--
-- PostgreSQL database dump
--

SET statement_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = off;
SET check_function_bodies = false;
SET client_min_messages = warning;
SET escape_string_warning = off;

SET search_path = public, pg_catalog;

SET default_tablespace = '';

SET default_with_oids = false;

--
-- Name: activite; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE activite (
    actid bigint NOT NULL,
    typactcod character varying(30) NOT NULL,
    catactcod character varying(20) NOT NULL,
    scrid bigint,
    comcod character varying(12),
    delegacod character varying(12),
    actlic character varying(90),
    actlib character varying(120),
    datdeb timestamp without time zone NOT NULL,
    datfin timestamp without time zone NOT NULL,
    validdat timestamp without time zone,
    envjodat timestamp without time zone,
    nb_participants bigint DEFAULT 0 NOT NULL,
    nb_delegations bigint DEFAULT 0 NOT NULL,
    giacod character varying(12),
    gecod character varying(12)
);


ALTER TABLE public.activite OWNER TO opendata;

--
-- Name: TABLE activite; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE activite IS 'Table des activités des Sénateurs faisant l''objet d''un relevé de présences';


--
-- Name: COLUMN activite.actid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN activite.actid IS 'Identifiant';


--
-- Name: COLUMN activite.typactcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN activite.typactcod IS 'Type';


--
-- Name: COLUMN activite.catactcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN activite.catactcod IS 'Catégorie';


--
-- Name: COLUMN activite.actlic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN activite.actlic IS 'Libellé court';


--
-- Name: COLUMN activite.actlib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN activite.actlib IS 'Libellé';


--
-- Name: activite_delegation; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE activite_delegation (
    delegactid bigint NOT NULL,
    actid bigint NOT NULL,
    senmat character(6) NOT NULL,
    senmat_delegue character(6),
    delegidx bigint DEFAULT 0 NOT NULL
);


ALTER TABLE public.activite_delegation OWNER TO opendata;

--
-- Name: TABLE activite_delegation; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE activite_delegation IS 'Délégations au cours d''une activité faisant l''objet d''un relevé de présences.';


--
-- Name: activite_loi; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE activite_loi (
    actid bigint NOT NULL,
    loicod character(12) NOT NULL
);


ALTER TABLE public.activite_loi OWNER TO opendata;

--
-- Name: TABLE activite_loi; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE activite_loi IS 'Liens optionnels vers les textes examinés lors d''une activité.';


--
-- Name: COLUMN activite_loi.actid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN activite_loi.actid IS 'Identifiant de l''activité';


--
-- Name: COLUMN activite_loi.loicod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN activite_loi.loicod IS 'Identifiant d''un texte dans la table loi de la base DOSLEG';


--
-- Name: activite_participant; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE activite_participant (
    actparid bigint NOT NULL,
    actid bigint NOT NULL,
    senmat character(6) NOT NULL,
    fapcod character varying(30) DEFAULT 'PARTICIPANT'::character varying NOT NULL,
    fapidx bigint DEFAULT 0,
    typactparcod character varying(20) DEFAULT 'PRESENT'::character varying NOT NULL,
    teleparticipation smallint DEFAULT 0
);


ALTER TABLE public.activite_participant OWNER TO opendata;

--
-- Name: TABLE activite_participant; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE activite_participant IS 'Participants à une activité.';


--
-- Name: COLUMN activite_participant.actparid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN activite_participant.actparid IS 'Identifiant';


--
-- Name: COLUMN activite_participant.actid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN activite_participant.actid IS 'Activité à laquelle le Sénateur participe';


--
-- Name: COLUMN activite_participant.senmat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN activite_participant.senmat IS 'Sénateur';


--
-- Name: COLUMN activite_participant.fapcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN activite_participant.fapcod IS 'Fonction particulière';


--
-- Name: COLUMN activite_participant.fapidx; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN activite_participant.fapidx IS 'Ordonnancement dans la fonction. Permet notamment d''ordonner les présidents de réunion.';


--
-- Name: COLUMN activite_participant.typactparcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN activite_participant.typactparcod IS 'Sénateur présent ou excusé (au sens de la commission, pas de l''article 23bis).';


--
-- Name: activite_senateur; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE activite_senateur (
    actsenid bigint NOT NULL,
    senmat character(6) NOT NULL,
    typactsencod character varying(20) NOT NULL,
    datdeb timestamp without time zone NOT NULL,
    datfin timestamp without time zone NOT NULL,
    libelle character varying(256)
);


ALTER TABLE public.activite_senateur OWNER TO opendata;

--
-- Name: TABLE activite_senateur; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE activite_senateur IS 'Activité personnelles saisies par un Sénateur';


--
-- Name: COLUMN activite_senateur.actsenid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN activite_senateur.actsenid IS 'Identifiant';


--
-- Name: COLUMN activite_senateur.senmat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN activite_senateur.senmat IS 'Sénateur';


--
-- Name: COLUMN activite_senateur.typactsencod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN activite_senateur.typactsencod IS 'Type d''activité';


--
-- Name: COLUMN activite_senateur.datdeb; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN activite_senateur.datdeb IS 'Début';


--
-- Name: COLUMN activite_senateur.datfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN activite_senateur.datfin IS 'Fin';


--
-- Name: activites_liees; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE activites_liees (
    gauche bigint NOT NULL,
    droite bigint NOT NULL
);


ALTER TABLE public.activites_liees OWNER TO opendata;

--
-- Name: TABLE activites_liees; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE activites_liees IS 'Table de regroupement d''activités. Permet notamment de modéliser les réunions communes entre commissions.';


--
-- Name: actpro; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE actpro (
    actprocod character varying(12) NOT NULL,
    actprolib character varying(60) NOT NULL,
    actpronumtri bigint,
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.actpro OWNER TO opendata;

--
-- Name: TABLE actpro; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE actpro IS 'Activités socio-professionnelles';


--
-- Name: COLUMN actpro.actprocod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN actpro.actprocod IS 'Code activité professionnelle';


--
-- Name: COLUMN actpro.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN actpro.syscredat IS 'Date système création';


--
-- Name: COLUMN actpro.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN actpro.sysmajdat IS 'Date système modification';


--
-- Name: adresse; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE adresse (
    adrid bigint NOT NULL,
    poiconid bigint NOT NULL,
    typbistercod character varying(12) NOT NULL,
    typvoicod character varying(12) NOT NULL,
    adrcmp character varying(38),
    adrcmp2 character varying(38),
    adrnumvoi character varying(38),
    adrnomvoi character varying(38),
    adrcom character varying(38),
    adrcodpos character(5),
    adrburdis character varying(38),
    adrcdxcod character varying(5),
    adrcdxlib character varying(38),
    adrnumtri bigint,
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.adresse OWNER TO opendata;

--
-- Name: TABLE adresse; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE adresse IS 'Adresses de Point de contact similiare à ADR (adresses)';


--
-- Name: COLUMN adresse.adrid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN adresse.adrid IS 'Identifiant';


--
-- Name: COLUMN adresse.poiconid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN adresse.poiconid IS 'Identifiant point de contact';


--
-- Name: COLUMN adresse.adrcmp; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN adresse.adrcmp IS 'Complément adresse';


--
-- Name: COLUMN adresse.adrcmp2; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN adresse.adrcmp2 IS 'Complément adresse 2';


--
-- Name: COLUMN adresse.adrnumvoi; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN adresse.adrnumvoi IS 'Numéro dans la voie';


--
-- Name: COLUMN adresse.adrnomvoi; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN adresse.adrnomvoi IS 'nom de la voie';


--
-- Name: COLUMN adresse.adrcom; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN adresse.adrcom IS 'Commune';


--
-- Name: COLUMN adresse.adrcodpos; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN adresse.adrcodpos IS 'Code postal';


--
-- Name: COLUMN adresse.adrburdis; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN adresse.adrburdis IS 'Bureau distributeur';


--
-- Name: COLUMN adresse.adrcdxcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN adresse.adrcdxcod IS 'Code Cedex';


--
-- Name: COLUMN adresse.adrcdxlib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN adresse.adrcdxlib IS 'Libellé Cedex';


--
-- Name: COLUMN adresse.adrnumtri; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN adresse.adrnumtri IS 'Numéro de tri';


--
-- Name: asster; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE asster (
    asstercod character varying(12) NOT NULL,
    assterlib character varying(120),
    assterlic character varying(60),
    assternumtri bigint,
    assterurlcmp character varying(255),
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone,
    assterart character varying(60)
);


ALTER TABLE public.asster OWNER TO opendata;

--
-- Name: TABLE asster; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE asster IS 'Assemblée territoriale';


--
-- Name: COLUMN asster.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN asster.syscredat IS 'Date système création';


--
-- Name: COLUMN asster.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN asster.sysmajdat IS 'Date système modification';


--
-- Name: bur; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE bur (
    burcod character varying(12) NOT NULL,
    burlib character varying(120),
    burlic character varying(60),
    burnumtri bigint,
    burlil character varying(255),
    burlibhon character varying(120),
    burlicfem character varying(60),
    burlibfem character varying(120),
    burlilfem character varying(255),
    burlicplu character varying(60),
    burlibplu character varying(120),
    burlilplu character varying(255),
    burlibhonfem character varying(120),
    burlibhonplu character varying(120),
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone,
    burlicfemplu character varying(60),
    burlibfemplu character varying(120),
    burlilfemplu character varying(255)
);


ALTER TABLE public.bur OWNER TO opendata;

--
-- Name: TABLE bur; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE bur IS 'Fonctions au bureau du Sénat';


--
-- Name: COLUMN bur.burcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN bur.burcod IS 'Code bureau 4e Rép.';


--
-- Name: COLUMN bur.burlib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN bur.burlib IS 'Libellé';


--
-- Name: COLUMN bur.burlic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN bur.burlic IS 'Libellé court';


--
-- Name: COLUMN bur.burnumtri; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN bur.burnumtri IS 'Numéro de tri';


--
-- Name: COLUMN bur.burlil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN bur.burlil IS 'Libellé long';


--
-- Name: COLUMN bur.burlibhon; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN bur.burlibhon IS 'Libellé honorariat';


--
-- Name: COLUMN bur.burlicfem; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN bur.burlicfem IS 'Libellé court féminin';


--
-- Name: COLUMN bur.burlibfem; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN bur.burlibfem IS 'Libellé féminin';


--
-- Name: COLUMN bur.burlilfem; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN bur.burlilfem IS 'Libellé long féminin';


--
-- Name: COLUMN bur.burlicplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN bur.burlicplu IS 'Libellé court pluriel';


--
-- Name: COLUMN bur.burlibplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN bur.burlibplu IS 'Libellé pluriel';


--
-- Name: COLUMN bur.burlilplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN bur.burlilplu IS 'Libellé long pluriel';


--
-- Name: COLUMN bur.burlibhonfem; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN bur.burlibhonfem IS 'Libellé honorariat féminin';


--
-- Name: COLUMN bur.burlibhonplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN bur.burlibhonplu IS 'Libellé honorariat pluriel';


--
-- Name: COLUMN bur.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN bur.syscredat IS 'Date système création';


--
-- Name: COLUMN bur.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN bur.sysmajdat IS 'Date système modification';


--
-- Name: COLUMN bur.burlicfemplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN bur.burlicfemplu IS 'Libellé court féminin pluriel';


--
-- Name: COLUMN bur.burlibfemplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN bur.burlibfemplu IS 'Libellé féminin pluriel';


--
-- Name: COLUMN bur.burlilfemplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN bur.burlilfemplu IS 'Libellé long féminin pluriel';


--
-- Name: categorie_activite; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE categorie_activite (
    catactcod character varying(20) NOT NULL,
    catactlic character varying(60) NOT NULL,
    catactlib character varying(120) NOT NULL,
    pleniere smallint DEFAULT 1,
    catactlibtap character varying(120),
    publiee_jo smallint DEFAULT 1
);


ALTER TABLE public.categorie_activite OWNER TO opendata;

--
-- Name: com; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE com (
    typorgcod character varying(12) NOT NULL,
    orgcod character varying(12) NOT NULL,
    orgnumtri bigint,
    orgdatcre timestamp without time zone,
    orgdatfin timestamp without time zone,
    orgnumtie character varying(12),
    temvalcod character varying(12),
    evelic character varying(60),
    evelib character varying(120),
    evelil character varying(500),
    orgart character varying(60),
    comlilmin character varying(500),
    orgurlsim character varying(500),
    orgurlcmp character varying(500),
    comlibameli character varying(120),
    comcodameli character varying(12),
    divcod character varying(12) DEFAULT '999'::character varying,
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.com OWNER TO opendata;

--
-- Name: TABLE com; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE com IS 'Commissions permanentes, spéciales, d''enquêtes, CMP, missions d''information.';


--
-- Name: COLUMN com.typorgcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN com.typorgcod IS 'Code type organisme';


--
-- Name: COLUMN com.orgcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN com.orgcod IS 'Code organisme';


--
-- Name: COLUMN com.orgnumtri; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN com.orgnumtri IS 'Numéro de tri';


--
-- Name: COLUMN com.orgdatcre; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN com.orgdatcre IS 'Date création';


--
-- Name: COLUMN com.orgdatfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN com.orgdatfin IS 'Date de fin';


--
-- Name: COLUMN com.orgnumtie; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN com.orgnumtie IS 'NuméroTiers';


--
-- Name: COLUMN com.temvalcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN com.temvalcod IS 'Code validité';


--
-- Name: COLUMN com.evelic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN com.evelic IS 'Libellé court';


--
-- Name: COLUMN com.evelib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN com.evelib IS 'Libellé';


--
-- Name: COLUMN com.evelil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN com.evelil IS 'Libellé long';


--
-- Name: COLUMN com.orgart; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN com.orgart IS 'Article';


--
-- Name: COLUMN com.comlilmin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN com.comlilmin IS 'Libellé long minuscule';


--
-- Name: COLUMN com.orgurlsim; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN com.orgurlsim IS 'URL simplifié';


--
-- Name: COLUMN com.orgurlcmp; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN com.orgurlcmp IS 'URL complet';


--
-- Name: COLUMN com.comlibameli; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN com.comlibameli IS 'Libellé AMELI';


--
-- Name: COLUMN com.comcodameli; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN com.comcodameli IS 'Code transfert AMELI';


--
-- Name: COLUMN com.divcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN com.divcod IS 'Code division';


--
-- Name: COLUMN com.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN com.syscredat IS 'Date système création';


--
-- Name: COLUMN com.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN com.sysmajdat IS 'Date système modification';


--
-- Name: csp; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE csp (
    cspcod character varying(12) NOT NULL,
    catprocod character varying(12) NOT NULL,
    cspfamcod character varying(12) NOT NULL,
    csplib character varying(120),
    cspnumtri bigint,
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.csp OWNER TO opendata;

--
-- Name: TABLE csp; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE csp IS 'Catégories Socio-professionnelles CSP de l''INSEE';


--
-- Name: COLUMN csp.cspcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN csp.cspcod IS 'Code CSP';


--
-- Name: COLUMN csp.catprocod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN csp.catprocod IS 'Code catégorie professionnelle';


--
-- Name: COLUMN csp.cspfamcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN csp.cspfamcod IS 'Code famille CSP';


--
-- Name: COLUMN csp.csplib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN csp.csplib IS 'Rubrique CSP';


--
-- Name: COLUMN csp.cspnumtri; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN csp.cspnumtri IS 'Numéro de tri CSP';


--
-- Name: COLUMN csp.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN csp.syscredat IS 'Date système création';


--
-- Name: COLUMN csp.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN csp.sysmajdat IS 'Date système modification';


--
-- Name: delega; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE delega (
    typorgcod character varying(12) NOT NULL,
    orgcod character varying(12) NOT NULL,
    orgnumtri bigint,
    orgdatcre timestamp without time zone,
    orgdatfin timestamp without time zone,
    orgnumtie character varying(12),
    temvalcod character varying(12),
    evelic character varying(60),
    evelib character varying(120),
    evelil character varying(255),
    orgart character varying(60),
    orgurlsim character varying(255),
    orgurlcmp character varying(255),
    orgregjur character varying(255),
    orgmoddes character varying(255),
    orgmemdep character varying(12) DEFAULT 'NON'::character varying,
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.delega OWNER TO opendata;

--
-- Name: TABLE delega; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE delega IS 'Délégations parlementaires';


--
-- Name: COLUMN delega.typorgcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN delega.typorgcod IS 'Code type organisme';


--
-- Name: COLUMN delega.orgcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN delega.orgcod IS 'Code organisme';


--
-- Name: COLUMN delega.orgnumtri; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN delega.orgnumtri IS 'Numéro de tri';


--
-- Name: COLUMN delega.orgdatcre; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN delega.orgdatcre IS 'Date création';


--
-- Name: COLUMN delega.orgdatfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN delega.orgdatfin IS 'Date de fin';


--
-- Name: COLUMN delega.orgnumtie; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN delega.orgnumtie IS 'NuméroTiers';


--
-- Name: COLUMN delega.temvalcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN delega.temvalcod IS 'Code validité';


--
-- Name: COLUMN delega.evelic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN delega.evelic IS 'Libellé court';


--
-- Name: COLUMN delega.evelib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN delega.evelib IS 'Libellé';


--
-- Name: COLUMN delega.evelil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN delega.evelil IS 'Libellé long';


--
-- Name: COLUMN delega.orgart; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN delega.orgart IS 'Article';


--
-- Name: COLUMN delega.orgurlsim; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN delega.orgurlsim IS 'URL simplifié';


--
-- Name: COLUMN delega.orgurlcmp; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN delega.orgurlcmp IS 'URL complet';


--
-- Name: COLUMN delega.orgregjur; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN delega.orgregjur IS 'Régime juridique';


--
-- Name: COLUMN delega.orgmoddes; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN delega.orgmoddes IS 'Mode désignation';


--
-- Name: COLUMN delega.orgmemdep; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN delega.orgmemdep IS 'Membres Députés';


--
-- Name: COLUMN delega.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN delega.syscredat IS 'Date système création';


--
-- Name: COLUMN delega.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN delega.sysmajdat IS 'Date système modification';


--
-- Name: design; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE design (
    designcod character varying(12) NOT NULL,
    moddescod character varying(12) NOT NULL,
    temvalcod character varying(12),
    orgcod character varying(12) NOT NULL,
    evelic character varying(60),
    evelib character varying(120),
    evelil character varying(255),
    eveobs character varying(255),
    designnumtri bigint,
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.design OWNER TO opendata;

--
-- Name: TABLE design; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE design IS 'Désignataires';


--
-- Name: COLUMN design.designcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN design.designcod IS 'Code désignataire';


--
-- Name: COLUMN design.moddescod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN design.moddescod IS 'Code';


--
-- Name: COLUMN design.temvalcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN design.temvalcod IS 'Code validité';


--
-- Name: COLUMN design.orgcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN design.orgcod IS 'Code organisme';


--
-- Name: COLUMN design.evelic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN design.evelic IS 'Libellé court';


--
-- Name: COLUMN design.evelib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN design.evelib IS 'Libellé';


--
-- Name: COLUMN design.evelil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN design.evelil IS 'Libellé long';


--
-- Name: COLUMN design.eveobs; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN design.eveobs IS 'Observations';


--
-- Name: COLUMN design.designnumtri; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN design.designnumtri IS 'Numéro de tri';


--
-- Name: COLUMN design.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN design.syscredat IS 'Date système création';


--
-- Name: COLUMN design.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN design.sysmajdat IS 'Date système modification';


--
-- Name: designoep; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE designoep (
    designcod character varying(12) NOT NULL,
    temvalcod character varying(12),
    orgcod character varying(12) NOT NULL,
    evelic character varying(60),
    evelib character varying(120),
    evelil character varying(255),
    designoepnumtri bigint,
    designoepnbrtit bigint,
    designoepnbrsup bigint,
    designoepdatdeb timestamp without time zone,
    designoepdatfin timestamp without time zone,
    designoepid bigint NOT NULL,
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone,
    fonmemextparcod character varying(20) DEFAULT 'MEMBRE'::character varying NOT NULL,
    fontemrem character varying(12) DEFAULT 'NON'::character varying,
    fonremlil character varying(512),
    incompat character varying(1024)
);


ALTER TABLE public.designoep OWNER TO opendata;

--
-- Name: COLUMN designoep.designcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN designoep.designcod IS 'Code désignataire';


--
-- Name: COLUMN designoep.temvalcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN designoep.temvalcod IS 'Code validité';


--
-- Name: COLUMN designoep.orgcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN designoep.orgcod IS 'Code organisme';


--
-- Name: COLUMN designoep.evelic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN designoep.evelic IS 'Libellé court';


--
-- Name: COLUMN designoep.evelib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN designoep.evelib IS 'Libellé';


--
-- Name: COLUMN designoep.evelil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN designoep.evelil IS 'Libellé long';


--
-- Name: COLUMN designoep.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN designoep.syscredat IS 'Date système création';


--
-- Name: COLUMN designoep.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN designoep.sysmajdat IS 'Date système modification';


--
-- Name: designorg; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE designorg (
    designcod character varying(12) NOT NULL,
    temvalcod character varying(12),
    evelic character varying(60),
    evelib character varying(120),
    evelil character varying(255),
    eveobs character varying(255),
    designnumtri bigint,
    designlib character varying(120),
    designlic character varying(60),
    designlil character varying(255),
    designlibfem character varying(120),
    designlicfem character varying(60),
    designlilfem character varying(255),
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.designorg OWNER TO opendata;

--
-- Name: TABLE designorg; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE designorg IS 'Désignataires d''organismes';


--
-- Name: COLUMN designorg.designcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN designorg.designcod IS 'Code désignataire';


--
-- Name: COLUMN designorg.temvalcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN designorg.temvalcod IS 'Code validité';


--
-- Name: COLUMN designorg.evelic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN designorg.evelic IS 'Libellé court';


--
-- Name: COLUMN designorg.evelib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN designorg.evelib IS 'Libellé';


--
-- Name: COLUMN designorg.evelil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN designorg.evelil IS 'Libellé long';


--
-- Name: COLUMN designorg.eveobs; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN designorg.eveobs IS 'Observations';


--
-- Name: COLUMN designorg.designnumtri; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN designorg.designnumtri IS 'Numéro de tri';


--
-- Name: COLUMN designorg.designlib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN designorg.designlib IS 'Libellé';


--
-- Name: COLUMN designorg.designlic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN designorg.designlic IS 'Libellé court';


--
-- Name: COLUMN designorg.designlil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN designorg.designlil IS 'Libellé long';


--
-- Name: COLUMN designorg.designlibfem; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN designorg.designlibfem IS 'Lbellé féminin';


--
-- Name: COLUMN designorg.designlicfem; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN designorg.designlicfem IS 'Libellé féminin court';


--
-- Name: COLUMN designorg.designlilfem; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN designorg.designlilfem IS 'Libellé féminin long';


--
-- Name: COLUMN designorg.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN designorg.syscredat IS 'Date système création';


--
-- Name: COLUMN designorg.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN designorg.sysmajdat IS 'Date système modification';


--
-- Name: dpt; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE dpt (
    dptnum bigint NOT NULL,
    dptcod character varying(12) NOT NULL,
    dptlib character varying(120) NOT NULL,
    dptnbrsen bigint,
    dptmodscrsen character varying(12),
    dptser character(1) NOT NULL,
    regcod character varying(12) NOT NULL,
    dptnumtri bigint NOT NULL,
    dptlic character varying(60),
    dptart character varying(60),
    dptlibtri character varying(120),
    temvalcod character varying(12),
    evelic character varying(60),
    evelib character varying(120),
    evelil character varying(255),
    dptser2004 character(1),
    dptcmt character varying(255),
    dptdatdeb timestamp without time zone,
    dptdatfin timestamp without time zone,
    dpturlcmp character varying(255),
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.dpt OWNER TO opendata;

--
-- Name: TABLE dpt; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE dpt IS 'Départements ou circonscriptions';


--
-- Name: COLUMN dpt.dptnum; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN dpt.dptnum IS 'Identifiant circonscription';


--
-- Name: COLUMN dpt.dptcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN dpt.dptcod IS 'Code INSEE';


--
-- Name: COLUMN dpt.dptlib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN dpt.dptlib IS 'Libellé';


--
-- Name: COLUMN dpt.dptnbrsen; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN dpt.dptnbrsen IS 'Nombre sénateurs';


--
-- Name: COLUMN dpt.dptmodscrsen; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN dpt.dptmodscrsen IS 'Mode scrutin sénatorial';


--
-- Name: COLUMN dpt.dptser; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN dpt.dptser IS 'Série (A,B,C)';


--
-- Name: COLUMN dpt.regcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN dpt.regcod IS 'Code région';


--
-- Name: COLUMN dpt.dptnumtri; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN dpt.dptnumtri IS 'Numéro de tri';


--
-- Name: COLUMN dpt.dptlic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN dpt.dptlic IS 'Libellé court';


--
-- Name: COLUMN dpt.dptart; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN dpt.dptart IS 'Article';


--
-- Name: COLUMN dpt.dptlibtri; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN dpt.dptlibtri IS 'Libellé Moyen';


--
-- Name: COLUMN dpt.temvalcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN dpt.temvalcod IS 'Code validité';


--
-- Name: COLUMN dpt.evelic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN dpt.evelic IS 'Libellé court';


--
-- Name: COLUMN dpt.evelib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN dpt.evelib IS 'Libellé';


--
-- Name: COLUMN dpt.evelil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN dpt.evelil IS 'Libellé long';


--
-- Name: COLUMN dpt.dptser2004; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN dpt.dptser2004 IS 'Série (1,2)';


--
-- Name: COLUMN dpt.dptcmt; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN dpt.dptcmt IS 'Commentaire listes';


--
-- Name: COLUMN dpt.dptdatdeb; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN dpt.dptdatdeb IS 'Date de début';


--
-- Name: COLUMN dpt.dptdatfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN dpt.dptdatfin IS 'Date de fin';


--
-- Name: COLUMN dpt.dpturlcmp; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN dpt.dpturlcmp IS 'URL';


--
-- Name: COLUMN dpt.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN dpt.syscredat IS 'Date système création';


--
-- Name: COLUMN dpt.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN dpt.sysmajdat IS 'Date système modification';


--
-- Name: dptele; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE dptele (
    dptnum bigint NOT NULL,
    dptelenbrsie bigint,
    dpteleid bigint NOT NULL,
    typelecod character varying(12) DEFAULT 'NEANT'::character varying NOT NULL,
    validcod character varying(32) DEFAULT 'NODATA'::character varying NOT NULL,
    valid2cod character varying(32) DEFAULT 'NODATA'::character varying NOT NULL,
    participaidt1 bigint,
    participaidt2 bigint,
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone,
    eleid bigint NOT NULL,
    dptelenbrsiepvr bigint,
    dptelecmt character varying(255)
);


ALTER TABLE public.dptele OWNER TO opendata;

--
-- Name: TABLE dptele; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE dptele IS 'Elections circonscriptions';


--
-- Name: COLUMN dptele.dptnum; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN dptele.dptnum IS 'Identifiant circonscription';


--
-- Name: COLUMN dptele.dptelenbrsie; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN dptele.dptelenbrsie IS 'Nombre de sièges';


--
-- Name: COLUMN dptele.dpteleid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN dptele.dpteleid IS 'Identifiant';


--
-- Name: COLUMN dptele.typelecod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN dptele.typelecod IS 'Code type élection';


--
-- Name: COLUMN dptele.validcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN dptele.validcod IS 'Code validation';


--
-- Name: COLUMN dptele.valid2cod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN dptele.valid2cod IS 'Code validation';


--
-- Name: COLUMN dptele.participaidt1; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN dptele.participaidt1 IS 'Identifiant participation';


--
-- Name: COLUMN dptele.participaidt2; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN dptele.participaidt2 IS 'Identifiant participation';


--
-- Name: COLUMN dptele.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN dptele.syscredat IS 'Date système création';


--
-- Name: COLUMN dptele.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN dptele.sysmajdat IS 'Date système modification';


--
-- Name: COLUMN dptele.eleid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN dptele.eleid IS 'Identifiant';


--
-- Name: dpttypman; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE dpttypman (
    dptnum bigint NOT NULL,
    typmancod character varying(12) NOT NULL,
    dpttypmanid bigint NOT NULL
);


ALTER TABLE public.dpttypman OWNER TO opendata;

--
-- Name: COLUMN dpttypman.dptnum; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN dpttypman.dptnum IS 'Identifiant circonscription';


--
-- Name: COLUMN dpttypman.typmancod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN dpttypman.typmancod IS 'Code type mandat';


--
-- Name: ele; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE ele (
    typmancod character varying(12) NOT NULL,
    eleann character varying(12) NOT NULL,
    eledat timestamp without time zone,
    eledatdeb timestamp without time zone,
    eledatfinpre timestamp without time zone,
    eleser character(1),
    elelic character varying(60),
    elelib character varying(120),
    elelil character varying(255),
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone,
    eleid bigint NOT NULL,
    elepar character varying(12) DEFAULT 'NON'::character varying
);


ALTER TABLE public.ele OWNER TO opendata;

--
-- Name: TABLE ele; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE ele IS 'Elections';


--
-- Name: COLUMN ele.typmancod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN ele.typmancod IS 'Code type mandat';


--
-- Name: COLUMN ele.eleann; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN ele.eleann IS 'Année';


--
-- Name: COLUMN ele.eledat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN ele.eledat IS 'Date de l''élection';


--
-- Name: COLUMN ele.eledatdeb; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN ele.eledatdeb IS 'Date début mandat';


--
-- Name: COLUMN ele.eledatfinpre; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN ele.eledatfinpre IS 'Date fin mandat précédent';


--
-- Name: COLUMN ele.eleser; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN ele.eleser IS 'Série';


--
-- Name: COLUMN ele.elelic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN ele.elelic IS 'Libellé court';


--
-- Name: COLUMN ele.elelib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN ele.elelib IS 'Libellé';


--
-- Name: COLUMN ele.elelil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN ele.elelil IS 'Libellé long';


--
-- Name: COLUMN ele.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN ele.syscredat IS 'Date système création';


--
-- Name: COLUMN ele.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN ele.sysmajdat IS 'Date système modification';


--
-- Name: COLUMN ele.eleid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN ele.eleid IS 'Identifiant';


--
-- Name: COLUMN ele.elepar; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN ele.elepar IS 'Élection partielle';


--
-- Name: elucan; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE elucan (
    eluid bigint NOT NULL,
    eludatdeb timestamp without time zone,
    eludatelu timestamp without time zone,
    eludatfin timestamp without time zone,
    temvalcod character varying(12),
    evelic character varying(60),
    evelib character varying(120),
    evelil character varying(255),
    eveobs character varying(255),
    eluanndeb bigint,
    eluannfin bigint,
    elunbrhab bigint,
    typmancod character varying(12),
    dptnum bigint,
    senmat character(6) NOT NULL,
    canart character varying(60),
    eludatcum timestamp without time zone,
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.elucan OWNER TO opendata;

--
-- Name: TABLE elucan; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE elucan IS 'Elu conseiller général (canton)';


--
-- Name: COLUMN elucan.eluid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elucan.eluid IS 'Identifiant';


--
-- Name: COLUMN elucan.eludatdeb; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elucan.eludatdeb IS 'Date début mandat';


--
-- Name: COLUMN elucan.eludatelu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elucan.eludatelu IS 'Date d''élection';


--
-- Name: COLUMN elucan.eludatfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elucan.eludatfin IS 'Date fin mandat';


--
-- Name: COLUMN elucan.temvalcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elucan.temvalcod IS 'Code validité';


--
-- Name: COLUMN elucan.evelic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elucan.evelic IS 'Libellé court';


--
-- Name: COLUMN elucan.evelib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elucan.evelib IS 'Libellé';


--
-- Name: COLUMN elucan.evelil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elucan.evelil IS 'Libellé long';


--
-- Name: COLUMN elucan.eveobs; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elucan.eveobs IS 'Observations';


--
-- Name: COLUMN elucan.eluanndeb; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elucan.eluanndeb IS 'Année début mandat';


--
-- Name: COLUMN elucan.eluannfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elucan.eluannfin IS 'Année fin mandat';


--
-- Name: COLUMN elucan.elunbrhab; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elucan.elunbrhab IS 'Nombre d''habitants';


--
-- Name: COLUMN elucan.typmancod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elucan.typmancod IS 'Code type mandat';


--
-- Name: COLUMN elucan.dptnum; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elucan.dptnum IS 'Identifiant du département';


--
-- Name: COLUMN elucan.senmat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elucan.senmat IS 'Matricule';


--
-- Name: COLUMN elucan.canart; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elucan.canart IS 'Aaticle de la circonscription';


--
-- Name: COLUMN elucan.eludatcum; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elucan.eludatcum IS 'Date cumul';


--
-- Name: COLUMN elucan.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elucan.syscredat IS 'Date système création';


--
-- Name: COLUMN elucan.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elucan.sysmajdat IS 'Date système modification';


--
-- Name: eludep; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE eludep (
    eluid bigint NOT NULL,
    eludatdeb timestamp without time zone,
    depcod character varying(12),
    eludatelu timestamp without time zone,
    eludatfin timestamp without time zone,
    temvalcod character varying(12),
    evelic character varying(60),
    evelib character varying(120),
    evelil character varying(255),
    eveobs character varying(255),
    eluanndeb bigint,
    eluannfin bigint,
    elunbrhab bigint,
    typmancod character varying(12),
    senmat character(6) NOT NULL,
    eludatcum timestamp without time zone,
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone,
    id_organe_assnat character varying(50) DEFAULT NULL::character varying,
    circo bigint
);


ALTER TABLE public.eludep OWNER TO opendata;

--
-- Name: TABLE eludep; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE eludep IS 'Elu député';


--
-- Name: COLUMN eludep.eluid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eludep.eluid IS 'Identifiant';


--
-- Name: COLUMN eludep.eludatdeb; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eludep.eludatdeb IS 'Date début mandat';


--
-- Name: COLUMN eludep.eludatelu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eludep.eludatelu IS 'Date d''élection';


--
-- Name: COLUMN eludep.eludatfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eludep.eludatfin IS 'Date fin mandat';


--
-- Name: COLUMN eludep.temvalcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eludep.temvalcod IS 'Code validité';


--
-- Name: COLUMN eludep.evelic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eludep.evelic IS 'Libellé court';


--
-- Name: COLUMN eludep.evelib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eludep.evelib IS 'Libellé';


--
-- Name: COLUMN eludep.evelil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eludep.evelil IS 'Libellé long';


--
-- Name: COLUMN eludep.eveobs; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eludep.eveobs IS 'Observations';


--
-- Name: COLUMN eludep.eluanndeb; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eludep.eluanndeb IS 'Année début mandat';


--
-- Name: COLUMN eludep.eluannfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eludep.eluannfin IS 'Année fin mandat';


--
-- Name: COLUMN eludep.elunbrhab; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eludep.elunbrhab IS 'Nombre d''habitants';


--
-- Name: COLUMN eludep.typmancod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eludep.typmancod IS 'Code type mandat';


--
-- Name: COLUMN eludep.senmat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eludep.senmat IS 'Matricule';


--
-- Name: COLUMN eludep.eludatcum; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eludep.eludatcum IS 'Date cumul';


--
-- Name: COLUMN eludep.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eludep.syscredat IS 'Date système création';


--
-- Name: COLUMN eludep.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eludep.sysmajdat IS 'Date système modification';


--
-- Name: eludiv; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE eludiv (
    eluid bigint NOT NULL,
    eludatdeb timestamp without time zone,
    eludatelu timestamp without time zone,
    eludatfin timestamp without time zone,
    temvalcod character varying(12),
    evelic character varying(60),
    evelib character varying(120),
    evelil character varying(255),
    eveobs character varying(255),
    eluanndeb bigint,
    eluannfin bigint,
    elunbrhab bigint,
    typmancod character varying(12),
    senmat character(6) NOT NULL,
    eludatcum timestamp without time zone,
    eludivurlcmp character varying(255),
    eludivart character varying(60),
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.eludiv OWNER TO opendata;

--
-- Name: TABLE eludiv; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE eludiv IS 'Elus divers';


--
-- Name: COLUMN eludiv.eluid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eludiv.eluid IS 'Identifiant';


--
-- Name: COLUMN eludiv.eludatdeb; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eludiv.eludatdeb IS 'Date début mandat';


--
-- Name: COLUMN eludiv.eludatelu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eludiv.eludatelu IS 'Date d''élection';


--
-- Name: COLUMN eludiv.eludatfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eludiv.eludatfin IS 'Date fin mandat';


--
-- Name: COLUMN eludiv.temvalcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eludiv.temvalcod IS 'Code validité';


--
-- Name: COLUMN eludiv.evelic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eludiv.evelic IS 'Libellé court';


--
-- Name: COLUMN eludiv.evelib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eludiv.evelib IS 'Libellé';


--
-- Name: COLUMN eludiv.evelil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eludiv.evelil IS 'Libellé long';


--
-- Name: COLUMN eludiv.eveobs; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eludiv.eveobs IS 'Observations';


--
-- Name: COLUMN eludiv.eluanndeb; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eludiv.eluanndeb IS 'Année début mandat';


--
-- Name: COLUMN eludiv.eluannfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eludiv.eluannfin IS 'Année fin mandat';


--
-- Name: COLUMN eludiv.elunbrhab; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eludiv.elunbrhab IS 'Nombre d''habitants';


--
-- Name: COLUMN eludiv.typmancod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eludiv.typmancod IS 'Code type mandat';


--
-- Name: COLUMN eludiv.senmat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eludiv.senmat IS 'Matricule';


--
-- Name: COLUMN eludiv.eludatcum; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eludiv.eludatcum IS 'Date cumul';


--
-- Name: COLUMN eludiv.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eludiv.syscredat IS 'Date système création';


--
-- Name: COLUMN eludiv.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eludiv.sysmajdat IS 'Date système modification';


--
-- Name: elueur; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE elueur (
    eluid bigint NOT NULL,
    eludatdeb timestamp without time zone,
    eludatelu timestamp without time zone,
    eludatfin timestamp without time zone,
    nationcod character varying(12),
    temvalcod character varying(12),
    evelic character varying(60),
    evelib character varying(120),
    evelil character varying(255),
    eveobs character varying(255),
    eluanndeb bigint,
    eluannfin bigint,
    elunbrhab bigint,
    typmancod character varying(12),
    senmat character(6) NOT NULL,
    eludatcum timestamp without time zone,
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.elueur OWNER TO opendata;

--
-- Name: TABLE elueur; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE elueur IS 'ELU européen';


--
-- Name: COLUMN elueur.eluid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elueur.eluid IS 'Identifiant';


--
-- Name: COLUMN elueur.eludatdeb; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elueur.eludatdeb IS 'Date début mandat';


--
-- Name: COLUMN elueur.eludatelu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elueur.eludatelu IS 'Date d''élection';


--
-- Name: COLUMN elueur.eludatfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elueur.eludatfin IS 'Date fin mandat';


--
-- Name: COLUMN elueur.temvalcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elueur.temvalcod IS 'Code validité';


--
-- Name: COLUMN elueur.evelic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elueur.evelic IS 'Libellé court';


--
-- Name: COLUMN elueur.evelib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elueur.evelib IS 'Libellé';


--
-- Name: COLUMN elueur.evelil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elueur.evelil IS 'Libellé long';


--
-- Name: COLUMN elueur.eveobs; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elueur.eveobs IS 'Observations';


--
-- Name: COLUMN elueur.eluanndeb; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elueur.eluanndeb IS 'Année début mandat';


--
-- Name: COLUMN elueur.eluannfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elueur.eluannfin IS 'Année fin mandat';


--
-- Name: COLUMN elueur.elunbrhab; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elueur.elunbrhab IS 'Nombre d''habitants';


--
-- Name: COLUMN elueur.typmancod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elueur.typmancod IS 'Code type mandat';


--
-- Name: COLUMN elueur.senmat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elueur.senmat IS 'Matricule';


--
-- Name: COLUMN elueur.eludatcum; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elueur.eludatcum IS 'Date cumul';


--
-- Name: COLUMN elueur.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elueur.syscredat IS 'Date système création';


--
-- Name: COLUMN elueur.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elueur.sysmajdat IS 'Date système modification';


--
-- Name: elureg; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE elureg (
    eluid bigint NOT NULL,
    eludatdeb timestamp without time zone,
    regcod character varying(12),
    eludatelu timestamp without time zone,
    eludatfin timestamp without time zone,
    temvalcod character varying(12),
    evelic character varying(60),
    evelib character varying(120),
    evelil character varying(255),
    eveobs character varying(255),
    eluanndeb bigint,
    eluannfin bigint,
    elunbrhab bigint,
    typmancod character varying(12),
    senmat character(6) NOT NULL,
    eludatcum timestamp without time zone,
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.elureg OWNER TO opendata;

--
-- Name: TABLE elureg; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE elureg IS 'ELU conseiller régional';


--
-- Name: COLUMN elureg.eluid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elureg.eluid IS 'Identifiant';


--
-- Name: COLUMN elureg.eludatdeb; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elureg.eludatdeb IS 'Date début mandat';


--
-- Name: COLUMN elureg.regcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elureg.regcod IS 'Code région';


--
-- Name: COLUMN elureg.eludatelu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elureg.eludatelu IS 'Date d''élection';


--
-- Name: COLUMN elureg.eludatfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elureg.eludatfin IS 'Date fin mandat';


--
-- Name: COLUMN elureg.temvalcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elureg.temvalcod IS 'Code validité';


--
-- Name: COLUMN elureg.evelic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elureg.evelic IS 'Libellé court';


--
-- Name: COLUMN elureg.evelib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elureg.evelib IS 'Libellé';


--
-- Name: COLUMN elureg.evelil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elureg.evelil IS 'Libellé long';


--
-- Name: COLUMN elureg.eveobs; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elureg.eveobs IS 'Observations';


--
-- Name: COLUMN elureg.eluanndeb; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elureg.eluanndeb IS 'Année début mandat';


--
-- Name: COLUMN elureg.eluannfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elureg.eluannfin IS 'Année fin mandat';


--
-- Name: COLUMN elureg.elunbrhab; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elureg.elunbrhab IS 'Nombre d''habitants';


--
-- Name: COLUMN elureg.typmancod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elureg.typmancod IS 'Code type mandat';


--
-- Name: COLUMN elureg.senmat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elureg.senmat IS 'Matricule';


--
-- Name: COLUMN elureg.eludatcum; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elureg.eludatcum IS 'Date cumul';


--
-- Name: COLUMN elureg.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elureg.syscredat IS 'Date système création';


--
-- Name: COLUMN elureg.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elureg.sysmajdat IS 'Date système modification';


--
-- Name: elusen; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE elusen (
    eluid bigint NOT NULL,
    dptnum bigint NOT NULL,
    eludatdeb timestamp without time zone,
    eludatelu timestamp without time zone,
    eludatfin timestamp without time zone,
    etadebmancod character varying(12) NOT NULL,
    etafinmancod character varying(12),
    temvalcod character varying(12),
    evelic character varying(60),
    evelib character varying(120),
    evelil character varying(255),
    eluanndeb bigint,
    eluannfin bigint,
    typmancod character varying(12),
    senmat character(6) NOT NULL,
    eludatcum timestamp without time zone,
    turelucod character varying(12) DEFAULT 'NR'::character varying NOT NULL,
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.elusen OWNER TO opendata;

--
-- Name: TABLE elusen; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE elusen IS 'Mandats Sénateurs';


--
-- Name: COLUMN elusen.eluid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elusen.eluid IS 'Identifiant';


--
-- Name: COLUMN elusen.dptnum; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elusen.dptnum IS 'Identifiant circonscription';


--
-- Name: COLUMN elusen.eludatdeb; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elusen.eludatdeb IS 'Date début mandat';


--
-- Name: COLUMN elusen.eludatelu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elusen.eludatelu IS 'Date d''élection';


--
-- Name: COLUMN elusen.eludatfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elusen.eludatfin IS 'Date fin mandat';


--
-- Name: COLUMN elusen.etadebmancod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elusen.etadebmancod IS 'Code début de mandat';


--
-- Name: COLUMN elusen.etafinmancod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elusen.etafinmancod IS 'Code état fin de mandat';


--
-- Name: COLUMN elusen.temvalcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elusen.temvalcod IS 'Code validité';


--
-- Name: COLUMN elusen.evelic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elusen.evelic IS 'Libellé court';


--
-- Name: COLUMN elusen.evelib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elusen.evelib IS 'Libellé';


--
-- Name: COLUMN elusen.evelil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elusen.evelil IS 'Libellé long';


--
-- Name: COLUMN elusen.eluanndeb; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elusen.eluanndeb IS 'Année début mandat';


--
-- Name: COLUMN elusen.eluannfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elusen.eluannfin IS 'Année fin mandat';


--
-- Name: COLUMN elusen.typmancod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elusen.typmancod IS 'Code type mandat';


--
-- Name: COLUMN elusen.senmat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elusen.senmat IS 'Matricule';


--
-- Name: COLUMN elusen.eludatcum; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elusen.eludatcum IS 'Date cumul';


--
-- Name: COLUMN elusen.turelucod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elusen.turelucod IS 'Code tour élection';


--
-- Name: COLUMN elusen.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elusen.syscredat IS 'Date système création';


--
-- Name: COLUMN elusen.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elusen.sysmajdat IS 'Date système modification';


--
-- Name: eluter; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE eluter (
    eluid bigint NOT NULL,
    asstercod character varying(12),
    typmancod character varying(12),
    temvalcod character varying(12),
    evelic character varying(60),
    evelib character varying(120),
    evelil character varying(255),
    eveobs character varying(255),
    eludatdeb timestamp without time zone,
    eluanndeb bigint,
    eludatelu timestamp without time zone,
    eludatfin timestamp without time zone,
    eluannfin bigint,
    elunbrhab bigint,
    senmat character(6) NOT NULL,
    eludatcum timestamp without time zone,
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.eluter OWNER TO opendata;

--
-- Name: TABLE eluter; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE eluter IS 'Elu Assemblée Territoriale ou de la Corse';


--
-- Name: COLUMN eluter.eluid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eluter.eluid IS 'Identifiant';


--
-- Name: COLUMN eluter.typmancod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eluter.typmancod IS 'Code type mandat';


--
-- Name: COLUMN eluter.temvalcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eluter.temvalcod IS 'Code validité';


--
-- Name: COLUMN eluter.evelic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eluter.evelic IS 'Libellé court';


--
-- Name: COLUMN eluter.evelib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eluter.evelib IS 'Libellé';


--
-- Name: COLUMN eluter.evelil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eluter.evelil IS 'Libellé long';


--
-- Name: COLUMN eluter.eveobs; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eluter.eveobs IS 'Observations';


--
-- Name: COLUMN eluter.eludatdeb; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eluter.eludatdeb IS 'Date début mandat';


--
-- Name: COLUMN eluter.eluanndeb; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eluter.eluanndeb IS 'Année début mandat';


--
-- Name: COLUMN eluter.eludatelu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eluter.eludatelu IS 'Date d''élection';


--
-- Name: COLUMN eluter.eludatfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eluter.eludatfin IS 'Date fin mandat';


--
-- Name: COLUMN eluter.eluannfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eluter.eluannfin IS 'Année fin mandat';


--
-- Name: COLUMN eluter.elunbrhab; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eluter.elunbrhab IS 'Nombre d''habitants';


--
-- Name: COLUMN eluter.senmat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eluter.senmat IS 'Matricule';


--
-- Name: COLUMN eluter.eludatcum; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eluter.eludatcum IS 'Date cumul';


--
-- Name: COLUMN eluter.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eluter.syscredat IS 'Date système création';


--
-- Name: COLUMN eluter.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eluter.sysmajdat IS 'Date système modification';


--
-- Name: elutit; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE elutit (
    eluid bigint NOT NULL,
    titeluid bigint NOT NULL,
    titelecod character varying(12) NOT NULL,
    titeludatdeb timestamp without time zone,
    titeluanndeb bigint,
    titeludatfin timestamp without time zone,
    titeluannfin bigint,
    temvalcod character varying(12),
    evelic character varying(60),
    evelib character varying(120),
    evelil character varying(255),
    titeluhon character varying(12),
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.elutit OWNER TO opendata;

--
-- Name: TABLE elutit; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE elutit IS 'Titres des élus';


--
-- Name: COLUMN elutit.eluid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elutit.eluid IS 'Identifiant';


--
-- Name: COLUMN elutit.titeluid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elutit.titeluid IS 'Identifiant';


--
-- Name: COLUMN elutit.titelecod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elutit.titelecod IS 'Code titre élu';


--
-- Name: COLUMN elutit.titeludatdeb; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elutit.titeludatdeb IS 'Date de début';


--
-- Name: COLUMN elutit.titeluanndeb; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elutit.titeluanndeb IS 'Année de début';


--
-- Name: COLUMN elutit.titeludatfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elutit.titeludatfin IS 'Date de fin';


--
-- Name: COLUMN elutit.titeluannfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elutit.titeluannfin IS 'Année de fin';


--
-- Name: COLUMN elutit.temvalcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elutit.temvalcod IS 'Code validité';


--
-- Name: COLUMN elutit.evelic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elutit.evelic IS 'Libellé court';


--
-- Name: COLUMN elutit.evelib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elutit.evelib IS 'Libellé';


--
-- Name: COLUMN elutit.evelil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elutit.evelil IS 'Libellé long';


--
-- Name: COLUMN elutit.titeluhon; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elutit.titeluhon IS 'Honorariat';


--
-- Name: COLUMN elutit.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elutit.syscredat IS 'Date système création';


--
-- Name: COLUMN elutit.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN elutit.sysmajdat IS 'Date système modification';


--
-- Name: eluvil; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE eluvil (
    eluid bigint NOT NULL,
    eludatdeb timestamp without time zone,
    eludatelu timestamp without time zone,
    eludatfin timestamp without time zone,
    temvalcod character varying(12),
    evelic character varying(60),
    evelib character varying(120),
    evelil character varying(255),
    eveobs character varying(255),
    eluanndeb bigint,
    eluannfin bigint,
    elunbrhab bigint,
    typmancod character varying(12),
    senmat character(6) NOT NULL,
    vilart character varying(60),
    eludatcum timestamp without time zone,
    vilurlcmp character varying(255),
    url character varying(120),
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.eluvil OWNER TO opendata;

--
-- Name: TABLE eluvil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE eluvil IS 'ELU conseiller municipal';


--
-- Name: COLUMN eluvil.eluid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eluvil.eluid IS 'Identifiant';


--
-- Name: COLUMN eluvil.eludatdeb; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eluvil.eludatdeb IS 'Date début mandat';


--
-- Name: COLUMN eluvil.eludatelu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eluvil.eludatelu IS 'Date d''élection';


--
-- Name: COLUMN eluvil.eludatfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eluvil.eludatfin IS 'Date fin mandat';


--
-- Name: COLUMN eluvil.temvalcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eluvil.temvalcod IS 'Code validité';


--
-- Name: COLUMN eluvil.evelic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eluvil.evelic IS 'Libellé court';


--
-- Name: COLUMN eluvil.evelib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eluvil.evelib IS 'Libellé';


--
-- Name: COLUMN eluvil.evelil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eluvil.evelil IS 'Libellé long';


--
-- Name: COLUMN eluvil.eveobs; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eluvil.eveobs IS 'Observations';


--
-- Name: COLUMN eluvil.eluanndeb; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eluvil.eluanndeb IS 'Année début mandat';


--
-- Name: COLUMN eluvil.eluannfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eluvil.eluannfin IS 'Année fin mandat';


--
-- Name: COLUMN eluvil.elunbrhab; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eluvil.elunbrhab IS 'Nombre d''habitants';


--
-- Name: COLUMN eluvil.typmancod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eluvil.typmancod IS 'Code type mandat';


--
-- Name: COLUMN eluvil.senmat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eluvil.senmat IS 'Matricule';


--
-- Name: COLUMN eluvil.eludatcum; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eluvil.eludatcum IS 'Date cumul';


--
-- Name: COLUMN eluvil.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eluvil.syscredat IS 'Date système création';


--
-- Name: COLUMN eluvil.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN eluvil.sysmajdat IS 'Date système modification';


--
-- Name: etadebman; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE etadebman (
    etadebmancod character varying(12) NOT NULL,
    etadebmanlic character varying(60) NOT NULL,
    etadebmanlib character varying(120) NOT NULL,
    etadebmannumtri bigint,
    etadebmanlil character varying(255),
    etadebmanlicfem character varying(120),
    etadebmanlibfem character varying(120),
    etadebmanlilfem character varying(255),
    etadebmanlicplu character varying(60),
    etadebmanlibplu character varying(255),
    etadebmanlilplu character varying(255),
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.etadebman OWNER TO opendata;

--
-- Name: TABLE etadebman; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE etadebman IS 'Etat début mandat';


--
-- Name: COLUMN etadebman.etadebmancod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN etadebman.etadebmancod IS 'Code début de mandat';


--
-- Name: COLUMN etadebman.etadebmanlic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN etadebman.etadebmanlic IS 'Libellé court';


--
-- Name: COLUMN etadebman.etadebmanlib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN etadebman.etadebmanlib IS 'Libellé';


--
-- Name: COLUMN etadebman.etadebmannumtri; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN etadebman.etadebmannumtri IS 'Numéro de tri';


--
-- Name: COLUMN etadebman.etadebmanlil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN etadebman.etadebmanlil IS 'Libellé long';


--
-- Name: COLUMN etadebman.etadebmanlicfem; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN etadebman.etadebmanlicfem IS 'Libellé court féminin';


--
-- Name: COLUMN etadebman.etadebmanlibfem; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN etadebman.etadebmanlibfem IS 'Libellé féminin';


--
-- Name: COLUMN etadebman.etadebmanlilfem; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN etadebman.etadebmanlilfem IS 'Libellé long féminin';


--
-- Name: COLUMN etadebman.etadebmanlicplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN etadebman.etadebmanlicplu IS 'Libellé court pluriel';


--
-- Name: COLUMN etadebman.etadebmanlibplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN etadebman.etadebmanlibplu IS 'Libellé pluriel';


--
-- Name: COLUMN etadebman.etadebmanlilplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN etadebman.etadebmanlilplu IS 'Libellé long pluriel';


--
-- Name: COLUMN etadebman.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN etadebman.syscredat IS 'Date système création';


--
-- Name: COLUMN etadebman.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN etadebman.sysmajdat IS 'Date système modification';


--
-- Name: etafinman; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE etafinman (
    etafinmancod character varying(12) NOT NULL,
    etafinmanlic character varying(60) NOT NULL,
    etafinman character varying(120) NOT NULL,
    etafinmannumtri bigint,
    etafinmanlil character varying(255),
    etafinmanlicfem character varying(60),
    etafinmanlibfem character varying(120),
    etafinmanlilfem character varying(255),
    etafinmanlicplu character varying(60),
    etafinmanlibplu character varying(120),
    etafinmanlilplu character varying(255),
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.etafinman OWNER TO opendata;

--
-- Name: TABLE etafinman; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE etafinman IS 'Etat fin de mandat';


--
-- Name: COLUMN etafinman.etafinmancod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN etafinman.etafinmancod IS 'Code état fin de mandat';


--
-- Name: COLUMN etafinman.etafinmanlic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN etafinman.etafinmanlic IS 'Libellé court';


--
-- Name: COLUMN etafinman.etafinman; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN etafinman.etafinman IS 'Libellé';


--
-- Name: COLUMN etafinman.etafinmannumtri; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN etafinman.etafinmannumtri IS 'Numéro de tri';


--
-- Name: COLUMN etafinman.etafinmanlil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN etafinman.etafinmanlil IS 'Libellé long';


--
-- Name: COLUMN etafinman.etafinmanlicfem; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN etafinman.etafinmanlicfem IS 'Libellé court féminin';


--
-- Name: COLUMN etafinman.etafinmanlibfem; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN etafinman.etafinmanlibfem IS 'Libellé féminin';


--
-- Name: COLUMN etafinman.etafinmanlilfem; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN etafinman.etafinmanlilfem IS 'Libellé long féminin';


--
-- Name: COLUMN etafinman.etafinmanlicplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN etafinman.etafinmanlicplu IS 'Libelle court pluriel';


--
-- Name: COLUMN etafinman.etafinmanlibplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN etafinman.etafinmanlibplu IS 'Libellé pluriel';


--
-- Name: COLUMN etafinman.etafinmanlilplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN etafinman.etafinmanlilplu IS 'Libellé long pluriel';


--
-- Name: COLUMN etafinman.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN etafinman.syscredat IS 'Date système création';


--
-- Name: COLUMN etafinman.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN etafinman.sysmajdat IS 'Date système modification';


--
-- Name: etasen; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE etasen (
    etasencod character varying(12) NOT NULL,
    etasenlic character varying(60) NOT NULL,
    etasenlib character varying(120),
    etasennumtri bigint,
    etasenlil character varying(255),
    etasenlicfem character varying(60),
    etasenlibfem character varying(120),
    etasenlilfem character varying(255),
    etasenlicplu character varying(60),
    etasenlibplu character varying(120),
    etasenlilplu character varying(255),
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.etasen OWNER TO opendata;

--
-- Name: TABLE etasen; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE etasen IS 'Etat Sénateur';


--
-- Name: COLUMN etasen.etasencod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN etasen.etasencod IS 'Code état sénateur';


--
-- Name: COLUMN etasen.etasenlic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN etasen.etasenlic IS 'Libellé court';


--
-- Name: COLUMN etasen.etasenlib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN etasen.etasenlib IS 'Libellé';


--
-- Name: COLUMN etasen.etasennumtri; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN etasen.etasennumtri IS 'Numéro de tri';


--
-- Name: COLUMN etasen.etasenlil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN etasen.etasenlil IS 'Libellé long';


--
-- Name: COLUMN etasen.etasenlicfem; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN etasen.etasenlicfem IS 'Libellé court féminin';


--
-- Name: COLUMN etasen.etasenlibfem; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN etasen.etasenlibfem IS 'Libellé féminin';


--
-- Name: COLUMN etasen.etasenlilfem; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN etasen.etasenlilfem IS 'Libellé long féminin';


--
-- Name: COLUMN etasen.etasenlicplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN etasen.etasenlicplu IS 'Libelle court pluriel';


--
-- Name: COLUMN etasen.etasenlibplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN etasen.etasenlibplu IS 'Libellé pluriel';


--
-- Name: COLUMN etasen.etasenlilplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN etasen.etasenlilplu IS 'Libellé long pluriel';


--
-- Name: COLUMN etasen.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN etasen.syscredat IS 'Date système création';


--
-- Name: COLUMN etasen.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN etasen.sysmajdat IS 'Date système modification';


--
-- Name: fonact_participant; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE fonact_participant (
    fapcod character varying(30) NOT NULL,
    faplic character varying(60) NOT NULL,
    faplicfem character varying(60) NOT NULL,
    faplib character varying(120) NOT NULL,
    faplibfem character varying(120) NOT NULL,
    faplicplu character varying(60) NOT NULL,
    faplicfemplu character varying(60) NOT NULL,
    faplibplu character varying(120) NOT NULL,
    faplibfemplu character varying(120) NOT NULL
);


ALTER TABLE public.fonact_participant OWNER TO opendata;

--
-- Name: foncom; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE foncom (
    foncomcod character varying(12) NOT NULL,
    foncomlib character varying(120) NOT NULL,
    foncomlic character varying(60) NOT NULL,
    foncomnumtri bigint,
    foncomlil character varying(255),
    foncomlicfem character varying(60),
    foncomlibfem character varying(120),
    foncomlilfem character varying(255),
    foncomlicplu character varying(60),
    foncomlibplu character varying(120),
    foncomlilplu character varying(255),
    foncomlicfemplu character varying(60),
    foncomlibfemplu character varying(120),
    foncomlilfemplu character varying(500),
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.foncom OWNER TO opendata;

--
-- Name: TABLE foncom; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE foncom IS 'Fonctions en commission';


--
-- Name: COLUMN foncom.foncomcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN foncom.foncomcod IS 'Code fonction commission';


--
-- Name: COLUMN foncom.foncomlib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN foncom.foncomlib IS 'Libellé';


--
-- Name: COLUMN foncom.foncomlic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN foncom.foncomlic IS 'Libellé court';


--
-- Name: COLUMN foncom.foncomnumtri; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN foncom.foncomnumtri IS 'Numéro de tri';


--
-- Name: COLUMN foncom.foncomlil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN foncom.foncomlil IS 'Libellé long';


--
-- Name: COLUMN foncom.foncomlicfem; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN foncom.foncomlicfem IS 'Libellé court féminin';


--
-- Name: COLUMN foncom.foncomlibfem; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN foncom.foncomlibfem IS 'Libellé féminin';


--
-- Name: COLUMN foncom.foncomlilfem; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN foncom.foncomlilfem IS 'Libellé long féminin';


--
-- Name: COLUMN foncom.foncomlicplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN foncom.foncomlicplu IS 'Libellé court pluriel';


--
-- Name: COLUMN foncom.foncomlibplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN foncom.foncomlibplu IS 'Libellé pluriel';


--
-- Name: COLUMN foncom.foncomlilplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN foncom.foncomlilplu IS 'Libellé long pluriel';


--
-- Name: COLUMN foncom.foncomlicfemplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN foncom.foncomlicfemplu IS 'Libellé court féminin pluriel';


--
-- Name: COLUMN foncom.foncomlibfemplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN foncom.foncomlibfemplu IS 'Libellé féminin pluriel';


--
-- Name: COLUMN foncom.foncomlilfemplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN foncom.foncomlilfemplu IS 'Libellé long féminin pluriel';


--
-- Name: COLUMN foncom.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN foncom.syscredat IS 'Date système création';


--
-- Name: COLUMN foncom.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN foncom.sysmajdat IS 'Date système modification';


--
-- Name: fondelega; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE fondelega (
    fondelcod character varying(12) NOT NULL,
    fondellib character varying(120) NOT NULL,
    fondellic character varying(60) NOT NULL,
    fondelnumtri bigint,
    fondellil character varying(255),
    fondellicfem character varying(60),
    fondellibfem character varying(120),
    fondellilfem character varying(255),
    fondellicplu character varying(60),
    fondellibplu character varying(120),
    fondellilplu character varying(255),
    fondellicfemplu character varying(60),
    fondellibfemplu character varying(120),
    fondellilfemplu character varying(500),
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.fondelega OWNER TO opendata;

--
-- Name: TABLE fondelega; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE fondelega IS 'Fonctions dans les délégations';


--
-- Name: COLUMN fondelega.fondelcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fondelega.fondelcod IS 'Code fonction délégation';


--
-- Name: COLUMN fondelega.fondellib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fondelega.fondellib IS 'Libellé';


--
-- Name: COLUMN fondelega.fondellic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fondelega.fondellic IS 'Libellé court';


--
-- Name: COLUMN fondelega.fondelnumtri; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fondelega.fondelnumtri IS 'Numéro de tri';


--
-- Name: COLUMN fondelega.fondellil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fondelega.fondellil IS 'Libellé long';


--
-- Name: COLUMN fondelega.fondellicfem; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fondelega.fondellicfem IS 'Libellé court féminin';


--
-- Name: COLUMN fondelega.fondellibfem; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fondelega.fondellibfem IS 'Libellé  féminin';


--
-- Name: COLUMN fondelega.fondellilfem; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fondelega.fondellilfem IS 'Libellé long féminin';


--
-- Name: COLUMN fondelega.fondellicplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fondelega.fondellicplu IS 'Libelle court pluriel';


--
-- Name: COLUMN fondelega.fondellibplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fondelega.fondellibplu IS 'Libellé pluriel';


--
-- Name: COLUMN fondelega.fondellilplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fondelega.fondellilplu IS 'Libellé long pluriel';


--
-- Name: COLUMN fondelega.fondellicfemplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fondelega.fondellicfemplu IS 'Libellé court féminin pluriel';


--
-- Name: COLUMN fondelega.fondellibfemplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fondelega.fondellibfemplu IS 'Libellé féminin pluriel';


--
-- Name: COLUMN fondelega.fondellilfemplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fondelega.fondellilfemplu IS 'Libellé long féminin pluriel';


--
-- Name: COLUMN fondelega.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fondelega.syscredat IS 'Date système création';


--
-- Name: COLUMN fondelega.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fondelega.sysmajdat IS 'Date système modification';


--
-- Name: fongrppol; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE fongrppol (
    fongrppolcod character varying(12) NOT NULL,
    fongrppollib character varying(120) NOT NULL,
    fongrppollic character varying(60) NOT NULL,
    fongrppolnumtri bigint,
    fongrppollil character varying(255),
    fongrppollibfem character varying(120),
    fongrppollicfem character varying(60),
    fongrppollilfem character varying(255),
    fongrppollibplu character varying(120),
    fongrppollicplu character varying(60),
    fongrppollilplu character varying(255),
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone,
    fongrppollicfemplu character varying(60),
    fongrppollibfemplu character varying(120),
    fongrppollilfemplu character varying(255)
);


ALTER TABLE public.fongrppol OWNER TO opendata;

--
-- Name: TABLE fongrppol; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE fongrppol IS 'Fonctions de groupe politique';


--
-- Name: COLUMN fongrppol.fongrppolcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fongrppol.fongrppolcod IS 'Code fonction groupe politique';


--
-- Name: COLUMN fongrppol.fongrppollib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fongrppol.fongrppollib IS 'Libellé';


--
-- Name: COLUMN fongrppol.fongrppollic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fongrppol.fongrppollic IS 'Libellé court';


--
-- Name: COLUMN fongrppol.fongrppolnumtri; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fongrppol.fongrppolnumtri IS 'Numéro de tri';


--
-- Name: COLUMN fongrppol.fongrppollil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fongrppol.fongrppollil IS 'Libellé long';


--
-- Name: COLUMN fongrppol.fongrppollibfem; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fongrppol.fongrppollibfem IS 'Libellé féminin';


--
-- Name: COLUMN fongrppol.fongrppollicfem; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fongrppol.fongrppollicfem IS 'Libellé court féminin';


--
-- Name: COLUMN fongrppol.fongrppollilfem; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fongrppol.fongrppollilfem IS 'Libellé long féminin';


--
-- Name: COLUMN fongrppol.fongrppollibplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fongrppol.fongrppollibplu IS 'Libellé pluriel';


--
-- Name: COLUMN fongrppol.fongrppollicplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fongrppol.fongrppollicplu IS 'Libellé court pluriel';


--
-- Name: COLUMN fongrppol.fongrppollilplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fongrppol.fongrppollilplu IS 'Libellé long pluriel';


--
-- Name: COLUMN fongrppol.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fongrppol.syscredat IS 'Date système création';


--
-- Name: COLUMN fongrppol.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fongrppol.sysmajdat IS 'Date système modification';


--
-- Name: COLUMN fongrppol.fongrppollicfemplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fongrppol.fongrppollicfemplu IS 'Libellé court féminin pluriel';


--
-- Name: COLUMN fongrppol.fongrppollibfemplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fongrppol.fongrppollibfemplu IS 'Libellé féminin pluriel';


--
-- Name: COLUMN fongrppol.fongrppollilfemplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fongrppol.fongrppollilfemplu IS 'Libellé long féminin pluriel';


--
-- Name: fongrpsen; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE fongrpsen (
    fongrpsencod character varying(12) NOT NULL,
    fongrpsenlib character varying(120) NOT NULL,
    fongrpsenlic character varying(60) NOT NULL,
    fongrpsennumtri bigint,
    fongrpsenlil character varying(255),
    fongrpsenlibfem character varying(120),
    fongrpsenlicfem character varying(60),
    fongrpsenlilfem character varying(255),
    fongrpsenlibplu character varying(120),
    fongrpsenlicplu character varying(60),
    fongrpsenlilplu character varying(255),
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone,
    fongrpsenlicfemplu character varying(60),
    fongrpsenlibfemplu character varying(120),
    fongrpsenlilfemplu character varying(255)
);


ALTER TABLE public.fongrpsen OWNER TO opendata;

--
-- Name: TABLE fongrpsen; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE fongrpsen IS 'Fonction dans le groupe sénatorial';


--
-- Name: COLUMN fongrpsen.fongrpsencod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fongrpsen.fongrpsencod IS 'Code fonction groupe sénatorial';


--
-- Name: COLUMN fongrpsen.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fongrpsen.syscredat IS 'Date système création';


--
-- Name: COLUMN fongrpsen.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fongrpsen.sysmajdat IS 'Date système modification';


--
-- Name: fonmemcom; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE fonmemcom (
    fonmemcomid bigint NOT NULL,
    foncomcod character varying(12) NOT NULL,
    fonmemcomdatdeb timestamp without time zone,
    fonmemcomdatfin timestamp without time zone,
    fonmemcomrngprt bigint,
    temvalcod character varying(12),
    evelic character varying(60),
    evelib character varying(120),
    evelil character varying(255),
    eveobs character varying(255),
    memcomid bigint NOT NULL,
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.fonmemcom OWNER TO opendata;

--
-- Name: TABLE fonmemcom; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE fonmemcom IS 'Fonctions des membres de Commission';


--
-- Name: COLUMN fonmemcom.fonmemcomid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemcom.fonmemcomid IS 'Identifiant';


--
-- Name: COLUMN fonmemcom.foncomcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemcom.foncomcod IS 'Code fonction commission';


--
-- Name: COLUMN fonmemcom.fonmemcomdatdeb; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemcom.fonmemcomdatdeb IS 'Date de début';


--
-- Name: COLUMN fonmemcom.fonmemcomdatfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemcom.fonmemcomdatfin IS 'Date de fin';


--
-- Name: COLUMN fonmemcom.fonmemcomrngprt; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemcom.fonmemcomrngprt IS 'Rang protocolaire';


--
-- Name: COLUMN fonmemcom.temvalcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemcom.temvalcod IS 'Code validité';


--
-- Name: COLUMN fonmemcom.evelic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemcom.evelic IS 'Libellé court';


--
-- Name: COLUMN fonmemcom.evelib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemcom.evelib IS 'Libellé';


--
-- Name: COLUMN fonmemcom.evelil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemcom.evelil IS 'Libellé long';


--
-- Name: COLUMN fonmemcom.eveobs; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemcom.eveobs IS 'Observations';


--
-- Name: COLUMN fonmemcom.memcomid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemcom.memcomid IS 'Identifiant';


--
-- Name: COLUMN fonmemcom.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemcom.syscredat IS 'Date système création';


--
-- Name: COLUMN fonmemcom.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemcom.sysmajdat IS 'Date système modification';


--
-- Name: fonmemdelega; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE fonmemdelega (
    fonmemdelid bigint NOT NULL,
    fondelcod character varying(12) NOT NULL,
    fonmemdeldatdeb timestamp without time zone,
    fonmemdeldatfin timestamp without time zone,
    temvalcod character varying(12),
    evelic character varying(60),
    evelib character varying(120),
    evelil character varying(255),
    eveobs character varying(255),
    memdelegaid bigint NOT NULL,
    fonmemdelrngele bigint,
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.fonmemdelega OWNER TO opendata;

--
-- Name: TABLE fonmemdelega; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE fonmemdelega IS 'Fonctions des membres de délégation';


--
-- Name: COLUMN fonmemdelega.fonmemdelid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemdelega.fonmemdelid IS 'Identifiant';


--
-- Name: COLUMN fonmemdelega.fondelcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemdelega.fondelcod IS 'Code fonction délégation';


--
-- Name: COLUMN fonmemdelega.fonmemdeldatdeb; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemdelega.fonmemdeldatdeb IS 'Date de début';


--
-- Name: COLUMN fonmemdelega.fonmemdeldatfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemdelega.fonmemdeldatfin IS 'Date de fin';


--
-- Name: COLUMN fonmemdelega.temvalcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemdelega.temvalcod IS 'Code validité';


--
-- Name: COLUMN fonmemdelega.evelic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemdelega.evelic IS 'Libellé court';


--
-- Name: COLUMN fonmemdelega.evelib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemdelega.evelib IS 'Libellé';


--
-- Name: COLUMN fonmemdelega.evelil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemdelega.evelil IS 'Libellé long';


--
-- Name: COLUMN fonmemdelega.eveobs; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemdelega.eveobs IS 'Observations';


--
-- Name: COLUMN fonmemdelega.memdelegaid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemdelega.memdelegaid IS 'Identifiant';


--
-- Name: COLUMN fonmemdelega.fonmemdelrngele; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemdelega.fonmemdelrngele IS 'Rang élection';


--
-- Name: COLUMN fonmemdelega.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemdelega.syscredat IS 'Date système création';


--
-- Name: COLUMN fonmemdelega.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemdelega.sysmajdat IS 'Date système modification';


--
-- Name: fonmemgrppol; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE fonmemgrppol (
    fonmemgrppolid bigint NOT NULL,
    fongrppolcod character varying(12) NOT NULL,
    fonmemgrppoldatdeb timestamp without time zone,
    fonmemgrppoldatfin timestamp without time zone,
    temvalcod character varying(12),
    evelic character varying(30),
    evelib character varying(60),
    evelil character varying(255),
    eveobs character varying(255),
    memgrppolid bigint NOT NULL,
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.fonmemgrppol OWNER TO opendata;

--
-- Name: TABLE fonmemgrppol; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE fonmemgrppol IS 'Fonctions des membres de groupe politique';


--
-- Name: COLUMN fonmemgrppol.fonmemgrppolid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemgrppol.fonmemgrppolid IS 'Identifiant';


--
-- Name: COLUMN fonmemgrppol.fongrppolcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemgrppol.fongrppolcod IS 'Code fonction groupe politique';


--
-- Name: COLUMN fonmemgrppol.fonmemgrppoldatdeb; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemgrppol.fonmemgrppoldatdeb IS 'Date de début';


--
-- Name: COLUMN fonmemgrppol.fonmemgrppoldatfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemgrppol.fonmemgrppoldatfin IS 'Date de fin';


--
-- Name: COLUMN fonmemgrppol.temvalcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemgrppol.temvalcod IS 'Code validité';


--
-- Name: COLUMN fonmemgrppol.evelic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemgrppol.evelic IS 'Libellé court';


--
-- Name: COLUMN fonmemgrppol.evelib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemgrppol.evelib IS 'Libellé';


--
-- Name: COLUMN fonmemgrppol.evelil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemgrppol.evelil IS 'Libellé long';


--
-- Name: COLUMN fonmemgrppol.eveobs; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemgrppol.eveobs IS 'Observations';


--
-- Name: COLUMN fonmemgrppol.memgrppolid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemgrppol.memgrppolid IS 'Identifiant';


--
-- Name: COLUMN fonmemgrppol.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemgrppol.syscredat IS 'Date système création';


--
-- Name: COLUMN fonmemgrppol.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemgrppol.sysmajdat IS 'Date système modification';


--
-- Name: fonmemgrpsen; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE fonmemgrpsen (
    fonmemgrpsenid bigint NOT NULL,
    fongrpsencod character varying(12) NOT NULL,
    fonmemgrpsendatdeb timestamp without time zone NOT NULL,
    fonmemgrpsendatfin timestamp without time zone,
    temvalcod character varying(12),
    evelic character varying(60),
    evelib character varying(120),
    evelil character varying(255),
    eveobs character varying(255),
    memgrpsenid bigint NOT NULL,
    fonmemgrpsenrngele bigint,
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.fonmemgrpsen OWNER TO opendata;

--
-- Name: TABLE fonmemgrpsen; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE fonmemgrpsen IS 'Fonction d''un membre d''un groupe sénatorial';


--
-- Name: COLUMN fonmemgrpsen.fongrpsencod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemgrpsen.fongrpsencod IS 'Code fonction groupe sénatorial';


--
-- Name: COLUMN fonmemgrpsen.temvalcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemgrpsen.temvalcod IS 'Code validité';


--
-- Name: COLUMN fonmemgrpsen.evelic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemgrpsen.evelic IS 'Libellé court';


--
-- Name: COLUMN fonmemgrpsen.evelib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemgrpsen.evelib IS 'Libellé';


--
-- Name: COLUMN fonmemgrpsen.evelil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemgrpsen.evelil IS 'Libellé long';


--
-- Name: COLUMN fonmemgrpsen.eveobs; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemgrpsen.eveobs IS 'Observations';


--
-- Name: COLUMN fonmemgrpsen.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemgrpsen.syscredat IS 'Date système création';


--
-- Name: COLUMN fonmemgrpsen.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemgrpsen.sysmajdat IS 'Date système modification';


--
-- Name: fonmemorg; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE fonmemorg (
    fonmemorgid bigint NOT NULL,
    memorgid bigint NOT NULL,
    fonorgcod character varying(12) NOT NULL,
    fonmemorgdatdeb timestamp without time zone,
    fonmemorganndeb bigint,
    fonmemorgdatfin timestamp without time zone,
    fonmemorgannfin bigint,
    temvalcod character varying(12),
    evelic character varying(60),
    evelib character varying(120),
    evelil character varying(255),
    eveobs character varying(255),
    fonmemorgrngele bigint,
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.fonmemorg OWNER TO opendata;

--
-- Name: TABLE fonmemorg; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE fonmemorg IS 'Fonctions membres d''organisme';


--
-- Name: COLUMN fonmemorg.fonmemorgid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemorg.fonmemorgid IS 'Identifiant';


--
-- Name: COLUMN fonmemorg.memorgid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemorg.memorgid IS 'Identifiant';


--
-- Name: COLUMN fonmemorg.fonorgcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemorg.fonorgcod IS 'Code fonction organisme';


--
-- Name: COLUMN fonmemorg.fonmemorgdatdeb; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemorg.fonmemorgdatdeb IS 'Date de début';


--
-- Name: COLUMN fonmemorg.fonmemorganndeb; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemorg.fonmemorganndeb IS 'Année de début';


--
-- Name: COLUMN fonmemorg.fonmemorgdatfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemorg.fonmemorgdatfin IS 'Date de fin';


--
-- Name: COLUMN fonmemorg.fonmemorgannfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemorg.fonmemorgannfin IS 'Année de fin';


--
-- Name: COLUMN fonmemorg.temvalcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemorg.temvalcod IS 'Code validité';


--
-- Name: COLUMN fonmemorg.evelic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemorg.evelic IS 'Libellé court';


--
-- Name: COLUMN fonmemorg.evelib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemorg.evelib IS 'Libellé';


--
-- Name: COLUMN fonmemorg.evelil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemorg.evelil IS 'Libellé long';


--
-- Name: COLUMN fonmemorg.eveobs; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemorg.eveobs IS 'Observations';


--
-- Name: COLUMN fonmemorg.fonmemorgrngele; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemorg.fonmemorgrngele IS 'Rang élection';


--
-- Name: COLUMN fonmemorg.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemorg.syscredat IS 'Date système création';


--
-- Name: COLUMN fonmemorg.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonmemorg.sysmajdat IS 'Date système modification';


--
-- Name: fonorg; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE fonorg (
    fonorgcod character varying(12) NOT NULL,
    fonorglib character varying(120),
    fonorglic character varying(60),
    fonorgnumtri bigint,
    fonorglil character varying(255),
    fonorglibfem character varying(120),
    fonorglicfem character varying(60),
    fonorglilfem character varying(255),
    fonorglibplu character varying(120),
    fonorglicplu character varying(60),
    fonorglilplu character varying(255),
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone,
    fonorglicfemplu character varying(60),
    fonorglibfemplu character varying(120),
    fonorglilfemplu character varying(255)
);


ALTER TABLE public.fonorg OWNER TO opendata;

--
-- Name: TABLE fonorg; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE fonorg IS 'Fonctions dans les organismes';


--
-- Name: COLUMN fonorg.fonorgcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonorg.fonorgcod IS 'Code fonction organisme';


--
-- Name: COLUMN fonorg.fonorglib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonorg.fonorglib IS 'Libellé';


--
-- Name: COLUMN fonorg.fonorglic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonorg.fonorglic IS 'Libellé court';


--
-- Name: COLUMN fonorg.fonorgnumtri; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonorg.fonorgnumtri IS 'Numéro de tri';


--
-- Name: COLUMN fonorg.fonorglil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonorg.fonorglil IS 'Libellé long';


--
-- Name: COLUMN fonorg.fonorglibfem; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonorg.fonorglibfem IS 'Libellé féminin';


--
-- Name: COLUMN fonorg.fonorglicfem; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonorg.fonorglicfem IS 'Libellé court féminin';


--
-- Name: COLUMN fonorg.fonorglilfem; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonorg.fonorglilfem IS 'Libellé long féminin';


--
-- Name: COLUMN fonorg.fonorglibplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonorg.fonorglibplu IS 'Libellé pluriel';


--
-- Name: COLUMN fonorg.fonorglicplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonorg.fonorglicplu IS 'Libellé court pluriel';


--
-- Name: COLUMN fonorg.fonorglilplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonorg.fonorglilplu IS 'Libellé long pluriel';


--
-- Name: COLUMN fonorg.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonorg.syscredat IS 'Date système création';


--
-- Name: COLUMN fonorg.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonorg.sysmajdat IS 'Date système modification';


--
-- Name: COLUMN fonorg.fonorglicfemplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonorg.fonorglicfemplu IS 'Libellé court féminin pluriel';


--
-- Name: COLUMN fonorg.fonorglibfemplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonorg.fonorglibfemplu IS 'Libellé féminin pluriel';


--
-- Name: COLUMN fonorg.fonorglilfemplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN fonorg.fonorglilfemplu IS 'Libellé long féminin pluriel';


--
-- Name: grppol; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE grppol (
    grppolcod character varying(12) NOT NULL,
    grppolpre character varying(12),
    grppoldatcre timestamp without time zone,
    grppoldatfin timestamp without time zone,
    grppolliccou character varying(60),
    grppollibcou character varying(120),
    grppollilcou character varying(255),
    temvalcod character varying(12),
    evelic character varying(60),
    evelib character varying(120),
    evelil character varying(255),
    typorgcod character varying(12) NOT NULL,
    grppolart character varying(60),
    grppolurlsim character varying(255),
    grppolurlcmp character varying(255),
    grppolcodamelicou character varying(12),
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.grppol OWNER TO opendata;

--
-- Name: TABLE grppol; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE grppol IS 'Groupes Politiques';


--
-- Name: COLUMN grppol.grppolcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN grppol.grppolcod IS 'Code groupe politique 4e Rép.';


--
-- Name: COLUMN grppol.grppolpre; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN grppol.grppolpre IS 'A un président (ou un délégué)';


--
-- Name: COLUMN grppol.grppoldatcre; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN grppol.grppoldatcre IS 'Date création';


--
-- Name: COLUMN grppol.grppoldatfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN grppol.grppoldatfin IS 'Date de fin';


--
-- Name: COLUMN grppol.grppolliccou; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN grppol.grppolliccou IS 'Libellé court courant';


--
-- Name: COLUMN grppol.grppollibcou; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN grppol.grppollibcou IS 'Libellé courant';


--
-- Name: COLUMN grppol.grppollilcou; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN grppol.grppollilcou IS 'Libellé long courant';


--
-- Name: COLUMN grppol.temvalcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN grppol.temvalcod IS 'Code validité';


--
-- Name: COLUMN grppol.evelic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN grppol.evelic IS 'Libellé court';


--
-- Name: COLUMN grppol.evelib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN grppol.evelib IS 'Libellé';


--
-- Name: COLUMN grppol.evelil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN grppol.evelil IS 'Libellé long';


--
-- Name: COLUMN grppol.typorgcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN grppol.typorgcod IS 'Code type organisme';


--
-- Name: COLUMN grppol.grppolart; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN grppol.grppolart IS 'Article';


--
-- Name: COLUMN grppol.grppolurlsim; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN grppol.grppolurlsim IS 'URL simplifiée (relative)';


--
-- Name: COLUMN grppol.grppolurlcmp; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN grppol.grppolurlcmp IS 'URL complète';


--
-- Name: COLUMN grppol.grppolcodamelicou; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN grppol.grppolcodamelicou IS 'Code transfert AMELI';


--
-- Name: COLUMN grppol.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN grppol.syscredat IS 'Date système création';


--
-- Name: COLUMN grppol.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN grppol.sysmajdat IS 'Date système modification';


--
-- Name: grpsenami; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE grpsenami (
    typorgcod character varying(12) NOT NULL,
    orgcod character varying(12) NOT NULL,
    orgnumtri bigint,
    orgdatcre timestamp without time zone NOT NULL,
    orgdatfin timestamp without time zone,
    grpsenalf character varying(5),
    scnorgcod character varying(12),
    temvalcod character varying(12),
    evelic character varying(60),
    evelib character varying(120),
    evelil character varying(255),
    orgart character varying(60),
    grpsenweb character varying(12),
    typgrpsencod character varying(12) DEFAULT 'AMITIE'::character varying NOT NULL,
    orgurlsim character varying(255),
    orgurlcmp character varying(255),
    comorgcod character varying(12) DEFAULT 'NEANT'::character varying NOT NULL,
    orgtemannu character varying(12) DEFAULT 'OUI'::character varying,
    plaindcod character varying(12) DEFAULT '0'::character varying NOT NULL,
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone,
    type_com_neant character varying(12)
);


ALTER TABLE public.grpsenami OWNER TO opendata;

--
-- Name: TABLE grpsenami; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE grpsenami IS 'Groupes sénatoriaux (anciennement d''amitié)';


--
-- Name: COLUMN grpsenami.typorgcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN grpsenami.typorgcod IS 'Code type organisme';


--
-- Name: COLUMN grpsenami.orgcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN grpsenami.orgcod IS 'Code organisme';


--
-- Name: COLUMN grpsenami.orgnumtri; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN grpsenami.orgnumtri IS 'Numéro de tri';


--
-- Name: COLUMN grpsenami.orgdatcre; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN grpsenami.orgdatcre IS 'Date création';


--
-- Name: COLUMN grpsenami.orgdatfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN grpsenami.orgdatfin IS 'Date de fin';


--
-- Name: COLUMN grpsenami.grpsenalf; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN grpsenami.grpsenalf IS 'Membre APF';


--
-- Name: COLUMN grpsenami.scnorgcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN grpsenami.scnorgcod IS 'Code organisme';


--
-- Name: COLUMN grpsenami.temvalcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN grpsenami.temvalcod IS 'Code validité';


--
-- Name: COLUMN grpsenami.evelic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN grpsenami.evelic IS 'Libellé court';


--
-- Name: COLUMN grpsenami.evelib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN grpsenami.evelib IS 'Libellé';


--
-- Name: COLUMN grpsenami.evelil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN grpsenami.evelil IS 'Libellé long';


--
-- Name: COLUMN grpsenami.orgart; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN grpsenami.orgart IS 'Article';


--
-- Name: COLUMN grpsenami.grpsenweb; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN grpsenami.grpsenweb IS 'Edition WEB';


--
-- Name: COLUMN grpsenami.typgrpsencod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN grpsenami.typgrpsencod IS 'Code type groupe';


--
-- Name: COLUMN grpsenami.orgurlsim; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN grpsenami.orgurlsim IS 'URL simplifié';


--
-- Name: COLUMN grpsenami.orgurlcmp; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN grpsenami.orgurlcmp IS 'URL complet';


--
-- Name: COLUMN grpsenami.comorgcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN grpsenami.comorgcod IS 'Code organisme';


--
-- Name: COLUMN grpsenami.orgtemannu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN grpsenami.orgtemannu IS 'Témoin transfert ANNUAIRE';


--
-- Name: COLUMN grpsenami.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN grpsenami.syscredat IS 'Date système création';


--
-- Name: COLUMN grpsenami.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN grpsenami.sysmajdat IS 'Date système modification';


--
-- Name: COLUMN grpsenami.type_com_neant; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN grpsenami.type_com_neant IS 'Pour les groupes non rattachés à une commission (COMORGCOD=''NEANT'')
précise le type spécial de groupe :
- HORSCOM : groupe hors commission (intergroupe par exemple)
- TOUTCOM : groupe rattaché à plusieurs commissions (nouveau besoin 01/2018)
';


--
-- Name: libcom; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE libcom (
    orgcod character varying(12) NOT NULL,
    libcomdatdeb timestamp without time zone NOT NULL,
    libcomdatfin timestamp without time zone,
    temvalcod character varying(12),
    evelic character varying(60),
    evelib character varying(120),
    evelil character varying(500),
    libcomart character varying(12),
    libcomlilmin character varying(500),
    libcomlibameli character varying(120),
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone,
    libcomid bigint NOT NULL
);


ALTER TABLE public.libcom OWNER TO opendata;

--
-- Name: TABLE libcom; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE libcom IS 'Historique des libellés de Commission';


--
-- Name: COLUMN libcom.orgcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libcom.orgcod IS 'Code organisme';


--
-- Name: COLUMN libcom.libcomdatdeb; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libcom.libcomdatdeb IS 'Date début';


--
-- Name: COLUMN libcom.libcomdatfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libcom.libcomdatfin IS 'Date fin';


--
-- Name: COLUMN libcom.temvalcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libcom.temvalcod IS 'Code validité';


--
-- Name: COLUMN libcom.evelic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libcom.evelic IS 'Libellé court';


--
-- Name: COLUMN libcom.evelib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libcom.evelib IS 'Libellé';


--
-- Name: COLUMN libcom.evelil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libcom.evelil IS 'Libellé long';


--
-- Name: COLUMN libcom.libcomart; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libcom.libcomart IS 'Article';


--
-- Name: COLUMN libcom.libcomlilmin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libcom.libcomlilmin IS 'Libellé Minuscule';


--
-- Name: COLUMN libcom.libcomlibameli; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libcom.libcomlibameli IS 'Libellé transfert AMELI';


--
-- Name: COLUMN libcom.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libcom.syscredat IS 'Date système création';


--
-- Name: COLUMN libcom.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libcom.sysmajdat IS 'Date système modification';


--
-- Name: COLUMN libcom.libcomid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libcom.libcomid IS 'Identifiant';


--
-- Name: libdelega; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE libdelega (
    orgcod character varying(12) NOT NULL,
    libdelegadatdeb timestamp without time zone NOT NULL,
    libdelegadatfin timestamp without time zone,
    temvalcod character varying(12),
    evelic character varying(60),
    evelib character varying(120),
    evelil character varying(255),
    eveobs character varying(255),
    libdelegaart character varying(12),
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone,
    libdelegaid bigint NOT NULL
);


ALTER TABLE public.libdelega OWNER TO opendata;

--
-- Name: TABLE libdelega; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE libdelega IS 'Historique des libellés de délégation';


--
-- Name: COLUMN libdelega.orgcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libdelega.orgcod IS 'Code organisme';


--
-- Name: COLUMN libdelega.libdelegadatdeb; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libdelega.libdelegadatdeb IS 'Date de début';


--
-- Name: COLUMN libdelega.libdelegadatfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libdelega.libdelegadatfin IS 'Date fin';


--
-- Name: COLUMN libdelega.temvalcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libdelega.temvalcod IS 'Code validité';


--
-- Name: COLUMN libdelega.evelic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libdelega.evelic IS 'Libellé court';


--
-- Name: COLUMN libdelega.evelib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libdelega.evelib IS 'Libellé';


--
-- Name: COLUMN libdelega.evelil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libdelega.evelil IS 'Libellé long';


--
-- Name: COLUMN libdelega.eveobs; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libdelega.eveobs IS 'Observations';


--
-- Name: COLUMN libdelega.libdelegaart; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libdelega.libdelegaart IS 'Article';


--
-- Name: COLUMN libdelega.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libdelega.syscredat IS 'Date système création';


--
-- Name: COLUMN libdelega.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libdelega.sysmajdat IS 'Date système modification';


--
-- Name: COLUMN libdelega.libdelegaid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libdelega.libdelegaid IS 'Identifiant';


--
-- Name: libgrppol; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE libgrppol (
    grppolcod character varying(12) NOT NULL,
    libgrppoldatdeb timestamp without time zone NOT NULL,
    libgrppoldatfin timestamp without time zone,
    temvalcod character varying(12),
    evelic character varying(60),
    evelib character varying(120),
    evelil character varying(255),
    eveobs character varying(255),
    libgrppolart character varying(60),
    libgrppolcodameli character varying(12),
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone,
    libgrppolid bigint NOT NULL
);


ALTER TABLE public.libgrppol OWNER TO opendata;

--
-- Name: TABLE libgrppol; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE libgrppol IS 'Libellés groupes politiques';


--
-- Name: COLUMN libgrppol.grppolcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libgrppol.grppolcod IS 'Code groupe politique 4e Rép.';


--
-- Name: COLUMN libgrppol.libgrppoldatdeb; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libgrppol.libgrppoldatdeb IS 'Date début';


--
-- Name: COLUMN libgrppol.libgrppoldatfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libgrppol.libgrppoldatfin IS 'Date de fin';


--
-- Name: COLUMN libgrppol.temvalcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libgrppol.temvalcod IS 'Code validité';


--
-- Name: COLUMN libgrppol.evelic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libgrppol.evelic IS 'Libellé court';


--
-- Name: COLUMN libgrppol.evelib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libgrppol.evelib IS 'Libellé';


--
-- Name: COLUMN libgrppol.evelil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libgrppol.evelil IS 'Libellé long';


--
-- Name: COLUMN libgrppol.eveobs; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libgrppol.eveobs IS 'Observations';


--
-- Name: COLUMN libgrppol.libgrppolart; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libgrppol.libgrppolart IS 'Article';


--
-- Name: COLUMN libgrppol.libgrppolcodameli; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libgrppol.libgrppolcodameli IS 'Code transfert AMELI';


--
-- Name: COLUMN libgrppol.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libgrppol.syscredat IS 'Date système création';


--
-- Name: COLUMN libgrppol.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libgrppol.sysmajdat IS 'Date système modification';


--
-- Name: COLUMN libgrppol.libgrppolid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libgrppol.libgrppolid IS 'Identifiant';


--
-- Name: libgrpsen; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE libgrpsen (
    orgcod character varying(12) NOT NULL,
    libgrpsendatautbur timestamp without time zone NOT NULL,
    libgrpsendatfin timestamp without time zone,
    libgrpsenlib character varying(120) NOT NULL,
    libgrpsenlic character varying(60) NOT NULL,
    libgrpsenlil character varying(255),
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone,
    libgrpsenid bigint NOT NULL,
    libgrpsenart character varying(60)
);


ALTER TABLE public.libgrpsen OWNER TO opendata;

--
-- Name: TABLE libgrpsen; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE libgrpsen IS 'Libellé groupe sénatorial';


--
-- Name: COLUMN libgrpsen.orgcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libgrpsen.orgcod IS 'Code organisme';


--
-- Name: COLUMN libgrpsen.libgrpsendatautbur; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libgrpsen.libgrpsendatautbur IS 'Date d''autorisation bureau';


--
-- Name: COLUMN libgrpsen.libgrpsendatfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libgrpsen.libgrpsendatfin IS 'Date de fin';


--
-- Name: COLUMN libgrpsen.libgrpsenlib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libgrpsen.libgrpsenlib IS 'Libellé groupe sénatorial';


--
-- Name: COLUMN libgrpsen.libgrpsenlic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libgrpsen.libgrpsenlic IS 'Libellé court';


--
-- Name: COLUMN libgrpsen.libgrpsenlil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libgrpsen.libgrpsenlil IS 'Libellé long';


--
-- Name: COLUMN libgrpsen.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libgrpsen.syscredat IS 'Date système création';


--
-- Name: COLUMN libgrpsen.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libgrpsen.sysmajdat IS 'Date système modification';


--
-- Name: COLUMN libgrpsen.libgrpsenart; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN libgrpsen.libgrpsenart IS 'Article';


--
-- Name: liborg; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE liborg (
    orgcod character varying(12) NOT NULL,
    liborgdatdeb timestamp without time zone NOT NULL,
    liborgdatfin timestamp without time zone,
    temvalcod character varying(12),
    evelic character varying(60),
    evelib character varying(120),
    evelil character varying(255),
    eveobs character varying(255),
    liborgart character varying(60),
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone,
    liborgid bigint NOT NULL
);


ALTER TABLE public.liborg OWNER TO opendata;

--
-- Name: TABLE liborg; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE liborg IS 'Historique des libellés d''organisme';


--
-- Name: COLUMN liborg.orgcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN liborg.orgcod IS 'Code organisme';


--
-- Name: COLUMN liborg.liborgdatdeb; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN liborg.liborgdatdeb IS 'Date de début';


--
-- Name: COLUMN liborg.liborgdatfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN liborg.liborgdatfin IS 'Date de fin';


--
-- Name: COLUMN liborg.temvalcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN liborg.temvalcod IS 'Code validité';


--
-- Name: COLUMN liborg.evelic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN liborg.evelic IS 'Libellé court';


--
-- Name: COLUMN liborg.evelib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN liborg.evelib IS 'Libellé';


--
-- Name: COLUMN liborg.evelil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN liborg.evelil IS 'Libellé long';


--
-- Name: COLUMN liborg.eveobs; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN liborg.eveobs IS 'Observations';


--
-- Name: COLUMN liborg.liborgart; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN liborg.liborgart IS 'Article';


--
-- Name: COLUMN liborg.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN liborg.syscredat IS 'Date système création';


--
-- Name: COLUMN liborg.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN liborg.sysmajdat IS 'Date système modification';


--
-- Name: COLUMN liborg.liborgid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN liborg.liborgid IS 'Identifiant';


--
-- Name: mel; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE mel (
    melid bigint NOT NULL,
    poiconid bigint NOT NULL,
    melema character varying(255),
    melnumtri bigint,
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.mel OWNER TO opendata;

--
-- Name: TABLE mel; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE mel IS 'Mels d''adresse de sénateurs';


--
-- Name: COLUMN mel.melid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN mel.melid IS 'Identifiant Mel';


--
-- Name: COLUMN mel.poiconid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN mel.poiconid IS 'Identifiant point de contact';


--
-- Name: COLUMN mel.melema; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN mel.melema IS 'Adresse Mel';


--
-- Name: COLUMN mel.melnumtri; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN mel.melnumtri IS 'Numéro de tri';


--
-- Name: memcom; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE memcom (
    memcomid bigint NOT NULL,
    orgcod character varying(12) NOT NULL,
    memcomdatdeb timestamp without time zone,
    memcomdatfin timestamp without time zone,
    temvalcod character varying(12),
    evelic character varying(60),
    evelib character varying(120),
    evelil character varying(255),
    eveobs character varying(255),
    senmat character(6) NOT NULL,
    memcomtitsup character varying(12),
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.memcom OWNER TO opendata;

--
-- Name: TABLE memcom; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE memcom IS 'Membres de commission';


--
-- Name: COLUMN memcom.memcomid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memcom.memcomid IS 'Identifiant';


--
-- Name: COLUMN memcom.orgcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memcom.orgcod IS 'Code organisme';


--
-- Name: COLUMN memcom.memcomdatdeb; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memcom.memcomdatdeb IS 'Date de début';


--
-- Name: COLUMN memcom.memcomdatfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memcom.memcomdatfin IS 'Date de fin';


--
-- Name: COLUMN memcom.temvalcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memcom.temvalcod IS 'Code validité';


--
-- Name: COLUMN memcom.evelic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memcom.evelic IS 'Libellé court';


--
-- Name: COLUMN memcom.evelib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memcom.evelib IS 'Libellé';


--
-- Name: COLUMN memcom.evelil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memcom.evelil IS 'Libellé long';


--
-- Name: COLUMN memcom.eveobs; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memcom.eveobs IS 'Observations';


--
-- Name: COLUMN memcom.senmat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memcom.senmat IS 'Matricule';


--
-- Name: COLUMN memcom.memcomtitsup; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memcom.memcomtitsup IS 'Titulaire/Suppléant';


--
-- Name: COLUMN memcom.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memcom.syscredat IS 'Date système création';


--
-- Name: COLUMN memcom.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memcom.sysmajdat IS 'Date système modification';


--
-- Name: memdelega; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE memdelega (
    memdelegaid bigint NOT NULL,
    orgcod character varying(12) NOT NULL,
    memdelegadatdeb timestamp without time zone,
    memdelegadatfin timestamp without time zone,
    temvalcod character varying(12),
    evelic character varying(60),
    evelib character varying(120),
    evelil character varying(255),
    eveobs character varying(255),
    senmat character(6) NOT NULL,
    designcod character varying(12) DEFAULT 'MEMBRE'::character varying NOT NULL,
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.memdelega OWNER TO opendata;

--
-- Name: TABLE memdelega; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE memdelega IS 'Membres de délégation';


--
-- Name: COLUMN memdelega.memdelegaid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memdelega.memdelegaid IS 'Identifiant';


--
-- Name: COLUMN memdelega.orgcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memdelega.orgcod IS 'Code organisme';


--
-- Name: COLUMN memdelega.memdelegadatdeb; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memdelega.memdelegadatdeb IS 'Date de début';


--
-- Name: COLUMN memdelega.memdelegadatfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memdelega.memdelegadatfin IS 'Date de fin';


--
-- Name: COLUMN memdelega.temvalcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memdelega.temvalcod IS 'Code validité';


--
-- Name: COLUMN memdelega.evelic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memdelega.evelic IS 'Libellé court';


--
-- Name: COLUMN memdelega.evelib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memdelega.evelib IS 'Libellé';


--
-- Name: COLUMN memdelega.evelil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memdelega.evelil IS 'Libellé long';


--
-- Name: COLUMN memdelega.eveobs; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memdelega.eveobs IS 'Observations';


--
-- Name: COLUMN memdelega.senmat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memdelega.senmat IS 'Matricule';


--
-- Name: COLUMN memdelega.designcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memdelega.designcod IS 'Code désignataire';


--
-- Name: COLUMN memdelega.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memdelega.syscredat IS 'Date système création';


--
-- Name: COLUMN memdelega.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memdelega.sysmajdat IS 'Date système modification';


--
-- Name: memextpar; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE memextpar (
    memextparid bigint NOT NULL,
    orgcod character varying(12),
    memextpardatdeb timestamp without time zone,
    memextpardatfin timestamp without time zone,
    memextpartitsup character varying(12),
    temvalcod character varying(12),
    evelic character varying(60),
    evelib character varying(120),
    evelil character varying(255),
    eveobs character varying(255),
    senmat character(6) NOT NULL,
    memextparrngele bigint,
    designcod character varying(12) DEFAULT 'PDTSEN'::character varying NOT NULL,
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone,
    fonmemextparcod character varying(20) DEFAULT 'MEMBRE'::character varying,
    avis_senat character varying(20) DEFAULT 'NON_APPLICABLE'::character varying NOT NULL,
    texte_avis_senat character varying(1024),
    avis_an character varying(20) DEFAULT 'NON_APPLICABLE'::character varying NOT NULL,
    texte_avis_an character varying(1024),
    avis_global character varying(20) DEFAULT 'NON_APPLICABLE'::character varying NOT NULL,
    texte_avis_global character varying(1024),
    date_saisine_exec timestamp without time zone,
    date_annonce_seance timestamp without time zone,
    date_audition_senat timestamp without time zone,
    date_avis_senat timestamp without time zone,
    date_avis_an timestamp without time zone,
    date_avis_global timestamp without time zone,
    date_reponse_exec timestamp without time zone,
    date_publication_jo timestamp without time zone
);


ALTER TABLE public.memextpar OWNER TO opendata;

--
-- Name: TABLE memextpar; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE memextpar IS 'Membre organisme extra-parlementaire';


--
-- Name: COLUMN memextpar.memextparid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memextpar.memextparid IS 'Identifiant';


--
-- Name: COLUMN memextpar.orgcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memextpar.orgcod IS 'Code organisme';


--
-- Name: COLUMN memextpar.memextpardatdeb; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memextpar.memextpardatdeb IS 'Date de Debut';


--
-- Name: COLUMN memextpar.memextpardatfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memextpar.memextpardatfin IS 'Date de fin';


--
-- Name: COLUMN memextpar.memextpartitsup; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memextpar.memextpartitsup IS 'Titulaire Suppleant';


--
-- Name: COLUMN memextpar.temvalcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memextpar.temvalcod IS 'Code validité';


--
-- Name: COLUMN memextpar.evelic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memextpar.evelic IS 'Libellé court';


--
-- Name: COLUMN memextpar.evelib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memextpar.evelib IS 'Libellé';


--
-- Name: COLUMN memextpar.evelil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memextpar.evelil IS 'Libellé long';


--
-- Name: COLUMN memextpar.eveobs; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memextpar.eveobs IS 'Observations';


--
-- Name: COLUMN memextpar.senmat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memextpar.senmat IS 'Matricule';


--
-- Name: COLUMN memextpar.designcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memextpar.designcod IS 'Code désignataire';


--
-- Name: COLUMN memextpar.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memextpar.syscredat IS 'Date système création';


--
-- Name: COLUMN memextpar.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memextpar.sysmajdat IS 'Date système modification';


--
-- Name: memgrppol; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE memgrppol (
    memgrppolid bigint NOT NULL,
    grppolcod character varying(12) NOT NULL,
    typapppolcod character(1) NOT NULL,
    memgrppoldatdeb timestamp without time zone,
    memgrppoldatfin timestamp without time zone,
    temvalcod character varying(12),
    evelic character varying(60),
    evelib character varying(120),
    evelil character varying(255),
    eveobs character varying(255),
    senmat character(6) NOT NULL,
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.memgrppol OWNER TO opendata;

--
-- Name: TABLE memgrppol; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE memgrppol IS 'Membres de groupe politique';


--
-- Name: COLUMN memgrppol.memgrppolid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memgrppol.memgrppolid IS 'Identifiant';


--
-- Name: COLUMN memgrppol.grppolcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memgrppol.grppolcod IS 'Code groupe politique 4e Rép.';


--
-- Name: COLUMN memgrppol.typapppolcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memgrppol.typapppolcod IS 'Code type appartenance';


--
-- Name: COLUMN memgrppol.memgrppoldatdeb; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memgrppol.memgrppoldatdeb IS 'Date de début';


--
-- Name: COLUMN memgrppol.memgrppoldatfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memgrppol.memgrppoldatfin IS 'Date de fin';


--
-- Name: COLUMN memgrppol.temvalcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memgrppol.temvalcod IS 'Code validité';


--
-- Name: COLUMN memgrppol.evelic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memgrppol.evelic IS 'Libellé court';


--
-- Name: COLUMN memgrppol.evelib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memgrppol.evelib IS 'Libellé';


--
-- Name: COLUMN memgrppol.evelil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memgrppol.evelil IS 'Libellé long';


--
-- Name: COLUMN memgrppol.eveobs; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memgrppol.eveobs IS 'Observations';


--
-- Name: COLUMN memgrppol.senmat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memgrppol.senmat IS 'Matricule';


--
-- Name: COLUMN memgrppol.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memgrppol.syscredat IS 'Date système création';


--
-- Name: COLUMN memgrppol.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memgrppol.sysmajdat IS 'Date système modification';


--
-- Name: memgrpsen; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE memgrpsen (
    memgrpsenid bigint NOT NULL,
    orgcod character varying(12) NOT NULL,
    memgrpsendatent timestamp without time zone NOT NULL,
    memgrpsendatsor timestamp without time zone NOT NULL,
    temvalcod character varying(12),
    evelic character varying(60),
    evelib character varying(120),
    evelil character varying(255),
    senmat character(6) NOT NULL,
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.memgrpsen OWNER TO opendata;

--
-- Name: TABLE memgrpsen; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE memgrpsen IS 'Membre groupe sénatorial';


--
-- Name: COLUMN memgrpsen.orgcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memgrpsen.orgcod IS 'Code organisme';


--
-- Name: COLUMN memgrpsen.temvalcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memgrpsen.temvalcod IS 'Code validité';


--
-- Name: COLUMN memgrpsen.evelic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memgrpsen.evelic IS 'Libellé court';


--
-- Name: COLUMN memgrpsen.evelib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memgrpsen.evelib IS 'Libellé';


--
-- Name: COLUMN memgrpsen.evelil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memgrpsen.evelil IS 'Libellé long';


--
-- Name: COLUMN memgrpsen.senmat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memgrpsen.senmat IS 'Matricule';


--
-- Name: COLUMN memgrpsen.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memgrpsen.syscredat IS 'Date système création';


--
-- Name: COLUMN memgrpsen.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memgrpsen.sysmajdat IS 'Date système modification';


--
-- Name: memorg; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE memorg (
    memorgid bigint NOT NULL,
    senmat character(6) NOT NULL,
    orgcod character varying(12) NOT NULL,
    temvalcod character varying(12),
    evelic character varying(60),
    evelib character varying(120),
    evelil character varying(255),
    eveobs character varying(255),
    memorgdatdeb timestamp without time zone,
    memorganndeb bigint,
    memorgdatfin timestamp without time zone,
    memorgannfin bigint,
    designcod character varying(12) DEFAULT 'MEMBRE'::character varying NOT NULL,
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.memorg OWNER TO opendata;

--
-- Name: TABLE memorg; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE memorg IS 'Membres d''organisme';


--
-- Name: COLUMN memorg.memorgid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memorg.memorgid IS 'Identifiant';


--
-- Name: COLUMN memorg.senmat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memorg.senmat IS 'Matricule';


--
-- Name: COLUMN memorg.orgcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memorg.orgcod IS 'Code organisme';


--
-- Name: COLUMN memorg.temvalcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memorg.temvalcod IS 'Code validité';


--
-- Name: COLUMN memorg.evelic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memorg.evelic IS 'Libellé court';


--
-- Name: COLUMN memorg.evelib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memorg.evelib IS 'Libellé';


--
-- Name: COLUMN memorg.evelil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memorg.evelil IS 'Libellé long';


--
-- Name: COLUMN memorg.eveobs; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memorg.eveobs IS 'Observations';


--
-- Name: COLUMN memorg.memorgdatdeb; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memorg.memorgdatdeb IS 'Date de début';


--
-- Name: COLUMN memorg.memorganndeb; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memorg.memorganndeb IS 'Année de début';


--
-- Name: COLUMN memorg.memorgdatfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memorg.memorgdatfin IS 'Date de fin';


--
-- Name: COLUMN memorg.memorgannfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memorg.memorgannfin IS 'Année de fin';


--
-- Name: COLUMN memorg.designcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memorg.designcod IS 'Code désignataire';


--
-- Name: COLUMN memorg.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memorg.syscredat IS 'Date système création';


--
-- Name: COLUMN memorg.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN memorg.sysmajdat IS 'Date système modification';


--
-- Name: minind; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE minind (
    minid bigint NOT NULL,
    senmat character(6),
    typmincod character varying(12) NOT NULL,
    gvtid bigint NOT NULL,
    memgvtrngprt bigint,
    mindatdeb timestamp without time zone,
    minanndeb bigint,
    mindatfin timestamp without time zone,
    minannfin bigint,
    mincirfin character varying(120),
    temvalcod character varying(12),
    evelic character varying(60),
    evelib character varying(120),
    evelil character varying(255),
    eveobs character varying(255),
    titmincod character varying(12) NOT NULL,
    mindel character varying(12) DEFAULT 'NON'::character varying,
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone,
    poicon bigint
);


ALTER TABLE public.minind OWNER TO opendata;

--
-- Name: TABLE minind; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE minind IS 'Ministre';


--
-- Name: COLUMN minind.minid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN minind.minid IS 'Identifiant';


--
-- Name: COLUMN minind.senmat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN minind.senmat IS 'Matricule';


--
-- Name: COLUMN minind.mindatdeb; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN minind.mindatdeb IS 'Date Nomination';


--
-- Name: COLUMN minind.minanndeb; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN minind.minanndeb IS 'Année début';


--
-- Name: COLUMN minind.mindatfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN minind.mindatfin IS 'Date fin fonctions';


--
-- Name: COLUMN minind.minannfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN minind.minannfin IS 'Année fin';


--
-- Name: COLUMN minind.mincirfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN minind.mincirfin IS 'Circ fin fon';


--
-- Name: COLUMN minind.temvalcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN minind.temvalcod IS 'Code validité';


--
-- Name: COLUMN minind.evelic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN minind.evelic IS 'Libellé court';


--
-- Name: COLUMN minind.evelib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN minind.evelib IS 'Libellé';


--
-- Name: COLUMN minind.evelil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN minind.evelil IS 'Libellé long';


--
-- Name: COLUMN minind.eveobs; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN minind.eveobs IS 'Observations';


--
-- Name: COLUMN minind.mindel; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN minind.mindel IS 'Ministre délégué';


--
-- Name: COLUMN minind.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN minind.syscredat IS 'Date système création';


--
-- Name: COLUMN minind.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN minind.sysmajdat IS 'Date système modification';


--
-- Name: mismin; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE mismin (
    misid bigint NOT NULL,
    minid bigint NOT NULL,
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.mismin OWNER TO opendata;

--
-- Name: TABLE mismin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE mismin IS 'Missions et Ministères';


--
-- Name: COLUMN mismin.misid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN mismin.misid IS 'Identifiant Mission';


--
-- Name: COLUMN mismin.minid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN mismin.minid IS 'Identifiant Ministre';


--
-- Name: COLUMN mismin.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN mismin.syscredat IS 'Date système création';


--
-- Name: COLUMN mismin.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN mismin.sysmajdat IS 'Date système modification';


--
-- Name: missen; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE missen (
    misid bigint NOT NULL,
    senmat character(6) NOT NULL,
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.missen OWNER TO opendata;

--
-- Name: TABLE missen; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE missen IS 'Missions et Sénateurs';


--
-- Name: COLUMN missen.misid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN missen.misid IS 'Identifiant';


--
-- Name: COLUMN missen.senmat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN missen.senmat IS 'Matricule';


--
-- Name: COLUMN missen.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN missen.syscredat IS 'Date système création';


--
-- Name: COLUMN missen.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN missen.sysmajdat IS 'Date système modification';


--
-- Name: moddes; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE moddes (
    moddescod character varying(12) NOT NULL,
    temvalcod character varying(12),
    evelic character varying(60),
    evelib character varying(120),
    evelil character varying(255),
    eveobs character varying(255),
    moddesnumtri bigint,
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone,
    avis_com_senat character varying(12) DEFAULT 'NON'::character varying,
    avis_com_an character varying(12) DEFAULT 'NON'::character varying,
    typmoddescod character varying(20) DEFAULT 'OEP'::character varying
);


ALTER TABLE public.moddes OWNER TO opendata;

--
-- Name: TABLE moddes; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE moddes IS 'Modes de désignation
';


--
-- Name: COLUMN moddes.moddescod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN moddes.moddescod IS 'Code';


--
-- Name: COLUMN moddes.temvalcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN moddes.temvalcod IS 'Code validité';


--
-- Name: COLUMN moddes.evelic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN moddes.evelic IS 'Libellé court';


--
-- Name: COLUMN moddes.evelib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN moddes.evelib IS 'Libellé';


--
-- Name: COLUMN moddes.evelil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN moddes.evelil IS 'Libellé long';


--
-- Name: COLUMN moddes.eveobs; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN moddes.eveobs IS 'Observations';


--
-- Name: COLUMN moddes.moddesnumtri; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN moddes.moddesnumtri IS 'Numéro de tri';


--
-- Name: COLUMN moddes.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN moddes.syscredat IS 'Date système création';


--
-- Name: COLUMN moddes.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN moddes.sysmajdat IS 'Date système modification';


--
-- Name: nation; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE nation (
    nationcod character varying(12) NOT NULL,
    nationlibcog character varying(70),
    nationnumtri bigint,
    nationactual character(1),
    nationannind character(4),
    nationlibenr character varying(70),
    nationancnom character varying(60),
    nationlic character varying(60),
    zongeocod character varying(12) NOT NULL,
    nationliccap character varying(60),
    nationlictri character varying(60),
    nationurlcmp character varying(255),
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.nation OWNER TO opendata;

--
-- Name: TABLE nation; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE nation IS 'Pays ou NATION';


--
-- Name: COLUMN nation.zongeocod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN nation.zongeocod IS 'Code zone géographique';


--
-- Name: COLUMN nation.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN nation.syscredat IS 'Date système création';


--
-- Name: COLUMN nation.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN nation.sysmajdat IS 'Date système modification';


--
-- Name: nationgrpsen; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE nationgrpsen (
    nationgrpsenid bigint NOT NULL,
    orgcod character varying(12) NOT NULL,
    nationcod character varying(12) NOT NULL,
    nationgpsendatdeb timestamp without time zone,
    nationgrpsendatfin timestamp without time zone,
    temvalcod character varying(12),
    evelic character varying(60),
    evelib character varying(120),
    evelil character varying(255),
    eveobs character varying(255),
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.nationgrpsen OWNER TO opendata;

--
-- Name: TABLE nationgrpsen; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE nationgrpsen IS 'Pays rattachés à un groupe';


--
-- Name: COLUMN nationgrpsen.orgcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN nationgrpsen.orgcod IS 'Code organisme';


--
-- Name: COLUMN nationgrpsen.temvalcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN nationgrpsen.temvalcod IS 'Code validité';


--
-- Name: COLUMN nationgrpsen.evelic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN nationgrpsen.evelic IS 'Libellé court';


--
-- Name: COLUMN nationgrpsen.evelib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN nationgrpsen.evelib IS 'Libellé';


--
-- Name: COLUMN nationgrpsen.evelil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN nationgrpsen.evelil IS 'Libellé long';


--
-- Name: COLUMN nationgrpsen.eveobs; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN nationgrpsen.eveobs IS 'Observations';


--
-- Name: COLUMN nationgrpsen.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN nationgrpsen.syscredat IS 'Date système création';


--
-- Name: COLUMN nationgrpsen.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN nationgrpsen.sysmajdat IS 'Date système modification';


--
-- Name: org; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE org (
    typorgcod character varying(12) NOT NULL,
    orgcod character varying(12) NOT NULL,
    temvalcod character varying(12),
    evelic character varying(60),
    evelib character varying(120),
    evelil character varying(255),
    orgart character varying(60),
    orgnumtri bigint,
    orgdatcre timestamp without time zone,
    orgdatfin timestamp without time zone,
    orgurlsim character varying(255),
    orgurlcmp character varying(255),
    orgregjur character varying(255),
    orgmoddes character varying(255),
    orgmemdep character varying(12) DEFAULT 'NON'::character varying,
    orgtemannu character varying(12) DEFAULT 'OUI'::character varying,
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.org OWNER TO opendata;

--
-- Name: TABLE org; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE org IS 'Organismes';


--
-- Name: COLUMN org.typorgcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN org.typorgcod IS 'Code type organisme';


--
-- Name: COLUMN org.orgcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN org.orgcod IS 'Code organisme';


--
-- Name: COLUMN org.temvalcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN org.temvalcod IS 'Code validité';


--
-- Name: COLUMN org.evelic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN org.evelic IS 'Libellé court';


--
-- Name: COLUMN org.evelib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN org.evelib IS 'Libellé';


--
-- Name: COLUMN org.evelil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN org.evelil IS 'Libellé long';


--
-- Name: COLUMN org.orgart; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN org.orgart IS 'Article';


--
-- Name: COLUMN org.orgnumtri; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN org.orgnumtri IS 'Numéro de tri';


--
-- Name: COLUMN org.orgdatcre; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN org.orgdatcre IS 'Date création';


--
-- Name: COLUMN org.orgdatfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN org.orgdatfin IS 'Date de fin';


--
-- Name: COLUMN org.orgurlsim; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN org.orgurlsim IS 'URL simplifié';


--
-- Name: COLUMN org.orgurlcmp; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN org.orgurlcmp IS 'URL complet';


--
-- Name: COLUMN org.orgregjur; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN org.orgregjur IS 'Régime juridique';


--
-- Name: COLUMN org.orgmoddes; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN org.orgmoddes IS 'Mode désignation';


--
-- Name: COLUMN org.orgmemdep; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN org.orgmemdep IS 'Membres Députés';


--
-- Name: COLUMN org.orgtemannu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN org.orgtemannu IS 'Témoin transfert ANNUAIRE';


--
-- Name: COLUMN org.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN org.syscredat IS 'Date système création';


--
-- Name: COLUMN org.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN org.sysmajdat IS 'Date système modification';


--
-- Name: orgext; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE orgext (
    typorgcod character varying(12) NOT NULL,
    orgcod character varying(12) NOT NULL,
    orgnumtri bigint,
    orgdatcre timestamp without time zone,
    orgdatfin timestamp without time zone,
    orgnumtie character varying(12),
    orgextregjur character varying(500),
    orgextrubclas character varying(255),
    orgextnbrsen bigint,
    orgextdurman character varying(120),
    temvalcod character varying(12),
    evelic character varying(60),
    evelib character varying(120),
    evelil character varying(255),
    eveobs character varying(255),
    orgart character varying(60),
    orgextmoddes character varying(500),
    orgextminrat character varying(120),
    orgextrep character varying(255),
    orgurlsim character varying(255),
    orgurlcmp character varying(255),
    orgtemannu character varying(12) DEFAULT 'OUI'::character varying,
    stajurcod character varying(12) DEFAULT 'NEANT'::character varying NOT NULL,
    etaprrcod character varying(12) DEFAULT 'NEANT'::character varying NOT NULL,
    orgextdatprr timestamp without time zone,
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone,
    basdescod character varying(12) DEFAULT 'NEANT'::character varying NOT NULL,
    orgparite character varying(12) DEFAULT 'NON'::character varying,
    typorgextcod character varying(64) DEFAULT 'INDETERMINEE'::character varying NOT NULL,
    orgextprescod character varying(20) DEFAULT 'NON'::character varying NOT NULL,
    codesgg character varying(60)
);


ALTER TABLE public.orgext OWNER TO opendata;

--
-- Name: TABLE orgext; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE orgext IS 'Organisme extra_parlementaire';


--
-- Name: COLUMN orgext.typorgcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN orgext.typorgcod IS 'Code type organisme';


--
-- Name: COLUMN orgext.orgcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN orgext.orgcod IS 'Code organisme';


--
-- Name: COLUMN orgext.orgnumtri; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN orgext.orgnumtri IS 'Numéro de tri';


--
-- Name: COLUMN orgext.orgdatcre; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN orgext.orgdatcre IS 'Date création';


--
-- Name: COLUMN orgext.orgdatfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN orgext.orgdatfin IS 'Date de fin';


--
-- Name: COLUMN orgext.orgnumtie; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN orgext.orgnumtie IS 'NuméroTiers';


--
-- Name: COLUMN orgext.orgextregjur; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN orgext.orgextregjur IS 'Régime juridique';


--
-- Name: COLUMN orgext.orgextrubclas; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN orgext.orgextrubclas IS 'Rubrique de classement (obsolète)';


--
-- Name: COLUMN orgext.orgextnbrsen; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN orgext.orgextnbrsen IS 'Nombre de représentants';


--
-- Name: COLUMN orgext.orgextdurman; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN orgext.orgextdurman IS 'Durée du mandat';


--
-- Name: COLUMN orgext.temvalcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN orgext.temvalcod IS 'Code validité';


--
-- Name: COLUMN orgext.evelic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN orgext.evelic IS 'Libellé court';


--
-- Name: COLUMN orgext.evelib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN orgext.evelib IS 'Libellé';


--
-- Name: COLUMN orgext.evelil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN orgext.evelil IS 'Libellé long';


--
-- Name: COLUMN orgext.eveobs; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN orgext.eveobs IS 'Observations';


--
-- Name: COLUMN orgext.orgart; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN orgext.orgart IS 'Article';


--
-- Name: COLUMN orgext.orgextmoddes; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN orgext.orgextmoddes IS 'Mode de désignation';


--
-- Name: COLUMN orgext.orgextminrat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN orgext.orgextminrat IS 'Ministère de rattachement';


--
-- Name: COLUMN orgext.orgextrep; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN orgext.orgextrep IS 'Représentants';


--
-- Name: COLUMN orgext.orgurlsim; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN orgext.orgurlsim IS 'URL simplifié';


--
-- Name: COLUMN orgext.orgurlcmp; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN orgext.orgurlcmp IS 'URL complet';


--
-- Name: COLUMN orgext.orgtemannu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN orgext.orgtemannu IS 'Témoin transfert ANNUAIRE';


--
-- Name: COLUMN orgext.stajurcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN orgext.stajurcod IS 'Code';


--
-- Name: COLUMN orgext.etaprrcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN orgext.etaprrcod IS 'Code';


--
-- Name: COLUMN orgext.orgextdatprr; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN orgext.orgextdatprr IS 'Date de décrêt de prorogation';


--
-- Name: COLUMN orgext.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN orgext.syscredat IS 'Date système création';


--
-- Name: COLUMN orgext.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN orgext.sysmajdat IS 'Date système modification';


--
-- Name: COLUMN orgext.basdescod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN orgext.basdescod IS 'Code';


--
-- Name: COLUMN orgext.orgparite; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN orgext.orgparite IS 'Parité';


--
-- Name: orgthe; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE orgthe (
    orgcod character varying(12) NOT NULL,
    thecle smallint NOT NULL
);


ALTER TABLE public.orgthe OWNER TO opendata;

--
-- Name: TABLE orgthe; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE orgthe IS 'Organismes et thèmes';


--
-- Name: COLUMN orgthe.orgcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN orgthe.orgcod IS 'Code organisme';


--
-- Name: COLUMN orgthe.thecle; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN orgthe.thecle IS 'Clé';


--
-- Name: pcs; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE pcs (
    pcscod character(4) NOT NULL,
    pcslil character varying(255),
    pcs42cod character(2) NOT NULL
);


ALTER TABLE public.pcs OWNER TO opendata;

--
-- Name: TABLE pcs; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE pcs IS 'Table INSEE Catégorie Socio-Professionnelle PCS';


--
-- Name: COLUMN pcs.pcscod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN pcs.pcscod IS 'Code PCS';


--
-- Name: COLUMN pcs.pcslil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN pcs.pcslil IS 'Libellé';


--
-- Name: COLUMN pcs.pcs42cod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN pcs.pcs42cod IS 'Code PCS42';


--
-- Name: pcs24; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE pcs24 (
    pcs24cod character(2) NOT NULL,
    pcs24lib character varying(95),
    pcs8cod character(1) NOT NULL
);


ALTER TABLE public.pcs24 OWNER TO opendata;

--
-- Name: TABLE pcs24; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE pcs24 IS 'Table INSEE Catégorie Socio-Professionnelle PCS24';


--
-- Name: COLUMN pcs24.pcs24cod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN pcs24.pcs24cod IS 'Code PCS24';


--
-- Name: COLUMN pcs24.pcs24lib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN pcs24.pcs24lib IS 'Libellé';


--
-- Name: COLUMN pcs24.pcs8cod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN pcs24.pcs8cod IS 'Code PCS8';


--
-- Name: pcs42; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE pcs42 (
    pcs42cod character(2) NOT NULL,
    pcs42lib character varying(84),
    pcs24cod character(2) NOT NULL
);


ALTER TABLE public.pcs42 OWNER TO opendata;

--
-- Name: TABLE pcs42; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE pcs42 IS 'Table INSEE Catégorie Socio-Professionnelle PCS42';


--
-- Name: COLUMN pcs42.pcs42cod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN pcs42.pcs42cod IS 'Code PCS42';


--
-- Name: COLUMN pcs42.pcs42lib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN pcs42.pcs42lib IS 'Libellé';


--
-- Name: COLUMN pcs42.pcs24cod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN pcs42.pcs24cod IS 'Code PCS24';


--
-- Name: pcs8; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE pcs8 (
    pcs8cod character(1) NOT NULL,
    pcs8lil character varying(255)
);


ALTER TABLE public.pcs8 OWNER TO opendata;

--
-- Name: TABLE pcs8; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE pcs8 IS 'Table INSEE Catégorie Socio-Professionnelle PCS8';


--
-- Name: COLUMN pcs8.pcs8cod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN pcs8.pcs8cod IS 'Code PCS8';


--
-- Name: COLUMN pcs8.pcs8lil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN pcs8.pcs8lil IS 'Libellé';


--
-- Name: pcscatpro; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE pcscatpro (
    catprocod character varying(12) NOT NULL,
    pcscod character(4) NOT NULL,
    procatprodef character varying(12),
    pcscatproid bigint NOT NULL
);


ALTER TABLE public.pcscatpro OWNER TO opendata;

--
-- Name: TABLE pcscatpro; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE pcscatpro IS 'Catégories Socio-professionelles';


--
-- Name: COLUMN pcscatpro.catprocod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN pcscatpro.catprocod IS 'Code catégorie professionnelle';


--
-- Name: COLUMN pcscatpro.pcscod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN pcscatpro.pcscod IS 'Code PCS';


--
-- Name: poicon; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE poicon (
    poiconid bigint NOT NULL,
    senmat character(6) NOT NULL,
    typpoiconcod character varying(12) NOT NULL,
    poiconlib character varying(120),
    poiconnumtri bigint,
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.poicon OWNER TO opendata;

--
-- Name: TABLE poicon; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE poicon IS 'Un point de contact est une adresse de sénateur comosée d''une adresse (postale) de numéros de tel et de mails';


--
-- Name: COLUMN poicon.poiconid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN poicon.poiconid IS 'Identifiant point de contact';


--
-- Name: COLUMN poicon.senmat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN poicon.senmat IS 'Matricule';


--
-- Name: COLUMN poicon.typpoiconcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN poicon.typpoiconcod IS 'Code type Point de contact';


--
-- Name: COLUMN poicon.poiconnumtri; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN poicon.poiconnumtri IS 'Numéro de tri';


--
-- Name: qua; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE qua (
    quacod character varying(12) NOT NULL,
    qualic character varying(60) NOT NULL,
    quanumtri bigint,
    quacodsex character(1),
    qualib character varying(120),
    qualil character varying(255),
    qualicplu character varying(60),
    qualibplu character varying(120),
    qualilplu character varying(255),
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.qua OWNER TO opendata;

--
-- Name: TABLE qua; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE qua IS 'Qualités (M., Mme, Mlle)';


--
-- Name: COLUMN qua.quacod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN qua.quacod IS 'Code qualité';


--
-- Name: COLUMN qua.qualic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN qua.qualic IS 'Libellé court';


--
-- Name: COLUMN qua.quanumtri; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN qua.quanumtri IS 'Numéro de tri';


--
-- Name: COLUMN qua.quacodsex; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN qua.quacodsex IS 'Code sexe';


--
-- Name: COLUMN qua.qualib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN qua.qualib IS 'Libellé';


--
-- Name: COLUMN qua.qualil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN qua.qualil IS 'Libellé long';


--
-- Name: COLUMN qua.qualicplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN qua.qualicplu IS 'Libellé court pluriel';


--
-- Name: COLUMN qua.qualibplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN qua.qualibplu IS 'Libellé pluriel';


--
-- Name: COLUMN qua.qualilplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN qua.qualilplu IS 'Libellé long pluriel';


--
-- Name: COLUMN qua.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN qua.syscredat IS 'Date système création';


--
-- Name: COLUMN qua.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN qua.sysmajdat IS 'Date système modification';


--
-- Name: reg; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE reg (
    regcod character varying(12) NOT NULL,
    territcod character varying(12) NOT NULL,
    reglib character varying(120) NOT NULL,
    regnumtri bigint,
    regcodparlis character varying(12),
    artreg character varying(60),
    regurlcmp character varying(255),
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone,
    regcodrpl character varying(12),
    reglic character varying(60),
    reglil character varying(255),
    regdatdeb timestamp without time zone,
    regdatfin timestamp without time zone,
    regcodint character varying(50) DEFAULT NULL::character varying
);


ALTER TABLE public.reg OWNER TO opendata;

--
-- Name: TABLE reg; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE reg IS 'Régions';


--
-- Name: COLUMN reg.regcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN reg.regcod IS 'Code région';


--
-- Name: COLUMN reg.territcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN reg.territcod IS 'Code';


--
-- Name: COLUMN reg.reglib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN reg.reglib IS 'Libellé région';


--
-- Name: COLUMN reg.regnumtri; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN reg.regnumtri IS 'Numéro de tri';


--
-- Name: COLUMN reg.regcodparlis; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN reg.regcodparlis IS 'Code transfert Parlis';


--
-- Name: COLUMN reg.artreg; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN reg.artreg IS 'Article';


--
-- Name: COLUMN reg.regurlcmp; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN reg.regurlcmp IS 'URL';


--
-- Name: COLUMN reg.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN reg.syscredat IS 'Date système création';


--
-- Name: COLUMN reg.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN reg.sysmajdat IS 'Date système modification';


--
-- Name: COLUMN reg.regcodrpl; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN reg.regcodrpl IS 'Code région remplaçante';


--
-- Name: COLUMN reg.reglic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN reg.reglic IS 'Libellé court région';


--
-- Name: COLUMN reg.reglil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN reg.reglil IS 'Libellé long région';


--
-- Name: COLUMN reg.regdatdeb; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN reg.regdatdeb IS 'Date début région';


--
-- Name: COLUMN reg.regdatfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN reg.regdatfin IS 'Date fin région';


--
-- Name: sen; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE sen (
    senmat character(6) NOT NULL,
    quacod character varying(12) NOT NULL,
    sennomuse character varying(40) NOT NULL,
    sennomtec character varying(60) NOT NULL,
    senprenomuse character varying(60) NOT NULL,
    sendatnai timestamp without time zone,
    sendatdec timestamp without time zone,
    etasencod character varying(12) NOT NULL,
    sendespro character varying(255),
    pcscod character(4) DEFAULT '8000'::bpchar NOT NULL,
    catprocod character varying(12) DEFAULT '80'::character varying NOT NULL,
    sengrppolcodcou character varying(12),
    sengrppolliccou character varying(60),
    sentypappcou character varying(60),
    sencomcodcou character varying(12),
    sencomliccou character varying(60),
    sencirnumcou bigint,
    sencircou character varying(120),
    senburliccou character varying(60),
    senema character varying(255),
    sennomusecap character varying(40) NOT NULL,
    senfem character varying(12) DEFAULT 'NON'::character varying,
    sennumsie bigint,
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone,
    sendaiurl character varying(255)
);


ALTER TABLE public.sen OWNER TO opendata;

--
-- Name: TABLE sen; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE sen IS 'Sénateurs';


--
-- Name: COLUMN sen.senmat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN sen.senmat IS 'Matricule';


--
-- Name: COLUMN sen.quacod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN sen.quacod IS 'Code qualité';


--
-- Name: COLUMN sen.sennomuse; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN sen.sennomuse IS 'Nom usuel';


--
-- Name: COLUMN sen.sennomtec; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN sen.sennomtec IS 'Nom technique (tris)';


--
-- Name: COLUMN sen.senprenomuse; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN sen.senprenomuse IS 'Prénom usuel';


--
-- Name: COLUMN sen.sendatnai; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN sen.sendatnai IS 'Date de naissance';


--
-- Name: COLUMN sen.sendatdec; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN sen.sendatdec IS 'Date du décés';


--
-- Name: COLUMN sen.etasencod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN sen.etasencod IS 'Code état sénateur';


--
-- Name: COLUMN sen.sendespro; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN sen.sendespro IS 'Description Profession';


--
-- Name: COLUMN sen.pcscod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN sen.pcscod IS 'Code PCS';


--
-- Name: COLUMN sen.catprocod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN sen.catprocod IS 'Code catégorie professionnelle';


--
-- Name: COLUMN sen.sengrppolcodcou; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN sen.sengrppolcodcou IS 'Code groupe politique courant';


--
-- Name: COLUMN sen.sengrppolliccou; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN sen.sengrppolliccou IS 'Libellé groupe politique courant';


--
-- Name: COLUMN sen.sentypappcou; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN sen.sentypappcou IS 'Appartenance politique courante';


--
-- Name: COLUMN sen.sencomcodcou; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN sen.sencomcodcou IS 'Code commission courante';


--
-- Name: COLUMN sen.sencomliccou; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN sen.sencomliccou IS 'Commission courante';


--
-- Name: COLUMN sen.sencirnumcou; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN sen.sencirnumcou IS 'Identifiant circonscription';


--
-- Name: COLUMN sen.sencircou; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN sen.sencircou IS 'Circonscription courante';


--
-- Name: COLUMN sen.senburliccou; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN sen.senburliccou IS 'Fonction bureau courante';


--
-- Name: COLUMN sen.senema; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN sen.senema IS 'Adresse électronique';


--
-- Name: COLUMN sen.sennomusecap; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN sen.sennomusecap IS 'Nom usuel Capitales';


--
-- Name: COLUMN sen.senfem; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN sen.senfem IS 'Féminisation fonctions';


--
-- Name: COLUMN sen.sennumsie; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN sen.sennumsie IS 'N° de siège Hémicycle';


--
-- Name: COLUMN sen.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN sen.syscredat IS 'Date système création';


--
-- Name: COLUMN sen.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN sen.sysmajdat IS 'Date système modification';


--
-- Name: COLUMN sen.sendaiurl; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN sen.sendaiurl IS 'URL des déclarations d''intérêts';


--
-- Name: senbur; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE senbur (
    senburid bigint NOT NULL,
    burcod character varying(12) NOT NULL,
    senburdatdeb timestamp without time zone,
    senburdatfin timestamp without time zone,
    senburrelint character varying(12),
    senburrngele bigint,
    temvalcod character varying(12),
    evelic character varying(60),
    evelib character varying(120),
    evelil character varying(255),
    eveobs character varying(255),
    senmat character(6) NOT NULL,
    senburhon character varying(12),
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.senbur OWNER TO opendata;

--
-- Name: TABLE senbur; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE senbur IS 'Fonctions des Sénateurs au bureau du Sénat';


--
-- Name: COLUMN senbur.senburid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN senbur.senburid IS 'Identifiant';


--
-- Name: COLUMN senbur.burcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN senbur.burcod IS 'Code bureau 4e Rép.';


--
-- Name: COLUMN senbur.senburdatdeb; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN senbur.senburdatdeb IS 'Date de début';


--
-- Name: COLUMN senbur.senburdatfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN senbur.senburdatfin IS 'Date de fin';


--
-- Name: COLUMN senbur.senburrelint; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN senbur.senburrelint IS 'Chargé Relations Internationales';


--
-- Name: COLUMN senbur.senburrngele; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN senbur.senburrngele IS 'Rang d''élection';


--
-- Name: COLUMN senbur.temvalcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN senbur.temvalcod IS 'Code validité';


--
-- Name: COLUMN senbur.evelic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN senbur.evelic IS 'Libellé court';


--
-- Name: COLUMN senbur.evelib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN senbur.evelib IS 'Libellé';


--
-- Name: COLUMN senbur.evelil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN senbur.evelil IS 'Libellé long';


--
-- Name: COLUMN senbur.eveobs; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN senbur.eveobs IS 'Observations';


--
-- Name: COLUMN senbur.senmat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN senbur.senmat IS 'Matricule';


--
-- Name: COLUMN senbur.senburhon; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN senbur.senburhon IS 'Honorariat';


--
-- Name: COLUMN senbur.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN senbur.syscredat IS 'Date système création';


--
-- Name: COLUMN senbur.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN senbur.sysmajdat IS 'Date système modification';


--
-- Name: sennom; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE sennom (
    senmat character(6) NOT NULL,
    sennomdatdeb timestamp without time zone NOT NULL,
    sennomdatfin timestamp without time zone,
    quacod character varying(12) NOT NULL,
    sennomuse character varying(40) NOT NULL,
    sennomusecap character varying(40) NOT NULL,
    sennomtec character varying(60) NOT NULL,
    senprenomuse character varying(60) NOT NULL,
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone,
    sennomid bigint NOT NULL
);


ALTER TABLE public.sennom OWNER TO opendata;

--
-- Name: TABLE sennom; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE sennom IS 'Historique des noms d''une personne';


--
-- Name: COLUMN sennom.senmat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN sennom.senmat IS 'Matricule';


--
-- Name: COLUMN sennom.sennomdatdeb; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN sennom.sennomdatdeb IS 'Date de début';


--
-- Name: COLUMN sennom.sennomdatfin; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN sennom.sennomdatfin IS 'Date de fin';


--
-- Name: COLUMN sennom.quacod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN sennom.quacod IS 'Code qualité';


--
-- Name: COLUMN sennom.sennomuse; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN sennom.sennomuse IS 'Nom usuel';


--
-- Name: COLUMN sennom.sennomusecap; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN sennom.sennomusecap IS 'Nom usuel Capitales';


--
-- Name: COLUMN sennom.sennomtec; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN sennom.sennomtec IS 'Nom technique';


--
-- Name: COLUMN sennom.senprenomuse; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN sennom.senprenomuse IS 'Prénom usuel';


--
-- Name: COLUMN sennom.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN sennom.syscredat IS 'Date système création';


--
-- Name: COLUMN sennom.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN sennom.sysmajdat IS 'Date système modification';


--
-- Name: COLUMN sennom.sennomid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN sennom.sennomid IS 'Identifiant';


--
-- Name: senurl; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE senurl (
    senurlid bigint NOT NULL,
    senmat character(6) NOT NULL,
    typurlcod character varying(12) NOT NULL,
    senurlurl character varying(255) NOT NULL,
    evelic character varying(60),
    evelib character varying(120),
    evelil character varying(255),
    eveobs character varying(255),
    temvalcod character varying(12),
    senurlnumtri bigint,
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.senurl OWNER TO opendata;

--
-- Name: TABLE senurl; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE senurl IS 'URLs des Sénateurs';


--
-- Name: COLUMN senurl.senurlid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN senurl.senurlid IS 'Identifiant';


--
-- Name: COLUMN senurl.senmat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN senurl.senmat IS 'Matricule';


--
-- Name: COLUMN senurl.typurlcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN senurl.typurlcod IS 'Code type URL';


--
-- Name: COLUMN senurl.senurlurl; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN senurl.senurlurl IS 'URL';


--
-- Name: COLUMN senurl.evelic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN senurl.evelic IS 'Libellé court';


--
-- Name: COLUMN senurl.evelib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN senurl.evelib IS 'Libellé';


--
-- Name: COLUMN senurl.evelil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN senurl.evelil IS 'Libellé long';


--
-- Name: COLUMN senurl.eveobs; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN senurl.eveobs IS 'Observations';


--
-- Name: COLUMN senurl.temvalcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN senurl.temvalcod IS 'Code validité';


--
-- Name: COLUMN senurl.senurlnumtri; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN senurl.senurlnumtri IS 'Numéro de tri';


--
-- Name: COLUMN senurl.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN senurl.syscredat IS 'Date système création';


--
-- Name: COLUMN senurl.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN senurl.sysmajdat IS 'Date système modification';


--
-- Name: stajur; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE stajur (
    stajurcod character varying(12) NOT NULL,
    stajurlic character varying(60),
    stajurlib character varying(120),
    stajurnumtri bigint,
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.stajur OWNER TO opendata;

--
-- Name: COLUMN stajur.stajurcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN stajur.stajurcod IS 'Code';


--
-- Name: COLUMN stajur.stajurlic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN stajur.stajurlic IS 'Libellé court';


--
-- Name: COLUMN stajur.stajurlib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN stajur.stajurlib IS 'Libellé';


--
-- Name: COLUMN stajur.stajurnumtri; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN stajur.stajurnumtri IS 'Numéro de tri';


--
-- Name: COLUMN stajur.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN stajur.syscredat IS 'Date système création';


--
-- Name: COLUMN stajur.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN stajur.sysmajdat IS 'Date système modification';


--
-- Name: telephone; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE telephone (
    telid bigint NOT NULL,
    typtelcod character varying(12) NOT NULL,
    poiconid bigint NOT NULL,
    telnum character varying(15),
    telnumtri bigint,
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.telephone OWNER TO opendata;

--
-- Name: TABLE telephone; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE telephone IS 'N° de téléphone (tel, fax, portable)';


--
-- Name: COLUMN telephone.telid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN telephone.telid IS 'Identifiant téléphone';


--
-- Name: COLUMN telephone.typtelcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN telephone.typtelcod IS 'Code type numéro de téléphone';


--
-- Name: COLUMN telephone.poiconid; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN telephone.poiconid IS 'Identifiant point de contact';


--
-- Name: COLUMN telephone.telnum; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN telephone.telnum IS 'Numéro de tel';


--
-- Name: COLUMN telephone.telnumtri; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN telephone.telnumtri IS 'Numéro de tri';


--
-- Name: temval; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE temval (
    temvalcod character varying(12) NOT NULL,
    temvallic character varying(60) NOT NULL,
    temvallib character varying(120) NOT NULL
);


ALTER TABLE public.temval OWNER TO opendata;

--
-- Name: TABLE temval; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE temval IS 'Témoin de validité';


--
-- Name: COLUMN temval.temvalcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN temval.temvalcod IS 'Code validité';


--
-- Name: COLUMN temval.temvallic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN temval.temvallic IS 'Libellé court';


--
-- Name: COLUMN temval.temvallib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN temval.temvallib IS 'Libellé';


--
-- Name: territ; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE territ (
    territcod character varying(12) NOT NULL,
    territlib character varying(120),
    territnumtri bigint,
    territart character varying(60),
    territurlcmp character varying(255),
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone,
    catterritcod character varying(12) DEFAULT 'ANCIEN'::character varying NOT NULL,
    territlic character varying(60),
    territlil character varying(255)
);


ALTER TABLE public.territ OWNER TO opendata;

--
-- Name: TABLE territ; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE territ IS 'Territoires';


--
-- Name: COLUMN territ.territcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN territ.territcod IS 'Code';


--
-- Name: COLUMN territ.territlib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN territ.territlib IS 'Libellé territoire';


--
-- Name: COLUMN territ.territnumtri; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN territ.territnumtri IS 'Ordre de tri';


--
-- Name: COLUMN territ.territart; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN territ.territart IS 'Article';


--
-- Name: COLUMN territ.territurlcmp; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN territ.territurlcmp IS 'URL';


--
-- Name: COLUMN territ.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN territ.syscredat IS 'Date système création';


--
-- Name: COLUMN territ.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN territ.sysmajdat IS 'Date système modification';


--
-- Name: titele; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE titele (
    titelecod character varying(12) NOT NULL,
    titelelic character varying(60) NOT NULL,
    typmancod character varying(12) NOT NULL,
    titelelib character varying(120) NOT NULL,
    titelelil character varying(255),
    titelenumtri bigint,
    titelelicfem character varying(60),
    titelelibfem character varying(120),
    titelelilfem character varying(255),
    titelelicplu character varying(60),
    titelelibplu character varying(120),
    titelelilplu character varying(255),
    titelelibhon character varying(120),
    titelelibhonfem character varying(120),
    titelelibhonplu character varying(120),
    titeleurltempub character varying(12),
    titeledef character varying(12),
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.titele OWNER TO opendata;

--
-- Name: TABLE titele; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE titele IS 'Titres électifs (Président , Maire, ...)';


--
-- Name: COLUMN titele.titelecod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN titele.titelecod IS 'Code titre élu';


--
-- Name: COLUMN titele.typmancod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN titele.typmancod IS 'Code type mandat';


--
-- Name: COLUMN titele.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN titele.syscredat IS 'Date système création';


--
-- Name: COLUMN titele.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN titele.sysmajdat IS 'Date système modification';


--
-- Name: typadr; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE typadr (
    typadrcod character varying(12) NOT NULL,
    typadrlic character varying(60),
    typadrlib character varying(120),
    typadrnumtri bigint,
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.typadr OWNER TO opendata;

--
-- Name: TABLE typadr; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE typadr IS 'Types d''adresse';


--
-- Name: COLUMN typadr.typadrcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typadr.typadrcod IS 'Code type adresse';


--
-- Name: COLUMN typadr.typadrlic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typadr.typadrlic IS 'Libellé court';


--
-- Name: COLUMN typadr.typadrlib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typadr.typadrlib IS 'Libellé';


--
-- Name: COLUMN typadr.typadrnumtri; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typadr.typadrnumtri IS 'Numéro de tri';


--
-- Name: COLUMN typadr.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typadr.syscredat IS 'Date système création';


--
-- Name: COLUMN typadr.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typadr.sysmajdat IS 'Date système modification';


--
-- Name: typapppol; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE typapppol (
    typapppolcod character(1) NOT NULL,
    typapppollib character varying(120),
    typapppollic character varying(60),
    typapppolnumtri bigint,
    typapppollil character varying(255),
    typapppollicfem character varying(60),
    typapppollibfem character varying(120),
    typapppollilfem character varying(255),
    typapppollicplu character varying(60),
    typapppollibplu character varying(120),
    typapppollilplu character varying(255),
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.typapppol OWNER TO opendata;

--
-- Name: TABLE typapppol; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE typapppol IS 'Types d''appartenances aux groupes politiques';


--
-- Name: COLUMN typapppol.typapppolcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typapppol.typapppolcod IS 'Code type appartenance';


--
-- Name: COLUMN typapppol.typapppollib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typapppol.typapppollib IS 'Libellé ';


--
-- Name: COLUMN typapppol.typapppollic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typapppol.typapppollic IS 'Libellé court';


--
-- Name: COLUMN typapppol.typapppolnumtri; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typapppol.typapppolnumtri IS 'Numéro de tri';


--
-- Name: COLUMN typapppol.typapppollil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typapppol.typapppollil IS 'Libellé long';


--
-- Name: COLUMN typapppol.typapppollicfem; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typapppol.typapppollicfem IS 'Libellé court féminin';


--
-- Name: COLUMN typapppol.typapppollibfem; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typapppol.typapppollibfem IS 'Libellé féminin';


--
-- Name: COLUMN typapppol.typapppollilfem; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typapppol.typapppollilfem IS 'Libellé long féminin';


--
-- Name: COLUMN typapppol.typapppollicplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typapppol.typapppollicplu IS 'Libellé court pluriel';


--
-- Name: COLUMN typapppol.typapppollibplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typapppol.typapppollibplu IS 'Libellé pluriel';


--
-- Name: COLUMN typapppol.typapppollilplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typapppol.typapppollilplu IS 'Libellé long pluriel';


--
-- Name: COLUMN typapppol.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typapppol.syscredat IS 'Date système création';


--
-- Name: COLUMN typapppol.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typapppol.sysmajdat IS 'Date système modification';


--
-- Name: typbister; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE typbister (
    typbistercod character varying(12) NOT NULL,
    typbisterlic character varying(60),
    typbisterlib character varying(120),
    typbisternumtri bigint
);


ALTER TABLE public.typbister OWNER TO opendata;

--
-- Name: TABLE typbister; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE typbister IS 'Type Bis Ter pour la gestion des adresses';


--
-- Name: COLUMN typbister.typbistercod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typbister.typbistercod IS 'Code Type bis ter';


--
-- Name: COLUMN typbister.typbisterlic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typbister.typbisterlic IS 'Libellé court';


--
-- Name: COLUMN typbister.typbisterlib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typbister.typbisterlib IS 'Libellé';


--
-- Name: COLUMN typbister.typbisternumtri; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typbister.typbisternumtri IS 'Numéro de tri';


--
-- Name: type_activite; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE type_activite (
    typactcod character varying(30) NOT NULL,
    typactlic character varying(60) NOT NULL,
    typactlib character varying(120) NOT NULL,
    typactlibtap character varying(120)
);


ALTER TABLE public.type_activite OWNER TO opendata;

--
-- Name: type_activite_participant; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE type_activite_participant (
    typactparcod character varying(20) NOT NULL,
    typactparlib character varying(60) NOT NULL,
    typactparlibfem character varying(60) NOT NULL
);


ALTER TABLE public.type_activite_participant OWNER TO opendata;

--
-- Name: type_activite_senateur; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE type_activite_senateur (
    typactsencod character varying(30) NOT NULL,
    typactsenlic character varying(60) NOT NULL,
    typactsenlib character varying(120) NOT NULL,
    numtri bigint NOT NULL
);


ALTER TABLE public.type_activite_senateur OWNER TO opendata;

--
-- Name: type_categorie; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE type_categorie (
    typactcod character varying(30) NOT NULL,
    catactcod character varying(20) NOT NULL,
    par_defaut character varying(4) DEFAULT 'NON'::character varying NOT NULL
);


ALTER TABLE public.type_categorie OWNER TO opendata;

--
-- Name: typele; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE typele (
    typelecod character varying(12) NOT NULL,
    typelelic character varying(60),
    typelelib character varying(120),
    typelelil character varying(500),
    typelenumtri bigint,
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.typele OWNER TO opendata;

--
-- Name: TABLE typele; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE typele IS 'Types d''élection 
';


--
-- Name: COLUMN typele.typelecod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typele.typelecod IS 'Code type élection';


--
-- Name: COLUMN typele.typelelic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typele.typelelic IS 'Libellé court';


--
-- Name: COLUMN typele.typelelib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typele.typelelib IS 'Libellé';


--
-- Name: COLUMN typele.typelelil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typele.typelelil IS 'Libellé long';


--
-- Name: COLUMN typele.typelenumtri; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typele.typelenumtri IS 'Numéro de tri';


--
-- Name: COLUMN typele.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typele.syscredat IS 'Date système création';


--
-- Name: COLUMN typele.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typele.sysmajdat IS 'Date système modification';


--
-- Name: typgrpsen; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE typgrpsen (
    typgrpsencod character varying(12) NOT NULL,
    temvalcod character varying(12),
    evelic character varying(60),
    evelib character varying(120),
    evelil character varying(255),
    typgrpsennumtri bigint,
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.typgrpsen OWNER TO opendata;

--
-- Name: COLUMN typgrpsen.typgrpsencod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typgrpsen.typgrpsencod IS 'Code type groupe';


--
-- Name: COLUMN typgrpsen.temvalcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typgrpsen.temvalcod IS 'Code validité';


--
-- Name: COLUMN typgrpsen.evelic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typgrpsen.evelic IS 'Libellé court';


--
-- Name: COLUMN typgrpsen.evelib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typgrpsen.evelib IS 'Libellé';


--
-- Name: COLUMN typgrpsen.evelil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typgrpsen.evelil IS 'Libellé long';


--
-- Name: COLUMN typgrpsen.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typgrpsen.syscredat IS 'Date système création';


--
-- Name: COLUMN typgrpsen.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typgrpsen.sysmajdat IS 'Date système modification';


--
-- Name: typman; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE typman (
    typmancod character varying(12) NOT NULL,
    typmanlib character varying(120),
    typmantypele character varying(12),
    typmannumtri bigint,
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.typman OWNER TO opendata;

--
-- Name: TABLE typman; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE typman IS 'Types de mandat';


--
-- Name: COLUMN typman.typmancod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typman.typmancod IS 'Code type mandat';


--
-- Name: COLUMN typman.typmanlib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typman.typmanlib IS 'Libellé type mandat';


--
-- Name: COLUMN typman.typmantypele; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typman.typmantypele IS 'Type d''élection';


--
-- Name: COLUMN typman.typmannumtri; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typman.typmannumtri IS 'Numéro de tri';


--
-- Name: COLUMN typman.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typman.syscredat IS 'Date système création';


--
-- Name: COLUMN typman.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typman.sysmajdat IS 'Date système modification';


--
-- Name: typorg; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE typorg (
    typorgcod character varying(12) NOT NULL,
    typorglib character varying(120) NOT NULL,
    typorglic character varying(60) NOT NULL,
    typorgnumtri bigint,
    typorgurlsim character varying(500),
    typorgurlcmp character varying(500),
    typorglibplu character varying(120),
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.typorg OWNER TO opendata;

--
-- Name: TABLE typorg; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE typorg IS 'Types d''organismes';


--
-- Name: COLUMN typorg.typorgcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typorg.typorgcod IS 'Code type organisme';


--
-- Name: COLUMN typorg.typorglib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typorg.typorglib IS 'Libellé';


--
-- Name: COLUMN typorg.typorglic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typorg.typorglic IS 'Libellé court';


--
-- Name: COLUMN typorg.typorgnumtri; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typorg.typorgnumtri IS 'Numéro de tri';


--
-- Name: COLUMN typorg.typorgurlsim; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typorg.typorgurlsim IS 'URL simplifiée';


--
-- Name: COLUMN typorg.typorgurlcmp; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typorg.typorgurlcmp IS 'URL complète';


--
-- Name: COLUMN typorg.typorglibplu; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typorg.typorglibplu IS 'Libellé pluriel';


--
-- Name: COLUMN typorg.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typorg.syscredat IS 'Date système création';


--
-- Name: COLUMN typorg.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typorg.sysmajdat IS 'Date système modification';


--
-- Name: typurl; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE typurl (
    typurlcod character varying(12) NOT NULL,
    temvalcod character varying(12),
    evelic character varying(60),
    evelib character varying(120),
    evelil character varying(255),
    eveobs character varying(255),
    typurllogo character varying(255),
    typurlnumtri bigint,
    typurllogoref character varying(255),
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.typurl OWNER TO opendata;

--
-- Name: TABLE typurl; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE typurl IS 'Types d''URL
';


--
-- Name: COLUMN typurl.typurlcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typurl.typurlcod IS 'Code type URL';


--
-- Name: COLUMN typurl.temvalcod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typurl.temvalcod IS 'Code validité';


--
-- Name: COLUMN typurl.evelic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typurl.evelic IS 'Libellé court';


--
-- Name: COLUMN typurl.evelib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typurl.evelib IS 'Libellé';


--
-- Name: COLUMN typurl.evelil; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typurl.evelil IS 'Libellé long';


--
-- Name: COLUMN typurl.eveobs; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typurl.eveobs IS 'Observations';


--
-- Name: COLUMN typurl.typurllogo; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typurl.typurllogo IS 'Logo';


--
-- Name: COLUMN typurl.typurlnumtri; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typurl.typurlnumtri IS 'Numéro de tri';


--
-- Name: COLUMN typurl.typurllogoref; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typurl.typurllogoref IS 'OBSOLETE';


--
-- Name: COLUMN typurl.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typurl.syscredat IS 'Date système création';


--
-- Name: COLUMN typurl.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typurl.sysmajdat IS 'Date système modification';


--
-- Name: typvoi; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE typvoi (
    typvoicod character varying(12) NOT NULL,
    typvoilic character varying(60),
    typvoilib character varying(255),
    typvoinumtri bigint
);


ALTER TABLE public.typvoi OWNER TO opendata;

--
-- Name: TABLE typvoi; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE typvoi IS 'Type ou nature de voie';


--
-- Name: COLUMN typvoi.typvoicod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typvoi.typvoicod IS 'Code type de voie';


--
-- Name: COLUMN typvoi.typvoilic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typvoi.typvoilic IS 'Libellé court';


--
-- Name: COLUMN typvoi.typvoilib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typvoi.typvoilib IS 'Libellé';


--
-- Name: COLUMN typvoi.typvoinumtri; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN typvoi.typvoinumtri IS 'Numéro de tri';


--
-- Name: zongeo; Type: TABLE; Schema: public; Owner: opendata; Tablespace: 
--

CREATE TABLE zongeo (
    zongeocod character varying(12) NOT NULL,
    concod character varying(12) NOT NULL,
    zongeolib character varying(120) NOT NULL,
    zongeolic character varying(60) NOT NULL,
    zongeonumtri bigint,
    syscredat timestamp without time zone,
    sysmajdat timestamp without time zone
);


ALTER TABLE public.zongeo OWNER TO opendata;

--
-- Name: TABLE zongeo; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON TABLE zongeo IS 'Zones géographique';


--
-- Name: COLUMN zongeo.zongeocod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN zongeo.zongeocod IS 'Code zone géographique';


--
-- Name: COLUMN zongeo.concod; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN zongeo.concod IS 'Code continent';


--
-- Name: COLUMN zongeo.zongeolib; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN zongeo.zongeolib IS 'Libellé';


--
-- Name: COLUMN zongeo.zongeolic; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN zongeo.zongeolic IS 'Libellé court';


--
-- Name: COLUMN zongeo.zongeonumtri; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN zongeo.zongeonumtri IS 'Numéro de tri';


--
-- Name: COLUMN zongeo.syscredat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN zongeo.syscredat IS 'Date système création';


--
-- Name: COLUMN zongeo.sysmajdat; Type: COMMENT; Schema: public; Owner: opendata
--

COMMENT ON COLUMN zongeo.sysmajdat IS 'Date système modification';


--
-- Data for Name: activite; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY activite (actid, typactcod, catactcod, scrid, comcod, delegacod, actlic, actlib, datdeb, datfin, validdat, envjodat, nb_participants, nb_delegations, giacod, gecod) FROM stdin;
107	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat PJL dialogue social et emploi	Débat PJL dialogue social et emploi	2015-06-24 14:30:00	2015-06-24 18:30:00	\N	\N	3	0	\N	\N
108	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat PJL dialogue social et emploi	Débat PJL dialogue social et emploi	2015-06-24 21:30:00	2015-06-25 00:30:00	\N	\N	39	0	\N	\N
5209	COM_EURO	CONTROLE	\N	AFEU	\N	Contrôle	Contrôle	2015-07-01 16:32:00	2015-07-01 18:02:00	\N	2015-07-07 16:56:52	12	0	\N	\N
5342	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2015-07-02 12:00:00	2015-07-02 13:00:00	2015-07-03 09:47:23	2015-07-03 09:47:37	15	0	\N	\N
5402	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au Gouvernement	Questions d'actualité au Gouvernement	2015-07-02 15:00:00	2015-07-02 15:45:00	\N	\N	99	0	\N	\N
5589	MISSION	AUCUNE	\N	COMMANDE	\N	MCI Commande publique 	MCI Commande publique 	2015-07-02 10:03:00	2015-07-02 13:28:00	2015-07-03 10:21:14	2015-07-07 16:57:38	8	0	\N	\N
5683	DELEGATION	AUCUNE	\N	\N	211	Examen du rapport Santé	Examen du rapport Santées femmes 	2015-07-02 09:00:00	2015-07-02 11:10:00	2015-07-03 12:20:18	2015-07-07 17:23:40	10	0	\N	\N
6362	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2015-07-07 16:00:00	2015-07-07 17:20:00	2015-07-08 10:25:25	2015-07-09 17:54:36	11	0	\N	\N
8070	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Résultat scrutin PJL LPM 2015-2019	Résultat scrutin PJL LPM 2015-2019	2015-07-15 15:45:00	2015-07-15 16:00:00	\N	\N	165	0	\N	\N
9997	SEANCE_PLENIERE	QO	\N	\N	\N	QO 	Questions orales	2015-07-21 09:30:00	2015-07-21 14:30:00	\N	\N	28	0	\N	\N
9998	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP handicap	CMP handicap	2015-07-21 14:30:00	2015-07-21 21:30:00	\N	\N	58	0	\N	\N
10023	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Examen PJL comptes 2014	Examen PJL de règlement du budget et d'approbation des comptes 2014	2015-07-21 19:30:00	2015-07-22 00:30:00	\N	\N	45	0	\N	\N
10092	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-07-21 09:48:00	2015-07-21 10:28:00	2015-07-21 15:50:22	2015-07-21 17:15:47	10	0	\N	\N
10111	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2015-07-21 09:33:00	2015-07-21 10:04:00	2015-07-21 14:10:47	2015-07-21 17:15:46	19	0	\N	\N
10209	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-07-21 09:08:00	2015-07-21 10:28:00	2015-07-21 17:52:31	2015-07-21 17:52:34	36	0	\N	\N
10905	MISSION	AUCUNE	\N	COMMANDE	\N	MCI Commande publique 	MCI Commande publique 	2015-07-23 09:22:00	2015-07-23 12:51:00	2015-07-23 16:08:34	2015-07-23 17:40:00	4	0	\N	\N
11326	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2015-09-14 15:00:00	2015-09-14 15:10:00	2015-09-15 15:40:08	2015-09-15 17:01:07	11	0	\N	\N
11570	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-09-14 19:30:00	2015-09-14 20:30:00	2015-09-14 23:07:16	2015-09-15 17:01:09	32	0	\N	\N
11656	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Examen  PJL santé	Examen PJL santé	2015-09-15 14:30:00	2015-09-15 16:00:00	\N	\N	135	0	\N	\N
11657	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Examen PJL Santé	Examen PJL Santé	2015-09-15 21:30:00	2015-09-16 02:00:00	\N	\N	109	0	\N	\N
11658	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Examen PJL Santé	Examen PJL Santé	2015-09-15 17:30:00	2015-09-15 19:30:00	\N	\N	107	0	\N	\N
11659	SEANCE_PLENIERE	DECL_GVT	\N	\N	\N	Décl. du Gvt interv. Syrie	Décl. du Gvt interv. Syrie	2015-09-15 16:00:00	2015-09-15 17:30:00	\N	\N	236	0	\N	\N
11963	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Modernisation santé	PJL Modernisation santé	2015-09-17 10:30:00	2015-09-17 12:30:00	\N	\N	95	0	\N	\N
11964	SEANCE_PLENIERE	QAG	\N	\N	\N	QAG 	QAG 	2015-09-17 15:00:00	2015-09-17 16:00:00	\N	\N	154	0	\N	\N
11966	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Modernisation  santé 	PJL Modernisation  santé	2015-09-17 16:15:00	2015-09-17 19:30:00	\N	\N	66	0	\N	\N
13978	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-09-17 09:30:00	2015-09-17 10:30:00	2015-09-17 22:18:04	2015-09-18 08:51:05	28	0	\N	\N
15810	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-09-29 14:05:00	2015-09-29 14:47:00	2015-09-30 09:16:33	2015-09-30 16:01:28	21	0	\N	\N
15863	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Examen pjl santé	Examen pjl santé	2015-09-30 14:31:00	2015-09-30 15:35:00	\N	\N	71	0	\N	\N
16532	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2015-09-30 09:00:00	2015-09-30 10:25:00	2015-09-30 14:18:55	2015-09-30 16:02:48	40	0	\N	\N
16725	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-09-30 09:05:00	2015-09-30 12:44:00	2015-09-30 15:51:51	2015-09-30 16:02:50	39	0	\N	\N
5028	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	Transition énergétique	2015-07-01 09:30:00	2015-07-01 10:25:00	2015-07-02 11:17:11	2015-07-02 17:45:41	28	0	\N	\N
5071	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-07-01 09:03:00	2015-07-01 12:54:00	2015-07-02 10:27:30	2015-07-02 17:38:18	33	7	\N	\N
6552	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2015-07-08 09:00:00	2015-07-08 12:20:00	2015-07-08 17:46:10	2015-07-08 17:51:32	38	0	\N	\N
7123	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-07-08 09:11:00	2015-07-08 10:50:00	2015-07-09 16:10:04	2015-07-09 16:20:11	36	0	\N	\N
8089	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2015-07-15 09:00:00	2015-07-15 11:25:00	2015-07-15 17:11:30	2015-07-15 17:49:53	24	0	\N	\N
9890	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-07-15 09:35:00	2015-07-15 10:37:00	2015-07-17 10:03:02	2015-07-17 15:07:45	24	0	\N	\N
10528	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2015-07-22 11:30:00	2015-07-22 11:40:00	2015-07-22 15:29:33	2015-07-22 16:35:56	18	0	\N	\N
13196	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-09-16 08:30:00	2015-09-16 13:30:00	2015-09-16 15:10:06	2015-09-16 17:56:47	49	0	\N	\N
13390	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2015-09-16 10:08:00	2015-09-16 10:30:00	2015-09-17 11:05:47	2015-09-17 11:28:22	40	0	\N	\N
17089	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2015-09-30 08:35:00	2015-09-30 09:10:00	2015-09-30 17:07:07	2015-09-30 17:59:12	36	0	\N	\N
17225	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Examen PJL Santé - Soir	Examen PJL Santé - Soir	2015-10-01 21:30:00	2015-10-02 00:30:00	\N	\N	0	0	\N	\N
17334	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-09-30 16:29:00	2015-09-30 19:08:00	2015-10-02 11:24:44	2015-10-02 11:26:03	34	0	\N	\N
17557	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2015-10-01 11:00:00	2015-10-01 12:30:00	2015-10-01 15:40:35	2015-10-01 17:33:42	31	0	\N	\N
17832	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Délégation sénatoriale aux entreprises 	Délégation sénatoriale aux entreprises 	2015-10-01 08:30:00	2015-10-01 12:40:00	2015-10-01 16:08:54	2015-10-01 17:35:01	36	0	\N	\N
17947	DELEGATION	AUCUNE	\N	\N	211	Droits des femmes 	Droits des femmes 	2015-10-01 08:30:00	2015-10-01 10:00:00	2015-10-01 16:02:36	2015-10-01 17:34:59	12	0	\N	\N
18363	DELEGATION	AUCUNE	\N	\N	COLTER	Collectivités  territoriales 	Collectivités  territoriales 	2015-10-08 08:30:00	2015-10-08 10:00:00	2015-10-08 11:19:14	2015-10-08 14:42:06	10	0	\N	\N
18403	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	301	\N	\N	PJL Santé	PJL Santé	2015-10-06 15:15:00	2015-10-06 16:10:00	\N	\N	304	0	\N	\N
18404	SEANCE_PLENIERE	QAG	\N	\N	\N	QAG 	QAG 	2015-10-06 16:45:00	2015-10-06 17:44:00	\N	\N	306	0	\N	\N
5995	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Suite PJL Prog. militaire	Suite PJL Prog. militaire	2015-07-08 18:00:00	2015-07-08 19:30:00	\N	\N	45	0	\N	\N
6036	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Prog. militaire	PJL Prog. militaire	2015-07-08 14:30:00	2015-07-08 19:30:00	\N	\N	120	0	\N	\N
6037	SEANCE_PLENIERE	DECL_GVT	\N	\N	\N	Décl. du Gvt  - Grèce	Décl. du Gvt  - Grèce	2015-07-08 16:15:00	2015-07-08 18:00:00	\N	\N	181	0	\N	\N
6301	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	PPL n° 544	2015-07-07 15:30:00	2015-07-07 15:56:00	2015-07-07 18:39:48	2015-07-08 15:55:50	26	0	\N	\N
7416	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-07-08 16:30:00	2015-07-08 18:38:00	2015-07-09 16:10:57	2015-07-09 16:20:12	31	0	\N	\N
7881	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Transition énergétique	PJL Transition énergétique 	2015-07-10 09:30:00	2015-07-10 12:30:00	\N	\N	23	0	\N	\N
7882	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Transition énergétique	PJL Transition énergétique 	2015-07-10 14:30:00	2015-07-10 19:00:00	\N	\N	24	0	\N	\N
10946	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2015-07-23 09:00:00	2015-07-23 10:53:00	2015-07-23 17:42:48	2015-07-23 18:03:00	12	0	\N	\N
11001	SEANCE_PLENIERE	OUV_SESSION	\N	\N	\N	Ouv. session  extraordinaire	Ouv. session extraordinaire	2015-09-14 16:00:00	2015-09-14 16:15:00	\N	\N	64	0	\N	\N
11003	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL  Système de santé (après-midi)	PJL  Système de santé (après-midi)	2015-09-14 16:30:00	2015-09-14 19:30:00	\N	\N	75	0	\N	\N
11004	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL  Système de santé (soir)	PJL  Système de santé (soir)	2015-09-14 19:30:00	2015-09-14 23:00:00	\N	\N	56	0	\N	\N
11005	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL  système de santé 	PJL  système de santé 	2015-09-14 21:30:00	2015-09-14 23:59:00	\N	\N	0	0	\N	\N
11440	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-09-14 14:30:00	2015-09-14 16:00:00	2015-09-14 18:25:29	2015-09-15 17:01:06	30	0	\N	\N
11971	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Modernisation santé	PJL Modernisation santé	2015-09-17 21:00:00	2015-09-17 23:59:00	\N	\N	35	0	\N	\N
13925	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-09-17 09:32:00	2015-09-17 11:10:00	2015-09-17 17:44:30	2015-09-18 08:49:27	20	0	\N	\N
15266	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Modernisation Santé	PJL Modernisation Santé	2015-09-29 14:30:00	2015-09-29 19:30:00	\N	\N	140	0	\N	\N
15267	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Modernisation Santé	PJL Modernisation Santé	2015-09-29 20:00:00	2015-09-29 23:59:00	\N	\N	83	0	\N	\N
15375	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-09-28 14:00:00	2015-09-28 16:00:00	2015-09-28 17:27:06	2015-09-28 18:09:28	19	0	\N	\N
15533	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2015-09-29 09:00:00	2015-09-29 10:40:00	2015-09-29 18:34:03	2015-09-30 10:39:27	31	0	\N	\N
18382	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Examen Concl. CMP 2e div. numérique	Examen Concl. CMP 2e div. numérique	2015-10-05 16:00:00	2015-10-05 17:30:00	\N	\N	17	0	\N	\N
18405	SEANCE_PLENIERE	DECL_GVT	\N	\N	\N	Décl. du Gvt - agriculture	Décl. du Gvt - agriculture	2015-10-06 17:45:00	2015-10-06 19:30:00	\N	\N	119	0	\N	\N
18407	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2015-10-06 09:07:00	2015-10-06 10:34:00	2015-10-06 11:23:07	2015-10-06 17:31:21	27	0	\N	\N
16788	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-09-30 09:30:00	2015-09-30 12:30:00	2015-09-30 15:36:58	2015-09-30 16:02:51	45	0	\N	\N
17131	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2015-09-30 09:15:00	2015-09-30 13:14:00	2015-09-30 17:47:33	2015-09-30 17:59:13	42	0	\N	\N
5144	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2015-07-01 10:00:00	2015-07-01 10:25:00	2015-07-01 16:55:43	2015-07-01 17:01:23	26	0	\N	\N
6399	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2015-07-08 09:00:00	2015-07-08 10:08:00	2015-07-08 11:38:59	2015-07-08 15:56:08	35	0	\N	\N
18439	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Proclamation résultats scrutin PJL Santé	Proclamation résultats scrutin PJL Santé	2015-10-06 16:30:00	2015-10-06 16:44:00	\N	\N	0	0	\N	\N
20101	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2015-10-06 17:45:00	2015-10-06 19:56:00	2015-10-07 14:29:53	2015-10-07 16:27:42	42	0	\N	\N
20149	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Afrique du sud et PJL Côte d'Ivoire	PJL Afrique du sud et PJL Côte d'Ivoire	2015-10-08 11:40:00	2015-10-08 12:00:00	\N	\N	15	0	\N	\N
20150	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Droit des étrangers	PJL Droit des étrangers	2015-10-08 12:00:00	2015-10-08 13:00:00	\N	\N	48	0	\N	\N
20152	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Droit des étrangers	PJL Droit des étrangers	2015-10-08 21:00:00	2015-10-08 23:59:00	\N	\N	48	0	\N	\N
20153	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE	Audition	2015-10-07 09:32:00	2015-10-07 11:58:00	2015-10-07 16:42:11	2015-10-07 17:45:30	35	0	\N	\N
20340	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2015-10-07 09:38:00	2015-10-07 11:59:00	2015-10-07 15:27:25	2015-10-07 16:27:40	49	0	\N	\N
20607	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	Audition	2015-10-07 11:00:00	2015-10-07 11:30:00	2015-10-07 17:00:07	2015-10-07 17:45:24	28	0	\N	\N
20655	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-10-07 10:39:00	2015-10-07 12:25:00	2015-10-07 17:42:03	2015-10-07 17:45:26	42	0	\N	\N
20726	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2015-10-07 09:30:00	2015-10-07 12:30:00	2015-10-07 16:42:01	2015-10-07 17:45:33	46	0	\N	\N
20816	COM_SPECIALE	PLENIERE	\N	PROSTITUTION	\N	CS sur la lutte contre le système prostitutionnel 	CS sur la lutte contre le système prostitutionnel 	2015-10-07 14:30:00	2015-10-07 16:00:00	2015-10-07 18:04:14	2015-10-08 14:43:52	22	0	\N	\N
20860	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Droit des étrangers	PJL Droit des étrangers	2015-10-07 21:00:00	2015-10-07 23:59:00	\N	\N	50	0	\N	\N
20866	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2015-10-07 18:10:00	2015-10-07 18:15:00	2015-10-08 10:10:35	2015-10-08 15:04:35	3	0	\N	\N
20871	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-10-07 17:30:00	2015-10-07 18:30:00	2015-10-07 19:28:19	2015-10-08 15:04:34	21	0	\N	\N
21075	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-10-08 09:00:00	2015-10-08 10:57:00	2015-10-08 11:19:20	2015-10-08 15:04:36	25	0	\N	\N
21124	DELEGATION	AUCUNE	\N	\N	211	Droits des femmes 	Droits des femmes 	2015-10-08 08:30:00	2015-10-08 11:00:00	2015-10-08 12:15:07	2015-10-08 14:42:07	12	0	\N	\N
21149	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Droit des étrangers	PJL Droit des étrangers	2015-10-08 14:30:00	2015-10-08 19:30:00	\N	\N	43	0	\N	\N
21185	MISSION	AUCUNE	\N	COMMANDE	\N	FINC 	FINC 	2015-10-08 08:19:00	2015-10-08 10:12:00	2015-10-08 15:41:44	2015-10-08 17:54:44	14	0	\N	\N
6352	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	suite pjl Prog. militaire	suite pjl Prog. militaire	2015-07-08 21:30:00	2015-07-08 23:59:00	\N	\N	0	0	\N	\N
7084	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Examen pjl transition énergétique matin	Examen du pjl transition énergétique pour une croissance verte matin	2015-07-09 10:30:00	2015-07-09 13:30:00	\N	\N	46	0	\N	\N
7090	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat sur l'orientation des finances publiques	Débat sur l'orientation des finances publiques	2015-07-09 14:30:00	2015-07-09 19:30:00	\N	\N	56	0	\N	\N
7100	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Examen pjl budget et comptes 2014 am	Examen du pjl de règlement du budget et d'approbation des comptes de l'année 2014 am	2015-07-09 14:31:00	2015-07-09 19:30:00	\N	\N	0	0	\N	\N
7116	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Examen pjl shoah am	Examen du pjl shoah am	2015-07-09 14:32:00	2015-07-09 19:30:00	\N	\N	24	0	\N	\N
7117	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Examen pjl shoah soir	Examen pjl shoah soir	2015-07-09 19:30:00	2015-07-10 04:00:00	\N	\N	0	0	\N	\N
7118	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Examen pjl transition énergétique am	Examen du pjl transition énergétique pour une croissance verte am	2015-07-09 14:33:00	2015-07-09 19:30:00	\N	\N	26	0	\N	\N
7119	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Examen pjl transition énergétique soir	Examen du pjl transition énergétique pour une croissance verte soir	2015-07-09 19:31:00	2015-07-10 04:00:00	\N	\N	22	0	\N	\N
7388	COM_ENQUETE	PLENIERE	\N	POLLUTION	\N	CE Pollution de l'air	CE Pollution de l'air	2015-07-08 12:00:00	2015-07-08 13:44:00	2015-07-08 18:33:15	2015-07-09 15:15:40	7	0	\N	\N
9367	SEANCE_PLENIERE	QAG	\N	\N	\N	QAG 	Questions d'actualité au Gouvernement	2015-07-16 15:00:00	2015-07-16 16:15:00	\N	\N	138	0	\N	\N
20151	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-10-07 09:32:00	2015-10-07 10:39:00	2015-10-07 17:41:39	2015-10-07 17:45:32	43	0	\N	\N
20194	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	PPL n° 565	2015-10-07 09:30:00	2015-10-07 10:33:00	2015-10-07 16:59:15	2015-10-07 17:45:35	31	0	\N	\N
20236	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2015-10-07 11:04:00	2015-10-07 11:40:00	2015-10-09 10:20:43	2015-10-09 10:26:44	40	0	\N	\N
20433	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2015-10-07 11:59:00	2015-10-07 12:22:00	2015-10-07 15:28:19	2015-10-07 16:27:29	49	0	\N	\N
20495	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2015-10-07 11:54:00	2015-10-07 13:07:00	2015-10-09 10:21:41	2015-10-09 10:26:45	40	0	\N	\N
20529	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-10-07 10:00:00	2015-10-07 13:50:00	2015-10-07 15:20:38	2015-10-07 16:27:37	52	0	\N	\N
9368	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Conclusions CMP NOTRe	Conclusions CMP NOTRe	2015-07-16 16:15:00	2015-07-16 23:59:00	\N	\N	57	0	\N	\N
9963	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-07-20 14:35:00	2015-07-20 14:59:00	2015-07-21 17:15:18	2015-07-21 17:15:27	11	0	\N	\N
9982	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL dialogue social et emploi - Après-midi	PJL dialogue social et emploi - Après-midi	2015-07-20 16:00:00	2015-07-20 19:30:00	\N	\N	28	0	\N	\N
9983	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL dialogue social et emploi - Soir	PJL dialogue social et emploi - Soir	2015-07-20 21:30:00	2015-07-21 00:30:00	\N	\N	0	0	\N	\N
10661	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-07-22 14:30:00	2015-07-22 19:00:00	2015-07-22 22:05:25	2015-07-23 10:45:22	47	0	\N	\N
10981	COM_ENQUETE	PLENIERE	\N	AUTORITES	\N	CE Autorités administratives indépendantes 	CE Autorités administratives indépendantes 	2015-07-29 14:37:00	2015-07-29 17:10:00	2015-07-31 16:27:38	2015-08-04 11:14:40	5	0	\N	\N
11021	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2015-09-08 16:30:00	2015-09-08 17:45:00	2015-09-15 11:30:30	2015-09-15 11:30:37	22	0	\N	\N
11184	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-09-09 14:36:00	2015-09-09 15:44:00	2015-09-11 15:00:28	2015-09-11 16:21:41	27	0	\N	\N
11719	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	pjl santé	pjl santé	2015-09-16 14:30:00	2015-09-17 00:30:00	\N	\N	180	0	\N	\N
11720	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat  réfugiés	Débat réfugiés	2015-09-16 21:30:00	2015-09-16 23:30:00	\N	\N	136	0	\N	\N
11721	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	pjl santé	pjl santé	2015-09-16 23:45:00	2015-09-16 23:59:00	\N	\N	56	0	\N	\N
12847	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-09-15 20:30:00	2015-09-15 21:30:00	2015-09-15 22:46:41	2015-09-16 12:28:10	32	0	\N	\N
13343	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2015-09-16 09:30:00	2015-09-16 10:45:00	2015-09-16 17:54:55	2015-09-17 11:28:21	26	0	\N	\N
14485	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-09-17 14:00:00	2015-09-17 15:00:00	2015-09-21 16:19:00	2015-09-21 16:19:27	15	0	\N	\N
15188	DELEGATION	AUCUNE	\N	\N	206	OPECST 	OPECST -EPTA-Audition publique sur les changements climatiques	2015-09-24 08:45:00	2015-09-24 18:30:00	2015-09-28 15:50:12	2015-09-28 18:08:15	9	0	\N	\N
15617	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2015-09-29 09:04:00	2015-09-29 09:53:00	2015-09-29 12:36:13	2015-09-29 16:00:35	19	0	\N	\N
15760	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-09-29 13:30:00	2015-09-29 14:15:00	2015-09-29 15:26:04	2015-09-29 16:00:37	31	0	\N	\N
15890	DELEGATION	AUCUNE	\N	\N	PROS	Délégation sénatoriale à la prospective 	Audition de Jean Pautrot, président du Conseil Magellan de l'International	2015-10-08 08:30:00	2015-10-08 09:30:00	\N	\N	6	0	\N	\N
15897	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-09-29 09:06:00	2015-09-29 10:40:00	2015-09-30 15:55:35	2015-09-30 16:01:26	21	0	\N	\N
16481	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-09-29 16:07:00	2015-09-29 18:53:00	2015-09-30 15:56:18	2015-09-30 16:01:30	35	0	\N	\N
16590	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2015-09-29 16:34:00	2015-09-29 19:01:00	2015-09-30 12:37:54	2015-09-30 16:01:31	34	0	\N	\N
16629	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2015-09-30 09:30:00	2015-09-30 11:05:00	2015-10-01 17:28:55	2015-10-01 17:33:19	28	0	\N	\N
16779	DELEGATION	AUCUNE	\N	\N	COLTER	Collectivités  territoriales 	Collectivités  territoriales 	2015-10-01 09:00:00	2015-10-01 11:50:00	2015-10-01 17:09:25	2015-10-01 17:35:02	14	0	\N	\N
17220	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Examen Concl. CMP Outre mer	Examen Concl. CMP Outre mer	2015-10-01 10:30:00	2015-10-01 12:00:00	\N	\N	63	0	\N	\N
17221	SEANCE_PLENIERE	QAG	\N	\N	\N	QAG 	QAG 	2015-10-01 15:00:00	2015-10-01 16:00:00	\N	\N	222	0	\N	\N
17223	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Examen PJL Santé - Matin	Examen PJL Santé - Matin	2015-10-01 12:05:00	2015-10-01 13:00:00	\N	\N	55	0	\N	\N
17224	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Examen PJL Santé - Après-midi	Examen PJL Santé- Après-midi	2015-10-01 16:15:00	2015-10-01 19:30:00	\N	\N	69	0	\N	\N
17948	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2015-10-01 08:35:00	2015-10-01 10:20:00	2015-10-01 16:09:18	2015-10-01 17:36:52	19	0	\N	\N
18311	COM_ENQUETE	PLENIERE	\N	AUTORITES	\N	CE Autorités administratives indépendantes 	CE Autorités administratives indépendantes 	2015-09-30 14:43:00	2015-09-30 18:19:00	2015-10-01 17:43:08	2015-10-01 17:45:58	6	0	\N	\N
18401	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	pjl droit des étrangers après-midi	pjl droit des étrangers après-midi	2015-10-07 14:30:00	2015-10-07 19:00:00	\N	\N	127	0	\N	\N
18406	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Examen PJL droit des étrangers	Examen PJL droit des étrangers	2015-10-06 21:30:00	2015-10-07 00:30:00	\N	\N	33	0	\N	\N
18436	SEANCE_PLENIERE	SCRUSOL	301	\N	\N	Scrutin n°3 PJL Santé	Scrutin n°3 - sur l'ensemble du projet de loi, adopté par l'Assemblée nationale après engagement de la procédure accélér	2015-10-06 16:10:00	2015-10-06 16:35:00	\N	\N	0	0	\N	\N
723	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Discussion PJL Nairobi	PJL Nairobi	2015-06-25 14:30:00	2015-06-25 15:00:00	\N	\N	0	0	\N	\N
724	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Discussion  PJL dialogue social	Pjl dialogue social	2015-06-25 15:00:00	2015-06-25 19:30:00	\N	\N	55	0	\N	\N
725	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	 PJL Géorgie	PJL Géorgie	2015-06-25 14:00:00	2015-06-25 14:30:00	\N	\N	0	0	\N	\N
820	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	pjl modernisation droit outre-mer	PJL modernisation droit outre-mer	2015-06-26 09:30:00	2015-06-26 12:30:00	\N	\N	10	0	\N	\N
10552	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-07-22 09:05:00	2015-07-22 13:08:00	2015-07-22 16:43:36	2015-07-22 17:31:54	49	0	\N	\N
11079	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2015-09-09 08:30:00	2015-09-09 09:40:00	2015-09-09 15:18:26	2015-09-09 17:24:15	42	0	\N	\N
13091	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-09-16 09:04:00	2015-09-16 12:18:00	2015-09-16 15:22:46	2015-09-16 17:56:48	39	0	\N	\N
14961	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2015-09-23 09:30:00	2015-09-23 11:12:00	2015-09-23 15:27:48	2015-09-23 17:48:49	25	0	\N	\N
821	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL modernisation droit outre-mer	PJL modernisation droit outre-mer	2015-06-26 14:30:00	2015-06-26 20:00:00	\N	\N	1	0	\N	\N
822	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	pjl modernisation droit outre-mer	pjl modernisation droit outre-mer	2015-06-26 22:00:00	2015-06-26 23:59:00	\N	\N	0	0	\N	\N
4234	DELEGATION	AUCUNE	\N	\N	206	OPECST 	Audition publique sur la place du traitement massif des données (big data) dans l'agriculture	2015-07-02 09:00:00	2015-07-02 12:50:00	2015-07-02 17:44:05	2015-07-07 17:23:42	3	0	\N	\N
4237	DELEGATION	AUCUNE	\N	\N	206	OPECST 	Audition publique sur  les terres rares et des matières premières stratégiques et critiques	2015-07-06 09:00:00	2015-07-06 18:00:00	\N	2015-07-07 17:31:52	2	0	\N	\N
4401	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Macron - Soir	PJL Macron	2015-07-01 21:30:00	2015-07-02 01:30:00	\N	\N	49	0	\N	\N
4402	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	pjl  Macron - après-midi	pjl Macron	2015-07-01 14:30:00	2015-07-01 19:30:00	\N	\N	125	0	\N	\N
5538	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2015-07-07 09:30:00	2015-07-07 09:40:00	2015-07-08 17:53:55	2015-07-09 15:55:46	16	0	\N	\N
5657	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Discussion PPL inscriptions sur les listes électorales - am	Discussion PPL inscriptions sur les listes électorales - am	2015-07-07 14:33:00	2015-07-07 19:30:00	\N	\N	0	0	\N	\N
5658	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2015-07-07 09:30:00	2015-07-07 13:00:00	\N	\N	26	0	\N	\N
5659	SEANCE_PLENIERE	ELOGE_FUNEBRE	\N	\N	\N	Éloge funèbre de Jean GERMAIN	Éloge funèbre de Jean GERMAIN	2015-07-07 14:30:00	2015-07-07 19:30:00	\N	\N	0	0	\N	\N
5660	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Discussion PJL enseignement France - Andorre	Discussion PJL enseignement France - Andorre	2015-07-07 14:31:00	2015-07-07 19:30:00	\N	\N	43	0	\N	\N
5661	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Discussion PJL changements climatiques	Discussion PJL changements climatiques 	2015-07-07 14:32:00	2015-07-07 19:30:00	\N	\N	43	0	\N	\N
5663	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Discussion PPL inscriptions listes électorales (soir))	Discussion PPL inscriptions sur les listes électorales (soir)	2015-07-07 21:30:00	2015-07-08 04:00:00	\N	\N	63	0	\N	\N
5664	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Discussion PJL réforme droit d'asile (am)	Discussion PJL réforme droit d'asile (am)	2015-07-07 14:34:00	2015-07-07 19:30:00	\N	\N	70	0	\N	\N
5665	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Discussion PJL réforme droit d'asile (soir)	Discussion PJL réforme droit d'asile (soir)	2015-07-07 21:30:00	2015-07-08 04:00:00	\N	\N	0	0	\N	\N
7883	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	CAE 	2015-07-09 17:00:00	2015-07-09 17:13:00	2015-07-10 13:35:47	2015-07-10 14:14:06	6	0	\N	\N
7943	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2015-07-09 14:30:00	2015-07-09 17:30:00	2015-07-10 13:35:58	2015-07-10 14:14:01	14	0	\N	\N
7986	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2015-07-10 11:48:00	2015-07-10 11:58:00	2015-07-10 16:43:02	2015-07-10 16:47:44	11	0	\N	\N
8061	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	282	\N	\N	Scrutin n°225, explication de vote	Scrutin n°225 - sur l'ensemble du projet de loi actualisant la programmation militaire pour les années 2015 à 2019 et po	2015-07-15 14:30:00	2015-07-15 15:15:00	\N	\N	161	0	\N	\N
8062	SEANCE_PLENIERE	DECL_GVT	\N	\N	\N	Décl. du Gvt - Grèce	Décl. du Gvt  - Grèce	2015-07-15 16:15:00	2015-07-15 18:15:00	\N	\N	169	0	\N	\N
8063	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Maroc	PJL Maroc	2015-07-15 18:45:00	2015-07-15 19:00:00	\N	\N	54	0	\N	\N
8064	SEANCE_PLENIERE	SCRUSOL	282	\N	\N	Scrutin n°225, explication de vote	Scrutin n°225 - sur l'ensemble du projet de loi actualisant la programmation militaire pour les années 2015 à 2019 et po	2015-07-15 15:15:00	2015-07-15 15:45:00	\N	\N	165	0	\N	\N
8065	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Belgique 	PJL Belgique	2015-07-15 18:15:00	2015-07-15 18:30:00	\N	\N	31	0	\N	\N
8066	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Transition énergétique	PJL Transition énergétique	2015-07-15 19:00:00	2015-07-15 20:00:00	\N	\N	0	0	\N	\N
8067	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Transition énergétique	PJL Transition énergétique	2015-07-15 21:00:00	2015-07-15 23:00:00	\N	\N	57	0	\N	\N
8068	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Transition énergétique	PJL Transition énergétique	2015-07-15 23:10:00	2015-07-15 23:59:00	\N	\N	0	0	\N	\N
8188	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	CAE 	2015-07-15 11:06:00	2015-07-15 12:13:00	2015-07-15 15:43:14	2015-07-15 16:57:46	17	0	\N	\N
9381	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Conclusions CMP LPM 2015-2019	Conclusions CMP LPM 2015-2019	2015-07-17 09:30:00	2015-07-17 11:00:00	\N	\N	13	0	\N	\N
9475	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-07-15 18:00:00	2015-07-15 18:45:00	2015-07-20 09:37:29	2015-07-20 09:40:04	21	0	\N	\N
10449	MISSION	AUCUNE	\N	COMMANDE	\N	MCI Commande publique 	MCI Commande publique 	2015-07-22 08:36:00	2015-07-22 09:59:00	2015-07-22 12:47:49	2015-07-22 16:35:07	5	0	\N	\N
6613	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-07-08 09:47:00	2015-07-08 12:50:00	2015-07-09 09:38:02	2015-07-09 16:22:32	39	4	\N	\N
6788	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2015-07-08 09:00:00	2015-07-08 12:30:00	2015-07-09 11:36:04	2015-07-09 16:09:03	23	0	\N	\N
6867	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	CAE 	2015-07-08 09:34:00	2015-07-08 11:28:00	2015-07-08 18:07:48	2015-07-09 16:01:28	26	0	\N	\N
8071	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-07-15 10:04:00	2015-07-15 10:50:00	2015-07-15 13:12:45	2015-07-15 17:06:39	20	0	\N	\N
13440	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-09-16 19:30:00	2015-09-16 20:30:00	2015-09-21 16:42:35	2015-09-21 16:42:39	27	0	\N	\N
14574	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-09-17 20:00:00	2015-09-17 20:40:00	2015-09-17 22:18:24	2015-09-18 08:51:07	11	0	\N	\N
2789	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJLO Nouvelle-Calédonie - Après-midi	Discussion	2015-06-29 16:00:00	2015-06-29 19:30:00	\N	\N	27	0	\N	\N
2821	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	262	\N	\N	Scrutin n°221, explication de vote	Scrutin n°221 - sur l'ensemble du projet de loi adopté par l'Assemblée nationale, après engagement de la procédure accél	2015-06-30 14:30:00	2015-06-30 15:15:00	\N	\N	192	0	\N	\N
2822	SEANCE_PLENIERE	SCRUSOL	262	\N	\N	Scrutin solennel - PJL dialogue social et emploi	Scrutin solennel - PJL dialogue social et emploi	2015-06-30 15:15:00	2015-06-30 15:45:00	\N	\N	343	0	\N	\N
2823	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Résultat du scrutin PJL dialogue social	Proclamation du résultat du scrutin PJL dialogue social et emploi	2015-06-30 15:45:00	2015-06-30 16:00:00	\N	\N	203	0	\N	\N
2824	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Discussion PJL Macron - après midi	Discussion PJL Macron - après-midi	2015-06-30 16:00:00	2015-06-30 19:30:00	\N	\N	149	0	\N	\N
2825	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Discussion PJL Macron - soir	Discussion PJL Macron - soir	2015-06-30 21:30:00	2015-07-01 00:30:00	\N	\N	84	0	\N	\N
4446	DELEGATION	AUCUNE	\N	\N	206	OPECST 	Politique spatiale européenne	2015-07-07 14:00:00	2015-07-07 18:00:00	2015-07-08 17:18:35	2015-07-08 17:18:48	6	0	\N	\N
4447	DELEGATION	AUCUNE	\N	\N	206	OPECST 	Audition de M. Alain Fuchs, Président  directeur général du CNRS	2015-07-07 19:00:00	2015-07-07 22:25:00	2015-07-08 17:13:09	2015-07-09 15:18:02	10	0	\N	\N
4448	DELEGATION	AUCUNE	\N	\N	206	OPECST 	Réunion plénière	2015-07-08 17:35:00	2015-07-08 19:50:00	2015-07-09 12:04:51	2015-07-09 15:18:04	9	2	\N	\N
5341	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2015-07-02 09:05:00	2015-07-02 11:10:00	2015-07-02 15:13:00	2015-07-07 16:57:02	17	0	\N	\N
5996	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	CAE 	2015-07-07 09:30:00	2015-07-07 10:09:00	2015-07-08 17:36:27	2015-07-08 17:51:30	20	0	\N	\N
6512	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2015-07-07 15:30:00	2015-07-07 19:40:00	2015-07-08 15:38:51	2015-07-09 16:20:04	25	0	\N	\N
7632	DELEGATION	AUCUNE	\N	\N	COLTER	Collectivités  territoriales 	Collectivités  territoriales 	2015-07-09 08:30:00	2015-07-09 10:10:00	2015-07-09 13:40:52	2015-07-09 15:19:11	8	0	\N	\N
7650	MISSION	AUCUNE	\N	COMMANDE	\N	MCI Commande publique 	MCI Commande publique 	2015-07-09 10:02:00	2015-07-09 13:01:00	\N	\N	6	0	\N	\N
9492	MISSION	AUCUNE	\N	COMMANDE	\N	MCI Commande publique 	MCI Commande publique 	2015-07-16 09:23:00	2015-07-16 13:02:00	2015-07-16 15:03:11	2015-07-16 15:09:47	3	0	\N	\N
9772	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2015-07-16 13:45:00	2015-07-16 14:55:00	2015-07-16 18:12:48	2015-07-16 18:13:49	11	0	\N	\N
10320	MISSION	AUCUNE	\N	COMMANDE	\N	MCI Commande publique 	MCI Commande publique 	2015-07-21 16:13:00	2015-07-21 17:19:00	2015-07-21 22:01:25	2015-07-22 16:35:06	8	0	\N	\N
10481	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Examen ppl tnt	Examen ppl tnt	2015-07-22 14:30:00	2015-07-22 20:30:00	\N	\N	73	0	\N	\N
10527	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Examen pjl procédure pénale	Examen pjl procédure pénale	2015-07-23 10:30:00	2015-07-23 21:30:00	\N	\N	36	0	\N	\N
10887	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2015-07-23 10:00:00	2015-07-23 10:15:00	2015-07-23 14:28:22	2015-07-23 17:37:43	13	0	\N	\N
10917	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-07-22 20:05:00	2015-07-23 00:15:00	2015-07-23 18:22:51	2015-07-23 18:22:57	25	0	\N	\N
11661	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-09-15 09:30:00	2015-09-15 10:30:00	2015-09-16 12:18:04	2015-09-16 12:28:06	42	0	\N	\N
12212	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-09-15 13:30:00	2015-09-15 14:30:00	2015-09-15 18:16:18	2015-09-16 12:28:08	36	0	\N	\N
14601	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Modernisation Santé	PJL Modernisation Santé	2015-09-18 09:30:00	2015-09-18 12:30:00	\N	\N	35	0	\N	\N
4403	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	Transition énergétique	2015-07-01 10:00:00	2015-07-01 11:23:00	2015-07-01 14:25:04	2015-07-01 14:34:38	29	0	\N	\N
4622	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2015-07-01 09:05:00	2015-07-01 12:30:00	2015-07-01 14:05:17	2015-07-01 14:34:33	36	0	\N	\N
4680	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-07-01 10:12:00	2015-07-01 11:25:00	2015-07-01 14:38:49	2015-07-01 16:12:45	44	0	\N	\N
4954	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2015-07-01 09:00:00	2015-07-01 12:30:00	2015-07-01 16:01:45	2015-07-01 16:12:47	40	0	\N	\N
8069	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2015-07-15 10:05:00	2015-07-15 11:51:00	2015-07-15 17:57:33	2015-07-16 14:52:47	20	0	\N	\N
11135	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-09-09 10:00:00	2015-09-09 13:00:00	2015-09-10 14:24:56	2015-09-10 14:56:53	41	0	\N	\N
12941	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2015-09-16 10:10:00	2015-09-16 12:00:00	2015-09-16 12:37:47	2015-09-16 17:56:49	43	0	\N	\N
14602	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Modernisation Santé	PJL Modernisation Santé	2015-09-18 14:30:00	2015-09-18 19:30:00	\N	\N	37	0	\N	\N
14603	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Modernisation Santé	PJL Modernisation Santé	2015-09-18 21:30:00	2015-09-18 23:59:00	\N	\N	17	0	\N	\N
14634	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Modernisation Santé	PJL Modernisation Santé	2015-09-28 10:00:00	2015-09-28 12:30:00	\N	\N	33	0	\N	\N
14646	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL St-Barthélémy	PJL St-Barthélémy	2015-09-28 14:30:00	2015-09-28 15:30:00	\N	\N	14	0	\N	\N
14647	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Ressources propres	PJL Ressources propres	2015-09-28 15:30:00	2015-09-28 16:30:00	\N	\N	26	0	\N	\N
14648	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Modernisation santé	PJL Modernisation santé	2015-09-28 17:30:00	2015-09-28 19:30:00	\N	\N	47	0	\N	\N
14649	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Modernisation santé	PJL Modernisation santé	2015-09-28 21:30:00	2015-09-28 23:59:00	\N	\N	50	0	\N	\N
14651	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-09-18 08:30:00	2015-09-18 09:30:00	2015-09-18 11:58:51	2015-09-21 10:35:10	13	0	\N	\N
14701	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-09-18 13:45:00	2015-09-18 14:30:00	2015-09-18 19:10:46	2015-09-21 10:35:12	13	0	\N	\N
15039	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	CAE 	2015-09-22 15:11:00	2015-09-22 17:34:00	2015-09-23 15:42:30	2015-09-23 17:48:48	29	0	\N	\N
15101	DELEGATION	AUCUNE	\N	\N	DSOM	Outre-mer 	Outre-mer 	2015-10-01 09:30:00	2015-10-01 10:30:00	2015-10-02 09:36:53	2015-10-02 11:32:24	17	0	\N	\N
15163	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Délégation aux entreprises 	Délégation sénatoriale aux entreprises 	2015-09-17 08:00:00	2015-09-17 09:00:00	\N	\N	13	0	\N	\N
15501	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-09-29 09:30:00	2015-09-29 10:30:00	2015-09-29 11:37:02	2015-09-29 16:00:36	29	0	\N	\N
15591	COM_ENQUETE	PLENIERE	\N	AUTORITES	\N	CE Autorités administratives indépendantes 	CE Autorités administratives indépendantes 	2015-09-29 15:03:00	2015-09-29 19:00:00	2015-10-01 09:54:59	2015-10-01 17:38:05	9	0	\N	\N
15862	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Examen PJL Bâtiments de construction	Examen PJL Bâtiments de construction	2015-09-30 14:30:00	2015-09-30 17:00:00	\N	\N	126	0	\N	\N
21352	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2015-10-08 10:10:00	2015-10-08 11:50:00	2015-10-08 18:39:13	2015-10-09 10:51:50	34	0	\N	\N
21521	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat éducation	Débat éducation	2015-10-12 16:00:00	2015-10-12 20:00:00	\N	\N	28	0	\N	\N
21522	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	ppl protection de l'enfant	ppl protection de l'enfant	2015-10-12 21:00:00	2015-10-13 00:30:00	\N	\N	30	0	\N	\N
21523	SEANCE_PLENIERE	QO	\N	\N	\N	QO 	QO 	2015-10-13 09:30:00	2015-10-13 14:00:00	\N	\N	39	0	\N	\N
21524	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Examen ppl protection de l'enfant am	Examen ppl protection de l'enfant am	2015-10-13 16:00:00	2015-10-13 18:00:00	\N	\N	93	0	\N	\N
21525	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Examen ppl protection de l'enfant soir	Examen ppl protection de l'enfant soir	2015-10-13 21:30:00	2015-10-14 00:30:00	\N	\N	60	0	\N	\N
21528	SEANCE_PLENIERE	EXAMEN	321	\N	\N	Scrutin n°9, explication de vote	Scrutin n°9 - sur l'ensemble de la proposition de loi organique portant dématérialisation du Journal officiel de la Répu	2015-10-12 16:01:00	2015-10-12 20:00:00	\N	\N	17	0	\N	\N
22405	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat - Réunion du Conseil européen	Débat - Réunion du Conseil européen	2015-10-13 18:00:00	2015-10-13 20:00:00	\N	\N	68	0	\N	\N
23573	COM_SPECIALE	PLENIERE	\N	PROSTITUTION	\N	CS sur la lutte contre le système prostitutionnel 	CS sur la lutte contre le système prostitutionnel 	2015-10-14 14:15:00	2015-10-14 14:45:00	2015-10-14 18:15:50	2015-10-15 10:09:44	26	0	\N	\N
27318	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2015-10-28 10:00:00	2015-10-28 12:30:00	2015-10-28 14:52:15	2015-10-28 17:20:44	34	0	\N	\N
27649	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-10-28 14:29:00	2015-10-28 18:07:00	2015-10-29 15:00:50	2015-10-29 15:37:52	38	0	\N	\N
28658	DELEGATION	AUCUNE	\N	\N	COLTER	Collectivités  territoriales 	Collectivités  territoriales 	2015-11-05 08:30:00	2015-11-05 09:30:00	2015-11-05 11:56:47	2015-11-05 12:21:07	11	0	\N	\N
28721	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJLO Indépendance magistrats	PJLO Indépendance magistrats	2015-11-04 14:30:00	2015-11-04 15:20:00	\N	\N	40	0	\N	\N
28724	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2015-11-03 09:05:00	2015-11-03 10:15:00	2015-11-03 12:25:14	2015-11-03 15:39:07	16	0	\N	\N
29988	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2015-11-04 10:30:00	2015-11-04 11:35:00	2015-11-04 14:26:40	2015-11-04 17:01:07	30	0	\N	\N
30456	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2015-11-04 14:20:00	2015-11-04 17:00:00	2015-11-04 17:59:47	2015-11-05 10:23:22	38	0	\N	\N
30948	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-11-05 10:15:00	2015-11-05 11:30:00	2015-11-05 17:21:53	2015-11-05 18:01:31	28	0	\N	\N
33041	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE  PLF 2016 - Economie	Audition Rapporteur CAE PLF 2016 - Economie 	2015-11-03 16:00:00	2015-11-03 17:00:00	\N	\N	1	0	\N	\N
33047	GIA	AUCUNE	\N	\N	\N	GIA Liban	Groupe interparlementaire Liban	2015-11-12 12:45:00	2015-11-12 14:15:00	\N	\N	11	0	597	\N
33060	GIA	AUCUNE	\N	\N	\N	GIA Cambodge et Laos	Groupe interparlementaire Cambodge et Laos	2015-11-04 12:45:00	2015-11-04 14:30:00	\N	\N	3	0	577	\N
33344	GIA	AUCUNE	\N	\N	\N	GIA Libye	Groupe interparlementaire Libye	2015-11-19 09:00:00	2015-11-19 11:00:00	\N	\N	2	0	657	\N
23299	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2015-10-14 08:37:00	2015-10-14 12:26:00	2015-10-14 18:39:58	2015-10-15 10:43:08	42	0	\N	\N
23349	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2015-10-14 12:34:00	2015-10-14 12:51:00	2015-10-15 10:16:06	2015-10-15 10:43:13	31	0	\N	\N
24441	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2015-07-22 10:05:00	2015-07-22 12:15:00	2015-10-20 15:54:21	2015-10-20 16:10:52	38	0	\N	\N
29941	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-11-04 09:10:00	2015-11-04 12:05:00	2015-11-05 09:58:12	2015-11-05 10:23:28	45	0	\N	\N
30006	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2015-11-04 09:00:00	2015-11-04 10:25:00	2015-11-04 14:26:06	2015-11-04 17:01:10	41	0	\N	\N
33361	GIA	AUCUNE	\N	\N	\N	GIA Pakistan	Groupe interparlementaire Pakistan	2015-11-04 08:00:00	2015-11-04 09:30:00	\N	\N	5	0	619	\N
33406	GIA	AUCUNE	\N	\N	\N	GIA Pakistan	Groupe interparlementaire Pakistan	2015-12-02 08:00:00	2015-12-02 09:30:00	\N	\N	4	0	619	\N
35181	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2015-11-10 17:00:00	2015-11-10 18:00:00	\N	\N	1	0	\N	\N
35183	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2015-11-10 09:30:00	2015-11-10 10:30:00	\N	\N	1	0	\N	\N
35185	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2015-11-10 10:30:00	2015-11-10 11:30:00	\N	\N	1	0	\N	\N
35187	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2015-11-12 09:00:00	2015-11-12 10:00:00	\N	\N	1	0	\N	\N
35621	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Protection des forêts	PPL Protection des forêts	2015-11-18 14:30:00	2015-11-18 15:55:00	\N	\N	50	0	\N	\N
35622	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat  Bilan bicamérisme	Débat Bilan bicamérisme	2015-11-18 16:25:00	2015-11-18 17:55:00	\N	\N	69	0	\N	\N
35623	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Nouvelle-Calédonie	PPL Nouvelle-Calédonie 	2015-11-18 18:35:00	2015-11-18 19:45:00	\N	\N	30	0	\N	\N
35624	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Entreprises donneuses d'ordre	PPL Entreprises donneuses d'ordre	2015-11-18 21:45:00	2015-11-18 23:30:00	\N	\N	25	0	\N	\N
35625	GIA	AUCUNE	\N	\N	\N	GIA Mongolie	Groupe interparlementaire Mongolie	2015-11-17 18:00:00	2015-11-17 18:30:00	\N	\N	5	0	612	\N
35631	GIA	AUCUNE	\N	\N	\N	GIA Mongolie	Groupe interparlementaire Mongolie	2015-11-18 13:30:00	2015-11-18 15:00:00	\N	\N	2	0	612	\N
35634	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2015-11-17 17:45:00	2015-11-17 19:50:00	2015-11-18 15:28:06	2015-11-18 16:38:56	47	0	\N	\N
36760	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-11-18 14:30:00	2015-11-18 17:55:00	2015-11-19 14:29:33	2015-11-19 15:39:55	40	0	\N	\N
36967	DELEGATION	AUCUNE	\N	\N	211	Droits des femmes 	Droits des femmes 	2015-11-19 08:30:00	2015-11-19 09:45:00	2015-11-19 10:46:34	2015-11-19 11:06:51	6	0	\N	\N
37057	GIA	AUCUNE	\N	\N	\N	GIA Brésil	Petit-déjeuner en l'honneur de l'ambassadeur du Brésil en France	2015-11-19 08:30:00	2015-11-19 09:45:00	\N	\N	7	0	576	\N
37248	DELEGATION	AUCUNE	\N	\N	206	OPECST 	OPECST 	2015-11-24 17:05:00	2015-11-24 20:00:00	2015-11-25 17:19:59	2015-11-25 17:28:23	11	0	\N	\N
37347	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition rapporteur ETRD	2015-11-18 14:30:00	2015-11-18 16:45:00	\N	\N	5	0	\N	\N
37353	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2015-11-18 16:45:00	2015-11-18 19:00:00	\N	\N	3	0	\N	\N
37366	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2015-11-18 14:30:00	2015-11-18 16:00:00	\N	\N	1	0	\N	\N
38145	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2015-11-18 16:30:00	2015-11-18 17:25:00	\N	\N	1	0	\N	\N
38148	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2015-11-17 08:30:00	2015-11-17 09:30:00	\N	\N	2	0	\N	\N
38924	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2016	PLF 2016	2015-11-25 11:00:00	2015-11-25 13:00:00	\N	\N	77	0	\N	\N
38925	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2016	PLF 2016	2015-11-25 14:30:00	2015-11-25 18:15:00	\N	\N	157	0	\N	\N
38926	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Intervention Syrie	Débat Intervention Syrie	2015-11-25 18:15:00	2015-11-25 20:30:00	\N	\N	142	0	\N	\N
38927	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2016	PLF 2016	2015-11-25 22:05:00	2015-11-26 00:50:00	\N	\N	49	0	\N	\N
21501	DELEGATION	AUCUNE	\N	\N	206	OPECST 	Audition publique sur les  ressources génétiques	2015-10-13 09:00:00	2015-10-13 13:10:00	2015-10-14 18:56:34	2015-10-15 10:10:20	2	0	\N	\N
21612	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	341	\N	\N	Explications de vote - PJL droit des étrangers	Explications de vote - PJL droit des étrangers	2015-10-13 14:30:00	2015-10-13 15:25:00	\N	\N	286	0	\N	\N
21613	SEANCE_PLENIERE	SCRUSOL	341	\N	\N	Scrutin solennel - PJL droit des étrangers	Scrutin solennel - PJL droit des étrangers	2015-10-13 15:25:00	2015-10-13 16:05:00	\N	\N	0	0	\N	\N
21650	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-10-12 18:30:00	2015-10-12 19:50:00	2015-10-12 21:51:58	2015-10-13 16:58:10	13	0	\N	\N
24361	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2015-10-20 09:03:00	2015-10-20 09:30:00	2015-10-20 11:57:37	2015-10-20 17:09:00	12	0	\N	\N
27142	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition ministre de l'Education nationale	Audition de Mme Najat VALLAUD-BELKACEM, ministre de l'Éducation nationale	2015-10-27 19:00:00	2015-10-27 20:55:00	2015-10-28 12:39:52	2015-10-28 15:02:55	25	0	\N	\N
27415	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	Audition M. Schweitzer	2015-10-28 11:02:00	2015-10-28 12:58:00	2015-10-28 16:27:05	2015-10-28 17:20:48	34	0	\N	\N
27822	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2015-10-29 08:30:00	2015-10-29 09:50:00	2015-10-29 15:42:05	2015-10-29 17:07:37	11	0	\N	\N
32291	ETUDES	AUCUNE	\N	\N	\N	GE Gestion des déchets	Groupe d'études Gestion des déchets	2015-11-12 14:00:00	2015-11-12 15:00:00	\N	\N	5	0	\N	922
32657	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI 	Audition Rapporteur SOCI 	2015-11-03 17:45:00	2015-11-03 19:30:00	2015-11-12 16:26:54	\N	2	0	\N	\N
33032	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2015-11-04 14:00:00	2015-11-04 15:15:00	\N	\N	2	0	\N	\N
33035	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2015-11-03 10:00:00	2015-11-03 11:00:00	\N	\N	1	0	\N	\N
33037	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2015-11-05 15:00:00	2015-11-05 16:30:00	\N	\N	1	0	\N	\N
35961	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2015-11-18 08:35:00	2015-11-18 12:30:00	2015-11-19 15:54:37	2015-11-19 15:55:19	46	0	\N	\N
36521	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2015-11-18 10:30:00	2015-11-18 12:30:00	2015-11-19 15:35:13	2015-11-19 15:35:47	44	0	\N	\N
25346	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-10-21 09:07:00	2015-10-21 10:34:00	2015-10-21 17:56:47	2015-10-22 10:01:08	48	0	\N	\N
33039	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2015-11-12 10:00:00	2015-11-12 11:30:00	\N	\N	1	0	\N	\N
33146	SEANCE_PLENIERE	HOMMAGE	\N	\N	\N	Hommage victimes attentats	Hommage victimes attentats	2015-11-16 21:30:00	2015-11-17 22:00:00	\N	\N	57	0	\N	\N
33147	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR Climat	PPR Climat	2015-11-16 22:00:00	2015-11-17 00:35:00	\N	\N	119	0	\N	\N
33345	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	381	\N	\N	Explications de vote PLFSS 2016	Explications de vote PLFSS 2016 	2015-11-17 15:00:00	2015-11-17 15:45:00	\N	\N	325	0	\N	\N
33346	SEANCE_PLENIERE	SCRUSOL	381	\N	\N	Scrutin PLFSS 2016	Scrutin PLFSS 2016	2015-11-17 15:45:00	2015-11-17 16:20:00	\N	\N	325	0	\N	\N
33347	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Proclamation résultats PLFSS 2016	Proclamation résultats PLFSS 2016	2015-11-17 16:15:00	2015-11-17 16:30:00	\N	\N	325	0	\N	\N
33348	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au Gouvernement	Questions d'actualité au Gouvernement	2015-11-17 16:30:00	2015-11-17 17:30:00	\N	\N	328	0	\N	\N
33349	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Dotation globale de fonctionnement	Débat Dotation globale de fonctionnement	2015-11-17 21:30:00	2015-11-18 00:40:00	\N	\N	84	0	\N	\N
36034	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2015-11-18 11:00:00	2015-11-18 12:30:00	2015-11-19 10:31:19	2015-11-19 10:55:59	41	0	\N	\N
37341	GIA	AUCUNE	\N	\N	\N	GIA Australie	Groupe interparlementaire Australie	2015-11-06 10:30:00	2015-11-16 14:45:00	\N	\N	4	0	578	\N
37587	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2015-11-12 11:00:00	2015-11-12 12:00:00	\N	\N	1	0	\N	\N
38023	ETUDES	AUCUNE	\N	\N	\N	GE Chasse et pêche	Groupe d'études Chasse et pêche	2015-11-18 08:30:00	2015-11-18 09:30:00	\N	\N	10	0	\N	907
38034	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	GT CDD Aménagement numérique du territoire	Groupe de travail CDD Aménagement numérique du territoire	2015-11-18 14:30:00	2015-11-18 15:30:00	\N	\N	4	0	\N	\N
38244	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-11-23 20:05:00	2015-11-23 20:20:00	2015-11-25 12:42:31	2015-11-25 14:24:00	20	0	\N	\N
38895	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2015-11-24 14:15:00	2015-11-24 17:45:00	\N	\N	1	0	\N	\N
40090	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2016 nouvelle lecture	PLFSS 2016 nouvelle lecture	2015-11-26 10:30:00	2015-11-26 12:15:00	\N	\N	68	0	\N	\N
40091	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au Gouvernement	Questions d'actualité au Gouvernement	2015-11-26 15:00:00	2015-11-26 16:10:00	\N	\N	227	0	\N	\N
40093	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2016	PLF 2016	2015-11-26 21:30:00	2015-11-26 23:15:00	\N	\N	25	0	\N	\N
40277	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2015-11-26 08:35:00	2015-11-26 10:35:00	2015-11-26 14:24:09	2015-11-26 15:44:26	14	0	\N	\N
40306	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-11-26 12:05:00	2015-11-26 12:45:00	2015-11-26 22:28:16	2015-11-27 14:49:28	19	0	\N	\N
40931	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2015-11-05 10:30:00	2015-11-05 11:30:00	\N	\N	1	0	\N	\N
40933	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2015-11-05 12:00:00	2015-11-05 12:30:00	\N	\N	1	0	\N	\N
40935	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2015-11-05 16:00:00	2015-11-05 18:00:00	\N	\N	1	0	\N	\N
40937	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2015-11-06 10:30:00	2015-11-06 12:00:00	\N	\N	1	0	\N	\N
40939	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2015-11-09 16:00:00	2015-11-09 17:00:00	\N	\N	1	0	\N	\N
40941	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2015-11-10 16:30:00	2015-11-10 17:30:00	\N	\N	1	0	\N	\N
40943	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2015-11-10 15:30:00	2015-11-10 16:30:00	\N	\N	1	0	\N	\N
40945	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2015-11-17 10:15:00	2015-11-17 11:00:00	\N	\N	2	0	\N	\N
40948	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2015-11-17 13:00:00	2015-11-17 14:30:00	\N	\N	1	0	\N	\N
40950	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2015-11-19 15:00:00	2015-11-19 17:15:00	\N	\N	2	0	\N	\N
40953	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2015-11-19 17:30:00	2015-11-19 18:30:00	\N	\N	1	0	\N	\N
40955	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2015-11-26 11:00:00	2015-11-26 11:45:00	\N	\N	2	0	\N	\N
40958	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2015-11-26 16:00:00	2015-11-26 17:00:00	\N	\N	2	0	\N	\N
40961	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2015-11-27 14:00:00	2015-11-27 14:45:00	\N	\N	2	0	\N	\N
21414	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	Audition	2015-10-08 10:12:00	2015-10-08 11:50:00	2015-10-08 18:15:37	2015-10-09 10:51:06	33	0	\N	\N
26213	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD	Audition Lemaire	2015-10-21 14:55:00	2015-10-21 16:25:00	2015-10-22 15:55:34	2015-10-22 17:14:43	21	0	\N	\N
26572	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2015-10-26 15:35:00	2015-10-26 15:51:00	2015-10-26 16:48:25	2015-10-26 17:15:44	4	0	\N	\N
27629	COM_ENQUETE	PLENIERE	\N	AUTORITES	\N	CE Autorités administratives indépendantes 	CE Autorités administratives indépendantes 	2015-10-28 15:03:00	2015-10-28 17:07:00	2015-10-28 18:10:31	2015-10-28 18:13:20	15	0	\N	\N
27823	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Délégation sénatoriale aux entreprises 	Délégation sénatoriale aux entreprises 	2015-10-29 08:30:00	2015-10-29 10:00:00	2015-10-29 10:40:35	2015-10-29 11:07:39	10	0	\N	\N
30318	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	Audition Fekl	2015-11-04 10:05:00	2015-11-04 12:35:00	2018-05-18 14:19:02	2018-05-18 14:19:17	32	0	\N	\N
35864	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-11-18 09:05:00	2015-11-18 12:05:00	2015-11-18 18:18:03	2015-11-19 11:05:56	47	0	\N	\N
35966	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2015-11-18 09:00:00	2015-11-18 10:55:00	2015-11-18 15:29:34	2015-11-18 16:41:19	49	0	\N	\N
39183	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-11-25 09:00:00	2015-11-25 11:55:00	2015-11-25 15:38:52	2015-11-25 17:22:14	49	0	\N	\N
39379	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2015-11-25 09:05:00	2015-11-25 12:25:00	2015-11-25 14:33:17	2015-11-25 17:22:10	46	0	\N	\N
30577	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-11-04 14:35:00	2015-11-04 17:35:00	2015-11-05 09:56:24	2015-11-05 10:23:24	40	0	\N	\N
30629	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-11-04 16:30:00	2015-11-04 18:00:00	2015-11-05 18:11:57	2015-11-05 18:12:18	18	0	\N	\N
31182	MECSS	AUCUNE	\N	\N	MECSS	MECSS 	MECSS 	2015-11-03 18:00:00	2015-11-03 19:00:00	2015-11-06 16:01:09	2015-11-06 18:47:04	10	0	\N	\N
31196	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2016	PLFSS 2016	2015-11-09 14:30:00	2015-11-09 19:30:00	\N	\N	46	0	\N	\N
31197	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2016	PLFSS 2016	2015-11-09 21:30:00	2015-11-10 01:05:00	\N	\N	49	0	\N	\N
31234	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-11-09 10:00:00	2015-11-09 12:30:00	2015-11-09 15:00:59	2015-11-09 16:48:06	24	0	\N	\N
32131	ETUDES	AUCUNE	\N	\N	\N	GE Sénateurs anciens combattants et mémoire combattante	Groupe d'études Sénateurs anciens combattants et mémoire combattante	2015-11-12 10:30:00	2015-11-12 12:30:00	\N	\N	5	0	\N	928
32166	ETUDES	AUCUNE	\N	\N	\N	GE Sénateurs anciens combattants et mémoire combattante	Groupe d'études Sénateurs anciens combattants et mémoire combattante	2015-11-12 14:00:00	2015-11-12 14:55:00	\N	\N	10	0	\N	928
33148	GIA	AUCUNE	\N	\N	\N	GIE Tibet	Groupe d'information Tibet	2015-11-10 10:00:00	2015-11-10 11:00:00	\N	\N	1	0	634	\N
33150	GIA	AUCUNE	\N	\N	\N	GIE Tibet	Groupe d'information Tibet	2015-10-15 08:00:00	2015-10-15 09:00:00	\N	\N	4	0	634	\N
36656	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2015-11-17 14:15:00	2015-11-17 15:00:00	\N	\N	1	0	\N	\N
37080	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2015-11-19 09:30:00	2015-11-19 10:50:00	2015-11-19 14:08:53	2015-11-19 15:39:58	29	0	\N	\N
37379	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-11-20 09:40:00	2015-11-20 12:15:00	2015-11-20 17:15:30	2015-11-20 17:41:46	27	0	\N	\N
37601	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2015-11-17 14:00:00	2015-11-17 15:30:00	\N	\N	1	0	\N	\N
38841	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2015-11-24 17:45:00	2015-11-24 19:20:00	2015-11-25 11:54:30	2015-11-25 14:24:02	20	0	\N	\N
39281	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	GT Aménagement numérique	2015-11-25 11:25:00	2015-11-25 12:15:00	2015-11-25 16:50:16	2015-11-25 17:22:04	25	0	\N	\N
40256	DELEGATION	AUCUNE	\N	\N	211	Droits des femmes 	Droits des femmes 	2015-11-25 14:00:00	2015-11-25 16:00:00	2015-11-26 13:27:10	2015-11-26 16:01:18	16	0	\N	\N
40964	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2016	PLF 2016	2015-11-27 10:30:00	2015-11-27 12:50:00	\N	\N	33	0	\N	\N
41113	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-11-27 14:15:00	2015-11-27 14:25:00	2015-11-27 15:13:39	2015-11-27 16:24:08	12	0	\N	\N
41145	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD  - Application de la loi sur l'eau	Audition Rapporteur CDD - App Loi Eau	2015-11-25 17:00:00	2015-11-25 18:00:00	\N	\N	1	0	\N	\N
41147	DELEGATION	AUDRAP	\N	\N	PROS	Délégation sénatoriale à la prospective 	Délégation sénatoriale à la prospective 	2015-11-24 17:00:00	2015-11-24 18:15:00	\N	\N	3	0	\N	\N
41148	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD - PLF 2016	Audition Rapporteur CDD  - PLF 2016	2015-11-24 09:00:00	2015-11-24 11:00:00	\N	\N	1	0	\N	\N
41155	DELEGATION	AUDRAP	\N	\N	PROS	Délégation sénatoriale à la prospective 	Délégation sénatoriale à la prospective 	2015-11-24 18:15:00	2015-11-24 19:15:00	\N	\N	3	0	\N	\N
41297	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2016	PLF 2016	2015-11-30 10:00:00	2015-11-30 12:00:00	\N	\N	36	0	\N	\N
41298	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2016	PLF 2016	2015-11-30 14:00:00	2015-11-30 19:30:00	\N	\N	46	0	\N	\N
41299	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2016	PLF 2016	2015-11-30 21:00:00	2015-11-30 23:35:00	\N	\N	33	0	\N	\N
41566	GIA	AUCUNE	\N	\N	\N	GIA Europe du Nord	GIA Europe du Nord	2015-11-25 08:30:00	2015-11-25 09:30:00	\N	\N	12	0	625	\N
41740	GIA	AUCUNE	\N	\N	\N	GIA Japon	Groupe interparlementaire Japon	2015-11-23 13:00:00	2015-11-23 14:15:00	\N	\N	1	0	596	\N
41848	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2016 - Mission Santé	PLF 2016 - Mission Santé	2015-12-01 14:30:00	2015-12-01 20:20:00	\N	\N	101	0	\N	\N
41881	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2016 - Mission Politique des territoires	PLF 2016 - Mission Politique des territoires	2015-12-02 14:30:00	2015-12-02 19:30:00	\N	\N	102	0	\N	\N
41950	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2015-12-01 14:30:00	2015-12-01 16:15:00	2015-12-01 17:14:57	2015-12-01 17:44:02	35	0	\N	\N
42463	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2015-12-01 14:30:00	2015-12-01 17:30:00	\N	\N	1	0	\N	\N
42474	QUESTURE	AUCUNE	\N	\N	\N	Questure	Réunion de Questure	2015-12-01 14:30:00	2015-12-01 16:20:00	\N	\N	3	0	\N	\N
42527	GIA	AUCUNE	\N	\N	\N	GIA Pakistan	Groupe interparlementaire Pakistan	2015-12-09 08:00:00	2015-12-09 09:30:00	\N	\N	5	0	619	\N
42530	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2015-12-02 08:35:00	2015-12-02 10:00:00	2015-12-02 11:09:17	2015-12-02 16:38:18	34	0	\N	\N
42648	QUESTURE	AUCUNE	\N	\N	\N	CA Public Sénat	Conseil d'administration de Public Sénat	2015-11-26 08:30:00	2015-11-26 09:30:00	\N	\N	1	0	\N	\N
42652	QUESTURE	AUCUNE	\N	\N	\N	Réunion COM Public Sénat	Réunion COM Public Sénat	2015-11-19 10:00:00	2015-11-19 11:00:00	\N	\N	3	0	\N	\N
42708	BUREAU	AUCUNE	\N	\N	\N	Délégation du Bureau	Statut et conditions d'exercice du mandat de sénateur	2015-12-02 11:30:00	2015-12-02 12:15:00	\N	\N	4	0	\N	\N
42957	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2015-12-02 10:30:00	2015-12-02 12:50:00	2015-12-02 17:48:32	2015-12-02 17:48:37	33	0	\N	\N
43134	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2016 Mission médias	PLF 2016 Mission médias	2015-12-03 09:35:00	2015-12-03 13:35:00	\N	\N	58	0	\N	\N
35805	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-11-18 09:00:00	2015-11-18 11:35:00	2015-11-18 13:27:33	2015-11-18 16:41:45	52	0	\N	\N
39241	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD	PLF2016	2015-11-25 09:00:00	2015-11-25 11:25:00	2015-11-26 16:51:23	2015-11-26 17:57:18	33	0	\N	\N
42478	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-12-02 09:05:00	2015-12-02 09:25:00	2015-12-02 11:07:27	2015-12-02 16:38:16	35	0	\N	\N
42590	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	PPL n° 113	2015-12-02 09:30:00	2015-12-02 10:35:00	2015-12-02 11:22:38	2015-12-02 16:38:11	31	0	\N	\N
42867	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2015-12-02 09:05:00	2015-12-02 10:30:00	2015-12-02 14:47:24	2015-12-02 16:38:15	41	0	\N	\N
43140	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2016 Mission sport	PLF 2016 Mission sport	2015-12-03 09:35:00	2015-12-03 13:35:00	\N	\N	57	0	\N	\N
26473	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	Audition Pinel	2015-10-22 11:30:00	2015-10-22 12:52:00	2015-10-22 18:25:59	2015-10-22 18:26:04	11	0	\N	\N
27068	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-10-27 18:33:00	2015-10-27 20:00:00	2015-10-29 14:45:00	2015-10-29 15:37:56	17	0	\N	\N
27593	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Examen pjl vieillissement - Soir	Examen pjl vieillissement - Soir	2015-10-28 21:30:00	2015-10-29 00:30:00	\N	\N	42	0	\N	\N
31401	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-11-10 09:05:00	2015-11-10 09:35:00	2015-11-12 09:19:03	2015-11-12 14:59:41	21	0	\N	\N
32163	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-11-12 13:35:00	2015-11-12 14:55:00	2015-11-12 19:15:39	2015-11-13 09:48:33	36	0	\N	\N
32678	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI 	Audition Rapporteur SOCI 	2015-11-04 14:00:00	2015-11-04 15:00:00	2015-11-12 16:29:09	\N	2	0	\N	\N
36441	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2015-11-17 15:05:00	2015-11-17 19:00:00	\N	\N	1	0	\N	\N
37002	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2015-11-19 08:35:00	2015-11-19 10:25:00	2015-11-19 11:17:07	2015-11-19 15:44:48	14	0	\N	\N
37605	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2015-11-20 14:40:00	2015-11-20 14:50:00	2015-11-20 17:39:22	2015-11-20 17:42:34	16	0	\N	\N
38039	SEANCE_PLENIERE	DEBAT	\N	\N	\N	PJLF 2016	PJLF 2016	2015-11-23 10:00:00	2015-11-23 12:55:00	\N	\N	36	0	\N	\N
38040	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJLF 2016	PJLF 2016	2015-11-23 14:30:00	2015-11-23 19:30:00	\N	\N	51	0	\N	\N
38041	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJLF 2016	PJLF 2016	2015-11-23 21:30:00	2015-11-24 01:35:00	\N	\N	39	0	\N	\N
38042	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJLF 2016	PJLF 2016	2015-11-24 14:30:00	2015-11-24 20:35:00	\N	\N	177	0	\N	\N
38394	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE 	Audition Rapporteur CAE 	2015-11-05 11:30:00	2015-11-05 12:30:00	\N	\N	1	0	\N	\N
38449	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Rapporteur 	Audition Rapporteur 	2015-11-05 14:00:00	2015-11-05 15:00:00	\N	\N	1	0	\N	\N
38451	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE 	Audition Rapporteur CAE 	2015-11-17 15:30:00	2015-11-17 17:00:00	\N	\N	1	0	\N	\N
38460	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE 	Audition Rapporteur CAE 	2015-11-10 15:00:00	2015-11-10 18:30:00	\N	\N	1	0	\N	\N
38479	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE  PLF 2016 - Economie	Audition Rapporteur CAE PLF 2016 - Economie	2015-11-12 14:00:00	2015-11-12 15:30:00	\N	\N	1	0	\N	\N
38493	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE 	Audition Rapporteur CAE 	2015-11-03 14:00:00	2015-11-03 15:00:00	\N	\N	1	0	\N	\N
38516	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE 	Audition Rapporteur CAE 	2015-11-05 09:00:00	2015-11-05 11:30:00	\N	\N	1	0	\N	\N
38527	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE 	Audition Rapporteur CAE 	2015-11-10 17:00:00	2015-11-10 17:50:00	\N	\N	1	0	\N	\N
38546	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE 	Audition Rapporteur CAE 	2015-11-17 18:00:00	2015-11-17 19:00:00	\N	\N	1	0	\N	\N
38594	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE 	Audition Rapporteur CAE 	2015-11-03 09:45:00	2015-11-03 11:15:00	\N	\N	1	0	\N	\N
38598	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE 	Audition Rapporteur CAE 	2015-11-04 13:15:00	2015-11-04 14:00:00	\N	\N	1	0	\N	\N
38601	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE 	Audition Rapporteur CAE 	2015-11-04 18:15:00	2015-11-04 19:20:00	\N	\N	1	0	\N	\N
38603	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE 	Audition Rapporteur CAE 	2015-11-12 13:45:00	2015-11-12 15:00:00	\N	\N	1	0	\N	\N
38891	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2015-11-24 08:30:00	2015-11-24 10:15:00	\N	\N	1	0	\N	\N
38893	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2015-11-24 10:15:00	2015-11-24 11:30:00	\N	\N	1	0	\N	\N
39631	BUREAU	AUCUNE	\N	\N	\N	Délégation du Bureau	Activités internationales	2015-11-25 14:30:00	2015-11-25 15:30:00	\N	\N	4	0	\N	\N
40570	QUESTURE	AUCUNE	\N	\N	\N	Questure	Réunion de Questure	2015-11-10 14:30:00	2015-11-10 15:40:00	\N	\N	2	0	\N	\N
40573	QUESTURE	AUCUNE	\N	\N	\N	Questure	Réunion de Questure	2015-11-17 18:00:00	2015-11-17 20:20:00	\N	\N	3	0	\N	\N
40577	QUESTURE	AUCUNE	\N	\N	\N	Questure	Réunion de Questure	2015-11-24 15:00:00	2015-11-24 17:10:00	\N	\N	3	0	\N	\N
40885	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-11-26 21:15:00	2015-11-26 21:25:00	2015-11-27 14:36:42	2015-11-27 14:49:30	8	0	\N	\N
40965	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2016	PLF 2016	2015-11-27 14:30:00	2015-11-27 18:50:00	\N	\N	58	0	\N	\N
40966	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2016	PLF 2016	2015-11-27 21:00:00	2015-11-27 22:50:00	\N	\N	29	0	\N	\N
40995	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJLF 2016	PJLF 2016 	2015-11-28 10:00:00	2015-11-28 12:45:00	\N	\N	36	0	\N	\N
40996	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJLF 2016	PJLF 2016	2015-11-28 14:30:00	2015-11-28 16:35:00	\N	\N	40	0	\N	\N
41003	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE Avis Recherche PLF 2016	Audition Rapporteur CAE 	2015-11-03 10:00:00	2015-11-03 10:45:00	\N	\N	1	0	\N	\N
41005	ETUDES	AUCUNE	\N	\N	\N	GE Forêt et filière bois	Groupe d'études Forêt et filière bois	2015-11-18 08:15:00	2015-11-18 09:30:00	\N	\N	13	0	\N	948
41008	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	GT CDD Climat Outre-mer	Groupe de travail CDD 	2015-11-03 09:45:00	2015-11-03 11:00:00	\N	\N	4	0	\N	\N
41011	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	GT CDD Négociations climatiques	Groupe de travail CDD 	2015-11-04 15:00:00	2015-11-04 16:30:00	\N	\N	10	0	\N	\N
41142	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2015-11-26 14:00:00	2015-11-26 14:40:00	\N	\N	2	0	\N	\N
41159	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2015-11-24 14:30:00	2015-11-24 15:30:00	\N	\N	2	0	\N	\N
41162	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	ETRD 	ETRD 	2015-11-24 16:00:00	2015-11-24 17:30:00	\N	\N	3	0	\N	\N
23511	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2015-10-14 12:51:00	2015-10-14 13:11:00	2015-10-14 18:38:40	2015-10-15 10:43:16	30	0	\N	\N
39321	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2015-11-25 09:30:00	2015-11-25 12:45:00	2015-11-25 15:59:35	2015-11-25 17:22:09	45	0	\N	\N
41166	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2015-11-25 15:00:00	2015-11-25 16:00:00	\N	\N	2	0	\N	\N
41172	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2015-11-17 09:00:00	2015-11-17 10:00:00	\N	\N	1	0	\N	\N
41174	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	LOIS 	LOIS 	2015-11-17 09:00:00	2015-11-17 10:00:00	\N	\N	1	0	\N	\N
41178	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2015-11-17 11:00:00	2015-11-17 12:15:00	\N	\N	1	0	\N	\N
41180	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2015-11-24 09:00:00	2015-11-24 10:15:00	\N	\N	1	0	\N	\N
41182	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2015-11-03 18:00:00	2015-11-03 19:00:00	\N	\N	1	0	\N	\N
41184	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2015-11-10 14:30:00	2015-11-10 15:30:00	\N	\N	1	0	\N	\N
41381	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2015-11-25 14:00:00	2015-11-25 15:30:00	\N	\N	1	0	\N	\N
41383	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2015-11-26 13:45:00	2015-11-26 14:35:00	\N	\N	1	0	\N	\N
41619	DELEGATION	AUCUNE	\N	\N	DSOM	Outre-mer 	Outre-mer 	2015-12-10 09:30:00	2015-12-10 10:35:00	2015-12-10 10:49:37	2015-12-10 10:49:58	7	0	\N	\N
41832	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2016 - Mission action extérieure de l'État	PLF 2016 - Mission action extérieure de l'État	2015-12-02 09:35:00	2015-12-02 13:15:00	\N	\N	117	0	\N	\N
41833	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2016 - Mission Pouvoirs publics	PLF 2016 - Mission Pouvoirs publics	2015-12-02 09:35:00	2015-12-02 13:15:00	\N	\N	27	0	\N	\N
41834	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2016 - Mission Conseil et contrôle de l'État	PLF 2016 - Mission Conseil et contrôle de l'État	2015-12-02 14:45:00	2015-12-02 20:20:00	\N	\N	66	0	\N	\N
42715	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2015-12-01 17:50:00	2015-12-01 19:30:00	2015-12-02 15:20:59	2015-12-02 16:38:20	24	0	\N	\N
22637	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2015-10-13 16:32:00	2015-10-13 17:56:00	2015-10-14 11:41:41	2015-10-14 17:01:52	64	0	\N	\N
22708	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-10-14 09:05:00	2015-10-14 10:25:00	2015-10-14 16:50:53	2015-10-14 17:21:47	43	0	\N	\N
22755	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2015-10-14 09:30:00	2015-10-14 10:36:00	2015-10-14 12:22:14	2015-10-14 17:21:46	44	0	\N	\N
23044	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-10-14 11:34:00	2015-10-14 13:10:00	2015-10-26 16:53:58	2015-10-26 16:54:21	26	0	\N	\N
23103	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	Audition Yché 	2015-10-14 10:34:00	2015-10-14 12:23:00	2015-10-14 17:47:08	2015-10-14 17:55:10	28	0	\N	\N
23187	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	Table ronde	2015-10-13 16:00:00	2015-10-13 18:00:00	2015-10-14 17:46:55	2015-10-14 17:53:35	18	0	\N	\N
23244	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-10-14 09:00:00	2015-10-14 12:30:00	2015-10-26 17:10:01	2015-10-27 12:40:09	43	0	\N	\N
24344	DELEGATION	AUCUNE	\N	\N	DSOM	Outre-mer 	Outre-mer 	2015-11-03 13:45:00	2015-11-03 15:00:00	2015-11-03 17:06:58	2015-11-03 17:08:16	39	0	\N	\N
24345	DELEGATION	AUCUNE	\N	\N	DSOM	Outre-mer 	Outre-mer 	2015-11-05 09:30:00	2015-11-05 10:30:00	2015-11-05 12:23:30	2015-11-05 12:24:44	7	0	\N	\N
25306	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	Audition Israël	2015-10-21 09:33:00	2015-10-21 12:00:00	2015-10-22 11:06:56	2015-10-22 15:17:29	32	0	\N	\N
25399	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-10-21 10:34:00	2015-10-21 12:40:00	2015-10-21 17:58:32	2015-10-22 10:01:03	40	0	\N	\N
26521	SEANCE_PLENIERE	QO	\N	\N	\N	QO 	QO 	2015-10-27 09:30:00	2015-10-27 12:00:00	\N	\N	35	0	\N	\N
26522	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Examen PJLC charte européenne langues régionales	Examen PJLC charte européenne langues régionales	2015-10-27 14:30:00	2015-10-27 19:30:00	\N	\N	171	0	\N	\N
26523	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Examen PPL mesures de surveillance	Examen PPL mesures de surveillance	2015-10-27 21:30:00	2015-10-28 01:00:00	\N	\N	41	0	\N	\N
26696	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2015-10-27 09:34:00	2015-10-27 09:46:00	2015-10-28 09:23:57	2015-10-28 15:02:53	23	0	\N	\N
26806	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Examen pjl vieillissement - Après-midi	Examen pjl vieillissement - Après-midi	2015-10-28 14:30:00	2015-10-28 19:30:00	\N	\N	112	0	\N	\N
30893	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2015-11-05 08:35:00	2015-11-05 10:25:00	2015-11-05 17:16:32	2015-11-05 17:19:23	17	0	\N	\N
31680	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2015-11-10 15:00:00	2015-11-10 17:20:00	2015-11-10 17:50:18	2015-11-12 15:00:05	14	0	\N	\N
32757	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2015-11-12 10:00:00	2015-11-12 11:00:00	2015-11-12 19:22:26	2015-11-13 09:48:30	25	0	\N	\N
32798	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2015-11-12 11:10:00	2015-11-12 12:45:00	2015-11-12 19:22:44	2015-11-13 09:48:32	25	0	\N	\N
32843	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	CAE 	2015-11-12 11:45:00	2015-11-12 13:05:00	2018-05-18 14:19:40	2018-05-18 14:19:56	25	0	\N	\N
35123	GIA	AUCUNE	\N	\N	\N	GIA Syrie	Groupe interparlementaire Syrie	2015-11-17 08:20:00	2015-11-17 10:00:00	\N	\N	3	0	644	\N
35127	GIA	AUCUNE	\N	\N	\N	GIA Syrie	Groupe interparlementaire Syrie	2015-11-17 12:30:00	2015-11-17 14:30:00	\N	\N	3	0	644	\N
35693	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition Fleur Pellerin	Audition de Mme Fleur Pellerin ministre de la culture et de la communication 	2015-11-17 17:45:00	2015-11-17 19:50:00	2015-11-18 14:51:05	2015-11-18 16:39:18	39	0	\N	\N
35863	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-11-17 17:35:00	2015-11-17 19:35:00	2015-11-19 09:33:21	2015-11-19 11:05:50	32	0	\N	\N
36893	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2016	PLF 2016	2015-11-19 11:00:00	2015-11-19 12:55:00	\N	\N	74	0	\N	\N
36894	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2016	PLF 2016	2015-11-19 14:30:00	2015-11-19 18:35:00	\N	\N	61	0	\N	\N
37215	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	Questions diverses	2015-11-19 10:15:00	2015-11-19 11:55:00	2015-11-19 14:58:18	2015-11-19 15:40:00	11	0	\N	\N
37279	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2015-11-19 16:10:00	2015-11-19 17:30:00	2015-11-20 12:18:51	2015-11-20 15:56:07	23	0	\N	\N
42666	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE	PPL  n° 86 et 453	2015-12-02 09:35:00	2015-12-02 11:55:00	2015-12-02 12:29:22	2015-12-02 16:38:09	35	0	\N	\N
22813	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2015-10-14 10:38:00	2015-10-14 11:23:00	2015-10-14 12:22:58	2015-10-14 17:21:41	46	0	\N	\N
22979	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-10-14 10:25:00	2015-10-14 11:27:00	2015-10-14 16:47:17	2015-10-14 17:21:42	44	0	\N	\N
37631	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2015-11-18 14:30:00	2015-11-18 18:00:00	\N	\N	1	0	\N	\N
38466	GIA	AUCUNE	\N	\N	\N	GIA Suisse	Groupe interparlementaire Suisse	2015-11-03 09:30:00	2015-11-03 11:00:00	\N	\N	8	0	610	\N
38476	GIA	AUCUNE	\N	\N	\N	GIA Suisse	Groupe interparlementaire Suisse	2015-11-12 09:00:00	2015-11-12 10:30:00	\N	\N	4	0	610	\N
38550	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	PLF 2016	2015-11-24 14:30:00	2015-11-24 16:50:00	2015-11-24 17:03:41	2015-11-24 17:07:25	33	0	\N	\N
38619	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Ports maritimes	CMP Ports maritimes	2015-11-24 22:15:00	2015-11-24 23:05:00	\N	\N	33	0	\N	\N
38622	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Prévention des risques	CMP Prévention des risques	2015-11-24 23:05:00	2015-11-24 23:45:00	\N	\N	30	0	\N	\N
40808	DELEGATION	AUCUNE	\N	\N	PROS	Délégation sénatoriale à la prospective 	Délégation sénatoriale à la prospective 	2015-11-26 08:30:00	2015-11-26 09:50:00	2015-11-26 17:54:35	2015-11-27 16:51:26	6	0	\N	\N
40853	DELEGATION	AUDRAP	\N	\N	PROS	Délégation sénatoriale à la prospective 	Délégation sénatoriale à la prospective 	2015-11-03 18:00:00	2015-11-03 19:10:00	\N	\N	2	0	\N	\N
41024	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2015-11-03 14:00:00	2015-11-03 15:00:00	\N	\N	1	0	\N	\N
41026	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2015-11-17 14:15:00	2015-11-17 15:00:00	\N	\N	2	0	\N	\N
41035	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2015-11-26 08:30:00	2015-11-26 11:20:00	\N	\N	2	0	\N	\N
41038	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2015-11-26 16:10:00	2015-11-26 17:40:00	\N	\N	10	0	\N	\N
41458	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE 	Audition Rapporteur CAE 	2015-11-03 09:30:00	2015-11-03 10:30:00	\N	\N	2	0	\N	\N
41461	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE 	Audition Rapporteur CAE 	2015-11-03 14:00:00	2015-11-03 15:00:00	\N	\N	5	0	\N	\N
41466	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE 	Audition Rapporteur CAE 	2015-11-04 16:00:00	2015-11-04 20:30:00	\N	\N	3	0	\N	\N
41471	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE 	Audition Rapporteur CAE 	2015-11-10 09:30:00	2015-11-10 16:30:00	\N	\N	2	0	\N	\N
41474	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE 	Audition Rapporteur CAE 	2015-11-18 16:30:00	2015-11-18 20:45:00	\N	\N	2	0	\N	\N
41477	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE 	Audition Rapporteur CAE 	2015-11-19 08:30:00	2015-11-19 12:00:00	\N	\N	2	0	\N	\N
41480	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE 	Audition Rapporteur CAE 	2015-11-24 10:15:00	2015-11-24 11:00:00	\N	\N	4	0	\N	\N
41485	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE 	Audition Rapporteur CAE 	2015-11-24 13:45:00	2015-11-24 14:30:00	\N	\N	1	0	\N	\N
41487	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE 	Audition Rapporteur CAE 	2015-11-25 14:00:00	2015-11-25 15:30:00	\N	\N	3	0	\N	\N
41491	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE 	Audition Rapporteur CAE 	2015-11-25 17:00:00	2015-11-25 19:00:00	\N	\N	3	0	\N	\N
41495	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE 	Audition Rapporteur CAE 	2015-11-26 09:15:00	2015-11-26 12:00:00	\N	\N	2	0	\N	\N
41498	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE 	Audition Rapporteur CAE 	2015-11-26 14:00:00	2015-11-26 15:00:00	\N	\N	2	0	\N	\N
41501	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-11-30 12:10:00	2015-11-30 12:35:00	2015-11-30 15:31:54	2015-11-30 16:34:12	16	0	\N	\N
41611	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2015-12-01 09:45:00	2015-12-01 12:25:00	\N	\N	37	0	\N	\N
41612	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2016	PLF 2016	2015-12-01 14:30:00	2015-12-01 20:20:00	\N	\N	115	0	\N	\N
41613	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2016 - Mission égalité des territoires et  logement	PLF 2016 - Mission égalité des territoires et  logement	2015-12-01 21:45:00	2015-12-01 23:40:00	\N	\N	57	0	\N	\N
41776	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-12-01 09:05:00	2015-12-01 10:20:00	2015-12-01 14:07:02	2015-12-01 16:14:11	28	0	\N	\N
41870	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2016 - Mission égalité des territoires et  logement	PLF 2016 - Mission égalité des territoires et  logement	2015-12-01 14:30:00	2015-12-01 20:20:00	\N	\N	73	0	\N	\N
22567	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat politique étrangère de la France	Débat  Politique étrangère de la France	2015-10-15 16:15:00	2015-10-15 18:00:00	\N	\N	47	0	\N	\N
22568	SEANCE_PLENIERE	QAG	\N	\N	\N	QAG 	QAG 	2015-10-15 15:00:00	2015-10-15 16:00:00	\N	\N	218	0	\N	\N
22569	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2015-10-13 16:32:00	2015-10-13 17:56:00	2015-10-14 14:11:19	2015-10-14 17:01:54	65	0	\N	\N
23629	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-10-14 16:30:00	2015-10-14 18:20:00	2015-10-14 19:23:32	2015-10-15 10:13:59	39	0	\N	\N
23701	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2015-10-14 16:30:00	2015-10-14 17:57:00	2015-10-15 10:51:42	2015-10-15 14:26:02	30	0	\N	\N
23795	DELEGATION	AUCUNE	\N	\N	COLTER	Collectivités  territoriales 	Examen rapport « Les collectivités territoriales et le changement climatique »	2015-10-22 08:30:00	2015-10-22 10:10:00	2015-10-22 14:42:02	2015-10-22 15:18:07	15	0	\N	\N
25161	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2015-10-20 18:00:00	2015-10-20 19:35:00	2015-10-21 12:35:07	2015-10-21 15:43:33	16	0	\N	\N
25239	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Signalement de maltraitance	PPL Signalement de maltraitance	2015-10-22 10:30:00	2015-10-22 11:30:00	\N	\N	32	0	\N	\N
25240	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Explications de vote pplo Saint-Barthélemy	Explications de vote pplo Saint-Barthélemy	2015-10-22 10:35:00	2015-10-22 12:30:00	\N	\N	16	0	\N	\N
25241	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	ppr Plan électricité objectif 2025	ppr Plan électricité objectif 2025	2015-10-22 14:30:00	2015-10-22 16:30:00	\N	\N	43	0	\N	\N
25242	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	ppl Contrats territoriaux 	ppl Contrats territoriaux 	2015-10-22 16:30:00	2015-10-22 18:30:00	\N	\N	36	0	\N	\N
26588	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	Examen texte n° 64	2015-10-26 15:30:00	2015-10-26 16:05:00	2015-10-27 10:23:21	2015-10-27 17:08:33	7	0	\N	\N
28399	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Examen ppl fin de vie 16h15	Examen ppl fin de vie 16h15	2015-10-29 16:15:00	2015-10-29 21:29:00	\N	\N	53	0	\N	\N
22871	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2015-10-14 09:45:00	2015-10-14 12:15:00	2015-10-14 14:39:22	2015-10-14 17:21:44	49	0	\N	\N
25704	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2015-10-21 09:26:00	2015-10-21 11:35:00	2015-10-27 12:39:20	2015-10-27 12:39:40	40	0	\N	\N
27091	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-10-28 09:02:00	2015-10-28 10:26:00	2015-10-29 14:57:40	2015-10-29 15:37:55	40	0	\N	\N
28401	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au Gouvernement	Questions d'actualité au Gouvernement	2015-11-03 16:45:00	2015-11-03 17:35:00	\N	\N	294	0	\N	\N
28402	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Magistrature	PJL Magistrature	2015-11-03 15:00:00	2015-11-03 20:10:00	\N	\N	64	0	\N	\N
28403	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Magistrature	PJL Magistrature	2015-11-03 21:40:00	2015-11-04 00:50:00	\N	\N	51	0	\N	\N
29881	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2015-11-03 18:00:00	2015-11-03 19:20:00	2015-11-04 14:57:50	2015-11-04 15:19:06	30	0	\N	\N
30075	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2015-11-03 18:00:00	2015-11-03 20:00:00	2015-11-04 12:18:07	2015-11-04 15:19:58	12	0	\N	\N
30801	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Convention Droits de l'enfant	Convention Droits de l'enfant	2015-11-05 10:30:00	2015-11-05 10:40:00	\N	\N	14	0	\N	\N
30802	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Communications électroniques 	PPL Communications électroniques 	2015-11-05 10:40:00	2015-11-05 11:25:00	\N	\N	23	0	\N	\N
30803	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Parti politique	PPL Parti politique	2015-11-05 11:50:00	2015-11-05 12:55:00	\N	\N	30	0	\N	\N
30805	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Justice du XXIe siècle	PJL Justice du XXIe siècle	2015-11-05 14:30:00	2015-11-05 21:00:00	\N	\N	43	0	\N	\N
31108	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	Audition de M. de Juniac	2015-11-05 11:00:00	2015-11-05 12:25:00	2015-11-05 17:12:42	2015-11-05 17:20:16	15	0	\N	\N
31514	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	206	Réunion du bureau	Réunion du bureau	2015-11-18 17:00:00	2015-11-18 19:00:00	\N	\N	7	0	\N	\N
31849	ETUDES	AUCUNE	\N	\N	\N	GE Cheval	Groupe d'études Cheval	2015-11-04 14:00:00	2015-11-04 15:00:00	\N	\N	9	0	\N	912
31888	DELEGATION	AUCUNE	\N	\N	211	Droits des femmes 	Droits des femmes 	2015-11-12 09:30:00	2015-11-12 10:15:00	2015-11-12 17:27:00	2015-11-12 17:27:13	3	0	\N	\N
31901	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-11-12 09:30:00	2015-11-12 12:30:00	2015-11-12 19:13:37	2015-11-13 09:48:29	41	0	\N	\N
32370	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	206	Plateau de Saclay	Déplacement plateau de Saclay	2015-11-26 09:30:00	2015-11-26 16:30:00	\N	\N	6	0	\N	\N
32377	DELEGATION	AUCUNE	\N	\N	206	OPECST - Epigénétique	OPECST - Epigénétique	2015-11-25 09:10:00	2015-11-25 17:45:00	2015-11-26 18:00:07	2015-11-27 16:50:32	6	0	\N	\N
32890	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2016	PLFSS 2016	2015-11-13 09:30:00	2015-11-13 13:05:00	\N	\N	33	0	\N	\N
32891	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2016	PLFSS 2016	2015-11-13 14:35:00	2015-11-13 18:05:00	\N	\N	39	0	\N	\N
33144	GIA	AUCUNE	\N	\N	\N	GIE Tibet	Groupe d'information Tibet	2015-11-04 17:00:00	2015-11-04 18:00:00	\N	\N	1	0	634	\N
35751	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2015-11-17 18:00:00	2015-11-17 19:25:00	2015-11-18 11:47:59	2015-11-18 16:42:09	51	0	\N	\N
36276	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	Audition M. CANETE	2015-11-17 18:00:00	2015-11-17 19:30:00	2015-11-18 16:03:05	2015-11-18 16:39:19	50	0	\N	\N
37357	BUREAU	AUCUNE	\N	\N	\N	Délégation  du Bureau 	Communication et chaîne Public Sénat	2015-11-19 16:00:00	2015-11-19 17:00:00	\N	\N	2	0	\N	\N
37629	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2015-11-20 09:30:00	2015-11-20 12:30:00	\N	\N	1	0	\N	\N
37633	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2015-11-20 14:00:00	2015-11-20 15:00:00	\N	\N	1	0	\N	\N
38484	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-11-24 15:00:00	2015-11-24 16:15:00	2015-11-26 10:43:36	2015-11-26 10:43:42	42	0	\N	\N
40565	QUESTURE	AUCUNE	\N	\N	\N	Questure	Réunion de Questure	2015-11-03 18:00:00	2015-11-03 19:30:00	\N	\N	3	0	\N	\N
40901	DELEGATION	AUCUNE	\N	\N	DSOM	Outre-mer 	Outre-mer 	2015-12-03 09:30:00	2015-12-03 11:00:00	2015-12-03 15:38:10	2015-12-03 17:22:33	15	0	\N	\N
40905	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2015-11-02 14:30:00	2015-11-02 17:30:00	\N	\N	1	0	\N	\N
40907	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2015-11-03 14:00:00	2015-11-03 14:30:00	\N	\N	1	0	\N	\N
40909	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2015-11-03 10:00:00	2015-11-03 10:45:00	\N	\N	1	0	\N	\N
40911	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2015-11-03 15:00:00	2015-11-03 17:00:00	\N	\N	1	0	\N	\N
40913	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2015-11-04 11:30:00	2015-11-04 12:15:00	\N	\N	1	0	\N	\N
40915	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2015-11-04 14:00:00	2015-11-04 14:45:00	\N	\N	1	0	\N	\N
23737	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2015-10-14 16:30:00	2015-10-14 18:00:00	2015-10-15 11:08:06	2015-10-15 14:26:03	21	0	\N	\N
23796	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2015-10-15 08:35:00	2015-10-15 10:40:00	2015-10-15 16:39:34	2015-10-15 16:47:15	20	0	\N	\N
23799	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Examen ppl agressions sexuelles 14h30	Examen ppl agressions sexuelles 14h30	2015-10-20 14:30:00	2015-10-20 16:44:00	\N	\N	92	0	\N	\N
23802	SEANCE_PLENIERE	QAG	\N	\N	\N	QAG 	QAG 	2015-10-20 16:45:00	2015-10-20 17:44:00	\N	\N	282	0	\N	\N
24530	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Examen PPL sportifs de haut niveau	Examen PPL sportifs de haut niveau	2015-10-21 14:30:00	2015-10-21 16:29:00	\N	\N	103	0	\N	\N
24531	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Examen PPL sociétés mères	Examen PPL sociétés mères	2015-10-21 16:30:00	2015-10-21 18:29:00	\N	\N	49	0	\N	\N
30170	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-11-04 09:00:00	2015-11-04 13:15:00	2015-11-04 14:49:13	2015-11-04 17:01:11	48	0	\N	\N
36236	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	Examen de rapports PJLF 2016	2015-11-18 09:45:00	2015-11-18 11:35:00	2015-11-18 16:03:24	2015-11-18 16:41:47	33	0	\N	\N
36359	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	PLF 2016	2015-11-18 09:35:00	2015-11-18 12:20:00	2018-05-18 14:20:13	2018-05-18 14:20:26	39	0	\N	\N
38982	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-11-25 09:00:00	2015-11-25 10:10:00	2015-11-26 10:49:08	2015-11-26 10:49:13	43	0	\N	\N
39045	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2015-11-25 09:00:00	2015-11-25 12:00:00	2015-11-25 12:34:28	2015-11-25 17:22:13	49	0	\N	\N
24532	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Examen PPR déplacés environnementaux	Examen PPR déplacés environnementaux	2015-10-21 18:30:00	2015-10-21 20:00:00	\N	\N	44	0	\N	\N
24546	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Examen PPL publicité jeunesse	Examen PPL publicité jeunesse	2015-10-21 21:00:00	2015-10-22 00:00:00	\N	\N	34	0	\N	\N
26311	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2015-10-22 08:35:00	2015-10-22 10:55:00	2015-10-22 18:07:40	2015-10-23 14:35:55	17	0	\N	\N
27201	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Renseignements comptes financiers	PJL Renseignements comptes financiers	2015-10-29 11:00:00	2015-10-29 11:30:00	\N	\N	66	0	\N	\N
27203	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Fin de vie	PPL Fin de vie	2015-10-29 12:30:00	2015-10-29 13:30:00	\N	\N	78	0	\N	\N
27204	SEANCE_PLENIERE	QAG	\N	\N	\N	QAG 	QAG 	2015-10-29 15:00:00	2015-10-29 16:00:00	\N	\N	219	0	\N	\N
27208	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2015-10-28 10:10:00	2015-10-28 12:05:00	2015-10-28 15:10:00	2015-10-28 17:20:47	36	0	\N	\N
27826	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-10-29 09:16:00	2015-10-29 10:16:00	2015-10-29 15:01:32	2015-10-29 15:37:50	23	0	\N	\N
28153	BUREAU	AUCUNE	\N	\N	\N	Aucune 	Aucune 	2015-10-29 09:00:00	2015-10-29 11:45:00	\N	\N	23	0	\N	\N
28702	DELEGATION	AUCUNE	\N	\N	211	Droits des femmes 	Droits des femmes 	2015-10-29 08:30:00	2015-10-29 12:30:00	2015-11-02 11:40:47	2015-11-02 14:04:24	10	0	\N	\N
30372	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Justice du XXIe siècle	PJL Justice du XXIe siècle	2015-11-04 15:20:00	2015-11-04 19:50:00	\N	\N	87	0	\N	\N
31452	DELEGATION	AUCUNE	\N	\N	DSOM	Outre-mer 	Outre-mer 	2015-11-26 09:00:00	2015-11-26 12:00:00	2015-11-26 15:25:17	2015-11-26 15:43:33	12	0	\N	\N
31455	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-11-10 09:30:00	2015-11-10 10:50:00	2015-11-10 12:23:02	2015-11-10 17:17:58	40	0	\N	\N
31621	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-11-10 13:30:00	2015-11-10 14:25:00	2015-11-10 17:03:32	2015-11-10 17:17:59	34	0	\N	\N
31683	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2016	PLFSS 2016	2015-11-12 10:30:00	2015-11-12 13:15:00	\N	\N	70	0	\N	\N
31687	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au Gouvernement	Questions d'actualité au Gouvernement	2015-11-12 15:00:00	2015-11-12 16:00:00	\N	\N	229	0	\N	\N
31690	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2016	PLFSS 2016	2015-11-12 16:15:00	2015-11-12 20:05:00	\N	\N	77	0	\N	\N
31697	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2016	PLFSS 2016	2015-11-12 21:40:00	2015-11-13 00:30:00	\N	\N	40	0	\N	\N
32306	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2015-11-12 10:00:00	2015-11-12 12:15:00	2015-11-12 17:36:38	2015-11-12 17:53:14	32	0	\N	\N
33368	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-11-17 09:00:00	2015-11-17 10:15:00	2015-11-19 15:57:59	2015-11-19 16:34:10	35	0	\N	\N
33407	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2015-11-04 14:30:00	2015-11-04 15:30:00	\N	\N	1	0	\N	\N
33409	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2015-11-05 09:30:00	2015-11-05 12:30:00	\N	\N	1	0	\N	\N
33413	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2015-11-12 10:00:00	2015-11-12 10:55:00	\N	\N	1	0	\N	\N
33464	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2015-11-12 10:55:00	2015-11-12 11:50:00	\N	\N	1	0	\N	\N
33466	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2015-11-12 11:50:00	2015-11-12 12:45:00	\N	\N	1	0	\N	\N
33468	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2015-11-05 09:00:00	2015-11-05 09:45:00	\N	\N	1	0	\N	\N
33470	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2015-11-05 09:45:00	2015-11-05 10:30:00	\N	\N	1	0	\N	\N
33472	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2015-11-05 10:30:00	2015-11-05 11:15:00	\N	\N	1	0	\N	\N
33474	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2015-11-05 12:00:00	2015-11-05 13:00:00	\N	\N	1	0	\N	\N
33488	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2015-11-05 11:15:00	2015-11-05 12:00:00	\N	\N	1	0	\N	\N
36454	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2015-11-18 09:10:00	2015-11-18 10:30:00	2015-11-18 17:39:54	2015-11-18 17:41:17	50	0	\N	\N
37373	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL État d'urgence	PJL État d'urgence	2015-11-20 15:00:00	2015-11-20 19:00:00	\N	\N	163	0	\N	\N
37375	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2016	PLF 2016	2015-11-20 21:00:00	2015-11-21 00:30:00	\N	\N	44	0	\N	\N
37582	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2015-11-17 14:00:00	2015-11-17 15:00:00	\N	\N	4	0	\N	\N
38371	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2015-11-24 08:00:00	2015-11-24 11:15:00	\N	\N	1	0	\N	\N
38374	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2015-11-24 13:30:00	2015-11-24 14:30:00	\N	\N	1	0	\N	\N
38897	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-11-24 19:25:00	2015-11-24 19:30:00	2015-11-26 10:48:29	2015-11-26 10:48:39	26	0	\N	\N
40541	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2015-11-25 14:30:00	2015-11-25 15:00:00	\N	\N	1	0	\N	\N
40543	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2015-11-25 17:30:00	2015-11-25 19:00:00	\N	\N	1	0	\N	\N
40917	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2015-11-04 15:30:00	2015-11-04 16:15:00	\N	\N	1	0	\N	\N
40919	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2015-11-04 13:30:00	2015-11-04 14:15:00	\N	\N	1	0	\N	\N
40921	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2015-11-04 15:00:00	2015-11-04 15:45:00	\N	\N	1	0	\N	\N
27536	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2015-10-28 09:00:00	2015-10-28 13:00:00	2015-10-28 15:44:48	2015-10-28 17:20:39	38	0	\N	\N
40923	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2015-11-04 14:00:00	2015-11-04 15:45:00	\N	\N	1	0	\N	\N
40925	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2015-11-04 14:00:00	2015-11-04 15:00:00	\N	\N	1	0	\N	\N
40927	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2015-11-04 17:30:00	2015-11-04 18:30:00	\N	\N	1	0	\N	\N
40929	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2015-11-04 17:00:00	2015-11-04 18:00:00	\N	\N	1	0	\N	\N
21374	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2015-10-07 16:20:00	2015-10-07 17:50:00	2015-10-08 18:39:50	2015-10-09 10:51:52	9	0	\N	\N
22564	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL ports maritimes	PPL ports maritimes	2015-10-14 16:00:00	2015-10-14 19:00:00	\N	\N	97	0	\N	\N
22565	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL prostitution	PPL prostitution	2015-10-14 20:30:00	2015-10-14 23:00:00	\N	\N	94	0	\N	\N
24684	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-10-20 14:30:00	2015-10-20 16:17:00	2015-10-21 17:54:03	2015-10-22 10:01:11	43	0	\N	\N
25181	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2015-10-20 17:45:00	2015-10-20 19:20:00	2015-10-21 12:12:06	2015-10-21 15:43:31	28	0	\N	\N
25623	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2015-10-21 09:38:00	2015-10-21 12:43:00	2015-10-21 17:25:42	2015-10-21 17:39:30	42	0	\N	\N
25876	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-10-21 14:32:00	2015-10-21 16:38:00	2015-10-22 15:57:16	2015-10-22 16:27:33	41	0	\N	\N
26024	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2015-10-21 17:05:00	2015-10-21 18:25:00	2015-10-21 19:01:30	2015-10-22 15:18:30	15	0	\N	\N
26502	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	pjl réutilisation des informations du secteur public 	réutilisation des informations du secteur public 	2015-10-26 16:00:00	2015-10-26 19:30:00	\N	\N	27	0	\N	\N
26503	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	pjl prévention des risques 	pjl prévention des risques 	2015-10-26 21:30:00	2015-10-26 23:50:00	\N	\N	17	0	\N	\N
27067	BUREAU	AUCUNE	\N	\N	\N	Délégation statut du sénateur	Aucune 	2015-10-21 11:30:00	2015-10-21 12:30:00	\N	\N	3	0	\N	\N
27266	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-10-28 10:26:00	2015-10-28 12:12:00	2015-10-29 14:58:13	2015-10-29 15:37:53	37	0	\N	\N
28666	DELEGATION	AUCUNE	\N	\N	206	OPECST - Diesel	Etat de l'art en matière de mesure des émissions de particules et de polluants par les véhicules. Regards croisés.	2015-11-13 09:00:00	2015-11-13 13:40:00	2015-11-16 12:29:32	2015-11-16 15:36:46	3	0	\N	\N
29094	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	RI Outre-mer	2015-11-03 13:45:00	2015-11-03 15:25:00	2015-11-04 09:26:05	2015-11-04 15:19:04	39	0	\N	\N
29801	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	Audition Macron	2015-11-03 17:50:00	2015-11-03 20:10:00	2018-05-18 14:17:13	2018-05-18 14:17:49	34	0	\N	\N
29841	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	Audition Wahl	2015-11-03 18:30:00	2015-11-03 20:00:00	2015-11-04 12:33:49	2015-11-04 15:19:07	24	0	\N	\N
30107	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2015-11-04 09:30:00	2015-11-04 12:30:00	2015-11-04 17:48:16	2015-11-05 10:23:29	41	0	\N	\N
30653	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Justice du XXIe siècle	PJL Justice du XXIe siècle	2015-11-04 21:30:00	2015-11-05 00:30:00	\N	\N	43	0	\N	\N
30808	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	Audition Le Foll	2015-11-04 17:20:00	2015-11-04 18:55:00	2018-05-18 14:18:16	2018-05-18 14:18:25	24	0	\N	\N
31277	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-11-09 19:30:00	2015-11-09 20:30:00	2015-11-09 20:49:47	2015-11-10 11:49:31	21	0	\N	\N
31371	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2016	PLFSS 2016	2015-11-10 14:30:00	2015-11-10 16:30:00	\N	\N	94	0	\N	\N
32634	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-11-12 09:30:00	2015-11-12 10:25:00	2015-11-12 17:41:03	2015-11-12 17:52:21	24	0	\N	\N
32694	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-11-12 16:05:00	2015-11-12 16:35:00	2015-11-12 19:24:37	2015-11-13 09:48:34	27	0	\N	\N
32743	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI 	Audition Rapporteur SOCI 	2015-11-03 09:00:00	2015-11-03 12:30:00	2015-11-12 17:31:01	\N	1	0	\N	\N
32745	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI 	Audition Rapporteur SOCI 	2015-11-03 18:00:00	2015-11-03 19:00:00	2015-11-12 17:32:10	\N	1	0	\N	\N
32747	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI 	Audition Rapporteur SOCI 	2015-11-03 11:00:00	2015-11-03 11:45:00	2015-11-12 17:33:27	\N	1	0	\N	\N
32749	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI 	Audition Rapporteur SOCI 	2015-11-03 14:00:00	2015-11-03 16:15:00	2015-11-12 17:34:33	\N	1	0	\N	\N
32751	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI 	Audition Rapporteur SOCI 	2015-11-04 14:30:00	2015-11-04 16:00:00	2015-11-12 17:35:56	\N	1	0	\N	\N
32753	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI 	Audition Rapporteur SOCI 	2015-11-04 14:45:00	2015-11-04 16:30:00	2015-11-12 17:37:02	\N	1	0	\N	\N
32755	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI 	Audition Rapporteur SOCI 	2015-11-10 17:00:00	2015-11-10 18:30:00	2015-11-12 17:38:27	\N	1	0	\N	\N
33026	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2015-11-02 14:30:00	2015-11-02 15:30:00	\N	\N	1	0	\N	\N
36104	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	Audition M. CANETE 	2015-11-17 18:00:00	2015-11-17 19:30:00	2015-11-18 15:52:55	2015-11-18 16:38:55	51	0	\N	\N
36595	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-11-18 14:30:00	2015-11-18 16:20:00	2015-11-18 16:41:31	2015-11-18 17:34:21	36	0	\N	\N
36665	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2015-11-09 09:00:00	2015-11-09 10:00:00	\N	\N	1	0	\N	\N
36668	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2015-11-18 14:30:00	2015-11-18 15:30:00	\N	\N	1	0	\N	\N
25247	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2015-10-21 09:30:00	2015-10-21 11:00:00	2015-10-21 12:11:45	2015-10-21 17:03:30	49	0	\N	\N
25484	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2015-10-21 09:00:00	2015-10-21 09:36:00	2015-10-21 17:25:58	2015-10-21 17:39:28	40	0	\N	\N
30106	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2015-11-04 09:30:00	2015-11-04 11:45:00	2015-11-05 11:55:46	2015-11-05 12:12:47	31	0	\N	\N
30731	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2015-11-04 09:10:00	2015-11-04 13:15:00	2015-11-05 10:03:41	2015-11-05 10:24:02	45	0	\N	\N
36901	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-11-19 09:15:00	2015-11-19 10:05:00	2015-11-19 15:32:38	2015-11-19 15:39:56	34	0	\N	\N
37376	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2016	PLF 2016	2015-11-21 09:30:00	2015-11-21 12:45:00	\N	\N	0	0	\N	\N
37377	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2016	PLF 2016	2015-11-21 14:15:00	2015-11-21 18:10:00	\N	\N	48	0	\N	\N
38241	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2015-11-23 14:00:00	2015-11-23 18:00:00	\N	\N	1	0	\N	\N
38385	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE  PLF 2016 - Economie	Audition Rapporteur CAE PLF 2016 - Economie	2015-11-04 15:15:00	2015-11-04 17:00:00	\N	\N	1	0	\N	\N
38437	ETUDES	AUCUNE	\N	\N	\N	GE Développement économique de la montagne	Groupe d'études Développement économique de la montagne	2015-11-04 14:30:00	2015-11-04 15:30:00	\N	\N	9	0	\N	918
38454	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD  PLF 2016 Politique des territoires	Audition Rapporteur CDD PLF 2016 Politique des territoires 	2015-11-05 14:45:00	2015-11-05 15:45:00	\N	\N	1	0	\N	\N
38456	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD  PLF 2016 - Politique des territoires	Audition Rapporteur CDD PLF 2016 - Politique des territoires 	2015-11-12 14:00:00	2015-11-12 15:00:00	\N	\N	1	0	\N	\N
38459	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE  PLF 2016 Economie	Audition Rapporteur CAE PLF 2016 Economie 	2015-11-10 14:30:00	2015-11-10 17:00:00	\N	\N	1	0	\N	\N
38463	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Rapporteur PLF 2016 - Economie	Audition Rapporteur PLF 2016 - Economie	2015-11-12 11:00:00	2015-11-12 12:00:00	\N	\N	1	0	\N	\N
38465	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	GT CDD  Mobilités et Transports	Groupe de travail Mobilités et Transports	2015-11-18 14:00:00	2015-11-18 19:00:00	\N	\N	5	0	\N	\N
38502	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	GT CDD Mobilités et Transports	Groupe de travail CDD Mobilités et Transports 	2015-11-24 17:30:00	2015-11-24 20:00:00	\N	\N	3	0	\N	\N
38541	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE 	Audition Rapporteur CAE 	2015-11-19 10:15:00	2015-11-19 11:30:00	\N	\N	1	0	\N	\N
38543	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE 	Audition Rapporteur CAE 	2015-11-25 14:30:00	2015-11-25 16:30:00	\N	\N	1	0	\N	\N
43185	GIA	AUCUNE	\N	\N	\N	GIA Asie du Sud-Est	Groupe interparlementaire Asie du Sud-Est	2015-11-25 08:30:00	2015-11-25 09:30:00	\N	\N	7	0	609	\N
43193	GIA	AUCUNE	\N	\N	\N	GIA Egypte	Groupe interparlementaire Egypte	2015-11-24 17:45:00	2015-11-24 22:30:00	\N	\N	6	0	617	\N
43201	GIA	AUCUNE	\N	\N	\N	GIA Egypte	Groupe interparlementaire Egypte	2015-11-26 09:00:00	2015-11-26 10:30:00	\N	\N	3	0	617	\N
43205	GIA	AUCUNE	\N	\N	\N	GIA Egypte	Groupe interparlementaire Egypte	2015-12-01 09:00:00	2015-12-01 14:00:00	\N	\N	3	0	617	\N
43212	GIA	AUCUNE	\N	\N	\N	GIA Egypte	Groupe interparlementaire Egypte	2015-11-30 20:00:00	2015-11-30 22:30:00	\N	\N	5	0	617	\N
43524	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2016 Articles de la seconde partie	PLF 2016 Articles de la seconde partie	2015-12-04 14:45:00	2015-12-04 19:45:00	\N	\N	44	0	\N	\N
43526	DELEGATION	AUDRAP	\N	\N	COLTER	Collectivités  territoriales 	Collectivités  territoriales 	2015-12-01 14:30:00	2015-12-01 15:30:00	\N	\N	3	0	\N	\N
43531	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	COLTER	bureau Collectivités  territoriales 	bureau Collectivités  territoriales 	2015-12-17 10:30:00	2015-12-17 12:00:00	\N	\N	4	0	\N	\N
43957	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2015-12-03 14:00:00	2015-12-03 15:00:00	\N	\N	2	0	\N	\N
43960	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2015-12-03 15:00:00	2015-12-03 16:00:00	\N	\N	3	0	\N	\N
43964	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2015-12-03 16:00:00	2015-12-03 17:00:00	\N	\N	3	0	\N	\N
43968	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2015-12-03 17:00:00	2015-12-03 18:00:00	\N	\N	2	0	\N	\N
43974	GIA	AUCUNE	\N	\N	\N	GIA Brésil	Groupe interparlementaire Brésil	2015-12-03 08:30:00	2015-12-03 09:45:00	\N	\N	6	0	576	\N
44122	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2016 - Articles de la 2nde partie non rattachés	PLF 2016 - Articles de la 2nde partie non rattachés	2015-12-07 10:00:00	2015-12-07 12:50:00	\N	\N	27	0	\N	\N
44123	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2016 - Articles de la 2nde partie non rattachés	PLF 2016 - Articles de la 2nde partie non rattachés	2015-12-07 14:30:00	2015-12-07 18:10:00	\N	\N	28	0	\N	\N
44210	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-12-07 17:35:00	2015-12-07 17:40:00	2015-12-10 10:23:01	2015-12-10 10:28:35	15	0	\N	\N
44248	DELEGATION	AUCUNE	\N	\N	206	Les robots et la loi	Audition publique Les robots et la loi	2015-12-10 09:05:00	2015-12-10 13:00:00	2015-12-10 16:13:05	2015-12-11 15:40:53	8	0	\N	\N
44256	GIA	AUCUNE	\N	\N	\N	GIA Russie	Groupe interparlementaire Russie	2015-12-04 11:00:00	2015-12-04 13:00:00	\N	\N	1	0	608	\N
44258	GIA	AUCUNE	\N	\N	\N	GIA Russie	Groupe interparlementaire Russie	2015-11-25 08:00:00	2015-11-25 09:00:00	\N	\N	11	0	608	\N
44283	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Entreprises	Relancer l'apprentissage : une urgence pour les entreprises et l'emploi	2015-12-08 14:00:00	2015-12-08 15:00:00	\N	\N	1	0	\N	\N
44317	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Délégation sénatoriale aux entreprises 	Délégation sénatoriale aux entreprises 	2015-12-10 09:00:00	2015-12-10 09:55:00	2015-12-10 12:25:32	2015-12-11 15:40:52	12	0	\N	\N
44368	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	ENTREPRISES	Entreprises	Réunion du Bureau	2015-12-15 18:30:00	2015-12-15 19:30:00	\N	\N	5	0	\N	\N
44560	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	ENTREPRISES	Délégation aux entreprises -Déplacement	Déplacement dans le département du Nord	2015-11-13 10:00:00	2015-11-13 17:00:00	\N	\N	11	0	\N	\N
44971	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	ENTREPRISES	Délégation sénatoriale aux entreprises Dépalcement	Déplacement dans le département du Bas-Rhin	2015-10-23 10:00:00	2015-10-23 16:00:00	\N	\N	7	0	\N	\N
45051	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE PLFR 2015	Audition Rapporteur CAE PLFR 2015	2015-12-03 14:30:00	2015-12-03 16:00:00	\N	\N	1	0	\N	\N
45601	DELEGATION	AUDRAP	\N	\N	211	Droits des femmes 	Droits des femmes 	2015-10-15 11:00:00	2015-10-15 12:50:00	\N	\N	5	0	\N	\N
45607	DELEGATION	AUDRAP	\N	\N	211	Droits des femmes 	Droits des femmes 	2015-10-29 11:00:00	2015-10-29 12:30:00	\N	\N	2	0	\N	\N
45610	DELEGATION	AUDRAP	\N	\N	211	Droits des femmes 	Droits des femmes 	2015-11-05 11:00:00	2015-11-05 11:45:00	\N	\N	8	0	\N	\N
45619	DELEGATION	AUDRAP	\N	\N	211	Droits des femmes 	Droits des femmes 	2015-11-05 11:45:00	2015-11-05 13:00:00	\N	\N	8	0	\N	\N
45628	DELEGATION	AUDRAP	\N	\N	211	Droits des femmes 	Droits des femmes 	2015-11-19 11:00:00	2015-11-19 12:00:00	\N	\N	3	0	\N	\N
45633	DELEGATION	AUDRAP	\N	\N	211	Droits des femmes 	Droits des femmes 	2015-11-19 12:00:00	2015-11-19 13:00:00	\N	\N	3	0	\N	\N
45637	DELEGATION	AUDRAP	\N	\N	211	Droits des femmes 	Droits des femmes 	2015-12-03 11:00:00	2015-12-03 13:00:00	\N	\N	5	0	\N	\N
46078	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2015-12-09 09:30:00	2015-12-09 12:10:00	2015-12-09 16:57:51	2015-12-09 17:01:28	44	0	\N	\N
47264	BUREAU	AUCUNE	\N	\N	\N	Bureau	Réunion du Bureau	2015-12-10 09:00:00	2015-12-10 12:15:00	\N	\N	19	0	\N	\N
47941	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Réunion du Conseil européen	Débat Réunion du Conseil européen	2015-12-15 18:05:00	2015-12-15 20:00:00	\N	\N	66	0	\N	\N
47942	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au Gouvernement	Questions d'actualité au Gouvernement	2015-12-15 16:45:00	2015-12-15 17:30:00	\N	\N	287	0	\N	\N
47943	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFR 2015 Nouvelle lecture	PLFR 2015 Nouvelle lecture	2015-12-16 16:00:00	2015-12-16 17:05:00	\N	\N	0	0	\N	\N
47944	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Allemagne	PJL Allemagne	2015-12-16 17:20:00	2015-12-16 18:10:00	\N	\N	30	0	\N	\N
47945	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Luxembourg	PJL Luxembourg	2015-12-16 18:10:00	2015-12-16 18:45:00	\N	\N	29	0	\N	\N
48554	GIA	AUCUNE	\N	\N	\N	GIA Caraïbes	GIA Caraïbes	2015-12-15 14:00:00	2015-12-15 15:00:00	\N	\N	4	0	642	\N
49567	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	ENTREPRISES	Entreprises	Echanges avec l'administration des douanes	2016-01-14 09:00:00	2016-01-14 10:30:00	\N	\N	15	0	\N	\N
49568	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	ENTREPRISES	Entreprises	Echanges avec la Fondation Entreprendre	2016-01-14 11:15:00	2016-01-14 12:45:00	\N	\N	12	0	\N	\N
49569	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Entreprises	Simplification : échanges avec Mme Clotilde Valter	2016-01-20 16:30:00	2016-01-20 18:15:00	\N	\N	6	0	\N	\N
49570	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion de la Délégation aux entreprises 	Réunion de la Délégation aux entreprises 	2016-02-11 13:00:00	2016-02-11 14:45:00	2016-02-11 17:12:00	2016-02-11 17:36:11	21	0	\N	\N
49872	DELEGATION	AUDRAP	\N	\N	206	Mine de lignite	Visite de la mine de lignite et de la centrale thermique de Garzweiler (Bedburg, Allemagne))	2016-01-07 20:30:00	2016-01-07 23:30:00	\N	\N	1	0	\N	\N
49874	DELEGATION	AUDRAP	\N	\N	206	Mine de lignite	Visite de la mine de lignite et de la centrale thermique de Garzweiler (Bedburg, Allemagne)	2016-01-08 09:00:00	2016-01-08 15:00:00	\N	\N	1	0	\N	\N
49876	DELEGATION	AUCUNE	\N	\N	206	Sciences humaines et technologiques	Audition publique sur "Les synergies entre les sciences humaines et les sciences technologiques"	2016-01-21 08:45:00	2016-01-21 13:25:00	2016-01-21 19:01:38	2016-01-22 09:11:40	4	0	\N	\N
43241	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2016  Mission apprentissage	PLF 2016  Mission apprentissage	2015-12-02 14:45:00	2015-12-02 20:20:00	\N	\N	59	0	\N	\N
43244	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2016  Mission enseignement scolaire	PLF 2016  Mission enseignement scolaire	2015-12-02 21:50:00	2015-12-03 00:35:00	\N	\N	53	0	\N	\N
43344	GIA	AUCUNE	\N	\N	\N	GIA Israël	Groupe interparlementaire Israël	2015-11-26 10:00:00	2015-11-26 11:00:00	\N	\N	1	0	595	\N
43984	ETUDES	AUCUNE	\N	\N	\N	GE Chasse et pêche	Groupe d'études Chasse et pêche	2015-12-02 08:30:00	2015-12-02 09:30:00	\N	\N	12	0	\N	907
43997	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD - Avis Transports maritimes	Audition Rapporteur CDD 	2015-11-05 08:30:00	2015-11-05 11:30:00	\N	\N	1	0	\N	\N
44039	GIA	AUCUNE	\N	\N	\N	GIE Taïwan	Groupe d'information Taïwan	2015-11-12 11:00:00	2015-11-12 12:00:00	\N	\N	1	0	623	\N
44041	GIA	AUCUNE	\N	\N	\N	GIE Taïwan	Groupe d'information Taïwan	2015-11-12 12:30:00	2015-11-12 14:00:00	\N	\N	2	0	623	\N
44061	GIA	AUCUNE	\N	\N	\N	GIA Italie	Groupe interparlementaire Italie	0015-11-16 13:10:39	0015-11-16 14:10:39	\N	\N	0	0	621	\N
44062	GIA	AUCUNE	\N	\N	\N	GIA Italie	Groupe interparlementaire Italie	0015-11-16 13:10:39	0015-11-16 14:10:39	\N	\N	0	0	621	\N
44064	GIA	AUCUNE	\N	\N	\N	GIA Italie	Groupe interparlementaire Italie	0015-11-17 13:10:39	0015-11-17 14:10:39	\N	\N	0	0	621	\N
44065	GIA	AUCUNE	\N	\N	\N	GIA Italie	Groupe interparlementaire Italie	2015-11-18 11:30:00	2015-11-18 12:30:00	\N	\N	1	0	621	\N
44077	GIA	AUCUNE	\N	\N	\N	GIA Asie Centrale	Groupe interparlementaire Asie Centrale	2015-11-04 11:00:00	2015-11-04 13:30:00	\N	\N	2	0	556	\N
44620	DELEGATION	AUCUNE	\N	\N	206	Laboratoire P4	Visite du laboratoire P4 de l'Inserm à Lyon	2015-12-17 10:00:00	2015-12-17 15:30:00	\N	\N	2	0	\N	\N
45682	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI 	Audition Rapporteur SOCI 	2015-12-10 16:45:00	2015-12-10 17:30:00	\N	\N	0	0	\N	\N
45694	GIA	AUCUNE	\N	\N	\N	GIA Pakistan	Groupe interparlementaire Pakistan	2015-12-16 08:00:00	2015-12-16 09:30:00	\N	\N	4	0	619	\N
45696	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI 	Audition Rapporteur SOCI 	2015-12-09 14:00:00	2015-12-09 19:30:00	\N	\N	1	0	\N	\N
45702	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI 	Audition Rapporteur SOCI 	2015-12-10 16:45:00	2015-12-10 17:30:00	\N	\N	1	0	\N	\N
45705	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI 	Audition Rapporteur SOCI 	2015-12-10 16:45:00	2015-12-10 17:30:00	\N	\N	1	0	\N	\N
46751	GIA	AUCUNE	\N	\N	\N	GIA Pays de la Corne de l'Afrique	Groupe interparlementaire Pays de la Corne de l'Afrique	2015-12-01 09:00:00	2015-12-01 10:00:00	\N	\N	1	0	588	\N
46779	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD RI Eau	Audition Rapporteur CDD  RI Eau	2015-12-08 17:30:00	2015-12-08 18:30:00	\N	\N	1	0	\N	\N
46785	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD RI Eau	Audition Rapporteur CDD RI Eau 	2015-12-09 17:00:00	2015-12-09 19:15:00	\N	\N	1	0	\N	\N
46814	DELEGATION	AUDRAP	\N	\N	PROS	Délégation sénatoriale à la prospective 	Délégation sénatoriale à la prospective 	2015-12-10 09:30:00	2015-12-10 10:45:00	\N	\N	2	0	\N	\N
47635	ETUDES	AUCUNE	\N	\N	\N	GE Communications électroniques et Poste	Groupe d'études Communications électroniques et Poste	2015-12-09 08:15:00	2015-12-09 09:30:00	\N	\N	8	0	\N	913
45744	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-12-09 10:30:00	2015-12-09 12:05:00	2015-12-09 12:53:41	2015-12-09 17:01:33	49	0	\N	\N
45882	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	PPL 217 et PLFR pour 2015	2015-12-09 09:30:00	2015-12-09 11:30:00	2015-12-09 14:19:12	2015-12-09 17:01:26	35	0	\N	\N
47646	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE  PLFR	Audition Rapporteur CAE PLFR	2015-12-08 16:00:00	2015-12-08 18:00:00	\N	\N	1	0	\N	\N
49205	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2015-12-16 12:40:00	2015-12-16 12:55:00	2015-12-16 16:35:41	2015-12-16 16:37:00	38	0	\N	\N
49557	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Crédit d'impôt recherche	Débat Crédit d'impôt recherche	2016-01-12 14:30:00	2016-01-12 16:10:00	\N	\N	89	0	\N	\N
49558	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Forêt	Débat Forêt	2016-01-12 16:25:00	2016-01-12 18:05:00	\N	\N	81	0	\N	\N
49559	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPLC Charges collectivités territoriales	PPLC Charges collectivités territoriales	2016-01-12 18:15:00	2016-01-12 20:35:00	\N	\N	63	0	\N	\N
49832	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2015-12-21 10:30:00	2015-12-21 11:45:00	\N	\N	2	0	\N	\N
49955	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR Urbanisme	PPR Urbanisme	2016-01-13 14:35:00	2016-01-13 16:15:00	\N	\N	94	0	\N	\N
49956	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Jour de mémoire	PPL Jour de mémoire	2016-01-13 16:15:00	2016-01-13 17:40:00	\N	\N	74	0	\N	\N
49957	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Chômage longue durée	PPL Chômage longue durée	2016-01-13 21:05:00	2016-01-14 00:25:00	\N	\N	69	0	\N	\N
49958	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Gaspillage alimentaire	PPL Gaspillage alimentaire	2016-01-14 00:25:00	2016-01-14 01:00:00	\N	\N	24	0	\N	\N
50701	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	CAE 	2016-01-13 11:30:00	2016-01-13 13:00:00	2016-01-13 14:41:49	2016-01-13 16:20:21	31	0	\N	\N
50847	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2016-01-13 09:05:00	2016-01-13 10:00:00	2016-01-13 16:25:31	2016-01-13 16:46:49	54	0	\N	\N
52255	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD - PJL Biodiversité	Audition Rapporteur CDD 	2016-01-13 15:00:00	2016-01-13 16:00:00	\N	\N	1	0	\N	\N
52257	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE PJL Chambres consultaires	Audition Rapporteur CAE 	2016-01-12 14:30:00	2016-01-12 18:30:00	\N	\N	1	0	\N	\N
52259	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	GT CDD - Aménagement aéroportuaire du territoire	Groupe de travail CDD 	2016-01-14 08:30:00	2016-01-14 12:30:00	\N	\N	1	0	\N	\N
54369	ETUDES	AUCUNE	\N	\N	\N	GE Energie	Groupe d'études Energie	2016-01-20 08:00:00	2016-01-20 09:05:00	\N	\N	18	0	\N	906
54477	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Entreprises	Relancer l'apprentissage : CCI France	2016-01-26 16:30:00	2016-01-26 17:40:00	\N	\N	5	0	\N	\N
54509	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-01-20 15:00:00	2016-01-20 15:30:00	\N	\N	1	0	\N	\N
54572	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2016-01-21 14:00:00	2016-01-21 14:10:00	2016-01-22 09:41:18	2016-01-22 09:43:20	14	0	\N	\N
54682	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-01-21 14:30:00	2016-01-21 16:00:00	\N	\N	1	0	\N	\N
54893	GIA	AUCUNE	\N	\N	\N	GIA Finlande	Groupe interparlementaire Finlande	2016-01-20 08:30:00	2016-01-20 09:30:00	\N	\N	6	0	640	\N
55997	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-01-26 10:30:00	2016-01-26 11:00:00	\N	\N	1	0	\N	\N
56002	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-01-26 15:30:00	2016-01-26 17:30:00	\N	\N	1	0	\N	\N
56055	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2016-01-26 16:00:00	2016-01-26 20:00:00	2016-01-27 09:39:03	2016-01-27 16:19:07	39	0	\N	\N
56229	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Rapport d'information Maisons d'assistants maternels	Audition Rapporteur SOCI 	2016-02-09 15:00:00	2016-02-09 19:00:00	\N	\N	3	0	\N	\N
56258	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	COLTER	Collectivités  territoriales 	Petit déjeuner travail rapporteurs 1er semestre 2016	2016-01-28 08:30:00	2016-01-28 09:30:00	\N	\N	9	0	\N	\N
56330	QUESTURE	AUCUNE	\N	\N	\N	Questure	Réunion de Questure	2016-01-26 16:30:00	2016-01-26 18:00:00	\N	\N	3	0	\N	\N
56334	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2016-01-27 09:00:00	2016-01-27 11:10:00	2016-01-27 15:28:47	2016-01-27 16:19:21	30	0	\N	\N
56688	MECSS	AUDRAP	\N	\N	MECSS	MECSS  - Avenir du FSV	Mission d'information sur l'avenir du FSV	2016-02-03 14:00:00	2016-02-03 15:00:00	\N	\N	2	0	\N	\N
56792	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Chambres de commerce et d'industrie	PJL Chambres de commerce et d'industrie	2016-01-28 11:00:00	2016-01-28 12:00:00	\N	\N	0	0	\N	\N
46235	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	COLTER	Collectivités  territoriales 	Collectivités  territoriales 	2015-11-24 13:00:00	2015-11-24 14:30:00	\N	\N	24	0	\N	\N
47333	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2015-12-08 16:35:00	2015-12-08 17:40:00	\N	\N	2	0	\N	\N
47794	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Vieillissement	CMP Vieillissement	2015-12-14 14:35:00	2015-12-14 15:55:00	\N	\N	21	0	\N	\N
47796	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Santé	PJL Santé	2015-12-14 15:55:00	2015-12-14 17:40:00	\N	\N	20	0	\N	\N
48678	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2015-12-15 12:00:00	2015-12-15 13:00:00	\N	\N	2	0	\N	\N
49123	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2015-12-10 09:30:00	2015-12-10 18:00:00	\N	\N	1	0	\N	\N
48636	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	Traité transatantique 	2015-12-16 10:05:00	2015-12-16 11:30:00	2018-05-18 14:21:12	2018-05-18 14:21:23	31	0	\N	\N
50526	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2016-01-13 10:00:00	2016-01-13 12:20:00	2016-01-13 15:07:19	2016-01-13 16:18:44	49	0	\N	\N
50787	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2016-01-13 11:30:00	2016-01-13 11:45:00	2016-01-13 15:20:28	2016-01-13 16:20:20	43	0	\N	\N
50929	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2016-01-13 10:10:00	2016-01-13 10:20:00	2016-01-13 16:24:38	2016-01-13 16:46:46	32	0	\N	\N
56375	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	CAE 	2016-01-27 10:30:00	2016-01-27 12:15:00	2016-01-27 14:52:54	2016-01-27 16:20:49	36	0	\N	\N
56415	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2016-01-27 09:05:00	2016-01-27 12:30:00	2016-01-27 13:28:23	2016-01-27 16:19:32	50	0	\N	\N
49125	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2015-11-12 09:00:00	2015-11-12 15:00:00	\N	\N	1	0	\N	\N
49127	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2015-11-17 14:15:00	2015-11-17 15:15:00	\N	\N	1	0	\N	\N
49130	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2015-11-24 08:00:00	2015-11-24 14:15:00	\N	\N	1	0	\N	\N
49132	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2015-11-25 16:00:00	2015-11-25 18:00:00	\N	\N	1	0	\N	\N
49134	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2015-11-26 08:30:00	2015-11-26 11:00:00	\N	\N	1	0	\N	\N
49136	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2015-12-01 09:00:00	2015-12-01 15:15:00	\N	\N	1	0	\N	\N
49142	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2015-12-01 08:30:00	2015-12-01 10:15:00	\N	\N	1	0	\N	\N
49144	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2015-12-10 10:00:00	2015-12-10 12:00:00	\N	\N	1	0	\N	\N
49150	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2015-12-15 08:00:00	2015-12-15 11:00:00	\N	\N	1	0	\N	\N
49393	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2015-12-16 16:30:00	2015-12-16 18:30:00	2015-12-16 18:59:43	2015-12-17 11:07:06	20	0	\N	\N
49416	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL UE - Colombie - Pérou	PJL UE - Colombie - Pérou	2015-12-17 10:30:00	2015-12-17 11:05:00	\N	\N	32	0	\N	\N
49417	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Conventions internationales - Procédure simplifiée	Conventions internationales - Procédure simplifiée	2015-12-17 11:05:00	2015-12-17 11:10:00	\N	\N	34	0	\N	\N
49418	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Informations secteur public	CMP Informations secteur public	2015-12-17 11:45:00	2015-12-17 12:35:00	\N	\N	21	0	\N	\N
49581	GIA	AUCUNE	\N	\N	\N	GIA Madagascar	Groupe interparlementaire Madagascar	2015-12-17 16:00:00	2015-12-17 17:00:00	\N	\N	3	0	622	\N
49585	GIA	AUCUNE	\N	\N	\N	GIA Cambodge et Laos	Groupe interparlementaire Cambodge et Laos	2015-12-04 08:00:00	2015-12-09 18:00:00	\N	\N	3	0	577	\N
49601	GIA	AUCUNE	\N	\N	\N	GIA Inde	Groupe interparlementaire Inde	2015-12-03 12:30:00	2015-12-03 14:30:00	\N	\N	3	0	618	\N
49605	MISSION	AUCUNE	\N	ISLAM	\N	MI organisation, place et financement de l'Islam en France 	MI organisation, place et financement de l'Islam en France 	2016-01-13 13:40:00	2016-01-13 14:30:00	2016-01-13 16:29:30	2016-01-13 16:48:24	17	0	\N	\N
49633	GIA	AUCUNE	\N	\N	\N	GIA Russie	Groupe interparlementaire Russie	2015-12-15 12:30:00	2015-12-15 14:00:00	\N	\N	8	0	608	\N
49642	GIA	AUCUNE	\N	\N	\N	GIA Pologne	Groupe interparlementaire Pologne	2015-12-16 08:00:00	2015-12-16 09:00:00	\N	\N	6	0	600	\N
49681	GIA	AUCUNE	\N	\N	\N	GIA Afrique centrale	Groupe interparlementaire Afrique centrale	2015-12-01 18:15:00	2015-12-01 19:15:00	\N	\N	3	0	572	\N
49701	GIA	AUCUNE	\N	\N	\N	GIA Caraïbes	Groupe interparlementaire Caraïbes	2015-12-09 08:30:00	2015-12-09 09:30:00	\N	\N	1	0	642	\N
49721	GIA	AUCUNE	\N	\N	\N	GIE Tibet	Himalaya - Troisième pôle : Audition Mme Dicki Chhoyang / Matthieu Ricard	2015-12-09 08:30:00	2015-12-09 09:30:00	\N	\N	9	0	634	\N
49731	GIA	AUCUNE	\N	\N	\N	GIA Slovénie	Groupe interparlementaire Slovénie	2015-12-15 13:00:00	2015-12-15 14:30:00	\N	\N	8	0	529	\N
49933	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-01-12 09:35:00	2016-01-12 10:00:00	2018-05-18 14:21:48	2018-05-18 14:21:52	17	0	\N	\N
50372	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-01-13 09:05:00	2016-01-13 10:00:00	2016-01-14 17:23:28	2016-01-14 17:34:37	54	0	\N	\N
50912	GIA	AUCUNE	\N	\N	\N	GIE Corée du Nord	Groupe d'information Corée du Nord	0015-12-07 10:05:39	0015-12-07 10:50:39	\N	\N	0	0	586	\N
50983	GIA	AUCUNE	\N	\N	\N	GIA Afrique de l'Ouest	Groupe interparlementaire Afrique de l'Ouest	0015-12-08 15:20:39	0015-12-08 16:20:39	\N	\N	0	0	573	\N
50985	GIA	AUCUNE	\N	\N	\N	GIA Afrique de l'Ouest	Groupe interparlementaire Afrique de l'Ouest	2015-12-09 14:30:00	2015-12-09 15:30:00	\N	\N	2	0	573	\N
50988	GIA	AUCUNE	\N	\N	\N	GIA Palestine	Groupe interparlementaire Palestine	2015-12-14 09:00:00	2015-12-14 18:00:00	\N	\N	3	0	632	\N
50994	GIA	AUCUNE	\N	\N	\N	GIA Corée du Sud	Groupe interparlementaire Corée du Sud	2015-12-15 20:00:00	2015-12-15 22:00:00	\N	\N	6	0	613	\N
51001	GIA	AUCUNE	\N	\N	\N	GIA Japon	Groupe interparlementaire Japon	0015-12-15 19:50:39	0015-12-15 20:50:39	\N	\N	0	0	596	\N
51006	GIA	AUCUNE	\N	\N	\N	GIA Japon	Groupe interparlementaire Japon	2015-12-16 19:00:00	2015-12-16 20:00:00	\N	\N	4	0	596	\N
51011	GIA	AUCUNE	\N	\N	\N	GIA Pays Baltes	Groupe interparlementaire Pays Baltes	2015-12-16 12:30:00	2015-12-16 14:00:00	\N	\N	2	0	616	\N
51017	GIA	AUCUNE	\N	\N	\N	GIA Tunisie	Groupe interparlementaire Tunisie	2015-12-16 08:00:00	2015-12-16 09:00:00	\N	\N	15	0	620	\N
51040	GIA	AUCUNE	\N	\N	\N	GIA Afghanistan	Groupe interparlementaire Afghanistan	2015-12-17 09:30:00	2015-12-17 10:30:00	\N	\N	2	0	648	\N
51043	GIA	AUCUNE	\N	\N	\N	GIA Israël	Groupe interparlementaire Israël	2015-12-17 11:30:00	2015-12-17 12:15:00	\N	\N	1	0	595	\N
51473	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Biodiversité	PJL Biodiversité	2016-01-19 14:30:00	2016-01-19 16:45:00	\N	\N	151	0	\N	\N
51474	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au Gouvernement	Questions d'actualité au Gouvernement	2016-01-19 16:45:00	2016-01-19 17:30:00	\N	\N	310	0	\N	\N
52177	DELEGATION	AUCUNE	\N	\N	211	Droits des femmes 	Droits des femmes 	2016-01-14 08:30:00	2016-01-14 10:00:00	2016-01-15 10:17:56	2016-01-15 10:46:20	10	0	\N	\N
52193	DELEGATION	AUCUNE	\N	\N	211	Droits des femmes 	Droits des femmes 	2016-01-14 10:00:00	2016-01-14 13:15:00	2016-01-14 17:40:38	2016-01-14 18:23:51	19	0	\N	\N
52221	DELEGATION	AUDRAP	\N	\N	211	Droits des femmes 	Droits des femmes 	2016-01-13 13:00:00	2016-01-13 15:00:00	\N	\N	5	0	\N	\N
52228	DELEGATION	AUDRAP	\N	\N	211	Droits des femmes 	Droits des femmes 	2016-01-11 11:30:00	2016-01-11 15:45:00	\N	\N	3	0	\N	\N
53761	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2016-01-20 09:50:00	2016-01-20 13:05:00	2018-05-18 14:23:33	2018-05-18 14:23:38	71	0	\N	\N
54794	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Entreprises	Relancer l'apprentissage	2016-01-27 17:00:00	2016-01-27 18:20:00	\N	\N	4	0	\N	\N
54797	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Entreprises	Relancer l'apprentissage	2016-01-27 18:20:00	2016-01-27 19:30:00	\N	\N	3	0	\N	\N
56225	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Déontologie fonctionnaires	PJL Déontologie fonctionnaires	2016-01-27 14:30:00	2016-01-27 19:30:00	\N	\N	128	0	\N	\N
53692	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2016-01-20 09:30:00	2016-01-20 09:50:00	2018-05-18 14:23:07	2018-05-18 14:23:11	50	0	\N	\N
54852	DELEGATION	AUCUNE	\N	\N	COLTER	Audition Bruno Delsol, DGCL	Collectivités  territoriales 	2016-02-11 09:00:00	2016-02-11 10:30:00	2016-02-11 18:40:17	2016-02-12 12:16:10	18	0	\N	\N
44241	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	421	\N	\N	Explications de vote PLF 2016	Explications de vote PLF 2016	2015-12-08 14:30:00	2015-12-08 16:40:00	\N	\N	289	0	\N	\N
44242	SEANCE_PLENIERE	SCRUSOL	421	\N	\N	Scrutin solennel PLF 2016	Scrutin solennel PLF 2016	2015-12-08 14:30:00	2015-12-08 16:40:00	\N	\N	284	0	\N	\N
44243	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Journal Officiel	CMP Journal Officiel	2015-12-08 16:50:00	2015-12-08 17:35:00	\N	\N	52	0	\N	\N
44244	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Restauration scolaire	PPL Restauration scolaire	2015-12-09 14:35:00	2015-12-09 16:45:00	\N	\N	93	0	\N	\N
44246	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Agriculture	PPL Agriculture	2015-12-09 17:00:00	2015-12-09 19:25:00	\N	\N	80	0	\N	\N
44247	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Agriculture	PPL Agriculture	2015-12-09 21:05:00	2015-12-10 00:00:00	\N	\N	61	0	\N	\N
44271	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE 	Audition Rapporteur CAE 	2015-11-04 14:45:00	2015-11-04 15:30:00	\N	\N	0	0	\N	\N
44330	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE 	Audition Rapporteur CAE 	2015-11-04 14:00:00	2015-11-04 17:00:00	\N	\N	1	0	\N	\N
47664	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-12-11 08:40:00	2015-12-11 09:25:00	2015-12-11 18:04:57	2015-12-11 18:06:16	18	0	\N	\N
47923	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2015-12-14 16:30:00	2015-12-14 18:00:00	\N	\N	1	0	\N	\N
47946	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2016 nouvelle lecture	PLF 2016 nouvelle lecture	2015-12-16 14:35:00	2015-12-16 16:00:00	\N	\N	60	0	\N	\N
49005	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE PJL Chambres consulaires 	Audition Rapporteur CAE  PJL Chambres consulaires	2015-12-15 11:45:00	2015-12-15 12:30:00	\N	\N	1	0	\N	\N
49065	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE  PJL Chambres consulaires	Audition Rapporteur CAE  PJL Chambres consulaires	2015-12-15 18:00:00	2015-12-15 19:00:00	\N	\N	1	0	\N	\N
49069	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE  PJL Chambres consulaires	Audition Rapporteur CAE  PJL Chambres consulaires	2015-12-16 15:15:00	2015-12-16 17:00:00	\N	\N	1	0	\N	\N
49487	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Viet Nam	PJL Viet Nam	2015-12-17 11:10:00	2015-12-17 11:45:00	\N	\N	32	0	\N	\N
49562	GIA	AUCUNE	\N	\N	\N	GIA Asie Centrale	Colloque au Sénat sur le Kirghizistan	2015-12-14 14:30:00	2015-12-14 17:30:00	\N	\N	2	0	556	\N
49783	ETUDES	AUCUNE	\N	\N	\N	Société numérique	Société numérique, nouveaux usages, nouveaux médias	2015-12-01 17:45:00	2015-12-01 19:00:00	\N	\N	6	0	\N	965
49855	DELEGATION	AUCUNE	\N	\N	COLTER	Présentation étude Klopfer	Présentation étude cabinet KLOPFER (baisse dotations de l¿État) - Programme de travail 1er semestre 2016	2016-01-14 09:00:00	2016-01-14 10:50:00	2016-01-14 12:03:13	2016-01-14 15:20:02	21	0	\N	\N
51234	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Sécurité numérique	Débat Sécurité numérique	2016-01-14 11:05:00	2016-01-14 12:30:00	\N	\N	43	0	\N	\N
51235	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au Gouvernement	Questions d'actualité au Gouvernement	2016-01-14 15:00:00	2016-01-14 16:10:00	\N	\N	251	0	\N	\N
51236	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Coût pollution	Débat Coût pollution	2016-01-14 16:30:00	2016-01-14 18:00:00	\N	\N	29	0	\N	\N
52207	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-01-12 09:35:00	2016-01-12 10:25:00	\N	\N	1	0	\N	\N
52215	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-01-12 14:30:00	2016-01-12 15:00:00	\N	\N	1	0	\N	\N
52219	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-01-14 16:00:00	2016-01-14 16:45:00	\N	\N	1	0	\N	\N
52272	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2016-01-14 17:15:00	2016-01-14 18:30:00	\N	\N	3	0	\N	\N
52285	COM_SPECIALE	PLENIERE	\N	COMSPEAPU	\N	Aucune 	Aucune 	2016-01-12 09:30:00	2016-01-12 10:30:00	\N	\N	7	0	\N	\N
52301	GIA	AUCUNE	\N	\N	\N	GIA Madagascar	Groupe interparlementaire Madagascar	2016-01-13 14:30:00	2016-01-13 15:30:00	\N	\N	1	0	622	\N
53773	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2016-01-20 09:00:00	2016-01-20 12:50:00	2016-01-20 17:11:25	2016-01-20 17:16:29	44	0	\N	\N
54160	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Biodiversité	PJL Biodiversité	2016-01-21 10:35:00	2016-01-21 11:30:00	\N	\N	58	0	\N	\N
54161	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Biodiversité	PJL Biodiversité	2016-01-21 14:30:00	2016-01-21 20:05:00	\N	\N	59	0	\N	\N
54162	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Biodiversité	PJL Biodiversité	2016-01-21 21:35:00	2016-01-22 00:05:00	\N	\N	27	0	\N	\N
54501	BUREAU	AUCUNE	\N	\N	\N	Délégation du Bureau	Délégation du Bureau statut du sénateur	2016-01-20 11:30:00	2016-01-20 12:30:00	\N	\N	3	0	\N	\N
54843	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE  PPL Logement social	Audition Rapporteur CAE 	2016-01-21 09:00:00	2016-01-21 10:40:00	\N	\N	1	0	\N	\N
54848	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-01-20 15:00:00	2016-01-20 15:45:00	\N	\N	1	0	\N	\N
54865	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	Bureau  de l'APF	Aucune Bureau de l'APF  Siem Reap	2016-01-26 10:30:00	2016-02-01 10:00:00	\N	\N	2	0	\N	\N
54872	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2016-01-26 09:30:00	2016-01-26 12:20:00	\N	\N	38	0	\N	\N
54873	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Protection des mineurs	PJL Protection des mineurs	2016-01-26 16:30:00	2016-01-26 19:50:00	\N	\N	73	0	\N	\N
54874	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Déontologie fonctionnaires	PJL Déontologie fonctionnaires	2016-01-26 21:35:00	2016-01-27 00:05:00	\N	\N	51	0	\N	\N
54944	GIA	AUCUNE	\N	\N	\N	GIA Asie du Sud-Est	Groupe interparlementaire Asie du Sud-Est	2016-01-26 08:45:00	2016-01-26 09:45:00	\N	\N	6	0	609	\N
54969	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	441	\N	\N	Explications de vote PJL Biodiversité et PPLO Nomination	Explications de vote PJL Biodiversité et PPLO Nomination	2016-01-26 14:30:00	2016-01-26 15:25:00	\N	\N	298	0	\N	\N
54971	SEANCE_PLENIERE	SCRUSOL	441	\N	\N	Scrutin PJL Biodiversité	Scrutin PJL Biodiversité	2016-01-26 15:25:00	2016-01-26 15:55:00	\N	\N	0	0	\N	\N
54972	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Proclamation résultats PJL Biodiversité	Proclamation résultats PJL Biodiversité	2016-01-26 15:45:00	2016-01-26 16:00:00	\N	\N	292	0	\N	\N
54976	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-01-26 09:05:00	2016-01-26 10:40:00	2016-01-26 12:08:29	2016-01-26 16:55:10	26	0	\N	\N
56119	GIA	AUCUNE	\N	\N	\N	GIA Pakistan	Groupe interparlementaire Pakistan	2016-01-26 08:30:00	2016-01-26 10:00:00	\N	\N	4	0	619	\N
56228	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Malades fin de vie	CMP Malades fin de vie	2016-01-27 21:30:00	2016-01-27 22:50:00	\N	\N	65	0	\N	\N
56235	MECSS	AUCUNE	\N	\N	MECSS	MECSS 	MECSS 	2016-01-27 10:35:00	2016-01-27 11:10:00	2016-01-27 14:29:59	2016-01-27 16:20:58	17	0	\N	\N
56261	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2016-01-27 10:15:00	2016-01-27 10:35:00	2016-01-27 16:19:35	2016-01-27 16:37:47	39	0	\N	\N
56473	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2016-01-27 08:30:00	2016-01-27 10:15:00	2018-05-18 14:24:20	2018-05-18 14:24:25	43	0	\N	\N
56573	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2016-01-27 09:35:00	2016-01-27 12:10:00	2018-05-18 14:25:14	2018-05-18 14:25:19	33	0	\N	\N
56636	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2016-01-27 11:10:00	2016-01-27 12:45:00	2018-05-18 14:25:56	2018-05-18 14:26:01	32	0	\N	\N
56793	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au Gouvernement	Questions d'actualité au Gouvernement	2016-01-28 15:00:00	2016-01-28 16:00:00	\N	\N	229	0	\N	\N
56794	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Sociétés cotées	PJL Sociétés cotées	2016-01-28 20:20:00	2016-01-28 21:00:00	\N	\N	0	0	\N	\N
119910	GIA	AUCUNE	\N	\N	\N	GIE Tibet	Groupe d'information Tibet	2016-09-13 13:00:00	2016-09-13 16:00:00	\N	\N	2	0	634	\N
43144	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2016 Mission finances publiques	PLF 2016 Mission finances publiques	2015-12-03 15:05:00	2015-12-03 20:05:00	\N	\N	63	0	\N	\N
43149	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2016 Mission outre-mer	PLF 2016 Mission outre-mer	2015-12-03 14:35:00	2015-12-03 21:30:00	\N	\N	43	0	\N	\N
43153	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2016 Mission anciens combattants	PLF 2016 Mission anciens combattants	2015-12-03 22:00:00	2015-12-04 00:45:00	\N	\N	33	0	\N	\N
43156	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2016 Mission action du Gouvernement	PLF 2016 Mission action du Gouvernement	2015-12-03 22:05:00	2015-12-04 00:45:00	\N	\N	22	0	\N	\N
43585	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2015-12-03 08:35:00	2015-12-03 10:45:00	2015-12-03 14:53:15	2015-12-03 14:56:46	14	0	\N	\N
45683	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI 	Audition Rapporteur SOCI 	2015-11-03 11:00:00	2015-11-03 16:15:00	\N	\N	1	0	\N	\N
45691	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI 	Audition Rapporteur SOCI 	2015-11-04 14:30:00	2015-11-04 16:00:00	\N	\N	1	0	\N	\N
45695	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI 	Audition Rapporteur SOCI 	2015-11-10 17:00:00	2015-11-10 18:30:00	\N	\N	0	0	\N	\N
45973	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI 	Audition Rapporteur SOCI 	2015-11-03 18:00:00	2015-11-03 19:45:00	\N	\N	1	0	\N	\N
45977	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI 	Audition Rapporteur SOCI 	2015-11-04 14:45:00	2015-11-04 16:30:00	\N	\N	1	0	\N	\N
45993	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI 	Audition Rapporteur SOCI 	2015-11-05 14:00:00	2015-11-05 18:00:00	\N	\N	1	0	\N	\N
46063	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI 	Audition Rapporteur SOCI 	2015-11-09 11:30:00	2015-11-09 12:30:00	\N	\N	1	0	\N	\N
46071	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI 	Audition Rapporteur SOCI 	2015-11-12 16:15:00	2015-11-12 17:15:00	\N	\N	1	0	\N	\N
46138	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI 	Audition Rapporteur SOCI 	2015-11-10 09:00:00	2015-11-10 11:00:00	\N	\N	1	0	\N	\N
46190	QUESTURE	AUCUNE	\N	\N	\N	Questure	Réunion de Questure	2015-12-08 15:30:00	2015-12-08 17:30:00	\N	\N	3	0	\N	\N
46681	GIA	AUCUNE	\N	\N	\N	GIA Sri Lanka	Groupe interparlementaire Sri Lanka	2015-12-02 08:00:00	2015-12-02 09:00:00	\N	\N	4	0	550	\N
46693	GIA	AUCUNE	\N	\N	\N	GIA Sri Lanka	Groupe interparlementaire Sri Lanka	2015-11-09 15:00:00	2015-11-09 16:00:00	\N	\N	1	0	550	\N
47303	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE PPRE Traité transatlantique	Audition Rapporteur CAE PPRE Traité transatlantique	2015-12-08 17:00:00	2015-12-08 18:00:00	\N	\N	1	0	\N	\N
47305	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE PPRE Traité transatlantique	Audition Rapporteur CAE PPRE Traité transatlantique	2015-12-10 14:00:00	2015-12-10 15:00:00	\N	\N	1	0	\N	\N
47308	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE PLFR 2015	Audition Rapporteur CAE PLFR 2015	2015-12-01 14:30:00	2015-12-01 15:30:00	\N	\N	1	0	\N	\N
47310	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE PLFR 2015	Audition Rapporteur CAE PLFR 2015	2015-12-03 14:30:00	2015-12-03 16:00:00	\N	\N	1	0	\N	\N
47313	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD PPL Gaspillage	Audition Rapporteur CDD PPL Gaspillage	2015-12-07 17:30:00	2015-12-07 18:30:00	\N	\N	1	0	\N	\N
47315	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD PPL Gaspillage	Audition Rapporteur CDD PPL Gaspillage	2015-12-08 08:30:00	2015-12-08 11:00:00	\N	\N	1	0	\N	\N
56523	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2016-01-27 10:15:00	2016-01-27 11:10:00	2018-05-18 14:25:33	2018-05-18 14:25:41	42	0	\N	\N
56740	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-01-27 09:30:00	2016-01-27 13:35:00	2018-05-18 14:24:41	2018-05-18 14:24:47	47	0	\N	\N
47318	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD PPL Gaspillage	Audition Rapporteur CDD PPL Gaspillage	2015-12-09 15:30:00	2015-12-09 16:30:00	\N	\N	1	0	\N	\N
48287	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition Ministre défense	Audition du Ministre de la défense 	2015-12-15 15:05:00	2015-12-15 16:35:00	2015-12-16 14:52:02	2015-12-16 15:09:51	36	0	\N	\N
48431	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2015-12-15 17:50:00	2015-12-15 18:00:00	2015-12-16 15:05:48	2015-12-16 15:09:59	24	0	\N	\N
48458	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2015-12-15 18:00:00	2015-12-15 18:55:00	2015-12-16 15:06:17	2015-12-16 15:10:03	18	0	\N	\N
49565	GIA	AUCUNE	\N	\N	\N	GIA Asie Centrale	20è anniversaire Déclaration de neutralité du Turkménistan	2015-12-11 12:00:00	2015-12-14 00:00:00	\N	\N	1	0	556	\N
50476	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2016-01-13 10:05:00	2016-01-13 12:00:00	2018-05-18 14:22:10	2018-05-18 14:22:14	35	0	\N	\N
50584	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-01-12 14:30:00	2016-01-12 16:15:00	\N	\N	1	0	\N	\N
50586	GIA	AUCUNE	\N	\N	\N	GIA Viêt Nam	Audience du PM à la Présidence	2015-12-01 10:00:00	2015-12-01 11:00:00	\N	\N	1	0	626	\N
50588	GIA	AUCUNE	\N	\N	\N	GIE Corée du Nord	Entretien avec le MAE 	0015-12-06 10:55:39	0015-12-06 11:40:39	\N	\N	0	0	586	\N
50590	GIA	AUCUNE	\N	\N	\N	GIE Corée du Nord	Entretien avec le MAE	0015-12-07 10:05:39	0015-12-07 10:50:39	\N	\N	0	0	586	\N
53413	QUESTURE	AUCUNE	\N	\N	\N	Questure	Réunion de Questure	2016-01-19 14:30:00	2016-01-19 16:45:00	\N	\N	3	0	\N	\N
53950	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	CAE 	2016-01-20 09:00:00	2016-01-20 11:00:00	2016-01-20 16:12:54	2016-01-20 16:45:52	36	0	\N	\N
54334	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2016-01-20 18:00:00	2016-01-20 19:15:00	\N	\N	1	0	\N	\N
54652	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-01-21 09:00:00	2016-01-21 11:00:00	\N	\N	1	0	\N	\N
54668	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-01-20 16:30:00	2016-01-20 17:45:00	\N	\N	3	0	\N	\N
54875	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-01-19 13:30:00	2016-01-19 14:30:00	\N	\N	1	0	\N	\N
54877	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-01-19 18:00:00	2016-01-19 20:30:00	\N	\N	1	0	\N	\N
54879	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-01-20 14:00:00	2016-01-20 16:30:00	\N	\N	1	0	\N	\N
54881	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-01-21 09:45:00	2016-01-21 11:30:00	\N	\N	1	0	\N	\N
43834	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-12-03 20:05:00	2015-12-03 20:35:00	2015-12-04 09:47:37	2015-12-04 10:04:01	15	0	\N	\N
43916	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2016 Articles seconde partie	PLF 2016 Articles seconde partie	2015-12-04 09:45:00	2015-12-04 13:10:00	\N	\N	42	0	\N	\N
44098	GIA	AUCUNE	\N	\N	\N	GIA Israël	Groupe interparlementaire Israël	2015-12-02 08:00:00	2015-12-02 09:30:00	\N	\N	8	0	595	\N
45643	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI 	Audition Rapporteur SOCI 	2015-11-03 18:45:00	2015-11-03 19:45:00	\N	\N	1	0	\N	\N
45646	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI 	Audition Rapporteur SOCI 	2015-11-04 15:30:00	2015-11-04 16:30:00	\N	\N	1	0	\N	\N
45648	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI 	Audition Rapporteur SOCI 	2015-11-04 16:30:00	2015-11-04 17:30:00	\N	\N	1	0	\N	\N
45650	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI 	Audition Rapporteur SOCI 	2015-11-04 17:30:00	2015-11-04 18:30:00	\N	\N	1	0	\N	\N
45652	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI 	Audition Rapporteur SOCI 	2015-11-05 09:00:00	2015-11-05 10:00:00	\N	\N	0	0	\N	\N
45653	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI 	Audition Rapporteur SOCI 	2015-11-05 10:00:00	2015-11-05 12:00:00	\N	\N	1	0	\N	\N
45655	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI 	Audition Rapporteur SOCI 	2015-11-05 09:00:00	2015-11-05 10:00:00	\N	\N	1	0	\N	\N
46077	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2015-12-09 11:30:00	2015-12-09 12:20:00	2015-12-09 16:01:28	2015-12-09 17:01:35	37	0	\N	\N
46279	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	Aucune 	Aucune 	2015-12-05 15:00:00	2015-12-06 18:00:00	\N	\N	4	0	\N	\N
46405	QUESTURE	AUCUNE	\N	\N	\N	Rendez-vous	RV Président Délégation à l'Outre-mer	2015-12-09 14:30:00	2015-12-09 15:00:00	\N	\N	2	0	\N	\N
46416	QUESTURE	AUCUNE	\N	\N	\N	Comité de gestion	Comité gestion Restaurant	2015-12-09 15:00:00	2015-12-09 16:30:00	\N	\N	1	0	\N	\N
46422	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-12-09 15:05:00	2015-12-09 16:55:00	2015-12-10 10:24:59	2015-12-10 10:28:33	24	0	\N	\N
46468	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2015-11-10 09:30:00	2015-11-10 18:00:00	\N	\N	0	0	\N	\N
46469	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2015-11-26 08:30:00	2015-11-26 12:00:00	\N	\N	0	0	\N	\N
46473	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2015-11-10 09:30:00	2015-11-10 18:00:00	\N	\N	0	0	\N	\N
46476	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2015-11-17 14:15:00	2015-11-17 15:15:00	\N	\N	0	0	\N	\N
46477	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2015-11-24 08:00:00	2015-11-24 14:15:00	\N	\N	0	0	\N	\N
46478	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2015-11-25 16:00:00	2015-11-25 18:00:00	\N	\N	0	0	\N	\N
46502	DELEGATION	AUDRAP	\N	\N	211	Droits des femmes 	Droits des femmes 	2015-12-09 14:00:00	2015-12-09 15:00:00	\N	\N	6	0	\N	\N
53475	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-01-20 11:35:00	2016-01-20 13:05:00	2016-01-22 18:05:29	2016-01-22 18:05:33	34	0	\N	\N
54002	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	CAE 	2016-01-20 11:00:00	2016-01-20 12:25:00	2016-01-20 15:49:27	2016-01-20 16:45:43	36	0	\N	\N
54114	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2016-01-20 09:05:00	2016-01-20 12:45:00	2016-01-21 10:04:15	2016-01-21 11:48:20	35	0	\N	\N
45711	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-12-09 09:35:00	2015-12-09 12:00:00	2015-12-10 10:30:47	2015-12-10 10:34:19	42	0	\N	\N
45819	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2015-12-09 09:20:00	2015-12-09 09:30:00	2015-12-09 16:58:12	2015-12-09 17:01:19	44	0	\N	\N
45976	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2015-12-09 10:05:00	2015-12-09 11:30:00	2015-12-09 16:01:06	2015-12-09 17:01:31	48	0	\N	\N
46509	DELEGATION	AUDRAP	\N	\N	211	Droits des femmes 	Droits des femmes 	2015-12-09 15:30:00	2015-12-09 18:00:00	\N	\N	3	0	\N	\N
47599	GIA	AUCUNE	\N	\N	\N	GIA Nouvelle-Zélande	Groupe interparlementaire Nouvelle-Zélande	2015-12-09 08:30:00	2015-12-09 09:30:00	\N	\N	7	0	663	\N
47612	GIA	AUCUNE	\N	\N	\N	GIA Vanuatu	Groupe interparlementaire Vanuatu	2015-12-09 12:30:00	2015-12-09 14:30:00	\N	\N	7	0	651	\N
47947	QUESTURE	AUCUNE	\N	\N	\N	Questure	Réunion de Questure	2015-12-10 11:50:00	2015-12-10 12:20:00	\N	\N	3	0	\N	\N
47951	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2015-12-15 08:00:00	2015-12-15 11:00:00	\N	\N	1	0	\N	\N
47961	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2015-12-15 14:35:00	2015-12-15 15:30:00	2015-12-15 16:07:00	2015-12-15 16:41:20	22	0	\N	\N
47962	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2015-12-10 16:15:00	2015-12-10 17:15:00	\N	\N	2	0	\N	\N
47965	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2015-12-10 17:15:00	2015-12-10 18:15:00	\N	\N	1	0	\N	\N
48351	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2015-12-15 15:00:00	2015-12-15 17:00:00	\N	\N	1	0	\N	\N
49661	GIA	AUCUNE	\N	\N	\N	GIA Arménie	Groupe interparlementaire Arménie	2015-12-09 08:30:00	2015-12-09 09:30:00	\N	\N	8	0	641	\N
49670	GIA	AUCUNE	\N	\N	\N	GIA Caucase	Groupe interparlementaire Caucase	2015-12-09 08:30:00	2015-12-09 09:30:00	\N	\N	4	0	534	\N
49741	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2015-12-01 16:30:00	2015-12-01 18:15:00	\N	\N	4	0	\N	\N
49746	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2015-12-02 14:30:00	2015-12-02 18:30:00	\N	\N	2	0	\N	\N
49749	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2015-12-03 14:00:00	2015-12-03 18:30:00	\N	\N	7	0	\N	\N
49757	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2015-12-08 14:30:00	2015-12-08 19:00:00	\N	\N	4	0	\N	\N
49762	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2015-12-09 14:45:00	2015-12-09 18:30:00	\N	\N	2	0	\N	\N
49765	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2015-12-10 09:30:00	2015-12-10 16:40:00	\N	\N	2	0	\N	\N
49768	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2015-12-15 14:00:00	2015-12-15 18:30:00	\N	\N	4	0	\N	\N
49773	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2015-12-16 14:00:00	2015-12-16 19:30:00	\N	\N	6	0	\N	\N
49780	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2015-12-17 09:00:00	2015-12-17 18:00:00	\N	\N	2	0	\N	\N
49835	DELEGATION	AUCUNE	\N	\N	DSOM	Auditions sur le foncier dans les collectivités du Pacifique	Auditions sur la problématique du foncier dans les collectivités territoriales  du Pacifique	2016-01-21 09:00:00	2016-01-21 11:00:00	2016-01-22 15:05:09	2016-01-22 15:22:04	13	0	\N	\N
50446	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2016-01-12 18:00:00	2016-01-12 19:10:00	2016-01-13 10:46:54	2016-01-13 14:48:37	17	0	\N	\N
50468	QUESTURE	AUCUNE	\N	\N	\N	Questure	Réunion de Questure	2016-01-12 14:30:00	2016-01-12 16:30:00	\N	\N	3	0	\N	\N
50472	QUESTURE	AUCUNE	\N	\N	\N	RV Bureau AMCAS	RV Bureau AMCAS	2016-01-12 16:30:00	2016-01-12 17:00:00	\N	\N	3	0	\N	\N
50592	GIA	AUCUNE	\N	\N	\N	GIE Corée du Nord	Entretien avec le MAE	0015-12-06 10:55:39	0015-12-06 11:40:39	\N	\N	0	0	586	\N
50642	GIA	AUCUNE	\N	\N	\N	GIE Corée du Nord	Groupe d'information Corée du Nord	2015-12-08 09:15:00	2015-12-08 10:00:00	\N	\N	2	0	586	\N
51002	GIA	AUCUNE	\N	\N	\N	GIA Caraïbes	Groupe interparlementaire Caraïbes	2016-01-13 12:15:00	2016-01-13 13:40:00	\N	\N	1	0	642	\N
51228	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2016-01-12 16:15:00	2016-01-12 18:00:00	\N	\N	1	0	\N	\N
51231	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2016-01-13 14:00:00	2016-01-13 16:35:00	\N	\N	2	0	\N	\N
51530	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2016-01-14 08:35:00	2016-01-14 10:05:00	2016-01-14 12:00:34	2016-01-14 15:19:33	20	0	\N	\N
51561	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-01-12 15:00:00	2016-01-12 16:15:00	\N	\N	1	0	\N	\N
51692	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-01-14 12:15:00	2016-01-14 13:15:00	\N	\N	1	0	\N	\N
51891	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Entreprises	Relancer l'apprentissage : Conseil régional Alsace, Champagne-Ardenne, Lorraine	2016-01-27 11:00:00	2016-01-27 12:15:00	\N	\N	3	0	\N	\N
51893	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Entreprises	Relancer l'apprentissage : Syndicats de salariés	2016-01-28 09:00:00	2016-01-28 10:30:00	\N	\N	5	0	\N	\N
43367	GIA	AUCUNE	\N	\N	\N	GIA Syrie	Groupe interparlementaire Syrie	2015-11-09 19:30:00	2015-11-09 20:30:00	\N	\N	1	0	644	\N
43371	GIA	AUCUNE	\N	\N	\N	GIA Syrie	Groupe interparlementaire Syrie	2015-11-03 20:00:00	2015-11-03 22:00:00	\N	\N	1	0	644	\N
43373	GIA	AUCUNE	\N	\N	\N	GIA Syrie	Groupe interparlementaire Syrie	2015-11-24 10:00:00	2015-11-24 11:00:00	\N	\N	1	0	644	\N
43375	GIA	AUCUNE	\N	\N	\N	GIA Syrie	Groupe interparlementaire Syrie	2015-11-24 16:30:00	2015-11-24 17:45:00	\N	\N	1	0	644	\N
45571	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2015-12-08 08:30:00	2015-12-08 10:30:00	\N	\N	1	0	\N	\N
45690	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI 	Audition Rapporteur SOCI 	2015-12-08 09:30:00	2015-12-08 10:30:00	\N	\N	1	0	\N	\N
45700	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI 	Audition Rapporteur SOCI 	2015-11-05 11:15:00	2015-11-05 12:15:00	\N	\N	1	0	\N	\N
45707	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFR 2015	PLFR 2015	2015-12-10 10:35:00	2015-12-10 12:35:00	\N	\N	73	0	\N	\N
45708	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au Gouvernement	Questions d'actualité au Gouvernement	2015-12-10 15:00:00	2015-12-10 16:00:00	\N	\N	211	0	\N	\N
45709	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Transport ferroviaire	PPL Transport ferroviaire	2015-12-10 16:20:00	2015-12-10 19:05:00	\N	\N	34	0	\N	\N
45802	GIA	AUCUNE	\N	\N	\N	GIA Chine	Groupe interparlementaire Chine	2015-12-09 11:00:00	2015-12-09 12:00:00	\N	\N	5	0	584	\N
45922	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2015-12-09 09:20:00	2015-12-09 12:25:00	2015-12-09 14:57:48	2015-12-09 17:01:24	36	0	\N	\N
46210	GIA	AUCUNE	\N	\N	\N	GIA Québec	Groupe interparlementaire Québec	2015-12-08 20:00:00	2015-12-08 23:45:00	\N	\N	5	0	602	\N
46221	GIA	AUCUNE	\N	\N	\N	GIA Québec	Groupe interparlementaire Québec	2015-12-09 20:00:00	2015-12-09 22:45:00	\N	\N	1	0	602	\N
48739	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-12-16 09:35:00	2015-12-16 11:30:00	2015-12-16 15:29:26	2015-12-16 15:34:26	41	0	\N	\N
50589	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-01-13 10:35:00	2016-01-13 12:40:00	2016-01-13 15:43:02	2016-01-13 16:18:47	42	0	\N	\N
46661	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL État d'urgence	PJL État d'urgence	2015-12-10 10:30:00	2015-12-10 10:35:00	\N	\N	87	0	\N	\N
46822	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2015-12-10 09:35:00	2015-12-10 11:15:00	2015-12-10 14:34:31	2015-12-10 17:27:38	25	0	\N	\N
46897	GIA	AUCUNE	\N	\N	\N	GIA Afrique de l'Ouest	Groupe interparlementaire Afrique de l'Ouest	2015-12-04 15:00:00	2015-12-04 16:00:00	\N	\N	2	0	573	\N
46901	GIA	AUCUNE	\N	\N	\N	GIA Afrique de l'Ouest	Groupe interparlementaire Afrique de l'Ouest	2015-12-04 16:00:00	2015-12-04 17:00:00	\N	\N	2	0	573	\N
46904	GIA	AUCUNE	\N	\N	\N	GIA Afrique de l'Ouest	Groupe interparlementaire Afrique de l'Ouest	2015-12-04 17:00:00	2015-12-04 18:30:00	\N	\N	1	0	573	\N
47059	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2015-12-10 08:35:00	2015-12-10 09:15:00	2015-12-10 15:53:58	2015-12-10 17:31:39	10	0	\N	\N
47336	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2015-12-10 09:35:00	2015-12-10 11:15:00	2015-12-10 16:23:58	2015-12-10 17:31:41	25	0	\N	\N
47661	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFR 2015	PLFR 2015	2015-12-11 09:30:00	2015-12-11 12:30:00	\N	\N	42	0	\N	\N
47662	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFR 2015	PLFR 2015	2015-12-11 14:30:00	2015-12-11 19:40:00	\N	\N	45	0	\N	\N
47663	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFR 2015	PLFR 2015	2015-12-11 21:15:00	2015-12-12 03:05:00	\N	\N	29	0	\N	\N
47727	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2015-12-11 12:30:00	2015-12-11 12:55:00	2015-12-11 18:05:47	2015-12-11 18:06:17	18	0	\N	\N
48545	GIA	AUCUNE	\N	\N	\N	GIA Viêt Nam	Groupe interparlementaire Viêt Nam	2015-12-16 08:30:00	2015-12-16 09:30:00	\N	\N	6	0	626	\N
48552	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD RI Eau	Audition Rapporteur CDD RI Eau	2015-12-16 17:00:00	2015-12-16 18:30:00	\N	\N	1	0	\N	\N
48839	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2015-12-16 09:05:00	2015-12-16 12:15:00	2015-12-16 14:52:33	2015-12-16 15:10:15	39	0	\N	\N
49004	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Table ronde Patrimoine	Table ronde sur le patrimoine	2015-12-16 10:20:00	2015-12-16 12:15:00	2015-12-16 15:25:28	2015-12-16 15:34:24	30	0	\N	\N
49138	QUESTURE	AUCUNE	\N	\N	\N	Questure	Réunion de Questure	2015-12-15 14:30:00	2015-12-15 16:30:00	\N	\N	3	0	\N	\N
49145	QUESTURE	AUCUNE	\N	\N	\N	Commission de concertation	Commission de concertation	2015-12-16 10:00:00	2015-12-16 12:50:00	\N	\N	3	0	\N	\N
49155	QUESTURE	AUCUNE	\N	\N	\N	CA AGAS	Conseil d'administration AGAS	2015-12-16 12:00:00	2015-12-16 12:40:00	\N	\N	1	0	\N	\N
49322	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2015-12-16 15:00:00	2015-12-16 15:45:00	\N	\N	1	0	\N	\N
49351	QUESTURE	AUCUNE	\N	\N	\N	RV Bureau AMCAS	RV avec le Bureau de l'AMCAS	2015-12-15 18:00:00	2015-12-15 18:50:00	\N	\N	3	0	\N	\N
49959	DELEGATION	AUCUNE	\N	\N	DSOM	Normes dans les outre-mer 	Auditions sur les normes dans les outre-mer	2016-01-28 09:00:00	2016-01-28 10:00:00	2016-01-28 14:11:12	2016-01-28 15:15:39	17	0	\N	\N
50643	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2016-01-13 09:35:00	2016-01-13 12:30:00	2016-01-13 15:13:30	2016-01-13 16:18:15	44	0	\N	\N
51563	DELEGATION	AUDRAP	\N	\N	PROS	Délégation sénatoriale à la prospective 	Délégation sénatoriale à la prospective 	2016-01-14 09:30:00	2016-01-14 11:20:00	\N	\N	4	0	\N	\N
52278	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Biodiversité	PJL Biodiversité	2016-01-19 17:30:00	2016-01-19 19:00:00	\N	\N	96	0	\N	\N
52279	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Biodiversité	PJL Biodiversité	2016-01-19 21:05:00	2016-01-20 01:10:00	\N	\N	87	0	\N	\N
52314	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Biodiversité	PJL Biodiversité	2016-01-20 14:35:00	2016-01-20 18:40:00	\N	\N	139	0	\N	\N
52315	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Biodiversité	PJL Biodiversité	2016-01-20 21:05:00	2016-01-21 01:05:00	\N	\N	67	0	\N	\N
52423	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2016-01-19 13:30:00	2016-01-19 14:25:00	2016-01-20 18:00:02	2016-01-21 09:55:59	29	0	\N	\N
52493	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Entreprises	Relancer l'apprentissage - Conseil régional d¨'Île de France	2016-01-26 18:40:00	2016-01-26 19:45:00	\N	\N	5	0	\N	\N
52494	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Entreprises	Relancer l'apprentissage : FNADIR 	2016-01-27 12:15:00	2016-01-27 13:20:00	\N	\N	3	0	\N	\N
52497	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Entreprises	Relancer l'apprentissage : Ministère de l'Education nationale	2016-01-27 14:30:00	2016-01-27 15:35:00	\N	\N	5	0	\N	\N
52499	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Entreprises	Relancer l'apprentissage : Organisations patronales	2016-01-28 10:30:00	2016-01-28 12:00:00	\N	\N	6	0	\N	\N
52505	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Entreprises	Relancer l'apprentissage : Ministère du Travail	2016-01-26 17:40:00	2016-01-26 18:40:00	\N	\N	5	0	\N	\N
53525	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2016-01-20 11:10:00	2016-01-20 12:40:00	2016-01-20 14:42:35	2016-01-20 16:45:41	36	0	\N	\N
53642	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-01-20 09:05:00	2016-01-20 11:35:00	2018-05-18 14:22:29	2018-05-18 14:22:34	44	0	\N	\N
53750	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-01-19 16:30:00	2016-01-19 17:00:00	\N	\N	1	0	\N	\N
53762	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-01-19 17:50:00	2016-01-19 18:30:00	\N	\N	1	0	\N	\N
54332	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Biodiversité	PJL Biodiversité	2016-01-22 09:35:00	2016-01-22 13:00:00	\N	\N	33	0	\N	\N
54333	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Biodiversité	PJL Biodiversité	2016-01-22 14:30:00	2016-01-22 20:10:00	\N	\N	33	0	\N	\N
54414	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2016-01-21 08:30:00	2016-01-21 10:20:00	2016-01-21 11:04:06	2016-01-21 15:00:14	13	0	\N	\N
54884	GIA	AUCUNE	\N	\N	\N	GIA Inde	Groupe interparlementaire Inde	2016-01-13 12:30:00	2016-01-13 14:00:00	\N	\N	8	0	618	\N
55005	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2016-01-26 09:30:00	2016-01-26 10:35:00	\N	\N	6	0	\N	\N
55060	GIA	AUCUNE	\N	\N	\N	GIA Mongolie	Groupe interparlementaire Mongolie	2016-01-25 18:00:00	2016-01-25 19:00:00	\N	\N	1	0	612	\N
55325	GIA	AUCUNE	\N	\N	\N	GIA Europe du Nord	Groupe interparlementaire Europe du Nord	2016-01-13 08:30:00	2016-01-13 09:30:00	\N	\N	1	0	625	\N
56172	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-01-27 08:30:00	2016-01-27 09:30:00	2018-05-18 14:23:56	2018-05-18 14:24:03	40	0	\N	\N
56213	GIA	AUCUNE	\N	\N	\N	GIA Slovaquie	Groupe interparlementaire Slovaquie	2016-01-12 13:00:00	2016-01-12 14:30:00	\N	\N	8	0	532	\N
56222	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	rapport d'info Maisons d'assistants maternels	Auditions des co-rapporteurs sur les maisons d'assistants maternels	2016-02-10 14:00:00	2016-02-10 19:00:00	\N	\N	2	0	\N	\N
107732	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Travail	PJL Travail	2016-06-22 14:30:00	2016-06-22 18:25:00	\N	\N	140	0	\N	\N
56796	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Chambres de commerce et d'industrie	PJL Chambres de commerce et d'industrie	2016-01-28 18:00:00	2016-01-28 20:20:00	\N	\N	25	0	\N	\N
56960	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Déontologie fonctionnaires	PJL Déontologie fonctionnaires 	2016-01-27 22:55:00	2016-01-28 01:30:00	\N	\N	31	0	\N	\N
57007	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Terrorisme transports	PPL Terrorisme transports	2016-01-28 10:35:00	2016-01-28 13:05:00	\N	\N	0	0	\N	\N
57008	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Terrorisme transports	PPL Terrorisme transports	2016-01-28 16:15:00	2016-01-28 18:00:00	\N	\N	37	0	\N	\N
58246	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Gaspillage alimentaire	PPL Gaspillage	2016-02-03 14:30:00	2016-02-03 15:55:00	\N	\N	86	0	\N	\N
58247	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Droit individuel à la formation	PPL Droit individuel à la formation	2016-02-03 16:05:00	2016-02-03 18:25:00	\N	\N	86	0	\N	\N
58248	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Laïcité	PPL Laïcité	2016-02-03 18:30:00	2016-02-03 20:50:00	\N	\N	74	0	\N	\N
58254	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Missions temporaires	PPL Missions temporaires	2016-02-03 22:20:00	2016-02-03 23:50:00	\N	\N	28	0	\N	\N
59250	GIA	AUCUNE	\N	\N	\N	GIA Québec	Groupe interparlementaire Québec	2016-02-02 19:45:00	2016-02-02 22:30:00	\N	\N	15	0	602	\N
59266	GIA	AUCUNE	\N	\N	\N	GIA Québec	Groupe interparlementaire Québec	2016-02-02 18:30:00	2016-02-02 19:45:00	\N	\N	24	0	602	\N
59350	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCIAffaires sociales 	SOCIAffaires sociales 	2016-02-03 09:30:00	2016-02-03 11:00:00	2016-02-04 16:59:31	2016-02-04 17:54:21	48	0	\N	\N
60233	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD RI Eau	Audition Rapporteur CDD RI Eau	2016-02-03 17:00:00	2016-02-03 19:30:00	\N	\N	1	0	\N	\N
60235	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	GT LOISLois 	Groupe de travail LOISLois 	2016-01-12 14:30:00	2016-01-12 15:30:00	\N	\N	3	0	\N	\N
60644	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Entreprises	Relancer l'apprentissage	2016-02-10 11:00:00	2016-02-10 12:35:00	\N	\N	3	0	\N	\N
61051	COM_EURO	AUTRE_NON_PLENIERE	\N	AFEU	\N	Affaires européennes 	Affaires européennes 	2016-02-03 16:10:00	2016-02-03 17:35:00	\N	\N	10	0	\N	\N
61080	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOISLois 	LOISLois 	2016-02-09 09:35:00	2016-02-09 09:40:00	2018-05-18 14:31:09	2018-05-18 14:31:13	14	0	\N	\N
61789	QUESTURE	AUCUNE	\N	\N	\N	Questure	Réunion de Questure	2016-02-09 15:00:00	2016-02-09 17:30:00	\N	\N	3	0	\N	\N
61849	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2016-02-09 19:50:00	2016-02-09 20:50:00	2016-02-09 23:22:51	2016-02-10 16:18:53	29	0	\N	\N
61987	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2016-02-09 18:30:00	2016-02-09 19:20:00	2016-02-10 11:47:04	2016-02-10 16:18:52	28	0	\N	\N
62288	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2016-02-10 11:10:00	2016-02-10 12:00:00	2016-02-11 17:44:00	2016-02-11 17:51:47	45	0	\N	\N
62527	GIA	AUCUNE	\N	\N	\N	GIA Andorre	Groupe interparlementaire Andorre	2016-02-10 08:30:00	2016-02-10 09:30:00	\N	\N	5	0	963	\N
62533	GIA	AUCUNE	\N	\N	\N	GIA Viêt Nam	Groupe interparlementaire Viêt Nam	2016-02-10 13:00:00	2016-02-10 14:30:00	\N	\N	9	0	626	\N
62543	GIA	AUCUNE	\N	\N	\N	GIA Viêt Nam	Groupe interparlementaire Viêt Nam	2016-02-09 19:00:00	2016-02-09 22:00:00	\N	\N	4	0	626	\N
62554	MISSION	AUCUNE	\N	ISLAM	\N	MI organisation, place et financement de l'Islam en France 	MI organisation, place et financement de l'Islam en France 	2016-02-10 15:05:00	2016-02-10 17:50:00	2016-02-10 17:58:24	2016-02-11 11:37:36	15	0	\N	\N
62734	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	Audition UIP-ONU	Audition UIP-ONU	2016-02-08 09:00:00	2016-02-10 15:00:00	\N	\N	3	0	\N	\N
62826	ETUDES	AUCUNE	\N	\N	\N	GE Sénateurs anciens combattants et mémoire combattante	Groupe d'études Sénateurs anciens combattants et mémoire combattante	2016-02-10 16:15:00	2016-02-10 19:00:00	\N	\N	13	0	\N	928
63777	GIA	AUCUNE	\N	\N	\N	GIA Indonésie et Timor-Est	Groupe interparlementaire Indonésie et Timor-Est	2016-02-11 14:20:00	2016-02-11 15:00:00	\N	\N	4	0	653	\N
63904	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2016-02-10 14:00:00	2016-02-10 14:30:00	\N	\N	2	0	\N	\N
63907	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition Rapporteur 	Audition Rapporteur 	2016-02-10 14:30:00	2016-02-10 15:00:00	\N	\N	5	0	\N	\N
63914	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2016-02-10 15:00:00	2016-02-10 15:30:00	\N	\N	5	0	\N	\N
63920	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2016-02-11 08:30:00	2016-02-11 09:00:00	\N	\N	1	0	\N	\N
63923	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2016-02-11 09:00:00	2016-02-11 09:30:00	\N	\N	2	0	\N	\N
63926	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2016-02-11 09:30:00	2016-02-11 10:00:00	\N	\N	2	0	\N	\N
63929	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2016-02-11 10:00:00	2016-02-11 10:30:00	\N	\N	4	0	\N	\N
63934	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2016-02-11 10:30:00	2016-02-11 11:00:00	\N	\N	3	0	\N	\N
63938	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2016-02-11 14:00:00	2016-02-11 14:30:00	\N	\N	2	0	\N	\N
63941	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2016-02-11 14:30:00	2016-02-11 15:00:00	\N	\N	3	0	\N	\N
63945	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2016-02-11 16:30:00	2016-02-11 17:00:00	\N	\N	3	0	\N	\N
65354	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL France - Singapour	PJL France - Singapour	2016-02-18 10:30:00	2016-02-18 11:20:00	\N	\N	33	0	\N	\N
65355	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL France - Suisse	PJL France - Suisse	2016-02-18 11:20:00	2016-02-18 12:30:00	\N	\N	37	0	\N	\N
65356	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Élections présidentielles	PPL Élections présidentielles	2016-02-18 14:30:00	2016-02-18 19:10:00	\N	\N	66	0	\N	\N
65357	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Protection enfant	PPL Protection enfant	2016-02-18 19:15:00	2016-02-18 20:20:00	\N	\N	19	0	\N	\N
65358	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Chômage longue durée	PJL Chômage longue durée	2016-02-19 00:05:00	2016-02-19 00:55:00	\N	\N	14	0	\N	\N
65359	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Liberté création	PJL Liberté création	2016-02-17 14:30:00	2016-02-17 17:40:00	\N	\N	134	0	\N	\N
65360	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Réunion conseil européen	Débat Réunion conseil européen	2016-02-17 17:45:00	2016-02-17 20:30:00	\N	\N	83	0	\N	\N
65361	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Liberté création	PJL Architecture	2016-02-17 22:00:00	2016-02-18 00:20:00	\N	\N	47	0	\N	\N
66289	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-02-17 15:30:00	2016-02-17 16:30:00	\N	\N	2	0	\N	\N
62162	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-02-10 10:05:00	2016-02-10 12:50:00	2018-05-18 14:27:39	2018-05-18 14:27:47	40	0	\N	\N
66293	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-02-18 10:30:00	2016-02-18 11:30:00	\N	\N	1	0	\N	\N
68562	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2016-03-02 09:30:00	2016-03-02 11:40:00	2016-03-02 12:42:56	2016-03-02 14:45:00	44	0	\N	\N
69231	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2016-03-02 10:00:00	2016-03-02 12:50:00	2018-05-18 14:33:57	2018-05-18 14:34:02	40	0	\N	\N
69307	QUESTURE	AUCUNE	\N	\N	\N	Comité de déontologie	Comité de déontologie	2016-03-02 18:30:00	2016-03-02 19:00:00	\N	\N	3	0	\N	\N
69312	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2016-03-03 09:05:00	2016-03-03 11:00:00	2016-03-03 15:39:40	2016-03-03 17:04:37	22	0	\N	\N
69392	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-03-02 14:00:00	2016-03-02 19:15:00	\N	\N	1	0	\N	\N
69394	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-03-03 09:30:00	2016-03-03 11:30:00	\N	\N	1	0	\N	\N
69396	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-03-03 14:30:00	2016-03-03 16:30:00	\N	\N	1	0	\N	\N
69419	MECSS	AUDRAP	\N	\N	MECSS	MECSS - Avenir du FSV	MECSS  - Avenir du FSV	2016-03-08 15:15:00	2016-03-08 16:45:00	\N	\N	2	0	\N	\N
69423	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI  PPL Apprentissage	Audition Rapporteur SOCI  Apprentissage	2016-03-08 10:00:00	2016-03-08 12:00:00	\N	\N	1	0	\N	\N
70418	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Groupe de travail - Transport	Les infrastructures de transport	2016-03-08 14:30:00	2016-03-08 16:15:00	\N	\N	6	0	\N	\N
119914	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-09-21 16:45:00	2016-09-21 19:00:00	\N	\N	1	0	\N	\N
57281	DELEGATION	AUCUNE	\N	\N	PROS	Délégation sénatoriale à la prospective 	Délégation sénatoriale à la prospective 	2016-01-28 08:40:00	2016-01-28 10:05:00	2016-01-28 12:19:48	2016-01-28 12:38:00	14	0	\N	\N
60055	ETUDES	AUCUNE	\N	\N	\N	GE Mer et littoral	Groupe d'études Mer et littoral	2016-02-02 17:45:00	2016-02-02 19:00:00	\N	\N	8	0	\N	908
60365	COM_EURO	CONTROLE	\N	AFEU	\N	AFEUAffaires européennes 	AFEUAffaires européennes 	2016-02-04 09:05:00	2016-02-04 10:25:00	2016-02-04 11:42:30	2016-02-04 15:18:58	17	0	\N	\N
60550	GIA	AUCUNE	\N	\N	\N	GIA Finlande	Groupe interparlementaire Finlande	2016-02-03 08:30:00	2016-02-03 09:00:00	\N	\N	2	0	640	\N
62583	GIA	AUCUNE	\N	\N	\N	GIA Canada	Groupe interparlementaire Canada	2016-02-10 08:15:00	2016-02-10 09:30:00	\N	\N	9	0	583	\N
62738	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2016-02-10 17:00:00	2016-02-10 18:35:00	2016-02-11 15:45:10	2016-02-11 16:27:30	18	0	\N	\N
63477	MISSION	AUDRAP	\N	ISLAM	\N	Aud. Rapp. MI organisation, place et financement de l'Islam 	Audition Rapporteur MI organisation, place et financement de l'Islam en France 	2016-02-11 11:00:00	2016-02-11 12:30:00	\N	\N	2	0	\N	\N
64015	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MECSS - Avenir du FSV	Mission d'information Avenir du FSV	2016-02-16 14:30:00	2016-02-16 17:00:00	\N	\N	2	0	\N	\N
65421	GIA	AUCUNE	\N	\N	\N	GIA Mexique-Pays d'Am. Centrale	Groupe interparlementaire Mexique-Pays d'Am. Centrale	2016-02-16 13:45:00	2016-02-16 14:30:00	\N	\N	7	0	643	\N
65551	MECSS	AUDRAP	\N	\N	MECSS	MECSS  - Avenir du FSV	Mission d'information sur l'avenir du FSV	2016-02-18 14:00:00	2016-02-18 17:00:00	\N	\N	2	0	\N	\N
65565	MECSS	AUDRAP	\N	\N	MECSS	MECSS - Avenir du FSV	Mission d'information sur l'avenir du FSV	2016-03-08 16:00:00	2016-03-08 16:45:00	\N	\N	2	0	\N	\N
65652	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-02-17 11:20:00	2016-02-17 12:40:00	2018-05-18 14:32:24	2018-05-18 14:32:29	32	0	\N	\N
66304	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-02-18 08:30:00	2016-02-18 10:00:00	\N	\N	1	0	\N	\N
66307	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-02-17 14:30:00	2016-02-17 17:00:00	\N	\N	5	0	\N	\N
66772	GIA	AUCUNE	\N	\N	\N	GIA Indonésie et Timor-Est	Groupe interparlementaire Indonésie et Timor-Est	2016-02-23 11:00:00	2016-02-23 11:50:00	\N	\N	1	0	653	\N
66803	DELEGATION	AUCUNE	\N	\N	206	Terres rares	AP "Quelle politique pour les terres rares et les matières premières stratégiques et critiques ?"	2016-02-29 09:00:00	2016-02-29 18:30:00	2016-03-01 12:21:30	2016-03-01 16:37:35	3	0	\N	\N
66808	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière	Réunion plénière	2016-03-03 09:00:00	2016-03-03 12:00:00	2016-03-07 17:35:15	2016-03-07 17:49:03	8	0	\N	\N
68620	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2016-03-02 10:00:00	2016-03-02 12:05:00	2016-03-02 13:03:39	2016-03-02 14:44:58	34	0	\N	\N
68892	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-03-02 09:55:00	2016-03-02 12:40:00	2016-03-02 19:01:09	2016-03-03 09:07:01	37	0	\N	\N
68964	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Communes nouvelles	PPL Communes nouvelles	2016-03-08 14:30:00	2016-03-08 16:45:00	\N	\N	110	0	\N	\N
68966	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au Gouvernement	Questions d'actualité au Gouvernement	2016-03-08 16:45:00	2016-03-08 17:40:00	\N	\N	284	0	\N	\N
68967	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Communes nouvelles	PPL Communes nouvelles	2016-03-08 17:45:00	2016-03-08 19:30:00	\N	\N	63	0	\N	\N
68968	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Candidats conseil municipal	PPL Candidats conseil municipal	2016-03-08 19:10:00	2016-03-08 20:20:00	\N	\N	39	0	\N	\N
69077	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	ENTREPRISES	Entreprises	Déplacement en Saône-et-Loire - Viste d'Areva à Saint-Marcel	2016-03-07 14:30:00	2016-03-07 15:45:00	\N	\N	11	0	\N	\N
69089	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	ENTREPRISES	Entreprises	Déplacement en Saône-et-Loire - Visite d'Amazon à Sevrey	2016-03-07 16:15:00	2016-03-07 17:30:00	\N	\N	10	0	\N	\N
69102	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière de la Délégaiton	Réunion de la Délégation	2016-03-17 08:30:00	2016-03-17 10:00:00	2016-03-17 11:51:52	2016-03-17 11:59:38	12	0	\N	\N
69476	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-03-02 14:30:00	2016-03-02 15:45:00	\N	\N	2	0	\N	\N
69479	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-03-02 15:45:00	2016-03-02 17:00:00	\N	\N	2	0	\N	\N
69482	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-03-02 15:00:00	2016-03-02 16:30:00	\N	\N	4	0	\N	\N
59291	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCLCulture 	AFCLCulture 	2016-02-03 09:30:00	2016-02-03 10:45:00	2016-02-04 16:59:20	2016-02-04 17:54:20	45	0	\N	\N
65607	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-02-17 09:00:00	2016-02-17 11:20:00	2016-02-17 15:49:45	2016-02-17 16:16:09	40	0	\N	\N
68420	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	CAE 	2016-03-02 09:05:00	2016-03-02 11:05:00	2018-05-18 14:33:36	2018-05-18 14:33:41	34	0	\N	\N
69487	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-03-03 10:00:00	2016-03-03 11:30:00	\N	\N	3	0	\N	\N
70825	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2016-03-09 10:45:00	2016-03-09 12:15:00	2018-05-18 14:36:17	2018-05-18 14:36:25	34	1	\N	\N
71896	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	Aucune Réunion groupe fr de l'UIP	Aucune Réunion groupe fr de l'UIP	2016-03-02 18:30:00	2016-03-02 19:45:00	\N	\N	17	0	\N	\N
71957	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2016-03-08 14:35:00	2016-03-08 16:00:00	\N	\N	7	0	\N	\N
71971	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2016-03-09 14:00:00	2016-03-09 16:40:00	\N	\N	1	0	\N	\N
71976	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2016-03-09 14:00:00	2016-03-09 15:10:00	\N	\N	1	0	\N	\N
72035	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Groupe de Travail - DGF	Groupe de travail - Réforme de la  DGF - Articulation de la réforme de la DGF avec la baisse des dotations	2016-03-10 09:30:00	2016-03-10 11:15:00	\N	\N	10	0	\N	\N
72100	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-03-09 14:30:00	2016-03-09 16:00:00	\N	\N	1	0	\N	\N
72102	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-03-09 16:30:00	2016-03-09 17:30:00	\N	\N	1	0	\N	\N
72104	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-03-08 15:30:00	2016-03-08 16:30:00	\N	\N	2	0	\N	\N
72110	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-03-09 09:00:00	2016-03-09 10:00:00	\N	\N	1	0	\N	\N
72119	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-03-09 15:30:00	2016-03-09 16:30:00	\N	\N	1	0	\N	\N
72121	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-03-08 15:00:00	2016-03-08 16:30:00	\N	\N	4	0	\N	\N
72126	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	ETRD 	ETRD 	2016-03-10 17:30:00	2016-03-10 18:30:00	\N	\N	1	0	\N	\N
72128	GIA	AUCUNE	\N	\N	\N	GIA Jordanie	Groupe interparlementaire Jordanie	2016-03-08 13:00:00	2016-03-08 14:30:00	\N	\N	1	0	659	\N
72130	GIA	AUCUNE	\N	\N	\N	GIA Indonésie et Timor-Est	Groupe interparlementaire Indonésie et Timor-Est	2016-03-10 14:30:00	2016-03-10 15:30:00	\N	\N	3	0	653	\N
72134	GIA	AUCUNE	\N	\N	\N	GIA Asie du Sud-Est	Groupe interparlementaire Asie du Sud-Est	2016-03-09 14:30:00	2016-03-09 15:30:00	\N	\N	1	0	609	\N
72136	GIA	AUCUNE	\N	\N	\N	GIA Etats-Unis	Groupe interparlementaire Etats-Unis	2016-03-08 12:30:00	2016-03-08 14:30:00	\N	\N	13	0	590	\N
72150	GIA	AUCUNE	\N	\N	\N	GIA Monaco	Groupe interparlementaire Monaco	2016-03-09 16:00:00	2016-03-09 17:15:00	\N	\N	7	0	673	\N
72165	GIA	AUCUNE	\N	\N	\N	GIA Monaco	Groupe interparlementaire Monaco	2016-03-09 20:00:00	2016-03-09 22:30:00	\N	\N	7	0	673	\N
72181	GIA	AUCUNE	\N	\N	\N	GIA Monaco	Groupe interparlementaire Monaco	2016-03-10 08:30:00	2016-03-10 09:30:00	\N	\N	6	0	673	\N
72188	GIA	AUCUNE	\N	\N	\N	GIA Monaco	Groupe interparlementaire Monaco	2016-03-10 11:00:00	2016-03-10 14:30:00	\N	\N	7	0	673	\N
72196	MISSION	AUCUNE	\N	ISLAM	\N	MI organisation, place et financement de l'Islam en France 	MI organisation, place et financement de l'Islam en France 	2016-03-14 16:00:00	2016-03-14 18:00:00	2016-03-14 18:29:55	2016-03-15 14:42:08	2	0	\N	\N
72860	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJLC Protection de la Nation	PJLC Protection de la Nation	2016-03-17 11:00:00	2016-03-17 12:45:00	\N	\N	160	0	\N	\N
56824	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2016-01-27 14:30:00	2016-01-27 16:30:00	2016-01-27 17:57:54	2016-01-28 12:36:09	37	0	\N	\N
56905	MISSION	AUCUNE	\N	ISLAM	\N	MI organisation, place et financement de l'Islam en France 	MI organisation, place et financement de l'Islam en France 	2016-01-27 15:05:00	2016-01-27 16:55:00	2016-01-27 17:36:39	2016-01-27 17:49:52	14	0	\N	\N
56934	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	GT Simplification urbanisme	Collectivités  territoriales 	2016-02-03 16:00:00	2016-02-03 18:00:00	\N	\N	13	0	\N	\N
56945	DELEGATION	AUCUNE	\N	\N	COLTER	Collectivités territoriales	Tome 3 rapport Finances locales	2016-03-17 08:30:00	2016-03-17 10:00:00	2016-03-18 10:20:39	2016-03-18 11:27:47	18	0	\N	\N
57065	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-01-27 19:35:00	2016-01-27 20:20:00	2018-05-18 14:26:18	2018-05-18 14:26:22	12	0	\N	\N
57652	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-01-28 11:40:00	2016-01-28 12:40:00	\N	\N	2	0	\N	\N
57992	GIA	AUCUNE	\N	\N	\N	GIA Asie du Sud-Est	Groupe interparlementaire Asie du Sud-Est	2016-01-27 14:30:00	2016-01-27 15:15:00	\N	\N	2	0	609	\N
59212	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINCFinances 	FINCFinances 	2016-02-02 17:35:00	2016-02-02 18:50:00	2018-05-18 14:28:59	2018-05-18 14:29:05	36	0	\N	\N
60257	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	GT LOISLois 	Groupe de travail LOISLois 	2016-01-12 15:30:00	2016-01-12 16:30:00	\N	\N	3	0	\N	\N
60594	GIA	AUCUNE	\N	\N	\N	GIA Italie	Groupe interparlementaire Italie	2016-02-03 12:00:00	2016-02-03 13:00:00	\N	\N	20	0	621	\N
60647	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRDAffaires étrangères 	Audition Rapporteur ETRDAffaires étrangères 	2016-02-04 09:30:00	2016-02-04 11:30:00	\N	\N	4	0	\N	\N
60652	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRDAffaires étrangères 	Audition Rapporteur ETRDAffaires étrangères 	2016-02-02 15:30:00	2016-02-02 16:30:00	\N	\N	2	0	\N	\N
60655	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRDAffaires étrangères 	Audition Rapporteur ETRDAffaires étrangères 	2016-02-03 16:30:00	2016-02-03 18:00:00	\N	\N	2	0	\N	\N
60658	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRDAffaires étrangères 	Audition Rapporteur ETRDAffaires étrangères 	2016-02-04 10:00:00	2016-02-04 11:45:00	\N	\N	2	0	\N	\N
60661	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRDAffaires étrangères 	Audition Rapporteur ETRDAffaires étrangères 	2016-02-02 12:15:00	2016-02-02 16:15:00	\N	\N	3	0	\N	\N
60677	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	Collectivités  territoriales 	Collectivités  territoriales 	2016-02-02 15:30:00	2016-02-02 17:00:00	\N	\N	3	0	\N	\N
61102	ETUDES	AUCUNE	\N	\N	\N	GE Cheval	Groupe d'études Cheval	2016-02-03 14:45:00	2016-02-03 15:45:00	\N	\N	7	0	\N	912
61379	GIA	AUCUNE	\N	\N	\N	GIA Chypre	Groupe interparlementaire Chypre	2016-02-09 12:30:00	2016-02-09 14:15:00	\N	\N	6	0	585	\N
61419	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Liberté création	PJL Liberté création	2016-02-09 17:05:00	2016-02-09 19:40:00	\N	\N	105	0	\N	\N
61420	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Liberté création	PJL Liberté création	2016-02-10 14:30:00	2016-02-10 18:30:00	\N	\N	140	0	\N	\N
61421	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Liberté création	PJL Liberté création	2016-02-10 21:30:00	2016-02-11 01:30:00	\N	\N	58	0	\N	\N
61794	COM_SPECIALE	PLENIERE	\N	COMSPEAPU	\N	Commission spéciale chargée du contrôle des comptes 	Commission spéciale chargée du contrôle des comptes 	2016-02-09 18:00:00	2016-02-09 19:15:00	2016-02-09 19:36:46	2016-02-10 16:18:05	7	0	\N	\N
62821	GIA	AUCUNE	\N	\N	\N	GIA Caraïbes	Groupe interparlementaire Caraïbes	2016-02-11 08:00:00	2016-02-11 09:00:00	\N	\N	2	0	642	\N
62824	GIA	AUCUNE	\N	\N	\N	GIA Caraïbes	Groupe interparlementaire Caraïbes	2016-02-10 16:00:00	2016-02-10 17:00:00	\N	\N	1	0	642	\N
62861	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Rapport cour des comptes	Rapport cour des comptes	2016-02-11 10:30:00	2016-02-11 11:20:00	\N	\N	111	0	\N	\N
62862	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL France - Mali	Convention Mali	2016-02-11 11:30:00	2016-02-11 12:15:00	\N	\N	65	0	\N	\N
62863	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Conventions internationales	Conventions internationales	2016-02-11 12:15:00	2016-02-11 12:20:00	\N	\N	0	0	\N	\N
62864	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Liberté création	PJL Liberté création	2016-02-11 12:20:00	2016-02-11 13:40:00	\N	\N	62	0	\N	\N
62865	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au Gouvernement	Questions d'actualité au Gouvernement	2016-02-11 15:00:00	2016-02-11 16:05:00	\N	\N	254	0	\N	\N
63149	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-02-09 14:30:00	2016-02-09 18:30:00	\N	\N	1	0	\N	\N
63151	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-02-10 14:00:00	2016-02-10 18:30:00	\N	\N	1	0	\N	\N
63441	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-02-09 14:45:00	2016-02-09 15:45:00	\N	\N	3	0	\N	\N
63998	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Liberté création	PJL Liberté création	2016-02-16 14:30:00	2016-02-16 16:30:00	\N	\N	165	0	\N	\N
63999	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au Gouvernement	Questions d'actualité au Gouvernement	2016-02-16 16:45:00	2016-02-16 17:30:00	\N	\N	308	0	\N	\N
64000	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Droit des étrangers	PJL Droit des étrangers	2016-02-16 17:45:00	2016-02-16 19:30:00	\N	\N	93	0	\N	\N
64003	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Liberté création	PJL Liberté création	2016-02-16 21:30:00	2016-02-17 00:40:00	\N	\N	87	0	\N	\N
65880	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2016-02-17 17:45:00	2016-02-17 17:50:00	2016-02-17 18:52:57	2016-02-18 11:20:17	17	0	\N	\N
66162	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2016-02-17 09:00:00	2016-02-17 11:35:00	2016-02-18 11:35:52	2016-02-18 11:39:08	32	0	\N	\N
66431	DELEGATION	AUCUNE	\N	\N	PROS	Audition de M. Alain Parant	Audition de M. Alain Parant, Alain Parant, démographe	2016-02-18 08:35:00	2016-02-18 09:55:00	2016-02-18 18:37:37	2016-02-22 10:58:49	7	0	\N	\N
66869	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI 	Audition Rapporteur SOCI 	2016-03-02 15:00:00	2016-03-02 17:00:00	\N	\N	2	0	\N	\N
66879	DELEGATION	AUCUNE	\N	\N	COLTER	Collectivités  territoriales 	Audition M. BAYLET et Mme GRELIER	2016-03-31 14:00:00	2016-03-31 15:00:00	2016-03-31 15:14:34	2016-03-31 17:35:36	12	0	\N	\N
66880	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	502	\N	\N	Explications de vote PJL Liberté création	Explications de vote PJL Liberté création	2016-03-01 15:15:00	2016-03-01 16:00:00	\N	\N	305	0	\N	\N
66881	SEANCE_PLENIERE	SCRUSOL	502	\N	\N	Scrutin solennel PJL Liberté création	Scrutin PJL Architecture	2016-03-01 16:00:00	2016-03-01 16:40:00	\N	\N	0	0	\N	\N
66882	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Situation financière des départements	Débat Situation financière des départements	2016-03-02 14:30:00	2016-03-02 16:20:00	\N	\N	94	0	\N	\N
66883	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Bac Pro	Débat Bac Pro	2016-03-02 16:20:00	2016-03-02 18:05:00	\N	\N	60	0	\N	\N
66884	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Sécurité transports	CMP Sécurité transports	2016-03-02 18:00:00	2016-03-02 19:25:00	\N	\N	53	0	\N	\N
66885	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Chambres de commerce et d'industrie	CMP Chambres de commerce et d'industrie	2016-03-02 19:25:00	2016-03-02 20:25:00	\N	\N	41	0	\N	\N
68251	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-03-01 18:10:00	2016-03-01 20:30:00	2018-05-18 14:32:44	2018-05-18 14:32:55	23	0	\N	\N
69356	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-03-03 11:00:00	2016-03-03 12:00:00	\N	\N	1	0	\N	\N
69358	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-03-03 09:30:00	2016-03-03 12:30:00	\N	\N	2	0	\N	\N
69425	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Déplacement situation sanitaire outre-mer	Déplacement situation sanitaire outre-mer	2016-03-29 15:30:00	2016-03-29 19:30:00	\N	\N	1	0	\N	\N
119913	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Entreprises	Réunion plénière de la Délégation sénatoriale aux entreprises 	2016-09-27 16:00:00	2016-09-27 17:00:00	2016-09-27 18:03:42	2016-09-28 15:25:34	19	0	\N	\N
57260	GIA	AUCUNE	\N	\N	\N	GIA Grèce	Groupe interparlementaire Grèce	2016-01-27 12:45:00	2016-01-27 14:30:00	\N	\N	15	0	591	\N
57434	BUREAU	AUCUNE	\N	\N	\N	Bureau	Réunion du Bureau	2016-01-28 09:00:00	2016-01-28 11:00:00	\N	\N	23	0	\N	\N
57623	QUESTURE	AUCUNE	\N	\N	\N	Questure	Réunion de Questure	2016-01-28 11:00:00	2016-01-28 11:15:00	\N	\N	3	0	\N	\N
59500	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINCFinances 	FINCFinances 	2016-02-03 09:35:00	2016-02-03 12:15:00	2016-02-03 16:11:20	2016-02-03 17:07:44	44	0	\N	\N
60034	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR Traité transatlantique	PPR Traité transatlantique	2016-02-04 10:30:00	2016-02-04 12:55:00	\N	\N	47	0	\N	\N
60037	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Logement social	PPL Logement social	2016-02-04 14:30:00	2016-02-04 16:30:00	\N	\N	34	0	\N	\N
60038	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Autorités administratives indépendantes	PPL Autorités administratives indépendantes	2016-02-04 16:40:00	2016-02-04 19:40:00	\N	\N	27	0	\N	\N
60039	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPLO Autorités administratives indépendantes	PPLO Autorités administratives indépendantes	2016-02-04 19:40:00	2016-02-04 19:50:00	\N	\N	0	0	\N	\N
60615	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOISLois 	Audition Rapporteur LOISLois 	2016-02-03 14:30:00	2016-02-03 16:15:00	\N	\N	1	0	\N	\N
60624	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Médicament	MI Politique du médicament	2016-02-10 16:30:00	2016-02-10 18:30:00	\N	\N	2	0	\N	\N
59450	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOISLois 	LOISLois 	2016-02-03 09:10:00	2016-02-03 12:25:00	2016-02-04 09:45:32	2016-02-04 15:49:54	42	0	\N	\N
60628	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Médicament	Mission d'info Politique du médicament	2016-02-17 14:30:00	2016-02-17 15:30:00	\N	\N	2	0	\N	\N
63404	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Liberté création	PJL Liberté création	2016-02-12 09:30:00	2016-02-12 12:50:00	\N	\N	27	0	\N	\N
63412	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Liberté création	PJL Liberté création	2016-02-12 14:30:00	2016-02-12 19:40:00	\N	\N	40	0	\N	\N
63419	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Architecture	PJL Architecture	2016-02-12 19:30:00	2016-02-13 01:00:00	\N	\N	0	0	\N	\N
63826	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-02-09 16:30:00	2016-02-09 17:30:00	\N	\N	2	0	\N	\N
63831	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-02-09 10:00:00	2016-02-09 10:30:00	\N	\N	1	0	\N	\N
63833	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-02-11 17:00:00	2016-02-11 18:30:00	\N	\N	1	0	\N	\N
63841	GIA	AUCUNE	\N	\N	\N	GIA Ukraine	Groupe interparlementaire Ukraine	2016-02-11 14:00:00	2016-02-11 15:00:00	\N	\N	3	0	530	\N
65094	GIA	AUCUNE	\N	\N	\N	GIA Vanuatu	Groupe interparlementaire Vanuatu	2016-02-16 12:45:00	2016-02-16 14:15:00	\N	\N	7	0	651	\N
65150	COM_SPECIALE	PLENIERE	\N	PROSTITUTION	\N	CS sur la lutte contre le système prostitutionnel 	CS sur la lutte contre le système prostitutionnel 	2016-02-16 17:45:00	2016-02-16 18:15:00	2016-02-16 19:16:32	2016-02-17 14:53:56	25	0	\N	\N
65438	MISSION	AUCUNE	\N	ISLAM	\N	MI organisation, place et financement de l'Islam en France 	MI organisation, place et financement de l'Islam en France 	2016-02-17 15:05:00	2016-02-17 17:10:00	2016-02-17 17:14:04	2016-02-18 11:38:19	17	0	\N	\N
65462	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2016-02-17 09:35:00	2016-02-17 12:05:00	2018-05-18 14:32:04	2018-05-18 14:32:09	47	0	\N	\N
65594	MECSS	AUDRAP	\N	\N	MECSS	MECSS - Avenir du FSV	Mission d'information sur l'avenir du FSV	2016-02-18 09:30:00	2016-02-18 12:00:00	\N	\N	2	0	\N	\N
66335	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-02-18 11:30:00	2016-02-18 13:00:00	\N	\N	2	0	\N	\N
66609	ETUDES	AUCUNE	\N	\N	\N	GE Tourisme et loisirs	Groupe d'études Tourisme et loisirs	2016-02-17 08:15:00	2016-02-17 09:30:00	\N	\N	7	0	\N	910
66645	COM_PERMANENTE	AUDRAP	\N	CAE	\N	CAE 	CAE 	2016-02-18 15:30:00	2016-02-18 16:30:00	\N	\N	1	0	\N	\N
66657	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE 	Audition Rapporteur CAE 	2016-02-17 17:45:00	2016-02-17 19:15:00	\N	\N	1	0	\N	\N
66659	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE 	Audition Rapporteur CAE 	2016-02-18 11:00:00	2016-02-18 12:00:00	\N	\N	1	0	\N	\N
66661	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE 	Audition Rapporteur CAE 	2016-02-18 14:30:00	2016-02-18 16:00:00	\N	\N	1	0	\N	\N
66663	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2016-02-16 10:00:00	2016-02-16 11:30:00	\N	\N	3	0	\N	\N
66667	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2016-02-16 14:00:00	2016-02-16 14:30:00	\N	\N	5	0	\N	\N
66673	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2016-02-17 14:00:00	2016-02-17 14:30:00	\N	\N	2	0	\N	\N
66676	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2016-02-17 14:30:00	2016-02-17 15:00:00	\N	\N	3	0	\N	\N
66680	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2016-02-17 15:00:00	2016-02-17 15:45:00	\N	\N	3	0	\N	\N
66684	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2016-02-18 09:30:00	2016-02-18 10:15:00	\N	\N	6	0	\N	\N
66691	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2016-02-18 10:45:00	2016-02-18 11:15:00	\N	\N	6	0	\N	\N
66698	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2016-02-18 16:00:00	2016-02-18 17:30:00	\N	\N	1	0	\N	\N
66701	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Groupe de travail - DGF	La réforme de la dotation globale de fonctionnement (DGF) - Réunion constitutive 	2016-02-17 09:30:00	2016-02-17 11:10:00	\N	\N	12	0	\N	\N
66717	GIA	AUCUNE	\N	\N	\N	GIA Allemagne	Groupe interparlementaire Allemagne	2016-02-18 18:30:00	2016-02-18 21:30:00	\N	\N	5	0	604	\N
66776	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Ambassadeur d'Arabie Saoudite	Petit déjeuner avec M. Besancenot, ambassadeur de France en Arabie Saoudite	2016-02-17 08:00:00	2016-02-17 09:20:00	\N	\N	26	0	\N	\N
69338	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-03-01 14:30:00	2016-03-01 15:30:00	\N	\N	2	0	\N	\N
69341	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-03-01 17:30:00	2016-03-01 18:30:00	\N	\N	2	0	\N	\N
69344	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-03-02 15:30:00	2016-03-02 16:30:00	\N	\N	1	0	\N	\N
69346	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-03-02 14:30:00	2016-03-02 15:30:00	\N	\N	3	0	\N	\N
69350	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-03-03 09:30:00	2016-03-03 10:30:00	\N	\N	3	0	\N	\N
69443	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	rapport d'info Maisons d'assistants maternels	Rapport d'information maisons d'assistants maternels	2016-03-17 14:00:00	2016-03-17 14:45:00	\N	\N	2	0	\N	\N
69446	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Apprentissage	Audition Rapporteur SOCI 	2016-03-08 17:30:00	2016-03-08 19:00:00	\N	\N	1	0	\N	\N
69448	COM_SPECIALE	PLENIERE	\N	COMSPEAPU	\N	Commission spéciale chargée du contrôle des comptes 	Commission spéciale chargée du contrôle des comptes 	2016-03-03 11:15:00	2016-03-03 12:30:00	2016-03-04 17:47:47	2016-03-07 17:48:41	6	0	\N	\N
69492	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI 	Audition Rapporteur SOCI 	2016-03-09 15:00:00	2016-03-09 16:00:00	\N	\N	2	0	\N	\N
69495	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-03-08 09:00:00	2016-03-08 11:10:00	2016-03-08 17:48:15	2016-03-08 17:49:41	25	0	\N	\N
70082	MISSION	AUDRAP	\N	ISLAM	\N	Aud. Rapp. MI organisation, place et financement de l'Islam 	Audition Rapporteur MI organisation, place et financement de l'Islam en France 	2016-03-03 09:00:00	2016-03-03 11:00:00	\N	\N	3	0	\N	\N
70419	MISSION	AUCUNE	\N	ISLAM	\N	MI organisation, place et financement de l'Islam en France 	MI organisation, place et financement de l'Islam en France 	2016-03-09 14:10:00	2016-03-09 16:05:00	2016-03-09 16:07:03	2016-03-09 16:23:32	11	0	\N	\N
57183	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Entreprises	Journée des entreprises - Table ronde sur le processus de simplification	2016-03-31 11:45:00	2016-03-31 13:00:00	\N	\N	43	0	\N	\N
57184	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Entreprises	Journée des entreprises - Parcours exemplaires de pilotage de performance	2016-03-31 16:15:00	2016-03-31 17:45:00	\N	\N	10	0	\N	\N
57241	DELEGATION	AUCUNE	\N	\N	211	Droits des femmes 	Droits des femmes 	2016-01-28 08:30:00	2016-01-28 10:00:00	2016-01-28 11:30:44	2016-01-28 12:37:59	10	0	\N	\N
62100	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2016-02-10 09:35:00	2016-02-10 11:10:00	2016-02-10 14:00:26	2016-02-10 17:45:09	49	0	\N	\N
57516	DELEGATION	AUCUNE	\N	\N	206	Visite plateau Saclay	Visite des universités de Paris-Sud et de Paris-Saclay	2016-02-11 09:30:00	2016-02-11 14:00:00	\N	\N	9	0	\N	\N
57815	DELEGATION	AUDRAP	\N	\N	PROS	Délégation sénatoriale à la prospective 	Délégation sénatoriale à la prospective 	2016-01-28 10:30:00	2016-01-28 12:00:00	\N	\N	4	0	\N	\N
57846	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2016-01-28 09:35:00	2016-01-28 10:55:00	2016-01-28 16:42:32	2016-01-28 17:39:10	20	0	\N	\N
57886	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au Gouvernement	Questions d'actualité au Gouvernement	2016-02-02 16:45:00	2016-02-02 17:45:00	\N	\N	304	0	\N	\N
57887	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Lutte antiterroriste	PPL Lutte antiterroriste	2016-02-02 17:45:00	2016-02-02 19:00:00	\N	\N	88	0	\N	\N
58964	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	Collectivités  territoriales 	Simplification normes urbanisme	2016-02-11 14:00:00	2016-02-11 15:00:00	\N	\N	12	0	\N	\N
60319	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	GT LOISLois 	Groupe de travail LOISLois 	2016-01-12 16:30:00	2016-01-12 17:30:00	\N	\N	1	0	\N	\N
60322	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	GT LOISLois 	Groupe de travail LOISLois 	2016-01-13 14:30:00	2016-01-13 16:30:00	\N	\N	3	0	\N	\N
60326	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	GT LOISLois 	Groupe de travail LOISLois 	2016-01-13 16:30:00	2016-01-13 18:30:00	\N	\N	2	0	\N	\N
60332	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	GT LOISLois 	Groupe de travail LOISLois 	2016-01-19 14:30:00	2016-01-19 16:30:00	\N	\N	5	0	\N	\N
60339	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	GT LOISLois 	Groupe de travail LOISLois 	2016-01-26 14:30:00	2016-01-26 15:30:00	\N	\N	1	0	\N	\N
60341	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	GT LOISLois 	Groupe de travail LOISLois 	2015-12-09 08:30:00	2015-12-09 09:30:00	\N	\N	6	0	\N	\N
60389	GIA	AUCUNE	\N	\N	\N	GIA Algérie	Groupe interparlementaire Algérie	2016-02-02 18:00:00	2016-02-02 18:30:00	\N	\N	9	0	575	\N
60449	GIA	AUCUNE	\N	\N	\N	GIA Israël	Groupe interparlementaire Israël	2016-02-02 14:00:00	2016-02-02 14:20:00	\N	\N	12	0	595	\N
60497	GIA	AUCUNE	\N	\N	\N	GIA Canada	Groupe interparlementaire Canada	2016-02-03 12:15:00	2016-02-03 13:45:00	\N	\N	1	0	583	\N
60545	GIA	AUCUNE	\N	\N	\N	GIA Jordanie	Groupe interparlementaire Jordanie	2016-02-02 18:30:00	2016-02-02 21:30:00	\N	\N	1	0	659	\N
60548	GIA	AUCUNE	\N	\N	\N	GIA Jordanie	Groupe interparlementaire Jordanie	2016-02-03 12:30:00	2016-02-03 14:00:00	\N	\N	1	0	659	\N
60553	GIA	AUCUNE	\N	\N	\N	GIA Pakistan	Groupe interparlementaire Pakistan	2016-02-03 08:15:00	2016-02-03 09:30:00	\N	\N	3	0	619	\N
60631	GIA	AUCUNE	\N	\N	\N	GIA Cambodge et Laos	Groupe interparlementaire Cambodge et Laos	2016-02-04 10:30:00	2016-02-04 15:30:00	\N	\N	6	0	577	\N
60692	GIA	AUCUNE	\N	\N	\N	GIA Québec	Groupe interparlementaire Québec	2016-02-02 18:00:00	2016-02-02 18:30:00	\N	\N	2	0	602	\N
60695	GIA	AUCUNE	\N	\N	\N	GIA Québec	Groupe interparlementaire Québec	2016-02-03 12:30:00	2016-02-03 14:30:00	\N	\N	1	0	602	\N
62256	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2016-02-10 10:30:00	2016-02-10 12:30:00	2018-05-18 14:31:21	2018-05-18 14:31:26	30	0	\N	\N
62840	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2016-02-11 08:35:00	2016-02-11 10:10:00	2016-02-11 10:35:30	2016-02-11 11:36:42	16	0	\N	\N
62994	DELEGATION	AUCUNE	\N	\N	211	Droits des femmes 	Droits des femmes 	2016-02-11 08:30:00	2016-02-11 11:00:00	2016-02-11 11:33:58	2016-02-11 11:35:47	15	0	\N	\N
63480	ETUDES	AUCUNE	\N	\N	\N	GE Communications électroniques et Poste	Groupe d'études Communications électroniques et Poste	2016-02-11 08:15:00	2016-02-11 09:30:00	\N	\N	5	0	\N	913
64019	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	Collectivités  territoriales 	Simplification normes urbanisme	2016-02-10 14:00:00	2016-02-10 16:00:00	\N	\N	3	0	\N	\N
66012	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2016-02-18 08:35:00	2016-02-18 09:50:00	2016-02-18 10:31:32	2016-02-18 11:21:22	14	0	\N	\N
66353	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-02-18 10:10:00	2016-02-18 12:25:00	2016-02-18 18:02:47	2016-02-18 18:12:12	21	0	\N	\N
66621	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	ETRD 	ETRD  déplacement Concarneau et Lorient	2016-02-18 08:00:00	2016-02-18 19:00:00	\N	\N	2	0	\N	\N
66636	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-02-16 14:30:00	2016-02-16 15:45:00	\N	\N	2	0	\N	\N
66646	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-02-17 14:30:00	2016-02-17 15:45:00	\N	\N	3	0	\N	\N
66653	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-02-17 15:45:00	2016-02-17 17:00:00	\N	\N	3	0	\N	\N
66723	GIA	AUCUNE	\N	\N	\N	GIA Nouvelle-Zélande	Groupe interparlementaire Nouvelle-Zélande	2016-02-18 12:30:00	2016-02-19 14:15:00	\N	\N	2	0	663	\N
69172	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2016-03-02 17:30:00	2016-03-02 18:50:00	2016-03-03 16:24:27	2016-03-03 16:24:33	38	0	\N	\N
69354	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-03-01 09:30:00	2016-03-01 10:30:00	\N	\N	1	0	\N	\N
69398	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD RI Eau	Audition Rapporteur CDD RI Eau	2016-03-01 17:30:00	2016-03-01 19:30:00	\N	\N	1	0	\N	\N
69400	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD RI Eau	Audition Rapporteur CDD RI Eau	2016-03-02 17:30:00	2016-03-02 18:15:00	\N	\N	1	0	\N	\N
69402	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD PJL Numérique	Audition Rapporteur CDD PJL Numérique	2016-03-02 16:00:00	2016-03-02 17:15:00	\N	\N	1	0	\N	\N
69404	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD PJL Numérique	Audition Rapporteur CDD PJL Numérique	2016-03-03 08:30:00	2016-03-03 09:45:00	\N	\N	1	0	\N	\N
70686	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Système prostitutionnel	PPL Système prostitutionnel	2016-03-10 10:30:00	2016-03-10 12:45:00	\N	\N	48	0	\N	\N
70701	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Économie bleue	PPL Économie bleue	2016-03-10 14:30:00	2016-03-10 18:35:00	\N	\N	54	0	\N	\N
70786	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2016-03-08 14:30:00	2016-03-08 16:00:00	\N	\N	1	0	\N	\N
70788	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2016-03-09 10:25:00	2016-03-09 11:55:00	2016-03-09 12:34:07	2016-03-09 14:08:54	30	0	\N	\N
59550	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAEAffaires économiques 	CAEAffaires économiques 	2016-02-03 11:20:00	2016-02-03 11:40:00	2018-05-18 14:29:41	2018-05-18 14:29:46	33	0	\N	\N
62213	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2016-02-10 09:30:00	2016-02-10 10:25:00	2018-05-18 14:27:16	2018-05-18 14:27:21	41	0	\N	\N
70864	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-03-09 09:10:00	2016-03-09 12:05:00	2018-05-18 14:35:10	2018-05-18 14:35:17	39	0	\N	\N
70942	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2016-03-09 09:10:00	2016-03-09 12:40:00	2016-03-10 11:33:58	2016-03-10 11:36:36	36	0	\N	\N
71050	QUESTURE	AUCUNE	\N	\N	\N	Questure	Réunion de Questure	2016-03-08 14:30:00	2016-03-08 15:45:00	\N	\N	2	0	\N	\N
71118	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	CAE 	2016-03-08 18:00:00	2016-03-08 19:35:00	2016-03-10 09:49:14	2016-03-10 11:36:38	61	0	\N	\N
71160	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	CAE 	2016-03-08 19:35:00	2016-03-08 19:55:00	2016-03-09 14:59:53	2016-03-09 15:56:22	17	0	\N	\N
71310	DELEGATION	AUCUNE	\N	\N	211	Droits des femmes 	Droits des femmes 	2016-03-09 13:00:00	2016-03-09 14:20:00	2016-03-09 15:13:24	2016-03-09 16:00:44	14	0	\N	\N
71510	COM_SPECIALE	PLENIERE	\N	PROSTITUTION	\N	CS sur la lutte contre le système prostitutionnel 	CS sur la lutte contre le système prostitutionnel 	2016-03-09 14:30:00	2016-03-09 14:45:00	2016-03-09 16:34:25	2016-03-09 16:36:04	23	0	\N	\N
57995	GIA	AUCUNE	\N	\N	\N	GIA Hongrie	Groupe interparlementaire Hongrie	2016-01-26 13:00:00	2016-01-26 15:00:00	\N	\N	1	0	592	\N
58002	GIA	AUCUNE	\N	\N	\N	GIA Iran	Groupe interparlementaire Iran	2016-01-27 18:00:00	2016-01-27 19:00:00	\N	\N	8	0	628	\N
58022	GIA	AUCUNE	\N	\N	\N	GIA Asie du Sud-Est	Groupe interparlementaire Asie du Sud-Est	2016-01-27 19:00:00	2016-01-27 21:00:00	\N	\N	2	0	609	\N
58025	GIA	AUCUNE	\N	\N	\N	GIA Algérie	Groupe interparlementaire Algérie	2016-01-26 20:30:00	2016-01-26 22:00:00	\N	\N	8	0	575	\N
58034	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-01-28 09:00:00	2016-01-28 10:00:00	\N	\N	1	0	\N	\N
58036	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2016-01-13 18:00:00	2016-01-13 19:00:00	\N	\N	1	0	\N	\N
58038	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2016-01-14 10:30:00	2016-01-14 12:00:00	\N	\N	1	0	\N	\N
58040	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2016-01-28 14:15:00	2016-01-28 15:00:00	\N	\N	1	0	\N	\N
58044	ETUDES	AUCUNE	\N	\N	\N	GE Photographie et autres arts visuels	Groupe d'études Photographie et autres arts visuels	2016-01-21 09:00:00	2016-01-21 10:30:00	\N	\N	2	0	\N	990
58060	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Lutte antiterroriste	PPL Lutte antiterroriste	2016-02-02 14:30:00	2016-02-02 16:45:00	\N	\N	178	0	\N	\N
58063	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Lutte antiterroriste	PPL Lutte antiterroriste	2016-02-02 21:35:00	2016-02-02 23:25:00	\N	\N	66	0	\N	\N
58096	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-02-02 09:15:00	2016-02-02 10:55:00	2018-05-18 14:28:38	2018-05-18 14:28:43	26	0	\N	\N
59797	MISSION	AUCUNE	\N	ISLAM	\N	MI organisation, place et financement de l'Islam en FranceMi	MI organisation, place et financement de l'Islam en FranceMission d'information sur l'organisation, la place et le finan	2016-02-03 15:10:00	2016-02-03 18:20:00	2016-02-05 10:12:32	2016-02-05 10:13:07	18	0	\N	\N
60572	COM_EURO	AUTRE_NON_PLENIERE	\N	AFEU	\N	AFEUAffaires européennes 	AFEUAffaires européennes 	2016-01-26 17:00:00	2016-01-26 18:00:00	\N	\N	13	0	\N	\N
60592	DELEGATION	AUCUNE	\N	\N	DSOM	Audition sur les normes agricoles dans les outre-mer	Audition sur les normes sanitaires et phytosanitaires applicables à l'agriculture des outre-mer	2016-02-18 14:00:00	2016-02-18 16:10:00	2016-02-18 16:38:19	2016-02-18 17:54:35	13	0	\N	\N
60617	GIA	AUCUNE	\N	\N	\N	GIA Indonésie et Timor-Est	Groupe interparlementaire Indonésie et Timor-Est	2016-02-04 14:00:00	2016-02-04 14:50:00	\N	\N	2	0	653	\N
60620	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2016-02-09 09:30:00	2016-02-09 12:20:00	\N	\N	30	0	\N	\N
60621	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL État d'urgence	PJL État d'urgence	2016-02-09 14:30:00	2016-02-09 16:55:00	\N	\N	240	0	\N	\N
60622	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL liberté création	PJL liberté création	2016-02-09 21:30:00	2016-02-10 00:40:00	\N	\N	78	0	\N	\N
64010	ETUDES	AUCUNE	\N	\N	\N	GE Vigne et vin	Groupe d'études Vigne et vin	2016-02-10 12:30:00	2016-02-10 14:30:00	\N	\N	1	0	\N	909
65430	QUESTURE	AUCUNE	\N	\N	\N	Questure	Réunion de Questure	2016-02-16 14:30:00	2016-02-16 16:45:00	\N	\N	3	0	\N	\N
65434	QUESTURE	AUCUNE	\N	\N	\N	Questure	Réunion de Questure	2016-02-16 18:00:00	2016-02-16 18:45:00	\N	\N	3	0	\N	\N
66452	COM_EURO	AUTRE_NON_PLENIERE	\N	AFEU	\N	AFEU 	AFEU 	2016-02-17 15:30:00	2016-02-17 16:45:00	\N	\N	4	0	\N	\N
66700	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2016-03-14 15:00:00	2016-03-14 16:00:00	\N	\N	0	0	\N	\N
66714	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Aide à la Grèce 	Suivi du plan d'aide à la Grèce 	2016-03-06 18:00:00	2016-03-08 17:15:00	\N	\N	2	0	\N	\N
66732	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-02-19 10:55:00	2016-02-19 11:35:00	\N	\N	1	0	\N	\N
66734	GIA	AUCUNE	\N	\N	\N	GIA Afrique centrale	Petit-déjeuner en présence de l'Ambassadeur de Guinée équatoriale en France	2016-02-17 08:30:00	2016-02-17 10:00:00	\N	\N	4	0	572	\N
66752	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	APM	10eme Session plénière de l'APM	2016-02-17 10:15:00	2016-02-20 19:00:00	\N	\N	1	0	\N	\N
66754	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT AFEU 	Groupe de travail AFEU 	2016-02-16 10:00:00	2016-02-16 17:00:00	\N	\N	2	0	\N	\N
66757	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT AFEU 	Groupe de travail AFEU 	2016-02-17 09:00:00	2016-02-17 18:30:00	\N	\N	2	0	\N	\N
66760	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT AFEU 	Groupe de travail AFEU 	2016-02-18 09:00:00	2016-02-19 00:00:00	\N	\N	2	0	\N	\N
66832	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE 	Audition Rapporteur CAE 	2016-02-23 15:00:00	2016-02-23 15:45:00	\N	\N	2	0	\N	\N
66834	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE 	Audition Rapporteur CAE 	2016-02-25 09:30:00	2016-02-25 10:15:00	\N	\N	2	0	\N	\N
66836	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE 	Audition Rapporteur CAE 	2016-02-25 10:15:00	2016-02-25 11:00:00	\N	\N	2	0	\N	\N
66838	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE 	Audition Rapporteur CAE 	2016-02-25 11:00:00	2016-02-25 11:45:00	\N	\N	2	0	\N	\N
66852	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	Aucune comité directeur  douze plus UIP	AComitébdirecteur douze plus UIPucune 	2016-02-21 19:30:00	2016-02-22 14:30:00	\N	\N	1	0	\N	\N
70902	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2016-03-09 09:30:00	2016-03-09 10:15:00	2016-03-09 14:57:30	2016-03-09 15:56:26	32	0	\N	\N
71061	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	CAE 	2016-03-09 09:35:00	2016-03-09 11:10:00	2018-05-18 14:35:37	2018-05-18 14:35:46	32	0	\N	\N
66865	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Apprentissage	PPL visant à développer l'apprentissage comme voie de réussite	2016-03-01 09:30:00	2016-03-01 12:30:00	\N	\N	1	0	\N	\N
69422	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	Collectivités  territoriales	Collectivités  territoriales - GT simplification droit urbanisme	2016-03-09 14:00:00	2016-03-09 16:00:00	\N	\N	4	0	\N	\N
69433	GIA	AUCUNE	\N	\N	\N	GIA Europe du Nord	Groupe interparlementaire Europe du Nord	2016-03-02 08:30:00	2016-03-02 10:00:00	\N	\N	3	0	625	\N
69437	GIA	AUCUNE	\N	\N	\N	GIA Europe du Nord	Groupe interparlementaire Europe du Nord	2016-03-03 12:30:00	2016-03-03 14:00:00	\N	\N	3	0	625	\N
69441	GIA	AUCUNE	\N	\N	\N	GIA Slovénie	Groupe interparlementaire Slovénie	2016-02-26 12:30:00	2016-02-26 14:30:00	\N	\N	1	0	529	\N
69644	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Alimentation	PPL Alimentation	2016-03-09 14:30:00	2016-03-09 18:30:00	\N	\N	132	0	\N	\N
69975	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2016-03-08 15:20:00	2016-03-08 16:35:00	2018-05-18 14:34:17	2018-05-18 14:34:27	22	0	\N	\N
71566	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2016-03-07 08:30:00	2016-03-08 11:30:00	\N	\N	2	0	\N	\N
71632	GIA	AUCUNE	\N	\N	\N	GIA Israël	Groupe interparlementaire Israël	2016-03-09 08:30:00	2016-03-09 09:30:00	\N	\N	19	0	595	\N
71672	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Rapport d'information Maisons d'assistants maternels	Auditions des co-rapporteurs sur les maisons d'assistants maternels	2016-03-30 15:30:00	2016-03-30 16:30:00	\N	\N	2	0	\N	\N
71704	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Rapport d'information Maisons d'assistants maternels	Auditions des co-rapporteurs sur les maisons d'assistants maternels	2016-03-17 10:00:00	2016-03-17 11:00:00	\N	\N	2	0	\N	\N
71707	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Rapport d'information Maisons d'assistants maternels	Rapport d'information maisons d'assistants maternels	2016-03-15 17:30:00	2016-03-15 19:00:00	\N	\N	2	0	\N	\N
71715	BUREAU	AUCUNE	\N	\N	\N	Délégation du Bureau	Délégation du Bureau en charge du statut et des conditions d'exercice du mandat de sénateur	2016-03-09 11:30:00	2016-03-09 12:30:00	\N	\N	4	0	\N	\N
71733	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2016-03-10 09:30:00	2016-03-10 11:00:00	2016-03-10 12:25:42	2016-03-10 14:38:49	15	0	\N	\N
71794	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2016-03-09 15:30:00	2016-03-09 16:30:00	\N	\N	2	0	\N	\N
71866	ETUDES	AUCUNE	\N	\N	\N	GE Cheval	Groupe d'études Cheval	2016-03-09 14:00:00	2016-03-09 15:00:00	\N	\N	5	0	\N	912
57174	COM_SPECIALE	PLENIERE	\N	COMSPEAPU	\N	Audition DAS	Aucune 	2016-01-28 11:15:00	2016-01-28 12:30:00	2016-01-28 15:26:45	2016-01-28 15:27:01	4	0	\N	\N
57873	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Rapport d'information Maisons d'assistants maternels	Rapport d'information maisons d'assistants maternels	2016-01-27 14:00:00	2016-01-27 15:00:00	\N	\N	4	0	\N	\N
58042	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD RI Eau	Audition Rapporteur CDD RI Eau	2016-01-27 16:00:00	2016-01-27 18:00:00	\N	\N	1	0	\N	\N
59648	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRDAffaires étrangères 	ETRDAffaires étrangères 	2016-02-03 10:50:00	2016-02-03 12:25:00	2018-05-18 14:29:18	2018-05-18 14:29:24	53	0	\N	\N
59775	DELEGATION	AUDRAP	\N	\N	PROS	Délégation sénatoriale à la prospective 	Délégation sénatoriale à la prospective 	2016-02-02 18:00:00	2016-02-02 19:35:00	\N	\N	3	0	\N	\N
59882	GIA	AUCUNE	\N	\N	\N	GIA Caraïbes	Groupe interparlementaire Caraïbes	2016-02-02 12:30:00	2016-02-02 13:20:00	\N	\N	1	0	642	\N
59889	GIA	AUCUNE	\N	\N	\N	GIA Caraïbes	Groupe interparlementaire Caraïbes	2016-02-03 14:30:00	2016-02-03 15:30:00	\N	\N	4	0	642	\N
59993	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRDAffaires étrangères 	ETRDAffaires étrangères 	2016-02-03 14:30:00	2016-02-03 16:10:00	2016-02-03 17:02:12	2016-02-03 17:08:10	35	0	\N	\N
60208	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOISLois 	LOISLois 	2016-02-03 21:05:00	2016-02-03 21:30:00	2018-05-18 14:30:05	2018-05-18 14:30:48	18	0	\N	\N
60565	GIA	AUCUNE	\N	\N	\N	GIA Chine	Groupe interparlementaire Chine	2016-02-17 11:00:00	2016-02-17 12:00:00	\N	\N	5	0	584	\N
62598	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2016-02-10 16:30:00	2016-02-10 17:50:00	2016-02-11 09:24:31	2016-02-11 11:35:13	27	0	\N	\N
62714	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-02-10 17:00:00	2016-02-10 18:35:00	2018-05-18 14:31:41	2018-05-18 14:31:46	19	0	\N	\N
63782	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière	Réunion plénière	2016-02-17 17:00:00	2016-02-17 19:00:00	2016-02-18 10:33:18	2016-02-18 11:20:54	9	0	\N	\N
63784	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	206	Réunion du Bureau	OPECST-Réunion du Bureau	2016-02-16 19:30:00	2016-02-16 21:00:00	\N	\N	5	0	\N	\N
63950	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	ETRD 	ETRD  Deplacement Cognac	2016-02-10 07:00:00	2016-02-10 19:00:00	\N	\N	23	0	\N	\N
64397	GIA	AUCUNE	\N	\N	\N	GIA Egypte	Groupe interparlementaire Egypte	2016-02-16 08:45:00	2016-02-16 09:50:00	\N	\N	6	0	617	\N
64424	GIA	AUCUNE	\N	\N	\N	GIA Jordanie	Groupe interparlementaire Jordanie	2016-02-16 12:30:00	2016-02-16 14:00:00	\N	\N	16	0	659	\N
64543	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2016-02-16 14:55:00	2016-02-16 15:00:00	2016-02-16 17:22:42	2016-02-16 17:48:46	28	0	\N	\N
65016	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE 	Audition Rapporteur CAE 	2016-02-09 16:00:00	2016-02-09 17:00:00	\N	\N	2	0	\N	\N
65523	MECSS	AUDRAP	\N	\N	MECSS	MECSS  - Avenir du FSV	Mission d'information sur l'avenir du FSV	2016-02-17 16:30:00	2016-02-17 18:00:00	\N	\N	2	0	\N	\N
66116	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-02-16 17:30:00	2016-02-16 18:35:00	\N	\N	1	0	\N	\N
66118	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-02-17 17:00:00	2016-02-17 18:20:00	\N	\N	1	0	\N	\N
66379	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-02-18 12:30:00	2016-02-18 12:45:00	2016-02-18 18:03:12	2016-02-18 18:12:14	20	0	\N	\N
66429	GIA	AUCUNE	\N	\N	\N	GIA Asie du Sud-Est	Groupe interparlementaire Asie du Sud-Est	2016-02-16 17:45:00	2016-02-16 18:30:00	\N	\N	1	0	609	\N
66519	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Protection de l'enfant	PPL Protection de l'enfant	2016-02-18 21:50:00	2016-02-18 23:55:00	\N	\N	17	0	\N	\N
66605	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au Gouvernement	Questions d'actualité au Gouvernement	2016-03-01 16:45:00	2016-03-01 17:40:00	\N	\N	304	0	\N	\N
66606	SEANCE_PLENIERE	QOD	\N	\N	\N	Question orale avec débat	Question orale avec débat	2016-03-01 17:45:00	2016-03-01 18:45:00	\N	\N	60	0	\N	\N
59935	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRDAffaires étrangères 	ETRDAffaires étrangères 	2016-02-03 09:30:00	2016-02-03 10:50:00	2016-02-03 16:42:59	2016-02-03 17:07:07	47	0	\N	\N
66607	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat  Réfugiés	Débat réfugiés	2016-03-01 21:00:00	2016-03-01 23:05:00	\N	\N	52	0	\N	\N
66617	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Rapporteur PPL Ancrage territorial alimentation	Audition Rapporteur PPL Ancrage territorial alimentation	2016-02-16 14:30:00	2016-02-16 16:00:00	\N	\N	3	0	\N	\N
66624	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE PPL Ancrage territorial alimentation	Audition Rapporteur CAE PPL Ancrage territorial alimentation	2016-02-16 18:00:00	2016-02-16 19:30:00	\N	\N	3	0	\N	\N
66628	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE PPL Ancrage territorial alimentation	Audition Rapporteur CAE PPL Ancrage territorial alimentation	2016-02-17 09:30:00	2016-02-17 12:00:00	\N	\N	3	0	\N	\N
66632	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE PPL Ancrage territorial alimentation	Audition Rapporteur CAE PPL Ancrage territorial alimentation	2016-02-17 15:15:00	2016-02-17 18:00:00	\N	\N	3	0	\N	\N
66639	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE 	Audition Rapporteur CAE 	2016-02-18 14:30:00	2016-02-18 16:30:00	\N	\N	1	0	\N	\N
66641	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE PPL Ancrage territorial alimentation	Audition Rapporteur CAE PPL Ancrage territorial alimentation	2016-02-19 09:00:00	2016-02-19 12:30:00	\N	\N	1	0	\N	\N
66643	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE PPL Ancrage territorial alimentation	Audition Rapporteur CAE PPL Ancrage territorial alimentation	2016-02-19 14:30:00	2016-02-19 15:30:00	\N	\N	1	0	\N	\N
66650	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD RI Eau	Audition Rapporteur CDD RI Eau	2016-02-17 17:00:00	2016-02-17 18:20:00	\N	\N	1	0	\N	\N
66872	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Audition Rapporteur FINC 	2016-03-02 12:00:00	2016-03-02 14:00:00	\N	\N	0	0	\N	\N
68332	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	CAE 	2016-03-01 17:45:00	2016-03-01 18:55:00	2016-03-02 17:37:18	2016-03-02 17:56:28	27	0	\N	\N
68417	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	ENTREPRISES	Entreprises	Déplacement en Saône-et-Loire - Visite de FRANCEOLE	2016-03-07 09:30:00	2016-03-07 10:45:00	\N	\N	10	0	\N	\N
68468	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	ENTREPRISES	Entreprises	Déplacement en Saône-et-Loire - Table ronde avec des entrepreneurs	2016-03-07 11:30:00	2016-03-07 14:15:00	\N	\N	11	0	\N	\N
69407	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2016-03-03 14:30:00	2016-03-03 16:00:00	\N	\N	1	0	\N	\N
70572	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2016-03-08 18:05:00	2016-03-08 19:35:00	2018-05-18 14:34:49	2018-05-18 14:34:57	60	0	\N	\N
70670	DELEGATION	AUCUNE	\N	\N	211	Droits des femmes 	Droits des femmes 	2016-03-08 14:30:00	2016-03-08 16:30:00	2016-03-09 11:38:06	2016-03-09 14:09:17	22	0	\N	\N
70704	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2016-03-15 09:30:00	2016-03-15 12:20:00	\N	\N	28	0	\N	\N
70707	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Forces armées	Débat Forces armées	2016-03-15 16:00:00	2016-03-15 18:05:00	\N	\N	106	0	\N	\N
70708	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Conventions internationales	Conventions internationales	2016-03-15 14:30:00	2016-03-15 15:05:00	\N	\N	88	0	\N	\N
70709	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Réunion Conseil européen	Débat Réunion Conseil européen	2016-03-15 18:15:00	2016-03-15 20:50:00	\N	\N	65	0	\N	\N
70710	GIA	AUCUNE	\N	\N	\N	GIA Pakistan	Groupe interparlementaire Pakistan	2016-03-09 08:15:00	2016-03-09 09:15:00	\N	\N	5	0	619	\N
70992	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2016-03-09 09:30:00	2016-03-09 11:45:00	2016-03-09 14:20:06	2016-03-09 15:56:28	42	0	\N	\N
71331	DELEGATION	AUCUNE	\N	\N	DSOM	Outre-mer 	Outre-mer 	2016-03-17 09:30:00	2016-03-17 11:05:00	2016-03-17 14:32:11	2016-03-17 14:49:43	12	0	\N	\N
71343	DELEGATION	AUCUNE	\N	\N	DSOM	Outre-mer 	Auditions sur les normes	2016-03-24 09:30:00	2016-03-24 12:45:00	2016-03-24 13:13:25	2016-03-24 18:41:57	10	0	\N	\N
71744	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2016-03-10 10:35:00	2016-03-10 12:15:00	2016-03-10 15:02:30	2016-03-10 15:50:18	11	0	\N	\N
71877	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD PJL Numérique	Audition Rapporteur CDD PJL Numérique 	2016-03-08 09:00:00	2016-03-08 11:30:00	\N	\N	1	0	\N	\N
71879	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD PJL Numérique	Audition Rapporteur CDD PJL Numérique	2016-03-09 13:30:00	2016-03-09 19:00:00	\N	\N	2	0	\N	\N
71882	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD PJL Numérique	Audition Rapporteur CDD PJL Numérique	2016-03-10 10:30:00	2016-03-10 13:00:00	\N	\N	1	0	\N	\N
71885	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD RI Eau	Audition Rapporteur CDD RI Eau	2016-03-09 16:50:00	2016-03-09 17:30:00	\N	\N	1	0	\N	\N
57997	GIA	AUCUNE	\N	\N	\N	GIA Pays du Golfe	Groupe interparlementaire Pays du Golfe	2016-01-24 09:00:00	2016-01-28 08:00:00	\N	\N	4	0	661	\N
58011	GIA	AUCUNE	\N	\N	\N	GIA Europe du Nord	Groupe interparlementaire Europe du Nord	2016-01-28 12:30:00	2016-01-28 14:00:00	\N	\N	10	0	625	\N
58047	GIA	AUCUNE	\N	\N	\N	GIA Russie	Groupe interparlementaire Russie	2016-01-27 19:00:00	2016-01-27 20:30:00	\N	\N	12	0	608	\N
58948	QUESTURE	AUCUNE	\N	\N	\N	Questure	Réunion de Questure	2016-02-02 14:30:00	2016-02-02 16:00:00	\N	\N	2	0	\N	\N
59130	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOISLois 	Audition Rapporteur LOISLois 	2016-02-02 15:00:00	2016-02-02 16:50:00	\N	\N	1	0	\N	\N
59410	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAEAffaires économiques 	CAEAffaires économiques 	2016-02-03 09:30:00	2016-02-03 11:20:00	2018-05-18 14:26:42	2018-05-18 14:26:48	33	0	\N	\N
60354	GIA	AUCUNE	\N	\N	\N	GIA Irlande	Groupe interparlementaire Irlande	2016-02-03 08:30:00	2016-02-03 09:30:00	\N	\N	10	0	594	\N
60638	GIA	AUCUNE	\N	\N	\N	GIA Pays du Golfe	Groupe interparlementaire Pays du Golfe	2016-02-04 00:00:00	2016-02-04 00:00:00	\N	\N	3	0	661	\N
60642	GIA	AUCUNE	\N	\N	\N	GIA Moldavie	Groupe interparlementaire Moldavie	2016-02-04 15:00:00	2016-02-04 16:00:00	\N	\N	1	0	851	\N
61122	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCLCulture 	AFCLCulture 	2016-02-09 09:10:00	2016-02-09 10:30:00	2016-02-09 17:06:20	2016-02-09 17:19:20	27	0	\N	\N
61221	GIA	AUCUNE	\N	\N	\N	GIE Tibet	Audition Penpa Tsering	2016-01-27 10:30:00	2016-01-27 12:00:00	\N	\N	1	0	634	\N
61224	GIA	AUCUNE	\N	\N	\N	GIE Tibet	Rencontre Sofia Stril-Rever	2016-02-10 09:00:00	2016-02-10 10:00:00	\N	\N	1	0	634	\N
62023	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-02-10 09:05:00	2016-02-10 10:05:00	2016-02-10 11:07:43	2016-02-10 17:45:11	34	0	\N	\N
62060	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	CAE 	2016-02-10 10:45:00	2016-02-10 11:05:00	2016-02-10 17:56:32	2016-02-11 11:35:15	27	0	\N	\N
63994	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	GT simplification urbanisme	GT simplification urbanisme	2016-02-16 17:30:00	2016-02-16 19:15:00	\N	\N	7	0	\N	\N
63995	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	GT simplification urbanisme	GT simplification urbanisme	2016-02-17 14:00:00	2016-02-17 16:00:00	\N	\N	5	0	\N	\N
63996	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	GT simplification urbanismeCollectivités  territoriales 	GT simplification urbanisme	2016-02-18 10:30:00	2016-02-18 12:20:00	\N	\N	6	0	\N	\N
65051	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-02-16 09:00:00	2016-02-16 10:10:00	2016-02-17 11:42:32	2016-02-17 14:54:44	18	0	\N	\N
66592	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2016-02-09 14:00:00	2016-02-09 15:00:00	\N	\N	1	0	\N	\N
66594	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2016-02-11 17:00:00	2016-02-11 19:00:00	\N	\N	1	0	\N	\N
66598	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT AFEU 	Groupe de travail AFEU 	2016-01-21 14:00:00	2016-01-21 18:00:00	\N	\N	2	0	\N	\N
66601	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT AFEU 	Groupe de travail AFEU 	2016-01-28 19:00:00	2016-01-28 20:15:00	\N	\N	2	0	\N	\N
66604	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2016-02-16 09:00:00	2016-02-16 15:00:00	\N	\N	1	0	\N	\N
66812	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	Collectivités  territoriales 	Simplification normes urbanisme	2016-03-01 14:00:00	2016-03-01 15:20:00	\N	\N	5	0	\N	\N
66813	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	Collectivités  territoriales 	Collectivités  territoriales 	2016-03-02 14:00:00	2016-03-02 16:00:00	\N	\N	5	0	\N	\N
68372	QUESTURE	AUCUNE	\N	\N	\N	Questure	Réunion de Questure	2016-03-01 18:00:00	2016-03-01 19:45:00	\N	\N	3	0	\N	\N
68659	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2016-03-02 10:30:00	2016-03-02 12:00:00	2016-03-02 14:47:57	2016-03-02 14:50:44	43	0	\N	\N
69406	ETUDES	AUCUNE	\N	\N	\N	GE Chasse et pêche	Groupe d'études Chasse et pêche	2016-03-03 08:30:00	2016-03-03 15:00:00	\N	\N	9	0	\N	907
69429	MECSS	AUDRAP	\N	\N	MECSS	MECSS travail dissimulé	MECSS travail dissimulé	2016-03-31 10:00:00	2016-03-31 12:00:00	\N	\N	3	0	\N	\N
71290	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2016-03-08 18:05:00	2016-03-08 19:35:00	2016-03-09 15:03:34	2016-03-09 16:00:15	61	0	\N	\N
71388	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	CAE 	2016-03-09 10:40:00	2016-03-09 12:40:00	2018-05-18 14:36:00	2018-05-18 14:36:05	59	0	\N	\N
71915	DELEGATION	AUDRAP	\N	\N	PROS	Délégation sénatoriale à la prospective 	Délégation sénatoriale à la prospective 	2016-03-10 09:30:00	2016-03-10 10:40:00	\N	\N	2	0	\N	\N
71990	MISSION	AUDRAP	\N	ISLAM	\N	Aud. Rapp. MI organisation, place et financement de l'Islam 	Audition Rapporteur MI organisation, place et financement de l'Islam en France 	2016-03-10 11:00:00	2016-03-10 11:20:00	\N	\N	2	0	\N	\N
72016	MECSS	AUDRAP	\N	\N	MECSS	MECSS 	MECSS 	2016-03-09 14:00:00	2016-03-09 19:00:00	\N	\N	2	0	\N	\N
72019	MECSS	AUDRAP	\N	\N	MECSS	MECSS 	MECSS 	2016-03-02 15:00:00	2016-03-02 17:00:00	\N	\N	2	0	\N	\N
72022	MECSS	AUDRAP	\N	\N	MECSS	MECSS 	MECSS 	2016-03-17 10:00:00	2016-03-17 12:00:00	\N	\N	2	0	\N	\N
72025	MECSS	AUDRAP	\N	\N	MECSS	MECSS 	MECSS 	2016-03-23 14:00:00	2016-03-23 18:00:00	\N	\N	2	0	\N	\N
72028	MECSS	AUDRAP	\N	\N	MECSS	MECSS 	MECSS 	2016-03-30 14:30:00	2016-03-30 18:00:00	\N	\N	2	0	\N	\N
72049	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Audition Ambassadeur de France en Russie	Audition de l'ambassadeur de France en Russie	2016-03-09 14:00:00	2016-03-09 14:30:00	\N	\N	8	0	\N	\N
72058	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Dialogue franco-russe	Dialogue stratégique de haut niveau franco-russe	2016-03-09 14:30:00	2016-03-09 17:15:00	\N	\N	11	0	\N	\N
72071	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-03-08 14:30:00	2016-03-08 15:15:00	\N	\N	1	0	\N	\N
72092	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-03-07 09:00:00	2016-03-07 12:45:00	\N	\N	1	0	\N	\N
72094	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-03-11 16:00:00	2016-03-11 18:00:00	\N	\N	1	0	\N	\N
72097	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-03-14 09:00:00	2016-03-14 12:45:00	\N	\N	1	0	\N	\N
72105	GIA	AUCUNE	\N	\N	\N	GE Chrétiens d'Orient	Groupe de liaison Chrétiens d'Orient	2016-03-11 09:00:00	2016-03-11 17:00:00	\N	\N	8	0	CHRETORIENT	CHRETORIENT
72205	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-03-08 14:00:00	2016-03-08 16:30:00	\N	\N	1	0	\N	\N
72207	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-03-09 16:00:00	2016-03-09 20:00:00	\N	\N	1	0	\N	\N
72250	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJLC Protection de la Nation	PJLC Protection de la Nation	2016-03-16 14:30:00	2016-03-16 20:05:00	\N	\N	261	0	\N	\N
72251	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJLC Protection de la Nation	PJLC Protection de la Nation	2016-03-16 21:45:00	2016-03-17 00:00:00	\N	\N	135	0	\N	\N
72439	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL OTAN	PJL OTAN	2016-03-15 15:05:00	2016-03-15 16:00:00	\N	\N	88	0	\N	\N
72441	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au Gouvernement	Questions d'actualité au Gouvernement	2016-03-17 15:00:00	2016-03-17 16:10:00	\N	\N	249	0	\N	\N
72458	MECSS	AUCUNE	\N	\N	MECSS	MECSS 	MECSS 	2016-03-15 15:45:00	2016-03-15 16:45:00	2016-03-15 16:50:58	2016-03-15 17:00:48	10	0	\N	\N
72466	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2016-03-14 10:00:00	2016-03-14 13:30:00	\N	\N	1	0	\N	\N
72469	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2016-03-14 16:00:00	2016-03-14 18:00:00	\N	\N	1	0	\N	\N
72805	GIA	AUCUNE	\N	\N	\N	GIA Algérie	Groupe interparlementaire Algérie	2016-03-09 12:30:00	2016-03-09 14:30:00	\N	\N	5	0	575	\N
72825	QUESTURE	AUCUNE	\N	\N	\N	Questure	Réunion de Questure	2016-03-15 15:00:00	2016-03-15 16:25:00	\N	\N	3	0	\N	\N
72832	GIA	AUCUNE	\N	\N	\N	GIA Russie	Groupe interparlementaire Russie	2016-03-10 12:30:00	2016-03-10 14:30:00	\N	\N	14	0	608	\N
72852	GIA	AUCUNE	\N	\N	\N	GIA Slovaquie - Déj Ambassadeur de Slovaquie en France	Groupe interparlementaire Slovaquie	2016-03-15 13:00:00	2016-03-15 14:30:00	\N	\N	4	0	532	\N
73542	MECSS	AUDRAP	\N	\N	MECSS	MECSS travail dissimulé	MECSS travail dissimulé	2016-03-16 14:00:00	2016-03-16 19:00:00	\N	\N	2	0	\N	\N
74653	QUESTURE	AUCUNE	\N	\N	\N	Questure	Réunion de Questure	2016-03-17 10:35:00	2016-03-17 10:50:00	\N	\N	3	0	\N	\N
74996	GIA	AUCUNE	\N	\N	\N	GIA Pays Baltes	Groupe interparlementaire Pays Baltes	2016-03-16 08:30:00	2016-03-16 09:30:00	\N	\N	5	0	616	\N
75049	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2016-03-15 16:00:00	2016-03-15 17:30:00	\N	\N	1	0	\N	\N
77517	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-03-23 15:30:00	2016-03-23 17:30:00	\N	\N	1	0	\N	\N
80114	ETUDES	AUCUNE	\N	\N	\N	GE Vigne et vin	Groupe d'études Vigne et vin	2016-03-30 08:30:00	2016-03-30 09:30:00	\N	\N	24	0	\N	909
68469	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-03-02 08:30:00	2016-03-02 09:55:00	2018-05-18 14:33:10	2018-05-18 14:33:20	37	0	\N	\N
68521	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2016-03-02 09:30:00	2016-03-02 11:25:00	2016-03-02 14:17:32	2016-03-02 14:45:02	34	0	\N	\N
70716	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2016-03-09 09:30:00	2016-03-09 10:40:00	2016-03-10 11:30:16	2016-03-10 11:36:35	48	1	\N	\N
77523	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2016 - Infrastructures et services de transport (AFITF)	2015-11-10 15:00:00	2015-11-10 16:00:00	\N	\N	1	0	\N	\N
77525	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2016 - Infrastructures et services de transport (DGITM)	2015-11-10 16:00:00	2015-11-10 17:00:00	\N	\N	1	0	\N	\N
77527	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2016 - Infrastructures et services de transport (SNCF Réseau)	2015-11-10 17:00:00	2015-11-10 18:00:00	\N	\N	1	0	\N	\N
77529	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2016 - Infrastructures et services de transport (VNF)	2015-11-10 18:00:00	2015-11-10 19:00:00	\N	\N	1	0	\N	\N
77531	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2016 - Infrastructures et services de transport (Société du Grand Paris)	2015-11-12 10:00:00	2015-11-12 11:00:00	\N	\N	1	0	\N	\N
77533	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2016 - Infrastructures et services de transport (Direction des affaires maritimes)	2015-11-12 11:00:00	2015-11-12 12:00:00	\N	\N	1	0	\N	\N
77535	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2016 - Engagements financiers de l'Etat (Agence France Trésor)	2015-11-12 16:30:00	2015-11-12 17:30:00	\N	\N	1	0	\N	\N
77537	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Première partie PLF 2016 ( Vinci Autoroutes)	2015-11-10 17:30:00	2015-11-10 18:30:00	\N	\N	1	0	\N	\N
77539	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PPL Logement social (Fédération des promoteurs immobiliers)	2016-01-12 14:30:00	2016-01-12 15:30:00	\N	\N	1	0	\N	\N
77541	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PPL Logement social (Direction du budget)	2016-01-12 15:30:00	2016-01-12 16:30:00	\N	\N	1	0	\N	\N
77543	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PPL Logement social (Auteurs PPL - groupe CRC)	2016-01-13 14:30:00	2016-01-13 15:30:00	\N	\N	1	0	\N	\N
77545	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PPL Logement social (Union sociale pour l'habitat)	2016-01-13 15:30:00	2016-01-13 16:30:00	\N	\N	1	0	\N	\N
77547	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PPL logement social (Fédération française du bâtiment)	2016-01-13 16:30:00	2016-01-13 17:30:00	\N	\N	1	0	\N	\N
77549	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PPL Logement social (FNAIM)	2016-01-14 16:00:00	2016-01-14 17:00:00	\N	\N	1	0	\N	\N
77551	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PPL Logement social (direction de l'habitat, de l'urbanisme et des paysages)	2016-01-14 17:00:00	2016-01-14 18:00:00	\N	\N	1	0	\N	\N
77553	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PPL Logement social (Caisse des dépôts et consignations)	2016-01-19 15:00:00	2016-01-19 15:30:00	\N	\N	1	0	\N	\N
77555	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	58-2 Compétitivité transport aérien (Cour des comptes)	2016-02-11 11:15:00	2016-02-11 12:30:00	\N	\N	1	0	\N	\N
77557	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Paris Saclay (Thales)	2016-03-01 15:30:00	2016-03-01 16:30:00	\N	\N	1	0	\N	\N
77564	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-03-23 14:45:00	2016-03-23 19:00:00	\N	\N	1	0	\N	\N
77566	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-03-24 08:30:00	2016-03-24 10:30:00	\N	\N	1	0	\N	\N
77608	GIA	AUCUNE	\N	\N	\N	GIA Asie du Sud-Est	Groupe interparlementaire Asie du Sud-Est	2016-03-23 08:00:00	2016-03-23 09:00:00	\N	\N	2	0	609	\N
77611	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-03-24 09:30:00	2016-03-24 10:45:00	\N	\N	1	0	\N	\N
77613	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-03-24 10:45:00	2016-03-24 12:05:00	\N	\N	2	0	\N	\N
77636	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-03-23 16:00:00	2016-03-23 17:00:00	\N	\N	2	0	\N	\N
77639	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-03-24 15:00:00	2016-03-24 15:50:00	\N	\N	1	0	\N	\N
77725	GIA	AUCUNE	\N	\N	\N	GIA Brésil	Petit-déjeuner de travail ambassadeur du Brésil et épidémiologiste Zika	2016-03-24 09:00:00	2016-03-24 10:30:00	\N	\N	4	0	576	\N
77745	GIA	AUCUNE	\N	\N	\N	GIA Mexique-Pays d'Am. Centrale	Groupe interparlementaire Mexique-Pays d'Am. Centrale	2016-03-15 16:00:00	2016-03-15 17:00:00	\N	\N	4	0	643	\N
77750	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	134e Assemblée de l'UIP	Aucune 134e Assemblée de l'UIP	2016-03-15 00:00:00	2016-03-25 09:00:00	\N	\N	1	0	\N	\N
77752	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	Au134e Assemblée de l'UIP 	134e Assemblée de l'UIP	2016-03-18 00:00:00	2016-03-25 09:00:00	\N	\N	2	0	\N	\N
78223	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Lutte contre le crime organisé	PJL Lutte contre le crime organisé	2016-03-30 14:30:00	2016-03-30 20:00:00	\N	\N	163	0	\N	\N
78224	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Lutte contre le crime organisé	PJL Lutte contre le crime organisé	2016-03-30 21:30:00	2016-03-31 00:10:00	\N	\N	76	0	\N	\N
78762	MISSION	AUCUNE	\N	ISLAM	\N	MI organisation, place et financement de l'Islam en France 	MI organisation, place et financement de l'Islam en France 	2016-03-30 14:10:00	2016-03-30 18:20:00	2016-03-30 18:22:47	2016-03-31 17:37:01	10	0	\N	\N
79217	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2016-03-31 08:35:00	2016-03-31 10:55:00	2016-03-31 12:01:16	2016-03-31 17:36:23	22	0	\N	\N
79328	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-03-29 14:55:00	2016-03-29 19:30:00	\N	\N	1	0	\N	\N
79355	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	GT simplification normes	GT simplification normes	2016-03-31 10:30:00	2016-03-31 12:00:00	\N	\N	5	0	\N	\N
79361	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	GT simplification normes	GT simplification normes	2016-03-30 14:00:00	2016-03-30 16:00:00	\N	\N	5	0	\N	\N
79372	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	Collectivités  territoriales 	Collectivités  territoriales 	2016-03-30 16:00:00	2016-03-30 18:00:00	\N	\N	6	0	\N	\N
79390	DELEGATION	AUCUNE	\N	\N	COLTER	Collectivités  territoriales 	Collectivités  territoriales 	2016-03-31 08:30:00	2016-03-31 10:30:00	2016-03-31 14:51:21	2016-03-31 17:35:40	13	0	\N	\N
79497	QUESTURE	AUCUNE	\N	\N	\N	Commission de concertation	Commission de concertation	2016-03-30 10:30:00	2016-03-30 13:05:00	\N	\N	2	0	\N	\N
79735	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2017	Anciens combattants	2016-03-31 14:15:00	2016-03-31 15:00:00	\N	\N	1	0	\N	\N
79737	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2017	Anciens combattants	2016-04-07 10:00:00	2016-04-07 12:00:00	\N	\N	1	0	\N	\N
79747	QUESTURE	AUCUNE	\N	\N	\N	COM Public Sénat	COM Public Sénat	2016-03-30 14:30:00	2016-03-30 16:00:00	\N	\N	3	0	\N	\N
79752	MISSION	AUCUNE	\N	ISLAM	\N	MI organisation, place et financement de l'Islam en France 	MI organisation, place et financement de l'Islam en France 	2016-03-31 13:35:00	2016-03-31 14:40:00	2016-03-31 16:10:05	2016-03-31 17:37:02	5	0	\N	\N
79758	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-03-31 12:05:00	2016-03-31 12:20:00	2018-05-18 14:41:16	2018-05-18 14:41:26	17	0	\N	\N
80149	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	Aménagement du territoire	Aménagement du territoire	2016-03-31 11:30:00	2016-03-31 12:45:00	\N	\N	6	0	\N	\N
78785	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-03-30 09:05:00	2016-03-30 13:00:00	2018-05-18 14:39:52	2018-05-18 14:39:59	43	0	\N	\N
80011	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle 2016 Paris-Saclay - Danone Research	2016-03-30 15:00:00	2016-03-30 16:00:00	\N	\N	1	0	\N	\N
80020	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle 2016 Paris-Saclay - SATT	2016-03-30 16:15:00	2016-03-30 18:15:00	\N	\N	1	0	\N	\N
80041	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE - Avis PJL "République numérique"	Audition Rapporteur CAE 	2016-03-29 09:30:00	2016-03-29 11:00:00	\N	\N	1	0	\N	\N
80043	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE Avis PJL "République numérique"	Audition Rapporteur CAE 	2016-03-29 14:30:00	2016-03-29 18:30:00	\N	\N	1	0	\N	\N
80045	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE Avis PJL "République numérique"	Audition Rapporteur CAE 	2016-03-31 09:30:00	2016-03-31 12:30:00	\N	\N	1	0	\N	\N
80047	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE - PJL Action logement	Audition Rapporteur CAE 	2016-03-30 16:45:00	2016-03-30 18:40:00	\N	\N	1	0	\N	\N
72863	ETUDES	AUCUNE	\N	\N	\N	GE Communications électroniques et Poste	Groupe d'études Communications électroniques et Poste	2016-03-16 08:30:00	2016-03-16 09:30:00	\N	\N	3	0	\N	913
72907	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2016-03-16 09:30:00	2016-03-16 11:15:00	2016-03-16 15:35:23	2016-03-16 16:50:13	28	0	\N	\N
73310	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2016-03-16 10:50:00	2016-03-16 12:15:00	2018-05-18 14:37:37	2018-05-18 14:37:43	43	1	\N	\N
75192	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2016 - Sécurités - Rapport spécial "Sécurité civile" - Audition de la DGSCGC	2015-11-03 17:45:00	2015-11-03 19:00:00	\N	\N	1	0	\N	\N
75194	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2016 - Sécurités - Rapport spécial "Police nationale" et "Gendarmerie nationale" - Audition du DGGN	2015-11-09 16:00:00	2015-11-09 17:30:00	\N	\N	1	0	\N	\N
75196	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2016 - Sécurités - Rapport spécial "Sécurité civile" - Table ronde syndicats de sapeurs-pompiers	2015-11-10 16:30:00	2015-11-10 18:00:00	\N	\N	1	0	\N	\N
75198	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contr. budg. : Moyens consacrés au renseig. au sein des progr.  "Police nle" -"Gendarmerie nle" - Contrôle à Orléans	2016-02-19 10:30:00	2016-02-19 17:00:00	\N	\N	1	0	\N	\N
75200	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Garantie européenne des dépôts - Déplacement à Bruxelles	2016-03-10 12:00:00	2016-03-10 18:00:00	\N	\N	1	0	\N	\N
75202	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PJL Criminalité organisée / Terrorisme - Audition Fédération bancaire française	2016-03-11 14:30:00	2016-03-11 15:30:00	\N	\N	1	0	\N	\N
75204	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Contrôle budg. Sécurités - 2016	Contrôle budg. Sécurités 2016 - La préfecture de police de Paris - Audition de M. Olivier Renaudie	2016-03-14 15:30:00	2016-03-14 16:30:00	\N	\N	1	0	\N	\N
75210	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au Gouvernement	Questions d'actualité au Gouvernement	2016-03-22 16:45:00	2016-03-22 17:30:00	\N	\N	320	0	\N	\N
75211	SEANCE_PLENIERE	QOD	\N	\N	\N	Question orale avec débat Santé et travail	Question orale avec débat Santé et travail	2016-03-22 17:45:00	2016-03-22 19:25:00	\N	\N	60	0	\N	\N
75219	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	521	\N	\N	Explications de vote PJLC Protection de la Nation	Explications de vote PJLC Protection de la Nation	2016-03-22 15:15:00	2016-03-22 16:15:00	\N	\N	320	0	\N	\N
75220	SEANCE_PLENIERE	SCRUSOL	521	\N	\N	Scrutin solennel PJLC Protection de la Nation	Scrutin solennel PJLC Protection de la Nation	2016-03-22 16:15:00	2016-03-22 16:40:00	\N	\N	320	0	\N	\N
75765	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-03-22 10:15:00	2016-03-22 11:30:00	\N	\N	1	0	\N	\N
76621	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2016-03-23 10:00:00	2016-03-23 11:30:00	2016-03-23 12:19:43	2016-03-23 15:20:15	35	0	\N	\N
76666	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2016-03-23 09:30:00	2016-03-23 10:45:00	2016-03-23 12:24:47	2016-03-23 15:20:11	30	0	\N	\N
77432	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2016-03-24 09:00:00	2016-03-24 11:00:00	2016-03-24 11:37:50	2016-03-24 18:41:16	15	0	\N	\N
77771	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Entreprises	Journée des entreprises  - Présentation des initiatives prise en réponse aux rencontres effectuées sur le terrain	2016-03-31 10:30:00	2016-03-31 11:45:00	\N	\N	39	0	\N	\N
77775	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Entreprises	Journée des entreprises - Échanges entre entrepreneurs français installés à Londres ou implantés en France	2016-03-31 13:45:00	2016-03-31 14:30:00	\N	\N	37	0	\N	\N
77780	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Entreprises	Entreprises et droit du travail	2016-04-06 15:30:00	2016-04-06 16:30:00	\N	\N	1	0	\N	\N
77781	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Entreprises	Auditions Entreprises et droit du travail	2016-04-06 16:30:00	2016-04-06 17:30:00	\N	\N	1	0	\N	\N
77813	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-03-25 14:00:00	2016-03-25 19:00:00	\N	\N	1	0	\N	\N
77816	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-03-29 09:10:00	2016-03-29 11:00:00	2018-05-18 14:39:14	2018-05-18 14:39:21	22	0	\N	\N
78299	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PJL Numérique - Audition Association Française du Multimedia Mobile (AFMM)	2016-03-29 08:30:00	2016-03-29 09:30:00	\N	\N	1	0	\N	\N
78301	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PJL Numérique - Audition parlementaires en mission	2016-03-29 15:00:00	2016-03-29 16:00:00	\N	\N	3	0	\N	\N
78918	GIA	AUCUNE	\N	\N	\N	GIA Jordanie	Groupe interparlementaire Jordanie	2016-03-30 12:30:00	2016-03-30 14:30:00	\N	\N	11	0	659	\N
80049	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE - PJL "Action logement"	Audition Rapporteur CAE 	2016-03-31 08:15:00	2016-03-31 09:30:00	\N	\N	1	0	\N	\N
80063	GIA	AUCUNE	\N	\N	\N	GIA Bulgarie	Groupe interparlementaire Bulgarie	2016-03-30 12:30:00	2016-03-30 14:30:00	\N	\N	4	0	582	\N
80073	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Auditions rapporteur SOCI	GT handicap	2016-03-30 15:00:00	2016-03-30 19:00:00	\N	\N	2	0	\N	\N
80078	COM_SPECIALE	PLENIERE	\N	COMSPEAPU	\N	Commission spéciale chargée du contrôle des comptes 	Commission spéciale chargée du contrôle des comptes 	2016-03-31 11:15:00	2016-03-31 12:45:00	2016-03-31 18:04:07	2016-04-01 09:13:19	8	0	\N	\N
80091	DELEGATION	AUCUNE	\N	\N	206	Biotechnologies	Audition publique biotechnologies	2016-04-07 09:00:00	2016-04-07 13:15:00	2016-04-08 12:34:19	2016-04-08 14:24:18	4	0	\N	\N
80092	DELEGATION	AUCUNE	\N	\N	206	 Maladies à transmission vectorielle	Audition publqiue sur les maladies à transmission vectorielle	2016-04-07 14:35:00	2016-04-07 19:45:00	2016-04-08 13:02:56	2016-04-08 14:24:16	6	0	\N	\N
80113	GIA	AUCUNE	\N	\N	\N	GIA Roumanie	Groupe interparlementaire Roumanie	2016-03-29 20:00:00	2016-03-29 22:00:00	\N	\N	10	0	605	\N
80158	ETUDES	AUCUNE	\N	\N	\N	GE Forêt et filière bois	Groupe d'études Forêt et filière bois	2016-03-31 08:30:00	2016-03-31 09:30:00	\N	\N	17	0	\N	948
80159	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-03-31 16:15:00	2016-03-31 17:00:00	\N	\N	1	0	\N	\N
80179	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle financement sûreté aérienne - DGAC 	2016-03-29 17:30:00	2016-03-29 19:30:00	\N	\N	1	0	\N	\N
80181	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle financemement sûreté aérienne - UAF	2016-03-31 10:00:00	2016-03-31 11:00:00	\N	\N	1	0	\N	\N
80183	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-03-29 15:45:00	2016-03-29 16:45:00	\N	\N	4	0	\N	\N
80188	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-03-30 15:05:00	2016-03-30 16:05:00	\N	\N	5	0	\N	\N
80194	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	ir France KLM	2016-03-31 11:00:00	2016-03-31 12:00:00	\N	\N	1	0	\N	\N
80196	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-03-30 17:00:00	2016-03-30 18:00:00	\N	\N	1	0	\N	\N
80198	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle financement sûreté aérienne - Air France/KLM	2016-03-31 16:00:00	2016-03-31 17:00:00	\N	\N	1	0	\N	\N
80199	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-03-29 14:15:00	2016-03-29 15:45:00	\N	\N	2	0	\N	\N
80202	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Contrôle APD 2016 - AFD/CDC	Audition Rapporteur FINC - Contrôle APD 	2016-03-29 16:30:00	2016-03-29 17:00:00	\N	\N	2	0	\N	\N
80206	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Controle APD 2016 - AFD/CDC	Audition Rapporteur FINC - Contrôle APD 	2016-03-30 16:45:00	2016-03-30 18:00:00	\N	\N	2	0	\N	\N
80209	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PJL numérique - Audition ministère de l'intérieur	2016-03-31 11:00:00	2016-03-31 12:00:00	\N	\N	1	0	\N	\N
80211	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PJL numérique - Audition de Winamax	2016-03-31 12:00:00	2016-03-31 13:00:00	\N	\N	1	0	\N	\N
80213	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PJL numérique - Audition de MM. Durain et Salles	2016-03-29 15:00:00	2016-03-29 16:00:00	\N	\N	1	0	\N	\N
80215	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2017 - Audition de la direction fiscale de Total	2016-03-29 15:00:00	2016-03-29 16:00:00	\N	\N	1	0	\N	\N
73309	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2016-03-15 14:30:00	2016-03-15 16:30:00	\N	\N	1	0	\N	\N
73356	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2016-03-15 16:00:00	2016-03-15 18:30:00	\N	\N	0	0	\N	\N
73516	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-03-16 12:35:00	2016-03-16 12:50:00	2018-05-18 14:37:55	2018-05-18 14:38:02	16	0	\N	\N
73517	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2016-03-15 09:00:00	2016-03-15 12:00:00	\N	\N	2	0	\N	\N
74116	BUREAU	AUCUNE	\N	\N	\N	Bureau	Réunion du Bureau	2016-03-17 09:00:00	2016-03-17 10:30:00	\N	\N	21	0	\N	\N
74164	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2016-03-16 11:20:00	2016-03-16 12:35:00	\N	\N	2	0	\N	\N
74174	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2016-03-17 08:30:00	2016-03-17 10:10:00	2016-03-17 12:15:09	2016-03-17 14:49:19	17	0	\N	\N
74383	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-03-15 10:00:00	2016-03-15 11:00:00	\N	\N	1	0	\N	\N
75009	GIA	AUCUNE	\N	\N	\N	GIA Mongolie	Groupe interparlementaire Mongolie	2016-03-17 12:00:00	2016-03-17 12:50:00	\N	\N	1	0	612	\N
75208	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat  Renseignement intérieur	Débat  Renseignement intérieur	2016-03-24 14:30:00	2016-03-24 16:00:00	\N	\N	0	0	\N	\N
75209	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Filière agroalimentaire	PPL Filière agroalimentaire 	2016-03-23 16:50:00	2016-03-23 20:00:00	\N	\N	87	0	\N	\N
75212	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Économie bleue	PPL Économie bleue	2016-03-23 21:30:00	2016-03-24 00:05:00	\N	\N	39	0	\N	\N
75222	GIA	AUCUNE	\N	\N	\N	GIA Afghanistan	Groupe interparlementaire Afghanistan	2016-03-17 14:00:00	2016-03-17 15:00:00	\N	\N	1	0	648	\N
75285	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	contrôle APD 2016	2016-03-16 10:00:00	2016-03-16 11:00:00	\N	\N	2	0	\N	\N
75304	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle APD 2016 CDC/AFD	2016-03-14 11:00:00	2016-03-14 11:30:00	\N	\N	2	0	\N	\N
75316	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle APD 2016 CDC/AFD	2016-03-14 11:30:00	2016-03-14 12:00:00	\N	\N	2	0	\N	\N
75322	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle APD 2016 CDC/AFD 	2016-03-14 12:00:00	2016-03-14 13:45:00	\N	\N	2	0	\N	\N
75329	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle APD 2016 CDC/AFD 	2016-03-14 15:45:00	2016-03-14 17:40:00	\N	\N	2	0	\N	\N
75335	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle APD 2016 CDC/AFD 	2016-03-15 14:15:00	2016-03-15 15:15:00	\N	\N	2	0	\N	\N
75341	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle APD 2016 CDC/AFD 	2016-03-16 14:30:00	2016-03-16 15:55:00	\N	\N	2	0	\N	\N
75346	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle APD 2016 CDC/AFD 	2016-03-16 16:00:00	2016-03-16 16:55:00	\N	\N	2	0	\N	\N
75614	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle 58-2 JDC 	2016-02-08 09:00:00	2016-02-08 12:50:00	\N	\N	1	0	\N	\N
75632	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle 58-2 JDC 	2016-02-08 13:35:00	2016-02-08 16:50:00	\N	\N	1	0	\N	\N
75695	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2016 - RCT 	2015-11-05 09:15:00	2015-11-05 10:00:00	\N	\N	2	0	\N	\N
75709	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2016 - Solidarité 	2015-11-09 10:30:00	2015-11-09 11:30:00	\N	\N	1	0	\N	\N
75725	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle budgétaire sur les élections 	2016-02-04 16:00:00	2016-02-04 17:00:00	\N	\N	1	0	\N	\N
76491	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-03-22 17:55:00	2016-03-22 19:15:00	2016-03-23 10:00:09	2016-03-23 10:38:39	27	0	\N	\N
77211	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2016 - Airbus	2015-11-03 15:00:00	2015-11-03 16:00:00	\N	\N	2	0	\N	\N
77214	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2016 - Recherche et enseignement supérieur - IRSTEA	2015-11-12 18:00:00	2015-11-12 19:00:00	\N	\N	1	0	\N	\N
77223	MISSION	AUCUNE	\N	ISLAM	\N	MI organisation, place et financement de l'Islam en France 	MI organisation, place et financement de l'Islam en France 	2016-03-23 14:35:00	2016-03-23 16:40:00	2016-03-23 17:29:04	2016-03-23 17:44:43	14	0	\N	\N
77685	GIA	AUCUNE	\N	\N	\N	GIA Israël	Accueil délégation israélienne - Déjeuner	2016-03-23 12:30:00	2016-03-23 14:00:00	\N	\N	14	0	595	\N
77700	GIA	AUCUNE	\N	\N	\N	GIA Israël	Accueil délégation israélienne - Réunion de travail - Lutte contre le terrorisme	2016-03-23 15:30:00	2016-03-23 16:30:00	\N	\N	3	0	595	\N
73226	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-03-16 09:40:00	2016-03-16 12:35:00	2018-05-18 14:36:40	2018-05-18 14:36:47	45	0	\N	\N
77704	GIA	AUCUNE	\N	\N	\N	GIA Israël	Accueil délégation israélienne - Réunion de travail - Commission affaires sociales	2016-03-23 16:30:00	2016-03-23 18:00:00	\N	\N	8	0	595	\N
77713	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2016-03-24 11:15:00	2016-03-24 12:35:00	\N	\N	2	0	\N	\N
77716	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE - Avis PJL "République numérique"	Audition Rapporteur CAE 	2016-03-23 16:30:00	2016-03-23 19:00:00	\N	\N	2	0	\N	\N
77718	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE - PJL Action logement	Audition Rapporteur CAE 	2016-03-23 08:30:00	2016-03-23 09:30:00	\N	\N	1	0	\N	\N
77720	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	GT CDD - Application loi sur l'eau	Groupe de travail CDD 	2016-03-24 14:00:00	2016-03-24 15:00:00	\N	\N	1	0	\N	\N
77722	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	CDD	\N	CDD - GE Déchets	CDD 	2016-03-22 14:00:00	2016-03-22 15:00:00	\N	\N	11	0	\N	\N
77739	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	CAE	\N	CAE - GE Cheval	CAE 	2016-03-23 08:15:00	2016-03-23 09:30:00	\N	\N	5	0	\N	\N
78011	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle budgétaire "Engagements financiers de l'État" - Banques SVT	2016-03-24 10:30:00	2016-03-24 11:30:00	\N	\N	1	0	\N	\N
78013	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle budgétaire "Culture"	2016-03-25 11:00:00	2016-03-25 12:00:00	\N	\N	1	0	\N	\N
78015	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle budgétaire "Culture"	2016-03-25 15:00:00	2016-03-25 16:00:00	\N	\N	1	0	\N	\N
78017	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2017 - Fonds d'urgence pour le spectacle vivant	2016-03-25 16:00:00	2016-03-25 16:45:00	\N	\N	2	0	\N	\N
78020	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PJL Numérique - Déplacement Gamers Assembly (Poitiers)	2016-03-26 09:30:00	2016-03-26 15:30:00	\N	\N	1	0	\N	\N
78049	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2016-03-20 21:00:00	2016-03-20 23:00:00	\N	\N	2	0	\N	\N
78052	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2016-03-21 09:00:00	2016-03-21 18:00:00	\N	\N	2	0	\N	\N
78055	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2016-03-22 11:30:00	2016-03-22 20:00:00	\N	\N	2	0	\N	\N
78058	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2016-03-23 09:30:00	2016-03-23 14:30:00	\N	\N	2	0	\N	\N
78061	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2016-03-24 11:00:00	2016-03-24 14:45:00	\N	\N	2	0	\N	\N
78064	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-03-22 10:15:00	2016-03-22 11:15:00	\N	\N	1	0	\N	\N
78068	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-03-22 19:00:00	2016-03-22 20:15:00	\N	\N	1	0	\N	\N
78071	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-03-23 16:30:00	2016-03-23 17:15:00	\N	\N	1	0	\N	\N
78814	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2016-03-29 17:05:00	2016-03-29 18:40:00	2016-03-30 15:46:52	2016-03-30 15:49:44	10	0	\N	\N
80217	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT FINC Transport	Groupe de travail FINC Financement des infrastructures de transport	2016-03-29 16:00:00	2016-03-29 17:30:00	\N	\N	8	0	\N	\N
80226	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	 Engagements financiers de l'État  - Banques SVT	2016-03-29 17:25:00	2016-03-29 18:15:00	\N	\N	1	0	\N	\N
80228	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Culture	Audition Rapporteur FINC - Culture 	2016-03-30 14:30:00	2016-03-30 15:40:00	\N	\N	1	0	\N	\N
80230	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Culture	Audition Rapporteur FINC - Culture 	2016-03-31 16:15:00	2016-03-31 17:30:00	\N	\N	1	0	\N	\N
80280	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2016-03-30 15:00:00	2016-03-30 16:40:00	\N	\N	3	0	\N	\N
80359	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle budgétaire Défense - 2016 - Audition major général de l'armée de terre	2016-03-29 15:00:00	2016-03-29 16:00:00	\N	\N	1	0	\N	\N
72999	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2016-03-16 10:35:00	2016-03-16 12:20:00	2018-05-18 14:37:20	2018-05-18 14:37:25	61	0	\N	\N
73649	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-03-15 16:15:00	2016-03-15 17:30:00	\N	\N	2	0	\N	\N
75091	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-03-18 09:00:00	2016-03-18 12:10:00	\N	\N	1	0	\N	\N
75112	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-03-18 14:00:00	2016-03-18 18:45:00	\N	\N	1	0	\N	\N
75134	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. PLF 2016	Aud. Rapp. PLF 2016 - DGCL	2015-11-03 14:30:00	2015-11-03 16:10:00	\N	\N	2	0	\N	\N
75137	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. PLF 2016	Aud. Rapp. PLF 2016 - Cabinet Ressources consultants	2015-11-04 18:00:00	2015-11-04 19:45:00	\N	\N	2	0	\N	\N
75140	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC  - Contrôle APD 2016 CDC/AFD	Aud. Rapp. FINC  - Contrôle APD 2016 CDC/AFD	2016-02-09 15:00:00	2016-02-09 16:20:00	\N	\N	2	0	\N	\N
75143	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Contrôle APD 2016 CDC/AFD	Aud. Rapp. FINC - Contrôle APD 2016 CDC/AFD	2016-02-10 08:30:00	2016-02-10 09:35:00	\N	\N	2	0	\N	\N
75146	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Groupe de travail DGF	Aud. Rapp. FINC - Groupe de travail DGF	2016-02-10 16:15:00	2016-02-10 19:00:00	\N	\N	2	0	\N	\N
75149	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Groupe de travail DGF	Aud. Rapp. FINC - Groupe de travail DGF	2016-02-11 11:00:00	2016-02-11 13:00:00	\N	\N	2	0	\N	\N
75152	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Groupe de travail DGF	Aud. Rapp. FINC - Groupe de travail DGF	2016-02-16 10:00:00	2016-02-16 11:05:00	\N	\N	2	0	\N	\N
75155	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Contrôle APD 2016 CDC/AFD	Aud. Rapp. FINC - Contrôle APD 2016 CDC/AFD	2016-02-24 14:30:00	2016-02-24 15:20:00	\N	\N	2	0	\N	\N
75158	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Contrôle APD 2016 CDC/AFD	Aud. Rapp. FINC - Contrôle APD 2016 CDC/AFD	2016-02-24 15:20:00	2016-02-24 16:10:00	\N	\N	2	0	\N	\N
75161	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Contrôle APD 2016 CDC/AFD	Aud. Rapp. FINC - Contrôle APD 2016 CDC/AFD	2016-03-01 10:00:00	2016-03-01 11:00:00	\N	\N	2	0	\N	\N
75164	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Contrôle APD 2016 CDC/AFD	Aud. Rapp. FINC - Contrôle APD 2016 CDC/AFD	2016-03-03 10:00:00	2016-03-03 11:05:00	\N	\N	2	0	\N	\N
75167	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC  - Contrôle APD 2016 CDC/AFD	Aud. Rapp. FINC  - Contrôle APD 2016 CDC/AFD	2016-03-03 11:30:00	2016-03-03 12:40:00	\N	\N	2	0	\N	\N
75170	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Contrôle APD 2016 CDC/AFD	Aud. Rapp. FINC - Contrôle APD 2016 CDC/AFD	2016-03-03 12:45:00	2016-03-03 13:15:00	\N	\N	2	0	\N	\N
75173	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Contrôle APD 2016 CDC/AFD	Aud. Rapp. FINC - Contrôle APD 2016 CDC/AFD	2016-03-03 13:35:00	2016-03-03 14:45:00	\N	\N	2	0	\N	\N
75176	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Contrôle APD 2016 CDC/AFD	Aud. Rapp. FINC - Contrôle APD 2016 CDC/AFD	2016-03-03 16:30:00	2016-03-03 17:30:00	\N	\N	2	0	\N	\N
75179	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Contrôle APD 2016 CDC/AFD	Aud. Rapp. FINC - Contrôle APD 2016 CDC/AFD	2016-03-09 15:00:00	2016-03-09 15:45:00	\N	\N	2	0	\N	\N
78316	DELEGATION	AUDRAP	\N	\N	206	Biotechnologies	Biotechnologies	2015-12-16 16:15:00	2015-12-16 19:00:00	\N	\N	2	0	\N	\N
75182	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Contrôle APD 2016 CDC/AFD	Aud. Rapp. FINC - Contrôle APD 2016 CDC/AFD	2016-03-09 15:45:00	2016-03-09 17:00:00	\N	\N	2	0	\N	\N
75185	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Contrôle APD 2016 CDC/AFD	Aud. Rapp. FINC - Contrôle APD 2016 CDC/AFD	2016-03-14 10:00:00	2016-03-14 11:00:00	\N	\N	2	0	\N	\N
75265	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Conf.  interparlementaire sur la stabilité, la coordination économique et la gouvernance au sein de l'UE (Bruxelles)	2016-02-16 10:00:00	2016-02-16 18:30:00	\N	\N	2	0	\N	\N
75270	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Conf. interparlementaire sur la stabilité, la coordination économique et la gouvernance au sein de l'UE (Bruxelles)	2016-02-17 09:00:00	2016-02-17 16:45:00	\N	\N	2	0	\N	\N
75273	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT FINC 	GT Financement des infrastructures de transport - Audition de M. Michel Savy	2016-03-08 15:10:00	2016-03-08 16:10:00	\N	\N	8	0	\N	\N
75300	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	GT Financement des infrastructures de transport - Audition Cour des comptes	2016-03-17 10:00:00	2016-03-17 11:20:00	\N	\N	8	0	\N	\N
75398	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - GT Plan aide Grèce	Audition  Rapporteur. Finances - Groupe de Travail Plan aide Grèce	2016-03-07 08:30:00	2016-03-07 09:30:00	\N	\N	2	0	\N	\N
75426	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - GT aide àla Grè	Audition Rapporteur FINC - Groupe de travail Aide à la Grèce	2016-03-07 10:00:00	2016-03-07 11:00:00	\N	\N	2	0	\N	\N
75473	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - GT aide à la Grèce	Audition Rapporteur FINC - Groupe de Travail aide à la Grèce	2016-03-07 11:15:00	2016-03-07 13:00:00	\N	\N	2	0	\N	\N
75542	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - GT Aide à la Grèce	Audition Rapporteur FINC - Groupe de travail Aide à la Grèce 	2016-03-07 13:15:00	2016-03-07 15:15:00	\N	\N	2	0	\N	\N
75679	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - GT aide à la Grèce	Audition Rapporteur FINC - Groupe de Travail Aide  à la Grèce	2016-03-07 16:00:00	2016-03-07 17:00:00	\N	\N	2	0	\N	\N
75700	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - GT aide à la Grèce	Audition Rapporteur FINC - Groupe de travail Aide à la Grèce 	2016-03-07 19:00:00	2016-03-07 20:00:00	\N	\N	2	0	\N	\N
75712	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - GT aide à la Grèce	Audition Rapporteur FINC  - Groupe de travail aide à la Grèce	2016-03-07 17:30:00	2016-03-07 18:30:00	\N	\N	2	0	\N	\N
75721	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - GT Aide à la Grèce	Audition Rapporteur FINC - Groupe de Travail Aide à la Grèce 	2016-03-07 20:30:00	2016-03-07 23:00:00	\N	\N	2	0	\N	\N
75738	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - GT Aide à la Grèce	Audition Rapporteur FINC - Groupe de travail Aide à la Grèce 	2016-03-08 09:00:00	2016-03-08 10:00:00	\N	\N	2	0	\N	\N
75742	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - GT Aide à la Grèce	Audition Rapporteur FINC- Groupe de travail Aide à la Grèce 	2016-03-08 10:30:00	2016-03-08 11:30:00	\N	\N	2	0	\N	\N
75746	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Conf. interparlementaire	Audition Rapporteur FINC - Conférence interparlementaire Luxembourg 	2015-11-10 08:30:00	2015-11-10 18:00:00	\N	\N	2	0	\N	\N
76860	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-03-23 08:30:00	2016-03-23 09:30:00	2016-03-23 15:45:50	2016-03-23 16:18:23	39	0	\N	\N
77493	DELEGATION	AUCUNE	\N	\N	211	Droits des femmes 	Droits des femmes 	2016-03-24 08:30:00	2016-03-24 10:50:00	2016-03-24 15:07:40	2016-03-24 18:41:56	8	0	\N	\N
77511	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Politique des territoires - FNADT	Audition Contrôle Politique des territoires 2016 -  FNADT - Assemblée des régions de France	2016-03-23 14:00:00	2016-03-23 15:00:00	\N	\N	1	0	\N	\N
77573	MISSION	AUDRAP	\N	ISLAM	\N	Aud. Rapp. MI organisation, place et financement de l'Islam 	Audition Rapporteur MI organisation, place et financement de l'Islam en France 	2016-03-24 10:00:00	2016-03-24 12:15:00	\N	\N	2	0	\N	\N
77576	MISSION	AUDRAP	\N	ISLAM	\N	Aud. Rapp. MI organisation, place et financement de l'Islam 	Audition Rapporteur MI organisation, place et financement de l'Islam en France 	2016-03-24 15:00:00	2016-03-24 16:30:00	\N	\N	1	0	\N	\N
77592	GIA	AUCUNE	\N	\N	\N	GIA Grèce	Groupe interparlementaire Grèce	2016-03-21 14:30:00	2016-03-21 18:30:00	\N	\N	2	0	591	\N
77598	GIA	AUCUNE	\N	\N	\N	GIA Japon	Groupe interparlementaire Japon	2016-03-09 08:30:00	2016-03-09 09:45:00	\N	\N	6	0	596	\N
77619	GIA	AUCUNE	\N	\N	\N	GIA Mexique-Pays d'Am. Centrale	Groupe interparlementaire Mexique-Pays d'Am. Centrale	2016-03-17 09:30:00	2016-03-17 10:30:00	\N	\N	1	0	643	\N
77621	GIA	AUCUNE	\N	\N	\N	GIA Mexique-Pays d'Am. Centrale	Groupe interparlementaire Mexique-Pays d'Am. Centrale	2016-03-22 14:00:00	2016-03-22 15:00:00	\N	\N	3	0	643	\N
77625	GIA	AUCUNE	\N	\N	\N	GIA Mexique-Pays d'Am. Centrale	Groupe interparlementaire Mexique-Pays d'Am. Centrale	2016-03-22 17:45:00	2016-03-22 19:00:00	\N	\N	4	0	643	\N
73078	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2016-03-16 09:30:00	2016-03-16 12:30:00	2016-03-16 17:04:35	2016-03-16 17:14:50	41	0	\N	\N
75213	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	 Rdv CCI Paris	2015-11-10 18:00:00	2015-11-10 18:30:00	\N	\N	1	0	\N	\N
75215	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Rdv Taj et Carrefour 	2015-11-17 14:00:00	2015-11-17 15:00:00	\N	\N	2	0	\N	\N
75327	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle budgétaire sur les subventions de l'Etat aux fédérations sportives - Audition FF Badminton	2015-11-05 09:00:00	2015-11-05 10:00:00	\N	\N	1	0	\N	\N
75334	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle 58-2 de la Cour des comptes sur l'AEFE - Audition magistrats	2016-02-02 15:00:00	2016-02-02 16:10:00	\N	\N	1	0	\N	\N
75355	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2016 mission "Enseignement scolaire" Préparation PLF	2015-11-04 15:30:00	2015-11-04 16:30:00	\N	\N	1	0	\N	\N
75377	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2016 - Préparation PLF	2015-11-04 08:00:00	2015-11-04 09:00:00	\N	\N	1	0	\N	\N
75389	COM_PERMANENTE	AUDRAP	\N	FINC	\N	FINC 	Contrôle budgétaire - Audition cabinet de la ministre de l'éducation nationale	2016-03-02 16:00:00	2016-03-02 17:00:00	\N	\N	1	0	\N	\N
76766	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2016-03-23 09:35:00	2016-03-23 12:25:00	2018-05-18 14:38:34	2018-05-18 14:38:40	36	0	\N	\N
76877	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Auditions rapporteur SOCI	GT Handicap	2016-03-23 15:30:00	2016-03-23 16:30:00	\N	\N	1	0	\N	\N
77562	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PJL 2016 - Audition Etat-major de la marine	2015-11-03 15:00:00	2015-11-03 16:00:00	\N	\N	1	0	\N	\N
77601	MECSS	AUDRAP	\N	\N	MECSS	MECSS  Médecine de ville en Allemagne	MECSS  Médecine de ville en Allemagne	2016-03-31 16:00:00	2016-03-31 18:00:00	\N	\N	2	0	\N	\N
77616	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-03-23 15:00:00	2016-03-23 17:30:00	\N	\N	2	0	\N	\N
77630	GIA	AUCUNE	\N	\N	\N	GIA Turquie	Groupe interparlementaire Turquie	2016-03-23 08:00:00	2016-03-23 09:10:00	\N	\N	5	0	624	\N
78319	DELEGATION	AUDRAP	\N	\N	206	Biotechnologies	Biotechnologies	2016-01-19 18:30:00	2016-01-19 20:00:00	\N	\N	2	0	\N	\N
77641	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle CICE - Mission "Remboursements et dégrèvements" - Audition CCI Paris-Ile-de-France	2016-03-24 14:30:00	2016-03-24 16:00:00	\N	\N	1	0	\N	\N
77643	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle CICE - Mission "Remboursements et dégrèvements" - Audition Bpifrance	2016-03-24 16:00:00	2016-03-24 17:40:00	\N	\N	1	0	\N	\N
77645	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2016-03-23 21:50:00	2016-03-23 22:00:00	2016-03-25 13:03:11	2016-03-25 16:10:34	10	0	\N	\N
77761	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Groupe de travail - DGF	Réforme de la DGF - Articulation de la réforme DGF avec la baisse des dotations	2016-03-24 16:30:00	2016-03-24 18:00:00	\N	\N	2	0	\N	\N
77764	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Groupe de travail - DGF	Groupe de travail DGF - Articulation de la réforme DGF avec la baisse des dotations - Préparation - Audition ministres 	2016-03-24 18:00:00	2016-03-24 19:00:00	\N	\N	13	0	\N	\N
77782	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Groupe de travail DGF	Groupe de travail DGF - Articulation de la réforme DGF avec la baisse des dotations - Audition ministres Baylet/DGF	2016-03-24 19:00:00	2016-03-24 20:20:00	\N	\N	12	0	\N	\N
77795	DELEGATION	AUCUNE	\N	\N	DSOM	Outre-mer 	Outre-mer 	2016-04-07 10:30:00	2016-04-07 11:45:00	2016-04-08 12:46:34	2016-04-08 14:16:49	9	0	\N	\N
77797	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle Paris-Saclay - Audition Délégation régionale à la recherche et à la technologie pour la région Ile-de-France	2016-03-24 17:00:00	2016-03-24 18:45:00	\N	\N	1	0	\N	\N
77799	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle MIRES 2016 - Paris Saclay - Audition Direction générale de la recherche et de l'innovation (Min. Educ. Nat.)	2016-03-24 15:30:00	2016-03-24 16:30:00	\N	\N	1	0	\N	\N
77801	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-03-24 11:00:00	2016-03-24 13:10:00	\N	\N	1	0	\N	\N
77803	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-03-24 17:00:00	2016-03-24 19:20:00	\N	\N	1	0	\N	\N
77805	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-03-25 09:00:00	2016-03-25 12:30:00	\N	\N	1	0	\N	\N
77939	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2016-03-29 14:30:00	2016-03-29 15:05:00	2016-03-30 14:53:05	2016-03-30 15:48:14	24	0	\N	\N
78029	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-03-23 09:00:00	2016-03-27 08:00:00	\N	\N	2	0	\N	\N
78232	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-03-29 15:00:00	2016-03-29 18:10:00	\N	\N	1	0	\N	\N
78234	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPLO et PPL Élection présidentielle	PPLO et PPL Élections présidentielles	2016-03-31 10:30:00	2016-03-31 12:00:00	\N	\N	75	0	\N	\N
78235	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Lutte contre le crime organisé	PJL Lutte contre le crime organisé	2016-03-31 12:20:00	2016-03-31 13:05:00	\N	\N	53	0	\N	\N
78236	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Lutte contre le crime organisé	PJL Lutte contre le crime organisé	2016-03-31 16:25:00	2016-03-31 19:25:00	\N	\N	49	0	\N	\N
78238	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au Gouvernement	Questions d'actualité au Gouvernement	2016-03-31 15:00:00	2016-03-31 16:15:00	\N	\N	223	0	\N	\N
78240	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition 	Audition de M. Macron	2016-03-29 16:35:00	2016-03-29 18:20:00	2018-05-18 14:39:34	2018-05-18 14:39:41	27	0	\N	\N
78305	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2017 - Audition du service des retraites de l'Etat	2016-03-29 14:00:00	2016-03-29 14:30:00	\N	\N	1	0	\N	\N
78312	QUESTURE	AUCUNE	\N	\N	\N	Questure	Réunion de Questure	2016-03-29 14:15:00	2016-03-29 16:15:00	\N	\N	3	0	\N	\N
78329	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au Gouvernement	Questions d'actualité au Gouvernement	2016-04-05 16:45:00	2016-04-05 17:35:00	\N	\N	299	0	\N	\N
78330	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Hooligans	PPL Hooligans	2016-04-05 17:50:00	2016-04-05 19:20:00	\N	\N	39	0	\N	\N
78333	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Hooligans	PPL Hooligans	2016-04-05 21:35:00	2016-04-06 00:50:00	\N	\N	58	0	\N	\N
78335	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Déontologie fonctionnaires	CMP Déontologie fonctionnaires	2016-04-07 18:45:00	2016-04-07 19:45:00	\N	\N	12	0	\N	\N
78336	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Protection des mineurs	CMP Protection des mineurs	2016-04-06 21:30:00	2016-04-06 22:30:00	\N	\N	14	0	\N	\N
78340	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	CAE 	2016-03-30 09:35:00	2016-03-30 11:25:00	2018-05-18 14:40:16	2018-05-18 14:40:26	32	0	\N	\N
78390	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2016-03-30 09:00:00	2016-03-30 11:00:00	2016-03-30 12:35:38	2016-03-30 14:35:00	30	0	\N	\N
78620	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Auditions	Turquie + M. Bertolotti ambassadeur	2016-03-30 09:35:00	2016-03-30 12:10:00	2016-03-30 15:19:39	2016-03-30 15:48:10	39	0	\N	\N
78749	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2016-03-29 17:30:00	2016-03-29 19:30:00	\N	\N	1	0	\N	\N
78892	GIA	AUCUNE	\N	\N	\N	GIA Pakistan	Groupe interparlementaire Pakistan	2016-03-30 08:15:00	2016-03-30 09:30:00	\N	\N	8	0	619	\N
78901	GIA	AUCUNE	\N	\N	\N	GIA Pakistan	Groupe interparlementaire Pakistan	2016-03-30 13:00:00	2016-03-30 14:30:00	\N	\N	3	0	619	\N
78916	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2016-03-30 15:30:00	2016-03-30 17:00:00	\N	\N	1	0	\N	\N
79404	GIA	AUCUNE	\N	\N	\N	GIA Egypte	Groupe interparlementaire Egypte	2016-03-31 08:45:00	2016-03-31 09:30:00	\N	\N	5	0	617	\N
79411	GIA	AUCUNE	\N	\N	\N	GIA Moldavie	Groupe interparlementaire Moldavie	2016-03-30 18:00:00	2016-03-30 20:00:00	\N	\N	4	0	851	\N
79720	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-03-30 15:00:00	2016-03-30 16:20:00	\N	\N	5	0	\N	\N
79728	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-03-30 16:15:00	2016-03-30 17:00:00	\N	\N	3	0	\N	\N
79732	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-03-31 09:30:00	2016-03-31 10:45:00	\N	\N	2	0	\N	\N
79739	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-03-29 15:30:00	2016-03-29 16:30:00	\N	\N	2	0	\N	\N
79742	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-03-31 10:30:00	2016-03-31 11:30:00	\N	\N	2	0	\N	\N
80071	DELEGATION	AUCUNE	\N	\N	COLTER	Collectivités  territoriales 	Collectivités  territoriales 	2016-04-07 14:00:00	2016-04-07 15:00:00	2016-04-07 15:07:53	2016-04-08 14:16:28	4	0	\N	\N
72861	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJLC Protection de la Nation	PJLC Protection de la Nation	2016-03-17 16:20:00	2016-03-17 20:20:00	\N	\N	120	0	\N	\N
74647	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-03-16 14:00:00	2016-03-16 15:05:00	\N	\N	5	0	\N	\N
78681	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2016-03-30 09:30:00	2016-03-30 12:10:00	2016-03-30 15:51:17	2016-03-30 17:48:32	53	0	\N	\N
74657	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-03-16 15:05:00	2016-03-16 16:10:00	\N	\N	5	0	\N	\N
74663	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-03-16 16:35:00	2016-03-16 17:55:00	\N	\N	5	0	\N	\N
74669	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-03-17 08:00:00	2016-03-17 09:30:00	\N	\N	2	0	\N	\N
75022	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-03-15 15:30:00	2016-03-15 15:45:00	\N	\N	1	0	\N	\N
75024	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-03-15 14:00:00	2016-03-15 21:15:00	\N	\N	1	0	\N	\N
75026	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-03-16 16:40:00	2016-03-16 18:30:00	\N	\N	1	0	\N	\N
75028	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-03-15 14:30:00	2016-03-15 17:00:00	\N	\N	1	0	\N	\N
75114	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-03-15 11:30:00	2016-03-15 12:30:00	\N	\N	2	0	\N	\N
75117	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-03-16 17:30:00	2016-03-16 18:30:00	\N	\N	2	0	\N	\N
75120	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-03-16 18:30:00	2016-03-16 19:30:00	\N	\N	2	0	\N	\N
75131	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Apprentissage	Audition Rapporteur SOCI 	2016-03-23 15:00:00	2016-03-23 16:00:00	\N	\N	1	0	\N	\N
75206	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2016 - Entretien général	2015-11-10 17:00:00	2015-11-10 17:30:00	\N	\N	1	0	\N	\N
75236	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2017 - DSAG et visite du site de Ségur-Fontenoy	2016-03-09 14:20:00	2016-03-09 17:00:00	\N	\N	1	0	\N	\N
75238	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2017 - Grande Chancellerie de la Légion d'honneur	2016-03-10 14:30:00	2016-03-10 16:30:00	\N	\N	1	0	\N	\N
75240	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT FINC 	Comité de pilotage Groupe de travail DGF	2016-03-09 16:30:00	2016-03-09 18:30:00	\N	\N	2	0	\N	\N
75254	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2017 - Défenseur des droits7 - 	2016-03-17 10:00:00	2016-03-17 11:00:00	\N	\N	1	0	\N	\N
75256	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-03-21 15:30:00	2016-03-21 19:30:00	\N	\N	1	0	\N	\N
75258	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - PLF 2016 - Numérique	PLF 2016 - Numérique  - au	2015-11-19 17:30:00	2015-11-19 18:30:00	\N	\N	6	0	\N	\N
75268	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2016 - Mission Economie	2015-11-23 09:00:00	2015-11-23 10:00:00	\N	\N	1	0	\N	\N
75274	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PJL Terrorisme	2016-01-20 16:00:00	2016-01-20 18:00:00	\N	\N	2	0	\N	\N
75277	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Convention fiscale Suisse	2016-02-18 08:00:00	2016-02-18 09:30:00	\N	\N	1	0	\N	\N
75279	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2017 	2016-03-02 16:00:00	2016-03-02 17:00:00	\N	\N	1	0	\N	\N
75281	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PJL Numérique	2016-03-03 09:00:00	2016-03-03 10:00:00	\N	\N	1	0	\N	\N
75283	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Audition Rapporteur FINC 	2016-03-09 15:00:00	2016-03-09 16:00:00	\N	\N	1	0	\N	\N
75288	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PJL Numérique 	2016-03-09 16:30:00	2016-03-09 17:30:00	\N	\N	1	0	\N	\N
75290	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PJL Numérique - Audition SELL (Syndicat des Editeurs de Logiciels de Loisirs)	2016-03-10 15:00:00	2016-03-10 16:00:00	\N	\N	1	0	\N	\N
75303	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PJL Numérique -Audition cabinent Axelle Lemaire, secrétaire d'Etat chargée du numérique	2016-03-10 16:00:00	2016-03-10 17:00:00	\N	\N	1	0	\N	\N
75339	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Audition Rapporteur FINC 	2016-03-10 17:00:00	2016-03-10 18:30:00	\N	\N	1	0	\N	\N
75357	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2016 - Contrôle et exploitation aériens	2015-11-02 13:00:00	2015-11-02 15:00:00	\N	\N	1	0	\N	\N
75387	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2016 - Contrôle et exploitation aériens	2015-11-03 10:15:00	2015-11-03 11:15:00	\N	\N	1	0	\N	\N
75407	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2016 - Contrôle et exploitation aériens	2015-11-05 09:00:00	2015-11-05 10:00:00	\N	\N	1	0	\N	\N
75442	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2016 - Contrôle et exploitation aériens	2015-11-05 10:00:00	2015-11-05 11:00:00	\N	\N	1	0	\N	\N
75484	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2016 - Contrôle et exploitation aériens	2015-11-06 11:00:00	2015-11-06 13:00:00	\N	\N	1	0	\N	\N
75489	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2016 - Météorologie	2015-11-03 09:00:00	2015-11-03 10:00:00	\N	\N	1	0	\N	\N
75628	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Audition Rapporteur FINC 	2015-11-06 10:00:00	2015-11-06 11:00:00	\N	\N	1	0	\N	\N
75750	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle budgétaire  Réunion de cadrage 58-2 ° archives nationales avec la Cour des comptes	2016-01-27 14:05:00	2016-01-27 14:55:00	\N	\N	2	0	\N	\N
75753	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT FINC 	Financement des infrastructures de transport	2016-03-22 14:00:00	2016-03-22 15:30:00	\N	\N	4	0	\N	\N
76536	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Économie bleue	PPL Économie bleue	2016-03-24 14:30:00	2016-03-24 20:15:00	\N	\N	40	0	\N	\N
76537	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Économie bleue	PPL Économie bleue	2016-03-24 20:30:00	2016-03-25 00:30:00	\N	\N	0	0	\N	\N
77266	QUESTURE	AUCUNE	\N	\N	\N	Questure	Réunion de Questure	2016-03-22 18:00:00	2016-03-22 19:30:00	\N	\N	3	0	\N	\N
77280	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	GT simplification nprmes	GT simplification normes	2016-03-23 14:00:00	2016-03-23 15:00:00	\N	\N	5	0	\N	\N
77286	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	GT simplification normes	GT simplification normes	2016-03-23 15:00:00	2016-03-23 16:00:00	\N	\N	5	0	\N	\N
77292	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	GT simplification normes	GT simplification normes	2016-03-23 16:00:00	2016-03-23 17:00:00	\N	\N	4	0	\N	\N
77580	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Lutte contre le crime organisé	PJL Lutte contre le crime organisé	2016-03-29 14:30:00	2016-03-29 19:30:00	\N	\N	157	0	\N	\N
77581	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Lutte contre le crime organisé	PJL Lutte contre le crime organisé	2016-03-29 21:30:00	2016-03-29 23:25:00	\N	\N	68	0	\N	\N
78328	DELEGATION	AUDRAP	\N	\N	206	Biotechnologies	Biotechnologies	2016-02-04 09:30:00	2016-02-04 11:00:00	\N	\N	2	0	\N	\N
78334	DELEGATION	AUDRAP	\N	\N	206	Biotechnologies	Biotechnologies	2016-02-09 17:00:00	2016-02-09 20:00:00	\N	\N	2	0	\N	\N
78380	DELEGATION	AUDRAP	\N	\N	206	Biotechnologies	Biotechnologies	2016-02-16 18:00:00	2016-02-16 19:30:00	\N	\N	2	0	\N	\N
78383	DELEGATION	AUDRAP	\N	\N	206	Biotechnologies	Biotechnologies	2016-02-18 09:30:00	2016-02-18 12:30:00	\N	\N	2	0	\N	\N
78497	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2016-03-30 09:40:00	2016-03-30 12:05:00	2018-05-18 14:40:48	2018-05-18 14:40:55	30	0	\N	\N
72947	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-03-15 11:00:00	2016-03-15 12:30:00	\N	\N	1	0	\N	\N
73568	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE - PPL Agriculture 2ème lecture	Audition Rapporteur CAE 	2016-03-08 14:00:00	2016-03-08 15:00:00	\N	\N	1	0	\N	\N
73570	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE PPL Agriculture 2ème lecture	Audition Rapporteur CAE 	2016-03-10 08:00:00	2016-03-10 10:00:00	\N	\N	1	0	\N	\N
73572	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	GT CDD - Aménagement aéroportuaire	Groupe de travail CDD 	2016-03-08 12:00:00	2016-03-08 13:00:00	\N	\N	1	0	\N	\N
73574	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE - Avis République numérique	Audition Rapporteur CAE 	2016-03-09 15:00:00	2016-03-09 19:00:00	\N	\N	2	0	\N	\N
73576	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE - Avis République numérique	Audition Rapporteur CAE 	2016-03-10 09:30:00	2016-03-10 12:30:00	\N	\N	1	0	\N	\N
73578	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE - Avis République numérique	Audition Rapporteur CAE 	2016-03-10 14:30:00	2016-03-10 16:45:00	\N	\N	0	0	\N	\N
73579	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE - Avis République numérique	Audition Rapporteur CAE 	2016-03-15 14:30:00	2016-03-15 19:00:00	\N	\N	2	0	\N	\N
73581	ETUDES	AUCUNE	\N	\N	\N	GE Energie	Groupe d'études Energie	2016-03-16 08:15:00	2016-03-16 09:35:00	\N	\N	14	0	\N	906
73628	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	GT CDD - Mobilités et transports	Groupe de travail CDD 	2016-03-15 14:30:00	2016-03-15 16:40:00	\N	\N	3	0	\N	\N
73632	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	GT CDD - Aménagement du territoire	Groupe de travail CDD 	2016-03-15 18:00:00	2016-03-15 18:45:00	\N	\N	15	0	\N	\N
74155	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT transport	Financement des infrastructures de transport	2016-03-17 10:00:00	2016-03-17 11:20:00	\N	\N	4	0	\N	\N
74210	MISSION	AUCUNE	\N	ISLAM	\N	MI organisation, place et financement de l'Islam en France 	MI organisation, place et financement de l'Islam en France 	2016-03-17 13:35:00	2016-03-17 14:45:00	2016-03-17 14:46:27	2016-03-17 14:50:03	8	0	\N	\N
75073	DELEGATION	AUCUNE	\N	\N	DSOM	Outre-mer 	Outre-mer 	2016-03-24 14:30:00	2016-03-24 15:45:00	2016-03-24 16:24:22	2016-03-24 18:41:58	2	0	\N	\N
75076	DELEGATION	AUCUNE	\N	\N	DSOM	Outre-mer 	Outre-mer 	2016-03-31 09:30:00	2016-03-31 11:00:00	2016-03-31 12:01:14	2016-03-31 17:35:38	11	0	\N	\N
75077	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD PJL Numérique	Audition Rapporteur CDD PJL Numérique	2016-03-17 10:15:00	2016-03-17 10:45:00	\N	\N	1	0	\N	\N
75079	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD PJL Biodiversité/Préjudice écologique	Audition Rapporteur CDD PJL Biodiversité/Préjudice écologique 	2016-03-15 14:30:00	2016-03-15 16:00:00	\N	\N	2	0	\N	\N
75082	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD PJL Biodiversité/Préjudice écologique	Audition Rapporteur CDD PJL Biodiversité/Préjudice écologique	2016-03-16 16:00:00	2016-03-16 18:30:00	\N	\N	2	0	\N	\N
75085	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2016-03-17 08:30:00	2016-03-17 11:00:00	\N	\N	2	0	\N	\N
75088	GIA	AUCUNE	\N	\N	\N	GIA Australie	Groupe interparlementaire Australie	2016-03-17 11:30:00	2016-03-17 12:15:00	\N	\N	1	0	578	\N
75487	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2016 - MIRES - Table ronde des fédérations représentant l'enseignement privé	2015-11-03 10:30:00	2015-11-03 11:15:00	\N	\N	1	0	\N	\N
75490	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2016 - MIRES - Conférence des grandes écoles	2015-11-03 11:30:00	2015-11-03 12:15:00	\N	\N	1	0	\N	\N
75511	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2016 - Logement - ANAH	2015-11-05 09:35:00	2015-11-05 10:15:00	\N	\N	1	0	\N	\N
75528	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2016 - MIRES - CURIF	2015-11-10 10:45:00	2015-11-10 11:30:00	\N	\N	1	0	\N	\N
75579	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2016 - MIRES (Thierry Mandon, sec. d'Etat à l'enseignement supérieur et à la recherche)	2015-11-12 15:10:00	2015-11-12 16:10:00	\N	\N	1	0	\N	\N
75597	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2016 - Logement - Mission d'évaluation de la politique du logement	2015-11-10 16:30:00	2015-11-10 17:30:00	\N	\N	1	0	\N	\N
75647	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2016 - Politique de la ville - Cabinet M. P. Kanner, ministre de la ville	2015-11-26 16:35:00	2015-11-26 17:30:00	\N	\N	1	0	\N	\N
75670	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle "Conditions de maintien des droits des étudiants boursiers" (DGFIP et IGAENR)	2016-01-27 14:30:00	2016-01-27 15:30:00	\N	\N	1	0	\N	\N
75690	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle "Conditions de maintien des droits des étudiants boursiers" (CNOUS)	2016-02-03 17:30:00	2016-02-03 18:50:00	\N	\N	1	0	\N	\N
75697	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle "Conditions de maintien des droits des étudiants boursiers" (Visite centre universitaire de Troyes)	2016-02-05 10:20:00	2016-02-05 10:50:00	\N	\N	1	0	\N	\N
75710	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle "Conditions de maintien des droits des étudiants boursiers"  (Visite IUT de Troyes)	2016-02-05 10:50:00	2016-02-05 11:25:00	\N	\N	1	0	\N	\N
75724	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT FINC 	Contrôle "Conditions de maintien des droits des étudiants boursiers"  (Visite Université de technologie de Troyes)	2016-02-05 11:30:00	2016-02-05 12:00:00	\N	\N	1	0	\N	\N
75733	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle "Conditions de maintien des droits des étudiants boursiers"  (Visite Université de technologie de  Troyes)	2016-02-05 15:30:00	2016-02-05 18:00:00	\N	\N	1	0	\N	\N
75763	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-03-22 14:30:00	2016-03-22 15:10:00	\N	\N	1	0	\N	\N
76427	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PJL Numérique - Audition SIINDA (Search &  Information Industry Information) 	2016-03-17 14:00:00	2016-03-17 15:00:00	\N	\N	1	0	\N	\N
76429	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PJL Numérique - Audition France Générosités	2016-03-22 14:00:00	2016-03-22 15:00:00	\N	\N	1	0	\N	\N
76706	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2016-03-23 09:30:00	2016-03-23 11:40:00	2016-03-23 11:58:40	2016-03-23 15:20:13	41	0	\N	\N
80456	CMP	AUTRE	\N	DEONTOLOGIE	\N	DEONTOLOGIE 	DEONTOLOGIE 	2016-03-29 12:35:00	2016-03-29 14:05:00	\N	\N	9	0	\N	\N
76858	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Renseignement intérieur 	Débat Renseignement intérieur 	2016-03-23 14:30:00	2016-03-23 16:30:00	\N	\N	82	0	\N	\N
76962	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2016-03-23 09:00:00	2016-03-23 12:15:00	2016-03-23 14:45:10	2016-03-23 15:20:11	36	0	\N	\N
77095	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2016-03-22 14:15:00	2016-03-22 15:45:00	\N	\N	2	0	\N	\N
77415	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle APD 2016 CDC/AFD	2016-03-23 09:00:00	2016-03-23 09:40:00	\N	\N	2	0	\N	\N
77418	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle APD 2016 CDC/AFD	2016-03-23 14:00:00	2016-03-23 15:15:00	\N	\N	2	0	\N	\N
77421	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle APD 2016 CDC/AFD	2016-03-23 15:15:00	2016-03-23 16:30:00	\N	\N	2	0	\N	\N
77424	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle APD 2016 AFD/CDC	2016-03-23 18:05:00	2016-03-23 19:40:00	\N	\N	2	0	\N	\N
77427	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - CAS Patrimoine Immobilier de l'Etat	PLF 2017 - CAS Patrimoine immobilier de l'Etat - Déplacement Ecole d'architecture de Nanterre	2016-03-23 13:00:00	2016-03-23 15:45:00	\N	\N	2	0	\N	\N
77433	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Audition Rapporteur FINC 	2016-03-23 15:00:00	2016-03-23 16:30:00	\N	\N	1	0	\N	\N
77755	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PJL numérique - Audition Axelle Lemaire, secrétaire d'Etat chargée du numérique	2016-03-24 15:00:00	2016-03-24 16:30:00	\N	\N	1	0	\N	\N
77757	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PJL numérique - Audition Pierre Bellanger, PDG de Skyrock	2016-03-24 16:30:00	2016-03-24 17:30:00	\N	\N	1	0	\N	\N
77759	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PJL numérique - Audition mission IGF sur la TVA sur le e-commerce	2016-03-24 17:30:00	2016-03-24 18:30:00	\N	\N	1	0	\N	\N
77840	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT CAE 	Groupe de travail CAE 	2016-03-24 09:30:00	2016-03-24 10:30:00	\N	\N	1	0	\N	\N
77936	GIA	AUCUNE	\N	\N	\N	GIA Asie du Sud-Est	Groupe interparlementaire Asie du Sud-Est	2016-03-29 13:00:00	2016-03-29 15:00:00	\N	\N	1	0	609	\N
78434	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	GT CDD  - Mobilités et Transports	Groupe de travail CDD 	2016-03-29 17:30:00	2016-03-29 19:15:00	\N	\N	3	0	\N	\N
78438	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2016-03-30 09:30:00	2016-03-30 12:10:00	2016-03-30 12:42:22	2016-03-30 14:35:24	42	0	\N	\N
80406	MECSS	AUDRAP	\N	\N	MECSS	MECSS 	MECSS 	2016-04-06 16:30:00	2016-04-06 17:30:00	\N	\N	2	0	\N	\N
82414	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2016-04-05 18:15:00	2016-04-05 20:05:00	2016-04-06 10:37:37	2016-04-06 11:03:14	9	0	\N	\N
82537	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	CAE 	2016-04-05 17:50:00	2016-04-05 19:55:00	2018-05-18 14:42:43	2018-05-18 14:42:48	31	0	\N	\N
82626	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2016-04-05 18:00:00	2016-04-05 19:25:00	2016-04-06 14:11:49	2016-04-06 14:59:26	23	0	\N	\N
82932	ETUDES	AUCUNE	\N	\N	\N	GE Économie Sociale et Solidaire	Groupe d'études Économie Sociale et Solidaire	2016-04-05 08:45:00	2016-04-05 10:00:00	\N	\N	8	0	\N	998
82948	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2016-04-05 09:30:00	2016-04-05 11:00:00	\N	\N	1	0	\N	\N
83287	GIA	AUCUNE	\N	\N	\N	GIA Liban	Réunion du Bureau du Groupe interparlementaire Liban	2016-04-06 08:30:00	2016-04-06 09:30:00	\N	\N	3	0	597	\N
83291	MISSION	AUDRAP	\N	ISLAM	\N	Aud. Rapp. MI organisation, place et financement de l'Islam 	Audition Rapporteur MI organisation, place et financement de l'Islam en France 	2016-04-07 11:30:00	2016-04-07 12:30:00	\N	\N	3	0	\N	\N
83297	MISSION	AUDRAP	\N	ISLAM	\N	Aud. Rapp. MI organisation, place et financement de l'Islam 	Audition Rapporteur MI organisation, place et financement de l'Islam en France 	2016-04-07 14:00:00	2016-04-07 16:15:00	\N	\N	2	0	\N	\N
83303	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Entreprises 	Auditions Entreprises et droit du travail	2016-04-26 15:30:00	2016-04-26 17:05:00	\N	\N	3	0	\N	\N
83351	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2016-04-07 09:40:00	2016-04-07 11:05:00	2016-04-07 12:05:26	2016-04-07 12:06:09	20	0	\N	\N
83521	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT CAE 	Groupe de travail CAE 	2016-04-05 14:30:00	2016-04-05 15:30:00	\N	\N	6	0	\N	\N
83550	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle Mission Remboursements et dégrèvement - CICE - 2016 - Audition OFCE	2016-04-05 17:30:00	2016-04-05 19:00:00	\N	\N	1	0	\N	\N
83552	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle Mission Remboursements et dégrèvements -  CICE - 2016 - Audition Tax4Business	2016-04-06 14:25:00	2016-04-06 16:00:00	\N	\N	1	0	\N	\N
83618	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Audition PLF 2017  - Mission Culture - OPPIC - Mmes Mazoyer et Pouget	2016-04-06 15:30:00	2016-04-06 16:30:00	\N	\N	2	0	\N	\N
83626	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Audition PLF 2017 - Mission "Culture" -  RMN - Mmes Hubac et Vesque-Jencard	2016-04-06 16:30:00	2016-04-06 17:30:00	\N	\N	2	0	\N	\N
83632	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Audition PLF 2017 - Mission "Culture" - Le Louvre - Dpt Arts de l'Islam - Mme Lintz et M. Féau 	2016-04-06 17:30:00	2016-04-06 18:30:00	\N	\N	2	0	\N	\N
83639	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Application de la LFI 2016 - Audition DHUP	2016-04-05 13:00:00	2016-04-05 13:30:00	\N	\N	1	0	\N	\N
83641	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	58-2 Efficience des dépenses fiscales en faveur du développement durable 	2016-04-05 14:40:00	2016-04-05 15:15:00	\N	\N	1	0	\N	\N
84032	MECSS	AUDRAP	\N	\N	MECSS	MECSS travail dissimulé	MECSS travail dissimulé	2016-05-17 17:45:00	2016-05-17 18:45:00	\N	\N	2	0	\N	\N
84035	MECSS	AUDRAP	\N	\N	MECSS	MECSS travail dissimulé	MECSS travail dissimulé	2016-05-18 14:30:00	2016-05-18 16:30:00	\N	\N	2	0	\N	\N
84038	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Rapport d'information Maisons d'assistants maternels	Rapport d'information maisons d'assistants maternels	2016-05-10 16:00:00	2016-05-10 17:00:00	\N	\N	2	0	\N	\N
84041	GIA	AUCUNE	\N	\N	\N	Aucune 	Aucune 	2016-04-09 23:00:00	2016-04-20 12:00:00	\N	\N	4	0	978	\N
84046	GIA	AUCUNE	\N	\N	\N	GIA Europe du Nord	Groupe interparlementaire Europe du Nord	2016-04-17 19:15:00	2016-04-21 19:10:00	\N	\N	4	0	625	\N
84051	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle de la mission "Remboursements et dégrèvements" -2016 -  CICE - Déplacement DRFiP Bordeaux	2016-04-20 11:00:00	2016-04-20 13:00:00	\N	\N	1	0	\N	\N
84053	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle de la mission "Remboursements et dégrèvements" -2016 - CICE - Déplacement Constructions Navales de Bordeaux 	2016-04-20 14:30:00	2016-04-20 16:00:00	\N	\N	1	0	\N	\N
84055	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle de la mission "Remboursements et dégrèvements" -2016 - CICE - Aerospace Valley	2016-04-20 17:20:00	2016-04-20 20:15:00	\N	\N	1	0	\N	\N
107095	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Travail	PJL Travail	2016-06-21 21:35:00	2016-06-22 01:00:00	\N	\N	90	0	\N	\N
82584	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	CAE 	2016-04-06 09:35:00	2016-04-06 10:05:00	2016-04-06 12:32:15	2016-04-06 16:28:45	31	0	\N	\N
84057	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle de la mission "Remboursements et dégrèvements" -2016 - CICE - Déplacement CIC Sud-Ouest	2016-04-21 09:00:00	2016-04-21 10:35:00	\N	\N	1	0	\N	\N
84059	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle de la mission "Remboursements et dégrèvements" -2016 - CICE - Déplacement CDiscount - Bordeaux	2016-04-21 11:00:00	2016-04-21 13:00:00	\N	\N	1	0	\N	\N
84061	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle de la mission "Remboursements et dégrèvements" -2016 - CICE -SIE Bordeaux centre	2016-04-21 15:00:00	2016-04-21 18:30:00	\N	\N	1	0	\N	\N
84151	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur	Audition Rapporteur SOCI 	2016-04-27 16:30:00	2016-04-27 17:30:00	\N	\N	2	0	\N	\N
84159	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2016-04-26 09:05:00	2016-04-26 10:55:00	2018-05-18 14:44:12	2018-05-18 14:44:16	31	0	\N	\N
86870	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	CAE	\N	CAE  - Audition syndicats EDF	CAE 	2016-04-26 09:30:00	2016-04-26 10:40:00	\N	\N	12	0	\N	\N
86884	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE - APLOI Conso & Macron	Audition Rapporteur CAE 	2016-04-26 14:00:00	2016-04-26 17:00:00	\N	\N	4	0	\N	\N
86889	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE  - Logement	Audition Rapporteur CAE 	2016-04-27 14:30:00	2016-04-27 15:50:00	\N	\N	2	0	\N	\N
86893	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE - PJL Action logement	Audition Rapporteur CAE 	2016-04-28 14:00:00	2016-04-28 15:10:00	\N	\N	1	0	\N	\N
87175	DELEGATION	AUCUNE	\N	\N	DSOM	Outre-mer 	Outre-mer 	2016-05-12 09:00:00	2016-05-12 12:00:00	2016-05-12 17:58:14	2016-05-12 18:08:48	12	0	\N	\N
87176	DELEGATION	AUCUNE	\N	\N	DSOM	Outre-mer 	Outre-mer 	2016-05-12 16:15:00	2016-05-12 17:30:00	2016-05-12 18:03:16	2016-05-12 18:08:46	4	0	\N	\N
87326	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-05-03 11:00:00	2016-05-03 12:15:00	\N	\N	1	0	\N	\N
87878	GIA	AUCUNE	\N	\N	\N	GIA Malte	Groupe interparlementaire Malte	2016-05-03 14:30:00	2016-05-03 15:15:00	\N	\N	3	0	603	\N
92048	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-05-10 16:00:00	2016-05-10 18:00:00	\N	\N	5	0	\N	\N
92056	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-05-11 16:00:00	2016-05-11 17:00:00	\N	\N	4	0	\N	\N
92063	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-05-11 17:00:00	2016-05-11 18:00:00	\N	\N	4	0	\N	\N
92068	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-05-12 10:15:00	2016-05-12 11:30:00	\N	\N	4	0	\N	\N
92074	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-05-12 11:30:00	2016-05-12 12:30:00	\N	\N	2	0	\N	\N
92081	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-05-11 15:00:00	2016-05-11 16:00:00	\N	\N	4	0	\N	\N
92088	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-05-11 16:00:00	2016-05-11 17:00:00	\N	\N	5	0	\N	\N
92102	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-05-11 14:30:00	2016-05-11 15:30:00	\N	\N	1	0	\N	\N
92245	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	CECAC APF	Assemblée Parlementaire de la Francophonie	2016-04-27 06:00:00	2016-04-30 09:00:00	\N	\N	1	0	\N	\N
92247	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Controle	Audition Rapporteur FINC 	2016-05-10 14:00:00	2016-05-10 18:00:00	\N	\N	1	0	\N	\N
92249	GIA	AUCUNE	\N	\N	\N	GIA Afghanistan	Groupe interparlementaire Afghanistan	2016-05-12 13:00:00	2016-05-12 15:00:00	\N	\N	2	0	648	\N
92250	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Controle	Audition Rapporteur FINC 	2016-05-12 16:30:00	2016-05-12 17:30:00	\N	\N	1	0	\N	\N
92253	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Controle	Audition Rapporteur FINC 	2016-05-10 15:00:00	2016-05-10 16:30:00	\N	\N	2	0	\N	\N
92257	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Contrôle	Audition Rapporteur FINC 	2016-05-11 16:30:00	2016-05-11 20:10:00	\N	\N	2	0	\N	\N
92260	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. Contrôle FNADT	Contrôle -Mission "Politique des territoires"  - 2016 - FNADT - Audition ADCF - Mme Taheri -M. Bayle	2016-05-18 14:00:00	2016-05-18 15:00:00	\N	\N	1	0	\N	\N
80433	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	562	\N	\N	Explications de vote PJL Lutte contre le crime organisé	Explications de vote PJL Lutte contre le crime organisé	2016-04-05 15:15:00	2016-04-05 16:10:00	\N	\N	301	0	\N	\N
80434	SEANCE_PLENIERE	SCRUSOL	562	\N	\N	Scrutin solennel PJL Lutte contre le crime organisé	Scrutin solennel PJL Lutte contre le crime organisé	2016-04-05 16:10:00	2016-04-05 16:40:00	\N	\N	299	0	\N	\N
80435	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR Aléa économique en agriculture	PPR Aléa économique en agriculture	2016-04-06 14:30:00	2016-04-06 16:25:00	\N	\N	88	0	\N	\N
82769	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2016-04-06 10:05:00	2016-04-06 12:35:00	2018-05-18 14:43:41	2018-05-18 14:43:47	28	0	\N	\N
82999	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Offre de soins	Débat Offre de soins	2016-04-07 17:20:00	2016-04-07 18:40:00	\N	\N	25	0	\N	\N
83002	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Nouvelles intercommunalités	PPL Nouvelles intercommunalités	2016-04-07 14:30:00	2016-04-07 17:15:00	\N	\N	52	0	\N	\N
83004	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Indépendance des médias	PPL Indépendance des médias	2016-04-06 16:30:00	2016-04-06 18:40:00	\N	\N	69	0	\N	\N
83339	ETUDES	AUCUNE	\N	\N	\N	GE Gestion des déchets	Groupe d'études Gestion des déchets	2016-03-30 15:00:00	2016-03-30 16:00:00	\N	\N	7	0	\N	922
83347	ETUDES	AUCUNE	\N	\N	\N	GE Chasse et pêche	Groupe d'études Chasse et pêche	2016-04-07 08:30:00	2016-04-07 10:35:00	\N	\N	3	0	\N	907
83501	GIA	AUCUNE	\N	\N	\N	GIA Balkans Occidentaux	Groupe interparlementaire Balkans Occidentaux	2016-04-07 08:30:00	2016-04-07 09:30:00	\N	\N	3	0	674	\N
83507	GIA	AUCUNE	\N	\N	\N	GIA Finlande	Groupe interparlementaire Finlande	2016-04-10 14:00:00	2016-04-14 19:00:00	\N	\N	3	0	640	\N
83725	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle Politique des Territoires -FNADT  - 2016 - Audition D. Budget	2016-04-06 18:30:00	2016-04-06 19:15:00	\N	\N	1	0	\N	\N
83776	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	GT CDD  - Mobilités et Transports	Groupe de travail CDD 	2016-04-06 08:30:00	2016-04-06 09:30:00	\N	\N	2	0	\N	\N
83784	ETUDES	AUCUNE	\N	\N	\N	GE Élevage	Groupe d'études Élevage	2016-04-07 08:15:00	2016-04-07 09:30:00	\N	\N	6	0	\N	911
83822	GIA	AUCUNE	\N	\N	\N	GIE Tibet	Groupe d'information Tibet	2016-04-06 17:00:00	2016-04-06 20:00:00	\N	\N	6	0	634	\N
83829	GIA	AUCUNE	\N	\N	\N	GIA Viêt Nam	Groupe interparlementaire Viêt Nam	2016-03-25 09:00:00	2016-03-25 14:30:00	\N	\N	1	0	626	\N
83831	GIA	AUCUNE	\N	\N	\N	GIA Viêt Nam / rencontre CHEMI	Groupe interparlementaire Viêt Nam	2016-04-06 14:30:00	2016-04-06 15:00:00	\N	\N	1	0	626	\N
83852	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL "droit du travail"	PJL "droit du travail"	2016-04-12 15:30:00	2016-04-12 17:30:00	\N	\N	1	0	\N	\N
82677	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2016-04-06 10:10:00	2016-04-06 12:10:00	2016-04-06 12:39:11	2016-04-06 16:28:42	49	0	\N	\N
83860	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle budg.  Mission Sécurités - 2016 -  La préfecture de police de Paris - rencontre M. Arella  - Dir. Interreg. PJ 	2016-04-07 11:30:00	2016-04-07 12:30:00	\N	\N	1	0	\N	\N
83866	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle budg. Mission Sécurités - 2016 - La préfecture de police de Paris - rencontre M. Nunez , préfet police	2016-04-07 12:30:00	2016-04-07 14:30:00	\N	\N	1	0	\N	\N
83868	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle budg. Mission Sécurités - 2016 - La préfecture de police de Paris - M. Harguindeguy - Commissaire div.	2016-04-07 14:30:00	2016-04-07 15:45:00	\N	\N	1	0	\N	\N
83870	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle budg.  Mission Sécurités - 2016 - La préfecture de police de Paris -Mme Ghizoli, commisssaire div.	2016-04-07 15:45:00	2016-04-07 17:00:00	\N	\N	1	0	\N	\N
83872	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle budg. Mission Sécurités - 2016 - La préfecture de police de Paris - Mme Pozmentier  - Vice Pdte Cel Reg.	2016-04-07 17:30:00	2016-04-07 19:30:00	\N	\N	1	0	\N	\N
83875	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle budg. Mission Sécurités - 2016 - La préfecture de police de Paris -  M. Blouin  - Commissaire div.	2016-04-08 09:00:00	2016-04-08 10:15:00	\N	\N	1	0	\N	\N
83878	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle budg. Mission Sécurités-2016-Préfect. de police de Paris - MM. Groult, comm. div./Tavart, cller préf. police	2016-04-08 10:15:00	2016-04-08 11:15:00	\N	\N	1	0	\N	\N
83882	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle budg. Mission Sécurités-2016 - La préfecture de police de Paris - Audition M. Galtier, cdt gendarmerie PACA	2016-04-08 12:30:00	2016-04-08 16:15:00	\N	\N	1	0	\N	\N
83884	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle budg. Mission Sécurités -2016 - La préfecture de police de Paris - M. Reynaud, sous-préfet	2016-04-08 11:15:00	2016-04-08 12:15:00	\N	\N	1	0	\N	\N
83912	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle "Recherche et ens. sup." - 2016  - Paris-Saclay - Entretien T.Mandon, secr. d'Etat - ens. sup. et  recherche	2016-04-12 15:30:00	2016-04-12 16:30:00	\N	\N	1	0	\N	\N
83914	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Mission "Ens. supérieur, recherche" -Contrôle Paris-Saclay - 2016 - Audition M. Matlotz - Pdt ANR	2016-04-13 15:00:00	2016-04-13 16:30:00	\N	\N	1	0	\N	\N
83916	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Mission "Ens. sup. et recherche" -Contrôle Paris-Saclay - 2016- Audition P. Van de Mael - DG EPA Paris-Saclay	2016-04-13 16:30:00	2016-04-13 17:30:00	\N	\N	1	0	\N	\N
83918	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle mission "Ens. supérieur et recherche"  - 2016 - Paris-Saclay - Audition P. Yvin - DG Société du Grand Paris	2016-04-13 17:30:00	2016-04-13 18:30:00	\N	\N	1	0	\N	\N
83920	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle mission "Ens. supérieur et recherche" - 2016 - Paris-Saclay - Audition M. Francq - CGI	2016-04-13 18:30:00	2016-04-13 20:00:00	\N	\N	1	0	\N	\N
83922	DELEGATION	AUCUNE	\N	\N	206	Sciences technologiques et sences du vivant	AP apport avancées technologiuqes aux sciences de la vie	2016-04-28 09:30:00	2016-04-28 13:20:00	2016-05-03 10:56:38	2016-05-03 11:17:04	6	0	\N	\N
83952	DELEGATION	AUCUNE	\N	\N	COLTER	Collectivités territoriales : rapport "communes nouvelles"	Collectivités territoriales	2016-04-28 08:30:00	2016-04-28 10:00:00	2016-04-29 17:25:04	2016-04-29 17:26:29	12	0	\N	\N
84085	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Entreprises	Auditions Entreprises et droit du travail	2016-04-26 14:30:00	2016-04-26 15:30:00	\N	\N	2	0	\N	\N
84087	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Entreprises 	Auditions Entreprises et droit du travail	2016-04-27 15:30:00	2016-04-27 16:50:00	\N	\N	1	0	\N	\N
84089	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Entreprises	Réunion plénière de la Délégation sénatoriale aux entreprises 	2016-05-26 08:30:00	2016-05-26 10:20:00	2016-05-26 11:16:47	2016-05-26 15:00:13	14	0	\N	\N
84156	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Programme de stabilité 	Débat Programme de stabilité	2016-04-27 14:30:00	2016-04-27 16:35:00	\N	\N	110	0	\N	\N
84157	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL République numérique	PJL République numérique	2016-04-27 16:40:00	2016-04-27 19:55:00	\N	\N	128	0	\N	\N
84158	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL République numérique	PJL République numérique	2016-04-27 21:35:00	2016-04-28 01:25:00	\N	\N	79	0	\N	\N
84633	GIA	AUCUNE	\N	\N	\N	GIE Tibet	Groupe d'information Tibet	2016-04-26 18:30:00	2016-04-26 19:00:00	\N	\N	1	0	634	\N
84637	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2016-04-27 09:30:00	2016-04-27 10:15:00	2016-04-27 16:18:00	2016-04-27 16:36:39	33	0	\N	\N
84717	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2016-04-27 09:05:00	2016-04-27 10:40:00	2018-05-18 14:45:13	2018-05-18 14:45:16	34	0	\N	\N
84889	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2016-04-27 11:05:00	2016-04-27 12:35:00	2018-05-18 14:48:38	2018-05-18 14:48:43	37	1	\N	\N
85250	QUESTURE	AUCUNE	\N	\N	\N	Questure	Réunion de Questure	2016-04-26 15:10:00	2016-04-26 18:10:00	\N	\N	3	0	\N	\N
119925	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2017 - Equilibres financiers - Assurance vieillesse	PLFSS 2017 - Equilibres financiers-Assurance vieillesse	2016-10-11 14:00:00	2016-10-11 18:00:00	\N	\N	3	0	\N	\N
80436	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-04-05 09:05:00	2016-04-05 11:00:00	2016-04-05 11:40:32	2016-04-05 14:04:33	18	0	\N	\N
80471	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2016-03-08 14:30:00	2016-03-08 16:45:00	\N	\N	1	0	\N	\N
80473	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2016-03-08 14:30:00	2016-03-08 15:30:00	\N	\N	1	0	\N	\N
80475	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2016-03-09 14:30:00	2016-03-09 19:00:00	\N	\N	1	0	\N	\N
80477	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2016-03-10 09:30:00	2016-03-10 11:00:00	\N	\N	1	0	\N	\N
80479	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2016-03-15 12:00:00	2016-03-15 13:00:00	\N	\N	1	0	\N	\N
80481	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2016-03-15 15:30:00	2016-03-15 17:30:00	\N	\N	1	0	\N	\N
80483	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2016-03-16 17:45:00	2016-03-16 19:15:00	\N	\N	1	0	\N	\N
80485	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2016-03-17 09:00:00	2016-03-17 11:00:00	\N	\N	2	0	\N	\N
80488	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2016-03-17 16:15:00	2016-03-17 17:15:00	\N	\N	1	0	\N	\N
80490	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2016-03-22 14:00:00	2016-03-22 15:00:00	\N	\N	1	0	\N	\N
80492	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2016-03-22 17:15:00	2016-03-22 18:00:00	\N	\N	1	0	\N	\N
107733	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Travail	PJL Travail	2016-06-22 21:30:00	2016-06-23 00:45:00	\N	\N	88	0	\N	\N
84820	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2016-04-27 09:30:00	2016-04-27 11:00:00	2018-05-18 14:45:51	2018-05-18 14:45:55	54	1	\N	\N
80494	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2016-03-22 17:30:00	2016-03-22 18:15:00	\N	\N	1	0	\N	\N
80496	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2016-03-23 14:30:00	2016-03-23 18:15:00	\N	\N	1	0	\N	\N
80498	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2016-03-24 09:30:00	2016-03-24 11:00:00	\N	\N	1	0	\N	\N
80500	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2016-03-24 10:00:00	2016-03-24 11:00:00	\N	\N	1	0	\N	\N
80502	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2016-03-24 14:00:00	2016-03-24 15:30:00	\N	\N	1	0	\N	\N
80504	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2016-03-24 16:30:00	2016-03-24 17:30:00	\N	\N	1	0	\N	\N
80626	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT AFCL 	Groupe de travail AFCL 	2016-03-31 10:30:00	2016-03-31 11:30:00	\N	\N	8	0	\N	\N
81724	MECSS	AUCUNE	\N	\N	MECSS	MECSS 	MECSS 	2016-04-05 17:50:00	2016-04-05 19:00:00	2016-04-05 19:08:38	2016-04-06 15:01:33	19	0	\N	\N
81854	GIA	AUCUNE	\N	\N	\N	GIA Asie du Sud-Est	Groupe interparlementaire Asie du Sud-Est	2016-04-05 08:30:00	2016-04-05 10:30:00	\N	\N	4	0	609	\N
82354	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2016-04-05 17:50:00	2016-04-05 19:20:00	2016-04-06 14:41:27	2016-04-06 14:59:13	32	0	\N	\N
82440	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2016-04-06 09:30:00	2016-04-06 10:20:00	2016-04-06 11:28:23	2016-04-06 16:28:46	41	0	\N	\N
82625	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2016-03-30 14:00:00	2016-03-30 15:00:00	\N	\N	3	0	\N	\N
82669	QUESTURE	AUCUNE	\N	\N	\N	Questure	Réunion de Questure	2016-04-05 18:00:00	2016-04-05 20:30:00	\N	\N	3	0	\N	\N
82674	GIA	AUCUNE	\N	\N	\N	GIA Hongrie	Groupe interparlementaire Hongrie	2016-04-05 14:30:00	2016-04-05 15:00:00	\N	\N	2	0	592	\N
82735	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT FINC Transport	Groupe de travail FINC Transport - Audition CGI	2016-04-05 14:00:00	2016-04-05 15:00:00	\N	\N	5	0	\N	\N
82980	MISSION	AUCUNE	\N	ISLAM	\N	MI organisation, place et financement de l'Islam en France 	MI organisation, place et financement de l'Islam en France 	2016-04-06 15:05:00	2016-04-06 17:30:00	2016-04-06 17:28:22	2016-04-06 17:34:43	8	0	\N	\N
83145	MISSION	AUDRAP	\N	ISLAM	\N	Aud. Rapp. MI organisation, place et financement de l'Islam 	Audition Rapporteur MI organisation, place et financement de l'Islam en France 	2016-04-04 10:00:00	2016-04-04 19:00:00	\N	\N	5	0	\N	\N
83854	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI 	Audition Rapporteur SOCI 	2016-04-12 12:00:00	2016-04-12 13:00:00	\N	\N	1	0	\N	\N
83874	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL "droit du travail"	PJL "droit du travail"	2016-04-13 17:45:00	2016-04-13 20:00:00	\N	\N	3	0	\N	\N
83930	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Entreprises	Réunion plénière	2016-05-11 13:00:00	2016-05-11 13:50:00	2016-05-11 15:25:37	2016-05-11 17:16:13	16	0	\N	\N
83931	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Entreprises	Matinée d'études de droi comparé sur la simplification du droit	2016-05-12 09:45:00	2016-05-12 12:30:00	2016-05-12 16:09:23	2016-05-12 17:14:48	12	0	\N	\N
83934	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle Mission "Ens. sup. et recherche" - 2016 -Financ. sûreté aérienne - Audition M. Wachenheim - Cller PDG Airbus	2016-04-14 08:45:00	2016-04-14 10:00:00	\N	\N	1	0	\N	\N
83936	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	DGF	Réforme de la dotation globale de fonctionnement - La DGF des EPCI et les dotations de péréquation	2016-04-12 16:30:00	2016-04-12 19:00:00	\N	\N	2	0	\N	\N
83972	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	Commission politique APF	Commission politique APF	2016-04-11 10:45:00	2016-04-15 09:00:00	\N	\N	1	0	\N	\N
84013	GIA	AUCUNE	\N	\N	\N	GIA Mexique-Pays d'Am. Centrale	Groupe interparlementaire Mexique-Pays d'Am. Centrale	2016-04-09 13:00:00	2016-04-19 18:30:00	\N	\N	5	0	643	\N
84092	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2016-04-26 09:30:00	2016-04-26 10:20:00	2016-04-26 11:44:18	2016-04-26 16:42:15	28	0	\N	\N
84154	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL République numérique	PJL République numérique	2016-04-26 14:30:00	2016-04-26 19:20:00	\N	\N	183	0	\N	\N
84155	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL République numérique	PJL République numérique	2016-04-26 21:30:00	2016-04-27 01:20:00	\N	\N	70	0	\N	\N
84209	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-04-26 09:05:00	2016-04-26 10:30:00	2018-05-18 14:44:53	2018-05-18 14:44:56	17	0	\N	\N
84229	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	CAE 	2016-04-26 13:30:00	2016-04-26 13:50:00	2016-04-26 14:17:24	2016-04-26 16:42:16	24	0	\N	\N
85304	BUREAU	AUCUNE	\N	\N	\N	Délégation du Bureau	Délégation du Bureau statut et conditions d'exercice mandat de sénateur	2016-04-26 12:00:00	2016-04-26 13:00:00	\N	\N	2	0	\N	\N
85339	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC - Réunion de la commission	2016-04-27 16:40:00	2016-04-27 18:10:00	2018-05-18 14:48:55	2018-05-18 14:48:59	32	0	\N	\N
85761	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2016-04-28 08:30:00	2016-04-28 10:05:00	2016-04-28 14:46:41	2016-04-28 15:23:04	38	0	\N	\N
85849	BUREAU	AUCUNE	\N	\N	\N	Bureau	Réunion du Bureau	2016-04-28 08:30:00	2016-04-28 11:00:00	\N	\N	23	0	\N	\N
86731	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PPL 402-Transparence vie financière - Bocquet - Audition de la DG Trésor et Dir. Lég. Fiscale - Marcus,Raspiller,Monnet	2016-04-26 16:30:00	2016-04-26 17:45:00	\N	\N	1	0	\N	\N
86733	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PPL N°402 - Bocquet - Transparence vie financière - Table ronde ONG  	2016-04-28 09:00:00	2016-04-28 10:00:00	\N	\N	1	0	\N	\N
86735	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PPL n°402 - Bocquet - Transparence vie financière - Audition MEDEF	2016-04-28 13:00:00	2016-04-28 14:00:00	\N	\N	1	0	\N	\N
86737	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Audition contrôle mission "Santé" - 2016 - INCA - Audition Fondation ARC	2016-04-28 14:00:00	2016-04-28 15:00:00	\N	\N	1	0	\N	\N
86739	MISSION	AUCUNE	\N	ISLAM	\N	MI organisation, place et financement de l'Islam en France 	MI organisation, place et financement de l'Islam en France 	2016-04-27 16:30:00	2016-04-27 18:30:00	2016-04-28 18:20:51	2016-04-29 09:31:57	11	0	\N	\N
86740	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Audition contrôle mission "Santé" - 2016 - INCA - Audition INRS	2016-04-28 16:30:00	2016-04-28 17:30:00	\N	\N	1	0	\N	\N
86755	MISSION	AUCUNE	\N	ISLAM	\N	MI organisation, place et financement de l'Islam en France 	MI organisation, place et financement de l'Islam en France 	2016-04-28 10:30:00	2016-04-28 13:00:00	2016-04-28 18:19:24	2016-04-29 09:31:59	11	0	\N	\N
86768	GIA	AUCUNE	\N	\N	\N	GIA Arménie	Groupe interparlementaire Arménie	2016-04-27 08:30:00	2016-04-27 09:30:00	\N	\N	11	0	641	\N
86973	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI 	Audition Rapporteur SOCI 	2016-05-03 14:00:00	2016-05-03 15:00:00	\N	\N	1	0	\N	\N
86975	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI 	Audition Rapporteur SOCI 	2016-05-04 14:00:00	2016-05-04 17:00:00	\N	\N	1	0	\N	\N
86978	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle - Mission affaires européennes -FEI - Audition Banque de France - M. Pfister	2016-04-28 16:15:00	2016-04-28 17:15:00	\N	\N	1	0	\N	\N
82194	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2016-04-05 17:45:00	2016-04-05 18:20:00	2016-04-06 09:11:11	2016-04-06 14:59:04	33	0	\N	\N
83138	QUESTURE	AUCUNE	\N	\N	\N	Syndicat des fonctionnaires	Syndicat des fonctionnaires du Sénat	2016-04-06 11:30:00	2016-04-06 12:30:00	\N	\N	3	0	\N	\N
83142	QUESTURE	AUCUNE	\N	\N	\N	CA Public Sénat	CA Public Sénat	2016-04-06 14:00:00	2016-04-06 16:25:00	\N	\N	1	0	\N	\N
83174	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2016-04-06 17:05:00	2016-04-06 18:30:00	2016-04-06 19:23:10	2016-04-07 12:03:08	14	0	\N	\N
83374	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2016-04-07 09:40:00	2016-04-07 11:05:00	2016-04-08 15:28:28	2016-04-08 15:34:26	20	0	\N	\N
83674	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-04-06 11:30:00	2016-04-06 12:30:00	\N	\N	2	0	\N	\N
83677	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	ETRD 	ETRD 	2016-04-08 08:00:00	2016-04-08 18:00:00	\N	\N	2	0	\N	\N
83680	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-04-07 12:00:00	2016-04-07 13:00:00	\N	\N	2	0	\N	\N
83683	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-04-05 14:00:00	2016-04-05 15:15:00	\N	\N	6	0	\N	\N
83690	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-04-06 14:30:00	2016-04-06 16:00:00	\N	\N	6	0	\N	\N
83697	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-04-06 16:00:00	2016-04-06 17:15:00	\N	\N	5	0	\N	\N
83703	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-04-06 17:15:00	2016-04-06 18:30:00	\N	\N	2	0	\N	\N
83706	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-04-07 09:30:00	2016-04-07 10:15:00	\N	\N	5	0	\N	\N
83712	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-04-07 10:15:00	2016-04-07 11:30:00	\N	\N	3	0	\N	\N
83812	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Déplacement en Turquie	Déplacement en Turquie 	2016-04-04 08:00:00	2016-04-08 18:00:00	\N	\N	2	0	\N	\N
83815	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	entretien avec Jacques Mézard	Entretien avec Jacques Mézard 	2016-03-30 16:15:00	2016-03-30 17:00:00	\N	\N	3	0	\N	\N
83819	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Audition Gérard Chaliand	Audition Gérard Chaliand	2016-03-31 09:30:00	2016-03-31 10:45:00	\N	\N	2	0	\N	\N
84988	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	CAE 	2016-04-27 10:00:00	2016-04-27 12:55:00	2016-04-27 16:18:53	2016-04-27 16:36:44	37	0	\N	\N
85636	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2016-04-28 08:30:00	2016-04-28 10:05:00	2016-04-28 10:46:11	2016-04-28 14:14:34	38	0	\N	\N
86892	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT FINC 	Financement des infrastructures de transport	2016-04-28 10:30:00	2016-04-28 11:15:00	\N	\N	3	0	\N	\N
87011	GIA	AUCUNE	\N	\N	\N	GE Chrétiens d'Orient	Groupe de liaison Chrétiens d'Orient	2016-04-26 14:15:00	2016-04-26 17:00:00	\N	\N	16	0	CHRETORIENT	CHRETORIENT
87050	MISSION	AUDRAP	\N	ISLAM	\N	Aud. Rapp. MI organisation, place et financement de l'Islam 	Audition Rapporteur MI organisation, place et financement de l'Islam en France Déplacement à Rabat	2016-04-24 10:30:00	2016-04-26 11:45:00	\N	\N	3	0	\N	\N
87059	MISSION	AUDRAP	\N	ISLAM	\N	Aud. Rapp. MI organisation, place et financement de l'Islam 	Audition Rapporteur MI organisation, place et financement de l'Islam en France Déplacement à Strasbourg	2016-05-01 17:55:00	2016-05-02 20:00:00	\N	\N	8	0	\N	\N
87076	MISSION	AUDRAP	\N	ISLAM	\N	Aud. Rapp. MI organisation, place et financement de l'Islam 	Audition Rapporteur MI organisation, place et financement de l'Islam en France 	2016-04-27 12:00:00	2016-04-27 14:00:00	\N	\N	4	0	\N	\N
87083	MISSION	AUDRAP	\N	ISLAM	\N	Aud. Rapp. MI organisation, place et financement de l'Islam 	Audition Rapporteur MI organisation, place et financement de l'Islam en France 	2016-04-28 13:00:00	2016-04-28 14:15:00	\N	\N	3	0	\N	\N
87093	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-04-13 11:30:00	2016-04-13 12:30:00	\N	\N	1	0	\N	\N
87154	QUESTURE	AUCUNE	\N	\N	\N	Questure	Réunion de Questure	2016-04-28 10:50:00	2016-04-28 11:00:00	\N	\N	3	0	\N	\N
87169	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT FINC 	Groupe de travail Transport -Audition SNCF Réseau - M. Rapoport/ M. Quinet/Mme Nion	2016-04-28 10:30:00	2016-04-28 11:45:00	\N	\N	0	0	\N	\N
87170	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle - Mission DAG - 2016 - DINSIC - Audition France Stratégie - M. Pisani-Ferry contrôleur gal	2016-04-28 11:30:00	2016-04-28 12:30:00	\N	\N	0	0	\N	\N
87172	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Traite des êtres humains 	Débat Traite des êtres humains 	2016-05-04 14:40:00	2016-05-04 16:10:00	\N	\N	53	0	\N	\N
87173	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Politique du tourisme	Débat Politique du tourisme	2016-05-04 16:15:00	2016-05-04 17:40:00	\N	\N	30	0	\N	\N
87174	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Stratégie nationale de l'enseignement supérieur 	Débat Stratégie nationale de l'enseignement supérieur 	2016-05-04 17:45:00	2016-05-04 19:15:00	\N	\N	19	0	\N	\N
88203	GIA	AUCUNE	\N	\N	\N	GIA Pakistan	Groupe interparlementaire Pakistan	2016-05-03 10:00:00	2016-05-03 11:00:00	\N	\N	3	0	619	\N
88232	MISSION	AUCUNE	\N	TURQUIE	\N	MI Accord UE/Turquie 	MI Accord UE/Turquie 	2016-05-03 13:35:00	2016-05-03 14:15:00	2016-05-03 17:54:02	2016-05-04 17:49:04	20	0	\N	\N
88358	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-05-03 17:45:00	2016-05-03 19:30:00	2018-05-18 14:49:28	2018-05-18 14:49:33	26	0	\N	\N
88450	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	CAE 	2016-05-03 17:45:00	2016-05-03 19:35:00	2018-05-18 14:49:15	2018-05-18 14:49:35	31	0	\N	\N
88492	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-04-26 16:00:00	2016-04-26 19:00:00	\N	\N	1	0	\N	\N
88494	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-04-28 14:00:00	2016-04-28 14:45:00	\N	\N	1	0	\N	\N
88561	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2016-05-03 18:00:00	2016-05-03 20:20:00	2016-05-04 15:56:36	2016-05-04 17:46:40	31	0	\N	\N
88601	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-05-03 19:30:00	2016-05-03 20:00:00	\N	\N	1	0	\N	\N
88603	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-05-03 13:30:00	2016-05-03 15:30:00	\N	\N	0	0	\N	\N
88605	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-05-03 17:45:00	2016-05-03 19:30:00	\N	\N	0	0	\N	\N
88644	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2016-05-04 09:30:00	2016-05-04 11:25:00	2016-05-04 14:07:33	2016-05-04 17:46:40	32	0	\N	\N
88743	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2016-05-04 09:00:00	2016-05-04 11:50:00	2016-05-04 13:19:58	2016-05-04 17:46:39	41	0	\N	\N
84677	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2016-04-27 10:15:00	2016-04-27 10:30:00	2018-05-18 14:46:08	2018-05-18 14:46:11	33	0	\N	\N
88995	COM_SPECIALE	PLENIERE	\N	COMSPEAPU	\N	Commission spéciale chargée du contrôle des comptes 	Commission spéciale chargée du contrôle des comptes 	2016-05-03 14:00:00	2016-05-03 15:15:00	2016-05-04 15:40:38	2016-05-04 17:50:27	4	0	\N	\N
89002	COM_SPECIALE	PLENIERE	\N	COMSPEAPU	\N	Commission spéciale chargée du contrôle des comptes 	Commission spéciale chargée du contrôle des comptes 	2016-05-04 10:00:00	2016-05-04 11:30:00	2016-05-04 15:41:54	2016-05-04 17:50:27	5	0	\N	\N
89063	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2016-05-10 09:30:00	2016-05-10 12:35:00	\N	\N	32	0	\N	\N
89066	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL État d'urgence	PJL État d'urgence	2016-05-10 14:30:00	2016-05-10 15:50:00	\N	\N	147	0	\N	\N
89068	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Abus de marché	PPL Abus de marché	2016-05-10 16:00:00	2016-05-10 18:00:00	\N	\N	105	0	\N	\N
89069	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Biodiversité	PJL Biodiversité	2016-05-10 21:35:00	2016-05-11 00:25:00	\N	\N	71	0	\N	\N
89079	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Biodiversité	PJL Biodiversité	2016-05-10 18:00:00	2016-05-10 19:55:00	\N	\N	75	0	\N	\N
89157	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière	OPECST -Réunion plénière	2016-05-18 18:05:00	2016-05-18 20:00:00	2016-05-19 10:40:09	2016-05-19 14:06:30	8	0	\N	\N
89162	DELEGATION	AUCUNE	\N	\N	206	Audition ASN et CNE2	Audition ASN et CNE2	2016-05-25 17:05:00	2016-05-25 20:25:00	2016-05-26 14:15:37	2016-05-26 15:00:12	15	0	\N	\N
83294	DELEGATION	AUDRAP	\N	\N	PROS	Délégation sénatoriale à la prospective 	Délégation sénatoriale à la prospective 	2016-03-31 09:30:00	2016-03-31 10:45:00	\N	\N	2	0	\N	\N
83299	DELEGATION	AUCUNE	\N	\N	PROS	Délégation sénatoriale à la prospective 	Délégation sénatoriale à la prospective 	2016-04-07 09:00:00	2016-04-07 10:20:00	2016-04-07 11:51:03	2016-04-07 12:04:05	8	0	\N	\N
83542	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle Affaires européennes - Aides financières aux enteprises - 2016 - Audition DGT	2016-04-04 14:00:00	2016-04-04 15:05:00	\N	\N	1	0	\N	\N
83544	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle Affaires européennes - Aides financières aux entreprises - 2016 - Audition FEI	2016-04-04 15:05:00	2016-04-04 16:15:00	\N	\N	1	0	\N	\N
83546	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle Politique des territoires -  FNADT - 2016 - Audition Association des maires ruraux de France	2016-04-06 15:00:00	2016-04-06 15:45:00	\N	\N	1	0	\N	\N
83548	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle Affaires européennes - Aides financières aux entreprises - 2016 - Audition DGE	2016-04-07 14:30:00	2016-04-07 16:00:00	\N	\N	1	0	\N	\N
83765	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2017 - Audition SYMOP - M. Tournoux, délégué général	2016-04-06 16:00:00	2016-04-06 17:00:00	\N	\N	1	0	\N	\N
83779	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Groupe de travail - Numérique	Groupe de travail Numérique - Audition Pascal Terrasse 	2015-11-18 18:30:00	2015-11-18 19:30:00	\N	\N	6	0	\N	\N
83793	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT FINC 	Groupe de travail Numérique	2016-01-26 16:00:00	2016-01-26 17:00:00	\N	\N	2	0	\N	\N
83798	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT FINC 	Groupe de travail Numérique	2016-03-10 16:00:00	2016-03-10 17:00:00	\N	\N	4	0	\N	\N
83856	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL "droit du travail"	Audition Rapporteur SOCI 	2016-04-13 09:00:00	2016-04-13 11:00:00	\N	\N	3	0	\N	\N
83862	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL "droit du travail"	PJL "droit du travail"	2016-04-13 13:45:00	2016-04-13 15:15:00	\N	\N	3	0	\N	\N
85066	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2016-04-27 10:00:00	2016-04-27 12:45:00	2016-04-27 16:15:25	2016-04-27 16:36:42	37	0	\N	\N
85916	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-04-28 08:30:00	2016-04-28 10:05:00	2016-04-28 11:57:41	2016-04-28 14:12:45	38	0	\N	\N
86006	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle - Mission  Agriculture -2016 - Moyens PSSA -  Audition M. Dehaumont - DGA - Mme Delva - M. Guilleray 	2016-04-27 14:30:00	2016-04-27 16:30:00	\N	\N	2	0	\N	\N
86010	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôlecx  - Mission Agriculture - 2016 - PSSA - Audition DGCCRF - M. Gérard et M. Duchemin/ Mme Servoz	2016-04-27 16:30:00	2016-04-27 18:10:00	\N	\N	2	0	\N	\N
86013	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT AFEU 	Groupe de travail AFEU 	2016-04-27 14:00:00	2016-04-27 15:05:00	\N	\N	3	0	\N	\N
86366	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-04-27 15:00:00	2016-04-27 16:00:00	\N	\N	1	0	\N	\N
86368	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-04-26 14:00:00	2016-04-26 16:15:00	\N	\N	4	0	\N	\N
86373	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-04-27 14:00:00	2016-04-27 16:10:00	\N	\N	6	0	\N	\N
86394	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-04-27 15:00:00	2016-04-27 16:00:00	\N	\N	5	0	\N	\N
86983	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2016-04-06 08:30:00	2016-04-06 09:50:00	\N	\N	1	0	\N	\N
86985	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Aud. Rapp. AFCL 	Audition Rapporteur AFCL 	2016-04-06 14:30:00	2016-04-06 15:30:00	\N	\N	1	0	\N	\N
86987	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT AFCL 	Groupe de travail AFCL 	2016-04-27 13:45:00	2016-04-27 14:45:00	\N	\N	2	0	\N	\N
87004	GIA	AUCUNE	\N	\N	\N	AG du GIA Corée du Sud	AG du Groupe interparlementaire Corée du Sud	2016-04-26 09:00:00	2016-04-26 10:00:00	\N	\N	6	0	613	\N
87096	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Intercommunalités	Débat Intercommunalités	2016-05-03 17:45:00	2016-05-03 19:30:00	\N	\N	65	0	\N	\N
87097	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Essais cliniques	Débat Essais cliniques	2016-05-03 19:30:00	2016-05-03 21:05:00	\N	\N	44	0	\N	\N
87150	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle- Mission Défense - 2016 - Opérations extérieures du Min. de la Défensevisite-dispositif Sentinelle -Vincennes	2016-04-26 13:00:00	2016-04-26 16:00:00	\N	\N	1	0	\N	\N
87152	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PPL Abus de marché - Audition AMF	2016-04-26 17:00:00	2016-04-26 18:00:00	\N	\N	1	0	\N	\N
87162	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle budgétaire - Mission immigration, asile et intégration - 2016 - CADA - Audition DG de l'OFII 	2016-04-29 15:30:00	2016-04-29 16:30:00	\N	\N	1	0	\N	\N
87186	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	581	\N	\N	Explications de vote PJL République numérique	Explications de vote PJL République numérique	2016-05-03 15:15:00	2016-05-03 16:10:00	\N	\N	318	0	\N	\N
87187	SEANCE_PLENIERE	SCRUSOL	581	\N	\N	Scrutin solennel PJL République numérique	Scrutin solennel PJL République numérique	2016-05-03 16:10:00	2016-05-03 16:35:00	\N	\N	318	0	\N	\N
87188	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au Gouvernement	Questions d'actualité au Gouvernement	2016-05-03 16:45:00	2016-05-03 17:30:00	\N	\N	320	0	\N	\N
87197	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-04-27 14:30:00	2016-04-27 18:00:00	\N	\N	1	0	\N	\N
88392	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2016-05-03 18:10:00	2016-05-03 19:20:00	2018-05-18 14:49:48	2018-05-18 14:49:54	18	0	\N	\N
88884	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-05-04 11:50:00	2016-05-04 12:30:00	2018-05-18 14:50:57	2018-05-18 14:51:04	41	0	\N	\N
88490	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2016-05-03 17:30:00	2016-05-03 19:00:00	\N	\N	1	0	\N	\N
88803	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2016-05-04 10:10:00	2016-05-04 12:10:00	2016-05-04 14:56:56	2016-05-04 17:46:38	45	1	\N	\N
89166	QUESTURE	AUCUNE	\N	\N	\N	Questure	Réunion de Questure	2016-05-03 18:00:00	2016-05-03 19:45:00	\N	\N	3	0	\N	\N
89170	QUESTURE	AUCUNE	\N	\N	\N	Commission spéciale des comptes	Commission spéciale "Contrôle des comptes et évaluation interne"	2016-05-04 10:00:00	2016-05-04 11:15:00	\N	\N	3	0	\N	\N
89174	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-05-04 15:30:00	2016-05-04 17:30:00	\N	\N	2	0	\N	\N
89192	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2016-05-04 14:00:00	2016-05-04 14:45:00	\N	\N	1	0	\N	\N
89194	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2016-05-04 14:45:00	2016-05-04 15:30:00	\N	\N	1	0	\N	\N
89196	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2016-05-04 15:30:00	2016-05-04 16:15:00	\N	\N	1	0	\N	\N
89198	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2016-05-04 16:15:00	2016-05-04 17:00:00	\N	\N	1	0	\N	\N
89200	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2016-05-04 09:30:00	2016-05-04 10:00:00	\N	\N	1	0	\N	\N
89202	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2016-05-04 10:00:00	2016-05-04 10:30:00	\N	\N	1	0	\N	\N
89204	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2016-05-04 10:30:00	2016-05-04 11:00:00	\N	\N	1	0	\N	\N
89206	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2016-05-04 11:00:00	2016-05-04 11:30:00	\N	\N	1	0	\N	\N
89208	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2016-05-04 11:30:00	2016-05-04 12:00:00	\N	\N	1	0	\N	\N
89210	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2016-05-04 14:00:00	2016-05-04 15:00:00	\N	\N	2	0	\N	\N
89213	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle mission "Agriculture" - 2016 -  Sécurité sanitaire des aliments - Mme Guillou - Anc. pdte de l'INRA	2016-05-04 15:00:00	2016-05-04 16:15:00	\N	\N	2	0	\N	\N
89216	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Controle	Audition Mission "Politique des territoires" - 2016  -  FNADT -  Mme Bonnet-Galzy	2016-05-04 14:00:00	2016-05-04 15:30:00	\N	\N	1	0	\N	\N
89218	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Contrôle	Audition contrôle mission "Affaires européennes" - 2016 - FEI - Sté Soridec - M. Religieux	2016-05-02 14:30:00	2016-05-02 15:30:00	\N	\N	1	0	\N	\N
89220	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Controle	Contrôle Mission "Affaires européennes" - 2016 - FEI - Audition  AFIC - M. Perpère, dél. gal	2016-05-04 15:30:00	2016-05-04 16:45:00	\N	\N	1	0	\N	\N
89222	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Controle	Audition contrôle Mission Culture - 2016 - Archives nationales - Cour des comptes - Mme Coudurier - Tournier... 	2016-05-05 14:10:00	2016-05-05 15:15:00	\N	\N	2	0	\N	\N
89225	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Controle	Audition contrôle Mission "Santé" - 2016 - INCA - Audition T. Breton, directeur	2016-05-04 14:00:00	2016-05-04 15:00:00	\N	\N	1	0	\N	\N
80376	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2017 - Visite du centre pénitentiaire de Fresnes 	2016-03-31 17:20:00	2016-03-31 19:15:00	\N	\N	1	0	\N	\N
80378	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Groupe de travail - DGF 	Réforme de la DGF - Architecture de la dotation forfaitaire	2016-03-30 14:30:00	2016-03-30 16:20:00	\N	\N	10	0	\N	\N
80409	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Union bancaire	2016-03-31 14:00:00	2016-03-31 15:00:00	\N	\N	1	0	\N	\N
80411	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Union bancaire	2016-04-04 14:00:00	2016-04-04 15:00:00	\N	\N	1	0	\N	\N
80749	ETUDES	AUCUNE	\N	\N	\N	GE Société numérique, nouveaux usages, nouveaux médias	Groupe d'études Société numérique, nouveaux usages, nouveaux médias	2016-03-16 08:30:00	2016-03-16 09:30:00	\N	\N	3	0	\N	965
82431	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2016-04-06 09:35:00	2016-04-06 10:30:00	2016-04-06 16:17:00	2016-04-06 16:39:54	32	1	\N	\N
83487	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	GT Simplification normes	GT Simplification normes	2016-04-07 09:30:00	2016-04-07 11:15:00	\N	\N	8	0	\N	\N
83498	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	Collectivités  territoriales 	Collectivités  territoriales 	2016-04-07 11:30:00	2016-04-07 12:30:00	\N	\N	4	0	\N	\N
83511	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	GT Simplification normes	GT Simplification normes	2016-04-06 14:00:00	2016-04-06 16:00:00	\N	\N	5	0	\N	\N
83517	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	GT Simplification normes	GT Simplification normes	2016-04-06 16:00:00	2016-04-06 18:00:00	\N	\N	4	0	\N	\N
83718	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PJL Numérique - Audition BPI France USA - MM. Serman et Boulay	2016-04-07 16:00:00	2016-04-07 17:30:00	\N	\N	1	0	\N	\N
83996	DELEGATION	AUCUNE	\N	\N	COLTER	Collectivités  territoriales 	Rapport Association des collectivités aux décisions + Audition de M. Jean-Vincent Placé	2016-05-26 08:30:00	2016-05-26 10:30:00	2016-05-26 11:18:28	2016-05-26 15:00:14	18	0	\N	\N
83997	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2016-04-19 10:00:00	2016-04-19 17:00:00	\N	\N	1	0	\N	\N
85927	DELEGATION	AUCUNE	\N	\N	211	Droits des femmes 	Droits des femmes 	2016-04-28 08:30:00	2016-04-28 10:30:00	2016-04-28 11:41:51	2016-04-28 14:13:48	9	0	\N	\N
85981	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle - Ecologie - 2016 - Enjeux budgétaires droit communautaire de l'environnement - Aud. Min. Envt - M. Rol-Tanguy	2016-04-26 10:30:00	2016-04-26 11:30:00	\N	\N	1	0	\N	\N
85983	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle -  Ecologie - 2016  - Enjeux budgétaires droit communautaire de l'environnement - Aud. SGAE -M.Leglise-Costa	2016-04-26 09:30:00	2016-04-26 10:30:00	\N	\N	1	0	\N	\N
85988	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT FINC DGF	Groupe de travail FINC - Réforme de la DGF - Audition Eric Julla - RCF - EPCI et dotations de péréquation	2016-04-27 11:00:00	2016-04-27 12:45:00	\N	\N	13	0	\N	\N
89229	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Controle	Audition PPL 402 - Bocquet - Transparence vie financière - AFEP 	2016-05-03 13:30:00	2016-05-03 14:30:00	\N	\N	1	0	\N	\N
89231	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle Mission - Anciens combattants - 2016 - INI - M. Bodin - SGA- M. Barrera	2016-05-04 17:00:00	2016-05-04 18:00:00	\N	\N	1	0	\N	\N
89233	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-05-03 09:30:00	2016-05-03 10:45:00	\N	\N	2	0	\N	\N
88496	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2016-05-04 09:05:00	2016-05-04 10:10:00	2018-05-18 14:50:08	2018-05-18 14:50:12	48	1	\N	\N
82742	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-04-06 09:05:00	2016-04-06 09:10:00	2018-05-18 14:43:01	2018-05-18 14:43:05	23	0	\N	\N
89236	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-05-04 14:00:00	2016-05-04 15:00:00	\N	\N	1	0	\N	\N
89238	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-05-04 15:30:00	2016-05-04 16:30:00	\N	\N	2	0	\N	\N
89241	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	garde nationale	Audition Favier garde nationale M. Bockel Mme Jourda 	2016-05-04 15:00:00	2016-05-04 16:00:00	\N	\N	5	0	\N	\N
89263	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-05-09 09:45:00	2016-05-09 12:30:00	\N	\N	1	0	\N	\N
89265	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Audition Rapporteur FINC 	2016-05-04 16:45:00	2016-05-04 17:45:00	\N	\N	1	0	\N	\N
89267	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Audition contrôle mission "Affaires européennes" - 2016 - FEI - Audition BPCE - MM. Michelin et Nezet 	2016-05-02 15:30:00	2016-05-02 16:30:00	\N	\N	1	0	\N	\N
89269	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Audition mission Affaires européennes - 2016 - FEI - Audition société Artemid - MM. Alliany et Komilikis	2016-05-02 16:30:00	2016-05-02 17:30:00	\N	\N	1	0	\N	\N
89271	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-05-09 14:30:00	2016-05-09 17:00:00	\N	\N	1	0	\N	\N
89302	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI 	Audition Rapporteur SOCI 	2016-05-10 14:00:00	2016-05-10 16:00:00	\N	\N	1	0	\N	\N
89362	GIA	AUCUNE	\N	\N	\N	Visite Mucem	Visite Mucem	2016-05-02 11:00:00	2016-05-02 15:00:00	\N	\N	3	0	575	\N
89391	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Fraude sociale	Audition Rapporteur SOCI 	2016-05-11 15:30:00	2016-05-11 16:30:00	\N	\N	1	0	\N	\N
89393	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI 	PPL Fraude sociale	2016-05-12 09:00:00	2016-05-12 11:00:00	\N	\N	1	0	\N	\N
89395	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI 	PPL Fraude sociale	2016-05-17 14:00:00	2016-05-17 16:45:00	\N	\N	1	0	\N	\N
89397	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI 	PPL Fraude sociale	2016-05-18 16:00:00	2016-05-18 19:00:00	\N	\N	1	0	\N	\N
89504	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2016-05-10 13:30:00	2016-05-10 14:25:00	2016-05-10 16:28:45	2016-05-10 17:15:12	28	0	\N	\N
89554	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Football	Gouvernance du football	2016-05-04 14:00:00	2016-05-04 15:30:00	\N	\N	3	0	\N	\N
90027	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2016-05-10 17:00:00	2016-05-10 18:50:00	2016-05-11 11:17:06	2016-05-11 14:25:50	34	0	\N	\N
90254	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	Simplification des normes	Simplification des normes	2016-05-10 15:30:00	2016-05-10 16:30:00	\N	\N	3	0	\N	\N
90263	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Banque asiatique	PJL Banque asiatique	2016-05-12 10:35:00	2016-05-12 11:30:00	\N	\N	53	0	\N	\N
90264	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Biodiversité	PJL Biodiversité	2016-05-12 11:30:00	2016-05-12 13:20:00	\N	\N	73	0	\N	\N
90265	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au Gouvernement	Questions d'actualité au Gouvernement	2016-05-12 15:00:00	2016-05-12 16:00:00	\N	\N	230	0	\N	\N
90324	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Banque asiatique	PJL Banque asiatique	2016-05-12 16:15:00	2016-05-12 18:00:00	\N	\N	0	0	\N	\N
90325	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Biodiversité	PJL Biodiversité	2016-05-12 16:30:00	2016-05-12 19:50:00	\N	\N	51	0	\N	\N
90326	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Biodiversité	PJL Biodiversité	2016-05-12 21:00:00	2016-05-13 00:40:00	\N	\N	26	0	\N	\N
90327	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL "droit du travail"	PJL "droit du travail"	2016-05-10 12:00:00	2016-05-10 13:00:00	\N	\N	3	0	\N	\N
90331	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL "droit du travail"	PJL "droit du travail"	2016-05-10 16:00:00	2016-05-10 17:00:00	\N	\N	3	0	\N	\N
90335	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL "droit du travail"	PJL "droit du travail"	2016-05-10 18:00:00	2016-05-10 20:00:00	\N	\N	3	0	\N	\N
90339	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL "droit du travail"	PJL "droit du travail"	2016-05-11 12:00:00	2016-05-11 13:00:00	\N	\N	3	0	\N	\N
90343	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL "droit du travail"	PJL "droit du travail"	2016-05-11 15:00:00	2016-05-11 16:30:00	\N	\N	3	0	\N	\N
90347	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL "droit du travail"	PJL "droit du travail"	2016-05-11 17:30:00	2016-05-11 20:30:00	\N	\N	3	0	\N	\N
80551	GIA	AUCUNE	\N	\N	\N	GIA Caraïbes	Groupe interparlementaire Caraïbes	2016-04-07 18:00:00	2016-04-07 20:30:00	\N	\N	0	0	642	\N
83672	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	DGF	Réforme de la dotation globale de fonctionnement - 2016 - Audition de M. Julla, responsable de RCF	2016-04-06 16:30:00	2016-04-06 18:30:00	\N	\N	1	0	\N	\N
83716	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle - Mission défense -2016 - Opérations extérieures du Min. de la Défense - Audition Major général de la Marine	2016-04-07 15:00:00	2016-04-07 16:00:00	\N	\N	1	0	\N	\N
83803	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-04-06 17:00:00	2016-04-06 18:30:00	\N	\N	2	0	\N	\N
83806	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	ETRD 	ETRD 	2016-04-07 08:00:00	2016-04-07 18:00:00	\N	\N	2	0	\N	\N
83809	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD RI Eau	Audition Rapporteur CDD RI Eau 	2016-04-07 14:00:00	2016-04-07 15:15:00	\N	\N	1	0	\N	\N
83892	DELEGATION	AUCUNE	\N	\N	DSOM	Outre-mer 	Outre-mer 	2016-04-28 09:40:00	2016-04-28 12:00:00	2016-04-28 15:48:31	2016-04-28 17:17:37	12	0	\N	\N
83924	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle Mission "Ecologie, devt. durable" - 2016 -  Financement sûreté aérienne - Préfet sûreté Roissy/Bourget	2016-04-12 15:30:00	2016-04-12 16:30:00	\N	\N	1	0	\N	\N
83926	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Mission "Ecologie, dvt durable" - Contrôle financement sûreté aérienne - 2016 - Audition L. Garnier, chef UCLAT	2016-04-12 16:30:00	2016-04-12 17:30:00	\N	\N	1	0	\N	\N
84443	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition réunification de Chypre	2016-04-26 15:30:00	2016-04-26 16:30:00	\N	\N	1	0	\N	\N
84456	ETUDES	AUCUNE	\N	\N	\N	GE Sénateurs anciens combattants et mémoire combattante	Groupe d'études Sénateurs anciens combattants et mémoire combattante	2016-04-26 16:00:00	2016-04-26 17:30:00	\N	\N	8	0	\N	928
85513	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Actionnaires 	PJL Actionnaires 	2016-04-28 10:30:00	2016-04-28 10:55:00	\N	\N	39	0	\N	\N
122564	QUESTURE	AUCUNE	\N	\N	\N	Questure	\N	2016-10-04 14:30:00	2016-10-04 16:20:00	\N	\N	3	0	\N	\N
90266	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2016-05-11 09:30:00	2016-05-11 10:15:00	2016-05-11 11:16:53	2016-05-11 14:26:44	47	0	\N	\N
85515	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL République numérique	PJL République numérique	2016-04-28 10:55:00	2016-04-28 13:30:00	\N	\N	82	0	\N	\N
85516	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au Gouvernement	Questions d'actualité au Gouvernement	2016-04-28 15:00:00	2016-04-28 16:05:00	\N	\N	255	0	\N	\N
85517	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL République numérique	PJL République numérique	2016-04-28 16:20:00	2016-04-28 19:50:00	\N	\N	72	0	\N	\N
85518	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL République numérique	PJL République numérique	2016-04-28 21:35:00	2016-04-29 00:30:00	\N	\N	24	0	\N	\N
85519	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL République numérique	PJL République numérique	2016-04-29 09:30:00	2016-04-29 12:40:00	\N	\N	21	0	\N	\N
85520	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL République numérique	PJL République numérique	2016-04-29 14:30:00	2016-04-29 19:25:00	\N	\N	25	0	\N	\N
85521	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2016-04-27 16:30:00	2016-04-27 18:00:00	2016-04-28 14:46:20	2016-04-28 15:23:02	34	0	\N	\N
86078	GIA	AUCUNE	\N	\N	\N	GIA Ukraine	Groupe interparlementaire Ukraine	2016-04-26 09:00:00	2016-04-26 13:00:00	\N	\N	1	0	530	\N
86080	GIA	AUCUNE	\N	\N	\N	GIA Ukraine	Groupe interparlementaire Ukraine	2016-04-26 13:00:00	2016-04-26 14:00:00	\N	\N	2	0	530	\N
86083	COM_SPECIALE	PLENIERE	\N	COMSPEAPU	\N	Aucune 	Aucune 	2016-04-28 11:15:00	2016-04-28 12:30:00	2016-04-28 14:13:19	2016-04-28 14:15:07	6	0	\N	\N
86380	COM_ENQUETE	PLENIERE	\N	CHOMAGE	\N	commission d'enquête sur les chiffres du chômage 	commission d'enquête sur les chiffres du chômage 	2016-04-28 13:30:00	2016-04-28 14:00:00	2016-04-28 16:07:42	2016-04-28 17:19:32	13	0	\N	\N
86909	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL République numérique	PJL République numérique	2016-05-02 10:00:00	2016-05-02 13:15:00	\N	\N	23	0	\N	\N
86910	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL République numérique	PJL République numérique	2016-05-02 15:30:00	2016-05-02 20:35:00	\N	\N	39	0	\N	\N
87202	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	Déradicalisation	Désembrigadement, désendoctrinement et réinsertion des djihadistes en France et en Europe	2016-04-28 13:30:00	2016-04-28 14:45:00	\N	\N	2	0	\N	\N
87542	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE - PJL Action logement	Audition Rapporteur CAE 	2016-05-03 14:00:00	2016-05-03 15:00:00	\N	\N	1	0	\N	\N
89552	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Entreprises 	Entreprises et droit du travail	2016-05-18 14:15:00	2016-05-18 15:15:00	\N	\N	2	0	\N	\N
89556	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	ENTREPRISES	Entreprises	Déplacement en Corrèze - Table ronde avec des entrepreneurs	2016-05-20 11:00:00	2016-05-20 14:30:00	\N	\N	7	0	\N	\N
89558	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	ENTREPRISES	Entreprises	Déplacement en Corrèze - Visite de l'entreprise ECOMERIS	2016-05-20 15:10:00	2016-05-20 16:00:00	\N	\N	7	0	\N	\N
89559	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	ENTREPRISES	Entreprises	Déplacement en Corrèze	2016-05-20 16:00:00	2016-05-20 16:50:00	\N	\N	7	0	\N	\N
90351	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL "droit du travail"	PJL "droit du travail"	2016-05-12 09:00:00	2016-05-12 12:45:00	\N	\N	3	0	\N	\N
90355	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL "droit du travail"	PJL "droit du travail"	2016-05-12 14:00:00	2016-05-12 15:00:00	\N	\N	3	0	\N	\N
90359	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL "droit du travail"	PJL "droit du travail"	2016-05-12 17:00:00	2016-05-12 17:45:00	\N	\N	0	0	\N	\N
90360	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL "droit du travail"	PJL "droit du travail"	2016-05-17 12:00:00	2016-05-17 13:00:00	\N	\N	3	0	\N	\N
90364	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL "droit du travail"	PJL "droit du travail"	2016-05-17 15:00:00	2016-05-17 16:00:00	\N	\N	3	0	\N	\N
90408	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL "droit du travail"	PJL "droit du travail"	2016-05-18 15:00:00	2016-05-18 19:00:00	\N	\N	3	0	\N	\N
90413	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL "droit du travail"	PJL "droit du travail"	2016-05-19 09:00:00	2016-05-19 12:00:00	\N	\N	3	0	\N	\N
90417	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL "droit du travail"	PJL "droit du travail"	2016-05-19 14:00:00	2016-05-19 18:00:00	\N	\N	3	0	\N	\N
90421	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL "droit du travail"	PJL "droit du travail"	2016-05-24 12:00:00	2016-05-24 13:00:00	\N	\N	3	0	\N	\N
90425	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL "droit du travail"	PJL "droit du travail"	2016-05-24 15:00:00	2016-05-24 18:00:00	\N	\N	3	0	\N	\N
90429	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL "droit du travail"	PJL "droit du travail"	2016-05-24 18:00:00	2016-05-24 20:00:00	\N	\N	2	0	\N	\N
90432	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL "droit du travail"	PJL "droit du travail"	2016-05-25 14:30:00	2016-05-25 16:30:00	\N	\N	3	0	\N	\N
90436	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL "droit du travail"	PJL "droit du travail"	2016-05-26 09:00:00	2016-05-26 10:00:00	\N	\N	3	0	\N	\N
90441	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2016-05-11 09:30:00	2016-05-11 12:15:00	2016-05-11 12:32:46	2016-05-11 14:26:46	47	0	\N	\N
90499	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2016-05-11 09:05:00	2016-05-11 12:05:00	2018-05-18 14:51:41	2018-05-18 14:51:46	40	0	\N	\N
90597	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2016-05-11 10:00:00	2016-05-11 10:30:00	2018-05-18 14:52:57	2018-05-18 14:53:05	40	0	\N	\N
90648	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2016-05-11 11:05:00	2016-05-11 12:55:00	2018-05-18 14:53:35	2018-05-18 14:53:41	32	0	\N	\N
90764	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	CAE 	2016-05-11 10:25:00	2016-05-11 11:40:00	2018-05-18 14:53:20	2018-05-18 14:53:23	31	0	\N	\N
90949	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	Simplification des normes	Simplification des normes	2016-05-11 14:00:00	2016-05-11 15:00:00	\N	\N	0	0	\N	\N
90985	COM_ENQUETE	PLENIERE	\N	CHOMAGE	\N	COMMISSION D'ENQUETE	COMMISSION D'ENQUETE	2016-05-11 14:35:00	2016-05-11 16:50:00	2016-05-12 10:02:04	2016-05-12 10:38:19	17	0	\N	\N
91010	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Entreprises	Auditions Apprentissage	2016-05-18 16:00:00	2016-05-18 17:00:00	\N	\N	1	0	\N	\N
80366	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle  Paris Saclay - Direction générale de la recherche et de l'innovation (Ministère de l'écucation nationale)	2016-03-25 16:00:00	2016-03-25 17:30:00	\N	\N	1	0	\N	\N
80368	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2017 - Audition de la direction fiscale de Total 	2016-03-29 10:00:00	2016-03-29 11:00:00	\N	\N	1	0	\N	\N
83932	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle budg. Mission Sécurités-2016 - La préfecture de police de Paris - M. le député P. Goujon	2016-04-12 15:00:00	2016-04-12 17:00:00	\N	\N	1	0	\N	\N
84072	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI 	Audition Rapporteur SOCI 	2016-04-26 12:00:00	2016-04-26 19:30:00	\N	\N	3	0	\N	\N
90365	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2016-05-11 08:30:00	2016-05-11 10:20:00	2016-05-11 11:30:11	2016-05-11 14:26:43	32	0	\N	\N
90547	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2016-05-11 09:30:00	2016-05-11 10:00:00	2018-05-18 14:52:00	2018-05-18 14:52:05	38	0	\N	\N
84076	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI 	Audition Rapporteur SOCI 	2016-04-27 17:00:00	2016-04-27 20:00:00	\N	\N	3	0	\N	\N
84080	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI 	Audition Rapporteur SOCI 	2016-04-28 09:30:00	2016-04-28 13:00:00	\N	\N	3	0	\N	\N
85882	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2016-04-27 16:00:00	2016-04-27 17:00:00	\N	\N	1	0	\N	\N
86070	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle - Mission MIRES - 2016 - conditions de maintien des droits des étudiants boursiers - CPU - M.Baillat	2016-04-26 10:30:00	2016-04-26 11:30:00	\N	\N	1	0	\N	\N
86072	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle- MIRES  - 2016 - conditions de maintien des droits des étudiants boursiers - Audition Rectorat de Paris-M.Foret	2016-04-26 11:30:00	2016-04-26 12:30:00	\N	\N	1	0	\N	\N
86074	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle - MIRES - 2016 - Conditions de maintien des droits des étudiants boursiers - Audition CROUS Paris	2016-04-28 10:30:00	2016-04-28 11:30:00	\N	\N	1	0	\N	\N
86076	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2017 - Action Logement - Audition Action Logement - M. Dolci - VP	2016-04-28 09:30:00	2016-04-28 10:30:00	\N	\N	1	0	\N	\N
86719	GIA	AUCUNE	\N	\N	\N	GIA Pays du Golfe	Groupe interparlementaire Pays du Golfe	2016-04-28 09:30:00	2016-04-28 10:30:00	\N	\N	4	0	661	\N
86898	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-04-27 14:00:00	2016-04-27 16:30:00	\N	\N	2	0	\N	\N
86903	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-04-27 15:05:00	2016-04-27 16:30:00	\N	\N	1	0	\N	\N
86905	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-04-28 10:30:00	2016-04-28 10:50:00	\N	\N	3	0	\N	\N
86912	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2016-04-26 11:30:00	2016-04-26 12:00:00	\N	\N	1	0	\N	\N
86914	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2016-04-28 10:00:00	2016-04-28 10:30:00	\N	\N	1	0	\N	\N
86916	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2016-04-28 10:30:00	2016-04-28 11:00:00	\N	\N	1	0	\N	\N
86918	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2016-04-28 11:00:00	2016-04-28 11:30:00	\N	\N	1	0	\N	\N
86920	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD 	Audition Rapporteur CDD 	2016-04-28 11:30:00	2016-04-28 12:00:00	\N	\N	1	0	\N	\N
86922	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle -Mission politique des territoires - 2016 - FNADT - Audition cabinet JM Baylet, Ministre	2016-04-27 18:00:00	2016-04-27 19:00:00	\N	\N	1	0	\N	\N
86959	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Contrôle	Contrôle - Mission DAG - 2016 - DINSIC - Audition A. Hazan, contrôle général des lieux de privation de liberté	2016-04-28 09:30:00	2016-04-28 11:00:00	\N	\N	1	0	\N	\N
86961	ETUDES	AUCUNE	\N	\N	\N	GE Économie Sociale et Solidaire	Groupe d'études Économie Sociale et Solidaire	2016-04-27 08:30:00	2016-04-27 09:30:00	\N	\N	7	0	\N	998
87876	GIA	AUCUNE	\N	\N	\N	GIA Autriche	Groupe interparlementaire Autriche	2016-05-03 12:45:00	2016-05-03 14:00:00	\N	\N	1	0	579	\N
88218	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	GT simplification normes	GT simplification normes	2016-05-03 14:00:00	2016-05-03 15:15:00	\N	\N	4	0	\N	\N
88290	GIA	AUCUNE	\N	\N	\N	GIA Chine	Rencontre avec des industriels chinois du secteur viticole	2016-05-17 10:30:00	2016-05-17 11:30:00	\N	\N	7	0	584	\N
88935	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2016-05-04 11:05:00	2016-05-04 12:45:00	2018-05-18 14:50:42	2018-05-18 14:50:46	30	0	\N	\N
89061	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Controle	Audition MIRES - 2016 - Conditions de maintien des droits des étudiants boursiers - Université Paris VII - Mme Baudier	2016-05-03 17:30:00	2016-05-03 18:30:00	\N	\N	1	0	\N	\N
89075	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC  - Controle	Audition PLF 2017 - mission DAG -  SOVAFIM + Sté membres de la légion d'honneur	2016-05-03 14:00:00	2016-05-03 16:15:00	\N	\N	1	0	\N	\N
89080	MISSION	AUCUNE	\N	ISLAM	\N	MI organisation, place et financement de l'Islam en France 	MI organisation, place et financement de l'Islam en France 	2016-05-04 14:10:00	2016-05-04 16:00:00	2016-05-04 17:39:48	2016-05-04 17:49:20	13	0	\N	\N
89140	GIA	AUCUNE	\N	\N	\N	GIA Asie du Sud-Est	Groupe interparlementaire Asie du Sud-Est	2016-05-03 12:30:00	2016-05-03 14:30:00	\N	\N	12	0	609	\N
89153	GIA	AUCUNE	\N	\N	\N	GIA Québec	Groupe interparlementaire Québec	2016-04-02 11:00:00	2016-04-02 15:00:00	\N	\N	3	0	602	\N
89158	GIA	AUCUNE	\N	\N	\N	GIA Québec	Groupe interparlementaire Québec	2016-04-30 11:00:00	2016-04-30 15:30:00	\N	\N	2	0	602	\N
89164	GIA	AUCUNE	\N	\N	\N	GIA Asie du Sud-Est	Groupe interparlementaire Asie du Sud-Est	2016-04-26 12:30:00	2016-04-26 14:30:00	\N	\N	1	0	609	\N
89310	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Biodiversité	PJL Biodiversité	2016-05-11 14:30:00	2016-05-11 19:00:00	\N	\N	144	0	\N	\N
89311	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL biodiversité	PJL biodiversité	2016-05-11 21:30:00	2016-05-12 01:30:00	\N	\N	81	0	\N	\N
89312	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2016-05-10 09:35:00	2016-05-10 09:40:00	2018-05-18 14:51:22	2018-05-18 14:51:28	18	0	\N	\N
91012	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-05-11 12:05:00	2016-05-11 12:10:00	2018-05-18 14:53:54	2018-05-18 14:54:16	42	0	\N	\N
91055	MISSION	AUCUNE	\N	ISLAM	\N	MI organisation, place et financement de l'Islam en France 	MI organisation, place et financement de l'Islam en France 	2016-05-11 15:05:00	2016-05-11 16:05:00	2016-05-11 17:48:12	2016-05-11 17:51:37	8	0	\N	\N
91272	MISSION	AUCUNE	\N	TURQUIE	\N	MI Accord UE/Turquie 	MI Accord UE/Turquie 	2016-05-11 15:00:00	2016-05-11 17:45:00	2016-05-12 09:51:19	2016-05-12 10:44:49	19	0	\N	\N
91420	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-05-11 15:30:00	2016-05-11 18:30:00	\N	\N	1	0	\N	\N
91448	DELEGATION	AUCUNE	\N	\N	DSOM	Outre-mer 	Outre-mer 	2016-05-26 09:00:00	2016-05-26 11:25:00	2016-05-26 12:52:19	2016-05-26 15:00:16	10	0	\N	\N
91452	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle MIRES	2016-05-10 10:00:00	2016-05-10 12:00:00	\N	\N	1	0	\N	\N
91457	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle MIRES	2016-05-10 12:15:00	2016-05-10 14:00:00	\N	\N	1	0	\N	\N
91459	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle MIRES	2016-05-10 14:00:00	2016-05-10 16:00:00	\N	\N	1	0	\N	\N
91461	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle MIRES	2016-05-10 16:15:00	2016-05-10 17:00:00	\N	\N	1	0	\N	\N
91739	DELEGATION	AUCUNE	\N	\N	211	Droits des femmes 	Droits des femmes 	2016-05-12 09:30:00	2016-05-12 12:00:00	2016-05-12 15:45:49	2016-05-12 17:14:47	11	0	\N	\N
92025	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2016-05-12 09:05:00	2016-05-12 11:00:00	2016-05-12 16:17:41	2016-05-12 17:15:19	18	0	\N	\N
92131	COM_SPECIALE	PLENIERE	\N	COMSPEAPU	\N	Commission spéciale chargée du contrôle des comptes 	Commission spéciale chargée du contrôle des comptes 	2016-05-12 11:00:00	2016-05-12 12:15:00	2016-05-12 18:29:11	2016-05-13 08:50:39	6	0	\N	\N
92216	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Drones	PPL Drones	2016-05-17 14:30:00	2016-05-17 16:40:00	\N	\N	69	0	\N	\N
92217	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au Gouvernement	Questions d'actualité au Gouvernement	2016-05-17 16:45:00	2016-05-17 17:35:00	\N	\N	287	0	\N	\N
92218	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Drones	PPL Drones	2016-05-17 17:45:00	2016-05-17 18:00:00	\N	\N	0	0	\N	\N
92219	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Déchets radioactifs	PPL Déchets radioactifs	2016-05-17 17:45:00	2016-05-17 20:20:00	\N	\N	70	0	\N	\N
92232	GIA	AUCUNE	\N	\N	\N	GIA Italie	Groupe interparlementaire Italie	2016-05-10 08:30:00	2016-05-10 09:30:00	\N	\N	3	0	621	\N
92236	GIA	AUCUNE	\N	\N	\N	GIA Pays du Golfe	Groupe interparlementaire Pays du Golfe	2016-05-12 11:00:00	2016-05-12 14:30:00	\N	\N	8	0	661	\N
93652	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2016-05-17 18:05:00	2016-05-17 19:40:00	2016-05-18 14:53:42	2016-05-18 16:28:33	16	0	\N	\N
93738	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-05-18 10:40:00	2016-05-18 13:00:00	2016-05-18 16:01:32	2016-05-18 16:30:07	37	0	\N	\N
94233	DELEGATION	AUCUNE	\N	\N	211	Droits des femmes 	Droits des femmes 	2016-05-19 09:00:00	2016-05-19 10:30:00	2016-05-19 11:38:40	2016-05-19 14:06:29	5	0	\N	\N
94261	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2016-05-19 08:40:00	2016-05-19 10:10:00	2016-05-19 12:45:06	2016-05-19 14:07:20	13	0	\N	\N
94597	GIA	AUCUNE	\N	\N	\N	GIA Chine	Groupe interparlementaire Chine	2016-05-26 11:00:00	2016-05-26 12:30:00	\N	\N	4	0	584	\N
95252	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Football	Gouvernance du football	2016-05-25 08:30:00	2016-05-25 09:30:00	\N	\N	9	0	\N	\N
95262	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	CAE 	2016-05-25 10:05:00	2016-05-25 11:40:00	2018-05-18 14:57:20	2018-05-18 14:57:24	31	0	\N	\N
95312	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2016-05-25 09:00:00	2016-05-25 11:20:00	2016-05-25 14:38:56	2016-05-25 16:10:27	54	0	\N	\N
96236	GIA	AUCUNE	\N	\N	\N	GIA Jordanie	Groupe interparlementaire Jordanie	2016-05-25 12:30:00	2016-05-25 14:30:00	\N	\N	14	0	659	\N
96321	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2016-05-26 08:30:00	2016-05-26 10:15:00	2016-05-26 11:04:36	2016-05-26 14:49:24	14	0	\N	\N
96376	ETUDES	AUCUNE	\N	\N	\N	Groupe d'études Aviation civile	Audition de M. Patrick Gandil, directeur général de l'aviation civile (DGAC)	2016-05-26 08:30:00	2016-05-26 10:15:00	\N	\N	6	0	\N	933
96424	DELEGATION	AUDRAP	\N	\N	211	Droits des femmes 	Droits des femmes 	2016-05-25 14:00:00	2016-05-25 16:00:00	2016-05-26 11:53:06	\N	7	0	\N	\N
96426	GIA	AUCUNE	\N	\N	\N	GIA Allemagne	Groupe interparlementaire Allemagne	2016-05-24 14:30:00	2016-05-24 15:30:00	\N	\N	1	0	604	\N
96452	GIA	AUCUNE	\N	\N	\N	GIA Ukraine	Groupe interparlementaire Ukraine	2016-05-24 10:00:00	2016-05-24 11:00:00	\N	\N	2	0	530	\N
96457	GIA	AUCUNE	\N	\N	\N	GIA Pays du Cône Sud	Groupe interparlementaire Pays du Cône Sud	2016-05-24 12:30:00	2016-05-24 14:30:00	\N	\N	10	0	978	\N
96466	DELEGATION	AUCUNE	\N	\N	211	Droits des femmes 	Droits des femmes 	2016-05-26 08:30:00	2016-05-26 10:45:00	2016-05-26 12:23:22	2016-05-26 15:00:15	4	0	\N	\N
96490	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	211	Droits des femmes 	Droits des femmes 	2016-05-25 12:30:00	2016-05-25 14:00:00	\N	\N	4	0	\N	\N
96498	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	 GT Transport	GT Transport - International Transport  Forum - OECD - M. Perkins, responsable recherche/ M. Crozet - Professeur 	2016-05-26 10:30:00	2016-05-26 12:30:00	\N	\N	5	0	\N	\N
97159	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT FINC - DGF	Groupe de travail  DGF -Comité de pilotage- E. Julla - RCF	2016-05-25 14:30:00	2016-05-25 16:30:00	\N	\N	2	0	\N	\N
97172	GIA	AUCUNE	\N	\N	\N	GIA Croatie	Groupe interparlementaire Croatie	2016-05-24 13:00:00	2016-05-24 14:30:00	\N	\N	1	0	647	\N
97288	GIA	AUCUNE	\N	\N	\N	GIA Chine	Groupe interparlementaire Chine	2016-05-26 10:45:00	2016-05-26 11:30:00	\N	\N	4	0	584	\N
97298	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Conditions maintien droits étudiants boursiers	Contrôle - Mission MIRES - 2016 - Cond. maintien droits étud. boursiers - Aud. DRFIP IDF - Chef de pôle	2016-05-26 16:30:00	2016-05-26 17:40:00	\N	\N	1	0	\N	\N
97752	ETUDES	AUCUNE	\N	\N	\N	GE Forêt et filière bois	Groupe d'études Forêt et filière bois	2016-05-25 08:00:00	2016-05-25 09:00:00	\N	\N	18	0	\N	948
97892	MISSION	AUCUNE	\N	ISLAM	\N	MI organisation, place et financement de l'Islam en France 	MI organisation, place et financement de l'Islam en France 	2016-05-31 14:35:00	2016-05-31 16:00:00	2016-05-31 16:36:26	2016-05-31 17:46:02	6	0	\N	\N
98637	GIA	AUCUNE	\N	\N	\N	GIA Indonésie et Timor-Est	Déjeuner de travail avec une délégation de la Chambre des Représentants des Régions	2016-05-31 13:00:00	2016-05-31 14:20:00	\N	\N	6	0	653	\N
98732	COM_ENQUETE	PLENIERE	\N	CHOMAGE	\N	commission d'enquête sur les chiffres du chômage 	commission d'enquête sur les chiffres du chômage 	2016-05-31 18:10:00	2016-05-31 19:45:00	2016-05-31 20:13:15	2016-06-01 17:46:27	11	0	\N	\N
100094	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle CICE	Contrôle - Mission "Remboursements et dégrèvements" - CICE - Audition Médiateur des entreprises - M. Mohr	2016-06-01 11:05:00	2016-06-01 12:15:00	\N	\N	1	0	\N	\N
100172	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2016-05-31 18:00:00	2016-05-31 19:15:00	\N	\N	4	0	\N	\N
100177	GIA	AUCUNE	\N	\N	\N	GIA Australie	Groupe interparlementaire Australie	2016-06-02 17:00:00	2016-06-02 19:00:00	\N	\N	7	0	578	\N
100341	ETUDES	AUCUNE	\N	\N	\N	GE cancer	Groupe d'études cancer	2016-06-07 14:15:00	2016-06-07 14:45:00	\N	\N	6	0	\N	1004
100952	GIA	AUCUNE	\N	\N	\N	GIA Russie	Groupe interparlementaire Russie	2016-06-08 08:30:00	2016-06-08 09:30:00	\N	\N	14	0	608	\N
100972	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2016-06-08 09:05:00	2016-06-08 12:20:00	2016-06-08 13:27:00	2016-06-08 16:29:06	42	0	\N	\N
101032	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2016-06-08 09:05:00	2016-06-08 12:55:00	2016-06-08 18:29:22	2016-06-09 16:40:05	70	0	\N	\N
101336	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-06-08 09:05:00	2016-06-08 12:55:00	2018-05-18 15:02:04	2018-05-18 15:02:11	68	0	\N	\N
103054	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-06-08 18:30:00	2016-06-08 19:00:00	\N	\N	1	0	\N	\N
103112	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Travail	PJL Travail	2016-06-14 14:30:00	2016-06-14 16:45:00	\N	\N	150	0	\N	\N
103113	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au Gouvernement	Questions d'actualité au Gouvernement	2016-06-14 16:45:00	2016-06-14 17:45:00	\N	\N	289	0	\N	\N
103114	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Travail	PJL Travail	2016-06-14 18:00:00	2016-06-14 19:30:00	\N	\N	99	0	\N	\N
103115	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Travail	PJL Travail	2016-06-14 21:30:00	2016-06-15 00:35:00	\N	\N	123	0	\N	\N
93687	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-05-18 10:20:00	2016-05-18 10:40:00	2018-05-18 14:55:03	2018-05-18 14:55:11	36	0	\N	\N
95212	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	CAE 	2016-05-25 09:00:00	2016-05-25 09:55:00	2018-05-18 14:56:24	2018-05-18 14:56:33	31	0	\N	\N
103116	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Entreprises	Entreprises : auditions prospectives	2016-06-07 15:30:00	2016-06-07 17:00:00	\N	\N	1	0	\N	\N
103118	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	ENTREPRISES	Entreprises	Déplacement dans les Hautes-Alpes : table ronde	2016-06-30 11:00:00	2016-06-30 13:45:00	\N	\N	5	0	\N	\N
103119	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	ENTREPRISES	Entreprises	Déplacement dans les Hautes-Alpes : visite d'entreprise	2016-06-30 14:00:00	2016-06-30 14:45:00	\N	\N	5	0	\N	\N
103120	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	ENTREPRISES	Entreprises	Déplacement dans les Hautes-Alpes : visite d'entreprise	2016-06-30 15:00:00	2016-06-30 15:45:00	\N	\N	5	0	\N	\N
103121	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	ENTREPRISES	Entreprises	Déplacement dans les Hautes-Alpes : visite du CERPF	2016-06-30 16:00:00	2016-06-30 16:30:00	\N	\N	5	0	\N	\N
103132	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. agriculture	Audition Rapporteur contrôle agriculture 2016	2016-06-09 09:30:00	2016-06-09 11:05:00	\N	\N	2	0	\N	\N
103492	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	Séminaire UIP 	 Séminaire UIP diplomatie parlementaire	2016-06-13 09:00:00	2016-06-14 18:00:00	\N	\N	1	0	\N	\N
103512	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Travail 	PJL Travail 	2016-06-15 14:30:00	2016-06-15 19:20:00	\N	\N	167	0	\N	\N
103513	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Travail 	PJL Travail 	2016-06-15 21:30:00	2016-06-16 00:25:00	\N	\N	66	0	\N	\N
104007	COM_EURO	AUDRAP	\N	AFEU	\N	GT AFEU	GT propriété intellectuelle	2016-06-14 15:15:00	2016-06-14 15:50:00	\N	\N	3	0	\N	\N
104604	ETUDES	AUCUNE	\N	\N	\N	GE TAAF	Groupe d'études TAAF	2016-06-09 08:30:00	2016-06-09 09:30:00	\N	\N	5	0	\N	938
104632	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-06-13 14:30:00	2016-06-13 19:30:00	\N	\N	1	0	\N	\N
104634	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-06-14 09:30:00	2016-06-14 12:45:00	\N	\N	1	0	\N	\N
104636	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-06-14 15:30:00	2016-06-14 16:00:00	\N	\N	1	0	\N	\N
104817	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2016-06-14 20:30:00	2016-06-14 21:30:00	2016-06-14 23:07:06	2016-06-15 08:59:02	24	0	\N	\N
105072	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2016-06-15 09:00:00	2016-06-15 11:20:00	2018-05-18 15:06:22	2018-05-18 15:06:30	32	0	\N	\N
92500	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2016-05-17 14:30:00	2016-05-17 16:10:00	2016-05-17 17:37:06	2016-05-17 17:56:40	23	0	\N	\N
92840	COM_ENQUETE	PLENIERE	\N	CHOMAGE	\N	commission d'enquête sur les chiffres du chômage 	commission d'enquête sur les chiffres du chômage 	2016-05-17 14:30:00	2016-05-17 16:45:00	2016-05-17 17:05:35	2016-05-17 17:57:28	14	0	\N	\N
93297	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-05-17 17:30:00	2016-05-17 20:30:00	\N	\N	1	0	\N	\N
93299	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-05-17 08:40:00	2016-05-17 11:20:00	\N	\N	1	0	\N	\N
93301	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2016-05-17 13:30:00	2016-05-17 13:45:00	2016-05-18 10:48:34	2016-05-18 14:32:16	24	0	\N	\N
93341	GIA	AUCUNE	\N	\N	\N	GIA Turquie	Groupe interparlementaire Turquie	2016-05-18 08:30:00	2016-05-18 10:15:00	\N	\N	8	0	624	\N
93350	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	CAE 	2016-05-18 09:30:00	2016-05-18 11:35:00	2018-05-18 14:54:31	2018-05-18 14:54:36	32	0	\N	\N
94072	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT AFEU - Propriété intellectuelle	Groupe de travail AFEU 	2016-05-18 16:30:00	2016-05-18 17:50:00	\N	\N	4	0	\N	\N
94077	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition M. Le Drian	ETRD 	2016-05-18 16:35:00	2016-05-18 18:10:00	2018-05-18 14:55:42	2018-05-18 14:55:49	26	0	\N	\N
94305	GIA	AUCUNE	\N	\N	\N	GIA Iraq	Groupe interparlementaire Iraq	2016-05-19 10:00:00	2016-05-19 11:15:00	\N	\N	1	0	615	\N
94307	ETUDES	AUCUNE	\N	\N	\N	GE Tourisme et loisirs	Groupe d'études Tourisme et loisirs	2016-05-18 08:15:00	2016-05-18 09:30:00	\N	\N	7	0	\N	910
94315	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT CAE 	Groupe de travail CAE 	2016-05-18 14:00:00	2016-05-18 15:00:00	\N	\N	5	0	\N	\N
94324	COM_EURO	AUTRE_NON_PLENIERE	\N	AFEU	\N	AFEU 	AFEU  - Suivi TTIP	2016-05-18 17:30:00	2016-05-18 18:30:00	\N	\N	3	0	\N	\N
94331	COM_SPECIALE	PLENIERE	\N	COMSPEAPU	\N	Commission spéciale chargée du contrôle des comptes 	Commission spéciale chargée du contrôle des comptes 	2016-05-17 17:45:00	2016-05-17 19:00:00	2016-05-19 15:40:29	2016-05-19 16:19:51	7	0	\N	\N
94343	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Groupe de travail 	Groupe de travail 	2016-05-18 17:30:00	2016-05-18 18:30:00	\N	\N	2	0	\N	\N
94346	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Football	Gouvernance du football	2016-05-19 10:30:00	2016-05-19 12:15:00	\N	\N	5	0	\N	\N
94397	COM_ENQUETE	PLENIERE	\N	CHOMAGE	\N	commission d'enquête sur les chiffres du chômage 	commission d'enquête sur les chiffres du chômage 	2016-05-19 14:00:00	2016-05-19 15:50:00	2016-05-19 16:35:39	2016-05-19 18:08:58	7	0	\N	\N
94409	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Rapporteur 	Audition Rapporteur SOCI 	2016-05-18 14:00:00	2016-05-18 15:20:00	\N	\N	2	0	\N	\N
94415	ETUDES	AUCUNE	\N	\N	\N	GE Pratiques sportives	Groupe d'études Pratiques sportives	2016-05-19 08:15:00	2016-05-19 09:30:00	\N	\N	8	0	\N	934
94424	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Francophonie	Groupe de travail Francophonie	2016-05-11 14:30:00	2016-05-11 16:30:00	\N	\N	3	0	\N	\N
94456	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-05-17 15:00:00	2016-05-17 16:00:00	\N	\N	1	0	\N	\N
94458	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-05-18 14:15:00	2016-05-18 15:30:00	\N	\N	2	0	\N	\N
94461	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-05-18 15:30:00	2016-05-18 16:15:00	\N	\N	2	0	\N	\N
94464	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-05-18 15:00:00	2016-05-18 16:00:00	\N	\N	3	0	\N	\N
94468	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-05-17 15:30:00	2016-05-17 16:00:00	\N	\N	3	0	\N	\N
94472	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-05-18 14:30:00	2016-05-18 15:45:00	\N	\N	2	0	\N	\N
94475	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-05-18 15:25:00	2016-05-18 15:45:00	\N	\N	1	0	\N	\N
94477	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-05-18 15:45:00	2016-05-18 16:30:00	\N	\N	3	0	\N	\N
94481	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-05-17 14:00:00	2016-05-17 15:15:00	\N	\N	5	0	\N	\N
94487	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-05-18 14:30:00	2016-05-18 15:30:00	\N	\N	5	0	\N	\N
94493	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-05-18 15:30:00	2016-05-18 16:30:00	\N	\N	3	0	\N	\N
94497	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-05-17 15:45:00	2016-05-17 16:40:00	\N	\N	1	0	\N	\N
94499	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-05-19 15:05:00	2016-05-19 15:45:00	\N	\N	1	0	\N	\N
94572	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT FINC - Transports	GT Transports - Audition Fed. Ind. Ferroviaires - M. Audoux, délégué général	2016-05-17 16:00:00	2016-05-17 16:30:00	\N	\N	4	0	\N	\N
94613	DELEGATION	AUCUNE	\N	\N	DSOM	Outre-mer 	Outre-mer 	2016-06-02 09:30:00	2016-06-02 11:20:00	2016-06-02 12:04:02	2016-06-02 15:15:03	5	0	\N	\N
94614	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur UE-Turquie	2016-05-23 09:30:00	2016-05-23 10:30:00	\N	\N	1	0	\N	\N
94616	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur UE-Turquie	2016-05-23 11:00:00	2016-05-23 12:20:00	\N	\N	1	0	\N	\N
94618	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition  Rapporteur	Prise en charge du handicap	2016-05-25 14:00:00	2016-05-25 15:00:00	\N	\N	2	0	\N	\N
94626	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2016-05-24 09:30:00	2016-05-24 10:30:00	2018-05-18 14:56:05	2018-05-18 14:56:10	20	0	\N	\N
94835	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2016-05-24 14:30:00	2016-05-24 15:50:00	2016-05-25 08:35:38	2016-05-25 11:50:53	24	0	\N	\N
94889	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU/Négociations chypriottes	2016-05-24 14:30:00	2016-05-24 15:30:00	\N	\N	1	0	\N	\N
94903	MISSION	AUCUNE	\N	ISLAM	\N	MI organisation, place et financement de l'Islam en France 	MI organisation, place et financement de l'Islam en France 	2016-05-24 14:35:00	2016-05-24 17:10:00	2016-05-24 17:51:43	2016-05-25 11:51:24	4	0	\N	\N
94948	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2016-05-24 19:50:00	2016-05-24 20:20:00	2016-05-24 22:18:13	2016-05-25 11:50:54	23	0	\N	\N
96072	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2016-05-25 15:00:00	2016-05-25 17:20:00	2018-05-18 14:58:18	2018-05-18 14:58:22	34	0	\N	\N
96232	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Médias	PPL Médias	2016-05-26 10:30:00	2016-05-26 13:15:00	\N	\N	62	0	\N	\N
96233	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au Gouvernement	Questions d'actualité au Gouvernement	2016-05-26 15:00:00	2016-05-26 16:10:00	\N	\N	234	0	\N	\N
96234	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Médias	PPL Médias	2016-05-26 16:25:00	2016-05-26 19:30:00	\N	\N	38	0	\N	\N
96698	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle - Mission "Transports" - 2016 - Financement de la sûreté aérienne - M. Leclair et Mme Manent	2016-05-25 17:00:00	2016-05-25 18:00:00	\N	\N	1	0	\N	\N
96788	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle AGTE	M°AGTE  - Contrôle - 2016 - Réfme  adm. ss-préfectorale - Audition Cour des comptes -  M. Martin, Pdt section	2016-05-25 16:30:00	2016-05-25 17:50:00	\N	\N	1	0	\N	\N
96852	COM_ENQUETE	PLENIERE	\N	CHOMAGE	\N	commission d'enquête sur les chiffres du chômage 	commission d'enquête sur les chiffres du chômage 	2016-05-26 14:00:00	2016-05-26 15:00:00	2016-05-26 15:22:37	2016-05-27 10:37:44	12	0	\N	\N
96871	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle CICE	Contrôle - Mission "Remboursements et dégrèvements" - 2016 - CICE - Audition LA POSTE - Mme François/M. Brassart	2016-05-25 09:00:00	2016-05-25 10:05:00	\N	\N	1	0	\N	\N
96874	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle CICE	Contrôle - Mission "Remboursements et dégrèvements" - 2016 - CICE - Audition SAFRAN - MM. Delpitte et Déchelotte	2016-05-25 10:05:00	2016-05-25 11:10:00	\N	\N	1	0	\N	\N
97183	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle - Mission "Affaires européennes" - 2016 -  FEI - Audition DG Commission europ.- Mmes Diss, Thelen et Bartels	2016-05-24 15:40:00	2016-05-24 17:00:00	\N	\N	1	0	\N	\N
97185	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle - Mission "Affaires européennes" - 2016 - FEI - Audition Partech Ventures - M. Collombel	2016-05-26 14:00:00	2016-05-26 15:00:00	\N	\N	1	0	\N	\N
97190	QUESTURE	AUCUNE	\N	\N	\N	Questure	Réunion de Questure	2016-05-24 14:30:00	2016-05-24 16:30:00	\N	\N	3	0	\N	\N
97196	QUESTURE	AUCUNE	\N	\N	\N	Questure	Réunion de Questure	2016-05-26 12:30:00	2016-05-26 12:45:00	\N	\N	3	0	\N	\N
97215	GIA	AUCUNE	\N	\N	\N	GE Chrétiens d'Orient	Groupe de liaison Chrétiens d'Orient	2016-05-25 15:00:00	2016-05-25 16:30:00	\N	\N	17	0	CHRETORIENT	CHRETORIENT
92312	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	contrôle opex défense 	2016-05-12 11:00:00	2016-05-12 12:00:00	\N	\N	1	0	\N	\N
92314	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	contrôle enseignement scolaire 	2016-05-12 09:45:00	2016-05-12 13:30:00	\N	\N	1	0	\N	\N
92316	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle sûreté aérienne	2016-05-13 14:00:00	2016-05-13 15:00:00	\N	\N	1	0	\N	\N
92318	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Transparence financière	PPL Transparence financière	2016-05-18 14:30:00	2016-05-18 16:40:00	\N	\N	71	0	\N	\N
92319	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Contrôles abusifs	PPL Contrôles abusifs	2016-05-18 16:40:00	2016-05-18 18:35:00	\N	\N	64	0	\N	\N
92320	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR Crédit immobilier	PPR Crédit immobilier	2016-05-18 18:35:00	2016-05-18 19:50:00	\N	\N	31	0	\N	\N
92324	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle sûreté aérienne	2016-05-13 15:00:00	2016-05-13 16:00:00	\N	\N	1	0	\N	\N
92326	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	contrôle enseignement scolaire	2016-05-12 14:00:00	2016-05-12 17:00:00	\N	\N	1	0	\N	\N
92328	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	contrôle CADA 	2016-05-09 15:30:00	2016-05-09 16:30:00	\N	\N	1	0	\N	\N
92334	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE Constructions milieu rural	Audition Rapporteur CAE Constructions milieu rural	2016-05-11 15:15:00	2016-05-11 18:45:00	\N	\N	1	0	\N	\N
93232	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2016-05-17 17:45:00	2016-05-17 20:20:00	2016-05-18 09:26:21	2016-05-18 14:32:17	52	0	\N	\N
94502	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE Constructions milieu rural	Audition Rapporteur CAE Constructions milieu rural	2016-05-17 14:30:00	2016-05-17 16:45:00	\N	\N	1	0	\N	\N
94504	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE Constructions milieu rural	Audition Rapporteur CAE Constructions milieu rural	2016-05-18 17:00:00	2016-05-18 19:00:00	\N	\N	1	0	\N	\N
94676	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2016-05-24 09:30:00	2016-05-24 11:00:00	2016-05-24 14:44:11	2016-05-24 15:10:19	25	0	\N	\N
99419	MISSION	AUCUNE	\N	TURQUIE	\N	MI Accord UE/Turquie 	MI Accord UE/Turquie 	2016-06-01 14:30:00	2016-06-01 16:40:00	2016-06-01 17:35:03	2016-06-01 17:46:28	14	0	\N	\N
124490	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Statut de Paris	\N	2016-10-11 15:00:00	2016-10-11 16:30:00	\N	\N	4	0	\N	\N
95141	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2016-05-25 09:30:00	2016-05-25 10:15:00	2016-05-25 12:15:18	2016-05-25 16:10:21	47	0	\N	\N
98752	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2016-06-01 09:35:00	2016-06-01 10:35:00	2016-06-01 11:19:22	2016-06-01 18:05:23	32	0	\N	\N
99612	DELEGATION	AUCUNE	\N	\N	DSOM	Outre-mer 	Outre-mer 	2016-06-23 09:15:00	2016-06-23 11:10:00	2016-06-23 16:31:00	2016-06-23 16:37:57	15	0	\N	\N
99613	DELEGATION	AUCUNE	\N	\N	DSOM	Outre-mer 	Outre-mer 	2016-07-07 09:30:00	2016-07-07 10:55:00	2016-07-07 14:09:48	2016-07-07 14:43:54	9	0	\N	\N
99632	GIA	AUCUNE	\N	\N	\N	GIA Asie du Sud-Est	Groupe interparlementaire Asie du Sud-Est	2016-06-01 17:30:00	2016-06-01 19:30:00	\N	\N	2	0	609	\N
99659	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. groupe travail "Garde nationale"	Aud. groupe de travail sur la Garde nationale	2016-05-31 15:00:00	2016-05-31 16:00:00	\N	\N	3	0	\N	\N
99666	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. Groupe de travail "Garde nationale"	Audition Rapporteur ETRD  "Garde nationale"	2016-05-31 16:00:00	2016-05-31 16:35:00	\N	\N	4	0	\N	\N
99675	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD  Défense européenne	Audition Rapporteur ETRD Défense européenne 	2016-06-01 12:20:00	2016-06-01 14:00:00	\N	\N	2	0	\N	\N
99792	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2016-06-02 08:40:00	2016-06-02 09:45:00	2016-06-02 11:45:54	2016-06-02 15:15:08	11	0	\N	\N
99834	GIA	AUCUNE	\N	\N	\N	GIA Chine	Groupe interparlementaire Chine	2016-06-02 10:00:00	2016-06-02 11:00:00	\N	\N	7	0	584	\N
100192	MISSION	AUDRAP	\N	ISLAM	\N	Aud. Rapp. MI organisation, place et financement de l'Islam 	Audition Rapporteur MI organisation, place et financement de l'Islam en France 	2016-06-05 20:05:00	2016-06-07 11:45:00	\N	\N	2	0	\N	\N
100284	GIA	AUCUNE	\N	\N	\N	GIA Ukraine	Groupe interparlementaire Ukraine	2016-06-07 10:00:00	2016-06-07 11:00:00	\N	\N	3	0	530	\N
101194	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2016-06-08 10:35:00	2016-06-08 11:55:00	2018-05-18 15:02:42	2018-05-18 15:02:47	30	1	\N	\N
101949	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-06-08 14:00:00	2016-06-08 14:30:00	\N	\N	1	0	\N	\N
102066	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2016-06-09 09:00:00	2016-06-09 09:55:00	2016-06-09 12:55:00	2016-06-09 16:46:15	20	0	\N	\N
102090	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2016-06-09 10:05:00	2016-06-09 12:20:00	2016-06-09 13:06:19	2016-06-09 16:46:17	41	0	\N	\N
102234	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle APD 2015  (financements climats en faveur des PMA)	Contrôle - Mission APD - 2015 -  sur les financements climats en faveur des PMA - Audition Mission flotte commerciale 	2016-06-07 11:00:00	2016-06-07 12:35:00	\N	\N	2	0	\N	\N
102414	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF 2017 - Justice	PLF 2017 - Justice - Déplacement au Parquet national financier - Mme Houlette - M. Toublanc 	2016-06-07 17:00:00	2016-06-07 18:30:00	\N	\N	3	0	\N	\N
102437	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Groupe de travail DGF	Groupe de travail  DGF -Comité de pilotage- E. Julla - RCF	2016-06-07 14:00:00	2016-06-07 16:30:00	\N	\N	2	0	\N	\N
102444	ETUDES	AUCUNE	\N	\N	\N	Aucune 	Aucune 	2016-06-09 08:30:00	2016-06-09 09:30:00	\N	\N	5	0	\N	938
102454	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF 2017  - Justice	PLF 2017 - Mission Justice - Aud° SG du Cté interministériel de prévention de la déliquance / radicalisat° -M. N'Gahane	2016-06-08 15:00:00	2016-06-08 16:15:00	\N	\N	1	0	\N	\N
102496	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-06-09 14:00:00	2016-06-09 15:00:00	\N	\N	1	0	\N	\N
102817	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-06-08 14:35:00	2016-06-08 18:55:00	2018-05-18 15:03:06	2018-05-18 15:03:11	15	0	\N	\N
102854	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Contrôle Etudiants boursiers	Contrôle -Mission MIRES-2016-Cond./  maintien des droits étudiants boursiersboursiers - Table ronde assoc. étudiantes	2016-06-09 09:30:00	2016-06-09 10:30:00	\N	\N	1	0	\N	\N
102857	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Football	Gouvernance du football	2016-06-09 09:40:00	2016-06-09 11:00:00	\N	\N	4	0	\N	\N
102870	COM_ENQUETE	PLENIERE	\N	CHOMAGE	\N	commission d'enquête sur les chiffres du chômage 	commission d'enquête sur les chiffres du chômage 	2016-06-09 14:10:00	2016-06-09 15:00:00	2016-06-09 17:46:00	2016-06-09 17:56:25	6	0	\N	\N
102878	GIA	AUCUNE	\N	\N	\N	GIA Afrique centrale	Groupe interparlementaire Afrique centrale	2016-06-08 16:30:00	2016-06-08 17:30:00	\N	\N	1	0	572	\N
102892	COM_ENQUETE	PLENIERE	\N	CHOMAGE	\N	commission d'enquête sur les chiffres du chômage 	commission d'enquête sur les chiffres du chômage 	2016-06-09 16:10:00	2016-06-09 17:20:00	2016-06-09 17:50:38	2016-06-09 17:56:26	8	0	\N	\N
102912	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	contrôle FEI	2016-06-06 11:30:00	2016-06-06 12:30:00	\N	\N	1	0	\N	\N
102914	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	contrôle FEI	2016-06-06 13:30:00	2016-06-06 15:30:00	\N	\N	1	0	\N	\N
102916	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	contrôle FEI	2016-06-06 16:00:00	2016-06-06 17:00:00	\N	\N	1	0	\N	\N
102918	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	contrôle FEI	2016-06-07 09:00:00	2016-06-07 10:00:00	\N	\N	1	0	\N	\N
102920	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	contrôle FEI	2016-06-07 10:30:00	2016-06-07 11:30:00	\N	\N	1	0	\N	\N
102922	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	contrôle FEI	2016-06-07 12:00:00	2016-06-07 13:00:00	\N	\N	1	0	\N	\N
102932	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	contrôle FEI	2016-06-07 13:00:00	2016-06-07 15:00:00	\N	\N	1	0	\N	\N
102934	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	contrôle FEI	2016-06-07 15:30:00	2016-06-07 16:00:00	\N	\N	1	0	\N	\N
102936	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	contrôle FEI	2016-06-07 16:00:00	2016-06-07 17:00:00	\N	\N	1	0	\N	\N
103092	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. Contrôle FNADT	Contrôle -Mission "Politique des territoires"  - 2016 - FNADT - Audition DGCL- Mme Taheri (ssdirFL) -M. Bayle	2016-05-18 14:00:00	2016-05-18 15:00:00	\N	\N	0	0	\N	\N
103165	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2016-06-13 13:30:00	2016-06-13 15:30:00	2016-06-13 16:29:01	2016-06-13 17:20:09	27	0	\N	\N
103260	DELEGATION	AUDRAP	\N	\N	COLTER	RI Evolution des missions des services déconcentrés	\N	2016-06-01 15:00:00	2016-06-01 16:00:00	\N	\N	2	0	\N	\N
103263	DELEGATION	AUDRAP	\N	\N	COLTER	RI Evolution des missions des services déconcentrés	\N	2016-06-08 17:00:00	2016-06-08 18:00:00	\N	\N	2	0	\N	\N
92288	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle mission agriculture 	2016-05-12 09:30:00	2016-05-12 11:10:00	\N	\N	2	0	\N	\N
92291	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle anciens combattants	2016-05-12 16:00:00	2016-05-12 18:25:00	\N	\N	1	0	\N	\N
92409	MISSION	AUCUNE	\N	ISLAM	\N	MI organisation, place et financement de l'Islam en France 	MI organisation, place et financement de l'Islam en France 	2016-05-17 13:30:00	2016-05-17 14:35:00	2016-05-17 16:01:36	2016-05-17 17:57:27	9	0	\N	\N
93547	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2016-05-18 09:35:00	2016-05-18 12:35:00	2016-05-18 14:43:06	2016-05-18 16:30:10	46	0	\N	\N
94550	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	contrôle FNADT 	2016-05-18 14:00:00	2016-05-18 15:00:00	\N	\N	1	0	\N	\N
94552	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	contrôle FNADT	2016-05-18 15:00:00	2016-05-18 16:00:00	\N	\N	1	0	\N	\N
94554	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle - Mission "Affaires européennes" - 2016 - FEI - Cour des Comptes européenne - M. Weber	2016-05-19 14:30:00	2016-05-19 16:00:00	\N	\N	1	0	\N	\N
94556	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle - Mission "Affaires européennes" - 2016 -  FEI - Audition BEI - M. Fayolle, vice-pdt	2016-05-19 17:00:00	2016-05-19 18:00:00	\N	\N	1	0	\N	\N
94558	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle - Mission "Affaires européennes" - 2016 - FEI - DG ECFIN - M. Angel - Directeur du trésor et op.financières	2016-05-19 18:30:00	2016-05-19 19:30:00	\N	\N	1	0	\N	\N
94560	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle - Mission "Aff.  européennes" - 2016 - FEI - Audition FEI - M. Gilibert - Dir. exec - Mme Leander - SG 	2016-05-20 09:00:00	2016-05-20 12:30:00	\N	\N	1	0	\N	\N
94594	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE - Action Logement	Audition Rapporteur CAE 	2016-05-17 17:35:00	2016-05-17 18:45:00	\N	\N	2	0	\N	\N
96131	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-05-25 15:15:00	2016-05-25 18:15:00	\N	\N	2	0	\N	\N
96412	GIA	AUCUNE	\N	\N	\N	GIA Afghanistan	Groupe interparlementaire Afghanistan	2016-05-25 08:30:00	2016-05-25 09:30:00	\N	\N	1	0	648	\N
96598	MISSION	AUDRAP	\N	ISLAM	\N	Aud. Rapp. MI organisation, place et financement de l'Islam 	Audition Rapporteur MI organisation, place et financement de l'Islam en France 	2016-05-24 10:30:00	2016-05-24 12:30:00	\N	\N	2	0	\N	\N
96885	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Santé INCa	Contrôle - Mission "Santé" - 2016 - INCa - Audition DGRI - M. Genet	2016-05-24 15:00:00	2016-05-24 16:00:00	\N	\N	1	0	\N	\N
96888	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle INCa	Contrôle - Mission "Santé" - 2016 - INCa - Audition ARS IDF - Mme Legrand	2016-05-25 16:30:00	2016-05-25 17:45:00	\N	\N	1	0	\N	\N
96890	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Santé INCa	Contrôle - Mission "Santé" - 2016 - INCa - Audition FHF - M. Ifrah 	2016-05-26 14:00:00	2016-05-26 15:00:00	\N	\N	1	0	\N	\N
97214	DELEGATION	AUCUNE	\N	\N	206	Audition réseau électrique	Audition publique  Les enjeux technologiques de l¿intégration des énergies renouvelables au réseau électrique 	2016-05-26 14:30:00	2016-05-26 18:30:00	2016-05-27 12:13:49	2016-05-27 17:17:25	3	0	\N	\N
98793	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Autorités publiques indépendantes 	PPL Autorités publiques indépendantes 	2016-06-02 10:30:00	2016-06-02 12:55:00	\N	\N	47	0	\N	\N
100152	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Controle	Contrôle - Mission "Santé" - 2016 - DGS - Mme Amprou - Dir-adj. de la Santé 	2016-05-31 14:00:00	2016-05-31 15:00:00	\N	\N	1	0	\N	\N
100154	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Controle	Contrôle - Mission Santé - 2016 - INCa - Aud. Canceropôle IDF -M.Fridman (Pdt),M. Puig (Dir. Scient.),Mme Gramain (SG) 	2016-05-31 17:30:00	2016-05-31 19:00:00	\N	\N	1	0	\N	\N
100158	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-06-01 17:00:00	2016-06-01 17:45:00	\N	\N	1	0	\N	\N
100160	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2016-06-07 09:30:00	2016-06-07 12:20:00	\N	\N	28	0	\N	\N
100161	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Bilan annuel de l'application des lois	Débat Bilan annuel de l'application des lois	2016-06-07 14:30:00	2016-06-07 16:25:00	\N	\N	49	0	\N	\N
100162	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Transition énergétique	Débat Transition énergétique	2016-06-07 16:45:00	2016-06-07 18:15:00	\N	\N	63	0	\N	\N
100163	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Économie bleue	CMP Économie bleue	2016-06-07 18:25:00	2016-06-07 19:25:00	\N	\N	51	0	\N	\N
100164	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Réforme politique agricole commune	Débat Réforme politique agricole commune	2016-06-07 21:35:00	2016-06-07 23:15:00	\N	\N	42	0	\N	\N
100253	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	Groupe de travail 	Groupe de travail 	2016-05-31 15:30:00	2016-05-31 16:15:00	\N	\N	9	0	\N	\N
100411	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT AFEU 	Groupe de travail AFEU propriété intellectuelle	2016-06-07 15:30:00	2016-06-07 16:40:00	\N	\N	2	0	\N	\N
100449	COM_PERMANENTE	AUTRE	\N	ETRD	\N	audition de Mme Bouchamaoui	Audition de Mme Ouided Bouchamaoui, prix Nobel de la Paix 2015	2016-06-07 16:05:00	2016-06-07 17:15:00	2016-06-07 18:03:36	2016-06-08 11:09:44	15	0	\N	\N
100772	COM_ENQUETE	PLENIERE	\N	CHOMAGE	\N	commission d'enquête sur les chiffres du chômage 	commission d'enquête sur les chiffres du chômage 	2016-06-07 17:15:00	2016-06-07 19:25:00	2016-06-08 10:20:35	2016-06-08 11:11:48	11	0	\N	\N
100792	QUESTURE	AUCUNE	\N	\N	\N	Questure	Réunion de Questure	2001-06-07 16:00:00	2001-06-07 18:00:00	\N	\N	0	0	\N	\N
100793	QUESTURE	AUCUNE	\N	\N	\N	Questure	Réunion de Questure	2016-06-07 16:00:00	2016-06-07 18:00:00	\N	\N	3	0	\N	\N
100797	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	CAE 	2016-06-08 09:35:00	2016-06-08 10:45:00	2016-06-08 11:50:15	2016-06-08 16:29:04	25	0	\N	\N
100899	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2016-06-08 09:35:00	2016-06-08 11:15:00	2018-05-18 15:02:24	2018-05-18 15:02:32	30	0	\N	\N
101186	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Nouvelles organisations intercommunales	Débat Nouvelles organisations intercommunales	2016-06-09 11:00:00	2016-06-09 12:45:00	\N	\N	54	0	\N	\N
101190	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au Gouvernement	Questions d'actualité au Gouvernement	2016-06-09 15:00:00	2016-06-09 16:05:00	\N	\N	234	0	\N	\N
101191	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Accord économique Canada	Débat Accord économique Canada	2016-06-09 16:20:00	2016-06-09 17:55:00	\N	\N	26	0	\N	\N
101420	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI Art. 27 Loi Dialogue social et emploi	Art. 27 Loi Dialogue social	2016-06-08 14:30:00	2016-06-08 16:30:00	\N	\N	1	0	\N	\N
102952	MISSION	AUCUNE	\N	REVENU	\N	MI Revenu de base en France 	MI Revenu de base en France 	2016-06-09 13:35:00	2016-06-09 14:50:00	2016-06-10 12:07:13	2016-06-10 12:23:01	14	0	\N	\N
102969	MISSION	AUCUNE	\N	REVENU	\N	MI Revenu de base en France 	MI Revenu de base en France 	2016-06-09 16:20:00	2016-06-09 17:30:00	2016-06-10 12:05:58	2016-06-10 12:23:03	7	0	\N	\N
102992	ETUDES	AUCUNE	\N	\N	\N	GE Energie	Groupe d'études Energie	2016-06-08 08:15:00	2016-06-08 09:30:00	\N	\N	14	0	\N	906
103007	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE - PJL Sapin	Audition Rapporteur CAE 	2016-06-08 16:00:00	2016-06-08 19:30:00	\N	\N	1	0	\N	\N
103009	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE - PJL SAPIN	Audition Rapporteur CAE 	2016-06-09 09:00:00	2016-06-09 11:00:00	\N	\N	1	0	\N	\N
103012	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-06-07 12:45:00	2016-06-07 14:15:00	\N	\N	2	0	\N	\N
103032	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE PPL 585	Audition Rapporteur CAE PPL 585	2016-06-07 18:15:00	2016-06-07 19:00:00	\N	\N	1	0	\N	\N
103034	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE PPL 585	Audition Rapporteur CAE PPL 585 	2016-06-08 15:00:00	2016-06-08 15:45:00	\N	\N	1	0	\N	\N
103266	DELEGATION	AUDRAP	\N	\N	COLTER	RI - Evolution des missions des services déconcentrés	\N	2016-06-08 18:00:00	2016-06-08 19:00:00	\N	\N	2	0	\N	\N
103269	DELEGATION	AUDRAP	\N	\N	COLTER	RI - Evolution des missions des services déconcentrés	\N	2016-06-14 15:00:00	2016-06-14 16:25:00	\N	\N	2	0	\N	\N
103272	DELEGATION	AUDRAP	\N	\N	COLTER	Collectivités  territoriales 	Collectivités  territoriales 	2016-04-26 00:00:00	2016-04-26 00:00:00	\N	\N	0	0	\N	\N
103415	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2016-06-13 21:45:00	2016-06-13 22:45:00	2016-06-13 23:11:19	2016-06-14 09:18:19	28	0	\N	\N
103532	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2016-06-14 09:30:00	2016-06-14 10:30:00	2016-06-14 12:21:26	2016-06-14 15:08:16	38	0	\N	\N
92262	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT FINC 	Financement des infrastructures de transport	2016-05-12 10:00:00	2016-05-12 11:30:00	\N	\N	6	0	\N	\N
92269	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT FINC 	Financement des infrastructures de transport	2016-05-12 11:30:00	2016-05-12 12:30:00	\N	\N	6	0	\N	\N
92276	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle INCa 	2016-05-10 14:00:00	2016-05-10 15:00:00	\N	\N	1	0	\N	\N
92278	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle INCa	2016-05-10 16:00:00	2016-05-10 17:00:00	\N	\N	1	0	\N	\N
92280	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle INCa	2016-05-12 14:00:00	2016-05-12 15:00:00	\N	\N	1	0	\N	\N
92282	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle INCa	2016-05-12 16:30:00	2016-05-12 17:30:00	\N	\N	1	0	\N	\N
92283	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	CAS Patrimoine immobilier de l'Etat 	2016-05-11 14:30:00	2016-05-11 16:30:00	\N	\N	2	0	\N	\N
92286	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle sûreté aérienne 	2016-05-11 14:30:00	2016-05-11 15:30:00	\N	\N	1	0	\N	\N
92382	GIA	AUCUNE	\N	\N	\N	GIA Brésil	Assemblée générale du groupe d'amitié France-Brésil	2016-05-17 14:00:00	2016-05-17 15:00:00	\N	\N	11	0	576	\N
92399	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Contrôle	Audition Rapporteur FINC 	2016-05-12 07:00:00	2016-05-13 22:00:00	\N	\N	1	0	\N	\N
93850	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Controle	Contrôle - Mission "Santé" - 2016 - INCA - Audition direction du Budget -M. Juéry et Mme Moisset	2016-05-17 14:00:00	2016-05-17 15:00:00	\N	\N	1	0	\N	\N
93947	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Controle	Contrôle - 2016 - Missions locales - Audition du Ministère du Travail et de l'Emploi - Mmes Agoumi, Jaeggy-Roulmann...	2016-05-17 17:45:00	2016-05-17 19:00:00	\N	\N	2	0	\N	\N
93950	MISSION	AUCUNE	\N	ISLAM	\N	MI organisation, place et financement de l'Islam en France 	MI organisation, place et financement de l'Islam en France 	2016-05-18 15:05:00	2016-05-18 16:20:00	2016-05-18 17:26:15	2016-05-18 17:36:08	9	0	\N	\N
94622	GIA	AUCUNE	\N	\N	\N	GIA Pays du Golfe	Groupe interparlementaire Pays du Golfe	2016-05-23 09:30:00	2016-05-23 18:00:00	\N	\N	2	0	661	\N
94734	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Lutte contre le crime organisé	CMP Lutte contre le crime organisé	2016-05-25 14:30:00	2016-05-25 15:40:00	\N	\N	54	0	\N	\N
94735	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Architecture	PJL Architecture	2016-05-25 16:00:00	2016-05-25 19:40:00	\N	\N	116	0	\N	\N
94736	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Architecture	PJL Architecture	2016-05-25 21:30:00	2016-05-26 01:20:00	\N	\N	70	0	\N	\N
94737	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Médias	PPL Médias	2016-05-25 14:30:00	2016-05-25 20:00:00	\N	\N	0	0	\N	\N
94738	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Médias	PPL Médias	2016-05-25 20:30:00	2016-05-26 00:30:00	\N	\N	0	0	\N	\N
95432	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2016-05-25 09:05:00	2016-05-25 13:00:00	2018-05-18 14:57:02	2018-05-18 14:57:09	40	0	\N	\N
95527	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-05-25 09:40:00	2016-05-25 10:25:00	2016-05-25 15:15:27	2016-05-25 16:10:20	41	0	\N	\N
95984	MISSION	AUCUNE	\N	TURQUIE	\N	MI Accord UE/Turquie 	MI Accord UE/Turquie 	2016-05-25 14:25:00	2016-05-25 16:35:00	2016-05-25 17:06:02	2016-05-25 17:31:02	14	0	\N	\N
96639	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-05-24 14:10:00	2016-05-24 18:30:00	\N	\N	1	0	\N	\N
96644	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-05-25 15:45:00	2016-05-25 17:45:00	\N	\N	1	0	\N	\N
96876	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	GT LOIS 	Groupe de travail LOIS 	2016-05-25 16:45:00	2016-05-25 17:45:00	\N	\N	3	0	\N	\N
97532	ETUDES	AUCUNE	\N	\N	\N	GE Chasse et pêche	Groupe d'études Chasse et pêche	2016-05-27 11:00:00	2016-05-27 18:30:00	\N	\N	2	0	\N	907
99292	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de M. Michel Barnier	ETRD 	2016-06-01 10:55:00	2016-06-01 12:05:00	2018-05-18 15:00:54	2018-05-18 15:01:07	25	0	\N	\N
99479	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Francophonie	Groupe de travail Francophonie	2016-06-01 15:00:00	2016-06-01 18:15:00	\N	\N	3	0	\N	\N
99532	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2016-06-01 14:30:00	2016-06-01 19:30:00	2016-06-02 01:50:02	2016-06-02 15:14:27	50	0	\N	\N
102804	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT FINC Transport	Groupe de travail FINC Transport	2016-06-09 10:30:00	2016-06-09 12:00:00	\N	\N	4	0	\N	\N
103038	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle - Mission Santé - 2016 - INCa - M. Wanecq (ss-dir) - Mme Monasse (chef bureau) 	2016-06-09 16:00:00	2016-06-09 17:00:00	\N	\N	1	0	\N	\N
103052	GIA	AUCUNE	\N	\N	\N	GIA Caraïbes	Entretien avec une délégation cubaineGroupe interparlementaire Caraïbes	2016-06-06 17:00:00	2016-06-06 18:00:00	\N	\N	1	0	642	\N
103234	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-06-09 10:00:00	2016-06-09 10:45:00	\N	\N	2	0	\N	\N
103691	DELEGATION	AUCUNE	\N	\N	206	AP communications électroniques 	Audition publique : "Le brouillage des communications électroniques : enjeux, limites et solutions"	2016-06-14 09:20:00	2016-06-14 12:05:00	2016-06-14 16:15:28	2016-06-14 18:07:43	3	0	\N	\N
103908	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-06-14 14:30:00	2016-06-14 15:30:00	\N	\N	1	0	\N	\N
103936	DELEGATION	AUCUNE	\N	\N	206	AP valorisation de la recherche	Audition publique, ouverte à la presse, sur « La valorisation de la recherche »	2016-06-30 09:00:00	2016-06-30 18:35:00	2016-07-01 19:13:48	2016-07-04 11:52:30	4	0	\N	\N
103971	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière	Réunion plénière	2016-06-28 18:40:00	2016-06-28 20:30:00	2016-06-29 13:15:37	2016-06-29 16:55:03	13	0	\N	\N
104236	MISSION	AUDRAP	\N	REVENU	\N	Aud. Rapp. MI Revenu de base en France 	Audition Rapporteur MI Revenu de base en France 	2016-06-14 15:35:00	2016-06-14 16:55:00	\N	\N	6	0	\N	\N
104892	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-06-14 17:55:00	2016-06-14 19:35:00	2018-05-18 15:04:58	2018-05-18 15:05:05	32	0	\N	\N
104932	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2016-06-14 17:55:00	2016-06-14 19:35:00	2018-05-18 15:05:56	2018-05-18 15:06:03	32	0	\N	\N
95371	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2016-05-25 11:25:00	2016-05-25 12:55:00	2016-05-25 13:33:02	2016-05-25 16:10:11	54	0	\N	\N
95591	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-05-25 10:25:00	2016-05-25 12:55:00	2018-05-18 14:57:38	2018-05-18 14:57:44	43	0	\N	\N
104972	GIA	AUCUNE	\N	\N	\N	GIA Népal	Groupe interparlementaire Népal	2016-06-14 10:00:00	2016-06-14 11:00:00	\N	\N	1	0	633	\N
105122	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE 	Audition Rapporteur CAE 	2016-06-14 18:00:00	2016-06-14 19:30:00	\N	\N	4	0	\N	\N
105132	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2016-06-15 10:30:00	2016-06-15 12:00:00	2016-06-15 14:58:36	2016-06-15 16:31:34	37	0	\N	\N
105416	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2016-06-15 11:20:00	2016-06-15 12:40:00	2016-06-15 15:40:19	2016-06-15 16:31:33	29	0	\N	\N
105594	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-06-15 11:15:00	2016-06-15 12:55:00	2018-05-18 15:07:08	2018-05-18 15:07:45	57	0	\N	\N
105732	MISSION	AUCUNE	\N	TURQUIE	\N	MI Accord UE/Turquie 	MI Accord UE/Turquie 	2016-06-15 14:30:00	2016-06-15 17:10:00	2016-06-15 17:45:49	2016-06-15 17:48:58	11	0	\N	\N
105752	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2016-06-15 14:35:00	2016-06-15 16:40:00	2016-06-16 11:18:20	2016-06-16 14:02:43	32	0	\N	\N
105815	QUESTURE	AUCUNE	\N	\N	\N	Questure	Réunion de Questure	2016-06-14 15:00:00	2016-06-14 16:40:00	\N	\N	3	0	\N	\N
105819	QUESTURE	AUCUNE	\N	\N	\N	Questure	Réunion de Questure	2016-06-14 18:30:00	2016-06-14 18:50:00	\N	\N	3	0	\N	\N
106032	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	CAE 	2016-06-15 10:00:00	2016-06-15 11:00:00	2016-06-16 09:54:34	2016-06-16 10:47:35	28	0	\N	\N
106052	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Conventions internationales	Conventions internationales	2016-06-16 10:30:00	2016-06-16 10:35:00	\N	\N	26	0	\N	\N
106067	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Travail 	PJL Travail 	2016-06-16 14:50:00	2016-06-16 19:30:00	\N	\N	66	0	\N	\N
106068	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Travail 	PJL Travail 	2016-06-16 21:10:00	2016-06-17 00:00:00	\N	\N	28	0	\N	\N
106069	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Travail 	PJL Travail 	2016-06-17 09:30:00	2016-06-17 12:50:00	\N	\N	31	0	\N	\N
92330	GIA	AUCUNE	\N	\N	\N	GIA Brésil	Rencontre avec le ministre de l'intérieur Bernard CAZENEUVE	2016-04-27 16:30:00	2016-04-27 18:30:00	\N	\N	3	0	576	\N
93438	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2016-05-18 09:00:00	2016-05-18 12:55:00	2016-05-18 13:18:22	2016-05-18 16:30:12	48	0	\N	\N
93496	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2016-05-18 09:45:00	2016-05-18 13:05:00	2018-05-18 14:54:47	2018-05-18 14:54:53	39	0	\N	\N
93548	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT FINC - Transports	GT Transports - Audition DGITM - M. Poupard - DG	2016-05-17 14:00:00	2016-05-17 16:00:00	\N	\N	4	0	\N	\N
93672	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition UE-Turquie	2016-05-12 11:00:00	2016-05-12 13:00:00	\N	\N	2	0	\N	\N
93679	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition UE-Turquie	2016-05-17 14:30:00	2016-05-17 15:40:00	\N	\N	2	0	\N	\N
93682	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition UE-Turquie	2016-05-17 16:00:00	2016-05-17 17:00:00	\N	\N	1	0	\N	\N
93684	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition UE-Turquie	2016-05-18 08:30:00	2016-05-18 10:00:00	\N	\N	2	0	\N	\N
93961	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Participation des employeurs	PJL Participation des employeurs	2016-05-19 10:30:00	2016-05-19 12:20:00	\N	\N	39	0	\N	\N
93962	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR Revenu de base	PPR Revenu de base	2016-05-19 14:40:00	2016-05-19 16:20:00	\N	\N	32	0	\N	\N
93963	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Alimentation	PPL Alimentation	2016-05-19 16:20:00	2016-05-19 17:20:00	\N	\N	22	0	\N	\N
93976	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	FINC	\N	FINC 	Groupe d'études - Aviation civile  - Audition ADP - M. De Romanet, M. Pascal, Mme Rossat-Mignod	2016-05-12 08:30:00	2016-05-12 10:00:00	\N	\N	6	0	\N	\N
94136	MISSION	AUCUNE	\N	TURQUIE	\N	MI Accord UE/Turquie 	MI Accord UE/Turquie 	2016-05-18 14:30:00	2016-05-18 17:10:00	2016-05-19 10:05:48	2016-05-19 14:07:56	12	0	\N	\N
94153	DELEGATION	AUCUNE	\N	\N	PROS	Délégation sénatoriale à la prospective 	Délégation sénatoriale à la prospective 	2016-05-19 08:30:00	2016-05-19 09:45:00	2016-05-19 10:15:47	2016-05-19 14:06:32	10	0	\N	\N
94188	DELEGATION	AUCUNE	\N	\N	PROS	Audition de J. K. Galbraith	Audition de J. K. Galbraith	2016-05-26 08:30:00	2016-05-26 09:50:00	2016-05-26 18:20:48	2016-05-27 10:37:52	19	0	\N	\N
94220	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Architecture	PJL Architecture	2016-05-24 14:30:00	2016-05-24 19:50:00	\N	\N	125	0	\N	\N
94221	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Architecture	PJL Architecture	2016-05-24 21:50:00	2016-05-25 00:25:00	\N	\N	62	0	\N	\N
94227	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur UE-Turquie	2016-05-18 17:00:00	2016-05-18 18:00:00	\N	\N	2	0	\N	\N
94452	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle -  Mission Santé - 2016 - INCA - Audition MG France - M. Philippe Marissal  	2016-05-19 14:30:00	2016-05-19 16:00:00	\N	\N	1	0	\N	\N
94454	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle - Mission "Santé"" - 2016 - INCA - Audition de Mme Agnès Buzyn	2016-05-19 16:15:00	2016-05-19 17:00:00	\N	\N	1	0	\N	\N
94517	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2017 - Mission Justice  - Syndicat des cadres de la sécurité intérieure - Mme Pons Mesouaki	2016-05-17 15:00:00	2016-05-17 15:35:00	\N	\N	1	0	\N	\N
94519	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2017 - Mission Justice - Audition Alliance Police Nationale - M. Gaudon	2016-05-17 15:30:00	2016-05-17 16:10:00	\N	\N	1	0	\N	\N
94521	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2017 - Mission  Justice - Audition Syndicat des commissaires de la police nationale - M. Taltavull	2016-05-17 18:00:00	2016-05-17 19:00:00	\N	\N	1	0	\N	\N
94523	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Audition PLF - Entretien pratiques non éthiques de Mc Donalds - EPSO - CGT - FO - Arcturus	2016-05-11 15:00:00	2016-05-11 16:00:00	\N	\N	1	0	\N	\N
95978	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Fraude sociale	PPL Fraude sociale	2016-05-31 14:30:00	2016-05-31 16:45:00	\N	\N	125	0	\N	\N
95979	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au Gouvernement	Questions d'actualité au Gouvernement	2016-05-31 16:45:00	2016-05-31 17:30:00	\N	\N	304	0	\N	\N
95980	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Fraude sociale	PPL Fraude sociale	2016-05-31 17:30:00	2016-05-31 18:15:00	\N	\N	62	0	\N	\N
96002	COM_ENQUETE	PLENIERE	\N	CHOMAGE	\N	commission d'enquête sur les chiffres du chômage 	commission d'enquête sur les chiffres du chômage 	2016-05-25 14:00:00	2016-05-25 15:20:00	2016-05-25 17:09:26	2016-05-25 17:31:01	21	0	\N	\N
97195	ETUDES	AUCUNE	\N	\N	\N	GE Industrie	Groupe d'études Industrie	2016-05-25 08:00:00	2016-05-25 09:00:00	\N	\N	7	0	\N	957
97332	ETUDES	AUCUNE	\N	\N	\N	GE Sénateurs anciens combattants et mémoire combattante	Groupe d'études Sénateurs anciens combattants et mémoire combattante	2016-05-26 09:20:00	2016-05-26 11:00:00	\N	\N	6	0	\N	928
97432	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT CAE 	Groupe de travail CAE 	2016-05-24 18:00:00	2016-05-24 19:00:00	\N	\N	2	0	\N	\N
105344	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2016-06-15 09:30:00	2016-06-15 11:35:00	2016-06-15 16:01:05	2016-06-15 16:31:36	49	0	\N	\N
97452	BUREAU	AUCUNE	\N	\N	\N	Délégation du Bureau	Délégation du Bureau statut et conditions d'exercice mandat de sénateur	2016-05-25 11:30:00	2016-05-25 12:30:00	\N	\N	5	0	\N	\N
97458	BUREAU	AUCUNE	\N	\N	\N	Bureau	Réunion du Bureau	2016-05-26 09:15:00	2016-05-26 12:30:00	\N	\N	23	0	\N	\N
97592	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Construction en milieu rural	PPL Construction en milieu rural	2016-06-01 17:00:00	2016-06-01 19:40:00	\N	\N	2	0	\N	\N
97594	GIA	AUCUNE	\N	\N	\N	GIA Afrique de l'Ouest	Groupe interparlementaire Afrique de l'Ouest	2016-05-27 08:00:00	2016-05-27 13:20:00	\N	\N	2	0	573	\N
97612	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2016-05-31 13:30:00	2016-05-31 13:45:00	2016-05-31 14:29:57	2016-05-31 16:32:56	15	0	\N	\N
97652	MISSION	AUCUNE	\N	REVENU	\N	MI Revenu de base en France 	MI Revenu de base en France 	2016-05-31 13:40:00	2016-05-31 13:55:00	2016-05-31 16:06:59	2016-05-31 16:33:35	12	0	\N	\N
98892	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-05-31 18:00:00	2016-05-31 18:45:00	\N	\N	1	0	\N	\N
98972	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2016-06-01 09:30:00	2016-06-01 12:00:00	2018-05-18 14:59:22	2018-05-18 14:59:29	36	0	\N	\N
99032	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-06-01 09:40:00	2016-06-01 09:55:00	2018-05-18 14:59:58	2018-05-18 15:00:04	40	0	\N	\N
99212	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-06-01 08:35:00	2016-06-01 09:05:00	2018-05-18 14:58:40	2018-05-18 14:58:45	24	0	\N	\N
99262	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-06-01 11:20:00	2016-06-01 12:10:00	2018-05-18 15:01:22	2018-05-18 15:01:27	21	0	\N	\N
100692	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	GT simplification normes	GT simplification normes	2016-06-07 17:00:00	2016-06-07 18:00:00	\N	\N	3	0	\N	\N
101416	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-06-08 13:30:00	2016-06-08 14:30:00	\N	\N	2	0	\N	\N
101426	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Francophonie	Groupe de travail Francophonie	2016-06-07 16:45:00	2016-06-07 18:15:00	\N	\N	5	0	\N	\N
101741	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2016-06-08 16:35:00	2016-06-08 18:35:00	2018-05-18 15:04:14	2018-05-18 15:04:20	32	0	\N	\N
101812	MISSION	AUCUNE	\N	TURQUIE	\N	MI Accord UE/Turquie 	MI Accord UE/Turquie 	2016-06-08 14:30:00	2016-06-08 16:50:00	2016-06-08 19:33:52	2016-06-09 16:42:50	11	0	\N	\N
102114	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2016-06-09 10:00:00	2016-06-09 12:20:00	2016-06-09 16:46:04	2016-06-09 16:49:41	42	0	\N	\N
102821	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2017	2016-06-07 16:30:00	2016-06-07 18:30:00	\N	\N	3	0	\N	\N
103036	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD RI Aménagement aéroportuaire territoire	Audition Rapporteur CDD Aménagement aéroportuaire territoire	2016-06-07 11:00:00	2016-06-07 12:00:00	\N	\N	1	0	\N	\N
103040	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-06-09 09:30:00	2016-06-09 12:45:00	\N	\N	1	0	\N	\N
103042	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-06-09 16:15:00	2016-06-09 19:15:00	\N	\N	1	0	\N	\N
103072	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE 	Audition Rapporteur CAE 	2016-06-08 14:30:00	2016-06-08 18:35:00	\N	\N	3	0	\N	\N
93431	GIA	AUCUNE	\N	\N	\N	GIA Iraq	Groupe interparlementaire Iraq	2016-05-18 08:15:00	2016-05-18 09:30:00	\N	\N	2	0	615	\N
93434	GIA	AUCUNE	\N	\N	\N	GIA Syrie	Groupe interparlementaire Syrie	2016-05-18 08:15:00	2016-05-18 09:30:00	\N	\N	3	0	644	\N
93812	GIA	AUCUNE	\N	\N	\N	Réunion déplacement	Groupe interparlementaire Algérie	2016-05-17 18:00:00	2016-05-17 18:30:00	\N	\N	8	0	575	\N
93844	QUESTURE	AUCUNE	\N	\N	\N	Questure	Réunion de Questure	2016-05-17 14:30:00	2016-05-17 16:00:00	\N	\N	3	0	\N	\N
94512	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	GT CDD  - Aménagement du territoire	Groupe de travail CDD 	2016-05-19 11:00:00	2016-05-19 12:00:00	\N	\N	4	0	\N	\N
94526	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT FINC - DGF	Groupe de travail DGF - Comité de pilotage - RCF - M. Julla	2016-05-18 09:30:00	2016-05-18 12:30:00	\N	\N	2	0	\N	\N
94529	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT FINC - DGF	Groupe de travail DGF - Table ronde des associations d'élus	2016-05-18 17:00:00	2016-05-18 19:00:00	\N	\N	8	0	\N	\N
94538	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT FINC - DGF	Groupe de travail DGF - Outil de simulation 	2016-05-19 09:00:00	2016-05-19 10:30:00	\N	\N	9	0	\N	\N
94548	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Controle 	Contrôle - MIRES - 2016 -  "Cond. de maintien des droits des étudiants boursiers" - Audition DGFiP - SCE - M. Tanguy	2016-05-18 18:00:00	2016-05-18 18:50:00	\N	\N	1	0	\N	\N
95719	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2016-05-25 09:40:00	2016-05-25 12:05:00	2016-05-25 15:44:29	2016-05-25 16:10:15	47	0	\N	\N
97512	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-05-24 15:30:00	2016-05-24 16:30:00	\N	\N	1	0	\N	\N
97514	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-05-25 15:00:00	2016-05-25 16:00:00	\N	\N	2	0	\N	\N
97519	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-05-26 10:00:00	2016-05-26 11:00:00	\N	\N	1	0	\N	\N
97521	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-05-26 16:00:00	2016-05-26 18:00:00	\N	\N	1	0	\N	\N
97523	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-05-24 14:30:00	2016-05-24 17:00:00	\N	\N	3	0	\N	\N
97811	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2016-05-31 14:35:00	2016-05-31 15:50:00	2016-05-31 17:22:34	2016-05-31 17:44:54	19	0	\N	\N
98794	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Prescription en matière pénale	PPL Prescription en matière pénale	2016-06-02 14:30:00	2016-06-02 16:25:00	\N	\N	18	0	\N	\N
98852	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	CAE 	2016-06-01 10:00:00	2016-06-01 11:10:00	2018-05-18 15:00:37	2018-05-18 15:00:43	36	0	\N	\N
99082	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2016-06-01 09:00:00	2016-06-01 13:10:00	2016-06-01 15:17:10	2016-06-01 18:11:53	52	0	\N	\N
99152	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-06-01 09:55:00	2016-06-01 11:20:00	2018-05-18 15:00:18	2018-05-18 15:00:23	42	0	\N	\N
95650	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2016-05-25 09:00:00	2016-05-25 09:40:00	2018-05-18 14:56:43	2018-05-18 14:56:50	44	0	\N	\N
98812	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	CAE 	2016-06-01 09:30:00	2016-06-01 10:00:00	2018-05-18 14:59:03	2018-05-18 14:59:09	36	0	\N	\N
99732	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2016-06-01 22:00:00	2016-06-02 01:30:00	2016-06-02 11:52:47	2016-06-02 15:14:28	29	0	\N	\N
99875	ETUDES	AUCUNE	\N	\N	\N	GE Élevage	Groupe d'études Élevage	2016-06-01 08:00:00	2016-06-01 09:30:00	\N	\N	11	0	\N	911
99892	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-06-01 15:00:00	2016-06-01 19:00:00	\N	\N	1	0	\N	\N
99953	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Groupe de travail Transport 	GT Transport - Audition BEI -  M. Ambroise FAYOLLE, vice-président ; M. Julien CHEBBO, conseiller	2016-05-31 14:30:00	2016-05-31 15:30:00	\N	\N	4	0	\N	\N
99961	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT Transport  	GT Transport- Aud.VNF - M. PAPINUTTI (DG), M.SPAZZI (DG adjoint),M.BELARD(dir. jur. éco. fin.), Mme MOURNETAS(resp. RI) 	2016-05-31 15:30:00	2016-05-31 16:30:00	\N	\N	4	0	\N	\N
99965	ETUDES	AUCUNE	\N	\N	\N	GE Cheval	Groupe d'études Cheval	2016-05-30 17:00:00	2016-05-30 18:30:00	\N	\N	1	0	\N	912
100014	GIA	AUCUNE	\N	\N	\N	GIA Pays Baltes	Groupe interparlementaire Pays Baltes	2016-06-02 12:30:00	2016-06-02 14:30:00	\N	\N	1	0	616	\N
100052	DELEGATION	AUCUNE	\N	\N	211	Droits des femmes 	Droits des femmes 	2016-06-02 08:30:00	2016-06-02 09:30:00	2016-06-02 16:08:47	2016-06-03 10:36:48	5	0	\N	\N
100065	DELEGATION	AUCUNE	\N	\N	211	Droits des femmes 	Droits des femmes 	2016-06-02 09:30:00	2016-06-02 10:30:00	2016-06-02 16:11:49	2016-06-03 10:36:49	5	0	\N	\N
100080	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD  groupe Migrants	Audition Rapporteur ETRD groupe Migrants 	2016-06-02 11:00:00	2016-06-02 12:30:00	\N	\N	2	0	\N	\N
100092	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-06-01 15:30:00	2016-06-01 16:30:00	\N	\N	1	0	\N	\N
100096	GIA	AUCUNE	\N	\N	\N	GIA Pakistan	Groupe interparlementaire Pakistan	2016-06-01 18:00:00	2016-06-01 19:00:00	\N	\N	2	0	619	\N
100112	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle "Missions locales"	Contrôle - Mission "Travail et emploi" - 2016 - Missions locales - Cel national des missions locales - SG 	2016-05-31 18:00:00	2016-05-31 19:00:00	\N	\N	2	0	\N	\N
100132	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle FACE 2016	Contrôle - Facé - 2016 -  Gest° et l'util° aides aux coll. pour l'électrif° rurale - Synd. énergie Pyrénées-Atlantiques	2016-05-30 14:00:00	2016-05-30 15:00:00	\N	\N	1	0	\N	\N
100134	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle FACE 2016	Contrôle - Facé - 2016 -  Gest° et l'util° aides aux coll. pour l'électrif° rurale - Préfet Pyrénées-Atlantiques	2016-05-30 15:00:00	2016-05-30 16:00:00	\N	\N	1	0	\N	\N
100136	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle enj. budg. de l'applic° du droit commun. de l'envt 	Mission Ecologie -  Contrôle - 2016 -  Enjx budg. dt environnemental - Conseil d'Etat - M. Fabien Raynaud	2016-05-31 10:00:00	2016-05-31 11:00:00	\N	\N	1	0	\N	\N
100138	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle enj. budg. de l'applic° du droit commun. de l'envt 	M° Ecologie -  Contrôle - 2016 -  Enjx budg. dt environnemental - France Nature envt - Mme Denier-Pasquier	2016-05-31 11:00:00	2016-05-31 12:00:00	\N	\N	1	0	\N	\N
100140	QUESTURE	AUCUNE	\N	\N	\N	Questure	Réunion de Questure	2016-05-31 15:00:00	2016-05-31 16:30:00	\N	\N	3	0	\N	\N
100156	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-06-30 10:30:00	2016-06-30 12:00:00	\N	\N	1	0	\N	\N
100252	COM_ENQUETE	PLENIERE	\N	CHOMAGE	\N	commission d'enquête sur les chiffres du chômage 	commission d'enquête sur les chiffres du chômage 	2016-06-07 09:00:00	2016-06-07 10:00:00	2016-06-07 11:46:03	2016-06-07 14:50:13	4	0	\N	\N
100267	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Accord de Paris 12/12/2015	PJL Accord de Paris 12/12/2015	2016-06-08 14:30:00	2016-06-08 16:25:00	\N	\N	98	0	\N	\N
100268	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Résolution européenne Sanctions Russie	Résolution européenne Sanctions Russie	2016-06-08 16:30:00	2016-06-08 20:35:00	\N	\N	107	0	\N	\N
100269	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Abus de marché	CMP Abus de marché	2016-06-08 22:00:00	2016-06-08 22:40:00	\N	\N	16	0	\N	\N
100837	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle OPEX 	Contrôle - Mission "Défense" - 2016 - OPEX - direction des affaires fin. du Min. de la défense - M. Charreton (DAF)	2016-06-07 14:30:00	2016-06-07 16:00:00	\N	\N	1	0	\N	\N
100841	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2016-06-08 10:00:00	2016-06-08 11:20:00	2016-06-08 11:50:40	2016-06-08 16:29:02	39	0	\N	\N
101567	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Orientation	Groupe de travail Orientation	2016-06-08 14:30:00	2016-06-08 15:30:00	\N	\N	9	0	\N	\N
101609	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2016-06-08 15:05:00	2016-06-08 16:30:00	2016-06-09 10:48:21	2016-06-09 16:40:03	35	0	\N	\N
101633	GIA	AUCUNE	\N	\N	\N	GIA Viêt Nam	déjeuner avec l'association d'amitié France-Vietnam Groupe interparlementaire Viêt Nam	2016-06-08 12:45:00	2016-06-08 14:15:00	\N	\N	8	0	626	\N
101666	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2016-06-08 15:05:00	2016-06-08 16:30:00	2016-06-08 17:27:20	2016-06-08 17:52:43	35	0	\N	\N
101912	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Travail	PJL Travail	2016-06-13 16:00:00	2016-06-13 20:45:00	\N	\N	68	0	\N	\N
101913	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Travail	PJL Travail	2016-06-13 22:45:00	2016-06-14 00:40:00	\N	\N	62	0	\N	\N
102152	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	CAE 	2016-06-09 10:05:00	2016-06-09 12:20:00	2016-06-09 16:51:29	2016-06-09 17:19:41	42	0	\N	\N
102841	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	M° Transports - Contrôle - 2016 - Financement sûreté aérienne - Synd. ent. sûreté aéroportuaire -  M. Thouverez	2016-06-07 14:00:00	2016-06-07 15:00:00	\N	\N	1	0	\N	\N
102856	GIA	AUCUNE	\N	\N	\N	GIA Espagne	Groupe interparlementaire Espagne	2016-06-07 10:00:00	2016-06-07 11:30:00	\N	\N	4	0	589	\N
106772	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Entreprises	Projet de loi visant  à renforcer la transparence et la lutte contre la corruption	2016-06-16 13:00:00	2016-06-16 15:00:00	\N	\N	1	0	\N	\N
106926	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Contrôle	Mission Sécurité-Contrôle 2016 - Préfecture de police - SG de la zone de défense et de sécurité - MM. Sapot et Meunier	2016-06-13 09:30:00	2016-06-13 10:30:00	\N	\N	1	0	\N	\N
106928	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Contrôle	Mission sécurités - Contrôle budgétaire - 2016 - Préfecture de police -DRPJ Paris -  MM. Sainte et  Huguet 	2016-06-13 15:30:00	2016-06-13 16:30:00	\N	\N	1	0	\N	\N
106930	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Contrôle	Audition Rapporteur FINC - Contrôle	2016-06-16 17:30:00	2016-06-16 18:30:00	\N	\N	1	0	\N	\N
106932	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Contrôle	Mission Sécurités-Contrôle budgétaire-2016-Préf. de police de Paris-D° services tech. et logistiques/DRH/D° Police gale	2016-06-17 09:30:00	2016-06-17 12:30:00	\N	\N	1	0	\N	\N
107413	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2016-06-21 09:05:00	2016-06-21 10:30:00	2018-05-18 15:07:58	2018-05-18 15:08:04	53	0	\N	\N
107524	GIA	AUCUNE	\N	\N	\N	GIA Syrie	GIA Syrie entretien Khaled Issa	2016-06-21 08:15:00	2016-06-21 09:30:00	\N	\N	3	0	644	\N
108052	QUESTURE	AUCUNE	\N	\N	\N	Questure	Réunion de Questure	2016-06-21 14:45:00	2016-06-21 16:45:00	\N	\N	2	0	\N	\N
108425	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2016-06-22 09:30:00	2016-06-22 11:00:00	2016-06-22 14:19:28	2016-06-22 16:18:40	26	0	\N	\N
108817	QUESTURE	AUCUNE	\N	\N	\N	Commission de concertation	Commission de concertation	2016-06-22 10:00:00	2016-06-22 12:00:00	\N	\N	3	0	\N	\N
108840	GIA	AUCUNE	\N	\N	\N	GIA Nouvelle-Zélande	Groupe interparlementaire Nouvelle-Zélande	2016-06-22 08:30:00	2016-06-22 09:30:00	\N	\N	6	0	663	\N
109796	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE - PJL Sapin II	Audition Rapporteur CAE 	2016-06-23 09:00:00	2016-06-23 13:00:00	\N	\N	1	0	\N	\N
109798	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE - PJL Sapin II	Audition Rapporteur CAE 	2016-06-23 14:00:00	2016-06-23 15:00:00	\N	\N	1	0	\N	\N
109800	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE - PJL Sapin II	Audition Rapporteur CAE 	2016-06-23 16:00:00	2016-06-23 17:00:00	\N	\N	1	0	\N	\N
110189	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Contrôle	M° Transports - Contrôle financement sûreté aérienne - SGDSN - M. Jacob/Cel Sabene 	2016-06-22 14:30:00	2016-06-22 15:30:00	\N	\N	1	0	\N	\N
110193	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Contrôle	Mission Défense - Contrôle - 2016 - OPEX - DG Armement - M. Videau, chef de service 	2016-06-23 16:15:00	2016-06-23 17:15:00	\N	\N	1	0	\N	\N
110198	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Contrôle	Mission Sécurités - Contrôle - 2016 -  Service aff. immob/ Dir° finances et cde publique - M. Méric/M. Clérissi 	2016-06-23 09:30:00	2016-06-23 11:30:00	\N	\N	1	0	\N	\N
110252	SEANCE_PLENIERE	QAG	\N	\N	\N	Débat Référendum britannique	Débat Référendum britannique	2016-06-28 15:00:00	2016-06-28 17:00:00	\N	\N	297	0	\N	\N
110253	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL et PPLO Listes électorales	PPL et PPLO Listes électorales	2016-06-28 21:40:00	2016-06-29 01:05:00	\N	\N	40	0	\N	\N
111162	GIA	AUCUNE	\N	\N	\N	GIA Pologne	Groupe interparlementaire Pologne	2016-06-29 08:15:00	2016-06-29 09:25:00	\N	\N	5	0	600	\N
112553	MISSION	AUCUNE	\N	REVENU	\N	MI Revenu de base en France 	MI Revenu de base en France 	2016-06-30 14:05:00	2016-06-30 17:30:00	2016-06-30 18:36:38	2016-07-01 09:40:07	5	0	\N	\N
112752	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Modernisation de la vie économique	PJL Modernisation de la vie économique	2016-07-05 14:30:00	2016-07-05 18:55:00	\N	\N	160	0	\N	\N
112753	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Modernisation de la vie économique	PJL Modernisation de la vie économique	2016-07-05 21:00:00	2016-07-06 00:00:00	\N	\N	83	0	\N	\N
113312	MISSION	AUCUNE	\N	ISLAM	\N	MI organisation, place et financement de l'Islam en France 	MI organisation, place et financement de l'Islam en France 	2016-07-05 13:35:00	2016-07-05 15:40:00	2016-07-05 17:04:04	2016-07-05 17:06:23	14	0	\N	\N
113784	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2016-07-06 09:35:00	2016-07-06 10:45:00	2016-07-06 11:32:27	2016-07-06 16:43:15	24	0	\N	\N
113912	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Guinée	PJL Guinée	2016-07-07 10:30:00	2016-07-07 13:30:00	\N	\N	2	0	\N	\N
113913	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Modernisation de la vie économique	PJL Modernisation de la vie économique	2016-07-07 10:30:00	2016-07-07 13:30:00	\N	\N	42	0	\N	\N
113939	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au Gouvernement	Questions d'actualité au Gouvernement	2016-07-07 15:00:00	2016-07-07 15:45:00	\N	\N	124	0	\N	\N
114180	QUESTURE	AUCUNE	\N	\N	\N	Questure	Réunion de Questure	2016-07-06 09:30:00	2016-07-06 11:10:00	\N	\N	2	0	\N	\N
114437	GIA	AUCUNE	\N	\N	\N	GIA France-Corée du Sud	GIA France-Corée du Sud	2016-07-05 14:30:00	2016-07-05 16:00:00	\N	\N	1	0	613	\N
114439	GIA	AUCUNE	\N	\N	\N	GIA France-Corée du Sud	GIA France-Corée du Sud	2016-07-06 12:30:00	2016-07-06 14:30:00	\N	\N	3	0	613	\N
115993	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au Gouvernement	Questions d'actualité au Gouvernement	2016-07-12 16:45:00	2016-07-12 17:45:00	\N	\N	215	0	\N	\N
117484	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	M° Egalité des territoires et logt  - Contrôle - 2016 - Dispositif d'héb. urgence - FNARS - M. Gueguen, DG	2016-07-13 13:30:00	2016-07-13 14:30:00	\N	\N	1	0	\N	\N
117552	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2016-07-13 16:00:00	2016-07-13 17:00:00	2016-07-13 17:29:49	2016-07-13 17:44:05	10	0	\N	\N
117592	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	FINC - Déplacement Loire-Atlantique (contrôle)	M° Pol. des territ.-Contrôle - 2016 -Adultes relais-Audition au collège E.Renan de Saint Herblain-Ppale/DG ass° Optima	2016-07-11 11:30:00	2016-07-11 12:30:00	\N	\N	1	0	\N	\N
117594	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Déplacement Loire-Atlantique (contrôle)	Mission Pol. des territoires - Contrôle - 2016 -  Audition d'un adulte-relais - M. Zaouat	2016-07-11 14:15:00	2016-07-11 15:15:00	\N	\N	1	0	\N	\N
117614	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Déplacement en Loire-Atlantique (contrôle)	Mission Pol. des territoires - Contrôle - 2016 -  Audition d'un adulte-relais - M. Zaouat	2016-07-11 15:45:00	2016-07-11 16:45:00	\N	\N	1	0	\N	\N
117633	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	M°Politique des territoires - Contrôle - 2016 - Adultes-relais - Audition de France Mediation - M. Giraud (directeur) 	2016-07-12 14:40:00	2016-07-12 15:45:00	\N	\N	1	0	\N	\N
117652	COM_PERMANENTE	AUDRAP	\N	FINC	\N	\N	\N	2016-06-27 16:00:00	2016-06-27 17:00:00	\N	\N	1	0	\N	\N
117672	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD PJL 752	2016-07-11 11:05:00	2016-07-11 12:05:00	\N	\N	1	0	\N	\N
117674	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Cooperation franco-britannique de défense	Coopération franco-brtiannique de défense	2016-07-12 14:00:00	2016-07-12 17:35:00	\N	\N	7	0	\N	\N
117692	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Audition Rapporteur FINC 	2016-07-13 17:00:00	2016-07-13 18:00:00	\N	\N	1	0	\N	\N
117694	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Audition Rapporteur FINC 	2016-07-13 18:30:00	2016-07-13 20:10:00	\N	\N	1	0	\N	\N
117696	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-07-12 16:30:00	2016-07-12 17:45:00	\N	\N	1	0	\N	\N
117712	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Audition Rapporteur FINC 	2016-07-11 10:00:00	2016-07-11 12:00:00	\N	\N	1	0	\N	\N
117714	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Audition Rapporteur FINC 	2016-07-11 15:00:00	2016-07-11 16:00:00	\N	\N	1	0	\N	\N
124495	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Statut de Paris	\N	2016-10-11 16:30:00	2016-10-11 17:30:00	\N	\N	2	0	\N	\N
108332	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	CAE 	2016-06-22 09:30:00	2016-06-22 10:55:00	2016-06-22 12:22:47	2016-06-22 16:18:41	29	0	\N	\N
113972	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	CAE 	2016-07-06 10:05:00	2016-07-06 11:10:00	2018-05-18 15:13:53	2018-05-18 15:14:03	26	0	\N	\N
114012	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2016-07-06 09:35:00	2016-07-06 11:35:00	2016-07-20 11:40:46	2016-07-20 11:40:54	28	0	\N	\N
108537	GIA	AUCUNE	\N	\N	\N	GIA Brésil	Petit-déjeuner de travail avec l'ambassadeur de France au Brésil	2016-06-22 08:30:00	2016-06-22 09:30:00	\N	\N	5	0	576	\N
108631	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2016-06-22 09:50:00	2016-06-22 12:55:00	2016-06-22 15:08:34	2016-06-22 16:18:38	33	0	\N	\N
108887	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2016-06-22 16:15:00	2016-06-22 17:35:00	2018-05-18 15:09:20	2018-05-18 15:09:29	28	0	\N	\N
109526	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-06-21 15:00:00	2016-06-21 16:00:00	\N	\N	1	0	\N	\N
109532	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-06-21 09:00:00	2016-06-21 10:30:00	\N	\N	4	0	\N	\N
109553	MISSION	AUCUNE	\N	ISLAM	\N	MI organisation, place et financement de l'Islam en France 	MI organisation, place et financement de l'Islam en France 	2016-06-23 10:35:00	2016-06-23 12:25:00	2016-06-23 16:00:42	2016-06-23 16:01:46	12	0	\N	\N
109783	MISSION	AUCUNE	\N	REVENU	\N	MI Revenu de base en France 	MI Revenu de base en France 	2016-06-23 13:35:00	2016-06-23 15:00:00	2016-06-24 09:51:02	2016-06-24 11:32:03	11	0	\N	\N
109849	BUREAU	AUCUNE	\N	\N	\N	Bureau	Réunion du Bureau	2016-06-23 08:30:00	2016-06-23 11:30:00	\N	\N	24	0	\N	\N
109890	GIA	AUCUNE	\N	\N	\N	GIA Autriche	Groupe interparlementaire Autriche	2016-06-23 12:30:00	2016-06-23 14:30:00	\N	\N	4	0	579	\N
109912	DELEGATION	AUCUNE	\N	\N	211	Droits des femmes 	Droits des femmes 	2016-06-23 08:30:00	2016-06-23 09:45:00	2016-06-23 17:28:19	2016-06-24 11:32:10	5	0	\N	\N
109928	MISSION	AUCUNE	\N	REVENU	\N	MI Revenu de base en France 	MI Revenu de base en France 	2016-06-23 16:15:00	2016-06-23 17:20:00	2016-06-23 17:56:19	2016-06-24 11:32:05	6	0	\N	\N
109939	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Entreprises	Réunion plénière	2016-07-07 09:00:00	2016-07-07 10:35:00	2016-07-07 15:40:14	2016-07-07 17:25:42	10	0	\N	\N
110110	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Rapporteur 	Audition Rapporteur 	2016-06-23 11:45:00	2016-06-23 12:30:00	\N	\N	1	0	\N	\N
110125	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT FINC 	GT Transport - FNTP -  M. Marchand (VP) - Vinci	2016-06-23 10:30:00	2016-06-23 12:00:00	\N	\N	2	0	\N	\N
112120	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2016-06-29 15:05:00	2016-06-29 16:50:00	2016-06-30 10:22:29	2016-06-30 11:14:42	57	0	\N	\N
112494	SEANCE_PLENIERE	OUV_SESSION	\N	\N	\N	Ouv. session extraordinaire	Ouv. session extraordinaire	2016-07-04 16:00:00	2016-07-04 16:00:00	\N	\N	31	0	\N	\N
112495	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Modernisation de la vie économique	PJL Modernisation de la vie économique	2016-07-04 16:00:00	2016-07-04 19:55:00	\N	\N	45	0	\N	\N
112496	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Modernisation de la vie économique	PJL Modernisation de la vie économique	2016-07-04 21:35:00	2016-07-05 00:00:00	\N	\N	30	0	\N	\N
112772	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	CAE 	2016-07-04 14:30:00	2016-07-04 14:55:00	2018-05-18 15:12:42	2018-05-18 15:12:46	5	0	\N	\N
112890	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-07-04 14:30:00	2016-07-04 15:25:00	2016-07-04 16:41:40	2016-07-04 17:56:26	10	0	\N	\N
112926	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-06-28 15:35:00	2016-06-28 16:10:00	\N	\N	1	0	\N	\N
112928	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-06-28 14:15:00	2016-06-28 15:00:00	\N	\N	3	0	\N	\N
112931	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-06-29 14:40:00	2016-06-29 16:15:00	\N	\N	2	0	\N	\N
112934	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-06-29 14:40:00	2016-06-29 15:30:00	\N	\N	1	0	\N	\N
113033	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	groupe de travail Garde nationale	Audition Rapporteur Groupe de travail Garde nationale	2016-07-28 14:15:00	2016-07-28 15:00:00	\N	\N	3	0	\N	\N
113037	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. Garde nationale	Audition Rapporteur Groupe de travail Garde nationale	2016-07-28 15:35:00	2016-07-28 16:10:00	\N	\N	1	0	\N	\N
113039	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. Garde nationale	Audition Rapporteur groupe de travail Garde nationale	2016-06-29 14:40:00	2016-06-29 15:30:00	\N	\N	3	0	\N	\N
113043	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD Garde nationale	Audition Rapporteur Groupe de travail Garde nationalkeD 	2016-06-29 15:30:00	2016-06-29 16:15:00	\N	\N	2	0	\N	\N
113046	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD Garde nationale	Audition Rapporteur Groupe de travail Garde nationale 	2016-06-30 10:30:00	2016-06-30 12:10:00	\N	\N	2	0	\N	\N
113049	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD  Garde nationale	Audition Rapporteur ETRD  Groupe de travail Garde nationale	2016-06-30 14:45:00	2016-06-30 15:15:00	\N	\N	2	0	\N	\N
114073	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2016-07-06 09:30:00	2016-07-06 12:30:00	2016-07-06 14:35:14	2016-07-06 16:43:17	40	0	\N	\N
114453	MISSION	AUCUNE	\N	TELEPHONE	\N	MI téléphones mobiles 	MI téléphones mobiles 	2016-07-06 16:30:00	2016-07-06 18:15:00	2016-07-06 19:15:38	2016-07-07 14:44:36	9	0	\N	\N
114792	MISSION	AUCUNE	\N	TURQUIE	\N	MI Accord UE/Turquie 	MI Accord UE/Turquie 	2016-07-06 14:30:00	2016-07-06 17:25:00	2016-07-07 10:00:47	2016-07-07 14:44:35	9	0	\N	\N
114808	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Modernisation de la vie économique	PJL Modernisation de la vie économique	2016-07-08 09:30:00	2016-07-08 13:00:00	\N	\N	16	0	\N	\N
114809	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Modernisation de la vie économique	PJL Modernisation de la vie économique	2016-07-08 14:30:00	2016-07-08 20:00:00	\N	\N	0	0	\N	\N
114952	GIA	AUCUNE	\N	\N	\N	GIA Québec	Groupe interparlementaire Québec	2016-07-06 12:45:00	2016-07-06 14:00:00	\N	\N	2	0	602	\N
114955	GIA	AUCUNE	\N	\N	\N	GIA Québec	Groupe interparlementaire Québec	2016-07-04 20:00:00	2016-07-04 22:30:00	\N	\N	9	0	602	\N
114965	GIA	AUCUNE	\N	\N	\N	GIA Québec	Groupe interparlementaire Québec	2016-07-05 20:00:00	2016-07-05 23:00:00	\N	\N	3	0	602	\N
114969	GIA	AUCUNE	\N	\N	\N	GIA Québec	Groupe interparlementaire Québec	2016-07-05 16:00:00	2016-07-05 17:15:00	\N	\N	2	0	602	\N
114972	GIA	AUCUNE	\N	\N	\N	GIA Québec	Groupe interparlementaire Québec	2016-07-04 09:00:00	2016-07-04 18:30:00	\N	\N	1	0	602	\N
114974	GIA	AUCUNE	\N	\N	\N	GIA Québec	Groupe interparlementaire Québec	2016-07-06 09:00:00	2016-07-06 11:30:00	\N	\N	1	0	602	\N
114976	GIA	AUCUNE	\N	\N	\N	GIA Québec	Groupe interparlementaire Québec	2016-07-06 11:35:00	2016-07-06 12:15:00	\N	\N	2	0	602	\N
108730	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2016-06-22 10:00:00	2016-06-22 12:15:00	2016-06-22 15:26:07	2016-06-22 16:18:37	43	0	\N	\N
114979	GIA	AUCUNE	\N	\N	\N	GIA Québec	Groupe interparlementaire Québec	2016-07-06 14:30:00	2016-07-06 16:00:00	\N	\N	5	0	602	\N
114985	GIA	AUCUNE	\N	\N	\N	GIA Québec	Groupe interparlementaire Québec	2016-07-06 16:00:00	2016-07-06 17:15:00	\N	\N	1	0	602	\N
115412	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2016-07-07 08:30:00	2016-07-07 11:35:00	2016-07-07 18:08:13	2016-07-08 10:02:19	19	0	\N	\N
115438	GIA	AUCUNE	\N	\N	\N	GIA Cambodge et Laos	Groupe interparlementaire Cambodge et Laos	2016-07-06 12:30:00	2016-07-06 14:30:00	\N	\N	3	0	577	\N
117716	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Audition Rapporteur FINC 	2016-07-12 14:30:00	2016-07-12 16:00:00	\N	\N	1	0	\N	\N
117752	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	FINC 	FINC 	2016-07-13 08:00:00	2016-07-13 17:00:00	\N	\N	1	0	\N	\N
117754	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Audition Rapporteur FINC 	2016-07-12 18:00:00	2016-07-12 19:30:00	\N	\N	1	0	\N	\N
118232	MISSION	AUCUNE	\N	TELEPHONE	\N	MI téléphones mobiles 	MI téléphones mobiles 	2016-07-18 17:10:00	2016-07-18 18:00:00	2016-07-19 18:12:15	2016-07-20 14:47:55	5	0	\N	\N
118245	MISSION	AUDRAP	\N	TELEPHONE	\N	Aud. Rapp. MI téléphones mobiles 	Audition Rapporteur MI téléphones mobiles 	2016-07-18 15:30:00	2016-07-18 17:05:00	\N	\N	5	0	\N	\N
118348	QUESTURE	AUCUNE	\N	\N	\N	Questure	Réunion de Questure	2016-07-19 15:00:00	2016-07-19 19:30:00	\N	\N	2	0	\N	\N
118390	ETUDES	AUCUNE	\N	\N	\N	GE Élevage	Groupe d'études Élevage	2016-07-20 08:30:00	2016-07-20 10:00:00	\N	\N	11	0	\N	911
118472	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2016-07-20 09:35:00	2016-07-20 12:50:00	2016-07-21 11:15:03	2016-07-21 11:49:10	29	0	\N	\N
118512	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Audition Cour des comptes	2016-07-19 09:30:00	2016-07-19 11:30:00	\N	\N	1	0	\N	\N
106812	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2016-06-21 09:30:00	2016-06-21 12:30:00	\N	\N	30	0	\N	\N
107132	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	Simplification des normes	Simplificatio des normes	2016-06-29 11:00:00	2016-06-29 12:00:00	\N	\N	4	0	\N	\N
108512	ETUDES	AUCUNE	\N	\N	\N	GE Pratiques sportives	Groupe d'études Pratiques sportives	2016-06-22 08:30:00	2016-06-22 09:45:00	\N	\N	6	0	\N	934
110097	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT FINC 	GT DGF - Conclusions des travaux du GT	2016-06-23 13:00:00	2016-06-23 15:00:00	\N	\N	11	0	\N	\N
110312	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	ENTREPRISES	Entreprises	Réunion du Bureau de la Délégation	2016-07-07 08:15:00	2016-07-07 09:00:00	\N	\N	3	0	\N	\N
110548	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Orientation	Groupe de travail Orientation	2016-06-28 14:00:00	2016-06-28 15:00:00	\N	\N	6	0	\N	\N
111351	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2016-06-29 09:30:00	2016-06-29 12:10:00	2016-06-29 16:07:49	2016-06-29 16:53:14	24	0	\N	\N
111504	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	CAE 	2016-06-29 10:25:00	2016-06-29 12:00:00	2016-06-30 15:34:56	2016-06-30 15:41:58	29	0	\N	\N
112061	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2016-06-29 09:30:00	2016-06-29 13:00:00	2016-06-30 10:07:39	2016-06-30 11:14:44	44	0	\N	\N
112179	GIA	AUCUNE	\N	\N	\N	GIA Pays du Golfe	Groupe interparlementaire Pays du Golfe	2016-06-28 11:45:00	2016-06-28 14:00:00	\N	\N	4	0	661	\N
112180	COM_SPECIALE	PLENIERE	\N	CITOYENNETE	\N	GT Egalité et citoyenneté 	GT Egalité et citoyenneté 	2016-06-29 18:00:00	2016-06-29 19:25:00	2016-06-30 10:34:16	2016-06-30 11:15:30	14	0	\N	\N
112267	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2016-06-30 08:35:00	2016-06-30 10:20:00	2016-06-30 10:51:53	2016-06-30 11:16:04	13	0	\N	\N
112392	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Contrôle	Audition Rapporteur FINC 	2016-06-28 09:00:00	2016-06-28 11:00:00	\N	\N	1	0	\N	\N
112394	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT FINC - Infrastructures de transport	GT Transport - C° europénne - DG Mobilité et transports - M. Ouaki, chef unité "Mécanisme pour interconnexion..."	2016-06-28 14:00:00	2016-06-28 15:00:00	\N	\N	2	0	\N	\N
112412	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Contrôle	M° AGTE - Contrôle - 2016 - Réfme adm. ss-préf - M. Carenco - Préf. rég IDF	2016-06-29 09:30:00	2016-06-29 10:40:00	\N	\N	1	0	\N	\N
112414	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Audition Rapporteur FINC 	2016-06-23 16:00:00	2016-06-23 17:00:00	\N	\N	1	0	\N	\N
112515	GIA	AUCUNE	\N	\N	\N	GIA Vanuatu	Groupe interparlementaire Vanuatu	2016-06-30 13:00:00	2016-06-30 14:30:00	\N	\N	2	0	651	\N
112912	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	 Facé - Contrôle - 2016 - Synd. dptal d'energie Corse-du-Sud - M. Panunzi - Pdt	2016-06-30 10:30:00	2016-06-30 15:30:00	\N	\N	1	0	\N	\N
112917	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	 Facé - Contrôle - 2016 - Gest° et ut° aides - Mairie de Porto-Vecchio - M. Mela, maire	2016-06-30 15:00:00	2016-06-30 17:00:00	\N	\N	1	0	\N	\N
112919	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	 Facé - Contrôle - 2016 - Gest° et util° aides - Mairie Porto-Vecchio - M. Mela, Pdt SDE2A	2016-07-01 09:30:00	2016-07-01 10:30:00	\N	\N	1	0	\N	\N
112921	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	 Facé - Contrôle  -2016 - Gest° et ut° des aides - Visite site de Bavella - M. Panunzi - Pdt du SDE2A	2016-07-01 11:00:00	2016-07-01 14:00:00	\N	\N	1	0	\N	\N
112923	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	M° Transports -Contrôle sûreté aérienne - DGAC - M. Plaisant, cller DG	2016-07-01 11:00:00	2016-07-01 12:00:00	\N	\N	1	0	\N	\N
114752	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Débat Finances et Examen PJL Règlement du budget 	Débat Finances et Examen PJL Règlement du budget 	2016-07-07 16:15:00	2016-07-07 19:30:00	\N	\N	35	0	\N	\N
114753	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Modernisation de la vie économique	PJL Modernisation de la vie économique	2016-07-07 16:15:00	2016-07-07 19:30:00	\N	\N	25	0	\N	\N
114772	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Modernisation de la vie économique	PJL Modernisation de la vie économique	2016-07-07 21:00:00	2016-07-08 00:30:00	\N	\N	22	0	\N	\N
114804	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC -Contrôle	M° Egal.terr.log.-Contrôle - 2016 - Dispo. d'héberg. d'urgence  - D° Budget  - M. Juery, ss-dir., M. Nezzar	2016-07-05 15:00:00	2016-07-05 16:00:00	\N	\N	1	0	\N	\N
114992	ETUDES	AUCUNE	\N	\N	\N	GE Forêt et filière bois	Groupe d'études Forêt et filière bois	2016-07-06 08:00:00	2016-07-06 09:15:00	\N	\N	15	0	\N	948
108372	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2016-06-22 08:40:00	2016-06-22 10:35:00	2018-05-18 15:08:17	2018-05-18 15:08:47	36	0	\N	\N
111393	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	CAE 	2016-06-29 09:30:00	2016-06-29 10:25:00	2016-06-29 15:44:14	2016-06-29 16:53:13	33	0	\N	\N
115262	COM_ENQUETE	PLENIERE	\N	CHOMAGE	\N	commission d'enquête sur les chiffres du chômage 	commission d'enquête sur les chiffres du chômage 	2016-07-07 13:30:00	2016-07-07 14:50:00	2016-07-07 15:38:11	2016-07-07 17:26:47	5	0	\N	\N
115684	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD RI Aménagement aéroportuaire du	Audition Rapporteur CDD RI Aménagement aéroportuaire du territoire	2016-07-06 10:00:00	2016-07-06 12:00:00	\N	\N	1	0	\N	\N
115912	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	AFCL	\N	AFCL 	AFCL 	2016-07-07 08:00:00	2016-07-07 18:00:00	\N	\N	8	0	\N	\N
115932	ETUDES	AUCUNE	\N	\N	\N	GE Développement économique de la montagne	Groupe d'études Développement économique de la montagne	2016-07-06 14:30:00	2016-07-06 16:00:00	\N	\N	7	0	\N	918
115952	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Facé - Contrôle - 2016 - Gestion et util° des aides aux collectivités - Synd. d'énergie  Pyr. Atl. - Mme Saint-Pé, Pdte	2016-06-03 14:00:00	2016-06-03 15:00:00	\N	\N	0	0	\N	\N
115953	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Facé - Contrôle - 2016 - Gestion et util° des aides aux collectivités - Préf. Pyr. Atlantique -  M. Durand, préfet	2016-06-03 15:00:00	2016-06-03 16:00:00	\N	\N	1	0	\N	\N
115955	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Facé - Contrôle - 2016 - Gestion et util° des aides aux collectivités - Synd. d'énergie  Pyr. Atl. - Mme Saint-Pé, Pdte 	2016-06-03 14:00:00	2016-06-03 15:00:00	\N	\N	1	0	\N	\N
116072	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-07-06 11:00:00	2016-07-06 12:30:00	\N	\N	4	0	\N	\N
116077	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2016-07-11 14:30:00	2016-07-11 15:10:00	2016-07-11 16:01:48	2016-07-11 17:22:00	13	0	\N	\N
116213	GIA	AUCUNE	\N	\N	\N	GIA Japon	Groupe interparlementaire Japon	2016-07-08 13:15:00	2016-07-08 14:30:00	\N	\N	2	0	596	\N
116851	COM_SPECIALE	PLENIERE	\N	EGALITE	\N	CS Egalité et citoyenneté 	CS Egalité et citoyenneté 	2016-07-12 14:35:00	2016-07-12 16:25:00	2016-07-12 17:33:10	2016-07-12 17:33:49	30	0	\N	\N
117732	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Audition Rapporteur FINC 	2016-07-13 16:00:00	2016-07-13 17:00:00	\N	\N	1	0	\N	\N
117733	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	FINC 	FINC 	2016-07-13 18:00:00	2016-07-13 19:00:00	\N	\N	1	0	\N	\N
117734	COM_SPECIALE	AUDRAP	\N	EGALITE	\N	Aud. Rapp. CS Egalité et citoyenneté 	Audition Rapporteur CS Egalité et citoyenneté 	2016-07-13 09:15:00	2016-07-13 10:00:00	\N	\N	2	0	\N	\N
117737	COM_SPECIALE	AUDRAP	\N	EGALITE	\N	Aud. Rapp. CS Egalité et citoyenneté 	Audition Rapporteur CS Egalité et citoyenneté 	2016-07-11 11:00:00	2016-07-11 12:30:00	\N	\N	1	0	\N	\N
117739	COM_SPECIALE	AUDRAP	\N	EGALITE	\N	Aud. Rapp. CS Egalité et citoyenneté 	Audition Rapporteur CS Egalité et citoyenneté 	2016-07-11 15:00:00	2016-07-11 20:00:00	\N	\N	1	0	\N	\N
117741	COM_SPECIALE	AUDRAP	\N	EGALITE	\N	Aud. Rapp. CS Egalité et citoyenneté 	Audition Rapporteur CS Egalité et citoyenneté 	2016-07-12 08:30:00	2016-07-12 12:30:00	\N	\N	1	0	\N	\N
106252	MISSION	AUDRAP	\N	ISLAM	\N	Aud. Rapp. MI organisation, place et financement de l'Islam 	Audition Rapporteur MI organisation, place et financement de l'Islam en France 	2016-06-16 12:00:00	2016-06-16 15:00:00	\N	\N	1	0	\N	\N
106353	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2016-06-16 09:30:00	2016-06-16 10:00:00	2016-06-16 15:21:47	2016-06-16 19:14:02	24	0	\N	\N
106403	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE - PJL "Sapin II"	Audition Rapporteur CAE 	2016-06-14 15:15:00	2016-06-14 16:15:00	\N	\N	1	0	\N	\N
106405	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE - PJL "Sapin II"	Audition Rapporteur CAE 	2016-06-14 18:00:00	2016-06-14 20:00:00	\N	\N	1	0	\N	\N
106407	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE - PJL "Sapin II"	Audition Rapporteur CAE 	2016-06-15 15:00:00	2016-06-15 19:00:00	\N	\N	1	0	\N	\N
106409	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE - PJL "Sapin II"	Audition Rapporteur CAE 	2016-06-16 11:00:00	2016-06-16 11:45:00	\N	\N	1	0	\N	\N
106411	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE - PJL "Sapin II"	Audition Rapporteur CAE 	2016-06-16 14:00:00	2016-06-16 17:00:00	\N	\N	1	0	\N	\N
106415	ETUDES	AUCUNE	\N	\N	\N	GE Section Trufficulture	Groupe d'études Section Trufficulture	2016-06-15 08:00:00	2016-06-15 09:00:00	\N	\N	50	0	\N	1005
106488	DELEGATION	AUCUNE	\N	\N	COLTER	Collectivités  territoriales 	Réunion conjointe avec le GT simplification (examen PPL et rapport d'information de MM. Calvet et Daunis	2016-06-23 09:00:00	2016-06-23 10:50:00	2016-06-24 12:40:09	2016-06-27 10:24:40	16	0	\N	\N
106513	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT AFEU 	Groupe de travail AFEU 	2016-06-16 15:30:00	2016-06-16 16:00:00	\N	\N	2	0	\N	\N
106792	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	M° Egal.terr.log.-Contrôle - 2016 - Dispo. d'héberg. d'urgence  - DG coh°soc. Min Aff. soc - DG Etr. en France-Min. Int	2016-06-15 11:15:00	2016-06-15 12:15:00	\N	\N	1	0	\N	\N
106795	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	M° Egal.terr.log.-Contrôle - 2016 - Dispo. d'héberg. d'urgence  - DRH Idf - M. Delorme - Dir. rég.	2016-06-16 16:00:00	2016-06-16 17:30:00	\N	\N	1	0	\N	\N
106893	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT FINC 	GT Transport - Table ronde APRR-SANEF-VINCI	2016-06-14 14:00:00	2016-06-14 15:45:00	\N	\N	2	0	\N	\N
106896	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	contrôle FNADT 	2016-06-16 11:15:00	2016-06-16 12:30:00	\N	\N	1	0	\N	\N
106898	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	contrôle FNADT	2016-06-16 12:30:00	2016-06-16 14:00:00	\N	\N	1	0	\N	\N
106900	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	contrôle FNADT	2016-06-16 14:00:00	2016-06-16 15:00:00	\N	\N	1	0	\N	\N
106902	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	contrôle FNADT	2016-06-16 16:30:00	2016-06-16 17:45:00	\N	\N	1	0	\N	\N
106912	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Mission Travail et emploi - Contrôle - 2016 - Missions locales - UNML - M. Gilles, pdt et M. Kroichvili, délégué gal	2016-06-15 16:30:00	2016-06-15 17:30:00	\N	\N	1	0	\N	\N
106922	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	M° Transports - Contrôle sûreté aérienne - Préfet police Paris	2016-06-16 14:30:00	2016-06-16 15:30:00	\N	\N	1	0	\N	\N
106924	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Déplacement Orly (contrôle)	M° Transport - Contrôle sûreté aérienne - Visite installations Orly - M. Mereyde (dir. Orly)	2016-06-16 16:30:00	2016-06-16 19:00:00	\N	\N	1	0	\N	\N
107740	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2016-06-21 13:30:00	2016-06-21 14:20:00	2016-06-21 16:44:01	2016-06-21 17:34:11	35	0	\N	\N
107830	GIA	AUCUNE	\N	\N	\N	GIA Allemagne	Groupe interparlementaire Allemagne	2016-06-21 14:30:00	2016-06-21 15:30:00	\N	\N	1	0	604	\N
107853	GIA	AUCUNE	\N	\N	\N	GIA Pays Baltes	Groupe interparlementaire Pays Baltes	2016-06-21 13:00:00	2016-06-21 15:00:00	\N	\N	1	0	616	\N
112333	GIA	AUCUNE	\N	\N	\N	GIA Asie du Sud-Est	Groupe interparlementaire Asie du Sud-Est	2016-06-29 13:00:00	2016-06-29 14:30:00	\N	\N	2	0	609	\N
112336	GIA	AUCUNE	\N	\N	\N	GIA Egypte	Groupe interparlementaire Egypte	2016-06-30 08:45:00	2016-06-30 10:15:00	\N	\N	5	0	617	\N
115687	COM_PERMANENTE	AUTRE	\N	\N	\N	MML 	MML 	2016-07-05 10:00:00	2016-07-05 10:45:00	\N	\N	0	0	\N	\N
112372	ETUDES	AUCUNE	\N	\N	\N	GE Sénateurs anciens combattants et mémoire combattante	Groupe d'études Sénateurs anciens combattants et mémoire combattante	2016-07-05 15:00:00	2016-07-05 17:00:00	\N	\N	1	0	\N	928
113092	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-07-05 09:35:00	2016-07-05 10:25:00	2016-07-05 11:45:31	2016-07-05 15:02:46	17	0	\N	\N
113112	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Magistrats	CMP Magistrats	2016-07-06 14:30:00	2016-07-06 15:25:00	\N	\N	48	0	\N	\N
113114	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Modernisation de la vie économique	PJL Modernisation de la vie économique	2016-07-06 15:35:00	2016-07-06 19:55:00	\N	\N	120	0	\N	\N
113115	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Modernisation de la vie économique	PJL Modernisation de la vie économique	2016-07-06 21:30:00	2016-07-07 01:25:00	\N	\N	47	0	\N	\N
113832	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	Assemblée parlementaire de la Francophonie	Aucune 	2016-07-05 16:00:00	2016-07-05 17:30:00	\N	\N	4	0	\N	\N
113952	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition Rapporteur AFEU 	2016-07-06 11:05:00	2016-07-06 12:10:00	\N	\N	2	0	\N	\N
115694	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2016-07-07 18:55:00	2016-07-07 19:00:00	2018-05-18 15:14:26	2018-05-18 15:14:34	12	1	\N	\N
115752	MISSION	AUCUNE	\N	REVENU	\N	MI Revenu de base en France 	MI Revenu de base en France 	2016-07-07 16:15:00	2016-07-07 18:45:00	2016-07-08 11:05:42	2016-07-08 11:57:37	4	0	\N	\N
115794	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Déplacement Roissy (contrôle) 	M° Transports -Contrôle sûreté aérienne - Visite install. sûreté Roissy - M. Goldnadel, DG adj.	2016-07-07 09:15:00	2016-07-07 12:15:00	\N	\N	1	0	\N	\N
115812	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Mission "Engagements financiers de l'Etat" - Contrôle  - 2016 - SVT - M. Angle, pdt Crédit Suisse	2016-07-06 17:00:00	2016-07-06 18:00:00	\N	\N	1	0	\N	\N
115816	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	M° Egal.terr.log.-Contrôle - 2016 - Dispo. d'héberg. d'urgence  - Délégué intermin. hébergt (DIHAL), M. Mathieu	2016-07-06 14:00:00	2016-07-06 15:00:00	\N	\N	1	0	\N	\N
115833	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Mission Défense - Contrôle - 2016 - Cour des comptes - Mme Rocard, M. Joubert	2016-07-06 14:30:00	2016-07-06 16:30:00	\N	\N	1	0	\N	\N
115835	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Mission Défense - Contrôle - 2016 - OPEX - MBDA - MM. Bouvier, Païtard et Mme Chollet	2016-07-07 08:15:00	2016-07-07 15:00:00	\N	\N	1	0	\N	\N
116293	MISSION	AUCUNE	\N	TELEPHONE	\N	MI téléphones mobiles 	MI téléphones mobiles 	2016-07-11 14:00:00	2016-07-11 16:00:00	2016-07-11 17:27:02	2016-07-11 17:56:42	4	0	\N	\N
116584	EXCUSES	AUTRE_NON_PLENIERE	\N	\N	\N	Autre (non plénière) 	Autre (non plénière) 	2016-07-06 00:00:00	2016-07-14 00:00:00	\N	\N	1	0	\N	\N
117532	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Déplacement Loire-Atlantique (contrôle)	Mission "Politique des territoires" - Contrôle - 2016 - Adultes-relais - Audition de M. Bécoulet (sous-préfet)	2016-07-11 10:00:00	2016-07-11 11:00:00	\N	\N	1	0	\N	\N
117756	SEANCE_PLENIERE	HOMMAGE	\N	\N	\N	Hommage aux victimes de Nice	Hommage aux victimes de Nice 	2016-07-19 14:30:00	2016-07-19 17:30:00	\N	\N	146	0	\N	\N
117806	MISSION	AUCUNE	\N	TELEPHONE	\N	MI téléphones mobiles 	MI téléphones mobiles 	2016-07-18 14:00:00	2016-07-18 14:40:00	2016-07-19 18:13:07	2016-07-20 14:58:02	5	0	\N	\N
106215	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD RI Aménagement aéroportuaire du territoire	Audition Rapporteur CDD RI Aménagement aéroportuaire du territoire 	2016-06-16 08:30:00	2016-06-16 10:30:00	\N	\N	1	0	\N	\N
106217	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE Gestion des risques agriculture	Audition Rapporteur CAE Gestion des risques agriculture	2016-06-14 09:30:00	2016-06-14 10:30:00	\N	\N	1	0	\N	\N
107053	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Travail 	PJL Travail 	2016-06-20 10:00:00	2016-06-20 12:35:00	\N	\N	26	0	\N	\N
107054	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Travail 	PJL Travail 	2016-06-20 14:30:00	2016-06-20 19:40:00	\N	\N	49	0	\N	\N
107055	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Travail 	PJL Travail 	2016-06-20 21:30:00	2016-06-21 00:00:00	\N	\N	38	0	\N	\N
107140	MISSION	AUDRAP	\N	ISLAM	\N	Déplacement à Alger du 17 au 19/06/2016	Déplacement à Alger du 17 au 19/06/2016	2016-06-17 20:55:00	2016-06-19 22:15:00	\N	\N	3	0	\N	\N
107312	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Travail	PJL Travail	2016-06-23 11:05:00	2016-06-23 13:00:00	\N	\N	86	0	\N	\N
107313	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Travail	PJL Travail	2016-06-23 21:30:00	2016-06-24 00:30:00	\N	\N	42	0	\N	\N
107314	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au Gouvernement	Questions d'actualité au Gouvernement	2016-06-23 15:00:00	2016-06-23 16:10:00	\N	\N	213	0	\N	\N
107315	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Travail	PJL Travail	2016-06-23 16:30:00	2016-06-23 20:00:00	\N	\N	64	0	\N	\N
107476	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-06-21 09:05:00	2016-06-21 10:30:00	2016-06-21 14:57:59	2016-06-21 17:34:09	53	0	\N	\N
110083	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	M° Pol. des territoires - Contrôle - 2016 -dispositif adultes-relais  - CGET - M. Briat	2016-06-22 14:30:00	2016-06-22 15:15:00	\N	\N	1	0	\N	\N
110085	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PJL de règlement 2015 - Audiion du CGET - M. Briat - Dir. adj. ville et cohésion urbaine	2016-06-22 15:15:00	2016-06-22 16:30:00	\N	\N	1	0	\N	\N
110094	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT FINC 	GT DGF - Comité de pilotage -  Mmes Pires Beaune et Louwagie	2016-06-21 18:30:00	2016-06-21 20:00:00	\N	\N	2	0	\N	\N
112943	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PJL 691 Sapin 2  - Audition BNP Paribas - MM. Rousseau (Dir. Aff. Pub)/ D'Etigny (Dir. adjoint)	2016-06-29 09:00:00	2016-06-29 10:00:00	\N	\N	1	0	\N	\N
112945	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	CAS participations financières de l'Etat - Contrôle - 2016 - M. Derrien, prof. HEC 	2016-06-29 14:00:00	2016-06-29 15:00:00	\N	\N	1	0	\N	\N
107326	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	CAE 	2016-06-21 09:05:00	2016-06-21 10:30:00	2016-06-21 16:54:24	2016-06-21 17:34:10	53	0	\N	\N
114146	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2016-07-06 09:30:00	2016-07-06 12:05:00	2018-05-18 15:13:29	2018-05-18 15:13:36	33	0	\N	\N
112947	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Audition sur la fraude fiscale - 2016 - M . Austry, Pdt de l'IACF, MM. Bornhauser, Teper,(IACF) Gaget  (Havas)	2016-06-30 18:00:00	2016-06-30 19:00:00	\N	\N	1	0	\N	\N
112949	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Mission Sécurités - Contrôle - 2016 - Préf. de police de Paris -Préfet de la préf. - M. Cadot	2016-07-01 15:00:00	2016-07-01 16:00:00	\N	\N	1	0	\N	\N
114854	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Francophonie	Groupe de travail Francophonie	2016-07-06 14:30:00	2016-07-06 16:30:00	\N	\N	2	0	\N	\N
117825	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL État d'urgence	PJL État d'urgence	2016-07-20 17:00:00	2016-07-20 18:00:00	\N	\N	198	0	\N	\N
118033	COM_SPECIALE	AUDRAP	\N	EGALITE	\N	Aud. Rapp. CS Egalité et citoyenneté 	Audition Rapporteur CS Egalité et citoyenneté 	2016-07-18 15:25:00	2016-07-18 19:30:00	\N	\N	2	0	\N	\N
118036	COM_SPECIALE	AUDRAP	\N	EGALITE	\N	Aud. Rapp. CS Egalité et citoyenneté 	Audition Rapporteur CS Egalité et citoyenneté 	2016-07-19 08:30:00	2016-07-19 11:10:00	\N	\N	4	0	\N	\N
118189	QUESTURE	AUCUNE	\N	\N	\N	Questure	Réunion de Questure	2016-06-23 11:30:00	2016-06-23 11:45:00	\N	\N	3	0	\N	\N
118272	MISSION	AUCUNE	\N	TELEPHONE	\N	MI téléphones mobiles 	MI téléphones mobiles 	2016-07-19 14:50:00	2016-07-19 15:50:00	2016-07-20 12:19:01	2016-07-20 14:47:58	10	0	\N	\N
118289	MISSION	AUDRAP	\N	TELEPHONE	\N	Aud. Rapp. MI téléphones mobiles 	Audition Rapporteur MI téléphones mobiles 	2016-07-19 18:30:00	2016-07-19 19:20:00	\N	\N	6	0	\N	\N
118296	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2016-07-19 17:30:00	2016-07-19 19:40:00	2016-07-20 17:47:24	2016-07-21 11:49:09	35	0	\N	\N
118344	COM_SPECIALE	PLENIERE	\N	EGALITE	\N	CS Egalité et citoyenneté 	CS Egalité et citoyenneté 	2016-07-19 14:45:00	2016-07-19 16:15:00	2016-07-20 12:18:11	2016-07-20 14:47:57	25	0	\N	\N
118378	COM_SPECIALE	PLENIERE	\N	EGALITE	\N	CS Egalité et citoyenneté 	CS Egalité et citoyenneté 	2016-07-19 16:40:00	2016-07-19 18:50:00	2016-07-20 12:18:25	2016-07-20 14:47:58	22	0	\N	\N
118412	MISSION	AUDRAP	\N	REVENU	\N	Aud. Rapp. MI Revenu de base en France 	Audition Rapporteur MI Revenu de base en France 	2016-07-19 14:30:00	2016-07-19 15:30:00	\N	\N	4	0	\N	\N
118514	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Audition Rapporteur FINC 	2016-07-13 09:00:00	2016-07-13 10:00:00	\N	\N	1	0	\N	\N
118516	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Audition SNIVPS	2016-07-19 14:00:00	2016-07-19 15:00:00	\N	\N	2	0	\N	\N
118519	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Audition BNEVP-DGAL	2016-07-19 15:00:00	2016-07-19 16:15:00	\N	\N	2	0	\N	\N
118522	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Audition SYNHORCAT 	2016-07-19 16:15:00	2016-07-19 17:40:00	\N	\N	2	0	\N	\N
118525	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-07-19 14:00:00	2016-07-19 14:45:00	\N	\N	1	0	\N	\N
118527	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	LOIS 	LOIS 	2016-07-19 09:30:00	2016-07-19 11:30:00	\N	\N	1	0	\N	\N
118760	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Football	Gouvernance du football	2016-07-20 14:30:00	2016-07-20 16:55:00	\N	\N	5	0	\N	\N
118775	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-07-20 18:50:00	2016-07-20 19:00:00	2018-05-18 15:16:31	2018-05-18 15:16:35	26	0	\N	\N
118812	GIA	AUCUNE	\N	\N	\N	GIA Afghanistan	Groupe interparlementaire Afghanistan	2016-07-19 14:30:00	2016-07-19 16:30:00	\N	\N	1	0	648	\N
118826	EXCUSES	AUTRE_NON_PLENIERE	\N	\N	\N	Autre (non plénière) 	Autre (non plénière) 	2016-07-20 00:00:00	2016-07-21 00:00:00	\N	\N	1	0	\N	\N
118914	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	FINC 	FINC 	2016-07-18 14:30:00	2016-07-18 15:30:00	\N	\N	1	0	\N	\N
118920	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Justice du XXIè siècle	PJL Justice du XXIè siècle	2016-09-27 14:35:00	2016-09-27 19:00:00	\N	\N	161	0	\N	\N
118921	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Justice du XXIè siècle	PJL Justice du XXIè siècle	2016-09-27 21:30:00	2016-09-27 23:50:00	\N	\N	49	0	\N	\N
118922	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	FINC 	FINC 	2016-07-19 15:00:00	2016-07-19 16:00:00	\N	\N	1	0	\N	\N
118923	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Audition Rapporteur FINC 	2016-07-20 10:00:00	2016-07-20 10:45:00	\N	\N	1	0	\N	\N
118932	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Audition Rapporteur FINC 	2016-07-19 14:30:00	2016-07-19 15:30:00	\N	\N	1	0	\N	\N
118934	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Audition Rapporteur FINC 	2016-07-19 15:30:00	2016-07-19 16:30:00	\N	\N	1	0	\N	\N
118936	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Audition Rapporteur FINC 	2016-07-20 15:00:00	2016-07-20 17:00:00	\N	\N	1	0	\N	\N
118938	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	FINC 	FINC 	2016-07-19 14:00:00	2016-07-19 17:00:00	\N	\N	1	0	\N	\N
118940	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	FINC 	FINC 	2016-07-20 13:15:00	2016-07-20 18:00:00	\N	\N	1	0	\N	\N
118941	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	FINC 	FINC 	2016-07-21 06:15:00	2016-07-21 17:30:00	\N	\N	2	0	\N	\N
118952	MISSION	AUDRAP	\N	TELEPHONE	\N	Aud. Rapp. MI téléphones mobiles 	Audition Rapporteur MI téléphones mobiles 	2016-07-21 17:10:00	2016-07-21 17:35:00	\N	\N	4	0	\N	\N
118956	MISSION	AUCUNE	\N	TELEPHONE	\N	MI téléphones mobiles 	MI téléphones mobiles 	2016-07-21 14:05:00	2016-07-21 17:10:00	2016-07-22 11:37:25	2016-07-22 12:14:09	5	0	\N	\N
118972	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-07-12 15:00:00	2016-07-12 16:00:00	\N	\N	1	0	\N	\N
118974	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-07-20 16:00:00	2016-07-20 17:00:00	\N	\N	1	0	\N	\N
118977	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-07-20 11:00:00	2016-07-20 11:45:00	\N	\N	1	0	\N	\N
106070	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Travail 	PJL Travail 	2016-06-17 14:30:00	2016-06-17 19:40:00	\N	\N	32	0	\N	\N
106108	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Travail	PJL Travail	2016-06-16 10:35:00	2016-06-16 13:10:00	\N	\N	70	0	\N	\N
106176	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT FINC - GT DGF	GT DGF - Cté pilotage - M. Julla - RCF Consultants	2016-06-14 14:00:00	2016-06-14 18:00:00	\N	\N	2	0	\N	\N
106179	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT FINC - GT DGF	Groupe de travail FINC -GT DGF	2016-06-15 16:30:00	2016-06-15 18:00:00	\N	\N	11	0	\N	\N
107093	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Travail 	PJL Travail 	2016-06-21 14:35:00	2016-06-21 17:20:00	\N	\N	153	0	\N	\N
107094	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Réunion Conseil européen	Débat Réunion Conseil européen	2016-06-21 17:30:00	2016-06-21 20:05:00	\N	\N	79	0	\N	\N
118417	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-07-20 09:20:00	2016-07-20 11:10:00	2018-05-18 15:17:30	2018-05-18 15:17:39	28	0	\N	\N
107739	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	CAE 	2016-06-21 15:00:00	2016-06-21 16:20:00	2016-06-22 11:12:34	2016-06-22 16:16:14	25	0	\N	\N
108092	COM_ENQUETE	PLENIERE	\N	CHOMAGE	\N	commission d'enquête sur les chiffres du chômage 	commission d'enquête sur les chiffres du chômage 	2016-06-21 15:00:00	2016-06-21 17:00:00	2016-06-22 09:39:36	2016-06-22 10:24:06	11	0	\N	\N
108532	GIA	AUCUNE	\N	\N	\N	GIA Ukraine	Groupe interparlementaire Ukraine	2016-06-22 08:30:00	2016-06-22 09:30:00	\N	\N	4	0	530	\N
109073	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Mission Sécurités - Contrôle 2016 - Préfecture de police de Paris  - D° du renseignement -  M. Bailly	2016-06-20 15:30:00	2016-06-20 16:30:00	\N	\N	1	0	\N	\N
109075	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Mission Sécurités-Contrôle -2016-Préf. de police de Paris - Dir° sécurité de prox. de l'agglo. parisienne - M. Meric	2016-06-20 16:30:00	2016-06-20 17:30:00	\N	\N	1	0	\N	\N
109093	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Misssion Défense - Contrôle - 2016 - OPEX - Major Gal de l'armée de l'Air - MM.  Adam, Surville/ Mme Bedino	2016-06-22 13:30:00	2016-06-22 14:30:00	\N	\N	1	0	\N	\N
109095	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2017 - Service industriel de l'aéronautique - M. JP Clerc (AIA Clermont)	2016-06-22 17:30:00	2016-06-22 18:30:00	\N	\N	1	0	\N	\N
109189	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle SAIP 	2016-06-21 10:00:00	2016-06-21 11:00:00	\N	\N	1	0	\N	\N
109193	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle SAIP	2016-06-21 11:00:00	2016-06-21 12:00:00	\N	\N	1	0	\N	\N
110352	GIA	AUCUNE	\N	\N	\N	GIA Mexique-Pays d'Am. Centrale	Groupe interparlementaire Mexique-Pays d'Am. Centrale	2016-06-28 12:30:00	2016-06-28 14:30:00	\N	\N	3	0	643	\N
111212	COM_SPECIALE	PLENIERE	\N	CITOYENNETE	\N	GT Egalité et citoyenneté 	GT Egalité et citoyenneté 	2016-06-28 18:30:00	2016-06-28 19:00:00	2016-06-29 15:12:41	2016-06-29 16:54:29	27	0	\N	\N
111249	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2016-06-29 09:35:00	2016-06-29 12:30:00	2016-06-29 13:06:18	2016-06-29 16:53:11	42	0	\N	\N
111932	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2016-06-29 15:05:00	2016-06-29 16:50:00	2016-06-30 10:21:34	2016-06-30 11:14:41	57	0	\N	\N
112342	DELEGATION	AUCUNE	\N	\N	211	Droits des femmes 	Droits des femmes 	2016-06-30 08:30:00	2016-06-30 09:30:00	2016-06-30 12:17:14	2016-06-30 15:34:20	7	0	\N	\N
113052	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2016-07-04 14:40:00	2016-07-04 15:10:00	2016-07-05 12:04:17	2016-07-05 15:02:47	16	0	\N	\N
113712	GIA	AUCUNE	\N	\N	\N	GIA Népal	Groupe interparlementaire Népal	2016-07-06 08:30:00	2016-07-06 09:30:00	\N	\N	3	0	633	\N
113732	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	Audition Harlem Désir sur le  Conseil européen des 28 et 29 juin.	2016-07-05 19:00:00	2016-07-05 20:45:00	2016-07-06 11:11:18	2016-07-06 16:44:54	40	0	\N	\N
115872	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Controle	CAS Partic° fin. de l'Etat - Contrôle - 2016 - Pol.E de dividendes de l'tat actionnaire -  APE - MM. Vial, Baron	2016-07-06 15:00:00	2016-07-06 16:00:00	\N	\N	1	0	\N	\N
115892	ETUDES	AUCUNE	\N	\N	\N	GE Chasse et pêche	Groupe d'études Chasse et pêche	2016-07-06 08:00:00	2016-07-06 09:00:00	\N	\N	19	0	\N	907
117718	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Audition Rapporteur FINC 	2016-07-13 15:30:00	2016-07-13 16:40:00	\N	\N	1	0	\N	\N
118730	MISSION	AUCUNE	\N	TELEPHONE	\N	MI téléphones mobiles 	MI téléphones mobiles 	2016-07-20 15:15:00	2016-07-20 16:30:00	2016-07-21 08:43:21	2016-07-21 11:46:39	9	0	\N	\N
118815	COM_SPECIALE	AUDRAP	\N	EGALITE	\N	Aud. Rapp. CS Egalité et citoyenneté 	Audition Rapporteur CS Egalité et citoyenneté 	2016-07-20 08:30:00	2016-07-20 11:35:00	\N	\N	6	0	\N	\N
118822	COM_SPECIALE	AUDRAP	\N	EGALITE	\N	Aud. Rapp. CS Egalité et citoyenneté 	Audition Rapporteur CS Egalité et citoyenneté 	2016-07-20 14:00:00	2016-07-20 15:30:00	\N	\N	1	0	\N	\N
118824	COM_SPECIALE	AUDRAP	\N	EGALITE	\N	Aud. Rapp. CS Egalité et citoyenneté 	Audition Rapporteur CS Egalité et citoyenneté 	2016-07-20 14:00:00	2016-07-20 15:30:00	\N	\N	1	0	\N	\N
118828	MISSION	AUCUNE	\N	TELEPHONE	\N	MI téléphones mobiles 	MI téléphones mobiles 	2016-07-21 09:00:00	2016-07-21 11:40:00	2016-07-21 12:02:17	2016-07-21 16:50:07	4	0	\N	\N
118852	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP État d'urgence	CMP État d'urgence	2016-07-21 15:00:00	2016-07-21 18:00:00	\N	\N	62	0	\N	\N
119012	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2016-07-26 14:30:00	2016-07-26 16:45:00	2016-07-27 16:16:10	2016-07-27 16:48:35	6	0	\N	\N
119092	COM_SPECIALE	PLENIERE	\N	EGALITE	\N	CS Egalité et citoyenneté 	CS Egalité et citoyenneté 	2016-07-27 10:00:00	2016-07-27 11:00:00	2016-07-28 14:27:55	2016-07-28 14:30:20	6	0	\N	\N
119099	COM_SPECIALE	PLENIERE	\N	EGALITE	\N	CS Egalité et citoyenneté 	CS Egalité et citoyenneté 	2016-07-27 14:30:00	2016-07-27 16:10:00	2016-07-28 14:28:35	2016-07-28 14:30:21	7	0	\N	\N
119112	COM_SPECIALE	AUDRAP	\N	EGALITE	\N	Aud. Rapp. CS Egalité et citoyenneté 	Audition Rapporteur CS Egalité et citoyenneté 	2016-07-26 09:30:00	2016-07-26 13:15:00	\N	\N	2	0	\N	\N
119115	COM_SPECIALE	AUDRAP	\N	EGALITE	\N	Audition Rapporteur 	Audition Rapporteur 	2016-07-26 14:30:00	2016-07-26 15:30:00	\N	\N	2	0	\N	\N
119132	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	MI Déradicalisation	Mission d'information Désendoctrinement, désembrigadement et réinsertion des djihadistes en France et en Europe	2016-05-12 10:00:00	2016-05-12 12:00:00	\N	\N	2	0	\N	\N
119135	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	MI déradicalisation 	Mission d'information Désendoctrinement, désembrigadement et réinsertion des djihadistes en France et en Europe	2016-05-26 10:00:00	2016-05-26 11:30:00	\N	\N	2	0	\N	\N
119138	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	MI déradicalisation 	Mission d'information désendoctrinement, désembrigadement et réinsertion des djihadistes en France et en Europe	2016-06-16 09:40:00	2016-06-16 11:40:00	\N	\N	2	0	\N	\N
119141	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	MI déradicalisation 	Misison d'information Désendoctrinement, désembrigadement et réinsertion des djihadistes en France et en Europe	2016-06-21 14:00:00	2016-06-21 15:30:00	\N	\N	2	0	\N	\N
119144	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	MI déradicalisation 	Mission d'information Désendoctrinement, désembrigadement et réinsertion des djihadistes en France et en Europe	2016-06-30 14:00:00	2016-06-30 16:00:00	\N	\N	2	0	\N	\N
119147	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	MI déradicalisation	Mission d'information Désendoctrinement, désembrigadement et réinsertion des djihadistes en France et en Europe	2016-06-15 14:30:00	2016-06-15 19:30:00	\N	\N	2	0	\N	\N
119150	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	MI déradicalisation 	Mission d'information Désendoctrinement, désembrigadement et réinsertion des djihadistes en France et en Europe	2016-06-01 16:00:00	2016-06-01 18:00:00	\N	\N	2	0	\N	\N
106172	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Mission Santé - Contrôle - 2016 -  INCa - Cour des comptes - M. Durrleman/Mme Prévot-Mouttalib	2016-06-14 15:00:00	2016-06-14 16:30:00	\N	\N	1	0	\N	\N
113833	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2016-07-06 09:15:00	2016-07-06 11:30:00	2016-07-06 12:40:55	2016-07-06 16:43:18	27	0	\N	\N
111112	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2016-06-29 09:05:00	2016-06-29 09:20:00	2018-05-18 15:10:40	2018-05-18 15:10:53	38	0	\N	\N
106341	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Mission Défense - Contrôle - 2016 - OPEX - Dir° Budget - MM. Moreau (sous-dir.) et Blaes (chef de bureau)	2016-06-14 14:30:00	2016-06-14 16:00:00	\N	\N	1	0	\N	\N
106348	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	M° Ecologie -  Enjx applicat° dt communautaire de l'envt - RP UE - MM. Blazy, Morellato, Mme Charrier	2016-06-14 12:30:00	2016-06-14 13:30:00	\N	\N	1	0	\N	\N
106351	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	M° Ecologie -  Enjx applicat° dt communautaire de l'envt - C° europ. - M. Ciobanu-Dodea - Directeu	2016-06-14 14:30:00	2016-06-14 15:30:00	\N	\N	1	0	\N	\N
107829	BUREAU	AUCUNE	\N	\N	\N	Délégation du Bureau	Délégation du Bureau statut et conditions d'exercice du mandat de sénateur	2016-06-21 14:00:00	2016-06-21 15:00:00	\N	\N	4	0	\N	\N
107859	ETUDES	AUCUNE	\N	\N	\N	GE Société numérique	Groupe d'études Société numérique, nouveaux usages, nouveaux médias	2016-06-16 09:00:00	2016-06-16 11:30:00	\N	\N	2	0	\N	965
107863	ETUDES	AUCUNE	\N	\N	\N	GE Société numérique	Groupe d'études Société numérique, nouveaux usages, nouveaux médias	2016-06-21 14:40:00	2016-06-21 16:30:00	\N	\N	7	0	\N	965
111343	GIA	AUCUNE	\N	\N	\N	GIA Afrique de l'Ouest	Groupe interparlementaire Afrique de l'Ouest	2016-06-29 08:30:00	2016-06-29 09:30:00	\N	\N	6	0	573	\N
111392	GIA	AUCUNE	\N	\N	\N	GIA Pakistan	Groupe interparlementaire Pakistan	2016-06-29 08:30:00	2016-06-29 09:30:00	\N	\N	3	0	619	\N
111773	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-06-29 09:45:00	2016-06-29 11:35:00	2016-06-29 16:38:18	2016-06-29 16:53:10	36	0	\N	\N
111888	GIA	AUCUNE	\N	\N	\N	GIA Maroc	Groupe interparlementaire Maroc	2016-06-29 08:30:00	2016-06-29 09:30:00	\N	\N	7	0	598	\N
112632	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT CAE 	Groupe de travail CAE 	2016-06-28 18:30:00	2016-06-28 19:30:00	\N	\N	3	0	\N	\N
112672	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Mission Sécurités - Contrôle - 2016 - Préf. de police de Paris  - Labo central (rue de Dantzig) - M. Carlotti	2016-06-27 15:30:00	2016-06-27 17:00:00	\N	\N	1	0	\N	\N
112692	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Mission Sécurités - Contrôle - 2016 - Préf. de police de Paris - Visite du centre d'info° et cdmt	2016-06-30 10:15:00	2016-06-30 13:00:00	\N	\N	1	0	\N	\N
112694	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	contrôle Préfecture de police de Paris	2016-06-30 12:00:00	2016-06-30 13:00:00	\N	\N	1	0	\N	\N
112702	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	M° Politique des territoires - Contrôle  - 2016 - Adultes-relais - ASP - M. Georges	2016-06-28 17:30:00	2016-06-28 18:15:00	\N	\N	1	0	\N	\N
113372	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Francophonie	Groupe de travail Francophonie	2016-06-29 14:30:00	2016-06-29 16:30:00	\N	\N	3	0	\N	\N
113376	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Football	Gouvernance du football	2016-07-05 15:30:00	2016-07-05 16:50:00	\N	\N	5	0	\N	\N
113384	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Francophonie	Groupe de travail Francophonie	2016-07-05 16:30:00	2016-07-05 17:30:00	\N	\N	4	0	\N	\N
113392	COM_ENQUETE	PLENIERE	\N	CHOMAGE	\N	commission d'enquête sur les chiffres du chômage 	commission d'enquête sur les chiffres du chômage 	2016-07-05 16:00:00	2016-07-05 17:10:00	2016-07-05 18:14:58	2016-07-06 16:45:54	12	0	\N	\N
115186	GIA	AUCUNE	\N	\N	\N	GIA Syrie	Groupe interparlementaire Syrie	2016-07-05 08:15:00	2016-07-05 09:30:00	\N	\N	1	0	644	\N
115192	GIA	AUCUNE	\N	\N	\N	GIA Iraq	Groupe interparlementaire Iraq	2016-07-06 17:15:00	2016-07-06 18:15:00	\N	\N	1	0	615	\N
115259	GIA	AUCUNE	\N	\N	\N	GIA Syrie	Groupe interparlementaire Syrie	2016-07-05 17:00:00	2016-07-05 18:00:00	\N	\N	1	0	644	\N
115273	GIA	AUCUNE	\N	\N	\N	GIA Royaume-Uni	Groupe interparlementaire Royaume-Uni	2016-07-05 12:30:00	2016-07-05 14:30:00	\N	\N	6	0	581	\N
115292	GIA	AUCUNE	\N	\N	\N	GIA Canada	Groupe interparlementaire Canada	2016-07-05 14:30:00	2016-07-05 15:20:00	\N	\N	1	0	583	\N
115295	GIA	AUCUNE	\N	\N	\N	GIA Canada	Groupe interparlementaire Canada	2016-07-05 15:30:00	2016-07-05 16:30:00	\N	\N	2	0	583	\N
115298	GIA	AUCUNE	\N	\N	\N	GIA Canada	Groupe interparlementaire Canada	2016-07-05 16:30:00	2016-07-05 17:30:00	\N	\N	1	0	583	\N
115300	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2016-07-06 17:30:00	2016-07-06 19:05:00	2016-07-07 16:28:22	2016-07-07 17:24:50	7	0	\N	\N
115312	GIA	AUCUNE	\N	\N	\N	GIA Inde	Groupe interparlementaire Inde	2016-07-05 19:30:00	2016-07-05 21:30:00	\N	\N	1	0	618	\N
115353	GIA	AUCUNE	\N	\N	\N	GIA Croatie	Groupe interparlementaire Croatie	2016-07-06 08:00:00	2016-07-06 09:00:00	\N	\N	4	0	647	\N
115972	ETUDES	AUCUNE	\N	\N	\N	GE Sénateurs anciens combattants et mémoire combattante	Groupe d'études Sénateurs anciens combattants et mémoire combattante	2016-07-05 15:00:00	2016-07-05 17:00:00	\N	\N	11	0	\N	928
116012	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	AG de l'APF	Aucune 	2016-07-08 09:00:00	2016-07-13 11:30:00	\N	\N	2	0	\N	\N
116015	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	AG de l'APF	Aucune 	2016-07-09 10:00:00	2016-07-13 11:30:00	\N	\N	1	0	\N	\N
116252	COM_PERMANENTE	DEPLACEMENT	\N	CAE	\N	CAE 	CAE 	2016-07-12 12:00:00	2016-07-12 14:00:00	\N	\N	0	0	\N	\N
116572	COM_SPECIALE	PLENIERE	\N	EGALITE	\N	CS Egalité et citoyenneté 	CS Egalité et citoyenneté 	2016-07-05 10:00:00	2016-07-05 10:45:00	\N	\N	4	0	\N	\N
116577	COM_SPECIALE	PLENIERE	\N	CITOYENNETE	\N	GT Egalité et citoyenneté 	GT Egalité et citoyenneté 	2016-07-05 14:00:00	2016-07-05 18:10:00	\N	\N	3	0	\N	\N
116581	COM_SPECIALE	PLENIERE	\N	CITOYENNETE	\N	GT Egalité et citoyenneté 	GT Egalité et citoyenneté 	2016-07-06 14:00:00	2016-07-06 16:45:00	\N	\N	2	0	\N	\N
116585	COM_SPECIALE	PLENIERE	\N	CITOYENNETE	\N	GT Egalité et citoyenneté 	GT Egalité et citoyenneté 	2016-07-06 17:45:00	2016-07-06 20:15:00	\N	\N	2	0	\N	\N
116589	COM_SPECIALE	PLENIERE	\N	CITOYENNETE	\N	GT Egalité et citoyenneté 	GT Egalité et citoyenneté 	2016-07-06 14:30:00	2016-07-06 17:30:00	\N	\N	3	0	\N	\N
116612	COM_SPECIALE	PLENIERE	\N	CITOYENNETE	\N	GT Egalité et citoyenneté 	GT Egalité et citoyenneté 	2016-07-06 08:30:00	2016-07-06 09:45:00	\N	\N	2	0	\N	\N
116615	COM_SPECIALE	PLENIERE	\N	CITOYENNETE	\N	GT Egalité et citoyenneté 	GT Egalité et citoyenneté 	2016-07-05 14:00:00	2016-07-05 18:30:00	\N	\N	3	0	\N	\N
116619	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Règlement du budget après-midi	PJL Règlement du budget	2016-07-13 14:30:00	2016-07-13 19:30:00	\N	\N	34	0	\N	\N
116620	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Gaz	PJL Gaz	2016-07-13 14:30:00	2016-07-13 19:30:00	\N	\N	18	0	\N	\N
108543	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-06-22 09:10:00	2016-06-22 13:20:00	2018-05-18 15:08:57	2018-05-18 15:09:03	43	0	\N	\N
111835	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-06-29 11:35:00	2016-06-29 11:45:00	2018-05-18 15:11:42	2018-05-18 15:11:50	25	0	\N	\N
116623	COM_SPECIALE	PLENIERE	\N	CITOYENNETE	\N	GT Egalité et citoyenneté 	GT Egalité et citoyenneté 	2016-07-07 09:00:00	2016-07-07 12:30:00	\N	\N	4	0	\N	\N
116750	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT FINC 	GT  Transport - Table ronde CDG Express - M. Pourquery de Boisserin - Mme Locquet	2016-07-12 14:00:00	2016-07-12 15:15:00	\N	\N	5	0	\N	\N
117055	COM_PERMANENTE	DEPLACEMENT	\N	AFCL	\N	Accord majeur	5e Rencontres Accord majeur à Aix-en-Provence	2016-07-11 14:00:00	2016-07-12 22:00:00	\N	\N	5	0	\N	\N
117072	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-07-13 09:05:00	2016-07-13 11:10:00	2018-05-18 15:14:54	2018-05-18 15:14:58	21	0	\N	\N
117112	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	CAE 	2016-07-13 11:15:00	2016-07-13 12:40:00	2018-05-18 15:16:05	2018-05-18 15:16:08	22	0	\N	\N
117212	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2016-07-13 09:35:00	2016-07-13 11:20:00	2016-07-13 15:59:18	2016-07-13 17:26:55	25	0	\N	\N
117492	COM_SPECIALE	PLENIERE	\N	EGALITE	\N	CS Egalité et citoyenneté 	CS Egalité et citoyenneté 	2016-07-13 14:20:00	2016-07-13 15:50:00	2016-07-13 17:06:58	2016-07-13 17:27:50	15	0	\N	\N
117572	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2016-07-19 09:30:00	2016-07-19 12:30:00	\N	\N	31	0	\N	\N
117573	GIA	AUCUNE	\N	\N	\N	GIA Italie	Groupe interparlementaire Italie	2016-06-28 12:45:00	2016-06-28 14:30:00	\N	\N	17	0	621	\N
117612	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	UIP sous comité des finances	Aucune 	2016-07-13 07:00:00	2016-07-13 19:00:00	\N	\N	1	0	\N	\N
106914	GIA	AUCUNE	\N	\N	\N	GIA Australie	Groupe interparlementaire Australie	2016-06-15 18:00:00	2016-06-15 19:30:00	\N	\N	6	0	578	\N
106952	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-06-16 16:30:00	2016-06-16 18:30:00	\N	\N	1	0	\N	\N
106954	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Controle	Mission Immigration - Contrôle - 2016 - CADA - DG Hébergement urgence - Min. Int. et Aff. Soc.	2016-06-14 11:15:00	2016-06-14 12:30:00	\N	\N	1	0	\N	\N
106972	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-06-15 14:30:00	2016-06-15 15:30:00	\N	\N	1	0	\N	\N
106992	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Francophonie	Groupe de travail Francophonie	2016-06-14 14:30:00	2016-06-14 15:30:00	\N	\N	4	0	\N	\N
107012	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-06-15 14:30:00	2016-06-15 19:45:00	\N	\N	1	0	\N	\N
107014	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-06-16 09:30:00	2016-06-16 13:15:00	\N	\N	1	0	\N	\N
107016	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Pierrefitte (contrôle Archives nationales)	Mission Culture - Contrôle - 2016 - Pierrefitte sur Seine - Mme Banat-Berger - Archives nationales	2016-06-17 14:00:00	2016-06-17 16:30:00	\N	\N	1	0	\N	\N
107018	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Contrôle	M° AGTE - Contrôle - 2016 - Réfme adm. ss-préf - M. Espinasse, DMAT et M. Seguy 	2016-06-14 09:00:00	2016-06-14 10:30:00	\N	\N	1	0	\N	\N
107020	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Déplacement Côtes d'Armor (contrôle)	M° Agriculture - Contrôle - Moy. pol. sanitaire  et alim. - Visite abattoir Ploufragan-Kerméné- Lanfains	2016-06-16 06:00:00	2016-06-16 17:30:00	\N	\N	2	0	\N	\N
108412	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2016-06-22 09:30:00	2016-06-22 12:00:00	2016-06-23 14:55:41	2016-06-23 15:32:53	34	0	\N	\N
109157	COM_EURO	CONTROLE	\N	AFEU	\N	AFEU 	AFEU 	2016-06-23 08:30:00	2016-06-23 09:25:00	2016-06-23 11:31:45	2016-06-23 15:33:28	11	0	\N	\N
109217	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Travail	PJL Travail	2016-06-24 09:30:00	2016-06-24 12:55:00	\N	\N	34	0	\N	\N
109218	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Travail	PJL Travail	2016-06-24 14:30:00	2016-06-24 20:00:00	\N	\N	41	0	\N	\N
109219	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Travail	PJL Travail	2016-06-24 21:50:00	2016-06-25 00:00:00	\N	\N	20	0	\N	\N
110195	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	M° Transport - Contrôle sûreté aérienne - Gendarmerie transp. aériens - Gal Hubert	2016-06-23 14:00:00	2016-06-23 15:00:00	\N	\N	1	0	\N	\N
110292	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	CDD	\N	CDD Iffstar	CDD Iffstar	2016-06-15 09:00:00	2016-06-15 12:00:00	\N	\N	8	0	\N	\N
110301	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD RI Eau	Audition Rapporteur CDD RI Eau	2016-06-22 14:30:00	2016-06-22 16:00:00	\N	\N	1	0	\N	\N
110303	ETUDES	AUCUNE	\N	\N	\N	GE Cheval	Groupe d'études Cheval	2016-06-22 08:30:00	2016-06-22 09:30:00	\N	\N	4	0	\N	912
110313	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Clercs de notaires	PPL Clercs de notaires	2016-06-29 14:30:00	2016-06-29 15:15:00	\N	\N	37	0	\N	\N
110314	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PJL Architecture	CMP PJL Architecture	2016-06-29 15:35:00	2016-06-29 17:10:00	\N	\N	55	0	\N	\N
110315	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-06-28 09:30:00	2016-06-28 10:10:00	2016-06-28 11:19:55	2016-06-28 15:55:35	16	0	\N	\N
110550	SEANCE_PLENIERE	SCRUSOL	621	\N	\N	Scrutin PJL travail	Scrutin PJL travail	2016-06-28 17:55:00	2016-06-28 18:25:00	\N	\N	0	0	\N	\N
110610	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	621	\N	\N	Explications de vote PJL Travail	Explications de vote PJL Travail	2016-06-28 17:00:00	2016-06-28 17:55:00	\N	\N	280	0	\N	\N
110630	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Listes électorales	PPL Listes électorales	2016-06-28 18:30:00	2016-06-28 20:10:00	\N	\N	54	0	\N	\N
111168	QUESTURE	AUCUNE	\N	\N	\N	Questure	Réunion de Questure	2016-06-28 18:00:00	2016-06-28 20:30:00	\N	\N	2	0	\N	\N
111171	QUESTURE	AUCUNE	\N	\N	\N	Questure	Réunion de Questure	2016-06-29 08:30:00	2016-06-29 10:00:00	\N	\N	2	0	\N	\N
111547	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2016-06-29 09:50:00	2016-06-29 12:25:00	2018-05-18 15:11:17	2018-05-18 15:11:27	45	1	\N	\N
111714	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2016-06-29 09:20:00	2016-06-29 12:15:00	2016-06-30 10:20:35	2016-06-30 11:14:45	43	0	\N	\N
112032	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2016-06-30 09:30:00	2016-06-30 10:30:00	\N	\N	14	0	\N	\N
112033	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Polynésie	PPL Polynésie	2016-06-30 10:30:00	2016-06-30 12:00:00	\N	\N	23	0	\N	\N
112035	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Agriculture	PPL Agriculture	2016-06-30 16:00:00	2016-06-30 18:20:00	\N	\N	26	0	\N	\N
112036	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Mayotte	PPL Mayotte	2016-06-30 18:35:00	2016-06-30 20:00:00	\N	\N	15	0	\N	\N
112432	MISSION	AUCUNE	\N	TELEPHONE	\N	MI téléphones mobiles 	MI téléphones mobiles 	2016-06-29 13:40:00	2016-06-29 14:00:00	2016-06-30 15:57:00	2016-06-30 16:57:17	15	0	\N	\N
112696	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE 	Audition Rapporteur CAE 	2016-06-28 08:00:00	2016-06-28 11:00:00	\N	\N	2	0	\N	\N
112699	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE 	Audition Rapporteur CAE 	2016-06-28 14:00:00	2016-06-28 15:10:00	\N	\N	1	0	\N	\N
111404	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2016-06-29 09:35:00	2016-06-29 09:50:00	2016-06-29 15:20:17	2016-06-29 16:53:15	45	1	\N	\N
113932	GIA	AUCUNE	\N	\N	\N	GIA Suisse	Groupe interparlementaire Suisse	2016-06-08 12:30:00	2016-06-08 14:30:00	\N	\N	6	0	610	\N
114470	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-07-06 09:25:00	2016-07-06 11:15:00	2018-05-18 15:13:01	2018-05-18 15:13:10	34	1	\N	\N
115194	MISSION	AUCUNE	\N	REVENU	\N	MI Revenu de base en France 	MI Revenu de base en France 	2016-07-07 13:40:00	2016-07-08 15:50:00	2016-07-07 16:53:43	2016-07-07 17:26:48	9	0	\N	\N
115688	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	APCEMN	Aucune 	2016-06-28 08:00:00	2016-07-01 17:00:00	\N	\N	1	0	\N	\N
115690	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	UIP	Aucune 	2016-06-28 08:00:00	2016-06-30 18:00:00	\N	\N	1	0	\N	\N
115713	GIA	AUCUNE	\N	\N	\N	GIA Canada	Groupe interparlementaire Canada	2016-07-05 12:30:00	2016-07-05 14:20:00	\N	\N	8	0	583	\N
115772	GIA	AUCUNE	\N	\N	\N	GIA Croatie	Groupe interparlementaire Croatie	2016-07-06 08:00:00	2016-07-06 09:30:00	\N	\N	4	0	647	\N
115792	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Controle	Mission Politique des territoires - Contrôle - 2016 - Adultes-relais - ed° centres socx de France 	2016-07-06 15:10:00	2016-07-06 16:10:00	\N	\N	1	0	\N	\N
115796	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC	Facé - Contrôle - 2016 - Gest° et ut° aides - FNCCR - M. Hourcabie 	2016-07-06 14:00:00	2016-07-06 15:00:00	\N	\N	1	0	\N	\N
115798	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC	Facé - Contrôle - 2016 - Gest° et ut° aides - M. Ladislas Poniatowski 	2016-07-05 16:00:00	2016-07-05 17:00:00	\N	\N	1	0	\N	\N
115814	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Biodiversité	PJL Biodiversité	2016-07-11 16:00:00	2016-07-11 19:30:00	\N	\N	34	0	\N	\N
115815	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Biodiversité	PJL Biodiversité	2016-07-11 20:30:00	2016-07-12 00:30:00	\N	\N	25	0	\N	\N
115852	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	GT CDD 	Groupe de travail CDD 	2016-07-07 10:00:00	2016-07-07 12:00:00	\N	\N	5	0	\N	\N
117032	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Dialogue social	PJL Dialogue social	2016-07-19 14:30:00	2016-07-19 16:30:00	\N	\N	115	0	\N	\N
117033	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Listes électorales	CMP Listes électorales	2016-07-19 16:30:00	2016-07-19 19:00:00	\N	\N	38	0	\N	\N
117052	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	réunion Bureau APM	Aucune 	2016-07-10 09:00:00	2016-07-12 19:00:00	\N	\N	2	0	\N	\N
117113	QUESTURE	AUCUNE	\N	\N	\N	Questure	Réunion de Questure	2016-07-13 09:30:00	2016-07-13 10:20:00	\N	\N	2	0	\N	\N
117372	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2016-07-13 10:05:00	2016-07-13 14:20:00	2018-05-18 15:15:46	2018-05-18 15:15:53	32	1	\N	\N
117454	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	M° Egalité des territ. et logt - Contrôle - 2016  Centres hébergement urgence - Samu Social - Mme Laconde, pdte 	2016-07-12 08:30:00	2016-07-12 09:45:00	\N	\N	1	0	\N	\N
117481	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	M° Egalité des territoires et logt  - Contrôle - 2016 - Dispositif d'héb. urgence - Cour des comptes - Mme Mattéi	2016-07-12 13:30:00	2016-07-12 14:25:00	\N	\N	1	0	\N	\N
119153	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	MI déradicalisation 	Mission d'information Désendoctrinement, désembrigadement et réinsertion des djihadistes en France et en Europe	2016-06-30 16:30:00	2016-07-01 20:00:00	\N	\N	2	0	\N	\N
119156	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	MI biométrie	Mission d'information biométrie	2016-05-25 14:00:00	2016-05-25 19:00:00	\N	\N	2	0	\N	\N
119159	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	MI biométrie	Mission d'information biométrie	2016-06-07 15:10:00	2016-06-07 18:00:00	\N	\N	2	0	\N	\N
119162	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	MI biométrie	Mission d'information biométrie	2016-03-24 13:15:00	2016-03-24 19:30:00	\N	\N	2	0	\N	\N
119329	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Audition Rapporteur FINC 	2016-09-06 11:00:00	2016-09-06 12:00:00	\N	\N	1	0	\N	\N
119334	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle	2016-09-06 15:30:00	2016-09-06 16:30:00	\N	\N	1	0	\N	\N
119346	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	FINC 	FINC 	2016-09-08 12:00:00	2016-09-08 14:00:00	\N	\N	1	0	\N	\N
119349	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	FINC 	FINC 	2016-09-08 14:30:00	2016-09-08 16:00:00	\N	\N	1	0	\N	\N
119352	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	FINC 	FINC 	2016-09-08 16:15:00	2016-09-08 18:30:00	\N	\N	1	0	\N	\N
119354	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	FINC 	FINC 	2016-09-09 08:15:00	2016-09-09 09:45:00	\N	\N	1	0	\N	\N
119356	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	FINC 	FINC 	2016-09-09 10:00:00	2016-09-09 11:15:00	\N	\N	1	0	\N	\N
119572	MISSION	AUCUNE	\N	REVENU	\N	MI Revenu de base en France 	MI Revenu de base en France 	2016-09-15 14:35:00	2016-09-15 17:15:00	2016-09-16 11:48:38	2016-09-16 15:22:00	4	0	\N	\N
119952	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT FINC 	GT infrastructures de transport	2016-09-13 16:30:00	2016-09-13 17:30:00	\N	\N	5	0	\N	\N
119958	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT FINC 	GT infrastructures de transport	2016-09-21 14:30:00	2016-09-21 15:00:00	\N	\N	4	0	\N	\N
119963	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	FINC 	FINC 	2016-09-20 10:00:00	2016-09-20 20:00:00	\N	\N	1	0	\N	\N
119966	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Contrôle	Audition Rapporteur FINC 	2016-09-21 15:00:00	2016-09-21 16:00:00	\N	\N	1	0	\N	\N
119968	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	FINC 	FINC 	2016-09-23 11:40:00	2016-09-23 14:40:00	\N	\N	1	0	\N	\N
119994	DELEGATION	DEPLACEMENT	\N	\N	ENTREPRISES	Déplacement Suède / Allemagne - Simplification du droit	Déplacement Suède / Allemagne	2016-09-28 20:00:00	2016-09-30 19:55:00	\N	\N	3	0	\N	\N
119998	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-09-27 09:05:00	2016-09-27 10:05:00	2018-05-18 15:16:51	2018-05-18 15:16:56	21	0	\N	\N
120768	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2016-09-28 10:15:00	2016-09-28 12:05:00	2016-09-28 14:53:47	2016-09-28 15:23:57	38	0	\N	\N
121645	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Éthique, régulation et transparence du sport professionnel	PPL Éthique, régulation et transparence du sport professionnel	2016-09-29 09:00:00	2016-09-29 12:00:00	\N	\N	4	0	\N	\N
121652	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	\N	2016-09-27 14:30:00	2016-09-27 15:00:00	\N	\N	1	0	\N	\N
121654	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	\N	2016-09-27 18:00:00	2016-09-27 19:10:00	\N	\N	2	0	\N	\N
121721	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Transmission  et reprise d'entreprises	RI Transmission et reprise d'entreprises	2016-10-11 14:00:00	2016-10-11 16:15:00	\N	\N	3	0	\N	\N
121724	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Transmission  et reprise d'entreprises	RI Transmission et reprise d'entreprises	2016-10-26 15:15:00	2016-10-26 16:30:00	\N	\N	2	0	\N	\N
121727	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Transmission  et reprise d'entreprises	RI Transmission et reprise d'entreprises	2016-10-19 15:00:00	2016-10-19 16:00:00	\N	\N	2	0	\N	\N
121990	DELEGATION	DEPLACEMENT	\N	\N	206	Visite Campus Bio Tech (Genêve)	\N	2016-09-22 09:00:00	2016-09-22 16:00:00	\N	\N	1	0	\N	\N
117155	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2016-07-13 09:35:00	2016-07-13 11:45:00	2018-05-18 15:15:16	2018-05-18 15:15:25	31	0	\N	\N
117297	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2016-07-13 10:00:00	2016-07-13 11:55:00	2016-07-20 11:43:25	2016-07-20 11:43:31	38	0	\N	\N
122637	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Égalité et citoyenneté	PJL Égalité et citoyenneté	2016-10-05 14:30:00	2016-10-05 19:30:00	\N	\N	143	0	\N	\N
122639	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Égalité et citoyenneté	PJL Égalité et citoyenneté	2016-10-05 21:00:00	2016-10-06 00:30:00	\N	\N	56	0	\N	\N
123204	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Francophonie	sur la Francophonie	2016-09-28 15:00:00	2016-09-28 16:00:00	\N	\N	3	0	\N	\N
123208	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Francophonie	sur la Francophonie	2016-09-29 10:30:00	2016-09-29 11:30:00	\N	\N	2	0	\N	\N
123237	DELEGATION	AUCUNE	\N	\N	206	Examen du projet de rapport sur "l'épigénétique"	\N	2016-10-11 17:10:00	2016-10-11 18:20:00	2016-10-12 11:22:10	2016-10-12 15:05:27	7	0	\N	\N
123262	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2016-10-05 16:40:00	2016-10-05 17:45:00	2016-10-06 10:33:53	2016-10-06 16:54:30	33	0	\N	\N
123852	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle agriculture 2016	Contrôle agriculture 2016 - Audition CGAAER	2016-10-04 14:45:00	2016-10-04 16:40:00	\N	\N	2	0	\N	\N
123855	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2017 - Avis Coordination travail gouvernemental	\N	2016-10-04 16:00:00	2016-10-04 16:45:00	\N	\N	1	0	\N	\N
123857	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2017 - Avis Coordination travail gouvernemental	\N	2016-10-05 14:00:00	2016-10-05 14:45:00	\N	\N	1	0	\N	\N
123859	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2017 - Avis Coordination travail gouvernemental	\N	2016-10-05 14:45:00	2016-10-05 15:30:00	\N	\N	1	0	\N	\N
123862	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2017 - Avis Coordination travail gouvernemental	\N	2016-10-05 15:30:00	2016-10-05 16:15:00	\N	\N	1	0	\N	\N
123864	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2017 - Avis Coordination travail gouvernemental	\N	2016-10-05 16:15:00	2016-10-05 17:00:00	\N	\N	1	0	\N	\N
123876	MISSION	AUDRAP	\N	REVENU	\N	\N	\N	2016-10-06 09:10:00	2016-10-06 10:15:00	\N	\N	2	0	\N	\N
123970	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Action extérieure de l'État	PLF pour 2017  - Action extérieure de l'État - Audition directrice générale de la mondialisation	2016-10-04 15:00:00	2016-10-04 16:00:00	\N	\N	2	0	\N	\N
123973	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Sport, jeunesse et vie associative	PLF pour 2017 - Sport, jeunesse et vie associative - Audition Président de l'agence de service civique	2016-10-06 09:30:00	2016-10-06 10:30:00	\N	\N	1	0	\N	\N
123975	COM_PERMANENTE	AUTRE	\N	ETRD	\N	PPL Action extérieure des collectivités territoriales	\N	2014-10-01 09:00:00	2014-10-01 12:00:00	2016-10-07 14:21:00	\N	37	0	\N	\N
124058	MISSION	PLEIN_NON_JO	\N	BREXIT	\N	\N	\N	2016-09-07 10:05:00	2016-09-07 11:25:00	2016-10-07 16:39:15	\N	13	0	\N	\N
124072	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2017 - Solidarité	PLF pour 2017 - Solidarité	2016-10-19 13:30:00	2016-10-19 14:30:00	\N	\N	1	0	\N	\N
124074	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2017 - Solidarité	PLF pour 2017 - Solidarité	2016-10-26 14:00:00	2016-10-26 18:00:00	\N	\N	1	0	\N	\N
124106	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Grand Paris Express	Aud. Rapp. CAE - Grand Paris Express	2016-10-06 08:00:00	2016-10-06 09:30:00	\N	\N	1	0	\N	\N
124148	DELEGATION	AUCUNE	\N	\N	206	Audition publique dans le cadre de l'étude sur les "biotechnologies"	"Les nouvelles biotechnologies : quelles applications, quel débat public ?"	2016-10-27 09:00:00	2016-10-27 13:20:00	2016-10-27 18:35:55	2016-10-28 10:17:08	10	0	\N	\N
124149	DELEGATION	AUCUNE	\N	\N	206	Audition publique de l'agence de la biomédecine	\N	2016-11-09 18:10:00	2016-11-09 19:20:00	2016-11-10 18:09:42	2016-11-14 16:12:30	5	0	\N	\N
124150	DELEGATION	DEPLACEMENT	\N	\N	206	Visite du pôle judiciaire de la Gendarmerie nationale (Pontoise)	\N	2016-11-10 08:30:00	2016-11-10 15:10:00	\N	\N	4	0	\N	\N
124154	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2016-10-11 09:35:00	2016-10-11 12:25:00	\N	\N	36	0	\N	\N
124448	GIA	AUCUNE	\N	\N	\N	Déjeuner en l'honneur de l'Ambassadeur de Finlande	Déjeuner en l'honneur de l'Ambassadeur de Finlande	2016-10-11 12:30:00	2016-10-11 14:30:00	\N	\N	5	0	640	\N
125175	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2016-10-12 10:15:00	2016-10-12 12:10:00	2016-10-12 15:27:36	2016-10-12 15:29:01	40	0	\N	\N
119192	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI 	Audition Rapporteur SOCI 	2016-09-13 10:00:00	2016-09-13 15:00:00	\N	\N	1	0	\N	\N
119194	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2017 - Solidarité	PLF pour 2017 - Solidarité	2016-10-11 14:00:00	2016-10-11 18:00:00	\N	\N	1	0	\N	\N
119331	DELEGATION	AUCUNE	\N	\N	211	Droits des femmes 	Droits des femmes 	2016-09-13 15:00:00	2016-09-13 16:15:00	2016-09-13 17:19:14	2016-09-14 17:24:49	3	0	\N	\N
119492	MISSION	DEPLACEMENT	\N	REVENU	\N	MI Revenu de base en France 	MI Revenu de base en France 	2016-09-11 18:00:00	2016-09-13 22:00:00	\N	\N	4	0	\N	\N
119532	MISSION	AUCUNE	\N	REVENU	\N	MI Revenu de base en France 	MI Revenu de base en France 	2016-09-14 14:35:00	2016-09-14 17:35:00	2016-09-15 16:27:12	2016-09-15 16:57:56	7	0	\N	\N
119612	DELEGATION	AUCUNE	\N	\N	211	Droits des femmes 	Droits des femmes 	2016-09-20 12:30:00	2016-09-20 14:30:00	2016-09-20 18:18:16	2016-09-21 15:23:07	6	0	\N	\N
119633	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2016-09-21 09:30:00	2016-09-21 10:10:00	2016-09-21 15:25:03	2016-09-21 16:58:16	31	0	\N	\N
119691	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2016-09-21 11:00:00	2016-09-21 12:30:00	2016-09-21 15:25:24	2016-09-21 16:58:09	28	0	\N	\N
119730	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-09-21 09:20:00	2016-09-21 12:30:00	2018-05-18 15:20:03	2018-05-18 15:20:08	28	1	\N	\N
119930	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP République numérique	CMP République numérique	2016-09-28 14:35:00	2016-09-28 15:50:00	\N	\N	70	0	\N	\N
119931	SEANCE_PLENIERE	DEBAT	\N	\N	\N	PJL Justice du XXIè siècle	PJL Justice du XXIè siècle	2016-09-28 16:05:00	2016-09-28 18:05:00	\N	\N	63	0	\N	\N
119932	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Conventions	Conventions	2016-09-29 10:30:00	2016-09-29 11:15:00	\N	\N	39	0	\N	\N
119933	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Croix-Rouge	PPL Croix-Rouge	2016-09-29 11:15:00	2016-09-29 12:05:00	\N	\N	36	0	\N	\N
119934	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au Gouvernement	Questions d'actualité au Gouvernement	2016-09-29 15:05:00	2016-09-29 16:10:00	\N	\N	184	0	\N	\N
119935	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Liberté des médias	PPL Liberté des médias	2016-09-29 16:20:00	2016-09-29 17:50:00	\N	\N	24	0	\N	\N
124734	COM_PERMANENTE	AUTRE	\N	CAE	\N	PPL Stabilisation du droit de l'urbanisme	PPL portant accélération des procédures et stabilisation du droit de l'urbanisme, de la construction et de l'aménagement	2016-10-12 09:30:00	2016-10-12 10:50:00	2016-10-12 15:26:57	2016-10-12 15:28:14	34	0	\N	\N
125099	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2016-10-12 10:00:00	2016-10-12 10:15:00	2016-10-12 15:26:45	2016-10-12 15:29:02	43	1	\N	\N
120432	ETUDES	AUCUNE	\N	\N	\N	GE Section Trufficulture	Groupe d'études Section Trufficulture	2016-09-28 08:30:00	2016-09-28 09:30:00	\N	\N	20	0	\N	1005
120503	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2016-09-28 10:05:00	2016-09-28 10:55:00	2018-05-18 15:19:03	2018-05-18 15:19:07	36	1	\N	\N
120660	COM_SPECIALE	PLENIERE	\N	EGALITE	\N	CS Egalité et citoyenneté 	CS Egalité et citoyenneté 	2016-09-28 09:30:00	2016-09-28 12:00:00	2016-09-28 14:23:17	2016-09-28 15:28:15	27	0	\N	\N
120963	COM_EURO	AUTRE_NON_PLENIERE	\N	AFEU	\N	AFEU 	AFEU -M. Ademi, vice-Premier ministre de Macédoine	2016-09-27 18:25:00	2016-09-27 19:10:00	\N	\N	4	0	\N	\N
121069	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2016-09-29 08:40:00	2016-09-29 10:15:00	2018-05-18 15:22:13	2018-05-18 15:22:20	25	0	\N	\N
122712	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Transmission  et reprise d'entreprises	Audition Transmission et reprise d'entreprises	2016-10-25 17:30:00	2016-10-25 18:30:00	\N	\N	2	0	\N	\N
122737	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2016-10-05 09:30:00	2016-10-05 11:00:00	2018-05-18 15:23:31	2018-05-18 15:24:04	30	0	\N	\N
122782	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	Etat d'urgence	Comité de suivi de l'état d'urgence	2016-10-04 15:00:00	2016-10-04 16:00:00	\N	\N	2	0	\N	\N
122915	DELEGATION	DEPLACEMENT	\N	\N	DSOM	RI Foncier outre-mer - Déplacement Mayotte	RI Foncier outre-mer - Déplacement Mayotte	2015-10-04 10:00:00	2015-10-08 00:00:00	\N	\N	4	0	\N	\N
122971	COM_PERMANENTE	AUTRE	\N	FINC	\N	RI FEI - RI Villa Médicis - Auditions Prélèvement à la source	RI FEI - RI Villa Médicis - Auditions Prélèvement à la source	2016-10-05 09:00:00	2016-10-05 11:55:00	2018-05-18 15:22:41	2018-05-18 15:22:48	37	0	\N	\N
123761	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2017 - Equilibres financiers	PLFSS 2017 -Equilibres financiers	2016-10-04 15:00:00	2016-10-04 16:00:00	\N	\N	3	0	\N	\N
123769	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2017 - Assurance maladie	PLFSS 2017 - Assurance maladie	2016-10-27 11:30:00	2016-10-27 12:30:00	\N	\N	1	0	\N	\N
123771	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2017 - Assurance maladie	PLFSS 2017 - Assurance maladie	2016-10-27 14:00:00	2016-10-27 15:00:00	\N	\N	1	0	\N	\N
123773	DELEGATION	DEPLACEMENT	\N	\N	206	Déplacement à Vienne pour la conférence organisée par l'EPTA	\N	2016-10-20 11:00:00	2016-10-21 20:00:00	\N	\N	1	0	\N	\N
123788	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	\N	\N	2016-10-05 14:05:00	2016-10-05 16:30:00	\N	\N	0	0	\N	\N
123793	DELEGATION	AUDRAP	\N	\N	206	M. Yann LeCun	Audition de Y. LeCun, directeur de recherche en intelligence artificielle chez Facebook	2016-10-06 10:00:00	2016-10-06 12:00:00	\N	\N	1	0	\N	\N
124015	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2017	\N	2016-10-04 15:30:00	2016-10-04 16:15:00	\N	\N	1	0	\N	\N
124017	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2017	\N	2016-10-05 14:45:00	2016-10-05 15:30:00	\N	\N	0	0	\N	\N
124096	MISSION	PLEIN_NON_JO	\N	BREXIT	\N	\N	\N	2016-10-05 14:05:00	2016-10-05 16:30:00	2016-10-07 17:41:30	\N	18	0	\N	\N
124155	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Égalité et citoyenneté	PJL Égalité et citoyenneté	2016-10-11 14:30:00	2016-10-11 19:00:00	\N	\N	169	0	\N	\N
124156	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Égalité et citoyenneté	PJL Égalité et citoyenneté	2016-10-11 21:30:00	2016-10-12 00:00:00	\N	\N	80	0	\N	\N
124157	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Égalité et citoyenneté	PJL Égalité et citoyenneté	2016-10-12 14:30:00	2016-10-12 18:25:00	\N	\N	136	0	\N	\N
124158	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Égalité et citoyenneté	PJL Égalité et citoyenneté	2016-10-12 21:30:00	2016-10-13 01:00:00	\N	\N	80	0	\N	\N
124776	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Transmission  et reprise d'entreprises	\N	2016-10-19 14:00:00	2016-10-19 14:45:00	\N	\N	2	0	\N	\N
124779	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Transmission  et reprise d'entreprises	\N	2016-10-19 18:00:00	2016-10-19 19:00:00	\N	\N	2	0	\N	\N
124783	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Transmission  et reprise d'entreprises	\N	2016-10-26 18:00:00	2016-10-26 19:00:00	\N	\N	2	0	\N	\N
124802	DELEGATION	DEPLACEMENT	\N	\N	ENTREPRISES	Déplacement Bruxelles - Simplification du droit	\N	2016-10-20 07:30:00	2016-10-20 19:30:00	\N	\N	6	0	\N	\N
124849	DELEGATION	AUDRAP	\N	\N	206	Plan national de gestion des matières et des déchets radioactifs (PNGMDR)	\N	2016-09-27 17:00:00	2016-09-27 18:30:00	\N	\N	2	0	\N	\N
124851	DELEGATION	AUDRAP	\N	\N	206	Plan national de gestion des matières et des déchets radioactifs (PNGMDR)	\N	2016-10-04 17:00:00	2016-10-04 19:30:00	\N	\N	2	0	\N	\N
124855	DELEGATION	AUDRAP	\N	\N	206	Plan national de gestion des matières et des déchets radioactifs (PNGMDR)	\N	2016-10-18 18:30:00	2016-10-18 19:30:00	\N	\N	2	0	\N	\N
125536	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Rapport Mission d'information SDIS	\N	2016-10-12 10:25:00	2016-10-12 11:30:00	2018-05-18 15:26:20	2018-05-18 15:26:24	43	0	\N	\N
125680	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Ecologie, développement et mobilité durables	PLF pour 2017 - Ecologie, développement et mobilité durables - Audition Président du Syndicat des énergies renouvelables	2016-10-12 14:30:00	2016-10-12 15:30:00	\N	\N	1	0	\N	\N
125749	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Ecologie, développement et mobilité durables 	PLF pour 2017 - Ecologie, développement et mobilité durables - Audition directeur général CEREMA	2016-10-12 18:30:00	2016-10-12 19:30:00	\N	\N	1	0	\N	\N
125874	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2016-10-12 17:05:00	2016-10-12 19:00:00	2016-10-13 10:04:50	2016-10-13 10:59:37	31	0	\N	\N
125939	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2016-10-12 16:30:00	2016-10-12 18:10:00	2016-10-13 11:45:55	2016-10-13 15:27:09	33	0	\N	\N
125998	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Entreprises donneuses d'ordre	PPL Entreprises donneuses d'ordre	2016-10-13 10:30:00	2016-10-13 12:45:00	\N	\N	69	0	\N	\N
125999	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2016-10-13 15:05:00	2016-10-13 16:00:00	\N	\N	227	0	\N	\N
120021	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Création de l'Agence nationale de santé publique	\N	2016-10-04 14:30:00	2016-10-04 16:30:00	\N	\N	1	0	\N	\N
120023	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2017 - Solidarité	PLF pour 2017 - Solidarité	2016-10-12 16:00:00	2016-10-12 17:00:00	\N	\N	3	0	\N	\N
120864	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2016-09-28 14:05:00	2016-09-28 15:25:00	2018-05-18 15:19:25	2018-05-18 15:19:28	26	0	\N	\N
125022	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2016-10-12 09:30:00	2016-10-12 12:15:00	2016-10-12 14:49:27	2016-10-12 15:08:55	46	0	\N	\N
125253	COM_PERMANENTE	AUTRE	\N	CDD	\N	Usage des drones civils	PPL relative au renforcement de la sécurité de l'usage des drones civils	2016-10-12 11:15:00	2016-10-12 11:20:00	2016-10-13 10:00:28	2016-10-13 10:59:40	26	0	\N	\N
121318	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Audition Deutsche Bank AG	2016-09-27 15:15:00	2016-09-27 16:15:00	\N	\N	1	0	\N	\N
121365	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFSS pour 2017	PLFSS pour 2017 - Audition Philip Morris	2016-09-27 16:00:00	2016-09-27 16:45:00	\N	\N	1	0	\N	\N
121396	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat de Test	Débat	2014-01-01 08:00:00	2014-01-01 10:00:00	\N	\N	0	0	\N	\N
121634	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Transport 3P	PPL Transport 3P	2016-09-27 08:00:00	2016-09-27 08:30:00	\N	\N	1	0	\N	\N
121636	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Transport 3P	PPL Transport 3P	2016-09-29 10:00:00	2016-09-29 10:45:00	\N	\N	1	0	\N	\N
121643	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Transport 3P	PPL Transport 3P	2016-09-29 11:30:00	2016-09-29 13:10:00	\N	\N	1	0	\N	\N
121692	ETUDES	AUCUNE	\N	\N	\N	\N	\N	2014-10-01 08:00:00	2014-10-01 12:00:00	\N	\N	0	0	\N	907
121755	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2017 Vieillesse	PLFSS pour 2017 Assurance Vieillesse - C3P	2016-09-28 15:00:00	2016-09-28 16:00:00	\N	\N	1	0	\N	\N
121757	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2017 Vieillesse	PLFSS pour 2017 Assurance vieillesse - C3P	2016-09-28 16:00:00	2016-09-28 17:00:00	\N	\N	1	0	\N	\N
121759	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2017 Vieillesse	PLFSS pour 2017 Assurance vieillesse - C3P	2016-09-28 17:00:00	2016-09-28 18:00:00	\N	\N	1	0	\N	\N
121761	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2017 Vieillesse	PLFSS pour 2017 Assurance vieillesse - C3P	2016-09-28 18:00:00	2016-09-28 19:00:00	\N	\N	1	0	\N	\N
121763	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2017 Vieillesse	PLFSS pour 2017 Assurance vieillesse - C3P	2016-09-29 09:00:00	2016-09-29 10:00:00	\N	\N	1	0	\N	\N
121765	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2017 Vieillesse	PLFSS pour 2017 Assurance vieillesse - C3P	2016-09-29 10:00:00	2016-09-29 11:00:00	\N	\N	1	0	\N	\N
121767	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2017 Vieillesse	PLFSS pour 2017 Assurance vieillesse - C3P	2016-09-29 11:00:00	2016-09-29 12:00:00	\N	\N	1	0	\N	\N
121769	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2017 Médico-social	PLFSS pour 2017 Secteur Médico-social	2016-10-04 14:00:00	2016-10-04 15:00:00	\N	\N	1	0	\N	\N
121771	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2017 Médico-social	PLFSS pour 2017 Secteur Médico-social	2016-10-04 15:00:00	2016-10-04 16:00:00	\N	\N	1	0	\N	\N
121773	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2017 Médico-social	PLFSS pour 2017 Secteur Médico-social	2016-10-04 16:00:00	2016-10-04 16:45:00	\N	\N	1	0	\N	\N
122012	DELEGATION	DEPLACEMENT	\N	\N	DSOM	RI Foncier outre-mer : Déplacement dans les collectivités du Pacifique	Déplacement Polynésie, Nouvelle-Calédonie, Wallis-et-Futuna	2016-02-24 10:00:00	2016-03-14 10:00:00	\N	\N	4	0	\N	\N
122693	COM_EURO	AUDRAP	\N	AFEU	\N	Plan d'investissement pour l'Europe	Bilan du plan d'investissement pour l'Europe	2016-10-04 17:45:00	2016-10-04 18:55:00	\N	\N	2	0	\N	\N
122713	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2017 Médico-social	PLFSS pour 2017 Secteur Médico-social	2016-10-12 15:00:00	2016-10-12 16:00:00	\N	\N	4	0	\N	\N
122715	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2017 Médico-social	PLFSS pour 2017 Secteur Médico-social	2016-10-13 09:00:00	2016-10-13 10:00:00	\N	\N	1	0	\N	\N
122717	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2017 Médico-social	PLFSS pour 2017 Secteur Médico-social	2016-10-13 10:00:00	2016-10-13 12:00:00	\N	\N	1	0	\N	\N
122719	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2017 Médico-social	PLFSS pour 2017 Secteur Médico-social	2016-10-18 15:00:00	2016-10-18 16:00:00	\N	\N	1	0	\N	\N
122721	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2017 Médico-social	PLFSS pour 2017 Secteur Médico-social	2016-10-19 14:30:00	2016-10-19 15:15:00	\N	\N	1	0	\N	\N
122723	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2017 Médico-social	PLFSS pour 2017 Secteur Médico-social	2016-10-19 15:15:00	2016-10-19 16:00:00	\N	\N	2	0	\N	\N
122725	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2017 Médico-social	PLFSS pour 2017 Secteur Médico-social	2016-10-25 16:45:00	2016-10-25 17:45:00	\N	\N	2	0	\N	\N
122727	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2017 Médico-social	PLFSS pour 2017 Secteur Médico-social	2016-10-25 17:45:00	2016-10-25 19:15:00	\N	\N	3	0	\N	\N
122729	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2017 Vieillesse	PLFSS pour 2017 Assurance vieillesse	2016-10-24 11:00:00	2016-10-24 12:00:00	\N	\N	1	0	\N	\N
122731	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2017 Vieillesse	PLFSS pour 2017 Assurance vieillesse	2016-10-18 10:00:00	2016-10-18 11:00:00	\N	\N	1	0	\N	\N
122733	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2017 Vieillesse	PLFSS pour 2017 Assurance vieillesse	2016-10-19 14:00:00	2016-10-19 15:00:00	\N	\N	1	0	\N	\N
122735	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2017 Vieillesse	PLFSS pour 2017 Assurance vieillesse	2016-10-19 15:00:00	2016-10-19 16:00:00	\N	\N	1	0	\N	\N
122972	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Action extérieure des collectivités territoriales et coopération de l'outre-mer	\N	2016-10-04 14:00:00	2016-10-04 14:30:00	\N	\N	1	0	\N	\N
122980	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Action extérieure des collectivités territoriales et coopération de l'outre-mer	\N	2016-10-04 17:45:00	2016-10-04 18:15:00	\N	\N	1	0	\N	\N
123126	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle FACE 2016	Contrôle sur la gestion et l'utilisation des aides aux collectivités pour l'électrification rurale	2016-10-04 14:00:00	2016-10-04 16:00:00	\N	\N	1	0	\N	\N
123520	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	COM France Télévisions	COM 2016-2020 de France Télévisions	2016-10-05 11:00:00	2016-10-05 12:15:00	\N	\N	1	0	\N	\N
123522	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	COM France Télévisions	COM 2016-2020 de France Télévisions	2016-10-05 17:30:00	2016-10-05 19:30:00	\N	\N	1	0	\N	\N
123524	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	COM France Télévisions	COM 2016-2020 de France Télévisions	2016-10-06 10:30:00	2016-10-06 12:30:00	\N	\N	1	0	\N	\N
123526	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Éthique, régulation et transparence du sport professionnel	PPL Éthique, régulation et transparence du sport professionnel	2016-10-05 09:00:00	2016-10-05 10:00:00	\N	\N	4	0	\N	\N
123531	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Éthique, régulation et transparence du sport professionnel	PPL Éthique, régulation et transparence du sport professionnel	2016-10-05 15:00:00	2016-10-05 16:00:00	\N	\N	6	0	\N	\N
123694	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2017	Audition rapporteur - PLFSS 2017 - Famille	2016-10-04 14:00:00	2016-10-04 15:00:00	\N	\N	4	0	\N	\N
123866	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle justice 2016 - AGRASC	Contrôle justice 2016 - AGRASC - Audition DGGN	2016-10-04 10:00:00	2016-10-04 11:00:00	\N	\N	1	0	\N	\N
123868	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle justice 2016 - AGRASC	Contrôle justice 2016 - AGRASC - Audition Caisse des dépôts	2016-10-04 18:00:00	2016-10-04 18:45:00	\N	\N	1	0	\N	\N
123870	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017  - Justice	PLF pour 2017  - Justice - Barreau de Paris	2016-10-04 14:30:00	2016-10-04 15:30:00	\N	\N	1	0	\N	\N
123872	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017  - Justice	PLF pour 2017  - Justice - Bouygues Entreprises France Europe	2016-10-04 15:30:00	2016-10-04 16:30:00	\N	\N	1	0	\N	\N
124520	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Recomposition de la carte intercommunale	\N	2016-10-11 10:00:00	2016-10-11 11:45:00	\N	\N	1	0	\N	\N
123874	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Justice - Déplacement	PLF pour 2017 - Justice - Déplacement EPPJP	2016-10-05 15:30:00	2016-10-05 17:30:00	\N	\N	1	0	\N	\N
123879	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017  - Justice	PLF pour 2017 - Justice - FGTI 	2016-10-05 18:00:00	2016-10-05 19:00:00	\N	\N	1	0	\N	\N
123942	DELEGATION	AUCUNE	\N	\N	COLTER	RI prévention radicalisation : audition Mme Domenach - SG-CIPDR	\N	2016-10-13 09:00:00	2016-10-13 10:30:00	2016-10-13 14:58:01	2016-10-13 15:28:00	17	0	\N	\N
124020	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Sécurité 2016  - SAIP	Contrôle Sécurité 2016  - SAIP - Fédération nationale des sapeurs-pompiers de France	2016-10-05 14:30:00	2016-10-05 15:30:00	\N	\N	1	0	\N	\N
124022	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Immigration 2016 - Places en CADA	Contrôle Immigration 2016 - Places en CADA - DRIHL	2016-10-07 10:00:00	2016-10-07 11:00:00	\N	\N	1	0	\N	\N
124036	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Médias	PLF pour 2017 - Médias - Audition de la DGMIC	2016-10-05 11:30:00	2016-10-05 12:05:00	\N	\N	1	0	\N	\N
119172	COM_SPECIALE	AUDRAP	\N	EGALITE	\N	Aud. Rapp. CS Egalité et citoyenneté DES	Audition Rapporteur CS Egalité et citoyenneté DES	2016-08-30 09:30:00	2016-08-30 10:00:00	\N	\N	1	0	\N	\N
119252	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud. Rapp. ETRD 	Audition Rapporteur ETRD 	2016-09-07 15:00:00	2016-09-07 17:00:00	\N	\N	2	0	\N	\N
119292	COM_SPECIALE	PLENIERE	\N	EGALITE	\N	CS Egalité et citoyenneté 	CS Egalité et citoyenneté 	2016-09-13 09:30:00	2016-09-13 13:00:00	2016-09-13 20:44:51	2016-09-14 16:58:02	25	0	\N	\N
119372	COM_SPECIALE	PLENIERE	\N	EGALITE	\N	CS Egalité et citoyenneté 	CS Egalité et citoyenneté 	2016-09-13 14:35:00	2016-09-13 19:30:00	2016-09-14 14:35:40	2016-09-14 16:58:03	25	0	\N	\N
119409	COM_SPECIALE	PLENIERE	\N	EGALITE	\N	CS Egalité et citoyenneté 	CS Egalité et citoyenneté 	2016-09-13 21:00:00	2016-09-13 23:35:00	2016-09-14 14:36:00	2016-09-14 16:58:04	22	0	\N	\N
119446	COM_SPECIALE	PLENIERE	\N	EGALITE	\N	CS Egalité et citoyenneté 	CS Egalité et citoyenneté 	2016-09-14 09:00:00	2016-09-14 11:15:00	2016-09-14 13:02:08	2016-09-14 16:58:07	23	0	\N	\N
119517	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	FINC 	FINC 	2016-09-14 09:30:00	2016-09-14 13:00:00	\N	\N	1	0	\N	\N
119519	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	contrôle DINSIC	2016-09-14 14:30:00	2016-09-14 15:30:00	\N	\N	1	0	\N	\N
119521	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	contrôle DINSIC	2016-09-14 15:30:00	2016-09-14 16:30:00	\N	\N	1	0	\N	\N
119523	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	contrôle DINSIC	2016-09-14 16:30:00	2016-09-14 17:30:00	\N	\N	1	0	\N	\N
119525	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	contrôle DINSIC	2016-09-14 17:30:00	2016-09-14 18:20:00	\N	\N	1	0	\N	\N
119527	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	contrôle DINSIC	2016-09-14 18:20:00	2016-09-14 19:15:00	\N	\N	1	0	\N	\N
119529	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	FINC 	PLF 2017	2016-09-13 07:30:00	2016-09-13 18:30:00	\N	\N	2	0	\N	\N
119579	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Contrôle	Audition Rapporteur FINC 	2016-09-13 14:30:00	2016-09-13 17:15:00	\N	\N	1	0	\N	\N
119581	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC - Contrôle	Audition Rapporteur FINC 	2016-09-14 09:00:00	2016-09-14 11:30:00	\N	\N	1	0	\N	\N
119846	MISSION	AUCUNE	\N	REVENU	\N	MI Revenu de base en France 	MI Revenu de base en France 	2016-09-21 14:05:00	2016-09-21 15:30:00	2016-09-22 17:49:24	2016-09-22 17:50:00	10	0	\N	\N
119863	MISSION	AUCUNE	\N	REVENU	\N	MI Revenu de base en France 	MI Revenu de base en France 	2016-09-22 10:40:00	2016-09-22 12:30:00	2016-09-23 10:34:57	2016-09-23 11:52:00	3	0	\N	\N
119890	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle HU	2016-09-21 14:30:00	2016-09-21 15:25:00	\N	\N	1	0	\N	\N
119892	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	FINC 	Contrôle HU	2016-09-22 09:30:00	2016-09-22 12:00:00	\N	\N	1	0	\N	\N
119894	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	FINC 	Contrôle HU	2016-09-22 17:00:00	2016-09-22 18:00:00	\N	\N	1	0	\N	\N
119906	GIA	AUCUNE	\N	\N	\N	GIA Pakistan	Groupe interparlementaire Pakistan	2016-09-27 13:00:00	2016-09-27 14:30:00	\N	\N	1	0	619	\N
119908	GIA	AUCUNE	\N	\N	\N	GIA Pakistan	Groupe interparlementaire Pakistan	2016-09-28 15:00:00	2016-09-28 16:00:00	\N	\N	1	0	619	\N
119916	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-09-22 09:30:00	2016-09-22 18:00:00	\N	\N	4	0	\N	\N
119921	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	LOIS 	LOIS 	2016-09-20 09:00:00	2016-09-20 18:45:00	\N	\N	1	0	\N	\N
119923	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2017 -Equilibres financiers	PLFSS 2017 -Equilibres financiers	2016-10-04 14:00:00	2016-10-04 15:00:00	\N	\N	4	0	\N	\N
119928	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2017 - Equilibres financiers et Assurance maladie	PLFSS pour 2017 - Equilibres financiers et Assurance maladie	2016-10-13 09:00:00	2016-10-13 13:00:00	\N	\N	5	0	\N	\N
119972	COM_SPECIALE	AUDRAP	\N	EGALITE	\N	Aud. Rapp. CS Egalité et citoyenneté 	Audition Rapporteur CS Egalité et citoyenneté 	2016-09-21 14:00:00	2016-09-21 14:50:00	\N	\N	1	0	\N	\N
120563	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2016-09-28 10:00:00	2016-09-28 11:40:00	2016-09-28 18:20:36	2016-09-29 14:30:22	36	0	\N	\N
120992	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2016-09-28 16:35:00	2016-09-28 18:55:00	2018-05-18 15:21:54	2018-05-18 15:21:59	32	0	\N	\N
121156	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au Gouvernement	Questions d'actualité au Gouvernement	2016-10-04 16:45:00	2016-10-04 17:40:00	\N	\N	301	0	\N	\N
121157	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Égalité et citoyenneté	PJL Égalité et citoyenneté	2016-10-04 14:35:00	2016-10-04 16:35:00	\N	\N	186	0	\N	\N
121159	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Égalité et citoyenneté	PJL Égalité et citoyenneté	2016-10-04 17:50:00	2016-10-04 20:00:00	\N	\N	110	0	\N	\N
121160	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Égalité et citoyenneté	PJL Égalité et citoyenneté	2016-10-04 21:35:00	2016-10-05 00:00:00	\N	\N	72	0	\N	\N
121250	MISSION	AUDRAP	\N	REVENU	\N	Aud. Rapp. MI Revenu de base en France 	Audition Rapporteur MI Revenu de base en France 	2016-09-28 14:15:00	2016-09-28 16:50:00	\N	\N	8	0	\N	\N
121259	MISSION	AUCUNE	\N	REVENU	\N	MI Revenu de base en France 	MI Revenu de base en France 	2016-09-28 16:50:00	2016-09-28 19:50:00	2016-09-29 12:09:54	2016-09-29 14:44:07	12	0	\N	\N
121970	COM_ENQUETE	PLENIERE	\N	CHOMAGE	\N	CE Chômage	\N	2016-10-04 08:00:00	2016-10-04 09:30:00	2016-10-04 15:52:52	2016-10-04 16:35:47	9	0	\N	\N
123078	GIA	AUCUNE	\N	\N	\N	\N	Déjeuner de travail avec la nouvelle ambassadrice de France en Slovénie	2016-10-05 12:30:00	2016-10-05 14:00:00	\N	\N	10	0	529	\N
123251	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF 2017	\N	2016-09-28 14:30:00	2016-09-28 15:45:00	\N	\N	2	0	\N	\N
123254	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF 2017	\N	2016-09-27 16:00:00	2016-09-27 17:00:00	\N	\N	2	0	\N	\N
123540	DELEGATION	AUCUNE	\N	\N	211	Echanges de vue - Femmes et laïcité	Echanges de vue - Femmes et laïcité	2016-10-06 08:30:00	2016-10-06 10:00:00	2016-10-06 11:48:20	2016-10-06 17:01:01	8	0	\N	\N
123559	COM_EURO	CONTROLE	\N	AFEU	\N	\N	\N	2016-10-06 09:30:00	2016-10-06 10:30:00	2016-10-06 11:57:30	2016-10-06 17:01:32	11	0	\N	\N
125517	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Simplification du droit pour les entreprises	\N	2016-11-02 19:00:00	2016-11-02 20:45:00	\N	\N	5	0	\N	\N
123720	COM_PERMANENTE	AUTRE	\N	CDD	\N	Audition de M. Alain Vidalies	Audition de M. Alain Vidalies, sectétaire d'État chargé des transports, de la mer et de la pêche	2016-10-05 16:30:00	2016-10-05 18:20:00	2016-10-06 15:45:07	2016-10-06 16:54:33	21	0	\N	\N
124049	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI redressement de la justice	\N	2016-10-06 14:30:00	2016-10-06 15:30:00	\N	\N	2	0	\N	\N
124052	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFSS pour 2017	PLFSS pour 2017 - CNAM	2016-10-05 15:00:00	2016-10-05 16:30:00	\N	\N	1	0	\N	\N
124133	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Drones	\N	2016-10-04 18:00:00	2016-10-04 19:00:00	\N	\N	1	0	\N	\N
124135	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Stabilisation du droit de l'urbanisme	\N	2016-10-04 14:00:00	2016-10-04 16:45:00	\N	\N	1	0	\N	\N
124137	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Stabilisation du droit de l'urbanisme	\N	2016-10-04 18:00:00	2016-10-04 19:00:00	\N	\N	1	0	\N	\N
124189	GIA	AUCUNE	\N	\N	\N	déplacement	déplacement à Fidji et Tuvalu	2016-09-05 21:00:00	2016-09-17 14:00:00	\N	\N	4	0	651	\N
124433	GIA	AUCUNE	\N	\N	\N	Audition de Mme Pilar AROSEMENA DE ALEMÁN	Audition de Mme Pilar AROSEMENA DE ALEMÁN, ambassadrice du Panama, sur les avancées en matière de transparence fiscale	2016-10-11 13:30:00	2016-10-11 14:30:00	\N	\N	5	0	643	\N
124484	QUESTURE	AUCUNE	\N	\N	\N	Questure	\N	2016-10-11 14:30:00	2016-10-11 16:15:00	\N	\N	3	0	\N	\N
124526	GIA	AUCUNE	\N	\N	\N	Diner de travail à l'Ambassade d'Egypte	\N	2016-10-11 20:00:00	2016-10-11 22:30:00	\N	\N	5	0	617	\N
124532	GIA	AUCUNE	\N	\N	\N	Réunion de travail 	Préparation du Forum sur l'Eau à Amman	2016-10-11 15:00:00	2016-10-11 16:00:00	\N	\N	2	0	659	\N
124782	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de Matthias Fekl	\N	2016-10-11 19:05:00	2016-10-11 20:35:00	2016-11-07 10:44:08	2016-11-07 10:44:10	62	0	\N	\N
124816	COM_PERMANENTE	AUDRAP	\N	CDD	\N	 Transport 3P	Au. Rapp. CDD Transport 3P	2016-10-11 14:00:00	2016-10-11 15:45:00	\N	\N	1	0	\N	\N
124853	GIA	AUCUNE	\N	\N	\N	entretien avec personnalités kurdes	\N	2016-10-12 15:30:00	2016-10-12 16:30:00	\N	\N	1	0	615	\N
124886	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2016-10-12 09:05:00	2016-10-12 11:40:00	2016-10-12 14:37:27	2016-10-12 15:08:53	47	0	\N	\N
124944	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL "Sapin II"	Aud. Rapp.  PJL "Sapin II"	2016-10-12 17:00:00	2016-10-12 18:00:00	\N	\N	1	0	\N	\N
124946	COM_PERMANENTE	AUDRAP	\N	CAE	\N	 CAE - PJL Sapin II	Aud. Rapp. CAE - PJL Sapin II	2016-10-13 09:30:00	2016-10-13 12:00:00	\N	\N	1	0	\N	\N
125295	GIA	AUCUNE	\N	\N	\N	Déjeuner avec M. Kijowski, fondateur du KOD	\N	2016-10-11 13:00:00	2016-10-11 14:45:00	\N	\N	6	0	600	\N
125467	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2017 - Assurance maladie	PLFSS 2017 - Assurance maladie	2016-10-19 17:00:00	2016-10-19 18:00:00	\N	\N	1	0	\N	\N
125523	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition Compétitivité transport aérien - RI Sûreté Transport aérien	Audition Compétitivité transport aérien - RI Sûreté Transport aérien	2016-10-12 09:35:00	2016-10-12 12:55:00	2018-05-18 15:25:58	2018-05-18 15:26:02	46	0	\N	\N
119214	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF2017 - mission solidarité	PLF 2017 - mission solidarité	2016-09-13 11:00:00	2016-09-13 12:00:00	\N	\N	1	0	\N	\N
119220	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF2017 - mission solidarité	PLF 2017 - mission solidarité	2016-09-13 14:00:00	2016-09-13 16:00:00	\N	\N	1	0	\N	\N
119497	MISSION	AUCUNE	\N	TELEPHONE	\N	MI téléphones mobiles 	MI téléphones mobiles 	2016-09-14 14:00:00	2016-09-14 17:30:00	2016-09-15 12:03:32	2016-09-15 14:16:01	1	0	\N	\N
119840	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD  - PPL Transport 3¨P	Audition Rapporteur CDD 	2016-09-19 16:30:00	2016-09-19 19:30:00	\N	\N	1	0	\N	\N
119842	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD - PJL Transport 3D	Audition Rapporteur CDD 	2016-09-21 09:00:00	2016-09-21 12:30:00	\N	\N	1	0	\N	\N
119844	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD - PJL Transport 3P	Audition Rapporteur CDD 	2016-09-21 15:00:00	2016-09-21 18:30:00	\N	\N	1	0	\N	\N
120169	MISSION	AUCUNE	\N	TELEPHONE	\N	MI téléphones mobiles 	MI téléphones mobiles 	2016-09-27 15:00:00	2016-09-27 15:40:00	2016-09-27 16:33:25	2016-09-28 15:28:13	14	0	\N	\N
120186	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2016-09-27 14:35:00	2016-09-27 15:35:00	2018-05-18 15:17:57	2018-05-18 15:18:06	33	0	\N	\N
120191	QUESTURE	AUCUNE	\N	\N	\N	Questure	Réunion de Questure	2016-09-27 14:30:00	2016-09-27 16:40:00	\N	\N	3	0	\N	\N
120972	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD PPL Drones	Audition Rapporteur CDD PPL Drones 	2016-09-28 10:30:00	2016-09-28 11:30:00	\N	\N	1	0	\N	\N
120974	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD PPL Drones	Audition Rapporteur CDD PPL Drones	2016-09-28 16:30:00	2016-09-28 17:00:00	\N	\N	0	0	\N	\N
121730	GIA	AUCUNE	\N	\N	\N	\N	Déplacement à Chypre	2016-09-25 14:00:00	2016-09-29 18:00:00	\N	\N	2	0	585	\N
121734	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Transmission  et reprise d'entreprises	Transmission et reprise d'entreprises	2016-10-20 09:45:00	2016-10-20 10:30:00	\N	\N	2	0	\N	\N
121739	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Transmission  et reprise d'entreprises	RI Transmission et reprise d'entreprises	2016-10-20 09:00:00	2016-10-20 09:45:00	\N	\N	2	0	\N	\N
121742	GIA	AUCUNE	\N	\N	\N	visite ministérielle	visite de M Nick Smith, ministre de l'environnement de Nouvelle-Zélande	2016-09-30 14:00:00	2016-09-30 15:00:00	\N	\N	1	0	663	\N
121744	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Transmission  et reprise d'entreprises	Transmission et reprise d'entreprises	2016-10-20 10:30:00	2016-10-20 12:20:00	\N	\N	2	0	\N	\N
121778	GIA	AUCUNE	\N	\N	\N	Déjeuner Délégation japonaise	Déjeunera avec une délégation de sénatrices japonaises membres du GIA Japon-France	2016-09-21 12:00:00	2016-09-21 13:15:00	\N	\N	1	0	596	\N
123019	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2016-10-05 09:00:00	2016-10-05 12:40:00	2016-10-05 14:27:36	2016-10-05 15:14:04	42	0	\N	\N
123194	COM_EURO	AUDRAP	\N	AFEU	\N	Plan d'investissement pour l'Europe	Plan d'investissement pour l'Europe	2016-10-05 14:00:00	2016-10-05 15:00:00	\N	\N	1	0	\N	\N
124018	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017	PLF pour 2017 - Audition M. Antoine MONIN directeur du FNPCA	2016-10-04 11:30:00	2016-10-04 13:00:00	\N	\N	1	0	\N	\N
124276	COM_SPECIALE	PLENIERE	\N	EGALITE	\N	Égalité et citoyenneté	Commission spéciale PJL "Égalité et citoyenneté"	2016-10-11 13:30:00	2016-10-11 13:45:00	2016-10-12 10:40:57	2016-10-12 14:56:07	14	0	\N	\N
124993	COM_PERMANENTE	AUTRE	\N	LOIS	\N	4 PPL	\N	2016-10-12 09:05:00	2016-10-12 10:25:00	2018-05-18 15:25:24	2018-05-18 15:25:37	42	0	\N	\N
125519	DELEGATION	DEPLACEMENT	\N	\N	ENTREPRISES	Déplacement à La Haye - Simplification du droit	\N	2016-11-14 07:25:00	2016-11-14 20:35:00	\N	\N	5	0	\N	\N
125632	DELEGATION	AUCUNE	\N	\N	206	Audition publique, ouverte à la presse, suivi COP 21	\N	2016-11-24 14:30:00	2016-11-24 19:45:00	2016-11-28 15:14:02	2016-11-28 16:46:02	4	0	\N	\N
125634	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	206	Petit-déjeuner débat en coopération avec l'IHEST sur l'intelligence artificielle	\N	2016-11-24 08:30:00	2016-11-24 10:15:00	\N	\N	3	0	\N	\N
125635	DELEGATION	AUCUNE	\N	\N	206	Nomination des membres du Conseil scientifique de l'OPECST	\N	2016-11-29 18:10:00	2016-11-29 20:05:00	2016-11-30 11:01:49	2016-11-30 16:14:01	8	0	\N	\N
125636	DELEGATION	AUCUNE	\N	\N	206	Audition du centre scientifique et technique du bâtiment (CSTB)	\N	2016-12-13 18:10:00	2016-12-13 19:55:00	2016-12-14 14:54:46	2016-12-14 15:43:58	4	0	\N	\N
125637	DELEGATION	AUCUNE	\N	\N	206	Audition publique sur "L'évaluation de la stratégie nationale de la recherche"	\N	2016-12-08 14:00:00	2016-12-08 19:00:00	2016-12-09 11:44:24	2016-12-09 16:31:53	3	0	\N	\N
125652	MISSION	AUCUNE	\N	TURQUIE	\N	MCI UE Turquie	\N	2016-10-12 14:35:00	2016-10-12 16:20:00	2016-10-12 17:26:31	2016-10-12 17:50:26	16	0	\N	\N
125683	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2016-10-12 15:30:00	2016-10-12 17:30:00	2016-10-12 18:40:41	2016-10-13 10:59:38	19	0	\N	\N
125741	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	Etat d'urgence	Comité de suivi de l'état d'urgence	2016-10-12 14:00:00	2016-10-12 16:00:00	\N	\N	1	0	\N	\N
125744	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Ecologie, développement et mobilité durables 	PLF pour 2017 - Ecologie, développement et mobilité durables - Audition directeur général DGEC	2016-10-12 17:30:00	2016-10-12 18:30:00	\N	\N	1	0	\N	\N
125746	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Déradicalisation	Mission d'information déradicalisation	2016-10-12 14:30:00	2016-10-12 17:30:00	\N	\N	2	0	\N	\N
126002	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Prescription en matière pénale	PPL Prescription en matière pénale	2016-10-13 16:15:00	2016-10-13 18:10:00	\N	\N	46	0	\N	\N
126003	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Drones	PPL Drones	2016-10-13 18:10:00	2016-10-13 19:30:00	\N	\N	21	0	\N	\N
126004	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Égalité et citoyenneté	PJL Égalité et citoyenneté	2016-10-14 09:30:00	2016-10-14 13:00:00	\N	\N	33	0	\N	\N
126080	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Égalité et citoyenneté	PJL Égalité et citoyenneté	2016-10-14 14:30:00	2016-10-14 19:15:00	\N	\N	22	0	\N	\N
126135	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI redressement de la justice	\N	2016-10-12 15:00:00	2016-10-12 18:00:00	\N	\N	3	0	\N	\N
126160	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017  - Justice - Déplacement 	PLF pour 2017  - Justice - Déplacement maison d'arrêt d'Osny	2016-10-12 15:30:00	2016-10-12 17:30:00	\N	\N	1	0	\N	\N
126170	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Ecologie, développement et mobilité durables	PLF pour 2017 - Ecologie, développement et mobilité durables - Audition ADEME	2016-10-13 09:30:00	2016-10-13 10:30:00	\N	\N	1	0	\N	\N
126181	DELEGATION	AUDRAP	\N	\N	206	Plan national de gestion des matières et des déchets radioactifs (PNGMDR)	\N	2016-11-08 17:30:00	2016-11-08 19:00:00	\N	\N	1	0	\N	\N
126183	DELEGATION	AUDRAP	\N	\N	206	Plan national de gestion des matières et des déchets radioactifs (PNGMDR)	\N	2016-11-15 17:30:00	2016-11-15 19:00:00	\N	\N	1	0	\N	\N
126185	DELEGATION	AUDRAP	\N	\N	206	Plan national de gestion des matières et des déchets radioactifs (PNGMDR)	\N	2016-11-22 17:30:00	2016-11-22 19:00:00	\N	\N	2	0	\N	\N
126187	DELEGATION	AUDRAP	\N	\N	206	Plan national de gestion des matières et des déchets radioactifs (PNGMDR)	\N	2016-11-23 17:30:00	2016-11-23 19:30:00	\N	\N	2	0	\N	\N
126285	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Statut de Paris	\N	2016-10-12 15:00:00	2016-10-12 16:00:00	\N	\N	1	0	\N	\N
126287	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Statut de Paris	\N	2016-10-12 16:00:00	2016-10-12 17:00:00	\N	\N	1	0	\N	\N
119224	MISSION	AUCUNE	\N	TELEPHONE	\N	MI téléphones mobiles 	MI téléphones mobiles 	2016-09-09 10:20:00	2016-09-09 12:00:00	2016-09-09 16:37:53	2016-09-09 16:40:28	3	0	\N	\N
119255	MISSION	AUCUNE	\N	TELEPHONE	\N	MI téléphones mobiles 	MI téléphones mobiles 	2016-09-12 13:55:00	2016-09-12 16:35:00	2016-09-15 16:27:38	2016-09-15 16:56:04	3	0	\N	\N
119266	COM_SPECIALE	AUDRAP	\N	EGALITE	\N	Aud. Rapp. CS Egalité et citoyenneté 	Audition Rapporteur CS Egalité et citoyenneté 	2016-09-06 14:30:00	2016-09-06 18:35:00	\N	\N	1	0	\N	\N
119268	COM_SPECIALE	AUDRAP	\N	EGALITE	\N	Aud. Rapp. CS Egalité et citoyenneté 	Audition Rapporteur CS Egalité et citoyenneté 	2016-09-07 09:45:00	2016-09-07 12:30:00	\N	\N	2	0	\N	\N
119272	COM_SPECIALE	AUDRAP	\N	EGALITE	\N	Aud. Rapp. CS Egalité et citoyenneté 	Audition Rapporteur CS Egalité et citoyenneté 	2016-09-07 14:30:00	2016-09-07 18:30:00	\N	\N	1	0	\N	\N
119274	COM_SPECIALE	AUDRAP	\N	EGALITE	\N	Aud. Rapp. CS Egalité et citoyenneté 	Audition Rapporteur CS Egalité et citoyenneté 	2016-09-08 09:30:00	2016-09-08 10:30:00	\N	\N	1	0	\N	\N
119584	GIA	AUCUNE	\N	\N	\N	GIE Tibet	Groupe d'information Tibet	2016-09-14 08:00:00	2016-09-14 09:30:00	\N	\N	13	0	634	\N
119598	GIA	AUCUNE	\N	\N	\N	GIA Caraïbes	entretien avec M Juan Valdés, Comité central du Parti communiste de Cuba	2016-09-12 16:00:00	2016-09-12 17:00:00	\N	\N	1	0	642	\N
119632	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2016-09-21 10:00:00	2016-09-21 12:40:00	2018-05-18 15:17:11	2018-05-18 15:17:43	32	0	\N	\N
119783	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	FINC 	Contrôle AGRASC	2016-09-20 14:30:00	2016-09-20 16:55:00	\N	\N	1	0	\N	\N
119785	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle AGRASC	2016-09-20 17:15:00	2016-09-20 17:50:00	\N	\N	1	0	\N	\N
119787	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle AGRASC	2016-09-20 18:00:00	2016-09-20 18:50:00	\N	\N	1	0	\N	\N
119789	MISSION	AUCUNE	\N	TURQUIE	\N	MI Accord UE/Turquie 	MI Accord UE/Turquie 	2016-09-21 14:35:00	2016-09-21 16:40:00	2016-09-21 17:07:05	2016-09-22 15:27:29	5	0	\N	\N
119795	COM_ENQUETE	PLENIERE	\N	CHOMAGE	\N	commission d'enquête sur les chiffres du chômage 	commission d'enquête sur les chiffres du chômage 	2016-09-21 15:30:00	2016-09-21 17:05:00	2016-09-21 17:52:03	2016-09-22 15:27:30	10	0	\N	\N
119900	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Francophonie	Groupe de travail Francophonie	2016-09-20 15:00:00	2016-09-20 17:00:00	\N	\N	2	0	\N	\N
119903	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Francophonie	Groupe de travail Francophonie	2016-09-22 11:00:00	2016-09-22 12:00:00	\N	\N	2	0	\N	\N
119970	EXCUSES	AUTRE_NON_PLENIERE	\N	\N	\N	Autre (non plénière) 	Autre (non plénière) 	2016-09-29 00:00:00	2016-10-03 00:00:00	\N	\N	1	0	\N	\N
119992	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	Assemblée parlementaire de la Francophonie	Assemblée régionale Europe	2016-09-26 14:00:00	2016-09-29 15:00:00	\N	\N	1	0	\N	\N
120453	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-09-28 09:00:00	2016-09-28 09:40:00	2018-05-18 15:21:12	2018-05-18 15:21:18	29	1	\N	\N
120562	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	Réunion Commission	2016-09-28 09:35:00	2016-09-28 11:40:00	2018-05-18 15:18:18	2018-05-18 15:18:22	38	0	\N	\N
120874	DELEGATION	AUCUNE	\N	\N	206	Audition publique sur la formation des scientifiques et des ingénieurs	\N	2016-10-06 08:40:00	2016-10-06 13:20:00	2016-10-06 16:45:22	2016-10-06 17:01:02	1	0	\N	\N
121299	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Audition Rapporteur FINC 	2016-09-27 15:00:00	2016-09-27 16:15:00	\N	\N	1	0	\N	\N
121301	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Audition Rapporteur FINC 	2016-09-27 17:30:00	2016-09-27 18:45:00	\N	\N	2	0	\N	\N
121304	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Audition Rapporteur FINC 	2016-09-29 17:00:00	2016-09-29 18:00:00	\N	\N	1	0	\N	\N
121306	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Audition Rapporteur FINC 	2016-09-27 10:00:00	2016-09-27 11:00:00	\N	\N	1	0	\N	\N
121308	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	FINC 	Déplacement Palais de justice de Paris	2016-09-27 14:30:00	2016-09-27 16:30:00	\N	\N	1	0	\N	\N
121310	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Audition Rapporteur FINC 	2016-09-27 17:50:00	2016-09-27 18:45:00	\N	\N	1	0	\N	\N
121312	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	FINC -Audition rapporteur	FINC - Audition rapporteur	2016-09-29 10:00:00	2016-09-29 12:30:00	\N	\N	1	0	\N	\N
121314	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Audition Rapporteur FINC 	2016-09-26 11:40:00	2016-09-26 12:35:00	\N	\N	1	0	\N	\N
121316	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	FINC 	FINC 	2016-09-21 16:00:00	2016-09-21 18:00:00	\N	\N	1	0	\N	\N
121368	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Audition Rapporteur FINC 	2016-09-28 15:30:00	2016-09-28 16:30:00	\N	\N	1	0	\N	\N
121712	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Transmission  et reprise d'entreprises	\N	2016-10-05 14:30:00	2016-10-05 15:30:00	\N	\N	2	0	\N	\N
121715	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Transmission et reprise d'entreprises	\N	2016-10-06 09:00:00	2016-10-06 10:00:00	\N	\N	3	0	\N	\N
121718	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Transmission  et reprise d'entreprises	RI Transmission et reprise d'entreprises	2016-10-06 10:00:00	2016-10-06 11:00:00	\N	\N	3	0	\N	\N
121776	GIA	AUCUNE	\N	\N	\N	colloque	Colloque Jeux Olympiques Paralympiques et Grands événements sportifs	2016-09-30 14:00:00	2016-09-30 18:00:00	\N	\N	1	0	596	\N
121929	COM_SPECIALE	PLENIERE	\N	EGALITE	\N	Égalité et citoyenneté	Projet de loi "Égalité et citoyenneté"	2016-10-04 10:00:00	2016-10-04 10:50:00	2016-10-05 09:34:01	2016-10-05 15:30:49	21	0	\N	\N
122706	GIA	AUCUNE	\N	\N	\N	Réunion interne	Réunion interne	2016-10-05 08:30:00	2016-10-05 09:30:00	\N	\N	5	0	615	\N
122758	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	Assemblée des Français de l'Etranger	Session plénière	2016-10-03 10:00:00	2016-10-03 12:30:00	\N	\N	7	0	\N	\N
122875	COM_PERMANENTE	AUTRE	\N	CAE	\N	\N	\N	2016-10-05 09:40:00	2016-10-05 11:40:00	2018-05-18 15:24:40	2018-05-18 15:24:46	36	0	\N	\N
122920	QUESTURE	AUCUNE	\N	\N	\N	Rendez-vous OPS	Rendez-vous organisations professionnelles du personnel du Sénat	2016-10-04 18:00:00	2016-10-04 19:45:00	\N	\N	3	0	\N	\N
123436	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Égalité et citoyenneté	\N	2016-10-06 10:30:00	2016-10-06 12:55:00	\N	\N	61	0	\N	\N
123437	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Égalité et citoyenneté	PJL Égalité et citoyenneté	2016-10-06 14:30:00	2016-10-06 20:05:00	\N	\N	66	0	\N	\N
123438	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Égalité et citoyenneté	PJL Égalité et citoyenneté	2016-10-06 21:45:00	2016-10-07 00:30:00	\N	\N	30	0	\N	\N
123946	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF 2017	\N	2016-10-04 15:00:00	2016-10-04 16:20:00	\N	\N	2	0	\N	\N
123949	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF 2017	\N	2016-10-05 14:30:00	2016-10-05 16:00:00	\N	\N	2	0	\N	\N
123952	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Statut de Paris	\N	2016-10-05 14:30:00	2016-10-05 15:00:00	\N	\N	1	0	\N	\N
123954	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Statut de Paris	\N	2016-10-05 15:00:00	2016-10-05 15:30:00	\N	\N	1	0	\N	\N
123956	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Statut de Paris	\N	2016-10-05 16:30:00	2016-10-05 17:30:00	\N	\N	1	0	\N	\N
123958	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Statut de Paris	\N	2016-10-05 17:30:00	2016-10-05 18:00:00	\N	\N	1	0	\N	\N
123960	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Statut de Paris	Statut de Paris	2016-10-05 18:00:00	2016-10-05 18:30:00	\N	\N	1	0	\N	\N
123962	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Statut de Paris	Statut de Paris	2016-10-06 09:00:00	2016-10-06 10:00:00	\N	\N	1	0	\N	\N
123964	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Statut de Paris	Statut de Paris	2016-10-06 10:00:00	2016-10-06 11:00:00	\N	\N	1	0	\N	\N
123966	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Statut de Paris	\N	2016-10-06 11:00:00	2016-10-06 11:45:00	\N	\N	1	0	\N	\N
123968	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Statut de Paris	\N	2016-10-06 14:00:00	2016-10-06 15:15:00	\N	\N	1	0	\N	\N
124024	MISSION	PLEIN_NON_JO	\N	BREXIT	\N	\N	\N	2016-07-13 14:20:00	2016-07-13 15:00:00	2016-10-07 15:55:56	\N	16	0	\N	\N
125334	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de Matthias Fekl	Audition de Matthias Fekl	2016-10-11 19:05:00	2016-10-11 20:35:00	2018-05-18 15:25:01	2018-05-18 15:25:06	62	0	\N	\N
119212	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	FINC 	FINC 	2016-09-01 14:30:00	2016-09-01 16:00:00	\N	\N	1	0	\N	\N
119215	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	FINC 	FINC 	2016-09-02 11:45:00	2016-09-02 13:00:00	\N	\N	1	0	\N	\N
119218	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	FINC 	FINC 	2016-09-02 13:00:00	2016-09-02 14:30:00	\N	\N	1	0	\N	\N
119222	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	FINC 	FINC 	2016-09-02 14:30:00	2016-09-02 17:00:00	\N	\N	1	0	\N	\N
119834	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Aud. Rapp. SOCI 	Audition Rapporteur SOCI 	2016-09-28 09:15:00	2016-09-28 10:15:00	\N	\N	1	0	\N	\N
119836	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2017 - Equilibres financiers-Assurance vieillesse	PLFSS 2017 - Equilibres financiers-Assurance vieillesse	2016-10-05 14:30:00	2016-10-05 16:00:00	\N	\N	3	0	\N	\N
119872	QUESTURE	AUCUNE	\N	\N	\N	Questure	Réunion de Questure	2016-09-20 15:30:00	2016-09-20 16:30:00	\N	\N	2	0	\N	\N
119875	QUESTURE	AUCUNE	\N	\N	\N	Rendez-vous OPS	Rendez-vous avec les organisations professionnelles et syndicales	2016-09-21 08:30:00	2016-09-21 09:30:00	\N	\N	3	0	\N	\N
119879	MISSION	AUCUNE	\N	REVENU	\N	MI Revenu de base en France 	MI Revenu de base en France 	2016-09-22 14:05:00	2016-09-22 16:35:00	2016-09-23 14:06:52	2016-09-23 14:07:39	8	0	\N	\N
122832	COM_PERMANENTE	AUTRE	\N	CDD	\N	Usage des drones civils	Renforcement de la sécurité de l'usage des drones civils	2016-10-05 09:30:00	2016-10-05 10:10:00	2016-10-06 16:54:25	2016-10-06 17:02:22	32	0	\N	\N
122925	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Devoir de vigilance des sociétés mères et PPL Prescription en matière pénale	\N	2016-10-05 09:30:00	2016-10-05 11:45:00	2018-05-18 15:23:11	2018-05-18 15:23:17	43	0	\N	\N
119896	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Football	Gouvernance du football	2016-09-21 15:30:00	2016-09-21 17:30:00	\N	\N	3	0	\N	\N
120697	DELEGATION	AUCUNE	\N	\N	DSOM	RI Normes BTP outre-mer	Outre-mer 	2016-10-13 09:00:00	2016-10-13 11:30:00	2016-10-13 12:37:25	2016-10-13 15:28:01	6	0	\N	\N
120699	DELEGATION	AUCUNE	\N	\N	DSOM	PPRE Normes agricoles outre-mer	Outre-mer 	2016-10-20 09:30:00	2016-10-20 10:35:00	2016-10-20 15:15:30	2016-10-20 17:24:28	14	0	\N	\N
120701	DELEGATION	AUCUNE	\N	\N	DSOM	RI Foncier outre-mer	Outre-mer 	2016-10-27 09:30:00	2016-10-27 11:00:00	2016-10-27 14:22:21	2016-10-27 16:16:32	9	0	\N	\N
121028	COM_SPECIALE	PLENIERE	\N	EGALITE	\N	CS Egalité et citoyenneté 	CS Egalité et citoyenneté 	2016-09-28 15:00:00	2016-09-28 20:10:00	2016-09-29 16:56:58	2016-09-30 09:31:57	27	0	\N	\N
121095	DELEGATION	AUCUNE	\N	\N	211	Droits des femmes 	Droits des femmes 	2016-09-29 08:30:00	2016-09-29 10:00:00	2016-09-29 10:42:45	2016-09-29 14:36:57	10	0	\N	\N
121128	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-09-26 11:00:00	2016-09-26 12:00:00	\N	\N	1	0	\N	\N
121131	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-09-26 14:00:00	2016-09-26 16:30:00	\N	\N	1	0	\N	\N
121136	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Aud. Rapp. LOIS 	Audition Rapporteur LOIS 	2016-09-27 18:00:00	2016-09-27 18:30:00	\N	\N	1	0	\N	\N
121161	DELEGATION	AUCUNE	\N	\N	COLTER	Débat d'orientation - Simplification des normes	\N	2016-10-06 09:00:00	2016-10-06 10:45:00	2016-10-06 14:43:14	2016-10-06 17:01:03	14	0	\N	\N
121232	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2017 - Mission Ecologie	2016-09-27 15:30:00	2016-09-27 16:30:00	\N	\N	1	0	\N	\N
121234	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2017 - Mission Ecologie	2016-09-27 16:30:00	2016-09-27 17:30:00	\N	\N	1	0	\N	\N
121238	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2017 - Mission Ecologie	2016-09-28 15:30:00	2016-09-28 16:30:00	\N	\N	1	0	\N	\N
121240	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2017 - Mission Ecologie	2016-09-28 16:30:00	2016-09-28 17:30:00	\N	\N	1	0	\N	\N
121242	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	Contrôle Gestion et utilisation des aides aux collectivités pour l'électrification rurale	2016-09-29 08:30:00	2016-09-29 09:30:00	\N	\N	1	0	\N	\N
121244	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2017 - Mission Financement des aides à l'électrification rurale	2016-09-29 09:30:00	2016-09-29 10:30:00	\N	\N	1	0	\N	\N
121246	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Aud. Rapp. FINC 	PLF 2017 - Mission Ecologie	2016-09-29 10:30:00	2016-09-29 11:30:00	\N	\N	1	0	\N	\N
121320	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2016-09-29 10:45:00	2016-09-29 12:30:00	2016-09-29 15:36:38	2016-09-30 09:23:42	16	0	\N	\N
121552	QUESTURE	AUCUNE	\N	\N	\N	Rendez-vous OPS	Rendez-vous avec les organisations professionnelles et syndicales	2016-09-28 16:30:00	2016-09-28 19:00:00	\N	\N	3	0	\N	\N
121559	COM_EURO	CONTROLE	\N	AFEU	\N	\N	\N	2016-09-29 08:40:00	2016-09-29 10:15:00	2016-09-30 09:36:29	2016-09-30 09:59:42	23	0	\N	\N
121672	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Éthique, régulation et transparence du sport professionnel	PPL Sport professionnel	2016-09-30 10:00:00	2016-09-30 12:30:00	\N	\N	1	0	\N	\N
124026	COM_EURO	AUDRAP	\N	AFEU	\N	Audition directive SMA	Audition rapporteur - directive SMA	2016-10-04 14:40:00	2016-10-04 16:30:00	\N	\N	2	0	\N	\N
124046	COM_EURO	AUDRAP	\N	AFEU	\N	Audition directive SMA	Audition rapporteur - directive SMA	2016-10-05 16:30:00	2016-10-05 17:35:00	\N	\N	2	0	\N	\N
124054	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Transmission  et reprise d'entreprises	\N	2016-10-11 16:15:00	2016-10-11 17:25:00	\N	\N	2	0	\N	\N
124057	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	\N	\N	2016-10-13 08:30:00	2016-10-13 10:00:00	2016-10-14 14:23:15	2016-10-14 14:23:37	11	0	\N	\N
124076	MISSION	PLEIN_NON_JO	\N	BREXIT	\N	\N	\N	2016-09-27 16:15:00	2016-09-27 17:55:00	2016-10-07 17:16:03	\N	11	0	\N	\N
124088	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2017 Livre et industries culturelles	PLF 2017 Livre et industries culturelles	2016-10-06 16:00:00	2016-10-06 16:45:00	\N	\N	1	0	\N	\N
124090	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF pour 2017 - Livre et industries culturelles	PLF pour 2017 - Livre et industries culturelles	2016-10-11 14:00:00	2016-10-11 17:45:00	\N	\N	1	0	\N	\N
124092	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF pour 2017 - Livre et industries culturelles	PLF pour 2017 - Livre et industries culturelles	2016-10-12 14:45:00	2016-10-12 15:30:00	\N	\N	1	0	\N	\N
124094	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF pour 2017 - Livre et industries culturelles	PLF pour 2017 - Livre et industries culturelles	2016-10-18 16:00:00	2016-10-18 17:00:00	\N	\N	1	0	\N	\N
124455	DELEGATION	DEPLACEMENT	\N	\N	206	Déplacement en Allemagne dans le cadre du rapport  sur les biotechnologies	Auditions à Berlin et à Munich	2016-07-04 07:00:00	2016-07-06 23:00:00	\N	\N	2	0	\N	\N
124468	DELEGATION	DEPLACEMENT	\N	\N	206	Déplacement Brésil et Argentine dans le cadre du rapport sur les biotechnologies	Auditions à Rio de Janeiro et Sao Paulo au Brésil, puis Buenos Aires en Argentine	2016-09-26 22:00:00	2016-10-03 00:00:00	\N	\N	2	0	\N	\N
124475	DELEGATION	DEPLACEMENT	\N	\N	206	Mission à Londres dans le cadre du rapport sur les biotechnologies	\N	2016-05-23 06:00:00	2016-05-24 20:00:00	\N	\N	2	0	\N	\N
124478	DELEGATION	DEPLACEMENT	\N	\N	206	Mission aux Etats-Unis dans le cadre du rapport sur les biotechnologies	\N	2016-05-30 09:00:00	2016-06-06 20:00:00	\N	\N	2	0	\N	\N
124488	DELEGATION	AUDRAP	\N	\N	206	Biotechnologies	\N	2016-02-02 17:00:00	2016-02-02 18:30:00	\N	\N	1	0	\N	\N
124498	DELEGATION	AUDRAP	\N	\N	206	Biotechnologies	\N	2016-03-22 14:30:00	2016-03-22 16:00:00	\N	\N	1	0	\N	\N
124509	DELEGATION	DEPLACEMENT	\N	\N	206	Mission à Pech Rouge (INRA) dans le cadre du rapport biotechnologies	\N	2016-09-09 05:00:00	2016-09-09 20:00:00	\N	\N	2	0	\N	\N
124860	COM_EURO	CONTROLE	\N	AFEU	\N	Audition de Matthias Fekl	\N	2016-10-11 19:05:00	2016-10-11 20:35:00	2016-11-07 10:45:47	2016-11-07 10:45:52	62	0	\N	\N
124956	DELEGATION	AUCUNE	\N	\N	206	Audition sur le contrôle des équipements sous pression nucléaires	\N	2016-10-25 18:00:00	2016-10-25 20:35:00	2016-10-26 12:00:03	2016-10-26 12:26:06	12	0	\N	\N
124982	DELEGATION	AUDRAP	\N	\N	206	 Biotechnologies	\N	2016-03-23 11:00:00	2016-03-23 12:30:00	\N	\N	1	0	\N	\N
125473	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de Mme Isabelle de Silva	Audition de Mme Isabelle de Silva, candidate aux fonctions de présidente de l'Autorité de la concurrence 	2016-10-12 11:15:00	2016-10-12 12:30:00	2018-05-18 15:26:38	2018-05-18 15:26:43	28	0	\N	\N
132856	QUESTURE	AUCUNE	\N	\N	\N	Questure	\N	2016-10-27 11:55:00	2016-10-27 12:20:00	\N	\N	3	0	\N	\N
125663	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - GFPRH - Déplacement	PLF pour 2017 - GFPRH - Entretien DGDDI	2016-10-11 08:30:00	2016-10-11 10:30:00	\N	\N	2	0	\N	\N
126846	GIA	AUCUNE	\N	\N	\N	Audition de Mme Mouchira KHATTAB	\N	2016-10-13 11:15:00	2016-10-13 12:15:00	\N	\N	7	0	617	\N
127004	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Transmission  et reprise d'entreprises	\N	2016-10-19 16:15:00	2016-10-19 17:00:00	\N	\N	2	0	\N	\N
127007	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Transmission  et reprise d'entreprises	\N	2016-10-19 17:00:00	2016-10-19 17:45:00	\N	\N	2	0	\N	\N
127063	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFSS pour 2017	PLFSS pour 2017 - Audition DSS	2016-10-13 16:45:00	2016-10-13 17:45:00	\N	\N	1	0	\N	\N
127065	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Sport, jeunesse et vie associative	PLF pour 2017 - Sport, jeunesse et vie associative - Audition directrice des sports	2016-10-10 16:00:00	2016-10-10 17:00:00	\N	\N	1	0	\N	\N
127138	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2017	\N	2016-10-11 15:00:00	2016-10-11 16:10:00	\N	\N	3	0	\N	\N
127142	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2017	\N	2016-10-12 14:30:00	2016-10-12 15:50:00	\N	\N	2	0	\N	\N
127172	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Recomposition de la carte intercommunale	\N	2016-10-13 09:00:00	2016-10-13 11:00:00	\N	\N	1	0	\N	\N
127174	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Recomposition de la carte intercommunale	\N	2016-10-13 14:00:00	2016-10-13 15:00:00	\N	\N	1	0	\N	\N
127391	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF pour 2017 - Médias,livre et industries culturelles	Crédits de la presse	2016-10-11 09:45:00	2016-10-11 11:15:00	\N	\N	1	0	\N	\N
127399	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF pour 2017 - Médias, livre et industries culturelles	Crédits de la presse	2016-10-18 09:45:00	2016-10-18 18:30:00	\N	\N	1	0	\N	\N
128998	DELEGATION	DEPLACEMENT	\N	\N	206	Visite de l'Institut du cerveau et de la moelle épinière (Hôpital de la Pitié-Salpêtrière)	\N	2016-12-15 09:00:00	2016-12-15 14:30:00	\N	\N	5	0	\N	\N
129202	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Statut de Paris	\N	2016-10-18 14:00:00	2016-10-18 15:15:00	\N	\N	1	0	\N	\N
129205	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Statut de Paris	\N	2016-10-18 15:15:00	2016-10-18 16:30:00	\N	\N	1	0	\N	\N
130172	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2017 - Famille	\N	2016-10-20 15:00:00	2016-10-20 17:00:00	\N	\N	2	0	\N	\N
130231	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Recherche et Enseignement supérieur	PLF pour 2017 - MIRES - Conférence des grandes écoles	2016-10-18 16:00:00	2016-10-18 16:50:00	\N	\N	1	0	\N	\N
130236	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Egalité des territoires et Logement	PLF pour 2017 - Egalité des territoires et Logement - FNAP	2016-10-19 14:45:00	2016-10-19 15:45:00	\N	\N	1	0	\N	\N
130239	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Egalité des territoires et Logement	PLF pour 2017 - Egalité des territoires et Logement - Caisse des dépôts	2016-10-20 09:30:00	2016-10-20 10:30:00	\N	\N	1	0	\N	\N
130244	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Egalité des territoires et Logement	PLF pour 2017 - Egalité des territoires et Logement - Action Logement - Fondation Abbé Pierre et Anah	2016-10-20 14:30:00	2016-10-20 17:30:00	\N	\N	1	0	\N	\N
130247	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Politique de la Ville	PLF pour 2017 - Politique de la ville - Action Logement	2016-10-20 14:30:00	2016-10-20 15:15:00	\N	\N	1	0	\N	\N
130273	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Sécurités	PLF pour 2017 - Sécurités - Table ronde Gendarmerie	2016-10-21 14:30:00	2016-10-21 16:35:00	\N	\N	1	0	\N	\N
130480	DELEGATION	AUCUNE	\N	\N	PROS	Le phénomène urbain : un atout pour le futur	Le phénomène urbain : un atout pour le futur	2016-10-21 09:00:00	2016-10-21 13:55:00	2016-10-25 17:10:52	2016-10-25 17:28:23	3	0	\N	\N
130520	DELEGATION	AUCUNE	\N	\N	PROS	Le phénomène urbain : un atout pour le futur	Le phénomène urbain : un atout pour le futur	2016-10-21 14:45:00	2016-10-21 18:00:00	2016-10-25 17:12:27	2016-10-25 17:28:22	3	0	\N	\N
130621	DELEGATION	AUCUNE	\N	\N	PROS	Le phénomène urbain : un atout pour le futur	Le phénomène urbain : un atout pour le futur	2016-10-22 09:00:00	2016-10-22 13:15:00	2016-10-25 17:16:22	2016-10-25 17:28:21	1	0	\N	\N
131021	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF pour 2017 - Recherche et enseignement supérieur	Recherche	2016-10-19 14:00:00	2016-10-19 18:00:00	\N	\N	1	0	\N	\N
131023	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF pour 2017 - Recherche et enseignement supérieur	Recherche	2016-10-20 10:00:00	2016-10-20 14:30:00	\N	\N	1	0	\N	\N
131074	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2016-10-26 09:45:00	2016-10-26 12:45:00	2016-10-26 14:46:31	2016-10-26 15:02:00	39	0	\N	\N
131631	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2017 - Conseil et contrôle de l'Etat	\N	2016-10-25 14:30:00	2016-10-25 15:45:00	\N	\N	1	0	\N	\N
131635	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2017 - Conseil et contrôle de l'Etat	\N	2016-10-26 15:00:00	2016-10-26 15:45:00	\N	\N	1	0	\N	\N
132835	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2017 - Avis protection des droits et libertés	\N	2016-10-27 14:00:00	2016-10-27 15:00:00	\N	\N	1	0	\N	\N
132837	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	PLF 2017 Avis protection des droits et libertés	\N	2016-10-27 16:10:00	2016-10-27 17:50:00	\N	\N	1	0	\N	\N
132854	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Recherche et Enseignement supérieur	PLF pour 2017 - Recherche et Enseignement supérieur -  CNOUS et Université Paris Saclay	2016-10-27 16:10:00	2016-10-27 18:00:00	\N	\N	1	0	\N	\N
132860	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL  Modernisation de la vie économique	PJL  Modernisation de la vie économique - Aliapur	2016-10-27 16:15:00	2016-10-27 17:15:00	\N	\N	1	0	\N	\N
133311	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2016-11-02 09:30:00	2016-11-02 11:10:00	2016-11-02 14:42:51	2016-11-02 17:16:30	39	0	\N	\N
133822	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF pour 2017 - Recherche et enseignement supérieur	PLF Recherche	2016-11-02 13:00:00	2016-11-02 14:30:00	\N	\N	1	0	\N	\N
134245	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF pour 2017 - Culture	Patrimoines	2016-11-02 10:00:00	2016-11-02 11:00:00	\N	\N	1	0	\N	\N
134247	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF pour 2017 - Culture	Patrimoines	2016-11-02 16:00:00	2016-11-02 16:45:00	\N	\N	1	0	\N	\N
134539	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Déradicalisation	Mission d'information déradicalisation	2016-11-02 16:00:00	2016-11-02 18:00:00	\N	\N	2	0	\N	\N
134587	GIA	AUCUNE	\N	\N	\N	Entretien avec Ministre des finanes et de l'Europe du Land de Sarre	Entretien avec M. Dtéphan Toscani	2016-11-02 13:00:00	2016-11-02 15:00:00	\N	\N	5	0	604	\N
134642	DELEGATION	AUCUNE	\N	\N	211	Audition de Mme Danielle Bousquet, présidente du HCE/FH	Audition de Mme Danielle Bousquet, présidente du HCE/FH	2016-11-03 08:30:00	2016-11-03 09:30:00	2016-11-03 11:57:25	2016-11-03 13:44:35	12	0	\N	\N
133024	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF pour 2017	PLF pour 2017	2016-10-27 09:15:00	2016-10-27 10:00:00	\N	\N	1	0	\N	\N
133132	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Modernisation de la vie économique + PPLO Lanceurs d'alerte	\N	2016-11-02 09:35:00	2016-11-02 10:30:00	2018-05-18 15:39:14	2018-05-18 15:39:22	30	0	\N	\N
134669	DELEGATION	AUCUNE	\N	\N	211	Examen du rapport Laïcité	Examen du rapport Laïcité	2016-11-03 09:30:00	2016-11-03 10:30:00	2016-11-03 12:02:28	2016-11-03 13:44:37	13	0	\N	\N
134702	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF pour 2017 - Culture	Patrimoines	2016-11-03 09:30:00	2016-11-03 11:45:00	\N	\N	1	0	\N	\N
135417	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2017	\N	2016-11-02 15:00:00	2016-11-02 16:15:00	\N	\N	2	0	\N	\N
135422	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF  pour 2017	\N	2016-11-03 10:15:00	2016-11-03 13:00:00	\N	\N	2	0	\N	\N
135530	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Relations avec les collectivités territoriales	PLF pour 2017 - Relations avec les collectivités territoriales - Audition Assemblée des communautés de France	2016-11-02 16:00:00	2016-11-02 17:50:00	\N	\N	2	0	\N	\N
135533	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Relations avec les collectivités territoriales	PLF pour 2017 - Relations avec les collectivités territoriales - Audition Cabinet Stratorial Finances	2016-11-02 10:30:00	2016-11-02 11:35:00	\N	\N	2	0	\N	\N
135536	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017	PLF pour 2017 - Rapport général - Audition AHTOP	2016-11-02 08:30:00	2016-11-02 09:30:00	\N	\N	1	0	\N	\N
135538	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF  pour 2017	\N	2016-11-03 16:30:00	2016-11-03 17:45:00	\N	\N	1	0	\N	\N
135540	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF  pour 2017	\N	2016-11-03 16:30:00	2016-11-03 18:45:00	\N	\N	1	0	\N	\N
135542	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	\N	\N	2016-11-02 17:00:00	2016-11-02 18:25:00	\N	\N	6	0	\N	\N
127055	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2017	\N	2016-10-12 15:30:00	2016-10-12 16:30:00	\N	\N	2	0	\N	\N
127096	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2017	\N	2016-10-11 14:30:00	2016-10-11 15:30:00	\N	\N	2	0	\N	\N
127099	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2017	\N	2016-10-11 14:30:00	2016-10-11 15:30:00	\N	\N	2	0	\N	\N
127102	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2017	\N	2016-10-12 14:30:00	2016-10-12 15:45:00	\N	\N	2	0	\N	\N
127145	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Sécurités	PLF pour 2017 - Sécurités - Gendarmerie nationale	2016-10-14 16:30:00	2016-10-14 17:30:00	\N	\N	1	0	\N	\N
129095	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2016-10-19 10:05:00	2016-10-19 11:15:00	2016-10-19 14:37:03	2016-10-19 16:45:43	37	0	\N	\N
129849	COM_PERMANENTE	AUTRE	\N	CDD	\N	Audition de M. Jean Pisani-Ferry	Audition de M. Jean Pisani-Ferry, Commissaire général de France Stratégie	2016-10-19 09:35:00	2016-10-19 11:15:00	2016-10-20 14:17:15	2016-10-20 15:00:01	31	0	\N	\N
129942	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de M. Edouard Balladur	Audition de M. Edouard Balladur, sur les négociations relatives au TTIP	2016-10-20 09:35:00	2016-10-20 10:45:00	2018-05-18 15:30:22	2018-05-18 15:30:27	20	0	\N	\N
130139	DELEGATION	AUCUNE	\N	\N	211	Examen du rapport d'information et des conclusions du rapport "Femmes et laïcité"	Examen du rapport d'information et des conclusions du rapport "Femmes et laïcité"	2016-10-20 08:30:00	2016-10-20 10:30:00	2016-10-20 16:34:30	2016-10-20 17:24:27	13	0	\N	\N
130251	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Déradicalisation	Mission d'information déradicalisation	2016-10-20 11:00:00	2016-10-20 12:00:00	\N	\N	1	0	\N	\N
130256	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Déradicalisation	Mission d'information déradicalisation	2016-10-20 15:00:00	2016-10-20 16:00:00	\N	\N	2	0	\N	\N
130292	GIA	AUCUNE	\N	\N	\N	Diner	Diner à l'ambassade du Maroc	2016-10-26 20:00:00	2016-10-26 22:15:00	\N	\N	19	0	598	\N
130293	GIA	AUCUNE	\N	\N	\N	Colloque	Colloque La femme en islam  : l'exemple marocain	2016-11-03 18:00:00	2016-11-03 20:00:00	\N	\N	2	0	598	\N
130356	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 	\N	2016-10-24 14:30:00	2016-10-25 16:30:00	\N	\N	2	0	\N	\N
130368	COM_PERMANENTE	AUTRE	\N	CAE	\N	PPL n° 770 Urbanisme et PJL n°866 Sapin II	PPL Stabilisation du droit de l'urbanisme et PJL Modernisation de la vie économique	2016-10-25 09:05:00	2016-10-25 09:50:00	2018-05-18 15:31:06	2018-05-18 15:31:37	20	0	\N	\N
130411	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2017 - Avis Justice judiciaire	\N	2016-10-25 09:30:00	2016-10-25 10:10:00	\N	\N	2	0	\N	\N
130604	DELEGATION	DEPLACEMENT	\N	\N	206	Déplacement à Rome dans le cadre du rapport sur les biotechnologies	\N	2016-10-27 17:00:00	2016-10-28 18:00:00	\N	\N	2	0	\N	\N
130716	COM_PERMANENTE	AUTRE	\N	FINC	\N	Sapin 2, examen rapport pour avis - PLF pour 2017 - Missions CCE et Anciens combattants	Sapin 2, examen du rapport pour avis - PLF pour 2017 - Missions CCE et Anciens combattants - Contrôle INI	2016-10-25 14:40:00	2016-10-25 16:10:00	2018-05-18 15:31:55	2018-05-18 15:32:02	34	0	\N	\N
130815	QUESTURE	AUCUNE	\N	\N	\N	Questure	\N	2016-10-25 14:55:00	2016-10-25 17:15:00	\N	\N	2	0	\N	\N
130821	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Ethique du sport	PPL Ethique du sport	2016-10-26 14:30:00	2016-10-26 18:20:00	\N	\N	82	0	\N	\N
130822	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Carte interco.	PPL Carte interco.	2016-10-26 18:30:00	2016-10-26 20:25:00	\N	\N	17	0	\N	\N
130823	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL LMD	PPL LMD	2016-10-26 21:55:00	2016-10-27 00:00:00	\N	\N	43	0	\N	\N
131213	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2016-10-26 14:10:00	2016-10-26 14:15:00	2016-10-26 15:57:35	2016-10-26 16:08:20	32	0	\N	\N
131502	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF pour 2017 - Culture	Patrimoines	2016-10-26 15:00:00	2016-10-26 16:00:00	\N	\N	1	0	\N	\N
131555	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017- CAS "Gestion du patrimoine immobilier de l'Etat"	PLF pour 2017- CAS "Gestion du patrimoine immobilier de l'Etat" - Audition de la Direction de l'immobilier de l'Etat	2016-10-25 09:00:00	2016-10-25 10:30:00	\N	\N	2	0	\N	\N
131933	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Ecologie, développement et mobilité durables  - Déplacement	PLF pour 2017 - Ecologie, développement et mobilité durables - Visite Blablacar  - Déplacement	2016-10-26 18:00:00	2016-10-26 20:00:00	\N	\N	2	0	\N	\N
131976	COM_EURO	AUDRAP	\N	AFEU	\N	Union économique et monétaire	Audition rapporteur - Approfondissement UEM	2016-10-25 14:30:00	2016-10-25 15:30:00	\N	\N	2	0	\N	\N
131979	COM_EURO	AUDRAP	\N	AFEU	\N	Union économique et monétaire	Audition rapporteur - UEM	2016-10-25 15:30:00	2016-10-25 16:30:00	\N	\N	2	0	\N	\N
132899	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017  - Justice	PLF pour 2017  - Justice - Elektron	2016-10-27 16:30:00	2016-10-27 17:20:00	\N	\N	1	0	\N	\N
128943	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2017 - Missions EFE, Sport, Solidarité	PLF pour 2017 - Missions EFE, Sport, Solidarité	2016-10-19 08:35:00	2016-10-19 10:35:00	2018-05-18 15:27:21	2018-05-18 15:27:28	42	0	\N	\N
132917	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017	PLF pour 2017  - Justice - Barreau de Paris	2016-10-27 13:45:00	2016-10-27 14:35:00	\N	\N	1	0	\N	\N
132919	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Recherche et Enseignement supérieur	PLF pour 2017 - Recherche et Enseignement supérieur - IFP Energies nouvelles	2016-10-26 15:00:00	2016-10-26 16:00:00	\N	\N	1	0	\N	\N
132921	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Recherche et Enseignement supérieur	PLF pour 2017 - Recherche et Enseignement supérieur - CNRS	2016-10-27 16:00:00	2016-10-27 17:00:00	\N	\N	1	0	\N	\N
133038	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2017 - Avis Justice judiciaire	\N	2016-10-27 16:00:00	2016-10-27 18:05:00	\N	\N	1	0	\N	\N
133040	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2017 - Avis Sécurité	\N	2016-10-25 14:15:00	2016-10-25 19:00:00	\N	\N	1	0	\N	\N
133042	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2017 - Avis Sécurité	\N	2016-10-26 14:00:00	2016-10-26 15:00:00	\N	\N	1	0	\N	\N
134392	DELEGATION	AUDRAP	\N	\N	COLTER	RI_prévention radicalisation et collectivités	RI_prévention radicalisation et collectivités	2016-11-02 17:00:00	2016-11-02 18:20:00	\N	\N	2	0	\N	\N
134514	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Modernisation de la vie économique	PJL Modernisation de la vie économique	2016-11-03 10:30:00	2016-11-03 13:10:00	\N	\N	82	0	\N	\N
134515	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2016-11-03 15:00:00	2016-11-03 16:10:00	\N	\N	249	0	\N	\N
134516	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Modernisation de la vie économique	PJL Modernisation de la vie économique	2016-11-03 16:25:00	2016-11-03 20:00:00	\N	\N	48	0	\N	\N
134517	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Modernisation de la vie économique	PJL Modernisation de la vie économique	2016-11-03 21:30:00	2016-11-03 23:50:00	\N	\N	17	0	\N	\N
135420	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Avis crédits Sport (PLF 2017)	Avis sur les crédits relatifs au sport (PLF 2017)	2016-11-03 10:30:00	2016-11-03 11:50:00	\N	\N	1	0	\N	\N
135425	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	sport	Avis sur les crédits relatifs au sport (PLF 2017)	2016-11-03 15:15:00	2016-11-03 16:15:00	\N	\N	1	0	\N	\N
126289	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Statut de Paris	\N	2016-10-12 18:30:00	2016-10-12 19:00:00	\N	\N	1	0	\N	\N
126291	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle "dispositifs d'hébergement d'urgence"	Contrôle Dispositifs d'hébergement d'urgence - Conseillers cabinet Mme COSSE	2016-10-13 11:30:00	2016-10-13 12:45:00	\N	\N	1	0	\N	\N
127019	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	Climat et Environnement	GT CDD Climat et Environnement	2016-10-13 11:00:00	2016-10-13 11:15:00	\N	\N	1	0	\N	\N
127021	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Transport 3¨P	\N	2016-10-13 16:15:00	2016-10-13 17:45:00	\N	\N	1	0	\N	\N
127027	COM_PERMANENTE	DEPLACEMENT	\N	CDD	\N	Visite du Mondial de l'Auto	\N	2016-10-12 15:00:00	2016-10-12 17:00:00	\N	\N	11	0	\N	\N
127039	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - DAG	PLF ¨pour 2017 - DAG - SIG - SGAE	2016-10-11 17:00:00	2016-10-11 19:00:00	\N	\N	1	0	\N	\N
127042	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017  - Justice	PLF POUR 2017  - Justice - Directrice des services judiciaires	2016-10-13 10:30:00	2016-10-13 11:30:00	\N	\N	1	0	\N	\N
127044	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - DAG - Déplacement	PLF pour 2017 - DAG - HATVP - Déplacement	2016-10-13 13:30:00	2016-10-13 14:30:00	\N	\N	1	0	\N	\N
127047	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - DAG	PLF pour 2017 - DAG - CNCTR	2016-10-13 16:00:00	2016-10-13 16:35:00	\N	\N	1	0	\N	\N
127049	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017  - Justice	PLF pour 2017  - Justice - Direction de l'administration pénitentiaire	2016-10-13 16:35:00	2016-10-13 18:00:00	\N	\N	1	0	\N	\N
127053	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - DAG - Déplacement	PLF pour 2017 - DAG - CNIL - Déplacement	2016-10-13 18:15:00	2016-10-13 19:20:00	\N	\N	1	0	\N	\N
127058	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Anciens Combattants - Déplacement	Contrôle Anciens Combattants - Hotel National des InvalidesDéplacement	2016-10-10 16:00:00	2016-10-10 18:10:00	\N	\N	1	0	\N	\N
127061	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle SAIP	Contrôle SAIP - audition Deveryware	2016-10-12 14:30:00	2016-10-12 15:30:00	\N	\N	1	0	\N	\N
127119	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Culture	PLF pour 2017 - Culture - Établissement public de Versailles	2016-10-12 15:30:00	2016-10-12 16:30:00	\N	\N	2	0	\N	\N
127122	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Culture	PLF pour 2017 - Culture - Ministère de la culture et de la communication	2016-10-10 17:00:00	2016-10-10 18:00:00	\N	\N	2	0	\N	\N
127126	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Culture	PLF pour 2017 - Culture - Direction générale de la création artistique	2016-10-12 17:30:00	2016-10-12 18:30:00	\N	\N	2	0	\N	\N
127130	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Culture	PLF pour 2017 - Culture - Direction générale des patrimoines	2016-10-13 14:00:00	2016-10-13 15:00:00	\N	\N	2	0	\N	\N
127133	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Engagements financiers de l'Etat	Contrôle Engagements financiers de l'Etat - Société générale	2016-10-13 11:30:00	2016-10-13 12:20:00	\N	\N	1	0	\N	\N
127136	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Rapport général	PLF pour 2017 - Rapport général - Boissons rafraichissantes	2016-10-13 09:00:00	2016-10-13 10:00:00	\N	\N	1	0	\N	\N
128833	QUESTURE	AUCUNE	\N	\N	\N	Questure	\N	2016-10-18 14:30:00	2016-10-18 16:30:00	\N	\N	3	0	\N	\N
128837	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Iran	\N	2016-10-11 16:05:00	2016-10-11 17:10:00	\N	\N	4	0	\N	\N
128842	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Iran	\N	2016-10-11 17:10:00	2016-10-11 17:50:00	\N	\N	2	0	\N	\N
128845	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Iran	\N	2016-10-13 10:00:00	2016-10-13 11:00:00	\N	\N	3	0	\N	\N
128849	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL Emirats arabes unis	\N	2016-10-18 09:50:00	2016-10-18 10:50:00	\N	\N	1	0	\N	\N
128996	GIA	AUCUNE	\N	\N	\N	Ambassadeur du Pakistan	Déjeuner de travail avec l'ambassadeur du Pakistan sur le Cachemire et les dossiers de coopération	2016-10-19 13:00:00	2016-10-19 14:30:00	\N	\N	1	0	619	\N
129001	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat filière équine	Débat	2016-10-20 14:40:00	2016-10-20 16:10:00	\N	\N	21	0	\N	\N
129019	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2016-10-19 09:00:00	2016-10-19 12:45:00	2016-10-19 17:06:16	2016-10-19 17:26:56	36	0	\N	\N
131751	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition OPEX	Audition OPEX	2016-10-26 17:30:00	2016-10-26 19:00:00	2018-05-18 15:38:02	2018-05-18 15:38:14	15	0	\N	\N
128851	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL AECT, PPL Recomposition de la carte interco	\N	2016-10-19 09:10:00	2016-10-19 10:45:00	2016-10-19 11:37:56	2016-10-19 16:45:39	37	0	\N	\N
129189	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition  Bruno Parent - Prélèvement à la source de l'impôt sur le revenu	Audition Bruno Parent - Prélèvement à la source de l'impôt sur le revenu	2016-10-19 11:05:00	2016-10-19 12:55:00	2016-10-19 18:41:17	2016-10-20 09:48:57	29	0	\N	\N
129541	DELEGATION	AUCUNE	\N	\N	COLTER	Table ronde "Evolution missions Etat / collectivités territoriales"	\N	2016-10-27 09:00:00	2016-10-27 10:50:00	2016-10-27 14:51:32	2016-10-27 16:16:33	17	0	\N	\N
130103	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Transmission  et reprise d'entreprises	\N	2016-11-03 09:45:00	2016-11-03 11:00:00	\N	\N	1	0	\N	\N
130116	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2017 	\N	2016-10-19 15:30:00	2016-10-19 16:30:00	\N	\N	2	0	\N	\N
130128	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2017	\N	2016-10-19 13:30:00	2016-10-19 14:40:00	\N	\N	2	0	\N	\N
130192	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2017	\N	2016-10-19 14:30:00	2016-10-19 16:00:00	\N	\N	2	0	\N	\N
130195	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	\N	\N	2016-10-20 14:00:00	2016-10-20 18:00:00	\N	\N	5	0	\N	\N
130201	COM_EURO	AUDRAP	\N	AFEU	\N	Bruxelles : auditions SMA	\N	2016-10-17 09:00:00	2016-10-17 16:45:00	\N	\N	2	0	\N	\N
130697	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2017 - Egalité des territoires	Mission égalité des territoires et logement - prévention de l'exclusion et insertion des personnes vulnérables	2016-10-25 15:00:00	2016-10-25 16:10:00	\N	\N	1	0	\N	\N
130709	GIA	AUCUNE	\N	\N	\N	Entretien avec des parlementaires ukrainiens	Entretien avec Mme Oksana Syroid, vice-présidente de la Rada, et M. Oleh Berezyuk, député	2016-10-24 16:30:00	2016-10-24 18:00:00	\N	\N	2	0	530	\N
130803	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF pour 2017 - Médias, livre et industries culturelles	Crédits de la presse	2016-10-25 10:45:00	2016-10-25 11:30:00	\N	\N	1	0	\N	\N
130806	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF pour 2017 - Culture	Transmission des savoirs et démocratisation de la culture	2016-10-25 16:30:00	2016-10-25 18:00:00	\N	\N	1	0	\N	\N
130849	GIA	AUCUNE	\N	\N	\N	Audition Sri Sri Ravi Sankhar	Audition Sri Sri Ravi Sankhar (invitation groupe France-Inde)	2016-10-19 08:30:00	2016-10-19 09:30:00	\N	\N	2	0	634	\N
130852	GIA	AUCUNE	\N	\N	\N	rencontre Tashi Phuntsok	rencontre Tashi Phuntsok (nouveau représentant du Dalaï Lama en France)	2016-10-27 11:00:00	2016-10-27 12:00:00	\N	\N	1	0	634	\N
130913	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2016-10-26 10:05:00	2016-10-26 11:00:00	2018-05-18 15:36:34	2018-05-18 15:36:41	38	0	\N	\N
131031	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Avis budgétaire fonction publique	\N	2016-10-25 11:00:00	2016-10-25 12:30:00	\N	\N	1	0	\N	\N
131350	COM_PERMANENTE	AUTRE	\N	CDD	\N	Audition de M. Jean-François Carenco	Audition de M. Jean-François Carenco, préfet de la région d¿Île-de-France,	2016-10-26 09:30:00	2016-10-26 11:25:00	2018-05-18 15:32:20	2018-05-18 15:32:25	32	0	\N	\N
131564	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Economie - Déplacement	PLF pour 2017 - Economie - Visite Bpifrance  - Déplacement	2016-10-25 15:30:00	2016-10-25 17:30:00	\N	\N	2	0	\N	\N
131567	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - GFPRH - Déplacement	PLF pour 2017 - GFPRH - Déplacement au ministère de la fonction publique	2016-10-25 11:30:00	2016-10-25 13:00:00	\N	\N	2	0	\N	\N
131650	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Avis budgétaire outre mer	\N	2016-10-25 17:15:00	2016-10-25 18:15:00	\N	\N	1	0	\N	\N
131657	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Avis budgétaire outre mer	\N	2016-10-25 19:00:00	2016-10-25 20:00:00	\N	\N	1	0	\N	\N
131661	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Déradicalisation	\N	2016-10-26 15:00:00	2016-10-26 16:30:00	\N	\N	2	0	\N	\N
126551	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL Costa Rica	\N	2016-10-11 17:00:00	2016-10-11 17:45:00	\N	\N	1	0	\N	\N
126572	DELEGATION	DEPLACEMENT	\N	\N	206	Déplacement au Japon dans le cadre du rapport sur les terres rares	\N	2016-02-07 00:00:00	2016-02-12 00:00:00	\N	\N	2	0	\N	\N
126858	MISSION	AUCUNE	\N	REVENU	\N	MCI REVENU DE BASE	MCI REVENU DE BASE - Examen du projet de rapport présenté par M. Daniel Percheron, rapporteur 	2016-10-13 12:35:00	2016-10-13 14:55:00	2016-10-14 09:39:13	2016-10-14 12:41:53	19	0	\N	\N
126881	DELEGATION	AUDRAP	\N	\N	206	Déplacement à La Rochelle dans le cadre du rapport sur les terres rares	\N	2016-02-22 08:00:00	2016-02-22 20:00:00	\N	\N	2	0	\N	\N
126884	DELEGATION	AUDRAP	\N	\N	206	Déplacement en Suède et en Finlande dans le cadre du rapport sur les terres rares	\N	2015-06-22 08:00:00	2015-06-26 20:00:00	\N	\N	1	0	\N	\N
127332	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Statut de Paris - Audition ministre	\N	2016-10-18 09:35:00	2016-10-18 10:50:00	2018-05-18 15:27:04	2018-05-18 15:27:08	16	0	\N	\N
129293	COM_EURO	AUDRAP	\N	AFEU	\N	Simplification des normes	Simplification des normes européennes	2016-10-18 14:00:00	2016-10-18 16:00:00	\N	\N	5	0	\N	\N
129384	COM_EURO	AUDRAP	\N	AFEU	\N	Plan d'investissement pour l'Europe	Bilan du plan d'investissement pour l'Europe	2016-10-19 15:05:00	2016-10-19 15:50:00	\N	\N	1	0	\N	\N
129387	COM_EURO	AUDRAP	\N	AFEU	\N	Plan d'investissement pour l'Europe	Bilan du plan d'investissement pour l'Europe	2016-10-19 14:00:00	2016-10-19 15:05:00	\N	\N	2	0	\N	\N
130000	COM_EURO	CONTROLE	\N	AFEU	\N	Audition de M. Edouard Balladur, ancien Premier ministre, sur les négociations relatives a	Audition de M. Edouard Balladur, ancien Premier ministre, sur les négociations relatives au TTIP	2016-10-20 09:35:00	2016-10-20 10:45:00	2016-10-20 12:07:32	2016-10-20 15:01:19	20	0	\N	\N
130204	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	\N	\N	2016-10-21 14:30:00	2016-10-21 16:30:00	\N	\N	1	0	\N	\N
130224	COM_EURO	AUDRAP	\N	AFEU	\N	Simplification des normes	Simplification des normes européennes	2016-10-19 11:40:00	2016-10-19 13:00:00	\N	\N	2	0	\N	\N
130229	COM_EURO	AUDRAP	\N	AFEU	\N	Simplification des normes	Simplification des normes européennes	2016-10-19 14:15:00	2016-10-19 15:15:00	\N	\N	1	0	\N	\N
130253	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	MI redressement de la justice	\N	2016-10-20 07:00:00	2016-10-20 19:00:00	\N	\N	2	0	\N	\N
130275	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Recherche et Enseignement supérieur	PLF pour 2017 - Recherche et Enseignement supérieur - Audition ministère de l'éducation nationale	2016-10-20 09:00:00	2016-10-20 10:00:00	\N	\N	1	0	\N	\N
130277	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Recherche et Enseignement supérieur	PLF pour 2017 - Recherche et Enseignement supérieur - Audition CEA	2016-10-20 10:00:00	2016-10-20 11:00:00	\N	\N	1	0	\N	\N
130279	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Recherche et Enseignement supérieur	PLF pour 2017 - Recherche et Enseignement supérieur - Audition INRA	2016-10-20 12:15:00	2016-10-20 13:15:00	\N	\N	1	0	\N	\N
131447	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2017 - Audition prélèvement à la source	PLF pour 2017 - Audition prélèvement à la source	2016-10-26 11:05:00	2016-10-26 12:45:00	2018-05-18 15:36:55	2018-05-18 15:37:01	25	0	\N	\N
129201	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Diverses dispositions relatives aux agences sanitaires et aux produits de santé	\N	2016-10-19 09:00:00	2016-10-19 10:55:00	2016-10-20 09:45:03	2016-10-20 09:45:07	49	0	\N	\N
131772	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Egalité des territoires et Logement	PLF pour 2017 - Egalité des territoires et Logement - USH	2016-10-25 10:00:00	2016-10-25 11:00:00	\N	\N	1	0	\N	\N
131774	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Recherche et Enseignement supérieur	PLF pour 2017 - Recherche et Enseignement supérieur - Fédérations enseignement privé	2016-10-25 11:00:00	2016-10-25 12:00:00	\N	\N	1	0	\N	\N
131776	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Recherche et Enseignement supérieur	PLF pour 2017 - Recherche et Enseignement supérieur - CCI	2016-10-25 16:30:00	2016-10-25 17:30:00	\N	\N	1	0	\N	\N
131778	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Recherche et Enseignement supérieur	PLF pour 2017 - Recherche et Enseignement supérieur - MENESR	2016-10-26 14:40:00	2016-10-26 16:00:00	\N	\N	1	0	\N	\N
131781	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Recherche et Enseignement supérieur	PLF pour 2017 - Recherche et Enseignement supérieur - CPU	2016-10-26 16:00:00	2016-10-26 16:35:00	\N	\N	1	0	\N	\N
131784	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Egalité des territoires et logement	PLF pour 2017 - Egalité des territoires et logement - DGCS	2016-10-26 17:05:00	2016-10-26 18:05:00	\N	\N	1	0	\N	\N
131964	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2017 - Solidarité	PLF pour 2017 - Solidarité	2016-10-26 14:00:00	2016-10-26 18:00:00	\N	\N	4	0	\N	\N
131982	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2017 - Assurance maladie	PLFSS pour 2017 - Assurance maladie	2016-10-26 14:00:00	2016-10-26 16:15:00	\N	\N	3	0	\N	\N
132020	COM_EURO	CONTROLE	\N	AFEU	\N	\N	\N	2016-10-27 09:00:00	2016-10-27 10:35:00	2016-10-27 11:39:12	2016-10-27 16:15:45	16	0	\N	\N
132167	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF pour 2017 - Culture	Transmission des savoirs et démocratisation de la culture	2016-10-27 10:00:00	2016-10-27 13:00:00	\N	\N	1	0	\N	\N
132283	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2017 	\N	2016-10-27 09:30:00	2016-10-27 11:20:00	\N	\N	2	0	\N	\N
132336	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2017 	\N	2016-10-25 14:30:00	2016-10-25 16:00:00	\N	\N	2	0	\N	\N
132445	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2017 	\N	2016-10-25 18:00:00	2016-10-25 19:00:00	\N	\N	2	0	\N	\N
132466	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Iran	\N	2016-10-25 14:15:00	2016-10-25 15:50:00	\N	\N	10	0	\N	\N
132479	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Adaptation du master au système LMD	Proposition de loi portant adaptation du deuxième cycle de l'enseignement supérieur français au système Licence-Master-D	2016-10-04 09:30:00	2016-10-04 11:00:00	\N	\N	0	0	\N	\N
132760	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2017 - Avis Justice judiciaire	\N	2016-10-26 16:15:00	2016-10-26 19:00:00	\N	\N	1	0	\N	\N
132777	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Accueil d'une délégation étrangère	\N	2016-10-26 15:30:00	2016-10-26 16:20:00	\N	\N	1	0	\N	\N
132779	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Avis crédits Sport (PLF 2017)	Avis sur les crédits relatifs au sport (PLF 2017)	2016-10-27 09:30:00	2016-10-27 10:30:00	\N	\N	1	0	\N	\N
132782	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Av	\N	2016-10-27 15:15:00	2016-10-27 17:30:00	\N	\N	1	0	\N	\N
132784	DELEGATION	AUCUNE	\N	\N	DSOM	RI Normes BTP outre-mer	\N	2016-11-03 09:30:00	2016-11-04 11:30:00	2016-11-03 12:15:11	2016-11-03 13:44:38	9	0	\N	\N
132833	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Avis budgétaire outre mer	Avis budgétaire outre mer PLF 2017	2016-10-27 17:00:00	2016-10-27 18:25:00	\N	\N	1	0	\N	\N
132839	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF pour 2017 - Recherche et enseignement supérieur	Recherche	2016-10-27 17:00:00	2016-10-27 19:00:00	\N	\N	1	0	\N	\N
132841	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF pour 2017 - Recherche et enseignement supérieur	Recherche	2016-10-27 09:30:00	2016-10-27 12:30:00	\N	\N	1	0	\N	\N
132843	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF pour 2017 - Recherche et enseignement supérieur	Recherche	2016-10-28 10:00:00	2016-10-28 12:00:00	\N	\N	1	0	\N	\N
132925	BUREAU	AUCUNE	\N	\N	\N	Bureau du Sénat	Bureau	2016-10-27 09:00:00	2016-10-27 11:30:00	\N	\N	24	0	\N	\N
132954	BUREAU	AUCUNE	\N	\N	\N	Délégation statut et conditions exercice mandat de sénateur	Délégation statut et conditions exercice mandat de sénateur	2016-10-26 11:30:00	2016-10-26 12:30:00	\N	\N	4	0	\N	\N
132990	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	GT Culture et Handicap	Groupe de travail Culture et Handicap	2016-10-20 15:15:00	2016-10-20 16:45:00	\N	\N	2	0	\N	\N
132993	COM_EURO	AUTRE_NON_PLENIERE	\N	AFEU	\N	Parlement d'Ukraine	Entretien avec Mme Oksana SIROYID, vice-présidente du Parlement d'Ukraine	2016-10-26 14:30:00	2016-10-26 15:30:00	\N	\N	2	0	\N	\N
133054	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF pour 2017 - Culture	PLF pour 2017 - Culture	2016-10-26 17:00:00	2016-10-26 17:45:00	\N	\N	2	0	\N	\N
133074	ETUDES	AUCUNE	\N	\N	\N	\N	\N	2016-11-02 08:15:00	2016-11-02 09:25:00	\N	\N	11	0	\N	906
126999	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	COM France Télévisions	COM 2016-2020 de France Télévisions	2016-10-13 09:30:00	2016-10-13 10:30:00	\N	\N	1	0	\N	\N
127001	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Éthique, régulation et transparence du sport professionnel	PPL Éthique, régulation et transparence du sport professionnel	2016-10-11 17:00:00	2016-10-11 19:00:00	\N	\N	1	0	\N	\N
127150	DELEGATION	AUDRAP	\N	\N	COLTER	RI Evolution des services déconcentrés	\N	2016-06-22 14:30:00	2016-06-22 15:30:00	\N	\N	2	0	\N	\N
127153	DELEGATION	AUDRAP	\N	\N	COLTER	RI Evolution des missions des services déconcentrés	\N	2016-06-23 14:00:00	2016-06-23 15:00:00	\N	\N	2	0	\N	\N
127156	DELEGATION	AUDRAP	\N	\N	COLTER	RI Evolution des missions des services déconcentrés	\N	2016-07-05 14:00:00	2016-07-05 15:00:00	\N	\N	2	0	\N	\N
129300	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Enseignement scolaire	PLF pour 2017 - Enseignement scolaire - MENESR	2016-10-18 10:30:00	2016-10-18 12:00:00	\N	\N	1	0	\N	\N
129459	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2016-10-19 10:55:00	2016-10-19 11:55:00	2016-10-19 17:02:40	2016-10-19 17:26:54	34	0	\N	\N
129791	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2016-10-19 17:45:00	2016-10-19 19:15:00	2018-05-18 15:30:03	2018-05-18 15:30:09	35	0	\N	\N
129889	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	Etat d'urgence	\N	2016-10-19 13:45:00	2016-10-19 17:30:00	\N	\N	4	0	\N	\N
129993	GIA	AUCUNE	\N	\N	\N	AG groupe France-Sri Lanka	Réunion interne	2016-10-19 19:00:00	2016-10-19 20:00:00	\N	\N	5	0	550	\N
130075	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Conférence interparlementaire Art 13 TSCG	Conférence interparlementaire Art 13 TSCG	2016-10-17 08:30:00	2016-10-18 14:30:00	\N	\N	4	0	\N	\N
130107	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Controle AGRASC	Controle AGRASC - MILDECA	2016-10-18 10:00:00	2016-10-18 11:00:00	\N	\N	1	0	\N	\N
133242	COM_PERMANENTE	AUTRE	\N	CAE	\N	\N	\N	2016-11-02 09:35:00	2016-11-02 09:55:00	2018-05-18 15:38:48	2018-05-18 15:38:56	22	0	\N	\N
133270	COM_PERMANENTE	AUTRE	\N	CDD	\N	\N	\N	2016-11-02 09:30:00	2016-11-02 10:25:00	2018-05-18 15:38:27	2018-05-18 15:38:33	30	0	\N	\N
133700	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2016-11-02 09:30:00	2016-11-02 11:40:00	2016-11-02 16:09:52	2016-11-02 17:16:32	46	1	\N	\N
130110	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017  - Justice	PLF pour 2017  - Justice - Directrice de la protection judiciaire de la jeunesse	2016-10-18 11:00:00	2016-10-18 12:00:00	\N	\N	1	0	\N	\N
130112	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017  - Justice	PLF pour 2017  - Justice - Secrétariat général ministère de la justice	2016-10-18 18:00:00	2016-10-18 19:00:00	\N	\N	1	0	\N	\N
130119	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017	PLF pour 2017 - Association des régions de France	2016-10-19 14:45:00	2016-10-19 15:50:00	\N	\N	8	0	\N	\N
130162	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Ecologie, développement et mobilité durables	PLF pour 2017 - Ecologie, développement et mobilité durables - Audition CCI France	2016-10-18 14:30:00	2016-10-18 15:30:00	\N	\N	1	0	\N	\N
130175	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Communes nouvelles	\N	2016-10-25 14:30:00	2016-10-25 15:55:00	\N	\N	77	0	\N	\N
130176	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Stabilisation droit urbanisme	\N	2016-10-25 16:30:00	2016-10-25 19:25:00	\N	\N	104	0	\N	\N
130206	ETUDES	AUCUNE	\N	\N	\N	Gestion des déchets	\N	2016-10-19 17:15:00	2016-10-19 18:30:00	\N	\N	5	0	\N	922
130212	ETUDES	AUCUNE	\N	\N	\N	Forêt et filière bois	\N	2016-10-19 08:15:00	2016-10-19 09:30:00	\N	\N	9	0	\N	948
130222	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Sapin II	\N	2016-10-20 15:00:00	2016-10-20 16:00:00	\N	\N	1	0	\N	\N
130227	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF 2017	PLF 2017 Avis Transports maritimes	2016-10-20 10:15:00	2016-10-20 11:15:00	\N	\N	1	0	\N	\N
130352	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF pour 2017	PLF pour 2017	2016-10-18 17:30:00	2016-10-18 19:00:00	\N	\N	1	0	\N	\N
130354	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF pour 2017	PLF pour 2017	2016-10-19 15:00:00	2016-10-19 16:00:00	\N	\N	1	0	\N	\N
130359	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF pour 2017	PLF pour 2017	2016-10-18 14:00:00	2016-10-18 15:00:00	\N	\N	1	0	\N	\N
130361	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF pour 2017	PLF pour 2017	2016-10-19 14:00:00	2016-10-19 16:00:00	\N	\N	1	0	\N	\N
130367	GIA	AUCUNE	\N	\N	\N	entretien	entretien avec Hon. Gerry Browlee minsitre de la défende de Nouvelle Zélande	2016-10-25 08:30:00	2016-10-26 09:30:00	\N	\N	2	0	663	\N
131517	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF pour 2017 - Culture	Cinéma	2016-10-26 14:30:00	2016-10-26 16:15:00	\N	\N	1	0	\N	\N
131523	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI redressement de la justice	\N	2016-10-26 14:30:00	2016-10-26 16:00:00	\N	\N	3	0	\N	\N
131931	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Ecologie, développement et mobilité durables	PLF pour 2017 - Ecologie, développement et mobilité durables - Audition IGN	2016-10-26 17:00:00	2016-10-26 18:00:00	\N	\N	1	0	\N	\N
131937	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Sécurités - Police et gendarmerie	PLF pour 2017 - Sécurités - Police et gendarmerie - Audition du SCSI-CFDT	2016-10-24 16:00:00	2016-10-24 18:00:00	\N	\N	1	0	\N	\N
131939	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - CAS "Participations financières de l'Etat" 	PLF pour 2017 - CAS "Participations financières de l'Etat" - Audition ENGIE	2016-10-26 11:30:00	2016-10-26 12:30:00	\N	\N	1	0	\N	\N
132805	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI redressement de la justice	\N	2016-10-27 09:00:00	2016-10-27 12:30:00	\N	\N	3	0	\N	\N
132809	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF pour 2017 - Création	Cinéma	2016-10-27 16:15:00	2016-10-27 17:00:00	\N	\N	1	0	\N	\N
132845	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2017 - Assurance maladie	PLFSS pour 2017 - Assurance maladie	2016-10-17 11:30:00	2016-10-17 12:30:00	\N	\N	3	0	\N	\N
132849	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2017 - Assurance maladie	PLFSS pour 2017 - Assurance maladie	2016-10-27 14:00:00	2016-10-27 15:00:00	\N	\N	4	0	\N	\N
132873	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2017 - Administration pénitentiaire	\N	2016-10-27 08:30:00	2016-10-27 13:20:00	\N	\N	1	0	\N	\N
132884	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF pour 2017	PLF pour 2017	2016-10-26 18:15:00	2016-10-26 19:00:00	\N	\N	1	0	\N	\N
132886	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF pour 2017	PLF pour 2017	2016-10-24 17:00:00	2016-10-24 18:30:00	\N	\N	1	0	\N	\N
132888	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF pour 2017	PLF pour 2017	2016-10-26 14:30:00	2016-10-26 16:00:00	\N	\N	1	0	\N	\N
132890	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF pour 2017	PLF pour 2017	2016-10-25 15:00:00	2016-10-25 16:00:00	\N	\N	1	0	\N	\N
132892	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF pour 2017	PLF pour 2017	2016-10-25 14:30:00	2016-10-25 18:30:00	\N	\N	1	0	\N	\N
132894	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF pour 2017	PLF pour 2017	2016-10-27 09:30:00	2016-10-27 10:30:00	\N	\N	1	0	\N	\N
132896	ETUDES	AUCUNE	\N	\N	\N	GE Vigne et vin	GE Vigne et vin	2016-10-26 14:00:00	2016-10-26 14:35:00	\N	\N	17	0	\N	909
132926	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Déplacement mission réforme territoriale	Déplacement mission réforme territoriale Besançon et Dijon	2016-01-21 14:15:00	2016-01-22 18:45:00	\N	\N	3	0	\N	\N
132959	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Déplacement mission réforme territoriale	Déplacement mission de suivi des dernières lois de réforme territoriale à Caen et Rouen	2016-03-24 12:00:00	2016-03-25 18:15:00	\N	\N	6	0	\N	\N
132966	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Déplacement mission réforme territoriale	Déplacement mission de suivi des dernières lois de réforme territoriale à Châlons en Champagne	2016-04-29 07:30:00	2016-04-29 19:00:00	\N	\N	5	0	\N	\N
132972	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Déplacement mission réforme territoriale	Déplacement mission de suivi des dernières lois de réforme territoriale à Poitiers et Bordeaux	2016-06-16 07:45:00	2016-06-17 20:00:00	\N	\N	4	0	\N	\N
132977	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Déplacement mission éforme territoriale	Déplacement mission de suivi des dernières lois de réforme territoriale Limoges	2016-06-24 07:45:00	2016-06-24 20:20:00	\N	\N	3	0	\N	\N
132981	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Mission réforme territoriale	Déplacement mission de suivi des dernières lois de réforme territoriale Chambéry et Lyon	2016-09-15 06:30:00	2016-09-16 19:30:00	\N	\N	4	0	\N	\N
132986	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Mission réforme territoriale	Mission de suivi des dernières lois de réforme territoriale Cantal et Clermont-Ferrand	2016-09-22 07:30:00	2016-09-23 21:00:00	\N	\N	3	0	\N	\N
133014	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF pour 2017	PLF pour 2017	2016-10-25 11:00:00	2016-10-25 12:30:00	\N	\N	1	0	\N	\N
133016	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF pour 2017	PLF pour 2017	2016-10-25 16:00:00	2016-10-25 19:00:00	\N	\N	1	0	\N	\N
133018	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF pour 2017	PLF pour 2017	2016-10-26 14:20:00	2016-10-26 17:00:00	\N	\N	1	0	\N	\N
133020	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF pour 2017	PLF pour 2017	2016-10-26 16:00:00	2016-10-26 17:00:00	\N	\N	1	0	\N	\N
133022	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF pour 2017	PLF pour 2017	2016-10-26 16:25:00	2016-10-26 19:00:00	\N	\N	1	0	\N	\N
126941	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Transports	PLF pour 2017 - Transports - Audition SNCF Réseau	2016-10-12 14:30:00	2016-10-12 15:30:00	\N	\N	1	0	\N	\N
126943	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Transports	PLF pour 2017 - Transports - Audition SNCF	2016-10-12 16:30:00	2016-10-12 17:30:00	\N	\N	1	0	\N	\N
126945	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Transports	PLF pour 2017 - Transports - Audition VNF	2016-10-12 17:30:00	2016-10-12 18:30:00	\N	\N	1	0	\N	\N
127094	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle budgétaire enseignement scolaire	Contrôle budgétaire enseignement scolaire - Table ronde syndicats	2016-10-11 15:00:00	2016-10-11 17:00:00	\N	\N	1	0	\N	\N
127214	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2017 Vieillesse	PLFSS pour 2017 Vieillesse	2016-10-19 13:00:00	2016-10-19 14:00:00	\N	\N	1	0	\N	\N
127215	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2017 Vieillesse	PLFSS pour 2017 Vieillesse	2016-10-24 10:00:00	2016-10-24 11:00:00	\N	\N	1	0	\N	\N
127218	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2017 Vieillesse	PLFSS pour 2017 Vieillesse	2016-10-18 18:30:00	2016-10-18 19:30:00	\N	\N	1	0	\N	\N
127220	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2017	PLF pour 2017 Mission santé	2016-10-26 17:00:00	2016-10-26 17:30:00	\N	\N	1	0	\N	\N
127222	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2017	PLF pour 2017 Mission santé	2016-11-03 14:10:00	2016-11-03 14:40:00	\N	\N	1	0	\N	\N
127224	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Transmission  et reprise d'entreprises	\N	2016-10-25 15:00:00	2016-10-25 17:00:00	\N	\N	2	0	\N	\N
127228	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Transmission  et reprise d'entreprises	\N	2016-10-25 14:00:00	2016-10-25 15:00:00	\N	\N	2	0	\N	\N
127231	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Transmission  et reprise d'entreprises	\N	2016-11-09 17:00:00	2016-11-09 17:45:00	\N	\N	2	0	\N	\N
127234	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Transmission  et reprise d'entreprises	\N	2016-11-09 15:30:00	2016-11-09 16:40:00	\N	\N	2	0	\N	\N
127237	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière	\N	2016-11-08 13:40:00	2016-11-08 14:40:00	2016-11-08 17:47:39	2016-11-09 11:47:33	11	0	\N	\N
127238	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière 	\N	2016-11-03 08:50:00	2016-11-03 10:10:00	2016-11-03 11:30:40	2016-11-03 13:44:36	12	0	\N	\N
127239	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière	\N	2016-11-15 12:45:00	2016-11-15 14:00:00	2016-11-15 15:56:27	2016-11-15 17:16:25	14	0	\N	\N
127240	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	661	\N	\N	Explications de vote sur l'ensemble du PJL Égalité et citoyenneté	Explications de vote sur l'ensemble du PJL Égalité et citoyenneté	2016-10-18 17:50:00	2016-10-18 18:40:00	\N	\N	283	0	\N	\N
127241	SEANCE_PLENIERE	SCRUSOL	661	\N	\N	Scrutin solennel PJL Égalité et citoyenneté	Scrutin solennel PJL Égalité et citoyenneté	2016-10-18 18:40:00	2016-10-18 19:10:00	\N	\N	280	0	\N	\N
127242	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Islam	Débat	2016-10-19 14:00:00	2016-10-19 15:55:00	\N	\N	73	0	\N	\N
127243	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Opérations extérieures	Débat	2016-10-19 16:15:00	2016-10-19 18:25:00	\N	\N	113	0	\N	\N
127244	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Conseil européen	Débat	2016-10-19 18:35:00	2016-10-19 20:55:00	\N	\N	41	0	\N	\N
127245	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Eau	Débat	2016-10-19 22:25:00	2016-10-20 00:10:00	\N	\N	25	0	\N	\N
127404	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2017 - Avis protection des droits et libertés	\N	2016-10-17 14:30:00	2016-10-17 16:30:00	\N	\N	1	0	\N	\N
130034	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition Enseignement français à l'étranger	Audition Enseignement français à l'étranger	2016-10-20 10:35:00	2016-10-20 12:50:00	2018-05-18 15:30:40	2018-05-18 15:30:47	17	0	\N	\N
130233	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Economie - Déplacement	PLF pour 2017 - Economie - Déplacement - Audition Business France	2016-10-19 16:00:00	2016-10-19 18:00:00	\N	\N	2	0	\N	\N
130237	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - GFPRH - Déplacement	PLF pour 2017 - GFPRH - Déplacement - Audition DGFiP	2016-10-20 08:30:00	2016-10-20 10:00:00	\N	\N	2	0	\N	\N
130249	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Anciens combattants, mémoire et liens avec la Nation	PLF pour 2017 - Anciens combattants, mémoire et liens avec la Nation - Audition SG ministère de la défense	2016-10-19 08:45:00	2016-10-19 09:55:00	\N	\N	1	0	\N	\N
130337	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL CDG EXPRESS	PJL CDG EXPRESS	2016-10-19 08:30:00	2016-10-19 10:00:00	\N	\N	1	0	\N	\N
130339	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL CDG EXPRESS	PJL CDG EXPRESS	2016-10-19 17:30:00	2016-10-19 18:30:00	\N	\N	1	0	\N	\N
130341	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD - PJL CDG Express	Aud. Rapp. CDD - PJL CDG Express	2016-10-18 14:00:00	2016-10-18 17:00:00	\N	\N	1	0	\N	\N
130344	GIA	AUCUNE	\N	\N	\N	Entretien avec un ministre étranger	Entretien au Sénat avec M. Melibaev, vice-ministre de la Défense d'Ouzbékistan	2016-10-20 10:30:00	2016-10-20 12:00:00	\N	\N	1	0	556	\N
130607	ETUDES	AUCUNE	\N	\N	\N	\N	Groupe d'études Société numérique, nouveaux usages, nouveaux médias	2016-10-19 14:00:00	2016-10-19 15:00:00	\N	\N	4	0	\N	965
130838	MISSION	PLEIN_NON_JO	\N	BREXIT	\N	\N	\N	2016-10-26 08:35:00	2016-10-26 09:35:00	2016-10-26 10:15:29	\N	7	0	\N	\N
130988	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Avis crédits Audiovisuel (PLF 2017)	Avis sur les crédits relatifs à l'audiovisuel (PLF 2017)	2016-10-25 15:00:00	2016-10-25 18:30:00	\N	\N	1	0	\N	\N
130993	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Adaptation du master au système LMD	PPL Adaptation du master au système Licence-Master-Doctorat	2016-10-04 09:30:00	2016-10-04 11:00:00	\N	\N	1	0	\N	\N
130995	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Adaptation du master au système LMD	PPL Adaptation du master au système Licence-Master-Doctorat	2016-10-05 14:30:00	2016-10-05 18:00:00	\N	\N	1	0	\N	\N
131007	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Adaptation du master au système LMD	PPL Adaptation du master au système Licence-Master-Doctorat	2016-10-11 09:30:00	2016-10-11 11:15:00	\N	\N	1	0	\N	\N
131026	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF pour 2017 - Culture	PLF pour 2017 - Culture	2016-10-26 16:15:00	2016-10-26 17:00:00	\N	\N	3	0	\N	\N
131028	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	pl	\N	2016-10-27 17:00:00	2016-10-27 18:30:00	\N	\N	1	0	\N	\N
131570	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Immigration, asile et intégration	PLF pour 2017 - Immigration, asile et intégration - Audition du Directeur général des étrangers en France	2016-10-24 16:00:00	2016-10-24 17:00:00	\N	\N	1	0	\N	\N
131873	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Explication de vote et vote PJL Système de santé	Explication de vote et vote PJL Système de santé	2016-10-27 10:30:00	2016-10-27 11:40:00	\N	\N	66	0	\N	\N
131874	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Vote PJL Produits de santé	Vote PJL Produits de santé	2016-10-27 10:30:00	2016-10-27 11:40:00	\N	\N	64	0	\N	\N
131875	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2016-10-27 15:00:00	2016-10-27 16:00:00	\N	\N	232	0	\N	\N
131876	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Mixité sociale GPE	PPL Mixité sociale GPE	2016-10-27 16:15:00	2016-10-27 17:40:00	\N	\N	36	0	\N	\N
130854	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2016-10-26 09:30:00	2016-10-26 10:40:00	2016-10-26 11:40:21	2016-10-26 15:02:02	49	0	\N	\N
133026	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF pour 2017	PLF pour 2017	2016-10-27 09:00:00	2016-10-27 10:30:00	\N	\N	1	0	\N	\N
133028	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF pour 2017	PLF pour 2017	2016-10-27 11:00:00	2016-10-27 12:20:00	\N	\N	1	0	\N	\N
133030	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Transport 3¨P	\N	2016-10-27 13:45:00	2016-10-27 14:30:00	\N	\N	1	0	\N	\N
133032	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF pour 2017	PLF pour 2017	2016-10-27 18:00:00	2016-10-27 19:30:00	\N	\N	1	0	\N	\N
133034	COM_PERMANENTE	DEPLACEMENT	\N	CDD	\N	PPL TRANSPORT 3 P	PPL TRANSPORT 3 P	2016-10-28 13:45:00	2016-10-28 17:00:00	\N	\N	1	0	\N	\N
133036	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL TRANSPORT 3 P	PPL TRANSPORT 3 P	2016-10-28 17:30:00	2016-10-28 19:10:00	\N	\N	1	0	\N	\N
133758	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2017 Médico-social	PLFSS pour 2017 Médico-social	2016-11-03 11:15:00	2016-11-03 12:15:00	\N	\N	1	0	\N	\N
126293	COM_EURO	CONTROLE	\N	AFEU	\N	\N	\N	2016-10-13 08:35:00	2016-10-13 09:55:00	2016-10-13 14:49:02	2016-10-13 15:29:23	20	0	\N	\N
127178	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF pour 2017	PLF 2017	2016-10-11 08:45:00	2016-10-11 09:15:00	\N	\N	1	0	\N	\N
127179	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF pour 2017	PLF pour 2017	2016-10-11 09:15:00	2016-10-11 10:00:00	\N	\N	1	0	\N	\N
127180	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF pour 2017	PLF pour 2017	2016-10-11 18:45:00	2016-10-11 19:15:00	\N	\N	1	0	\N	\N
127182	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF pour 2017	PLF pour 2017	2016-10-11 19:15:00	2016-10-11 19:45:00	\N	\N	1	0	\N	\N
127184	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF pour 2017	PLF pour 2017	2016-10-11 19:45:00	2016-10-11 20:00:00	\N	\N	1	0	\N	\N
127191	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Crise au Levant	Débat Crise au Levant	2016-10-18 14:30:00	2016-10-18 16:30:00	\N	\N	130	0	\N	\N
127192	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2016-10-18 16:45:00	2016-10-18 17:35:00	\N	\N	294	0	\N	\N
127193	SEANCE_PLENIERE	QOD	\N	\N	\N	Question orale avec débat Rythmes scolaires	Question orale avec débat	2016-10-18 19:15:00	2016-10-18 21:00:00	\N	\N	77	0	\N	\N
127194	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Orientation scolaire	Débat Orientation scolaire	2016-10-18 22:35:00	2016-10-19 00:10:00	\N	\N	33	0	\N	\N
129522	MISSION	PLEIN_NON_JO	\N	BREXIT	\N	\N	\N	2016-10-19 14:00:00	2016-10-19 16:15:00	\N	\N	18	0	\N	\N
129556	DELEGATION	AUDRAP	\N	\N	211	Association Surrénales	Association Surrénales	2016-10-19 14:30:00	2016-10-19 16:00:00	\N	\N	2	0	\N	\N
129934	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Statut de Paris	\N	2016-10-19 15:00:00	2016-10-19 15:45:00	\N	\N	1	0	\N	\N
129936	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Statut de Paris	\N	2016-10-19 15:45:00	2016-10-19 16:30:00	\N	\N	1	0	\N	\N
129938	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Statut de Paris	\N	2016-10-19 16:30:00	2016-10-19 17:15:00	\N	\N	1	0	\N	\N
129940	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Statut de Paris	\N	2016-10-19 17:30:00	2016-10-19 19:00:00	\N	\N	1	0	\N	\N
130243	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Affaires européennes	PLF pour 2017 - Affaires européennes - Audition direction du budget	2016-10-19 16:00:00	2016-10-19 17:00:00	\N	\N	1	0	\N	\N
130363	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2017 - Famille	PLFSS 2017 - Famille	2016-10-25 09:00:00	2016-10-25 10:15:00	\N	\N	2	0	\N	\N
131132	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de M. Pierre-René Lemas	Audition de M. Pierre-René Lemas directeur général du groupe Caisse des dépôts	2016-10-26 09:35:00	2016-10-26 12:05:00	2018-05-18 15:32:38	2018-05-18 15:36:18	32	0	\N	\N
131433	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Communes associées et commune nouvelle	\N	2016-10-25 14:15:00	2016-10-25 14:20:00	2016-10-26 15:33:56	2016-10-26 16:04:51	9	0	\N	\N
131533	GIA	AUCUNE	\N	\N	\N	Audition Sri Sri Ravi Shankar	Audition Sri Sri Ravi Shankar en présence de l'ambassadeur d'Inde en France (+GIA Tibet, Pakistan et Népal)	2016-10-19 08:30:00	2016-10-19 09:15:00	\N	\N	7	0	618	\N
131542	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017  - Transports 	PLF pour 2017 - Transports - Audition Société du Grand Paris	2016-10-25 15:00:00	2016-10-25 16:00:00	\N	\N	1	0	\N	\N
131544	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017  - Transports	PLF pour 2017  - Transports - Audition AFITF	2016-10-25 16:15:00	2016-10-25 17:15:00	\N	\N	1	0	\N	\N
131546	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Ecologie, développement et mobilité durables 	PLF pour 2017 - Ecologie, développement et mobilité durables - Audition Météo-France	2016-10-25 17:30:00	2016-10-25 18:30:00	\N	\N	1	0	\N	\N
131550	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017  - Transports	PLF pour 2017  - Transports - Audition ARAFER	2016-10-25 18:30:00	2016-10-25 19:30:00	\N	\N	1	0	\N	\N
132869	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	FINC	\N	PLF pour 2017	PLF pour 2017 - Aide publique au développement - Audition Agence française de développement	2016-06-28 18:15:00	2016-06-28 19:20:00	\N	\N	0	0	\N	\N
132871	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Aide publique au développement	PLF pour 2017 - Aide publique au développement - Audition Agence française de développement	2016-10-27 11:05:00	2016-10-27 13:00:00	\N	\N	1	0	\N	\N
132881	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Culture	PLF pour 2017 - Culture - Audition Directeur de l'Opéra national de Paris	2016-10-27 14:00:00	2016-10-27 15:00:00	\N	\N	2	0	\N	\N
133759	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2017	PLF pour 2017 Anciens combattants	2016-11-03 11:00:00	2016-11-03 11:45:00	\N	\N	1	0	\N	\N
133760	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2017	PLF pour 2017 Anciens combattants	2016-11-03 12:00:00	2016-11-03 13:00:00	\N	\N	1	0	\N	\N
133762	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2016-11-02 11:45:00	2016-11-02 12:45:00	2016-11-02 16:10:37	2016-11-02 17:16:19	24	0	\N	\N
133824	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2017	PLF pour 2017 Anciens combattants	2016-11-03 16:15:00	2016-11-03 17:00:00	\N	\N	1	0	\N	\N
133826	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2017	PLF pour 2017 Anciens combattants	2016-11-09 14:00:00	2016-11-09 15:00:00	\N	\N	1	0	\N	\N
133828	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2017	PLF pour 2017 Anciens combattants	2016-11-21 11:30:00	2016-11-21 12:30:00	\N	\N	1	0	\N	\N
134149	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2017 - Egalité des territoires	Mission égalité des territoires et logement - prévention de l'exclusion et insertion des personnes vulnérables	2016-11-02 15:35:00	2016-11-02 16:10:00	\N	\N	1	0	\N	\N
130699	CMP	AUTRE	\N	PLEC	\N	PJL Egalité et citoyenneté	PJL Egalité et citoyenneté	2016-10-25 14:05:00	2016-10-25 15:00:00	\N	\N	9	0	\N	\N
134172	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Politique de la Ville	PLF pour 2017 - Politique de la Ville - Anru	2016-11-02 13:30:00	2016-11-02 14:30:00	\N	\N	1	0	\N	\N
134278	MISSION	PLEIN_NON_JO	\N	BREXIT	\N	\N	\N	2016-11-02 16:00:00	2016-11-02 17:40:00	2016-11-02 18:11:45	\N	11	0	\N	\N
134308	COM_PERMANENTE	AUTRE	\N	CAE	\N	\N	\N	2016-11-02 16:35:00	2016-11-02 18:25:00	2018-05-18 15:40:00	2018-05-18 15:40:06	25	0	\N	\N
134355	COM_PERMANENTE	AUTRE	\N	FINC	\N	Communication sur le prélèvement à la source IR - Missions Économie-FACé-Pouvoirs publics	Communication sur le prélèvement à la source IR - Missions Économie-FACé-Pouvoirs publics	2016-11-02 16:00:00	2016-11-02 18:40:00	2016-11-03 10:07:11	2016-11-03 10:28:42	32	0	\N	\N
134395	DELEGATION	AUDRAP	\N	\N	COLTER	RI Evolution des missions des services déconcentrés - Table-ronde	\N	2016-10-11 15:00:00	2016-10-11 17:00:00	\N	\N	2	0	\N	\N
134398	DELEGATION	AUDRAP	\N	\N	COLTER	RI Evolution des missions des services déconcentrés - Audition	\N	2016-11-02 16:00:00	2016-11-02 17:00:00	\N	\N	2	0	\N	\N
134401	DELEGATION	AUDRAP	\N	\N	COLTER	RI Evolution des missions des services déconcentrés - Audition	\N	2016-11-02 17:00:00	2016-11-02 18:00:00	\N	\N	2	0	\N	\N
134704	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2017 - Famille	PLFSS 2017 - Famille	2016-11-03 09:30:00	2016-11-03 11:30:00	\N	\N	2	0	\N	\N
134777	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2017 - Missions APD, Immigration et budget UE	PLF pour 2017 - Missions APD, Immigration et participation de la France au budget UE	2016-11-03 10:35:00	2016-11-03 12:50:00	2016-11-04 10:57:53	2016-11-04 11:32:39	28	0	\N	\N
134827	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF pour 2017 Enseignement scolaire	Enseignement technique agricole	2016-10-18 10:00:00	2016-10-18 11:00:00	\N	\N	1	0	\N	\N
134829	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF pour 2017 Enseignement scolairea	Enseignement technique agricole	2016-10-19 14:15:00	2016-10-19 17:45:00	\N	\N	1	0	\N	\N
134832	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF pour 2017 - Enseignement supérieur et recherche	Enseignement supérieur	2016-10-25 14:30:00	2016-10-25 18:15:00	\N	\N	1	0	\N	\N
134834	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF pour 2017 - Enseignement supérieur et recherchee	Enseignement supérieur	2016-10-27 09:30:00	2016-10-27 11:45:00	\N	\N	1	0	\N	\N
130259	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017  - Transports	PLF pour 2017  - Transports - DGITM	2016-10-19 14:30:00	2016-10-19 15:30:00	\N	\N	1	0	\N	\N
130261	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017  - Transports	PLF pour 2017  - Transports - Direction des affaires maritimes	2016-10-19 17:30:00	2016-10-19 18:30:00	\N	\N	1	0	\N	\N
130263	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017  - Contrôle et exploitation aériens	PLF pour 2017  - Contrôle et exploitation aériens - GIFAS	2016-10-20 11:00:00	2016-10-20 12:00:00	\N	\N	1	0	\N	\N
130265	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017  - Contrôle et exploitation aériens	PLF pour 2017  - Contrôle et exploitation aériens - Air France KLM	2016-10-20 14:00:00	2016-10-20 15:00:00	\N	\N	1	0	\N	\N
130267	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017  - Contrôle et exploitation aériens	PLF pour 2017  - Contrôle et exploitation aériens - ADP	2016-10-20 15:00:00	2016-10-20 16:00:00	\N	\N	1	0	\N	\N
130269	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017  - Contrôle et exploitation aériens	PLF pour 2017  - Contrôle et exploitation aériens - FNAM	2016-10-20 16:00:00	2016-10-20 17:00:00	\N	\N	1	0	\N	\N
130271	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017  - Contrôle et exploitation aériens	PLF pour 2017  - Contrôle et exploitation aériens - DGAC	2016-10-21 11:15:00	2016-10-21 12:15:00	\N	\N	1	0	\N	\N
130334	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Aud. Rapp. CDD PJL CDG EXPRESS	Aud. Rapp. CDD PJL CDG EXPRESS	2016-10-19 08:30:00	2016-10-19 10:00:00	\N	\N	1	0	\N	\N
131573	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2017 - Mission Remboursements et dégrèvements	PLF pour 2017 - Mission Remboursements et dégrèvements	2016-10-26 16:35:00	2016-10-26 17:05:00	2018-05-18 15:37:34	2018-05-18 15:37:43	21	0	\N	\N
132170	DELEGATION	AUCUNE	\N	\N	211	Audition de Mme Laurence Rossignol, ministre des Familles et des Droits des femmes	Audition de Mme Laurence Rossignol, ministre des Familles et des Droits des femmes	2016-10-27 09:30:00	2016-10-27 11:00:00	2016-10-27 13:24:55	2016-10-27 16:16:32	13	0	\N	\N
132781	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Evasion fiscale	Débat	2016-10-27 17:50:00	2016-10-27 19:05:00	\N	\N	22	0	\N	\N
132879	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Recherche et Enseignement supérieur	PLF pour 2017 - Recherche et Enseignement supérieur - Audition INSERM	2016-10-27 18:15:00	2016-10-27 19:15:00	\N	\N	1	0	\N	\N
133012	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2017 - Immigration	\N	2016-10-25 14:30:00	2016-10-25 18:35:00	\N	\N	1	0	\N	\N
133072	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2017 - Avis Asile	\N	2016-10-27 16:45:00	2016-10-27 17:45:00	\N	\N	1	0	\N	\N
133120	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2017	\N	2016-10-26 16:30:00	2016-10-26 18:00:00	\N	\N	1	0	\N	\N
133122	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2017	\N	2016-10-27 16:00:00	2016-10-27 17:00:00	\N	\N	2	0	\N	\N
133126	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	701	\N	\N	Explications de vote sur l'ensemble PPL  Stabilisation droit urbanisme	Explications de vote sur l'ensemble PPL Stabilisation droit urbanisme 	2016-11-02 14:30:00	2016-11-02 15:15:00	\N	\N	276	0	\N	\N
133127	SEANCE_PLENIERE	SCRUSOL	701	\N	\N	Scrutin solennel PPL Stabilisation droit urbanisme	Scrutin solennel PPL Stabilisation droit urbanisme	2016-11-02 15:15:00	2016-11-02 15:55:00	\N	\N	0	0	\N	\N
133128	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Code sport	PJL Code sport	2016-11-02 16:10:00	2016-11-02 17:05:00	\N	\N	57	0	\N	\N
133130	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Transport public particulier personnes	PPL Transport public particulier personnes	2016-11-02 17:05:00	2016-11-02 19:55:00	\N	\N	81	0	\N	\N
133131	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Transport public particulier personnes	PPL Transport public particulier personnes	2016-11-02 21:35:00	2016-11-03 00:05:00	\N	\N	50	0	\N	\N
133182	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2016-11-02 09:50:00	2016-11-02 11:00:00	2018-05-18 15:39:33	2018-05-18 15:39:43	37	0	\N	\N
134273	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2017 - Immigration	\N	2016-11-02 16:30:00	2016-11-02 17:30:00	\N	\N	1	0	\N	\N
134606	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2017 - Avis Protection judiciaire de la jeunesse	\N	2016-11-02 16:00:00	2016-11-02 19:30:00	\N	\N	1	0	\N	\N
134838	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Adaptation du master au système licence-master-doctoral	\N	2016-10-04 09:30:00	2016-10-04 11:00:00	\N	\N	1	0	\N	\N
134846	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Adaptation du master au système licence-master-doctorat	\N	2016-10-05 14:30:00	2016-10-05 17:00:00	\N	\N	1	0	\N	\N
134851	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Adaptation du master au système licence-master-doctorat	\N	2016-11-11 09:30:00	2016-11-11 11:15:00	\N	\N	1	0	\N	\N
134859	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF pour 2017 Enseignement scolaire	Enseignement technique agricole	2016-11-03 09:15:00	2016-11-03 10:00:00	\N	\N	1	0	\N	\N
135106	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion de Commission du 3 novembre 2016	Réunion de Commission du 3 novembre 2016	2016-11-03 08:35:00	2016-11-03 10:00:00	2016-11-03 16:29:35	2016-11-03 17:38:43	14	0	\N	\N
135128	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière	Réunion plénière	2016-12-01 08:30:00	2016-12-01 09:30:00	2016-12-01 12:02:23	2016-12-01 14:21:21	12	0	\N	\N
135429	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF pour 2017 - Enseignement scolaire	PLF pour 2017 - Enseignement scolaire	2016-11-03 10:00:00	2016-11-03 11:15:00	\N	\N	1	0	\N	\N
135431	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF pour 2017 - Enseignement scolaire	PLF pour 2017 - Enseignement scolaire	2016-11-03 14:00:00	2016-11-03 14:45:00	\N	\N	1	0	\N	\N
135447	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Recherche et Enseignement supérieur	PLF pour 2017 - Recherche et Enseignement supérieur - Audition Direction générale de la recherche et de l'innovation	2016-11-02 15:00:00	2016-11-02 16:00:00	\N	\N	1	0	\N	\N
135450	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Recherche et Enseignement supérieur	PLF pour 2017 - Recherche et Enseignement supérieur - Audition IRSTEA	2016-11-03 14:00:00	2016-11-03 15:00:00	\N	\N	1	0	\N	\N
135456	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2017 - Avis Justice judiciaire	\N	2016-10-25 10:10:00	2016-10-25 10:45:00	\N	\N	1	0	\N	\N
135458	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2017 - Avis Justice judiciaire	\N	2016-11-03 10:15:00	2016-11-03 11:30:00	\N	\N	1	0	\N	\N
135460	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2017 - Avis Justice judiciaire	\N	2016-11-03 14:00:00	2016-11-03 15:15:00	\N	\N	2	0	\N	\N
135512	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2017 - Travail et emploi	\N	2016-11-02 19:00:00	2016-11-02 20:00:00	\N	\N	1	0	\N	\N
135514	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2017 - Travail et emploi	\N	2016-11-02 17:00:00	2016-11-02 18:00:00	\N	\N	1	0	\N	\N
135516	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF	\N	2016-11-03 08:45:00	2016-11-03 12:30:00	\N	\N	1	0	\N	\N
135518	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Action extérieure de l'État	PLF pour 2017 - Action extérieure de l'État - Audition France Domaine	2016-11-02 18:00:00	2016-11-02 19:00:00	\N	\N	2	0	\N	\N
135521	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Action extérieure de l'État	PLF pour 2017 - Action extérieure de l'État - Audition Direction des Français de l'étranger	2016-11-03 14:00:00	2016-11-03 15:00:00	\N	\N	2	0	\N	\N
135524	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2017 - Travail et emploi	\N	2016-11-15 14:00:00	2016-11-15 17:30:00	\N	\N	1	0	\N	\N
135526	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2017 - Travail et emploi	\N	2016-11-17 14:00:00	2016-11-17 15:00:00	\N	\N	1	0	\N	\N
135528	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour  2017 - Mildeca	PLF pour  2017 - Mildeca	2016-11-02 16:00:00	2016-11-02 18:00:00	\N	\N	1	0	\N	\N
135734	DELEGATION	AUDRAP	\N	\N	COLTER	RI Evolution des missions des services déconcentrés - Déplacement (Orléans)	\N	2016-11-07 10:00:00	2016-11-07 17:40:00	\N	\N	2	0	\N	\N
135737	DELEGATION	AUDRAP	\N	\N	COLTER	RI - Evolution des missions des services déconcentrés - Déplacement (Limoges)	\N	2016-11-14 10:00:00	2016-11-14 16:20:00	\N	\N	2	0	\N	\N
136919	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de M. Christophe Sirugue	Audition de M. Christophe Sirugue	2016-11-08 17:50:00	2016-11-08 19:20:00	2016-11-09 15:43:15	2016-11-09 16:50:27	21	0	\N	\N
137459	COM_EURO	AUDRAP	\N	AFEU	\N	Aud. Rapp. AFEU 	Audition rapporteur - ARCEP	2016-11-08 14:00:00	2016-11-08 14:50:00	\N	\N	2	0	\N	\N
137571	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2017 - Avis Protection judiciaire de la jeunesse	\N	2016-11-08 14:15:00	2016-11-08 16:20:00	\N	\N	1	0	\N	\N
137583	ETUDES	AUCUNE	\N	\N	\N	Groupe d'études des sénateurs anciens combattants	Groupe d'études des Sénateurs anciens combattants et de la mémoire combattante	2016-11-09 16:15:00	2016-11-09 17:10:00	\N	\N	9	0	\N	928
137703	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Egalité des territoires et Logement	PLF pour 2017 - Egalité des territoires et Logement - Audition DHUP	2016-11-10 11:30:00	2016-11-10 13:10:00	\N	\N	1	0	\N	\N
137776	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017	PLF pour 2017 - Audition Leboncoin	2016-11-10 08:30:00	2016-11-10 09:30:00	\N	\N	1	0	\N	\N
137778	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017	PLF pour 2017 - Entretien avec l'ambassadrice du Panama	2016-11-10 10:30:00	2016-11-10 11:30:00	\N	\N	2	0	\N	\N
138872	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2017	PLFSS 2017	2016-11-16 16:50:00	2016-11-16 18:00:00	\N	\N	108	0	\N	\N
138873	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2017	PLFSS 2017	2016-11-16 21:00:00	2016-11-17 00:40:00	\N	\N	76	0	\N	\N
138874	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Traitement données	Débat Traitement données	2016-11-16 14:30:00	2016-11-16 16:40:00	\N	\N	153	0	\N	\N
139822	DELEGATION	AUDRAP	\N	\N	206	Auditions dans le cadre du rapport sur les biotechnologies	\N	2016-11-22 17:45:00	2016-11-22 19:00:00	\N	\N	2	0	\N	\N
139951	GIA	AUCUNE	\N	\N	\N	Déjeuner avec la chargée d'affaires a.i. de l'Ambassade d'Autriche	\N	2016-11-16 12:30:00	2016-11-16 14:30:00	\N	\N	1	0	579	\N
140332	BUREAU	AUCUNE	\N	\N	\N	Bureau du Sénat	Bureau	2016-11-17 09:00:00	2016-11-17 11:00:00	\N	\N	25	0	\N	\N
140953	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Musées du XXIe siècle	Musées du XXIe siècle	2016-11-15 15:30:00	2016-11-15 17:00:00	\N	\N	14	0	\N	\N
140969	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Francophonie	Groupe de travail Francophonie	2016-11-10 10:30:00	2016-11-10 11:30:00	\N	\N	2	0	\N	\N
140972	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Francophonie	Groupe de travail Francophonie	2016-11-16 17:00:00	2016-11-16 18:00:00	\N	\N	2	0	\N	\N
140975	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Francophonie	Groupe de travail Francophonie	2016-11-16 10:30:00	2016-11-16 12:30:00	\N	\N	2	0	\N	\N
140992	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2017 - Avis Développement des entreprises	\N	2016-11-17 14:15:00	2016-11-17 15:00:00	\N	\N	1	0	\N	\N
141012	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Simplification du droit pour les entreprises	\N	2016-11-23 16:00:00	2016-11-23 16:45:00	\N	\N	1	0	\N	\N
141015	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Simplification du droit pour les entreprises	\N	2016-12-01 10:00:00	2016-12-01 11:00:00	\N	\N	2	0	\N	\N
141021	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Transmission  et reprise d'entreprises	\N	2016-11-29 15:00:00	2016-11-29 16:00:00	\N	\N	2	0	\N	\N
141029	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Violences conjugales	Débat Violences conjugales	2016-11-22 17:45:00	2016-11-22 19:30:00	\N	\N	47	0	\N	\N
141055	QUESTURE	AUCUNE	\N	\N	\N	Questure	\N	2016-11-17 10:40:00	2016-11-17 10:55:00	\N	\N	3	0	\N	\N
141059	DELEGATION	DEPLACEMENT	\N	\N	206	Déplacement au Royaume-Uni dans le cadre du rapport sur l'Intelligence artificielle	\N	2016-12-13 16:00:00	2016-12-16 22:00:00	\N	\N	1	0	\N	\N
141072	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	741	\N	\N	Explications de vote sur l'ensemble du PLFSS 2017	Explications de vote sur l'ensemble du PLFSS 2017	2016-11-22 15:15:00	2016-11-22 16:05:00	\N	\N	301	0	\N	\N
141073	SEANCE_PLENIERE	SCRUSOL	741	\N	\N	Scrutin solennel PLFSS 2017	Scrutin solennel PLFSS 2017	2016-11-22 16:05:00	2016-11-22 16:35:00	\N	\N	0	0	\N	\N
141092	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Territoires de montagne	\N	2016-11-22 09:00:00	2016-11-22 10:00:00	\N	\N	1	0	\N	\N
141094	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Territoires de montagne	\N	2016-11-22 10:00:00	2016-11-22 10:50:00	\N	\N	2	0	\N	\N
141096	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Territoires de montagne	\N	2016-11-23 17:00:00	2016-11-23 17:45:00	\N	\N	3	0	\N	\N
141097	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Territoires de montagne	\N	2016-11-22 14:30:00	2016-11-22 15:00:00	\N	\N	2	0	\N	\N
141100	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Territoires de montagne	\N	2016-11-23 17:50:00	2016-11-23 18:15:00	\N	\N	3	0	\N	\N
141102	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Territoires de montagne	\N	2016-11-29 10:00:00	2016-11-29 11:00:00	\N	\N	1	0	\N	\N
141104	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Territoires de montagne	\N	2016-11-29 14:00:00	2016-11-29 15:00:00	\N	\N	1	0	\N	\N
141108	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Territoires de montagne	\N	2016-11-30 14:00:00	2016-11-30 14:45:00	\N	\N	1	0	\N	\N
141110	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Territoires de montagne	\N	2016-11-30 14:45:00	2016-11-30 15:15:00	\N	\N	1	0	\N	\N
141172	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	MI redressement de la justice	\N	2016-11-10 07:00:00	2016-11-10 22:00:00	\N	\N	3	0	\N	\N
141391	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Transmission  et reprise d'entreprises	\N	2016-12-01 11:00:00	2016-12-01 11:45:00	\N	\N	2	0	\N	\N
141572	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Transmission  et reprise d'entreprises	\N	2016-12-06 15:15:00	2016-12-06 16:15:00	\N	\N	2	0	\N	\N
142732	QUESTURE	AUCUNE	\N	\N	\N	Questure	\N	2016-11-22 14:30:00	2016-11-22 15:10:00	\N	\N	3	0	\N	\N
142759	GIA	AUCUNE	\N	\N	\N	Entretien avec le  Directeur Afrique et Océan indien MAEDI	Entretien avec M. Rémi MARÉCHAUX, Directeur Afrique et Océan indien au ministère des Affaires étrangères	2016-11-23 08:00:00	2016-11-23 09:15:00	\N	\N	6	0	588	\N
142819	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de Mme E. Cosse	Audition de Mme E. Cosse, ministre du logement et de l'habitat durable 	2016-11-22 17:50:00	2016-11-22 19:35:00	2016-11-23 14:15:03	2016-11-23 15:51:49	25	0	\N	\N
142864	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	Suivi de la PAC	GT Suivi de la PAC	2016-11-16 17:00:00	2016-11-16 17:50:00	\N	\N	3	0	\N	\N
142868	MISSION	PLEIN_NON_JO	\N	BREXIT	\N	Audition de M. Philippe Leglise-Costa, SGAE	Audition de M. Philippe Leglise-Costa, Secrétaire général aux affaires européennes	2016-11-23 08:05:00	2016-11-23 09:15:00	\N	\N	9	0	\N	\N
143419	COM_PERMANENTE	AUTRE	\N	CDD	\N	Audition de MM. A. Granjean et G. Mestrallet	Audition de MM. A. Granjean et G. Mestrallet sur les conclusions du prix du carbone	2016-11-23 09:30:00	2016-11-23 10:40:00	2016-11-23 16:15:46	2016-11-23 17:52:11	29	0	\N	\N
143676	BUREAU	AUCUNE	\N	\N	\N	Délégation aux activités internationales et aux GIA	Délégation aux activités internationales et aux GIA	2016-11-23 08:45:00	2016-11-23 09:15:00	\N	\N	5	0	\N	\N
144132	DELEGATION	AUDRAP	\N	\N	PROS	Autorité des marchés financiers	\N	2016-06-21 16:00:00	2016-06-21 17:20:00	\N	\N	0	0	\N	\N
144133	DELEGATION	AUDRAP	\N	\N	PROS	Société du Grand Paris	\N	2016-06-21 14:00:00	2016-06-21 15:45:00	\N	\N	0	0	\N	\N
144152	DELEGATION	AUDRAP	\N	\N	PROS	Société du Grand Paris	\N	2016-06-16 09:15:00	2016-06-16 11:00:00	\N	\N	0	0	\N	\N
144272	COM_EURO	CONTROLE	\N	AFEU	\N	\N	Réunion du 24 novembre 2016	2016-11-24 09:00:00	2016-11-24 10:10:00	2016-11-24 14:10:19	2016-11-24 18:42:34	23	0	\N	\N
144512	DELEGATION	AUDRAP	\N	\N	PROS	Audition	\N	2016-05-10 12:30:00	2016-05-10 14:30:00	\N	\N	1	0	\N	\N
135890	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2017 (Missions PFE et RSR) et PLFSS 2017	PLF pour 2017 (Missions PFE et régimes sociaux de retraite) et PLFSS 2017	2016-11-08 14:15:00	2016-11-08 15:45:00	2016-11-08 17:34:49	2016-11-09 11:46:58	35	0	\N	\N
136745	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2017 - Avis Justice judiciaire	\N	2016-11-08 15:45:00	2016-11-08 16:45:00	\N	\N	1	0	\N	\N
136767	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour  2017 - Mildeca	\N	2016-11-08 14:30:00	2016-11-08 15:30:00	\N	\N	1	0	\N	\N
136769	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour  2017 - Mildeca	\N	2016-11-08 18:00:00	2016-11-08 18:40:00	\N	\N	1	0	\N	\N
137090	GIA	AUCUNE	\N	\N	\N	Petit déjeuner de travail	réunion interne	2016-11-09 08:30:00	2016-11-09 09:40:00	\N	\N	4	0	625	\N
137095	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2017 - Avis Développement des entreprises	\N	2016-11-08 11:00:00	2016-11-08 12:40:00	\N	\N	1	0	\N	\N
137097	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2017 - Avis Développement des entreprises	\N	2016-11-08 14:45:00	2016-11-08 16:30:00	\N	\N	1	0	\N	\N
137256	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2016-11-09 10:05:00	2016-11-09 13:00:00	2016-11-09 15:17:41	2016-11-09 15:19:38	32	0	\N	\N
137353	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Nomination rapporteur PJL Egalité réelle + nominations et examens création 2 comm enquête	\N	2016-11-09 10:10:00	2016-11-09 10:20:00	2016-11-09 15:35:36	2016-11-09 16:53:59	33	1	\N	\N
137566	COM_EURO	AUDRAP	\N	AFEU	\N	Audition simplification	Audition rapporteur simplification et marché unique	2016-11-09 14:40:00	2016-11-09 16:35:00	\N	\N	2	0	\N	\N
137745	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Politique des territoires	PLF pour 2017 - Politique des territoires - Audition Commissariat général à l'égalité des territoires	2016-11-10 10:30:00	2016-11-10 11:30:00	\N	\N	1	0	\N	\N
137755	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Relations avec les collectivités territoriales	PLF pour 2017 - Relations avec les collectivités territoriales - Audition Association des maires de France	2016-11-08 18:00:00	2016-11-08 19:30:00	\N	\N	2	0	\N	\N
137142	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2016-11-09 09:05:00	2016-11-09 10:00:00	2016-11-09 15:17:00	2016-11-09 15:19:43	37	2	\N	\N
137758	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Relations avec les collectivités territoriales	PLF pour 2017 - Relations avec les collectivités territoriales - Audition Régions de France	2016-11-09 15:00:00	2016-11-09 15:50:00	\N	\N	2	0	\N	\N
137761	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Relations avec les collectivités territoriales	PLF pour 2017 - Relations avec les collectivités territoriales - Audition Assemblée des départements de France	2016-11-09 16:00:00	2016-11-09 17:05:00	\N	\N	2	0	\N	\N
137802	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	DSOM	Rencontre maires des Iles Marquises	\N	2016-11-10 14:30:00	2016-11-10 15:45:00	\N	\N	5	0	\N	\N
137837	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2016-11-15 09:35:00	2016-11-15 12:30:00	\N	\N	30	0	\N	\N
137838	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2017	PLFSS 2017	2016-11-15 14:35:00	2016-11-15 19:20:00	\N	\N	148	0	\N	\N
137839	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2017	PLFSS 2017	2016-11-15 21:30:00	2016-11-16 00:15:00	\N	\N	68	0	\N	\N
137883	GIA	AUCUNE	\N	\N	\N	Entretien Députés du Costa Rica	\N	2016-11-14 15:30:00	2016-11-14 16:30:00	\N	\N	1	0	643	\N
137895	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2016-11-15 09:00:00	2016-11-15 10:35:00	2016-11-15 11:00:52	2016-11-15 14:58:20	18	0	\N	\N
138300	DELEGATION	AUDRAP	\N	\N	COLTER	RI-nouvelles technologies au service des CT-ADF	RI-nouvelles technologies au service des CT-ADF	2016-11-15 10:00:00	2016-11-15 11:00:00	\N	\N	2	0	\N	\N
138570	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2017 - Missions "Culture", "GFPRH", "AEE"	PLF pour 2017 - Missions "Culture", "GFPRH", "AEE"	2016-11-15 15:00:00	2016-11-15 17:20:00	2016-11-16 18:25:33	2016-11-16 18:40:09	32	0	\N	\N
138715	GIA	AUCUNE	\N	\N	\N	déplacement	déplacement à Marrakech (COP22)	2016-11-06 14:25:00	2016-11-10 15:20:00	\N	\N	7	0	598	\N
140054	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2016-11-16 18:05:00	2016-11-16 20:00:00	2016-11-17 10:36:08	2016-11-17 11:49:00	29	0	\N	\N
140094	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL montagne	PJL MONTAGNE	2016-11-16 13:30:00	2016-11-16 14:30:00	\N	\N	8	0	\N	\N
140159	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Travail et emploi 	PLF pour 2017 - Travail et emploi - Audition Cabinet de la ministre du travail	2016-11-15 09:30:00	2016-11-15 10:30:00	\N	\N	2	0	\N	\N
140169	ETUDES	AUCUNE	\N	\N	\N	GE économie agricole alimentaire	GE économie agricole alimentaire	2016-11-16 08:00:00	2016-11-16 09:00:00	\N	\N	12	0	\N	919
140852	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Transmission  et reprise d'entreprises	\N	2016-12-01 11:45:00	2016-12-01 12:30:00	\N	\N	2	0	\N	\N
140873	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Simplification du droit pour les entreprises	\N	2016-11-29 15:30:00	2016-11-29 16:15:00	\N	\N	2	0	\N	\N
140932	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Simplification du droit pour les entreprises	\N	2016-12-01 11:00:00	2016-12-01 17:30:00	\N	\N	2	0	\N	\N
142739	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PLF pour 2017 - Justice	\N	2016-11-22 17:50:00	2016-11-22 19:40:00	2016-11-23 09:35:01	2016-11-23 11:10:45	14	0	\N	\N
142763	ETUDES	AUCUNE	\N	\N	\N	\N	\N	2016-11-23 08:00:00	2016-11-23 09:00:00	\N	\N	11	0	\N	910
142932	QUESTURE	AUCUNE	\N	\N	\N	Questure	\N	2016-11-22 17:30:00	2016-11-22 18:40:00	\N	\N	3	0	\N	\N
143346	GIA	AUCUNE	\N	\N	\N	Déjeuner délégation chypriote	Visite de M. Giorgos LILLIKAS, Pdt GIA Chypre-France et S.E.M. Pantias ELIADES	2016-11-23 13:00:00	2016-11-23 14:30:00	\N	\N	8	0	585	\N
143736	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2016-11-23 14:45:00	2016-11-23 17:05:00	2016-11-23 18:17:53	2016-11-24 18:18:36	31	1	\N	\N
143814	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2016-11-23 14:35:00	2016-11-23 15:45:00	2016-11-23 18:35:57	2016-11-24 18:18:39	23	0	\N	\N
144153	COM_PERMANENTE	AUTRE	\N	LOIS	\N	\N	\N	2016-11-24 09:00:00	2016-11-24 10:10:00	2016-11-24 11:46:41	2016-11-24 18:41:41	23	0	\N	\N
144353	GIA	AUCUNE	\N	\N	\N	Entretien avec S. Exc, Mme Carmen Maria Gallardo de Hernandez, ambassadrice d'El Salvador	Entretien avec S. Exc, Mme Carmen Maria Gallardo de Hernandez, ambassadrice d'El Salvador en France	2016-11-22 18:00:00	2016-11-22 19:45:00	\N	\N	2	0	643	\N
144495	GIA	AUCUNE	\N	\N	\N	Entretien avec le nouvel Ambassadeur de France en Thaïlande	Entretien avec M. Gilles GARACHON, nouvel Ambassadeur de France en Thaïlande pour faire le point sur la situation politi	2016-11-23 15:45:00	2016-11-23 16:15:00	\N	\N	4	0	609	\N
144515	DELEGATION	AUDRAP	\N	\N	PROS	Audition ministère de l'intérieur	\N	2016-04-27 14:30:00	2016-04-27 16:10:00	\N	\N	1	0	\N	\N
144591	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Francophonie	\N	2016-11-24 11:00:00	2016-11-24 12:00:00	\N	\N	2	0	\N	\N
144812	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Simplification du droit pour les entreprises	\N	2016-12-01 11:45:00	2016-12-01 12:30:00	\N	\N	2	0	\N	\N
144815	GIA	AUCUNE	\N	\N	\N	Audience	Audience du Vice-Premier ministre du Kirghizistan	2016-11-24 17:15:00	2016-11-24 18:30:00	\N	\N	2	0	556	\N
144818	GIA	AUCUNE	\N	\N	\N	Entretien avec une personnalité extérieure	Entretien avec la directrice régionale de l'IFEAC	2016-11-24 18:30:00	2016-11-24 19:30:00	\N	\N	2	0	556	\N
144821	GIA	AUCUNE	\N	\N	\N	Audience	Audience de l'ambassadeur du Turkménistan	2016-11-25 11:00:00	2016-11-25 11:50:00	\N	\N	1	0	556	\N
144952	GIA	AUCUNE	\N	\N	\N	Déplacement du groupe au Kurdistan irakien	Déplacement du groupe au Kurdistan irakien	2016-11-21 07:00:00	2016-11-25 22:00:00	\N	\N	2	0	615	\N
136772	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2016-11-08 17:50:00	2016-11-08 19:10:00	2016-11-08 19:27:19	2016-11-09 11:46:57	26	0	\N	\N
136823	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition Dépenses fiscales relatives au développement durable	\N	2016-11-08 18:00:00	2016-11-08 19:35:00	2016-11-08 21:13:12	2016-11-09 11:46:56	16	0	\N	\N
136878	MISSION	PLEIN_NON_JO	\N	BREXIT	\N	Audition de M. Sandro Gozi, secrétaire d'Etat italien chargé des affaires européennes	Audition de M. Sandro Gozi, sous secrétaire d'Etat chargé des affaires européennes auprès de la Présidence du Conseil de	2016-11-09 08:00:00	2016-11-10 09:10:00	\N	\N	5	0	\N	\N
137657	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF  pour 2017	\N	2016-11-09 16:00:00	2016-11-09 18:30:00	\N	\N	4	0	\N	\N
137662	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF  pour 2017	\N	2016-11-09 18:30:00	2016-11-09 19:20:00	\N	\N	3	0	\N	\N
137666	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF  pour 2017	\N	2016-11-10 08:00:00	2016-11-10 09:15:00	\N	\N	4	0	\N	\N
138928	COM_PERMANENTE	AUTRE	\N	CAE	\N	\N	\N	2016-11-16 09:35:00	2016-11-16 12:25:00	2016-11-16 15:57:56	2016-11-16 17:27:05	30	0	\N	\N
139115	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2016-11-16 09:35:00	2016-11-16 12:45:00	2016-11-16 15:44:05	2016-11-16 17:27:03	49	0	\N	\N
137705	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Politique des territoires	PLF pour 2017 - Politique des territoires - Audition Business France	2016-11-08 15:15:00	2016-11-08 16:15:00	\N	\N	1	0	\N	\N
138492	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2016-11-15 19:25:00	2016-11-15 20:25:00	2016-11-15 22:51:32	2016-11-16 14:03:42	33	0	\N	\N
138552	GIA	AUCUNE	\N	\N	\N	Rencontre avec le nouvel ambassadeur	\N	2016-11-16 08:15:00	2016-11-16 09:30:00	\N	\N	6	0	619	\N
139332	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2016-11-16 15:05:00	2016-11-16 16:20:00	2016-11-16 17:54:32	2016-11-16 17:59:53	16	0	\N	\N
140090	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Recherche et Enseignement supérieur	PLF pour 2017 - Recherche et Enseignement supérieur - Audition de l'Association des structures de recherche sous contrat	2016-11-15 11:30:00	2016-11-15 12:10:00	\N	\N	1	0	\N	\N
140092	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017	PLF pour 2017 - Rapport Général - Entretien CCI France	2016-11-16 17:00:00	2016-11-16 18:00:00	\N	\N	1	0	\N	\N
140206	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL Emirats arabes unis	\N	2016-11-16 14:00:00	2016-11-16 14:40:00	\N	\N	1	0	\N	\N
140211	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Transmission et reprise d'entreprises	\N	2016-11-30 14:00:00	2016-11-30 15:00:00	\N	\N	1	0	\N	\N
140214	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Transmission et reprise d'entreprises	\N	2016-12-06 14:30:00	2016-12-06 15:15:00	\N	\N	2	0	\N	\N
140217	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Simplification du droit pour les entreprises	\N	2016-11-30 17:45:00	2016-11-30 18:45:00	\N	\N	1	0	\N	\N
140291	COM_PERMANENTE	AUTRE	\N	FINC	\N	Désignation rapporteur pour avis ACCIS- PLF pour 2017 - Santé et Politique des territoires	Rapporteur pour avis ACCIS - PLF pour 2017 - Missions Santé et Politique des territoires	2016-11-17 10:35:00	2016-11-17 12:40:00	2016-11-17 17:58:21	2016-11-18 10:05:30	30	0	\N	\N
140647	COM_EURO	AUDRAP	\N	AFEU	\N	Audiition Perturbateurs endocriniens	Perturbateurs endocriniens	2016-11-10 15:30:00	2016-11-10 16:30:00	\N	\N	2	0	\N	\N
140655	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Perturbateurs endocriniens	Perturbateurs endocriniens	2016-11-16 15:00:00	2016-11-16 16:20:00	\N	\N	2	0	\N	\N
140660	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Perturbateurs endocriniens	Perturbateurs endocriniens	2016-11-17 10:30:00	2016-11-17 12:20:00	\N	\N	2	0	\N	\N
140860	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	\N	2016-11-15 15:30:00	2016-11-15 17:30:00	\N	\N	1	0	\N	\N
140862	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	\N	2016-11-16 14:30:00	2016-11-16 17:30:00	\N	\N	1	0	\N	\N
140864	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	\N	2016-11-16 15:45:00	2016-11-16 17:15:00	\N	\N	1	0	\N	\N
140866	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	\N	2016-11-17 08:30:00	2016-11-17 12:00:00	\N	\N	1	0	\N	\N
140868	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	\N	2016-11-17 14:15:00	2016-11-17 14:45:00	\N	\N	1	0	\N	\N
140877	DELEGATION	AUDRAP	\N	\N	206	Déplacement en Allemagne dans le cadre du PNGMDR 2016-2018	\N	2016-11-27 20:00:00	2016-11-30 22:00:00	\N	\N	2	0	\N	\N
140880	DELEGATION	AUDRAP	\N	\N	206	Déplacement à La Hague dans le cadre du PNGMDR 2016-2018	\N	2016-12-05 12:00:00	2016-12-06 18:00:00	\N	\N	2	0	\N	\N
140946	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Simplification du droit pour les entreprises	\N	2016-11-23 15:00:00	2016-11-23 16:00:00	\N	\N	1	0	\N	\N
140950	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Simplification du droit pour les entreprises	\N	2016-11-29 16:15:00	2016-11-29 17:00:00	\N	\N	2	0	\N	\N
141132	DELEGATION	AUDRAP	\N	\N	PROS	Société du Grand Paris	\N	2016-07-05 16:15:00	2016-07-05 17:30:00	\N	\N	1	0	\N	\N
141220	DELEGATION	AUDRAP	\N	\N	COLTER	RI-nouvelles technologies au service des CT-AMF	\N	2016-11-22 18:30:00	2016-11-22 20:00:00	\N	\N	2	0	\N	\N
142892	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF pour 2017	PLF pour 2017	2016-11-22 17:15:00	2016-11-22 18:00:00	\N	\N	1	0	\N	\N
142894	ETUDES	AUCUNE	\N	\N	\N	section Trufficulture	section Trufficulture	2016-11-23 08:00:00	2016-11-23 09:00:00	\N	\N	22	0	\N	919
143624	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	\N	\N	2016-11-22 18:00:00	2016-11-22 19:00:00	\N	\N	9	0	\N	\N
143652	GIA	AUCUNE	\N	\N	\N	Réception de la délégation du Sénat cambodgien	Réception de la délégation du Sénat cambodgien	2016-11-23 12:15:00	2016-11-23 15:30:00	\N	\N	3	0	577	\N
143686	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2017 - Missions Justice et CCE et Articles non rattachés 2nde partie	PLF pour 2017 - Missions Justice et CCE et Articles non rattachés 2nde partie	2016-11-23 15:40:00	2016-11-23 17:05:00	2016-11-24 12:09:15	2016-11-24 18:18:23	26	0	\N	\N
143897	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Territoires de Montagne	\N	2016-11-22 09:55:00	2016-11-22 09:55:00	\N	\N	1	0	\N	\N
143899	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Territoires de montagne	\N	2016-11-22 14:00:00	2016-11-22 15:40:00	\N	\N	2	0	\N	\N
143902	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Territoires de Montagne	\N	2016-11-22 17:00:00	2016-11-22 19:45:00	\N	\N	1	0	\N	\N
143904	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Territoires de montagne	\N	2016-11-23 14:00:00	2016-11-23 16:15:00	\N	\N	1	0	\N	\N
143909	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Transports scolaires	\N	2016-11-22 09:00:00	2016-11-22 12:30:00	\N	\N	1	0	\N	\N
143911	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Transports scolaires	\N	2016-11-22 14:45:00	2016-11-22 15:30:00	\N	\N	1	0	\N	\N
143913	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Transports scolaires	\N	2016-11-22 17:00:00	2016-11-22 19:30:00	\N	\N	1	0	\N	\N
144052	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2016-11-24 09:00:00	2016-11-24 10:10:00	2016-11-24 14:18:04	2016-11-24 18:41:42	23	0	\N	\N
144332	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	\N	\N	2016-11-23 16:30:00	2016-11-23 18:00:00	\N	\N	1	0	\N	\N
144416	MISSION	PLEIN_NON_JO	\N	BREXIT	\N	Auditions L'Europe de la croissance	Audition de MG. Mestrallet, président de Paris Europlace, N. Baverez, essayiste et  B. Potier, président d'ERT 	2016-11-23 14:30:00	2016-11-23 17:15:00	\N	\N	17	0	\N	\N
144725	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL montagne	PJL MONTAGNE	2016-11-22 09:15:00	2016-11-22 09:45:00	\N	\N	1	0	\N	\N
144729	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL montagne	pjl montagne	2016-11-22 09:45:00	2016-11-22 10:30:00	\N	\N	1	0	\N	\N
144731	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL montagne	pjl montagne	2016-11-22 10:30:00	2016-11-22 11:15:00	\N	\N	1	0	\N	\N
144733	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL montagne	pjl montagne	2016-11-22 13:15:00	2016-11-22 15:00:00	\N	\N	1	0	\N	\N
144735	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL montagne	PJL MONTAGNE	2016-11-22 19:00:00	2016-11-22 20:00:00	\N	\N	1	0	\N	\N
144740	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL MONTAGNE	\N	2016-11-23 08:00:00	2016-11-23 09:00:00	\N	\N	1	0	\N	\N
144742	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL MONTAGNE	pjl montagne	2016-11-23 13:15:00	2016-11-23 14:15:00	\N	\N	1	0	\N	\N
144974	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Extension du délit d'entrave à l'IVG	\N	2016-11-24 10:00:00	2016-11-24 12:00:00	\N	\N	2	0	\N	\N
145012	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF  pour 2017	\N	2016-11-22 15:40:00	2016-11-22 16:40:00	\N	\N	3	0	\N	\N
145016	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL convention sécurité sociale Québec	\N	2016-11-24 10:55:00	2016-11-24 11:50:00	\N	\N	1	0	\N	\N
145032	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Transmission  et reprise d'entreprises	\N	2016-12-07 14:30:00	2016-12-07 15:15:00	\N	\N	2	0	\N	\N
145092	COM_PERMANENTE	AUTRE	\N	FINC	\N	Décret d'avance Financement de dépenses urgentes	Décret d'avance Financement de dépenses urgentes	2016-11-29 09:35:00	2016-11-29 10:10:00	2016-11-29 11:45:21	2016-11-29 17:09:38	22	0	\N	\N
145322	COM_ENQUETE	PLENIERE	\N	ATTEINTES	\N	\N	\N	2016-11-29 13:35:00	2016-11-29 14:00:00	2016-11-30 11:13:26	2016-11-30 16:26:35	12	0	\N	\N
145352	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Égalité réelle outre-mer	\N	2016-11-29 14:30:00	2016-11-29 15:20:00	\N	\N	1	0	\N	\N
135565	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL liaison ferroviaire Paris aéroport Charles de Gaulle 	PJL liaison ferroviaire Paris aéroport Charles de Gaulle 	2016-11-07 15:05:00	2016-11-07 17:55:00	\N	\N	35	0	\N	\N
135566	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL liaison ferroviaire Paris aéroport Charles de Gaulle 	PJL liaison ferroviaire Paris aéroport Charles de Gaulle 	2016-11-07 21:05:00	2016-11-07 23:55:00	\N	\N	0	0	\N	\N
135567	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Statut Paris aménagement métropolitain	PJL Statut Paris aménagement métropolitain	2016-11-07 18:05:00	2016-11-07 19:30:00	\N	\N	24	0	\N	\N
135568	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Statut Paris aménagement métropolitain	PJL Statut Paris aménagement métropolitain	2016-11-07 21:30:00	2016-11-08 00:30:00	\N	\N	26	0	\N	\N
137791	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017	PLF pour 2017 - Audition APCMA	2016-11-09 17:00:00	2016-11-09 18:00:00	\N	\N	1	0	\N	\N
137958	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2016-11-15 09:30:00	2016-11-15 10:45:00	2016-11-15 11:34:41	2016-11-15 15:28:37	32	0	\N	\N
138360	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF pour 2017 - Culture	\N	2016-11-15 16:00:00	2016-11-15 17:15:00	\N	\N	1	0	\N	\N
138661	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PLF 2017	\N	2016-11-15 18:35:00	2016-11-15 19:55:00	2016-11-18 15:33:13	2016-11-18 15:33:14	33	0	\N	\N
139236	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2017	PLFSS 2017	2016-11-17 10:30:00	2016-11-17 13:20:00	\N	\N	95	0	\N	\N
139237	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2016-11-17 15:00:00	2016-11-17 16:00:00	\N	\N	238	0	\N	\N
139238	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2017	PLFSS 2017	2016-11-17 16:15:00	2016-11-17 19:25:00	\N	\N	69	0	\N	\N
139239	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2017	PLFSS 2017	2016-11-17 21:00:00	2016-11-18 00:45:00	\N	\N	24	0	\N	\N
139240	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2017 - Avis Développement des entreprises	\N	2016-11-16 14:15:00	2016-11-16 15:00:00	\N	\N	1	0	\N	\N
139242	COM_PERMANENTE	AUTRE	\N	CDD	\N	\N	\N	2016-11-16 09:05:00	2016-11-16 10:15:00	2016-11-16 17:58:05	2016-11-16 17:59:57	27	0	\N	\N
139393	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2017 - Mission Égalité des territoires	PLF 2017 - Mission Égalité des territoires	2016-11-16 14:35:00	2016-11-16 16:35:00	\N	\N	1	0	\N	\N
140231	DELEGATION	AUCUNE	\N	\N	211	Audition de M. Édouard Durand, magistrat, membre du HCE/fh	Audition de M. Édouard Durand, magistrat, membre du HCE/fh	2016-11-17 08:30:00	2016-11-17 10:10:00	2016-11-17 12:11:44	2016-11-17 15:31:43	9	0	\N	\N
140255	DELEGATION	AUDRAP	\N	\N	COLTER	RI_prévention radicalisation et collectivités	\N	2016-11-17 10:30:00	2016-11-17 12:10:00	\N	\N	2	0	\N	\N
144213	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Déit d'entrave à l'interruption volontaire de grossesse	\N	2016-11-23 14:00:00	2016-11-23 14:40:00	\N	\N	1	0	\N	\N
144312	MISSION	DEPLACEMENT	\N	BREXIT	\N	Rencontres au Parlement européen et à la Cour européenne des droits de l'Homme	\N	2016-11-21 16:00:00	2016-11-22 11:45:00	\N	\N	5	0	\N	\N
144464	DELEGATION	AUDRAP	\N	\N	COLTER	RI_prévention radicalisation et collectivités	\N	2016-11-23 17:00:00	2016-11-23 18:25:00	\N	\N	2	0	\N	\N
144517	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ambassadeur du Soudan à Paris	Entretien avec S.E. M. Daffa-Alla ELHAG ALI OSMAN, Ambassadeur du Soudan à Paris	2016-11-24 08:30:00	2016-11-24 09:15:00	\N	\N	3	0	588	\N
144692	DELEGATION	AUDRAP	\N	\N	206	Auditions dans le cadre du rapport sur l'Intelligence artificielle	\N	2016-11-24 15:00:00	2016-11-24 18:45:00	\N	\N	1	0	\N	\N
144693	DELEGATION	AUDRAP	\N	\N	206	Auditions rapporteur dans le cadre du rapport sur l'intelligence artificielle	\N	2016-11-28 14:15:00	2016-11-28 17:30:00	\N	\N	1	0	\N	\N
144698	DELEGATION	AUDRAP	\N	\N	206	Auditions dans le cadre du rapport sur l'Intelligence artificielle	\N	2016-11-30 10:00:00	2016-11-30 12:00:00	\N	\N	2	0	\N	\N
144712	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	\N	2016-11-22 14:30:00	2016-11-22 16:45:00	\N	\N	1	0	\N	\N
144714	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	\N	2016-11-22 17:45:00	2016-11-22 19:45:00	\N	\N	1	0	\N	\N
144716	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	\N	2016-11-23 15:30:00	2016-11-23 16:00:00	\N	\N	1	0	\N	\N
144718	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	\N	2016-11-24 10:00:00	2016-11-24 10:30:00	\N	\N	1	0	\N	\N
144720	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	\N	2016-11-23 18:30:00	2016-11-23 19:15:00	\N	\N	1	0	\N	\N
144722	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	Aménagement du territoire	\N	2016-11-24 11:00:00	2016-11-24 12:00:00	\N	\N	2	0	\N	\N
144727	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	\N	\N	2016-11-22 14:30:00	2016-11-22 15:30:00	\N	\N	1	0	\N	\N
144737	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Simplification du droit pour les entreprises	\N	2016-12-06 15:00:00	2016-12-06 15:45:00	\N	\N	2	0	\N	\N
144772	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Simplification du droit pour les entreprises	\N	2016-12-06 17:15:00	2016-12-06 18:00:00	\N	\N	2	0	\N	\N
145414	GIA	AUCUNE	\N	\N	\N	Accueil de M. PRAK Sokhonn, Ministre des affaires étrangères du Cambodge	Accueil de M. PRAK Sokhonn, Ministre des affaires étrangères du Cambodge	2016-11-29 12:30:00	2016-11-29 14:00:00	\N	\N	2	0	577	\N
145452	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Extension du délit d'entrave à l'IVG	\N	2016-11-28 14:00:00	2016-11-28 15:15:00	\N	\N	3	0	\N	\N
145512	COM_PERMANENTE	AUTRE	\N	LOIS	\N	\N	\N	2016-11-29 17:40:00	2016-11-29 18:30:00	2016-11-30 10:33:08	2016-11-30 16:10:35	8	0	\N	\N
145522	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	781	\N	\N	Explications de vote sur la motion PLF 2017	Explications de vote sur la motion PLF 2017	2016-11-30 15:00:00	2016-11-30 16:55:00	\N	\N	193	0	\N	\N
145523	SEANCE_PLENIERE	SCRUSOL	781	\N	\N	Scrutin solennel	Scrutin solennel	2016-11-30 16:30:00	2016-11-30 17:30:00	\N	\N	0	0	\N	\N
145532	GIA	AUCUNE	\N	\N	\N	Medecins du Monde et Première Urgence Internationale	Entretien avec M. Léo GOUPIL-BARBIER, coordinateur plaidoyer de Médecins du Monde ¿ France (Mission Palestine) et Mme Pa	2016-11-30 09:00:00	2016-11-30 09:40:00	\N	\N	5	0	632	\N
145538	ETUDES	AUCUNE	\N	\N	\N	\N	\N	2016-11-30 08:30:00	2016-11-30 09:30:00	\N	\N	6	0	\N	922
145545	GIA	AUCUNE	\N	\N	\N	Ambassadeur de Pologne en France	Entretien avec S.E. M. Dariusz WI¿NIEWSKI, Ambassadeur de Pologne en France	2016-11-30 08:15:00	2016-11-30 09:45:00	\N	\N	5	0	600	\N
137747	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL montagne	PJL montagne	2016-11-09 18:30:00	2016-11-09 20:30:00	\N	\N	3	0	\N	\N
138773	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen articles première partie du PLF pour 2017	Examen articles première partie du PLF pour 2017 - Tome II du rapport général	2016-11-16 09:30:00	2016-11-16 11:15:00	2016-11-17 09:17:20	2016-11-17 11:49:05	39	0	\N	\N
145662	COM_PERMANENTE	AUTRE	\N	CDD	\N	Audition de M. Jean-Marc Janaillac	Audition de M. Jean-Marc Janaillac, président-directeur général du groupe Air France-KLM 	2016-11-30 09:35:00	2016-11-30 10:50:00	2016-11-30 16:07:04	2016-11-30 16:13:25	27	0	\N	\N
145712	COM_EURO	AUDRAP	\N	AFEU	\N	Etiquetage et gaspillage alimentaire	Audition rapporteur - Etiquetage et gaspillage alimentaire	2016-11-29 09:00:00	2016-11-29 12:15:00	\N	\N	1	0	\N	\N
145714	COM_EURO	AUDRAP	\N	AFEU	\N	Etiquetage et gaspillage alimentaire	Audition rapporteur - Etiquetage et gaspillage alimentaire	2016-11-29 10:15:00	2016-11-29 12:15:00	\N	\N	1	0	\N	\N
145716	COM_EURO	AUDRAP	\N	AFEU	\N	Etiquetage et gaspillage alimentaire	Audition rapporteur - Etiquetage et gaspillage alimentaire	2016-11-29 14:00:00	2016-11-29 15:00:00	\N	\N	1	0	\N	\N
145718	COM_EURO	AUDRAP	\N	AFEU	\N	Etiquetage et gaspillage alimentaire	Audition rapporteur - Etiquetage et gaspillage alimentaire	2016-11-30 08:30:00	2016-11-30 09:45:00	\N	\N	2	0	\N	\N
145732	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2016-11-30 09:30:00	2016-11-30 10:45:00	2016-11-30 15:11:58	2016-11-30 16:13:27	40	0	\N	\N
145949	COM_EURO	AUDRAP	\N	AFEU	\N	Perturbateurs endocriniens	Audition rapporteur - Perturbateurs endocriniens	2016-11-24 10:30:00	2016-11-24 12:50:00	\N	\N	2	0	\N	\N
145963	COM_EURO	AUDRAP	\N	AFEU	\N	Audiition Perturbateurs endocriniens	Audition rapporteur - Perturbateurs endocriniens	2016-11-24 15:00:00	2016-11-24 16:00:00	\N	\N	1	0	\N	\N
146035	QUESTURE	AUCUNE	\N	\N	\N	Questure	\N	2016-11-29 14:50:00	2016-11-29 16:50:00	\N	\N	3	0	\N	\N
146052	QUESTURE	AUCUNE	\N	\N	\N	Commission de concertation	Commission de concertation	2016-11-30 10:00:00	2016-11-30 12:00:00	\N	\N	3	0	\N	\N
146097	ETUDES	AUCUNE	\N	\N	\N	\N	\N	2016-11-30 08:30:00	2016-11-30 09:30:00	\N	\N	8	0	\N	908
135557	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Recherche et Enseignement supérieur	PLF pour 2017 - Recherche et Enseignement supérieur -  Ministère éducation, enseignement supérieur et recherche	2016-11-03 09:00:00	2016-11-03 10:00:00	\N	\N	1	0	\N	\N
135559	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Sécurités - Police et gendarmerie	PLF pour 2017 - Sécurités - Police et gendarmerie - Conseil de la Fonction Militaire Gendarmerie (CFMG)	2016-11-03 17:00:00	2016-11-03 18:30:00	\N	\N	1	0	\N	\N
135561	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Sécurités - Police et gendarmerie	PLF pour 2017 - Sécurités - Police et gendarmerie - CFE-CGC	2016-11-04 10:00:00	2016-11-04 11:30:00	\N	\N	1	0	\N	\N
135563	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Sécurités - Police et gendarmerie	PLF pour 2017 - Sécurités - Police et gendarmerie- Police natinale	2016-11-04 15:00:00	2016-11-04 16:15:00	\N	\N	1	0	\N	\N
135613	COM_PERMANENTE	AUTRE	\N	CDD	\N	\N	\N	2016-11-07 14:30:00	2016-11-07 14:45:00	2016-11-08 14:28:52	2016-11-08 14:29:33	7	0	\N	\N
135637	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Statut de Paris	\N	2016-11-07 14:30:00	2016-11-07 16:00:00	2016-11-07 17:02:22	2016-11-07 17:32:57	7	0	\N	\N
135740	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2017 - Egalité des territoires	PLF 2017 - Egalité des territoires	2016-11-08 10:05:00	2016-11-08 11:55:00	\N	\N	1	0	\N	\N
135754	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions AGTE 	Auditions avis budgétaire AGTE	2016-11-08 09:30:00	2016-11-08 11:35:00	\N	\N	1	0	\N	\N
135769	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions Sécurité civile	Auditions avis budgétaire Sécurité civile	2016-11-09 14:30:00	2016-11-09 17:30:00	\N	\N	1	0	\N	\N
136852	ETUDES	AUCUNE	\N	\N	\N	\N	\N	2016-11-09 08:00:00	2016-11-09 09:15:00	\N	\N	25	0	\N	907
136887	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2017 - Conseil et contrôle de l'Etat	\N	2016-11-08 14:20:00	2016-11-08 19:15:00	\N	\N	1	0	\N	\N
136898	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Francophonie	\N	2016-06-07 14:30:00	2016-06-07 16:30:00	\N	\N	2	0	\N	\N
136901	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Francophonie	\N	2016-06-29 14:30:00	2016-06-29 17:30:00	\N	\N	2	0	\N	\N
136904	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Francophonie	\N	2016-07-05 16:30:00	2016-07-05 17:30:00	\N	\N	2	0	\N	\N
136907	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Francophonie	\N	2016-07-06 14:30:00	2016-07-06 16:30:00	\N	\N	2	0	\N	\N
136910	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Francophonie	\N	2016-09-20 15:00:00	2016-09-20 17:00:00	\N	\N	2	0	\N	\N
136913	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Francophonie	\N	2016-09-22 11:00:00	2016-09-22 12:00:00	\N	\N	2	0	\N	\N
136916	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT	\N	2016-09-28 15:00:00	2016-09-28 16:00:00	\N	\N	2	0	\N	\N
137029	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Francophonie	\N	2016-09-29 10:30:00	2016-09-29 11:30:00	\N	\N	2	0	\N	\N
137479	DELEGATION	AUDRAP	\N	\N	206	Auditions dans le cadre du rapport sur l'Intelligence artificielle	\N	2016-11-09 14:30:00	2016-11-09 21:30:00	\N	\N	1	0	\N	\N
137517	DELEGATION	AUCUNE	\N	\N	206	Présentation par Mme Geneviève Fioraso, députée, de son rapport  "Open Space"	Présentation par Mme Geneviève Fioraso, députée, de son rapport au Premier ministre "Open space"	2016-11-15 17:15:00	2016-11-15 19:00:00	2016-11-16 11:30:23	2016-11-16 14:01:40	8	0	\N	\N
137532	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2017 - Missions "Recherche et enseignement supérieur" et "Outre-mer"	PLF pour 2017 - Missions "Recherche et enseignement supérieur" et "Outre-mer"	2016-11-09 14:35:00	2016-11-09 16:10:00	2016-11-10 15:13:28	2016-11-10 16:30:56	22	0	\N	\N
137708	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF pour 2017	PLF pour 2017	2016-11-08 09:30:00	2016-11-08 11:00:00	\N	\N	2	0	\N	\N
137714	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF pour 2017	PLF pour 2017	2016-11-08 14:30:00	2016-11-08 17:00:00	\N	\N	2	0	\N	\N
137721	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF pour 2017	PLF pour 2017	2016-11-09 14:30:00	2016-11-09 15:30:00	\N	\N	1	0	\N	\N
137734	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF pour 2017	PLF pour 2017	2016-11-08 19:00:00	2016-11-08 20:20:00	\N	\N	2	0	\N	\N
137737	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF pour 2017	PLF pour 2017	2016-11-09 15:00:00	2016-11-09 16:15:00	\N	\N	2	0	\N	\N
137740	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL montagne	PJL montagne	2016-11-09 15:00:00	2016-11-09 16:30:00	\N	\N	4	0	\N	\N
145622	COM_PERMANENTE	AUTRE	\N	CAE	\N	PLF 2017, examen sur les crédits de la mission "Économie" 	PLF 2017, examen du rapport sur les crédits de la mission "Économie	2016-11-30 09:30:00	2016-11-30 11:25:00	2016-11-30 14:20:29	2016-11-30 16:13:26	32	0	\N	\N
145790	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2016-11-30 10:45:00	2016-11-30 12:10:00	2016-11-30 15:11:30	2016-11-30 16:13:23	39	0	\N	\N
137751	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	\N	\N	2016-11-10 09:45:00	2016-11-10 11:00:00	\N	\N	3	0	\N	\N
137772	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017	PLF pour 2017 - Agriculture - Audition Meuneries	2016-11-08 08:30:00	2016-11-08 09:30:00	\N	\N	0	0	\N	\N
137774	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Agriculture	PLF pour 2017 - Agriculture - Audition ONF	2016-11-10 09:15:00	2016-11-10 10:20:00	\N	\N	1	0	\N	\N
137812	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2017 - Avis Asile	\N	2016-11-10 14:30:00	2016-11-10 15:15:00	\N	\N	1	0	\N	\N
137866	GIA	AUCUNE	\N	\N	\N	Remise du prix annuel de l'association "Perspectives Ukrainiennes"	Remise du prix Grégoire Orlyk de l'association Perspectives Ukrainiennes	2016-11-07 18:00:00	2016-11-07 20:30:00	\N	\N	1	0	530	\N
138072	COM_PERMANENTE	AUTRE	\N	CAE	\N	\N	\N	2016-11-15 09:30:00	2016-11-15 10:35:00	2016-11-15 12:23:59	2016-11-15 14:58:21	21	0	\N	\N
138132	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	\N	\N	2016-11-10 14:30:00	2016-11-10 16:45:00	\N	\N	1	0	\N	\N
138231	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PLFSS pour 2017	\N	2016-11-15 13:35:00	2016-11-15 14:20:00	2016-11-15 16:42:40	2016-11-15 17:14:05	34	0	\N	\N
138559	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2017 - Audition du ministre de l'intérieur	PLF pour 2017 - Audition du ministre de l'intérieur	2016-11-15 18:35:00	2016-11-15 19:55:00	2016-11-17 16:30:09	2016-11-17 16:30:21	33	0	\N	\N
138659	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2017 - Relations avec les collectivités territoriales	\N	2016-11-15 09:30:00	2016-11-15 11:30:00	\N	\N	1	0	\N	\N
140831	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF pour 2017 - Audiovisuel extérieur	Avis sur les crédits relatifs à l'audiovisuel extérieur (PLF 2017)	2016-11-10 15:30:00	2016-11-10 17:30:00	\N	\N	1	0	\N	\N
140833	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Avis crédits Sport (PLF 2017)	Avis sur les crédits relatifs au sport (PLF 2017)	2016-11-16 14:00:00	2016-11-16 15:00:00	\N	\N	1	0	\N	\N
140835	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Avis crédits Audiovisuel (PLF 2017)	Avis sur les crédits relatifs à l'audiovisuel (PLF 2017)	2016-11-16 16:30:00	2016-11-16 18:00:00	\N	\N	1	0	\N	\N
140837	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Avis crédits Audiovisuel (PLF 2017)	Avis sur les crédits relatifs à l'audiovisuel (PLF 2017)	2016-11-17 11:00:00	2016-11-17 12:30:00	\N	\N	1	0	\N	\N
140840	COM_PERMANENTE	AUTRE	\N	CDD	\N	\N	\N	2016-11-17 16:15:00	2016-11-17 17:50:00	2016-11-18 14:31:10	2016-11-18 14:54:54	10	0	\N	\N
141030	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2016-11-22 16:45:00	2016-11-22 17:35:00	\N	\N	303	0	\N	\N
141031	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR RUP	PPR RUP	2016-11-22 21:30:00	2016-11-22 23:30:00	\N	\N	40	0	\N	\N
141032	DELEGATION	AUCUNE	\N	\N	COLTER	Table ronde "Nouveaux territoires de projets : PETR- Pôles métropolitains"	\N	2016-12-01 08:30:00	2016-12-01 10:40:00	2016-12-01 15:26:16	2016-12-01 17:37:42	17	0	\N	\N
141034	DELEGATION	AUCUNE	\N	\N	COLTER	Rapport "Évolution des missions de l'État au profit des collectivités territoriales"	\N	2016-12-01 13:00:00	2016-12-01 14:30:00	2016-12-01 15:48:51	2016-12-01 17:37:45	17	0	\N	\N
141035	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Simplification du droit pour les entreprises	\N	2016-11-23 14:15:00	2016-11-23 15:00:00	\N	\N	1	0	\N	\N
141463	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2017 - Désignation rapporteurs pour avis et Mission RCT	PLF pour 2017 - Missions RCT et Travail et Emploi	2016-11-22 14:00:00	2016-11-22 15:10:00	2016-11-23 14:36:33	2016-11-23 15:51:47	34	0	\N	\N
142761	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2017 - Missions Suite RCT et Travail et emploi	PLF pour 2017 - Missions Suite RCT et Travail et emploi	2016-11-22 17:45:00	2016-11-22 18:40:00	2016-11-24 12:06:51	2016-11-24 18:14:34	24	0	\N	\N
135552	GIA	AUCUNE	\N	\N	\N	Visite nouvel ambassadeur Botswana	Visite de S.E. M. Pierre VOILLERY, nouvel Ambassadeur de France au Botswana	2016-11-03 16:30:00	2016-11-03 17:30:00	\N	\N	1	0	646	\N
135554	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Agriculture	PLF pour 2017 - Agriculture - Ministère de l'agriculture	2016-11-03 16:30:00	2016-11-03 18:20:00	\N	\N	2	0	\N	\N
135574	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Statut de Paris	PJL Statut de Paris	2016-11-08 14:35:00	2016-11-08 16:45:00	\N	\N	116	0	\N	\N
135575	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2016-11-08 16:45:00	2016-11-08 17:35:00	\N	\N	282	0	\N	\N
135578	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Statut de Paris	PJL Statut de Paris	2016-11-08 17:45:00	2016-11-08 19:55:00	\N	\N	74	0	\N	\N
135784	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	\N	\N	2016-10-07 15:30:00	2016-10-07 16:30:00	\N	\N	3	0	\N	\N
135791	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	\N	\N	2016-10-20 08:00:00	2016-10-20 11:30:00	\N	\N	3	0	\N	\N
136726	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2017	PLF pour 2017 Anciens combattants	2016-11-21 09:00:00	2016-11-21 10:00:00	\N	\N	1	0	\N	\N
136731	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2017	PLF pour 2017 Anciens combattants	2016-11-21 10:00:00	2016-11-21 11:00:00	\N	\N	1	0	\N	\N
137475	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2017 - Immigration	\N	2016-11-09 14:30:00	2016-11-09 15:40:00	\N	\N	1	0	\N	\N
137553	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2017 - Avis Développement des entreprises	\N	2016-11-09 14:00:00	2016-11-09 15:55:00	\N	\N	1	0	\N	\N
137569	DELEGATION	AUCUNE	\N	\N	COLTER	Table ronde "La réforme territoriale et la politique de décentralisation culturelle"	\N	2016-11-17 09:00:00	2016-11-17 10:30:00	2016-11-17 11:14:08	2016-11-17 11:49:52	8	0	\N	\N
137675	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2017 - Avis Asile	\N	2016-11-10 09:30:00	2016-11-10 10:30:00	\N	\N	1	0	\N	\N
137677	COM_EURO	CONTROLE	\N	AFEU	\N	\N	Réunion du 10 novembre 2016	2016-11-10 09:05:00	2016-11-10 11:25:00	2016-11-10 12:28:11	2016-11-10 14:43:52	17	0	\N	\N
137783	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Défense  - Déplacement	PLF pour 2017 - Défense  - Déplacement - EMAT	2016-11-10 08:00:00	2016-11-10 09:30:00	\N	\N	1	0	\N	\N
137785	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Défense	PLF pour 2017 - Défense - Audition Etat-major de la marine	2016-11-10 10:30:00	2016-11-10 11:30:00	\N	\N	1	0	\N	\N
137787	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Défense	PLF pour 2017 - Défense - Audition Cabinet du ministre de la défense	2016-11-10 14:30:00	2016-11-10 16:00:00	\N	\N	1	0	\N	\N
137793	GIA	AUCUNE	\N	\N	\N	\N	\N	2016-11-08 12:45:00	2016-11-08 14:00:00	\N	\N	11	0	\N	\N
137956	COM_PERMANENTE	AUTRE	\N	LOIS	\N	\N	\N	2016-11-15 09:10:00	2016-11-15 10:40:00	2016-11-15 15:24:12	2016-11-15 15:28:05	44	0	\N	\N
138647	MISSION	PLEIN_NON_JO	\N	BREXIT	\N	Audition du Général Patrick de Rousiers, Conseiller spécial de Mme Mogherini	Audition du Général Patrick de Rousiers, Conseiller spécial de Mme Mogherini	2016-11-16 08:00:00	2016-11-16 09:15:00	\N	\N	8	0	\N	\N
138699	ETUDES	AUCUNE	\N	\N	\N	\N	\N	2016-11-16 08:00:00	2016-11-16 09:00:00	\N	\N	10	0	\N	922
150195	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	\N	2016-12-08 10:00:00	2016-12-08 11:45:00	\N	\N	1	0	\N	\N
138814	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2016-11-16 10:00:00	2016-11-16 11:20:00	2016-11-16 13:25:39	2016-11-16 17:27:02	48	0	\N	\N
139174	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2016-11-16 10:55:00	2016-11-16 12:15:00	2016-11-16 16:42:15	2016-11-16 17:26:58	48	1	\N	\N
139787	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2017 - Missions Sécurités et Défense	PLF pour 2017 - Missions Sécurités et Défense	2016-11-16 15:00:00	2016-11-16 16:55:00	2016-11-17 16:34:41	2016-11-17 16:35:13	30	0	\N	\N
139953	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation de l'Association France-Autriche	Accueil d'une délégation de l'Association France-Autriche	2016-11-15 18:15:00	2016-11-15 20:15:00	\N	\N	1	0	579	\N
139955	GIA	AUCUNE	\N	\N	\N	Déjeuner de travail	Déjeuner de travail avec le ministre des Affaires étrangères d'Estonie	2016-11-16 12:45:00	2016-11-16 14:15:00	\N	\N	8	0	616	\N
139964	GIA	AUCUNE	\N	\N	\N	Réunion de travail	Compte rendu déplacement Egypte 	2016-11-15 17:30:00	2016-11-15 18:05:00	\N	\N	1	0	617	\N
139966	GIA	AUCUNE	\N	\N	\N	Réunion de travail	Compte rendu déplacement Jordanie 	2016-11-15 16:00:00	2016-11-15 17:30:00	\N	\N	2	0	659	\N
140148	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Politique des territoires	PLF pour 2017 - Politique des territoires - Audition du Secrétariat général du ministère de l'intérieur	2016-11-15 16:00:00	2016-11-15 16:45:00	\N	\N	1	0	\N	\N
140220	GIA	AUCUNE	\N	\N	\N	petit déjeuner	petit déjeuner avec l'ambassadrice d'Israël 	2016-11-17 08:30:00	2016-11-17 09:30:00	\N	\N	5	0	595	\N
140258	COM_EURO	CONTROLE	\N	AFEU	\N	\N	\N	2016-11-17 08:30:00	2016-11-17 10:55:00	2016-11-17 12:37:56	2016-11-17 15:32:20	17	0	\N	\N
140679	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI redressement de la justice	\N	2016-11-16 16:30:00	2016-11-16 18:00:00	\N	\N	3	0	\N	\N
140683	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	\N	2016-11-17 09:00:00	2016-11-17 13:15:00	\N	\N	3	0	\N	\N
140939	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Rapport général	PLF pour 2017 - Rapport général - FEDOM	2016-11-17 09:00:00	2016-11-17 10:30:00	\N	\N	0	0	\N	\N
140942	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Relations avec les collectivités territoriales	PLF pour 2017 - Relations avec les collectivités territoriales - Cabinet de M. Baylet	2016-11-17 08:15:00	2016-11-17 09:20:00	\N	\N	0	0	\N	\N
141018	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Francophonie	\N	2016-11-17 10:30:00	2016-11-17 12:30:00	\N	\N	2	0	\N	\N
141024	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Montagne	\N	2016-11-16 13:30:00	2016-11-16 19:30:00	\N	\N	4	0	\N	\N
143032	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Avenir transport ferroviaire	Débat Avenir transport ferroviaire	2016-11-23 14:30:00	2016-11-23 16:30:00	\N	\N	81	0	\N	\N
143033	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Sauvegarde et valorisation filière élevage	Débat Sauvegarde et valorisation filière élevage	2016-11-23 16:30:00	2016-11-23 18:20:00	\N	\N	49	0	\N	\N
143034	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Collectivités territoriales et coopération outre-mer	PPL Collectivités territoriales et coopération outre-mer	2016-11-23 18:30:00	2016-11-23 20:10:00	\N	\N	43	0	\N	\N
143036	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2017	PLF 2017	2016-11-24 15:00:00	2016-11-24 19:00:00	\N	\N	81	0	\N	\N
143380	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Extension du délit d'entrave à l'IVG	\N	2016-11-22 17:00:00	2016-11-22 18:00:00	\N	\N	1	0	\N	\N
143932	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de Mme Ségolène Royal	Audition de Mme Ségolène Royal, ministre de l'environnement, de l'Energie et de la Mer 	2016-11-23 17:05:00	2016-11-23 18:55:00	2018-05-18 15:43:02	2018-05-18 15:43:12	29	0	\N	\N
143987	COM_PERMANENTE	AUTRE	\N	CDD	\N	Audition de Mme Ségolène Royal	Audition de Mme Ségolène Royal, ministre de l'environnement, de l'Energie et de la Mer 	2016-11-23 17:05:00	2016-11-23 18:55:00	2018-05-18 15:42:41	2018-05-18 15:42:49	29	0	\N	\N
144212	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2017 - CMP - Examen définitif de l'équilibre	PLF pour 2017 - CMP - Examen définitif de l'équilibre	2016-11-24 09:35:00	2016-11-24 10:15:00	2018-05-18 15:43:28	2018-05-18 15:43:35	31	0	\N	\N
144347	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Simplification du droit pour les entreprises	\N	2016-12-06 16:30:00	2016-12-06 17:15:00	\N	\N	2	0	\N	\N
144350	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Simplification du droit pour les entreprises	\N	2016-12-06 14:00:00	2016-12-06 15:00:00	\N	\N	2	0	\N	\N
144514	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2017	PLF 2017	2016-11-29 14:35:00	2016-11-29 19:50:00	\N	\N	169	0	\N	\N
144744	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI redressement de la justice	\N	2016-11-23 15:00:00	2016-11-23 15:45:00	\N	\N	2	0	\N	\N
144747	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	MI redressement de la justice	\N	2016-11-24 07:00:00	2016-11-24 21:00:00	\N	\N	2	0	\N	\N
144752	GIA	AUCUNE	\N	\N	\N	Entretien avec la directrice de l'UNRWA	Entretien avec Mme Françoise VANNI, nouvelle directrice des relations extérieures de l'UNRWA (Office de secours aux réfu	2016-11-24 11:00:00	2016-11-24 12:00:00	\N	\N	1	0	632	\N
135572	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF pour 2017	\N	2016-11-02 15:30:00	2016-11-02 17:30:00	\N	\N	1	0	\N	\N
135576	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF pour 	\N	2016-11-03 09:00:00	2016-11-03 11:00:00	\N	\N	1	0	\N	\N
135580	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF pour 2017	\N	2016-11-03 11:20:00	2016-11-03 13:00:00	\N	\N	1	0	\N	\N
135582	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF poru 2017	\N	2016-11-03 16:00:00	2016-11-03 16:30:00	\N	\N	1	0	\N	\N
135584	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF pour 2017	\N	2016-11-03 14:45:00	2016-11-03 15:30:00	\N	\N	1	0	\N	\N
135586	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF pour 2017	\N	2016-11-03 17:00:00	2016-11-03 18:00:00	\N	\N	0	0	\N	\N
135830	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Mission Sécurités	PLF pour 2017 - Mission Sécurités - Programme Police et Gendarmerie - FSMI FO	2016-11-07 11:00:00	2016-11-07 12:30:00	\N	\N	1	0	\N	\N
135833	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Sécurités	PLF pour 2017 - Sécurités - Police et gendarmerie - UNSA POLICE	2016-11-08 09:00:00	2016-11-08 11:00:00	\N	\N	1	0	\N	\N
135842	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2017	\N	2016-11-03 14:00:00	2016-11-03 15:00:00	\N	\N	2	0	\N	\N
135848	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2017 	\N	2016-11-03 16:00:00	2016-11-03 17:00:00	\N	\N	2	0	\N	\N
135851	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF  pour 2017	\N	2016-11-03 17:30:00	2016-11-03 18:30:00	\N	\N	1	0	\N	\N
135871	DELEGATION	AUCUNE	\N	\N	DSOM	RI Normes BTP outre-mer	\N	2016-11-17 08:30:00	2016-11-17 09:45:00	2016-11-17 12:41:32	2016-11-17 15:31:42	6	0	\N	\N
135882	DELEGATION	AUCUNE	\N	\N	DSOM	RI Normes BTP outre-mer	\N	2016-11-22 18:30:00	2016-11-22 19:55:00	2016-11-23 09:54:53	2016-11-23 11:10:05	5	0	\N	\N
136163	DELEGATION	AUCUNE	\N	\N	DSOM	RI Foncier dans les outre-mer	\N	2016-11-23 15:00:00	2016-11-23 17:20:00	2016-11-23 18:14:49	2016-11-24 18:43:13	10	0	\N	\N
136176	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2017 - Egalité des territoires	PLF 2017 - Egalité des territoires	2016-11-08 15:05:00	2016-11-08 16:20:00	\N	\N	1	0	\N	\N
142936	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2016-11-23 09:00:00	2016-11-23 11:25:00	2016-11-23 11:51:08	2016-11-23 17:52:16	50	0	\N	\N
144594	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2016-11-23 09:00:00	2016-11-23 12:20:00	2016-11-24 18:41:24	2016-11-25 10:38:15	53	0	\N	\N
136202	DELEGATION	AUCUNE	\N	\N	DSOM	RI Foncier dans les outre-mer	\N	2016-11-24 08:30:00	2016-11-24 11:20:00	2016-11-24 14:47:48	2016-11-24 18:43:14	7	0	\N	\N
136337	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF pour 2017	\N	2016-11-08 08:30:00	2016-11-08 09:30:00	\N	\N	1	0	\N	\N
136340	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF pour 2017	\N	2016-11-08 09:30:00	2016-11-08 12:30:00	\N	\N	1	0	\N	\N
136343	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF pour 2017	\N	2016-11-08 14:00:00	2016-11-08 15:30:00	\N	\N	1	0	\N	\N
136346	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF pour 2017	\N	2016-11-08 10:00:00	2016-11-08 11:00:00	\N	\N	1	0	\N	\N
136348	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF pour 2017	\N	2016-11-08 14:00:00	2016-11-08 16:10:00	\N	\N	1	0	\N	\N
136357	ETUDES	AUCUNE	\N	\N	\N	\N	\N	2016-11-08 14:00:00	2016-11-08 15:00:00	\N	\N	11	0	\N	918
136371	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF pour 	\N	2016-11-08 17:30:00	2016-11-08 19:30:00	\N	\N	1	0	\N	\N
136655	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2017 - Avis protection des droits et libertés	\N	2016-11-07 16:30:00	2016-11-07 17:20:00	\N	\N	1	0	\N	\N
136683	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF pour 2017	\N	2016-11-09 14:00:00	2016-11-09 16:00:00	\N	\N	1	0	\N	\N
136705	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF pour 2017	\N	2016-11-09 17:00:00	2016-11-09 18:00:00	\N	\N	1	0	\N	\N
136720	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	Aménagement du territoire	\N	2016-11-09 15:00:00	2016-11-09 17:00:00	\N	\N	2	0	\N	\N
136722	ETUDES	AUCUNE	\N	\N	\N	Montagne	\N	2016-11-09 16:45:00	2016-11-09 18:00:00	\N	\N	10	0	\N	918
136734	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF pour 2017	\N	2016-11-10 08:30:00	2016-11-10 09:30:00	\N	\N	1	0	\N	\N
136742	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Conventions internationales	Conventions internationales	2016-11-09 14:40:00	2016-11-09 20:35:00	\N	\N	17	0	\N	\N
136743	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Statut de Paris	PJL Statut de Paris	2016-11-09 14:45:00	2016-11-09 19:00:00	\N	\N	103	0	\N	\N
136744	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Statut de Paris	PJL Statut de Paris	2016-11-09 20:30:00	2016-11-10 00:30:00	\N	\N	0	0	\N	\N
136758	QUESTURE	AUCUNE	\N	\N	\N	Questure	\N	2016-11-08 14:30:00	2016-11-08 16:40:00	\N	\N	2	0	\N	\N
137498	COM_SPECIALE	PLENIERE	\N	COMSPEAPU	\N	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne	Réunion de la Commission spéciale chargée du contrôle des comptes et de l'évaluation interne	2016-11-09 14:00:00	2016-11-09 15:45:00	2016-11-09 16:26:37	2016-11-09 17:10:34	11	0	\N	\N
137510	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF pour 2017 - Enseignement scolaire	PLF pour 2017 - Enseignement scolaire	2016-11-08 12:00:00	2016-11-08 14:00:00	\N	\N	1	0	\N	\N
137512	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF pour 2017 - Enseignement scolaire	PLF pour 2017 - Enseignement scolaire	2016-11-08 15:00:00	2016-11-08 16:45:00	\N	\N	1	0	\N	\N
137514	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF pour 2017 - Enseignement scolaire	PLF pour 2017 - Enseignement scolaire	2016-11-08 17:45:00	2016-11-08 18:45:00	\N	\N	1	0	\N	\N
137593	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Déradicalisation	\N	2016-11-08 18:00:00	2016-11-08 19:00:00	\N	\N	2	0	\N	\N
137596	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Recherche et enseignement supérieur - SATT	Contrôle Recherche et enseignement supérieur - SATT - Lucia Robert	2016-11-08 11:30:00	2016-11-08 12:30:00	\N	\N	1	0	\N	\N
137598	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF 2017 Politique des territoires - Ville	PLF 2017 Politique des territoires - Ville - Audition du cabinet de Mme Geoffroy, secrétaire d'Etat chargée de la ville	2016-11-09 16:00:00	2016-11-09 16:45:00	\N	\N	1	0	\N	\N
137612	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2016-11-09 16:35:00	2016-11-09 18:35:00	2018-05-18 15:40:24	2018-05-18 15:40:30	24	0	\N	\N
137641	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF pour 2017 - Audiovisuel extérieur	Avis sur les crédits relatifs à l'audiovisuel extérieur (PLF 2017)	2016-11-08 14:30:00	2016-11-08 16:30:00	\N	\N	1	0	\N	\N
137643	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Avis crédits Sport (PLF 2017)	Avis sur les crédits relatifs au sport (PLF 2017)	2016-11-09 14:30:00	2016-11-09 15:30:00	\N	\N	1	0	\N	\N
137671	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2017 jeunesse et vie associative	PLF 2017 jeunesse et vie associative	2016-11-08 14:15:00	2016-11-08 15:15:00	\N	\N	1	0	\N	\N
137673	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2017 jeunesse et vie associative	PLF 2017 jeunesse et vie associative	2016-11-09 13:30:00	2016-11-09 14:00:00	\N	\N	1	0	\N	\N
137707	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF	\N	2016-11-09 14:30:00	2016-11-09 16:00:00	\N	\N	1	0	\N	\N
137712	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF  pour 2017	\N	2016-11-09 14:30:00	2016-11-09 16:15:00	\N	\N	1	0	\N	\N
137717	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF  pour 2017	\N	2016-11-08 14:30:00	2016-11-08 15:45:00	\N	\N	1	0	\N	\N
137723	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PL	\N	2016-11-09 15:30:00	2016-11-09 16:15:00	\N	\N	1	0	\N	\N
137789	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT assurances	GT assurances	2016-11-08 17:45:00	2016-11-08 19:00:00	\N	\N	1	0	\N	\N
137855	GIA	AUCUNE	\N	\N	\N	Invitation ambassade d'Italie	Exposition "Léonard en France" à l'invitation de l'ambassade d'Italie	2016-11-08 14:00:00	2016-11-08 14:30:00	\N	\N	4	0	621	\N
137860	GIA	AUCUNE	\N	\N	\N	Conférence de presse Chrétiens d'Orient	Conférence de presse concert de l'Association Pueri cantores France	2016-11-02 10:30:00	2016-11-02 11:30:00	\N	\N	2	0	CHRETORIENT	CHRETORIENT
138298	COM_PERMANENTE	DEPLACEMENT	\N	SOCI	\N	Mission UHSA	Mission sur les unités hospitalières spécialement aménagées 	2016-10-25 15:30:00	2016-10-25 18:00:00	\N	\N	3	0	\N	\N
138389	QUESTURE	AUCUNE	\N	\N	\N	Questure	\N	2016-11-15 14:30:00	2016-11-15 16:30:00	\N	\N	3	0	\N	\N
138403	COM_PERMANENTE	AUTRE	\N	LOIS	\N	\N	\N	2016-11-15 16:30:00	2016-11-15 18:05:00	2016-11-16 11:37:32	2016-11-16 14:03:37	15	0	\N	\N
140162	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2017 - Relations avec les collectivités territoriales	\N	2016-11-16 15:30:00	2016-11-16 17:45:00	\N	\N	1	0	\N	\N
140492	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2017	PLFSS 2017	2016-11-18 09:50:00	2016-11-18 12:50:00	\N	\N	27	0	\N	\N
140494	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2017	PLFSS 2017	2016-11-18 14:30:00	2016-11-18 18:50:00	\N	\N	26	0	\N	\N
140674	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF  pour 2017	\N	2016-11-15 16:00:00	2016-11-15 16:45:00	\N	\N	4	0	\N	\N
140687	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	P	\N	2016-11-15 16:45:00	2016-11-15 17:25:00	\N	\N	5	0	\N	\N
140693	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF  pour 2017	\N	2016-11-15 17:25:00	2016-11-15 18:10:00	\N	\N	3	0	\N	\N
140698	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2017	\N	2016-11-15 18:10:00	2016-11-15 19:15:00	\N	\N	1	0	\N	\N
140703	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF  pour 2017	\N	2016-11-17 14:00:00	2016-11-17 15:15:00	\N	\N	1	0	\N	\N
140713	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Transmission  et reprise d'entreprises	\N	2016-11-30 17:30:00	2016-11-30 18:30:00	\N	\N	2	0	\N	\N
140760	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL montagne	PJL MONTAGNE	2016-11-17 08:30:00	2016-11-17 11:00:00	\N	\N	5	0	\N	\N
146212	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Égalité réelle outre-mer	\N	2016-11-30 14:00:00	2016-11-30 15:40:00	\N	\N	1	0	\N	\N
138723	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PLF 2017 - Divers avis budgétaires	\N	2016-11-16 09:15:00	2016-11-16 11:10:00	2016-11-16 11:55:34	2016-11-16 17:27:07	41	0	\N	\N
146502	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition ACCIS	ACCIS - Audition sur les propositions de directives du Conseil de l'Union européenne	2016-12-01 10:05:00	2016-12-01 11:55:00	2016-12-01 16:47:25	2016-12-01 17:36:35	19	0	\N	\N
146794	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Déplacement	PLF pour 2017 - Rapport général - Déplacement MInistère de l'économie et des finances	2016-11-30 09:00:00	2016-11-30 11:30:00	\N	\N	2	0	\N	\N
146805	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de Mme Vestager commissaire européenne à la concurrence	Audition de Mme Vestager commissaire européenne à la concurrence	2016-12-01 13:30:00	2016-12-01 14:30:00	2016-12-01 18:37:36	2016-12-02 10:27:26	19	0	\N	\N
146828	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2016-12-06 09:35:00	2016-12-06 09:45:00	\N	\N	9	0	\N	\N
146829	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR Crimes Syrie Irak	PPR Crimes Syrie Irak	2016-12-06 14:30:00	2016-12-06 16:00:00	\N	\N	78	0	\N	\N
146830	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Transports scolaires	PPL Transports scolaires	2016-12-06 16:00:00	2016-12-06 17:35:00	\N	\N	65	0	\N	\N
146831	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR Normes agriculture	PPR Normes agriculture	2016-12-06 17:40:00	2016-12-06 19:20:00	\N	\N	50	0	\N	\N
147235	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Transports scolaires + PJL Territoires de montagne	\N	2016-12-06 09:05:00	2016-12-06 10:20:00	2016-12-06 11:59:53	2016-12-06 16:31:39	20	0	\N	\N
147892	COM_SPECIALE	PLENIERE	\N	EGALITE	\N	Égalité et citoyenneté	Commission spéciale "Égalité et citoyenneté"	2016-12-06 21:00:00	2016-12-06 22:05:00	2016-12-08 14:52:50	2016-12-08 15:56:33	17	0	\N	\N
148272	COM_PERMANENTE	AUTRE	\N	FINC	\N	Contrôles budgétaires - CR Conférence Gouvernance économique et financière de l'UE	Communications de MM. P. Dallier et G. Longuet - CR sur la gouvernance économique et financière de l'UE	2016-12-07 09:35:00	2016-12-07 12:05:00	2016-12-07 15:56:47	2016-12-07 17:31:51	35	0	\N	\N
148396	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2016-12-07 08:35:00	2016-12-07 09:20:00	2016-12-07 16:20:41	2016-12-07 17:31:53	24	0	\N	\N
148551	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2016-12-07 10:25:00	2016-12-07 12:00:00	2016-12-07 16:21:39	2016-12-07 17:31:47	44	0	\N	\N
149212	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Égalité réelle outre-mer	\N	2016-12-07 14:30:00	2016-12-07 15:40:00	\N	\N	2	0	\N	\N
149215	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Égalité réelle outre-mer	\N	2016-12-07 16:00:00	2016-12-07 18:15:00	\N	\N	1	0	\N	\N
152732	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFR 2016	PLFR 2016	2016-12-15 11:30:00	2016-12-15 13:05:00	\N	\N	66	0	\N	\N
152733	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2016-12-15 15:00:00	2016-12-15 16:00:00	\N	\N	223	0	\N	\N
152734	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Etat d'urgence	PJL Etat d'urgence	2016-12-15 16:15:00	2016-12-15 17:55:00	\N	\N	79	0	\N	\N
152735	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFR 2016	PLFR 2016	2016-12-15 21:35:00	2016-12-16 00:30:00	\N	\N	41	0	\N	\N
152736	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFR 2016	PLFR 2016	2016-12-15 18:10:00	2016-12-15 20:05:00	\N	\N	43	0	\N	\N
152937	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Ordonnances consommation	PJL Ordonnances consommation	2016-12-14 10:00:00	2016-12-14 10:30:00	\N	\N	1	0	\N	\N
152943	DELEGATION	AUCUNE	\N	\N	PROS	Réunion plénière	Présentation par Pierre-Yves Collombat de son étude	2016-12-15 08:30:00	2016-12-15 10:15:00	2016-12-15 11:54:29	2016-12-15 15:29:06	7	0	\N	\N
152949	ETUDES	AUCUNE	\N	\N	\N	GE Vigne et Vin	GE Vigne et Vin	2016-12-08 05:45:00	2016-12-08 19:15:00	\N	\N	12	0	\N	909
153621	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Assainissement cadastral	\N	2016-12-14 14:15:00	2016-12-14 17:00:00	\N	\N	1	0	\N	\N
154019	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Gouvernance du football	Mission d'information sur la gouvernance du football	2016-12-15 16:15:00	2016-12-15 17:00:00	\N	\N	3	0	\N	\N
154096	COM_EURO	DEPLACEMENT	\N	AFEU	\N	Paquet droit d'auteur	\N	2016-12-16 07:30:00	2016-12-16 18:30:00	\N	\N	1	0	\N	\N
154952	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2017 - Rapport général	PLF pour 2017 - Rapport général - Audition CNC	2016-12-13 08:30:00	2016-12-13 09:00:00	\N	\N	1	0	\N	\N
155352	COM_EURO	AUDRAP	\N	AFEU	\N	Perturbateurs endocriniens	Perturbateurs endocriniens	2016-12-20 10:00:00	2016-12-20 12:15:00	\N	\N	2	0	\N	\N
155959	COM_ENQUETE	PLENIERE	\N	ATTEINTES	\N	"Table ronde" des juristes	Audition de M.  Gossement, M. Lucas, M. Trebulle	2016-12-20 17:55:00	2016-12-20 19:40:00	2016-12-22 14:20:49	2016-12-22 16:47:33	8	0	\N	\N
157092	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI redressement de la justice	\N	2016-12-21 14:30:00	2016-12-21 19:15:00	\N	\N	1	0	\N	\N
157132	COM_ENQUETE	PLENIERE	\N	ATTEINTES	\N	5ème séquence d'auditions généralistes (chercheurs/associations écologistes)	Tables rondes des chercheurs et des associations de défense de l'environnement	2016-12-22 14:35:00	2016-12-22 19:00:00	2016-12-22 19:33:20	2016-12-23 10:19:18	5	0	\N	\N
157936	COM_PERMANENTE	AUTRE	\N	FINC	\N	Loi de programmation outre-mer - Examen du rapport	\N	2017-01-10 15:35:00	2017-01-10 16:15:00	2017-01-11 09:54:56	2017-01-11 17:26:08	26	0	\N	\N
160418	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	\N	\N	2017-01-10 10:00:00	2017-01-10 10:50:00	\N	\N	1	0	\N	\N
160432	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	\N	\N	2017-01-12 16:00:00	2017-01-12 17:10:00	\N	\N	1	0	\N	\N
160452	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	\N	\N	2017-01-12 17:10:00	2017-01-12 17:50:00	\N	\N	2	0	\N	\N
160592	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Ratification ordonnances applicables à la Corse	\N	2017-01-13 14:00:00	2017-01-13 17:00:00	\N	\N	1	0	\N	\N
160652	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	COLTER	RI services déconcentrés - Conférence de presse	\N	2017-01-12 14:00:00	2017-01-12 15:00:00	\N	\N	3	0	\N	\N
160656	GIA	AUCUNE	\N	\N	\N	petit-déjeuner de tarvail avec le Directeur Afrique et Océanie du MAEDI	\N	2017-01-11 08:30:00	2017-01-11 09:30:00	\N	\N	12	0	622	\N
161826	QUESTURE	AUCUNE	\N	\N	\N	Questure	Questure	2017-01-17 14:30:00	2017-01-17 16:40:00	\N	\N	3	0	\N	\N
161892	COM_ENQUETE	PLENIERE	\N	SCHENGEN	\N	CE SCHENGEN	CE SCHENGEN	2017-01-17 13:30:00	2017-01-17 14:30:00	2017-01-19 18:08:01	2017-01-19 18:19:18	13	0	\N	\N
162636	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Obligations comptables des partis politiques	\N	2017-01-17 14:30:00	2017-01-17 15:00:00	\N	\N	1	0	\N	\N
162732	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Égalité réelle outre-mer	PJL Égalité réelle outre-mer	2017-01-18 14:30:00	2017-01-18 19:05:00	\N	\N	112	0	\N	\N
162733	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Égalité réelle outre-mer	PJL Égalité réelle outre-mer	2017-01-18 21:35:00	2017-01-19 00:00:00	\N	\N	38	0	\N	\N
163199	COM_ENQUETE	PLENIERE	\N	ATTEINTES	\N	1ère séquence du cycle d'auditions LGV/ 11e séquence d'auditions généralistes	1ère séquence du cycle  LGV (SNCF Réseau)/ 11e séquence d'auditions généralistes (DGITM)	2017-01-18 14:10:00	2017-01-18 16:45:00	2017-01-20 10:04:42	2017-01-20 10:19:33	6	0	\N	\N
163592	MISSION	AUCUNE	\N	PSYCHIATRIE	\N	\N	\N	2017-01-18 14:10:00	2017-01-18 16:40:00	2017-01-18 17:32:40	2017-01-18 17:39:52	9	0	\N	\N
148431	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2016-12-07 10:00:00	2016-12-07 10:25:00	2016-12-07 16:21:14	2016-12-07 17:31:49	43	2	\N	\N
163654	COM_ENQUETE	PLENIERE	\N	ATTEINTES	\N	12ème séquence du cycle d'auditions généralistes (ADEME)	12ème séquence du cycle d'auditions généralistes (ADEME - B. Léchevin)	2017-01-18 18:10:00	2017-01-18 19:00:00	2017-01-20 10:03:24	2017-01-20 10:19:31	5	0	\N	\N
163932	COM_ENQUETE	PLENIERE	\N	SCHENGEN	\N	CE SCHENGEN	CE SCHENGEN - Direction générale des étrangers	2017-01-18 15:10:00	2017-01-18 16:40:00	2017-01-19 09:11:44	2017-01-19 18:02:39	13	0	\N	\N
163946	DELEGATION	DEPLACEMENT	\N	\N	COLTER	RI_CT et prévention de la radicalisation-déplacement à Sarcelles	\N	2017-01-11 15:00:00	2017-01-11 20:30:00	\N	\N	1	0	\N	\N
163949	DELEGATION	AUDRAP	\N	\N	COLTER	RI_prévention radicalisation et collectivités	\N	2017-01-18 15:30:00	2017-01-18 16:30:00	\N	\N	1	0	\N	\N
163953	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Renforcer l'efficacité de la justice pénale	\N	2017-01-18 14:30:00	2017-01-18 16:30:00	\N	\N	1	0	\N	\N
163955	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Renforcer l'efficacité de la justice pénale	\N	2017-01-18 17:45:00	2017-01-18 18:30:00	\N	\N	1	0	\N	\N
163972	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	Audition PAC	Audition rapporteur - PAC	2017-01-18 16:45:00	2017-01-18 18:30:00	\N	\N	2	0	\N	\N
164072	GIA	AUCUNE	\N	\N	\N	Dejeuner de travail	Dejeuner de travail à l'invitation de l'ambassadeur d'Indonésie à Paris	2017-01-18 12:30:00	2017-01-18 14:30:00	\N	\N	5	0	653	\N
146170	MISSION	AUCUNE	\N	PSYCHIATRIE	\N	\N	\N	2016-11-30 13:30:00	2016-11-30 14:20:00	2016-12-01 11:43:29	2016-12-01 15:37:20	22	0	\N	\N
146932	COM_PERMANENTE	AUTRE	\N	CDD	\N	Audition de M. Jean-Michel Baylet	Audition de M. Jean-Michel Baylet, ministre de l'aménagement du territoire	2016-12-01 16:20:00	2016-12-01 17:25:00	2016-12-02 11:56:53	2016-12-02 12:00:26	17	0	\N	\N
147603	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Extension délit entrave IVG	PPL Extension délit entrave IVG	2016-12-07 14:35:00	2016-12-07 17:40:00	\N	\N	124	0	\N	\N
147610	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR Contrats de ressources	PPR Contrats de ressources	2016-12-07 18:35:00	2016-12-07 19:45:00	\N	\N	26	0	\N	\N
147613	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Publicité jeunesse	PPL Publicité jeunesse	2016-12-07 21:30:00	2016-12-07 23:05:00	\N	\N	22	0	\N	\N
147774	COM_EURO	CONTROLE	\N	AFEU	\N	\N	Audition de MM. Désir et Roth	2016-12-06 17:30:00	2016-12-06 18:50:00	2016-12-06 19:18:26	2016-12-07 15:47:16	17	0	\N	\N
148640	ETUDES	AUCUNE	\N	\N	\N	\N	\N	2016-12-07 08:00:00	2016-12-07 09:00:00	\N	\N	5	0	\N	922
148687	MISSION	PLEIN_NON_JO	\N	BREXIT	\N	Communications Défense européenne et Politique commerciale	Communications Défense européenne et Politique commerciale de l'Union européenne	2016-12-07 14:30:00	2016-12-07 15:35:00	\N	\N	7	0	\N	\N
148737	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2016-12-07 14:05:00	2016-12-07 14:20:00	2016-12-07 17:26:27	2016-12-07 17:31:45	34	0	\N	\N
149532	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Simplification du droit pour les entreprises	\N	2016-12-20 14:30:00	2016-12-20 15:15:00	\N	\N	2	0	\N	\N
149592	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PJL Territoires de montagne	\N	2016-12-12 14:00:00	2016-12-12 14:35:00	2016-12-12 15:34:30	2016-12-12 17:03:41	9	0	\N	\N
150087	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLFR pour 2016 - Rapport du rapporteur général	PLFR pour 2016 - Rapport du rapporteur général	2016-12-13 09:05:00	2016-12-13 10:40:00	2016-12-13 18:10:51	2016-12-13 18:10:54	28	0	\N	\N
151282	MISSION	PLEIN_NON_JO	\N	BREXIT	\N	Audition de M. Jean-Claude Piris	Audition de M. Jean-Claude Piris, ancien jurisconsulte du Conseil européen	2016-12-14 08:35:00	2016-12-14 09:35:00	\N	\N	5	0	\N	\N
151796	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Cour d'assises spéciale	\N	2016-12-13 14:00:00	2016-12-13 19:15:00	\N	\N	1	0	\N	\N
153052	COM_EURO	AUDRAP	\N	AFEU	\N	Situation en turquie	Situation en Turquie	2016-12-13 16:00:00	2016-12-13 17:00:00	\N	\N	2	0	\N	\N
153055	COM_EURO	AUDRAP	\N	AFEU	\N	Situation en turquie	Situation en Turquie	2016-12-13 17:00:00	2016-12-13 18:00:00	\N	\N	4	0	\N	\N
153972	QUESTURE	AUCUNE	\N	\N	\N	Questure	\N	2016-12-15 11:45:00	2016-12-15 12:00:00	\N	\N	3	0	\N	\N
154572	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Égalité réelle outre-mer	PJL Égalité réelle outre-mer - Audition DGFiP	2016-12-13 14:30:00	2016-12-13 17:00:00	\N	\N	1	0	\N	\N
154574	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Égalité réelle outre-mer	PJL Égalité réelle outre-mer - Audition Ministère des outre-mer	2016-12-13 17:00:00	2016-12-13 18:00:00	\N	\N	1	0	\N	\N
154592	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Égalité réelle outre-mer	PJL Égalité réelle outre-mer - Audition APICAP	2016-12-14 14:30:00	2016-12-14 15:30:00	\N	\N	1	0	\N	\N
155492	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	\N	2016-12-20 10:00:00	2016-12-20 11:00:00	\N	\N	1	0	\N	\N
155512	GIA	AUCUNE	\N	\N	\N	déjeuner du groue d'amitié	\N	2016-12-13 12:45:00	2016-12-13 14:30:00	\N	\N	5	0	626	\N
156992	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Renforcer l'efficacité de la justice pénale	\N	2016-12-21 14:00:00	2016-12-21 17:45:00	\N	\N	1	0	\N	\N
158832	QUESTURE	AUCUNE	\N	\N	\N	Conseil d'administration de l'AGAS	Conseil d'administration de l'AGAS	2017-01-10 15:00:00	2017-01-10 16:30:00	\N	\N	1	0	\N	\N
160338	GIA	AUCUNE	\N	\N	\N	Audition commune coprésident du groupe de Minsk	Petit-déjeuner commun au groupe France-Caucase autour de l'ambassadeur Stéphane Visconti, coprésident du groupe de Minsk	2017-01-12 08:30:00	2017-01-12 09:45:00	\N	\N	5	0	641	\N
160344	GIA	AUCUNE	\N	\N	\N	Audition commune coprésident du groupe de Minsk	Petit-déjeuner commun au groupe France-Arménie autour de l'ambassadeur Stéphane Visconti, coprésident du groupe de Minsk	2017-01-12 08:30:00	2017-01-12 09:45:00	\N	\N	6	0	534	\N
160392	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Sécurité publique	\N	2017-01-12 11:30:00	2017-01-12 12:30:00	\N	\N	1	0	\N	\N
160394	MISSION	AUDRAP	\N	DEMOCRATIE	\N	\N	\N	2017-01-12 13:30:00	2017-01-12 14:55:00	\N	\N	4	0	\N	\N
161040	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2017-01-17 13:40:00	2017-01-17 14:00:00	2017-01-17 14:46:07	2017-01-17 17:11:58	28	1	\N	\N
163157	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2017-01-18 10:35:00	2017-01-18 13:10:00	2017-01-18 16:50:21	2017-01-18 17:14:59	51	0	\N	\N
163246	MECSS	AUCUNE	\N	\N	MECSS	\N	\N	2017-01-18 14:00:00	2017-01-18 14:15:00	2017-01-18 14:40:45	2017-01-18 17:15:46	5	0	\N	\N
146112	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2016-11-30 10:05:00	2016-11-30 10:50:00	2016-12-01 17:14:10	2016-12-01 17:33:18	48	0	\N	\N
146552	CMP	AUTRE	\N	VTC	\N	PPL Transport particulier de personnes	Transport particulier de personnes	2016-11-30 18:30:00	2016-11-30 19:10:00	\N	\N	9	0	\N	\N
163372	DELEGATION	AUCUNE	\N	\N	COLTER	Audition - Jean-Vincent PLACÉ	\N	2017-01-26 09:00:00	2017-01-26 10:30:00	2017-01-26 11:02:46	2017-01-26 17:47:13	16	0	\N	\N
164193	COM_ENQUETE	PLENIERE	\N	ATTEINTES	\N	2ème séquence d'auditions  spécialisées sur l'A65/LGV Tours-Bordeaux	2ème séquence d'auditions  spécialisées sur l'A65/LGV Tours-Bordeaux	2017-01-19 14:05:00	2017-01-19 15:15:00	2017-01-20 10:01:01	2017-01-20 10:19:29	6	0	\N	\N
164352	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Groupe de travail Culture et handicap	Groupe de travail Culture et handicap	2017-01-17 15:00:00	2017-01-17 16:30:00	\N	\N	1	0	\N	\N
164354	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Groupe de travail Culture et handicap	Groupe de travail Culture et handicap	2017-01-19 10:30:00	2017-01-19 12:00:00	\N	\N	2	0	\N	\N
164357	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Francophonie	\N	2017-01-17 17:45:00	2017-01-17 18:45:00	\N	\N	2	0	\N	\N
164358	COM_ENQUETE	PLENIERE	\N	ATTEINTES	\N	3è séquence du cycle d'auditions sur la LGV/A65 et 13è séquence d'auditions généralistes	3ème séquence du cycle d'auditions  spécialisées  l'A65/LGV  (Cté TGV) et 13è séquence du cycle généraliste (Dubois)	2017-01-19 16:00:00	2017-01-19 18:45:00	2017-01-20 09:57:34	2017-01-20 10:19:27	3	0	\N	\N
164372	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Francophonie	\N	2017-01-19 14:30:00	2017-01-19 15:30:00	\N	\N	2	0	\N	\N
164375	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	groupe de travail Rythmes scolaires	groupe de travail Rythmes scolaires	2017-01-18 15:00:00	2017-01-18 17:00:00	\N	\N	1	0	\N	\N
164433	MISSION	AUCUNE	\N	DEMOCRATIE	\N	\N	\N	2017-01-19 13:30:00	2017-01-19 15:00:00	2017-01-19 16:35:26	2017-01-19 18:02:50	6	0	\N	\N
164472	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL Lyon-Turin	\N	2017-01-16 10:00:00	2017-01-16 10:30:00	\N	\N	2	0	\N	\N
164475	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL Lyon-Turin	\N	2017-01-17 15:00:00	2017-01-17 16:00:00	\N	\N	2	0	\N	\N
164478	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Protocole prévention du terrorisme	\N	2017-01-18 15:00:00	2017-01-18 16:25:00	\N	\N	2	0	\N	\N
164482	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Drones	\N	2017-01-17 14:30:00	2017-01-17 15:30:00	\N	\N	2	0	\N	\N
164485	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Drones	\N	2017-01-18 14:30:00	2017-01-18 15:30:00	\N	\N	3	0	\N	\N
164492	MISSION	DEPLACEMENT	\N	BREXIT	\N	Berlin	\N	2017-01-15 15:00:00	2017-01-16 19:00:00	\N	\N	4	0	\N	\N
164532	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle "Les moyens de la politique de sécurité sanitaire et alimentaire"	Contrôle "Les moyens de la politique de sécurité sanitaire et alimentaire" - Audition de la Direction générale des Douan	2017-01-17 16:00:00	2017-01-17 16:45:00	\N	\N	1	0	\N	\N
164535	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle "Les moyens de la politique de sécurité sanitaire et alimentaire" 	Contrôle "Les moyens de la politique de sécurité sanitaire et alimentaire" - Direction générale de la Santé	2017-01-18 14:45:00	2017-01-18 16:15:00	\N	\N	1	0	\N	\N
146172	COM_ENQUETE	PLENIERE	\N	SCHENGEN	\N	CE SCHENGEN	\N	2016-11-29 09:35:00	2016-11-29 10:10:00	2016-11-30 18:23:59	2016-11-30 18:25:16	12	0	\N	\N
147012	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	GT Aménagement du territoire	GT Aménagement du territoire	2016-11-30 10:00:00	2016-11-30 12:00:00	\N	\N	3	0	\N	\N
147016	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	\N	2016-11-29 15:30:00	2016-11-29 18:00:00	\N	\N	1	0	\N	\N
147018	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	\N	2016-12-30 14:30:00	2016-12-30 15:30:00	\N	\N	1	0	\N	\N
147032	ETUDES	AUCUNE	\N	\N	\N	Candidature de Paris JO 2024	Candidature de Paris JO 2024	2016-11-30 08:15:00	2016-11-30 09:30:00	\N	\N	10	0	\N	934
147044	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPRE Directive SMA	PPRE sur la révision de la directive Services de Médias Audiovisuels (SMA)	2016-10-04 14:30:00	2016-10-04 16:15:00	\N	\N	1	0	\N	\N
147046	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPRE Directive SMA	PPRE sur la révision de la directive Services de Médias Audiovisuels (SMA)	2016-10-05 16:15:00	2016-10-05 17:15:00	\N	\N	1	0	\N	\N
147048	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPRE Directive SMA	PPRE sur la révision de la directive Services de Médias Audiovisuels (SMA)	2016-10-13 11:00:00	2016-10-13 12:30:00	\N	\N	1	0	\N	\N
147050	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPRE Directive SMA	PPRE sur la révision de la directive Services de Médias Audiovisuels (SMA)	2016-10-18 14:30:00	2016-10-18 15:30:00	\N	\N	1	0	\N	\N
147132	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF pour 2017	PLR POUR 2017	2016-10-25 15:00:00	2016-10-25 16:00:00	\N	\N	1	0	\N	\N
147134	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF pour 2017	PLF POUR 2017	2016-11-29 14:30:00	2016-11-29 15:15:00	\N	\N	1	0	\N	\N
147192	MISSION	DEPLACEMENT	\N	BREXIT	\N	Rencontre avec les institutions européennes à Bruxelles	Rencontre avec les institutions européennes à Bruxelles-5 et 6 décembre 2016	2016-12-05 07:55:00	2016-12-05 23:00:00	\N	\N	4	0	\N	\N
149356	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Egalité réelle Outre-mer	\N	2016-11-30 16:30:00	2016-11-30 18:30:00	\N	\N	1	0	\N	\N
149358	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Egalité réelle Outre-mer	\N	2016-12-06 09:00:00	2016-12-06 13:15:00	\N	\N	1	0	\N	\N
149360	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL	\N	2016-12-08 10:00:00	2016-12-08 12:30:00	\N	\N	1	0	\N	\N
149364	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Egalité réelle Outre-mer	\N	2016-12-08 15:00:00	2016-12-08 18:00:00	\N	\N	1	0	\N	\N
149368	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Egalité réelle Outre-mer	\N	2016-12-16 09:00:00	2016-12-16 12:30:00	\N	\N	1	0	\N	\N
149370	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Egalité réelle Outre-mer	\N	2016-12-16 14:00:00	2016-12-16 17:30:00	\N	\N	1	0	\N	\N
149372	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Francophonie	\N	2016-12-07 17:30:00	2016-12-07 18:30:00	\N	\N	2	0	\N	\N
150748	COM_EURO	DEPLACEMENT	\N	AFEU	\N	PAC (DUBLIN - 8-9 DECEMBRE 2016)	PAC (DUBLIN - 8-9 DECEMBRE 2016)	2016-12-08 06:30:00	2016-12-09 20:30:00	\N	\N	3	0	\N	\N
152103	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	Entretien avec l'ambassadeur de l'Inde en France	Entretien des membres du groupe avec S.E. le Dr Mohan KUMAR, Ambassadeur de l¿Inde en France	2016-12-14 12:45:00	2016-12-14 14:45:00	\N	\N	8	0	\N	\N
156065	COM_EURO	AUDRAP	\N	AFEU	\N	Perturbateurs endocriniens	Perturbateurs endocriniens	2016-12-20 14:30:00	2016-12-20 15:30:00	\N	\N	2	0	\N	\N
156068	COM_EURO	AUDRAP	\N	AFEU	\N	Situation en Turquie	Situation en Turquie	2016-12-20 15:30:00	2016-12-20 16:45:00	\N	\N	3	0	\N	\N
150197	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	\N	2016-12-08 14:30:00	2016-12-08 16:30:00	\N	\N	1	0	\N	\N
146253	CMP	AUTRE	\N	CDGEXPRESS	\N	PJL Liaison ferroviaire Paris-CDG	Liaison ferroviaire Paris-CDG	2016-11-30 17:30:00	2016-11-30 18:25:00	\N	\N	9	0	\N	\N
154912	CMP	AUTRE	\N	PLFR2016	\N	PLFR 2016	PLFR 2016	2016-12-19 09:40:00	2016-12-19 10:20:00	\N	\N	6	0	\N	\N
156072	COM_EURO	DEPLACEMENT	\N	AFEU	\N	Perturbateurs endocriniens	Perturbateurs endocriniens	2016-12-08 07:00:00	2016-12-08 18:00:00	\N	\N	2	0	\N	\N
156094	GIA	AUCUNE	\N	\N	\N	accueil de délégation	visite de Mme Jiko Luveni , présidente du parlement fidjien	2016-12-19 11:30:00	2016-12-19 16:15:00	\N	\N	6	0	651	\N
156333	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de Mme Muriel Pénicaud	Audition de Mme Muriel Pénicaud, directrice générale de Business France	2016-12-21 10:20:00	2016-12-21 11:55:00	2018-05-18 15:46:26	2018-05-18 15:46:37	24	0	\N	\N
156453	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFR 2016	PLFR 2016	2016-12-21 14:35:00	2016-12-21 17:00:00	\N	\N	61	0	\N	\N
156825	COM_ENQUETE	PLENIERE	\N	ATTEINTES	\N	3ème séquence d'auditions généralistes (In Vivo, agriculteurs,MNHN, CDC biodiversité)	Auditions, InVivo Agrosolutions/Syndicats agricoles/Muséum national d'Histoire naturelle/CDC Biodiversité	2016-12-21 14:05:00	2016-12-21 19:40:00	2016-12-22 16:35:31	2016-12-22 16:47:35	9	0	\N	\N
157052	COM_ENQUETE	PLENIERE	\N	ATTEINTES	\N	4ème séquence d'auditions généralistes (CGDD, chasseurs et pêcheurs)	Audition de Mme Laurence Monnoyer-Smith (CGDD) et M. Courbois (chasseur), M. Guillouet et Mme Colombet (pêcheurs)	2016-12-22 11:05:00	2016-12-22 13:15:00	2016-12-22 16:50:43	2016-12-22 17:26:25	5	0	\N	\N
157274	GIA	AUCUNE	\N	\N	\N	Petit déjeuner M. Zeller	Petit déjeuner en l'honner de M. Zeller, ambassadeur de France près le Saint-Siège	2017-01-12 08:30:00	2017-01-12 09:30:00	\N	\N	0	0	629	\N
157312	GIA	AUCUNE	\N	\N	\N	déjeuner en l'honneur de députés arméniens	déjeuner en l'honneur d'une délégation de l'AN d'Arménie en visite en France à l'invitation du Sénat	2016-11-29 13:00:00	2016-11-29 14:30:00	\N	\N	6	0	641	\N
157612	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Sécurité publique +  PPL Cour d'assises spéciale + PPL et PPLO AAI	\N	2017-01-10 09:10:00	2017-01-10 10:10:00	2017-01-10 11:15:52	2017-01-10 16:19:13	14	0	\N	\N
158052	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2017-01-12 15:05:00	2017-01-12 16:05:00	\N	\N	234	0	\N	\N
158053	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Zone euro	Débat Zone euro	2017-01-12 16:20:00	2017-01-12 17:50:00	\N	\N	26	0	\N	\N
158054	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Hôpital	Débat Hôpital	2017-01-12 17:50:00	2017-01-12 19:35:00	\N	\N	17	0	\N	\N
159154	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Sécurité publique	\N	2017-01-10 14:00:00	2017-01-10 19:30:00	\N	\N	1	0	\N	\N
159208	MISSION	AUCUNE	\N	PSYCHIATRIE	\N	\N	\N	2017-01-11 18:30:00	2017-01-11 19:40:00	2017-01-11 19:52:47	2017-01-12 15:00:19	14	0	\N	\N
159372	MISSION	AUCUNE	\N	DEMOCRATIE	\N	\N	\N	2017-01-11 17:00:00	2017-01-11 19:05:00	2017-01-12 09:52:12	2017-01-12 15:00:18	6	0	\N	\N
159392	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Sécurité publique	\N	2017-01-11 14:00:00	2017-01-11 19:30:00	\N	\N	1	0	\N	\N
159492	DELEGATION	AUCUNE	\N	\N	206	Audition publique sur l'intelligence artificielle	\N	2017-01-19 09:05:00	2017-01-19 19:05:00	2017-01-20 18:04:32	2017-01-31 09:45:47	8	0	\N	\N
160832	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2017-01-17 09:30:00	2017-01-17 09:50:00	2017-01-18 17:09:42	2017-01-18 17:14:46	19	2	\N	\N
160995	COM_PERMANENTE	AUTRE	\N	CAE	\N	Egalité réelle outre-mer	Egalité réelle outre-mer	2017-01-17 13:30:00	2017-01-17 14:05:00	2017-01-17 15:14:21	2017-01-17 17:11:59	26	0	\N	\N
146435	DELEGATION	AUCUNE	\N	\N	211	Echanges de vues - désignation de rapporteures	Echanges de vues - désignation de rapporteures	2016-12-01 08:30:00	2016-12-01 10:00:00	2016-12-01 12:07:25	2016-12-01 14:21:22	16	0	\N	\N
146861	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Egalité réelle Outre-mer	\N	2016-12-01 10:30:00	2016-12-01 12:15:00	\N	\N	2	0	\N	\N
146977	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	Réunion de l'APCEMN	48ème AG de l'APCEMN	2016-11-29 07:15:00	2016-12-01 21:00:00	\N	\N	1	0	\N	\N
147052	DELEGATION	DEPLACEMENT	\N	\N	206	Déplacement à Genève dans le cadre du rapport sur les biotechnologies	\N	2016-11-30 09:00:00	2016-12-01 20:00:00	\N	\N	2	0	\N	\N
147092	GIA	AUCUNE	\N	\N	\N	Audition Nyima Lhoma	Audition Nyima Lhoma	2016-12-07 08:30:00	2016-12-07 09:30:00	\N	\N	3	0	634	\N
147782	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Égalité réelle outre-mer	\N	2016-12-06 14:30:00	2016-12-06 15:00:00	\N	\N	1	0	\N	\N
147793	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Égalité réelle outre-mer	\N	2016-12-06 15:00:00	2016-12-06 15:40:00	\N	\N	2	0	\N	\N
147799	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Égalité réelle outre-mer	\N	2016-12-06 16:00:00	2016-12-06 16:30:00	\N	\N	2	0	\N	\N
147802	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Égalité réelle outre-mer	\N	2016-12-06 16:30:00	2016-12-06 18:15:00	\N	\N	1	0	\N	\N
148086	MISSION	PLEIN_NON_JO	\N	BREXIT	\N	Audition de S.E. Mme Sylvie Bermann	Audition de S.E. Mme Sylvie Bermann, ambassadeur de France au Royaume-Uni	2016-12-07 08:30:00	2016-12-07 09:20:00	\N	\N	24	0	\N	\N
149332	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Autoconsommation élecrtricité	\N	2016-12-07 10:00:00	2016-12-07 11:00:00	\N	\N	1	0	\N	\N
149338	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	\N	\N	2016-12-08 10:00:00	2016-12-08 11:00:00	\N	\N	3	0	\N	\N
149632	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Transmission  et reprise d'entreprises	\N	2016-12-14 14:30:00	2016-12-14 15:15:00	\N	\N	2	0	\N	\N
150056	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	\N	2016-12-06 09:30:00	2016-12-06 10:30:00	\N	\N	1	0	\N	\N
150058	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	\N	2016-12-06 15:00:00	2016-12-06 18:00:00	\N	\N	1	0	\N	\N
150060	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	\N	2016-12-07 16:00:00	2016-12-07 18:00:00	\N	\N	1	0	\N	\N
150062	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	\N	2016-12-08 09:30:00	2016-12-08 11:30:00	\N	\N	1	0	\N	\N
150064	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	\N	2016-12-08 15:00:00	2016-12-08 16:00:00	\N	\N	1	0	\N	\N
150072	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Antoine SFEIR	Entretien avec M. Antoine SFEIR	2016-12-08 09:00:00	2016-12-08 10:00:00	\N	\N	14	0	CHRETORIENT	CHRETORIENT
156213	COM_PERMANENTE	AUTRE	\N	CDD	\N	Adaptation des territoires littoraux	Adaptation des territoires littoraux au changement climatique	2016-12-21 09:30:00	2016-12-21 11:20:00	2016-12-21 12:12:17	2016-12-21 15:07:45	27	0	\N	\N
156272	COM_PERMANENTE	AUTRE	\N	CAE	\N	Contrats de crédits aux consommateurs	Contrats de crédits aux consommateurs relatifs aux biens immobiliers	2016-12-21 09:35:00	2016-12-21 10:15:00	2018-05-18 15:45:56	2018-05-18 15:46:04	25	0	\N	\N
150258	SEANCE_PLENIERE	DECL_GVT	\N	\N	\N	Déclaration du Gouvernement Politique générale	Déclaration du Gouvernement Politique générale	2016-12-13 15:05:00	2016-12-13 15:45:00	\N	\N	180	0	\N	\N
150694	COM_EURO	AUDRAP	\N	AFEU	\N	Politique commerciale et éfense des intérêts économiques de l'Union européenne	POLITIQUE COMMERCIALE ASSURANT LA DÉFENSE DES INTÉRÊTS ÉCONOMIQUES DE L¿UNION EUROPÉENNE	2016-12-06 15:30:00	2016-12-06 16:45:00	\N	\N	2	0	\N	\N
150722	COM_EURO	AUDRAP	\N	AFEU	\N	Régulation de la finance parallèle (Shadow banking)	Régulation de la finance parallèle (Shadow banking)	2016-12-08 16:00:00	2016-12-08 17:00:00	\N	\N	1	0	\N	\N
151272	QUESTURE	AUCUNE	\N	\N	\N	Questure	\N	2016-12-13 16:00:00	2016-12-13 17:45:00	\N	\N	3	0	\N	\N
151296	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Abrogation de la « Loi Travail »	\N	2016-12-14 14:00:00	2016-12-14 16:00:00	\N	\N	1	0	\N	\N
151298	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Abrogation de la « Loi Travail »	\N	2016-12-15 14:00:00	2016-12-15 15:00:00	\N	\N	1	0	\N	\N
152659	GIA	AUCUNE	\N	\N	\N	Entretien Ambassadeur du Cambodge	Entretien Ambassadeur du Cambodge	2016-12-13 13:00:00	2016-12-13 14:30:00	\N	\N	1	0	577	\N
152661	GIA	AUCUNE	\N	\N	\N	Conférence de presse de lancement des Rendez-vous de Vientiane	Conférence de presse de lancement des Rendez-vous de Vientiane	2016-12-08 08:45:00	2016-12-08 10:30:00	\N	\N	1	0	577	\N
153657	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Groupe de travail Culture et handicap	Groupe de travail Culture et handicap	2016-12-15 14:00:00	2016-12-15 14:55:00	\N	\N	2	0	\N	\N
154892	GIA	AUCUNE	\N	\N	\N	Réception de l'ambassadrice d'Irlande et assemblée générale du groupe	Réception de S.E. Geraldine Byrne Nason, ambassadrice d'Irlande, suivie de l'assemblée générale du groupe	2016-12-15 08:15:00	2016-12-15 10:00:00	\N	\N	5	0	594	\N
156032	MISSION	AUCUNE	\N	DEMOCRATIE	\N	\N	\N	2016-12-20 13:50:00	2016-12-20 14:30:00	2016-12-21 15:24:24	2016-12-21 16:24:07	7	0	\N	\N
156052	MISSION	AUCUNE	\N	DEMOCRATIE	\N	\N	\N	2016-12-20 15:00:00	2016-12-20 15:50:00	2016-12-21 15:24:47	2016-12-21 16:24:05	4	0	\N	\N
156583	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition François Villeroy de Galhau	Audition François Villeroy de Galhau	2016-12-21 10:05:00	2016-12-21 11:25:00	2016-12-21 17:48:38	2016-12-21 17:50:19	33	0	\N	\N
157372	COM_ENQUETE	DEPLACEMENT	\N	SCHENGEN	\N	Déplacement OFPRA	\N	2017-01-05 08:00:00	2017-01-05 12:30:00	\N	\N	11	0	\N	\N
157432	DELEGATION	AUCUNE	\N	\N	DSOM	Auditions normes dans les outre-mer	Auditions normes dans les outre-mer	2017-01-12 16:30:00	2017-01-12 18:55:00	2017-01-12 19:10:10	2017-01-13 09:57:56	10	0	\N	\N
157435	DELEGATION	AUCUNE	\N	\N	DSOM	Auditions sur le foncier dans les outre-mer	Auditions sur le foncier dans les outre-mer	2017-02-01 15:00:00	2017-02-01 17:15:00	2017-02-02 16:55:53	2017-02-02 17:57:12	6	0	\N	\N
157436	DELEGATION	AUCUNE	\N	\N	DSOM	Auditions sur le foncier dans les outre-mer	Auditions sur le foncier dans les outre-mer	2017-02-01 19:00:00	2017-02-01 21:20:00	2017-02-02 17:03:54	2017-02-02 17:57:13	4	0	\N	\N
157437	DELEGATION	AUCUNE	\N	\N	DSOM	Auditions sur le foncier dans les outre-mer	Auditions sur le foncier dans les outre-mer	2017-02-02 08:30:00	2017-02-02 12:20:00	2017-02-02 17:14:43	2017-02-02 17:57:14	7	0	\N	\N
157438	DELEGATION	AUCUNE	\N	\N	DSOM	Auditions sur les normes BTP dans les outre-mer	Auditions sur les normes BTP dans les outre-mer	2017-02-09 09:30:00	2017-02-09 11:20:00	2017-02-09 13:44:34	2017-02-09 15:12:42	9	0	\N	\N
157452	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	DSOM	Rencontre avec le Dr Jean Marie Cohen	Rencontre avec le Dr Jean Marie Cohen	2017-01-17 09:30:00	2017-01-17 10:30:00	\N	\N	0	0	\N	\N
157453	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	DSOM	Conférence économique sur le bassin de l'océan Indien	Conférence économique sur le bassin de l'océan Indien	2017-02-23 09:00:00	2017-02-23 19:00:00	\N	\N	0	0	\N	\N
158232	MISSION	AUCUNE	\N	PSYCHIATRIE	\N	\N	\N	2017-01-10 17:30:00	2017-01-10 19:20:00	2017-01-11 09:38:06	2017-01-11 17:26:44	16	0	\N	\N
158273	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2017-01-11 09:10:00	2017-01-11 10:10:00	2017-01-11 15:54:45	2017-01-11 17:26:06	33	0	\N	\N
158312	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Renforcer l'efficacité de la justice pénale	\N	2017-01-10 16:30:00	2017-01-10 19:20:00	\N	\N	1	0	\N	\N
158314	MISSION	PLEIN_NON_JO	\N	BREXIT	\N	Audition de M. Hubert Védrine,	Audition de M. Hubert Védrine, ancien ministre des affaires étrangères	2017-01-11 08:35:00	2017-01-11 09:55:00	\N	\N	8	0	\N	\N
158452	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation de députés néerlandais	Accueil d'une délégation de députés néerlandais	2017-01-10 12:00:00	2017-01-10 14:00:00	\N	\N	5	0	599	\N
158669	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2017-01-11 10:05:00	2017-01-11 12:40:00	2017-01-11 15:14:20	2017-01-11 17:26:01	35	1	\N	\N
159521	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière	Réunion plénière	2017-02-09 08:45:00	2017-02-09 10:45:00	2017-02-09 11:35:12	2017-02-09 15:12:43	14	0	\N	\N
159917	GIA	AUCUNE	\N	\N	\N	déjeuner à l'invitation ambassadeur d'Irak en France	\N	2017-01-12 12:30:00	2017-01-12 15:00:00	\N	\N	1	0	615	\N
159930	MISSION	AUCUNE	\N	PSYCHIATRIE	\N	\N	\N	2017-01-12 14:05:00	2017-01-12 14:55:00	2017-01-12 15:36:26	2017-01-12 15:54:38	13	0	\N	\N
159959	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	Réforme de la PAC - Audition MOMAGRI	Réforme de la PAC - Audition de représentants de MOMAGRI	2017-01-11 17:00:00	2017-01-11 18:40:00	\N	\N	7	0	\N	\N
160259	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Egalité réelle outre-mer	PJL Egalité réelle outre-mer	2017-01-17 14:35:00	2017-01-17 16:30:00	\N	\N	151	0	\N	\N
160261	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2017-01-17 16:45:00	2017-01-17 17:40:00	\N	\N	302	0	\N	\N
160262	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Egalité réelle outre-mer	PJL Egalité réelle outre-mer	2017-01-17 17:50:00	2017-01-17 18:55:00	\N	\N	87	0	\N	\N
146193	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2017	PLFSS 2017	2016-12-01 10:30:00	2016-12-01 12:20:00	\N	\N	74	0	\N	\N
146195	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2016-12-01 15:00:00	2016-12-01 16:10:00	\N	\N	232	0	\N	\N
146888	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL accord de passation conjointe de marché de contre-mesures médicales	\N	2016-11-30 10:00:00	2016-11-30 10:45:00	\N	\N	1	0	\N	\N
146890	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL conventions ferroviaires franco-suisses	\N	2016-12-01 14:00:00	2016-12-01 14:45:00	\N	\N	1	0	\N	\N
147072	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Territoires de montagne	\N	2016-11-29 14:00:00	2016-11-29 15:00:00	\N	\N	1	0	\N	\N
147074	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Territoires de Montagne	\N	2016-11-29 16:15:00	2016-11-29 18:45:00	\N	\N	1	0	\N	\N
147076	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Territoires de Montagne	\N	2016-11-30 14:00:00	2016-11-30 15:00:00	\N	\N	1	0	\N	\N
147373	MISSION	AUCUNE	\N	DEMOCRATIE	\N	\N	\N	2016-12-06 13:35:00	2016-12-06 14:20:00	2016-12-06 15:58:59	2016-12-06 16:32:10	18	0	\N	\N
156123	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2016-12-21 10:00:00	2016-12-21 10:45:00	2016-12-22 10:13:50	2016-12-22 11:00:21	30	0	\N	\N
156455	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PPL Abrogation de la « Loi Travail »	\N	2016-12-21 10:35:00	2016-12-21 11:55:00	2016-12-22 09:48:44	2016-12-22 09:48:47	39	0	\N	\N
149252	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Égalité réelle outre-mer	PJL Égalité réelle outre-mer - Audition DGFiP Bureau des agréments et rescrits	2016-12-06 15:00:00	2016-12-06 17:00:00	\N	\N	1	0	\N	\N
149254	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Égalité réelle outre-mer	PJL Égalité réelle outre-mer - Audition de la FEDOM	2016-12-07 16:00:00	2016-12-07 18:00:00	\N	\N	1	0	\N	\N
149432	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Simplification du droit pour les entreprises	\N	2016-12-14 14:30:00	2016-12-14 15:30:00	\N	\N	2	0	\N	\N
149435	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Simplification du droit pour les entreprises	\N	2016-12-20 15:15:00	2016-12-20 16:00:00	\N	\N	2	0	\N	\N
149438	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Simplification du droit pour les entreprises	\N	2016-12-20 18:00:00	2016-12-20 19:15:00	\N	\N	2	0	\N	\N
149652	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Égalité réelle outre-mer	\N	2016-12-12 14:30:00	2016-12-12 15:10:00	\N	\N	1	0	\N	\N
151458	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Auditions traitement données à caractère personnel + Désignation CMP Statut de Paris	\N	2016-12-14 09:40:00	2016-12-14 10:30:00	2016-12-14 15:10:25	2016-12-14 15:27:37	25	1	\N	\N
151959	MISSION	PLEIN_NON_JO	\N	BREXIT	\N	Audition de M. Fabrice Leggeri	Audition de M. Fabrice Leggeri, directeur exécutif de Frontex	2016-12-14 14:10:00	2016-12-14 15:20:00	\N	\N	5	0	\N	\N
154972	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Égalité et citoyenneté	PJL Égalité et citoyenneté	2016-12-19 16:00:00	2016-12-19 19:00:00	\N	\N	35	0	\N	\N
154973	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2017	PLF 2017	2016-12-19 18:00:00	2016-12-19 20:00:00	\N	\N	24	0	\N	\N
155036	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2017 - Examen du rapport en nouvelle lecture	PLF 2017 - Examen du rapport en nouvelle lecture	2016-12-19 15:30:00	2016-12-19 16:00:00	2016-12-20 18:06:42	2016-12-21 10:44:29	12	0	\N	\N
157293	GIA	AUCUNE	\N	\N	\N	petit-déjeuner	petit-déjeuner sur les activités et projets du groupe	2016-09-29 08:30:00	2016-09-29 09:30:00	\N	\N	7	0	641	\N
157532	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Ratification ordonnances applicables à la Corse	\N	2017-01-09 09:00:00	2017-01-09 10:50:00	\N	\N	2	0	\N	\N
157890	COM_PERMANENTE	AUTRE	\N	CAE	\N	Egalité réelle outre-mer	PJL n° 19 relatif à l'égalité réelle outre-mer	2017-01-10 15:00:00	2017-01-10 16:10:00	2018-05-18 15:47:05	2018-05-18 15:47:07	27	0	\N	\N
158004	COM_PERMANENTE	AUTRE	\N	CDD	\N	Egalité réelle outre-mer	PJL n° 19 Egalité réelle outre-mer	2017-01-10 15:35:00	2017-01-10 16:20:00	2018-05-18 15:47:22	2018-05-18 15:47:25	26	0	\N	\N
158513	COM_ENQUETE	PLENIERE	\N	ATTEINTES	\N	6ème séquence du cycle d'auditions généralistes	Table ronde des associations des élus locaux  (AMF, ADF, ARF, AdCF)	2017-01-11 14:10:00	2017-01-11 15:40:00	2017-01-13 14:23:04	2017-01-13 15:17:37	9	0	\N	\N
160236	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	\N	\N	2017-01-10 14:30:00	2017-01-10 15:30:00	\N	\N	1	0	\N	\N
160239	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	\N	\N	2017-01-10 15:45:00	2017-01-10 16:30:00	\N	\N	1	0	\N	\N
160247	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	\N	\N	2017-01-12 09:30:00	2017-01-12 10:30:00	\N	\N	4	0	\N	\N
160255	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	\N	\N	2017-01-12 10:30:00	2017-01-12 12:00:00	\N	\N	4	0	\N	\N
160263	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Egalité réelle outre-mer	PJL Egalité réelle outre-mer	2017-01-17 21:30:00	2017-01-18 00:05:00	\N	\N	55	0	\N	\N
160272	COM_ENQUETE	PLENIERE	\N	SCHENGEN	\N	CE SCHENGEN	CE SCHENGEN	2017-01-11 15:05:00	2017-01-11 17:25:00	2017-01-12 17:14:42	2017-01-12 17:22:18	16	0	\N	\N
160289	COM_ENQUETE	PLENIERE	\N	SCHENGEN	\N	CE SCHENGEN	CE SCHENGEN	2017-01-12 11:05:00	2017-01-12 12:35:00	2017-01-12 17:16:51	2017-01-12 17:22:16	13	0	\N	\N
160472	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Renforcer l'efficacité de la justice pénale	\N	2017-01-11 14:30:00	2017-01-11 19:40:00	\N	\N	1	0	\N	\N
160532	COM_PERMANENTE	AUTRE	\N	CDD	\N	Littoral et changement climatique	Adaptation des territoires littoraux au changement climatique	2017-01-11 20:45:00	2017-01-11 20:55:00	2017-01-13 16:27:45	2017-01-13 17:27:01	8	0	\N	\N
160612	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI redressement de la justice	\N	2017-01-11 14:00:00	2017-01-11 18:30:00	\N	\N	2	0	\N	\N
160615	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI redressement de la justice	\N	2017-01-12 14:30:00	2017-01-12 15:00:00	\N	\N	1	0	\N	\N
160617	GIA	AUCUNE	\N	\N	\N	Audition de M. Jean-François COLOSIMO	Audition de M. Jean-François COLOSIMO, philosophe, spécialiste des religions	2017-01-12 09:30:00	2017-01-12 11:00:00	\N	\N	16	0	CHRETORIENT	CHRETORIENT
160752	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Égalité réelle outre-mer	\N	2017-01-17 09:05:00	2017-01-17 09:20:00	2017-01-17 11:32:01	2017-01-17 17:12:01	16	0	\N	\N
160905	COM_PERMANENTE	AUTRE	\N	FINC	\N	PJL Égalité réelle outre-mer - Examen des amendements de séance	PJL Égalité réelle outre-mer - Examen des amendements de séance	2017-01-17 09:30:00	2017-01-17 09:50:00	2017-01-18 10:51:14	2017-01-18 17:14:48	16	0	\N	\N
162262	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière	Réunion plénière	2017-02-23 08:30:00	2017-02-23 09:50:00	2017-02-23 10:43:20	2017-02-23 15:14:09	16	0	\N	\N
162752	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Renforcer l'efficacité de la justice pénale	\N	2017-01-17 14:30:00	2017-01-17 16:40:00	\N	\N	1	0	\N	\N
162792	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2017-01-18 10:35:00	2017-01-18 11:30:00	2017-01-18 11:58:29	2017-01-18 17:14:58	44	0	\N	\N
162852	COM_PERMANENTE	AUTRE	\N	CDD	\N	Déplacement à Marrakech dans le cadre de la COP22	Déplacement à Marrakech dans le cadre de la COP22	2017-01-18 09:35:00	2017-01-18 10:50:00	2018-05-18 15:48:36	2018-05-18 15:48:40	28	0	\N	\N
163012	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de M. Didier MIGAUD, président CPO	Audition de M. Didier MIGAUD, président du Conseil des prélèvements obligatoires (CPO)	2017-01-18 10:30:00	2017-01-18 12:10:00	2017-01-18 16:56:26	2017-01-18 17:14:56	34	0	\N	\N
163532	MISSION	AUDRAP	\N	DEMOCRATIE	\N	\N	\N	2017-01-17 17:45:00	2017-01-17 19:00:00	\N	\N	7	0	\N	\N
163572	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe France-Pays Baltes	Assemblée générale du groupe France-Pays Baltes	2017-01-18 14:15:00	2017-01-18 14:30:00	\N	\N	7	0	616	\N
156312	CMP	AUTRE	\N	STATUT	\N	PJL Statut de Paris	PJL Statut de Paris	2016-12-21 12:05:00	2016-12-21 12:20:00	\N	\N	9	0	\N	\N
162772	CMP	AUTRE	\N	ANSP	\N	PJL Création de l'Agence nationale de santé publique	PJL Création de l'Agence nationale de santé publique	2017-01-17 18:05:00	2017-01-17 18:25:00	\N	\N	8	0	\N	\N
163912	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Egalité outre-mer	PJL Egalité outre-mer	2017-01-19 10:30:00	2017-01-19 11:35:00	\N	\N	40	0	\N	\N
163913	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Egalité outre-mer	PJL Egalité outre-mer	2017-01-19 14:30:00	2017-01-19 18:40:00	\N	\N	45	0	\N	\N
146312	ETUDES	AUCUNE	\N	\N	\N	\N	\N	2016-11-30 17:00:00	2016-11-30 20:00:00	\N	\N	12	0	\N	928
146458	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	ENTREPRISES	Réunion du Bureau de la Délégation	\N	2016-12-14 12:30:00	2016-12-14 14:20:00	\N	\N	5	0	\N	\N
146466	COM_EURO	CONTROLE	\N	AFEU	\N	\N	Réunion du 1er décembre 2016	2016-12-01 09:00:00	2016-12-01 10:20:00	2016-12-01 16:43:36	2016-12-01 17:40:44	18	0	\N	\N
146492	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	PROS	Organisation des travaux de la délégation	\N	2016-12-01 08:30:00	2016-12-01 09:10:00	\N	\N	9	0	\N	\N
146980	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Simplification du droit pour les entreprises	\N	2016-12-07 09:00:00	2016-12-07 09:45:00	\N	\N	2	0	\N	\N
147870	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Massif central	Débat	2016-12-08 11:00:00	2016-12-08 12:40:00	\N	\N	26	0	\N	\N
147871	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat La Poste	Débat La Poste	2016-12-08 15:00:00	2016-12-08 16:30:00	\N	\N	24	0	\N	\N
147872	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Montagne	PJL Montagne	2016-12-12 15:05:00	2016-12-12 19:55:00	\N	\N	40	0	\N	\N
147873	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Montagne	PJL Montagne	2016-12-12 21:30:00	2016-12-13 02:00:00	\N	\N	32	0	\N	\N
149375	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Territoires littoraux	PJL Territoires littoraux	2016-12-07 15:30:00	2016-12-07 16:30:00	\N	\N	1	0	\N	\N
149377	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Territoires Littoraux	PJL Territoires Littoraux	2016-12-07 18:30:00	2016-12-07 20:00:00	\N	\N	1	0	\N	\N
149379	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Territoires littoraux	PJL Territoires littoraux	2016-12-08 09:00:00	2016-12-08 10:00:00	\N	\N	2	0	\N	\N
149382	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Territoires Littoraux	PJL Territoires Littoraux	2016-12-08 11:00:00	2016-12-08 11:30:00	\N	\N	1	0	\N	\N
149392	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Déradicalisation	\N	2016-12-07 15:30:00	2016-12-07 16:50:00	\N	\N	1	0	\N	\N
149912	COM_PERMANENTE	AUTRE	\N	CDD	\N	Territoires de montagne	Modernisation, développement et protection des territoires de montagne	2016-12-12 14:00:00	2016-12-12 14:35:00	2018-05-18 15:45:00	2018-05-18 15:45:07	11	0	\N	\N
149976	COM_PERMANENTE	AUTRE	\N	CAE	\N	Territoires de montagne	Territoires de montagne	2016-12-12 14:00:00	2016-12-12 14:30:00	2016-12-13 11:12:45	2016-12-13 16:08:57	3	0	\N	\N
150016	COM_PERMANENTE	AUTRE	\N	CAE	\N	Territoires de montagne	Territoires de montagne	2016-12-13 09:00:00	2016-12-13 09:30:00	2018-05-18 15:45:28	2018-05-18 15:45:33	11	0	\N	\N
150152	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Egalité réelle Outre-mer	\N	2016-12-13 10:30:00	2016-12-13 11:30:00	\N	\N	1	0	\N	\N
150154	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Égalité réelle outre-mer	\N	2016-12-13 09:05:00	2016-12-13 10:35:00	2016-12-14 14:57:42	2016-12-14 15:09:04	18	0	\N	\N
150192	COM_EURO	AUDRAP	\N	AFEU	\N	Audiition Perturbateurs endocriniens	\tAudition rapporteur - Commission des affaires européennes - Audiition Perturbateurs endocriniens	2016-12-13 10:00:00	2016-12-13 12:00:00	\N	\N	2	0	\N	\N
151487	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2016-12-14 09:50:00	2016-12-14 11:45:00	2016-12-14 15:16:31	2016-12-14 15:27:42	42	2	\N	\N
151598	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2016-12-14 09:05:00	2016-12-14 11:55:00	2016-12-14 15:02:30	2016-12-14 15:27:27	39	0	\N	\N
152011	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	Accueil d'une délégtion du Québec	Entretien des membres du groupe avec M. Gaëtan BARRETTE, ministre de la Santé et des Services sociaux du Québec et Mme L	2016-12-14 12:30:00	2016-12-14 14:30:00	\N	\N	5	0	\N	\N
152772	GIA	AUCUNE	\N	\N	\N	Assemblée générale	\N	2016-12-15 08:15:00	2016-12-15 09:30:00	\N	\N	5	0	644	\N
153072	COM_ENQUETE	PLENIERE	\N	ATTEINTES	\N	Audition de M. Paul DELDUC, DGALN	Audition de M. Paul DELDUC, directeur général de l'aménagement, du logement et de la nature 	2016-12-15 14:05:00	2016-12-16 14:55:00	2016-12-16 15:45:32	2016-12-16 15:47:04	9	0	\N	\N
153640	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Cour d'assises spéciale	\N	2016-12-14 18:30:00	2016-12-14 19:00:00	\N	\N	1	0	\N	\N
153672	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 15 décembre 2016	Réunion du 15 décembre 2016	2016-12-15 08:35:00	2016-12-15 10:25:00	2016-12-15 17:46:42	2016-12-15 18:00:19	15	0	\N	\N
154152	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	\N	2016-12-13 14:30:00	2016-12-13 16:50:00	\N	\N	1	0	\N	\N
154154	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	\N	2016-12-13 17:40:00	2016-12-13 18:40:00	\N	\N	1	0	\N	\N
154156	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	\N	2016-12-14 14:00:00	2016-12-14 17:00:00	\N	\N	1	0	\N	\N
155076	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2016-12-20 09:30:00	2016-12-20 13:00:00	\N	\N	33	0	\N	\N
155077	SEANCE_PLENIERE	ELOGE_FUNEBRE	\N	\N	\N	Éloge funèbre de Louis PINTON	Éloge funèbre de Louis PINTON	2016-12-20 14:30:00	2016-12-20 15:00:00	\N	\N	0	0	\N	\N
155093	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Liaison ferroviaire Paris-CDG	CMP Liaison ferroviaire Paris-CDG	2016-12-20 15:00:00	2016-12-20 16:45:00	\N	\N	66	0	\N	\N
155094	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2016-12-20 16:45:00	2016-12-20 17:45:00	\N	\N	245	0	\N	\N
155095	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Sapeurs-pompiers	PPL Sapeurs-pompiers	2016-12-20 17:45:00	2016-12-20 21:00:00	\N	\N	55	0	\N	\N
155096	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Sapeurs-pompiers	PPL Sapeurs-pompiers	2016-12-20 20:00:00	2016-12-21 00:00:00	\N	\N	0	0	\N	\N
155097	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Conso	PJL Conso	2016-12-21 14:30:00	2016-12-21 21:00:00	\N	\N	42	0	\N	\N
155098	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Transport de personnes	CMP Transport de personnes	2016-12-21 15:30:00	2016-12-21 21:00:00	\N	\N	21	0	\N	\N
155099	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Montagne	CMP Montagne	2016-12-21 16:30:00	2016-12-21 21:00:00	\N	\N	26	0	\N	\N
155100	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Cour d'assises	PPL Cour d'assises	2017-01-10 15:00:00	2017-01-10 16:20:00	\N	\N	60	0	\N	\N
155101	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL et PPLO Autorités administratives indépendantes	PPL et PPLO Autorités administratives indépendantes	2017-01-10 16:20:00	2017-01-10 17:35:00	\N	\N	74	0	\N	\N
155102	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Services déconcentrés de l'Etat	Débat Services déconcentrés de l'Etat	2017-01-10 21:35:00	2017-01-10 23:00:00	\N	\N	39	0	\N	\N
155762	QUESTURE	AUCUNE	\N	\N	\N	Questure	\N	2016-12-20 14:50:00	2016-12-20 16:45:00	\N	\N	3	0	\N	\N
156192	GIA	AUCUNE	\N	\N	\N	petit-déjeuner	autour de Mme Hélène Duchêne, ambassadrice à l'OTAN	2016-12-21 08:15:00	2016-12-21 09:30:00	\N	\N	9	0	608	\N
157172	COM_ENQUETE	PLENIERE	\N	SCHENGEN	\N	CE SCHENGEN	CE SCHENGEN	2017-01-03 11:00:00	2017-01-03 12:45:00	2017-01-04 15:56:20	2017-01-04 17:21:10	10	0	\N	\N
183131	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Nucléaire	\N	2017-03-08 16:30:00	2017-03-08 17:30:00	\N	\N	3	0	\N	\N
150252	CMP	AUTRE	\N	PLF2017	\N	PLF 2017	PLF 2017	2016-12-13 13:30:00	2016-12-13 13:50:00	\N	\N	6	0	\N	\N
151332	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2016-12-14 09:30:00	2016-12-14 09:50:00	2016-12-14 15:16:58	2016-12-14 15:27:32	42	2	\N	\N
157212	COM_ENQUETE	PLENIERE	\N	SCHENGEN	\N	CE SCHENGEN	CE SCHENGEN	2017-01-03 14:40:00	2017-01-03 17:00:00	2017-01-04 15:57:35	2017-01-04 17:21:12	14	0	\N	\N
157332	COM_ENQUETE	PLENIERE	\N	SCHENGEN	\N	CE SCHENGEN	CE SCHENGEN	2017-01-04 10:05:00	2017-01-04 12:20:00	2017-01-04 15:58:51	2017-01-04 17:21:13	16	0	\N	\N
157742	COM_EURO	AUTRE_NON_PLENIERE	\N	AFEU	\N	Réunion avec des parlementaires néerlandais	Réunion avec des parlementaires néerlandais	2017-01-10 10:00:00	2017-01-10 11:00:00	\N	\N	1	0	\N	\N
158608	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2017-01-11 14:15:00	2017-01-11 14:35:00	2017-01-11 15:26:54	2017-01-11 17:25:58	27	0	\N	\N
159532	COM_ENQUETE	PLENIERE	\N	ATTEINTES	\N	Huitième séquence d'auditions généralistes	Audition du Conseil national de protection de la nature (CNPN)	2017-01-12 14:05:00	2017-01-12 15:00:00	2017-01-13 14:24:23	2017-01-13 15:17:32	8	0	\N	\N
159552	COM_ENQUETE	PLENIERE	\N	ATTEINTES	\N	Septième séquence du cycle d'auditions généralistes	Audition de l'Association des sociétés d'autoroutes françaises (ASFA)	2017-01-11 16:35:00	2017-01-11 18:05:00	2017-01-13 14:23:47	2017-01-13 15:17:35	9	0	\N	\N
160238	COM_ENQUETE	PLENIERE	\N	ATTEINTES	\N	9ème séquence du cycle d'auditions généralistes	\N	2017-01-12 16:35:00	2017-01-12 17:50:00	2017-01-13 14:25:43	2017-01-13 15:17:30	6	0	\N	\N
146532	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Égalité réelle outre-mer	\N	2016-12-01 09:30:00	2016-12-01 10:30:00	\N	\N	1	0	\N	\N
146864	COM_EURO	CONTROLE	\N	AFEU	\N	\N	Audition Vestagher	2016-12-01 13:30:00	2016-12-01 14:30:00	2016-12-01 18:22:13	2016-12-01 18:24:22	19	0	\N	\N
146912	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI redressement de la justice	\N	2016-11-30 14:00:00	2016-11-30 15:30:00	\N	\N	2	0	\N	\N
146915	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI redressement de la justice	\N	2016-11-30 17:30:00	2016-11-30 19:30:00	\N	\N	1	0	\N	\N
146917	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI redressement de la justice	\N	2016-12-01 09:00:00	2016-12-01 12:00:00	\N	\N	3	0	\N	\N
147152	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Simplification du droit pour les entreprises	\N	2016-12-06 15:45:00	2016-12-06 16:30:00	\N	\N	2	0	\N	\N
147232	MISSION	DEPLACEMENT	\N	BREXIT	\N	Rencontre avec les institutions européennes à Bruxelles	Rencontre avec les institutions européennes à Bruxelles-5 et 6 décembre 2016	2016-12-06 09:00:00	2016-12-06 12:35:00	\N	\N	2	0	\N	\N
147812	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2016-12-06 15:15:00	2016-12-06 17:45:00	2016-12-07 10:16:37	2016-12-07 15:46:27	43	0	\N	\N
148028	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2016-12-07 10:20:00	2016-12-07 10:40:00	2016-12-07 11:49:04	2016-12-07 15:50:01	39	0	\N	\N
148116	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2016-12-07 10:30:00	2016-12-07 11:10:00	2016-12-07 11:37:50	2016-12-07 15:50:00	38	0	\N	\N
148620	GIA	AUCUNE	\N	\N	\N	Réunion	\N	2016-12-07 14:30:00	2016-12-07 15:00:00	\N	\N	5	0	575	\N
148932	GIA	AUCUNE	\N	\N	\N	AG du groupe d 'amitié	\N	2016-12-07 08:30:00	2016-12-07 09:30:00	\N	\N	9	0	584	\N
149361	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPRE Directive Droits d'auteur	PPRE Directive Droits d'auteur	2016-12-07 15:45:00	2016-12-07 17:30:00	\N	\N	1	0	\N	\N
149366	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPRE Directive Droits d'auteur	PPRE Directive Droits d'auteur	2016-12-08 14:45:00	2016-12-08 17:30:00	\N	\N	1	0	\N	\N
149412	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT AFEU - Propriété intellectuelle	Laboratoire de Physiologie Cellulaire Végétale	2016-12-08 09:30:00	2016-12-08 10:25:00	\N	\N	3	0	\N	\N
149472	SEANCE_PLENIERE	ELOGE_FUNEBRE	\N	\N	\N	Éloge funèbre Paul Vergès	Éloge funèbre Paul Vergès	2016-12-13 14:15:00	2016-12-13 14:45:00	\N	\N	19	0	\N	\N
149473	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Montagne	PJL Montagne	2016-12-13 16:05:00	2016-12-13 17:55:00	\N	\N	88	0	\N	\N
149474	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Réunion Conseil européen	Débat Réunion Conseil européen	2016-12-13 18:00:00	2016-12-13 19:55:00	\N	\N	57	0	\N	\N
149475	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Montagne	PJL Montagne	2016-12-13 21:30:00	2016-12-14 02:00:00	\N	\N	64	0	\N	\N
149492	DELEGATION	AUDRAP	\N	\N	COLTER	RI_nouvelles technologies au service des CT	RI-nouvelles technologies au service des CT	2016-12-14 15:30:00	2016-12-14 16:30:00	\N	\N	2	0	\N	\N
149493	DELEGATION	AUDRAP	\N	\N	COLTER	RI-nouvelles technologies au service des CT	RI-nouvelles technologies au service des CT	2016-12-20 10:15:00	2016-12-20 11:15:00	\N	\N	2	0	\N	\N
149494	DELEGATION	AUDRAP	\N	\N	COLTER	RI-nouvelles technologies au service des CT	RI-nouvelles technologies au service des CT	2017-01-10 10:15:00	2017-01-10 11:15:00	\N	\N	2	0	\N	\N
149495	DELEGATION	AUDRAP	\N	\N	COLTER	RI-nouvelles technologies au service des CT	RI-nouvelles technologies au service des CT	2017-01-17 10:15:00	2017-01-17 11:15:00	\N	\N	2	0	\N	\N
149496	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT Droits d'auteur	La Quadrature du Net	2016-12-07 15:45:00	2016-12-07 16:30:00	\N	\N	2	0	\N	\N
149499	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT Droits d'auteur	Canal+	2016-12-07 16:30:00	2016-12-07 17:40:00	\N	\N	2	0	\N	\N
149502	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT Droits d'auteur	SACEM/SACD	2016-12-08 10:30:00	2016-12-08 12:00:00	\N	\N	2	0	\N	\N
149505	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT Droits d'auteur	Association de lutte contre la piraterie audiovisuelle (ALPA)	2016-12-08 14:45:00	2016-12-08 15:40:00	\N	\N	2	0	\N	\N
149508	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT Droits d'auteur	CNL/CNC	2016-12-08 15:40:00	2016-12-08 16:45:00	\N	\N	2	0	\N	\N
149512	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT Droits d'auteur	Google	2016-12-08 16:45:00	2016-12-08 17:50:00	\N	\N	2	0	\N	\N
149973	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Montagne	PJL Montagne	2016-12-14 18:20:00	2016-12-14 19:00:00	\N	\N	54	0	\N	\N
149974	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Montagne	PJL Montagne	2016-12-14 21:30:00	2016-12-15 02:05:00	\N	\N	64	0	\N	\N
149975	SEANCE_PLENIERE	DECL_GVT	\N	\N	\N	Déclaration du Gouvernement	Déclaration du Gouvernement	2016-12-14 16:15:00	2016-12-14 18:10:00	\N	\N	186	0	\N	\N
151012	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Egalité réelle Outre-mer	\N	2016-12-13 17:20:00	2016-12-13 17:45:00	\N	\N	1	0	\N	\N
147928	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2016-12-07 10:00:00	2016-12-07 10:20:00	2016-12-07 11:48:50	2016-12-07 15:50:04	38	0	\N	\N
148192	COM_PERMANENTE	AUTRE	\N	CDD	\N	Territoires de montagne	Protection des territoires de montagne	2016-12-07 09:00:00	2016-12-07 10:30:00	2016-12-07 14:33:49	2016-12-07 15:50:07	32	0	\N	\N
148332	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Nominations rapporteurs + PPL Sapeurs-pompiers + PPL Délit d'entrave à l'IVG	\N	2016-12-07 09:05:00	2016-12-07 12:15:00	2016-12-07 14:45:48	2016-12-07 15:50:06	40	0	\N	\N
151039	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Égalité réelle outre-mer	\N	2016-12-13 18:45:00	2016-12-13 19:25:00	\N	\N	1	0	\N	\N
151252	COM_EURO	DEPLACEMENT	\N	AFEU	\N	Position de l'Italie dans les négociations européennes	Position de l'Italie dans les négociations européennes	2016-12-11 11:00:00	2016-12-13 16:30:00	\N	\N	6	0	\N	\N
151292	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Egalité réelle Outre-mer	\N	2016-12-16 09:00:00	2016-12-16 11:30:00	\N	\N	1	0	\N	\N
151294	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Egalité réelle Outre-mer	\N	2016-12-16 15:00:00	2016-12-16 17:30:00	\N	\N	1	0	\N	\N
151558	MECSS	AUCUNE	\N	\N	MECSS	\N	\N	2016-12-14 14:35:00	2016-12-14 15:15:00	2016-12-14 15:19:47	2016-12-14 15:39:38	12	0	\N	\N
152752	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFR 2016	PLFR 2016	2016-12-16 09:30:00	2016-12-16 12:55:00	\N	\N	42	0	\N	\N
152753	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFR 2016	PLFR 2016	2016-12-16 14:30:00	2016-12-16 20:00:00	\N	\N	49	0	\N	\N
152755	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFR 2016	PLFR 2016	2016-12-16 21:30:00	2016-12-17 00:00:00	\N	\N	34	0	\N	\N
152832	ETUDES	AUCUNE	\N	\N	\N	GE Communications électroniques et Poste	GE Communications électroniques et Poste	2016-12-14 08:15:00	2016-12-14 09:15:00	\N	\N	3	0	\N	913
152838	ETUDES	AUCUNE	\N	\N	\N	GE Vigne et Vin	GE Vigne et Vin	2016-12-14 14:00:00	2016-12-14 15:00:00	\N	\N	11	0	\N	909
152850	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Ordonnances consommation	PJL Ordonnances consommation	2016-12-13 16:30:00	2016-12-13 19:00:00	\N	\N	1	0	\N	\N
153019	BUREAU	AUCUNE	\N	\N	\N	Bureau du Sénat	Bureau du Sénat	2016-12-15 09:00:00	2016-12-15 11:45:00	\N	\N	21	0	\N	\N
154133	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI redressement de la justice	\N	2016-12-13 15:30:00	2016-12-13 17:00:00	\N	\N	2	0	\N	\N
154136	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI redressement de la justice	\N	2016-12-13 17:45:00	2016-12-13 19:00:00	\N	\N	1	0	\N	\N
154138	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI redressement de la justice	\N	2016-12-14 14:30:00	2016-12-14 16:15:00	\N	\N	1	0	\N	\N
154140	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI redressement de la justice	\N	2016-12-14 18:15:00	2016-12-14 19:00:00	\N	\N	1	0	\N	\N
154142	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI redressement de la justice	\N	2016-12-15 09:00:00	2016-12-15 12:15:00	\N	\N	2	0	\N	\N
154158	GIA	AUCUNE	\N	\N	\N	Visite Bureau du Tibet à Paris	Visite Bureau du Tibet à Paris	2016-12-15 11:00:00	2016-12-15 14:00:00	\N	\N	1	0	634	\N
154298	COM_EURO	AUTRE_NON_PLENIERE	\N	AFEU	\N	Entretien avec M. Kossatchev (parlementaire russe)	Entretien avec M. Kossatchev (parlementaire russe)	2016-12-15 11:00:00	2016-12-15 12:00:00	\N	\N	2	0	\N	\N
154301	COM_EURO	AUTRE_NON_PLENIERE	\N	AFEU	\N	Entretien avec l'ambassadeur de Bosnie-Herzégovine en France	Entretien avec l'ambassadeur de Bosnie-Herzégovine en France	2016-12-14 11:00:00	2016-12-14 11:45:00	\N	\N	1	0	\N	\N
155312	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Sapeurs-pompiers + PPL Littoral	\N	2016-12-20 09:10:00	2016-12-20 09:55:00	2016-12-20 12:05:29	2016-12-20 18:03:26	14	0	\N	\N
156632	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Égalité réelle outre-mer	PJL Égalité réelle outre-mer - Audition de Inter-Invest	2016-12-20 14:00:00	2016-12-20 15:00:00	\N	\N	1	0	\N	\N
156712	MISSION	AUCUNE	\N	PSYCHIATRIE	\N	\N	\N	2016-12-21 14:30:00	2016-12-21 15:40:00	2016-12-22 09:50:08	2016-12-22 09:50:10	11	0	\N	\N
157818	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2017-01-10 15:05:00	2017-01-10 16:10:00	2017-01-10 16:51:06	2017-01-10 17:45:38	37	2	\N	\N
158072	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Abrogation loi travail	PPL Abrogation loi travail	2017-01-11 14:35:00	2017-01-11 16:55:00	\N	\N	103	0	\N	\N
158073	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR Enseignement supérieur	PPR Enseignement supérieur	2017-01-11 17:00:00	2017-01-11 18:40:00	\N	\N	59	0	\N	\N
147173	DELEGATION	AUDRAP	\N	\N	206	Auditions dans le cadre du rapport sur l'Intelligence artificielle	\N	2016-11-30 14:30:00	2016-11-30 18:15:00	\N	\N	2	0	\N	\N
147272	DELEGATION	DEPLACEMENT	\N	\N	ENTREPRISES	Déplacement dans l'Aube à la rencontre d'entrepreneurs	\N	2017-01-19 07:00:00	2017-01-19 18:45:00	\N	\N	3	0	\N	\N
147572	QUESTURE	AUCUNE	\N	\N	\N	Questure	\N	2016-12-06 14:30:00	2016-12-06 16:30:00	\N	\N	3	0	\N	\N
147668	COM_PERMANENTE	AUTRE	\N	CAE	\N	PJL Territoires de montagne	PJL de modernisation et de protection des territoires de montagne	2016-12-06 15:00:00	2016-12-06 17:30:00	2018-05-18 15:43:56	2018-05-18 15:44:03	29	0	\N	\N
148634	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Groupe de travail Culture et handicap	\N	2016-12-06 14:30:00	2016-12-06 16:20:00	\N	\N	2	0	\N	\N
148637	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Groupe de travail Culture et handicap	\N	2016-12-07 14:00:00	2016-12-07 14:55:00	\N	\N	2	0	\N	\N
148732	GIA	AUCUNE	\N	\N	\N	Entretien Ambassadeur du Brunei	Entretien avec S.E. Mme Datin Malai Hajah Halimah MALAI HAJI YUSSOF, ambassadeur du Brunei en France	2016-12-07 16:30:00	2016-12-07 17:15:00	\N	\N	2	0	609	\N
149092	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2016-12-08 10:30:00	2016-12-08 11:00:00	\N	\N	14	0	\N	\N
149132	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Egalité réelle Outre-mer	\N	2016-12-08 09:00:00	2016-12-08 09:30:00	\N	\N	1	0	\N	\N
149972	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Montagne	PJL Montagne	2016-12-14 14:30:00	2016-12-14 16:00:00	\N	\N	100	0	\N	\N
150853	COM_EURO	AUDRAP	\N	AFEU	\N	Audition simplification	Audition simplification et marché unique	2016-12-13 16:05:00	2016-12-13 16:55:00	\N	\N	2	0	\N	\N
152792	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Territoires  Littoraux	PPL Territoires Littoraux	2016-12-13 14:00:00	2016-12-13 15:45:00	\N	\N	2	0	\N	\N
152852	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLFR pour 2016 - Examen des amendements	PLFR pour 2016 - Examen des amendements	2016-12-15 09:05:00	2016-12-15 10:55:00	2016-12-15 17:28:43	2016-12-15 17:59:33	26	0	\N	\N
154352	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFR 2016	PLFR 2016	2016-12-17 09:30:00	2016-12-17 13:30:00	\N	\N	34	0	\N	\N
154353	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFR 2016	PLFR 2016	2016-12-17 14:30:00	2016-12-17 19:30:00	\N	\N	32	0	\N	\N
154932	DELEGATION	AUDRAP	\N	\N	211	Audition de Mme Astrid MARAIS	Audition de Mme Astrid MARAIS	2016-12-13 16:00:00	2016-12-13 17:30:00	\N	\N	2	0	\N	\N
157272	DELEGATION	AUCUNE	\N	\N	COLTER	Audition de M. Thornary, commissaire général à l'égalité des territoires	\N	2017-01-12 09:00:00	2017-01-12 10:30:00	2017-01-12 10:56:19	2017-01-12 14:58:23	7	0	\N	\N
157392	GIA	AUCUNE	\N	\N	\N	entretien 	entretien avec SE M. Gilles Favret	2017-01-05 15:30:00	2017-01-05 16:15:00	\N	\N	1	0	651	\N
157674	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2017-01-10 15:05:00	2017-01-10 15:50:00	2017-01-10 16:43:01	2017-01-10 17:45:39	30	0	\N	\N
158074	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Changement climatique	PPL Changement climatique	2017-01-11 18:45:00	2017-01-11 19:30:00	\N	\N	36	0	\N	\N
158075	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Changement climatique	PPL Changement climatique	2017-01-11 21:05:00	2017-01-12 00:15:00	\N	\N	50	0	\N	\N
155273	CMP	AUTRE	\N	MONTAGNE	\N	PJL Territoires de montagne	PJL Territoires de montagne	2016-12-19 16:00:00	2016-12-19 20:50:00	\N	\N	11	0	\N	\N
158214	DELEGATION	AUDRAP	\N	\N	COLTER	RI-nouvelles technologies au service des CT	Audition de S. E M. Streimann, ambassadeur d'Estonie	2017-01-11 10:15:00	2017-01-11 11:15:00	\N	\N	2	0	\N	\N
158217	DELEGATION	AUDRAP	\N	\N	COLTER	RI-nouvelles technologies au service des CT	audition FNCCR	2017-01-24 10:15:00	2017-01-24 11:15:00	\N	\N	2	0	\N	\N
158365	COM_PERMANENTE	AUTRE	\N	CDD	\N	Déplacement de la commission en Californie	Déplacement de la commission en Californie	2017-01-11 10:30:00	2017-01-11 11:10:00	2018-05-18 15:48:16	2018-05-18 15:48:19	30	0	\N	\N
158973	MISSION	PLEIN_NON_JO	\N	BREXIT	\N	Audition de Mme Pervenche Berès, députée européenne, et M. Jean-Claude Trichet, Président 	Audition de Mme Pervenche Berès, députée européenne, et M. Jean-Claude Trichet, Président de la Banque centrale européen	2017-01-11 14:40:00	2017-01-11 16:40:00	\N	\N	8	0	\N	\N
159412	GIA	AUCUNE	\N	\N	\N	Petit déjeuner en l'honneur de M. Zeller, ambassadeur auprès du Saint-Siège	Petit déjeuner en l'honneur de M. Zeller, ambassadeur auprès du Saint-Siège	2017-01-12 08:30:00	2017-01-12 09:45:00	\N	\N	15	0	629	\N
159438	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 12 janvier 2017	Réunion du 12 janvier 2017	2017-01-12 09:05:00	2017-01-12 10:45:00	2017-02-02 15:25:14	2017-02-02 15:26:39	19	0	\N	\N
159512	GIA	AUCUNE	\N	\N	\N	Réunion 	Réunion organisée par le président du groupe pour informer ses collègues de sa décision de quitter le Sénat  	2016-12-21 15:00:00	2016-12-21 15:45:00	\N	\N	4	0	653	\N
159825	DELEGATION	AUCUNE	\N	\N	211	Débat sur le rapport "La laïcité garantit-elle l'égalité femmes-hommes ?"	Débat sur le rapport "La laïcité garantit-elle l'égalité femmes-hommes ?"	2017-01-12 09:30:00	2017-01-12 13:00:00	2017-01-12 15:24:21	2017-01-12 15:53:45	16	0	\N	\N
160474	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Groupe de travail Culture et handicap	Groupe de travail Culture et handicap	2017-01-12 14:00:00	2017-01-12 15:00:00	\N	\N	2	0	\N	\N
160477	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	groupe de travail Rythmes scolaires	groupe de travail Rythmes scolaires	2017-01-11 15:00:00	2017-01-11 17:00:00	\N	\N	1	0	\N	\N
160512	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	groupe de travail Rythmes scolaires	groupe de travail Rythmes scolaires	2017-01-12 09:00:00	2017-01-12 11:00:00	\N	\N	3	0	\N	\N
160533	COM_EURO	AUDRAP	\N	AFEU	\N	Paquet "Droit d'auteur"	\N	2017-01-11 00:00:00	2017-01-11 13:15:00	\N	\N	2	0	\N	\N
160672	GIA	AUCUNE	\N	\N	\N	coopération interparlemenaire-déleg. Japonaise-bicamérisme-démocratie participative	\N	2017-01-10 13:00:00	2017-01-10 14:30:00	\N	\N	1	0	596	\N
160674	GIA	AUCUNE	\N	\N	\N	coopération interparlemenaire-déleg. Japonaise-bicamérisme-démocratie participative	\N	2017-01-10 14:30:00	2017-01-10 15:30:00	\N	\N	2	0	596	\N
160772	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2017-01-17 09:00:00	2017-01-17 09:45:00	2017-01-17 10:55:14	2017-01-17 17:12:01	23	0	\N	\N
161222	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Conférence interparlementaire Art 13 TSCG	Conférence interparlementaire Art 13 TSCG à Bruxelles	2017-01-30 10:25:00	2017-01-31 20:10:00	\N	\N	3	0	\N	\N
161236	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Compétitivité des places financières à Luxembourg	Déplacement à Luxembourg sur la Compétitivité des places financières	2017-01-19 07:40:00	2017-01-19 21:20:00	\N	\N	2	0	\N	\N
161240	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Groupe de travail sur la fiscalité numérique à Londres	Déplacement du Groupe de travail sur la fiscalité numérique à Londres	2017-01-26 07:15:00	2017-01-26 21:30:00	\N	\N	3	0	\N	\N
162209	MISSION	AUCUNE	\N	PSYCHIATRIE	\N	\N	\N	2017-01-17 14:40:00	2017-01-17 16:40:00	2017-01-17 17:46:57	2017-01-17 17:50:43	14	0	\N	\N
162265	COM_ENQUETE	PLENIERE	\N	ATTEINTES	\N	1ere séquence d'audition "Notre-Dame des Landes"	Election du président de la CE et 1ère séquence du cycle NDDL  (CIDEPA, AcDPA et ADECA)	2017-01-17 17:50:00	2017-01-17 19:00:00	2017-01-20 09:46:00	2017-01-20 10:19:34	11	0	\N	\N
162632	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Obligations comptables des partis politiques	\N	2017-01-17 09:30:00	2017-01-17 11:00:00	\N	\N	1	0	\N	\N
165162	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Formation professionnelle des adultes	\N	2017-01-24 18:00:00	2017-01-24 19:00:00	\N	\N	1	0	\N	\N
165164	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	pjl formation	\N	2017-01-25 14:30:00	2017-01-25 15:30:00	\N	\N	1	0	\N	\N
165166	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Formation professionnelle des adultes	\N	2017-01-25 16:00:00	2017-01-25 19:00:00	\N	\N	2	0	\N	\N
165168	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Formation professionnelle des adultes	\N	2017-01-26 08:30:00	2017-01-26 11:00:00	\N	\N	1	0	\N	\N
166264	MISSION	AUDRAP	\N	DEMOCRATIE	\N	\N	\N	2017-01-25 16:00:00	2017-01-25 17:00:00	\N	\N	4	0	\N	\N
167453	COM_ENQUETE	PLENIERE	\N	ATTEINTES	\N	4ème séquence d'auditions sur la LGV-A65 et 2ème séquence de Notre Dame des Landes	4ème séquence d'auditions sur la LGV-A65 (COSEA) et 2ème séquence de Notre Dame des Landes  (SMA) 	2017-01-24 17:05:00	2017-01-24 19:40:00	2017-01-26 18:35:57	2017-01-26 19:04:37	8	0	\N	\N
167474	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT suivi de la PAC	GT Suivi de la PAC	2017-01-25 17:00:00	2017-01-25 18:15:00	\N	\N	3	0	\N	\N
167572	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Groupe de travail Culture et handicap	Groupe de travail Culture et handicap	2017-01-26 16:15:00	2017-01-26 18:15:00	\N	\N	1	0	\N	\N
170126	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Groupe de travail Culture et handicap	Groupe de travail Culture et handicap	2017-01-31 14:30:00	2017-01-31 16:30:00	\N	\N	2	0	\N	\N
170129	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Groupe de travail Culture et handicap	Groupe de travail Culture et handicap	2017-01-31 18:00:00	2017-01-31 19:00:00	\N	\N	2	0	\N	\N
158325	COM_PERMANENTE	AUTRE	\N	CDD	\N	Territoires littoraux	Adaptation des territoires littoraux au changement climatique	2017-01-11 09:35:00	2017-01-11 10:25:00	2018-05-18 15:47:57	2018-05-18 15:48:00	33	0	\N	\N
158412	COM_PERMANENTE	AUTRE	\N	CAE	\N	Autoconsommation d'électricité et énergies renouvelables	Autoconsommation d'électricité et énergies renouvelables	2017-01-11 09:30:00	2017-01-11 11:30:00	2018-05-18 15:47:41	2018-05-18 15:47:45	34	0	\N	\N
160890	CMP	AUTRE	\N	CONSOMMATION	\N	PJL Ratification de deux ordonnances relatives à la consommation	PJL Ratification de deux ordonnances relatives à la consommation	2017-01-17 09:00:00	2017-01-17 09:40:00	\N	\N	7	0	\N	\N
168848	COM_PERMANENTE	AUTRE	\N	LOIS	\N	\N	\N	2017-02-01 09:05:00	2017-02-01 12:30:00	2017-02-01 11:52:33	2017-02-01 17:03:03	39	0	\N	\N
170692	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	MI Déradicalisation	Mission d'information déradicalisation	2017-02-03 07:15:00	2017-02-03 16:00:00	\N	\N	2	0	\N	\N
171137	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Audition 58-2 Programme "Habiter mieux"	Audition 58-2 Programme "Habiter mieux" - Réunion de cadrage Cour des comptes	2017-02-07 09:00:00	2017-02-07 09:50:00	\N	\N	1	0	\N	\N
171180	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Mineurs isolés	\N	2017-02-07 09:30:00	2017-02-07 12:30:00	\N	\N	3	0	\N	\N
171196	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Mineurs isolés	\N	2017-02-07 15:00:00	2017-02-07 18:00:00	\N	\N	5	0	\N	\N
171199	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Mineurs isolés	\N	2017-02-08 14:30:00	2017-02-08 16:30:00	\N	\N	5	0	\N	\N
171202	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Mineurs isolés	\N	2017-02-08 17:30:00	2017-02-08 18:30:00	\N	\N	2	0	\N	\N
171221	DELEGATION	AUDRAP	\N	\N	COLTER	RI nouvelles technologies au service des CT	\N	2017-01-31 10:30:00	2017-01-31 11:30:00	\N	\N	2	0	\N	\N
171232	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Sincérité des comptes des collectivités territoriales	\N	2017-02-07 14:30:00	2017-02-07 16:00:00	\N	\N	2	0	\N	\N
171395	MISSION	AUCUNE	\N	PSYCHIATRIE	\N	\N	\N	2017-02-07 15:00:00	2017-02-07 17:25:00	2017-02-07 18:11:00	2017-02-08 11:09:26	17	0	\N	\N
171619	MISSION	PLEIN_NON_JO	\N	BREXIT	\N	   Audition de M. Dariusz Wisniewski,  Ambassade de Pologne 	   Audition de M. Dariusz Wisniewski, chargé d¿affaires a.i. ¿ Ambassade de Pologne 	2017-02-08 08:45:00	2017-02-08 10:00:00	\N	\N	7	0	\N	\N
172783	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de M. Jean François Carenco	Audition de M. Jean François Carenco	2017-02-08 14:45:00	2017-02-08 16:05:00	2018-05-18 15:53:01	2018-05-18 15:53:06	30	0	\N	\N
172852	MISSION	AUCUNE	\N	PSYCHIATRIE	\N	\N	\N	2017-02-08 15:00:00	2017-02-08 17:10:00	2017-02-08 18:25:37	2017-02-09 15:15:51	11	0	\N	\N
172879	MISSION	PLEIN_NON_JO	\N	BREXIT	\N	Audition de M. Michel Barnier	Audition de M. Michel Barnier, négociateur en chef de la Commission européenne sur le Brexit	2017-02-08 16:35:00	2017-02-08 17:55:00	\N	\N	11	0	\N	\N
172892	MISSION	PLEIN_NON_JO	\N	BREXIT	\N	Communications Avenir de la zone euro et Sécurité/migrations	Communications Avenir de la zone euro et Sécurité/migrations	2017-02-08 15:15:00	2017-02-08 16:35:00	\N	\N	9	0	\N	\N
172972	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2017-02-07 14:40:00	2017-02-07 16:50:00	\N	\N	3	0	\N	\N
173633	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Compétences des intercommunalités	\N	2017-02-09 14:30:00	2017-02-09 15:00:00	\N	\N	2	0	\N	\N
174092	BUREAU	AUCUNE	\N	\N	\N	Bureau 	Bureau	2017-02-09 09:00:00	2017-02-09 11:00:00	\N	\N	24	0	\N	\N
174338	MECSS	AUDRAP	\N	\N	MECSS	interrégimes en matière de retraite	\N	2017-03-08 09:15:00	2017-03-08 12:00:00	\N	\N	2	0	\N	\N
174507	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition sur la compétitivité de la place de Paris et Contrôles AGTE, AGRASC et FACé	Audition sur la compétitivité de la place de Paris et Contrôles AGTE, AGRASC et FACé	2017-02-15 09:10:00	2017-02-15 12:40:00	2017-02-16 15:29:06	2017-02-16 16:43:49	32	0	\N	\N
174511	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen des Amendements de séance PPL n° 394 (2016-2017)	Examen des Amendements de séance PPL n° 394  (2016-2017) Calcul du potentiel fiscal de communautés d'agglomération	2017-02-16 10:05:00	2017-02-16 10:10:00	2017-02-16 16:57:02	2017-02-17 09:05:48	9	2	\N	\N
174960	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2017-02-14 15:35:00	2017-02-14 16:25:00	2017-02-14 17:13:23	2017-02-14 17:14:48	38	0	\N	\N
175930	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2017-02-15 09:25:00	2017-02-15 10:05:00	2017-02-15 12:03:14	2017-02-15 17:27:02	47	0	\N	\N
176132	ETUDES	AUCUNE	\N	\N	\N	\N	\N	2017-02-09 08:30:00	2017-02-09 09:30:00	\N	\N	4	0	\N	966
176312	COM_ENQUETE	PLENIERE	\N	ATTEINTES	\N	10e séquence d'auditions sur la LGV/A65	10e séquence d'auditions sur la LGV/A65 (Préfet de région Centre-Val de Loire	2017-02-15 14:10:00	2017-02-15 15:00:00	2017-02-16 21:17:50	2017-02-17 09:09:15	7	0	\N	\N
176366	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2017-02-15 10:20:00	2017-02-15 12:25:00	2017-02-16 09:45:55	2017-02-16 16:43:45	48	2	\N	\N
176952	COM_ENQUETE	PLENIERE	\N	ATTEINTES	\N	16ème séquence d'auditions généralistes (CILB)	16ème séquence d'auditions généralistes (CILB)	2017-02-15 15:30:00	2017-02-15 16:45:00	2017-02-16 21:20:48	2017-02-17 09:09:13	7	0	\N	\N
177312	DELEGATION	AUCUNE	\N	\N	211	Audition du Défenseur des droits	Audition du Défenseur des droits	2017-02-16 09:00:00	2017-02-16 10:35:00	2017-02-16 11:56:54	2017-02-16 16:44:27	9	0	\N	\N
177452	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT suivi de la PAC	\N	2017-02-15 18:00:00	2017-02-15 19:20:00	\N	\N	6	0	\N	\N
177517	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Groupe de travail rythmes scolaires	groupe de travail Rythmes scolaires	2017-02-15 15:00:00	2017-02-15 18:00:00	\N	\N	1	0	\N	\N
177592	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Mineurs isolés	\N	2017-02-15 14:30:00	2017-02-15 15:30:00	\N	\N	3	0	\N	\N
177595	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Mineurs isolés	\N	2017-02-21 15:30:00	2017-02-21 18:30:00	\N	\N	6	0	\N	\N
177598	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Mineurs isolés	\N	2017-02-22 16:00:00	2017-02-22 17:45:00	\N	\N	2	0	\N	\N
177601	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Mineurs isolés	\N	2017-03-09 14:30:00	2017-03-09 19:00:00	\N	\N	2	0	\N	\N
177612	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Communication MI Désendoctrinement	\N	2017-02-21 09:35:00	2017-02-21 10:45:00	2017-02-21 11:49:32	2017-02-21 16:14:15	13	0	\N	\N
177614	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Rapport annuel du Défenseur des droits	\N	2017-02-22 11:00:00	2017-02-22 12:45:00	2017-02-22 14:39:46	2017-02-22 15:45:54	20	1	\N	\N
177636	COM_ENQUETE	PLENIERE	\N	ATTEINTES	\N	8ème séquence d'audition sur Notre-Dame-des-Landes (M. Pinte, Conseil régional)	8ème séquence d'audition sur Notre-Dame-des-Landes (M. Pinte, Conseil régional)	2017-02-15 17:30:00	2017-02-15 18:40:00	2017-02-16 21:25:29	2017-02-17 09:09:11	4	0	\N	\N
177652	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI redressement de la justice	MI redressement de la justice	2017-02-14 18:00:00	2017-02-14 19:00:00	\N	\N	1	0	\N	\N
164592	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 19 janvier 2017	\N	2017-01-19 08:40:00	2017-01-19 10:05:00	2017-01-19 18:11:20	2017-01-19 18:18:21	8	0	\N	\N
164825	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Transport sanitaire héliporté	\N	2017-01-18 18:30:00	2017-01-18 19:15:00	\N	\N	1	0	\N	\N
176697	COM_ENQUETE	PLENIERE	\N	SCHENGEN	\N	CE SCHENGEN	CE SCHENGEN	2017-02-15 15:00:00	2017-02-15 16:00:00	2017-02-15 16:22:10	2017-02-15 17:28:35	9	0	\N	\N
173293	CMP	AUTRE	\N	ACCAPAREMENT	\N	PPL lutte contre l'accaparement des terres agricoles	PPL lutte contre l'accaparement des terres agricoles	2017-02-09 09:00:00	2017-02-09 09:55:00	\N	\N	7	0	\N	\N
175872	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2017-02-15 09:05:00	2017-02-15 09:25:00	2017-02-15 12:03:43	2017-02-15 17:26:55	46	0	\N	\N
165233	GIA	AUCUNE	\N	\N	\N	Réunion du groupe France - Cambodge et Laos	Réunion du groupe France - Cambodge et Laos	2017-01-24 16:00:00	2017-01-24 16:20:00	\N	\N	4	0	577	\N
166050	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2017-01-25 10:40:00	2017-01-25 12:20:00	2017-01-25 16:16:41	2017-01-25 16:25:02	36	0	\N	\N
166152	MISSION	PLEIN_NON_JO	\N	BREXIT	\N	Audition de S. Exc. Lord Edward Llewellyn, ambassadeur du Royaume-Uni en France	Audition de S. Exc. Lord Edward Llewellyn, ambassadeur du Royaume-Uni en France	2017-01-25 14:35:00	2017-01-25 15:45:00	\N	\N	12	0	\N	\N
166166	MISSION	PLEIN_NON_JO	\N	BREXIT	\N	Communications Europe croissance et Relation franco-allemande	Communications Europe croissance et Relation franco-allemande	2017-01-25 15:45:00	2017-01-25 16:45:00	\N	\N	10	0	\N	\N
166205	DELEGATION	DEPLACEMENT	\N	\N	COLTER	RI_CT et prévention de la radicalisation-déplacement à Colmar	\N	2017-01-27 10:00:00	2017-01-27 17:20:00	\N	\N	1	0	\N	\N
166352	COM_PERMANENTE	AUTRE	\N	FINC	\N	Accord Pays par Pays - Examen des amendements de séance	Accord Pays par Pays - Examen des amendements de séance	2017-01-26 10:15:00	2017-01-26 10:25:00	2017-01-26 16:14:59	2017-01-26 17:46:18	15	0	\N	\N
166712	COM_PERMANENTE	AUTRE	\N	CDD	\N	Audition de M. Bernard ROMAN, Président de l'ARAFER	Audition de M. Bernard ROMAN, Président de l'Autorité de Régulation des Activités Ferroviaires et Routières	2017-01-26 11:05:00	2017-01-26 12:30:00	2018-05-18 15:50:11	2018-05-18 15:50:18	18	0	\N	\N
166752	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	\N	\N	2017-01-25 17:00:00	2017-01-25 18:30:00	\N	\N	1	0	\N	\N
167632	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	groupe de travail Rythmes scolaires	groupe de travail Rythmes scolaires	2017-01-25 16:00:00	2017-01-25 18:00:00	\N	\N	1	0	\N	\N
167634	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	groupe de travail Rythmes scolaires	groupe de travail Rythmes scolaires	2017-01-26 09:00:00	2017-01-26 12:00:00	\N	\N	1	0	\N	\N
168839	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Stéphane BERGERON, député de l'Assemblée nationale du Québec	\N	2017-01-25 14:30:00	2017-01-25 15:30:00	\N	\N	1	0	602	\N
169002	COM_EURO	AUDRAP	\N	AFEU	\N	Union de l'énergie	\N	2017-01-31 14:30:00	2017-01-31 15:30:00	\N	\N	1	0	\N	\N
169232	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2017-02-01 09:35:00	2017-02-01 11:10:00	2017-02-01 15:02:56	2017-02-01 17:02:59	46	1	\N	\N
169379	BUREAU	AUCUNE	\N	\N	\N	Délégation du Bureau	Délégation statut et conditions d'exercice du mandat de sénateur	2017-02-01 12:00:00	2017-02-01 13:00:00	\N	\N	3	0	\N	\N
169718	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle FACE 2016	Contrôle FACE 2016 - Audition Ministère de l'environnement, de l'énergie et de la mer	2017-02-01 14:00:00	2017-02-01 15:00:00	\N	\N	1	0	\N	\N
169806	GIA	AUCUNE	\N	\N	\N	Réunion du bureau	Réunion du bureau	2017-02-01 15:30:00	2017-02-01 16:00:00	\N	\N	4	0	620	\N
170598	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Assainissement cadastral	PPL Assainissement cadastral	2017-02-08 14:30:00	2017-02-08 16:00:00	\N	\N	70	0	\N	\N
170599	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Contrats de crédit	CMP Contrats de crédit	2017-02-08 16:45:00	2017-02-08 17:45:00	\N	\N	55	0	\N	\N
171652	COM_PERMANENTE	AUTRE	\N	CDD	\N	Table ronde sur l¿état des infrastructures routières et autoroutières,	Table ronde sur l¿état des infrastructures routières et autoroutières,	2017-02-08 09:00:00	2017-02-08 11:10:00	2018-05-18 15:52:26	2018-05-18 15:52:30	24	0	\N	\N
171692	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition  de M. Henri Poupart-Lafarge	Audition  de M. Henri Poupart-Lafarge, Président-directeur général d¿Alstom	2017-02-08 09:30:00	2017-02-08 11:15:00	2018-05-18 15:52:44	2018-05-18 15:52:49	32	0	\N	\N
174000	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Francophonie	Groupe de travail Francophonie	2017-02-09 10:00:00	2017-02-09 11:30:00	\N	\N	4	0	\N	\N
174252	ETUDES	AUCUNE	\N	\N	\N	\N	\N	2017-02-08 08:15:00	2017-02-08 09:10:00	\N	\N	28	0	\N	907
174282	COM_PERMANENTE	AUDRAP	\N	CDD	\N	\N	\N	2017-02-07 09:30:00	2017-02-07 10:30:00	\N	\N	1	0	\N	\N
174284	COM_PERMANENTE	AUDRAP	\N	CDD	\N	\N	\N	2017-02-08 11:00:00	2017-02-08 12:00:00	\N	\N	1	0	\N	\N
174472	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Égalité réelle outre-mer	\N	2017-02-14 17:50:00	2017-02-14 17:55:00	2017-02-15 09:11:23	2017-02-15 17:26:38	9	0	\N	\N
174533	COM_PERMANENTE	AUTRE	\N	LOIS	\N	\N	\N	2017-02-15 11:45:00	2017-02-15 12:35:00	2017-02-15 18:18:58	2017-02-16 16:43:43	18	0	\N	\N
175155	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Ordonnances relatives à la Corse	\N	2017-02-16 09:10:00	2017-02-16 09:15:00	2017-02-16 10:07:24	2017-02-16 16:43:40	8	0	\N	\N
175676	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe d'amitié	AG du groupe d'amitié pour la préparation de l'accueil de la délégation du Bundesrat en juin	2017-02-14 14:00:00	2017-02-14 14:30:00	\N	\N	11	0	604	\N
175705	GIA	AUCUNE	\N	\N	\N	Entretien avec le Ministre plénipotentiaire de l'Ambassade d'Allemagne	Entretien du Bureau du GA avec le Ministre plénipotentiaire de l'Ambassade d'Allemagne	2017-02-01 12:45:00	2017-02-01 14:30:00	\N	\N	6	0	604	\N
176676	COM_ENQUETE	PLENIERE	\N	SCHENGEN	\N	SCHENGEN	SCHENGEN	2017-02-14 14:05:00	2017-02-14 16:10:00	2017-02-15 16:14:45	2017-02-15 17:28:33	11	0	\N	\N
165832	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2017-01-25 09:35:00	2017-01-25 10:40:00	2017-01-25 16:18:14	2017-01-25 16:24:48	46	1	\N	\N
169292	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2017-02-01 11:10:00	2017-02-01 12:25:00	2017-02-01 14:45:40	2017-02-01 17:02:55	46	1	\N	\N
174510	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Compétences des intercommunalités	\N	2017-02-15 09:00:00	2017-02-15 11:40:00	2017-02-15 12:36:55	2017-02-15 17:26:45	44	1	\N	\N
174792	CMP	AUTRE	\N	PRESCRIPTION	\N	PPL Réforme de la prescription en matière pénale	PPL Réforme de la prescription en matière pénale	2017-02-13 16:05:00	2017-02-13 16:40:00	\N	\N	8	0	\N	\N
177113	MISSION	AUCUNE	\N	DEMOCRATIE	\N	\N	\N	2017-02-15 17:30:00	2017-02-15 18:50:00	2017-02-15 19:18:43	2017-02-16 16:49:50	4	0	\N	\N
177472	GIA	AUCUNE	\N	\N	\N	Déjeuner	Déjeuner avec des élus marocains	2016-12-02 13:00:00	2016-12-02 14:30:00	\N	\N	1	0	598	\N
177474	GIA	AUCUNE	\N	\N	\N	colloque	Colloque Business France France Maroc	2017-02-03 09:00:00	2017-02-03 14:00:00	\N	\N	1	0	598	\N
177476	GIA	AUCUNE	\N	\N	\N	Colloque	Colloque Relations culturelles France Maroc	2017-02-14 14:00:00	2017-02-14 18:00:00	\N	\N	3	0	598	\N
177512	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Gouvernance du football	Mission d'information sur la gouvernance du football	2017-02-16 10:00:00	2017-02-16 11:10:00	\N	\N	4	0	\N	\N
177521	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Gouvernance du football	Mission d'information sur la gouvernance du football	2017-02-16 11:35:00	2017-02-16 12:35:00	\N	\N	3	0	\N	\N
164812	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL FAURE POTIER	PJL FAURE POTIER	2017-01-19 09:30:00	2017-01-19 10:30:00	\N	\N	1	0	\N	\N
164814	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL FAURE POTIER	PJL FAURE POTIER	2017-01-19 10:30:00	2017-01-19 11:30:00	\N	\N	1	0	\N	\N
164816	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL FAURE POTIER	PJL FAURE POTIER	2017-01-19 14:00:00	2017-01-19 15:00:00	\N	\N	1	0	\N	\N
164818	ETUDES	AUCUNE	\N	\N	\N	GE  "économie agricole et alimentaire" : section "trufficulture"	GE "économie agricole et alimentaire" : section "trufficulture"	2017-01-18 08:30:00	2017-01-18 09:30:00	\N	\N	10	0	\N	1005
165143	COM_ENQUETE	PLENIERE	\N	ATTEINTES	\N	3ème séquence d'auditions sur la LGV/A65 	3ème séquence d'auditions sur la LGV/A65  (Préfet de Nouvelle-Aquitaine et DREAL)	2017-01-24 15:05:00	2017-01-24 16:40:00	2017-01-26 18:10:47	2017-01-26 19:04:36	7	0	\N	\N
165892	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2017-01-25 09:05:00	2017-01-25 11:00:00	2017-01-25 14:32:50	2017-01-25 14:59:51	46	0	\N	\N
166271	DELEGATION	DEPLACEMENT	\N	\N	206	Déplacement aux Etats-Unis dans le cadre du rapport sur l'intelligence artificielle	\N	2017-01-22 12:00:00	2017-01-29 12:00:00	\N	\N	2	0	\N	\N
166460	MISSION	AUCUNE	\N	PSYCHIATRIE	\N	\N	\N	2017-01-25 14:40:00	2017-01-25 18:45:00	2017-01-26 11:16:18	2017-01-26 17:54:55	16	0	\N	\N
166973	COM_SPECIALE	PLENIERE	\N	COMSPEAPU	\N	Audition	\N	2017-01-26 14:00:00	2017-01-26 15:00:00	2017-01-26 15:17:33	2017-01-26 17:54:49	5	0	\N	\N
166996	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Gouvernance du football	Mission d'information sur la gouvernance du football	2017-01-26 10:05:00	2017-01-26 11:30:00	\N	\N	6	0	\N	\N
167027	COM_ENQUETE	PLENIERE	\N	SCHENGEN	\N	\N	\N	2017-01-26 11:05:00	2017-01-26 12:25:00	2017-01-26 16:11:05	2017-01-26 17:54:51	9	0	\N	\N
167277	COM_ENQUETE	PLENIERE	\N	SCHENGEN	\N	\N	\N	2017-01-26 14:00:00	2017-01-26 14:50:00	2017-01-26 16:19:22	2017-01-26 17:54:50	10	0	\N	\N
167278	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL IVG	PPL IVG	2017-02-14 14:30:00	2017-02-14 16:15:00	\N	\N	126	0	\N	\N
167279	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2017-02-14 16:45:00	2017-02-14 17:45:00	\N	\N	300	0	\N	\N
167288	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PJL ANSM et ANSP	CMP PJL ANSM et ANSP	2017-02-14 18:00:00	2017-02-14 18:50:00	\N	\N	54	0	\N	\N
167291	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PJL Égalité réelle outre-mer	CMP PJL Égalité réelle outre-mer	2017-02-14 19:05:00	2017-02-14 20:40:00	\N	\N	53	0	\N	\N
167306	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PPL Biocontrôle	CMP PPL Biocontrôle	2017-02-15 14:30:00	2017-02-15 15:45:00	\N	\N	67	0	\N	\N
167310	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Éthique du sport	PPL Éthique du sport	2017-02-15 17:00:00	2017-02-15 18:55:00	\N	\N	59	0	\N	\N
167312	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Prescription en matière pénale	PPL Prescription en matière pénale	2017-02-15 18:55:00	2017-02-15 19:50:00	\N	\N	30	0	\N	\N
167315	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Corse	PJL Corse	2017-02-16 14:45:00	2017-02-16 16:05:00	\N	\N	23	0	\N	\N
167332	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PJL  Sécurité publique	CMP PJL Sécurité publique	2017-02-16 12:00:00	2017-02-16 13:05:00	\N	\N	36	0	\N	\N
167337	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2017-02-21 09:30:00	2017-02-21 13:00:00	\N	\N	31	0	\N	\N
167338	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR Gestion de l'eau	PPR Gestion de l'eau	2017-02-21 14:30:00	2017-02-21 17:45:00	\N	\N	74	0	\N	\N
167339	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Économie circulaire	Débat Économie circulaire	2017-02-21 15:30:00	2017-02-21 17:45:00	\N	\N	66	0	\N	\N
167340	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Bilan de l'application des lois	Débat Bilan de l'application des lois	2017-02-21 17:45:00	2017-02-21 20:00:00	\N	\N	54	0	\N	\N
167342	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Communes en zones rurales	Débat Communes en zones rurales	2017-02-21 21:00:00	2017-02-22 00:00:00	\N	\N	30	0	\N	\N
167345	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Perturbateurs endocriniens	PPL Perturbateurs endocriniens	2017-02-22 14:30:00	2017-02-22 18:30:00	\N	\N	84	0	\N	\N
167346	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Eau potable	PPL Eau potable	2017-02-22 15:30:00	2017-02-22 18:30:00	\N	\N	88	0	\N	\N
167347	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Déserts médicaux	Débat Déserts médicaux	2017-02-22 18:30:00	2017-02-22 20:00:00	\N	\N	53	0	\N	\N
167348	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Déserts médicaux	Débat Déserts médicaux	2017-02-22 21:30:00	2017-02-23 00:00:00	\N	\N	0	0	\N	\N
167349	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Comptes des collectivités territoriales	PPL Comptes des collectivités territoriales	2017-02-22 19:00:00	2017-02-22 20:30:00	\N	\N	0	0	\N	\N
167350	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Comptes des collectivités territoriales	PPL Comptes des collectivités territoriales	2017-02-22 21:30:00	2017-02-23 00:00:00	\N	\N	20	0	\N	\N
167351	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Choc de simplification	Débat Choc de simplification	2017-02-23 10:00:00	2017-02-23 13:30:00	\N	\N	63	0	\N	\N
167352	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2017-02-23 15:00:00	2017-02-23 16:15:00	\N	\N	253	0	\N	\N
167353	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Eau et assainissement	PPL Eau et assainissement	2017-02-23 16:15:00	2017-02-23 20:00:00	\N	\N	59	0	\N	\N
167412	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	Aménagement du territoire	\N	2017-01-26 09:30:00	2017-01-26 11:00:00	\N	\N	7	0	\N	\N
169170	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2017-02-01 10:20:00	2017-02-01 12:00:00	2017-02-01 12:36:40	2017-02-01 17:02:57	43	0	\N	\N
170361	GIA	AUCUNE	\N	\N	\N	Entretien - ambassadeur de Cuba	Entretien avec M. IGARZA CABRERA, ambassadeur de Cuba	2017-01-31 15:00:00	2017-01-31 15:30:00	\N	\N	1	0	642	\N
170612	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Drones	\N	2017-01-31 14:30:00	2017-01-31 15:30:00	\N	\N	4	0	\N	\N
170617	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Nucléaire	\N	2017-01-31 14:30:00	2017-01-31 16:40:00	\N	\N	2	0	\N	\N
170812	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Réforme de la prescription en matière pénale PPL Assainissement cadastral 	\N	2017-02-07 09:40:00	2017-02-07 10:30:00	2017-02-07 15:59:17	2017-02-07 16:16:29	13	0	\N	\N
171612	GIA	AUCUNE	\N	\N	\N	Visite ministre géorgien des affaires étrangères	Petit-déjeuner en l'honneur du ministre des affaires étrangères de Géorgie	2017-02-08 08:30:00	2017-02-08 09:30:00	\N	\N	6	0	534	\N
171734	GIA	AUCUNE	\N	\N	\N	Entretien avec une délégation de députés suédois	Entretien avec une délégation de députés suédois	2017-02-08 08:30:00	2017-02-08 10:00:00	\N	\N	10	0	625	\N
171752	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition sur la compétitivité de la place de Paris	Audition de différents acteurs bancaires et financiers sur la compétitivité de la place de Paris	2017-02-08 10:00:00	2017-02-08 12:05:00	2017-02-08 15:00:24	2017-02-08 15:44:11	32	0	\N	\N
171870	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2017-02-08 11:15:00	2017-02-08 12:35:00	2017-02-08 14:07:36	2017-02-08 15:44:08	23	0	\N	\N
172504	GIA	AUCUNE	\N	\N	\N	Audition de M. Mahmoud ABBAS	Audition de M. Mahmoud ABBAS devant la commission des Affaires étrangères	2017-02-08 11:45:00	2017-02-08 13:00:00	\N	\N	13	0	632	\N
172956	DELEGATION	AUCUNE	\N	\N	PROS	Réunion plénière	Réunion plénière - Adoption du rapport Système financier	2017-02-09 08:40:00	2017-02-09 09:50:00	2017-02-09 10:51:12	2017-02-09 15:12:44	10	0	\N	\N
172973	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 9 février 2017	Réunion du 9 février 2017	2017-02-09 08:35:00	2017-02-09 10:35:00	2017-02-09 11:04:34	2017-02-09 15:13:23	13	0	\N	\N
172980	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Gouvernance du football	Mission d'information sur la gouvernance du football	2017-02-08 15:00:00	2017-02-08 18:00:00	\N	\N	5	0	\N	\N
173151	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2017-02-09 11:10:00	2017-02-09 11:25:00	\N	\N	3	0	\N	\N
164692	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL Assistance alimentaire	\N	2017-01-17 10:00:00	2017-01-17 10:45:00	\N	\N	1	0	\N	\N
164732	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Gouvernance du football	Mission d'information sur la gouvernance du football	2017-01-18 15:00:00	2017-01-18 17:00:00	\N	\N	5	0	\N	\N
164752	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Réforme rythmes scolaires	Groupe de travail sur la réforme des rythmes scolaires - Audition de Mme Françoise MOULIN-CIVIL	2017-01-11 15:00:00	2017-01-11 16:00:00	\N	\N	1	0	\N	\N
164754	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Réforme rythmes scolaires	Groupe de travail sur la réforme des rythmes scolaires - Audition de M. Alexandre SINÉ	2017-01-11 16:00:00	2017-01-11 17:00:00	\N	\N	1	0	\N	\N
164756	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Réforme rythmes scolaires	Groupe de travail sur la réforme des rythmes scolaires - Audition de Mme Claire LECOMTE	2017-01-12 09:00:00	2017-01-12 10:00:00	\N	\N	1	0	\N	\N
164758	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Réforme rythmes scolaires	Groupe de travail sur la réforme des rythmes scolaires - Audition de l'AMF	2017-01-12 10:00:00	2017-01-12 10:40:00	\N	\N	1	0	\N	\N
164772	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	FOST	\N	2017-01-19 05:45:00	2017-01-19 18:00:00	\N	\N	13	0	\N	\N
164875	COM_ENQUETE	DEPLACEMENT	\N	SCHENGEN	\N	CE SCHENGEN - Bruxelles	CE SCHENGEN - déplacement à Bruxelles	2017-01-23 06:00:00	2017-01-23 20:45:00	\N	\N	5	0	\N	\N
164974	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Formation professionnelle des adultes	\N	2017-01-17 15:00:00	2017-01-17 17:00:00	\N	\N	1	0	\N	\N
164992	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Formation professionnelle des adultes	\N	2017-01-17 15:45:00	2017-01-17 17:00:00	\N	\N	1	0	\N	\N
164997	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2017-01-18 14:00:00	2017-01-18 15:00:00	\N	\N	1	0	\N	\N
166574	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 26 janvier 2017	\N	2017-01-26 09:00:00	2017-01-26 10:35:00	2017-01-26 12:19:46	2017-01-26 17:46:50	19	0	\N	\N
167472	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle FACE 2016	Contrôle FACE 2016 - FNCCR	2017-01-25 14:30:00	2017-01-25 15:30:00	\N	\N	1	0	\N	\N
167476	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle FACE 2016	Contrôle FACE 2016 - FNSICAE	2017-01-26 11:00:00	2017-01-26 12:00:00	\N	\N	1	0	\N	\N
167612	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL France-Algérie échanges jeunes actifs	\N	2017-01-26 16:15:00	2017-01-26 17:15:00	\N	\N	1	0	\N	\N
167614	MISSION	AUDRAP	\N	BREXIT	\N	\N	\N	2017-01-24 15:00:00	2017-01-24 16:15:00	\N	\N	2	0	\N	\N
167672	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Assainissement cadastral	\N	2017-01-26 14:15:00	2017-01-26 15:00:00	\N	\N	3	0	\N	\N
169094	DELEGATION	AUCUNE	\N	\N	COLTER	Audition de M. Alain Lambert, président du CNEN	\N	2017-02-09 13:00:00	2017-02-09 14:30:00	2017-02-09 17:03:44	2017-02-09 17:59:28	20	0	\N	\N
169852	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2017-02-01 16:35:00	2017-02-01 18:10:00	2017-02-02 09:41:05	2017-02-02 15:02:52	29	0	\N	\N
170095	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	MI redressement de la justice	déplacement PNIJ	2017-01-12 07:45:00	2017-01-12 13:00:00	\N	\N	5	0	\N	\N
170101	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	MI redressement de la justice	déplacement Nancy et Metz	2017-01-19 07:00:00	2017-01-19 21:30:00	\N	\N	2	0	\N	\N
170104	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	MI redressement de la justice	déplacement Batignolles	2017-01-26 08:45:00	2017-01-26 12:15:00	\N	\N	4	0	\N	\N
170233	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 2 février 2016	\N	2017-02-02 08:35:00	2017-02-02 10:00:00	2017-02-02 12:26:21	2017-02-02 15:06:40	13	0	\N	\N
170272	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Réforme rythmes scolaires - audition rapporteur	Réforme rythmes scolaires - audition rapporteur - Table ronde syndicats d'enseignants	2017-02-01 15:00:00	2017-02-01 16:30:00	\N	\N	1	0	\N	\N
170312	DELEGATION	DEPLACEMENT	\N	\N	COLTER	RI_CT et prévention de la radicalisation-déplacement à Bruxelles	\N	2017-02-02 09:00:00	2017-02-02 16:00:00	\N	\N	2	0	\N	\N
170372	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	groupe de travail Rythmes scolaires	groupe de travail Rythmes scolaires	2017-02-01 15:00:00	2017-02-01 18:00:00	\N	\N	1	0	\N	\N
170432	COM_EURO	CONTROLE	\N	AFEU	\N	Audition de MM. Mario Monti et Alain Lamassoure	Audition de MM. Mario Monti et Alain Lamassoure	2017-02-01 15:40:00	2017-02-01 17:10:00	2017-02-02 18:14:03	2017-02-02 18:22:50	31	0	\N	\N
170512	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Francophonie	\N	2017-01-24 15:00:00	2017-01-24 16:00:00	\N	\N	2	0	\N	\N
170532	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Francophonie	\N	2017-01-24 16:00:00	2017-01-24 17:00:00	\N	\N	2	0	\N	\N
170554	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Gouvernance du football	Mission d'information sur la gouvernance du football	2017-02-01 15:00:00	2017-02-01 17:00:00	\N	\N	5	0	\N	\N
165686	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2017-01-25 09:35:00	2017-01-25 11:30:00	2017-01-27 14:22:28	2017-01-27 14:22:41	43	0	\N	\N
170560	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	MI Déradicalisation	Mission d'information déradicalisation	2017-02-02 07:55:00	2017-02-02 17:00:00	\N	\N	1	0	\N	\N
170562	ETUDES	AUCUNE	\N	\N	\N	\N	\N	2017-01-31 12:30:00	2017-01-31 14:00:00	\N	\N	4	0	\N	934
170567	ETUDES	AUCUNE	\N	\N	\N	\N	\N	2017-02-01 08:30:00	2017-02-01 09:30:00	\N	\N	12	0	\N	965
172221	COM_ENQUETE	PLENIERE	\N	ATTEINTES	\N	8ème séquence d'auditions sur LGV-A65/6ème séquence NDDL	6ème séquence d'auditions LGV-A65 (Cel Rég. Nelle Aquitaine/Ch. agri 37)/6ème séquence NDDL (Préfet Pays de la Loire) 	2017-02-08 14:00:00	2017-02-08 18:55:00	2017-02-09 16:19:23	2017-02-09 16:20:50	10	0	\N	\N
172952	GIA	AUCUNE	\N	\N	\N	Rencontre avec les représentants du CRIF	\N	2017-02-09 08:15:00	2017-02-09 09:30:00	\N	\N	8	0	595	\N
173207	MISSION	AUDRAP	\N	DEMOCRATIE	\N	\N	\N	2017-02-08 15:00:00	2017-02-08 18:30:00	\N	\N	2	0	\N	\N
173329	GIA	AUCUNE	\N	\N	\N	Déjeuner avec M. l'ambassadeur Regazzoni	\N	2017-02-08 12:30:00	2017-02-08 14:15:00	\N	\N	9	0	610	\N
173350	GIA	AUCUNE	\N	\N	\N	Visite de Firmenich	\N	2017-02-08 15:00:00	2017-02-08 16:45:00	\N	\N	3	0	610	\N
173464	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT PAC - Coop de France	GT PAC - Coop de France	2017-02-08 18:00:00	2017-02-08 19:30:00	\N	\N	7	0	\N	\N
173608	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	groupe de travail Rythmes scolaires	\N	2017-02-08 15:00:00	2017-02-08 18:00:00	\N	\N	1	0	\N	\N
173611	COM_SPECIALE	PLENIERE	\N	COMSPEAPU	\N	Contrôle sur pièces et sur place	Contrôle sur pièces et sur place	2017-02-09 14:00:00	2017-02-09 15:00:00	2017-02-09 15:29:17	2017-02-09 15:30:15	9	0	\N	\N
173629	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	groupe de travail Rythmes scolaires	\N	2017-02-09 10:00:00	2017-02-09 12:00:00	\N	\N	2	0	\N	\N
173637	MISSION	AUCUNE	\N	DEMOCRATIE	\N	\N	\N	2017-02-09 13:35:00	2017-02-09 14:55:00	2017-02-09 16:40:24	2017-02-09 16:53:27	8	0	\N	\N
173648	GIA	AUCUNE	\N	\N	\N	Entretien avec nouvel ambassadeur du Yémen à Paris	Entretien avec nouvel ambassadeur du Yémen à Paris afin de faire le point sur la situation du conflit au Yémen	2017-02-09 09:30:00	2017-02-09 10:30:00	\N	\N	3	0	661	\N
173652	ETUDES	AUCUNE	\N	\N	\N	Réunion - Audition AIR FRANCE - KLM	Réunion - Audition de M. Jean-Marc JANAILLAC, président-directeur général d'AIR FRANCE - KLM	2017-02-09 08:15:00	2017-02-09 09:30:00	\N	\N	8	0	\N	933
173931	MECSS	AUDRAP	\N	\N	MECSS	lutte contre la fraude aux prestations sociales	\N	2017-02-08 16:30:00	2017-02-08 18:30:00	\N	\N	3	0	\N	\N
173935	MECSS	AUDRAP	\N	\N	MECSS	lutte contre la fraude aux prestations sociales	\N	2017-02-09 09:30:00	2017-02-09 10:30:00	\N	\N	3	0	\N	\N
174152	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	Aménagement du territoire	\N	2017-02-09 10:45:00	2017-02-09 12:30:00	\N	\N	8	0	\N	\N
174354	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen du rapport PPL n°394 (2016-2017)	Examen du rapport PPL n°394  (2016-2017) Calcul du potentiel fiscal de communautés d'agglomération	2017-02-14 15:30:00	2017-02-14 16:20:00	2017-02-15 09:38:50	2017-02-15 17:26:29	29	1	\N	\N
175752	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2017-02-14 14:30:00	2017-02-14 16:30:00	\N	\N	3	0	\N	\N
175931	ETUDES	AUCUNE	\N	\N	\N	\N	\N	2017-02-14 12:45:00	2017-02-14 14:30:00	\N	\N	8	0	\N	934
176513	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2017-02-15 10:05:00	2017-02-15 11:55:00	2017-02-15 15:36:47	2017-02-15 17:27:25	41	0	\N	\N
176714	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de M. Christian ECKERT - révision des valeurs locatives	Audition de M. Christian ECKERT sur l'expérimentation de la révision des valeurs locatives des locaux d'habitation	2017-02-21 16:20:00	2017-02-21 17:35:00	2017-02-22 12:40:54	2017-02-22 15:46:09	20	0	\N	\N
164893	COM_PERMANENTE	AUTRE	\N	CAE	\N	Autoconsommation d'électricité et énergies renouvelables	Autoconsommation d'électricité et énergies renouvelables	2017-01-24 09:30:00	2017-01-24 10:00:00	2018-05-18 15:48:58	2018-05-18 15:49:02	12	1	\N	\N
165125	GIA	AUCUNE	\N	\N	\N	Entretien	Entreiten avec le Ministre du Développement local égyptien	2017-01-19 12:30:00	2017-01-19 14:00:00	\N	\N	1	0	617	\N
165238	MISSION	AUCUNE	\N	PSYCHIATRIE	\N	\N	\N	2017-01-24 14:50:00	2017-01-24 16:45:00	2017-01-24 17:34:52	2017-01-24 18:15:27	13	0	\N	\N
167280	DELEGATION	DEPLACEMENT	\N	\N	206	Déplacement aux Etats-Unis dans le cadre du PNGMDR 2016-2018	Rapport sur le "Plan national de gestion des matières et des déchets radioactifs 2016-2018"	2017-01-30 12:00:00	2017-02-02 23:00:00	\N	\N	1	0	\N	\N
167386	MISSION	AUDRAP	\N	DEMOCRATIE	\N	\N	\N	2017-01-26 13:30:00	2017-01-26 14:50:00	\N	\N	4	0	\N	\N
167652	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Drones	\N	2017-01-26 11:00:00	2017-01-26 12:00:00	\N	\N	4	0	\N	\N
167657	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Drones	\N	2017-01-26 14:00:00	2017-01-26 15:00:00	\N	\N	4	0	\N	\N
169044	COM_PERMANENTE	AUTRE	\N	CDD	\N	Audition de M. Philippe MARTIN, candidat à l'agence française pour la biodiversité 	Audition de M. Philippe MARTIN, candidat à l'agence française pour la biodiversité 	2017-02-01 09:30:00	2017-02-01 10:55:00	2018-05-18 15:50:46	2018-05-18 15:50:50	28	0	\N	\N
169112	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2017-02-01 09:30:00	2017-02-01 11:40:00	2018-05-18 15:51:06	2018-05-18 15:51:27	36	0	\N	\N
169375	COM_PERMANENTE	AUTRE	\N	FINC	\N	Contrôle Préfecture de Paris - Audition 58°2 Archives nationales	Contrôle Préfecture - Audition 58°2 Archives nationales	2017-02-01 09:35:00	2017-02-01 12:50:00	2017-02-01 17:48:47	2017-02-01 17:51:47	36	0	\N	\N
169592	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de M. Michel LAURENT, D.G. de l'énergie et du climat sur le paquet "Energie"	Audition de M. Michel LAURENT, D.G. de l'énergie et du climat sur le paquet "Energie"	2017-02-01 10:35:00	2017-02-01 12:15:00	2018-05-18 15:51:21	2018-05-18 15:51:29	26	0	\N	\N
169812	COM_ENQUETE	PLENIERE	\N	ATTEINTES	\N	4ème séquence d'auditions spécialisées sur la LGV/A65	4ème séquence d'auditions spécialisées sur la LGV/A65 (LISEA)	2017-01-31 18:00:00	2017-01-31 19:25:00	2017-02-01 17:45:09	2017-02-01 17:48:26	6	0	\N	\N
170033	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Mission réforme territoriale Amiens Lille	Mission réforme territoriale Amiens Lille	2017-01-26 17:30:00	2017-01-27 18:00:00	\N	\N	2	0	\N	\N
170072	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI redressement de la justice	\N	2017-02-01 18:30:00	2017-02-01 20:00:00	\N	\N	1	0	\N	\N
170092	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	MI redressement de la justice	déplacement à Riom	2017-02-02 07:10:00	2017-02-02 19:25:00	\N	\N	1	0	\N	\N
170772	MISSION	DEPLACEMENT	\N	BREXIT	\N	\N	\N	2017-02-06 08:00:00	2017-02-07 17:30:00	\N	\N	7	0	\N	\N
175543	CMP	AUTRE	\N	COLLCORSE	\N	PJL Ordonnances relatives à la Corse	PJL Ordonnances relatives à la Corse	2017-02-13 17:40:00	2017-02-13 17:40:00	\N	\N	6	0	\N	\N
175572	CMP	AUTRE	\N	SECURITEPUBL	\N	PJL Sécurité publique	PJL Sécurité publique	2017-02-13 16:40:00	2017-02-13 17:40:00	\N	\N	9	0	\N	\N
170932	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Sincérité des comptes des collectivités territoriales	\N	2017-02-06 15:00:00	2017-02-06 19:50:00	\N	\N	1	0	\N	\N
170953	COM_ENQUETE	PLENIERE	\N	ATTEINTES	\N	6ème séquence d'auditions sur Notre-Dame-des-Landes/14ème séquence généraliste	6ème séquence Notre-Dame-des-Landes (Naturalistes en lutte, des ailes pour l'ouest, monde agricole)/14e gale (C. Etat)	2017-02-07 14:00:00	2017-02-07 18:40:00	2017-02-08 16:08:01	2017-02-08 17:07:38	6	0	\N	\N
171087	MISSION	AUCUNE	\N	DEMOCRATIE	\N	\N	\N	2017-02-07 13:35:00	2017-02-07 15:10:00	2017-02-07 15:53:35	2017-02-07 16:16:52	5	0	\N	\N
172512	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2017-02-08 09:30:00	2017-02-08 12:10:00	2017-02-08 15:51:10	2017-02-08 15:51:47	49	1	\N	\N
174172	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI redressement de la justice	MI redressement de la justice	2017-02-08 09:45:00	2017-02-08 10:45:00	\N	\N	1	0	\N	\N
174174	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI redressement de la justice	MI redressement de la justice	2017-02-09 09:45:00	2017-02-09 12:30:00	\N	\N	1	0	\N	\N
174292	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle justice 2016 - AGRASC - Déplacement	Contrôle justice 2016 - AGRASC - Déplacement à l'AGRASC	2017-02-07 15:30:00	2017-02-07 17:15:00	\N	\N	1	0	\N	\N
174352	DELEGATION	AUCUNE	\N	\N	COLTER	Audition de M. AUBY et Mme BOMBERGER-RIVOT	\N	2017-02-23 09:00:00	2017-02-23 10:20:00	2017-02-23 11:04:21	2017-02-23 15:14:06	13	0	\N	\N
174535	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PPL Délit d'entrave à l'IVG	\N	2017-02-14 14:15:00	2017-02-14 14:25:00	2017-02-14 15:47:17	2017-02-14 17:14:47	33	1	\N	\N
176052	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition des représentants des métiers d'art et du luxe	Audition des représentants des industries des métiers d'art et du luxe	2017-02-15 09:30:00	2017-02-15 11:20:00	2018-05-18 15:53:22	2018-05-18 15:53:29	33	0	\N	\N
176212	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	fiscalité numérique - Déplacement Bruxelles	fiscalité numérique - Déplacement Bruxelles	2017-02-21 07:25:00	2017-02-21 19:40:00	\N	\N	3	0	\N	\N
176217	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Compétitivité des places financières - Déplacement Francfort	Compétitivité des places financières - Déplacement Francfort	2017-02-23 07:25:00	2017-02-23 19:50:00	\N	\N	1	0	\N	\N
176220	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Fiscalité numérique - Déplacement Berlin	Fiscalité numérique - Déplacement Berlin	2017-02-23 19:50:00	2017-02-24 19:30:00	\N	\N	4	0	\N	\N
176294	COM_PERMANENTE	AUTRE	\N	FINC	\N	Compte-Rendu semestre européen et Audition William COEN (Comité de Bâle)	Compte-Rendu semestre européen et Audition William COEN (Comité de Bâle)	2017-02-22 10:05:00	2017-02-22 11:40:00	2017-02-23 15:50:31	2017-02-23 16:17:40	32	0	\N	\N
176295	COM_PERMANENTE	AUTRE	\N	FINC	\N	Contrôle sécurité sanitaire et alimentaire	Contrôle sécurité sanitaire et alimentaire	2017-02-23 14:15:00	2017-02-23 15:00:00	2017-02-23 16:31:33	2017-02-23 16:54:38	17	0	\N	\N
176296	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Autoconsommation d'électricité et énergies renouvelables	PJL Autoconsommation d'électricité et énergies renouvelables	2017-02-15 15:45:00	2017-02-15 17:00:00	\N	\N	62	0	\N	\N
176855	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2017-02-15 16:40:00	2017-02-15 17:35:00	2017-02-16 09:48:52	2017-02-16 16:43:41	34	0	\N	\N
176953	COM_EURO	AUTRE	\N	AFEU	\N	Audition de M. Jean-Marc Ayrault, ministre des affaires étrangères 	Audition de M. Jean-Marc Ayrault, ministre des affaires étrangères et du développement international	2017-02-15 16:40:00	2017-02-15 17:35:00	2017-02-15 18:42:40	2017-02-16 16:45:22	35	0	\N	\N
177002	MISSION	PLEIN_NON_JO	\N	BREXIT	\N	Audition de M. Jean-Marc Ayrault, ministre des affaires étrangères	Audition de M. Jean-Marc Ayrault, ministre des affaires étrangères et du développement international	2017-02-15 16:40:00	2017-02-15 17:35:00	\N	\N	35	0	\N	\N
177053	MISSION	PLEIN_NON_JO	\N	BREXIT	\N	Communications Institutions, Subsidiarité et Brexit	Communications Institutions, Subsidiarité et Brexit	2017-02-15 14:50:00	2017-02-15 16:30:00	\N	\N	15	0	\N	\N
177213	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Potentiel fiscal	PPL Potentiel fiscal	2017-02-16 10:35:00	2017-02-16 12:00:00	\N	\N	0	0	\N	\N
177252	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion de Commission du 16 février 2017	Réunion de Commission du 16 février 2017	2017-02-16 08:35:00	2017-02-16 10:50:00	2017-02-22 10:04:04	2017-02-22 10:07:12	9	0	\N	\N
177292	MISSION	AUCUNE	\N	PSYCHIATRIE	\N	\N	\N	2017-02-15 14:00:00	2017-02-15 16:05:00	2017-02-16 16:54:02	2017-02-16 16:57:06	12	0	\N	\N
177528	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Gouvernance du football	Mission d'information sur la gouvernance du football	2017-02-16 14:00:00	2017-02-16 15:00:00	\N	\N	1	0	\N	\N
177531	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	\N	\N	2017-02-14 17:45:00	2017-02-14 19:45:00	\N	\N	3	0	\N	\N
177554	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Drones	\N	2017-02-14 14:30:00	2017-02-14 15:30:00	\N	\N	4	0	\N	\N
177572	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Drones	\N	2017-02-15 14:30:00	2017-02-15 15:30:00	\N	\N	2	0	\N	\N
164852	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2017-01-24 09:30:00	2017-01-24 12:30:00	\N	\N	34	0	\N	\N
164853	SEANCE_PLENIERE	ELOGE_FUNEBRE	\N	\N	\N	Éloge funèbre de Jean-Claude Frécon	Éloge funèbre de Jean-Claude Frécon	2017-01-24 14:15:00	2017-01-24 14:35:00	\N	\N	27	0	\N	\N
164854	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Energies	PJL Energies	2017-01-24 14:50:00	2017-01-24 18:15:00	\N	\N	98	0	\N	\N
164855	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Sécurité publique	PJL Sécurité publique	2017-01-24 18:15:00	2017-01-24 20:05:00	\N	\N	48	0	\N	\N
164856	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Sécurité publique	PJL Sécurité publique	2017-01-24 21:35:00	2017-01-25 00:25:00	\N	\N	53	0	\N	\N
165592	GIA	AUCUNE	\N	\N	\N	Rencontre avec Tashi Phuntsok (situation au Tibet)	Rencontre avec Tashi Phuntsok (situation au Tibet)	2017-01-31 15:30:00	2017-01-31 16:30:00	\N	\N	5	0	634	\N
165612	MISSION	PLEIN_NON_JO	\N	BREXIT	\N	Audition de Mme Nicole Fontaine et MM. François Lafond et Jean-Luc Sauron	Audition de Mme Nicole Fontaine et MM. François Lafond et Jean-Luc Sauron	2017-01-25 08:35:00	2017-01-25 10:05:00	\N	\N	11	0	\N	\N
165625	GIA	AUCUNE	\N	\N	\N	Conférence sur l'Asie centrale	Conférence sur la évolutions récentes et la situation géopolitique des cinq Etats d'Asie centrale	2017-01-18 15:00:00	2017-01-18 16:30:00	\N	\N	2	0	556	\N
165632	QUESTURE	AUCUNE	\N	\N	\N	Questure	Questure	2017-01-24 14:30:00	2017-01-24 16:00:00	\N	\N	3	0	\N	\N
165636	COM_PERMANENTE	AUTRE	\N	FINC	\N	Contrôle Etat actionnaire - "Bâle III" - Suivi quinquennal application des lois	Contrôle Etat actionnaire - Communication accord "Bâle III" - Com Suivi quinquennal application des lois + prog travail 	2017-01-25 09:30:00	2017-01-25 11:10:00	2017-01-26 17:58:23	2017-01-26 18:10:28	42	0	\N	\N
170887	CMP	AUTRE	\N	OUTRE_MER	\N	PJL Égalité réelle outre-mer	PJL Egalité réelle outre-mer	2017-02-06 17:10:00	2017-02-06 20:30:00	\N	\N	8	0	\N	\N
165752	COM_PERMANENTE	AUTRE	\N	CAE	\N	Communication sur le suivi quinquennal de l'application des lois	Communication sur le suivi quinquennal de l'application des lois	2017-01-25 10:00:00	2017-01-25 10:40:00	2018-05-18 15:49:43	2018-05-18 15:49:50	26	0	\N	\N
165952	COM_PERMANENTE	AUTRE	\N	CDD	\N	Bilan quinquennal et audition de M. Patrick JEANTET	Bilan quinquennal de l'application des lois et audition de M. Patrick JEANTET	2017-01-25 09:35:00	2017-01-25 12:00:00	2018-05-18 15:49:16	2018-05-18 15:49:21	26	0	\N	\N
166178	COM_ENQUETE	PLENIERE	\N	SCHENGEN	\N	\N	\N	2017-01-25 15:00:00	2017-01-25 16:20:00	2017-01-26 10:27:14	2017-01-26 17:54:53	13	0	\N	\N
166232	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Monténégro	PJL Monténégro	2017-01-26 11:45:00	2017-01-26 12:35:00	\N	\N	44	0	\N	\N
166233	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Lyon-Turin	PJL Lyon-Turin	2017-01-26 10:45:00	2017-01-26 11:35:00	\N	\N	53	0	\N	\N
166234	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Echange des déclarations pays par pays	PJL Echange des déclarations pays par pays	2017-01-26 12:20:00	2017-01-26 13:25:00	\N	\N	28	0	\N	\N
166235	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2017-01-26 15:05:00	2017-01-26 16:05:00	\N	\N	233	0	\N	\N
166236	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Corse	PJL Corse	2017-01-26 16:20:00	2017-01-26 18:35:00	\N	\N	33	0	\N	\N
166252	COM_EURO	AUDRAP	\N	AFEU	\N	Audition "Paquet connectivité UE"	\N	2017-01-19 11:00:00	2017-01-19 12:00:00	\N	\N	1	0	\N	\N
166255	COM_EURO	AUDRAP	\N	AFEU	\N	Audition "Paquet connectivité UE"	\N	2017-01-17 14:45:00	2017-01-17 15:35:00	\N	\N	2	0	\N	\N
166258	COM_EURO	AUDRAP	\N	AFEU	\N	Audition "Paquet connectivité UE"	\N	2017-01-17 15:45:00	2017-01-17 16:35:00	\N	\N	2	0	\N	\N
166261	COM_EURO	AUDRAP	\N	AFEU	\N	Audition "Paquet connectivité UE"	\N	2017-01-17 17:55:00	2017-01-17 18:40:00	\N	\N	2	0	\N	\N
166269	COM_EURO	AUDRAP	\N	AFEU	\N	Audition "Paquet connectivité UE"	\N	2017-01-11 15:05:00	2017-01-11 16:05:00	\N	\N	2	0	\N	\N
166275	COM_EURO	AUDRAP	\N	AFEU	\N	Audition "Paquet connectivité UE"	\N	2017-01-11 16:05:00	2017-01-11 17:05:00	\N	\N	1	0	\N	\N
166277	COM_EURO	AUDRAP	\N	AFEU	\N	Audition "Paquet connectivité UE"	\N	2017-01-11 17:20:00	2017-01-11 18:20:00	\N	\N	2	0	\N	\N
167492	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL FAURE POTIER	PPL FAURE POTIER	2017-01-25 14:15:00	2017-01-25 15:15:00	\N	\N	1	0	\N	\N
167494	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL FAURE POTIER	PPL FAURE POTIER	2017-01-25 18:30:00	2017-01-25 20:30:00	\N	\N	1	0	\N	\N
167496	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL FAURE POTIER	PPL FAURE POTIER	2017-01-26 08:30:00	2017-01-26 09:30:00	\N	\N	1	0	\N	\N
167512	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL FAURE POTIER	\N	2017-01-26 13:30:00	2017-01-26 17:00:00	\N	\N	1	0	\N	\N
167532	ETUDES	AUCUNE	\N	\N	\N	G.E. Vigne et Vin	G.E. Vigne et Vin	2017-01-25 08:30:00	2017-01-25 09:25:00	\N	\N	21	0	\N	909
167554	ETUDES	AUCUNE	\N	\N	\N	G.E. Communications électroniques et Postes	G.E. Communications électroniques et Postes	2017-01-25 08:30:00	2017-01-25 09:30:00	\N	\N	4	0	\N	913
167692	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Renforcer l'efficacité de la justice pénale	\N	2017-01-31 09:05:00	2017-01-31 09:20:00	2017-01-31 11:52:10	2017-01-31 17:42:38	17	1	\N	\N
167712	GIA	AUCUNE	\N	\N	\N	Rencontre avec Mme Dilma ROUSSEFF	Rencontre avec Mme Dilma ROUSSEFF, ancienne présidente de la République du Brésil	2017-01-31 17:30:00	2017-01-31 19:15:00	\N	\N	10	0	576	\N
167839	DELEGATION	DEPLACEMENT	\N	\N	COLTER	RI_CT et prévention de la radicalisation-déplacement à Chalon-Sur-Saône	\N	2017-01-30 10:30:00	2017-01-30 16:00:00	\N	\N	1	0	\N	\N
167873	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2017-01-31 14:30:00	2017-01-31 15:30:00	\N	\N	2	0	\N	\N
169772	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition Mario Monti et Alain Lamassoure	Audition Mario Monti et Alain Lamassoure	2017-02-01 15:40:00	2017-02-01 17:10:00	2017-02-01 17:47:33	2017-02-01 17:51:36	31	0	\N	\N
170332	COM_EURO	AUDRAP	\N	AFEU	\N	Gestion des fonds structurels	\N	2017-02-01 14:00:00	2017-02-01 15:15:00	\N	\N	3	0	\N	\N
170336	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	Réforme de la PAC	Réforme de la PAC - Audtion FNSEA	2017-02-01 17:00:00	2017-02-01 18:15:00	\N	\N	4	0	\N	\N
170392	MISSION	AUCUNE	\N	DEMOCRATIE	\N	\N	\N	2017-02-01 17:35:00	2017-02-01 19:20:00	2017-02-02 18:19:29	2017-02-02 18:24:21	8	0	\N	\N
170475	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Mineurs isolés	\N	2017-02-02 10:30:00	2017-02-02 18:30:00	\N	\N	2	0	\N	\N
170792	COM_ENQUETE	DEPLACEMENT	\N	SCHENGEN	\N	CE SCHENGEN-Strasbourg	CE SCHENGEN-Déplacement à Strasbourg	2017-02-06 07:45:00	2017-02-06 20:20:00	\N	\N	6	0	\N	\N
170832	COM_PERMANENTE	AUTRE	\N	CAE	\N	lutte contre l'accaparement des terres agricoles	lutte contre l'accaparement des terres agricoles	2017-02-07 09:00:00	2017-02-07 09:10:00	2018-05-18 15:52:09	2018-05-18 15:52:13	16	0	\N	\N
171105	GIA	AUCUNE	\N	\N	\N	Rencontre avec une délégation lettonne	Déjeuner au Sénat avec une délégation lettonne	2017-02-07 13:00:00	2017-02-07 14:30:00	\N	\N	2	0	616	\N
171193	GIA	AUCUNE	\N	\N	\N	Rencontre avec le couple d'Ambassadeurs de France en Croatie	Rencontre entre Mme Michèle ANDRÉ et le couple d'Ambassadeurs de France en Croatie	2017-02-07 10:00:00	2017-02-07 10:45:00	\N	\N	1	0	647	\N
173949	COM_ENQUETE	PLENIERE	\N	ATTEINTES	\N	15ème séquence d'auditions généralistes (CNEFAF)	15ème séquence d'auditions généralistes (CNEFAF)	2017-02-09 14:00:00	2017-02-09 15:00:00	2017-02-09 16:24:01	2017-02-09 16:53:24	6	0	\N	\N
173973	COM_ENQUETE	PLENIERE	\N	ATTEINTES	\N	9ème séquence d'auditions LGV-A65	9ème séquence d'auditions LGV-A65	2017-02-09 16:15:00	2017-02-09 17:00:00	2017-02-10 11:07:43	2017-02-10 11:38:27	4	0	\N	\N
173981	COM_ENQUETE	DEPLACEMENT	\N	ATTEINTES	\N	Déplacement à la réserve naturelle des Coussouls-de-Crau (Bouches-du-Rhône)	Déplacement à la réserve naturelle des Coussouls-de-Crau (Bouches-du-Rhône)	2017-02-06 06:05:00	2017-02-06 20:25:00	\N	\N	2	0	\N	\N
174072	COM_ENQUETE	PLENIERE	\N	ATTEINTES	\N	7ème séquence d'auditions NDDL (C° du dialogue et Cté des experts scientifiques)	7ème séquence d'auditions NDDL (C° du dialogue et Cté des experts scientifiques)	2017-02-09 17:35:00	2017-02-09 19:10:00	2017-02-10 11:06:49	2017-02-10 11:38:29	3	0	\N	\N
174332	MECSS	AUDRAP	\N	\N	MECSS	interrégimes en matière de retraite	\N	2017-02-15 14:30:00	2017-02-15 16:30:00	\N	\N	2	0	\N	\N
164944	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Sécurité publique	\N	2017-01-24 09:10:00	2017-01-24 10:00:00	2017-01-24 12:01:58	2017-01-24 15:31:07	13	1	\N	\N
183121	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Nucléaire	\N	2017-03-08 11:00:00	2017-03-08 12:00:00	\N	\N	4	0	\N	\N
165792	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Ord. s/Corse + PPL Efficacité justice pénale + PPL Partis politiques	\N	2017-01-25 09:35:00	2017-01-25 12:30:00	2017-01-25 16:16:35	2017-01-25 16:17:59	37	1	\N	\N
164994	DELEGATION	AUCUNE	\N	\N	206	Audition publique sur "Les enjeux de la recherche en énergie"	Audition publique sur "Les enjeux de la recherche en énergie"	2017-02-09 09:30:00	2017-02-09 17:10:00	2017-02-10 16:37:18	2017-02-10 16:39:13	7	0	\N	\N
164995	DELEGATION	AUCUNE	\N	\N	206	Réunion planière, stratégie nationale de recherche	\N	2017-02-22 18:00:00	2017-02-22 19:25:00	2017-02-23 15:02:15	2017-02-23 15:14:08	6	0	\N	\N
164996	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière	\N	2017-02-23 09:30:00	2017-02-23 11:30:00	2017-02-23 16:19:11	2017-02-23 16:54:19	5	0	\N	\N
165000	DELEGATION	AUCUNE	\N	\N	206	Examen du projet de rapport PNGMDR	Examen du projet de rapport sur "L'évaluation du plan national de gestion des matières et déchets radioactifs"	2017-03-08 15:05:00	2017-03-08 16:15:00	2017-03-08 19:01:13	2017-03-09 09:21:51	5	0	\N	\N
165001	DELEGATION	AUCUNE	\N	\N	206	Examen du projet de rapport sur l'intelligence artificielle	\N	2017-03-14 16:45:00	2017-03-14 18:40:00	2017-03-15 11:17:27	2017-03-28 09:50:43	9	0	\N	\N
166132	MISSION	AUCUNE	\N	DEMOCRATIE	\N	\N	\N	2017-01-25 14:40:00	2017-01-25 15:55:00	2017-01-25 17:05:30	2017-01-25 17:27:12	13	0	\N	\N
167006	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Justice pénale	PPL Justice pénale	2017-01-31 14:35:00	2017-01-31 16:30:00	\N	\N	135	0	\N	\N
167007	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2017-01-31 16:50:00	2017-01-31 17:30:00	\N	\N	305	0	\N	\N
167008	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Justice pénale	PPL Justice pénale	2017-01-31 17:45:00	2017-01-31 19:30:00	\N	\N	89	0	\N	\N
167010	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Obligations comptables des partis politiques	PPL Obligations comptables des partis politiques	2017-02-01 14:30:00	2017-02-01 16:00:00	\N	\N	70	0	\N	\N
167011	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Entreprises donneuses d'ordre	PPL Entreprises donneuses d'ordre	2017-02-01 16:15:00	2017-02-01 17:40:00	\N	\N	41	0	\N	\N
167012	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Transport sanitaire héliporté	PPL Transport sanitaire héliporté	2017-02-01 18:30:00	2017-02-01 20:00:00	\N	\N	31	0	\N	\N
167014	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat ENA	Débat ENA	2017-02-01 21:30:00	2017-02-02 23:15:00	\N	\N	20	0	\N	\N
167015	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Violences sexuelles	Débat Violences sexuelles	2017-02-02 10:40:00	2017-02-02 12:15:00	\N	\N	31	0	\N	\N
167017	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Biocontrôle	PPL Biocontrôle	2017-02-07 14:35:00	2017-02-07 17:45:00	\N	\N	133	0	\N	\N
167018	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Prescription en matière pénale	PPL Prescription en matière pénale	2017-02-07 17:45:00	2017-02-07 19:15:00	\N	\N	67	0	\N	\N
167020	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Statut de Paris	PJL Statut de Paris	2017-02-07 19:25:00	2017-02-07 21:15:00	\N	\N	50	0	\N	\N
167024	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Rapport cour des comptes	Rapport cour des comptes	2017-02-09 11:35:00	2017-02-09 12:20:00	\N	\N	169	0	\N	\N
167025	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2017-02-09 15:05:00	2017-02-09 16:00:00	\N	\N	264	0	\N	\N
167032	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Formation professionnelle des adultes	PJL Formation professionnelle des adultes	2017-02-09 16:15:00	2017-02-09 18:00:00	\N	\N	28	0	\N	\N
167375	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ONG "Portes ouvertes"	Entretien avec l'ONG "Portes ouvertes" pour la présentation de son index mondial de la persécution des chrétiens	2017-01-26 09:00:00	2017-01-26 11:00:00	\N	\N	11	0	CHRETORIENT	CHRETORIENT
167592	ETUDES	AUCUNE	\N	\N	\N	Réunion - Audition du GIFAS	Réunion - Audition du GIFAS	2017-01-26 08:30:00	2017-01-26 09:45:00	\N	\N	5	0	\N	933
167598	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Réforme rythmes scolaires	Réforme rythmes scolaires - Table ronde représentants élus locaux	2017-01-26 09:00:00	2017-01-26 11:00:00	\N	\N	2	0	\N	\N
167601	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Réforme rythmes scolaires	Réforme rythmes scolaires - Audition de Georges FOTINOS	2017-01-26 11:00:00	2017-01-26 12:20:00	\N	\N	2	0	\N	\N
167617	COM_PERMANENTE	AUDRAP	\N	FINC	\N	\N	\N	2017-01-25 15:00:00	2017-01-25 16:00:00	\N	\N	1	0	\N	\N
168344	COM_PERMANENTE	AUTRE	\N	FINC	\N	PJL Assainissement cadastral - Examen rapport pour avis et amendements	PJL Assainissement cadastral - Examen rapport pour avis et amendements	2017-01-31 15:35:00	2017-01-31 16:05:00	2017-02-01 17:48:17	2017-02-01 17:51:50	28	0	\N	\N
168757	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Compétences eau & assainissement des communautés de communes	\N	2017-01-31 14:30:00	2017-01-31 17:00:00	\N	\N	2	0	\N	\N
168760	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Compétences des intercommunalités	\N	2017-01-31 14:30:00	2017-01-31 17:00:00	\N	\N	2	0	\N	\N
170036	MISSION	AUCUNE	\N	PSYCHIATRIE	\N	\N	\N	2017-02-01 15:10:00	2017-02-01 18:45:00	2017-02-02 11:12:33	2017-02-02 15:16:02	12	0	\N	\N
170472	GIA	AUCUNE	\N	\N	\N	petit-déjeuner ambassadeur de Géorgie	petit-déjeuner de travail du président et du président du groupe avec l'ambassadeur de Géorgie en France	2017-01-25 08:15:00	2017-01-25 09:30:00	\N	\N	2	0	534	\N
170552	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL "Faure Potier"	PPL "Faure Potier"	2017-01-31 14:30:00	2017-01-31 15:15:00	\N	\N	1	0	\N	\N
170632	GIA	AUCUNE	\N	\N	\N	visite de parlementaires coréens	\N	2017-02-02 16:30:00	2017-02-02 17:30:00	\N	\N	2	0	613	\N
165953	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PPL Transport sanitaire héliporté	\N	2017-01-25 11:00:00	2017-01-25 11:55:00	2017-01-25 14:41:13	2017-01-25 15:01:28	46	0	\N	\N
169832	CMP	AUTRE	\N	ENERGIE	\N	PJL Autoconsommation d'électricité et énergies renouvelables	PJL Autoconsommation d'électricité et énergies renouvelables	2017-02-01 16:30:00	2017-02-01 17:10:00	\N	\N	7	0	\N	\N
170652	COM_ENQUETE	PLENIERE	\N	ATTEINTES	\N	Réunion à huis clos  NDDL/ 5eme sequence d'auditions LGV-A65/13e sequence généraliste	Réunion à huis clos sur la préparation du déplacement à Notre-Dame-des-Landes (17 février 2017) /5e LGV-A65/13e generale	2017-02-01 14:15:00	2017-02-01 18:05:00	2017-02-03 15:41:59	2017-02-03 16:00:20	9	0	\N	\N
170674	COM_ENQUETE	PLENIERE	\N	SCHENGEN	\N	CE SCHENGEN-DCPJ	CE SCHENGEN-Direction centrale de la police judiciaire	2017-02-01 16:35:00	2017-02-01 17:40:00	2017-02-03 15:25:56	2017-02-03 16:00:18	9	0	\N	\N
172312	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2017-02-08 10:30:00	2017-02-08 12:35:00	2017-02-08 15:30:04	2017-02-08 15:44:10	55	0	\N	\N
174132	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Groupe de travail Dissuasion nucléaire	\N	2017-02-07 08:00:00	2017-02-07 14:00:00	\N	\N	2	0	\N	\N
174135	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Groupe de travail Dissuasion nucléaire	\N	2017-02-07 17:30:00	2017-02-07 19:00:00	\N	\N	2	0	\N	\N
174138	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Nucléaire	\N	2017-02-07 16:00:00	2017-02-07 17:10:00	\N	\N	2	0	\N	\N
174141	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Drones	\N	2017-02-09 10:30:00	2017-02-09 11:30:00	\N	\N	2	0	\N	\N
174335	MECSS	AUDRAP	\N	\N	MECSS	interrégimes en matière de retraite	\N	2017-03-07 14:00:00	2017-03-07 18:00:00	\N	\N	2	0	\N	\N
178659	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2017-02-21 14:50:00	2017-02-21 16:05:00	\N	\N	3	0	\N	\N
178793	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Gouvernance du football	Mission d'information sur la gouvernance du football	2017-02-21 17:05:00	2017-02-21 17:45:00	\N	\N	6	0	\N	\N
180134	COM_ENQUETE	PLENIERE	\N	SCHENGEN	\N	CE SCHENGEN	CE SCHENGEN-CNIL-DSI	2017-02-22 14:00:00	2017-02-22 15:45:00	2017-02-22 16:54:03	2017-02-22 17:14:34	11	0	\N	\N
181772	MISSION	AUCUNE	\N	DEMOCRATIE	\N	\N	\N	2017-02-23 13:35:00	2017-02-23 15:00:00	2017-02-23 18:43:27	2017-02-24 10:11:59	13	0	\N	\N
182056	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Déradicalisation	\N	2017-02-23 15:45:00	2017-02-23 17:00:00	\N	\N	1	0	\N	\N
183052	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Déplacement mission Réforme territoriale	Déplacement mission de suivi et de contrôle des dernières lois de réforme territoriale à Toulouse	2017-03-13 08:35:00	2017-03-13 20:20:00	\N	\N	5	0	\N	\N
183272	COM_EURO	DEPLACEMENT	\N	AFEU	\N	Bruxelles - Relations entre l'Union européenne et la Russie	Bruxelles - Relations entre l'Union européenne et la Russie	2017-03-14 10:00:00	2017-03-14 17:00:00	\N	\N	2	0	\N	\N
183312	GIA	AUCUNE	\N	\N	\N	Déjeuner préparation déplacement	Déjeuner de préparation du déplacement du GIA France-Pologne à Varsovie	2017-03-09 12:30:00	2017-03-09 14:00:00	\N	\N	1	0	600	\N
183992	MISSION	DEPLACEMENT	\N	DEMOCRATIE	\N	\N	\N	2017-03-14 11:00:00	2017-03-14 19:00:00	\N	\N	4	0	\N	\N
184012	MISSION	DEPLACEMENT	\N	DEMOCRATIE	\N	\N	\N	2017-03-15 07:45:00	2017-03-15 19:00:00	\N	\N	6	0	\N	\N
184053	MISSION	DEPLACEMENT	\N	DEMOCRATIE	\N	\N	\N	2017-03-16 08:00:00	2017-03-16 16:30:00	\N	\N	5	0	\N	\N
184592	DELEGATION	AUCUNE	\N	\N	206	Examen du projet de rapport sur les biotechnologies	\N	2017-03-28 16:40:00	2017-03-28 18:35:00	2017-03-29 16:32:31	2017-03-29 16:58:59	8	0	\N	\N
185132	DELEGATION	AUCUNE	\N	\N	211	DDF - TABLE RONDE ENSEIGNEMENT AGRICOLE	DDF - TABLE RONDE ENSEIGNEMENT AGRICOLE	2017-03-30 09:00:00	2017-03-30 12:00:00	2017-03-30 12:52:31	2017-03-30 15:27:25	8	0	\N	\N
185152	COM_PERMANENTE	AUTRE	\N	LOIS	\N	MI Redressement de la justice	\N	2017-04-04 14:40:00	2017-04-04 16:40:00	2017-04-04 17:19:48	2017-04-04 17:25:01	21	4	\N	\N
185612	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Situation des urgences hospitalières	\N	2017-04-04 14:30:00	2017-04-04 18:30:00	\N	\N	3	0	\N	\N
185616	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Situation des urgences hospitalières	\N	2017-04-05 11:00:00	2017-04-05 13:00:00	\N	\N	3	0	\N	\N
185652	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	UNIC	Déplacement à Kiev pour le Conseil interparlementaire Ukraine-OTAN (UNIC)	2017-04-04 08:00:00	2017-04-06 18:00:00	\N	\N	1	0	\N	\N
185692	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Ecologie 2017 - Enjeux budgétaire application droit communautaire de l'environnem	Contrôle Ecologie 2017 - Audition du ministère des affaires européennes	2017-04-04 09:30:00	2017-04-04 11:00:00	\N	\N	1	0	\N	\N
185732	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Justice 2017 - Déplacement	Contrôle Justice 2017 - Déplacement Unité sanitaire du centre pénitentiaire de Laon	2017-04-06 10:00:00	2017-04-06 16:30:00	\N	\N	1	0	\N	\N
185752	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail 2 % du PIB	\N	2017-04-06 08:30:00	2017-04-06 10:00:00	\N	\N	2	0	\N	\N
185755	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Visite d'une délégation étrangère	\N	2017-04-06 14:00:00	2017-04-06 16:00:00	\N	\N	1	0	\N	\N
186112	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Parc immobilier du ministère de la défense 2017 - Déplacement	Contrôle Parc immobilier du ministère de la défense 2017 - Déplacement aux Invalides	2017-04-14 10:00:00	2017-04-14 13:00:00	\N	\N	1	0	\N	\N
172226	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2017-02-08 09:45:00	2017-02-08 10:25:00	2017-02-08 15:33:46	2017-02-08 15:44:13	46	1	\N	\N
186132	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Parc immobilier du ministère de la défense 2017 	Contrôle Parc immobilier du ministère de la défense 2017 - Audition Etat-major de l'armée de Terre	2017-04-14 14:30:00	2017-04-14 15:30:00	\N	\N	1	0	\N	\N
186172	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Recherche et enseignement supérieur - SATT - Déplacement Lille	Contrôle Recherche et enseignement supérieur - SATT - Déplacement Lille	2017-04-20 08:15:00	2017-04-20 19:20:00	\N	\N	1	0	\N	\N
186192	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Situation des urgences hospitalières	\N	2017-04-20 10:00:00	2017-04-20 11:00:00	\N	\N	3	0	\N	\N
186196	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Situation des urgences hospitalières	\N	2017-04-20 14:30:00	2017-04-20 17:00:00	\N	\N	3	0	\N	\N
186244	GIA	AUCUNE	\N	\N	\N	Entretien de M. Vial avec Mme  Lara Scarlett Gervais	Entretien de M. Vial avec Mme  Lara Scarlett Gervais (chercheuse)	2017-04-19 08:00:00	2017-04-19 10:00:00	\N	\N	1	0	644	\N
186252	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Groupe de travail Culture et handicap	Groupe de travail Culture et handicap	2017-04-12 15:00:00	2017-04-12 16:45:00	\N	\N	2	0	\N	\N
186255	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Groupe de travail Culture et handicap	Groupe de travail Culture et handicap	2017-04-13 10:30:00	2017-04-13 11:30:00	\N	\N	1	0	\N	\N
186257	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	\N	\N	2017-04-13 12:30:00	2017-04-13 16:30:00	\N	\N	2	0	\N	\N
186272	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Groupe de travail rythmes scolaires	Groupe de travail rythmes scolaires	2017-04-12 11:00:00	2017-04-12 12:00:00	\N	\N	2	0	\N	\N
186275	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	groupe de travail Rythmes scolaires	Groupe de travail rythmes scolaires	2017-04-12 14:00:00	2017-04-12 17:00:00	\N	\N	2	0	\N	\N
186292	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation de députés mongols du Grand Khoural de Mongolie 	"Petit-déjeuner des entreprises françaises"	2017-04-04 08:05:00	2017-04-04 10:05:00	\N	\N	3	0	612	\N
186296	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation parlementaire du Grand Khoural de Mongolie	Visite du Musée d'Orsay	2017-04-03 13:30:00	2017-04-03 15:00:00	\N	\N	1	0	612	\N
186298	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation parlementaire du Grand Khoural de Mongolie	Croisière en bateau-mouche	2017-04-03 17:00:00	2017-04-03 18:15:00	\N	\N	2	0	612	\N
186301	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation parlementaire du Grand Khoural de Mongolie	Déplacement en Nouvelle-Aquitaine (Deux-Sèvres et Charente-Maritime)	2017-04-05 10:00:00	2017-04-05 21:00:00	\N	\N	2	0	612	\N
177752	DELEGATION	AUDRAP	\N	\N	COLTER	RI_prévention radicalisation et collectivités	RI_prévention radicalisation et collectivités	2017-02-08 17:00:00	2017-02-08 17:45:00	\N	\N	2	0	\N	\N
178235	MISSION	AUCUNE	\N	DEMOCRATIE	\N	\N	\N	2017-02-21 13:30:00	2017-02-21 14:30:00	2017-02-21 16:24:02	2017-02-21 17:50:22	8	0	\N	\N
178632	MISSION	AUCUNE	\N	PSYCHIATRIE	\N	\N	\N	2017-02-21 14:35:00	2017-02-21 16:40:00	2017-02-21 17:32:59	2017-02-21 17:50:23	16	0	\N	\N
180738	GIA	AUCUNE	\N	\N	\N	Colloque Egypte	Colloque Sénat-Business France sur l'Egypte	2017-02-20 14:30:00	2017-02-20 19:00:00	\N	\N	2	0	617	\N
180743	MISSION	AUDRAP	\N	DEMOCRATIE	\N	\N	\N	2017-02-21 15:00:00	2017-02-21 16:00:00	\N	\N	1	0	\N	\N
180747	MISSION	AUDRAP	\N	DEMOCRATIE	\N	\N	\N	2017-02-21 16:00:00	2017-02-21 17:00:00	\N	\N	1	0	\N	\N
180772	MISSION	AUCUNE	\N	DEMOCRATIE	\N	\N	\N	2017-02-22 15:00:00	2017-02-22 19:10:00	2017-02-23 12:22:43	2017-02-23 15:10:53	10	0	\N	\N
180972	COM_EURO	CONTROLE	\N	AFEU	\N	\N	\N	2017-02-23 08:35:00	2017-02-23 10:25:00	2017-02-23 11:31:48	2017-02-23 15:10:04	15	0	\N	\N
182732	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Mineurs isolés	\N	2017-02-22 16:00:00	2017-02-22 17:45:00	\N	\N	5	0	\N	\N
182752	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Dialogue France-Russie	\N	2017-02-26 12:45:00	2017-03-01 11:55:00	\N	\N	6	0	\N	\N
182759	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Nucléaire	\N	2017-02-28 09:30:00	2017-02-28 12:30:00	\N	\N	4	0	\N	\N
182764	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Nucléaire	\N	2017-02-28 15:20:00	2017-02-28 16:10:00	\N	\N	4	0	\N	\N
182769	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Nucléaire	\N	2017-03-01 08:00:00	2017-03-01 09:40:00	\N	\N	5	0	\N	\N
182775	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Groupe de travail Nucléaire	\N	2017-02-28 16:30:00	2017-02-28 18:30:00	\N	\N	5	0	\N	\N
182812	COM_ENQUETE	AUDRAP	\N	ATTEINTES	\N	Audition rapporteur de M.H.  Delgado-Rosa ( DG Environnement - Commission européenne)	Audition rapporteur de M.H.  Delgado-Rosa ( DG Environnement - Commission européenne)	2017-03-02 16:35:00	2017-03-02 18:00:00	\N	\N	3	0	\N	\N
182852	COM_ENQUETE	AUDRAP	\N	ATTEINTES	\N	\N	\N	2017-03-07 16:40:00	2017-03-07 18:55:00	\N	\N	1	0	\N	\N
183058	MISSION	AUDRAP	\N	DEMOCRATIE	\N	\N	\N	2017-03-08 17:15:00	2017-03-08 18:45:00	\N	\N	3	0	\N	\N
183192	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Situation des urgences hospitalières	\N	2017-03-14 12:00:00	2017-03-14 13:00:00	\N	\N	3	0	\N	\N
183196	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Situation des urgences hospitalières	\N	2017-03-14 16:00:00	2017-03-14 17:30:00	\N	\N	3	0	\N	\N
183412	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2017-03-14 14:30:00	2017-03-14 16:45:00	\N	\N	3	0	\N	\N
183416	QUESTURE	AUCUNE	\N	\N	\N	COM Public Sénat	Comité de suivi du COM Public Sénat	2017-03-14 16:50:00	2017-03-14 18:10:00	\N	\N	3	0	\N	\N
183432	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Gabriel ATANASOV, Chargé d'affaires à l'Ambassade de Macédoine	Entretien avec M. Gabriel ATANASOV, chargé d'affaires par intérim à l'Ambassade de Macédoine (ARYM)	2017-03-14 16:30:00	2017-03-14 17:30:00	\N	\N	3	0	674	\N
183452	GIA	AUCUNE	\N	\N	\N	Entretien avec S.E. M. Rajko RISTIC, Ambassadeur de Serbie	Entretien avec S.E. M. Rajko RISTIC, Ambassadeur de Serbie	2017-03-15 08:45:00	2017-03-15 09:45:00	\N	\N	2	0	674	\N
184112	GIA	AUCUNE	\N	\N	\N	ambassadeur	petit déjeuner avec l'ambassadeur du Royaume-Uni en France	2017-02-15 08:30:00	2017-02-15 09:45:00	\N	\N	12	0	581	\N
184144	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Situation des urgences hospitalières	\N	2017-03-21 14:00:00	2017-03-21 15:30:00	\N	\N	3	0	\N	\N
184152	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Situation des urgences hospitalières	\N	2017-03-29 09:30:00	2017-03-29 12:45:00	\N	\N	3	0	\N	\N
184156	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Situation des urgences hospitalières	\N	2017-03-29 14:30:00	2017-03-29 16:00:00	\N	\N	3	0	\N	\N
184215	MECSS	AUDRAP	\N	\N	MECSS	Mecss zones sous-dotées	Mecss zones sous-dotées	2017-03-29 14:30:00	2017-03-29 17:30:00	\N	\N	5	0	\N	\N
184232	MECSS	AUDRAP	\N	\N	MECSS	Mecss zones sous-dotées	Mecss zones sous-dotées	2017-04-05 08:30:00	2017-04-05 16:30:00	\N	\N	2	0	\N	\N
184235	MECSS	AUDRAP	\N	\N	MECSS	Mecss zones sous-dotées	Mecss zones sous-dotées	2017-04-19 08:30:00	2017-04-19 10:30:00	\N	\N	4	0	\N	\N
184239	MECSS	AUDRAP	\N	\N	MECSS	Mecss zones sous-dotées	Mecss zones sous-dotées	2017-04-25 17:30:00	2017-04-25 18:30:00	\N	\N	3	0	\N	\N
184243	MECSS	AUDRAP	\N	\N	MECSS	Mecss zones sous-dotées	Mecss zones sous-dotées	2017-04-26 09:30:00	2017-04-26 10:30:00	\N	\N	2	0	\N	\N
184247	MECSS	AUDRAP	\N	\N	MECSS	Mecss interrégimes en matière de retraite	Mecss interrégimes en matière de retraite	2017-03-22 09:00:00	2017-03-22 12:00:00	\N	\N	2	0	\N	\N
183126	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Nucléaire	\N	2017-03-08 14:30:00	2017-03-08 15:30:00	\N	\N	4	0	\N	\N
184251	MECSS	AUDRAP	\N	\N	MECSS	Mecss interrégimes en matière de retraite	Mecss interrégimes en matière de retraite	2017-03-22 15:00:00	2017-03-22 16:00:00	\N	\N	2	0	\N	\N
184254	MECSS	AUDRAP	\N	\N	MECSS	Mecss interrégimes en matière de retraite	Mecss interrégimes en matière de retraite	2017-04-11 10:00:00	2017-04-11 12:00:00	\N	\N	2	0	\N	\N
184963	DELEGATION	AUCUNE	\N	\N	COLTER	Examen rapport "Nouvelles technologies"	\N	2017-04-19 11:15:00	2017-04-19 12:25:00	2017-04-20 11:43:53	2017-04-20 12:08:00	12	0	\N	\N
185872	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ambassadeur du Soudan à Paris	Entretien avec l'ambassadeur du Soudan à Paris	2017-04-12 13:00:00	2017-04-12 15:00:00	\N	\N	1	0	588	\N
185892	GIA	AUCUNE	\N	\N	\N	Visite des collaborateurs parlementaires stagiaires allemands de l¿Assemblée nationale	Visite des collaborateurs parlementaires stagiaires allemands de l¿Assemblée nationale	2017-04-12 14:15:00	2017-04-12 15:00:00	\N	\N	1	0	604	\N
186304	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation parlementaire du Grand Khoural de Mongolie	Remise de décoration de l'Etoile Polaire et dîner	2017-04-04 18:00:00	2017-04-04 21:00:00	\N	\N	2	0	612	\N
186332	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation parlementaire du Grand Khoural de Mongolie	Accueil et séance d'information de M. Madani CHEURFA, secrétaire général du CEVIPOF sur les élections françaises de 2017	2017-04-03 09:30:00	2017-04-03 11:30:00	\N	\N	1	0	612	\N
186352	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation parlementaire du Grand Khoural de Mongolie	Dîner de clôture	2017-04-06 20:00:00	2017-04-06 22:00:00	\N	\N	1	0	612	\N
186354	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation parlementaire du Grand Khoural de Mongolie	Déjeuner d'accueil	2017-04-03 12:00:00	2017-04-03 13:30:00	\N	\N	1	0	612	\N
186356	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation parlementaire du Grand Khoural de Mongolie	Entretien avec M. François Croquette, ambassadeur de France pour les droits de l'homme	2017-04-04 16:40:00	2017-04-04 17:55:00	\N	\N	1	0	612	\N
186358	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation parlementaire du Grand Khoural de Mongolie	Retour du déplacement en Nouvelle-Aquitaine (Deux-Sèvres et Charente-Maritime)	2017-04-06 09:15:00	2017-04-06 12:30:00	\N	\N	1	0	612	\N
186360	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation parlementaire du Grand Khoural de Mongolie	Départ de la délégation	2017-04-07 08:00:00	2017-04-07 08:45:00	\N	\N	1	0	612	\N
186372	COM_PERMANENTE	AUTRE	\N	CDD	\N	Contrat de performance Etat-SNCF Réseau	\N	2017-04-19 14:45:00	2017-04-19 16:00:00	2017-04-20 11:45:53	2017-04-20 12:05:42	7	0	\N	\N
186397	COM_PERMANENTE	AUTRE	\N	CDD	\N	contrat de performance Etat-SNCF Réseau	\N	2017-04-19 18:00:00	2017-04-19 19:15:00	2017-04-20 11:45:27	2017-04-20 12:05:43	3	0	\N	\N
186432	ETUDES	AUCUNE	\N	\N	\N	\N	Déplacement Isère	2017-04-13 06:00:00	2017-04-13 19:00:00	\N	\N	5	0	\N	922
186452	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Avenir des médias d'information	MI sur l'avenir des médias d'information	2017-04-19 14:30:00	2017-04-19 18:00:00	\N	\N	4	0	\N	\N
186472	COM_PERMANENTE	DEPLACEMENT	\N	CDD	\N	Australie	Mission de la commission en Australie	2017-03-24 00:00:00	2017-04-02 00:00:00	\N	\N	5	0	\N	\N
186478	MISSION	AUDRAP	\N	DEMOCRATIE	\N	\N	\N	2017-04-19 15:30:00	2017-04-19 17:50:00	\N	\N	3	0	\N	\N
186482	MECSS	AUDRAP	\N	\N	MECSS	Pertinence des actes	Pertinence des actes	2017-04-26 11:00:00	2017-04-26 12:00:00	\N	\N	1	0	\N	\N
186517	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Groupe de travail Nucléaire	\N	2017-04-20 08:00:00	2017-04-20 10:30:00	\N	\N	3	0	\N	\N
186532	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Nucléaire	\N	2017-04-20 11:00:00	2017-04-20 12:00:00	\N	\N	3	0	\N	\N
186552	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Drones	\N	2017-04-18 10:00:00	2017-04-18 12:15:00	\N	\N	4	0	\N	\N
186557	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Drones	\N	2017-04-18 14:00:00	2017-04-18 15:00:00	\N	\N	3	0	\N	\N
186572	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Engagements financiers de l'Etat	Contrôle Engagements financiers de l'Etat - Audition Natixis	2017-04-18 16:00:00	2017-04-18 17:00:00	\N	\N	1	0	\N	\N
177712	COM_EURO	AUDRAP	\N	AFEU	\N	Erasmus des Apprentis	\N	2017-02-15 16:45:00	2017-02-15 18:00:00	\N	\N	2	0	\N	\N
178217	GIA	AUCUNE	\N	\N	\N	déjeuner de travail	Rencontre avec M. Daniel COHEN, expert en cyber-terrorisme à l¿Institut israélien pour les Études de Sécurité nationale	2017-02-21 12:45:00	2017-02-21 14:30:00	\N	\N	6	0	595	\N
178755	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation de députés turcs de la GANT	conduite par Mme Serap YASAR	2017-02-14 12:30:00	2017-02-15 21:00:00	\N	\N	11	0	624	\N
179363	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2017-02-22 10:30:00	2017-02-22 11:05:00	2017-02-22 14:19:17	2017-02-22 15:45:58	30	0	\N	\N
181443	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion conjointe du 22 février 2017	\N	2017-02-22 17:30:00	2017-02-22 19:25:00	2017-02-23 16:25:50	2017-02-23 16:27:53	9	0	\N	\N
181592	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe et accueil d'une délégation de députés de Jordanie	Assemblée générale en vue du projet de déplacement et Visite d¿une délégation de membres de la Chambre des députés du Ro	2017-02-23 08:30:00	2017-02-23 12:30:00	\N	\N	6	0	659	\N
182492	COM_ENQUETE	PLENIERE	\N	ATTEINTES	\N	17è séquence d'auditions généralistes et 9è séquence Notre-Dame-des-Landes	Auditions de bureaux d'études et de représentants des intercommunalités de Nantes 	2017-03-01 09:05:00	2017-03-01 12:30:00	2017-03-02 09:57:40	2017-03-02 10:11:16	5	0	\N	\N
182532	COM_ENQUETE	DEPLACEMENT	\N	ATTEINTES	\N	Déplacement au Conseil départemental des Yvelines (Versailles)	Déplacement au Conseil départemental des Yvelines (Versailles)	2017-02-28 13:50:00	2017-02-28 16:15:00	\N	\N	3	0	\N	\N
182816	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Compétitivité des places financières -Déplacement à Hong-Kong et Singapour	Compétitivité des places financières -Déplacement à Hong-Kong et Singapour	2017-03-04 23:30:00	2017-03-11 06:10:00	\N	\N	6	0	\N	\N
182833	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI redressement de la justice	MI redressement de la justice	2017-03-02 10:15:00	2017-03-02 12:00:00	\N	\N	1	0	\N	\N
182835	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI redressement de la justice	MI redressement de la justice	2017-03-02 14:30:00	2017-03-02 19:30:00	\N	\N	1	0	\N	\N
182837	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI redressement de la justice	MI redressement de la justice	2017-03-03 09:00:00	2017-03-03 11:30:00	\N	\N	1	0	\N	\N
182932	MISSION	AUDRAP	\N	DEMOCRATIE	\N	\N	\N	2017-03-07 10:00:00	2017-03-07 11:30:00	\N	\N	2	0	\N	\N
182937	MISSION	AUDRAP	\N	DEMOCRATIE	\N	\N	\N	2017-03-07 11:30:00	2017-03-07 12:30:00	\N	\N	3	0	\N	\N
182943	MISSION	AUDRAP	\N	DEMOCRATIE	\N	\N	\N	2017-03-07 12:30:00	2017-03-07 13:45:00	\N	\N	2	0	\N	\N
182947	MISSION	DEPLACEMENT	\N	DEMOCRATIE	\N	\N	\N	2017-03-07 13:45:00	2017-03-07 17:00:00	\N	\N	2	0	\N	\N
182955	MISSION	AUCUNE	\N	DEMOCRATIE	\N	\N	\N	2017-03-08 09:35:00	2017-03-08 11:10:00	2017-03-08 17:37:41	2017-03-09 09:20:56	3	0	\N	\N
183094	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Engagements financiers de l'Etat	Contrôle Engagements financiers de l'Etat - Banque de France	2017-03-06 16:00:00	2017-03-06 17:00:00	\N	\N	1	0	\N	\N
183112	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Nucléaire	\N	2017-03-07 14:00:00	2017-03-07 16:30:00	\N	\N	4	0	\N	\N
183117	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Nucléaire	\N	2017-03-07 17:30:00	2017-03-07 18:30:00	\N	\N	3	0	\N	\N
183135	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Nucléaire	\N	2017-03-08 17:30:00	2017-03-08 18:30:00	\N	\N	2	0	\N	\N
183332	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI justice	MI justice	2017-03-14 09:45:00	2017-03-14 12:30:00	\N	\N	1	0	\N	\N
183334	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI justice	MI justice	2017-03-14 14:30:00	2017-03-14 19:15:00	\N	\N	1	0	\N	\N
183338	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI redressement de la justice	MI redressement de la justice	2017-03-15 14:30:00	2017-03-15 19:15:00	\N	\N	1	0	\N	\N
183552	MISSION	PLEIN_NON_JO	\N	BREXIT	\N	Rencontre avec les ambassadeurs de l'UE27	Rencontre avec les ambassadeurs de l'UE27	2017-03-15 14:30:00	2017-03-15 17:40:00	\N	\N	29	0	\N	\N
183752	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Défense 2017	Contrôle Défense 2017 - Le parc immobilier du ministère de la défense - Audition du Ministère de la défense	2017-03-15 15:00:00	2017-03-15 16:15:00	\N	\N	1	0	\N	\N
183792	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Défense 2017 - Déplacement	Contrôle Défense 2017 - Parc immobilier du ministère de la défense - - Déplacement - Ministère de la défense	2017-03-16 12:00:00	2017-03-16 13:00:00	\N	\N	1	0	\N	\N
183892	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail 2 % du PIB	\N	2017-03-16 09:00:00	2017-03-16 11:00:00	\N	\N	2	0	\N	\N
183912	MECSS	AUDRAP	\N	\N	MECSS	Offre de soins primaires dans les zones sous-dotées	Offre de soins primaires dans les zones sous-dotées	2017-03-15 09:30:00	2017-03-15 10:15:00	\N	\N	2	0	\N	\N
183915	MECSS	AUDRAP	\N	\N	MECSS	Offre de soins primaires dans les zones sous-dotées	Offre de soins primaires dans les zones sous-dotées	2017-03-15 14:30:00	2017-03-15 17:15:00	\N	\N	2	0	\N	\N
183918	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Accords de compétitivité au sein des entreprises	La mise en oeuvre des accords de compétitivité au sein des entreprises	2017-03-23 09:00:00	2017-03-23 11:00:00	\N	\N	1	0	\N	\N
184238	GIA	AUCUNE	\N	\N	\N	Entretien avec S.E. M. Qëndrim GASHI, Ambassadeur du Kosovo	Entretien avec S.E. M. Qëndrim GASHI, Ambassadeur du Kosovo	2017-03-21 10:00:00	2017-03-21 11:00:00	\N	\N	2	0	674	\N
184248	GIA	AUCUNE	\N	\N	\N	Entretien avec S.E. M. Ivan ORLIC, Ambassadeur de Bosnie-Herzégovine	Entretien avec S.E. M. Ivan ORLIC, Ambassadeur de Bosnie-Herzégovine	2017-03-21 15:30:00	2017-03-21 16:30:00	\N	\N	2	0	674	\N
184272	GIA	AUCUNE	\N	\N	\N	Entretien avec S.E. Mme Dragica PONORAC, Ambassadrice du Monténégro	Entretien avec S.E. Mme Dragica PONORAC, Ambassadrice du Monténégro	2017-03-21 17:00:00	2017-03-21 18:00:00	\N	\N	2	0	674	\N
184293	GIA	AUCUNE	\N	\N	\N	Audition Lefeuvre politologue afghanistan	\N	2017-03-22 09:30:00	2017-03-22 11:00:00	\N	\N	2	0	619	\N
184296	GIA	AUCUNE	\N	\N	\N	réunion de travail ambassadeur du Pakistan	\N	2017-03-22 11:00:00	2017-03-22 12:15:00	\N	\N	1	0	619	\N
185012	DELEGATION	DEPLACEMENT	\N	\N	206	Déplacement en Russie dans le cadre de l'EPTA	\N	2017-04-02 09:00:00	2017-04-08 00:00:00	\N	\N	3	0	\N	\N
185092	COM_ENQUETE	PLENIERE	\N	SCHENGEN	\N	CE SCHENGEN	CE SCHENGEN	2017-03-29 09:35:00	2017-03-29 11:30:00	2017-03-29 17:22:42	2017-03-29 17:35:29	14	2	\N	\N
185292	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Groupe de travail Drones	Déplacement à Chaumont (base militaire)	2017-03-30 07:45:00	2017-03-30 19:45:00	\N	\N	3	0	\N	\N
185912	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Déradicalisation	Mission d'information déradicalisation	2017-04-12 09:15:00	2017-04-12 13:00:00	\N	\N	2	0	\N	\N
185915	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Déradicalisation	Mission d'information déradicalisation	2017-04-12 15:00:00	2017-04-12 18:10:00	\N	\N	2	0	\N	\N
185932	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Parc immobilier du ministère de la défense 2017 - Déplacement	Contrôle Défense - Déplacement base aérienne d'Orléans	2017-04-11 10:00:00	2017-04-11 16:00:00	\N	\N	1	0	\N	\N
185972	COM_PERMANENTE	AUDRAP	\N	CAE	\N	APLOI - Ville et cohésion urbaine	\N	2017-04-12 16:30:00	2017-04-12 18:55:00	\N	\N	2	0	\N	\N
186152	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Ministère de l'Économie et des Finances - Déplacement	Ministère de l'Économie et des Finances - Déplacement	2017-04-04 08:00:00	2017-04-04 09:00:00	\N	\N	1	0	\N	\N
186154	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Parc immobilier du ministère de la défense 2017 - Déplacement	Contrôle Parc immobilier du ministère de la défense 2017 - Déplacement Le Mans	2017-04-19 09:30:00	2017-04-19 16:30:00	\N	\N	1	0	\N	\N
186156	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Dépenses de santé des détenus - Déplacement Lille	Contrôle Dépenses de santé des détenus - Déplacement Lille	2017-04-20 08:15:00	2017-04-20 19:20:00	\N	\N	1	0	\N	\N
179470	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2017-02-22 09:35:00	2017-02-22 11:30:00	2017-02-22 14:34:44	2017-02-22 15:46:02	38	1	\N	\N
181052	DELEGATION	AUCUNE	\N	\N	211	DDF - Examen et adoption du rapport d'information "Intersexes"	DDF - Examen et adoption du rapport d'information "Intersexes"	2017-02-23 09:00:00	2017-02-23 10:30:00	2017-02-23 13:02:31	2017-02-23 15:14:04	9	0	\N	\N
181092	COM_ENQUETE	PLENIERE	\N	ATTEINTES	\N	11ème séquence d'auditions sur la LGV/A65 (CEN, RNF de Vienne)	11ème séquence d'auditions sur la LGV/A65 (CEN, RNF de Vienne)	2017-02-23 14:05:00	2017-02-23 15:05:00	2017-02-24 10:19:33	2017-02-24 10:46:56	8	0	\N	\N
182192	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	Aù	\N	2017-02-22 11:45:00	2017-02-22 12:45:00	\N	\N	5	0	\N	\N
182372	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle APD 2017 Développement urbain	Contrôle APD 2017  Développement urbain - Audition Agence française de développement	2017-02-22 16:00:00	2017-02-22 18:15:00	\N	\N	2	0	\N	\N
182392	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFSS pour 2017 - Déplacement	PLFSS pour 2017 - Audition ACOSS - Déplacement	2017-02-21 15:30:00	2017-02-21 17:00:00	\N	\N	1	0	\N	\N
182394	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Recherche et enseignement supérieur - SATT	Contrôle Recherche et enseignement supérieur - SATT - Audition Cour des comptes	2017-02-21 10:30:00	2017-02-21 11:30:00	\N	\N	1	0	\N	\N
182396	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Recherche et enseignement supérieur - SATT	Contrôle Recherche et enseignement supérieur - SATT - Audition France Stratégie	2017-02-21 11:30:00	2017-02-21 12:30:00	\N	\N	1	0	\N	\N
182398	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Recherche et enseignement supérieur - SATT	Contrôle Recherche et enseignement supérieur - SATT - Audition Commissariat général à l'investissement	2017-02-23 10:00:00	2017-02-23 11:30:00	\N	\N	1	0	\N	\N
182400	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle CAS "Gestion du patrimoine immobilier de l'Etat"	Contrôle CAS "Gestion du patrimoine immobilier de l'Etat" - Audition SNCF immobilier	2017-02-23 10:00:00	2017-02-23 11:00:00	\N	\N	2	0	\N	\N
182403	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle CAS "Gestion du patrimoine immobilier de l'Etat"	Contrôle CAS "Gestion du patrimoine immobilier de l'Etat" - Audition du ministère de la justice - Secrétariat général	2017-02-23 16:00:00	2017-02-23 17:00:00	\N	\N	2	0	\N	\N
182412	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	\N	\N	2017-02-23 07:30:00	2017-02-23 13:30:00	\N	\N	3	0	\N	\N
182416	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	\N	\N	2017-02-22 14:30:00	2017-02-22 20:00:00	\N	\N	3	0	\N	\N
182472	DELEGATION	DEPLACEMENT	\N	\N	COLTER	RI_CT nouvelles technologies	\N	2017-02-22 09:00:00	2017-02-23 17:00:00	\N	\N	1	0	\N	\N
182514	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2017-02-28 14:30:00	2017-02-28 17:00:00	\N	\N	3	0	\N	\N
182552	MISSION	AUDRAP	\N	DEMOCRATIE	\N	\N	\N	2017-02-28 16:00:00	2017-02-28 19:30:00	\N	\N	2	0	\N	\N
182592	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Fabrice BALANCHE, spécialiste Syrie	Entretien avec M. Fabrice BALANCHE, Visiting Fellow au Washington Institute for Near East Policy, spécialiste de la Syri	2017-03-01 09:00:00	2017-03-01 11:00:00	\N	\N	5	0	644	\N
182612	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	11e session plénière de l'Assemblée parlementaire de la Méditerranée	11e session plénière de l'Assemblée parlementaire de la Méditerranée à Porto (Portugal)	2017-02-22 09:00:00	2017-02-24 18:00:00	\N	\N	2	0	\N	\N
182638	GIA	AUCUNE	\N	\N	\N	Entretien avec une délégation du Parlement Sami de Finlande	Entretien avec les membres d¿une délégation du Parlement Sami de Finlande conduite par sa Présidente, Mme Tilna SANILA-A	2017-03-01 12:30:00	2017-03-01 14:00:00	\N	\N	3	0	640	\N
182672	MISSION	AUCUNE	\N	DEMOCRATIE	\N	\N	\N	2017-03-01 16:10:00	2017-03-01 19:10:00	2017-03-02 11:03:30	2017-03-02 14:06:29	4	0	\N	\N
182692	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Fiscalité numérique - 2017 - Audition	Groupe de travail - Fiscalité numérique- 2017 - Audition IGAS	2017-02-28 15:00:00	2017-02-28 16:30:00	\N	\N	4	0	\N	\N
182697	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Fiscalité numérique - 2017 - Audition	Groupe de travail - Fiscalité numérique - 2017 - Audition ACOSS	2017-02-28 17:00:00	2017-02-28 18:30:00	\N	\N	2	0	\N	\N
182700	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	La compétitivité des places financières - Audition	La compétitivité des places financières - Audition France Fintech et Bankin	2017-03-01 11:00:00	2017-03-01 12:00:00	\N	\N	2	0	\N	\N
182892	COM_EURO	CONTROLE	\N	AFEU	\N	\N	Audition de M. Harlem Désir, secrétaire d'Etat aux affaires européennes	2017-03-07 17:05:00	2017-03-07 19:00:00	2017-03-08 10:40:01	2017-03-08 14:19:16	23	0	\N	\N
182946	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	PROS	Présentation à la presse du rapport d'information n°393	Présentation à la presse du rapport "Une crise en quête de fin - Quand l'histoire bégaie", P.-. Collombat rapporteur	2017-03-01 00:00:00	2017-03-02 10:00:00	\N	\N	4	0	\N	\N
183032	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Immigration, asile et intégration 2017	Contrôle Immigration, asile et intégration 2017 - Audition OFII	2017-03-08 15:00:00	2017-03-08 16:00:00	\N	\N	1	0	\N	\N
183096	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Mission de contrôle lois de réforme territoriale	\N	2017-03-15 09:05:00	2017-03-15 11:15:00	2017-03-15 11:56:49	2017-03-16 11:58:15	21	1	\N	\N
183232	GIA	AUCUNE	\N	\N	\N	Audience avec l'ambassadeur d'Ouzbékistan	Audience avec l'ambassadeur d'Ouzbékistan	2017-03-02 10:00:00	2017-03-02 11:00:00	\N	\N	1	0	556	\N
183234	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation turkmène	Accueil d'une délégation turkmène	2017-03-06 15:00:00	2017-03-06 16:00:00	\N	\N	1	0	556	\N
183375	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI redressement de la justice	MI redressement de la justice	2017-03-16 09:30:00	2017-03-16 12:30:00	\N	\N	1	0	\N	\N
183382	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI redressement de la justice	MI redressement de la justice	2017-03-16 14:30:00	2017-03-16 16:00:00	\N	\N	1	0	\N	\N
183384	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI redressement de la justice	MI redressement de la justice	2017-03-16 09:30:00	2017-03-16 12:30:00	\N	\N	1	0	\N	\N
183532	QUESTURE	AUCUNE	\N	\N	\N	Commission de concertation	Commission de concertation	2017-03-15 10:00:00	2017-03-15 12:50:00	\N	\N	2	0	\N	\N
183592	COM_ENQUETE	PLENIERE	\N	SCHENGEN	\N	CE SCHENGEN	\N	2017-03-15 14:00:00	2017-03-15 15:10:00	2017-03-16 09:13:39	2017-03-16 11:59:22	12	0	\N	\N
183652	COM_PERMANENTE	DEPLACEMENT	\N	SOCI	\N	MI Mineurs isolés	Mineurs étrangers isolés	2017-03-15 08:00:00	2017-03-15 18:00:00	\N	\N	2	0	\N	\N
183655	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	GT-normes sportives et collectivités locales	GT-normes sportives et collectivités locales	2017-03-16 10:30:00	2017-03-16 11:30:00	\N	\N	4	0	\N	\N
184192	DELEGATION	AUCUNE	\N	\N	COLTER	Rapport "Prévention de la radicalisation"	\N	2017-03-29 09:00:00	2017-03-29 10:10:00	2017-03-29 10:48:00	2017-03-29 15:45:18	6	0	\N	\N
184652	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Affaires européennes - L'assistance macrofinancière de l'UE aux pays tiers	Contrôle Affaires européennes - L'assistance macrofinancière de l'UE aux pays tiers - Audition DG Trésor	2017-03-21 09:00:00	2017-03-21 10:00:00	\N	\N	1	0	\N	\N
184654	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Affaires européennes - L'assistance macrofinancière de l'UE aux pays tiers	Contrôle Affaires européennes - L'assistance macrofinancière de l'UE aux pays tiers - Audition Ambassade d'Ukraine	2017-03-21 10:15:00	2017-03-21 11:00:00	\N	\N	1	0	\N	\N
184752	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Fiscalité numérique - 2017 - Auditions	Fiscalité numérique - 2017 - Auditions AHTOP, CNPA et Airbnb	2017-03-21 14:30:00	2017-03-21 17:00:00	\N	\N	6	0	\N	\N
184759	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Fiscalité numérique - 2017 - Audition	Fiscalité numérique - 2017 -  Audition CNCC	2017-03-21 17:00:00	2017-03-21 18:00:00	\N	\N	4	0	\N	\N
184764	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Fiscalité numérique - 2017 - Audition	Fiscalité numérique - 2017 - Audition Amazon France	2017-03-21 18:00:00	2017-03-21 19:00:00	\N	\N	2	0	\N	\N
184767	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Fiscalité numérique - 2017 - Auditions	Fiscalité numérique - 2017 - Auditions Blablacar et DGFiP controle fiscal	2017-03-23 09:30:00	2017-03-23 11:30:00	\N	\N	4	0	\N	\N
184772	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Fiscalité numérique - 2017 - Audition	Fiscalité numérique - 2017 - Audition Leboncoin	2017-03-23 11:30:00	2017-03-23 12:30:00	\N	\N	3	0	\N	\N
177732	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPRE Paquet énergie	PPRE Paquet énergie	2017-02-14 09:30:00	2017-02-14 11:00:00	\N	\N	1	0	\N	\N
177734	DELEGATION	DEPLACEMENT	\N	\N	206	Déplacement à Bruxelles dans le cadre du rapport sur l'intelligence artificielle	\N	2017-02-08 14:00:00	2017-02-09 19:00:00	\N	\N	1	0	\N	\N
179032	MISSION	PLEIN_NON_JO	\N	BREXIT	\N	   Synthèse des travaux du groupe de suivi sur la refondation de l¿Union européenne	   Synthèse des travaux du groupe de suivi sur la refondation de l¿Union européenne 	2017-02-22 08:30:00	2017-02-22 10:15:00	\N	\N	14	0	\N	\N
180873	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RI Transmission  et reprise d'entreprises - Déplacement à Nantes	RI Transmission  et reprise d'entreprises - Déplacement à Nantes	2017-02-20 08:00:00	2017-02-20 18:30:00	\N	\N	2	0	\N	\N
181813	COM_ENQUETE	PLENIERE	\N	ATTEINTES	\N	12ème séquence d'auditions sur la LGV/A65 (associations écolo. Vienne)	12ème séquence d'auditions sur la LGV/A65 (associations écolo. Vienne)	2017-02-23 16:05:00	2017-02-23 17:25:00	2017-02-24 10:21:27	2017-02-24 10:46:58	5	0	\N	\N
181852	GIA	AUCUNE	\N	\N	\N	Entretien avec la Présidente du groupe d'amitié Moldavie-France	Entretien avec Mme Valentina BULIGA, Présidente du groupe d¿amitié Moldavie-France, et une délégation de députés moldave	2017-02-23 12:30:00	2017-02-23 15:30:00	\N	\N	4	0	851	\N
182012	ETUDES	AUCUNE	\N	\N	\N	\N	\N	2017-02-22 08:15:00	2017-02-22 09:15:00	\N	\N	14	0	\N	907
182052	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Drones	\N	2017-02-22 15:30:00	2017-02-22 16:30:00	\N	\N	3	0	\N	\N
182072	ETUDES	AUCUNE	\N	\N	\N	GE Vigne et Vin	GE Vigne et Vin	2017-02-22 17:15:00	2017-02-22 18:15:00	\N	\N	10	0	\N	909
182132	ETUDES	AUCUNE	\N	\N	\N	GE Tourisme et Loisirs	GE Tourisme et Loisirs	2017-02-22 08:15:00	2017-02-22 09:15:00	\N	\N	7	0	\N	910
182152	COM_ENQUETE	DEPLACEMENT	\N	ATTEINTES	\N	Déplacement en Loire-Atlantique sur le site de l'aéroport du Grand Ouest 	Déplacement en Loire-Atlantique sur le site de l'aéroport du Grand Ouest	2017-02-17 06:55:00	2017-02-17 19:35:00	\N	\N	6	0	\N	\N
182175	COM_ENQUETE	DEPLACEMENT	\N	ATTEINTES	\N	Déplacement en Gironde pour la visite de 3 sites de compensation de la LGV/A65	Déplacement en Gironde pour la visite de 3 sites de compensation de la LGV/A65	2017-02-23 18:35:00	2017-02-24 18:35:00	\N	\N	3	0	\N	\N
182312	MISSION	AUCUNE	\N	PSYCHIATRIE	\N	\N	\N	2017-02-24 14:30:00	2017-02-24 17:00:00	2017-02-24 17:10:15	2017-02-24 17:19:58	4	0	\N	\N
182854	GIA	AUCUNE	\N	\N	\N	Déjeuner de travail avec M. l'Ambassadeur du Mexique en France	\N	2017-03-07 12:30:00	2017-03-07 14:30:00	\N	\N	2	0	643	\N
183034	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Fiscalité numérique - 2017 - Audition	Groupe de travail - Fiscalité numérique - 2017 - Audition Fédération des plateformes collaboratives (FPC)	2017-03-07 14:30:00	2017-03-07 15:30:00	\N	\N	5	0	\N	\N
183040	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Fiscalité numérique - 2017 - Audition	Fiscalité numérique - 2017 - Audition DRIVY - ZILOK - OUICAR	2017-03-07 15:30:00	2017-03-07 16:30:00	\N	\N	4	0	\N	\N
183045	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Fiscalité numérique - 2017 - Audition	Groupe de travail - Numérique - 2017 - Audition eBay	2017-03-07 16:30:00	2017-03-07 17:30:00	\N	\N	2	0	\N	\N
183072	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 - Soutien aux énergies renouvelables	58-2 - Soutien aux énergies renouvelables  - Audition de la Cour des comptes	2017-03-08 09:30:00	2017-03-08 10:30:00	\N	\N	1	0	\N	\N
184172	COM_EURO	DEPLACEMENT	\N	AFEU	\N	Russie - Relations entre l'Union européenne et la Russie	Russie - Du 19 au 24 mars 2017 - Relations entre l'Union européenne et la Russie	2017-03-19 12:00:00	2017-03-23 14:00:00	\N	\N	1	0	\N	\N
184359	COM_PERMANENTE	DEPLACEMENT	\N	SOCI	\N	UHSA 	unités hospitalières spécialement aménagées : déplacement à Toulouse	2017-03-22 08:00:00	2017-03-22 16:00:00	\N	\N	3	0	\N	\N
184453	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Mission de contrôle lois de réforme territoriale	\N	2017-03-29 14:00:00	2017-03-29 14:40:00	2017-03-30 11:38:13	2017-03-30 11:38:44	9	1	\N	\N
184776	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Fiscalité numérique - 2017 - Auditions	Fiscalité numérique - 2017 - Auditions G7; Unit et UMIH	2017-03-23 14:30:00	2017-03-23 16:00:00	\N	\N	1	0	\N	\N
185172	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Immigration, asile et intégration 2017 	Contrôle Immigration, asile et intégration 2017 - Audition ministère de l'intérieur	2017-03-27 15:00:00	2017-03-27 16:00:00	\N	\N	1	0	\N	\N
185232	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2017-04-04 14:30:00	2017-04-04 17:45:00	\N	\N	3	0	\N	\N
185236	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Accords de compétitivité au sein des entreprises	Accords de compétitivité au sein des entreprises	2017-04-05 11:30:00	2017-04-05 12:15:00	\N	\N	1	0	\N	\N
185238	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Accords de compétitivité au sein des entreprises	Accords de compétitivité au sein des entreprises	2017-04-05 16:00:00	2017-04-05 18:15:00	\N	\N	1	0	\N	\N
185252	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Parc immobilier du ministère de la défense - Déplacement	Contrôle Parc immobilier du ministère de la défense - Déplacement Lycée militaire d'Autun	2017-03-29 07:55:00	2017-03-29 18:10:00	\N	\N	1	0	\N	\N
185272	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 - Recours aux personnels contractuels dans l'éducation nationale	58-2 - Recours aux personnels contractuels dans l'éducation nationale - Réunion de cadrage	2017-03-30 15:00:00	2017-03-30 16:00:00	\N	\N	1	0	\N	\N
185274	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Parc immobilier du ministère de la défense - Déplacement	Contrôle Parc immobilier du ministère de la défense - Déplacement Etat-Major des Armées	2017-03-31 09:30:00	2017-03-31 10:30:00	\N	\N	1	0	\N	\N
185276	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Parc immobilier du ministère de la défense	Contrôle Parc immobilier du ministère de la défense - Direction des affaires financières du ministère de la défense	2017-03-31 14:30:00	2017-03-31 15:30:00	\N	\N	1	0	\N	\N
185278	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Parc immobilier du ministère de la défense	Contrôle Parc immobilier du ministère de la défense - Direction de l'immobilier de l'Etat	2017-03-31 15:30:00	2017-03-31 16:30:00	\N	\N	1	0	\N	\N
178594	COM_EURO	AUDRAP	\N	AFEU	\N	Avis politique - Règlementation prudentielle en matière bancaire	\N	2017-02-10 09:30:00	2017-02-10 10:30:00	\N	\N	1	0	\N	\N
178596	COM_EURO	AUDRAP	\N	AFEU	\N	Avis politique - Règlementation prudentielle en matière bancaire	\N	2017-02-21 15:00:00	2017-02-21 16:15:00	\N	\N	2	0	\N	\N
179432	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2017-02-22 10:10:00	2017-02-22 12:20:00	2017-02-22 16:36:05	2017-02-22 16:51:53	31	0	\N	\N
181072	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	groupe de travail Rythmes scolaires	groupe de travail Rythmes scolaires	2017-02-22 15:00:00	2017-02-22 18:00:00	\N	\N	1	0	\N	\N
187812	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	\N	\N	2017-05-24 09:30:00	2017-05-24 11:30:00	2017-05-24 16:59:12	2017-05-24 17:41:36	5	0	\N	\N
182252	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Groupe de travail - Numérique - 2017	Audition de HOPWORK - BLABLACAR - France Digitale	2017-02-22 14:00:00	2017-02-22 15:00:00	\N	\N	5	0	\N	\N
182258	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Groupe de travail - Numérique - 2017	Audition Blog "Droit du Partage"	2017-02-22 15:00:00	2017-02-22 16:00:00	\N	\N	8	0	\N	\N
182274	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Groupe de travail - Numérique - 2017	Audition HEETCH	2017-02-22 16:00:00	2017-02-22 17:00:00	\N	\N	7	0	\N	\N
182282	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Groupe de travail - Numérique - 2017	Audition STOOTIE	2017-02-22 17:00:00	2017-02-22 18:00:00	\N	\N	6	0	\N	\N
182518	COM_ENQUETE	DEPLACEMENT	\N	SCHENGEN	\N	CE SCHENGEN	CE SCHENGEN - Bulgarie	2017-02-26 10:00:00	2017-03-01 14:00:00	\N	\N	4	0	\N	\N
182576	COM_ENQUETE	PLENIERE	\N	ATTEINTES	\N	Echanges de vues sur les orientations du rapport	Echanges de vues sur les orientations du rapport	2017-03-01 13:30:00	2017-03-01 14:30:00	2017-03-02 09:58:27	2017-03-02 10:11:15	3	0	\N	\N
182580	COM_ENQUETE	PLENIERE	\N	ATTEINTES	\N	18ème séquence d'auditions généralistes  (AFB, CGEDD, CNDP) 	18ème séquence d'auditions généralistes  (AFB, CGEDD, CNDP)	2017-03-01 14:40:00	2017-03-01 18:00:00	2017-03-02 09:59:19	2017-03-02 10:11:14	4	0	\N	\N
182652	GIA	AUCUNE	\N	\N	\N	Réunion de travail en vue du déplacement à l¿Île Maurice et en Tanzanie	\N	2017-03-01 11:00:00	2017-03-01 12:00:00	\N	\N	2	0	622	\N
182792	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI redressement de la justice	MI redressement de la justice	2017-03-01 09:30:00	2017-03-01 11:30:00	\N	\N	2	0	\N	\N
182794	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI redressement de la justice	MI redressement de la justice	2017-03-01 15:00:00	2017-03-01 20:30:00	\N	\N	1	0	\N	\N
182872	GIA	AUCUNE	\N	\N	\N	Rencontre Michel Boivin, directeur d'études EHESS	\N	2017-03-08 14:00:00	2017-03-08 15:00:00	\N	\N	1	0	619	\N
182992	MISSION	AUCUNE	\N	DEMOCRATIE	\N	\N	\N	2017-03-08 14:15:00	2017-03-08 17:00:00	2017-03-08 17:40:23	2017-03-09 09:20:57	5	0	\N	\N
183252	GIA	AUCUNE	\N	\N	\N	Déplacement au Cambodge Francophonie économique et numérique	Déplacement au Cambodge Francophonie économique et numérique	2017-03-14 08:30:00	2017-03-23 20:00:00	\N	\N	3	0	577	\N
183340	MISSION	DEPLACEMENT	\N	PSYCHIATRIE	\N	\N	\N	2017-02-28 08:00:00	2017-03-01 19:00:00	\N	\N	5	0	\N	\N
183352	MISSION	DEPLACEMENT	\N	PSYCHIATRIE	\N	\N	\N	2017-03-07 08:00:00	2017-03-07 19:00:00	\N	\N	2	0	\N	\N
183692	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail 2 % du PIB	\N	2017-03-14 15:00:00	2017-03-14 16:30:00	\N	\N	2	0	\N	\N
183732	COM_PERMANENTE	AUTRE	\N	LOIS	\N	\N	\N	2017-03-21 09:05:00	2017-03-21 10:10:00	2017-03-21 10:45:35	2017-03-22 10:40:44	11	0	\N	\N
183932	COM_EURO	AUDRAP	\N	AFEU	\N	La situation en Turquie	La situation en Turquie	2017-03-16 16:30:00	2017-03-16 18:00:00	\N	\N	2	0	\N	\N
183952	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	MI redressement de la justice	MI redressement de la justice	2017-03-09 07:20:00	2017-03-09 19:20:00	\N	\N	1	0	\N	\N
183954	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI redressement de la justice	MI redressement de la justice	2017-03-10 09:45:00	2017-03-10 12:15:00	\N	\N	1	0	\N	\N
183972	COM_EURO	DEPLACEMENT	\N	AFEU	\N	Russie - Relations entre l'Union européenne et la Russie	Russie - Du 19 au 24 mars 2017 - Relations entre l'Union européenne et la Russie	2017-03-19 12:00:00	2017-03-24 18:00:00	\N	\N	1	0	\N	\N
184612	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Groupe de travail Nucléaire	Aquitaine - Visite sites du CEA et de Airbus Safran Launchers	2017-03-24 08:00:00	2017-03-24 18:00:00	\N	\N	4	0	\N	\N
184632	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Groupe de travail drones	Déplacement aux USA	2017-03-20 08:00:00	2017-03-25 00:00:00	\N	\N	3	0	\N	\N
184672	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle Aide Publique au Développement 2017 - Déplacement en Colombie	Contrôle Aide Publique au Développement 2017 - Déplacement en Colombie	2017-03-26 11:35:00	2017-04-01 16:00:00	\N	\N	2	0	\N	\N
184712	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle Recherche et enseignement supérieur - SATT - Déplacement à Dijon	Contrôle Recherche et enseignement supérieur - SATT - Déplacement à Dijon	2017-03-24 06:50:00	2017-03-24 20:00:00	\N	\N	1	0	\N	\N
184820	COM_PERMANENTE	AUTRE	\N	FINC	\N	Conclusions du groupe de travail économie numérique	conclusions du groupe de travail sur le recouvrement de l¿impôt à l¿heure de l¿économie numérique	2017-03-29 09:10:00	2017-03-29 10:40:00	2017-03-29 11:59:52	2017-03-29 15:44:50	17	0	\N	\N
184832	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Compétitivité des places financières - Déplacement Amsterdam	Compétitivité des places financières - Déplacement Amsterdam	2017-03-30 07:30:00	2017-03-30 21:00:00	\N	\N	2	0	\N	\N
184852	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Dépenses de santé des détenus - Déplacement Laon	Contrôle Dépenses de santé des détenus - Déplacement Laon	2017-04-06 09:30:00	2017-04-06 17:30:00	\N	\N	1	0	\N	\N
184854	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Ecologie - contentieux environnementaux - Déplacement Lille	Contrôle Ecologie - contentieux environnementaux - Déplacement Lille	2017-04-13 09:30:00	2017-04-13 17:00:00	\N	\N	1	0	\N	\N
185032	MISSION	AUCUNE	\N	DEMOCRATIE	\N	\N	\N	2017-03-28 14:30:00	2017-03-28 17:05:00	2017-03-29 16:05:20	2017-03-29 16:58:24	8	0	\N	\N
185053	MISSION	AUCUNE	\N	DEMOCRATIE	\N	\N	\N	2017-03-29 11:00:00	2017-03-29 12:00:00	2017-03-29 16:08:55	2017-03-29 16:58:25	2	0	\N	\N
185112	MISSION	AUDRAP	\N	DEMOCRATIE	\N	\N	\N	2017-03-29 10:00:00	2017-03-29 11:00:00	\N	\N	2	0	\N	\N
185115	MISSION	AUDRAP	\N	DEMOCRATIE	\N	\N	\N	2017-03-29 14:30:00	2017-03-29 16:30:00	\N	\N	1	0	\N	\N
185280	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Parc immobilier du ministère de la défense	Contrôle Parc immobilier du ministère de la défense - Service d'infrastructure de la défense (SID)	2017-03-31 16:30:00	2017-03-31 17:30:00	\N	\N	1	0	\N	\N
185432	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de M. Gérard Romiti, président du CNPMEM	Audition de M. Gérard Romiti, président du CNPMEM	2017-04-04 14:35:00	2017-04-04 15:55:00	2018-05-18 15:57:05	2018-05-18 15:57:08	25	0	\N	\N
185492	DELEGATION	AUCUNE	\N	\N	211	DDF - TABLE RONDE SUR LES QUESTIONS SOCIALES CONCERNANT LES FEMMES AGRICULTRICES	DDF - TABLE RONDE SUR LES QUESTIONS SOCIALES CONCERNANT LES FEMMES AGRICULTRICES	2017-04-04 14:00:00	2017-04-04 16:00:00	2017-04-04 17:14:46	2017-04-04 17:25:21	5	0	\N	\N
185512	COM_EURO	CONTROLE	\N	AFEU	\N	\N	\N	2017-04-04 14:35:00	2017-04-04 15:55:00	2017-04-04 17:46:53	2017-04-05 09:07:26	25	0	\N	\N
185572	GIA	AUCUNE	\N	\N	\N	Entretien Mission archéologique française  bassin de l'Indus	\N	2017-04-04 14:30:00	2017-04-04 15:45:00	\N	\N	3	0	619	\N
185576	GIA	AUCUNE	\N	\N	\N	Entretien Saint-Mezard Relations Inde Pakistan	\N	2017-04-04 15:45:00	2017-04-04 17:15:00	\N	\N	2	0	619	\N
177654	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	MI redressement de la justice	MI redressement de la justice	2017-02-16 07:20:00	2017-02-16 21:50:00	\N	\N	1	0	\N	\N
177656	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI redressement de la justice	MI redressement de la justice	2017-02-15 14:30:00	2017-02-15 18:00:00	\N	\N	1	0	\N	\N
177672	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Nucléaire	\N	2017-02-14 15:00:00	2017-02-14 16:00:00	\N	\N	3	0	\N	\N
177676	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Nucléaire	\N	2017-02-14 17:30:00	2017-02-14 19:00:00	\N	\N	3	0	\N	\N
177680	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Valduc (CEA-DAM)	\N	2017-02-15 11:30:00	2017-02-15 19:45:00	\N	\N	3	0	\N	\N
177684	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Site Airbus Safran Launchers aux Mureaux	\N	2017-02-16 08:30:00	2017-02-16 15:30:00	\N	\N	6	0	\N	\N
177692	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	Aménagement du territoire	\N	2017-02-15 15:00:00	2017-02-15 16:45:00	\N	\N	4	0	\N	\N
178427	GIA	AUCUNE	\N	\N	\N	Dîner à l'ambassade de Finlande	Dîner à l'ambassade de Finlande en l'honneur d'une délégation de députés finlandais	2017-02-20 19:30:00	2017-02-20 22:00:00	\N	\N	2	0	640	\N
178430	GIA	AUCUNE	\N	\N	\N	Déjeuner à l'Assemblée nationale en l'honneur d'une délégation de députés finlandais	Déjeuner à l'Assemblée nationale en l'honneur d'une délégation de députés finlandais	2017-02-21 12:30:00	2017-02-21 14:30:00	\N	\N	1	0	640	\N
178573	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ambassadeur d'Irak	Entretien avec S.E. le Dr Ismieal Shafiq MUHSIN, Ambassadeur  d'Irak en France	2017-02-15 12:30:00	2017-02-15 14:00:00	\N	\N	4	0	615	\N
178732	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ambassadeur de France au Caire	Entretien avec S.E. M. André PARANT, Ambassadeur de France au Caire	2017-02-21 15:45:00	2017-02-21 17:00:00	\N	\N	11	0	617	\N
178752	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ambassadeur de France en République centrafricaine	Entretien avec S.E. M. Christian BADER, Ambassadeur de France en République Centrafricaine (RCA)	2017-02-21 14:30:00	2017-02-21 15:30:00	\N	\N	2	0	572	\N
179092	COM_PERMANENTE	AUTRE	\N	CDD	\N	Table ronde sur les pollinisateurs	Table ronde sur les pollinisateurs	2017-02-22 09:30:00	2017-02-22 11:35:00	2018-05-18 15:55:19	2018-05-18 15:55:26	23	0	\N	\N
179132	COM_PERMANENTE	AUTRE	\N	CAE	\N	Présentation par M. Thierry Repentin du 3éme rapport de la CNAUF	Présentation par M. Thierry Repentin du 3éme rapport de la CNAUF	2017-02-22 09:30:00	2017-02-22 10:40:00	2018-05-18 15:54:04	2018-05-18 15:55:04	34	0	\N	\N
179638	COM_PERMANENTE	AUTRE	\N	CDD	\N	Droit à l'eau potable et à l'assainissement	Droit à l'eau potable et à l'assainissement	2017-02-22 14:15:00	2017-02-22 14:40:00	2018-05-18 15:56:05	2018-05-18 15:56:11	17	0	\N	\N
180412	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	ENTREPRISES	Journée des entreprises	Journée des entreprises	2017-03-16 10:00:00	2017-03-16 12:30:00	\N	\N	27	0	\N	\N
180892	DELEGATION	AUCUNE	\N	\N	PROS	Audition de Jean-Pierre Henry, directeur de recherche au CNRS, sur le thème "Progrès dans 	Audition sur le thème "Progrès dans la connaissance des mécanismes du cerveau. Vers l'homme augmenté ?"	2017-02-23 08:35:00	2017-02-23 10:10:00	2017-02-24 10:18:57	2017-02-24 10:46:13	9	0	\N	\N
181129	GIA	AUCUNE	\N	\N	\N	Entretien avec le Directeur adjoint Afrique du Nord-Moyen Orient	Entretien avec M. Ludovic POUILLE, Directeur-adjoint Afrique du Nord-Moyen Orient au ministère des Affaires étrangères, 	2017-02-23 10:00:00	2017-02-23 12:30:00	\N	\N	7	0	644	\N
183152	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail 2 % du PIB	\N	2017-03-09 16:05:00	2017-03-09 17:50:00	\N	\N	2	0	\N	\N
183155	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail 2 % du PIB	\N	2017-03-07 15:00:00	2017-03-07 16:30:00	\N	\N	2	0	\N	\N
183158	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Situation des urgences hospitalières	\N	2017-03-08 15:30:00	2017-03-08 17:00:00	\N	\N	3	0	\N	\N
183172	COM_PERMANENTE	DEPLACEMENT	\N	SOCI	\N	 Mineurs étrangers isolés	prise en charge sociale des mineurs étrangers isolés	2017-03-08 08:00:00	2017-03-08 18:00:00	\N	\N	2	0	\N	\N
183612	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ambassadeur du Botswana à Bruxelles	Entretien avec l'ambassadeur du Botswana à Bruxelles	2017-03-16 08:30:00	2017-03-16 09:30:00	\N	\N	2	0	646	\N
183632	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Groupe de travail Drones 	Déplacement à Cognac	2017-03-15 07:00:00	2017-03-15 19:00:00	\N	\N	2	0	\N	\N
183660	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Fiscalité numérique - 2017 - Audition 	Fiscalité numérique - 2017 - Audition A little market	2017-03-14 14:00:00	2017-03-14 15:00:00	\N	\N	3	0	\N	\N
183664	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Fiscalité numérique - 2017 - Audition	Fiscalité numérique - 2017 - Audition Direction de la sécurité sociale	2017-03-14 15:00:00	2017-03-14 16:30:00	\N	\N	3	0	\N	\N
183668	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Fiscalité numérique - 2017 - Audition	Fiscalité numérique - 2017 - Audition DGFiP DLF	2017-03-14 17:00:00	2017-03-14 17:30:00	\N	\N	4	0	\N	\N
183673	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Fiscalité numérique - 2017 - Audition	Fiscalité numérique - 2017 - Audition DGFiP Gestion fiscale	2017-03-14 17:30:00	2017-03-14 18:00:00	\N	\N	4	0	\N	\N
183712	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 Agence de services et de paiement (ASP)	58-2 Agence de services et de paiement (ASP) - Audition Cour des Comptes	2017-03-14 14:00:00	2017-03-14 15:15:00	\N	\N	2	0	\N	\N
184472	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT suivi de la PAC	GT suivi de la PAC	2017-03-21 14:30:00	2017-03-21 17:15:00	\N	\N	5	0	\N	\N
185192	MISSION	DEPLACEMENT	\N	DEMOCRATIE	\N	\N	\N	2017-03-30 08:00:00	2017-03-30 20:00:00	\N	\N	4	0	\N	\N
185197	MISSION	DEPLACEMENT	\N	DEMOCRATIE	\N	\N	\N	2017-03-31 08:00:00	2017-03-31 20:00:00	\N	\N	4	0	\N	\N
185202	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Dépenses Santé des détenus	Contrôle Dépenses Santé des détenus - Audition OIP	2017-03-29 14:30:00	2017-03-29 15:30:00	\N	\N	1	0	\N	\N
185204	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Dépenses Santé des détenus	Contrôle Dépenses Santé des détenus - Audition Direction de l'administration pénitentiaire	2017-03-29 16:00:00	2017-03-29 17:30:00	\N	\N	1	0	\N	\N
185212	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Dépenses Santé des détenus	Contrôle Dépenses Santé des détenus - Audition ARSIF	2017-03-30 14:30:00	2017-03-30 15:30:00	\N	\N	1	0	\N	\N
179172	COM_PERMANENTE	AUTRE	\N	CAE	\N	Examen PPRE n°429 énergie renouvelables	Examen PPRE n°429 énergies renouvelables et les mécanismes de capacité	2017-02-22 10:40:00	2017-02-22 11:55:00	2018-05-18 15:55:44	2018-05-18 15:55:51	34	1	\N	\N
185214	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Dépenses de santé des détenus - Déplacement Villejuif	Contrôle Dépenses de santé des détenus - Groupe hospitalier Paul Guiraud - Déplacement Villejuif	2017-03-30 16:15:00	2017-03-30 18:15:00	\N	\N	0	0	\N	\N
185592	COM_ENQUETE	PLENIERE	\N	ATTEINTES	\N	Examen du rapport final	Examen du rapport final	2017-04-05 14:35:00	2017-04-05 16:45:00	2017-04-06 12:39:30	2017-04-06 14:08:10	12	0	\N	\N
185672	GIA	AUCUNE	\N	\N	\N	Rencontre Maire 10ème Paris	Rencontre Maire 10ème Paris	2017-04-05 11:00:00	2017-04-05 12:00:00	\N	\N	1	0	634	\N
185712	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Mineurs isolés	\N	2017-04-18 14:30:00	2017-04-18 16:30:00	\N	\N	2	0	\N	\N
185715	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Situation des urgences hospitalières	\N	2017-04-20 10:00:00	2017-04-20 11:00:00	\N	\N	3	0	\N	\N
185719	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Situation des urgences hospitalières	\N	2017-04-20 14:30:00	2017-04-20 15:30:00	\N	\N	3	0	\N	\N
185772	GIA	AUCUNE	\N	\N	\N	Visite de Tshekedi Khama ministre environnement et tourisme du Botswana	Visite de Tshekedi Khama ministre environnement et tourisme du Botswana	2017-04-10 11:30:00	2017-04-10 12:30:00	\N	\N	1	0	646	\N
185792	GIA	AUCUNE	\N	\N	\N	Dîner avec l'ambassadeur d'Albanie 	Dîner avec l'ambassadeur d'Albanie 	2017-04-04 19:30:00	2017-04-04 21:30:00	\N	\N	3	0	571	\N
185796	COM_SPECIALE	PLENIERE	\N	COMSPEAPU	\N	\N	\N	2017-04-11 11:00:00	2017-04-11 12:45:00	2017-04-11 17:49:17	2017-04-12 10:21:01	4	0	\N	\N
185852	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2017-04-11 14:30:00	2017-04-11 16:15:00	\N	\N	3	0	\N	\N
185992	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Parc immobilier du ministère de la défense 2017 - Déplacement	Contrôle Parc immobilier du ministère de la défense 2017 - Déplacement fort de l'est Saint-Denis (93)	2017-04-13 13:00:00	2017-04-13 17:00:00	\N	\N	1	0	\N	\N
177772	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ambassadeur du Kazakhstan	\N	2017-02-16 16:30:00	2017-02-16 17:30:00	\N	\N	1	0	556	\N
182292	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Recherche et enseignement supérieur 2017	Contrôle Recherche et enseignement supérieur 2017 - Audition Agence nationale de la recherche	2017-02-22 15:30:00	2017-02-22 16:30:00	\N	\N	1	0	\N	\N
182294	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Recherche et enseignement supérieur 2017	Contrôle Recherche et enseignement supérieur 2017 - Audition Secrétariat d'État chargé de l'enseignement supérieur et de	2017-02-22 16:30:00	2017-02-22 17:30:00	\N	\N	1	0	\N	\N
182296	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Modernisation du contrôle de la navigation aérienne 2017	Contrôle Modernisation du contrôle de la navigation aérienne 2017 - Audition DGAC et DNSA	2017-02-23 09:30:00	2017-02-23 11:30:00	\N	\N	1	0	\N	\N
182332	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 Matériels et équipement de la police et de la gendarmerie	58-2 Matériels et équipement de la police et de la gendarmerie - cadrage avec la Cour des comptes	2017-02-22 15:00:00	2017-02-22 16:30:00	\N	\N	1	0	\N	\N
182352	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	La compétitivité des places financières - Audition	La compétitivité des places financières - Audition de M. Christian NOYER	2017-02-21 10:00:00	2017-02-21 11:00:00	\N	\N	2	0	\N	\N
182632	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI redressement de la justice	MI redressement de la justice	2017-02-21 14:30:00	2017-02-21 17:30:00	\N	\N	2	0	\N	\N
182635	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	MI redressement de la justice	MI redressement de la justice	2017-02-28 06:45:00	2017-02-28 21:45:00	\N	\N	2	0	\N	\N
182712	GIA	AUCUNE	\N	\N	\N	Entretien avec Président du Sénat pakistanais M. Rabbani	Entretien avec Président du Sénat pakistanais M. Rabbani	2017-03-01 17:30:00	2017-03-01 18:30:00	\N	\N	2	0	619	\N
182823	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	La compétitivité des places financières - Audition	La compétitivité des places financières - Audition AMF/ACPR	2017-03-01 10:00:00	2017-03-01 11:00:00	\N	\N	1	0	\N	\N
183004	GIA	AUCUNE	\N	\N	\N	Entretien Ambassadeur du Laos	Entretien Ambassadeur du Laos	2017-03-07 08:30:00	2017-03-07 09:30:00	\N	\N	2	0	577	\N
183372	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Alberto TOSCANO	Entretien avec M. Alberto TOSCANO, Docteur en sciences politiques, journaliste et écrivain italien	2017-03-14 12:30:00	2017-03-14 14:00:00	\N	\N	7	0	621	\N
183812	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Séminaire Défense	\N	2017-03-15 14:00:00	2017-03-15 18:30:00	\N	\N	2	0	\N	\N
183815	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Nucléaire	\N	2017-03-16 14:45:00	2017-03-16 16:00:00	\N	\N	1	0	\N	\N
183860	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	ENTREPRISES	Journée des entrepirses	Journée des entreprises	2017-03-16 14:45:00	2017-03-16 17:25:00	\N	\N	17	0	\N	\N
184313	COM_EURO	CONTROLE	\N	AFEU	\N	\N	\N	2017-03-22 15:00:00	2017-03-22 16:50:00	2017-03-22 17:13:12	2017-03-23 17:13:09	7	0	\N	\N
184352	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI redressement de la justice	MI redressement de la justice	2017-03-22 11:00:00	2017-03-22 12:30:00	\N	\N	2	0	\N	\N
184355	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI redressement de la justice	MI redressement de la justice	2017-03-21 10:00:00	2017-03-21 11:15:00	\N	\N	1	0	\N	\N
184357	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI redressement de la justice	MI redressement de la justice	2017-03-21 16:30:00	2017-03-21 17:15:00	\N	\N	1	0	\N	\N
184392	MECSS	AUDRAP	\N	\N	MECSS	Pertinence des actes	Pertinence des actes	2017-03-28 09:30:00	2017-03-28 11:30:00	\N	\N	1	0	\N	\N
184394	MECSS	AUDRAP	\N	\N	MECSS	Pertinence des actes	Pertinence des actes	2017-03-29 09:00:00	2017-03-29 11:30:00	\N	\N	1	0	\N	\N
184396	MECSS	AUDRAP	\N	\N	MECSS	Pertinence des actes	Pertinence des actes	2017-04-04 09:30:00	2017-04-04 10:30:00	\N	\N	1	0	\N	\N
184532	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Engagements financiers de l'Etat	Contrôle Engagements financiers de l'Etat - Audition Standard & Poor's	2017-03-21 15:40:00	2017-03-21 16:50:00	\N	\N	1	0	\N	\N
184552	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2017 - CAS Gestion du patrimoine de l'Etat - Déplacement à Londres	Contrôle 2017 - CAS Gestion du patrimoine de l'Etat - Déplacement à Londres	2017-03-20 07:45:00	2017-03-20 21:30:00	\N	\N	2	0	\N	\N
184556	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Direction de l'action du Gouvernement 2017 - Déplacement	Contrôle Direction de l'action du Gouvernement 2017 - Audition du Groupement interministériel de contrôle (GIC) 	2017-03-21 14:00:00	2017-03-21 17:00:00	\N	\N	1	0	\N	\N
184558	GIA	AUCUNE	\N	\N	\N	Réunion de travail en vue du déplacement d'une délégation du groupe	\N	2017-03-21 12:45:00	2017-03-21 14:00:00	\N	\N	2	0	532	\N
184561	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Groupe de travail nucléaire	Déplacement à Istres	2017-03-21 08:00:00	2017-03-22 12:00:00	\N	\N	4	0	\N	\N
184872	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2017-03-28 15:30:00	2017-03-28 17:10:00	\N	\N	3	0	\N	\N
185312	MISSION	AUCUNE	\N	PSYCHIATRIE	\N	MI psychiatrie des mineurs	MI psychiatrie des mineurs	2017-04-04 09:00:00	2017-04-04 11:00:00	2017-04-04 11:28:55	2017-04-04 16:15:53	16	0	\N	\N
185352	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 4 avril 2017	Réunion du 4 avril 2017	2017-04-04 09:35:00	2017-04-04 11:05:00	2017-04-04 11:55:36	2017-04-04 16:15:27	14	0	\N	\N
185632	COM_PERMANENTE	DEPLACEMENT	\N	SOCI	\N	Situation urgences hospitalières	Situation urgences hospitalières : Déplacement au cHU de Reims et au Groupement hospitalier Aube Marne	2017-04-06 08:00:00	2017-04-06 19:00:00	\N	\N	3	0	\N	\N
185812	COM_EURO	DEPLACEMENT	\N	AFEU	\N	OMC - Genève	Entretiens avec des représentants de l'OMC sur le thème "L'avenir des négociations commerciales multilatérales"	2017-04-11 20:00:00	2017-04-12 22:00:00	\N	\N	1	0	\N	\N
185952	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle CVAE	Contrôle CVAE - Audition Ministère (Bercy + cabinet)	2017-04-12 10:30:00	2017-04-12 12:05:00	\N	\N	2	0	\N	\N
186032	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Modernisation du contrôle de la navigation aérienne 2017 - Déplacement	Contrôle Modernisation du contrôle de la navigation aérienne 2017 - Déplacement CRNA Nord à Athis-Mons	2017-04-05 14:30:00	2017-04-05 17:30:00	\N	\N	1	0	\N	\N
186618	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Politique des territoires 2017 - Déplacement	Contrôle Politique des territoires 2017 - Déplacement Marais Poitevin	2017-04-25 15:00:00	2017-04-27 15:00:00	\N	\N	1	0	\N	\N
186620	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Compétitivité des places financières - Déplacement Dublin	Compétitivité des places financières - Déplacement Dublin	2017-04-25 15:10:00	2017-04-26 19:40:00	\N	\N	2	0	\N	\N
187112	GIA	AUCUNE	\N	\N	\N	Rencontre avec une délégation du CCPCC du YUNAN	Rencontre avec une délégation du CCPCC du YUNAN	2017-05-04 10:30:00	2017-05-04 12:00:00	\N	\N	3	0	584	\N
187172	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Déradicalisation	\N	2017-05-03 15:00:00	2017-05-03 18:15:00	\N	\N	2	0	\N	\N
187175	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Déradicalisation	\N	2017-05-04 10:00:00	2017-05-04 11:45:00	\N	\N	2	0	\N	\N
187178	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 9 mai 2017	\N	2017-05-09 09:40:00	2017-05-09 11:00:00	2017-05-09 12:01:56	2017-05-09 15:26:02	17	0	\N	\N
187412	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Sihasak PHUANGKETKEOW, Ambassadeur de Thaïlande à Paris	Entretien avec M. Sihasak PHUANGKETKEOW, Ambassadeur de Thaïlande à Paris	2017-05-09 13:00:00	2017-05-09 14:30:00	\N	\N	2	0	609	\N
187452	MISSION	AUCUNE	\N	DEMOCRATIE	\N	\N	\N	2017-05-17 10:05:00	2017-05-17 12:00:00	2017-05-17 15:22:45	2017-05-17 15:43:36	11	0	\N	\N
187492	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Recherche et enseignement supérieur - SATT	Contrôle Recherche et enseignement supérieur - SATT - Audition ANR	2017-05-18 10:00:00	2017-05-18 11:00:00	\N	\N	1	0	\N	\N
187494	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Recherche et enseignement supérieur - SATT	Contrôle Recherche et enseignement supérieur - SATT - Audition Réseau C.U.R.I.E.	2017-05-18 11:00:00	2017-05-18 12:00:00	\N	\N	1	0	\N	\N
187496	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Recherche et enseignement supérieur - SATT	Contrôle Recherche et enseignement supérieur - SATT - Audition INSERM	2017-05-18 15:00:00	2017-05-18 16:00:00	\N	\N	1	0	\N	\N
187514	ETUDES	AUCUNE	\N	\N	\N	\N	Groupe d'études Arts de la scène	2017-05-17 09:00:00	2017-05-17 12:00:00	\N	\N	3	0	\N	966
187536	ETUDES	AUCUNE	\N	\N	\N	\N	Groupe d'études Arts de la scène	2017-05-17 15:30:00	2017-05-17 16:30:00	\N	\N	2	0	\N	966
187539	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Avenir des médias d'information	Avenir des médias	2017-05-16 14:30:00	2017-05-16 17:30:00	\N	\N	7	0	\N	\N
187547	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Formation au numérique	Formation au numérique	2017-05-16 09:30:00	2017-05-16 12:45:00	\N	\N	1	0	\N	\N
187572	GIA	AUCUNE	\N	\N	\N	Rencontre	Rencontre entre Alain Richard et l'ambassadeur Zhang Min-zhong	2017-05-03 11:00:00	2017-05-03 12:00:00	\N	\N	1	0	623	\N
187835	GIA	AUCUNE	\N	\N	\N	Philippines	Entretien avec Mme Ma Theresa Lazzaro, Ambassadeur des Philippines	2017-05-23 09:30:00	2017-05-23 10:30:00	\N	\N	1	0	609	\N
187839	GIA	AUCUNE	\N	\N	\N	Fête nationale	Réception à l'UNESCO organisée par l'Ambassade de Jordanie à Paris	2017-05-23 18:00:00	2017-05-23 19:00:00	\N	\N	1	0	659	\N
187841	GIA	AUCUNE	\N	\N	\N	Mission en Jordanie	Déplacement d'une délégation du groupe d'amitié	2017-05-13 14:00:00	2017-05-18 17:00:00	\N	\N	4	0	659	\N
187846	GIA	AUCUNE	\N	\N	\N	Mission au Québec	Mission au Québec	2017-04-03 11:00:00	2017-04-09 08:00:00	\N	\N	4	0	602	\N
188292	DELEGATION	AUDRAP	\N	\N	COLTER	Table ronde - Agence de l'eau	\N	2017-06-20 16:00:00	2017-06-20 17:30:00	\N	\N	2	0	\N	\N
188312	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT Compétitivité des places financières - Audition	GT Compétitivité des places financières - Audition BNP Paribas	2017-05-30 18:00:00	2017-05-30 19:00:00	\N	\N	2	0	\N	\N
188315	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT Compétitivité des places financières - Audition	GT Compétitivité des places financières - Audition London Stock Exchange	2017-05-30 14:30:00	2017-05-30 16:00:00	\N	\N	1	0	\N	\N
188392	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 6 juin 2017	\N	2017-06-06 09:30:00	2017-06-06 11:15:00	2017-06-06 12:09:48	2017-06-07 14:22:50	10	0	\N	\N
187818	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	\N	\N	2017-05-09 14:30:00	2017-05-09 18:00:00	2017-05-24 16:56:43	\N	8	0	\N	\N
188432	COM_PERMANENTE	AUTRE	\N	CAE	\N	Communication sur le bilan annuel d'application des lois	Communication sur le bilan annuel d'application des lois	2017-06-06 15:00:00	2017-06-06 16:00:00	2018-05-18 15:59:28	2018-05-18 15:59:32	15	0	\N	\N
188473	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2017-05-31 13:20:00	2017-05-31 13:35:00	\N	\N	3	0	\N	\N
188513	GIA	AUCUNE	\N	\N	\N	déjeuner parlementaires russes	déjeuner présidé par M. Pozzo di Borgo en l'honneur d'une délégation russe conduite par M. Anatoly Karpov	2017-06-01 12:30:00	2017-06-01 15:30:00	\N	\N	3	0	608	\N
188732	COM_PERMANENTE	DEPLACEMENT	\N	CAE	\N	APLOI VILLE	\N	2017-05-16 08:00:00	2017-05-16 18:00:00	\N	\N	2	0	\N	\N
188752	COM_PERMANENTE	DEPLACEMENT	\N	CAE	\N	APLOI VILLE	\N	2017-05-30 09:00:00	2017-05-31 12:00:00	\N	\N	1	0	\N	\N
188754	COM_PERMANENTE	AUDRAP	\N	CAE	\N	APLOI VILLE	\N	2017-05-31 14:30:00	2017-05-31 18:00:00	\N	\N	2	0	\N	\N
188757	COM_PERMANENTE	DEPLACEMENT	\N	CAE	\N	APLOI VILLE	\N	2017-06-07 14:00:00	2017-06-07 18:00:00	\N	\N	2	0	\N	\N
188760	COM_PERMANENTE	AUDRAP	\N	CAE	\N	APLOI VILLE	\N	2017-06-07 10:00:00	2017-06-07 12:00:00	\N	\N	2	0	\N	\N
188772	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Normalisation volontaire	\N	2017-06-06 14:00:00	2017-06-06 15:00:00	\N	\N	1	0	\N	\N
188774	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Normalisation volontaire	\N	2017-06-06 16:15:00	2017-06-06 17:30:00	\N	\N	1	0	\N	\N
188776	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Ouverture à la concurrence domaine ferroviaire	\N	2017-06-07 09:30:00	2017-06-07 11:30:00	\N	\N	2	0	\N	\N
188779	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Ouverture à la concurrence domaine ferroviaire	\N	2017-06-07 15:00:00	2017-06-07 16:00:00	\N	\N	2	0	\N	\N
188782	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Ouverture à la concurrence domaine ferroviaire	\N	2017-06-08 09:00:00	2017-06-08 10:00:00	\N	\N	1	0	\N	\N
188804	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT suivi de la PAC	GT suivi de la PAC	2017-06-13 14:00:00	2017-06-13 15:00:00	\N	\N	8	0	\N	\N
188814	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT suivi de la PAC	GT suivi de la PAC	2017-06-13 15:00:00	2017-06-13 16:30:00	\N	\N	8	0	\N	\N
188976	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Culture - Agence France Muséums	Contrôle Culture - Agence France Muséums - Audition AFM	2017-06-13 17:10:00	2017-06-13 18:10:00	\N	\N	1	0	\N	\N
188995	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle CVAE	Contrôle CVAE - Audition Assemblée des départements de France	2017-06-13 10:15:00	2017-06-13 12:20:00	\N	\N	2	0	\N	\N
189159	COM_EURO	AUDRAP	\N	AFEU	\N	Résolution et supervision des chambres de compensation	Résolution et supervision des chambres de compensation	2017-06-19 15:00:00	2017-06-19 16:30:00	\N	\N	1	0	\N	\N
189171	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle Action Extérieure de l'Etat  2017 - IFRE - Berlin	Contrôle Action Extérieure de l'Etat  2017 - IFRE - Berlin	2017-06-21 14:00:00	2017-06-21 16:00:00	\N	\N	1	0	\N	\N
189274	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Formation au numérique	Formation au numérique	2017-06-21 09:30:00	2017-06-21 12:30:00	\N	\N	1	0	\N	\N
189492	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJLO et PJL Rétablir la confiance dans l'action publique	\N	2017-06-27 15:00:00	2017-06-27 17:00:00	2017-06-27 18:16:32	2017-06-28 14:08:57	104	0	\N	\N
189493	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Sixième prorogation de l'État d'urgence PJL Code des juridictions financières	\N	2017-06-28 09:40:00	2017-06-28 11:00:00	2017-06-28 11:36:41	2017-06-28 14:09:02	33	3	\N	\N
189532	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Investissement locatif	Investissement locatif	2017-06-21 14:00:00	2017-06-21 15:10:00	\N	\N	1	0	\N	\N
190117	COM_PERMANENTE	AUTRE	\N	AFCL	\N	audition Blanquer	audition Blanquer	2017-06-28 16:35:00	2017-06-28 18:40:00	2017-06-29 10:41:51	2017-06-29 14:25:12	75	0	\N	\N
190157	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Investissement locatif	\N	2017-06-27 16:30:00	2017-06-27 19:00:00	\N	\N	1	0	\N	\N
190159	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Ouverture à la concurrence domaine ferroviaire	\N	2017-06-28 11:00:00	2017-06-28 12:00:00	\N	\N	1	0	\N	\N
190161	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Ouverture à la concurrence domaine ferroviaire	\N	2017-06-28 16:00:00	2017-06-28 17:00:00	\N	\N	1	0	\N	\N
186635	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Mineurs étrangers isolés	Mineurs étrangers isolés	2017-04-20 08:00:00	2017-04-20 19:00:00	\N	\N	2	0	\N	\N
186824	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT suivi de la PAC	GT suivi de la PAC	2017-04-25 14:30:00	2017-04-25 16:00:00	\N	\N	3	0	\N	\N
186832	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT suivi de la PAC	GT suivi de la PAC	2017-04-25 16:00:00	2017-04-25 18:15:00	\N	\N	4	0	\N	\N
187072	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Groupe de travail Culture et handicap	Groupe de travail Culture et handicap	2017-05-03 10:00:00	2017-05-03 12:00:00	\N	\N	3	0	\N	\N
187076	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	groupe de travail Rythmes scolaires	groupe de travail Rythmes scolaires	2017-04-25 10:00:00	2017-04-25 17:00:00	\N	\N	1	0	\N	\N
187078	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Groupe de travail Culture et handicap	Groupe de travail Culture et handicap	2017-05-03 14:30:00	2017-05-03 15:30:00	\N	\N	3	0	\N	\N
187252	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Normalisation volontaire	\N	2017-05-09 14:00:00	2017-05-09 18:00:00	\N	\N	1	0	\N	\N
187372	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	Ouverture à la concurrence domaine ferroviaire	Ouverture à la concurrence ferroviaire	2017-05-11 09:00:00	2017-05-11 12:30:00	\N	\N	2	0	\N	\N
187512	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Rapport général	PLF pour 2018 - Rapport général - Audition de la Fédération française des Télécoms	2017-05-16 14:30:00	2017-05-16 15:30:00	\N	\N	1	0	\N	\N
187592	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Culture - Agence France Muséums	Contrôle Culture - Agence France Muséums - Audition AFM	2017-05-18 09:00:00	2017-05-18 10:00:00	\N	\N	2	0	\N	\N
187612	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Groupe de travail rythmes scolaires	Groupe de travail rythmes scolaires	2017-05-09 10:00:00	2017-05-10 18:00:00	\N	\N	2	0	\N	\N
187632	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Groupe de travail rythmes scolaires	Groupe de travail rythmes scolaires	2017-05-11 09:00:00	2017-05-11 17:00:00	\N	\N	1	0	\N	\N
187634	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Groupe de travail rythmes scolaires	Groupe de travail rythmes scolaires	2017-05-15 10:00:00	2017-05-15 18:00:00	\N	\N	1	0	\N	\N
187636	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Groupe de travail rythmes scolaires	Groupe de travail rythmes scolaires	2017-05-16 09:00:00	2017-05-16 18:00:00	\N	\N	2	0	\N	\N
187827	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	\N	\N	2017-05-10 09:30:00	2017-05-10 11:15:00	2017-05-24 16:57:38	\N	7	0	\N	\N
187992	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2017-05-23 14:30:00	2017-05-23 16:00:00	\N	\N	3	0	\N	\N
188032	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT suivi de la PAC	GT suivi de la PAC	2017-05-23 14:30:00	2017-05-23 16:00:00	\N	\N	6	0	\N	\N
188076	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT suivi de la PAC	GT suivi de la PAC	2017-05-23 16:00:00	2017-05-23 17:00:00	\N	\N	6	0	\N	\N
188112	COM_PERMANENTE	AUTRE	\N	CDD	\N	Présentation du rapport du groupe de travail sur l'aménagement du territoire	Présentation du rapport du groupe de travail sur l'aménagement du territoire	2017-05-31 09:35:00	2017-05-31 11:30:00	2017-05-31 15:41:12	2017-06-01 15:35:54	11	0	\N	\N
188552	DELEGATION	AUCUNE	\N	\N	211	DDF - Audition de représentantes de la Confédération paysanne	DDF - Audition de représentantes de la Confédération paysanne	2017-06-07 14:00:00	2017-06-07 15:30:00	2017-06-07 16:58:35	2017-06-08 09:36:21	5	0	\N	\N
188712	COM_PERMANENTE	DEPLACEMENT	\N	CAE	\N	APLOI VILLE	\N	2017-05-11 09:45:00	2017-05-11 19:15:00	\N	\N	2	0	\N	\N
189012	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Examen pétitions - Application des lois	\N	2017-06-20 15:05:00	2017-06-20 15:40:00	2017-06-20 17:50:12	2017-06-21 11:16:57	25	0	\N	\N
189352	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Code des juridictions financières	\N	2017-06-20 17:45:00	2017-06-20 20:30:00	\N	\N	1	0	\N	\N
189432	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Recherche et enseignement supérieur - SATT	Contrôle Recherche et enseignement supérieur - SATT - ESPCI Paris Tech et BPIFrance	2017-06-21 15:00:00	2017-06-21 17:00:00	\N	\N	1	0	\N	\N
189452	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Préparation UED	\N	2017-06-20 17:30:00	2017-06-20 18:30:00	\N	\N	2	0	\N	\N
189455	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Préparation UED	\N	2017-06-20 19:00:00	2017-06-20 20:00:00	\N	\N	1	0	\N	\N
189457	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Préparation UED	\N	2017-06-20 14:30:00	2017-06-20 15:15:00	\N	\N	2	0	\N	\N
189460	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Préparation UED	\N	2017-06-20 15:15:00	2017-06-20 16:00:00	\N	\N	2	0	\N	\N
189464	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Culture - Agence France Muséums	Contrôle Culture - Agence France Muséums - Audition APIE	2017-06-19 15:00:00	2017-06-19 16:15:00	\N	\N	2	0	\N	\N
189467	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Culture - Agence France Muséums	Contrôle Culture - Agence France Muséums - Audition M. Didier Selles	2017-06-21 11:00:00	2017-06-21 12:30:00	\N	\N	1	0	\N	\N
189802	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLO et PJL Rétablir la confiance dans l'action publique	\N	2017-06-27 14:00:00	2017-06-27 14:30:00	\N	\N	1	0	\N	\N
189804	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLO et PJL Rétablir la confiance dans l'action publique	\N	2017-06-27 14:30:00	2017-06-27 15:00:00	\N	\N	2	0	\N	\N
189807	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLO Rétablir la confiance dans l'action publique	\N	2017-06-27 17:00:00	2017-06-27 20:00:00	\N	\N	1	0	\N	\N
189820	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLO et PJL Rétablir la confiance dans l'action publique	\N	2017-06-28 12:00:00	2017-06-28 12:30:00	\N	\N	1	0	\N	\N
189990	COM_PERMANENTE	AUTRE	\N	CDD	\N	Communication sur le bilan annuel de l'application des lois	Communication sur le bilan annuel de l'application des lois	2017-06-28 09:35:00	2017-06-28 11:10:00	2017-06-28 13:57:05	2017-06-28 14:09:00	23	0	\N	\N
190052	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2017-06-28 09:35:00	2017-06-28 12:50:00	2017-06-28 14:31:59	2017-06-28 15:48:41	38	0	\N	\N
190249	COM_EURO	CONTROLE	\N	AFEU	\N	Auditiond e Mme Nathalie Loiseau, ministre déléguée aux affaires européennes	Audition de Mme Nathalie Loiseau, ministre déléguée aux affaires européennes	2017-06-27 17:05:00	2017-06-27 18:45:00	2017-06-29 10:23:24	2017-06-29 14:27:18	17	0	\N	\N
190413	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion de Commission du 29 juin 2017	Réunion de Commission du 29 juin 2017	2017-06-29 09:05:00	2017-06-29 10:20:00	2017-06-29 12:10:36	2017-06-29 14:27:23	10	0	\N	\N
190432	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Recherche et enseignement supérieur 2017	Contrôle Recherche et enseignement supérieur 2017 - Agence nationale de la recherche (ANR)	2017-06-26 16:30:00	2017-06-26 17:30:00	\N	\N	1	0	\N	\N
190434	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Recherche et enseignement supérieur 2017	Contrôle Recherche et enseignement supérieur 2017 - HCERES	2017-06-26 17:30:00	2017-06-26 18:30:00	\N	\N	1	0	\N	\N
190436	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Recherche et enseignement supérieur 2017	Contrôle Recherche et enseignement supérieur 2017 - CEA	2017-06-26 18:30:00	2017-06-26 19:30:00	\N	\N	1	0	\N	\N
190438	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Modernisation du contrôle de la navigation aérienne 2017	Contrôle Modernisation du contrôle de la navigation aérienne 2017 - SNCTA	2017-06-27 14:00:00	2017-06-27 15:30:00	\N	\N	1	0	\N	\N
190440	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Modernisation du contrôle de la navigation aérienne 2017	Contrôle Modernisation du contrôle de la navigation aérienne 2017 - USAC-CGT	2017-06-27 15:30:00	2017-06-27 16:30:00	\N	\N	1	0	\N	\N
190442	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Modernisation du contrôle de la navigation aérienne 2017	Contrôle Modernisation du contrôle de la navigation aérienne 2017 - SNNA - FO	2017-06-27 16:30:00	2017-06-27 17:30:00	\N	\N	1	0	\N	\N
186574	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Engagements financiers de l'Etat	Contrôle Engagements financiers de l'Etat - Audition AFT	2017-04-20 16:00:00	2017-04-20 17:00:00	\N	\N	1	0	\N	\N
186576	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Culture - Agence France Muséums	Contrôle Culture - Agence France Muséums - Audition ministère de l'économie et de finances	2017-04-19 10:00:00	2017-04-19 11:00:00	\N	\N	2	0	\N	\N
186592	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Parc immobilier du ministère de la défense 2017 	Contrôle Parc immobilier du ministère de la défense 2017  - EMAA	2017-04-20 10:00:00	2017-04-20 11:00:00	\N	\N	1	0	\N	\N
186594	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Parc immobilier du ministère de la défense 2017 	Contrôle Parc immobilier du ministère de la défense 2017  - EMM	2017-04-20 11:00:00	2017-04-20 12:00:00	\N	\N	1	0	\N	\N
186612	COM_PERMANENTE	AUDRAP	\N	FINC	\N	La compétitivité des places financières	La compétitivité des places financières - Audition IGF	2017-04-19 09:00:00	2017-04-19 10:00:00	\N	\N	1	0	\N	\N
186614	COM_PERMANENTE	AUDRAP	\N	FINC	\N	La compétitivité des places financières	La compétitivité des places financières - Audition ESMA	2017-04-19 10:00:00	2017-04-19 11:00:00	\N	\N	1	0	\N	\N
186616	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 Inclusion bancaire	58-2 Inclusion bancaire - Audition ASF	2017-04-19 16:00:00	2017-04-19 17:00:00	\N	\N	1	0	\N	\N
186652	DELEGATION	AUDRAP	\N	\N	COLTER	RI_prévention radicalisation et collectivités	RI_prévention radicalisation et collectivités	2017-04-19 15:00:00	2017-04-19 15:45:00	\N	\N	1	0	\N	\N
186654	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	COLTER	RI_CT et prévention de la radicalisation-conférence presse	RI_prévention radicalisation et collectivités_conférence presse	2017-04-11 11:00:00	2017-04-11 12:00:00	\N	\N	2	0	\N	\N
187232	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2017-05-09 16:00:00	2017-05-09 19:25:00	\N	\N	3	0	\N	\N
187132	MECSS	AUDRAP	\N	\N	MECSS	Mecss zones sous-dotée : déplacement Loiret	Mecss zones sous-dotée : déplacement dans le Loiret	2017-05-04 09:00:00	2017-05-04 18:00:00	\N	\N	2	0	\N	\N
187272	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	GT Réforme du marché du travail en Italie	GT réforme du marché du travail en Italie	2017-05-10 09:00:00	2017-05-10 12:00:00	\N	\N	3	0	\N	\N
187558	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Réforme rythmes scolaires - déplacement Seine-Maritime	Réforme rythmes scolaires - déplacement Seine-Maritime	2017-05-15 11:00:00	2017-05-15 17:30:00	\N	\N	1	0	\N	\N
187560	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Réforme rythmes scolaires - déplacement Haute-Savoie	Réforme rythmes scolaires - déplacement Haute-Savoie	2017-05-16 10:00:00	2017-05-16 19:00:00	\N	\N	1	0	\N	\N
188252	DELEGATION	AUCUNE	\N	\N	211	DDF - AUDITION SYNDICAT JEUNES AGRICULTEURS	DDF - AUDITION SYNDICAT JEUNES AGRICULTEURS	2017-06-01 09:30:00	2017-06-01 10:45:00	2017-06-01 11:59:39	2017-06-01 15:37:07	1	0	\N	\N
188953	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition remise rapport AMF - Nomination rapporteur PJL 491 et saisine PJLO 580-PJL 581	Audition remise rapport AMF - Nomination rapporteur PJL 491 et saisine PJLO 580-PJL 581	2017-06-21 14:35:00	2017-06-21 15:45:00	2017-06-22 17:42:31	2017-06-22 17:44:13	16	4	\N	\N
188972	COM_EURO	AUDRAP	\N	AFEU	\N	Énergie propre pour tous les Européens	Énergie propre pour tous les Européens	2017-06-14 10:00:00	2017-06-14 12:00:00	\N	\N	1	0	\N	\N
188974	COM_EURO	AUDRAP	\N	AFEU	\N	Énergie propre pour tous les Européens	Énergie propre pour tous les Européens	2017-06-15 09:00:00	2017-06-15 12:00:00	\N	\N	1	0	\N	\N
188992	COM_EURO	DEPLACEMENT	\N	AFEU	\N	Commission européenne - Bruxelles - 16/06/2017	Rencontre avec le président Juncker - Commission européenne - Bruxelles, le 16 juin 2017	2017-06-16 08:25:00	2017-06-16 12:00:00	\N	\N	2	0	\N	\N
189412	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition conventions fiscales et Contrôles assistance macrofinancière, SAIP et CVAE	Audition M. SAINT-AMANS conventions fiscales et Contrôles budgétaires assistance macrofinancière, SAIP et CVAE	2017-06-28 09:05:00	2017-06-28 12:10:00	2017-06-29 17:59:39	2017-06-30 09:24:28	28	0	\N	\N
189413	COM_PERMANENTE	AUTRE	\N	FINC	\N	Présentation cabinet Taj étude impact pour entreprises prélèvement à la source 	Présentation cabinet Taj étude impact pour entreprises prélèvement à la source 	2017-06-28 15:05:00	2017-06-28 15:55:00	2017-06-29 18:01:10	2017-06-30 09:24:24	25	0	\N	\N
189773	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2017-06-28 10:05:00	2017-06-28 11:40:00	2017-06-28 16:58:18	2017-06-29 14:25:15	27	4	\N	\N
189824	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2017-06-28 14:40:00	2017-06-28 16:00:00	2017-06-28 16:59:19	2017-06-29 14:25:13	29	0	\N	\N
190152	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle Navigation aérienne 2017 - Toulouse	Contrôle Navigation aérienne 2017 - Toulouse	2017-06-28 09:45:00	2017-06-28 21:55:00	\N	\N	1	0	\N	\N
190373	COM_EURO	AUDRAP	\N	AFEU	\N	Résolution et supervision des chambres de compensation	Résolution et supervision des chambres de compensation	2017-06-27 16:00:00	2017-06-27 17:00:00	\N	\N	1	0	\N	\N
190375	COM_EURO	AUDRAP	\N	AFEU	\N	Résolution et supervision des chambres de compensation	Résolution et supervision des chambres de compensation	2017-06-28 16:30:00	2017-06-28 17:30:00	\N	\N	1	0	\N	\N
190444	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Modernisation du contrôle de la navigation aérienne 2017	Contrôle Modernisation du contrôle de la navigation aérienne 2017 - UNSA-ICNA	2017-06-27 17:30:00	2017-06-27 18:30:00	\N	\N	1	0	\N	\N
190492	COM_EURO	AUDRAP	\N	AFEU	\N	Auditions Véhicules autonomes	Véhicules autonomes	2017-06-28 10:00:00	2017-06-28 11:30:00	\N	\N	1	0	\N	\N
190495	COM_EURO	AUDRAP	\N	AFEU	\N	Auditions Véhicules autonomes	Véhicules autonomes	2017-06-28 16:00:00	2017-06-28 18:00:00	\N	\N	1	0	\N	\N
190672	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 6 juillet 2017	Réunion du 6 juillet 2017	2017-07-06 09:30:00	2017-07-06 11:00:00	2017-07-06 16:03:45	2017-07-06 16:28:36	15	0	\N	\N
190695	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen Rapport pour avis PJLO 580 et PJL 581 Confiance et amendements	Examen Rapport pour avis PJLO 580 et PJL 581 Confiance et amendements	2017-07-04 14:20:00	2017-07-04 15:00:00	2017-07-05 17:50:40	2017-07-05 18:18:21	35	1	\N	\N
190756	SEANCE_PLENIERE	DECL_GVT	\N	\N	\N	Déclaration Politique générale du Gouvernement	Déclaration Politique générale du Gouvernement	2017-07-04 15:00:00	2017-07-04 16:45:00	\N	\N	285	0	\N	\N
190757	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL État d'urgence	PJL État d'urgence	2017-07-04 17:00:00	2017-07-04 18:55:00	\N	\N	108	0	\N	\N
191586	GIA	AUCUNE	\N	\N	\N	Visite d¿un groupe d'étudiants australiens de l'université de Curtin à Perth	Visite d¿un groupe d'étudiants australiens de l'université de Curtin à Perth	2017-07-04 13:00:00	2017-07-04 14:30:00	\N	\N	1	0	578	\N
191597	GIA	AUCUNE	\N	\N	\N	Entretien avec Mme Marie-Christine GERBER, Consule honoraire de France à Louxor	Entretien avec Mme Marie-Christine GERBER, Consule honoraire de France à Louxor	2017-07-04 12:30:00	2017-07-04 14:30:00	\N	\N	3	0	617	\N
191612	GIA	AUCUNE	\N	\N	\N	Entretien de M. Gérard MIQUEL, Président du groupe d'amitié, avec M. Aquilino « Koko » PIM	Entretien de M. Gérard MIQUEL, Président du groupe d'amitié, avec M. Aquilino « Koko » PIMENTEL III, Président du Sénat 	2017-07-04 12:30:00	2017-07-04 14:30:00	\N	\N	1	0	609	\N
191812	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Anciens combattants - CIVS - 2017	Contrôle Anciens combattants - CIVS - 2017 - Audition de Mme Corinne BOUCHOUX	2017-07-04 16:55:00	2017-07-04 18:25:00	\N	\N	1	0	\N	\N
191814	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Recherche et enseignement supérieur - SATT	Contrôle Recherche et enseignement supérieur - SATT - Commissariat général à l'investissement	2017-07-05 11:15:00	2017-07-05 12:35:00	\N	\N	1	0	\N	\N
192164	ETUDES	AUCUNE	\N	\N	\N	\N	\N	2017-07-05 08:30:00	2017-07-05 10:00:00	\N	\N	7	0	\N	934
192172	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Sécurité intérieure et lutte contre le terrorisme	\N	2017-07-05 14:00:00	2017-07-05 16:05:00	\N	\N	3	0	\N	\N
192270	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLO et PJL Rétablir la confiance dans l'action publique	\N	2017-07-04 09:00:00	2017-07-04 09:30:00	\N	\N	2	0	\N	\N
192453	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Préparation des UED	Préparation des UED	2017-07-04 14:00:00	2017-07-04 15:00:00	\N	\N	2	0	\N	\N
186672	COM_EURO	AUTRE_NON_PLENIERE	\N	AFEU	\N	Perturbateurs endocriniens	Colloque "Les pouvoirs publics face aux perturbateurs endocriniens"	2017-04-11 14:00:00	2017-04-11 18:00:00	\N	\N	3	0	\N	\N
186752	GIA	AUCUNE	\N	\N	\N	Entretien avec quatre sénateurs malgaches et cinq maires	Entretien avec quatre sénateurs malgaches et cinq maires	2017-04-25 12:30:00	2017-04-25 14:00:00	\N	\N	3	0	622	\N
186756	GIA	AUCUNE	\N	\N	\N	Entretien de M. YUNG avec Mme RAJAOARINELINA de l'AN malgache	Entretien de M. Richard YUNG, Président du groupe, avec Mme Lova RAJAOARINELINA, conseillère spéciale pour le Président 	2017-04-25 16:00:00	2017-04-25 17:00:00	\N	\N	1	0	622	\N
186892	COM_EURO	DEPLACEMENT	\N	AFEU	\N	Bruxelles - 28/04/2017	Rencontre avec les institutions européennes à Bruxelles-28 avril 2017	2017-04-28 09:00:00	2017-04-28 16:00:00	\N	\N	2	0	\N	\N
187152	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Affaires européennes - L'assistance macrofinancière de l'UE aux pays tiers	Contrôle Affaires européennes - L'assistance macrofinancière de l'UE aux pays tiers - Audition Ambassade de Tunisie	2017-05-03 10:00:00	2017-05-03 11:00:00	\N	\N	1	0	\N	\N
187154	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Affaires européennes - L'assistance macrofinancière de l'UE aux pays tiers	Contrôle Affaires européennes - L'assistance macrofinancière de l'UE aux pays tiers - Audition Ambassade de Géorgie	2017-05-03 11:15:00	2017-05-03 12:15:00	\N	\N	1	0	\N	\N
187156	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Dépenses Santé des détenus	Contrôle Dépenses Santé des détenus - Audition CGLPL	2017-05-02 14:30:00	2017-05-02 15:30:00	\N	\N	1	0	\N	\N
187158	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Dépenses Santé des détenus	Contrôle Dépenses Santé des détenus - Audition DGOS et DGS	2017-05-02 16:30:00	2017-05-02 17:15:00	\N	\N	1	0	\N	\N
187160	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Dépenses Santé des détenus	Contrôle Dépenses Santé des détenus - Audition DSS	2017-05-02 17:15:00	2017-05-02 18:00:00	\N	\N	1	0	\N	\N
187432	GIA	AUCUNE	\N	\N	\N	Déjeuner de travil - Jaffrelot - relations Inde-Pakistan	\N	2017-05-09 12:15:00	2017-05-09 14:00:00	\N	\N	5	0	619	\N
187438	GIA	AUCUNE	\N	\N	\N	Audtion Chaudet - sécurité/ terrorisme Asie centrale	\N	2017-05-09 14:15:00	2017-05-09 15:30:00	\N	\N	4	0	619	\N
187443	GIA	AUCUNE	\N	\N	\N	Audtion Racine - géopolitique Asie du Sud	\N	2017-05-09 15:30:00	2017-05-09 17:00:00	\N	\N	3	0	619	\N
187772	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2017-05-24 09:35:00	2017-05-24 11:15:00	2017-05-24 11:51:01	2017-05-24 13:36:53	25	3	\N	\N
188152	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI déradicalisation 	\N	2017-05-30 15:40:00	2017-05-30 19:20:00	\N	\N	2	0	\N	\N
188192	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Avenir des médias d'information	MI sur l'avenir des médias d'information	2017-05-30 14:30:00	2017-05-30 17:35:00	\N	\N	6	0	\N	\N
188232	COM_PERMANENTE	AUTRE	\N	FINC	\N	Communications places financières, missions locales et sur l'application des lois	Communications places financières, missions locales et sur l'application des lois	2017-06-07 09:35:00	2017-06-07 12:10:00	2017-06-08 11:39:46	2017-06-08 11:49:47	26	0	\N	\N
188272	DELEGATION	AUDRAP	\N	\N	COLTER	Audition conjointe délégation entreprises : revitalisation centres-villes IGF et CGEDD	\N	2017-06-20 14:20:00	2017-06-20 15:50:00	\N	\N	8	0	\N	\N
188273	DELEGATION	AUDRAP	\N	\N	COLTER	Audition conjointe délégation entreprises : revitalisation centres-villes CGET	\N	2017-06-21 11:00:00	2017-06-21 12:30:00	\N	\N	9	0	\N	\N
188570	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2017-06-07 14:30:00	2017-06-07 16:30:00	2017-06-07 17:30:16	2017-06-08 09:33:59	25	0	\N	\N
188852	COM_EURO	AUDRAP	\N	AFEU	\N	Véhicules autonomes	Véhicules autonomes	2017-06-13 13:30:00	2017-06-13 16:30:00	\N	\N	3	0	\N	\N
189168	COM_EURO	AUDRAP	\N	AFEU	\N	Propositions de règlements  relatives à l'asile	Propositions de règlements  relatives à l'asile	2017-06-21 10:30:00	2017-06-21 11:45:00	\N	\N	2	0	\N	\N
189192	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2017-06-21 10:10:00	2017-06-21 10:45:00	2017-06-21 11:29:24	2017-06-21 12:00:01	27	0	\N	\N
189354	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLO et PJL Rétablir la confiance dans l'action publique	\N	2017-06-21 11:30:00	2017-06-21 13:30:00	\N	\N	5	0	\N	\N
189360	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	\N	2017-06-21 14:00:00	2017-06-21 20:15:00	\N	\N	3	0	\N	\N
189472	COM_EURO	DEPLACEMENT	\N	AFEU	\N	Démocratie, État de droit et droits fondamentaux	Institution d¿un mécanisme européen sur la démocratie, l¿État de droit et les droits fondamentaux	2017-06-22 08:00:00	2017-06-22 17:00:00	\N	\N	2	0	\N	\N
189988	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Création de l'établissement public Paris La Défense	\N	2017-06-27 17:00:00	2017-06-27 17:35:00	\N	\N	1	0	\N	\N
190458	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLO et PJL Rétablir la confiance dans l'action publique	\N	2017-06-28 14:45:00	2017-06-28 18:45:00	\N	\N	5	0	\N	\N
190497	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Sixième prorogation de l'état d'urgence	\N	2017-07-04 09:35:00	2017-07-04 09:40:00	2018-05-18 15:59:53	2018-05-18 15:59:59	24	2	\N	\N
190512	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Code des juridictions financières PJLO  Rétablir la confiance dans l'action publique	\N	2017-07-04 19:05:00	2017-07-04 22:40:00	2017-07-05 17:57:04	2017-07-05 18:12:52	29	1	\N	\N
190513	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Sécurité intérieure et lutte contre le terrorisme	\N	2017-07-05 18:50:00	2017-07-05 20:30:00	2017-07-05 20:38:55	2017-07-06 10:25:37	27	0	\N	\N
190673	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation du Sénat philippin	Audience Pdt Gérad larcher	2017-06-28 12:00:00	2017-06-28 13:10:00	\N	\N	5	0	609	\N
190679	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation du Sénat philippin	Entretien avec des membres de la Commissioàn des Lois	2017-06-28 15:00:00	2017-06-28 16:15:00	\N	\N	3	0	609	\N
190683	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation du Sénat philippin	Déjeuner officiel à la Questure 	2017-06-28 13:20:00	2017-06-28 14:55:00	\N	\N	2	0	609	\N
190686	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation du Sénat philippin	Entretien avec M. Nicolas HULOT, ministre des transitions écologique et solidaire	2017-06-28 18:30:00	2017-06-28 19:40:00	\N	\N	1	0	609	\N
190688	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation du Sénat philippin	Visite culturelle	2017-06-30 08:00:00	2017-06-30 14:00:00	\N	\N	1	0	609	\N
190690	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation du Sénat philippin	Déjeuner officiel Salon Napoléon	2017-06-29 12:15:00	2017-06-29 14:00:00	\N	\N	4	0	609	\N
190772	SEANCE_PLENIERE	DECL_GVT	\N	\N	\N	Déclaration du Gouvernement	Déclaration du Gouvernement	2017-07-05 16:30:00	2017-07-05 18:25:00	\N	\N	243	0	\N	\N
190774	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Juridictions financières	PJL Juridictions financières	2017-07-06 09:30:00	2017-07-06 10:20:00	\N	\N	29	0	\N	\N
190775	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2017-07-06 15:00:00	2017-07-06 16:00:00	\N	\N	166	0	\N	\N
190776	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Confiance dans l'action publique	PJL Confiance dans l'action publique	2017-07-10 16:00:00	2017-07-10 18:40:00	\N	\N	61	0	\N	\N
190777	SEANCE_PLENIERE	ELOGE_FUNEBRE	\N	\N	\N	Éloge funèbre François FORTASSION	Éloge funèbre François FORTASSION	2017-07-11 14:15:00	2017-07-11 14:45:00	\N	\N	0	0	\N	\N
190778	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Confiance dans l'action publique	PJL Confiance dans l'action publique	2017-07-11 15:00:00	2017-07-11 16:30:00	\N	\N	215	0	\N	\N
190779	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2017-07-11 16:45:00	2017-07-11 17:30:00	\N	\N	275	0	\N	\N
190780	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Confiance dans l'action publique	PJL Confiance dans l'action publique	2017-07-11 17:45:00	2017-07-11 19:00:00	\N	\N	126	0	\N	\N
190781	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Confiance dans l'action publique	PJL Confiance dans l'action publique	2017-07-12 14:30:00	2017-07-12 20:45:00	\N	\N	177	0	\N	\N
190782	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Confiance dans l'action publique	PJL Confiance dans l'action publique	2017-07-12 22:00:00	2017-07-13 00:30:00	\N	\N	59	0	\N	\N
190783	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Confiance dans l'action publique	PJL Confiance dans l'action publique	2017-07-13 09:30:00	2017-07-13 12:45:00	\N	\N	79	0	\N	\N
186632	COM_EURO	DEPLACEMENT	\N	AFEU	\N	La situation en Turquie	La situation en Turquie	2017-04-25 15:00:00	2017-04-28 22:30:00	\N	\N	2	0	\N	\N
186732	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2017-04-25 14:40:00	2017-04-25 16:40:00	\N	\N	3	0	\N	\N
186828	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Situation urgences hospitalières	\N	2017-04-21 14:00:00	2017-04-21 18:00:00	\N	\N	3	0	\N	\N
187012	MECSS	AUDRAP	\N	\N	MECSS	Pertinence des actes	Pertinence des actes	2017-05-09 15:00:00	2017-05-09 16:00:00	\N	\N	1	0	\N	\N
187212	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Groupe de travail Culture et handicap	\N	2017-05-09 14:45:00	2017-05-09 16:00:00	\N	\N	1	0	\N	\N
187332	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Conférence interparlementaire PSDC-PESC	\N	2017-04-26 08:00:00	2017-04-27 18:00:00	\N	\N	1	0	\N	\N
187352	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle Affaires européennes - L'assistance macrofinancière de l'UE aux pays tiers	Contrôle Affaires européennes - L'assistance macrofinancière de l'UE aux pays tiers - Moldavie	2017-05-10 06:25:00	2017-05-12 17:10:00	\N	\N	1	0	\N	\N
187377	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Recherche et enseignement supérieur - SATT	Contrôle Recherche et enseignement supérieur - SATT - Audition CDC	2017-05-09 09:30:00	2017-05-09 11:00:00	\N	\N	1	0	\N	\N
187379	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Recherche et enseignement supérieur - SATT	Contrôle Recherche et enseignement supérieur - SATT - Audition CNRS	2017-05-09 11:00:00	2017-05-09 12:30:00	\N	\N	1	0	\N	\N
187556	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Réforme rythmes scolaires - déplacement la Fléche	Réforme rythmes scolaires - déplacement la Fléche	2017-05-11 09:30:00	2017-05-11 15:00:00	\N	\N	1	0	\N	\N
187672	GIA	AUCUNE	\N	\N	\N	Visite d'une délégation de neuf membres du Cabinet du Président du Bangladesh	Visite d'une délégation de neuf membres du Cabinet du Président du Bangladesh	2017-05-23 14:50:00	2017-05-23 16:15:00	\N	\N	1	0	609	\N
187692	COM_PERMANENTE	AUTRE	\N	FINC	\N	Communication dette publique et audition M. MIGAUD exercice 2016	Communication sur la dette publique de la France et audition M. MIGAUD  sur les résultats et certification exercice 2016	2017-05-31 09:35:00	2017-05-31 12:50:00	2017-06-01 10:56:09	2017-06-01 15:35:57	30	0	\N	\N
187693	COM_PERMANENTE	AUTRE	\N	FINC	\N	Communication avenir CAS Gestion patrimoine immobilier de l'Etat	Communication du contrôle budgétaire sur l'avenir du CAS Gestion patrimoine immobilier de l'Etat	2017-05-31 15:00:00	2017-05-31 16:00:00	2017-06-01 10:57:30	2017-06-01 15:35:58	20	0	\N	\N
187732	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2017-05-23 15:05:00	2017-05-23 16:55:00	2017-05-24 09:26:05	2017-05-24 13:36:52	31	4	\N	\N
187912	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Recherche et enseignement supérieur - SATT	Contrôle Recherche et enseignement supérieur - SATT - Auditions SITTAR et DGE	2017-05-24 09:30:00	2017-05-24 12:00:00	\N	\N	1	0	\N	\N
187914	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Culture - Agence France Muséums	Contrôle Culture - Agence France Muséums - Audition AFM	2017-05-23 16:15:00	2017-05-23 17:15:00	\N	\N	2	0	\N	\N
188012	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Action Extérieure de l'Etat  2017 - IFRE	Contrôle Action Extérieure de l'Etat  2017 - IFRE - Auditions	2017-05-23 15:00:00	2017-05-23 17:30:00	\N	\N	1	0	\N	\N
188352	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	groupe de travail Rythmes scolaires	groupe de travail Rythmes scolaires	2017-05-31 14:30:00	2017-05-31 15:30:00	\N	\N	2	0	\N	\N
188355	COM_PERMANENTE	AUTRE	\N	FINC	\N	Communication GT Rythmes scolaires	Communication GT Rythmes scolaires	2017-06-07 14:30:00	2017-06-07 16:30:00	2017-06-08 11:38:57	2017-06-08 11:49:48	25	2	\N	\N
188372	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Ouverture à la concurrence domaine ferroviaire	\N	2017-05-30 09:00:00	2017-05-30 10:00:00	\N	\N	2	0	\N	\N
188374	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Normalisation volontaire	\N	2017-05-31 11:00:00	2017-05-31 12:30:00	\N	\N	0	0	\N	\N
188823	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Avenir des médias d'information	MI sur l'avenir des médias d'information	2017-06-13 14:30:00	2017-06-13 17:00:00	\N	\N	6	0	\N	\N
188838	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Avenir des médias d'information	MI sur l'avenir des médias d'information	2017-06-14 09:00:00	2017-06-14 11:10:00	\N	\N	5	0	\N	\N
188844	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Avenir des médias d'information	MI sur l'avenir des médias d'information	2017-06-14 11:10:00	2017-06-14 12:10:00	\N	\N	4	0	\N	\N
188872	COM_PERMANENTE	AUDRAP	\N	CAE	\N	APLOI VILLE	\N	2017-06-13 16:00:00	2017-06-13 17:00:00	\N	\N	2	0	\N	\N
189152	COM_EURO	AUDRAP	\N	AFEU	\N	Véhicules autonomes	Véhicules autonomes	2017-06-20 14:00:00	2017-06-20 19:00:00	\N	\N	2	0	\N	\N
189155	COM_EURO	DEPLACEMENT	\N	AFEU	\N	GT suivi de la PAC	Bruxelles - Groupe de travail du suivi sur l'avenir de la PAC	2017-06-20 08:00:00	2017-06-20 19:00:00	\N	\N	3	0	\N	\N
189161	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Formation au numérique	Formation au numérique	2017-06-20 17:45:00	2017-06-20 18:45:00	\N	\N	1	0	\N	\N
189165	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Groupe de travail Culture et handicap	Groupe de travail Culture et handicap	2017-06-21 09:30:00	2017-06-21 11:30:00	\N	\N	2	0	\N	\N
189364	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Salon aéronautique du Bourget	\N	2017-06-21 07:30:00	2017-06-21 15:30:00	\N	\N	9	0	\N	\N
189632	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Formation au numérique	Formation au numérique	2017-06-27 15:00:00	2017-06-27 18:00:00	\N	\N	1	0	\N	\N
190412	DELEGATION	AUCUNE	\N	\N	DSOM	Examen du rapport d'information sur le foncier outre-mer	Examen du rapport d'information sur le foncier outre-mer	2017-07-06 08:30:00	2017-07-06 09:30:00	2017-07-06 10:49:36	2017-07-06 11:50:36	15	0	\N	\N
190538	BUREAU	AUCUNE	\N	\N	\N	Réunion du Bureau	Réunion du Bureau	2017-05-31 09:00:00	2017-05-31 13:00:00	\N	\N	22	0	\N	\N
190562	BUREAU	AUCUNE	\N	\N	\N	Réunion du Bureau	Réunion du Bureau	2017-06-29 08:30:00	2017-06-29 11:30:00	\N	\N	19	0	\N	\N
190592	BUREAU	AUCUNE	\N	\N	\N	Délégation statut du sénateur	Délégation en charge du statut et des conditions d'exercice du mandat de sénateur	2017-05-23 17:30:00	2017-05-23 18:00:00	\N	\N	2	0	\N	\N
190595	BUREAU	AUCUNE	\N	\N	\N	Délégation statut du sénateur	Délégation en charge du statut et des conditions d'exercice du mandat de sénateur	2017-06-21 12:00:00	2017-06-21 12:35:00	\N	\N	3	0	\N	\N
190599	COM_PERMANENTE	DEPLACEMENT	\N	SOCI	\N	\N	\N	2017-06-29 07:45:00	2017-06-29 19:15:00	\N	\N	0	0	\N	\N
190613	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2017-07-05 18:35:00	2017-07-05 20:15:00	2017-07-06 09:53:38	2017-07-06 10:25:36	21	0	\N	\N
190632	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Culture - Agence France Muséums	Contrôle Culture - Agence France Muséums - Audition Louvre	2017-06-30 16:30:00	2017-06-30 17:45:00	\N	\N	2	0	\N	\N
190652	COM_PERMANENTE	DEPLACEMENT	\N	SOCI	\N	MI Situation des urgences hospitalières	MI Situation des urgences hospitalières	2017-06-30 07:45:00	2017-06-30 19:15:00	\N	\N	3	0	\N	\N
190784	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Confiance dans l'action publique	PJL Confiance dans l'action publique	2017-07-13 14:30:00	2017-07-13 15:55:00	\N	\N	43	0	\N	\N
190785	SEANCE_PLENIERE	ELOGE_FUNEBRE	\N	\N	\N	Éloge funèbre Patrick MASCLET	Éloge funèbre Patrick MASCLET	2017-07-18 14:20:00	2017-07-18 14:40:00	\N	\N	0	0	\N	\N
190786	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Sécurité intérieure	PJL Sécurité intérieure	2017-07-18 15:00:00	2017-07-18 20:15:00	\N	\N	181	0	\N	\N
190787	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Sécurité intérieure	PJL Sécurité intérieure	2017-07-18 21:45:00	2017-07-19 00:40:00	\N	\N	65	0	\N	\N
186712	GIA	AUCUNE	\N	\N	\N	Table ronde sur le Botswana	Entretiens sur les enjeux économiques des entreprises françaises au Botswana dans la perspective d¿un « après-diamant »	2017-04-25 15:00:00	2017-04-25 17:00:00	\N	\N	4	0	646	\N
186772	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Affaires européennes - L'assistance macrofinancière de l'UE aux pays tiers 	Contrôle Affaires européennes - L'assistance macrofinancière de l'UE aux pays tiers - Déplacement Bruxelles	2017-05-02 08:45:00	2017-05-02 18:15:00	\N	\N	1	0	\N	\N
186792	COM_PERMANENTE	AUDRAP	\N	CAE	\N	APLOI - Ville et cohésion urbaine	\N	2017-04-25 14:30:00	2017-04-25 17:10:00	\N	\N	2	0	\N	\N
186795	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	\N	\N	2017-04-25 16:00:00	2017-04-25 17:30:00	\N	\N	1	0	\N	\N
186812	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Ouverture à la concurrence domaine ferroviaire	Ouverture à la concurrence domaine ferroviaire	2017-04-25 10:15:00	2017-04-25 11:15:00	\N	\N	1	0	\N	\N
186815	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Ouverture à la concurrence domaine ferroviaire	Ouverture à la concurrence domaine ferroviaire	2017-04-25 14:30:00	2017-04-25 18:30:00	\N	\N	1	0	\N	\N
186818	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Ouverture à la concurrence domaine ferroviaire	\N	2017-04-26 09:00:00	2017-04-26 12:00:00	\N	\N	1	0	\N	\N
186821	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Ouverture à la concurrence domaine ferroviaire	\N	2017-04-26 14:00:00	2017-04-26 16:00:00	\N	\N	1	0	\N	\N
186852	DELEGATION	DEPLACEMENT	\N	\N	ENTREPRISES	Déplacement en Bretagne (Finistère)	Déplacement en Bretagne (Finistère)	2017-04-26 07:30:00	2017-04-26 19:30:00	\N	\N	7	0	\N	\N
186860	DELEGATION	DEPLACEMENT	\N	\N	ENTREPRISES	Déplacement en Bretagne (Côtes-d'Armor)	Déplacement en Bretagne (Côtes-d'Armor)	2017-04-27 06:15:00	2017-04-27 19:30:00	\N	\N	8	0	\N	\N
186912	MECSS	AUDRAP	\N	\N	MECSS	Offre de soins primaires dans les zones sous-dotées	\N	2017-04-27 09:00:00	2017-04-27 18:00:00	\N	\N	2	0	\N	\N
186932	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Dépenses Santé des détenus	Contrôle Dépenses Santé des détenus - Audition CNAMTS	2017-04-25 18:00:00	2017-04-25 18:45:00	\N	\N	1	0	\N	\N
186952	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Recherche et enseignement supérieur - SATT	Contrôle Recherche et enseignement supérieur - SATT - Déplacement SATT IDF	2017-04-25 09:30:00	2017-04-25 14:00:00	\N	\N	1	0	\N	\N
186954	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Ecologie 2017 - Enjeux budgétaire application droit communautaire de l'environnem	Contrôle Ecologie 2017 - Enjeux budgétaires application droit communautaire de l'environnement - Audition MEEM	2017-04-25 09:30:00	2017-04-25 10:30:00	\N	\N	1	0	\N	\N
186973	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Culture - Agence France Muséums	Contrôle Culture - Agence France Muséums - Audition Centre Georges Pompidou	2017-04-25 15:30:00	2017-04-25 16:30:00	\N	\N	2	0	\N	\N
186976	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Culture - Agence France Muséums	Contrôle Culture - Agence France Muséums - Audition Musée Guimet	2017-04-25 16:30:00	2017-04-25 17:30:00	\N	\N	2	0	\N	\N
186979	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Culture - Agence France Muséums	Contrôle Culture - Agence France Muséums - Audition Louvre	2017-04-25 19:00:00	2017-04-25 21:00:00	\N	\N	2	0	\N	\N
186992	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Culture - Agence France Muséums	Contrôle Culture - Agence France Muséums - Audition Henri Loyrette	2017-04-26 18:00:00	2017-04-26 19:00:00	\N	\N	2	0	\N	\N
186995	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Culture - Agence France Muséums	Contrôle Culture - Agence France Muséums - Audition Direction générale des musées de France	2017-04-27 10:00:00	2017-04-27 11:30:00	\N	\N	1	0	\N	\N
186998	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Culture - Agence France Muséums	Contrôle Culture - Agence France Muséums - Audition Didier Selles	2017-04-27 15:00:00	2017-04-27 16:20:00	\N	\N	1	0	\N	\N
187001	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Culture - Agence France Muséums	Contrôle Culture - Agence France Muséums - Audition Musée d'Orsay	2017-04-27 16:20:00	2017-04-27 17:40:00	\N	\N	1	0	\N	\N
187032	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Dette publique	Contrôle Dette publique - Audition Agence France Trésor	2017-04-27 11:00:00	2017-04-27 12:00:00	\N	\N	1	0	\N	\N
187034	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Instituts français de recherche à l'étranger (IFRE)	Contrôle Instituts français de recherche à l'étranger (IFRE) - Audition Ministère des affaires étrangères	2017-04-25 14:30:00	2017-04-25 15:45:00	\N	\N	1	0	\N	\N
187036	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Culture - Agence France Muséums	Contrôle Culture - Agence France Muséums - Audition Bruno Maquart	2017-04-28 15:00:00	2017-04-28 16:20:00	\N	\N	1	0	\N	\N
187052	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Culture - Agence France Muséums	Contrôle Culture - Agence France Muséums - Audition Agence France Muséums (AFM)	2017-04-28 16:20:00	2017-04-28 17:45:00	\N	\N	1	0	\N	\N
187092	GIA	AUCUNE	\N	\N	\N	France-Jordanie	Entretien avec l'Ambassadeur de Jordanie à Paris	2017-05-02 19:30:00	2017-05-02 22:00:00	\N	\N	1	0	659	\N
188695	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 Inclusion bancaire	58-2 Inclusion bancaire - Audition de l'association Crésus	2017-06-07 17:00:00	2017-06-07 18:00:00	\N	\N	1	0	\N	\N
188696	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Recherche et enseignement supérieur - SATT	Contrôle Recherche et enseignement supérieur - SATT - Audition CEA	2017-06-06 10:05:00	2017-06-06 11:15:00	\N	\N	1	0	\N	\N
188912	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière	Réunion plénière	2017-06-28 13:50:00	2017-06-28 15:00:00	2017-06-28 17:46:46	2017-06-29 14:26:40	12	0	\N	\N
188932	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle Recherche et enseignement supérieur - SATT - Oxford	Contrôle Recherche et enseignement supérieur - SATT - Oxford	2017-06-13 07:45:00	2017-06-14 18:55:00	\N	\N	1	0	\N	\N
188934	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle Parc immobilier du ministère de la défense 2017  - Toulon	Contrôle Parc immobilier du ministère de la défense 2017  - Toulon	2017-06-15 09:05:00	2017-06-15 19:35:00	\N	\N	1	0	\N	\N
188952	DELEGATION	AUCUNE	\N	\N	DSOM	Examen du rapport d'information sur les normes dans la construction outre-mer	Examen du rapport d'information sur les normes dans la construction outre-mer	2017-06-29 09:30:00	2017-06-29 11:05:00	2017-06-29 11:32:50	2017-06-29 14:26:42	7	0	\N	\N
189033	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Préparation UED	\N	2017-06-14 09:30:00	2017-06-14 10:30:00	\N	\N	2	0	\N	\N
189036	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Préparation UED	\N	2017-06-14 11:00:00	2017-06-14 12:15:00	\N	\N	2	0	\N	\N
189332	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2017-06-20 15:30:00	2017-06-20 16:45:00	\N	\N	3	0	\N	\N
189552	GIA	AUCUNE	\N	\N	\N	Remise de la Légion d'honneur moldave à Mme Josette DURRIEU	Remise de la Légion d'honneur moldave à Mme Josette DURRIEU, Présidente du groupe interparlementaire d'amitié	2017-06-24 11:00:00	2017-06-24 13:30:00	\N	\N	2	0	851	\N
190532	COM_PERMANENTE	AUTRE	\N	FINC	\N	Suite Examen Rapport pour avis PJLO 580 / PJL 581,Contrôles PITE , Environnement et EFE	Suite Examen Rapport pour avis PJLO 580 / PJL 581,Contrôles PITE , Environnement et EFE	2017-07-04 17:00:00	2017-07-04 19:15:00	2017-07-05 17:50:08	2017-07-05 18:12:53	27	1	\N	\N
190533	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition Didier MIGAUD préalable au DOFP et sur audit des comptes publics	Audition Didier MIGAUD préalable au DOFP et sur audit des comptes publics	2017-07-05 14:30:00	2017-07-05 16:30:00	2017-07-06 09:50:37	2017-07-06 10:25:35	63	0	\N	\N
190790	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Paris La Défense	PJL Paris La Défense	2017-07-20 09:35:00	2017-07-20 11:35:00	\N	\N	59	0	\N	\N
190791	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2017-07-20 15:05:00	2017-07-20 16:15:00	\N	\N	182	0	\N	\N
190793	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Règlement du budget 2016 et débat d'orientation des finances publiques	PJL Règlement du budget 2016 et débat d'orientation des finances publiques	2017-07-20 16:35:00	2017-07-20 20:00:00	\N	\N	44	0	\N	\N
186676	COM_ENQUETE	PLENIERE	\N	ATTEINTES	\N	Suite de l'examen du rapport final 	Suite de l'examen du rapport final 	2017-04-25 16:05:00	2017-04-25 16:50:00	2017-04-25 20:00:53	2017-04-26 09:02:42	11	0	\N	\N
187292	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Déradicalisation	\N	2017-05-10 09:30:00	2017-05-10 10:15:00	\N	\N	1	0	\N	\N
187312	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Déradicalisation	\N	2017-05-10 15:00:00	2017-05-10 18:15:00	\N	\N	2	0	\N	\N
187552	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Anciens combattants - CIVS - 2017	Contrôle Anciens combattants - CIVS - 2017 - Audition de la CIVS	2017-05-17 14:45:00	2017-05-17 16:30:00	\N	\N	1	0	\N	\N
187554	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Anciens combattants - CIVS - 2017	Contrôle Anciens combattants - CIVS - 2017 - Audition de Mme Claire Andrieu, professeure des universités à Sciences Po	2017-05-17 16:30:00	2017-05-17 17:30:00	\N	\N	1	0	\N	\N
187652	GIA	AUCUNE	\N	\N	\N	préparation festival Himalaya	préparation festival Himalaya	2017-05-23 14:30:00	2017-05-23 16:00:00	\N	\N	2	0	634	\N
187655	GIA	AUCUNE	\N	\N	\N	Festival Himalaya - table ronde	Festival Himalaya - table ronde	2017-06-10 12:00:00	2017-06-10 17:00:00	\N	\N	2	0	634	\N
187658	GIA	AUCUNE	\N	\N	\N	petit-déjeuner - Thubten Wangchen	petit-déjeuner - Thubten Wangchen	2017-06-07 08:30:00	2017-06-07 10:00:00	\N	\N	3	0	634	\N
187694	DELEGATION	AUCUNE	\N	\N	211	Audition de Mme Christiane Lambert - présidente de la FNSEA	Audition de Mme Christiane Lambert - présidente de la FNSEA	2017-05-23 14:30:00	2017-05-23 16:15:00	2017-05-23 17:10:05	2017-05-23 17:26:47	12	0	\N	\N
187770	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Groupe de travail Culture et handicap	Groupe de travail Culture et handicap	2017-05-23 16:00:00	2017-05-23 17:20:00	\N	\N	1	0	\N	\N
187872	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	GT Aménagement du territoire	\N	2017-05-24 09:00:00	2017-05-24 10:20:00	\N	\N	8	0	\N	\N
187892	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle Recherche et enseignement supérieur - SATT Marseille	Contrôle Recherche et enseignement supérieur - SATT Marseille	2017-05-30 11:35:00	2017-05-31 20:25:00	\N	\N	1	0	\N	\N
187932	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Simplification du droit pour les entreprises	\N	2017-06-06 17:15:00	2017-06-06 18:30:00	\N	\N	1	0	\N	\N
187934	DELEGATION	DEPLACEMENT	\N	\N	ENTREPRISES	Déplacement SIAE	\N	2017-06-20 13:20:00	2017-06-20 18:30:00	\N	\N	9	0	\N	\N
187942	DELEGATION	DEPLACEMENT	\N	\N	ENTREPRISES	Déplacement au Havre	\N	2017-06-29 06:15:00	2017-06-29 18:30:00	\N	\N	11	0	\N	\N
187952	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion commune avec la Commission des Finances - Prélèvement à la source IR	Réunion commune avec la Commission des Finances  - Prélèvement à la source IR	2017-06-28 15:05:00	2017-06-28 15:55:00	2017-06-28 18:04:15	2017-06-29 14:26:41	25	0	\N	\N
189112	DELEGATION	AUCUNE	\N	\N	211	DDF - Audition de Mme Stéphanie Pageot - présidente de la FNAB	DDF - Audition de Mme Stéphanie Pageot - présidente de la FNAB	2017-06-20 14:30:00	2017-06-20 15:30:00	2017-06-20 17:53:18	2017-06-21 12:00:34	12	0	\N	\N
189292	GIA	AUCUNE	\N	\N	\N	Entretien de M. Alain RICHARD avec le maire de la ville de Taichung, M. LIN Chia-lung	 Entretien de M. Alain RICHARD avec le maire de la ville de Taichung, M. LIN Chia-lung	2017-06-21 20:00:00	2017-06-21 21:30:00	\N	\N	1	0	623	\N
189930	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2017-06-28 09:30:00	2017-06-28 11:20:00	2017-06-28 11:44:23	2017-06-28 14:08:59	29	0	\N	\N
190154	COM_PERMANENTE	DEPLACEMENT	\N	SOCI	\N	MI Situation des urgences hospitalières	MI Situation des urgences hospitalières	2017-06-27 12:15:00	2017-06-27 16:00:00	\N	\N	2	0	\N	\N
190465	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Convention fiscale Portugal CVN Portugal	Convention fiscale Portugal CVN Portugal - Altitude avocats	2017-06-28 17:00:00	2017-06-28 18:00:00	\N	\N	1	0	\N	\N
190467	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Convention fiscale Portugal CVN Portugal	Convention fiscale Portugal CVN Portugal - AFE	2017-06-28 18:00:00	2017-06-28 19:00:00	\N	\N	1	0	\N	\N
190469	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJLO Confiance action publique	PJLO Confiance action publique - ministère intérieur	2017-06-29 09:30:00	2017-06-29 10:30:00	\N	\N	1	0	\N	\N
190471	COM_EURO	AUDRAP	\N	AFEU	\N	Auditions "Paquet Energie"	Paquet Energie	2017-06-27 09:00:00	2017-06-27 10:00:00	\N	\N	1	0	\N	\N
190473	COM_EURO	AUDRAP	\N	AFEU	\N	Auditions "Paquet Energie"	Paquet Energie	2017-06-27 12:00:00	2017-06-27 15:00:00	\N	\N	1	0	\N	\N
190475	COM_EURO	AUDRAP	\N	AFEU	\N	Auditions "Paquet Energie"	Paquet Energie	2017-06-28 14:00:00	2017-06-28 16:00:00	\N	\N	1	0	\N	\N
190477	COM_EURO	AUDRAP	\N	AFEU	\N	Auditions "Paquet Energie"	Paquet Energie	2017-06-29 11:00:00	2017-06-29 12:00:00	\N	\N	1	0	\N	\N
190534	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Sécurité intérieure et lutte contre le terrorisme	\N	2017-06-28 15:00:00	2017-06-28 19:30:00	\N	\N	1	0	\N	\N
190536	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Sécurité intérieure et lutte contre le terrorisme	\N	2017-06-29 09:00:00	2017-06-29 12:45:00	\N	\N	1	0	\N	\N
190794	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL France - Portugal doubles impositions	PJL France - Portugal doubles impositions	2017-07-20 20:00:00	2017-07-20 20:20:00	\N	\N	8	0	\N	\N
190795	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Habilitation loi travail	PJL Habilitation loi travail	2017-07-24 16:00:00	2017-07-24 20:00:00	\N	\N	62	0	\N	\N
190796	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2017-07-25 09:35:00	2017-07-25 12:30:00	\N	\N	46	0	\N	\N
190797	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Habilitation loi travail	PJL Habilitation loi travail	2017-07-25 14:35:00	2017-07-25 20:00:00	\N	\N	202	0	\N	\N
190798	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Habilitation loi travail	PJL Habilitation loi travail	2017-07-25 21:30:00	2017-07-26 00:20:00	\N	\N	85	0	\N	\N
190801	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Habilitation loi travail	PJL Habilitation loi travail	2017-07-26 14:30:00	2017-07-26 20:05:00	\N	\N	136	0	\N	\N
190802	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Habilitation loi travail	PJL Habilitation loi travail	2017-07-26 21:35:00	2017-07-27 00:25:00	\N	\N	63	0	\N	\N
190803	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Habilitation loi travail	PJL Habilitation loi travail	2017-07-27 09:30:00	2017-07-27 13:00:00	\N	\N	80	0	\N	\N
190804	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Habilitation loi travail	PJL Habilitation loi travail	2017-07-27 14:35:00	2017-07-27 20:15:00	\N	\N	65	0	\N	\N
190806	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2017-08-01 16:45:00	2017-08-01 17:45:00	\N	\N	192	0	\N	\N
190807	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PJL Confiance dans la vie politique	CMP PJL Confiance dans la vie politique	2017-08-02 16:00:00	2017-08-02 19:00:00	\N	\N	86	0	\N	\N
190815	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	sportives	\N	2017-07-13 09:00:00	2017-07-13 12:00:00	\N	\N	4	0	\N	\N
191712	DELEGATION	AUCUNE	\N	\N	211	DDF - Examen du rapport "Femmes et agriculture"	DDF - Examen du rapport "Femmes et agriculture"	2017-07-05 13:00:00	2017-07-05 14:30:00	2017-07-05 16:14:03	2017-07-05 16:46:55	13	0	\N	\N
191732	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Délégation aux Collectivités territoriales - Revitalisation centres bourgs	Réunion commune Délégation aux entreprises / Délégation aux Collectivités territoriales - Révitalisation centres bourgs	2017-07-20 08:30:00	2017-07-20 10:10:00	2017-07-21 11:26:55	2017-07-21 16:39:36	23	0	\N	\N
191733	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière	Réunion plénière	2017-07-20 10:15:00	2017-07-20 11:35:00	2017-07-21 16:33:40	2017-07-21 16:39:38	9	0	\N	\N
191734	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	ENTREPRISES	Bilan d'activité	\N	2017-07-18 12:30:00	2017-07-18 14:05:00	\N	\N	15	0	\N	\N
191752	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2017-07-05 09:30:00	2017-07-05 10:45:00	2017-07-05 12:12:28	2017-07-05 15:46:23	25	0	\N	\N
192019	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2017-07-05 14:30:00	2017-07-05 16:30:00	2017-07-05 17:42:17	2017-07-05 17:48:31	63	0	\N	\N
192472	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle Action Extérieure de l'Etat 2017 - IFRE - Jérusalem	Contrôle Action Extérieure de l'Etat 2017 - IFRE - Jérusalem	2017-07-06 17:50:00	2017-07-07 21:40:00	\N	\N	1	0	\N	\N
192693	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Sécurité intérieure et lutte contre le terrorisme	\N	2017-07-06 09:00:00	2017-07-06 13:15:00	\N	\N	1	0	\N	\N
196772	ETUDES	AUCUNE	\N	\N	\N	G.E. "Vigne et Vin"	G.E. "Vigne et Vin"	2017-07-12 08:30:00	2017-07-12 09:25:00	\N	\N	19	0	\N	909
196909	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Rétablir la confiance dans l'action publique	\N	2017-07-12 23:50:00	2017-07-12 23:55:00	2017-07-13 11:48:40	2017-07-13 15:26:07	10	0	\N	\N
197457	QUESTURE	AUCUNE	\N	\N	\N	Commission de concertation	Commission de concertation	2017-07-12 10:00:00	2017-07-12 12:45:00	\N	\N	3	0	\N	\N
203792	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle Sécurités Police et Gendarmerie à Biarritz	Contrôle Sécurités Police et Gendarmerie à Biarritz - 58-2 Les moyens d¿investissement et de fonctionnement de la police	2017-08-03 08:45:00	2017-08-04 18:00:00	\N	\N	1	0	\N	\N
203832	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2018 - Mission Egalité des Territoires et logement	PLF pour 2018 - Mission Egalité des Territoires et logement - Île de France	2017-07-26 14:00:00	2017-07-26 15:30:00	\N	\N	1	0	\N	\N
203834	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT Taxe d'habitation	Groupe de Travail sur la réforme de la taxe d'habitation	2017-07-26 12:10:00	2017-07-26 12:35:00	\N	\N	6	0	\N	\N
203852	GIA	AUCUNE	\N	\N	\N	petit déjeuner de travail	Entretien avec l'attaché de défense M. Chatellereau de l'Ambassade de France au Royaume Uni	2017-07-05 08:30:00	2017-07-05 10:00:00	\N	\N	4	0	581	\N
203872	GIA	AUCUNE	\N	\N	\N	Entretiens avec Georges Lefeuvre, anthropologue	Entretiens G. Lefeuvre	2017-07-18 14:00:00	2017-07-18 15:30:00	\N	\N	1	0	619	\N
203875	GIA	AUCUNE	\N	\N	\N	Entretiens avec l'ambassadeur du Pakistan	\N	2017-07-19 08:15:00	2017-07-19 09:30:00	\N	\N	1	0	619	\N
205172	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2017-09-19 14:30:00	2017-09-19 17:00:00	\N	\N	3	0	\N	\N
205332	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Réforme du droit des contrats	\N	2017-09-14 10:00:00	2017-09-14 10:35:00	\N	\N	1	0	\N	\N
205334	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Réforme du droit des contrats	\N	2017-09-14 15:15:00	2017-09-14 16:45:00	\N	\N	1	0	\N	\N
205336	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Réforme du droit des contrats	\N	2017-09-15 09:35:00	2017-09-15 11:45:00	\N	\N	1	0	\N	\N
192752	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation du Sénat du Cambodge	Accueil d'une délégation du Sénat du Cambodge	2017-07-04 12:30:00	2017-07-04 14:00:00	\N	\N	4	0	577	\N
205372	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition Migaud avis HCFP sur PLF et PLFSS pour 2018 et sur LPFP	Audition Migaud avis HCFP sur PLF et PLFSS pour 2018 et sur LPFP	2017-09-27 14:30:00	2017-09-27 15:40:00	2017-09-28 10:20:10	2017-09-29 17:14:01	29	0	\N	\N
205373	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition ministres EcoFin sur PLF pour 2018 et LPFP	Audition ministres EcoFin sur PLF pour 2018 et LPFP	2017-09-27 16:25:00	2017-09-27 18:25:00	2017-09-29 17:11:11	2017-09-29 17:14:02	28	0	\N	\N
205930	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 5 octobre 2017	Réunion du 5 octobre 2017	2017-10-05 15:45:00	2017-10-05 16:20:00	2017-10-06 10:39:20	2017-10-06 11:23:47	36	0	\N	\N
206578	COM_PERMANENTE	AUTRE	\N	CDD	\N	Régles applicables à l'évaluation environnementales	Régles applicables à l'évaluation environnementales	2017-10-10 14:00:00	2017-10-10 14:15:00	2018-05-18 16:04:26	\N	33	0	\N	\N
207070	GIA	AUCUNE	\N	\N	\N	Déjeuner à l'ambassade de Finlande	Invitation à déjeuner des membres du groupe par S.E. M. Risto PIIPPONEN, Ambassadeur de Finlande à l¿occasion de la visi	2017-10-02 12:00:00	2017-10-02 14:00:00	\N	\N	4	0	640	\N
208061	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2017-10-17 15:10:00	2017-10-17 16:45:00	2017-10-17 17:28:11	2017-10-18 16:44:07	38	0	\N	\N
208062	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2017-10-18 09:05:00	2017-10-18 11:40:00	2017-10-18 12:10:25	2017-10-18 16:44:05	38	0	\N	\N
208063	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2017-10-18 15:05:00	2017-10-18 16:25:00	2017-10-18 16:57:23	2017-10-18 17:08:38	34	0	\N	\N
208066	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2017-10-17 14:00:00	2017-10-17 16:45:00	\N	\N	4	0	\N	\N
208069	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2017-10-18 14:00:00	2017-10-18 16:45:00	\N	\N	5	0	\N	\N
208071	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2017-10-19 09:00:00	2017-10-19 12:00:00	\N	\N	1	0	\N	\N
208073	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2017-10-24 14:00:00	2017-10-24 18:00:00	\N	\N	8	0	\N	\N
208076	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2017-10-25 14:00:00	2017-10-25 18:00:00	\N	\N	3	0	\N	\N
208078	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2017-10-31 15:15:00	2017-10-31 16:00:00	\N	\N	1	0	\N	\N
208429	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL HYDROCARBURES	\N	2017-10-10 14:00:00	2017-10-10 15:00:00	\N	\N	1	0	\N	\N
208431	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL HYDROCARBURES	\N	2017-10-10 18:00:00	2017-10-10 20:00:00	\N	\N	1	0	\N	\N
208433	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL HYDROCARBURES	\N	2017-10-11 09:00:00	2017-10-11 13:15:00	\N	\N	1	0	\N	\N
210096	GIA	AUCUNE	\N	\N	\N	Réception à l'occasion de la fête nationale ukrainienne	\N	2017-09-21 13:00:00	2017-09-21 14:00:00	\N	\N	1	0	530	\N
210098	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2017-10-24 17:00:00	2017-10-24 19:30:00	2017-10-25 15:14:10	2017-10-25 15:23:04	38	0	\N	\N
210099	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2017-10-25 09:00:00	2017-10-25 12:45:00	2017-10-25 16:14:28	2017-10-25 16:33:52	42	0	\N	\N
210107	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Représentation des communes déléguées	\N	2017-10-19 09:00:00	2017-10-19 12:10:00	\N	\N	2	0	\N	\N
210157	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF 2018 - Programme 129	\N	2017-10-18 14:00:00	2017-10-18 15:00:00	\N	\N	2	0	\N	\N
210191	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2017-10-31 08:30:00	2017-10-31 09:15:00	\N	\N	1	0	\N	\N
210194	GIA	AUCUNE	\N	\N	\N	accueil délégation parlementaire tibétaine	accueil délégation parlementaire tibétaine	2017-11-15 08:30:00	2017-11-15 10:00:00	\N	\N	8	0	634	\N
211416	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de finances 2018	Loi de finances 2018 (Audiovisuel)	2017-10-24 14:30:00	2017-10-24 19:15:00	\N	\N	4	0	\N	\N
211679	DELEGATION	DEPLACEMENT	\N	\N	206	Visite au CEA 	Visite au CEA - Très Grand Centre de Calcul (TGCC)	2017-10-26 08:15:00	2017-10-26 14:00:00	\N	\N	8	0	\N	\N
212411	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 -  Conseil et contrôle de l'État	PLF pour 2018 -  Conseil et contrôle de l'État - Audition Conseil d'État	2017-10-24 14:20:00	2017-10-24 15:20:00	\N	\N	1	0	\N	\N
213122	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Sécurités "Police nationale " et "gendarmerie nationale"	PLF pour 2018 - Sécurités "Police nationale " et "gendarmerie nationale" - APNM Gendarmerie	2017-10-23 15:00:00	2017-10-23 16:30:00	\N	\N	1	0	\N	\N
213124	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Sécurités "Police nationale " et "gendarmerie nationale"	PLF pour 2018 - Sécurités "Police nationale " et "gendarmerie nationale" - Syndicats police	2017-10-24 17:00:00	2017-10-24 18:30:00	\N	\N	1	0	\N	\N
213126	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Sécurités "Police nationale " et "gendarmerie nationale"	PLF pour 2018 - Sécurités "Police nationale " et "gendarmerie nationale" - DGPN Direction	2017-10-25 15:30:00	2017-10-25 16:30:00	\N	\N	1	0	\N	\N
213128	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Sécurités "Police nationale " et "gendarmerie nationale"	PLF pour 2018 - Sécurités "Police nationale " et "gendarmerie nationale" - Alliance Police nationale	2017-10-25 17:00:00	2017-10-25 18:30:00	\N	\N	1	0	\N	\N
213130	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Sécurités "Sécurité civile"	PLF pour 2018 - Sécurités "Sécurité civile" - Fédération nationale des sapeurs-pompierss	2017-10-25 14:00:00	2017-10-25 15:00:00	\N	\N	1	0	\N	\N
213132	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2018 - Avis budgétaire "Fonction publique"	\N	2017-10-24 14:00:00	2017-10-24 15:20:00	\N	\N	1	0	\N	\N
193658	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL Jordanie	\N	2017-07-11 10:00:00	2017-07-11 10:30:00	\N	\N	1	0	\N	\N
197294	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition 58-2°inclusion bancaire	Audition suite à donner Cour des comptes 58-2°inclusion bancaire	2017-07-18 09:00:00	2017-07-18 11:00:00	2017-07-19 08:51:54	2017-07-19 10:52:41	21	0	\N	\N
197297	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 13 juillet 2017	Réunion du 13 juillet 2017	2017-07-13 09:10:00	2017-07-13 10:45:00	2017-07-13 11:50:27	2017-07-13 15:35:04	11	0	\N	\N
197892	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de Nicolas Hulot	Audition de M. Nicolas Hulot, ministre d¿État, ministre de la Transition écologique et solidaire 	2017-07-18 17:35:00	2017-07-18 19:25:00	2018-05-18 16:00:19	2018-05-18 16:00:26	37	0	\N	\N
201041	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen amendements séance sur l'article 9 au fond sur l'Habilitation dialogue social	Examen amendements de séance sur l'article 9 au fond sur l'Habilitation dialogue social	2017-07-25 14:10:00	2017-07-25 14:15:00	2017-07-26 16:23:23	2017-07-26 17:00:58	23	1	\N	\N
208428	COM_PERMANENTE	AUTRE	\N	FINC	\N	Nominations-désignations rapporteurs - PLF 2018 examen rapports Sport-DAG-AC et PP	Nominations-désignations rapporteurs PLF 2018 PLFSS 2018 et Bâle-Mulhouse - PLF 2018 examen rapports Sport-DAG-AC et PP	2017-10-18 09:05:00	2017-10-18 11:50:00	2017-10-19 09:59:44	2017-10-19 10:34:10	47	0	\N	\N
210100	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2017-10-25 12:45:00	2017-10-25 13:15:00	2017-10-25 15:23:08	2017-10-25 15:24:25	43	0	\N	\N
201055	COM_PERMANENTE	AUTRE	\N	FINC	\N	Communications Contrôles Justice, MIRES SATT et ANR	Communications Contrôles Justice santé des détenus, MIRES SATT et MIRES ANR	2017-07-26 09:35:00	2017-07-26 12:15:00	2017-07-27 09:47:34	2017-07-27 09:48:08	25	1	\N	\N
202812	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2017-07-26 14:45:00	2017-07-26 17:15:00	\N	\N	3	0	\N	\N
204352	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJLO Confiance dans la vie politique	\N	2017-08-04 10:35:00	2017-08-04 11:25:00	2017-08-04 17:25:50	2017-08-04 17:26:25	13	1	\N	\N
204912	GIA	AUCUNE	\N	\N	\N	Rencontre avec une délégation taïwanaise	Echange de vues avec six députés du Yuan législatif de Taïwan, membres du groupe d'amitié Taïwan - France	2017-09-06 10:00:00	2017-09-06 12:00:00	\N	\N	1	0	623	\N
204972	DELEGATION	AUCUNE	\N	\N	COLTER	Echanges de vues	Inflation normative ; lois relatives aux collectivités ; nombre des élus locaux	2017-09-19 15:00:00	2017-09-19 16:00:00	2017-09-19 16:09:50	2018-05-18 16:02:37	5	0	\N	\N
205192	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	groupe de travail Formation au numérique	groupe de travail Formation au numérique	2017-09-20 10:00:00	2017-09-20 12:30:00	\N	\N	1	0	\N	\N
205194	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	groupe de travail Formation au numérique	groupe de travail Formation au numérique	2017-09-20 15:30:00	2017-09-20 19:00:00	\N	\N	1	0	\N	\N
205212	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière avec les membres du Conseil scientifique de l'OPECST	\N	2017-09-27 16:45:00	2017-09-27 19:15:00	2017-09-28 10:47:38	2017-09-29 15:49:32	13	0	\N	\N
205215	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	206	Réunion du bureau de l'OPECST	\N	2017-09-28 12:45:00	2017-09-28 14:30:00	\N	\N	6	0	\N	\N
205687	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Constitution du Bureau + Nomination rapporteurs	\N	2017-10-05 09:35:00	2017-10-05 10:10:00	2017-10-05 15:49:41	2017-10-05 17:24:43	43	0	\N	\N
207999	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 12 octobre 2017	Réunion du 12 octobre 2017	2017-10-12 09:35:00	2017-10-12 10:40:00	2017-10-12 11:26:28	2017-10-12 15:21:47	25	0	\N	\N
208064	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Réforme du droit des contrats	\N	2017-10-17 09:05:00	2017-10-17 09:40:00	2017-10-17 11:45:45	2017-10-17 16:32:33	23	0	\N	\N
208435	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLO Conflits d'intérêts	\N	2017-10-12 10:05:00	2017-10-12 11:45:00	\N	\N	1	0	\N	\N
208437	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	\N	2017-10-12 14:00:00	2017-10-12 14:45:00	\N	\N	1	0	\N	\N
208439	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLO Conflits d'intérêts	\N	2017-10-12 17:00:00	2017-10-12 18:30:00	\N	\N	1	0	\N	\N
208441	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Commission mixte paritaire	PJL Sécurité intérieure et lutte contre le terrorisme	2017-10-09 16:00:00	2017-10-09 17:05:00	\N	\N	1	0	\N	\N
208444	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2017-10-04 15:10:00	2017-10-04 17:10:00	\N	\N	3	0	\N	\N
208448	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2017-10-17 09:15:00	2017-10-17 11:45:00	2017-10-17 11:49:05	2017-10-17 16:32:32	41	0	\N	\N
208449	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2017-10-18 09:30:00	2017-10-18 12:10:00	2017-10-18 12:09:49	2017-10-18 16:43:58	42	0	\N	\N
209764	GIA	AUCUNE	\N	\N	\N	Entretien avec Ralf GRUENERT (UNHCR)	Entretien avec Ralf GRUENERT, représentant du Haut Commissariat aux réfugiés en France	2017-10-18 08:30:00	2017-10-18 09:05:00	\N	\N	1	0	644	\N
210030	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Intelligence artificielle	Débat Intelligence artificielle	2017-10-25 14:30:00	2017-10-25 16:40:00	\N	\N	0	0	\N	\N
210031	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Participation dans l'entreprise	Débat Participation dans l'entreprise	2017-10-25 16:40:00	2017-10-25 18:20:00	\N	\N	0	0	\N	\N
210032	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Logement social	Débat Logement social	2017-10-26 16:40:00	2017-10-26 18:40:00	\N	\N	83	0	\N	\N
210042	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 19 octobre 2017	Réunion du 19 octobre 2017	2017-10-19 09:05:00	2017-10-19 10:05:00	2017-10-19 11:09:40	2017-10-19 13:49:32	20	0	\N	\N
210115	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Redressement de la justice PPLO Redressement de la justice	\N	2017-10-24 09:00:00	2017-10-24 10:30:00	2017-10-25 14:30:05	2017-10-25 14:55:17	31	1	\N	\N
210116	COM_PERMANENTE	AUTRE	\N	LOIS	\N	\N	\N	2017-10-25 09:10:00	2017-10-25 10:20:00	2017-10-25 14:27:53	2017-10-25 14:55:12	44	0	\N	\N
210148	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Affaires européennes	PLF pour 2018 - Affaires européennes - PSRUE	2017-10-19 15:00:00	2017-10-19 16:00:00	\N	\N	1	0	\N	\N
210568	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Conférence interparlementaire article 13 - Tallinn	Conférence interparlementaire article 13 - Tallinn	2017-10-29 18:50:00	2017-10-31 18:10:00	\N	\N	1	0	\N	\N
210613	GIA	AUCUNE	\N	\N	\N	Réception organisée par le Bureau de représentation de Taïpei	\N	2017-10-04 18:30:00	2017-10-04 21:00:00	\N	\N	4	0	623	\N
210622	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition Ministre de la culture	Audition Ministre de la culture	2017-10-25 16:30:00	2017-10-25 18:30:00	2017-10-25 18:45:44	2017-10-26 14:30:31	31	0	\N	\N
212972	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Cohésion des territoires	PLF pour 2018 - Cohésion des territoires - ANAH	2017-10-23 09:45:00	2017-10-23 10:30:00	\N	\N	1	0	\N	\N
212974	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Cohésion des territoires	PLF pour 2018 - Cohésion des territoires - SNI	2017-10-23 10:30:00	2017-10-23 11:30:00	\N	\N	1	0	\N	\N
212976	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Cohésion des territoires	PLF pour 2018 - Cohésion des territoires - Action logement	2017-10-23 15:30:00	2017-10-23 16:15:00	\N	\N	1	0	\N	\N
212977	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Cohésion des territoires	PLF pour 2018 - Cohésion des territoires - Fédération française du bâtiment	2017-10-23 16:15:00	2017-10-23 17:15:00	\N	\N	1	0	\N	\N
212979	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Cohésion des territoires	PLF pour 2018 - Cohésion des territoires - CNAF	2017-10-23 17:15:00	2017-10-23 18:15:00	\N	\N	1	0	\N	\N
212981	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Cohésion des territoires	PLF pour 2018 - Cohésion des territoires - Fondation Abbé Pierre	2017-10-24 09:00:00	2017-10-24 09:45:00	\N	\N	1	0	\N	\N
212983	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Cohésion des territoires	PLF pour 2018 - Cohésion des territoires - Caisse des dépôts et consignations	2017-10-24 09:45:00	2017-10-24 10:30:00	\N	\N	1	0	\N	\N
212985	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Investissements d'avenir	PLF pour 2018 - Investissements d'avenir - ADEME	2017-10-24 15:00:00	2017-10-24 16:00:00	\N	\N	1	0	\N	\N
207696	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Gens du voyage	PPL Gens du voyage	2017-10-31 17:50:00	2017-10-31 19:50:00	\N	\N	66	0	\N	\N
208065	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Nomination rapporteurs + PPL et PPLO Redressement de la justice	\N	2017-10-18 10:05:00	2017-10-18 12:50:00	2017-10-18 18:19:57	2017-10-19 10:34:09	43	1	\N	\N
192772	DELEGATION	AUCUNE	\N	\N	COLTER	Audition de M. Mézard, ministre de la Cohésion des territoires	\N	2017-07-13 09:30:00	2017-07-13 11:00:00	2017-07-13 11:51:03	2017-07-13 15:34:02	9	0	\N	\N
192812	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2017-06-29 11:00:00	2017-06-29 11:20:00	\N	\N	2	0	\N	\N
192815	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2017-07-04 16:30:00	2017-07-04 18:30:00	\N	\N	3	0	\N	\N
192832	ETUDES	AUCUNE	\N	\N	\N	\N	\N	2017-07-05 08:15:00	2017-07-05 09:15:00	\N	\N	32	0	\N	907
193072	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Confiance dans l'action publique	PJL Confiance dans l'action publique	2017-07-11 21:30:00	2017-07-12 01:00:00	\N	\N	119	0	\N	\N
193212	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition Frédérique Vidal	\N	2017-07-11 17:45:00	2017-07-11 19:30:00	2017-07-11 19:39:45	2017-07-12 09:57:30	28	0	\N	\N
196659	COM_PERMANENTE	AUTRE	\N	CDD	\N	Table ronde sur les objectifs de développement durable	Table ronde sur les objectifs de développement durable	2017-07-12 10:00:00	2017-07-12 11:45:00	2017-07-12 16:19:12	2017-07-12 16:24:17	23	0	\N	\N
197413	COM_PERMANENTE	AUTRE	\N	FINC	\N	Rapport avis PJL habilitation dialogue social et contrôle sécurités radars	Rapport avis PJL ordonnaces habilitation dialogue social et contrôle sécurités implantation radars	2017-07-18 17:05:00	2017-07-18 18:35:00	2017-07-19 17:09:13	2017-07-19 17:10:23	22	2	\N	\N
197493	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen PLR 2016, decret d'avance, rapport DOFP et contrôles APD- IAI-Défense	Examen PLR 2016, decret d'avance, rapport DOFP et contrôles APD- IAI-Défense	2017-07-19 08:35:00	2017-07-19 12:45:00	2017-07-20 15:01:54	2017-07-20 15:45:39	31	1	\N	\N
197512	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de M. Robert OPHÈLE, candidat proposé à l'AMF (Article 13)	Audition de M. Robert OPHÈLE, candidat proposé à l'AMF (Article 13)	2017-07-19 14:05:00	2017-07-19 15:30:00	2017-07-20 15:02:14	2017-07-20 15:45:37	23	0	\N	\N
200232	GIA	AUCUNE	\N	\N	\N	Entretien avec Jacques CHAGNON, Président de l'Assemblée nationale du Québec	Entretien avec Jacques CHAGNON, Président de l'Assemblée nationale du Québec	2017-07-19 18:30:00	2017-07-19 19:30:00	\N	\N	1	0	602	\N
200234	GIA	AUCUNE	\N	\N	\N	Entretien avec Jacques CHAGNON, Président de l'Assemblée nationale du Québec	Entretien avec Jacques CHAGNON, Président de l'Assemblée nationale du Québec	2017-07-19 19:30:00	2017-07-19 21:30:00	\N	\N	1	0	602	\N
200372	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Régulation de la vie publique	\N	2017-07-26 09:35:00	2017-07-26 09:45:00	2017-07-26 09:59:35	2017-07-26 16:20:41	19	1	\N	\N
202352	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Entretien avec le ministre des affaires étrangères égyptien	\N	2017-07-26 10:00:00	2017-07-26 11:15:00	\N	\N	4	0	\N	\N
202527	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2017-07-26 17:00:00	2017-07-26 17:50:00	2017-07-26 18:23:33	2017-07-27 09:48:09	19	3	\N	\N
203892	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2018 - Mission Egalité des Territoires et logement	PLF pour 2018 - Mission Egalité des Territoires et logement - Île de France	2017-07-28 16:00:00	2017-07-28 17:00:00	\N	\N	1	0	\N	\N
204333	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJLO Confiance dans la vie politique	PJLO Confiance dans la vie politique	2017-08-04 15:00:00	2017-08-04 17:40:00	\N	\N	1	0	\N	\N
204892	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Ratification ordonnances santé	\N	2017-08-30 10:30:00	2017-08-30 16:30:00	\N	\N	1	0	\N	\N
204932	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2017-07-18 14:30:00	2017-07-18 16:00:00	\N	\N	3	0	\N	\N
205589	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Redressement de la justice PPLO Redressement de la justice	\N	2017-09-28 09:15:00	2017-09-28 12:10:00	\N	\N	2	0	\N	\N
205598	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Réforme du droit des contrats	PJL Réforme du droit des contrats	2017-09-26 14:05:00	2017-09-26 16:25:00	\N	\N	1	0	\N	\N
206480	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Redressement de la justice PPLO Redressement de la justice	\N	2017-10-04 09:40:00	2017-10-04 13:00:00	\N	\N	2	0	\N	\N
207252	DELEGATION	AUCUNE	\N	\N	DSOM	Réunion constitutive de la délégation	Réunion constitutive de la délégation	2017-11-09 10:30:00	2017-11-09 11:45:00	2017-11-09 14:57:14	2017-11-09 16:33:23	30	0	\N	\N
207449	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2017-10-11 09:30:00	2017-10-11 10:30:00	2017-10-11 15:14:04	2017-10-11 16:30:14	48	0	\N	\N
207519	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Droit des contrats	PJL Droit des contrats	2017-10-17 17:50:00	2017-10-17 19:15:00	\N	\N	72	0	\N	\N
207521	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PJL Terrorisme	CMP PJL Terrorisme	2017-10-18 21:00:00	2017-10-18 23:30:00	\N	\N	0	0	\N	\N
207523	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2017-10-17 16:45:00	2017-10-17 17:40:00	\N	\N	313	0	\N	\N
207682	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Droit des contrats	PJL Droit des contrats	2017-10-17 14:30:00	2017-10-17 16:35:00	\N	\N	147	0	\N	\N
207683	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PJL Terrorisme	CMP PJL Terrorisme	2017-10-18 14:30:00	2017-10-18 21:00:00	\N	\N	186	0	\N	\N
207684	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2017-10-24 09:30:00	2017-10-24 12:30:00	\N	\N	49	0	\N	\N
207685	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Sécurité nationale	Débat Sécurité nationale	2017-10-24 14:35:00	2017-10-24 16:35:00	\N	\N	140	0	\N	\N
207686	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Redressement de la justice	PPL Redressement de la justice	2017-10-24 16:40:00	2017-10-24 17:55:00	\N	\N	56	0	\N	\N
207687	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Redressement de la justice	PPL Redressement de la justice	2017-10-24 21:30:00	2017-10-25 01:30:00	\N	\N	54	0	\N	\N
207688	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Aménagement du territoire	Débat Aménagement du territoire	2017-10-25 18:30:00	2017-10-25 20:40:00	\N	\N	89	0	\N	\N
207689	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2017-10-26 15:00:00	2017-10-26 16:05:00	\N	\N	270	0	\N	\N
207690	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Eau potable	PPL Eau potable	2017-10-26 18:40:00	2017-10-26 19:40:00	\N	\N	40	0	\N	\N
207693	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Redressement de la justice	PPL Redressement de la justice	2017-10-31 14:30:00	2017-10-31 16:30:00	\N	\N	22	0	\N	\N
207695	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2017-10-31 16:45:00	2017-10-31 17:45:00	\N	\N	230	0	\N	\N
207699	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Hydrocarbures	PJL Hydrocarbures	2017-11-07 14:35:00	2017-11-07 19:55:00	\N	\N	175	0	\N	\N
207700	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Hydrocarbures	PJL Hydrocarbures	2017-11-07 21:30:00	2017-11-08 00:00:00	\N	\N	73	0	\N	\N
207702	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Hydrocarbures	PJL Hydrocarbures	2017-11-08 14:30:00	2017-11-08 18:00:00	\N	\N	137	0	\N	\N
207703	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Programmation finances publiques	PJL Programmation finances publiques	2017-11-09 10:30:00	2017-11-09 13:20:00	\N	\N	109	0	\N	\N
207704	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2017-11-09 15:00:00	2017-11-09 16:05:00	\N	\N	267	0	\N	\N
207706	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Programmation finances publiques	PJL Programmation finances publiques	2017-11-09 16:15:00	2017-11-09 21:50:00	\N	\N	34	0	\N	\N
207709	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS	PLFSS	2017-11-13 16:00:00	2017-11-13 20:10:00	\N	\N	64	0	\N	\N
192492	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2017-07-12 09:30:00	2017-07-12 12:00:00	2017-07-12 15:17:41	2017-07-12 15:21:10	45	1	\N	\N
192732	GIA	AUCUNE	\N	\N	\N	célébration anniversaire Dalaï Lama	Projection d'un film et débat - célébration anniversaire Dalaï Lama	2017-07-19 14:00:00	2017-07-19 19:00:00	\N	\N	7	0	634	\N
192876	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Préparation des UED	Préparation des UED	2017-07-06 17:00:00	2017-07-06 18:00:00	\N	\N	1	0	\N	\N
192878	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Préparation des UED	Préparation des UED	2017-06-27 16:00:00	2017-06-27 17:00:00	\N	\N	1	0	\N	\N
196535	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2017-07-12 09:05:00	2017-07-12 13:35:00	2017-07-12 14:37:25	2017-07-12 15:21:12	39	0	\N	\N
196812	COM_EURO	AUDRAP	\N	AFEU	\N	Propositions de règlements relatives à l'asile	Propositions de règlements relatives à l'asile	2017-07-12 12:45:00	2017-07-12 14:30:00	\N	\N	2	0	\N	\N
197332	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Normes sportives	Normes sportives	2017-07-13 09:00:00	2017-07-13 11:50:00	\N	\N	2	0	\N	\N
197338	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Normes sportives	\N	2017-03-15 09:30:00	2017-03-15 11:30:00	\N	\N	1	0	\N	\N
197943	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2017-07-18 17:00:00	2017-07-18 19:15:00	2017-07-18 19:18:40	2017-07-19 10:52:43	42	0	\N	\N
197952	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2017-07-19 09:30:00	2017-07-19 12:50:00	2017-07-19 16:07:53	2017-07-19 16:14:33	44	1	\N	\N
197996	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2017-07-20 09:10:00	2017-07-20 11:00:00	2017-07-20 11:03:53	2017-07-20 11:23:37	16	0	\N	\N
198532	DELEGATION	AUCUNE	\N	\N	COLTER	Délégation aux collectivités territoriales - délégation aux entreprises - centres villes 	Délégation aux collectivités territoriales - délégation aux entreprises - revitalisation des centres villes	2017-07-20 08:30:00	2017-07-20 10:10:00	2017-07-20 18:54:11	2017-07-21 09:51:28	23	0	\N	\N
198583	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe	Assemblée générale du groupe	2017-07-18 19:30:00	2017-07-18 21:00:00	\N	\N	15	0	659	\N
198612	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2017-07-19 14:30:00	2017-07-19 16:10:00	2017-07-19 16:34:45	2017-07-19 17:04:07	33	2	\N	\N
198745	GIA	AUCUNE	\N	\N	\N	Entretien de M. Jacques CHAGNON, Président de l'Assemblée nationale du Québec	Entretien de M. Jacques CHAGNON, Président de l'Assemblée nationale du Québec, avec certains membres du groupe	2017-07-18 12:30:00	2017-07-18 14:00:00	\N	\N	7	0	602	\N
199772	COM_EURO	CONTROLE	\N	AFEU	\N	Avenir de la politique agricole commune	\N	2017-07-20 13:30:00	2017-07-20 14:55:00	2017-07-20 16:12:07	2017-07-20 16:34:18	25	0	\N	\N
200592	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	COM AFD	\N	2017-07-19 15:00:00	2017-07-19 16:00:00	\N	\N	2	0	\N	\N
200595	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière	Audition du Centre scientifique et technique du bâtiment (CSTB) 	2017-07-26 17:30:00	2017-07-26 20:10:00	2017-07-27 16:04:49	2017-07-27 17:05:10	15	0	\N	\N
204952	COM_EURO	AUDRAP	\N	AFEU	\N	Audition "Résolution et supervision des chambres de compensation"	Audition "Résolution et supervision des chambres de compensation"	2017-09-12 10:00:00	2017-09-12 11:20:00	\N	\N	1	0	\N	\N
205093	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Réforme du droit des contrats	\N	2017-09-13 10:30:00	2017-09-13 12:45:00	\N	\N	1	0	\N	\N
205095	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Réforme du droit des contrats	\N	2017-09-13 14:40:00	2017-09-13 18:30:00	\N	\N	1	0	\N	\N
205352	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Redressement de la justice PPLO Redressement de la justice	\N	2017-09-20 14:00:00	2017-09-20 19:30:00	\N	\N	2	0	\N	\N
206477	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2017-10-11 09:45:00	2017-10-11 12:45:00	2017-10-11 14:26:39	2017-10-11 14:47:38	40	0	\N	\N
206478	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Anciens combattants	PLF pour 2018 - Anciens combattants - Audition du ministère des Armées	2017-10-03 09:00:00	2017-10-03 10:15:00	\N	\N	1	0	\N	\N
206483	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Anciens combattants - CIVS - 2017	Contrôle Anciens combattants - CIVS - 2017 - Conseil ventes  + INHA + Généalogistes de France	2017-10-04 14:15:00	2017-10-04 17:30:00	\N	\N	1	0	\N	\N
206485	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2017-10-10 18:00:00	2017-10-10 19:55:00	2017-10-11 09:55:11	2017-10-11 14:47:34	42	0	\N	\N
206512	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Réforme du droit des contrats	\N	2017-10-04 14:05:00	2017-10-04 17:45:00	\N	\N	1	0	\N	\N
206514	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Environnement	PJL Environnement	2017-10-10 14:30:00	2017-10-10 16:30:00	\N	\N	174	0	\N	\N
206515	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2017-10-10 16:45:00	2017-10-10 18:00:00	\N	\N	299	0	\N	\N
206516	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Environnement	PJL Environnement	2017-10-10 17:55:00	2017-10-10 19:35:00	\N	\N	79	0	\N	\N
207294	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de M. Henri POUPART-LAFARGE PDG Alstom	Audition de M. Henri POUPART-LAFARGE PDG Alstom	2017-10-11 15:15:00	2017-10-11 16:40:00	2017-10-11 17:46:46	2017-10-12 11:10:59	49	0	\N	\N
207712	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFR 2017	PLFR 2017	2017-11-14 14:35:00	2017-11-14 16:15:00	\N	\N	125	0	\N	\N
207713	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2017-11-14 16:45:00	2017-11-14 17:40:00	\N	\N	305	0	\N	\N
207714	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS	PLFSS	2017-11-14 17:50:00	2017-11-14 19:30:00	\N	\N	95	0	\N	\N
207715	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS	PLFSS	2017-11-14 21:35:00	2017-11-15 00:25:00	\N	\N	107	0	\N	\N
207716	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS	PLFSS	2017-11-15 14:35:00	2017-11-15 19:55:00	\N	\N	167	0	\N	\N
207717	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS	PLFSS	2017-11-15 21:30:00	2017-11-16 00:25:00	\N	\N	89	0	\N	\N
206486	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2017-10-11 10:30:00	2017-10-11 10:50:00	2017-10-11 10:54:35	2017-10-11 16:30:15	48	0	\N	\N
206517	CMP	AUTRE	\N	TERRORISME	\N	PJL Sécurité intérieure et lutte contre le terrorisme	PJL Sécurité intérieure et lutte contre le terrorisme	2017-10-09 16:00:00	2017-10-09 17:05:00	\N	\N	9	0	\N	\N
207718	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS	PLFSS	2017-11-16 10:30:00	2017-11-16 13:00:00	\N	\N	93	0	\N	\N
207719	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS	PLFSS	2017-11-16 14:30:00	2017-11-16 20:10:00	\N	\N	103	0	\N	\N
207720	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS	PLFSS	2017-11-16 21:40:00	2017-11-17 00:30:00	\N	\N	48	0	\N	\N
207721	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS	PLFSS	2017-11-17 09:40:00	2017-11-17 13:00:00	\N	\N	55	0	\N	\N
207722	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS	PLFSS	2017-11-17 14:30:00	2017-11-17 19:30:00	\N	\N	44	0	\N	\N
208520	GIA	AUCUNE	\N	\N	\N	50e anniversaire de l'ASEAN	Réception en l'honneur du 50e anniversaire de la création de l'Association of Southeast Asian Nations (ASEAN)	2017-10-16 18:00:00	2017-10-16 20:00:00	\N	\N	1	0	609	\N
210043	DELEGATION	AUCUNE	\N	\N	COLTER	Réunion constitutive du Bureau de la Délégation	\N	2017-10-26 09:30:00	2017-10-26 10:30:00	2017-10-26 13:30:23	2017-10-26 14:31:07	21	0	\N	\N
210105	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2017-10-18 16:00:00	2017-10-18 18:00:00	\N	\N	2	0	\N	\N
210145	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2018 - Examen Mission budget UE et Audition MEZARD finances locales	PLF pour 2018 - Examen Mission budget UE et Audition MEZARD finances locales	2017-10-24 16:00:00	2017-10-24 18:45:00	2017-10-25 16:55:16	2017-10-25 16:59:28	42	0	\N	\N
210146	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF 2018 - Programme 105	\N	2017-10-19 11:00:00	2017-10-19 12:35:00	\N	\N	1	0	\N	\N
210151	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2018 - Audition GOURAULT	PLF pour 2018 - Audition GOURAULT - Finances locales	2017-10-25 08:05:00	2017-10-25 09:35:00	2017-10-25 16:55:02	2017-10-25 16:59:26	35	0	\N	\N
210455	QUESTURE	AUCUNE	\N	\N	\N	\N	\N	2017-10-17 14:00:00	2017-10-17 16:45:00	\N	\N	3	0	\N	\N
210459	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2017-10-17 17:30:00	2017-10-17 19:30:00	\N	\N	3	0	\N	\N
210894	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation du ministère de la Justice de Mongolie	Accueil d'une délégation du ministère de la Justice de Mongolie, conduite  par M.Sandag BYAMBATSOGT 	2017-10-24 13:00:00	2017-10-24 14:30:00	\N	\N	2	0	612	\N
211158	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2017-10-25 18:00:00	2017-10-25 19:00:00	\N	\N	2	0	\N	\N
211160	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2017-11-07 16:30:00	2017-11-07 19:30:00	\N	\N	3	0	\N	\N
211162	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2017-11-09 14:00:00	2017-11-09 15:00:00	\N	\N	1	0	\N	\N
211167	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2017-11-02 09:30:00	2017-11-02 12:30:00	\N	\N	1	0	\N	\N
211169	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2017-11-09 11:30:00	2017-11-09 12:30:00	\N	\N	1	0	\N	\N
192474	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Création de l'établissement public Paris La Défense	\N	2017-07-05 14:00:00	2017-07-05 16:10:00	\N	\N	1	0	\N	\N
196858	GIA	AUCUNE	\N	\N	\N	Visite 	Visite d'une délégation de parlementaires iraniens	2017-07-12 14:00:00	2017-07-12 16:30:00	\N	\N	5	0	628	\N
197218	COM_PERMANENTE	AUTRE	\N	CDD	\N	Audition de M. Nicolas Hulot	Audition de M. Nicolas Hulot	2017-07-12 16:30:00	2017-07-12 18:20:00	2017-07-13 14:14:10	2017-07-13 15:26:08	21	0	\N	\N
197672	COM_EURO	DEPLACEMENT	\N	AFEU	\N	Politique méditerranéenne de l'Union européenne (le cas de l'Algérie)	\N	2017-07-06 07:30:00	2017-07-09 22:15:00	\N	\N	1	0	\N	\N
198065	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2017-07-19 10:00:00	2017-07-19 11:20:00	2017-07-19 14:19:15	2017-07-19 15:39:58	31	3	\N	\N
198066	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2017-07-19 16:30:00	2017-07-19 18:00:00	2017-07-19 18:07:55	2017-07-20 09:23:12	26	0	\N	\N
199392	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition sur la gouvernance et l'approfondissement de la zone euro	Audition sur la gouvernance et l'approfondissement de la zone euro	2017-07-20 09:25:00	2017-07-20 11:00:00	2017-07-20 14:25:08	2017-07-20 15:45:35	22	0	\N	\N
200532	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ambassadeur de Mongolie en France, son Excellence Batsaikhan MUNDAGBAATAR	Entretien avec l'ambassadeur de Mongolie en France, son Excellence Batsaikhan MUNDAGBAATAR	2017-07-18 12:45:00	2017-07-18 14:00:00	\N	\N	1	0	612	\N
200572	COM_PERMANENTE	DEPLACEMENT	\N	CAE	\N	RI Ville	Rapport information application de la loi de programmation pour la ville et la cohésion urbaine	2017-07-20 06:00:00	2017-07-20 21:00:00	\N	\N	2	0	\N	\N
200575	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Ouverture à la concurrence ferroviaire	PPL Ouverture à la concurrence ferroviaire	2017-07-19 15:00:00	2017-07-19 16:00:00	\N	\N	2	0	\N	\N
203697	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation de sénateurs jordaniens	Accueil d'une délégation de sénateurs jordaniens	2017-07-24 13:00:00	2017-07-24 15:00:00	\N	\N	1	0	659	\N
203772	COM_PERMANENTE	AUDRAP	\N	CAE	\N	RI Investissement locatif	RI Investissement locatif	2017-07-13 08:30:00	2017-07-13 10:00:00	\N	\N	1	0	\N	\N
203912	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2017-08-01 14:35:00	2017-08-01 16:05:00	2017-08-01 16:09:04	2017-08-01 16:34:49	24	0	\N	\N
205032	DELEGATION	AUDRAP	\N	\N	COLTER	DCT - Revitalisation centres-villes - Audition Confédération des commerçants de France	DCT - Revitalisation centres-villes - Audition Confédération des commerçants de France	2017-09-13 11:00:00	2017-09-13 12:20:00	\N	\N	2	0	\N	\N
205054	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	groupe de travail Formation au numérique	groupe de travail Formation au numérique	2017-09-12 15:00:00	2017-09-12 18:00:00	\N	\N	1	0	\N	\N
205056	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	groupe de travail Formation au numérique	groupe de travail Formation au numérique	2017-09-13 09:30:00	2017-09-13 13:00:00	\N	\N	1	0	\N	\N
205058	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	groupe de travail Formation au numérique	groupe de travail Formation au numérique	2017-09-13 14:30:00	2017-09-13 15:30:00	\N	\N	1	0	\N	\N
205232	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Audition 58-2 Programme "Habiter mieux"	Audition 58-2 Programme "Habiter mieux" - Audition de la Cour des comptes	2017-09-19 14:30:00	2017-09-19 15:30:00	\N	\N	1	0	\N	\N
205252	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Investissements d'avenir	PLF pour 2018 - Investissements d'avenir - Audition de M. Jean Pisani-Ferry	2017-09-20 10:00:00	2017-09-20 11:00:00	\N	\N	1	0	\N	\N
205254	COM_EURO	AUDRAP	\N	AFEU	\N	Audition "Résolution et supervision des chambres de compensation"	Audition "Résolution et supervision des chambres de compensation"	2017-09-21 14:00:00	2017-09-21 15:30:00	\N	\N	1	0	\N	\N
205292	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Ratification ordonnances santé	\N	2017-09-26 10:00:00	2017-09-26 12:30:00	\N	\N	1	0	\N	\N
205294	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Ratification ordonnances santé	\N	2017-09-26 14:30:00	2017-09-26 18:00:00	\N	\N	1	0	\N	\N
205612	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Évolution de la taxe d'habitation - Présentation réponses et échange de vues	Évolution de la taxe d'habitation - Présentation réponses questionnaire et échange de vues	2017-09-26 14:30:00	2017-09-26 16:00:00	\N	\N	8	0	\N	\N
205621	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2017-10-05 12:10:00	2017-10-05 13:00:00	2017-10-05 15:00:49	2017-10-05 15:39:28	46	0	\N	\N
205623	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	AP-OTAN	Ottawa	2017-09-12 15:30:00	2017-09-17 08:00:00	\N	\N	1	0	\N	\N
205625	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	AP-OTAN	Corée du Sud	2017-09-09 21:00:00	2017-09-15 13:50:00	\N	\N	1	0	\N	\N
205627	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	UED	Université d'été de la Défense Toulon	2017-09-03 20:00:00	2017-09-05 20:00:00	\N	\N	12	0	\N	\N
205652	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière constitutive de l'OPECST	Réunion constitutive de l'OPECST	2017-11-09 08:40:00	2017-11-09 10:20:00	2017-11-09 12:51:26	2017-11-09 16:33:21	25	1	\N	\N
205676	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Polynésie française	MI Polynésie française	2017-06-19 15:00:00	2017-06-19 16:00:00	\N	\N	3	0	\N	\N
205680	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Polynésie française	MI Polynésie française	2017-10-03 15:30:00	2017-10-03 16:30:00	\N	\N	2	0	\N	\N
206075	SEANCE_PLENIERE	OUV_SESSION	\N	\N	\N	Election du Président du Sénat	Ouverture de session	2017-10-02 15:00:00	2017-10-02 17:40:00	\N	\N	337	0	\N	\N
208617	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2017-10-17 18:00:00	2017-10-17 19:00:00	\N	\N	2	0	\N	\N
209616	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion	Réunion	2017-10-18 10:30:00	2017-10-18 12:30:00	2017-10-18 12:43:16	2017-10-18 16:43:45	40	1	\N	\N
210109	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de finances 2018	Loi de finances 2018 (Audiovisuel)	2017-10-17 14:30:00	2017-10-17 16:00:00	\N	\N	1	0	\N	\N
210111	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de finances 2018	Loi de finances 2018 (Audiovisuel)	2017-10-17 18:00:00	2017-10-17 19:30:00	\N	\N	1	0	\N	\N
210113	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de finances 2018	Loi de finances 2018 (Audiovisuel)	2017-10-18 14:45:00	2017-10-18 17:30:00	\N	\N	1	0	\N	\N
210121	GIA	AUCUNE	\N	\N	\N	Déplacement en Ukraine	\N	2017-09-10 14:00:00	2017-09-15 19:00:00	\N	\N	3	0	530	\N
210125	GIA	AUCUNE	\N	\N	\N	Déjeuner avec l'ambassadeur d'Ukraine en France	\N	2017-09-28 12:30:00	2017-09-28 13:45:00	\N	\N	1	0	530	\N
210127	GIA	AUCUNE	\N	\N	\N	Rencontre avec le conseiller diplomatique du Président de la République	\N	2017-10-11 10:00:00	2017-10-11 10:30:00	\N	\N	1	0	530	\N
210132	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2017-10-25 09:05:00	2017-10-25 12:20:00	2017-10-25 12:20:20	2017-10-25 14:55:15	43	0	\N	\N
210164	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL HYDROCARBURES	\N	2017-10-17 14:00:00	2017-10-17 16:15:00	\N	\N	2	0	\N	\N
210167	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL HYDROCARBURES	\N	2017-10-18 09:00:00	2017-10-18 11:30:00	\N	\N	1	0	\N	\N
210169	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL HYDROCARBURES	\N	2017-10-18 14:45:00	2017-10-18 18:15:00	\N	\N	2	0	\N	\N
210900	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition  Rapporteur UNAPEI	UNAPEI	2017-10-24 14:30:00	2017-10-24 15:45:00	\N	\N	3	0	\N	\N
210902	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	SYNERPA	\N	2017-10-24 15:45:00	2017-10-24 17:00:00	\N	\N	2	0	\N	\N
210904	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition CNSA	\N	2017-10-24 17:00:00	2017-10-24 18:15:00	\N	\N	4	0	\N	\N
210908	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	DGCS	Audition DGCS	2017-10-24 18:15:00	2017-10-24 19:30:00	\N	\N	2	0	\N	\N
210968	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	ADF	ADF	2017-10-25 14:30:00	2017-10-25 15:45:00	\N	\N	1	0	\N	\N
210970	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	ARS	\N	2017-10-26 09:00:00	2017-10-26 10:00:00	\N	\N	1	0	\N	\N
210972	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	NEXEM	\N	2017-10-26 11:00:00	2017-10-26 12:00:00	\N	\N	1	0	\N	\N
210974	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	APF	\N	2017-10-26 13:30:00	2017-10-26 15:00:00	\N	\N	2	0	\N	\N
210976	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	EHPAD	\N	2017-10-31 14:00:00	2017-10-31 15:15:00	\N	\N	1	0	\N	\N
210978	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	FHF	\N	2017-10-31 15:15:00	2017-10-31 16:00:00	\N	\N	1	0	\N	\N
210980	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	FEHAP	\N	2017-10-31 17:15:00	2017-10-31 19:00:00	\N	\N	1	0	\N	\N
212116	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	PROS	Réunion du Bureau de la Prospective	Réunion des membres du Bureau de la Délégation à la Prospective	2017-11-08 12:45:00	2017-11-08 14:00:00	\N	\N	14	0	\N	\N
212117	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 26 octobre 2017	Réunion du 26 octobre 2017	2017-10-26 09:05:00	2017-10-26 11:00:00	2017-10-26 13:36:23	2017-10-26 14:31:49	24	0	\N	\N
192515	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL "Habilitation droit du travail"	\N	2017-07-11 15:00:00	2017-07-11 17:45:00	\N	\N	8	0	\N	\N
192679	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL sécurité intérieure et lutte contre le terrorisme	PJL sécurité intérieure et lutte contre le terrorisme	2017-07-06 11:45:00	2017-07-06 12:15:00	\N	\N	1	0	\N	\N
192682	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Recherche et enseignement supérieur 2017 - Agence nationale de la Recherche (ANR)	Contrôle Recherche et enseignement supérieur 2017 - 3 auditions (CGI, CNRS & INSERM)	2017-07-05 17:00:00	2017-07-05 19:30:00	\N	\N	1	0	\N	\N
192685	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL sécurité intérieure et lutte contre le terrorisme	PJL sécurité intérieure et lutte contre le terrorisme	2017-06-28 15:00:00	2017-06-28 19:30:00	\N	\N	1	0	\N	\N
192686	MECSS	AUDRAP	\N	\N	MECSS	pe	\N	2017-07-12 16:00:00	2017-07-12 17:00:00	\N	\N	1	0	\N	\N
192757	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Formation au numérique	Formation au numérique	2017-07-11 09:45:00	2017-07-11 11:30:00	\N	\N	1	0	\N	\N
192774	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen rapport PJL 491 et texte et Controles IFRE, Rembts et Degrevts et France Muséums	Examen rapport PJL 491 et texte et Controles IFRE, Remboursements et Dégrèvements et France Muséums	2017-07-12 09:00:00	2017-07-12 11:40:00	2017-07-13 09:19:36	2017-07-13 11:00:44	28	2	\N	\N
192792	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition des ministres de l'économie et des finances et des comptes publics	Audition des ministres de l'économie et des finances et des comptes publics - PJL réglement	2017-07-12 18:05:00	2017-07-12 20:10:00	2017-07-13 16:43:33	2017-07-13 17:08:54	28	0	\N	\N
195879	DELEGATION	AUCUNE	\N	\N	211	 Audition de Mme Marlène Schiappa, secrétaire chargée de l'égalité femmes/hommes	\N	2017-07-20 09:00:00	2017-07-20 11:00:00	2017-07-27 14:22:08	2017-07-27 14:22:12	18	0	\N	\N
196430	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Préparation des UED	Préparation des UED	2017-07-11 16:00:00	2017-07-11 16:30:00	\N	\N	2	0	\N	\N
196815	GIA	AUCUNE	\N	\N	\N	Entretien à l'ambassade d'Allemagn e	Entretien à l'ambassade d'Allemagn e	2017-07-12 12:30:00	2017-07-12 14:30:00	\N	\N	6	0	604	\N
199192	GIA	AUCUNE	\N	\N	\N	Audition de Mme Vera el-Khoury-Lacoeuilhe, candidate à la direction générale de l'UNESCO	Audition de Mme Vera el-Khoury-Lacoeuilhe	2017-07-19 12:30:00	2017-07-19 14:15:00	\N	\N	6	0	597	\N
199802	COM_PERMANENTE	AUTRE	\N	CDD	\N	Audition de Mme Élisabeth Borne 	Audition de Mme Élisabeth Borne, ministre de la transition écologique et solidaire, chargée des transports 	2017-07-20 11:00:00	2017-07-20 12:50:00	2017-07-20 16:31:23	2017-07-20 16:35:13	22	0	\N	\N
200612	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PJL Renforcer le dialogue social	\N	2017-07-24 15:45:00	2017-07-24 15:50:00	2017-07-24 15:55:38	2017-07-24 17:14:07	18	1	\N	\N
267297	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Mission "Routes de la soie"	\N	2018-04-10 14:15:00	2018-04-10 15:00:00	\N	\N	2	0	\N	\N
200613	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PJL Renforcer le dialogue social	\N	2017-07-25 09:00:00	2017-07-25 10:00:00	2017-07-25 10:07:58	2017-07-25 15:16:14	33	0	\N	\N
200614	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PJL Renforcer le dialogue social	\N	2017-07-25 13:30:00	2017-07-25 14:15:00	2017-07-26 09:52:59	2017-07-26 09:53:02	34	1	\N	\N
200632	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PJL Renforcer le dialogue social	\N	2017-07-25 18:30:00	2017-07-25 18:55:00	2017-07-25 18:59:25	2017-07-26 09:14:16	36	1	\N	\N
200633	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2017-07-26 09:05:00	2017-07-26 12:20:00	2017-07-26 12:23:01	2017-07-26 16:20:40	36	0	\N	\N
201772	COM_PERMANENTE	AUTRE	\N	CDD	\N	Audition de M. Jacques MÉZARD	Audition de M. Jacques MÉZARD, Ministre de la Cohésion des territoires	2017-07-25 16:30:00	2017-07-25 18:40:00	2018-05-18 16:01:58	2018-05-18 16:02:04	25	0	\N	\N
203436	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 27 juillet 2017	\N	2017-07-27 08:35:00	2017-07-27 10:45:00	2017-07-27 11:27:26	2017-07-27 11:41:40	11	0	\N	\N
204672	QUESTURE	AUCUNE	\N	\N	\N	\N	Conseil de Questure	2017-08-01 15:00:00	2017-08-01 16:30:00	\N	\N	3	0	\N	\N
205453	GIA	AUCUNE	\N	\N	\N	entretien avec une délégation du ministère indonésien de l'économie 	entretien avec une délégation du ministère indonésien de l'économie sur le thème de la production d'huile de palme	2017-09-26 11:20:00	2017-09-26 12:00:00	\N	\N	4	0	653	\N
205526	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion de la délégation aux entreprises	Compte rendu déplacement Guyane, Communication Mme Loisier réforme droit des contrats	2017-09-27 14:35:00	2017-09-27 16:05:00	2017-09-27 18:34:18	2017-09-29 15:49:31	13	0	\N	\N
205622	COM_PERMANENTE	AUTRE	\N	FINC	\N	Élection du bureau de la commission	Élection du bureau de la commission	2017-10-05 09:05:00	2017-10-05 09:45:00	2018-05-18 16:03:34	2018-05-18 16:03:41	44	0	\N	\N
205672	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2017-10-05 11:00:00	2017-10-05 13:00:00	2017-10-06 11:28:05	2017-10-06 11:48:37	49	0	\N	\N
205673	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Redressement de la justice PPLO Redressement de la justice	\N	2017-10-03 14:20:00	2017-10-03 17:50:00	\N	\N	2	0	\N	\N
205693	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion constitutive	Réunion constitutive	2017-10-05 11:30:00	2017-10-05 12:20:00	2017-10-05 12:55:28	2017-10-05 14:19:37	46	0	\N	\N
206654	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	3 PJL Santé	3 PJL Santé	2017-10-11 14:30:00	2017-10-11 17:30:00	\N	\N	115	0	\N	\N
206656	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Avenir de l'UE	Débat Avenir de l'UE	2017-10-11 17:30:00	2017-10-11 19:50:00	\N	\N	96	0	\N	\N
206803	GIA	AUCUNE	\N	\N	\N	Entretien avec le Gouverneur de Louxor Mohamed BADR	Entretien sur la réforme territoriale en Egypte	2017-10-03 15:30:00	2017-10-03 16:30:00	\N	\N	1	0	617	\N
206810	GIA	AUCUNE	\N	\N	\N	Entretien avec le Gouverneur de Louxor Mohamed BADR	Dîner à l'invitation du Groupe d'amitié	2017-10-03 20:00:00	2017-10-03 23:00:00	\N	\N	4	0	617	\N
207231	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2017-10-10 14:30:00	2017-10-10 16:50:00	\N	\N	3	0	\N	\N
208708	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Représentation des communes déléguées	\N	2017-10-17 09:45:00	2017-10-17 10:45:00	\N	\N	2	0	\N	\N
210118	GIA	AUCUNE	\N	\N	\N	déplacement en Egypte pour la commémoration de la bataille d'El-Alamein 	déplacement en Egypte pour la commémoration de la bataille d'El-Alamein invitée par la Secrétaire d'Etat aux anciens com	2017-10-20 09:00:00	2017-10-22 17:00:00	\N	\N	1	0	617	\N
210129	DELEGATION	AUCUNE	\N	\N	211	Réunion constitutive de la délégation aux droits fes femmes	Réunion constitutive de la délégation aux droits fes femmes	2017-10-26 11:30:00	2017-10-26 12:30:00	2017-10-26 17:26:00	2017-10-26 17:35:21	25	0	\N	\N
210154	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Défense	PLF pour 2018 - Défense - Auditions SGA - DB - EMA	2017-10-19 14:00:00	2017-10-19 17:30:00	\N	\N	1	0	\N	\N
210176	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Convention fiscale Bâle-Mulhouse	Convention fiscale Bâle-Mulhouse - Audition DLF DGAC MAEE Bâle-Mulhouse	2017-10-20 10:00:00	2017-10-20 12:00:00	\N	\N	1	0	\N	\N
210178	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Investissements d'avenir	PLF pour 2018 - Investissements d'avenir - Audition Agence Nationale de la Recherche (ANR)	2017-10-20 15:00:00	2017-10-20 16:20:00	\N	\N	1	0	\N	\N
211714	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL accord aérien UE-Israël	\N	2017-10-25 15:05:00	2017-10-25 15:50:00	\N	\N	1	0	\N	\N
212114	GIA	AUCUNE	\N	\N	\N	Rencontre avec M. Rami Adwan, ambassadeur du Liban en France	Rencontre avec M. Rami Adwan, ambassadeur du Liban en France	2017-10-26 10:30:00	2017-10-26 11:30:00	\N	\N	1	0	644	\N
212987	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Investissements d'avenir	PLF pour 2018 - Investissements d'avenir - Cabinet Premier ministre	2017-10-24 19:00:00	2017-10-24 20:00:00	\N	\N	1	0	\N	\N
212997	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Investissements d'avenir	PLF pour 2018 - Investissements d'avenir - CGI	2017-10-25 14:15:00	2017-10-25 15:15:00	\N	\N	1	0	\N	\N
213006	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Investissements d'avenir	PLF pour 2018 - Investissements d'avenir - BPIFrance	2017-10-26 09:30:00	2017-10-26 10:20:00	\N	\N	1	0	\N	\N
213014	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Investissements d'avenir	PLF pour 2018 - Investissements d'avenir - Caisse des dépôts et consignations	2017-10-26 10:20:00	2017-10-26 11:10:00	\N	\N	1	0	\N	\N
213049	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen rapport amendements et élaboration texte LPFP 2018-2022	Examen du rapport amendements et élaboration texte PJL de programmation des finances publiques pour années 2018 à 2022	2017-10-31 08:35:00	2017-10-31 10:20:00	2017-10-31 14:55:49	2017-10-31 18:12:42	36	0	\N	\N
192872	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF 2018 - Programme 212	PLF 2018 - Programme 212	2017-07-04 14:00:00	2017-07-04 14:45:00	\N	\N	1	0	\N	\N
192874	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Russie	Délgation DGRIS - Audition Russie	2017-07-06 10:00:00	2017-07-06 12:00:00	\N	\N	1	0	\N	\N
192892	GIA	AUCUNE	\N	\N	\N	Visite de M. Anowarul HAQUE du Bangladesh	Visite de M. Anowarul HAQUE du Bangladesh	2017-07-06 08:30:00	2017-07-06 09:30:00	\N	\N	1	0	609	\N
194793	GIA	AUCUNE	\N	\N	\N	Audition de l'Ambassadeur d'Arabie saoudite 	Audition de l'Ambassadeur d'Arabie saoudite sur la crise entre les pays du CCEAG	2017-07-06 09:00:00	2017-07-06 10:15:00	\N	\N	3	0	661	\N
197404	DELEGATION	AUCUNE	\N	\N	COLTER	Audition de Mme Jacqueline GOURAULT	Audition de Mme Jacqueline GOURAULT, Ministre auprès du ministre de l'Intérieur	2017-07-20 13:45:00	2017-07-20 15:00:00	2017-07-20 18:51:34	2017-07-21 09:51:25	15	0	\N	\N
197532	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Sécurité intérieure et lutte contre le terrorisme	\N	2017-07-18 09:10:00	2017-07-18 10:20:00	2017-07-18 12:01:55	2017-07-18 15:17:35	20	4	\N	\N
197533	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Sécurité intérieure + PJL Paris La Défense	\N	2017-07-19 10:10:00	2017-07-19 10:25:00	2017-07-19 10:54:05	2017-07-19 15:40:04	25	1	\N	\N
197552	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2017-07-18 09:30:00	2017-07-18 11:10:00	2017-07-18 12:13:07	2017-07-18 15:17:36	13	0	\N	\N
197553	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2017-07-18 16:30:00	2017-07-18 18:10:00	2017-07-18 18:18:25	2017-07-19 10:52:42	30	0	\N	\N
197554	COM_EURO	AUDRAP	\N	AFEU	\N	Propositions de règlements relatives à l'asile	Propositions de règlements relatives à l'asile	2017-07-17 14:35:00	2017-07-17 15:45:00	\N	\N	1	0	\N	\N
198656	COM_PERMANENTE	AUTRE	\N	CDD	\N	\N	\N	2017-07-19 09:30:00	2017-07-19 11:50:00	2017-07-19 16:01:25	2017-07-19 16:14:32	30	0	\N	\N
199234	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 20 juillet 2017 - 8h30	Réunion du 20 juillet 2017 - 8h30	2017-07-20 08:35:00	2017-07-20 09:15:00	2017-07-20 11:39:33	2017-07-20 11:51:59	12	0	\N	\N
199263	COM_EURO	CONTROLE	\N	AFEU	\N	Table ronde du 20 juillet 2017	Table ronde du 20 juillet 2017	2017-07-20 09:25:00	2017-07-20 11:00:00	2017-07-20 11:38:33	2017-07-20 11:52:00	22	0	\N	\N
204692	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2018 - Relations avec les collectivités territoriales	PLF pour 2018 - Relations avec les collectivités territoriales - Assemblée Nationale	2017-08-01 09:30:00	2017-08-01 11:30:00	\N	\N	1	0	\N	\N
205312	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	groupe de travail Formation au numérique	groupe de travail Formation au numérique	2017-09-21 09:00:00	2017-09-21 13:00:00	\N	\N	1	0	\N	\N
205683	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2017-09-26 15:00:00	2017-09-26 17:10:00	\N	\N	3	0	\N	\N
205692	COM_PERMANENTE	AUTRE	\N	CAE	\N	Constitution du bureau	Constitution du bureau de la commission des affaires économiques	2017-10-05 10:00:00	2017-10-05 10:35:00	2018-05-18 16:04:01	2018-05-18 16:04:09	46	0	\N	\N
206487	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	Réunion	Reconstitution du Bureau	2017-10-05 12:30:00	2017-10-05 13:00:00	2017-10-06 11:38:01	2017-10-06 11:48:02	6	0	\N	\N
206727	GIA	AUCUNE	\N	\N	\N	Entretien avec S.E. M. Guillaume ROUSSON, Ambassadeur de France en Bosnie-Herzégovine 	Entretien avec S.E. M. Guillaume ROUSSON, Ambassadeur de France en Bosnie-Herzégovine 	2017-10-10 08:30:00	2017-10-10 09:30:00	\N	\N	3	0	674	\N
206755	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Redressement de la justice PPLO Redressement de la justice	\N	2017-10-10 14:30:00	2017-10-10 15:05:00	\N	\N	1	0	\N	\N
207291	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion 	Réunion	2017-10-11 11:00:00	2017-10-11 12:45:00	2017-10-11 12:55:32	2017-10-11 14:47:40	37	0	\N	\N
207389	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Pascal HECTOR, ministre plénipotentiaire de l'Ambassade d'Allemagne sur 	Entretien avec M. Pascal HECTOR, ministre plénipotentiaire de l'Ambassade d'Allemagne sur le résultat des élections légi	2017-10-11 08:00:00	2017-10-11 09:15:00	\N	\N	16	0	604	\N
208012	GIA	AUCUNE	\N	\N	\N	Entretien à l'Ambassade d'Argentine	Entretien avec Mme Maria Laura LEGUIZAMON, Sénatrice argentine, Présidente du groupe d¿amitié Argentine-France	2017-10-11 19:00:00	2017-10-11 21:00:00	\N	\N	2	0	978	\N
208015	GIA	AUCUNE	\N	\N	\N	Entretien de M. Joël Guerriau avec le Président de la commission des lois iranien	Entretien de M. Joël Guerriau avec le Président de la commission des lois iranien	2017-10-10 17:30:00	2017-10-10 18:30:00	\N	\N	1	0	628	\N
208080	GIA	AUCUNE	\N	\N	\N	Entretien à l'Élysée avec Mme Ahlem GHARBI	Entretien avec Mme Ahlem GHARBI, conseillère du Président de la République pour l'Afrique du Nord et le Moyen-Orient	2017-10-10 12:00:00	2017-10-10 13:00:00	\N	\N	1	0	644	\N
210045	DELEGATION	AUCUNE	\N	\N	PROS	Réunion constitutive de la Délégaton à la Prospective	Réunion constitutive de la Délégaton sénatoriale  à la Prospective	2017-10-26 08:35:00	2017-10-26 09:20:00	2017-10-26 13:21:12	2017-10-26 14:31:06	24	0	\N	\N
210103	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2017-10-26 16:00:00	2017-10-26 18:00:00	\N	\N	1	0	\N	\N
210162	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Cohésion des territoires	PLF pour 2018 - Cohésion des territoires - auditions ANRU - CGET et Crédit foncier	2017-10-19 15:15:00	2017-10-19 18:00:00	\N	\N	1	0	\N	\N
210172	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Haut comité d'évaluation de la condition militaire	\N	2017-10-20 15:00:00	2017-10-20 16:00:00	\N	\N	3	0	\N	\N
210180	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Accueil des gens du voyage	\N	2017-10-17 14:00:00	2017-10-17 20:00:00	\N	\N	1	0	\N	\N
210182	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de M. Nicolas Hulot Ministre de la transition écologique et solidaire	Audition de M. Nicolas Hulot Ministre de la transition écologique et solidaire	2017-10-24 16:30:00	2017-10-24 18:30:00	2017-10-25 15:06:54	2017-10-25 15:08:47	40	0	\N	\N
210183	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de M. Sébastien Soriano Président de l'ARCEP	Audition de M. Sébastien Soriano Président de l'ARCEP	2017-10-25 16:00:00	2017-10-25 17:40:00	2017-10-26 11:42:18	2017-10-26 14:30:30	23	0	\N	\N
210184	COM_PERMANENTE	AUTRE	\N	CDD	\N	Audition de M. Sébastien Soriano Président de l'ARCEP	Audition de M. Sébastien Soriano Président de l'ARCEP	2017-10-25 16:00:00	2017-10-25 17:40:00	2017-10-26 11:36:50	2017-10-26 14:30:29	27	0	\N	\N
210185	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2017-10-24 15:00:00	2017-10-24 18:30:00	\N	\N	3	0	\N	\N
210187	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2017-10-25 14:00:00	2017-10-25 16:00:00	\N	\N	2	0	\N	\N
210189	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2017-10-25 18:00:00	2017-10-25 19:30:00	\N	\N	1	0	\N	\N
212038	GIA	AUCUNE	\N	\N	\N	Visite de parlementaires lituaniens et ukrainiens	Visite de parlementaires lituaniens et ukrainiens	2017-10-25 11:00:00	2017-10-25 12:30:00	\N	\N	4	0	616	\N
212040	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF 2018 - Programme 185	\N	2017-10-25 14:30:00	2017-10-25 17:30:00	\N	\N	1	0	\N	\N
212042	GIA	AUCUNE	\N	\N	\N	Visite de parlementaires lituaniens et ukrainiens 	Visite de parlementaires lituaniens et ukrainiens dans le cadre de l¿initiative lituano-ukrainienne 	2017-10-25 12:30:00	2017-10-25 14:00:00	\N	\N	1	0	530	\N
212047	GIA	AUCUNE	\N	\N	\N	Visite de parlementaires lituaniens et ukrainiens 	Visite de parlementaires lituaniens et ukrainiens dans le cadre de l¿initiative lituano-ukrainienne	2017-10-25 14:30:00	2017-10-25 15:15:00	\N	\N	2	0	616	\N
212147	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2017-10-26 10:00:00	2017-10-26 12:00:00	\N	\N	2	0	\N	\N
212150	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL Convention entraide judiciaire pénale Algérie	\N	2017-10-25 14:35:00	2017-10-25 15:45:00	\N	\N	1	0	\N	\N
213059	COM_PERMANENTE	AUTRE	\N	FINC	\N	Rapport et texte Convention Bâle-Mulhouse	Examen rapport et élaboration texte Convention fiscale - aéroport de Bâle-Mulhouse	2017-10-31 14:20:00	2017-10-31 14:30:00	2017-11-02 16:12:11	2017-11-02 17:16:05	18	0	\N	\N
213071	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 -  Conseil et contrôle de l'État	PLF pour 2018 -  Conseil et contrôle de l'État - Audition Premier Pdt Cour des comptes	2017-10-26 07:50:00	2017-10-26 09:35:00	\N	\N	1	0	\N	\N
213074	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Rapport général	PLF pour 2018 - Rapport général - Audition AFEP	2017-10-25 14:30:00	2017-10-25 15:00:00	\N	\N	1	0	\N	\N
213116	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Modalités de dépôt de candidature aux élections	\N	2017-10-26 14:00:00	2017-10-26 17:00:00	\N	\N	2	0	\N	\N
192759	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL + PJLO Rétablir la confiance dans l'action publique	\N	2017-07-11 09:10:00	2017-07-11 11:00:00	2017-07-12 15:20:20	2017-07-12 15:29:43	26	0	\N	\N
206494	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Nomination rapporteurs avis budgétaires + PJL Réforme du droit des contrats	\N	2017-10-11 10:00:00	2017-10-11 12:05:00	2017-10-11 12:31:48	2017-10-11 14:47:39	42	0	\N	\N
192760	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL + PJLO Confiance action publique - PJL Sécurité intérieure - PJL Paris La Défense	\N	2017-07-12 08:35:00	2017-07-12 12:15:00	2017-07-13 11:05:45	2017-07-13 15:26:10	35	0	\N	\N
193252	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	\N	2017-07-11 12:30:00	2017-07-11 14:15:00	\N	\N	1	0	\N	\N
194372	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	Chronologie des m édias	2017-07-12 09:05:00	2017-07-12 12:20:00	2017-07-12 15:01:41	2017-07-12 15:21:13	27	0	\N	\N
194396	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	Chronologie des m édias	2017-07-12 14:35:00	2017-07-12 17:30:00	2017-07-12 17:36:44	2017-07-12 17:59:40	10	0	\N	\N
195301	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL Portugal-Luxembourg sécurité civile	PJL Accord avec le Portugal et le Luxembourg relatifs à la sécurité civile	2017-07-11 15:00:00	2017-07-11 15:25:00	\N	\N	1	0	\N	\N
196272	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2017-07-11 14:50:00	2017-07-11 16:10:00	\N	\N	3	0	\N	\N
196293	COM_PERMANENTE	AUTRE	\N	CAE	\N	Normalisation volontaire	Examen du rapport de Mme Elisabeth Lamure sur la normalisation volontaire	2017-07-12 09:30:00	2017-07-12 11:30:00	2017-07-12 14:39:11	2017-07-12 15:21:11	24	0	\N	\N
196738	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2017-07-19 10:00:00	2017-07-19 12:05:00	2017-07-19 16:30:22	2017-07-19 17:04:09	27	1	\N	\N
196878	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière constitutive de l'OPECST	Désignation du président et des vice-présidents	2017-07-13 11:00:00	2017-07-13 13:00:00	2017-07-13 15:52:17	2017-07-13 16:38:05	20	0	\N	\N
196952	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Remboursements et dégrèvements - Maquette budgétaire de la mission	Contrôle Remboursements et dégrèvements - Maquette budgétaire de la mission - Audition DGFiP	2017-07-11 09:00:00	2017-07-11 10:35:00	\N	\N	1	0	\N	\N
197269	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Culture et Handicap	\N	2017-07-13 09:00:00	2017-07-13 09:30:00	\N	\N	4	0	\N	\N
198064	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de Stéphane Travert	Audition de M. Stéphane Travert, ministre de l'Agriculture et de l'Alimentation	2017-07-19 16:35:00	2017-07-19 18:45:00	2017-07-20 10:17:36	2017-07-20 11:23:04	25	0	\N	\N
198067	COM_PERMANENTE	AUTRE	\N	CAE	\N	Rapports loi Ville et OPECST intelligence artificielle	Rapports sur l'application de la loi sur la Ville et de l'OPECST sur l'intelligence artificielle	2017-07-19 09:35:00	2017-07-19 12:30:00	2018-05-18 16:00:38	2018-05-18 16:00:44	28	1	\N	\N
198068	COM_PERMANENTE	AUTRE	\N	CAE	\N	Examen du rapport groupe suivi PAC	Examen du rapport du groupe de suivi sur la mise en oeuvre de la réforme de la politique agricole commune	2017-07-20 13:30:00	2017-07-20 14:55:00	2018-05-18 16:00:58	2018-05-18 16:01:03	25	0	\N	\N
200552	COM_EURO	AUDRAP	\N	AFEU	\N	Propositions de règlements relatives à l'asile	Propositions de règlements relatives à l'asile	2017-07-20 11:10:00	2017-07-20 12:05:00	\N	\N	2	0	\N	\N
201040	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de Bruno Le Maire	Audition de M. Bruno Le Maire, ministre de l¿Économie et des Finances 	2017-07-25 16:05:00	2017-07-25 17:50:00	2018-05-18 16:01:27	2018-05-18 16:01:46	25	0	\N	\N
201254	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2017-07-25 17:00:00	2017-07-25 18:40:00	2017-07-25 18:46:19	2017-07-26 09:14:15	29	0	\N	\N
202442	COM_PERMANENTE	AUTRE	\N	CDD	\N	Audition de Mme Catherine Guillouard, article 13, RATP	Audition de Mme Catherine Guillouard, article 13, RATP	2017-07-26 09:35:00	2017-07-26 11:35:00	2018-05-18 16:02:15	2018-05-18 16:02:19	21	0	\N	\N
202913	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition M. Mercier (nomination au CC)	\N	2017-08-02 10:00:00	2017-08-02 11:00:00	2017-08-03 09:21:44	2017-08-03 12:02:57	32	2	\N	\N
202915	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition M. Mercier (nomination au CC - vote)	\N	2017-08-02 11:10:00	2017-08-02 11:25:00	2017-08-03 09:22:00	2017-08-03 12:02:58	32	2	\N	\N
205012	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Réforme du droit des contrats	\N	2017-09-12 09:30:00	2017-09-12 12:15:00	\N	\N	1	0	\N	\N
205014	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Réforme du droit des contrats	\N	2017-09-12 15:00:00	2017-09-12 18:15:00	\N	\N	1	0	\N	\N
205052	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	Entretien avec Jacques CHAGNON, Président de l'Assemblée nationale du Québec	Entretien avec Jacques CHAGNON, Président de l'Assemblée nationale du Québec	2017-09-13 14:00:00	2017-09-13 15:00:00	\N	\N	1	0	\N	\N
205072	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Évolution de la taxe d'habitation - Présentation et auditions	Évolution de la taxe d'habitation - Présentation et auditions DGCL et DLF	2017-09-13 10:00:00	2017-09-13 12:40:00	\N	\N	7	0	\N	\N
205412	COM_PERMANENTE	DEPLACEMENT	\N	SOCI	\N	Déplacement en Italie	\N	2017-09-18 14:00:00	2017-09-21 22:00:00	\N	\N	4	0	\N	\N
205520	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Redressement de la justice PPLO Redressement de la justice	\N	2017-09-26 14:00:00	2017-09-26 16:10:00	\N	\N	1	0	\N	\N
205523	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Redressement de la justice PPLO Redressement de la justice	\N	2017-09-26 17:40:00	2017-09-26 18:15:00	\N	\N	1	0	\N	\N
205584	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Redressement de la justice PPLO Redressement de la justice	\N	2017-09-27 10:00:00	2017-09-27 13:00:00	\N	\N	1	0	\N	\N
205586	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Redressement de la justice PPLO Redressement de la justice	\N	2017-09-27 14:00:00	2017-09-27 19:30:00	\N	\N	2	0	\N	\N
205640	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	AP-OTAN	Norvège	2017-05-08 08:55:00	2017-05-10 19:00:00	\N	\N	1	0	\N	\N
205642	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	AP-OTAN	Norvège	2017-05-08 08:55:00	2017-05-11 23:00:00	\N	\N	1	0	\N	\N
205644	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	PESC-PSDC	Malte	2017-04-26 08:00:00	2017-04-28 20:00:00	\N	\N	1	0	\N	\N
205738	COM_PERMANENTE	AUTRE	\N	CDD	\N	Constitution du Bureau de la commission et PJL n° 666	Constitution du Bureau de la commission et régles applicables à l'évaluation environnementale	2017-10-05 10:30:00	2017-10-05 12:30:00	2017-10-05 17:40:39	2017-10-05 17:45:20	43	0	\N	\N
208524	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Accueil des gens du voyage	\N	2017-10-10 14:30:00	2017-10-10 15:15:00	\N	\N	2	0	\N	\N
208528	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Accueil des gens du voyage	\N	2017-10-11 15:00:00	2017-10-11 18:15:00	\N	\N	2	0	\N	\N
210033	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Réhabiliter la police de proximité	\N	2017-10-17 14:30:00	2017-10-17 16:45:00	\N	\N	1	0	\N	\N
210088	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2017-10-24 15:00:00	2017-10-24 18:00:00	\N	\N	2	0	\N	\N
210133	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Agriculture	PLF pour 2018 - Agriculture - Audition DGPE	2017-10-17 15:00:00	2017-10-17 16:45:00	\N	\N	2	0	\N	\N
210136	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Agriculture	PLF pour 2018 - Agriculture - Audition Ministère de l'agriculture	2017-10-17 17:45:00	2017-10-17 19:00:00	\N	\N	2	0	\N	\N
210139	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Engagements financiers de l'État	PLF pour 2018 - Engagements financiers de l'État - Agence France Trésor	2017-10-18 18:00:00	2017-10-18 19:00:00	\N	\N	1	0	\N	\N
210141	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Rapport général	PLF pour 2018 - Rapport général - Assemblée nationale	2017-10-18 13:00:00	2017-10-18 14:00:00	\N	\N	1	0	\N	\N
210143	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 -  Conseil et contrôle de l'État	PLF pour 2018 -  Conseil et contrôle de l'État - CESE	2017-10-18 11:30:00	2017-10-18 12:40:00	\N	\N	1	0	\N	\N
210153	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion constitutive de la Délégaton sénatoriale  aux entreprises	Réunion constitutive de la Délégaton sénatoriale  aux entreprises	2017-10-26 10:35:00	2017-10-26 11:10:00	2017-10-26 14:36:10	2017-10-26 15:49:02	28	0	\N	\N
218243	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2018 (avis PJJ)	\N	2017-11-14 15:00:00	2017-11-14 16:00:00	\N	\N	1	0	\N	\N
218456	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion	Réunion	2017-11-15 16:35:00	2017-11-15 18:45:00	2017-11-15 18:53:56	2017-11-16 08:15:48	37	0	\N	\N
219900	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	Auditions GT Infractions sexuelles	Auditions GT Infractions sexuelles	2017-11-15 15:00:00	2017-11-15 18:25:00	\N	\N	5	0	\N	\N
220181	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Écologie, développement et mobilité durables/Transports	PLF pour 2018 - Écologie, développement et mobilité durables/Transports - Audition VNF	2017-11-16 11:30:00	2017-11-16 12:30:00	\N	\N	1	0	\N	\N
220183	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Écologie, développement et mobilité durables/Transports	PLF pour 2018 - Écologie, développement et mobilité durables/Transports - Audition ARAFER	2017-11-16 15:30:00	2017-11-16 16:30:00	\N	\N	1	0	\N	\N
220188	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 16 novembre 2017	Réunion du 16 novembre 2017	2017-11-16 08:40:00	2017-11-16 10:15:00	2017-11-17 10:19:59	2017-11-17 10:57:42	18	0	\N	\N
220228	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2018 - Avis Relations avec les collectiviités territoriales	\N	2017-11-14 14:00:00	2017-11-14 15:30:00	\N	\N	1	0	\N	\N
220230	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2018 - Avis Relations avec les collectiviités territoriales	\N	2017-11-16 14:00:00	2017-11-16 17:00:00	\N	\N	1	0	\N	\N
222245	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL Convention Sainte-Lucie	\N	2017-11-23 09:25:00	2017-11-23 10:20:00	\N	\N	1	0	\N	\N
223622	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	GT revitalisation centres - réunion constitutive	\N	2017-11-29 16:00:00	2017-11-29 16:30:00	\N	\N	9	0	\N	\N
223625	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	GT revitalisation - Table ronde professionnels commerces de détail	\N	2017-11-29 16:30:00	2017-11-29 18:00:00	\N	\N	10	0	\N	\N
226742	GIA	AUCUNE	\N	\N	\N	Accueil de M. VONGDARA, Ministre de la culture du Laos	Accueil de M. VONGDARA, Ministre de la culture du Laos	2017-12-05 12:30:00	2017-12-05 15:00:00	\N	\N	5	0	577	\N
228118	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	SGDSN	\N	2017-12-05 10:00:00	2017-12-05 14:00:00	\N	\N	2	0	\N	\N
228122	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	SGDSN	\N	2017-12-05 10:00:00	2017-12-05 11:00:00	\N	\N	1	0	\N	\N
230446	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition cyle de vie des entreprises	Audition cyle de vie des entreprises (MEDEF)	2017-12-04 13:00:00	2017-12-04 14:00:00	\N	\N	1	0	\N	\N
230521	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition cyle de vie des entreprises	Audition cyle de vie des entreprises - administrateur et mandataire judiciaires	2017-12-07 09:15:00	2017-12-07 10:15:00	\N	\N	1	0	\N	\N
230538	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition cyle de vie des entreprises	Audition cyle de vie des entreprises (Droit et roissance)	2017-12-07 10:15:00	2017-12-07 11:00:00	\N	\N	1	0	\N	\N
230544	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition cyle de vie des entreprises	Audition cyle de vie des entreprises (METI)	2017-12-11 11:00:00	2017-12-11 11:45:00	\N	\N	1	0	\N	\N
230556	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition cyle de vie des entreprises	Audition cyle de vie des entreprises (Conseil national des barreaux)	2017-12-12 14:00:00	2017-12-12 14:45:00	\N	\N	1	0	\N	\N
230572	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition cyle de vie des entreprises	Audition cyle de vie des entreprises (CPME)	2017-12-12 16:00:00	2017-12-12 17:00:00	\N	\N	1	0	\N	\N
232325	GIA	AUCUNE	\N	\N	\N	Assemblée générale	Assemblée générale reconstitutive	2017-12-20 08:30:00	2017-12-20 09:20:00	\N	\N	8	0	613	\N
238759	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI contrats aidés	MI contrats aidés	2018-01-24 14:30:00	2018-01-24 16:00:00	\N	\N	2	0	\N	\N
238762	COM_PERMANENTE	DEPLACEMENT	\N	AFCL	\N	PPL Régime d'ouverture des établissements privés hors contrat	PPL Régime d'ouverture des établissements privés hors contrat	2018-01-23 11:00:00	2018-01-23 16:00:00	\N	\N	1	0	\N	\N
238764	COM_PERMANENTE	DEPLACEMENT	\N	AFCL	\N	PPL Régime d'ouverture des établissements privés hors contrat	PPL Régime d'ouverture des établissements privés hors contrat	2018-01-25 16:30:00	2018-01-25 18:30:00	\N	\N	1	0	\N	\N
238971	DELEGATION	AUCUNE	\N	\N	DSOM	Déplacement à l'INSEP (Vincennes)	Déplacement à l'INSEP (Vincennes)	2018-02-02 09:00:00	2018-02-02 18:00:00	2018-02-02 14:21:24	2018-02-14 13:58:35	11	0	\N	\N
239004	DELEGATION	AUCUNE	\N	\N	DSOM	Réunion de la délégation	Réunion de la délégation	2018-02-01 08:45:00	2018-02-01 11:35:00	2018-02-01 12:48:04	2018-02-01 20:08:55	17	0	\N	\N
242872	GIA	AUCUNE	\N	\N	\N	AG Groupe 	Asemblée Générale du Groupe	2018-02-06 10:00:00	2018-02-06 10:45:00	\N	\N	8	0	673	\N
244130	COM_EURO	AUTRE_NON_PLENIERE	\N	AFEU	\N	Entretien du Bureau avec M. László Tróczányi, ministre hongrois de la Justice	Entretien du Bureau avec M. László Tróczányi, ministre hongrois de la Justice	2018-02-08 15:30:00	2018-02-08 16:40:00	\N	\N	3	0	\N	\N
249813	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2018-02-20 18:00:00	2018-02-20 20:45:00	\N	\N	3	0	\N	\N
260435	GIA	AUCUNE	\N	\N	\N	entretien avec l'ambassadeur du Yémen	entretien avec l'ambassadeur du Yémen	2018-03-27 14:15:00	2018-03-27 15:15:00	\N	\N	2	0	627	\N
261094	DELEGATION	AUCUNE	\N	\N	211	Echange de vues sur la révision constitutionnelle	Echange de vues sur la révision constitutionnelle	2018-03-29 08:30:00	2018-03-29 10:30:00	2018-03-29 12:40:58	2018-03-29 14:19:42	10	0	\N	\N
262433	GIA	AUCUNE	\N	\N	\N	entretien avec SE M. Fabien Penone, ambassadeur de France en Corée du Sud	entretien avec SE M. Fabien Penone, ambassadeur de France en Corée du Sud	2018-04-04 12:15:00	2018-04-04 13:45:00	\N	\N	1	0	613	\N
265710	ETUDES	AUCUNE	\N	\N	\N	GE Chasse et Pêche	GE Chasse et Pêche	2018-04-11 08:00:00	2018-04-11 09:20:00	\N	\N	23	0	\N	907
224180	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion	Réunion	2017-11-29 09:00:00	2017-11-29 10:55:00	2017-11-29 11:32:01	2017-11-29 16:50:32	43	0	\N	\N
267301	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Mission "Routes de la soie"	\N	2018-04-10 15:00:00	2018-04-10 15:15:00	\N	\N	3	0	\N	\N
267314	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition pléinière	\N	2018-04-17 17:00:00	2018-04-17 18:30:00	2018-04-18 14:47:17	2018-04-18 16:47:53	33	0	\N	\N
267315	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Communications	\N	2018-04-18 09:30:00	2018-04-18 12:15:00	2018-04-18 15:21:13	2018-04-18 16:47:49	34	0	\N	\N
270357	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	LPM	\N	2018-04-19 14:00:00	2018-04-19 15:00:00	\N	\N	1	0	\N	\N
270562	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	\N	GT Financement du handicap	2018-05-22 14:00:00	2018-05-22 18:00:00	\N	\N	5	0	\N	\N
270566	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2018-05-16 09:00:00	2018-05-16 11:25:00	2018-05-16 11:26:11	2018-05-16 14:13:51	38	1	\N	\N
271910	COM_ENQUETE	PLENIERE	\N	CHUTE	\N	Audition plénière	\N	2018-05-15 15:00:00	2018-05-15 15:55:00	2018-05-16 10:31:15	2018-05-16 14:14:06	7	0	\N	\N
271933	COM_ENQUETE	AUTRE	\N	CHUTE	\N	Autre	\N	2018-05-24 13:45:00	2018-05-24 14:50:00	2018-05-25 17:24:14	2018-05-25 17:24:34	10	0	\N	\N
275556	AUTRE_TEMPORAIRE	DEPLACEMENT	\N	\N	\N	Déplacement à Toulouse	\N	2018-03-05 08:40:00	2018-03-05 19:30:00	\N	\N	0	0	\N	\N
275628	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Audition CNAOC	\N	2018-05-24 13:30:00	2018-05-24 14:30:00	\N	\N	0	0	\N	\N
275649	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Agriculture	\N	2018-05-23 17:00:00	2018-05-23 19:30:00	\N	\N	1	0	\N	\N
275651	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Agriculture	\N	2018-05-23 14:00:00	2018-05-23 16:30:00	\N	\N	1	0	\N	\N
275740	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2018 - Mission "Culture" - Gestion déconcentrée des crédits DRAC - Montpellier	Contrôle 2018 - Mission "Culture" - Gestion déconcentrée des crédits DRAC - Montpellier	2018-05-28 08:20:00	2018-05-28 20:00:00	\N	\N	2	0	\N	\N
275750	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2018 - Mission "Travail et emploi" - Les maisons de l'emploi - Strasbourg	Contrôle 2018 - Mission "Travail et emploi" - Les maisons de l'emploi - Strasbourg	2018-06-05 07:45:00	2018-06-05 17:15:00	\N	\N	1	0	\N	\N
275753	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Audition de Mme Geneviève AVENARD, Défenseur des enfants	\N	2018-05-29 17:45:00	2018-05-29 19:00:00	\N	\N	0	0	\N	\N
280499	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	Audition de Mme Isabelle Kocher	2018-06-06 09:05:00	2018-06-06 10:30:00	2018-06-06 19:24:21	2018-06-07 18:43:42	47	0	\N	\N
292345	MISSION	PLEIN_NON_JO	\N	BREXIT2	\N	Audition de M. Llewellyn, ambassadeur de Grande-Bretagne en France	Audition de M. Llewellyn, ambassadeur de Grande-Bretagne en France	2018-06-27 15:10:00	2018-06-27 16:20:00	\N	\N	7	0	\N	\N
292510	DELEGATION	AUCUNE	\N	\N	COLTER	Examen rapport d'information "Faciliter l'exercice des mandats locaux"	\N	2018-07-05 08:30:00	2018-07-05 10:45:00	2018-07-05 11:48:07	2018-07-05 16:05:40	15	0	\N	\N
293118	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Renforcer la lutte contre les rodéos motorisés	\N	2018-06-28 14:00:00	2018-06-28 15:00:00	\N	\N	3	0	\N	\N
293122	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Renforcer la lutte contre les rodéos motorisés	\N	2018-06-28 15:00:00	2018-06-28 15:30:00	\N	\N	2	0	\N	\N
293129	COM_EURO	AUDRAP	\N	AFEU	\N	GT AFEU - Traité de l'Elysée	GT AFEU - Traité de l'Ellysée	2018-06-28 11:15:00	2018-06-28 12:20:00	\N	\N	2	0	\N	\N
293132	COM_EURO	AUDRAP	\N	AFEU	\N	GT AFEU - Traité de l'Elysée	GT AFEU - Traité de l'Elysée	2018-06-28 17:10:00	2018-06-28 18:10:00	\N	\N	1	0	\N	\N
295646	ETUDES	AUCUNE	\N	\N	\N	Audition de M. Augustin de Romanet Président ADP	Audition de M. Augustin de Romanet Président ADP	2018-07-05 08:30:00	2018-07-05 10:00:00	\N	\N	5	0	\N	933
295657	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière	Réunion plénière	2018-07-12 09:05:00	2018-07-12 11:50:00	2018-07-12 16:18:08	2018-07-12 16:37:37	8	0	\N	\N
295670	ETUDES	AUCUNE	\N	\N	\N	\N	\N	2018-07-10 18:00:00	2018-07-10 19:30:00	\N	\N	8	0	\N	928
295673	MISSION	AUDRAP	\N	HERBE	\N	\N	\N	2018-07-12 14:30:00	2018-07-12 15:30:00	\N	\N	1	0	\N	\N
295676	MISSION	AUDRAP	\N	HERBE	\N	\N	\N	2018-07-20 09:00:00	2018-07-20 12:00:00	\N	\N	1	0	\N	\N
305938	COM_ENQUETE	PLENIERE	\N	HAUTE	\N	Réunion du 20 septembre 2018	Réunion du 20 septembre 2018	2018-09-20 10:05:00	2018-09-20 11:55:00	2018-09-20 16:28:08	2018-09-20 17:46:38	7	0	\N	\N
306020	MISSION	AUCUNE	\N	HERBE	\N	Réunion d'adoption du rapport	\N	2018-09-25 20:25:00	2018-09-25 23:30:00	2018-09-26 15:42:09	2018-09-26 17:51:28	18	1	\N	\N
308754	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ambassadeur de Bosnie-Herzégovine	Entretien avec l'ambassadeur de Bosnie-Herzégovine	2018-10-03 08:00:00	2018-10-03 09:20:00	\N	\N	2	0	674	\N
309062	DELEGATION	AUDRAP	\N	\N	206	Audition Planète Mars de Sébastien Fontaine	Audition Planète Mars de Sébastien Fontaine, directeur du planétarium Palais de la découverte	2018-10-04 16:00:00	2018-10-04 17:30:00	\N	\N	1	0	\N	\N
309066	DELEGATION	AUDRAP	\N	\N	206	Audition Planète Mars de Philippe Lognonné	Audition Planète Mars de Philippe Lognonné (Institut de physique du globe de Paris)	2018-10-04 17:30:00	2018-10-04 19:00:00	\N	\N	0	0	\N	\N
309107	MECSS	AUDRAP	\N	\N	MECSS	PJL Retraites	\N	2018-10-23 16:15:00	2018-10-23 17:00:00	\N	\N	1	0	\N	\N
311187	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Presse	PLF 2019 - Crédits Presse	2018-10-11 10:00:00	2018-10-11 12:15:00	\N	\N	1	0	\N	\N
311190	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Livre et Industries culturelles	PLF 2019 - Crédits Livre et Industries culturelles	2018-10-11 13:45:00	2018-10-11 14:45:00	\N	\N	3	0	\N	\N
313900	COM_SPECIALE	AUDRAP	\N	RETRAIT	\N	Audition rapporteur	Audition UK Finance	2018-10-16 17:00:00	2018-10-16 18:00:00	\N	\N	2	0	\N	\N
313903	COM_SPECIALE	AUDRAP	\N	RETRAIT	\N	Audition rapporteur	Audition CS Brexit	2018-10-17 17:05:00	2018-10-17 18:30:00	\N	\N	10	0	\N	\N
314265	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2019 - Assurance maladie	\N	2018-10-24 11:30:00	2018-10-24 12:30:00	\N	\N	2	0	\N	\N
314268	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2019 - Assurance maladie	\N	2018-10-24 15:30:00	2018-10-24 16:30:00	\N	\N	1	0	\N	\N
314270	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2019 - Assurance maladie	\N	2018-10-24 16:30:00	2018-10-24 19:00:00	\N	\N	1	0	\N	\N
314272	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2019 - Assurance maladie	\N	2018-10-25 09:30:00	2018-10-25 12:00:00	\N	\N	1	0	\N	\N
314274	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2019 - Assurance maladie	\N	2018-10-25 16:00:00	2018-10-25 17:00:00	\N	\N	1	0	\N	\N
314276	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2019 - Assurance maladie	\N	2018-10-30 16:00:00	2018-10-30 16:45:00	\N	\N	2	0	\N	\N
314278	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2019 - Assurance maladie	\N	2018-10-30 18:00:00	2018-10-30 19:00:00	\N	\N	3	0	\N	\N
280690	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	PPL Centres-villes et PPRE PAC	2018-06-06 10:35:00	2018-06-06 11:35:00	2018-06-06 19:23:54	2018-06-07 18:43:39	46	0	\N	\N
314280	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2019 - Hébergement	\N	2018-10-23 11:45:00	2018-10-23 12:30:00	\N	\N	1	0	\N	\N
314282	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2019 - Hébergement	\N	2018-10-24 18:00:00	2018-10-24 19:30:00	\N	\N	1	0	\N	\N
314284	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2019 - Hébergement	\N	2018-10-30 09:00:00	2018-10-30 12:15:00	\N	\N	1	0	\N	\N
314286	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2019 - Hébergement	\N	2018-11-07 11:45:00	2018-11-07 12:30:00	\N	\N	1	0	\N	\N
314454	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Andreï NASTASE	Entretien avec M. Andreï NASTASE, maire élu de Chisinau	2018-10-23 12:00:00	2018-10-23 13:15:00	\N	\N	2	0	851	\N
314465	GIA	AUCUNE	\N	\N	\N	Rencontre Luai Jaff	Rencontre entre M. Cazeau et M. Luai Jaff, président du KESCC (représentant de l'UPK en France)	2018-10-17 17:00:00	2018-10-17 18:00:00	\N	\N	1	0	615	\N
314743	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	\N	Mission d'information sur la Sécurité des ponts - Réunion constitutive	2018-10-10 14:35:00	2018-10-10 14:55:00	\N	\N	8	0	\N	\N
314754	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Violences dans les manifestations	PPL Violences dans les manifestations	2018-10-23 16:15:00	2018-10-23 19:20:00	\N	\N	148	0	\N	\N
315419	GIA	AUCUNE	\N	\N	\N	\N	\N	2018-10-23 00:00:00	2018-10-23 00:00:00	\N	\N	0	0	615	\N
315943	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Entretien commission défense Lituanie	\N	2018-10-23 15:15:00	2018-10-23 17:00:00	\N	\N	6	0	\N	\N
316399	DELEGATION	DEPLACEMENT	\N	\N	206	Visite du CEA-LITEN (Arrêt des véhicules thermiques)	Visite du CEA-LITEN (Arrêt des véhicules thermiques)	2018-10-25 06:30:00	2018-10-25 20:30:00	\N	\N	2	0	\N	\N
317222	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	\N	MI Sécurité des ponts	2018-10-25 10:15:00	2018-10-25 12:15:00	\N	\N	8	0	\N	\N
317250	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Justice - Les amendes pénales - DACG	Contrôle 2018 - Justice - Les amendes pénales - DACG	2018-10-24 14:30:00	2018-10-24 15:30:00	\N	\N	1	0	\N	\N
317262	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - RCT - AdCF / AMF	PLF pour 2019 - RCT - AdCF / AMF	2018-10-24 16:00:00	2018-10-24 18:05:00	\N	\N	1	0	\N	\N
317280	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Rapport général - AMORCE	PLF pour 2019 - Rapport général - AMORCE	2018-10-24 15:45:00	2018-10-24 16:30:00	\N	\N	1	0	\N	\N
317286	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF 2019 - Cohésion des territoires (aménagement du territoire) - DGPR	PLF 2019 - Cohésion des territoires (aménagement du territoire) - DGPR	2018-10-24 16:30:00	2018-10-24 17:30:00	\N	\N	1	0	\N	\N
317296	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Cohésion des territoires (aménagement du territoire) - CGET	PLF pour 2019 - Cohésion des territoires (aménagement du territoire) - CGET	2018-10-25 11:00:00	2018-10-25 12:00:00	\N	\N	1	0	\N	\N
317312	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - AEE - DRH MEAE / DFEAC / Cabinet MEAE	PLF pour 2019 - AEE - DRH MEAE / DFEAC / Cabinet MEAE	2018-10-24 14:00:00	2018-10-24 17:45:00	\N	\N	2	0	\N	\N
317322	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2019 - CAS Contrôle circulation et stationnement routiers - Déplac. ANTAI PARIS	PLF pour 2019 - CAS Contrôle de la circulation et du stationnement routiers - Déplacement ANTAI PARIS	2018-10-24 14:15:00	2018-10-24 16:35:00	\N	\N	1	0	\N	\N
317324	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Sport	PLF 2019 - Crédits Sport	2018-10-25 16:00:00	2018-10-25 17:15:00	\N	\N	1	0	\N	\N
317330	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Solidarité - NID	PLF pour 2019 - Solidarité - NID	2018-10-24 17:00:00	2018-10-24 18:00:00	\N	\N	2	0	\N	\N
317333	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Solidarité - Délégué Interministériel Pauvreté	PLF pour 2019 - Solidarité - Délégué Interministériel Pauvreté	2018-10-24 18:00:00	2018-10-24 19:00:00	\N	\N	1	0	\N	\N
317335	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Solidarité - DFAS	PLF pour 2019 - Solidarité - DFAS	2018-10-25 09:30:00	2018-10-25 10:30:00	\N	\N	2	0	\N	\N
214532	COM_EURO	CONTROLE	\N	AFEU	\N	Plan d'investissement pour l'Europe	Plan d'investissement pour l'Europe	2017-10-31 14:30:00	2017-10-31 16:30:00	\N	\N	2	0	\N	\N
214535	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2017-11-08 14:00:00	2017-11-08 15:00:00	\N	\N	1	0	\N	\N
214537	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF 2018 - Avis Biodiversité et Transition énergétique	\N	2017-10-30 18:00:00	2017-10-30 19:00:00	\N	\N	1	0	\N	\N
214539	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF 2018 - Avis Biodiversité et Transition énergétique	\N	2017-10-31 14:00:00	2017-10-31 16:00:00	\N	\N	1	0	\N	\N
214541	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF pour 2018 - Avis "enseignement supérieur et recherche"	PJLF pour 2018 - Avis "enseignement supérieur et recherche"	2017-11-02 10:30:00	2017-11-02 11:15:00	\N	\N	1	0	\N	\N
214543	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF pour 2018 - Avis "enseignement supérieur et recherche"	PJLF pour 2018 - Avis "enseignement supérieur et recherche"	2017-11-02 11:15:00	2017-11-02 12:00:00	\N	\N	1	0	\N	\N
214545	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF pour 2018 - Avis "enseignement supérieur et recherche"	PJLF pour 2018 - Avis "enseignement supérieur et recherche"	2017-11-02 17:00:00	2017-11-02 17:45:00	\N	\N	1	0	\N	\N
214547	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF pour 2018 - Avis "enseignement supérieur et recherche"	PJLF pour 2018 - Avis "enseignement supérieur et recherche"	2017-11-02 17:45:00	2017-11-02 18:15:00	\N	\N	1	0	\N	\N
214550	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2017-11-08 16:30:00	2017-11-08 19:00:00	2017-11-08 19:09:14	2017-11-09 15:57:15	37	0	\N	\N
217414	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2017-11-09 08:30:00	2017-11-09 10:30:00	\N	\N	1	0	\N	\N
217470	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Rapport général	PLF pour 2018 - Rapport général - Monuments historiques	2017-11-09 09:30:00	2017-11-09 10:30:00	\N	\N	2	0	\N	\N
218995	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Jean-Yves LECONTE de Mme Marija OBRADOVIC, Députée du Parti progressiste	Entretien avec M. Jean-Yves LECONTE de Mme Marija OBRADOVIC, Députée du Parti progressiste	2017-11-15 15:30:00	2017-11-15 16:30:00	\N	\N	1	0	674	\N
219897	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2018 - Programme 185	\N	2017-11-14 09:00:00	2017-11-14 10:00:00	\N	\N	2	0	\N	\N
219906	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2018 - Programme 185	\N	2017-11-14 12:00:00	2017-11-14 13:00:00	\N	\N	2	0	\N	\N
219911	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL transfèrement Pérou	\N	2017-11-14 14:30:00	2017-11-14 15:15:00	\N	\N	1	0	\N	\N
221364	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de finances 2018	Loi de finances 2018 (Presse)	2017-11-21 14:00:00	2017-11-21 16:00:00	\N	\N	1	0	\N	\N
221368	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion	Réunion	2017-11-22 15:10:00	2017-11-22 17:45:00	2017-11-22 17:58:04	2017-11-23 14:23:42	30	1	\N	\N
221839	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2017-11-21 14:30:00	2017-11-21 15:20:00	\N	\N	3	0	\N	\N
221843	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2017-11-21 16:30:00	2017-11-21 17:30:00	\N	\N	3	0	\N	\N
232992	QUESTURE	AUCUNE	\N	\N	\N	Commission de concertation	Commission de concertation	2017-11-30 10:00:00	2017-11-30 12:25:00	\N	\N	3	0	\N	\N
239148	COM_PERMANENTE	CONTROLE	\N	CDD	\N	test FG	\N	2014-01-17 09:30:00	2014-01-17 11:30:00	\N	\N	0	0	\N	\N
244325	GIA	AUCUNE	\N	\N	\N	Déjeuner de travail avec Mme Anne GRILLO, ambassadrice de France au Mexique	Déjeuner de travail avec Mme Anne GRILLO, ambassadrice de France au Mexique	2018-02-07 12:30:00	2018-02-07 14:30:00	\N	\N	6	0	643	\N
253493	COM_SPECIALE	PLENIERE	\N	SOCIETE	\N	PJL État au service d'une société de confiance	\N	2018-03-13 09:00:00	2018-03-13 10:50:00	2018-03-14 09:59:42	2018-03-14 15:42:42	25	0	\N	\N
253494	COM_SPECIALE	PLENIERE	\N	SOCIETE	\N	PJL État au service d'une société de confiance	\N	2018-03-13 19:40:00	2018-03-13 21:00:00	2018-03-14 09:59:59	2018-03-14 15:42:40	22	0	\N	\N
253495	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	\N	\N	2018-03-06 13:00:00	2018-03-06 14:00:00	\N	\N	0	0	\N	\N
253496	COM_ENQUETE	AUTRE	\N	CHUTE	\N	Audition plénière	\N	2018-03-13 14:50:00	2018-03-13 15:55:00	2018-03-15 11:41:33	2018-03-15 12:00:28	12	0	\N	\N
253497	COM_ENQUETE	AUTRE	\N	CHUTE	\N	Audition plénière	\N	2018-03-14 15:05:00	2018-03-14 16:00:00	2018-03-16 15:23:57	2018-03-16 15:30:59	11	0	\N	\N
253498	COM_ENQUETE	AUTRE	\N	CHUTE	\N	Audition plénière	\N	2018-03-14 16:10:00	2018-03-14 16:55:00	2018-03-16 15:24:45	2018-03-16 15:31:00	8	0	\N	\N
253499	COM_ENQUETE	AUTRE	\N	CHUTE	\N	Audition plénière	\N	2018-03-13 16:00:00	2018-03-13 16:45:00	2018-03-16 15:23:05	2018-03-16 15:31:01	8	0	\N	\N
253526	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Protection des données personnelles	\N	2018-03-07 09:30:00	2018-03-07 10:45:00	\N	\N	1	0	\N	\N
258883	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Indivision successorale et politique du logement ultramarin	\N	2018-03-22 11:00:00	2018-03-22 11:40:00	\N	\N	1	0	\N	\N
275729	MISSION	AUCUNE	\N	MINEURSENF	\N	\N	\N	2018-05-24 16:30:00	2018-05-24 18:05:00	2018-05-24 18:06:19	2018-05-24 18:18:43	7	0	\N	\N
282657	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	PJL EGAlim	2018-06-12 14:45:00	2018-06-12 16:40:00	2018-06-13 19:49:52	2018-06-14 09:49:23	42	0	\N	\N
310543	COM_SPECIALE	PLENIERE	\N	SURTRANSPO	\N	Réunion constitutive	\N	2018-10-10 18:00:00	2018-10-10 18:37:00	2018-10-10 19:13:56	2018-10-11 16:04:37	23	1	\N	\N
310578	DELEGATION	AUDRAP	\N	\N	PROS	Audition de Gilles Dansart	\N	2018-10-23 17:00:00	2018-10-23 18:00:00	\N	\N	4	0	\N	\N
310584	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Plf 2019 - Crédits de l'audiovisuel public	Plf 2019 - Crédits de l'audiovisuel public	2018-10-10 16:00:00	2018-10-10 17:00:00	\N	\N	4	0	\N	\N
310585	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Plf 2019 - Crédits de l'audiovisuel public	Plf 2019 - Crédits de l'audiovisuel public	2018-10-10 17:00:00	2018-10-10 18:00:00	\N	\N	3	0	\N	\N
310594	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Plf 2019 - Crédits de l'audiovisuel public	Plf 2019 - Crédits de l'audiovisuel public	2018-10-10 14:30:00	2018-10-10 16:00:00	\N	\N	3	0	\N	\N
313340	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	auditions Bruno Gilles PLF mission anciens combattants	\N	2018-11-08 10:45:00	2018-11-08 11:30:00	\N	\N	1	0	\N	\N
313611	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2018-10-17 13:30:00	2018-10-17 14:15:00	\N	\N	0	0	\N	\N
313634	COM_PERMANENTE	AUTRE	\N	SOCI	\N	réunion plénière	\N	2018-10-24 08:35:00	2018-10-24 11:15:00	2018-10-24 11:13:24	2018-10-24 12:15:28	47	0	\N	\N
313750	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Sport	PLF 2019 - Crédits Sport	2018-10-17 14:00:00	2018-10-17 15:00:00	\N	\N	2	0	\N	\N
313751	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Sport	PLF 2019 - Crédits Sport	2018-10-17 15:00:00	2018-10-17 16:00:00	\N	\N	2	0	\N	\N
313768	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition des associations d'élus	Audition des associations d'élus	2018-10-17 17:00:00	2018-10-17 19:00:00	\N	\N	1	0	\N	\N
313769	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Jeunesse et vie associative	PLF 2019 - Crédits Jeunesse et vie associative	2018-10-16 15:30:00	2018-10-16 16:45:00	\N	\N	1	0	\N	\N
313770	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Jeunesse et vie associative	PLF 2019 - Crédits Jeunesse et vie associative	2018-10-16 17:45:00	2018-10-16 18:45:00	\N	\N	1	0	\N	\N
313773	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition GT Déserts médicaux	Audition de Mmes Doineau, sénatrice, et Augros, médecin, Délégués nationaux plan d'accès territorial à l'offre de soins	2018-10-17 14:30:00	2018-10-17 15:15:00	\N	\N	7	0	\N	\N
313774	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition GT Déserts médicaux	Audition de la Cour des comptes (GT Déserts médicaux)	2018-10-17 15:15:00	2018-10-17 16:00:00	\N	\N	7	0	\N	\N
313777	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition GT Déserts médicaux	Audition CNOM (GT Déserts médicaux)	2018-10-17 16:00:00	2018-10-17 16:45:00	\N	\N	7	0	\N	\N
331116	GIA	AUCUNE	\N	\N	\N	Réception MAE Soudan	Réception au Sénat de M. le ministre des affaires étrangères du Soudan	2018-11-21 17:30:00	2018-11-21 19:00:00	\N	\N	2	0	588	\N
331337	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	\N	\N	2018-11-28 08:00:00	2018-11-28 09:45:00	\N	\N	1	0	\N	\N
270198	COM_ENQUETE	DEPLACEMENT	\N	FORCES	\N	Déplacement à Bordeaux de la CE FSI	Déplacement à Bordeaux de la CE FSI	2018-04-20 07:10:00	2018-04-20 19:00:00	\N	\N	5	0	\N	\N
270300	COM_ENQUETE	DEPLACEMENT	\N	CHUTE	\N	Déplacement à Bruxelles	Déplacement à Bruxelles	2018-04-23 08:00:00	2018-04-24 22:00:00	\N	\N	3	0	\N	\N
270544	COM_ENQUETE	DEPLACEMENT	\N	CHUTE	\N	Déplacement à Bourg-en-Bresse et Lyon	\N	2018-05-02 08:00:00	2018-05-02 22:00:00	\N	\N	3	0	\N	\N
270548	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	Handi Val de Seine, UNEA, Envie, Fondation Autisme	\N	2018-05-16 15:00:00	2018-05-16 19:00:00	\N	\N	0	0	\N	\N
270549	AUTRE_TEMPORAIRE	AUTRE_NON_PLENIERE	\N	\N	\N	\N	\N	2018-05-16 15:00:00	2018-05-16 16:00:00	\N	\N	0	0	\N	\N
270550	AUTRE_TEMPORAIRE	AUTRE_NON_PLENIERE	\N	\N	\N	\N	\N	2018-05-16 16:00:00	2018-05-16 17:00:00	\N	\N	0	0	\N	\N
270551	AUTRE_TEMPORAIRE	AUTRE_NON_PLENIERE	\N	\N	\N	\N	\N	2018-05-22 14:00:00	2018-05-22 15:00:00	\N	\N	0	0	\N	\N
270552	AUTRE_TEMPORAIRE	AUTRE_NON_PLENIERE	\N	\N	\N	\N	\N	2018-05-22 15:00:00	2018-05-22 16:00:00	\N	\N	0	0	\N	\N
270553	AUTRE_TEMPORAIRE	AUTRE_NON_PLENIERE	\N	\N	\N	\N	\N	2018-05-22 16:00:00	2018-05-22 17:00:00	\N	\N	0	0	\N	\N
270554	AUTRE_TEMPORAIRE	AUTRE_NON_PLENIERE	\N	\N	\N	\N	\N	2018-05-22 17:00:00	2018-05-22 18:00:00	\N	\N	0	0	\N	\N
270555	AUTRE_TEMPORAIRE	AUTRE_NON_PLENIERE	\N	\N	\N	\N	\N	2018-05-29 15:00:00	2018-05-29 17:00:00	\N	\N	0	0	\N	\N
270556	AUTRE_TEMPORAIRE	AUTRE_NON_PLENIERE	\N	\N	\N	\N	\N	2018-05-29 16:00:00	2018-05-29 17:00:00	\N	\N	0	0	\N	\N
270557	AUTRE_TEMPORAIRE	AUTRE_NON_PLENIERE	\N	\N	\N	\N	\N	2018-05-29 18:00:00	2018-05-29 19:00:00	\N	\N	0	0	\N	\N
270558	AUTRE_TEMPORAIRE	AUTRE_NON_PLENIERE	\N	\N	\N	\N	\N	2018-06-06 14:00:00	2018-06-06 16:00:00	\N	\N	0	0	\N	\N
270559	AUTRE_TEMPORAIRE	AUTRE_NON_PLENIERE	\N	\N	\N	\N	\N	2018-06-06 15:00:00	2018-06-06 16:00:00	\N	\N	0	0	\N	\N
270560	AUTRE_TEMPORAIRE	AUTRE_NON_PLENIERE	\N	\N	\N	\N	\N	2018-06-06 16:00:00	2018-06-06 17:00:00	\N	\N	0	0	\N	\N
270561	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	ADMDPH, Andicat, Denis Piveteau, TouPI	\N	2018-05-22 14:00:00	2018-05-22 18:00:00	\N	\N	0	0	\N	\N
247286	CMP	AUTRE	\N	JO2024	\N	PJL Organisation des Jeux Olympiques et Paralympiques de 2024	PJL Organisation des Jeux Olympiques et Paralympiques de 2024	2018-02-20 09:15:00	2018-02-20 09:40:00	\N	\N	10	0	\N	\N
270563	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	SOCI	\N	PPL Autorisation d'analyses génétiques sur personnes décédées	PPL Autorisation d'analyses génétiques sur personnes décédées	2018-05-15 15:30:00	2018-05-15 16:30:00	\N	\N	1	0	\N	\N
270643	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion 20180516	\N	2018-05-16 08:35:00	2018-05-16 10:10:00	2018-05-16 10:46:32	2018-05-16 14:13:50	39	0	\N	\N
270872	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur thanatopraxie	\N	2018-05-15 14:30:00	2018-05-15 16:00:00	\N	\N	1	0	\N	\N
271247	DELEGATION	AUCUNE	\N	\N	211	Table ronde sur les conditions d'exercice de leur mandat par les élues locales	Table ronde sur les conditions d'exercice de leur mandat par les élues locales	2018-05-24 09:00:00	2018-05-24 11:25:00	2018-05-24 16:02:40	2018-05-24 18:18:14	26	0	\N	\N
272603	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL  Agriculture	PJL Agriculture	2018-04-10 09:30:00	2018-04-10 10:30:00	\N	\N	3	0	\N	\N
272614	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Agriculture	PJL Agriculture	2018-04-10 14:30:00	2018-04-10 20:00:00	\N	\N	8	0	\N	\N
272641	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Agriculture	PJL Agriculture	2018-04-17 13:30:00	2018-04-17 19:00:00	\N	\N	2	0	\N	\N
272657	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Agriculture	PJL Agriculture	2018-04-18 13:30:00	2018-04-18 20:00:00	\N	\N	2	0	\N	\N
272665	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL  Agriculture	PJL Agriculture	2018-04-19 09:00:00	2018-04-19 12:30:00	\N	\N	3	0	\N	\N
272682	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Agriculture	PJL Agriculture	2018-04-19 14:30:00	2018-04-19 20:00:00	\N	\N	2	0	\N	\N
273285	DELEGATION	DEPLACEMENT	\N	\N	211	Visite des locaux de l'association FNSF	Visite des locaux de l'association FNSF	2018-05-17 10:30:00	2018-05-17 12:30:00	\N	\N	3	0	\N	\N
273327	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de M. Günther OETTINGER, commissaire européen budget et ressources humaines	Audition de M. Günther OETTINGER, commissaire européen au budget et aux ressources humaines	2018-05-24 09:15:00	2018-05-24 10:50:00	2018-05-25 15:59:10	2018-05-25 17:04:40	28	0	\N	\N
273328	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de M. Gérald DARMANIN sur le projet de loi de règlement du budget 2017	Audition de M. Gérald DARMANIN ministre action et des comptes publics sur le projet de loi de règlement du budget 2017	2018-05-23 16:40:00	2018-05-23 18:10:00	2018-05-25 15:59:44	2018-05-25 17:04:39	34	0	\N	\N
273399	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Modernisation de la navigation aérienne - Auditions DGAC & DTA	Contrôle Modernisation de la navigation aérienne - Auditions DGAC & DTA	2018-05-16 14:30:00	2018-05-16 17:00:00	\N	\N	1	0	\N	\N
273401	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Modernisation navigation aérienne - Direction contrôle opérations Air France	Contrôle Modernisation de la navigation aérienne - Direction du contrôle des opérations Air France	2018-05-17 09:30:00	2018-05-17 11:00:00	\N	\N	1	0	\N	\N
273421	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle CIVS - Audition Fondation pour la mémoire de la Shoah	Contrôle CIVS - Audition Fondation pour la mémoire de la Shoah	2018-05-16 10:45:00	2018-05-16 12:00:00	\N	\N	1	0	\N	\N
273423	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Agriculture Biologique - INAO	Contrôle Agriculture Biologique - INAO	2018-05-16 14:30:00	2018-05-16 16:00:00	\N	\N	2	0	\N	\N
273426	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle CIVS - CIVS	Contrôle CIVS - CIVS	2018-05-16 16:00:00	2018-05-16 19:20:00	\N	\N	1	0	\N	\N
273434	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2018 - Mission "Outre-Mer" - Le service militaire adapté - Déplacement à Mayotte	Contrôle 2018 - Mission "Outre-Mer" - Le service militaire adapté - Déplacement à Mayotte	2018-05-21 21:10:00	2018-05-25 06:10:00	\N	\N	2	0	\N	\N
273494	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition sur le PJL Liberté de choisir son avenir professionnel	\N	2018-05-23 09:00:00	2018-05-23 12:05:00	2018-05-23 14:38:01	2018-05-23 16:02:30	32	0	\N	\N
273517	DELEGATION	AUDRAP	\N	\N	PROS	Audition du Crédit Foncier	\N	2018-06-12 09:45:00	2018-06-12 10:30:00	\N	\N	0	0	\N	\N
273521	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Métier d'enseignant	Métier d'enseignant - Déplacement à Bordeaux	2018-05-14 08:00:00	2018-05-14 20:00:00	\N	\N	2	0	\N	\N
273522	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Métier d'enseignant	Groupe de travail Métier d'enseignant	2018-05-25 08:00:00	2018-05-25 18:00:00	\N	\N	1	0	\N	\N
273523	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Métier d'enseignant	métier d'enseignant	2018-06-11 08:00:00	2018-06-11 20:00:00	\N	\N	2	0	\N	\N
273533	COM_ENQUETE	PLENIERE	\N	HAUTE	\N	Table ronde journalistes	\N	2018-05-17 15:30:00	2018-05-17 17:10:00	2018-05-17 18:59:50	2018-05-18 18:23:08	11	0	\N	\N
273571	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Réforme du logement	PJL Réforme du logement	2018-05-16 16:50:00	2018-05-16 17:30:00	\N	\N	2	0	\N	\N
273574	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Réforme du logement	PJL Réforme du logement	2018-05-16 17:30:00	2018-05-16 18:45:00	\N	\N	1	0	\N	\N
273576	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Réforme du logement	PJL Réforme du logement	2018-05-15 15:00:00	2018-05-15 16:00:00	\N	\N	2	0	\N	\N
273579	COM_EURO	AUDRAP	\N	AFEU	\N	Direction générale du Trésor	\N	2018-05-17 14:00:00	2018-05-17 16:00:00	\N	\N	2	0	\N	\N
273585	COM_EURO	AUDRAP	\N	AFEU	\N	Serbie et Monténégro	Audition de M. RISTIC, ambassadeur de Serbie en France	2018-05-17 11:00:00	2018-05-17 11:50:00	\N	\N	2	0	\N	\N
273588	COM_EURO	AUDRAP	\N	AFEU	\N	Serbie et Monténégro	Auditions de représentants du ministère de l'Europe et des affaires étrangères	2018-05-17 12:00:00	2018-05-17 12:40:00	\N	\N	2	0	\N	\N
273596	COM_EURO	DEPLACEMENT	\N	AFEU	\N	Détachement des travailleurs	Rencontre avec des représentants des institutions eu	2018-05-14 08:00:00	2018-05-14 20:00:00	\N	\N	2	0	\N	\N
273602	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Mission culture - PLF 2019 - Déplacement Ministère de la Culture	Mission culture - PLF 2019 - Déplacement Ministère de la Culture	2018-05-14 11:30:00	2018-05-14 12:30:00	\N	\N	2	0	\N	\N
273603	COM_EURO	DEPLACEMENT	\N	AFEU	\N	Institutions européennes	\N	2018-05-14 08:30:00	2018-05-14 20:00:00	\N	\N	1	0	\N	\N
273619	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Table ronde sur la différenciation territoriale	\N	2018-05-22 16:45:00	2018-05-22 18:15:00	2018-05-22 18:38:39	2018-05-23 16:02:28	18	0	\N	\N
273625	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2018-05-22 17:00:00	2018-05-22 18:50:00	2018-05-23 17:25:55	2018-05-23 17:39:50	26	0	\N	\N
273626	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Mission réflexion FPT	Mission de réflexion sur les enjeux de l'évolution de la fonction publique territoriale	2018-05-15 18:00:00	2018-05-15 20:40:00	\N	\N	1	0	\N	\N
273628	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Mission réflexion FPT	Mission de réflexion sur les enjeux de l'évolution de la fonction publique territoriale	2018-05-16 17:00:00	2018-05-16 20:30:00	\N	\N	1	0	\N	\N
273682	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle - CAS "Gestion du patrimoine immobilier de l'État" - Rome	Contrôle - CAS "Gestion du patrimoine immobilier de l'État" - Rome	2018-05-30 17:50:00	2018-06-01 22:20:00	\N	\N	2	0	\N	\N
278356	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Auditions rapporteur PPL défibrillateur cardiaque 	\N	2018-05-31 09:30:00	2018-05-31 11:30:00	\N	\N	0	0	\N	\N
217317	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Solidarité, insertion et égalité des chances	PLF pour 2018 - Solidarité, insertion et égalité des chances - UNAPEI	2017-11-07 16:30:00	2017-11-07 17:30:00	\N	\N	3	0	\N	\N
217321	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Solidarité, insertion et égalité des chances	PLF pour 2018 - Solidarité, insertion et égalité des chances - NEXEM	2017-11-09 09:30:00	2017-11-09 10:30:00	\N	\N	3	0	\N	\N
217325	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018  - Action extérieure de l'Etat	PLF pour 2018  - Action extérieure de l'Etat - Atout France	2017-11-06 08:30:00	2017-11-06 09:30:00	\N	\N	1	0	\N	\N
217327	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF 2018 Action extérieure de l'Etat - Ministère des affaires étrangères	PLF 2018 Action extérieure de l'Etat - Ministère des affaires étrangères	2017-11-07 09:30:00	2017-11-07 10:30:00	\N	\N	2	0	\N	\N
217330	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018  - Action extérieure de l'Etat	PLF pour 2018  - Action extérieure de l'Etat - Campus France	2017-11-07 16:30:00	2017-11-07 17:30:00	\N	\N	1	0	\N	\N
217332	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Cohésion des territoires	PLF pour 2018 - Cohésion des territoires - Ministère de l'intérieur	2017-11-08 18:30:00	2017-11-08 19:30:00	\N	\N	1	0	\N	\N
217334	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2018 - programme 212	\N	2017-11-07 14:00:00	2017-11-07 15:45:00	\N	\N	2	0	\N	\N
217555	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2018	\N	2017-11-08 16:30:00	2017-11-08 18:30:00	\N	\N	1	0	\N	\N
217557	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2018	\N	2017-11-09 09:30:00	2017-11-09 10:15:00	\N	\N	1	0	\N	\N
217559	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2018	\N	2017-11-09 16:00:00	2017-11-09 17:00:00	\N	\N	1	0	\N	\N
217561	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2018	\N	2017-11-10 10:30:00	2017-11-10 12:00:00	\N	\N	1	0	\N	\N
217563	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2018	\N	2017-11-10 14:30:00	2017-11-10 18:30:00	\N	\N	1	0	\N	\N
225830	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2018 - Examen amendements de séance mission Écologie	PLF pour 2018 - Examen amendements de séance mission Écologie	2017-12-01 14:35:00	2017-12-01 14:45:00	2017-12-01 18:50:23	2017-12-01 18:51:35	9	0	\N	\N
225844	COM_PERMANENTE	AUTRE	\N	CDD	\N	Table ronde  sur le Canal Seine-Nord Europe	Table ronde  sur le Canal Seine-Nord Europe	2017-12-06 09:05:00	2017-12-06 11:00:00	2017-12-06 14:18:24	2017-12-06 16:20:42	43	0	\N	\N
225850	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition   de M. Rémi de Verdilhac, directeur Michelin France	Audition   de M. Rémi de Verdilhac, directeur Michelin France	2017-12-06 09:05:00	2017-12-06 10:30:00	2017-12-06 14:17:31	2017-12-06 16:20:44	34	0	\N	\N
233052	DELEGATION	AUCUNE	\N	\N	DSOM	Audition Mme Laura Flessel	Audition de Mme Laura Flessel, ministre des outre-mer, dans le cadre de l'étude "La jeunese des outre-mer et le sport"	2018-01-24 16:30:00	2018-01-24 18:25:00	2018-01-25 15:45:11	2018-01-25 15:59:06	22	0	\N	\N
233331	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Territoires  Littoraux	PPL Terrtoires Littoraux	2018-01-09 16:15:00	2018-01-09 18:30:00	\N	\N	0	0	\N	\N
233332	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Territoires Littoraux	PPL Territoires Littoraux	2018-01-10 11:15:00	2018-01-10 12:00:00	\N	\N	0	0	\N	\N
233333	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Territoires Littoraux	PPL Territoires Littoraux	2018-01-10 14:00:00	2018-01-10 15:00:00	\N	\N	0	0	\N	\N
235097	BUREAU	AUCUNE	\N	\N	\N	Délégation statut du sénateur	Délégation statut et conditions d'exercice du mandat de sénateur	2018-01-17 15:00:00	2018-01-17 16:15:00	\N	\N	6	0	\N	\N
235169	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe d'amitié France - Mexique et pays d'Amérique centrale	Assemblée générale du groupe d'amitié France - Mexique et pays d'Amérique centrale	2018-01-17 13:45:00	2018-01-17 14:30:00	\N	\N	12	0	643	\N
243237	COM_PERMANENTE	AUTRE	\N	AFCL	\N	ORE amdts du Gouvernement 	ORE amdts du Gouvernement 	2018-02-07 17:00:00	2018-02-07 17:10:00	2018-02-07 17:21:17	2018-02-09 17:02:47	18	0	\N	\N
244111	COM_SPECIALE	AUDRAP	\N	SOCIETE	\N	\N	PJL  pour un Etat au service d'une société de confiance	2018-02-06 09:15:00	2018-02-06 11:00:00	\N	\N	1	0	\N	\N
244113	COM_SPECIALE	AUDRAP	\N	SOCIETE	\N	\N	PJL  pour un Etat au service d'une société de confiance	2018-02-06 14:00:00	2018-02-06 15:45:00	\N	\N	3	0	\N	\N
244115	COM_SPECIALE	AUDRAP	\N	SOCIETE	\N	\N	PJL  pour un Etat au service d'une société de confiance	2018-02-08 09:45:00	2018-02-08 12:45:00	\N	\N	3	0	\N	\N
244117	COM_SPECIALE	AUDRAP	\N	SOCIETE	\N	\N	PJL  pour un Etat au service d'une société de confiance	2018-02-08 15:30:00	2018-02-08 16:30:00	\N	\N	1	0	\N	\N
246170	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Protection des données personnelles	\N	2018-02-07 15:00:00	2018-02-07 18:30:00	\N	\N	1	0	\N	\N
246177	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Protection des données personnelles	\N	2018-02-14 14:45:00	2018-02-14 21:00:00	\N	\N	3	0	\N	\N
249102	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ambassadeur Extraordinaire et Plénipotentiaire d'Angola	Entretien avec l'ambassadeur EetP  d'Angola, chargé de mission pour la Fondation France-Angola	2018-02-20 14:00:00	2018-02-20 15:00:00	\N	\N	2	0	646	\N
249217	GIA	AUCUNE	\N	\N	\N	Entretien avec le ministre adjoint pour les droits de l¿homme et l'ambassadeur d'Egypte 	Entretien avec  M. Ahmed Gamal EDDIN, ministre adjoint pour les droits de l¿homme et M. Ehab BADAWY, Ambassadeur d¿Égypt	2018-02-07 12:15:00	2018-02-07 13:00:00	\N	\N	1	0	617	\N
251537	MECSS	AUDRAP	\N	\N	MECSS	\N	Accès précoce à l'innovation dans le domaine des produits de santé	2018-02-21 15:00:00	2018-02-21 16:30:00	\N	\N	3	0	\N	\N
251541	MECSS	AUDRAP	\N	\N	MECSS	\N	Accès précoce à l'innovation dans le domaine des produits de santé	2018-02-21 16:30:00	2018-02-21 17:30:00	\N	\N	8	0	\N	\N
251793	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Rapprochement France3 / France Bleu	Perspectives de rapprochement entre France3 et France Bleu	2018-03-07 17:30:00	2018-03-07 18:40:00	\N	\N	5	0	\N	\N
256012	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Élection au parlement européen	\N	2018-03-15 11:30:00	2018-03-15 13:30:00	\N	\N	1	0	\N	\N
261484	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat EHPAD	Débat EHPAD	2018-04-03 14:30:00	2018-04-03 16:30:00	\N	\N	97	0	\N	\N
261485	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat IVG	Débat IVG	2018-04-03 17:55:00	2018-04-03 19:45:00	\N	\N	102	0	\N	\N
261486	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Fret ferroviaire	Débat Fret ferroviaire	2018-04-03 16:00:00	2018-04-03 17:00:00	\N	\N	84	0	\N	\N
261487	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Tarification eau	PPL Tarification eau	2018-04-04 14:30:00	2018-04-04 16:05:00	\N	\N	108	0	\N	\N
261489	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Indivision successorale	PPL Indivision successorale	2018-04-04 16:20:00	2018-04-04 18:45:00	\N	\N	88	0	\N	\N
261490	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2018-04-05 15:00:00	2018-04-05 16:05:00	\N	\N	271	0	\N	\N
244228	COM_PERMANENTE	AUDRAP	\N	CDD	\N	\N	\N	2018-02-06 18:00:00	2018-02-06 19:30:00	\N	\N	2	0	\N	\N
261491	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Election conseillers métropolitains	PPL Election conseillers métropolitains	2018-04-05 16:20:00	2018-04-05 19:10:00	\N	\N	82	0	\N	\N
261492	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat études médecine	Débat études médecine	2018-04-05 19:10:00	2018-04-05 20:25:00	\N	\N	33	0	\N	\N
267963	MISSION	AUDRAP	\N	ALSTOM	\N	MI ALSTOM - Auditions président&rapporteur	\N	2018-04-18 14:00:00	2018-04-18 18:00:00	\N	\N	0	0	\N	\N
273314	MISSION	AUDRAP	\N	ALSTOM	\N	MI ALSTOM - Auditions président&rapporteur	\N	2018-05-15 18:00:00	2018-05-15 19:00:00	\N	\N	2	0	\N	\N
273317	MISSION	AUDRAP	\N	ALSTOM	\N	MI ALSTOM - Auditions président&rapporteur	\N	2018-05-16 14:00:00	2018-05-16 15:00:00	\N	\N	2	0	\N	\N
273322	MISSION	AUDRAP	\N	ALSTOM	\N	MI ALSTOM - Auditions président&rapporteur	\N	2018-05-16 15:00:00	2018-05-16 17:00:00	\N	\N	1	0	\N	\N
273329	ETUDES	AUCUNE	\N	\N	\N	\N	\N	2018-05-16 08:00:00	2018-05-16 09:00:00	\N	\N	23	0	\N	906
273384	ETUDES	AUCUNE	\N	\N	\N	\N	\N	2018-05-16 08:00:00	2018-05-16 09:30:00	\N	\N	9	0	\N	912
285994	COM_PERMANENTE	AUTRE	\N	FINC	\N	Auditions sur le Projet de loi relatif à la lutte contre la fraude	Auditions sur le Projet de loi relatif à la lutte contre la fraude - ONG puis Cour de cassation	2018-06-20 09:40:00	2018-06-20 12:30:00	2018-06-20 13:21:51	2018-06-20 16:07:07	30	0	\N	\N
285998	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition enjeux financement des jeux Olympiques et Paralympiques de Paris 2024	Audition sur les enjeux liés au financement des jeux Olympiques et Paralympiques de Paris 2024	2018-06-20 14:05:00	2018-06-20 16:05:00	2018-06-21 15:21:32	2018-06-21 17:02:15	13	0	\N	\N
286003	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de M. Stéphane TRAVERT, ministre de l'agriculture - exécution crédits Agriculture	Audition de M. Stéphane TRAVERT, ministre de l'agriculture - éxécution des crédits de la mission Agriculture	2018-06-21 13:50:00	2018-06-21 14:50:00	2018-06-22 15:47:14	2018-06-22 15:49:26	9	0	\N	\N
286212	COM_EURO	AUDRAP	\N	AFEU	\N	Réforme de l'Autorité européenne de sécurité des aliments (AESA / EFSA)	Audition de représentants de l'Association nationale des industries alimentaires	2018-06-12 18:05:00	2018-06-12 19:20:00	\N	\N	2	0	\N	\N
286239	COM_ENQUETE	AUTRE	\N	HAUTE	\N	Audition plénière	\N	2018-06-15 10:35:00	2018-06-15 11:45:00	\N	\N	0	0	\N	\N
286267	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition plénière	\N	2018-06-19 18:15:00	2018-06-19 19:30:00	2018-06-19 19:37:28	2018-06-20 16:07:13	27	0	\N	\N
286271	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	Meunier, Cavallier, Tournay	\N	2018-06-22 09:00:00	2018-06-22 12:00:00	\N	\N	0	0	\N	\N
286272	AUTRE_TEMPORAIRE	AUTRE_NON_PLENIERE	\N	\N	\N	\N	\N	2018-06-22 09:00:00	2018-06-22 10:00:00	\N	\N	0	0	\N	\N
286273	AUTRE_TEMPORAIRE	AUTRE_NON_PLENIERE	\N	\N	\N	\N	\N	2018-06-22 10:00:00	2018-06-22 11:00:00	\N	\N	0	0	\N	\N
293993	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion - Audition JM Blanquer	Réunion - Audition JM Blanquer	2018-07-04 10:30:00	2018-07-04 12:25:00	2018-07-04 12:44:11	2018-07-04 15:24:23	30	1	\N	\N
317338	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLF pour 2019 - Mission Administration pénitentiaire	\N	2018-10-25 13:45:00	2018-10-25 14:30:00	\N	\N	1	0	\N	\N
317383	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLF pour 2019 - Mission Administration pénitentiaire	\N	2018-10-25 17:30:00	2018-10-25 18:15:00	\N	\N	1	0	\N	\N
317513	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Sport	PLF 2019 - Crédits Sport	2018-10-23 16:15:00	2018-10-23 17:00:00	\N	\N	1	0	\N	\N
317526	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Enseignement scolaire	PLF 2019 - Crédits Enseignement scolaire	2018-10-24 17:00:00	2018-10-24 18:00:00	\N	\N	1	0	\N	\N
317528	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Enseignement scolaire	PLF 2019 - Crédits Enseignement scolaire	2018-10-24 18:00:00	2018-10-24 19:00:00	\N	\N	1	0	\N	\N
317530	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Livre et Industries culturelles	PLF 2019 - Crédits Livre et Industries culturelles	2018-10-25 09:30:00	2018-10-25 10:30:00	\N	\N	1	0	\N	\N
317532	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Enseignement scolaire	PLF 2019 - Crédits Enseignement scolaire	2018-10-25 14:00:00	2018-10-25 15:00:00	\N	\N	1	0	\N	\N
317535	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Jeunesse et vie associative	PLF 2019 - Crédits Jeunesse et vie associative	2018-10-25 08:30:00	2018-10-25 12:15:00	\N	\N	1	0	\N	\N
317537	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Enseignement scolaire	PLF 2019 - Crédits Enseignement scolaire	2018-10-25 09:45:00	2018-10-25 12:00:00	\N	\N	1	0	\N	\N
317539	ETUDES	AUCUNE	\N	\N	\N	G.E. "Section Cultures traditionnelles et spécialisées"	G.E. "Section Cultures traditionnelles et spécialisées"	2018-10-24 08:00:00	2018-10-24 09:00:00	\N	\N	17	0	\N	1005
317638	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions rapporteur PLF 2019 DAG	\N	2018-10-29 14:15:00	2018-10-29 18:00:00	\N	\N	1	0	\N	\N
317770	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	PJLF pour 2019 - Mission Administration pénitentiaire (déplacmt maison d'arrêt Nanterre)	\N	2018-10-30 09:30:00	2018-10-30 16:00:00	\N	\N	3	0	\N	\N
318038	COM_PERMANENTE	AUTRE	\N	CDD	\N	Audition plénière	\N	2018-11-07 10:30:00	2018-11-07 12:10:00	2018-11-07 14:59:04	2018-11-07 15:25:35	32	2	\N	\N
318044	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Plf 2019 - Crédits de l'audiovisuel public	Plf 2019 - Crédits de l'audiovisuel public	2018-10-30 15:00:00	2018-10-30 16:00:00	\N	\N	2	0	\N	\N
318047	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Plf 2019 - Crédits de l'audiovisuel public	Plf 2019 - Crédits de l'audiovisuel public	2018-10-30 16:00:00	2018-10-30 16:45:00	\N	\N	2	0	\N	\N
318050	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2018-11-07 17:05:00	2018-11-07 19:30:00	2018-11-08 14:55:16	2018-11-08 16:20:45	36	0	\N	\N
318328	COM_SPECIALE	PLENIERE	\N	SURTRANSPO	\N	Réunion plénière	\N	2018-10-30 18:00:00	2018-10-30 21:00:00	2018-10-31 15:48:11	2018-10-31 16:28:31	21	0	\N	\N
318342	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Déplacement PLF 2019 Conseil et contrôle de l'Etat	\N	2018-10-26 08:00:00	2018-10-26 18:30:00	\N	\N	1	0	\N	\N
318369	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - MIRES Recherche - CIR / IRSTEA / DGRI / Cabinet Ministre	PLF pour 2019 - MIRES Recherche - CIR / IRSTEA / DGRI / Cabinet Ministre	2018-10-29 16:00:00	2018-10-29 20:00:00	\N	\N	1	0	\N	\N
318797	DELEGATION	AUCUNE	\N	\N	COLTER	Table ronde collectivités territoriales métropole de Lyon	\N	2018-11-08 09:00:00	2018-11-08 10:45:00	2018-11-08 11:13:41	2018-11-08 15:47:11	10	0	\N	\N
293992	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion	Réunion	2018-07-04 09:05:00	2018-07-04 10:15:00	2018-07-04 15:23:45	2018-07-04 15:56:53	34	1	\N	\N
318863	COM_SPECIALE	PLENIERE	\N	RETRAIT	\N	Examen amendements de séance	\N	2018-11-06 09:35:00	2018-11-06 10:20:00	2018-11-09 11:28:06	2018-11-09 12:18:36	17	0	\N	\N
319040	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Sport	PLF 2019 - Crédits Sport	2018-10-31 17:00:00	2018-10-31 18:00:00	\N	\N	2	0	\N	\N
319583	GIA	AUCUNE	\N	\N	\N	Vice-Premier ministre du Vietnam	Audience à la présidence du Vic-Premier ministre du Vietnam	2018-10-26 11:15:00	2018-10-26 12:00:00	\N	\N	1	0	626	\N
319592	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation	Accueil d'une délégation dans le cadre de l'AVSE	2018-10-31 14:00:00	2018-10-31 15:00:00	\N	\N	1	0	626	\N
319833	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2018-11-06 14:00:00	2018-11-06 16:40:00	\N	\N	3	0	\N	\N
320182	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2019 - Mission outre-mer	\N	2018-11-16 15:15:00	2018-11-16 16:45:00	\N	\N	2	0	\N	\N
320563	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière - Audition publique Parcoursup / Examen projet note Huile de palme	Réunion plénière - Audition publique Parcoursup / Examen projet note Huile de palme	2018-11-22 10:00:00	2018-11-22 12:50:00	2018-11-23 15:26:19	\N	9	0	\N	\N
320699	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Culture (Création, Transmission, Démocratisation)	PLF 2019 - Crédits Culture (Création, Transmission, Démocratisation)	2018-11-07 14:10:00	2018-11-07 15:15:00	\N	\N	1	0	\N	\N
320701	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Culture (Création, Transmission, Démocratisation)	PLF 2019 - Crédits Culture (Création, Transmission, Démocratisation)	2018-11-07 15:15:00	2018-11-07 16:30:00	\N	\N	4	0	\N	\N
320706	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Culture (Patrimoine)	PLF 2019 - Crédits Culture (Patrimoine)	2018-11-07 16:20:00	2018-11-07 17:05:00	\N	\N	2	0	\N	\N
320709	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Lutter contre l'exposition précoce des enfants aux écrans	PPL Lutter contre l'exposition précoce des enfants aux écrans	2018-11-06 09:00:00	2018-11-06 10:00:00	\N	\N	1	0	\N	\N
320710	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2018-11-13 18:05:00	2018-11-13 20:05:00	2018-11-14 14:42:25	2018-11-14 15:06:11	36	0	\N	\N
320712	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Lutter contre l'exposition précoce des enfants aux écrans	PPL Lutter contre l'exposition précoce des enfants aux écrans	2018-11-07 11:00:00	2018-11-07 12:00:00	\N	\N	1	0	\N	\N
220352	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF pour 2018 - Mission "enseignement supérieur et recherche"	PJLF pour 2018 - Mission "enseignement supérieur et recherche"	2017-11-14 15:30:00	2017-11-14 16:30:00	\N	\N	1	0	\N	\N
220354	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF pour 2018 - Avis "enseignement supérieur et recherche"	PJLF pour 2018 - Avis "enseignement supérieur et recherche"	2017-11-15 15:30:00	2017-11-15 16:30:00	\N	\N	1	0	\N	\N
220356	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF pour 2018 - Avis "énergie"	PJLF pour 2018 - Avis "énergie"	2017-11-14 14:00:00	2017-11-14 17:30:00	\N	\N	1	0	\N	\N
220358	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF pour 2018 - Avis "énergie"	PJLF pour 2018 - Avis "énergie"	2017-11-16 09:00:00	2017-11-16 12:00:00	\N	\N	1	0	\N	\N
220361	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF pour 2018 - Avis "agriculture"	PJLF pour 2018 - Avis "agriculture"	2017-11-14 11:45:00	2017-11-14 12:30:00	\N	\N	2	0	\N	\N
222236	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL n° 6 Brevet	\N	2017-11-22 15:30:00	2017-11-22 16:55:00	\N	\N	1	0	\N	\N
223265	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PLF 2018 (Justice)	\N	2017-11-28 09:10:00	2017-11-28 11:00:00	2017-11-28 11:52:35	2017-11-28 15:43:31	30	0	\N	\N
226755	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Orientation et réussite des étudiants	PJL Orientation et réussite des étudiants	2017-12-05 11:15:00	2017-12-05 12:00:00	\N	\N	1	0	\N	\N
226757	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Orientation et réussite des étudiants	PJL Orientation et réussite des étudiants	2017-12-05 14:00:00	2017-12-05 15:00:00	\N	\N	2	0	\N	\N
226760	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Orientation et réussite des étudiants	PJL Orientation et réussite des étudiants	2017-12-05 15:30:00	2017-12-05 16:30:00	\N	\N	2	0	\N	\N
226763	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Orientation et réussite des étudiants	PJL Orientation et réussite des étudiants	2017-12-05 16:30:00	2017-12-05 17:30:00	\N	\N	2	0	\N	\N
228592	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2018 - Examen d'un amendement du gouvernement	PLF pour 2018 - Examen d'un amendement du gouvernement	2017-12-11 18:15:00	2017-12-11 18:20:00	2017-12-12 09:26:57	2017-12-12 16:10:26	10	0	\N	\N
232317	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Quatre conventions internationales	Quatre conventions internationales	2017-12-20 14:30:00	2017-12-20 14:35:00	\N	\N	58	0	\N	\N
232318	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Professions de santé	CMP Professions de santé	2017-12-20 15:45:00	2017-12-20 16:20:00	\N	\N	39	0	\N	\N
232319	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Gemapi	CMP Gemapi	2017-12-20 16:25:00	2017-12-20 17:10:00	\N	\N	33	0	\N	\N
236072	DELEGATION	DEPLACEMENT	\N	\N	206	Visite usine ENERCON	Visite de l'usine ENERCON, premier constructeur d'éoliennes terrestres en France	2018-02-01 08:00:00	2018-02-01 12:30:00	\N	\N	3	0	\N	\N
247284	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	862	\N	\N	Explications de vote sur l'ensemble du PJL Nouvelle-Calédonie	Explications de vote sur l'ensemble du PJL Nouvelle-Calédonie	2018-02-20 15:05:00	2018-02-20 15:55:00	\N	\N	308	0	\N	\N
278357	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Auditions rapporteur PPL défibrillateur cardiaque 	\N	2018-05-31 13:00:00	2018-05-31 13:45:00	\N	\N	0	0	\N	\N
318859	COM_PERMANENTE	AUTRE	\N	ETRD	\N	PLF pour 2019 - Avis budgétaires	\N	2018-11-07 09:30:00	2018-11-07 12:05:00	2018-11-07 14:41:31	2018-11-07 15:25:36	41	1	\N	\N
320098	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2018-11-07 09:40:00	2018-11-07 11:05:00	2018-11-07 11:31:36	2018-11-07 11:35:21	42	1	\N	\N
320713	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2018-11-14 09:30:00	2018-11-14 11:55:00	2018-11-14 14:54:44	2018-11-14 15:06:10	44	1	\N	\N
247285	SEANCE_PLENIERE	SCRUSOL	862	\N	\N	Scrutin solennel PJL Nouvelle-Calédonie	Scrutin solennel PJL Nouvelle-Calédonie	2018-02-20 16:00:00	2018-02-20 16:30:00	\N	\N	0	0	\N	\N
251195	DELEGATION	AUCUNE	\N	\N	206	Audition de l'Agence de la biomédecine	Audition, ouverte à la presse, de Mme Anne Courrèges, directrice générale de l'Agence de la biomédecine	2018-03-22 09:10:00	2018-03-22 11:40:00	2018-03-23 11:00:51	2018-03-23 11:03:48	10	0	\N	\N
251235	CONF_PRES	AUCUNE	\N	\N	\N	\N	\N	2018-02-06 16:25:00	2018-02-06 16:35:00	\N	\N	24	0	\N	\N
251313	CONF_PRES	AUCUNE	\N	\N	\N	\N	\N	2018-01-31 19:05:00	2018-01-31 20:05:00	\N	\N	23	0	\N	\N
251360	CONF_PRES	AUCUNE	\N	\N	\N	\N	\N	2017-12-13 18:35:00	2017-12-13 19:40:00	\N	\N	31	0	\N	\N
251432	CONF_PRES	AUCUNE	\N	\N	\N	\N	\N	2017-11-08 19:05:00	2017-11-08 19:30:00	\N	\N	24	0	\N	\N
251458	CONF_PRES	AUCUNE	\N	\N	\N	\N	\N	2017-10-24 18:05:00	2017-10-24 18:25:00	\N	\N	23	0	\N	\N
251499	CONF_PRES	AUCUNE	\N	\N	\N	\N	\N	2017-10-05 17:05:00	2017-10-05 17:55:00	\N	\N	26	0	\N	\N
253897	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Chaîne des aides agricoles et ASP	Contrôle Chaîne des aides agricoles et ASP - Audition ministère des finances	2018-03-06 16:30:00	2018-03-06 18:30:00	\N	\N	2	0	\N	\N
254024	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT AFEU - Négociations commerciales de l'UE	GT AFEU - Négociations commerciales de l'UE	2018-03-13 14:30:00	2018-03-13 15:50:00	\N	\N	8	0	\N	\N
258039	MISSION	AUCUNE	\N	MINEURSENF	\N	\N	\N	2018-03-21 13:30:00	2018-03-21 14:15:00	2018-03-21 15:42:38	2018-03-21 15:42:45	20	0	\N	\N
258947	DELEGATION	AUDRAP	\N	\N	206	Audition du Dr Pierre Lévy-Soussan, pédopsychiatre	Audition du Dr Pierre Lévy-Soussan, pédopsychiatre, membre du conseil d'orientation de l'Agence de la biomédecine	2018-04-04 16:00:00	2018-04-04 17:00:00	\N	\N	3	0	\N	\N
258948	DELEGATION	AUDRAP	\N	\N	206	Audition de Mme Dominique Stoppa-Lyonnet, professeur en génétique médicale	Audition de Mme Dominique Stoppa-Lyonnet, professeur en génétique médicale à l'Université Paris-Descartes	2018-04-04 17:00:00	2018-04-04 18:00:00	\N	\N	0	0	\N	\N
258949	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Jean-Paul Delahaye, professeur des universités	Audition de M. Jean-Paul Delahaye, professeur des universités	2018-04-04 10:00:00	2018-04-04 11:00:00	\N	\N	2	0	\N	\N
258950	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Manuel Valente, directeur de la Maison du Bitcoin	Audition de M. Manuel Valente, directeur de la Maison du Bitcoin	2018-04-04 11:00:00	2018-04-04 12:00:00	\N	\N	2	0	\N	\N
258951	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Gérard Memmi, Télécom ParisTech	Audition de M. Gérard Memmi, responsable du département d'informatique de Télécom ParisTech	2018-04-04 12:00:00	2018-04-04 13:00:00	\N	\N	2	0	\N	\N
258967	MECSS	AUDRAP	\N	\N	MECSS	\N	Accès précoce à l'innovation dans le domaine des produits de santé	2018-03-28 14:30:00	2018-03-28 15:30:00	\N	\N	5	0	\N	\N
258968	MECSS	AUDRAP	\N	\N	MECSS	\N	Accès précoce à l'innovation dans le domaine des produits de santé	2018-04-04 16:00:00	2018-04-04 18:00:00	\N	\N	6	0	\N	\N
258969	MECSS	AUDRAP	\N	\N	MECSS	\N	Accès précoce à l'innovation dans le domaine des produits de santé	2018-04-11 15:00:00	2018-04-11 17:00:00	\N	\N	3	0	\N	\N
258989	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	\N	GT Financement du handicap	2018-03-27 15:45:00	2018-03-27 16:30:00	\N	\N	3	0	\N	\N
258991	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	\N	GT Financement du handicap	2018-03-28 15:00:00	2018-03-28 16:00:00	\N	\N	3	0	\N	\N
260582	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Stevo Pendarovski, coordinateur national de la Macédoine pour l'OTAN	Entretien avec M. Stevo Pendarovski, coordinateur national de la Macédoine pour l'OTAN	2018-03-28 13:00:00	2018-03-28 15:05:00	\N	\N	3	0	674	\N
260590	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de M. Olivier Dussopt	\N	2018-04-04 18:00:00	2018-04-04 18:40:00	2018-04-04 18:48:31	2018-04-05 09:46:50	22	0	\N	\N
260596	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Conclusions de M. Milon Rappel produits alimentaires présentant un risque sanitaire	\N	2018-04-05 11:00:00	2018-04-05 12:00:00	2018-04-05 14:36:58	2018-04-05 18:07:42	52	0	\N	\N
273700	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	\N	GT Financement du handicap	2018-06-05 18:00:00	2018-06-05 20:00:00	\N	\N	1	0	\N	\N
273702	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	GT Financement du handicap	GT Financement du handicap	2018-06-07 14:00:00	2018-06-07 15:00:00	\N	\N	2	0	\N	\N
273704	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	GT Financement du handicap	GT Financement du handicap	2018-06-07 16:00:00	2018-06-07 18:00:00	\N	\N	2	0	\N	\N
273706	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Nomination et présence des parlementaires dans certains OEP	\N	2018-05-15 16:00:00	2018-05-15 16:30:00	\N	\N	1	0	\N	\N
273708	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Nomination et présence des parlementaires dans certains OEP	\N	2018-05-16 10:30:00	2018-05-16 11:30:00	\N	\N	2	0	\N	\N
273711	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Nomination et présence des parlementaires dans certains OEP	\N	2018-05-16 11:30:00	2018-05-16 12:00:00	\N	\N	1	0	\N	\N
275294	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Ministres des cultes et membres des congrégations religieuses	\N	2018-05-22 09:00:00	2018-05-22 09:30:00	\N	\N	1	0	\N	\N
275296	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Ministres des cultes et membres des congrégations religieuses	\N	2018-05-23 15:50:00	2018-05-23 17:30:00	\N	\N	1	0	\N	\N
275298	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Mission Mécénat	Mission Mécénat	2018-05-23 14:30:00	2018-05-23 15:40:00	\N	\N	6	0	\N	\N
275305	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Mission Mécénat	Mission Mécénat	2018-05-23 15:40:00	2018-05-23 17:30:00	\N	\N	7	0	\N	\N
275315	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Mission Mécénat	Mission Mécénat	2018-05-23 17:30:00	2018-05-23 18:30:00	\N	\N	4	0	\N	\N
275342	ETUDES	AUCUNE	\N	\N	\N	GE Francophonie	GE Francophonie	2018-05-24 14:00:00	2018-05-24 15:00:00	\N	\N	7	0	\N	1006
275757	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition 58-2 personnels contractuels dans l'Éducation nationale	Audition 58-2 personnels contractuels dans l'Éducation nationale	2018-05-30 10:40:00	2018-05-30 12:40:00	2018-06-01 09:48:27	2018-06-01 09:49:35	20	1	\N	\N
275758	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de M. Didier MIGAUD sur comptes de l'État et Loi de Rglt 2017	Audition de M. Didier MIGAUD sur comptes de l'État et Loi de Rglt 2017	2018-05-30 15:00:00	2018-05-30 16:40:00	2018-06-01 09:43:41	2018-06-01 09:49:36	28	1	\N	\N
275759	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle CAS immo - SG Ministère Justice	Contrôle CAS immo - SG Ministère Justice	2018-05-24 14:00:00	2018-05-24 14:45:00	\N	\N	2	0	\N	\N
275785	ETUDES	AUCUNE	\N	\N	\N	\N	\N	2018-05-24 16:00:00	2018-05-24 18:15:00	\N	\N	2	0	\N	966
276026	GIA	AUCUNE	\N	\N	\N	Entretien de Mme DEROMEDI avec M. S. ISWARANT Ministre de la Communication (coopé)	Entretien de Mme DEROMEDI avec M. S. ISWARANT Ministre de la Communication (coopé)	2018-05-22 15:00:00	2018-05-22 16:00:00	\N	\N	1	0	609	\N
278103	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL pour la liberté de choisir son avenir professionnel	PJL pour la liberté de choisir son avenir professionnel	2018-05-31 09:00:00	2018-05-31 12:00:00	\N	\N	4	0	\N	\N
278907	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Mission Mécénat	Mission Mécénat	2018-05-30 14:45:00	2018-05-30 16:15:00	\N	\N	6	0	\N	\N
278916	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2018-05-30 14:45:00	2018-05-30 17:30:00	\N	\N	3	0	\N	\N
279435	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Agriculture	\N	2018-06-04 14:30:00	2018-06-04 21:00:00	\N	\N	1	0	\N	\N
280501	COM_EURO	AUDRAP	\N	AFEU	\N	Réforme de l'Autorité européenne de sécurité des aliments	Entretien avec des représentants de l'ANSES	2018-06-05 17:05:00	2018-06-05 18:30:00	\N	\N	1	0	\N	\N
281355	DELEGATION	AUCUNE	\N	\N	211	Audition de M. Ferdinand Mélin-Soucramanien - révision constitutionnelle	Audition de M. Ferdinand Mélin-Soucramanien - révision constitutionnelle	2018-07-05 08:30:00	2018-07-05 09:45:00	2018-07-05 13:25:25	2018-07-05 16:05:39	7	0	\N	\N
281395	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions ELAN (Avis ATDD - M. Patrick Chaize)	\N	2018-06-06 15:30:00	2018-06-06 18:15:00	\N	\N	1	0	\N	\N
281410	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions ELAN (Avis ATDD - M. Patrick CHAIZE)	\N	2018-06-07 09:00:00	2018-06-07 12:00:00	\N	\N	1	0	\N	\N
282023	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Libye	\N	2018-06-05 16:00:00	2018-06-05 17:00:00	\N	\N	4	0	\N	\N
282040	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Libye	\N	2018-06-05 17:00:00	2018-06-05 18:15:00	\N	\N	3	0	\N	\N
282053	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Programme 129	\N	2018-06-07 14:00:00	2018-06-07 15:00:00	\N	\N	2	0	\N	\N
282411	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Réseau enseignement français à l'étranger - Sénateur des français hors de France	Contrôle Réseau enseignement français à l'étranger - Sénateur des français établis hors de France	2018-06-07 16:15:00	2018-06-07 17:30:00	\N	\N	1	0	\N	\N
282417	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Audition de Franck TERNER directeur général d'Air France	\N	2018-06-07 06:30:00	2018-06-07 08:30:00	\N	\N	0	0	\N	\N
283118	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Réforme de la procédure budgétaire - Déplacement Berlin	Réforme de la procédure budgétaire - Déplacement Berlin	2018-06-13 10:30:00	2018-06-14 20:30:00	\N	\N	2	0	\N	\N
283431	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2018 - Réseau enseignement français à l'étranger - Déplacement à Zurich	Contrôle 2018 - Réseau enseignement français à l'étranger - Déplacement à Zurich	2018-06-15 07:35:00	2018-06-15 19:50:00	\N	\N	1	0	\N	\N
286249	COM_EURO	AUTRE_NON_PLENIERE	\N	AFEU	\N	Entretien du bureau avec M. Thierry Breton, PDG d'ATOS	Entretien du bureau avec M. Thierry Breton, PDG d'ATOS	2018-06-12 15:30:00	2018-06-12 16:30:00	\N	\N	7	0	\N	\N
286257	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	Politique de cohésion régionale de l'Union européenne	Audition de représentants du Secrétariat général des affaires européennes	2018-06-13 17:30:00	2018-06-13 18:40:00	\N	\N	3	0	\N	\N
286261	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	Politique de cohésion régionale de l'Union européenne	Examen du projet de proposition de résolution européenne	2018-06-14 11:00:00	2018-06-14 11:45:00	\N	\N	5	0	\N	\N
286268	GIA	AUCUNE	\N	\N	\N	Entretien de Mme F. Keller avec Mme Ka Kumba JAITEH, députée gambienne (coopé)	Entretien de Mme F. Keller avec Mme Ka Kumba JAITEH, députée gambienne (coopé)	2018-06-06 17:15:00	2018-06-06 17:45:00	\N	\N	1	0	573	\N
286409	GIA	AUCUNE	\N	\N	\N	Entretien avec Mme  NINJJAMTS,  directrice de la télévision nationale (MNB)	Entretien avec Mme  NINJJAMTS,  directrice de la télévision nationale (MNB) et M.ENKHTUR, président de l'Ecole de Police	2018-06-13 13:15:00	2018-06-13 14:15:00	\N	\N	2	0	612	\N
286619	COM_ENQUETE	PLENIERE	\N	HAUTE	\N	Audition	Audition	2018-06-19 09:15:00	2018-06-19 10:25:00	2018-06-19 16:28:58	2018-06-19 17:52:51	5	0	\N	\N
286650	GIA	AUCUNE	\N	\N	\N	AG	assemblée générale	2018-06-19 14:30:00	2018-06-19 15:00:00	\N	\N	7	0	663	\N
287283	GIA	AUCUNE	\N	\N	\N	Audition Délégué RPDC	Audition du délégué général de la République populaire démocratique de Corée	2018-06-19 13:45:00	2018-06-19 15:10:00	\N	\N	7	0	586	\N
287293	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2018-06-20 09:30:00	2018-06-20 11:15:00	2018-06-20 12:09:53	2018-06-20 16:07:10	37	0	\N	\N
289495	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL "Agriculture"	PJL "Agriculture"	2018-05-30 16:00:00	2018-05-30 18:00:00	\N	\N	2	0	\N	\N
289498	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL "Agriculture"	PJL "Agriculture"	2018-05-31 11:00:00	2018-05-31 13:00:00	\N	\N	2	0	\N	\N
289501	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL "Agriculture"	PJL"Agriculture"	2018-06-01 10:00:00	2018-06-01 12:00:00	\N	\N	2	0	\N	\N
289504	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL "Agriculture"	PJL "Agriculture"	2018-06-01 15:00:00	2018-06-01 17:00:00	\N	\N	2	0	\N	\N
289507	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL "Agriculture"	PJL "Agriculture"	2018-06-05 16:30:00	2018-06-05 17:30:00	\N	\N	2	0	\N	\N
291974	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions GT fiche S	\N	2018-06-21 08:30:00	2018-06-21 09:30:00	\N	\N	3	0	\N	\N
292067	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF 2019 - "Mission Immigration, asile, intégration" - Déplacement France Terre d'asile	PLF 2019 - "Mission Immigration, asile, intégration" - Déplacement France Terre d'asile	2018-06-26 08:30:00	2018-06-26 10:30:00	\N	\N	1	0	\N	\N
214488	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Modalités de dépôt de candidature aux élections	\N	2017-10-31 12:00:00	2017-10-31 12:30:00	\N	\N	3	0	\N	\N
214492	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de Mme Parly	\N	2017-11-07 16:35:00	2017-11-07 18:15:00	2017-11-08 14:42:29	2017-11-08 15:55:42	40	0	\N	\N
214583	COM_PERMANENTE	AUTRE	\N	FINC	\N	Rapport avis PLFSS pour 2018 - PLF pour 2018  Examen rapports Travail et emploi - Culture	Rapport avis PLFSS pour 2018 - PLF pour 2018  Examen rapports Travail et emploi - Culture	2017-11-07 14:35:00	2017-11-07 17:00:00	2017-11-08 10:59:52	2017-11-08 14:33:27	36	0	\N	\N
214584	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition Pierre MOSCOVICI sur Stabilité 	Audition Pierre MOSCOVICI sur le pacte de Stabilité 	2017-11-07 17:30:00	2017-11-07 19:05:00	2017-11-10 15:37:36	2017-11-10 16:02:02	42	0	\N	\N
214588	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2018 : rapports Agriculture - Investissements d'avenir - Défense	PLF pour 2018 : rapports Agriculture - Investissements d'avenir - Défense	2017-11-08 14:35:00	2017-11-08 16:10:00	2017-11-09 09:49:43	2017-11-09 15:57:17	31	0	\N	\N
270355	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Mission Établissements publics de coopération culturelle	\N	2018-05-02 14:00:00	2018-05-02 15:00:00	\N	\N	1	0	\N	\N
286679	CMP	AUTRE	\N	LPM	\N	PJL Programmation militaire pour les années 2019 à 2025	PJL Programmation militaire pour les années 2019 à 2025	2018-06-19 14:58:00	2018-06-19 16:04:00	\N	\N	12	0	\N	\N
214589	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition Jean-Michel BLANQUER sur le PLF pour 2018	Audition Jean-Michel BLANQUER sur le PLF pour 2018	2017-11-08 16:35:00	2017-11-08 18:20:00	2017-11-10 09:59:58	2017-11-10 16:01:58	30	0	\N	\N
214590	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen Amdts de séance sur le PLFR pour 2017	Examen Amdts de séance sur le PLFR pour 2017	2017-11-09 14:35:00	2017-11-09 14:55:00	2017-11-10 15:59:13	2017-11-10 16:01:53	19	0	\N	\N
223399	MISSION	AUCUNE	\N	ALSTOM	\N	Réunion constitutive	Réunion constitutive	2017-11-29 18:00:00	2017-11-29 18:45:00	2017-11-30 14:17:24	2017-11-30 14:46:31	19	0	\N	\N
225237	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2017-11-28 14:30:00	2017-11-28 16:30:00	\N	\N	3	0	\N	\N
225918	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Mission "Routes de la soie"	\N	2017-11-30 11:00:00	2017-11-30 12:15:00	\N	\N	2	0	\N	\N
225935	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	GT revitalisation - Table ronde professionnels enseignes de centre-ville	\N	2017-12-06 15:00:00	2017-12-06 16:30:00	\N	\N	12	0	\N	\N
225949	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	GT revitalisation - Table ronde des experts	\N	2017-12-07 14:00:00	2017-12-07 15:30:00	\N	\N	7	0	\N	\N
227651	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	GT Infractions sexuelles	2017-12-05 14:30:00	2017-12-05 16:30:00	\N	\N	4	0	\N	\N
227656	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	GT Infractions sexuelles	2017-12-06 16:30:00	2017-12-06 17:30:00	\N	\N	5	0	\N	\N
228515	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2017-12-07 12:50:00	2017-12-07 13:05:00	\N	\N	3	0	\N	\N
229482	GIA	AUCUNE	\N	\N	\N	Entretien avec MM. Gilles Rémy et Jürgen Krahn	Entretien avec MM. Gilles Rémy (commission Eurasie du CCEF, chambre de commerce France-Turkménistan) et Jürgen Krahn	2017-12-13 14:00:00	2017-12-13 14:30:00	\N	\N	2	0	556	\N
230542	COM_PERMANENTE	DEPLACEMENT	\N	CAE	\N	Déplacement de la commission des affaires économiques à Rungis	Déplacement de la commission des affaires économiques à Rungis	2017-12-14 04:00:00	2017-12-14 09:30:00	\N	\N	16	0	\N	\N
233007	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI thanatopraxie	MI thanatopraxie	2018-01-10 10:30:00	2018-01-10 12:00:00	\N	\N	1	0	\N	\N
233200	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL JO 2024	PJL JO 2024	2018-01-09 14:30:00	2018-01-09 15:45:00	\N	\N	1	0	\N	\N
233203	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Réforme du logement	\N	2018-01-10 10:00:00	2018-01-10 11:45:00	\N	\N	1	0	\N	\N
238791	GIA	AUCUNE	\N	\N	\N	Petit-déjeuner en présence de l'ambvassadeur de Cuba	Petit-déjeuner en présence de l'ambvassadeur de Cuba M. Elio RODRIGUEZ PERDOMO	2018-01-25 08:30:00	2018-01-25 09:30:00	\N	\N	6	0	642	\N
238881	GIA	AUCUNE	\N	\N	\N	Assemblée générale	Assemblée générale du grouped 'amitié	2018-01-24 14:00:00	2018-01-25 14:30:00	\N	\N	11	0	601	\N
246411	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	\N	\N	2018-02-12 14:30:00	2018-02-12 17:30:00	\N	\N	1	0	\N	\N
246413	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Libye	\N	2018-02-14 17:00:00	2018-02-14 18:15:00	\N	\N	3	0	\N	\N
250141	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	GT revitalisation : table ronde centres commerciaux	\N	2018-03-07 15:00:00	2018-03-07 16:30:00	\N	\N	5	0	\N	\N
253071	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Libye	\N	2018-03-07 14:00:00	2018-03-07 15:45:00	\N	\N	2	0	\N	\N
258932	COM_ENQUETE	PLENIERE	\N	CHUTE	\N	Questions diverses	Echanges de vues	2018-04-04 18:10:00	2018-04-04 19:05:00	2018-04-06 09:22:43	2018-04-06 14:33:55	12	0	\N	\N
258933	COM_ENQUETE	PLENIERE	\N	CHUTE	\N	Audition plénière	\N	2018-04-11 16:10:00	2018-04-11 17:05:00	2018-04-13 17:58:41	2018-04-13 18:05:14	7	0	\N	\N
258935	COM_ENQUETE	AUTRE	\N	CHUTE	\N	Audition plénière	\N	2018-04-12 15:00:00	2018-04-12 16:00:00	2018-04-13 17:59:20	2018-04-13 18:05:16	10	0	\N	\N
258936	COM_ENQUETE	AUTRE	\N	CHUTE	\N	Audition plénière	\N	2018-04-19 09:05:00	2018-04-19 10:40:00	2018-06-26 16:12:52	\N	11	0	\N	\N
258937	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2018-03-28 09:00:00	2018-03-28 10:10:00	2018-03-28 11:31:26	2018-03-28 11:39:29	63	0	\N	\N
258945	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur	MI thanatopraxie	2018-03-22 10:00:00	2018-03-22 11:30:00	\N	\N	1	0	\N	\N
258952	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission CAE	Conclusions, en commun avec la commission des affaires sociales, sur l'affaire Lactalis	2018-03-28 09:10:00	2018-03-28 10:10:00	2018-03-28 12:14:44	2018-03-28 12:20:24	63	0	\N	\N
258963	AUTRE_TEMPORAIRE	AUTRE_NON_PLENIERE	\N	\N	\N	\N	\N	2018-03-28 15:30:00	2018-03-28 16:30:00	\N	\N	0	0	\N	\N
258964	AUTRE_TEMPORAIRE	AUTRE_NON_PLENIERE	\N	\N	\N	\N	\N	2018-04-04 16:00:00	2018-04-04 17:00:00	\N	\N	0	0	\N	\N
258965	AUTRE_TEMPORAIRE	AUTRE_NON_PLENIERE	\N	\N	\N	\N	\N	2018-04-04 17:00:00	2018-04-04 18:00:00	\N	\N	0	0	\N	\N
258966	AUTRE_TEMPORAIRE	AUTRE_NON_PLENIERE	\N	\N	\N	\N	\N	2018-04-11 15:00:00	2018-04-11 17:00:00	\N	\N	0	0	\N	\N
258972	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de M. Guillaume BOUDY, secrétaire général pour l'investissement	Audition de M. Guillaume BOUDY, secrétaire général pour l'investissement	2018-03-28 09:00:00	2018-03-28 10:10:00	2018-03-29 18:26:28	2018-03-30 09:56:05	30	0	\N	\N
258973	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 14	\N	2018-03-28 13:45:00	2018-03-28 15:25:00	2018-05-18 14:09:58	2018-05-18 14:10:04	25	0	\N	\N
262895	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Nikola Dimitrov, MAE de Macédoine	Entretien avec M. Nikola Dimitrov, ministre des Affaires étrangères de Macédoine	2018-04-04 17:00:00	2018-04-04 18:00:00	\N	\N	2	0	674	\N
262948	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 5 avril 2018	Réunion de la commission des affaires européennes du 5 avril 2018	2018-04-05 11:15:00	2018-04-05 11:50:00	2018-04-05 12:13:31	2018-04-05 14:15:01	15	0	\N	\N
262993	DELEGATION	AUCUNE	\N	\N	COLTER	Table ronde "Statut de l'élu local" (auteurs de travaux parlementaires et chercheurs)	\N	2018-04-12 10:00:00	2018-04-12 11:45:00	2018-04-12 12:08:29	2018-04-12 18:13:33	12	0	\N	\N
262998	DELEGATION	AUCUNE	\N	\N	COLTER	Présentation conclusions groupe de travail "Revitalisation centres-villes centres-bourgs"	\N	2018-04-12 12:15:00	2018-04-12 14:00:00	2018-04-12 14:48:08	2018-04-12 18:13:35	22	0	\N	\N
270191	COM_ENQUETE	DEPLACEMENT	\N	CHUTE	\N	TGI Paris-Préfecture de police de Paris-TGI Bobigny	TGI Paris-Préfecture de police de Paris-TGI Bobigny	2018-04-06 09:00:00	2018-04-06 18:00:00	\N	\N	6	0	\N	\N
225976	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PLF pour 2018 (Avis économie) + PPL Police proximité + PPR Législation en commission	\N	2017-12-06 10:00:00	2017-12-06 12:15:00	2017-12-06 14:46:57	2017-12-06 16:20:38	42	1	\N	\N
262903	CMP	AUTRE	\N	EFFICACITE	\N	PJL État au service d'une société de confiance	PJL État au service d'une société de confiance	2018-04-05 09:10:00	2018-04-05 10:15:00	\N	\N	7	0	\N	\N
279374	DELEGATION	AUCUNE	\N	\N	206	"Femmes et sciences"	Réunion commune avec les délégations aux droits des femmes de l'A.N. et du Sénat sur le thème "Femmes et sciences"	2018-06-28 10:00:00	2018-06-28 12:00:00	\N	\N	6	0	\N	\N
289494	COM_PERMANENTE	AUTRE	\N	FINC	\N	Désignation rapporteur Démocratie et Communication PAS	Désignation rapporteur Démocratie et Communication PAS	2018-06-27 10:51:00	2018-06-27 11:05:00	2018-06-28 15:58:30	2018-06-28 16:16:15	33	1	\N	\N
289581	CONF_PRES	AUCUNE	\N	\N	\N	\N	\N	2018-06-20 19:35:00	2018-06-20 20:10:00	\N	\N	25	0	\N	\N
293842	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2018-07-03 14:40:00	2018-07-03 16:30:00	\N	\N	3	0	\N	\N
313615	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	plfss pour 2019 - médico-social. Auditions M. Bonne	\N	2018-10-17 13:30:00	2018-10-17 14:15:00	\N	\N	2	0	\N	\N
313618	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	plfss pour 2019 - médico-social. Auditions M. Bonne	\N	2018-10-17 14:15:00	2018-10-17 15:00:00	\N	\N	2	0	\N	\N
315759	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Culture (Création, Transmission, Démocratisation)	PLF 2019 - Crédits Culture (Création, Transmission, Démocratisation)	2018-10-23 14:30:00	2018-10-23 15:30:00	\N	\N	1	0	\N	\N
315762	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Culture (Création, Transmission, Démocratisation)	PLF 2019 - Crédits Culture (Création, Transmission, Démocratisation)	2018-10-23 15:30:00	2018-10-23 16:15:00	\N	\N	3	0	\N	\N
315763	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Culture (Création, Transmission, Démocratisation)	PLF 2019 - Crédits Culture (Création, Transmission, Démocratisation)	2018-10-23 16:15:00	2018-10-23 17:00:00	\N	\N	2	0	\N	\N
316003	COM_SPECIALE	PLENIERE	\N	SURTRANSPO	\N	Audition plénière Loiseau (ministre)	\N	2018-10-24 15:00:00	2018-10-24 16:35:00	2018-10-24 19:06:15	2018-10-25 10:34:47	24	0	\N	\N
316079	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition plénière	\N	2018-10-31 09:05:00	2018-10-31 12:30:00	2018-10-31 17:40:44	2018-11-02 10:15:55	38	0	\N	\N
316087	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Enseignement scolaire	PLF 2019 - Crédits Enseignement scolaire	2018-10-23 16:00:00	2018-10-23 17:00:00	\N	\N	2	0	\N	\N
316179	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Enseignement scolaire	PLF 2019 - Crédits Enseignement scolaire	2018-10-24 16:00:00	2018-10-24 17:00:00	\N	\N	2	0	\N	\N
320716	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2018-11-14 17:10:00	2018-11-14 18:05:00	2018-11-15 09:26:28	2018-11-15 14:56:22	16	0	\N	\N
320726	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Plf 2019 - Crédits de l'audiovisuel public	Plf 2019 - Crédits de l'audiovisuel public	2018-11-07 14:30:00	2018-11-07 15:30:00	\N	\N	2	0	\N	\N
320729	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Plf 2019 - Crédits de l'audiovisuel public	Plf 2019 - Crédits de l'audiovisuel public	2018-11-07 15:30:00	2018-11-07 16:30:00	\N	\N	1	0	\N	\N
321164	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	\N	MI Sécurité des ponts	2018-11-08 08:30:00	2018-11-08 10:30:00	\N	\N	6	0	\N	\N
321365	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Culture (Patrimoine)	PLF 2019 - Crédits Culture (Patrimoine)	2018-11-08 11:00:00	2018-11-08 12:10:00	\N	\N	3	0	\N	\N
321376	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Culture (Patrimoine)	PLF 2019 - Crédits Culture (Patrimoine)	2018-11-08 10:00:00	2018-11-08 11:00:00	\N	\N	2	0	\N	\N
321381	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Sport	PLF 2019 - Crédits Sport	2018-11-08 14:00:00	2018-11-08 15:00:00	\N	\N	1	0	\N	\N
321386	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Jeunesse et vie associative	PLF 2019 - Crédits Jeunesse et vie associative	2018-11-07 14:00:00	2018-11-07 15:00:00	\N	\N	1	0	\N	\N
321723	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2019 - Pouvoirs publics - Déplacement Conseil Constitutionnel	PLF pour 2019 - Pouvoirs publics - Déplacement Conseil Constitutionnel	2018-11-06 14:40:00	2018-11-06 16:00:00	\N	\N	1	0	\N	\N
321725	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2019 - Pouvoirs publics - Déplacement Questeurs AN	PLF pour 2019 - Pouvoirs publics - Déplacement Questeurs AN	2018-11-06 16:00:00	2018-11-06 17:20:00	\N	\N	1	0	\N	\N
321727	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Pouvoirs publics - Questeurs Sénat	PLF pour 2019 - Pouvoirs publics - Questeurs Sénat	2018-11-07 15:00:00	2018-11-07 16:00:00	\N	\N	1	0	\N	\N
321729	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Cohésion des territoires - Logement et ville - Cnaf	PLF pour 2019 - Cohésion des territoires - Logement et ville - Cnaf	2018-11-06 09:00:00	2018-11-06 10:10:00	\N	\N	1	0	\N	\N
321732	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Écologie/Transports - DAM	PLF pour 2019 - Écologie/Transports - DAM	2018-11-06 12:00:00	2018-11-06 13:00:00	\N	\N	1	0	\N	\N
321734	GIA	AUCUNE	\N	\N	\N	Entretien  de M. LONGUET avec une délégation de six journalistes russes (coopé)	Entretien  de M. LONGUET avec une délégation de six journalistes russes (coopé)	2018-10-18 15:45:00	2018-10-18 16:45:00	\N	\N	1	0	608	\N
321738	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Contrôle et exploitation aériens - Air France	PLF pour 2019 - Contrôle et exploitation aériens - Air France	2018-11-06 16:00:00	2018-11-06 17:00:00	\N	\N	1	0	\N	\N
321740	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Écologie/énergie - CRE	PLF pour 2019 - Écologie/énergie - CRE	2018-11-06 17:00:00	2018-11-06 18:00:00	\N	\N	1	0	\N	\N
321800	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLF pour 2019 - Mission Outre-mer	\N	2018-11-09 09:00:00	2018-11-09 11:30:00	\N	\N	1	0	\N	\N
321809	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2019 - programme 144	\N	2018-11-07 14:00:00	2018-11-07 17:40:00	\N	\N	1	0	\N	\N
321811	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Entretien parlement finlandais	\N	2018-10-23 17:30:00	2018-10-23 18:30:00	\N	\N	4	0	\N	\N
321829	GIA	AUCUNE	\N	\N	\N	\N	déjeuner Ambassadeur du Koweït	2018-11-06 13:00:00	2018-11-06 14:30:00	\N	\N	8	0	661	\N
321929	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-11-08 11:30:00	2018-11-08 12:15:00	\N	\N	2	0	\N	\N
321972	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Avis "Outre-mer"'	Avis "Outre-mer"	2018-11-09 10:00:00	2018-11-09 12:30:00	\N	\N	1	0	\N	\N
321974	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition rapporteur PLF 2019 outre-mer	Auditions rapporteur PJLF 2019 Outre-mer	2018-11-09 15:30:00	2018-11-09 16:30:00	\N	\N	1	0	\N	\N
321976	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition rapporteur PLF 2019 outre-mer	\N	2018-11-15 16:00:00	2018-11-15 17:00:00	\N	\N	1	0	\N	\N
321978	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition rapporteur PLF 2019 outre-mer	\N	2018-11-20 17:30:00	2018-11-20 18:30:00	\N	\N	1	0	\N	\N
321980	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF pour 2018 - Avis "enseignement supérieur et recherche"	\N	2018-11-07 09:30:00	2018-11-07 10:30:00	\N	\N	1	0	\N	\N
321982	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF pour 2018 - Avis "enseignement supérieur et recherche"	\N	2018-11-08 09:15:00	2018-11-08 12:00:00	\N	\N	1	0	\N	\N
321985	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition avis "Energie"	Audition avis "Energie"	2018-11-07 11:00:00	2018-11-07 12:00:00	\N	\N	1	0	\N	\N
321987	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition avis "Energie"	\N	2018-11-07 16:45:00	2018-11-07 18:30:00	\N	\N	1	0	\N	\N
321989	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition avis "Energie"	\N	2018-11-08 09:30:00	2018-11-08 13:00:00	\N	\N	1	0	\N	\N
321992	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition avis "Energie"	\N	2018-11-08 14:00:00	2018-11-08 16:30:00	\N	\N	1	0	\N	\N
322778	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	DSOM	Conférence de presse : rapport "jeunesse des outre-mer et sport"	Conférence de presse : rapport "jeunesse des outre-mer et sport"	2018-11-20 16:15:00	2018-11-20 17:45:00	\N	\N	14	0	\N	\N
324163	GIA	AUCUNE	\N	\N	\N	déjeuner de travail avec l'Ambassadeur de Sri Lanka	\N	2018-11-08 13:00:00	2018-11-08 14:30:00	\N	\N	4	0	550	\N
324514	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 15 novembre 	Réunion du 15 novembre	2018-11-15 08:30:00	2018-11-15 10:00:00	2018-11-15 10:15:31	2018-11-15 14:56:41	17	0	\N	\N
325217	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	PJLF pour 2019 - Mission Administration pénitentiaire	Centre pénitentiaire Réau	2018-11-14 10:30:00	2018-11-14 17:00:00	\N	\N	2	0	\N	\N
325451	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de Mme Pénicaud	\N	2018-11-27 18:00:00	2018-11-27 19:55:00	2018-11-29 14:44:45	2018-11-29 14:47:58	30	0	\N	\N
325790	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition plénière - PJLF Budget 2019	\N	2018-11-21 16:35:00	2018-11-21 18:45:00	2018-11-22 10:53:20	2018-11-22 10:54:53	33	2	\N	\N
220307	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Engagements financiers de l'État	PLF pour 2018 - Engagements financiers de l'État - agence FITCH	2017-11-16 17:00:00	2017-11-16 18:00:00	\N	\N	1	0	\N	\N
220309	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour  2018 - Engagements financiers de l'Etat	PLF pour  2018 - Engagements financiers de l'Etat - Agence Moody's	2017-11-17 10:00:00	2017-11-17 11:00:00	\N	\N	1	0	\N	\N
220311	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour  2018 - Engagements financiers de l'Etat	PLF pour  2018 - Engagements financiers de l'Etat - ATOS	2017-11-17 15:30:00	2017-11-17 16:00:00	\N	\N	1	0	\N	\N
241371	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Conflits d'intérêts et mobilité des hauts fonctionnaires	\N	2018-02-06 09:00:00	2018-02-06 11:35:00	\N	\N	1	0	\N	\N
246341	ETUDES	AUCUNE	\N	\N	\N	\N	\N	2018-02-15 08:00:00	2018-02-15 09:00:00	\N	\N	19	0	\N	948
249718	COM_SPECIALE	PLENIERE	\N	SOCIETE	\N	\N	\N	2018-02-21 20:00:00	2018-02-21 21:30:00	2018-02-22 14:31:38	2018-02-22 14:50:52	13	0	\N	\N
253561	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Les financements publics réservés à l¿agriculture biologique	Contrôle Les financements publics réservés à l¿agriculture biologique - Audition DGPE	2018-03-06 14:00:00	2018-03-06 15:00:00	\N	\N	2	0	\N	\N
253563	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Les financements publics réservés à l¿agriculture biologique	Contrôle Les financements publics réservés à l¿agriculture biologique - Audition Cour des comptes	2018-03-06 15:00:00	2018-03-06 16:30:00	\N	\N	2	0	\N	\N
253680	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2  Les politiques de valorisation de l¿ingénierie et des marques culturelles françaises	58-2  Les politiques de valorisation de l¿ingénierie et des marques culturelles françaises - Audition cour des comptes	2018-03-06 15:50:00	2018-03-06 16:30:00	\N	\N	2	0	\N	\N
254782	COM_ENQUETE	PLENIERE	\N	FORCES	\N	CE état des forces de sécurité intérieure	CE état des forces de sécurité intérieure	2018-03-13 16:00:00	2018-03-13 20:10:00	2018-03-14 09:40:37	2018-03-14 15:42:39	13	0	\N	\N
261332	GIA	AUCUNE	\N	\N	\N	Rencontre avec M. Cero Gomes	Rencontre avec M. Cero Gomes, , candidat aux élections présidentielles brésiliennes	2018-03-28 17:15:00	2018-03-28 18:00:00	\N	\N	4	0	576	\N
261337	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT suivi de la PAC	GT suivi de la PAC	2018-03-28 16:30:00	2018-03-28 18:30:00	\N	\N	12	0	\N	\N
267420	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Programmation militaire pour les années 2019 à 2025	\N	2018-04-12 17:15:00	2018-04-12 19:20:00	\N	\N	1	0	\N	\N
269467	BUREAU	AUCUNE	\N	\N	\N	Bureau du Sénat	Bureau du Sénat	2018-04-19 10:00:00	2018-04-19 11:50:00	\N	\N	19	0	\N	\N
270097	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 19 avril 2018 (après-midi)	Réunion conjointe avec la commission des questions de l¿Union européenne du Bundesrat allemand	2018-04-19 16:20:00	2018-04-19 18:15:00	2018-04-19 19:24:02	2018-04-20 10:36:53	12	0	\N	\N
270135	GIA	AUCUNE	\N	\N	\N	Exposition Goldblatt - Centre Pompidou	Visite de l'exposition consacrée à David Goldblatt au Centre Pompidou	2018-04-18 11:55:00	2018-04-18 15:25:00	\N	\N	1	0	574	\N
270273	ETUDES	AUCUNE	\N	\N	\N	G.E. "Agriculture et alimentation"	G.E. "Agriculture et alimentation"	2018-04-19 13:30:00	2018-04-19 14:30:00	\N	\N	3	0	\N	919
270277	ETUDES	AUCUNE	\N	\N	\N	G.E. "Agriculture et Alimentation"	G.E. "Agriculture et Alimentation"	2018-04-10 13:30:00	2018-04-10 14:30:00	\N	\N	21	0	\N	919
270575	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Traité de Pékin OMPI	\N	2018-05-14 15:00:00	2018-05-14 15:35:00	\N	\N	1	0	\N	\N
272576	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	Commission des comptes	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne	2018-05-15 18:00:00	2018-05-15 19:30:00	2018-05-16 17:24:16	2018-05-16 18:01:37	8	0	\N	\N
272588	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	Commission des comptes	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne 	2018-05-16 14:30:00	2018-05-16 15:15:00	2018-05-16 17:28:01	2018-05-16 18:01:37	9	0	\N	\N
272631	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	Commission des comptes	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne	2018-05-16 16:00:00	2018-05-16 17:00:00	2018-05-16 17:40:25	2018-05-16 18:01:40	9	0	\N	\N
273868	GIA	AUCUNE	\N	\N	\N	Réunion du groupe France-Chypre	Entretien avec le secrétaire général du parti AKEL	2018-05-22 14:00:00	2018-05-22 15:15:00	\N	\N	3	0	585	\N
273926	GIA	AUCUNE	\N	\N	\N	Entretien de M. EBLE avec Chak SOPHEAP (coopé)	Entretien de M. EBLE avec Chak SOPHEAP, invitée cambodgienne (coopé)	2018-05-22 15:30:00	2018-05-22 16:00:00	\N	\N	1	0	577	\N
273937	GIA	AUCUNE	\N	\N	\N	Entretien de Claudine LEPAGE avec Cathy WONG  (coopé)	Entretien de Claudine LEPAGE avec Cathy WONG (coopé)	2018-05-16 15:00:00	2018-05-16 15:45:00	\N	\N	1	0	583	\N
274815	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	Audition du Pr Caillat-Zucman (présidence du conseil d'administration de l'Agence de la biomédecine)	2018-05-30 08:30:00	2018-05-30 10:50:00	2018-05-30 11:00:17	2018-05-30 15:48:50	30	0	\N	\N
274817	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PPL Autorisation d'analyses génétiques sur personnes décédées	Examen du rapport et du texte PPL Autorisation analyses génétiques sur personnes décédées	2018-05-30 14:35:00	2018-05-30 15:45:00	2018-05-30 16:05:27	2018-05-30 16:32:39	45	0	\N	\N
281678	COM_PERMANENTE	AUTRE	\N	LOIS	\N	\N	\N	2018-06-07 09:10:00	2018-06-07 11:45:00	2018-06-07 12:29:59	2018-06-07 18:47:04	23	1	\N	\N
305307	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe	Assemblée générale du groupe	2018-01-23 15:45:00	2018-01-23 16:15:00	\N	\N	6	0	588	\N
270360	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2018-05-02 14:30:00	2018-05-02 17:00:00	\N	\N	2	0	\N	\N
325784	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2018-11-21 09:05:00	2018-11-21 11:45:00	2018-11-21 15:49:55	2018-11-21 16:30:38	43	0	\N	\N
311670	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Assadullah Fareedzai, conseiller politique de l'ambassade de Norvège	Entretien avec M. Assadullah Fareedzai, conseiller politique de l'ambassade de Norvège.	2018-10-11 08:15:00	2018-10-11 09:15:00	\N	\N	2	0	648	\N
313509	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPLO Élection sénateurs (nomination) -  ENQ Abus sexuels mineurs Église catholique (avis)	PPLO Élection sénateurs (nomination) -  ENQ Abus sexuels mineurs Église catholique (avis)	2018-10-17 09:05:00	2018-10-17 11:35:00	2018-10-17 14:52:38	2018-10-17 15:34:24	43	0	\N	\N
313998	GIA	AUCUNE	\N	\N	\N	Conférence Tibet (Parl. europ. Bruxelles)	Conférence Tibet (Parl. europ. Bruxelles)	2018-11-21 15:00:00	2018-11-21 18:00:00	\N	\N	1	0	634	\N
314087	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Manipulation information	PPL Manipulation information	2018-11-06 14:30:00	2018-11-06 17:05:00	\N	\N	142	0	\N	\N
314090	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Préparation Brexit	PJL Préparation Brexit	2018-11-06 17:10:00	2018-11-06 20:15:00	\N	\N	133	0	\N	\N
314097	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL sur-transpositions	PJL sur-transpositions	2018-11-06 21:45:00	2018-11-07 00:10:00	\N	\N	60	0	\N	\N
314105	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL sur-transpositions	PJL sur-transpositions	2018-11-07 14:30:00	2018-11-07 16:50:00	\N	\N	115	0	\N	\N
314107	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Cohésion des territoires	PPL Cohésion des territoires	2018-11-08 10:30:00	2018-11-08 13:20:00	\N	\N	98	0	\N	\N
275819	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ambassadeur de Slovénie 	Entretien avec l'ambassadeur de Slovénie à l'occasion de la journée mondiale des abeilles	2018-05-22 12:30:00	2018-05-22 14:00:00	\N	\N	6	0	529	\N
275826	COM_ENQUETE	DEPLACEMENT	\N	FORCES	\N	Déplacement au Courbat (ANAS)	Déplacement au Courbat (ANAS)	2018-05-25 06:45:00	2018-05-25 17:30:00	\N	\N	4	0	\N	\N
275831	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Mission réflexion FPT	Mission de réflexion sur les enjeux de l'évolution de la fonction publique territoriale	2018-05-23 14:00:00	2018-05-23 16:50:00	\N	\N	1	0	\N	\N
278171	GIA	AUCUNE	\N	\N	\N	Petit-déjeuner	Petit déjeuner avec M. Thierry Mathou (ministère des Affaires étrangères)	2018-05-30 08:00:00	2018-05-30 09:00:00	\N	\N	7	0	626	\N
278234	GIA	AUCUNE	\N	\N	\N	Petit-déjeuner	Petit-déjeuner avec l'ambassadeur du Vietnam, S.E.M. Nguyen Thiep	2018-02-21 08:00:00	2018-02-21 09:00:00	\N	\N	8	0	626	\N
291742	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Audition plénière	\N	2018-07-11 13:30:00	2018-07-11 14:30:00	\N	\N	0	0	\N	\N
291989	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions rapporteur	\N	2018-06-25 15:30:00	2018-06-25 19:00:00	\N	\N	2	0	\N	\N
291992	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur	\N	2018-06-26 18:15:00	2018-06-26 19:45:00	\N	\N	5	0	\N	\N
291993	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur	\N	2018-06-27 14:30:00	2018-06-27 15:30:00	\N	\N	4	0	\N	\N
292081	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Réseau enseignement français à l'étranger - Claudine Lepage	Contrôle 2018 - Réseau enseignement français à l'étranger - Claudine Lepage	2018-06-25 14:30:00	2018-06-25 15:20:00	\N	\N	2	0	\N	\N
292084	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Réseau enseignement français à l'étranger - Christophe-André Frassa	Contrôle 2018 - Réseau enseignement français à l'étranger - Christophe-André Frassa	2018-06-25 15:30:00	2018-06-25 16:30:00	\N	\N	2	0	\N	\N
292087	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Réseau enseignement français à l'étranger - Catherine Morin-Desailly	Contrôle 2018 - Réseau enseignement français à l'étranger - Catherine Morin-Desailly - Présidente	2018-06-26 10:00:00	2018-06-26 10:30:00	\N	\N	2	0	\N	\N
292145	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 27 juin 2018	\N	2018-06-27 17:15:00	2018-06-27 18:30:00	\N	\N	0	0	\N	\N
292338	GIA	AUCUNE	\N	\N	\N	Audition de l'ambassadrice d'El Salvador	Audition de S. Exc. Mme Carmen Maria GALLARDO DE HERNANDEZ, ambassadrice de la République d'El Salvador	2018-06-27 08:30:00	2018-06-27 09:45:00	\N	\N	3	0	643	\N
293460	MISSION	AUDRAP	\N	PENURIE	\N	MI Pénurie de médicaments et de vaccins	MI Pénurie de médicaments et de vaccins	2018-07-05 09:00:00	2018-07-05 10:00:00	\N	\N	1	0	\N	\N
293462	MISSION	AUDRAP	\N	PENURIE	\N	MI Pénurie de médicaments et de vaccinsmi	MI Pénurie de médicaments et de vaccins	2018-07-06 15:30:00	2018-07-06 18:00:00	\N	\N	2	0	\N	\N
293464	MISSION	AUCUNE	\N	PENURIE	\N	MI pénurie de médicaments et de vaccins	PI pénurie de médicaments et de vaccins	2018-07-05 10:15:00	2018-07-05 12:40:00	2018-07-05 15:00:29	2018-07-06 15:44:42	10	0	\N	\N
293466	MISSION	AUCUNE	\N	PENURIE	\N	MI pénurie de médicaments et de vaccins	MI Pénurie de médicaments et de vaccins	2018-07-06 09:30:00	2018-07-06 12:40:00	2018-07-06 14:31:46	2018-07-06 15:45:20	2	0	\N	\N
293468	MISSION	AUCUNE	\N	PENURIE	\N	MI pénurie de médicaments et de vaccins	MI Pénurie de médicaments et de vaccins	2018-07-06 15:30:00	2018-07-06 16:25:00	2018-07-06 16:25:43	2018-07-06 17:53:11	2	0	\N	\N
294264	DELEGATION	AUCUNE	\N	\N	211	Examen du rapport d'information de Mme Annick Billon sur la révision constitutionnelle	Examen du rapport d'information de Mme Annick Billon sur la révision constitutionnelle	2018-07-17 17:30:00	2018-07-17 18:30:00	2018-07-17 19:36:52	2018-07-18 09:31:40	9	0	\N	\N
296066	GIA	AUCUNE	\N	\N	\N	Entretien de M. LEFEVRE avec M. Robet PITTINGER, Chambre des Représentants (coopé)	Entretien de M. LEFEVRE avec M. Robet PITTINGER, Chambre des Représentants (coopé)	2018-07-05 16:00:00	2018-07-05 17:00:00	\N	\N	2	0	590	\N
296074	GIA	AUCUNE	\N	\N	\N	Entretien de M. CADIC avec M. Robert PITTINGER (Chambre des Représentants) (coopé)	Entretien de M. CADIC avec M. Robert PITTINGER (Chambre des Représentants) (coopé)	2018-07-06 09:00:00	2018-07-06 17:00:00	\N	\N	1	0	590	\N
291386	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2018-06-27 09:35:00	2018-06-27 11:05:00	2018-07-03 18:02:03	2018-07-03 18:03:42	40	2	\N	\N
296085	GIA	AUCUNE	\N	\N	\N	Entre de M. DAUNIS avec M. Chris CREWTHER, Député australien (coopé)	Entre de M. DAUNIS avec M. Chris CREWTHER, Député australien (coopé)	2018-07-10 14:00:00	2018-07-10 15:00:00	\N	\N	1	0	578	\N
299050	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL constitutionnelle	PJL constitutionnelle	2018-07-11 15:45:00	2018-07-11 18:30:00	\N	\N	1	0	\N	\N
300116	DELEGATION	AUDRAP	\N	\N	206	Audition dans le cadre de la mission "perte de biodiversité"	Audition dans le cadre de la mission "perte de biodiversité"	2018-07-11 17:00:00	2018-07-11 18:00:00	\N	\N	1	0	\N	\N
300118	DELEGATION	AUDRAP	\N	\N	206	Audition dans le cadre de la mission "perte de biodiversité"	Audition dans le cadre de la mission "perte de biodiversité"	2018-07-11 18:00:00	2018-07-11 19:00:00	\N	\N	1	0	\N	\N
300420	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 18 juillet 2018	\N	2018-07-18 17:35:00	2018-07-18 19:30:00	2018-07-19 09:42:58	2018-07-19 09:48:19	20	0	\N	\N
301310	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL démocratie plus représentative - Ministère des solidarités et de la santé	PJL démocratie plus représentative - Ministère des solidarités et de la santé	2018-07-18 15:00:00	2018-07-18 16:00:00	\N	\N	1	0	\N	\N
301323	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 2018 - Très grandes infrastructures de recherche - CEA	58-2 2018 - Très grandes infrastructures de recherche - CEA	2018-07-19 14:00:00	2018-07-19 15:00:00	\N	\N	1	0	\N	\N
305102	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Guillaume GUENNEC, Chargé de plaidoyer de l¿ONG Portes Ouvertes	Entretien avec M. Guillaume GUENNEC, Chargé de plaidoyer de l¿ONG Portes Ouvertes	2018-07-25 14:00:00	2018-07-25 15:00:00	\N	\N	1	0	609	\N
305926	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Gilles Bernard, président de l'AFIREV	Audition de M. Gilles Bernard, président de l'AFIREV	2018-09-13 14:00:00	2018-09-13 15:00:00	\N	\N	2	0	\N	\N
305954	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière	Réunion plénière	2018-09-27 09:05:00	2018-09-27 11:35:00	2018-09-27 15:06:20	2018-09-27 17:39:06	11	0	\N	\N
306922	BUREAU	AUCUNE	\N	\N	\N	Bureau du Sénat	Bureau du Sénat	2018-09-26 08:30:00	2018-09-26 10:30:00	\N	\N	24	0	\N	\N
307425	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	PLF pour 2019 - Déplacement à Bourges	\N	2018-09-27 07:15:00	2018-09-27 18:30:00	\N	\N	3	0	\N	\N
308987	GIA	AUCUNE	\N	\N	\N	Entretien de Marc DAUNIS avec Mme Terri BUTLER, Députée australienne (coopé)	Entretien de Marc DAUNIS avec Mme Terri BUTLER, Députée australienne (coopé)	2018-10-03 14:00:00	2018-10-03 15:00:00	\N	\N	1	0	578	\N
309034	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2018-10-03 15:00:00	2018-10-03 17:00:00	\N	\N	3	0	\N	\N
309039	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	AFCL	\N	Rencontre avec l'UNAPEI	Rencontre avec l'UNAPEI	2018-10-03 16:55:00	2018-10-03 18:00:00	\N	\N	12	0	\N	\N
309057	COM_ENQUETE	PLENIERE	\N	HAUTE	\N	Réunion du 4 octobre 2018	Réunion du 4 octobre 2018	2018-10-04 09:35:00	2018-10-04 10:15:00	2018-10-05 11:41:38	2018-10-05 19:06:04	14	0	\N	\N
309058	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 4 octobre 2018	\N	2018-10-04 09:15:00	2018-10-04 11:00:00	2018-10-08 15:56:15	2018-10-08 15:56:37	16	0	\N	\N
309060	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL et PJLO Justice	PJL et PJLO Justice	2018-10-09 21:30:00	2018-10-09 23:55:00	\N	\N	69	0	\N	\N
215352	COM_EURO	CONTROLE	\N	AFEU	\N	\N	\N	2017-11-07 17:30:00	2017-11-07 19:05:00	2017-11-09 15:54:28	2017-11-09 16:01:26	42	0	\N	\N
220368	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2018 (Développement des entreprises)	\N	2017-11-15 15:15:00	2017-11-15 18:15:00	\N	\N	1	0	\N	\N
230127	DELEGATION	AUCUNE	\N	\N	211	Auditions de Mme Ghada Hatem et de Maîttre Carine Durrieu-Diebolt	Auditions de Mme Ghada Hatem et de Maître Carine Durrieu-Diebolt	2017-12-14 08:30:00	2017-12-14 10:45:00	2017-12-14 11:45:00	2017-12-14 14:40:55	13	0	\N	\N
243960	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Mission "Flash" Ehpad	Situation dans les Ehpad	2018-02-06 15:30:00	2018-02-06 16:45:00	\N	\N	10	0	\N	\N
243986	GIA	AUCUNE	\N	\N	\N	Réunion constitutive	Réunion constititutive	2018-01-17 14:30:00	2018-01-17 15:00:00	\N	\N	9	0	624	\N
250234	DELEGATION	AUDRAP	\N	\N	206	Audition de Greenpeace-France	Audition de Greenpeace-France	2018-03-05 15:15:00	2018-03-05 16:15:00	\N	\N	2	0	\N	\N
250235	DELEGATION	AUDRAP	\N	\N	206	Audition de l'Association Justice Pesticides	Audition de l'Association Justice Pesticides	2018-03-05 16:30:00	2018-03-05 17:30:00	\N	\N	2	0	\N	\N
250236	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Stéphane Foucart et Mme Stéphane HOREL, journalistes du Monde	Audition de M. Stéphane Foucart et Mme Stéphane HOREL, journalistes du Monde	2018-03-05 17:30:00	2018-03-05 18:45:00	\N	\N	2	0	\N	\N
251150	GIA	AUCUNE	\N	\N	\N	Déjeuner	Déjeuner du groupe d'amitié suite à l'AG constitutive du nouveau bureau après le renouvellement sénatorial	2018-03-07 12:30:00	2018-03-07 14:45:00	\N	\N	10	0	605	\N
255794	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	Groupe de travail sur la sécurité routière	\N	2018-03-14 14:00:00	2018-03-14 18:00:00	\N	\N	4	0	\N	\N
255953	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Affaires européennes	PLF pour 2019 - Affaires européennes - Audition ministère de l'agriculture et de l'alimentation	2018-03-14 16:00:00	2018-03-14 17:00:00	\N	\N	1	0	\N	\N
255963	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Réforme des retraites 2018	Contrôle Réforme des retraites 2018 - Audition Caisse des dépôts et consignations	2018-03-13 16:00:00	2018-03-13 17:30:00	\N	\N	1	0	\N	\N
255976	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Mission "Routes de la soie"	\N	2018-03-13 15:15:00	2018-03-13 16:30:00	\N	\N	1	0	\N	\N
255978	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Mission "Routes de la soie"	\N	2018-03-14 08:30:00	2018-03-14 09:30:00	\N	\N	2	0	\N	\N
255981	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Mission "Routes de la soie"	\N	2018-03-14 14:30:00	2018-03-14 17:00:00	\N	\N	2	0	\N	\N
264302	COM_ENQUETE	PLENIERE	\N	FORCES	\N	Audition CE FSI	Audition CE FSI	2018-04-10 14:10:00	2018-04-10 16:50:00	2018-04-10 17:14:50	2018-04-10 17:21:20	12	0	\N	\N
270266	GIA	AUCUNE	\N	\N	\N	Accueiil d'une délégation parlementaire lituanienne au Sénat	Accueiil d'une délégation parlementaire lituanienne au Sénat	2018-04-10 12:30:00	2018-04-10 14:00:00	\N	\N	6	0	616	\N
270353	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Mission Établissements publics de coopération culturelle	\N	2018-05-02 09:00:00	2018-05-02 13:00:00	\N	\N	1	0	\N	\N
244231	COM_PERMANENTE	AUDRAP	\N	CDD	\N	\N	\N	2018-02-06 18:45:00	2018-02-06 19:30:00	\N	\N	0	0	\N	\N
308227	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJLO Programmation 2018-2022 et réforme pour la justice - Examen rapport et texte	PJLO Programmation 2018-2022 et réforme pour la justice - Examen rapport et texte	2018-10-03 09:15:00	2018-10-03 13:25:00	2018-10-03 17:26:58	2018-10-03 17:35:59	46	0	\N	\N
232733	CMP	AUTRE	\N	ENVIRONNEMEN	\N	PJL Évaluation environnementale	\N	2017-12-20 16:35:00	2017-12-20 17:35:00	\N	\N	11	0	\N	\N
270367	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Métier d'enseignant	Métier d'enseignant	2018-04-18 16:00:00	2018-04-18 17:00:00	\N	\N	3	0	\N	\N
272033	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2018-05-15 14:30:00	2018-05-15 16:50:00	\N	\N	3	0	\N	\N
272037	GIA	AUCUNE	\N	\N	\N	Entretien avec S. Exc. M. José A. FABREGA ROUX, ambassadeur de la République du Panama	Entretien avec S. Exc. M. José A. FABREGA ROUX, ambassadeur de la République du Panama	2018-05-16 08:30:00	2018-05-16 09:30:00	\N	\N	5	0	643	\N
272206	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Guillaume Delvallée, diplomate	Entretien avec le futur directeur-adjoint du Bureau de représentation de la France à Taïpe	2018-05-09 11:00:00	2018-05-09 12:00:00	\N	\N	1	0	623	\N
273320	COM_EURO	AUDRAP	\N	AFEU	\N	Détachement des travailleurs	\N	2018-05-16 14:30:00	2018-05-16 16:00:00	\N	\N	2	0	\N	\N
279257	COM_PERMANENTE	AUTRE	\N	FINC	\N	Communication Contrôle CIVS et Audition OPHELE Rapport AMF	Communication Contrôle CIVS et Audition OPHELE Rapport AMF	2018-06-06 10:50:00	2018-06-06 12:50:00	2018-06-08 18:33:43	2018-06-08 19:33:56	29	0	\N	\N
279401	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion 20180605	\N	2018-06-05 09:10:00	2018-06-05 11:05:00	2018-06-05 12:19:04	2018-06-05 16:31:10	21	1	\N	\N
282586	COM_PERMANENTE	AUTRE	\N	CDD	\N	Audition	Audition plénière de M. Philippe WAHL, PDG du groupe La Poste	2018-06-13 09:00:00	2018-06-13 11:05:00	2018-06-13 11:50:14	2018-06-13 14:24:28	28	0	\N	\N
286025	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Naval Group  à Cherbourg	\N	2018-06-14 08:00:00	2018-06-14 18:00:00	\N	\N	3	0	\N	\N
287976	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	Article 13 CNR - Élisabeth Ayrault	2018-06-21 10:50:00	2018-06-21 12:05:00	2018-06-22 15:18:16	2018-06-22 15:18:30	27	0	\N	\N
288056	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL ELAN	PJL ELAN	2018-06-19 09:45:00	2018-06-19 10:30:00	\N	\N	1	0	\N	\N
288061	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL ELAN	PJL ELAN	2018-06-19 16:30:00	2018-06-19 17:50:00	\N	\N	3	0	\N	\N
288067	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL ELAN	PJL ELAN	2018-06-20 15:00:00	2018-06-20 17:30:00	\N	\N	1	0	\N	\N
289094	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	Audition, en commun avec la commission des affaires européennes, de Mme Corina Cretu, Commissaire européenne 	2018-06-27 17:15:00	2018-06-27 18:30:00	2018-06-28 09:17:40	2018-06-28 10:14:33	21	0	\N	\N
289205	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition Didier MIGAUD Cour des comptes DOFP	Audition Didier MIGAUD Cour des comptes DOFP	2018-06-27 14:35:00	2018-06-27 16:20:00	2018-06-28 15:58:54	2018-06-28 16:16:16	21	1	\N	\N
296555	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2018-07-10 14:40:00	2018-07-10 17:00:00	\N	\N	3	0	\N	\N
296567	ETUDES	AUCUNE	\N	\N	\N	G.E. "Mer et Littoral"	G.E. "Mer et Littoral"	2018-07-05 10:30:00	2018-07-05 11:30:00	\N	\N	4	0	\N	908
298407	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PROG Programmation 2018-2022 et réforme pour la justice	PJL/PPLO Programmation et organisation Justice	2018-07-10 17:45:00	2018-07-10 20:15:00	\N	\N	2	0	\N	\N
298410	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PROG Programmation 2018-2022 et réforme pour la justice	PJL/PPLO Programmation et organisation Justice	2018-07-12 10:30:00	2018-07-12 12:00:00	\N	\N	1	0	\N	\N
298412	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PROG Programmation 2018-2022 et réforme pour la justice	PJL/PPLO Programmation et organisation Justice	2018-07-12 15:00:00	2018-07-12 17:45:00	\N	\N	2	0	\N	\N
302704	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL ELAN	PJL ELAN	2018-07-25 14:30:00	2018-07-25 17:50:00	\N	\N	121	0	\N	\N
304016	COM_EURO	AUDRAP	\N	AFEU	\N	Retour au taux réduit de TVA pour la filière équine	Audition de représentants du ministère de l'agriculture et de l'alimentation	2018-07-24 15:30:00	2018-07-24 16:15:00	\N	\N	1	0	\N	\N
304017	COM_EURO	AUDRAP	\N	AFEU	\N	Retour au taux réduit de TVA pour la filière équine	Audition de représentants du ministère de l'économie et des finances	2018-07-24 14:00:00	2018-07-24 15:30:00	\N	\N	1	0	\N	\N
304226	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	\N	\N	2018-07-26 15:00:00	2018-07-26 16:00:00	\N	\N	0	0	\N	\N
304591	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Vote contrôle article 13 - M. Jean-Raphaël Alventosa	Vote contrôle article 13 - M. Jean-Raphaël Alventosa	2018-07-26 12:15:00	2018-07-26 12:20:00	2018-07-26 13:39:30	2018-07-26 17:23:05	13	0	\N	\N
307123	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Vote électronique - Auditions rapporteurs	\N	2018-09-10 08:30:00	2018-09-10 11:30:00	\N	\N	2	0	\N	\N
307124	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Déplacement à Tallinn	\N	2018-09-12 17:00:00	2018-09-14 20:00:00	\N	\N	2	0	\N	\N
309106	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	\N	\N	2018-10-23 15:30:00	2018-10-23 16:30:00	\N	\N	0	0	\N	\N
309109	COM_EURO	AUDRAP	\N	AFEU	\N	Audition suivi CE Schengen	Audition de représetants du SGAE	2018-10-04 11:05:00	2018-10-04 12:10:00	\N	\N	3	0	\N	\N
285385	GIA	AUCUNE	\N	\N	\N	Rencontre Garnier - Quai Branly	viiste collections Océanie musée du Quai Branly avec consrevateur N. Garnier	2018-06-13 17:00:00	2018-06-13 19:00:00	\N	\N	3	0	651	\N
298496	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	audition plénière	\N	2018-07-19 14:00:00	2018-07-19 15:00:00	\N	\N	0	0	\N	\N
298505	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Audition plénière	\N	2018-07-19 11:30:00	2018-07-19 12:15:00	\N	\N	0	0	\N	\N
298506	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	auditions plénières	\N	2018-07-19 14:00:00	2018-07-19 15:00:00	\N	\N	0	0	\N	\N
298556	DELEGATION	AUDRAP	\N	\N	PROS	Audition rapporteurs	\N	2018-07-19 10:00:00	2018-07-19 11:30:00	\N	\N	3	0	\N	\N
298585	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Déplacement Manche	\N	2018-06-28 13:00:00	2018-06-28 22:30:00	\N	\N	3	0	\N	\N
298614	DELEGATION	AUDRAP	\N	\N	PROS	Audition rapporteurs	\N	2018-07-26 14:00:00	2018-07-26 15:15:00	\N	\N	2	0	\N	\N
298617	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Déplacement Nantes	\N	2018-07-11 11:00:00	2018-07-11 18:00:00	\N	\N	3	0	\N	\N
298622	COM_PERMANENTE	AUTRE	\N	CAE	\N	Examen des motions et amendements de séance	\N	2018-07-16 17:35:00	2018-07-16 19:55:00	2018-07-17 17:45:49	2018-07-18 09:31:53	17	2	\N	\N
299339	GIA	AUCUNE	\N	\N	\N	Entretien avec SE M. Pantias Eliades, ambassadeur de Chypre à Paris	Entretien avec SE M. Pantias Eliades, ambassadeur de Chypre à Paris	2018-07-11 08:30:00	2018-07-11 09:45:00	\N	\N	7	0	585	\N
326217	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ambassadeur de France au Kosovo	Entretien avec l'ambassadeur de France au Kosovo	2018-11-20 09:25:00	2018-11-20 10:30:00	\N	\N	1	0	674	\N
326519	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2018-11-21 09:30:00	2018-11-21 10:00:00	2018-11-21 12:32:25	2018-11-21 14:52:36	39	0	\N	\N
289196	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen du rapport PJL lutte contre la fraude	Examen du rapport PJL lutte contre la fraude	2018-06-27 09:05:00	2018-06-27 10:50:00	2018-06-28 15:58:10	2018-06-28 16:16:18	43	1	\N	\N
326411	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Examen avis budgétaires PLF 2019	\N	2018-11-21 08:30:00	2018-11-21 11:45:00	2018-11-21 11:42:56	2018-11-21 14:52:40	43	0	\N	\N
326608	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	PJL Croissance, activité et égalité des chances	\N	2018-11-20 08:00:00	2018-11-20 11:00:00	\N	\N	1	0	\N	\N
326991	MISSION	AUCUNE	\N	INFRACTIONS	\N	Réunion du Bureau	Réunion du Bureau	2018-11-21 16:30:00	2018-11-21 17:00:00	2018-11-27 15:29:23	\N	9	0	\N	\N
327004	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	\N	\N	2018-11-19 15:15:00	2018-11-19 16:45:00	\N	\N	1	0	\N	\N
327009	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Elysée	\N	2018-11-19 18:15:00	2018-11-19 19:45:00	\N	\N	1	0	\N	\N
327045	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions thanatopraxie	\N	2018-11-21 14:15:00	2018-11-21 16:00:00	\N	\N	1	0	\N	\N
327587	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2018-11-22 08:40:00	2018-11-22 09:55:00	2018-11-22 10:15:01	2018-11-22 10:24:32	19	0	\N	\N
327604	COM_EURO	AUDRAP	\N	AFEU	\N	Parquet européen	Audition rapporteur - Parquet européen	2018-11-21 16:35:00	2018-11-21 17:35:00	\N	\N	2	0	\N	\N
327720	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	\N	\N	2018-11-22 08:30:00	2018-11-22 09:30:00	\N	\N	0	0	\N	\N
327736	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	AUDITION DE de M. Alexandre de JUNIAC DG IATA	\N	2018-11-22 08:30:00	2018-11-22 09:30:00	\N	\N	0	0	\N	\N
327746	COM_EURO	AUDRAP	\N	AFEU	\N	\N	\N	2018-11-21 17:30:00	2018-11-21 18:30:00	\N	\N	2	0	\N	\N
327747	COM_EURO	AUDRAP	\N	AFEU	\N	Adaptation du corridor "Mer du Nord - Méditerranée" à un éventuel BREXIT "dur"	Audition de représentants du ministère de la transition écologique et solidaire	2018-11-21 15:00:00	2018-11-21 16:00:00	\N	\N	2	0	\N	\N
327778	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Rapport général - MEL	PLF pour 2019 - Rapport général - MEL	2018-11-19 11:00:00	2018-11-19 11:45:00	\N	\N	1	0	\N	\N
327781	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2019 - Justice - Déplacement Paris Maison d¿Arrêt "la Santé"	PLF pour 2019 - Justice - Déplacement Paris Maison d¿Arrêt "la Santé"	2018-11-20 10:30:00	2018-11-20 12:30:00	\N	\N	1	0	\N	\N
327797	COM_PERMANENTE	AUTRE	\N	FINC	\N	Contrôle 2018 - Lutte contre la fraude et l'évasion fiscales - Réunion de travail	Contrôle 2018 - Lutte contre la fraude et l'évasion fiscales - Réunion de travail	2018-11-20 19:00:00	2018-11-20 19:30:00	\N	\N	3	0	\N	\N
327812	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - CAS Contrôle de la circulation et du stationnement routiers - DMSR	PLF pour 2019 - CAS Contrôle de la circulation et du stationnement routiers - Délégué sécurité routière	2018-11-19 11:05:00	2018-11-19 12:50:00	\N	\N	1	0	\N	\N
328145	DELEGATION	AUDRAP	\N	\N	PROS	Bureau de recherches géologiques et minières (BRGM)	\N	2018-12-04 15:00:00	2018-12-04 16:30:00	\N	\N	1	0	\N	\N
328252	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	PJL Croissance, activité et égalité des chances	\N	2018-11-20 16:00:00	2018-11-20 18:00:00	\N	\N	0	0	\N	\N
328688	MISSION	AUCUNE	\N	INFRACTIONS	\N	Audition de M. Éric Guéret et Mme Christine Pedotti	Audition de M. Éric Guéret et Mme Christine Pedotti	2018-11-28 14:05:00	2018-11-28 15:45:00	2018-11-28 16:24:01	2018-11-28 16:39:24	23	0	\N	\N
328696	GIA	AUCUNE	\N	\N	\N	Visite  d'élèves de plusieurs classes du Collège national "Sfantul Sava" de Bucarest	Visite  d'élèves de plusieurs classes du Collège national "Sfantul Sava" de Bucarest	2018-11-13 18:20:00	2018-11-13 20:20:00	\N	\N	1	0	605	\N
328722	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	GT justice prud'homale	\N	2018-11-22 07:50:00	2018-11-23 19:00:00	\N	\N	1	0	\N	\N
328724	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI thanatopraxie	\N	2018-11-22 10:45:00	2018-11-22 13:45:00	\N	\N	1	0	\N	\N
328726	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLFR pour 2018-Examen rapport en Nlle lecture - PLF pour 2019-Examen AMDTS non examinés	PLFR pour 2018-Examen rapport en Nlle lecture - PLF pour 2019-Examen AMDTS non examinés	2018-11-27 09:30:00	2018-11-27 10:00:00	2018-11-27 10:40:09	2018-11-28 11:50:25	26	0	\N	\N
328751	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	PJL Croissance et transformation des entreprises	\N	2018-11-22 14:00:00	2018-11-22 14:45:00	\N	\N	1	0	\N	\N
328753	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	PJL Croissance et transformation des entreprises	\N	2018-11-22 16:15:00	2018-11-22 18:00:00	\N	\N	1	0	\N	\N
329064	DELEGATION	AUDRAP	\N	\N	PROS	Santé publique France	\N	2018-12-19 10:30:00	2018-12-19 11:45:00	\N	\N	2	0	\N	\N
329069	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2019 - Examen Amdts séance sur missions Économie-R&D-EFE-IA- Cohésion-AGTE	PLF pour 2019 - Examen Amdts de séance sur les missions Économie - R & D-EFE-IA- Cohésion des territoires et AGTE	2018-11-30 09:00:00	2018-11-30 09:30:00	2018-11-30 16:31:51	2018-11-30 17:00:28	13	0	\N	\N
329070	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2019 - Examen Amdts séance missions Anc. Comb.-Agriculture-Défense-Écologie-Sport	PLF pour 2019 - Examen Amdts de séance sur les missions Anciens combattants-Agriculture-Défense-Écologie-BA CEA-Sport	2018-11-30 14:00:00	2018-11-30 14:20:00	2018-11-30 16:32:32	2018-11-30 17:00:30	11	0	\N	\N
329635	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Handicap dans la fonction publique	\N	2018-11-27 14:00:00	2018-11-27 16:30:00	\N	\N	2	0	\N	\N
331421	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL PADHUE	\N	2018-12-03 15:30:00	2018-12-03 18:30:00	\N	\N	0	0	\N	\N
331424	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL PADHUE	\N	2018-12-04 09:00:00	2018-12-04 11:00:00	\N	\N	0	0	\N	\N
331425	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL PADHUE	\N	2018-12-04 15:30:00	2018-12-04 16:30:00	\N	\N	0	0	\N	\N
331577	DELEGATION	AUCUNE	\N	\N	DSOM	Audition de M. Franck Riester, ministre de la culture	Audition de M. Franck Riester, ministre de la culture	2019-01-17 09:10:00	2019-01-17 10:50:00	2019-01-17 11:33:19	2019-01-17 11:57:20	31	0	\N	\N
331590	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Auditions	\N	2018-12-05 09:05:00	2018-12-05 11:05:00	2018-12-05 11:52:56	2018-12-05 16:42:20	64	0	\N	\N
214974	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Réhabiliter la police de proximité	\N	2017-11-07 14:40:00	2017-11-07 17:00:00	\N	\N	2	0	\N	\N
217338	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de M. Benjamin Griveaux, secrétaire d'Etat 	Audition de M. Benjamin Griveaux, secrétaire d'Etat auprès du ministre de l'économie et des finances 	2017-11-07 19:10:00	2017-11-07 20:10:00	2017-11-10 15:37:24	2017-11-10 16:02:02	23	0	\N	\N
328614	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2018-11-28 09:35:00	2018-11-28 11:20:00	2018-11-28 11:52:12	2018-11-28 12:00:10	38	2	\N	\N
227640	COM_EURO	AUDRAP	\N	AFEU	\N	COSI	Comité permanent de coopération opérationnelle en matière de sécurité intérieure (COSI)	2017-12-06 15:10:00	2017-12-06 16:10:00	\N	\N	2	0	\N	\N
227643	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	Négociations commerciales	Négociations commerciales	2017-12-06 15:30:00	2017-12-06 16:30:00	\N	\N	4	0	\N	\N
241242	GIA	AUCUNE	\N	\N	\N	Assemblée générale	Assemblée générale	2018-01-17 14:00:00	2018-01-17 14:30:00	\N	\N	4	0	611	\N
241494	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2018-02-07 10:55:00	2018-02-07 11:55:00	2018-02-07 12:32:46	2018-02-07 15:02:25	39	0	\N	\N
242005	GIA	AUCUNE	\N	\N	\N	Assemblée générale	Assemblée générale (composition du bureau et échange sur les projets)	2018-01-31 14:30:00	2018-01-31 15:00:00	\N	\N	2	0	532	\N
243139	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation de la KNESSET	Déjeuner de travail avec uine délégation de la KNESSET	2018-02-07 13:00:00	2018-02-07 14:30:00	\N	\N	23	0	595	\N
247233	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Simplification du code de commerce	\N	2018-02-14 17:00:00	2018-02-14 19:00:00	\N	\N	2	0	\N	\N
255913	DELEGATION	AUDRAP	\N	\N	211	Audition du Docteur Emmanuelle Piet, présidente du Collectif féministe contre le viol	Audition du Docteur Emmanuelle Piet, présidente du Collectif féministe contre le viol	2018-03-15 13:30:00	2018-03-15 14:45:00	\N	\N	3	0	\N	\N
258032	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition Orsenna	Audition Orsenna	2018-03-21 11:20:00	2018-03-21 13:00:00	2018-03-22 17:58:28	2018-03-23 10:19:21	35	0	\N	\N
262795	ETUDES	AUCUNE	\N	\N	\N	Réunion constitutive	Réunion constitutive	2018-04-03 14:00:00	2018-04-03 14:45:00	\N	\N	7	0	\N	1006
264156	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Programmation militaire pour les années 2019 à 2025	\N	2018-04-05 14:00:00	2018-04-05 15:15:00	\N	\N	1	0	\N	\N
265792	AUTRE_TEMPORAIRE	AUTRE_NON_PLENIERE	\N	\N	\N	\N	\N	2018-05-16 14:30:00	2018-05-16 15:30:00	\N	\N	0	0	\N	\N
266028	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2018 - Mission "Écologie" - Péages Urbains - Déplacement à Londres	Contrôle 2018 - Mission "Écologie" - Péages Urbains - Déplacement à Londres	2018-04-11 17:05:00	2018-04-12 21:45:00	\N	\N	1	0	\N	\N
266413	GIA	AUCUNE	\N	\N	\N	Audition du nonce apostlique en France	Audition du nonce apostlique en France	2018-04-10 18:00:00	2018-04-10 19:30:00	\N	\N	23	0	629	\N
266640	BUREAU	AUCUNE	\N	\N	\N	Délégation Statut du sénateur	Délégation Statut du sénateur	2018-04-11 12:00:00	2018-04-11 12:30:00	\N	\N	4	0	\N	\N
266685	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions rapporteurs	MI responsabilité civile	2018-04-10 15:45:00	2018-04-10 16:45:00	\N	\N	2	0	\N	\N
266808	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2018-04-12 09:35:00	2018-04-12 11:05:00	2018-04-12 12:13:11	2018-04-12 18:12:06	37	0	\N	\N
266954	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Agriculture bio 	Contrôle 2018 - Mission "Agriculture, alimentation, forêt et affaires rurales" - Agriculture bio - INRA	2018-04-11 14:30:00	2018-04-11 16:00:00	\N	\N	2	0	\N	\N
266959	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Agriculture bio - FNSEA	Contrôle 2018 - Mission "Agriculture, alimentation, forêt et affaires rurales" - Agriculture bio - FNSEA	2018-04-11 16:00:00	2018-04-11 18:15:00	\N	\N	2	0	\N	\N
267664	COM_PERMANENTE	AUTRE	\N	CDD	\N	\N	\N	2018-04-17 17:00:00	2018-04-17 18:05:00	2018-04-18 12:32:53	2018-04-18 16:47:54	17	0	\N	\N
267666	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	Négociations commerciales - Canada	Entretien avec M. François-Philippe Champagne, ministre canadien du commerce international	2018-04-17 12:20:00	2018-04-17 13:20:00	\N	\N	6	0	\N	\N
268583	COM_ENQUETE	PLENIERE	\N	FORCES	\N	Audition CE FSI	Audition CE FSI	2018-04-18 14:00:00	2018-04-18 17:15:00	2018-04-20 14:41:40	2018-04-20 14:57:26	11	0	\N	\N
269369	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GS Brexit - Audition CNP et FNSEA	GS Brexit - Audition CNP et FNSEA	2018-04-18 15:05:00	2018-04-18 16:30:00	\N	\N	8	0	\N	\N
273867	DELEGATION	AUDRAP	\N	\N	206	Audition bioéthique de Mme Esper et du Pr Fiessinger, Académie nationale de médecine	Audition bioéthique de Mme C. Esper et du Professeur J.N. Fiessinger, membres de l'Académie nationale de médecine	2018-05-23 15:00:00	2018-05-23 16:00:00	\N	\N	2	0	\N	\N
273872	DELEGATION	AUDRAP	\N	\N	206	Audition Risques sanitaires	Audition Risques sanitaires de France Stratégie	2018-06-07 11:30:00	2018-06-07 12:30:00	\N	\N	1	0	\N	\N
295633	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2018  - Réseau enseignement français à l'étranger - Cabinets Ministres	Contrôle 2018  - Réseau enseignement français à l'étranger - Cabinets Ministres	2018-07-05 10:30:00	2018-07-05 11:45:00	\N	\N	2	0	\N	\N
295643	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Audition de M. Augustin de Romanet (ADP)	\N	2018-07-05 08:30:00	2018-07-05 10:00:00	\N	\N	0	0	\N	\N
295668	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Audition plénière	\N	2018-07-10 18:00:00	2018-07-10 19:30:00	\N	\N	0	0	\N	\N
295669	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Audition plénière	\N	2018-07-10 16:00:00	2018-07-10 17:30:00	\N	\N	0	0	\N	\N
295671	AUTRE_TEMPORAIRE	AUTRE_NON_PLENIERE	\N	\N	\N	\N	\N	2018-07-12 14:30:00	2018-07-12 15:30:00	\N	\N	0	0	\N	\N
295672	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	Auditions rapporteur	\N	2018-07-20 09:00:00	2018-07-20 12:00:00	\N	\N	0	0	\N	\N
295675	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 5 juillet 2018	Réunion du 5 juillet 2018	2018-07-05 09:05:00	2018-07-05 10:15:00	2018-07-06 17:21:25	2018-07-06 17:50:35	14	0	\N	\N
295678	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	SOCI	\N	\N	\N	2018-07-04 17:00:00	2018-07-04 18:00:00	\N	\N	0	0	\N	\N
295679	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJLC démocratie plus représentative	\N	2018-07-03 10:15:00	2018-07-03 11:15:00	\N	\N	2	0	\N	\N
295680	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJLC démocratie plus représentative	\N	2018-07-04 17:00:00	2018-07-04 18:00:00	\N	\N	2	0	\N	\N
314108	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Cohésion des territoires	PPL Cohésion des territoires	2018-11-08 16:20:00	2018-11-08 20:30:00	\N	\N	0	0	\N	\N
314126	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2018-11-08 15:00:00	2018-11-08 16:10:00	\N	\N	235	0	\N	\N
314135	ETUDES	AUCUNE	\N	\N	\N	\N	\N	2018-10-18 08:30:00	2018-10-18 09:30:00	\N	\N	6	0	\N	922
314147	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2019	PLFSS 2019	2018-11-12 16:00:00	2018-11-12 19:50:00	\N	\N	49	0	\N	\N
314148	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2019	PLFSS 2019	2018-11-13 14:30:00	2018-11-13 16:30:00	\N	\N	153	0	\N	\N
314149	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2019	PLFSS 2019	2018-11-13 18:00:00	2018-11-13 19:30:00	\N	\N	107	0	\N	\N
314150	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2019	PLFSS 2019	2018-11-13 21:30:00	2018-11-14 00:20:00	\N	\N	112	0	\N	\N
241490	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2018-02-07 09:50:00	2018-02-07 10:55:00	2018-02-07 12:33:54	2018-02-07 15:01:20	39	0	\N	\N
255306	CMP	AUTRE	\N	CONTRATS	\N	PJL Réforme du droit des contrats	PJL Réforme du droit des contrats	2018-03-14 11:35:00	2018-03-14 11:50:00	\N	\N	8	0	\N	\N
314151	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2018-11-13 16:45:00	2018-11-13 17:50:00	\N	\N	299	0	\N	\N
314152	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2019	PLFSS 2019	2018-11-14 14:30:00	2018-11-14 19:35:00	\N	\N	179	0	\N	\N
314153	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2019	PLFSS 2019	2018-11-14 21:30:00	2018-11-15 01:10:00	\N	\N	85	0	\N	\N
314154	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2019	PLFSS 2019	2018-11-15 10:30:00	2018-11-15 13:00:00	\N	\N	98	0	\N	\N
314155	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2019	PLFSS 2019	2018-11-15 14:30:00	2018-11-15 19:50:00	\N	\N	96	0	\N	\N
314156	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2019	PLFSS 2019	2018-11-15 21:30:00	2018-11-16 00:30:00	\N	\N	50	0	\N	\N
314157	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2019	PLFSS 2019	2018-11-16 09:30:00	2018-11-16 13:00:00	\N	\N	46	0	\N	\N
314158	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2019	PLFSS 2019	2018-11-16 14:30:00	2018-11-16 19:20:00	\N	\N	47	0	\N	\N
289806	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	justice prud'hommale	justice prud'hommale	2018-06-25 14:00:00	2018-06-25 17:30:00	\N	\N	2	0	\N	\N
309069	DELEGATION	AUCUNE	\N	\N	COLTER	TR "Communes dans les intercommunalités" ; Bilan travaux "Revitalisation centres-villes"	\N	2018-10-11 09:00:00	2018-10-11 11:15:00	2018-10-11 11:44:18	2018-10-11 16:05:29	21	0	\N	\N
309214	GIA	AUCUNE	\N	\N	\N	petit-déjeuner directeur général de l'ANSSI	petit-déjeuner directeur général de l'ANSSI	2018-10-03 08:00:00	2018-10-03 10:00:00	\N	\N	13	0	608	\N
309239	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Pastoralisme	GT Pastoralisme	2018-09-26 10:00:00	2018-09-26 11:30:00	\N	\N	12	0	\N	\N
309265	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL-PJLO Justice	PJL-PJLO Justice	2018-10-10 14:30:00	2018-10-10 19:55:00	\N	\N	151	0	\N	\N
309266	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL-PJLO Justice	PJL-PJLO Justice	2018-10-10 21:30:00	2018-10-11 00:00:00	\N	\N	65	0	\N	\N
309267	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL-PJLO Justice	PJL-PJLO Justice	2018-10-11 10:30:00	2018-10-11 12:50:00	\N	\N	85	0	\N	\N
309268	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2018-10-11 15:00:00	2018-10-11 16:10:00	\N	\N	235	0	\N	\N
309269	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL-PJLO Justice	PJL-PJLO Justice	2018-10-11 16:20:00	2018-10-11 19:05:00	\N	\N	50	0	\N	\N
309270	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PJL ELAN	CMP PJL ELAN	2018-10-16 14:30:00	2018-10-16 16:35:00	\N	\N	173	0	\N	\N
309271	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2018-10-16 16:45:00	2018-10-16 17:55:00	\N	\N	301	0	\N	\N
309272	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL-PJLO Justice	PJL-PJLO Justice	2018-10-16 18:05:00	2018-10-16 20:05:00	\N	\N	87	0	\N	\N
309273	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL-PJLO Justice	PJL-PJLO Justice	2018-10-16 21:35:00	2018-10-17 00:10:00	\N	\N	54	0	\N	\N
309274	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat préalable Conseil européen du 18 octobre	Débat préalable Conseil européen du 18 octobre	2018-10-17 14:30:00	2018-10-17 16:40:00	\N	\N	111	0	\N	\N
309275	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL-PJLO Justice	PJL-PJLO Justice	2018-10-17 16:45:00	2018-10-17 19:20:00	\N	\N	77	0	\N	\N
309276	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL-PJLO Justice	PJL-PJLO Justice	2018-10-17 21:30:00	2018-10-17 22:15:00	\N	\N	24	0	\N	\N
309279	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2018-10-23 09:30:00	2018-10-23 12:50:00	\N	\N	48	0	\N	\N
309281	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Gens du voyage	PPL Gens du voyage	2018-10-23 19:25:00	2018-10-23 21:20:00	\N	\N	78	0	\N	\N
309282	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Calcul allocations adultes handicapés	PPL Calcul allocations adultes handicapés	2018-10-24 14:30:00	2018-10-24 16:10:00	\N	\N	90	0	\N	\N
309283	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Dette publique, dette privée	Débat Dette publique, dette privée	2018-10-24 16:15:00	2018-10-24 17:40:00	\N	\N	62	0	\N	\N
309288	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2018-10-25 15:00:00	2018-10-25 16:05:00	\N	\N	256	0	\N	\N
309289	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Reconnaissance proches aidants	PPL Reconnaissance proches aidants	2018-10-25 16:15:00	2018-10-25 18:55:00	\N	\N	62	0	\N	\N
309290	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2018-10-30 16:45:00	2018-10-30 17:45:00	\N	\N	270	0	\N	\N
309291	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Crise migratoire	Débat Crise migratoire	2018-10-30 17:55:00	2018-10-30 19:45:00	\N	\N	76	0	\N	\N
309292	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Surtransposition droit européen	Débat Surtransposition droit européen	2018-10-31 15:55:00	2018-10-31 17:30:00	\N	\N	61	0	\N	\N
309293	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat financement accompagnement personnes handicapées	Débat financement accompagnement personnes handicapées	2018-10-31 15:30:00	2018-10-31 15:55:00	\N	\N	38	0	\N	\N
310235	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2019 - Programme 151	\N	2018-10-09 09:00:00	2018-10-09 10:30:00	\N	\N	2	0	\N	\N
310257	COM_SPECIALE	PLENIERE	\N	RETRAIT	\N	Réunion constitutive	\N	2018-10-10 17:05:00	2018-10-10 17:35:00	2018-10-10 18:26:30	2018-10-11 16:04:35	24	1	\N	\N
311614	COM_SPECIALE	PLENIERE	\N	SURTRANSPO	\N	\N	\N	2018-10-11 16:20:00	2018-10-11 16:25:00	2018-10-12 17:17:46	2018-10-12 17:18:04	7	0	\N	\N
313326	GIA	AUCUNE	\N	\N	\N	petit déjeuner de travail 	petit déjeuner de travail Avec la sous-directrice de l¿Asie méridionale du Ministère des affaires étrangères et de l¿Eur	2018-10-17 08:30:00	2018-10-17 09:15:00	\N	\N	5	0	550	\N
313924	DELEGATION	AUDRAP	\N	\N	206	Audition FNTV (Arrêt des véhicules thermiques)	Audition FNTV (Arrêt des véhicules thermiques)	2018-10-16 09:00:00	2018-10-16 10:00:00	\N	\N	2	0	\N	\N
313927	DELEGATION	AUDRAP	\N	\N	206	Audition PFA (Arrêt des véhicules thermiques)	Audition PFA (Arrêt des véhicules thermiques)	2018-10-16 10:00:00	2018-10-16 11:00:00	\N	\N	2	0	\N	\N
313930	DELEGATION	AUDRAP	\N	\N	206	Audition Toyota France (Arrêt des véhicules thermiques)	Audition Toyota France (Arrêt des véhicules thermiques)	2018-10-18 09:00:00	2018-10-18 10:00:00	\N	\N	2	0	\N	\N
218302	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2018 matin	PLF 2018 matin	2017-11-30 10:30:00	2017-11-30 12:05:00	\N	\N	83	0	\N	\N
313933	DELEGATION	AUDRAP	\N	\N	206	Audition CEA (Arrêt des véhicules thermiques)	Audition CEA (Arrêt des véhicules thermiques)	2018-10-18 10:00:00	2018-10-18 11:00:00	\N	\N	2	0	\N	\N
313936	DELEGATION	AUDRAP	\N	\N	206	Audition Agence internationale de l'énergie (Arrêt des véhicules thermiques)	Audition Agence internationale de l'énergie (Arrêt des véhicules thermiques)	2018-10-18 11:00:00	2018-10-18 12:00:00	\N	\N	2	0	\N	\N
314069	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	COM AFD	\N	2018-10-16 18:00:00	2018-10-16 19:00:00	\N	\N	2	0	\N	\N
314072	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	COM AFD	\N	2018-10-17 12:00:00	2018-10-17 13:00:00	\N	\N	2	0	\N	\N
314127	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition PME et Numérique	Audition PME et Numérique	2018-10-16 09:30:00	2018-10-16 10:30:00	\N	\N	1	0	\N	\N
314130	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition PME et Numérique	Audition PME et Numérique	2018-10-17 16:30:00	2018-10-17 17:30:00	\N	\N	1	0	\N	\N
314169	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat CETA	Débat CETA	2018-11-20 21:30:00	2018-11-20 23:05:00	\N	\N	33	0	\N	\N
314173	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Désertification bancaire	PPL Désertification bancaire	2018-11-21 14:35:00	2018-11-21 17:15:00	\N	\N	113	0	\N	\N
314174	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Ruralité chance pour la France	Débat Ruralité chance pour la France	2018-11-21 17:20:00	2018-11-21 18:40:00	\N	\N	78	0	\N	\N
314175	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPLO Élections sénateurs	PPLO Élections sénateurs	2018-11-21 18:45:00	2018-11-21 20:40:00	\N	\N	88	0	\N	\N
314178	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Risques pneumatiques usagés terrains de sport	PPL Risques pneumatiques usagés terrains de sport	2018-11-21 22:10:00	2018-11-21 23:35:00	\N	\N	45	0	\N	\N
314179	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Conseils d'administration des SDIS 	PPL Conseils d'administration des SDIS 	2018-10-30 14:30:00	2018-10-30 15:15:00	\N	\N	78	0	\N	\N
314180	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Culture - DG Pat. et SG Culture	PLF pour 2019 - Culture - DG Pat. et SG Culture	2018-10-18 15:00:00	2018-10-18 17:00:00	\N	\N	1	0	\N	\N
314181	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Exposition précoce enfants écrans	PPL Exposition précoce enfants écrans	2018-11-20 17:55:00	2018-11-20 18:50:00	\N	\N	39	0	\N	\N
314184	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - APD - AFD	PLF pour 2019 - APD - AFD	2018-10-17 18:30:00	2018-10-17 19:15:00	\N	\N	2	0	\N	\N
314187	COM_SPECIALE	PLENIERE	\N	ENTREPRISES	\N	Réunion 20181025	\N	2018-10-25 10:45:00	2018-10-25 12:40:00	2018-10-25 12:42:38	2018-10-25 18:10:20	27	0	\N	\N
217351	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2018 Justice - TGI Bobigny	PLF pour 2018 Justice - TGI Bobigny	2017-11-07 09:00:00	2017-11-07 12:00:00	\N	\N	1	0	\N	\N
217365	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF 2018 - Justice	PLF 2018 - Justice - Ministère de la justice	2017-11-07 14:00:00	2017-11-07 15:15:00	\N	\N	1	0	\N	\N
217367	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour  2018 - Justice 	PLF pour  2018 - Justice  - Ministère du budget	2017-11-07 18:00:00	2017-11-07 18:45:00	\N	\N	1	0	\N	\N
217410	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF POUR 2018 - Avis Outre-mer	\N	2017-11-10 09:00:00	2017-11-10 12:00:00	\N	\N	1	0	\N	\N
217420	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2018 Avis DAG	\N	2017-10-20 09:30:00	2017-10-20 12:00:00	\N	\N	1	0	\N	\N
217426	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	P	PLF pour 2018 Avis DAG	2017-10-20 14:30:00	2017-10-20 17:00:00	\N	\N	1	0	\N	\N
217431	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	PLF pour 2018 Avis DAG	2017-10-23 18:00:00	2017-10-23 19:00:00	\N	\N	1	0	\N	\N
217433	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2018 Avis DAG	PLF pour 2018 Avis DAG	2017-10-30 15:00:00	2017-10-30 16:30:00	\N	\N	1	0	\N	\N
217435	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	PLF pour 2018 Avis DAG	2017-11-06 14:15:00	2017-11-06 18:00:00	\N	\N	1	0	\N	\N
223380	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Délégation ukrainienne	\N	2017-11-20 09:45:00	2017-11-20 10:45:00	\N	\N	1	0	\N	\N
223667	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	Auditions GT Infractions sexuelles	GT Infractions sexuelles	2017-11-29 14:00:00	2017-11-29 18:00:00	\N	\N	6	0	\N	\N
232766	COM_EURO	CONTROLE	\N	AFEU	\N	Audition de Mme Nathalie Loiseau	Audition de Mme Nathalie Loiseau, ministre déléguée aux affaires européennes	2017-12-21 09:05:00	2017-12-21 10:30:00	2017-12-21 11:15:15	2017-12-21 14:49:07	12	0	\N	\N
241162	DELEGATION	AUDRAP	\N	\N	206	Audition de l'Agence de la biomédecine	Audition de l'Agence de la biomédecine	2018-02-15 16:30:00	2018-02-15 18:00:00	\N	\N	2	0	\N	\N
241177	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Missions et moyens de la douane - 2018	Missions et moyens de la douane - 2018	2018-01-31 13:15:00	2018-01-31 18:15:00	\N	\N	16	0	\N	\N
250225	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Protection des données personnelles	\N	2018-02-27 14:30:00	2018-02-27 18:00:00	\N	\N	1	0	\N	\N
250227	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Protection des données personnelles	\N	2018-02-28 11:30:00	2018-02-28 12:50:00	\N	\N	1	0	\N	\N
250229	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Protection des données personnelles	\N	2018-02-28 14:30:00	2018-02-28 17:30:00	\N	\N	1	0	\N	\N
250231	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Protection des données personnelles	\N	2018-02-28 17:30:00	2018-02-28 19:15:00	\N	\N	2	0	\N	\N
264287	COM_EURO	AUTRE_NON_PLENIERE	\N	AFEU	\N	M. Dombrovskis, vice-président de la Commission européenne	Entretien avec M. Valdis Dombrovskis, vice-président de la Commission européenne, chargé de l'euro et du dialogue social	2018-04-09 17:00:00	2018-04-09 18:00:00	\N	\N	3	0	\N	\N
280946	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	Audition de M. Stéphane Travert	2018-06-06 14:05:00	2018-06-06 15:55:00	2018-06-06 19:25:36	2018-06-07 18:43:41	56	0	\N	\N
281391	ETUDES	AUCUNE	\N	\N	\N	GE Cheval	\N	2018-06-06 08:00:00	2018-06-06 09:00:00	\N	\N	3	0	\N	912
232753	CMP	AUTRE	\N	GEMAPI	\N	PPL Gestion des milieux aquatiques et prévention des inondations	\N	2017-12-19 20:30:00	2017-12-19 20:40:00	\N	\N	7	0	\N	\N
244580	COM_PERMANENTE	AUTRE	\N	CDD	\N	Examen PPL Investissements dans les réseaux à très haut débit	Examen du rapport et du texte de la commission sur la proposition de loi n° 83 (2017-2018) tendant à sécuriser et à enco	2018-02-21 11:25:00	2018-02-21 12:35:00	2018-02-22 19:16:17	2018-02-23 09:59:51	42	2	\N	\N
289416	COM_EURO	AUTRE_NON_PLENIERE	\N	AFEU	\N	Rencontre avec une délégation du Parlement chypriote	Rencontre avec une délégation du Parlement chypriote	2018-06-20 18:00:00	2018-06-20 19:00:00	\N	\N	1	0	\N	\N
289418	COM_EURO	AUTRE_NON_PLENIERE	\N	AFEU	\N	Rencontre avec une délégation du Sénat du Royaume du Maroc	Rencontre avec une délégation du Sénat du Royaume du Maroc	2018-06-21 11:00:00	2018-06-21 14:00:00	\N	\N	2	0	\N	\N
289601	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation	Déjeuner du 21 juin	2018-06-21 12:30:00	2018-06-21 14:00:00	\N	\N	6	0	626	\N
302583	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition des organisations professionnelles de la police nationale	\N	2018-07-24 14:30:00	2018-07-24 16:35:00	2018-07-25 15:55:41	2018-07-25 17:10:45	44	0	\N	\N
303132	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	La maion de l'artemisia	\N	2018-07-26 11:00:00	2018-07-26 12:00:00	\N	\N	0	0	\N	\N
305372	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Didier Chabert, ambassadeur de France au Kosovo	Entretien avec M. Didier Chabert, ambassadeur de France au Kosovo	2018-08-29 15:00:00	2018-08-29 16:15:00	\N	\N	1	0	674	\N
305374	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Guillaume Rousson, ambassadeur de France en Bosnie-Herzégovine	Entretien avec M. Guillaume Rousson, ambassadeur de France en Bosnie-Herzégovine	2018-08-30 08:00:00	2018-08-30 09:30:00	\N	\N	3	0	674	\N
307031	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2018-10-03 10:10:00	2018-10-03 13:05:00	2018-10-03 15:47:28	2018-10-03 17:35:56	41	0	\N	\N
307055	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PROG Programmation 2018-2022 et réforme pour la justice	\N	2018-09-25 09:00:00	2018-09-25 10:00:00	\N	\N	2	0	\N	\N
307058	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PROG Programmation 2018-2022 et réforme pour la justice	\N	2018-09-26 14:30:00	2018-09-26 19:30:00	\N	\N	2	0	\N	\N
307061	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PROG Programmation 2018-2022 et réforme pour la justice	\N	2018-09-27 10:30:00	2018-09-27 12:15:00	\N	\N	2	0	\N	\N
308810	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Pastoralisme	GT Pastoralisme	2018-09-19 17:00:00	2018-09-19 18:30:00	\N	\N	8	0	\N	\N
308826	ETUDES	AUCUNE	\N	\N	\N	GE Cultures traditionnelles et spécialisées - Déjeuner 3 octobre 2018	GE Cultures traditionnelles et spécialisées - Déjeuner 3 octobre 2018	2018-10-03 13:00:00	2018-10-03 14:30:00	\N	\N	25	0	\N	1005
308855	ETUDES	AUCUNE	\N	\N	\N	Réunion GE Agriculture et alimentation	Réunion GE Agriculture et alimentation	2018-10-02 18:00:00	2018-10-02 20:00:00	\N	\N	23	0	\N	919
308898	ETUDES	AUCUNE	\N	\N	\N	GE Chasse et pêche	GE Chasse et pêche	2018-10-03 08:00:00	2018-10-03 09:45:00	\N	\N	34	0	\N	907
309124	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition 58-2 chaîne de paiement aides agricoles - Contrôle Aide alimentaire	Audition 58-2 chaîne de paiement aides agricoles - Contrôle Aide alimentaire	2018-10-10 09:00:00	2018-10-10 11:35:00	2018-10-10 14:31:24	2018-10-10 16:56:08	34	0	\N	\N
309153	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2018-10-10 09:30:00	2018-10-10 11:50:00	2018-10-10 16:55:34	2018-10-10 16:56:09	31	0	\N	\N
309156	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Livre et Industries culturelles	PLF 2019 - Crédits Presse	2018-10-04 16:00:00	2018-10-04 17:00:00	\N	\N	2	0	\N	\N
309157	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Presse	PLF 2019 - Crédits Presse	2018-10-04 17:00:00	2018-10-04 18:00:00	\N	\N	2	0	\N	\N
309202	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - MIRES - Conf PDTS Universités (CPU) - Ministère enseignement supérieur	PLF pour 2019 - MIRES - Conf PDTS Universités (CPU) - Ministère enseignement supérieur	2018-10-03 15:00:00	2018-10-03 17:00:00	\N	\N	1	0	\N	\N
309204	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - PIA - BPIFrance et SGPI	PLF pour 2019 - PIA - BPIFrance et SGPI	2018-10-03 15:00:00	2018-10-03 17:30:00	\N	\N	1	0	\N	\N
309206	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - PIA - CNRS	PLF pour 2019 - PIA - CNRS	2018-10-02 18:00:00	2018-10-02 19:00:00	\N	\N	1	0	\N	\N
309208	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Lutte contre les feux de forêts - FNSPF	Contrôle 2018 - Lutte contre les feux de forêts - FNSPF	2018-10-03 08:30:00	2018-10-03 09:30:00	\N	\N	1	0	\N	\N
286215	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2018-06-20 09:45:00	2018-06-20 11:00:00	2018-06-20 14:48:29	2018-06-20 16:07:08	33	0	\N	\N
288631	MISSION	AUCUNE	\N	HERBE	\N	Audition plénière	\N	2018-06-21 10:35:00	2018-06-21 12:10:00	2018-06-21 16:47:05	2018-06-21 17:03:47	9	0	\N	\N
288668	MISSION	AUCUNE	\N	HERBE	\N	Audition plénière	\N	2018-06-21 14:10:00	2018-06-21 15:00:00	2018-06-21 16:48:50	2018-06-21 17:03:48	8	0	\N	\N
288954	GIA	AUCUNE	\N	\N	\N	Table ronde ONG 	table ronde avec les ONG sur la situation humanitiare du Yémen 	2018-06-20 14:00:00	2018-06-20 15:30:00	\N	\N	5	0	627	\N
288963	GIA	AUCUNE	\N	\N	\N	Entretien groupe Total Yémen	déjeuner de travail avec 2 représentants du groupe Total au Yémen 	2018-06-21 12:45:00	2018-06-21 14:15:00	\N	\N	4	0	627	\N
289087	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Droit d'asile	PJL Droit d'asile	2018-06-22 09:30:00	2018-06-22 13:10:00	\N	\N	55	0	\N	\N
289088	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Droit d'asile	PJL Droit d'asile	2018-06-22 14:40:00	2018-06-22 20:25:00	\N	\N	58	0	\N	\N
333981	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des PRésidents	2018-12-04 14:00:00	2018-12-04 14:25:00	\N	\N	27	0	\N	\N
334024	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-12-04 14:30:00	2018-12-04 16:00:00	\N	\N	3	0	\N	\N
334029	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-12-04 16:00:00	2018-12-04 16:20:00	\N	\N	2	0	\N	\N
334033	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-12-04 16:45:00	2018-12-04 17:30:00	\N	\N	2	0	\N	\N
334036	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-12-04 17:30:00	2018-12-04 18:30:00	\N	\N	4	0	\N	\N
334042	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-12-04 18:30:00	2018-12-04 19:00:00	\N	\N	1	0	\N	\N
335732	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	1022	\N	\N	Explications de vote sur l'ensemble	Explications de vote sur l'ensemble	2018-12-11 15:45:00	2018-12-11 17:00:00	\N	\N	312	0	\N	\N
336568	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ambassadrice de France en Ukraine	Entretien avec Mme Isabelle Dumont, ambassadrice de France en Ukraine	2018-12-11 15:30:00	2018-12-11 16:15:00	\N	\N	3	0	530	\N
338592	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2018-12-19 11:00:00	2018-12-19 12:55:00	2018-12-19 14:34:44	2018-12-19 17:46:40	32	0	\N	\N
307030	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2018-10-03 09:30:00	2018-10-03 10:00:00	2018-10-03 15:46:51	2018-10-03 17:35:58	42	0	\N	\N
286214	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2018-06-20 09:30:00	2018-06-20 09:45:00	2018-06-20 14:50:14	2018-06-20 16:07:10	31	0	\N	\N
339473	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition plénière	\N	2018-12-19 16:30:00	2018-12-19 18:35:00	2018-12-19 18:41:17	2018-12-20 15:38:23	16	0	\N	\N
339505	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL PPLO Polynésie (nomination) - Rapport information Fiches S - Communication MCS SILT	PPL PPLO Polynésie (nomination) - Rapport information Fiches S - Communication MCS SILT	2018-12-19 09:40:00	2018-12-19 12:00:00	2018-12-19 15:50:51	2018-12-19 17:46:38	36	1	\N	\N
339552	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL  Croissance et transformation des entreprises	PJL  Croissance et transformation des entreprises	2019-02-07 11:35:00	2019-02-07 13:00:00	\N	\N	51	0	\N	\N
339553	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL  Croissance et transformation des entreprises	PJL  Croissance et transformation des entreprises	2019-02-07 14:30:00	2019-02-07 17:45:00	\N	\N	62	0	\N	\N
339556	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL et PJLO Réforme justice	PJL et PJLO Réforme justice	2019-02-12 16:05:00	2019-02-12 20:10:00	\N	\N	142	0	\N	\N
339558	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJLO et PJL Polynésie	PJLO et PJL Polynésie	2019-02-13 14:30:00	2019-02-13 17:45:00	\N	\N	121	0	\N	\N
339594	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Délai intervention juge Mayotte	PPL Délai intervention juge Mayotte	2019-02-14 11:50:00	2019-02-14 13:00:00	\N	\N	62	0	\N	\N
339595	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2019-02-14 15:00:00	2019-02-14 16:10:00	\N	\N	282	0	\N	\N
339596	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Délai intervention juge Mayotte	PPL Délai intervention juge Mayotte	2019-02-14 13:00:00	2019-02-14 14:00:00	\N	\N	0	0	\N	\N
339597	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2019-02-19 16:45:00	2019-02-19 17:50:00	\N	\N	299	0	\N	\N
340508	DELEGATION	AUTRE	\N	\N	211	Audition de Mme Nathalie Boy de la Tour	\N	2019-01-31 09:00:00	2019-01-31 10:30:00	\N	\N	0	0	\N	\N
340541	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Petites communes au sein des conseils communautaires	\N	2019-01-15 09:00:00	2019-01-15 09:35:00	\N	\N	1	0	\N	\N
340939	MECSS	AUDRAP	\N	\N	MECSS	\N	\N	2019-02-07 09:00:00	2019-02-07 10:30:00	\N	\N	1	0	\N	\N
346157	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Dépouillement article 13	\N	2019-01-30 10:30:00	2019-01-30 10:40:00	2019-02-05 16:00:03	2019-02-05 16:43:49	13	0	\N	\N
346173	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-01-30 11:05:00	2019-01-30 12:45:00	2019-01-30 16:25:59	2019-01-30 16:38:34	35	0	\N	\N
346252	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-01-30 14:10:00	2019-01-30 16:00:00	2019-01-30 16:36:17	2019-01-30 16:38:34	33	2	\N	\N
346296	DELEGATION	AUCUNE	\N	\N	DSOM	Visioconférence avec la Polynésie française	Visioconférence avec la Polynésie française	2019-01-30 18:30:00	2019-01-30 20:20:00	2019-01-31 12:02:37	2019-01-31 18:30:29	5	0	\N	\N
346533	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-02-06 16:00:00	2019-02-06 17:50:00	2019-02-06 18:07:10	2019-02-06 18:10:55	29	1	\N	\N
346571	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Prise en charge des cancers pédiatriques	\N	2019-01-30 15:00:00	2019-01-30 16:00:00	\N	\N	4	0	\N	\N
346577	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Prise en charge des cancers pédiatriques	\N	2019-01-30 16:00:00	2019-01-30 17:00:00	\N	\N	4	0	\N	\N
346938	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière	Réunion plénière	2019-01-31 09:05:00	2019-01-31 10:10:00	2019-01-31 11:10:42	2019-01-31 18:30:31	15	0	\N	\N
348023	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	GT ruralités : Les territoires de projet	\N	2019-02-07 09:00:00	2019-02-07 11:00:00	\N	\N	14	0	\N	\N
349650	GIA	AUCUNE	\N	\N	\N	réception ambassade de Biélorussie	réception ambassade de Biélorussie	2019-01-30 19:00:00	2019-01-30 20:30:00	\N	\N	2	0	852	\N
349653	GIA	AUCUNE	\N	\N	\N	entretien avec l'ambassadeur d'Arabie saoudite	entretien avec Son Excellence AL ANKARY, ambassadeur d'Arabie saoudite à Paris	2019-02-05 14:00:00	2019-02-05 14:45:00	\N	\N	1	0	627	\N
350902	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2019-02-12 09:30:00	2019-02-12 12:40:00	\N	\N	44	0	\N	\N
350956	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Sécurité des sapeurs-pompiers	PPL Sécurité des sapeurs-pompiers	2019-02-11 13:00:00	2019-02-11 17:00:00	\N	\N	2	0	\N	\N
352313	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Tourisme	Tourisme	2019-02-13 08:20:00	2019-02-13 09:00:00	\N	\N	8	0	\N	\N
353792	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI mission innovation et défense	\N	2019-02-13 14:00:00	2019-02-13 15:20:00	\N	\N	1	0	\N	\N
353794	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI mission innovation et défense	\N	2019-02-14 10:00:00	2019-02-14 12:20:00	\N	\N	1	0	\N	\N
356138	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Ecole militaire	\N	2019-02-21 08:15:00	2019-02-21 09:15:00	\N	\N	2	0	\N	\N
356141	GIA	AUCUNE	\N	\N	\N	Rencontre avec le président de la République d'Irak, Barham Saleh	Rencontre du Président du Sénat avec le président de la République d'Irak, Barham Saleh, suivie d'un dîner	2019-02-26 18:30:00	2019-02-26 21:00:00	\N	\N	1	0	615	\N
356290	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR Lutte contre mariage enfants	PPR Lutte contre mariage enfants	2019-03-14 16:00:00	2019-03-14 17:40:00	\N	\N	35	0	\N	\N
217120	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2018 - Programme 185	\N	2017-11-09 12:30:00	2017-11-09 13:30:00	\N	\N	2	0	\N	\N
217126	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2018 - Programme 144	\N	2017-11-07 15:30:00	2017-11-07 16:15:00	\N	\N	2	0	\N	\N
217143	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2018 - Programme 144	\N	2017-11-09 16:00:00	2017-11-09 18:00:00	\N	\N	2	0	\N	\N
227291	GIA	AUCUNE	\N	\N	\N	Entretien avec Mme Nathalie GOULET, sur le thème du secteur sportif	Entretien avec Mme Nathalie GOULET, sur le thème du secteur sportif	2017-12-05 14:30:00	2017-12-05 16:00:00	\N	\N	1	0	661	\N
227302	GIA	AUCUNE	\N	\N	\N	Entretien de Mme Ulricke BICK , juge au tribunal administratif allemand, avec M. BIGOT	Entretien de Mme Ulricke BICK , juge au tribunal administratif allemand, avec M. BIGOT	2017-12-05 14:30:00	2017-12-05 15:30:00	\N	\N	1	0	604	\N
227311	GIA	AUCUNE	\N	\N	\N	Entretien d'une délégation israélienne conduite par M. Jackie LEVI avec M. Patrick KANNER	Entretien d'une délégation israélienne conduite par M. Jackie LEVI avec M. Patrick KANNER	2017-12-04 14:30:00	2017-12-04 15:30:00	\N	\N	1	0	595	\N
227372	GIA	AUCUNE	\N	\N	\N	Entretien de M. ADNOT avec Marialbert Juliana BARRIOS SLOTHER, Députée à l'AN du Vénézuéla	Entretien de M. ADNOT avec Marialbert Juliana BARRIOS SLOTHER, Députée à l'AN du Vénézuéla	2017-12-06 16:30:00	2017-12-06 17:15:00	\N	\N	1	0	979	\N
227412	GIA	AUCUNE	\N	\N	\N	Entretien de M. ÉBLÉ avec une délégation de Sénateurs cambodgiens	Entretien de M. ÉBLÉ avec une délégation de Sénateurs cambodgiens	2017-10-23 14:00:00	2017-10-23 14:30:00	\N	\N	1	0	577	\N
227416	GIA	AUCUNE	\N	\N	\N	Dïner de travail présidé par M. LONGUET avec une délégation russes de parlementaires...	Dïner de travail présidé par M. LONGUET avec une délégation russes de parlementaires...	2017-10-17 19:15:00	2017-10-17 22:00:00	\N	\N	1	0	608	\N
231309	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	Auditions GT Infractions sexuelles 	2017-12-19 14:30:00	2017-12-19 16:30:00	\N	\N	6	0	\N	\N
231350	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	Audition GT Infractions sexuelles	2017-12-19 09:00:00	2017-12-19 10:00:00	\N	\N	2	0	\N	\N
232208	DELEGATION	DEPLACEMENT	\N	\N	ENTREPRISES	Déplacement de la délégation en Côte-d'Or	Déplacement de la délégation en Côte-d'Or	2017-12-15 06:15:00	2017-12-15 18:35:00	\N	\N	6	0	\N	\N
232997	DELEGATION	AUCUNE	\N	\N	COLTER	Audition AdCF : MM. Cauret et Lemaignen	\N	2018-01-18 09:30:00	2018-01-18 11:05:00	2018-01-18 14:55:35	2018-01-18 14:57:10	22	0	\N	\N
232998	DELEGATION	AUCUNE	\N	\N	COLTER	Audition M. Lambert, président du Conseil national d'évaluation des normes	\N	2018-01-18 12:30:00	2018-01-18 13:50:00	2018-01-18 14:50:26	2018-01-18 14:57:08	20	0	\N	\N
235429	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2018-01-24 09:30:00	2018-01-24 11:50:00	2018-01-24 18:12:44	2018-01-25 15:33:04	36	0	\N	\N
235434	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2018-01-24 15:00:00	2018-01-24 16:30:00	2018-01-25 16:51:31	2018-01-25 17:28:23	33	3	\N	\N
237543	GIA	AUCUNE	\N	\N	\N	AG du groupe	Assemblée générale du groupe et désignation du Bureau	2018-01-23 15:00:00	2018-01-23 15:35:00	\N	\N	6	0	659	\N
237746	GIA	AUCUNE	\N	\N	\N	AG du groupe	Assemblée générale du groupe et désignation du Bureau	2018-01-24 08:45:00	2018-01-24 09:15:00	\N	\N	8	0	581	\N
238514	GIA	AUCUNE	\N	\N	\N	Entretien avec l'Ambassadeur de la République du Kazakhstan	Entretien avec M. Jean Galiev, Ambassadeur de la République du Kazakhstan	2018-01-24 16:30:00	2018-01-24 17:15:00	\N	\N	3	0	556	\N
246408	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL  Convention Fondation UE-AC	\N	2018-02-15 10:30:00	2018-02-15 11:50:00	\N	\N	1	0	\N	\N
247119	COM_ENQUETE	PLENIERE	\N	FORCES	\N	Auditions syndicats policiers municipaux	\N	2018-02-15 16:15:00	2018-02-15 18:00:00	2018-02-20 16:05:37	2018-02-20 16:10:08	7	0	\N	\N
247127	GIA	AUCUNE	\N	\N	\N	Entretien avec le Quai d'Orsay	Entretien avec M. Frédéric Doré, Directeur des Amériques et des Caraïbes au Ministère de l'Europe et des affaires étrang	2018-02-13 14:00:00	2018-02-13 15:15:00	\N	\N	6	0	643	\N
253501	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de Mme Isabelle de Silva	Audition de Mme Isabelle de Silva, présidente de l'Autorité de la concurrence	2018-03-14 09:40:00	2018-03-14 11:05:00	2018-03-14 11:32:28	2018-03-14 15:31:52	41	0	\N	\N
255724	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition plénière	\N	2018-03-21 09:35:00	2018-03-21 11:45:00	2018-03-21 11:48:29	2018-03-21 12:07:11	36	0	\N	\N
255730	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition sur l'adaptation des règles impôt sociétés au nouveau contexte international	Audition sur l'adaptation des règles de l'impôt sur les sociétés au nouveau contexte international et européen	2018-03-21 10:10:00	2018-03-21 12:35:00	2018-03-21 15:11:48	2018-03-21 15:41:53	41	0	\N	\N
255870	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle - Les maisons de l'emploi	Contrôle - Les maisons de l'emploi - AMF	2018-03-13 17:45:00	2018-03-13 18:45:00	\N	\N	1	0	\N	\N
255872	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Défense - La disponibilité des hélicoptères du ministère des Armées	Contrôle Défense - La disponibilité des hélicoptères du ministère des Armées - Etat Major des Armées	2018-03-14 14:30:00	2018-03-14 16:00:00	\N	\N	1	0	\N	\N
255874	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle Navigation Aérienne 2018 - Déplacement Bordeaux	Contrôle Navigation Aérienne 2018 - Déplacement Bordeaux	2018-03-16 09:55:00	2018-03-16 19:40:00	\N	\N	1	0	\N	\N
255876	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe	Assemblée générale du groupe	2018-03-15 10:30:00	2018-03-15 11:00:00	\N	\N	4	0	852	\N
255882	GIA	AUCUNE	\N	\N	\N	groupe d'amitié France-Biélorussie	visite du Vice-minsitre des affaires étrangères biélorusse	2018-03-15 11:00:00	2018-03-15 12:00:00	\N	\N	3	0	852	\N
255918	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle APD	Contrôle APD - DG Trésor	2018-03-13 14:30:00	2018-03-13 16:30:00	\N	\N	2	0	\N	\N
255955	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Aide alimentaire	Contrôle Aide alimentaire - Associations d'aide alimentaire	2018-03-13 14:30:00	2018-03-13 16:30:00	\N	\N	1	0	\N	\N
255957	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Modernisation du contrôle de la navigation aérienne	Contrôle Modernisation du contrôle de la navigation aérienne - SNCTA	2018-03-14 15:15:00	2018-03-14 16:15:00	\N	\N	1	0	\N	\N
255959	DELEGATION	AUCUNE	\N	\N	DSOM	\N	\N	2018-03-21 19:00:00	2018-03-21 21:50:00	2018-03-23 10:44:03	2018-03-23 10:55:19	4	0	\N	\N
255960	DELEGATION	AUCUNE	\N	\N	DSOM	Visioconférence avec La Nouvelle-Calédonie	Visioconférence avec La Nouvelle-Calédonie (Jeunesse des outre-mer et sport)	2018-03-22 08:30:00	2018-03-22 10:55:00	2018-03-22 11:59:17	2018-03-22 12:25:50	6	0	\N	\N
255961	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Réforme des retraites 2018 	Contrôle Réforme des retraites 2018 - RATP	2018-03-13 14:30:00	2018-03-13 15:30:00	\N	\N	1	0	\N	\N
255969	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Aide alimentaire	Contrôle Aide alimentaire - Direction du budget	2018-03-14 18:00:00	2018-03-14 19:00:00	\N	\N	1	0	\N	\N
260438	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Gilles PÉCOUT, recteur de l'académie de Paris	Entretien avec M. Gilles PÉCOUT, recteur de l'académie de Paris	2018-03-28 08:15:00	2018-03-28 09:30:00	\N	\N	12	0	621	\N
263476	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2018-04-11 09:35:00	2018-04-11 10:40:00	2018-04-11 13:43:27	2018-04-11 14:43:10	37	1	\N	\N
270125	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	LPM 2019-2025	\N	2018-04-17 14:30:00	2018-04-17 15:30:00	\N	\N	2	0	\N	\N
275956	COM_EURO	AUTRE_NON_PLENIERE	\N	AFEU	\N	Entretien du bureau avec M. Georges Károlyi, ambassadeur de Hongrie en France	Entretien du bureau avec M. Georges Károlyi, ambassadeur de Hongrie en France	2018-05-23 18:50:00	2018-05-23 20:00:00	\N	\N	1	0	\N	\N
255729	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen des amendements de séance déposés sur le texte n° 349  - PJL n° 292	Examen des amendements de séance déposés sur le texte n° 349  - PJL n° 292 DSP2	2018-03-21 09:50:00	2018-03-21 10:10:00	2018-03-21 15:11:23	2018-03-21 15:41:50	40	0	\N	\N
218449	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2018 après-midi (Missions : Agriculture; Économie ; Outre-mer ; Recherc	PLF 2018 après-midi (Missions : Agriculture; Économie ; Outre-mer ; Recherc	2017-12-07 15:00:00	2017-12-07 20:10:00	\N	\N	102	0	\N	\N
218450	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2018 soir (Missions : Agriculture; Économie ; Outre-mer ; Recherche)	PLF 2018 soir (Missions : Agriculture; Économie ; Outre-mer ; Recherche)	2017-12-07 22:10:00	2017-12-08 00:40:00	\N	\N	32	0	\N	\N
289756	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	941	\N	\N	Explications de vote sur l'ensemble - PJL Droit d'asile	Explications de vote sur l'ensemble - PJL Droit d'asile	2018-06-26 15:00:00	2018-06-26 15:55:00	\N	\N	299	0	\N	\N
289757	SEANCE_PLENIERE	SCRUSOL	941	\N	\N	Scrutin solennel - PJL Droit d'asile	Scrutin solennel - PJL Droit d'asile	2018-06-26 16:00:00	2018-06-26 16:30:00	\N	\N	0	0	\N	\N
289809	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL "Démocratie locale"	PPL "Démocratie locale"	2018-05-31 08:30:00	2018-05-31 09:30:00	\N	\N	1	0	\N	\N
295636	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Avenir professionnel	PJL Avenir professionnel	2018-07-12 10:35:00	2018-07-12 13:10:00	\N	\N	84	0	\N	\N
295637	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Avenir professionnel	PJL Avenir professionnel	2018-07-12 21:00:00	2018-07-13 00:35:00	\N	\N	39	0	\N	\N
295638	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL ELAN	PJL ELAN	2018-07-16 14:30:00	2018-07-16 17:25:00	\N	\N	73	0	\N	\N
295640	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL ELAN	PJL ELAN	2018-07-19 10:35:00	2018-07-19 13:05:00	\N	\N	123	0	\N	\N
295641	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL ELAN	PJL ELAN	2018-07-23 15:05:00	2018-07-23 20:00:00	\N	\N	97	0	\N	\N
295642	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL ELAN	PJL ELAN	2018-07-23 21:30:00	2018-07-24 00:30:00	\N	\N	62	0	\N	\N
295644	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL ELAN	PJL ELAN	2018-07-24 14:30:00	2018-07-24 16:30:00	\N	\N	126	0	\N	\N
295654	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Relation de confiance	PJL Relation de confiance	2018-07-25 16:00:00	2018-07-25 21:00:00	\N	\N	43	0	\N	\N
295655	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Rodéos motorisés	PPL Rodéos motorisés	2018-07-26 15:00:00	2018-07-26 16:50:00	\N	\N	55	0	\N	\N
295658	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Fausses informations	PPL Fausses informations	2018-07-26 16:55:00	2018-07-26 19:45:00	\N	\N	47	0	\N	\N
295660	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Eau et assainissement	PPL Eau et assainissement	2018-07-26 19:45:00	2018-07-26 21:25:00	\N	\N	19	0	\N	\N
314190	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions PLF 2019 DAG	\N	2018-10-18 14:15:00	2018-10-18 18:00:00	\N	\N	1	0	\N	\N
314227	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 -Crédits Enseignement agricole	PLF 2019 -Crédits Enseignement agricole	2018-10-19 09:45:00	2018-10-19 10:30:00	\N	\N	2	0	\N	\N
314230	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 -Crédits Enseignement agricole	PLF 2019 -Crédits Enseignement agricole	2018-10-19 10:30:00	2018-10-19 11:15:00	\N	\N	2	0	\N	\N
314233	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 -Crédits Enseignement agricole	PLF 2019 -Crédits Enseignement agricole	2018-10-19 11:15:00	2018-10-19 12:00:00	\N	\N	2	0	\N	\N
314236	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Livre et Industries culturelles	PLF 2019 - Crédits Livre et Industries culturelles	2018-10-17 15:00:00	2018-10-17 16:00:00	\N	\N	2	0	\N	\N
314239	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Livre et Industries culturelles	PLF 2019 - Crédits Livre et Industries culturelles	2018-10-17 16:00:00	2018-10-17 17:00:00	\N	\N	2	0	\N	\N
314242	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Livre et Industries culturelles	PLF 2019 - Crédits Livre et Industries culturelles	2018-10-17 17:00:00	2018-10-17 18:00:00	\N	\N	2	0	\N	\N
314245	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Enseignement scolaire	PLF 2019 - Crédits Enseignement scolaire	2018-10-17 15:30:00	2018-10-17 16:30:00	\N	\N	2	0	\N	\N
314248	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Enseignement scolaire	PLF 2019 - Crédits Enseignement scolaire	2018-10-17 17:30:00	2018-10-17 18:15:00	\N	\N	2	0	\N	\N
314251	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Enseignement scolaire	PLF 2019 - Crédits Enseignement scolaire	2018-10-17 18:15:00	2018-10-17 19:00:00	\N	\N	1	0	\N	\N
314253	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Enseignement scolaire	PLF 2019 - Crédits Enseignement scolaire	2018-10-17 16:30:00	2018-10-17 17:30:00	\N	\N	1	0	\N	\N
314255	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Enseignement scolaire	PLF 2019 - Crédits Enseignement scolaire	2018-10-18 10:15:00	2018-10-18 11:00:00	\N	\N	1	0	\N	\N
314257	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Enseignement supérieur	PLF 2019 - Crédits Enseignement supérieur	2018-10-18 15:00:00	2018-10-18 16:30:00	\N	\N	2	0	\N	\N
314259	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Enseignement supérieur	PLF 2019 - Crédits Enseignement supérieur	2018-10-18 13:30:00	2018-10-18 14:15:00	\N	\N	1	0	\N	\N
335695	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-12-06 10:45:00	2018-12-06 11:30:00	\N	\N	1	0	\N	\N
314263	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Enseignement supérieur	PLF 2019 - Crédits Enseignement supérieur	2018-10-18 14:15:00	2018-10-18 15:00:00	\N	\N	1	0	\N	\N
314288	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 -Crédits Enseignement agricole	PLF 2019 -Crédits Enseignement agricole	2018-10-22 14:00:00	2018-10-22 14:45:00	\N	\N	1	0	\N	\N
314290	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 -Crédits Enseignement agricole	PLF 2019 -Crédits Enseignement agricole	2018-10-22 14:45:00	2018-10-22 15:30:00	\N	\N	1	0	\N	\N
314292	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition Rapp. PLF 2019 Transports	Audition Rapp. PLF 2019 Transports	2018-10-24 17:45:00	2018-10-24 18:45:00	\N	\N	1	0	\N	\N
314294	COM_PERMANENTE	DEPLACEMENT	\N	CDD	\N	Chantier RATP - Gare Pont Cardinet	\N	2018-10-18 13:00:00	2018-10-18 15:30:00	\N	\N	1	0	\N	\N
314301	COM_SPECIALE	AUDRAP	\N	SURTRANSPO	\N	SGAE	\N	2018-10-18 16:00:00	2018-10-18 17:45:00	\N	\N	1	0	\N	\N
314307	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition F. VIDAL	\N	2018-10-23 17:05:00	2018-10-23 18:50:00	2018-10-23 19:03:49	2018-10-24 12:15:27	30	0	\N	\N
314399	DELEGATION	AUDRAP	\N	\N	206	Audition Académie des technologies (Arrêt des véhicules thermiques)	Audition Académie des technologies (Arrêt des véhicules thermiques)	2018-10-23 09:00:00	2018-10-23 10:00:00	\N	\N	2	0	\N	\N
314402	DELEGATION	AUDRAP	\N	\N	206	Audition EDF (Arrêt des véhicules thermiques)	Audition EDF (Arrêt des véhicules thermiques)	2018-10-23 10:00:00	2018-10-23 11:00:00	\N	\N	2	0	\N	\N
217570	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2017-11-13 15:45:00	2017-11-13 15:55:00	2017-11-13 15:58:23	2017-11-13 17:12:24	29	0	\N	\N
217571	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2017-11-14 09:30:00	2017-11-14 10:35:00	2017-11-14 14:40:59	2017-11-14 16:13:53	45	0	\N	\N
217572	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2017-11-14 13:45:00	2017-11-14 16:10:00	2017-11-15 11:53:36	2017-11-15 15:05:53	41	0	\N	\N
217573	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2017-11-14 19:35:00	2017-11-14 20:30:00	2017-11-15 11:52:08	2017-11-15 15:05:48	38	0	\N	\N
217575	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2017-11-16 14:15:00	2017-11-16 14:20:00	2017-11-16 14:22:03	2017-11-16 15:28:21	9	0	\N	\N
226155	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2018 - Examen Amendements séance Missions	PLF pour 2018 - Examen Amendements de séance sur plusieurs Missions	2017-12-07 10:00:00	2017-12-07 10:15:00	2017-12-07 16:59:16	2017-12-08 09:09:04	21	1	\N	\N
226156	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2018 - Examen Amendements sur articles non rattachés	PLF pour 2018 - Examen Amendements sur les articles non rattachés aux crédits des missions	2017-12-07 20:15:00	2017-12-07 20:50:00	2017-12-08 15:28:12	2017-12-08 15:29:30	13	1	\N	\N
230909	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	\N	GT Infrations sexuelles Déplacement CHI Créteil	2017-12-18 14:00:00	2017-12-18 18:30:00	\N	\N	1	0	\N	\N
230911	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	\N	GT Infraction sexuelles : déplacement Brigade des mineurs de Paris et OCRVP	2017-12-20 14:00:00	2017-12-20 18:30:00	\N	\N	1	0	\N	\N
232729	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Orientation et réussite des étudiants	PJL Orientation et réussite des étudiants	2017-12-20 14:15:00	2017-12-20 16:00:00	\N	\N	2	0	\N	\N
232732	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Orientation	PJL Orientation et réussite des étudiants	2017-12-20 16:00:00	2017-12-20 17:00:00	\N	\N	1	0	\N	\N
232749	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI contrats aidés	MI contrats aidés	2017-12-19 14:00:00	2017-12-19 15:00:00	\N	\N	2	0	\N	\N
232752	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI contrats aidés	MI contrats aidés	2017-12-20 09:00:00	2017-12-20 10:00:00	\N	\N	2	0	\N	\N
232763	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI contrats aidés	MI contrats aidés	2017-12-20 14:00:00	2017-12-20 16:30:00	\N	\N	2	0	\N	\N
233055	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Route de la soie	\N	2018-01-09 18:00:00	2018-01-09 19:45:00	\N	\N	2	0	\N	\N
236345	GIA	AUCUNE	\N	\N	\N	Déjeuner en l'honneur d'une délégation du Sénat kényan conduite par son Président (coopé)	Déjeuner en l'honneur d'une délégation du Sénat kényan conduite par son Président (coopé)	2018-01-23 12:30:00	2018-01-23 14:30:00	\N	\N	4	0	622	\N
254840	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2018-03-13 14:40:00	2018-03-13 16:30:00	\N	\N	3	0	\N	\N
254997	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion	Réunion	2018-03-14 11:05:00	2018-03-14 12:30:00	2018-03-14 12:54:41	2018-03-14 15:32:20	61	0	\N	\N
254998	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Pass Culture	Pass Culture	2018-03-14 09:00:00	2018-03-14 10:00:00	\N	\N	5	0	\N	\N
258621	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Réunion de la commission des affaires étrangères	\N	2018-03-28 16:35:00	2018-03-28 18:20:00	2018-03-29 11:52:06	2018-03-29 12:40:01	20	0	\N	\N
279377	DELEGATION	AUCUNE	\N	\N	DSOM	Audition de Mme Annick Girardin, ministre des outre-mer	Audition de Mme Annick Girardin, ministre des outre-mer	2018-06-05 17:00:00	2018-06-05 19:00:00	2018-06-06 10:57:11	2018-06-06 12:30:16	13	0	\N	\N
305525	GIA	AUCUNE	\N	\N	\N	Réunion avec une délégation de l'association de développement économique serbe NALED	Réunion avec une délégation de l'association de développement économique serbe NALED	2018-09-12 10:00:00	2018-09-12 11:30:00	\N	\N	3	0	674	\N
305529	GIA	AUCUNE	\N	\N	\N	Fête nationale de Macédoine et 25ème anniversaire des relations bilatérales	Fête nationale de Macédoine et 25ème anniversaire des relations bilatérales	2018-09-12 18:00:00	2018-09-12 20:00:00	\N	\N	2	0	674	\N
307457	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	\N	2018-10-03 10:10:00	2018-10-03 11:25:00	2018-10-03 12:07:56	2018-10-03 15:16:39	40	1	\N	\N
307508	COM_PERMANENTE	AUTRE	\N	SOCI	\N	plénière	\N	2018-10-10 09:30:00	2018-10-10 12:50:00	2018-10-10 12:46:43	2018-10-10 12:52:10	45	0	\N	\N
307750	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Sport	PLF 2019 - Crédits Sport	2018-10-02 14:30:00	2018-10-02 15:25:00	\N	\N	4	0	\N	\N
307755	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Sport	PLF 2019 - Crédits Sport	2018-10-02 15:25:00	2018-10-02 16:10:00	\N	\N	3	0	\N	\N
307759	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Sport	PLF 2019 - Crédits Sport	2018-10-02 16:10:00	2018-10-02 16:45:00	\N	\N	2	0	\N	\N
307763	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Handicap dans la fonction publique	MI Handicap dans la fonction publique	2018-10-02 14:00:00	2018-10-02 16:30:00	\N	\N	2	0	\N	\N
309210	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Sports - Direction des sports du Ministère des sports et CNOSF	PLF pour 2019 - Sports - Direction des sports du Ministère des sports et CNOSF	2018-10-03 14:30:00	2018-10-03 16:30:00	\N	\N	1	0	\N	\N
309212	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - PIA - ADEME et Caisse des dépôts	PLF pour 2019 - PIA - ADEME et Caisse des dépôts	2018-10-05 10:00:00	2018-10-05 12:00:00	\N	\N	1	0	\N	\N
309228	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Justice - Les amendes pénales - DRFIP Ile de France	Contrôle 2018 - Justice - Les amendes pénales - DRFIP Ile de France	2018-10-04 10:30:00	2018-10-04 11:40:00	\N	\N	1	0	\N	\N
335698	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-12-06 14:30:00	2018-12-06 16:00:00	\N	\N	1	0	\N	\N
217574	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2017-11-15 09:30:00	2017-11-15 11:45:00	2017-11-15 11:53:15	2017-11-15 15:05:46	50	0	\N	\N
309230	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Justice - DPJJ et DAP	PLF pour 2019 - Justice - DPJJ et DAP	2018-10-04 14:40:00	2018-10-04 16:55:00	\N	\N	1	0	\N	\N
309232	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Les amendes pénales - DGFiP	Contrôle 2018 - Les amendes pénales - DGFiP	2018-10-04 17:00:00	2018-10-04 18:15:00	\N	\N	1	0	\N	\N
309235	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2019 - Sécurités - Déplacement DCI Nanterre	PLF pour 2019 - Sécurités - Déplacement DCI Nanterre	2018-10-04 14:00:00	2018-10-04 18:00:00	\N	\N	1	0	\N	\N
309252	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Jeunesse et vie associative	PLF 2019 - Crédits Jeunesse et vie associative	2018-10-02 16:00:00	2018-10-02 16:45:00	\N	\N	1	0	\N	\N
309253	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Jeunesse et vie associative	PLF 2019 - Crédits Jeunesse et vie associative	2018-10-02 18:00:00	2018-10-02 18:30:00	\N	\N	2	0	\N	\N
309254	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2019 - BA Contrôle et exploitation aériens - Déplacement Saint-Mandé Météo France	PLF pour 2019 - BA Contrôle et exploitation aériens - Déplacement Saint-Mandé Météo France	2018-10-04 09:00:00	2018-10-04 13:00:00	\N	\N	1	0	\N	\N
309255	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Jeunesse et vie associative	PLF 2019 - Crédits Jeunesse et vie associative	2018-10-02 14:45:00	2018-10-02 15:30:00	\N	\N	1	0	\N	\N
309261	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Action extérieure de l'Etat	PLF 2019 - Crédits Action extérieure de l'Etat	2018-10-03 14:00:00	2018-10-03 15:00:00	\N	\N	1	0	\N	\N
309262	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Action extérieure de l'Etat	PLF 2019 - Crédits Action extérieure de l'Etat	2018-10-03 15:00:00	2018-10-03 16:00:00	\N	\N	1	0	\N	\N
310845	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Prévenir et sanctionner les violences lors des manifestations	\N	2018-10-10 15:10:00	2018-10-10 15:40:00	\N	\N	1	0	\N	\N
316457	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLF pour 2019 - Mission Sécurités	PJLF pour 2019 - Mission Sécurités	2018-10-24 14:00:00	2018-10-24 16:40:00	\N	\N	1	0	\N	\N
316528	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition PME et Numérique	Audition PME et Numérique - DGE	2018-10-23 09:30:00	2018-10-23 10:30:00	\N	\N	1	0	\N	\N
316530	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	PME	Audition PME et Numérique - MEDEF	2018-10-24 16:00:00	2018-10-24 17:00:00	\N	\N	1	0	\N	\N
316797	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière	Réunion plénière	2018-10-25 09:00:00	2018-10-25 10:30:00	2018-10-25 15:23:11	2018-10-25 18:03:11	18	0	\N	\N
317204	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - MIRES Recherche - CEA / INRA	PLF pour 2019 - MIRES Recherche - CEA / INRA	2018-10-23 16:30:00	2018-10-23 18:30:00	\N	\N	1	0	\N	\N
317223	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	plfss pour 2019 - médico-social. Auditions M. Bonne	\N	2018-10-25 09:15:00	2018-10-25 10:00:00	\N	\N	2	0	\N	\N
317241	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	plfss pour 2019 - médico-social. Auditions M. Bonne	\N	2018-10-25 10:00:00	2018-10-25 10:45:00	\N	\N	3	0	\N	\N
279399	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPRE Déontologie et prévention des conflits d'intérêts des sénateurs	\N	2018-05-29 14:40:00	2018-05-29 15:00:00	\N	\N	1	0	\N	\N
281180	GIA	AUCUNE	\N	\N	\N	petit-déjeuner parution revue l'ena hors les murs sur la Russie	petit-déjeuner parution revue l'ena hors les murs sur la Russie	2018-06-06 08:15:00	2018-06-06 09:45:00	\N	\N	11	0	608	\N
286778	DELEGATION	AUCUNE	\N	\N	211	Audition de Mme Marie-Pierre Rixain, présidente, et de M. Erwan Balanant	Audition de Mme Marie-Pierre Rixain, présidente, et de M. Erwan Balanant	2018-06-19 18:00:00	2018-06-19 19:30:00	2018-06-20 11:41:10	2018-06-20 16:00:36	7	0	\N	\N
287695	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Avis PJL ELAN	\N	2018-06-14 14:30:00	2018-06-14 17:30:00	\N	\N	1	0	\N	\N
293263	COM_ENQUETE	PLENIERE	\N	HAUTE	\N	Réunion du 26 juillet 2018	Réunion du 26 juillet 2018	2018-06-26 18:05:00	2018-06-26 18:55:00	2018-06-29 19:38:40	2018-06-29 21:13:48	8	0	\N	\N
295234	GIA	AUCUNE	\N	\N	\N	déjeuner au Sénat avec Mme Aglaia Balta, ambassadrice de Grèce	déjeuner au Sénat avec Mme Aglaia Balta, ambassadrice de Grèce	2018-07-05 12:45:00	2018-07-05 14:00:00	\N	\N	6	0	591	\N
299371	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2018-04-19 11:55:00	2018-04-19 12:05:00	\N	\N	3	0	\N	\N
338563	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-12-18 10:00:00	2018-12-18 11:00:00	\N	\N	2	0	\N	\N
338567	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-12-18 10:30:00	2018-12-18 11:00:00	\N	\N	1	0	\N	\N
338769	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 18 décembre 2019	Réunion du 18 décembre 2019	2018-12-18 15:35:00	2018-12-18 15:55:00	2018-12-18 16:30:59	2018-12-18 17:59:33	12	0	\N	\N
344794	DELEGATION	AUCUNE	\N	\N	211	Audition de représentants de l'association Droit Pluriel	Audition de représentants de l'association Droit Pluriel	2019-03-14 08:30:00	2019-03-14 10:05:00	\N	\N	9	0	\N	\N
344805	DELEGATION	AUCUNE	\N	\N	211	Audition de Mme Audrey Keysers	Audition de Mme Audrey Keysers	2019-02-05 18:00:00	2019-02-05 19:00:00	2019-02-05 19:26:54	2019-02-06 17:37:45	6	0	\N	\N
344806	DELEGATION	AUCUNE	\N	\N	211	Echanges de vue - PPR et PPL	Echanges de vue - PPR et PPL	2019-02-07 08:30:00	2019-02-07 10:00:00	2019-02-07 10:52:42	2019-02-07 17:22:49	12	0	\N	\N
344811	DELEGATION	AUCUNE	\N	\N	211	Audition de Mme Marie Rabatel et du Docteur Salmona	Audition de Mme Marie Rabatel et du Docteur Salmona	2019-02-14 09:00:00	2019-02-14 11:00:00	2019-02-14 11:45:55	2019-02-14 16:06:30	11	0	\N	\N
344820	DELEGATION	AUCUNE	\N	\N	211	Réunion plénière	Audition de Mme Catherine Troendlé - Échange de vues sur la célébration du vingtième anniversaire de la délégation	2019-03-07 08:30:00	2019-03-07 10:35:00	\N	\N	15	0	\N	\N
344821	DELEGATION	AUCUNE	\N	\N	211	Audition de Mme Frédérique Jossinet (FFF) - Echange de vues sur l'évènement du 10 10 2019	Audition de Mme Frédérique Jossinet (FFF) - Echange de vues sur l'évènement du 10 10 2019	2019-03-21 09:00:00	2019-03-21 10:45:00	\N	\N	11	0	\N	\N
344822	DELEGATION	AUCUNE	\N	\N	211	Audition de Mme Marianne Gazeau	\N	2019-04-11 08:30:00	2019-04-11 10:00:00	\N	\N	7	0	\N	\N
344823	MISSION	AUCUNE	\N	INFRACTIONS	\N	Audition d'associations de victimes	Audition d'associations de victimes	2019-01-23 16:35:00	2019-01-23 18:45:00	2019-01-23 20:03:58	2019-01-24 10:01:16	9	0	\N	\N
344975	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition plénière - Plan national de mobilisation contre les addictions	\N	2019-01-30 10:00:00	2019-01-30 12:05:00	2019-01-30 12:07:12	2019-01-30 14:49:52	38	0	\N	\N
344980	MISSION	AUCUNE	\N	INFRACTIONS	\N	Fédération des autonomes de solidarité laïques association « C¿est-à-dire »	Fédération des autonomes de solidarité laïques association « C¿est-à-dire »	2019-01-24 11:00:00	2019-01-24 13:00:00	2019-01-24 12:58:23	2019-01-24 18:28:53	7	0	\N	\N
299357	COM_PERMANENTE	AUTRE	\N	CAE	\N	Examen des motions et amendements de séance	\N	2018-07-18 09:00:00	2018-07-18 12:00:00	2018-07-19 15:43:28	2018-07-19 15:58:11	37	1	\N	\N
345424	COM_SPECIALE	PLENIERE	\N	ENTREPRISES	\N	Réunion 20190129	\N	2019-01-29 13:15:00	2019-01-29 13:55:00	2019-01-29 14:59:30	2019-01-29 16:52:20	27	0	\N	\N
345540	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	Audition M. Philippe Bas	\N	2019-01-30 12:00:00	2019-01-30 13:00:00	\N	\N	0	0	\N	\N
345541	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	\N	\N	2019-01-30 12:00:00	2019-01-30 13:00:00	\N	\N	0	0	\N	\N
345559	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	\N	\N	2019-01-30 17:00:00	2019-01-30 17:45:00	\N	\N	0	0	\N	\N
345617	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Nomination Article 13	\N	2019-01-29 16:04:00	2019-01-29 17:15:00	2019-01-29 18:02:02	2019-01-30 14:49:55	22	0	\N	\N
345626	MISSION	AUDRAP	\N	INFRACTIONS	\N	ONPE	Audition ONPE	2019-02-07 09:45:00	2019-02-07 11:00:00	\N	\N	4	0	\N	\N
345631	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion du 29 janvier vote	\N	2019-01-29 17:25:00	2019-01-29 17:35:00	2019-01-31 10:11:12	2019-01-31 18:32:26	22	0	\N	\N
346331	DELEGATION	AUCUNE	\N	\N	DSOM	Visioconférence avec La Réunion	Visioconférence avec La Réunion	2019-01-31 08:30:00	2019-01-31 09:40:00	2019-01-31 11:58:07	2019-01-31 18:30:30	7	0	\N	\N
346332	DELEGATION	AUCUNE	\N	\N	DSOM	Visioconférence avec la station Martinique La 1ère	Visioconférence avec la station Martinique La 1ère	2019-02-05 14:35:00	2019-02-05 16:05:00	2019-02-05 16:36:56	2019-02-05 16:44:23	8	0	\N	\N
346333	DELEGATION	AUCUNE	\N	\N	DSOM	Auditions - Production audiovisuelle et CNC	Auditions - Production audiovisuelle et CNC	2019-02-07 08:30:00	2019-02-07 10:25:00	2019-02-07 11:57:24	2019-02-07 17:22:49	8	0	\N	\N
346441	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition table ronde	\N	2019-01-30 14:30:00	2019-01-30 17:30:00	2019-01-31 09:16:59	2019-01-31 18:30:00	17	0	\N	\N
346586	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de Mme Nicole Belloubet	\N	2019-01-30 18:00:00	2019-01-30 19:50:00	2019-01-31 09:18:34	2019-01-31 18:30:00	20	0	\N	\N
346589	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Prise en charge des cancers pédiatriques	\N	2019-01-31 16:00:00	2019-01-31 17:00:00	\N	\N	2	0	\N	\N
346613	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-02-06 09:35:00	2019-02-06 11:05:00	2019-02-06 15:01:11	2019-02-06 17:44:16	41	0	\N	\N
348099	COM_SPECIALE	PLENIERE	\N	ENTREPRISES	\N	Réunion 20190205	\N	2019-02-05 14:15:00	2019-02-05 14:30:00	2019-02-05 17:13:57	2019-02-05 17:54:51	21	0	\N	\N
348100	DELEGATION	AUDRAP	\N	\N	PROS	Audition de Bertrand Badie	\N	2019-02-06 15:00:00	2019-02-06 16:20:00	\N	\N	1	0	\N	\N
348101	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	MI Handicap dans la fonction publique déplacement à Rouen	\N	2019-02-01 09:30:00	2019-02-01 18:30:00	\N	\N	1	0	\N	\N
350997	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Christian MASSET, Ambassadeur de France en Italie	Entretien avec M. Christian MASSET, Ambassadeur de France en Italie	2019-02-11 17:00:00	2019-02-11 18:00:00	\N	\N	5	0	621	\N
352231	GIA	AUCUNE	\N	\N	\N	Petit-déjeuner en présence ambassadrice Canada	Petit-déjeuner au Sénat  en présence de l'ambassadrice du Canada, Isabelle Hudon	2019-02-13 08:30:00	2019-02-13 09:30:00	\N	\N	16	0	583	\N
352542	GIA	AUCUNE	\N	\N	\N	Diner du bureau du groupe	Diner du bureau du groupe	2019-02-13 20:00:00	2019-02-13 22:00:00	\N	\N	6	0	598	\N
353833	MISSION	AUCUNE	\N	INFRACTIONS	\N	Audition Ministère des sports	\N	2019-02-19 13:45:00	2019-02-19 15:00:00	2019-02-19 15:11:47	2019-02-19 17:58:33	10	0	\N	\N
353834	MISSION	AUCUNE	\N	INFRACTIONS	\N	Audition PedoHelp	\N	2019-02-19 18:00:00	2019-02-19 18:45:00	2019-02-19 18:48:12	2019-02-20 15:04:05	5	0	\N	\N
353835	MISSION	AUCUNE	\N	INFRACTIONS	\N	Fédération nationale des transports de voyageurs - Direction de l'admin. pénitentiaire	\N	2019-02-20 16:35:00	2019-02-20 18:20:00	2019-02-20 18:35:14	2019-02-21 17:54:10	6	0	\N	\N
354847	COM_PERMANENTE	AUTRE	\N	LOIS	\N	MI Participation opérations maintien de contrôle	\N	2019-02-20 08:10:00	2019-02-20 11:00:00	2019-02-21 18:00:25	2019-02-21 18:14:51	39	0	\N	\N
354848	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion commission	\N	2019-02-20 15:30:00	2019-02-20 18:45:00	2019-02-21 08:50:46	2019-02-21 17:56:28	22	1	\N	\N
355281	MISSION	AUTRE	\N	SIDERURGIE	\N	Audition plénière - MI Sidérurgie	\N	2019-02-19 17:50:00	2019-02-19 19:10:00	2019-02-20 15:26:25	2019-02-20 15:40:43	11	0	\N	\N
355368	MISSION	AUCUNE	\N	CLIMATIQUE	\N	Auditions UNALCI-France-Inondations Météo-France et DGPR	\N	2019-02-20 16:32:00	2019-02-20 19:27:00	2019-02-20 20:42:03	2019-02-21 17:54:10	13	0	\N	\N
355557	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 20 février 2019	\N	2019-02-20 15:30:00	2019-02-20 17:10:00	2019-02-20 17:46:04	2019-02-20 17:59:50	23	0	\N	\N
355582	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	audition de M. Bonne Mme Meunier	\N	2019-03-12 13:00:00	2019-03-12 16:00:00	\N	\N	0	0	\N	\N
355589	AUTRE_TEMPORAIRE	DEPLACEMENT	\N	\N	\N	dépendance des personnes âgées	\N	2019-03-13 08:00:00	2019-03-14 22:00:00	\N	\N	0	0	\N	\N
355590	AUTRE_TEMPORAIRE	DEPLACEMENT	\N	\N	\N	déplacement rapporteurs 	\N	2019-03-06 08:00:00	2019-03-07 22:00:00	\N	\N	0	0	\N	\N
355640	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Bioéthique	\N	2019-03-06 14:30:00	2019-03-06 15:15:00	\N	\N	7	0	\N	\N
222513	DELEGATION	AUCUNE	\N	\N	211	Audition de Mme Laurence Rossignol	Audition de Mme Laurence Rossignol	2017-11-23 08:45:00	2017-11-23 10:30:00	2017-11-23 16:33:42	2017-11-23 16:59:45	19	0	\N	\N
228392	DELEGATION	AUCUNE	\N	\N	206	Audition sur "Les enjeux des compteurs communicants"	Audition, ouverte à la presse, conjointe avec la com. des Aff. éco. de l'A.N. sur les enjeux des compteurs communicants	2017-12-14 09:30:00	2017-12-14 13:30:00	2017-12-14 15:43:19	2017-12-14 16:23:12	13	0	\N	\N
228399	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	GT infractions sexuelles	GT infractions sexuelles	2017-12-07 11:00:00	2017-12-07 21:00:00	\N	\N	1	0	\N	\N
239197	GIA	AUCUNE	\N	\N	\N	AG du groupe France-Pays Andins	Assemblée générale du groupe	2018-01-30 15:00:00	2018-01-30 15:20:00	\N	\N	9	0	979	\N
239208	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2018-01-30 14:30:00	2018-01-30 16:45:00	\N	\N	3	0	\N	\N
244032	MECSS	AUDRAP	\N	\N	MECSS	\N	\N	2018-02-15 09:30:00	2018-02-15 12:00:00	\N	\N	5	0	\N	\N
247239	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 Indemnisation des victimes du terrorisme	58-2 Indemnisation des victimes du terrorisme - Audition Cour des comptes	2018-02-15 18:00:00	2018-02-15 18:45:00	\N	\N	1	0	\N	\N
251151	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	GT Statut de l'élu local : Table ronde "Le régime indemnitaire"	\N	2018-03-14 15:00:00	2018-03-14 17:00:00	\N	\N	9	0	\N	\N
259733	COM_EURO	AUTRE_NON_PLENIERE	\N	AFEU	\N	Entretien du bureau avec M. Petr Drulak, ambassadeur de la République tchèque en France	Entretien du bureau avec M. Petr Drulak, ambassadeur de la République tchèque en France	2018-03-27 15:10:00	2018-03-27 16:10:00	\N	\N	3	0	\N	\N
259746	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GS Brexit - Audition de M. Mike CHERRY, président de la fédération britannique des PME	GS Brexit - Audition de M. Mike CHERRY, président de la fédération britannique des PME	2018-03-27 12:30:00	2018-03-27 14:20:00	\N	\N	2	0	\N	\N
315998	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLF pour 2019 - Mission Outre-mer	\N	2018-10-22 17:00:00	2018-10-22 18:40:00	\N	\N	1	0	\N	\N
266861	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Martin Pigeon, membre de l'organisation CEO	Audition de M. Martin Pigeon, membre de l'organisation Corporate Europe Observatory (CEO)	2018-05-23 16:15:00	2018-05-23 17:15:00	\N	\N	3	0	\N	\N
266863	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Eric THYBAUD, docteur en écotoxicologie	Audition de M. Eric THYBAUD, docteur en écotoxicologie, responsable du pôle "dangers et impact sur le vivant" à l'INERIS	2018-05-23 17:15:00	2018-05-23 18:15:00	\N	\N	3	0	\N	\N
270395	COM_PERMANENTE	AUTRE	\N	CDD	\N	\N	\N	2018-05-16 09:20:00	2018-05-16 09:45:00	2018-05-16 14:41:01	2018-05-16 14:57:19	39	1	\N	\N
270652	COM_ENQUETE	PLENIERE	\N	FORCES	\N	Auditions CE FSI	Auditions CE FSI	2018-05-15 14:05:00	2018-05-15 16:15:00	2018-05-15 16:56:17	2018-05-15 18:19:22	9	0	\N	\N
273289	MISSION	DEPLACEMENT	\N	MINEURSENF	\N	Déplacement à la maison d'arrêt de Villepinte (93) 	Déplacement à la maison d'arrêt de Villepinte (93) 	2018-05-09 13:30:00	2018-05-09 18:00:00	\N	\N	5	0	\N	\N
278421	COM_EURO	AUTRE_NON_PLENIERE	\N	AFEU	\N	Entretien Parlement letton	Entretien du bureau avec Mme Lolita Cigane	2018-05-30 14:35:00	2018-05-30 15:25:00	\N	\N	3	0	\N	\N
287933	DELEGATION	AUCUNE	\N	\N	COLTER	Audition - M. Weiten, vice-président de l'Assemblée des départements de France	\N	2018-06-28 09:30:00	2018-06-28 10:50:00	2018-06-28 11:23:08	2018-06-28 11:24:25	11	0	\N	\N
298186	DELEGATION	AUDRAP	\N	\N	206	Audition "Stockage de l'électricité" de l'Académie des technologies	Audition "Stockage de l'électricité" de M. Yves Bamberger, président du comité des travaux - Académie des technologies	2018-07-18 10:30:00	2018-07-18 11:30:00	\N	\N	1	0	\N	\N
304227	MISSION	AUDRAP	\N	HERBE	\N	\N	\N	2018-07-26 15:00:00	2018-07-26 16:00:00	\N	\N	1	0	\N	\N
305036	MISSION	DEPLACEMENT	\N	HERBE	\N	Déplacement dans la Drôme	\N	2018-07-30 09:00:00	2018-07-30 19:00:00	\N	\N	6	0	\N	\N
305283	ETUDES	AUCUNE	\N	\N	\N	\N	Auditions	2018-09-13 14:30:00	2018-09-13 18:00:00	\N	\N	3	0	\N	1004
308816	ETUDES	AUCUNE	\N	\N	\N	Réunion du Bureau du Groupe d'études	Réunion du Bureau du Groupe d'études	2018-10-03 14:00:00	2018-10-03 14:30:00	\N	\N	6	0	\N	934
309380	COM_PERMANENTE	DEPLACEMENT	\N	CDD	\N	Déplacement CEA de Marcoule (Gard)	\N	2018-10-08 06:40:00	2018-10-08 20:25:00	\N	\N	6	0	\N	\N
309387	COM_PERMANENTE	DEPLACEMENT	\N	CDD	\N	Centre de de l¿ANDRA (projet Cigéo et écothèque) - BURE	\N	2018-09-21 07:00:00	2018-09-21 19:48:00	\N	\N	3	0	\N	\N
309391	COM_PERMANENTE	DEPLACEMENT	\N	CAE	\N	Déplacement au Mondial de l'Automobile	\N	2018-10-04 09:30:00	2018-10-04 13:00:00	\N	\N	6	0	\N	\N
309514	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Auditions M. Gilles (PLF pour 2019 (anciens combattants)	\N	2018-10-11 11:00:00	2018-10-11 12:00:00	\N	\N	3	0	\N	\N
309517	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Auditions M. Gilles (PLF pour 2019 Anciens combattants	\N	2018-10-16 14:00:00	2018-10-16 16:00:00	\N	\N	1	0	\N	\N
309521	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	auditions M. Gilles (PLF pour 2019 - Anciens combattants)	\N	2018-11-07 16:30:00	2018-11-07 19:00:00	\N	\N	3	0	\N	\N
309620	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	auditions de M. Gilles (PLF pour 2019 - Anciens combattants)	\N	2018-11-15 09:00:00	2018-11-15 09:45:00	\N	\N	1	0	\N	\N
309702	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2018-10-10 09:30:00	2018-10-10 11:15:00	2018-10-10 11:46:00	2018-10-10 11:48:28	34	0	\N	\N
311709	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Patrice Simon, professeur (Arrêt des véhicules thermiques)	Audition de M. Patrice Simon, professeur  (Arrêt des véhicules thermiques)	2018-10-10 15:30:00	2018-10-10 16:30:00	\N	\N	2	0	\N	\N
311712	DELEGATION	AUDRAP	\N	\N	206	Audition de Motor Development International (Arrêt des véhicules thermiques)	Audition de M. A. Bossard, responsable communication - Motor Development International (Arrêt des véhicules thermiques)	2018-10-11 09:00:00	2018-10-11 10:00:00	\N	\N	2	0	\N	\N
311715	DELEGATION	AUDRAP	\N	\N	206	Audition du Conseil national des professions de l'automobile (Arrêt véhicules thermiques)	Audition du Conseil national des professions de l'automobile (Arrêt des véhicules thermiques)	2018-10-11 10:00:00	2018-10-11 11:00:00	\N	\N	2	0	\N	\N
311718	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Rémi Bastien, président MOVEO/VEDECOM (Arrêt des véhicules thermiques)	Audition de M. Rémi Bastien, président de MOVEO/VEDECOM (Arrêt des véhicules thermiques)	2018-10-11 11:00:00	2018-10-11 12:00:00	\N	\N	2	0	\N	\N
311779	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF 2019 - Programme 178	\N	2018-10-09 15:00:00	2018-10-09 16:00:00	\N	\N	2	0	\N	\N
311782	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF 2019 - Programme 178	\N	2018-10-10 14:30:00	2018-10-10 15:30:00	\N	\N	2	0	\N	\N
311785	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	¨PLF 2019 - Programme 105	\N	2018-10-09 09:00:00	2018-10-09 10:15:00	\N	\N	1	0	\N	\N
311787	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2019 - Programme 105	\N	2018-10-11 16:30:00	2018-10-11 18:00:00	\N	\N	1	0	\N	\N
313876	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 18 octobre 2018	Réunion du 18 octobre 2018	2018-10-18 08:35:00	2018-10-18 10:20:00	2018-10-18 12:22:00	2018-10-18 18:39:19	16	0	\N	\N
314088	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Défense - EMM	PLF pour 2019 - Défense - EMM	2018-10-16 10:00:00	2018-10-16 11:00:00	\N	\N	1	0	\N	\N
314092	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Travail et Emploi - AMF	PLF pour 2019 - Travail et Emploi - AMF	2018-10-16 14:15:00	2018-10-16 15:15:00	\N	\N	2	0	\N	\N
314098	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Défense - Direction du budget, EMM	PLF pour 2019 - Défense - Direction du budget, EMM	2018-10-17 15:30:00	2018-10-17 18:00:00	\N	\N	1	0	\N	\N
314106	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2019 (Mildeca)	\N	2018-10-19 09:30:00	2018-10-19 12:30:00	\N	\N	1	0	\N	\N
314109	COM_PERMANENTE	AUDRAP	\N	FINC	\N	\N	PLF pour 2019 - Travail et emploi - UNML	2018-10-18 09:00:00	2018-10-18 10:00:00	\N	\N	1	0	\N	\N
314112	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Défense - EMAA / SGA	PLF pour 2019 - Défense - EMAA / SGA	2018-10-18 10:30:00	2018-10-18 12:30:00	\N	\N	1	0	\N	\N
297289	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Ali Ismael Hassan, représentant en France du Somaliland 	Entretien avec le représentant en france du Somaliland	2018-07-11 08:30:00	2018-07-11 09:30:00	\N	\N	1	0	588	\N
297338	MISSION	AUCUNE	\N	HERBE	\N	Audition plénière	\N	2018-07-10 18:00:00	2018-07-10 19:35:00	2018-07-11 18:30:50	2018-07-12 15:58:07	11	0	\N	\N
297353	MISSION	AUCUNE	\N	HERBE	\N	Audition plénière	\N	2018-07-11 14:00:00	2018-07-11 17:15:00	2018-07-11 18:33:46	2018-07-12 15:58:05	10	0	\N	\N
315995	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLF pour 2019 - Mission Outre-mer	\N	2018-10-19 14:30:00	2018-10-19 17:55:00	\N	\N	1	0	\N	\N
308538	CMP	AUTRE	\N	ELAN	\N	PJL Évolution du logement, de l'aménagement et du numérique	PJL Évolution du logement, de l'aménagement et du numérique	2018-09-12 14:37:00	2018-09-12 21:06:00	\N	\N	13	0	\N	\N
316000	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLF pour 2019 - Mission Outre-mer	\N	2018-10-23 08:15:00	2018-10-23 08:50:00	\N	\N	1	0	\N	\N
316215	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2018-10-24 16:40:00	2018-10-24 18:35:00	2018-10-25 10:43:43	2018-10-25 18:04:35	34	0	\N	\N
316342	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 24 octobre 2018	Réunion de la commission des affaires européennes du 24 octobre 2018	2018-10-24 17:05:00	2018-10-24 18:10:00	2018-10-25 11:21:31	2018-10-25 18:06:03	20	0	\N	\N
316364	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 25 octobre 2018	Réunion de la commission des affaires européennes du 25 octobre 2018	2018-10-25 09:15:00	2018-10-25 10:40:00	2018-10-25 11:22:03	2018-10-25 18:06:04	18	0	\N	\N
316864	ETUDES	AUCUNE	\N	\N	\N	G.E. "Cultures traditionnelles et spécialisées"	G.E. "Cultures traditionnelles et spécialisées"	2018-10-24 08:00:00	2018-10-24 09:00:00	\N	\N	17	0	\N	1005
316888	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Pastoralisme	GT Pastoralisme	2018-10-16 18:00:00	2018-10-16 19:30:00	\N	\N	9	0	\N	\N
316914	ETUDES	AUCUNE	\N	\N	\N	G.E. "Elevage"	G.E. "Elevage"	2018-10-09 18:00:00	2018-10-09 19:30:00	\N	\N	10	0	\N	911
317252	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2019 - Programme 844	\N	2018-10-24 14:00:00	2018-10-24 15:10:00	\N	\N	2	0	\N	\N
317256	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2019 - Programme 844	\N	2018-10-24 16:10:00	2018-10-24 17:30:00	\N	\N	2	0	\N	\N
317259	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Entretien délégation libyenne	\N	2018-10-24 15:00:00	2018-10-24 16:15:00	\N	\N	4	0	\N	\N
317268	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	PLF pour 2019 - Programme 129	\N	2018-10-26 09:00:00	2018-10-26 18:00:00	\N	\N	1	0	\N	\N
317289	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF 2019 - Programme 178	\N	2018-10-23 16:15:00	2018-10-23 17:15:00	\N	\N	2	0	\N	\N
317292	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF 2019 - Programme 178	\N	2018-10-24 15:00:00	2018-10-24 16:00:00	\N	\N	1	0	\N	\N
317340	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Solidarité - Associations Aide alimentaire	PLF pour 2019 - Solidarité - Associations Aide alimentaire	2018-10-25 10:30:00	2018-10-25 11:30:00	\N	\N	1	0	\N	\N
317443	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2019 - Programme 185	\N	2018-10-24 15:30:00	2018-10-24 16:30:00	\N	\N	2	0	\N	\N
317446	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2019 - Programme 185	\N	2018-10-25 14:00:00	2018-10-25 15:00:00	\N	\N	1	0	\N	\N
317448	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2019 - programme 212	\N	2018-10-24 17:15:00	2018-10-24 18:15:00	\N	\N	2	0	\N	\N
317507	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions pour 2019 - Avis Fonction publique	\N	2018-10-24 11:30:00	2018-10-24 12:30:00	\N	\N	1	0	\N	\N
317509	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2019 - Avis Fonction publique	\N	2018-10-24 17:30:00	2018-10-24 18:30:00	\N	\N	1	0	\N	\N
317511	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	PLF pour 2019 - Avis Fonction publique	\N	2018-10-25 07:20:00	2018-10-26 12:13:00	\N	\N	1	0	\N	\N
317664	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF pour 2019 - mission "Agriculture, alimentation, forêt et affaires rurales"	PJLF pour 2019 - mission "Agriculture, alimentation, forêt et affaires rurales"	2018-10-25 09:00:00	2018-10-25 12:00:00	\N	\N	3	0	\N	\N
317677	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF pour 2019 - mission " agriculture, alimentation, forêt et affaires rurales"	PJLF pour 2019 - mission "agriculture, alimentation, forêt et affaires rurales"	2018-10-25 14:00:00	2018-10-25 15:00:00	\N	\N	3	0	\N	\N
317756	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF pour 2019 - mission "Agriculture, alimentation, forêt et affaires rurales"	PJLF pour 2019 - mission "Agriculture, alimentation, forêt et affaires rurales"	2018-10-24 14:30:00	2018-10-24 15:30:00	\N	\N	1	0	\N	\N
317758	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJLF pour 2019 - Avis "biodiversité et transition énergétique"	PJLF pour 2019 - Avis "biodiversité et transition énergétique"	2018-10-23 11:00:00	2018-10-23 13:00:00	\N	\N	1	0	\N	\N
317759	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJLF pour 2019 - Avis "biodiversité et transition énergétique"	PJLF pour 2019 - Avis "biodiversité et transition énergétique"	2018-10-24 14:00:00	2018-10-24 16:30:00	\N	\N	1	0	\N	\N
317760	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJLF pour 2019 - Avis "biodiversité et transition énergétique"	PJLF pour 2019 - Avis "biodiversité et transition énergétique"	2018-10-25 10:00:00	2018-10-25 11:00:00	\N	\N	1	0	\N	\N
319209	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Écologie/Énergie -AFB et SG Ministère transition écologique	PLF pour 2019 - Écologie/Énergie -AFB et SG Ministère transition écologique	2018-10-30 09:00:00	2018-10-30 11:00:00	\N	\N	1	0	\N	\N
319211	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Cohésion des territoires (aménagement du territoire) -AdCF et SG Min Int. 	PLF pour 2019 - Cohésion des territoires (aménagement du territoire) -AdCF et SG Min Int. 	2018-10-31 14:45:00	2018-10-31 16:00:00	\N	\N	1	0	\N	\N
319213	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLFSS pour 2019 - Avis  / PLF pour 2019 - Examen Rapports Santé-Sécurités-Économie	PLFSS pour 2019 - Avis  / PLF pour 2019 - Examen Rapports Santé-Sécurités-Économie	2018-11-06 14:35:00	2018-11-06 18:00:00	2018-11-06 18:52:01	2018-11-07 10:34:08	41	0	\N	\N
319214	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Culture (Création, Transmission, Démocratisation)	PLF 2019 - Crédits Culture (Création, Transmission, Démocratisation)	2018-10-29 14:30:00	2018-10-29 15:40:00	\N	\N	2	0	\N	\N
319217	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Culture (Création, Transmission, Démocratisation)	PLF 2019 - Crédits Culture (Création, Transmission, Démocratisation)	2018-10-29 15:40:00	2018-10-29 16:50:00	\N	\N	2	0	\N	\N
319220	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Culture (Création, Transmission, Démocratisation)	PLF 2019 - Crédits Culture (Création, Transmission, Démocratisation)	2018-10-30 14:30:00	2018-10-30 15:40:00	\N	\N	2	0	\N	\N
319224	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Culture (Patrimoine)	PLF 2019 - Crédits Culture (Patrimoine)	2018-10-30 15:30:00	2018-10-30 16:45:00	\N	\N	4	0	\N	\N
319235	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 -Crédits Recherche	PLF 2019 -Crédits Recherche	2018-10-30 09:30:00	2018-10-30 11:00:00	\N	\N	2	0	\N	\N
319238	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 -Crédits Recherche	PLF 2019 -Crédits Recherche	2018-10-30 15:00:00	2018-10-30 16:00:00	\N	\N	1	0	\N	\N
319240	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 -Crédits Recherche	PLF 2019 -Crédits Recherche	2018-10-30 16:00:00	2018-10-30 16:45:00	\N	\N	1	0	\N	\N
319242	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 -Crédits Recherche	PLF 2019 -Crédits Recherche	2018-10-30 17:45:00	2018-10-30 18:30:00	\N	\N	2	0	\N	\N
319245	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 -Crédits Recherche	PLF 2019 -Crédits Recherche	2018-10-31 15:00:00	2018-10-31 17:30:00	\N	\N	1	0	\N	\N
319247	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Plf 2019 - Crédits de l'audiovisuel public	Plf 2019 - Crédits de l'audiovisuel public	2018-10-31 15:00:00	2018-10-31 16:00:00	\N	\N	2	0	\N	\N
319250	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Plf 2019 - Crédits de l'audiovisuel public	Plf 2019 - Crédits de l'audiovisuel public	2018-10-31 16:00:00	2018-10-31 17:00:00	\N	\N	2	0	\N	\N
319254	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Enseignement supérieur	PLF 2019 - Crédits Enseignement supérieur	2018-10-31 14:00:00	2018-10-31 16:30:00	\N	\N	3	0	\N	\N
335700	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-12-06 16:00:00	2018-12-06 18:45:00	\N	\N	2	0	\N	\N
319276	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions avis budgétaires conseil et contrôle de l'Etat	Auditions avis budgétaires conseil et contrôle de l'Etat	2018-11-07 18:30:00	2018-11-07 19:00:00	\N	\N	1	0	\N	\N
319277	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	\N	2018-11-07 14:00:00	2018-11-07 15:00:00	\N	\N	0	0	\N	\N
220252	COM_PERMANENTE	DEPLACEMENT	\N	SOCI	\N	PLF pour 2018	Cohésion des territoires	2017-11-21 16:30:00	2017-11-21 19:30:00	\N	\N	1	0	\N	\N
220258	COM_PERMANENTE	DEPLACEMENT	\N	SOCI	\N	PLF pour 2018	Cohésion des territoires	2017-11-22 16:30:00	2017-11-22 19:30:00	\N	\N	1	0	\N	\N
232716	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	Négociations commerciales UE	Négociations commerciales de l'Union européenne	2017-12-20 15:00:00	2017-12-20 16:30:00	\N	\N	7	0	\N	\N
232724	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition cyle de vie des entreprises	Audition cyle de vie des entreprises - U2P	2017-12-20 18:30:00	2017-12-20 19:15:00	\N	\N	1	0	\N	\N
235564	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Expertise France	\N	2018-01-16 09:00:00	2018-01-16 10:00:00	\N	\N	2	0	\N	\N
235568	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Expertise France	\N	2018-01-16 14:45:00	2018-01-16 16:45:00	\N	\N	2	0	\N	\N
235589	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Expertise France	\N	2018-01-17 16:15:00	2018-01-17 17:30:00	\N	\N	2	0	\N	\N
247273	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Protection des données personnelles	\N	2018-02-15 16:00:00	2018-02-15 18:15:00	\N	\N	1	0	\N	\N
249860	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Réunion constitutive	\N	2018-02-21 17:00:00	2018-02-21 17:30:00	\N	\N	0	0	\N	\N
250112	GIA	AUCUNE	\N	\N	\N	Viste au Centre de recherches sur l'Océanie (CREDO) à Marseille	\N	2018-02-16 07:30:00	2018-02-16 18:30:00	\N	\N	5	0	651	\N
261392	GIA	AUCUNE	\N	\N	\N	Entretien de M. Charles GUENÉ avec Mme Anna KANOPATSKAYA, Député biélorusse (coop)	Entretien de M. Charles GUENÉ avec Mme Anna KANOPATSKAYA, Député biélorusse (coop)	2018-03-21 14:15:00	2018-03-21 15:00:00	\N	\N	1	0	852	\N
261394	GIA	AUCUNE	\N	\N	\N	Entretien de Mme C. PROCACCIA avec une délégation de parlementaires indonésiens (coop)	Entretien de Mme C. PROCACCIA avec une délégation de parlementaires indonésiens (coop)	2018-03-15 10:15:00	2018-03-16 10:45:00	\N	\N	1	0	653	\N
261408	GIA	AUCUNE	\N	\N	\N	Entretien de M. Bernard CAZEAU avec M. Shunas ABDULLA, du parti d'opposition GORRAN (coop)	Entretien de M. Bernard CAZEAU avec M. Shunas ABDULLA, du parti d'opposition GORRAN (coop)	2018-03-28 17:10:00	2018-03-28 18:10:00	\N	\N	1	0	615	\N
261413	GIA	AUCUNE	\N	\N	\N	Entretien de M. André GATTOLIN avec M. Jakob ELLEMANN-JENSSEN, député danois (coop)	Entretien de M. André GATTOLIN avec M. Jakob ELLEMANN-JENSSEN, député danois (coop)	2018-03-07 14:40:00	2018-03-07 15:30:00	\N	\N	1	0	625	\N
262945	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Auditions CEMM et SGA	Auditions CEMM et SGA sur la LPM	2018-04-11 10:00:00	2018-04-11 12:40:00	2018-04-12 09:31:42	2018-04-12 10:09:00	41	0	\N	\N
264160	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Présentation conclusions groupe de travail "Revitalisation centres-villes centres-bourgs"	Présentation conclusions groupe de travail "Revitalisation centres-villes centres-bourgs"	2018-04-12 12:15:00	2018-04-12 14:00:00	2018-04-12 15:22:01	2018-04-12 18:13:34	22	0	\N	\N
268010	COM_EURO	AUTRE_NON_PLENIERE	\N	AFEU	\N	Entretien avec Mme Teresa Castaldo, ambassadrice d'Italie en France	Entretien avec Mme Teresa Castaldo, ambassadrice d'Italie en France	2018-04-17 16:05:00	2018-04-17 17:05:00	\N	\N	2	0	\N	\N
271077	COM_ENQUETE	PLENIERE	\N	FORCES	\N	Auditions CE FSI	Auditions CE FSI	2018-05-16 14:20:00	2018-05-16 18:15:00	2018-05-16 18:28:46	2018-05-17 18:01:04	11	0	\N	\N
271233	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Mécénat	Mission Mécénat	2018-05-15 15:35:00	2018-05-15 16:40:00	\N	\N	10	0	\N	\N
285672	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Performance des établissements d'enseignement supérieur - CURIF	Contrôle 2018 - Performance des établissements d'enseignement supérieur - CURIF	2018-06-13 11:30:00	2018-06-13 12:45:00	\N	\N	1	0	\N	\N
285899	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Réseau enseignement français à l'étranger - Jacky Deromedi	Contrôle 2018 - Réseau enseignement français à l'étranger - Jacky Deromedi	2018-06-12 14:00:00	2018-06-12 14:45:00	\N	\N	2	0	\N	\N
285902	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Réseau enseignement français à l'étranger - Richard Yung	Contrôle 2018 - Réseau enseignement français à l'étranger - Richard Yung	2018-06-12 15:00:00	2018-06-12 15:45:00	\N	\N	2	0	\N	\N
285951	DELEGATION	AUTRE	\N	\N	ENTREPRISES	Réunion plénière	\N	2018-06-14 08:15:00	2018-06-14 09:55:00	2018-06-14 17:10:05	2018-06-15 10:41:04	15	0	\N	\N
285978	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Réseau enseignement français à l'étranger - Direction du budget	Contrôle 2018 - Réseau enseignement français à l'étranger - Direction du budget	2018-06-12 17:45:00	2018-06-12 19:00:00	\N	\N	2	0	\N	\N
285981	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF 2019 - Affaires européennes - Elève fonctionnaire ENA	PLF 2019 - Affaires européennes - Elève fonctionnaire ENA	2018-06-13 14:30:00	2018-06-13 15:15:00	\N	\N	1	0	\N	\N
285985	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Réseau de l'enseignement français à l'étranger - AEFE	Contrôle 2018 - Réseau de l'enseignement français à l'étranger - Direction financière AEFE	2018-06-14 10:00:00	2018-06-14 11:00:00	\N	\N	2	0	\N	\N
285992	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de Mme Muriel PÉNICAUD, Ministre du travail exécution crédits Travail et emploi	Audition de Mme Muriel PÉNICAUD, Ministre du travail sur l'exécution des crédits de la mission Travail et emploi	2018-06-19 09:00:00	2018-06-19 10:35:00	2018-06-19 17:29:02	2018-06-19 17:53:28	21	0	\N	\N
286036	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions rapporteur thanatopraxie	\N	2018-06-14 09:00:00	2018-06-14 11:15:00	\N	\N	1	0	\N	\N
289323	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Réseau enseignement français à l'étranger - Hélène Conway-Mouret	Contrôle 2018 - Réseau enseignement français à l'étranger - Hélène Conway-Mouret	2018-06-18 13:30:00	2018-06-18 14:30:00	\N	\N	1	0	\N	\N
289325	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF 2019 - Mission "Sécurités" - SC Val d'Oise	PLF 2019 - Mission "Sécurités" - SC Val d'Oise	2018-06-21 10:00:00	2018-06-21 12:25:00	\N	\N	1	0	\N	\N
293125	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Equilibre relations commerciales secteur agricole	PJL Equilibre relations commerciales secteur agricole	2018-07-02 14:30:00	2018-07-02 20:00:00	\N	\N	63	0	\N	\N
293126	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Equilibre relations commerciales secteur agricole	PJL Equilibre relations commerciales secteur agricole	2018-07-02 21:30:00	2018-07-03 00:35:00	\N	\N	55	0	\N	\N
293134	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	\N	2018-06-28 16:00:00	2018-06-28 17:00:00	\N	\N	1	0	\N	\N
299052	GIA	AUCUNE	\N	\N	\N	Petit-déjeuner de fin de session parlementaire du GA Palestine	\N	2018-07-05 08:30:00	2018-07-05 09:30:00	\N	\N	7	0	632	\N
223890	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2018 - Programme 844	\N	2017-11-21 17:00:00	2017-11-21 18:30:00	\N	\N	1	0	\N	\N
299062	COM_PERMANENTE	AUTRE	\N	CAE	\N	Examen des motions et amendements de séance	\N	2018-07-17 13:35:00	2018-07-17 14:20:00	2018-07-17 17:46:09	2018-07-18 09:31:55	26	1	\N	\N
302228	ETUDES	AUCUNE	\N	\N	\N	\N	\N	2018-07-11 13:30:00	2018-07-11 14:30:00	\N	\N	8	0	\N	1004
302240	MISSION	AUDRAP	\N	HERBE	\N	\N	\N	2018-07-19 14:00:00	2018-07-19 15:00:00	\N	\N	1	0	\N	\N
306947	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Auditions rapport santé au travail	\N	2018-10-03 09:25:00	2018-10-03 12:00:00	2018-10-03 11:55:39	2018-10-03 15:16:36	44	0	\N	\N
310314	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	Réforme du traité de l'Élysée	Audition de Mme Gaillard, maître de conférences - sciens-Po Paris	2018-10-09 17:00:00	2018-10-09 18:00:00	\N	\N	1	0	\N	\N
310315	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	Réforme du traité de l'Élysée	Audition de représentants de la chambre franco-allemande de commerce et d'industrie	2018-10-09 18:00:00	2018-10-09 19:30:00	\N	\N	1	0	\N	\N
310421	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2018-10-17 09:30:00	2018-10-17 12:45:00	2018-10-17 12:43:01	2018-10-17 15:34:20	41	1	\N	\N
310462	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Plénière	\N	2018-10-10 17:00:00	2018-10-10 20:00:00	2018-10-10 19:58:17	2018-10-11 16:06:21	41	0	\N	\N
313503	GIA	AUCUNE	\N	\N	\N	Entretien avec la chambre de commerce France-Turkménistan (CCFT)	Entretien avec MM. Gilles Rémy et Daniel Patat, Président et Secrétaire général de la CCFT	2018-10-17 13:45:00	2018-10-17 14:30:00	\N	\N	1	0	556	\N
313939	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2019 - programme 212	\N	2018-10-17 16:30:00	2018-10-17 18:00:00	\N	\N	1	0	\N	\N
276025	DELEGATION	AUCUNE	\N	\N	206	Rapport sur les États généraux de la bioéthique du CCNE et opinions du comité citoyen	Présentation rapport États généraux bioéthique du CCNE par M. J.F. Delfraissy, président et opinions du comité citoyen	2018-06-07 10:00:00	2018-06-07 12:20:00	2018-06-07 15:56:34	2018-06-07 18:51:15	16	0	\N	\N
284818	DELEGATION	AUCUNE	\N	\N	PROS	Réunion plénière	Point d'étape sur le rapport « Les nouvelles mobilités » (Françoise Cartron, Alain Fouché, Olivier Jacquin, Didier Ram	2018-06-21 08:30:00	2018-06-21 09:45:00	2018-06-21 17:36:10	2018-06-22 15:10:03	10	0	\N	\N
288461	GIA	AUCUNE	\N	\N	\N	Visite du rucher du Jardin du Luxembourg	Visite du rucher du Jardin du Luxembourg	2018-06-20 15:00:00	2018-06-20 16:30:00	\N	\N	2	0	529	\N
288606	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 21 juin	Réunion du 21 juin	2018-06-21 09:00:00	2018-06-21 10:35:00	2018-06-21 17:04:04	2018-06-22 15:07:57	42	0	\N	\N
289755	COM_ENQUETE	AUDRAP	\N	FORCES	\N	\N	\N	2018-06-12 14:30:00	2018-06-12 15:30:00	\N	\N	2	0	\N	\N
289785	COM_ENQUETE	AUDRAP	\N	FORCES	\N	\N	\N	2018-06-14 11:30:00	2018-06-14 12:30:00	\N	\N	3	0	\N	\N
294871	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Lutte contre les violences sexuelles et sexistes	\N	2018-07-03 16:00:00	2018-07-03 17:30:00	\N	\N	1	0	\N	\N
294927	GIA	AUCUNE	\N	\N	\N	Entretien avec M. DANO, Président de la Chambre de commerce franco-finlandaise	Entretien avec M. DANO, Président de la Chambre de commerce franco-finlandaise	2018-07-05 08:30:00	2018-07-05 09:30:00	\N	\N	5	0	640	\N
331620	MISSION	AUCUNE	\N	INFRACTIONS	\N	Audition de M. Georges Picherot	Audition de M. Georges Picherot	2018-12-04 15:00:00	2018-12-04 16:10:00	2018-12-05 12:19:04	2018-12-05 16:45:33	12	0	\N	\N
331636	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2019 - Examen de deux amendements de séance à l'article d'équilibre	PLF pour 2019 - Examen de deux amendements de séance à l'article d'équilibre	2018-11-29 21:55:00	2018-11-29 22:10:00	2018-11-30 16:31:36	2018-11-30 17:00:27	18	0	\N	\N
333448	DELEGATION	AUDRAP	\N	\N	PROS	Audition de la CEREMA	\N	2018-12-19 15:45:00	2018-12-19 16:30:00	\N	\N	2	0	\N	\N
338217	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Praticiens hors UE	PPL Praticiens hors UE	2018-12-18 14:30:00	2018-12-18 16:45:00	\N	\N	77	0	\N	\N
338218	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Praticiens hors UE	PPL Praticiens hors UE	2018-12-18 17:45:00	2018-12-18 20:30:00	\N	\N	0	0	\N	\N
338219	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Praticiens hors UE	PPL Praticiens hors UE	2018-12-18 21:00:00	2018-12-19 00:00:00	\N	\N	0	0	\N	\N
338469	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Petites communes (nomination rapporteur) - PPL Indivision successorale OM (rapport)	PPL Petites communes (nomination rapporteur) - PPL Indivision successorale OM (rapport)	2018-12-18 09:05:00	2018-12-18 09:25:00	2018-12-18 09:48:04	2018-12-18 14:44:15	17	1	\N	\N
340313	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2018-12-17 09:45:00	2018-12-17 12:15:00	\N	\N	2	0	\N	\N
340316	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2018-12-17 14:45:00	2018-12-17 15:30:00	\N	\N	2	0	\N	\N
340319	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2018-12-17 15:30:00	2018-12-17 18:45:00	\N	\N	1	0	\N	\N
340321	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2018-12-18 09:30:00	2018-12-18 11:00:00	\N	\N	2	0	\N	\N
340324	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2018-12-18 11:00:00	2018-12-18 11:45:00	\N	\N	3	0	\N	\N
340328	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2018-12-18 11:45:00	2018-12-18 12:30:00	\N	\N	1	0	\N	\N
340330	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités (LOM)	2018-12-18 14:30:00	2018-12-18 15:30:00	\N	\N	4	0	\N	\N
340335	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2018-12-18 15:30:00	2018-12-18 16:15:00	\N	\N	3	0	\N	\N
340339	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2018-12-18 18:00:00	2018-12-18 18:45:00	\N	\N	5	0	\N	\N
340345	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2018-12-19 12:00:00	2018-12-19 13:00:00	\N	\N	3	0	\N	\N
340349	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2018-12-19 14:00:00	2018-12-19 15:30:00	\N	\N	2	0	\N	\N
340352	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2018-12-19 15:30:00	2018-12-19 16:15:00	\N	\N	2	0	\N	\N
340355	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2018-12-19 16:30:00	2018-12-19 19:30:00	\N	\N	1	0	\N	\N
310419	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2018-10-17 08:30:00	2018-10-17 09:30:00	2018-10-17 12:28:14	2018-10-17 15:34:23	41	1	\N	\N
334152	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2018-12-12 11:05:00	2018-12-12 11:20:00	2018-12-12 11:40:01	2018-12-12 11:42:18	36	2	\N	\N
340357	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2018-12-20 08:30:00	2018-12-20 10:00:00	\N	\N	2	0	\N	\N
340360	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orienation Mobilités" (LOM)	2018-12-20 10:00:00	2018-12-20 11:45:00	\N	\N	1	0	\N	\N
340362	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2018-12-20 11:45:00	2018-12-20 12:30:00	\N	\N	2	0	\N	\N
340365	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2018-12-20 12:30:00	2018-12-20 13:15:00	\N	\N	2	0	\N	\N
340480	DELEGATION	AUCUNE	\N	\N	COLTER	Audition de l'Association des maires ruraux de France - AMRF	\N	2019-01-17 10:00:00	2019-01-17 11:30:00	2019-01-17 15:31:47	2019-01-17 15:36:56	9	0	\N	\N
340484	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition	\N	2019-01-16 10:40:00	2019-01-16 12:10:00	2019-01-16 14:31:39	2019-01-16 14:54:07	40	5	\N	\N
340560	GIA	AUCUNE	\N	\N	\N	Visite MAE	Réunion avec le rédacteur Chypre du ministère des affaires étrangères	2018-12-04 11:00:00	2018-12-04 12:30:00	\N	\N	2	0	585	\N
350662	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Suite cyberattaque Ariane	\N	2019-02-05 15:30:00	2019-02-05 16:45:00	\N	\N	2	0	\N	\N
350986	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL École de la confiance	PJL École de la confiance	2019-02-12 09:00:00	2019-02-12 10:00:00	\N	\N	5	0	\N	\N
350992	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL École de la confiance	PJL École de la confiance	2019-02-12 10:00:00	2019-02-12 11:00:00	\N	\N	3	0	\N	\N
351756	DELEGATION	AUCUNE	\N	\N	PROS	Audition de M. Bertrand Badie	Audition de M. Bertrand Badie	2019-03-07 08:30:00	2019-03-07 09:45:00	\N	\N	13	0	\N	\N
353832	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière CAP 2040	Réunion plénière CAP 2040	2019-03-14 09:15:00	2019-03-14 11:15:00	\N	\N	7	0	\N	\N
353912	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Protection des activités agricoles et des cultures marines	Audition de représentants du ministère de l'agriculture et de l'alimentation	2019-02-12 17:00:00	2019-02-12 17:45:00	\N	\N	1	0	\N	\N
353913	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Protection des activités agricoles et des cultures marines	Audition de représentants de la Fédération nationale des SAFER	2019-02-12 17:45:00	2019-02-12 18:15:00	\N	\N	1	0	\N	\N
353914	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Protection des activités agricoles et des cultures marines	Audition de M. Jimmy PAHUN, député du Morbihan	2019-02-12 18:30:00	2019-02-12 19:00:00	\N	\N	1	0	\N	\N
353915	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Protection des activités agricoles et des cultures marines	Audition de représentants de Sels de France	2019-02-14 11:00:00	2019-02-14 11:30:00	\N	\N	1	0	\N	\N
354209	MISSION	AUDRAP	\N	SIDERURGIE	\N	Comité stratégique de filière "Mines et métallurgie"	\N	2019-02-19 14:05:00	2019-02-19 15:05:00	\N	\N	1	0	\N	\N
354217	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL École de la confiance	PJL École de la confiance	2019-02-19 09:30:00	2019-02-19 11:00:00	\N	\N	4	0	\N	\N
216121	DELEGATION	AUCUNE	\N	\N	211	Echange de vues sur le programme de travail de la délégation aux droits des femmes	Echange de vues sur le programme de travail de la délégation aux droits des femmes	2017-11-09 08:30:00	2017-11-09 10:00:00	2017-11-09 10:51:19	2017-11-09 16:33:19	22	0	\N	\N
223685	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPRE Pérenniser la procédure de législation en commission	\N	2017-11-23 10:20:00	2017-11-23 12:20:00	\N	\N	1	0	\N	\N
226074	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2018 - Programme 844/847	\N	2017-11-27 15:00:00	2017-11-27 15:30:00	\N	\N	1	0	\N	\N
229388	MISSION	AUCUNE	\N	ALSTOM	\N	Audition commune organisations syndicales CCE Alstom	Audition commune organisations syndicales CCE Alstom	2017-12-13 17:30:00	2017-12-13 19:05:00	2017-12-14 14:31:12	2017-12-14 14:43:59	19	0	\N	\N
230677	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL "Réforme du Logement"	PJL "Réforme du Logement"	2017-12-13 15:30:00	2017-12-13 16:30:00	\N	\N	2	0	\N	\N
230680	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL "Réforme du Logement"	PJL "Réforme du Logement"	2017-12-14 16:40:00	2017-12-14 17:55:00	\N	\N	1	0	\N	\N
230682	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Etats Généraux de l'Alimentation	Etats Généraux de l'Alimentation	2017-12-13 15:30:00	2017-12-13 16:30:00	\N	\N	13	0	\N	\N
235399	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL "Réforme du Logement"	PJL "Réforme du Logement"	2018-01-16 15:45:00	2018-01-16 16:30:00	\N	\N	0	0	\N	\N
235400	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL "Réforme du Logement"	PJL "Réforme du Logement"	2018-01-17 15:10:00	2018-01-17 15:45:00	\N	\N	2	0	\N	\N
235403	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL "Réforme du Logement"	PJL "Réforme du Logement"	2018-01-17 15:45:00	2018-01-17 18:50:00	\N	\N	0	0	\N	\N
241249	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Déplacement à Fresnes	\N	2018-01-30 08:00:00	2018-01-30 13:00:00	\N	\N	9	0	\N	\N
241259	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	LOIS	\N	Situation des prisons	\N	2018-02-01 09:00:00	2018-02-01 11:15:00	\N	\N	6	0	\N	\N
241272	COM_SPECIALE	EXAMEN	\N	ETAT	\N	Réunion constitutive	\N	2018-01-24 13:40:00	2018-01-24 14:00:00	\N	\N	0	0	\N	\N
241275	AUTRE_TEMPORAIRE	DEPLACEMENT	\N	\N	\N	Lse conditions de réussite d'une réforme systémique des retraites	\N	2018-01-29 07:30:00	2018-01-31 09:30:00	\N	\N	0	0	\N	\N
241276	COM_SPECIALE	PLENIERE	\N	SOCIETE	\N	\N	\N	2018-02-07 14:35:00	2018-02-07 17:25:00	2018-02-08 18:35:31	2018-02-09 17:08:27	20	0	\N	\N
241277	COM_PERMANENTE	EXAMEN	\N	AFCL	\N	Réunion	\N	2018-01-30 14:00:00	2018-01-30 15:00:00	\N	\N	0	0	\N	\N
241278	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion	Réunion	2018-02-06 09:30:00	2018-02-06 10:00:00	2018-02-06 10:51:06	2018-02-07 14:55:40	23	1	\N	\N
249278	ETUDES	AUCUNE	\N	\N	\N	\N	\N	2018-02-21 08:15:00	2018-02-21 09:15:00	\N	\N	25	0	\N	907
250554	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition cycle de vie des entreprises	Audition cycle de vie des entreprises - Conseil national des greffiers des tribunaux de commerce	2018-03-06 16:30:00	2018-03-06 18:10:00	\N	\N	1	0	\N	\N
250556	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition cycle de vie des entreprises	Audition cycle de vie des entreprises - Middlenext	2018-03-06 18:15:00	2018-03-06 19:15:00	\N	\N	1	0	\N	\N
258034	GIA	AUCUNE	\N	\N	\N	Entrevue avec Son Excellence Avirmid BATTUR, nouvel ambassadeur de Mongolie en France	Entrevue  avec Son Excellence Avirmid BATTUR, nouvel ambassadeur de Mongolie en France	2018-03-21 08:30:00	2018-03-21 09:15:00	\N	\N	4	0	612	\N
258248	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 21 mars 2018	Réunion de la commission des affaires européennes du 21 mars 2018	2018-03-21 17:25:00	2018-03-21 18:30:00	2018-03-21 18:48:22	2018-03-22 12:21:57	14	0	\N	\N
307093	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2019 - Assurance vieillesse	\N	2018-10-23 13:45:00	2018-10-23 14:30:00	\N	\N	1	0	\N	\N
340483	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Examen d'un rapport et établissement du texte	\N	2019-01-16 10:00:00	2019-01-16 10:40:00	2019-01-16 14:31:58	2019-01-16 14:54:09	40	0	\N	\N
258632	GIA	AUCUNE	\N	\N	\N	Entretien avec des diplomates français	Entretien avec la directrice Europe continentale et le chef de la mission Europe balkanique du MEAE	2018-03-21 17:30:00	2018-03-21 19:00:00	\N	\N	5	0	674	\N
258953	GIA	AUCUNE	\N	\N	\N	Petit déjeuner de bureau	Petit déjeuner de bureau	2018-03-21 08:30:00	2018-03-21 09:30:00	\N	\N	9	0	598	\N
258977	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Mission "Routes de la soie"	\N	2018-03-20 14:00:00	2018-03-20 15:00:00	\N	\N	2	0	\N	\N
260823	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Métier d'enseignant	Métier d'enseignant	2018-03-21 16:00:00	2018-03-21 19:00:00	\N	\N	2	0	\N	\N
260826	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Métier d'enseignant	Métier d'enseignant	2018-03-28 14:00:00	2018-03-28 15:00:00	\N	\N	3	0	\N	\N
260830	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Métier d'enseignant	Métier d'enseignant	2018-03-28 15:00:00	2018-03-28 16:00:00	\N	\N	3	0	\N	\N
260846	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Métier d'enseignant	Métier d'enseignant	2018-04-03 14:00:00	2018-04-03 16:00:00	\N	\N	2	0	\N	\N
260850	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Métier d'enseignant	Métier d'enseignant	2018-04-04 08:30:00	2018-04-04 09:30:00	\N	\N	2	0	\N	\N
260853	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Métier d'enseignant	Métier d'enseignant	2018-04-04 14:00:00	2018-04-04 15:00:00	\N	\N	3	0	\N	\N
261058	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2018-03-27 14:40:00	2018-03-27 16:40:00	\N	\N	3	0	\N	\N
269188	DELEGATION	AUCUNE	\N	\N	211	Audition de Mme Sylvue Pierre-Brosselette - CSA	Audition de Mme Sylvue Pierre-Brosselette - CSA	2018-04-19 09:30:00	2018-04-19 11:00:00	2018-04-19 12:08:34	2018-04-19 14:52:31	28	0	\N	\N
269525	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Protection des savoir-faire et des informations commerciales	\N	2018-04-19 01:15:00	2018-04-19 01:20:00	2018-04-19 15:05:43	2018-04-20 10:36:28	1	0	\N	\N
270579	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Nomination rapporteurs + Rapport Avis PJL Programmation militaire 2019 à 2025	\N	2018-05-15 09:10:00	2018-05-15 10:00:00	2018-05-15 10:41:40	2018-05-15 18:19:16	18	0	\N	\N
270871	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2018-05-16 13:10:00	2018-05-16 13:25:00	2018-05-16 17:36:47	2018-05-16 18:01:31	44	0	\N	\N
271924	GIA	AUCUNE	\N	\N	\N	Ambassadeur d'Azerbaïdjan	Petit-déjeuner en l'honneur de l'ambassadeur d'Azerbaïdjan en France	2018-05-16 08:55:00	2018-05-16 09:45:00	\N	\N	7	0	534	\N
309349	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT "Tourisme"	GT "Tourisme"	2018-10-03 08:00:00	2018-10-03 09:00:00	\N	\N	28	0	\N	\N
314114	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Défense - EMAT	PLF pour 2019 - Défense - EMAT	2018-10-18 15:30:00	2018-10-18 16:30:00	\N	\N	1	0	\N	\N
314116	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2019 (Mildeca)	\N	2018-10-23 14:30:00	2018-10-23 15:30:00	\N	\N	1	0	\N	\N
314117	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Enseignement scolaire - Cabinet Ministre	PLF pour 2019 - Enseignement scolaire - Cabinet Ministre	2018-10-18 17:45:00	2018-10-18 19:20:00	\N	\N	1	0	\N	\N
314119	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2019 (Mildeca)	\N	2018-10-31 15:00:00	2018-10-31 16:00:00	\N	\N	1	0	\N	\N
314122	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - AEE - MEAE 	PLF pour 2019 - AEE - MEAE	2018-10-16 15:00:00	2018-10-16 16:00:00	\N	\N	2	0	\N	\N
314129	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - AEE - Direction du budget et DGM du MEAE	PLF pour 2019 - AEE - Direction du budget et DGM du MEAE	2018-10-18 14:30:00	2018-10-18 16:30:00	\N	\N	2	0	\N	\N
314134	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	\N	\N	2018-10-18 08:30:00	2018-10-18 09:30:00	\N	\N	0	0	\N	\N
314136	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Médias - CNC et Arte France	PLF pour 2019 - Médias - CNC et Arte France	2018-10-15 14:45:00	2018-10-15 16:30:00	\N	\N	1	0	\N	\N
314138	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 2018 - Valorisation marques culturelles françaises - Cour des comptes	58-2 2018 - Valorisation marques culturelles françaises - Cour des comptes	2018-10-18 10:30:00	2018-10-18 11:30:00	\N	\N	1	0	\N	\N
314160	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFR 2018	PLFR 2018	2018-11-19 16:00:00	2018-11-19 18:10:00	\N	\N	48	0	\N	\N
314162	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2018-11-20 09:30:00	2018-11-20 12:40:00	\N	\N	39	0	\N	\N
314165	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Diplomatie climatique France	Débat Diplomatie climatique France	2018-11-20 16:00:00	2018-11-20 17:45:00	\N	\N	88	0	\N	\N
279282	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Equilibre territorial et vitalité de la démocratie locale	\N	2018-05-31 10:45:00	2018-05-31 12:30:00	\N	\N	2	0	\N	\N
279285	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Equilibre territorial et vitalité de la démocratie locale	\N	2018-05-31 14:00:00	2018-05-31 14:45:00	\N	\N	2	0	\N	\N
279288	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2018-06-06 09:10:00	2018-06-06 10:10:00	2018-06-06 14:42:11	2018-06-06 16:06:15	42	0	\N	\N
284536	MISSION	AUCUNE	\N	HERBE	\N	Audition plénière	\N	2018-06-13 16:00:00	2018-06-13 17:25:00	2018-06-13 20:02:11	2018-06-14 09:52:13	10	0	\N	\N
295313	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Déplacement à Eurosatory 	\N	2018-06-13 08:00:00	2018-06-13 15:30:00	\N	\N	17	0	\N	\N
295349	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	206	Conférence de presse sur le rapport "blockchains"	Conférence de presse sur le rapport "Comprendre les blockchains"	2018-07-05 11:10:00	2018-07-05 12:45:00	\N	\N	5	0	\N	\N
295355	ETUDES	AUCUNE	\N	\N	\N	Déplacement Paris Saint-Germain 	Déplacement Paris Saint-Germain 	2018-07-05 11:00:00	2018-07-05 14:30:00	\N	\N	10	0	\N	934
295816	DELEGATION	AUDRAP	\N	\N	206	Audition "Planète Mars" de l'Institut d'astrophysique spatiale	Audition "Planète Mars" de M. François Poulet, responsable de l'équipe de planétologie-Institut d'astrophysique spatiale	2018-07-12 17:30:00	2018-07-12 18:30:00	\N	\N	1	0	\N	\N
319278	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	\N	2018-11-07 15:00:00	2018-11-07 15:30:00	\N	\N	0	0	\N	\N
319279	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	\N	2018-11-07 15:30:00	2018-11-07 16:00:00	\N	\N	0	0	\N	\N
319280	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	\N	2018-11-07 16:00:00	2018-11-07 17:00:00	\N	\N	0	0	\N	\N
319281	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	\N	2018-11-07 16:00:00	2018-11-07 17:00:00	\N	\N	0	0	\N	\N
319282	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	\N	2018-11-16 08:30:00	2018-11-16 09:15:00	\N	\N	0	0	\N	\N
295778	CMP	AUTRE	\N	OEP	\N	PPL Nomination et présence des parlementaires dans certains OEP	PPL Nomination et présence des parlementaires dans certains OEP	2018-07-04 10:42:00	2018-07-04 10:56:00	\N	\N	7	0	\N	\N
295786	CMP	AUTRE	\N	ASILE	\N	PJL Immigration, droit d'asile et intégration	PJL Immigration, droit d'asile et intégration	2018-07-04 11:33:00	2018-07-04 11:59:00	\N	\N	11	0	\N	\N
319283	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2019 - Examen Rapports AEE-APD-GFPRH	PLF pour 2019 - Examen Rapports AEE-APD-GFPRH	2018-11-07 14:35:00	2018-11-07 17:32:00	2018-11-07 17:46:51	2018-11-07 18:13:11	32	0	\N	\N
319284	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	\N	2018-11-08 13:30:00	2018-11-08 14:15:00	\N	\N	0	0	\N	\N
319285	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2019 - Examen Rapports Anciens combattants-Défense et Communication Vienne	PLF pour 2019 - Examen Rapports Anciens combattants-Défense et Communication Vienne	2018-11-08 09:35:00	2018-11-08 10:45:00	2018-11-08 16:33:03	2018-11-08 16:40:02	23	0	\N	\N
319286	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	\N	2018-11-08 16:15:00	2018-11-08 17:00:00	\N	\N	0	0	\N	\N
319301	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Election des sénateurs	\N	2018-10-31 09:30:00	2018-10-31 12:30:00	\N	\N	2	0	\N	\N
319304	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Election des sénateurs	\N	2018-10-31 14:00:00	2018-10-31 14:30:00	\N	\N	1	0	\N	\N
319327	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Orrin HATCH, sénateur américain	Entretien avec M. Orrin HATCH, sénateur américain	2018-10-30 15:30:00	2018-10-30 16:00:00	\N	\N	5	0	590	\N
319337	DELEGATION	AUCUNE	\N	\N	211	Échange de vues sur les dispositions du PLFSS 2019 - désignation de rapporteurs	Échange de vues sur les dispositions du PLFSS 2019 - désignation de rapporteurs	2018-11-08 08:30:00	2018-11-08 10:00:00	2018-11-08 10:57:56	2018-11-08 15:47:10	17	0	\N	\N
319413	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 -Crédits Enseignement agricole	PLF 2019 -Crédits Enseignement agricole	2018-11-05 14:00:00	2018-11-05 15:00:00	\N	\N	1	0	\N	\N
319579	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF pour 2019 - Avis "énergie"	PJLF pour 2019 - Avis "énergie"	2018-10-31 11:30:00	2018-10-31 13:00:00	\N	\N	1	0	\N	\N
319585	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF pour 2019 - Avis "énergie"	PJLF pour 2019 - Avis "énergie"	2018-10-31 16:00:00	2018-10-31 17:00:00	\N	\N	1	0	\N	\N
319594	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF pour 2019 - Avis "énergie"	PJLF pour 2019 - Avis "énergie"	2018-10-30 14:00:00	2018-10-30 15:00:00	\N	\N	0	0	\N	\N
319595	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJLF pour 2019 - Avis "biodiversité et transition énergétique"	PJLF pour 2019 - Avis "biodiversité et transition énergétique"	2018-10-30 10:00:00	2018-10-30 11:00:00	\N	\N	1	0	\N	\N
319597	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF pour 2019 - mission "Agriculture, alimentation, forêt et affaires rurales"	PJLF pour 2019 - mission "Agriculture, alimentation, forêt et affaires rurales"	2018-10-30 14:00:00	2018-10-30 15:30:00	\N	\N	0	0	\N	\N
319601	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF pour 2019 - mission "Agriculture, alimentation, forêt et affaires rurales"	PJLF pour 2019 - mission "Agriculture, alimentation, forêt et affaires rurales"	2018-10-31 14:00:00	2018-10-31 16:30:00	\N	\N	3	0	\N	\N
319763	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJLF pour 2019 - Avis "Prévention des risques"	PJLF pour 2019 - Avis "Prévention des risques"	2018-10-29 13:30:00	2018-10-29 16:00:00	\N	\N	1	0	\N	\N
319784	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJLF pour 2019 - Avis "Prévention des risques"	PJLF pour 2019 - Avis "Prévention des risques"	2018-10-29 18:00:00	2018-10-29 19:00:00	\N	\N	1	0	\N	\N
319829	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PLF 2019 - Audition de M. Christophe Castaner, ministre de l'intérieur	PLF 2019 - Audition de M. Christophe Castaner, ministre de l'intérieur	2018-11-13 18:10:00	2018-11-13 20:10:00	2018-11-13 20:14:27	2018-11-14 09:27:57	28	0	\N	\N
320509	DELEGATION	AUDRAP	\N	\N	206	Audition CRE (Stockage de l'électricité)	Audition Commission de régulation de l'énergie (CRE) (Stockage de l'électricité)	2018-11-14 14:00:00	2018-11-14 15:15:00	\N	\N	1	0	\N	\N
320511	DELEGATION	AUDRAP	\N	\N	206	Audition RTE (Stockage de l'électricité)	Audition Réseau de transport de l'électricité (RTE) (Stockage de l'électricité)	2018-11-15 10:00:00	2018-11-15 11:15:00	\N	\N	1	0	\N	\N
320513	DELEGATION	AUDRAP	\N	\N	206	Audition CEA LITEN (Stockage de l'électricité)	Audition CEA LITEN (Stockage de l'électricité)	2018-11-15 11:15:00	2018-11-15 12:30:00	\N	\N	1	0	\N	\N
320553	GIA	AUCUNE	\N	\N	\N	Déjeuner de travail avec S. Exc. M. ANDRADE FALLA, Ambassadeur du Guatelama en France	Déjeuner de travail avec S. Exc. M. Luis Fernando ANDRADE FALLA, Ambassadeur du Guatelama en France	2018-11-07 12:30:00	2018-11-07 14:30:00	\N	\N	5	0	643	\N
320658	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	PLF 2019 - Avis logement	2018-11-06 14:30:00	2018-11-06 16:40:00	\N	\N	1	0	\N	\N
320661	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	PLF 2019 - Avis budgétaire Logement	2018-11-06 17:50:00	2018-11-06 19:10:00	\N	\N	1	0	\N	\N
320747	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 8 novembre 2018	Réunion de la commission des affaires européennes du 8 novembre 2018	2018-11-08 08:35:00	2018-11-08 09:55:00	2018-11-08 12:41:27	2018-11-08 15:45:27	18	0	\N	\N
320800	COM_EURO	AUDRAP	\N	AFEU	\N	Corridor "Mer du Nord - Méditerranée"	Audition de représentants du Cluster maritime français	2018-11-07 14:15:00	2018-11-07 15:30:00	\N	\N	3	0	\N	\N
320801	COM_EURO	AUDRAP	\N	AFEU	\N	Corridor "Mer du Nord - Méditerranée"	Audition de représentants de Armateurs de France	2018-11-07 15:30:00	2018-11-07 16:30:00	\N	\N	2	0	\N	\N
320802	COM_EURO	AUDRAP	\N	AFEU	\N	Statut des sapeurs-pompiers volontaires	Audition de représentants de la DGSCGS - Ministère de l'intérieur	2018-11-07 14:05:00	2018-11-07 15:25:00	\N	\N	2	0	\N	\N
320803	COM_EURO	AUDRAP	\N	AFEU	\N	Staut des sapeurs-pompiers volontaires	Audition de représentants de la Fédération nationale des sapeurs-pompiers de France	2018-11-07 16:05:00	2018-11-07 16:55:00	\N	\N	2	0	\N	\N
320970	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen Rapport PLF pour 2019 RSR/Pensions et Rapport PPL 730 Désertification bancaire	Examen Rapport PLF pour 2019 RSR/Pensions et Rapport PPL 730 Désertification bancaire	2018-11-13 14:35:00	2018-11-13 16:05:00	2018-11-13 18:52:27	2018-11-14 09:27:55	27	0	\N	\N
214607	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Recherche et Enseignement supérieur	PLF pour 2018 - Recherche et Enseignement supérieur - INSERM	2017-10-30 15:00:00	2017-10-30 16:15:00	\N	\N	1	0	\N	\N
214611	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Recherche et Enseignement supérieur	PLF pour 2018 - Recherche et Enseignement supérieur - CNRS	2017-11-02 10:00:00	2017-11-02 11:10:00	\N	\N	1	0	\N	\N
214613	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Recherche et Enseignement supérieur	PLF pour 2018 - Recherche et Enseignement supérieur - IFPEN	2017-11-02 11:10:00	2017-11-02 12:15:00	\N	\N	1	0	\N	\N
214615	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Recherche et Enseignement supérieur	PLF pour 2018 - Recherche et Enseignement supérieur - ASRC	2017-11-02 14:00:00	2017-11-02 15:10:00	\N	\N	1	0	\N	\N
215509	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Modalités de dépôt de candidature aux élections	\N	2017-11-07 18:30:00	2017-11-07 19:15:00	\N	\N	2	0	\N	\N
319828	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPLO Élection des sénateurs - Examen du rapport et du texte de la commission	PPLO Élection des sénateurs - Examen du rapport et du texte de la commission	2018-11-14 10:05:00	2018-11-14 11:20:00	2018-11-14 11:27:14	2018-11-14 11:44:18	37	0	\N	\N
229927	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 14 décembre 2017 - 8h30	Réunion du 14 décembre 2017 - 8h30	2017-12-14 08:35:00	2017-12-14 10:10:00	2017-12-14 10:34:00	2017-12-14 14:53:02	17	0	\N	\N
230064	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Echanges de vues sur les ordonannces "travail" et le PLFR	Echanges de vue sur les ordonnances "travail" et le PLFR (dont prélèvement à la source de l'IR)	2017-12-14 09:15:00	2017-12-14 10:20:00	2017-12-14 11:27:54	2017-12-14 14:40:56	18	0	\N	\N
234017	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition cycle de vie des entreprises	Audition cycle de vie des entreprises - Euronext -	2018-01-16 14:10:00	2018-01-16 15:30:00	\N	\N	1	0	\N	\N
243746	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 7 février 2018	Réunion du 7 février 2018	2018-02-07 17:05:00	2018-02-07 18:35:00	\N	\N	20	0	\N	\N
243771	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 8 février 2018	Réunion du 8 février 2018	2018-02-08 09:05:00	2018-02-08 10:35:00	2018-02-08 18:59:41	2018-02-09 17:06:10	16	0	\N	\N
243898	DELEGATION	AUCUNE	\N	\N	DSOM	Déplacement à Saint-Mandé (Météo France)	Déplacement à Saint-Mandé (Météo France)	2018-02-19 14:45:00	2018-02-19 18:00:00	2018-02-20 08:45:52	2018-02-20 14:53:24	7	0	\N	\N
244782	COM_SPECIALE	AUDRAP	\N	SOCIETE	\N	\N	\N	2018-02-13 16:15:00	2018-02-13 17:45:00	\N	\N	5	0	\N	\N
244790	COM_SPECIALE	AUCUNE	\N	SOCIETE	\N	\N	\N	2018-02-21 14:30:00	2018-02-21 19:00:00	2018-02-23 15:09:51	2018-02-23 15:11:54	27	0	\N	\N
244792	COM_SPECIALE	AUDRAP	\N	SOCIETE	\N	\N	\N	2018-02-15 09:30:00	2018-02-15 12:00:00	\N	\N	1	0	\N	\N
244799	COM_SPECIALE	PLENIERE	\N	SOCIETE	\N	\N	\N	2018-02-22 10:05:00	2018-02-22 11:35:00	2018-02-23 12:01:22	2018-02-23 12:01:29	21	0	\N	\N
244819	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	test fg	\N	2014-01-23 09:30:00	2014-01-23 11:30:00	\N	\N	0	0	\N	\N
245180	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	SOCI	\N	Mission "Flash" Ehpad	Situation dans les EHPAD	2018-02-13 14:00:00	2018-02-13 15:30:00	\N	\N	5	0	\N	\N
247102	GIA	AUCUNE	\N	\N	\N	Entretien avec Ambassadrice de France en Namibie	Entretien avec Ambassadrice de France en Namibie	2018-02-01 09:30:00	2018-02-01 10:30:00	\N	\N	3	0	646	\N
249983	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Libye	\N	2018-02-20 14:00:00	2018-02-20 15:15:00	\N	\N	3	0	\N	\N
249987	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Libye	\N	2018-02-21 14:00:00	2018-02-21 15:15:00	\N	\N	3	0	\N	\N
253092	MISSION	AUDRAP	\N	ALSTOM	\N	MI ALSTOM - Auditions président&rapporteur	\N	2018-03-08 08:00:00	2018-03-08 11:00:00	\N	\N	3	0	\N	\N
255374	GIA	AUCUNE	\N	\N	\N	Déjeuner GIA Ambassadeur	Déjeuner du groupe d'amitié avec l'ambassadeur d'Irak	2018-03-14 12:30:00	2018-03-14 14:30:00	\N	\N	11	0	615	\N
256163	DELEGATION	DEPLACEMENT	\N	\N	COLTER	Délégation aux collectivités - GT statut élu local - Déplacement Milan	Délégation aux collectivités - GT statut élu local - Déplacement Milan	2018-03-15 13:00:00	2018-03-16 18:30:00	\N	\N	2	0	\N	\N
267662	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition plénière et communication	\N	2018-04-18 09:30:00	2018-04-18 11:40:00	2018-04-18 11:41:03	2018-04-18 16:47:50	33	0	\N	\N
267817	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2018 - Aide alimentaire - Déplacement Compiègne et Chantilly	Contrôle 2018 - Aide alimentaire -Déplacement à Compiègne (banque alimentaire de l'oise) et Chantilly (épicerie sociale)	2018-04-12 08:00:00	2018-04-12 13:00:00	\N	\N	2	0	\N	\N
267821	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Mission APD - 0,7 % 	Contrôle 2018 - Mission APD - Quelle trajectoire financière pour atteindre 0,7 % - Coordination Sud	2018-04-11 14:40:00	2018-04-11 16:00:00	\N	\N	2	0	\N	\N
267837	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Sports	PLF pour 2019 - Sports - (DJEPVA)	2018-04-11 14:30:00	2018-04-11 15:30:00	\N	\N	1	0	\N	\N
267874	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Réseau de l'enseignement français à l'étranger	Contrôle 2018 -  Réseau de l'enseignement français à l'étranger - Fondation de l'alliance française	2018-04-11 16:00:00	2018-04-11 16:45:00	\N	\N	2	0	\N	\N
267962	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	MI ALSTOM - Auditions président & rapporteur	\N	2018-04-18 14:00:00	2018-04-18 18:00:00	\N	\N	0	0	\N	\N
267968	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Préparation PPL	Préparation PPL suppression du verrou de Bercy - Audition du cabinet du ministère de l'action et des comptes publics	2018-04-10 15:45:00	2018-04-10 16:30:00	\N	\N	1	0	\N	\N
267970	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL suppression du verrou de Bercy	PPL suppression du verrou de Bercy - Commission des infractions fiscales	2018-04-12 14:30:00	2018-04-12 15:15:00	\N	\N	1	0	\N	\N
267972	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL Suppression du verrou de Bercy	PPL Suppression du verrou de Bercy - DGFiP	2018-04-12 17:15:00	2018-04-12 18:00:00	\N	\N	1	0	\N	\N
267975	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL Suppression du verrou de Bercy	PPL Suppression du verrou de Bercy - Audition de Mme de la Gontrie	2018-04-16 15:00:00	2018-04-16 15:45:00	\N	\N	1	0	\N	\N
269043	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion	Réunion	2018-04-19 09:30:00	2018-04-19 10:55:00	2018-04-20 14:47:42	2018-04-20 14:49:32	28	0	\N	\N
269044	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Mission Mécénat	Mission Mécénat	2018-04-17 15:30:00	2018-04-17 16:30:00	\N	\N	6	0	\N	\N
269050	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Mission Mécénat	Mission Mécénat	2018-04-17 16:30:00	2018-04-17 17:45:00	\N	\N	5	0	\N	\N
269055	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Mission Mécénat	Mission Mécénat	2018-04-18 16:00:00	2018-04-18 18:10:00	\N	\N	4	0	\N	\N
270033	ETUDES	AUCUNE	\N	\N	\N	\N	\N	2018-04-18 17:00:00	2018-04-18 18:45:00	\N	\N	14	0	\N	928
271641	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion	Réunion	2018-05-16 09:35:00	2018-05-16 12:15:00	2018-05-16 16:57:09	2018-05-16 18:01:27	41	0	\N	\N
273518	GIA	AUCUNE	\N	\N	\N	Remise de diplômes par l'Ambassadeur de Slovaquie	Remise de diplômes par l'Ambassadeur de Slovaquie à MM. Hervé Marseille et André Vantomme	2018-05-14 18:30:00	2018-05-14 20:00:00	\N	\N	2	0	532	\N
305981	MISSION	AUCUNE	\N	PENURIE	\N	\N	\N	2018-09-27 10:00:00	2018-09-27 12:05:00	2018-09-27 12:10:54	2018-09-27 17:39:11	12	0	\N	\N
307065	MECSS	AUDRAP	\N	\N	MECSS	\N	\N	2018-10-03 15:15:00	2018-10-03 17:30:00	\N	\N	1	0	\N	\N
307078	MECSS	AUDRAP	\N	\N	MECSS	\N	\N	2018-10-03 15:15:00	2018-10-03 17:30:00	\N	\N	1	0	\N	\N
307080	MECSS	AUDRAP	\N	\N	MECSS	\N	\N	2018-10-09 14:30:00	2018-10-09 16:00:00	\N	\N	2	0	\N	\N
307082	MECSS	AUDRAP	\N	\N	MECSS	\N	\N	2018-10-10 14:30:00	2018-10-10 16:45:00	\N	\N	1	0	\N	\N
307084	MECSS	AUDRAP	\N	\N	MECSS	\N	\N	2018-10-11 11:15:00	2018-10-11 12:00:00	\N	\N	1	0	\N	\N
307086	MECSS	AUDRAP	\N	\N	MECSS	\N	\N	2018-10-16 14:30:00	2018-10-16 16:45:00	\N	\N	1	0	\N	\N
307088	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2019 - Equilibres financiers généraux et assurance vieillesse	\N	2018-10-17 15:00:00	2018-10-17 18:00:00	\N	\N	2	0	\N	\N
307091	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2019 - Régimes sociaux et de retraite	\N	2018-10-24 14:00:00	2018-10-24 16:00:00	\N	\N	1	0	\N	\N
307095	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2019 - Assurance vieillesse	\N	2018-10-24 16:00:00	2018-10-24 17:00:00	\N	\N	1	0	\N	\N
314445	ETUDES	AUCUNE	\N	\N	\N	\N	\N	2018-10-24 08:30:00	2018-10-24 09:30:00	\N	\N	9	0	\N	922
314452	COM_PERMANENTE	AUDRAP	\N	CDD	\N	\N	PLF 2019  - Avis transports ferroviaires	2018-10-24 15:00:00	2018-10-24 17:00:00	\N	\N	1	0	\N	\N
279797	MISSION	AUCUNE	\N	HERBE	\N	Audition plénière	\N	2018-06-05 13:40:00	2018-06-05 14:30:00	2018-06-05 15:17:10	2018-06-05 16:31:26	14	0	\N	\N
284150	ETUDES	AUCUNE	\N	\N	\N	Audition Comité paralympique et sportif français	Audition Comité paralympique et sportif français	2018-06-13 08:00:00	2018-06-13 09:00:00	\N	\N	17	0	\N	934
284270	GIA	AUCUNE	\N	\N	\N	Petit-déjeuner 	Petit-déjeuner du GIA France-Hongrie avec l'ambassadeur de Hongrie en France	2018-06-13 08:30:00	2018-06-13 09:30:00	\N	\N	4	0	592	\N
294104	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL télephone portable	\N	2018-06-21 09:00:00	2018-06-21 10:00:00	\N	\N	2	0	\N	\N
294107	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL télephone portable	\N	2018-06-21 10:00:00	2018-06-21 11:00:00	\N	\N	3	0	\N	\N
294135	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL télephone portable	\N	2018-06-21 13:30:00	2018-06-21 15:00:00	\N	\N	0	0	\N	\N
294136	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL télephone portable	\N	2018-06-26 09:00:00	2018-06-26 11:00:00	\N	\N	1	0	\N	\N
294139	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL télephone portable	\N	2018-06-26 13:30:00	2018-06-26 15:00:00	\N	\N	2	0	\N	\N
294143	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL télephone portable	\N	2018-06-27 14:30:00	2018-06-27 15:30:00	\N	\N	4	0	\N	\N
294148	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL télephone portable	\N	2018-06-28 13:30:00	2018-06-28 14:30:00	\N	\N	1	0	\N	\N
307069	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Calcul de l'allocation aux adultes handicapés	\N	2018-10-02 14:45:00	2018-10-02 15:30:00	\N	\N	2	0	\N	\N
307071	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Calcul de l'allocation aux adultes handicapés	\N	2018-10-02 15:30:00	2018-10-02 16:15:00	\N	\N	2	0	\N	\N
307072	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Calcul de l'allocation aux adultes handicapés	\N	2018-10-03 15:30:00	2018-10-03 16:15:00	\N	\N	2	0	\N	\N
307073	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Calcul de l'allocation aux adultes handicapés	\N	2018-10-03 16:15:00	2018-10-03 17:00:00	\N	\N	2	0	\N	\N
332986	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 5 décembre 2018	Réunion de la commission des affaires européennes du 5 décembre 2018	2018-12-05 17:30:00	2018-12-05 19:00:00	2018-12-05 19:27:21	2018-12-06 11:17:41	15	0	\N	\N
338198	GIA	AUCUNE	\N	\N	\N	Entretien avec Mme Florence Jeanblanc-Risler, Ambassadeur de France au Laos	Entretien avec Mme Florence Jeanblanc-Risler, Ambassadeur de France au Laos	2018-12-13 16:30:00	2018-12-13 17:30:00	\N	\N	2	0	577	\N
339690	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition Parquet antiterroriste	\N	2018-04-04 14:00:00	2018-04-04 15:15:00	\N	\N	0	0	\N	\N
339983	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL PJLO Polynésie - ADFE	PJL PJLO Polynésie - ADFE	2018-12-19 14:15:00	2018-12-19 14:45:00	\N	\N	2	0	\N	\N
339984	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL PJLO Polynésie - Ministère de l'intérieur (DMAT)	PJL PJLO Polynésie - Ministère de l'intérieur (DMAT)	2018-12-19 14:45:00	2018-12-19 15:45:00	\N	\N	2	0	\N	\N
339985	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL PJLO Polynésie - Ministère de l'Europe et des affaires étrangères (DFAE)	PJL PJLO Polynésie - Ministère de l'Europe et des affaires étrangères (DFAE)	2018-12-19 16:00:00	2018-12-19 17:00:00	\N	\N	2	0	\N	\N
339986	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL PJLO Polynésie - AFE	PJL PJLO Polynésie - AFE	2018-12-19 17:00:00	2018-12-19 18:00:00	\N	\N	1	0	\N	\N
339987	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL PJLO Polynésie - Hélène CONWAY-MOURET	PJL PJLO Polynésie - Hélène CONWAY-MOURET	2018-12-19 18:00:00	2018-12-19 18:30:00	\N	\N	2	0	\N	\N
339988	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL et PPLO Elections organisées à l'étranger	PPL et PPLO Elections organisées à l'étranger	2019-01-14 11:00:00	2019-01-14 11:50:00	\N	\N	2	0	\N	\N
339989	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL et PPLO Elections organisées à l'étranger	PPL et PPLO Elections organisées à l'étranger	2019-01-14 11:50:00	2019-01-14 12:40:00	\N	\N	1	0	\N	\N
340055	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 90	\N	2018-12-19 14:03:00	2018-12-19 14:06:00	2018-12-19 17:24:23	2018-12-19 17:46:41	16	0	\N	\N
340433	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Petites communes au sein des conseils communautaires	\N	2019-01-07 14:00:00	2019-01-07 16:30:00	\N	\N	1	0	\N	\N
340479	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de M. François VILLEROY de GALHAU, gouverneur de la Banque de France	Audition de M. François VILLEROY de GALHAU, gouverneur de la Banque de France	2019-01-16 10:05:00	2019-01-16 11:35:00	2019-01-16 18:35:30	2019-01-17 11:58:11	33	0	\N	\N
340488	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-01-16 10:00:00	2019-01-16 12:05:00	2019-01-16 12:39:45	2019-01-16 14:54:08	37	0	\N	\N
340501	MISSION	AUCUNE	\N	INFRACTIONS	\N	Auditions plénières	\N	2019-01-15 16:30:00	2019-01-15 18:25:00	2019-01-15 18:24:02	2019-01-16 11:11:38	14	0	\N	\N
340502	MISSION	AUCUNE	\N	INFRACTIONS	\N	Auditions plénières	Auditions plénières	2019-01-17 11:10:00	2019-01-17 13:10:00	2019-01-17 15:51:24	2019-01-17 16:12:02	8	0	\N	\N
342107	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientations Mobilités" (LOM)	2019-01-15 14:00:00	2019-01-15 14:45:00	\N	\N	3	0	\N	\N
342111	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2019-01-15 14:45:00	2019-01-15 15:30:00	\N	\N	4	0	\N	\N
342116	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2019-01-16 14:30:00	2019-01-16 16:15:00	\N	\N	5	0	\N	\N
342122	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2019-01-16 16:15:00	2019-01-16 17:15:00	\N	\N	2	0	\N	\N
345100	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Désenclavement des territoires	PPL Désenclavement des territoires	2019-02-20 14:30:00	2019-02-20 16:50:00	\N	\N	111	0	\N	\N
345104	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat : L'hydrogène, une énergie d'avenir	Débat : L'hydrogène, une énergie d'avenir	2019-02-20 16:50:00	2019-02-20 18:35:00	\N	\N	55	0	\N	\N
345106	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat : Fracture numérique et inégalités d'accès aux services publics	Débat : Fracture numérique et inégalités d'accès aux services publics	2019-02-20 18:35:00	2019-02-20 20:20:00	\N	\N	54	0	\N	\N
345111	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Encadrer le démarchage téléphonique 	PPL Encadrer le démarchage téléphonique	2019-02-21 15:30:00	2019-02-21 18:30:00	\N	\N	53	0	\N	\N
345112	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Renforcer la prise en charge des cancers pédiatriques	PPL Renforcer la prise en charge des cancers pédiatriques	2019-02-21 14:30:00	2019-02-21 18:30:00	\N	\N	54	0	\N	\N
345115	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Information aux patientes sur la reconstruction mammaire en cas de mastectomie	PPL Information aux patientes sur la reconstruction mammaire en cas de mastectomie	2019-03-05 14:30:00	2019-03-05 15:25:00	\N	\N	101	0	\N	\N
244227	COM_PERMANENTE	EXAMEN	\N	CDD	\N	PPL Investissements dans les réseaux à très haut débit	\N	2018-02-06 18:00:00	2018-02-06 19:30:00	\N	\N	0	0	\N	\N
345116	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Améliorer la lutte contre l'habitat insalubre ou dangereux	PPL Améliorer la lutte contre l'habitat insalubre ou dangereux	2019-03-05 15:35:00	2019-03-06 17:35:00	\N	\N	121	0	\N	\N
345117	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Engagement associatif	PPL Engagement associatif	2019-03-06 14:30:00	2019-03-06 17:10:00	\N	\N	145	0	\N	\N
345118	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Protection des activités agricoles  et des cultures marines en zone littorale	PPL Protection des activités agricoles  et des cultures marines en zone littorale	2019-03-06 17:15:00	2019-03-06 18:35:00	\N	\N	102	0	\N	\N
345119	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Renforcement de la sécurité des sapeurs-pompiers	PPL Renforcement de la sécurité des sapeurs-pompiers	2019-03-06 18:35:00	2019-03-06 19:30:00	\N	\N	86	0	\N	\N
345120	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Lutter contre toutes les violences éducatives ordinaires	PPL Lutter contre toutes les violences éducatives ordinaires	2019-03-06 19:35:00	2019-03-06 21:10:00	\N	\N	64	0	\N	\N
345305	GIA	AUCUNE	\N	\N	\N	Entretien sur les disparitions forcées au Mexique	Entretien sur les disparitions forcées au Mexique avec Mme et M. Marquez de Favela et l'ACAT	2019-01-24 09:45:00	2019-01-24 11:15:00	\N	\N	1	0	643	\N
347044	BUREAU	AUCUNE	\N	\N	\N	Bureau du Sénat	Bureau du Sénat	2019-01-31 09:00:00	2019-01-31 11:00:00	\N	\N	23	0	\N	\N
348103	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Intelligence artificielle	Audition intelligence artificielle : Salima Benhamou	2019-01-29 15:00:00	2019-01-29 16:30:00	\N	\N	1	0	\N	\N
352538	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2019-02-13 14:30:00	2019-02-13 16:40:00	\N	\N	3	0	\N	\N
214494	QUESTURE	AUCUNE	\N	\N	\N	\N	\N	2017-10-31 14:45:00	2017-10-31 16:40:00	\N	\N	3	0	\N	\N
214501	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de finances 2018	Loi de finances 2018 (Enseignement technique agricole)	2017-10-30 14:00:00	2017-10-30 18:00:00	\N	\N	1	0	\N	\N
214503	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de finances 2018	Loi de finances 2018 (Action extérieure de l'État)	2017-10-31 09:30:00	2017-10-31 10:30:00	\N	\N	2	0	\N	\N
214506	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de finances 2018	Loi de finances 2018 (Création et transmission des savoirs)	2017-10-31 10:00:00	2017-10-31 13:00:00	\N	\N	1	0	\N	\N
214508	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de finances 2018	Loi de finances 2018 (Création et transmission des savoirs)	2017-10-31 15:00:00	2017-10-31 15:45:00	\N	\N	1	0	\N	\N
214510	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de finances 2018	Loi de finances 2018 (Enseignement supérieur)	2017-10-31 11:00:00	2017-10-31 12:00:00	\N	\N	1	0	\N	\N
214512	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de finances 2018	Loi de finances 2018 (Recherche)	2017-10-31 13:30:00	2017-10-31 16:30:00	\N	\N	1	0	\N	\N
214514	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2017-10-31 15:45:00	2017-10-31 16:45:00	\N	\N	1	0	\N	\N
214516	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2017-11-07 15:00:00	2017-11-07 16:00:00	\N	\N	1	0	\N	\N
214518	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2017-11-08 16:00:00	2017-11-08 19:00:00	\N	\N	1	0	\N	\N
214520	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2017-11-14 14:00:00	2017-11-14 16:00:00	\N	\N	1	0	\N	\N
215569	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2017-10-26 11:45:00	2017-10-26 12:00:00	\N	\N	3	0	\N	\N
221543	DELEGATION	AUCUNE	\N	\N	DSOM	Tables rondes biodiversité ultramarine	Tables rondes biodiversité ultramarine	2017-12-07 09:00:00	2017-12-07 12:15:00	2017-12-07 16:11:30	2017-12-07 16:19:42	18	0	\N	\N
226085	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI contrats aidés	MI contrats aidés	2017-11-28 14:00:00	2017-11-28 15:00:00	\N	\N	2	0	\N	\N
230027	GIA	AUCUNE	\N	\N	\N	Petit-déjeuner ambassadeur Russie	Petit-déjeuner ambassadeur Russie	2017-12-13 08:45:00	2017-12-13 10:15:00	\N	\N	8	0	608	\N
230114	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI contrats aidés	MI contrats aidés	2017-12-14 09:00:00	2017-12-14 10:30:00	\N	\N	2	0	\N	\N
232726	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Droit des sites naturels ouverts au public	\N	2017-12-20 14:00:00	2017-12-20 16:00:00	\N	\N	1	0	\N	\N
232999	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI thanatopraxie	MI thanatopraxie	2018-01-09 09:30:00	2018-01-09 12:00:00	\N	\N	1	0	\N	\N
233002	COM_EURO	AUDRAP	\N	AFEU	\N	Agences de surveillance européennes	Agences de surveillance européennes - ESMA	2018-01-09 15:30:00	2018-01-09 17:15:00	\N	\N	2	0	\N	\N
233357	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	206	Réunion des membres du Bureau de l'OPECST	Réunion des membres du Bureau de l'OPECST	2018-01-18 12:20:00	2018-01-18 12:45:00	\N	\N	4	0	\N	\N
235410	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL Convention France-Allemagne emploi transfrontalier d'aéronefs	\N	2018-01-18 14:00:00	2018-01-18 14:50:00	\N	\N	1	0	\N	\N
241266	COM_PERMANENTE	AUTRE	\N	CDD	\N	Audition de Mme Catherine de Kersauson, Présidente de la 2ème Chambre de la Cour des cptes	Audition de Mme Catherine de Kersauson, Présidente de la 2ème Chambre de la Cour des comptes	2018-02-06 09:30:00	2018-02-06 10:45:00	2018-02-06 17:21:19	2018-02-07 14:56:44	29	0	\N	\N
241267	COM_PERMANENTE	AUTRE	\N	CDD	\N	Audition  de M. Philippe Duron, Président du Conseil d¿orientation des infrastructures 	Audition  de M. Philippe Duron, Président du Conseil d¿orientation des infrastructures 	2018-02-07 10:05:00	2018-02-07 12:15:00	2018-02-07 17:44:32	2018-02-08 14:50:51	32	0	\N	\N
244149	COM_PERMANENTE	AUTRE	\N	FINC	\N	Nomination Rapp PJL DSP2 - Auditions DSP2 - Audition M. MIGAUD CPO	Nomination Rapporteur PJL DSP2 - Auditions DSP2 - Audition M. MIGAUD CPO capital ménages	2018-02-14 09:35:00	2018-02-14 12:45:00	2018-02-16 18:10:02	2018-02-16 18:45:01	39	0	\N	\N
244151	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de M. HEYER pour nomination au Haut Conseil des finances publiques par le Préside	Audition de M. HEYER pour nomination au Haut Conseil des finances publiques par le Président de la commission 	2018-02-13 09:35:00	2018-02-13 10:30:00	2018-02-14 14:13:02	2018-02-14 17:03:30	32	0	\N	\N
244220	AUTRE_TEMPORAIRE	CONTROLE	\N	\N	\N	MI ALSTOM - Audition président&rapporteur	\N	2018-02-07 14:30:00	2018-02-07 16:30:00	\N	\N	0	0	\N	\N
244224	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	\N	\N	2018-02-06 14:30:00	2018-02-06 16:30:00	\N	\N	0	0	\N	\N
244226	AUTRE_TEMPORAIRE	AUTRE_NON_PLENIERE	\N	\N	\N	\N	\N	2018-02-06 15:30:00	2018-02-06 16:30:00	\N	\N	0	0	\N	\N
244232	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL THD Numérique	PPL THD Numérique	2018-02-07 14:30:00	2018-02-07 15:30:00	\N	\N	2	0	\N	\N
244233	AUTRE_TEMPORAIRE	AUTRE_NON_PLENIERE	\N	\N	\N	\N	\N	2018-02-07 14:30:00	2018-02-07 16:30:00	\N	\N	0	0	\N	\N
244236	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL THD Numérique	PPL THD Numérique	2018-02-08 15:00:00	2018-02-08 16:00:00	\N	\N	2	0	\N	\N
244239	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	CAE	\N	\N	\N	2018-02-06 09:00:00	2018-02-06 10:00:00	\N	\N	0	0	\N	\N
244240	AUTRE_TEMPORAIRE	CONTROLE	\N	\N	\N	MI ALSTOM - Auditions président et rapporteur	\N	2018-02-06 14:30:00	2018-02-06 16:30:00	\N	\N	0	0	\N	\N
253502	DELEGATION	AUCUNE	\N	\N	DSOM	Visioconférence Wallis-et-Futuna (risques naturels majeurs)	Visioconférence Wallis-et-Futuna (risques naturels majeurs)	2018-03-13 08:30:00	2018-03-13 10:30:00	2018-03-13 10:48:38	2018-03-13 13:59:10	5	0	\N	\N
253540	DELEGATION	AUCUNE	\N	\N	DSOM	Audiditons Étude sur les risques naturels majeurs	Audiditons Étude sur les risques naturels majeurs	2018-03-13 18:00:00	2018-03-13 20:20:00	2018-03-14 14:50:02	2018-03-14 15:41:41	7	0	\N	\N
253546	DELEGATION	AUCUNE	\N	\N	DSOM	Visioconférences La Réunion - Mayotte (risques naturels majeurs)	Visioconférences La Réunion - Mayotte (risques naturels majeurs)	2018-03-15 08:30:00	2018-03-15 10:40:00	2018-03-15 11:34:43	2018-03-15 11:57:43	5	0	\N	\N
258881	GIA	AUCUNE	\N	\N	\N	Petit-déjeuner de l'AIFC à l'AN	Petit-déjeuner de l'Association Interparlementaire France-Canada à l'Assemblée nationale	2018-02-22 08:00:00	2018-02-22 09:30:00	\N	\N	1	0	583	\N
259071	DELEGATION	AUDRAP	\N	\N	206	Audition de la Caisse centrale de la Mutualité sociale agricole	Audition de la Caisse centrale de la Mutualité sociale agricole	2018-04-12 15:00:00	2018-04-12 16:00:00	\N	\N	2	0	\N	\N
259072	DELEGATION	AUDRAP	\N	\N	206	Audition de l'INERIS	Audition de l'Institut national de l'environnement industriel et des risques (INERIS)	2018-04-12 16:15:00	2018-04-12 17:15:00	\N	\N	2	0	\N	\N
259073	DELEGATION	AUDRAP	\N	\N	206	Audition ATMO France	Audition de la Fédération des associations de surveillance de la qualité de l'air - ATMO France	2018-04-12 17:15:00	2018-04-12 18:15:00	\N	\N	1	0	\N	\N
259074	DELEGATION	AUDRAP	\N	\N	206	Audition de Mme Annie Martin, juriste chargée de recherches au CNRS	Audition de Mme Annie Martin, juriste chargée de recherches au CNRS	2018-04-16 14:30:00	2018-04-16 15:30:00	\N	\N	1	0	\N	\N
259075	DELEGATION	AUDRAP	\N	\N	206	Audition du CNRS	Audition du Centre national de la recherche scientifique (CNRS)	2018-04-16 15:30:00	2018-04-16 16:30:00	\N	\N	1	0	\N	\N
279501	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Mission réflexion FPT	Mission de réflexion sur les enjeux de l'évolution de la fonction publique territoriale	2018-05-30 18:30:00	2018-05-30 19:45:00	\N	\N	1	0	\N	\N
279503	MISSION	AUCUNE	\N	ALSTOM	\N	Réunion d'adoption du rapport final de la mission volet "stratégie industrielle"	Réunion d'adoption du rapport final de la mission portant sur le volet "stratégie industrielle"	2018-06-06 13:15:00	2018-06-06 14:35:00	2018-06-06 16:54:00	2018-06-07 18:48:49	15	1	\N	\N
280853	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Utilisation des caméras mobiles	\N	2018-05-29 14:15:00	2018-05-29 15:00:00	\N	\N	1	0	\N	\N
280855	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Utilisation des caméras mobiles	\N	2018-05-29 17:45:00	2018-05-29 19:15:00	\N	\N	1	0	\N	\N
280857	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Utilisation des caméras mobiles	\N	2018-05-30 14:30:00	2018-05-30 16:45:00	\N	\N	1	0	\N	\N
287543	BUREAU	AUCUNE	\N	\N	\N	Délégation statut et conditions d'exercice du mandat de sénateur	Délégation statut et conditions d'exercice du mandat de sénateur	2018-06-20 11:30:00	2018-06-20 11:45:00	\N	\N	4	0	\N	\N
293670	GIA	AUCUNE	\N	\N	\N	Diver, CPS	Rencontre avec M. Cameron Diver, DG adjoint de la Communauté du Pacifique	2018-07-05 08:15:00	2018-07-05 09:30:00	\N	\N	6	0	651	\N
294986	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2018-07-11 11:35:00	2018-07-11 12:50:00	2018-07-11 15:05:15	2018-07-11 15:11:33	31	0	\N	\N
321055	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2019 - Examen Rapports Pouvoirs Publics-Outre-Mer-PFE-Travail et Emploi	PLF pour 2019 - Examen Rapports Pouvoirs Publics-Outre-Mer-PFE-Travail et Emploi	2018-11-14 14:35:00	2018-11-14 17:20:00	2018-11-14 17:49:24	2018-11-14 17:59:13	29	0	\N	\N
321749	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Contrôle et exploitation aériens - ADP / CEREMA	PLF pour 2019 - Contrôle et exploitation aériens - ADP / CEREMA	2018-11-06 18:00:00	2018-11-06 20:00:00	\N	\N	1	0	\N	\N
321751	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Écologie/Transports - SNCF Réseau	PLF pour 2019 - Écologie/Transports - SNCF Réseau	2018-11-07 08:30:00	2018-11-07 09:30:00	\N	\N	1	0	\N	\N
321753	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Contrôle et exploitation aériens - DGAC	PLF pour 2019 - Contrôle et exploitation aériens - DGAC	2018-11-08 17:00:00	2018-11-08 18:30:00	\N	\N	1	0	\N	\N
321755	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Travail et emploi - CFE-CGC AFPA	PLF pour 2019 - Travail et emploi - CFE-CGC AFPA	2018-11-05 14:00:00	2018-11-05 14:45:00	\N	\N	1	0	\N	\N
321757	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Travail et emploi - Syndicats AFPA	PLF pour 2019 - Travail et emploi - Syndicats AFPA	2018-11-07 16:30:00	2018-11-07 17:45:00	\N	\N	2	0	\N	\N
321760	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Déplacement CEF St Brice sous Forêt	\N	2018-11-07 15:15:00	2018-11-07 18:15:00	\N	\N	1	0	\N	\N
321762	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Participations Financières de l'État - APE	PLF pour 2019 - Participations Financières de l'État - APE	2018-11-06 08:00:00	2018-11-06 10:00:00	\N	\N	1	0	\N	\N
321764	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL 730 Désertification bancaire - Fédération bancaire française / Groupe La Poste 	PPL 730 Désertification bancaire - Fédération bancaire française / Groupe La Poste 	2018-11-06 18:00:00	2018-11-06 20:00:00	\N	\N	1	0	\N	\N
321780	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Écologie/Énergie - FNH	PLF pour 2019 - Écologie/Énergie - FNH	2018-11-06 14:30:00	2018-11-06 15:30:00	\N	\N	1	0	\N	\N
294985	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2018-07-11 10:50:00	2018-07-11 11:35:00	2018-07-11 15:04:41	2018-07-11 15:11:32	31	0	\N	\N
295308	COM_PERMANENTE	AUTRE	\N	FINC	\N	Candidats CMP- Examen Rapport DOFP et Controles Budget. Aff Euro-Défense-Travail Emploi	Candidats CMP - Examen Rapport DOFP et Controles Budget. Aff Euro-Défense-Travail Emploi	2018-07-11 09:05:00	2018-07-11 11:50:00	2018-07-11 16:42:48	2018-07-11 17:37:32	34	0	\N	\N
321782	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Écologie/énergie - ADEME	PLF pour 2019 - Écologie/énergie - ADEME	2018-11-08 11:00:00	2018-11-08 12:00:00	\N	\N	1	0	\N	\N
321784	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Écologie/énergie - DGALN	PLF pour 2019 - Écologie/énergie - DGALN	2018-11-08 17:00:00	2018-11-08 18:00:00	\N	\N	1	0	\N	\N
321786	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Rapport Général - Ministre chargé des relations avec le parlement	PLF pour 2019 - Rapport Général - Ministre chargé des relations avec le parlement	2018-11-08 17:10:00	2018-11-08 17:50:00	\N	\N	1	0	\N	\N
321788	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Examen amendements PLFSS 2019	\N	2018-11-12 20:00:00	2018-11-12 21:05:00	2018-11-12 21:08:55	2018-11-13 16:46:32	31	0	\N	\N
321789	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Suite examen amendements PLFSS 2019	\N	2018-11-13 09:30:00	2018-11-13 10:30:00	2018-11-13 10:30:17	2018-11-13 16:46:34	34	0	\N	\N
321790	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Suite examen amendements PLFSS 2019	\N	2018-11-13 13:30:00	2018-11-13 14:30:00	2018-11-13 16:44:57	2018-11-13 16:46:35	34	0	\N	\N
321791	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Suite examen amendements PLFSS 2019	\N	2018-11-13 19:35:00	2018-11-13 20:25:00	2018-11-15 15:52:12	2018-11-15 15:58:08	42	0	\N	\N
321818	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2019 Mission solidarité	\N	2018-11-15 14:00:00	2018-11-15 15:00:00	\N	\N	1	0	\N	\N
321820	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2019 - Conseil et contrôle de l'Etat	PLF pour 2019 - Conseil et contrôle de l'Etat	2018-11-16 08:30:00	2018-11-16 09:45:00	\N	\N	1	0	\N	\N
321822	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PLF 2019 - Audition de Mme Jacqueline Gourault et M. Sébastien Lecornu	Audition de Mme Jacqueline Gourault et M. Sébastien Lecornu	2018-11-14 17:00:00	2018-11-14 18:55:00	2018-11-14 19:01:28	2018-11-15 14:56:19	23	0	\N	\N
321832	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	LOIS	\N	Colloque sur la revitalisation de l'échelon communal	\N	2018-11-15 14:30:00	2018-11-15 18:50:00	\N	\N	13	0	\N	\N
321839	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Réunion constitutive	\N	2018-11-15 09:15:00	2018-11-15 10:00:00	\N	\N	0	0	\N	\N
321859	ETUDES	AUCUNE	\N	\N	\N	\N	\N	2018-11-08 13:30:00	2018-11-08 14:40:00	\N	\N	17	0	\N	909
321877	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-11-07 09:30:00	2018-11-07 11:30:00	\N	\N	5	0	\N	\N
321883	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-11-08 09:30:00	2018-11-08 10:15:00	\N	\N	2	0	\N	\N
321886	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-11-08 10:15:00	2018-11-08 11:00:00	\N	\N	3	0	\N	\N
321890	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-11-08 11:00:00	2018-11-08 11:30:00	\N	\N	4	0	\N	\N
321895	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-11-08 11:30:00	2018-11-08 12:00:00	\N	\N	1	0	\N	\N
321898	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Examen de la motion PLFSS 2019	\N	2018-11-12 15:50:00	2018-11-12 16:00:00	2018-11-12 16:00:21	2018-11-12 17:51:29	24	0	\N	\N
322082	COM_EURO	DEPLACEMENT	\N	AFEU	\N	ROME-12-13 novembre 2018	ROME-12-13 novembre 2018	2018-11-12 08:00:00	2018-11-13 22:00:00	\N	\N	5	0	\N	\N
322213	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière - Audition publique Arrêt véhicules thermiques	Réunion plénière - Audition publique Arrêt véhicules thermiques	2018-11-29 10:05:00	2018-11-29 13:00:00	2018-11-29 14:59:08	\N	5	0	\N	\N
322214	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière - Examen note scientifique - Réunion avec Conseil scientifique	Réunion plénière -  Examen note scientifique -Examen conclusions audition publique 5G -Réunion avec Conseil scientifique	2018-12-06 10:05:00	2018-12-06 13:30:00	2018-12-06 15:52:35	\N	10	0	\N	\N
322776	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLF pour 2019 - Mission Administration pénitentiaire	\N	2018-11-13 14:30:00	2018-11-13 16:45:00	\N	\N	1	0	\N	\N
323264	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2018-11-07 19:35:00	2018-11-07 20:15:00	\N	\N	24	0	\N	\N
214618	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour  2018 - Engagements financiers de l'Etat	PLF pour  2018 - Engagements financiers de l'Etat - Assemblée Nationale co rapporteurs de la mission	2017-11-02 11:00:00	2017-11-02 12:00:00	\N	\N	1	0	\N	\N
214621	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Écologie, développement et mobilité durables/Énergie	PLF pour 2018 - Écologie, développement et mobilité durables/Énergie - DGALN	2017-10-31 13:30:00	2017-10-31 14:30:00	\N	\N	1	0	\N	\N
217177	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions GT Infractions sexuelles	GT Infractions sexuelles	2017-11-09 10:00:00	2017-11-09 12:50:00	\N	\N	7	0	\N	\N
223615	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2018 (Développement des entreprises)	\N	2017-11-22 14:30:00	2017-11-22 18:30:00	\N	\N	1	0	\N	\N
223617	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2018 (Développement des entreprises)	\N	2017-11-23 11:00:00	2017-11-23 12:00:00	\N	\N	1	0	\N	\N
223619	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2018 (Développement des entreprises)	\N	2017-11-23 14:00:00	2017-11-23 15:00:00	\N	\N	1	0	\N	\N
226089	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPRE Pérenniser la procédure de législation en commission	\N	2017-11-30 12:15:00	2017-11-30 12:35:00	\N	\N	1	0	\N	\N
226092	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPRE Pérenniser la procédure de législation en commission	\N	2017-11-30 16:00:00	2017-11-30 16:20:00	\N	\N	1	0	\N	\N
226095	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPRE Pérenniser la procédure de législation en commission	\N	2017-12-01 09:40:00	2017-12-01 10:00:00	\N	\N	1	0	\N	\N
237642	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe	assemblée générale	2018-01-23 14:00:00	2018-01-23 14:30:00	\N	\N	2	0	586	\N
239773	GIA	AUCUNE	\N	\N	\N	Assemblée générale	Assemblée générale reconstitutive	2018-01-30 14:00:00	2018-01-30 14:30:00	\N	\N	8	0	534	\N
241126	GIA	AUCUNE	\N	\N	\N	Assemblée générale	Assemblée générale constitutive	2018-01-31 14:00:00	2018-01-31 14:20:00	\N	\N	10	0	618	\N
241163	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Organisation des Jeux Olympiques et Paralympiques de 2024	\N	2018-02-06 09:00:00	2018-02-06 09:20:00	2018-02-06 17:59:20	2018-02-07 14:57:10	17	1	\N	\N
241176	COM_PERMANENTE	AUTRE	\N	LOIS	\N	GT sur les infractions sexuelles à l'encontre des mineurs	GT sur les infractions sexuelles à l'encontre des mineurs	2018-02-07 11:00:00	2018-02-07 12:40:00	2018-02-07 19:07:47	2018-02-09 17:01:00	33	0	\N	\N
241194	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Outre-mer 2018 - Service militaire adapté	Contrôle Outre-mer 2018 - Service militaire adapté - Audition SMA	2018-02-02 14:00:00	2018-02-02 15:30:00	\N	\N	2	0	\N	\N
331610	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Sécurité des ponts	\N	2018-11-29 10:20:00	2018-11-29 13:00:00	\N	\N	8	0	\N	\N
321792	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Suite examen amendements PLFSS 2019 et examen avis Mildéca	\N	2018-11-14 09:35:00	2018-11-14 11:50:00	2018-11-14 11:52:13	2018-11-14 12:15:59	44	0	\N	\N
241173	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJLO Accession à la pleine souveraineté de la Nouvelle-Calédonie	\N	2018-02-07 09:40:00	2018-02-07 11:00:00	2018-02-07 19:06:57	2018-02-08 14:48:09	44	0	\N	\N
241197	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Outre-mer 2018 - Service militaire adapté	Contrôle Outre-mer 2018 - Service militaire adapté - Audition DGOM	2018-02-02 16:00:00	2018-02-02 17:00:00	\N	\N	2	0	\N	\N
241205	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation de la ville de Marioupol	\N	2018-01-30 16:15:00	2018-01-30 17:30:00	\N	\N	4	0	530	\N
241210	GIA	AUCUNE	\N	\N	\N	Accueil de représentantes de familles de disparus du conflit à l'Est de l'Ukraine	\N	2018-01-31 18:00:00	2018-01-31 18:30:00	\N	\N	2	0	530	\N
244909	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Réussite édudiants	PJL Réussite édudiants	2018-02-07 21:30:00	2018-02-07 23:55:00	\N	\N	60	0	\N	\N
254993	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 15 mars 2018	Réunion de la commission des affaires européennes du 15 mars 2018	2018-03-15 08:35:00	2018-03-15 10:10:00	2018-03-15 11:17:12	2018-03-15 11:58:04	16	0	\N	\N
255595	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Conclusions CMP  PJL  Jeux Olympiques et paralympiques 2024	Conclusions CMP  PJL  Jeux Olympiques et paralympiques 2024	2018-03-15 10:30:00	2018-03-15 11:40:00	\N	\N	45	0	\N	\N
259095	COM_ENQUETE	PLENIERE	\N	FORCES	\N	CE FSI	CE FSI	2018-03-27 14:15:00	2018-03-27 16:30:00	2018-03-28 17:27:58	2018-03-28 17:31:11	10	0	\N	\N
260496	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Transport ferroviaire	PPL Transport ferroviaire	2018-03-28 21:30:00	2018-03-29 00:30:00	\N	\N	62	0	\N	\N
260612	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	\N	GT Financement du handicap	2018-04-17 15:00:00	2018-04-17 19:00:00	\N	\N	1	0	\N	\N
260615	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	\N	GT Financement du handicap	2018-04-18 16:00:00	2018-04-18 18:00:00	\N	\N	1	0	\N	\N
260621	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	\N	GT Financement du handicap	2018-05-02 14:00:00	2018-05-02 19:00:00	\N	\N	1	0	\N	\N
261091	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2018-04-04 09:30:00	2018-04-04 12:10:00	2018-04-04 14:45:02	2018-04-04 15:03:46	35	0	\N	\N
261092	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2018-04-04 15:00:00	2018-04-04 16:55:00	2018-04-04 17:21:02	2018-04-04 17:51:28	29	1	\N	\N
261301	COM_PERMANENTE	DEPLACEMENT	\N	AFCL	\N	Bordeaux (GT France3/France Bleu)	Bordeaux (GT France3/FranceBleu)	2018-03-23 09:00:00	2018-03-23 19:00:00	\N	\N	8	0	\N	\N
261311	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Mission Établissements publics de coopération culturelle	Mission Établissements publics de coopération culturelle	2018-03-28 16:45:00	2018-03-28 17:45:00	\N	\N	2	0	\N	\N
262806	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2018-04-04 14:30:00	2018-04-04 15:30:00	\N	\N	1	0	\N	\N
262809	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2018-04-04 16:00:00	2018-04-04 17:00:00	\N	\N	1	0	\N	\N
264113	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	LPM 2019-2025	\N	2018-04-03 11:45:00	2018-04-03 12:45:00	\N	\N	2	0	\N	\N
264120	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	LPM 2019-2025	Versailles-Satory	2018-04-03 12:30:00	2018-04-03 17:00:00	\N	\N	2	0	\N	\N
264123	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	LPM 2019-2025	\N	2018-04-05 10:30:00	2018-04-05 11:30:00	\N	\N	2	0	\N	\N
264126	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	LPM 2019-2025	\N	2018-04-05 11:30:00	2018-04-05 12:30:00	\N	\N	2	0	\N	\N
266083	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GS Brexit - Audition de Mme Sandrine Gaudin, SGAE	GS Brexit - Audition de Mme Sandrine Gaudin, SGAE	2018-04-10 15:35:00	2018-04-10 16:45:00	\N	\N	13	0	\N	\N
268761	GIA	AUCUNE	\N	\N	\N	Entretien avec l'Ambassadeur des Pays-Bas	Entretien avec M. Pieter de GOOIJER, Ambassadeur des Pays-Bas	2018-04-18 08:30:00	2018-04-18 09:30:00	\N	\N	3	0	599	\N
268765	GIA	AUCUNE	\N	\N	\N	Accueil d'étudiants néerlandais de l'Université d'Utrecht	Accueil d'étudiants néerlandais de l'Université d'Utrecht	2018-04-18 16:00:00	2018-04-18 17:00:00	\N	\N	1	0	599	\N
273857	MISSION	AUDRAP	\N	ALSTOM	\N	MI ALSTOM - Auditions président&rapporteur	\N	2018-05-22 16:00:00	2018-05-22 17:00:00	\N	\N	4	0	\N	\N
279251	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen Rapport pour Avis PPL 460 centres-villes et centres-bourgs	Examen Rapport pour Avis PPL 460 centres-villes et centres-bourgs	2018-06-05 09:05:00	2018-06-05 10:25:00	2018-06-05 15:08:55	2018-06-05 16:31:08	28	0	\N	\N
279252	COM_PERMANENTE	AUTRE	\N	FINC	\N	Suite Examen Rapport pour Avis PPL 460 centres-villes et centres-bourgs	Suite Examen Rapport pour Avis PPL 460 centres-villes et centres-bourgs	2018-06-05 18:05:00	2018-06-05 18:40:00	2018-06-06 09:50:05	2018-06-06 12:29:33	25	0	\N	\N
279256	COM_PERMANENTE	AUTRE	\N	FINC	\N	Auditions sur PJL lutte contre la fraude DGFiP	Auditions sur PJL lutte contre la fraude DGFiP	2018-06-06 15:05:00	2018-06-06 17:00:00	2018-06-29 15:56:02	2018-06-29 15:56:04	26	0	\N	\N
279270	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Programmes d'investissement d'avenir (PIA) - Secrétaire général pour l'investissement	Programmes d'investissement d'avenir (PIA) - Secrétaire général pour l'investissement	2018-05-29 18:00:00	2018-05-29 19:00:00	\N	\N	1	0	\N	\N
279278	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Commission nationale des comptes de campagne et des financements politiques	Commission nationale des comptes de campagne et des financements politiques - CNCCFP et ANTS	2018-05-29 09:00:00	2018-05-29 11:30:00	\N	\N	1	0	\N	\N
279280	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Réforme des retraites  - Conseil d'orientation des retraites (COR)	Contrôle Réforme des retraites - Conseil d'orientation des retraites (COR)	2018-05-29 14:45:00	2018-05-29 15:45:00	\N	\N	1	0	\N	\N
279302	COM_ENQUETE	PLENIERE	\N	HAUTE	\N	Audition	Audition	2018-05-30 15:30:00	2018-05-30 16:30:00	2018-06-01 17:13:10	2018-06-01 17:16:00	8	0	\N	\N
278243	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Métier d'enseignant	Métier d'enseignant	2018-05-30 14:30:00	2018-05-30 15:30:00	\N	\N	2	0	\N	\N
278766	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion de commission du 31 mai 2018	Réunion de commission du 31 mai 2018	2018-05-31 08:35:00	2018-05-31 09:50:00	2018-05-31 10:27:58	2018-05-31 14:30:06	16	0	\N	\N
284524	GIA	AUCUNE	\N	\N	\N	Rencontre avec SEM. Emil DRUC, Ambassadeur de Moldavie en France	Rencontre avec SEM. Emil DRUC, Ambassadeur de Moldavie en France	2018-06-12 20:00:00	2018-06-12 21:30:00	\N	\N	2	0	851	\N
294519	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Mission Mécénat	Mission Mécénat	2018-07-03 15:30:00	2018-07-03 18:40:00	\N	\N	5	0	\N	\N
294527	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Mission Mécénat	Mission Mécénat	2018-07-04 15:00:00	2018-07-04 17:00:00	\N	\N	2	0	\N	\N
294533	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Passe Culture	Groupe de travail Passe Culture	2018-07-03 14:30:00	2018-07-03 15:30:00	\N	\N	4	0	\N	\N
295817	GIA	AUCUNE	\N	\N	\N	Dîner avec l'ambassadeur de Suède	Dîner avec l'ambassadeur de Suède	2018-07-03 19:45:00	2018-07-03 22:15:00	\N	\N	8	0	625	\N
298792	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Métier d'enseignant	\N	2018-07-11 08:45:00	2018-07-11 09:45:00	\N	\N	2	0	\N	\N
331602	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Entraves à des libertés, à des évènements et activités légales	\N	2018-11-29 09:45:00	2018-11-29 11:30:00	\N	\N	1	0	\N	\N
331603	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	PJL Croissance et transformation des entreprises	\N	2018-11-29 09:00:00	2018-11-29 11:30:00	\N	\N	1	0	\N	\N
337672	COM_EURO	AUDRAP	\N	AFEU	\N	Parquet européen - DACG	Parquet européen	2018-12-12 17:05:00	2018-12-12 18:20:00	\N	\N	1	0	\N	\N
337676	COM_PERMANENTE	AUTRE	\N	LOIS	\N	CMP - PROG Programmation 2018-2022 et réforme pour la justice	CMP - PROG Programmation 2018-2022 et réforme pour la justice	2018-12-13 09:10:00	2018-12-13 09:50:00	2018-12-13 15:20:38	2018-12-13 15:51:09	9	0	\N	\N
337680	COM_PERMANENTE	AUTRE	\N	LOIS	\N	CMP - PJLO Renforcement de l'organisation des juridictions	CMP - PJLO Renforcement de l'organisation des juridictions	2018-12-13 09:50:00	2018-12-13 10:00:00	2018-12-13 15:20:30	2018-12-13 15:51:12	9	0	\N	\N
337744	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Handicap dans la fonction publique	\N	2018-12-12 17:00:00	2018-12-12 19:30:00	\N	\N	3	0	\N	\N
341604	DELEGATION	AUCUNE	\N	\N	211	Table ronde sur la parité dans les intercommunalités	Table ronde sur la parité dans les intercommunalités	2019-01-17 08:30:00	2019-01-17 10:45:00	2019-01-17 16:29:40	2019-01-17 16:46:47	11	0	\N	\N
343151	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL PPL AN RECUE DE SOLON	PPL PPL AN RECUE DE SOLON	2019-01-21 09:15:00	2019-01-21 12:00:00	\N	\N	1	0	\N	\N
344968	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2019-01-23 14:30:00	2019-01-23 16:40:00	\N	\N	3	0	\N	\N
345546	MECSS	AUDRAP	\N	\N	MECSS	Prise en charge financière de la dépendance des personnes âgées	\N	2019-01-30 12:00:00	2019-01-30 13:00:00	\N	\N	2	0	\N	\N
345576	MECSS	AUDRAP	\N	\N	MECSS	Prise en charge financière de la dépendance des personnes âgées	\N	2019-01-30 17:00:00	2019-01-30 19:15:00	\N	\N	4	0	\N	\N
350813	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Examen du rapport PPL Mastectomie	\N	2019-02-14 13:50:00	2019-02-14 14:50:00	2019-02-14 14:53:05	2019-02-14 16:05:54	32	0	\N	\N
350814	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition-Association nationale des élus du littoral	Audition de représentants de l'Association nationale des élus du littoral	2019-02-05 17:45:00	2019-02-05 19:00:00	\N	\N	1	0	\N	\N
350815	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition-Comité national de la conchyliculture	Audition de représentants du Comité national de la conchyliculture	2019-02-06 15:00:00	2019-02-06 16:15:00	\N	\N	1	0	\N	\N
350820	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Situation de l'Office national des forêts	Situation de l'Office national des forêts - Audition de représentants de la DGALN, ministère de la transition écologique	2019-02-06 15:30:00	2019-02-06 17:30:00	\N	\N	1	0	\N	\N
350824	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Faciliter le désenclavement des territoires	PPL Faciliter le désenclavement des territoires - Audition de représentants de l'ADF	2019-02-07 15:30:00	2019-02-07 16:15:00	\N	\N	1	0	\N	\N
350838	MISSION	AUCUNE	\N	INFRACTIONS	\N	Conférence des Évêques de France	Conférence des Évêques de France	2019-02-12 16:30:00	2019-02-12 18:00:00	2019-02-12 18:22:20	2019-02-13 16:52:42	14	0	\N	\N
350839	MISSION	AUCUNE	\N	INFRACTIONS	\N	Fédération protestante de France	\N	2019-02-14 11:05:00	2019-02-14 12:00:00	2019-02-14 12:14:07	2019-02-14 16:07:09	8	0	\N	\N
350840	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Bioéthique	\N	2019-02-14 09:30:00	2019-02-14 11:30:00	\N	\N	4	0	\N	\N
350842	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Bioéthique	\N	2019-02-20 15:30:00	2019-02-20 17:00:00	\N	\N	6	0	\N	\N
355196	GIA	AUCUNE	\N	\N	\N	Entretien de JM. BOCKEL avec M. Cheick Oumar SOUMANO, Juriste d'affaires malien (coopé)	Entretien de JM. BOCKEL avec M. Cheick Oumar SOUMANO, Juriste d'affaires malien (coopé)	2019-02-19 17:45:00	2019-02-19 18:30:00	\N	\N	1	0	573	\N
355595	GIA	AUCUNE	\N	\N	\N	déjeuner avec Tom Brake membre de la Chambre des Communes	déjeuner avec Tom Brake membre de la Chambre des Communes	2019-02-19 12:45:00	2019-02-19 14:30:00	\N	\N	6	0	581	\N
355641	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Bioéthique	\N	2019-03-06 15:15:00	2019-03-06 16:00:00	\N	\N	7	0	\N	\N
355723	MECSS	AUDRAP	\N	\N	MECSS	Prise en charge financière de la dépendance des personnes âgées	\N	2019-03-12 13:30:00	2019-03-12 16:00:00	\N	\N	3	0	\N	\N
355794	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 21 février 2019	Réunion de la commission des affaires européennes du 21 février 2019	2019-02-21 08:35:00	2019-02-21 11:30:00	2019-02-21 12:57:49	2019-02-21 17:54:40	20	0	\N	\N
356228	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	\N	\N	2019-03-05 16:45:00	2019-03-05 17:45:00	\N	\N	0	0	\N	\N
356229	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	\N	\N	2019-03-14 09:30:00	2019-03-14 10:15:00	\N	\N	0	0	\N	\N
356230	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	\N	\N	2019-03-14 10:15:00	2019-03-14 11:00:00	\N	\N	0	0	\N	\N
356237	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2019-03-07 10:00:00	2019-03-07 11:00:00	\N	\N	0	0	\N	\N
356267	DELEGATION	AUCUNE	\N	\N	DSOM	Audition du président de LCP Assemblée nationale	Audition du président de LCP Assemblée nationale	2019-03-07 09:00:00	2019-03-07 10:30:00	\N	\N	9	0	\N	\N
356272	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 7 mars 2019	Réunion du 7 mars 2019	2019-03-07 09:35:00	2019-03-07 11:00:00	2019-03-07 14:56:16	2019-03-07 16:08:33	22	0	\N	\N
356291	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Orientation des mobilités	PJL Orientation des mobilités	2019-03-28 14:30:00	2019-03-28 18:25:00	\N	\N	77	0	\N	\N
356293	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat suite Conseil européen des 21 et 22 mars 2019	Débat suite Conseil européen des 21 et 22 mars 2019	2019-04-02 16:15:00	2019-04-02 18:15:00	\N	\N	110	0	\N	\N
214498	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2018 - Programme 129	\N	2017-10-31 10:00:00	2017-10-31 12:30:00	\N	\N	2	0	\N	\N
337877	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2019 - Examen Rapport en Nlle Lecture	PLF pour 2019 - Examen Rapport en Nlle Lecture	2018-12-19 11:05:00	2018-12-19 11:55:00	2018-12-19 14:03:11	2018-12-19 17:46:40	37	0	\N	\N
350812	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Examen du rapport PPL Prise en charge des cancers pédiatriques	\N	2019-02-13 09:30:00	2019-02-13 10:15:00	2019-02-13 10:16:16	2019-02-13 16:52:10	45	0	\N	\N
356254	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-03-06 10:05:00	2019-03-06 10:25:00	2019-03-06 12:24:40	2019-03-06 16:49:16	41	0	\N	\N
356273	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Améliorer la lisibilité du droit - Examen rapport et texte de la commission (LEC)	\N	2019-03-06 11:00:00	2019-03-06 12:30:00	2019-03-06 15:11:21	2019-03-06 16:49:14	35	1	\N	\N
220463	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	\N	Déplacement PLF 2018 avis Justice à Evry	2017-11-16 09:30:00	2017-11-16 17:30:00	\N	\N	1	0	\N	\N
220465	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	\N	Déplacement PLF 2018 avis Justice Béthune	2017-11-17 08:00:00	2017-11-17 19:00:00	\N	\N	1	0	\N	\N
235988	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Sport	PLF pour 2019 - Sport - Audition Syndicat Première lligue	2018-01-17 14:00:00	2018-01-17 15:30:00	\N	\N	1	0	\N	\N
235990	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle CAS "Gestion du patrimoine immobilier de l'Etat"	Contrôle CAS "Gestion du patrimoine immobilier de l'Etat" - Audition gouvernement du Québec	2018-01-18 14:00:00	2018-01-18 15:00:00	\N	\N	2	0	\N	\N
237860	GIA	AUCUNE	\N	\N	\N	Rencontre avec Mgr Boutros Marayati, archevêque catholique arménien d'Alep	Rencontre avec Mgr Boutros Marayati, archevêque catholique arménien d'Alep	2018-01-24 12:00:00	2018-01-24 14:30:00	\N	\N	5	0	644	\N
245659	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ambassadeur de France en Angola	Entretien avec l'ambassadeur de France en Angola	2018-02-13 15:00:00	2018-02-13 16:00:00	\N	\N	5	0	646	\N
246117	GIA	AUCUNE	\N	\N	\N	Réunion avec des experts russes sur l'élection présidentielle en Russie 	Réunion avec des experts russes sur l'élection présidentielle en Russie 	2018-02-14 14:30:00	2018-02-14 16:00:00	\N	\N	13	0	608	\N
246131	GIA	AUCUNE	\N	\N	\N	Audience donnée au ministre-représentant de la République du Tatarstan en France	Audience donnée au ministre-représentant de la République du Tatarstan en France	2018-02-14 16:00:00	2018-02-14 17:00:00	\N	\N	1	0	608	\N
249648	GIA	AUCUNE	\N	\N	\N	Entretiens avec Mgr Gollnisch et M. Michel Vartron	Entretiens avec Mgr Gollnisch et M. Michel Vartron	2018-02-21 14:30:00	2018-02-21 16:45:00	\N	\N	17	0	CHRETORIENT	CHRETORIENT
253068	DELEGATION	AUDRAP	\N	\N	206	Audition de l'OCDE	Audition de M. Robert Diderich, chef de division à la direction de l'environnement	2018-03-26 14:30:00	2018-03-26 15:30:00	\N	\N	2	0	\N	\N
253069	DELEGATION	AUDRAP	\N	\N	206	Audition de l'INSERM	Audition de M. Yves Lévy, président-directeur général	2018-03-26 15:30:00	2018-03-26 16:30:00	\N	\N	2	0	\N	\N
253070	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Jean-Noël Jouzel, sociologue, Sciences-Po	Audition de M. Jean-Noël Jouzel, sociologue, Sciences-Po	2018-03-26 16:30:00	2018-03-26 17:30:00	\N	\N	2	0	\N	\N
255999	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ambassadeur du Mexique en France	Entretien avec S.E.M. Juan Manuel Gomez Robledo, ambassadeur du Mexique en France	2018-03-14 14:00:00	2018-03-14 15:00:00	\N	\N	3	0	643	\N
256005	GIA	AUCUNE	\N	\N	\N	entretien avec une délégation de la Chambre des Représentants 	entretien avec une délégation sur le thème de la lutte contre les violences faites aux femmes 	2018-03-15 10:20:00	2018-03-15 11:15:00	\N	\N	1	0	653	\N
256007	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2018-03-20 16:45:00	2018-03-20 17:50:00	\N	\N	298	0	\N	\N
259089	COM_ENQUETE	PLENIERE	\N	FORCES	\N	Auditions CE FSI	Auditions CE FSI 	2018-03-28 16:10:00	2018-03-28 17:15:00	2018-03-28 18:21:37	2018-03-29 09:14:35	6	0	\N	\N
262265	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Ziad Msallati (Croissant-Rouge arabe syrien)	Entretien avec M. Ziad Msallati (Croissant-Rouge arabe syrien)	2018-04-04 08:30:00	2018-04-04 09:30:00	\N	\N	8	0	644	\N
262332	GIA	AUCUNE	\N	\N	\N	Audition directrice Europe continentale au MAE	Petit-déjeuner avec Mme Florence Mangin, directrice Europe continentale au ministère des affaires étrangères	2018-04-04 08:30:00	2018-04-04 09:25:00	\N	\N	3	0	641	\N
262336	GIA	AUCUNE	\N	\N	\N	Audition de la directrice Europe continentale au MAE	Petit-déjeuner avec Mme Florence Mangin, directrice Europe continentale au ministère des affaires étrangères	2018-04-04 08:30:00	2018-04-04 09:25:00	\N	\N	4	0	534	\N
262724	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ambassadeur de Chine en France	\N	2018-04-04 08:30:00	2018-04-04 09:45:00	\N	\N	20	0	584	\N
263235	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Programmation militaire pour les années 2019 à 2025	\N	2018-04-04 16:00:00	2018-04-04 17:20:00	\N	\N	1	0	\N	\N
263255	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Programmation militaire pour les années 2019 à 2025	\N	2018-04-05 09:00:00	2018-04-05 09:55:00	\N	\N	1	0	\N	\N
266904	MISSION	AUCUNE	\N	MINEURSENF	\N	\N	\N	2018-04-11 15:30:00	2018-04-11 17:05:00	2018-04-11 17:18:06	2018-04-11 17:29:34	17	0	\N	\N
266931	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GS Brexit - Audition Ambassadeur d'Irlande	GS Brexit - Audition Ambassadeur d'Irlande	2018-04-11 16:05:00	2018-04-11 17:25:00	\N	\N	11	0	\N	\N
266943	MISSION	DEPLACEMENT	\N	MINEURSENF	\N	Déplacement à Marseille	Déplacement à Marseille	2018-04-12 15:00:00	2018-04-13 00:00:00	\N	\N	4	0	\N	\N
266980	GIA	AUCUNE	\N	\N	\N	Déjeuner avec des membres de l'association Golos et de l'association D'EST	Déjeuner avec des membres de l'association Golos et de l'association D'EST	2018-04-11 13:00:00	2018-04-11 15:00:00	\N	\N	13	0	608	\N
267022	COM_PERMANENTE	AUTRE	\N	FINC	\N	Communication sur le projet de programme de stabilité pour les années 2018 à 2022	Communication sur le projet de programme de stabilité pour les années 2018 à 2022	2018-04-18 09:05:00	2018-04-18 10:25:00	2018-04-18 17:50:50	2018-04-19 14:52:14	33	0	\N	\N
267023	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition pour suite à donner 58-2 sur le soutien aux énergies renouvelables	Audition pour suite à donner 58-2 sur le soutien aux énergies renouvelables	2018-04-18 10:35:00	2018-04-18 12:55:00	2018-04-18 17:52:22	2018-04-19 14:52:12	20	0	\N	\N
267024	COM_PERMANENTE	AUTRE	\N	CDD	\N	Audition plénière	\N	2018-04-17 16:05:00	2018-04-17 16:30:00	2018-04-18 12:30:08	2018-04-18 16:47:55	21	0	\N	\N
267060	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2018-04-18 08:40:00	2018-04-18 09:55:00	2018-04-18 15:08:50	2018-04-18 16:47:52	55	1	\N	\N
268348	GIA	AUCUNE	\N	\N	\N	Entretien de Mme C. PROCACCIA avec une délégation de parlementaires indonésiens (coop)	Entretien de Mme C. PROCACCIA avec une délégation de parlementaires indonésiens (coop)	2018-04-17 14:15:00	2018-04-17 17:00:00	\N	\N	1	0	653	\N
268502	GIA	AUCUNE	\N	\N	\N	Entretien de M. DUPLOMB avec M. AL JABRI, invité qatari (coopé)	Entretien de M. DUPLOMB avec M. AL JABRI, invité qatari (coopé)	2018-04-18 09:20:00	2018-04-18 10:00:00	\N	\N	1	0	661	\N
270318	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Libye	\N	2018-04-24 16:00:00	2018-04-24 17:15:00	\N	\N	2	0	\N	\N
272043	DELEGATION	AUCUNE	\N	\N	COLTER	\N	Table ronde commune DCT et DDF : conditions d'exercice des mandats locaux par les élues	2018-05-24 09:00:00	2018-05-24 11:25:00	2018-05-24 12:02:37	2018-05-24 14:29:43	26	0	\N	\N
343404	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-01-23 10:05:00	2019-01-23 12:25:00	2019-01-23 12:52:44	2019-01-23 15:27:14	31	0	\N	\N
272664	GIA	AUCUNE	\N	\N	\N	Rencontre avec la direction de l'Europe continentale	Rencontre avec la direction de l'Europe continentale (petit-déjeuner de travail)	2018-05-16 08:15:00	2018-05-16 09:15:00	\N	\N	7	0	530	\N
273269	GIA	AUCUNE	\N	\N	\N	Entretien avec Son Exc. M. Jean-Maurice RIPERT, ambassadeur de France en Chine	\N	2018-05-17 08:30:00	2018-05-17 09:30:00	\N	\N	9	0	584	\N
273279	AUTRE_TEMPORAIRE	DEPLACEMENT	\N	\N	\N	Déplacement à la maison d'arrêt de Villepinte (93) 	\N	2018-05-09 13:30:00	2018-05-09 18:00:00	\N	\N	0	0	\N	\N
273310	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Table ronde sur la bioéthique	\N	2018-05-16 12:00:00	2018-05-16 13:00:00	\N	\N	12	0	\N	\N
273311	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2018 - Réseau de l'enseignement français à l'étranger - Déplacement Londres	Contrôle 2018 - Mission "Action extérieure de l'Etat" - Réseau de l'enseignement français à l'étranger- Londres	2018-05-14 07:45:00	2018-05-14 21:15:00	\N	\N	2	0	\N	\N
273325	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition commune sur l¿utilisation des données et des algorithmes en matière fiscale	Audition commune sur l¿utilisation et l¿ouverture des données et des algorithmes en matière fiscale	2018-05-23 10:45:00	2018-05-23 12:40:00	2018-05-25 15:57:55	2018-05-25 17:04:38	30	0	\N	\N
287671	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Avis PJL ELAN	Avis PJL ELAN	2018-06-19 18:00:00	2018-06-19 19:30:00	\N	\N	4	0	\N	\N
297237	ETUDES	AUCUNE	\N	\N	\N	G.E. "Energie"	G.E. "Energie"	2018-07-04 08:15:00	2018-07-04 09:35:00	\N	\N	14	0	\N	906
297291	ETUDES	AUCUNE	\N	\N	\N	G.E. "Forêt et Filière bois"	G.E. "Forêt et Filière bois"	2018-07-11 08:00:00	2018-07-11 09:00:00	\N	\N	6	0	\N	948
299029	COM_PERMANENTE	DEPLACEMENT	\N	SOCI	\N	Intégration du RSI	Intégration RSI	2018-07-16 08:15:00	2018-07-16 18:15:00	\N	\N	1	0	\N	\N
305546	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Culture - Gestion déconcentrée des crédits DRAC - SG ministère culture	Contrôle 2018 - Culture - Gestion déconcentrée des crédits DRAC - SG ministère culture	2018-09-12 14:30:00	2018-09-12 16:00:00	\N	\N	1	0	\N	\N
305548	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Culture-Gestion déconcentrée des crédits DRAC-Syndicat musiques actuelles	Contrôle 2018 - Culture - Gestion déconcentrée des crédits DRAC - Syndicat musiques actuelles	2018-09-12 17:00:00	2018-09-12 18:00:00	\N	\N	1	0	\N	\N
305550	DELEGATION	AUCUNE	\N	\N	211	Echange de vues sur le programme de travail de la session 2018-2019	Echange de vues sur le programme de travail de la session 2018-2019	2018-10-02 17:30:00	2018-10-02 18:30:00	2018-10-03 12:56:56	2018-10-03 15:16:50	17	0	\N	\N
305551	DELEGATION	AUCUNE	\N	\N	211	Table ronde avec UNICEF France	Table ronde avec UNICEF France	2018-10-11 09:00:00	2018-10-11 11:00:00	2018-10-11 12:33:03	2018-10-11 16:05:29	12	0	\N	\N
305555	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	auditions M. Henno, rapporteur	\N	2018-09-13 14:30:00	2018-09-13 16:30:00	\N	\N	1	0	\N	\N
305556	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	auditions M. Henno, rapporteur	\N	2018-09-14 10:00:00	2018-09-14 11:00:00	\N	\N	1	0	\N	\N
305557	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	auditions M. Henno, rapporteur	\N	2018-09-18 16:00:00	2018-09-18 17:00:00	\N	\N	2	0	\N	\N
305558	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	auditions de M. Henno, rapporteur	\N	2018-09-24 15:30:00	2018-09-24 18:30:00	\N	\N	1	0	\N	\N
323323	GIA	AUCUNE	\N	\N	\N	Déjeuner en l'honneur d'une délégation du Sénat cambodgien	Déjeuner en l'honneur d'une délégation du Sénat cambodgien	2018-11-13 12:30:00	2018-11-13 14:00:00	\N	\N	4	0	577	\N
323816	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLF pour 2019 - Mission RCT	PJLF pour 2019 - Mission Relations avec les collectivités territoriales	2018-11-13 15:00:00	2018-11-13 16:30:00	\N	\N	3	0	\N	\N
323965	MECSS	AUDRAP	\N	\N	MECSS	\N	\N	2018-12-05 14:00:00	2018-12-05 18:00:00	\N	\N	2	0	\N	\N
323971	DELEGATION	AUDRAP	\N	\N	206	Audition négaWatt (Stockage de l'électricité)	Audition négaWatt (Stockage de l'électricité)	2018-11-28 14:00:00	2018-11-28 15:30:00	\N	\N	1	0	\N	\N
324075	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	Auditions de M. Savary	\N	2018-12-05 14:00:00	2018-12-05 17:00:00	\N	\N	0	0	\N	\N
324091	MECSS	AUDRAP	\N	\N	MECSS	\N	\N	2018-11-28 16:00:00	2018-11-28 17:00:00	\N	\N	1	0	\N	\N
324142	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Suite examen amendements PLFSS 2019	\N	2018-11-14 19:40:00	2018-11-14 20:25:00	2018-11-14 20:25:37	2018-11-15 14:56:23	33	0	\N	\N
324675	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2018-11-14 15:15:00	2018-11-14 16:35:00	\N	\N	3	0	\N	\N
325057	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Palais de Justice	\N	2018-11-15 14:30:00	2018-11-15 18:30:00	\N	\N	2	0	\N	\N
325162	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Rapport Général - Eutelsat	PLF pour 2019 - Rapport Général - Eutelsat	2018-11-13 09:30:00	2018-11-13 10:30:00	\N	\N	1	0	\N	\N
325171	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Handicap dans la fonction publique	MI Handicap dans la fonction publique	2018-10-09 14:00:00	2018-10-09 16:15:00	\N	\N	2	0	\N	\N
325182	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI handicap dans la fonction publique	\N	2018-11-13 14:00:00	2018-11-13 17:30:00	\N	\N	2	0	\N	\N
325185	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions rapporteur	\N	2018-11-14 14:30:00	2018-11-14 16:30:00	\N	\N	1	0	\N	\N
325188	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur PJJ 2019	\N	2018-11-15 15:30:00	2018-11-15 16:30:00	\N	\N	0	0	\N	\N
326974	DELEGATION	AUCUNE	\N	\N	COLTER	Audition de M. Sébastien Lecornu, ministre chargé des collectivités territoriales	\N	2018-11-28 16:15:00	2018-11-28 18:00:00	2018-11-28 18:42:43	2018-11-29 14:36:58	23	0	\N	\N
327667	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	GT justice prud'homale	GT justice prud'homale	2018-11-22 07:50:00	2018-11-22 19:00:00	\N	\N	1	0	\N	\N
327669	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	GT justice prud'homale	\N	2018-11-23 09:30:00	2018-11-23 16:00:00	\N	\N	1	0	\N	\N
327792	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2018-11-21 14:45:00	2018-11-21 16:30:00	\N	\N	3	0	\N	\N
328625	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Institution de funérailles républicaines	PPL Institution de funérailles républicaines	2018-11-22 14:00:00	2018-11-22 14:30:00	\N	\N	1	0	\N	\N
330828	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Institution de funérailles républicaines	PPL Institution de funérailles républicaines	2018-11-27 18:00:00	2018-11-27 20:10:00	\N	\N	2	0	\N	\N
330964	GIA	AUCUNE	\N	\N	\N	Déjeuner avec l'ambassadeur d'Afrique du Sud en France	Déjeuner avec S. E. M. Rapulane Sydney MOLEKANE, ambassadeur d'Afrique du Sud en France	2018-11-28 12:50:00	2018-11-28 14:15:00	\N	\N	8	0	574	\N
331345	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	PJL Croissance et transformation des entreprises	\N	2018-11-28 14:30:00	2018-11-28 19:30:00	\N	\N	1	0	\N	\N
343293	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	auditions rapporteurs	\N	2019-01-30 14:00:00	2019-01-30 19:30:00	\N	\N	0	0	\N	\N
325060	COM_PERMANENTE	AUTRE	\N	ETRD	\N	PLF pour 2019	\N	2018-11-21 09:35:00	2018-11-21 10:50:00	2018-11-21 15:27:35	2018-11-21 16:30:37	40	2	\N	\N
326803	CMP	AUTRE	\N	PLFSS2019	\N	PLFSS pour 2019	PLFSS pour 2019	2018-11-20 18:00:00	2018-11-20 18:55:00	\N	\N	9	0	\N	\N
343407	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-01-23 14:20:00	2019-01-23 14:35:00	2019-01-23 14:47:13	2019-01-23 15:27:15	27	2	\N	\N
348067	DELEGATION	AUDRAP	\N	\N	206	Audition INRIA (Arrêt des véhicules thermiques)	Audition INRIA (Arrêt des véhicules thermiques)	2019-01-24 11:00:00	2019-01-24 12:00:00	\N	\N	2	0	\N	\N
348070	DELEGATION	AUDRAP	\N	\N	206	Audition ALD Automotive (Arrêt des véhicules thermiques)	Audition ALD Automotive (Arrêt des véhicules thermiques)	2019-01-31 09:00:00	2019-01-31 10:00:00	\N	\N	2	0	\N	\N
348073	DELEGATION	AUDRAP	\N	\N	206	Audition FIEV (Arrêt des véhicules thermiques)	Audition FIEV (Arrêt des véhicules thermiques)	2019-01-31 10:00:00	2019-01-31 11:00:00	\N	\N	2	0	\N	\N
348076	DELEGATION	AUDRAP	\N	\N	206	Audition FNTR (Arrêt des véhicules thermiques)	Audition FNTR (Arrêt des véhicules thermiques)	2019-01-31 11:00:00	2019-01-31 12:00:00	\N	\N	2	0	\N	\N
348079	DELEGATION	AUDRAP	\N	\N	206	Audition M. Yannick Perez (Arrêt des véhicules thermiques)	Audition M. Yannick Perez (Arrêt des véhicules thermiques)	2019-02-06 13:30:00	2019-02-06 14:30:00	\N	\N	2	0	\N	\N
348082	DELEGATION	AUDRAP	\N	\N	206	Audition ALSTOM (Arrêt des véhicules thermiques)	Audition ALSTOM (Arrêt des véhicules thermiques)	2019-02-07 10:00:00	2019-02-07 11:00:00	\N	\N	2	0	\N	\N
348085	DELEGATION	AUDRAP	\N	\N	206	Audition SNAM (Arrêt des véhicules thermiques)	Audition SNAM (Arrêt des véhicules thermiques)	2019-02-07 11:00:00	2019-02-07 12:00:00	\N	\N	2	0	\N	\N
348088	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière - Audition publique : Intelligence artificielle et données de santé	Réunion plénière - Audition publique : Intelligence artificielle et données de santé	2019-02-21 09:00:00	2019-02-21 13:05:00	2019-02-21 15:02:42	\N	10	0	\N	\N
348089	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	Déplacement dans le département de la Moselle	Mission d'information sur la Sécurité des ponts - Déplacement dans le département de la Moselle	2019-02-04 08:15:00	2019-02-04 19:20:00	\N	\N	1	0	\N	\N
350766	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL "Lutte contre l'habitat insalubre"	PPL "Lutte contre l'habitat insalubre"	2019-01-29 15:00:00	2019-01-29 16:20:00	\N	\N	1	0	\N	\N
350768	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL "Lutte contre l'habitat insalubre"	PPL "Lutte contre l'habitat insalubre"	2019-01-30 17:30:00	2019-01-30 18:30:00	\N	\N	2	0	\N	\N
350772	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL "Lutte contre l'habitat insalubre"	PPL "Lutte contre l'habitat insalubre"	2019-01-30 18:30:00	2019-01-30 19:50:00	\N	\N	1	0	\N	\N
214919	COM_EURO	AUDRAP	\N	AFEU	\N	Audition création d'un Tribunal pénal international	Audition création d'un Tribunal pénal international (TPI) pour juger les djihadistes	2017-11-07 14:35:00	2017-11-07 15:35:00	\N	\N	2	0	\N	\N
216821	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2018 (avis Immigration)	\N	2017-11-09 14:30:00	2017-11-09 15:10:00	\N	\N	3	0	\N	\N
217478	COM_EURO	AUDRAP	\N	AFEU	\N	Cybersécurité	Cybersécurité	2017-11-08 08:35:00	2017-11-08 10:35:00	\N	\N	2	0	\N	\N
217482	COM_EURO	AUDRAP	\N	AFEU	\N	Cybersécurité	Cybersécurité	2017-11-08 12:00:00	2017-11-08 12:45:00	\N	\N	2	0	\N	\N
217492	COM_EURO	AUDRAP	\N	AFEU	\N	Données non personnelles	Libre circulation des données non personnelles	2017-11-08 11:30:00	2017-11-08 12:00:00	\N	\N	1	0	\N	\N
217495	COM_EURO	AUDRAP	\N	AFEU	\N	Données non personnelles	Libre circulation des données non personnelles	2017-10-26 11:00:00	2017-10-26 11:45:00	\N	\N	1	0	\N	\N
218273	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2017-11-21 09:35:00	2017-11-21 12:30:00	\N	\N	49	0	\N	\N
218274	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Avenir de l'Institut français	Débat Avenir de l'Institut français	2017-11-21 16:55:00	2017-11-21 18:45:00	\N	\N	89	0	\N	\N
218275	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Politique de la ville	Débat Politique de la ville	2017-11-21 18:45:00	2017-11-21 20:45:00	\N	\N	43	0	\N	\N
218276	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Représentation des communes	Débat Représentation des communes	2017-11-22 14:30:00	2017-11-22 16:20:00	\N	\N	89	0	\N	\N
218277	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Energies	Débat Energies	2017-11-22 16:30:00	2017-11-22 18:20:00	\N	\N	60	0	\N	\N
218278	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Collectivités locales	Débat Collectivités locales	2017-11-22 18:30:00	2017-11-23 20:35:00	\N	\N	62	0	\N	\N
218279	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Dépôt de candidatures	PPL Dépôt de candidatures	2017-11-22 22:05:00	2017-11-23 23:50:00	\N	\N	33	0	\N	\N
218280	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2018	PLF 2018	2017-11-23 11:00:00	2017-11-23 13:30:00	\N	\N	132	0	\N	\N
218281	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2018 après-midi	PLF 2018 après-midi	2017-11-23 16:15:00	2017-11-23 19:45:00	\N	\N	86	0	\N	\N
218283	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2017-11-23 15:00:00	2017-11-23 16:00:00	\N	\N	291	0	\N	\N
218284	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2018 après-midi	PLF 2018 après-midi	2017-11-24 14:30:00	2017-11-24 20:00:00	\N	\N	59	0	\N	\N
218285	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2018 soir	PLF 2018 soir	2017-11-24 21:30:00	2017-11-25 00:35:00	\N	\N	43	0	\N	\N
218286	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2018 matin	PLF 2018 matin	2017-11-25 09:35:00	2017-11-25 13:00:00	\N	\N	46	0	\N	\N
218287	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2018 après-midi	PLF 2018 après-midi	2017-11-25 14:30:00	2017-11-25 18:40:00	\N	\N	55	0	\N	\N
218292	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2018 matin	PLF 2018 matin	2017-11-27 10:00:00	2017-11-27 12:50:00	\N	\N	50	0	\N	\N
218293	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2018 après-midi	PLF 2018 après-midi	2017-11-27 14:30:00	2017-11-27 20:35:00	\N	\N	79	0	\N	\N
218295	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2018 après-midi 1	PLF 2018 après-midi 1	2017-11-28 14:30:00	2017-11-28 16:00:00	\N	\N	228	0	\N	\N
218298	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2017-11-28 16:45:00	2017-11-28 17:40:00	\N	\N	289	0	\N	\N
218299	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2018 matin	PLF 2018 matin	2017-11-29 10:30:00	2017-11-29 12:25:00	\N	\N	110	0	\N	\N
218300	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2018 après-midi	PLF 2018 après-midi	2017-11-29 14:00:00	2017-11-29 19:45:00	\N	\N	170	0	\N	\N
218301	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2018 soir	PLF 2018 soir	2017-11-29 21:15:00	2017-11-30 00:35:00	\N	\N	80	0	\N	\N
218303	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2018 après-midi	PLF 2018 après-midi	2017-11-30 14:30:00	2017-11-30 18:05:00	\N	\N	95	0	\N	\N
218304	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2018 mission Défense	PLF 2018 mission Défense	2017-11-30 18:30:00	2017-11-30 20:40:00	\N	\N	40	0	\N	\N
218305	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2018 Nouvelle lecture	PLFSS 2018 Nouvelle lecture	2017-12-01 09:30:00	2017-12-01 11:00:00	\N	\N	38	0	\N	\N
218306	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2018 après-midi	PLF 2018 après-midi	2017-12-01 15:00:00	2017-12-01 18:30:00	\N	\N	39	0	\N	\N
218315	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2018 soir	PLF 2018 soir	2017-12-04 21:20:00	2017-12-05 00:30:00	\N	\N	51	0	\N	\N
218316	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2018 matin	PLF 2018 matin	2017-12-04 10:00:00	2017-12-04 13:00:00	\N	\N	40	0	\N	\N
218317	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2018 après-midi	PLF 2018 après-midi	2017-12-04 13:45:00	2017-12-04 19:50:00	\N	\N	82	0	\N	\N
218441	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2018  (Missions : Sécurités  ; Immigration ; Administration générale ; Justice)  	PLF 2018  (Missions : Sécurités  ; Immigration ; Administration générale ; Justice)  	2017-12-05 14:00:00	2017-12-05 20:20:00	\N	\N	184	0	\N	\N
218442	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2018  (Missions : Sécurités  ; Immigration ; Administration générale ; Justice)  	PLF 2018  (Missions : Sécurités  ; Immigration ; Administration générale ; Justice)  	2017-12-05 21:50:00	2017-12-05 23:25:00	\N	\N	60	0	\N	\N
218443	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2017-12-05 09:30:00	2017-12-05 12:10:00	\N	\N	43	0	\N	\N
218444	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2018 soir	PLF 2018 soir	2017-12-06 21:45:00	2017-12-07 01:50:00	\N	\N	65	0	\N	\N
218445	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2018 après-midi	PLF 2018 après-midi	2017-12-06 14:30:00	2017-12-06 20:15:00	\N	\N	181	0	\N	\N
218447	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2018 matin	PLF 2018 matin	2017-12-06 10:30:00	2017-12-06 12:55:00	\N	\N	119	0	\N	\N
218448	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2018 matin (Missions : Agriculture; Économie ; Outre-mer ; Recherche )	PLF 2018 matin (Missions : Agriculture; Économie ; Outre-mer ; Recherche )	2017-12-07 10:50:00	2017-12-07 13:30:00	\N	\N	94	0	\N	\N
218454	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2018 matin	PLF 2018 matin	2017-12-08 09:40:00	2017-12-08 13:05:00	\N	\N	43	0	\N	\N
218458	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2018 après-midi	PLF 2018 après-midi	2017-12-08 14:35:00	2017-12-08 18:45:00	\N	\N	40	0	\N	\N
218468	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2018 après-midi	PLF 2018 après-midi	2017-12-11 14:30:00	2017-12-11 18:25:00	\N	\N	42	0	\N	\N
218469	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2018 matin	PLF 2018 matin	2017-12-11 10:00:00	2017-12-11 13:00:00	\N	\N	44	0	\N	\N
218472	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	841	\N	\N	PLF 2018 - Explications de vote sur l'ensemble	PLF 2018 - Explications de vote sur l'ensemble	2017-12-12 14:35:00	2017-12-12 16:00:00	\N	\N	300	0	\N	\N
220244	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2018	\N	2017-11-14 09:30:00	2017-11-14 10:30:00	\N	\N	1	0	\N	\N
278425	MISSION	PLEIN_NON_JO	\N	BREXIT2	\N	Audition de l'association The3Million	Audition de l'association The3Million	2018-05-30 16:05:00	2018-05-30 17:15:00	\N	\N	7	0	\N	\N
281751	MISSION	AUCUNE	\N	MINEURSENF	\N	\N	\N	2018-06-07 11:05:00	2018-06-07 12:15:00	2018-06-07 12:23:43	2018-06-07 18:47:57	7	0	\N	\N
282440	GIA	AUCUNE	\N	\N	\N	Remise du prix Pasternak 2017-2018	Remise du prix Pasternak 2017-2018	2018-06-07 12:30:00	2018-06-07 13:30:00	\N	\N	4	0	530	\N
284216	MISSION	AUCUNE	\N	MINEURSENF	\N	\N	\N	2018-06-12 17:55:00	2018-06-12 19:15:00	2018-06-13 09:47:41	2018-06-13 14:24:49	6	0	\N	\N
287686	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Avis PJL ELAN	\N	2018-06-14 14:30:00	2018-06-14 17:30:00	\N	\N	1	0	\N	\N
298326	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Avenir professionnel	PJL Avenir professionnel	2018-07-16 10:00:00	2018-07-16 12:35:00	\N	\N	39	0	\N	\N
298953	GIA	AUCUNE	\N	\N	\N	Visite d'une personnalité azerbaïdjanaise	Entretien avec M. Fuad MOURADOV, président du comité d'Etat pour le travail avec la diaspora de la République d'Azerbaïd	2018-07-10 19:15:00	2018-07-10 20:20:00	\N	\N	1	0	534	\N
305768	GIA	AUCUNE	\N	\N	\N	Rencontre Cazeau Dolamari	Rencontre entre M. Cazeau et M. Ali Dolamari, représentant du Gouvernement régional du Kurdistan en France	2018-09-19 15:00:00	2018-09-19 16:00:00	\N	\N	1	0	615	\N
305770	GIA	AUCUNE	\N	\N	\N	Rencontre Cazeau Bonnafont Pinelli	Rencontre entre M. Cazeau et MM. Bonnafont et Pinelli au quai d'Orsay	2018-10-23 15:00:00	2018-10-23 17:00:00	\N	\N	1	0	615	\N
333850	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	PJL Croissance et transformation des entreprises	\N	2018-12-04 16:30:00	2018-12-04 19:30:00	\N	\N	1	0	\N	\N
333857	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	PJL Croissance et transformation des entreprises	\N	2018-12-05 10:30:00	2018-12-05 11:15:00	\N	\N	1	0	\N	\N
335678	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	\N	\N	2018-11-27 14:00:00	2018-11-27 15:00:00	\N	\N	5	0	\N	\N
335691	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-12-06 09:30:00	2018-12-06 10:45:00	\N	\N	3	0	\N	\N
337674	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 13 décembre - Audition Pierre Moscovici	Réunion du 13 décembre - Audition Pierre Moscovici	2018-12-13 08:30:00	2018-12-13 09:45:00	2018-12-13 18:19:23	2018-12-14 11:24:51	32	0	\N	\N
337701	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 13 décembre - 10h15	Réunion du 13 décembre - 10h15	2018-12-13 10:15:00	2018-12-13 11:50:00	2018-12-13 18:18:59	2018-12-14 11:24:52	13	0	\N	\N
340177	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	PJL Croissance et transformation des entreprises	\N	2018-12-20 14:00:00	2018-12-20 15:30:00	\N	\N	1	0	\N	\N
340179	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	\N	\N	2018-12-20 17:45:00	2018-12-20 18:30:00	\N	\N	1	0	\N	\N
340184	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Orientation des mobilités	\N	2018-12-20 14:00:00	2018-12-20 17:00:00	\N	\N	1	0	\N	\N
342039	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Sécurité des ponts	\N	2019-01-17 10:20:00	2019-01-17 12:35:00	\N	\N	8	0	\N	\N
342100	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Sécurité des ponts	\N	2019-01-16 16:30:00	2019-01-16 17:15:00	\N	\N	3	0	\N	\N
342129	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 17 janvier 2019	Réunion de la commission des affaires européennes du 17 janvier 2019	2019-01-17 09:05:00	2019-01-17 10:00:00	2019-01-17 12:19:14	2019-01-17 15:02:51	13	0	\N	\N
342189	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition SSA	\N	2019-01-23 10:05:00	2019-01-23 11:20:00	2019-01-23 12:18:53	2019-01-23 15:27:13	38	0	\N	\N
342191	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition JY Le Drian	\N	2019-01-23 16:30:00	2019-01-23 18:15:00	2019-01-24 10:24:39	2019-01-24 10:41:53	28	0	\N	\N
342222	MISSION	AUCUNE	\N	BREXIT2	\N	\N	\N	2019-01-17 10:35:00	2019-01-17 11:45:00	2019-01-18 09:30:41	2019-01-18 11:44:59	12	0	\N	\N
342498	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Turquie	\N	2019-01-16 14:50:00	2019-01-16 17:00:00	\N	\N	3	0	\N	\N
342504	ETUDES	AUCUNE	\N	\N	\N	Audition de représentants du ministère de l'agriculture et de l'alimentation	Situation de l'Office national des forêts -Audition de représentants du ministère de l'agriculture et de l'alimentation	2019-01-17 11:15:00	2019-01-17 13:00:00	\N	\N	4	0	\N	948
344573	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Santé visuelle	PPL Santé visuelle	2019-01-23 15:55:00	2019-01-23 17:35:00	\N	\N	30	0	\N	\N
344992	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Colombie	\N	2019-01-23 15:00:00	2019-01-23 16:30:00	\N	\N	4	0	\N	\N
345003	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 24 janvier 2019	Réunion du 24 janvier 2019	2019-01-24 08:35:00	2019-01-24 10:35:00	2019-01-24 15:17:54	2019-01-24 18:28:25	12	1	\N	\N
345021	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Agriculture biologique - Agence Bio	Contrôle 2018 - Agriculture biologique - Agence Bio	2019-01-22 15:30:00	2019-01-22 16:45:00	\N	\N	1	0	\N	\N
345023	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Agriculture biologique - FNAB	Contrôle 2018 - Agriculture biologique - FNAB	2019-01-23 14:30:00	2019-01-23 16:45:00	\N	\N	1	0	\N	\N
345029	DELEGATION	AUDRAP	\N	\N	206	Audition CEA / IFPEN (Arrêt des véhicules thermiques)	Audition CEA / IFPEN (Arrêt des véhicules thermiques)	2019-01-24 09:00:00	2019-01-24 11:00:00	\N	\N	2	0	\N	\N
345036	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Réunion de la commission	\N	2019-01-30 09:35:00	2019-01-30 12:05:00	2019-01-30 14:18:35	2019-01-30 14:49:53	35	0	\N	\N
348334	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Favoriser la reconnaissance des proches aidants	\N	2019-02-07 11:00:00	2019-02-07 12:00:00	\N	\N	1	0	\N	\N
348336	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Favoriser la reconnaissance des proches aidants	\N	2019-02-07 14:00:00	2019-02-07 15:00:00	\N	\N	1	0	\N	\N
348339	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Favoriser la reconnaissance des proches aidants	\N	2019-02-08 12:00:00	2019-02-08 13:00:00	\N	\N	1	0	\N	\N
348345	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Favoriser la reconnaissance des proches aidants	\N	2019-02-12 16:00:00	2019-02-12 17:00:00	\N	\N	1	0	\N	\N
348355	MECSS	AUDRAP	\N	\N	MECSS	\N	\N	2019-02-13 14:00:00	2019-02-13 18:00:00	\N	\N	5	0	\N	\N
349657	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Pascal BONIFACE de l'IRIS	Entretien avec M. Pascal BONIFACE de l'IRIS	2019-02-06 08:15:00	2019-02-06 09:15:00	\N	\N	10	0	590	\N
349748	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Orientation des mobilités	\N	2019-02-05 15:15:00	2019-02-05 16:15:00	\N	\N	0	0	\N	\N
349785	GIA	AUCUNE	\N	\N	\N	Petit déjeuenr Ambassadeur Belgique	Petit déjeuner de travail SE François de Kerchove d'Exaerde, ambassadeur de Belgique en France	2019-02-06 08:00:00	2019-02-06 09:15:00	\N	\N	7	0	580	\N
350737	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 7 février 2019	Réunion du 7 février 2019	2019-02-07 08:40:00	2019-02-07 10:15:00	2019-02-07 16:05:33	2019-02-07 17:23:06	16	0	\N	\N
350939	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Election membres Parlement européen suffrage universel direct	PJL Election membres Parlement européen suffrage universel direct	2019-02-14 10:30:00	2019-02-14 11:55:00	\N	\N	79	0	\N	\N
351930	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de la commission	\N	2019-02-13 09:40:00	2019-02-13 11:55:00	2019-02-13 12:08:11	2019-02-13 16:52:07	35	0	\N	\N
351931	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-02-14 10:30:00	2019-02-14 12:25:00	2019-02-14 12:37:47	2019-02-14 16:05:53	16	0	\N	\N
351932	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-02-14 16:35:00	2019-02-14 18:55:00	2019-02-14 19:06:38	2019-02-15 10:55:10	15	0	\N	\N
352195	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Audition plénière - GE Chasse et Pêche 2018	\N	2019-03-13 08:00:00	2019-03-13 09:07:00	\N	\N	0	0	\N	\N
352249	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur mastectomie	\N	2019-02-12 15:00:00	2019-02-12 15:45:00	\N	\N	1	0	\N	\N
213136	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Travail et emploi 	PLF pour 2018 - Travail et emploi - Missions locales	2017-10-25 19:00:00	2017-10-25 20:15:00	\N	\N	2	0	\N	\N
213140	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Travail et emploi 	PLF pour 2018 - Travail et emploi - ANACT-Pole Emploi Syndicats-AMF-INRS	2017-10-26 08:00:00	2017-10-26 12:00:00	\N	\N	2	0	\N	\N
213143	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - enseignement scolaire	PLF pour 2018 - enseignement scolaire - Cabinet ministre education nationale	2017-10-26 14:00:00	2017-10-26 15:00:00	\N	\N	1	0	\N	\N
213145	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Solidarité, insertion et égalité des chances	PLF pour 2018 - Solidarité, insertion et égalité des chances - Audition direction des finances	2017-10-24 14:30:00	2017-10-24 15:40:00	\N	\N	2	0	\N	\N
342188	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-01-23 09:30:00	2019-01-23 10:05:00	2019-01-23 12:16:22	2019-01-23 15:27:19	36	1	\N	\N
352190	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-02-20 09:05:00	2019-02-20 10:50:00	2019-02-20 15:47:14	2019-02-20 15:55:50	48	0	\N	\N
213148	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Solidarité, insertion et égalité des chances	PLF pour 2018 - Solidarité, insertion et égalité des chances - Fédération des acteurs de la solidarité	2017-10-25 14:30:00	2017-10-25 15:45:00	\N	\N	3	0	\N	\N
213151	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Solidarité, insertion et égalité des chances	PLF pour 2018 - Solidarité, insertion et égalité des chances - Direction générale de la cohésion sociale	2017-10-25 16:15:00	2017-10-25 17:15:00	\N	\N	2	0	\N	\N
213154	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Recherche et Enseignement supérieur	PLF pour 2018 - Recherche et Enseignement supérieur - Irstea	2017-10-25 14:00:00	2017-10-25 15:15:00	\N	\N	1	0	\N	\N
219909	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2018 - Mission Recherche et enseignement supérieur	PLF pour 2018 - Mission Recherche et enseignement supérieur	2017-11-21 09:35:00	2017-11-21 10:40:00	2017-11-22 09:24:06	2017-11-22 11:06:00	26	0	\N	\N
219910	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2018 - Missions Santé et RSR	PLF pour 2018 - Missions Santé et Régimes sociaux de retraite	2017-11-21 14:05:00	2017-11-21 14:40:00	2017-11-22 16:30:24	2017-11-22 16:42:24	21	0	\N	\N
219916	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2018 - Articles réservés-Position commission 1ère partie Tome II-RCT	PLF pour 2018 - Articles réservés-Position commission1ère partie Tome II-Mission Relations collectivités territoriales	2017-11-21 16:35:00	2017-11-21 18:05:00	2017-11-23 09:46:41	2017-11-23 14:24:17	31	0	\N	\N
219918	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2018 - Missions GFPRH et Écologie	PLF pour 2018 - Missions GFPRH et Écologie	2017-11-22 14:35:00	2017-11-22 17:30:00	2017-11-23 17:04:09	2017-11-23 17:07:05	29	0	\N	\N
219921	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2018 - Examen définitif équilibre Missions, BA, Comptes spéciaux 2nde partie	PLF pour 2018 - Examen définitif équilibre Missions, BA, Comptes spéciaux 2nde partie	2017-11-23 09:05:00	2017-11-23 10:10:00	2017-11-24 10:46:32	2017-11-24 11:28:22	29	0	\N	\N
219923	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2018 - Examen Amendements de séance sur le1ère partie	PLF pour 2018 - Examen Amendements de séance sur le1ère partie	2017-11-24 09:05:00	2017-11-24 10:50:00	2017-11-24 17:22:00	2017-11-24 17:32:10	24	0	\N	\N
229663	BUREAU	AUCUNE	\N	\N	\N	Bureau du Sénat	Bureau du Sénat	2017-12-13 15:00:00	2017-12-13 17:00:00	\N	\N	22	0	\N	\N
230024	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2017-12-20 09:35:00	2017-12-20 11:20:00	2017-12-20 16:43:45	2017-12-20 17:35:44	37	0	\N	\N
230033	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2017-12-20 15:05:00	2017-12-20 16:05:00	2017-12-20 17:01:53	2017-12-20 17:35:42	25	0	\N	\N
230055	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	PROS	Réunion de travail rapport "Nouvelles mobilités"	Réunion de travail rapport "Nouvelles mobilités"	2017-12-19 14:30:00	2017-12-19 15:30:00	\N	\N	5	0	\N	\N
232334	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL accords franco-andorrans	\N	2017-12-19 10:00:00	2017-12-19 10:50:00	\N	\N	1	0	\N	\N
232409	GIA	AUCUNE	\N	\N	\N	GIA France-Japon - réunion constitutive	GIA France-Japon - réunion constitutive	2017-12-19 14:00:00	2017-12-19 14:45:00	\N	\N	12	0	596	\N
232853	GIA	AUCUNE	\N	\N	\N	Réception à l'ambassade pour le centenaire de la Finlande	Réception à l'ambassade pour le centenaire de la Finlande	2017-12-05 18:00:00	2017-12-05 20:00:00	\N	\N	6	0	640	\N
232861	GIA	AUCUNE	\N	\N	\N	Conférence inaugurale de l'Institut du Monde Lusophone	Conférence inaugurale de l'Institut du Monde Lusophone	2017-12-08 09:00:00	2017-12-08 18:00:00	\N	\N	1	0	601	\N
234934	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Vote électronique	MI vote électronique	2018-01-18 09:30:00	2018-01-18 12:30:00	\N	\N	2	0	\N	\N
234938	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Vote électronique	MI Vote électronique	2018-01-18 14:30:00	2018-01-18 19:30:00	\N	\N	2	0	\N	\N
238428	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Expertise France	\N	2018-01-23 09:00:00	2018-01-23 10:00:00	\N	\N	2	0	\N	\N
238432	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Expertise France	\N	2018-01-23 15:00:00	2018-01-23 16:00:00	\N	\N	2	0	\N	\N
238435	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Expertise France	\N	2018-01-23 18:00:00	2018-01-23 19:00:00	\N	\N	2	0	\N	\N
238633	BUREAU	AUCUNE	\N	\N	\N	Bureau du Sénat	Bureau du Sénat	2018-01-25 09:00:00	2018-01-25 12:00:00	\N	\N	24	0	\N	\N
238701	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Carpiagne	\N	2018-01-25 06:30:00	2018-01-25 22:30:00	\N	\N	20	0	\N	\N
238722	MISSION	AUDRAP	\N	ALSTOM	\N	\N	MI Alstom - Auditions président & rapporteur	2018-01-23 14:30:00	2018-01-23 16:30:00	\N	\N	9	0	\N	\N
238732	MISSION	AUDRAP	\N	ALSTOM	\N	\N	MI Alstom - Auditions président & rapporteur	2018-01-24 17:45:00	2018-01-24 18:45:00	\N	\N	7	0	\N	\N
241164	ETUDES	AUCUNE	\N	\N	\N	\N	GE Economie sociale et solidaire	2018-01-30 14:00:00	2018-01-30 15:00:00	\N	\N	5	0	\N	998
250518	COM_PERMANENTE	AUTRE	\N	LOIS	\N	\N	\N	2018-03-07 09:40:00	2018-03-07 12:40:00	2018-03-07 14:49:47	2018-03-07 18:23:06	66	0	\N	\N
250529	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2018-03-07 16:45:00	2018-03-07 18:30:00	2018-03-07 18:29:57	2018-03-08 09:59:55	38	0	\N	\N
250533	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2018-03-08 10:35:00	2018-03-08 12:35:00	2018-03-08 14:59:48	2018-03-08 15:11:46	21	0	\N	\N
250937	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Réunion constitutive	\N	2018-03-07 08:00:00	2018-03-07 09:00:00	\N	\N	0	0	\N	\N
251102	COM_PERMANENTE	AUTRE	\N	CDD	\N	\N	\N	2018-03-07 16:35:00	2018-03-07 18:15:00	2018-03-09 17:05:21	2018-03-09 17:05:26	32	0	\N	\N
251120	COM_PERMANENTE	AUTRE	\N	CDD	\N	\N	\N	2018-03-07 10:30:00	2018-03-07 12:10:00	2018-03-09 17:05:13	2018-03-09 17:05:25	36	0	\N	\N
251307	MISSION	AUCUNE	\N	ALSTOM	\N	Débat d'Orientation	Débat d'Orientation	2018-03-08 11:05:00	2018-03-08 11:55:00	2018-03-08 15:38:09	2018-03-08 15:47:46	11	0	\N	\N
251308	MISSION	AUCUNE	\N	ALSTOM	\N	Audition de de M. Bruno LE MAIRE, Ministre de l'Économie et des Finances	Audition de de M. Bruno LE MAIRE, Ministre de l'Économie et des Finances	2018-03-08 13:45:00	2018-03-08 15:00:00	2018-03-08 15:38:21	2018-03-08 15:47:48	14	0	\N	\N
254777	COM_EURO	AUDRAP	\N	AFEU	\N	Détachement des travailleurs	Détachement des travailleurs	2018-03-13 14:30:00	2018-03-13 15:30:00	\N	\N	1	0	\N	\N
254779	COM_EURO	AUDRAP	\N	AFEU	\N	Détachement des travailleurs	Détachement des travailleurs	2018-03-13 15:30:00	2018-03-13 16:30:00	\N	\N	2	0	\N	\N
255886	BUREAU	AUCUNE	\N	\N	\N	Bureau du Sénat	Bureau du Sénat	2018-03-15 09:10:00	2018-03-15 11:30:00	\N	\N	22	0	\N	\N
267437	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Métier d'enseignant	Métier d'enseignant	2018-04-12 09:45:00	2018-04-12 11:15:00	\N	\N	3	0	\N	\N
267441	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Métier d'enseignant	Métier d'enseignant	2018-04-12 11:15:00	2018-04-12 12:15:00	\N	\N	2	0	\N	\N
242647	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2018-02-14 16:00:00	2018-02-14 18:00:00	\N	\N	7	0	\N	\N
219917	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2018 - Examen Missions et article réservés-Missions EFE-Cohésion territoires	PLF pour 2018 - Examen Missions et article rattaché réservés-Missions EFE-Cohésion des territoires	2017-11-22 09:05:00	2017-11-22 12:20:00	2017-11-23 09:46:22	2017-11-23 14:24:08	46	1	\N	\N
267444	COM_PERMANENTE	DEPLACEMENT	\N	AFCL	\N	Groupe de travail Formation au numérique	Groupe de travail Formation au numérique	2018-03-07 15:00:00	2018-03-07 18:30:00	\N	\N	1	0	\N	\N
267446	COM_PERMANENTE	DEPLACEMENT	\N	AFCL	\N	Groupe de travail Formation au numérique	Groupe de travail Formation au numérique	2018-03-12 09:00:00	2018-03-12 17:30:00	\N	\N	1	0	\N	\N
267448	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Formation au numérique	Formation au numérique	2018-03-13 14:30:00	2018-03-13 16:30:00	\N	\N	0	0	\N	\N
267449	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Formation au numérique	Formation au numérique	2018-03-20 16:45:00	2018-03-20 18:30:00	\N	\N	1	0	\N	\N
294307	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Violences sexuelles	PJL Violences sexuelles	2018-07-04 14:35:00	2018-07-04 20:15:00	\N	\N	160	0	\N	\N
294495	COM_ENQUETE	PLENIERE	\N	CHUTE	\N	Examen et adoption du rapport	Examen et adoption du rapport	2018-07-04 15:00:00	2018-07-04 17:40:00	\N	\N	15	0	\N	\N
316570	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLF pour 2019 - Mission Administration pénitentiaire	\N	2018-10-25 09:00:00	2018-10-25 12:00:00	\N	\N	1	0	\N	\N
335738	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2019	PLF 2019	2018-12-11 14:30:00	2018-12-11 15:30:00	\N	\N	0	0	\N	\N
337759	GIA	AUCUNE	\N	\N	\N	Audition de M. Ali DOLAMARI, représentant du Gouvernement régional du Kurdistan irakien	Audition de M. Ali DOLAMARI, représentant du Gouvernement régional du Kurdistan irakien	2018-12-13 09:15:00	2018-12-13 10:30:00	\N	\N	13	0	CHRETORIENT	CHRETORIENT
342125	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Création d'un droit voisin au profit des agences et éditeurs de presse	PPL Création d'un droit voisin au profit des agences et éditeurs de presse	2019-01-10 14:00:00	2019-01-10 18:00:00	\N	\N	1	0	\N	\N
342127	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-01-23 09:40:00	2019-01-23 11:35:00	2019-01-23 12:17:34	2019-01-23 15:27:12	38	0	\N	\N
342128	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-01-22 09:20:00	2019-01-22 09:35:00	2019-01-22 10:10:25	2019-01-22 11:59:18	20	0	\N	\N
342171	COM_SPECIALE	AUTRE	\N	ENTREPRISES	\N	Réunion 20190117b	\N	2019-01-17 13:50:00	2019-01-17 14:55:00	2019-01-17 15:02:06	2019-01-17 15:03:36	23	0	\N	\N
342172	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-01-23 09:35:00	2019-01-23 11:35:00	2019-01-23 14:09:47	2019-01-23 15:27:13	40	0	\N	\N
356295	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Avenir institutionnel Alsace	PJL Avenir institutionnel Alsace	2019-04-02 18:25:00	2019-04-02 20:00:00	\N	\N	102	0	\N	\N
356296	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Avenir institutionnel Alsace	PJL Avenir institutionnel Alsace	2019-04-02 21:30:00	2019-04-03 00:40:00	\N	\N	69	0	\N	\N
356297	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Mentions origine produits agricoles	PPL Mentions origine produits agricoles	2019-04-03 14:30:00	2019-04-03 18:35:00	\N	\N	150	0	\N	\N
356298	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Politique industrielle européenne	Débat Politique industrielle européenne	2019-04-03 18:40:00	2019-04-03 20:20:00	\N	\N	74	0	\N	\N
356299	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Avenir institutionnel Alsace	PJL Avenir institutionnel Alsace	2019-04-03 21:50:00	2019-04-04 01:15:00	\N	\N	65	0	\N	\N
356301	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2019-04-04 15:00:00	2019-04-04 16:05:00	\N	\N	265	0	\N	\N
356303	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Actionnariat sociétés	PPL Actionnariat sociétés	2019-04-04 16:25:00	2019-04-04 17:55:00	\N	\N	61	0	\N	\N
356304	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Interdiction vente drapeaux anciens combattants	PPL Interdiction vente drapeaux anciens combattants	2019-04-04 18:05:00	2019-04-04 19:25:00	\N	\N	29	0	\N	\N
356305	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2019-04-09 09:30:00	2019-04-09 12:45:00	\N	\N	54	0	\N	\N
356308	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL PACTE nouvelle lecture	PJL PACTE nouvelle lecture	2019-04-09 14:30:00	2019-04-09 16:45:00	\N	\N	119	0	\N	\N
356312	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Office français biodiversité	PJL Office français biodiversité	2019-04-10 14:30:00	2019-04-10 16:20:00	\N	\N	112	0	\N	\N
356313	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Office français biodiversité	PJL Office français biodiversité	2019-04-10 22:10:00	2019-04-11 01:30:00	\N	\N	80	0	\N	\N
356314	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Office français biodiversité	PJL Office français biodiversité	2019-04-11 10:30:00	2019-04-11 13:25:00	\N	\N	87	0	\N	\N
356315	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Office français biodiversité	PJL Office français biodiversité	2019-04-11 16:15:00	2019-04-11 20:40:00	\N	\N	63	0	\N	\N
356317	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2019-04-11 15:00:00	2019-04-11 16:00:00	\N	\N	240	0	\N	\N
356319	COM_PERMANENTE	DEPLACEMENT	\N	CAE	\N	PPL Lutte contre l'habitat insalubre - Déplacement en Seine-Saint-Denis	PPL Lutte contre l'habitat insalubre - Déplacement en Seine-Saint-Denis	2019-02-28 07:30:00	2019-02-28 15:30:00	\N	\N	4	0	\N	\N
356324	COM_PERMANENTE	DEPLACEMENT	\N	CAE	\N	PPL Lutte contre l'habitat insalubre - Déplacement à Marseille	PPL Lutte contre l'habitat insalubre - Déplacement à Marseille	2019-03-01 05:45:00	2019-03-01 21:50:00	\N	\N	5	0	\N	\N
356333	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Nouveaux territoires de l'éducation	MI Nouveaux territoires de l'éducation	2019-03-04 11:00:00	2019-03-04 12:00:00	\N	\N	4	0	\N	\N
356338	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Nouveaux territoires de l'éducation	MI Nouveaux territoires de l'éducation	2019-03-04 15:00:00	2019-03-04 17:00:00	\N	\N	5	0	\N	\N
302538	CMP	AUTRE	\N	VIOLENCES	\N	PJL Lutte contre les violences sexuelles et sexistes	PJL Lutte contre les violences sexuelles et sexistes	2018-07-23 18:06:00	2018-07-23 18:36:00	\N	\N	9	0	\N	\N
356330	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Nomination rapporteurs - Examen amendements de séances - Examen rapport et texte	\N	2019-03-06 09:05:00	2019-03-06 11:00:00	2019-03-06 14:51:09	2019-03-06 16:49:24	41	1	\N	\N
356618	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Prévenir et sanctionner les violences lors des manifestations	\N	2019-03-04 17:00:00	2019-03-04 19:00:00	\N	\N	1	0	\N	\N
356747	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Nouveaux territoires de l'éducation	MI Nouveaux territoires de l'éducation	2019-03-05 15:00:00	2019-03-05 16:00:00	\N	\N	3	0	\N	\N
356751	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Nouveaux territoires de l'éducation	MI Nouveaux territoires de l'éducation	2019-03-05 16:00:00	2019-03-05 16:45:00	\N	\N	3	0	\N	\N
356855	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-03-06 10:25:00	2019-03-06 11:25:00	2019-03-06 11:54:34	2019-03-06 16:49:15	29	0	\N	\N
356985	GIA	AUCUNE	\N	\N	\N	Déjeuner en l'honneur de Miss Népal	\N	2019-03-05 12:30:00	2019-03-05 14:15:00	\N	\N	2	0	633	\N
357100	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition pour suite à donner à l'enquête de la Cour des comptes sur la CGLLS	\N	2019-03-06 11:00:00	2019-03-06 12:45:00	2019-03-06 18:16:16	2019-03-07 12:20:40	34	0	\N	\N
357103	DELEGATION	AUDRAP	\N	\N	PROS	Audition de Jean-Yves Potel	Audition de Jean-Yves Potel	2019-03-12 09:30:00	2019-03-12 11:15:00	\N	\N	1	0	\N	\N
357139	DELEGATION	AUDRAP	\N	\N	PROS	Audition de Mme Catherine Simon	\N	2019-04-03 14:30:00	2019-04-03 15:45:00	\N	\N	2	0	\N	\N
357152	DELEGATION	AUCUNE	\N	\N	COLTER	Audition AdCF - Communes et intercommunalités	\N	2019-03-14 09:00:00	2019-03-14 10:45:00	2019-03-14 11:40:10	\N	13	0	\N	\N
357271	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-03-06 14:35:00	2019-03-06 16:45:00	2019-03-06 17:02:38	2019-03-07 12:20:39	37	0	\N	\N
357391	ETUDES	AUCUNE	\N	\N	\N	Audition du Centre national de la propriété forestière	Audition de représentants du Centre national de la propriété forestière	2019-03-06 08:00:00	2019-03-06 09:45:00	\N	\N	10	0	\N	948
357422	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Mission évaluation du contrat d'objectifs et de performance (COP) 2016-2020	Mission évaluation du contrat d'objectifs et de performance (COP) 2016-2020 de l'ONF	2019-03-06 14:30:00	2019-03-06 16:30:00	\N	\N	5	0	\N	\N
358661	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL École de la confiance	PJL École de la confiance	2019-03-06 16:30:00	2019-03-06 18:45:00	\N	\N	2	0	\N	\N
358664	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Frais d'inscription à l'université pour les étrangers extra-communautaires	\N	2019-03-07 08:45:00	2019-03-07 12:30:00	\N	\N	3	0	\N	\N
213290	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 	PLF pour 2018 - Sécurités "Police nationale " et "gendarmerie nationale" - DGGN Directeur	2017-10-26 17:00:00	2017-10-26 18:00:00	\N	\N	1	0	\N	\N
214596	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour  2018 - Engagements financiers de l'Etat	PLF pour  2018 - Engagements financiers de l'Etat - Direction générale des finances publiques	2017-11-02 15:00:00	2017-11-02 16:00:00	\N	\N	1	0	\N	\N
214598	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour  2018 - Engagements financiers de l'Etat	PLF pour  2018 - Engagements financiers de l'Etat - Banque de France	2017-11-03 10:00:00	2017-11-03 11:00:00	\N	\N	1	0	\N	\N
220246	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2018	\N	2017-11-14 14:30:00	2017-11-14 16:45:00	\N	\N	1	0	\N	\N
220248	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2018	\N	2017-11-15 14:30:00	2017-11-15 18:40:00	\N	\N	3	0	\N	\N
220260	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2018	\N	2017-11-16 15:30:00	2017-11-16 16:45:00	\N	\N	2	0	\N	\N
220263	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2018	\N	2017-11-16 18:55:00	2017-11-16 20:00:00	\N	\N	2	0	\N	\N
223694	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de M. Éric LOMBARD, candidat proposé à la CDC, article 13	Audition de M. Éric LOMBARD, candidat proposé à la Caisse des dépôts et consignations (CDC), article 13	2017-11-28 09:05:00	2017-11-28 10:40:00	2017-11-29 16:34:55	2017-11-29 16:48:55	28	0	\N	\N
223695	COM_PERMANENTE	AUTRE	\N	FINC	\N	Communication sur le projet de décret d'avance du 21 novembre 2017	Communication sur le projet de décret d'avance du 21 novembre 2017	2017-11-28 16:05:00	2017-11-28 16:20:00	2017-11-29 16:35:16	2017-11-29 16:48:59	29	1	\N	\N
224734	MECSS	AUCUNE	\N	\N	MECSS	\N	\N	2017-11-29 17:30:00	2017-11-29 18:15:00	2017-11-29 18:14:22	2017-11-30 11:53:50	11	0	\N	\N
228551	DELEGATION	DEPLACEMENT	\N	\N	COLTER	GT revitalisation - Déplacement à Châtellerault	\N	2017-12-08 07:35:00	2017-12-08 18:25:00	\N	\N	2	0	\N	\N
228574	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	Audition GT Infractions sexuelles	2017-12-11 14:15:00	2017-12-11 17:15:00	\N	\N	4	0	\N	\N
230590	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2017-12-13 17:10:00	2017-12-13 17:25:00	\N	\N	3	0	\N	\N
233168	DELEGATION	AUCUNE	\N	\N	DSOM	Déplacement à Orléans (BRGM)	Déplacement à Orléans et rencontres au BRGM	2018-01-29 09:00:00	2018-01-29 18:00:00	2018-01-30 10:27:58	2018-01-31 11:28:44	4	0	\N	\N
233171	DELEGATION	AUCUNE	\N	\N	DSOM	Auditions Risques naturels majeurs 	Auditions Étude sur les Risques naturels majeurs	2018-01-30 14:45:00	2018-01-30 18:10:00	2018-01-31 09:11:07	2018-01-31 11:28:45	15	0	\N	\N
234416	GIA	AUCUNE	\N	\N	\N	AG du groupe	Assemblée générale du groupe et désignation du Bureau	2018-01-16 17:45:00	2018-01-16 18:15:00	\N	\N	4	0	633	\N
234421	GIA	AUCUNE	\N	\N	\N	AG du groupe	Assemblée générale du groupe et désignation du Bureau	2018-01-16 14:00:00	2018-01-16 14:30:00	\N	\N	5	0	615	\N
235285	GIA	AUCUNE	\N	\N	\N	Assemblée générale	\N	2018-01-16 14:00:00	2018-01-16 14:30:00	\N	\N	11	0	610	\N
235507	GIA	AUCUNE	\N	\N	\N	AG du groupe	Assemblée générale du groupe et désignation du Bureau	2018-01-16 18:00:00	2018-01-16 18:30:00	\N	\N	10	0	605	\N
237781	GIA	AUCUNE	\N	\N	\N	Déjeuner de travail Lechervy ambassadeur, secrétaire permanent pour le Pacifique	\N	2018-01-24 12:30:00	2018-01-24 14:00:00	\N	\N	15	0	651	\N
241201	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT Convergence sociale	GT Convergence sociale	2018-01-17 16:00:00	2018-01-17 17:00:00	\N	\N	1	0	\N	\N
241203	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT Convergence sociale	GT Convergence sociale	2018-01-30 15:30:00	2018-01-30 18:00:00	\N	\N	1	0	\N	\N
242610	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2018-02-07 16:00:00	2018-02-07 17:30:00	\N	\N	2	0	\N	\N
242612	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2018-02-08 09:00:00	2018-02-08 10:00:00	\N	\N	3	0	\N	\N
242643	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2018-02-08 10:00:00	2018-02-08 11:00:00	\N	\N	3	0	\N	\N
242645	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2018-02-15 13:30:00	2018-02-15 14:30:00	\N	\N	3	0	\N	\N
356854	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-03-06 09:40:00	2019-03-06 10:25:00	2019-03-06 11:52:46	2019-03-06 16:49:17	41	0	\N	\N
223696	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2018 - Examen Amdts séance Mission RCT et 9 autres	PLF pour 2018 - Examen Amdts séance Mission RCT et 9 autres	2017-11-29 09:00:00	2017-11-29 10:00:00	2017-11-29 16:35:49	2017-11-29 16:50:35	41	0	\N	\N
242655	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2018-02-15 10:30:00	2018-02-15 11:30:00	\N	\N	2	0	\N	\N
243388	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe	\N	2018-02-07 13:45:00	2018-02-07 14:15:00	\N	\N	5	0	603	\N
245197	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion	Réunion	2018-02-14 09:35:00	2018-02-14 12:10:00	2018-02-14 12:18:11	2018-02-14 13:53:51	30	0	\N	\N
248851	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2018-02-21 10:50:00	2018-02-21 12:10:00	2018-02-21 15:05:26	2018-02-21 15:55:03	62	0	\N	\N
250070	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	FIN - CIVS - Audition Louvre - DP	\N	2018-02-22 10:30:00	2018-02-22 12:15:00	\N	\N	1	0	\N	\N
250128	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	\N	\N	2018-03-06 18:00:00	2018-03-06 19:00:00	\N	\N	0	0	\N	\N
250132	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Polyhandicap, FHF	\N	2018-03-20 13:00:00	2018-03-20 15:00:00	\N	\N	0	0	\N	\N
251100	COM_ENQUETE	PLENIERE	\N	FORCES	\N	\N	\N	2018-03-07 15:45:00	2018-03-07 18:15:00	2018-03-07 18:50:36	2018-03-08 10:00:34	11	0	\N	\N
252529	GIA	AUCUNE	\N	\N	\N	GIA France-Mongolie - Assemblée générale 	GIA France-Mongolie - Assemblée générale 	2018-03-08 14:35:00	2018-03-08 15:05:00	\N	\N	7	0	612	\N
253076	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Libye	\N	2018-03-06 15:00:00	2018-03-06 16:40:00	\N	\N	4	0	\N	\N
253081	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	\N	\N	2018-03-07 09:30:00	2018-03-07 10:45:00	\N	\N	6	0	\N	\N
254465	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Compétences eau et assainissement aux communautés de communes	\N	2018-03-13 14:25:00	2018-03-13 16:40:00	\N	\N	2	0	\N	\N
255946	MECSS	AUDRAP	\N	\N	MECSS	\N	Accès précoce à l'innovation dans le domaine de produits de santé	2018-03-21 14:30:00	2018-03-21 16:30:00	\N	\N	3	0	\N	\N
256014	GIA	AUCUNE	\N	\N	\N	Entretien de M. Jean-Marie BOCKEL avec M. Antoine Bienaimé OBAM'ONDON, député du Congo	Entretien de M. JM. BOCKEL avec M. Antoine Bienaimé OBAM'ONDON, député du Congo (coopé)	2018-03-14 17:30:00	2018-03-14 18:30:00	\N	\N	1	0	572	\N
258642	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2018-03-27 18:00:00	2018-03-27 19:25:00	2018-03-28 14:04:23	2018-03-28 14:38:00	31	0	\N	\N
258735	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle budgétaire 2018 - Les maisons de l'emploi	Contrôle budgétaire 2018 - Les maisons de l'emploi - Pôle Emploi	2018-03-21 14:00:00	2018-03-21 15:00:00	\N	\N	2	0	\N	\N
258739	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Défense - Disponibilité des hélicoptères du ministères des Armées	Contrôle 2018 - Défense - Disponibilité des hélicoptères du ministères des Armées - Simmad	2018-03-20 14:30:00	2018-03-20 15:30:00	\N	\N	1	0	\N	\N
258748	DELEGATION	AUCUNE	\N	\N	DSOM	Visioconférence avec Wallis-et-Futuna  (Jeunesse des outre-mer et sport)	Visioconférence avec Wallis-et-Futuna (Jeunesse des outre-mer et sport)	2018-03-27 08:30:00	2018-03-27 10:15:00	2018-03-27 11:01:46	2018-03-27 14:34:55	5	0	\N	\N
258752	DELEGATION	AUCUNE	\N	\N	DSOM	Visioconférence avec Saint-Pierre-et-Mquelon  (Jeunesse dans les outre-mer et sport)	Visioconférence avec Saint-Pierre-et-Mquelon (Jeunesse dans les outre-mer et sport)	2018-03-27 18:00:00	2018-03-27 19:35:00	2018-03-27 20:10:59	2018-03-28 11:39:00	6	0	\N	\N
258757	DELEGATION	AUCUNE	\N	\N	DSOM	Visioconférence avec la Guyane (risques naturels majeurs outre-mer)	Visioconférence avec la Guyane (risques naturels majeurs)	2018-04-11 16:00:00	2018-04-11 18:00:00	2018-04-11 18:35:54	2018-04-12 10:09:52	9	0	\N	\N
258758	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	DSOM	Rencontre avec l'AFD	Rencontre avec l'AFD	2018-04-12 08:00:00	2018-04-12 09:00:00	\N	\N	11	0	\N	\N
258759	DELEGATION	AUCUNE	\N	\N	DSOM	Audition Réseaux sociaux et Initiatives citoyennes (risques naturels majeurs outre-mer)	Audition Réseaux sociaux et Initiatives citoyennes (risques naturels majeurs outre-mer)	2018-04-12 09:15:00	2018-04-12 12:15:00	2018-04-12 14:30:10	2018-04-12 18:13:32	8	0	\N	\N
214057	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2017-11-08 14:00:00	2017-11-08 16:00:00	\N	\N	1	0	\N	\N
279829	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Lutte contre les violences sexuelles et sexistes	\N	2018-06-05 14:30:00	2018-06-05 15:15:00	\N	\N	1	0	\N	\N
282363	ETUDES	AUCUNE	\N	\N	\N	GE Vigne et Vin	GE Vignt et Vin	2018-06-07 13:30:00	2018-06-07 14:50:00	\N	\N	24	0	\N	909
282490	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2018-06-12 08:30:00	2018-06-12 10:15:00	2018-06-12 13:58:49	2018-06-12 15:37:22	32	1	\N	\N
283115	DELEGATION	DEPLACEMENT	\N	\N	ENTREPRISES	Déplacement Seine-Maritime	Déplacement Seine-Maritime	2018-06-11 06:20:00	2018-06-11 20:40:00	\N	\N	8	0	\N	\N
286107	COM_ENQUETE	PLENIERE	\N	HAUTE	\N	Audition	Audition	2018-06-14 11:35:00	2018-06-14 12:25:00	2018-06-14 19:20:31	2018-06-15 10:40:55	6	0	\N	\N
286115	COM_ENQUETE	PLENIERE	\N	HAUTE	\N	Audition	Audition	2018-06-14 16:30:00	2018-06-14 17:40:00	2018-06-14 19:22:33	2018-06-15 10:40:55	8	0	\N	\N
286125	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 14 juin	Réunion du 14 juin	2018-06-14 09:00:00	2018-06-14 10:20:00	2018-06-21 15:55:28	2018-06-21 15:55:41	17	0	\N	\N
294346	COM_ENQUETE	AUDRAP	\N	HAUTE	\N	\N	\N	2018-07-03 14:00:00	2018-07-03 15:00:00	\N	\N	4	0	\N	\N
294359	COM_ENQUETE	PLENIERE	\N	HAUTE	\N	Auditions	Auditions	2018-07-03 15:05:00	2018-07-03 19:30:00	2018-07-06 17:24:15	2018-07-06 17:53:16	9	0	\N	\N
299863	GIA	AUCUNE	\N	\N	\N	Réunion du GIA France-Balkans occidentaux	Entretien avec l'Ambassadrice de Macédoine, Mme Jadranka CHAUSHEVSKA DIMOV	2018-07-18 08:30:00	2018-07-18 09:25:00	\N	\N	4	0	674	\N
305282	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	Auditions Mme Deroche	\N	2018-09-13 14:30:00	2018-09-13 18:00:00	\N	\N	0	0	\N	\N
305295	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Comités de protection des personnes	\N	2018-09-12 09:00:00	2018-09-12 11:45:00	\N	\N	1	0	\N	\N
305297	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Comités de protection des personnes	\N	2018-09-12 14:00:00	2018-09-12 17:00:00	\N	\N	1	0	\N	\N
305299	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Comités de protection des personnes	\N	2018-09-13 09:00:00	2018-09-13 10:00:00	\N	\N	1	0	\N	\N
248850	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2018-02-21 09:05:00	2018-02-21 10:10:00	2018-02-22 20:08:44	2018-02-23 09:59:41	43	0	\N	\N
258643	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2018-03-28 09:00:00	2018-03-28 09:55:00	2018-05-18 14:09:40	2018-05-18 14:09:45	45	1	\N	\N
305300	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Comités de protection des personnes	\N	2018-09-13 10:00:00	2018-09-13 11:00:00	\N	\N	1	0	\N	\N
305301	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Comités de protection des personnes	\N	2018-09-13 11:00:00	2018-09-13 12:00:00	\N	\N	1	0	\N	\N
305305	COM_PERMANENTE	DEPLACEMENT	\N	SOCI	\N	PPL Comités de protection des personnes	\N	2018-09-18 11:45:00	2018-09-18 13:30:00	\N	\N	1	0	\N	\N
336972	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-12-11 16:00:00	2018-12-11 19:15:00	\N	\N	1	0	\N	\N
339913	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Orientation des mobilités	\N	2018-12-18 15:40:00	2018-12-18 16:40:00	\N	\N	1	0	\N	\N
339915	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Permis à points et baisse de la limitation de vitesse à 80 km/h	\N	2018-12-18 15:30:00	2018-12-18 16:30:00	\N	\N	2	0	\N	\N
339918	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Permis à points et baisse de la limitation de vitesse à 80 km/h	\N	2018-12-19 15:00:00	2018-12-19 15:30:00	\N	\N	1	0	\N	\N
346259	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	GT ruralités : Table ronde "Relations Etat et collectivités en zone rurale"	\N	2019-01-31 13:30:00	2019-01-31 15:00:00	\N	\N	11	0	\N	\N
350871	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Conséquences de la fraude documentaire sur la fraude aux prestations sociales	\N	2019-02-12 17:00:00	2019-02-12 18:00:00	\N	\N	5	0	\N	\N
350872	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Conséquences de la fraude documentaire sur la fraude aux prestations sociales	\N	2019-02-13 11:00:00	2019-02-13 12:00:00	\N	\N	2	0	\N	\N
350873	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Conséquences de la fraude documentaire sur la fraude aux prestations sociales	\N	2019-02-20 09:00:00	2019-02-20 10:00:00	\N	\N	2	0	\N	\N
350892	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Reconstruction mammaire en cas de mastectomie	PropositInformation aux patientes sur la reconstruction mammaire en cas de mastectomie	2019-01-31 10:30:00	2019-01-31 11:15:00	\N	\N	1	0	\N	\N
350894	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Reconstruction mammaire en cas de mastectomie	Proposition de loi visant à fournir une information aux patientes sur la reconstruction mammaire en cas de mastectomie	2019-02-06 10:15:00	2019-02-06 11:00:00	\N	\N	2	0	\N	\N
350897	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Reconstruction mammaire en cas de mastectomie	Proposition de loi visant à fournir une information aux patientes sur la reconstruction mammaire en cas de mastectomie	2019-02-06 11:00:00	2019-02-06 11:45:00	\N	\N	2	0	\N	\N
350898	DELEGATION	AUDRAP	\N	\N	PROS	Audition de l'AMF	\N	2019-03-05 10:00:00	2019-03-05 11:00:00	\N	\N	1	0	\N	\N
352504	MISSION	AUCUNE	\N	BREXIT2	\N	\N	\N	2019-02-13 15:05:00	2019-02-14 16:45:00	2019-02-13 17:26:20	2019-02-13 17:42:04	12	0	\N	\N
352528	GIA	AUCUNE	\N	\N	\N	rencontre avec M l'ambassadeur de Corée du Sud	rencontre avec M l'ambassadeur de Corée du Sud	2019-01-23 19:00:00	2019-01-23 23:00:00	\N	\N	3	0	613	\N
352836	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Pass Culture	Pass Culture	2019-02-13 09:00:00	2019-02-13 09:30:00	\N	\N	6	0	\N	\N
352937	ETUDES	AUCUNE	\N	\N	\N	Visite du Stade de France	Visite du Stade de France	2019-02-12 17:00:00	2019-02-12 19:30:00	\N	\N	8	0	\N	934
353053	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Améliorer la lisibilité du droit	PPL Améliorer la lisibilité du droit	2019-02-14 10:00:00	2019-02-14 12:00:00	\N	\N	1	0	\N	\N
353675	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Turquie	\N	2019-02-13 14:30:00	2019-02-13 15:45:00	\N	\N	2	0	\N	\N
353678	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Turquie	\N	2019-02-13 15:45:00	2019-02-13 17:00:00	\N	\N	2	0	\N	\N
353681	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Turquie	\N	2019-02-13 17:00:00	2019-02-13 18:15:00	\N	\N	2	0	\N	\N
353730	ETUDES	AUCUNE	\N	\N	\N	G.E. "Elevage"	G.E. "Elevage"	2019-02-14 13:45:00	2019-02-14 14:45:00	\N	\N	10	0	\N	911
353741	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	GT "Climat et environnement"	GT "Climat et environnement"	2019-02-14 09:30:00	2019-02-14 10:30:00	\N	\N	6	0	\N	\N
353796	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL n° 157 (2018-2019) Orientation des mobilités - RATP	PJL n° 157 (2018-2019) Orientation des mobilités - RATP	2019-02-13 14:30:00	2019-02-13 15:30:00	\N	\N	1	0	\N	\N
353806	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 2019 - ANRU Nouveau programme national de renouvellement urbain (NPNRU)	58-2 2019 - ANRU Nouveau programme national de renouvellement urbain (NPNRU) - Cour des Comptes	2019-02-13 14:30:00	2019-02-13 15:05:00	\N	\N	1	0	\N	\N
353808	COM_PERMANENTE	AUTRE	\N	FINC	\N	Contrôles budgétaires SMA et Amendes pénales et Audition 58-2 dette entités publiques	Contrôles budgétaires SMA et Amendes pénales et Audition 58-2 dette entités publiques	2019-02-20 09:15:00	2019-02-20 12:35:00	2019-02-20 12:45:54	2019-02-20 15:04:00	41	0	\N	\N
353812	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition Gérald DARMANIN, ministre de l'action et des comptes publics, résultats 2018	Audition de M. Gérald DARMANIN, ministre de l'action et des comptes publics, sur les résultats de l'exercice 2018	2019-02-21 10:35:00	2019-02-21 12:30:00	2019-02-21 12:55:02	2019-02-21 17:56:26	29	0	\N	\N
353814	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Engagement associatif	PPL Engagement associatif	2019-02-13 11:30:00	2019-02-13 12:30:00	\N	\N	1	0	\N	\N
353815	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Engagement associatif	PPL Engagement associatif	2019-02-15 10:00:00	2019-02-15 10:30:00	\N	\N	1	0	\N	\N
353820	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Nouveaux territoires de l'éducation	MI Nouveaux territoires de l'éducation	2019-02-13 17:00:00	2019-02-13 18:00:00	\N	\N	11	0	\N	\N
213278	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Écologie, développement et mobilité durables/Transports	PLF pour 2018 - Écologie, développement et mobilité durables/Transports - Auditions SNCF Réseau, DGITM	2017-10-25 15:30:00	2017-10-25 17:30:00	\N	\N	1	0	\N	\N
213280	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Écologie, développement et mobilité durables/Énergie	PLF pour 2018 - Écologie, développement et mobilité durables/Énergie - Audition SER	2017-10-25 14:30:00	2017-10-25 15:30:00	\N	\N	1	0	\N	\N
213282	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2018 - Écologie, développement et mobilité durables/Transports	PLF pour 2018 - Écologie, développement et mobilité durables/Transports - Audition Ministère transition écologique	2017-10-26 09:30:00	2017-10-26 11:30:00	\N	\N	1	0	\N	\N
213287	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de finances 2018	Loi de finances 2018 (Audiovisuel)	2017-10-26 15:00:00	2017-10-26 17:45:00	\N	\N	2	0	\N	\N
213291	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de finances 2018	\N	2017-10-24 09:30:00	2017-10-24 10:30:00	\N	\N	2	0	\N	\N
213294	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de finances 2018	Loi de finances 2018 (Recherche)	2017-10-24 15:00:00	2017-10-24 16:45:00	\N	\N	1	0	\N	\N
213296	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de finances 2018	Loi de finances 2018 (Recherche)	2017-10-25 08:30:00	2017-10-25 11:30:00	\N	\N	1	0	\N	\N
213298	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de finances 2018	Loi de finances 2018 (Recherche)	2017-10-26 08:30:00	2017-10-26 11:30:00	\N	\N	1	0	\N	\N
213300	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de finances 2018	Loi de finances 2018 (Enseignement supérieur)	2017-10-26 10:00:00	2017-10-26 12:00:00	\N	\N	1	0	\N	\N
213302	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de finances 2018	Loi de finances 2018 (Enseignement scolaire)	2017-10-25 09:30:00	2017-10-25 12:00:00	\N	\N	1	0	\N	\N
213304	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de finances 2018	Loi de finances 2018 (Enseignement scolaire)	2017-10-26 09:30:00	2017-10-26 10:30:00	\N	\N	1	0	\N	\N
213306	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de finances 2018	Loi de finances 2018 (Enseignement scolaire)	2017-10-26 14:00:00	2017-10-26 15:00:00	\N	\N	1	0	\N	\N
213308	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de finances 2018	Loi de finances 2018 (Création et transmission des savoirs)	2017-10-24 15:15:00	2017-10-24 16:15:00	\N	\N	2	0	\N	\N
213311	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de finances 2018	Loi de finances 2018 (Création et transmission des savoirs)	2017-10-24 17:30:00	2017-10-24 18:30:00	\N	\N	3	0	\N	\N
213315	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de finances 2018	Loi de finances 2018 (Création et transmission des savoirs)	2017-10-26 15:30:00	2017-10-26 16:30:00	\N	\N	3	0	\N	\N
214626	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion de commission	Réunion de la commission des affaires européennes du 9 novembre 2017	2017-11-09 08:35:00	2017-11-09 10:20:00	2017-11-09 11:11:45	2017-11-09 16:01:27	19	0	\N	\N
215512	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2018 - Avis Justice judiciaire	\N	2017-11-07 09:45:00	2017-11-07 12:00:00	\N	\N	1	0	\N	\N
215514	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2018 - Avis Justice judiciaire	\N	2017-11-07 17:15:00	2017-11-07 21:15:00	\N	\N	1	0	\N	\N
216304	BUREAU	AUCUNE	\N	\N	\N	Bureau du Sénat	Bureau du Sénat	2017-10-26 09:05:00	2017-10-26 11:30:00	\N	\N	25	0	\N	\N
216331	BUREAU	AUCUNE	\N	\N	\N	Bureau du Sénat	Bureau du Sénat	2017-11-09 09:05:00	2017-11-09 09:45:00	\N	\N	23	0	\N	\N
217418	COM_EURO	AUDRAP	\N	AFEU	\N	Contôle investissements étrangers	Contrôle des investissements étrangers	2017-11-08 15:00:00	2017-11-08 18:30:00	\N	\N	2	0	\N	\N
217423	COM_EURO	AUDRAP	\N	AFEU	\N	Contrôle investissements étrangers	Contrôle des investissements étrangers	2017-11-09 16:00:00	2017-11-09 17:45:00	\N	\N	2	0	\N	\N
217474	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2018 - Missions GFPRH et Économie - Station F et French Tech Central	PLF pour 2018 - Missions GFPRH et Économie - Visite Station F et French Tech Central	2017-11-10 10:00:00	2017-11-10 13:00:00	\N	\N	2	0	\N	\N
228072	COM_PERMANENTE	AUTRE	\N	CDD	\N	Communication sur le déplacement à la COP23, et le déplacement à Bruxelles	Communication sur le déplacement à la COP23, et le déplacement à Bruxelles	2017-12-13 09:35:00	2017-12-13 11:50:00	2017-12-13 16:29:23	2017-12-13 16:30:32	35	0	\N	\N
228416	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLFR pour 2017 - Examen amendements de séance	PLFR pour 2017 - Examen amendements de séance	2017-12-15 08:35:00	2017-12-15 09:15:00	2017-12-15 12:43:15	2017-12-15 14:59:55	20	1	\N	\N
228891	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Expertise internationale	\N	2017-11-09 08:30:00	2017-11-09 09:30:00	\N	\N	8	0	\N	\N
228901	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Expertise internationale	\N	2017-11-29 14:30:00	2017-11-29 15:30:00	\N	\N	2	0	\N	\N
229511	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Orientation et réussite des étudiants	PJL Orientation et réussite des étudiants	2017-12-12 09:30:00	2017-12-12 12:00:00	\N	\N	1	0	\N	\N
229514	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Orientation et réussite des étudiants	PJL Orientation et réussite des étudiants	2017-12-13 14:00:00	2017-12-13 15:00:00	\N	\N	2	0	\N	\N
229517	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Orientation et réussite des étudiants	PJL Orientation et réussite des étudiants	2017-12-13 15:00:00	2017-12-13 16:00:00	\N	\N	3	0	\N	\N
229521	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Orientation et réussite des étudiants	PJL Orientation et réussite des étudiants	2017-12-13 16:00:00	2017-12-13 17:00:00	\N	\N	2	0	\N	\N
229605	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI contrats aidés	MI contrats aidés	2017-12-13 15:00:00	2017-12-13 17:00:00	\N	\N	2	0	\N	\N
232954	DELEGATION	AUDRAP	\N	\N	PROS	Audition de Michel Savy	Audition de Michel Savy dans le cadre du rapport sur les nouvelles mobilités	2018-01-30 10:00:00	2018-01-30 11:05:00	\N	\N	2	0	\N	\N
233020	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Application du régime d'asile européen	\N	2018-01-10 10:40:00	2018-01-10 11:00:00	\N	\N	2	0	\N	\N
233023	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Application du régime d'asile européen	\N	2018-01-10 14:10:00	2018-01-10 15:00:00	\N	\N	2	0	\N	\N
233026	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Application du régime d'asile européen	\N	2018-01-10 15:10:00	2018-01-10 15:50:00	\N	\N	3	0	\N	\N
243358	GIA	AUCUNE	\N	\N	\N	Dîner du groupe à l'invitation de M. l'Ambassadeur du Maroc 	Dîner du groupe à l'invitation de M. l'Ambassadeur du Maroc 	2018-02-06 20:00:00	2018-02-06 22:30:00	\N	\N	29	0	598	\N
244022	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe	Assemblée générale du groupe	2018-01-24 14:00:00	2018-01-24 14:30:00	\N	\N	1	0	550	\N
244031	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe	Assemblée générale du groupe	2018-01-30 18:00:00	2018-01-30 18:30:00	\N	\N	3	0	648	\N
245801	COM_SPECIALE	AUDRAP	\N	SOCIETE	\N	\N	\N	2018-02-13 13:45:00	2018-02-13 20:00:00	\N	\N	12	0	\N	\N
250596	GIA	AUCUNE	\N	\N	\N	Entretien avec un chef d'entreprise chinois	\N	2018-03-06 17:30:00	2018-03-06 18:30:00	\N	\N	7	0	584	\N
259175	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL "tarification sociale de l'eau"	PPL"tarification sociale de l'eau"	2018-03-20 17:45:00	2018-03-20 19:00:00	\N	\N	1	0	\N	\N
259180	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL "tarification sociale de l'eau"	PPL "tarification sociale de l'eau"	2018-03-21 17:00:00	2018-03-21 18:00:00	\N	\N	1	0	\N	\N
259193	ETUDES	AUCUNE	\N	\N	\N	Groupe d'études Développement économique de la montagne	Groupe d'études Développement économique de la montagne	2018-03-21 14:30:00	2018-03-21 18:00:00	\N	\N	12	0	\N	918
259466	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition cycle de vie des entreprises	Audition cycle de vie des entreprises - CIP	2018-03-27 10:00:00	2018-03-27 11:00:00	\N	\N	1	0	\N	\N
259476	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition cycle de vie des entreprises	Audition cycle de vie des entreprises - Jean-N	2018-03-27 14:40:00	2018-03-27 16:00:00	\N	\N	1	0	\N	\N
260927	GIA	AUCUNE	\N	\N	\N	Rencontre M. Cazeau Shunas Abdullah	Rencontre entre M. Cazeau et M. Shunas Abdullah, membre du parti Gorran	2018-03-28 18:15:00	2018-03-28 19:00:00	\N	\N	1	0	615	\N
260929	GIA	AUCUNE	\N	\N	\N	Déjeuner avec Hosham Dawod	Déjeuner du groupe d'amitié avec Hosham Dawod, anthropologue spécialiste de l'Irak	2018-04-11 13:00:00	2018-04-11 14:30:00	\N	\N	2	0	615	\N
214482	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Réhabiliter la police de proximité	\N	2017-10-31 14:45:00	2017-10-31 16:45:00	\N	\N	1	0	\N	\N
282395	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2018-06-13 14:30:00	2018-06-13 18:30:00	\N	\N	1	0	\N	\N
273607	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL "Agriculture"	PJL "Agriculture"	2018-04-20 09:00:00	2018-04-20 12:30:00	\N	\N	1	0	\N	\N
273611	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL "Agriculture"	\N	2018-04-23 17:15:00	2018-04-23 19:00:00	\N	\N	1	0	\N	\N
284615	GIA	AUCUNE	\N	\N	\N	Ambassadeur de Géorgie	Petit-déjeuner en l'honneur de l'ambassadeur de Géorgie en France	2018-06-13 08:30:00	2018-06-13 09:20:00	\N	\N	7	0	534	\N
289070	MISSION	AUCUNE	\N	HERBE	\N	Audition plénière	\N	2018-06-21 16:30:00	2018-06-21 17:45:00	2018-06-21 18:12:54	2018-06-22 15:07:28	5	0	\N	\N
289102	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Programmation militaire	CMP Programmation militaire	2018-06-28 10:30:00	2018-06-28 11:40:00	\N	\N	47	0	\N	\N
289103	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2018-07-03 09:35:00	2018-07-03 12:15:00	\N	\N	35	0	\N	\N
289104	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Lutte contre la fraude	PJL Lutte contre la fraude	2018-07-03 14:30:00	2018-07-03 20:05:00	\N	\N	140	0	\N	\N
289105	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Lutte contre la fraude	PJL Lutte contre la fraude	2018-07-03 21:35:00	2018-07-04 00:40:00	\N	\N	59	0	\N	\N
289108	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Violences sexuelles	PJL Violences sexuelles	2018-07-04 21:45:00	2018-07-05 00:35:00	\N	\N	71	0	\N	\N
289109	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Violences sexuelles	PJL Violences sexuelles	2018-07-05 10:30:00	2018-07-05 13:20:00	\N	\N	93	0	\N	\N
289110	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2018-07-05 15:00:00	2018-07-05 16:10:00	\N	\N	176	0	\N	\N
289111	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Violences sexuelles	PJL Violences sexuelles	2018-07-05 16:20:00	2018-07-05 18:55:00	\N	\N	60	0	\N	\N
289178	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Avenir professionnel	PJL Avenir professionnel	2018-07-10 14:30:00	2018-07-10 16:30:00	\N	\N	177	0	\N	\N
289179	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2018-07-10 16:45:00	2018-07-10 17:40:00	\N	\N	279	0	\N	\N
289180	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Avenir professionnel	PJL Avenir professionnel	2018-07-10 17:45:00	2018-07-10 19:45:00	\N	\N	121	0	\N	\N
289181	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Avenir professionnel	PJL Avenir professionnel	2018-07-10 22:15:00	2018-07-11 01:20:00	\N	\N	92	0	\N	\N
289182	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Avenir professionnel	PJL Avenir professionnel	2018-07-11 14:30:00	2018-07-11 19:00:00	\N	\N	172	0	\N	\N
289183	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Avenir professionnel	PJL Avenir professionnel	2018-07-11 21:00:00	2018-07-12 01:35:00	\N	\N	87	0	\N	\N
289184	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Concurrence Polynésie et Nouvelle-Calédonie	CMP Concurrence Polynésie et Nouvelle-Calédonie	2018-07-12 14:45:00	2018-07-12 15:30:00	\N	\N	34	0	\N	\N
289185	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Débat et PJL Finances publiques	Débat et PJL Finances publiques	2018-07-12 15:30:00	2018-07-12 18:25:00	\N	\N	67	0	\N	\N
289187	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Avenir professionnel	PJL Avenir professionnel	2018-07-13 09:30:00	2018-07-13 13:00:00	\N	\N	44	0	\N	\N
289188	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Avenir professionnel	PJL Avenir professionnel	2018-07-13 14:30:00	2018-07-13 18:00:00	\N	\N	40	0	\N	\N
289189	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Téléphone portable à l'école	PPL Téléphone portable à l'école	2018-07-16 17:25:00	2018-07-16 19:25:00	\N	\N	45	0	\N	\N
289191	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL ELAN	PJL ELAN	2018-07-17 14:30:00	2018-07-17 20:05:00	\N	\N	208	0	\N	\N
289192	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL ELAN	PJL ELAN	2018-07-17 21:35:00	2018-07-18 00:30:00	\N	\N	117	0	\N	\N
289193	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL ELAN	PJL ELAN	2018-07-18 14:30:00	2018-07-18 20:05:00	\N	\N	195	0	\N	\N
289194	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL ELAN	PJL ELAN	2018-07-18 21:35:00	2018-07-19 01:30:00	\N	\N	118	0	\N	\N
289198	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	1 convention internationale	2 conventions internationales	2018-07-19 10:30:00	2018-07-19 10:35:00	\N	\N	21	0	\N	\N
289200	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2018-07-19 15:00:00	2018-07-19 16:05:00	\N	\N	205	0	\N	\N
289201	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL ELAN	PJL ELAN	2018-07-19 16:20:00	2018-07-19 20:05:00	\N	\N	107	0	\N	\N
289202	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL ELAN	PJL ELAN	2018-07-19 21:35:00	2018-07-20 01:05:00	\N	\N	63	0	\N	\N
289203	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL ELAN	PJL ELAN	2018-07-20 10:05:00	2018-07-20 13:00:00	\N	\N	65	0	\N	\N
289204	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL ELAN	PJL ELAN	2018-07-20 14:30:00	2018-07-20 20:15:00	\N	\N	60	0	\N	\N
289206	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL ELAN	PJL ELAN	2018-07-20 21:45:00	2018-07-21 01:50:00	\N	\N	30	0	\N	\N
289207	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2018-07-24 09:30:00	2018-07-24 12:20:00	\N	\N	39	0	\N	\N
289210	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2018-07-24 16:45:00	2018-07-24 17:45:00	\N	\N	241	0	\N	\N
289211	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL ELAN	PJL ELAN	2018-07-24 17:50:00	2018-07-24 20:25:00	\N	\N	92	0	\N	\N
289212	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL ELAN	PJL ELAN	2018-07-24 22:00:00	2018-07-25 00:50:00	\N	\N	79	0	\N	\N
289213	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Services paiement marché intérieur	PJL Services paiement marché intérieur	2018-07-25 18:05:00	2018-07-25 19:10:00	\N	\N	40	0	\N	\N
289215	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Conclusions CMP Téléphone portable à l'école	Conclusions CMP Téléphone portable à l'école	2018-07-26 11:55:00	2018-07-26 12:40:00	\N	\N	29	0	\N	\N
289218	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Conclusions CMP OEP	Conclusions CMP OEP	2018-07-26 12:40:00	2018-07-26 13:25:00	\N	\N	18	0	\N	\N
289219	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Avenir professionnel	CMP Avenir professionnel	2018-07-30 14:30:00	2018-07-30 16:10:00	\N	\N	33	0	\N	\N
289221	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2018-07-31 09:30:00	2018-07-31 12:05:00	\N	\N	37	0	\N	\N
289222	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Violences sexuelles	CMP Violences sexuelles	2018-07-31 14:30:00	2018-07-31 15:35:00	\N	\N	42	0	\N	\N
295722	DELEGATION	DEPLACEMENT	\N	\N	206	Déplacement à Parme, étude risques sanitaires et environnementaux	Déplacement à Parme ( étude risques sanitaires et environnementaux, auditions à l'EFSA)	2018-07-04 15:00:00	2018-07-05 23:00:00	\N	\N	3	0	\N	\N
299910	GIA	AUCUNE	\N	\N	\N	Petit déjeuner GIA France-Irak Pinelli	Petit déjeuner de travail du GIA France-Irak avec M. Adrien Pinelli et Mme Olivia Eteneau	2018-07-18 08:30:00	2018-07-18 09:30:00	\N	\N	4	0	615	\N
305277	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	ARS Nouvelle-Aquitaine	\N	2018-09-12 14:00:00	2018-09-12 15:00:00	\N	\N	0	0	\N	\N
305278	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	\N	\N	2018-09-12 14:00:00	2018-09-12 15:00:00	\N	\N	0	0	\N	\N
305279	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	\N	\N	2018-09-12 15:00:00	2018-09-12 16:00:00	\N	\N	0	0	\N	\N
220329	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Relations avec le CESE	Relations avec le CESE - Audition Président du Conseil économique, social et environnemental	2017-11-13 11:25:00	2017-11-13 12:00:00	\N	\N	1	0	\N	\N
220331	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour  2018 - Direction de l'action du Gouvernement - DILA	PLF pour  2018 - Direction de l'action du Gouvernement - DILA - Directeur	2017-11-16 09:00:00	2017-11-16 10:15:00	\N	\N	1	0	\N	\N
220333	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Relations avec les collectivités territoriales	PLF pour 2018 - Relations avec les collectivités territoriales - DGCL	2017-11-16 14:00:00	2017-11-16 15:30:00	\N	\N	2	0	\N	\N
220336	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Recherche et Enseignement supérieur	PLF pour 2018 - Recherche et Enseignement supérieur - DGRI	2017-11-16 09:00:00	2017-11-16 10:00:00	\N	\N	1	0	\N	\N
220338	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Cohésion des territoires	PLF pour 2018 - Cohésion des territoires - CGET	2017-11-16 14:45:00	2017-11-16 16:15:00	\N	\N	1	0	\N	\N
228942	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Visite du porte-avions Charles de Gaulle	\N	2017-12-13 08:00:00	2017-12-13 22:00:00	\N	\N	23	0	\N	\N
233039	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL Protocole de Montréal	\N	2018-01-11 11:00:00	2018-01-11 11:40:00	\N	\N	1	0	\N	\N
233061	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2018-01-16 15:05:00	2018-01-16 15:55:00	2018-01-16 15:54:37	2018-01-16 17:14:45	24	0	\N	\N
233063	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2018-01-17 10:30:00	2018-01-17 12:00:00	2018-01-17 12:04:39	2018-01-17 16:07:59	43	0	\N	\N
236073	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	AG groupe d'amitié Iran	\N	2018-01-16 14:00:00	2018-01-16 14:45:00	\N	\N	7	0	\N	\N
236081	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	AG groupe d'amitié Palestine	\N	2018-01-17 14:00:00	2018-01-17 14:45:00	\N	\N	6	0	\N	\N
244152	GIA	AUCUNE	\N	\N	\N	Renouvellement du Bureau et présentation du "Code Québec"	\N	2018-02-06 17:45:00	2018-02-06 20:45:00	\N	\N	15	0	602	\N
244314	MISSION	AUCUNE	\N	ALSTOM	\N	Audition de M. Henri POUPART-LAFARGE, Président-directeur général d'Alstom	Audition de M. Henri POUPART-LAFARGE, Président-directeur général d'Alstom	2018-02-15 11:05:00	2018-02-15 12:25:00	2018-02-15 16:54:48	2018-02-15 17:34:53	14	0	\N	\N
244315	MISSION	AUCUNE	\N	ALSTOM	\N	Audition de M. Philippe VARIN, Président de France Industrie	Audition de M. Philippe VARIN, Président de France Industrie, Vice-président du Conseil national de l'industrie	2018-02-15 13:40:00	2018-02-15 14:40:00	2018-02-15 16:55:22	2018-02-15 17:34:52	7	0	\N	\N
244317	MISSION	DEPLACEMENT	\N	ALSTOM	\N	Déplacement à Munich	Déplacement à Munich	2018-02-12 08:45:00	2018-02-13 17:15:00	\N	\N	3	0	\N	\N
244321	MISSION	DEPLACEMENT	\N	ALSTOM	\N	Visite FactoryLab Saclay	Visite FactoryLab Saclay	2018-02-14 13:30:00	2018-02-14 18:40:00	\N	\N	5	0	\N	\N
245186	GIA	AUCUNE	\N	\N	\N	Entretien avec M. l'ambassadeur	\N	2018-02-13 12:30:00	2018-02-13 14:30:00	\N	\N	10	0	589	\N
246155	COM_EURO	AUDRAP	\N	AFEU	\N	Directive Accis	Directive Accis	2018-02-01 09:00:00	2018-02-01 11:15:00	\N	\N	2	0	\N	\N
249612	GIA	AUCUNE	\N	\N	\N	Déjeuner avec une délégation de huit députés et parlementaires maliens (coop)	Déjeuner avec une délégation de huit députés et parlementaires maliens (coop)	2018-02-21 12:30:00	2018-02-21 14:30:00	\N	\N	14	0	573	\N
250123	COM_PERMANENTE	DEPLACEMENT	\N	SOCI	\N	Mission EHPAD	Déplacement à Lyon	2018-02-27 08:00:00	2018-02-27 18:00:00	\N	\N	1	0	\N	\N
250137	MECSS	AUDRAP	\N	\N	MECSS	\N	Accès précoce à l'innovation dans le domaine des produits de santé	2018-03-07 15:45:00	2018-03-07 16:45:00	\N	\N	5	0	\N	\N
255572	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI responsabilité civile	MI responsabilité civile	2018-03-13 14:00:00	2018-03-13 16:45:00	\N	\N	2	0	\N	\N
256449	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	\N	GT Financement handicap	2018-03-20 14:00:00	2018-03-20 15:00:00	\N	\N	9	0	\N	\N
258680	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Élection des conseillers métropolitains	\N	2018-03-20 14:00:00	2018-03-20 15:05:00	\N	\N	1	0	\N	\N
258684	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Élection des conseillers métropolitains	\N	2018-03-20 17:45:00	2018-03-20 19:40:00	\N	\N	1	0	\N	\N
258692	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Élection des conseillers métropolitains	\N	2018-03-22 09:30:00	2018-03-22 11:15:00	\N	\N	1	0	\N	\N
262812	MECSS	AUDRAP	\N	\N	MECSS	\N	Les conditions de réussite d'une réforme systémique des retraites	2018-04-05 10:00:00	2018-04-05 11:00:00	\N	\N	1	0	\N	\N
264061	COM_EURO	AUTRE_NON_PLENIERE	\N	AFEU	\N	Accueil délégation russe	M. Konstantin Rosachev, pdt de la commission des aff. etrangères du Conseil de la Fédération de Russie	2018-04-05 16:15:00	2018-04-05 17:20:00	\N	\N	4	0	\N	\N
266994	CONF_PRES	AUCUNE	\N	\N	\N	\N	\N	2018-04-04 19:05:00	2018-04-04 19:25:00	\N	\N	27	0	\N	\N
267232	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	LPM 2019-2025	\N	2018-04-10 14:00:00	2018-04-10 15:00:00	\N	\N	2	0	\N	\N
267250	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	LPM 2019-2025	\N	2018-04-11 14:00:00	2018-04-11 15:00:00	\N	\N	2	0	\N	\N
267262	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	LPM 2019-2025	\N	2018-04-11 15:00:00	2018-04-11 16:00:00	\N	\N	2	0	\N	\N
267266	ETUDES	AUCUNE	\N	\N	\N	Déplacement Stade de Roland-Garros	Déplacement Stade de Roland-Garros	2018-04-12 09:00:00	2018-04-12 12:00:00	\N	\N	8	0	\N	934
267408	ETUDES	AUCUNE	\N	\N	\N	GE Economie circulaire	GE Economie circulaire	2018-03-28 15:00:00	2018-03-28 16:30:00	\N	\N	5	0	\N	922
267451	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Mi	\N	2018-04-11 14:00:00	2018-04-11 15:15:00	\N	\N	2	0	\N	\N
233062	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2018-01-17 10:10:00	2018-01-17 10:30:00	2018-01-17 12:05:26	2018-01-17 16:08:00	43	0	\N	\N
267454	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Mission Établissements publics de coopération culturelle	Mission Établissements publics de coopération culturelle	2018-04-11 16:00:00	2018-04-11 17:10:00	\N	\N	2	0	\N	\N
270091	COM_PERMANENTE	DEPLACEMENT	\N	SOCI	\N	GT justice prud'homale	GT jutice prud'homale	2018-04-18 14:00:00	2018-04-18 19:00:00	\N	\N	3	0	\N	\N
270363	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	AFCL	\N	\N	\N	2018-04-18 15:00:00	2018-04-18 16:00:00	\N	\N	0	0	\N	\N
270364	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	AFCL	\N	\N	\N	2018-04-18 16:00:00	2018-04-18 17:00:00	\N	\N	0	0	\N	\N
270371	COM_EURO	AUDRAP	\N	AFEU	\N	Extraterritorialité des lois américaines	Extraterritorialité des lois américaines	2018-05-02 14:30:00	2018-05-02 15:30:00	\N	\N	1	0	\N	\N
276036	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion CATDD	\N	2018-05-29 14:00:00	2018-05-29 14:45:00	2018-05-29 15:24:52	2018-05-30 15:48:48	38	1	\N	\N
276229	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL pour la liberté de choisir son avenir professionnel	PJL pour la liberté de choisir son avenir professionnel	2018-05-15 14:00:00	2018-05-15 15:30:00	\N	\N	3	0	\N	\N
276347	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL pour la liberté de choisir son avenir professionnel	PJL pour la liberté de choisir son avenir professionnel	2018-05-16 15:40:00	2018-05-16 18:50:00	\N	\N	3	0	\N	\N
276449	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL pour la liberté de choisir son avenir professionnel	PJL pour la liberté de choisir son avenir professionnel	2018-05-17 09:00:00	2018-05-17 12:15:00	\N	\N	3	0	\N	\N
276466	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL pour la liberté de choisir son avenir professionnel	PJL pour la liberté de choisir son avenir professionnel	2018-05-22 15:00:00	2018-05-22 17:40:00	\N	\N	5	0	\N	\N
276470	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL pour la liberté de choisir son avenir professionnel	PJL pour la liberté de choisir son avenir professionnel	2018-05-23 14:00:00	2018-05-23 18:30:00	\N	\N	4	0	\N	\N
276474	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL pour la liberté de choisir son avenir professionnel	PJL pour la liberté de choisir son avenir professionnel	2018-05-24 09:00:00	2018-05-24 10:30:00	\N	\N	3	0	\N	\N
276475	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL pour la liberté de choisir son avenir professionnel	PJL pour la liberté de choisir son avenir professionnel	2018-05-30 15:15:00	2018-05-30 18:45:00	\N	\N	3	0	\N	\N
276479	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL pour la liberté de choisir son avenir professionnel	PJL pour la liberté de choisir son avenir professionnel	2018-06-05 13:30:00	2018-06-05 18:30:00	\N	\N	4	0	\N	\N
276486	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL pour la liberté de choisir son avenir professionnel	PJL pour la liberté de choisir son avenir professionnel	2018-06-06 14:00:00	2018-06-06 18:30:00	\N	\N	3	0	\N	\N
276487	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Dr Rogier et Pr Kessler	\N	2018-06-06 12:00:00	2018-06-06 13:00:00	\N	\N	0	0	\N	\N
276886	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	CANSSM	\N	2018-06-06 15:00:00	2018-06-06 16:00:00	\N	\N	0	0	\N	\N
277022	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL pour la liberté de choisir son avenir professionnel	PJL pour la liberté de choisir son avenir professionnel	2018-06-11 14:00:00	2018-06-11 20:30:00	\N	\N	4	0	\N	\N
277035	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	ENGIE	\N	2018-06-12 15:30:00	2018-06-12 16:45:00	\N	\N	0	0	\N	\N
277070	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	Cavimac, CNBF, CNIEG et Régime Banque de France	\N	2018-06-13 14:30:00	2018-06-13 18:30:00	\N	\N	0	0	\N	\N
281510	MISSION	AUCUNE	\N	HERBE	\N	Audition plénière 	\N	2018-06-06 17:35:00	2018-06-06 19:10:00	2018-06-06 19:29:15	2018-06-07 18:49:22	17	0	\N	\N
305388	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Frédéric Mondoloni, ambassadeur de France en Serbie	Entretien avec M. Frédéric Mondoloni, ambassadeur de France en Serbie	2018-08-31 10:30:00	2018-08-31 12:00:00	\N	\N	3	0	674	\N
305968	DELEGATION	AUDRAP	\N	\N	206	Visite du pôle judiciaire de la Gendarmerie nationale	Visite du pôle judiciaire de la Gendarmerie nationale	2018-09-20 09:45:00	2018-09-20 12:55:00	\N	\N	4	0	\N	\N
332424	DELEGATION	AUCUNE	\N	\N	PROS	Audition de M. Sébastien Jean, directeur du CEPII	Audition de M. Sébastien Jean, directeur du CEPII	2018-12-13 08:30:00	2018-12-13 09:30:00	2018-12-13 16:28:27	2018-12-14 11:25:48	13	0	\N	\N
333451	GIA	AUCUNE	\N	\N	\N	Rencontre groupe France Espagne COCEF	Rencontre groupe France Espagne COCEF	2018-12-05 08:00:00	2018-12-05 09:15:00	\N	\N	6	0	589	\N
334111	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2018-12-05 15:35:00	2018-12-05 17:10:00	\N	\N	3	0	\N	\N
334137	GIA	AUCUNE	\N	\N	\N	Petit-déjeuner de travail	Entretien avec B. de Tréglodé, chercheur à l'Inserm	2018-12-05 08:00:00	2018-12-05 09:00:00	\N	\N	4	0	626	\N
335130	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière (Examen note scientifique sur les lanceurs spatiaux réutilisables)	Réunion plénière (Examen note scientifique sur les lanceurs spatiaux réutilisables - Jean-Luc Fugit, député, rapporteur)	2018-12-13 09:40:00	2018-12-13 11:15:00	2018-12-14 10:53:33	\N	7	0	\N	\N
335566	COM_PERMANENTE	DEPLACEMENT	\N	CDD	\N	Déplacement -Avis budgétaire - Programme 190 Recherche en matière de développement durable	\N	2018-11-12 06:00:00	2018-11-12 17:00:00	\N	\N	1	0	\N	\N
335567	COM_PERMANENTE	DEPLACEMENT	\N	CDD	\N	Déplacement en Pologne (COP24)	\N	2018-12-12 06:45:00	2018-12-14 17:15:00	\N	\N	5	0	\N	\N
335657	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition Silt	Audition GT SILT	2018-12-04 15:00:00	2018-12-04 16:00:00	\N	\N	2	0	\N	\N
335703	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2019 - Examen de l'amendement du Gouvernement à l'article d'équilibre	PLF pour 2019 - Examen de l'amendement du Gouvernement à l'article d'équilibre	2018-12-10 17:10:00	2018-12-10 17:15:00	2018-12-10 17:38:19	2018-12-10 17:38:58	16	0	\N	\N
337743	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition	\N	2018-12-19 10:40:00	2018-12-19 11:55:00	2018-12-19 15:15:59	2018-12-19 17:46:39	37	0	\N	\N
340449	GIA	AUCUNE	\N	\N	\N	Audience 	Audience de M. Nguyen Phu Truong, Secrétaire général du PC vietnamien	2019-03-26 11:00:00	2019-03-26 12:00:00	\N	\N	1	0	626	\N
348091	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	Contrôle des Comptes	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne	2019-01-31 09:30:00	2019-01-31 10:20:00	2019-02-04 15:32:28	2019-02-04 17:27:16	3	0	\N	\N
352196	ETUDES	AUCUNE	\N	\N	\N	Audition de la Fédération nationale des chasseurs	Audition de la Fédération nationale des chasseurs	2019-02-13 08:00:00	2019-02-13 09:07:00	\N	\N	32	0	\N	907
356246	DELEGATION	AUCUNE	\N	\N	PROS	Audition de M. Laurent Alexandre	Audition de M. Laurent Alexandre	2019-03-21 08:30:00	2019-03-21 09:45:00	\N	\N	14	0	\N	\N
244351	GIA	AUCUNE	\N	\N	\N	Assemblée générale	\N	2018-01-24 14:15:00	2018-01-24 14:45:00	\N	\N	12	0	622	\N
276033	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion	\N	2018-05-30 09:35:00	2018-05-30 10:50:00	2018-05-30 11:16:50	2018-05-30 15:48:45	42	2	\N	\N
337742	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Conventions internationales	\N	2018-12-19 10:15:00	2018-12-19 10:40:00	2018-12-19 15:14:14	2018-12-19 17:46:39	37	0	\N	\N
356358	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	charte européenne autonomie locale	\N	2019-03-05 09:00:00	2019-03-05 09:30:00	\N	\N	1	0	\N	\N
358672	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Frais d'inscription à l'université pour les étrangers extra-communautaires	\N	2019-03-05 18:00:00	2019-03-05 19:30:00	\N	\N	5	0	\N	\N
358714	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Frais d'inscription à l'université pour les étrangers extra-communautaires	\N	2019-03-05 12:00:00	2019-03-05 13:00:00	\N	\N	1	0	\N	\N
358736	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2019-02-20 19:30:00	2019-02-20 21:30:00	\N	\N	21	0	\N	\N
358761	DELEGATION	DEPLACEMENT	\N	\N	206	Invitation au siège du CNRS (Paris 16e)	Invitation au siège du CNRS (Paris 16e)	2019-03-07 09:30:00	2019-03-07 11:45:00	\N	\N	6	0	\N	\N
358776	COM_EURO	AUDRAP	\N	AFEU	\N	Audition sur le programme spatial de l'UE	Audition sur le programme spatial de l'UE	2019-03-07 16:30:00	2019-03-07 17:20:00	\N	\N	2	0	\N	\N
358873	GIA	AUCUNE	\N	\N	\N	Entretien avec le co-président du groupe interparlementaire d'amitié Ukraine-France	Entretien avec M. Olexsei Hontcharentko, co-président du groupe interparlementaire d'amitié Ukraine-France de la Rada	2019-03-05 19:00:00	2019-03-05 20:00:00	\N	\N	3	0	530	\N
358877	GIA	AUCUNE	\N	\N	\N	Petit-déjeuner de travail avec la direction générale du Trésor	Petit-déjeuner de travail avec MM. Ronan Venetz et Jean-Robert Jouanny de la direction générale du Trésor	2019-03-07 08:30:00	2019-03-07 09:30:00	\N	\N	4	0	530	\N
358911	MISSION	AUDRAP	\N	INFRACTIONS	\N	Direction générale de l'offre de soins	\N	2019-03-14 11:00:00	2019-03-14 12:00:00	\N	\N	2	0	\N	\N
358915	MISSION	AUCUNE	\N	INFRACTIONS	\N	Auditions plénières	\N	2019-03-13 14:05:00	2019-03-13 18:30:00	2019-03-13 18:28:54	2019-03-14 11:45:57	9	0	\N	\N
358961	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Nouveaux territoires de la culture	MI Nouveaux territoires de la culture	2019-03-06 14:30:00	2019-03-06 15:30:00	\N	\N	5	0	\N	\N
358967	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Nouveaux territoires de la culture	MI Nouveaux territoires de la culture	2019-03-06 15:30:00	2019-03-06 17:30:00	\N	\N	2	0	\N	\N
358970	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL École de la confiance	PJL École de la confiance	2019-03-07 09:00:00	2019-03-07 09:45:00	\N	\N	3	0	\N	\N
358974	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL École de la confiance	PJL École de la confiance	2019-03-07 09:45:00	2019-03-07 11:15:00	\N	\N	4	0	\N	\N
358983	GIA	AUCUNE	\N	\N	\N	Audition commune de M. JY LE DRIAN avec comm aff etr	Audition commune de M. JY LE DRIAN avec comm aff etrangères	2019-03-06 17:30:00	2019-03-06 19:00:00	\N	\N	18	0	CHRETORIENT	CHRETORIENT
359198	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Réunion avec le secrétaire d'État	Réunion avec le secrétaire d'État	2019-03-12 12:00:00	2019-03-12 14:30:00	\N	\N	12	0	\N	\N
359218	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - La sécurité informatique des pouvoirs publics - RSSI du Sénat	Contrôle 2019 - La sécurité informatique des pouvoirs publics - RSSI du Sénat	2019-03-07 10:00:00	2019-03-07 12:00:00	\N	\N	1	0	\N	\N
359221	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Culture - INRAP	PLF pour 2020 - Culture - INRAP	2019-03-07 16:30:00	2019-03-07 17:30:00	\N	\N	1	0	\N	\N
359466	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-03-13 09:05:00	2019-03-13 12:20:00	2019-03-13 15:31:59	2019-03-14 11:43:53	39	0	\N	\N
360069	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2019-03-12 09:45:00	2019-03-12 10:45:00	\N	\N	0	0	\N	\N
360101	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2019-03-12 09:45:00	2019-03-12 10:45:00	\N	\N	3	0	\N	\N
360122	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2019-03-13 14:00:00	2019-03-13 17:15:00	\N	\N	2	0	\N	\N
360132	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2019-03-19 09:30:00	2019-03-19 10:45:00	\N	\N	2	0	\N	\N
360139	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2019-03-19 14:15:00	2019-03-19 18:15:00	\N	\N	2	0	\N	\N
360186	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2019-03-07 16:00:00	2019-03-07 18:00:00	\N	\N	3	0	\N	\N
360191	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2019-03-12 14:30:00	2019-03-12 16:00:00	\N	\N	3	0	\N	\N
360195	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2019-03-25 16:00:00	2019-03-25 19:00:00	\N	\N	3	0	\N	\N
360199	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2019-04-04 09:00:00	2019-04-04 12:00:00	\N	\N	3	0	\N	\N
360205	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2019-04-04 14:00:00	2019-04-04 15:00:00	\N	\N	3	0	\N	\N
360209	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2019-04-04 14:00:00	2019-04-04 15:00:00	\N	\N	3	0	\N	\N
360215	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2019-04-11 16:00:00	2019-04-11 17:00:00	\N	\N	3	0	\N	\N
360226	MECSS	AUDRAP	\N	\N	MECSS	\N	\N	2019-03-13 17:00:00	2019-03-13 18:00:00	\N	\N	2	0	\N	\N
360229	MECSS	AUDRAP	\N	\N	MECSS	\N	\N	2019-04-11 10:00:00	2019-04-11 11:00:00	\N	\N	2	0	\N	\N
361154	GIA	AUCUNE	\N	\N	\N	Entretien avec Son Exc. Michael LINHART, Ambassadeur d'Autriche en France	Entretien avec Son Exc. Michael LINHART, Ambassadeur d'Autriche en France	2019-03-13 12:30:00	2019-03-13 14:00:00	\N	\N	5	0	579	\N
361177	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 14 mars 2019	Réunion du 14 mars 2019	2019-03-14 09:35:00	2019-03-14 11:00:00	2019-03-14 15:45:48	2019-03-14 17:11:22	16	0	\N	\N
361352	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Création de l'Office français de la biodiversité	PJL Création de l'Office français de la biodiversité	2019-03-13 14:30:00	2019-03-13 15:30:00	\N	\N	4	0	\N	\N
361357	COM_PERMANENTE	AUDRAP	\N	CDD	\N	\N	\N	2019-03-13 15:30:00	2019-03-13 16:30:00	\N	\N	4	0	\N	\N
233030	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition Gouverneur Banque de France Bale III et désignation OEP	Audition du Gouverneur de la Banque de France sur Bale III et désignation OEP BPIFRANCE ET Comité CICE	2018-01-17 09:35:00	2018-01-17 11:35:00	2018-01-18 14:53:00	2018-01-18 14:56:16	38	0	\N	\N
233031	MISSION	AUCUNE	\N	ALSTOM	\N	Audition de M. Pierre-Noël Giraud, professeur d'économie	Audition de M. Pierre-Noël Giraud, professeur d'économie	2018-01-18 10:40:00	2018-01-18 11:35:00	2018-01-18 12:12:50	2018-01-18 15:03:54	16	0	\N	\N
235198	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2018-01-18 09:30:00	2018-01-18 10:45:00	2018-01-18 15:27:48	2018-01-18 16:38:27	33	0	\N	\N
237180	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2018-01-23 15:10:00	2018-01-23 17:10:00	\N	\N	3	0	\N	\N
237565	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe	Assemblée générale du groupe	2018-01-24 08:30:00	2018-01-24 09:15:00	\N	\N	5	0	640	\N
239282	GIA	AUCUNE	\N	\N	\N	Entretien avec S.E.M. Pascal Le Deunff, ambassadeur de France en Moldavie 	Entretien avec S.E.M. Pascal Le Deunff, ambassadeur de France en République de Moldavie 	2018-01-30 18:00:00	2018-01-30 19:00:00	\N	\N	1	0	851	\N
241300	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Mission "Routes de la soie"	\N	2018-01-30 14:30:00	2018-01-30 15:45:00	\N	\N	3	0	\N	\N
241304	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Mission "Routes de la soie"	\N	2018-01-31 14:30:00	2018-01-31 16:45:00	\N	\N	2	0	\N	\N
244072	DELEGATION	AUCUNE	\N	\N	211	Table ronde sur les mutilations sexuelles féminines	Table ronde sur les mutilations sexuelles féminines	2018-02-08 09:30:00	2018-02-08 12:00:00	2018-02-08 18:21:54	2018-02-09 17:11:53	13	0	\N	\N
246158	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Réforme Action Logement	Réforme Action Logement	2018-02-14 14:30:00	2018-02-14 16:30:00	\N	\N	1	0	\N	\N
246161	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Sport - Auditions	PLF pour 2019 - Sport - Auditions - Le mouvement associatif et CNDS	2018-02-14 15:00:00	2018-02-14 17:00:00	\N	\N	1	0	\N	\N
246296	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 - Caisse de garantie du logement locatif social (CGLLS)	58-2 - Caisse de garantie du logement locatif social (CGLLS) - Cour des comptes	2018-02-14 15:00:00	2018-02-14 15:45:00	\N	\N	1	0	\N	\N
247195	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL "Réforme du Logement"	PJL "Réforme du Logement"	2018-02-13 15:00:00	2018-02-13 16:50:00	\N	\N	3	0	\N	\N
247199	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL "Réforme du Logement"	PJL "Réforme du Logement"	2018-02-15 10:15:00	2018-02-15 11:00:00	\N	\N	2	0	\N	\N
247202	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL "Réforme du Logement"	PJL"Réforme du Logement"	2018-02-15 11:00:00	2018-02-15 12:45:00	\N	\N	1	0	\N	\N
251001	BUREAU	AUCUNE	\N	\N	\N	Délégation statut du sénateur	Délégation statut et conditions d'exercice du mandat de sénateur	2018-03-07 11:30:00	2018-03-07 12:00:00	\N	\N	5	0	\N	\N
251079	GIA	AUCUNE	\N	\N	\N	petit-déjeuner de travail avec l'ambassadrice d'Andorre	\N	2018-03-07 08:30:00	2018-03-07 09:30:00	\N	\N	8	0	963	\N
251122	COM_EURO	AUTRE_NON_PLENIERE	\N	AFEU	\N	Entretien du bureau avec M. Ismail Hakki Musa, ambassadeur de Turquie en France	Entretien du bureau avec M. Ismail Hakki Musa, ambassadeur de Turquie en France	2018-03-07 11:25:00	2018-03-07 12:55:00	\N	\N	12	0	\N	\N
252475	DELEGATION	AUCUNE	\N	\N	211	Rencontre avec des élues locales - Journée internationale des droits des femmes	Rencontre avec des élues locales - Journée internationale des droits des femmes	2018-03-08 09:30:00	2018-03-08 13:00:00	2018-03-08 15:42:21	2018-03-08 15:57:03	31	0	\N	\N
258760	DELEGATION	DEPLACEMENT	\N	\N	DSOM	Déplacement Antilles, Saint-Martin et Saint-Barthélemy (risques naturels majeurs)	Déplacement Antilles, Saint-Martin et Saint-Barthélemy (risques naturels majeurs)	2018-04-20 14:00:00	2018-04-28 20:00:00	\N	\N	0	0	\N	\N
258761	DELEGATION	DEPLACEMENT	\N	\N	DSOM	Déplacement Antilles Guyane (Jeunesse des outre-mer et sport)	Déplacement Antilles Guyane (Jeunesse des outre-mer et sport)	2018-04-28 14:00:00	2018-05-06 20:00:00	\N	\N	0	0	\N	\N
262770	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Modernisation du contrôle de la navigation aérienne	Contrôle Modernisation du contrôle de la navigation aérienne	2018-03-27 10:00:00	2018-03-27 11:00:00	\N	\N	1	0	\N	\N
262778	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Modernisation du contrôle de la navigation aérienne	Contrôle Modernisation du contrôle de la navigation aérienne	2018-03-30 09:00:00	2018-03-30 10:00:00	\N	\N	1	0	\N	\N
262804	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	Colonel Vaquette	\N	2018-04-05 10:00:00	2018-04-05 11:00:00	\N	\N	0	0	\N	\N
262805	AUTRE_TEMPORAIRE	AUTRE_NON_PLENIERE	\N	\N	\N	\N	\N	2018-04-05 10:00:00	2018-04-05 11:00:00	\N	\N	0	0	\N	\N
262814	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 Soutien énergies renouvelables 2018	58-2 Soutien énergies renouvelables 2018 -  CRE - SER - ENGIE	2018-03-28 15:00:00	2018-03-28 17:30:00	\N	\N	1	0	\N	\N
264079	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL de programmation militaire pour les années 2019-2025	PJL de programmation militaire pour les années 2019-2025 - DGA	2018-04-04 14:15:00	2018-04-04 15:00:00	\N	\N	1	0	\N	\N
264086	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Programmation militaire 2017-2025	PJL Programmation militaire 2017-2025 - Etat-major des Armées	2018-04-04 18:00:00	2018-04-04 19:00:00	\N	\N	1	0	\N	\N
264091	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL de programmation militaire pour les années 2019-2025	PJL de programmation militaire pour les années 2019-2025 - Direction du budget	2018-04-05 09:30:00	2018-04-05 10:30:00	\N	\N	1	0	\N	\N
264129	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Performance des établissements ens. sup.	Contrôle Performance des établissements ens. sup. - EUA	2018-04-04 09:45:00	2018-04-04 10:45:00	\N	\N	1	0	\N	\N
264132	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2018-04-11 09:35:00	2018-04-11 11:30:00	2018-04-11 11:31:21	2018-04-11 12:05:49	39	0	\N	\N
264134	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle enseignement français à l'étranger - AEFE	Contrôle enseignement français à l'étranger - AEFE	2018-04-05 11:15:00	2018-04-05 12:15:00	\N	\N	2	0	\N	\N
264135	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle enseignement français à l'étranger - Ministère Education nationale	Contrôle enseignement français à l'étranger - Ministère Education nationale	2018-04-04 14:30:00	2018-04-04 15:30:00	\N	\N	2	0	\N	\N
264136	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle enseignement français à l'étranger - Ministère de l'Europe	Contrôle enseignement français à l'étranger - Ministère de l'Europe	2018-04-05 10:00:00	2018-04-05 11:15:00	\N	\N	2	0	\N	\N
264143	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle CAS Immo - APIJ	Contrôle CAS Immo - Agence publique pour l'immobilier de la Justice (APIJ)	2018-04-03 09:30:00	2018-04-03 10:30:00	\N	\N	2	0	\N	\N
264144	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle CAS immo - MRAI	Contrôle CAS immo - Mission pour la réalisation des actifs immobiliers (MRAI)	2018-04-05 17:30:00	2018-04-05 18:30:00	\N	\N	2	0	\N	\N
265781	GIA	AUCUNE	\N	\N	\N	Réunion sur les aspects environnementaux du CETA	Réunion sur les aspects environnementaux du CETA en présence du cabinet du ministre Hulot et de la DGPR	2018-04-03 17:00:00	2018-04-03 18:00:00	\N	\N	4	0	583	\N
265789	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion 	Réunion	2018-04-11 10:05:00	2018-04-11 11:15:00	2018-04-11 11:56:50	2018-04-11 12:05:50	32	0	\N	\N
265855	ETUDES	AUCUNE	\N	\N	\N	Audition	Audition	2018-04-11 08:30:00	2018-04-11 11:50:00	\N	\N	12	0	\N	1007
265867	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Rapprochement France3 / France Bleu	Rapprochement France 3 / France Bleu	2018-04-10 16:00:00	2018-04-10 17:00:00	\N	\N	4	0	\N	\N
265872	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Rapprochement France3 / France Bleu	Rapprochement France 3 / France Bleu	2018-04-10 17:45:00	2018-04-10 18:35:00	\N	\N	2	0	\N	\N
267103	MISSION	AUCUNE	\N	ALSTOM	\N	Réunion d'adoption du rapport d'étape sur Alstom	Réunion d'adoption du rapport d'étape sur Alstom	2018-04-18 18:00:00	2018-04-18 19:10:00	2018-04-18 19:21:20	2018-04-19 14:52:55	12	0	\N	\N
267187	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 12 avril 2018	Réunion du 12 avril 2018	2018-04-12 08:30:00	2018-04-12 09:25:00	2018-04-12 16:24:14	2018-04-12 18:13:55	13	0	\N	\N
267270	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Tourisme	\N	2018-04-10 18:00:00	2018-04-10 19:00:00	\N	\N	5	0	\N	\N
267280	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Tourisme	\N	2018-04-11 14:30:00	2018-04-11 15:15:00	\N	\N	5	0	\N	\N
275805	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPRE Déontologie et prévention des conflits d'intérêts des sénateurs	\N	2018-05-15 14:35:00	2018-05-15 15:05:00	\N	\N	1	0	\N	\N
275807	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPRE Déontologie et prévention des conflits d'intérêts des sénateurs	\N	2018-05-16 12:30:00	2018-05-16 12:50:00	\N	\N	1	0	\N	\N
275809	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPRE Déontologie et prévention des conflits d'intérêts des sénateurs	\N	2018-05-17 10:10:00	2018-05-17 10:30:00	\N	\N	1	0	\N	\N
275811	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPRE Déontologie et prévention des conflits d'intérêts des sénateurs	\N	2018-05-22 09:30:00	2018-05-22 09:50:00	\N	\N	1	0	\N	\N
275813	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPRE Déontologie et prévention des conflits d'intérêts des sénateurs	\N	2018-05-22 10:10:00	2018-05-22 10:30:00	\N	\N	1	0	\N	\N
275815	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPRE Déontologie et prévention des conflits d'intérêts des sénateurs	\N	2018-05-22 12:00:00	2018-05-22 12:30:00	\N	\N	1	0	\N	\N
275817	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPRE Déontologie et prévention des conflits d'intérêts des sénateurs	\N	2018-05-22 14:00:00	2018-05-22 16:40:00	\N	\N	1	0	\N	\N
279322	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Immigration, droit d'asile et intégration	\N	2018-05-29 17:45:00	2018-05-29 23:00:00	\N	\N	3	0	\N	\N
279330	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Immigration, droit d'asile et intégration	\N	2018-05-30 17:30:00	2018-05-30 21:00:00	\N	\N	1	0	\N	\N
281194	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL centres-villes	PPL centres-villes	2018-06-14 22:00:00	2018-06-15 00:15:00	\N	\N	28	0	\N	\N
281196	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Droit d'asile	PJL Droit d'asile	2018-06-21 11:45:00	2018-06-21 13:00:00	\N	\N	98	0	\N	\N
295772	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Examen des motions et amendements de séance	\N	2018-07-16 14:00:00	2018-07-16 14:15:00	2018-07-16 14:57:54	2018-07-16 16:38:25	17	1	\N	\N
295773	COM_PERMANENTE	AUDRAP	\N	CDD	\N	\N	\N	2014-06-05 15:15:00	2014-06-05 16:00:00	\N	\N	0	0	\N	\N
295774	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	Table ronde relative à l'inscription des enjeux climatiques et environnementaux dans la Constitution	2018-07-11 10:30:00	2018-07-11 12:30:00	2018-07-11 15:58:49	2018-07-11 17:37:33	38	1	\N	\N
295775	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur SILT	\N	2018-07-09 11:00:00	2018-07-09 12:00:00	\N	\N	1	0	\N	\N
300127	MISSION	AUCUNE	\N	MINEURSENF	\N	\N	\N	2018-07-18 16:45:00	2018-07-18 18:30:00	2018-07-18 18:37:08	2018-07-19 09:48:21	5	0	\N	\N
301832	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Echange de vues et nomination rapporteurs MI Personnel non forces de sécurité intérieure	Réunion commission 23 juillet 2018	2018-07-23 10:00:00	2018-07-23 11:00:00	2018-07-23 19:19:03	2018-07-24 17:10:11	14	0	\N	\N
301835	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL ELAN	PJL ELAN	2018-07-23 10:30:00	2018-07-23 13:10:00	\N	\N	53	0	\N	\N
305285	GIA	AUCUNE	\N	\N	\N	Entretien avec M. SU Chia-chyuan, président du Yuan législatif	Entretien avec M. SU Chia-chyuan, président du Yuan législatif	2018-07-26 12:30:00	2018-07-26 14:30:00	\N	\N	5	0	623	\N
305347	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Rami ADWAN, ambassadeur du Liban en France	Entretien avec M. Rami ADWAN, ambassadeur du Liban en France	2018-07-12 08:30:00	2018-07-12 09:30:00	\N	\N	4	0	644	\N
305352	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	audition M. Savary, rapporteur	\N	2018-09-19 11:00:00	2018-09-19 18:45:00	\N	\N	0	0	\N	\N
305353	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	Auditions M. Savary, rapporteur	\N	2018-09-26 14:30:00	2018-09-26 17:00:00	\N	\N	0	0	\N	\N
305354	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	Auditions M. Savary, rapporteur	\N	2018-09-27 10:30:00	2018-09-27 12:00:00	\N	\N	0	0	\N	\N
305355	GIA	AUCUNE	\N	\N	\N	Entretien de M. JP SUEUR avec des membres de l'ARP de Tunisie (coopé)	Entretien de M. JP SUEUR avec des membres de l'ARP de Tunisie (coopé)	2018-05-16 14:30:00	2018-05-16 15:00:00	\N	\N	1	0	620	\N
305357	GIA	AUCUNE	\N	\N	\N	Entretien de M. Rachel MAZUIR avec une délégaton de parlementaires albanais (coopé)	Entretien de M. Rachel MAZUIR avec une délégaton de parlementaires albanais (coopé)	2018-07-10 10:30:00	2018-07-10 18:00:00	\N	\N	2	0	571	\N
305427	MISSION	DEPLACEMENT	\N	MINEURSENF	\N	\N	Déplacement  à l¿École Nationale de Protection Judiciaire de la Jeunesse - Roubaix	2018-09-06 08:00:00	2018-09-06 18:00:00	\N	\N	3	0	\N	\N
310748	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Culture (Création, Transmission, Démocratisation)	PLF 2019 - Crédits Culture (Création, Transmission, Démocratisation)	2018-10-10 10:30:00	2018-10-10 11:30:00	\N	\N	2	0	\N	\N
310749	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Culture (Création, Transmission, Démocratisation)	PLF 2019 - Crédits Culture (Création, Transmission, Démocratisation)	2018-10-10 15:30:00	2018-10-10 16:30:00	\N	\N	1	0	\N	\N
310750	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Culture (Création, Transmission, Démocratisation)	PLF 2019 - Crédits Culture (Création, Transmission, Démocratisation)	2018-10-10 16:30:00	2018-10-10 17:30:00	\N	\N	1	0	\N	\N
310751	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Culture (Création, Transmission, Démocratisation)	PLF 2019 - Crédits Culture (Création, Transmission, Démocratisation)	2018-10-10 17:30:00	2018-10-10 18:15:00	\N	\N	1	0	\N	\N
310847	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - DAG - DILA et DSAF	PLF pour 2019 - DAG - DILA et DSAF	2018-10-10 16:00:00	2018-10-10 18:00:00	\N	\N	1	0	\N	\N
310855	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Médias - France Médias Monde - Ministère - AFP 	PLF pour 2019 - Médias - France Médias Monde - Ministère - AFP 	2018-10-08 16:00:00	2018-10-08 18:30:00	\N	\N	1	0	\N	\N
310867	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Médias - BNF, Radio France, FNPS et INA	PLF pour 2019 - Médias - BNF, Radio France, FNPS et INA	2018-10-09 14:00:00	2018-10-09 17:15:00	\N	\N	1	0	\N	\N
310933	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Affaires européennes - Direction du Budget	PLF pour 2019 - Affaires européennes - Direction du Budget	2018-10-09 14:30:00	2018-10-09 15:45:00	\N	\N	1	0	\N	\N
310940	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2018-10-17 09:30:00	2018-10-17 10:25:00	2018-10-17 13:36:46	2018-10-17 15:34:20	28	0	\N	\N
310950	DELEGATION	AUDRAP	\N	\N	PROS	Audition de la DGITM	\N	2018-10-31 15:30:00	2018-10-31 16:30:00	\N	\N	3	0	\N	\N
310953	DELEGATION	AUDRAP	\N	\N	PROS	Audition de M. Gérard-François Dumont	\N	2018-10-23 16:00:00	2018-10-23 17:00:00	\N	\N	4	0	\N	\N
310959	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Investissements d'avenir - Wandercraft Paris	Contrôle 2018 - Investissements d'avenir - Wandercraft Paris	2018-10-08 09:30:00	2018-10-08 13:00:00	\N	\N	1	0	\N	\N
310961	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFSS pour 2019 - CADES	PLFSS pour 2019 - CADES	2018-10-09 14:00:00	2018-10-09 15:00:00	\N	\N	1	0	\N	\N
311050	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Conseil et contrôle de l'Etat - Conseil d'État	PLF pour 2019 - Conseil et contrôle de l'Etat - Conseil d'État	2018-10-10 14:25:00	2018-10-10 15:20:00	\N	\N	1	0	\N	\N
311052	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Conseil et contrôle de l'Etat - CESE	PLF pour 2019 - Conseil et contrôle de l'Etat - CESE	2018-10-11 09:30:00	2018-10-11 10:25:00	\N	\N	1	0	\N	\N
311133	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Justice - Direction Services judiciaires	PLF pour 2019 - Justice - Direction Services judiciaires	2018-10-11 11:40:00	2018-10-11 12:35:00	\N	\N	1	0	\N	\N
278292	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2018-06-06 10:10:00	2018-06-06 12:00:00	2018-06-06 14:44:24	2018-06-06 16:06:17	45	0	\N	\N
311344	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Rapport général - Airbnb et IGF	PLF pour 2019 - Rapport général - Airbnb et IGF	2018-10-10 15:00:00	2018-10-10 17:00:00	\N	\N	1	0	\N	\N
223285	GIA	AUCUNE	\N	\N	\N	Déjeuner en l'honneur de l'ambassadeur d'Ukraine en France à l'Assemblée nationale	\N	2017-11-23 12:30:00	2017-11-23 14:00:00	\N	\N	1	0	530	\N
227662	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2017-12-13 09:15:00	2017-12-13 11:30:00	2017-12-13 11:29:49	2017-12-13 15:07:03	41	0	\N	\N
227663	MECSS	AUCUNE	\N	\N	MECSS	\N	\N	2017-12-13 11:20:00	2017-12-13 12:30:00	2017-12-13 15:10:31	2017-12-13 15:10:37	23	0	\N	\N
232878	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFR 2017	PLFR 2017	2017-12-20 14:35:00	2017-12-20 15:45:00	\N	\N	58	0	\N	\N
232938	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2018-01-16 09:30:00	2018-01-16 12:30:00	\N	\N	36	0	\N	\N
232939	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Situation SNCF et avenir	Débat Situation SNCF et avenir	2018-01-16 14:30:00	2018-01-16 16:30:00	\N	\N	108	0	\N	\N
232940	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2018-01-16 16:45:00	2018-01-16 17:50:00	\N	\N	308	0	\N	\N
232941	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Transports Ile-de-France	Débat Transports Ile-de-France	2018-01-16 17:50:00	2018-01-16 19:45:00	\N	\N	60	0	\N	\N
232942	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Une crise en quête de fin	Débat Une crise en quête de fin	2018-01-17 14:30:00	2018-01-17 16:20:00	\N	\N	88	0	\N	\N
232943	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat  Prise en charge des mineurs isolés	Débat  Prise en charge des mineurs isolés	2018-01-17 16:30:00	2018-01-17 18:30:00	\N	\N	97	0	\N	\N
232944	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Renforcement dialogue social	PJL Renforcement dialogue social	2018-01-23 14:30:00	2018-01-23 16:35:00	\N	\N	147	0	\N	\N
232945	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2018-01-23 16:45:00	2018-01-23 17:45:00	\N	\N	309	0	\N	\N
232946	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Renforcement dialogue social soir	PJL Renforcement dialogue social soir	2018-01-23 21:30:00	2018-01-24 00:30:00	\N	\N	60	0	\N	\N
232947	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Renforcement dialogue social	PJL Renforcement dialogue social	2018-01-23 18:05:00	2018-01-23 19:25:00	\N	\N	63	0	\N	\N
232948	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Renforcement dialogue social après-midi	PJL Renforcement dialogue social après-midi	2018-01-24 14:30:00	2018-01-24 19:50:00	\N	\N	71	0	\N	\N
232949	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Renforcement dialogue social soir	PJL Renforcement dialogue social soir	2018-01-24 21:30:00	2018-01-24 23:10:00	\N	\N	44	0	\N	\N
232951	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Régime d'asile européen après-midi	PPL Régime d'asile européen après-midi	2018-01-25 14:30:00	2018-01-25 16:30:00	\N	\N	51	0	\N	\N
232952	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Profession santé	PJL Profession santé	2018-01-25 16:35:00	2018-01-25 17:25:00	\N	\N	16	0	\N	\N
233032	COM_PERMANENTE	EXAMEN	\N	SOCI	\N	CNSA	\N	2014-01-12 09:30:00	2014-01-12 10:30:00	\N	\N	0	0	\N	\N
233053	COM_PERMANENTE	EXAMEN	\N	AFCL	\N	test envoi Kairos	\N	2014-01-08 13:00:00	2014-01-08 14:00:00	\N	\N	0	0	\N	\N
233059	COM_PERMANENTE	AUCUNE	\N	AFCL	\N	test evenement	\N	2014-01-09 08:00:00	2014-01-09 22:00:00	\N	\N	0	0	\N	\N
233060	COM_PERMANENTE	DEPLACEMENT	\N	AFCL	\N	test deplacement	\N	2014-01-09 07:00:00	2014-01-10 09:00:00	\N	\N	0	0	\N	\N
233179	COM_PERMANENTE	EXAMEN	\N	CAE	\N	PJL Réforme du logement	\N	2014-01-09 14:30:00	2014-01-09 15:45:00	\N	\N	0	0	\N	\N
233183	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Réforme du logement	PJL Réforme du logement	2014-01-10 10:00:00	2014-01-10 10:45:00	\N	\N	0	0	\N	\N
233184	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Réforme du logement	PJL Réforme du logement	2014-01-10 10:45:00	2014-01-10 11:30:00	\N	\N	0	0	\N	\N
235461	GIA	AUCUNE	\N	\N	\N	Assemblée générale constitutive	Assemblée générale constitutive	2018-01-16 15:30:00	2018-01-16 15:50:00	\N	\N	11	0	597	\N
236303	ETUDES	AUCUNE	\N	\N	\N	GE Pratiques sportives	GE Pratiques sportives	2018-01-23 14:00:00	2018-01-23 14:20:00	\N	\N	15	0	\N	934
241332	GIA	AUCUNE	\N	\N	\N	Entretien avec Pierre-Marc Johnson, ancien Premier ministre du Québec	Entretien avec PM Johnson, ancien Premier ministre du Québec	2018-02-06 08:00:00	2018-02-06 09:00:00	\N	\N	1	0	602	\N
242883	ETUDES	AUCUNE	\N	\N	\N	Réunion	Réunion	2018-02-07 08:00:00	2018-02-07 09:00:00	\N	\N	17	0	\N	934
244109	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 La dette des entités publiques : périmètres et risques	58-2 La dette des entités publiques : périmètres et risques - Audition de la Cour des comptes	2018-02-08 09:30:00	2018-02-08 10:30:00	\N	\N	1	0	\N	\N
245644	COM_SPECIALE	PLENIERE	\N	SOCIETE	\N	\N	Auditions plénières	2018-02-14 15:00:00	2018-02-14 18:35:00	2018-02-15 09:45:30	2018-02-15 10:12:32	25	0	\N	\N
247146	COM_PERMANENTE	AUTRE	\N	CAE	\N	Table rond rassemblant des représentants de consommateurs	Table rond rassemblant des représentants de consommateurs	2018-02-21 10:50:00	2018-02-21 12:10:00	2018-02-21 14:49:04	2018-02-21 15:55:04	62	0	\N	\N
247147	COM_PERMANENTE	AUTRE	\N	CDD	\N	Audition de M. Jean-Benoît Albertini, Commissaire général à l'égalité des territoires	Audition de M. Jean-Benoît Albertini, Commissaire général à l'égalité des territoires	2018-02-21 09:30:00	2018-02-21 11:25:00	2018-02-22 19:14:22	2018-02-23 09:59:42	43	1	\N	\N
316532	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2019 - Examen Rapports Enseignement scolaire-Médias-Immigration-CCE	PLF pour 2019 - Examen Rapports Enseignement scolaire-Médias-Immigration-CCE	2018-10-31 09:05:00	2018-10-31 12:30:00	2018-10-31 17:22:09	2018-10-31 17:39:46	41	0	\N	\N
233182	COM_PERMANENTE	AUTRE	\N	CAE	\N	PJL Réforme du Logement	\N	2014-01-10 10:00:00	2014-01-10 11:30:00	\N	\N	0	0	\N	\N
247145	COM_PERMANENTE	AUTRE	\N	CAE	\N	accord de libre-échange entre l'UE et l'Australie, d'une part, et la Nouvelle-Zélande	accord de libre-échange entre l'Union européenne et l'Australie, d'une part, et la Nouvelle-Zélande	2018-02-21 10:00:00	2018-02-21 10:45:00	2018-02-21 14:46:57	2018-02-21 14:47:11	46	0	\N	\N
249158	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Tourisme	\N	2018-02-21 09:15:00	2018-02-21 10:00:00	\N	\N	17	0	\N	\N
253088	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Djibouti	\N	2018-03-06 16:30:00	2018-03-06 18:00:00	\N	\N	3	0	\N	\N
255919	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	SMV Montigny les Metz	Déplacement au SMV à Montigny les Metz	2018-03-12 10:40:00	2018-03-12 19:20:00	\N	\N	2	0	\N	\N
255922	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Service national universel	\N	2018-03-13 14:30:00	2018-03-13 15:30:00	\N	\N	2	0	\N	\N
255984	COM_ENQUETE	AUTRE	\N	CHUTE	\N	Audition plénière	\N	2018-03-27 15:15:00	2018-03-27 16:25:00	2018-03-28 09:42:46	2018-03-28 11:38:27	9	0	\N	\N
255985	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contôle MIRES - Performance établissements ens. sup	Contôle MIRES - Performance établissements ens. sup - DGESIP	2018-03-13 18:00:00	2018-03-13 19:00:00	\N	\N	1	0	\N	\N
255987	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contôle MIRES - Performance établissements ens. sup	Contôle MIRES - Performance établissements ens. sup - Hcéres et COURROIE	2018-03-15 10:30:00	2018-03-15 12:30:00	\N	\N	1	0	\N	\N
255989	AUTRE_TEMPORAIRE	DEPLACEMENT	\N	\N	\N	Conditions de réussite d'une réforme systémique des retraites	\N	2018-03-12 08:00:00	2018-03-15 22:00:00	\N	\N	0	0	\N	\N
255990	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2018-03-20 18:05:00	2018-03-20 19:20:00	2018-03-22 10:38:36	2018-03-22 12:26:39	29	0	\N	\N
255992	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Entretien AFEP	\N	2018-03-15 18:00:00	2018-03-15 18:30:00	\N	\N	1	0	\N	\N
255998	COM_EURO	AUTRE_NON_PLENIERE	\N	AFEU	\N	\N	\N	2018-03-14 16:00:00	2018-03-14 17:15:00	\N	\N	0	0	\N	\N
256003	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Mission Sports, jeunesse et vie associative	Mission Sports, jeunesse et vie associative - FFJ	2018-03-13 15:30:00	2018-03-13 16:30:00	\N	\N	1	0	\N	\N
265671	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Audition ONCFS	\N	2018-04-11 08:00:00	2018-04-11 09:20:00	\N	\N	0	0	\N	\N
266009	COM_EURO	AUDRAP	\N	AFEU	\N	Sifaris	\N	2018-03-28 14:35:00	2018-03-28 18:40:00	\N	\N	0	0	\N	\N
290492	DELEGATION	AUDRAP	\N	\N	PROS	Audition "Pacte entre les générations" de M. André Masson (PjSE)	Audition "Pacte entre les générations" de M. André Masson, membre du Paris-Jourdan Sciences économiques	2018-06-26 18:00:00	2018-06-26 19:15:00	\N	\N	1	0	\N	\N
290503	DELEGATION	AUDRAP	\N	\N	PROS	Audition "Pacte entre les générations" de Mme Essafi et M. Simon, Univ. Paris-Dauphine	Audition "Pacte entre les générations" de Mme Essafi et M. Simon, Univ. Paris-Dauphine	2018-06-28 10:15:00	2018-06-28 11:15:00	\N	\N	1	0	\N	\N
290672	COM_PERMANENTE	DEPLACEMENT	\N	AFCL	\N	Déplacement Château de Versailles	Déplacement Château de Versailles	2018-06-25 13:30:00	2018-06-25 17:30:00	\N	\N	9	0	\N	\N
291186	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion	Réunion	2018-06-27 10:15:00	2018-06-27 12:40:00	2018-06-27 12:50:58	2018-06-27 14:46:51	34	1	\N	\N
292891	GIA	AUCUNE	\N	\N	\N	rencontre avec M. l'ambassadeur de Corée du Sud	rencontre avec M. l'ambassadeur de Corée du Sud	2018-06-28 10:15:00	2018-06-28 11:30:00	\N	\N	3	0	613	\N
292898	DELEGATION	AUCUNE	\N	\N	PROS	Réunion plénière	Point d'étape sur le rapport "le pacte entre les générations"	2018-07-05 08:35:00	2018-07-05 09:45:00	2018-07-05 15:40:02	2018-07-05 16:05:41	13	0	\N	\N
315396	DELEGATION	AUCUNE	\N	\N	211	Audition de M. Jean-Philippe Vinquant, directeur général de la cohésion sociale	Audition de M. Jean-Philippe Vinquant, directeur général de la cohésion sociale	2018-10-23 17:30:00	2018-10-23 19:20:00	2018-10-23 19:41:56	2018-10-24 12:14:01	11	0	\N	\N
332992	SEANCE_PLENIERE	DECL_GVT	\N	\N	\N	Déclaration du Gouvernement	Déclaration du Gouvernement	2018-12-06 14:30:00	2018-12-06 17:00:00	\N	\N	220	0	\N	\N
333609	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MCS Sécurité intérieure et lutte contre le terrorisme	\N	2018-12-04 14:00:00	2018-12-04 16:00:00	\N	\N	2	0	\N	\N
334831	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	\N	\N	2018-12-06 09:00:00	2018-12-06 11:00:00	\N	\N	1	0	\N	\N
336820	GIA	AUCUNE	\N	\N	\N	Audition du ministère des affaires étrangères	Audition du sous-directeur de l'Europe méditéranéenne au MEAE	2018-12-12 08:00:00	2018-12-12 09:00:00	\N	\N	6	0	624	\N
336834	GIA	AUCUNE	\N	\N	\N	Audition journalistes turcs	Audition journalistes turcs (programme d'accueil du MEAE)	2018-11-20 08:00:00	2018-11-20 09:30:00	\N	\N	4	0	624	\N
340094	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Orientation des mobilités	\N	2018-12-20 09:30:00	2018-12-20 11:00:00	\N	\N	1	0	\N	\N
340109	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-12-18 15:00:00	2018-12-18 15:45:00	\N	\N	2	0	\N	\N
340112	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-12-19 14:00:00	2018-12-19 15:00:00	\N	\N	4	0	\N	\N
340117	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-12-19 15:00:00	2018-12-19 15:30:00	\N	\N	4	0	\N	\N
340122	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-12-19 15:30:00	2018-12-19 16:15:00	\N	\N	1	0	\N	\N
340124	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-12-19 16:15:00	2018-12-19 18:15:00	\N	\N	5	0	\N	\N
340130	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-12-19 18:15:00	2018-12-19 19:15:00	\N	\N	2	0	\N	\N
341435	DELEGATION	AUDRAP	\N	\N	PROS	Audition du syndicat des énergies renouvelables	\N	2019-03-05 14:30:00	2019-03-05 15:30:00	\N	\N	2	0	\N	\N
341473	COM_SPECIALE	PLENIERE	\N	ENTREPRISES	\N	Réunion 20190116	\N	2019-01-16 14:05:00	2019-01-16 23:05:00	2019-01-17 09:18:25	2019-01-17 11:56:36	33	0	\N	\N
342915	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de M. Alexandre Benalla	Audition de M. Alexandre Benalla	2019-01-21 14:00:00	2019-01-21 17:30:00	2019-01-21 18:22:16	2019-01-21 18:27:33	45	0	\N	\N
342916	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Nomination commission article 25 de la Constitution - Audition de M. Michel Sappin	Nomination commission article 25 de la Constitution - Audition de M. Michel Sappin	2019-01-23 08:30:00	2019-01-23 09:15:00	2019-01-23 10:46:15	2019-01-23 10:51:30	28	0	\N	\N
255991	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2018-03-21 09:30:00	2018-03-21 11:25:00	2018-03-22 10:39:08	2018-03-22 12:26:39	44	1	\N	\N
291185	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion	Réunion	2018-06-27 09:05:00	2018-06-27 10:15:00	2018-06-27 12:49:33	2018-06-27 14:46:36	42	1	\N	\N
341062	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Démarchage téléphonique (nom. rapp.) - PPL Permis à points et Petites communes (texte)	PPL Démarchage téléphonique (nom. rapp.) - PPL Permis à points et Petites communes (texte)	2019-01-16 09:00:00	2019-01-16 12:05:00	2019-01-16 12:30:14	2019-01-16 14:54:11	45	0	\N	\N
343207	MISSION	AUTRE	\N	CLIMATIQUE	\N	PLENIERE - 1	\N	2019-01-22 15:33:00	2019-01-22 16:21:00	2019-01-24 18:14:57	2019-01-24 18:28:52	20	0	\N	\N
346476	GIA	AUCUNE	\N	\N	\N	Projet de déplacement en Bulgarie	Réunion sur le projet de déplacement d¿une délégation du groupe en Bulgarie	2019-01-29 14:00:00	2019-01-29 14:30:00	\N	\N	3	0	582	\N
346534	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière - Audition Pr G. Mourou - Examen note scientifique	Réunion plénière - Audition Pr G. Mourou, prix Nobel physique 2018 - Examen note scientifique	2019-02-14 09:40:00	2019-02-14 12:10:00	2019-02-14 15:40:10	\N	9	0	\N	\N
346982	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 31 janvier 2019	Réunion de la commission des affaires européennes du 31 janvier 2019	2019-01-31 09:05:00	2019-01-31 10:20:00	2019-01-31 11:08:46	2019-01-31 18:30:34	16	0	\N	\N
347929	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Aleksandr Drozdenko, Gouverneur de la région de Leningrad	Entretien avec M. Aleksandr Drozdenko, Gouverneur de la région de Leningrad	2019-01-28 16:30:00	2019-01-28 17:30:00	\N	\N	1	0	608	\N
350826	MECSS	AUDRAP	\N	\N	MECSS	Prise en charge financière de la dépendance des personnes âgées	\N	2019-02-13 11:30:00	2019-02-13 12:30:00	\N	\N	3	0	\N	\N
350829	MECSS	AUDRAP	\N	\N	MECSS	Prise en charge financière de la dépendance des personnes âgées	\N	2019-02-13 14:00:00	2019-02-13 18:00:00	\N	\N	3	0	\N	\N
350832	MECSS	AUDRAP	\N	\N	MECSS	Prise en charge financière de la dépendance des personnes âgées	\N	2019-02-14 08:30:00	2019-02-14 09:30:00	\N	\N	2	0	\N	\N
350835	MECSS	AUDRAP	\N	\N	MECSS	Prise en charge financière de la dépendance des personnes âgées	\N	2019-02-14 10:00:00	2019-02-14 13:00:00	\N	\N	2	0	\N	\N
352373	MISSION	AUCUNE	\N	SIDERURGIE	\N	Audition plénière DGE	\N	2019-02-14 14:00:00	2019-02-14 14:55:00	2019-02-14 19:17:55	2019-02-15 10:55:22	17	0	\N	\N
352378	MISSION	AUCUNE	\N	CLIMATIQUE	\N	PLENIERE - 3	Audition de la Fédération française d'assurance (FFA) et du cabinet Exème Action	2019-02-13 15:01:00	2019-02-13 16:54:00	2019-02-13 18:52:04	2019-02-14 11:05:51	19	0	\N	\N
352535	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Vin & Société	\N	2019-02-14 13:30:00	2019-02-14 14:45:00	\N	\N	0	0	\N	\N
352536	COM_PERMANENTE	AUTRE	\N	SOCI	\N	réunion plénière	\N	2019-02-20 09:35:00	2019-02-20 11:20:00	2019-02-20 15:24:15	2019-02-20 15:41:39	42	0	\N	\N
354222	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL École de la confiance	PJL École de la confiance	2019-02-19 14:00:00	2019-02-19 15:15:00	\N	\N	5	0	\N	\N
354228	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-02-20 09:15:00	2019-02-20 10:30:00	2019-02-20 11:46:48	2019-02-20 15:04:01	36	2	\N	\N
355523	BUREAU	AUCUNE	\N	\N	\N	\N	\N	2013-02-01 14:00:00	2013-02-01 16:00:00	\N	\N	0	0	\N	\N
355789	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Améliorer la lisibilité du droit	PPL Améliorer la lisibilité du droit	2019-02-20 17:00:00	2019-02-20 17:45:00	\N	\N	1	0	\N	\N
355792	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Améliorer la lisibilité du droit	PPL Améliorer la lisibilité du droit	2019-02-21 09:30:00	2019-02-21 10:30:00	\N	\N	1	0	\N	\N
214969	COM_PERMANENTE	DEPLACEMENT	\N	SOCI	\N	PLFSS 2018	Anciens combattants, mémoire et liens avec la Nation	2017-11-07 14:00:00	2017-11-07 17:00:00	\N	\N	1	0	\N	\N
216850	GIA	AUCUNE	\N	\N	\N	Entretien avec le nouvel ambassadeur de France en Papouasie-Nouvelle Guinée	Entretien avec le nouvel ambassadeur de France en Papouasie-Nouvelle Guinée	2017-11-09 11:30:00	2017-11-09 12:30:00	\N	\N	1	0	651	\N
230432	COM_PERMANENTE	AUTRE	\N	FINC	\N	Compte rendu Conférence Article 13 dy TSCG et désignations	Compte rendu Conférence Article 13 dy TSCG et désignations	2017-12-13 10:55:00	2017-12-13 11:15:00	2017-12-14 15:52:12	2017-12-14 16:24:20	42	0	\N	\N
235539	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 18 janvier 2018	Réunion du 18 janvier 2018	2018-01-18 08:30:00	2018-01-18 09:30:00	2018-01-19 11:21:29	2018-01-19 15:13:14	14	0	\N	\N
235567	COM_EURO	AUTRE	\N	AFEU	\N	Réunion conjointe du 18 janvier 2018	Réunion conjointe du 18 janvier 2018	2018-01-18 09:30:00	2018-01-18 10:45:00	2018-01-19 12:19:11	2018-01-19 15:13:13	33	0	\N	\N
235977	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT suivi de la PAC	Secrétariat général des affaires européennes	2018-01-17 17:15:00	2018-01-17 18:45:00	\N	\N	10	0	\N	\N
237551	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe	Assemblée générale du groupe	2018-01-23 18:00:00	2018-01-23 18:15:00	\N	\N	6	0	579	\N
238005	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe d'amitié	Assemblée générale du groupe d'amitié	2018-01-24 14:00:00	2018-01-24 14:30:00	\N	\N	16	0	590	\N
238076	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe d'amitié	Assemblée générale du groupe d'amitié	2018-01-17 18:00:00	2018-01-17 18:30:00	\N	\N	23	0	573	\N
240613	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Libye	\N	2018-01-31 15:00:00	2018-01-31 16:30:00	\N	\N	2	0	\N	\N
240616	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Libye	\N	2018-02-01 10:30:00	2018-02-01 12:15:00	\N	\N	3	0	\N	\N
241368	DELEGATION	AUCUNE	\N	\N	COLTER	Table ronde - Statut de l'élu	\N	2018-02-15 08:30:00	2018-02-15 10:45:00	2018-02-15 13:03:12	2018-02-15 14:17:15	26	0	\N	\N
244312	COM_PERMANENTE	AUTRE	\N	CDD	\N	Audition de M. Julien Denormandie, Secrétaire d¿État 	Audition de M. Julien Denormandie, Secrétaire d¿État auprès du Ministre de la Cohésion des territoires 	2018-02-14 11:00:00	2018-02-14 13:00:00	2018-02-15 10:03:25	2018-02-15 10:09:47	39	0	\N	\N
244313	COM_PERMANENTE	AUTRE	\N	CDD	\N	Audition de Mme Agnès Buzyn, Ministre des Solidarités et de la 	Audition de Mme Agnès Buzyn, Ministre des Solidarités et de la 	2018-02-14 16:35:00	2018-02-14 18:05:00	2018-02-15 10:04:24	2018-02-15 10:10:31	34	0	\N	\N
244316	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de M. Patrick Dehaumont, directeur général de l¿Alimentation 	Audition de M. Patrick Dehaumont, directeur général de l¿Alimentation 	2018-02-13 16:35:00	2018-02-13 17:45:00	2018-02-14 17:54:13	2018-02-14 18:21:47	48	0	\N	\N
244322	COM_PERMANENTE	AUTRE	\N	CAE	\N	Table ronde rassemblant des acteurs de la distribution 	Table ronde rassemblant des acteurs de la distribution 	2018-02-14 09:30:00	2018-02-14 11:30:00	2018-02-14 17:55:13	2018-02-14 18:21:46	77	0	\N	\N
342919	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Nomination article 25 (vote) - PPL 80 km/h & Petites communes (amendements)	Nomination article 25 (vote) - PPL 80 km/h & Petites communes (amendements)	2019-01-23 09:25:00	2019-01-23 10:35:00	2019-01-23 10:51:40	2019-01-23 11:16:58	43	1	\N	\N
249780	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Marc LAZAR, Professeur des Université et à Sciences Po et à Rome	Entretien avec M. Marc LAZAR, Professeur des Université et à Sciences Po et à Rome	2018-02-21 12:45:00	2018-02-21 14:15:00	\N	\N	22	0	621	\N
255971	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Libye	\N	2018-03-13 18:00:00	2018-03-13 19:25:00	\N	\N	4	0	\N	\N
261000	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Transport ferroviaire	\N	2018-03-29 10:30:00	2018-03-29 13:20:00	\N	\N	55	0	\N	\N
261001	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Transport ferroviaire	PPL Transport ferroviaire	2018-03-29 15:15:00	2018-03-29 17:15:00	\N	\N	52	0	\N	\N
261002	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Transport ferroviaire	PPL Transport ferroviaire	2018-03-29 21:30:00	2018-03-30 00:00:00	\N	\N	0	0	\N	\N
261290	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Mission "Routes de la soie"	\N	2018-03-27 14:15:00	2018-03-27 16:30:00	\N	\N	2	0	\N	\N
261293	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Mission "Routes de la soie"	\N	2018-03-28 08:30:00	2018-03-28 09:55:00	\N	\N	3	0	\N	\N
261297	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Mission "Routes de la soie"	\N	2018-03-28 15:30:00	2018-03-28 16:15:00	\N	\N	2	0	\N	\N
261386	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Sanctions en matière de concurrence en Polynésie française	\N	2018-03-29 15:15:00	2018-03-29 18:00:00	\N	\N	1	0	\N	\N
267286	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Tourisme	\N	2018-04-11 15:15:00	2018-04-11 16:00:00	\N	\N	5	0	\N	\N
267292	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	touri	\N	2018-04-11 16:00:00	2018-04-11 16:45:00	\N	\N	4	0	\N	\N
267300	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	gt tou	\N	2018-04-11 16:45:00	2018-04-11 18:30:00	\N	\N	3	0	\N	\N
267308	MISSION	AUDRAP	\N	ALSTOM	\N	mi a	\N	2018-04-10 14:30:00	2018-04-10 15:30:00	\N	\N	5	0	\N	\N
267316	MISSION	AUDRAP	\N	ALSTOM	\N	MI ALSTOM - Auditions président&rapporteur	\N	2018-04-10 15:30:00	2018-04-10 16:30:00	\N	\N	6	0	\N	\N
267324	MISSION	AUDRAP	\N	ALSTOM	\N	MI ALSTOM - Auditions président&rapporteur	\N	2018-04-10 18:00:00	2018-04-10 19:00:00	\N	\N	4	0	\N	\N
267329	COM_PERMANENTE	AUDRAP	\N	CDD	\N	\N	\N	2018-04-11 17:00:00	2018-04-11 18:30:00	\N	\N	2	0	\N	\N
267457	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Formation au numérique	Formation au numérique	2018-03-21 14:30:00	2018-03-21 16:15:00	\N	\N	1	0	\N	\N
267459	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Formation au numérique	Formation au numérique	2018-04-12 09:00:00	2018-04-12 13:15:00	\N	\N	1	0	\N	\N
267461	COM_PERMANENTE	DEPLACEMENT	\N	AFCL	\N	groupe de travail Formation au numérique	groupe de travail Formation au numérique	2018-04-12 14:30:00	2018-04-12 17:30:00	\N	\N	1	0	\N	\N
267663	MECSS	AUCUNE	\N	\N	MECSS	\N	\N	2018-04-17 17:00:00	2018-04-17 18:10:00	2018-04-17 18:09:52	2018-04-17 19:29:30	14	0	\N	\N
267934	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - PIA	Contrôle 2018 - PIA - Audition ADEME	2018-04-12 13:30:00	2018-04-12 14:30:00	\N	\N	1	0	\N	\N
267935	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - PIA 	Contrôle 2018 - PIA - Bpifrance 	2018-04-12 14:30:00	2018-04-12 15:30:00	\N	\N	1	0	\N	\N
268031	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL PACTE	PJL PACTE - Audition FDJ - Mme PALLEZ	2018-04-11 15:30:00	2018-04-11 16:30:00	\N	\N	2	0	\N	\N
268608	GIA	AUCUNE	\N	\N	\N	Déjeuner de travail 	Déjeuner de travail avec Mme Haifa NAJJAR, Pdte du GIA Jordanie-France du Sénat jordanien	2018-04-11 12:45:00	2018-04-11 14:30:00	\N	\N	3	0	659	\N
268612	GIA	AUCUNE	\N	\N	\N	diner de travail	Dîner de travail avec les intervenants du colloque du 12 avril 	2018-04-11 19:30:00	2018-04-11 22:00:00	\N	\N	4	0	CHRETORIENT	CHRETORIENT
270172	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT Réforme de la PAC	Rencontre avec une délégation du Parlement de Finlande	2018-04-19 11:30:00	2018-04-19 12:30:00	\N	\N	1	0	\N	\N
270174	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT Réforme de la PAC	Rencontre avec des représentants des ambassades de pays membres de l'UE	2018-04-18 17:00:00	2018-04-18 18:45:00	\N	\N	9	0	\N	\N
270332	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Déplacement d'une délégation du bureau de la commission au Canada	Déplacement d'une délégation du bureau de la commission au Canada	2018-04-29 16:10:00	2018-05-05 08:40:00	\N	\N	6	0	\N	\N
270386	COM_PERMANENTE	DEPLACEMENT	\N	SOCI	\N	Déplacement en Guyane-Guadeloupe. 	Déplacement Guyane-Guadeloupe, situation sanitaire en Outre-Mer	2018-04-22 10:45:00	2018-04-28 10:35:00	\N	\N	6	0	\N	\N
270393	COM_PERMANENTE	DEPLACEMENT	\N	SOCI	\N	Visite d'un centre d'innovation thérapeutique à Lyon	\N	2018-04-20 06:30:00	2018-04-20 14:00:00	\N	\N	1	0	\N	\N
270396	COM_PERMANENTE	AUTRE	\N	CDD	\N	Audition plénière	\N	2018-05-16 10:00:00	2018-05-16 12:10:00	2018-05-16 14:50:20	2018-05-16 14:57:20	35	0	\N	\N
270397	COM_PERMANENTE	AUTRE	\N	CDD	\N	Audition plénière	\N	2018-05-16 17:00:00	2018-05-16 19:10:00	2018-05-17 15:49:37	2018-05-17 18:01:41	29	0	\N	\N
280178	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion	Réunion	2018-06-06 09:30:00	2018-06-06 12:10:00	2018-06-06 12:28:44	2018-06-06 14:32:47	36	0	\N	\N
289572	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Equilibre relations commerciales secteur agricole	PJL Equilibre relations commerciales secteur agricole	2018-06-29 09:40:00	2018-06-29 13:00:00	\N	\N	51	0	\N	\N
289573	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Equilibre relations commerciales secteur agricole	PJL Equilibre relations commerciales secteur agricole	2018-06-29 14:30:00	2018-06-29 20:00:00	\N	\N	43	0	\N	\N
289574	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Equilibre relations commerciales secteur agricole	PJL Equilibre relations commerciales secteur agricole	2018-06-29 21:30:00	2018-06-30 00:30:00	\N	\N	26	0	\N	\N
294009	AUTRE_TEMPORAIRE	AUTRE_NON_PLENIERE	\N	\N	\N	\N	\N	2018-07-04 14:45:00	2018-07-04 15:45:00	\N	\N	0	0	\N	\N
294208	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur	\N	2018-07-03 18:00:00	2018-07-03 19:00:00	\N	\N	2	0	\N	\N
301347	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PROG Programmation 2018-2022 et réforme pour la justice	PJL/PPLO Programmation et organisation Justice	2018-07-17 14:30:00	2018-07-17 17:00:00	\N	\N	1	0	\N	\N
301349	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PROG Programmation 2018-2022 et réforme pour la justice	PJL/PPLO Programmation et organisation Justice	2018-07-17 17:00:00	2018-07-17 20:30:00	\N	\N	2	0	\N	\N
301352	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PROG Programmation 2018-2022 et réforme pour la justice	PJL/PPLO Programmation et organisation Justice	2018-07-18 14:30:00	2018-07-18 18:30:00	\N	\N	1	0	\N	\N
301354	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PROG Programmation 2018-2022 et réforme pour la justice	PJL/PPLO Programmation et organisation Justice	2018-07-19 10:00:00	2018-07-19 10:30:00	\N	\N	2	0	\N	\N
301357	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PROG Programmation 2018-2022 et réforme pour la justice	PJL/PPLO Programmation et organisation Justice	2018-07-19 16:15:00	2018-07-19 18:30:00	\N	\N	2	0	\N	\N
268488	CMP	AUTRE	\N	EUROPEEN	\N	PJL Élection des représentants au Parlement européen	PJL Élection des représentants au Parlement européen	2018-04-18 13:05:00	2018-04-18 13:25:00	\N	\N	8	0	\N	\N
305823	COM_PERMANENTE	DEPLACEMENT	\N	AFCL	\N	Déplacement à l'Institut Pasteur	Déplacement à l'Institut Pasteur	2018-09-19 09:30:00	2018-09-19 12:00:00	\N	\N	6	0	\N	\N
316534	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2019-Audition E. WARGON enjeux budgétaires fiscaux de la transition énerg.et éco.	PLF pour 2019 - Audition E. WARGON enjeux budgétaires fiscaux de la transition énerg.et éco.	2018-10-31 16:34:00	2018-10-31 17:54:00	2018-10-31 19:05:04	2018-11-02 10:15:57	15	0	\N	\N
316535	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2019 - Pouvoirs publics - Déplacement PR	PLF pour 2019 - Pouvoirs publics - Déplacement PR	2018-10-24 14:40:00	2018-10-24 16:40:00	\N	\N	1	0	\N	\N
316537	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2018-10-31 08:30:00	2018-10-31 10:45:00	2018-10-31 17:19:22	2018-10-31 17:39:47	36	0	\N	\N
316538	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	plfss pour 2019 - médico-social. Auditions M. Bonne	\N	2018-10-23 16:30:00	2018-10-23 17:30:00	\N	\N	2	0	\N	\N
316541	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Culture - DGCA / CMN / Philarmonie	PLF pour 2019 - Culture - DGCA / CMN / Philarmonie	2018-10-22 14:30:00	2018-10-22 16:45:00	\N	\N	2	0	\N	\N
316545	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	plfss pour 2019 - médico-social. Auditions M. Bonne	\N	2018-10-23 17:30:00	2018-10-23 18:15:00	\N	\N	2	0	\N	\N
316548	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Cohésion des territoires - Logement et ville - ANRU, Anah, DGCS	PLF pour 2019 - Cohésion des territoires - Logement et ville - ANRU, Anah, DGCS	2018-10-22 14:00:00	2018-10-22 16:30:00	\N	\N	1	0	\N	\N
316565	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Cohésion des territoire - Logement et ville -  FPI et FFB	PLF pour 2019 - Cohésion des territoire - Logement et ville -  FPI et FFB	2018-10-22 17:15:00	2018-10-22 19:00:00	\N	\N	1	0	\N	\N
316572	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition rapporteur PLF 2019 outre-mer	Audition rapporteur PLF 2019 outre-mer - cabinet ministre outre-mer	2018-10-26 10:00:00	2018-10-26 11:30:00	\N	\N	1	0	\N	\N
316575	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 2018 - CGLLS - Cour des comptes	58-2 2018 - CGLLS - Cour des comptes	2018-10-22 16:30:00	2018-10-22 17:15:00	\N	\N	1	0	\N	\N
316583	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition rapporteur PLF 2019 outre-mer	Audition rapporteur PLF 2019 outre-mer - LADOM	2018-10-26 11:30:00	2018-10-26 12:30:00	\N	\N	1	0	\N	\N
316613	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	plfss pour 2019 - médico-social. Auditions M. Bonne	\N	2018-10-25 08:30:00	2018-10-25 09:15:00	\N	\N	1	0	\N	\N
316707	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Écologie/Énergie - SER	PLF pour 2019 - Écologie/Énergie - SER	2018-10-23 09:00:00	2018-10-23 10:00:00	\N	\N	1	0	\N	\N
316783	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition rapporteur PLF 2019 outre-mer	Audition rapporteur PLF 2019 outre-mer - CCI Mayotte	2018-10-24 15:00:00	2018-10-24 16:00:00	\N	\N	1	0	\N	\N
316788	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Écologie/Transports - SNCF Mobilités	PLF pour 2019 - Écologie/Transports - SNCF Mobilités	2018-10-23 17:30:00	2018-10-23 18:30:00	\N	\N	1	0	\N	\N
317282	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	\N	Mission d'information sur la Sécurité des ponts 	2018-10-09 17:00:00	2018-10-09 18:00:00	\N	\N	3	0	\N	\N
340096	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Sécurité des ponts	\N	2018-12-20 09:05:00	2018-12-20 11:55:00	\N	\N	6	0	\N	\N
340103	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Suite cyberattaque Ariane	\N	2018-12-19 09:00:00	2018-12-19 10:00:00	\N	\N	2	0	\N	\N
340106	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Suite cyberattaque Ariane	\N	2018-12-19 14:30:00	2018-12-19 16:00:00	\N	\N	2	0	\N	\N
341437	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL accord UE - Nouvelle-Zélande	\N	2019-01-15 16:35:00	2019-01-15 18:05:00	\N	\N	1	0	\N	\N
342016	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2019-01-15 15:00:00	2019-01-15 17:30:00	\N	\N	3	0	\N	\N
349777	GIA	AUCUNE	\N	\N	\N	Petit déjeuenr de travail Ambassadeur de Belgique en France	Petit d"jeuenr de travail avec SE M. François de Kerchive d'Exaerde, ambassadeur de Belgiqye en France	2019-02-06 08:00:00	2019-02-06 09:15:00	\N	\N	7	0	580	\N
351725	GIA	AUCUNE	\N	\N	\N	Entretien avec l'Ambassadeur de Serbie à Paris, Mme Natasa Maric	Entretien avec l'Ambassadeur de Serbie à Paris, Mme Natasa Maric	2019-02-12 10:00:00	2019-02-12 11:00:00	\N	\N	6	0	674	\N
356344	GIA	AUCUNE	\N	\N	\N	Réunion du bureau	Réunion du bureau sur le programme d'activités du groupe	2019-02-05 14:00:00	2019-02-05 14:45:00	\N	\N	3	0	641	\N
359446	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Nouveaux territoires du sport	MI Nouveaux territoires du sport	2019-03-12 14:30:00	2019-03-12 16:20:00	\N	\N	8	0	\N	\N
361362	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Création de l'Office français de la biodiversité	PJL Création de l'Office français de la biodiversité	2019-03-13 16:30:00	2019-03-13 17:30:00	\N	\N	5	0	\N	\N
361367	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Création de l'Office français de la biodiversité	PJL Création de l'Office français de la biodiversité	2019-03-13 17:30:00	2019-03-13 18:30:00	\N	\N	5	0	\N	\N
361414	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Collectivité européenne d'Alsace	\N	2019-03-14 10:00:00	2019-03-14 12:30:00	\N	\N	1	0	\N	\N
361416	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Collectivité européenne d'Alsace	\N	2019-03-14 13:30:00	2019-03-14 15:30:00	\N	\N	1	0	\N	\N
361491	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition PME et Numérique	Audition PME et Numérique - CPME	2019-03-13 14:30:00	2019-03-13 15:30:00	\N	\N	1	0	\N	\N
361493	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition PME et Numérique	Audition PME et Numérique - CMA France	2019-03-13 17:00:00	2019-03-13 18:00:00	\N	\N	1	0	\N	\N
361554	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI mission défense européenne	\N	2019-01-23 14:30:00	2019-01-23 15:30:00	\N	\N	2	0	\N	\N
361557	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI mission défense européenne	\N	2019-01-30 16:30:00	2019-01-30 17:30:00	\N	\N	2	0	\N	\N
361560	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI mission défense européenne	\N	2019-02-05 11:00:00	2019-02-05 12:00:00	\N	\N	2	0	\N	\N
361563	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI mission défense européenne	\N	2019-02-06 16:30:00	2019-02-06 17:30:00	\N	\N	2	0	\N	\N
361566	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI mission défense européenne	\N	2019-02-14 11:00:00	2019-02-14 12:00:00	\N	\N	2	0	\N	\N
361569	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI mission défense européenne	\N	2019-03-12 15:30:00	2019-03-12 16:30:00	\N	\N	2	0	\N	\N
361572	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI mission défense européenne	\N	2019-03-13 16:30:00	2019-03-13 18:30:00	\N	\N	2	0	\N	\N
361581	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI mission innovation et défense	\N	2019-03-12 15:30:00	2019-03-12 16:35:00	\N	\N	2	0	\N	\N
213332	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Engagements financiers de l'État	PLF pour 2018 - Engagements financiers de l'État - OCDE	2017-10-26 10:00:00	2017-10-26 11:00:00	\N	\N	1	0	\N	\N
213339	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Rapport général	PLF pour 2018 - Rapport général - Altarea Cogedim	2017-10-23 11:30:00	2017-10-23 12:15:00	\N	\N	1	0	\N	\N
213341	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFSS pour 2018 	PLFSS pour 2018 - FSV	2017-10-24 10:00:00	2017-10-24 11:00:00	\N	\N	1	0	\N	\N
213343	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLSS pour 2018	PLSS pour 2018 -  CADES et ministère de la sécurité sociale	2017-10-24 15:00:00	2017-10-24 17:00:00	\N	\N	1	0	\N	\N
213345	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2018  - Action extérieure de l'Etat	PLF pour 2018  - Action extérieure de l'Etat - Audition Ministère des affaires étrangères	2017-10-27 09:30:00	2017-10-27 11:00:00	\N	\N	0	0	\N	\N
213348	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018  - Action extérieure de l'Etat	PLF pour 2018  - Action extérieure de l'Etat - Direction du budget	2017-10-27 11:30:00	2017-10-27 12:30:00	\N	\N	2	0	\N	\N
219630	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de finances 2018	Loi de finances 2018 (Création et transmission des savoirs)	2017-11-15 14:15:00	2017-11-15 16:30:00	\N	\N	3	0	\N	\N
219634	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de finances 2018	Loi de finances 2018 (Enseignement scolaire)	2017-11-14 14:30:00	2017-11-14 15:30:00	\N	\N	2	0	\N	\N
219637	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de finances 2018	Loi de finances 2018 (Enseignement technique agricole)	2017-11-16 10:00:00	2017-11-16 11:30:00	\N	\N	2	0	\N	\N
219640	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de finances 2018	Loi de finances 2018 (Presse)	2017-11-14 09:30:00	2017-11-14 11:00:00	\N	\N	1	0	\N	\N
219642	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de finances 2018	Loi de finances 2018 (Presse)	2017-11-14 15:00:00	2017-11-14 18:00:00	\N	\N	1	0	\N	\N
219695	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de finances 2018	Loi de finances 2018 (Sport)	2017-11-14 15:00:00	2017-11-14 16:00:00	\N	\N	4	0	\N	\N
219700	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de finances 2018	Loi de finances 2018 (Sport)	2017-11-14 18:00:00	2017-11-14 19:00:00	\N	\N	1	0	\N	\N
219702	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de finances 2018	Loi de finances 2018 (Sport)	2017-11-15 15:00:00	2017-11-15 16:00:00	\N	\N	1	0	\N	\N
219704	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de finances 2018	Loi de finances 2018 (Jeunesse et vie associative)	2017-11-14 15:00:00	2017-11-14 16:30:00	\N	\N	1	0	\N	\N
219706	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de finances 2018	Loi de finances 2018 (Jeunesse et vie associative)	2017-11-14 17:45:00	2017-11-14 18:45:00	\N	\N	1	0	\N	\N
219708	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de finances 2018	Loi de finances 2018 (Jeunesse et vie associative)	2017-11-15 14:30:00	2017-11-15 16:00:00	\N	\N	1	0	\N	\N
219710	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de finances 2018	Loi de finances 2018 (Culture)	2017-11-14 15:15:00	2017-11-14 16:45:00	\N	\N	2	0	\N	\N
219816	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2017-11-16 12:35:00	2017-11-16 13:55:00	2017-11-16 15:29:45	2017-11-16 15:57:44	39	0	\N	\N
225444	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Pjl n° 6  Brevet	\N	2017-11-29 14:00:00	2017-11-29 16:00:00	\N	\N	1	0	\N	\N
226370	COM_EURO	DEPLACEMENT	\N	AFEU	\N	8ème Conférence sur la subsidiarité	8ème Conférence sur la subsidiarité - 4 décembre 2017 - Vienne (Autriche)	2017-12-04 09:00:00	2017-12-04 17:30:00	\N	\N	1	0	\N	\N
235490	ETUDES	AUCUNE	\N	\N	\N	GE Chasse et Pêche 2018	GE Chasse et Pêche 2018	2018-01-18 08:15:00	2018-01-18 09:00:00	\N	\N	16	0	\N	907
235518	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Orientation et réussite des étudiants	PJL Orientation et réussite des étudiants	2018-01-18 09:30:00	2018-01-18 11:30:00	\N	\N	1	0	\N	\N
235520	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Régime d'ouverture des établissements privés hors contrat	PPL Régime d'ouverture des établissements privés hors contrat	2018-01-18 15:30:00	2018-01-18 16:30:00	\N	\N	1	0	\N	\N
235522	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Régime d'ouverture des établissements privés hors contrat	PPL Régime d'ouverture des établissements privés hors contrat	2018-01-18 17:00:00	2018-01-18 18:00:00	\N	\N	0	0	\N	\N
235523	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI contrats aidés	Audition Ministre de la culture	2018-01-18 14:30:00	2018-01-18 16:30:00	\N	\N	2	0	\N	\N
235527	COM_PERMANENTE	DEPLACEMENT	\N	AFCL	\N	PPL Régime d'ouverture des établissements privés hors contrat	\N	2018-01-19 08:00:00	2018-01-19 13:00:00	\N	\N	1	0	\N	\N
235531	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Organisation des JOP de 2024	PJL Organisation des JOP de 2024	2018-01-18 08:30:00	2018-01-18 09:15:00	\N	\N	1	0	\N	\N
235534	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Organisation des JOP de 2024	PJL Organisation des JOP de 2024	2018-01-18 09:15:00	2018-01-18 11:00:00	\N	\N	2	0	\N	\N
235537	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Organisation des JOP de 2024	PJL Organisation des JOP de 2024	2018-01-18 11:00:00	2018-01-18 13:00:00	\N	\N	1	0	\N	\N
240963	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière du 15 février 2018	Audition conjointe du SGDSN, du ministère de la transition écologique et du ministère de l'intérieur et de l'ASN et EDF	2018-02-15 09:00:00	2018-02-15 13:00:00	2018-02-15 18:07:25	2018-02-16 09:44:33	13	0	\N	\N
244121	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2018-02-13 09:30:00	2018-02-13 10:30:00	2018-02-13 11:30:06	2018-02-13 16:27:43	32	0	\N	\N
244124	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2018-02-13 16:30:00	2018-02-13 17:45:00	2018-02-14 16:17:13	2018-02-14 17:03:31	47	0	\N	\N
244125	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2018-02-14 09:30:00	2018-02-14 11:20:00	2018-02-14 16:12:01	2018-02-14 17:03:33	76	0	\N	\N
261783	COM_ENQUETE	PLENIERE	\N	FORCES	\N	Audition CE FSI	Audition CE FSI	2018-04-03 15:50:00	2018-04-03 19:00:00	2018-04-03 19:16:11	2018-04-04 15:00:49	13	0	\N	\N
262747	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Métier d'enseignant	Métier d'enseignant	2018-04-11 14:00:00	2018-04-11 17:15:00	\N	\N	2	0	\N	\N
262750	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Métier d'enseignant	Métier d'enseignant	2018-04-12 09:00:00	2018-04-12 09:45:00	\N	\N	2	0	\N	\N
262761	COM_PERMANENTE	DEPLACEMENT	\N	AFCL	\N	Groupe travail métier d'enseignant	Groupe travail métier d'enseignant	2018-04-12 13:00:00	2018-04-12 18:00:00	\N	\N	2	0	\N	\N
262765	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Métier d'enseignant	Métier d'enseignant	2018-04-18 14:15:00	2018-04-18 16:00:00	\N	\N	4	0	\N	\N
264212	GIA	AUCUNE	\N	\N	\N	Entretien de M. BOCKEL avec M. ALAWWAD, ministre de la Culture d'Arabie Saoudite - coopé	Entretien de M. BOCKEL avec M. ALAWWAD, ministre de la Culture d'Arabie Saoudite - coopé	2018-04-10 11:30:00	2018-04-10 12:30:00	\N	\N	1	0	661	\N
266032	COM_PERMANENTE	AUTRE	\N	FINC	\N	Contrôle budgétaire ANSSI - Examen rapport PPL Verrou de Bercy - Communication directives	Contrôle budgétaire ANSSI - Examen rapport PPL Verrou de Bercy - Communication directives 147 et 148	2018-04-18 14:35:00	2018-04-18 16:30:00	2018-04-18 18:02:11	2018-04-19 14:52:11	29	0	\N	\N
266034	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2018 - Mission "Défense" - Disponibilté des hélicoptères - Villacoublay	Contrôle 2018 - Mission "Défense" - La disponibilité des hélicoptères des Armées - Villacoublay	2018-04-09 11:00:00	2018-04-09 17:00:00	\N	\N	1	0	\N	\N
266081	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Mecss audition plénière	\N	2018-04-17 17:00:00	2018-04-17 19:00:00	\N	\N	0	0	\N	\N
266082	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Mecss audition plénière	\N	2018-04-17 17:00:00	2018-04-17 19:00:00	\N	\N	0	0	\N	\N
266800	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions rapporteurs MI responsabilité civile	MI responsabilité civile	2018-04-10 17:45:00	2018-04-10 19:30:00	\N	\N	2	0	\N	\N
266870	DELEGATION	AUDRAP	\N	\N	PROS	Audition de Jacques Friggit	\N	2018-04-19 17:20:00	2018-04-19 18:05:00	\N	\N	2	0	\N	\N
267357	COM_ENQUETE	AUTRE	\N	CHUTE	\N	Audition plénière	\N	2018-04-18 15:00:00	2018-04-18 16:00:00	2018-06-26 16:11:44	\N	7	0	\N	\N
267358	COM_ENQUETE	AUTRE	\N	CHUTE	\N	Audition plénière	\N	2018-04-17 16:00:00	2018-04-17 17:05:00	2018-05-18 14:11:37	\N	7	0	\N	\N
244594	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	\N	2018-02-07 15:45:00	2018-02-07 16:50:00	\N	\N	1	0	\N	\N
267359	COM_ENQUETE	AUTRE	\N	CHUTE	\N	Audition plénière	\N	2018-04-18 16:05:00	2018-04-18 17:10:00	2018-06-26 16:12:22	\N	7	0	\N	\N
267360	COM_ENQUETE	AUTRE	\N	CHUTE	\N	Audition plénière	\N	2018-04-19 13:55:00	2018-04-19 15:00:00	2018-06-26 16:13:17	\N	6	0	\N	\N
267361	COM_ENQUETE	AUTRE	\N	CHUTE	\N	Audition plénière	\N	2018-05-17 11:00:00	2018-05-17 12:30:00	\N	\N	0	0	\N	\N
267362	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Mission AEE - Réseau enseignement français à l'étranger 	Contrôle 2018 - Mission Action extérieure de l'État - Réseau enseignement français à l'étranger - FAPEE	2018-04-12 10:00:00	2018-04-12 10:50:00	\N	\N	2	0	\N	\N
267363	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Réseau de l'enseignement français à l'étranger	Contrôle 2018 - Réseau de l'enseignement français à l'étranger -  Cour des comptes	2018-04-10 09:30:00	2018-04-10 10:30:00	\N	\N	2	0	\N	\N
286220	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	justice prud'hommale	justice prud'hommale	2018-05-16 14:00:00	2018-05-16 17:30:00	\N	\N	4	0	\N	\N
286225	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	justice prud'hommale	justice prud'hommale	2018-04-18 14:00:00	2018-04-18 19:00:00	\N	\N	3	0	\N	\N
286229	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	justice prud'hommale	justice prud'hommale	2018-05-28 09:30:00	2018-05-28 18:00:00	\N	\N	3	0	\N	\N
286233	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	justice prud'hommale	justice prud'hommale	2018-06-13 14:30:00	2018-06-13 17:50:00	\N	\N	1	0	\N	\N
300799	COM_EURO	AUDRAP	\N	AFEU	\N	Platforms to business	Platforms to business	2018-07-17 14:30:00	2018-07-17 16:40:00	\N	\N	2	0	\N	\N
300821	COM_EURO	AUDRAP	\N	AFEU	\N	Platforms to business	Platforms to business	2018-07-18 15:15:00	2018-07-18 17:15:00	\N	\N	2	0	\N	\N
305552	GIA	AUCUNE	\N	\N	\N	colloque sur le Yémen 	participation au colloque de l'Assemblée nationale "Yémen: un pays riche de culture dans la tourmente"	2018-09-13 14:30:00	2018-09-13 18:30:00	\N	\N	2	0	627	\N
305559	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	proches aidants	proches aidants	2018-09-13 09:30:00	2018-09-13 11:30:00	\N	\N	2	0	\N	\N
305576	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Affaire Benalla - Examen demande report et huis clos	Examen demande report et huis clos d'audition	2018-09-19 08:15:00	2018-09-19 08:30:00	2018-09-19 19:12:54	2018-09-20 14:21:46	34	0	\N	\N
305577	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Auditions affaire Benalla suite	Auditions Benalla suite	2018-09-19 08:50:00	2018-09-19 13:15:00	2018-09-19 18:59:02	2018-09-20 14:21:47	89	1	\N	\N
305885	DELEGATION	AUCUNE	\N	\N	PROS	Examen du rapport d'information	Nouvelles mobilités	2018-11-08 08:30:00	2018-11-08 09:45:00	2018-11-08 14:34:45	2018-11-08 15:47:10	18	0	\N	\N
305886	DELEGATION	AUCUNE	\N	\N	PROS	Examen du rapport d'information sur le Pacte entre les générations	Examen du rapport d'information sur le Pacte entre les générations	2018-10-11 08:30:00	2018-10-11 10:00:00	2018-10-11 17:04:49	2018-10-11 17:12:25	15	0	\N	\N
305902	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2018 - Les amendes pénales - Déplacement à Bobigny	Contrôle 2018 - Les amendes pénales - Déplacement à Bobigny	2018-09-19 13:30:00	2018-09-19 17:30:00	\N	\N	1	0	\N	\N
305904	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Lutte contre les feux de forêts - DGSCGC	Contrôle 2018 - Lutte contre les feux de forêts - DGSCGC	2018-09-18 08:45:00	2018-09-18 10:00:00	\N	\N	1	0	\N	\N
305907	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de M. Bruno LE MAIRE et de M. Gérald DARMANIN sur le PLF pour 2019	Audition de M. Bruno LE MAIRE et de M. Gérald DARMANIN sur le PLF pour 2019	2018-09-24 17:35:00	2018-09-24 19:25:00	2018-09-25 09:21:55	2018-09-25 14:43:52	21	0	\N	\N
305910	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de M. Didier MIGAUD, président du HCFP, avis Haut Conseil sur PLF et PLFSS 2019	Audition de M. Didier MIGAUD, président du HCFP, sur l¿avis du Haut Conseil relatif aux PLF et PLFSS pour 2019	2018-09-26 15:05:00	2018-09-26 16:30:00	2018-09-27 11:29:55	2018-09-27 17:38:52	27	0	\N	\N
305911	DELEGATION	AUDRAP	\N	\N	206	Audition de l'Union française de l'électricité (UFE)	Audition de l'Union française de l'électricité (UFE)	2018-09-05 10:00:00	2018-09-05 11:15:00	\N	\N	2	0	\N	\N
305914	DELEGATION	AUDRAP	\N	\N	206	Audition de Anne Caroline Prévot (MNHN)	Audition de Anne Caroline Prévot (MNHN)	2018-09-12 09:30:00	2018-09-12 11:00:00	\N	\N	1	0	\N	\N
305916	DELEGATION	AUDRAP	\N	\N	206	Audition de Bruno Latour, philosophe et sociologue	Audition de Bruno Latour, philosophe et sociologue	2018-09-11 17:00:00	2018-09-11 18:30:00	\N	\N	1	0	\N	\N
305918	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Benjamin Topper,  fondateur de la société Wattsrat.	Audition de M. Benjamin Topper,  fondateur de la société Wattsrat.	2018-09-12 09:00:00	2018-09-12 09:45:00	\N	\N	2	0	\N	\N
305921	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Nom. rapporteurs + Audition Mme la garde des sceaux s/ PJL et PJLO Réforme justice	\N	2018-09-25 17:45:00	2018-09-25 20:15:00	2018-09-27 15:39:14	2018-09-27 17:38:49	28	1	\N	\N
305922	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Joseph Beretta, président d'AVERE France	Audition de M. Joseph Beretta, président d'AVERE France	2018-09-12 14:00:00	2018-09-12 15:30:00	\N	\N	2	0	\N	\N
305925	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Auditions affaire Benalla	\N	2018-09-26 09:35:00	2018-09-26 12:20:00	2018-09-27 15:21:19	2018-09-27 17:38:50	34	0	\N	\N
305929	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Patrick Corbin, président de l'Association française du gaz (AFG)	Audition de M. Patrick Corbin, président de l'Association française du gaz (AFG)	2018-09-13 15:00:00	2018-09-13 16:00:00	\N	\N	2	0	\N	\N
305932	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Daniel HIssel, CNRS, directeur du FCLAB	Audition de M. Daniel HIssel, CNRS, directeur du FCLAB	2018-09-18 10:00:00	2018-09-18 11:00:00	\N	\N	2	0	\N	\N
305935	DELEGATION	AUDRAP	\N	\N	206	Audition de l'Association française du gaz naturel véhicule	Audition de l'Association française du gaz naturel véhicule	2018-09-18 09:00:00	2018-09-18 10:00:00	\N	\N	2	0	\N	\N
305950	DELEGATION	AUDRAP	\N	\N	206	Audition du Cabinet E-cube	Audition du Cabinet E-cube	2018-09-20 09:00:00	2018-09-20 10:00:00	\N	\N	2	0	\N	\N
305962	COM_EURO	DEPLACEMENT	\N	AFEU	\N	Extraterritorialité des sanctions américaines	Déplacement Bruxelles - Audition de représentants du SGAE et du SEAE	2018-09-20 14:00:00	2018-09-20 21:00:00	\N	\N	1	0	\N	\N
305964	GIA	AUCUNE	\N	\N	\N	Entretien avec l'Ambassadrice de France en Lituanie	Entretien avec l'Ambassadrice de France en Lituanie	2018-09-21 13:30:00	2018-09-21 14:30:00	\N	\N	1	0	616	\N
310542	GIA	AUCUNE	\N	\N	\N	Entretien de Mme TROENDLE avec M. Woflgang SILBERMANN (coopé)	Entretien de Mme TROENDLE avec M. Woflgang SILBERMANN (coopé)	2018-10-09 17:30:00	2018-10-09 18:30:00	\N	\N	0	0	604	\N
332892	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Pastoralisme	GT Pastoralisme	2018-11-28 08:00:00	2018-11-28 09:00:00	\N	\N	6	0	\N	\N
332907	COM_PERMANENTE	AUDRAP	\N	CDD	\N	\N	PJL Orientation des mobilités	2018-11-28 14:00:00	2018-11-28 18:00:00	\N	\N	8	0	\N	\N
333597	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Handicap dans la fonction publique	\N	2018-12-04 14:00:00	2018-12-04 20:00:00	\N	\N	2	0	\N	\N
249861	ETUDES	AUCUNE	\N	\N	\N	\N	\N	2018-02-21 17:00:00	2018-02-21 17:30:00	\N	\N	5	0	\N	922
334061	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition plénière - assurance chômage	\N	2018-12-13 09:10:00	2018-12-13 10:45:00	2018-12-13 10:42:04	2018-12-13 15:51:10	25	0	\N	\N
334834	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL accord de coopération défense Albanie et Chypre	\N	2018-12-04 14:15:00	2018-12-04 14:40:00	\N	\N	1	0	\N	\N
335380	GIA	AUCUNE	\N	\N	\N	Entretien avec Mme Laïla NEHMÉ, Directeur de recherche au CNRS	Entretien avec Mme Laïla NEHMÉ, Directeur de recherche au CNRS	2018-11-07 11:00:00	2018-11-07 12:00:00	\N	\N	5	0	661	\N
335576	GIA	AUCUNE	\N	\N	\N	Entretien de M. Yves DAUDIGNY,  avec M. Karlo RESSLER, Conseiller du Premier croate (coopé	Entretien de M. Yves DAUDIGNY,  avec M. Karlo RESSLER, Conseiller du Premier croate (coopé)	2018-11-28 14:00:00	2018-11-28 14:45:00	\N	\N	0	0	647	\N
335736	DELEGATION	AUDRAP	\N	\N	PROS	Audition de Jezabel Couppey	\N	2018-12-13 17:30:00	2018-12-13 19:10:00	\N	\N	1	0	\N	\N
335740	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2019 - Examen de trois amendements du gouvernement en seconde délibération	PLF pour 2019 - Examen de trois amendements du gouvernement en seconde délibération	2018-12-11 15:10:00	2018-12-11 15:25:00	2018-12-11 18:10:48	2018-12-11 18:11:39	43	0	\N	\N
338266	MISSION	AUCUNE	\N	INFRACTIONS	\N	Auditions de la DJEPVA (éducation nationale) et de la DACG (justice)	Auditions de la DJEPVA (éducation nationale) et de la DACG (justice)	2018-12-19 14:15:00	2018-12-19 16:05:00	2018-12-19 16:41:12	2018-12-19 17:46:51	13	0	\N	\N
338456	DELEGATION	AUDRAP	\N	\N	206	Audition EDF (Stockage de l'électricité)	Audition EDF (Stockage de l'électricité)	2018-12-19 17:15:00	2018-12-19 18:30:00	\N	\N	1	0	\N	\N
338458	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	Groupe de travail ruralités : État des lieux des ruralités avec des experts	Groupe de travail ruralités : État des lieux des ruralités avec des experts	2018-12-13 13:30:00	2018-12-13 15:00:00	\N	\N	10	0	\N	\N
213355	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2018	PLF 2018	2017-10-23 17:00:00	2017-10-23 19:15:00	\N	\N	1	0	\N	\N
213357	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	PLF 2018	2017-10-25 15:10:00	2017-10-25 16:15:00	\N	\N	5	0	\N	\N
213363	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	PLF 2018	2017-10-26 09:15:00	2017-10-26 10:20:00	\N	\N	1	0	\N	\N
213365	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	PLF 2018	2017-10-25 14:30:00	2017-10-25 17:30:00	\N	\N	1	0	\N	\N
213367	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	PLF 2018	2017-10-26 10:00:00	2017-10-26 11:30:00	\N	\N	1	0	\N	\N
216217	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de finances 2018	Loi de finances 2018 (Action extérieure de l'État)	2017-11-07 09:15:00	2017-11-07 12:30:00	\N	\N	3	0	\N	\N
216223	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de 	Loi de finances 2018 (Enseignement scolaire)	2017-11-09 10:00:00	2017-11-09 11:30:00	\N	\N	1	0	\N	\N
216229	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de finances 2018	Loi de finances 2018 (Presse)	2017-11-07 14:45:00	2017-11-07 18:00:00	\N	\N	1	0	\N	\N
216232	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de finances 2018	Loi de finances 2018 (Sport)	2017-11-07 17:00:00	2017-11-07 18:00:00	\N	\N	3	0	\N	\N
216236	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de finances 2018	Loi de finances 2018 (Sport)	2017-11-08 15:00:00	2017-11-08 16:00:00	\N	\N	3	0	\N	\N
216240	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de finances 2018	Loi de finances 2018 (Sport)	2017-11-09 09:30:00	2017-11-09 10:30:00	\N	\N	1	0	\N	\N
216302	COM_PERMANENTE	AUTRE	\N	FINC	\N	PROG Programmation des finances publiques de 2018 à 2022 - Examen motion et amendement GVT	PROG Programmation des finances publiques de 2018 à 2022 - Examen motion et amendement GVT	2017-11-09 11:30:00	2017-11-09 11:40:00	2017-11-10 10:00:32	2017-11-10 16:01:55	22	0	\N	\N
219745	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2017-11-21 17:00:00	2017-11-21 18:05:00	2017-11-21 18:03:46	2017-11-22 11:05:57	32	0	\N	\N
220364	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Contrôle et exploitation aériens 	PLF pour 2018 - Contrôle et exploitation aériens - Cerema et UAF	2017-11-13 10:30:00	2017-11-13 12:30:00	\N	\N	1	0	\N	\N
220366	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Sécurités "Police nationale " et "gendarmerie nationale"	PLF pour 2018 - Sécurités "Police nationale " et "gendarmerie nationale" - Cour des comptes	2017-11-17 11:30:00	2017-11-17 12:30:00	\N	\N	1	0	\N	\N
228446	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Gestion des milieux aquatiques et prévention des inondations	\N	2017-12-05 14:00:00	2017-12-05 17:45:00	\N	\N	3	0	\N	\N
228450	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Gestion des milieux aquatiques et prévention des inondations	\N	2017-12-06 09:30:00	2017-12-06 10:10:00	\N	\N	3	0	\N	\N
233282	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	PPL Application du régime d'asile européen	\N	2018-01-08 11:00:00	2018-01-08 19:00:00	\N	\N	2	0	\N	\N
240939	DELEGATION	AUCUNE	\N	\N	211	Échange de vues sur l'organisation du programme de travail de la délégation	Échange de vues sur l'organisation du programme de travail de la délégation	2018-02-01 08:30:00	2018-02-01 10:30:00	2018-02-01 17:23:15	2018-02-01 20:08:53	16	0	\N	\N
240941	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Mécanisme de protection civile de l'UE	\N	2018-02-01 14:00:00	2018-02-01 15:00:00	\N	\N	2	0	\N	\N
245565	COM_EURO	AUTRE_NON_PLENIERE	\N	AFEU	\N	Commission ECON - Parlement européen	Entretien avec une délégation de la commission des affaires économiques et monétaires du Parlement européen	2018-02-13 18:00:00	2018-02-13 19:10:00	\N	\N	7	0	\N	\N
248854	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Défense 2018 - Disponibilité des hélicoptères	Contrôle Défense 2018 - Disponibilité des hélicoptères - EMAA	2018-02-20 14:25:00	2018-02-20 15:15:00	\N	\N	1	0	\N	\N
249867	DELEGATION	AUCUNE	\N	\N	211	Auditions dans le cadre des travaux consacrés aux violences faites aux femmes 	Auditions dans le cadre des travaux consacrés aux violences faites aux femmes	2018-02-22 09:00:00	2018-02-22 12:00:00	2018-02-22 12:36:58	2018-02-22 14:04:35	14	0	\N	\N
251862	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Djilali Benchabane, chercheur	Entretien avec M. Djilali Benchabane, chercheur	2018-03-08 08:30:00	2018-03-08 09:45:00	\N	\N	5	0	597	\N
255774	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2018-03-21 09:35:00	2018-03-21 12:35:00	2018-03-21 14:51:53	2018-03-21 15:41:49	33	0	\N	\N
255850	GIA	AUCUNE	\N	\N	\N	table-ronde sur la Corée du Nord et les relations intercoréennes	table-ronde sur la Corée du Nord et les relations intercoréennes	2018-03-15 08:30:00	2018-03-15 10:00:00	\N	\N	4	0	613	\N
213434	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2017-11-08 15:00:00	2017-11-08 17:00:00	\N	\N	1	0	\N	\N
219746	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2017-11-22 09:00:00	2017-11-22 11:15:00	2017-11-22 11:24:25	2017-11-22 15:31:42	48	0	\N	\N
241367	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion	Réunion	2018-02-07 09:05:00	2018-02-07 11:35:00	2018-02-07 12:04:08	2018-02-07 14:56:10	46	0	\N	\N
255858	GIA	AUCUNE	\N	\N	\N	Audition de chercheurs sur la situation en Corée du Nord	Audition de chercheurs sur la situation en Corée du Nord	2018-03-15 08:30:00	2018-03-15 09:45:00	\N	\N	3	0	586	\N
258488	COM_PERMANENTE	DEPLACEMENT	\N	AFCL	\N	Comédie-Française	Comédie-Française	2018-03-21 09:00:00	2018-03-21 11:00:00	\N	\N	22	0	\N	\N
258895	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Élection des représentants au Parlement européen	\N	2018-03-22 12:15:00	2018-03-22 13:00:00	\N	\N	1	0	\N	\N
258897	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Élection des représentants au Parlement européen	\N	2018-03-23 09:30:00	2018-03-23 11:40:00	\N	\N	1	0	\N	\N
258913	DELEGATION	AUDRAP	\N	\N	206	Audition de Blockchain France	Audition de Mme Claire Balva, présidente de Blockchain France et de Blockchain Partner	2018-03-27 15:00:00	2018-03-27 16:00:00	\N	\N	3	0	\N	\N
258914	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Renaud Lifchitz, consultant et chercheur en sécurité informatique 	Audition de M. Renaud Lifchitz, consultant et chercheur en sécurité informatique et en cryptographie	2018-03-27 16:00:00	2018-03-27 17:00:00	\N	\N	3	0	\N	\N
258915	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Ricardo Perez-Marco (CNRS/Université Paris Diderot)	Audition de M. Ricardo Perez-Marco, directeur de recherche en mathématiques (CNRS/Université Paris Diderot)	2018-03-27 17:00:00	2018-03-27 18:00:00	\N	\N	3	0	\N	\N
258916	DELEGATION	AUDRAP	\N	\N	206	Audition de Mme Emmanuelle Anceaume (Irisa-INRIA-CNRS)	Audition de Mme Emmanuelle Anceaume, chargée de recherche en informatique (Irisa-INRIA-CNRS)	2018-03-28 15:00:00	2018-03-28 16:00:00	\N	\N	1	0	\N	\N
258917	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Simon Polrot, fondateur d'Ethereum France et de VariabL	Audition de M. Simon Polrot, fondateur d'Ethereum France et de VariabL	2018-03-28 16:00:00	2018-03-28 17:00:00	\N	\N	2	0	\N	\N
258918	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Pierre Porthaux, président de Blockchain Solutions et d'EmergenceLab	Audition de M. Pierre Porthaux, président de Blockchain Solutions et d'EmergenceLab	2018-03-28 17:00:00	2018-03-28 18:00:00	\N	\N	2	0	\N	\N
263035	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Polynésie code de commerce	PJL Polynésie code de commerce	2018-04-10 14:30:00	2018-04-10 15:20:00	\N	\N	94	0	\N	\N
263038	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Élections représentants Parlement européen	PJL Élections représentants Parlement européen	2018-04-10 15:20:00	2018-04-10 16:30:00	\N	\N	132	0	\N	\N
263044	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2018-04-10 16:45:00	2018-04-10 17:40:00	\N	\N	306	0	\N	\N
263051	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Élections représentants Parlement européen	PJL Élections représentants Parlement européen	2018-04-10 17:50:00	2018-04-10 20:30:00	\N	\N	111	0	\N	\N
263054	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Élections représentants Parlement européen	PJL Élections représentants Parlement européen	2018-04-10 22:00:00	2018-04-11 00:35:00	\N	\N	78	0	\N	\N
270532	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Carte du combattant aux soldats engagés après les accords d'Évian	\N	2018-05-16 17:00:00	2018-05-16 18:00:00	\N	\N	3	0	\N	\N
270533	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Carte du combattant aux soldats engagés après les accords d'Évian	\N	2018-05-16 18:00:00	2018-05-16 19:00:00	\N	\N	3	0	\N	\N
278438	DELEGATION	AUCUNE	\N	\N	PROS	Atelier de prospective	L'avenir des relations entre les générations	2018-06-07 09:00:00	2018-06-07 12:15:00	2018-06-07 14:54:55	2018-06-07 18:51:15	12	0	\N	\N
278444	DELEGATION	AUDRAP	\N	\N	PROS	Audition de la CNAV	Audition de la CNVA	2018-06-05 18:45:00	2018-06-05 20:15:00	\N	\N	1	0	\N	\N
281507	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Mission Mécénat	Mission Mécénat	2018-06-06 15:45:00	2018-06-06 17:00:00	\N	\N	2	0	\N	\N
286324	GIA	AUCUNE	\N	\N	\N	Entretien avec le Président de l'Assemblée de la République du Kosovo	Entretien avec le Président de l'Assemblée de la République du Kosovo	2018-06-18 11:00:00	2018-06-18 12:05:00	\N	\N	2	0	674	\N
289355	GIA	AUCUNE	\N	\N	\N	\N	\N	2018-06-20 20:00:00	2018-06-20 22:20:00	\N	\N	3	0	641	\N
292816	MISSION	AUCUNE	\N	PENURIE	\N	\N	\N	2018-06-28 14:30:00	2018-06-28 15:00:00	2018-06-28 15:02:48	2018-06-28 15:45:15	10	0	\N	\N
294209	DELEGATION	AUDRAP	\N	\N	PROS	Audition de Mme Solange MARTIN, sociologue à l'ADEME	Audition "Pacte entre les générations" de Mme Solange MARTIN, sociologue à l'ADEME	2018-07-10 18:00:00	2018-07-10 19:00:00	\N	\N	1	0	\N	\N
294210	DELEGATION	AUDRAP	\N	\N	PROS	Audition de Mme Bénédicte Ravache, secrétaire générale de l'ANDRH	Audition "Pacte entre les générations" de Mme Bénédicte Ravache, secrétaire générale de l'ANDRH	2018-07-17 09:00:00	2018-07-17 10:10:00	\N	\N	1	0	\N	\N
294625	GIA	AUCUNE	\N	\N	\N	Entretien avec une délégation de la Cour constitutionnelle d'Ouzbékistan (coopé)	Entretien avec une délégation de la Cour constitutionnelle d'Ouzbékistan (coopé)	2018-07-04 12:30:00	2018-07-04 14:30:00	\N	\N	5	0	556	\N
305392	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2018-09-04 15:20:00	2018-09-04 18:10:00	\N	\N	3	0	\N	\N
305396	GIA	AUCUNE	\N	\N	\N	GIA France-Japon - rencontre avec une délégation de sénateurs japonais	GIA France-Japon - rencontre avec une délégation de sénateurs japonais	2018-08-31 12:30:00	2018-08-31 14:15:00	\N	\N	3	0	596	\N
310877	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière	Réunion plénière	2018-10-11 09:00:00	2018-10-11 10:00:00	2018-10-11 11:43:27	2018-10-11 16:05:28	18	0	\N	\N
337899	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2018-12-13 14:10:00	2018-12-13 15:00:00	2018-12-13 15:51:44	2018-12-13 16:00:58	18	0	\N	\N
337910	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Nomination de rapporteur - PJL mesures d'urgence économiques et sociales	\N	2018-12-18 14:00:00	2018-12-18 14:15:00	2018-12-18 14:17:37	2018-12-18 14:44:15	24	0	\N	\N
339493	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat sur la programmation pluriannuelle de l'énergie	Débat sur la programmation pluriannuelle de l'énergie	2019-01-15 14:30:00	2019-01-15 16:20:00	\N	\N	88	0	\N	\N
339494	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat sur la gouvernance des grands groupes coopératifs agricoles	Débat sur la gouvernance des grands groupes coopératifs agricoles	2019-01-15 18:00:00	2019-01-15 19:45:00	\N	\N	73	0	\N	\N
339495	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat sur les mobilités du futur 	Débat sur les mobilités du futur 	2019-01-15 16:00:00	2019-01-15 18:30:00	\N	\N	48	0	\N	\N
339496	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat sur le thème : «  Quelle politique d¿attractivité de la France à l¿égard des étudian	Débat sur le thème : «  Quelle politique d¿attractivité de la France à l¿égard des étudiants internationaux ? » 	2019-01-16 14:30:00	2019-01-16 16:05:00	\N	\N	76	0	\N	\N
339497	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat sur le thème : « Après un an d'application, bilan et évaluation de Parcoursup » 	Débat sur le thème : « Après un an d'application, bilan et évaluation de Parcoursup » 	2019-01-16 16:20:00	2019-01-16 17:55:00	\N	\N	69	0	\N	\N
339498	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat sur la solidarité intergénérationnelle 	Débat sur la solidarité intergénérationnelle 	2019-01-16 17:55:00	2019-01-16 19:25:00	\N	\N	56	0	\N	\N
339499	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2019-01-17 15:00:00	2019-01-17 16:05:00	\N	\N	252	0	\N	\N
339500	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat sur le retrait britannique de l'Union européenne 	Débat sur le retrait britannique de l'Union européenne 	2019-01-17 16:15:00	2019-01-17 17:55:00	\N	\N	49	0	\N	\N
339501	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Conclusions CMP Brexit	Conclusions CMP Brexit	2019-01-17 17:55:00	2019-01-17 18:50:00	\N	\N	19	0	\N	\N
339502	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2019-01-22 09:30:00	2019-01-22 12:45:00	\N	\N	44	0	\N	\N
339503	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Mécanisme de justice transitionnelle en Irak	PPL Mécanisme de justice transitionnelle en Irak	2019-01-22 14:30:00	2019-01-22 16:20:00	\N	\N	94	0	\N	\N
339504	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2019-01-22 16:45:00	2019-01-22 17:40:00	\N	\N	309	0	\N	\N
339506	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL et PPLO Elections Français à l'étranger	PPL et PPLO Elections Français à l'étranger	2019-01-22 17:50:00	2019-01-22 18:45:00	\N	\N	67	0	\N	\N
339507	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL articles 91 et 121 loi ELAN	PPL articles 91 et 121 loi ELAN	2019-01-22 21:30:00	2019-01-22 23:20:00	\N	\N	45	0	\N	\N
339508	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Permis à points et baisse de la limitation de vitesse à 80 km/h 	PPL Permis à points et baisse de la limitation de vitesse à 80 km/h 	2019-01-23 14:30:00	2019-01-23 15:55:00	\N	\N	104	0	\N	\N
339509	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Petites communes au sein des conseils communautaires	PPL Petites communes au sein des conseils communautaires	2019-01-24 14:30:00	2019-01-24 16:50:00	\N	\N	57	0	\N	\N
339510	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Création d'un droit voisin au profit des agences et éditeurs de presse	PPL Création d'un droit voisin au profit des agences et éditeurs de presse	2019-01-24 16:55:00	2019-01-24 18:40:00	\N	\N	22	0	\N	\N
339511	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL  Croissance et transformation des entreprises	PJL  Croissance et transformation des entreprises	2019-01-29 14:30:00	2019-01-29 20:10:00	\N	\N	214	0	\N	\N
339512	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL  Croissance et transformation des entreprises	PJL  Croissance et transformation des entreprises	2019-01-29 21:40:00	2019-01-30 00:35:00	\N	\N	86	0	\N	\N
339513	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL  Croissance et transformation des entreprises	PJL  Croissance et transformation des entreprises	2019-01-30 14:30:00	2019-01-30 20:10:00	\N	\N	200	0	\N	\N
339514	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL  Croissance et transformation des entreprises	PJL  Croissance et transformation des entreprises	2019-01-30 21:45:00	2019-01-31 00:45:00	\N	\N	95	0	\N	\N
339515	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL  Croissance et transformation des entreprises	PJL  Croissance et transformation des entreprises	2019-01-31 10:30:00	2019-01-31 13:10:00	\N	\N	116	0	\N	\N
339516	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2019-01-31 15:00:00	2019-01-31 16:10:00	\N	\N	257	0	\N	\N
339517	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL  Croissance et transformation des entreprises	PJL  Croissance et transformation des entreprises	2019-01-31 16:20:00	2019-01-31 19:55:00	\N	\N	72	0	\N	\N
339518	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL  Croissance et transformation des entreprises	PJL  Croissance et transformation des entreprises	2019-01-31 21:30:00	2019-02-01 00:05:00	\N	\N	26	0	\N	\N
339519	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL  Croissance et transformation des entreprises	PJL  Croissance et transformation des entreprises	2019-02-05 14:30:00	2019-02-05 16:35:00	\N	\N	181	0	\N	\N
339522	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL  Croissance et transformation des entreprises	PJL  Croissance et transformation des entreprises	2019-02-05 18:00:00	2019-02-05 20:45:00	\N	\N	151	0	\N	\N
339523	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL  Croissance et transformation des entreprises	PJL  Croissance et transformation des entreprises	2019-02-05 22:20:00	2019-02-06 00:30:00	\N	\N	89	0	\N	\N
339524	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2019-02-05 16:45:00	2019-02-05 17:50:00	\N	\N	299	0	\N	\N
339548	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL  Croissance et transformation des entreprises	PJL  Croissance et transformation des entreprises	2019-02-06 14:35:00	2019-02-06 21:30:00	\N	\N	143	0	\N	\N
339550	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL  Croissance et transformation des entreprises	PJL  Croissance et transformation des entreprises	2019-02-06 21:30:00	2019-02-07 00:05:00	\N	\N	57	0	\N	\N
213247	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF 2018 - Programme 105	\N	2017-10-23 18:30:00	2017-10-23 19:50:00	\N	\N	1	0	\N	\N
213252	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	PLF pour 2018 - Programme 178	\N	2017-10-25 16:00:00	2017-10-25 18:00:00	\N	\N	2	0	\N	\N
213259	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2018 - Programme 847	\N	2017-10-24 15:30:00	2017-10-24 16:30:00	\N	\N	2	0	\N	\N
213262	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2018 - Programmes 844 et  847	\N	2017-10-24 18:00:00	2017-10-24 19:15:00	\N	\N	1	0	\N	\N
214876	COM_PERMANENTE	AUTRE	\N	CDD	\N	Audition de Mme Élisabeth Borne, Ministre des transports	Audition de Mme Élisabeth Borne, Ministre des transports	2017-11-08 09:00:00	2017-11-08 11:20:00	2017-11-08 14:59:12	2017-11-08 15:51:19	46	0	\N	\N
214917	COM_PERMANENTE	AUTRE	\N	CDD	\N	Audition de M. Mounir Mahjoubi, Secrétaire d'État chargé du numérique	Audition de M. Mounir Mahjoubi, Secrétaire d'État chargé du numérique	2017-11-09 11:05:00	2017-11-09 12:30:00	2017-11-09 16:23:13	2017-11-09 17:16:53	24	0	\N	\N
217302	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2018 - Programmes 110 et 209 	\N	2017-11-07 14:30:00	2017-11-07 15:45:00	\N	\N	2	0	\N	\N
217305	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2018 - Programmes 110 et 209 	\N	2017-11-08 15:30:00	2017-11-08 16:30:00	\N	\N	2	0	\N	\N
224112	COM_PERMANENTE	AUTRE	\N	CDD	\N	Test FG2	\N	2012-02-05 15:30:21	2012-02-05 16:30:21	\N	\N	0	0	\N	\N
232158	GIA	AUCUNE	\N	\N	\N	Assemblée générale constitutive	\N	2017-12-19 14:45:00	2017-12-19 15:15:00	\N	\N	5	0	619	\N
234691	GIA	AUCUNE	\N	\N	\N	Entretien avec S.E M. Elio RODRIGUEZ PERDOMO	Entretien avec S.E M. Elio RODRIGUEZ PERDOMO	2018-01-09 14:30:00	2018-01-09 15:15:00	\N	\N	1	0	642	\N
234693	GIA	AUCUNE	\N	\N	\N	Assemblée générale constitutive	Assemblée générale constitutive	2018-01-16 14:00:00	2018-01-16 14:30:00	\N	\N	11	0	642	\N
237480	GIA	AUCUNE	\N	\N	\N	 Assemblée générale	Assemblée générale	2018-01-23 14:00:00	2018-01-23 14:40:00	\N	\N	23	0	598	\N
238607	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Organisation des Jeux Olympiques et Paralympiques 2024	\N	2018-01-25 09:00:00	2018-01-25 09:40:00	\N	\N	2	0	\N	\N
238615	GIA	AUCUNE	\N	\N	\N	assemblée générale	Assemblée générale reconstitutive	2018-01-24 14:30:00	2018-01-24 15:10:00	\N	\N	10	0	641	\N
242649	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition cycle de vie des entreprises	Audition cycle de vie des entreprises - Formalex	2018-02-06 14:00:00	2018-02-06 15:30:00	\N	\N	1	0	\N	\N
244585	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Exécution des peines liées aux violences conjugales	\N	2018-02-07 14:00:00	2018-02-07 14:30:00	\N	\N	4	0	\N	\N
244590	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Exécution des peines liées aux violences conjugales	\N	2018-02-07 14:30:00	2018-02-07 15:45:00	\N	\N	2	0	\N	\N
250073	GIA	AUCUNE	\N	\N	\N	Assemblée générale	Assemblée générale reconstitutive de reconstitution du groupe d'amitié France-Pologne	2018-01-31 13:45:00	2018-01-31 14:30:00	\N	\N	7	0	600	\N
250938	ETUDES	AUCUNE	\N	\N	\N	\N	\N	2018-03-07 08:00:00	2018-03-07 09:00:00	\N	\N	13	0	\N	908
250963	GIA	AUCUNE	\N	\N	\N	Audition commune du coprésident du Groupe de Minsk	Entretien avec l'ambassadeur Stéphane Visconti, coprésident du Groupe de Minsk	2018-03-07 08:30:00	2018-03-07 09:45:00	\N	\N	11	0	641	\N
255731	GIA	AUCUNE	\N	\N	\N	Petit-déjeuner avec le représentant de Taïwan en France	\N	2018-03-15 08:30:00	2018-03-15 09:30:00	\N	\N	9	0	623	\N
255829	COM_SPECIALE	PLENIERE	\N	SOCIETE	\N	\N	Réunion CS Confiance	2018-03-14 23:35:00	2018-03-14 23:35:00	2018-03-15 11:34:02	2018-03-15 11:59:34	16	0	\N	\N
255856	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Élection au parlement européen	\N	2018-03-14 14:30:00	2018-03-14 17:45:00	\N	\N	1	0	\N	\N
261434	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Action extérieure de l'État	Contrôle Action extérieure de l'État - Enseignement français à l'étranger	2018-03-29 11:00:00	2018-03-29 11:45:00	\N	\N	2	0	\N	\N
270214	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	LPM 2019-2025	\N	2018-04-12 09:30:00	2018-04-12 10:45:00	\N	\N	1	0	\N	\N
279289	COM_ENQUETE	PLENIERE	\N	FORCES	\N	\N	\N	2018-05-30 15:45:00	2018-05-30 17:00:00	2018-06-01 16:54:39	2018-06-01 17:04:02	9	0	\N	\N
279299	COM_ENQUETE	PLENIERE	\N	FORCES	\N	\N	\N	2018-05-30 17:00:00	2018-05-30 18:30:00	2018-06-01 16:58:09	2018-06-01 17:04:03	8	0	\N	\N
279822	COM_EURO	DEPLACEMENT	\N	AFEU	\N	Bruxelles - Rencontre avec des représentants des institutions européennes	Entretien avec M. Guillaume Denis, Conseiller politique régionale et aménagement du territoire, RP France	2018-06-05 09:30:00	2018-06-05 10:15:00	\N	\N	2	0	\N	\N
284004	GIA	AUCUNE	\N	\N	\N	Déjeuner du groupe interparlementaire d'amitié Ukraine-France	Déjeuner d'accueil de la co-présidente du groupe d'amitié Ukraine-France de la Rada	2018-06-12 12:45:00	2018-06-12 14:15:00	\N	\N	2	0	530	\N
284059	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Lutte contre la fraude	\N	2018-06-12 14:00:00	2018-06-12 15:20:00	\N	\N	1	0	\N	\N
284076	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Lutte contre les violences sexuelles et sexistes	\N	2018-06-12 14:30:00	2018-06-12 17:00:00	\N	\N	1	0	\N	\N
284078	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Lutte contre les violences sexuelles et sexistes	\N	2018-06-12 18:00:00	2018-06-12 20:40:00	\N	\N	1	0	\N	\N
284796	GIA	AUCUNE	\N	\N	\N	Réception de l'ambassadrice d'Irlande	Réception de Mme Patricia O'Brien, ambassadrice d'Irlande à Paris	2018-05-23 08:15:00	2018-05-23 09:15:00	\N	\N	8	0	594	\N
284816	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	PJL EGAlim	2018-06-12 18:00:00	2018-06-12 20:00:00	2018-06-13 19:48:53	2018-06-14 09:49:25	39	0	\N	\N
284822	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	PJL EGAlim	2018-06-12 21:05:00	2018-06-12 23:30:00	2018-06-13 19:52:25	2018-06-14 09:49:26	34	0	\N	\N
285109	GIA	AUCUNE	\N	\N	\N	Entretien avec des étudiantes et militantes Nicaraguayennes	Entretien avec des étudiantes et militantes Nicaraguayennes	2018-06-13 14:00:00	2018-06-13 15:15:00	\N	\N	2	0	643	\N
286235	COM_PERMANENTE	AUTRE	\N	CDD	\N	Audition plénière	Audition  de Mme Brune Poirson, Secrétaire d'État auprès du ministre d'État, ministre de la Transition écologique et sol	2018-06-20 09:35:00	2018-06-20 11:20:00	2018-06-20 12:16:29	2018-06-20 16:07:09	40	2	\N	\N
286237	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	Politique de cohésion de l'Union européenne : proposition de résolution européenne du groupe de suivi 	2018-06-21 09:00:00	2018-06-21 10:35:00	2018-06-21 17:04:02	2018-06-22 14:52:05	42	0	\N	\N
291527	COM_ENQUETE	PLENIERE	\N	FORCES	\N	Réunion CE FSI (adoption du rapport)	Réunion CE FSI (adoption du rapport)	2018-06-27 14:00:00	2018-06-27 16:15:00	2018-06-27 16:36:51	2018-06-27 17:07:25	17	0	\N	\N
299099	MISSION	AUCUNE	\N	MINEURSENF	\N	\N	\N	2018-07-17 12:50:00	2018-07-17 14:15:00	2018-07-17 14:32:20	2018-07-17 16:43:15	16	0	\N	\N
301002	MISSION	AUCUNE	\N	HERBE	\N	Auditions plénières	\N	2018-07-18 14:50:00	2018-07-18 17:50:00	2018-07-19 15:29:56	2018-07-19 15:32:43	10	0	\N	\N
301038	ETUDES	AUCUNE	\N	\N	\N	Bureau GE Vigne et Vin	Bureau GE Vigne et Vin	2018-07-19 14:10:00	2018-07-19 14:50:00	\N	\N	6	0	\N	909
303978	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PROG Programmation 2018-2022 et réforme pour la justice	PJL/PPLO Programmation et organisation Justice	2018-07-24 14:30:00	2018-07-24 15:30:00	\N	\N	2	0	\N	\N
303989	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Pastoralisme	GT Pastoralisme	2018-07-25 13:30:00	2018-07-25 15:30:00	\N	\N	9	0	\N	\N
304007	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PROG Programmation 2018-2022 et réforme pour la justice	PJL/PPLO Programmation et organisation Justice	2018-07-24 19:15:00	2018-07-24 20:00:00	\N	\N	2	0	\N	\N
305146	GIA	AUCUNE	\N	\N	\N	Entretien avec Amnesty International France	Entretien avec des représentants d'Amnesty International France sur la crise au Nicaragua	2018-07-18 17:30:00	2018-07-18 18:30:00	\N	\N	1	0	643	\N
305751	MECSS	AUDRAP	\N	\N	MECSS	\N	\N	2018-09-19 11:00:00	2018-09-19 11:45:00	\N	\N	1	0	\N	\N
305756	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2018-09-19 15:15:00	2018-09-19 18:15:00	\N	\N	2	0	\N	\N
305758	MECSS	AUDRAP	\N	\N	MECSS	\N	\N	2018-09-25 14:30:00	2018-09-25 15:15:00	\N	\N	1	0	\N	\N
305760	MECSS	AUDRAP	\N	\N	MECSS	\N	\N	2018-09-25 17:45:00	2018-09-25 18:30:00	\N	\N	1	0	\N	\N
286032	GIA	AUCUNE	\N	\N	\N	Entretien de M. Daunis avec une délégation de parlementaires australiens (coopé)	Entretien de M. Daunis avec une délégation de parlementaires australiens (coopé)	2018-06-11 12:30:00	2018-06-11 14:30:00	\N	\N	1	0	578	\N
305533	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 2018 - L'indemnisation des victimes du terrorisme - Cour des Comptes	58-2 2018 - L'indemnisation des victimes du terrorisme - Cour des Comptes	2018-09-12 14:30:00	2018-09-12 16:00:00	\N	\N	1	0	\N	\N
305535	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2018 - Les amendes pénales - TGI de Paris	Contrôle 2018 - Les amendes pénales - TGI de Paris	2018-09-12 10:00:00	2018-09-12 12:30:00	\N	\N	1	0	\N	\N
305537	COM_EURO	AUDRAP	\N	AFEU	\N	Extraterritorialité des sanctions américaines	Extraterritorialité des sanctions américaines - Audition de représentants de la Banque de France	2018-09-13 10:00:00	2018-09-13 11:30:00	\N	\N	1	0	\N	\N
305539	COM_EURO	AUDRAP	\N	AFEU	\N	Retour au taux réduit de TVA pour la filière équine	Retour au taux réduit de TVA pour la filière équine - Syndicat National des Propriétaires de Chevaux de Course au Galop	2018-09-13 14:00:00	2018-09-13 14:45:00	\N	\N	1	0	\N	\N
305540	COM_EURO	AUDRAP	\N	AFEU	\N	Retour au taux réduit de TVA pour la filière équine	Retour au taux réduit de TVA pour la filière équine - Audition de représentants du Groupement hippique national	2018-09-13 14:45:00	2018-09-13 15:30:00	\N	\N	1	0	\N	\N
213436	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2017-11-09 11:00:00	2017-11-09 11:45:00	\N	\N	1	0	\N	\N
286236	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2018-06-20 11:20:00	2018-06-20 11:40:00	2018-06-20 12:28:15	2018-06-20 16:07:05	40	1	\N	\N
305541	COM_EURO	AUDRAP	\N	AFEU	\N	Retour au taux réduit de TVA pour la filière équine	Retour au taux réduit de TVA pour la filière équine - Audition de représentants de France Galop	2018-09-13 15:30:00	2018-09-13 16:15:00	\N	\N	1	0	\N	\N
311767	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Conseils d'administration des SDIS	\N	2018-10-09 15:00:00	2018-10-09 17:45:00	\N	\N	0	0	\N	\N
311768	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Conseils d'administration des SDIS	\N	2018-10-10 14:15:00	2018-10-10 15:00:00	\N	\N	0	0	\N	\N
311769	DELEGATION	AUDRAP	\N	\N	COLTER	Audition rôle des communes dans les intercommunalités	Audition rôle des communes dans les intercommunalités : France urbaine	2018-10-16 15:30:00	2018-10-16 16:30:00	\N	\N	2	0	\N	\N
311775	DELEGATION	AUDRAP	\N	\N	COLTER	Audition rôle des communes dans les intercommunalités	Audition rôle des communes dans les intercommunalités : Audition Julia MOUZON	2018-10-23 17:00:00	2018-10-23 18:00:00	\N	\N	2	0	\N	\N
331358	DELEGATION	AUCUNE	\N	\N	COLTER	Audition de M. Serge Morvan - CGET	\N	2018-12-06 11:00:00	2018-12-06 12:45:00	2018-12-06 15:00:33	2018-12-06 17:15:58	12	0	\N	\N
331925	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2019 - Examen Amdts séance missions Outre-Mer-APD-AEE et MIRES	PLF pour 2019 - Examen Amdts séance missions Outre-Mer-APD-AEE et MIRES	2018-12-03 09:30:00	2018-12-03 09:55:00	2018-12-03 11:17:07	2018-12-03 17:47:22	14	0	\N	\N
340438	DELEGATION	AUCUNE	\N	\N	DSOM	Audition dans le cadre de la visite du pôle outre-mer de France Télévisions	Audition dans le cadre de la visite du pôle outre-mer de France Télévisions	2019-01-21 14:30:00	2019-01-21 19:00:00	2019-01-22 08:33:09	2019-01-22 12:00:01	7	0	\N	\N
340451	DELEGATION	AUDRAP	\N	\N	PROS	Audition de M. Hervé Le Treut, climatologue	\N	2019-01-16 11:00:00	2019-01-16 12:15:00	\N	\N	2	0	\N	\N
340453	DELEGATION	AUDRAP	\N	\N	PROS	Audition de l'ADEME	\N	2019-01-22 09:00:00	2019-01-22 10:00:00	\N	\N	1	0	\N	\N
340455	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Création d'un droit voisin au profit des agences et éditeurs de presse	PPL Création d'un droit voisin au profit des agences et éditeurs de presse	2019-01-07 14:00:00	2019-01-07 15:00:00	\N	\N	1	0	\N	\N
340457	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Création d'un droit voisin au profit des agences et éditeurs de presse	PPL Création d'un droit voisin au profit des agences et éditeurs de presse	2019-01-07 15:00:00	2019-01-07 18:00:00	\N	\N	2	0	\N	\N
340460	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Création d'un droit voisin au profit des agences et éditeurs de presse	PPL Création d'un droit voisin au profit des agences et éditeurs de presse	2019-01-08 14:30:00	2019-01-08 15:30:00	\N	\N	2	0	\N	\N
340463	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Création d'un droit voisin au profit des agences et éditeurs de presse	PPL Création d'un droit voisin au profit des agences et éditeurs de presse	2019-01-08 15:30:00	2019-01-08 17:30:00	\N	\N	3	0	\N	\N
346480	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	Audition de M. Lardy en vue de sa nomination à France compétences	2019-02-06 09:30:00	2019-02-06 11:00:00	2019-02-06 11:29:29	2019-02-06 17:44:23	31	0	\N	\N
348108	COM_EURO	AUDRAP	\N	AFEU	\N	Audition BCE	Audition BCE	2019-01-30 16:00:00	2019-01-30 17:00:00	\N	\N	2	0	\N	\N
348111	COM_EURO	AUDRAP	\N	AFEU	\N	Audition BCE	Audition BCE	2019-01-29 16:30:00	2019-01-29 17:45:00	\N	\N	1	0	\N	\N
348321	COM_EURO	AUDRAP	\N	AFEU	\N	\N	\N	2019-02-05 14:00:00	2019-02-05 15:00:00	\N	\N	2	0	\N	\N
348329	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	Auditions rapporteurs	\N	2019-02-13 14:00:00	2019-02-13 18:00:00	\N	\N	0	0	\N	\N
349223	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-02-06 09:05:00	2019-02-06 12:30:00	2019-02-06 14:40:13	2019-02-06 17:44:20	43	2	\N	\N
349285	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Démarchage téléphonique et lutte contre les appels frauduleux - Opposetel	\N	2019-02-05 18:10:00	2019-02-05 19:00:00	\N	\N	1	0	\N	\N
349286	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Démarchage téléphonique et lutte contre les appels frauduleux - M. Laurent Leveneur	\N	2019-02-05 19:00:00	2019-02-05 19:35:00	\N	\N	1	0	\N	\N
349287	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Démarchage téléphonique et lutte contre les appels frauduleux - M. Christophe Naegelen	\N	2019-02-05 19:35:00	2019-02-05 20:30:00	\N	\N	1	0	\N	\N
349542	DELEGATION	AUCUNE	\N	\N	DSOM	Audition de la Caisse centrale de réassurance	Délégation sénatoriale aux outre-mer - Audition de la Caisse centrale de réassurance	2019-02-14 09:05:00	2019-02-14 10:40:00	2019-02-14 11:25:59	2019-02-14 16:06:31	6	0	\N	\N
350049	COM_PERMANENTE	DEPLACEMENT	\N	CDD	DSOM	Déplacement sur le site d'expérimentation du véhicule autonome à Rouen-Métropole	\N	2019-02-07 12:45:00	2019-02-07 19:30:00	\N	\N	6	0	\N	\N
356231	MECSS	AUDRAP	\N	\N	MECSS	\N	\N	2019-03-05 16:45:00	2019-03-05 17:45:00	\N	\N	2	0	\N	\N
356234	MECSS	AUDRAP	\N	\N	MECSS	\N	\N	2019-03-14 09:30:00	2019-03-14 11:00:00	\N	\N	2	0	\N	\N
356238	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2019-03-07 10:00:00	2019-03-07 11:00:00	\N	\N	3	0	\N	\N
356242	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2019-03-07 16:00:00	2019-03-07 18:00:00	\N	\N	3	0	\N	\N
356248	GIA	AUCUNE	\N	\N	\N	Audition Persecutions Religieuses en Inde	Audition d'un témoinsur les persuctions dont sont victimes les Chrétiens en Inde à l'initiative de l'association Porte O	2019-02-20 15:00:00	2019-02-20 16:00:00	\N	\N	3	0	618	\N
357082	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Vladimir Fedorovski	Entretien avec M. Vladimir Fedorovski	2019-03-06 08:00:00	2019-03-06 09:30:00	\N	\N	16	0	608	\N
358909	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	GT justice prud'homale	Déplacement Aix-en-Provence	2019-03-04 06:00:00	2019-03-05 21:00:00	\N	\N	1	0	\N	\N
358916	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL "Habitat insalubre ou dangereux"	PPL "Habitat insalubre ou dangereux"	2019-03-06 14:30:00	2019-03-06 15:30:00	\N	\N	1	0	\N	\N
361175	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-03-19 13:35:00	2019-03-19 14:05:00	2019-03-19 18:18:22	2019-03-20 15:55:50	36	1	\N	\N
361176	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désignation de CMP - PJL Orientation des mobilités	\N	2019-03-20 08:30:00	2019-03-20 08:35:00	\N	\N	0	0	\N	\N
361240	COM_PERMANENTE	AUTRE	\N	CDD	\N	Désignation de CMP - PPL ANCT	\N	2019-03-20 08:30:00	2019-03-20 08:35:00	\N	\N	0	0	\N	\N
361242	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Agriculture biologique - INAO	Contrôle 2019 - Agriculture biologique - INAO	2019-03-12 14:30:00	2019-03-12 16:35:00	\N	\N	2	0	\N	\N
361272	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-03-20 10:25:00	2019-03-20 11:30:00	2019-03-20 15:54:43	2019-03-20 16:12:54	43	0	\N	\N
361318	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Produits agricoles ou alimentaires	PPL Produits agricoles ou alimentaires	2019-03-14 09:00:00	2019-03-14 10:30:00	\N	\N	3	0	\N	\N
213432	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2017-11-07 15:00:00	2017-11-07 15:45:00	\N	\N	1	0	\N	\N
349527	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Justice, Polynésie,Mayotte	\N	2019-02-06 09:10:00	2019-02-06 12:25:00	2019-02-06 14:36:35	2019-02-06 18:10:57	41	0	\N	\N
213476	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF  pour 2018 - Sécurité civile	\N	2017-10-30 16:35:00	2017-10-30 19:00:00	\N	\N	1	0	\N	\N
215984	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Cohésion des territoires	PLF pour 2018 - Cohésion des territoires - DHUP	2017-11-06 11:00:00	2017-11-06 12:45:00	\N	\N	1	0	\N	\N
215986	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Cohésion des territoires	PLF pour 2018 - Cohésion des territoires - Union sociale pour l'habitat	2017-11-06 14:30:00	2017-11-06 16:00:00	\N	\N	1	0	\N	\N
215988	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018  - Sécurité routière	PLF pour 2018  - Sécurité routière - Délégué interministériel à la sécurité routière	2017-11-07 09:30:00	2017-11-07 11:30:00	\N	\N	1	0	\N	\N
232498	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Application du régime d'asile européen	\N	2017-12-20 09:00:00	2017-12-20 10:00:00	\N	\N	4	0	\N	\N
232504	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Application du régime d'asile européen	\N	2017-12-20 10:00:00	2017-12-20 10:45:00	\N	\N	5	0	\N	\N
232512	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Application du régime d'asile européen	\N	2017-12-20 10:45:00	2017-12-20 11:30:00	\N	\N	4	0	\N	\N
232517	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Application du régime d'asile européen	\N	2017-12-20 11:30:00	2017-12-20 12:00:00	\N	\N	4	0	\N	\N
232523	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Application du régime d'asile européen	\N	2017-12-20 12:00:00	2017-12-20 12:30:00	\N	\N	3	0	\N	\N
232528	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Application du régime d'asile européen	\N	2017-12-20 12:30:00	2017-12-20 13:00:00	\N	\N	2	0	\N	\N
233329	COM_PERMANENTE	AUTRE	\N	AFCL	\N	auditions	auditions	2018-01-17 09:35:00	2018-01-17 12:30:00	2018-01-17 12:44:08	2018-01-17 16:08:05	49	0	\N	\N
233330	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition de Mme Frédérique Vidal PJL Orientation et réussite des étudiants	audition Vidal	2018-01-17 15:35:00	2018-01-17 17:35:00	2018-01-18 16:48:28	2018-01-18 16:49:47	27	0	\N	\N
239186	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition Presstalis	Audition Presstalis	2018-01-31 11:30:00	2018-01-31 12:50:00	2018-01-31 13:15:51	2018-01-31 14:23:06	28	0	\N	\N
239188	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition de M. Pierre Mathiot	Audition de M. Pierre Mathiot	2018-01-31 14:35:00	2018-01-31 16:35:00	2018-01-31 16:51:20	2018-01-31 17:15:15	29	0	\N	\N
239751	COM_SPECIALE	PLENIERE	\N	ETAT	\N	GT Essoc - réunion bureau	\N	2018-01-30 15:20:00	2018-01-30 16:10:00	2018-02-01 11:17:15	2018-02-14 13:56:33	16	0	\N	\N
239756	COM_PERMANENTE	EXAMEN	\N	LOIS	\N	PPL Conflits d'intérêts - Auditions rapporteur	\N	2018-02-08 08:30:00	2018-02-08 11:00:00	\N	\N	0	0	\N	\N
240183	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	LOIS	\N	Situation des prisons	\N	2018-01-30 17:10:00	2018-01-30 17:40:00	\N	\N	0	0	\N	\N
249817	ETUDES	AUCUNE	\N	\N	\N	GE Élevage	\N	2018-02-20 14:00:00	2018-02-20 15:00:00	\N	\N	15	0	\N	911
249902	MISSION	AUDRAP	\N	ALSTOM	\N	MI ALSTOM - Auditions président&rapporteur	\N	2018-02-21 14:30:00	2018-02-21 15:30:00	\N	\N	4	0	\N	\N
249917	MISSION	AUDRAP	\N	ALSTOM	\N	MI ALSTOM - Auditions président&rapporteur	\N	2018-02-21 15:30:00	2018-02-21 16:30:00	\N	\N	2	0	\N	\N
250368	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Référé gestion dépenses de personnels au MAE	Contrôle Référé gestion dépenses de personnels au MAE - Audition de la Cour des comptes	2018-02-27 11:00:00	2018-02-27 12:00:00	\N	\N	1	0	\N	\N
250453	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Teemu Tanner, ambassadeur de Finlande en France	Entretien avec M. Teemu Tanner, ambassadeur de Finlande en France	2018-03-06 12:30:00	2018-03-06 14:15:00	\N	\N	12	0	640	\N
251926	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition	\N	2018-03-14 11:05:00	2018-03-14 12:30:00	2018-03-14 15:22:11	2018-03-14 15:32:27	62	0	\N	\N
252180	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	Commission des comptes	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne	2018-03-08 14:15:00	2018-03-08 14:30:00	2018-03-08 16:07:14	2018-03-08 16:07:48	7	0	\N	\N
252447	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL "Réforme du Logement"	PJL "Réforme du Logement"	2018-03-06 15:00:00	2018-03-06 17:00:00	\N	\N	4	0	\N	\N
252452	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL "Réforme du Logement"	PJL "Réforme du Logement"	2018-03-07 15:00:00	2018-03-07 17:55:00	\N	\N	5	0	\N	\N
252459	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL "Réforme du Logement"	PJL "Réforme du Logement"	2018-03-08 10:45:00	2018-03-08 12:35:00	\N	\N	3	0	\N	\N
252469	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL "Réforme du Logement"	PJL "Réforme du Logement"	2018-03-08 14:00:00	2018-03-08 15:00:00	\N	\N	4	0	\N	\N
252508	ETUDES	AUCUNE	\N	\N	\N	G.E. "Elevage"	G.E. "Elevage"	2018-03-07 08:00:00	2018-03-07 09:00:00	\N	\N	14	0	\N	911
256024	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de M. Christian Dubreuil	Audition de M. Christian Dubreuil, directeur général de l'ONF	2018-03-21 09:35:00	2018-03-21 11:40:00	2018-03-23 10:51:51	2018-03-23 10:54:58	36	0	\N	\N
256028	DELEGATION	AUDRAP	\N	\N	206	Audition de Générations Futures	Audition de M. François Veillerette, porte-parole de Générations Futures	2018-04-09 14:45:00	2018-04-09 16:00:00	\N	\N	2	0	\N	\N
256029	DELEGATION	AUDRAP	\N	\N	206	Audition de UFC-Que Choisir	Audition de UFC-Que Choisir	2018-04-09 16:00:00	2018-04-09 16:45:00	\N	\N	2	0	\N	\N
256030	DELEGATION	AUDRAP	\N	\N	206	Audition de Réseau Environnement et Santé (RES)	Audition de M. André Cicolella, président de Réseau Environnement et Santé (RES)	2018-04-09 16:45:00	2018-04-09 17:45:00	\N	\N	2	0	\N	\N
263760	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	GT justice prud'homale	GT justice prud'homale	2018-04-04 14:00:00	2018-04-04 18:00:00	\N	\N	3	0	\N	\N
263859	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	GT justice prud'homale	GT justice prud'homale	2018-03-21 15:00:00	2018-03-21 18:15:00	\N	\N	4	0	\N	\N
266868	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Alain Claeys, ancien député	Audition de M. Alain Claeys, ancien député, rapporteur du projet de loi de révision de la loi bioéthique	2018-04-18 16:30:00	2018-04-18 17:30:00	\N	\N	3	0	\N	\N
267465	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL de programmation militaire pour les années 2019-2025	PJL de programmation militaire pour les années 2019-2025 - Audition GICAT	2018-04-10 15:30:00	2018-04-10 16:30:00	\N	\N	1	0	\N	\N
267468	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Défense - Disponibilité des hélicoptères du ministère des Armées	Contrôle Défense - Disponibilité des hélicoptères du ministère des Armées - Safran Helicopter Engines	2018-04-12 14:30:00	2018-04-12 15:30:00	\N	\N	1	0	\N	\N
345234	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Orientation des mobilités	PJL Orientation des mobilités	2019-03-20 21:30:00	2019-03-21 01:20:00	\N	\N	96	0	\N	\N
251925	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Examen de conventions internationales	\N	2018-03-14 10:15:00	2018-03-14 10:45:00	2018-03-14 15:18:59	2018-03-14 15:32:11	37	1	\N	\N
267470	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL de programmation militaire pour les années 2019-2025	PJL de programmation militaire pour les années 2019-2025 - SGA	2018-04-12 15:30:00	2018-04-12 17:00:00	\N	\N	1	0	\N	\N
267472	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Commission de vérification des fonds spéciaux - Remise du rapport annuel	Commission de vérification des fonds spéciaux - Remise du rapport annuel	2018-04-11 17:30:00	2018-04-11 18:10:00	\N	\N	2	0	\N	\N
267475	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2018-04-17 15:00:00	2018-04-17 16:05:00	2018-04-17 16:45:32	2018-04-17 19:29:12	24	0	\N	\N
267476	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2018-04-18 10:05:00	2018-04-18 11:45:00	2018-04-18 14:46:13	2018-04-18 16:47:46	32	0	\N	\N
267625	DELEGATION	AUDRAP	\N	\N	DSOM	Renconttre avec Mme Muriel Peneveyre, ministre après de l'ambassade de Suisse en France	\N	2018-04-16 15:00:00	2018-04-16 16:30:00	\N	\N	1	0	\N	\N
304883	MISSION	DEPLACEMENT	\N	HERBE	\N	Déplacement dans le Maine-et-Loire	\N	2018-07-27 09:00:00	2018-07-27 19:00:00	\N	\N	6	0	\N	\N
305883	DELEGATION	AUCUNE	\N	\N	COLTER	Audition de Mme Jacqueline Gourault	Audition de Mme Jacqueline Gourault, Ministre auprès du ministre de l'Intérieur	2018-09-27 09:00:00	2018-09-27 10:15:00	2018-09-27 10:43:56	2018-09-27 17:39:05	13	0	\N	\N
305897	DELEGATION	AUCUNE	\N	\N	PROS	Audition de Jean-Paul Delevoye	Audition de Jean-Paul Delevoye	2018-10-25 08:30:00	2018-10-25 10:00:00	2018-10-25 16:47:28	2018-10-25 18:03:09	25	0	\N	\N
305900	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	PROS	Réunion du Bureau de la délégation	Réunion du Bureau de la délégation	2018-10-11 12:30:00	2018-10-11 14:00:00	\N	\N	11	0	\N	\N
316300	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2018-10-17 19:35:00	2018-10-17 20:30:00	\N	\N	26	0	\N	\N
337781	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Groupe de travail Biocarburants	Groupe de travail Biocarburants	2018-12-12 15:00:00	2018-12-12 18:00:00	\N	\N	6	0	\N	\N
340409	GIA	AUCUNE	\N	\N	\N	Entretien avec une délégation de parlementaires et de fonctionnaires indonésiens 	Entretien avec une délégation de parlementaires et de fonctionnaires indonésiens de l'agence du cadastre 	2018-12-04 16:30:00	2018-12-04 17:15:00	\N	\N	2	0	653	\N
340513	GIA	AUCUNE	\N	\N	\N	Marche de soutien à la cause tibétaine	Marche de soutien à la cause tibétaine	2018-03-10 14:00:00	2018-03-10 18:00:00	\N	\N	1	0	634	\N
340515	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2019-01-10 16:00:00	2019-01-10 18:30:00	\N	\N	1	0	\N	\N
340630	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2018-12-18 18:35:00	2018-12-18 19:50:00	\N	\N	36	0	\N	\N
340842	DELEGATION	AUDRAP	\N	\N	PROS	Audition de l'ANEM	\N	2019-01-29 09:30:00	2019-01-29 10:30:00	\N	\N	1	0	\N	\N
340917	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	Auditions M. Savary	\N	2019-02-07 10:00:00	2019-02-07 12:00:00	\N	\N	0	0	\N	\N
340949	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Vote candidats CSM et dépouillement des scrutins propositions Président du Sénat	Vote candidats CSM et dépouillement des scrutins propositions Président du Sénat	2019-01-15 17:25:00	2019-01-15 17:45:00	2019-01-15 18:53:46	2019-01-16 11:15:35	29	0	\N	\N
341436	DELEGATION	DEPLACEMENT	\N	\N	PROS	Visite de Station F	Visite de Station F	2019-01-31 09:00:00	2019-01-31 11:15:00	\N	\N	9	0	\N	\N
343154	GIA	AUCUNE	\N	\N	\N	Petit déjeuner Nadine Girault	Pett déjeuner avec la ministre des relations internationales et de la francophonie du Québec	2019-01-22 08:30:00	2019-01-23 09:30:00	\N	\N	9	0	602	\N
344099	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation	Accueil d'une délégation de fonctionnaires vietnamiens	2019-01-16 17:00:00	2019-01-16 18:00:00	\N	\N	1	0	626	\N
344991	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition 58-2 Indemnisation victimes du terrorisme et Programme contrôle 2019	Audition 58-2 Indemnisation victimes du terrorisme et Programme contrôle 2019	2019-01-30 10:05:00	2019-01-30 12:10:00	2019-01-30 16:26:38	2019-01-30 16:38:53	41	0	\N	\N
345033	DELEGATION	AUDRAP	\N	\N	PROS	Audition de Régions de France	\N	2019-02-21 15:30:00	2019-02-21 16:30:00	\N	\N	1	0	\N	\N
345105	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-01-30 09:35:00	2019-01-30 11:35:00	2019-01-30 14:33:24	2019-01-30 14:49:54	37	0	\N	\N
345107	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Audition de Thierry Lepaon	\N	2019-01-24 14:00:00	2019-01-24 15:00:00	\N	\N	0	0	\N	\N
345123	DELEGATION	AUCUNE	\N	\N	COLTER	Audition M. Espinasse, SG adjoint ministère Intérieur - simplification normative	\N	2019-01-31 09:00:00	2019-01-31 10:30:00	2019-01-31 10:57:53	2019-01-31 18:30:31	11	0	\N	\N
345131	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI handicap dans la fonction publique. 	\N	2019-01-23 15:30:00	2019-01-23 19:00:00	\N	\N	2	0	\N	\N
345218	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2019-03-07 15:00:00	2019-03-07 16:05:00	\N	\N	242	0	\N	\N
345219	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Nationalisation des sociétés d'autoroutes	PPL Nationalisation des sociétés d'autoroutes	2019-03-07 16:15:00	2019-03-07 18:30:00	\N	\N	67	0	\N	\N
345220	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Interdiction lanceurs de balles	PPL Interdiction lanceurs de balles	2019-03-07 18:35:00	2019-03-07 20:20:00	\N	\N	33	0	\N	\N
345221	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Violences manifestations	PPL Violences manifestations	2019-03-12 14:30:00	2019-03-12 16:30:00	\N	\N	167	0	\N	\N
345222	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2019-03-12 16:45:00	2019-03-12 17:40:00	\N	\N	305	0	\N	\N
345223	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Violences manifestations	PPL Violences manifestations	2019-03-12 17:55:00	2019-03-12 20:00:00	\N	\N	124	0	\N	\N
345224	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Violences manifestations	PPL Violences manifestations	2019-03-12 21:30:00	2019-03-13 23:15:00	\N	\N	83	0	\N	\N
345225	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Proches aidants	PPL Proches aidants	2019-03-13 14:30:00	2019-03-13 15:20:00	\N	\N	87	0	\N	\N
345226	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Lisibilité du droit	PPL Lisibilité du droit	2019-03-13 15:25:00	2019-03-13 16:10:00	\N	\N	84	0	\N	\N
345227	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Bénévolat dans la société française	Débat Bénévolat dans la société française	2019-03-13 16:20:00	2019-03-13 17:50:00	\N	\N	54	0	\N	\N
345228	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Soutien territoires ruraux fragiles	Débat Soutien territoires ruraux fragiles	2019-03-14 10:30:00	2019-03-14 12:00:00	\N	\N	48	0	\N	\N
345229	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Précarité énergétique des ménages	Débat Précarité énergétique des ménages	2019-03-14 14:30:00	2019-03-14 15:55:00	\N	\N	39	0	\N	\N
345230	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2019-03-19 09:30:00	2019-03-19 12:50:00	\N	\N	40	0	\N	\N
345231	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Orientation des mobilités	PJL Orientation des mobilités	2019-03-19 14:30:00	2019-03-19 20:00:00	\N	\N	215	0	\N	\N
345232	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Orientation des mobilités	PJL Orientation des mobilités	2019-03-19 21:30:00	2019-03-20 00:30:00	\N	\N	106	0	\N	\N
345233	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Orientation des mobilités	PJL Orientation des mobilités	2019-03-20 14:30:00	2019-03-20 19:25:00	\N	\N	179	0	\N	\N
345235	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Orientation des mobilités	PJL Orientation des mobilités	2019-03-21 11:30:00	2019-03-21 13:15:00	\N	\N	108	0	\N	\N
345237	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Orientation des mobilités	PJL Orientation des mobilités	2019-03-21 16:25:00	2019-03-21 20:10:00	\N	\N	88	0	\N	\N
345238	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Orientation des mobilités	PJL Orientation des mobilités	2019-03-21 21:45:00	2019-03-22 01:00:00	\N	\N	34	0	\N	\N
345239	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Orientation des mobilités	PJL Orientation des mobilités	2019-03-26 14:30:00	2019-03-26 16:30:00	\N	\N	140	0	\N	\N
345240	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2019-03-26 16:45:00	2019-03-26 17:40:00	\N	\N	302	0	\N	\N
345241	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Orientation des mobilités	PJL Orientation des mobilités	2019-03-26 17:50:00	2019-03-26 20:10:00	\N	\N	126	0	\N	\N
345242	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Orientation des mobilités	PJL Orientation des mobilités	2019-03-26 21:40:00	2019-03-27 00:30:00	\N	\N	101	0	\N	\N
345243	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Orientation des mobilités	PJL Orientation des mobilités	2019-03-27 14:30:00	2019-03-27 20:05:00	\N	\N	153	0	\N	\N
345245	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Orientation des mobilités	PJL Orientation des mobilités	2019-03-28 10:30:00	2019-03-28 13:00:00	\N	\N	70	0	\N	\N
345251	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-01-30 10:10:00	2019-01-30 12:00:00	2019-01-30 12:26:18	2019-01-30 14:49:51	41	0	\N	\N
345252	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-01-29 16:05:00	2019-01-29 17:55:00	2019-01-29 18:19:47	2019-01-30 14:49:54	32	0	\N	\N
345590	COM_SPECIALE	PLENIERE	\N	ENTREPRISES	\N	\N	\N	2019-01-30 13:15:00	2019-01-30 14:30:00	\N	\N	11	0	\N	\N
214967	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2018 - Conseil et contrôle de l'Etat	\N	2017-11-07 14:30:00	2017-11-07 16:45:00	\N	\N	1	0	\N	\N
230145	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne	2017-12-14 09:00:00	2017-12-14 11:30:00	2017-12-14 11:49:15	2017-12-14 14:44:56	6	0	\N	\N
233313	DELEGATION	DEPLACEMENT	\N	\N	211	Visite du pôle judiciaire de la Gendarmerie nationale (Pontoise)	Visite du pôle judiciaire de la Gendarmerie nationale (Pontoise)	2018-01-22 11:30:00	2018-01-22 17:30:00	\N	\N	4	0	\N	\N
233318	DELEGATION	DEPLACEMENT	\N	\N	211	Visite de l'Institut de santé génésique (St Germain en Laye)	Visite de l'Institut de santé génésique (St Germain en Laye)	2018-02-05 13:30:00	2018-02-05 17:30:00	\N	\N	4	0	\N	\N
233323	DELEGATION	AUDRAP	\N	\N	211	Association Elues contre les violences faites aux femmes (ECVF)	Association Elues contre les violences faites aux femmes (ECVF)	2017-12-12 18:00:00	2017-12-12 19:00:00	\N	\N	2	0	\N	\N
233324	DELEGATION	AUDRAP	\N	\N	211	Audition de M. Erick Dal, contrôleur général des armées	Audition de M. Erick Dal, contrôleur général des armées	2017-12-19 18:00:00	2017-12-19 20:00:00	\N	\N	2	0	\N	\N
238767	GIA	AUCUNE	\N	\N	\N	AG du groupe	Assemblée générale reconstitutive du groupe et désignation du bureau	2018-01-17 14:30:00	2018-01-17 15:00:00	\N	\N	7	0	576	\N
238780	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition article 13 DG BPI - Communication PDT Bureau et programme contrîole	Audition article 13 DG BPI M. Nicolas DUFOURCQ - Communication PDT Bureau et programme contrîole	2018-01-31 09:05:00	2018-01-31 10:55:00	2018-01-31 18:43:53	2018-02-01 20:06:41	40	0	\N	\N
238781	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition Directeur général des douanes	Audition Directeur général des douanes M. Rodolphe GINTZ	2018-01-31 10:55:00	2018-01-31 12:30:00	2018-01-31 18:44:18	2018-02-01 20:06:57	26	0	\N	\N
238782	MISSION	AUCUNE	\N	ALSTOM	\N	Audition de M. Louis SCHWEITZER	Audition  de M. Louis SCHWEITZER	2018-02-01 11:00:00	2018-02-01 12:30:00	2018-02-01 16:58:51	2018-02-01 20:08:37	13	0	\N	\N
238783	MISSION	AUCUNE	\N	ALSTOM	\N	Audition commune d'entreprises industrielles de taille intermédiaire	Audition commune d'entreprises industrielles de taille intermédiaire	2018-02-01 13:35:00	2018-02-01 14:40:00	2018-02-01 16:59:07	2018-02-01 20:08:38	11	0	\N	\N
238878	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Territoires littoraux	PPL Territoires littoraux	2018-01-30 14:30:00	2018-01-30 20:20:00	\N	\N	151	0	\N	\N
247275	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	GT Sécurité routière	Groupe de travail sur la sécurité routière	2018-02-13 14:00:00	2018-02-13 17:15:00	\N	\N	8	0	\N	\N
247485	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe	Assemblée générale du groupe	2018-02-20 13:45:00	2018-02-20 14:30:00	\N	\N	8	0	616	\N
250958	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	\N	GT Financement handicap	2018-03-06 17:00:00	2018-03-06 18:00:00	\N	\N	1	0	\N	\N
250960	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	\N	GT Financement handicap	2018-03-06 18:00:00	2018-03-06 19:00:00	\N	\N	2	0	\N	\N
258773	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Libye	\N	2018-03-20 14:00:00	2018-03-20 15:00:00	\N	\N	4	0	\N	\N
258778	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Libye	\N	2018-03-20 15:00:00	2018-03-20 15:50:00	\N	\N	2	0	\N	\N
258781	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Libye	\N	2018-03-20 15:45:00	2018-03-20 16:40:00	\N	\N	2	0	\N	\N
258784	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Libye	\N	2018-03-20 16:30:00	2018-03-20 17:30:00	\N	\N	3	0	\N	\N
258788	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Libye	\N	2018-03-20 17:30:00	2018-03-20 18:30:00	\N	\N	2	0	\N	\N
258891	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Mission "Sport, jeunesse et vie associative"	PLF pour 2019 - Mission "Sport, jeunesse et vie associative" - Agence service civique	2018-03-21 15:30:00	2018-03-21 16:30:00	\N	\N	1	0	\N	\N
258893	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Modernisation du contrôle de la navigation aérienne	Contrôle Modernisation du contrôle de la navigation aérienne - Audition DSAC	2018-03-22 10:00:00	2018-03-22 11:30:00	\N	\N	1	0	\N	\N
258899	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Réforme des retraites 	Contrôle Réforme des retraites  - Auditions CCMSA, Cour des comptes, SNCF	2018-03-21 14:00:00	2018-03-21 18:00:00	\N	\N	1	0	\N	\N
282390	MECSS	AUCUNE	\N	\N	MECSS	réforme systémique des retraites	\N	2018-06-07 09:00:00	2018-06-07 12:00:00	\N	\N	2	0	\N	\N
345588	COM_SPECIALE	AUTRE	\N	ENTREPRISES	\N	\N	\N	2019-01-30 08:00:00	2019-01-30 10:05:00	\N	\N	24	0	\N	\N
258902	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle APD - Audition OCDE	Contrôle APD - Audition OCDE	2018-03-21 15:30:00	2018-03-21 17:00:00	\N	\N	2	0	\N	\N
258903	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle - 58-2 Soutien énergies renouvelables 2018	Contrôle - 58-2 Soutien énergies renouvelables 2018 - DGEC - EDF - ADEME	2018-03-21 15:00:00	2018-03-21 17:30:00	\N	\N	1	0	\N	\N
258911	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle MIRES 2018 - Performance établissements ens. sup	Contrôle MIRES 2018 - Performance établissements ens. sup - CGE - CPU - CDEFI	2018-03-22 09:30:00	2018-03-22 12:30:00	\N	\N	1	0	\N	\N
261314	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI thanatopraxie	MI thanatopraxie	2018-03-29 09:30:00	2018-03-29 10:30:00	\N	\N	1	0	\N	\N
261316	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI thanatopraxie	MI thanatopraxie	2018-03-29 11:00:00	2018-03-29 12:30:00	\N	\N	1	0	\N	\N
270304	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Jérôme Bonnafont, directeur Afrique du Nord et Moyen-Orient (MEAE)	Entretien avec M. Jérôme Bonnafont, directeur Afrique du Nord et Moyen-Orient (MEAE)	2018-04-25 10:15:00	2018-04-25 11:15:00	\N	\N	1	0	644	\N
270306	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Régis Savioz, chef de la délégation du CICR à Paris	Entretien avec M. Régis Savioz, chef de la délégation du CICR à Paris	2018-04-25 12:00:00	2018-04-25 13:30:00	\N	\N	1	0	644	\N
275112	CONF_PRES	AUCUNE	\N	\N	\N	\N	\N	2018-05-16 19:40:00	2018-05-16 19:55:00	\N	\N	21	0	\N	\N
285015	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PJL Lutte contre la fraude - Contrôle sur place Verrou de Bercy - MIN ECOFIN	PJL Lutte contre la fraude - Contrôle sur place Verrou de Bercy - MIN ECOFIN	2018-06-11 15:30:00	2018-06-11 18:00:00	\N	\N	2	0	\N	\N
290517	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Audition avenir pro	\N	2018-06-12 15:15:00	2018-06-12 16:45:00	\N	\N	1	0	\N	\N
293387	COM_SPECIALE	PLENIERE	\N	SOCIETE	\N	Examen d'un rapport et établissement du texte	\N	2018-07-11 14:05:00	2018-07-11 16:15:00	2018-07-11 19:14:14	2018-07-12 15:58:09	21	0	\N	\N
293388	AUTRE_TEMPORAIRE	DEPLACEMENT	\N	\N	\N	Financement médico-social du handicap	\N	2018-06-22 06:00:00	2018-06-22 15:45:00	\N	\N	0	0	\N	\N
293438	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI thanatopraxie	MI thanatopraxie	2018-06-28 16:00:00	2018-06-28 17:30:00	\N	\N	1	0	\N	\N
293444	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2018-07-03 14:50:00	2018-07-03 20:00:00	2018-07-04 16:43:56	2018-07-04 16:58:22	43	2	\N	\N
293445	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2018-07-03 21:05:00	2018-07-03 23:20:00	2018-07-04 16:43:32	2018-07-04 16:58:23	34	2	\N	\N
293454	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	auditions plénières	\N	2018-07-05 10:15:00	2018-07-05 12:15:00	\N	\N	0	0	\N	\N
293455	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	réunions plénières	\N	2018-07-06 09:30:00	2018-07-06 12:30:00	\N	\N	0	0	\N	\N
293458	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	auditions rapporteur	\N	2018-07-06 14:30:00	2018-07-06 18:00:00	\N	\N	0	0	\N	\N
298803	COM_SPECIALE	AUTRE	\N	SOCIETE	\N	Examen des amendements de séance	\N	2018-07-24 09:34:00	2018-07-24 10:00:00	2018-07-25 11:24:18	2018-07-25 11:37:38	17	0	\N	\N
305762	MECSS	AUDRAP	\N	\N	MECSS	\N	\N	2018-09-26 14:30:00	2018-09-26 17:30:00	\N	\N	2	0	\N	\N
305413	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion du 20180912 - PPLO Nomination rapp. - PPL Violences - Nomination membres CMP	\N	2018-09-12 15:00:00	2018-09-12 16:05:00	2018-09-13 17:51:56	2018-09-13 17:52:14	27	1	\N	\N
305414	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	\N	\N	2018-09-12 16:00:00	2018-09-12 17:00:00	\N	\N	0	0	\N	\N
305431	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2018 - Aides à la pierre - Déplacement Lille	Contrôle 2018 - Aides à la pierre - Déplacement Lille	2018-08-30 08:10:00	2018-08-30 18:15:00	\N	\N	1	0	\N	\N
305433	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2018 - Culture - Gestion déconcentrée des crédits DRAC  - Déplacement Bordeaux	Contrôle 2018 - Culture - Gestion déconcentrée des crédits DRAC  - Déplacement Bordeaux	2018-09-13 07:50:00	2018-09-13 19:15:00	\N	\N	1	0	\N	\N
305436	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Conférence interparlementaire article 13 du TSCG à Vienne	Conférence interparlementaire article 13 du TSCG à Vienne	2018-09-17 10:00:00	2018-09-18 17:10:00	\N	\N	5	0	\N	\N
305980	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Examen du rapport	\N	2018-09-27 10:00:00	2018-09-27 13:00:00	\N	\N	0	0	\N	\N
306962	GIA	AUCUNE	\N	\N	\N	Entretien avec Mme Daniela Réa, journaliste mexicaine, lauréate du Prix Breach-Valdez	Entretien avec Mme Daniela Réa, journaliste mexicaine, lauréate du Prix Breach-Valdez	2018-09-26 08:30:00	2018-09-26 10:15:00	\N	\N	7	0	643	\N
307104	GIA	AUCUNE	\N	\N	\N	GIA-France-Japon rencontre avec une délégation de députés japonais	GIA-France-Japon : rencontre avec une délégation de députés japonais	2018-08-31 14:30:00	2018-08-31 15:15:00	\N	\N	1	0	596	\N
307106	DELEGATION	AUDRAP	\N	\N	206	Audition de l'ADEME (Arrêt des véhicules thermiques)	Audition de l'ADEME (Arrêt des véhicules thermiques)	2018-09-25 09:00:00	2018-09-25 10:00:00	\N	\N	2	0	\N	\N
307109	DELEGATION	AUDRAP	\N	\N	206	Audition Air Liquide (Arrêt des véhicules thermiques)	Audition Air Liquide (Arrêt des véhicules thermiques)	2018-09-25 10:00:00	2018-09-25 11:00:00	\N	\N	2	0	\N	\N
307112	DELEGATION	AUDRAP	\N	\N	206	Audition CEA et IFP-EN (Arrêt des véhicules thermiques)	Audition CEA et IFP-EN (Arrêt des véhicules thermiques)	2018-09-25 11:00:00	2018-09-25 12:30:00	\N	\N	2	0	\N	\N
307116	DELEGATION	AUDRAP	\N	\N	206	Audition du ministère de la transition écologique et solidaire	Audition du ministère de la transition écologique et solidaire	2018-09-27 10:30:00	2018-09-27 11:30:00	\N	\N	2	0	\N	\N
307119	DELEGATION	AUDRAP	\N	\N	206	Audition IFP Énergies nouvelles (Arrêt des véhicules thermiques)	Audition IFP Énergies nouvelles (Arrêt des véhicules thermiques)	2018-10-02 09:00:00	2018-10-02 10:00:00	\N	\N	0	0	\N	\N
307120	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Patrick CRIQUI, directeur de recherche CNRS (Arrêt véhicules thermiques)	Audition de M. Patrick CRIQUI, directeur de recherche CNRS (Arrêt véhicules thermiques)	2018-10-02 10:00:00	2018-10-02 11:00:00	\N	\N	0	0	\N	\N
282393	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2018-06-12 15:30:00	2018-06-12 16:30:00	\N	\N	1	0	\N	\N
293446	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2018-07-04 09:30:00	2018-07-04 13:15:00	2018-07-04 16:43:16	2018-07-04 16:58:21	39	1	\N	\N
307122	DELEGATION	AUDRAP	\N	\N	206	Audition AFHYPAC (Arrêt des véhicules thermiques)	Audition AFHYPAC (Arrêt des véhicules thermiques)	2018-10-09 10:00:00	2018-10-09 11:00:00	\N	\N	2	0	\N	\N
307133	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2018-10-03 10:05:00	2018-10-03 12:05:00	2018-10-03 14:25:29	2018-10-03 15:16:38	44	0	\N	\N
309777	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Plf 2019 - Crédits de l'audiovisuel public	Plf 2019 - Crédits de l'audiovisuel public	2018-10-09 14:30:00	2018-10-09 16:00:00	\N	\N	4	0	\N	\N
309778	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Plf 2019 - Crédits de l'audiovisuel public	Plf 2019 - Crédits de l'audiovisuel public	2018-10-09 16:00:00	2018-10-09 17:10:00	\N	\N	4	0	\N	\N
335284	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition plénière - Santé	\N	2018-12-12 09:35:00	2018-12-12 11:45:00	2018-12-12 11:50:21	2018-12-12 12:11:53	35	0	\N	\N
335286	COM_PERMANENTE	AUTRE	\N	SOCI	\N	rapport Padhue	\N	2018-12-13 13:35:00	2018-12-13 14:15:00	2018-12-13 14:17:52	2018-12-13 15:51:13	26	0	\N	\N
335293	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de M. P. MOSCOVICI sur les affaires éco et monétaires, la fiscalité et douanes	Audition de M. Pierre MOSCOVICI sur les affaires éco et monétaires, la fiscalité et les douanes	2018-12-13 08:35:00	2018-12-13 09:50:00	2018-12-13 10:31:04	2018-12-13 15:51:08	34	0	\N	\N
335391	COM_EURO	AUDRAP	\N	AFEU	\N	Audition MESRI	Audition du ministère de k'enseignement supérieur, de la recherche et de l'innovation	2018-11-07 12:00:00	2018-11-07 13:00:00	\N	\N	1	0	\N	\N
335393	COM_EURO	AUDRAP	\N	AFEU	\N	Audition de Bruno Sportisse, INRIA	Audition Horizon Europe :  Bruno Sportisse, INRIA	2018-11-07 19:00:00	2018-11-07 20:15:00	\N	\N	1	0	\N	\N
335394	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Universcience/ACSTI	Audition Horizon Europe : Universcience/ACSTI	2018-11-13 15:35:00	2018-11-13 16:20:00	\N	\N	1	0	\N	\N
335398	COM_EURO	AUDRAP	\N	AFEU	\N	Audition de Carle Bonafous-Murat, CPU	Audition Horizon Europe : Carle Bonafous-Murat, CPU	2018-11-14 11:30:00	2018-11-14 12:45:00	\N	\N	2	0	\N	\N
335401	COM_EURO	AUDRAP	\N	AFEU	\N	Audition d'Antoine Petit, CNRS	Audition Horizon Europe : Antoine Petit, CNRS	2018-11-14 15:20:00	2018-11-14 16:10:00	\N	\N	2	0	\N	\N
335405	COM_EURO	AUDRAP	\N	AFEU	\N	Audition de Matthieu Landon, DGE	Audition Horizon Europe : Matthieu Landon, DGE	2018-11-15 11:10:00	2018-11-15 12:05:00	\N	\N	2	0	\N	\N
335408	COM_EURO	AUDRAP	\N	AFEU	\N	Audition de Giulia Del Brenna, Commission européenne	Audition Horizon Europe : Giulia Del Brenna, Commission européenne	2018-11-15 15:10:00	2018-11-15 16:05:00	\N	\N	2	0	\N	\N
335411	COM_EURO	AUDRAP	\N	AFEU	\N	Audition de Jean-Pierre Bourguignon, CER	Audition Horizon Europe :  Jean-Pierre Bourguignon, CER	2018-11-15 16:05:00	2018-11-15 17:05:00	\N	\N	2	0	\N	\N
335414	COM_EURO	AUDRAP	\N	AFEU	\N	Audition de Nicolas Demassieux, Orange	Audition intelligence artificielle : Nicolas Demassieux, Orange	2018-11-27 14:05:00	2018-11-27 15:05:00	\N	\N	2	0	\N	\N
335417	COM_EURO	AUDRAP	\N	AFEU	\N	Audition de Raja Chatila, CNRS	Audition intelligence artificielle : Raja Chatila, CNRS	2018-11-27 18:05:00	2018-11-27 19:45:00	\N	\N	2	0	\N	\N
335421	COM_EURO	AUDRAP	\N	AFEU	\N	Audition de Bruno Sportisse, INRIA	\N	2018-11-28 08:30:00	2018-11-28 09:35:00	\N	\N	3	0	\N	\N
335425	COM_EURO	AUDRAP	\N	AFEU	\N	Audition de Françoise Soulié	Audition intelligence artificielle : Françoise Soulié	2018-11-28 14:35:00	2018-11-28 15:40:00	\N	\N	2	0	\N	\N
335428	COM_EURO	AUDRAP	\N	AFEU	\N	Audition de Thierry Tingaud, STMicroelectronics France	Audition intelligence artificielle : Thierry Tingaud, STMicroelectronics France	2018-11-28 15:45:00	2018-11-28 16:50:00	\N	\N	1	0	\N	\N
335430	COM_EURO	AUDRAP	\N	AFEU	\N	Audition de Nozha Boujemaa, INRIA	Audition intelligence artificielle : Nozha Boujemaa, INRIA	2018-11-28 17:15:00	2018-11-28 18:10:00	\N	\N	1	0	\N	\N
335432	COM_EURO	AUDRAP	\N	AFEU	\N	Audition d'Isabelle Falque-Pierrotin, CNIL	Audition intelligence artificielle : Isabelle Falque-Pierrotin, CNIL	2018-11-28 18:15:00	2018-11-28 19:15:00	\N	\N	3	0	\N	\N
335437	COM_EURO	AUDRAP	\N	AFEU	\N	Audition de Jean-Gabriel Ganascia, CNRS	Audition intelligence artificielle : Jean-Gabriel Ganascia, CNRS	2018-11-29 14:05:00	2018-11-29 15:05:00	\N	\N	2	0	\N	\N
335440	COM_EURO	AUDRAP	\N	AFEU	\N	Audition de Khalil Rouhana, Commission européenne	Audition intelligence artificielle : Khalil Rouhana, Commission européenne	2018-11-29 15:05:00	2018-11-29 16:05:00	\N	\N	2	0	\N	\N
335443	GIA	AUCUNE	\N	\N	\N	Rencontre avec Katrin Jacobsdottir, Première ministre d'Islande	Rencontre avec Katrin Jacobsdottir, Première ministre d'Islande	2018-11-21 12:30:00	2018-11-21 14:10:00	\N	\N	4	0	625	\N
335448	COM_EURO	AUTRE_NON_PLENIERE	\N	AFEU	\N	Entretien avec Katrin Jacobsdottir	Entretien avec Katrin Jacobsdottir, Première ministre d'Islande	2018-11-21 11:00:00	2018-11-21 12:00:00	\N	\N	0	0	\N	\N
281773	COM_PERMANENTE	AUTRE	\N	FINC	\N	Communication de M. Vincent CAPO CANELLAS, Contrôle modernisation navigation aérienne	Communication de M. Vincent CAPO CANELLAS, Contrôle budgétaire modernisation des services de la navigation aérienne 	2018-06-13 10:25:00	2018-06-13 11:40:00	2018-06-13 23:41:02	2018-06-14 09:51:28	31	1	\N	\N
282294	COM_EURO	AUDRAP	\N	AFEU	\N	Les relations entre l'Union européenne et la Turquie	Rencontre avec des représentants de l'Institut kurde de Paris	2018-06-07 14:00:00	2018-06-07 15:00:00	\N	\N	3	0	\N	\N
282328	DELEGATION	AUCUNE	\N	\N	211	Examen du rapport d'information sur les violences faites aux femmes	Examen du rapport d'information sur les violences faites aux femmes	2018-06-12 13:00:00	2018-06-12 14:15:00	2018-06-12 15:05:02	2018-06-12 15:31:40	14	0	\N	\N
282329	DELEGATION	AUCUNE	\N	\N	211	Audition de Mme Bousquet - PJL lutte contre les violences sexuelles et sexistes	Audition de Mme Bousquet - PJL lutte contre les violences sexuelles et sexistes	2018-06-12 18:00:00	2018-06-12 19:00:00	2018-06-12 19:22:02	2018-06-13 14:25:34	11	0	\N	\N
282330	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur	\N	2018-06-07 10:00:00	2018-06-07 10:30:00	\N	\N	1	0	\N	\N
282331	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur	\N	2018-06-07 10:30:00	2018-06-07 11:00:00	\N	\N	1	0	\N	\N
282332	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur	\N	2018-06-07 11:00:00	2018-06-07 11:45:00	\N	\N	1	0	\N	\N
282333	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur	\N	2018-06-07 11:45:00	2018-06-07 12:15:00	\N	\N	1	0	\N	\N
282340	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	FINC	\N	PLF pour 2019 - Mission Sports, jeunesse et vie associative - Direction du budget	PLF pour 2019 - Mission Sports, jeunesse et vie associative - Direction du budget	2018-06-06 15:00:00	2018-06-06 16:00:00	\N	\N	1	0	\N	\N
282356	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL ELAN	\N	2018-06-07 10:05:00	2018-06-07 12:15:00	\N	\N	1	0	\N	\N
282358	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL ELAN	\N	2018-06-06 16:00:00	2018-06-06 17:00:00	\N	\N	1	0	\N	\N
282388	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2018-06-06 15:00:00	2018-06-06 16:00:00	\N	\N	1	0	\N	\N
335290	COM_PERMANENTE	AUTRE	\N	FINC	\N	PJL n° 84 Convention Luxembourg - Examen Rapport et élaboration texte	PJL n° 84 Convention Luxembourg - Examen Rapport et élaboration texte	2018-12-12 10:00:00	2018-12-12 10:45:00	2018-12-12 18:41:53	2018-12-13 15:51:05	37	0	\N	\N
282568	GIA	AUCUNE	\N	\N	\N	Audition Fraternité en Irak et fonds ALIPH	Audition de Faraj-Benoît CAMURAT, président de Fraternité en Irak et Bariza KHIARI, Co-présidente du Fonds ALIPH	2018-06-07 08:30:00	2018-06-07 10:00:00	\N	\N	15	0	CHRETORIENT	CHRETORIENT
283807	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Equilibre territorial	PPL Equilibre territorial	2018-06-12 21:55:00	2018-06-13 00:45:00	\N	\N	66	0	\N	\N
283821	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Mission Mécénat	Mission Mécénat	2018-06-12 16:00:00	2018-06-12 16:45:00	\N	\N	3	0	\N	\N
284599	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL pour la liberté de choisir son avenir professionnel	PJL pour la liberté de choisir son avenir professionnel	2018-06-12 11:00:00	2018-06-12 12:15:00	\N	\N	4	0	\N	\N
284611	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition plénière	\N	2018-06-20 09:00:00	2018-06-20 11:35:00	2018-06-20 12:00:05	2018-06-20 16:07:15	36	0	\N	\N
284612	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition plénière	\N	2018-06-20 16:30:00	2018-06-20 18:40:00	2018-06-21 10:02:15	2018-06-21 13:57:39	30	0	\N	\N
284624	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL pour la liberté de choisir son avenir professionnel	PJL pour la liberté de choisir son avenir professionnel	2018-06-12 14:00:00	2018-06-12 15:55:00	\N	\N	5	0	\N	\N
284627	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL pour la liberté de choisir son avenir professionnel	PJL pour la liberté de choisir son avenir professionnel	2018-06-12 18:00:00	2018-06-12 19:00:00	\N	\N	4	0	\N	\N
284758	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL pour la liberté de choisir son avenir professionnel	PJL pour la liberté de choisir son avenir professionnel	2018-06-13 14:00:00	2018-06-13 18:30:00	\N	\N	4	0	\N	\N
284793	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL pour la liberté de choisir son avenir professionnel	PJL pour la liberté de choisir son avenir professionnel	2018-06-14 09:00:00	2018-06-14 12:00:00	\N	\N	5	0	\N	\N
284823	MISSION	AUCUNE	\N	MINEURSENF	\N	\N	\N	2018-06-13 14:45:00	2018-06-13 18:55:00	2018-06-13 19:03:14	2018-06-14 09:52:12	9	0	\N	\N
284973	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Audition avenir pro	\N	2018-06-12 08:30:00	2018-06-12 09:15:00	\N	\N	1	0	\N	\N
284976	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Métier d'enseignant	\N	2018-06-12 14:30:00	2018-06-12 15:30:00	\N	\N	1	0	\N	\N
284978	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	AFCL	\N	\N	\N	2018-06-15 16:30:00	2018-06-15 17:00:00	\N	\N	0	0	\N	\N
284980	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Avenir pro	\N	2018-06-15 15:00:00	2018-06-15 17:45:00	\N	\N	1	0	\N	\N
284986	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Coût fonctionnement audiovisuel - Audition Canal +	Contrôle 2018 - Coût fonctionnement audiovisuel - Audition Canal +	2018-06-11 17:30:00	2018-06-11 18:30:00	\N	\N	1	0	\N	\N
284988	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Avenir pro	\N	2018-06-18 15:00:00	2018-06-18 17:00:00	\N	\N	1	0	\N	\N
284991	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Audition avenir pro	\N	2018-06-11 10:00:00	2018-06-11 11:45:00	\N	\N	1	0	\N	\N
284994	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Les maisons de l'emploi - DGEFP	Contrôle 2018 - Les maisons de l'emploi - DGEFP	2018-06-13 15:30:00	2018-06-13 16:15:00	\N	\N	1	0	\N	\N
285171	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL ELAN	\N	2018-05-22 16:00:00	2018-05-22 17:45:00	\N	\N	1	0	\N	\N
285174	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL ELAN	\N	2018-05-23 14:30:00	2018-05-23 15:15:00	\N	\N	1	0	\N	\N
285177	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL ELAN	\N	2018-05-23 16:00:00	2018-05-23 17:00:00	\N	\N	1	0	\N	\N
285179	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL ELAN	\N	2018-05-29 09:30:00	2018-05-29 10:00:00	\N	\N	1	0	\N	\N
285182	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL ELAN	\N	2018-06-05 09:30:00	2018-06-05 10:15:00	\N	\N	1	0	\N	\N
285480	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL pour la liberté de choisir son avenir professionnel	PJL pour la liberté de choisir son avenir professionnel	2018-05-15 18:00:00	2018-05-15 19:30:00	\N	\N	3	0	\N	\N
285490	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL pour la liberté de choisir son avenir professionnel	PJL pour la liberté de choisir son avenir professionnel	2018-05-17 14:30:00	2018-05-17 17:00:00	\N	\N	3	0	\N	\N
285906	GIA	AUCUNE	\N	\N	\N	Entretien avec une délégation moldave	Entretien avec des membres de la Commission des droits humains et des relations inter-ethniques du Parlement moldave	2018-06-12 17:45:00	2018-06-12 19:15:00	\N	\N	1	0	851	\N
285983	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL Accords aériens	\N	2018-06-12 15:00:00	2018-06-12 15:45:00	\N	\N	1	0	\N	\N
286240	COM_ENQUETE	PLENIERE	\N	HAUTE	\N	Audition	Audition	2018-06-15 10:35:00	2018-06-15 11:45:00	2018-06-15 12:33:12	2018-06-21 17:05:38	4	0	\N	\N
286278	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Lutte contre les violences sexuelles et sexistes	\N	2018-06-13 14:30:00	2018-06-13 19:50:00	\N	\N	1	0	\N	\N
286328	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion commission des lois 	Réunion commission des lois 	2018-06-19 09:10:00	2018-06-19 10:15:00	2018-06-19 14:52:21	2018-06-19 17:53:28	18	1	\N	\N
286510	MISSION	DEPLACEMENT	\N	MINEURSENF	\N	\N	\N	2018-06-18 08:00:00	2018-06-18 21:00:00	\N	\N	4	0	\N	\N
286589	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion	Réunion	2018-06-19 16:05:00	2018-06-19 17:00:00	2018-06-19 17:12:36	2018-06-19 17:53:29	30	0	\N	\N
286592	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion	Réunion	2018-06-20 10:30:00	2018-06-20 12:40:00	2018-06-20 15:09:06	2018-06-20 16:07:05	38	0	\N	\N
286723	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2018-06-19 14:45:00	2018-06-19 17:35:00	\N	\N	3	0	\N	\N
286727	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL ELAN	\N	2018-06-19 16:30:00	2018-06-19 17:40:00	\N	\N	1	0	\N	\N
287666	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur EFSA	\tAudition rapporteur - Commission des affaires européennes - Audition EFSA	2018-06-20 14:05:00	2018-06-20 15:00:00	\N	\N	2	0	\N	\N
213481	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF 2018 - Avis transports routiers et ferroviaires	\N	2017-10-25 15:00:00	2017-10-25 16:30:00	\N	\N	2	0	\N	\N
213484	COM_PERMANENTE	AUDRAP	\N	CDD	\N	\N	PLF 2018 - Avis Transports ferroviaires	2017-10-26 12:00:00	2017-10-26 13:00:00	\N	\N	1	0	\N	\N
213486	COM_PERMANENTE	AUDRAP	\N	CDD	\N	\N	PLF 2018 - Avis Biodiversité et Transition énergétique	2017-10-25 15:00:00	2017-10-25 16:00:00	\N	\N	1	0	\N	\N
213488	COM_PERMANENTE	AUDRAP	\N	CDD	\N	\N	PLF 2018 - Avis Biodiversité et Transition énergétique	2017-10-26 10:30:00	2017-10-26 11:30:00	\N	\N	1	0	\N	\N
215990	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2018 - Avis Justice judiciaire	\N	2017-11-08 16:00:00	2017-11-08 17:30:00	\N	\N	1	0	\N	\N
215992	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2018 - Avis Conseil et contrôle Etat	\N	2017-11-08 15:00:00	2017-11-08 17:00:00	\N	\N	1	0	\N	\N
286539	CMP	AUTRE	\N	PACTE	\N	PJL Nouveau pacte ferroviaire	PJL Nouveau pacte ferroviaire	2018-06-11 14:30:00	2018-06-11 15:40:00	\N	\N	10	0	\N	\N
286590	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion	Réunion	2018-06-20 09:05:00	2018-06-20 10:30:00	2018-06-20 15:08:16	2018-06-20 16:07:11	47	0	\N	\N
225222	DELEGATION	AUCUNE	\N	\N	206	Echange de vues avec Rémy Quirion / Présentation rapport d'étape de Cédric Villani	Echanges de vues avec Rémy Quirion, scientifique en chef, Québec / Rapport de C. Villani sur l'intelligence artificielle	2017-12-07 09:00:00	2017-12-07 11:45:00	2017-12-07 15:44:35	2017-12-07 15:45:27	12	0	\N	\N
227783	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	Glyphosate	Glyphosate et usage d'autres pesticides	2017-12-07 09:25:00	2017-12-07 16:35:00	\N	\N	2	0	\N	\N
228101	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Adaptation dans le domaine de la sécurité au droit de l'UE	\N	2017-12-06 15:30:00	2017-12-06 19:00:00	\N	\N	1	0	\N	\N
233496	DELEGATION	AUDRAP	\N	\N	PROS	Auditions dans le cadre du rapport "Nouvelles mobilités"	 Audition de MM. Olivier Marembaud, Bruno Duchemin et  Philippe Méraud	2018-01-23 09:30:00	2018-01-23 10:50:00	\N	\N	4	0	\N	\N
233553	DELEGATION	AUDRAP	\N	\N	PROS	Auditions dans le cadre du rapport "Nouvelles mobilités"	Audition de MM. Stéphane Schultz et Nicolas Louvet	2018-01-25 11:00:00	2018-01-25 13:15:00	\N	\N	2	0	\N	\N
233555	DELEGATION	AUDRAP	\N	\N	PROS	Auditions dans le cadre du rapport "Nouvelles mobilités"	Audition de M. Thierry Péchard	2018-02-01 11:10:00	2018-02-01 12:30:00	\N	\N	3	0	\N	\N
238605	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2018-01-31 09:35:00	2018-01-31 12:55:00	2018-01-31 14:40:47	2018-01-31 17:14:40	39	0	\N	\N
244306	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Conflits d'intérêts et mobilité des hauts fonctionnaires	\N	2018-02-08 08:20:00	2018-02-08 09:15:00	\N	\N	1	0	\N	\N
244308	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Conflits d'intérêts et mobilité des hauts fonctionnaires	\N	2018-02-08 09:55:00	2018-02-08 12:20:00	\N	\N	1	0	\N	\N
244310	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Conflits d'intérêts et mobilité des hauts fonctionnaires	\N	2018-02-08 17:30:00	2018-02-08 18:30:00	\N	\N	1	0	\N	\N
249266	GIA	AUCUNE	\N	\N	\N	Audition de l'Ambassadeur de Turquie en France, M. Ismail Hakki Musa	Audition de l'Ambassadeur de Turquie en France, M. Ismail Hakki Musa	2018-02-21 08:30:00	2018-02-21 09:40:00	\N	\N	8	0	624	\N
249276	GIA	AUCUNE	\N	\N	\N	Entretien avc Mme Fabienne KELLER, Président délégué  pour le Congo (coop)	Entretien avc Mme Fabienne KELLER, Président délégué du GIA Afrique centrale pour le Congo (coop)	2018-02-21 14:00:00	2018-02-21 14:30:00	\N	\N	1	0	572	\N
249613	GIA	AUCUNE	\N	\N	\N	Petit déjeuner de travail	Petit déjeuner de travail en présence de l'ambassadeur du Brésil en France	2018-02-21 08:00:00	2018-02-21 09:00:00	\N	\N	4	0	576	\N
258284	COM_ENQUETE	PLENIERE	\N	FORCES	\N	Auditions CE FSI	Auditions CE FSI	2018-03-21 14:15:00	2018-03-21 17:45:00	2018-03-23 10:56:23	2018-03-23 11:04:21	8	0	\N	\N
258308	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2018-03-20 14:00:00	2018-03-20 15:20:00	\N	\N	3	0	\N	\N
258312	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2018-03-20 16:15:00	2018-03-20 17:30:00	\N	\N	3	0	\N	\N
261472	GIA	AUCUNE	\N	\N	\N	Petit-déjeuner en présence de l'ambassadrice du Canada	Petit-déjeuner en présence de l'ambassadrice du Canada au Sénat	2018-03-28 08:30:00	2018-03-28 09:45:00	\N	\N	11	0	583	\N
267494	SEANCE_PLENIERE	DECL_GVT	\N	\N	\N	Déclaration du Gouvernement - Intervention en Syrie	Déclaration du Gouvernement - Intervention en Syrie	2018-04-16 17:00:00	2018-04-16 19:00:00	\N	\N	129	0	\N	\N
268545	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2018-04-17 15:20:00	2018-04-17 18:30:00	\N	\N	3	0	\N	\N
268549	MISSION	AUCUNE	\N	MINEURSENF	\N	\N	\N	2018-04-18 14:45:00	2018-04-18 17:00:00	2018-04-18 17:13:31	2018-04-18 17:46:55	15	0	\N	\N
270980	DELEGATION	DEPLACEMENT	\N	\N	PROS	Visite de l'école "Cuisine Mode d'Emploi(s)"	Visite de de l¿école de la réinsertion "Cuisine Mode d¿Emploi(s)" fondée par le chef étoilé Thierry 	2018-05-24 10:00:00	2018-05-24 12:00:00	\N	\N	8	0	\N	\N
275059	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Immigration, droit d'asile et intégration	\N	2018-05-17 08:40:00	2018-05-17 11:15:00	\N	\N	5	0	\N	\N
275065	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Immigration, droit d'asile et intégration	\N	2018-05-17 15:30:00	2018-05-17 19:35:00	\N	\N	4	0	\N	\N
275151	GIA	AUCUNE	\N	\N	\N	Accueil d¿une délégation de la Chambre des Conseillers du Maroc 	Accueil d¿une délégation de la Chambre des Conseillers du Maroc 	2018-04-17 16:00:00	2018-04-21 12:00:00	\N	\N	3	0	598	\N
275969	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Immigration, droit d'asile et intégration	\N	2018-05-22 14:00:00	2018-05-22 15:10:00	\N	\N	4	0	\N	\N
275974	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	PJL Immigration, droit d'asile et intégration	\N	2018-05-22 15:10:00	2018-05-22 19:30:00	\N	\N	7	0	\N	\N
275989	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Immigration, droit d'asile et intégration	\N	2018-05-23 16:30:00	2018-05-23 20:00:00	\N	\N	5	0	\N	\N
275995	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Immigration, droit d'asile et intégration	\N	2018-05-24 11:00:00	2018-05-24 12:00:00	\N	\N	3	0	\N	\N
275999	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Immigration, droit d'asile et intégration	\N	2018-05-24 12:00:00	2018-05-24 13:00:00	\N	\N	2	0	\N	\N
276002	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Immigration, droit d'asile et intégration	\N	2018-05-24 13:45:00	2018-05-24 14:30:00	\N	\N	1	0	\N	\N
276006	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	PJL Immigration, droit d'asile et intégration	\N	2018-05-25 07:00:00	2018-05-25 21:00:00	\N	\N	2	0	\N	\N
276017	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	Partenariat oriental	Audition de Mme Hasmik Tolmajian, ambassadrice d'Arménie en France	2018-05-23 15:45:00	2018-05-23 19:00:00	\N	\N	2	0	\N	\N
281803	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Lutte contre les violences sexuelles et sexistes	\N	2018-06-06 16:30:00	2018-06-06 18:15:00	\N	\N	1	0	\N	\N
281824	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Lutte contre les violences sexuelles et sexistes	\N	2018-06-07 08:30:00	2018-06-07 10:15:00	\N	\N	1	0	\N	\N
282020	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 7juin - 9h00	Réunion du 7juin - 9h00	2018-06-07 09:00:00	2018-06-07 10:00:00	2018-06-08 18:12:53	2018-06-08 18:13:25	15	0	\N	\N
317557	DELEGATION	AUCUNE	\N	\N	DSOM	Audition de M. Philippe Gustin, préfet de la Guadeloupe	\N	2018-11-14 14:00:00	2018-11-14 15:30:00	2018-11-14 16:20:36	2018-11-14 16:24:57	10	0	\N	\N
317558	COM_SPECIALE	PLENIERE	\N	SURTRANSPO	\N	Réunion plénière commission spéciale	\N	2018-11-06 13:50:00	2018-11-06 14:45:00	2018-11-06 19:49:00	2018-11-07 10:33:29	19	0	\N	\N
317663	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de M. Bruno Le Maire (PLF 2019)	\N	2018-10-30 17:55:00	2018-10-30 20:00:00	2018-10-31 11:10:42	2018-10-31 12:27:39	37	0	\N	\N
317764	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Livre et Industries culturelles	PLF 2019 - Crédits Livre et Industries culturelles	2018-10-30 14:30:00	2018-10-30 15:30:00	\N	\N	4	0	\N	\N
318415	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Enseignement supérieur	PLF 2019 - Crédits Enseignement supérieur	2018-10-30 14:00:00	2018-10-30 16:00:00	\N	\N	2	0	\N	\N
318416	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - RCT - France Urbaine	PLF pour 2019 - RCT - France Urbaine	2018-10-30 15:45:00	2018-10-30 16:50:00	\N	\N	2	0	\N	\N
244364	GIA	AUCUNE	\N	\N	\N	Assemblée générale	\N	2018-02-06 18:00:00	2018-02-06 18:30:00	\N	\N	7	0	963	\N
318426	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Enseignement scolaire	PLF 2019 - Crédits Enseignement scolaire	2018-10-30 17:45:00	2018-10-30 18:45:00	\N	\N	2	0	\N	\N
318463	COM_SPECIALE	PLENIERE	\N	SURTRANSPO	\N	Législation en commission	\N	2018-10-30 21:00:00	2018-10-30 22:15:00	2018-10-31 15:51:18	2018-10-31 16:28:52	18	0	\N	\N
332431	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-11-27 14:30:00	2018-11-27 15:30:00	\N	\N	1	0	\N	\N
332433	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-11-27 15:30:00	2018-11-27 16:15:00	\N	\N	2	0	\N	\N
295010	MISSION	AUCUNE	\N	HERBE	\N	Audition plénière	\N	2018-07-05 11:05:00	2018-07-05 12:30:00	2018-07-05 16:20:32	2018-07-05 16:35:37	10	0	\N	\N
295028	MISSION	AUCUNE	\N	HERBE	\N	Audition plénière	\N	2018-07-05 14:05:00	2018-07-05 15:00:00	2018-07-05 16:21:11	2018-07-05 16:35:38	8	0	\N	\N
298633	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Renforcer la lutte contre les rodéos motorisés	\N	2018-07-11 18:30:00	2018-07-11 19:05:00	\N	\N	1	0	\N	\N
300445	MISSION	AUCUNE	\N	PENURIE	\N	\N	\N	2018-07-19 11:00:00	2018-07-19 12:30:00	2018-07-19 15:34:38	2018-07-19 15:58:48	10	0	\N	\N
300448	MISSION	AUCUNE	\N	PENURIE	\N	\N	\N	2018-07-19 14:00:00	2018-07-19 15:15:00	2018-07-19 15:36:51	2018-07-19 15:58:49	7	0	\N	\N
300451	MISSION	AUCUNE	\N	PENURIE	\N	\N	\N	2018-07-20 09:00:00	2018-07-20 12:40:00	2018-07-23 09:45:16	2018-07-24 17:11:18	5	0	\N	\N
300455	MISSION	AUCUNE	\N	PENURIE	\N	\N	\N	2018-07-20 14:00:00	2018-07-20 16:30:00	2018-07-23 09:46:08	2018-07-24 17:11:18	2	0	\N	\N
306076	DELEGATION	DEPLACEMENT	\N	\N	206	Visite du site de recherche Les Renardières d'EDF	Visite du site de recherche Les Renardières d'EDF	2018-10-04 09:30:00	2018-10-04 13:30:00	\N	\N	2	0	\N	\N
306078	MISSION	AUCUNE	\N	MINEURSENF	\N	\N	\N	2018-09-25 14:55:00	2018-09-25 16:30:00	2018-09-25 16:38:32	2018-09-25 18:03:35	18	0	\N	\N
306372	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2018-09-25 14:45:00	2018-09-25 16:45:00	\N	\N	3	0	\N	\N
306384	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PROG Programmation 2018-2022 et réforme pour la justice	\N	2018-09-25 09:00:00	2018-09-25 10:00:00	\N	\N	2	0	\N	\N
306387	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PROG Programmation 2018-2022 et réforme pour la justice	\N	2018-09-25 14:30:00	2018-09-25 16:40:00	\N	\N	2	0	\N	\N
308737	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Permis à points et baisse de la limitation de vitesse à 80 km/h	\N	2018-10-02 18:00:00	2018-10-02 19:35:00	\N	\N	1	0	\N	\N
309307	ETUDES	AUCUNE	\N	\N	\N	G.E. "Vigne et Vin"	G.E. "Vigne et Vin"	2018-10-03 08:30:00	2018-10-03 09:30:00	\N	\N	27	0	\N	909
309337	GIA	AUCUNE	\N	\N	\N	Entretien avec une délégation de la Silk Road Alliance	\N	2018-10-03 15:15:00	2018-10-03 15:15:00	\N	\N	11	0	584	\N
310258	GIA	AUCUNE	\N	\N	\N	Analyse des résultats des élections législatives du 1er octobre  au Québec	Présentation par M. Martial Foucault, directeur du CEVIPOF, d'une analyse du résultat des élections législatives	2018-10-10 08:00:00	2018-10-10 09:15:00	\N	\N	13	0	602	\N
311336	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2019 - Assurance maladie	\N	2018-10-09 14:00:00	2018-10-09 16:00:00	\N	\N	4	0	\N	\N
311342	COM_PERMANENTE	AUTRE	\N	ETRD	\N	PJLF pour 2019 Audition du CEMAT et du DGA	\N	2018-10-17 09:35:00	2018-10-17 12:05:00	2018-10-17 15:09:26	2018-10-17 15:34:19	41	0	\N	\N
311346	COM_PERMANENTE	AUTRE	\N	ETRD	\N	PJLF pour 2019 Audition ministre des Armées	\N	2018-10-17 18:05:00	2018-10-17 19:55:00	2018-10-18 10:21:08	2018-10-18 18:38:46	28	0	\N	\N
311635	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2019 - Assurance maladie	\N	2018-10-10 14:30:00	2018-10-10 16:30:00	\N	\N	3	0	\N	\N
311639	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2019 - Assurance maladie	\N	2018-10-11 10:00:00	2018-10-11 11:00:00	\N	\N	1	0	\N	\N
311666	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL Convention Protocole Nagoya-Kuala Lumpur	PJL Convention Protocole Nagoya-Kuala Lumpur	2018-10-09 09:00:00	2018-10-09 10:00:00	\N	\N	1	0	\N	\N
311724	DELEGATION	AUCUNE	\N	\N	DSOM	Nomination de rapporteurs - Programme de travail	Nomination de rapporteurs - Programme de travail	2018-10-25 09:45:00	2018-10-25 10:45:00	2018-10-25 16:27:54	2018-10-25 18:03:12	14	0	\N	\N
312295	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	plfss pour 2019 - médico-social. Auditions M. Bonne	\N	2018-10-16 13:30:00	2018-10-16 14:15:00	\N	\N	2	0	\N	\N
312555	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	plfss pour 2019 - médico-social. Auditions M. Bonne	\N	2018-10-16 15:15:00	2018-10-16 16:00:00	\N	\N	1	0	\N	\N
312559	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition de l'Agence du numérique	Audition de l'Agence du numérique	2018-10-15 18:00:00	2018-10-15 19:00:00	\N	\N	1	0	\N	\N
312560	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition EPARECA	Audition EPARECA	2018-10-16 09:30:00	2018-10-16 10:15:00	\N	\N	1	0	\N	\N
312561	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition de la Caisse des dépôts	Audition de la Caisse des dépôts	2018-10-16 11:30:00	2018-10-16 12:30:00	\N	\N	1	0	\N	\N
312562	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition du Commissariat général à l'égalité des territoires	Audition du Commissariat général à l'égalité des territoires	2018-10-16 16:00:00	2018-10-16 17:00:00	\N	\N	1	0	\N	\N
313440	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition plénière	\N	2018-10-25 10:30:00	2018-10-25 11:30:00	2018-10-25 11:31:29	2018-10-25 18:04:37	12	0	\N	\N
313943	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Auditions PJLF pour 2019	\N	2018-10-24 09:00:00	2018-10-24 13:00:00	2018-10-24 15:57:20	2018-10-24 16:05:59	39	0	\N	\N
314075	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2018-09-26 10:30:00	2018-09-26 10:40:00	\N	\N	3	0	\N	\N
314079	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2019 - Programme 185	\N	2018-10-16 09:00:00	2018-10-16 10:00:00	\N	\N	1	0	\N	\N
314081	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2019 - Programme 105	\N	2018-10-16 15:45:00	2018-10-16 16:30:00	\N	\N	1	0	\N	\N
314083	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2019 - Programme 105	\N	2018-10-18 15:30:00	2018-10-18 16:45:00	\N	\N	2	0	\N	\N
314188	COM_SPECIALE	PLENIERE	\N	RETRAIT	\N	Audiition M. Darmanin	\N	2018-10-23 09:35:00	2018-10-23 10:50:00	2018-10-24 10:08:41	2018-10-24 12:13:43	16	0	\N	\N
314189	COM_SPECIALE	PLENIERE	\N	RETRAIT	\N	Audition Mme Loiseau	\N	2018-10-23 16:20:00	2018-10-23 17:40:00	2018-10-24 10:09:25	2018-10-24 12:13:44	20	0	\N	\N
314192	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	211	Colloque "Les femmes pendant la Grande Guerre"	Colloque "Les femmes pendant la Grande Guerre"	2018-10-18 09:30:00	2018-10-18 18:30:00	\N	\N	15	0	\N	\N
314208	GIA	AUCUNE	\N	\N	\N	Entretien de M. LONGUET avec six journalistes russes (coopé)	Entretien de M. LONGUET avec six journalistes russes (coopé)	2018-10-18 15:45:00	2018-10-18 16:45:00	\N	\N	0	0	608	\N
244372	GIA	AUCUNE	\N	\N	\N	AG du groupe	\N	2018-02-06 18:00:00	2018-02-06 19:00:00	\N	\N	25	0	629	\N
311341	COM_PERMANENTE	AUTRE	\N	ETRD	\N	conventions internationales	\N	2018-10-17 09:15:00	2018-10-17 09:35:00	2018-10-17 15:08:20	2018-10-17 15:34:21	39	0	\N	\N
316769	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Écologie/Transports - Société du Grand Paris	PLF pour 2019 - Écologie/Transports - Société du Grand Paris	2018-10-23 11:00:00	2018-10-23 12:00:00	\N	\N	1	0	\N	\N
316868	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2018-10-24 15:25:00	2018-10-24 18:10:00	\N	\N	3	0	\N	\N
316891	COM_SPECIALE	PLENIERE	\N	RETRAIT	\N	Examen du rapport et du texte	\N	2018-10-30 14:05:00	2018-10-30 16:15:00	2018-11-02 14:40:51	2018-11-02 14:41:33	28	0	\N	\N
317417	COM_SPECIALE	PLENIERE	\N	RETRAIT	\N	Audition CS Brexit	\N	2018-10-25 16:15:00	2018-10-25 17:15:00	\N	\N	8	0	\N	\N
318677	ETUDES	AUCUNE	\N	\N	\N	\N	Audition du groupe d'études	2018-10-31 08:00:00	2018-10-31 09:30:00	\N	\N	24	0	\N	907
318750	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2019 - Avis Immigration, asile et intégration	\N	2018-10-30 14:30:00	2018-10-30 16:15:00	\N	\N	2	0	\N	\N
318793	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLF pour 2019 - Mission Administration pénitentiaire	\N	2018-10-30 18:30:00	2018-10-30 20:00:00	\N	\N	1	0	\N	\N
318795	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLF pour 2019 - Mission Sécurités	\N	2018-10-30 14:30:00	2018-10-30 20:15:00	\N	\N	1	0	\N	\N
319259	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	PLF 2019	2018-11-06 08:30:00	2018-11-06 09:30:00	\N	\N	1	0	\N	\N
319263	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	PLF 2019	2018-11-07 09:00:00	2018-11-07 10:00:00	\N	\N	1	0	\N	\N
319265	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	PLF 2019 - Avis budgétaire "Ville"	2018-11-06 11:00:00	2018-11-06 12:30:00	\N	\N	1	0	\N	\N
319267	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	PLF 2019 - Avis budgétaire Ville	2018-11-07 14:00:00	2018-11-07 16:30:00	\N	\N	1	0	\N	\N
319269	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	PLF 2019 - Avis budgétaire "Ville"	2018-11-08 09:00:00	2018-11-08 12:50:00	\N	\N	1	0	\N	\N
319271	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	PLF 2019 - Avis budgétaire "Economie"	2018-11-07 08:45:00	2018-11-07 09:30:00	\N	\N	1	0	\N	\N
319273	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	PLF 2019  - Avis budgétaire "Economie"	2018-11-07 14:15:00	2018-11-07 16:15:00	\N	\N	1	0	\N	\N
319287	COM_PERMANENTE	AUDRAP	\N	CDD	\N	\N	PLF 2019 - Avis budgétaire "Maritime"	2018-11-06 15:00:00	2018-11-06 17:00:00	\N	\N	1	0	\N	\N
214551	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2018	\N	2017-10-31 14:00:00	2017-10-31 15:30:00	\N	\N	1	0	\N	\N
214553	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Médias	PLF pour 2018 - Médias - France Médias Monde + Min. culture + AFP	2017-10-30 15:45:00	2017-10-30 18:30:00	\N	\N	1	0	\N	\N
214555	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Médias	PLF pour 2018 - Médias - Radio France	2017-11-02 17:30:00	2017-11-02 18:30:00	\N	\N	1	0	\N	\N
214572	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour  2018 - Action extérieure de l'Etat	PLF pour 2018 - Action extérieure de l'Etat - Direction FAE et Institut Français	2017-11-02 10:00:00	2017-11-02 12:00:00	\N	\N	1	0	\N	\N
214577	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour  2018 - Action extérieure de l'Etat	PLF pour  2018 - Action extérieure de l'Etat - AEFE	2017-11-02 14:30:00	2017-11-02 15:30:00	\N	\N	1	0	\N	\N
214579	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour  2018 - Action extérieure de l'Etat	PLF pour  2018 - Action extérieure de l'Etat - Direction de la mondialisation, de la culture et  de l'enseignement 	2017-11-02 17:30:00	2017-11-02 18:30:00	\N	\N	1	0	\N	\N
214581	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour  2018 - Justice 	PLF pour  2018 - Justice  - Direction des services judiciaires	2017-10-31 14:00:00	2017-10-31 15:00:00	\N	\N	1	0	\N	\N
217406	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Cohésion des territoires	PLF pour 2018 - Cohésion des territoires - Auditions OPH et Direction du Budget	2017-11-07 09:00:00	2017-11-07 11:00:00	\N	\N	1	0	\N	\N
217408	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Recherche et Enseignement supérieur	PLF pour 2018 - Recherche et Enseignement supérieur - CPU	2017-11-09 09:30:00	2017-11-09 10:30:00	\N	\N	1	0	\N	\N
217412	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Participations fiancières de l'Etat	PLF pour 2018 - Participations fiancières de l'Etat - APE	2017-11-08 15:30:00	2017-11-08 17:00:00	\N	\N	1	0	\N	\N
217416	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Participations fiancières de l'Etat	PLF pour 2018 - Participations fiancières de l'Etat - Bpifrance et Caisse des dépôts	2017-11-10 14:30:00	2017-11-10 17:30:00	\N	\N	1	0	\N	\N
217429	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2018 - Anciens combattants - Ministère des Armées	PLF pour 2018 - Anciens combattants - Secrétaire d'État aux Armées	2017-11-06 17:30:00	2017-11-06 18:15:00	\N	\N	1	0	\N	\N
217439	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Écologie, développement et mobilité durables/Énergie	PLF pour 2018 - Écologie, développement et mobilité durables/Énergie - ADEME	2017-11-07 09:30:00	2017-11-07 10:30:00	\N	\N	1	0	\N	\N
217444	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Écologie, développement et mobilité durables/Énergie	PLF pour 2018 - Écologie, développement et mobilité durables/Énergie - DGEC et DGPR	2017-11-09 08:00:00	2017-11-09 10:00:00	\N	\N	1	0	\N	\N
235473	DELEGATION	AUCUNE	\N	\N	211	Audition de M. Jacques Toubon, Défenseur des Droits	Audition de M. Jacques Toubon, Défenseur des Droits	2018-01-25 08:30:00	2018-01-25 10:00:00	2018-01-25 10:44:14	2018-01-25 15:59:07	8	0	\N	\N
238873	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL "Réforme du Logement"	PJL "Réforme du Logement"	2018-01-23 14:40:00	2018-01-23 16:45:00	\N	\N	2	0	\N	\N
238876	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL "Réforme du Logement"	PJL "Réforme du Logement"	2018-01-24 15:15:00	2018-01-24 18:55:00	\N	\N	1	0	\N	\N
239666	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Don de jours de repos non pris	PPL Don de jours de repos non pris	2018-01-31 14:30:00	2018-01-31 15:50:00	\N	\N	92	0	\N	\N
239667	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat "Véhicules autonomes : enjeux économiques et cadres légaux"	Débat "Véhicules autonomes : enjeux économiques et cadres légaux"	2018-01-31 15:50:00	2018-01-31 17:35:00	\N	\N	83	0	\N	\N
239668	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Sites naturels ouverts au public	PPL Sites naturels ouverts au public	2018-01-31 21:30:00	2018-01-31 23:05:00	\N	\N	48	0	\N	\N
239669	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Droit des contrats	PJL Droit des contrats	2018-02-01 10:30:00	2018-02-01 11:40:00	\N	\N	64	0	\N	\N
239671	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Indemnisation des victimes des produits phytopharmaceutiques	PPL Indemnisation des victimes des produits phytopharmaceutiques	2018-02-01 16:15:00	2018-02-01 19:05:00	\N	\N	66	0	\N	\N
239672	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Caisse des Français de l'étranger	PPL Caisse des Français de l'étranger	2018-02-01 19:05:00	2018-02-01 20:10:00	\N	\N	22	0	\N	\N
239694	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL JO 2024	PJL JO 2024	2018-02-06 14:30:00	2018-02-06 16:15:00	\N	\N	142	0	\N	\N
239695	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2018-02-06 16:45:00	2018-02-06 17:40:00	\N	\N	306	0	\N	\N
239697	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL JO 2024	PJL JO 2024	2018-02-06 17:50:00	2018-02-06 20:35:00	\N	\N	114	0	\N	\N
245897	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe	Assemblée générale du groupe	2018-01-30 14:00:00	2018-01-30 14:30:00	\N	\N	5	0	591	\N
246193	ETUDES	AUCUNE	\N	\N	\N	Réunion constitutive	Réunion constitutive	2018-02-15 14:15:00	2018-02-15 14:45:00	\N	\N	12	0	\N	938
250262	MECSS	AUDRAP	\N	\N	MECSS	\N	\N	2018-03-07 10:30:00	2018-03-07 11:30:00	\N	\N	1	0	\N	\N
253606	MISSION	PLEIN_NON_JO	\N	BREXIT2	\N	\N	\N	2018-03-08 16:35:00	2018-03-08 17:45:00	\N	\N	10	0	\N	\N
255439	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	Groupe de travail sur la sécurité routière	\N	2018-03-06 13:00:00	2018-03-06 17:30:00	\N	\N	9	0	\N	\N
255468	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	Groupe de travail sur la sécurité routière	\N	2018-03-07 13:15:00	2018-03-07 19:45:00	\N	\N	5	0	\N	\N
258875	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	GT statut de l'élu : table ronde formation permanente et préparation de la reconversion	\N	2018-03-29 09:30:00	2018-03-29 11:10:00	\N	\N	9	0	\N	\N
273515	DELEGATION	AUDRAP	\N	\N	206	Audition de l'EFSA	Audition de l'EFSA dans le cadre de la mission Risques sanitaires et environnementaux	2018-06-01 10:00:00	2018-06-01 11:00:00	\N	\N	1	0	\N	\N
285116	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Lutte contre la fraude - Direction des douanes et droits indirects	PJL Lutte contre la fraude - Direction des douanes et droits indirects	2018-06-12 08:30:00	2018-06-12 10:00:00	\N	\N	2	0	\N	\N
317411	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2019 - GFPRH - Déplacement DGFiP Bercy	PLF pour 2019 - GFPRH - Déplacement DGFiP Bercy	2018-10-23 08:00:00	2018-10-23 10:30:00	\N	\N	2	0	\N	\N
317414	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - GFPRH - DGDDI	PLF pour 2019 - GFPRH - DGDDI	2018-10-24 10:30:00	2018-10-24 12:30:00	\N	\N	2	0	\N	\N
317426	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2019 - GFPRH - Déplacement SG MEF Bercy	PLF pour 2019 - GFPRH - Déplacement SG MEF Bercy	2018-10-24 14:00:00	2018-10-24 16:30:00	\N	\N	2	0	\N	\N
317430	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Rapport général - APCMA	PLF pour 2019 - Rapport général - APCMA	2018-10-24 16:30:00	2018-10-24 17:30:00	\N	\N	1	0	\N	\N
317432	DELEGATION	AUCUNE	\N	\N	211	Audition de Mme Roxana Maracineanu, ministre des Sports	Audition de Mme Roxana Maracineanu, ministre des Sports	2018-12-13 08:30:00	2018-12-13 10:10:00	2018-12-13 12:36:12	2018-12-14 11:25:48	15	0	\N	\N
317433	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Rapport général - Groupe La Poste	PLF pour 2019 - Rapport général - Groupe La Poste	2018-10-24 17:30:00	2018-10-24 18:30:00	\N	\N	1	0	\N	\N
317435	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Lutte contre la fraude et l'évasion fiscales - DGFiP / DLF et AMF / ACPR	Contrôle 2018 - Lutte contre la fraude et l'évasion fiscales - DGFiP / DLF et AMF / ACPR	2018-10-25 10:00:00	2018-10-25 11:55:00	\N	\N	5	0	\N	\N
317441	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Rapport général - AFEP	PLF pour 2019 - Rapport général - AFEP	2018-10-25 14:00:00	2018-10-25 15:00:00	\N	\N	1	0	\N	\N
317451	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Économie - Business France	PLF pour 2019 - Économie - Business France	2018-10-25 16:00:00	2018-10-25 17:30:00	\N	\N	2	0	\N	\N
287935	MISSION	AUCUNE	\N	MINEURSENF	\N	\N	\N	2018-06-20 14:00:00	2018-06-20 18:05:00	2018-06-21 09:52:05	2018-06-21 13:58:21	5	0	\N	\N
289353	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	DSOM	Colloque "Ancrage local des collectivités ultramarines"	Colloque "Ancrage local des collectivités ultramarines"	2018-06-21 14:30:00	2018-06-21 19:40:00	\N	\N	7	0	\N	\N
289492	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2018 - Disponibilité des hélicoptères - Toulon	Contrôle 2018 - Disponibilité des hélicoptères - Toulon	2018-06-25 08:20:00	2018-06-25 17:50:00	\N	\N	1	0	\N	\N
289510	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Fraude - Entretien MIC procédures poursuite infractions fiscales de l'AN et avocats	PJL Fraude - Entretien MIC procédures de poursuite des infractions fiscales de l'AN et cabinets d'avocats	2018-06-19 14:00:00	2018-06-19 16:30:00	\N	\N	2	0	\N	\N
289513	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Fraude - Syndicats fonctionnaires DGFiP	PJL Fraude - Syndicats fonctionnaires DGFiP	2018-06-20 18:30:00	2018-06-20 19:30:00	\N	\N	1	0	\N	\N
289521	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PJL Fraude - Déplacement DGFiP - Paris/Pantin	PJL Fraude - Déplacement DGFiP - Paris/Pantin	2018-06-21 08:30:00	2018-06-21 13:15:00	\N	\N	1	0	\N	\N
289532	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Programme de contrôle - 2018 - Rapporteur général du rapport public et des programmes	Programme de contrôle - 2018 - rapporteur général du rapport public et des programmes de la Cour des comptes	2018-06-21 16:00:00	2018-06-21 16:45:00	\N	\N	1	0	\N	\N
289578	COM_PERMANENTE	AUTRE	\N	CAE	\N	Examen des motions et amendements de séance	\N	2018-06-26 09:00:00	2018-06-26 10:25:00	2018-06-27 12:14:50	2018-06-27 12:19:16	27	0	\N	\N
289579	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	auditions rapporteurs	\N	2018-06-21 09:30:00	2018-06-21 12:00:00	\N	\N	0	0	\N	\N
289580	COM_PERMANENTE	AUTRE	\N	CAE	\N	Examen des motions et amendements de séance	\N	2018-06-26 13:50:00	2018-06-26 14:55:00	2018-06-27 12:14:41	2018-06-27 12:19:17	29	0	\N	\N
289587	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Liberté de choisir son avenir professionnel	\N	2018-06-20 18:30:00	2018-06-20 20:00:00	\N	\N	4	0	\N	\N
289592	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Liberté de choisir son avenir professionnel	\N	2018-06-21 09:30:00	2018-06-21 12:00:00	\N	\N	4	0	\N	\N
289597	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Liberté de choisir son avenir professionnel	\N	2018-06-26 09:15:00	2018-06-26 10:00:00	\N	\N	3	0	\N	\N
289733	COM_PERMANENTE	AUTRE	\N	LOIS	\N	réunion commission 26 juin 2018	réunion commission 26 juin 2018	2018-06-26 09:10:00	2018-06-26 10:00:00	2018-06-26 12:37:09	2018-06-26 16:28:50	24	1	\N	\N
289796	GIA	AUCUNE	\N	\N	\N	Entretien avec M. ZHAO Jinjun, ancien ambassadeur et vice-président du think tank CCIEC 	Entretien avec M. ZHAO Jinjun, ancien ambassadeur de Chine en France et vice-président du think tank CCIEC	2018-06-26 08:30:00	2018-06-26 10:00:00	\N	\N	8	0	584	\N
291331	MISSION	AUCUNE	\N	MINEURSENF	\N	Audition Plénière	\N	2018-06-26 17:45:00	2018-06-26 18:50:00	2018-06-27 08:29:53	2018-06-27 12:14:53	6	0	\N	\N
292052	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2019 - programme 212	\N	2018-06-27 15:15:00	2018-06-27 16:15:00	\N	\N	2	0	\N	\N
292799	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 28 juin - Première partie	Réunion du 28 juin - Première partie	2018-06-28 08:40:00	2018-06-28 09:15:00	2018-06-28 15:04:55	2018-06-28 15:46:37	4	0	\N	\N
292844	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 28 juin 2018 - 2ème partie	Réunion du 28 juin 2018 - 2ème partie	2018-06-28 09:25:00	2018-06-28 10:25:00	2018-06-28 15:12:17	2018-06-28 15:46:38	15	0	\N	\N
294874	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL et PPLO Lutte contre manipulation de l'information	\N	2018-07-17 09:00:00	2018-07-17 09:55:00	2018-07-17 16:16:48	2018-07-17 16:42:34	21	1	\N	\N
289582	COM_PERMANENTE	AUTRE	\N	CAE	\N	Examen des motions et amendements de séance	\N	2018-06-27 09:35:00	2018-06-27 11:30:00	2018-06-27 12:14:29	2018-06-27 12:19:30	47	0	\N	\N
295875	DELEGATION	AUDRAP	\N	\N	PROS	Audition de Gabriel Plassat	\N	2018-07-17 14:00:00	2018-07-17 15:00:00	\N	\N	3	0	\N	\N
296100	DELEGATION	AUDRAP	\N	\N	PROS	Audition rapporteurs	Audition d'Olivier Bouba Olga, professeur des universités	2018-07-17 15:00:00	2018-07-17 16:00:00	\N	\N	3	0	\N	\N
297358	DELEGATION	AUDRAP	\N	\N	DSOM	Rencontre avec des maires des îles Marquises	\N	2018-07-11 11:00:00	2018-07-11 12:40:00	\N	\N	2	0	\N	\N
297472	DELEGATION	AUDRAP	\N	\N	PROS	Audition rapporteurs (UBER)	\N	2018-07-19 11:30:00	2018-07-19 12:45:00	\N	\N	3	0	\N	\N
297481	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Aide Alimentaire - Cellule Fonds Européen DGFiP	Contrôle 2018 - Aide Alimentaire - Cellule Fonds Européen DGFiP	2018-07-10 14:00:00	2018-07-10 15:00:00	\N	\N	1	0	\N	\N
297483	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Aide Alimentaire - société comerso	Contrôle 2018 - Aide Alimentaire - société comerso	2018-07-10 15:30:00	2018-07-10 16:30:00	\N	\N	1	0	\N	\N
297489	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition plénière	\N	2018-07-18 09:30:00	2018-07-18 11:35:00	2018-07-18 11:38:10	2018-07-18 14:48:50	30	0	\N	\N
297502	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Affaires Européennes - Représentation permanente de la France à Bruxelles	Contrôle 2018 - Affaires Européennes - Représentation permanente de la France à Bruxelles	2018-07-10 15:30:00	2018-07-10 16:30:00	\N	\N	1	0	\N	\N
297573	COM_EURO	AUDRAP	\N	AFEU	\N	Retour au taux réduit de TVA pour la filière équine	Audition de représentants de la Fédération française d'équitation	2018-07-18 14:00:00	2018-07-18 15:30:00	\N	\N	1	0	\N	\N
297574	COM_EURO	AUDRAP	\N	AFEU	\N	Retour au taux réduit de TVA pour la filière équine	Audition de représentants du ministère de l'économie et des finances	2018-07-18 15:30:00	2018-07-18 17:00:00	\N	\N	1	0	\N	\N
297576	COM_EURO	AUDRAP	\N	AFEU	\N	Retour au taux réduit de TVA pour la filière équine	Audition de représentants du SGAE	2018-07-19 09:00:00	2018-07-19 10:00:00	\N	\N	1	0	\N	\N
297577	COM_EURO	AUDRAP	\N	AFEU	\N	Retour au taux réduit de TVA pour la filière équine	Audition de représentants de la Gouvernance de la filière cheval	2018-07-19 11:15:00	2018-07-19 12:45:00	\N	\N	1	0	\N	\N
297578	COM_EURO	AUDRAP	\N	AFEU	\N	Retour au taux réduit de TVA pour la filière équine	Audition de représentants de l'Institut français du cheval et de l'équitation	2018-07-19 12:45:00	2018-07-19 13:30:00	\N	\N	1	0	\N	\N
297846	COM_EURO	DEPLACEMENT	\N	AFEU	\N	Réforme de l'Autorité européenne de sécurité des aliments (AESA / EFSA)-	Bruxelles - Rencontre avec des représentants des institutions européennes	2018-07-11 08:00:00	2018-07-11 18:00:00	\N	\N	1	0	\N	\N
297932	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Aides à la pierre - ADF, AdCF et France urbaine	Contrôle 2018 - Aides à la pierre - ADF, AdCF et France urbaine	2018-07-12 09:00:00	2018-07-12 10:30:00	\N	\N	1	0	\N	\N
298190	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions rapporteur thanatopraxie	\N	2018-07-10 13:00:00	2018-07-10 16:45:00	\N	\N	1	0	\N	\N
298578	GIA	AUCUNE	\N	\N	\N	Petit-déjeuner avec l'Ambassadeur chargé des questions frontalières	\N	2018-07-12 08:30:00	2018-07-12 09:30:00	\N	\N	5	0	610	\N
300806	ETUDES	AUCUNE	\N	\N	\N	Audition	Audition	2018-07-19 14:00:00	2018-07-19 15:00:00	\N	\N	2	0	\N	1006
301380	DELEGATION	AUDRAP	\N	\N	206	Audition bioéthique de M. Vincent Lévy	Audition bioéthique de M. Vincent Lévy (hôpital Avicenne)	2018-07-19 16:30:00	2018-07-19 18:00:00	\N	\N	2	0	\N	\N
301383	DELEGATION	AUDRAP	\N	\N	206	Audition bioéthique de  M. Alain Luciani	Audition bioéthique de M. Alain Luciani, chef du service d¿imagerie médicale de l¿hôpital Henri Mondor 	2018-07-24 11:15:00	2018-07-24 12:15:00	\N	\N	1	0	\N	\N
301625	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen amendements séance Nlle lecture PJL DSP2	Examen amendements séance Nlle lecture PJL DSP2	2018-07-24 10:05:00	2018-07-24 10:15:00	2018-07-24 11:27:02	2018-07-24 17:10:14	20	0	\N	\N
301628	COM_PERMANENTE	AUTRE	\N	FINC	\N	Contrôle budgétaire Enseignement Français etranger- Commun. déplacement Washington/Berlin	Contrôle budgétaire Enseignement Français etranger - Communication déplacement Washington/Berlin	2018-07-25 10:05:00	2018-07-25 11:55:00	2018-07-25 16:07:43	2018-07-25 17:10:42	28	0	\N	\N
223678	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Sylvain ITTÉ, Ambassadeur de France en Angola	Entretien avec M. Sylvain ITTÉ, Ambassadeur de France en Angola	2017-11-21 15:00:00	2017-11-21 16:00:00	\N	\N	1	0	646	\N
223682	GIA	AUCUNE	\N	\N	\N	Entretien avec S.E. M. Rolf Einar FIFE, Ambassadeur de Norvège en France	Entretien avec S.E. M. Rolf Einar FIFE, Ambassadeur de Norvège en France	2017-11-23 18:00:00	2017-11-23 19:00:00	\N	\N	2	0	625	\N
228124	BUREAU	AUCUNE	\N	\N	\N	Bureau du Sénat	Bureau du Sénat	2017-12-07 09:00:00	2017-12-07 12:30:00	\N	\N	24	0	\N	\N
228236	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Expertise internationale	\N	2017-12-05 17:00:00	2017-12-05 18:00:00	\N	\N	2	0	\N	\N
230586	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2018-Nlle lecture-Examen rapport - LPFP 2018-2022-Nlle Lecture-Examen rapport	PLF pour 2018-Nlle lecture-Examen rapport - LPFP 2018-2022-Nlle Lecture-Examen rapport	2017-12-19 09:05:00	2017-12-19 10:00:00	2017-12-20 17:32:02	2017-12-20 17:35:47	19	1	\N	\N
230587	COM_PERMANENTE	AUTRE	\N	FINC	\N	LPFP 2018-2022-Nlle Lecture-Examen Amdts	LPFP 2018-2022-Nlle Lecture-Examen Amdts	2017-12-19 16:25:00	2017-12-19 16:30:00	2017-12-20 17:31:38	2017-12-20 17:35:46	28	1	\N	\N
232852	ETUDES	AUCUNE	\N	\N	\N	\N	\N	2017-12-19 14:10:00	2017-12-19 14:30:00	\N	\N	14	0	\N	1004
244168	ETUDES	AUCUNE	\N	\N	\N	G.E. "Section Cultures traditionnelles"	G.E. "Section Cultures traditionnelles"	2018-02-07 08:00:00	2018-02-07 09:00:00	\N	\N	10	0	\N	1005
244179	ETUDES	AUCUNE	\N	\N	\N	G.E. "Agriculture et alimentation"	G.E. "Agriculture et alimentation"	2018-02-06 18:30:00	2018-02-06 19:30:00	\N	\N	32	0	\N	919
244212	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Groupe de suivi "Etats généraux de l'alimentation"	Groupe de suivi "Etats généraux de l'alimentation"	2018-02-07 14:15:00	2018-02-07 15:15:00	\N	\N	4	0	\N	\N
244217	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL "Réforme du Logement"	PJL "Réforme du Logement"	2018-02-08 09:15:00	2018-02-08 12:05:00	\N	\N	2	0	\N	\N
298280	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen Rapport PJL 644 DSP2 - Compte rendu déplacement Canada -nomination rapporteur PLFSS	Examen Rapport PJL 644 DSP2 - Compte rendu déplacement Canada -nomination rapporteur avis PLFSS 2019	2018-07-18 10:05:00	2018-07-18 11:00:00	2018-07-20 18:35:54	2018-07-24 17:10:49	31	1	\N	\N
298800	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Rapport PPL Rodéos motorisés + Rapport nvelle lecture PPL Eau et assainissement	Réunion commission Mercredi 18 juillet 2018	2018-07-18 09:40:00	2018-07-18 11:30:00	2018-07-18 16:12:24	2018-07-18 17:02:40	36	0	\N	\N
249949	DELEGATION	AUDRAP	\N	\N	206	Audition de l'UIPP	Audition de l'Union des industries de la protection des plantes (UIPP)	2018-02-22 09:00:00	2018-02-22 10:30:00	\N	\N	4	0	\N	\N
251800	CONF_PRES	AUCUNE	\N	\N	\N	\N	\N	2018-02-21 19:05:00	2018-02-21 19:30:00	\N	\N	25	0	\N	\N
256504	DELEGATION	DEPLACEMENT	\N	\N	PROS	Visite de l'école 42	\N	2018-04-19 10:00:00	2018-04-19 12:00:00	\N	\N	9	0	\N	\N
258653	DELEGATION	AUCUNE	\N	\N	211	Audition du Docteur Pierre FOLDÈS, urologue, et de Frédérique MARTZ, Women Safe	Audition du Docteur Pierre FOLDÈS, urologue, et de Frédérique MARTZ, Women Safe	2018-03-22 09:00:00	2018-03-22 10:45:00	2018-03-22 11:09:49	2018-03-22 12:25:51	7	0	\N	\N
267657	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Jean-François Narbonne, toxicologue	Audition de M. Jean-François Narbonne, toxicologue, ancien directeur de l'unité CNRS 5255, ancien expert de l'Anses	2018-05-24 16:30:00	2018-05-24 17:30:00	\N	\N	2	0	\N	\N
267658	DELEGATION	AUDRAP	\N	\N	206	Audition de l'Union des industries chimiques (UIC)	Audition de l'Union des industries chimiques (UIC)	2018-05-28 14:30:00	2018-05-28 15:30:00	\N	\N	2	0	\N	\N
267659	DELEGATION	AUDRAP	\N	\N	206	Audition de la DGS au ministère des solidarités et de la santé	Audition du Pr Jérôme Salomon, DG à la DGS au ministère des solidarités et de la santé	2018-05-28 15:30:00	2018-05-28 16:30:00	\N	\N	2	0	\N	\N
267660	DELEGATION	AUDRAP	\N	\N	206	Audition de la DGAL au sein du ministère de l'agriculture	Audition de la directin générale de l'alimentation au sein du ministère de l'agriculture	2018-05-28 16:30:00	2018-05-28 17:30:00	\N	\N	1	0	\N	\N
275765	MISSION	AUCUNE	\N	HERBE	\N	Audition plénière	\N	2018-05-24 11:05:00	2018-05-24 12:55:00	2018-05-24 19:05:20	2018-05-25 17:14:17	13	0	\N	\N
275788	MISSION	AUCUNE	\N	HERBE	\N	Audition plénière	\N	2018-05-24 16:35:00	2018-05-24 17:40:00	2018-05-24 19:04:34	2018-05-25 17:14:21	7	0	\N	\N
276945	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	Comédie française	\N	2018-06-07 09:00:00	2018-06-07 12:00:00	\N	\N	0	0	\N	\N
277135	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	CPR-RATP et CnavPL	\N	2018-06-20 16:30:00	2018-06-20 19:00:00	\N	\N	0	0	\N	\N
277138	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	DRH-EDF, DRH-RATP et DRH-SNCF	\N	2018-06-21 09:00:00	2018-06-21 12:00:00	\N	\N	0	0	\N	\N
279259	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Cultes	\N	2018-05-29 14:00:00	2018-05-29 14:45:00	\N	\N	1	0	\N	\N
279261	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Formation des ministres des cultes	\N	2018-05-29 18:00:00	2018-05-29 20:00:00	\N	\N	1	0	\N	\N
282452	DELEGATION	AUCUNE	\N	\N	211	 Audition de Mme Belloubet, garde des Sceaux et de Mme Schiappa, secrétaire d'État	Audition de Mme Belloubet, garde des Sceaux et de Mme Schiappa, secrétaire d'État	2018-06-11 18:35:00	2018-06-11 20:45:00	2018-06-12 11:18:08	2018-06-12 15:31:39	19	0	\N	\N
282453	DELEGATION	AUCUNE	\N	\N	DSOM	Réunion de la délégation	Nomination d'un rapporteur et audition dans le cadre du POSEI	2018-06-21 09:40:00	2018-06-21 11:20:00	2018-06-22 12:36:23	2018-06-22 15:10:06	12	0	\N	\N
282454	COM_ENQUETE	PLENIERE	\N	HAUTE	\N	Audition	Audition	2018-06-11 10:35:00	2018-06-11 11:40:00	2018-06-11 16:32:50	2018-06-12 15:31:21	5	0	\N	\N
299814	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2018 - Péages urbains - Stockholm	Contrôle 2018 - Péages urbains - Stockholm	2018-07-16 09:20:00	2018-07-17 22:20:00	\N	\N	1	0	\N	\N
300025	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018  - Réseau enseignement français à l'étranger - Collectif Avenir des lycées 	Contrôle 2018  - Réseau enseignement français à l'étranger - Collectif "Avenir des lycées français du monde en danger"	2018-07-18 11:30:00	2018-07-18 12:45:00	\N	\N	2	0	\N	\N
300120	DELEGATION	AUDRAP	\N	\N	206	Audition dans le cadre de la mission "perte de biodiversité"	Audition dans le cadre de la mission "perte de biodiversité"	2018-07-17 14:30:00	2018-07-17 15:30:00	\N	\N	1	0	\N	\N
300123	DELEGATION	AUDRAP	\N	\N	206	Audition dans le cadre de la mission "perte de biodiversité"	Audition dans le cadre de la mission "perte de biodiversité"	2018-07-24 14:00:00	2018-07-24 17:00:00	\N	\N	1	0	\N	\N
300125	DELEGATION	AUDRAP	\N	\N	206	Audition dans le cadre de la mission "perte de biodiversité"	\N	2018-07-10 14:30:00	2018-07-10 15:30:00	\N	\N	1	0	\N	\N
300135	DELEGATION	AUDRAP	\N	\N	206	Audition dans le cadre de la mission "perte de biodiversité"	Audition dans le cadre de la mission "perte de biodiversité"	2018-07-12 10:30:00	2018-07-12 11:30:00	\N	\N	1	0	\N	\N
307415	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Prévenir et sanctionner les violences lors des manifestations	\N	2018-10-01 17:00:00	2018-10-01 19:35:00	\N	\N	1	0	\N	\N
307419	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Prévenir et sanctionner les violences lors des manifestations	\N	2018-10-02 10:00:00	2018-10-02 10:40:00	\N	\N	1	0	\N	\N
309070	COM_EURO	AUTRE_NON_PLENIERE	\N	AFEU	\N	Réunion du Bureau de la commission des affaires européennes	Réunion du Bureau de la commission des affaires européennes	2018-10-04 08:00:00	2018-10-04 09:10:00	\N	\N	12	0	\N	\N
309114	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	FINC	\N	CMP sur les dispositions restant en discussion du PJL relatif à la lutte contre la fraude	CMP sur les dispositions restant en discussion du PJL relatif à la lutte contre la fraude	2018-10-04 10:20:00	2018-10-04 11:35:00	\N	\N	9	0	\N	\N
311789	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2018-10-16 14:15:00	2018-10-16 14:20:00	2018-10-16 17:06:07	2018-10-16 17:20:09	23	0	\N	\N
287982	GIA	AUCUNE	\N	\N	\N	Christine St Pierre	Petit-déjeuner avec Mme Christine St Pierre ministre des relations internationales et de la francophonie du Québec	2018-06-21 08:00:00	2018-06-21 09:00:00	\N	\N	8	0	602	\N
288339	GIA	AUCUNE	\N	\N	\N	Fête nationale du Québec	Réception offerte en l'honneur de la fête nationale du Québec	2018-06-21 13:00:00	2018-06-21 15:00:00	\N	\N	6	0	602	\N
297568	GIA	AUCUNE	\N	\N	\N	GIA France-Allemagne : entretien	Entretien avec Mme Claudia Roth, VP du Bundestag	2018-07-11 12:45:00	2018-07-11 14:45:00	\N	\N	3	0	604	\N
297575	DELEGATION	AUDRAP	\N	\N	206	Audition "Stockage de l'électricité" d'Équilibre des énergies	Audition "Stockage de l'électricité" d'Équilibre des énergies	2018-07-18 09:30:00	2018-07-18 10:30:00	\N	\N	1	0	\N	\N
319289	COM_PERMANENTE	AUDRAP	\N	CDD	\N	\N	PLF 2019 - Avis budgétaire "Maritime"	2018-11-06 18:00:00	2018-11-06 18:45:00	\N	\N	1	0	\N	\N
319291	COM_PERMANENTE	AUDRAP	\N	CDD	\N	\N	PLF 2019  - Avis "Recherche"	2018-11-06 15:00:00	2018-11-06 18:00:00	\N	\N	1	0	\N	\N
319293	COM_PERMANENTE	AUDRAP	\N	CDD	\N	\N	PLF 2019 - Avis "Transports"	2018-11-06 14:30:00	2018-11-06 16:00:00	\N	\N	2	0	\N	\N
319296	COM_PERMANENTE	AUDRAP	\N	CDD	\N	\N	PLF 2019 - Avis budgétaire "Transport ferroviaire"	2018-11-07 08:00:00	2018-11-07 09:00:00	\N	\N	1	0	\N	\N
319298	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2019 - Avis fonction publique	\N	2018-10-29 15:00:00	2018-10-29 17:15:00	\N	\N	1	0	\N	\N
319300	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2019 - Avis fonction publique	\N	2018-11-29 18:30:00	2018-11-29 20:00:00	\N	\N	0	0	\N	\N
320133	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	PJLF pour 2019 - Mission Sécurités	PJLF pour 2019 - Mission Sécurités	2018-11-06 13:45:00	2018-11-06 19:30:00	\N	\N	3	0	\N	\N
320137	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLF pour 2019 - Mission RCT	PJLF pour 2019 - Mission Relations avec les collectivités territoriales	2018-11-06 17:00:00	2018-11-06 18:00:00	\N	\N	1	0	\N	\N
320192	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe France-Balkans occidentaux	Assemblée générale du groupe France-Balkans occidentaux	2018-11-07 08:00:00	2018-11-07 09:20:00	\N	\N	6	0	674	\N
320359	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions avis budgétaires conseil et contrôle de l'Etat	Auditions avis budgétaires conseil et contrôle de l'Etat	2018-11-07 14:00:00	2018-11-07 17:00:00	\N	\N	1	0	\N	\N
320363	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	\N	2018-11-07 17:35:00	2018-11-07 20:05:00	2018-11-07 20:14:27	2018-11-08 16:20:44	35	0	\N	\N
320372	GIA	AUCUNE	\N	\N	\N	Réunion du groupe	Réunion du groupe autour de l'ambassadeur de Taïwan	2018-11-07 08:30:00	2018-11-07 09:30:00	\N	\N	8	0	623	\N
320717	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLF pour 2019 - Mission Sécurités	PJLF pour 2019 - Mission Sécurités	2018-11-07 14:00:00	2018-11-07 15:15:00	\N	\N	2	0	\N	\N
320720	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLF pour 2019 - Mission Sécurités	PJLF pour 2019 - Mission Sécurités	2018-11-07 15:15:00	2018-11-07 17:30:00	\N	\N	1	0	\N	\N
320722	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLF pour 2019 - Mission RCT	PJLF pour 2019 - Mission Relations avec les collectivités territoriales	2018-11-07 14:30:00	2018-11-07 17:00:00	\N	\N	2	0	\N	\N
320771	COM_EURO	AUDRAP	\N	AFEU	\N	GS EURO_PAC	GS EURO_PAC	2018-11-06 14:30:00	2018-11-06 16:00:00	\N	\N	11	0	\N	\N
320804	COM_EURO	AUDRAP	\N	AFEU	\N	Corridor "Mer du Nord - Méditerranée"	\N	2018-11-06 18:00:00	2018-11-06 19:00:00	\N	\N	2	0	\N	\N
321076	GIA	AUCUNE	\N	\N	\N	déjeuner avec M. l'ambassadeur de Corée du Sud	déjeuner avec M. l'ambassadeur de Corée du Sud	2018-11-08 12:30:00	2018-11-08 14:00:00	\N	\N	4	0	613	\N
321849	DELEGATION	AUDRAP	\N	\N	206	Audition SAFT (Stockage de l'électricité)	Audition SAFT (Stockage de l'électricité)	2018-11-13 14:30:00	2018-11-13 16:00:00	\N	\N	1	0	\N	\N
321897	DELEGATION	AUDRAP	\N	\N	206	Audition M. François Dedieu, chercheur en sociologie INRA  (Risques sanitaires)	Audition M. François Dedieu, chercheur en sociologie INRA  (Risques sanitaires)	2018-11-21 18:30:00	2018-11-21 19:20:00	\N	\N	1	0	\N	\N
321970	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Avis budgétaire "Prévention des risques"	Avis budgétaire "Prévention des risques"	2018-11-13 09:30:00	2018-11-13 11:00:00	\N	\N	1	0	\N	\N
322117	MISSION	AUCUNE	\N	INFRACTIONS	\N	Réunion constitutive	Réunion constitutive	2018-11-15 09:20:00	2018-11-15 10:00:00	2018-11-15 10:37:47	2018-11-15 14:56:40	22	0	\N	\N
322159	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition plénière - PJLF Budget 2019	\N	2018-11-13 18:05:00	2018-11-13 20:00:00	2018-11-14 15:19:54	2018-11-14 15:31:21	34	0	\N	\N
322283	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Plf 2019 - Crédits de l'audiovisuel public	Plf 2019 - Crédits de l'audiovisuel public	2018-11-13 14:30:00	2018-11-13 15:30:00	\N	\N	2	0	\N	\N
322289	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition de Didier Guillaume	\N	2018-11-13 18:05:00	2018-11-13 19:25:00	2018-11-13 19:47:23	2018-11-14 09:27:56	26	0	\N	\N
322292	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2018-11-14 17:00:00	2018-11-14 19:55:00	2018-11-14 20:01:37	2018-11-15 14:56:21	29	0	\N	\N
322456	DELEGATION	AUCUNE	\N	\N	PROS	Audition ONERC	Audition de MM Laurent Michel et Eric Brun (ONERC)	2018-11-22 08:30:00	2018-11-22 09:30:00	2018-11-22 10:02:55	2018-11-22 10:24:24	15	0	\N	\N
322759	DELEGATION	AUCUNE	\N	\N	DSOM	Présentation du rapport d'information "Jeunesse des outre-mer et sport"	Présentation du rapport d'information "Jeunesse des outre-mer et sport"	2018-11-20 09:00:00	2018-11-20 10:05:00	2018-11-20 10:49:13	2018-11-20 12:09:03	9	0	\N	\N
324187	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2018-11-07 11:45:00	2018-11-07 12:00:00	\N	\N	3	0	\N	\N
324508	GIA	AUCUNE	\N	\N	\N	29ème anniversaire Prix Nobel de la Paix (Dalaï-Lama)	29ème anniversaire Prix Nobel de la Paix (Dalaï-Lama)	2018-12-10 11:00:00	2018-12-10 14:00:00	\N	\N	0	0	634	\N
324608	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ambassadeur d'Arménie en France	Entretien avec l'ambassadeur d'Arménie en France	2018-10-23 12:30:00	2018-10-23 14:00:00	\N	\N	2	0	641	\N
324632	DELEGATION	AUDRAP	\N	\N	206	Audition M. Francis Vuibert, préfet (Arrêt des véhicules thermiques)	Audition M. Francis Vuibert, préfet (Arrêt des véhicules thermiques)	2018-11-20 09:30:00	2018-11-20 11:00:00	\N	\N	2	0	\N	\N
324637	DELEGATION	AUDRAP	\N	\N	206	Audition Negawatt (Arrêt des véhicules thermiques)	Audition Negawatt (Arrêt des véhicules thermiques)	2018-11-22 10:00:00	2018-11-22 11:00:00	\N	\N	2	0	\N	\N
324643	DELEGATION	AUDRAP	\N	\N	206	Audition M. G. Pitron (Arrêt des véhicules thermiques)	Audition M. G. Pitron (Arrêt des véhicules thermiques)	2018-11-22 11:00:00	2018-11-22 12:00:00	\N	\N	0	0	\N	\N
324645	DELEGATION	AUDRAP	\N	\N	206	Audition ENEDIS (Arrêt des véhicules thermiques)	Audition ENEDIS (Arrêt des véhicules thermiques)	2018-11-27 09:00:00	2018-11-27 10:00:00	\N	\N	2	0	\N	\N
324648	DELEGATION	AUDRAP	\N	\N	206	Audition Whylot (Arrêt des véhicules thermiques)	Audition Whylot (Arrêt des véhicules thermiques)	2018-11-27 10:00:00	2018-11-27 11:00:00	\N	\N	2	0	\N	\N
324673	COM_PERMANENTE	AUDRAP	\N	CDD	\N	\N	PLF 2019 - Avis "Recherche"	2018-11-14 15:00:00	2018-11-14 16:00:00	\N	\N	1	0	\N	\N
324679	COM_PERMANENTE	AUDRAP	\N	CDD	\N	\N	PLF 2019 - Avis "Cohésin des territoires"	2018-11-14 18:30:00	2018-11-14 19:30:00	\N	\N	1	0	\N	\N
324853	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2019 - programme 144	\N	2018-11-13 15:30:00	2018-11-13 16:35:00	\N	\N	2	0	\N	\N
325318	GIA	AUCUNE	\N	\N	\N	Entretien à l'Ambassade d'Italie	Entretien à l'Ambassade d'Italie	2018-11-19 12:30:00	2018-11-19 14:00:00	\N	\N	4	0	621	\N
326678	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions AGTE 2019	\N	2018-11-20 16:00:00	2018-11-20 17:15:00	\N	\N	1	0	\N	\N
322194	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2018-11-14 09:30:00	2018-11-14 12:25:00	2018-11-14 15:20:25	2018-11-14 15:31:19	45	1	\N	\N
322290	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	\N	2018-11-14 08:35:00	2018-11-14 10:30:00	2018-11-14 20:04:06	2018-11-15 14:56:27	47	1	\N	\N
326851	DELEGATION	AUDRAP	\N	\N	PROS	Museum National d'Histoire Naturelle (MNHN)	Museum National d'Histoire Naturelle (MNHN)	2018-12-11 10:00:00	2018-12-11 11:00:00	\N	\N	1	0	\N	\N
326852	DELEGATION	AUDRAP	\N	\N	PROS	Agence française pour la Biodiversité 	\N	2018-12-11 09:00:00	2018-12-11 10:00:00	\N	\N	1	0	\N	\N
214585	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Écologie, développement et mobilité durables/Énergie	PLF pour 2018 - Écologie, développement et mobilité durables/Énergie - Audition Ministères écologie-territoires-CNPA	2017-10-31 14:30:00	2017-10-31 16:30:00	\N	\N	1	0	\N	\N
214591	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Travail et emploi 	PLF pour 2018 - Travail et emploi - Audition Direction du budget	2017-10-31 18:00:00	2017-10-31 19:00:00	\N	\N	2	0	\N	\N
214594	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Travail et emploi 	PLF pour 2018 - Travail et emploi  - Audition Cabinet de la ministre du travail	2017-11-02 11:45:00	2017-11-02 12:45:00	\N	\N	1	0	\N	\N
214600	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Économie	PLF pour 2018 - Économie - Audition Business France-CCI Paris IDF-CCI France	2017-10-30 15:15:00	2017-10-30 19:00:00	\N	\N	1	0	\N	\N
214602	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Rapport général	PLF pour 2018 - Rapport général - Audition CCI Paris IDF	2017-10-30 17:00:00	2017-10-30 18:00:00	\N	\N	1	0	\N	\N
214604	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Solidarité, insertion et égalité des chances	PLF pour 2018 - Solidarité, insertion et égalité des chances - Audition APF, Restos du coeur, Banque alim., Secours pop.	2017-11-02 15:00:00	2017-11-02 17:15:00	\N	\N	2	0	\N	\N
216041	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2018 (avis Immigration)	\N	2017-11-08 14:00:00	2017-11-08 15:00:00	\N	\N	3	0	\N	\N
216045	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	PLF 2018 (Avis Immigration)	\N	2017-11-08 15:15:00	2017-11-08 18:40:00	\N	\N	1	0	\N	\N
216047	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	PLF 2018 (Avis PJJ)	\N	2017-11-07 14:00:00	2017-11-07 18:00:00	\N	\N	1	0	\N	\N
216049	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	PLF 2018 (Avis PJJ)	\N	2017-11-08 08:50:00	2017-11-08 17:00:00	\N	\N	1	0	\N	\N
219933	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2018 - Programme 144	\N	2017-11-14 14:30:00	2017-11-14 16:30:00	\N	\N	1	0	\N	\N
219942	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2018 - Programme 146	\N	2017-11-15 18:00:00	2017-11-15 19:20:00	\N	\N	2	0	\N	\N
219967	COM_EURO	CONTROLE	\N	AFEU	\N	Audition Michel Barnier, Négociateur en chef de l'Union européenne	Audition Michel Barnier, Négociateur en chef de l'Union européenne	2017-11-16 12:35:00	2017-11-16 13:55:00	2017-11-16 16:58:48	2017-11-16 17:24:20	39	0	\N	\N
226198	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2017-12-05 14:30:00	2017-12-05 16:15:00	2017-12-05 16:12:57	2017-12-05 16:49:58	35	0	\N	\N
226199	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2017-12-06 09:05:00	2017-12-06 10:50:00	2017-12-07 11:06:45	2017-12-07 11:07:28	39	0	\N	\N
238385	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 25 janvier 2018	Réunion du 25 janvier 2018	2018-01-25 09:05:00	2018-01-25 09:55:00	2018-01-25 12:19:37	2018-01-25 15:37:49	8	0	\N	\N
255927	ETUDES	AUCUNE	\N	\N	\N	GE Montagne 2018	GE Montagne 2018	2018-03-14 13:45:00	2018-03-14 18:30:00	\N	\N	16	0	\N	918
261493	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle MIRES - Performance établissements ens. sup	Contrôle MIRES - Performance établissements ens. sup - IGAENR	2018-03-27 14:30:00	2018-03-27 16:00:00	\N	\N	1	0	\N	\N
261572	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion 2018 04 03	\N	2018-04-03 18:10:00	2018-04-03 20:15:00	2018-04-03 20:15:19	2018-04-04 15:03:46	36	0	\N	\N
261751	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de M. Édouard Sauvage, directeur général de GrDF	\N	2018-04-04 11:05:00	2018-04-04 12:15:00	2018-04-04 14:38:23	2018-04-04 15:03:42	49	0	\N	\N
262003	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Réforme Action Logement	Réforme Action Logement	2018-04-03 17:00:00	2018-04-03 18:20:00	\N	\N	1	0	\N	\N
263008	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	\N	GT Financement du handicap	2018-05-29 19:00:00	2018-05-29 20:00:00	\N	\N	4	0	\N	\N
263464	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Conventions fiscales	PJL Conventions fiscales	2018-04-19 10:35:00	2018-04-19 11:50:00	\N	\N	78	0	\N	\N
263465	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Conclusions de la CMP PJL Protection données personnelles	Conclusions de la CMP PJL Protection données personnelles	2018-04-19 11:55:00	2018-04-19 13:05:00	\N	\N	60	0	\N	\N
263466	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2018-04-19 15:00:00	2018-04-19 16:05:00	\N	\N	243	0	\N	\N
263470	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Conclusions de la CMP PJL Protection données personnelles	Conclusions de la CMP PJL Protection données personnelles	2018-04-19 16:20:00	2018-04-19 17:25:00	\N	\N	30	0	\N	\N
263471	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Union européenne défis sécurité	Débat Union européenne défis sécurité	2018-05-09 14:30:00	2018-05-09 16:15:00	\N	\N	51	0	\N	\N
263472	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Union européenne défis compétitivité	Débat Union européenne défis compétitivité	2018-05-09 16:25:00	2018-05-09 17:45:00	\N	\N	24	0	\N	\N
263473	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Infrastructures routières	Débat Infrastructures routières	2018-05-15 14:30:00	2018-05-15 16:05:00	\N	\N	89	0	\N	\N
263474	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2018-05-15 16:45:00	2018-05-15 17:50:00	\N	\N	302	0	\N	\N
263475	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR FATCA	PPR FATCA	2018-05-15 18:05:00	2018-05-15 19:35:00	\N	\N	64	0	\N	\N
263481	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Politique familiale en France	Débat Politique familiale en France	2018-05-17 14:30:00	2018-05-17 16:00:00	\N	\N	38	0	\N	\N
263482	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Politique concurrence 	Débat Politique concurrence 	2018-05-17 16:15:00	2018-05-17 17:40:00	\N	\N	25	0	\N	\N
326842	COM_PERMANENTE	AUTRE	\N	SOCI	\N	réunion plénière	\N	2018-11-28 08:30:00	2018-11-28 10:15:00	2018-11-28 10:19:31	2018-11-28 11:50:24	42	1	\N	\N
261573	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Concurrence Polynésie + PJL Elections européennes + PPL Indivision + PPL Conseillers	\N	2018-04-04 08:30:00	2018-04-04 11:35:00	2018-04-04 16:51:21	2018-04-04 17:01:29	43	0	\N	\N
263483	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2018-05-22 09:30:00	2018-05-22 12:05:00	\N	\N	12	0	\N	\N
263484	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Programmation militaire	PJL Programmation militaire	2018-05-22 14:35:00	2018-05-22 20:00:00	\N	\N	172	0	\N	\N
263485	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Programmation militaire	PJL Programmation militaire	2018-05-22 21:30:00	2018-05-23 00:35:00	\N	\N	74	0	\N	\N
263756	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Conclusions de la CMP PJL Élection représentants Parlement européen	Conclusions de la CMP PJL Élection représentants Parlement européen	2018-05-23 14:30:00	2018-05-23 15:40:00	\N	\N	90	0	\N	\N
263758	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Programmation militaire	PJL Programmation militaire	2018-05-23 15:40:00	2018-05-23 20:00:00	\N	\N	142	0	\N	\N
263759	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Programmation militaire	PJL Programmation militaire	2018-05-23 21:30:00	2018-05-23 23:55:00	\N	\N	68	0	\N	\N
263766	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2018-05-24 15:00:00	2018-05-24 16:15:00	\N	\N	252	0	\N	\N
263768	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2018-05-29 16:45:00	2018-05-29 17:40:00	\N	\N	319	0	\N	\N
263769	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Nouveau pacte ferroviaire	PJL Nouveau pacte ferroviaire	2018-05-29 17:55:00	2018-05-29 20:20:00	\N	\N	160	0	\N	\N
300142	GIA	AUCUNE	\N	\N	\N	Audition de l'Ambassaeur SE M. François-Xavier DENIAU	Audition de l'Ambassaeur SE M. François-Xavier DENIAU	2018-07-18 16:30:00	2018-07-18 17:30:00	\N	\N	21	0	CHRETORIENT	CHRETORIENT
301751	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018  - Coûts audiovisuel public - TF1 et M6	Contrôle 2018  - Coûts audiovisuel public - TF1 et M6	2018-07-20 10:00:00	2018-07-20 11:30:00	\N	\N	1	0	\N	\N
301755	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteur	Audition de M. Henri SAFA	2018-07-25 09:30:00	2018-07-25 10:45:00	\N	\N	1	0	\N	\N
301918	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Prérogatives  attribuées  aux  commissions  d¿enquête  - Mission d'information	Prérogatives  attribuées  aux  commissions  d¿enquête  - Mission d'information	2018-07-23 14:45:00	2018-07-23 15:05:00	\N	\N	87	0	\N	\N
302264	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Programmation et réforme justice + PJLO Organisation juridictions	\N	2018-07-23 10:00:00	2018-07-23 11:00:00	\N	\N	1	0	\N	\N
302268	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Programmation et réforme pour la justice + PJLO Organisation des juridictions	\N	2018-07-23 11:00:00	2018-07-23 12:30:00	\N	\N	3	0	\N	\N
302272	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Programmation et réforme pour la justice + PJLO Organisation des juridictions	\N	2018-07-23 14:30:00	2018-07-23 16:15:00	\N	\N	3	0	\N	\N
304405	GIA	AUCUNE	\N	\N	\N	Réunion du bureau du groupe	Réunion du bureau du groupe, bilan et perspectives de l'activité du groupe	2018-07-24 20:00:00	2018-07-24 23:55:00	\N	\N	8	0	602	\N
305477	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PROG Programmation 2018-2022 et réforme pour la justice	\N	2018-09-11 10:00:00	2018-09-11 11:45:00	\N	\N	1	0	\N	\N
306069	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition MI Réforme territoriale	\N	2018-09-26 15:15:00	2018-09-26 16:00:00	\N	\N	4	0	\N	\N
306070	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2018-09-26 09:40:00	2018-09-26 12:02:00	2018-09-26 12:24:19	2018-09-26 17:51:25	37	0	\N	\N
306071	COM_EURO	AUDRAP	\N	AFEU	\N	Extraterritorialité des sanctions américaines	Extraterritorialité sanctions américaines - Audition de représentants de l'Ambassade des États-Unis d'Amérique en France	2018-09-25 13:45:00	2018-09-25 14:45:00	\N	\N	1	0	\N	\N
306072	COM_EURO	DEPLACEMENT	\N	AFEU	\N	Rapport "Platforms to business"	Bruxelles - Rencontre avec des représentants des institutions européennes	2018-09-24 08:00:00	2018-09-24 17:30:00	\N	\N	2	0	\N	\N
306392	COM_EURO	AUDRAP	\N	AFEU	\N	Extraterritorialité des sanctions américaines	Extraterritorialité des sanctions américaines - Ministère de l'économie et des finances - DG Trésor	2018-09-25 11:00:00	2018-09-25 11:45:00	\N	\N	1	0	\N	\N
306695	GIA	AUCUNE	\N	\N	\N	Entretien de Mme LEPAGE avec une délégation de fonctionnaires allemands	Entretien de Mme LEPAGE avec une délégation de fonctionnaires allemands	2018-09-25 15:00:00	2018-09-25 16:00:00	\N	\N	1	0	604	\N
307049	GIA	AUCUNE	\N	\N	\N	Entretien de M. JOMIER avec M. Kenneth OKOTH, Député kenyan (coopé)	Entretien de M. JOMIER avec M. Kenneth OKOTH, Député kenyan (coopé)	2018-09-26 17:00:00	2018-09-26 18:00:00	\N	\N	1	0	622	\N
307136	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR Pastoralisme	PPR Pastoralisme	2018-10-02 14:30:00	2018-10-02 16:00:00	\N	\N	119	0	\N	\N
307137	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2018-10-02 16:45:00	2018-10-02 17:45:00	\N	\N	311	0	\N	\N
307138	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Comités de protection des personnes	PPL Comités de protection des personnes	2018-10-02 17:50:00	2018-10-02 18:40:00	\N	\N	57	0	\N	\N
307140	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat  politique énergétique	Débat  politique énergétique	2018-10-02 18:40:00	2018-10-02 20:20:00	\N	\N	48	0	\N	\N
307290	COM_PERMANENTE	AUTRE	\N	ETRD	\N	PJLF pour 2019 - Audition	\N	2018-10-09 17:00:00	2018-10-09 18:30:00	2018-10-10 14:30:14	2018-10-10 16:56:12	35	0	\N	\N
307294	COM_PERMANENTE	AUTRE	\N	ETRD	\N	PJLF pour 2019 Auditions	\N	2018-10-10 09:45:00	2018-10-10 12:40:00	2018-10-10 15:40:39	2018-10-10 16:56:10	35	0	\N	\N
307418	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat politique industrielle	Débat politique industrielle	2018-10-03 17:25:00	2018-10-03 18:00:00	\N	\N	39	0	\N	\N
307421	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat réforme baccalauréat	Débat réforme baccalauréat	2018-10-03 14:50:00	2018-10-03 17:20:00	\N	\N	51	0	\N	\N
307422	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Conclusions CMP lutte contre la fraude	Conclusions CMP lutte contre la fraude	2018-10-09 14:30:00	2018-10-09 15:50:00	\N	\N	93	0	\N	\N
307423	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL et PJLO justice	PJL et PJLO justice	2018-10-09 15:50:00	2018-10-09 20:00:00	\N	\N	147	0	\N	\N
308609	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Action extérieure de l'Etat	PLF 2019 - Crédits Action extérieure de l'Etat	2018-10-02 15:30:00	2018-10-02 16:30:00	\N	\N	1	0	\N	\N
308745	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Prog justice 2018-2022 - PJLO Renforcement juridictions - Examen rapport et textes	PJL Prog justice 2018-2022 - PJLO Renforcement juridictions - Examen rapport et textes	2018-10-03 16:05:00	2018-10-03 16:55:00	2018-10-03 17:27:28	2018-10-03 17:35:56	0	0	\N	\N
308984	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Presse	PLF 2019 - Crédits Presse	2018-10-03 15:00:00	2018-10-03 16:15:00	\N	\N	2	0	\N	\N
309027	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL Protocole armes à feu	\N	2018-10-01 11:00:00	2018-10-01 12:10:00	\N	\N	1	0	\N	\N
309038	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	DSOM	Rencontre le président de l'UNAPEI	\N	2018-10-03 16:45:00	2018-10-03 18:30:00	\N	\N	0	0	\N	\N
309053	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Programmation 2018-2022 et réforme pour la justice - Amendements de séance	PJL Programmation 2018-2022 et réforme pour la justice - Amendements de séance	2018-10-09 09:05:00	2018-10-09 10:10:00	2018-10-09 10:31:49	2018-10-09 18:56:54	25	1	\N	\N
309054	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion 20181010 - Affaire Benalla - Audition de Mme Sophie Hatt	Réunion 20181010 - Affaire Benalla - Audition de Mme Sophie Hatt	2018-10-10 08:35:00	2018-10-10 09:35:00	2018-10-10 12:14:15	2018-10-10 12:46:03	31	0	\N	\N
310565	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2018-10-10 14:40:00	2018-10-10 17:25:00	\N	\N	3	0	\N	\N
311612	COM_SPECIALE	PLENIERE	\N	RETRAIT	\N	Table ronde	\N	2018-10-16 14:05:00	2018-10-16 16:40:00	2018-10-17 16:21:11	2018-10-17 16:32:18	23	0	\N	\N
311790	GIA	AUCUNE	\N	\N	\N	Rencontre avec une délégation cubaine de l'ANPP (PDJ)	Rencontre avec une délégation cubaine de l'Assemblée nationale du pouvoir populaire (PDJ)	2018-10-11 08:30:00	2018-10-11 09:45:00	\N	\N	5	0	642	\N
311796	GIA	AUCUNE	\N	\N	\N	Réunion avec l'ambassadeur d'Haïti Mme Vanessa LAMOTHE-MATIGNON	Réunion avec l'ambassadeur d'Haïti Mme Vanessa LAMOTHE-MATIGNON	2018-04-05 14:30:00	2018-04-05 15:15:00	\N	\N	2	0	642	\N
225774	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2017-12-06 10:15:00	2017-12-06 12:20:00	2017-12-06 15:14:22	2017-12-06 16:20:37	34	0	\N	\N
230786	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Expertise France	Expertise France	2017-12-12 16:00:00	2017-12-12 17:30:00	\N	\N	2	0	\N	\N
241475	GIA	AUCUNE	\N	\N	\N	Assemblée générale	Assemblée générale	2018-02-06 14:00:00	2018-02-06 14:35:00	\N	\N	10	0	623	\N
241503	GIA	AUCUNE	\N	\N	\N	Diner du Nouvel an taïwanais	Diner du Nouvel an taïwanais	2018-02-06 19:30:00	2018-02-06 22:30:00	\N	\N	8	0	623	\N
246403	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Affaires européennes	PLF pour 2019 - Affaires européennes - Audition de la conseillère Europe auprès du Premier ministre	2018-03-07 18:00:00	2018-03-07 19:00:00	\N	\N	1	0	\N	\N
246453	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Vote électronique	MI Vote électronique	2018-02-08 08:30:00	2018-02-08 12:45:00	\N	\N	2	0	\N	\N
246471	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Vote électronique	MI Vote électronique	2018-02-15 09:00:00	2018-02-15 13:00:00	\N	\N	2	0	\N	\N
247061	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition conjointe sur la politique d¿émission de dette par l¿État des obligations vertes	Audition conjointe sur la politique d¿émission de dette par l¿État et le développement du marché des obligations vertes	2018-02-21 09:35:00	2018-02-21 11:20:00	2018-02-21 15:59:32	2018-02-21 16:10:52	34	0	\N	\N
247088	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	DGCS, CNSA, Autisme France	\N	2018-03-06 16:00:00	2018-03-06 19:00:00	\N	\N	0	0	\N	\N
247091	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Auditions MM Mouiller et Milon	\N	2018-02-20 18:00:00	2018-02-20 19:00:00	\N	\N	0	0	\N	\N
247096	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	\N	\N	2018-02-20 18:00:00	2018-02-20 19:00:00	\N	\N	0	0	\N	\N
247099	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	\N	\N	2018-03-06 16:00:00	2018-03-06 17:00:00	\N	\N	0	0	\N	\N
247100	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	\N	\N	2018-03-06 17:00:00	2018-03-06 18:00:00	\N	\N	0	0	\N	\N
247106	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	SOCI	\N	Situation dans les EHPAD	\N	2018-02-15 13:45:00	2018-02-15 14:45:00	\N	\N	4	0	\N	\N
247107	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	SOCI	\N	Situation dans les EHPAD	Situation dans les EHPAD	2018-02-15 09:00:00	2018-02-15 10:30:00	\N	\N	7	0	\N	\N
251104	GIA	AUCUNE	\N	\N	\N	assemblée générale 	AG	2018-03-07 14:00:00	2018-03-08 14:30:00	\N	\N	3	0	627	\N
253008	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Libye	\N	2018-03-07 17:45:00	2018-03-07 19:15:00	\N	\N	4	0	\N	\N
268393	GIA	AUCUNE	\N	\N	\N	Colloque Citoyenneté et Justice	Un défi pour le Moyen Orient Quels enseignements pour l'avenir de l'Irak	2018-04-12 09:00:00	2018-04-12 16:30:00	\N	\N	10	0	CHRETORIENT	CHRETORIENT
271934	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2018-05-16 11:00:00	2018-05-16 11:20:00	2018-05-16 16:01:41	2018-05-16 18:01:29	41	0	\N	\N
272477	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion	Réunion	2018-05-16 16:00:00	2018-05-16 18:00:00	2018-05-16 18:17:14	2018-05-17 18:01:40	14	0	\N	\N
272597	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Mission Mécénat	Mission Mécénat	2018-05-16 14:30:00	2018-05-16 15:25:00	\N	\N	4	0	\N	\N
272605	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Mission Mécénat	Mission Mécénat	2018-05-16 15:25:00	2018-05-16 16:15:00	\N	\N	4	0	\N	\N
273906	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion - Audition MLP	Réunion - Audition MLP	2018-05-23 09:10:00	2018-05-23 10:20:00	2018-05-23 12:03:44	2018-05-23 16:02:30	33	2	\N	\N
274820	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Jean Zundel, spécialiste d'Ethereum, membre d'Asseth	Audition de M. Jean Zundel, spécialiste d'Ethereum, membre d'Asseth	2018-05-24 14:30:00	2018-05-24 15:50:00	\N	\N	2	0	\N	\N
328643	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Emplois en France	Débat	2018-12-12 22:00:00	2018-12-13 00:00:00	\N	\N	28	0	\N	\N
309056	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL PJLO Prog justice 2018-2022 -  Exam amts séance ; PPL Gens voyage - Exam rapport	PJL PJLO Prog justice 2018-2022 -  Exam amts séance ; PPL Gens voyage - Exam rapport	2018-10-10 09:50:00	2018-10-10 11:35:00	2018-10-10 12:23:04	2018-10-10 12:46:01	46	0	\N	\N
225773	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2017-12-06 09:30:00	2017-12-06 10:15:00	2017-12-06 15:16:08	2017-12-06 16:20:41	37	0	\N	\N
271980	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2018-05-16 11:20:00	2018-05-16 12:15:00	2018-05-16 16:02:02	2018-05-16 18:01:30	42	0	\N	\N
274852	DELEGATION	AUDRAP	\N	\N	206	Audition de MM. Timsit et de Tychey (ConsenSys)	Audition de M. Ken Timsit, directeur général de ConsenSys et de M. Jérôme de Tychey, directeur du dept Solutions	2018-05-24 15:50:00	2018-05-24 17:00:00	\N	\N	2	0	\N	\N
274853	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Courtois (University College London)	Audition de M. Nicolas Courtois, professeur d'informatique au University College London (UCL)	2018-05-24 17:00:00	2018-05-24 18:00:00	\N	\N	2	0	\N	\N
274855	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Danos (CNRS)	Audition de M. Vincent Danos, directeur de recherche au CNRS et à l'École normale supérieure de Paris	2018-05-24 18:00:00	2018-05-24 19:15:00	\N	\N	2	0	\N	\N
274856	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Augot (INRIA)	Audition de M. Daniel Augot, directeur de recherche à l'INRIA	2018-05-24 19:15:00	2018-05-24 20:15:00	\N	\N	2	0	\N	\N
274857	DELEGATION	AUDRAP	\N	\N	206	Audition de MM. Chouli et Roquebert (NeuroChain)	Audition de MM. Billal Chouli, directeur technique et Renaud Roquebert, avocat conseil (NeuroChain)	2018-05-29 10:30:00	2018-05-29 11:30:00	\N	\N	2	0	\N	\N
274858	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Pointcheval (CNRS)	Audition de M. David Pointcheval, directeur de recherche au CNRS	2018-05-29 11:45:00	2018-05-29 13:00:00	\N	\N	2	0	\N	\N
274859	DELEGATION	AUDRAP	\N	\N	206	Audition de Mme Amandine Jambert, ingénieur expert auprès de la CNIL	Audition de Mme Amandine Jambert, ingénieur expert auprès de la CNIL	2018-05-29 15:00:00	2018-05-29 16:30:00	\N	\N	2	0	\N	\N
274860	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Georg Fuchsbauer, chargé de recherche ENS Paris	Audition de M. Georg Fuchsbauer, chargé de recherche à la "Crypto Team" de l'École normale supérieure de Paris ENS Paris	2018-05-29 16:30:00	2018-05-29 18:00:00	\N	\N	2	0	\N	\N
274867	MECSS	AUDRAP	\N	\N	MECSS	Accès précoce à l'innovation dans le domaine des produits de santé	Accès précoce à l'innovation dans le domaine des produits de santé	2018-05-31 10:00:00	2018-05-31 11:00:00	\N	\N	5	0	\N	\N
279497	SEANCE_PLENIERE	SCRUSOL	921	\N	\N	Scrutin solennel Nouveau pacte ferroviaire	Scrutin solennel Nouveau pacte ferroviaire	2018-06-05 15:30:00	2018-06-05 16:00:00	\N	\N	0	0	\N	\N
279498	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	921	\N	\N	Explications de vote sur l'ensemble du PJL Nouveau pacte ferroviaire	Explications de vote sur l'ensemble du PJL Nouveau pacte ferroviaire	2018-06-05 14:30:00	2018-06-05 15:30:00	\N	\N	295	0	\N	\N
280698	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Lutte contre les violences sexuelles et sexistes	\N	2018-06-05 17:00:00	2018-06-05 20:00:00	\N	\N	1	0	\N	\N
304827	GIA	AUCUNE	\N	\N	\N	Déjeuner de travail avec Rémi MARECHAUX	Déjeuner de travail avec Rémi MARECHAUX, Directeur Afrique et Océan indien au ministère des Affaires étréangères	2018-07-25 12:30:00	2018-07-25 14:30:00	\N	\N	9	0	622	\N
305164	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Droit d'asile	PJL Droit d'asile	2018-07-31 15:35:00	2018-07-31 17:15:00	\N	\N	44	0	\N	\N
305246	MISSION	AUDRAP	\N	HERBE	\N	\N	\N	2018-08-01 15:00:00	2018-08-01 17:00:00	\N	\N	1	0	\N	\N
316086	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition AFD et Examen RI COM AFD	\N	2018-10-31 10:10:00	2018-10-31 12:15:00	2018-10-31 16:03:58	2018-10-31 16:27:50	39	0	\N	\N
316398	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	AFCL	\N	Réunion CRPA	Rencontre avec les présidents des commissions régionales du patrimoine et de l'architecture	2018-10-25 10:15:00	2018-10-25 12:30:00	\N	\N	15	0	\N	\N
316402	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2018-10-30 18:00:00	2018-10-30 20:00:00	\N	\N	0	0	\N	\N
316410	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 -Crédits Recherche	PLF 2019 -Crédits Recherche	2018-10-23 08:00:00	2018-10-23 10:15:00	\N	\N	1	0	\N	\N
316413	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Jeunesse et vie associative	PLF 2019 - Crédits Jeunesse et vie associative	2018-10-23 14:30:00	2018-10-23 15:15:00	\N	\N	2	0	\N	\N
316416	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Jeunesse et vie associative	PLF 2019 - Crédits Jeunesse et vie associative	2018-10-23 15:15:00	2018-10-23 16:15:00	\N	\N	1	0	\N	\N
316418	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 -Crédits Recherche	PLF 2019 -Crédits Recherche	2018-10-24 14:30:00	2018-10-24 15:15:00	\N	\N	2	0	\N	\N
316421	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 -Crédits Recherche	PLF 2019 -Crédits Recherche	2018-10-24 15:15:00	2018-10-24 16:00:00	\N	\N	1	0	\N	\N
316498	DELEGATION	AUDRAP	\N	\N	PROS	Audition SCNF / TER	\N	2018-10-31 16:30:00	2018-10-31 17:45:00	\N	\N	3	0	\N	\N
323973	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	Audition de M. Savary	\N	2018-12-03 14:00:00	2018-12-03 17:00:00	\N	\N	0	0	\N	\N
324282	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur PLF 2019  PJJ	\N	2018-11-13 15:30:00	2018-11-13 16:45:00	\N	\N	1	0	\N	\N
324285	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition PLF 2019 PJJ	\N	2018-11-14 09:00:00	2018-11-14 10:20:00	\N	\N	1	0	\N	\N
324297	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion 20181120	\N	2018-11-20 09:05:00	2018-11-20 10:45:00	2018-11-21 17:04:59	2018-11-21 17:28:03	22	1	\N	\N
326861	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2018-11-21 14:20:00	2018-11-21 15:35:00	2018-11-21 15:47:55	2018-11-21 16:30:36	27	1	\N	\N
327748	ETUDES	AUCUNE	\N	\N	\N	AUDITION DE de M. Alexandre de JUNIAC, directeur général de l'IATA	AUDITION DE de M. Alexandre de JUNIAC, directeur général de l'Association internationale du transport aérien (IATA)	2018-11-22 08:30:00	2018-11-22 09:30:00	\N	\N	9	0	\N	933
327921	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Préparation mission ONU	\N	2018-11-20 16:00:00	2018-11-20 17:00:00	\N	\N	3	0	\N	\N
328127	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Colloque Renseignement	Colloque des 10 ans de la délégation parlementaire au renseignement	2018-11-22 09:00:00	2018-11-22 13:00:00	\N	\N	3	0	\N	\N
328204	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition M. Fouché PPL Contrôleurs aériens	Audition M. Fouché PPL Contrôleurs aériens	2018-11-20 17:00:00	2018-11-20 18:30:00	\N	\N	1	0	\N	\N
328211	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition M. Fouché PPL Contrôleurs aériens	Audition M. Fouché PPL Contrôleurs aériens	2018-11-21 15:00:00	2018-11-21 15:45:00	\N	\N	1	0	\N	\N
328215	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition M. Fouché PPL Contrôleurs aériens	Audition M. Fouché PPL Contrôleurs aériens	2018-11-22 09:00:00	2018-11-22 11:30:00	\N	\N	1	0	\N	\N
328218	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition M. Fouché PPL Contrôleurs aériens	Audition M. Fouché PPL Contrôleurs aériens	2018-11-23 09:00:00	2018-11-23 12:00:00	\N	\N	1	0	\N	\N
328231	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 22 novembre 2018	Réunion du 22 novembre 2018	2018-11-22 08:35:00	2018-11-22 10:20:00	2018-11-22 16:03:02	2018-11-22 16:07:14	15	0	\N	\N
316085	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Convention (Pjl n° 611) et PPRE n° 18	\N	2018-10-31 09:15:00	2018-10-31 10:10:00	2018-10-31 16:03:03	2018-10-31 16:27:49	39	0	\N	\N
328700	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2018-11-20 19:30:00	2018-11-20 19:45:00	\N	\N	21	0	\N	\N
328749	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLFR pour 2018 - Nlle Lecture Examen des AMDTS de séance	PLFR pour 2018 - Nlle Lecture Examen des AMDTS de séance	2018-11-27 19:00:00	2018-11-27 19:45:00	\N	\N	0	0	\N	\N
328755	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-11-19 10:00:00	2018-11-19 12:15:00	\N	\N	2	0	\N	\N
328758	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-11-19 14:00:00	2018-11-19 16:00:00	\N	\N	1	0	\N	\N
328760	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-11-20 15:00:00	2018-11-20 15:45:00	\N	\N	5	0	\N	\N
328766	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-11-21 16:00:00	2018-11-21 17:40:00	\N	\N	2	0	\N	\N
328769	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-11-22 09:30:00	2018-11-22 11:00:00	\N	\N	3	0	\N	\N
328771	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-11-20 17:30:00	2018-11-20 18:00:00	\N	\N	3	0	\N	\N
328839	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Déplacement PLF 2019 avis AGTE à Bensaçon	\N	2018-11-19 07:00:00	2018-11-19 18:30:00	\N	\N	1	0	\N	\N
328841	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions rapporteur AGTE 2019	\N	2018-11-22 10:00:00	2018-11-22 11:30:00	\N	\N	1	0	\N	\N
329083	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2018-11-26 09:05:00	2018-11-26 09:40:00	\N	\N	19	0	\N	\N
330924	DELEGATION	AUCUNE	\N	\N	211	Echange de vues sur la loi du 13 avril 2016 - QPC transmise au CC le 12 11 2018	Echange de vues sur la loi du 13 avril 2016 - QPC transmise au CC le 12 11 2018	2018-11-29 08:30:00	2018-11-29 10:30:00	2018-11-29 16:03:29	2018-11-29 16:37:47	12	0	\N	\N
330988	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2018-11-28 15:00:00	2018-11-28 16:55:00	\N	\N	3	0	\N	\N
332436	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-11-28 14:30:00	2018-11-28 19:00:00	\N	\N	2	0	\N	\N
332673	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2018-11-24 09:00:00	2018-11-24 10:05:00	\N	\N	19	0	\N	\N
332770	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2019 - Examen Amdts séance des articles non rattachés aux missions	PLF pour 2019 - Examen Amdts séance des articles non rattachés aux missions	2018-12-06 19:45:00	2018-12-06 20:40:00	2018-12-07 14:44:20	2018-12-07 15:22:44	18	0	\N	\N
332771	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2019-Examen Amdts séance missions Solidarité-Santé-GFPRH-CNR-ATP-RSR-IAI-Sécurité	PLF pour 2019-Examen Amdts séance missions Solidarité-Santé-GFPRH-CNR-ATP-RSR-IAI-Sécurité	2018-12-06 09:00:00	2018-12-06 09:25:00	2018-12-06 14:27:14	2018-12-06 14:52:54	20	0	\N	\N
332845	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition MM. Castaner et Nunez	\N	2018-12-04 16:30:00	2018-12-04 19:00:00	2018-12-05 12:34:08	2018-12-05 16:42:22	85	0	\N	\N
333404	COM_PERMANENTE	AUTRE	\N	CAE	\N	Communication sur le déplacement d'une délégation de la commission en Russie	Communication mission en Russie	2018-12-05 09:35:00	2018-12-05 10:30:00	2018-12-05 14:21:26	2018-12-05 16:42:19	25	0	\N	\N
333825	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière	Réunion plénière	2018-12-05 12:40:00	2018-12-05 13:50:00	2018-12-05 14:46:49	2018-12-05 16:45:41	17	0	\N	\N
333910	DELEGATION	DEPLACEMENT	\N	\N	ENTREPRISES	Déplacement à Caen	Déplacement à Caen pour la première des trois journées de la finale nationale  des 45ème	2018-11-29 08:00:00	2018-11-29 19:18:00	\N	\N	4	0	\N	\N
333915	DELEGATION	DEPLACEMENT	\N	\N	ENTREPRISES	Déplacement à Berlin - PME et Numérique	Déplacement à Berlin dans le cadre du rapport PME et Numérique	2018-12-18 18:00:00	2018-12-19 22:20:00	\N	\N	2	0	\N	\N
333921	DELEGATION	DEPLACEMENT	\N	\N	ENTREPRISES	Déplacement à Bruxelles - PME et Numérique	Déplacement à Bruxelles dans le cadre du rapport PME et Numérique	2018-10-26 07:25:00	2018-10-26 18:35:00	\N	\N	2	0	\N	\N
333926	DELEGATION	DEPLACEMENT	\N	\N	ENTREPRISES	Déplacement dans le Doubs	Déplacement dans le Doubs - Rencontre avec les entrepreneurs	2018-10-18 06:15:00	2018-10-18 20:37:00	\N	\N	6	0	\N	\N
333946	DELEGATION	DEPLACEMENT	\N	\N	ENTREPRISES	déplacement en Seine-Maritime	déplacement en Seine-Maritime -rencontre avec les entrepreneurs	2018-06-11 06:20:00	2018-06-11 20:40:00	\N	\N	8	0	\N	\N
333956	DELEGATION	DEPLACEMENT	\N	\N	ENTREPRISES	Déplacement dans la Creuse	Déplacement dans la Creuse - Rencontre avec les entrepreneurs	2018-05-25 06:50:00	2018-05-25 21:34:00	\N	\N	8	0	\N	\N
333967	DELEGATION	DEPLACEMENT	\N	\N	ENTREPRISES	Déplacement en Savoie	Déplacement en Savoie - Rencontre avec les entrepreneurs	2018-02-12 06:00:00	2018-02-12 21:19:00	\N	\N	7	0	\N	\N
333975	DELEGATION	DEPLACEMENT	\N	\N	ENTREPRISES	Déplacement en Côte-d'Or	Déplacement en Côte-d'Or - Rencontre avec les entrepreneurs	2017-12-15 06:15:00	2017-12-15 18:37:00	\N	\N	6	0	\N	\N
334410	MECSS	AUCUNE	\N	\N	MECSS	Mecss	Mecss	2018-12-12 15:00:00	2018-12-12 15:15:00	2018-12-12 15:15:44	2018-12-12 15:22:34	7	0	\N	\N
334446	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition + communication	\N	2018-12-12 10:00:00	2018-12-12 12:00:00	2018-12-12 14:04:41	2018-12-12 15:22:34	35	0	\N	\N
335622	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	Déplacement en Italie	Mission d'information sur la Sécurité des ponts - Déplacement en Italie	2018-12-02 14:30:00	2018-12-04 23:25:00	\N	\N	5	0	\N	\N
217936	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Cohésion des territoires	PLF pour 2018 - Cohésion des territoires - EPL et FPI	2017-11-13 10:45:00	2017-11-13 12:10:00	\N	\N	1	0	\N	\N
217938	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Cohésion des territoires	PLF pour 2018 - Cohésion des territoires - DGCS et fédération des ESH	2017-11-13 14:05:00	2017-11-13 16:00:00	\N	\N	1	0	\N	\N
227827	DELEGATION	AUCUNE	\N	\N	PROS	Réunion plénière	Echange de vues sur le programme de travail 2018	2017-12-14 08:30:00	2017-12-14 09:20:00	2017-12-14 09:57:15	2017-12-14 14:40:53	18	0	\N	\N
234842	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Organisation des JOP de 2024	PJL Organisation des JOP de 2024	2018-01-16 15:00:00	2018-01-16 15:30:00	\N	\N	4	0	\N	\N
234848	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Organisation des JOP de 2024	PJL Organisation des JOP de 2024	2018-01-16 15:30:00	2018-01-16 16:30:00	\N	\N	3	0	\N	\N
234852	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Organisation des JOP de 2024	PJL Organisation des JOP de 2024	2018-01-16 18:00:00	2018-01-16 20:10:00	\N	\N	4	0	\N	\N
332759	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2019 - Examen Amdts séance missions RCT et Enseignement Scolaire	PLF pour 2019 - Examen Amdts séance missions RCT et Enseignement Scolaire	2018-12-05 09:30:00	2018-12-05 10:35:00	2018-12-05 18:49:57	2018-12-06 11:18:25	45	0	\N	\N
227786	CMP	AUTRE	\N	PARIS	\N	PJL Création de l'établissement public Paris La Défense	PJL Création de l'établissement public Paris La Défense	2017-12-06 18:10:00	2017-12-06 18:45:00	\N	\N	9	0	\N	\N
234860	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Orientation et réussite des étudiants	PJL Orientation et réussite des étudiants	2018-01-16 18:00:00	2018-01-16 19:00:00	\N	\N	2	0	\N	\N
234867	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI contrats aidés	MI contrats aidés	2018-01-16 18:00:00	2018-01-16 19:30:00	\N	\N	2	0	\N	\N
234870	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Régime d'ouverture des établissements privés hors contrat	PPL Régime d'ouverture des établissements privés hors contrat	2018-01-16 16:00:00	2018-01-16 16:45:00	\N	\N	1	0	\N	\N
234880	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Régime d'ouverture des établissements privés hors contrat	PPL Régime d'ouverture des établissements privés hors contrat	2017-12-14 16:00:00	2017-12-14 17:00:00	\N	\N	1	0	\N	\N
234882	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Régime d'ouverture des établissements privés hors contrat	PPL Régime d'ouverture des établissements privés hors contrat	2017-12-21 10:15:00	2017-12-21 11:00:00	\N	\N	1	0	\N	\N
239079	COM_PERMANENTE	CONTROLE	\N	AFCL	\N	Rv avec le président	\N	2014-01-10 09:30:00	2014-01-10 11:30:00	\N	\N	0	0	\N	\N
239080	COM_PERMANENTE	CONTROLE	\N	AFCL	\N	Rv avec le président	\N	2014-01-10 09:30:00	2014-01-10 11:30:00	\N	\N	0	0	\N	\N
243266	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2018-02-06 15:00:00	2018-02-06 16:35:00	\N	\N	3	0	\N	\N
244271	COM_SPECIALE	AUDRAP	\N	SOCIETE	\N	\N	\N	2018-02-06 09:00:00	2018-02-06 10:45:00	\N	\N	1	0	\N	\N
244273	COM_SPECIALE	AUDRAP	\N	SOCIETE	\N	\N	\N	2018-02-06 14:30:00	2018-02-06 16:45:00	\N	\N	2	0	\N	\N
244276	COM_SPECIALE	AUDRAP	\N	SOCIETE	\N	\N	\N	2018-02-06 17:45:00	2018-02-06 19:15:00	\N	\N	2	0	\N	\N
244279	COM_SPECIALE	AUDRAP	\N	SOCIETE	\N	\N	\N	2018-02-08 09:00:00	2018-02-08 12:00:00	\N	\N	3	0	\N	\N
246404	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2018-02-20 18:00:00	2018-02-20 19:45:00	2018-02-21 14:37:10	2018-02-21 14:38:30	28	0	\N	\N
246405	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2018-02-21 09:35:00	2018-02-21 12:10:00	2018-02-21 14:37:45	2018-02-21 14:38:32	30	0	\N	\N
246406	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Mission "Routes de la soie"	\N	2018-02-14 14:40:00	2018-02-14 15:40:00	\N	\N	2	0	\N	\N
247194	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLO Qualité des études d'impact PPL Évaluation des politiques publiques et du bien-être	\N	2018-02-15 10:00:00	2018-02-15 11:10:00	\N	\N	1	0	\N	\N
247243	DELEGATION	AUCUNE	\N	\N	DSOM	Auditions Risques naturels majeurs dans les outre-mer	Auditions Risques naturels majeurs dans les outre-mer	2018-02-21 16:00:00	2018-02-21 19:20:00	2018-02-21 20:00:58	2018-02-22 09:43:19	11	0	\N	\N
249577	ETUDES	AUCUNE	\N	\N	\N	Réunion	Réunion	2018-02-21 08:30:00	2018-02-21 09:30:00	\N	\N	8	0	\N	1007
250867	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	Auditionconjointe FHF/FHP/Fehap/Unicancer	\N	2018-02-21 15:00:00	2018-02-21 16:30:00	\N	\N	0	0	\N	\N
250874	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	Institut national du cancer	\N	2018-02-21 16:30:00	2018-02-21 17:30:00	\N	\N	0	0	\N	\N
259029	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Tarification sociale de l'eau	\N	2018-03-20 17:45:00	2018-03-20 19:00:00	\N	\N	1	0	\N	\N
259031	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Tarification sociale de l'eau	\N	2018-03-21 17:00:00	2018-03-21 18:00:00	\N	\N	1	0	\N	\N
263770	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Nouveau pacte ferroviaire	PJL Nouveau pacte ferroviaire	2018-05-29 21:50:00	2018-05-30 00:35:00	\N	\N	97	0	\N	\N
263771	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Nouveau pacte ferroviaire	PJL Nouveau pacte ferroviaire	2018-05-30 16:00:00	2018-05-30 19:30:00	\N	\N	109	0	\N	\N
263772	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Nouveau pacte ferroviaire	PJL Nouveau pacte ferroviaire	2018-05-30 21:00:00	2018-05-31 01:25:00	\N	\N	85	0	\N	\N
263774	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Nouveau pacte ferroviaire	PJL Nouveau pacte ferroviaire	2018-05-31 10:30:00	2018-05-31 13:20:00	\N	\N	87	0	\N	\N
263775	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Nouveau pacte ferroviaire	PJL Nouveau pacte ferroviaire	2018-05-31 14:50:00	2018-05-31 20:00:00	\N	\N	72	0	\N	\N
263780	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Nouveau pacte ferroviaire	PJL Nouveau pacte ferroviaire	2018-05-31 21:30:00	2018-06-01 01:50:00	\N	\N	31	0	\N	\N
263850	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Présentation rapport d'information	Présentation rapport d'information sur l'accompagnement du cycle de vie des entreprises	2018-04-05 09:00:00	2018-04-05 10:15:00	2018-04-05 17:30:28	2018-04-06 14:33:37	21	0	\N	\N
267102	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Réunion d'adoption du rapport d'étape sur Alstom	\N	2018-04-18 18:00:00	2018-04-18 20:00:00	\N	\N	0	0	\N	\N
267352	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Mission "Régimes sociaux et de retraite" - Réforme des retraites	Contrôle 2018 - Mission "Régimes sociaux et de retraite" - Réforme des retraites - Paris school of economics	2018-04-10 17:45:00	2018-04-10 19:35:00	\N	\N	1	0	\N	\N
267353	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Mission "Régimes sociaux et de retraite" - Réforme des retraites	Contrôle 2018 - Mission "Régimes sociaux et de retraite" - Réforme des retraites - Régime de retraite additionnelle 	2018-04-10 14:30:00	2018-04-10 16:00:00	\N	\N	1	0	\N	\N
267356	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Aide alimentaire	Contrôle 2018 - Aide alimentaire - France AGRIMER	2018-04-11 16:30:00	2018-04-11 17:30:00	\N	\N	2	0	\N	\N
268710	COM_ENQUETE	PLENIERE	\N	HAUTE	\N	Réunion constitutive du 17 avril 2018	Réunion constitutive du 17 avril 2018	2018-04-17 17:35:00	2018-04-17 18:15:00	2018-04-18 19:22:02	2018-04-19 14:52:57	12	0	\N	\N
270137	ETUDES	AUCUNE	\N	\N	\N	G.E. "Agriculture et alimentation"	Audition de M. Dominique POTTIER	2018-04-11 08:00:00	2018-04-11 09:00:00	\N	\N	33	0	\N	919
270236	MISSION	AUDRAP	\N	ALSTOM	\N	MI ALSTOM - Auditions président&rapporteur	\N	2018-04-18 14:30:00	2018-04-18 15:00:00	\N	\N	2	0	\N	\N
270239	MISSION	AUDRAP	\N	ALSTOM	\N	MI ALSTOM - Auditions président&rapporteur	\N	2018-04-18 15:00:00	2018-04-18 16:00:00	\N	\N	3	0	\N	\N
270243	MISSION	AUDRAP	\N	ALSTOM	\N	MI ALSTOM - Auditions président&rapporteur	\N	2018-04-18 16:00:00	2018-04-18 18:00:00	\N	\N	5	0	\N	\N
270249	MISSION	AUDRAP	\N	ALSTOM	\N	MI ALSTOM - Auditions président&rapporteur	\N	2018-04-19 11:30:00	2018-04-19 12:30:00	\N	\N	5	0	\N	\N
270256	ETUDES	AUCUNE	\N	\N	\N	\N	\N	2018-04-18 08:00:00	2018-04-18 09:00:00	\N	\N	9	0	\N	912
270536	MECSS	AUDRAP	\N	\N	MECSS	\N	Accès précoce à l'innovation dans le domaine des produits de santé	2018-05-16 14:30:00	2018-05-16 16:00:00	\N	\N	3	0	\N	\N
270540	MECSS	AUDRAP	\N	\N	MECSS	\N	Accès précoce à l'innovation dans le domaine des produits de santé	2018-05-23 14:30:00	2018-05-23 15:30:00	\N	\N	3	0	\N	\N
273295	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2018-05-22 08:30:00	2018-05-22 10:30:00	2018-05-22 15:20:30	2018-05-23 16:02:27	34	0	\N	\N
289477	COM_ENQUETE	PLENIERE	\N	HAUTE	\N	Auditions	Auditions	2018-06-20 14:00:00	2018-06-20 19:00:00	\N	2018-06-25 14:29:40	8	0	\N	\N
292405	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière	Réunion plénière	2018-06-28 08:45:00	2018-06-28 09:15:00	2018-06-28 11:09:53	2018-06-28 11:15:10	8	0	\N	\N
292467	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion commune avec la Commission des Affaires européennes	Réunion commune avec la Commission des Affaires européennes	2018-06-28 09:15:00	2018-06-28 10:25:00	2018-06-28 11:29:41	2018-06-28 11:46:40	14	0	\N	\N
296075	DELEGATION	AUDRAP	\N	\N	206	Audition "Planète Mars" de l'Agence spatiale européenne (ESA)	Audition "Planète Mars" de Mme Sylvie Espinasse, coordination team leader - Agence spatiale européenne (ESA)	2018-07-12 16:30:00	2018-07-12 17:30:00	\N	\N	1	0	\N	\N
298201	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Avenir professionnel	PJL Avenir professionnel	2018-07-12 18:30:00	2018-07-12 20:00:00	\N	\N	44	0	\N	\N
311799	DELEGATION	DEPLACEMENT	\N	\N	206	Petit-déjeuner à l'Académie des Sciences Programmation pluriannuelle de l'énergie (PPE)	Petit-déjeuner à l'Académie des Sciences Programmation pluriannuelle de l'énergie (PPE)	2018-10-24 08:30:00	2018-10-24 10:30:00	\N	\N	1	0	\N	\N
311802	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière - Examen note sur huile de palme - Suite examen rapport bioéthique	Réunion plénière - Examen note sur huile de palme - Suite examen rapport bioéthique	2018-10-25 08:35:00	2018-10-25 12:05:00	2018-10-25 18:03:34	2018-10-25 18:03:42	18	0	\N	\N
311803	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière - Audition publique 5G 	Réunion plénière - Audition publique 5G 	2018-11-08 10:05:00	2018-11-08 12:45:00	2018-11-08 15:26:16	\N	9	0	\N	\N
311807	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2019 - AT-MP	\N	2018-10-16 15:00:00	2018-10-16 16:30:00	\N	\N	1	0	\N	\N
311809	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2019 - AT-MP	\N	2018-10-17 15:45:00	2018-10-17 18:00:00	\N	\N	2	0	\N	\N
311811	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2019 - Famille	\N	2018-10-17 16:00:00	2018-10-17 17:45:00	\N	\N	1	0	\N	\N
311922	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2019 - Famille	\N	2018-10-23 16:30:00	2018-10-23 17:30:00	\N	\N	2	0	\N	\N
311925	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2019 - Famille	\N	2018-10-24 14:00:00	2018-10-24 17:00:00	\N	\N	1	0	\N	\N
312038	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2019 - Assurance maladie	\N	2018-10-16 14:30:00	2018-10-16 16:15:00	\N	\N	2	0	\N	\N
312040	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2019 - Assurance maladie	\N	2018-10-17 15:30:00	2018-10-17 18:45:00	\N	\N	3	0	\N	\N
313953	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Cohésion des territoires-Logement et ville - CDD/Fondation Abbé-Pierre/AL	PLF pour 2019 - Cohésion des territoires - Logement et ville - CDD / Fondation Abbé-Pierre / AL	2018-10-15 09:15:00	2018-10-15 10:45:00	\N	\N	1	0	\N	\N
313980	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2019 - Programme 844	\N	2018-10-16 18:00:00	2018-10-16 19:10:00	\N	\N	2	0	\N	\N
313983	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2019 - Programme 129	\N	2018-10-18 10:30:00	2018-10-18 12:30:00	\N	\N	1	0	\N	\N
315206	GIA	AUCUNE	\N	\N	\N	Entretien avec une délégation de la commission de Sécurité nationale et de Défense du Parl	Entretien avec une délégation de la commission de Sécurité nationale et de Défense du Parlement lituanien, conduite par 	2018-10-23 13:00:00	2018-10-23 14:30:00	\N	\N	10	0	616	\N
315528	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2018-10-24 09:22:00	2018-10-24 11:15:00	2018-10-24 12:18:11	2018-10-24 13:00:18	43	1	\N	\N
315844	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2019 (mission "Travail et emploi")	\N	2018-10-18 10:00:00	2018-10-18 12:00:00	\N	\N	1	0	\N	\N
315845	COM_EURO	AUDRAP	\N	AFEU	\N	GT AFEU - Traité de l'Elysée	Audition de M. DEJOUANY, président de The Nesting Company	2018-10-23 08:30:00	2018-10-23 09:30:00	\N	\N	2	0	\N	\N
316278	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Cohésion des territoires - Logement et ville - USH et DHUP	PLF pour 2019 - Cohésion des territoires - Logement et ville - USH et DHUP	2018-10-23 08:30:00	2018-10-23 10:45:00	\N	\N	1	0	\N	\N
316290	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition du cabinet de la ministre de la cohésion des territoires	Audition du cabinet de la ministre de la cohésion des territoires (PPL création agence nationale cohésion territoires)	2018-10-25 19:00:00	2018-10-25 20:00:00	\N	\N	1	0	\N	\N
316327	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Enseignement supérieur	PLF 2019 - Crédits Enseignement supérieur	2018-10-24 14:00:00	2018-10-24 15:00:00	\N	\N	2	0	\N	\N
316330	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Enseignement supérieur	PLF 2019 - Crédits Enseignement supérieur	2018-10-24 15:00:00	2018-10-24 16:00:00	\N	\N	1	0	\N	\N
316332	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Enseignement supérieur	PLF 2019 - Crédits Enseignement supérieur	2018-10-24 16:00:00	2018-10-24 17:00:00	\N	\N	3	0	\N	\N
316336	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Sport	PLF 2019 - Crédits Sport	2018-10-24 14:00:00	2018-10-24 15:00:00	\N	\N	3	0	\N	\N
316389	DELEGATION	AUDRAP	\N	\N	206	Audition Groupe Renault (Arrêt des véhicules thermiques)	Audition Groupe Renault (Arrêt des véhicules thermiques)	2018-10-30 09:00:00	2018-10-30 10:00:00	\N	\N	1	0	\N	\N
316392	DELEGATION	AUDRAP	\N	\N	206	Audition Groupe PSA (Arrêt des véhicules thermiques)	Audition Groupe PSA (Arrêt des véhicules thermiques)	2018-10-30 10:00:00	2018-10-30 11:00:00	\N	\N	1	0	\N	\N
316395	DELEGATION	AUDRAP	\N	\N	206	Audition GrDF (Arrêt des véhicules thermiques)	Audition GrDF (Arrêt des véhicules thermiques)	2018-10-30 11:00:00	2018-10-30 12:00:00	\N	\N	1	0	\N	\N
317454	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Rapport général - FMI	PLF pour 2019 - Rapport général - FMI	2018-10-25 09:00:00	2018-10-25 10:00:00	\N	\N	2	0	\N	\N
317457	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Agriculture - MSA / CERFRANCE / Jeunes Agriculteurs	PLF pour 2019 - Agriculture - MSA / CERFRANCE / Jeunes Agriculteurs	2018-10-23 16:30:00	2018-10-23 19:30:00	\N	\N	1	0	\N	\N
317459	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Anciens combattants - Secrétaire d'État	PLF pour 2019 - Anciens combattants - Secrétaire d'État	2018-10-25 16:30:00	2018-10-25 18:30:00	\N	\N	1	0	\N	\N
317461	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - MIRES Recherche - CNRS	PLF pour 2019 - MIRES Recherche - CNRS	2018-10-24 18:30:00	2018-10-24 19:30:00	\N	\N	1	0	\N	\N
317463	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - MIRES Recherche - IFREMER	PLF pour 2019 - MIRES Recherche - IFREMER	2018-10-25 16:00:00	2018-10-25 17:00:00	\N	\N	1	0	\N	\N
317465	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFSS pour 2019 - FSV et DSS	PLFSS pour 2019 - FSV et DSS	2018-10-25 17:00:00	2018-10-25 19:00:00	\N	\N	1	0	\N	\N
317467	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Travail et emploi - Cabinet Ministère du travail	PLF pour 2019 - Travail et emploi - Cabinet Ministère du travail	2018-10-23 18:30:00	2018-10-23 20:30:00	\N	\N	2	0	\N	\N
317470	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Enseignement scolaire - DGRH et DAF Ministère Éducation Nationale	PLF pour 2019 - Enseignement scolaire - DGRH et DAF Ministère Éducation Nationale	2018-10-24 11:00:00	2018-10-24 12:10:00	\N	\N	1	0	\N	\N
317472	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Travail et emploi - Syndicats Pôle emploi	PLF pour 2019 - Travail et emploi - Syndicats Pôle emploi	2018-10-24 14:00:00	2018-10-24 15:00:00	\N	\N	2	0	\N	\N
317473	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2019 mission travail et emploi	\N	2018-10-30 14:00:00	2018-10-30 17:00:00	\N	\N	2	0	\N	\N
317474	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2019 mission travail et emploi	\N	2018-10-30 18:00:00	2018-10-30 19:00:00	\N	\N	1	0	\N	\N
317475	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2019 mission travail et emploi	\N	2018-10-31 14:00:00	2018-10-31 17:00:00	\N	\N	1	0	\N	\N
317476	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2019 mission travail et emploi	\N	2018-11-13 14:00:00	2018-11-13 15:00:00	\N	\N	1	0	\N	\N
317479	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2019 mission travail et emploi	\N	2018-11-14 14:00:00	2018-11-14 16:30:00	\N	\N	1	0	\N	\N
317480	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2019 mission travail et emploi	\N	2018-11-15 14:00:00	2018-11-15 15:00:00	\N	\N	0	0	\N	\N
317481	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Enseignement scolaire - DGESCO	PLF pour 2019 - Enseignement scolaire - DGESCO	2018-10-24 16:30:00	2018-10-24 17:30:00	\N	\N	1	0	\N	\N
213266	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 - Programme de contrôles	58-2 - Programme de contrôles - Cour des comptes	2017-10-26 11:00:00	2017-10-26 11:45:00	\N	\N	1	0	\N	\N
219964	DELEGATION	AUCUNE	\N	\N	206	Rapport annuel de la CNE	Présentation rapport annuel Commission nationale d'évaluation des recherches études gestion matières déchets radioactifs	2017-11-23 10:05:00	2017-11-23 12:10:00	2017-11-23 17:24:41	2017-11-23 17:59:41	11	0	\N	\N
220055	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Police de proximité	PPL Police de proximité	2017-12-13 14:30:00	2017-12-13 18:30:00	\N	\N	114	0	\N	\N
220056	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Fret ferroviaire	PPL Fret ferroviaire	2017-12-13 15:30:00	2017-12-13 18:05:00	\N	\N	72	0	\N	\N
220057	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat COP 23	Débat COP 23	2017-12-13 23:00:00	2017-12-14 00:45:00	\N	\N	48	0	\N	\N
220058	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Retour des djihadistes	Débat Retour des djihadistes	2017-12-13 21:00:00	2017-12-14 23:00:00	\N	\N	51	0	\N	\N
220059	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR Législation en commission	PPR Législation en commission	2017-12-14 10:30:00	2017-12-14 12:55:00	\N	\N	101	0	\N	\N
220060	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2017-12-14 15:00:00	2017-12-14 16:05:00	\N	\N	245	0	\N	\N
220062	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFR 2017	PLFR 2017	2017-12-14 18:30:00	2017-12-15 19:45:00	\N	\N	33	0	\N	\N
220063	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFR 2017 matin	PLFR 2017 matin	2017-12-15 09:30:00	2017-12-15 12:55:00	\N	\N	34	0	\N	\N
220064	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFR 2017 après-midi	PLFR 2017 après-midi	2017-12-15 14:30:00	2017-12-15 19:55:00	\N	\N	37	0	\N	\N
220069	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Établissement public Paris La Défense 	CMP Établissement public Paris La Défense 	2017-12-18 15:00:00	2017-12-18 15:40:00	\N	\N	21	0	\N	\N
220070	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Hydrocarbures soir	PJL Hydrocarbures soir	2017-12-18 15:50:00	2017-12-18 17:35:00	\N	\N	32	0	\N	\N
220072	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL UE Sécurité soir	PJL UE Sécurité soir	2017-12-18 18:00:00	2017-12-18 21:05:00	\N	\N	25	0	\N	\N
220073	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2018 après-midi 1	PLF 2018 après-midi 1	2017-12-19 14:30:00	2017-12-19 16:25:00	\N	\N	135	0	\N	\N
220074	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2018 après-midi 2	PLF 2018 après-midi 2	2017-12-19 17:45:00	2017-12-19 19:45:00	\N	\N	42	0	\N	\N
220076	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2017-12-19 16:45:00	2017-12-19 17:40:00	\N	\N	284	0	\N	\N
220077	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL UE / sécurité	PJL UE / sécurité	2017-12-19 19:45:00	2017-12-19 20:05:00	\N	\N	284	0	\N	\N
225446	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPRE Pérenniser la procédure de législation en commission	\N	2017-11-28 14:00:00	2017-11-28 15:20:00	\N	\N	1	0	\N	\N
225452	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPRE Pérenniser la procédure de législation en commission	\N	2017-11-28 18:00:00	2017-11-28 19:00:00	\N	\N	1	0	\N	\N
225457	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPRE Pérenniser la procédure de législation en commission	\N	2017-11-28 20:00:00	2017-11-28 20:20:00	\N	\N	1	0	\N	\N
233046	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Orientation et réussite des étudiants	PJL Orientation et réussite des étudiants	2018-01-09 09:30:00	2018-01-09 12:30:00	\N	\N	1	0	\N	\N
240531	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 1er février 2018	Réunion du 1er février 2018	2018-02-01 08:30:00	2018-02-01 10:40:00	2018-02-01 12:04:33	2018-02-01 20:08:28	21	0	\N	\N
247236	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	\N	GT Financement handicap	2018-02-20 18:00:00	2018-02-20 19:00:00	\N	\N	5	0	\N	\N
249803	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Service national universel	\N	2018-02-19 18:00:00	2018-02-19 19:15:00	\N	\N	5	0	\N	\N
249809	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Service national universel	\N	2018-02-21 16:00:00	2018-02-21 18:00:00	\N	\N	3	0	\N	\N
264637	COM_EURO	AUTRE_NON_PLENIERE	\N	AFEU	\N	Parlement de Lituanie	Rencontre avec une délégation du groupe d'amitié Lituanie-France du Parlement de Lituanie	2018-04-10 14:45:00	2018-04-10 15:30:00	\N	\N	3	0	\N	\N
267673	COM_ENQUETE	DEPLACEMENT	\N	FORCES	\N	Déplacement à Versailles-Satory	Déplacement à Versailles-Satory	2018-04-17 13:00:00	2018-04-17 18:00:00	\N	\N	5	0	\N	\N
268440	DELEGATION	AUCUNE	\N	\N	206	Présentation rapport de M. Cosnard, président Hcéres et Mme F. Sachwald, directrice OST 	Présentation du rapport de M. Cosnard, président du Hcéres et de Mme F. Sachwald, directrice OST 	2018-05-17 09:40:00	2018-05-17 12:30:00	2018-05-17 16:27:34	2018-05-18 18:22:38	13	0	\N	\N
268443	DELEGATION	AUCUNE	\N	\N	206	Audition publique sur l'avenir du nucléaire	Audition publique sur les "Nouvelles tendances de la recherche sur l'énergie - I - L'avenir du nucléaire"	2018-05-24 09:10:00	2018-05-24 13:40:00	2018-05-29 16:24:24	2018-06-13 14:26:11	11	0	\N	\N
268444	DELEGATION	AUCUNE	\N	\N	206	Audition publique sur l'hypersensibilité électromagnétique	Audition publique sur le thème de l'hypersensibilité électromagnétique	2018-05-31 09:30:00	2018-05-31 13:45:00	2018-05-31 16:21:02	2018-05-31 16:24:18	10	0	\N	\N
273863	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Bilan de l'application des lois	Débat Bilan de l'application des lois	2018-06-05 16:15:00	2018-06-05 17:45:00	\N	\N	82	0	\N	\N
273865	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Transport fluvial	Débat Transport fluvial	2018-06-05 18:00:00	2018-06-05 19:30:00	\N	\N	61	0	\N	\N
273866	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Sécurité routière	Débat Sécurité routière	2018-06-05 21:30:00	2018-06-05 23:25:00	\N	\N	78	0	\N	\N
273877	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Analyses génétiques sur personnes décédées	PPL Analyses génétiques sur personnes décédées	2018-06-06 14:30:00	2018-06-06 15:15:00	\N	\N	64	0	\N	\N
273878	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Carte combattant soldats engagés en Algérie	PPL Carte combattant soldats engagés en Algérie	2018-06-06 15:15:00	2018-06-06 16:00:00	\N	\N	69	0	\N	\N
273879	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPRE Politique agricole commune forte	PPRE Politique agricole commune forte	2018-06-06 16:05:00	2018-06-06 20:00:00	\N	\N	100	0	\N	\N
273881	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR Prévention conflits d'intérêts Sénateurs	PPR Prévention conflits d'intérêts Sénateurs	2018-06-06 21:00:00	2018-06-06 22:30:00	\N	\N	74	0	\N	\N
273883	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2018-06-07 15:00:00	2018-06-07 16:05:00	\N	\N	228	0	\N	\N
273884	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Transmission d'entreprise	PPL Transmission d'entreprise	2018-06-07 16:15:00	2018-06-07 20:00:00	\N	\N	51	0	\N	\N
335730	DELEGATION	AUDRAP	\N	\N	PROS	Audition de la FNSEA	\N	2018-12-19 11:30:00	2018-12-19 12:30:00	\N	\N	2	0	\N	\N
336154	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2018-12-12 09:30:00	2018-12-12 11:10:00	2018-12-12 12:23:45	2018-12-12 13:40:54	36	0	\N	\N
336478	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2018-12-12 09:35:00	2018-12-12 12:50:00	2018-12-12 16:12:43	2018-12-12 16:13:27	39	0	\N	\N
336541	DELEGATION	AUDRAP	\N	\N	206	Audition ADEME (Stockage de l'électricité)	Audition ADEME (Stockage de l'électricité)	2018-12-17 15:00:00	2018-12-17 16:30:00	\N	\N	1	0	\N	\N
336544	DELEGATION	AUDRAP	\N	\N	206	Audition Syndicat des énergies renouvelables (Stockage de l'électricité)	Audition Syndicat des énergies renouvelables (Stockage de l'électricité)	2018-12-19 14:30:00	2018-12-19 15:45:00	\N	\N	1	0	\N	\N
336708	GIA	AUCUNE	\N	\N	\N	Assemblée générale	Audition de Mme Marianne Beseme, secrétaire générale de l'OFQJ	2018-12-12 08:00:00	2018-12-12 09:00:00	\N	\N	8	0	602	\N
336828	GIA	AUCUNE	\N	\N	\N	Petit-déjeuner du groupe d'amitié France-Hongrie	Petit-déjeuner avec l'ambassadeur de Hongrie en France	2018-12-12 08:15:00	2018-12-12 09:30:00	\N	\N	5	0	592	\N
336976	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Andrej Slapnicar, ambassadeur de Slovénie	Entretien avec M. Andrej Slapnicar, ambassadeur de Slovénie	2018-12-12 12:45:00	2018-12-12 14:15:00	\N	\N	3	0	529	\N
337065	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2018-12-19 16:35:00	2018-12-19 18:55:00	2018-12-19 19:09:58	2018-12-20 15:38:23	44	0	\N	\N
337095	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2018-12-19 09:15:00	2018-12-19 11:55:00	2018-12-21 10:35:34	2018-12-21 16:21:54	34	0	\N	\N
337096	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2018-12-19 16:35:00	2018-12-19 18:55:00	2018-12-21 10:10:49	2018-12-21 16:21:53	44	0	\N	\N
337447	COM_SPECIALE	PLENIERE	\N	ENTREPRISES	\N	Réunion 20181212	\N	2018-12-12 18:15:00	2018-12-12 20:10:00	2018-12-12 20:08:57	2018-12-13 16:00:17	26	0	\N	\N
337745	GIA	AUCUNE	\N	\N	\N	Entretien avec une délégation de l'Assemblée populaire nationale de Chine	Commission des affires ethniques de l'APN	2018-12-12 14:30:00	2018-12-12 16:00:00	\N	\N	5	0	584	\N
337754	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion commune avec la Commission des affaires sociales	Réunion commune avec la Commission des affaires sociales - Présentation du rapport de  l'OFCE sur les contrats courts	2018-12-13 09:10:00	2018-12-13 10:45:00	2018-12-13 11:42:52	2018-12-14 11:25:49	25	0	\N	\N
338180	GIA	AUCUNE	\N	\N	\N	Diner avec l'ambassadeur de Pologne 	Diner avec l'ambassadeur de Pologne  organisé par l'Institut de recherche et de communication sur l'Europe	2018-12-12 20:00:00	2018-12-12 22:45:00	\N	\N	1	0	600	\N
338264	GIA	AUCUNE	\N	\N	\N	Entretien de M. Jean-Yves LECONTE avec délégation ukrainienne (coopé)	Entretien de M. Jean-Yves LECONTE avec délégation ukrainienne (coopé)	2018-12-14 11:00:00	2018-12-15 11:30:00	\N	\N	1	0	530	\N
338267	GIA	AUCUNE	\N	\N	\N	Entretien sur le Dialogue de Trianon	Entretien sur le Dialogue de Trianon	2018-12-13 08:00:00	2018-12-13 09:30:00	\N	\N	6	0	608	\N
339475	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2018-12-18 14:35:00	2018-12-18 16:30:00	\N	\N	3	0	\N	\N
339520	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	PJL Croissance et transformation des entreprises	\N	2018-12-18 09:00:00	2018-12-18 11:00:00	\N	\N	1	0	\N	\N
339549	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	PJL Croissance et transformation des entreprises	\N	2018-12-18 18:15:00	2018-12-19 19:00:00	\N	\N	1	0	\N	\N
339691	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2018-12-13 12:20:00	2018-12-13 12:30:00	\N	\N	3	0	\N	\N
340307	GIA	AUCUNE	\N	\N	\N	Visite du centre culturel irlandais	Visite du centre culturel irlandais	2018-11-28 19:30:00	2018-11-28 21:00:00	\N	\N	5	0	594	\N
340391	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2019-01-16 09:30:00	2019-01-16 11:00:00	2019-01-16 10:57:47	2019-01-16 11:15:35	46	0	\N	\N
340392	DELEGATION	AUDRAP	\N	\N	PROS	Audition de la FNAU	\N	2019-01-15 09:00:00	2019-01-15 10:00:00	\N	\N	1	0	\N	\N
340395	DELEGATION	AUDRAP	\N	\N	PROS	Audition EDF	\N	2019-01-17 11:00:00	2019-01-17 12:15:00	\N	\N	2	0	\N	\N
321354	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF2019	PLF2019	2018-11-30 21:35:00	2018-12-01 00:00:00	\N	\N	28	0	\N	\N
340388	COM_PERMANENTE	AUTRE	\N	SOCI	\N	réunion plénière	\N	2019-01-16 08:30:00	2019-01-16 09:30:00	2019-01-16 10:52:24	2019-01-16 11:15:34	51	0	\N	\N
340397	DELEGATION	AUCUNE	\N	\N	PROS	Audition de Mme Brune POIRSON, Secrétaire d'Etat	Audition Brune Poirson, Secrétaire d¿État auprès du Ministre d¿État, ministre de la Transition écologique et solidaire	2019-01-17 08:30:00	2019-01-17 09:45:00	2019-01-17 10:47:33	2019-01-17 11:57:21	19	0	\N	\N
340399	DELEGATION	AUDRAP	\N	\N	PROS	Auditiond de Jacques Sapir	\N	2019-01-17 16:30:00	2019-01-17 18:30:00	\N	\N	1	0	\N	\N
340400	DELEGATION	AUDRAP	\N	\N	PROS	Audition de Martine Orange	\N	2019-01-14 14:00:00	2019-01-14 15:05:00	\N	\N	1	0	\N	\N
340403	DELEGATION	AUDRAP	\N	\N	PROS	Audition de Henri Sterdyniak	\N	2019-01-18 10:00:00	2019-01-18 11:00:00	\N	\N	1	0	\N	\N
340404	DELEGATION	AUDRAP	\N	\N	PROS	Audition de Patrick Artus	\N	2019-01-18 16:30:00	2019-01-18 17:30:00	\N	\N	1	0	\N	\N
340405	DELEGATION	AUDRAP	\N	\N	PROS	Audition de Pierre-Charles Pradier	\N	2019-01-30 14:30:00	2019-01-30 16:00:00	\N	\N	1	0	\N	\N
340427	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière-Note Lanceurs spatiaux-Désign. Rapp. -Audition publique expérim. animale	Exam. note Lanceurs spatiaux-Désign. rapp. Valorisation énergétique terres agricoles-Audition pub. expériment. animale	2019-01-17 09:00:00	2019-01-17 13:40:00	2019-01-21 10:28:41	\N	12	0	\N	\N
340428	GIA	AUCUNE	\N	\N	\N	Entretien avec S. Exc. l'Ambassadeur des Philippines à Paris	Entretien avec S. Exc. Mme Teresa Ma LAZARO, Ambassadeur des Philippines en France	2018-12-12 12:45:00	2018-12-12 14:15:00	\N	\N	2	0	609	\N
340431	GIA	AUCUNE	\N	\N	\N	Petit-déjeuner AIFC en présence ambassadrice Canada	Petit-déjeuner AIFC à l'AN  en présence de l'ambassadrice du Canada, Isabelle Hudon	2018-10-24 08:30:00	2018-10-24 10:00:00	\N	\N	1	0	583	\N
340442	GIA	AUCUNE	\N	\N	\N	Déjeuner à l'ambassade du Vietnam	Déjeuner à l'ambassade du Vietnam	2018-12-12 12:30:00	2018-12-12 14:00:00	\N	\N	6	0	626	\N
340467	DELEGATION	AUDRAP	\N	\N	PROS	Audition de la Caisse des dépôts	\N	2019-01-15 14:00:00	2019-01-15 15:00:00	\N	\N	1	0	\N	\N
340468	DELEGATION	AUDRAP	\N	\N	PROS	Audition de M. François Gemenne	\N	2019-01-15 15:00:00	2019-01-15 16:00:00	\N	\N	1	0	\N	\N
340469	DELEGATION	AUDRAP	\N	\N	PROS	Audition de la Direction de l¿habitat de l¿urbanisme et des paysages 	\N	2019-01-15 10:00:00	2019-01-15 11:00:00	\N	\N	1	0	\N	\N
340471	DELEGATION	AUDRAP	\N	\N	PROS	Audition de la Fédération française de l'Assurance	\N	2019-02-12 17:30:00	2019-02-12 19:15:00	\N	\N	1	0	\N	\N
340473	DELEGATION	AUCUNE	\N	\N	DSOM	Audition de Delphine Ernotte, présidente de France Télévisions	Audition de Delphine Ernotte, présidente de France Télévisions	2019-01-22 15:00:00	2019-01-22 16:50:00	2019-01-22 17:36:37	2019-01-22 17:39:32	13	0	\N	\N
340474	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Création d'un droit voisin au profit des agences et éditeurs de presse	PPL Création d'un droit voisin au profit des agences et éditeurs de presse	2019-01-09 14:30:00	2019-01-09 16:00:00	\N	\N	4	0	\N	\N
340555	DELEGATION	AUDRAP	\N	\N	PROS	Audition de la Fédération bancaire française	\N	2019-02-05 10:00:00	2019-02-05 11:00:00	\N	\N	2	0	\N	\N
340563	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Auditions de candidats pour siéger au Conseil supérieur de la magistrature	Auditions de candidats pour siéger au Conseil supérieur de la magistrature	2019-01-15 14:30:00	2019-01-15 17:15:00	2019-01-15 18:53:38	2019-01-16 11:15:36	30	0	\N	\N
340564	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Affaire Benalla - Auditions de Patrick Strzoda, Christophe Castaner et Jean-Yves Le Drian	Affaire Benalla - Auditions de Patrick Strzoda, Christophe Castaner et Jean-Yves Le Drian	2019-01-16 15:05:00	2019-01-16 19:40:00	2019-01-16 20:14:44	2019-01-17 11:58:12	50	0	\N	\N
340626	COM_PERMANENTE	AUTRE	\N	SOCI	\N	audition Catherine Geindre	\N	2019-01-23 09:30:00	2019-01-23 11:45:00	2019-01-23 11:45:07	2019-01-23 11:47:00	39	0	\N	\N
341450	ETUDES	AUCUNE	\N	\N	\N	G.E. "Elevage"	G.E. "Elevage"	2019-01-16 08:00:00	2019-01-16 09:00:00	\N	\N	18	0	\N	911
341594	ETUDES	AUCUNE	\N	\N	\N	Audition UDES	Audition UDES	2019-01-16 13:30:00	2019-01-16 15:00:00	\N	\N	9	0	\N	998
341909	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-01-17 09:10:00	2019-01-17 10:50:00	2019-01-17 11:36:35	2019-01-17 11:58:13	31	0	\N	\N
341936	COM_SPECIALE	PLENIERE	\N	ENTREPRISES	\N	Réunion 20190117a	\N	2019-01-17 09:30:00	2019-01-17 11:15:00	2019-01-17 11:21:42	2019-01-17 11:56:37	32	0	\N	\N
341956	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière Examen note Biodiversité-Auditions menaces captation savoirs-ZRR	Examen note Biodiversité - Audition menaces captation de savoirs - Audition ZRR	2019-01-24 08:40:00	2019-01-24 13:30:00	2019-01-24 17:59:39	\N	8	0	\N	\N
213320	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pout 2018 - Justice	PLF pout 2018 - Justice - DINSIC et ministère de la justice	2017-10-25 14:40:00	2017-10-25 16:50:00	\N	\N	1	0	\N	\N
213322	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Justice	PLF pour 2018 - Justice - Ministère de la Justice	2017-10-26 14:15:00	2017-10-26 15:05:00	\N	\N	1	0	\N	\N
213374	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2018 - Programme 152	\N	2017-10-26 10:00:00	2017-10-26 12:00:00	\N	\N	2	0	\N	\N
213377	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2018 - Programmes 110 et 209 	\N	2017-10-26 12:00:00	2017-10-26 13:00:00	\N	\N	2	0	\N	\N
213383	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Médias	PLF pour 2018 - Médias - France Televisions	2017-10-27 15:00:00	2017-10-27 16:00:00	\N	\N	1	0	\N	\N
213385	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Sécurités "Police nationale " et "Gendarmerie nationale"	PLF pour 2018 - Sécurités "Police nationale " et "Gendarmerie nationale" - Prefet de police de Paris	2017-10-27 15:00:00	2017-10-27 16:00:00	\N	\N	1	0	\N	\N
213387	GIA	AUCUNE	\N	\N	\N	Déjeuner avec la présidente du groupe d'amitié France-Ukraine de l'Assemblée nationale	\N	2017-10-24 08:00:00	2017-10-24 09:00:00	\N	\N	1	0	530	\N
214871	GIA	AUCUNE	\N	\N	\N	Interview de Mme Catherine MORIN-DESAILLY par une équipe de télévision égyptienne	Interview de Mme Catherine MORIN-DESAILLY par une équipe de télévision égyptienne	2017-10-24 16:30:00	2017-10-24 17:00:00	\N	\N	1	0	617	\N
214877	GIA	AUCUNE	\N	\N	\N	Accueil délégation suisse	Accueil d'une délégation en charge des relations avec le Parlement français du Parlement fédéral suisse	2017-11-06 12:05:00	2017-11-07 17:30:00	\N	\N	6	0	610	\N
217454	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2018	\N	2017-11-07 19:00:00	2017-11-07 20:00:00	\N	\N	1	0	\N	\N
217456	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2018	\N	2017-11-08 08:30:00	2017-11-08 09:30:00	\N	\N	1	0	\N	\N
217458	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2018	\N	2017-11-09 08:30:00	2017-11-09 12:30:00	\N	\N	1	0	\N	\N
217465	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2018	\N	2017-11-08 14:30:00	2017-11-08 15:30:00	\N	\N	1	0	\N	\N
217581	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen rapport Nlle lect. PLFR pour 2017 - PLF pour 2018 Justice et Solidarité	Examen rapport Nlle lect. PLFR pour 2017 - PLF pour 2018 Missions Justice et Solidarité	2017-11-14 09:05:00	2017-11-14 10:35:00	2017-11-15 09:03:07	2017-11-15 09:39:57	27	1	\N	\N
217582	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2018 Enseignement scolaire	PLF pour 2018 Mission Enseignement scolaire	2017-11-14 17:45:00	2017-11-14 18:35:00	2017-11-15 09:02:46	2017-11-15 09:39:54	19	1	\N	\N
340472	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-01-16 10:05:00	2019-01-16 11:00:00	2019-01-16 14:19:43	2019-01-16 14:54:08	44	0	\N	\N
217584	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2018 - Participation financières État-AGTE-Sécurités	PLF pour 2018 - Missions Participation financières de l'État-AGTE-Sécurités	2017-11-15 14:35:00	2017-11-15 17:50:00	2017-11-16 09:48:06	2017-11-16 11:37:48	35	0	\N	\N
217585	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2018 - Médias-Action Extérieure de l'État-Économie	PLF pour 2018 - Missions Médias-Action Extérieure de l'État-Économie	2017-11-16 10:35:00	2017-11-16 13:00:00	2017-11-17 16:23:25	2017-11-17 16:25:34	31	0	\N	\N
217672	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF 2018 - Avis Prévention des risques	PLF 2018 - Avis Prévention des risques	2017-11-06 14:15:00	2017-11-06 17:30:00	\N	\N	1	0	\N	\N
217674	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF 2018 - Avis Cohésion des territoires	PLF 2018 - Avis Cohésion des territoires	2017-11-07 08:30:00	2017-11-07 10:30:00	\N	\N	1	0	\N	\N
217676	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF 2018 - Avis Biodiversité et Transition énergétique	PLF 2018 - Avis Biodiversité et Transition énergétique	2017-11-07 10:00:00	2017-11-07 10:45:00	\N	\N	1	0	\N	\N
217678	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF 2018 - Avis Biodiversité et Transition énergétique	PLF 2018 - Avis Biodiversité et Transition énergétique	2017-11-07 11:45:00	2017-11-07 12:30:00	\N	\N	1	0	\N	\N
217680	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF 2018 - Avis sur la première partie	PLF 2018 - Avis sur la première partie	2017-11-07 15:30:00	2017-11-07 16:30:00	\N	\N	1	0	\N	\N
217682	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF 2018 - Avis transports routiers et ferroviaires	\N	2017-11-08 15:00:00	2017-11-08 16:00:00	\N	\N	1	0	\N	\N
217685	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF 2018 - Avis sur la première partie	\N	2017-11-08 15:30:00	2017-11-08 18:45:00	\N	\N	1	0	\N	\N
217687	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF 2018 - Avis Recherche	PLF 2018 - Avis Recherche	2017-11-09 09:00:00	2017-11-09 10:00:00	\N	\N	1	0	\N	\N
217689	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF 2018 - Avis Recherche	\N	2017-11-14 09:30:00	2017-11-14 10:30:00	\N	\N	1	0	\N	\N
217691	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF 2018 - Avis Recherche	\N	2017-11-14 14:00:00	2017-11-14 16:15:00	\N	\N	1	0	\N	\N
217693	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF 2018 - Avis Transports aériens	PLF 2018 - Avis Transports aériens	2017-11-14 14:15:00	2017-11-14 16:00:00	\N	\N	1	0	\N	\N
217695	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF 2018 - Avis Transports aériens	\N	2017-11-14 19:30:00	2017-11-14 20:30:00	\N	\N	1	0	\N	\N
217697	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF 2018 - Avis Transports aériens	\N	2017-11-15 14:00:00	2017-11-15 17:00:00	\N	\N	1	0	\N	\N
218821	DELEGATION	AUCUNE	\N	\N	PROS	Auditions	Auditions	2017-12-07 08:35:00	2017-12-07 09:55:00	2017-12-07 10:34:10	2017-12-07 11:02:25	20	0	\N	\N
223368	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	\N	\N	2017-11-20 16:30:00	2017-11-20 17:30:00	\N	\N	1	0	\N	\N
223370	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Visite délégation étrangère	\N	2017-11-22 17:15:00	2017-11-22 18:15:00	\N	\N	5	0	\N	\N
223376	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2018 - Programme 144	\N	2017-11-23 17:30:00	2017-11-23 18:30:00	\N	\N	1	0	\N	\N
233118	COM_PERMANENTE	AUTRE	\N	LOIS	\N	\N	\N	2018-01-18 09:30:00	2018-01-18 10:45:00	2018-01-18 11:24:31	2018-01-18 14:56:13	33	0	\N	\N
236356	GIA	AUCUNE	\N	\N	\N	assemblée générale	désignation des membres du Bureau	2018-01-23 14:20:00	2018-01-23 14:50:00	\N	\N	7	0	653	\N
240277	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Réussite étudiants après-midi	PJL Réussite étudiants après-midi	2018-02-07 14:35:00	2018-02-07 16:40:00	\N	\N	146	0	\N	\N
240278	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Rapport Cour des comptes	Rapport Cour des comptes	2018-02-08 10:30:00	2018-02-08 11:25:00	\N	\N	131	0	\N	\N
240279	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Réussite étudiants matin	PJL Réussite étudiants matin	2018-02-08 11:35:00	2018-02-08 13:00:00	\N	\N	71	0	\N	\N
240280	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Réussite étudiants après-midi	PJL Réussite étudiants après-midi	2018-02-08 14:30:00	2018-02-08 19:05:00	\N	\N	62	0	\N	\N
240282	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2018-02-13 09:30:00	2018-02-13 12:10:00	\N	\N	43	0	\N	\N
240283	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJLO Nouvelle Calédonie après-midi	PJLO Nouvelle Calédonie après-midi	2018-02-13 14:30:00	2018-02-13 16:25:00	\N	\N	108	0	\N	\N
240285	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PJL Dialogue social 	CMP PJL Dialogue social 	2018-02-14 14:30:00	2018-02-14 21:00:00	\N	\N	84	0	\N	\N
240286	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PJL DADUE Sécurité	CMP PJL DADUE Sécurité	2018-02-14 15:00:00	2018-02-14 21:00:00	\N	\N	72	0	\N	\N
240289	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP¨PJL Environnement	CMP¨PJL Environnement	2018-02-15 10:35:00	2018-02-15 11:40:00	\N	\N	57	0	\N	\N
240291	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2018-02-15 15:00:00	2018-02-15 16:10:00	\N	\N	275	0	\N	\N
305517	COM_EURO	AUDRAP	\N	AFEU	\N	Retour au taux réduit de TVA pour la filière équine	Retour au taux réduit de TVA pour la filière équine - Audition de représentants des entraîneurs et des éleveurs	2018-09-12 10:30:00	2018-09-12 12:35:00	\N	\N	1	0	\N	\N
305522	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2018-09-19 14:30:00	2018-09-19 16:30:00	2018-09-19 17:45:55	2018-09-20 14:21:48	26	1	\N	\N
305523	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 2018 - Très grandes infrastructures de recherche - Audition Cour des Comptes	58-2 2018 - Très grandes infrastructures de recherche - Audition Cour des Comptes	2018-09-12 10:30:00	2018-09-12 11:45:00	\N	\N	1	0	\N	\N
317483	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Travail et emploi - DGEFP	PLF pour 2019 - Travail et emploi - DGEFP	2018-10-25 14:00:00	2018-10-25 15:00:00	\N	\N	2	0	\N	\N
217583	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2018 - Examen articles 1ère partie (Tome II)	PLF pour 2018 - Examen articles 1ère partie (Tome II)	2017-11-15 08:35:00	2017-11-15 10:40:00	2017-11-15 18:31:23	2017-11-16 08:15:56	43	0	\N	\N
233068	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Application du régime d'asile européen	\N	2018-01-17 10:05:00	2018-01-17 11:10:00	2018-01-17 12:24:30	2018-01-17 16:08:02	41	0	\N	\N
317487	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Travail et emploi - ANACT	PLF pour 2019 - Travail et emploi - ANACT	2018-10-26 13:30:00	2018-10-26 14:30:00	\N	\N	1	0	\N	\N
317489	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Travail et emploi - Direction générale du travail	PLF pour 2019 - Travail et emploi - Direction générale du travail	2018-10-26 15:30:00	2018-10-26 16:35:00	\N	\N	1	0	\N	\N
318541	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Écologie/Transports - AFITF	PLF pour 2019 - Écologie/Transports - AFITF	2018-10-30 12:30:00	2018-10-30 14:00:00	\N	\N	1	0	\N	\N
318602	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Écologie/Énergie - DGEC	PLF pour 2019 - Écologie/Énergie - DGEC	2018-10-31 15:30:00	2018-10-31 16:30:00	\N	\N	1	0	\N	\N
318672	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Nomination de rapporteurs et examen rapport d'information Revitaliser l'échelon communal	Nomination de rapporteurs & examen RI Revitaliser l'échelon communal	2018-11-07 09:10:00	2018-11-07 11:45:00	2018-11-07 16:37:53	2018-11-07 16:38:27	37	1	\N	\N
318809	GIA	AUCUNE	\N	\N	\N	Rencontre Président du Parlement tibétain en exil	Rencontre Président du Parlement tibétain en exil	2018-11-22 08:30:00	2018-11-22 10:00:00	\N	\N	2	0	634	\N
318810	GIA	AUCUNE	\N	\N	\N	Rencontre K.Buffetrille (à l'Assemblée nationale)	Rencontre K.Buffetrille (à l'Assemblée nationale)	2018-12-05 08:30:00	2018-12-05 10:00:00	\N	\N	1	0	634	\N
318820	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 -  Solidarité - Direction du budget	PLF pour 2019 -  Solidarité - Direction du budget	2018-10-30 18:00:00	2018-10-30 19:00:00	\N	\N	2	0	\N	\N
318848	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Économie - CCI France et  France Très haut débit	PLF pour 2019 - Économie - CCI France et  France Très haut débit	2018-10-31 10:00:00	2018-10-31 12:00:00	\N	\N	2	0	\N	\N
318864	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Culture - Musées Nationaux et Grand Palais	PLF pour 2019 - Culture - Musées Nationaux et Grand Palais	2018-10-30 15:00:00	2018-10-30 16:00:00	\N	\N	1	0	\N	\N
318867	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Culture - Patrimoine	PLF pour 2019 - Culture - Patrimoine	2018-10-31 16:00:00	2018-10-31 16:30:00	\N	\N	1	0	\N	\N
318988	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition M. Mouiller	\N	2018-11-06 14:00:00	2018-11-06 16:15:00	\N	\N	2	0	\N	\N
318989	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Mission solidarité	\N	2018-11-13 14:00:00	2018-11-13 16:15:00	\N	\N	1	0	\N	\N
318990	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2019 Mission solidarité	\N	2018-11-20 13:45:00	2018-11-20 14:30:00	\N	\N	1	0	\N	\N
318991	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2019 Mission solidarité	\N	2018-11-20 16:15:00	2018-11-20 17:00:00	\N	\N	2	0	\N	\N
318996	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2019 - Avis Immigration, asile et intégration	\N	2018-10-31 15:40:00	2018-10-31 16:30:00	\N	\N	2	0	\N	\N
319335	COM_SPECIALE	PLENIERE	\N	ENTREPRISES	\N	Réunion 20181107	\N	2018-11-07 14:20:00	2018-11-07 16:00:00	2018-11-07 18:23:33	2018-11-08 15:44:53	23	0	\N	\N
319336	COM_SPECIALE	PLENIERE	\N	ENTREPRISES	\N	Réunion 20181107b	\N	2018-11-07 16:00:00	2018-11-07 17:50:00	2018-11-07 18:24:54	2018-11-08 15:44:54	22	0	\N	\N
319338	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2018-11-06 14:00:00	2018-11-06 14:10:00	2018-11-06 14:43:38	2018-11-06 15:36:22	27	3	\N	\N
319339	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2018-11-06 16:50:00	2018-11-06 18:40:00	2018-11-06 18:54:22	2018-11-07 10:34:09	25	3	\N	\N
319497	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2018-11-07 10:30:00	2018-11-07 12:10:00	2018-11-07 16:46:38	2018-11-07 16:57:41	34	0	\N	\N
320524	BUREAU	AUCUNE	\N	\N	\N	Bureau du Sénat	Bureau du Sénat	2018-11-07 09:30:00	2018-11-07 11:45:00	\N	\N	19	0	\N	\N
321318	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF2019	PLF2019	2018-11-22 11:00:00	2018-11-22 13:00:00	\N	\N	121	0	\N	\N
321319	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF2019	PLF2019	2018-11-22 16:15:00	2018-11-22 19:15:00	\N	\N	88	0	\N	\N
321323	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2018-11-22 15:00:00	2018-11-22 16:05:00	\N	\N	271	0	\N	\N
321327	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF2019	PLF2019	2018-11-23 14:30:00	2018-11-23 18:10:00	\N	\N	50	0	\N	\N
321331	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF2019	PLF2019	2018-11-24 10:20:00	2018-11-24 10:25:00	\N	\N	10	0	\N	\N
321340	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF2019	PLF2019	2018-11-26 14:30:00	2018-11-26 20:25:00	\N	\N	91	0	\N	\N
321341	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF2019	PLF2019	2018-11-26 22:00:00	2018-11-27 01:40:00	\N	\N	74	0	\N	\N
321342	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFR 2018 Nouvelle lecture	PLFR 2018 Nouvelle lecture	2018-11-27 14:30:00	2018-11-27 15:35:00	\N	\N	112	0	\N	\N
321343	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF2019	PLF2019	2018-11-27 18:00:00	2018-11-27 20:05:00	\N	\N	126	0	\N	\N
321344	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF2019	PLF2019	2018-11-27 21:35:00	2018-11-28 01:30:00	\N	\N	108	0	\N	\N
321345	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2018-11-27 16:45:00	2018-11-27 17:50:00	\N	\N	301	0	\N	\N
321346	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF2019	PLF2019	2018-11-28 10:35:00	2018-11-28 13:00:00	\N	\N	120	0	\N	\N
321347	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF2019	PLF2019	2018-11-28 14:30:00	2018-11-28 19:55:00	\N	\N	171	0	\N	\N
321348	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF2019	PLF2019	2018-11-28 21:30:00	2018-11-29 01:25:00	\N	\N	91	0	\N	\N
321349	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF2019	PLF2019	2018-11-29 10:30:00	2018-11-29 13:05:00	\N	\N	83	0	\N	\N
321350	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF2019	PLF2019	2018-11-29 14:35:00	2018-11-29 20:40:00	\N	\N	98	0	\N	\N
321351	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF2019	PLF2019	2018-11-29 22:15:00	2018-11-29 23:40:00	\N	\N	43	0	\N	\N
321352	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF2019	PLF2019	2018-11-30 09:30:00	2018-11-30 12:55:00	\N	\N	50	0	\N	\N
321353	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF2019	PLF2019	2018-11-30 14:30:00	2018-11-30 20:05:00	\N	\N	52	0	\N	\N
317486	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Examen d¿un rapport législatif	\N	2018-11-07 09:00:00	2018-11-07 12:30:00	2018-11-07 12:28:29	2018-11-07 14:15:26	46	0	\N	\N
321134	COM_PERMANENTE	AUTRE	\N	ETRD	\N	PJLF pour 2019 : examen d'avis budgétaires	\N	2018-11-14 09:30:00	2018-11-14 11:25:00	2018-11-14 14:21:06	2018-11-14 15:06:09	42	0	\N	\N
321355	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF2019	PLF2019	2018-12-01 09:30:00	2018-12-01 13:30:00	\N	\N	54	0	\N	\N
321356	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF2019	PLF2019	2018-12-01 15:00:00	2018-12-01 20:05:00	\N	\N	68	0	\N	\N
321357	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF2019	PLF2019	2018-12-01 21:00:00	2018-12-02 00:00:00	\N	\N	0	0	\N	\N
321358	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF2019	PLF2019	2018-12-02 10:00:00	2018-12-02 13:05:00	\N	\N	53	0	\N	\N
321359	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF2019	PLF2019	2018-12-02 14:35:00	2018-12-02 18:58:00	\N	\N	53	0	\N	\N
321360	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF2019	PLF2019	2018-12-02 21:00:00	2018-12-03 00:00:00	\N	\N	0	0	\N	\N
321361	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2019	PLF 2019	2018-12-03 10:00:00	2018-12-03 12:55:00	\N	\N	50	0	\N	\N
321362	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF2019	PLF2019	2018-12-03 14:30:00	2018-12-03 19:55:00	\N	\N	79	0	\N	\N
321363	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF2019	PLF2019	2018-12-03 21:30:00	2018-12-04 00:10:00	\N	\N	52	0	\N	\N
217576	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2017-11-15 14:00:00	2017-11-15 15:00:00	\N	\N	1	0	\N	\N
217578	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2017-11-14 08:45:00	2017-11-14 11:00:00	\N	\N	1	0	\N	\N
225955	DELEGATION	AUCUNE	\N	\N	211	Audition de Mme Hirigoyen, psychiatre	Audition de Mme Hirigoyen, psychiatre	2017-11-30 08:30:00	2017-11-30 10:30:00	2017-11-30 17:32:29	2017-11-30 18:01:24	11	0	\N	\N
233513	GIA	AUCUNE	\N	\N	\N	AG	\N	2018-01-16 14:15:00	2018-01-16 14:45:00	\N	\N	14	0	651	\N
236384	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL SS Algérie	\N	2018-01-23 14:55:00	2018-01-23 15:40:00	\N	\N	1	0	\N	\N
238577	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe	Assemblée générale du groupe	2018-01-24 16:00:00	2018-01-24 16:30:00	\N	\N	5	0	599	\N
238586	GIA	AUCUNE	\N	\N	\N	Assemblée générale	Assemblée générale	2018-02-01 11:00:00	2018-02-01 12:00:00	\N	\N	4	0	577	\N
238588	GIA	AUCUNE	\N	\N	\N	Déjeuner en l'honneur de Mme Eva NGUYEN-BINH, ambassadrice de france au Cambodge	Déjeuner en l'honneur de Mme Eva NGUYEN-BINH, ambassadrice de france au Cambodge	2018-02-01 12:15:00	2018-02-01 14:00:00	\N	\N	8	0	577	\N
238589	GIA	AUCUNE	\N	\N	\N	AG 	Assemblée générale reconstitutive du GIA France-Irlande	2018-01-24 08:15:00	2018-01-24 09:00:00	\N	\N	11	0	594	\N
238610	DELEGATION	AUDRAP	\N	\N	206	Audition bioéthique	Audition du Professeur Patrick Niaudet, expert au Conseil d'orientation de l'Agence de biomédecine	2018-01-24 16:00:00	2018-01-24 18:00:00	\N	\N	1	0	\N	\N
244241	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPRE Australie Nouvelle-Zélande	\N	2018-02-06 09:00:00	2018-02-06 11:00:00	\N	\N	1	0	\N	\N
244243	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPRE Australie Nouvelle-Zélande	\N	2018-02-07 14:45:00	2018-02-07 15:45:00	\N	\N	1	0	\N	\N
244245	MISSION	AUDRAP	\N	ALSTOM	\N	MI ALSTOM - Auditions président&rapporteur	\N	2018-02-06 14:30:00	2018-02-06 15:30:00	\N	\N	4	0	\N	\N
244250	MISSION	AUDRAP	\N	ALSTOM	\N	MI ALSTOM - Auditions président&rapporteur	\N	2018-02-06 15:30:00	2018-02-06 16:30:00	\N	\N	5	0	\N	\N
244256	MISSION	AUDRAP	\N	ALSTOM	\N	MI ALSTOM - Auditions président&rapporteur	\N	2018-02-07 14:30:00	2018-02-07 15:30:00	\N	\N	5	0	\N	\N
246268	DELEGATION	AUCUNE	\N	\N	211	Audition CESE "violences contre les femmes dans les outre-mer	Audition CESE "violences contre les femmes dans les outre-mer	2018-02-15 08:30:00	2018-02-15 11:00:00	2018-02-15 11:46:59	2018-02-15 12:13:51	22	0	\N	\N
247639	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion de la commission des affaires européennes	\N	2018-02-20 18:00:00	2018-02-20 19:05:00	2018-02-20 19:32:34	2018-02-21 09:38:15	23	0	\N	\N
250161	GIA	AUCUNE	\N	\N	\N	Entretien avec une délégation parlementaire de haut niveau pour évoquer la situation à Jér	Entretien avec une délégation parlementaire de haut niveau pour évoquer la situation à Jérusalem	2018-02-13 08:30:00	2018-02-13 10:00:00	\N	\N	3	0	632	\N
256478	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Sanctions en matière de concurrence en Polynésie française	\N	2018-03-20 14:30:00	2018-03-20 15:00:00	\N	\N	1	0	\N	\N
261014	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	\N	GT Financement du handicap	2018-03-28 16:00:00	2018-03-28 17:00:00	\N	\N	4	0	\N	\N
261019	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	\N	GT Financement du handicap	2018-03-28 17:00:00	2018-03-28 17:45:00	\N	\N	3	0	\N	\N
261023	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	\N	GT Financement du handicap	2018-05-16 15:00:00	2018-05-16 17:00:00	\N	\N	4	0	\N	\N
261083	MECSS	AUDRAP	\N	\N	MECSS	\N	Accès à l'innovation dans le domaine des produits de santé	2018-03-28 15:30:00	2018-03-28 16:30:00	\N	\N	5	0	\N	\N
262755	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2018-04-03 14:30:00	2018-04-03 17:10:00	\N	\N	3	0	\N	\N
273890	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Présence parlementaires organimes extérieurs	PPL Présence parlementaires organimes extérieurs	2018-06-12 14:30:00	2018-06-12 15:30:00	\N	\N	100	0	\N	\N
273894	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Equilibre territorial	PPL Equilibre territorial	2018-06-12 15:30:00	2018-06-12 16:30:00	\N	\N	127	0	\N	\N
273895	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2018-06-12 16:45:00	2018-06-12 17:45:00	\N	\N	301	0	\N	\N
273896	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Equilibre territorial	PPL Equilibre territorial	2018-06-12 18:00:00	2018-06-12 20:20:00	\N	\N	109	0	\N	\N
273897	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Défibrillateur cardiaque	PPL Défibrillateur cardiaque	2018-06-13 14:30:00	2018-06-13 16:15:00	\N	\N	94	0	\N	\N
273898	SEANCE_PLENIERE	DEBAT	\N	\N	\N	PPL Caméras mobiles	PPL Caméras mobiles	2018-06-13 16:15:00	2018-06-13 17:50:00	\N	\N	78	0	\N	\N
273899	SEANCE_PLENIERE	DEBAT	\N	\N	\N	PPL Equilibre territorial	PPL Equilibre territorial	2018-06-13 18:30:00	2018-06-13 20:20:00	\N	\N	87	0	\N	\N
273901	SEANCE_PLENIERE	DEBAT	\N	\N	\N	PPL Centres-villes	PPL Centres-villes	2018-06-13 21:50:00	2018-06-14 00:30:00	\N	\N	81	0	\N	\N
273902	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Conclusions CMP Pacte ferroviaire	\N	2018-06-14 10:30:00	2018-06-14 12:00:00	\N	\N	99	0	\N	\N
273903	SEANCE_PLENIERE	DEBAT	\N	\N	\N	PPL Formation ministres des cultes	PPL Formation ministres des cultes	2018-06-14 14:30:00	2018-06-14 17:55:00	\N	\N	56	0	\N	\N
273905	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Centres-villes	PPL Centres-villes	2018-06-14 18:30:00	2018-06-14 20:25:00	\N	\N	38	0	\N	\N
238606	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Droit des sites naturels ouverts au public PJL droit des contrats	\N	2018-01-31 10:10:00	2018-01-31 12:20:00	2018-01-31 16:23:53	2018-01-31 17:14:43	43	0	\N	\N
260214	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Indiv. successorale outre-mer + PPL Élection conseillers métropolitains + Nomination	\N	2018-03-28 08:35:00	2018-03-28 10:00:00	2018-03-28 13:26:02	2018-03-28 14:38:02	37	0	\N	\N
273911	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2018-06-19 09:30:00	2018-06-19 12:15:00	\N	\N	34	0	\N	\N
273912	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Droit d'asile	PJL Droit d'asile	2018-06-19 14:30:00	2018-06-19 20:00:00	\N	\N	224	0	\N	\N
273913	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Droit d'asile	PJL Droit d'asile	2018-06-19 21:30:00	2018-06-20 00:40:00	\N	\N	110	0	\N	\N
273914	SEANCE_PLENIERE	DEBAT	\N	\N	\N	PJL Droit d'asile	PJL Droit d'asile	2018-06-20 14:35:00	2018-06-20 19:30:00	\N	\N	190	0	\N	\N
273915	SEANCE_PLENIERE	DEBAT	\N	\N	\N	PJL Droit d'asile	PJL Droit d'asile	2018-06-20 21:30:00	2018-06-21 00:30:00	\N	\N	112	0	\N	\N
273917	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Conclusions CMP Secret des affaires	Conclusions CMP Secret des affaires	2018-06-21 10:30:00	2018-06-21 11:40:00	\N	\N	68	0	\N	\N
273918	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2018-06-21 15:00:00	2018-06-21 16:05:00	\N	\N	261	0	\N	\N
273919	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Droit d'asile	PJL Droit d'asile	2018-06-21 16:15:00	2018-06-21 20:00:00	\N	\N	86	0	\N	\N
273920	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Droit d'asile	PJL Droit d'asile	2018-06-21 21:30:00	2018-06-22 00:00:00	\N	\N	50	0	\N	\N
273921	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2018-06-26 16:45:00	2018-06-26 17:40:00	\N	\N	302	0	\N	\N
273922	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat préalable Conseil européen	Débat préalable Conseil européen	2018-06-26 21:45:00	2018-06-27 00:40:00	\N	\N	44	0	\N	\N
273923	SEANCE_PLENIERE	DEBAT	\N	\N	\N	PJL Equilibre relations commerciales secteur agricole	PJL Equilibre relations commerciales secteur agricole	2018-06-26 17:50:00	2018-06-27 20:15:00	\N	\N	130	0	\N	\N
273924	SEANCE_PLENIERE	DEBAT	\N	\N	\N	PJL Equilibre relations commerciales secteur agricole	PJL Equilibre relations commerciales secteur agricole	2018-06-27 14:30:00	2018-06-27 19:50:00	\N	\N	160	0	\N	\N
273925	SEANCE_PLENIERE	DEBAT	\N	\N	\N	PJL Equilibre relations commerciales secteur agricole	PJL Equilibre relations commerciales secteur agricole	2018-06-27 21:30:00	2018-06-28 01:20:00	\N	\N	96	0	\N	\N
288039	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PJL Liberté de choisir son avenir professionnel	\N	2018-06-27 19:00:00	2018-06-27 20:00:00	\N	\N	0	0	\N	\N
288052	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Commission des affaires étrangères	\N	2018-06-27 09:30:00	2018-06-27 12:10:00	2018-06-27 14:48:48	2018-06-27 15:05:51	30	0	\N	\N
288053	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Commission des affaires étrangères	\N	2018-06-27 16:30:00	2018-06-27 18:15:00	2018-06-27 18:28:19	2018-06-28 10:14:31	25	0	\N	\N
293372	MISSION	DEPLACEMENT	\N	BREXIT2	\N	Déplacement à Dublin, Belfast et Londres	Déplacement à Dublin, Belfast et Londres	2018-07-01 16:00:00	2018-07-04 18:30:00	\N	\N	5	0	\N	\N
293381	MISSION	DEPLACEMENT	\N	BREXIT2	\N	Déplacement à Dublin, Belfast et Londres	Déplacement à Dublin, Belfast et Londres	2018-07-02 08:00:00	2018-07-03 13:30:00	\N	\N	1	0	\N	\N
293383	MISSION	DEPLACEMENT	\N	BREXIT2	\N	Déplacement à Dublin, Belfast et Londres	Déplacement à Dublin, Belfast et Londres	2018-07-03 17:00:00	2018-07-04 18:30:00	\N	\N	2	0	\N	\N
293389	COM_PERMANENTE	DEPLACEMENT	\N	SOCI	\N	Fiancement médico-social du handicap	Financement médico-social du handicap	2018-06-22 06:00:00	2018-06-22 18:15:00	\N	\N	1	0	\N	\N
293441	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion commission des lois mardi 3 juillet 	Réunion Réunion commission des lois mardi 3 juillet 	2018-07-03 09:05:00	2018-07-03 10:10:00	2018-07-03 10:57:31	2018-07-03 16:51:50	19	1	\N	\N
363550	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Clarifier dispositions droit électoral	PPL Clarifier dispositions droit électoral	2019-05-02 17:00:00	2019-05-02 18:50:00	\N	\N	50	0	\N	\N
363918	GIA	AUCUNE	\N	\N	\N	Rencontre-débat à l'ambassade du Maroc	Rencontre-débat à l'ambassade du Maroc	2019-03-13 18:00:00	2019-03-13 20:00:00	\N	\N	3	0	598	\N
363924	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Alexey Mechkov, ambassadeur de Russie en France	Entretien avec M. Alexey Mechkov, ambassadeur de Russie en France	2019-03-20 08:00:00	2019-03-20 09:00:00	\N	\N	17	0	608	\N
364303	GIA	AUCUNE	\N	\N	\N	Entretien avec Mme McCOURT, Ambassadeur des Etats-Unis en France	Entretien avec Mme McCOURT, Ambassadeur des Etats-Unis en France	2019-03-21 13:00:00	2019-03-21 14:30:00	\N	\N	14	0	590	\N
364318	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Pascal HECTOR, ministre plénipotentiaire de l'Ambassade d'Allemagne	Entretien avec M. Pascal HECTOR, ministre plénipotentiaire de l'Ambassade d'Allemagne	2019-03-21 13:00:00	2019-03-21 14:30:00	\N	\N	4	0	604	\N
364425	GIA	AUCUNE	\N	\N	\N	petit-déjeuner de travail	Petit-déjeuner avec M. Rémi Maréchaux, Directeur Afrique et Océanie au MEAE	2019-03-20 08:30:00	2019-03-20 09:30:00	\N	\N	10	0	622	\N
364475	COM_PERMANENTE	DEPLACEMENT	\N	AFCL	\N	Déplacement au Centre Pompidou	Déplacement au Centre Pompidou	2019-03-20 10:00:00	2019-03-20 11:30:00	\N	\N	8	0	\N	\N
364484	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2019-03-20 19:35:00	2019-03-20 20:00:00	\N	\N	25	0	\N	\N
364511	BUREAU	AUCUNE	\N	\N	\N	Réunion du Bureau	Réunion du Bureau	2019-03-21 08:40:00	2019-03-21 11:50:00	\N	\N	25	0	\N	\N
365632	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	206	Petit déjeuner de travail avec le CEA	Petit déjeuner de travail avec le CEA	2019-04-11 08:30:00	2019-04-11 10:00:00	\N	\N	8	0	\N	\N
366532	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Création de l'Office français de la biodiversité	PJL Création de l'Office français de la biodiversité	2019-03-26 09:30:00	2019-03-26 10:15:00	\N	\N	1	0	\N	\N
366777	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition commune borréliose de Lyme	\N	2019-04-03 09:00:00	2019-04-03 10:45:00	2019-04-03 11:33:54	2019-04-03 15:04:14	34	0	\N	\N
366779	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Examen rapport financement de la dépendance	\N	2019-04-03 10:55:00	2019-04-03 12:15:00	2019-04-03 14:02:40	2019-04-03 15:04:11	44	0	\N	\N
321770	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	AP OTAN	\N	2018-11-06 17:30:00	2018-11-06 18:50:00	\N	\N	4	0	\N	\N
293442	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion mercredi 4 juillet 2018	Réunion mercredi 4 juillet 2018	2018-07-04 09:36:00	2018-07-04 09:50:00	2018-07-04 14:59:47	2018-07-04 15:24:07	28	1	\N	\N
366778	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Examen amendements séance PPL Drapeaux	\N	2019-04-03 10:45:00	2019-04-03 10:55:00	2019-04-03 14:02:13	2019-04-03 15:04:12	44	0	\N	\N
366780	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de M. Dominique Libault	\N	2019-04-04 13:50:00	2019-04-04 14:50:00	2019-04-04 14:49:28	2019-04-04 16:14:56	22	0	\N	\N
366781	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Communication	\N	2019-04-03 17:25:00	2019-04-03 17:50:00	2019-04-03 17:53:48	2019-04-04 11:42:15	19	0	\N	\N
366789	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	algorithmes locaux dans Parcoursup	\N	2019-03-26 10:00:00	2019-03-26 11:00:00	\N	\N	2	0	\N	\N
366792	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	algorithmes locaux dans Parcoursup	\N	2019-03-26 15:15:00	2019-03-26 16:45:00	\N	\N	4	0	\N	\N
368174	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2019-03-26 14:00:00	2019-03-26 16:15:00	\N	\N	2	0	\N	\N
368178	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2019-03-27 14:30:00	2019-03-27 15:30:00	\N	\N	2	0	\N	\N
368181	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2019-04-09 13:45:00	2019-04-09 14:30:00	\N	\N	2	0	\N	\N
369160	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Reconnaissance du crime d'écocide	\N	2019-04-02 13:30:00	2019-04-02 14:15:00	\N	\N	2	0	\N	\N
369169	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition et vote article 13 président de l'OFPRA	Audition et vote article 13 président de l'OFPRA	2019-04-03 09:05:00	2019-04-03 10:15:00	2019-04-03 17:49:26	2019-04-04 11:41:02	40	0	\N	\N
369214	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition évènement 16 mars 	Audition évènement 16 mars 	2019-04-03 10:45:00	2019-04-03 11:40:00	2019-04-03 17:49:17	2019-04-04 11:40:57	40	0	\N	\N
369691	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-04-10 09:45:00	2019-04-10 12:00:00	2019-04-10 14:24:39	2019-04-10 16:50:59	26	0	\N	\N
371140	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPRA Contrôle de l'application et de l'évaluation des lois	PPRA Contrôle de l'application et de l'évaluation des lois	2019-04-09 15:00:00	2019-04-09 15:30:00	\N	\N	2	0	\N	\N
371149	ETUDES	AUCUNE	\N	\N	\N	Réunion PJL OFB	Réunion PJL OFB	2019-04-04 08:00:00	2019-04-04 08:30:00	\N	\N	3	0	\N	907
371187	MISSION	AUCUNE	\N	CLIMATIQUE	\N	Audition commune de représentants des syndicats agricoles	\N	2019-04-09 17:08:00	2019-04-09 18:35:00	2019-04-10 15:24:03	2019-04-10 16:51:30	13	0	\N	\N
371216	MISSION	AUDRAP	\N	CLIMATIQUE	\N	Audition de représentants de la direction générale du Trésor	\N	2019-04-09 08:00:00	2019-04-09 09:00:00	\N	\N	6	0	\N	\N
371217	MISSION	AUDRAP	\N	CLIMATIQUE	\N	Audition de représentants de la DGPE (Ministère de l'agriculture)	\N	2019-04-09 09:00:00	2019-04-09 10:00:00	\N	\N	6	0	\N	\N
371405	ETUDES	AUCUNE	\N	\N	\N	Rencontre avec M. Guillaume Sainteny	Rencontre avec M. Guillaume Sainteny	2019-04-10 08:00:00	2019-04-10 09:30:00	\N	\N	10	0	\N	948
371421	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL corruption transnationale	PPL corruption transnationale	2019-05-02 18:55:00	2019-05-02 20:20:00	\N	\N	37	0	\N	\N
371423	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL lutte contre espèces toxiques	PPL lutte contre espèces toxiques	2019-05-07 14:30:00	2019-05-07 15:25:00	\N	\N	85	0	\N	\N
371424	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR PAC	PPR PAC	2019-05-07 15:30:00	2019-05-07 16:30:00	\N	\N	101	0	\N	\N
371425	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2019-05-07 16:45:00	2019-05-07 17:45:00	\N	\N	260	0	\N	\N
371426	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR PAC	PPR PAC	2019-05-07 17:50:00	2019-05-07 20:10:00	\N	\N	35	0	\N	\N
371427	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR Règlement du Sénat	PPR Règlement du Sénat	2019-05-07 18:50:00	2019-05-07 20:00:00	\N	\N	15	0	\N	\N
371428	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Caducité du Traité sur la stabilité	Débat Caducité du Traité sur la stabilité	2019-05-09 10:30:00	2019-05-09 11:50:00	\N	\N	25	0	\N	\N
371471	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Synergies entre les conseils municipaux et communautaires	PPL Synergies entre les conseils municipaux et communautaires	2019-05-09 14:30:00	2019-05-09 17:40:00	\N	\N	47	0	\N	\N
371472	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Mécénat territorial	Débat Mécénat territorial	2019-05-09 17:45:00	2019-05-09 18:40:00	\N	\N	17	0	\N	\N
213268	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Culture	PLF pour 2018 - Culture - table ronde 'cité du théâtre" et Ministère de la culture	2017-10-23 16:45:00	2017-10-23 19:00:00	\N	\N	2	0	\N	\N
213271	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Culture	PLF pour 2018 - Culture - Ministère de la Culture + OPPIC	2017-10-26 16:30:00	2017-10-26 19:15:00	\N	\N	2	0	\N	\N
213336	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2018 - GHPRH	PLF pour 2018 - GHPRH - Audition DGFiP	2017-10-26 08:30:00	2017-10-26 10:30:00	\N	\N	2	0	\N	\N
213369	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2018 - Défense	PLF pour 2018 - Défense - Audition EMM et EMA	2017-10-26 17:30:00	2017-10-26 19:30:00	\N	\N	1	0	\N	\N
213371	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL n°40 de programmation des finances publiques  2018-2022	PJL n°40 de programmation des finances publiques  2018-2022 - Rencontre avec délégation FMI	2017-10-26 14:00:00	2017-10-26 15:00:00	\N	\N	2	0	\N	\N
223391	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions GT Infractions sexuelles	Auditions GT Infractions sexuelles	2017-11-23 10:45:00	2017-11-23 13:00:00	\N	\N	7	0	\N	\N
223402	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2018 - Avis Justice judiciaire	\N	2017-11-21 18:00:00	2017-11-21 18:40:00	\N	\N	1	0	\N	\N
223404	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2018 - Avis Justice judiciaire	\N	2017-11-23 14:15:00	2017-11-23 15:00:00	\N	\N	1	0	\N	\N
223980	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2018 - Examen d'un amendement à l'article d'équilibre	PLF pour 2018 - Examen d'un amendement à l'article d'équilibre	2017-11-28 14:50:00	2017-11-28 14:55:00	2017-11-29 11:04:58	2017-11-29 16:48:57	28	1	\N	\N
225428	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL Vietnam entraide judiciaire	\N	2017-11-28 15:05:00	2017-11-28 15:35:00	\N	\N	1	0	\N	\N
227030	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion	Réunion	2017-12-06 09:35:00	2017-12-06 11:10:00	2017-12-07 11:05:06	2017-12-07 11:07:30	31	0	\N	\N
227031	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion	Réunion	2017-12-06 14:35:00	2017-12-06 16:45:00	2017-12-06 16:56:54	2017-12-06 17:08:52	18	0	\N	\N
227680	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 6 décembre 2017	Réunion du 6 décembre 2017	2017-12-06 17:35:00	2017-12-06 19:35:00	2017-12-06 19:50:20	2017-12-07 11:03:08	19	0	\N	\N
233676	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	PPL portant création d'un fonds d'indemnisation des victimes des produits psytopharmaceutiquess	2018-01-15 09:30:00	2018-01-15 11:30:00	\N	\N	1	0	\N	\N
233687	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	PPL portant création d'un fonds d'indemnisation des victimes des produits psytopharmaceutiquess	2018-01-17 16:00:00	2018-01-17 17:00:00	\N	\N	1	0	\N	\N
233715	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	PPL portant création d'un fonds d'indemnisation des victimes des produits psytopharmaceutiquess	2018-01-18 09:30:00	2018-01-18 13:00:00	\N	\N	1	0	\N	\N
371214	COM_PERMANENTE	AUTRE	\N	LOIS	\N	\N	\N	2019-04-10 09:05:00	2019-04-10 12:15:00	2019-04-10 17:25:21	2019-04-10 17:48:33	39	1	\N	\N
233731	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	PPL portant création d'un fonds d'indemnisation des victimes des produits psytopharmaceutiquess	2018-01-18 17:30:00	2018-01-18 18:00:00	\N	\N	1	0	\N	\N
233812	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	PPL portant création d'un fonds d'indemnisation des victimes des produits psytopharmaceutiques	2018-01-18 19:15:00	2018-01-18 20:15:00	\N	\N	1	0	\N	\N
233979	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Orientation et réussite des étudiants	PJL Orientation et réussite des étudiants	2018-01-16 09:30:00	2018-01-16 11:30:00	\N	\N	1	0	\N	\N
233999	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Orientation et réussite des étudiants	PJL Orientation et réussite des étudiants	2018-01-16 14:00:00	2018-01-16 15:00:00	\N	\N	1	0	\N	\N
234008	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Orientation et réussite des étudiants	PJL Orientation et réussite des étudiants	2018-01-16 15:00:00	2018-01-16 16:00:00	\N	\N	4	0	\N	\N
234031	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI contrats aidés	MI contrats aidés	2018-01-16 15:15:00	2018-01-16 16:45:00	\N	\N	2	0	\N	\N
238210	COM_EURO	CONTROLE	\N	AFEU	\N	Audition de M. Nikolaus Meyer-Landrut du 24 janvier 2018 - 15h00	Audition de M. Nikolaus Meyer-Landrut du 24 janvier 2018 - 15h00	2018-01-24 15:00:00	2018-01-24 16:25:00	2018-01-25 10:39:46	2018-01-25 15:37:47	30	0	\N	\N
240294	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PJL Réussite étudiants	CMP PJL Réussite étudiants	2018-02-15 16:20:00	2018-02-15 17:40:00	\N	\N	50	0	\N	\N
240295	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2018-02-20 16:45:00	2018-02-20 17:40:00	\N	\N	309	0	\N	\N
240296	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Femmes et agriculture	Débat Femmes et agriculture	2018-02-20 17:50:00	2018-02-20 19:40:00	\N	\N	81	0	\N	\N
240297	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Avenir audiovisuel	Débat Avenir audiovisuel	2018-02-20 21:30:00	2018-02-20 23:20:00	\N	\N	42	0	\N	\N
240298	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Établissements privés	PPL Établissements privés	2018-02-21 14:35:00	2018-02-21 18:35:00	\N	\N	157	0	\N	\N
240299	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR UE Australie Nouvelle-Zélande	PPR UE Australie Nouvelle-Zélande	2018-02-21 21:30:00	2018-02-22 00:40:00	\N	\N	40	0	\N	\N
240300	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Conflits d'intérêts	PPL Conflits d'intérêts	2018-02-22 14:30:00	2018-02-22 17:15:00	\N	\N	62	0	\N	\N
240301	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Violences conjugales	PPL Violences conjugales	2018-02-22 17:25:00	2018-02-22 18:45:00	\N	\N	31	0	\N	\N
240302	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2018-03-06 09:30:00	2018-03-06 12:20:00	\N	\N	41	0	\N	\N
240303	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Communications électroniques après-midi	PPL Communications électroniques après-midi	2018-03-06 14:30:00	2018-03-06 17:00:00	\N	\N	126	0	\N	\N
240305	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPLO Études d'impact	PPLO Études d'impact	2018-03-07 14:35:00	2018-03-07 17:00:00	\N	\N	116	0	\N	\N
240306	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Bien-être	PPL Bien-être	2018-03-07 17:00:00	2018-03-07 18:20:00	\N	\N	70	0	\N	\N
240307	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Retraites agricoles après-midi	PPL Retraites agricoles après-midi	2018-03-07 19:35:00	2018-03-07 23:15:00	\N	\N	131	0	\N	\N
240310	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2018-03-08 15:00:00	2018-03-08 16:05:00	\N	\N	277	0	\N	\N
240313	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Code du commerce	PPL Code du commerce	2018-03-08 16:25:00	2018-03-08 18:30:00	\N	\N	42	0	\N	\N
240315	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Société de confiance après-midi 1	PJL Société de confiance après-midi 1	2018-03-13 14:30:00	2018-03-13 16:30:00	\N	\N	142	0	\N	\N
240316	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2018-03-13 16:45:00	2018-03-13 17:40:00	\N	\N	288	0	\N	\N
240317	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Société de confiance après-midi 2	PJL Société de confiance après-midi 2	2018-03-13 18:10:00	2018-03-13 19:30:00	\N	\N	89	0	\N	\N
240318	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Société de confiance soir	PJL Société de confiance soir	2018-03-13 21:30:00	2018-03-14 00:30:00	\N	\N	79	0	\N	\N
240319	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Société de confiance après-midi	PJL Société de confiance après-midi	2018-03-14 14:30:00	2018-03-14 20:00:00	\N	\N	144	0	\N	\N
240320	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Société de confiance soir	PJL Société de confiance soir	2018-03-14 21:30:00	2018-03-15 00:50:00	\N	\N	52	0	\N	\N
297941	MISSION	PLEIN_NON_JO	\N	BREXIT2	\N	Présentation du rapport sur les négociations de retrait	Présentation du rapport sur les négociations de retrait	2018-07-12 08:40:00	2018-07-12 09:40:00	\N	\N	8	0	\N	\N
297957	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 12 juillet 2018	Réunion du 12 juillet 2018	2018-07-12 10:05:00	2018-07-12 11:25:00	2018-07-12 12:33:11	2018-07-12 15:58:21	7	0	\N	\N
304624	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	\N	2018-03-23 10:15:00	2018-03-23 11:40:00	\N	\N	0	0	\N	\N
304630	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	\N	2018-03-23 09:30:00	2018-03-23 10:15:00	\N	\N	0	0	\N	\N
304774	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Auditions plénières - Affaire "Benalla"	Auditions plénières - Affaire "Benalla"	2018-07-30 10:35:00	2018-07-30 12:55:00	2018-07-30 14:14:33	2018-07-30 15:36:31	32	0	\N	\N
304777	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Auditions plénières	Auditions plénières Lundi 30 juillet 2018	2018-07-30 14:30:00	2018-07-30 18:55:00	2018-07-30 19:01:15	2018-07-31 10:20:51	36	0	\N	\N
309427	GIA	AUCUNE	\N	\N	\N	Rencontre avec Chagaï TZURIEL, Directeur général du Ministère israélien du Renseignement	\N	2018-10-09 08:30:00	2018-10-09 09:45:00	\N	\N	12	0	595	\N
309725	GIA	AUCUNE	\N	\N	\N	rencontre avec une ONG	Entretien avec M Kleiche , de l'ONG AIDL	2018-10-09 13:00:00	2018-10-09 14:00:00	\N	\N	1	0	627	\N
314303	ETUDES	AUCUNE	\N	\N	\N	\N	\N	2018-10-23 17:00:00	2018-10-23 19:00:00	\N	\N	11	0	\N	948
314305	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF 2019 - Avis "Mesures fiscales"	\N	2018-10-23 16:30:00	2018-10-23 19:00:00	\N	\N	1	0	\N	\N
321364	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2018-12-04 09:30:00	2018-12-04 12:50:00	\N	\N	43	0	\N	\N
321366	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF2019	PLF2019	2018-12-04 14:30:00	2018-12-04 21:05:00	\N	\N	181	0	\N	\N
321367	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF2019	PLF2019	2018-12-04 21:00:00	2018-12-05 00:00:00	\N	\N	61	0	\N	\N
321368	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF2019	PLF2019	2018-12-05 11:00:00	2018-12-05 13:00:00	\N	\N	120	0	\N	\N
321369	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF2019	PLF2019	2018-12-05 14:30:00	2018-12-05 20:30:00	\N	\N	189	0	\N	\N
321370	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF2019	PLF2019	2018-12-05 21:00:00	2018-12-06 00:00:00	\N	\N	69	0	\N	\N
321374	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF2019	PLF2019	2018-12-06 21:00:00	2018-12-07 00:00:00	\N	\N	40	0	\N	\N
321375	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF2019	PLF2019	2018-12-06 09:30:00	2018-12-06 13:00:00	\N	\N	102	0	\N	\N
321377	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF2019	PLF2019	2018-12-06 15:00:00	2018-12-06 20:30:00	\N	\N	71	0	\N	\N
321380	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF2019	PLF2019	2018-12-07 09:30:00	2018-12-07 13:00:00	\N	\N	45	0	\N	\N
321382	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF2019	PLF2019	2018-12-07 14:30:00	2018-12-07 20:30:00	\N	\N	55	0	\N	\N
321384	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF2019	PLF2019	2018-12-07 21:00:00	2018-12-08 00:00:00	\N	\N	35	0	\N	\N
321385	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF2019	PLF2019	2018-12-08 09:30:00	2018-12-08 13:00:00	\N	\N	0	0	\N	\N
321387	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF2019	PLF2019	2018-12-08 14:30:00	2018-12-08 20:30:00	\N	\N	0	0	\N	\N
321388	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF2019	PLF2019	2018-12-08 21:00:00	2018-12-09 00:00:00	\N	\N	0	0	\N	\N
321390	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF2019	PLF2019	2018-12-09 09:30:00	2018-12-09 13:00:00	\N	\N	0	0	\N	\N
321392	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF2019	PLF2019	2018-12-09 21:00:00	2018-12-10 00:00:00	\N	\N	0	0	\N	\N
321393	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF2019	PLF2019	2018-12-09 14:30:00	2018-12-09 20:30:00	\N	\N	0	0	\N	\N
321394	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF2019	PLF2019	2018-12-10 10:00:00	2018-12-10 13:00:00	\N	\N	43	0	\N	\N
321395	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF2019	PLF2019	2018-12-10 14:30:00	2018-12-10 20:30:00	\N	\N	41	0	\N	\N
321396	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF2019	PLF2019	2018-12-10 21:00:00	2018-12-11 00:00:00	\N	\N	0	0	\N	\N
321399	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR Voile intégral	PPR Voile intégral	2018-12-11 18:30:00	2018-12-11 20:30:00	\N	\N	92	0	\N	\N
321402	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Communes nouvelles	PPL Communes nouvelles	2018-12-11 19:30:00	2018-12-11 20:30:00	\N	\N	0	0	\N	\N
321403	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Communes nouvelles	PPL Communes nouvelles	2018-12-11 21:30:00	2018-12-12 00:00:00	\N	\N	57	0	\N	\N
321406	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Funérailles républicaines	PPL Funérailles républicaines	2018-12-12 14:30:00	2018-12-12 18:30:00	\N	\N	120	0	\N	\N
321407	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR Paiements services agriculteurs	PPR Paiements services agriculteurs	2018-12-12 15:00:00	2018-12-12 18:30:00	\N	\N	90	0	\N	\N
321408	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Préavis grève contrôleurs aériens	PPL Préavis grève contrôleurs aériens	2018-12-12 18:30:00	2018-12-12 20:00:00	\N	\N	67	0	\N	\N
321409	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Préavis grève contrôleurs aériens	PPL Préavis grève contrôleurs aériens	2018-12-12 21:30:00	2018-12-13 00:00:00	\N	\N	0	0	\N	\N
321411	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2018-12-13 15:00:00	2018-12-13 16:00:00	\N	\N	239	0	\N	\N
321415	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Conseil européen 13 et 14 décembre	Débat Conseil européen 13 et 14 décembre	2018-12-17 15:00:00	2018-12-17 20:30:00	\N	\N	32	0	\N	\N
321419	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Evasion fiscale Luxembourg	PJL Evasion fiscale Luxembourg	2018-12-17 15:00:00	2018-12-17 20:30:00	\N	\N	20	0	\N	\N
321420	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Evasion fiscale Luxembourg	PJL Evasion fiscale Luxembourg	2018-12-17 21:00:00	2018-12-18 00:00:00	\N	\N	0	0	\N	\N
321421	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP ou Nouvelle lecture PLF2019	CMP ou Nouvelle lecture PLF2019	2018-12-19 14:30:00	2018-12-19 16:45:00	\N	\N	100	0	\N	\N
321422	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Logement outre-mer	PPL Logement outre-mer	2018-12-18 14:30:00	2018-12-18 16:45:00	\N	\N	88	0	\N	\N
321424	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2018-12-18 16:45:00	2018-12-18 17:45:00	\N	\N	285	0	\N	\N
321425	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Logement outre-mer	PPL Logement outre-mer	2018-12-18 17:45:00	2018-12-18 20:30:00	\N	\N	37	0	\N	\N
321426	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Logement outre-mer	PPL Logement outre-mer	2018-12-18 21:00:00	2018-12-19 00:00:00	\N	\N	0	0	\N	\N
321766	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	AP OTAN	\N	2018-11-06 16:00:00	2018-11-06 17:30:00	\N	\N	3	0	\N	\N
321775	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2019 - Programme 105	\N	2018-11-08 16:00:00	2018-11-08 17:00:00	\N	\N	1	0	\N	\N
321777	DELEGATION	DEPLACEMENT	\N	\N	206	Déplacement en Norvège (Arrêt des véhicules thermiques)	Déplacement en Norvège (Arrêt des véhicules thermiques)	2018-11-14 21:00:00	2018-11-16 20:00:00	\N	\N	2	0	\N	\N
214616	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Avis budgétaire "AGTE"	\N	2017-11-14 14:30:00	2017-11-14 16:30:00	\N	\N	1	0	\N	\N
214617	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	PLF pour 2018 - Avis AGTE - Déplacement	\N	2017-11-15 07:30:00	2017-11-15 19:00:00	\N	\N	1	0	\N	\N
214623	COM_PERMANENTE	AUTRE	\N	CAE	\N	PJL n° 43 Fin de la recherche et de l'exploitation des hydrocarbures	PJL n° 43 Fin de la recherche et de l'exploitation des hydrocarbures	2017-11-07 09:00:00	2017-11-07 09:45:00	2017-11-07 11:17:32	2017-11-07 17:06:57	28	0	\N	\N
214624	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de M. Nicolas Grivel, directeur général de l'ANRU	Audition de M. Nicolas Grivel, directeur général de l'ANRU	2017-11-08 09:35:00	2017-11-08 11:15:00	2017-11-08 16:09:26	2017-11-08 16:16:29	37	0	\N	\N
235487	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Développement durable des territoires littoraux	\N	2018-01-23 09:00:00	2018-01-23 09:30:00	2018-01-23 14:37:57	2018-01-23 17:20:39	19	0	\N	\N
235488	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition délégué interministériel sécurité routière et nomination GT sécurité routière	\N	2018-01-24 09:00:00	2018-01-24 10:45:00	2018-01-24 15:17:46	2018-01-24 16:00:59	62	0	\N	\N
236577	GIA	AUCUNE	\N	\N	\N	AG du groupe	Assemblée générale du groupe et désignation du Bureau	2018-01-23 14:00:00	2018-01-23 14:20:00	\N	\N	13	0	609	\N
238081	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe	Assemblée générale du groupe	2018-01-24 12:00:00	2018-01-24 12:30:00	\N	\N	9	0	572	\N
238148	GIA	AUCUNE	\N	\N	\N	Audition ambassadeur de France à Djibouti	audition ambassadeur de France à Djibouti	2018-01-24 15:30:00	2018-01-24 16:30:00	\N	\N	3	0	588	\N
238153	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe interparlementaire d'amitié France-Ukraine	Assemblée générale du groupe interparlementaire d'amitié France-Ukraine	2018-01-24 08:00:00	2018-01-24 08:30:00	\N	\N	9	0	530	\N
238658	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Mission "Routes de la soie"	\N	2018-01-23 14:30:00	2018-01-23 16:30:00	\N	\N	2	0	\N	\N
245198	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2018-02-13 17:30:00	2018-02-13 18:30:00	\N	\N	4	0	\N	\N
245304	AUTRE_TEMPORAIRE	CONTROLE	\N	\N	\N	Audition FNC	\N	2018-02-14 08:15:00	2018-02-14 09:25:00	\N	\N	0	0	\N	\N
246034	GIA	AUCUNE	\N	\N	\N	groupe France-Nouvelle Zélande	entretien avec SEMme Coombs , ambassadrice de la NZ	2018-02-14 08:30:00	2018-02-14 09:30:00	\N	\N	11	0	663	\N
246048	COM_SPECIALE	AUDRAP	\N	SOCIETE	\N	\N	\N	2018-02-13 09:00:00	2018-02-13 10:45:00	\N	\N	3	0	\N	\N
246111	COM_SPECIALE	AUDRAP	\N	SOCIETE	\N	\N	\N	2018-02-15 14:00:00	2018-02-15 14:45:00	\N	\N	1	0	\N	\N
250129	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	\N	GT Financement handicap	2018-03-06 16:00:00	2018-03-06 17:00:00	\N	\N	8	0	\N	\N
250133	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	\N	GT Financement handicap	2018-03-20 13:00:00	2018-03-20 14:00:00	\N	\N	6	0	\N	\N
250299	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Aud Protocole 16 CEDH	\N	2018-03-06 10:05:00	2018-03-06 10:30:00	\N	\N	1	0	\N	\N
251309	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Rapprochement France3 / France Bleu	Perspectives de rapprochement entre France3 et France Bleu	2018-03-06 14:30:00	2018-03-06 16:00:00	\N	\N	3	0	\N	\N
251315	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Rapprochement France3 / France Bleu	Perspectives de rapprochement entre France3 et France Bleu	2018-03-06 16:00:00	2018-03-06 17:30:00	\N	\N	4	0	\N	\N
251328	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Rapprochement France3 / France Bleu	Perspectives de rapprochement entre France3 et France Bleu	2018-03-07 15:00:00	2018-03-07 16:40:00	\N	\N	4	0	\N	\N
251352	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Formation au numérique	Groupe de travail Formation au numérique	2018-03-06 15:30:00	2018-03-06 19:00:00	\N	\N	1	0	\N	\N
251356	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Formation au numérique	Groupe de travail Formation au numérique	2018-03-07 14:00:00	2018-03-07 15:00:00	\N	\N	1	0	\N	\N
259751	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL accord routes France-Andorre	\N	2018-03-27 13:00:00	2018-03-27 14:30:00	\N	\N	1	0	\N	\N
266881	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	Commission des comptes	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne	2018-04-11 14:30:00	2018-04-11 15:45:00	2018-04-11 17:00:28	2018-04-11 17:29:34	9	0	\N	\N
273930	SEANCE_PLENIERE	DEBAT	\N	\N	\N	PJL Equilibre relations commerciales secteur agricole	PJL Equilibre relations commerciales secteur agricole	2018-06-28 11:50:00	2018-06-28 13:00:00	\N	\N	61	0	\N	\N
273967	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Equilibre relations commerciales secteur agricole	PJL Equilibre relations commerciales secteur agricole	2018-06-28 14:30:00	2018-06-28 19:40:00	\N	\N	95	0	\N	\N
273969	SEANCE_PLENIERE	DEBAT	\N	\N	\N	PJL Equilibre relations commerciales secteur agricole	PJL Equilibre relations commerciales secteur agricole	2018-06-28 21:10:00	2018-06-29 00:35:00	\N	\N	57	0	\N	\N
274053	COM_ENQUETE	PLENIERE	\N	HAUTE	\N	Auditions	Auditions	2018-05-22 14:30:00	2018-05-22 17:20:00	2018-05-22 18:37:27	2018-05-23 16:01:53	10	0	\N	\N
275857	DELEGATION	AUDRAP	\N	\N	206	Audition bioéthique du Professeur Stéphane Viville	Audition bioéthique du Professeur Stéphane Viville	2018-06-27 16:00:00	2018-06-27 17:50:00	\N	\N	1	0	\N	\N
275878	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Libye	\N	2018-05-23 12:15:00	2018-05-23 13:30:00	\N	\N	4	0	\N	\N
277639	GIA	AUCUNE	\N	\N	\N	déjeuner avec des parlementaires russes	déjeuner avec des parlementaires russes	2018-05-29 12:30:00	2018-05-29 14:00:00	\N	\N	6	0	608	\N
277666	GIA	AUCUNE	\N	\N	\N	entretien avec le Ministre des affaires étrangères de Lituanie	groupe d'amitié France-pays Baltes- entretien	2018-05-29 13:00:00	2018-05-29 14:30:00	\N	\N	1	0	616	\N
279272	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Formation des ministres des cultes	\N	2018-05-31 09:00:00	2018-05-31 12:30:00	\N	\N	1	0	\N	\N
235489	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL régime d'asile européen PPL Droit des sites ouverts au public PJL Droit des contrats	\N	2018-01-24 10:55:00	2018-01-24 12:20:00	2018-01-24 15:16:05	2018-01-24 16:00:53	46	0	\N	\N
275868	CMP	AUTRE	\N	SECRET	\N	PPL Protection des savoir-faire et des informations commerciales	PPL Protection des savoir-faire et des informations commerciales	2018-05-24 17:05:00	2018-05-24 17:35:00	\N	\N	8	0	\N	\N
279274	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Lutte contre les violences sexuelles et sexistes	\N	2018-05-29 14:30:00	2018-05-29 19:30:00	\N	\N	1	0	\N	\N
279276	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Lutte contre les violences sexuelles et sexistes	\N	2018-05-30 14:30:00	2018-05-30 17:30:00	\N	\N	1	0	\N	\N
280937	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Immigration, droit d'asile et intégration	\N	2018-06-06 14:30:00	2018-06-06 18:30:00	2018-06-07 12:54:46	2018-06-07 18:47:00	31	1	\N	\N
282397	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Liberté de choisir son avenir professionnel	\N	2018-06-20 11:30:00	2018-06-20 13:00:00	\N	\N	4	0	\N	\N
282399	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2018-06-21 09:00:00	2018-06-21 12:00:00	\N	\N	1	0	\N	\N
282463	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition Mme Belloubet et Mme Schiappa	\N	2018-06-11 18:30:00	2018-06-11 20:45:00	2018-06-13 14:43:49	2018-06-13 14:53:15	19	0	\N	\N
295834	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2018-07-10 09:05:00	2018-07-10 10:45:00	2018-07-10 10:53:31	2018-07-10 17:40:50	35	0	\N	\N
295835	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2018-07-10 13:30:00	2018-07-10 14:20:00	2018-07-10 14:27:47	2018-07-10 17:40:50	32	1	\N	\N
301909	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion	Réunion	2018-07-25 09:35:00	2018-07-25 12:10:00	2018-07-25 18:17:32	2018-07-26 17:23:10	31	3	\N	\N
305245	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	\N	\N	2018-08-01 15:00:00	2018-08-01 17:00:00	\N	\N	0	0	\N	\N
289514	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Droit d'asile	PJL Droit d'asile	2018-06-25 14:30:00	2018-06-25 19:30:00	\N	\N	68	0	\N	\N
294211	DELEGATION	AUDRAP	\N	\N	PROS	Audition de M. François Taddei, directeur du CRI	Audition "Pacte entre les générations" de M. François Taddei, directeur du Centre de recherches interdisciplinaires -CRI	2018-07-17 10:10:00	2018-07-17 11:15:00	\N	\N	1	0	\N	\N
317515	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	PLF 2019	2018-10-31 09:30:00	2018-10-31 11:30:00	\N	\N	1	0	\N	\N
317517	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	PLF 2019	2018-10-31 09:00:00	2018-10-31 12:00:00	\N	\N	1	0	\N	\N
317519	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	PLF 2019	2018-10-30 08:30:00	2018-10-30 09:15:00	\N	\N	1	0	\N	\N
317521	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	PLF 2019	2018-10-29 13:30:00	2018-10-29 14:00:00	\N	\N	1	0	\N	\N
317523	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	PLF 2019	2018-10-29 19:15:00	2018-10-29 20:00:00	\N	\N	1	0	\N	\N
345285	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL et PJLO Réforme justice	PJL et PJLO Réforme justice	2019-02-12 21:40:00	2019-02-13 00:15:00	\N	\N	53	0	\N	\N
345289	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Orientation des mobilités	PJL Orientation des mobilités	2019-03-27 21:35:00	2019-03-28 01:00:00	\N	\N	69	0	\N	\N
345290	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2019-03-21 15:00:00	2019-03-21 16:05:00	\N	\N	252	0	\N	\N
345291	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLO Modification du statut d'autonomie de la Polynésie française	\N	2019-01-21 16:00:00	2019-01-21 19:30:00	\N	\N	1	0	\N	\N
345293	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLO Modification du statut d'autonomie de la Polynésie française	\N	2019-01-24 10:00:00	2019-01-24 12:00:00	\N	\N	1	0	\N	\N
346501	GIA	AUCUNE	\N	\N	\N	Déjeuner-débat avec M. François PARADIS, Pdt AN du Québec	Déjeuner-débat avec M. François PARADIS, Pdt AN du Québec	2019-01-29 13:00:00	2019-01-29 14:30:00	\N	\N	12	0	602	\N
347505	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2019-01-22 09:00:00	2019-01-22 09:45:00	\N	\N	1	0	\N	\N
347509	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2019-01-22 09:45:00	2019-01-22 10:30:00	\N	\N	3	0	\N	\N
347513	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2019-01-22 10:30:00	2019-01-22 11:15:00	\N	\N	3	0	\N	\N
347517	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2019-01-22 14:45:00	2019-01-22 15:45:00	\N	\N	2	0	\N	\N
347520	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2019-01-22 15:45:00	2019-01-22 16:30:00	\N	\N	3	0	\N	\N
347524	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2019-01-22 16:30:00	2019-01-22 17:15:00	\N	\N	1	0	\N	\N
347526	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2019-01-23 14:30:00	2019-01-23 15:15:00	\N	\N	2	0	\N	\N
347529	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2019-01-23 15:15:00	2019-01-23 16:00:00	\N	\N	2	0	\N	\N
347535	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2019-01-31 09:00:00	2019-01-31 10:00:00	\N	\N	4	0	\N	\N
347557	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2019-01-31 10:00:00	2019-01-31 10:45:00	\N	\N	6	0	\N	\N
347838	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2019-01-31 10:45:00	2019-02-01 11:30:00	\N	\N	3	0	\N	\N
347845	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2019-01-31 11:30:00	2019-01-31 12:15:00	\N	\N	4	0	\N	\N
347854	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2019-01-31 14:00:00	2019-01-31 15:00:00	\N	\N	3	0	\N	\N
347878	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Etats Généraux de l'Alimentation	Etats Généraux de l'Alimentation	2019-01-29 13:45:00	2019-01-29 15:00:00	\N	\N	10	0	\N	\N
347903	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Etats Généraux de l'Alimentation	Etats Généraux de l'Alimentation	2019-01-30 15:30:00	2019-01-30 18:00:00	\N	\N	8	0	\N	\N
348042	MECSS	AUDRAP	\N	\N	MECSS	Prise en charge financière de la dépendance des personnes âgées	\N	2019-02-05 13:30:00	2019-02-05 16:30:00	\N	\N	3	0	\N	\N
348045	MECSS	AUDRAP	\N	\N	MECSS	Prise en charge financière de la dépendance des personnes âgées	\N	2019-02-06 15:00:00	2019-02-06 19:00:00	\N	\N	4	0	\N	\N
349806	DELEGATION	AUDRAP	\N	\N	PROS	Audition de ATOUT FRANCE	\N	2019-03-12 09:30:00	2019-03-12 11:00:00	\N	\N	1	0	\N	\N
295836	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2018-07-11 09:00:00	2018-07-11 13:00:00	2018-07-13 16:28:17	2018-07-13 16:34:58	40	0	\N	\N
301908	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion	Réunion	2018-07-25 09:30:00	2018-07-25 09:35:00	2018-07-25 18:18:55	2018-07-26 17:23:10	24	3	\N	\N
353878	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Orientation des mobilités	\N	2019-02-12 16:30:00	2019-02-12 18:25:00	\N	\N	1	0	\N	\N
353895	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Prévenir et sanctionner les violences lors des manifestations	\N	2019-02-18 16:15:00	2019-02-18 17:15:00	\N	\N	2	0	\N	\N
355933	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-03-05 16:35:00	2019-03-05 18:05:00	2019-03-06 14:19:24	2019-03-06 16:49:26	55	0	\N	\N
355935	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-03-06 09:30:00	2019-03-06 12:20:00	2019-03-06 14:17:36	2019-03-06 16:49:19	29	0	\N	\N
355936	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-03-06 17:35:00	2019-03-06 19:05:00	2019-03-07 10:06:51	2019-03-07 12:20:41	37	0	\N	\N
355944	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Nouveaux territoires du sport	MI Nouveaux territoires du sport	2019-02-20 17:40:00	2019-02-20 18:15:00	\N	\N	7	0	\N	\N
356061	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Turquie	\N	2019-02-20 15:45:00	2019-02-20 17:00:00	\N	\N	1	0	\N	\N
356067	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	\N	\N	2019-03-21 11:30:00	2019-03-21 12:45:00	\N	\N	1	0	\N	\N
356256	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Fraude sociale : déplacement à Tours	Fraude sociale : déplacement à Tours	2019-02-26 08:00:00	2019-02-26 19:00:00	\N	\N	1	0	\N	\N
358050	GIA	AUCUNE	\N	\N	\N	Déjeuner en l'honneur d'une délégation de sénateurs des Pays-Bas	Déjeuner en l'honneur d'une délégation de sénateurs des Pays-Bas	2019-03-14 12:15:00	2019-03-14 14:00:00	\N	\N	2	0	599	\N
358890	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Turquie	\N	2019-03-06 14:30:00	2019-03-06 15:55:00	\N	\N	2	0	\N	\N
358893	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Turquie	\N	2019-03-06 15:55:00	2019-03-06 17:00:00	\N	\N	3	0	\N	\N
358897	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Turquie	\N	2019-03-07 11:30:00	2019-03-07 12:40:00	\N	\N	3	0	\N	\N
362803	GIA	AUCUNE	\N	\N	\N	Petit déjeuner avec l'ambassadeur du Kazakhstan 	Petit déjeuner avec l'ambassadeur du Kazakhstan 	2019-03-20 08:30:00	2019-03-20 09:30:00	\N	\N	6	0	556	\N
363184	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Nouveaux territoires de l'éducation	MI Nouveaux territoires de l'éducation	2019-03-20 10:00:00	2019-03-20 10:45:00	\N	\N	2	0	\N	\N
363189	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Nouveaux territoires de l'éducation	MI Nouveaux territoires de l'éducation	2019-03-20 14:30:00	2019-03-20 16:00:00	\N	\N	6	0	\N	\N
363409	ETUDES	AUCUNE	\N	\N	\N	Audition de représentants de France Gaz renouvelables	Audition de représentants de France Gaz renouvelables	2019-03-20 08:00:00	2019-03-20 09:10:00	\N	\N	13	0	\N	906
363556	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-03-27 11:00:00	2019-03-27 12:30:00	\N	\N	0	0	\N	\N
364409	MISSION	AUDRAP	\N	INFRACTIONS	\N	Auditions rapporteures	\N	2019-03-28 11:15:00	2019-03-28 13:00:00	\N	\N	3	0	\N	\N
364413	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI handicap	Auditions DGOS, Table ronde syndicats et table ronde d'universitaires et chercheurs	2019-03-19 13:30:00	2019-03-19 19:45:00	\N	\N	2	0	\N	\N
364420	GIA	AUCUNE	\N	\N	\N	Déjeuner avec le ministre des Affaires étrangères de Tanzanie	\N	2019-02-21 13:00:00	2019-02-21 14:30:00	\N	\N	4	0	622	\N
364436	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 2019 - Pilotage des grands projets informatiques - Cour des comptes	58-2 2019 - Pilotage des grands projets informatiques - Cour des comptes	2019-03-18 16:00:00	2019-03-18 16:45:00	\N	\N	1	0	\N	\N
233010	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	GT revitalisation centres : table ronde élus locaux	\N	2018-01-17 15:00:00	2018-01-17 17:15:00	\N	\N	12	0	\N	\N
234807	GIA	AUCUNE	\N	\N	\N	entetien avec des journalistes coréens	Entetien avec les correspondants de la presse coréenne à Paris	2018-01-15 11:30:00	2018-01-15 12:30:00	\N	\N	1	0	613	\N
234890	MECSS	AUCUNE	\N	\N	MECSS	\N	\N	2018-01-17 15:00:00	2018-01-17 16:20:00	2018-01-17 16:20:10	2018-01-17 16:57:39	15	0	\N	\N
235087	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Droit des sites naturels ouverts au public	\N	2018-01-17 14:30:00	2018-01-17 16:20:00	\N	\N	1	0	\N	\N
235404	GIA	AUCUNE	\N	\N	\N	Assemblée générale	Assemblée générale reconstitutive du groupe d'amitié France - Afrique du Sud, Lesotho, Swaziland	2018-01-17 14:20:00	2018-01-17 14:35:00	\N	\N	5	0	574	\N
235426	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Droit des sites naturels ouverts au public	\N	2018-01-18 14:45:00	2018-01-18 15:30:00	\N	\N	2	0	\N	\N
238776	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Réforme des retraites 2018 - Audition Haut-commissaire à la réforme des retraites	Contrôle Réforme des retraites 2018 - Audition Haut-commissaire à la réforme des retraites	2018-01-24 16:00:00	2018-01-24 17:00:00	\N	\N	1	0	\N	\N
238778	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Réforme des retraites 2018 - Audition Comité de suivi des retraites	Contrôle Réforme des retraites 2018 - Audition Comité de suivi des retraites	2018-01-24 17:00:00	2018-01-24 18:00:00	\N	\N	1	0	\N	\N
238869	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition  de M. Jean-Christophe Fromantin, 	Audition  de M. Jean-Christophe Fromantin, président du conseil d¿administration d¿EXPOFRANCE 2025	2018-01-30 16:05:00	2018-01-30 17:40:00	2018-01-31 15:14:41	2018-01-31 17:14:02	35	0	\N	\N
238870	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de M. Laurent Vallée	Audition de M. Laurent Vallée, secrétaire général du groupe 	2018-01-31 09:35:00	2018-01-31 11:05:00	2018-01-31 15:15:05	2018-01-31 17:14:39	39	0	\N	\N
238871	COM_PERMANENTE	AUTRE	\N	CDD	\N	PJL n° 203 J.O. 2024, et PJL n°244 territoires littoraux 	PJL n° 203 J.O. 2024, et PJL n°244 développement durable des territoires littoraux 	2018-01-30 09:30:00	2018-01-30 10:15:00	2018-01-31 14:04:55	2018-01-31 14:23:12	31	1	\N	\N
238872	COM_PERMANENTE	AUTRE	\N	CDD	\N	Table ronde sur les Assises de la mobilité	Table ronde  sur les Assises de la mobilité	2018-01-31 09:35:00	2018-01-31 11:55:00	2018-01-31 14:53:42	2018-01-31 17:14:42	34	0	\N	\N
238880	COM_ENQUETE	PLENIERE	\N	FORCES	\N	\N	\N	2018-01-30 13:35:00	2018-01-30 14:25:00	2018-01-31 17:22:15	2018-01-31 17:23:06	19	0	\N	\N
240324	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2018-03-20 09:30:00	2018-03-20 12:25:00	\N	\N	41	0	\N	\N
240325	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Protection données personnelles après-midi	PJL Protection données personnelles après-midi	2018-03-20 18:00:00	2018-03-20 20:00:00	\N	\N	85	0	\N	\N
240326	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Protection données personnelles soir	PJL Protection données personnelles soir	2018-03-20 21:30:00	2018-03-21 00:50:00	\N	\N	70	0	\N	\N
240327	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Conseil européen	Débat Conseil européen	2018-03-21 14:30:00	2018-03-21 17:15:00	\N	\N	109	0	\N	\N
240328	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Protection données personnelles après-midi	PJL Protection données personnelles après-midi	2018-03-21 17:30:00	2018-03-21 20:05:00	\N	\N	54	0	\N	\N
240329	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Protection données personnelles soir	PJL Protection données personnelles soir	2018-03-21 21:35:00	2018-03-22 00:40:00	\N	\N	31	0	\N	\N
240330	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Marché intérieur matin	PJL Marché intérieur matin	2018-03-22 10:30:00	2018-03-22 12:10:00	\N	\N	33	0	\N	\N
240337	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Régime d'asile européen matin	PPL Régime d'asile européen matin	2018-01-25 10:30:00	2018-01-25 11:55:00	\N	\N	0	0	\N	\N
244008	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe France-Chypre	Assemblée générale du groupe France-Chypre	2018-02-07 14:05:00	2018-02-07 14:15:00	\N	\N	2	0	585	\N
244011	GIA	AUCUNE	\N	\N	\N	Entretien avec les diplomates slovènes en poste à Paris	Entretien avec les diplomates slovènes en poste à Paris	2018-02-08 12:45:00	2018-02-08 14:25:00	\N	\N	4	0	529	\N
244849	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT Evolution de la fiscalité locale - Pistes de travail révision des valeurs locatives	GT Evolution de la fiscalité locale - Pistes de travail révision des valeurs locatives	2018-02-13 15:30:00	2018-02-13 16:25:00	\N	\N	11	0	\N	\N
245613	ETUDES	AUCUNE	\N	\N	\N	GE Energie	\N	2018-02-14 08:15:00	2018-02-14 09:20:00	\N	\N	23	0	\N	906
246494	ETUDES	AUCUNE	\N	\N	\N	Réunion constitutive	Réunion constitutive	2018-02-15 14:15:00	2018-02-15 14:50:00	\N	\N	15	0	\N	928
249547	GIA	AUCUNE	\N	\N	\N	Entretien avec les ambassadeurs de la zone	Entretien avec les ambassadeurs de la zone	2018-02-20 20:00:00	2018-02-20 22:00:00	\N	\N	22	0	609	\N
250901	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Sensibilisation protection infos sensibles	\N	2018-03-07 10:05:00	2018-03-07 11:30:00	\N	\N	16	0	\N	\N
250919	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	CAE	\N	Module de sensibilisation DGSI	Module de sensibilisation à la protection des informations sensibles DGSI	2018-03-07 10:05:00	2018-03-07 11:30:00	\N	\N	17	0	\N	\N
254464	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions rapporteur	\N	2018-03-13 14:25:00	2018-03-13 16:40:00	\N	\N	0	0	\N	\N
255090	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Réforme Action Logement	Réforme Action Logement	2018-03-13 15:30:00	2018-03-13 16:45:00	\N	\N	1	0	\N	\N
255799	DELEGATION	AUCUNE	\N	\N	211	Audition de Sandrine Dauphin et Stéphanie Condon sur le projet Virage Dom	Audition de Sandrine Dauphin et Stéphanie Condon sur le projet Virage Dom	2018-03-15 09:00:00	2018-03-15 10:30:00	2018-03-15 11:22:11	2018-03-15 11:57:46	8	0	\N	\N
256505	COM_EURO	AUTRE_NON_PLENIERE	\N	AFEU	\N	Lituanie	Entretien avec M. Arunas Gelunas, président du groupe d'amitié Lituanie-France du Parlement lituanien	2018-03-20 08:45:00	2018-03-20 09:30:00	\N	\N	1	0	\N	\N
256509	COM_EURO	AUTRE_NON_PLENIERE	\N	AFEU	\N	Parlement de Lettonie	Entretien du Bureau avec MM. Oj¿rs ¿. Kalni¿¿ et Edvards Smilt¿ns, députés du Parlement de Lettonie	2018-03-20 14:20:00	2018-03-20 15:05:00	\N	\N	4	0	\N	\N
257487	COM_ENQUETE	PLENIERE	\N	FORCES	\N	Auditions CE FSI	Auditions CE FSI	2018-03-20 18:10:00	2018-03-20 19:30:00	2018-03-21 18:28:23	2018-03-22 12:22:05	9	0	\N	\N
257543	CONF_PRES	AUCUNE	\N	\N	\N	\N	\N	2018-03-07 18:45:00	2018-03-07 19:35:00	\N	\N	23	0	\N	\N
257571	CONF_PRES	AUCUNE	\N	\N	\N	\N	\N	2018-03-13 17:50:00	2018-03-13 18:00:00	\N	\N	24	0	\N	\N
258934	DELEGATION	AUCUNE	\N	\N	206	Présentation rapport de M. Cédric Villani sur l'intelligence artificielle	Présentation, par M. Cédric Villani, de son rapport au Premier ministre sur l'intelligence artificielle	2018-04-05 09:40:00	2018-04-05 11:25:00	2018-04-05 15:19:43	2018-04-06 14:33:38	10	0	\N	\N
259033	MISSION	AUCUNE	\N	ALSTOM	\N	\N	\N	2018-03-13 14:30:00	2018-03-13 16:30:00	\N	\N	4	0	\N	\N
259038	ETUDES	AUCUNE	\N	\N	\N	\N	\N	2018-03-14 08:15:00	2018-03-14 09:30:00	\N	\N	18	0	\N	906
259070	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Tourisme	\N	2018-03-21 17:00:00	2018-03-21 19:30:00	\N	\N	3	0	\N	\N
259081	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	GT POLLUTION DE L'AIR	\N	2018-03-20 13:00:00	2018-03-20 16:00:00	\N	\N	1	0	\N	\N
259083	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	GT POLLUTION DE L'AIR	\N	2018-03-21 08:30:00	2018-03-21 09:30:00	\N	\N	2	0	\N	\N
259086	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	gt poll	\N	2018-03-21 13:00:00	2018-03-21 19:00:00	\N	\N	1	0	\N	\N
259090	MISSION	AUDRAP	\N	ALSTOM	\N	MI ALSTOM - Auditions président&rapporteur	\N	2018-03-21 14:15:00	2018-03-21 16:15:00	\N	\N	3	0	\N	\N
261003	DELEGATION	AUCUNE	\N	\N	COLTER	Table ronde "Responsabilité pénale et obligations déontologiques des élus locaux"	\N	2018-04-05 09:00:00	2018-04-05 11:00:00	2018-04-05 12:06:39	2018-04-05 14:04:51	17	0	\N	\N
295690	DELEGATION	AUDRAP	\N	\N	PROS	Audition "Nouvelles mobilités" de M. Olivier Schneider, pdt de la FUB	Audition "Nouvelles mobilités" de M. Olivier Schneider, pdt de la Fédération française des usagers de la bicyclette -FUB	2018-07-10 14:00:00	2018-07-10 15:30:00	\N	\N	2	0	\N	\N
295691	DELEGATION	AUDRAP	\N	\N	PROS	Audition "Nouvelles mobilités" d'Île-de-France Mobilités	Audition "Nouvelles mobilités" d'Île-de-France Mobilités	2018-07-10 16:00:00	2018-07-10 16:45:00	\N	\N	1	0	\N	\N
295711	COM_ENQUETE	PLENIERE	\N	HAUTE	\N	Auditions	Auditions	2018-07-04 15:30:00	2018-07-04 19:00:00	2018-07-06 17:41:09	2018-07-06 17:53:15	10	0	\N	\N
295726	COM_ENQUETE	PLENIERE	\N	HAUTE	\N	Auditions	Auditions	2018-07-05 10:35:00	2018-07-05 11:40:00	2018-07-06 17:48:05	2018-07-06 17:53:14	8	0	\N	\N
295736	COM_ENQUETE	PLENIERE	\N	HAUTE	\N	Audition	Audition	2018-07-05 12:05:00	2018-07-05 13:05:00	2018-07-06 17:49:40	2018-07-06 17:53:06	8	0	\N	\N
295746	COM_ENQUETE	PLENIERE	\N	HAUTE	\N	Audition	Audition	2018-07-05 14:00:00	2018-07-05 14:50:00	2018-07-06 17:51:38	2018-07-06 17:53:09	5	0	\N	\N
298504	DELEGATION	AUDRAP	\N	\N	206	Audition "Stockage de l'électricité" d'IFP Energies nouvelles	Audition "Stockage de l'électricité" d'IFP Energies nouvelles	2018-07-18 11:30:00	2018-07-18 12:30:00	\N	\N	1	0	\N	\N
312545	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2018-10-16 14:35:00	2018-10-16 16:30:00	\N	\N	3	0	\N	\N
321795	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2019 - Avis Immigration, asile et intégration	\N	2018-11-06 14:30:00	2018-11-06 18:05:00	\N	\N	2	0	\N	\N
321798	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2019 - Justice judiciaire	\N	2018-11-08 16:30:00	2018-11-08 20:00:00	\N	\N	1	0	\N	\N
321802	GIA	AUCUNE	\N	\N	\N	Entretien avec une délégation de sénateurs et fonctionnaires du Sénat ivoirien	Entretien avec une délégation de sénateurs et fonctionnaires du Sénat ivoirien	2018-11-08 12:45:00	2018-11-08 14:30:00	\N	\N	6	0	573	\N
321847	DELEGATION	AUDRAP	\N	\N	206	Audition INRA (Risques sanitaires)	Audition INRA (Risques sanitaires)	2018-11-21 16:15:00	2018-11-21 17:30:00	\N	\N	2	0	\N	\N
321848	DELEGATION	AUDRAP	\N	\N	206	Audition AFIS (Risques sanitaires)	Audition AFIS (Risques sanitaires)	2018-11-21 17:30:00	2018-11-21 18:30:00	\N	\N	2	0	\N	\N
322034	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2019 - Développement des entreprises	\N	2018-11-06 15:00:00	2018-11-06 15:45:00	\N	\N	1	0	\N	\N
322036	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2019 - Développement des entreprises	\N	2018-11-06 16:30:00	2018-11-06 18:45:00	\N	\N	1	0	\N	\N
250553	COM_PERMANENTE	AUTRE	\N	LOIS	\N	nom. rap+ PPLO Etudes d'impact + PPL Eval. pol. publ + PPL Simplif. code commerce	\N	2018-03-07 08:55:00	2018-03-07 09:20:00	2018-03-07 14:45:51	2018-03-07 18:23:05	36	0	\N	\N
322038	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2019 - Développement des entreprises	\N	2018-11-08 10:30:00	2018-11-08 12:00:00	\N	\N	1	0	\N	\N
322040	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2019 - Développement des entreprises	\N	2018-11-08 16:40:00	2018-11-08 17:50:00	\N	\N	1	0	\N	\N
323981	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2019 - Justice judiciaire	\N	2018-11-12 10:30:00	2018-11-13 12:00:00	\N	\N	1	0	\N	\N
323983	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2019 - Justice judiciaire	\N	2018-11-12 14:00:00	2018-11-12 19:30:00	\N	\N	1	0	\N	\N
324181	COM_EURO	AUDRAP	\N	AFEU	\N	Parquet européen	Audition rapporteur - Parquet européen	2018-11-14 14:00:00	2018-11-14 15:00:00	\N	\N	2	0	\N	\N
324640	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapport PLF 2019 PJJ	\N	2018-11-15 09:00:00	2018-11-15 10:50:00	\N	\N	1	0	\N	\N
324702	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT Biocarburants	Auditions GT Biocarburants	2018-11-14 16:30:00	2018-11-14 17:20:00	\N	\N	7	0	\N	\N
324704	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT Biocarburants	Auditions GT Biocarburants	2018-11-14 15:40:00	2018-11-14 16:30:00	\N	\N	4	0	\N	\N
324706	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT Biocarburants	Auditions GT Biocarburants	2018-11-14 17:20:00	2018-11-14 18:30:00	\N	\N	6	0	\N	\N
324709	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 -  RCT - Cabinet Gourault et DGCL	PLF pour 2019 -  RCT - Cabinet Gourault et DGCL	2018-11-13 09:30:00	2018-11-13 10:50:00	\N	\N	2	0	\N	\N
324712	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Recherche - Intelligence artificielle	PLF pour 2019 - Recherche - Intelligence artificielle	2018-11-14 11:00:00	2018-11-14 11:30:00	\N	\N	1	0	\N	\N
324831	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Plf 2019 - Crédits de l'audiovisuel public	Plf 2019 - Crédits de l'audiovisuel public	2018-11-14 15:30:00	2018-11-14 16:30:00	\N	\N	2	0	\N	\N
324835	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Presse	PLF 2019 - Crédits Presse	2018-11-14 16:00:00	2018-11-14 17:00:00	\N	\N	1	0	\N	\N
324877	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLFR pour 2018 - Examen des amendements de séance	PLFR pour 2018 - Examen des amendements de séance	2018-11-19 14:35:00	2018-11-19 14:45:00	2018-11-19 16:38:55	2018-11-19 16:51:17	18	0	\N	\N
324885	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2019 - Examen Rapport Agriculture	PLF pour 2019 - Examen Rapport Agriculture	2018-11-20 09:20:00	2018-11-20 10:30:00	2018-11-22 15:52:31	2018-11-22 16:06:07	24	0	\N	\N
324892	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2019 - Examen Rapports Cohésion des territoires	PLF pour 2019 - Examen Rapports Cohésion des territoires	2018-11-20 16:20:00	2018-11-20 17:30:00	2018-11-21 09:33:03	2018-11-21 09:48:22	34	0	\N	\N
324897	DELEGATION	AUDRAP	\N	\N	PROS	Audition Météo France	\N	2018-12-04 14:00:00	2018-12-04 14:45:00	\N	\N	1	0	\N	\N
324909	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Audition plénière - MCI Répression infractions sexuelles sur mineurs	\N	2018-11-21 16:00:00	2018-11-21 18:00:00	\N	\N	0	0	\N	\N
324910	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Examen d'un rapport pour avis - Pouvoirs publics	\N	2018-11-27 09:05:00	2018-11-27 10:20:00	2018-11-27 11:21:23	2018-11-28 11:50:26	20	1	\N	\N
324913	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2019 - Examen Rapports Écologie	PLF pour 2019 - Examen Rapports Écologie	2018-11-21 17:30:00	2018-11-21 19:05:00	2018-11-22 14:55:00	2018-11-22 14:56:09	18	0	\N	\N
324917	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2019 - Examen définitif de l'équilibre des missions et AMDTS ART Liminaire et 37	PLF pour 2019 - Examen définitif de l'équilibre des missions et AMDTS ART Liminaire et 37	2018-11-22 09:05:00	2018-11-22 10:00:00	2018-11-22 14:56:29	2018-11-22 15:34:57	31	0	\N	\N
324921	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2019 -  Examen des amendements de séance sur la première partie	PLF pour 2019 -  Examen des amendements de séance sur la première partie	2018-11-23 09:00:00	2018-11-23 11:05:00	2018-11-23 12:03:04	2018-11-23 14:58:31	22	0	\N	\N
325065	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2019 - Justice judiciaire	\N	2018-11-15 11:00:00	2018-11-15 12:00:00	\N	\N	1	0	\N	\N
325208	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2019 - Développement des entreprises	\N	2018-11-14 17:00:00	2018-11-14 17:45:00	\N	\N	1	0	\N	\N
325210	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-11-13 14:30:00	2018-11-13 16:00:00	\N	\N	2	0	\N	\N
325213	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-11-13 18:00:00	2018-11-13 18:45:00	\N	\N	1	0	\N	\N
326848	DELEGATION	AUDRAP	\N	\N	PROS	Audition de l'ANSES	Agence nationale de sécurité sanitaire de l'alimentation, de l'environnement et du travail  (ANSES) 	2018-12-04 09:15:00	2018-12-04 10:30:00	\N	\N	2	0	\N	\N
326855	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	PROS	Débat : Vers une tarification à l'usage  des mobilités ?	Débat : Vers une tarification à l'usage  des mobilités ?	2018-12-12 14:35:00	2018-12-12 17:50:00	\N	\N	13	0	\N	\N
328576	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Communes nouvelles - diversité des territoires	\N	2018-11-21 14:30:00	2018-11-21 16:00:00	\N	\N	1	0	\N	\N
328737	GIA	AUCUNE	\N	\N	\N	Petit-déjeuner avec Livia Leu, ambassadrice de Suisse en France	\N	2018-11-22 08:30:00	2018-11-22 09:30:00	\N	\N	9	0	610	\N
213639	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2018 -  audition Florence PARLY Ministre des Armées	PLF pour 2018 -  audition Florence PARLY Ministre des Armées	2017-10-31 15:00:00	2017-10-31 16:40:00	2017-11-02 10:12:23	2017-11-02 17:16:06	26	0	\N	\N
216549	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2017-11-15 11:15:00	2017-11-15 13:20:00	2017-11-15 15:14:35	2017-11-15 16:15:08	37	0	\N	\N
216728	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2018 - avis "Administration pénitentiaire"	\N	2017-11-08 14:10:00	2017-11-08 17:30:00	\N	\N	1	0	\N	\N
216763	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2018 - avis "Administration pénitentiaire"	\N	2017-11-09 09:00:00	2017-11-09 10:00:00	\N	\N	1	0	\N	\N
217374	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF	\N	2017-11-07 15:30:00	2017-11-07 17:30:00	\N	\N	2	0	\N	\N
217385	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2018	\N	2017-11-08 16:00:00	2017-11-08 16:45:00	\N	\N	2	0	\N	\N
217390	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2018	\N	2017-11-09 08:00:00	2017-11-09 08:45:00	\N	\N	1	0	\N	\N
324696	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2018-11-21 09:35:00	2018-11-21 11:10:00	2018-11-21 11:48:46	2018-11-21 14:52:38	45	0	\N	\N
324906	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF2019 Tome II - PPL 730 Examen AMDTS séance -PLF2019 Rapports MIRES et RCT	PLF2019 Tome II - PPL 730 Examen AMDTS séance -PLF2019 Rapports MIRES et RCT	2018-11-21 08:35:00	2018-11-21 12:15:00	2018-11-21 12:25:54	2018-11-21 14:52:40	46	0	\N	\N
216548	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2017-11-15 09:35:00	2017-11-15 11:15:00	2017-11-15 15:15:50	2017-11-15 16:15:21	42	0	\N	\N
217392	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2018	\N	2017-11-09 13:50:00	2017-11-09 14:45:00	\N	\N	1	0	\N	\N
220238	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition   de M. Stéphane Travert, ministre de l¿Agriculture et de l¿Alimentation	Audition   de M. Stéphane Travert, ministre de l¿Agriculture et de l¿Alimentation	2017-11-21 16:45:00	2017-11-21 19:05:00	2017-11-22 13:42:09	2017-11-22 15:31:49	41	0	\N	\N
220241	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition   de M. Jacques Mézard, et de M. Julien Denormandie 	Audition   de M. Jacques Mézard, ministre de la Cohésion des territoires, et de M. Julien Denormandie, secrétaire d¿État	2017-11-22 17:35:00	2017-11-22 19:15:00	2017-11-23 10:28:22	2017-11-23 14:23:37	35	0	\N	\N
226080	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2018 - Examen Amdts séance Missions Culture-Médias-Travail & Emploi	PLF pour 2018 - Examen Amdts séance Missions Culture-Médias-Travail & Emploi	2017-12-04 09:35:00	2017-12-04 10:00:00	2017-12-06 16:25:50	2017-12-06 16:28:14	9	0	\N	\N
226081	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour  2018 - Examen amtds séance Mission AEE	PLF pour  2018 - Examen amtds séance Mission Action Extérieure de l'État	2017-12-04 21:05:00	2017-12-04 21:15:00	2017-12-06 16:26:05	2017-12-06 16:28:13	8	1	\N	\N
226099	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2018 - Exam. articles non rattachés-Exam. Mission Cohésion-Exam. Amdts Sécurités	PLF pour 2018 - Exam. articles non rattachés-Examen Mission Cohésion Territoires-Examen Amdts Mission Sécurités	2017-12-05 08:30:00	2017-12-05 10:15:00	2017-12-06 16:26:22	2017-12-06 16:28:11	34	0	\N	\N
226144	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Sécurités  - Sécurité routière	PLF pour 2018 - Sécurités - Sécurité routière - Audition 40 millions d'automobilistes	2017-11-29 14:30:00	2017-11-29 15:50:00	\N	\N	1	0	\N	\N
226146	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Sécurités - Sécurité routière	PLF pour 2018 - Sécurités  - Sécurité routière - Audition ANTAI	2017-11-30 09:40:00	2017-11-30 10:20:00	\N	\N	1	0	\N	\N
226148	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2018  - Action extérieure de l'Etat -  Ministère des affaires étrangères	PLF pour 2018  - Action extérieure de l'Etat - Audition Cabinet Ministère des affaires étrangères	2017-11-29 16:30:00	2017-11-29 17:30:00	\N	\N	2	0	\N	\N
226151	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2018 - Cohésion des territoires - Cabinet du premier ministre	PLF pour 2018 - Cohésion des territoires - Audition Cabinet du premier ministre	2017-11-29 14:00:00	2017-11-29 14:45:00	\N	\N	1	0	\N	\N
233189	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	PPL Application du régime d'asile européen	\N	2018-01-08 08:00:00	2018-01-09 15:30:00	\N	\N	5	0	\N	\N
233199	COM_PERMANENTE	AUTRE	\N	CDD	\N	Audition de Mme Anne-Marie Idrac	Audition de Mme Anne-Marie Idrac, Haute responsable chargée de piloter la stratégie nationale sur le véhicule autonome	2018-01-17 09:30:00	2018-01-17 11:25:00	2018-01-18 15:11:21	2018-01-18 16:38:30	38	0	\N	\N
233205	COM_PERMANENTE	AUTRE	\N	CDD	\N	Audition de M. Jean-Marc Janaillac,	Audition de M. Jean-Marc Janaillac, Président-directeur général du groupe Air France-KLM	2018-01-18 11:15:00	2018-01-18 12:40:00	2018-01-18 15:10:42	2018-01-18 16:38:26	24	0	\N	\N
239742	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe France-Balkans occidentaux	Assemblée générale du groupe France-Balkans occidentaux	2018-01-31 13:45:00	2018-01-31 14:15:00	\N	\N	5	0	674	\N
243974	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe	Assemblée générale du groupe	2018-02-07 14:00:00	2018-02-07 14:50:00	\N	\N	11	0	625	\N
247635	GIA	AUCUNE	\N	\N	\N	Déjeuner avec l'ambassadeur de France au Kazakhstan	\N	2018-02-06 13:00:00	2018-02-06 14:30:00	\N	\N	3	0	556	\N
250088	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Protection des mineurs	PPL Protection des mineurs	2018-03-27 14:30:00	2018-03-27 16:30:00	\N	\N	161	0	\N	\N
250089	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2018-03-27 16:45:00	2018-03-27 17:55:00	\N	\N	287	0	\N	\N
250090	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Protection des mineurs	PPL Protection des mineurs	2018-03-27 18:15:00	2018-03-27 20:40:00	\N	\N	96	0	\N	\N
250092	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR Équipements sportifs	PPR Équipements sportifs	2018-03-28 14:30:00	2018-03-28 16:00:00	\N	\N	78	0	\N	\N
250093	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Avenir lignes LGV	DébatDébat Avenir lignes LGV	2018-03-28 16:00:00	2018-03-28 17:55:00	\N	\N	90	0	\N	\N
253013	GIA	AUCUNE	\N	\N	\N	Entretien avec S.E. M. Philippe VUCAK, Ambassadeur de Croatie en France	Entretien avec S.E. M. Philippe VUCAK, Ambassadeur de Croatie en France	2018-03-08 08:30:00	2018-03-08 09:30:00	\N	\N	9	0	647	\N
253024	GIA	AUCUNE	\N	\N	\N	Entretien avec  une délégation de dignitaires et de magistrats du Kurdistan d'Irak	Entretien avec  une délégation de dignitaires et de magistrats du Kurdistan d'Irak	2018-03-08 09:30:00	2018-03-08 10:30:00	\N	\N	2	0	CHRETORIENT	CHRETORIENT
256120	SEANCE_PLENIERE	SCRUSOL	881	\N	\N	Scrutin solennel sur l'ensemble du  PJL pour un État au service d'une société de Confiance	Scrutin solennel sur l'ensemble du  PJL pour un État au service d'une société de Confiance	2018-03-20 16:00:00	2018-03-20 16:30:00	\N	\N	0	0	\N	\N
256121	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	881	\N	\N	Explications de vote sur l'ensemble	Explications de vote sur l'ensemble	2018-03-20 15:00:00	2018-03-20 15:55:00	\N	\N	300	0	\N	\N
256482	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Indivision successorale et politique du logement ultramarin	\N	2018-03-14 14:10:00	2018-03-14 17:00:00	\N	\N	1	0	\N	\N
256486	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Indivision successorale et politique du logement ultramarin	\N	2018-03-14 19:00:00	2018-03-14 19:45:00	\N	\N	1	0	\N	\N
256490	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Indivision successorale et politique du logement ultramarin	\N	2018-03-19 11:00:00	2018-03-19 12:10:00	\N	\N	1	0	\N	\N
256496	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Indivision successorale et politique du logement ultramarin	\N	2018-03-19 15:00:00	2018-03-19 16:30:00	\N	\N	1	0	\N	\N
256498	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Indivision successorale et politique du logement ultramarin	\N	2018-03-19 17:30:00	2018-03-19 18:00:00	\N	\N	1	0	\N	\N
289275	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Lutte contre les violences sexuelles et sexistes	\N	2018-06-21 11:00:00	2018-06-21 11:45:00	\N	\N	1	0	\N	\N
220236	COM_PERMANENTE	AUTRE	\N	CDD	\N	PLF 2018 "Cohésion des territoires" et "Transports aériens"	PLF 2018 "Cohésion des territoires" et "Transports aériens"	2017-11-22 09:30:00	2017-11-22 12:15:00	2017-11-22 17:11:48	2017-11-23 14:23:51	43	0	\N	\N
289277	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Lutte contre les violences sexuelles et sexistes	\N	2018-06-21 14:00:00	2018-06-21 16:15:00	\N	\N	1	0	\N	\N
292362	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion	Réunion	2018-06-28 10:45:00	2018-06-28 12:20:00	2018-06-28 12:37:05	2018-06-28 13:33:35	16	0	\N	\N
292395	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	PPLO PPL AN RECUE DE SOLON PJL Lutte contre les violences sexuelles et sexistes	\N	2018-06-19 08:30:00	2018-06-19 11:00:00	\N	\N	5	0	\N	\N
292449	COM_ENQUETE	DEPLACEMENT	\N	FORCES	\N	Déplacement à Calais	\N	2018-03-16 06:45:00	2018-03-16 18:15:00	\N	\N	6	0	\N	\N
292496	COM_ENQUETE	DEPLACEMENT	\N	FORCES	\N	\N	\N	2018-03-26 05:15:00	2018-03-26 22:00:00	\N	\N	6	0	\N	\N
292573	COM_ENQUETE	DEPLACEMENT	\N	FORCES	\N	\N	\N	2018-04-18 13:00:00	2018-04-18 20:15:00	\N	\N	7	0	\N	\N
310941	GIA	AUCUNE	\N	\N	\N	Audition de Fouad Abou Nader	Audition de M. Fouad Abou Nader	2018-10-11 09:00:00	2018-10-11 10:00:00	\N	\N	7	0	CHRETORIENT	CHRETORIENT
312877	COM_SPECIALE	AUDRAP	\N	RETRAIT	\N	\N	\N	2018-10-17 17:00:00	2018-10-17 18:30:00	\N	\N	0	0	\N	\N
312879	COM_SPECIALE	AUDRAP	\N	RETRAIT	\N	\N	\N	2018-10-18 16:00:00	2018-10-18 19:00:00	\N	\N	0	0	\N	\N
312950	GIA	AUCUNE	\N	\N	\N	Entretien avec le Président du groupe d'amitié Egypte-France	Entretien avec le Dr.Ayman Aboul Ela, Pdt du groupe d'amitié Egypte-France	2018-10-09 15:30:00	2018-10-09 16:30:00	\N	\N	1	0	617	\N
312962	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLF pour 2019 - Mission Outre-mer	\N	2018-10-15 17:30:00	2018-10-15 18:15:00	\N	\N	1	0	\N	\N
324290	GIA	AUCUNE	\N	\N	\N	Petit-déjeuner de travail avec l'ambassadeur d'Ukraine en France	Petit-déjeuner de travail avec M. Oleg SHAMSHUR, ambassadeur d'Ukraine en France	2018-11-14 08:15:00	2018-11-14 09:00:00	\N	\N	4	0	530	\N
329643	GIA	AUCUNE	\N	\N	\N	Entretien avec l'Ambassadeur de Finlande, M. Teemu TANNER	Entretien avec l'Ambassadeur de Finlande, M. Teemu TANNER	2018-11-27 12:45:00	2018-11-27 14:25:00	\N	\N	8	0	640	\N
330051	GIA	AUCUNE	\N	\N	\N	Entretien avec une délégation de l'Assemblée nationale de Bulgarie	Entretien avec une délégation de l'Assemblée nationale de Bulgarie	2018-11-19 15:00:00	2018-11-19 17:00:00	\N	\N	2	0	582	\N
342808	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Centre d'études et de réalisations pastorales Alpes-Méditerranée	Pastoralisme - Audition de représentants du Centre d'études et de réalisations pastorales Alpes-Méditerranée	2019-01-17 13:45:00	2019-01-17 15:00:00	\N	\N	5	0	\N	\N
342870	COM_EURO	AUDRAP	\N	AFEU	\N	Audition intelligence artificielle	Audition intelligence artificielle	2019-01-16 14:00:00	2019-01-16 15:00:00	\N	\N	3	0	\N	\N
342903	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Visite au SSA de Clamart	\N	2019-01-16 15:00:00	2019-01-16 17:00:00	\N	\N	1	0	\N	\N
350070	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2019-02-06 14:30:00	2019-02-06 16:00:00	\N	\N	2	0	\N	\N
350505	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Démarcharge téléphonique et lutte contre les appels frauduleux	\N	2019-02-06 14:00:00	2019-02-06 19:30:00	\N	\N	1	0	\N	\N
350556	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-02-13 09:30:00	2019-02-13 12:05:00	2019-02-13 14:36:56	2019-02-13 16:52:09	30	0	\N	\N
350579	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL "Lutte contre l'habitat insalubre"	PPL "Lutte contre l'habitat insalubre"	2019-02-05 09:00:00	2019-02-05 10:30:00	\N	\N	1	0	\N	\N
350584	COM_PERMANENTE	AUDRAP	\N	CAE	\N	ppl 	PPL "Lutte contre l'habitat insalubre"	2019-02-05 16:10:00	2019-02-05 16:50:00	\N	\N	1	0	\N	\N
350593	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL "Lutte contre l'habitat insalubre"	PPL "Lutte contre l'habitat insalubre"	2019-02-07 09:45:00	2019-02-07 10:35:00	\N	\N	1	0	\N	\N
350686	DELEGATION	AUCUNE	\N	\N	DSOM	Audition du président de Public Sénat	\tDélégation sénatoriale aux outre-mer - Audition du président de Public Sénat	2019-02-12 17:05:00	2019-02-12 18:20:00	2019-02-13 10:10:35	2019-02-13 16:52:15	12	0	\N	\N
350702	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-02-13 17:00:00	2019-02-13 19:15:00	2019-02-14 09:40:15	2019-02-14 11:05:36	45	0	\N	\N
350762	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	\N	\N	2019-02-14 09:45:00	2019-02-14 10:15:00	\N	\N	0	0	\N	\N
350765	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de M. Rémy RIOUX, directeur général de l'Agence française de développement	Audition de M. Rémy RIOUX, directeur général de l'Agence française de développement	2019-02-13 09:35:00	2019-02-13 11:15:00	2019-02-13 12:29:18	2019-02-13 16:52:09	33	0	\N	\N
350790	COM_SPECIALE	PLENIERE	\N	ENTREPRISES	\N	Réunion 20190212	\N	2019-02-12 12:30:00	2019-02-12 12:35:00	2019-02-12 12:39:16	2019-02-13 16:52:41	13	0	\N	\N
350791	MISSION	DEPLACEMENT	\N	INFRACTIONS	\N	Déplacement à Angers	\N	2019-02-08 08:00:00	2019-02-08 22:00:00	\N	\N	4	0	\N	\N
350863	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Délai intervention juge Mayotte	PPL Délai intervention juge Mayotte	2019-02-14 16:20:00	2019-02-15 17:05:00	\N	\N	24	0	\N	\N
350972	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Lutter contre toutes les violences éducatives ordinaires	\N	2019-02-07 17:00:00	2019-02-07 18:30:00	\N	\N	1	0	\N	\N
350974	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Lutter contre toutes les violences éducatives ordinaires	\N	2019-02-11 10:15:00	2019-02-11 12:05:00	\N	\N	1	0	\N	\N
350976	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Lutter contre toutes les violences éducatives ordinaires	\N	2019-02-11 14:25:00	2019-02-11 15:15:00	\N	\N	1	0	\N	\N
350978	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Lutter contre toutes les violences éducatives ordinaires	\N	2019-02-11 16:45:00	2019-02-11 18:30:00	\N	\N	1	0	\N	\N
353876	GIA	AUCUNE	\N	\N	\N	Entretien de Mme Suzanne RUBLACK par Mme TROENDLE (coopé)	Entretien de Mme Suzanne RUBLACK par Mme TROENDLE (coopé)	2019-02-14 09:00:00	2019-02-14 09:45:00	\N	\N	1	0	604	\N
353884	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	1061	\N	\N	Explications de vote sur l'ensemble du PJLO Autonomie Polynésie française	Explications de vote sur l'ensemble du PJLO Autonomie Polynésie française	2019-02-19 15:00:00	2019-02-19 15:55:00	\N	\N	290	0	\N	\N
353885	SEANCE_PLENIERE	SCRUSOL	1061	\N	\N	Scrutin solennel PJLO Autonomie Polynésie française	Scrutin solennel PJLO Autonomie Polynésie française	2019-02-19 16:00:00	2019-02-19 16:30:00	\N	\N	0	0	\N	\N
356853	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2019-03-06 09:35:00	2019-03-06 10:45:00	2019-03-06 11:22:07	2019-03-06 16:49:18	38	1	\N	\N
350700	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-02-13 10:00:00	2019-02-13 11:35:00	2019-02-13 12:36:52	2019-02-13 16:52:07	46	1	\N	\N
360603	GIA	AUCUNE	\N	\N	\N	rencontre avec Me Philippe Li, ancien président de la chambre de commerce franco-coréenne	rencontre avec Me Philippe Li, ancien président de la chambre de commerce franco-coréenne	2019-03-13 08:30:00	2019-03-13 09:30:00	\N	\N	6	0	613	\N
362680	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ambassadeur de Biélorussie à Paris	Entretien avec SEM Fissenko, précédé d'une visite du palais du Luxembourg	2019-03-19 18:30:00	2019-03-19 21:30:00	\N	\N	5	0	852	\N
365989	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Pastoralisme	GT Pastoralisme	2019-03-26 14:00:00	2019-03-26 15:00:00	\N	\N	8	0	\N	\N
366416	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-04-02 09:30:00	2019-04-02 10:40:00	2019-04-02 11:54:57	2019-04-02 14:54:12	29	0	\N	\N
366817	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Nouveaux territoires du sport	MI Nouveaux territoires du sport	2019-03-27 14:30:00	2019-03-27 15:30:00	\N	\N	4	0	\N	\N
366822	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Nouveaux territoires de la culture	MI Nouveaux territoires de la culture	2019-03-27 14:15:00	2019-03-27 16:15:00	\N	\N	5	0	\N	\N
367327	COM_EURO	AUDRAP	\N	AFEU	\N	Audition du CNES	\N	2019-03-26 15:00:00	2019-03-26 15:40:00	\N	\N	0	0	\N	\N
367351	COM_PERMANENTE	AUTRE	\N	LOIS	\N	reunion de commission	\N	2019-04-02 09:00:00	2019-04-02 09:50:00	2019-04-02 10:17:57	2019-04-02 14:54:13	22	0	\N	\N
214574	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	FNAPAEF	\N	2017-10-26 10:00:00	2017-10-26 11:00:00	\N	\N	1	0	\N	\N
216212	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF pour 2018 - Avis "agriculture"	PJLF pour 2018 - Avis "agriculture"	2017-11-08 11:30:00	2017-11-08 12:30:00	\N	\N	3	0	\N	\N
216225	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF pour	\N	2017-11-08 15:30:00	2017-11-08 18:30:00	\N	\N	3	0	\N	\N
216246	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJLF pour 2018 - Avis "transports maritimes"	PJLF pour 2018 - Avis "transports maritimes"	2017-11-07 14:00:00	2017-11-07 15:45:00	\N	\N	1	0	\N	\N
216285	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJLF pour 2018 - Avis "transports maritimes"	\N	2017-11-08 13:30:00	2017-11-08 17:30:00	\N	\N	1	0	\N	\N
216543	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2018 - Programme 146	\N	2017-11-08 15:00:00	2017-11-08 19:00:00	\N	\N	3	0	\N	\N
217220	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de finances 2018	Loi de finances 2018 (Culture)	2017-11-07 10:30:00	2017-11-07 12:00:00	\N	\N	2	0	\N	\N
217223	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de finances 2018	Loi de finances 2018 (Culture)	2017-11-07 13:00:00	2017-11-07 14:00:00	\N	\N	2	0	\N	\N
217228	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de finances 2018	Loi de finances 2018 (Culture)	2017-11-07 14:30:00	2017-11-07 16:00:00	\N	\N	4	0	\N	\N
217233	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de finances 2018	Loi de finances 2018 (Culture)	2017-11-08 14:30:00	2017-11-08 15:15:00	\N	\N	3	0	\N	\N
217237	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de finances 2018	Loi de finances 2018 (Création et transmission des savoirs)	2017-11-09 11:30:00	2017-11-09 12:30:00	\N	\N	2	0	\N	\N
217240	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Loi de finances 2018	Loi de finances 2018 (Enseignement scolaire)	2017-11-09 14:00:00	2017-11-09 15:00:00	\N	\N	1	0	\N	\N
217378	GIA	AUCUNE	\N	\N	\N	Entretien avec une délégation serbe	\N	2017-11-09 12:30:00	2017-11-09 14:20:00	\N	\N	4	0	674	\N
232864	DELEGATION	AUDRAP	\N	\N	PROS	Audition rapporteur sur le Pacte entre les générations	Audition de M. Gérard Mauger	2018-01-16 18:00:00	2018-01-16 18:45:00	\N	\N	3	0	\N	\N
232868	DELEGATION	GROUPE_TRAVAIL	\N	\N	PROS	Réunion des rapporteurs sur les Nouvelles mobilités	Réunion des rapporteurs sur les Nouvelles mobilités	2018-01-17 11:30:00	2018-01-17 12:15:00	\N	\N	4	0	\N	\N
232874	DELEGATION	AUDRAP	\N	\N	PROS	Audition rapporteur sur le Pacte entre les générations	Audition de M. Pierre-Henri Tavaillot	2018-01-18 11:45:00	2018-01-18 13:00:00	\N	\N	2	0	\N	\N
232875	DELEGATION	AUDRAP	\N	\N	PROS	Auditions dans le cadre du rapport "Nouvelles mobilités"	Audition de M. Olivier Razemon	2018-02-01 10:10:00	2018-02-01 11:10:00	\N	\N	4	0	\N	\N
232876	DELEGATION	AUCUNE	\N	\N	PROS	Réunion plénière avec audition de M. Eric Chareyron	Réunion plénière avec audition de M. Eric Chareyron du groupe KEOLIS	2018-02-15 08:30:00	2018-02-15 09:50:00	2018-02-15 10:45:51	2018-02-15 10:48:19	18	0	\N	\N
232877	DELEGATION	AUCUNE	\N	\N	PROS	Réunion plénière avec audition de M. Hakim El Karoui	Réunion plénière avec audition de M. Hakim El Karoui	2018-03-08 08:30:00	2018-03-08 09:35:00	2018-03-08 10:32:35	2018-03-08 10:34:55	19	0	\N	\N
233065	DELEGATION	AUCUNE	\N	\N	206	Audition, ouverte à la presse, de l'OFIS et du Hcéres	Audition, ouverte à la presse, de M. Olivier Le Gall, président de l'OFIS, et de M. Michel Cosnard, président du Hcérès	2018-01-18 10:15:00	2018-01-18 12:20:00	2018-01-19 15:15:23	2018-01-19 16:48:20	12	0	\N	\N
238003	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI thanatopraxie	MI thanatopraxie	2018-01-24 14:30:00	2018-01-24 16:10:00	\N	\N	1	0	\N	\N
240227	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière du jeudi 8 février 2018	Conclusions auditions compteurs communicants et algorithmes publics / Désignation rapporteurs bioéthique	2018-02-08 09:35:00	2018-02-08 11:05:00	2018-02-09 16:52:38	2018-02-14 13:58:40	15	0	\N	\N
240228	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	GT revitalisation centres : table ronde grandes enseignes	Groupe de travail - GT revitalisation centres : table ronde grandes enseignes	2018-01-31 15:00:00	2018-01-31 17:00:00	\N	\N	7	0	\N	\N
247319	COM_ENQUETE	PLENIERE	\N	FORCES	\N	\N	\N	2018-02-20 18:10:00	2018-02-20 20:00:00	2018-02-21 09:51:27	2018-02-21 11:12:18	11	0	\N	\N
251799	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion CATDD	\N	2018-03-14 10:00:00	2018-03-14 12:10:00	2018-03-14 17:36:58	2018-03-14 17:38:34	43	0	\N	\N
251861	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition plénière	\N	2018-03-14 10:05:00	2018-03-14 11:00:00	2018-03-14 11:03:48	2018-03-14 15:32:04	39	0	\N	\N
252036	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion de commission du 8 mars 2017	Réunion commune avec la délégation aux entreprises sur les surtranspositions des normes européennes	2018-03-08 09:05:00	2018-03-08 10:00:00	2018-03-08 15:24:39	2018-03-08 15:30:04	32	0	\N	\N
255862	COM_EURO	AUDRAP	\N	AFEU	\N	Agences de surveillance européennes	Agences de surveillance européennes - AMF	2018-03-13 10:00:00	2018-03-13 11:00:00	\N	\N	1	0	\N	\N
255867	COM_EURO	AUDRAP	\N	AFEU	\N	Détachement des travailleurs	Détachement des travailleurs	2018-03-14 14:30:00	2018-03-14 17:15:00	\N	\N	2	0	\N	\N
256031	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Protection des données personnelles (Examen des motions et amendements de séance)	\N	2018-03-20 09:05:00	2018-03-20 09:35:00	2018-03-20 17:28:39	2018-03-20 17:46:52	17	1	\N	\N
256143	DELEGATION	AUDRAP	\N	\N	PROS	Audition de TRANSDEV	Audition de M. Julien Réau, Directeur Innovation et Produits, Transdev France	2018-04-17 18:00:00	2018-04-17 18:50:00	\N	\N	1	0	\N	\N
256147	DELEGATION	AUDRAP	\N	\N	PROS	Audition de la Fédération Nationale des Transports Routiers	\N	2018-04-03 18:00:00	2018-04-03 19:00:00	\N	\N	2	0	\N	\N
256148	DELEGATION	AUDRAP	\N	\N	PROS	Audition du CGET	Audition de M. Hugo Bevort et de M. Philippe Matheron de la CGET	2018-04-03 19:00:00	2018-04-03 20:15:00	\N	\N	2	0	\N	\N
256166	DELEGATION	AUDRAP	\N	\N	PROS	Audition de la Fédération nationale des SCoT	\N	2018-04-17 18:50:00	2018-04-17 19:30:00	\N	\N	1	0	\N	\N
256470	AUTRE_TEMPORAIRE	AUTRE_NON_PLENIERE	\N	\N	\N	\N	\N	2018-03-28 15:00:00	2018-03-28 16:00:00	\N	\N	0	0	\N	\N
256471	AUTRE_TEMPORAIRE	AUTRE_NON_PLENIERE	\N	\N	\N	\N	\N	2018-03-28 16:00:00	2018-03-28 17:00:00	\N	\N	0	0	\N	\N
256473	AUTRE_TEMPORAIRE	AUTRE_NON_PLENIERE	\N	\N	\N	\N	\N	2018-03-28 17:00:00	2018-03-28 18:00:00	\N	\N	0	0	\N	\N
256474	AUTRE_TEMPORAIRE	AUTRE_NON_PLENIERE	\N	\N	\N	\N	\N	2018-03-28 18:00:00	2018-03-28 19:00:00	\N	\N	0	0	\N	\N
261179	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	GT revitalisation - Table ronde foncier, aménagement, promotion	\N	2018-04-04 15:00:00	2018-04-04 17:15:00	\N	\N	9	0	\N	\N
261181	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	GT revitalisation - Présentation travaux rapporteurs	\N	2018-04-04 17:40:00	2018-04-04 18:40:00	\N	\N	9	0	\N	\N
261364	ETUDES	AUCUNE	\N	\N	\N	\N	\N	2018-03-28 08:00:00	2018-03-28 09:00:00	\N	\N	14	0	\N	948
261379	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	GT POLLUTION DE L'AIR	\N	2018-03-27 14:30:00	2018-03-27 16:30:00	\N	\N	1	0	\N	\N
261381	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Tourisme	\N	2018-03-27 18:00:00	2018-03-27 19:30:00	\N	\N	4	0	\N	\N
263837	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Rapport conjoint France-Russie	\N	2018-04-05 09:30:00	2018-04-05 12:35:00	\N	\N	8	0	\N	\N
267075	DELEGATION	AUCUNE	\N	\N	211	Table ronde sur le parcours de sortie de la prostitution	Table ronde sur le parcours de sortie de la prostitution	2018-04-12 08:30:00	2018-04-12 10:30:00	2018-04-12 11:49:11	2018-04-12 18:13:31	8	0	\N	\N
267208	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 12 avril - 9h30	Réunion du 12 avril - 9h30	2018-04-12 09:35:00	2018-04-12 11:05:00	2018-04-12 16:48:10	2018-04-12 18:13:56	37	0	\N	\N
267387	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Propositions Directives Taxation activités numériques	Propositions Directives Taxation activités numériques - Audition Commission européenne - DG TAXUD	2018-04-10 18:00:00	2018-04-10 18:45:00	\N	\N	3	0	\N	\N
267394	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Propositions Directives Taxation activités numériques	Propositions Directives Taxation activités numériques - Audition Le Bon Coin	2018-04-11 14:15:00	2018-04-11 15:00:00	\N	\N	3	0	\N	\N
267395	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Propositions Directives Taxation activités numériques	Propositions Directives Taxation activités numériques - Audition CRITEO	2018-04-11 15:00:00	2018-04-11 16:00:00	\N	\N	3	0	\N	\N
267402	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion  2018 04 17	\N	2018-04-17 09:05:00	2018-04-17 10:00:00	2018-04-17 10:19:50	2018-04-17 19:29:59	27	0	\N	\N
267403	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Rapport information GT Sécurtié routière	Réunion 2018 04 18 a	2018-04-18 08:40:00	2018-04-18 09:55:00	2018-04-18 15:06:50	2018-04-18 16:47:51	55	0	\N	\N
305280	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	GT Financement du handicap	GT Financement du handicap	2018-09-12 14:00:00	2018-09-12 17:00:00	\N	\N	1	0	\N	\N
312483	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	plfss pour 2019 - médico-social. Auditions M. Bonne	\N	2018-10-16 14:30:00	2018-10-16 15:15:00	\N	\N	1	0	\N	\N
314164	COM_SPECIALE	AUDRAP	\N	RETRAIT	\N	\N	\N	2018-10-18 16:10:00	2018-10-18 18:25:00	\N	\N	2	0	\N	\N
314168	COM_SPECIALE	AUDRAP	\N	RETRAIT	\N	\N	\N	2018-10-18 16:10:00	2018-10-18 17:25:00	\N	\N	3	0	\N	\N
324616	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Sebastian Sass, représentant du projet Nord Stream 2 auprès de l'UE	Entretien avec M. Sebastian Sass, représentant du projet Nord Stream 2 auprès de l'UE	2018-11-15 08:00:00	2018-11-15 09:15:00	\N	\N	7	0	608	\N
329065	COM_EURO	DEPLACEMENT	\N	AFEU	\N	Relations UE-Turquie	Relations UE-Turquie	2018-11-25 09:00:00	2018-11-28 14:00:00	\N	\N	3	0	\N	\N
330683	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	PJL Croissance et transformation des entreprises	\N	2018-11-27 14:30:00	2018-11-27 16:30:00	\N	\N	1	0	\N	\N
330686	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	PJL Croissance et transformation des entreprises	\N	2018-11-27 18:00:00	2018-11-27 19:00:00	\N	\N	0	0	\N	\N
330983	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition déplacement Besançon	Déplacement AGTE 2019 - auditions	2018-11-19 09:45:00	2018-11-19 13:00:00	\N	\N	1	0	\N	\N
331037	DELEGATION	AUDRAP	\N	\N	PROS	Audition ONF	\N	2018-11-28 15:30:00	2018-11-28 16:45:00	\N	\N	2	0	\N	\N
331298	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI handicap dans la fonction publique	\N	2018-11-28 15:30:00	2018-11-28 18:35:00	\N	\N	2	0	\N	\N
331301	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2018-11-29 10:35:00	2018-11-29 12:45:00	2018-11-29 12:58:55	2018-11-29 14:39:08	19	0	\N	\N
331305	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2018-12-05 17:40:00	2018-12-05 19:10:00	2018-12-05 19:26:01	2018-12-06 11:18:26	26	0	\N	\N
331889	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Institution de funérailles républicaines	PPL Institution de funérailles républicaines	2018-11-28 14:30:00	2018-11-28 16:15:00	\N	\N	1	0	\N	\N
331915	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Institution de funérailles républicaines	PPL Institution de funérailles républicaines	2018-11-28 16:15:00	2018-11-28 17:00:00	\N	\N	2	0	\N	\N
331918	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Institution de funérailles républicaines	PPL Institution de funérailles républicaines	2018-11-28 17:30:00	2018-11-28 18:30:00	\N	\N	1	0	\N	\N
331927	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Visite du PA CdG le 29 novembre 2018	\N	2018-11-29 07:00:00	2018-11-29 22:00:00	\N	\N	19	0	\N	\N
332348	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2019-Examen Art non rattachés-Examen Amdts missions Culture-Médias-PP-CCE-DAG-T&E	PLF pour 2019-Examen Art non rattachés-Examen Amdts missions Culture-Médias-PP-CCE-DAG-T&E	2018-12-04 09:05:00	2018-12-04 09:55:00	2018-12-04 11:52:33	2018-12-04 14:11:13	28	0	\N	\N
332438	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-11-28 18:30:00	2018-11-28 19:30:00	\N	\N	1	0	\N	\N
332440	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-11-29 09:45:00	2018-11-29 11:45:00	\N	\N	1	0	\N	\N
332443	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-11-30 14:30:00	2018-11-30 16:45:00	\N	\N	1	0	\N	\N
332445	DELEGATION	AUDRAP	\N	\N	PROS	Audition de M. Romaric Godin	\N	2018-12-06 17:00:00	2018-12-06 19:00:00	\N	\N	1	0	\N	\N
332540	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	Consultant - INRA	\N	2018-12-05 14:30:00	2018-12-05 18:00:00	\N	\N	0	0	\N	\N
332565	DELEGATION	AUCUNE	\N	\N	PROS	Audition de M. Jean-Michel Naulot	Audition de M. Jean-Michel Naulot	2019-02-14 08:30:00	2019-02-14 10:00:00	2019-02-14 18:31:39	2019-02-15 10:54:32	12	0	\N	\N
333055	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2018-12-05 11:05:00	2018-12-05 12:50:00	2018-12-05 14:48:57	2018-12-05 16:42:18	28	0	\N	\N
333056	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2018-12-05 09:05:00	2018-12-05 11:00:00	2018-12-05 14:48:35	2018-12-05 16:42:21	65	0	\N	\N
333065	COM_PERMANENTE	DEPLACEMENT	\N	CAE	\N	Mission annuelle d'information en Russie	\N	2018-08-26 13:00:00	2018-08-31 17:00:00	\N	\N	6	0	\N	\N
334088	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Communes nouvelles et diversité des territoires	\N	2018-12-03 18:00:00	2018-12-03 19:00:00	\N	\N	1	0	\N	\N
334154	DELEGATION	AUCUNE	\N	\N	211	Table ronde sur les violences faites aux femmes handicapées	Table ronde sur les violences faites aux femmes handicapées	2018-12-06 08:30:00	2018-12-06 11:00:00	2018-12-06 11:58:12	2018-12-06 12:03:42	13	0	\N	\N
334381	DELEGATION	AUCUNE	\N	\N	DSOM	Audition M. Schrameck, président du CSA	Audition M. Schrameck, président du CSA	2019-01-17 16:15:00	2019-01-17 18:05:00	2019-01-18 08:45:04	2019-01-18 11:45:07	11	0	\N	\N
334406	COM_EURO	AUDRAP	\N	AFEU	\N	Coopération pénale européenne et parquet européen	Audition_Coopération pénale européenne et parquet européen	2018-12-05 16:10:00	2018-12-05 17:05:00	\N	\N	1	0	\N	\N
334415	MISSION	AUCUNE	\N	INFRACTIONS	\N	Auditions de M. Jean-Marie Durand et de Geneviève Avenard	Auditions de M. Jean-Marie Durand et de Geneviève Avenard	2018-12-12 16:35:00	2018-12-12 18:35:00	2018-12-12 18:51:59	2018-12-13 16:00:16	20	0	\N	\N
334786	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GS EURO_PAC	GS EURO_PAC	2018-12-05 14:30:00	2018-12-05 16:00:00	\N	\N	9	0	\N	\N
334796	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GS EURO_PAC	GS EURO_PAC	2018-12-05 16:30:00	2018-12-05 18:00:00	\N	\N	10	0	\N	\N
334814	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Déplacement pole judiciaire de la gendarmerie	\N	2018-12-05 13:30:00	2018-12-05 19:00:00	\N	\N	8	0	\N	\N
334826	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-12-05 10:00:00	2018-12-05 12:00:00	\N	\N	1	0	\N	\N
334828	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-12-05 15:00:00	2018-12-05 19:00:00	\N	\N	2	0	\N	\N
335069	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Nomination rapporteur - PPL Communes nouvelles & Funérailles républicaines - Amdts séance	\N	2018-12-11 14:00:00	2018-12-11 14:25:00	2018-12-11 15:35:05	2018-12-11 16:20:31	27	0	\N	\N
335128	DELEGATION	AUDRAP	\N	\N	PROS	Audition INRA	\N	2018-12-18 14:30:00	2018-12-18 16:00:00	\N	\N	2	0	\N	\N
335660	ETUDES	AUCUNE	\N	\N	\N	G.E. "Elevage"	G.E. "Elevage"	2018-12-05 08:00:00	2018-12-05 09:00:00	\N	\N	18	0	\N	911
335739	COM_SPECIALE	PLENIERE	\N	RETRAIT	\N	Désignation CMP	\N	2018-12-11 14:05:00	2018-12-11 14:10:00	2018-12-11 17:29:15	2018-12-11 17:58:52	13	0	\N	\N
336147	SEANCE_PLENIERE	SCRUSOL	1022	\N	\N	Scrutin solennel PLF 2019	Scrutin solennel PLF 2019	2018-12-11 16:15:00	2018-12-11 16:45:00	\N	\N	0	0	\N	\N
336152	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	PJL Croissance et transformation des entreprises	\N	2018-12-11 10:00:00	2018-12-11 11:00:00	\N	\N	1	0	\N	\N
336155	ETUDES	AUCUNE	\N	\N	\N	Audition de M. Itier	Audition de M. Itier	2018-12-11 13:15:00	2018-12-11 14:30:00	\N	\N	3	0	\N	998
338228	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-12-12 09:30:00	2018-12-12 11:00:00	\N	\N	1	0	\N	\N
338230	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-12-12 14:30:00	2018-12-12 15:30:00	\N	\N	3	0	\N	\N
338234	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-12-12 15:45:00	2018-12-12 17:00:00	\N	\N	4	0	\N	\N
338239	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-12-12 17:00:00	2018-12-12 18:05:00	\N	\N	5	0	\N	\N
338245	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-12-13 14:00:00	2018-12-13 15:00:00	\N	\N	2	0	\N	\N
338248	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-12-13 14:00:00	2018-12-13 15:00:00	\N	\N	1	0	\N	\N
338250	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-12-13 16:30:00	2018-12-13 17:40:00	\N	\N	4	0	\N	\N
338255	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-12-13 17:40:00	2018-12-13 18:10:00	\N	\N	5	0	\N	\N
338261	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	Pacte	\N	2018-12-13 18:10:00	2018-12-13 18:45:00	\N	\N	2	0	\N	\N
338287	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	auditions rapporteur Mme Doineau (santé visuelle)	\N	2018-12-18 14:30:00	2018-12-18 16:30:00	\N	\N	1	0	\N	\N
338289	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	audition rapporteur (Mme Doineau)	\N	2018-12-18 10:00:00	2018-12-18 11:00:00	\N	\N	1	0	\N	\N
338290	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	audition rapporteur Mme Doineau (PPL santé visuelle des personnes âgées)	\N	2018-12-19 15:30:00	2018-12-19 16:00:00	\N	\N	1	0	\N	\N
338311	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2018-12-12 14:45:00	2018-12-12 15:30:00	\N	\N	0	0	\N	\N
222439	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 23 novembre 2017	Réunion du 23 novembre 2017	2017-11-23 09:05:00	2017-11-23 11:25:00	2017-11-23 12:01:15	2017-11-23 14:51:22	25	0	\N	\N
225954	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	206	Fonctionnement et perspectives de l'OPECST	Réunion d'information et de réflexion sur le fonctionnement et les perspectives de l'OPECST	2017-12-05 18:10:00	2017-12-05 19:15:00	\N	\N	9	0	\N	\N
225989	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	Audition GT Infraction sexuelles	2017-11-30 09:30:00	2017-11-30 11:30:00	\N	\N	6	0	\N	\N
226015	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Réhabiliter la police de proximité	\N	2017-11-29 15:00:00	2017-11-29 15:30:00	\N	\N	2	0	\N	\N
226035	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Adaptation dans le domaine de la sécurité au droit de l'UE	\N	2017-11-29 14:00:00	2017-11-29 15:00:00	\N	\N	1	0	\N	\N
226038	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Adaptation dans le domaine de la sécurité au droit de l'UE	\N	2017-11-29 15:45:00	2017-11-29 18:00:00	\N	\N	1	0	\N	\N
229179	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	Auditions GT Infractions sexuelles	2017-12-12 17:00:00	2017-12-12 19:00:00	\N	\N	3	0	\N	\N
229183	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	Auditions GT Infractions sexuelles	2017-12-13 15:00:00	2017-12-13 17:00:00	\N	\N	3	0	\N	\N
230594	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Gestion des milieux aquatiques et prévention des inondations	\N	2017-12-18 17:30:00	2017-12-18 17:45:00	2017-12-18 18:02:01	2017-12-19 11:42:31	8	1	\N	\N
230595	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Adaptation dans le domaine de la sécurité au droit de l'UE	\N	2017-12-19 14:05:00	2017-12-19 14:20:00	2017-12-19 14:37:55	2017-12-19 16:56:57	17	1	\N	\N
238301	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL accord UE-Kazakhstan	\N	2018-01-24 15:00:00	2018-01-24 16:25:00	\N	\N	1	0	\N	\N
337802	CMP	AUTRE	\N	PLF2019	\N	PLF pour 2019	PLF pour 2019	2018-12-12 16:32:00	2018-12-12 16:59:00	\N	\N	9	0	\N	\N
337820	CMP	AUTRE	\N	REFORME	\N	PROG Programmation 2018-2022 et réforme pour la justice	PROG Programmation 2018-2022 et réforme pour la justice	2018-12-13 09:08:00	2018-12-13 09:48:00	\N	\N	9	0	\N	\N
337847	CMP	AUTRE	\N	JURIDICTIONS	\N	PJLO Renforcement de l'organisation des juridictions	PJLO Renforcement de l'organisation des juridictions	2018-12-13 09:48:00	2018-12-13 09:58:00	\N	\N	9	0	\N	\N
230002	CMP	AUTRE	\N	PLF2018	\N	PLF pour 2018	PLF pour 2018	2017-12-13 16:20:00	2017-12-13 16:35:00	\N	\N	9	0	\N	\N
244262	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Réforme des retraites 2018 - Audition SGA ministère des armées	Contrôle Réforme des retraites 2018 - Audition SGA ministère des armées	2018-02-06 15:00:00	2018-02-06 16:30:00	\N	\N	1	0	\N	\N
244776	DELEGATION	AUDRAP	\N	\N	206	Audition de l'Agence de la biomédecine	Audition de l'Agence de la biomédecine sur les moyens informatiques	2018-02-22 14:15:00	2018-02-22 16:00:00	\N	\N	2	0	\N	\N
244809	COM_ENQUETE	PLENIERE	\N	FORCES	\N	\N	\N	2018-02-13 14:20:00	2018-02-13 17:50:00	2018-02-20 15:28:45	2018-02-20 16:10:06	15	0	\N	\N
244810	COM_ENQUETE	PLENIERE	\N	FORCES	\N	\N	\N	2018-02-14 15:15:00	2018-02-14 20:30:00	2018-02-20 16:06:26	2018-02-20 16:10:03	13	0	\N	\N
245505	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2018-02-13 15:30:00	2018-02-13 18:00:00	\N	\N	3	0	\N	\N
247208	COM_ENQUETE	PLENIERE	\N	CHUTE	\N	Réunion constitutive	Réunion constitutive	2018-02-14 13:35:00	2018-02-14 14:10:00	2018-02-16 12:04:58	2018-02-16 14:42:47	18	0	\N	\N
256144	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion	Réunion	2018-03-20 14:00:00	2018-03-20 15:00:00	2018-03-20 16:42:58	2018-03-20 17:46:53	26	0	\N	\N
256145	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion	Réunion	2018-03-21 11:10:00	2018-03-21 13:00:00	2018-05-18 14:12:41	2018-05-18 14:13:10	33	0	\N	\N
258919	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition cycle de vie des entreprises	Audition cycle de vie des entreprises - AFNOR	2018-03-22 16:35:00	2018-03-22 17:45:00	\N	\N	1	0	\N	\N
259472	DELEGATION	AUDRAP	\N	\N	206	Audition de Mme Marie-Monique Robin, journaliste	Audition de Mme Marie-Monique Robin, journaliste	2018-04-18 16:15:00	2018-04-18 17:45:00	\N	\N	1	0	\N	\N
259475	DELEGATION	AUDRAP	\N	\N	206	Audition du LASEM de Toulon	Audition de M. Jean-Ulrich Mullot, chef du LASEM de Toulon	2018-04-18 17:45:00	2018-04-18 19:00:00	\N	\N	1	0	\N	\N
260796	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GS Brexit 	Groupe de travail - GS Brexit	2018-03-28 15:05:00	2018-03-28 16:20:00	\N	\N	12	0	\N	\N
261177	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de Mme Florence PARLY, ministre des armées sur la LPM 2019-2025	Audition de Mme Florence PARLY, ministre des armées, sur le PJL  programmation militaire 2019-2025	2018-04-03 09:00:00	2018-04-03 10:35:00	2018-04-03 14:39:25	2018-04-03 15:31:28	26	0	\N	\N
261183	COM_PERMANENTE	AUTRE	\N	FINC	\N	Saisine et désignation rapporteur DIR 147 et 148 - Audition 58-2° « Habiter mieux »	Saisine et désignation rapporteur DIR 147 et 148 - Audition 58-2° programme « Habiter mieux »	2018-04-04 10:35:00	2018-04-04 12:20:00	2018-04-04 14:50:32	2018-04-04 15:03:43	40	0	\N	\N
261264	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 29 mars 2018	\N	2018-03-29 09:05:00	2018-03-29 10:05:00	2018-03-29 16:27:37	2018-03-29 18:16:18	13	0	\N	\N
261396	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Protection des secrets d'affaires	\N	2018-03-23 16:00:00	2018-03-23 18:45:00	\N	\N	1	0	\N	\N
261398	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Protection des secrets d'affaires	\N	2018-03-26 16:30:00	2018-03-26 18:25:00	\N	\N	1	0	\N	\N
261399	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Protection des secrets d'affaires	\N	2018-03-27 14:45:00	2018-03-27 16:45:00	\N	\N	1	0	\N	\N
261402	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Protection des secrets d'affaires	\N	2018-03-28 11:15:00	2018-03-28 12:30:00	\N	\N	1	0	\N	\N
261404	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Protection des secrets d'affaires	\N	2018-03-28 14:30:00	2018-03-28 19:30:00	\N	\N	1	0	\N	\N
261406	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Protection des secrets d'affaires	\N	2018-03-29 10:00:00	2018-03-29 13:00:00	\N	\N	1	0	\N	\N
261498	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Programmation militaire pour les années 2019 à 2025	\N	2018-03-29 14:00:00	2018-03-29 18:00:00	\N	\N	1	0	\N	\N
268504	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	Commission des Comptes	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne	2018-04-18 14:30:00	2018-04-18 15:45:00	2018-04-18 16:07:55	2018-04-18 16:48:00	7	0	\N	\N
269331	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 19 avril 2018 (matin)	Réunion du 19 avril 2018 (matin)	2018-04-19 08:35:00	2018-04-19 10:40:00	2018-04-19 12:06:27	2018-04-19 14:52:34	21	0	\N	\N
270116	COM_PERMANENTE	AUDRAP	\N	FINC	\N	La disponibilité des hélicoptères du ministère des Armées	La disponibilité des hélicoptères du ministère des Armées - Airbus	2018-04-17 10:30:00	2018-04-17 11:30:00	\N	\N	1	0	\N	\N
270118	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 -  Défense - Disponibilité des hélicoptères du ministère des Armées	Contrôle 2018 - Défense - Disponibilité des hélicoptères du ministère des Armées - M. Chabbert	2018-04-17 15:00:00	2018-04-17 16:00:00	\N	\N	1	0	\N	\N
270120	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Sports - MHP - Audition 	PLF pour 2019 - Sports - MHP - Audition  - FFF	2018-04-17 15:30:00	2018-04-17 16:30:00	\N	\N	1	0	\N	\N
270122	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Mission Action extérieure de l'État - Réseau enseignement français à l'étranger	Mission Action extérieure de l'État - Réseau enseignement français à l'étranger - Mission laïque française	2018-04-19 14:00:00	2018-04-19 15:00:00	\N	\N	2	0	\N	\N
270131	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Très grandes infrastructures de recherche	Contrôle 2018 - Très grandes infrastructures de recherche - Direction générale de la recherche et de l'innovation	2018-04-19 13:30:00	2018-04-19 15:00:00	\N	\N	1	0	\N	\N
270133	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018  modernisation de la navigation aérienne	Contrôle 2018  modernisation de la navigation aérienne - DGA	2018-04-19 17:45:00	2018-04-19 19:00:00	\N	\N	1	0	\N	\N
296027	GIA	AUCUNE	\N	\N	\N	Entretien l' ambassadrice de France en Nouvelle-Zélande 	Entretien avec SE Mme Carta- Le Vert , ambassadrice de France en Nouvelle-Zélande 	2018-07-10 12:15:00	2018-07-10 14:00:00	\N	\N	7	0	663	\N
299031	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	Audition mission réforme territoriale Aveyron	2018-07-16 13:30:00	2018-07-16 16:30:00	\N	\N	4	0	\N	\N
299032	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	Mission réforme territoriale Lozère	2018-07-16 18:00:00	2018-07-16 19:00:00	\N	\N	3	0	\N	\N
299033	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	Audition Mission réforme territoriale Lozère	2018-07-16 20:00:00	2018-07-16 22:00:00	\N	\N	3	0	\N	\N
299035	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	Audition mission Réforme terriotiale Lozère	2018-07-17 09:30:00	2018-07-17 11:15:00	\N	\N	3	0	\N	\N
299060	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	58-2 2018 - Très grandes infrastructures de recherche - Genève	58-2 2018 - Très grandes infrastructures de recherche - Genève	2018-07-17 07:00:00	2018-07-17 20:55:00	\N	\N	1	0	\N	\N
311078	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2019 - programme 144	\N	2018-10-09 13:30:00	2018-10-09 16:30:00	\N	\N	2	0	\N	\N
311081	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2019 - programme 144	\N	2018-10-10 15:00:00	2018-10-10 17:30:00	\N	\N	2	0	\N	\N
316224	COM_SPECIALE	AUDRAP	\N	RETRAIT	\N	\N	\N	2018-10-24 08:00:00	2018-10-24 09:45:00	\N	\N	2	0	\N	\N
316227	COM_SPECIALE	AUDRAP	\N	RETRAIT	\N	\N	\N	2018-10-24 14:30:00	2018-10-24 16:05:00	\N	\N	11	0	\N	\N
323962	DELEGATION	AUCUNE	\N	\N	COLTER	Avenir des services publics dans les territoires : propositions du rapport CAP 2022	\N	2018-11-22 09:00:00	2018-11-22 10:30:00	2018-11-22 10:51:07	2018-11-22 10:55:41	12	0	\N	\N
330704	ETUDES	AUCUNE	\N	\N	\N	Audition de M. Préaud	Audition de M. Préaud	2018-11-28 08:00:00	2018-11-28 09:30:00	\N	\N	10	0	\N	912
331881	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 29 novembre 2018	Réunion du 29 novembre 2018	2018-11-29 08:35:00	2018-11-29 10:20:00	2018-11-30 16:02:40	2018-11-30 17:00:33	11	0	\N	\N
331920	DELEGATION	DEPLACEMENT	\N	\N	206	Visite d'étude d'une délégation du Bundestag allemand (rue Saint-Dominique)	Visite d'étude d'une délégation du Bundestag allemand (rue Saint-Dominique)	2018-12-04 09:20:00	2018-12-04 11:00:00	\N	\N	1	0	\N	\N
343285	GIA	AUCUNE	\N	\N	\N	Assemblée générale 2018	Assemblée générale 2018	2019-01-16 14:00:00	2019-01-16 15:00:00	\N	\N	6	0	642	\N
344664	COM_SPECIALE	AUDRAP	\N	ENTREPRISES	\N	PJL Croissance et transformation des entreprises	\N	2019-01-22 14:00:00	2019-01-22 16:00:00	\N	\N	9	0	\N	\N
345280	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Situation de l'Office national des forêts	Situation de l'Office national des forêts - Rencontre avec le DGA de l'ONF	2019-01-22 14:00:00	2019-01-22 15:45:00	\N	\N	4	0	\N	\N
345295	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Situation de l'Office national des forêts	Situation de l'Office national des forêts - Audition des représentations syndicales de l'ONF	2019-01-23 14:00:00	2019-01-23 16:45:00	\N	\N	1	0	\N	\N
345296	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Situation de l'Office national des forêts	Situation de l'Office national des forêts - Audition de représentants de la Fédération nationale du bois	2019-01-23 17:00:00	2019-01-23 18:45:00	\N	\N	2	0	\N	\N
345297	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Situation de l'Office national des forêts	Situation de l'Office national des forêts - Audition de représentants du ministère de l'action et des comptes publics	2019-01-24 14:00:00	2019-01-24 15:45:00	\N	\N	1	0	\N	\N
345298	COM_PERMANENTE	AUDRAP	\N	CAE	\N	situat	Situation de l'Office national des forêts - Audition de représentants de la Fédération nationale des communes forestière	2019-01-24 15:45:00	2019-01-24 17:00:00	\N	\N	1	0	\N	\N
348048	GIA	AUCUNE	\N	\N	\N	Entretien avec le représentant de l'Arménie auprès de l'OIF	Petit-déjeuner en l'honneur de M. Christian Ter Stepanian, représentant de l'Arménie auprès de l'Organisation internatio	2019-01-31 08:30:00	2019-01-31 09:45:00	\N	\N	3	0	641	\N
350877	COM_EURO	AUDRAP	\N	AFEU	\N	Détachement des travailleurs	Audition Détachement des travailleurs	2019-02-05 11:00:00	2019-02-05 12:15:00	\N	\N	2	0	\N	\N
350880	COM_EURO	AUDRAP	\N	AFEU	\N	Détachement des travailleurs	Audition Détachement des travailleurs	2019-02-07 12:30:00	2019-02-07 13:30:00	\N	\N	2	0	\N	\N
353701	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Biocarburants	Biocarburants	2019-02-13 15:00:00	2019-02-13 18:15:00	\N	\N	4	0	\N	\N
355707	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LEC PPL Sécurité des sapeurs-pompiers	\N	2019-02-21 10:30:00	2019-02-21 11:30:00	2019-02-21 13:24:04	2019-02-21 17:56:26	30	1	\N	\N
355708	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition Article 13 M. François Pillet	\N	2019-02-21 12:00:00	2019-02-21 13:45:00	2019-02-21 13:26:05	2019-02-21 17:56:25	27	1	\N	\N
355709	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition Article 13 M. Jacques Mézard	\N	2019-02-21 14:15:00	2019-02-21 15:10:00	2019-02-21 15:22:26	2019-02-21 17:56:25	0	0	\N	\N
356087	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL École de la confiance	PJL École de la confiance	2019-02-19 17:45:00	2019-02-19 19:00:00	\N	\N	4	0	\N	\N
356091	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL École de la confiance	PJL École de la confiance	2019-02-20 14:30:00	2019-02-20 15:30:00	\N	\N	5	0	\N	\N
356092	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL École de la confiance	PJL École de la confiance	2019-02-20 15:30:00	2019-02-20 16:15:00	\N	\N	5	0	\N	\N
356093	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL École de la confiance	PJL École de la confiance	2019-02-20 16:15:00	2019-02-20 16:45:00	\N	\N	4	0	\N	\N
356109	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL École de la confiance	PJL École de la confiance	2019-02-20 16:45:00	2019-02-20 17:45:00	\N	\N	4	0	\N	\N
356114	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL École de la confiance	PJL École de la confiance	2019-02-21 09:30:00	2019-02-21 11:00:00	\N	\N	4	0	\N	\N
356119	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL École de la confiance	PJL École de la confiance	2019-02-21 11:00:00	2019-02-21 11:45:00	\N	\N	2	0	\N	\N
356122	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL École de la confiance	PJL École de la confiance	2019-02-21 14:30:00	2019-02-21 15:15:00	\N	\N	2	0	\N	\N
356125	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL École de la confiance	PJL École de la confiance	2019-02-21 15:15:00	2019-02-21 16:00:00	\N	\N	3	0	\N	\N
356129	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL École de la confiance	PJL École de la confiance	2019-02-21 16:00:00	2019-02-21 17:00:00	\N	\N	4	0	\N	\N
356163	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Emploi des seniors	\N	2019-03-07 10:00:00	2019-03-07 11:00:00	\N	\N	2	0	\N	\N
356164	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Emploi des seniors	\N	2019-03-07 11:00:00	2019-03-07 11:45:00	\N	\N	3	0	\N	\N
356165	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Emploi des seniors	\N	2019-03-12 14:00:00	2019-03-12 16:00:00	\N	\N	4	0	\N	\N
356166	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Emploi des seniors	\N	2019-03-14 11:00:00	2019-03-14 11:45:00	\N	\N	3	0	\N	\N
356167	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Emploi des seniors	\N	2019-03-14 14:00:00	2019-03-14 14:45:00	\N	\N	3	0	\N	\N
356168	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Emploi des seniors	\N	2019-03-14 14:45:00	2019-03-14 15:30:00	\N	\N	3	0	\N	\N
356169	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Emploi des seniors	\N	2019-03-14 15:30:00	2019-03-14 16:15:00	\N	\N	3	0	\N	\N
356170	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Emploi des seniors	\N	2019-03-26 13:45:00	2019-03-26 14:30:00	\N	\N	3	0	\N	\N
356171	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Emploi des seniors	\N	2019-03-26 14:30:00	2019-03-26 15:15:00	\N	\N	3	0	\N	\N
356172	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Emploi des seniors	\N	2019-03-26 16:00:00	2019-03-26 16:45:00	\N	\N	3	0	\N	\N
356173	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Emploi des seniors	\N	2019-03-28 10:00:00	2019-03-28 11:30:00	\N	\N	3	0	\N	\N
356174	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Emploi des seniors	\N	2019-03-28 14:00:00	2019-03-28 14:45:00	\N	\N	2	0	\N	\N
356175	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Emploi des seniors	\N	2019-03-28 15:30:00	2019-03-28 16:15:00	\N	\N	2	0	\N	\N
356176	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Emploi des seniors	\N	2019-03-28 14:45:00	2019-03-28 15:30:00	\N	\N	2	0	\N	\N
356181	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Emploi des seniors	\N	2019-03-07 14:00:00	2019-03-07 14:45:00	\N	\N	3	0	\N	\N
356184	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Emploi des seniors	\N	2019-03-12 16:00:00	2019-03-12 16:45:00	\N	\N	4	0	\N	\N
355955	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2019-03-06 08:30:00	2019-03-06 09:35:00	2019-03-06 11:26:32	2019-03-06 16:49:22	39	1	\N	\N
356197	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Emploi des seniors	\N	2019-03-26 15:15:00	2019-03-26 16:00:00	\N	\N	3	0	\N	\N
222380	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Echanges de vues sur le PLF2018	Echanges de vues sur le projet de loi de finances pour 2018	2017-11-23 09:05:00	2017-11-23 09:45:00	2017-11-23 11:47:47	2017-11-23 14:52:02	21	0	\N	\N
233295	DELEGATION	AUCUNE	\N	\N	211	Audition de Mme Sandrine Rousseau, présidente de l'association "Parler".	Audition de Mme Sandrine Rousseau, présidente de l'association "Parler".	2018-01-17 13:45:00	2018-01-17 14:45:00	2018-01-17 17:29:04	2018-01-17 17:43:20	11	0	\N	\N
233300	DELEGATION	AUCUNE	\N	\N	211	Auditions sur les violences faites aux femmes : CFCV, MIPROF, FNSF, Mme Flament	Auditions sur les violences faites aux femmes : CFCV, MIPROF, FNSF, Mme Flament	2018-01-18 08:30:00	2018-01-18 12:30:00	2018-01-18 16:23:35	2018-01-18 16:41:25	19	0	\N	\N
240014	ETUDES	AUCUNE	\N	\N	\N	Réunion constitutive	Réunion constitutive	2018-01-31 14:00:00	2018-01-31 14:30:00	\N	\N	4	0	\N	966
246300	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Compte rendu du déplacement en Savoie	Réunion plénière - Compte rendu du déplacement en Savoie	2018-02-15 08:35:00	2018-02-15 10:15:00	2018-02-15 12:12:02	2018-02-15 12:13:52	21	0	\N	\N
246335	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition cycle de vie des entreprises	Audition cycle de vie des entreprises - Conférence générale des juges consulaires de France	2018-02-14 14:00:00	2018-02-14 15:30:00	\N	\N	1	0	\N	\N
246337	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition cycle de vie des entreprises	Audition cycle de vie des entreprises - Réseau entreprendre	2018-02-14 15:20:00	2018-02-14 16:05:00	\N	\N	1	0	\N	\N
246338	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition cycle de vie des entreprises	Audition cycle de vie des entreprises - Croissance Plus	2018-02-14 16:10:00	2018-02-14 17:20:00	\N	\N	1	0	\N	\N
250548	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2018-03-06 14:30:00	2018-03-06 16:50:00	\N	\N	3	0	\N	\N
251879	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 8 mars - 10h00	Réunion du 8 mars - 10h00	2018-03-08 10:10:00	2018-03-08 11:15:00	2018-03-09 15:46:32	2018-03-09 15:46:39	18	0	\N	\N
255996	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Djibouti	\N	2018-03-12 15:15:00	2018-03-12 16:40:00	\N	\N	1	0	\N	\N
257771	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2018-03-15 11:40:00	2018-03-15 11:55:00	\N	\N	3	0	\N	\N
258515	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Mécénat	Mécénat	2018-03-21 15:00:00	2018-03-21 16:00:00	\N	\N	7	0	\N	\N
261956	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition commune comm. culture Fausses informations	\N	2018-04-03 18:10:00	2018-04-03 20:15:00	2018-04-04 15:07:43	2018-04-04 15:09:15	36	0	\N	\N
264374	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Tourisme	\N	2018-04-03 15:15:00	2018-04-03 16:00:00	\N	\N	4	0	\N	\N
264397	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Tourisme	\N	2018-04-03 16:00:00	2018-04-03 16:45:00	\N	\N	5	0	\N	\N
264593	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Tourisme	\N	2018-04-03 16:45:00	2018-04-03 17:30:00	\N	\N	3	0	\N	\N
264597	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Tourisme	\N	2018-04-03 17:30:00	2018-04-03 19:00:00	\N	\N	4	0	\N	\N
264602	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Tourisme	\N	2018-04-04 15:00:00	2018-04-04 16:30:00	\N	\N	5	0	\N	\N
264609	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Tourisme	\N	2018-04-04 16:30:00	2018-04-04 17:15:00	\N	\N	2	0	\N	\N
264613	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Tourisme	\N	2018-04-04 16:30:00	2018-04-04 17:15:00	\N	\N	2	0	\N	\N
264617	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Tourisme	\N	2018-04-04 17:15:00	2018-04-04 18:00:00	\N	\N	3	0	\N	\N
265542	COM_ENQUETE	PLENIERE	\N	CHUTE	\N	Audition plenière	\N	2018-04-10 14:20:00	2018-04-10 15:20:00	2018-04-13 17:57:21	2018-04-13 18:05:20	9	0	\N	\N
267414	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Propositions Directives Taxation activités numériques	Propositions Directives Taxation activités numériques - Audition Apple	2018-04-10 15:30:00	2018-04-10 16:30:00	\N	\N	1	0	\N	\N
267416	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Propositions Directives Taxation activités numériques	Propositions Directives Taxation activités numériques - Audition Syntec Numérique	2018-04-12 15:00:00	2018-04-12 16:00:00	\N	\N	2	0	\N	\N
268277	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Audition Le Trot	\N	2018-04-18 08:00:00	2018-04-18 09:00:00	\N	\N	0	0	\N	\N
268514	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	211	Mutilations sexuelles féminines - conférence de presse de présentation du rapport	Mutilations sexuelles féminines - conférence de presse de présentation du rapport	2018-05-16 18:30:00	2018-05-16 19:30:00	\N	\N	4	0	\N	\N
270204	ETUDES	AUCUNE	\N	\N	\N	Audition	Audition	2018-04-19 14:00:00	2018-04-19 15:00:00	\N	\N	4	0	\N	966
270226	COM_PERMANENTE	AUTRE	\N	FINC	\N	Commission mixte paritaire DSP 2	Commission mixte paritaire DSP 2	2018-04-19 08:30:00	2018-04-19 09:05:00	\N	\N	9	0	\N	\N
270373	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Disponibilité hélicoptères des Armées	Contrôle 2018 - Disponibilité hélicoptères des Armées - DGA	2018-04-24 14:30:00	2018-04-24 16:00:00	\N	\N	1	0	\N	\N
270380	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 -  La disponibilité des hélicoptères du ministère des Armées	Contrôle 2018 -  La disponibilité des hélicoptères du ministère des Armées - ALAT	2018-05-04 15:00:00	2018-05-04 17:10:00	\N	\N	1	0	\N	\N
270382	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	LPM 2019-2025	\N	2018-04-11 14:30:00	2018-04-11 15:30:00	\N	\N	2	0	\N	\N
270385	GIA	AUCUNE	\N	\N	\N	Entretien de M. HOUPERT avec Mme Shala ISMAYIL sur les droits de l'homme (coopé)	Entretien de M. HOUPERT avec Mme Shala ISMAYIL sur les droits de l'homme (coopé)	2018-04-24 16:30:00	2018-04-24 17:00:00	\N	\N	0	0	534	\N
270439	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen Rapport sur PPRE 448 - Examen Amdts PPL 376 et nominations	Examen  Rapport sur PPRE 448 Directives 147 et 148 - Examen Amdts PPL 376 Verrou de Bercy et nominations	2018-05-15 09:10:00	2018-05-15 10:05:00	2018-05-16 12:13:57	2018-05-16 14:13:49	37	1	\N	\N
270440	COM_PERMANENTE	AUTRE	\N	FINC	\N	Communication application des lois et Examen rapport pour avis LPM 2019-2025	Communication sur l' application des lois et Examen rapport pour avis sur Loi de programmation militaire pour 2019-2025	2018-05-15 14:30:00	2018-05-15 15:25:00	2018-05-16 12:41:40	2018-05-16 14:13:50	25	0	\N	\N
270441	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Perspectives de l'économie mondiale - Déplacement à Washington	Perspectives de l'économie mondiale et enjeux des réformes de la Nlle administration américaine-Déplacement à Washington	2018-05-15 13:25:00	2018-05-19 10:40:00	\N	\N	2	0	\N	\N
267404	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Protection des savoir-faire et des informations commerciales	\N	2018-04-18 10:05:00	2018-04-18 11:45:00	2018-04-20 14:39:30	2018-04-20 14:49:28	39	0	\N	\N
271231	DELEGATION	AUCUNE	\N	\N	COLTER	Audition de M. Olivier DUSSOPT, secrétaire d'État	\N	2018-05-22 16:30:00	2018-05-22 17:45:00	2018-05-22 18:34:52	2018-05-23 16:02:04	11	0	\N	\N
271642	GIA	AUCUNE	\N	\N	\N	déjeuner de travail	déjeuner avec M Laurent Bonnefoy , chercheur spécialiste du Yémen	2018-05-15 12:30:00	2018-05-15 14:00:00	\N	\N	3	0	627	\N
271656	GIA	AUCUNE	\N	\N	\N	entretien Miinistère de l'Europe et des affaires étrangères	entrentretien avec Mme Fesnau-Castaing redactice Yémen du quai d'Orsay	2018-05-15 15:30:00	2018-05-15 16:30:00	\N	\N	3	0	627	\N
272424	COM_ENQUETE	PLENIERE	\N	HAUTE	\N	Audition	Audition	2018-05-15 14:30:00	2018-05-15 15:30:00	2018-05-16 16:42:21	2018-05-16 18:01:33	11	0	\N	\N
272439	COM_ENQUETE	PLENIERE	\N	HAUTE	\N	Audition	Audition	2018-05-15 15:30:00	2018-05-15 16:30:00	2018-05-16 16:45:12	2018-05-16 18:01:34	12	0	\N	\N
272454	COM_ENQUETE	PLENIERE	\N	HAUTE	\N	Audition	Audition	2018-05-15 18:00:00	2018-05-15 19:00:00	2018-05-16 16:48:55	2018-05-16 18:01:35	12	0	\N	\N
272519	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Immigration, droit d'asile et intégration	\N	2018-05-15 15:30:00	2018-05-15 17:15:00	\N	\N	2	0	\N	\N
272653	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Détachement des travailleurs	Audition Détachement des travailleurs	2018-05-15 14:00:00	2018-05-15 15:15:00	\N	\N	1	0	\N	\N
272919	MISSION	PLEIN_NON_JO	\N	BREXIT2	\N	Table-ronde Industrie et Finances	Table-ronde Industrie et Finances	2018-05-16 17:00:00	2018-05-16 18:30:00	\N	\N	9	0	\N	\N
308569	GIA	AUCUNE	\N	\N	\N	Audition Mgr Sharaf	Audition Mgr SHARAF Archevêque orthodoxe syriaque	2018-10-03 08:30:00	2018-10-03 09:30:00	\N	\N	15	0	CHRETORIENT	CHRETORIENT
308599	GIA	AUCUNE	\N	\N	\N	Audition Mgr Sharaf	Audition Mgr SHARAF Archevêque orthodoxe syriaque	2018-10-03 08:30:00	2018-10-03 09:30:00	\N	\N	3	0	615	\N
308603	GIA	AUCUNE	\N	\N	\N	Audition Mgr Sharaf	Audition Mgr SHARAF Archevêque orthodoxe syriaque	2018-10-03 08:30:00	2018-10-03 09:30:00	\N	\N	4	0	644	\N
311731	COM_PERMANENTE	DEPLACEMENT	\N	AFCL	\N	Déplacement en Israël	Déplacement de la commission en Israël	2018-10-10 08:00:00	2018-10-16 20:00:00	\N	\N	6	0	\N	\N
338312	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2018-12-12 15:30:00	2018-12-12 16:15:00	\N	\N	2	0	\N	\N
338315	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobiités" (LOM)	2018-12-12 16:30:00	2018-12-12 17:15:00	\N	\N	3	0	\N	\N
338319	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2018-12-12 17:15:00	2018-12-12 18:00:00	\N	\N	1	0	\N	\N
338321	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2018-12-12 18:00:00	2018-12-12 19:00:00	\N	\N	1	0	\N	\N
338326	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2018-12-04 09:00:00	2018-12-04 10:15:00	\N	\N	1	0	\N	\N
338328	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2018-12-04 10:15:00	2018-12-04 11:00:00	\N	\N	2	0	\N	\N
338331	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2018-12-04 14:00:00	2018-12-04 14:45:00	\N	\N	3	0	\N	\N
338335	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2018-12-04 14:00:00	2018-12-04 14:45:00	\N	\N	3	0	\N	\N
338339	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2018-12-04 15:30:00	2018-12-04 16:15:00	\N	\N	0	0	\N	\N
338341	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2018-12-04 16:30:00	2018-12-04 17:15:00	\N	\N	1	0	\N	\N
338343	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2018-12-04 17:15:00	2018-12-04 18:00:00	\N	\N	2	0	\N	\N
338347	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orienation Mobilités" (LOM)	2018-12-04 18:00:00	2018-12-05 18:45:00	\N	\N	0	0	\N	\N
338348	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2018-12-05 10:15:00	2018-12-05 11:00:00	\N	\N	3	0	\N	\N
338352	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2018-12-05 11:00:00	2018-12-05 11:45:00	\N	\N	2	0	\N	\N
338357	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2018-12-05 11:45:00	2018-12-05 12:30:00	\N	\N	3	0	\N	\N
338362	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2018-12-05 14:00:00	2018-12-05 14:45:00	\N	\N	1	0	\N	\N
338364	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2018-12-05 14:45:00	2018-12-05 15:30:00	\N	\N	2	0	\N	\N
338367	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2018-12-05 15:30:00	2018-12-05 17:30:00	\N	\N	1	0	\N	\N
338369	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2018-12-06 08:30:00	2018-12-06 09:15:00	\N	\N	2	0	\N	\N
338372	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobiités" (LOM)	2018-12-06 09:15:00	2018-12-06 10:00:00	\N	\N	1	0	\N	\N
338374	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2018-12-06 15:45:00	2018-12-06 17:15:00	\N	\N	1	0	\N	\N
338378	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL "Loi d'Orientation Mobilités" (LOM)	PJL "Loi d'Orientation Mobilités" (LOM)	2018-12-06 17:30:00	2018-12-06 18:15:00	\N	\N	0	0	\N	\N
338379	ETUDES	AUCUNE	\N	\N	\N	G.E. "Cultures traditionnelles et spécialisées"	G.E. "Cultures traditionnelles et spécialisées"	2018-12-12 08:00:00	2018-12-12 09:00:00	\N	\N	15	0	\N	1005
338395	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL mesures d'urgence économiques et sociales	PJL mesures d'urgence économiques et sociales	2018-12-21 16:00:00	2018-12-21 20:05:00	\N	\N	95	0	\N	\N
338396	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL mesures d'urgence économiques et sociales	PJL mesures d'urgence économiques et sociales	2018-12-21 21:30:00	2018-12-22 00:00:00	\N	\N	0	0	\N	\N
338403	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Examen amendements de séance PJL mesures d'urgence économiques et sociales	\N	2018-12-21 18:00:00	2018-12-21 18:20:00	2018-12-21 18:21:33	\N	21	0	\N	\N
291395	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion 2018 06 27	Réunion 2018 06 27	2018-06-27 09:35:00	2018-06-27 11:30:00	2018-06-27 15:47:57	2018-06-27 16:02:51	34	1	\N	\N
295826	CMP	AUTRE	\N	MARCHE	\N	PJL Directive services de paiement dans le marché intérieur	PJL Directive services de paiement dans le marché intérieur	2018-04-19 08:31:00	2018-04-19 09:07:00	\N	\N	7	0	\N	\N
338404	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Examen rapport et texte PJL mesures d'urgence économiques et sociales	\N	2018-12-21 11:00:00	2018-12-21 12:00:00	2018-12-21 12:02:50	2018-12-21 16:21:53	23	1	\N	\N
339734	ETUDES	AUCUNE	\N	\N	\N	G.E. "Agriculture et alimentation"	G.E. "Agriculture et alimentation"	2018-12-19 08:00:00	2018-12-19 09:00:00	\N	\N	21	0	\N	919
340081	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	Audition GT Déserts médicaux	Audition GT Déserts médicaux	2018-12-18 15:00:00	2018-12-18 16:30:00	\N	\N	4	0	\N	\N
340090	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	auditions Mme Doineau (PPL santé visuelle des personnes âgées)	\N	2019-01-08 15:30:00	2019-01-08 17:00:00	\N	\N	1	0	\N	\N
340091	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	auditions Mme Doineau rapporteur PPL santé visuelle des personnes âgées	\N	2019-01-09 09:00:00	2019-01-09 12:00:00	\N	\N	2	0	\N	\N
340408	DELEGATION	AUDRAP	\N	\N	PROS	Audition de M. Thierry Philipponnat	\N	2019-01-14 15:05:00	2019-01-14 16:20:00	\N	\N	1	0	\N	\N
340481	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Dispositions institutionnelles en Polynésie française	\N	2019-01-08 14:00:00	2019-01-08 18:45:00	\N	\N	1	0	\N	\N
341220	COM_PERMANENTE	AUTRE	\N	SOCI	\N	audition plénière	\N	2019-01-17 10:30:00	2019-01-17 11:50:00	2019-01-17 11:51:17	2019-01-17 11:58:13	34	0	\N	\N
341545	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL accord de dialogue politique et de coopération UE Cuba	\N	2019-01-14 11:00:00	2019-01-14 11:45:00	\N	\N	1	0	\N	\N
341547	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL Accord de dialogue politique et de coopération UE Cuba	\N	2019-01-14 14:00:00	2019-01-14 14:45:00	\N	\N	1	0	\N	\N
341785	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de M. Bruno DALLES, directeur de TRACFIN	Audition de M. Bruno DALLES, directeur de TRACFIN	2019-01-22 09:20:00	2019-01-22 10:45:00	2019-01-22 18:38:41	2019-01-23 08:56:23	26	0	\N	\N
341994	DELEGATION	DEPLACEMENT	\N	\N	206	Petit-déjeuner de travail à l'Académie nationale de médecine	Petit-déjeuner de travail à l'Académie nationale de médecine	2019-02-06 08:30:00	2019-02-06 10:30:00	\N	\N	3	0	\N	\N
352735	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-02-20 09:45:00	2019-02-20 11:05:00	2019-02-20 14:14:21	2019-02-20 15:03:59	31	0	\N	\N
352738	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-02-20 17:40:00	2019-02-20 19:05:00	2019-02-21 12:14:01	2019-02-21 17:56:27	28	0	\N	\N
362921	ETUDES	AUCUNE	\N	\N	\N	Rencontre avec la Fédération française de golf	Rencontre avec la Fédération française de golf	2019-03-20 08:15:00	2019-03-20 09:15:00	\N	\N	11	0	\N	934
223798	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF 2018 - Avis Transports maritimes	PLF 2018 - Avis Transports maritimes	2017-11-23 14:00:00	2017-11-23 15:00:00	\N	\N	2	0	\N	\N
223805	DELEGATION	AUCUNE	\N	\N	206	Communication de M. Bruno Sido - Audition de l'ASN	Communication de M. B. Sido sur sa mission en Russie en avril 2017 - Audition de M. P.F. Chevet, président de l'ASN	2017-11-30 09:05:00	2017-11-30 11:35:00	2017-11-30 17:06:48	2017-11-30 17:20:13	13	0	\N	\N
227770	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	GT Statut de l'élu local : méthodes et programme de travail	\N	2017-12-07 08:30:00	2017-12-07 09:35:00	\N	\N	8	0	\N	\N
230886	GIA	AUCUNE	\N	\N	\N	AG bureau 2018-2020	AG bureau 2018-2020	2018-01-16 15:30:00	2018-01-16 16:30:00	\N	\N	8	0	634	\N
230889	GIA	AUCUNE	\N	\N	\N	Accueil Sikyong Lobsang Sangay (Pdt Gouv. Tib. exil)	Accueil Sikyong Lobsang Sangay (Pdt Gouv. Tib. exil)	2018-01-25 14:00:00	2018-01-25 16:00:00	\N	\N	2	0	634	\N
232539	DELEGATION	AUCUNE	\N	\N	PROS	Réunion plénière avec audition de M. Louis Chauvel	Réunion plénière avec audition de M. Louis Chauvel	2018-01-18 08:30:00	2018-01-18 10:00:00	2018-01-18 16:44:00	2018-01-18 18:25:10	18	0	\N	\N
232547	DELEGATION	AUCUNE	\N	\N	PROS	Réunion plénière avec audition de M. Martin Vanier	Réunion plénière avec audition de M. Martin Vanier	2018-02-01 08:35:00	2018-02-01 10:00:00	2018-02-01 14:48:34	2018-02-01 20:08:54	17	0	\N	\N
236006	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Organisation des Jeux Olympiques et Paralympiques 2024	\N	2018-01-16 14:00:00	2018-01-16 14:30:00	\N	\N	2	0	\N	\N
236011	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Organisation des Jeux Olympiques et Paralympiques 2024	\N	2018-01-16 14:30:00	2018-01-16 15:00:00	\N	\N	3	0	\N	\N
236015	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Organisation des Jeux Olympiques et Paralympiques 2024	\N	2018-01-16 15:00:00	2018-01-16 15:30:00	\N	\N	3	0	\N	\N
236023	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Organisation des Jeux Olympiques et Paralympiques 2024	\N	2018-01-16 15:30:00	2018-01-16 16:00:00	\N	\N	1	0	\N	\N
236028	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Organisation des Jeux Olympiques et Paralympiques 2024	\N	2018-01-16 16:00:00	2018-01-16 16:30:00	\N	\N	1	0	\N	\N
236033	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Organisation des Jeux Olympiques et Paralympiques 2024	\N	2018-01-16 18:00:00	2018-01-16 20:10:00	\N	\N	1	0	\N	\N
236039	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Organisation des Jeux Olympiques et Paralympiques 2024	\N	2018-01-18 08:30:00	2018-01-18 09:15:00	\N	\N	0	0	\N	\N
236042	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Organisation des Jeux Olympiques et Paralympiques 2024	\N	2018-01-18 09:15:00	2018-01-18 10:00:00	\N	\N	1	0	\N	\N
236047	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Organisation des Jeux Olympiques et Paralympiques 2024	\N	2018-01-18 10:15:00	2018-01-18 11:00:00	\N	\N	2	0	\N	\N
236052	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Organisation des Jeux Olympiques et Paralympiques 2024	\N	2018-01-18 11:00:00	2018-01-18 11:45:00	\N	\N	1	0	\N	\N
236055	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Organisation des Jeux Olympiques et Paralympiques 2024	\N	2018-01-18 11:45:00	2018-01-18 13:00:00	\N	\N	1	0	\N	\N
236058	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Organisation des Jeux Olympiques et Paralympiques 2024	\N	2018-01-18 13:15:00	2018-01-18 14:30:00	\N	\N	1	0	\N	\N
236090	ETUDES	AUCUNE	\N	\N	\N	GE Métiers d'art	GE Métiers d'art	2018-01-19 08:30:00	2018-01-19 13:30:00	\N	\N	2	0	\N	1007
236093	ETUDES	AUCUNE	\N	\N	\N	GE Métiers d'art	GE Métiers d'art	2018-01-16 14:00:00	2018-01-16 14:30:00	\N	\N	9	0	\N	1007
237571	GIA	AUCUNE	\N	\N	\N	Audition de l'Ambassadeur du Liban en France	Audition de S.E. M Rami Adwan, ambassadeur du Liban en France	2018-01-24 08:30:00	2018-01-24 10:10:00	\N	\N	7	0	597	\N
239412	GIA	AUCUNE	\N	\N	\N	Assemblée générale	Assemblée générale	2018-01-31 08:30:00	2018-01-31 09:10:00	\N	\N	4	0	851	\N
241169	DELEGATION	AUDRAP	\N	\N	206	Audition sols et carbone	Audition sols et carbone	2018-01-30 16:30:00	2018-01-30 18:30:00	\N	\N	1	0	\N	\N
241171	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Philippe Mauguin, président de l'INRA	Audition de M. Philippe Mauguin, président de l'INRA	2018-02-13 19:00:00	2018-02-13 20:00:00	\N	\N	1	0	\N	\N
364562	GIA	AUCUNE	\N	\N	\N	\N	Petit-déjeuner Ambassadeur du Pakistan	2019-03-21 08:30:00	2019-03-21 09:45:00	\N	\N	6	0	619	\N
341079	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-01-16 09:35:00	2019-01-16 10:55:00	2019-01-16 11:18:38	2019-01-16 11:40:36	45	2	\N	\N
237429	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion	Réunion	2018-01-24 09:35:00	2018-01-24 12:15:00	2018-01-24 12:47:33	2018-01-24 16:00:56	45	1	\N	\N
241174	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Sylvain Pellerin, directeur de recherche à l'INRA	Audition de M. Sylvain Pellerin, directeur de recherche à l'INRA	2018-02-14 16:30:00	2018-02-14 17:30:00	\N	\N	1	0	\N	\N
247958	COM_PERMANENTE	AUDRAP	\N	FINC	\N	FIN - DAG - Mildeca - Auc et LK	FIN - DAG - Mildeca - Auc et LK	2018-02-20 11:00:00	2018-02-20 12:15:00	\N	\N	1	0	\N	\N
248263	COM_ENQUETE	PLENIERE	\N	CHUTE	\N	Réunion de bureau	\N	2018-02-20 14:00:00	2018-02-20 15:00:00	\N	\N	7	0	\N	\N
251929	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Aide alimentaire	Contrôle Aide alimentaire - Audition Direction générale de la cohésion sociale 	2018-03-06 14:30:00	2018-03-06 16:00:00	\N	\N	2	0	\N	\N
252031	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	DGOS/DGS	\N	2018-03-14 14:30:00	2018-03-14 15:30:00	\N	\N	0	0	\N	\N
252207	COM_ENQUETE	AUTRE	\N	CHUTE	\N	Audition	\N	2018-03-27 14:20:00	2018-03-27 15:15:00	2018-03-28 09:41:38	2018-03-28 11:38:26	9	0	\N	\N
253066	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	DSS	\N	2018-03-21 14:30:00	2018-03-21 15:30:00	\N	\N	0	0	\N	\N
253067	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	Cnamts	\N	2018-03-21 15:30:00	2018-03-21 16:30:00	\N	\N	0	0	\N	\N
253659	GIA	AUCUNE	\N	\N	\N	Invitation de l'ambassadeur britannique à la Résidence de l'Ambassade du Royaume-Uni	Invitation de l'ambassadeur britannique à la Résidence de l'Ambassade du Royaume-Uni	2018-03-13 09:00:00	2018-03-13 10:00:00	\N	\N	11	0	581	\N
255994	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL accord de défense avec le Nigéria	\N	2018-03-16 14:00:00	2018-03-16 15:30:00	\N	\N	1	0	\N	\N
259749	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	pJL Convention OIT	\N	2018-03-27 14:00:00	2018-03-27 15:15:00	\N	\N	1	0	\N	\N
261184	GIA	AUCUNE	\N	\N	\N	Entretien avec Mme Aurélia Daher, universitaire	Entretien avec Mme Aurélia Daher, universitaire	2018-03-29 08:30:00	2018-03-29 09:45:00	\N	\N	6	0	597	\N
270184	COM_ENQUETE	DEPLACEMENT	\N	CHUTE	\N	Déplacement à Fleury-Mérogis et Osny	Déplacement à Fleury-Mérogis et Osny	2018-04-16 09:00:00	2018-04-16 18:00:00	\N	\N	5	0	\N	\N
270190	DELEGATION	AUCUNE	\N	\N	211	Réunion conjointe de l'OPECST et des délégations aux droits des femmes de l'An et du Sénat	Réunion conjointe de l'OPECST et des délégations aux droits des femmes de l'An et du Sénat	2018-06-28 10:00:00	2018-06-28 12:00:00	2018-06-28 14:20:59	2018-06-28 14:35:32	6	0	\N	\N
270523	GIA	AUCUNE	\N	\N	\N	Entretien au centre de crise et de soutien du MEAE	Entretien au centre de crise et de soutien du MEAE	2018-05-03 15:00:00	2018-05-03 16:00:00	\N	\N	1	0	644	\N
270528	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Trait de côte	PPL Trait de côte	2018-05-16 14:30:00	2018-05-16 16:00:00	\N	\N	108	0	\N	\N
270529	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Verrou de Bercy	PPL Verrou de Bercy	2018-05-16 16:00:00	2018-05-16 18:20:00	\N	\N	107	0	\N	\N
270530	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Pensions agricoles	PPL Pensions agricoles	2018-05-16 18:30:00	2018-05-16 19:30:00	\N	\N	120	0	\N	\N
270531	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat évolution Parlement	Débat évolution Parlement	2018-05-16 23:05:00	2018-05-17 00:40:00	\N	\N	33	0	\N	\N
270644	COM_ENQUETE	PLENIERE	\N	FORCES	\N	Auditions CE FSI	Auditions CE FSI	2018-05-15 09:30:00	2018-05-15 11:00:00	2018-05-15 14:04:24	2018-05-15 18:19:21	6	0	\N	\N
271568	COM_PERMANENTE	DEPLACEMENT	\N	AFCL	\N	71e Festival de Cannes	71e Festival de Cannes	2018-05-08 09:00:00	2018-05-13 22:00:00	\N	\N	3	0	\N	\N
273330	GIA	AUCUNE	\N	\N	\N	Réunion reconstitutive	Réunion reconstitutive 	2018-01-23 13:30:00	2018-01-23 14:30:00	\N	\N	15	0	575	\N
299306	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Mission Mécénat	Mission Mécénat	2018-07-17 15:30:00	2018-07-17 16:30:00	\N	\N	3	0	\N	\N
299315	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2018-07-18 11:05:00	2018-07-18 11:45:00	2018-07-18 12:11:21	2018-07-18 14:48:51	24	1	\N	\N
311954	COM_SPECIALE	PLENIERE	\N	ENTREPRISES	\N	Réunion de bureau	\N	2018-10-16 14:10:00	2018-10-16 14:35:00	2018-10-16 15:11:43	2018-10-16 15:12:55	12	0	\N	\N
314344	COM_PERMANENTE	DEPLACEMENT	\N	CAE	\N	Orange Gardens	\N	2018-10-17 12:30:00	2018-10-17 16:30:00	\N	\N	7	0	\N	\N
314364	COM_PERMANENTE	DEPLACEMENT	\N	CAE	\N	Salon International de l'Alimentation	\N	2018-10-22 13:00:00	2018-10-22 19:00:00	\N	\N	8	0	\N	\N
314390	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2018-10-24 09:30:00	2018-10-24 11:50:00	2018-10-24 16:44:05	2018-10-24 16:54:41	73	0	\N	\N
314392	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions PLF 2019 DAG	\N	2018-10-22 14:30:00	2018-10-22 19:00:00	\N	\N	1	0	\N	\N
314412	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 -Crédits Recherche	PLF 2019 -Crédits Recherche	2018-10-17 14:30:00	2018-10-17 15:15:00	\N	\N	1	0	\N	\N
314414	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 -Crédits Recherche	PLF 2019 -Crédits Recherche	2018-10-17 15:15:00	2018-10-17 16:00:00	\N	\N	1	0	\N	\N
331359	GIA	AUCUNE	\N	\N	\N	Audition Dejean de la Batie	Audition Dejean de la Batie - Secrétaire permanent pour le Pacifique	2018-11-29 08:30:00	2018-11-29 09:30:00	\N	\N	3	0	651	\N
331414	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Communes nouvelles et diversité des territoires	\N	2018-11-27 10:15:00	2018-11-27 11:00:00	\N	\N	1	0	\N	\N
331417	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Communes nouvelles et diversité des territoires	\N	2018-11-27 18:00:00	2018-11-27 18:45:00	\N	\N	1	0	\N	\N
331419	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Communes nouvelles et diversité des territoires	\N	2018-11-28 08:30:00	2018-11-28 09:45:00	\N	\N	1	0	\N	\N
331422	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Communes nouvelles et diversité des territoires	\N	2018-11-28 14:30:00	2018-11-28 16:20:00	\N	\N	1	0	\N	\N
347020	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-02-06 10:30:00	2019-02-06 12:25:00	2019-02-06 14:46:32	2019-02-06 17:44:15	39	0	\N	\N
350883	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Interdire l'usage des lanceurs de balles de défense	\N	2019-02-07 14:00:00	2019-02-07 15:45:00	\N	\N	2	0	\N	\N
350886	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Interdire l'usage des lanceurs de balles de défense	\N	2019-02-07 15:45:00	2019-02-07 18:15:00	\N	\N	1	0	\N	\N
350888	DELEGATION	AUDRAP	\N	\N	206	Audition SAFT (Arrêt des véhicules thermiques)	Audition SAFT (Arrêt des véhicules thermiques)	2019-02-21 09:30:00	2019-02-21 10:30:00	\N	\N	0	0	\N	\N
247080	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Nom° rapp.+PPL Conflits d'intérêts+PPL Exécution peines+PPLO Etudes impact+PPL Politiques 	\N	2018-02-21 10:05:00	2018-02-21 11:45:00	2018-02-21 15:21:26	2018-02-21 15:55:02	41	0	\N	\N
270525	COM_PERMANENTE	AUTRE	\N	ETRD	\N	PJL LPM  2019-2025	\N	2018-05-16 09:00:00	2018-05-16 13:10:00	2018-05-16 17:36:08	2018-05-16 18:01:26	46	0	\N	\N
350889	DELEGATION	AUDRAP	\N	\N	206	Audition Fondation pour la Nature et l'Homme (Arrêt des véhicules thermiques)	Audition Fondation pour la Nature et l'Homme (Arrêt des véhicules thermiques)	2019-02-21 10:30:00	2019-02-21 12:30:00	\N	\N	0	0	\N	\N
351017	GIA	AUCUNE	\N	\N	\N	Rencontre avec des associations	Rencontre avec des membres de l'association Afrane, puis des membres de l'association Kolbaih Doust	2019-02-14 10:00:00	2019-02-14 12:00:00	\N	\N	1	0	648	\N
351019	GIA	AUCUNE	\N	\N	\N	Rencontre avec Mme Marie Philippe	Rencontre avec Mme Marie Philippe, , conseillère du président de la République pour le Moyen-Orient	2019-03-05 18:00:00	2019-03-05 19:00:00	\N	\N	1	0	615	\N
353865	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL "Habitat insalubre ou dangereux"	PPL "Habitat insalubre ou dangereux"	2019-02-12 16:30:00	2019-02-12 18:35:00	\N	\N	1	0	\N	\N
353867	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL "Lutte contre l'habitat insalubre"	PPL "Lutte contre l'habitat insalubre"	2019-02-13 11:30:00	2019-02-13 12:40:00	\N	\N	2	0	\N	\N
353870	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL "Habitat insalubre ou dangereux"	PPL "Habitat insalubre ou dangereux"	2019-02-14 10:30:00	2019-02-14 13:00:00	\N	\N	1	0	\N	\N
353872	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL "Habitat insalubre ou dangereux"	PPL "Habitat insalubre ou dangereux"	2019-02-14 13:45:00	2019-02-14 14:40:00	\N	\N	1	0	\N	\N
353874	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL "Habitat insalubre ou dangereux"	PPL "Habitat insalubre ou dangereux"	2019-02-14 16:30:00	2019-02-14 17:40:00	\N	\N	1	0	\N	\N
355517	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2019-02-20 14:40:00	2019-02-20 17:15:00	\N	\N	3	0	\N	\N
356134	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Prévenir et sanctionner les violences lors des manifestations	\N	2019-02-19 17:40:00	2019-02-19 18:30:00	\N	\N	1	0	\N	\N
356136	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Prévenir et sanctionner les violences lors des manifestations	\N	2019-02-21 14:30:00	2019-02-21 17:15:00	\N	\N	1	0	\N	\N
358123	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Prévenir et sanctionner les violences lors des manifestations - Motions et amendements	\N	2019-03-12 14:00:00	2019-03-12 14:20:00	2019-03-13 11:28:09	2019-03-13 11:30:32	21	0	\N	\N
359568	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Jean-Charles Bouthonnet, ambassadeur de France en Indonésie	Entretien avec M. Jean-Charles Bouthonnet, ambassadeur de France en Indonésie	2019-03-06 15:00:00	2019-03-06 16:00:00	\N	\N	3	0	653	\N
362181	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Actionnariat des SPL et SEM	\N	2019-03-19 09:45:00	2019-03-19 11:00:00	\N	\N	2	0	\N	\N
362185	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Actionnariat des SPL et SEM	\N	2019-03-19 15:30:00	2019-03-19 18:00:00	\N	\N	1	0	\N	\N
362189	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition PME et Numérique	Audition PME et Numérique - Gilles Babinet, French Digital Champion	2019-03-19 14:00:00	2019-03-19 15:00:00	\N	\N	1	0	\N	\N
362191	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition PME et Numérique	Audition PME et Numérique - McKinsey	2019-03-19 15:00:00	2019-03-19 16:00:00	\N	\N	1	0	\N	\N
362193	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition PME et Numérique	Audition PME et Numérique - Syntec Numérique	2019-03-19 16:00:00	2019-03-19 17:00:00	\N	\N	1	0	\N	\N
363408	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	SOCI	\N	Colloque réforme des retraites	\N	2019-03-21 14:00:00	2019-03-21 19:00:00	\N	\N	0	0	\N	\N
363423	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions par Mme Estrosi Sassone	\N	2019-03-21 08:30:00	2019-03-21 09:30:00	\N	\N	1	0	\N	\N
363427	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI mission défense européenne	\N	2019-03-19 15:00:00	2019-03-19 18:00:00	\N	\N	1	0	\N	\N
364439	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 2019 - Arrêt Installations nucléaires civiles - Cour des comptes	58-2 2019 - Arrêt Installations nucléaires civiles - Cour des comptes	2019-03-19 09:30:00	2019-03-19 10:30:00	\N	\N	1	0	\N	\N
364441	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Masse salariale du MEAE - Syndicats MEAE	Contrôle 2019 - Masse salariale du MEAE - Syndicats MEAE	2019-03-19 16:00:00	2019-03-19 17:30:00	\N	\N	2	0	\N	\N
364444	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n° 109 Corruption transnationale - Transparency International	PPL n° 109 Corruption transnationale - Transparency International	2019-03-19 15:30:00	2019-03-19 16:30:00	\N	\N	1	0	\N	\N
364446	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n° 109 Corruption transnationale - DDD DGM du MEAE	PPL n° 109 Corruption transnationale - DDD DGM du MEAE	2019-03-20 09:00:00	2019-03-20 10:15:00	\N	\N	1	0	\N	\N
364448	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n° 109 Corruption transnationale - DACG Min Justice	PPL n° 109 Corruption transnationale - DACG Min Justice	2019-03-20 11:00:00	2019-03-20 12:00:00	\N	\N	1	0	\N	\N
364450	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 21 mars 2019	Réunion du 21 mars 2019	2019-03-21 09:35:00	2019-03-21 10:10:00	2019-03-22 14:53:44	2019-03-22 15:00:17	16	0	\N	\N
364451	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Fraude fonds européens - SGAE / DNLF	Contrôle 2019 - Fraude fonds européens - SGAE / DNLF	2019-03-21 10:30:00	2019-03-21 12:30:00	\N	\N	1	0	\N	\N
364552	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ambassadeur d'Arménie	Déjeuner à l'invitation de l'ambassadeur d'Arménie en France	2019-03-19 13:00:00	2019-03-19 14:25:00	\N	\N	9	0	641	\N
364572	COM_EURO	AUDRAP	\N	AFEU	\N	Audition de l'ESA	Audition de l'ESA	2019-03-19 16:05:00	2019-03-19 17:10:00	\N	\N	2	0	\N	\N
364573	COM_EURO	AUDRAP	\N	AFEU	\N	Audition d'ArianeGroup	Audition d'ArianeGroup	2019-03-19 18:40:00	2019-03-19 19:45:00	\N	\N	2	0	\N	\N
364704	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2019-04-09 13:45:00	2019-04-09 14:30:00	\N	\N	2	0	\N	\N
364917	MECSS	AUDRAP	\N	\N	MECSS	Prise en charge financière de la dépendance des personnes âgées	Prise en charge financière de la dépendance des personnes âgées	2019-03-21 10:30:00	2019-03-21 11:30:00	\N	\N	2	0	\N	\N
365214	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	\N	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne 	2019-03-26 15:30:00	2019-03-26 16:10:00	2019-03-26 17:20:01	2019-03-26 18:02:15	8	0	\N	\N
214715	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion	Réunion	2017-11-07 16:35:00	2017-11-07 18:30:00	2017-11-07 18:38:10	2017-11-08 14:33:25	28	0	\N	\N
214719	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion	Réunion	2017-11-08 09:00:00	2017-11-08 10:00:00	2017-11-08 11:18:44	2017-11-08 14:33:22	38	0	\N	\N
214725	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion	Réunion	2017-11-08 16:45:00	2017-11-08 18:15:00	2017-11-08 18:30:46	2017-11-09 15:57:13	0	0	\N	\N
217369	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF pour 2018 - Avis "enseignement supérieur et recherche"	PJLF pour 2018 - Avis "enseignement supérieur et recherche"	2017-11-07 14:15:00	2017-11-07 15:00:00	\N	\N	1	0	\N	\N
217372	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF pour 2018 - Avis "enseignement supérieur et recherche"	PJLF pour 2018 - Avis "enseignement supérieur et recherche"	2017-11-07 16:00:00	2017-11-07 16:45:00	\N	\N	1	0	\N	\N
217376	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF pour 2018 - 	PJLF pour 2018 - Avis "enseignement supérieur et recherche"	2017-11-07 16:45:00	2017-11-07 17:30:00	\N	\N	1	0	\N	\N
217383	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF pour 2018 - Avis "enseignement supérieur et recherche"	PJLF pour 2018 - Avis "enseignement supérieur et recherche"	2017-11-07 18:00:00	2017-11-07 18:45:00	\N	\N	1	0	\N	\N
217388	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF pour 2018 - 	PJLF pour 2018 - Avis "enseignement supérieur et recherche"	2017-11-08 16:30:00	2017-11-08 17:00:00	\N	\N	1	0	\N	\N
217394	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF pour 2018 - Avis "enseignement supérieur et recherche"	PJLF pour 2018 - Avis "enseignement supérieur et recherche"	2017-11-08 17:00:00	2017-11-08 17:30:00	\N	\N	1	0	\N	\N
217400	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	\N	2017-11-09 15:00:00	2017-11-09 15:30:00	\N	\N	1	0	\N	\N
225151	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion de la commission des affaires européennes	\N	2017-11-30 08:30:00	2017-11-30 10:30:00	2017-11-30 11:52:18	2017-11-30 11:54:32	22	0	\N	\N
232974	GIA	AUCUNE	\N	\N	\N	Déplacement en Irak et au Liban	Déplacement en Irak et au Liban	2018-01-05 10:00:00	2018-01-09 21:00:00	\N	\N	4	0	CHRETORIENT	CHRETORIENT
238123	ETUDES	AUCUNE	\N	\N	\N	Réunion constitutive	Réunion constitutive	2018-01-24 08:30:00	2018-01-24 09:30:00	\N	\N	16	0	\N	948
238457	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2018-01-24 16:30:00	2018-01-24 17:45:00	2018-01-25 16:51:55	2018-01-25 17:28:24	42	0	\N	\N
240339	GIA	AUCUNE	\N	\N	\N	Assemblée générale GIA France-Chine	Assemblée générale GIA France-Chine	2018-02-01 08:30:00	2018-02-01 09:00:00	\N	\N	18	0	584	\N
241232	DELEGATION	AUCUNE	\N	\N	DSOM	Déplacement à Toulouse (Centre national de prévision météorologique)	Déplacement à Toulouse (Centre national de prévision météorologique)	2018-03-09 09:00:00	2018-03-09 20:00:00	2018-03-09 14:56:18	2018-03-09 15:42:14	7	0	\N	\N
241235	DELEGATION	AUCUNE	\N	\N	DSOM	Auditions étude sur la jeunesse des outre-mer et le sport	Auditions étude sur la jeunesse des outre-mer et le sport	2018-02-08 08:45:00	2018-02-08 11:50:00	2018-02-08 14:17:45	2018-02-08 15:08:05	14	0	\N	\N
241269	COM_PERMANENTE	AUTRE	\N	FINC	\N	Auditions conjointes Régulation des chaines de blocs et Essor monnaies virtuelles	Auditions conjointes Régulation des chaines de blocs et Essor monnaies virtuelles	2018-02-07 09:35:00	2018-02-07 12:25:00	2018-02-07 17:23:49	2018-02-08 14:52:24	26	0	\N	\N
245290	GIA	AUCUNE	\N	\N	\N	Petit-déjeuner avec l'Ambassadeur de Suisse	\N	2018-02-14 08:30:00	2018-02-14 09:30:00	\N	\N	11	0	610	\N
250063	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	PROS	Réunion de cadrage 	Réunion de cadrage pour la préparation du rapport sur "Le pacte entre les générations"	2018-02-20 10:00:00	2018-02-20 10:45:00	\N	\N	2	0	\N	\N
250066	DELEGATION	AUDRAP	\N	\N	PROS	Audition de l'UTP	Audition de M. Claude Faucher, délégué général de  l'UTP	2018-03-06 10:00:00	2018-03-06 11:00:00	\N	\N	3	0	\N	\N
250067	DELEGATION	AUDRAP	\N	\N	PROS	Audition de M. Louis Nègre, président du GART	Audition de M. Louis Nègre, président du GART	2018-03-06 18:15:00	2018-03-06 19:45:00	\N	\N	4	0	\N	\N
250068	DELEGATION	AUDRAP	\N	\N	PROS	Audition de l'AQST	Audition de M. Alain Sauvant, directeur de l'AQST et Arnaud Dumontier, secrétaire général de l'AQST 	2018-03-08 10:30:00	2018-03-08 11:25:00	\N	\N	2	0	\N	\N
250069	DELEGATION	AUDRAP	\N	\N	PROS	Audition de la FNTV	Audition de M. Jean-Sébastien Barrault et de Mme Ingrid Mareschal de la FNTV	2018-03-13 18:00:00	2018-03-13 19:00:00	\N	\N	4	0	\N	\N
252072	MECSS	AUDRAP	\N	\N	MECSS	\N	Accès précoce à l'innovation dans le domaine des produits de santé	2018-03-14 14:30:00	2018-03-14 15:30:00	\N	\N	3	0	\N	\N
256869	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Compétences eau et assainissement aux communautés de communes	\N	2018-03-20 14:00:00	2018-03-20 15:40:00	\N	\N	1	0	\N	\N
268101	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion	Réunion	2018-04-18 09:30:00	2018-04-18 12:25:00	2018-04-18 12:46:12	2018-04-18 16:47:47	31	0	\N	\N
268167	MISSION	AUCUNE	\N	HERBE	\N	Réunion constitutive	\N	2018-04-18 18:05:00	2018-04-18 18:40:00	2018-04-30 10:53:15	2018-04-30 10:53:23	25	0	\N	\N
269219	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2018 - Disponibilité hélicoptères des Armées - Déplacement à CAZAUX	Contrôle 2018 - Disponibilité des hélicoptères du ministère des Armées - Déplacement à CAZAUX	2018-04-20 06:50:00	2018-04-20 19:10:00	\N	\N	1	0	\N	\N
269290	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Réforme du logement	\N	2018-04-18 17:00:00	2018-04-18 19:20:00	\N	\N	1	0	\N	\N
269330	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL ELAN	PJL ELAN	2018-04-19 09:30:00	2018-04-19 10:20:00	\N	\N	1	0	\N	\N
269453	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Protection des données personnelles	\N	2018-04-19 14:05:00	2018-04-19 14:15:00	2018-04-19 15:06:01	2018-04-20 10:36:29	11	0	\N	\N
270018	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Audition plénière	\N	2018-04-18 17:00:00	2018-04-18 18:45:00	\N	\N	0	0	\N	\N
270095	AUTRE_TEMPORAIRE	AUTRE_NON_PLENIERE	\N	\N	\N	\N	\N	2018-04-19 11:30:00	2018-04-19 12:30:00	\N	\N	0	0	\N	\N
270096	AUTRE_TEMPORAIRE	AUTRE_NON_PLENIERE	\N	\N	\N	\N	\N	2018-04-18 17:00:00	2018-04-18 18:45:00	\N	\N	0	0	\N	\N
270216	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	LPM 2019-2025	\N	2018-04-12 10:45:00	2018-04-12 11:45:00	\N	\N	1	0	\N	\N
273304	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2018-05-23 11:05:00	2018-05-23 12:15:00	2018-05-23 14:24:29	2018-05-23 16:02:35	44	0	\N	\N
273396	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	Partenariat oriental	Auditions de représentants du ministère de l'Europe et des affaires étrangères	2018-05-16 17:30:00	2018-05-16 18:30:00	\N	\N	1	0	\N	\N
273460	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Mission "Routes de la soie"	\N	2018-05-16 16:00:00	2018-05-16 17:50:00	\N	\N	2	0	\N	\N
273487	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Immigration, droit d'asile et intégration	\N	2018-05-16 18:00:00	2018-05-16 19:30:00	\N	\N	3	0	\N	\N
273547	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 17 mai	Réunion du 17 mai	2018-05-17 09:05:00	2018-05-17 10:40:00	2018-05-17 19:09:17	2018-05-18 18:22:53	17	0	\N	\N
273583	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	Partenariat oriental	Audition de Mme Siradzé-Delaunay, ambassadrice de Géorgie en France	2018-05-17 15:30:00	2018-05-17 17:05:00	\N	\N	1	0	\N	\N
273599	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	LPM 2019-2025	\N	2018-05-17 16:00:00	2018-05-17 17:30:00	\N	\N	2	0	\N	\N
274851	DELEGATION	AUCUNE	\N	\N	COLTER	Audition de M. Jean-Luc Moudenc	\N	2018-05-31 09:00:00	2018-05-31 10:30:00	2018-05-31 10:57:13	2018-05-31 14:30:43	9	0	\N	\N
275187	MISSION	AUDRAP	\N	ALSTOM	\N	MI ALSTOM - Auditions président&rapporteur	\N	2018-05-22 17:00:00	2018-05-22 18:00:00	\N	\N	3	0	\N	\N
275213	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 24 mai 2018	Réunion de la commission des affaires européennes du 24 mai 2018	2018-05-24 08:30:00	2018-05-24 09:10:00	2018-05-25 17:08:20	2018-05-25 17:09:37	15	0	\N	\N
364547	GIA	AUCUNE	\N	\N	\N	Déjeuner du groupe d'amitié avec M. Sébastien Botreau Bonneterre (Expertise France)	Déjeuner du groupe d'amitié France-Albanie	2019-03-20 13:00:00	2019-03-20 14:00:00	\N	\N	4	0	571	\N
273302	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2018-05-23 10:35:00	2018-05-23 11:05:00	2018-05-23 14:23:55	2018-05-23 16:02:34	44	0	\N	\N
275234	COM_EURO	CONTROLE	\N	AFEU	\N	Audition de M. Gunther Oettinger, commissaire européen au budget	Audition de M. Gunther Oettinger, commissaire européen au budget	2018-05-24 09:15:00	2018-05-24 10:50:00	2018-05-25 17:08:43	2018-05-25 17:09:38	28	0	\N	\N
275290	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI responsabilité civile	\N	2018-05-23 14:30:00	2018-05-23 18:00:00	\N	\N	2	0	\N	\N
275629	ETUDES	AUCUNE	\N	\N	\N	\N	\N	2018-05-24 13:30:00	2018-05-24 14:50:00	\N	\N	18	0	\N	909
292076	GIA	AUCUNE	\N	\N	\N	Entretien avec une délégation gabonaise 	Entretien avec MM . Mba , ancien premier minsitre et M. Nguema , vice -président du Sénat gabonais 	2018-06-27 15:00:00	2018-06-27 16:30:00	\N	\N	2	0	572	\N
302442	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Auditions plénières	\N	2018-07-25 08:30:00	2018-07-25 13:30:00	2018-07-25 15:51:10	2018-07-25 17:10:44	51	0	\N	\N
302500	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2018-07-26 09:25:00	2018-07-26 10:45:00	2018-07-26 11:22:00	2018-07-26 17:23:09	17	1	\N	\N
302874	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de M. Gérard COLLOMB, Ministre d'État, Ministre de l'intérieur	Audition de M. Gérard COLLOMB, Ministre d'État, Ministre de l'intérieur	2018-07-24 17:55:00	2018-07-24 20:15:00	2018-07-25 15:56:23	2018-07-25 17:10:44	87	0	\N	\N
341958	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière-Examen note scientifique -Communic. A. Genetet-Audition risque de tsunami	Réunion plénière-Examen note scientifique -Communic. A. Genetet-Audition risque de tsunami	2019-02-07 09:15:00	2019-02-07 13:15:00	2019-02-07 15:22:14	\N	11	0	\N	\N
342001	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion 20190117	\N	2019-01-17 11:00:00	2019-01-17 13:00:00	2019-01-18 11:53:36	2019-01-18 11:53:49	27	2	\N	\N
342022	DELEGATION	AUDRAP	\N	\N	PROS	Audition du Ministère de l'Agriculture	\N	2019-01-23 11:00:00	2019-01-23 12:30:00	\N	\N	1	0	\N	\N
342803	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2020 - Justice - CADEJ	PLF pour 2020 - Justice - CADEJ	2019-01-15 08:30:00	2019-01-15 11:25:00	\N	\N	1	0	\N	\N
342868	COM_EURO	AUDRAP	\N	AFEU	\N	Audition de Yann Bonnet	\N	2019-01-16 14:00:00	2019-01-16 15:00:00	\N	\N	0	0	\N	\N
342940	DELEGATION	AUDRAP	\N	\N	PROS	Audition de M. Jean-Yves Camus	Audition de M. Jean-Yves Camus	2019-01-24 09:30:00	2019-01-24 11:10:00	\N	\N	1	0	\N	\N
344982	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT Biocarburants	Audition rapporteur - GT Biocarburants	2019-01-23 15:30:00	2019-01-23 16:40:00	\N	\N	4	0	\N	\N
344987	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT Biocarburants	GT Biocarburants - Audition rapporteur	2019-01-23 16:40:00	2019-01-23 17:30:00	\N	\N	3	0	\N	\N
345196	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Suite cyberattaque Ariane	\N	2019-01-23 14:00:00	2019-01-23 16:30:00	\N	\N	2	0	\N	\N
345199	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Turquie	\N	2019-01-24 12:00:00	2019-01-24 13:00:00	\N	\N	2	0	\N	\N
345203	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Turquie	\N	2019-01-24 15:00:00	2019-01-24 16:00:00	\N	\N	2	0	\N	\N
361498	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Colombie	\N	2019-03-12 14:45:00	2019-03-12 16:00:00	\N	\N	4	0	\N	\N
361504	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Turquie	\N	2019-03-13 14:30:00	2019-03-13 16:45:00	\N	\N	3	0	\N	\N
361550	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition sur le rapport sur les relations financières entre l'État et la sécurité sociale	Audition sur le rapport sur les relations financières entre l'État et la sécurité sociale	2019-03-20 10:35:00	2019-03-20 12:10:00	2019-03-20 15:14:08	2019-03-20 15:55:47	29	0	\N	\N
361575	DELEGATION	AUDRAP	\N	\N	PROS	Audition de la Compagnie nationale du Rhône (CNR)	\N	2019-03-27 11:00:00	2019-03-27 12:45:00	\N	\N	1	0	\N	\N
361576	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI thanatopraxie	\N	2019-03-14 09:30:00	2019-03-14 11:00:00	\N	\N	1	0	\N	\N
361578	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Recouvrement des amendes  - DGFiP	Contrôle 2019 - Recouvrement des amendes  - DGFiP	2019-03-14 10:30:00	2019-03-14 12:30:00	\N	\N	2	0	\N	\N
361617	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Création de l'Office français de la biodiversité	PJL Création de l'Office français de la biodiversité	2019-03-12 08:30:00	2019-03-12 10:00:00	\N	\N	1	0	\N	\N
361619	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Création de l'Office français de la biodiversité	PJL Création de l'Office français de la biodiversité	2019-03-12 14:00:00	2019-03-12 15:00:00	\N	\N	3	0	\N	\N
361623	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Création de l'Office français de la biodiversité	PJL Création de l'Office français de la biodiversité	2019-03-12 15:00:00	2019-03-12 16:10:00	\N	\N	3	0	\N	\N
361631	COM_PERMANENTE	AUDRAP	\N	CDD	\N	\N	\N	2019-03-13 14:30:00	2019-03-13 15:30:00	\N	\N	0	0	\N	\N
361633	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Création de l'Office français de la biodiversité	PJL Création de l'Office français de la biodiversité	2019-03-13 15:30:00	2019-03-13 16:30:00	\N	\N	4	0	\N	\N
361638	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Création de l'Office français de la biodiversité	PJL Création de l'Office français de la biodiversité	2019-03-13 16:30:00	2019-03-13 17:30:00	\N	\N	5	0	\N	\N
361683	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	groupe de travail justice prud'homale	groupe de travail justice prud'homale	2019-03-13 14:30:00	2019-03-13 18:30:00	\N	\N	3	0	\N	\N
362862	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2018 - Performance établissements ens. sup - Déplacement à La Haye	Contrôle 2018 - Performance établissements ens. sup - Déplacement à La Haye	2019-03-18 12:00:00	2019-03-19 21:40:00	\N	\N	1	0	\N	\N
362867	DELEGATION	AUDRAP	\N	\N	DSOM	Rencontre avec le personnel de France Ô	\N	2019-02-07 15:00:00	2019-02-07 17:30:00	\N	\N	3	0	\N	\N
362936	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Conséquences de la fraude documentaire sur la fraude aux prestations sociales	\N	2019-03-26 15:30:00	2019-03-26 16:30:00	\N	\N	3	0	\N	\N
363528	DELEGATION	AUDRAP	\N	\N	DSOM	Rencontre avec l'ADIE	\N	2019-03-21 11:15:00	2019-03-21 12:10:00	\N	\N	1	0	\N	\N
363577	COM_PERMANENTE	AUTRE	\N	CDD	\N	Examen des motions et amendements de séance - PJL Orientation des mobilités	\N	2019-03-26 13:30:00	2019-03-26 14:00:00	2019-03-26 15:49:25	2019-03-26 18:01:32	32	1	\N	\N
364203	COM_SPECIALE	AUTRE	\N	ENTREPRISES	\N	Réunion 20190327	\N	2019-03-27 14:35:00	2019-03-27 15:40:00	2019-03-27 15:44:59	2019-03-27 17:51:06	24	0	\N	\N
364282	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition commune sur la dématérialisation des moyens de paiement	Audition commune sur la dématérialisation des moyens de paiement	2019-03-27 10:00:00	2019-03-27 12:10:00	2019-03-27 16:06:04	2019-03-27 17:53:32	35	0	\N	\N
364292	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Création de l'Office français de la biodiversité	PJL Création de l'Office français de la biodiversité	2019-03-21 14:00:00	2019-03-21 15:00:00	\N	\N	3	0	\N	\N
364296	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Création de l'Office français de la biodiversité	PJL Création de l'Office français de la biodiversité	2019-03-21 14:00:00	2019-03-21 15:00:00	\N	\N	3	0	\N	\N
265117	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2018-04-10 14:30:00	2018-04-10 17:05:00	\N	\N	3	0	\N	\N
366009	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Échanges de vues sur le PJL OFB/AFB	\N	2019-03-26 18:15:00	2019-03-26 19:10:00	\N	\N	0	0	\N	\N
366990	MISSION	AUCUNE	\N	SIDERURGIE	\N	Audition de M. François MARZORATI	\N	2019-03-27 15:05:00	2019-03-27 16:15:00	\N	\N	8	0	\N	\N
367012	COM_SPECIALE	PLENIERE	\N	ENTREPRISES	\N	Réunion 201904	\N	2019-04-09 09:35:00	2019-04-09 09:55:00	2019-04-09 17:37:40	2019-04-09 17:42:01	15	0	\N	\N
367013	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Evénements 16 mars - Auditions directeurs généraux gendarmerie et police nationales	\N	2019-03-28 11:00:00	2019-03-28 13:20:00	2019-03-28 13:23:35	2019-03-28 17:22:28	10	0	\N	\N
367088	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-04-04 16:20:00	2019-04-04 17:15:00	2019-04-04 18:38:59	2019-04-05 10:15:03	20	0	\N	\N
367093	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - CNCCFP - ANC	Contrôle 2018 - CNCCFP - ANC	2019-03-26 14:45:00	2019-03-26 16:00:00	\N	\N	1	0	\N	\N
367098	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2020 - DAG - Visite CADA - Paris	PLF pour 2020 - DAG - Visite CADA - Paris	2019-03-26 14:10:00	2019-03-26 16:45:00	\N	\N	1	0	\N	\N
219598	GIA	AUCUNE	\N	\N	\N	Entretien délégation malienne avec M. Joël LABBE, Président délégué pour le Mali 	Entretien délégation malienne avec M. Joël LABBE, Président délégué pour le Mali 	2017-11-16 09:45:00	2017-11-16 10:30:00	\N	\N	1	0	573	\N
219601	GIA	AUCUNE	\N	\N	\N	Entretien délégation malienne avec Mme Fabienne KELLER, membre GIA Afrique de l'Ouest	Entretien délégation malienne avec Mme Fabienne KELLER, membre GIA Afrique de l'Ouest	2017-11-16 10:30:00	2017-11-16 11:00:00	\N	\N	1	0	573	\N
219928	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Écologie, développement et mobilité durables/Transports	PLF pour 2018 - Écologie, développement et mobilité durables/Transports - Audition DAM	2017-11-15 14:30:00	2017-11-15 15:30:00	\N	\N	1	0	\N	\N
219930	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Écologie, développement et mobilité durables/Énergie	PLF pour 2018 - Écologie, développement et mobilité durables/Énergie - Audition CRE	2017-11-14 15:00:00	2017-11-14 16:00:00	\N	\N	1	0	\N	\N
219935	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Écologie, développement et mobilité durables/Énergie	PLF pour 2018 - Écologie, développement et mobilité durables/Énergie - Audition AFB	2017-11-14 11:00:00	2017-11-14 12:00:00	\N	\N	1	0	\N	\N
219940	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Écologie, développement et mobilité durables/Énergie	PLF pour 2018 - Écologie, développement et mobilité durables/Énergie - Audition AMORCE	2017-11-14 16:00:00	2017-11-14 17:00:00	\N	\N	1	0	\N	\N
220138	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Contrôle et exploitation aériens 	PLF pour 2018 - Contrôle et exploitation aériens - Airbus, Acnusa et IGN	2017-11-16 15:00:00	2017-11-16 18:00:00	\N	\N	1	0	\N	\N
220140	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Contrôle et exploitation aériens 	PLF pour 2018 - Contrôle et exploitation aériens  - Météo France	2017-11-17 11:00:00	2017-11-17 12:00:00	\N	\N	1	0	\N	\N
220142	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Anciens combattants - CIVS - 2017	Contrôle Anciens combattants - CIVS - 2017 - Audition Ministère de la Culture, Direction générale des patrimoines	2017-11-16 09:00:00	2017-11-16 10:30:00	\N	\N	1	0	\N	\N
220145	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - GFPRH	PLF pour 2018 - GFPRH - DINSIC	2017-11-16 17:30:00	2017-11-16 18:30:00	\N	\N	1	0	\N	\N
220147	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2018 - Cohésion des territoires - Ministère de l'économie et des finances 	PLF pour 2018 - Cohésion des territoires - Ministère de l'économie et des finances - Bercy	2017-11-15 12:00:00	2017-11-15 13:15:00	\N	\N	1	0	\N	\N
220149	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2018 - Cohésion des territoires - Cabinet Premier ministre	PLF pour 2018 - Cohésion des territoires - Cabinet du Premier ministre	2017-11-16 08:00:00	2017-11-16 09:00:00	\N	\N	1	0	\N	\N
220151	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Rapport général	PLF pour 2018 - Rapport général - UNPI	2017-11-16 15:00:00	2017-11-16 15:30:00	\N	\N	1	0	\N	\N
230769	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Aide publique au développement	PLF pour 2018 - Aide publique au développement -  OCDE	2017-12-12 11:00:00	2017-12-12 12:00:00	\N	\N	1	0	\N	\N
232796	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2017-12-19 14:30:00	2017-12-19 16:45:00	\N	\N	3	0	\N	\N
232800	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2017-12-19 18:00:00	2017-12-19 19:00:00	\N	\N	3	0	\N	\N
232804	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Service national universel	\N	2017-12-19 17:45:00	2017-12-19 18:45:00	\N	\N	2	0	\N	\N
247163	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 15 février 2018	Réunion du 15 février 2018	2018-02-15 09:35:00	2018-02-15 11:05:00	2018-02-16 10:31:59	2018-02-16 11:49:51	17	0	\N	\N
247190	COM_EURO	AUDRAP	\N	AFEU	\N	Cabinet de la Garde des sceaux	Cabinet de la Garde des sceaux	2018-02-14 18:15:00	2018-02-14 19:05:00	\N	\N	2	0	\N	\N
248853	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion 2	Réunion 2	2018-02-21 10:35:00	2018-02-21 11:40:00	2018-02-21 11:54:05	2018-02-21 12:05:42	42	0	\N	\N
249771	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GS Brexit 	Groupe de travail - GS Brexit - Ambassadeur de France en Irlande	2018-02-21 16:10:00	2018-02-21 17:10:00	\N	\N	7	0	\N	\N
250199	COM_EURO	DEPLACEMENT	\N	AFEU	\N	La Haye (Pays-Bas) - 5 et 6 mars 2018	Rencontres avec le Parlement néerlandais - La Haye (Pays-Bas), 5 et 6 mars 2018	2018-03-05 14:15:00	2018-03-06 16:00:00	\N	\N	4	0	\N	\N
258340	GIA	AUCUNE	\N	\N	\N	Entretien Cambon délégation kurde	Entretien entre M. Cambon et une délégation de parlementaires kurdes	2018-03-19 17:30:00	2018-03-19 19:00:00	\N	\N	5	0	615	\N
258723	GIA	AUCUNE	\N	\N	\N	Visites de 3 délégations des pays baltes	Visites de 3 délégations des pays baltes	2018-03-20 08:45:00	2018-03-20 15:30:00	\N	\N	15	0	616	\N
258745	GIA	AUCUNE	\N	\N	\N	Colloque sur les Pays baltes	Colloque sur les Pays baltes	2018-03-19 14:00:00	2018-03-19 19:30:00	\N	\N	5	0	616	\N
267219	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Rapprochement France3 / France Bleu	Rapprochement entre France3 et France Bleu	2018-04-11 16:30:00	2018-04-11 17:30:00	\N	\N	4	0	\N	\N
269744	MISSION	AUCUNE	\N	MINEURSENF	\N	\N	\N	2018-04-19 14:00:00	2018-04-19 15:00:00	2018-04-19 15:22:49	2018-04-19 15:52:22	10	0	\N	\N
273354	GIA	AUCUNE	\N	\N	\N	Ambassadeur	Dîner autour de l'ambassadeur d'Algérie	2018-05-15 19:00:00	2018-05-15 22:00:00	\N	\N	14	0	575	\N
503728	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2021 Création	\N	2020-11-05 16:15:00	2020-11-05 17:05:00	\N	\N	3	0	\N	\N
365979	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion commission des lois	\N	2019-03-27 09:55:00	2019-03-27 13:00:00	2019-03-27 15:46:52	2019-03-27 17:53:33	44	1	\N	\N
367087	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-04-03 09:30:00	2019-04-03 10:35:00	2019-04-03 15:49:32	2019-04-03 15:50:02	43	0	\N	\N
273666	DELEGATION	AUCUNE	\N	\N	DSOM	Jeunesse des outre-mer et sport : audition de l'ANDES	Jeunesse des outre-mer et sport : audition de l'ANDES	2018-05-22 15:00:00	2018-05-22 17:20:00	2018-05-23 08:30:03	2018-05-23 16:02:03	8	0	\N	\N
273667	DELEGATION	AUCUNE	\N	\N	DSOM	Jeunesse des outre-mer et sport : audition du CNOSF et des fédérations sportives	Jeunesse des outre-mer et sport : audition du CNOSF et des fédérations sportives	2018-05-23 17:00:00	2018-05-23 18:35:00	2018-05-24 13:47:33	2018-05-24 14:29:41	6	0	\N	\N
273668	DELEGATION	AUCUNE	\N	\N	DSOM	Jeunessse des outre-mer et sport : visioconférence Mayotte, ambassadeurs	Jeunessse des outre-mer et sport : visioconférence Mayotte, ambassadeurs	2018-05-24 08:30:00	2018-05-24 11:45:00	2018-05-24 13:53:03	2018-05-24 14:29:42	8	0	\N	\N
273669	DELEGATION	AUCUNE	\N	\N	DSOM	Risques naturels majeurs : visioconférence Mayotte	Risques naturels majeurs : visioconférence Mayotte	2018-05-29 09:15:00	2018-05-29 11:00:00	2018-05-29 13:06:40	2018-05-30 15:49:01	8	0	\N	\N
273670	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	DSOM	Colloque Biodiversité du Pacifique	Colloque Biodiversité du Pacifique	2018-05-31 14:30:00	2018-05-31 19:00:00	\N	\N	0	0	\N	\N
273985	DELEGATION	AUCUNE	\N	\N	206	Rapport Cour des comptes sur les outils du PIA et présentation rapport Blockchains	Présentation rapport public thématique Cour des comptes sur les outils du PIA et présentation rapport Blockchains	2018-06-14 09:40:00	2018-06-14 12:55:00	2018-06-18 11:32:03	2018-06-21 15:55:55	12	0	\N	\N
273988	DELEGATION	AUCUNE	\N	\N	206	Audition de l'IRSN et présentation du rapport 2017 de la CNE2	Audition de M. Jean-Christophe NIEL, DG de l'IRSN et présentation du rapport 2017 de la CNE2	2018-06-21 09:40:00	2018-06-21 12:30:00	2018-06-21 16:47:45	2018-06-21 17:02:23	10	0	\N	\N
275162	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL ELAN	\N	2018-05-22 15:15:00	2018-05-22 18:30:00	\N	\N	1	0	\N	\N
275164	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL ELAN	\N	2018-05-23 14:30:00	2018-05-23 15:15:00	\N	\N	3	0	\N	\N
275168	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL ELAN	\N	2018-05-23 15:15:00	2018-05-23 16:00:00	\N	\N	1	0	\N	\N
275170	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL ELAN	\N	2018-05-23 16:00:00	2018-05-23 16:45:00	\N	\N	1	0	\N	\N
293824	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Pass Culture	\N	2018-06-19 15:00:00	2018-06-19 16:00:00	\N	\N	4	0	\N	\N
294202	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Renforcer la lutte contre les rodéos motorisés	\N	2018-07-03 14:30:00	2018-07-03 15:15:00	\N	\N	1	0	\N	\N
294955	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	auditions plénières	\N	2018-07-06 15:30:00	2018-07-06 17:00:00	\N	\N	0	0	\N	\N
295008	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 2018 - Très grandes infrastructures de recherche - CNRS	58-2 2018 - Très grandes infrastructures de recherche - CNRS	2018-07-04 11:15:00	2018-07-04 12:15:00	\N	\N	1	0	\N	\N
295026	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 2018 - Très grandes infrastructures de recherche - IFREMER	58-2 2018 - Très grandes infrastructures de recherche - IFREMER	2018-07-04 13:30:00	2018-07-04 14:30:00	\N	\N	1	0	\N	\N
295130	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Affaires Européennes - Cabinet Ministre des Affaires européennes	Contrôle 2018 - Affaires Européennes - Cabinet Ministre des Affaires européennes	2018-07-03 16:30:00	2018-07-03 17:30:00	\N	\N	1	0	\N	\N
295584	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018  - Coûts audiovisuel public -Jara Production-Société auteurs jeux-TV Consult	Contrôle 2018  - Coûts audiovisuel public - Jara Production et Société des auteurs de jeux et Tv Consult	2018-07-04 15:30:00	2018-07-04 18:00:00	\N	\N	1	0	\N	\N
295598	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Audition plénière	\N	2018-07-12 09:00:00	2018-07-12 10:00:00	\N	\N	0	0	\N	\N
350910	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	1041	\N	\N	Explications de vote sur l'ensemble PJL PACTE	Explications de vote sur l'ensemble PJL PACTE	2019-02-12 14:30:00	2019-02-12 15:35:00	\N	\N	308	0	\N	\N
350932	SEANCE_PLENIERE	SCRUSOL	1041	\N	\N	Scrutin solennel PJL PACTE	Scrutin solennel PJL PACTE	2019-02-12 15:35:00	2019-02-12 16:05:00	\N	\N	0	0	\N	\N
353854	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT Biocarburants	GT Biocarburants - Audition rapporteur - SNPAA	2019-02-13 15:00:00	2019-02-13 16:00:00	\N	\N	3	0	\N	\N
353858	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT Biocarburants	GT Biocarburants - Audition rapporteur - FranceAgriMer puis Total	2019-02-13 16:00:00	2019-02-13 18:15:00	\N	\N	4	0	\N	\N
364407	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Collectivité européenne d'Alsace	\N	2019-03-19 09:30:00	2019-03-19 11:00:00	\N	\N	1	0	\N	\N
364416	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2019-04-11 17:00:00	2019-04-11 18:00:00	\N	\N	3	0	\N	\N
364578	ETUDES	AUCUNE	\N	\N	\N	Audition d'Inaporc, l'interprofession de la filière porcine	Audition d'Inaporc, l'interprofession de la filière porcine	2019-03-27 08:00:00	2019-03-27 09:00:00	\N	\N	14	0	\N	911
364579	ETUDES	AUCUNE	\N	\N	\N	Audition de Domaines skiables de France	Audition de Domaines skiables de France	2019-03-27 08:30:00	2019-03-27 09:30:00	\N	\N	11	0	\N	918
364580	ETUDES	AUCUNE	\N	\N	\N	PJL Office français de la biodiversité	PJL Office français de la biodiversité	2019-03-26 18:15:00	2019-03-26 19:10:00	\N	\N	33	0	\N	907
367354	COM_PERMANENTE	AUTRE	\N	LOIS	\N	réunion de commission	Auditions évènements du 16 mars	2019-04-03 14:00:00	2019-04-03 17:40:00	2019-04-03 18:01:54	2019-04-04 11:40:58	30	0	\N	\N
367466	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	1081	\N	\N	Explications de vote sur l'ensemble	Explications de vote sur l'ensemble	2019-04-02 14:30:00	2019-04-02 15:30:00	\N	\N	300	0	\N	\N
367467	SEANCE_PLENIERE	SCRUSOL	1081	\N	\N	Scrutin solennel	Scrutin solennel	2019-04-02 15:30:00	2019-04-02 16:00:00	\N	\N	0	0	\N	\N
368184	SEANCE_PLENIERE	AUTRE	\N	\N	\N	Audition Grand débat national	Audition sur la méthodologie du Grand débat national	2019-04-04 08:30:00	2019-04-04 10:00:00	\N	\N	121	0	\N	\N
502341	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PLFR 2020	CMP PLFR 2020	2020-11-24 14:30:00	2020-11-24 15:30:00	\N	\N	83	0	\N	\N
367353	COM_PERMANENTE	AUTRE	\N	LOIS	\N	réunion de commission PPL Actionnariat des SPL et SEM	\N	2019-04-03 10:15:00	2019-04-03 10:25:00	2019-04-03 11:59:59	2019-04-04 11:41:00	40	1	\N	\N
368608	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	algorithmes locaux dans Parcoursup	\N	2019-04-02 14:00:00	2019-04-02 15:00:00	\N	\N	3	0	\N	\N
368631	GIA	AUCUNE	\N	\N	\N	Rencontre avec l'ambassadeur du Turkménistan	Rencontre avec l'ambassadeur du Turkménistan	2019-04-03 08:30:00	2019-04-03 09:30:00	\N	\N	5	0	556	\N
368970	GIA	AUCUNE	\N	\N	\N	Entretien avec une délégation du CESE (affaires européennes et internationales)	Entretien avec une délégation du CESE (section des affaires européennes et internationales)	2019-04-03 08:30:00	2019-04-03 09:20:00	\N	\N	6	0	674	\N
368991	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-04-10 10:50:00	2019-04-10 12:15:00	2019-04-10 12:20:19	2019-04-10 16:50:57	33	0	\N	\N
369090	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition commune	\N	2019-04-10 10:35:00	2019-04-10 12:30:00	2019-04-10 12:28:28	2019-04-10 16:50:58	45	0	\N	\N
369678	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	GT justice prud'homale	\N	2019-03-20 13:45:00	2019-03-20 18:30:00	\N	\N	3	0	\N	\N
369682	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	GT justice prud'homale	\N	2019-03-26 14:30:00	2019-03-26 16:30:00	\N	\N	2	0	\N	\N
369685	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	GT justice prud'homale	\N	2019-04-02 16:00:00	2019-04-02 18:15:00	\N	\N	2	0	\N	\N
369711	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition thanatopraxie	MI thanatopraxie	2019-04-04 10:00:00	2019-04-04 11:00:00	\N	\N	1	0	\N	\N
369716	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2020 - Défense - Déplacement MASCATE CDG	PLF pour 2020 - Défense - Déplacement MASCATE CDG	2019-04-23 21:00:00	2019-04-26 20:00:00	\N	\N	1	0	\N	\N
369838	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Conséquences de la fraude documentaire sur la fraude aux prestations sociales	\N	2019-04-30 17:30:00	2019-04-30 18:30:00	\N	\N	1	0	\N	\N
369841	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition Didier MIGAUD président HCFP Avis prévisions programme stabilité 2019-2023	Audition Didier MIGAUD président HCFP sur l¿avis relatif aux prévisions macroéconomiques programme stabilité 2019-2023	2019-04-10 15:00:00	2019-04-10 16:10:00	2019-04-10 16:55:21	2019-04-10 17:14:03	24	0	\N	\N
369842	COM_PERMANENTE	AUTRE	\N	FINC	\N	Contrôle budgétaire création métropole de Lyon - Audition transformation ISF en IFI et PFU	Contrôle budgétaire création métropole de Lyon - Audition transformation ISF en IFI et PFU	2019-04-10 09:35:00	2019-04-10 12:35:00	2019-04-10 14:55:07	2019-04-10 16:51:00	34	0	\N	\N
369858	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de M. Rodolphe GINTZ, directeur général des douanes et des droits indirects	Audition de M. Rodolphe GINTZ, directeur général des douanes et des droits indirects	2019-04-11 11:05:00	2019-04-11 12:30:00	2019-04-12 17:28:49	2019-04-12 17:32:50	16	0	\N	\N
370163	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 3 avril 2019	\N	2019-04-03 18:05:00	2019-04-03 18:45:00	2019-04-04 18:45:02	2019-04-05 10:14:36	12	0	\N	\N
370164	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Turquie	\N	2019-04-03 14:30:00	2019-04-03 15:45:00	\N	\N	2	0	\N	\N
370167	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Turquie	\N	2019-04-03 15:45:00	2019-04-03 17:00:00	\N	\N	3	0	\N	\N
370172	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	tur	\N	2019-04-03 17:00:00	2019-04-03 18:15:00	\N	\N	2	0	\N	\N
370185	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Turquie	\N	2019-04-04 09:30:00	2019-04-04 10:40:00	\N	\N	2	0	\N	\N
370199	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Le recouvrement des amendes de circulation - FNMS	Contrôle 2019 - Le recouvrement des amendes de circulation - FNMS	2019-04-03 09:00:00	2019-04-03 10:00:00	\N	\N	2	0	\N	\N
370821	DELEGATION	DEPLACEMENT	\N	\N	ENTREPRISES	Déplacement dans le Val-d'Oise	Déplacement dans le Val-d'Oise	2019-03-15 08:00:00	2019-03-15 17:00:00	\N	\N	8	0	\N	\N
371078	ETUDES	AUCUNE	\N	\N	\N	GE numérique	\N	2019-04-04 16:45:00	2019-04-04 17:15:00	\N	\N	4	0	\N	1008
371097	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	DSOM	Représentation et visibilité des outre-mer dans l'audiovisuel public (conférence  presse)	\N	2019-04-09 15:10:00	2019-04-09 16:35:00	\N	\N	5	0	\N	\N
371185	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL accords sanitaires France-Monaco	\N	2019-04-09 13:45:00	2019-04-09 16:00:00	\N	\N	1	0	\N	\N
371681	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion de la commission des lois	\N	2019-04-10 12:20:00	2019-04-10 13:10:00	2019-04-10 17:24:48	2019-04-10 17:48:31	39	0	\N	\N
219119	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2017-11-14 14:30:00	2017-11-14 16:15:00	\N	\N	3	0	\N	\N
219125	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2017-11-14 17:45:00	2017-11-15 00:00:00	\N	\N	3	0	\N	\N
222386	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2017-11-29 10:55:00	2017-11-29 11:15:00	2017-11-29 11:53:46	2017-11-29 16:50:30	39	1	\N	\N
222532	DELEGATION	AUCUNE	\N	\N	COLTER	PPR  maîtrise et simplification normes réglementaires relatives au sport	\N	2017-11-30 08:00:00	2017-11-30 09:00:00	2017-11-30 10:11:13	2017-11-30 11:57:53	19	0	\N	\N
227449	BUREAU	AUCUNE	\N	\N	\N	Délégation statut du sénateur	Délégation statut du sénateur	2017-12-06 12:00:00	2017-12-06 12:50:00	\N	\N	6	0	\N	\N
228581	COM_EURO	AUDRAP	\N	AFEU	\N	Audition de M. Klaus-Heiner Lehne	Audition de M. Klaus-Heiner Lehne, président de la Cour des comptes européenne	2017-12-05 17:30:00	2017-12-05 18:30:00	\N	\N	10	0	\N	\N
235356	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Compte rendu du déplacement en Côte-d'Or	Compte rendu du déplacement en Côte-d'Or et échanges de vues sur le programme de la journée des entreprises	2018-01-18 08:30:00	2018-01-18 10:00:00	2018-01-18 14:51:21	2018-01-18 14:57:13	19	0	\N	\N
235395	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition cyle de vie des entreprises	Audition cycle de vie des entreprises - liquidation et insolvabilité	2018-01-18 16:00:00	2018-01-18 17:10:00	\N	\N	1	0	\N	\N
235397	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition cycle de vie des entreprises	Audition cycle de vie des entreprises - Association 60 000 rebonds	2018-01-18 17:15:00	2018-01-18 17:55:00	\N	\N	1	0	\N	\N
238740	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe	Assemblée générale du groupe	2018-01-23 12:30:00	2018-01-23 13:00:00	\N	\N	20	0	604	\N
239630	COM_PERMANENTE	DEPLACEMENT	\N	AFCL	\N	Bibliothèque nationale de France	Bibliothèque nationale de France	2018-01-31 08:30:00	2018-01-31 11:00:00	\N	\N	25	0	\N	\N
247158	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Russie	\N	2018-02-13 09:30:00	2018-02-13 10:45:00	\N	\N	2	0	\N	\N
247161	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Russie	\N	2018-02-15 16:15:00	2018-02-15 17:30:00	\N	\N	1	0	\N	\N
369859	COM_PERMANENTE	AUTRE	\N	ETRD	\N	test envoi kairos itop R-074819	\N	2015-04-03 09:00:00	2015-04-03 11:00:00	\N	\N	0	0	\N	\N
222384	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2017-11-29 09:35:00	2017-11-29 10:55:00	2017-11-29 11:54:03	2017-11-29 16:50:29	39	1	\N	\N
250192	COM_ENQUETE	PLENIERE	\N	CHUTE	\N	\N	\N	2018-03-08 16:30:00	2018-03-08 17:25:00	2018-03-09 14:04:13	2018-03-09 14:42:28	6	0	\N	\N
250193	COM_ENQUETE	PLENIERE	\N	CHUTE	\N	Institut de relations internationales et stratégiques	Institut de relations internationales et stratégiques	2018-03-06 14:00:00	2018-03-06 15:00:00	2018-03-09 15:30:34	2018-03-09 15:42:51	11	0	\N	\N
250194	COM_ENQUETE	PLENIERE	\N	CHUTE	\N	Société de conseil et formation en contre-terrorisme et radicalisation Action résilience	Société de conseil et formation en contre-terrorisme et radicalisation Action résilience	2018-03-06 15:00:00	2018-03-06 16:00:00	2018-03-09 15:30:49	2018-03-09 15:42:53	12	0	\N	\N
250195	COM_ENQUETE	PLENIERE	\N	CHUTE	\N	DGSE / DGSI	DGSE / DGSI	2018-03-07 15:00:00	2018-03-07 16:30:00	2018-03-09 15:29:12	2018-03-09 15:42:54	16	0	\N	\N
250196	COM_ENQUETE	CONTROLE	\N	CHUTE	\N	\N	\N	2018-03-07 16:35:00	2018-03-07 17:45:00	2018-03-09 15:30:01	2018-03-09 15:42:55	10	0	\N	\N
250197	COM_ENQUETE	PLENIERE	\N	CHUTE	\N	\N	\N	2018-03-08 12:00:00	2018-03-08 13:00:00	2018-03-09 14:02:26	2018-03-09 14:42:22	12	0	\N	\N
250198	COM_ENQUETE	PLENIERE	\N	CHUTE	\N	\N	\N	2018-03-08 11:00:00	2018-03-08 12:00:00	2018-03-09 14:01:03	2018-03-09 14:42:21	12	0	\N	\N
250204	DELEGATION	AUCUNE	\N	\N	DSOM	Auditions Risques naturels majeurs dans les outre-mer	Auditions Risques naturels majeurs dans les outre-mer	2018-03-07 17:00:00	2018-03-07 20:45:00	2018-03-08 13:36:20	2018-03-08 13:53:14	7	0	\N	\N
250210	DELEGATION	AUCUNE	\N	\N	DSOM	Visioconférence avec la Nouvelle-Calédonie et Mayotte  (risques naturels outre-mer) 	Visioconférence avec la Nouvelle-Calédonie et Mayotte (risques naturels majeurs dans les outre-mer)	2018-04-05 08:35:00	2018-04-05 10:35:00	2018-04-05 11:15:26	2018-04-05 11:36:00	12	0	\N	\N
250221	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contôle MIRES - Performance établissements ens. sup	Contôle MIRES - Performance établissements ens. sup - Cabinet du ministre	2018-03-15 16:00:00	2018-03-15 17:00:00	\N	\N	1	0	\N	\N
250224	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2018-03-07 10:10:00	2018-03-07 11:50:00	2018-03-07 11:58:59	2018-03-07 12:09:54	45	0	\N	\N
254554	DELEGATION	AUDRAP	\N	\N	206	Audition de l'INRA	Audition de M. Philippe Mauguin, président-directeur général de l'Institut national de la recherche agronomique (INRA)	2018-03-29 11:30:00	2018-03-29 13:00:00	\N	\N	2	0	\N	\N
255562	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	GT revitalisation: e-commerce	\N	2018-03-14 15:00:00	2018-03-14 16:45:00	\N	\N	9	0	\N	\N
258974	GIA	AUCUNE	\N	\N	\N	Rencontre avec l'Ambassadeur de France en Afrique du Sud	Rencontre avec S.E. M. Christophe FARNAUD, Ambassadeur de France en Afrique du Sud	2018-03-22 18:00:00	2018-03-22 19:05:00	\N	\N	2	0	574	\N
259773	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT Evolution de la fiscalité locale	GT Fiscalité locale Scénarios de répartition au sein du bloc communal de recettes pour compenser la suppression de la TH	2018-03-27 14:30:00	2018-03-27 15:15:00	\N	\N	9	0	\N	\N
270317	DELEGATION	AUDRAP	\N	\N	PROS	Audition de l'Observatoire des inégalités	Audition de Nina Schmidt, cheffe de projets, responsable de l'antenne Île-de France de l'Observatoire des inégalités.	2018-05-15 09:45:00	2018-05-15 10:45:00	\N	\N	2	0	\N	\N
275724	DELEGATION	AUCUNE	\N	\N	211	Conclusions du groupe de travail (com. des Lois) - échange de vues PJL violences sexuelles	Conclusions du groupe de travail (com. des Lois) - échange de vues PJL violences sexuelles	2018-05-31 09:00:00	2018-05-31 10:45:00	2018-05-31 12:39:25	2018-05-31 14:30:44	13	0	\N	\N
275840	GIA	AUCUNE	\N	\N	\N	Entretien de M. Joël BIGOT avec M. Andres HERKEL, Pdt GA Estonie-France	Entretien de M. Joël BIGOT avec M. Andres HERKEL, Pdt GA Estonie-France	2018-05-25 08:45:00	2018-05-25 09:45:00	\N	\N	1	0	616	\N
275895	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Modernisation de la transmission d'entreprise	\N	2018-05-22 09:30:00	2018-05-22 10:30:00	\N	\N	1	0	\N	\N
275897	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Modernisation de la transmission d'entreprise	\N	2018-05-22 15:30:00	2018-05-22 16:30:00	\N	\N	1	0	\N	\N
275899	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Autorisation d'analyses génétiques sur personnes décédées	\N	2018-05-22 14:00:00	2018-05-22 18:00:00	\N	\N	1	0	\N	\N
275901	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Autorisation d'analyses génétiques sur personnes décédées	\N	2018-05-23 18:15:00	2018-05-23 19:15:00	\N	\N	1	0	\N	\N
276020	GIA	AUCUNE	\N	\N	\N	Déplacement à l'école française d'extrême-orient	Déplacement à l'école française d'extrême-orient	2018-05-24 11:30:00	2018-05-24 14:30:00	\N	\N	4	0	577	\N
277645	MISSION	AUCUNE	\N	MINEURSENF	\N	\N	\N	2018-05-29 17:50:00	2018-05-29 19:15:00	2018-05-29 19:46:19	2018-05-30 15:48:16	5	0	\N	\N
277969	GIA	AUCUNE	\N	\N	\N	Entretien de M. Khaled Mechri, Président du Haut Conseil d¿Etat libyen	Entretien de M. Khaled Mechri, Président du Haut Conseil d¿Etat libyen	2018-05-29 18:00:00	2018-05-29 19:15:00	\N	\N	4	0	657	\N
278102	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion 2018 05 30 b	Réunion 2018 05 30 b	2018-05-30 15:05:00	2018-05-30 17:05:00	2018-05-31 10:15:42	2018-05-31 14:31:02	31	0	\N	\N
278168	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL pour la liberté de choisir son avenir professionnel	PJL pour la liberté de choisir son avenir professionnel	2018-05-14 14:00:00	2018-05-14 17:10:00	\N	\N	3	0	\N	\N
278170	GIA	AUCUNE	\N	\N	\N	Entretien de M. Reichardt avec une délégation de parlementaires du Ghana (coopé)	Entretien de M. Reichardt avec une délégation de parlementaires du Ghana (coopé)	2018-05-30 12:30:00	2018-05-30 14:00:00	\N	\N	7	0	573	\N
278252	GIA	AUCUNE	\N	\N	\N	Entretien de M. SUTOUR avec Mme DEMETROU, Députée de la Chambre des Représentants (Coopé)	Entretien de M. SUTOUR avec Mme DEMETROU, Députée de la Chambre des Représentants (Coopé)	2018-04-11 11:30:00	2018-04-11 12:00:00	\N	\N	1	0	585	\N
292654	GIA	AUCUNE	\N	\N	\N	Réunion du groupe 	Réunion du groupe	2018-06-21 14:00:00	2018-06-21 14:30:00	\N	\N	6	0	623	\N
292714	BUREAU	AUCUNE	\N	\N	\N	Bureau	Bureau	2018-06-28 09:00:00	2018-06-28 12:10:00	\N	\N	22	0	\N	\N
299284	ETUDES	AUCUNE	\N	\N	\N	G.E. Economie sociale et solidaire	G.E. Economie sociale et solidaire	2018-07-17 08:00:00	2018-07-17 09:15:00	\N	\N	6	0	\N	998
300540	GIA	AUCUNE	\N	\N	\N	Entretien avec Jean-Christophe Deberre	Entretien avec Jean-Christophe Deberre, directeur général de la Mission laïque française	2018-07-19 08:30:00	2018-07-19 09:30:00	\N	\N	5	0	597	\N
317299	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	Commission des comptes	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne	2018-10-25 14:35:00	2018-10-25 14:55:00	2018-10-25 17:11:58	2018-10-25 18:10:19	9	0	\N	\N
250223	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2018-03-07 09:30:00	2018-03-07 10:10:00	2018-03-07 11:58:22	2018-03-07 12:09:53	45	0	\N	\N
278101	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion 2018 05 30a	Réunion 2018 05 30a	2018-05-30 09:40:00	2018-05-30 11:15:00	2018-05-30 12:35:08	2018-05-30 15:48:42	45	0	\N	\N
345108	ETUDES	AUCUNE	\N	\N	\N	Audition	Audition de M. Thierry LEPAON	2019-01-24 14:00:00	2019-01-24 15:00:00	\N	\N	2	0	\N	1006
348095	DELEGATION	AUCUNE	\N	\N	COLTER	Audition Secrétariat général du Gouvernement (simplification normative)	\N	2019-02-14 09:00:00	2019-02-14 10:15:00	2019-02-14 10:58:07	2019-02-14 11:06:12	14	0	\N	\N
348096	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	GT ruralités : Les grands opérateurs et les ruralités	\N	2019-02-14 13:30:00	2019-02-14 15:00:00	\N	\N	0	0	\N	\N
348097	DELEGATION	AUCUNE	\N	\N	COLTER	Auditions préfets simplification des normes ; Audition Mme Troendlé communication	\N	2019-02-21 09:30:00	2019-02-21 12:00:00	2019-02-21 16:12:30	2019-02-21 17:54:59	9	0	\N	\N
350016	GIA	AUCUNE	\N	\N	\N	Diner	Participation du Président Vall au diner du collectif France-Népal	2018-09-03 18:00:00	2018-09-03 23:00:00	\N	\N	1	0	633	\N
350020	GIA	AUCUNE	\N	\N	\N	Diner collectif France-Népal	Participation du Président Vall au diner du collectif France-Népal	2019-01-29 20:30:00	2019-01-29 23:30:00	\N	\N	1	0	633	\N
353786	GIA	AUCUNE	\N	\N	\N	Entretien avec Mme KASEBA-SATA, ambassadrice de Zambie en France	Entretien avec Mme KASEBA-SATA, ambassadrice de Zambie en France	2019-02-14 11:00:00	2019-02-14 12:00:00	\N	\N	5	0	646	\N
356227	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Création de l'Office français de la biodiversité	PJL Création de l'Office français de la biodiversité	2019-02-25 09:00:00	2019-02-25 12:00:00	\N	\N	0	0	\N	\N
356982	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI mission défense européenne	\N	2019-03-05 14:30:00	2019-03-05 16:00:00	\N	\N	2	0	\N	\N
358313	COM_PERMANENTE	DEPLACEMENT	\N	CAE	\N	Salon international de l'agriculture 2019	Salon international de l'agriculture 2019	2019-02-27 08:30:00	2019-02-27 18:00:00	\N	\N	15	0	\N	\N
360656	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2019-03-20 09:30:00	2019-03-20 11:15:00	2019-03-20 11:28:19	2019-03-20 15:55:49	46	0	\N	\N
361144	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 2019 - Pilotage des opérateurs de l'action extérieure de l'Etat - Cour des comptes	58-2 2019 - Pilotage des opérateurs de l'action extérieure de l'Etat - Cour des comptes	2019-03-12 09:00:00	2019-03-12 10:30:00	\N	\N	2	0	\N	\N
361147	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Masse salariale du MEAE - MEAE	Contrôle 2019 - Masse salariale du MEAE - MEAE	2019-03-12 15:00:00	2019-03-12 16:00:00	\N	\N	2	0	\N	\N
361150	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Les contrats de ruralité - SGAR Auvergne rhône alpes	Contrôle 2019 - Les contrats de ruralité - SGAR Auvergne rhône alpes	2019-03-13 10:00:00	2019-03-13 11:00:00	\N	\N	1	0	\N	\N
361169	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-03-20 09:00:00	2019-03-20 10:40:00	2019-03-20 18:51:31	2019-03-21 14:21:53	42	0	\N	\N
361753	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Actionnariat des SPL et SEM	\N	2019-03-19 09:00:00	2019-03-19 09:45:00	\N	\N	1	0	\N	\N
361859	MISSION	DEPLACEMENT	\N	INFRACTIONS	\N	Déplacement à Lyon	\N	2019-03-19 08:00:00	2019-03-19 18:00:00	\N	\N	6	0	\N	\N
362011	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2019-04-09 14:00:00	2019-04-09 15:00:00	\N	\N	3	0	\N	\N
362064	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions thanatopraxie	MI thanatopraxie	2019-03-19 14:30:00	2019-03-19 16:00:00	\N	\N	1	0	\N	\N
367114	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL École de la confiance	\N	2019-03-28 08:15:00	2019-03-28 09:00:00	\N	\N	3	0	\N	\N
367119	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL École de la confiance	\N	2019-03-28 09:15:00	2019-03-28 10:00:00	\N	\N	4	0	\N	\N
367135	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL École de la confiance	\N	2019-03-28 10:15:00	2019-03-28 11:00:00	\N	\N	2	0	\N	\N
367138	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL École de la confiance	\N	2019-03-28 11:00:00	2019-03-28 12:00:00	\N	\N	1	0	\N	\N
367372	COM_PERMANENTE	AUTRE	\N	FINC	\N	Communication - Contrôle recevabilité financière des amendements et PPL au titre de l'Art 	Communication - Contrôle recevabilité financière des amendements et PPL au titre de l'Art 40	2019-04-03 10:15:00	2019-04-03 11:25:00	2019-04-03 15:50:53	2019-04-03 15:58:58	44	0	\N	\N
367391	MISSION	AUDRAP	\N	INFRACTIONS	\N	Auditions rapporteures	\N	2019-04-02 16:30:00	2019-04-02 18:30:00	\N	\N	3	0	\N	\N
367778	MISSION	AUDRAP	\N	CLIMATIQUE	\N	Audition CEREMA	Audition CEREMA	2019-04-02 08:00:00	2019-04-02 09:00:00	\N	\N	5	0	\N	\N
367799	DELEGATION	AUCUNE	\N	\N	COLTER	Audition O. Lluansi, délégué aux territoires d'industrie	\N	2019-04-11 10:00:00	2019-04-11 11:30:00	2019-04-11 11:41:14	\N	12	0	\N	\N
368187	COM_PERMANENTE	DEPLACEMENT	\N	SOCI	\N	\N	\N	2019-04-09 15:30:00	2019-04-09 17:00:00	\N	\N	2	0	\N	\N
368782	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition par Mme Estrosi Sassone	\N	2019-03-27 17:30:00	2019-03-27 18:30:00	\N	\N	1	0	\N	\N
369421	COM_PERMANENTE	DEPLACEMENT	\N	AFCL	\N	Déplacement à la FEMIS	Déplacement à la FEMIS	2019-04-03 09:45:00	2019-04-03 11:30:00	\N	\N	14	0	\N	\N
370719	DELEGATION	AUDRAP	\N	\N	PROS	Audition du CSTB	\N	2019-04-09 09:00:00	2019-04-09 10:15:00	\N	\N	2	0	\N	\N
370720	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Reconnaissance du crime d'écocide	\N	2019-04-04 09:15:00	2019-04-04 10:30:00	\N	\N	1	0	\N	\N
370723	MISSION	AUCUNE	\N	SIDERURGIE	\N	Audition plénière - MI Sidérurgie	Audition plénière - MI Sidérurgie	2019-04-04 14:00:00	2019-04-04 15:00:00	2019-04-05 16:45:02	2019-04-05 16:57:20	6	0	\N	\N
370739	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 2019 - L'enseignement supérieur artistique - Cour des comptes	58-2 2019 - L'enseignement supérieur artistique - Cour des comptes	2019-04-04 16:15:00	2019-04-04 17:15:00	\N	\N	1	0	\N	\N
370768	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2019 -Ressources humaines du ministère des armées - Déplacement à Mailly-Le-Camp	Contrôle 2019 -Ressources humaines du ministère des armées - Déplacement à Mailly-Le-Camp	2019-04-15 07:00:00	2019-04-15 18:55:00	\N	\N	1	0	\N	\N
370769	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	DSOM	Rencontre avec une délégation de l'Assemblée de Polynésie française	\N	2019-04-04 10:00:00	2019-04-04 10:45:00	\N	\N	8	0	\N	\N
370800	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	santé au travail	Santé au travail	2019-03-26 15:00:00	2019-03-26 16:00:00	\N	\N	1	0	\N	\N
271232	MISSION	AUCUNE	\N	MINEURSENF	\N	\N	\N	2018-05-15 17:55:00	2018-05-15 19:30:00	2018-05-15 19:27:30	2018-05-16 14:14:06	11	0	\N	\N
360657	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière PPL Protection des drapeaux d'associations d'anciens combattants	\N	2019-03-20 11:15:00	2019-03-20 11:40:00	2019-03-20 11:37:05	2019-03-20 15:55:44	49	0	\N	\N
361170	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-03-20 10:40:00	2019-03-20 11:30:00	2019-03-20 18:52:02	2019-03-21 14:21:51	44	0	\N	\N
370806	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Évaluation transformation ISF en IFI et création PFU	Contrôle 2019 - Évaluation transformation ISF en IFI et création PFU - VHAvocats/CNRS et Ecole d'Economie de Paris/FIDAL	2019-04-04 09:00:00	2019-04-04 11:45:00	\N	\N	2	0	\N	\N
370815	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Évaluation transformation ISF en IFI et création PFU - France Digitale	Contrôle 2019 - Évaluation transformation ISF en IFI et création PFU - France Digitale	2019-04-04 17:45:00	2019-04-04 18:30:00	\N	\N	2	0	\N	\N
370820	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière	\N	2019-04-11 09:00:00	2019-04-11 10:15:00	2019-04-11 11:23:49	\N	15	0	\N	\N
213351	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2017-10-24 14:30:00	2017-10-24 17:00:00	\N	\N	3	0	\N	\N
213380	GIA	AUCUNE	\N	\N	\N	Fête Nationale à l'Ambassade	Fête Nationale à l'Ambassade	2017-10-26 12:30:00	2017-10-26 14:30:00	\N	\N	2	0	579	\N
220500	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	821	\N	\N	Explications de vote sur l'ensemble du PLFSS 2018	Explications de vote sur l'ensemble du PLFSS 2018	2017-11-21 15:10:00	2017-11-21 16:50:00	\N	\N	320	0	\N	\N
220501	SEANCE_PLENIERE	SCRUSOL	821	\N	\N	Scrutin solennel sur le PLFSS 2018	Scrutin solennel sur le PLFSS 2018	2017-11-21 16:00:00	2017-11-21 16:30:00	\N	\N	0	0	\N	\N
226343	GIA	AUCUNE	\N	\N	\N	Rencontre avec des figures montantes du militantisme non violent	Rencontre à l'initiative d'Amnesty International avec MM. Farid AL ATRASH et ISSA AMRO	2017-12-04 10:00:00	2017-12-04 11:00:00	\N	\N	2	0	632	\N
226349	DELEGATION	AUCUNE	\N	\N	COLTER	Audition de M. LAIGNEL, premier vice-président de l'AMF	\N	2017-12-07 10:00:00	2017-12-07 11:10:00	2017-12-07 11:47:14	2017-12-07 12:12:05	9	0	\N	\N
226785	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2017-12-05 14:30:00	2017-12-05 17:30:00	\N	\N	3	0	\N	\N
227939	GIA	AUCUNE	\N	\N	\N	Entretien avec Pirre-Marc JOHNSON, Ancioen premier ministre du Québec	SUjet : AECG entre l'Union européenne et le Canada	2017-12-06 15:30:00	2017-12-06 16:30:00	\N	\N	5	0	602	\N
227945	GIA	AUCUNE	\N	\N	\N	Entretien avec une délégation de la Commission Culture de l'Assemblée nationale du Vietnam	Salut en Séance et entretien avec le Président Phan Thanh Binh de la Commission et 5 autres députés de la commission	2017-12-06 17:45:00	2017-12-06 21:45:00	\N	\N	5	0	626	\N
228307	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFR pour 2017 (2) - DLF	PLFR pour 2017 (2) - Audition de la Direction de la législation fiscale	2017-12-07 08:45:00	2017-12-07 09:55:00	\N	\N	2	0	\N	\N
230978	GIA	AUCUNE	\N	\N	\N	AG France-Slovénie	\N	2017-12-19 13:45:00	2017-12-19 14:00:00	\N	\N	8	0	529	\N
231107	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition cyle de vie des entreprises	Audition cycle de vie des entreprises - Expert comptable	2017-12-19 09:30:00	2017-12-19 10:55:00	\N	\N	1	0	\N	\N
238662	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	MCS Sécurité intérieure et lutte contre le terrorisme	Mission de contrôle et de suivi de la loi renforçant la sécurité intérieure et lutte contre le terrorisme	2018-01-24 14:40:00	2018-01-24 15:15:00	\N	\N	7	0	\N	\N
238694	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MCS Sécurité intérieure et lutte contre le terrorisme	Mission de contrôle et de suivi de la loi renforçant la sécurité intérieure et lutte contre le terrorisme	2018-01-24 15:15:00	2018-01-24 16:05:00	\N	\N	6	0	\N	\N
241240	COM_ENQUETE	PLENIERE	\N	FORCES	\N	\N	\N	2018-02-06 14:45:00	2018-02-06 16:20:00	2018-02-06 18:53:34	2018-02-07 14:41:17	12	0	\N	\N
244044	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Russie	\N	2018-02-05 16:30:00	2018-02-05 17:15:00	\N	\N	1	0	\N	\N
244046	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Russie	\N	2018-02-06 15:00:00	2018-02-06 16:15:00	\N	\N	2	0	\N	\N
244049	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Russie	\N	2018-02-08 15:00:00	2018-02-08 16:20:00	\N	\N	3	0	\N	\N
244053	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	\N	\N	2018-02-06 10:00:00	2018-02-06 11:00:00	\N	\N	5	0	\N	\N
244060	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Réunion du bureau	\N	2018-02-07 08:30:00	2018-02-07 09:30:00	\N	\N	6	0	\N	\N
244067	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Accords Lancaster House	\N	2018-02-07 12:30:00	2018-02-07 17:00:00	\N	\N	4	0	\N	\N
244349	GIA	AUCUNE	\N	\N	\N	Déjeuner de M. CAZEAU avec M. DOLAMARI, Représenant du parti kurde PDK en France	Déjeuner de M. CAZEAU avec M. DOLAMARI, Représenant du parti kurde PDK en France	2018-01-16 13:00:00	2018-01-16 14:00:00	\N	\N	1	0	615	\N
250310	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle Navigation Aérienne 2018 - Déplacement Bruxelles et Maastricht	Contrôle Navigation Aérienne 2018 - Déplacement Bruxelles et Maastricht	2018-02-28 15:50:00	2018-03-02 12:35:00	\N	\N	1	0	\N	\N
250497	DELEGATION	DEPLACEMENT	\N	\N	206	Visite de l'Institut Pasteur	Visite de l'Institut Pasteur	2018-03-08 09:00:00	2018-03-08 12:45:00	\N	\N	6	0	\N	\N
250604	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion	Réunion	2018-03-07 09:40:00	2018-03-07 12:45:00	2018-03-07 14:24:58	2018-03-07 14:37:06	68	0	\N	\N
252509	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL STCW-F	\N	2018-03-06 14:30:00	2018-03-06 15:15:00	\N	\N	1	0	\N	\N
252847	DELEGATION	AUDRAP	\N	\N	206	Audition de Santé Publique France 	Audition de Santé Publique France (SPF)	2018-03-07 16:15:00	2018-03-07 17:30:00	\N	\N	2	0	\N	\N
252848	DELEGATION	AUDRAP	\N	\N	206	Audition de la Société des experts chimistes de France	Audition de la Société des experts chimistes de France (SECF)	2018-03-08 14:00:00	2018-03-08 15:00:00	\N	\N	3	0	\N	\N
252849	DELEGATION	AUDRAP	\N	\N	206	Audition de la Société ITK	Audition de M. Philippe STOOP, directeur Recherche et innovation de la Société ITK	2018-03-08 16:30:00	2018-03-08 17:30:00	\N	\N	3	0	\N	\N
253034	GIA	AUCUNE	\N	\N	\N	Entretien délégation kurde	Entretien avec une délégation du Kurdistan d'Irak	2018-03-08 14:00:00	2018-03-08 15:00:00	\N	\N	1	0	615	\N
253274	GIA	AUCUNE	\N	\N	\N	Déjeuner Ali Dolamari	Déjeuner avec Ali Dolamari, représentant du PDK/KRG en France	2018-01-16 13:00:00	2018-01-16 14:00:00	\N	\N	1	0	615	\N
253276	GIA	AUCUNE	\N	\N	\N	Entretien ambassadeur d'Irak	Entretien avec l'ambassadeur d'Irak Ismail Shafiq Muhsin	2018-02-22 10:30:00	2018-02-22 12:00:00	\N	\N	1	0	615	\N
255917	DELEGATION	AUCUNE	\N	\N	PROS	Audition de Gilles de Margerie (France stratégie)	Audition de Gilles de Margerie (France stratégie)	2018-04-05 08:30:00	2018-04-05 09:45:00	2018-04-05 10:58:11	2018-04-05 11:11:01	20	0	\N	\N
261437	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle CAS Immo - Direction de l'immobilier de l'Etat	Contrôle CAS Immo - Direction de l'immobilier de l'Etat	2018-03-28 15:00:00	2018-03-28 16:30:00	\N	\N	2	0	\N	\N
263900	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Libye	\N	2018-04-03 18:00:00	2018-04-03 19:15:00	\N	\N	2	0	\N	\N
263903	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	LPM 2019-2025	\N	2018-04-04 08:00:00	2018-04-04 09:25:00	\N	\N	1	0	\N	\N
263911	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	LPM 2019-2025	\N	2018-04-05 14:00:00	2018-04-05 15:15:00	\N	\N	4	0	\N	\N
263917	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Service national universel	\N	2018-04-03 15:30:00	2018-04-03 16:30:00	\N	\N	2	0	\N	\N
263920	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Service national universel	\N	2018-04-03 16:30:00	2018-04-03 17:30:00	\N	\N	2	0	\N	\N
263923	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Service national universel	\N	2018-04-04 16:00:00	2018-04-04 17:00:00	\N	\N	2	0	\N	\N
263927	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	LPM 2019-2025	\N	2018-04-04 16:00:00	2018-04-04 17:00:00	\N	\N	2	0	\N	\N
271234	MISSION	AUCUNE	\N	MINEURSENF	\N	\N	\N	2018-05-16 14:50:00	2018-05-16 16:20:00	2018-05-16 16:27:16	2018-05-16 18:01:39	12	0	\N	\N
273609	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL "Agriculture"	PJL "Agriculture"	2018-04-20 14:00:00	2018-04-20 17:00:00	\N	\N	1	0	\N	\N
273615	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL "Centres-villes - Centres-bourgs"	PPL "Centres-villes - Centres-bourgs"	2018-05-15 09:30:00	2018-05-15 10:30:00	\N	\N	1	0	\N	\N
273617	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL "Centres-villes - Centres-bourgs"	PPL "Centres-villes - Centres-bourgs"	2018-05-15 14:30:00	2018-05-15 19:00:00	\N	\N	1	0	\N	\N
273620	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL "Centres-villes - Centres-bourgs"	\N	2018-05-16 16:30:00	2018-05-16 19:00:00	\N	\N	1	0	\N	\N
273622	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL "Centres-villes - Centres-bourgs"	PPL "Centres-villes - Centres-bourgs"	2018-05-17 10:45:00	2018-05-17 12:30:00	\N	\N	1	0	\N	\N
275176	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL ELAN	\N	2018-05-23 17:00:00	2018-05-23 17:45:00	\N	\N	1	0	\N	\N
275183	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL ELAN	\N	2018-05-23 17:45:00	2018-05-23 18:30:00	\N	\N	1	0	\N	\N
275210	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	Partenariat oriental	Auditions de représentants du ministère de l'Europe et des affaires étrangères	2018-05-23 14:30:00	2018-05-23 15:45:00	\N	\N	1	0	\N	\N
275833	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition CNDA	\N	2018-05-22 16:00:00	2018-05-22 17:00:00	\N	\N	7	0	\N	\N
275843	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2018-05-30 12:05:00	2018-05-30 12:20:00	2018-05-30 17:14:19	2018-05-30 17:19:39	39	0	\N	\N
275844	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions déplacement Lyon	\N	2018-05-25 13:30:00	2018-05-25 17:30:00	\N	\N	2	0	\N	\N
275845	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Recherche - TGIR - Cour des comptes	Contrôle 2018 - Recherche - TGIR - Cour des comptes	2018-05-22 13:30:00	2018-05-22 14:30:00	\N	\N	1	0	\N	\N
298817	DELEGATION	AUDRAP	\N	\N	PROS	Audition rapporteurs	Audition mission noubelles mobilités	2018-07-26 09:30:00	2018-07-26 11:00:00	\N	\N	2	0	\N	\N
298973	COM_PERMANENTE	AUTRE	\N	CAE	\N	Examen des motions et amendements de séance	\N	2018-07-17 09:05:00	2018-07-17 10:20:00	2018-07-17 17:45:58	2018-07-18 09:31:54	29	1	\N	\N
305367	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Christian Thimonier, ambassadeur de France en Macédoine	Entretien avec M. Christian Thimonier, ambassadeur de France en Macédoine	2018-08-27 16:30:00	2018-08-27 17:45:00	\N	\N	4	0	674	\N
305571	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition CAP 2022 et 58-2 moyens police et gendarmerie	Audition CAP 2022 et 58-2 moyens police et gendarmerie	2018-09-19 09:05:00	2018-09-19 12:35:00	2018-09-19 15:08:30	2018-09-19 17:31:56	29	0	\N	\N
305572	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Examen du rapport et du texte PPL Comités de protection des personnes	\N	2018-09-25 14:00:00	2018-09-25 14:50:00	2018-09-25 15:11:52	2018-09-25 18:03:03	41	1	\N	\N
309172	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Réunion franco-allemande	\N	2018-10-04 09:30:00	2018-10-04 14:00:00	\N	\N	8	0	\N	\N
319508	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2019 - Mission Santé	\N	2018-11-08 10:30:00	2018-11-08 12:00:00	\N	\N	2	0	\N	\N
319513	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2019 - Mission Santé	\N	2018-11-15 09:45:00	2018-11-15 11:15:00	\N	\N	1	0	\N	\N
327622	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2019 - Programmes 105 et 185	\N	2018-11-20 16:30:00	2018-11-20 17:15:00	\N	\N	2	0	\N	\N
331001	COM_EURO	AUTRE_NON_PLENIERE	\N	AFEU	\N	Entretien du Bureau avec Judit Varga, Secrétaire d'État aux affaires européennes, Hongrie	Entretien du Bureau avec Mme Judit Varga, Secrétaire d'État aux affaires européennes - Office du Premier ministre de Hon	2018-11-28 15:35:00	2018-11-28 17:00:00	\N	\N	5	0	\N	\N
343680	DELEGATION	AUCUNE	\N	\N	211	Examen du rapport d'information sur les mariages forcés et les grossesses précoces	Examen du rapport d'information sur les mariages forcés et les grossesses précoces	2019-01-22 18:00:00	2019-01-22 18:50:00	2019-01-22 19:24:06	2019-01-23 08:56:18	11	0	\N	\N
345208	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL accord UE-Afghanistan	\N	2019-01-24 14:30:00	2019-01-24 15:40:00	\N	\N	1	0	\N	\N
345210	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI mission innovation et défense	\N	2019-01-22 14:00:00	2019-01-22 15:00:00	\N	\N	2	0	\N	\N
345213	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI mission innovation et défense	\N	2019-01-23 14:00:00	2019-01-23 15:00:00	\N	\N	2	0	\N	\N
345216	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI mission innovation et défense	\N	2019-01-23 15:15:00	2019-01-23 16:20:00	\N	\N	1	0	\N	\N
346826	COM_SPECIALE	PLENIERE	\N	ENTREPRISES	\N	Réunion 20190131	\N	2019-01-31 09:05:00	2019-01-31 10:30:00	2019-01-31 10:38:13	2019-01-31 18:32:20	11	0	\N	\N
346842	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-01-31 10:05:00	2019-01-31 11:35:00	2019-01-31 11:55:45	2019-01-31 18:30:01	14	0	\N	\N
347119	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition réforme recouvrement fiscal et social et Audition APE	Audition réforme recouvrement fiscal et social et Audition APE	2019-02-06 09:35:00	2019-02-06 12:35:00	2019-02-06 14:47:38	2019-02-06 17:44:16	34	0	\N	\N
347501	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Démarchage téléphonique et lutte contre les appels frauduleux - DGCCRF & DGE	PPL Démarchage téléphonique et lutte contre les appels frauduleux	2019-01-31 10:00:00	2019-01-31 10:45:00	\N	\N	1	0	\N	\N
347502	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Démarchage téléphonique & lutte contre les appels frauduleux - Ministère de la justice	PPL Démarchage téléphonique et lutte contre les appels frauduleux	2019-01-31 10:45:00	2019-01-31 11:30:00	\N	\N	1	0	\N	\N
347507	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Démarchage téléphonique et lutte contre les appels frauduleux - FFTelecoms	PPL Démarchage téléphonique et lutte contre les appels frauduleux	2019-01-31 14:00:00	2019-01-31 15:00:00	\N	\N	1	0	\N	\N
347935	MISSION	AUCUNE	\N	CLIMATIQUE	\N	Auditions de M. Robert VAUTARD, directeur de recherche CNRS, et de la CCR 	\N	2019-02-06 14:01:00	2019-02-06 16:06:00	2019-02-06 16:30:06	2019-02-06 17:40:10	16	0	\N	\N
348008	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Situation de l'Office national des forêts	Situation de l'Office national des forêts - Audition du président de l'ONF	2019-01-30 14:00:00	2019-01-30 15:30:00	\N	\N	9	0	\N	\N
348009	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Situation de l'Office national des forêts	Situation de l'Office national des forêts - Audition de représentants de France Nature Environnement	2019-01-31 11:00:00	2019-01-31 12:30:00	\N	\N	1	0	\N	\N
348020	DELEGATION	AUDRAP	\N	\N	PROS	Audition de l'ANEL	\N	2019-03-12 15:30:00	2019-03-12 16:30:00	\N	\N	1	0	\N	\N
348021	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Faciliter le désenclavement des territoires	PPL Faciliter le désenclavement des territoires - Audition de représentants de la DGAC	2019-01-28 16:15:00	2019-01-28 17:00:00	\N	\N	1	0	\N	\N
279087	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL ELAN	PJL ELAN	2018-05-29 17:45:00	2018-05-29 18:45:00	\N	\N	2	0	\N	\N
275842	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2018-05-30 09:35:00	2018-05-30 12:05:00	2018-05-30 17:14:38	2018-05-30 17:19:38	49	0	\N	\N
348022	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Faciliter le désenclavement des territoires	PPL Faciliter le désenclavement des territoires - Audition d'un représentant de l'AFITF	2019-01-29 18:00:00	2019-01-29 18:45:00	\N	\N	1	0	\N	\N
348024	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Faciliter le désenclavement des territoires	PPL Faciliter le désenclavement des territoires - Audition de représentants de la DGCL	2019-01-30 14:00:00	2019-01-30 14:45:00	\N	\N	1	0	\N	\N
348025	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	\N	\N	2019-01-25 09:00:00	2019-01-25 18:00:00	\N	\N	1	0	\N	\N
348027	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Faciliter le désenclavement des territoires	PPL Faciliter le désenclavement des territoires - Audition d'un représentant du CGET	2019-01-31 16:00:00	2019-01-31 16:45:00	\N	\N	1	0	\N	\N
348034	MISSION	AUCUNE	\N	INFRACTIONS	\N	Audition plénière	\N	2019-02-06 16:30:00	2019-02-06 18:45:00	2019-02-06 18:44:55	2019-02-07 17:24:05	13	0	\N	\N
348035	MISSION	AUCUNE	\N	INFRACTIONS	\N	Auditions plénières	\N	2019-02-07 11:00:00	2019-02-07 13:15:00	2019-02-07 14:28:26	2019-02-07 17:24:05	13	0	\N	\N
348036	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Auditions rapporteur PPL Prise en charge des cancers pédiatriques	\N	2019-02-06 14:30:00	2019-02-06 18:30:00	\N	\N	2	0	\N	\N
348038	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Auditions représentants associations PPL Prise en charge des cancers pédiatriques	\N	2019-02-05 17:30:00	2019-02-05 19:00:00	\N	\N	1	0	\N	\N
348040	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	Auditions rapporteurs	\N	2019-02-05 13:30:00	2019-02-05 16:30:00	\N	\N	0	0	\N	\N
348041	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	Auditions rapporteurs	\N	2019-02-06 15:00:00	2019-02-06 19:00:00	\N	\N	0	0	\N	\N
363172	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	\N	\N	2019-03-21 09:30:00	2019-03-21 11:00:00	\N	\N	1	0	\N	\N
364581	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Création de l'Office français de la biodiversité	PJL Création de l'Office français de la biodiversité	2019-03-21 17:00:00	2019-03-21 18:00:00	\N	\N	2	0	\N	\N
364697	COM_PERMANENTE	DEPLACEMENT	\N	SOCI	\N	Déplacement rapporteurs	\N	2019-04-09 15:30:00	2019-04-09 17:00:00	\N	\N	2	0	\N	\N
364916	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	audition rapporteurs	\N	2019-03-21 10:30:00	2019-03-21 11:30:00	\N	\N	0	0	\N	\N
367103	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Contrats de ruralité - CGET / ANPP	Contrôle 2019 - Contrats de ruralité - CGET / ANPP	2019-03-27 15:00:00	2019-03-27 17:30:00	\N	\N	1	0	\N	\N
367109	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Stade de France - FFF / Cour des comptes / Consortium Stade de France	Contrôle 2019 - Stade de France - FFF / Cour des comptes / Consortium Stade de France	2019-03-27 16:30:00	2019-03-27 19:30:00	\N	\N	1	0	\N	\N
367206	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	RI Colombie	\N	2019-03-27 13:00:00	2019-03-27 14:30:00	\N	\N	3	0	\N	\N
367258	DELEGATION	AUCUNE	\N	\N	DSOM	Audition de Mme Catherine Troendlé sur la politique de communication du Sénat	\N	2019-04-04 16:20:00	2019-04-04 17:00:00	2019-04-04 17:22:24	\N	3	0	\N	\N
367265	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audiovisuel extérieur	\N	2019-03-27 11:00:00	2019-03-27 12:05:00	\N	\N	2	0	\N	\N
367273	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition thanatopraxie	MI thanatopraxie	2019-03-28 10:00:00	2019-03-28 11:30:00	\N	\N	1	0	\N	\N
367293	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2019 - Gestion RH ministère des armées - Déplacement CEMA Paris	Contrôle 2019 - Gestion RH ministère des armées - Déplacement CEMA Paris	2019-03-29 17:10:00	2019-03-29 18:30:00	\N	\N	1	0	\N	\N
217449	DELEGATION	AUCUNE	\N	\N	206	Audition APB (Admission Post-Bac)	Audition sur "Les algorithmes au service de l'action publique : le cas du portail Admission Post-Bac (APB)"	2017-11-16 09:30:00	2017-11-16 13:25:00	2017-11-16 16:33:27	2017-11-16 17:24:54	10	0	\N	\N
217469	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de M. Bruno Lemaire, ministre de l'économie et des finances	Audition de M. Bruno Lemaire, ministre de l'économie et des finances	2017-11-14 17:55:00	2017-11-14 19:35:00	2017-11-15 15:50:58	2017-11-15 16:15:26	42	0	\N	\N
220313	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PLF 2018 - 3 avis budgétaires	\N	2017-11-21 09:05:00	2017-11-21 10:45:00	2017-11-21 14:46:24	2017-11-21 16:38:24	29	0	\N	\N
223255	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2018 - programme 212	\N	2017-11-21 17:30:00	2017-11-21 19:00:00	\N	\N	1	0	\N	\N
230086	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2017-12-13 15:00:00	2017-12-13 15:00:00	\N	\N	3	0	\N	\N
230104	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2017-12-13 16:00:00	2017-12-13 17:30:00	\N	\N	4	0	\N	\N
239086	GIA	AUCUNE	\N	\N	\N	AG GIA France-Hongrie	Assemblée générale du groupe d'amitié France-Hongrie	2018-01-30 13:30:00	2018-01-30 13:50:00	\N	\N	3	0	592	\N
241118	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Ministère des Armées	\N	2018-01-24 08:00:00	2018-01-24 09:15:00	\N	\N	4	0	\N	\N
241123	DELEGATION	AUDRAP	\N	\N	206	Audition du Professeur Didier Houssin, président de AP-HP International	Audition du Professeur Didier Houssin, président de AP-HP International - Evaluation de la loi de bioéthique de 2011	2018-02-07 16:00:00	2018-02-07 17:00:00	\N	\N	3	0	\N	\N
241124	DELEGATION	AUDRAP	\N	\N	206	Audition du Docteur Hervé Chneiweiss, président du comité d'éthique de l'INSERM	Audition du Docteur Hervé Chneiweiss, président du comité d'éthique de l'INSERM - Evaluation loi bioéthique de 2011	2018-02-07 17:00:00	2018-02-07 18:00:00	\N	\N	3	0	\N	\N
241125	DELEGATION	AUDRAP	\N	\N	206	Audition de la direction générale de la santé	Audition de la division des droits des usagers et affaires juridiques et éthiques de la direction générale de la santé	2018-02-14 16:00:00	2018-02-14 18:00:00	\N	\N	2	0	\N	\N
246735	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Conférence interparlementaire Art 13 TSCG	Conférence interparlementaire Art 13 TSCG à Bruxelles	2018-02-19 12:20:00	2018-02-20 19:35:00	\N	\N	2	0	\N	\N
249885	GIA	AUCUNE	\N	\N	\N	Petit-déjeuner du 21 février 2018	Audition de Mme Agnès BLASSELLE, adjointe à la sous-directrice d'Afrique australe et de l'océan Indien (MEAE)	2018-02-21 08:20:00	2018-02-21 09:30:00	\N	\N	6	0	574	\N
261247	ETUDES	AUCUNE	\N	\N	\N	G.E. "Agriculture et alimentation"	G.E. "Agriculture et alimentation"	2018-03-27 18:00:00	2018-03-27 19:00:00	\N	\N	16	0	\N	919
261271	ETUDES	AUCUNE	\N	\N	\N	G.E. "Développement économique de la montagne"	G.E. "Développement économique de la montagne"	2018-03-28 13:45:00	2018-03-28 17:15:00	\N	\N	4	0	\N	918
262277	GIA	AUCUNE	\N	\N	\N	Audition Irrmann (MAE) 	Audition Jules Irrmann (MAE) chef de la Mission d'Océanie	2018-04-04 08:30:00	2018-04-04 09:30:00	\N	\N	5	0	651	\N
264117	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Métier d'enseignant	Métier d'enseignant	2018-04-04 15:00:00	2018-04-04 17:15:00	\N	\N	2	0	\N	\N
278347	COM_EURO	AUDRAP	\N	AFEU	\N	Règlement "Cosmétiques"	Audition de M. O'QUIN, président de la fédération des entreprises de la beauté	2018-05-30 14:30:00	2018-05-30 15:40:00	\N	\N	1	0	\N	\N
278351	GIA	AUCUNE	\N	\N	\N	Entretien de M. LEFEVRE et des membres avec une délégation de staffers (coopé)	Entretien de M. LEFEVRE et des membres avec une délégation de staffers (coopé)	2018-05-29 13:00:00	2018-05-29 14:15:00	\N	\N	4	0	590	\N
279094	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLO PPL Fausses informations PPL PPL AN RECUE DE SOLON	PPLO PPL Fausses informations	2018-05-30 17:30:00	2018-05-30 18:45:00	\N	\N	1	0	\N	\N
279105	GIA	AUCUNE	\N	\N	\N	déjeuner avec Joachim Son-Forget, président du groupe d'amitié France-Corée à l'Assemblée 	déjeuner avec Joachim Son-Forget, député, président du groupe d'amitié France-Corée à l'Assemblée nationale	2018-05-23 12:30:00	2018-05-23 14:30:00	\N	\N	1	0	613	\N
279119	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Richard BOIDIN, Ambassadeur de France au Zimbabwe	Entretien avec M. Richard BOIDIN, Ambassadeur de France au Zimbabwe	2018-05-30 18:45:00	2018-05-30 19:45:00	\N	\N	5	0	646	\N
279146	GIA	AUCUNE	\N	\N	\N	Réception à l'ambassade à l'occasion de la visite de M. Steven CIOBO	Réception à l'ambassade à l'occasion de la visite de M. Steven CIOBOministre australien du commerce, du tourisme et de l	2018-05-29 19:30:00	2018-05-29 21:30:00	\N	\N	4	0	578	\N
279154	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	GT Financement du handicap	GT Financement du handicap	2018-06-13 17:30:00	2018-06-13 18:30:00	\N	\N	1	0	\N	\N
279242	COM_ENQUETE	PLENIERE	\N	FORCES	\N	Audition CE FSI	Audition CE FSI	2018-05-31 14:05:00	2018-05-31 16:50:00	2018-06-01 16:20:50	2018-06-01 16:30:24	6	0	\N	\N
279499	COM_ENQUETE	AUTRE	\N	CHUTE	\N	Audition plénière	\N	2018-06-12 18:00:00	2018-06-12 19:15:00	2018-06-14 10:22:43	2018-06-14 10:53:56	13	0	\N	\N
279504	COM_PERMANENTE	AUDRAP	\N	CDD	\N	\N	\N	2014-06-05 17:00:00	2014-06-06 18:00:00	\N	\N	0	0	\N	\N
279505	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions ELAN (Avis ATDD - M. Patrick Chaize)	\N	2014-06-05 15:15:00	2014-06-06 18:00:00	\N	\N	0	0	\N	\N
280165	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Lutte contre la fraude - DLF	PJL Lutte contre la fraude - DLF	2018-06-04 16:30:00	2018-06-04 17:30:00	\N	\N	1	0	\N	\N
280174	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2018-06-05 16:10:00	2018-06-05 17:50:00	\N	\N	3	0	\N	\N
280500	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Mission Mécénat	Mission Mécénat	2018-06-06 14:45:00	2018-06-06 15:45:00	\N	\N	3	0	\N	\N
281715	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Aides à la pierre - DHUP	Contrôle 2018 - Aides à la pierre - DHUP	2018-06-05 17:00:00	2018-06-05 18:00:00	\N	\N	1	0	\N	\N
281716	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Aides à la pierre - Direction du budget	Contrôle 2018 - Aides à la pierre  - Direction du budget	2018-06-06 14:00:00	2018-06-06 14:30:00	\N	\N	1	0	\N	\N
281719	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLO PPL Fausses informations PPL PPL AN RECUE DE SOLON	PPLO PPL Fausses informations	2018-06-06 14:30:00	2018-06-06 17:15:00	\N	\N	1	0	\N	\N
282404	COM_EURO	AUDRAP	\N	AFEU	\N	\N	\N	2018-05-31 17:00:00	2018-05-31 18:15:00	\N	\N	1	0	\N	\N
282406	COM_EURO	AUDRAP	\N	AFEU	\N	\N	\N	2018-06-06 15:05:00	2018-06-06 17:30:00	\N	\N	1	0	\N	\N
282408	COM_EURO	AUDRAP	\N	AFEU	\N	\N	\N	2018-06-07 11:00:00	2018-06-07 12:30:00	\N	\N	2	0	\N	\N
282508	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion 20180612	\N	2018-06-12 09:05:00	2018-06-12 10:15:00	2018-06-12 15:01:39	2018-06-12 15:37:23	23	1	\N	\N
284080	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion	Réunion	2018-06-13 10:00:00	2018-06-13 12:25:00	2018-06-13 12:46:59	2018-06-13 14:24:30	36	0	\N	\N
284424	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL pour la liberté de choisir son avenir professionnel	PJL pour la liberté de choisir son avenir professionnel	2018-06-07 10:30:00	2018-06-07 12:30:00	\N	\N	5	0	\N	\N
284585	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle Affaires Européennes - Déplacement Bruxelles	Contrôle Affaires Européennes - Déplacement Bruxelles	2018-06-19 07:55:00	2018-06-19 20:35:00	\N	\N	1	0	\N	\N
284595	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2018 - Performance établissements ens. sup - Dublin	Contrôle 2018 - Performance établissements ens. sup - Dublin	2018-06-19 10:20:00	2018-06-20 21:20:00	\N	\N	1	0	\N	\N
307239	ETUDES	AUCUNE	\N	\N	\N	réunion groupe cheval	impact privatisation de la Française des Jeux	2018-10-02 09:00:00	2018-10-02 11:00:00	\N	\N	5	0	\N	912
309067	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2019 - Programme 105	\N	2018-10-02 08:30:00	2018-10-02 09:30:00	\N	\N	1	0	\N	\N
350901	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL PJLO Justice juridictions	PJL  PJLO Justice juridictions	2019-02-12 09:10:00	2019-02-12 09:35:00	2019-02-12 10:08:57	2019-02-13 16:52:11	19	1	\N	\N
357450	MISSION	AUCUNE	\N	BREXIT2	\N	Impact du Brexit sur le secteur du médicament	Impact du Brexit sur le secteur du médicament	2019-03-06 15:05:00	2019-03-06 16:00:00	2019-03-08 11:24:41	2019-03-08 11:25:46	7	0	\N	\N
364280	GIA	AUCUNE	\N	\N	\N	Rencontre entre M. Cazeau et le nouvel ambassadeur d'Irak	Déjeuner entre M. Cazeau et le nouvel ambassadeur d'Irak, Abderrahman al-Husseini, au restaurant La Méditerranée	2019-03-26 13:00:00	2019-03-26 14:30:00	\N	\N	1	0	615	\N
364472	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Turquie	\N	2019-03-21 10:45:00	2019-03-21 12:00:00	\N	\N	2	0	\N	\N
366559	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Création de l'Office français de la biodiversité	PJL Création de l'Office français de la biodiversité	2019-03-26 17:30:00	2019-03-26 18:15:00	\N	\N	2	0	\N	\N
366622	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition syndicats	\N	2019-03-27 14:45:00	2019-03-27 19:00:00	2019-03-27 19:06:05	2019-03-28 10:23:39	16	0	\N	\N
367754	MISSION	AUCUNE	\N	TRANSPORTS	\N	Réunion constitutive	\N	2019-04-02 16:35:00	2019-04-02 17:05:00	2019-04-02 17:38:29	2019-04-02 18:00:36	15	1	\N	\N
369500	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Reconnaissance du crime d'écocide	\N	2019-04-03 18:10:00	2019-04-03 18:45:00	\N	\N	2	0	\N	\N
371474	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL École de la confiance	PJL École de la confiance	2019-05-14 14:40:00	2019-05-14 19:30:00	\N	\N	224	0	\N	\N
371475	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL École de la confiance	PJL École de la confiance	2019-05-14 21:30:00	2019-05-15 00:30:00	\N	\N	116	0	\N	\N
371476	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL École de la confiance	PJL École de la confiance	2019-05-15 14:30:00	2019-05-15 20:00:00	\N	\N	195	0	\N	\N
280395	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPRE Déontologie + PPL Equilibre territorial + PJL Immigation + Echange de vues	\N	2018-06-06 08:40:00	2018-06-06 13:00:00	2018-06-07 12:53:04	2018-06-07 18:47:02	45	0	\N	\N
284102	COM_PERMANENTE	AUTRE	\N	LOIS	\N	réunion commission des lois 13 juin 2018	réunion commission des lois 13 juin 2018	2018-06-13 09:40:00	2018-06-13 11:09:00	2018-06-13 17:05:17	2018-06-13 17:23:49	41	0	\N	\N
351798	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion du 20190213	\N	2019-02-13 10:00:00	2019-02-13 12:05:00	2019-02-13 12:20:33	2019-02-13 16:52:06	43	0	\N	\N
371477	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL École de la confiance	PJL École de la confiance	2019-05-15 21:35:00	2019-05-16 00:40:00	\N	\N	100	0	\N	\N
371478	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Représentants au Parlement européen élus en France	PJL Représentants au Parlement européen élus en France	2019-05-16 10:30:00	2019-05-16 12:40:00	\N	\N	85	0	\N	\N
371479	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2019-05-16 15:00:00	2019-05-16 16:00:00	\N	\N	287	0	\N	\N
371484	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL École de la confiance	PJL École de la confiance	2019-05-16 16:20:00	2019-05-16 20:10:00	\N	\N	106	0	\N	\N
371485	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL École de la confiance	PJL École de la confiance	2019-05-16 21:40:00	2019-05-17 00:30:00	\N	\N	48	0	\N	\N
371528	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2019-05-21 16:45:00	2019-05-21 17:40:00	\N	\N	307	0	\N	\N
371530	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Taxe services numériques	PJL Taxe services numériques	2019-05-21 17:45:00	2019-05-21 20:30:00	\N	\N	87	0	\N	\N
371531	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Taxe services numériques	PJL Taxe services numériques	2019-05-21 21:45:00	2019-05-22 01:05:00	\N	\N	67	0	\N	\N
371532	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Conclusions CMP PJLO/PJL Polynésie	Conclusions CMP PJLO/PJL Polynésie	2019-05-22 14:30:00	2019-05-22 18:15:00	\N	\N	55	0	\N	\N
371535	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Modernisation de la presse	PJL Modernisation de la presse	2019-05-22 18:25:00	2019-05-22 20:00:00	\N	\N	103	0	\N	\N
371540	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Avenir du cinéma français	Débat Avenir du cinéma français	2019-05-28 14:35:00	2019-05-28 16:20:00	\N	\N	65	0	\N	\N
371541	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2019-05-28 16:45:00	2019-05-28 17:40:00	\N	\N	287	0	\N	\N
371542	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Avenir enseignement professionnel	Débat Avenir enseignement professionnel	2019-05-28 17:50:00	2019-05-28 19:30:00	\N	\N	82	0	\N	\N
371543	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Fraude TVA frontalière	Débat Fraude TVA frontalière	2019-05-29 14:35:00	2019-05-29 16:10:00	\N	\N	49	0	\N	\N
371820	COM_PERMANENTE	AUTRE	\N	SOCI	\N	réunion de commission	\N	2019-04-30 13:40:00	2019-04-30 14:20:00	2019-04-30 14:22:46	2019-04-30 17:33:06	31	0	\N	\N
372190	ETUDES	AUCUNE	\N	\N	\N	GE numérique	\N	2019-04-09 16:00:00	2019-04-09 16:40:00	\N	\N	12	0	\N	1008
372216	ETUDES	AUCUNE	\N	\N	\N	GE numérique	\N	2019-04-09 16:40:00	2019-04-09 17:10:00	\N	\N	10	0	\N	1008
372657	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Lutte contre les espèces toxiques envahissantes	\N	2019-04-10 14:20:00	2019-04-10 16:00:00	\N	\N	1	0	\N	\N
372660	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition suivi de l'application de la loi ELAN	Audition suivi de l'application de la loi ELAN	2019-04-11 08:30:00	2019-04-11 09:05:00	\N	\N	1	0	\N	\N
372756	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2019-04-09 19:40:00	2019-04-09 20:05:00	\N	\N	23	0	\N	\N
372808	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 11 avril 2019	Réunion du 11 avril 2019	2019-04-11 09:45:00	2019-04-11 11:15:00	2019-04-11 19:27:27	2019-04-12 17:18:44	9	0	\N	\N
372859	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Modernisation de la distribution de la presse	PJL Modernisation de la distribution de la presse	2019-04-10 14:00:00	2019-04-10 15:00:00	\N	\N	1	0	\N	\N
372861	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Modernisation de la distribution de la presse	PJL Modernisation de la distribution de la presse	2019-04-10 15:00:00	2019-04-10 17:00:00	\N	\N	2	0	\N	\N
372863	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Modernisation de la distribution de la presse	PJL Modernisation de la distribution de la presse	2019-04-10 17:00:00	2019-04-10 18:00:00	\N	\N	1	0	\N	\N
372873	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL École de la confiance	PJL École de la confiance	2019-04-11 10:15:00	2019-04-11 11:40:00	\N	\N	9	0	\N	\N
372898	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Synergies entre les conseils municipaux et communautaires	\N	2019-04-11 10:15:00	2019-04-12 11:00:00	\N	\N	1	0	\N	\N
373174	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL École de la confiance	\N	2019-04-09 18:40:00	2019-04-09 19:40:00	\N	\N	6	0	\N	\N
373462	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Masse salariale du MEAE - Contrôleur budgétaire ECOFIN	Contrôle 2019 - Masse salariale du MEAE - Contrôleur budgétaire ECOFIN	2019-04-08 09:00:00	2019-04-08 10:00:00	\N	\N	1	0	\N	\N
373476	MISSION	AUCUNE	\N	SIDERURGIE	\N	Audition Direction générale du Trésor	\N	2019-04-11 14:00:00	2019-04-11 14:55:00	2019-04-12 09:46:21	2019-04-12 17:19:00	9	0	\N	\N
373497	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Masse salariale du MEAE - Syndicats MEAE	Contrôle 2019 - Masse salariale du MEAE - Syndicats MEAE	2019-04-08 14:30:00	2019-04-08 16:00:00	\N	\N	2	0	\N	\N
373500	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Masse salariale MEAE - IGAE & IGF	Contrôle 2019 - Masse salariale MEAE - IGAE & IGF	2019-04-09 17:30:00	2019-04-09 18:45:00	\N	\N	2	0	\N	\N
373524	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Lutte contre les feux de forêt - Fransylva	Contrôle 2019 - Lutte contre les feux de forêt - Fransylva	2019-04-09 09:00:00	2019-04-09 10:10:00	\N	\N	1	0	\N	\N
373562	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Agriculture biologique - ITAB	Contrôle 2018 - Agriculture biologique - ITAB	2019-04-09 14:30:00	2019-04-09 16:30:00	\N	\N	1	0	\N	\N
373564	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - AGTE - Réflexe carte grise	PLF pour 2020 - AGTE - Réflexe carte grise	2019-04-09 16:30:00	2019-04-09 17:25:00	\N	\N	1	0	\N	\N
217911	GIA	AUCUNE	\N	\N	\N	Entretien délégation du Burkina Faso avec M. Philippe MOUILLER	Entretien de  la délégation du Burkina Faso avec M. Philippe MOUILLER, Président délégué pour le Burkina Faso	2017-11-14 16:00:00	2017-11-14 16:45:00	\N	\N	1	0	573	\N
279153	AUTRE_TEMPORAIRE	AUTRE_NON_PLENIERE	\N	\N	\N	\N	\N	2018-06-13 17:30:00	2018-06-13 18:30:00	\N	\N	0	0	\N	\N
217956	GIA	AUCUNE	\N	\N	\N	Entretien Mme Monika ROSA, députée polonaise et M. Jean-Pierre LELEUX	Entretien Mme Monika ROSA, députée polonaise et M. Jean-Pierre LELEUX	2017-11-15 15:00:00	2017-11-15 16:00:00	\N	\N	0	0	600	\N
233287	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition cycle de vie des entreprises	Audition cycle de vie des entreprises	2018-01-15 10:00:00	2018-01-15 12:00:00	\N	\N	1	0	\N	\N
235474	GIA	AUCUNE	\N	\N	\N	AG du groupe	Assemblée générale du groupe et désignation du Bureau	2018-01-16 18:00:00	2018-01-16 18:30:00	\N	\N	10	0	556	\N
241088	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2018-02-06 18:00:00	2018-02-06 19:50:00	2018-02-07 10:46:52	2018-02-07 14:54:04	22	0	\N	\N
241089	MECSS	AUDRAP	\N	\N	MECSS	\N	\N	2018-02-07 16:00:00	2018-02-07 18:15:00	\N	\N	6	0	\N	\N
243522	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2018-02-14 09:35:00	2018-02-14 11:05:00	2018-02-14 11:46:28	2018-02-14 13:53:50	37	0	\N	\N
245339	ETUDES	AUCUNE	\N	\N	\N	GE Chasse et Pêche	GE Chasse et Pêche	2018-02-14 08:15:00	2018-02-14 09:25:00	\N	\N	33	0	\N	907
245509	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 "Les maisons de l'emploi"	Contrôle 2018 "Les maisons de l'emploi" - Audition de Alliance Villes emploi	2018-02-13 16:20:00	2018-02-13 17:30:00	\N	\N	2	0	\N	\N
250975	GIA	AUCUNE	\N	\N	\N	Audition commune du coprésident du Groupe de Minsk	Entretien avec l'ambassadeur Stéphane Visconti, coprésident du Groupe de Minsk	2018-03-07 08:30:00	2018-03-07 09:45:00	\N	\N	6	0	534	\N
267477	ETUDES	AUCUNE	\N	\N	\N	Audition de M. Patrick Gandil, DGAC	Audition de M. Patrick Gandil, DGAC	2018-04-11 08:15:00	2018-04-11 09:15:00	\N	\N	14	0	\N	933
270212	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	LPM 2019-2025	\N	2018-04-18 17:30:00	2018-04-18 18:30:00	\N	\N	1	0	\N	\N
275848	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Mission Sports, jeunesse et vie associative - PLF pour 2019 - CNOSF	Mission Sports, jeunesse et vie associative - PLF pour 2019 - CNOSF	2018-05-22 15:00:00	2018-05-22 15:45:00	\N	\N	1	0	\N	\N
275850	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Mission Sports, jeunesse et vie associative - PLF pour 2019 - Direction des sports	Mission Sports, jeunesse et vie associative - PLF pour 2019 - Direction des sports	2018-05-23 17:30:00	2018-05-23 18:15:00	\N	\N	1	0	\N	\N
275852	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL Modernisation de la transmission d'entreprise - INSEE	PPL Modernisation de la transmission d'entreprise - INSEE	2018-05-23 09:05:00	2018-05-23 10:40:00	\N	\N	1	0	\N	\N
275854	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Mission AGTE - CNCCFP - Audition DMAT	Contrôle 2018 - Mission AGTE - CNCCFP - Audition DMAT	2018-05-23 15:00:00	2018-05-23 17:00:00	\N	\N	1	0	\N	\N
275858	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Perspective economie mondiale - Délégation FMI	Perspective economie mondiale - Délégation FMI	2018-05-24 08:30:00	2018-05-24 09:45:00	\N	\N	1	0	\N	\N
275860	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 Recours personnels contractuels Éducation Nationale - Cour des comptes	58-2 Recours personnels contractuels Éducation Nationale - Cour des comptes	2018-05-23 12:50:00	2018-05-23 14:05:00	\N	\N	1	0	\N	\N
275862	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL Centres-villes - FNAIM	PPL Centres-villes - FNAIM	2018-05-22 17:15:00	2018-05-22 18:05:00	\N	\N	1	0	\N	\N
275863	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL Centres-villes - Villes de France 	PPL Centres-villes - Villes de France 	2018-05-22 18:30:00	2018-05-22 19:15:00	\N	\N	1	0	\N	\N
275866	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL Centres-Villes - Sénateurs auteurs de la PPL	PPL Centres-Villes - Sénateurs auteurs de la PPL	2018-05-23 18:15:00	2018-05-23 19:15:00	\N	\N	1	0	\N	\N
275913	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL Centres-villes - Cabinet Ministre de l'Économie - DLF	PPL Centres-villes - Cabinet Ministre de l'Économie - DLF	2018-05-25 11:00:00	2018-05-25 12:25:00	\N	\N	1	0	\N	\N
278445	DELEGATION	DEPLACEMENT	\N	\N	ENTREPRISES	Déplacement dans la Creuse	Déplacement de la Délégation sénatoriale aux entreprises dans la Creuse	2018-05-25 00:00:00	2018-05-25 00:00:00	\N	\N	7	0	\N	\N
278758	COM_PERMANENTE	AUTRE	\N	CDD	\N	Examen d'un rapport pour avis	\N	2018-06-05 09:35:00	2018-06-05 10:05:00	2018-06-05 10:26:52	2018-06-05 16:31:11	30	2	\N	\N
278759	COM_PERMANENTE	AUTRE	\N	CDD	\N	Audition plénière	\N	2018-06-06 09:10:00	2018-06-06 11:40:00	2018-06-07 09:54:27	2018-06-07 18:45:29	39	0	\N	\N
278761	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Suivi mise en oeuvre préconisations rapport 570 - Cabinet Ministère	Contrôle 2018 - Suivi de la mise en oeuvre des préconisations du rapport n° 570- CAS immo  - Cabinet Ministère Ens Sup	2018-05-29 14:00:00	2018-05-29 15:00:00	\N	\N	2	0	\N	\N
278827	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition MI responsabilité civile	\N	2018-05-30 17:00:00	2018-05-30 19:00:00	\N	\N	2	0	\N	\N
278833	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n° 460 centres-villes centres-bourgs - Fédération du Commerce et de la Distribution	PPL n° 460 centres-villes centres-bourgs - Fédération du Commerce et de la Distribution	2018-05-30 14:10:00	2018-05-30 15:00:00	\N	\N	1	0	\N	\N
278838	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n° 460 centres-villes centres-bourgs - Union nationale des aménageurs	PPL n° 460 centres-villes centres-bourgs - Union nationale des aménageurs	2018-05-30 17:05:00	2018-05-30 17:55:00	\N	\N	1	0	\N	\N
278840	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n° 460 centres-villes centres-bourgs - Fédération des sociétés immobilières foncières	PPL n° 460 centres-villes centres-bourgs - Fédération des sociétés immobilières foncières	2018-05-30 17:55:00	2018-05-30 18:30:00	\N	\N	1	0	\N	\N
278884	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle flux de transports - Agence de l'environnement et de la maitrise de l'énergie	Contrôle flux de transports - Agence de l'environnement et de la maitrise de l'énergie 	2018-05-23 14:00:00	2018-05-23 15:30:00	\N	\N	1	0	\N	\N
278890	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle flux de transports - DG Trésor	Contrôle flux de transports - DG Trésor	2018-05-23 17:00:00	2018-05-23 18:30:00	\N	\N	1	0	\N	\N
278892	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle flux de transports - Université de LYON	Contrôle flux de transports - Université de LYON - Yves CROZET	2018-05-29 14:00:00	2018-05-29 15:30:00	\N	\N	1	0	\N	\N
278895	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle "Gestion déconcentrée des crédits du ministère de la culture"	Contrôle "Gestion déconcentrée des crédits du ministère de la culture" - DGP et  DRAC Île-de-France	2018-06-01 10:15:00	2018-06-01 12:00:00	\N	\N	1	0	\N	\N
279079	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2018-06-06 11:00:00	2018-06-06 12:25:00	2018-06-06 14:48:19	2018-06-06 16:08:53	35	0	\N	\N
279081	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL ELAN	PJL ELAN	2018-05-29 09:30:00	2018-05-29 10:20:00	\N	\N	2	0	\N	\N
279084	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL ELAN	PJL ELAN	2018-05-29 14:30:00	2018-05-29 15:15:00	\N	\N	1	0	\N	\N
232243	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2017-12-20 09:35:00	2017-12-20 11:10:00	2017-12-20 11:09:06	2017-12-20 16:19:35	37	0	\N	\N
279155	COM_PERMANENTE	AUTRE	\N	CDD	\N	Examen des motions et amendements de séance	\N	2018-05-31 18:10:00	2018-05-31 18:20:00	2018-06-01 11:02:04	2018-06-01 11:03:59	13	0	\N	\N
280758	ETUDES	AUCUNE	\N	\N	\N	GE Chasse et Pêche	GE Chasse et Pêche	2018-06-06 08:00:00	2018-06-06 08:55:00	\N	\N	22	0	\N	907
301899	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur Fiche S	Audition rapporteur Fiche S	2018-07-17 14:30:00	2018-07-17 19:00:00	\N	\N	6	0	\N	\N
302056	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Autre	\N	2018-09-05 13:45:00	2018-09-05 15:00:00	\N	\N	0	0	\N	\N
302221	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Audition plénière	\N	2018-07-11 13:30:00	2018-07-11 14:30:00	\N	\N	0	0	\N	\N
302239	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	\N	\N	2018-07-19 14:00:00	2018-07-19 15:00:00	\N	\N	0	0	\N	\N
302278	DELEGATION	AUDRAP	\N	\N	206	Audition dans le cadre de la mission "perte de biodiversité"	Audition de Florian Kirchner	2018-07-24 09:30:00	2018-07-24 10:45:00	\N	\N	1	0	\N	\N
302441	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Exam amdts séance PPL rodéos + amdts PPL & PPLO manip info + PPL eau et assainissement	Réunion commission Mardi 24 juillet 2018	2018-07-24 09:05:00	2018-07-24 09:25:00	2018-07-24 10:20:23	2018-07-24 17:10:13	21	0	\N	\N
325376	GIA	AUCUNE	\N	\N	\N	Groupe d'amitié France-Moldavie	Conférence-débat organisée par les think-tanks IPSE et IVERIS (Assemblée nationale)	2018-11-12 18:00:00	2018-11-12 20:00:00	\N	\N	1	0	851	\N
325378	GIA	AUCUNE	\N	\N	\N	Groupe d'amitié France-Moldavie	Dîner avec les conseillers du président Dodon (Assemblée nationale)	2018-11-12 20:00:00	2018-11-12 22:15:00	\N	\N	1	0	851	\N
325382	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	1001	\N	\N	Explications de vote sur l'ensemble du PLFSS 2019	Explications de vote sur l'ensemble du PLFSS 2019	2018-11-20 14:30:00	2018-11-20 15:30:00	\N	\N	310	0	\N	\N
325383	SEANCE_PLENIERE	SCRUSOL	1001	\N	\N	Scrutin solennel PLFSS 2019	Scrutin solennel PLFSS 2019	2018-11-20 15:30:00	2018-11-20 16:30:00	\N	\N	0	0	\N	\N
353798	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Réunion AP-OTAN avec la DGRIS	\N	2019-02-13 16:30:00	2019-02-13 17:30:00	\N	\N	6	0	\N	\N
356143	GIA	AUCUNE	\N	\N	\N	rencontre DG Communauté du Pacifique	\N	2019-02-14 08:30:00	2019-02-14 10:00:00	\N	\N	6	0	651	\N
356150	ETUDES	AUCUNE	\N	\N	\N	Rencontre avec le président de la FFC	Rencontre avec le président de la Fédération française de cyclisme	2019-02-20 08:00:00	2019-02-20 09:00:00	\N	\N	12	0	\N	934
360711	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Collectivité européenne d'Alsace	\N	2019-03-13 10:30:00	2019-03-13 12:15:00	\N	\N	1	0	\N	\N
360803	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL "Habitat insalubre ou dangereux"	PPL "Habitat insalubre ou dangereux"	2019-03-13 09:15:00	2019-03-13 11:10:00	\N	\N	1	0	\N	\N
360817	GIA	AUCUNE	\N	\N	\N	Assemblée générale annuelle	Assemblée générale annuelle du GIA France-Asie centrale	2019-03-12 17:45:00	2019-03-12 18:00:00	\N	\N	8	0	556	\N
360915	GIA	AUCUNE	\N	\N	\N	Rencontre avec l'association Novastan	Rencontre avec l'association Novastan	2019-03-12 18:00:00	2019-03-12 18:30:00	\N	\N	8	0	556	\N
361142	DELEGATION	AUCUNE	\N	\N	COLTER	Audition A. Lambert, président du CNEN	\N	2019-03-21 10:00:00	2019-03-21 11:05:00	2019-03-21 12:26:41	\N	12	0	\N	\N
361162	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL École de la confiance	\N	2019-03-12 09:00:00	2019-03-12 11:00:00	\N	\N	1	0	\N	\N
361164	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL École de la confiance	\N	2019-03-12 17:45:00	2019-03-12 18:45:00	\N	\N	1	0	\N	\N
361166	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL École de la confiance	\N	2019-03-13 14:00:00	2019-03-13 18:00:00	\N	\N	1	0	\N	\N
361551	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Suite cyberattaque Ariane	\N	2019-03-13 15:30:00	2019-03-13 17:30:00	\N	\N	2	0	\N	\N
364263	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Collectivité européenne d'Alsace	\N	2019-03-20 17:30:00	2019-03-20 18:30:00	\N	\N	1	0	\N	\N
370830	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Taxe sur les services numériques - Booking.com	PJL Taxe sur les services numériques - Booking.com	2019-04-03 15:30:00	2019-04-03 16:30:00	\N	\N	1	0	\N	\N
370835	DELEGATION	AUCUNE	\N	\N	DSOM	Examen du rapport sur l'audiovisuel public et les outre-mer	\N	2019-04-09 08:40:00	2019-04-09 09:55:00	2019-04-10 17:43:00	\N	10	0	\N	\N
370840	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Taxe sur les services numériques - France Digitale	PJL Taxe sur les services numériques - France Digitale	2019-04-04 17:00:00	2019-04-04 17:45:00	\N	\N	3	0	\N	\N
370843	DELEGATION	AUCUNE	\N	\N	DSOM	Auditions de la Délégation aux outre-mer	\N	2019-04-11 16:15:00	2019-04-11 17:45:00	2019-04-11 18:22:41	\N	3	0	\N	\N
370848	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Rapport général - RMN-GP	PLF pour 2020 - Rapport général - RMN-GP	2019-04-04 16:15:00	2019-04-04 17:00:00	\N	\N	1	0	\N	\N
370850	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions thanatopraxie	\N	2019-04-11 16:15:00	2019-04-11 17:30:00	\N	\N	0	0	\N	\N
370851	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions thanatopraxie	MI thanatopraxie	2019-04-10 14:30:00	2019-04-10 16:30:00	\N	\N	1	0	\N	\N
370852	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions thanatopraxie	MI thanatopraxie	2019-04-09 14:30:00	2019-04-09 16:30:00	\N	\N	1	0	\N	\N
370965	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-04-09 14:05:00	2019-04-09 16:15:00	2019-04-09 17:53:26	2019-04-10 11:23:58	36	0	\N	\N
370966	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-04-10 09:15:00	2019-04-10 11:25:00	2019-04-10 11:51:15	2019-04-10 16:51:01	34	2	\N	\N
371146	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Autre - GE Chasse et Pêche 2018	\N	2019-04-04 08:00:00	2019-04-04 08:30:00	\N	\N	0	0	\N	\N
373566	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Mobilisation des financements régionaux - ARF	Contrôle 2019 - Mobilisation des financements régionaux - ARF	2019-04-09 15:00:00	2019-04-09 16:00:00	\N	\N	1	0	\N	\N
373568	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Mobilisation des financements régionaux - Région Île-de-France	Contrôle 2019 - Mobilisation des financements régionaux - Région Île-de-France	2019-04-10 15:00:00	2019-04-10 16:00:00	\N	\N	1	0	\N	\N
373570	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Recouvrement des amendes de stationnement - ANTAI	Contrôle 2019 - Recouvrement des amendes de stationnement - ANTAI	2019-04-10 14:00:00	2019-04-10 15:30:00	\N	\N	2	0	\N	\N
373596	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Lutte contre les espèces toxiques envahissantes	\N	2019-04-11 16:30:00	2019-04-11 18:00:00	\N	\N	1	0	\N	\N
373598	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Lutte contre les espèces toxiques envahissantes	\N	2019-04-11 14:15:00	2019-04-11 15:00:00	\N	\N	1	0	\N	\N
373649	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Taxe sur les services numériques - CNIL	PJL Taxe sur les services numériques - CNIL	2019-04-10 17:45:00	2019-04-10 18:30:00	\N	\N	1	0	\N	\N
373651	DELEGATION	AUDRAP	\N	\N	PROS	Audition de Serge Tisseron	\N	2019-04-30 10:00:00	2019-04-30 11:00:00	\N	\N	2	0	\N	\N
373652	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Taxe sur les services numériques - Ebay	PJL Taxe sur les services numériques - Ebay	2019-04-11 08:00:00	2019-04-11 09:00:00	\N	\N	3	0	\N	\N
373656	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Taxe sur les services numériques - TECH in / Cabinet STEHLIN	PJL Taxe sur les services numériques - TECH in / Cabinet STEHLIN	2019-04-11 09:00:00	2019-04-11 11:00:00	\N	\N	3	0	\N	\N
373660	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Stade de France - FFR	Contrôle 2019 - Stade de France - FFR	2019-04-11 11:30:00	2019-04-11 12:15:00	\N	\N	1	0	\N	\N
373665	DELEGATION	AUDRAP	\N	\N	PROS	Audition de M. Bertrand Braunschweig	\N	2019-04-30 09:00:00	2019-04-30 10:00:00	\N	\N	2	0	\N	\N
373666	DELEGATION	AUCUNE	\N	\N	PROS	Examen du rapport	\N	2019-05-16 08:35:00	2019-05-16 10:05:00	\N	\N	19	0	\N	\N
373667	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2019-04-30 14:45:00	2019-04-30 15:45:00	\N	\N	3	0	\N	\N
373671	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-05-02 10:35:00	2019-05-02 12:20:00	2019-05-03 09:47:20	2019-05-03 09:51:10	14	0	\N	\N
373672	MECSS	AUDRAP	\N	\N	MECSS	\N	\N	2019-05-14 14:45:00	2019-05-14 16:30:00	\N	\N	1	0	\N	\N
373687	COM_PERMANENTE	AUTRE	\N	FINC	\N	Rapport programme de stabilité 2019-2022 - Application des lois mars 2019	Rapport programme de stabilité 2019-2022 - Application des lois mars 2019	2019-04-29 15:05:00	2019-04-29 16:30:00	2019-05-02 10:51:50	2019-05-02 10:53:58	25	0	\N	\N
373688	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition commune sur le PJL 452 (2018-2019) - Taxe sur les services numériques 	Audition commune sur le PJL 452 (2018-2019) - Taxe sur les services numériques 	2019-04-30 08:40:00	2019-04-30 10:25:00	2019-04-30 11:29:04	2019-04-30 17:33:08	26	0	\N	\N
373691	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	PROS	Déjeuner de travail politique de comunication et programme de travail	Déjeuner de travail politique de comunication et programme de travail	2019-04-30 12:30:00	2019-04-30 14:00:00	\N	\N	21	0	\N	\N
373694	DELEGATION	DEPLACEMENT	\N	\N	206	Visite du CERN à Genève	Visite du CERN à Genève	2019-05-03 11:00:00	2019-05-03 16:00:00	\N	\N	5	0	\N	\N
373695	DELEGATION	AUDRAP	\N	\N	PROS	Audition de France Stratégie	Audition de France Stratégie	2019-05-14 17:00:00	2019-05-14 18:30:00	\N	\N	1	0	\N	\N
217443	COM_PERMANENTE	AUTRE	\N	CDD	\N	PLF 2018, Prévention des risques, Écologie, développement et mobilité durables	PLF 2018, Prévention des risques, Écologie, développement et mobilité durables	2017-11-16 11:05:00	2017-11-16 13:00:00	2017-11-17 11:15:56	2017-11-17 13:36:03	26	0	\N	\N
217448	COM_PERMANENTE	AUTRE	\N	CDD	\N	Audition de M. J. Mézard, ministre de la cohésion sociale 	Audition de M. J. Mézard, ministre de la cohésion sociale 	2017-11-16 15:05:00	2017-11-16 17:10:00	2017-11-17 11:16:37	2017-11-17 13:36:04	22	0	\N	\N
217450	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2017-11-15 14:30:00	2017-11-15 17:30:00	\N	\N	1	0	\N	\N
217452	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2017-11-15 17:00:00	2017-11-15 18:00:00	\N	\N	1	0	\N	\N
217460	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Écologie, développement et mobilité durables/Transports	PLF pour 2018 - Écologie, développement et mobilité durables/Transports - Audition Société du Grand Paris	2017-11-07 10:00:00	2017-11-07 11:00:00	\N	\N	1	0	\N	\N
217462	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Écologie, développement et mobilité durables/Transports	PLF pour 2018 - Écologie, développement et mobilité durables/Transports - Audition SNCF Mobilités	2017-11-09 12:00:00	2017-11-09 13:00:00	\N	\N	1	0	\N	\N
217467	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Contrôle et exploitation aériens 	PLF pour 2018 - Contrôle et exploitation aériens -Auditions DGAC et Groupe ADP	2017-11-10 10:00:00	2017-11-10 12:30:00	\N	\N	1	0	\N	\N
228073	DELEGATION	AUCUNE	\N	\N	211	Audition de Mme Brigitte Grésy, secrétaire générale du CSEP	Audition de Mme Brigitte Grésy, secrétaire générale du CSEP	2017-12-07 08:30:00	2017-12-07 10:00:00	2017-12-07 14:37:59	2017-12-07 14:50:42	16	0	\N	\N
228098	DELEGATION	AUCUNE	\N	\N	211	Audition de Mme Marie Pezé, docteur en psychologie	Audition de Mme Marie Pezé, docteur en psychologie	2017-12-07 10:00:00	2017-12-07 11:05:00	2017-12-07 14:43:04	2017-12-07 14:50:43	14	0	\N	\N
228647	SEANCE_PLENIERE	SCRUSOL	841	\N	\N	PLF 2018 - Scrutin public à la tribune sur l'ensemble	PLF 2018 - Scrutin public à la tribune sur l'ensemble	2017-12-12 16:00:00	2017-12-12 16:40:00	\N	\N	0	0	\N	\N
228675	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Conseil européen	Débat Conseil européen	2017-12-12 19:00:00	2017-12-12 21:10:00	\N	\N	60	0	\N	\N
230185	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2017-12-12 16:30:00	2017-12-12 18:30:00	\N	\N	3	0	\N	\N
230189	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Audition OTICE	\N	2017-12-14 09:45:00	2017-12-14 10:45:00	\N	\N	2	0	\N	\N
233240	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2018-01-16 17:45:00	2018-01-16 19:30:00	\N	\N	1	0	\N	\N
233242	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2018-01-18 14:00:00	2018-01-18 18:00:00	\N	\N	1	0	\N	\N
233248	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Organisation des Jeux Olympiques et Paralympiques 2024	\N	2018-01-09 16:30:00	2018-01-09 17:30:00	\N	\N	3	0	\N	\N
233252	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Organisation des Jeux Olympiques et Paralympiques 2024	\N	2018-01-10 08:45:00	2018-01-10 11:30:00	\N	\N	2	0	\N	\N
233255	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Organisation des Jeux Olympiques et Paralympiques 2024	\N	2018-01-10 11:30:00	2018-01-10 12:00:00	\N	\N	1	0	\N	\N
233259	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Organisation des Jeux Olympiques et Paralympiques 2024	\N	2018-01-10 14:30:00	2018-01-10 15:00:00	\N	\N	2	0	\N	\N
233262	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Organisation des Jeux Olympiques et Paralympiques 2024	\N	2018-01-10 15:00:00	2018-01-10 15:45:00	\N	\N	1	0	\N	\N
233264	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Organisation des Jeux Olympiques et Paralympiques 2024	\N	2018-01-10 15:45:00	2018-01-10 16:15:00	\N	\N	2	0	\N	\N
233267	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Organisation des Jeux Olympiques et Paralympiques 2024	\N	2018-01-10 16:15:00	2018-01-10 16:45:00	\N	\N	3	0	\N	\N
233271	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Organisation des Jeux Olympiques et Paralympiques 2024	\N	2018-01-10 16:45:00	2018-01-10 17:45:00	\N	\N	2	0	\N	\N
233274	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Organisation des Jeux Olympiques et Paralympiques 2024	\N	2018-01-10 17:45:00	2018-01-10 19:00:00	\N	\N	1	0	\N	\N
233276	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Organisation des Jeux Olympiques et Paralympiques 2024	\N	2018-01-11 19:00:00	2018-01-11 20:00:00	\N	\N	1	0	\N	\N
233289	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	PJL Organisation des Jeux Olympiques et Paralympiques 2024	PJL JO 2024 - Déplacement à Bobigny et Saint-Denis	2018-01-11 10:30:00	2018-01-11 17:30:00	\N	\N	1	0	\N	\N
233291	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	PJL Organisation des Jeux Olympiques et Paralympiques 2024	PJL JO 2024 - Déplacement à Bobigny	2018-01-11 11:00:00	2018-01-11 13:00:00	\N	\N	1	0	\N	\N
233293	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	PJL Organisation des Jeux Olympiques et Paralympiques 2024	PJL JO 2024 - Déplacement à Saint-Denis	2018-01-11 15:30:00	2018-01-11 17:30:00	\N	\N	1	0	\N	\N
235526	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2018-01-23 09:05:00	2018-01-23 10:00:00	2018-01-23 10:04:26	2018-01-23 17:20:40	33	0	\N	\N
235529	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2018-01-23 13:45:00	2018-01-23 14:25:00	2018-01-23 14:28:13	2018-01-23 17:20:41	24	0	\N	\N
217437	COM_PERMANENTE	AUTRE	\N	CDD	\N	PLF 2018, Prévention des risques, Écologie, développement et mobilité durables	PLF 2018, Prévention des risques, Écologie, développement et mobilité durables	2017-11-15 09:35:00	2017-11-15 12:15:00	2017-11-15 15:38:04	2017-11-15 16:15:14	42	0	\N	\N
235609	COM_PERMANENTE	AUTRE	\N	CDD	\N	Audition de M. Emmanuel Barbe, délégué interministériel à la sécurité routière 	Audition de M. Emmanuel Barbe, délégué interministériel à la sécurité routière 	2018-01-24 09:00:00	2018-01-24 10:45:00	2018-01-24 17:11:55	2018-01-24 17:43:05	62	2	\N	\N
235612	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition  de Mme Virginie Beaumeunier, DG de la Direction Générale de la Concurrence 	Audition  de Mme Virginie Beaumeunier, directrice générale de la Direction Générale de la Concurrence	2018-01-23 18:00:00	2018-01-23 19:15:00	2018-01-24 16:03:44	2018-01-24 16:17:18	35	0	\N	\N
235613	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de M. Michel Nalet, directeur de la communication de Lactalis 	Audition de M. Michel Nalet, directeur de la communication de Lactalis 	2018-01-24 09:30:00	2018-01-24 11:05:00	2018-01-24 16:03:17	2018-01-24 16:17:16	39	0	\N	\N
238292	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	AG groupe d'amitié Cône Sud	\N	2018-01-25 10:00:00	2018-01-25 10:30:00	\N	\N	8	0	\N	\N
238310	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition cycle de vie des entreprises	Audition cycle de vie des entreprises - Union des autoentrepreneurs	2018-01-24 18:00:00	2018-01-24 18:45:00	\N	\N	1	0	\N	\N
238630	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2018-01-31 09:55:00	2018-01-31 11:30:00	2018-01-31 11:34:46	2018-01-31 14:23:10	43	0	\N	\N
238690	MECSS	AUDRAP	\N	\N	MECSS	\N	\N	2018-02-01 09:30:00	2018-02-01 11:30:00	\N	\N	5	0	\N	\N
238775	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition N. Belloubet, GS, ministre de la justice sur la situation des prisons	\N	2018-02-01 16:20:00	2018-02-01 18:10:00	2018-02-01 18:27:03	2018-02-01 20:08:21	20	0	\N	\N
239410	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	Audition MM. Bourdillon Salomon	2018-02-07 09:00:00	2018-02-07 10:30:00	2018-02-07 16:05:12	2018-02-08 14:47:28	56	0	\N	\N
239906	DELEGATION	AUCUNE	\N	\N	211	Audition de Mme Marilyn Baldeck (AVFT)	Audition de Mme Marilyn Baldeck (AVFT)	2018-01-31 13:45:00	2018-01-31 15:00:00	2018-01-31 15:54:36	2018-01-31 17:23:45	4	0	\N	\N
241152	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT Evolution de la fiscalité locale	GT Evolution de la fiscalité locale -Réunion constitutive	2018-01-30 15:30:00	2018-01-30 16:35:00	\N	\N	8	0	\N	\N
244266	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière du 22 février 2018	Audition, ouverte à la presse, de M. Roger Genet, directeur général de l'ANSES	2018-02-22 10:40:00	2018-02-22 12:45:00	2018-02-22 17:40:38	2018-02-22 17:57:42	10	0	\N	\N
303728	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Auditions plénières - Affaire "Benalla"	Auditions plénières - Affaire "Benalla"	2018-07-25 14:30:00	2018-07-25 18:45:00	2018-07-26 14:39:56	2018-07-26 17:23:08	45	0	\N	\N
303916	COM_EURO	AUDRAP	\N	AFEU	\N	Retour au taux réduit de TVA pour la filière équine	Audition de représentants de ARQANA	2018-07-25 09:00:00	2018-07-25 10:30:00	\N	\N	1	0	\N	\N
303956	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition plénière de M. Alexis KOHLER	Audition de M. Alexis KOHLER, Secrétaire général de la présidence de la République	2018-07-26 08:35:00	2018-07-26 11:10:00	2018-07-26 13:31:50	2018-07-26 17:23:09	54	0	\N	\N
303961	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition article 13 - M. Jean-Raphaël Alventosa	Audition article 13 - M. Jean-Raphaël Alventosa	2018-07-26 11:15:00	2018-07-26 12:10:00	2018-07-26 13:08:03	2018-07-26 17:23:06	12	0	\N	\N
303968	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions rapporteur	Audition Réforme territoriale	2018-07-18 15:15:00	2018-07-18 16:00:00	\N	\N	3	0	\N	\N
303969	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions rapporteur	Auditions Réforme territoriale	2018-07-19 10:15:00	2018-07-19 12:30:00	\N	\N	4	0	\N	\N
324911	MISSION	AUCUNE	\N	INFRACTIONS	\N	Audition de M. Jean-Marie Delarue et du docteur Sabine Mouchet-Mages	Audition de M. Jean-Marie Delarue et du docteur Sabine Mouchet-Mages	2018-11-21 17:00:00	2018-11-21 18:20:00	2018-11-23 14:54:46	2018-11-23 14:58:45	19	0	\N	\N
330479	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2018-11-29 08:30:00	2018-11-29 09:15:00	2018-11-29 09:38:44	2018-11-29 14:39:07	21	1	\N	\N
330480	COM_PERMANENTE	AUTRE	\N	SOCI	\N	amdts séance nouvelle lecture PLFSS pour 2019	\N	2018-11-29 11:00:00	2018-11-29 12:00:00	\N	\N	0	0	\N	\N
330628	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2018-12-05 11:00:00	2018-12-05 12:35:00	2018-12-05 12:34:57	2018-12-05 16:42:19	35	0	\N	\N
348032	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Orientation des mobilités	\N	2019-01-31 16:10:00	2019-01-31 18:50:00	\N	\N	1	0	\N	\N
348298	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	Contrôle des Comptes	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne	2019-02-05 14:30:00	2019-02-05 15:30:00	2019-02-05 15:55:43	2019-02-05 16:45:03	7	0	\N	\N
350763	ETUDES	AUCUNE	\N	\N	\N	Audition MSD Vaccins	\N	2019-02-14 09:15:00	2019-02-14 10:00:00	\N	\N	5	0	\N	1004
358058	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	\N	\N	2019-03-07 09:00:00	2019-03-07 10:30:00	2019-03-07 11:04:10	2019-03-07 12:20:48	5	0	\N	\N
358064	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2019-03-06 15:00:00	2019-03-06 17:00:00	\N	\N	3	0	\N	\N
358103	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-03-13 09:30:00	2019-03-13 11:25:00	2019-03-13 12:18:54	2019-03-14 11:44:50	31	0	\N	\N
365640	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Nouveaux territoires du sport	MI Nouveaux territoires du sport	2019-03-26 14:30:00	2019-03-26 15:30:00	\N	\N	4	0	\N	\N
367470	COM_EURO	DEPLACEMENT	\N	AFEU	\N	Parlement européen - CAE - Bruxelles	Parlement européen - CAE - Bruxelles - Conférence interparlementaire	2019-04-02 07:00:00	2019-04-02 15:00:00	\N	\N	1	0	\N	\N
367784	DELEGATION	AUCUNE	\N	\N	206	Audition de Mme Catherine Troendlé sur la politique de communication du Sénat	Audition de Mme Catherine Troendlé sur la politique de communication du Sénat (pour les sénateurs membres de l'Office)	2019-04-11 10:15:00	2019-04-11 11:00:00	\N	\N	4	0	\N	\N
367788	DELEGATION	AUCUNE	\N	\N	206	Examen du rapport sur l'expertise des risques sanitaires et environnementaux 	Examen du rapport sur l'expertise des risques sanitaires et environnementaux - Désignation rapporteurs	2019-05-02 10:40:00	2019-05-02 12:50:00	\N	\N	10	0	\N	\N
367789	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2019-04-01 15:15:00	2019-04-01 17:15:00	\N	\N	2	0	\N	\N
367792	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2019-04-03 14:15:00	2019-04-03 15:00:00	\N	\N	1	0	\N	\N
367794	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2019-04-04 09:30:00	2019-04-04 10:30:00	\N	\N	1	0	\N	\N
235532	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2018-01-24 09:05:00	2018-01-24 11:20:00	2018-01-24 11:22:05	2018-01-24 16:00:57	45	0	\N	\N
238631	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2018-01-31 11:30:00	2018-01-31 11:55:00	2018-01-31 11:56:40	2018-01-31 14:23:08	45	0	\N	\N
239413	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2018-02-07 10:50:00	2018-02-07 11:10:00	2018-02-07 11:11:21	2018-02-07 15:03:34	35	0	\N	\N
369128	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Nouveaux territoires du sport	MI Nouveaux territoires du sport	2019-04-03 14:30:00	2019-04-03 15:30:00	\N	\N	5	0	\N	\N
369150	MISSION	AUCUNE	\N	BREXIT2	\N	Audition de Mme Sylvie Goulard, sous-gouverneure de la Banque de France	Audition de Mme Sylvie Goulard, sous-gouverneure de la Banque de France	2019-04-03 14:35:00	2019-04-03 15:30:00	2019-04-03 16:19:08	2019-04-04 11:42:33	8	0	\N	\N
369692	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	GT justice prud'homale	\N	2018-07-04 12:30:00	2018-07-04 19:15:00	\N	\N	2	0	\N	\N
369695	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	GT justice prud'homale	\N	2018-11-05 07:20:00	2018-11-05 21:40:00	\N	\N	1	0	\N	\N
369697	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	GT justice prud'homale	\N	2018-11-22 07:50:00	2018-11-22 19:00:00	\N	\N	2	0	\N	\N
369700	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	GT justice prud'homale	\N	2018-11-23 08:15:00	2018-11-23 19:15:00	\N	\N	2	0	\N	\N
369704	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	GT justice prud'homale	\N	2018-12-10 08:20:00	2018-12-10 19:40:00	\N	\N	2	0	\N	\N
369707	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	GT justice prud'homale	\N	2019-03-04 05:30:00	2019-03-04 19:30:00	\N	\N	1	0	\N	\N
369709	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	GT justice prud'homale	\N	2019-03-05 08:50:00	2019-03-05 20:20:00	\N	\N	1	0	\N	\N
369713	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	GT justice prud'homale	\N	2019-04-01 06:10:00	2019-04-01 21:00:00	\N	\N	2	0	\N	\N
369926	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Pastoralisme	GT Pastoralisme	2019-04-04 13:45:00	2019-04-04 14:50:00	\N	\N	7	0	\N	\N
370171	DELEGATION	AUCUNE	\N	\N	211	Audition de Mme Nathalie Boy de la Tour	Audition de Mme Nathalie Boy de la Tour	2019-04-04 10:30:00	2019-04-04 11:45:00	\N	\N	12	0	\N	\N
370536	MISSION	AUCUNE	\N	INFRACTIONS	\N	Auditions plénières	\N	2019-04-09 16:35:00	2019-04-09 18:15:00	2019-04-09 18:19:01	2019-04-10 11:23:03	8	0	\N	\N
370539	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Agriculture biologique - UFC-Que choisir	Contrôle 2019 - Agriculture biologique - UFC-Que choisir	2019-04-02 16:15:00	2019-04-02 17:00:00	\N	\N	2	0	\N	\N
370545	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Réforme des retraites - DREES / Agirc-Arrco	Contrôle 2018 - Réforme des retraites - DREES / Agirc-Arrco	2019-04-02 17:00:00	2019-04-02 19:55:00	\N	\N	1	0	\N	\N
370547	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Agriculture biologique - DGCCRF/ Ministère transition écologique	Contrôle 2019 - Agriculture biologique - DGCCRF/ Ministère transition écologique	2019-04-03 10:30:00	2019-04-03 13:00:00	\N	\N	2	0	\N	\N
370550	GIA	AUCUNE	\N	\N	\N	réunion du groupe (Malakoff - Bureau du Tibet)	réunion du groupe (Malakoff - Bureau du Tibet)	2019-04-10 12:30:00	2019-04-10 15:00:00	\N	\N	3	0	634	\N
370562	DELEGATION	AUDRAP	\N	\N	PROS	Audition de l'Union Nationale de Fédérations d'Organismes Hlm	\N	2019-04-09 10:15:00	2019-04-09 11:15:00	\N	\N	2	0	\N	\N
370567	MISSION	AUCUNE	\N	CLIMATIQUE	\N	Auditions BRGM et FFB	\N	2019-04-04 16:05:00	2019-04-04 18:00:00	2019-04-05 16:55:41	2019-04-05 16:57:20	6	0	\N	\N
370741	ETUDES	AUCUNE	\N	\N	\N	Table ronde sur l'hydrogène	\N	2019-04-04 13:30:00	2019-04-04 15:00:00	\N	\N	13	0	\N	906
370780	ETUDES	AUCUNE	\N	\N	\N	GE numérique	\N	2019-04-04 14:00:00	2019-04-04 15:00:00	\N	\N	15	0	\N	1008
370795	ETUDES	AUCUNE	\N	\N	\N	GE numérique	\N	2019-04-04 16:15:00	2019-04-04 16:45:00	\N	\N	5	0	\N	1008
370801	DELEGATION	AUDRAP	\N	\N	COLTER	Le rôle des communes dans les intercommunalités	Le rôle des communes dans les intercommunalités - Audition Patrick OLLIER, président de la métropole du Grand Paris	2019-01-16 15:30:00	2019-01-16 16:30:00	\N	\N	2	0	\N	\N
370804	DELEGATION	DEPLACEMENT	\N	\N	COLTER	Déplacement Dreux - Le rôle des communes dans les intercommunalités	Déplacement à Dreux dans le cadre du rapport d'information « La place des élus municipaux dans les intercommunalités »	2019-03-06 12:45:00	2019-03-06 18:15:00	\N	\N	1	0	\N	\N
213324	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Entretien avec une délégation italienne	\N	2017-10-26 14:00:00	2017-10-26 15:00:00	\N	\N	4	0	\N	\N
213329	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Entretien avec une délégation lituano-ukrainienne	\N	2017-10-25 14:30:00	2017-10-25 15:15:00	\N	\N	2	0	\N	\N
213334	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2018 - Programme 151	\N	2017-10-25 15:15:00	2017-10-25 16:45:00	\N	\N	1	0	\N	\N
217438	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2018 - Mission GFPRH - Montreuil	PLF pour 2018 - Mission GFPRH - DGDDI Montreuil	2017-11-07 08:30:00	2017-11-07 10:30:00	\N	\N	2	0	\N	\N
217446	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Economie	PLF pour 2018 - Economie - Entretien ETSY	2017-11-07 16:30:00	2017-11-07 17:30:00	\N	\N	1	0	\N	\N
225360	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	206	Réunion informelle avec une délégation de parlementaires russes	Réunion informelle avec une délégation de parlementaires russes, membres de la Douma et du Conseil de la Fédération	2017-11-28 09:00:00	2017-11-28 11:00:00	\N	\N	8	0	\N	\N
225373	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	206	Déjeuner de travail avec une délégation de parlementaires russes	Déjeuner de travail avec une délégation de parlementaires russes, membres de la Douma et du Conseil de la Fédération	2017-11-28 12:30:00	2017-11-28 14:30:00	\N	\N	6	0	\N	\N
228906	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Réunion de bureau	\N	2017-10-05 14:45:00	2017-10-05 16:30:00	\N	\N	13	0	\N	\N
228920	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Réunion de bureau	\N	2017-10-26 08:30:00	2017-10-26 10:00:00	\N	\N	12	0	\N	\N
228933	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Réunion de bureau	\N	2017-12-12 09:30:00	2017-12-12 10:30:00	\N	\N	7	0	\N	\N
235194	GIA	AUCUNE	\N	\N	\N	Assemblée générale	Assemblée générale du groupe d'amitié France-Albanie	2018-01-17 13:30:00	2018-01-17 14:00:00	\N	\N	3	0	571	\N
238784	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Libye	\N	2018-01-24 18:00:00	2018-01-24 19:00:00	\N	\N	2	0	\N	\N
240184	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	LOIS	\N	Situation des prisons	Situation des prisons	2018-01-30 16:00:00	2018-01-30 17:00:00	\N	\N	11	0	\N	\N
240196	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	LOIS	\N	Situation des prisons	Situation des prisons	2018-01-30 17:10:00	2018-01-30 17:40:00	\N	\N	8	0	\N	\N
369657	CMP	AUTRE	\N	ANCT	\N	PPL Agence nationale de la cohésion des territoires	PPL Agence nationale de la cohésion des territoires	2019-04-03 16:35:00	2019-04-03 17:40:00	\N	\N	9	0	\N	\N
369667	CMP	AUTRE	\N	ANCTORG	\N	\N	PPLO Directeur général de l'Agence nationale de la cohésion des territoires	2019-04-03 17:45:00	2019-04-03 17:47:00	\N	\N	9	0	\N	\N
370534	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-04-10 09:30:00	2019-04-10 10:15:00	2019-04-10 10:31:16	2019-04-10 11:23:57	39	0	\N	\N
250118	COM_EURO	AUDRAP	\N	AFEU	\N	Audition suivi CE Schengen	Audition suivi CE Schengen	2018-02-22 09:15:00	2018-02-22 14:30:00	\N	\N	2	0	\N	\N
250136	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	Inserm	\N	2018-03-07 15:45:00	2018-03-07 16:45:00	\N	\N	0	0	\N	\N
253027	DELEGATION	AUDRAP	\N	\N	206	Audition de l'IRD	Audition de l'Institut de recherche pour le développement (IRD)	2018-03-19 14:30:00	2018-03-19 15:30:00	\N	\N	3	0	\N	\N
253028	DELEGATION	AUDRAP	\N	\N	206	Audition de l'UNAF	Audition de l'Union nationale de l'apiculture française (UNAF)	2018-03-19 15:30:00	2018-03-19 16:30:00	\N	\N	3	0	\N	\N
253029	DELEGATION	AUDRAP	\N	\N	206	Audition DGPR	Audition de la Direction générale de la prévention des risques (DGPR) (ministère transition écologique et solidaire)	2018-03-19 16:30:00	2018-03-19 17:30:00	\N	\N	2	0	\N	\N
261717	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	Commission des comptes	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne	2018-04-03 14:30:00	2018-04-03 15:45:00	2018-04-03 16:44:11	2018-04-03 17:21:23	7	0	\N	\N
264235	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Élection des représentants au Parlement européen	\N	2018-04-10 09:05:00	2018-04-10 09:40:00	2018-04-10 10:45:22	2018-04-10 17:21:45	18	0	\N	\N
264236	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Candidats CMP Election parlement européen, nomination rapporteur, audition Mme Hazan	\N	2018-04-11 09:05:00	2018-04-11 10:45:00	2018-04-11 15:15:24	2018-04-11 17:31:21	45	0	\N	\N
265122	COM_ENQUETE	PLENIERE	\N	CHUTE	\N	Audition plénière	\N	2018-04-12 11:05:00	2018-04-12 12:20:00	2018-04-13 17:58:59	2018-04-13 18:05:16	6	0	\N	\N
265432	COM_ENQUETE	AUTRE	\N	CHUTE	\N	Audition plénière	\N	2018-04-12 16:00:00	2018-04-12 17:20:00	2018-04-13 17:59:29	2018-04-13 18:05:17	9	0	\N	\N
270339	GIA	AUCUNE	\N	\N	\N	Entretien avec S. Exc. Mme Ruth Esperanza TAPIA ROA, ambassadrice du Nicaragua en France	Entretien avec S. Exc. Mme Ruth Esperanza TAPIA ROA, ambassadrice du Nicaragua en France	2018-04-04 14:00:00	2018-04-04 15:00:00	\N	\N	3	0	643	\N
270343	GIA	AUCUNE	\N	\N	\N	Audition de M. Gilles BATAILLON, Directeur d'études de l¿EHESS	Audition de M. Gilles BATAILLON, Directeur d'études de l¿École des hautes études en sciences sociales (EHESS)	2018-04-18 16:00:00	2018-04-18 17:15:00	\N	\N	6	0	643	\N
270350	DELEGATION	AUDRAP	\N	\N	206	Audition bioéthique du Pr Benoît Vallet, ancien directeur général de la santé	Audition bioéthique du Pr Benoît Vallet, ancien directeur général de la santé	2018-05-16 16:00:00	2018-05-16 17:25:00	\N	\N	5	0	\N	\N
270351	DELEGATION	AUDRAP	\N	\N	206	Audition bioéthique de M. Jean Leonetti, ancien député	Audition bioéthique de M. Jean Leonetti, ancien député, ancien rapporteur du PJL de révision de la loi de bioéthique	2018-05-22 16:30:00	2018-05-22 17:30:00	\N	\N	2	0	\N	\N
270352	DELEGATION	AUDRAP	\N	\N	206	Audition bioéthique du Dr Faroudja et du Pr Uzan	Audition bioéthique du Dr J.M. Faroudja, conseil national de l'ordre des médecins et du Pr S. Uzan, Sorbonne Université	2018-05-23 16:00:00	2018-05-23 17:00:00	\N	\N	2	0	\N	\N
274412	MISSION	DEPLACEMENT	\N	MINEURSENF	\N	Déplacement à Savigny Sur Orge	Déplacement au CEF de Savigny Sur Orge	2018-05-23 12:00:00	2018-05-23 18:00:00	\N	\N	7	0	\N	\N
275573	MISSION	DEPLACEMENT	\N	ALSTOM	\N	Déplacement à Toulouse	Déplacement à Toulouse	2018-03-05 08:40:00	2018-03-05 19:30:00	\N	\N	4	0	\N	\N
275603	MISSION	DEPLACEMENT	\N	ALSTOM	\N	Usine-école du futur du cabinet The Boston Consulting Group à Villebon-sur-Yvette	Usine-école du futur du cabinet The Boston Consulting Group à Villebon-sur-Yvette	2018-03-06 13:00:00	2018-03-06 17:00:00	\N	\N	4	0	\N	\N
275660	MISSION	DEPLACEMENT	\N	ALSTOM	\N	Déplacement à Bruxelles : représentation permanente ¿ commission européenne ¿ parlement eu	Déplacement à Bruxelles : représentation permanente ¿ commission européenne ¿ parlement européen	2018-03-19 08:19:00	2018-03-19 20:05:00	\N	\N	3	0	\N	\N
275666	MISSION	DEPLACEMENT	\N	ALSTOM	\N	Déplacement à Aytré - Usine Alstom	Déplacement à Aytré - Usine Alstom	2018-04-17 07:25:00	2018-04-17 19:35:00	\N	\N	3	0	\N	\N
275703	MISSION	DEPLACEMENT	\N	ALSTOM	\N	Déplacement à Belfort	Déplacement à Belfort	2018-06-01 07:25:00	2018-06-01 16:00:00	\N	\N	1	0	\N	\N
275726	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle APD 2018 - trajectoire financière 0,7% - New-York et Washington	Contrôle APD 2018 - trajectoire financière 0,7% - New-York et Washington	2018-06-04 14:25:00	2018-06-09 10:45:00	\N	\N	2	0	\N	\N
275737	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2018 - La Disponibilté des hélicoptères des Armées - Pau	Contrôle 2018 - La Disponibilté des hélicoptères des Armées - Pau	2018-05-28 07:00:00	2018-05-28 22:35:00	\N	\N	1	0	\N	\N
276009	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2018-05-22 14:40:00	2018-05-22 17:40:00	\N	\N	3	0	\N	\N
276013	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2018-05-24 11:45:00	2018-05-24 12:00:00	\N	\N	3	0	\N	\N
278349	COM_EURO	DEPLACEMENT	\N	AFEU	\N	Partenariat oriental	Bruxelles - Rencontre avec des représentants des institutions européennes	2018-05-30 11:00:00	2018-05-30 18:30:00	\N	\N	1	0	\N	\N
278358	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	Politique de cohésion régionale de l'Union européenne	Audition du Commissaire général à l'égalité des territoires	2018-05-30 16:00:00	2018-05-30 17:30:00	\N	\N	7	0	\N	\N
281704	MISSION	AUCUNE	\N	MINEURSENF	\N	\N	\N	2018-06-06 16:10:00	2018-06-06 19:00:00	2018-06-07 10:24:50	2018-06-07 18:47:56	10	0	\N	\N
281725	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	Politique de cohésion régionale de l'Union européenne	Rencontre avec M. Renaud Muselier, président de la commission "Europe" de Régions de France	2018-06-06 17:00:00	2018-06-06 18:15:00	\N	\N	5	0	\N	\N
299319	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	Commission des Comptes	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne 	2018-07-10 14:30:00	2018-07-10 16:00:00	2018-07-17 16:55:50	\N	8	0	\N	\N
299330	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	Commission des Comptes	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne 	2018-07-17 14:30:00	2018-07-17 16:30:00	2018-07-17 17:04:35	2018-07-18 09:35:22	3	0	\N	\N
299337	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL accord France-Autriche personnes en situation irrégulière	PJL accord France-Autriche personnes en situation irrégulière	2018-07-26 10:30:00	2018-07-26 11:55:00	\N	\N	35	0	\N	\N
311675	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Engagements financiers de l'État - AFT et S&P	PLF pour 2019 - Engagements financiers de l'État - AFT et S&P	2018-10-08 10:00:00	2018-10-08 12:00:00	\N	\N	1	0	\N	\N
311677	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - MIRES - Fédérations enseignement privé	PLF pour 2019 - MIRES - Fédérations enseignement privé	2018-10-11 09:30:00	2018-10-11 11:00:00	\N	\N	1	0	\N	\N
264238	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Protection savoir-faire, PPL eau et assainissement	\N	2018-04-11 10:45:00	2018-04-11 13:10:00	2018-04-11 15:12:45	2018-04-11 17:31:19	45	0	\N	\N
311679	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - MIRES - CNOUS /CGE /DGESIP	PLF pour 2019 - MIRES - CNOUS /CGE /DGESIP	2018-10-10 14:30:00	2018-10-10 18:00:00	\N	\N	1	0	\N	\N
311682	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Défense - Ministre des Armées	PLF pour 2019 - Défense - Ministre des Armées	2018-10-02 18:30:00	2018-10-02 20:15:00	\N	\N	1	0	\N	\N
311684	COM_PERMANENTE	DEPLACEMENT	\N	CDD	\N	Mondial de l'Auto 2018	\N	2018-10-11 09:30:00	2018-10-11 13:00:00	\N	\N	16	0	\N	\N
311693	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Travail et Emploi - Pôle emploi	PLF pour 2019 - Travail et Emploi - Pôle emploi	2018-10-11 16:05:00	2018-10-11 17:00:00	\N	\N	2	0	\N	\N
311706	COM_PERMANENTE	AUTRE	\N	FINC	\N	Contrôle 2018 - flux de transports en milieu urbain	Contrôle 2018 - flux de transports en milieu urbain	2018-10-17 12:05:00	2018-10-17 12:50:00	2018-10-17 15:13:26	2018-10-17 15:34:17	15	0	\N	\N
311729	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Presse	PLF 2019 - Crédits Presse	2018-10-11 17:15:00	2018-10-11 18:45:00	\N	\N	1	0	\N	\N
311743	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Sécurités - Syndicats police et APNM Gend XXI	PLF pour 2019 - Sécurités - Syndicats police et APNM Gend XXI	2018-10-09 14:00:00	2018-10-09 16:15:00	\N	\N	1	0	\N	\N
311745	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Sécurités - DGGN / Syndicat Alliance	PLF pour 2019 - Sécurités - DGGN / Syndicat Alliance	2018-10-11 09:00:00	2018-10-11 12:00:00	\N	\N	1	0	\N	\N
311747	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Sécurités - DGPN	PLF pour 2019 - Sécurités - DGPN	2018-10-12 10:30:00	2018-10-12 11:50:00	\N	\N	1	0	\N	\N
311749	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2019 - BA Contrôle et exploitation aériens - IGN	PLF pour 2019 - BA Contrôle et exploitation aériens - IGN	2018-10-11 09:30:00	2018-10-11 14:00:00	\N	\N	1	0	\N	\N
311751	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2018-10-11 10:30:00	2018-10-11 11:15:00	\N	\N	1	0	\N	\N
311754	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	plfss pour 2019 - médico-social	\N	2018-10-11 11:15:00	2018-10-11 12:00:00	\N	\N	2	0	\N	\N
345313	GIA	AUCUNE	\N	\N	\N	Entretien avec M. LONG Ling, du ministère chinois des Affaires étrangères (coopé)	Entretien avec M. LONG Ling, du ministère chinois des Affaires étrangères (coopé)	2019-01-30 16:30:00	2019-01-30 17:30:00	\N	\N	0	0	623	\N
350058	MISSION	PLEIN_NON_JO	\N	BREXIT2	\N	Audition Impact du Brexit sur le secteur de la pêche	Audition Impact du Brexit sur le secteur de la pêche	2019-02-06 15:05:00	2019-02-06 16:15:00	\N	\N	7	0	\N	\N
350586	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Sécurité des ponts	\N	2019-02-07 10:10:00	2019-02-07 11:40:00	\N	\N	5	0	\N	\N
350849	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI mission innovation et défense	\N	2019-02-05 14:00:00	2019-02-05 15:00:00	\N	\N	2	0	\N	\N
350852	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI mission innovation et défense	\N	2019-02-06 15:30:00	2019-02-06 16:35:00	\N	\N	2	0	\N	\N
350855	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI mission innovation et défense	\N	2019-02-06 17:00:00	2019-02-06 18:00:00	\N	\N	2	0	\N	\N
361512	COM_EURO	CONTROLE	\N	AFEU	\N	Débat préalable au Conseil européen des 21 et 22 mars 2019	Débat préalable au Conseil européen des 21 et 22 mars 2019	2019-03-14 16:30:00	2019-03-14 18:50:00	2019-03-14 19:21:16	2019-03-15 16:09:49	23	0	\N	\N
361584	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI mission innovation et défense	\N	2019-03-13 14:00:00	2019-03-13 15:45:00	\N	\N	2	0	\N	\N
361587	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI mission innovation et défense	\N	2019-03-06 15:00:00	2019-03-06 16:00:00	\N	\N	1	0	\N	\N
361647	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Création de l'Office français de la biodiversité	PJL Création de l'Office français de la biodiversité	2019-03-13 17:30:00	2019-03-13 18:20:00	\N	\N	5	0	\N	\N
361653	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Création de l'Office français de la biodiversité	PJL Création de l'Office français de la biodiversité	2019-03-14 08:00:00	2019-03-14 08:45:00	\N	\N	2	0	\N	\N
361656	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Création de l'Office français de la biodiversité	PJL Création de l'Office français de la biodiversité	2019-03-14 08:45:00	2019-03-14 09:30:00	\N	\N	2	0	\N	\N
361659	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Création de l'Office français de la biodiversité	PJL Création de l'Office français de la biodiversité	2019-03-14 10:15:00	2019-03-14 11:00:00	\N	\N	2	0	\N	\N
361662	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Création de l'Office français de la biodiversité	PJL Création de l'Office français de la biodiversité	2019-03-14 11:00:00	2019-03-14 12:00:00	\N	\N	2	0	\N	\N
361665	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Création de l'Office français de la biodiversité	PJL Création de l'Office français de la biodiversité	2019-03-14 14:00:00	2019-03-14 15:15:00	\N	\N	2	0	\N	\N
361670	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Création de l'Office français de la biodiversité	PJL Création de l'Office français de la biodiversité	2019-03-14 16:00:00	2019-03-14 18:33:00	\N	\N	2	0	\N	\N
361674	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n° 109 Corruption transnationale - AGRASC	PPL n° 109 Corruption transnationale - AGRASC	2019-03-14 18:10:00	2019-03-14 19:05:00	\N	\N	1	0	\N	\N
361678	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2019 - Les contrats de ruralité - Déplacement à Poitiers	Contrôle 2019 - Les contrats de ruralité - Déplacement à Poitiers	2019-03-18 08:30:00	2019-03-18 17:35:00	\N	\N	1	0	\N	\N
361687	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-03-19 16:30:00	2019-03-19 19:30:00	2019-03-20 16:53:08	2019-03-20 17:30:18	111	0	\N	\N
361688	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Création de l'Office français de la biodiversité	PJL Création de l'Office français de la biodiversité	2019-03-14 09:30:00	2019-03-14 10:30:00	\N	\N	3	0	\N	\N
361692	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Création de l'Office français de la biodiversité	PJL Création de l'Office français de la biodiversité	2019-03-14 14:00:00	2019-03-14 15:15:00	\N	\N	2	0	\N	\N
361695	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Création de l'Office français de la biodiversité	PJL Création de l'Office français de la biodiversité	2019-03-14 18:15:00	2019-03-14 19:00:00	\N	\N	1	0	\N	\N
361725	DELEGATION	AUDRAP	\N	\N	PROS	Auditiond de Mohamed Chetouani	\N	2019-04-03 16:45:00	2019-04-03 17:30:00	\N	\N	2	0	\N	\N
361762	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 28 mars 2019	\N	2019-03-28 08:30:00	2019-03-28 10:00:00	2019-04-01 17:09:17	2019-04-01 17:33:31	13	0	\N	\N
361764	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Création de l'Office français de la biodiversité	PJL Création de l'Office français de la biodiversité	2019-03-19 09:00:00	2019-03-19 10:00:00	\N	\N	2	0	\N	\N
311721	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2019 - Examen Rapports Sports, IA, EFE et DAG	PLF pour 2019 - Examen Rapports Sports, IA, EFE et DAG	2018-10-17 09:00:00	2018-10-17 12:05:00	2018-10-17 15:12:46	2018-10-17 15:34:23	48	0	\N	\N
215602	DELEGATION	AUCUNE	\N	\N	COLTER	Programme de travail	Programme de travail	2017-11-16 09:00:00	2017-11-16 10:20:00	2017-11-16 11:05:37	2017-11-16 15:14:29	18	0	\N	\N
217201	GIA	AUCUNE	\N	\N	\N	Entretien délégation chinoise (CCPPC)	Entretien avec une délégation de la Conférence consultative politique du peuple chinois	2017-11-09 14:30:00	2017-11-09 15:15:00	\N	\N	8	0	584	\N
217477	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GS Brexit - Audition Chambre des communes	GS Brexit - Audition Chambre des communes	2017-11-09 11:50:00	2017-11-09 12:50:00	\N	\N	13	0	\N	\N
230789	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Coopération parlementaire France-Russie	\N	2017-12-14 14:30:00	2017-12-14 15:30:00	\N	\N	2	0	\N	\N
232450	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe	Assemblée générale du groupe	2017-12-20 08:45:00	2017-12-20 09:30:00	\N	\N	11	0	617	\N
233041	COM_EURO	AUDRAP	\N	AFEU	\N	Agences de surveillance européennes	Agences de surveillance européennes - AMF	2018-01-10 14:30:00	2018-01-10 16:00:00	\N	\N	2	0	\N	\N
235599	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Jeux Olympiques 2024	PJL Jeux Olympiques 2024	2018-01-17 16:00:00	2018-01-17 17:30:00	\N	\N	1	0	\N	\N
235601	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Jeux Olympiques 2024	PJL Jeux Olympiques 2024	2018-01-18 17:30:00	2018-01-18 18:30:00	\N	\N	1	0	\N	\N
235603	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Territoires  Littoraux	PPL Territoires Littoraux	2018-01-16 13:30:00	2018-01-16 15:00:00	\N	\N	2	0	\N	\N
235606	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Territoires Littoraux	PPL Territoires Littoraux	2018-01-17 14:00:00	2018-01-17 15:00:00	\N	\N	2	0	\N	\N
240203	GIA	AUCUNE	\N	\N	\N	Assemblée générale	Assemblée générale de reconstitution du bureau du groupe et des membres de l'AIFC	2018-01-24 16:30:00	2018-01-24 17:00:00	\N	\N	12	0	583	\N
240599	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2018-02-01 15:00:00	2018-02-01 16:05:00	\N	\N	251	0	\N	\N
243394	GIA	AUCUNE	\N	\N	\N	Entretien avec le représentant de Taipei en France	Entretien avec le représentant de Taipei en France	2018-02-07 11:00:00	2018-02-07 12:00:00	\N	\N	1	0	623	\N
244334	MISSION	DEPLACEMENT	\N	ALSTOM	\N	 Sites Alstom Belfort et Ornans	 Sites Alstom Belfort et Ornans	2018-02-08 07:25:00	2018-02-08 21:05:00	\N	\N	5	0	\N	\N
247137	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	GT revitalisation - Table ronde acteurs économiques et financeurs	\N	2018-02-22 14:00:00	2018-02-22 15:30:00	\N	\N	9	0	\N	\N
249899	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition cycle de vie des entreprises	Audition cycle de vie des entreprises - American Chamber of Commerce	2018-02-21 17:15:00	2018-02-21 18:00:00	\N	\N	1	0	\N	\N
250047	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Déplacement sur la base de Saint-Dizier	\N	2018-02-22 07:00:00	2018-02-22 16:15:00	\N	\N	15	0	\N	\N
250285	AUTRE_TEMPORAIRE	CONTROLE	\N	\N	\N	MI_ALSTOM - PLENIERE - 8	\N	2018-03-08 11:00:00	2018-03-08 12:30:00	\N	\N	0	0	\N	\N
250304	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Mission DAG - Audition ANSSI	Mission DAG - Audition ANSSI	2018-02-22 15:00:00	2018-02-22 16:20:00	\N	\N	1	0	\N	\N
250308	COM_PERMANENTE	AUTRE	\N	CDD	\N	\N	\N	2018-03-06 13:45:00	2018-03-06 13:55:00	2018-03-08 18:13:09	2018-03-08 18:14:23	23	2	\N	\N
250309	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Mission "Affaires européennes" - AL	\N	2018-02-21 15:30:00	2018-02-21 16:30:00	\N	\N	1	0	\N	\N
250312	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Mission "Affaires européennes" - AL	\N	2018-02-22 08:30:00	2018-02-22 09:30:00	\N	\N	1	0	\N	\N
250560	COM_PERMANENTE	AUTRE	\N	FINC	\N	Communication GT Fiscalité locale - CR Déplacement Bruxelles Conférence Art 13	Communication du groupe de travail évolution de la fiscalité locale - Compte rendu déplacement Bruxelles Conf art 13	2018-03-07 09:35:00	2018-03-07 11:20:00	2018-03-07 14:14:47	2018-03-07 14:37:04	38	0	\N	\N
250562	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition M. Gérald DARMANIN, ministre de l'action et des comptes publics	Audition M. Gérald DARMANIN, ministre de l'action et des comptes publics - résultats de l¿exercice 2017 et réforme état	2018-03-07 16:35:00	2018-03-07 18:45:00	2018-03-08 18:12:00	2018-03-08 18:14:27	29	0	\N	\N
251753	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR Finance mondiale	PPR Finance mondiale	2018-03-07 23:15:00	2018-03-08 00:40:00	\N	\N	39	0	\N	\N
252527	COM_ENQUETE	PLENIERE	\N	FORCES	\N	CE Etat des forces de sécurité intérieure	CE Etat des forces de sécurité intérieure	2018-03-08 16:15:00	2018-03-08 19:10:00	2018-03-09 14:48:58	2018-03-09 14:55:40	8	0	\N	\N
258674	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	GT revitalisation : table ronde ministères et institutions nationales	\N	2018-03-28 15:00:00	2018-03-28 16:50:00	\N	\N	7	0	\N	\N
258694	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	GT revitalisation : table ronde chambres consulaires et club managers centre-villes	\N	2018-03-29 10:00:00	2018-03-29 11:30:00	\N	\N	3	0	\N	\N
258796	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	206	Conférence de presse sur les notes scientifiques de l'Office	Conférence de presse sur les notes scientifiques de l'Office	2018-03-22 11:45:00	2018-03-22 12:30:00	\N	\N	10	0	\N	\N
262902	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2018-04-10 09:05:00	2018-04-10 10:05:00	2018-04-10 10:58:37	2018-04-10 17:21:46	17	0	\N	\N
262916	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2018-04-11 15:00:00	2018-04-11 17:05:00	2018-04-12 14:21:28	2018-04-12 18:12:05	37	0	\N	\N
262994	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	Suite des conclusions sur l'affaire Lactalis	2018-04-05 11:05:00	2018-04-05 12:00:00	2018-04-05 14:52:42	2018-04-05 18:07:42	52	0	\N	\N
263000	AUTRE_TEMPORAIRE	AUTRE_NON_PLENIERE	\N	\N	\N	\N	\N	2018-04-11 14:30:00	2018-04-11 15:30:00	\N	\N	0	0	\N	\N
263167	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition "Taxe carbone"	Audition "Taxe carbone"	2018-04-11 10:30:00	2018-04-11 12:30:00	2018-04-12 10:00:13	2018-04-12 10:08:59	31	0	\N	\N
263171	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Relations Etat Sécurité sociale	PLF pour 2019 - Relations Etat Sécurité sociale	2018-03-26 17:30:00	2018-03-26 19:00:00	\N	\N	1	0	\N	\N
263179	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Relations Etat Sécurité sociale	PLF pour 2019 - Relations Etat Sécurité sociale	2018-03-27 09:30:00	2018-03-27 10:30:00	\N	\N	1	0	\N	\N
263102	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen du rapport PJL 227 Erosion base d'imposition	Examen du rapport PJL 227 Erosion base d'imposition	2018-04-11 09:30:00	2018-04-11 10:25:00	2018-04-12 09:59:53	2018-04-12 10:09:01	42	0	\N	\N
271621	DELEGATION	AUCUNE	\N	\N	211	Examen du rapport d'information sur les mutilations sexuelles féminines	Examen du rapport d'information sur les mutilations sexuelles féminines	2018-05-16 13:00:00	2018-05-16 14:40:00	2018-05-16 14:58:21	2018-05-16 17:59:12	17	0	\N	\N
271625	GIA	AUCUNE	\N	\N	\N	Conférence internationale Bruxelles 	Conférence sur les vicitmes de violences ethniques et religieuses 	2018-05-14 14:00:00	2018-05-14 18:30:00	\N	\N	1	0	CHRETORIENT	CHRETORIENT
271627	GIA	AUCUNE	\N	\N	\N	Déjeuner de travail	Déjeuner de travail en présence de l'Ambassadeur de Jordanie	2018-05-15 12:45:00	2018-05-15 14:20:00	\N	\N	10	0	659	\N
274004	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	AFCL	\N	\N	\N	2018-06-07 08:45:00	2018-06-07 09:45:00	\N	\N	0	0	\N	\N
292136	MISSION	AUCUNE	\N	MINEURSENF	\N	audition plénière	\N	2018-06-27 15:05:00	2018-06-27 18:20:00	2018-06-27 19:05:38	2018-06-28 10:16:17	6	0	\N	\N
296082	DELEGATION	AUDRAP	\N	\N	206	Audition "Planète Mars" du Centre national d'études spatiales (CNES)	Audition "Planète Mars" du Centre national d'études spatiales (CNES)	2018-07-12 15:30:00	2018-07-12 16:30:00	\N	\N	1	0	\N	\N
300645	DELEGATION	DEPLACEMENT	\N	\N	206	Déplacement à Bruxelles (étude risques sanitaires et environnementaux)	Déplacement à Bruxelles (étude risques sanitaires et environnementaux, auditions Commission européenne	2018-07-11 07:55:00	2018-07-12 14:30:00	\N	\N	2	0	\N	\N
300660	GIA	AUCUNE	\N	\N	\N	Petit-déjeuner	Petit-déjeuner d'accueil de l'ambassadeur du Pakistan	2018-07-18 08:30:00	2018-07-18 09:30:00	\N	\N	6	0	619	\N
305400	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PROG Programmation 2018-2022 et réforme pour la justice	\N	2018-09-04 14:30:00	2018-09-04 18:30:00	\N	\N	5	0	\N	\N
305406	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PROG Programmation 2018-2022 et réforme pour la justice	\N	2018-09-05 09:00:00	2018-09-05 12:10:00	\N	\N	5	0	\N	\N
321851	GIA	AUCUNE	\N	\N	\N	Entretien avec Fabrice BALANCHE	Entretien avec Fabrice BALANCHE	2018-11-07 08:30:00	2018-11-07 09:30:00	\N	\N	5	0	644	\N
321857	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	PLF 2019 - Avis budgétaire Logement	2018-11-14 14:35:00	2018-11-14 15:30:00	\N	\N	1	0	\N	\N
329326	COM_PERMANENTE	DEPLACEMENT	\N	AFCL	\N	Déplacement à Londres	Déplacement à Londres	2018-11-27 08:00:00	2018-11-27 22:00:00	\N	\N	1	0	\N	\N
342791	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	GT ruralités : Table ronde assos élus "Etat des lieux ruralités et politiques publiques"	\N	2019-01-23 16:00:00	2019-01-23 18:00:00	\N	\N	9	0	\N	\N
342817	DELEGATION	AUCUNE	\N	\N	COLTER	Audition représentants AITF et SNDGCT (simplification des normes)	\N	2019-01-24 10:00:00	2019-01-24 11:00:00	2019-01-24 14:33:37	2019-01-24 18:27:39	10	0	\N	\N
345309	MISSION	AUCUNE	\N	INFRACTIONS	\N	Auditions Ministère de l'éducation nationale - Association Notre parole aussi libérée	Auditions Ministère de l'éducation nationale - Association Notre parole aussi libérée	2019-01-29 16:30:00	2019-01-29 19:45:00	2019-01-30 10:50:03	2019-01-30 14:48:11	10	0	\N	\N
345310	MISSION	AUCUNE	\N	INFRACTIONS	\N	Auditions "Collosse aux pieds d'argile" et "Apprentis d'Auteuil"	Auditions "Collosse aux pieds d'argile" et "Apprentis d'Auteuil"	2019-01-31 11:00:00	2019-01-31 13:10:00	2019-01-31 13:12:43	2019-01-31 18:32:21	10	0	\N	\N
345316	DELEGATION	AUDRAP	\N	\N	PROS	Audition de l'Association des maires ruraux de France	\N	2019-02-12 09:00:00	2019-02-12 10:00:00	\N	\N	2	0	\N	\N
345317	DELEGATION	AUDRAP	\N	\N	PROS	Audition de l'Assemblée des Communautés de France	\N	2019-02-05 09:00:00	2019-02-05 10:00:00	\N	\N	1	0	\N	\N
345318	DELEGATION	AUDRAP	\N	\N	PROS	Audition de la Mairie de Paris	Audition de Célia Blauel, adjointe à la Maire de Paris, chargée des questions relatives à la transition écologique	2019-02-13 16:00:00	2019-02-13 17:00:00	\N	\N	2	0	\N	\N
346843	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe	Assemblée générale du groupe	2019-01-30 13:30:00	2019-01-30 14:30:00	\N	\N	10	0	578	\N
350217	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Cour des comptes	Débat	2019-02-07 10:30:00	2019-02-07 11:35:00	\N	\N	109	0	\N	\N
355024	GIA	AUCUNE	\N	\N	\N	Réunion des membres du Bureau du groupe	Réunion des membres du Bureau du groupe	2019-02-19 17:45:00	2019-02-19 18:30:00	\N	\N	8	0	598	\N
361589	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Jo	\N	2019-03-14 10:00:00	2019-03-14 11:15:00	\N	\N	3	0	\N	\N
361593	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Jordanie	\N	2019-03-14 11:45:00	2019-03-14 13:00:00	\N	\N	4	0	\N	\N
361598	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Jordanie	\N	2019-03-14 15:00:00	2019-03-14 16:15:00	\N	\N	4	0	\N	\N
361603	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL CAMO	\N	2019-03-14 18:00:00	2019-03-14 19:15:00	\N	\N	2	0	\N	\N
365231	DELEGATION	AUCUNE	\N	\N	PROS	Audition	Audition de M. Guillaume Benoît, Ingénieur général des ponts, des eaux et des forêts, membre du CGAAER	2019-04-11 08:30:00	2019-04-11 09:45:00	\N	\N	12	0	\N	\N
365637	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-03-27 09:35:00	2019-03-27 10:55:00	2019-03-27 11:02:53	2019-03-27 17:53:33	34	0	\N	\N
365638	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-03-27 16:35:00	2019-03-27 18:40:00	2019-03-27 18:50:28	2019-03-28 10:23:40	18	0	\N	\N
366474	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GS EURO_PAC	GS EURO_PAC	2019-03-26 14:30:00	2019-03-26 16:00:00	\N	\N	11	0	\N	\N
367374	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Système de santé	\N	2019-03-26 14:30:00	2019-03-26 18:30:00	\N	\N	6	0	\N	\N
367376	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Système de santé	\N	2019-03-27 14:30:00	2019-03-27 17:45:00	\N	\N	7	0	\N	\N
367378	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Système de santé	\N	2019-04-02 17:30:00	2019-04-02 18:15:00	\N	\N	1	0	\N	\N
367380	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Système de santé	\N	2019-04-03 14:30:00	2019-04-03 17:00:00	\N	\N	1	0	\N	\N
367382	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Système de santé	\N	2019-04-04 09:30:00	2019-04-04 11:15:00	\N	\N	1	0	\N	\N
367384	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Système de santé	\N	2019-04-09 15:00:00	2019-04-09 18:00:00	\N	\N	19	0	\N	\N
367386	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Système de santé	\N	2019-04-10 14:00:00	2019-04-10 16:30:00	\N	\N	1	0	\N	\N
367388	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Système de santé	\N	2019-04-11 08:30:00	2019-04-11 12:00:00	\N	\N	13	0	\N	\N
371674	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2019-03-13 14:30:00	2019-03-13 16:45:00	\N	\N	2	0	\N	\N
371837	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PPL Résiliation des contrats de complémentaire santé	\N	2019-05-02 14:00:00	2019-05-02 14:05:00	2019-05-02 14:11:33	2019-05-02 14:31:25	18	1	\N	\N
369086	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PPL Résiliation des contrats de complémentaire santé	\N	2019-04-10 09:00:00	2019-04-10 10:35:00	2019-04-10 12:08:58	2019-04-10 16:51:03	45	0	\N	\N
372232	MISSION	AUCUNE	\N	BREXIT2	\N	Audition M. Potier	\N	2019-04-10 15:35:00	2019-04-10 16:40:00	2019-04-10 17:13:21	2019-04-10 17:15:19	7	0	\N	\N
373182	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	Contrôle des comptes	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne	2019-04-10 18:00:00	2019-04-10 19:40:00	2019-04-11 15:58:59	2019-04-11 16:48:29	4	0	\N	\N
373465	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2019-03-27 14:30:00	2019-03-27 16:45:00	\N	\N	3	0	\N	\N
373577	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2019-04-10 14:30:00	2019-04-10 15:30:00	\N	\N	0	0	\N	\N
373578	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2019-04-09 14:30:00	2019-04-09 15:30:00	\N	\N	3	0	\N	\N
373583	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	santé au travail	santé au travail	2019-04-09 15:30:00	2019-04-09 16:15:00	\N	\N	3	0	\N	\N
373587	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Santé au travail	Santé au travail	2019-04-10 14:30:00	2019-04-10 15:30:00	\N	\N	2	0	\N	\N
373590	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Colombie	\N	2019-04-09 15:00:00	2019-04-09 16:00:00	\N	\N	3	0	\N	\N
373594	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI mission innovation et défense	\N	2019-04-09 14:30:00	2019-04-09 17:00:00	\N	\N	1	0	\N	\N
373601	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2019-04-10 14:30:00	2019-04-10 16:15:00	\N	\N	3	0	\N	\N
373605	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Le numérique à l'école - Directeur du numérique pour l'éducation	Contrôle 2019 - Le numérique à l'école - Directeur du numérique pour l'éducation	2019-04-09 10:00:00	2019-04-09 11:00:00	\N	\N	2	0	\N	\N
373608	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Gestion RH ministère des armées - Directeur des personnels de la Marine	Contrôle 2019 - Gestion RH ministère des armées - Directeur des personnels de la Marine	2019-04-10 14:30:00	2019-04-10 16:10:00	\N	\N	1	0	\N	\N
373610	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Gestion RH ministère des armées - DRHAT	Contrôle 2019 - Gestion RH ministère des armées - DRHAT	2019-04-09 17:30:00	2019-04-09 19:00:00	\N	\N	1	0	\N	\N
373612	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Évaluation transformation ISF en IFI et création PFU -	Contrôle 2019 - Évaluation transformation ISF en IFI et création PFU	2019-04-09 09:25:00	2019-04-09 10:15:00	\N	\N	2	0	\N	\N
373615	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Évaluation transformation ISF en IFI et création PFU - METI	 \tContrôle 2019 - Évaluation transformation ISF en IFI et création PFU - METI	2019-04-09 18:00:00	2019-04-09 19:20:00	\N	\N	2	0	\N	\N
373618	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - APD - AFD	PLF pour 2020 - APD - AFD	2019-04-10 14:00:00	2019-04-10 15:00:00	\N	\N	2	0	\N	\N
216249	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Echange de vues sur le programme de travail de la délégation aux entreprises	Echange de vues sur le programme de travail de la délégation aux entreprises	2017-11-09 09:00:00	2017-11-09 10:25:00	2017-11-09 16:06:34	2017-11-09 16:33:22	22	0	\N	\N
219184	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2018 (Avis Immigration et Sécurités)	\N	2017-11-15 14:30:00	2017-11-15 15:45:00	\N	\N	3	0	\N	\N
232790	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe	Assemblée générale du groupe	2017-12-14 14:00:00	2017-12-14 14:30:00	\N	\N	4	0	626	\N
232807	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2018-01-09 14:30:00	2018-01-09 17:30:00	\N	\N	1	0	\N	\N
232809	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2018-01-10 09:30:00	2018-01-10 15:30:00	\N	\N	1	0	\N	\N
232811	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2018-01-11 09:30:00	2018-01-11 10:30:00	\N	\N	1	0	\N	\N
232813	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Orientation et réussite des étudiants	PJL Orientation et réussite des étudiants	2017-12-21 09:30:00	2017-12-21 11:30:00	\N	\N	1	0	\N	\N
232815	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe	Assemblée générale du groupe	2017-12-19 13:45:00	2017-12-19 14:15:00	\N	\N	10	0	620	\N
232826	GIA	AUCUNE	\N	\N	\N	France-Pays du Golfe	assemblée générale	2017-12-20 14:30:00	2017-12-20 15:00:00	\N	\N	10	0	661	\N
233005	GIA	AUCUNE	\N	\N	\N	Entretien avec S.E.M. Emil Druc, ambassadeur de Moldavie 	Entretien avec S.E.M. Emil Druc, ambassadeur de Moldavie en France	2018-01-08 15:30:00	2018-01-08 16:30:00	\N	\N	1	0	851	\N
233501	GIA	AUCUNE	\N	\N	\N	AG groupe d'amitié France-Espagne	Assemblée générale du groupe d'amitié France-Espagne	2018-01-16 14:00:00	2018-01-16 14:20:00	\N	\N	9	0	589	\N
235485	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI thanatopraxie	MI thanatopraxie	2018-01-18 11:00:00	2018-01-18 12:50:00	\N	\N	1	0	\N	\N
247062	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	Partenariat oriental	Partenariat oriental	2018-01-30 09:00:00	2018-01-30 12:00:00	\N	\N	1	0	\N	\N
247068	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe	Assemblée générale du groupe	2018-02-14 08:30:00	2018-02-14 09:15:00	\N	\N	5	0	647	\N
247248	GIA	AUCUNE	\N	\N	\N	Réunion du groupe 	Entretien avec le directeur de l'Asie au ministère de l'Europe et des Affaires étrangères	2018-02-15 13:30:00	2018-02-15 14:50:00	\N	\N	4	0	586	\N
260434	GIA	AUCUNE	\N	\N	\N	Entretien à la résidence de l'Ambassadeur du Cambodge	Entretien à la résidence de l'Ambassadeur du Cambodge	2018-03-28 12:00:00	2018-03-28 14:00:00	\N	\N	7	0	577	\N
270085	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	LPM 2019-2025	\N	2018-04-18 08:00:00	2018-04-18 09:15:00	\N	\N	2	0	\N	\N
270088	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	LPM 2019-2025	\N	2018-04-19 14:00:00	2018-04-19 15:30:00	\N	\N	2	0	\N	\N
272936	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Retraites agricoles	PPL Retraites agricoles	2018-05-16 21:30:00	2018-05-16 23:00:00	\N	\N	89	0	\N	\N
275134	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2018-05-30 09:30:00	2018-05-30 12:40:00	2018-05-30 15:14:39	2018-05-30 15:48:45	38	0	\N	\N
276038	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	901	\N	\N	Explications de vote sur l'ensemble - PJL Programmation militaire	Explications de vote sur l'ensemble - PJL Programmation militaire	2018-05-29 15:00:00	2018-05-29 15:55:00	\N	\N	317	0	\N	\N
276039	SEANCE_PLENIERE	SCRUSOL	901	\N	\N	Scrutin solennel - PJL Programmation militaire	Scrutin solennel - PJL Programmation militaire	2018-05-29 16:00:00	2018-05-29 16:30:00	\N	\N	0	0	\N	\N
279263	DELEGATION	AUCUNE	\N	\N	COLTER	Audition Alain RICHARD - Rapport fiscalité locale	\N	2018-06-14 08:30:00	2018-06-14 10:10:00	2018-06-14 11:13:39	2018-06-14 12:05:01	21	0	\N	\N
279265	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	GT statut de l'élu : réunion de coordination des rapporteurs	\N	2018-06-14 10:30:00	2018-06-14 12:00:00	\N	\N	2	0	\N	\N
282419	ETUDES	AUCUNE	\N	\N	\N	Audition de Franck TERNER directeur général d'Air France	Audition de Franck TERNER directeur général d'Air France	2018-06-07 08:30:00	2018-06-07 10:30:00	\N	\N	15	0	\N	933
282435	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLO PPL Fausses informations	PPLO PPL Fausses informations	2018-06-07 17:00:00	2018-06-07 18:30:00	\N	\N	2	0	\N	\N
282438	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLO PPL Fausses informations	PPLO PPL Fausses informations	2018-06-07 18:30:00	2018-06-07 20:15:00	\N	\N	1	0	\N	\N
282693	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2018-06-13 11:05:00	2018-06-13 13:20:00	2018-06-13 19:53:08	2018-06-14 09:50:17	44	0	\N	\N
283418	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2018-06-12 14:55:00	2018-06-12 16:40:00	\N	\N	3	0	\N	\N
284941	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Examen du RI fonction publique 	Examen du RI fonction publique 	2018-06-13 11:09:00	2018-06-13 12:30:00	2018-06-13 17:11:18	2018-06-13 17:23:51	28	0	\N	\N
285008	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL ELAN	\N	2018-06-05 09:30:00	2018-06-05 11:15:00	\N	\N	1	0	\N	\N
285010	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL ELAN	\N	2018-06-05 16:15:00	2018-06-05 18:00:00	\N	\N	1	0	\N	\N
285013	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL ELAN	\N	2018-06-12 09:30:00	2018-06-12 10:00:00	\N	\N	1	0	\N	\N
285017	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL ELAN	\N	2018-06-12 14:00:00	2018-06-12 16:40:00	\N	\N	1	0	\N	\N
285096	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL ELAN	\N	2018-06-13 08:45:00	2018-06-13 09:45:00	\N	\N	1	0	\N	\N
285098	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL ELAN	\N	2018-06-13 14:30:00	2018-06-13 15:15:00	\N	\N	1	0	\N	\N
285101	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL ELAN	\N	2018-06-13 15:15:00	2018-06-13 16:00:00	\N	\N	2	0	\N	\N
285104	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL ELAN	\N	2018-06-13 16:00:00	2018-06-13 17:00:00	\N	\N	1	0	\N	\N
285674	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Centres-villes	PPL Centres-villes	2018-06-14 12:00:00	2018-06-14 13:05:00	\N	\N	64	0	\N	\N
286280	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL ELAN	PJL ELAN	2018-06-13 16:10:00	2018-06-13 17:15:00	\N	\N	1	0	\N	\N
286282	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL ELAN	PJL ELAN	2018-06-14 10:00:00	2018-06-14 10:20:00	\N	\N	1	0	\N	\N
286284	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Fraude - CNB	PJL Fraude - Conseil National des Barraux	2018-06-15 11:00:00	2018-06-15 12:30:00	\N	\N	3	0	\N	\N
286285	GIA	AUCUNE	\N	\N	\N	Petit-déjeuner JL LEVET	Petit-déjeuner autour de J-L LEVET, haut responsable à la coopération technologique et industrielle franco-algérienne	2018-06-13 08:30:00	2018-06-13 09:30:00	\N	\N	7	0	575	\N
286296	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Fraude - PNF	PJL Fraude - Parquet National Financier	2018-06-15 15:00:00	2018-06-15 16:15:00	\N	\N	3	0	\N	\N
286300	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Fraude - CNIL	PJL Fraude - CNIL	2018-06-15 16:15:00	2018-06-15 17:30:00	\N	\N	3	0	\N	\N
286322	GIA	AUCUNE	\N	\N	\N	anniversaire Dalaï Lama  à l'AN (Bureau du Tibet)	anniversaire Dalaï Lama  à l'AN (Bureau du Tibet)	2018-07-06 16:30:00	2018-07-06 18:00:00	\N	\N	0	0	634	\N
286323	GIA	AUCUNE	\N	\N	\N	déjeuner ICT - Réciptrocité relations avevc la Chine	déjeuner ICT - Réciptrocité relations avevc la Chine	2018-06-21 08:30:00	2018-06-21 10:00:00	\N	\N	3	0	634	\N
287603	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	Partenariat oriental	Audition de M. Rahman MUSTAFAYEV, ambassadeur d'Azerbaïdjan en France	2018-06-19 15:00:00	2018-06-19 16:35:00	\N	\N	3	0	\N	\N
287620	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PJL pour la liberté de choisir son avenir professionnel	PJL pour la liberté de choisir son avenir professionnel	2018-06-27 14:00:00	2018-06-27 15:35:00	2018-06-27 15:49:41	2018-06-27 16:02:49	33	2	\N	\N
287632	MISSION	PLEIN_NON_JO	\N	BREXIT2	\N	Présentation Rapport suivi recommandations refondation	Présentation Rapport suivi recommandations refondation	2018-06-20 15:05:00	2018-06-20 16:25:00	\N	\N	12	0	\N	\N
287928	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLO et PPL Lutte contre les fausses informations	\N	2018-06-20 14:30:00	2018-06-20 15:15:00	\N	\N	1	0	\N	\N
287930	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLO et PPL Lutte contre les fausses informations	\N	2018-06-20 16:15:00	2018-06-20 17:40:00	\N	\N	1	0	\N	\N
287977	GIA	AUCUNE	\N	\N	\N	Petit déjeuner avec l'Ambassadeur	Petit déjeuner avec l'Ambassadeur	2018-06-21 08:30:00	2018-06-21 09:30:00	\N	\N	4	0	579	\N
292921	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2018-06-27 15:30:00	2018-06-27 18:30:00	\N	\N	3	0	\N	\N
292925	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2018-06-28 12:15:00	2018-06-28 12:45:00	\N	\N	3	0	\N	\N
303838	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	DSOM	Conférence de presse - Risques naturels majeurs outre-mer	Conférence de presse - Risques naturels majeurs outre-mer	2018-07-24 14:30:00	2018-07-24 16:00:00	\N	\N	5	0	\N	\N
305267	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PROG Programmation 2018-2022 et réforme pour la justice	PJL/PPLO Programmation et organisation Justice	2018-07-25 14:30:00	2018-07-25 15:00:00	\N	\N	1	0	\N	\N
305269	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PROG Programmation 2018-2022 et réforme pour la justice	PJL/PPLO Programmation et organisation Justice	2018-07-25 16:45:00	2018-07-25 18:45:00	\N	\N	1	0	\N	\N
305271	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PROG Programmation 2018-2022 et réforme pour la justice	PJL/PPLO Programmation et organisation Justice	2018-07-26 09:00:00	2018-07-26 10:45:00	\N	\N	1	0	\N	\N
305273	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PROG Programmation 2018-2022 et réforme pour la justice	PJL/PPLO Programmation et organisation Justice	2018-07-26 14:30:00	2018-07-26 18:30:00	\N	\N	2	0	\N	\N
307097	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Pierre NGOLO, Président du Sénat de la République du Congo Brazaville	Entretien avec M. Pierre NGOLO, Président du Sénat de la République du Congo Brazaville	2018-09-26 15:00:00	2018-09-26 16:30:00	\N	\N	4	0	572	\N
307102	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Michel GBEZERA-BRIA, ambassadeur de la République Centrafricaine	Entretien avec M. Michel GBEZERA-BRIA, ambassadeur de la République Centrafricaine	2018-09-27 10:30:00	2018-09-27 11:30:00	\N	\N	1	0	572	\N
310746	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 11 octobre 2018	Réunion du 11 octobre 2018	2018-10-11 09:05:00	2018-10-11 09:50:00	2018-10-11 10:48:43	2018-10-11 16:04:56	16	0	\N	\N
344817	DELEGATION	AUDRAP	\N	\N	PROS	Audition de Françoise Coutant	Audition de Françoise Coutant, vice-présidente Région Nouvelle Aquitaine	2019-02-21 14:30:00	2019-02-21 15:30:00	\N	\N	2	0	\N	\N
345600	GIA	AUCUNE	\N	\N	\N	Dîner	Dîner-commentaire du dernier déplacement du  Groupe Interparlementaire d'Amitié France-Roumanie	2019-01-15 19:30:00	2019-01-15 22:00:00	\N	\N	6	0	605	\N
347128	GIA	AUCUNE	\N	\N	\N	Assemblée générale du GIA France-Irak	\N	2019-01-30 12:45:00	2019-01-30 14:00:00	\N	\N	4	0	615	\N
347224	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Turquie	\N	2019-01-30 08:30:00	2019-01-30 09:25:00	\N	\N	3	0	\N	\N
350774	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2018-12-12 14:45:00	2018-12-12 16:35:00	\N	\N	3	0	\N	\N
361710	ETUDES	AUCUNE	\N	\N	\N	Audition du groupe CMA-CGM 	Audition du groupe CMA-CGM	2019-03-13 08:30:00	2019-03-13 09:30:00	\N	\N	13	0	\N	908
362038	COM_EURO	CONTROLE	\N	AFEU	\N	\N	\N	2019-03-19 15:00:00	2019-03-19 16:25:00	2019-03-19 17:13:00	2019-03-19 17:43:26	21	0	\N	\N
367007	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-04-03 09:00:00	2019-04-03 11:30:00	2019-04-03 12:14:59	2019-04-03 15:04:15	27	0	\N	\N
367118	DELEGATION	AUCUNE	\N	\N	211	Audition de Mme Laura Georges, SG de la Fédération française de football	Audition de Mme Laura Georges, SG de la Fédération française de football	2019-03-28 09:00:00	2019-03-28 10:30:00	\N	\N	4	0	\N	\N
367274	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI mission défense européenne	\N	2019-03-26 15:30:00	2019-03-26 16:30:00	\N	\N	2	0	\N	\N
367279	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI mission défense européenne	\N	2019-03-26 18:00:00	2019-03-26 19:00:00	\N	\N	0	0	\N	\N
367302	COM_PERMANENTE	GROUPE_TRAVAIL	\N	ETRD	\N	Négociations commerciales	\N	2019-03-27 16:00:00	2019-03-27 17:45:00	\N	\N	3	0	\N	\N
367313	GIA	AUCUNE	\N	\N	\N	Visio-conférence avec l'Ecole française d'extrème-orient de Siem Reap	Visio-conférence avec l'Ecole française d'extrème-orient de Siem Reap	2019-04-03 08:30:00	2019-04-03 09:30:00	\N	\N	4	0	577	\N
370807	DELEGATION	AUDRAP	\N	\N	COLTER	Déplacement à Dreux - Le rôle des communes dans les intercommunalités : audition M. HAMEL	Rencontre avec M. Gérard Hamel, Président de l¿intercommunalité	2019-03-06 14:30:00	2019-03-06 15:30:00	\N	\N	1	0	\N	\N
370810	DELEGATION	AUDRAP	\N	\N	COLTER	Déplacement à Dreux : le rôle des communes dans les intercommunalités - Table ronde	Déplacement à Dreux : le rôle des communes dans les intercommunalités - Table ronde avec des maires et élus municipaux	2019-03-06 15:30:00	2019-03-06 16:30:00	\N	\N	1	0	\N	\N
370813	DELEGATION	DEPLACEMENT	\N	\N	COLTER	Déplacement à Reims : Le rôle des communes dans les intercommunalités	Déplacement à Reims : Le rôle des communes dans les intercommunalités	2019-04-05 11:45:00	2019-04-05 18:30:00	\N	\N	1	0	\N	\N
370816	DELEGATION	AUDRAP	\N	\N	COLTER	Déplacement à Reims : Le rôle des communes dans les intercommunalités - Table ronde	Déplacement à Reims : Le rôle des communes dans les intercommunalités - Rencontre avec des maires et élus municipaux	2019-04-05 14:00:00	2019-04-05 16:00:00	\N	\N	1	0	\N	\N
370853	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPRA Contrôle de l'application et de l'évaluation des lois	PPRA Contrôle de l'application et de l'évaluation des lois	2019-04-02 17:00:00	2019-04-02 17:30:00	\N	\N	1	0	\N	\N
370855	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPRA Contrôle de l'application et de l'évaluation des lois	PPRA Contrôle de l'application et de l'évaluation des lois	2019-04-02 19:15:00	2019-04-02 19:45:00	\N	\N	2	0	\N	\N
370858	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPRA Contrôle de l'application et de l'évaluation des lois	PPRA Contrôle de l'application et de l'évaluation des lois	2019-04-03 11:30:00	2019-04-03 12:00:00	\N	\N	1	0	\N	\N
370860	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPRA Contrôle de l'application et de l'évaluation des lois	PPRA Contrôle de l'application et de l'évaluation des lois	2019-04-03 12:00:00	2019-04-03 13:00:00	\N	\N	2	0	\N	\N
370863	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPRA Contrôle de l'application et de l'évaluation des lois	PPRA Contrôle de l'application et de l'évaluation des lois	2019-04-03 14:00:00	2019-04-03 14:30:00	\N	\N	2	0	\N	\N
370866	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPRA Contrôle de l'application et de l'évaluation des lois	PPRA Contrôle de l'application et de l'évaluation des lois	2019-04-04 08:00:00	2019-04-04 08:45:00	\N	\N	2	0	\N	\N
370869	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPRA Contrôle de l'application et de l'évaluation des lois	PPRA Contrôle de l'application et de l'évaluation des lois	2019-04-04 10:30:00	2019-04-04 12:15:00	\N	\N	1	0	\N	\N
370871	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPRA Contrôle de l'application et de l'évaluation des lois	PPRA Contrôle de l'application et de l'évaluation des lois	2019-04-04 12:15:00	2019-04-04 13:30:00	\N	\N	2	0	\N	\N
370874	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPRA Contrôle de l'application et de l'évaluation des lois	PPRA Contrôle de l'application et de l'évaluation des lois	2019-04-04 13:30:00	2019-04-04 14:00:00	\N	\N	1	0	\N	\N
370926	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	Déplacement dans le département de la Seine-et-Marne	Mission d'information sur la Sécurité des ponts - Déplacement dans le département de la Seine-ert-Marne	2019-04-08 08:15:00	2019-04-08 16:00:00	\N	\N	3	0	\N	\N
371199	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2019-04-03 14:50:00	2019-04-03 18:05:00	\N	\N	3	0	\N	\N
371203	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI mission défense européenne	\N	2019-04-02 17:00:00	2019-04-02 18:00:00	\N	\N	2	0	\N	\N
371473	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2019-05-14 09:30:00	2019-05-14 12:40:00	\N	\N	42	0	\N	\N
371823	COM_PERMANENTE	DEPLACEMENT	\N	SOCI	\N	\N	\N	2019-04-09 15:30:00	2019-04-09 17:00:00	\N	\N	2	0	\N	\N
372868	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Modernisation de la distribution de la presse	PJL Modernisation de la distribution de la presse	2019-04-11 11:00:00	2019-04-11 12:30:00	\N	\N	2	0	\N	\N
372869	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Modernisation de la distribution de la presse	PJL Modernisation de la distribution de la presse	2019-04-11 14:00:00	2019-04-11 15:00:00	\N	\N	2	0	\N	\N
372871	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Réforme de l'audiovisuel	Réforme de l'audiovisuel	2019-04-10 14:30:00	2019-04-10 16:30:00	\N	\N	1	0	\N	\N
373553	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Modernisation de la distribution de la presse	PJL Modernisation de la distribution de la presse	2019-04-11 16:15:00	2019-04-11 17:15:00	\N	\N	2	0	\N	\N
373556	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Modernisation de la distribution de la presse	PJL Modernisation de la distribution de la presse	2019-04-11 17:15:00	2019-04-11 18:15:00	\N	\N	3	0	\N	\N
214627	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2018 - Avis budgétaire "Fonction publique"	\N	2017-11-06 11:00:00	2017-11-06 12:30:00	\N	\N	1	0	\N	\N
214629	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2018 - Avis budgétaire "Fonction publique"	\N	2017-11-06 14:00:00	2017-11-06 19:30:00	\N	\N	1	0	\N	\N
217247	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Recherche et Enseignement supérieur	PLF pour 2018 - Recherche et Enseignement supérieur - INRA	2017-11-07 10:00:00	2017-11-07 11:00:00	\N	\N	1	0	\N	\N
217249	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Recherche et Enseignement supérieur	PLF pour 2018 - Recherche et Enseignement supérieur - CEA	2017-11-07 13:30:00	2017-11-07 14:30:00	\N	\N	1	0	\N	\N
217251	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Recherche et Enseignement supérieur	PLF pour 2018 - Recherche et Enseignement supérieur - CGE	2017-11-08 18:00:00	2017-11-08 19:10:00	\N	\N	1	0	\N	\N
217255	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Recherche et Enseignement supérieur	PLF pour 2018 - Recherche et Enseignement supérieur - FESIC	2017-11-09 13:45:00	2017-11-09 14:30:00	\N	\N	1	0	\N	\N
217293	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2018  - programme 105	\N	2017-11-07 15:00:00	2017-11-07 16:00:00	\N	\N	2	0	\N	\N
217296	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2018 - programme 178	\N	2017-11-08 14:00:00	2017-11-08 15:00:00	\N	\N	2	0	\N	\N
217299	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2018 - programme 178	\N	2017-11-08 15:45:00	2017-11-08 18:00:00	\N	\N	2	0	\N	\N
217308	CMP	AUTRE	\N	PLFR2017	\N	PLFR pour 2017	PLFR pour 2017	2017-11-10 09:05:00	2017-11-10 09:10:00	\N	\N	8	0	\N	\N
217504	COM_PERMANENTE	DEPLACEMENT	\N	CDD	\N	COP23	Déplacement d'une délégation de la commission à la Conférence des parties sur le changement climatique (COP23)	2017-11-12 08:00:00	2017-11-15 22:00:00	\N	\N	4	0	\N	\N
221326	COM_EURO	DEPLACEMENT	\N	AFEU	\N	\N	Forum franco-allemand sur l'avenir de l'Europe - Berlin, le 23 novembre 2017	2017-11-23 09:00:00	2017-11-23 22:00:00	\N	\N	1	0	\N	\N
221353	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Réhabiliter la police de proximité	\N	2017-11-21 16:30:00	2017-11-21 17:20:00	\N	\N	1	0	\N	\N
222534	COM_PERMANENTE	AUTRE	\N	LOIS	\N	\N	Copmmunication de M. Simon Sutour	2017-11-22 09:10:00	2017-11-22 09:25:00	2017-11-23 14:47:49	2017-11-23 14:50:24	45	0	\N	\N
222880	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Contrôle et exploitation aériens 	PLF pour 2018 - Contrôle et exploitation aériens - GIFAS	2017-11-20 12:30:00	2017-11-20 14:00:00	\N	\N	1	0	\N	\N
222882	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2018 - Contrôle et exploitation aériens 	PLF pour 2018 - Contrôle et exploitation aériens - Air France KLM	2017-11-20 17:00:00	2017-11-20 18:00:00	\N	\N	1	0	\N	\N
231070	GIA	AUCUNE	\N	\N	\N	groupe d'amitié France-Nouvelle-Zélande	assemblée générale du groupe d'amitié France-Nouvelle-Zélande	2017-12-19 14:00:00	2017-12-19 14:45:00	\N	\N	9	0	663	\N
231091	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion	Réunion	2017-12-20 10:00:00	2017-12-20 12:15:00	2017-12-20 12:23:04	2017-12-20 16:19:34	35	0	\N	\N
236159	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe	\N	2018-01-17 17:00:00	2018-01-17 17:30:00	\N	\N	20	0	621	\N
237866	COM_SPECIALE	PLENIERE	\N	ETAT	\N	\N	PJL  pour un Etat au service d'une société de confiance	2018-01-24 13:40:00	2018-01-24 14:10:00	2018-01-24 15:22:51	2018-01-24 16:17:53	21	0	\N	\N
237998	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Régime d'ouverture des établissements privés hors contrat	PPL Régime d'ouverture des établissements privés hors contrat	2018-01-24 14:30:00	2018-01-24 15:30:00	\N	\N	4	0	\N	\N
244598	GIA	AUCUNE	\N	\N	\N	entretien avec SE M. CHOI Jongmoon, ambassadeur de Corée du Sud	entretien avec SE M. CHOI Jongmoon, ambassadeur de Corée du Sud	2018-02-13 08:30:00	2018-02-13 10:00:00	\N	\N	1	0	613	\N
247134	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Anciens combattants - CIVS - 2018	Contrôle Anciens combattants - CIVS - 2018 - Audition Rapporteur CIVS	2018-02-13 15:00:00	2018-02-13 17:30:00	\N	\N	1	0	\N	\N
247138	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Anciens combattants - CIVS - 2018	Contrôle Anciens combattants - CIVS - 2018 - Audition François Croquette ambassadeur pour droits de l'homme	2018-02-14 09:45:00	2018-02-14 11:00:00	\N	\N	1	0	\N	\N
247143	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Anciens combattants - CIVS - 2018	Contrôle Anciens combattants - CIVS - 2018 - Audition directeur de l'OCBC	2018-02-15 14:00:00	2018-02-15 15:00:00	\N	\N	1	0	\N	\N
247149	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Mission "Routes de la soie"	\N	2018-02-13 14:15:00	2018-02-13 16:35:00	\N	\N	4	0	\N	\N
247154	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Mission "Routes de la soie"	\N	2018-02-14 08:20:00	2018-02-14 09:35:00	\N	\N	3	0	\N	\N
250072	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2018-03-07 16:05:00	2018-03-07 17:30:00	2018-03-07 17:48:32	2018-03-08 09:59:54	26	0	\N	\N
252860	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Défense 2018 - Disponibilité des hélicoptères	Contrôle Défense 2018 - Disponibilité des hélicoptères - SIAé	2018-03-08 09:30:00	2018-03-08 11:00:00	\N	\N	1	0	\N	\N
252877	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Affaires européennes	PLF pour 2019 - Affaires européennes - Audition ministère de l'Europe et des affaires étrangères	2018-03-07 14:00:00	2018-03-07 15:00:00	\N	\N	1	0	\N	\N
252935	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière en commun avec la Commission des affaires européennes	Réunion plénière en commun avec la Commission des affaires européennes	2018-03-08 09:05:00	2018-03-08 10:00:00	2018-03-08 18:41:37	2018-03-09 11:22:36	32	0	\N	\N
252979	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière du 8 mars 2018	Réunion plénière du 8 mars 2018 - PJL Essoc et Journée des entreprises	2018-03-08 10:00:00	2018-03-08 10:30:00	2018-03-08 18:55:39	2018-03-09 11:22:37	17	0	\N	\N
259000	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Protection des mineurs victimes d'infractions sexuelles - Examen admts de séance	\N	2018-03-27 09:05:00	2018-03-27 09:50:00	2018-03-27 10:24:48	2018-03-27 14:34:29	18	0	\N	\N
259018	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Ouverture concurrence	\N	2018-03-13 08:45:00	2018-03-13 11:00:00	\N	\N	0	0	\N	\N
259019	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Transport ferroviaire voyageurs	\N	2018-03-13 09:30:00	2018-03-13 11:00:00	\N	\N	1	0	\N	\N
259021	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Transport ferroviaire voyageurs	\N	2018-03-13 18:30:00	2018-03-13 19:30:00	\N	\N	1	0	\N	\N
259023	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Transport ferroviaire voyageurs	\N	2018-03-14 14:00:00	2018-03-14 18:45:00	\N	\N	1	0	\N	\N
259025	COM_PERMANENTE	AUDRAP	\N	CDD	\N	\N	\N	2018-03-14 15:30:00	2018-03-14 18:30:00	\N	\N	1	0	\N	\N
262822	DELEGATION	GROUPE_TRAVAIL	\N	\N	COLTER	GT statut de l'élu : table ronde régime social	\N	2018-04-04 16:30:00	2018-04-04 18:00:00	\N	\N	6	0	\N	\N
263133	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Conclusions de la CMP PJL Droit des contrats	Conclusions de la CMP PJL Droit des contrats	2018-04-11 14:30:00	2018-04-11 15:15:00	\N	\N	45	0	\N	\N
263146	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Élections représentants Parlement européen	PJL Élections représentants Parlement européen	2018-04-11 15:20:00	2018-04-11 17:30:00	\N	\N	96	0	\N	\N
304966	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de M. Christophe CASTANER	Audition de M. Christophe CASTANER	2018-07-31 08:05:00	2018-07-31 09:30:00	2018-07-31 14:58:19	2018-07-31 16:13:03	44	0	\N	\N
304982	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Amdt CMP PJL Violences sexuelles -  Exam texte et QP NL PJL Immigration	\N	2018-07-31 09:54:00	2018-07-31 10:25:00	2018-07-31 11:24:25	2018-07-31 12:16:16	20	0	\N	\N
217404	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF 2018 - Justice	PLF 2018 - Justice - Ministère du Budget	2017-11-08 18:00:00	2017-11-08 18:45:00	\N	\N	1	0	\N	\N
217782	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion	Réunion	2017-11-15 09:35:00	2017-11-15 11:45:00	2017-11-15 15:44:55	2017-11-15 16:15:17	41	1	\N	\N
305010	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion 20180731c - Dépouillemement vote article 13	Dépouillement vote article 13 - M. Jean-Raphël Alventosa	2018-07-31 14:15:00	2018-07-31 14:18:00	2018-07-31 14:25:20	2018-07-31 14:43:07	6	0	\N	\N
305011	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion 20180731d	\N	2018-07-31 16:00:00	2018-07-31 18:00:00	\N	\N	0	0	\N	\N
305012	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion 20180801	Réunion du 1er août 2018 - Premières conclusions affaire "Benalla"	2018-08-01 09:05:00	2018-08-01 09:50:00	2018-08-01 10:01:25	\N	10	0	\N	\N
305573	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2019 - "Justice" - Déplacement à Laon	PLF pour 2019 - "Justice" - Déplacement à Laon	2018-10-08 07:30:00	2018-10-08 20:00:00	\N	\N	1	0	\N	\N
306017	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	PROS	Débat sur les mobilités urbaines	Débat sur les mobilités urbaines	2018-10-10 14:30:00	2018-10-10 17:05:00	\N	\N	9	0	\N	\N
306058	DELEGATION	DEPLACEMENT	\N	\N	PROS	Déplacement à Berne (Suisse)	Rencontre avec les acteurs des transports et de la mobilité	2018-10-01 07:00:00	2018-10-01 22:00:00	\N	\N	2	0	\N	\N
307016	COM_EURO	DEPLACEMENT	\N	AFEU	\N	Réunion du Groupe de contrôle parlementaire conjoint d'Europol (GCPC)	Réunion du Groupe de contrôle parlementaire conjoint d'Europol (GCPC)	2018-09-24 08:00:00	2018-09-25 12:30:00	\N	\N	1	0	\N	\N
307028	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Coûts audiovisuel public - France Télévisions	Contrôle 2018 - Coûts audiovisuel public - France Télévisions	2018-09-26 17:30:00	2018-09-26 19:00:00	\N	\N	1	0	\N	\N
307048	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de M. Didier MIGAUD, président du CPO sur le rapport relatif aux taxes affectées	Audition de M. Didier MIGAUD, président du CPO sur le rapport relatif aux taxes affectées	2018-10-02 15:05:00	2018-10-02 16:15:00	2018-10-03 11:45:50	2018-10-03 15:16:40	33	0	\N	\N
307054	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition commune État et perspectives générosité en France - Contrôle Budget. Aides Pierre	Audition commune État et perspectives générosité en France - Contrôle Budgetaire Aides à la Pierre	2018-10-03 09:35:00	2018-10-03 12:30:00	2018-10-08 16:50:19	2018-10-08 16:50:31	38	0	\N	\N
307064	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2018-10-03 09:35:00	2018-10-03 11:35:00	2018-10-03 13:00:57	2018-10-03 15:16:37	38	0	\N	\N
309163	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	COM AFD	\N	2018-10-02 14:00:00	2018-10-02 15:00:00	\N	\N	2	0	\N	\N
309166	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2019 - Programme 185	\N	2018-10-02 14:30:00	2018-10-02 16:30:00	\N	\N	2	0	\N	\N
309169	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2019 - Programme 185	\N	2018-10-03 14:00:00	2018-10-03 16:00:00	\N	\N	2	0	\N	\N
344559	GIA	AUCUNE	\N	\N	\N	Audition de M. Khaled ISSA, représentant de l'auto administration du Nord-est de la Syrie	Audition de M. Khaled ISSA, représentant à Paris de l'auto administration du Nord-est de la Syrie	2019-01-23 08:15:00	2019-01-23 09:30:00	\N	\N	6	0	644	\N
345269	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Orientation des mobilités	\N	2019-01-23 14:00:00	2019-01-23 14:45:00	\N	\N	1	0	\N	\N
345271	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLO Modification du statut d'autonomie de la Polynésie française	\N	2019-01-17 10:00:00	2019-01-17 13:30:00	\N	\N	1	0	\N	\N
345273	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLO Modification du statut d'autonomie de la Polynésie française	\N	2019-01-23 15:30:00	2019-01-23 17:40:00	\N	\N	1	0	\N	\N
345275	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLO Modification du statut d'autonomie de la Polynésie française	\N	2019-01-24 18:30:00	2019-01-24 20:50:00	\N	\N	1	0	\N	\N
345782	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2019-01-23 19:30:00	2019-01-23 20:25:00	\N	\N	20	0	\N	\N
347424	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Jordanie	\N	2019-01-31 10:30:00	2019-01-31 11:45:00	\N	\N	3	0	\N	\N
347532	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2019-01-30 19:25:00	2019-01-30 20:15:00	\N	\N	2	0	\N	\N
347540	MISSION	AUCUNE	\N	BREXIT2	\N	\N	\N	2019-01-31 10:30:00	2019-01-31 12:00:00	2019-01-31 16:06:58	2019-01-31 18:32:21	12	0	\N	\N
347917	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI mission innovation et défense	\N	2019-01-30 14:00:00	2019-01-30 15:30:00	\N	\N	2	0	\N	\N
347920	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI mission innovation et défense	\N	2019-01-31 09:00:00	2019-01-31 12:25:00	\N	\N	2	0	\N	\N
350206	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Faciliter le désenclavement des territoires	PPL Faciliter le désenclavement des territoires - Audition d'un représentant de l'AMRF	2019-02-05 10:15:00	2019-02-05 11:00:00	\N	\N	1	0	\N	\N
350208	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions MI handicap fonction publique	\N	2019-02-05 14:30:00	2019-02-05 19:10:00	\N	\N	2	0	\N	\N
350211	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition MI handicap fonction publique	\N	2019-02-06 15:30:00	2019-02-06 16:45:00	\N	\N	1	0	\N	\N
350213	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-02-13 09:35:00	2019-02-13 11:25:00	2019-02-13 17:05:06	2019-02-14 11:05:35	39	0	\N	\N
350214	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Faciliter le désenclavement des territoires	PPL Faciliter le désenclavement des territoires - Audition de représentants de la DIT	2019-02-06 08:45:00	2019-02-06 09:30:00	\N	\N	1	0	\N	\N
350215	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-02-14 09:00:00	2019-02-14 10:55:00	2019-02-15 17:19:44	2019-02-15 17:21:33	46	0	\N	\N
350221	MISSION	AUTRE	\N	SIDERURGIE	\N	Réunion constitutive	\N	2019-02-06 13:40:00	2019-02-06 14:15:00	2019-02-07 12:26:31	2019-02-07 17:24:04	22	0	\N	\N
350340	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Faciliter le désenclavement des territoires	PPL Faciliter le désenclavement des territoires - Audition de représentants d'Air France	2019-02-06 13:30:00	2019-02-06 14:15:00	\N	\N	1	0	\N	\N
350391	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	PPL Démarchage téléphonique - Déplacement à Calais - Visite d'un centre d'appels	\N	2019-02-07 07:00:00	2019-02-07 14:30:00	\N	\N	1	0	\N	\N
352551	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 14 février 2019	Réunion du 14 février 2019	2019-02-14 09:05:00	2019-02-14 10:55:00	2019-02-15 11:45:25	2019-02-15 12:11:41	46	0	\N	\N
352641	GIA	AUCUNE	\N	\N	\N	Audition de S.E. M. Rami Adwan, Ambassadeur du Liban en France	Audition de S.E. M. Rami Adwan, Ambassadeur du Liban en France	2019-02-14 08:30:00	2019-02-14 09:45:00	\N	\N	8	0	597	\N
353689	ETUDES	AUCUNE	\N	\N	\N	Audition de l'association "Vin & société"	Audition de l'association "Vin & société"	2019-02-14 13:30:00	2019-02-14 14:45:00	\N	\N	11	0	\N	909
361767	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Création de l'Office français de la biodiversité	PJL Création de l'Office français de la biodiversité	2019-03-19 10:00:00	2019-03-19 11:00:00	\N	\N	2	0	\N	\N
361770	DELEGATION	AUCUNE	\N	\N	DSOM	Audition M. Walles Kotra, directeur exécutif en charge de l'outre-mer à France Télévisions	\N	2019-03-26 09:10:00	2019-03-26 10:30:00	2019-03-28 09:32:14	\N	6	0	\N	\N
361771	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Création de l'Office français de la biodiversité	PJL Création de l'Office français de la biodiversité	2019-03-19 09:00:00	2019-03-19 10:00:00	\N	\N	2	0	\N	\N
361776	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Création de l'Office français de la biodiversité	PJL Création de l'Office français de la biodiversité	2019-03-19 10:00:00	2019-03-19 11:00:00	\N	\N	2	0	\N	\N
362033	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition 	\N	2019-03-19 16:30:00	2019-03-19 19:30:00	2019-03-20 16:26:47	2019-03-20 17:30:19	111	0	\N	\N
362303	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-03-27 10:30:00	2019-03-27 11:45:00	2019-03-27 17:20:04	2019-03-27 17:53:31	38	0	\N	\N
363158	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2019-03-19 14:45:00	2019-03-19 17:25:00	\N	\N	3	0	\N	\N
363174	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Tables rondes et nomination rapporteur	\N	2019-03-27 09:00:00	2019-03-27 13:00:00	2019-03-27 13:02:17	2019-03-27 17:53:35	34	0	\N	\N
363183	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Système de santé	\N	2019-03-20 15:00:00	2019-03-20 18:00:00	\N	\N	12	0	\N	\N
363527	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Avenir institutionnel Alsace	PJL Avenir institutionnel Alsace	2019-04-04 21:30:00	2019-04-05 23:45:00	\N	\N	24	0	\N	\N
216828	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PLF pour 2018	\N	2017-11-14 17:55:00	2017-11-14 20:00:00	2017-11-15 14:15:29	2017-11-15 15:05:51	36	0	\N	\N
220048	DELEGATION	AUCUNE	\N	\N	DSOM	Programme de travail et audition Ministre des outre-mer	Programme de travail et audition Ministre des outre-mer	2017-11-23 09:00:00	2017-11-23 12:15:00	2017-11-23 13:58:14	2017-11-23 16:08:25	29	0	\N	\N
223289	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2017-11-28 09:00:00	2017-11-28 10:45:00	2017-11-28 10:49:36	2017-11-28 15:43:30	27	0	\N	\N
223292	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2017-11-30 09:00:00	2017-11-30 09:25:00	2017-11-30 09:27:56	2017-11-30 11:53:36	23	0	\N	\N
223384	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Mission "Routes de la soie"	\N	2017-11-22 08:15:00	2017-11-22 09:30:00	\N	\N	3	0	\N	\N
233208	COM_EURO	DEPLACEMENT	\N	AFEU	\N	Bruxelles - Rencontre avec des représentants des institutions européennes	Bruxelles - Rencontre avec des représentants des institutions européennes	2018-01-15 08:00:00	2018-01-16 12:35:00	\N	\N	6	0	\N	\N
242313	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT Evolution de la fiscalité locale - Analyse des scénarios visant à remplacer la TH	GT Evolution de la fiscalité locale	2018-02-06 15:00:00	2018-02-06 16:10:00	\N	\N	9	0	\N	\N
246133	DELEGATION	AUCUNE	\N	\N	DSOM	Audition CESE "violences contre les femmes dans les outre-mer	Audition CESE "violences contre les femmes dans les outre-mer	2018-02-15 08:30:00	2018-02-15 11:00:00	2018-02-15 12:26:23	2018-02-15 14:17:16	22	0	\N	\N
249105	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition cycle de vie des entreprises	Audition cycle de vie des entreprises - Institut de la Protection Sociale	2018-02-21 14:40:00	2018-02-21 15:25:00	\N	\N	1	0	\N	\N
249107	DELEGATION	DEPLACEMENT	\N	\N	ENTREPRISES	Déplacement en Savoie	Déplacement en Savoie	2018-02-12 06:30:00	2018-02-12 21:20:00	\N	\N	8	0	\N	\N
250144	GIA	AUCUNE	\N	\N	\N	Entretien avec S.E. M. Walter GRAHAMMER, Ambassadeur d¿Autriche en France	Entretien avec S.E. M. Walter GRAHAMMER, Ambassadeur d¿Autriche en France	2018-02-20 12:30:00	2018-02-20 14:30:00	\N	\N	16	0	579	\N
250237	GIA	AUCUNE	\N	\N	\N	AG France Belgique/Luxemebourg	Assemblée générale reconstitutive	2018-01-17 08:30:00	2018-01-17 09:30:00	\N	\N	14	0	580	\N
250298	DELEGATION	AUDRAP	\N	\N	PROS	Audition de la FNAUT	Audition de Bruno Gazeau, président de la Fédération nationale des associations d'usagers des transports (FNAUT)	2018-03-08 11:25:00	2018-03-08 12:20:00	\N	\N	3	0	\N	\N
253030	DELEGATION	AUDRAP	\N	\N	206	Audition CNRS	Audition de Mme Alice René, docteur en sciences, Institut des sciences biologiques (CNRS)	2018-03-14 16:00:00	2018-03-14 17:00:00	\N	\N	3	0	\N	\N
253032	DELEGATION	AUDRAP	\N	\N	206	Audition Université Paris-Saclay	Audition du Pr Emmanuel HIRSCH, président du conseil pour l'éthique de la rechrche et l'intégrité scientifique	2018-03-28 16:00:00	2018-03-28 17:00:00	\N	\N	2	0	\N	\N
254796	COM_SPECIALE	PLENIERE	\N	SOCIETE	\N	Réunion 2018 03 14	\N	2018-03-13 22:05:00	2018-03-13 22:10:00	2018-03-14 11:16:07	2018-03-14 15:42:40	24	0	\N	\N
256016	COM_ENQUETE	PLENIERE	\N	CHUTE	\N	Audition plénière	\N	2018-04-03 15:00:00	2018-04-03 16:10:00	2018-04-06 16:13:58	2018-04-06 17:07:28	11	0	\N	\N
256017	COM_ENQUETE	AUTRE	\N	CHUTE	\N	Audition plénière	\N	2018-04-03 16:15:00	2018-04-03 17:35:00	2018-04-06 16:14:22	2018-04-06 17:07:28	11	0	\N	\N
256018	COM_ENQUETE	PLENIERE	\N	CHUTE	\N	Audition plénière	\N	2018-04-04 17:00:00	2018-04-04 18:10:00	2018-04-06 09:19:00	2018-04-06 14:33:54	10	0	\N	\N
256019	COM_ENQUETE	AUTRE	\N	CHUTE	\N	Auditions plénières	\N	2018-04-05 11:10:00	2018-04-05 12:45:00	2018-04-06 09:17:53	2018-04-06 14:33:56	9	0	\N	\N
256021	COM_ENQUETE	PLENIERE	\N	CHUTE	\N	Audition plénière	\N	2018-04-05 16:30:00	2018-04-05 17:25:00	2018-04-06 09:17:00	2018-04-06 14:33:56	7	0	\N	\N
256022	COM_ENQUETE	PLENIERE	\N	CHUTE	\N	Audition plenière	\N	2018-04-10 15:25:00	2018-04-10 16:25:00	2018-04-13 17:57:55	2018-04-13 18:05:19	10	0	\N	\N
256023	COM_ENQUETE	PLENIERE	\N	CHUTE	\N	Audition plénière	\N	2018-04-11 15:05:00	2018-04-11 16:05:00	2018-04-13 17:58:24	2018-04-13 18:05:12	6	0	\N	\N
260576	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de Mme Patricia Ferrand, présidente de l¿Unédic	\N	2018-04-04 10:00:00	2018-04-04 12:10:00	2018-04-04 13:54:43	2018-04-04 15:03:44	30	0	\N	\N
260614	COM_EURO	AUDRAP	\N	AFEU	\N	Suivi des conclusions de la commission d'enquête Schengen	\N	2018-03-28 14:10:00	2018-03-28 15:10:00	\N	\N	2	0	\N	\N
262350	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition plénière M. François Molins	\N	2018-04-04 14:00:00	2018-04-04 15:15:00	2018-04-04 18:23:07	2018-04-05 09:46:49	24	0	\N	\N
270308	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Immigration, droit d'asile et intégration	\N	2018-04-26 09:30:00	2018-04-26 13:35:00	\N	\N	3	0	\N	\N
270312	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Immigration, droit d'asile et intégration	\N	2018-04-26 14:20:00	2018-04-26 15:00:00	\N	\N	4	0	\N	\N
362302	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-03-27 09:00:00	2019-03-27 10:10:00	2019-03-27 17:19:49	2019-03-27 17:53:36	49	0	\N	\N
216835	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Dépôt de candidature aux élections + nomination rapporteurs + MI Polynésie française	\N	2017-11-15 10:05:00	2017-11-15 10:50:00	2017-11-15 14:15:57	2017-11-15 15:05:42	41	0	\N	\N
223290	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2017-11-29 09:00:00	2017-11-29 12:20:00	2017-11-29 12:19:08	2017-11-29 16:50:31	44	0	\N	\N
245373	CMP	AUTRE	\N	ORIENTATION	\N	PJL Orientation et réussite des étudiants	PJL Orientation et réussite des étudiants	2018-02-13 16:35:00	2018-02-13 18:30:00	\N	\N	12	0	\N	\N
274333	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désign membres GT Fiches S + Table ronde Alsace-Moselle	Désignation des membres du GT Fiches S + Table ronde Alsace-Lorraine-Moselle	2018-05-23 09:40:00	2018-05-23 11:50:00	2018-05-23 13:49:31	2018-05-23 16:02:31	30	0	\N	\N
274501	DELEGATION	AUDRAP	\N	\N	PROS	Audition de l'INED	\N	2018-06-19 18:00:00	2018-06-19 19:00:00	\N	\N	0	0	\N	\N
274504	DELEGATION	AUDRAP	\N	\N	PROS	Audition de la Caisse des dépôts	\N	2018-06-12 18:45:00	2018-06-12 19:30:00	\N	\N	0	0	\N	\N
286274	MISSION	AUDRAP	\N	HERBE	\N	MI Herboristerie	\N	2018-06-22 09:00:00	2018-06-22 12:00:00	\N	\N	1	0	\N	\N
286276	MISSION	AUDRAP	\N	HERBE	\N	MI Herboristerie	\N	2018-06-22 14:00:00	2018-06-22 15:00:00	\N	\N	1	0	\N	\N
290145	DELEGATION	AUDRAP	\N	\N	206	Audition bioéthique du Professeur Samir Hamamah	Audition bioéthique du Professeur Samir Hamamah, CHU de Montpellier	2018-07-10 15:00:00	2018-07-10 17:00:00	\N	\N	2	0	\N	\N
290147	DELEGATION	AUDRAP	\N	\N	206	Audition Bioéthique de l'Agence de la biomédecine	Audition Bioéthique de Mme Anne Courrèges, directrice générale de l'Agence de la biomédecine 	2018-07-11 14:30:00	2018-07-11 17:30:00	\N	\N	2	0	\N	\N
290535	COM_EURO	AUTRE_NON_PLENIERE	\N	AFEU	\N	Rencontre avec une délégation du Kosovo	Rencontre avec une délégation du Kosovo	2018-06-26 09:10:00	2018-06-26 10:20:00	\N	\N	5	0	\N	\N
292092	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLO PPL Fausses informations PPL PPL AN RECUE DE SOLON	PPLO PPL Fausses informations	2018-06-14 14:30:00	2018-06-14 16:00:00	\N	\N	1	0	\N	\N
292094	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLO PPL Fausses informations PPL PPL AN RECUE DE SOLON	PPLO PPL Fausses informations	2018-06-25 16:30:00	2018-06-25 17:00:00	\N	\N	1	0	\N	\N
292107	COM_EURO	CONTROLE	\N	AFEU	\N	Audition de Mme Corina Cretu - 27 juin 2018	Audition de Mme Corina Cretu - 27 juin 2018	2018-06-27 17:15:00	2018-06-27 18:30:00	2018-06-27 19:00:00	2018-06-28 10:15:34	21	0	\N	\N
292354	COM_EURO	AUDRAP	\N	AFEU	\N	Audition suivi CE Schengen	Auditions de représentants du ministère de l'Europe et des affaires étrangères	2018-06-27 14:00:00	2018-06-27 15:30:00	\N	\N	2	0	\N	\N
292359	COM_PERMANENTE	AUTRE	\N	CDD	\N	Audition plénière	Audition  de M. Éric Lombard, Directeur général de la Caisse des Dépôts 	2018-07-04 10:05:00	2018-07-04 11:40:00	2018-07-04 12:03:00	2018-07-04 15:24:15	24	0	\N	\N
292361	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Commission des affaires étrangères	\N	2018-07-04 11:00:00	2018-07-04 12:10:00	2018-07-04 14:47:09	2018-07-04 15:24:29	28	0	\N	\N
292914	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Aide alimentaire - CICC	Contrôle 2018 - Aide alimentaire - Commission interministérielle de coordination des contrôles CICC	2018-06-27 14:00:00	2018-06-27 15:30:00	\N	\N	2	0	\N	\N
305977	DELEGATION	AUCUNE	\N	\N	206	Audition publique Expertise risques sanitaires et environnementaux 	Audition publique sur l'expertise des risques sanitaires et environnementaux en France et en Europe	2018-10-11 09:30:00	2018-10-11 12:30:00	2018-10-11 17:59:14	2018-10-11 18:11:39	14	0	\N	\N
305978	DELEGATION	AUCUNE	\N	\N	206	Examen du rapport Bioéthique	Examen du rapport sur l'évaluation de l'application de la loi du 7 juillet 2011 relative à la bioéthique	2018-10-18 10:05:00	2018-10-18 12:15:00	2018-10-18 17:33:27	\N	14	0	\N	\N
310767	COM_SPECIALE	PLENIERE	\N	ENTREPRISES	\N	Réunion constitutive	\N	2018-10-11 14:05:00	2018-10-11 14:30:00	2018-10-11 14:31:30	2018-10-11 16:04:36	20	0	\N	\N
312053	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2018-10-17 09:40:00	2018-10-17 12:20:00	2018-10-17 12:32:56	2018-10-17 15:34:19	42	0	\N	\N
312061	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Livre et Industries culturelles	PLF 2019 - Crédits Livre et Industries culturelles	2018-10-16 14:00:00	2018-10-16 15:00:00	\N	\N	1	0	\N	\N
312062	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Livre et Industries culturelles	PLF 2019 - Crédits Livre et Industries culturelles	2018-10-16 15:00:00	2018-10-16 16:00:00	\N	\N	1	0	\N	\N
312247	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2019 - Crédits Sport	PLF 2019 - Crédits Sport	2018-10-16 15:00:00	2018-10-16 16:30:00	\N	\N	3	0	\N	\N
313914	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	Audition interprofession ANVOL	\N	2018-10-09 18:00:00	2018-10-09 19:30:00	\N	\N	0	0	\N	\N
313915	DELEGATION	AUDRAP	\N	\N	DSOM	Réunion avec M. Y. Dorner, président de I2F Nouvelle-Calédonie / I2F Polynésie française	Réunion avec M. Y. Dorner, président de I2F Nouvelle-Calédonie / I2F Polynésie française	2018-10-17 16:30:00	2018-10-17 18:15:00	\N	\N	1	0	\N	\N
313949	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2019 - Conseil et contrôle de l'Etat - Déplacement Cour des comptes	PLF pour 2019 - Conseil et contrôle de l'Etat - Déplacement Cour des comptes	2018-10-16 07:30:00	2018-10-16 09:30:00	\N	\N	1	0	\N	\N
313951	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - EFE - Fitch Ratings	PLF pour 2019 - EFE - Fitch Ratings	2018-10-15 15:00:00	2018-10-15 16:00:00	\N	\N	1	0	\N	\N
313958	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - AGTE - DMAT	PLF pour 2019 - AGTE - DMAT	2018-10-16 09:00:00	2018-10-16 10:30:00	\N	\N	1	0	\N	\N
313960	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - CAS "Pensions" et RSR - DGFiP et DB	PLF pour 2019 - CAS "Pensions" et RSR - DGFiP et DB	2018-10-16 14:00:00	2018-10-16 15:00:00	\N	\N	1	0	\N	\N
313962	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - DAG - DINSIC	PLF pour 2019 - DAG - DINSIC	2018-10-16 08:30:00	2018-10-16 09:45:00	\N	\N	1	0	\N	\N
313964	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Justice - SG Justice	PLF pour 2019 - Justice - SG Justice	2018-10-16 18:00:00	2018-10-16 19:00:00	\N	\N	1	0	\N	\N
313966	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Justice - Direction du budget	PLF pour 2019 - Justice - Direction du budget	2018-10-17 15:30:00	2018-10-17 16:30:00	\N	\N	1	0	\N	\N
313969	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - MIRES Recherche - DRI et INSERM	PLF pour 2019 - MIRES Recherche - DRI et INSERM	2018-10-16 17:45:00	2018-10-16 19:45:00	\N	\N	1	0	\N	\N
313971	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - CAS Immobilier de l'État - DIE	PLF pour 2019 - CAS Immobilier de l'État - DIE	2018-10-16 14:30:00	2018-10-16 15:30:00	\N	\N	2	0	\N	\N
313974	DELEGATION	AUDRAP	\N	\N	PROS	Audition de l'Association des Régions de France	\N	2018-10-30 18:45:00	2018-10-30 19:30:00	\N	\N	4	0	\N	\N
313975	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Sport - Cabinet Ministre	PLF pour 2019 - Sport - Cabinet Ministre	2018-10-16 17:30:00	2018-10-16 18:05:00	\N	\N	1	0	\N	\N
313977	DELEGATION	AUDRAP	\N	\N	PROS	Audition du président du Conseil d'orientation des infrastructures	Audition du président du Conseil d'orientation des infrastructures	2018-10-24 16:00:00	2018-10-24 17:00:00	\N	\N	2	0	\N	\N
313978	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Rapport général - Booking.com	PLF pour 2019 - Rapport général - Booking.com	2018-10-16 15:00:00	2018-10-16 16:00:00	\N	\N	1	0	\N	\N
313989	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Examen du rapport d'information sur le vote électronique	Examen du rapport d'information sur le vote électronique	2018-10-24 09:50:00	2018-10-24 10:35:00	2018-10-24 11:11:37	2018-10-24 12:15:25	31	1	\N	\N
313990	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion 20181023	\N	2018-10-23 09:05:00	2018-10-23 09:40:00	2018-10-23 14:41:09	2018-10-23 18:04:27	20	1	\N	\N
313991	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2019 - Sécurités - Déplacement à Metz	PLF pour 2019 - Sécurités - Déplacement à Metz	2018-10-29 07:40:00	2018-10-29 19:20:00	\N	\N	1	0	\N	\N
313992	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Solidarité - DGCS	PLF pour 2019 - Solidarité - DGCS	2018-10-16 12:00:00	2018-10-16 13:00:00	\N	\N	2	0	\N	\N
313995	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Solidarité - APF et ADF	PLF pour 2019 - Solidarité - APF et ADF	2018-10-17 16:00:00	2018-10-17 18:15:00	\N	\N	2	0	\N	\N
314000	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions GT Déserts médicaux	Auditions GT Déserts médicaux	2018-10-18 10:00:00	2018-10-18 11:30:00	\N	\N	5	0	\N	\N
314014	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2018-10-24 09:30:00	2018-10-24 12:00:00	2018-10-24 15:05:17	2018-10-24 15:18:08	73	0	\N	\N
314063	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Écologie/Transports - ARAFER	PLF pour 2019 - Écologie/Transports - ARAFER	2018-10-16 11:00:00	2018-10-16 12:00:00	\N	\N	1	0	\N	\N
314065	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Écologie/Transports - DGITM	PLF pour 2019 - Écologie/Transports - DGITM	2018-10-16 15:30:00	2018-10-16 17:00:00	\N	\N	1	0	\N	\N
314067	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Écologie/Transports - VNF	PLF pour 2019 - Écologie/Transports - VNF	2018-10-18 11:00:00	2018-10-18 12:00:00	\N	\N	1	0	\N	\N
314348	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	981	\N	\N	Explications de vote sur l'ensemble PJL et PJLO Justice	Explications de vote sur l'ensemble PJL et PJLO Justice 	2018-10-23 14:35:00	2018-10-23 15:30:00	\N	\N	284	0	\N	\N
314350	SEANCE_PLENIERE	SCRUSOL	981	\N	\N	Scrutin solennel PJL et PJLO Justice	Scrutin solennel PJL et PJLO Justice	2018-10-23 15:30:00	2018-10-23 15:55:00	\N	\N	0	0	\N	\N
314384	GIA	AUCUNE	\N	\N	\N	Déjeuner ambassadeur d'Irak	Déjeuner entre M. Cazeau et l'ambassadeur d'Irak, M. Ismail Shafiq Muhsin, à l'occasion du départ de ce dernier	2018-10-17 13:00:00	2018-10-17 14:30:00	\N	\N	1	0	615	\N
320954	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Election des sénateurs	\N	2018-11-07 16:00:00	2018-11-07 17:10:00	\N	\N	1	0	\N	\N
320972	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	PJLF pour 2019 - Mission Administration pénitentiaire	\N	2018-11-08 08:30:00	2018-11-08 12:00:00	\N	\N	2	0	\N	\N
342004	COM_EURO	AUTRE_NON_PLENIERE	\N	AFEU	\N	Réunion du bureau	Réunion du bureau	2019-01-16 11:45:00	2019-01-16 12:45:00	\N	\N	10	0	\N	\N
342158	COM_EURO	AUTRE_NON_PLENIERE	\N	AFEU	\N	Entretien avec Catherine Colonna	Entretien avec Catherine Colonna	2019-01-16 15:00:00	2019-01-16 16:00:00	\N	\N	9	0	\N	\N
359011	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Collectivité européenne d'Alsace	\N	2019-03-12 09:30:00	2019-03-12 11:00:00	\N	\N	1	0	\N	\N
359193	GIA	AUCUNE	\N	\N	\N	Rencontre avec le représentant de Taipei en France	Rencontre avec le représentant de Taipei en France	2019-02-26 15:00:00	2019-02-26 16:00:00	\N	\N	1	0	623	\N
213244	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF  pour 2018 - Sécurités	\N	2017-10-24 17:25:00	2017-10-24 20:10:00	\N	\N	1	0	\N	\N
213274	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2017-10-31 17:45:00	2017-10-31 18:30:00	\N	\N	1	0	\N	\N
213276	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2017-10-31 14:45:00	2017-10-31 16:30:00	2017-10-31 16:26:35	2017-10-31 18:12:44	32	0	\N	\N
215009	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2017-11-07 14:30:00	2017-11-07 17:30:00	\N	\N	3	0	\N	\N
219851	DELEGATION	AUCUNE	\N	\N	211	Audition de M. Edouard Durand et de Mme Ernestine Ronai	Audition de M. Edouard Durand et de Mme Ernestine Ronai	2017-11-16 09:00:00	2017-11-16 11:00:00	2017-11-16 15:09:04	2017-11-16 15:14:30	18	0	\N	\N
230773	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition cyle de vie des entreprises	Audition cycle de vie des entreprises (AFIC)	2017-12-15 14:30:00	2017-12-15 15:45:00	\N	\N	1	0	\N	\N
233049	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2018-01-17 10:00:00	2018-01-17 12:50:00	2018-01-17 14:53:57	2018-01-17 16:08:03	46	0	\N	\N
234027	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2018-01-16 14:30:00	2018-01-16 17:00:00	\N	\N	3	0	\N	\N
238562	DELEGATION	AUCUNE	\N	\N	COLTER	Communication de M. Pointereau : revitalisation centres-villes centres-bourgs	\N	2018-02-01 09:00:00	2018-02-01 10:30:00	2018-02-01 11:06:58	2018-02-01 20:08:56	18	0	\N	\N
240358	GIA	AUCUNE	\N	\N	\N	Assemblée générale de reconstitution du groupe	Assemblée générale de reconstitution du groupe	2018-01-31 08:45:00	2018-01-31 09:30:00	\N	\N	8	0	644	\N
246055	COM_PERMANENTE	PLEIN_NON_JO	\N	FINC	\N	\N	\N	2018-02-13 18:00:00	2018-02-13 19:10:00	2018-02-15 15:53:06	\N	13	0	\N	\N
259068	DELEGATION	AUCUNE	\N	\N	206	Présentation du rapport annuel de l'ASN - Examen note courte sur les blockchains	Présentation, ouverte à la presse, du rapport annuel de l'ASN par M. Chevet, président - Examen note courte Blockchains	2018-04-12 09:45:00	2018-04-12 12:40:00	2018-04-13 09:54:26	2018-04-13 17:43:54	11	0	\N	\N
259069	DELEGATION	AUCUNE	\N	\N	206	Examen d'une note courte sur les bloc-chaînes	Examen d'une note courte sur les bloc-chaînes (blockchains)	2018-04-12 11:30:00	2018-04-12 12:30:00	\N	\N	0	0	\N	\N
260165	GIA	AUCUNE	\N	\N	\N	Dejeuner de travail avec l'ambassadeur d'Indonésie à Paris	Dejeuner de travail avec l'ambassadeur d'Indonésie à Paris	2018-03-27 12:30:00	2018-03-27 14:40:00	\N	\N	4	0	653	\N
263168	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Transfert compétences eau et assainissement	PPL Transfert compétences eau et assainissement	2018-04-17 14:30:00	2018-04-17 19:35:00	\N	\N	196	0	\N	\N
263174	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Protection des savoir-faire	PPL Protection des savoir-faire	2018-04-18 14:30:00	2018-04-18 20:05:00	\N	\N	94	0	\N	\N
313986	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2019 - Examen Rapports R&D, UE et Justice	PLF pour 2019 - Examen Rapports R&D, UE et Justice	2018-10-24 09:35:00	2018-10-24 11:50:00	2018-10-24 12:50:34	2018-10-24 13:00:17	42	0	\N	\N
221849	CMP	AUTRE	\N	PLFSS2018	\N	PLFSS pour 2018	PLFSS pour 2018	2017-11-22 11:30:00	2017-11-22 12:20:00	\N	\N	10	0	\N	\N
233048	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2018-01-17 09:30:00	2018-01-17 10:00:00	2018-01-17 14:52:24	2018-01-17 16:08:07	45	0	\N	\N
263191	SEANCE_PLENIERE	DECL_GVT	\N	\N	\N	Déclaration du Gouvernement Programme de stabilité 2018-2022	Déclaration du Gouvernement Programme de stabilité 2018-2022	2018-04-18 21:35:00	2018-04-18 23:40:00	\N	\N	72	0	\N	\N
263237	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Protection des savoir-faire	\N	2018-04-18 23:40:00	2018-04-19 01:35:00	\N	\N	49	0	\N	\N
270299	DELEGATION	AUDRAP	\N	\N	PROS	Audition de la DARES	\N	2018-05-29 10:00:00	2018-05-29 11:00:00	\N	\N	2	0	\N	\N
270567	COM_EURO	AUTRE_NON_PLENIERE	\N	AFEU	\N	Entretien Mme Catherine Defraigne, présidente du Sénat Belge	Entretien Mme Catherine Defraigne, présidente du Sénat Belge	2018-05-09 17:45:00	2018-05-09 18:50:00	\N	\N	3	0	\N	\N
275395	BUREAU	AUCUNE	\N	\N	\N	Bureau du Sénat	Bureau du Sénat	2018-05-24 09:10:00	2018-05-24 11:35:00	\N	\N	19	0	\N	\N
275607	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL "Agriculture"	PJL "Agriculture"	2018-05-14 09:30:00	2018-05-14 12:30:00	\N	\N	2	0	\N	\N
275624	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL "Agriculture"	PJL "Agriculture"	2018-05-14 14:00:00	2018-05-14 19:30:00	\N	\N	3	0	\N	\N
275653	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL "Agriculture"	PJL "Agriculture"	2018-05-15 13:30:00	2018-05-15 19:00:00	\N	\N	5	0	\N	\N
275690	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL "Centres-villes - Centres-bourgs"	PPL - Centres-villes - Centres-bourgs"	2018-05-22 14:30:00	2018-05-22 18:00:00	\N	\N	1	0	\N	\N
275699	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL "Centres-villes - Centres-bourgs"	PPL "Centres-villes - Centres-bourgs"	2018-05-22 09:45:00	2018-05-22 10:30:00	\N	\N	1	0	\N	\N
275701	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL "Centres-villes - Centres-bourgs"	PPL "Centres-villes - Centres-bourgs"	2018-05-23 09:30:00	2018-05-23 11:00:00	\N	\N	1	0	\N	\N
275705	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL "Centres-villes - Centres-bourgs"	PPL "Centres-villes - Centres-bourgs"	2018-05-23 14:30:00	2018-05-23 19:00:00	\N	\N	1	0	\N	\N
275707	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL "Centres-villes - Centres-bourgs"	PPL "Centres-villes - Centres-bourgs"	2018-05-24 09:00:00	2018-05-24 10:00:00	\N	\N	1	0	\N	\N
275709	ETUDES	AUCUNE	\N	\N	\N	Section Cultures traditionnelles et spécialisées	Section Cultures traditionnelles et spécialisées	2018-05-16 08:00:00	2018-05-16 09:00:00	\N	\N	13	0	\N	1005
275903	COM_ENQUETE	PLENIERE	\N	HAUTE	\N	Audition	Audition	2018-05-23 14:05:00	2018-05-23 14:55:00	2018-05-25 16:34:08	2018-05-25 17:14:11	7	0	\N	\N
275912	COM_ENQUETE	PLENIERE	\N	HAUTE	\N	Audition	Audition	2018-05-23 14:55:00	2018-05-23 16:05:00	2018-05-25 16:40:38	2018-05-25 17:14:13	6	0	\N	\N
275924	COM_ENQUETE	PLENIERE	\N	HAUTE	\N	Audition	Audition	2018-05-23 16:05:00	2018-05-23 17:00:00	2018-05-25 16:40:18	2018-05-25 17:14:17	6	0	\N	\N
276028	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Examen du rapport et du texte sur la PPL Carte du combattant	\N	2018-05-29 14:00:00	2018-05-29 14:40:00	2018-05-29 14:43:35	2018-05-30 15:48:47	39	0	\N	\N
276029	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Examen rapport pour avis PPL Modernisation de la transmission d'entreprise	\N	2018-05-29 18:00:00	2018-05-29 18:40:00	2018-05-29 18:43:53	2018-05-30 15:48:49	34	0	\N	\N
279326	COM_ENQUETE	PLENIERE	\N	HAUTE	\N	Audition	Audition	2018-05-30 16:30:00	2018-05-30 17:30:00	2018-06-01 17:15:07	2018-06-01 17:15:59	7	0	\N	\N
279337	COM_ENQUETE	PLENIERE	\N	HAUTE	\N	Audition	Audition	2018-05-31 10:10:00	2018-05-31 11:10:00	2018-06-01 17:18:08	2018-06-01 17:29:15	9	0	\N	\N
279349	COM_ENQUETE	PLENIERE	\N	HAUTE	\N	Audition	Audition	2018-05-31 11:10:00	2018-05-31 12:10:00	2018-06-01 17:21:25	2018-06-01 17:29:16	9	0	\N	\N
279388	COM_EURO	DEPLACEMENT	\N	AFEU	\N	Bruxelles - Rencontre avec des représentants des institutions européennes	Présentation du rapport d'information "Subsidiarité" à M. Frans Timmermans, commissaire européen	2018-06-05 10:45:00	2018-06-05 11:30:00	\N	\N	2	0	\N	\N
279389	COM_EURO	DEPLACEMENT	\N	AFEU	\N	Institutions européennes	Bruxelles - Rencontre avec des représentants des institutions européennes - Extraterritorialité des lois américaines	2018-06-06 11:00:00	2018-06-06 18:00:00	\N	\N	1	0	\N	\N
280757	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Audition plénière	\N	2018-06-06 08:00:00	2018-06-06 08:55:00	\N	\N	0	0	\N	\N
280904	DELEGATION	AUCUNE	\N	\N	211	Bilan de la session 2017-2018 et perspectives de programme pour 2018-2019	Bilan de la session 2017-2018 et perspectives de programme pour 2018-2019	2018-07-19 08:30:00	2018-07-19 10:30:00	2018-07-19 14:09:04	2018-07-19 14:35:40	8	0	\N	\N
280907	DELEGATION	AUCUNE	\N	\N	211	Examen du rapport - PJL renforçant la lutte contre les violences sexuelles et sexistes	Examen du rapport - PJL renforçant la lutte contre les violences sexuelles et sexistes	2018-06-14 08:30:00	2018-06-14 10:40:00	2018-06-14 11:17:56	2018-06-14 12:05:07	13	0	\N	\N
281404	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Evolution du logement, de l'aménagement et du numérique	\N	2018-06-05 10:15:00	2018-06-05 12:00:00	\N	\N	1	0	\N	\N
281407	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Evolution du logement, de l'aménagement et du numérique	\N	2018-06-05 16:15:00	2018-06-05 18:30:00	\N	\N	0	0	\N	\N
281721	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	PJL Avenir professionnel - Table ronde organisations employeurs 	2018-06-13 09:05:00	2018-06-13 10:30:00	2018-06-13 10:59:57	2018-06-13 14:24:29	30	0	\N	\N
281723	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2018-06-13 10:50:00	2018-06-13 11:55:00	2018-06-13 12:00:15	2018-06-13 14:24:31	40	0	\N	\N
281726	DELEGATION	AUCUNE	\N	\N	211	Audition du COFRADE/ACPE	Audition du COFRADE/ACPE	2018-06-07 09:00:00	2018-06-07 11:00:00	2018-06-07 12:12:21	2018-06-07 18:51:13	14	0	\N	\N
281771	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de M. Marc EL NOUCHI, Pdt commission des infractions fiscales  sur PJL 460 fraude	Audition de M. Marc EL NOUCHI, Pdt commission des infractions fiscales sur le PJL 460 lutte contre la fraude	2018-06-12 17:55:00	2018-06-12 19:00:00	2018-06-13 23:26:51	2018-06-14 09:49:48	18	0	\N	\N
293109	DELEGATION	AUCUNE	\N	\N	DSOM	Audition sur l'avenir de la chaîne France Ô	Audition sur l'avenir de la chaîne France Ô	2018-07-05 09:15:00	2018-07-05 12:15:00	2018-07-05 17:29:18	2018-07-06 14:18:34	9	0	\N	\N
293137	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018  - Coûts audiovisuel public - Big Band Story	Contrôle 2018  - Coûts audiovisuel public - Big Band Story	2018-06-28 15:00:00	2018-06-28 16:00:00	\N	\N	1	0	\N	\N
293139	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Aide à la pierre - DRIHR 	Contrôle 2018 - Aide à la pierre - DRIHR 	2018-06-28 16:30:00	2018-06-28 17:15:00	\N	\N	1	0	\N	\N
293141	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Aide à la pierre - USH	Contrôle 2018 - Aide à la pierre - USH	2018-06-28 14:30:00	2018-06-28 15:45:00	\N	\N	1	0	\N	\N
293230	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2018 - ANTAI : mode de fonctionnement et flux financiers - ANTAI Rennes	Contrôle 2018 - ANTAI : mode de fonctionnement et flux financiers -ANTAI  Rennes	2018-07-05 06:50:00	2018-07-05 14:50:00	\N	\N	1	0	\N	\N
293238	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Programme de contrôle - 2018 - Rapporteur général du rapport public et des programmes	Programme de contrôle - 2018 - Rapporteur général du rapport public et des programmes	2018-06-26 13:45:00	2018-06-26 14:30:00	\N	\N	1	0	\N	\N
361335	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Produits agricoles ou alimentaires	PPL Produits agricoles ou alimentaires	2019-03-12 17:45:00	2019-03-12 19:45:00	\N	\N	4	0	\N	\N
293253	DELEGATION	AUDRAP	\N	\N	DSOM	Réunion du président avec des représentant d'Interco' Outre-mer	Réunion du président avec des représentant d'Interco' Outre-mer	2018-06-29 15:00:00	2018-06-29 16:15:00	\N	\N	0	0	\N	\N
293257	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Disponibilité des hélicoptères - Airbus	Contrôle 2018 - Disponibilité des hélicoptères - Airbus	2018-06-28 16:30:00	2018-06-28 17:30:00	\N	\N	1	0	\N	\N
293259	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2018 - Les maisons de l'emploi - Paris	Contrôle 2018 - Les maisons de l'emploi - Maison de l'emploi à Paris	2018-06-29 12:55:00	2018-06-29 17:00:00	\N	\N	1	0	\N	\N
297864	MISSION	AUCUNE	\N	PENURIE	\N	Mission d'information sur la pénurie de médicaments	Mission d'information sur la pénurie de médicaments	2018-07-12 09:00:00	2018-07-12 10:25:00	2018-07-12 10:40:03	2018-07-12 15:58:09	7	0	\N	\N
305412	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Auditions affaire Benalla (suite)	Affaire Benalla - Suite des auditions	2018-09-12 09:35:00	2018-09-12 13:20:00	2018-09-12 14:43:43	2018-09-12 16:55:53	43	0	\N	\N
309127	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2018-09-25 19:35:00	2018-09-25 20:20:00	\N	\N	25	0	\N	\N
310074	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Scolarisation des enfants en situation de handicap	Débat Scolarisation des enfants en situation de handicap	2018-10-25 17:00:00	2018-10-25 20:20:00	\N	\N	26	0	\N	\N
318683	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2019 - Programme 844	\N	2018-10-30 15:30:00	2018-10-30 16:30:00	\N	\N	2	0	\N	\N
345248	GIA	AUCUNE	\N	\N	\N	Entretien avec M. ZHAKU, Conseiller du Vice-premier ministre de Macédoine (coopé)	Entretien avec M. ZHAKU, Conseiller du Vice-premier ministre de Macédoine (coopé)	2019-01-24 15:00:00	2019-01-24 16:00:00	\N	\N	2	0	674	\N
356361	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	\N	2019-03-05 16:35:00	2019-03-05 18:05:00	2019-03-05 18:51:12	2019-03-06 16:49:21	55	0	\N	\N
356663	DELEGATION	AUCUNE	\N	\N	DSOM	Table ronde des directeurs des stations La 1ère	\N	2019-03-12 09:00:00	2019-03-12 11:00:00	\N	\N	8	0	\N	\N
356666	DELEGATION	AUCUNE	\N	\N	DSOM	Suivi du rapport d'information sur la jeunesse des outre-mer et le sport	\N	2019-03-14 09:30:00	2019-03-14 11:20:00	\N	\N	8	0	\N	\N
356668	DELEGATION	AUCUNE	\N	\N	DSOM	Étude sur les risques naturels majeurs outre-mer - Auditions	\N	2019-04-04 10:45:00	2019-04-04 13:00:00	2019-04-04 13:24:46	\N	11	0	\N	\N
356669	DELEGATION	AUCUNE	\N	\N	DSOM	Audition de la DGOM - Étude sur les risques naturels majeurs (volet 2)	\N	2019-04-11 09:00:00	2019-04-11 10:45:00	\N	\N	6	0	\N	\N
356820	DELEGATION	AUDRAP	\N	\N	PROS	Audition de Futuribles	\N	2019-04-03 15:45:00	2019-04-03 16:45:00	\N	\N	2	0	\N	\N
356821	DELEGATION	AUDRAP	\N	\N	PROS	Audition de Olivier EZRATTY, consultant, spécialiste des nouvelles technologies, bloggeur	\N	2019-04-04 11:30:00	2019-04-04 12:30:00	\N	\N	1	0	\N	\N
358053	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-03-13 10:00:00	2019-03-13 12:20:00	2019-03-13 13:27:15	2019-03-14 11:45:36	31	0	\N	\N
358734	COM_PERMANENTE	AUTRE	\N	FINC	\N	Nomination rapporteur taxe numérique-Audition commune financement infrastructures transp.	Nomination rapporteur taxe numérique et Audition commune sur le financement des infrastructures de transport 	2019-03-12 14:35:00	2019-03-12 16:30:00	2019-03-13 12:59:18	2019-03-14 11:43:17	27	0	\N	\N
358939	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Le numérique à l'école - Cour des comptes	Contrôle 2019 - Le numérique à l'école - Cour des comptes	2019-03-05 15:00:00	2019-03-05 16:00:00	\N	\N	2	0	\N	\N
358941	DELEGATION	AUTRE	\N	\N	211	Audition de Mme Brigitte Henriques	\N	2019-04-11 09:30:00	2019-04-11 11:00:00	\N	\N	0	0	\N	\N
358942	MISSION	AUCUNE	\N	SIDERURGIE	\N	Audition de M. Sébastien GUÉRÉMY, conseiller industrie et innovation	Audition de M. Sébastien GUÉRÉMY, conseiller industrie et innovation cabinet du ministre de l¿économie et des finances	2019-03-12 14:35:00	2019-03-12 15:50:00	2019-03-13 11:13:36	2019-03-13 11:19:23	12	0	\N	\N
358946	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Les contrats de ruralité - Association des communautés de France	Contrôle 2019 - Les contrats de ruralité - Association des communautés de France	2019-03-06 14:00:00	2019-03-06 15:30:00	\N	\N	1	0	\N	\N
358948	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Les contrats de ruralité - Association des maires ruraux de France	Contrôle 2019 - Les contrats de ruralité - Association des maires ruraux de France	2019-03-06 18:30:00	2019-03-06 19:00:00	\N	\N	1	0	\N	\N
358950	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - La prime d'activité - DGCS	Contrôle 2019 - La prime d'activité - DGCS	2019-03-07 10:00:00	2019-03-07 11:00:00	\N	\N	2	0	\N	\N
358953	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Fusion métropoles avec département - DRFIP Auvergne-Rhône-Alpes	Contrôle 2019 - Fusion métropoles avec département - DRFIP Auvergne-Rhône-Alpes	2019-03-07 10:30:00	2019-03-07 11:30:00	\N	\N	2	0	\N	\N
358956	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - La mobilisation des financements en faveur de la recherche - DGRI	Contrôle 2019 - La mobilisation des financements en faveur de la recherche - DGRI	2019-03-07 13:30:00	2019-03-07 15:00:00	\N	\N	1	0	\N	\N
358958	COM_PERMANENTE	AUTRE	\N	FINC	\N	Compte-Rendu Conférence Art 13 - Audition situation et perspectives économie française	Compte-Rendu Conférence Art 13 - Audition commune sur la situation et les perspectives de l¿économie française	2019-03-13 09:35:00	2019-03-13 11:45:00	2019-03-13 12:58:09	2019-03-14 11:45:18	37	0	\N	\N
358959	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2019 - Lutte contre les feux de forêt - Déplacement à Nîmes	Contrôle 2019 - Lutte contre les feux de forêt - Déplacement à Nîmes	2019-03-11 06:00:00	2019-03-11 20:00:00	\N	\N	1	0	\N	\N
358979	DELEGATION	AUDRAP	\N	\N	PROS	Audition du LIMSI (laboratoire du CNRS)	\N	2019-03-20 15:30:00	2019-03-20 17:00:00	\N	\N	2	0	\N	\N
369643	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Clarifier diverses dispositions du droit électoral	\N	2019-04-03 16:30:00	2019-04-03 20:15:00	\N	\N	3	0	\N	\N
369646	GIA	AUCUNE	\N	\N	\N	Réception chez l'ambassadeur de Biélorussie M Igor FISSENKO	Réception chez l'ambassadeur de Biélorussie	2019-04-03 20:00:00	2019-04-03 22:30:00	\N	\N	3	0	852	\N
369650	GIA	AUCUNE	\N	\N	\N	Déjeuner de travail avec M. David IZZO, ambassadeur de France à El Salvador	Déjeuner de travail avec M. David IZZO, ambassadeur de France à El Salvador	2019-04-03 12:30:00	2019-04-03 14:30:00	\N	\N	3	0	643	\N
373504	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI mission défense européenne	\N	2019-04-10 12:00:00	2019-04-10 13:00:00	\N	\N	2	0	\N	\N
373647	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Stade de France - CDES	Contrôle 2019 - Stade de France - CDES	2019-04-10 16:00:00	2019-04-10 16:30:00	\N	\N	1	0	\N	\N
217402	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2018 - Recherche et Enseignement supérieur-Ministère de l'enseignement supérieur	PLF pour 2018 - Recherche et Enseignement supérieur - Ministre de l'enseignement supérieur	2017-11-09 14:30:00	2017-11-09 15:30:00	\N	\N	1	0	\N	\N
225128	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Visioconférence avec la Commission européenne 	Visioconférence avec la Commission européenne, suites du rapport sur la simplification du droit pour les entreprises 	2017-11-28 18:00:00	2017-11-28 19:10:00	\N	\N	2	0	\N	\N
230169	GIA	AUCUNE	\N	\N	\N	AG RECONSTITUTIVE DU GROUPE D'AMITIE	Assemblée générale	2017-12-14 09:30:00	2017-12-14 10:00:00	\N	\N	15	0	595	\N
233174	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2018-01-12 09:30:00	2018-01-12 12:30:00	\N	\N	1	0	\N	\N
233176	MECSS	AUDRAP	\N	\N	MECSS	\N	\N	2018-01-15 13:45:00	2018-01-15 18:00:00	\N	\N	1	0	\N	\N
233185	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2018-01-22 17:00:00	2018-01-22 18:00:00	\N	\N	1	0	\N	\N
241247	GIA	AUCUNE	\N	\N	\N	Entretien de Mme Nathalie GOULET avec une délégation de six journalistes tadjiks	Entretien de Mme Nathalie GOULET avec une délégation de six journalistes tadjiks	2018-02-01 14:15:00	2018-02-01 15:00:00	\N	\N	1	0	556	\N
241271	DELEGATION	AUDRAP	\N	\N	206	Audition de l'Agence de la biomédecine	Agence de la biomédecine : audition de Mme Anne Courrèges, DG et Mme le Docteur Evelyne Marry, directrice 	2018-02-08 14:15:00	2018-02-08 16:00:00	\N	\N	2	0	\N	\N
244269	COM_EURO	AUDRAP	\N	AFEU	\N	Audition sur les achats en ligne	Audition sur les achats en ligne	2018-02-05 11:35:00	2018-02-05 12:25:00	\N	\N	1	0	\N	\N
244283	GIA	AUCUNE	\N	\N	\N	AG du groupe	Assemblée générale du groupe et désignation du Bureau	2018-01-17 13:45:00	2018-01-17 14:15:00	\N	\N	8	0	578	\N
244332	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJLO Accession de la Nouvelle Calédonie à la pleine souveraineté	\N	2018-02-13 09:10:00	2018-02-13 09:15:00	2018-02-13 14:45:43	2018-02-13 16:28:19	22	0	\N	\N
251823	ETUDES	AUCUNE	\N	\N	\N	Groupe d'études Aviation civile - Réunion constitutive	Groupe d'études Aviation civile - Réunion constitutive et échanges de vues	2018-03-08 08:30:00	2018-03-08 09:00:00	\N	\N	11	0	\N	933
255393	ETUDES	AUCUNE	\N	\N	\N	\N	\N	2018-03-07 18:30:00	2018-03-07 19:30:00	\N	\N	19	0	\N	1008
273442	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	Commission des comptes	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne 	2018-05-17 11:00:00	2018-05-17 11:45:00	2018-05-17 15:13:50	2018-05-18 18:23:07	7	0	\N	\N
273455	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Libye	\N	2018-05-16 16:00:00	2018-05-16 16:45:00	\N	\N	2	0	\N	\N
292917	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Disponibilité des hélicoptères - Maintenance aéronautique-Cour des Comptes	Contrôle 2018 - Disponibilité des hélicoptères - Maintenance aéronautique et Cour des Comptes	2018-06-27 15:30:00	2018-06-27 17:30:00	\N	\N	1	0	\N	\N
292920	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Aides à la pierre - SOLIHA et EPL	Contrôle 2018 - Aides à la pierre - SOLIHA et EPL	2018-06-27 16:45:00	2018-06-27 18:15:00	\N	\N	1	0	\N	\N
292930	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen amendements PJL lutte contre la fraude	Examen amendements PJL lutte contre la fraude	2018-07-03 09:00:00	2018-07-03 10:00:00	2018-07-03 11:25:18	2018-07-03 16:51:50	28	0	\N	\N
292937	COM_ENQUETE	PLENIERE	\N	HAUTE	\N	Auditions	Auditions	2018-06-27 14:05:00	2018-06-27 17:55:00	2018-06-29 19:41:23	2018-06-29 21:13:50	8	0	\N	\N
293835	COM_PERMANENTE	AUTRE	\N	SOCI	\N	réunion plénière	\N	2018-07-04 09:30:00	2018-07-04 11:30:00	2018-07-04 11:38:36	2018-07-04 15:23:56	35	0	\N	\N
294010	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2018-07-04 14:45:00	2018-07-04 15:45:00	\N	\N	1	0	\N	\N
294108	COM_EURO	DEPLACEMENT	\N	AFEU	\N	Déplacement en Israël (25 au 27 juin 2018)	Déplacement en Israël - Rapport d'information "Les relations entre l'Union européenne et Israël", du 25 au 27 juin 2018	2018-06-25 08:00:00	2018-06-27 14:00:00	\N	\N	0	0	\N	\N
297304	DELEGATION	AUDRAP	\N	\N	PROS	Audition rapporteurs	Audition de BLABLACAR	2018-07-17 17:00:00	2018-07-17 18:15:00	\N	\N	3	0	\N	\N
297354	DELEGATION	AUCUNE	\N	\N	DSOM	Examen du rapport d'information sur les risques naturels majeurs	\N	2018-07-24 09:15:00	2018-07-24 10:45:00	2018-07-24 12:16:25	2018-07-24 17:09:29	13	0	\N	\N
298308	COM_ENQUETE	AUDRAP	\N	HAUTE	\N	Audition	Audition	2018-07-10 14:30:00	2018-07-10 15:30:00	\N	\N	6	0	\N	\N
298314	COM_ENQUETE	PLENIERE	\N	HAUTE	\N	Audition	Audition	2018-07-10 15:35:00	2018-07-10 16:05:00	2018-07-12 19:01:39	2018-07-13 10:56:07	10	0	\N	\N
298333	COM_ENQUETE	PLENIERE	\N	HAUTE	\N	Audition	Audition	2018-07-10 18:05:00	2018-07-10 19:05:00	2018-07-12 19:07:06	2018-07-13 10:56:04	10	0	\N	\N
298344	COM_ENQUETE	AUDRAP	\N	HAUTE	\N	Auditions	Auditions	2018-07-11 14:35:00	2018-07-11 17:30:00	\N	\N	6	0	\N	\N
298351	COM_ENQUETE	PLENIERE	\N	HAUTE	\N	Audition	Audition	2018-07-11 17:35:00	2018-07-11 19:00:00	2018-07-12 19:11:56	2018-07-13 10:56:05	6	0	\N	\N
299302	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Audition plénière	\N	2018-07-20 10:00:00	2018-07-20 10:45:00	\N	\N	0	0	\N	\N
299303	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Audition plénière	\N	2018-07-20 11:30:00	2018-07-20 12:30:00	\N	\N	0	0	\N	\N
299304	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	auditions plénières	\N	2018-07-20 09:00:00	2018-07-20 12:30:00	\N	\N	0	0	\N	\N
299305	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Audition plénière	\N	2018-07-20 15:30:00	2018-07-20 16:15:00	\N	\N	0	0	\N	\N
299310	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Audition plénière	\N	2018-07-20 14:45:00	2018-07-20 15:30:00	\N	\N	0	0	\N	\N
299818	GIA	AUCUNE	\N	\N	\N	Visite de l'exposition sur le Canal de Suez 	Visite de l'exposition sur le Canal de Suez à l'IMA	2018-07-17 18:00:00	2018-07-17 19:00:00	\N	\N	5	0	617	\N
299824	GIA	AUCUNE	\N	\N	\N	Entretien avec SE Ehab BADAWI, ambassadeur d'Egypte	Entretien avec SE Ehab BADAWI, ambassadeur d'Egypte	2018-07-17 19:30:00	2018-07-17 21:15:00	\N	\N	9	0	617	\N
300523	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Délégation aux entreprises - Réunion plénière	Délégation sénatoriale aux entreprises - Réunion plénière	2018-07-19 09:00:00	2018-07-19 09:40:00	2018-07-19 10:49:05	2018-07-19 10:54:46	8	0	\N	\N
230813	CMP	AUTRE	\N	PLFR2017_2	\N	PLFR pour 2017	PLFR pour 2017	2017-12-18 09:10:00	2017-12-18 09:30:00	\N	\N	7	0	\N	\N
244333	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Exécution des peines liées aux violences conjugales	\N	2018-02-14 09:35:00	2018-02-14 11:10:00	2018-02-20 15:50:32	2018-02-20 16:09:14	46	0	\N	\N
292933	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen rapport PJL n° 595 (2017-2018) de règlement du budget	Examen rapport PJL n° 595 (2017-2018) de règlement du budget et actualisation programme budgétaire	2018-07-04 10:05:00	2018-07-04 11:35:00	2018-07-04 16:22:40	2018-07-04 16:58:18	34	0	\N	\N
299311	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	\N	2018-07-18 09:35:00	2018-07-18 11:05:00	2018-07-18 12:01:14	2018-07-18 14:48:50	39	1	\N	\N
301759	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Sadiq SAFAEV, Vice-président du Sénat d'Ouzbékistan	Entretien avec M. Sadiq SAFAEV, Vice-président du Sénat d'Ouzbékistan	2018-07-20 10:00:00	2018-07-20 11:30:00	\N	\N	1	0	556	\N
303133	MISSION	AUDRAP	\N	HERBE	\N	\N	\N	2018-07-26 11:00:00	2018-07-26 12:00:00	\N	\N	1	0	\N	\N
304242	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2018-07-25 15:30:00	2018-07-25 19:30:00	\N	\N	3	0	\N	\N
305512	COM_EURO	AUDRAP	\N	AFEU	\N	Extraterritorialité des sanctions américaines	Extraterritorialité des sanctions américaines - Audition de M. Affaki et de représentants de l'OMC	2018-09-11 15:00:00	2018-09-11 17:15:00	\N	\N	1	0	\N	\N
305819	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2018-09-19 14:40:00	2018-09-19 16:50:00	\N	\N	3	0	\N	\N
305881	DELEGATION	DEPLACEMENT	\N	\N	206	Visite du site de Rueil-Malmaison d'IFP Energies nouvelles (IFPEN)	Visite du site de Rueil-Malmaison d'IFP Energies nouvelles (IFPEN)	2018-09-18 08:30:00	2018-09-18 13:30:00	\N	\N	1	0	\N	\N
213134	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	PLF 2018 - Avis budgétaire "Fonction publique"	\N	2017-10-25 14:15:00	2017-10-25 16:15:00	\N	\N	1	0	\N	\N
305467	GIA	AUCUNE	\N	\N	\N	Entretien avec Mme Ankie BROEKERS-KNOL, Présidente du Sénat des Pays-Bas	Entretien avec Mme Ankie BROEKERS-KNOL, Présidente de la Première chambre des États généraux	2018-09-05 15:00:00	2018-09-05 16:00:00	\N	\N	3	0	599	\N
306009	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2018-09-25 16:45:00	2018-09-25 17:40:00	\N	\N	281	0	\N	\N
306010	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Alimentation	PJL Alimentation	2018-09-25 17:50:00	2018-09-25 20:00:00	\N	\N	130	0	\N	\N
306011	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Alimentation	PJL Alimentation	2018-09-25 21:30:00	2018-09-26 00:00:00	\N	\N	0	0	\N	\N
342958	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Examen d'une demande d'huis clos d'une audition	Examen d'une demande d'huis clos d'une audition	2019-01-21 16:10:00	2019-01-21 16:20:00	2019-01-21 18:22:24	2019-01-21 18:27:33	30	0	\N	\N
343003	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de M. Vincent Crase	Audition de M. Vincent Crase	2019-01-21 16:30:00	2019-01-21 17:10:00	2019-01-21 18:22:31	2019-01-21 18:27:34	27	0	\N	\N
343005	DELEGATION	AUDRAP	\N	\N	PROS	Audition de la Banque de France	\N	2019-02-06 14:00:00	2019-02-06 15:00:00	\N	\N	1	0	\N	\N
352426	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Interdire l'usage des lanceurs de balles de défense	\N	2019-02-13 14:00:00	2019-02-13 15:45:00	\N	\N	3	0	\N	\N
352430	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Interdire l'usage des lanceurs de balles de défense	\N	2019-02-13 15:45:00	2019-02-13 16:40:00	\N	\N	2	0	\N	\N
352455	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Interdire l'usage des lanceurs de balles de défense	\N	2019-02-14 10:00:00	2019-02-14 10:30:00	\N	\N	1	0	\N	\N
352712	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL École de la confiance	PJL École de la confiance	2019-02-13 14:00:00	2019-02-13 15:00:00	\N	\N	5	0	\N	\N
352729	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL École de la confiance	PJL École de la confiance	2019-02-13 15:00:00	2019-02-13 16:00:00	\N	\N	5	0	\N	\N
352749	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL École de la confiance	PJL École de la confiance	2019-02-12 15:00:00	2019-02-12 16:00:00	\N	\N	6	0	\N	\N
352815	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Nouveaux territoires de la culture	MI Nouveaux territoires de la culture	2019-02-13 15:00:00	2019-02-13 16:00:00	\N	\N	10	0	\N	\N
352925	AUTRE_TEMPORAIRE	DEPLACEMENT	\N	\N	\N	Visite du Stade de France	\N	2019-02-12 17:00:00	2019-02-12 19:30:00	\N	\N	0	0	\N	\N
352979	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Mayotte question préalable	\N	2019-02-14 12:10:00	2019-02-14 12:15:00	2019-02-14 12:33:30	2019-02-14 16:10:43	8	0	\N	\N
353346	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	MSD Vaccins	\N	2019-02-14 09:15:00	2019-02-14 10:00:00	\N	\N	0	0	\N	\N
353847	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2019 - Fusion métropoles avec département - Déplacement à LYON	Contrôle 2019 - Fusion métropoles avec département - Déplacement à LYON	2019-02-18 06:30:00	2019-02-19 14:00:00	\N	\N	2	0	\N	\N
353850	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Conférence interparlementaire article 13 du TSCG à Bruxelles	Conférence interparlementaire article 13 du TSCG à Bruxelles	2019-02-18 09:45:00	2019-02-19 14:00:00	\N	\N	3	0	\N	\N
357037	COM_PERMANENTE	AUTRE	\N	SOCI	\N	audition plénière	\N	2019-03-13 09:30:00	2019-03-13 11:10:00	2019-03-13 11:08:23	2019-03-13 11:18:26	39	0	\N	\N
357424	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière	Examen conclusions auditions publiques	2019-03-21 09:30:00	2019-03-21 11:45:00	\N	\N	10	0	\N	\N
357444	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière	 Examen rapport Bilan des 12 premières notes scientifiques - Examen note Technologies quantiques	2019-03-28 09:15:00	2019-03-28 10:30:00	\N	\N	10	0	\N	\N
357616	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Frais d'inscription à l'université pour les étrangers extra-communautaires	Frais différenciés d'inscription à l'université pour les étrangers extra-communautaires	2019-03-05 18:00:00	2019-03-05 19:30:00	\N	\N	5	0	\N	\N
358068	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière	Réunion plénière	2019-03-07 08:45:00	2019-03-07 10:30:00	2019-03-07 11:09:45	\N	20	0	\N	\N
358887	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2019-03-07 14:00:00	2019-03-07 15:00:00	\N	\N	0	0	\N	\N
358888	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	audition de M. Milon, rapporteur du PJL Santé	\N	2019-03-07 14:00:00	2019-03-07 15:00:00	\N	\N	1	0	\N	\N
358889	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-03-13 11:10:00	2019-03-13 12:40:00	2019-03-14 11:52:37	2019-03-14 11:56:45	35	0	\N	\N
358901	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Protection des drapeaux d'associations d'anciens combattants	\N	2019-03-12 09:00:00	2019-03-12 12:00:00	\N	\N	2	0	\N	\N
360546	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Collectivité européenne d'Alsace	\N	2019-03-12 13:30:00	2019-03-12 14:30:00	\N	\N	1	0	\N	\N
360549	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Collectivité européenne d'Alsace	\N	2019-03-12 14:30:00	2019-03-12 16:00:00	\N	\N	2	0	\N	\N
360552	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Collectivité européenne d'Alsace	\N	2019-03-12 16:00:00	2019-03-12 16:45:00	\N	\N	1	0	\N	\N
360698	ETUDES	AUCUNE	\N	\N	\N	G.E. "Mer et Littoral"	G.E. "Mer et Littoral"	2019-03-12 08:30:00	2019-03-12 09:30:00	\N	\N	12	0	\N	908
361333	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Produits agricoles ou alimentaires	PPL Produits agricoles ou alimentaires	2019-03-14 10:30:00	2019-03-14 11:00:00	\N	\N	1	0	\N	\N
352732	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-02-20 09:35:00	2019-02-20 10:50:00	2019-02-20 11:40:48	2019-02-20 15:04:00	40	0	\N	\N
356865	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-03-06 09:00:00	2019-03-06 13:00:00	2019-03-06 13:20:40	2019-03-06 16:49:23	45	0	\N	\N
361503	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	206	Conférence de presse : rapport Arrêt commercialisation véhicules thermiques en 2040	Conférence de presse : rapport Arrêt commercialisation véhicules thermiques en 2040	2019-03-20 12:00:00	2019-03-20 13:00:00	\N	\N	0	0	\N	\N
362644	MISSION	AUDRAP	\N	CLIMATIQUE	\N	Audition DGSCGC	\N	2019-03-19 08:00:00	2019-03-19 09:00:00	\N	\N	11	0	\N	\N
362657	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition DDD	Audition Défenseur des droits	2019-03-20 11:05:00	2019-03-20 12:55:00	2019-03-20 15:14:19	2019-03-20 15:55:45	37	0	\N	\N
362658	MISSION	AUDRAP	\N	CLIMATIQUE	\N	Audition SMACL	\N	2019-03-19 09:00:00	2019-03-19 10:30:00	\N	\N	11	0	\N	\N
363122	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Système de santé	\N	2019-03-19 14:45:00	2019-03-19 17:00:00	\N	\N	11	0	\N	\N
363151	MISSION	AUCUNE	\N	INFRACTIONS	\N	Auditions L'Ange bleu - Alexis Danan - L'Enfant bleu	Auditions	2019-03-26 18:00:00	2019-03-26 20:00:00	2019-03-27 15:03:56	2019-03-27 17:51:05	7	0	\N	\N
363152	MISSION	AUCUNE	\N	INFRACTIONS	\N	Auditions	\N	2019-03-26 14:45:00	2019-03-26 16:30:00	2019-03-26 16:28:19	2019-03-26 18:02:14	12	0	\N	\N
363529	SEANCE_PLENIERE	DECL_GVT	\N	\N	\N	Déclaration du Gouvernement suivie d'un débat - Grand débat national	Déclaration du Gouvernement suivie d'un débat - Grand débat national	2019-04-10 16:30:00	2019-04-10 20:35:00	\N	\N	262	0	\N	\N
363530	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Programme de stabilité 2019-2023	Débat Programme de stabilité 2019-2023	2019-04-29 17:00:00	2019-04-29 18:55:00	\N	\N	35	0	\N	\N
363531	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Zone euro	Débat Zone euro	2019-04-30 14:30:00	2019-04-30 16:15:00	\N	\N	86	0	\N	\N
363532	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2019-04-30 16:45:00	2019-04-30 17:45:00	\N	\N	270	0	\N	\N
363541	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Recyclage du plastique	Débat Recyclage du plastique	2019-04-30 17:55:00	2019-04-30 19:35:00	\N	\N	34	0	\N	\N
363545	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Droit de résiliation contrats santé	PPL Droit de résiliation contrats santé	2019-05-02 14:30:00	2019-05-02 16:50:00	\N	\N	68	0	\N	\N
363547	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Crime d'écocide	PPL Crime d'écocide	2019-05-02 18:30:00	2019-05-02 20:00:00	\N	\N	0	0	\N	\N
363548	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Crime d'écocide	PPL Crime d'écocide	2019-05-02 21:50:00	2019-05-03 00:30:00	\N	\N	27	0	\N	\N
213249	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Accueil des gens du voyage	\N	2017-10-31 09:05:00	2017-10-31 09:15:00	2017-10-31 14:26:20	2017-10-31 18:12:43	23	0	\N	\N
213253	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	P¨LF 2018 - Avis "Administration pénitentiaire"	\N	2017-10-23 14:30:00	2017-10-23 16:20:00	\N	\N	1	0	\N	\N
213255	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2018 - Avis Administration pénitentiiaire	\N	2017-10-26 10:40:00	2017-10-26 11:50:00	\N	\N	1	0	\N	\N
213392	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE  PLF 2018 Agriculture	Aud. Rapp. CAE PLF 2018 Agriculture	2017-10-24 14:15:00	2017-10-24 16:30:00	\N	\N	3	0	\N	\N
213396	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE PLF 2018 Agriculture	Aud.Rapp. CAE PLF 2018 Agriculture	2017-10-25 14:15:00	2017-10-25 17:30:00	\N	\N	2	0	\N	\N
213399	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aud. Rapp. CAE - PLF 2018 Agriculture	Aud. Rapp. CAE - PLF 2018 Agriculture	2017-10-26 14:00:00	2017-10-26 15:00:00	\N	\N	3	0	\N	\N
213403	GIA	AUCUNE	\N	\N	\N	Visite d¿une délégation de parlementaires saoudiens du Majlis	Visite d¿une délégation de parlementaires saoudiens du Majlis	2017-10-30 14:00:00	2017-10-30 15:00:00	\N	\N	1	0	661	\N
215757	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2018 (avis PJJ)	\N	2017-11-07 08:00:00	2017-11-07 12:30:00	\N	\N	1	0	\N	\N
215763	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2018 (avis Immigration)	\N	2017-11-07 14:00:00	2017-11-07 15:00:00	\N	\N	1	0	\N	\N
215768	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2018 (avis Immigration)	\N	2017-11-07 15:00:00	2017-11-07 16:45:00	\N	\N	2	0	\N	\N
215775	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2018 (avis Immigration)	\N	2017-11-07 16:45:00	2017-11-07 19:00:00	\N	\N	1	0	\N	\N
226368	GIA	AUCUNE	\N	\N	\N	Rencontre avec M. Régis Savioz (CICR)	Rencontre avec M. Régis Savioz (CICR)	2017-12-01 15:00:00	2017-12-01 16:00:00	\N	\N	1	0	644	\N
228464	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Rapport d'information Polynésie française	\N	2017-12-13 12:45:00	2017-12-13 13:30:00	2017-12-13 15:44:22	2017-12-13 16:30:28	13	0	\N	\N
228988	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion	Réunion	2017-12-13 11:40:00	2017-12-13 12:55:00	2017-12-13 13:01:10	2017-12-13 15:06:59	28	1	\N	\N
238968	COM_PERMANENTE	AUTRE	\N	AFCL	\N	PJL Organisation des JOP de 2024	PJL Organisation des JOP de 2024	2018-01-30 14:00:00	2018-01-30 15:00:00	2018-01-30 16:01:44	2018-01-30 17:38:17	34	1	\N	\N
240864	ETUDES	AUCUNE	\N	\N	\N	\N	\N	2018-02-01 14:00:00	2018-02-01 14:40:00	\N	\N	28	0	\N	909
240896	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de M. François Bourdillon, DG de Santé publique France	Audition de M. François Bourdillon, directeur général de Santé publique France	2018-02-07 09:00:00	2018-02-07 10:30:00	2018-02-07 16:39:06	2018-02-08 14:46:35	56	0	\N	\N
240897	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de M. Nicolas Dufourcq, directeur général de Bpifrance ;	Audition de M. Nicolas Dufourcq, directeur général de Bpifrance ;	2018-02-07 10:45:00	2018-02-07 12:25:00	2018-02-07 16:39:28	2018-02-08 14:46:30	28	0	\N	\N
241093	MISSION	AUDRAP	\N	ALSTOM	\N	\N	\N	2018-01-30 14:30:00	2018-01-30 15:30:00	\N	\N	10	0	\N	\N
241104	MISSION	AUDRAP	\N	ALSTOM	\N	\N	\N	2018-01-30 15:30:00	2018-01-30 16:30:00	\N	\N	8	0	\N	\N
241113	MISSION	AUDRAP	\N	ALSTOM	\N	\N	\N	2018-01-30 18:00:00	2018-01-30 19:00:00	\N	\N	4	0	\N	\N
241241	COM_ENQUETE	PLENIERE	\N	FORCES	\N	Auditions fédérations police nationale et M. Lebeau et Mme Biskupski	\N	2018-02-07 14:05:00	2018-02-07 18:30:00	2018-02-20 15:46:07	\N	12	0	\N	\N
244339	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe	Assemblée générale du groupe	2018-01-31 11:30:00	2018-01-31 12:00:00	\N	\N	6	0	657	\N
255500	ETUDES	AUCUNE	\N	\N	\N	G.E. "Agriculture et alimentation"	G.E. "Agriculture et alimentation"	2018-03-14 08:00:00	2018-03-14 09:00:00	\N	\N	25	0	\N	919
255561	COM_ENQUETE	PLENIERE	\N	FORCES	\N	CE état des forces de sécurité intérieure	\N	2018-03-14 14:50:00	2018-03-14 17:40:00	2018-03-14 18:32:23	2018-03-15 09:42:28	9	0	\N	\N
258970	GIA	AUCUNE	\N	\N	\N	Rencontre avec Mme l'ambassadrice d¿El Salvador en France	Rencontre avec S. Exc. Mme Carmen Maria Gallardo de Hernandez, ambassadrice d¿El Salvador en France	2018-03-22 14:30:00	2018-03-22 15:30:00	\N	\N	1	0	643	\N
228463	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Nom° rapporteurs + PPL police prox + PPR législ° com° + PJL DDADUE sécurité + PPL Gemapi	\N	2017-12-13 10:10:00	2017-12-13 12:45:00	2017-12-13 15:45:03	2017-12-13 16:30:30	45	0	\N	\N
262373	GIA	AUCUNE	\N	\N	\N	Rencontre autour de l'entreprenariat Taïwanais	Rencontre autour de l'entreprenariat Taïwanais	2018-04-03 19:00:00	2018-04-03 20:30:00	\N	\N	8	0	623	\N
262382	GIA	AUCUNE	\N	\N	\N	Dîner autour de l'entreprenariat taïwanais	Dîner autour de l'entreprenariat taïwanais	2018-04-03 20:00:00	2018-04-03 22:30:00	\N	\N	3	0	623	\N
262464	ETUDES	AUCUNE	\N	\N	\N	G.E. "Développement économique de la montagne"	G.E. "Développement économique de la montagne"	2018-04-03 08:30:00	2018-04-03 09:30:00	\N	\N	7	0	\N	918
262478	ETUDES	AUCUNE	\N	\N	\N	G.E. "Elevage"	G.E. "Elevage"	2018-04-04 09:00:00	2018-04-04 10:00:00	\N	\N	14	0	\N	911
262558	COM_ENQUETE	DEPLACEMENT	\N	FORCES	\N	Déplacement à Coulommiers	Déplacement à Coulommiers	2018-04-04 13:00:00	2018-04-04 20:15:00	\N	\N	7	0	\N	\N
262966	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion conjointe Assemblée nationale - Parlement européen 	Réunion conjointe Assemblée nationale - Parlement européen	2018-04-05 09:05:00	2018-04-05 11:00:00	2018-04-05 12:19:59	2018-04-05 14:15:00	22	0	\N	\N
263065	DELEGATION	AUCUNE	\N	\N	211	Audition de Mme Françoise Thébaud, historienne	Audition de Mme Françoise Thébaud, historienne	2018-04-05 10:00:00	2018-04-05 12:30:00	2018-04-05 13:03:21	2018-04-05 14:04:50	19	0	\N	\N
264155	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2018 - Mission "Recherche et Ens. sup." - Performance établissements ens. sup	Contrôle 2018 - Mission "Recherche et Ens. sup." - Performance établissements ens. sup - Déplacement à Rennes	2018-04-05 08:00:00	2018-04-05 17:30:00	\N	\N	1	0	\N	\N
264173	DELEGATION	AUDRAP	\N	\N	PROS	Audition du Conseil d'Orientation pour l'Emploi	\N	2018-04-19 16:30:00	2018-04-19 17:20:00	\N	\N	2	0	\N	\N
264185	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	FINC	\N	Propositions Directives Taxation activités numériques - Audition DLF	Propositions de  Directives Taxation activités numériques - Audition DLF	2018-04-05 16:00:00	2018-04-05 17:00:00	\N	\N	3	0	\N	\N
264186	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	FINC	\N	\N	\N	2018-04-04 15:30:00	2018-04-04 16:15:00	\N	\N	0	0	\N	\N
264187	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	FINC	\N	\N	\N	2018-04-04 17:00:00	2018-04-04 18:00:00	\N	\N	0	0	\N	\N
264188	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	FINC	\N	\N	\N	2018-04-04 18:00:00	2018-04-04 19:00:00	\N	\N	0	0	\N	\N
264189	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Propositions Directives Taxation activités numériques - Auditions France Digitale	Propositions de  Directives Taxation activités numériques - Auditions  France Digitale - Blablacar - Drivy - OCDE	2018-04-04 15:30:00	2018-04-04 19:00:00	\N	\N	5	0	\N	\N
264200	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Réforme de la procédure budgétaire - Échange de vues	Réforme de la procédure budgétaire - Échange de vues	2018-04-04 09:30:00	2018-04-04 10:30:00	\N	\N	10	0	\N	\N
264201	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle modernisation de la navigation aérienne	Contrôle modernisation de la navigation aérienne - Déplacement Rungis Sky Center	2018-04-04 15:00:00	2018-04-04 18:00:00	\N	\N	1	0	\N	\N
264204	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Sport	PLF pour 2019 - Sport - Audition  Fonjep	2018-04-03 14:45:00	2018-04-03 15:45:00	\N	\N	1	0	\N	\N
264214	COM_EURO	AUDRAP	\N	AFEU	\N	Direction générale des entreprises	\N	2018-04-03 17:15:00	2018-04-03 18:15:00	\N	\N	2	0	\N	\N
264215	COM_EURO	AUDRAP	\N	AFEU	\N	Audition de l'Afnor	\N	2018-04-04 10:00:00	2018-04-04 11:00:00	\N	\N	2	0	\N	\N
264216	COM_EURO	AUDRAP	\N	AFEU	\N	\N	\N	2018-04-05 17:05:00	2018-04-05 18:25:00	\N	\N	2	0	\N	\N
264223	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2019 - Mission APD -  AFD	PLF pour 2019 - Mission APD -  AFD	2018-04-03 16:40:00	2018-04-03 17:20:00	\N	\N	5	0	\N	\N
279125	MISSION	AUCUNE	\N	HERBE	\N	Audition plénière	\N	2018-05-31 15:05:00	2018-05-31 16:50:00	2018-05-31 18:05:51	2018-06-01 09:33:03	13	0	\N	\N
376926	DELEGATION	AUCUNE	\N	\N	DSOM	Réunion plénière (audition à définir)	\N	2019-05-28 15:30:00	2019-05-28 16:45:00	\N	\N	6	0	\N	\N
376927	COM_PERMANENTE	DEPLACEMENT	\N	SOCI	\N	Déplacement MM. Morisset et Arnell	\N	2019-05-15 14:30:00	2019-05-15 17:15:00	\N	\N	2	0	\N	\N
376930	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Conséquences de la fraude documentaire sur la fraude aux prestations sociales	Conséquences de la fraude documentaire sur la fraude aux prestations sociales	2019-05-22 14:30:00	2019-05-22 15:30:00	\N	\N	1	0	\N	\N
376932	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Organisation du système de santé	PJL Organisation du système de santé	2019-05-10 14:00:00	2019-05-10 14:45:00	\N	\N	1	0	\N	\N
392879	GIA	AUCUNE	\N	\N	\N	Présentation du livre "La Moldavie à la croisée des chemins"	Rencontre avec Mme Josette Durrieu et Florent Parmentier, auteurs du livre "La Moldavie à la croisée des chemins"	2019-06-18 17:30:00	2019-06-18 19:00:00	\N	\N	2	0	851	\N
396050	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-07-03 09:45:00	2019-07-03 12:20:00	2019-07-03 15:07:05	2019-07-03 15:56:33	38	2	\N	\N
396079	DELEGATION	AUDRAP	\N	\N	206	Audition de Mme Ghislaine Dehaene-Lambertz (Neurosciences)	Audition de Mme Ghislaine Dehaene-Lambertz (Neurosciences)	2019-07-09 17:00:00	2019-07-09 18:00:00	\N	\N	0	0	\N	\N
396125	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Energie - Auditions M. Gremillet	PJL Energie - Auditions M. Gremillet	2019-06-26 16:00:00	2019-06-26 18:00:00	\N	\N	2	0	\N	\N
396191	ETUDES	AUCUNE	\N	\N	\N	Auditions sur le thème de la noix	Auditions sur le thème de la noix	2019-06-26 08:00:00	2019-06-26 09:15:00	\N	\N	9	0	\N	1005
400462	COM_ENQUETE	AUDRAP	\N	SOUVERAINETE	\N	C.E. "Souveraineté numérique"	C.E. "Souveraineté numérique"	2019-07-09 18:15:00	2019-07-09 19:15:00	\N	\N	2	0	\N	\N
400465	COM_ENQUETE	PLENIERE	\N	SOUVERAINETE	\N	C.E. "Souveraineté numérique"	C.E. "Souveraineté numérique"	2019-07-10 14:00:00	2019-07-10 19:00:00	2019-07-11 16:59:21	2019-07-11 17:44:17	3	0	\N	\N
400469	COM_ENQUETE	AUDRAP	\N	SOUVERAINETE	\N	C.E. "Souveraineté numérique"	C.E. "Souveraineté numérique"	2019-07-10 15:00:00	2019-07-10 16:00:00	\N	\N	4	0	\N	\N
400474	COM_ENQUETE	PLENIERE	\N	SOUVERAINETE	\N	C.E. "Souveraineté numérique"	C.E. "Souveraineté numérique"	2019-07-11 09:45:00	2019-07-11 11:00:00	2019-07-11 17:07:22	2019-07-11 17:44:18	7	0	\N	\N
400482	COM_ENQUETE	AUDRAP	\N	SOUVERAINETE	\N	C.E. 	C.E. "Souveraineté numérique"	2019-07-11 08:30:00	2019-07-11 09:30:00	\N	\N	5	0	\N	\N
400489	COM_ENQUETE	AUDRAP	\N	SOUVERAINETE	\N	C.E. "Souveraineté numérique"	C.E. "Souveraineté numérique"	2019-07-11 11:00:00	2019-07-11 12:30:00	\N	\N	3	0	\N	\N
281772	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen Amdts séance sur PPL 460 revitalisation des centres-villes et centres-bourgs	Examen Amdts séance sur PPL 460 revitalisation des centres-villes et centres-bourgs	2018-06-13 09:00:00	2018-06-13 10:25:00	2018-06-13 23:26:10	2018-06-14 09:49:56	45	1	\N	\N
400578	CMP	AUTRE	\N	MOBILITES	\N	PJL Orientation des mobilités	PJL Orientation des mobilités	2019-07-10 16:39:00	2019-07-10 18:35:00	\N	\N	11	0	\N	\N
401846	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Nouveaux territoires de la culture	MI Nouveaux territoires de la culture	2019-07-16 16:00:00	2019-07-16 19:20:00	\N	\N	6	0	\N	\N
413950	GIA	AUCUNE	\N	\N	\N	Coopé_Visite de Mme Tamar Khulordava (Parlement géorgien)	Coopé_Visite de Mme Tamar Khulordava (Parlement géorgien)	2019-10-09 13:00:00	2019-10-09 14:30:00	\N	\N	1	0	534	\N
414076	DELEGATION	AUCUNE	\N	\N	206	Petit déjeuner Office-Académies Recherche participative et recherche hors murs	Petit déjeuner Office-Académies sur le thème de la recherche participative et de la recherche hors murs	2019-10-23 08:30:00	2019-10-23 10:00:00	\N	\N	0	0	\N	\N
414077	DELEGATION	DEPLACEMENT	\N	\N	206	Déplacement à la centrale de Dampierre-en-Burly (Loiret)	Déplacement à la centrale de Dampierre-en-Burly (Loiret)	2019-10-24 08:00:00	2019-10-24 18:00:00	\N	\N	2	0	\N	\N
414078	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière	Audition publique sur les enjeux du conseil ministériel de l'Agence spatiale européenne	2019-10-29 17:05:00	2019-10-29 19:30:00	\N	\N	5	0	\N	\N
414079	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière	Réunion plénière 	2019-11-07 09:40:00	2019-11-07 12:45:00	\N	\N	14	0	\N	\N
420382	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT États généraux de l'alimentation	présentation des orientations du premier bilan du titre Ier de la loi EGALIM	2019-10-22 11:00:00	2019-10-22 12:00:00	\N	\N	11	0	\N	\N
420415	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT États généraux de l'alimentation	GT États généraux de l'alimentation - Réunion d'arbitrage	2019-10-22 13:00:00	2019-10-22 14:30:00	\N	\N	3	0	\N	\N
421708	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS Budget 2020 - Equilibres financiers généraux	\N	2019-10-29 16:15:00	2019-10-29 16:50:00	\N	\N	1	0	\N	\N
439807	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion 20191217	\N	2019-12-17 09:05:00	2019-12-17 09:47:00	2019-12-17 10:08:57	2019-12-17 16:50:22	12	0	\N	\N
439845	COM_SPECIALE	AUDRAP	\N	BIOETHIQUE	\N	Audition DGS	\N	2019-12-12 08:15:00	2019-12-12 10:15:00	\N	\N	4	0	\N	\N
458963	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Audition de la représentation permanente des Pays-Bas auprès de l'UE	\N	2020-01-14 08:30:00	2020-01-14 09:45:00	\N	\N	0	0	\N	\N
458964	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Audition du Cabinet de Thierry Breton	\N	2020-01-14 09:45:00	2020-01-14 11:15:00	\N	\N	0	0	\N	\N
458977	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Audition DG concurrence et cabinet de la VP de la commission en charge de la concurrence	\N	2020-01-14 11:15:00	2020-01-14 12:30:00	\N	\N	0	0	\N	\N
458978	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Audition Philippe Léglise-Costa	\N	2020-01-14 12:30:00	2020-01-14 13:30:00	\N	\N	0	0	\N	\N
458979	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Audition Business Europe	\N	2020-01-14 15:15:00	2020-01-14 16:30:00	\N	\N	0	0	\N	\N
458980	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Audiction BEUC	\N	2020-01-14 16:30:00	2020-01-14 17:30:00	\N	\N	0	0	\N	\N
459039	ETUDES	AUTRE	\N	\N	\N	Auditions GE Cancer	\N	2020-02-25 14:00:00	2020-02-25 16:00:00	\N	\N	5	0	\N	1004
459085	COM_EURO	AUDRAP	\N	AFEU	\N	Auditions M.P. Leclerc	\N	2020-02-24 14:00:00	2020-02-24 15:00:00	\N	\N	1	0	\N	\N
459086	COM_EURO	AUDRAP	\N	AFEU	\N	Audition - Dimitri Keridis	\N	2020-02-24 15:30:00	2020-02-24 16:30:00	\N	\N	1	0	\N	\N
459087	COM_EURO	AUDRAP	\N	AFEU	\N	Audition - Georgios KOTSIRAS	\N	2020-02-24 16:45:00	2020-02-24 17:30:00	\N	\N	1	0	\N	\N
459088	COM_EURO	AUDRAP	\N	AFEU	\N	Audition - G. Markopouliotis	\N	2020-02-25 11:15:00	2020-02-25 12:15:00	\N	\N	1	0	\N	\N
463607	DELEGATION	AUCUNE	\N	\N	206	Point sur la situation de l'épidémie de coronavirus	\N	2020-03-27 09:30:00	2020-03-27 11:00:00	\N	\N	13	0	\N	\N
466208	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi Covid-19 - Droit électoral	Suivi Covid-19 - Droit électoral	2020-04-14 08:45:00	2020-04-14 11:00:00	\N	\N	11	0	\N	\N
466220	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi Covid-19 - Droit électoral	\N	2020-04-22 11:00:00	2020-04-22 12:00:00	\N	\N	5	0	\N	\N
468391	COM_PERMANENTE	AUTRE	\N	CAE	\N	\N	\N	2020-05-06 09:30:00	2020-05-06 12:40:00	\N	\N	35	0	\N	\N
468538	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Famille/Mme Doineau - Table ronde de représentants de crèches (visioconférence)	\N	2020-04-20 10:00:00	2020-04-20 11:45:00	\N	\N	4	0	\N	\N
468554	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Hébergement d'urgence/M. Morisset - Audition de la FAS (visioconférence)	\N	2020-04-21 14:30:00	2020-04-21 15:35:00	\N	\N	2	0	\N	\N
468587	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Hébergement d'urgence/M. Morisset - Audition du Samu social de Paris (visioconférence)	\N	2020-04-21 15:45:00	2020-04-21 16:50:00	\N	\N	3	0	\N	\N
468593	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Hébergement d'urgence/M. Morisset - Audition de la Croix-Rouge française (visioconférence)	\N	2020-04-23 14:30:00	2020-04-23 15:30:00	\N	\N	2	0	\N	\N
456714	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions rapporteur - PJL DADUE	PJL Adaptation au droit de l'Union européenne en matière économique et financière	2020-02-19 16:30:00	2020-02-19 18:00:00	\N	\N	1	0	\N	\N
456725	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - Les aides à la presse - Table ronde éditeurs	Contrôle 2020 - Les aides à la presse - Table ronde éditeurs	2020-02-14 14:30:00	2020-02-14 16:00:00	\N	\N	1	0	\N	\N
456727	COM_ENQUETE	PLENIERE	\N	SOLS	\N	Réunion commission	\N	2020-02-26 16:53:00	2020-02-26 20:10:00	2020-02-28 17:17:53	2020-02-28 17:18:53	9	0	\N	\N
456728	COM_ENQUETE	AUDRAP	\N	AUTOROUT	\N	CE concessions autoroutières - Auditions Journalistes	CE concessions autoroutières - Auditions Journalistes	2020-02-27 10:00:00	2020-02-27 12:50:00	\N	\N	6	0	\N	\N
456735	COM_SPECIALE	AUDRAP	\N	ASAP	\N	Auditions CS ASAP	\N	2020-02-18 18:00:00	2020-02-18 18:30:00	\N	\N	7	0	\N	\N
456743	COM_SPECIALE	AUDRAP	\N	ASAP	\N	Auditions CS ASAP	\N	2020-02-18 17:00:00	2020-02-18 17:30:00	\N	\N	12	0	\N	\N
456745	COM_SPECIALE	AUDRAP	\N	ASAP	\N	a	\N	2020-02-18 17:30:00	2020-02-18 18:00:00	\N	\N	12	0	\N	\N
458947	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Français établis hors de France - Examen du rapport et du texte  de la commission	PPL Français établis hors de France - Examen du rapport et du texte  de la commission	2020-03-04 10:30:00	2020-03-04 12:00:00	2020-03-04 12:02:04	2020-03-04 16:20:00	43	0	\N	\N
456716	COM_PERMANENTE	AUTRE	\N	LOIS	\N	 Victimes  violences conjugales : Nomination rapporteur - Haine internet : Exam amdts 	 Victimes  violences conjugales : Nomination rapporteur - Haine internet : Exam amdts 	2020-02-26 10:05:00	2020-02-26 10:25:00	2020-02-26 12:16:22	2020-02-26 17:33:07	39	0	\N	\N
456749	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - Héritage jeux olympiques et paralympiques 2024 - DB	Contrôle 2020 - Héritage jeux olympiques et paralympiques 2024 - DB	2020-02-19 13:30:00	2020-02-19 14:15:00	\N	\N	1	0	\N	\N
456762	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Conférence interparlementaire article 13 du TSCG à Bruxelles - Fev 2020	Conférence interparlementaire article 13 du TSCG à Bruxelles - Fev 2020	2020-02-18 10:25:00	2020-02-18 21:40:00	\N	\N	3	0	\N	\N
456766	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - ENAP - Direction de l'administration pénitentiaire	Contrôle 2020 - ENAP - Direction de l'administration pénitentiaire	2020-02-19 18:00:00	2020-02-19 19:00:00	\N	\N	1	0	\N	\N
456768	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - ENAP - APIJ	Contrôle 2020 - ENAP - APIJ	2020-02-20 10:00:00	2020-02-20 11:00:00	\N	\N	1	0	\N	\N
456770	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - Financement politiques lutte contre violences femmes - FNSF et CIDFF / NID	Contrôle 2020 - Financement politiques lutte contre violences femmes - FNSF et CIDFF / NID	2020-02-20 14:00:00	2020-02-20 17:00:00	\N	\N	2	0	\N	\N
456773	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - CNCCFP - CSA	Contrôle 2019 - CNCCFP - CSA	2020-02-19 14:00:00	2020-02-19 15:00:00	\N	\N	1	0	\N	\N
457083	COM_ENQUETE	PLENIERE	\N	RADICALI	\N	Audition de Frédéric VEAUX, directeur général de la police nationale	Audition de Frédéric VEAUX, directeur général de la police nationale	2020-02-25 17:00:00	2020-02-25 18:25:00	2020-02-26 09:02:11	2020-02-26 11:21:36	12	0	\N	\N
457225	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition GT Nouvelles formes de commerce - Rapporteur M. Babary	Audition GT Nouvelles formes de commerce - Rapporteur M. Babary	2020-02-25 10:00:00	2020-02-25 10:45:00	\N	\N	1	0	\N	\N
457227	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition GT Nouvelles formes de commerce - Rapporteur M. Babary	Audition GT Nouvelles formes de commerce - Rapporteur M. Babary	2020-02-25 14:00:00	2020-02-25 17:00:00	\N	\N	1	0	\N	\N
457414	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition MI Gouvernance des ports maritimes -Présidente Mme Filleul, Rapporteur M. Vaspart	Audition MI Gouvernance des ports maritimes -Présidente Mme Filleul, Rapporteur M. Vaspart	2020-02-25 08:30:00	2020-02-25 09:30:00	\N	\N	3	0	\N	\N
457422	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition MI Gouvernance des ports maritimes -Présidente Mme Filleul, Rapporteur M. Vaspart	Audition MI Gouvernance des ports maritimes -Présidente Mme Filleul, Rapporteur M. Vaspart	2020-02-25 14:34:00	2020-02-25 17:21:00	\N	\N	5	0	\N	\N
457428	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition MI Gouvernance des ports maritimes -Présidente Mme Filleul, Rapporteur M. Vaspart	Audition MI Gouvernance des ports maritimes -Présidente Mme Filleul, Rapporteur M. Vaspart	2020-02-25 15:15:00	2020-02-25 16:05:00	\N	\N	3	0	\N	\N
457432	COM_PERMANENTE	DEPLACEMENT	\N	CDD	\N	MI Gouvernance des ports maritimes -Présidente Mme Filleul, Rapporteur M. Vaspart	MI Gouvernance des ports maritimes -Présidente Mme Filleul, Rapporteur M. Vaspart	2020-02-21 10:00:00	2020-02-21 16:00:00	\N	\N	5	0	\N	\N
457438	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GS Stratégie industrielle de l'Union européenne	Audition de M. COZIGOU - Directeur général faisant fonction DG GROW - Commission européenne	2020-02-26 08:30:00	2020-02-26 09:15:00	\N	\N	3	0	\N	\N
457443	COM_PERMANENTE	DEPLACEMENT	\N	CDD	\N	MI Gouvernance des ports maritimes -Présidente Mme Filleul, Rapporteur M. Vaspart	MI Gouvernance des ports maritimes -Présidente Mme Filleul, Rapporteur M. Vaspart	2020-02-24 10:00:00	2020-02-24 13:30:00	\N	\N	4	0	\N	\N
457448	COM_PERMANENTE	DEPLACEMENT	\N	CDD	\N	MI Gouvernance des ports maritimes -Présidente Mme Filleul, Rapporteur M. Vaspart	MI Gouvernance des ports maritimes -Présidente Mme Filleul, Rapporteur M. Vaspart	2020-02-24 15:15:00	2020-02-24 17:45:00	\N	\N	4	0	\N	\N
458318	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution plastique	Audition rapporteurs Pollution plastique (OFB)	2020-02-27 16:15:00	2020-02-27 17:15:00	\N	\N	2	0	\N	\N
458658	QUESTURE	AUCUNE	\N	\N	\N	Consiel de Questure	Conseil de Questure	2020-02-18 14:30:00	2020-02-18 16:30:00	\N	\N	3	0	\N	\N
458948	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	GT Métier d'enseignant	GT Métier d'enseignant	2020-02-26 16:15:00	2020-02-26 17:30:00	\N	\N	3	0	\N	\N
378894	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Sources de financement du logement social - FOPH / USH	Contrôle 2019 - Sources de financement du logement social - FOPH / USH	2019-05-09 14:30:00	2019-05-09 16:45:00	\N	\N	1	0	\N	\N
502820	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2021 - Avis asile, immigration, intégration et nationalité	PLF pour 2021 - Avis asile, immigration, intégration et nationalité	2020-11-12 10:25:00	2020-11-12 11:40:00	\N	\N	2	0	\N	\N
457565	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2020-02-26 12:25:00	2020-02-26 12:30:00	2020-02-28 16:47:29	2020-02-28 16:48:58	40	1	\N	\N
378915	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - CNCCFP - Médiateur du crédit aux candidats et aux partis politiques	Contrôle 2019 - CNCCFP - Médiateur du crédit aux candidats et aux partis politiques	2019-05-14 11:00:00	2019-05-14 12:45:00	\N	\N	1	0	\N	\N
378916	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - CNCCFP - Observatoire de l'éthique publique	Contrôle 2019 - CNCCFP - Observatoire de l'éthique publique	2019-05-14 15:00:00	2019-05-14 16:00:00	\N	\N	1	0	\N	\N
386069	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Transformation de la fonction publique	\N	2019-06-04 14:00:00	2019-06-04 15:00:00	\N	\N	3	0	\N	\N
386073	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Transformation de la fonction publique	\N	2019-06-04 15:00:00	2019-06-04 17:00:00	\N	\N	2	0	\N	\N
386079	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Transformation de la fonction publique	\N	2019-06-04 18:00:00	2019-06-04 19:30:00	\N	\N	2	0	\N	\N
386357	MISSION	AUCUNE	\N	SIDERURGIE	\N	Plénière - Auditions	\N	2019-06-05 14:30:00	2019-06-05 17:15:00	2019-06-07 12:27:39	2019-06-07 14:28:04	12	0	\N	\N
390317	MISSION	AUTRE	\N	FONDS	\N	Association des Directeurs Généraux des Communautés de France (ADGCF)	\N	2019-06-19 15:03:00	2019-06-19 16:00:00	2019-06-19 18:21:23	2019-06-20 16:08:32	7	0	\N	\N
401906	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-07-24 09:35:00	2019-07-24 11:35:00	2019-07-24 16:16:31	2019-07-24 16:21:42	22	0	\N	\N
421702	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2020 - Travail et emploi	\N	2019-10-29 18:15:00	2019-10-29 19:00:00	\N	\N	1	0	\N	\N
421703	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS Budget 2020 - Equilibres financiers généraux	\N	2019-10-29 15:00:00	2019-10-29 16:15:00	\N	\N	2	0	\N	\N
421705	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2020 - Travail et emploi	\N	2019-10-29 19:00:00	2019-10-29 19:45:00	\N	\N	2	0	\N	\N
421728	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Travailleurs indépendants	\N	2019-10-29 16:30:00	2019-10-29 17:30:00	\N	\N	3	0	\N	\N
421730	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Travailleurs indépendants	\N	2019-10-29 17:30:00	2019-10-29 18:30:00	\N	\N	3	0	\N	\N
421738	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Assurance maladie	\N	2019-10-29 14:00:00	2019-10-29 15:00:00	\N	\N	1	0	\N	\N
421859	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Rapport général - MEDEF	PLF pour 2020 - Rapport général - MEDEF	2019-10-29 12:45:00	2019-10-29 14:00:00	\N	\N	1	0	\N	\N
421861	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Culture - Réunion Musées nationaux - Grand Palais	PLF pour 2020 - Culture - Réunion Musées nationaux - Grand Palais	2019-10-29 14:15:00	2019-10-29 15:15:00	\N	\N	1	0	\N	\N
421882	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - GFPRH - DGDDI	PLF pour 2020 - GFPRH - DGDDI	2019-10-28 18:30:00	2019-10-28 19:35:00	\N	\N	2	0	\N	\N
421915	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - GFPRH - Secrétaire d'État Action et des comptes publics	PLF pour 2020 - GFPRH - Secrétaire d'État Action et des comptes publics	2019-10-29 18:30:00	2019-10-29 19:30:00	\N	\N	2	0	\N	\N
426316	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2019-12-11 15:01:00	2019-12-11 16:21:00	\N	\N	260	0	\N	\N
426317	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Usages dangereux du protoxyde d'azote	PPL Usages dangereux du protoxyde d'azote	2019-12-11 16:36:00	2019-12-11 18:31:00	\N	\N	60	0	\N	\N
426318	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat OTAN	Débat OTAN	2019-12-12 10:31:00	2019-12-12 12:00:00	\N	\N	28	0	\N	\N
426319	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR Résilience alimentaire	PPR Résilience alimentaire	2019-12-12 14:30:00	2019-12-12 18:30:00	\N	\N	28	0	\N	\N
426320	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Prévention suicide des agriculteurs	PPL Prévention suicide des agriculteurs	2019-12-12 15:35:00	2019-12-12 18:30:00	\N	\N	24	0	\N	\N
431205	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Politique énergétique	Débat Politique énergétique	2019-12-11 18:32:00	2019-12-11 20:07:00	\N	\N	35	0	\N	\N
437609	GIA	AUCUNE	\N	\N	\N	Rencontre avec M. Mykola Siruk	Rencontre avec M. Mykola Siruk, journaliste ukrainien	2019-11-21 11:30:00	2019-11-21 12:30:00	\N	\N	1	0	530	\N
437611	GIA	AUCUNE	\N	\N	\N	Rencontre avec M. Oleg Sentsov	Rencontre avec M. Oleg Sentsov, cinéaste ukrainien	2019-12-03 08:30:00	2019-12-03 09:30:00	\N	\N	2	0	530	\N
453664	COM_SPECIALE	PLENIERE	\N	ASAP	\N	Réunion constitutive	\N	2020-02-06 10:30:00	2020-02-06 10:55:00	2020-02-06 14:49:23	2020-02-06 16:10:58	13	0	\N	\N
453742	DELEGATION	AUDRAP	\N	\N	DSOM	Reunion du président avec le Délégué interministériel aux risques majeurs outre-mer	\N	2020-02-06 17:30:00	2020-02-06 19:45:00	\N	\N	0	0	\N	\N
453967	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 10	\N	2020-02-19 09:35:00	2020-02-19 12:45:00	2020-02-19 17:19:42	2020-02-19 17:59:11	37	0	\N	\N
453990	DELEGATION	AUCUNE	\N	\N	211	Les retraites des agricultrices	Les retraites des agricultrices	2020-02-18 17:00:00	2020-02-18 19:00:00	2020-02-18 19:14:02	\N	12	0	\N	\N
453991	DELEGATION	AUCUNE	\N	\N	211	Réunion plénière dont audition de M. Bertrand FRAGONARD (HCFEA)	Réunion plénière dont audition de M. Bertrand FRAGONARD (HCFEA)	2020-02-20 08:30:00	2020-02-20 12:00:00	2020-02-20 14:42:26	\N	11	0	\N	\N
455309	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Assurance récolte	GT Assurance récolte	2020-02-18 16:15:00	2020-02-18 17:30:00	\N	\N	5	0	\N	\N
463507	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition de Mme Frédérique Vidal (visioconférence-format restreint)	Audition de Mme Frédérique Vidal (visioconférence-format restreint)	2020-04-01 18:10:00	2020-04-01 19:20:00	\N	\N	13	0	\N	\N
463744	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2020-03-31 14:45:00	2020-03-31 17:00:00	\N	\N	3	0	\N	\N
470168	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi Covid-19 - Droit électoral	\N	2020-05-13 17:30:00	2020-05-13 18:35:00	\N	\N	6	0	\N	\N
479094	DELEGATION	AUCUNE	\N	\N	COLTER	Audition ANCT	\N	2020-06-25 09:30:00	2020-06-25 10:50:00	2020-06-25 11:51:05	\N	13	0	\N	\N
481098	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière - Examen 2 notes Covid-19	Réunion plénière - Examen 2 notes Covid-19	2020-07-02 09:35:00	2020-07-02 11:45:00	\N	\N	5	0	\N	\N
481110	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2020-06-25 09:00:00	2020-06-25 10:45:00	\N	\N	4	0	\N	\N
481115	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2020-06-25 14:30:00	2020-06-25 17:20:00	\N	\N	1	0	\N	\N
491709	COM_PERMANENTE	AUDRAP	\N	CDD	\N	¨¨PJL Néonicotinoïdes - ITB	\N	2020-10-13 14:15:00	2020-10-13 14:45:00	\N	\N	6	0	\N	\N
491718	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Néonicotinoïdes - Confédération paysanne	\N	2020-10-13 14:45:00	2020-10-13 15:15:00	\N	\N	4	0	\N	\N
496328	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2021 - Travail et emploi - Audition de la DGT	\N	2020-10-27 14:30:00	2020-10-27 15:30:00	\N	\N	1	0	\N	\N
496329	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2021 - Travail et emploi - Table ronde des organisations patronales	\N	2020-10-27 15:30:00	2020-10-27 17:00:00	\N	\N	1	0	\N	\N
496330	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2021 - Travail et emploi - Table ronde des organisations syndicales	\N	2020-10-27 17:00:00	2020-10-27 18:30:00	\N	\N	1	0	\N	\N
502824	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Médias - CNM	PLF pour 2021 - Médias - CNM	2020-11-09 15:00:00	2020-11-09 15:45:00	\N	\N	1	0	\N	\N
502829	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Culture - TR opérateurs du Patrimoine	PLF pour 2021 - Culture - TR opérateurs du Patrimoine	2020-11-10 14:00:00	2020-11-10 15:15:00	\N	\N	2	0	\N	\N
502832	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Culture - DG Patrimoines/Pass Culture	PLF pour 2021 - Culture - DG Patrimoines/Pass Culture	2020-11-10 16:30:00	2020-11-10 18:15:00	\N	\N	2	0	\N	\N
502835	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2021 - Avis juridictions administratives et financières	PLF pour 2021 - Avis juridictions administratives et financières	2020-11-12 09:30:00	2020-11-12 10:40:00	\N	\N	1	0	\N	\N
502836	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Écologie - DGALN / ANH	PLF pour 2021 - Écologie - DGALN / ANH	2020-11-02 09:00:00	2020-11-02 10:30:00	\N	\N	1	0	\N	\N
454205	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition SRE PJLO et PJL Système universel des retraites	\N	2020-02-11 15:00:00	2020-02-11 16:00:00	\N	\N	3	0	\N	\N
454206	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Ircantec PJLO et PJL Système universel des retraites	\N	2020-02-11 16:00:00	2020-02-11 16:45:00	\N	\N	3	0	\N	\N
454207	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition CSR PJLO et PJL Système universel des retraites	\N	2020-02-11 16:45:00	2020-02-11 17:30:00	\N	\N	3	0	\N	\N
454208	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition CRP RATP PJLO et PJL Système universel des retraites	\N	2020-02-11 17:45:00	2020-02-11 18:30:00	\N	\N	3	0	\N	\N
454209	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition CNIEG PJLO et PJL Système universel des retraites	\N	2020-02-12 09:00:00	2020-02-12 09:45:00	\N	\N	2	0	\N	\N
454210	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition CRP SNCF PJLO et PJL Système universel des retraites	\N	2020-02-12 09:45:00	2020-02-12 10:30:00	\N	\N	2	0	\N	\N
454254	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Aisen Nikolaev, chef du gouvernement de la République de Sakha 	Entretien avec M. Aisen Nikolaev, chef du gouvernement de la République de Sakha 	2020-02-16 17:00:00	2020-02-16 18:00:00	\N	\N	1	0	608	\N
455402	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Restitution des oeuvres d'art	MI Restitution des oeuvres d'art	2020-02-19 11:40:00	2020-02-19 12:20:00	\N	\N	7	0	\N	\N
456131	ETUDES	AUCUNE	\N	\N	\N	Auditions suivi loi Montagne II	Audition DGESCO	2020-02-18 14:00:00	2020-02-18 15:00:00	\N	\N	4	0	\N	918
456136	ETUDES	AUCUNE	\N	\N	\N	Auditions suivi loi Montagne II	Audition Domaines Skiables de France	2020-02-18 15:00:00	2020-02-18 16:00:00	\N	\N	3	0	\N	918
456179	GIA	AUCUNE	\N	\N	\N	Petit déjeuner de travail	Petit déjeuner de travail avec S.E. M. Luis Fernando Serra, Ambassadeur du Brésil en France	2020-02-18 08:30:00	2020-02-18 10:00:00	\N	\N	6	0	576	\N
456321	ETUDES	AUCUNE	\N	\N	\N	GE Élevage - Section Cheval	GE Élevage - Section Cheval	2020-02-19 08:00:00	2020-02-19 09:00:00	\N	\N	5	0	\N	912
456363	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition GS Stratégie industrielle de l'UE	Audition GS Stratégie industrielle de l'UE	2020-02-19 08:30:00	2020-02-19 09:45:00	\N	\N	13	0	\N	\N
456616	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PPL Mineurs vulnérables sur le territoire français - Désignation rapporteur pour avis	\N	2020-02-26 10:20:00	2020-02-26 10:25:00	\N	\N	0	0	\N	\N
456617	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Table ronde risques Coronavirus	\N	2020-02-26 10:35:00	2020-02-26 12:20:00	2020-02-27 19:04:03	2020-02-28 16:48:58	40	1	\N	\N
456618	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PPL Pérennisation et généralisation des maisons de naissance - Désignation rapporteur	\N	2020-02-26 10:25:00	2020-02-26 10:30:00	\N	\N	0	0	\N	\N
456640	MISSION	AUCUNE	\N	DEPARTEMENT	\N	Réunion constitutive	\N	2020-02-25 14:30:00	2020-02-25 15:25:00	2020-02-25 16:13:13	2020-02-26 11:21:40	17	1	\N	\N
456665	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2020-02-25 09:31:00	2020-02-25 11:10:00	2020-02-26 16:03:12	2020-02-26 17:33:10	32	0	\N	\N
456666	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière  CATDD	\N	2020-02-25 18:24:00	2020-02-25 19:49:00	2020-02-26 16:02:44	2020-02-26 17:33:13	23	0	\N	\N
456675	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Système universel de retraite	\N	2020-02-19 16:00:00	2020-02-19 17:30:00	\N	\N	2	0	\N	\N
456682	GIA	AUCUNE	\N	\N	\N	AG du groupe d'études Sénat-Taiwan	Assemblée générale du groupe 	2020-03-03 18:30:00	2020-03-03 19:45:00	\N	\N	22	0	623	\N
456711	COM_ENQUETE	PLENIERE	\N	AUTOROUT	\N	Audition de M. Fabien BALDERELLI, DGTIM	Audition de M. Fabien BALDERELLI, sous-directeur de la gestion et du contrôle du réseau autoroutier concédé à la DGTIM	2020-02-26 16:35:00	2020-02-26 18:20:00	2020-02-26 18:19:20	2020-02-27 14:42:19	12	0	\N	\N
456718	GIA	AUCUNE	\N	\N	\N	Rencontre Ambassadeur Palestine	Petit-déjeuner avec S.E. l'Ambassadeur de Palestine en France	2020-02-20 09:00:00	2020-02-20 10:00:00	\N	\N	5	0	632	\N
456729	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Français établis hors de France	PPL Français établis hors de France	2020-02-24 15:00:00	2020-02-24 16:00:00	\N	\N	1	0	\N	\N
456732	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Français établis hors de France	PPL Français établis hors de France	2020-02-24 16:00:00	2020-02-24 17:00:00	\N	\N	2	0	\N	\N
457282	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Système universel de retraite	\N	2020-02-25 15:45:00	2020-02-25 16:30:00	\N	\N	6	0	\N	\N
457289	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Système universel de retraite	\N	2020-02-25 16:30:00	2020-02-25 17:15:00	\N	\N	4	0	\N	\N
457294	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Système universel de retraite	\N	2020-02-25 17:15:00	2020-02-25 18:00:00	\N	\N	3	0	\N	\N
457893	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 4 mars 2020	\N	2020-03-04 13:30:00	2020-03-04 15:00:00	2020-03-04 15:33:45	2020-03-04 16:25:40	16	0	\N	\N
457914	COM_EURO	AUDRAP	\N	AFEU	\N	Controle - Sécurité des infrastructures financières	Controle - Sécurité des infrastructures financières - Audition de l'Autorité des marchés financiers	2020-02-25 17:30:00	2020-02-25 19:00:00	\N	\N	2	0	\N	\N
458210	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Contôle Mobilité des professions de santé	Audition Contôle Mobilité des professions de santé - Audition du Conseil de l'ordre des médecins	2020-02-25 17:00:00	2020-02-25 18:40:00	\N	\N	1	0	\N	\N
458313	DELEGATION	AUCUNE	\N	\N	211	Synthèse des travaux communs aux délégation aux droits des femmes et aux outre-mer	Synthèse des travaux communs aux délégation aux droits des femmes et aux outre-mer	2020-03-03 17:00:00	2020-03-03 17:50:00	2020-03-03 18:29:27	\N	8	0	\N	\N
458323	COM_ENQUETE	PLENIERE	\N	LUBRIZOL	\N	Réunion de commission	\N	2020-02-26 18:05:00	2020-02-26 19:30:00	2020-02-26 19:31:46	2020-02-27 14:42:20	13	0	\N	\N
458397	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Auditions rapporteurs - MI Travailleurs indépendants	\N	2020-02-25 14:00:00	2020-02-25 14:45:00	\N	\N	3	0	\N	\N
458400	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Auditions rapporteurs - MI Travailleurs indépendants	\N	2020-02-25 14:45:00	2020-02-25 15:30:00	\N	\N	3	0	\N	\N
458401	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Auditions rapporteurs - MI Travailleurs indépendants	\N	2020-02-25 15:30:00	2020-02-25 17:00:00	\N	\N	3	0	\N	\N
458404	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Auditions rapporteurs - MI Travailleurs indépendants	\N	2020-02-25 17:45:00	2020-02-25 18:30:00	\N	\N	3	0	\N	\N
458406	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Auditions rapporteurs - MI Travailleurs indépendants	\N	2020-02-26 13:45:00	2020-02-26 14:45:00	\N	\N	3	0	\N	\N
458657	DELEGATION	AUCUNE	\N	\N	COLTER	Table ronde "Communes face à l'inflation des prix de l'immobilier"	\N	2020-03-05 10:00:00	2020-03-05 12:00:00	2020-03-05 14:54:59	\N	8	0	\N	\N
458793	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Français établis hors de France	PPL Français établis hors de France	2020-02-27 14:00:00	2020-02-27 14:45:00	\N	\N	2	0	\N	\N
458815	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI SCAF	\N	2020-02-25 14:00:00	2020-02-25 16:10:00	\N	\N	2	0	\N	\N
458828	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI SCAF	\N	2020-02-27 15:00:00	2020-02-27 16:30:00	\N	\N	2	0	\N	\N
459027	DELEGATION	AUDRAP	\N	\N	206	Audition	\N	2020-03-04 15:00:00	2020-03-04 16:00:00	\N	\N	2	0	\N	\N
459030	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Production de l'énergie dans le secteur agricole	Audition rapporteurs Production de l'énergie dans le secteur agricole (Académie des sciences)	2020-03-04 16:00:00	2020-03-04 17:00:00	\N	\N	2	0	\N	\N
459033	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Production de l'énergie dans le secteur agricole	Audition rapporteurs Production de l'énergie dans le secteur agricole (Agridées think tank)	2020-03-05 14:00:00	2020-03-05 15:00:00	\N	\N	2	0	\N	\N
459036	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Production de l'énergie dans le secteur agricole	Audition rapporteurs Production de l'énergie dans le secteur agricole (Coordination rurale)	2020-03-05 15:00:00	2020-03-05 16:00:00	\N	\N	2	0	\N	\N
459089	GIA	AUCUNE	\N	\N	\N	réunion de travail avec Frédéric Mondoloni	\N	2020-02-25 12:30:00	2020-02-25 14:30:00	\N	\N	3	0	674	\N
459305	COM_SPECIALE	PLENIERE	\N	ASAP	\N	Réunion de commission	Réunion de commission	2020-03-03 12:00:00	2020-03-03 12:55:00	2020-03-03 14:28:13	2020-03-03 17:22:30	25	0	\N	\N
460084	GIA	AUCUNE	\N	\N	\N	Entretien ambassadrice principauté d'Andorre	\N	2020-03-04 08:30:00	2020-03-04 09:15:00	\N	\N	9	0	963	\N
460677	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - ENAP - SNRP / ENAP	Contrôle 2020 - ENAP - SNRP / ENAP	2020-03-03 16:00:00	2020-03-03 18:00:00	\N	\N	1	0	\N	\N
378111	ETUDES	AUCUNE	\N	\N	\N	Audition Paris Turf	Audition Paris Turf	2019-05-15 08:00:00	2019-05-15 09:00:00	\N	\N	3	0	\N	912
382637	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition Lorent Saleh	\N	2019-05-29 09:40:00	2019-05-29 11:20:00	2019-05-29 12:07:02	2019-05-29 15:16:12	26	0	\N	\N
382638	GIA	AUCUNE	\N	\N	\N	Réception  à l'ambassade de Biélorussie  	Réception à l'ambassade à l'occasion de la saison musicale biélorusse en France 	2019-05-22 20:00:00	2019-05-22 22:00:00	\N	\N	1	0	852	\N
384593	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Participation des conseillers de Lyon aux élections sénatoriales	\N	2019-05-29 14:30:00	2019-05-29 16:00:00	\N	\N	2	0	\N	\N
387714	MISSION	AUCUNE	\N	TRANSPORTS	\N	MIGT - Audition de France urbaine et l'AdCF	\N	2019-06-06 13:30:00	2019-06-06 15:00:00	2019-06-07 11:31:28	2019-06-07 11:32:31	6	0	\N	\N
393744	DELEGATION	AUCUNE	\N	\N	COLTER	Table ronde - Patrimoine historique et culturel	\N	2019-06-27 09:30:00	2019-06-27 11:15:00	2019-06-27 12:11:13	\N	8	0	\N	\N
393814	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Droit des sociétés	PPL Droit des sociétés	2019-06-10 14:30:00	2019-06-10 20:30:00	\N	\N	0	0	\N	\N
393815	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Droit des sociétés	PPL Droit des sociétés	2019-07-10 18:25:00	2019-07-10 19:30:00	\N	\N	36	0	\N	\N
396123	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Energie - Auditions M. Gremillet	\N	2019-06-26 14:00:00	2019-06-26 16:00:00	\N	\N	1	0	\N	\N
396129	DELEGATION	AUCUNE	\N	\N	DSOM	Audition Délégué interministériel aux risques majeurs	\N	2019-07-02 14:35:00	2019-07-02 17:00:00	\N	\N	8	0	\N	\N
396130	DELEGATION	AUCUNE	\N	\N	DSOM	Réunion conjointe avec la Délégation aux droits des femmes	\N	2019-07-04 09:00:00	2019-07-04 10:45:00	\N	\N	11	0	\N	\N
396131	DELEGATION	AUCUNE	\N	\N	DSOM	Étude sur les risques naturels majeurs outre-mer : Audition sur les sargasses	\N	2019-07-04 16:30:00	2019-07-04 18:40:00	2019-07-05 10:38:29	\N	10	0	\N	\N
396134	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Energie - Auditions M. Gremillet	\N	2019-06-27 09:00:00	2019-06-27 13:00:00	\N	\N	0	0	\N	\N
396169	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Énergie - Auditions Mme Bories	\N	2019-06-26 14:00:00	2019-06-26 18:00:00	\N	\N	1	0	\N	\N
396171	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Énergie - Auditions Mme Bories	\N	2019-06-25 17:30:00	2019-06-25 19:30:00	\N	\N	1	0	\N	\N
396209	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Inspection du travail - OP inspection du travail	Contrôle 2019 - Inspection du travail - OP inspection du travail	2019-06-25 14:30:00	2019-06-25 16:15:00	\N	\N	2	0	\N	\N
396212	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Inspection du travail - CNIT	Contrôle 2019 - Inspection du travail - CNIT	2019-06-26 15:30:00	2019-06-26 16:15:00	\N	\N	1	0	\N	\N
396214	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Masse salariale du MEAE - Direction du budget	Contrôle 2019 - Masse salariale du MEAE - Direction du budget	2019-06-25 17:30:00	2019-06-25 18:45:00	\N	\N	2	0	\N	\N
396219	DELEGATION	AUCUNE	\N	\N	PROS	Point sur les travaux en cours et programme de travail du second semestre	\N	2019-07-04 08:30:00	2019-07-04 09:10:00	\N	\N	16	0	\N	\N
396238	MISSION	AUCUNE	\N	AERIEN	\N	Audition plénière - Transports aériens et aménagement des territoires	\N	2019-07-04 11:03:00	2019-07-04 12:09:00	2019-07-04 17:15:33	2019-07-04 18:04:12	15	0	\N	\N
396242	MISSION	AUCUNE	\N	AERIEN	\N	Réunion plénière MI Transports aériens	\N	2019-07-04 12:13:00	2019-07-04 13:09:00	2019-07-04 17:16:10	2019-07-04 18:04:13	10	0	\N	\N
396243	MISSION	AUCUNE	\N	AERIEN	\N	Réunion plénière MI Transports aériens	\N	2019-07-02 16:15:00	2019-07-02 17:45:00	2019-07-03 09:53:42	2019-07-03 15:57:37	12	0	\N	\N
396256	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Déplacement Bruxelle mission SILT	\N	2019-06-24 08:30:00	2019-06-24 20:00:00	\N	\N	1	0	\N	\N
396280	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Évaluation transformation ISF en IFI et création PFU - Economiste	Contrôle 2019 - Évaluation transformation ISF en IFI et création PFU - Economiste	2019-06-26 15:00:00	2019-06-26 16:00:00	\N	\N	2	0	\N	\N
402884	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Services de l'Etat dans les territoires - Cour des comptes	Contrôle 2019 - Services de l'Etat dans les territoires - Cour des comptes	2019-07-16 11:30:00	2019-07-16 12:30:00	\N	\N	1	0	\N	\N
402886	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Services publics dans les territoires - AMRF	Contrôle 2019 - Services publics dans les territoires - AMRF	2019-07-16 18:30:00	2019-07-16 19:30:00	\N	\N	1	0	\N	\N
402888	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Inspection du travail - Cabinet ministre travail	Contrôle 2019 - Inspection du travail - Cabinet ministre travail	2019-07-16 16:30:00	2019-07-16 17:35:00	\N	\N	0	0	\N	\N
402889	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2019 - Inspection du travail - Déplacement Paris 16 Longchamps	Contrôle 2019 - Inspection du travail - Déplacement Paris 16 Longchamps	2019-07-17 13:00:00	2019-07-17 17:45:00	\N	\N	2	0	\N	\N
402900	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions Mme de CIDRAC	\N	2019-07-17 15:00:00	2019-07-17 18:30:00	\N	\N	1	0	\N	\N
402905	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Économie circulaire - Auditions Mme de CIDRAC	\N	2019-07-18 09:30:00	2019-07-18 10:30:00	\N	\N	2	0	\N	\N
402906	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Économie circulaire - Auditions Mme de CIDRAC	\N	2019-07-18 14:30:00	2019-07-18 15:30:00	\N	\N	1	0	\N	\N
402915	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	GE Economie circulaire - Audition de Mme Poirson	\N	2019-07-18 16:00:00	2019-07-18 16:50:00	\N	\N	0	0	\N	\N
402923	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - ZRR - CGET	Contrôle 2019 - ZRR - CGET	2019-07-16 17:30:00	2019-07-16 18:30:00	\N	\N	3	0	\N	\N
402927	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - ZRR - Sénateur	Contrôle 2019 - ZRR - Sénateur	2019-07-17 11:15:00	2019-07-17 12:15:00	\N	\N	3	0	\N	\N
402931	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Programme des contrôles 2019 - Rapporteure générale Cour des comptes	Programme des contrôles 2019 - Rapporteure générale Cour des comptes	2019-07-16 15:40:00	2019-07-16 16:30:00	\N	\N	1	0	\N	\N
402933	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Lutte contre les feux de forêt - IGSC	Contrôle 2019 - Lutte contre les feux de forêt - IGSC	2019-07-17 12:30:00	2019-07-17 14:30:00	\N	\N	1	0	\N	\N
402935	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - CGLLS - Caisse des dépôts et consignations	Contrôle 2019 - CGLLS - Caisse des dépôts et consignations	2019-07-17 14:00:00	2019-07-17 15:00:00	\N	\N	1	0	\N	\N
402937	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Sécurité informatiques des pouvoirs public - Ministère de l'intérieur	Contrôle 2019 - Sécurité informatiques des pouvoirs public - Ministère de l'intérieur	2019-07-16 16:30:00	2019-07-16 17:30:00	\N	\N	1	0	\N	\N
402939	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2020 - Immigration, asile et intégration - Déplacement OFPRA	PLF pour 2020 - Immigration, asile et intégration - Déplacement OFPRA	2019-07-18 13:30:00	2019-07-18 16:15:00	\N	\N	1	0	\N	\N
402941	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Évaluation transformation ISF en IFI et création PFU - Paris Europlace	Contrôle 2019 - Évaluation transformation ISF en IFI et création PFU - Paris Europlace	2019-07-16 16:30:00	2019-07-16 17:15:00	\N	\N	2	0	\N	\N
402944	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen rapport Nlle Lecture PJLR 2018	Examen rapport Nlle Lecture PJLR 2018	2019-07-23 14:30:00	2019-07-23 14:35:00	2019-07-23 17:25:08	2019-07-23 17:39:54	15	0	\N	\N
404707	GIA	AUCUNE	\N	\N	\N	Accueil délégation du Bundesrat du 4 au 5 juillet-Déjeuner du 4 juillet 2019	Accueil délégation du Bundesrat du 4 au 5 juillet-Déjeuner du 4 juillet 2019	2019-07-04 13:00:00	2019-07-04 14:30:00	\N	\N	10	0	604	\N
404718	GIA	AUCUNE	\N	\N	\N	Accueil délégation du Bundesrat du 4 au 5 juillet-Echanges de vues du 4 juillet 2019	Accueil délégation du Bundesrat du 4 au 5 juillet-Echanges de vues du 4 juillet 2019	2019-07-04 16:15:00	2019-07-04 18:30:00	\N	\N	6	0	604	\N
404725	GIA	AUCUNE	\N	\N	\N	Accueil délégation du Bundesrat du 4 au 5 juillet-Dîner du 4 juillet 2019	Accueil délégation du Bundesrat du 4 au 5 juillet-Dîner du 4 juillet 2019	2019-07-04 20:00:00	2019-07-04 21:30:00	\N	\N	3	0	604	\N
404729	GIA	AUCUNE	\N	\N	\N	Accueil délégation du Bundesrat du 4 au 5 juillet-Déjeuner du 5 juillet 2019	Accueil délégation du Bundesrat du 4 au 5 juillet-Déjeuner du 5 juillet 2019	2019-07-05 12:00:00	2019-07-05 14:00:00	\N	\N	3	0	604	\N
459118	COM_ENQUETE	PLENIERE	\N	RADICALI	\N	Audition Tracfin	Audition Tracfin	2020-03-03 15:50:00	2020-03-03 16:40:00	2020-03-03 19:50:52	2020-03-05 15:38:31	10	0	\N	\N
459119	COM_ENQUETE	PLENIERE	\N	RADICALI	\N	Audition DDCSPP Haute-Saône, DRDJSCS Auvergne-Rhône-Alpes & DDCS Seine-Saint-Denis	Audition DDCSPP Haute-Saône, DRDJSCS Auvergne-Rhône-Alpes & DDCS Seine-Saint-Denis	2020-03-05 10:30:00	2020-03-05 11:50:00	2020-03-05 12:08:08	2020-03-05 15:38:34	4	0	\N	\N
459124	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-03-04 09:30:00	2020-03-04 11:20:00	2020-03-04 15:36:23	2020-03-04 16:20:02	44	0	\N	\N
459126	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-03-05 10:35:00	2020-03-05 12:10:00	2020-03-05 12:34:02	2020-03-05 15:34:37	18	0	\N	\N
459127	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - La masse salariale du MEAE - CGT du MEAE	Contrôle 2019 - La masse salariale du MEAE - CGT du MEAE	2020-02-24 14:30:00	2020-02-24 15:30:00	\N	\N	1	0	\N	\N
459129	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Projet de loi de programmation pour la recherche - 2020 - CDEFI 	Projet de loi de programmation pour la recherche - 2020 - CDEFI 	2020-02-25 11:30:00	2020-02-25 12:30:00	\N	\N	1	0	\N	\N
459131	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n°179 Français établis hors de France - DINR / Avocat Fiscaliste	PPL n°179 Français établis hors de France - DINR / Avocat Fiscaliste	2020-02-24 15:00:00	2020-02-24 16:45:00	\N	\N	1	0	\N	\N
459133	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n°179 Français établis hors de France - Représentants Français établis hors de France	PPL n°179 Français établis hors de France - Représentants Français établis hors de France	2020-02-26 16:45:00	2020-02-26 17:45:00	\N	\N	1	0	\N	\N
459135	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n°179 Français établis hors de France - DLF	PPL n°179 Français établis hors de France - DLF	2020-02-27 15:35:00	2020-02-27 16:50:00	\N	\N	1	0	\N	\N
459137	COM_PERMANENTE	AUDRAP	\N	FINC	\N	GS lutte contre la fraude et l'évasion fiscales - Service Cont. Fiscal DGFiP - CNB	GS lutte contre la fraude et l'évasion fiscales - Service Cont. Fiscal DGFiP - CNB	2020-02-25 17:00:00	2020-02-25 19:10:00	\N	\N	8	0	\N	\N
459146	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - Le franc CFA - Franc CFA et Institutions	Contrôle 2020 - Le franc CFA - Franc CFA et Institutions	2020-02-26 18:00:00	2020-02-26 19:10:00	\N	\N	2	0	\N	\N
459157	COM_EURO	AUDRAP	\N	AFEU	\N	Audition - K. Bitsios	\N	2020-02-25 10:00:00	2020-02-25 11:00:00	\N	\N	1	0	\N	\N
459125	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-03-04 11:20:00	2020-03-04 12:45:00	2020-03-04 15:34:06	2020-03-04 16:19:58	44	0	\N	\N
459170	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - CNCCFP - Cour des comptes	Contrôle 2019 - CNCCFP - Cour des comptes	2020-02-25 17:30:00	2020-02-25 18:30:00	\N	\N	1	0	\N	\N
459172	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 Démantèlement des installations nucléaires - EDF	58-2 Démantèlement des installations nucléaires - EDF	2020-02-25 15:30:00	2020-02-25 16:30:00	\N	\N	1	0	\N	\N
459174	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - Héritage jeux olympiques et paralympiques 2024 - Solidéo	Contrôle 2020 - Héritage jeux olympiques et paralympiques 2024 - Solidéo	2020-02-26 14:00:00	2020-02-26 15:15:00	\N	\N	1	0	\N	\N
459179	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Système universel de retraite - INSEE	PJL Système universel de retraite - INSEE	2020-02-25 15:45:00	2020-02-25 16:30:00	\N	\N	1	0	\N	\N
459181	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - Les aides à la presse - SPPIL	Contrôle 2020 - Les aides à la presse - SPPIL	2020-02-28 11:00:00	2020-02-28 11:45:00	\N	\N	1	0	\N	\N
459183	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - Les aides à la presse - DGE	Contrôle 2020 - Les aides à la presse - DGE	2020-02-28 14:15:00	2020-02-28 15:00:00	\N	\N	1	0	\N	\N
459185	COM_EURO	AUDRAP	\N	AFEU	\N	Audition - C. Triantopoulos	\N	2020-02-25 15:40:00	2020-02-25 16:45:00	\N	\N	1	0	\N	\N
459188	COM_EURO	AUDRAP	\N	AFEU	\N	Audition - Y. Stournaras	\N	2020-02-25 17:05:00	2020-02-25 17:55:00	\N	\N	1	0	\N	\N
459273	SEANCE_PLENIERE	SCRUSOL	1321	\N	\N	Scrutin solennel - PJL Parquet europÃ©en	Scrutin solennel - PJL Parquet europÃ©en	2020-03-03 14:30:00	2020-03-03 15:45:00	\N	\N	0	0	\N	\N
459601	DELEGATION	AUDRAP	\N	\N	211	Audition de Mme Sophie Binet (CGT)	Audition de Mme Sophie Binet (CGT)	2020-03-03 09:30:00	2020-03-03 10:30:00	\N	\N	4	0	\N	\N
460048	ETUDES	AUCUNE	\N	\N	\N	Audition Atout France	Audition Suivi de la loi Montagne II	2020-03-03 11:00:00	2020-03-03 11:45:00	\N	\N	1	0	\N	918
460134	COM_EURO	AUDRAP	\N	AFEU	\N	Audition de Mme Catherine Del-Cont, Maître de conférences	\N	2020-03-03 09:30:00	2020-03-03 11:00:00	\N	\N	0	0	\N	\N
460854	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Démarchage téléphonique et lutte contre les appels frauduleux	PPL Démarchage téléphonique et lutte contre les appels frauduleux	2020-03-03 16:00:00	2020-03-03 17:15:00	\N	\N	1	0	\N	\N
460856	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Démarchage téléphonique et lutte contre les appels frauduleux	PPL Démarchage téléphonique et lutte contre les appels frauduleux	2020-03-04 09:00:00	2020-03-04 10:25:00	\N	\N	1	0	\N	\N
460972	COM_PERMANENTE	AUTRE	\N	CDD	\N	Mission d'information sur la gouvernance et les performances des ports	Audition des représentants de la Sous-direction des ports et du transport fluvial	2020-03-03 08:30:00	2020-03-03 10:10:00	\N	\N	4	0	\N	\N
460977	COM_PERMANENTE	AUTRE	\N	CDD	\N	Mission d'information sur la gouvernance et les performances des ports	Audition de représentants de SNCF Réseau	2020-03-03 10:10:00	2020-03-03 11:05:00	\N	\N	3	0	\N	\N
460985	GIA	AUCUNE	\N	\N	\N	réunion de travail	Audition de S.E. Mme Martine SCHOMMER, Ambassadeur du Grand-Duché de Luxembourg à Par	2020-03-04 08:30:00	2020-03-04 09:40:00	\N	\N	10	0	580	\N
461304	ETUDES	AUCUNE	\N	\N	\N	Audition Vignerons coopérateurs	Audition M. Boris Calmette, président des Vignerons Coopérateurs	2020-03-04 13:30:00	2020-03-04 14:40:00	\N	\N	13	0	\N	909
461609	ETUDES	AUCUNE	\N	\N	\N	Audition de représentants d'Enedis	Audition de représentants d'Enedis	2020-03-04 13:30:00	2020-03-04 15:00:00	\N	\N	7	0	\N	906
461972	GIA	AUCUNE	\N	\N	\N	Entretien avec Monsieur le Dr François-Xavier NGARAMBE, Ambassadeur du Rwanda à Paris	Entretien avec Monsieur le Dr François-Xavier NGARAMBE, Ambassadeur du Rwanda à Paris	2020-03-04 16:15:00	2020-03-04 17:15:00	\N	\N	2	0	572	\N
462176	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Mission action logement	Mission action logement	2020-03-03 16:00:00	2020-03-03 17:00:00	\N	\N	1	0	\N	\N
462342	GIA	AUCUNE	\N	\N	\N	Coopé - Visite de Mme Vanessa METOU-MOUINI, personnalité d'avenir du Congo Brazzaville	Coopé - Visite de Mme Vanessa METOU-MOUINI, personnalité d'avenir du Congo Brazzaville	2020-03-03 17:00:00	2020-03-03 18:00:00	\N	\N	1	0	572	\N
380179	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Transformation de la fonction publique	\N	2019-05-15 14:00:00	2019-05-15 15:15:00	\N	\N	4	0	\N	\N
380184	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Transformation de la fonction publique	\N	2019-05-15 15:15:00	2019-05-15 16:15:00	\N	\N	3	0	\N	\N
380188	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Transformation de la fonction publique	\N	2019-05-15 16:15:00	2019-05-15 17:15:00	\N	\N	2	0	\N	\N
382784	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Cherbourg - Visite sous-marin Suffren et préfecture maritime	\N	2019-05-23 07:00:00	2019-05-23 20:00:00	\N	\N	13	0	\N	\N
396519	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-07-02 09:35:00	2019-07-02 10:05:00	2019-07-02 11:10:07	2019-07-02 16:18:48	19	1	\N	\N
404612	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière	Réunion plénière - Conclusions audition EPR Flamanville - Désignation membre - Audition Bertrand Pailhès	2019-07-26 10:00:00	2019-07-26 12:00:00	\N	\N	0	0	\N	\N
406764	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Économie circulaire	PJL Économie circulaire	2019-09-27 09:30:00	2019-09-27 12:45:00	\N	\N	38	0	\N	\N
406765	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Économie circulaire	PJL Économie circulaire	2019-09-27 14:30:00	2019-09-27 18:15:00	\N	\N	32	0	\N	\N
406802	SEANCE_PLENIERE	ELOGE_FUNEBRE	\N	\N	\N	Éloge funèbre P. MADRELLE	Éloge funèbre P. MADRELLE	2019-10-08 14:35:00	2019-10-08 15:00:00	\N	\N	0	0	\N	\N
406842	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Engagement vie locale	PJL Engagement vie locale	2019-10-08 15:15:00	2019-10-08 20:30:00	\N	\N	229	0	\N	\N
406843	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Engagement vie locale	PJL Engagement vie locale	2019-10-08 21:35:00	2019-10-09 00:30:00	\N	\N	124	0	\N	\N
406844	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2019-10-09 15:00:00	2019-10-09 16:20:00	\N	\N	306	0	\N	\N
406845	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Engagement vie locale	PJL Engagement vie locale	2019-10-09 19:20:00	2019-10-09 20:15:00	\N	\N	95	0	\N	\N
406846	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Engagement vie locale	PJL Engagement vie locale	2019-10-09 21:30:00	2019-10-10 00:55:00	\N	\N	104	0	\N	\N
406847	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Engagement vie locale	PJL Engagement vie locale	2019-10-10 11:00:00	2019-10-10 13:00:00	\N	\N	105	0	\N	\N
406848	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Engagement vie locale	PJL Engagement vie locale	2019-10-10 14:30:00	2019-10-10 20:05:00	\N	\N	99	0	\N	\N
406849	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Engagement vie locale	PJL Engagement vie locale	2019-10-10 21:40:00	2019-10-11 00:35:00	\N	\N	42	0	\N	\N
406850	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2019-10-15 09:30:00	2019-10-15 12:55:00	\N	\N	42	0	\N	\N
396520	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-07-03 10:05:00	2019-07-03 10:40:00	2019-07-03 10:56:57	2019-07-03 15:56:33	31	2	\N	\N
406851	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Engagement vie locale	PJL Engagement vie locale	2019-10-15 14:30:00	2019-10-15 19:35:00	\N	\N	207	0	\N	\N
406852	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Engagement vie locale	PJL Engagement vie locale	2019-10-15 21:30:00	2019-10-16 00:45:00	\N	\N	122	0	\N	\N
406854	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2019-10-16 15:00:00	2019-10-16 16:25:00	\N	\N	303	0	\N	\N
406855	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Musique	CMP Musique	2019-10-16 16:35:00	2019-10-16 17:45:00	\N	\N	85	0	\N	\N
406859	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Engagement vie locale	PJL Engagement vie locale	2019-10-16 17:50:00	2019-10-16 20:00:00	\N	\N	115	0	\N	\N
406860	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Engagement vie locale	PJL Engagement vie locale	2019-10-16 21:30:00	2019-10-17 00:30:00	\N	\N	92	0	\N	\N
406865	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Conventions internationales	Conventions internationales	2019-10-17 10:30:00	2019-10-17 10:35:00	\N	\N	1	0	\N	\N
406891	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Ratification traité Macédoine	PJL Ratification traité Macédoine	2019-10-17 10:35:00	2019-10-17 11:40:00	\N	\N	43	0	\N	\N
406927	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Engagement vie locale	PJL Engagement vie locale	2019-10-17 11:55:00	2019-10-17 13:35:00	\N	\N	79	0	\N	\N
406929	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Engagement vie locale	PJL Engagement vie locale	2019-10-17 15:05:00	2019-10-17 19:55:00	\N	\N	108	0	\N	\N
406931	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Engagement vie locale	PJL Engagement vie locale	2019-10-17 21:30:00	2019-10-18 01:35:00	\N	\N	49	0	\N	\N
410910	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Lutte contre la haine sur internet	\N	2019-10-04 14:00:00	2019-10-04 15:00:00	\N	\N	2	0	\N	\N
410916	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Biocarburants	GT Biocarburants	2019-10-03 09:00:00	2019-10-03 11:00:00	\N	\N	1	0	\N	\N
410918	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Biocarburants	GT Biocarburants	2019-10-03 15:30:00	2019-10-03 19:30:00	\N	\N	1	0	\N	\N
419341	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Agir contre les violences au sein de la famille	PPL Violences au sein de la famille	2019-10-22 16:30:00	2019-10-22 19:35:00	\N	\N	2	0	\N	\N
422590	GIA	AUCUNE	\N	\N	\N	accueil d'une délégation de parlementaires tibétains	accueil d'une délégation de parlementaires tibétains	2019-11-18 08:30:00	2019-11-18 10:00:00	\N	\N	2	0	634	\N
430520	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteurs	Adhésion de l'UE à la CEDH - Audition CEDH	2019-11-20 18:05:00	2019-11-20 19:05:00	\N	\N	1	0	\N	\N
438335	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-12-11 09:30:00	2019-12-11 11:10:00	2019-12-11 11:44:04	2019-12-11 11:54:40	38	0	\N	\N
438492	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Auditions enquête Cour des comptes sur l'ANSM + Communication droit de retrait	\N	2019-12-11 09:30:00	2019-12-11 11:30:00	2019-12-11 15:52:02	2019-12-11 16:05:15	38	0	\N	\N
441624	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Créer un droit à l'erreur des collectivités locales	PPL Droit à l'erreur collectivités locales	2019-12-19 11:15:00	2019-12-19 12:00:00	\N	\N	1	0	\N	\N
441789	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2020-01-07 10:03:00	2020-01-07 10:53:00	2020-01-07 15:10:06	2020-01-07 16:46:42	31	1	\N	\N
441791	COM_ENQUETE	PLENIERE	\N	RADICALI	\N	Audition d'Olivier Roy	Audition d'Olivier Roy	2020-01-07 13:35:00	2020-01-07 15:00:00	2020-01-07 16:49:12	2020-01-07 16:49:28	8	0	\N	\N
443682	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2020-01-15 09:30:00	2020-01-15 12:20:00	2020-01-15 14:41:43	2020-01-15 17:49:14	36	0	\N	\N
448296	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - Mission SILT - DGSI	\N	2020-01-22 13:45:00	2020-01-22 14:35:00	\N	\N	2	0	\N	\N
448371	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	GT Métier d'enseignant	GT Métier d'enseignant	2020-01-22 16:30:00	2020-01-22 17:50:00	\N	\N	3	0	\N	\N
448486	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PPL Libre choix du consommateur dans le cyberespace	\N	2020-01-22 14:15:00	2020-01-22 15:00:00	\N	\N	3	0	\N	\N
448490	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Sécurités - DGGN	PLF pour 2020 - Sécurités - DGGN	2020-01-21 16:30:00	2020-01-21 17:30:00	\N	\N	1	0	\N	\N
448561	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur	\N	2020-01-21 14:30:00	2020-01-21 15:15:00	\N	\N	0	0	\N	\N
448563	COM_PERMANENTE	AUTRE	\N	FINC	\N	Résultats de l'exercice 2019 - Audition de M. Gérald DARMANIN	Résultats de l'exercice 2019 - Audition de M. Gérald DARMANIN	2020-01-28 19:35:00	2020-01-28 20:30:00	2020-01-29 09:00:19	2020-01-29 18:04:02	22	0	\N	\N
448573	COM_PERMANENTE	AUTRE	\N	FINC	\N	Contrôle financements publics réservés à l'agriculture biologique - Nomination rapporteur 	Contrôle financements publics réservés à l'agriculture biologique - Nomination rapporteur PPRE cadre financier pluriann.	2020-01-29 10:00:00	2020-01-29 11:15:00	2020-01-29 11:21:33	2020-01-29 18:04:06	33	0	\N	\N
448613	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Améliorer les droits des usagers des transports en cas de grève	\N	2020-01-22 17:00:00	2020-01-22 17:45:00	\N	\N	1	0	\N	\N
448624	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Système universel de retraite	\N	2020-01-23 10:30:00	2020-01-23 12:30:00	\N	\N	1	0	\N	\N
461755	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL n° 368 - Système universel de retraite - Économistes	PJL n° 368 - Système universel de retraite - Économistes	2020-03-04 10:30:00	2020-03-04 12:30:00	\N	\N	1	0	\N	\N
461768	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL n° 368 - Système universel de retraite - FFA / COR	PJL n° 368 - Système universel de retraite - FFA / COR	2020-03-04 13:30:00	2020-03-04 15:15:00	\N	\N	1	0	\N	\N
462243	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions rapporteur PJL Adaptation au droit de l'Union européenne	Auditions M. Laurent Duplomb	2020-03-04 13:30:00	2020-03-04 15:00:00	\N	\N	1	0	\N	\N
462246	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions rapporteur DADUE PJL Adaptation au droit de l'Union européenne	Auditions M. Laurent Duplomb	2020-03-04 16:30:00	2020-03-04 19:30:00	\N	\N	1	0	\N	\N
462250	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition GT Nouvelles formes de commerce	Audition GT Nouvelles formes de commerce	2020-03-05 09:45:00	2020-03-05 10:30:00	\N	\N	1	0	\N	\N
462252	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - La mission « Action et transformation publiques » - DGAFP	Contrôle 2020 - La mission « Action et transformation publiques » - DGAFP	2020-03-03 15:45:00	2020-03-03 16:45:00	\N	\N	2	0	\N	\N
462270	COM_ENQUETE	AUDRAP	\N	RADICALI	\N	Philippe Sibille, direction des sports	Philippe Sibille, direction des sports	2020-03-05 11:50:00	2020-03-05 12:45:00	\N	\N	2	0	\N	\N
462434	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Pass Culture	Pass Culture	2020-03-04 12:05:00	2020-03-04 12:15:00	\N	\N	4	0	\N	\N
438288	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Examen des amendements de séance et désignation de rapporteurs	\N	2019-12-11 09:00:00	2019-12-11 09:30:00	2019-12-11 15:01:50	2019-12-11 16:05:14	38	0	\N	\N
441788	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion 20200108	Réunion de la commission	2020-01-08 10:05:00	2020-01-08 12:01:00	2020-01-08 14:14:32	2020-01-08 15:13:19	36	1	\N	\N
462439	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Protéger les victimes de violences conjugales	\N	2020-03-04 16:30:00	2020-03-04 18:30:00	\N	\N	1	0	\N	\N
462441	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Protéger les victimes de violences conjugales	\N	2020-03-05 09:00:00	2020-03-05 10:15:00	\N	\N	1	0	\N	\N
462460	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition rapporteur PJL Adaptation au droit de l'Union européenne	Auditions M. Laurent Duplomb	2020-03-05 14:30:00	2020-03-05 16:20:00	\N	\N	1	0	\N	\N
462478	COM_ENQUETE	PLENIERE	\N	AUTOROUT	\N	Audition de M. Philippe MARTIN puis de M. Bruno ANGLES	Audition de M. Philippe MARTIN puis de M. Bruno ANGLES	2020-03-11 09:35:00	2020-03-11 12:10:00	2020-03-11 14:21:31	2020-03-12 14:44:52	8	0	\N	\N
462479	COM_ENQUETE	PLENIERE	\N	AUTOROUT	\N	Audition de M. Gilles de ROBIEN puis de M. Gilles CARREZ	Audition de M. Gilles de ROBIEN puis de M. Gilles CARREZ	2020-03-11 15:45:00	2020-03-11 18:00:00	2020-03-11 18:03:16	2020-03-12 14:44:55	8	0	\N	\N
462494	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Auditions rapporteurs MI Travailleurs indépendants	\N	2020-03-03 15:45:00	2020-03-03 19:45:00	\N	\N	2	0	\N	\N
462495	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteurs MI travailleurs indépendants	\N	2020-03-04 13:45:00	2020-03-04 14:45:00	\N	\N	2	0	\N	\N
462496	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Auditions rapporteurs MI travailleurs indépendants	\N	2020-03-05 08:30:00	2020-03-05 10:30:00	\N	\N	3	0	\N	\N
462617	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Système universel de retraite	PJL Système universel de retraite	2020-03-10 11:00:00	2020-03-10 12:30:00	\N	\N	1	0	\N	\N
462619	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Système universel de retraite	PJL Système universel de retraite	2020-03-10 14:00:00	2020-03-10 19:00:00	\N	\N	2	0	\N	\N
462644	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PJL Système universel de retraite - Audition	\N	2020-03-25 16:30:00	2020-03-25 18:00:00	\N	\N	0	0	\N	\N
462645	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition PJL Syst. retraite et exam. rapport information MI Travailleurs indépendants	\N	2020-03-25 09:00:00	2020-03-25 12:00:00	\N	\N	0	0	\N	\N
463347	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2020-03-03 14:40:00	2020-03-03 16:50:00	\N	\N	3	0	\N	\N
463351	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2020-03-10 14:30:00	2020-03-10 16:15:00	\N	\N	2	0	\N	\N
463354	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	c	2020-02-25 14:30:00	2020-02-25 17:40:00	\N	\N	3	0	\N	\N
463445	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2020-03-24 14:50:00	2020-03-24 16:20:00	\N	\N	3	0	\N	\N
463841	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-04-10 11:10:00	2020-04-10 12:40:00	\N	\N	37	0	\N	\N
463842	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-04-09 14:30:00	2020-04-09 17:15:00	\N	\N	40	0	\N	\N
463847	DELEGATION	AUDRAP	\N	\N	206	Audition Réseau Environnement Santé (RES)	\N	2020-04-07 18:00:00	2020-04-07 19:40:00	\N	\N	2	0	\N	\N
463927	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Michel Duru, chercheur à l'INRAE	\N	2020-04-08 15:00:00	2020-04-08 16:00:00	\N	\N	1	0	\N	\N
463929	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Christian Couturier	\N	2020-04-08 16:00:00	2020-04-08 17:20:00	\N	\N	1	0	\N	\N
463955	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition de M. Jean-Michel Blanquer - Visioconférence	Audition de M. Jean-Michel Blanquer - Visioconférence	2020-04-09 11:10:00	2020-04-09 13:20:00	\N	\N	32	0	\N	\N
464307	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLFR pour 2020 - Audition de plusieurs économistes	PLFR pour 2020 - Audition de plusieurs économistes	2020-04-14 17:05:00	2020-04-14 18:40:00	\N	\N	30	0	\N	\N
464308	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLFR pour 2020 - Audition Gouverneur Banque de France et Médiateur national du crédit 	PLFR pour 2020 - Audition du gouverneur de la Banque de France et du médiateur national du crédit aux entreprises	2020-04-15 10:30:00	2020-04-15 12:15:00	2020-04-15 12:46:19	\N	29	0	\N	\N
464309	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLFR pour 2020 - Audition de M. DARMANIN, Ministre, et Mme PANNIER-RUNACHER et M. DUSSOPT	PLFR pour 2020 - Audition de M. DARMANIN, Ministre, et Mme PANNIER-RUNACHER et M. DUSSOPT, secrétaires d'État	2020-04-15 18:05:00	2020-04-15 20:20:00	\N	\N	37	0	\N	\N
464310	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFR 2020	PLFR 2020	2020-04-21 14:30:00	2020-04-21 16:28:00	\N	\N	50	0	\N	\N
464311	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFR 2020	PLFR 2020	2020-04-21 21:43:00	2020-04-22 00:30:00	\N	\N	52	0	\N	\N
464312	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition du Conseil scientifique Covid-19 par visioconférence	\N	2020-04-15 11:10:00	2020-04-15 12:50:00	\N	\N	35	0	\N	\N
464313	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de la CNIL par visioconférence	\N	2020-04-15 09:30:00	2020-04-15 11:05:00	\N	\N	35	0	\N	\N
464314	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-04-14 15:15:00	2020-04-14 17:30:00	\N	\N	28	0	\N	\N
464342	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-04-15 17:00:00	2020-04-15 19:15:00	\N	\N	37	0	\N	\N
464347	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Audition de M. Thomas Courbe, directeur général des entreprises (MINEFI)	Audition de M. Thomas Courbe, directeur général des entreprises (MINEFI)	2020-04-14 17:00:00	2020-04-14 18:45:00	\N	\N	14	0	\N	\N
464622	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PLFR 2020	CMP PLFR 2020	2020-04-23 19:04:00	2020-04-23 20:24:00	\N	\N	21	0	\N	\N
465390	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi Covid-19 - Juridictions judiciaires et administratives	Audition de la Conférence nationale des Procureurs de la République	2020-04-15 16:30:00	2020-04-15 17:30:00	\N	\N	12	0	\N	\N
465403	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi urgence Covid-19 - Juridictions judiciaires et administratives	Audition du CNB - Conférence des bâtonniers et Barreau de Paris	2020-04-17 10:30:00	2020-04-17 11:30:00	\N	\N	11	0	\N	\N
465415	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-04-20 14:00:00	2020-04-20 15:50:00	\N	\N	22	0	\N	\N
465416	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFR pour 2020 "Engagements financiers de l'État" - Suivi mesures crise covid-19 - AFT	PLFR pour 2020 "Engagements financiers de l'État" - Suivi mesures crise covid-19 - AFT	2020-04-15 14:00:00	2020-04-15 14:40:00	\N	\N	1	0	\N	\N
465418	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFR pour 2020 "Engagements financiers de l'État" - Suivi mesures crise covid-19 - Moody's	PLFR pour 2020 "Engagements financiers de l'État" - Suivi mesures crise covid-19 - Moody's	2020-04-16 11:00:00	2020-04-16 11:40:00	\N	\N	1	0	\N	\N
465469	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition par visioconférence de l'Institut Pasteur	\N	2020-04-20 14:35:00	2020-04-20 16:25:00	\N	\N	32	0	\N	\N
465505	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Audition de M. Pierre Pelouzet, médiateur des entreprises	\N	2020-04-20 14:30:00	2020-04-20 15:30:00	\N	\N	10	0	\N	\N
465926	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audioconférence avec Airbus	\N	2020-04-16 09:45:00	2020-04-16 10:45:00	\N	\N	2	0	\N	\N
375329	MISSION	AUDRAP	\N	CLIMATIQUE	\N	Audition de l'association "Les oubliés de la canicule"	\N	2019-04-30 14:30:00	2019-04-30 15:30:00	\N	\N	7	0	\N	\N
375330	MISSION	AUDRAP	\N	CLIMATIQUE	\N	Auditions rapporteure (SEBAN & ASSOCIES, M. DANIEL-LACOMBE et CEPRI)	\N	2019-04-30 09:30:00	2019-04-30 12:30:00	\N	\N	5	0	\N	\N
502342	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2020-12-01 09:30:00	2020-12-01 12:40:00	\N	\N	45	0	\N	\N
462646	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PPL Pérennisation et généralisation des maisons de naissance	\N	2020-03-25 12:00:00	2020-03-25 13:00:00	\N	\N	0	0	\N	\N
375331	MISSION	AUDRAP	\N	CLIMATIQUE	\N	Audition de l'AFPCN, Mme DEBRAS et de l'ACZA/ASSIL	\N	2019-04-30 15:00:00	2019-04-30 18:00:00	\N	\N	5	0	\N	\N
375349	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Organisation du système de santé	PJL Organisation du système de santé	2019-04-23 10:15:00	2019-04-23 11:15:00	\N	\N	1	0	\N	\N
375351	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Organisation du système de santé	PJL Organisation du système de santé	2019-04-23 14:00:00	2019-04-23 15:00:00	\N	\N	1	0	\N	\N
375353	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Organisation du système de santé	PJL Organisation du système de santé	2019-04-30 16:00:00	2019-04-30 17:00:00	\N	\N	1	0	\N	\N
375355	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Organisation du système de santé	PJL Organisation du système de santé	2019-04-30 17:45:00	2019-04-30 18:30:00	\N	\N	2	0	\N	\N
375358	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Organisation du système de santé	PJL Organisation du système de santé	2019-05-02 09:00:00	2019-05-02 09:50:00	\N	\N	2	0	\N	\N
375363	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Organisation du système de santé	PJL Organisation du système de santé	2019-05-02 10:00:00	2019-05-02 11:45:00	\N	\N	3	0	\N	\N
375377	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Organisation du système de santé	PJL Organisation du système de santé	2019-05-02 11:45:00	2019-05-02 13:00:00	\N	\N	3	0	\N	\N
375395	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Organisation du système de santé	PJL Organisation du système de santé	2019-05-02 15:00:00	2019-05-02 16:30:00	\N	\N	4	0	\N	\N
375423	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Organisation du système de santé	PJL Organisation du système de santé	2019-05-02 16:30:00	2019-05-02 17:30:00	\N	\N	4	0	\N	\N
375443	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Organisation du système de santé	PJL Organisation du système de santé	2019-05-02 10:00:00	2019-05-02 13:00:00	\N	\N	2	0	\N	\N
383087	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	SGAE	\N	2019-06-04 15:00:00	2019-06-04 16:30:00	\N	\N	0	0	\N	\N
383115	MISSION	DEPLACEMENT	\N	CLIMATIQUE	\N	MI Risques climatiques - Déplacement en Charente 	MI Risques climatiques - Déplacement en Charente 	2019-05-20 07:45:00	2019-05-20 19:50:00	\N	\N	3	0	\N	\N
383140	MISSION	AUCUNE	\N	INFRACTIONS	\N	Examen et adoption du rapport	\N	2019-05-28 14:45:00	2019-05-28 16:40:00	2019-05-28 16:40:25	2019-05-29 15:26:34	19	0	\N	\N
384104	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-06-04 16:35:00	2019-06-04 17:40:00	2019-06-04 18:40:45	2019-06-05 11:49:11	25	0	\N	\N
384105	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-06-05 09:35:00	2019-06-05 12:10:00	2019-06-05 12:15:58	2019-06-05 12:22:44	40	0	\N	\N
384671	MISSION	AUCUNE	\N	CLIMATIQUE	\N	Audition commune des associations d'élus locaux	\N	2019-05-28 14:11:00	2019-05-28 15:45:00	2019-05-31 09:26:58	2019-05-31 14:44:15	7	0	\N	\N
391583	GIA	AUCUNE	\N	\N	\N	Assemblée générale	Assemblée générale	2019-06-18 13:00:00	2019-06-18 13:30:00	\N	\N	5	0	612	\N
394458	GIA	AUCUNE	\N	\N	\N	Entretien de Marta de CIDRAC avec Mme Vjosa OSMANI, Députée du Kosovo (coopé)	Entretien de Marta de CIDRAC avec Mme Vjosa OSMANI, Députée du Kosovo (coopé)	2019-06-12 14:00:00	2019-06-12 15:00:00	\N	\N	1	0	674	\N
396227	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière - Audition Recherche énergies renouvelables - Loi de bioéthique	Réunion plénière - Audition Recherche énergies renouvelables - Loi de bioéthique	2019-07-04 09:15:00	2019-07-04 13:30:00	\N	\N	8	0	\N	\N
396296	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	 MI Santé au travail santé au travail	\N	2019-06-25 14:30:00	2019-06-25 16:00:00	\N	\N	2	0	\N	\N
396305	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Mme Gruny M. Artano MI Santé au travail	\N	2019-06-25 16:00:00	2019-06-25 16:45:00	\N	\N	2	0	\N	\N
396308	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Mme Gruny M. Artano MI Santé au travail	\N	2019-06-26 14:00:00	2019-06-26 14:45:00	\N	\N	2	0	\N	\N
396311	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition "Article 13" de Mme Stéphane PALLEZ, candidate FDJ puis Vote	Audition "Article 13" de Mme Stéphane PALLEZ, candidate FDJ puis Vote	2019-07-03 09:05:00	2019-07-03 11:00:00	2019-07-04 09:50:28	2019-07-04 16:30:20	35	0	\N	\N
396312	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Mme Gruny M. Artano MI Santé au travail	\N	2019-06-26 14:45:00	2019-06-26 15:30:00	\N	\N	2	0	\N	\N
396313	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Mme Gruny M. Artano MI Santé au travail	\N	2019-06-26 15:30:00	2019-06-26 16:15:00	\N	\N	2	0	\N	\N
396318	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL de règlement 2018 - Mission "Sécurités" - DGPN	PJL de règlement 2018 - Mission "Sécurités" - DGPN	2019-06-27 09:00:00	2019-06-27 11:00:00	\N	\N	1	0	\N	\N
396428	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2019 - Sécurité informatiques des pouvoirs public - Elysée	Contrôle 2019 - Sécurité informatiques des pouvoirs public - Elysée	2019-06-24 14:00:00	2019-06-24 16:00:00	\N	\N	1	0	\N	\N
396430	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Sécurité informatiques des pouvoirs public - Public Sénat	Contrôle 2019 - Sécurité informatiques des pouvoirs public - Public Sénat	2019-06-26 09:00:00	2019-06-26 10:00:00	\N	\N	1	0	\N	\N
396432	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2019 - Masse salariale du MEAE - Déplacement Tallinn	Contrôle 2019 - Masse salariale du MEAE - Déplacement Tallinn	2019-06-30 18:40:00	2019-07-01 18:00:00	\N	\N	2	0	\N	\N
396433	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2019 - Masse salariale du MEAE - Déplacement Helsinki	Contrôle 2019 - Masse salariale du MEAE - Déplacement Helsinki	2019-07-01 18:00:00	2019-07-02 21:35:00	\N	\N	2	0	\N	\N
462515	COM_PERMANENTE	AUTRE	\N	CDD	\N	Audition MI empreinte environnementale du numérique	Audition MI empreinte environnementale du numérique	2020-03-04 13:30:00	2020-03-04 14:45:00	\N	\N	5	0	\N	\N
462527	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - Les aides à la presse - Culture Presse	Contrôle 2020 - Les aides à la presse - Culture Presse	2020-03-09 15:00:00	2020-03-09 16:00:00	\N	\N	1	0	\N	\N
462552	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - Financement politiques lutte contre violences femmes - HCE	Contrôle 2020 - Financement politiques lutte contre violences femmes - HCE	2020-03-09 10:00:00	2020-03-09 11:45:00	\N	\N	2	0	\N	\N
462555	COM_ENQUETE	AUDRAP	\N	AUTOROUT	\N	CE concessions autoroutières - DGCCRF	CE concessions autoroutières - DGCCRF	2020-03-10 10:00:00	2020-03-10 11:30:00	\N	\N	4	0	\N	\N
462560	COM_ENQUETE	AUDRAP	\N	AUTOROUT	\N	CE concessions autoroutières - Alain VIDALIES, Ancien ministre	CE concessions autoroutières - Alain VIDALIES, Ancien ministre	2020-03-10 11:30:00	2020-03-10 12:30:00	\N	\N	4	0	\N	\N
462565	COM_ENQUETE	AUDRAP	\N	AUTOROUT	\N	CE concessions autoroutières - Frédéric FORTIN, auteur d'un rapport	CE concessions autoroutières - Frédéric FORTIN, auteur d'un rapport	2020-03-10 14:30:00	2020-03-10 16:00:00	\N	\N	2	0	\N	\N
462568	COM_ENQUETE	PLENIERE	\N	RADICALI	\N	Audition plénière	\N	2020-03-11 13:05:00	2020-03-11 14:20:00	2020-03-12 10:27:57	2020-03-12 14:44:53	4	0	\N	\N
462569	COM_ENQUETE	PLENIERE	\N	RADICALI	\N	Audition de la FNEM	Audition de la FNEM	2020-03-11 14:20:00	2020-03-11 15:45:00	2020-03-12 10:28:32	2020-03-12 14:44:52	5	0	\N	\N
462570	COM_ENQUETE	PLENIERE	\N	RADICALI	\N	Audition de Gilles Roussel, président de la Conférence des présidents d'université	\N	2020-03-11 15:45:00	2020-03-11 17:00:00	2020-03-12 14:36:54	2020-03-12 14:44:54	5	0	\N	\N
462667	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - La protection des épargnants - FAIDER  / France FINTECH	Contrôle 2020 - La protection des épargnants - FAIDER  / France FINTECH	2020-03-10 15:00:00	2020-03-10 17:00:00	\N	\N	1	0	\N	\N
462669	DELEGATION	AUCUNE	\N	\N	COLTER	Table ronde projet loi "3D" : universitaires	\N	2020-03-25 16:30:00	2020-03-25 18:30:00	\N	\N	0	0	\N	\N
463520	DELEGATION	AUCUNE	\N	\N	PROS	Audition de M. David Djaïz	\N	2020-04-09 09:35:00	2020-04-09 10:45:00	\N	\N	18	0	\N	\N
463521	DELEGATION	AUTRE	\N	\N	211	Réunion de bureau	\N	2020-03-30 10:00:00	2020-03-30 11:30:00	\N	\N	9	0	\N	\N
463531	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion visioconférence CATDD	\N	2020-04-02 15:00:00	2020-04-02 17:15:00	\N	\N	41	0	\N	\N
463542	DELEGATION	AUCUNE	\N	\N	211	Réunion de la délégation	\N	2020-04-06 14:00:00	2020-04-06 15:15:00	\N	\N	18	0	\N	\N
463627	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission 	\N	2020-04-06 11:00:00	2020-04-06 13:00:00	\N	\N	45	0	\N	\N
463675	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition de Mme Frédérique Vidal (visioconférence-format restreint)	Audition de Mme Frédérique Vidal (visioconférence-format restreint)	2020-04-06 15:00:00	2020-04-06 16:30:00	\N	\N	13	0	\N	\N
463731	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2020-04-15 15:01:00	2020-04-15 15:55:00	\N	\N	23	0	\N	\N
463732	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2020-04-22 15:01:00	2020-04-22 15:55:00	\N	\N	42	0	\N	\N
463733	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2020-04-29 15:05:00	2020-04-29 16:05:00	\N	\N	23	0	\N	\N
464134	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Cybersécurité en période de crise sanitaire	Cybersécurité en période de crise sanitaire	2020-03-31 15:00:00	2020-03-31 16:00:00	\N	\N	2	0	\N	\N
464137	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Cybersécurité en période de crise sanitaire	Cybersécurité en période de crise sanitaire	2020-04-01 11:00:00	2020-04-01 12:00:00	\N	\N	2	0	\N	\N
464513	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFR pour 2020 "MIRES et IA" - Suivi mesures crise covid-19 - SGI	PLFR pour 2020 "MIRES et IA" - Suivi mesures crise covid-19 - SGI	2020-04-14 16:00:00	2020-04-14 17:00:00	\N	\N	2	0	\N	\N
464587	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2020-04-15 10:00:00	2020-04-15 12:12:00	\N	\N	33	0	\N	\N
464641	DELEGATION	AUDRAP	\N	\N	206	Audition de membres de l'Université de Montpellier 	\N	2020-04-14 10:00:00	2020-04-14 13:35:00	\N	\N	2	0	\N	\N
464648	DELEGATION	AUCUNE	\N	\N	211	Réunion du Bureau de la délégation	\N	2020-04-15 11:00:00	2020-04-15 12:15:00	\N	\N	10	0	\N	\N
396435	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen rapport PJLR 2018 - Désignations et nominations - Actualisation contrôles 2019	Examen rapport PJLR 2018 - Désignations et nominations - Actualisation contrôles 2019	2019-07-03 11:00:00	2019-07-03 12:00:00	2019-07-04 09:50:44	2019-07-04 16:30:18	36	0	\N	\N
465053	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition par visioconférence de M. Jean-Yves Le Drian	\N	2020-04-15 16:30:00	2020-04-15 18:40:00	\N	\N	41	0	\N	\N
465287	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLFR pour 2020 (2) - Examen du rapport et désignation CMP	PLFR pour 2020 (2) - Examen du rapport et désignation CMP	2020-04-21 09:10:00	2020-04-21 11:15:00	2020-04-21 11:52:59	2020-04-21 16:31:54	37	0	\N	\N
465288	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLFR pour 2020 (2) - Examen des AMDTS de séance	PLFR pour 2020 (2) - Examen des AMDTS de séance	2020-04-21 19:35:00	2020-04-21 20:45:00	\N	\N	29	0	\N	\N
465293	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition en visioconférence de la directrice centrale du service de santé des armées	\N	2020-04-17 10:00:00	2020-04-17 11:35:00	\N	\N	33	0	\N	\N
465328	DELEGATION	AUDRAP	\N	\N	206	Audition de représentants d'EDF	\N	2020-04-15 15:00:00	2020-04-15 17:00:00	\N	\N	1	0	\N	\N
465330	DELEGATION	AUDRAP	\N	\N	206	Audition de l'Institut méditerranéen d'océanologie (M.I.O)	\N	2020-04-15 16:00:00	2020-04-15 18:40:00	\N	\N	2	0	\N	\N
465333	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de M. Cédric O par visioconférence	Audition de M. Cédric O par visioconférence	2020-04-20 14:30:00	2020-04-20 16:00:00	\N	\N	21	0	\N	\N
465335	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de M. Jacques Toubon par visioconférence	Audition de M. Jacques Toubon par visioconférence	2020-04-22 09:05:00	2020-04-22 10:45:00	\N	\N	29	0	\N	\N
465336	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de M. Olivier Dussopt par visioconférence	\N	2020-04-23 14:30:00	2020-04-23 16:17:00	\N	\N	23	0	\N	\N
465337	DELEGATION	AUDRAP	\N	\N	206	Audition de l'Observatoire océanologique de Banyuls-sur-mer	\N	2020-04-16 15:00:00	2020-04-16 17:00:00	\N	\N	2	0	\N	\N
465341	DELEGATION	AUCUNE	\N	\N	206	Audition sur les scénarios de sortie du confinement	\N	2020-04-16 09:40:00	2020-04-16 12:15:00	\N	\N	22	0	\N	\N
465364	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de Mme Isabelle Sancerni et M. Vincent Mazauric de la CNAF (téléconférence)	\N	2020-04-22 10:00:00	2020-04-22 12:00:00	2020-04-23 19:47:54	\N	35	0	\N	\N
465365	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de G. Darmanin, ministre de l'action et des comptes publics (téléconférence)	\N	2020-04-22 16:30:00	2020-04-22 18:30:00	2020-04-23 20:16:53	\N	40	0	\N	\N
375504	MECSS	AUDRAP	\N	\N	MECSS	GT Réforme des retraites	GT Réforme des retraites	2019-05-28 15:30:00	2019-05-28 16:30:00	\N	\N	1	0	\N	\N
375506	MECSS	AUDRAP	\N	\N	MECSS	GT Réforme des retraites	GT Réforme des retraites	2019-06-11 17:45:00	2019-06-11 18:45:00	\N	\N	1	0	\N	\N
382640	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Instituer un médiateur territorial dans certaines collectivités	PPL Instituer un médiateur territorial dans certaines collectivités	2019-05-22 16:40:00	2019-05-22 18:15:00	\N	\N	2	0	\N	\N
382643	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Instituer un médiateur territorial dans certaines collectivités	PPL Instituer un médiateur territorial dans certaines collectivités	2019-05-23 09:15:00	2019-05-23 10:30:00	\N	\N	1	0	\N	\N
382674	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPRE Clarifier et actualiser le Règlement du Sénat	PPRE Clarifier et actualiser le Règlement du Sénat	2019-05-22 17:15:00	2019-05-22 19:30:00	\N	\N	1	0	\N	\N
387434	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Transformation de la fonction publique	\N	2019-06-05 16:00:00	2019-06-05 17:00:00	\N	\N	3	0	\N	\N
387468	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Transformation de la fonction publique	\N	2019-06-05 17:30:00	2019-06-05 19:00:00	\N	\N	2	0	\N	\N
387471	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Transformation de la fonction publique	\N	2019-06-05 21:00:00	2019-06-05 22:15:00	\N	\N	3	0	\N	\N
392638	GIA	AUCUNE	\N	\N	\N	Entretien avec le  président du groupe d'amitié France-Mongolie de l'Assemblée nationale	Entretien avec M. Stéphane BAUDU  président du groupe d'amitié France-Mongolie de l'Assemblée nationale	2019-06-19 12:45:00	2019-06-19 14:05:00	\N	\N	1	0	612	\N
392641	GIA	AUCUNE	\N	\N	\N	Groupe d'amitié France-Slovénie : entretien "Journée mondiale de l'abeille"	Groupe d'amitié France-Slovénie : entretien "Journée mondiale de l'abeille"	2019-06-19 12:30:00	2019-06-19 14:05:00	\N	\N	5	0	529	\N
392655	DELEGATION	AUDRAP	\N	\N	206	Audition M. Hervé Chneiweiss, INSERM (Neurosciences)	Audition M. Hervé Chneiweiss, INSERM (Neurosciences)	2019-07-09 14:00:00	2019-07-09 15:00:00	\N	\N	1	0	\N	\N
403027	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion commission des lois 23/07/2019	Réunion commission des lois 23/07/2019	2019-07-23 14:00:00	2019-07-23 14:20:00	2019-07-23 14:43:58	2019-07-23 17:39:53	16	0	\N	\N
404902	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Économie circulaire - Auditions Mme LOISIER	PJL Économie circulaire	2019-09-04 14:30:00	2019-09-04 15:05:00	\N	\N	1	0	\N	\N
404903	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Économie circulaire - Auditions Mme LOISIER	PJL Économie circulaire	2019-09-04 08:30:00	2019-09-04 09:00:00	\N	\N	1	0	\N	\N
404904	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Économie circulaire - Auditions Mme LOISIER	PJL Économie circulaire	2019-09-04 09:25:00	2019-09-04 10:00:00	\N	\N	1	0	\N	\N
404905	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Économie circulaire - Auditions Mme LOISIER	PJL Économie circulaire	2019-09-04 10:15:00	2019-09-04 11:05:00	\N	\N	1	0	\N	\N
404906	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Économie circulaire - Auditions Mme LOISIER	PJL Économie circulaire	2019-09-04 11:05:00	2019-09-04 11:35:00	\N	\N	1	0	\N	\N
404907	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Économie circulaire - Auditions Mme LOISIER	PJL Économie circulaire	2019-09-04 11:40:00	2019-09-04 13:00:00	\N	\N	1	0	\N	\N
404908	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Économie circulaire - Auditions Mme LOISIER	PJL Économie circulaire	2019-09-04 15:10:00	2019-09-04 16:10:00	\N	\N	1	0	\N	\N
404909	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Économie circulaire - Auditions Mme LOISIER	PJL Économie circulaire	2019-09-04 16:15:00	2019-09-04 17:00:00	\N	\N	1	0	\N	\N
404910	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Économie circulaire - Auditions Mme LOISIER	PJL Économie circulaire	2019-09-04 17:00:00	2019-09-04 17:35:00	\N	\N	1	0	\N	\N
404911	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Économie circulaire - Auditions Mme LOISIER	PJL Économie circulaire	2019-09-04 17:35:00	2019-09-04 18:15:00	\N	\N	1	0	\N	\N
404912	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Économie circulaire - Auditions Mme LOISIER	PJL Économie circulaire	2019-09-04 18:20:00	2019-09-04 19:45:00	\N	\N	1	0	\N	\N
404924	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-09-17 13:30:00	2019-09-17 14:45:00	2019-09-18 11:27:22	2019-09-18 11:29:20	20	2	\N	\N
413998	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Lutte contre la haine sur internet	\N	2019-10-10 09:00:00	2019-10-10 12:00:00	\N	\N	1	0	\N	\N
414000	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Lutte contre la haine sur internet	\N	2019-10-10 14:30:00	2019-10-10 16:00:00	\N	\N	2	0	\N	\N
405201	CMP	AUTRE	\N	MUSIQUE	\N	PPL Création du Centre national de la musique	PPL Création du Centre national de la musique	2019-09-13 13:00:00	2019-09-13 13:25:00	\N	\N	8	0	\N	\N
418965	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS Budget 2020 - Equilibres financiers généraux	\N	2019-10-22 15:30:00	2019-10-22 17:00:00	\N	\N	1	0	\N	\N
420399	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Agir contre les violences au sein de la famille	PPL Violences au sein de la famille	2019-10-24 09:05:00	2019-10-24 10:00:00	\N	\N	1	0	\N	\N
420402	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Agir contre les violences au sein de la famille	PPL Violences au sein de la famille	2019-10-24 11:10:00	2019-10-24 12:10:00	\N	\N	1	0	\N	\N
430232	DELEGATION	AUCUNE	\N	\N	COLTER	Audition général Rodriguez, directeur général de la gendarmerie nationale	\N	2019-11-28 11:00:00	2019-11-28 12:30:00	2019-11-28 15:42:05	\N	8	0	\N	\N
446079	GIA	AUCUNE	\N	\N	\N	AG du groupe France - Cambodge et Laos	Assemblée générale du groupe France - Cambodge et Laos	2020-01-22 14:00:00	2020-01-22 14:45:00	\N	\N	4	0	577	\N
448625	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Système universel de retraite	\N	2020-01-22 09:00:00	2020-01-22 11:15:00	\N	\N	1	0	\N	\N
448632	COM_SPECIALE	PLENIERE	\N	BIOETHIQUE	\N	Réunion CS Bioéthique - jeudi 23 janvier 2020	\N	2020-01-23 19:15:00	2020-01-23 19:30:00	2020-01-27 09:43:00	2020-01-27 18:07:22	16	0	\N	\N
448634	DELEGATION	AUDRAP	\N	\N	PROS	Audition du CREDOC	\N	2020-02-04 17:30:00	2020-02-04 18:45:00	\N	\N	1	0	\N	\N
450802	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI  Coopération France Russie	RI  Coopération France Russie	2020-01-28 09:45:00	2020-01-28 11:00:00	\N	\N	2	0	\N	\N
450806	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI  Coopération France Russie	RI Coopération France Russie	2020-01-30 10:45:00	2020-01-30 11:00:00	\N	\N	2	0	\N	\N
452047	GIA	AUCUNE	\N	\N	\N	Entretien avec plusieurs ambassadeurs de la région	Entretien avec plusieurs ambassadeurs de la région (Singapour, Bangladesh, Brunei, Malaisie)	2020-02-04 19:30:00	2020-02-04 22:15:00	\N	\N	13	0	609	\N
453567	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	GT Expertise psychiatrique en matière pénale	GT Expertise psychiatrique en matière pénale	2020-02-05 16:00:00	2020-02-05 19:15:00	\N	\N	1	0	\N	\N
453593	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Agriculteurs en situation de détresse	GT Agriculteurs en situation de détresse - Audition P. Spoljar	2020-02-05 13:30:00	2020-02-05 14:30:00	\N	\N	8	0	\N	\N
453857	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT infrastructures de transport - Réunion	GT infrastructures de transport - Réunion	2020-02-05 14:00:00	2020-02-05 14:45:00	\N	\N	7	0	\N	\N
454549	COM_SPECIALE	PLENIERE	\N	ASAP	\N	Bureau de la commission spéciale ASAP	Bureau de la commission spéciale ASAP	2020-02-18 14:30:00	2020-02-18 14:55:00	\N	\N	10	0	\N	\N
454567	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	entretien avec S. Exc. M. Jamoliddin Ubaidullo, ambassadeur du Tadjikistan en France	\N	2020-02-18 13:30:00	2020-02-18 14:30:00	\N	\N	2	0	\N	\N
456844	GIA	AUCUNE	\N	\N	\N	Coopé - Visite d'une délégation parlementaire indonésienne	Coopé - Visite d'une délégation parlementaire indonésienne	2020-02-24 11:00:00	2020-02-24 12:30:00	\N	\N	1	0	653	\N
456847	GIA	AUCUNE	\N	\N	\N	Déjeuner avec l'ambassadeur d'Irak	Déjeuner à la résidence de M. l'ambassadeur d'Irak, Nizar al-Khayrallah	2020-02-18 12:45:00	2020-02-18 14:30:00	\N	\N	4	0	615	\N
456852	GIA	AUCUNE	\N	\N	\N	Rencontre avec M. Ali Fares	Rencontre au Sénat avec M. Ali Fares, membre du conseil irakien de sécurité nationale	2020-02-24 16:00:00	2020-02-24 16:30:00	\N	\N	1	0	615	\N
459208	COM_PERMANENTE	AUDRAP	\N	FINC	\N	GT 2018 - Évolution de la fiscalité locale - OFGL Secrétaire Général	GT 2018 - Évolution de la fiscalité locale - OFGL Secrétaire Général	2020-03-04 13:45:00	2020-03-04 14:45:00	\N	\N	4	0	\N	\N
466407	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de Philippe Sansonetti, médecin et chercheur en microbiologie (téléconférence)	\N	2020-04-30 15:30:00	2020-04-30 17:30:00	2020-05-12 16:30:42	\N	23	0	\N	\N
466411	DELEGATION	AUCUNE	\N	\N	DSOM	Audition de Mme Marlène Schiappa	\N	2020-05-13 16:30:00	2020-05-13 17:40:00	\N	\N	25	0	\N	\N
466527	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi Covid-19 - Outils numériques de traçage	Auditions universitaires - Associations de défense des libertés sur Internet - Inria	2020-04-23 16:00:00	2020-04-23 19:15:00	\N	\N	3	0	\N	\N
466531	DELEGATION	AUDRAP	\N	\N	206	Audition du Centre technique de la conservation des produits alimentaires (CTCPA)	\N	2020-04-23 11:00:00	2020-04-23 13:00:00	\N	\N	2	0	\N	\N
466534	DELEGATION	AUCUNE	\N	\N	206	 Veille sur l'épidémie de Covid-19	\N	2020-04-23 09:30:00	2020-04-23 11:05:00	\N	\N	18	0	\N	\N
466554	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition de M. Edward Jossa, Pdg de l'UGAP	\N	2020-04-21 14:50:00	2020-04-21 16:15:00	\N	\N	2	0	\N	\N
466557	DELEGATION	AUDRAP	\N	\N	206	Audition de Michel Vampouille, président de Terres de liens	\N	2020-04-22 13:45:00	2020-04-22 14:35:00	\N	\N	1	0	\N	\N
466559	DELEGATION	AUDRAP	\N	\N	206	Audition de France Nature Environnement	\N	2020-04-22 14:35:00	2020-04-22 15:35:00	\N	\N	1	0	\N	\N
466561	DELEGATION	AUDRAP	\N	\N	206	Audition du président du Club Bio-plastiques (suite)	\N	2020-04-23 08:30:00	2020-04-23 10:00:00	\N	\N	2	0	\N	\N
466564	DELEGATION	AUCUNE	\N	\N	COLTER	Communication du président Jean-Marie Bockel	\N	2020-04-23 09:30:00	2020-04-23 10:30:00	\N	\N	10	0	\N	\N
466583	DELEGATION	AUCUNE	\N	\N	211	Audition de Mme Marlène Schiappa	\N	2020-05-13 16:30:00	2020-05-13 17:40:00	2020-05-14 11:02:11	\N	25	0	\N	\N
466590	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid19 Médias	Audition CSA	2020-04-28 15:00:00	2020-04-28 16:30:00	\N	\N	4	0	\N	\N
466591	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion de la commission par visioconférence 	\N	2020-04-29 09:30:00	2020-04-29 12:45:00	\N	\N	40	0	\N	\N
466592	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFR pour 2020 (2) - "Cohésion des territoires" - Caisse des dépôts	PLFR pour 2020 (2) - "Cohésion des territoires" - Caisse des dépôts	2020-04-22 15:00:00	2020-04-22 16:00:00	\N	\N	1	0	\N	\N
466598	DELEGATION	AUDRAP	\N	\N	206	Audition de WWF	\N	2020-04-24 16:00:00	2020-04-24 16:50:00	\N	\N	1	0	\N	\N
466600	DELEGATION	AUDRAP	\N	\N	206	Audition CLER - Réseau pour la transition énergétique	\N	2020-04-24 16:50:00	2020-04-24 17:50:00	\N	\N	1	0	\N	\N
466603	DELEGATION	AUDRAP	\N	\N	206	Auditiion de Nicolas Garnier, délégué général d'AMORCE	\N	2020-04-24 10:00:00	2020-04-24 12:00:00	\N	\N	2	0	\N	\N
466606	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition de Mme Nathalie de Gaulle et Me Christian Nouel	\N	2020-04-24 09:35:00	2020-04-24 10:55:00	\N	\N	6	0	\N	\N
466627	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFR pour 2020 (2) "MIRES et IA" - Suivi mesures crise covid-19 - DGRI	PLFR pour 2020 (2) "MIRES et IA" - Suivi mesures crise covid-19 - DGRI	2020-04-20 17:00:00	2020-04-20 18:00:00	\N	\N	2	0	\N	\N
466630	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFR pour 2020 "Écologie" - Suivi mesures crise covid-19 - SNCF Fret 	PLFR pour 2020 "Écologie" - Suivi mesures crise covid-19 - SNCF Fret 	2020-04-09 14:30:00	2020-04-09 15:30:00	\N	\N	1	0	\N	\N
466632	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFR pour 2020 "Écologie" - Suivi mesures crise covid-19 - DGAC	PLFR pour 2020 "Écologie" - Suivi mesures crise covid-19 - DGAC	2020-04-16 10:30:00	2020-04-16 12:30:00	\N	\N	1	0	\N	\N
466635	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFR pour 2020 "Écologie" - Suivi mesures crise covid-19 - ADP	PLFR pour 2020 "Écologie" - Suivi mesures crise covid-19 - ADP	2020-04-20 12:00:00	2020-04-20 13:00:00	\N	\N	1	0	\N	\N
466637	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFR pour 2020 "Écologie" - Suivi mesures crise covid-19 - VNF	PLFR pour 2020 "Écologie" - Suivi mesures crise covid-19 - VNF	2020-04-21 14:30:00	2020-04-21 15:30:00	\N	\N	1	0	\N	\N
466643	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	GT Covid19 Création	Audition France Festivals	2020-04-23 15:00:00	2020-04-23 16:00:00	\N	\N	3	0	\N	\N
466647	DELEGATION	AUCUNE	\N	\N	206	Audition de M. Cédric O,  secrétaire d'État chargé du numérique	\N	2020-04-27 14:05:00	2020-04-27 15:10:00	\N	\N	17	0	\N	\N
466675	DELEGATION	AUDRAP	\N	\N	206	Audition du CEDRE	\N	2020-04-27 10:00:00	2020-04-27 13:30:00	\N	\N	2	0	\N	\N
466682	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition de M. Thomas Lesueur commissaire général au développement durable	\N	2020-04-27 09:35:00	2020-04-27 10:40:00	\N	\N	6	0	\N	\N
466689	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Audition de l'Ordre des experts-comptables de Paris Île-de-France	\N	2020-04-27 16:00:00	2020-04-27 17:30:00	\N	\N	15	0	\N	\N
466967	DELEGATION	AUDRAP	\N	\N	206	Audition de Mme Kako NAIT ALI	\N	2020-04-28 11:30:00	2020-04-28 12:30:00	\N	\N	2	0	\N	\N
466993	DELEGATION	AUDRAP	\N	\N	206	Audition de la CME	\N	2020-04-28 10:00:00	2020-04-28 11:30:00	\N	\N	2	0	\N	\N
467054	DELEGATION	AUCUNE	\N	\N	DSOM	Audition de M. Bertrand Willocquet	\N	2020-04-30 14:00:00	2020-04-30 15:50:00	\N	\N	11	0	\N	\N
467056	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Enjeux sanitaires - Audition HCSP (Mme Deroche-téléconférence)	\N	2020-04-20 11:15:00	2020-04-20 12:15:00	\N	\N	9	0	\N	\N
467057	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Enjeux sanitaires - Audition LEEM (Mme Deroche)	\N	2020-04-20 14:30:00	2020-04-20 15:30:00	\N	\N	9	0	\N	\N
467058	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Enjeux sanitaires - Audition SANOFI (Mme Deroche)	\N	2020-04-21 14:30:00	2020-04-21 15:30:00	\N	\N	2	0	\N	\N
467059	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Enjeux sanitaires - Audition SIDIV (Mme Deroche)	\N	2020-04-23 10:45:00	2020-04-23 11:45:00	\N	\N	6	0	\N	\N
467060	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Enjeux sanitaires - Audition W. DAB (Mme Deroche)	\N	2020-04-23 14:30:00	2020-04-23 15:30:00	\N	\N	10	0	\N	\N
467061	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Enjeux sanitaires - Audition PHARMACIENS (Mme Deroche)	\N	2020-04-28 14:30:00	2020-04-28 16:00:00	\N	\N	7	0	\N	\N
467062	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Enjeux sanitaires - Audition PDS (Mme Deroche)	\N	2020-04-29 16:30:00	2020-04-29 17:45:00	\N	\N	7	0	\N	\N
467063	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Enjeux sanitaires - Audition DOCTOLIB (Mme Deroche)	\N	2020-04-30 14:00:00	2020-04-30 15:00:00	\N	\N	3	0	\N	\N
467090	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Enjeux sanitaires - Audition MONDOR (Mme Deroche)	\N	2020-04-21 17:00:00	2020-04-21 18:00:00	\N	\N	4	0	\N	\N
467123	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Enjeux sanitaires - Audition SJB (Mme Deroche)	\N	2020-04-21 15:45:00	2020-04-21 16:45:00	\N	\N	6	0	\N	\N
467209	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Enjeux sanitaires - Audition Pr BUISSON (Mme Deroche)	\N	2020-04-23 15:45:00	2020-04-23 16:45:00	\N	\N	9	0	\N	\N
467226	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission (visioconférence)	Réunion de commission (visioconférence)	2020-04-29 09:30:00	2020-04-29 12:15:00	\N	\N	33	0	\N	\N
467535	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi urgence Covid-19 - Forces de sécurité intérieure	Audition du préfet de police de Paris	2020-04-30 14:30:00	2020-04-30 15:30:00	\N	\N	6	0	\N	\N
468154	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2020-04-28 14:05:00	2020-04-28 18:40:00	\N	\N	3	0	\N	\N
468217	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission (visioconférence)	Réunion de commission (visioconférence)	2020-05-05 17:00:00	2020-05-05 18:40:00	\N	\N	27	0	\N	\N
468261	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition par visioconférence de l'ambassadeur de France en Chine	\N	2020-05-06 09:45:00	2020-05-06 12:00:00	\N	\N	41	0	\N	\N
468351	DELEGATION	AUDRAP	\N	\N	206	Audition : LEESU  (École des Ponts Paris Tech)	\N	2020-05-05 11:30:00	2020-05-05 12:20:00	\N	\N	2	0	\N	\N
468354	DELEGATION	AUDRAP	\N	\N	206	Audition : AgroParisTech	\N	2020-05-05 10:15:00	2020-05-05 11:30:00	\N	\N	2	0	\N	\N
468357	DELEGATION	AUDRAP	\N	\N	206	Audition CEREMA	\N	2020-05-05 09:00:00	2020-05-05 10:15:00	\N	\N	2	0	\N	\N
468676	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Audition d'Antoine Frérot, président de l'Institut de l'entreprise	Audition d'Antoine Frérot, président de l'Institut de l'entreprise, sur le travail prospectif	2020-05-07 14:30:00	2020-05-07 15:55:00	2020-05-07 16:59:26	\N	6	0	\N	\N
469071	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-05-13 09:30:00	2020-05-13 12:15:00	2020-05-13 18:48:21	2020-05-14 16:54:56	38	0	\N	\N
469110	COM_ENQUETE	AUDRAP	\N	AUTOROUT	\N	CE concessions autoroutières - DG Trésor	CE concessions autoroutières - DG Trésor	2020-05-12 10:00:00	2020-05-12 10:50:00	\N	\N	3	0	\N	\N
469127	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2020-05-20 09:30:00	2020-05-20 12:03:00	2020-05-20 13:46:58	2020-05-20 14:34:59	33	0	\N	\N
469128	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition commune de MM. Dominique Bussereau, Renaud Muselier, André Laignel	\N	2020-05-13 09:00:00	2020-05-13 10:40:00	2020-05-13 11:27:25	2020-05-13 18:07:57	39	0	\N	\N
469228	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFR pour 2020 (2) "MIRES et IA" - Suivi mesures crise covid-19 - Owkin	PLFR pour 2020 (2) "MIRES et IA" - Suivi mesures crise covid-19 - Owkin	2020-05-12 15:00:00	2020-05-12 16:00:00	\N	\N	2	0	\N	\N
386753	MISSION	PLEIN_NON_JO	\N	BREXIT2	\N	\N	\N	2019-06-05 15:05:00	2019-06-05 17:55:00	\N	\N	9	0	\N	\N
387767	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Examen des motions et amendements de séance - PPL Création d'un statut de l'élu communal	\N	2019-06-11 09:45:00	2019-06-11 10:34:00	2019-06-12 17:03:21	2019-06-12 17:32:10	15	0	\N	\N
387772	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition plénière - PJL de transformation de la Fonction publique	\N	2019-06-11 19:20:00	2019-06-11 20:30:00	2019-06-12 10:00:50	2019-06-12 16:55:45	12	0	\N	\N
396442	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Mme Gruny M. Artano MI Santé au travail	\N	2019-06-27 15:15:00	2019-06-27 16:00:00	\N	\N	2	0	\N	\N
396449	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Mme Gruny M. Artano MI Santé au travail	\N	2019-06-27 16:00:00	2019-06-27 16:45:00	\N	\N	2	0	\N	\N
396492	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2019 - ZRR - Déplacement Bourges	Contrôle 2019 - ZRR - Déplacement Bourges	2019-07-01 06:15:00	2019-07-01 21:00:00	\N	\N	3	0	\N	\N
397110	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Audition Dgesco	\N	2019-07-16 15:00:00	2019-07-16 17:00:00	\N	\N	0	0	\N	\N
397570	COM_PERMANENTE	AUTRE	\N	SOCI	\N	GT justice prud'homale et application LFSS pour 2018	\N	2019-07-10 09:35:00	2019-07-10 10:55:00	2019-07-10 15:14:53	2019-07-11 11:26:39	59	0	\N	\N
397572	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de Mme Muriel Pénicaud	\N	2019-07-09 18:00:00	2019-07-09 20:00:00	2019-07-09 20:09:51	2019-07-11 11:26:42	25	0	\N	\N
397595	DELEGATION	AUCUNE	\N	\N	211	Échanges de vues	Échanges de vues	2019-07-11 08:30:00	2019-07-11 10:30:00	\N	\N	9	0	\N	\N
397641	MISSION	AUCUNE	\N	FONDS	\N	Audition - Sous-utilisation chronique des fonds européens en France	\N	2019-07-03 16:00:00	2019-07-03 17:45:00	2019-07-08 12:32:26	2019-07-08 17:08:52	8	0	\N	\N
400546	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Nouveaux territoires de l'éducation	MI Nouveaux territoires de l'éducation	2019-07-09 14:00:00	2019-07-09 16:15:00	\N	\N	2	0	\N	\N
400549	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Nouveaux territoires de l'éducation	MI Nouveaux territoires de l'éducation	2019-07-09 17:45:00	2019-07-09 19:30:00	\N	\N	2	0	\N	\N
400609	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Économie circulaire - Auditions Mme de CIDRAC	\N	2019-07-11 17:00:00	2019-07-11 18:45:00	\N	\N	2	0	\N	\N
400612	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Économie circulaire - Auditions Mme de CIDRAC	\N	2019-07-11 18:45:00	2019-07-11 19:25:00	\N	\N	1	0	\N	\N
400623	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Économie circulaire - Auditions Mme de CIDRAC	\N	2019-07-11 10:00:00	2019-07-11 11:00:00	\N	\N	5	0	\N	\N
400629	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Économie circulaire - Auditions Mme de CIDRAC	\N	2019-07-11 11:15:00	2019-07-11 11:45:00	\N	\N	4	0	\N	\N
400634	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Économie circulaire - Auditions Mme de CIDRAC	\N	2019-07-11 11:45:00	2019-07-11 12:15:00	\N	\N	3	0	\N	\N
400706	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	\N	\N	2019-07-10 17:00:00	2019-07-10 19:00:00	\N	\N	0	0	\N	\N
400707	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	Réunion du mercredi 10 juillet	\N	2019-07-10 17:00:00	2019-07-10 19:00:00	\N	\N	0	0	\N	\N
400807	COM_PERMANENTE	DEPLACEMENT	\N	SOCI	\N	MI santé au travail Mme Gruny M. Artano	MI santé au travail Mme Gruny M. Artano Déplacement dans les Hauts-de-France	2019-07-11 08:45:00	2019-07-11 19:45:00	\N	\N	2	0	\N	\N
401307	MISSION	AUTRE	\N	AERIEN	\N	Réunion plénière	\N	2019-07-16 16:33:00	2019-07-16 18:00:00	2019-07-16 18:04:25	2019-07-17 12:33:40	7	0	\N	\N
404733	GIA	AUCUNE	\N	\N	\N	Accueil délégation du Bundesrat du 4 au 5 juillet-Echanges de vues du 5juillet 2019	Accueil délégation du Bundesrat du 4 au 5 juillet-Echanges de vues du 5 juillet 2019	2019-07-05 09:30:00	2019-07-05 12:00:00	\N	\N	3	0	604	\N
404797	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Économie circulaire - Auditions Mme LOISIER	PJL Économie circulaire	2019-09-02 14:35:00	2019-09-02 15:40:00	\N	\N	1	0	\N	\N
404799	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Économie circulaire - Auditions Mme LOISIER	PJL Économie circulaire	2019-09-02 15:40:00	2019-09-02 16:30:00	\N	\N	1	0	\N	\N
404801	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Économie circulaire - Auditions Mme LOISIER	PJL Économie circulaire	2019-09-02 16:30:00	2019-09-02 17:15:00	\N	\N	1	0	\N	\N
404803	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Économie circulaire - Auditions Mme LOISIER	PJL Économie circulaire	2019-09-02 17:15:00	2019-09-02 17:45:00	\N	\N	1	0	\N	\N
404805	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Économie circulaire - Auditions Mme LOISIER	PJL Économie circulaire	2019-09-03 09:30:00	2019-09-03 10:20:00	\N	\N	1	0	\N	\N
404806	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Économie circulaire - Auditions Mme LOISIER	PJL Économie circulaire	2019-09-03 10:20:00	2019-09-03 11:10:00	\N	\N	1	0	\N	\N
404807	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Économie circulaire - Auditions Mme LOISIER	\N	2019-09-03 11:10:00	2019-09-03 11:50:00	\N	\N	1	0	\N	\N
404808	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Économie circulaire - Auditions Mme LOISIER	PJL Économie circulaire	2019-09-03 11:50:00	2019-09-03 13:15:00	\N	\N	1	0	\N	\N
404809	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Économie circulaire - Auditions Mme LOISIER	PJL Économie circulaire	2019-09-03 14:40:00	2019-09-03 15:20:00	\N	\N	1	0	\N	\N
404810	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Économie circulaire - Auditions Mme LOISIER	PJL Économie circulaire	2019-09-03 15:20:00	2019-09-03 15:50:00	\N	\N	1	0	\N	\N
404811	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Économie circulaire - Auditions Mme LOISIER	PJL Économie circulaire	2019-09-03 15:55:00	2019-09-03 16:30:00	\N	\N	1	0	\N	\N
404819	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Économie circulaire - Auditions Mme de CIDRAC	PJL Économie circulaire	2019-09-03 09:30:00	2019-09-03 10:00:00	\N	\N	1	0	\N	\N
404820	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Économie circulaire - Auditions Mme de CIDRAC	PJL Économie circulaire	2019-09-03 10:00:00	2019-09-03 10:30:00	\N	\N	1	0	\N	\N
404821	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Économie circulaire - Auditions Mme de CIDRAC	PJL Économie circulaire	2019-09-03 10:30:00	2019-09-03 11:00:00	\N	\N	1	0	\N	\N
404822	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Économie circulaire - Auditions Mme de CIDRAC	PJL Économie circulaire	2019-09-03 11:15:00	2019-09-03 11:45:00	\N	\N	1	0	\N	\N
404823	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Économie circulaire - Auditions Mme de CIDRAC	PJL Économie circulaire	2019-09-03 11:45:00	2019-09-03 12:15:00	\N	\N	2	0	\N	\N
404824	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Économie circulaire - Auditions Mme de CIDRAC	PJL Économie circulaire	2019-09-03 12:15:00	2019-09-03 12:45:00	\N	\N	2	0	\N	\N
404825	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Économie circulaire - Auditions Mme de CIDRAC	PJL Économie circulaire	2019-09-03 14:30:00	2019-09-03 15:00:00	\N	\N	3	0	\N	\N
404826	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Économie circulaire - Auditions Mme de CIDRAC	PJL Économie circulaire	2019-09-03 15:00:00	2019-09-03 15:30:00	\N	\N	3	0	\N	\N
404827	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Économie circulaire - Auditions Mme de CIDRAC	PJL Économie circulaire	2019-09-03 15:30:00	2019-09-03 16:00:00	\N	\N	3	0	\N	\N
404828	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Économie circulaire - Auditions Mme de CIDRAC	PJL Économie circulaire	2019-09-03 16:00:00	2019-09-03 16:30:00	\N	\N	3	0	\N	\N
404871	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Engagement et proximité - Audition de Mme Jacqueline Gourault et M. Sébastien Lecornu	PJL Engagement et proximité - Audition de Mme Jacqueline Gourault et M. Sébastien Lecornu	2019-09-25 15:05:00	2019-09-25 17:45:00	2019-09-25 18:11:12	2019-09-26 16:34:40	21	0	\N	\N
405188	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PJL Énergie climat	CMP PJL Énergie climat	2019-09-26 11:00:00	2019-09-26 12:25:00	\N	\N	58	0	\N	\N
405190	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Économie circulaire	PJL Économie circulaire	2019-09-26 15:05:00	2019-09-26 19:55:00	\N	\N	96	0	\N	\N
406861	ETUDES	AUCUNE	\N	\N	\N	Audition	Audition	2019-09-25 08:00:00	2019-09-25 09:15:00	\N	\N	11	0	\N	909
465465	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi urgence Covid-19 - Prisons et autres lieux privatifs de liberté	\N	2020-04-20 16:30:00	2020-04-20 17:20:00	\N	\N	3	0	\N	\N
465527	DELEGATION	AUCUNE	\N	\N	211	Audition de M. Alain Legrand, président de la FNACAV	\N	2020-04-20 17:00:00	2020-04-20 18:35:00	\N	\N	11	0	\N	\N
465629	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFR 2020	PLFR 2020	2020-04-22 09:31:00	2020-04-22 13:24:00	\N	\N	52	0	\N	\N
465630	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFR 2020	PLFR 2020	2020-04-22 16:31:00	2020-04-22 19:58:00	\N	\N	53	0	\N	\N
465631	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFR 2020	PLFR 2020	2020-04-22 21:33:00	2020-04-23 03:06:00	\N	\N	44	0	\N	\N
502343	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2021	PLF pour 2021	2020-12-01 14:35:00	2020-12-01 19:45:00	\N	\N	186	0	\N	\N
465632	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi urgence Covid-19 - Juridictions judiciaires et administratives	Audition de la Conférence nationale des présidents de tribunaux de grande instance	2020-04-21 09:30:00	2020-04-21 10:30:00	\N	\N	8	0	\N	\N
465772	DELEGATION	AUDRAP	\N	\N	206	Audition de l'Institut de chimie de Clermont-Ferrand (ICCF) - SIGMA Clermont	\N	2020-04-20 10:00:00	2020-04-20 12:20:00	\N	\N	2	0	\N	\N
465775	DELEGATION	AUDRAP	\N	\N	206	Audition du Club Bio-plastiques	\N	2020-04-20 15:00:00	2020-04-20 16:00:00	\N	\N	2	0	\N	\N
465777	DELEGATION	AUDRAP	\N	\N	206	Audition du Laboratoire Géosciences Rennes (UMR6118 CNRS/Université de Rennes1)	\N	2020-04-21 10:00:00	2020-04-21 11:15:00	\N	\N	2	0	\N	\N
465778	DELEGATION	AUDRAP	\N	\N	206	Bernard JÉGOU, directeur de la recherche - École des hautes études en santé publique	\N	2020-04-21 11:15:00	2020-04-21 12:25:00	\N	\N	2	0	\N	\N
465963	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission (visioconférence)	Réunion de commission (visioconférence)	2020-04-22 09:00:00	2020-04-22 10:50:00	\N	\N	29	0	\N	\N
466045	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-05-05 08:30:00	2020-05-05 10:15:00	\N	\N	35	0	\N	\N
466046	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-04-28 14:30:00	2020-04-28 16:05:00	\N	\N	33	0	\N	\N
466047	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-04-29 09:30:00	2020-04-29 11:40:00	\N	\N	34	0	\N	\N
466107	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi urgence Covid-19 - Juridictions judiciaires et administratives	Audition de la Conférence générale des juges consulaires de France	2020-04-22 16:30:00	2020-04-22 17:30:00	\N	\N	2	0	\N	\N
466111	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Groupe de travail Décentralisation	Audition de Régions de France	2020-04-22 17:00:00	2020-04-22 18:00:00	\N	\N	4	0	\N	\N
466138	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi Covid-19 - Administration, collectivités, fonction publique	\N	2020-04-15 14:00:00	2020-04-15 15:00:00	\N	\N	4	0	\N	\N
466143	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi Covid-19 - Administration, collectivités, fonction publique	\N	2020-04-15 17:00:00	2020-04-15 18:30:00	\N	\N	3	0	\N	\N
466147	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi Covid-19 - Administration, collectivités, fonction publique	\N	2020-04-16 09:00:00	2020-04-16 10:00:00	\N	\N	3	0	\N	\N
466151	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi Covid-19 - Administration, collectivités, fonction publique	\N	2020-04-20 09:00:00	2020-04-20 10:00:00	\N	\N	7	0	\N	\N
466159	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi Covid-19 - Administration, collectivités, fonction publique	\N	2020-04-20 10:00:00	2020-04-20 11:00:00	\N	\N	4	0	\N	\N
466164	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi Covid-19 - Administration, collectivités, fonction publique	\N	2020-04-21 14:00:00	2020-04-21 15:00:00	\N	\N	3	0	\N	\N
466168	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi Covid-19 - Administration, collectivités, fonction publique	\N	2020-04-21 15:00:00	2020-04-21 16:00:00	\N	\N	5	0	\N	\N
466174	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi Covid-19 - Administration, collectivités, fonction publique	\N	2020-04-21 16:00:00	2020-04-21 17:00:00	\N	\N	3	0	\N	\N
466178	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi Covid-19 - Administration, collectivités, fonction publique	\N	2020-04-22 14:00:00	2020-04-22 15:00:00	\N	\N	4	0	\N	\N
466639	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFR pour 2020 (2) "Écologie" - Suivi mesures crise covid-19 - DGTIM	PLFR pour 2020 (2) "Écologie" - Suivi mesures crise covid-19 - DGTIM	2020-04-24 14:30:00	2020-04-24 15:30:00	\N	\N	1	0	\N	\N
466641	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	GT Covid19 Médias	Audition France Télévisions	2020-04-30 15:00:00	2020-04-30 16:30:00	\N	\N	5	0	\N	\N
466642	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	GT Covid 19 Sport	Cabinet ministère Sports	2020-04-30 10:00:00	2020-04-30 11:30:00	\N	\N	6	0	\N	\N
466678	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi urgence Covid-19 - Prisons et autres lieux privatifs de liberté	Audition CPIP	2020-04-24 15:00:00	2020-04-24 16:00:00	\N	\N	2	0	\N	\N
466727	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	GT Covid19 Enseignement scolaire	\N	2020-04-16 08:30:00	2020-04-16 09:30:00	\N	\N	3	0	\N	\N
466731	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid19 Enseignement scolaire	\N	2020-04-17 09:00:00	2020-04-17 10:00:00	\N	\N	6	0	\N	\N
466738	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid19 Enseignement scolaire	\N	2020-04-17 11:00:00	2020-04-17 12:00:00	\N	\N	6	0	\N	\N
466745	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid19 Enseignement scolaire	\N	2020-04-17 14:00:00	2020-04-17 15:00:00	\N	\N	7	0	\N	\N
466753	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid19 Enseignement scolaire	\N	2020-04-17 15:30:00	2020-04-17 16:30:00	\N	\N	6	0	\N	\N
466760	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid19 Enseignement scolaire	\N	2020-04-17 16:30:00	2020-04-17 17:30:00	\N	\N	5	0	\N	\N
466766	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid19 Enseignement scolaire	\N	2020-04-20 09:00:00	2020-04-20 10:15:00	\N	\N	7	0	\N	\N
466774	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid19 Enseignement scolaire	\N	2020-04-20 15:30:00	2020-04-20 16:30:00	\N	\N	8	0	\N	\N
466783	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid19 Enseignement scolaire	\N	2020-04-20 16:30:00	2020-04-20 17:20:00	\N	\N	6	0	\N	\N
466790	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid19 Enseignement scolaire	\N	2020-04-21 09:00:00	2020-04-21 10:15:00	\N	\N	7	0	\N	\N
466798	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid19 Enseignement scolaire	\N	2020-04-21 14:00:00	2020-04-21 15:00:00	\N	\N	1	0	\N	\N
466800	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid19 Enseignement scolaire	\N	2020-04-22 11:00:00	2020-04-22 12:00:00	\N	\N	8	0	\N	\N
466809	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid19 Enseignement agricole	Audition Snetap-FSU	2020-04-27 17:00:00	2020-04-27 18:15:00	\N	\N	7	0	\N	\N
467269	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2020-05-20 15:00:00	2020-05-20 16:00:00	\N	\N	60	0	\N	\N
467270	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2020-05-26 09:30:00	2020-05-26 12:40:00	\N	\N	38	0	\N	\N
467271	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat perspectives de la saison estivale	Débat perspectives de la saison estivale	2020-05-19 14:30:00	2020-05-19 16:30:00	\N	\N	39	0	\N	\N
467272	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Français établis hors de France	PPL Français établis hors de France	2020-05-19 17:55:00	2020-05-19 20:40:00	\N	\N	42	0	\N	\N
467273	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2020-05-27 15:00:00	2020-05-27 15:50:00	\N	\N	80	0	\N	\N
467274	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Covid-19 et numérique	Débat Covid-19 et numérique	2020-05-27 16:15:00	2020-05-27 17:50:00	\N	\N	43	0	\N	\N
467275	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL cadre stable d'épanouissement mineurs vulnérables	PPL cadre stable d'épanouissement et de développement aux mineurs vulnérables	2020-05-28 09:00:00	2020-05-28 12:20:00	\N	\N	43	0	\N	\N
413758	ETUDES	AUDRAP	\N	\N	\N	GEAC - Audition SAFRAN	GEAC - Audition SAFRAN	2019-10-10 08:30:00	2019-10-10 10:00:00	\N	\N	4	0	\N	933
467277	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL plafonnement frais bancaires,	PPL Rendre effectif et à renforcer le plafonnement des frais bancaires,	2020-05-28 14:30:00	2020-05-28 17:05:00	\N	\N	40	0	\N	\N
467278	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2020-05-13 15:00:00	2020-05-13 15:50:00	\N	\N	50	0	\N	\N
467283	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid19 Enseignement agricole	Audition Maisons Familiales rurales	2020-04-29 14:00:00	2020-04-29 15:00:00	\N	\N	7	0	\N	\N
467291	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid 19 Jeunesse et Vie associative	Audition Unis-Cité	2020-04-28 09:30:00	2020-04-28 10:30:00	\N	\N	3	0	\N	\N
378391	DELEGATION	AUCUNE	\N	\N	COLTER	Audition d'experts "Collectivités, leviers de développement pour les territoires ruraux ?"	\N	2019-05-23 09:00:00	2019-05-23 11:00:00	2019-05-23 14:36:40	\N	9	0	\N	\N
385053	MISSION	AUTRE	\N	FONDS	\N	Réunion du bureau de la mission	\N	2019-06-04 14:05:00	2019-06-04 14:35:00	2019-06-04 15:02:04	\N	6	0	\N	\N
385066	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Energie - Auditions M. Gremillet	\N	2019-05-29 14:15:00	2019-05-29 17:05:00	\N	\N	1	0	\N	\N
385077	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 6 juin 2019	Réunion du 6 juin 2019	2019-06-06 08:35:00	2019-06-06 09:30:00	2019-06-07 11:02:45	2019-06-07 11:16:48	16	0	\N	\N
385081	DELEGATION	AUCUNE	\N	\N	PROS	Réunion plénière	Audition de M. Olivier Darrason	2019-06-20 08:30:00	2019-06-20 09:40:00	\N	\N	7	0	\N	\N
385092	MISSION	AUTRE	\N	FONDS	\N	Auditions	\N	2019-06-11 17:50:00	2019-06-11 18:50:00	2019-06-11 19:02:44	2019-06-12 16:58:39	10	0	\N	\N
385093	MISSION	AUTRE	\N	FONDS	\N	Audition	\N	2019-06-12 16:10:00	2019-06-12 17:15:00	2019-06-12 17:40:57	2019-06-13 15:38:27	7	0	\N	\N
385336	MISSION	AUDRAP	\N	CLIMATIQUE	\N	Audition de MM. Bruno DEPRESLE (CGEDD) et Jean-Pierre MENANTEAU (IGF)	Audition de MM. Bruno DEPRESLE (CGEDD) et Jean-Pierre MENANTEAU (IGF)	2019-06-04 08:15:00	2019-06-04 09:20:00	\N	\N	1	0	\N	\N
386949	ETUDES	AUCUNE	\N	\N	\N	Audition de M. Jean Marc FRON, directeur général de Boeing France	Audition de M. Jean Marc FRON, directeur général de Boeing France	2019-06-06 08:30:00	2019-06-06 10:00:00	\N	\N	8	0	\N	933
387465	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Évaluation transformation ISF en IFI et création PFU - INSEE/Associations	Contrôle 2019 - Évaluation transformation ISF en IFI et création PFU - INSEE / Associations	2019-06-05 10:30:00	2019-06-05 13:00:00	\N	\N	2	0	\N	\N
396518	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-07-03 09:30:00	2019-07-03 12:20:00	2019-07-03 15:43:21	2019-07-03 15:56:32	33	0	\N	\N
404893	MISSION	AUCUNE	\N	FONDS	\N	Réunion du mardi 23 juillet 2019	\N	2019-07-23 14:00:00	2019-07-23 15:10:00	2019-09-05 17:57:06	\N	5	0	\N	\N
405683	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Nouveaux territoires du sport	MI Nouveaux territoires du sport	2019-09-24 14:30:00	2019-09-24 15:30:00	\N	\N	2	0	\N	\N
405686	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Nouveaux territoires du sport	MI Nouveaux territoires du sport	2019-09-24 15:30:00	2019-09-24 16:30:00	\N	\N	3	0	\N	\N
414386	ETUDES	AUTRE	\N	\N	\N	Audition de Mme Geneviève Darrieussecq, secrétaire d'État auprès de la ministre des armées	\N	2019-10-23 16:30:00	2019-10-23 18:00:00	\N	\N	12	0	\N	928
414419	DELEGATION	AUCUNE	\N	\N	PROS	Examen du rapport de Pierre-Yves Collombat, actualisant son rapport n° 393 (2016-2017)	Examen du rapport de Pierre-Yves Collombat, actualisant son rapport n° 393 (2016-2017)	2019-11-14 08:35:00	2019-11-14 09:35:00	\N	\N	10	0	\N	\N
414444	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-10-16 09:35:00	2019-10-16 11:20:00	2019-10-16 11:38:51	2019-10-16 17:31:07	32	0	\N	\N
416482	COM_ENQUETE	PLENIERE	\N	LUBRIZOL	\N	Réunion constitutive	\N	2019-10-17 10:30:00	2019-10-17 11:05:00	2019-10-17 12:24:44	2019-10-17 15:57:02	14	0	\N	\N
416543	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-10-23 09:00:00	2019-10-23 12:30:00	2019-10-23 15:03:52	2019-10-23 16:36:03	38	0	\N	\N
417146	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Presse	PLF 2020 - Crédits Presse	2019-10-15 09:00:00	2019-10-15 11:00:00	\N	\N	1	0	\N	\N
417148	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Sport	PLF 2020 - Crédits Sport	2019-10-15 14:30:00	2019-10-15 16:30:00	\N	\N	1	0	\N	\N
417150	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Sport	PLF 2020 - Crédits Sport	2019-10-16 14:00:00	2019-10-16 15:00:00	\N	\N	1	0	\N	\N
417152	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Sport	PLF 2020 - Crédits Sport	2019-10-16 16:30:00	2019-10-16 17:30:00	\N	\N	1	0	\N	\N
417154	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Recherche	PLF 2020 - Crédits Recherche	2019-10-15 17:15:00	2019-10-15 18:00:00	\N	\N	2	0	\N	\N
419343	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2020 - avis AGTE	\N	2019-10-24 09:00:00	2019-10-24 09:45:00	\N	\N	1	0	\N	\N
419803	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Travailleurs indépendants	\N	2019-10-23 14:00:00	2019-10-23 15:00:00	\N	\N	3	0	\N	\N
419925	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-10-29 14:00:00	2019-10-29 16:00:00	\N	\N	0	0	\N	\N
439869	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2019-12-11 19:30:00	2019-12-11 20:05:00	\N	\N	20	0	\N	\N
454724	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Système universel de retraite	\N	2020-02-18 15:15:00	2020-02-18 16:00:00	\N	\N	2	0	\N	\N
454727	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Système universel de retraite	\N	2020-02-18 16:00:00	2020-02-18 17:00:00	\N	\N	5	0	\N	\N
454733	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Système universel de retraite	\N	2020-02-18 17:00:00	2020-02-18 17:45:00	\N	\N	5	0	\N	\N
459223	COM_ENQUETE	AUDRAP	\N	AUTOROUT	\N	CE concessions autoroutières - Anticor	CE concessions autoroutières - Anticor	2020-03-05 11:00:00	2020-03-05 12:00:00	\N	\N	4	0	\N	\N
459235	COM_SPECIALE	AUTRE	\N	ASAP	\N	Réunion de commission ASAP	\N	2020-03-03 12:00:00	2020-03-03 13:30:00	\N	\N	0	0	\N	\N
459241	COM_EURO	AUDRAP	\N	AFEU	\N	Audition - Migration et asile	Suivi de la situation en Grèce	2020-02-26 09:35:00	2020-02-26 10:35:00	\N	\N	1	0	\N	\N
459243	COM_EURO	AUDRAP	\N	AFEU	\N	Audition - G.Apostolou	\N	2020-02-26 11:45:00	2020-02-26 12:35:00	\N	\N	1	0	\N	\N
463387	SEANCE_PLENIERE	DEBAT	\N	\N	\N	PLFR	PLFR	2020-03-20 14:36:00	2020-03-20 21:09:00	\N	\N	42	0	\N	\N
464074	DELEGATION	AUCUNE	\N	\N	206	Épidémie de Covid-19 : Point sur les technologies de l'information	\N	2020-04-09 09:30:00	2020-04-09 11:30:00	\N	\N	22	0	\N	\N
464097	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition par visioconférence de M. Jean-Baptiste Lemoyne	\N	2020-04-09 11:00:00	2020-04-09 12:40:00	2020-04-09 19:35:53	\N	35	0	\N	\N
465107	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de M. Christophe Castaner par visioconférence	\N	2020-04-16 15:00:00	2020-04-16 17:48:00	\N	\N	37	0	\N	\N
478250	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Porte-avions	\N	2020-06-16 15:00:00	2020-06-16 16:00:00	\N	\N	2	0	\N	\N
465145	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition de M. Franck Riester (Visioconférence)	Audition de M. Franck Riester (Visioconférence)	2020-04-16 15:20:00	2020-04-16 18:00:00	\N	\N	32	0	\N	\N
465176	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2020-04-07 14:35:00	2020-04-07 17:15:00	\N	\N	3	0	\N	\N
465182	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audition de la FAPEE sur l'enseignement français à l'étranger	\N	2020-04-16 15:00:00	2020-04-16 16:15:00	\N	\N	4	0	\N	\N
465187	DELEGATION	AUCUNE	\N	\N	COLTER	Réunion du Bureau de la délégation	\N	2020-04-15 09:30:00	2020-04-15 10:30:00	\N	\N	11	0	\N	\N
465200	DELEGATION	AUCUNE	\N	\N	COLTER	Table ronde « Les collectivités territoriales face à l¿épidémie de Covid-19 »	\N	2020-04-16 14:00:00	2020-04-16 16:00:00	\N	\N	29	0	\N	\N
465232	DELEGATION	AUCUNE	\N	\N	211	Audition de M. Adrien Taquet, secrétaire d'État chargé de la protection de l'enfance	\N	2020-04-16 11:00:00	2020-04-16 13:15:00	\N	\N	21	0	\N	\N
465257	DELEGATION	AUCUNE	\N	\N	DSOM	Audition de M. Jean-Pierre Philibert	\N	2020-04-16 14:00:00	2020-04-16 16:00:00	\N	\N	13	0	\N	\N
465274	DELEGATION	AUCUNE	\N	\N	DSOM	Auditions Urgence économique dans les outre-mer	\N	2020-04-23 14:00:00	2020-04-23 15:55:00	\N	\N	16	0	\N	\N
466116	DELEGATION	AUCUNE	\N	\N	PROS	Audition de M. Rudy Reichstadt	\N	2020-04-23 09:30:00	2020-04-23 10:25:00	\N	\N	13	0	\N	\N
466136	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2020-04-28 15:00:00	2020-04-28 17:00:00	\N	\N	12	0	\N	\N
466137	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2020-04-29 08:30:00	2020-04-29 12:10:00	\N	\N	35	0	\N	\N
466221	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition par visioconférence du chef d'état-major des armées	\N	2020-04-23 15:00:00	2020-04-23 17:00:00	\N	\N	40	0	\N	\N
466320	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2020-04-22 09:00:00	2020-04-22 12:00:00	\N	\N	34	0	\N	\N
466321	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion Plénière CATDD	\N	2020-04-22 16:00:00	2020-04-22 18:00:00	\N	\N	32	0	\N	\N
466389	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de Yann-Gaël Amghar, directeur de l'Acoss (téléconférence)	\N	2020-04-29 10:00:00	2020-04-29 12:00:00	\N	\N	34	0	\N	\N
466401	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de MM. Delfraissy et Fontanet, du Comité scientifique Covid-19 (téléconférence)	\N	2020-04-30 10:30:00	2020-04-30 12:30:00	2020-05-12 16:30:20	\N	41	0	\N	\N
469242	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Enjeux sanitaires - Audition Pr RAOULT (Mme Deroche)	\N	2020-05-07 11:00:00	2020-05-07 12:00:00	\N	\N	28	0	\N	\N
469264	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Enjeux sanitaires - Audition FHF (Mme Deroche)	\N	2020-05-11 15:45:00	2020-05-11 17:00:00	\N	\N	7	0	\N	\N
469282	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Enjeux sanitaires - Audition FHP (Mme Deroche)	\N	2020-05-11 17:15:00	2020-05-11 18:30:00	\N	\N	8	0	\N	\N
469303	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Enjeux sanitaires - Audition FEHAP (Mme Deroche)	\N	2020-05-12 14:30:00	2020-05-12 15:30:00	\N	\N	7	0	\N	\N
469310	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Enjeux sanitaires - Audition MG France / CSMF (Mme Deroche)	\N	2020-05-12 15:45:00	2020-05-12 16:45:00	\N	\N	8	0	\N	\N
469311	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Enjeux sanitaires - Audition SPS (Mme Deroche)	\N	2020-05-12 17:00:00	2020-05-12 18:00:00	\N	\N	6	0	\N	\N
469312	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Enjeux sanitaires - Audition ONCD (Mme Deroche)	\N	2020-05-14 13:45:00	2020-05-14 14:45:00	\N	\N	6	0	\N	\N
469355	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - ICCF	Audition Pollution plastique - Institut de chimie de Clermont-Ferrand (ICCF)	2020-05-14 14:30:00	2020-05-14 16:30:00	\N	\N	2	0	\N	\N
469358	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - Reporters du Large SAS	Audition Pollution plastique - Reporters du Large SAS	2020-05-14 16:45:00	2020-05-14 18:10:00	\N	\N	2	0	\N	\N
469366	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Enjeux sanitaires - Audition INDUSTRIES TEXTILES (Mme Deroche)	\N	2020-04-28 16:15:00	2020-04-28 17:15:00	\N	\N	3	0	\N	\N
469367	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Enjeux sanitaires - Audition FMF (Mme Deroche)	\N	2020-04-28 17:30:00	2020-04-28 18:30:00	\N	\N	8	0	\N	\N
469379	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Enjeux sanitaires - Audition CNOMK (Mme Deroche)	\N	2020-04-16 14:30:00	2020-04-16 15:30:00	\N	\N	3	0	\N	\N
469381	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Enjeux sanitaires - Audition ANSM (Mme Deroche)	\N	2020-04-16 17:00:00	2020-04-16 18:00:00	\N	\N	4	0	\N	\N
469491	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi urgence Covid-19 - Prisons et autres lieux privatifs de liberté	Audition commune de la DGEF et de la DCPAF	2020-05-12 14:30:00	2020-05-12 15:35:00	\N	\N	5	0	\N	\N
469505	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi urgence Covid-19 - Prisons et autres lieux privatifs de liberté	Audition commune de l'Ofpra et de l'OFII	2020-05-12 15:35:00	2020-05-12 16:40:00	\N	\N	3	0	\N	\N
469588	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Suivi urgence Covid-19 - Prisons et autres lieux privatifs de liberté	Centre pénitentiaire de Fresnes	2020-05-12 09:20:00	2020-05-12 12:55:00	\N	\N	2	0	\N	\N
469648	DELEGATION	AUDRAP	\N	\N	206	Entretien avec M. Jean-Claude Desenclos, directeur scientifique de Santé publique France	Entretien avec M. Jean-Claude Desenclos, directeur scientifique de Santé publique France	2020-05-12 15:00:00	2020-05-12 16:00:00	\N	\N	2	0	\N	\N
469649	DELEGATION	AUDRAP	\N	\N	206	Entretien avec M. Ali Nouri, président de la Federation of American Scientists	Entretien avec M. Ali Nouri, président de la Federation of American Scientists	2020-05-12 16:00:00	2020-05-12 17:00:00	\N	\N	1	0	\N	\N
470374	DELEGATION	AUDRAP	\N	\N	206	Entretien avec M. Peter Gluckman, ancien chef scientifique de Nouvelle-Zélande	Entretien avec M. Peter Gluckman, ancien chef scientifique de Nouvelle-Zélande	2020-05-14 08:00:00	2020-05-14 09:30:00	\N	\N	9	0	\N	\N
470489	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 14 mai 2020	Réunion du 14 mai 2020	2020-05-14 10:05:00	2020-05-14 12:25:00	2020-05-14 17:23:34	2020-05-14 17:33:58	22	0	\N	\N
470506	DELEGATION	AUCUNE	\N	\N	COLTER	Audition J.R. Cazeneuve, Délégation collectivités Assemblée nationale	\N	2020-05-20 16:30:00	2020-05-20 18:00:00	2020-05-20 18:18:13	\N	20	0	\N	\N
470573	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi urgence Covid-19 - Forces de sécurité intérieure	Table ronde des fédérations syndicales représentatives de la police nationale	2020-05-14 14:30:00	2020-05-14 16:15:00	\N	\N	4	0	\N	\N
470595	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid 19 Sport	Audition SPL	2020-05-13 09:30:00	2020-05-13 11:20:00	\N	\N	6	0	\N	\N
470602	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid 19 Recherche	Audition INSERM	2020-05-12 15:00:00	2020-05-12 17:00:00	\N	\N	3	0	\N	\N
470606	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid19 Médias	Audition Radio France	2020-05-14 16:30:00	2020-05-14 18:10:00	\N	\N	5	0	\N	\N
470888	MISSION	AUCUNE	\N	ILLECTRONISM	\N	Audition de M. Jacques Toubon, Défenseur des droits	Audition de M. Jacques Toubon, Défenseur des droits	2020-05-25 15:30:00	2020-05-25 17:20:00	2020-05-25 18:25:10	2020-05-26 14:16:50	13	0	\N	\N
470889	MISSION	AUDRAP	\N	ILLECTRONISM	\N	Audition de M. Jean-Marc MERRIAUX Directeur du numérique pour l'éducation	Audition de M. Jean-Marc MERRIAUX Directeur du numérique pour l¿éducation	2020-05-26 15:00:00	2020-05-26 16:00:00	\N	\N	6	0	\N	\N
470890	MISSION	AUCUNE	\N	ILLECTRONISM	\N	Audition de l'Assemblée des communautés de France	Audition de l'Assemblée des communautés de France (AdCF)	2020-05-28 16:00:00	2020-05-28 17:40:00	2020-05-29 10:19:41	2020-05-29 11:48:20	7	0	\N	\N
470975	MISSION	AUDRAP	\N	ILLECTRONISM	\N	Audition DGESCO et DGRH, éducation nationale	Jean HUBAC - DGESCO,  Lionel FERREIRA et Isabelle TALAZAC - DGRH	2020-05-26 16:00:00	2020-05-26 17:00:00	\N	\N	4	0	\N	\N
470978	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid19 Médias	Audition Canal+	2020-05-19 15:30:00	2020-05-19 17:00:00	\N	\N	0	0	\N	\N
470979	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid19 Médias	Audition Newen	2020-05-19 17:00:00	2020-05-19 18:20:00	\N	\N	2	0	\N	\N
470980	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid19 Médias	Audition FMM	2020-05-20 15:00:00	2020-05-20 16:16:00	\N	\N	4	0	\N	\N
470981	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid19 Médias	Audition SIRTI	2020-05-28 15:00:00	2020-05-28 16:30:00	\N	\N	1	0	\N	\N
470982	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid19 Médias	Audition Locales TV	2020-05-28 16:30:00	2020-05-28 17:30:00	\N	\N	1	0	\N	\N
470983	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid 19 Sport	Audition ANDIIS	2020-05-20 09:00:00	2020-05-20 10:30:00	\N	\N	6	0	\N	\N
470984	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid 19 Sport	Audition CosMos	2020-05-25 14:30:00	2020-05-25 15:30:00	\N	\N	6	0	\N	\N
470987	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid 19 Patrimoine	Audition ANABF	2020-05-18 14:00:00	2020-05-18 15:00:00	\N	\N	3	0	\N	\N
470988	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid 19 Patrimoine	Audition CMN	2020-05-18 16:00:00	2020-05-18 17:00:00	\N	\N	4	0	\N	\N
470989	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid 19 Patrimoine	Audition GMH	2020-05-18 17:00:00	2020-05-18 18:00:00	\N	\N	3	0	\N	\N
471364	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - Université de Montpellier	Audition Pollution plastique - Université de Montpellier	2020-05-19 09:00:00	2020-05-19 11:15:00	\N	\N	2	0	\N	\N
471902	DELEGATION	AUDRAP	\N	\N	206	Audition Production de l'énergie dans le secteur agricole	Audition Production de l'énergie dans le secteur agricole - Ademe	2020-05-18 11:00:00	2020-05-18 12:45:00	\N	\N	1	0	\N	\N
471905	DELEGATION	AUDRAP	\N	\N	206	Audition Production de l'énergie dans le secteur agricole	Audition Production de l'énergie dans le secteur agricole - LITEN CEAA de Grenoble	2020-05-19 16:45:00	2020-05-19 18:45:00	\N	\N	1	0	\N	\N
472071	DELEGATION	AUCUNE	\N	\N	211	Réunion du Bureau de la délégation	\N	2020-05-27 13:45:00	2020-05-27 14:55:00	2020-05-27 15:10:33	\N	9	0	\N	\N
472073	MISSION	AUCUNE	\N	GUYANE	\N	Audition de M. Marc Del Grande	\N	2020-05-25 18:00:00	2020-05-25 19:10:00	2020-05-25 19:14:16	2020-05-26 14:16:51	11	0	\N	\N
472075	MISSION	AUCUNE	\N	GUYANE	\N	Audition de Nicolas Prisse	\N	2020-05-28 14:30:00	2020-05-28 15:30:00	2020-05-28 16:07:47	2020-05-28 18:13:55	13	0	\N	\N
472082	COM_PERMANENTE	AUTRE	\N	FINC	\N	PPL 440 diverses dispositions COVID 19 - Examen amendements séance	PPL 440 diverses dispositions COVID 19 - Examen amendements séance	2020-05-26 14:10:00	2020-05-26 14:30:00	2020-05-26 23:37:16	2020-05-27 17:08:58	20	0	\N	\N
472083	DELEGATION	AUDRAP	\N	\N	211	Audition de Mme Sylvie Pierre-Brossolette	\N	2020-06-02 14:30:00	2020-06-02 15:30:00	\N	\N	7	0	\N	\N
472085	DELEGATION	AUDRAP	\N	\N	211	Audition de Mme Agnès Saal	\N	2020-06-02 16:30:00	2020-06-02 17:30:00	\N	\N	8	0	\N	\N
472086	COM_PERMANENTE	AUTRE	\N	FINC	\N	PPL n°402 et PPL n°312-Examen Rapports et établissement textes - PPL n° 339-AMDTS Séance	PPL n°402 et PPL n°312-Examen Rapports et établissement textes - PPL n° 339-AMDTS Séance	2020-05-27 09:35:00	2020-05-27 11:30:00	2020-05-27 17:46:45	2020-05-28 14:39:10	25	0	\N	\N
472088	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule agriculture Club Déméter	Auditions cellule agriculture	2020-05-19 09:00:00	2020-05-19 10:00:00	\N	\N	7	0	\N	\N
472096	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule agriculture Lactalis	Auditions cellule agriculture	2020-05-20 08:00:00	2020-05-20 09:15:00	\N	\N	10	0	\N	\N
373922	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Nomination Parlement Européen, désignation  CMP PJL PJLP Polynésie, rapport Synergie.	Nomination Parlement Européen, désignation  CMP PJL PJLP Polynésie, rapport Synergie.	2019-04-30 09:30:00	2019-04-30 10:35:00	2019-04-30 10:59:08	2019-04-30 17:33:06	26	2	\N	\N
380301	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Suite du Déplacement d'une délégation du Bureau de la commission Mai 2019 - DG Trésor	Suite du Déplacement d'une délégation du Bureau de la commission des finances Mai 2019 - DG Trésor	2019-05-21 09:00:00	2019-05-21 10:15:00	\N	\N	4	0	\N	\N
381599	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-05-21 18:05:00	2019-05-21 20:05:00	2019-05-22 09:08:23	2019-05-22 17:38:18	28	0	\N	\N
391476	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	groupe de travail justice prud'homale	groupe de travail justice prud'homale	2019-06-18 10:00:00	2019-06-18 12:00:00	\N	\N	1	0	\N	\N
392118	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2019 - Masse salariale du MEAE - Déplacement Berlin	Contrôle 2019 - Masse salariale du MEAE - Déplacement Berlin	2019-06-17 09:20:00	2019-06-18 19:35:00	\N	\N	2	0	\N	\N
392136	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Solidarités - France Générosités	PLF pour 2020 - Solidarités - France Générosités	2019-06-18 09:30:00	2019-06-18 10:30:00	\N	\N	2	0	\N	\N
392169	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Prestation de compensation du handicap	\N	2019-06-19 17:45:00	2019-06-19 19:15:00	\N	\N	1	0	\N	\N
392177	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Energie - Auditions M. Gremillet	\N	2019-06-18 14:00:00	2019-06-18 18:00:00	\N	\N	2	0	\N	\N
392688	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2019-05-29 14:30:00	2019-05-29 17:10:00	\N	\N	3	0	\N	\N
397651	DELEGATION	AUCUNE	\N	\N	COLTER	Audition ministre S. Lecornu - Conditions exercice mandats locaux	\N	2019-07-11 08:30:00	2019-07-11 10:30:00	2019-07-11 15:00:02	\N	16	0	\N	\N
398365	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-07-08 18:10:00	2019-07-08 19:25:00	2019-07-08 19:33:23	2019-07-09 14:20:53	15	1	\N	\N
398366	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-07-09 09:40:00	2019-07-09 10:10:00	2019-07-09 10:29:33	2019-07-09 14:20:54	20	2	\N	\N
398367	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de la commission	Réunion de la commission	2019-07-09 14:05:00	2019-07-09 15:25:00	2019-07-09 15:40:11	2019-07-09 15:41:08	12	0	\N	\N
399900	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Espace - Audition de Mme Geneviève Fioraso	Espace - Audition de Mme Geneviève Fioraso	2019-07-09 17:45:00	2019-07-09 18:55:00	\N	\N	10	0	\N	\N
400709	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	Groupe de suivi PAC	Groupe de suivi PAC	2019-07-10 17:00:00	2019-07-10 19:00:00	\N	\N	8	0	\N	\N
401107	GIA	AUCUNE	\N	\N	\N	Réunion du groupe d'amitié dans la perspective de l'accueil d'une délégation du groupe d'a	Réunion du groupe d'amitié dans la perspective de l'accueil d'une délégation du groupe d'amitié Allemagne-France du Bund	2019-06-26 16:00:00	2019-06-26 17:00:00	\N	\N	16	0	604	\N
404566	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions PJL Économie circulaire	\N	2019-07-22 10:00:00	2019-07-22 12:30:00	\N	\N	1	0	\N	\N
404576	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Économie circulaire - Auditions Mme de Cidrac 	\N	2019-07-23 14:30:00	2019-07-23 15:00:00	\N	\N	3	0	\N	\N
404583	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Économie circulaire - Auditions Mme de Cidrac 	\N	2019-07-24 17:15:00	2019-07-24 17:45:00	\N	\N	2	0	\N	\N
409433	ETUDES	AUCUNE	\N	\N	\N	Audition CNPF	Audition CNPF	2019-10-02 08:00:00	2019-10-02 09:00:00	\N	\N	17	0	\N	948
413764	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Changement d'assurance emprunteur	Audition DG Trésor	2019-10-09 14:00:00	2019-10-09 15:00:00	\N	\N	4	0	\N	\N
413765	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Changement d'assurance emprunteur	Audition CCSF	2019-10-09 16:00:00	2019-10-09 17:00:00	\N	\N	2	0	\N	\N
413766	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Changement d'assurance emprunteur	Audition FBF	2019-10-10 09:00:00	2019-10-10 10:00:00	\N	\N	2	0	\N	\N
413767	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Changement d'assurance emprunteur	Audition DGCCRF	2019-10-10 10:00:00	2019-10-10 11:00:00	\N	\N	2	0	\N	\N
413768	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - EFE - Standard & Poor's	PLF pour 2020 - EFE - Standard & Poor's	2019-10-07 18:20:00	2019-10-07 19:35:00	\N	\N	1	0	\N	\N
413770	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Changement d'assurance emprunteur	Audition UFC Que choisir	2019-10-10 14:00:00	2019-10-10 15:00:00	\N	\N	1	0	\N	\N
413960	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Renforcer l'encadrement des rave-parties	\N	2019-10-08 14:00:00	2019-10-08 15:30:00	\N	\N	1	0	\N	\N
413988	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2019-09-11 09:00:00	2019-09-11 10:30:00	\N	\N	3	0	\N	\N
413994	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2019-09-25 14:30:00	2019-09-25 17:30:00	\N	\N	3	0	\N	\N
417113	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Code de l'urbanisme de Saint-Martin	\N	2019-10-16 17:15:00	2019-10-16 18:00:00	\N	\N	1	0	\N	\N
417119	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Code de l'urbanisme de Saint-Martin	\N	2019-10-17 09:00:00	2019-10-17 10:15:00	\N	\N	1	0	\N	\N
417123	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Lutte contre la haine sur internet	\N	2019-10-17 15:00:00	2019-10-17 17:00:00	\N	\N	1	0	\N	\N
417348	DELEGATION	AUDRAP	\N	\N	DSOM	Rencontre avec M. Jean-Michel Zammite (AFB)	\N	2019-10-16 17:00:00	2019-10-16 18:45:00	\N	\N	1	0	\N	\N
417350	DELEGATION	AUDRAP	\N	\N	DSOM	Réunion avec l'ODEADOM	\N	2019-10-10 16:15:00	2019-10-10 17:15:00	\N	\N	1	0	\N	\N
417352	DELEGATION	AUDRAP	\N	\N	DSOM	Réunion avec EURODOM	\N	2019-10-09 17:00:00	2019-10-09 18:00:00	\N	\N	1	0	\N	\N
417354	DELEGATION	AUDRAP	\N	\N	DSOM	Rencontre avec M. Charles Samathy (Interco'outre-mer)	\N	2019-10-04 15:00:00	2019-10-04 16:30:00	\N	\N	1	0	\N	\N
417356	DELEGATION	AUDRAP	\N	\N	DSOM	Rencontre avec M. José Althey	\N	2019-03-14 15:10:00	2019-03-14 16:00:00	\N	\N	1	0	\N	\N
417358	DELEGATION	AUDRAP	\N	\N	DSOM	Réunion avec M. Pierre Dubreuil, DG délégué du MNHN	\N	2019-03-11 11:00:00	2019-03-11 12:30:00	\N	\N	1	0	\N	\N
417360	DELEGATION	AUDRAP	\N	\N	DSOM	Rencontre avec Mme Chantal Clem	\N	2019-01-28 17:30:00	2019-01-28 19:00:00	\N	\N	1	0	\N	\N
417362	DELEGATION	AUDRAP	\N	\N	DSOM	Réunion avec Yves Laffoucrière	\N	2019-01-15 16:15:00	2019-01-15 18:30:00	\N	\N	1	0	\N	\N
417364	DELEGATION	AUDRAP	\N	\N	DSOM	Réunion QUALITROPIC	\N	2018-11-22 16:15:00	2018-11-22 17:00:00	\N	\N	1	0	\N	\N
417366	DELEGATION	AUDRAP	\N	\N	DSOM	Réunion élus polynésiens	\N	2018-11-21 16:30:00	2018-11-21 17:00:00	\N	\N	1	0	\N	\N
417368	DELEGATION	AUDRAP	\N	\N	DSOM	Rencontre Président - Dominique Monteiro	\N	2018-10-15 15:00:00	2018-10-15 16:30:00	\N	\N	1	0	\N	\N
417370	DELEGATION	AUDRAP	\N	\N	DSOM	Rendez-vous avec Roger Genet, directeur général de l'Anses	\N	2018-10-12 18:00:00	2018-10-12 19:45:00	\N	\N	1	0	\N	\N
417371	DELEGATION	AUDRAP	\N	\N	DSOM	Rendez-vous avec le président IEDOM / IEOM	\N	2018-10-12 16:00:00	2018-10-12 17:45:00	\N	\N	1	0	\N	\N
417374	DELEGATION	AUDRAP	\N	\N	DSOM	Rencontre avec M. Sébastien Folin	\N	2018-12-13 16:15:00	2018-12-13 18:00:00	\N	\N	3	0	\N	\N
417388	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion de la commission	Réunion de la commission	2019-10-22 10:00:00	2019-10-22 10:20:00	2019-10-23 10:06:34	2019-10-23 10:32:46	16	1	\N	\N
417428	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Action extérieure de l'État	PLF 2020 - Crédits Action extérieure de l'État	2019-10-15 14:30:00	2019-10-15 16:30:00	\N	\N	1	0	\N	\N
417429	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Action extérieure de l'État	PLF 2020 - Crédits Action extérieure de l'État	2019-10-15 10:00:00	2019-10-15 11:00:00	\N	\N	1	0	\N	\N
417434	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Enseignement supérieur	PLF 2020 - Crédits Enseignement supérieur	2019-10-17 09:00:00	2019-10-17 12:30:00	\N	\N	1	0	\N	\N
417435	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Enseignement supérieur	PLF 2020 - Crédits Enseignement supérieur	2019-10-17 16:00:00	2019-10-17 18:00:00	\N	\N	1	0	\N	\N
417536	GIA	AUCUNE	\N	\N	\N	accueil délégation chinoise du Tibet	accueil délégation chinoise du Tibet	2019-10-16 08:30:00	2019-10-16 10:00:00	\N	\N	11	0	634	\N
419807	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2020 - Mission Immigration, asile et intégration	\N	2019-10-22 15:40:00	2019-10-22 16:30:00	\N	\N	1	0	\N	\N
419809	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2020 - Mission Immigration, asile et intégration	\N	2019-10-22 16:30:00	2019-10-22 18:35:00	\N	\N	2	0	\N	\N
420251	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-10-30 10:05:00	2019-10-30 12:55:00	2019-10-30 14:52:31	2019-10-30 14:57:24	32	0	\N	\N
467295	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid 19 Jeunesse et Vie associative	Audition Agence du Service civique	2020-04-28 10:45:00	2020-04-28 11:30:00	\N	\N	1	0	\N	\N
467297	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid 19 Jeunesse et Vie associative	Audition Mouvement associatif	2020-04-30 09:00:00	2020-04-30 09:45:00	\N	\N	2	0	\N	\N
467300	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid 19 Jeunesse et Vie associative	Audition France Bénévolat	2020-04-30 10:00:00	2020-04-30 10:45:00	\N	\N	1	0	\N	\N
467302	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi urgence Covid-19 - Prisons et autres lieux privatifs de liberté	Audition DAP	2020-04-29 17:30:00	2020-04-29 19:05:00	\N	\N	4	0	\N	\N
467311	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid19 Presse	Audition Les Echos/Le Parisien	2020-04-30 10:30:00	2020-04-30 11:30:00	\N	\N	4	0	\N	\N
467627	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid19 Création	\N	2020-04-30 17:30:00	2020-04-30 18:45:00	\N	\N	4	0	\N	\N
467632	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid19 Enseignement agricole	\N	2020-04-30 14:00:00	2020-04-30 14:40:00	\N	\N	5	0	\N	\N
467638	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid19 Enseignement agricole	Audition P. Poussin - CNEAP	2020-05-04 14:00:00	2020-05-04 14:50:00	\N	\N	5	0	\N	\N
467640	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid19 Presse	\N	2020-04-27 15:00:00	2020-04-27 16:00:00	\N	\N	3	0	\N	\N
467644	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid19 Presse	\N	2020-04-28 16:30:00	2020-04-28 17:30:00	\N	\N	2	0	\N	\N
467652	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid 19 Enseign Sup	\N	2020-04-28 10:00:00	2020-04-28 11:00:00	\N	\N	5	0	\N	\N
502344	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2021	PLF pour 2021	2020-12-01 21:15:00	2020-12-02 01:40:00	\N	\N	109	0	\N	\N
417389	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion de la commission	Réunion de la commission	2019-10-23 10:05:00	2019-10-23 11:00:00	2019-10-23 15:50:10	2019-10-23 16:36:05	40	0	\N	\N
467658	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid 19 Enseign Sup	CPU	2020-04-22 14:00:00	2020-04-22 15:00:00	\N	\N	6	0	\N	\N
467660	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid 19 Enseign Sup	Cnous	2020-04-29 14:00:00	2020-04-29 15:00:00	\N	\N	6	0	\N	\N
467667	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid 19 Enseign Sup	\N	2020-04-27 11:15:00	2020-04-27 12:15:00	\N	\N	2	0	\N	\N
467670	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid 19 AEF	AEFE	2020-04-28 14:00:00	2020-04-28 15:00:00	\N	\N	3	0	\N	\N
467674	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid 19 Enseign Sup	P Diot, CNDM	2020-04-24 14:00:00	2020-04-24 15:00:00	\N	\N	5	0	\N	\N
467685	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid 19 Recherche	F. Trottein	2020-05-04 10:00:00	2020-05-04 11:00:00	\N	\N	3	0	\N	\N
467687	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid 19 Recherche	Inserm	2020-05-04 14:00:00	2020-05-04 15:00:00	\N	\N	3	0	\N	\N
467689	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid 19 Recherche	Académie Sciences	2020-05-06 16:00:00	2020-05-06 17:30:00	\N	\N	2	0	\N	\N
467691	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid 19 AEF	Fapée	2020-05-04 17:00:00	2020-05-04 18:00:00	\N	\N	3	0	\N	\N
467693	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid 19 AEF	MAE	2020-05-05 14:00:00	2020-05-05 14:45:00	\N	\N	3	0	\N	\N
467695	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid 19 AEF	MLF - JC Deberre	2020-05-05 14:45:00	2020-05-05 15:30:00	\N	\N	3	0	\N	\N
467697	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid 19 AEF	syndicats enseignants représentés au CA de AEFE	2020-05-07 10:30:00	2020-05-07 11:30:00	\N	\N	3	0	\N	\N
467699	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid 19 AEF	K. Velasco	2020-05-07 11:30:00	2020-05-07 12:30:00	\N	\N	3	0	\N	\N
467701	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid19 Création	TR Collter	2020-05-14 14:30:00	2020-05-14 16:20:00	\N	\N	6	0	\N	\N
467703	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid19 Création	DRAC association: L Roturier	2020-05-15 09:30:00	2020-05-15 10:40:00	\N	\N	5	0	\N	\N
467834	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audition de France Médias Monde	\N	2020-04-14 10:30:00	2020-04-14 12:00:00	\N	\N	2	0	\N	\N
467835	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audition de TV5 Monde	\N	2020-04-17 11:30:00	2020-04-17 13:00:00	\N	\N	2	0	\N	\N
468367	DELEGATION	AUCUNE	\N	\N	211	Audition de Mme Ernestine Ronai et M. Édouard Durand	\N	2020-05-20 16:30:00	2020-05-20 18:25:00	2020-05-20 18:30:27	\N	13	0	\N	\N
468368	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition par visioconférence du directeur de l'AEFE	\N	2020-05-07 10:00:00	2020-05-07 11:35:00	\N	\N	30	0	\N	\N
468598	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Hébergement d'urgence/M. Morisset - Audition de la société Adoma (audioconférence)	\N	2020-04-23 15:45:00	2020-04-23 16:20:00	\N	\N	1	0	\N	\N
468599	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Médico-social & Hébergement/MM.Bonne et Morisset - Audition de l'Uniopss (visioconférence)	\N	2020-04-24 10:30:00	2020-04-24 11:35:00	\N	\N	6	0	\N	\N
468600	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Hébergement d'urgence/M. Morisset - Audition de la Fondation Abbé Pierre (visioconférence)	\N	2020-04-24 14:45:00	2020-04-24 15:30:00	\N	\N	3	0	\N	\N
468601	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Médico-social/M. Bonne - Audition de la CNDEPAH (visioconférence)	\N	2020-04-14 10:30:00	2020-04-14 11:30:00	\N	\N	1	0	\N	\N
468602	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Médico-social/M. Bonne - Audition de la Fédération hospitalière de France (visioconf.)	\N	2020-04-16 11:30:00	2020-04-16 12:30:00	\N	\N	1	0	\N	\N
468603	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Médico-social/M. Bonne - Audition de Synerpa (visioconférence)	\N	2020-04-17 10:30:00	2020-04-17 11:30:00	\N	\N	1	0	\N	\N
468604	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Enjeux sanitaires - Audition CNOM (Mme Deroche)	\N	2020-04-16 10:45:00	2020-04-16 11:45:00	\N	\N	6	0	\N	\N
468605	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Médico-social/M. Bonne - Audition de l'Unapei (visioconférence)	\N	2020-04-20 11:00:00	2020-04-20 12:00:00	\N	\N	5	0	\N	\N
468606	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Médico-social/M. Bonne - Audition de la CNSA (visioconférence)	\N	2020-04-24 15:00:00	2020-04-24 16:00:00	\N	\N	4	0	\N	\N
468607	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Médico-social/M. Bonne - Audition de la Fnadepa (visioconférence)	\N	2020-04-27 10:30:00	2020-04-27 11:30:00	\N	\N	5	0	\N	\N
468608	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Médico-social/M. Bonne - Audition de la Fehap (visioconférence)	\N	2020-04-27 11:30:00	2020-04-27 12:30:00	\N	\N	7	0	\N	\N
468609	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Médico-social/M. Bonne - Audition de l'AD-PA (visioconférence)	\N	2020-04-28 14:00:00	2020-04-28 15:00:00	\N	\N	3	0	\N	\N
468610	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Médico-social/M. Bonne - Audition de l'UNA (visioconférence)	\N	2020-04-29 14:00:00	2020-04-29 15:00:00	\N	\N	4	0	\N	\N
468611	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Médico-social/M. Bonne - Audition de la société Nexem (visioconférence)	\N	2020-04-29 15:00:00	2020-04-29 16:00:00	\N	\N	1	0	\N	\N
468612	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Médico-social/M. Bonne - Audition du CNCPH (visioconférence)	\N	2020-05-06 16:00:00	2020-05-06 17:00:00	\N	\N	3	0	\N	\N
468634	DELEGATION	AUCUNE	\N	\N	DSOM	Auditions de la délégation	\N	2020-05-07 14:00:00	2020-05-07 17:00:00	\N	\N	10	0	\N	\N
468643	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Audition du Mouvement des entreprises de taille intermédiaire (METI)	\N	2020-05-05 16:35:00	2020-05-05 17:35:00	\N	\N	10	0	\N	\N
468656	DELEGATION	AUDRAP	\N	\N	206	Audition de l'IFREMER	\N	2020-05-04 09:00:00	2020-05-04 13:00:00	\N	\N	2	0	\N	\N
468659	DELEGATION	AUCUNE	\N	\N	206	Réunion de veille sur l'épidémie de Covid-19	\N	2020-05-07 09:10:00	2020-05-07 10:05:00	\N	\N	15	0	\N	\N
468730	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition par visioconférence de Mmes Florence Parly et Geneviève Darrieussecq	\N	2020-05-12 09:10:00	2020-05-12 10:55:00	2020-05-12 11:29:17	2020-05-13 18:07:56	37	0	\N	\N
468731	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition par visioconférence d'Expertise France et examen du COM 2020-2022	\N	2020-05-13 10:30:00	2020-05-13 12:10:00	2020-05-13 12:57:21	2020-05-13 18:07:58	35	0	\N	\N
468732	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition par visioconférence des représentants de l'industrie de défense	\N	2020-05-14 10:00:00	2020-05-14 12:05:00	2020-05-14 12:55:19	2020-05-14 16:55:16	32	0	\N	\N
468734	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi Covid-19 - Juridictions judiciaires et administratives	Audition des Conseils de prud'hommes de Paris, Strasbourg et Montpellier	2020-05-07 09:30:00	2020-05-07 12:00:00	\N	\N	5	0	\N	\N
468740	DELEGATION	AUDRAP	\N	\N	PROS	Audition de Mme Elisabeth Carbone, Secrétaire générale du MIRAMAP	Audition de Mme Elisabeth Carbone, Secrétaire générale du MIRAMAP	2020-05-05 09:00:00	2020-05-05 10:00:00	\N	\N	2	0	\N	\N
373770	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2019-04-16 14:40:00	2019-04-16 16:45:00	\N	\N	3	0	\N	\N
373774	GIA	AUCUNE	\N	\N	\N	réunion à la ville de Paris (urbanisme)	réunion à la ville de Paris	2019-04-18 11:30:00	2019-04-18 12:30:00	\N	\N	2	0	622	\N
373777	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Lutte contre les espèces toxiques envahissantes	\N	2019-04-25 10:30:00	2019-04-25 11:40:00	\N	\N	1	0	\N	\N
374933	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Modernisation de la distribution de la presse	\N	2019-04-30 14:00:00	2019-04-30 14:45:00	\N	\N	2	0	\N	\N
374936	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Modernisation de la distribution de la presse	\N	2019-04-30 14:45:00	2019-04-30 15:30:00	\N	\N	1	0	\N	\N
375490	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Sécurité des ponts	\N	2019-05-07 09:05:00	2019-05-07 09:45:00	\N	\N	7	0	\N	\N
375542	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	PJL relatif à l'entrée en fonction des représentants au Parlement européen élus en France aux élections de 2019	2019-05-07 08:30:00	2019-05-07 09:30:00	\N	\N	1	0	\N	\N
380208	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Wifi pour tous	Audition Wifi pour tous	2019-05-15 17:20:00	2019-05-15 18:05:00	\N	\N	1	0	\N	\N
380210	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Wifi pour tous	Audition Wifi pour tous	2019-05-16 14:25:00	2019-05-16 15:00:00	\N	\N	1	0	\N	\N
384847	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	\N	\N	2019-06-18 14:30:00	2019-06-18 15:15:00	\N	\N	0	0	\N	\N
385590	COM_ENQUETE	PLENIERE	\N	SOUVERAINETE	\N	Auditions d'Henri Verdier	Auditions d'Henri Verdier	2019-06-04 14:05:00	2019-06-04 15:05:00	2019-06-05 09:22:12	2019-06-05 11:49:54	8	0	\N	\N
385602	COM_ENQUETE	PLENIERE	\N	SOUVERAINETE	\N	Auditions du 4 juin	Auditions du 4 juin	2019-06-04 16:05:00	2019-06-04 17:45:00	2019-06-05 09:24:40	2019-06-05 11:49:54	6	0	\N	\N
386607	MISSION	AUCUNE	\N	AERIEN	\N	Réunion plénière	Audition de M. Augustin de Romanet, PDG du groupe ADP	2019-06-06 10:32:00	2019-06-06 11:50:00	2019-06-06 15:01:00	2019-06-07 10:48:53	14	0	\N	\N
386719	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Energie - Auditions M. Gremillet	\N	2019-06-05 14:30:00	2019-06-05 16:30:00	\N	\N	2	0	\N	\N
386745	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	Audition du 26 juin 2019	\N	2019-06-26 14:30:00	2019-06-26 16:30:00	\N	\N	0	0	\N	\N
386793	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Stade de France - DIJOP	Contrôle 2019 - Stade de France - DIJOP	2019-06-04 14:45:00	2019-06-04 15:30:00	\N	\N	1	0	\N	\N
386833	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - ZRR - Table ronde acteurs économiques	Contrôle 2019 - ZRR - Table ronde acteurs économiques	2019-06-04 18:00:00	2019-06-04 20:00:00	\N	\N	3	0	\N	\N
386923	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Ressources humaines du ministère des armées - HCECM	Contrôle 2019 - Ressources humaines du ministère des armées - HCECM	2019-06-05 14:30:00	2019-06-05 15:30:00	\N	\N	1	0	\N	\N
386925	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJLR pour 2018 - Anciens combattants - ONACVG	PJLR pour 2018 - Anciens combattants - ONACVG	2019-06-04 16:00:00	2019-06-04 18:00:00	\N	\N	1	0	\N	\N
386938	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Audition Boeing France J.M. FRON	\N	2019-06-06 08:30:00	2019-06-06 10:00:00	\N	\N	0	0	\N	\N
386943	MISSION	AUCUNE	\N	SIDERURGIE	\N	Audition Président région Grand Est	\N	2019-06-06 11:05:00	2019-06-06 12:00:00	2019-06-06 16:05:35	2019-06-07 10:48:04	5	0	\N	\N
387199	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition 58-2°  Valorisation internationale de l'ingénierie et des marques culturelles	Audition 58-2° sur la valorisation internationale de l'ingénierie et des marques culturelles	2019-06-12 10:35:00	2019-06-12 12:15:00	2019-06-14 10:57:50	2019-06-14 14:27:43	27	0	\N	\N
387583	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Suivi de la politique de la ville	Audition Suivi de la politique de la ville	2019-06-05 14:45:00	2019-06-05 16:15:00	\N	\N	1	0	\N	\N
393951	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Création du Centre national de la musique	PPL Création du Centre national de la musique	2019-06-19 16:00:00	2019-06-19 19:00:00	\N	\N	3	0	\N	\N
393952	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Création du Centre national de la musique	\N	2019-06-20 09:30:00	2019-06-20 11:30:00	\N	\N	1	0	\N	\N
393957	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion 20190625	\N	2019-06-25 09:35:00	2019-06-25 09:55:00	2019-06-25 14:22:44	2019-06-25 16:26:02	12	0	\N	\N
394023	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2019 - Ressources humaines du ministère des armées - Déplacement Ile Longue	Contrôle 2019 - Ressources humaines du ministère des armées - Déplacement Ile Longue	2019-06-24 09:05:00	2019-06-25 18:20:00	\N	\N	1	0	\N	\N
394025	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2019 - Mobilisation financements régionaux - Déplacement Saint-Aubin	Contrôle 2019 - Mobilisation financements régionaux - Déplacement Saint-Aubin	2019-06-19 14:00:00	2019-06-19 19:30:00	\N	\N	1	0	\N	\N
394081	COM_ENQUETE	PLENIERE	\N	SOUVERAINETE	\N	Auditions	\N	2019-06-25 14:40:00	2019-06-25 16:50:00	2019-07-01 17:48:33	2019-07-02 14:50:59	11	0	\N	\N
394111	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Communication coopération judiciaire	\N	2019-06-26 11:25:00	2019-06-26 11:57:00	2019-06-26 12:18:58	2019-06-28 11:50:02	18	0	\N	\N
398441	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Énergie - Auditions M. Gremillet	\N	2019-07-03 16:15:00	2019-07-03 17:00:00	\N	\N	2	0	\N	\N
398451	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Énergie - Auditions M. Gremillet	\N	2019-07-02 13:30:00	2019-07-02 14:45:00	\N	\N	2	0	\N	\N
398465	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Énergie - Auditions Mme Bories	\N	2019-07-03 13:50:00	2019-07-03 16:50:00	\N	\N	2	0	\N	\N
398618	MISSION	AUTRE	\N	FONDS	\N	Réunion du mardi 16 juillet 2019	\N	2019-07-16 14:50:00	2019-07-16 18:30:00	2019-07-17 15:52:06	2019-07-17 18:22:10	11	0	\N	\N
399682	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Économie circulaire - Auditions Mme de CIDRAC	\N	2019-07-09 15:35:00	2019-07-09 16:35:00	\N	\N	3	0	\N	\N
404747	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution plastique	Audition rapporteurs Pollution plastique (Table ronde Agriculture)	2019-09-18 16:15:00	2019-09-18 18:45:00	\N	\N	2	0	\N	\N
404748	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution plastique	Audition rapporteurs Pollution plastique (Table ronde Transport maritime et industrie nautique)	2019-10-01 16:15:00	2019-10-01 17:45:00	\N	\N	2	0	\N	\N
404749	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière	Réunion plénière - Conclusions EPR Flamanville, désignation membre, audition B. Pailhès	2019-09-26 10:25:00	2019-09-26 13:10:00	\N	\N	6	0	\N	\N
404927	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Économie circulaire - Auditions Mme de CIDRAC	PJL Économie circulaire	2019-09-05 14:30:00	2019-09-05 15:15:00	\N	\N	1	0	\N	\N
404929	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Économie circulaire - Auditions Mme LOISIER	PJL Économie circulaire	2019-09-05 08:45:00	2019-09-05 09:35:00	\N	\N	1	0	\N	\N
404930	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Économie circulaire - Auditions Mme LOISIER	PJL Économie circulaire	2019-09-05 09:35:00	2019-09-05 10:15:00	\N	\N	1	0	\N	\N
502345	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2021	PLF pour 2021	2020-12-02 10:40:00	2020-12-02 13:20:00	\N	\N	112	0	\N	\N
386606	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-06-12 10:20:00	2019-06-12 10:55:00	2019-06-12 11:20:25	2019-06-12 16:55:44	38	0	\N	\N
394110	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion 20190626 	Rapp. Trés. assoc. , violences éducatives, simplification droit des sociétés. 	2019-06-26 09:05:00	2019-06-26 11:24:00	2019-06-26 12:25:08	2019-06-28 11:50:04	37	0	\N	\N
404931	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Économie circulaire - Auditions Mme LOISIER	PJL Économie circulaire	2019-09-05 10:15:00	2019-09-05 11:50:00	\N	\N	1	0	\N	\N
404932	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Économie circulaire - Auditions Mme LOISIER	PJL Économie circulaire	2019-09-05 11:50:00	2019-09-05 12:50:00	\N	\N	1	0	\N	\N
404933	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Économie circulaire - Auditions Mme LOISIER	PJL Économie circulaire	2019-09-05 14:35:00	2019-09-05 15:20:00	\N	\N	1	0	\N	\N
404934	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Économie circulaire - Auditions Mme LOISIER	PJL Économie circulaire	2019-09-05 15:20:00	2019-09-05 17:05:00	\N	\N	1	0	\N	\N
404935	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Économie circulaire - Auditions Mme LOISIER	PJL Économie circulaire	2019-09-05 17:05:00	2019-09-05 17:45:00	\N	\N	1	0	\N	\N
404936	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Économie circulaire - Auditions Mme LOISIER	PJL Économie circulaire	2019-09-05 17:45:00	2019-09-05 18:15:00	\N	\N	1	0	\N	\N
404937	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Économie circulaire - Auditions Mme LOISIER	PJL Économie circulaire	2019-09-05 18:15:00	2019-09-05 18:45:00	\N	\N	1	0	\N	\N
472122	COM_ENQUETE	PLENIERE	\N	LUBRIZOL	\N	Examen du projet de rapport de la commission d'enquête	\N	2020-06-02 18:05:00	2020-06-02 19:45:00	2020-06-02 20:15:23	2020-06-04 18:27:08	13	0	\N	\N
472123	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid 19 Patrimoine	Audition Demeure Historique et Vieilles Maisons Françaises	2020-05-25 14:30:00	2020-05-25 16:00:00	\N	\N	5	0	\N	\N
472135	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid19 Médias	Audition Mediawan	2020-05-25 16:00:00	2020-05-25 17:20:00	\N	\N	2	0	\N	\N
472140	DELEGATION	AUDRAP	\N	\N	206	Entretien avec M. Stéphane Messika, M. Gabriel Turinici et Mme Émilie Rannou 	Entretien avec M. Stéphane Messika, M. Gabriel Turinici et Mme Émilie Rannou 	2020-05-25 16:00:00	2020-05-25 17:00:00	\N	\N	2	0	\N	\N
472143	DELEGATION	AUDRAP	\N	\N	206	Entretien avec M. Christophe Fraser	Entretien avec M. Christophe Fraser	2020-05-25 17:00:00	2020-05-25 18:00:00	\N	\N	2	0	\N	\N
472597	COM_ENQUETE	PLENIERE	\N	SOLS	\N	Réunion plénière CE pollution des sols	\N	2020-05-26 16:30:00	2020-05-26 18:00:00	2020-05-27 14:42:07	2020-05-28 14:44:38	7	0	\N	\N
472598	COM_ENQUETE	PLENIERE	\N	SOLS	\N	Réunion plénière CE Pollution des sols	\N	2020-05-27 16:45:00	2020-05-27 18:30:00	2020-05-28 10:13:37	2020-05-28 14:44:37	5	0	\N	\N
472734	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission (visioconférence)	Réunion de commission (visioconférence)	2020-05-27 09:40:00	2020-05-27 12:30:00	2020-05-27 12:36:22	2020-05-27 17:09:03	32	0	\N	\N
473143	BUREAU	AUCUNE	\N	\N	\N	Bureau du Sénat	Bureau du Sénat	2020-05-27 09:00:00	2020-05-27 12:45:00	\N	\N	26	0	\N	\N
473521	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2020-06-03 09:30:00	2020-06-03 11:40:00	2020-06-03 15:20:57	2020-06-08 15:49:39	37	1	\N	\N
474306	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Inde	\N	2020-05-29 09:30:00	2020-05-29 10:45:00	\N	\N	1	0	\N	\N
475792	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - Pr B. Dautzendberg	Audition Pollution plastique - Pr B. Dautzendberg	2020-06-09 12:00:00	2020-06-09 13:00:00	\N	\N	2	0	\N	\N
476047	DELEGATION	AUCUNE	\N	\N	COLTER	Table ronde "Think tank" - Décentralisation	\N	2020-06-11 09:30:00	2020-06-11 11:15:00	2020-06-11 11:17:36	\N	17	0	\N	\N
476447	GIA	AUCUNE	\N	\N	\N	Entretien avec Son Exc. LU Shaye, Ambassadeur de Chine en France (visio)	\N	2020-06-08 15:00:00	2020-06-08 16:20:00	\N	\N	9	0	584	\N
476993	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT subsidiarité	GT subsidiarité	2020-06-09 18:50:00	2020-06-09 19:00:00	\N	\N	3	0	\N	\N
477594	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du GT Subsidiarité	\N	2020-04-08 17:15:00	2020-04-08 17:35:00	2020-06-11 11:50:47	\N	4	0	\N	\N
477692	DELEGATION	AUCUNE	\N	\N	DSOM	Table ronde Économie et Statistiques	\N	2020-06-18 14:00:00	2020-06-18 17:25:00	\N	\N	7	0	\N	\N
477694	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule logement - MIchel Mouillard	\N	2020-04-29 18:30:00	2020-04-29 19:30:00	\N	\N	2	0	\N	\N
477695	DELEGATION	AUCUNE	\N	\N	206	Présentation par l'Académie nationale de médecine	Présentation par l'Académie nationale de médecine de l'état actuel de la recherche en biologie-santé	2020-06-18 09:30:00	2020-06-18 11:45:00	\N	\N	9	0	\N	\N
477698	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule logement - Alila	\N	2020-04-29 17:30:00	2020-04-29 18:30:00	\N	\N	2	0	\N	\N
477701	COM_PERMANENTE	AUTRE	\N	FINC	\N	PPRE 497 Examen Rapport et Texte - Communication RG Stratégie relance économie	PPRE 497 Examen Rapport et Texte - Communication RG Stratégie relance économie	2020-06-16 15:30:00	2020-06-16 17:00:00	2020-06-16 18:41:17	2020-06-17 18:15:20	20	1	\N	\N
477703	COM_PERMANENTE	AUTRE	\N	FINC	\N	PJL Reglement 2019 Examen Rapport - Audition 58-2 ANRU et NPNRU	PJL Reglement 2019 Examen Rapport - Audition 58-2 ANRU et NPNRU	2020-06-17 09:05:00	2020-06-17 12:30:00	2020-06-17 13:08:55	2020-06-17 18:15:17	34	0	\N	\N
477713	MISSION	AUDRAP	\N	GUYANE	\N	Auditions Association Mama Mobi et Mme Guéda Gadio	\N	2020-06-11 14:30:00	2020-06-11 17:30:00	\N	\N	9	0	\N	\N
477724	COM_EURO	AUTRE	\N	AFEU	\N	Audition de M.Benoît Coeuré par la CAEU	Audition par audioconférence de Benoît COEURÉ, directeur du pôle innovation de la Banque des règlements internationaux	2020-04-14 09:00:00	2020-04-14 10:10:00	2020-06-11 15:27:51	\N	18	0	\N	\N
477744	COM_ENQUETE	PLENIERE	\N	RADICALI	\N	Audition de Christophe Castaner, ministre de l'intérieur	Audition de Christophe Castaner, ministre de l'intérieur	2020-06-18 14:00:00	2020-06-18 15:45:00	2020-06-19 12:23:20	2020-06-19 14:57:20	6	0	\N	\N
477747	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJLO Report des élections sénatoriales et des élections législatives partielles 	PJLO Report des élections sénatoriales et des élections législatives partielles - Examen texte et rapport      	2020-06-16 09:40:00	2020-06-16 10:40:00	2020-06-17 10:07:24	2020-06-17 18:08:18	27	0	\N	\N
477748	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion de la commissin	Réunion de la commission	2020-06-17 09:35:00	2020-06-17 10:30:00	2020-06-17 11:03:04	2020-06-17 18:45:58	29	1	\N	\N
477750	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJLO Report des élections sénatoriales et des élections législatives partielles 	PJLO Report des élections sénatoriales et des élections législatives partielles 	2020-06-17 17:44:00	2020-06-17 17:50:00	2020-06-17 19:30:03	2020-06-18 17:25:45	10	0	\N	\N
478049	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Programme 144 : financement de la BITD 	\N	2020-06-09 15:00:00	2020-06-09 18:00:00	\N	\N	2	0	\N	\N
478271	MISSION	AUDRAP	\N	FEDERATION	\N	Auditions MI FFS	Auditions MI FFS	2020-06-16 16:00:00	2020-06-16 16:35:00	\N	\N	7	0	\N	\N
478279	MISSION	AUDRAP	\N	FEDERATION	\N	Auditions MI FFS	Auditions MI FFS	2020-06-16 17:00:00	2020-06-16 18:10:00	\N	\N	7	0	\N	\N
478424	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2020-06-17 11:00:00	2020-06-17 13:00:00	2020-06-17 19:26:18	2020-06-18 17:18:50	28	0	\N	\N
478425	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2020-06-17 17:00:00	2020-06-17 19:00:00	2020-06-19 18:03:26	2020-06-24 17:56:51	25	0	\N	\N
478591	COM_ENQUETE	PLENIERE	\N	AUTOROUT	\N	CE Concessions autoroutières - Auditions - Pierre COPPEY et Arnaud QUEMARD 	CE Concessions autoroutières - Auditions - Pierre COPPEY (Vinci Aut.) et Arnaud QUEMARD ( SANEF)	2020-06-23 14:35:00	2020-06-23 17:55:00	2020-06-23 17:57:48	2020-06-24 11:41:32	10	0	\N	\N
478678	MISSION	AUCUNE	\N	GUYANE	\N	Audition de M. David Weinberger	\N	2020-06-17 15:30:00	2020-06-17 16:45:00	2020-06-17 18:05:56	2020-06-17 18:45:36	5	0	\N	\N
478697	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Alimentation durable et locale-Synabio	Covid-19-Alimentation durable et locale-Synabio	2020-06-15 09:30:00	2020-06-15 10:30:00	\N	\N	7	0	\N	\N
478850	MISSION	AUDRAP	\N	FEDERATION	\N	Auditions MI FFS	Auditions MI FFS	2020-06-17 14:00:00	2020-06-17 15:10:00	\N	\N	10	0	\N	\N
478886	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen Rapports PJLO-PJL Dette sociale et DADDUE - Nomination Rapporteur CVN France-Luxemb	Examen Rapports PJLO-PJL Dette sociale et DADDUE - Nomination Rapporteur CVN France-Luxembourg	2020-06-24 09:50:00	2020-06-24 11:50:00	2020-06-24 12:28:37	2020-06-24 15:07:32	28	1	\N	\N
478951	COM_EURO	AUTRE	\N	AFEU	\N	Audition M. Timmermans, VP Commission européenne	Commission des affaires européennes  et Commission de l'aménagement du territoire et du développement durable	2020-06-17 17:00:00	2020-06-17 19:00:00	2020-06-18 13:40:23	2020-06-30 16:27:12	25	0	\N	\N
378893	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	\N	\N	2019-05-15 15:00:00	2019-05-15 16:45:00	2019-05-16 14:48:55	2019-05-16 15:01:24	7	0	\N	\N
379025	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	\N	\N	2019-05-16 09:30:00	2019-05-16 10:30:00	2019-05-16 14:50:31	2019-05-16 15:01:25	7	0	\N	\N
404767	ETUDES	AUCUNE	\N	\N	\N	Audition du président de l'Union des employeurs de l'économie sociale et solidaire (UDES)	Audition du président de l'Union des employeurs de l'économie sociale et solidaire (UDES)	2019-09-18 08:00:00	2019-09-18 09:30:00	\N	\N	5	0	\N	998
410100	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 10 octobre 2019 - débat préalable au Conseil européen	Réunion du 10 octobre 2019 - débat préalable au Conseil européen	2019-10-10 08:45:00	2019-10-10 11:15:00	2019-10-10 18:01:09	2019-10-11 17:50:36	22	0	\N	\N
410230	MISSION	AUCUNE	\N	MARITIME	\N	MCI Sauvetage en Mer - Auditions plénières SNSM / Station Sables-d'Olonne	MCI Sauvetage en Mer - Auditions plénières SNSM / Station Sables-d'Olonne	2019-10-10 09:05:00	2019-10-10 13:40:00	2019-10-11 12:40:42	2019-10-11 17:51:17	8	0	\N	\N
416672	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2020 - APD	\N	2019-10-15 17:00:00	2019-10-15 18:00:00	\N	\N	2	0	\N	\N
416915	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJLF POUR 2020 - P. 144	PJLF POUR 2020 - P. 144	2019-10-16 16:30:00	2019-10-16 17:30:00	\N	\N	2	0	\N	\N
416938	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJLF pour 2020 - p 151	PJLF pour 2020 - P 151	2019-10-15 17:30:00	2019-10-15 18:30:00	\N	\N	2	0	\N	\N
416941	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJLF pour 2020 - p 151	PJLF pour 2020 - p 151	2019-10-17 15:00:00	2019-10-17 16:45:00	\N	\N	2	0	\N	\N
420257	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Agir contre les violences au sein de la famille	PPL Violences au sein de la famille	2019-10-23 14:00:00	2019-10-23 15:00:00	\N	\N	3	0	\N	\N
420260	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Agir contre les violences au sein de la famille	PPL Violences au sein de la famille	2019-10-23 16:20:00	2019-10-23 19:15:00	\N	\N	2	0	\N	\N
420316	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion conjointe avec le Groupe d'étude sur le numérique	Réunion conjointe avec le Groupe d'étude sur le numérique - Banque des territoires, OVH, CMA France, Mazars	2019-10-22 15:45:00	2019-10-22 18:45:00	2019-10-24 11:40:29	\N	6	0	\N	\N
420338	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion conjointe avec le Groupe d'étude sur le numérique	Réunion conjointe avec le Groupe d'étude sur le numérique - Audition DGE	2019-10-23 16:30:00	2019-10-23 17:30:00	2019-10-24 11:45:14	\N	2	0	\N	\N
420423	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2020 - Programmes 844/847	\N	2019-10-17 17:00:00	2019-10-17 18:00:00	\N	\N	1	0	\N	\N
420448	GIA	AUCUNE	\N	\N	\N	Audition de M. Fabrice BALANCHE, géographe, spécialiste de la Syrie et du Moyen-Orient	Audition de M. Fabrice BALANCHE, géographe, spécialiste de la Syrie et du Moyen-Orient	2019-10-22 08:30:00	2019-10-22 10:00:00	\N	\N	6	0	644	\N
424899	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion conjointe avec le Groupe d'études sur le numérique	Réunion conjointe avec le Groupe d'études sur le numérique - Bpifrance	2019-11-05 18:25:00	2019-11-05 19:30:00	2019-11-07 10:01:02	\N	5	0	\N	\N
425057	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2019-11-06 16:30:00	2019-11-06 17:05:00	\N	\N	25	0	\N	\N
425316	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Mission administration de l'Etat	PLF pour 2020 - Mission administration de l'Etat	2019-11-28 18:43:00	2019-11-29 20:02:00	\N	\N	37	0	\N	\N
425327	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Mission Action extérieure de l'état	PLF pour 2020 - Mission Action extérieure de l'état	2019-11-29 09:32:00	2019-11-29 12:58:00	\N	\N	52	0	\N	\N
478512	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	\N	2020-06-17 09:35:00	2020-06-17 12:20:00	2020-06-17 13:07:59	2020-06-18 17:34:13	42	0	\N	\N
425329	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Mission Aide publique développement	PLF pour 2020 - Mission Aide publique développement	2019-11-29 14:30:00	2019-11-29 16:15:00	\N	\N	45	0	\N	\N
425331	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Mission Santé	PLF pour 2020 - Mission Santé	2019-11-29 16:17:00	2019-11-29 19:06:00	\N	\N	46	0	\N	\N
425334	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Mission Solidarité	PLF pour 2020 - Mission Solidarité	2019-11-29 19:07:00	2019-11-29 20:03:00	\N	\N	37	0	\N	\N
425340	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Mission Solidarité	PLF pour 2020 - Mission Solidarité	2019-11-29 21:35:00	2019-11-30 22:41:00	\N	\N	39	0	\N	\N
425342	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Mission Recherche enseignement supérieur	PLF pour 2020 - Mission Recherche enseignement supérieur	2019-11-29 22:30:00	2019-11-30 00:30:00	\N	\N	28	0	\N	\N
425347	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	NL PLFSS pour 2020	NL PLFSS pour 2020	2019-11-30 14:35:00	2019-11-30 21:10:00	\N	\N	44	0	\N	\N
425434	GIA	AUCUNE	\N	\N	\N	CCI France-Russie	Entretien avec M. Emmanuel Quidet, président de la CCI France-Russie	2019-11-07 08:00:00	2019-11-07 09:00:00	\N	\N	6	0	608	\N
425666	GIA	AUCUNE	\N	\N	\N	Rencontre avec M. Vincent FALCOZ	Rencontre avec M. Vincent FALCOZ, chef du service économique régional à Varsovie	2019-11-07 08:30:00	2019-11-07 09:45:00	\N	\N	2	0	600	\N
425756	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Art. 2e partie	PLF pour 2020 - Art. 2e partie	2019-12-06 12:00:00	2019-12-06 13:01:00	\N	\N	31	0	\N	\N
425770	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Art. 2e partie	PLF pour 2020 - Art. 2e partie	2019-12-06 14:30:00	2019-12-06 20:07:00	\N	\N	43	0	\N	\N
425771	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Art. 2e partie	PLF pour 2020 - Art. 2e partie	2019-12-06 21:40:00	2019-12-07 00:25:00	\N	\N	37	0	\N	\N
425778	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Art. 2e partie	PLF pour 2020 - Art. 2e partie	2019-12-07 21:30:00	2019-12-08 00:00:00	\N	\N	0	0	\N	\N
425782	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Art. 2e partie	PLF pour 2020 - Art. 2e partie	2019-12-09 10:01:00	2019-12-09 12:58:00	\N	\N	34	0	\N	\N
425783	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Art. 2e partie	PLF pour 2020 - Art. 2e partie	2019-12-09 14:31:00	2019-12-09 20:29:00	\N	\N	63	0	\N	\N
425784	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Art. 2e partie	PLF pour 2020 - Art. 2e partie	2019-12-09 21:30:00	2019-12-10 00:00:00	\N	\N	0	0	\N	\N
468743	DELEGATION	AUCUNE	\N	\N	PROS	Audition de M. Antoine Frérot, président de l'Institut de l'Entreprise	Audition de M. Antoine Frérot, président, et de M. Paul Allibert, directeur général, de l'Institut de l'Entreprise	2020-05-07 14:30:00	2020-05-07 15:55:00	\N	\N	11	0	\N	\N
468776	MISSION	AUCUNE	\N	ILLECTRONISM	\N	Réunion constitutive de la MI Illectronisme et inclusion numérique	Réunion constitutive de la MI Illectronisme et inclusion numérique	2020-05-13 18:00:00	2020-05-13 18:30:00	2020-05-14 17:09:40	2020-05-14 17:20:28	17	0	\N	\N
468777	DELEGATION	AUCUNE	\N	\N	211	Audition de M. Luc Frémiot	\N	2020-05-28 09:30:00	2020-05-28 11:00:00	\N	\N	11	0	\N	\N
468778	COM_ENQUETE	AUDRAP	\N	AUTOROUT	\N	CE concessions autoroutières - Anne BOLLIET	CE concessions autoroutières - Anne BOLLIET	2020-05-07 11:30:00	2020-05-07 12:20:00	\N	\N	5	0	\N	\N
468794	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Visioconférence sur l'action de l'OTAN contre le Covid-19	\N	2020-05-07 15:00:00	2020-05-07 16:40:00	\N	\N	7	0	\N	\N
468806	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	FSU	FSU	2020-05-07 09:45:00	2020-05-07 11:20:00	\N	\N	0	0	\N	\N
468807	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	ENTREPRISES	Réunion du Bureau	Réunion du Bureau	2020-05-07 11:20:00	2020-05-07 12:15:00	\N	\N	5	0	\N	\N
468819	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid 19 Sport	Audition ANLSP	2020-05-05 09:30:00	2020-05-05 11:00:00	\N	\N	6	0	\N	\N
468826	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid 19 Sport	Audition ANDES	2020-05-07 09:30:00	2020-05-07 10:20:00	\N	\N	6	0	\N	\N
468836	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid19 Médias	Audition Groupe M6	2020-05-07 16:00:00	2020-05-07 17:15:00	\N	\N	4	0	\N	\N
468869	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission (visioconférence)	Réunion de commission (visioconférence)	2020-05-07 14:40:00	2020-05-07 16:00:00	\N	\N	24	0	\N	\N
468895	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de M.Martin Hirsch et bilan annuel de l'application des lois (en visioconférence)	\N	2020-05-13 10:30:00	2020-05-13 12:25:00	2020-05-15 15:55:11	2020-05-15 16:02:18	39	0	\N	\N
468995	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2020-05-05 14:30:00	2020-05-05 16:05:00	\N	\N	3	0	\N	\N
468999	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid19 Création	RMN-GP	2020-05-11 09:30:00	2020-05-11 10:40:00	\N	\N	5	0	\N	\N
469005	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid 19 Livre et Industries culturelles	Audition SACD	2020-04-21 10:30:00	2020-04-21 11:30:00	\N	\N	6	0	\N	\N
469012	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid 19 Livre et Industries culturelles	Audition SACEM	2020-04-21 15:30:00	2020-04-21 16:30:00	\N	\N	6	0	\N	\N
469019	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid 19 Livre et Industries culturelles	Audition SLF	2020-04-22 11:00:00	2020-04-22 12:00:00	\N	\N	6	0	\N	\N
469026	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT	Audition CNC	2020-04-22 14:30:00	2020-04-22 15:30:00	\N	\N	6	0	\N	\N
469118	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid 19 Sport	Audition CNOSF	2020-05-12 09:30:00	2020-05-12 11:00:00	\N	\N	5	0	\N	\N
470435	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat réouverture des établissements d'enseignement	Débat réouverture des établissements d'enseignement	2020-05-19 16:00:00	2020-05-19 18:00:00	\N	\N	41	0	\N	\N
470436	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Français établis hors de France	PPL Français établis hors de France	2020-05-19 22:10:00	2020-05-19 23:50:00	\N	\N	26	0	\N	\N
470437	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL dispositions urgentes pour faire face aux conséquences de l'épidémie de covid-19	PJL dispositions urgentes pour faire face aux conséquences de l'épidémie de covid-19	2020-05-26 14:30:00	2020-05-26 20:00:00	\N	\N	77	0	\N	\N
470439	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL dispositions urgentes pour faire face aux conséquences de l'épidémie de covid-19	PJL dispositions urgentes pour faire face aux conséquences de l'épidémie de covid-19	2020-05-26 21:30:00	2020-05-27 00:05:00	\N	\N	48	0	\N	\N
470440	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Covid-19 et productions stratégiques	Débat Covid-19 et productions stratégiques	2020-05-27 17:50:00	2020-05-27 19:25:00	\N	\N	41	0	\N	\N
470441	SEANCE_PLENIERE	DECL_GVT	\N	\N	\N	Déclaration du Gouvernement 50-1 - Covid	Déclaration du Gouvernement, suivie d'un débat et d'un vote sur cette déclaration, en application de l'article 50-1 de l	2020-05-27 21:30:00	2020-05-27 23:55:00	\N	\N	52	0	\N	\N
470444	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Pacte social national 	Débat Pacte social national	2020-05-28 17:15:00	2020-05-28 18:45:00	\N	\N	35	0	\N	\N
470445	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL dispositions urgentes pour faire face aux conséquences de l'épidémie de covid-19	PJL dispositions urgentes pour faire face aux conséquences de l'épidémie de covid-19	2020-05-28 18:50:00	2020-05-28 20:20:00	\N	\N	42	0	\N	\N
470446	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL dispositions urgentes pour faire face aux conséquences de l'épidémie de covid-19	PJL dispositions urgentes pour faire face aux conséquences de l'épidémie de covid-19	2020-05-28 21:55:00	2020-05-29 03:35:00	\N	\N	39	0	\N	\N
470538	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid19 Médias	Audition TF1	2020-05-07 15:00:00	2020-05-07 16:00:00	\N	\N	4	0	\N	\N
471001	MISSION	AUCUNE	\N	GUYANE	\N	\N	\N	2020-05-19 16:00:00	2020-05-19 16:35:00	2020-05-20 11:58:15	2020-05-20 14:35:03	18	0	\N	\N
471007	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière - ASN	Réunion plénière - ASN	2020-05-28 09:35:00	2020-05-28 11:35:00	\N	\N	9	0	\N	\N
471047	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Dispositions urgentes face à l'épidémie de covid-19	\N	2020-05-15 09:00:00	2020-05-15 10:00:00	\N	\N	4	0	\N	\N
471052	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Dispositions urgentes face à l'épidémie de covid-19	\N	2020-05-15 11:30:00	2020-05-15 12:30:00	\N	\N	2	0	\N	\N
471055	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Dispositions urgentes face à l'épidémie de covid-19	\N	2020-05-15 16:30:00	2020-05-15 17:30:00	\N	\N	3	0	\N	\N
471082	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Création de Points d'accueil pour soins immédiats	\N	2020-05-15 16:30:00	2020-05-15 17:15:00	\N	\N	1	0	\N	\N
471516	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Création de Points d'accueil pour soins immédiats	\N	2020-05-19 17:00:00	2020-05-19 17:50:00	\N	\N	2	0	\N	\N
472001	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Création de Points d'accueil pour soins immédiats	\N	2020-05-20 14:00:00	2020-05-20 14:55:00	\N	\N	3	0	\N	\N
472003	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Création de Points d'accueil pour soins immédiats	\N	2020-05-20 16:30:00	2020-05-20 17:30:00	\N	\N	1	0	\N	\N
472008	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Création de Points d'accueil pour soins immédiats	\N	2020-05-20 17:45:00	2020-05-20 18:30:00	\N	\N	1	0	\N	\N
472067	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Scaf	\N	2020-05-18 16:15:00	2020-05-18 17:30:00	\N	\N	3	0	\N	\N
473288	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2020-05-27 16:35:00	2020-05-27 18:20:00	2020-05-28 16:06:31	2020-05-28 18:11:04	29	0	\N	\N
473389	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Procurations électorales	PPL Procurations électorales	2020-06-02 16:35:00	2020-06-02 19:45:00	\N	\N	43	0	\N	\N
473390	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Politiques publiques jeunesse	Débat Politiques publiques jeunesse	2020-06-03 16:20:00	2020-06-03 17:55:00	\N	\N	36	0	\N	\N
473391	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR 34-1	PPR Mettre en oeuvre une imposition de solidarité sur le capital	2020-06-03 18:00:00	2020-06-03 19:20:00	\N	\N	34	0	\N	\N
473392	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Violences conjugales	PPL Protéger les victimes de violences conjugales	2020-06-09 14:30:00	2020-06-09 20:05:00	\N	\N	61	0	\N	\N
473393	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Violences conjugales	PPL Protéger les victimes de violences conjugales	2020-06-09 21:35:00	2020-06-10 01:10:00	\N	\N	40	0	\N	\N
473394	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2020-06-10 15:00:00	2020-06-10 16:20:00	\N	\N	110	0	\N	\N
473395	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PJL Crise sanitaire et Brexit	CMP PJL Crise sanitaire et Brexit	2020-06-10 16:35:00	2020-06-10 17:30:00	\N	\N	32	0	\N	\N
378919	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD 	\N	2019-05-21 09:05:00	2019-05-21 11:00:00	2019-05-21 11:28:27	2019-05-21 17:55:44	37	1	\N	\N
378920	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-05-22 08:45:00	2019-05-22 10:50:00	2019-05-22 12:23:11	2019-05-22 17:38:12	31	0	\N	\N
378921	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen AMDTS de séance texte n° 497 Taxe GAFA	Examen AMDTS de séance texte n° 497 Taxe GAFA	2019-05-21 14:05:00	2019-05-21 14:25:00	2019-05-21 14:56:16	2019-05-21 17:55:45	27	0	\N	\N
378923	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de Mme Isabelle SAURAT, directrice de l'immobilier de l'État	Audition de Mme Isabelle SAURAT, directrice de l'immobilier de l'État	2019-05-22 10:05:00	2019-05-22 11:35:00	2019-05-22 12:15:05	2019-05-22 17:38:07	19	0	\N	\N
378932	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Mme Gruny M. Artano MI Santé au travail	\N	2019-05-15 15:30:00	2019-05-15 16:30:00	\N	\N	2	0	\N	\N
378942	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Mme Gruny M. Artano MI Santé au travail	\N	2019-05-15 18:00:00	2019-05-15 19:00:00	\N	\N	1	0	\N	\N
379044	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-05-22 09:30:00	2019-05-22 11:05:00	2019-05-22 11:40:01	2019-05-22 17:38:11	63	0	\N	\N
472049	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2020-05-27 17:05:00	2020-05-27 19:10:00	\N	\N	36	0	\N	\N
473287	COM_PERMANENTE	AUTRE	\N	AFCL	\N	audition Jean Baptiste Lemoyne	audition Jean Baptiste Lemoyne	2020-05-27 16:40:00	2020-05-27 18:45:00	\N	\N	0	0	\N	\N
379323	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Recouvrement des amendes de circulation - DINSIC	Contrôle 2019 - Recouvrement des amendes de circulation - DINSIC	2019-05-14 13:30:00	2019-05-14 14:30:00	\N	\N	2	0	\N	\N
380164	MISSION	AUCUNE	\N	BREXIT2	\N	Réunion du 15 mai 2019	Réunion du 15 mai 2019	2019-05-15 15:05:00	2019-05-15 16:25:00	2019-05-17 17:00:17	\N	8	0	\N	\N
381733	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	211	Réunion de travail sur l'organisation de la célébration du 20ème anniversaire de la DDF	Réunion de travail sur l'organisation de la célébration du 20ème anniversaire de la DDF	2019-05-21 13:00:00	2019-05-21 14:45:00	\N	\N	4	0	\N	\N
382613	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-05-28 10:15:00	2019-05-28 10:35:00	2019-05-28 11:46:22	2019-05-28 17:02:57	30	2	\N	\N
382614	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-05-28 15:05:00	2019-05-28 16:30:00	2019-05-28 16:41:46	2019-05-28 17:02:58	43	0	\N	\N
382615	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-05-29 10:00:00	2019-05-29 11:50:00	2019-05-29 14:36:02	2019-05-29 15:17:09	28	0	\N	\N
382645	MISSION	AUDRAP	\N	TRANSPORTS	\N	MIGT	\N	2019-05-22 14:00:00	2019-05-22 16:50:00	\N	\N	2	0	\N	\N
382646	MISSION	AUCUNE	\N	TRANSPORTS	\N	MIGT - Auditions RATP et SNCF	\N	2019-05-23 11:05:00	2019-05-23 13:25:00	2019-05-27 12:05:32	2019-05-27 14:49:30	9	0	\N	\N
382700	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Sécurité Sapeurs-pompiers	\N	2019-05-23 10:30:00	2019-05-23 12:00:00	\N	\N	3	0	\N	\N
382713	MISSION	AUCUNE	\N	SIDERURGIE	\N	Plénière - Auditions	\N	2019-05-22 14:15:00	2019-05-22 17:00:00	2019-05-23 16:55:14	2019-05-23 17:09:02	12	0	\N	\N
382730	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Mme Saint-Pé PPL Précarité énergétique	\N	2019-05-23 15:00:00	2019-05-23 16:45:00	\N	\N	2	0	\N	\N
382828	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Transformation de la fonction publique	\N	2019-05-24 09:00:00	2019-05-24 11:40:00	\N	\N	1	0	\N	\N
382831	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Transformation de la fonction publique	\N	2019-05-24 14:30:00	2019-05-24 18:30:00	\N	\N	1	0	\N	\N
383088	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	DSOM	Colloque "Biodiversités du bassin Atlantique"	Colloque "Biodiversités du bassin Atlantique"	2019-06-06 14:40:00	2019-06-06 19:15:00	\N	\N	7	0	\N	\N
384147	COM_EURO	DEPLACEMENT	\N	AFEU	\N	Réunion OMC	Réunion OMC	2019-05-26 17:00:00	2019-05-28 16:00:00	\N	\N	1	0	\N	\N
399887	ETUDES	AUCUNE	\N	\N	\N	Audition dopage	Audition dopage	2019-07-10 08:30:00	2019-07-10 10:30:00	\N	\N	3	0	\N	912
401557	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-07-17 09:35:00	2019-07-17 11:30:00	2019-07-17 11:43:44	2019-07-17 12:33:20	35	0	\N	\N
402962	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Pastoralisme	\N	2019-07-18 13:45:00	2019-07-18 15:00:00	\N	\N	6	0	\N	\N
404987	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-09-11 11:20:00	2019-09-11 12:50:00	2019-09-11 14:37:55	2019-09-12 15:33:55	18	0	\N	\N
404988	MISSION	DEPLACEMENT	\N	MARITIME	\N	MCI Sauvetage en mer - Déplacement Alpes-Maritimes	MCI Sauvetage en mer - Déplacement Alpes-Maritimes	2019-08-05 08:00:00	2019-08-05 22:00:00	\N	\N	8	0	\N	\N
404997	MISSION	DEPLACEMENT	\N	MARITIME	\N	MCI Sauvetage en mer - Déplacement Calvados	MCI Sauvetage en mer - Déplacement Calvados	2019-08-26 07:00:00	2019-08-26 21:00:00	\N	\N	7	0	\N	\N
405005	MISSION	DEPLACEMENT	\N	MARITIME	\N	MCI Sauvetage en mer - Déplacement Finistère	MCI Sauvetage en mer - Déplacement Finistère	2019-09-03 07:00:00	2019-09-03 21:50:00	\N	\N	8	0	\N	\N
405014	MISSION	DEPLACEMENT	\N	MARITIME	\N	MCI Sauvetage en mer - Déplacement Loire-Atlantique	MCI Sauvetage en mer - Déplacement Loire-Atlantique	2019-09-04 07:15:00	2019-09-04 20:25:00	\N	\N	5	0	\N	\N
405059	MISSION	AUCUNE	\N	MARITIME	\N	Auditions FIN et FFPP	Auditions FIN et FFPP	2019-09-17 14:35:00	2019-09-17 16:25:00	2019-09-17 17:26:28	2019-09-18 11:29:43	6	0	\N	\N
410787	DELEGATION	DEPLACEMENT	\N	\N	206	Déplacement à Toulouse-Visite du CNES, de la Cité de l'Espace , d'Aibus et du Booster Nova	Déplacement à Toulouse-Visite du CNES, de la Cité de l'Espace , d'Aibus et du Booster Nova	2019-10-02 12:00:00	2019-10-03 20:00:00	\N	\N	7	0	\N	\N
410820	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Sport - le mouvement associatif 	PLF pour 2020 - Sport - le mouvement associatif 	2019-10-01 14:30:00	2019-10-01 15:30:00	\N	\N	1	0	\N	\N
410822	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Sport - DJEPVA	PLF pour 2020 - Sport - DJEPVA	2019-10-02 16:00:00	2019-10-02 17:00:00	\N	\N	1	0	\N	\N
412265	DELEGATION	AUCUNE	\N	\N	COLTER	Table ronde France urbaine + Communication J. Costes	\N	2019-10-16 16:45:00	2019-10-16 18:45:00	2019-10-16 19:37:16	\N	8	0	\N	\N
415013	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Travailleurs indépendants	\N	2019-10-15 14:30:00	2019-10-15 16:00:00	\N	\N	3	0	\N	\N
415014	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2019-10-15 14:30:00	2019-10-15 16:00:00	\N	\N	0	0	\N	\N
415045	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Assurance maladie	\N	2019-10-15 15:00:00	2019-10-15 16:00:00	\N	\N	2	0	\N	\N
415090	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Assurance maladie	\N	2019-10-15 16:00:00	2019-10-15 17:00:00	\N	\N	2	0	\N	\N
415093	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 23 octobre 2019 - communication sur l'Arctique et communication APCE	\N	2019-10-23 13:45:00	2019-10-23 14:50:00	2019-10-23 15:19:30	2019-10-23 16:36:20	17	0	\N	\N
415094	COM_EURO	AUTRE	\N	AFEU	\N	Communication	\N	2019-10-23 12:30:00	2019-10-23 13:00:00	\N	\N	0	0	\N	\N
415095	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 17 octobre 2019 - Commission des Affaires européennes	Réunion du 17 octobre 2019 - Commission des Affaires européennes	2019-10-17 08:30:00	2019-10-17 10:10:00	2019-10-17 15:19:23	2019-10-17 15:56:33	15	0	\N	\N
415099	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL AVIA	\N	2019-10-15 14:30:00	2019-10-15 16:30:00	\N	\N	2	0	\N	\N
415100	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL AVIA	\N	2019-10-15 16:30:00	2019-10-15 18:30:00	\N	\N	1	0	\N	\N
415251	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition branche Famille	\N	2019-10-24 09:30:00	2019-10-24 11:30:00	\N	\N	1	0	\N	\N
417523	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2019-10-01 16:35:00	2019-10-01 17:55:00	\N	\N	2	0	\N	\N
417532	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2019-10-08 15:05:00	2019-10-08 17:00:00	\N	\N	3	0	\N	\N
420305	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Prestation de compensation du handicap	\N	2019-10-23 16:30:00	2019-10-23 17:30:00	\N	\N	2	0	\N	\N
413357	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion de la commission	Réunion de la commission	2019-10-16 09:00:00	2019-10-16 12:15:00	2019-10-16 12:32:50	2019-10-16 17:31:00	46	0	\N	\N
478963	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule Énergie - SFEN	Covid-19 - cellule Énergie - SFEN	2020-06-16 15:30:00	2020-06-16 16:00:00	\N	\N	3	0	\N	\N
478990	MISSION	AUDRAP	\N	DEPARTEMENT	\N	Audition de Mmes Chavrier et Long	Audition de Mmes Chavrier et Long	2020-06-18 10:30:00	2020-06-18 12:15:00	\N	\N	8	0	\N	\N
479089	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Fin état d'urgence sanitaire	PJL Fin état d'urgence sanitaire	2020-06-22 17:00:00	2020-06-22 18:15:00	\N	\N	26	0	\N	\N
479090	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Fin état d'urgence sanitaire	PJL Fin état d'urgence sanitaire	2020-06-22 21:30:00	2020-06-22 23:35:00	\N	\N	29	0	\N	\N
479091	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Débat Projet d'annexion de la vallée du Jourdain	Débat Projet d'annexion de la vallée du Jourdain	2020-06-24 21:30:00	2020-06-24 23:05:00	\N	\N	27	0	\N	\N
479092	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR Nouvelle ère de la decentralisation	PPR Nouvelle ère de la decentralisation	2020-06-25 09:00:00	2020-06-25 10:40:00	\N	\N	42	0	\N	\N
479100	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Deuxième lecture PPL retraite agricole	Deuxième lecture PPL retraite agricole	2020-06-29 16:00:00	2020-06-29 17:50:00	\N	\N	21	0	\N	\N
479110	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR CE grandes pandémies	PPR CE grandes pandémies	2020-06-30 15:10:00	2020-06-30 15:30:00	\N	\N	74	0	\N	\N
479111	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Alimentatation durable	Débat Alimentatation durable	2020-06-30 21:30:00	2020-06-30 23:05:00	\N	\N	41	0	\N	\N
479183	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJLO PJL Dette sociale et autonomie	PJLO PJL Dette sociale et autonomie	2020-07-01 16:30:00	2020-07-01 21:20:00	\N	\N	62	0	\N	\N
479186	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Fin état d'urgence sanitaire	PJL Fin état d'urgence sanitaire	2020-07-02 10:30:00	2020-07-02 11:25:00	\N	\N	20	0	\N	\N
479193	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Démarchage téléphonique	CMP Démarchage téléphonique	2020-07-08 16:40:00	2020-07-08 17:35:00	\N	\N	40	0	\N	\N
479195	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Règlement, budget et comptes année 2019	PJL Règlement, budget et comptes année 2019	2020-07-08 17:35:00	2020-07-08 18:50:00	\N	\N	42	0	\N	\N
479198	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL DADUE	PJL DADUE	2020-07-08 19:00:00	2020-07-08 20:00:00	\N	\N	28	0	\N	\N
479199	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFR 2020	PLFR 2020	2020-07-18 09:30:00	2020-07-18 13:00:00	\N	\N	66	0	\N	\N
479200	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFR 2020	PLFR 2020	2020-07-18 14:30:00	2020-07-18 20:00:00	\N	\N	67	0	\N	\N
479201	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFR 2020	PLFR 2020	2020-07-19 10:00:00	2020-07-19 12:00:00	\N	\N	43	0	\N	\N
479202	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat orientation des finances publiques - PLFR	Débat orientation des finances publiques - PLFR	2020-07-23 15:00:00	2020-07-23 18:00:00	\N	\N	23	0	\N	\N
479203	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFR 2020	PLFR 2020	2020-07-18 21:00:00	2020-07-18 23:30:00	\N	\N	49	0	\N	\N
479204	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFR 2020	PLFR 2020	2020-07-17 11:00:00	2020-07-17 13:00:00	\N	\N	58	0	\N	\N
479205	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFR 2020	PLFR 2020	2020-07-17 14:30:00	2020-07-17 20:00:00	\N	\N	67	0	\N	\N
479206	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFR 2020	PLFR 2020	2020-07-17 21:00:00	2020-07-17 23:30:00	\N	\N	52	0	\N	\N
479207	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Peines d'emprisonnement en Nouvelle-Calédonie	PPL Peines d'emprisonnement en Nouvelle-Calédonie	2020-07-21 14:30:00	2020-07-21 20:00:00	\N	\N	37	0	\N	\N
479208	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Peines d'emprisonnement en Nouvelle-Calédonie	PPL Peines d'emprisonnement en Nouvelle-Calédonie	2020-07-21 21:00:00	2020-07-21 21:30:00	\N	\N	0	0	\N	\N
479211	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL protéger les victimes de violences conjugales	PPL protéger les victimes de violences conjugales	2020-07-21 15:15:00	2020-07-21 16:00:00	\N	\N	67	0	\N	\N
477743	COM_ENQUETE	PLENIERE	\N	RADICALI	\N	Auditions plénières - Représentants du CCIF - Jean-Michel Blanquer, ministre	Auditions plénières - Représentants du CCIF - Jean-Michel Blanquer, ministre	2020-06-18 09:30:00	2020-06-18 12:30:00	2020-06-18 15:56:23	2020-06-18 17:29:07	9	0	\N	\N
479212	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL protéger les victimes de violences conjugales	PPL protéger les victimes de violences conjugales	2020-07-21 21:30:00	2020-07-21 22:00:00	\N	\N	0	0	\N	\N
479213	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJLO Mandat CESE	PJLO Mandat CESE	2020-07-23 10:30:00	2020-07-23 13:00:00	\N	\N	24	0	\N	\N
479215	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Infractions terroristes	PPL Infractions terroristes	2020-07-21 15:20:00	2020-07-21 17:00:00	\N	\N	61	0	\N	\N
479216	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Infractions terroristes	PPL Infractions terroristes	2020-07-21 22:00:00	2020-07-21 23:00:00	\N	\N	0	0	\N	\N
479217	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2020-06-18 09:00:00	2020-06-18 12:30:00	\N	\N	1	0	\N	\N
479246	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Règlement, budget et comptes année 2019	PJL Règlement, budget et comptes année 2019	2020-07-22 21:00:00	2020-07-22 23:00:00	\N	\N	0	0	\N	\N
479247	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Don de chèques vacances	PPL Don de chèques vacances	2020-07-22 17:50:00	2020-07-22 20:00:00	\N	\N	28	0	\N	\N
479248	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Don de chèques vacances	PPL Don de chèques vacances	2020-07-22 21:40:00	2020-07-22 23:00:00	\N	\N	0	0	\N	\N
479249	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJLO PJL Dette sociale et autonomie	PJLO PJL Dette sociale et autonomie	2020-07-22 22:00:00	2020-07-22 23:00:00	\N	\N	0	0	\N	\N
479250	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Règlement, budget et comptes année 2019	PJL Règlement, budget et comptes année 2019	2020-07-22 16:40:00	2020-07-22 20:00:00	\N	\N	32	0	\N	\N
479251	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJLO PJL Dette sociale et autonomie	PJLO PJL Dette sociale et autonomie	2020-07-22 17:30:00	2020-07-22 20:00:00	\N	\N	25	0	\N	\N
479252	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFR 2020	PLFR 2020	2020-07-23 14:30:00	2020-07-23 20:00:00	\N	\N	24	0	\N	\N
479258	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2020-07-01 15:00:00	2020-07-01 16:20:00	\N	\N	185	0	\N	\N
393673	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation de parlementaires taïwanais	\N	2019-05-27 05:30:00	2019-05-30 22:00:00	\N	\N	7	0	623	\N
393681	GIA	AUCUNE	\N	\N	\N	Rencontre avec M. Chiang, directeur des affaires européennes au MOFA	\N	2019-06-20 09:00:00	2019-06-20 09:45:00	\N	\N	1	0	623	\N
399937	MISSION	AUDRAP	\N	AERIEN	\N	\N	\N	2019-07-09 09:00:00	2019-07-09 10:30:00	\N	\N	3	0	\N	\N
408106	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2019-09-24 19:30:00	2019-09-24 20:25:00	\N	\N	25	0	\N	\N
422441	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GS Stratégie industrielle de l'UE	GS Stratégie industrielle de l'UE - Audition de M. Thomas Courbe, directeur général - Direction générale des entreprises	2019-10-29 17:05:00	2019-10-29 17:55:00	\N	\N	5	0	\N	\N
425785	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	1281	\N	\N	Explications de vote sur l'ensemble	Explications de vote sur l'ensemble	2019-12-10 14:32:00	2019-12-10 16:32:00	\N	\N	276	0	\N	\N
425835	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2020 - Avis Justice judiciaire	PLF pour 2020 - Avis Justice judiciaire	2019-11-12 15:15:00	2019-11-12 16:00:00	\N	\N	1	0	\N	\N
425837	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2020 - Avis Développement des entreprises	PLF pour 2020 - Avis Développement des entreprises	2019-11-12 14:00:00	2019-11-12 18:00:00	\N	\N	1	0	\N	\N
425839	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition entreprises responsables et engagées	Audition entreprises responsables et engagées - CPME	2019-11-12 14:05:00	2019-11-12 15:00:00	\N	\N	2	0	\N	\N
425842	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition entreprises responsables et engagées	Audition entreprises responsables et engagées - ESS-France	2019-11-12 15:00:00	2019-11-12 16:10:00	\N	\N	2	0	\N	\N
425845	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition entreprises responsables et engagées	Audition entreprises responsables et engagées - Haut-commissaire à l'economie sociale et solidaire 	2019-11-12 16:10:00	2019-11-12 17:15:00	\N	\N	2	0	\N	\N
425848	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition entreprises responsables et engagées	Audition entreprises responsables et engagées - France Active	2019-11-12 17:15:00	2019-11-12 18:30:00	\N	\N	2	0	\N	\N
425851	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition difficultés de recrutement et évolution des métiers	Audition difficultés de recrutement et évolution des métiers- Pôle Emploi, departement observatoire de l'emploi	2019-11-05 10:00:00	2019-11-05 11:00:00	\N	\N	3	0	\N	\N
425855	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition difficultés de recrutement et évolution des métiers	Audition difficultés de recrutement et évolution des métiers - Plateforme RSE de FRANCE STRATÉGIE	2019-11-05 14:00:00	2019-11-05 15:30:00	\N	\N	2	0	\N	\N
425858	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition difficultés de recrutement et évolution des métiers	Audition difficultés de recrutement et évolution des métiers -  \tORSE	2019-11-05 15:30:00	2019-11-05 16:30:00	\N	\N	2	0	\N	\N
425861	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition difficultés de recrutement et évolution des métiers	Audition difficultés de recrutement et évolution des métiers	2019-11-05 17:00:00	2019-11-05 18:15:00	\N	\N	2	0	\N	\N
427647	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2020 - Avis Développement des entreprises	PLF pour 2020 - Avis Développement des entreprises	2019-11-13 16:30:00	2019-11-13 19:15:00	\N	\N	1	0	\N	\N
431920	GIA	AUCUNE	\N	\N	\N	Déjeuner de travail 	Déjeuner de travail avec Mme Marie-Pierre Giron, chef de la mission d'Océanie au ministère des affaires étrangères	2019-11-26 12:30:00	2019-11-26 14:10:00	\N	\N	5	0	651	\N
434009	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Prévention du suicide des agriculteurs	Auditions Mme Férat - PPL prévention du suicide des agriculteurs	2019-11-27 13:30:00	2019-11-27 14:45:00	\N	\N	2	0	\N	\N
434094	ETUDES	AUTRE	\N	\N	\N	GEAC - Audition Airbus	GEAC - Audition Airbus	2019-11-28 08:30:00	2019-11-28 10:00:00	\N	\N	8	0	\N	933
434347	COM_PERMANENTE	DEPLACEMENT	\N	SOCI	\N	Déplacement - PPL Usages dangereux du protoxyde d'azote	\N	2019-11-28 08:00:00	2019-11-28 16:00:00	\N	\N	3	0	\N	\N
434352	COM_SPECIALE	AUDRAP	\N	BIOETHIQUE	\N	Audition M. Jomier Associations art 20 et 21	\N	2019-11-28 16:30:00	2019-11-28 17:15:00	\N	\N	1	0	\N	\N
435247	DELEGATION	AUCUNE	\N	\N	211	Résultats de l'enquête Virage Dom en Guadeloupe et en Martinique	Résultats de l'enquête Virage Dom en Guadeloupe et en Martinique	2019-12-12 09:30:00	2019-12-12 11:10:00	2019-12-12 13:32:02	\N	11	0	\N	\N
435330	COM_SPECIALE	AUDRAP	\N	BIOETHIQUE	\N	Audition Mme Imbert	\N	2019-12-04 16:30:00	2019-12-04 17:45:00	\N	\N	4	0	\N	\N
435341	COM_SPECIALE	AUDRAP	\N	BIOETHIQUE	\N	Audition Mme Imbert	\N	2019-12-11 16:30:00	2019-12-11 19:00:00	\N	\N	2	0	\N	\N
436940	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-12-11 10:20:00	2019-12-11 11:50:00	2019-12-11 12:38:47	2019-12-11 14:26:15	37	0	\N	\N
439795	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-12-18 10:35:00	2019-12-18 11:45:00	2019-12-18 14:59:41	2019-12-18 15:32:33	32	0	\N	\N
439909	COM_SPECIALE	AUDRAP	\N	BIOETHIQUE	\N	Audition M. Jomier & Mme Jourda UNAF	\N	2019-12-11 17:50:00	2019-12-11 18:50:00	\N	\N	2	0	\N	\N
439914	COM_SPECIALE	AUDRAP	\N	BIOETHIQUE	\N	Maladies rares du développement génital - Associations - M. Jomier	\N	2019-12-12 15:30:00	2019-12-12 17:10:00	\N	\N	2	0	\N	\N
439933	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL suivi EGALIM - Auditions M. Raison	PPL Préserver l'activité des entreprises alimentaires françaises	2019-12-10 16:45:00	2019-12-10 19:00:00	\N	\N	3	0	\N	\N
439937	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL suivi EGALIM - Auditions M. Raison	PPL suivi EGALIM - Auditions M. Raison	2019-12-11 16:30:00	2019-12-11 17:00:00	\N	\N	5	0	\N	\N
439944	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL suivi EGALIM - Auditions M. Raison	PPL suivi EGALIM - Auditions M. Raison	2019-12-11 17:00:00	2019-12-11 17:20:00	\N	\N	5	0	\N	\N
439950	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL suivi EGALIM - Auditions M. Raison	PPL suivi EGALIM - Auditions M. Raison	2019-12-11 17:20:00	2019-12-11 17:50:00	\N	\N	5	0	\N	\N
439956	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL suivi EGALIM - Auditions M. Raison	PPL suivi EGALIM - Auditions M. Raison	2019-12-11 17:50:00	2019-12-11 18:15:00	\N	\N	5	0	\N	\N
439962	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL suivi EGALIM - Auditions M. Raison	PPL suivi EGALIM - Auditions M. Raison	2019-12-11 18:15:00	2019-12-11 18:45:00	\N	\N	5	0	\N	\N
439968	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL suivi EGALIM - Auditions M. Raison	PPL suivi EGALIM - Auditions M. Raison	2019-12-11 18:45:00	2019-12-11 19:15:00	\N	\N	3	0	\N	\N
439972	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL suivi EGALIM - Auditions M. Raison	PPL suivi EGALIM - Auditions M. Raison	2019-12-16 14:00:00	2019-12-16 16:00:00	\N	\N	1	0	\N	\N
439974	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Immigration, asile et intégration - OFIII	PLF pour 2020 - Immigration, asile et intégration - OFIII	2019-12-17 10:00:00	2019-12-17 11:00:00	\N	\N	1	0	\N	\N
440256	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-12-18 09:31:00	2019-12-18 11:20:00	2019-12-18 11:52:49	2019-12-18 12:14:58	31	0	\N	\N
473396	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Annulation second tour conseillers municipaux	PJL Annulation second tour conseillers municipaux	2020-06-10 17:30:00	2020-06-10 20:35:00	\N	\N	58	0	\N	\N
473406	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2020-06-16 09:30:00	2020-06-16 12:45:00	\N	\N	34	0	\N	\N
473407	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Dons de congés payés	PPL Dons de congés payés	2020-06-16 14:30:00	2020-06-16 16:05:00	\N	\N	42	0	\N	\N
473409	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2020-06-17 15:00:00	2020-06-17 16:20:00	\N	\N	121	0	\N	\N
473410	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJLO Report élections sénatoriales	PJLO Report élections sénatoriales	2020-06-17 16:40:00	2020-06-17 18:50:00	\N	\N	50	0	\N	\N
473414	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PJL Sécuriser l¿organisation du second tour 	CMP PJL Sécuriser l¿organisation du second tour des élections municipales	2020-06-17 18:50:00	2020-06-17 19:35:00	\N	\N	26	0	\N	\N
473418	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Situation logement	Débat Situation du logement	2020-06-23 14:30:00	2020-06-23 16:15:00	\N	\N	46	0	\N	\N
473419	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Bilan application des lois	Débat Bilan application des lois	2020-06-23 17:35:00	2020-06-23 19:10:00	\N	\N	44	0	\N	\N
473420	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Conseil européen des 18 et 19 juin	DébatDébat Conseil européen des 18 et 19 juin	2020-06-23 21:30:00	2020-06-23 23:35:00	\N	\N	29	0	\N	\N
473421	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2020-06-24 15:00:00	2020-06-24 16:10:00	\N	\N	162	0	\N	\N
473422	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Droit des victimes	PPL Droit des victimes	2020-06-24 18:00:00	2020-06-24 19:00:00	\N	\N	34	0	\N	\N
473423	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR Encourager le développement de l¿assurance récolte	PPR Encourager le développement de l¿assurance récolte	2020-06-24 16:30:00	2020-06-24 17:55:00	\N	\N	39	0	\N	\N
473425	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Fonds d'indemnisation victimes covid-19	PPL Fonds d'indemnisation victimes covid-19	2020-06-25 10:40:00	2020-06-25 12:00:00	\N	\N	42	0	\N	\N
473426	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Exploitation image d'enfants	PPL Exploitation image d'enfants	2020-06-25 14:30:00	2020-06-25 15:50:00	\N	\N	22	0	\N	\N
473427	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Statut citoyen sauveteur	PPL Statut citoyen sauveteur	2020-06-25 15:50:00	2020-06-25 16:40:00	\N	\N	17	0	\N	\N
473428	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Difficultés de recrutement des entreprises	Débat Difficultés de recrutement des entreprises	2020-06-25 18:30:00	2020-06-25 20:10:00	\N	\N	18	0	\N	\N
473435	SEANCE_PLENIERE	ELOGE_FUNEBRE	\N	\N	\N	Éloge funèbre Alain Bertrand	Éloge funèbre Alain Bertrand	2020-06-30 14:30:00	2020-06-30 14:50:00	\N	\N	22	0	\N	\N
502346	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2021	PLF pour 2021	2020-12-02 14:50:00	2020-12-02 20:20:00	\N	\N	158	0	\N	\N
436938	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-12-11 09:35:00	2019-12-11 10:20:00	2019-12-11 12:37:40	2019-12-11 14:26:15	37	0	\N	\N
473436	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Fonds d'urgence Français de l'étranger	PPL Fonds d'urgence Français de l'étranger	2020-06-30 17:05:00	2020-06-30 19:30:00	\N	\N	58	0	\N	\N
473720	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	Covid-19-Climat-M. François GEMENNE, chercheur en sciences politiques	Covid-19-Climat-M. François GEMENNE, chercheur en sciences politiques	2020-04-15 16:30:00	2020-04-15 17:30:00	\N	\N	6	0	\N	\N
473950	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	Covid-19-Climat-Haut conseil pour le climat	Covid-19-Climat-Haut conseil pour le climat	2020-04-30 15:00:00	2020-04-30 16:10:00	\N	\N	5	0	\N	\N
474327	COM_PERMANENTE	AUTRE	\N	LOIS	\N	\N	\N	2020-06-03 08:50:00	2020-06-03 10:30:00	2020-06-03 10:58:33	2020-06-05 18:19:30	34	0	\N	\N
474918	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-06-10 09:30:00	2020-06-10 11:25:00	2020-06-10 11:27:36	2020-06-10 18:07:13	37	0	\N	\N
474919	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-06-10 16:15:00	2020-06-10 18:00:00	\N	\N	0	0	\N	\N
475000	DELEGATION	AUDRAP	\N	\N	206	Entretien avec M. Greg Clark, président du Science & Technology Committee 	Entretien avec M. Greg Clark président du Science & Technology Committee de la Chambre des communes	2020-06-04 15:00:00	2020-06-04 16:30:00	\N	\N	1	0	\N	\N
475033	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule Énergie - EDF	\N	2020-04-09 17:30:00	2020-04-09 18:40:00	\N	\N	3	0	\N	\N
475037	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule Énergie - Union française de l'électricité	\N	2020-04-10 17:30:00	2020-04-10 18:30:00	\N	\N	3	0	\N	\N
475041	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule Énergie - Anode	\N	2020-04-14 17:00:00	2020-04-14 18:00:00	\N	\N	5	0	\N	\N
475118	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule Énergie - Agence internationale de l'énergie	\N	2020-04-16 17:00:00	2020-04-16 18:00:00	\N	\N	4	0	\N	\N
475124	MISSION	AUDRAP	\N	FEDERATION	\N	Audition Centre Droit et économie du sport	Audition Centre Droit et économie du sport	2020-06-03 14:00:00	2020-06-03 15:00:00	\N	\N	15	0	\N	\N
475175	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule Énergie - Total	\N	2020-04-17 17:30:00	2020-04-17 18:50:00	\N	\N	6	0	\N	\N
475192	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule Énergie - Médiateur national de l'énergie	\N	2020-04-21 17:00:00	2020-04-21 18:20:00	\N	\N	3	0	\N	\N
475215	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule Énergie - AFG - FGR	\N	2020-04-23 17:00:00	2020-04-23 18:15:00	\N	\N	2	0	\N	\N
475223	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule Énergie - SNPAA	\N	2020-04-24 17:00:00	2020-04-24 18:20:00	\N	\N	4	0	\N	\N
475250	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule Énergie - GrDF	\N	2020-05-13 17:00:00	2020-05-13 18:00:00	\N	\N	2	0	\N	\N
475254	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule Énergie - EpE	\N	2020-05-12 17:00:00	2020-05-12 18:20:00	\N	\N	4	0	\N	\N
475255	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule Énergie - Capeb	\N	2020-05-06 17:00:00	2020-05-06 18:30:00	\N	\N	3	0	\N	\N
475256	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule Énergie - Haut Conseil pour le climat	\N	2020-05-05 17:00:00	2020-05-05 18:30:00	\N	\N	11	0	\N	\N
475257	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule Énergie - Air liquide	\N	2020-05-29 16:30:00	2020-05-29 17:50:00	\N	\N	10	0	\N	\N
475486	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition I4CE et AFIEG et Dyneff	\N	2020-04-29 17:00:00	2020-04-29 19:30:00	\N	\N	2	0	\N	\N
475504	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule Énergie - Afieg	\N	2020-04-29 18:10:00	2020-04-29 18:40:00	\N	\N	3	0	\N	\N
475508	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule Énergie - Dyneff	\N	2020-04-29 18:40:00	2020-04-29 19:30:00	\N	\N	3	0	\N	\N
475526	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions cellule PME Rakuten	Audition cellule PME commerce artisanat	2020-06-03 14:30:00	2020-06-03 15:30:00	\N	\N	4	0	\N	\N
475547	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule Énergie - Cooperl environnement	\N	2020-05-29 16:30:00	2020-05-29 17:50:00	\N	\N	5	0	\N	\N
475557	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule industrie - France industrie	\N	2020-04-08 14:15:00	2020-04-08 14:55:00	\N	\N	3	0	\N	\N
475561	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule industrie - France chimie	\N	2020-05-08 17:10:00	2020-05-08 17:50:00	\N	\N	3	0	\N	\N
475565	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule industrie - Fédération des industries mécaniques (FIM)	\N	2020-04-09 16:30:00	2020-04-09 17:05:00	\N	\N	3	0	\N	\N
475569	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule industrie - Plateforme française automobile (PFA)	\N	2020-04-09 17:10:00	2020-04-09 17:45:00	\N	\N	3	0	\N	\N
377351	COM_PERMANENTE	DEPLACEMENT	\N	CDD	\N	Déplacement dans le Doubs-PJL Organisation du système de santé	Déplacement dans le Doubs - PJL Organisation du système de santé	2019-05-13 08:00:00	2019-05-13 22:00:00	\N	\N	2	0	\N	\N
377414	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2019 - Les sources de financement du logement social - Déplacement Londres	Contrôle 2019 - Les sources de financement du logement social - Déplacement Londres	2019-05-13 07:15:00	2019-05-13 21:20:00	\N	\N	1	0	\N	\N
388106	SEANCE_PLENIERE	DECL_GVT	\N	\N	\N	Lecture d'une déclaratin de politique générale	Lecture d'une déclaratin de politique générale	2019-06-12 15:00:00	2019-06-12 16:20:00	\N	\N	247	0	\N	\N
388119	SEANCE_PLENIERE	DECL_GVT	\N	\N	\N	Déclaration de politique générale du Gouvernement	Déclaration de politique générale du Gouvernement	2019-06-13 09:30:00	2019-06-13 12:20:00	\N	\N	246	0	\N	\N
389964	SEANCE_PLENIERE	AUTRE	\N	\N	\N	Application des lois	Débat annuel sur le bilan de l'application des lois	2019-06-12 08:00:00	2019-06-12 09:30:00	\N	\N	43	0	\N	\N
410795	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière	Réunion plénière	2019-10-17 09:40:00	2019-10-17 12:00:00	\N	\N	11	0	\N	\N
410796	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution plastique	Audition rapporteurs Pollution plastique (Table ronde Industries alimentaires)	2019-10-16 16:15:00	2019-10-16 18:00:00	\N	\N	2	0	\N	\N
410797	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution plastique	Audition rapporteurs Pollution plastique (Elipso)	2019-10-16 18:15:00	2019-10-16 19:45:00	\N	\N	2	0	\N	\N
410798	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution plastique 	Audition rapporteurs Pollution plastique (Table ronde grande distribution)	2019-10-22 15:30:00	2019-10-22 17:00:00	\N	\N	2	0	\N	\N
410800	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution plastique	Audition rapporteurs Pollution plastique (ANSES)	2019-10-30 16:15:00	2019-10-30 17:15:00	\N	\N	2	0	\N	\N
410801	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution plastique	Audition rapporturs Pollution plastique (M. Matthieu Combe)	2019-10-30 17:30:00	2019-10-30 18:30:00	\N	\N	2	0	\N	\N
410802	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution plastique	Audition rapporteurs Pollution plastique (Table ronde Bâtiment)	2019-10-31 09:00:00	2019-10-31 10:45:00	\N	\N	2	0	\N	\N
480797	MISSION	AUDRAP	\N	GUYANE	\N	Auditions DGDDID, DNRED et M. Frédéric Veaux	\N	2020-06-29 14:30:00	2020-06-29 16:30:00	\N	\N	8	0	\N	\N
410803	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution plastique	Audition rapporteurs Pollution plastique (Table ronde Automobile)	2019-10-31 11:00:00	2019-10-31 12:45:00	\N	\N	2	0	\N	\N
410805	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Espace - Audition	GT Espace - Audition de représentants de l'Agence spatiale européenne	2019-10-02 17:30:00	2019-10-02 18:30:00	\N	\N	7	0	\N	\N
410813	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Espace - Audition	GT Espace - Audition de représentants de la Direction générale de l'armement	2019-10-02 18:30:00	2019-10-02 19:15:00	\N	\N	6	0	\N	\N
420273	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Enseignement scolaire	PLF 2020 - Crédits Enseignement scolaire	2019-10-23 16:30:00	2019-10-23 18:30:00	\N	\N	1	0	\N	\N
420274	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Assurance maladie	\N	2019-10-23 18:00:00	2019-10-23 19:30:00	\N	\N	2	0	\N	\N
420285	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Assurance maladie	\N	2019-10-23 17:00:00	2019-10-23 18:00:00	\N	\N	1	0	\N	\N
420306	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Prestation de compensation du handicap	\N	2019-10-23 14:15:00	2019-10-23 15:00:00	\N	\N	2	0	\N	\N
420397	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Cohésion des territoires - Logement et urbanisme - Action logement	PLF pour 2020 - Cohésion des territoires - Logement et urbanisme - Action logement	2019-10-21 09:00:00	2019-10-21 10:00:00	\N	\N	1	0	\N	\N
420400	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 2019 - L'Agence nationale pour la rénovation urbaine - Cour des comptes	58-2 2019 - L'Agence nationale pour la rénovation urbaine - Cour des comptes	2019-10-21 11:00:00	2019-10-21 12:00:00	\N	\N	1	0	\N	\N
420405	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Cohésion des territoires - Logement et urbanisme - ANAH	PLF pour 2020 - Cohésion des territoires - Logement et urbanisme - ANAH	2019-10-22 09:00:00	2019-10-22 10:00:00	\N	\N	1	0	\N	\N
420407	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Cohésion des territoires - Logement et urbanisme - Fondation Abbé PIERRE	PLF pour 2020 - Cohésion des territoires - Logement et urbanisme - Fondation Abbé PIERRE	2019-10-23 14:00:00	2019-10-23 15:10:00	\N	\N	1	0	\N	\N
420409	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Cohésion des territoires - Logement et urbanisme - NEXEM	PLF pour 2020 - Cohésion des territoires - Logement et urbanisme - NEXEM	2019-10-23 17:00:00	2019-10-23 17:45:00	\N	\N	1	0	\N	\N
420419	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Culture - IGF et IGAC	PLF pour 2020 - Culture - IGF et IGAC	2019-10-18 16:00:00	2019-10-18 17:00:00	\N	\N	1	0	\N	\N
420421	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 -  Médias, livre et industries culturelles - SNEP / CNC	PLF pour 2020 -  Médias, livre et industries culturelles - SNEP / CNC	2019-10-21 10:00:00	2019-10-21 11:30:00	\N	\N	1	0	\N	\N
420433	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFSS pour 2020 - Cour des comptes	PLFSS pour 2020 - Cour des comptes	2019-10-22 13:00:00	2019-10-22 14:00:00	\N	\N	1	0	\N	\N
420483	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Culture - Ministère DGCA	PLF pour 2020 - Culture - Ministère DGCA	2019-10-22 18:30:00	2019-10-22 19:45:00	\N	\N	2	0	\N	\N
420499	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFSS pour 2020 - Direction  de la sécurité sociale	PLFSS pour 2020 - Direction de la sécurité sociale	2019-10-23 10:00:00	2019-10-23 10:45:00	\N	\N	1	0	\N	\N
420503	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Culture (Création, Transmission, Démocratisation)	PLF 2020 - Crédits Culture (Création, Transmission, Démocratisation)	2019-10-23 16:15:00	2019-10-23 17:15:00	\N	\N	2	0	\N	\N
420509	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFSS pour 2020 - IGF / CCSS	PLFSS pour 2020 - IGF / CCSS	2019-10-23 17:00:00	2019-10-23 17:45:00	\N	\N	1	0	\N	\N
420514	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - CCE - CE et CNDA 	PLF pour 2020 - CCE - CE et CNDA 	2019-10-22 17:00:00	2019-10-22 18:00:00	\N	\N	1	0	\N	\N
420518	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - MIRES - Enseignement supérieur - CNOUS	PLF pour 2020 - MIRES - Enseignement supérieur - CNOUS	2019-10-22 10:00:00	2019-10-22 11:00:00	\N	\N	1	0	\N	\N
420520	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - DAG - IHEDN	PLF pour 2020 - DAG - IHEDN	2019-10-22 18:30:00	2019-10-22 19:45:00	\N	\N	1	0	\N	\N
420524	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - DAG - SIG / SGDSN	PLF pour 2020 - DAG - SIG / SGDSN	2019-10-23 17:00:00	2019-10-23 19:45:00	\N	\N	1	0	\N	\N
420529	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-10-30 10:05:00	2019-10-30 11:40:00	2019-10-30 11:38:17	2019-10-30 14:57:25	35	0	\N	\N
420531	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Écologie - Direction des affaires maritimes	PLF pour 2020 - Écologie - Direction des affaires maritimes	2019-10-22 09:00:00	2019-10-22 10:15:00	\N	\N	1	0	\N	\N
420533	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Écologie - IGN	PLF pour 2020 - Écologie - IGN	2019-10-22 18:00:00	2019-10-22 19:00:00	\N	\N	1	0	\N	\N
420535	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Écologie - CEREMA	PLF pour 2020 - Écologie - CEREMA	2019-10-23 18:30:00	2019-10-23 19:30:00	\N	\N	1	0	\N	\N
420537	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Écologie - ADP	PLF pour 2020 - Écologie - ADP	2019-10-24 09:00:00	2019-10-24 10:00:00	\N	\N	1	0	\N	\N
420539	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Écologie - FNAM	PLF pour 2020 - Écologie - FNAM	2019-10-24 10:30:00	2019-10-24 11:30:00	\N	\N	1	0	\N	\N
420541	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Écologie - DGAC	PLF pour 2020 - Écologie - DGAC	2019-10-24 14:30:00	2019-10-24 16:00:00	\N	\N	1	0	\N	\N
420543	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Défense - DB	PLF pour 2020 - Défense - DB	2019-10-22 11:00:00	2019-10-22 12:00:00	\N	\N	1	0	\N	\N
420545	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Défense - EMA	PLF pour 2020 - Défense - EMA	2019-10-24 14:30:00	2019-10-24 15:30:00	\N	\N	1	0	\N	\N
420546	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Économie - M. Serge Babary	\N	2019-10-24 09:45:00	2019-10-24 12:30:00	\N	\N	1	0	\N	\N
479260	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2020-07-08 15:00:00	2020-07-08 16:30:00	\N	\N	209	0	\N	\N
479261	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2020-07-16 18:00:00	2020-07-16 19:15:00	\N	\N	101	0	\N	\N
479262	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2020-07-22 15:00:00	2020-07-22 16:30:00	\N	\N	171	0	\N	\N
479847	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL Accord franco-suisse instruction militaire	\N	2020-06-23 17:05:00	2020-06-23 17:45:00	\N	\N	1	0	\N	\N
479881	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2020-06-24 09:03:00	2020-06-24 10:05:00	2020-06-25 09:43:59	2020-06-25 09:52:33	31	0	\N	\N
477745	COM_ENQUETE	PLENIERE	\N	RADICALI	\N	Audition de Gabriel Attal, secrétaire d'État	Audition de Gabriel Attal, secrétaire d'État auprès du ministre de l'éducation nationale et de la jeunesse	2020-06-19 10:30:00	2020-06-19 11:35:00	2020-06-19 11:50:04	2020-06-24 10:56:56	4	0	\N	\N
480003	MISSION	AUDRAP	\N	GUYANE	\N	MI Guyane - Audition association Aurore et Trop violans	\N	2020-06-25 15:30:00	2020-06-25 17:30:00	\N	\N	6	0	\N	\N
480811	MISSION	AUDRAP	\N	GUYANE	\N	Auditions de M. Jean-Marc Descoux et Mme Catherine Pignon	\N	2020-07-02 14:30:00	2020-07-02 16:30:00	\N	\N	5	0	\N	\N
480828	COM_EURO	AUDRAP	\N	AFEU	\N	Action européenne pour le climat	Action européenne pour le climat - Institut Jacques Delors	2020-04-24 18:00:00	2020-04-24 20:00:00	\N	\N	2	0	\N	\N
480833	COM_EURO	AUDRAP	\N	AFEU	\N	Mobilité des professionnels de santé	Mobilité des professionnels de santé - Conseil de l'ordre des Kinés	2020-05-12 14:30:00	2020-05-12 16:00:00	\N	\N	1	0	\N	\N
480853	COM_EURO	AUDRAP	\N	AFEU	\N	Mobilité des professionnels de santé	Mobilité des professionnels de santé - CE DG commerce	2020-05-15 11:00:00	2020-05-15 12:00:00	\N	\N	1	0	\N	\N
480855	COM_ENQUETE	PLENIERE	\N	RADICALI	\N	Echange de vues sur les orientations et le plan du rapport (en visioconférence)	Echange de vues sur les orientations et le plan du rapport (en visioconférence)	2020-06-29 09:30:00	2020-06-29 10:20:00	2020-06-29 10:26:32	2020-06-29 18:45:09	9	0	\N	\N
480856	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de M. Castaner	Audition de M. Castaner	2020-06-25 14:15:00	2020-06-25 16:00:00	2020-06-25 17:43:31	2020-06-26 09:39:25	7	0	\N	\N
480876	MISSION	AUDRAP	\N	DEPARTEMENT	\N	Audition de de CMA et CCI France	\N	2020-07-02 10:30:00	2020-07-02 11:30:00	\N	\N	5	0	\N	\N
480977	COM_PERMANENTE	AUTRE	\N	FINC	\N	PPL 312 Création d'un fonds d'urgence Français de l'étranger - Examen AMDTS Séance	PPL 312 Création d'un fonds d'urgence Français de l'étranger - Examen AMDTS Séance	2020-06-30 14:05:00	2020-06-30 14:10:00	2020-06-30 17:21:04	2020-06-30 17:24:29	12	0	\N	\N
481054	COM_EURO	AUDRAP	\N	AFEU	\N	Le cadre financier pluriannuel 2021-2027	Le cadre financier pluriannuel 2021-2027 - Direction du Budget	2020-06-04 16:30:00	2020-06-04 18:00:00	\N	\N	3	0	\N	\N
481058	COM_EURO	AUDRAP	\N	AFEU	\N	Cadre financier pluriannuel 2021-2027	Cadre financier pluriannuel 2021-2027 - Parlement européen	2020-06-05 14:30:00	2020-06-05 16:00:00	\N	\N	1	0	\N	\N
481067	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de Pierre MOSCOVICI - PPT CdC - situation et perspectives des finances publiques	Audition de Pierre MOSCOVICI - PPT CdC - Rapport situation et perspectives des finances publiques	2020-07-01 11:05:00	2020-07-01 12:30:00	2020-07-01 17:56:23	2020-07-02 18:18:19	25	0	\N	\N
481068	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de M. Jean-Paul FAUGÈRE - Candidat proposé VP ACPR	Audition de M. Jean-Paul FAUGÈRE - Candidat proposé VP ACPR	2020-07-01 13:40:00	2020-07-01 14:40:00	2020-07-01 16:20:43	2020-07-02 18:18:20	17	0	\N	\N
481086	COM_EURO	AUDRAP	\N	AFEU	\N	Fonds européens	Fonds européens - IGAS	2020-05-29 11:00:00	2020-05-29 12:00:00	\N	\N	2	0	\N	\N
481474	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI SCAF	\N	2020-06-25 09:00:00	2020-06-25 10:00:00	\N	\N	2	0	\N	\N
481577	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2020-06-09 14:40:00	2020-06-09 17:30:00	\N	\N	3	0	\N	\N
481581	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	\N	2020-06-16 14:35:00	2020-06-16 17:15:00	\N	\N	3	0	\N	\N
481585	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2020-06-23 14:50:00	2020-06-23 16:25:00	\N	\N	3	0	\N	\N
482268	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - ANR	Audition Pollution plastique - ANR	2020-06-30 09:00:00	2020-06-30 10:00:00	\N	\N	2	0	\N	\N
482296	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - Table ronde Roubaix, Grand Besançon Métropole, Colmar	Audition Pollution plastique - Table ronde Roubaix, Grand Besançon Métropole, Colmar	2020-06-30 10:15:00	2020-06-30 12:45:00	\N	\N	2	0	\N	\N
483387	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion de la commission	Réunion de la commission	2020-07-08 10:05:00	2020-07-08 12:22:00	2020-07-08 12:44:17	2020-07-08 17:02:39	29	3	\N	\N
483389	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	GT Laïcité	Groupe de travail - GT Laïcité	2020-07-01 14:35:00	2020-07-01 19:00:00	\N	\N	3	0	\N	\N
483393	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - Port  La Rochelle - Port Camargue	Audition Pollution plastique - Port  La Rochelle - Port Camargue	2020-07-06 08:45:00	2020-07-06 10:30:00	\N	\N	2	0	\N	\N
483396	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - France Urbaine	Audition Pollution plastique - France Urbaine	2020-07-06 10:45:00	2020-07-06 13:00:00	\N	\N	2	0	\N	\N
483467	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - AMF-APVF-ADF-ARF	Audition Pollution plastique - AMF-APVF-ADF-ARF	2020-07-07 08:30:00	2020-07-07 11:00:00	\N	\N	2	0	\N	\N
483470	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - Grand port maritime de Marseille	Audition Pollution plastique - Grand port maritime de Marseille	2020-07-07 11:00:00	2020-07-07 12:00:00	\N	\N	2	0	\N	\N
484400	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL DADUE	PJL DADUE	2020-07-08 21:35:00	2020-07-09 23:30:00	\N	\N	31	0	\N	\N
484587	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFR 2020	PLFR 2020	2020-07-19 14:30:00	2020-07-19 20:00:00	\N	\N	47	0	\N	\N
484588	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFR 2020	PLFR 2020	2020-07-19 21:30:00	2020-07-19 23:00:00	\N	\N	34	0	\N	\N
484589	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PPL Infractions terroristes	CMP PPL Infractions terroristes	2020-07-23 11:00:00	2020-07-23 13:00:00	\N	\N	20	0	\N	\N
484637	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière - Examen rapport J.L. Fugit - R. Courteau	Réunion plénière - Examen rapport J.L. Fugit - R. Courteau	2020-07-16 08:40:00	2020-07-16 10:15:00	\N	\N	8	0	\N	\N
484638	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - Total Raffinage-Chimie	Audition Pollution plastique - Total Raffinage-Chimie	2020-07-09 14:00:00	2020-07-09 15:30:00	\N	\N	2	0	\N	\N
484641	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - Anses	Audition Pollution plastique - Anses	2020-07-09 15:45:00	2020-07-09 17:00:00	\N	\N	2	0	\N	\N
484644	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - Vinci Autoroutes	Audition Pollution plastique - Vinci Autoroutes	2020-07-09 08:15:00	2020-07-09 09:15:00	\N	\N	2	0	\N	\N
484672	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ambassadeur du Danemark	Entretien avec S.E.M. Michael STARBAEK CHRISTENSEN, ambassadeur du Danemark en France	2020-07-09 13:00:00	2020-07-09 15:00:00	\N	\N	3	0	625	\N
484676	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2020-07-09 09:00:00	2020-07-09 12:30:00	\N	\N	4	0	\N	\N
484681	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2020-07-09 14:30:00	2020-07-09 16:30:00	\N	\N	1	0	\N	\N
484695	DELEGATION	AUCUNE	\N	\N	206	Conférence de presse rapport production d'énergie dans le secteur agricole	Conférence de presse de présentation du rapport sur la  production d'énergie dans le secteur agricole	2020-07-21 11:00:00	2020-07-21 12:30:00	\N	\N	0	0	\N	\N
373764	MISSION	AUCUNE	\N	INFRACTIONS	\N	Echange de vues sur les orientations du rapport	\N	2019-04-30 15:00:00	2019-04-30 16:15:00	2019-04-30 16:50:44	2019-04-30 17:33:22	11	0	\N	\N
373765	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Table ronde "Concilier maladie et travail"	\N	2019-06-06 08:30:00	2019-06-06 10:30:00	\N	\N	0	0	\N	\N
411906	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	GT Obligation de signalement	\N	2019-10-09 17:30:00	2019-10-09 19:00:00	\N	\N	4	0	\N	\N
484600	CMP	AUTRE	\N	DETTESOCIALE	\N	PJL Dette sociale et autonomie	PJL Dette sociale et autonomie	2020-07-08 17:00:00	2020-07-08 17:40:00	\N	\N	8	0	\N	\N
373780	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2019 - Les contrats de ruralité - Déplacement à Arras	Contrôle 2019 - Les contrats de ruralité - Déplacement à Arras	2019-04-23 10:45:00	2019-04-23 18:10:00	\N	\N	1	0	\N	\N
383124	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Sécurité des ponts	\N	2019-05-28 09:05:00	2019-05-28 10:00:00	\N	\N	5	0	\N	\N
386693	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	« Conséquences économiques des gilets jaunes »	« Conséquences économiques des gilets jaunes »	2019-06-05 14:30:00	2019-06-05 16:00:00	\N	\N	2	0	\N	\N
386705	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	« Conséquences économiques des gilets jaunes »	« Conséquences économiques des gilets jaunes »	2019-06-05 16:00:00	2019-06-05 17:30:00	\N	\N	4	0	\N	\N
386718	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	« Conséquences économiques des gilets jaunes »	« Conséquences économiques des gilets jaunes »	2019-06-05 17:30:00	2019-06-05 18:45:00	\N	\N	2	0	\N	\N
387200	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Sécurité des ponts	\tGroupe de travail - MI Sécurité des ponts	2019-06-04 14:30:00	2019-06-04 15:30:00	\N	\N	3	0	\N	\N
387478	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Transformation de la fonction publique	\N	2019-06-05 15:00:00	2019-06-05 16:00:00	\N	\N	2	0	\N	\N
391479	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	CNRACL	\N	2019-07-10 11:30:00	2019-07-10 12:15:00	\N	\N	0	0	\N	\N
391480	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	\N	\N	2019-07-10 11:30:00	2019-07-10 12:15:00	\N	\N	0	0	\N	\N
391483	MISSION	AUCUNE	\N	TRANSPORTS	\N	Table ronde	\N	2019-06-18 14:00:00	2019-06-18 15:30:00	2019-06-21 09:59:21	2019-06-21 16:34:55	11	0	\N	\N
391484	MISSION	AUDRAP	\N	TRANSPORTS	\N	Auditions rapporteur	\N	2019-06-19 14:00:00	2019-06-19 16:00:00	\N	\N	5	0	\N	\N
391485	MISSION	AUCUNE	\N	TRANSPORTS	\N	MIGT - Audition Mairie de Paris	\N	2019-06-20 13:35:00	2019-06-20 14:35:00	2019-06-21 10:00:29	2019-06-21 16:34:57	7	0	\N	\N
391508	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Energie - Auditions M. Gremillet	\N	2019-06-18 10:00:00	2019-06-18 11:00:00	\N	\N	2	0	\N	\N
391577	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	\N	\N	2019-06-25 14:30:00	2019-06-25 15:15:00	\N	\N	0	0	\N	\N
391626	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion suspension	\N	2019-06-18 16:25:00	2019-06-18 16:42:00	2019-06-19 17:32:52	2019-06-19 18:03:01	17	0	\N	\N
391691	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Jeux Olympiques et Paralympiques de 2024	PJL Jeux Olympiques et Paralympiques de 2024	2019-06-18 12:00:00	2019-06-18 12:45:00	\N	\N	2	0	\N	\N
395441	MECSS	AUCUNE	\N	\N	MECSS	PLF pour 2018	PLF pour 2018	2019-06-25 18:00:00	2019-06-25 19:40:00	2019-06-26 14:49:30	2019-06-26 18:35:57	8	0	\N	\N
397111	ETUDES	AUCUNE	\N	\N	\N	\N	\N	2019-07-16 15:00:00	2019-07-16 16:20:00	\N	\N	5	0	\N	928
398304	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Nouveaux territoires de l'éducation	\N	2019-07-04 14:00:00	2019-07-04 15:00:00	\N	\N	1	0	\N	\N
404601	ETUDES	AUCUNE	\N	\N	\N	Réunion	Réunion	2019-07-17 14:30:00	2019-07-17 16:30:00	\N	\N	2	0	\N	966
404604	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	\N	\N	2019-07-23 16:00:00	2019-07-23 16:30:00	\N	\N	0	0	\N	\N
407720	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2019-10-23 15:00:00	2019-10-23 16:30:00	\N	\N	292	0	\N	\N
407721	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Fiscalité de la succession et de la donation	PPL Fiscalité de la succession et de la donation	2019-10-23 16:30:00	2019-10-23 18:51:00	\N	\N	94	0	\N	\N
407722	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Assurance emprunteur	PPL Assurance emprunteur	2019-10-23 18:51:00	2019-10-23 20:12:00	\N	\N	46	0	\N	\N
407723	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	EV PPL Fondation du Patrimoine	EV PPL Fondation du Patrimoine	2019-10-23 22:00:00	2019-10-23 23:04:00	\N	\N	34	0	\N	\N
407746	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Régulation du marché de l'art	PPL Régulation du marché de l'art	2019-10-23 23:04:00	2019-10-24 00:55:00	\N	\N	24	0	\N	\N
407808	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR 34-1 Pouvoir dérogation  normes	PPR 34-1 Pouvoir dérogation  normes	2019-10-24 10:30:00	2019-10-24 11:42:00	\N	\N	41	0	\N	\N
407810	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Statut du citoyen sauveteur	PPL Statut du citoyen sauveteur	2019-10-24 15:41:00	2019-10-24 16:36:00	\N	\N	22	0	\N	\N
407829	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	2L PPL PPLO Droit électoral	2L PPL PPLO Droit électoral	2019-10-24 14:30:00	2019-10-24 15:32:00	\N	\N	25	0	\N	\N
407833	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Neutralité religieuse - service public de l'éducation	PPL Neutralité religieuse - service public de l'éducation	2019-10-29 14:31:00	2019-10-29 19:12:00	\N	\N	209	0	\N	\N
407834	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Assistons-nous au recul de l'État de droit en France ?	Débat Assistons-nous au recul de l'État de droit en France ?	2019-10-29 19:19:00	2019-10-29 20:32:00	\N	\N	36	0	\N	\N
407835	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Politique sportive	Débat Politique sportive	2019-10-29 22:08:00	2019-10-29 23:43:00	\N	\N	53	0	\N	\N
407836	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Catastrophes climatiques	Débat Catastrophes climatiques	2019-10-29 23:45:00	2019-10-30 01:20:00	\N	\N	29	0	\N	\N
407837	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2019-10-30 15:00:00	2019-10-30 16:10:00	\N	\N	269	0	\N	\N
407839	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Acier français	Débat Acier français	2019-10-30 16:30:00	2019-10-30 17:59:00	\N	\N	58	0	\N	\N
407840	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Enseignement agricole	Débat Enseignement agricole	2019-10-30 18:11:00	2019-10-30 19:45:00	\N	\N	36	0	\N	\N
407844	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR 34-1 Violations des droits humains au Venezuela	PPR 34-1 Violations des droits humains au Venezuela	2019-10-30 19:45:00	2019-10-31 21:02:00	\N	\N	18	0	\N	\N
409432	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-10-09 09:06:00	2019-10-09 10:50:00	2019-10-09 13:48:55	2019-10-09 17:38:40	66	0	\N	\N
409852	COM_PERMANENTE	DEPLACEMENT	\N	CAE	\N	Sommet de l'élevage 2019 - Clermont-Ferrand	Sommet de l'élevage 2019 - Clermont-Ferrand	2019-10-02 07:30:00	2019-10-02 13:00:00	\N	\N	7	0	\N	\N
411696	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	algorithmes locaux dans Parcoursup	algorithmes locaux dans Parcoursup	2019-10-08 17:30:00	2019-10-08 18:15:00	\N	\N	5	0	\N	\N
411905	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	GT Obligation de signalement	\N	2019-10-09 14:00:00	2019-10-09 15:00:00	\N	\N	3	0	\N	\N
391674	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-06-19 09:30:00	2019-06-19 10:30:00	2019-06-19 10:43:09	2019-06-19 18:02:57	43	2	\N	\N
404586	CMP	AUTRE	\N	CLIMAT	\N	PJL Énergie et climat	PJL Énergie et climat	2019-07-25 09:35:00	2019-07-25 11:20:00	\N	\N	10	0	\N	\N
408815	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Engagement et proximité - Présentation du rapport et examen des articles 1er à 4	PJL Engagement et proximité - Présentation du rapport et examen des articles 1er à 4	2019-10-02 08:35:00	2019-10-02 12:15:00	2019-10-02 14:52:44	2019-10-02 16:04:04	45	0	\N	\N
411907	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	GT Obligation de signalement	\N	2019-10-16 14:00:00	2019-10-16 15:00:00	\N	\N	4	0	\N	\N
411919	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	GT Obligation de signalement	\N	2019-10-16 16:30:00	2019-10-16 17:30:00	\N	\N	4	0	\N	\N
411920	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	GT Obligation de signalement	\N	2019-10-22 17:00:00	2019-10-22 18:00:00	\N	\N	2	0	\N	\N
413952	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions MI responsabilité civile	\N	2019-10-10 10:30:00	2019-10-10 12:00:00	\N	\N	2	0	\N	\N
413953	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions responsabilité civile	\N	2019-10-10 14:15:00	2019-10-10 16:15:00	\N	\N	2	0	\N	\N
413962	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Agriculture - Centre National de la Propriété Forestière - CNPF	PLF pour 2020 - Agriculture - Centre National de la Propriété Forestière - CNPF	2019-10-08 14:45:00	2019-10-08 16:00:00	\N	\N	2	0	\N	\N
413965	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Réforme des retraites - IPP	Contrôle 2018 - Réforme des retraites - IPP	2019-10-08 16:00:00	2019-10-08 18:00:00	\N	\N	1	0	\N	\N
475574	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule industrie - CCI France	\N	2020-04-09 17:50:00	2020-04-09 18:35:00	\N	\N	3	0	\N	\N
475578	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule industrie - Airbus	\N	2020-04-14 14:00:00	2020-04-14 14:50:00	\N	\N	5	0	\N	\N
475584	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule industrie - Fieec	\N	2020-04-16 14:00:00	2020-04-16 14:40:00	\N	\N	3	0	\N	\N
475588	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule industrie - Association nationale des industries alimentaires (ANIA)	\N	2020-04-16 16:45:00	2020-04-16 17:20:00	\N	\N	3	0	\N	\N
475596	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule industrie -Les entreprises du médicament (LEEM)	\N	2020-04-16 17:30:00	2020-04-16 18:30:00	\N	\N	4	0	\N	\N
475601	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule industrie - Michelin	\N	2020-04-22 14:00:00	2020-04-22 15:00:00	\N	\N	4	0	\N	\N
475606	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule industrie - Comité stratégique de la fillière Mines et métallurgie	\N	2020-04-23 16:30:00	2020-04-23 17:30:00	\N	\N	3	0	\N	\N
475610	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule industrie - Safran	\N	2020-04-28 17:00:00	2020-04-28 18:00:00	\N	\N	3	0	\N	\N
475614	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule industrie - Snitem	\N	2020-04-30 14:30:00	2020-04-30 15:30:00	\N	\N	3	0	\N	\N
475618	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule industrie - Airbus	\N	2020-05-05 17:00:00	2020-05-05 17:45:00	\N	\N	4	0	\N	\N
475623	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule industrie - Dassault systèmes	\N	2020-05-07 15:00:00	2020-05-07 15:45:00	\N	\N	3	0	\N	\N
475628	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule industrie - Saint-Gobain	\N	2020-05-07 17:00:00	2020-05-07 18:00:00	\N	\N	4	0	\N	\N
475633	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 -cellule industrie - Direction générale des douanes et des droits indirects	\N	2020-05-28 15:30:00	2020-05-28 16:30:00	\N	\N	4	0	\N	\N
475634	MISSION	AUCUNE	\N	ILLECTRONISM	\N	Table ronde des opérateurs et des entreprises du numérique	Table ronde des opérateurs et des entreprises du numérique	2020-06-08 15:00:00	2020-06-08 16:55:00	2020-06-08 17:00:00	2020-06-09 16:24:36	7	0	\N	\N
475640	COM_ENQUETE	PLENIERE	\N	AUTOROUT	\N	Point d'étape sur les travaux de la commission d'enquête sur les concessions autoroutières	Point d'étape sur les travaux de la commission d'enquête sur les concessions autoroutières	2020-06-09 14:05:00	2020-06-09 15:10:00	2020-06-09 15:18:58	2020-06-09 16:24:36	12	0	\N	\N
475758	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - J.P. Vanderlinden	Audition Pollution plastique - J.P. Vanderlinden	2020-06-05 11:30:00	2020-06-05 12:30:00	\N	\N	2	0	\N	\N
475761	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - Mmes Rossi et Pitollat, députées et M.Michel Vialay, député	Audition Pollution plastique - Mmes Rossi et Pitollat, députées et M. Michel Vialay, député	2020-06-15 09:00:00	2020-06-15 10:00:00	\N	\N	2	0	\N	\N
475764	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - Laboratoire d'Océanographie de Villefranche-sur-mer	Audition Pollution plastique - Laboratoire d'Océanographie de Villefranche-sur-mer	2020-06-15 10:15:00	2020-06-15 11:15:00	\N	\N	2	0	\N	\N
475767	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique  - Suez	Audition Pollution plastique  - Suez	2020-06-15 11:30:00	2020-06-15 13:00:00	\N	\N	2	0	\N	\N
475770	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - D. Blot	Audition Pollution plastique - D. Blot	2020-06-16 09:00:00	2020-06-16 10:00:00	\N	\N	2	0	\N	\N
475773	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - École des mines d¿Alès	Audition Pollution plastique - École des mines d¿Alès	2020-06-18 14:00:00	2020-06-18 15:30:00	\N	\N	2	0	\N	\N
475776	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - No plastic in my sea	Audition Pollution plastique - No plastic in my sea	2020-06-18 15:30:00	2020-06-18 16:30:00	\N	\N	2	0	\N	\N
475779	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - Citeo	Audition Pollution plastique - Citeo	2020-06-18 16:45:00	2020-06-18 18:00:00	\N	\N	2	0	\N	\N
475783	DELEGATION	AUCUNE	\N	\N	PROS	Échanges de vues sur les nouveaux thèmes de travail de la Délégation	Échanges de vues sur les nouveaux thèmes de travail de la Délégation	2020-06-11 09:30:00	2020-06-11 10:15:00	\N	\N	11	0	\N	\N
475790	COM_ENQUETE	AUDRAP	\N	AUTOROUT	\N	CE concessions autoroutières - EDHEC/Scientific Beta	CE concessions autoroutières - EDHEC/Scientific Beta	2020-06-04 10:00:00	2020-06-04 11:00:00	\N	\N	1	0	\N	\N
475795	MISSION	AUDRAP	\N	GUYANE	\N	\N	\N	2020-06-04 14:30:00	2020-06-04 17:00:00	\N	\N	12	0	\N	\N
475829	COM_ENQUETE	PLENIERE	\N	RADICALI	\N	Auditions secrétariat générale de l'éducation national et CFCM (visioconférence)	Auditions secrétariat générale de l'éducation national et CFCM (visioconférence)	2020-06-11 10:30:00	2020-06-11 12:40:00	2020-06-11 13:06:15	2020-06-11 18:27:50	6	0	\N	\N
475830	COM_ENQUETE	AUTRE	\N	RADICALI	\N	Audition de Roxana MARACINEANU, ministre des sports	\N	2020-06-11 14:00:00	2020-06-11 15:20:00	2020-06-11 15:42:45	2020-06-11 17:40:56	4	0	\N	\N
475890	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Prévention de la perte d'autonomie - Audition de la SFGG	\N	2020-06-02 16:00:00	2020-06-02 16:35:00	\N	\N	1	0	\N	\N
475892	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Prévention de la perte d'autonomie - Audition du Pr Olivier Saint-Jean	\N	2020-06-03 13:00:00	2020-06-03 14:00:00	\N	\N	4	0	\N	\N
475893	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - J. Boucher - D. Friot	Audition Pollution plastique - J. Boucher - D. Friot	2020-06-16 11:30:00	2020-06-16 13:00:00	\N	\N	2	0	\N	\N
476227	DELEGATION	AUDRAP	\N	\N	DSOM	Rencontrte avec M. Thierry Santa, président du gouvernement de la Nouvelle-Calédonie	\N	2020-05-28 23:00:00	2020-05-29 00:00:00	\N	\N	1	0	\N	\N
476263	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid19 Médias	Audition Canal+	2020-06-04 11:15:00	2020-06-04 12:45:00	\N	\N	3	0	\N	\N
476267	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid 19 Sport	Audition LFP	2020-06-10 14:00:00	2020-06-10 15:00:00	\N	\N	3	0	\N	\N
476269	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2020-05-26 14:45:00	2020-05-26 16:25:00	\N	\N	3	0	\N	\N
477322	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid19 Médias	Audition LOVGroup	2020-06-09 15:00:00	2020-06-09 15:50:00	\N	\N	3	0	\N	\N
477382	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid19 Médias	Audition Arte	2020-06-09 16:30:00	2020-06-09 17:30:00	\N	\N	1	0	\N	\N
477455	DELEGATION	AUDRAP	\N	\N	211	Audition de M. Jean-Baptiste Gourdin et de M. Ludovic Berthelot - DGMIC	Audition de M. Jean-Baptiste Gourdin et de M. Ludovic Berthelot - DGMIC	2020-06-10 16:30:00	2020-06-10 17:35:00	\N	\N	6	0	\N	\N
477712	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2020-06-17 09:00:00	2020-06-17 11:30:00	2020-06-17 14:24:57	2020-06-18 17:49:58	35	0	\N	\N
477714	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2020-06-18 15:00:00	2020-06-18 16:55:00	2020-06-18 19:07:32	2020-06-19 14:56:17	30	0	\N	\N
477770	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2020-06-11 09:30:00	2020-06-11 11:45:00	\N	\N	3	0	\N	\N
477878	MISSION	AUDRAP	\N	FEDERATION	\N	Auditions MI FFS	Auditions MI FFS	2020-06-11 15:55:00	2020-06-11 16:40:00	\N	\N	8	0	\N	\N
477887	MISSION	AUDRAP	\N	FEDERATION	\N	Auditions MI FFS	Auditions MI FFS	2020-06-11 16:40:00	2020-06-11 17:45:00	\N	\N	9	0	\N	\N
478253	COM_ENQUETE	PLENIERE	\N	AUTOROUT	\N	CE Concessions autoroutières - Audition de Mme Elisabeth BORNE	CE Concessions autoroutières - Audition de Mme Elisabeth BORNE, ministre de la Transition écologique et solidaire	2020-06-24 16:35:00	2020-06-24 18:00:00	2020-06-24 18:25:35	2020-06-25 09:53:47	9	0	\N	\N
478264	MISSION	AUDRAP	\N	FEDERATION	\N	Auditions MI FFS	Auditions MI FFS	2020-06-16 15:00:00	2020-06-16 16:00:00	\N	\N	6	0	\N	\N
478969	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule Énergie - FNSEA	Covid-19 - cellule Énergie - FNSEA	2020-06-16 16:00:00	2020-06-16 16:45:00	\N	\N	2	0	\N	\N
479182	COM_EURO	AUTRE	\N	AFEU	\N	Audition de Mme Vestager VP Commission européenne (numérique)	\N	2020-06-16 13:05:00	2020-06-16 15:15:00	2020-06-24 14:35:05	2020-06-24 18:04:35	13	0	\N	\N
479418	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - Métropole de Lyon	Audition Pollution plastique - Métropole de Lyon	2020-06-22 08:00:00	2020-06-22 09:00:00	\N	\N	2	0	\N	\N
479434	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - EMPA	Audition Pollution plastique - EMPA	2020-06-19 11:00:00	2020-06-19 13:00:00	\N	\N	2	0	\N	\N
375049	MISSION	AUCUNE	\N	INFRACTIONS	\N	Auditions plénières	\N	2019-05-07 14:10:00	2019-05-07 16:40:00	2019-05-09 14:34:22	2019-05-09 17:08:58	8	0	\N	\N
375051	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	audition de M. Milon PJL Santé	\N	2019-05-07 15:00:00	2019-05-07 16:30:00	\N	\N	1	0	\N	\N
375052	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	audition de M. Milon PJL Santé	\N	2019-05-14 14:00:00	2019-05-14 15:30:00	\N	\N	1	0	\N	\N
377116	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Ali Dolamari	Entretien avec Ali Dolamari, représentant du Gouvernement régional du Kurdistan d'Irak en France, et son chef de cabinet	2019-05-15 16:00:00	2019-05-15 16:45:00	\N	\N	1	0	615	\N
377239	GIA	AUCUNE	\N	\N	\N	Rencontre délégation afghane	Rencontre, conjointe avec la DDF, avec une délégation de femmes afghanes en formation à l'ESSEC	2019-06-20 14:00:00	2019-06-20 15:00:00	\N	\N	1	0	648	\N
404605	MISSION	AUDRAP	\N	FONDS	\N	ASP	Audition ASP	2019-07-23 14:00:00	2019-07-23 15:00:00	\N	\N	5	0	\N	\N
407831	GIA	AUCUNE	\N	\N	\N	Coopé_Visite de M. Damir MARJANOVI¿, Député du canton de Sarajevo	Coopé_Visite de M. Damir MARJANOVI¿, Député du canton de Sarajevo	2019-09-25 14:45:00	2019-09-25 15:30:00	\N	\N	1	0	674	\N
411747	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Audiovisuel	PLF 2020 - Crédits Audiovisuel	2019-10-08 17:00:00	2019-10-08 18:30:00	\N	\N	1	0	\N	\N
414039	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Nouveaux territoires du sport	MI Nouveaux territoires du sport	2019-10-10 10:00:00	2019-10-10 12:00:00	\N	\N	2	0	\N	\N
414046	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Enseignement supérieur	PLF 2020 - Crédits Enseignement supérieur	2019-10-10 10:00:00	2019-10-10 12:30:00	\N	\N	2	0	\N	\N
416354	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFR pour 2019	PLFR pour 2019	2019-11-18 17:01:00	2019-11-18 20:05:00	\N	\N	43	0	\N	\N
416366	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL carte Vitale biométrique	PPL carte Vitale biométrique	2019-11-19 14:31:00	2019-11-19 16:22:00	\N	\N	113	0	\N	\N
416367	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat gratuité totale des transports collectifs	Débat gratuité totale des transports collectifs	2019-11-19 16:27:00	2019-11-19 17:56:00	\N	\N	76	0	\N	\N
416368	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2019-11-20 15:01:00	2019-11-20 16:18:00	\N	\N	306	0	\N	\N
416369	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL création de délégations parlementaires aux droits des enfants	PPL création de délégations parlementaires aux droits des enfants	2019-11-20 16:38:00	2019-11-20 18:44:00	\N	\N	74	0	\N	\N
416370	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL hyper-fréquentation » dans les sites naturels et culturels	PPL hyper-fréquentation » dans les sites naturels et culturels	2019-11-21 09:00:00	2019-11-21 10:21:00	\N	\N	46	0	\N	\N
416375	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat urgence climatique par le développement ferroviaire	Débat urgence climatique par le développement ferroviaire	2019-11-20 18:44:00	2019-11-20 20:09:00	\N	\N	40	0	\N	\N
416439	GIA	AUCUNE	\N	\N	\N	Déplacement en Namibie et Angola	Déplacement en Namibie et Angola	2019-09-21 18:15:00	2019-09-29 11:00:00	\N	\N	2	0	646	\N
420548	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Économie - M. Serge Babary	\N	2019-10-24 14:00:00	2019-10-24 17:00:00	\N	\N	1	0	\N	\N
420551	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Sécurités - DGGN	PLF pour 2020 - Sécurités - DGGN	2019-10-21 14:00:00	2019-10-21 15:00:00	\N	\N	1	0	\N	\N
420553	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Sécurités - Syndicat Alliance Police Nationale	PLF pour 2020 - Sécurités - Syndicat Alliance Police Nationale	2019-10-21 15:30:00	2019-10-21 17:00:00	\N	\N	1	0	\N	\N
420555	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Sécurités - DGPN	PLF pour 2020 - Sécurités - DGPN	2019-10-25 14:00:00	2019-10-25 15:00:00	\N	\N	1	0	\N	\N
420556	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Solidarité - Associations d'aide alimentaire et APF France Handicap	PLF pour 2020 - Solidarité - Associations d'aide alimentaire et APF France Handicap	2019-10-22 15:30:00	2019-10-22 18:00:00	\N	\N	2	0	\N	\N
420559	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Solidarité - NEXEM	PLF pour 2020 - Solidarité - NEXEM	2019-10-23 14:00:00	2019-10-23 15:00:00	\N	\N	2	0	\N	\N
420562	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Solidarité - RUA / AVFT	PLF pour 2020 - Solidarité - RUA / AVFT	2019-10-24 14:30:00	2019-10-24 16:30:00	\N	\N	2	0	\N	\N
420565	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Justice - DAP	PLF pour 2020 - Justice - DAP	2019-10-22 09:30:00	2019-10-22 10:30:00	\N	\N	1	0	\N	\N
420567	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Justice - CNB Avocat  / Syndicat de la magistrature	PLF pour 2020 - Justice - CNB Avocat  / Syndicat de la magistrature	2019-10-22 15:30:00	2019-10-22 16:30:00	\N	\N	1	0	\N	\N
420569	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Économie - INPI	PLF pour 2020 - Économie - INPI	2019-10-23 16:45:00	2019-10-23 18:00:00	\N	\N	1	0	\N	\N
420571	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Investissements d'avenir - ANR	PLF pour 2020 - Investissements d'avenir - ANR	2019-10-21 15:00:00	2019-10-21 16:00:00	\N	\N	1	0	\N	\N
420573	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Travail et emploi - COORACE et FAS	PLF pour 2020 - Travail et emploi - COORACE et FAS	2019-10-23 14:00:00	2019-10-23 15:00:00	\N	\N	2	0	\N	\N
420576	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Travail et emploi DGEFP et DGT	PLF pour 2020 - Travail et emploi DGEFP et DGT	2019-10-24 17:30:00	2019-10-24 19:00:00	\N	\N	2	0	\N	\N
420579	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - CAS PFE - APE	PLF pour 2020 - CAS PFE - APE	2019-10-22 09:30:00	2019-10-22 11:00:00	\N	\N	1	0	\N	\N
420581	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Sécurités - Sécurité Civile - FNSPF	PLF pour 2020 - Sécurités - Sécurité Civile - FNSPF	2019-10-22 17:00:00	2019-10-22 18:15:00	\N	\N	1	0	\N	\N
422849	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GS États généraux de l'alimentation	GS États généraux de l'alimentation - Rapport d'information - Réunon d'arbitrage	2019-10-22 13:45:00	2019-10-22 14:00:00	\N	\N	3	0	\N	\N
422853	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GS États généraux de l'alimentation	GS États généraux de l'alimentation - Présentation des orientations du premier bilan du titre Ier de la loi EGALIM	2019-10-23 11:00:00	2019-10-23 12:00:00	\N	\N	11	0	\N	\N
423100	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2020 - Avis Justice administrative	\N	2019-11-05 15:00:00	2019-11-05 15:45:00	\N	\N	1	0	\N	\N
423101	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2020 - Avis juridictions administratives et juridictions financières	PLF pour 2020 - Avis juridictions administratives et juridictions financières	2019-11-05 17:15:00	2019-11-05 19:30:00	\N	\N	1	0	\N	\N
424976	GIA	AUCUNE	\N	\N	\N	Coopé - Visite de Mme Vokosava Crnjanski, Directrice pour la Serbie du CRTA	Coopé - Visite de Mme Vokosava Crnjanski, Directrice pour la Serbie du CRTA	2019-11-06 14:00:00	2019-11-06 15:00:00	\N	\N	1	0	674	\N
425003	GIA	AUCUNE	\N	\N	\N	Coopé - Visite de Mme Ria Schröder, présidente des Jeunes libéraux	Coopé - Visite de Mme Ria Schröder, présidente des Jeunes libéraux	2019-11-06 14:00:00	2019-11-06 15:00:00	\N	\N	1	0	604	\N
425007	GIA	AUCUNE	\N	\N	\N	Coopé - Visite de Mme Faride RAFUL, députée dominicaine 	Coopé - Visite de Mme Faride RAFUL, députée dominicaine 	2019-11-06 08:30:00	2019-11-06 09:00:00	\N	\N	1	0	642	\N
425014	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJLF pour 2020 - P 212	\N	2019-11-05 15:00:00	2019-11-05 18:00:00	\N	\N	2	0	\N	\N
484696	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - Laboratoire Pacte	Audition Pollution plastique - Laboratoire Pacte	2020-07-10 14:00:00	2020-07-10 15:00:00	\N	\N	2	0	\N	\N
484699	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - Métropole européenne de Lille	Audition Pollution plastique - Métropole européenne de Lille	2020-07-10 15:15:00	2020-07-10 16:15:00	\N	\N	2	0	\N	\N
484702	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - Snitem	Audition Pollution plastique - Snitem	2020-07-10 16:30:00	2020-07-10 17:30:00	\N	\N	2	0	\N	\N
484705	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - Restoria	Audition Pollution plastique - Restoria	2020-07-10 17:30:00	2020-07-10 18:30:00	\N	\N	2	0	\N	\N
484708	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - Commission européenne	Audition Pollution plastique - Commission européenne	2020-07-15 09:00:00	2020-07-15 10:00:00	\N	\N	2	0	\N	\N
484711	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - Université Rennes 1	Audition Pollution plastique - Université Rennes 1	2020-07-15 13:30:00	2020-07-15 15:00:00	\N	\N	2	0	\N	\N
484714	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - Break free from plastic	Audition Pollution plastique - Break free from plastic	2020-07-16 08:45:00	2020-07-16 09:45:00	\N	\N	1	0	\N	\N
484717	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - Commission européenne	Audition Pollution plastique - Commission européenne	2020-07-16 10:00:00	2020-07-16 11:00:00	\N	\N	1	0	\N	\N
484720	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - Haropa - Ports de Paris	Audition Pollution plastique - Haropa - Ports de Paris	2020-07-16 14:00:00	2020-07-16 15:30:00	\N	\N	1	0	\N	\N
484727	COM_ENQUETE	PLENIERE	\N	AUTOROUT	\N	CE Concessions autoroutières - Table ronde d'associations d'usagers des autoroutes	CE Concessions autoroutières - Table ronde d'associations d'usagers des autoroutes	2020-07-16 14:00:00	2020-07-16 15:35:00	2020-07-16 15:35:56	2020-07-16 17:12:34	4	0	\N	\N
484728	COM_ENQUETE	PLENIERE	\N	AUTOROUT	\N	CE Concessions autoroutières - Audition de M. Bruno Le Maire	CE Concessions autoroutières - Audition de M. Bruno Le Maire	2020-07-16 09:00:00	2020-07-16 09:50:00	2020-07-16 09:50:27	2020-07-16 17:12:33	6	0	\N	\N
484729	COM_ENQUETE	PLENIERE	\N	AUTOROUT	\N	CE Concessions autoroutières - Audition de M. Alexis KOHLER	CE Concessions autoroutières - Audition de M. Alexis KOHLER	2020-07-15 16:35:00	2020-07-15 17:50:00	2020-07-15 17:50:35	2020-07-15 18:37:46	7	0	\N	\N
485176	COM_ENQUETE	PLENIERE	\N	AUTOROUT	\N	Examen du projet de rapport présenté par M. Vincent DELAHAYE, rapporteur	Examen du projet de rapport présenté par M. Vincent DELAHAYE, rapporteur	2020-09-16 14:30:00	2020-09-16 16:10:00	2020-09-16 16:12:11	2020-09-16 18:02:23	9	0	\N	\N
485540	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion du 22 juillet 2020 matin	Réunion du 22 juillet 2020 matin	2020-07-22 08:45:00	2020-07-22 12:30:00	2020-07-22 15:26:09	2020-07-22 18:00:36	25	2	\N	\N
485542	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition d'Eric Dupond-Moretti, garde des sceaux, ministre de la justice	Audition d'Eric Dupond-Moretti, garde des sceaux, ministre de la justice	2020-07-22 13:30:00	2020-07-22 15:00:00	2020-07-22 15:25:43	2020-07-22 18:00:37	44	3	\N	\N
484687	DELEGATION	AUTRE	\N	\N	DSOM	Réunion de la délégation	\N	2020-07-16 14:00:00	2020-07-16 15:30:00	\N	\N	8	0	\N	\N
485543	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Mesures de sûreté contre les auteurs d'infractions terroristes (amendements de séance)	PPL Mesures de sûreté contre les auteurs d'infractions terroristes (amendements de séance)	2020-07-21 14:00:00	2020-07-21 14:05:00	2020-07-21 14:20:01	2020-07-21 15:44:03	8	1	\N	\N
486059	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	GT Expertise psychiatrique en matière pénale	GT Expertise psychiatrique en matière pénale	2020-07-22 09:00:00	2020-07-22 09:45:00	\N	\N	0	0	\N	\N
486060	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	GT Expertise psychiatrique en matière pénale	GT Expertise psychiatrique en matière pénale	2020-07-22 09:45:00	2020-07-22 10:30:00	\N	\N	0	0	\N	\N
486187	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Convention France-Luxembourg	Convention France-Luxembourg	2020-07-22 16:15:00	2020-07-22 16:45:00	\N	\N	35	0	\N	\N
486762	GIA	AUCUNE	\N	\N	\N	Audition de Mme Corinne CAHEN	Audition de Mme Corinne CAHEN, ministre de la Famille et de l'Intégration et ministre à la Grande Région, du gouvernemen	2020-07-20 10:00:00	2020-07-20 10:45:00	\N	\N	7	0	580	\N
486770	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Pass culture	\N	2020-07-16 14:30:00	2020-07-16 16:00:00	\N	\N	2	0	\N	\N
486861	COM_ENQUETE	AUDRAP	\N	AUTOROUT	\N	CE Concessions autoroutières - Audition de M. Frédéric FORTIN	CE Concessions autoroutières - Audition de M. Frédéric FORTIN	2020-07-20 09:00:00	2020-07-20 12:30:00	\N	\N	1	0	\N	\N
486863	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Audition médiateur des relations commerciales agricoles	\N	2020-07-08 13:30:00	2020-07-08 15:30:00	\N	\N	0	0	\N	\N
486880	COM_ENQUETE	PLENIERE	\N	PANDEMIE	\N	Audition	\N	2020-07-21 14:10:00	2020-07-21 16:05:00	2020-07-22 10:48:25	2020-07-22 18:00:51	15	0	\N	\N
486929	MISSION	PEC_NON_MML	\N	FEDERATION	\N	Audition de Mme Roxana Maracineanu	Audition de Mme Roxana Maracineanu, ministre déléguée, chargée des Sports	2020-07-21 16:40:00	2020-07-21 17:50:00	2020-07-21 18:28:55	2020-07-22 18:00:52	4	0	\N	\N
486939	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2020-07-22 10:05:00	2020-07-22 12:25:00	2020-07-22 12:54:05	2020-07-22 18:00:37	13	0	\N	\N
486981	COM_ENQUETE	PLENIERE	\N	SOLS	\N	Échange de vues	\N	2020-07-22 16:30:00	2020-07-22 18:30:00	2020-07-24 09:59:29	2020-07-28 17:30:29	7	0	\N	\N
487274	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de M. Éric DOLIGÉ pour siéger au HCFP	Audition de M. Éric DOLIGÉ pour siéger au HCFP	2020-07-28 13:30:00	2020-07-28 14:15:00	2020-07-28 17:26:37	2020-07-28 17:30:46	21	0	\N	\N
487669	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de M. Eric Doligé	\N	2020-07-28 13:30:00	2020-07-28 14:25:00	2020-07-28 19:53:44	2020-07-29 15:37:12	21	0	\N	\N
487670	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de M. Toujas	\N	2020-07-28 18:00:00	2020-07-28 19:00:00	2020-07-28 19:37:05	2020-07-29 15:37:13	10	0	\N	\N
488194	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Prévention de la perte d'autonomie - Audition de l'ANAH	\N	2020-07-21 14:00:00	2020-07-21 14:45:00	\N	\N	2	0	\N	\N
488195	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Prévention de la perte d'autonomie - Audition de l'Agirc-Arrco	\N	2020-07-21 15:00:00	2020-07-21 16:00:00	\N	\N	2	0	\N	\N
488196	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition de M. Laurent Vachey	\N	2020-07-21 16:00:00	2020-07-21 17:00:00	\N	\N	2	0	\N	\N
488197	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Prévention de la perte d'autonomie - Audition de la Direction des sports	\N	2020-07-23 10:00:00	2020-07-23 11:00:00	\N	\N	2	0	\N	\N
488198	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Santé environnementale - Table ronde de spécialistes	\N	2020-07-10 09:00:00	2020-07-10 10:30:00	\N	\N	2	0	\N	\N
488199	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Santé environnementale -  Audition de Réseau Environnement Santé	\N	2020-07-10 10:30:00	2020-07-10 11:30:00	\N	\N	2	0	\N	\N
488200	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Santé environnementale - Audition de la Ligue nationale contre le cancer	\N	2020-07-10 11:30:00	2020-07-10 12:30:00	\N	\N	2	0	\N	\N
488201	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Santé environnementale - Audition de Mme Francelyne Marano	\N	2020-07-24 10:00:00	2020-07-24 11:00:00	\N	\N	1	0	\N	\N
488202	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Santé environnementale - Audition de l'association Générations Futures	\N	2020-07-24 11:00:00	2020-07-24 12:00:00	\N	\N	1	0	\N	\N
488616	DELEGATION	AUCUNE	\N	\N	206	Réunion avec le conseil scientifique	Réunion avec le conseil scientifique	2020-09-10 10:10:00	2020-09-10 13:05:00	\N	\N	10	0	\N	\N
488674	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Prévention de la perte d'autonomie - Audition de la DHUP	\N	2020-09-02 17:00:00	2020-09-02 18:00:00	\N	\N	2	0	\N	\N
488852	COM_ENQUETE	PLENIERE	\N	PANDEMIE	\N	Audition de Mme Andrea Ammon, directrice de l'ECDC	\N	2020-09-09 16:30:00	2020-09-09 17:30:00	2020-09-09 17:37:28	2020-09-09 17:42:10	10	0	\N	\N
489408	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition 58-2 sur la politique de lutte contre pollution de l'air - Contrôle immobilier PP	58-2 sur la politique de lutte contre la pollution de l'air et Contrôle Projets Immobilier Pouvoirs Publics	2020-09-23 14:30:00	2020-09-23 16:35:00	2020-09-23 16:51:32	2020-09-24 16:42:04	13	0	\N	\N
382827	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-06-05 10:05:00	2019-06-05 11:55:00	2019-06-05 12:09:03	2019-06-05 12:22:45	29	0	\N	\N
382835	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-05-27 14:15:00	2019-05-27 15:10:00	2019-05-27 15:43:53	2019-05-27 17:27:26	21	3	\N	\N
382861	DELEGATION	AUDRAP	\N	\N	PROS	Audition rapporteur	Audition de James Kenneth Galbraith	2019-05-29 14:00:00	2019-05-29 15:30:00	\N	\N	1	0	\N	\N
383055	MISSION	AUDRAP	\N	CLIMATIQUE	\N	Audition du GIP Littoral Aquitaine	\N	2019-05-22 14:00:00	2019-05-22 15:00:00	\N	\N	9	0	\N	\N
383065	MISSION	AUDRAP	\N	CLIMATIQUE	\N	Audition de M. Gwenahel Thirel, avocat	\N	2019-05-22 15:00:00	2019-05-22 15:45:00	\N	\N	8	0	\N	\N
401563	MISSION	AUDRAP	\N	AERIEN	\N	\N	\N	2019-07-15 10:00:00	2019-07-15 12:30:00	\N	\N	2	0	\N	\N
401594	MISSION	AUDRAP	\N	AERIEN	\N	\N	\N	2019-07-16 09:00:00	2019-07-16 10:10:00	\N	\N	3	0	\N	\N
401598	MISSION	AUDRAP	\N	AERIEN	\N	\N	\N	2019-07-16 10:10:00	2019-07-16 10:40:00	\N	\N	2	0	\N	\N
401609	MISSION	AUDRAP	\N	AERIEN	\N	\N	\N	2019-07-16 14:30:00	2019-07-16 15:40:00	\N	\N	2	0	\N	\N
401612	MISSION	AUDRAP	\N	AERIEN	\N	\N	\N	2019-07-16 15:40:00	2019-07-16 16:20:00	\N	\N	1	0	\N	\N
401619	MISSION	AUDRAP	\N	AERIEN	\N	\N	\N	2019-07-18 16:30:00	2019-07-18 17:30:00	\N	\N	2	0	\N	\N
403023	GIA	AUCUNE	\N	\N	\N	Visite d'une délégation de l'Assemblée nationale du Mali (Coopé)	Visite d'une délégation de l'Assemblée nationale du Mali (Coopé)	2019-07-09 12:30:00	2019-07-09 14:00:00	\N	\N	1	0	573	\N
405342	DELEGATION	AUDRAP	\N	\N	COLTER	DCT - GT ruralités - Audition sur le contrat de réciprocité brestois	DCT - GT ruralités - Audition sur le contrat de réciprocité brestois	2019-09-25 16:00:00	2019-09-25 17:00:00	\N	\N	3	0	\N	\N
405343	DELEGATION	DEPLACEMENT	\N	\N	COLTER	DCT - GT ruralités - Déplacement à Toulouse	DCT - GT ruralités - Déplacement à Toulouse	2019-09-26 08:45:00	2019-09-26 20:00:00	\N	\N	3	0	\N	\N
408075	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Entraves à des libertés, à des évènements et activités légales	\N	2019-09-24 10:00:00	2019-09-24 11:00:00	\N	\N	1	0	\N	\N
408078	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Modernisation de la régulation du marché de l'art	\N	2019-09-23 09:00:00	2019-09-23 12:15:00	\N	\N	1	0	\N	\N
408080	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Modernisation de la régulation du marché de l'art	\N	2019-09-23 15:00:00	2019-09-23 18:45:00	\N	\N	1	0	\N	\N
408082	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Modernisation de la régulation du marché de l'art	\N	2019-09-24 16:00:00	2019-09-24 17:00:00	\N	\N	1	0	\N	\N
408084	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Modernisation de la régulation du marché de l'art	\N	2019-09-26 10:00:00	2019-09-26 11:00:00	\N	\N	1	0	\N	\N
410612	GIA	AUCUNE	\N	\N	\N	Déjeuner de travail avec la Sénatrice jordanienne Haifa NAJJAR	Déjeuner de travail avec la Sénatrice jordanienne Haifa NAJJAR, Présidente du groupe d'amitié Jordanie- France	2019-10-02 12:30:00	2019-10-02 14:30:00	\N	\N	9	0	659	\N
410623	GIA	AUCUNE	\N	\N	\N	Déjeuner de travail Think tank de Macédoine du Nord	Déjeuner de travail Think tank de Macédoine du Nord	2019-10-03 12:30:00	2019-10-03 14:30:00	\N	\N	2	0	674	\N
413967	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Agriculture - Chambres d'agriculture France (APCA)	PLF pour 2020 - Agriculture - Chambres d'agriculture France (APCA)	2019-10-10 15:30:00	2019-10-10 16:15:00	\N	\N	1	0	\N	\N
413971	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	AT-MP	\N	2019-10-16 17:30:00	2019-10-16 19:45:00	\N	\N	2	0	\N	\N
413973	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Justice - Secrétariat général ministère de la justice	PLF pour 2020 - Justice - Secrétariat général ministère de la justice	2019-10-08 15:00:00	2019-10-08 16:00:00	\N	\N	1	0	\N	\N
413975	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 2019 - Arrêt et démantèlement installations nucléaires civiles - Cour des comptes	58-2 2019 - Arrêt et démantèlement installations nucléaires civiles - Cour des comptes	2019-10-09 14:00:00	2019-10-09 15:00:00	\N	\N	1	0	\N	\N
413977	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - DAG - DILA	PLF pour 2020 - DAG - DILA	2019-10-08 09:00:00	2019-10-08 10:00:00	\N	\N	1	0	\N	\N
413979	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Action extérieure de l'Etat - MEAE - DGMO et Français à l'étranger	PLF pour 2020 - Action extérieure de l'Etat - MEAE -DGMO et Français à l'étranger et administration consulaire	2019-10-08 15:30:00	2019-10-08 17:30:00	\N	\N	2	0	\N	\N
413982	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Action extérieure de l'Etat - MEAE - DGP	PLF pour 2020 - Action extérieure de l'Etat - MEAE - DGP	2019-10-09 18:00:00	2019-10-09 19:00:00	\N	\N	2	0	\N	\N
413986	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Action extérieure de l'Etat - AEFE	PLF pour 2020 - Action extérieure de l'Etat - AEFE	2019-10-11 14:30:00	2019-10-11 15:30:00	\N	\N	1	0	\N	\N
413992	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Sport - Direction des sports	PLF pour 2020 - Sport - Direction des sports	2019-10-09 13:45:00	2019-10-09 14:30:00	\N	\N	1	0	\N	\N
414002	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Écologie - ARAFER	PLF pour 2020 - Écologie - ARAFER	2019-10-08 09:30:00	2019-10-08 10:30:00	\N	\N	1	0	\N	\N
414004	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Écologie - VNF	PLF pour 2020 - Écologie - VNF	2019-10-09 17:00:00	2019-10-09 18:00:00	\N	\N	1	0	\N	\N
414006	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Écologie - SNCF Mobilités	PLF pour 2020 - Écologie - SNCF Mobilités	2019-10-10 11:00:00	2019-10-10 12:15:00	\N	\N	1	0	\N	\N
414008	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Rapport général - CNPA	PLF pour 2020 - Rapport général - CNPA	2019-10-10 17:40:00	2019-10-10 18:30:00	\N	\N	1	0	\N	\N
414010	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - EFE - Cour des comptes	PLF pour 2020 - EFE - Cour des comptes	2019-10-11 10:00:00	2019-10-11 10:45:00	\N	\N	1	0	\N	\N
414012	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - EFE - AFT	PLF pour 2020 - EFE - AFT	2019-10-11 11:15:00	2019-10-11 12:10:00	\N	\N	1	0	\N	\N
420709	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Critères d'évolution de la carte judiciaire - Audition de Mme Nicole Belloubet	Critères d'évolution de la carte judiciaire - Audition de Mme Nicole Belloubet	2019-10-30 12:30:00	2019-10-30 13:35:00	2019-10-30 14:12:07	2019-10-30 14:57:22	23	0	\N	\N
420710	COM_SPECIALE	PLENIERE	\N	BIOETHIQUE	\N	Auditions plénières	CS Bioéthique 	2019-10-30 16:35:00	2019-10-30 18:30:00	2019-10-31 17:39:42	2019-10-31 17:41:29	19	0	\N	\N
420711	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Cohésion des territoires - Logement et urbanisme - ANCOLS / FPI / DHUP	PLF pour 2020 - Cohésion des territoires - Logement et urbanisme - ANCOLS / FPI / DHUP	2019-10-24 09:00:00	2019-10-24 12:00:00	\N	\N	1	0	\N	\N
420713	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Cohésion des territoires - Logement et urbanisme - CDC	PLF pour 2020 - Cohésion des territoires - Logement et urbanisme - CDC	2019-10-29 09:00:00	2019-10-29 10:00:00	\N	\N	1	0	\N	\N
420715	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 -  Médias, livre et industries culturelles - Radio France	PLF pour 2020 -  Médias, livre et industries culturelles - Radio France	2019-10-28 15:00:00	2019-10-28 16:00:00	\N	\N	1	0	\N	\N
420717	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLF 2020 DAG	\N	2019-10-28 14:30:00	2019-10-28 18:10:00	\N	\N	1	0	\N	\N
420720	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-11-05 14:02:00	2019-11-05 14:05:00	2019-11-06 10:55:34	2019-11-06 14:36:25	20	0	\N	\N
420722	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-11-06 10:30:00	2019-11-06 12:00:00	2019-11-08 17:05:45	2019-11-08 17:07:15	32	0	\N	\N
420723	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJLF 2020 - Avis Première partie - Auditions de M. Longeot	PJLF 2020 - Avis Première partie - Auditions de M. Longeot	2019-10-24 11:30:00	2019-10-24 13:00:00	\N	\N	1	0	\N	\N
420725	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJLF 2020 - Avis Première partie - Auditions de M. Longeot	PJLF 2020 - Avis Première partie - Auditions de M. Longeot	2019-10-24 14:05:00	2019-10-24 16:30:00	\N	\N	1	0	\N	\N
420727	DELEGATION	AUDRAP	\N	\N	PROS	Audition de France Stratégie	\N	2019-11-19 15:30:00	2019-11-19 16:30:00	\N	\N	1	0	\N	\N
420728	DELEGATION	AUDRAP	\N	\N	PROS	Audition de la Confédération paysanne	\N	2019-11-19 16:30:00	2019-11-19 17:45:00	\N	\N	1	0	\N	\N
420763	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Sécurités - Sécurité routière - DSR	PLF pour 2020 - Sécurités - Sécurité routière - DSR	2019-10-28 17:30:00	2019-10-28 19:30:00	\N	\N	1	0	\N	\N
479437	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - UPPA	Audition Pollution plastique - UPPA	2020-06-22 09:00:00	2020-06-22 10:00:00	\N	\N	2	0	\N	\N
420707	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Urbanisme à Saint-Martin - Violences au sein de la famille (rapports et textes)	Urbanisme à Saint-Martin - Violences au sein de la famille (rapports et textes)	2019-10-30 09:40:00	2019-10-30 11:40:00	2019-10-30 12:45:12	2019-10-30 14:57:25	36	0	\N	\N
479441	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - BASF France	Audition Pollution plastique - BASF France	2020-06-22 10:15:00	2020-06-22 12:15:00	\N	\N	2	0	\N	\N
479444	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique  - GIFAM	Audition Pollution plastique  - GIFAM	2020-06-22 14:00:00	2020-06-22 14:45:00	\N	\N	2	0	\N	\N
479477	MISSION	AUDRAP	\N	FEDERATION	\N	Auditions MI FFS	Auditions MI FFS	2020-06-22 15:30:00	2020-06-22 16:30:00	\N	\N	8	0	\N	\N
479486	MISSION	AUDRAP	\N	FEDERATION	\N	Auditions MI FFS	Auditions MI FFS	2020-06-22 16:30:00	2020-06-22 17:30:00	\N	\N	8	0	\N	\N
480080	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	covid PPL Protéger les victimes de violences conjugales	\N	2020-06-23 09:10:00	2020-06-23 09:40:00	\N	\N	2	0	\N	\N
481185	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - Inserm	Audition Pollution plastique - Inserm	2020-06-25 14:00:00	2020-06-25 15:00:00	\N	\N	2	0	\N	\N
481188	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - Agence française du développement	Audition Pollution plastique - Agence française du développement	2020-06-25 16:00:00	2020-06-25 17:00:00	\N	\N	2	0	\N	\N
481191	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - Laurence Rocher	Audition Pollution plastique - Laurence Rocher	2020-06-25 17:15:00	2020-06-25 18:15:00	\N	\N	2	0	\N	\N
481205	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - Laboratoire MAPIEM	Audition Pollution plastique - Laboratoire MAPIEM	2020-06-29 09:00:00	2020-06-29 10:00:00	\N	\N	2	0	\N	\N
481215	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - INRA	Audition Pollution plastique - INRA	2020-06-29 10:15:00	2020-06-29 11:15:00	\N	\N	2	0	\N	\N
481225	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - Plastipolis	Audition Pollution plastique - Plastipolis	2020-06-29 11:30:00	2020-06-29 12:45:00	\N	\N	2	0	\N	\N
481232	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - Métropole Aix-Marseille	Audition Pollution plastique - Métropole Aix-Marseille	2020-06-29 14:00:00	2020-06-29 15:00:00	\N	\N	2	0	\N	\N
481507	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PJLO et PJL Dette sociale et autonomie + Désig. membres CMP Dette sociale	\N	2020-07-01 09:05:00	2020-07-01 10:00:00	2020-07-01 12:45:24	2020-07-02 18:18:14	35	0	\N	\N
481618	MISSION	AUDRAP	\N	FEDERATION	\N	Auditions MI FFS	Auditions MI FFS	2020-06-29 17:30:00	2020-06-29 18:30:00	\N	\N	7	0	\N	\N
481943	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Programme 144 : financement de la BITD 	\N	2020-06-23 15:30:00	2020-06-23 16:30:00	\N	\N	2	0	\N	\N
481946	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Programme 144 : financement de la BITD 	\N	2020-06-24 13:45:00	2020-06-24 17:30:00	\N	\N	2	0	\N	\N
482069	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT subsidiarité	Réunion du groupe de travail sur la subsidiarité	2020-06-30 17:40:00	2020-06-30 18:10:00	\N	\N	5	0	\N	\N
482216	DELEGATION	AUCUNE	\N	\N	211	Réunion plénière - examen de rapport d'information sur les violences	Réunion plénière - examen de rapport d'information sur les violences	2020-07-07 17:30:00	2020-07-07 18:35:00	2020-07-08 17:42:05	\N	16	0	\N	\N
482345	MISSION	AUCUNE	\N	ILLECTRONISM	\N	Audition de la DG Connect	Audition de la DG Connect	2020-07-06 10:05:00	2020-07-06 10:55:00	2020-07-06 11:10:58	2020-07-07 14:35:05	4	0	\N	\N
483111	GIA	AUCUNE	\N	\N	\N	dîner chez Son Excellence Sheikh Ali Bin Jassim Al-Thani, Ambassadeur du Qatar	\N	2020-07-01 20:00:00	2020-07-01 22:00:00	\N	\N	8	0	661	\N
483229	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2020-07-08 17:00:00	2020-07-08 18:15:00	2020-07-09 11:33:25	2020-07-09 11:40:19	15	0	\N	\N
483238	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition GT Agriculteurs en détresse	Audition GT Agriculteurs en détresse	2020-06-30 10:30:00	2020-06-30 12:00:00	\N	\N	1	0	\N	\N
483276	COM_ENQUETE	AUTRE	\N	PANDEMIE	\N	Réunion plénière	\N	2020-07-09 09:30:00	2020-07-09 12:30:00	\N	\N	25	0	\N	\N
483286	MISSION	AUDRAP	\N	FEDERATION	\N	Auditions MI FFS	Auditions MI FFS	2020-07-03 14:30:00	2020-07-03 15:30:00	\N	\N	4	0	\N	\N
483287	MISSION	PEC_NON_MML	\N	FEDERATION	\N	Audition plénière	Audition plénière	2020-07-03 15:30:00	2020-07-03 16:30:00	2020-07-03 16:48:43	2020-07-03 18:37:19	6	0	\N	\N
483299	MISSION	AUDRAP	\N	GUYANE	\N	Audition de Mme Cherbonnier	\N	2020-07-07 15:55:00	2020-07-07 17:15:00	\N	\N	2	0	\N	\N
483300	COM_ENQUETE	PLENIERE	\N	SOLS	\N	Audition plénière CE poll sol 	\N	2020-07-03 14:00:00	2020-07-03 15:12:00	2020-07-03 17:26:29	2020-07-03 18:37:13	5	0	\N	\N
483314	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Prévention de la perte d'autonomie - Audition de Old'up	\N	2020-06-30 14:00:00	2020-06-30 15:00:00	\N	\N	3	0	\N	\N
483315	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Prévention de la perte d'autonomie - Audition de l'UNCCAS	\N	2020-06-30 16:00:00	2020-06-30 17:00:00	\N	\N	3	0	\N	\N
483322	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Prévention de la perte d'autonomie - Audition de la Fedepsad	\N	2020-07-01 14:15:00	2020-07-01 14:45:00	\N	\N	2	0	\N	\N
483325	COM_ENQUETE	AUDRAP	\N	SOLS	\N	Table ronde sur les enjeux des sites et sols pollués dans le Nord lorrain	\N	2020-07-02 15:00:00	2020-07-02 16:40:00	\N	\N	3	0	\N	\N
483349	MISSION	AUCUNE	\N	DEPARTEMENT	\N	Audtion commune	\N	2020-07-07 14:03:00	2020-07-07 15:13:00	2020-07-07 17:23:13	2020-07-07 18:16:01	7	0	\N	\N
483351	COM_ENQUETE	PLENIERE	\N	PANDEMIE	\N	Audition de M. Jean Rottner, président de la région Grand-Est	\N	2020-07-08 18:45:00	2020-07-08 20:35:00	2020-07-08 20:36:13	2020-07-09 11:41:00	28	0	\N	\N
483361	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLO Prorogation mandat des membres du CESE	PJLO Prorogation mandat des membres du CESE	2020-07-06 14:05:00	2020-07-06 19:15:00	\N	\N	1	0	\N	\N
483363	COM_ENQUETE	DEPLACEMENT	\N	AUTOROUT	\N	CE concessions autoroutières - ART	CE concessions autoroutières - ART	2020-07-03 13:30:00	2020-07-03 17:30:00	\N	\N	1	0	\N	\N
483365	MISSION	AUDRAP	\N	FEDERATION	\N	Auditions MI FFS	Auditions MI FFS	2020-07-06 10:30:00	2020-07-06 12:05:00	\N	\N	5	0	\N	\N
483366	MISSION	PEC_NON_MML	\N	FEDERATION	\N	Auditions MI FFs - Table ronde  FFT, FFF, FFR	Auditions MI FFs - Table ronde  FFT, FFF, FFR	2020-07-06 14:15:00	2020-07-06 16:05:00	2020-07-06 17:05:31	2020-07-07 14:35:04	6	0	\N	\N
483367	COM_ENQUETE	DEPLACEMENT	\N	AUTOROUT	\N	CE concessions autoroutières - DGITM	CE concessions autoroutières - DGITM	2020-07-08 09:15:00	2020-07-08 12:45:00	\N	\N	1	0	\N	\N
483369	MISSION	AUDRAP	\N	FEDERATION	\N	Auditions MI FFS	Auditions MI FFS	2020-07-06 16:05:00	2020-07-06 16:50:00	\N	\N	4	0	\N	\N
483370	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Examen rapport information lutte contre la cybercriminalité	Examen rapport information lutte contre la cybercriminalité	2020-07-09 08:30:00	2020-07-09 09:25:00	2020-07-10 15:43:24	2020-07-10 18:47:00	9	0	\N	\N
483386	COM_ENQUETE	AUDRAP	\N	AUTOROUT	\N	CE concessions autoroutières - Atlandes	CE concessions autoroutières - Atlandes	2020-07-07 08:30:00	2020-07-07 09:15:00	\N	\N	1	0	\N	\N
483388	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion  de commission	Réunion  de commission	2020-07-15 09:35:00	2020-07-15 11:35:00	2020-07-15 11:59:22	2020-07-15 18:38:42	12	0	\N	\N
484689	COM_ENQUETE	PLENIERE	\N	PANDEMIE	\N	Auditions de la commission d'enquête	\N	2020-07-15 16:30:00	2020-07-15 20:30:00	2020-07-15 21:42:38	2020-07-16 17:12:33	26	0	\N	\N
484690	COM_ENQUETE	PLENIERE	\N	PANDEMIE	\N	Audition commune de services d'urgence	\N	2020-07-16 13:30:00	2020-07-16 16:25:00	2020-07-16 17:52:58	2020-07-17 18:42:19	27	0	\N	\N
484691	COM_ENQUETE	PLENIERE	\N	SOLS	\N	Audition de M. Olivier Véran, ministre des solidarités et de la santé	\N	2020-07-17 14:30:00	2020-07-17 15:35:00	2020-07-21 10:46:39	2020-07-21 15:43:31	7	0	\N	\N
484693	COM_EURO	AUDRAP	\N	AFEU	\N	Audition de la fédération des entreprises du médicament	\N	2020-07-08 16:30:00	2020-07-08 17:40:00	\N	\N	1	0	\N	\N
484735	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Déclaration du Gouvernement, suivie d¿un débat, en application de l¿article 50¿1 de la Con	Déclaration du Gouvernement, suivie d¿un débat, en application de l¿article 50¿1 de la Constitution	2020-07-16 10:00:00	2020-07-16 12:45:00	\N	\N	158	0	\N	\N
484736	SEANCE_PLENIERE	AUTRE	\N	\N	\N	PLFR 2020 - DG	PLFR 2020 - Discussion générale	2020-07-16 14:30:00	2020-07-16 17:10:00	\N	\N	78	0	\N	\N
484737	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2020-07-21 09:30:00	2020-07-21 12:30:00	\N	\N	29	0	\N	\N
378696	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 16 mai 2019	Réunion de la commission des affaires européennes du 16 mai 2019	2019-05-16 08:35:00	2019-05-16 10:25:00	2019-05-16 10:46:05	2019-05-16 15:00:51	19	0	\N	\N
389892	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de Mme Dominique Le Guludec, présidente de la Haute Autorité de santé	Audition de Mme Dominique Le Guludec, présidente de la Haute Autorité de santé	2019-06-19 09:30:00	2019-06-19 11:05:00	2019-06-19 11:07:31	2019-06-19 18:02:56	24	0	\N	\N
390948	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 13 juin 2019	Réunion de la commission des affaires européennes du 13 juin 2019	2019-06-13 08:30:00	2019-06-13 09:25:00	2019-06-13 10:28:31	2019-06-13 16:25:48	13	0	\N	\N
396229	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2019-06-05 15:00:00	2019-06-05 16:30:00	\N	\N	3	0	\N	\N
396233	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2019-06-12 14:20:00	2019-06-12 17:20:00	\N	\N	3	0	\N	\N
396239	ETUDES	AUCUNE	\N	\N	\N	Audition commune "Dispositifs de maintien en emploi des patients traités pour un cancer"	Audition commune "Dispositifs de maintien en emploi des patients traités pour un cancer"	2019-07-04 10:00:00	2019-07-04 11:30:00	\N	\N	5	0	\N	1004
396247	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Sécurité des ponts	\N	2019-06-25 15:05:00	2019-06-25 16:05:00	\N	\N	8	0	\N	\N
398273	ETUDES	AUCUNE	\N	\N	\N	Rencontre avec M. Alain Canet	Rencontre avec M. Alain Canet	2019-07-03 08:00:00	2019-07-03 09:00:00	\N	\N	14	0	\N	948
400036	MISSION	DEPLACEMENT	\N	TRANSPORTS	\N	Déplacement à Dunkerque	Déplacement à Dunkerque	2019-07-09 11:30:00	2019-07-09 20:00:00	\N	\N	1	0	\N	\N
409988	COM_PERMANENTE	AUTRE	\N	FINC	\N	Contrôle budgétaire ZRR	Contrôle budgétaire ZRR	2019-10-09 09:05:00	2019-10-09 10:50:00	2019-10-09 19:20:33	2019-10-10 14:55:46	66	0	\N	\N
409997	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du jeudi 3 octobre 2019	\N	2019-10-03 08:30:00	2019-10-03 09:25:00	2019-10-03 10:00:13	2019-10-03 15:59:10	10	0	\N	\N
412278	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation du PArlement de MAcédoine du Nord	Déjeuner de travail avec une délégation de députés de Macédoine du Nord	2019-10-09 12:30:00	2019-10-09 14:15:00	\N	\N	10	0	674	\N
425028	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJLF pour 	PJLF pour 2020 - P 212	2019-11-06 16:30:00	2019-11-06 18:15:00	\N	\N	2	0	\N	\N
425056	DELEGATION	AUCUNE	\N	\N	211	Réunion plénière - 21/11/2019	Réunion plénière - 21/11/2019	2019-11-21 08:30:00	2019-11-21 10:00:00	\N	\N	11	0	\N	\N
425126	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière	Réunion plénière - Audition publique sur l'hésitation vaccinale	2019-11-14 09:50:00	2019-11-14 12:50:00	\N	\N	9	0	\N	\N
427656	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2020 - Avis Justice judiciaire	PLF pour 2020 - Avis Justice judiciaire	2019-11-13 19:30:00	2019-11-13 20:40:00	\N	\N	1	0	\N	\N
428229	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF 2020 - Programme 144	\N	2019-11-14 09:00:00	2019-11-14 10:10:00	\N	\N	1	0	\N	\N
428382	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2019-10-15 14:40:00	2019-10-15 16:55:00	\N	\N	2	0	\N	\N
430646	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-11-27 09:35:00	2019-11-27 12:00:00	2019-11-27 16:06:09	2019-11-27 16:20:20	28	0	\N	\N
430799	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation de hauts fonctionnaires	\N	2019-11-18 15:00:00	2019-11-18 16:00:00	\N	\N	1	0	626	\N
430801	GIA	AUCUNE	\N	\N	\N	accueil d'une délégation d'experts scientifiques	\N	2019-10-03 10:00:00	2019-10-03 11:00:00	\N	\N	1	0	626	\N
432904	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière	\N	2019-12-04 09:00:00	2019-12-04 11:02:00	2019-12-06 14:58:34	2019-12-06 15:00:08	29	1	\N	\N
433637	COM_SPECIALE	AUDRAP	\N	BIOETHIQUE	\N	Audition Mme Imbert et M. Henno	\N	2019-12-04 15:00:00	2019-12-04 15:45:00	\N	\N	3	0	\N	\N
435632	COM_SPECIALE	PLENIERE	\N	BIOETHIQUE	\N	Auditions de la FFCPDP et audition commune d'associations - Commission spéciale Bioéthique	\N	2019-12-03 17:30:00	2019-12-03 20:50:00	2019-12-04 17:23:49	2019-12-04 17:37:10	20	0	\N	\N
435768	COM_SPECIALE	AUDRAP	\N	BIOETHIQUE	\N	Audition Mme Jourda Association ADEDD art 3	\N	2019-12-03 08:45:00	2019-12-03 09:40:00	\N	\N	2	0	\N	\N
435770	COM_SPECIALE	AUDRAP	\N	BIOETHIQUE	\N	Audition Mme Jourda Collectif des maires pour l'enfance art 4	\N	2019-12-03 09:40:00	2019-12-03 10:45:00	\N	\N	2	0	\N	\N
435786	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-12-04 09:35:00	2019-12-04 10:15:00	2019-12-04 12:19:54	2019-12-04 14:11:15	36	3	\N	\N
435793	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-12-04 09:05:00	2019-12-04 11:05:00	2019-12-04 16:50:42	2019-12-04 16:52:45	44	1	\N	\N
435811	COM_SPECIALE	AUDRAP	\N	BIOETHIQUE	\N	Audition rapporteur	\N	2019-12-03 15:00:00	2019-12-03 15:50:00	\N	\N	4	0	\N	\N
502347	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2021	PLF pour 2021	2020-12-02 21:55:00	2020-12-03 00:20:00	\N	\N	56	0	\N	\N
429453	CMP	AUTRE	\N	PLFR2019	\N	PLFR pour 2019	PLFR pour 2019	2019-11-19 19:30:00	2019-11-19 19:50:00	\N	\N	9	0	\N	\N
432684	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Examen du rapport et du texte de la commission PPL Usages dangereux du protoxyde d'azote	\N	2019-12-04 09:40:00	2019-12-04 10:30:00	2019-12-04 11:26:14	2019-12-04 14:11:14	39	1	\N	\N
435787	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-12-04 10:15:00	2019-12-04 11:55:00	2019-12-04 12:20:08	2019-12-04 14:11:13	36	3	\N	\N
435888	ETUDES	AUTRE	\N	\N	\N	Audition plénière	GE Développement économique de la montagne - Application de la loi Montagne II	2019-12-03 13:00:00	2019-12-03 14:00:00	\N	\N	5	0	\N	918
435894	ETUDES	AUTRE	\N	\N	\N	Audition plénière	GE Développement économique de la montagne - Application de la loi Montagne II	2019-11-26 13:00:00	2019-11-26 14:00:00	\N	\N	3	0	\N	918
436031	COM_ENQUETE	PLENIERE	\N	RADICALI	\N	Auditions plénières	Auditions plénières	2019-12-12 09:30:00	2019-12-12 12:40:00	2019-12-12 12:42:34	2019-12-12 16:22:57	7	0	\N	\N
438983	COM_PERMANENTE	DEPLACEMENT	\N	AFCL	\N	Déplacement Institut du Monde Arabe	Déplacement Institut du Monde Arabe	2019-12-11 10:00:00	2019-12-11 12:00:00	\N	\N	13	0	\N	\N
439275	ETUDES	AUCUNE	\N	\N	\N	GE Énergie - Table ronde "Filière française du biogaz"	GE Énergie -Table ronde sur "Le potentiel de développement de la filière française du biogaz"	2019-12-11 13:30:00	2019-12-11 15:00:00	\N	\N	11	0	\N	906
439832	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition entreprises responsables et engagées	Audition entreprises responsables et engagées - CAMIF	2019-12-03 14:00:00	2019-12-03 15:00:00	\N	\N	2	0	\N	\N
439835	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition entreprises responsables et engagées	Audition entreprises responsables et engagées - Groupe SOS	2019-12-03 15:00:00	2019-12-03 16:00:00	\N	\N	2	0	\N	\N
439836	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition entreprises responsables et engagées	Audition entreprises responsables et engagées -  \tVigeo Eiris	2019-12-03 16:30:00	2019-12-03 17:30:00	\N	\N	2	0	\N	\N
439842	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition entreprises responsables et engagées 	Audition entreprises responsables et engagées - Pro Bono Lab	2019-12-03 17:30:00	2019-12-03 18:30:00	\N	\N	2	0	\N	\N
443849	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions de M. Montaugé et Mme Noël-PPL Libre choix du consommateur dans le cyberespace	Affaires économiques - Auditions de M. Montaugé et Mme Noël	2020-01-08 18:30:00	2020-01-08 20:00:00	\N	\N	2	0	\N	\N
489509	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Santé environnementale - Audition D. Zmirou-Navier	\N	2020-09-18 10:00:00	2020-09-18 11:00:00	\N	\N	1	0	\N	\N
489511	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Santé environnementale - Audition ASEF	\N	2020-09-18 11:00:00	2020-09-18 12:00:00	\N	\N	1	0	\N	\N
489513	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Santé environnementale - Audition F. Bourdillon	\N	2020-09-18 12:00:00	2020-09-18 13:00:00	\N	\N	1	0	\N	\N
489749	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de M. Pierre MOSCOVICI, PDT du HCFP sur le PLF et le PLFSS pour 2021	Audition de M. Pierre MOSCOVICI, PDT du HCFP sur le PLF et le PLFSS pour 2021	2020-09-29 15:35:00	2020-09-29 16:35:00	2020-09-29 17:45:42	2020-10-01 16:28:53	21	0	\N	\N
489750	COM_PERMANENTE	AUTRE	\N	FINC	\N	Controles budgét. sur mesures d'urgence  crise sanitaire et ambassadeurs thématiques	Controles budgétaires sur les mesures d'urgence de la crise sanitaire et sur les ambassadeurs thématiques	2020-09-30 09:05:00	2020-09-30 10:05:00	2020-09-30 10:44:25	2020-10-01 16:28:53	20	0	\N	\N
489751	COM_PERMANENTE	AUTRE	\N	FINC	\N	Controle budgétaire Franc CFA	Controle budgétaire Franc CFA	2020-09-30 16:10:00	2020-09-30 16:50:00	2020-09-30 17:15:44	2020-10-01 16:28:54	18	0	\N	\N
489752	COM_PERMANENTE	DEPLACEMENT	\N	SOCI	\N	PPL Territoire zéro chômeur de longue durée	\N	2020-09-30 14:30:00	2020-09-30 16:30:00	\N	\N	1	0	\N	\N
489753	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Projet de loi de programmation pour la recherche - Conférence des présidents d'université	Projet de loi de programmation pour la recherche - Conférence des présidents d'université	2020-09-23 10:00:00	2020-09-23 11:00:00	\N	\N	1	0	\N	\N
489755	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Projet de loi de programmation pour la recherche - CEA	Projet de loi de programmation pour la recherche - CEA	2020-09-23 15:30:00	2020-09-23 16:30:00	\N	\N	1	0	\N	\N
489757	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Projet de loi de programmation pour la recherche - ANR	Projet de loi de programmation pour la recherche - ANR	2020-09-23 16:30:00	2020-09-23 17:10:00	\N	\N	1	0	\N	\N
489815	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Mise sur le marché de certains produits phytopharmaceutiques	\N	2020-09-24 09:00:00	2020-09-24 09:45:00	\N	\N	1	0	\N	\N
489828	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL LPPR	\N	2020-09-24 14:30:00	2020-09-24 17:30:00	\N	\N	2	0	\N	\N
489887	DELEGATION	AUDRAP	\N	\N	PROS	Audition rapporteur de M. Pierre VELTZ	\N	2020-09-22 09:30:00	2020-09-22 11:00:00	\N	\N	1	0	\N	\N
490447	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-10-07 10:00:00	2020-10-07 10:30:00	2020-10-07 11:20:35	2020-10-07 18:04:36	48	0	\N	\N
490449	COM_PERMANENTE	AUTRE	\N	FINC	\N	Élection bureau de la commission et Nominations rapporteurs PPL594-PPLC682-PJL722	Élection bureau de la commission et Nominations rapporteurs PPL594-PPLC682-PJL722	2020-10-07 09:00:00	2020-10-07 09:45:00	2020-10-07 10:38:08	2020-10-07 18:04:35	46	0	\N	\N
490450	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Constitution bureau de la commission	\N	2020-10-07 11:30:00	2020-10-07 12:00:00	2020-10-07 12:31:28	2020-10-07 18:04:33	44	0	\N	\N
490451	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition Mme Frédérique Vidal	\N	2020-10-07 14:00:00	2020-10-07 15:50:00	2020-10-07 16:32:43	2020-10-07 18:04:33	32	0	\N	\N
490452	COM_SPECIALE	PLENIERE	\N	ASAP	\N	Constitution du Bureau	\N	2020-10-07 16:50:00	2020-10-07 17:15:00	2020-10-07 17:57:02	2020-10-07 18:04:45	19	0	\N	\N
490455	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2020-10-07 10:39:00	2020-10-07 12:05:00	2020-10-09 11:43:00	\N	43	0	\N	\N
491050	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL de programmation recherche - Cabinet Ministre Ens Sup et Recherche	PJL de programmation pour la recherche - Cabinet Ministre Ens Sup et Recherche	2020-10-06 09:30:00	2020-10-06 10:30:00	\N	\N	1	0	\N	\N
491178	DELEGATION	AUDRAP	\N	\N	PROS	Audition de Routes de France	\N	2020-10-21 14:00:00	2020-10-21 15:00:00	\N	\N	1	0	\N	\N
491179	DELEGATION	AUDRAP	\N	\N	PROS	Audition de l'ADEME	Audition de M. Jérôme Almosni, ADEME	2020-10-28 14:00:00	2020-10-28 15:00:00	\N	\N	1	0	\N	\N
502348	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2021	PLF pour 2021	2020-12-03 10:35:00	2020-12-03 13:00:00	\N	\N	87	0	\N	\N
442830	CMP	AUTRE	\N	GASPILLE	\N	PJL Économie circulaire	PJL Économie circulaire	2020-01-08 09:38:00	2020-01-08 11:25:00	\N	\N	12	0	\N	\N
443668	CMP	AUTRE	\N	HAINE	\N	PPL Lutte contre la haine sur internet	PPL Lutte contre la haine sur internet	2020-01-08 17:10:00	2020-01-08 17:55:00	\N	\N	7	0	\N	\N
491467	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-10-13 15:20:00	2020-10-13 16:50:00	2020-10-13 17:21:06	2020-10-13 18:06:12	28	0	\N	\N
491471	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examens Rapports PJL n°722 - PPL n°594 - PPLC n°682 et PPLO n°683	Examens Rapports PJL n°722 - PPL n°594 - PPLC n°682 et PPLO n°683	2020-10-13 15:30:00	2020-10-13 17:30:00	2020-10-14 09:53:21	2020-10-14 18:26:50	35	0	\N	\N
491472	COM_PERMANENTE	AUTRE	\N	FINC	\N	Nominations Rapporteur PLFSS2021-GT Gd Paris Exp.-Audition 58-2 Projets Numériques État	Nominations Rapporteur PLFSS2021-GT Gd Paris Exp.-Audition 58-2 Projets Numériques État	2020-10-14 09:35:00	2020-10-14 12:00:00	2020-10-14 12:53:11	2020-10-14 18:22:43	36	0	\N	\N
491473	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Auditions rapporteur - PPL Déshérence des contrats de retraite supplémentaire	Auditions rapporteur - PPL Déshérence des contrats de retraite supplémentaire	2020-10-09 14:30:00	2020-10-09 17:00:00	\N	\N	1	0	\N	\N
491474	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-10-14 09:05:00	2020-10-14 10:45:00	2020-10-14 19:03:49	2020-10-15 11:06:09	37	0	\N	\N
491475	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-10-14 11:05:00	2020-10-14 12:40:00	2020-10-14 19:03:24	2020-10-15 11:06:11	61	0	\N	\N
491476	COM_ENQUETE	PLENIERE	\N	PANDEMIE	\N	Audition commune 	\N	2020-10-14 16:35:00	2020-10-14 18:45:00	2020-10-15 10:48:41	2020-10-15 15:15:25	19	0	\N	\N
491477	COM_ENQUETE	PLENIERE	\N	PANDEMIE	\N	\N	\N	2020-10-15 09:05:00	2020-10-15 10:10:00	2020-10-16 12:42:47	2020-10-16 18:53:03	11	0	\N	\N
491478	COM_ENQUETE	PLENIERE	\N	PANDEMIE	\N	Audition commune	\N	2020-10-15 14:30:00	2020-10-15 15:40:00	2020-10-15 15:41:05	2020-10-15 16:30:47	13	0	\N	\N
491479	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n°594 Octroi dotation d'équipement territoires ruraux - Audition Auteur PPL	PPL n°594 Octroi dotation d'équipement territoires ruraux - Audition Auteur PPL	2020-10-07 15:30:00	2020-10-07 16:30:00	\N	\N	2	0	\N	\N
491482	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n°594 Octroi dotation d'équipement territoires ruraux - DGCL	PPL n°594 Octroi dotation d'équipement territoires ruraux - DGCL	2020-10-07 14:00:00	2020-10-07 15:00:00	\N	\N	1	0	\N	\N
491484	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur - PPL Déshérence des contrats de retraite supplémentaire	Auditions rapporteur - PPL Déshérence des contrats de retraite supplémentaire	2020-10-12 15:15:00	2020-10-12 17:15:00	\N	\N	2	0	\N	\N
491507	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2020-10-13 09:35:00	2020-10-13 10:10:00	2020-10-13 10:30:41	2020-10-13 15:52:50	21	0	\N	\N
491509	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2020-10-14 08:30:00	2020-10-14 09:05:00	2020-10-14 16:17:33	2020-10-14 18:26:48	23	0	\N	\N
491510	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Auditions CNAM et CNAV - PLFSS pour 2021	Auditions CNAM et CNAV - PLFSS pour 2021	2020-10-14 09:30:00	2020-10-14 11:50:00	2020-10-14 16:26:57	2020-10-14 18:26:47	35	0	\N	\N
491513	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2020-10-07 18:05:00	2020-10-07 19:05:00	\N	\N	29	0	\N	\N
491662	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition Roselyne Bachelot (PJL Restitutions)	\N	2020-10-20 17:20:00	2020-10-20 18:55:00	\N	\N	0	0	\N	\N
491683	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition Thierry Coulhon (al. 5, art. 13 Const.)	\N	2020-10-21 11:30:00	2020-10-21 13:35:00	2020-10-21 18:25:00	2020-10-22 18:43:01	31	0	\N	\N
491698	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition Frédérique Vidal (PLF 2021)	\N	2020-10-21 16:40:00	2020-10-21 17:55:00	2020-10-21 18:29:31	2020-10-23 17:26:46	12	0	\N	\N
491700	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Néonicotinoïdes - Interapi	\N	2020-10-13 13:45:00	2020-10-13 14:15:00	\N	\N	4	0	\N	\N
491881	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2021 - Branche Autonomie - Audition de M. Dominique Libault	\N	2020-10-13 13:30:00	2020-10-13 14:30:00	\N	\N	4	0	\N	\N
492316	COM_PERMANENTE	AUTRE	\N	FINC	\N	GT 2020 Le Grand Paris Express - Réunion en vue de l'adoption du rapport	GT 2020 Le Grand Paris Express - Réunion en vue de l'adoption du rapport	2020-10-13 18:00:00	2020-10-13 19:00:00	2020-10-14 12:13:57	2020-10-14 18:26:49	10	0	\N	\N
492438	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI Restitution des oeuvres d'art	\N	2020-10-13 16:45:00	2020-10-13 17:45:00	\N	\N	8	0	\N	\N
492447	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Conférence interparlementaire article 13 du TSCG en Visioconférence	Conférence interparlementaire article 13 du TSCG en Visioconférence	2020-10-12 10:30:00	2020-10-12 12:30:00	\N	\N	1	0	\N	\N
373784	DELEGATION	AUCUNE	\N	\N	COLTER	Présentation du rapport d'information de M. Antoine Lefèvre et Mme Patricia Schillinger	Présentation du rapport d'information de M. Antoine Lefèvre et Mme Patricia Schillinger	2019-05-16 09:30:00	2019-05-16 11:00:00	2019-05-16 11:12:59	\N	14	0	\N	\N
373788	GIA	AUCUNE	\N	\N	\N	Entretien de M. Rémi FERAUD avec  M. Mohammed MAAN ABDULQADER AL-ZAKARIA, journaliste irak	Entretien de M. Rémi FERAUD avec  M. Mohammed MAAN ABDULQADER AL-ZAKARIA, journaliste irakien (coope)	2019-04-25 09:00:00	2019-04-25 09:45:00	\N	\N	1	0	615	\N
384434	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-06-05 09:35:00	2019-06-05 11:50:00	2019-06-05 12:31:43	2019-06-05 14:09:41	32	1	\N	\N
384667	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL 5G	PPL 5G	2019-05-29 16:15:00	2019-05-29 17:30:00	\N	\N	3	0	\N	\N
384684	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PPL Sécurité des réseaux radioélectriques	\N	2019-05-29 14:30:00	2019-05-29 17:30:00	\N	\N	1	0	\N	\N
384687	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2019-05-22 16:40:00	2019-05-22 19:10:00	\N	\N	3	0	\N	\N
384691	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	« Conséquences économiques des gilets jaunes »	« Conséquences économiques des gilets jaunes »	2019-05-29 14:00:00	2019-05-29 16:20:00	\N	\N	4	0	\N	\N
391449	COM_ENQUETE	AUDRAP	\N	SOUVERAINETE	\N	Audition de Bernard Stiegler	\N	2019-06-12 19:05:00	2019-06-12 20:15:00	\N	\N	4	0	\N	\N
400907	MISSION	AUCUNE	\N	TRANSPORTS	\N	MI Gratuité des transports	Réunion rapport MI Gratuité des transports	2019-07-16 09:45:00	2019-07-16 13:40:00	2019-07-19 16:18:28	2019-07-19 16:21:47	2	0	\N	\N
406662	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-09-25 09:35:00	2019-09-25 11:30:00	2019-09-25 11:42:13	2019-09-25 15:38:51	39	4	\N	\N
407179	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-09-26 11:35:00	2019-09-26 11:45:00	2019-09-26 11:59:24	2019-09-26 16:34:37	21	0	\N	\N
417325	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur	\N	2019-10-24 11:30:00	2019-10-24 12:30:00	\N	\N	0	0	\N	\N
420689	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Presse	PLF 2020 - Crédits Presse	2019-10-29 15:30:00	2019-10-29 16:30:00	\N	\N	1	0	\N	\N
420691	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-10-29 14:00:00	2019-10-29 14:30:00	2019-10-29 14:15:26	2019-10-29 17:49:53	26	2	\N	\N
420692	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Recherche	PLF 2020 - Crédits Recherche	2019-10-21 09:00:00	2019-10-21 12:30:00	\N	\N	1	0	\N	\N
420693	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Recherche	PLF 2020 - Crédits Recherche	2019-10-22 10:00:00	2019-10-22 13:00:00	\N	\N	1	0	\N	\N
420694	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Recherche	PLF 2020 - Crédits Recherche	2019-10-22 16:00:00	2019-10-22 17:00:00	\N	\N	1	0	\N	\N
420695	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Recherche	PLF 2020 - Crédits Recherche	2019-10-24 09:00:00	2019-10-24 11:00:00	\N	\N	1	0	\N	\N
420696	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Recherche	PLF 2020 - Crédits Recherche	2019-10-24 15:00:00	2019-10-24 18:00:00	\N	\N	1	0	\N	\N
420702	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition PLF 2020 - avis administration pénitentiaire	\N	2019-10-28 17:30:00	2019-10-28 18:15:00	\N	\N	1	0	\N	\N
420765	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-11-06 16:30:00	2019-11-06 18:00:00	2019-11-08 17:06:17	2019-11-08 17:07:15	27	0	\N	\N
420981	COM_ENQUETE	AUTRE	\N	LUBRIZOL	\N	Réunion de commission	\N	2019-10-29 16:00:00	2019-10-29 18:20:00	2019-10-29 19:11:01	2019-10-30 14:57:11	11	0	\N	\N
422728	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2020 - APD	\N	2019-10-29 16:15:00	2019-10-29 18:15:00	\N	\N	1	0	\N	\N
422730	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2020 - Programme 185	\N	2019-10-29 16:30:00	2019-10-29 17:15:00	\N	\N	2	0	\N	\N
422733	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2020 - Programme 185	\N	2019-10-30 16:00:00	2019-10-30 16:45:00	\N	\N	2	0	\N	\N
422738	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 30 octobre 2019	Réunion de la commission des affaires européennes du 30 octobre 2019	2019-10-30 16:40:00	2019-10-30 18:20:00	2019-10-31 10:59:38	2019-10-31 11:44:27	8	0	\N	\N
424989	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Enseignement scolaire	PLF 2020 - Crédits Enseignement scolaire	2019-11-06 16:30:00	2019-11-06 17:15:00	\N	\N	2	0	\N	\N
428227	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Logement - Mme Estrosi Sassone	PJLF 2020 Audition Mme Estrosi Sassone avis logement	2019-11-14 10:00:00	2019-11-14 11:15:00	\N	\N	1	0	\N	\N
428233	COM_ENQUETE	AUTRE	\N	LUBRIZOL	\N	Réunion de commission	\N	2019-11-19 09:00:00	2019-11-19 11:00:00	2019-11-19 11:02:37	2019-11-19 15:05:18	14	0	\N	\N
428234	COM_ENQUETE	PLENIERE	\N	LUBRIZOL	\N	Réunion de commission	\N	2019-11-19 16:30:00	2019-11-19 18:55:00	2019-11-19 18:57:44	2019-11-20 16:18:04	9	0	\N	\N
428235	COM_ENQUETE	AUTRE	\N	LUBRIZOL	\N	Réunion de commission	\N	2019-11-20 16:30:00	2019-11-20 18:25:00	2019-11-20 19:24:29	2019-11-21 10:28:31	14	0	\N	\N
428236	COM_ENQUETE	PLENIERE	\N	LUBRIZOL	\N	Réunion de commission	\N	2019-11-21 15:35:00	2019-11-21 18:25:00	2019-11-21 18:39:41	2019-11-22 17:01:44	9	0	\N	\N
428237	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-11-19 17:40:00	2019-11-19 18:05:00	2019-11-19 18:26:47	2019-11-20 17:04:10	28	0	\N	\N
428238	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-11-20 08:35:00	2019-11-20 09:30:00	2019-11-21 18:42:51	2019-11-22 17:00:57	30	0	\N	\N
428240	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-11-20 17:30:00	2019-11-20 19:15:00	2019-11-21 18:41:22	2019-11-22 17:00:53	26	0	\N	\N
428241	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-11-21 10:30:00	2019-11-22 10:55:00	2019-11-21 11:03:47	2019-11-21 15:13:12	25	0	\N	\N
428242	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2020 - Examen missions réservées - Missions Cohésion des territoires-Solidarité	PLF pour 2020 - Examen missions réservées - Missions Cohésion des territoires-Solidarité	2019-11-20 16:35:00	2019-11-20 19:00:00	2019-11-20 19:46:31	2019-11-21 10:29:20	32	0	\N	\N
428243	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2020 - Examen mission réservée - Examen définitif de l'équilibre seconde partie	PLF pour 2020 - Examen mission réservée - Examen définitif de l'équilibre seconde partie	2019-11-21 09:00:00	2019-11-21 09:50:00	2019-11-21 13:05:11	2019-11-21 15:13:11	25	1	\N	\N
428245	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2020 - Première partie - Examen des amendements de séance	PLF pour 2020 - Première partie - Examen des amendements de séance	2019-11-22 09:00:00	2019-11-22 10:40:00	2019-11-22 11:24:05	2019-11-22 17:00:54	23	0	\N	\N
428246	COM_PERMANENTE	DEPLACEMENT	\N	CDD	\N	Avis biodiversité M. Chevrollier - Météopole Toulouse	PJLF 2020 - Avis biodiversité - M. Chevrollier	2019-11-12 08:00:00	2019-11-12 18:00:00	\N	\N	1	0	\N	\N
428248	ETUDES	AUDRAP	\N	\N	\N	GEAC - Audition SNPL	GEAC - Audition SNPL	2019-11-14 08:30:00	2019-11-14 10:00:00	\N	\N	5	0	\N	933
428254	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - MIRES - Recherche - CEA / AFPC	PLF pour 2020 - MIRES - Recherche - CEA / AFPC	2019-11-12 14:00:00	2019-11-12 15:30:00	\N	\N	1	0	\N	\N
428256	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - MIRES - Enseignement supérieur - DGESIP	PLF pour 2020 - MIRES - Enseignement supérieur - DGESIP	2019-11-12 16:00:00	2019-11-12 17:00:00	\N	\N	1	0	\N	\N
428258	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - MIRES - Recherche et Enseignement supérieur - Cabinet Ministre	PLF pour 2020 - MIRES - Recherche et Enseignement supérieur - Cabinet Ministre Ens Sup et Rech	2019-11-12 18:00:00	2019-11-12 19:00:00	\N	\N	2	0	\N	\N
428261	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - MIRES - Recherche - IRSN	PLF pour 2020 - MIRES - Recherche - IRSN	2019-11-13 17:15:00	2019-11-13 18:15:00	\N	\N	1	0	\N	\N
428262	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - MIRES - Enseignement supérieur - CDEI	PLF pour 2020 - MIRES - Enseignement supérieur - CDEI	2019-11-13 18:30:00	2019-11-13 19:15:00	\N	\N	1	0	\N	\N
428265	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Cohésion des territoires - Logement et urbanisme - DGCS	PLF pour 2020 - Cohésion des territoires - Logement et urbanisme - DGCS	2019-11-12 09:00:00	2019-11-12 09:45:00	\N	\N	1	0	\N	\N
428267	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Écologie - Secrétariat Général Ministère	PLF pour 2020 - Écologie - Secrétariat Général Ministère	2019-11-12 17:00:00	2019-11-12 18:00:00	\N	\N	1	0	\N	\N
484747	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Mesures de sûreté (nomination CMP et rapport) - PJLO Mandat CESE (rapport)	PPL Mesures de sûreté (nomination CMP et rapport) - PJLO Mandat CESE (rapport)	2020-07-15 09:00:00	2020-07-15 11:40:00	2020-07-15 14:42:47	2020-07-15 18:38:44	21	2	\N	\N
485907	MISSION	AUCUNE	\N	DEPARTEMENT	\N	Audition de Régions de France	\N	2020-07-22 13:50:00	2020-07-22 15:00:00	2020-07-22 18:51:14	2020-07-23 18:20:08	8	0	\N	\N
485910	COM_ENQUETE	PLENIERE	\N	PANDEMIE	\N	Audition 	\N	2020-07-22 16:35:00	2020-07-23 18:40:00	2020-07-22 18:41:07	2020-07-23 18:20:11	21	0	\N	\N
485911	COM_ENQUETE	PLENIERE	\N	PANDEMIE	\N	Audition plénière sur la gestion de la pandémie dans l'Oise	\N	2020-07-23 09:30:00	2020-07-23 12:40:00	2020-07-28 17:28:28	2020-07-28 17:30:29	19	0	\N	\N
428239	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-11-20 09:30:00	2019-11-20 11:55:00	2019-11-21 18:42:12	2019-11-22 17:00:56	47	0	\N	\N
485920	COM_PERMANENTE	AUTRE	\N	FINC	\N	PJLR 2019 Nlle Lecture-Examen Rappport - Controles Budget. Controle fiscal-Fonds Européen	PJLR 2019 Nlle Lecture-Examen Rappport - Controles Budget. Controle fiscal-Fonds Européen	2020-07-22 09:32:00	2020-07-22 10:52:00	2020-07-22 14:18:39	2020-07-22 18:00:36	21	1	\N	\N
486032	MISSION	AUDRAP	\N	DEPARTEMENT	\N	Audition de la direction générale des collectivités locales	\N	2020-07-22 11:00:00	2020-07-22 12:00:00	\N	\N	1	0	\N	\N
486038	ETUDES	AUCUNE	\N	\N	\N	Auditions plénières GE Cancer	\N	2020-07-27 09:00:00	2020-07-27 11:40:00	\N	\N	3	0	\N	1004
486066	DELEGATION	AUDRAP	\N	\N	DSOM	Réunion avec des constitutionnalistes	\N	2020-07-23 14:00:00	2020-07-23 17:20:00	\N	\N	9	0	\N	\N
486659	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - Fonds européen - CICC	Contrôle 2020 - Fonds européen - CICC	2020-07-15 14:30:00	2020-07-15 15:00:00	\N	\N	1	0	\N	\N
487909	COM_ENQUETE	PLENIERE	\N	PANDEMIE	\N	Table ronde de praticiens hospitaliers et professionnels de santé	\N	2020-07-28 14:30:00	2020-07-28 17:00:00	2020-07-28 19:49:43	2020-07-29 15:37:41	22	0	\N	\N
487910	COM_ENQUETE	PLENIERE	\N	PANDEMIE	\N	Table ronde d'élus	\N	2020-07-29 09:35:00	2020-07-29 12:55:00	2020-07-30 17:14:31	2020-07-31 14:25:38	22	0	\N	\N
487927	ETUDES	AUDRAP	\N	\N	\N	GEAC - Audition Antoine BOUVIER Airbus	GEAC - Audition Antoine BOUVIER Airbus	2020-07-23 09:00:00	2020-07-23 10:20:00	\N	\N	9	0	\N	933
487975	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19 - Gestion des déchets - FNSEA	Covid-19-Gestion des déchets-FNSEA	2020-07-22 14:10:00	2020-07-22 15:00:00	\N	\N	3	0	\N	\N
487979	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Alimentation durable et locale-France Urbaine	Covid-19-Alimentation durable et locale-France Urbaine	2020-07-21 14:30:00	2020-07-21 15:45:00	\N	\N	2	0	\N	\N
488275	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	GT Expertise psychiatrique en matière pénale	GT Expertise psychiatrique en matière pénale	2020-07-28 10:00:00	2020-07-28 13:00:00	\N	\N	1	0	\N	\N
488277	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2020-07-22 09:05:00	2020-07-22 15:35:00	\N	\N	3	0	\N	\N
488447	COM_ENQUETE	PLENIERE	\N	SOLS	\N	Examen du projet de rapport de la commission d'enquête	\N	2020-09-08 15:06:00	2020-09-08 16:14:00	2020-09-08 17:41:53	2020-09-09 17:42:13	9	0	\N	\N
488467	MISSION	AUCUNE	\N	ILLECTRONISM	\N	Audition du Conseil national du numérique	\N	2020-09-09 15:05:00	2020-09-09 16:20:00	2020-09-10 10:42:56	2020-09-10 16:13:35	3	0	\N	\N
488468	MISSION	AUDRAP	\N	ILLECTRONISM	\N	Audition du recteur de l'Académie de Toulouse	\N	2020-09-09 11:45:00	2020-09-09 12:20:00	\N	\N	1	0	\N	\N
488469	MISSION	AUCUNE	\N	ILLECTRONISM	\N	Audition de Cédric O.	\N	2020-09-09 16:35:00	2020-09-09 17:35:00	2020-09-10 10:43:39	2020-09-10 16:13:37	3	0	\N	\N
489027	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - Le franc CFA - Économistes	Contrôle 2020 - Le franc CFA - Économistes	2020-09-10 15:00:00	2020-09-10 17:55:00	\N	\N	2	0	\N	\N
489030	COM_ENQUETE	PLENIERE	\N	PANDEMIE	\N	Audition du Pr Jean-François Delfraissy, président du conseil scientifique	\N	2020-09-15 10:30:00	2020-09-15 13:20:00	2020-09-15 13:20:48	2020-09-15 17:25:56	20	0	\N	\N
489031	COM_ENQUETE	PLENIERE	\N	PANDEMIE	\N	Audition du Pr Didier Raoult, directeur de l'IHU Méditerranée Infection	\N	2020-09-15 15:00:00	2020-09-15 17:10:00	2020-09-15 17:42:55	2020-09-16 18:02:27	24	0	\N	\N
489032	COM_ENQUETE	PLENIERE	\N	PANDEMIE	\N	Table ronde avec des experts scientifiques	\N	2020-09-15 17:15:00	2020-09-15 19:00:00	2020-09-15 19:03:41	2020-09-16 18:02:25	18	0	\N	\N
489033	COM_ENQUETE	PLENIERE	\N	PANDEMIE	\N	Table ronde avec des experts en santé publique	\N	2020-09-16 09:00:00	2020-09-16 11:50:00	2020-09-16 14:42:29	2020-09-16 18:02:24	17	0	\N	\N
489034	COM_ENQUETE	PLENIERE	\N	PANDEMIE	\N	Table ronde avec des acteurs institutionnels	\N	2020-09-16 14:30:00	2020-09-16 17:55:00	2020-09-17 09:33:45	2020-09-17 12:02:37	22	0	\N	\N
489035	COM_ENQUETE	PLENIERE	\N	PANDEMIE	\N	Audition  de Mme Marisol Touraine, ancienne ministre de la Santé	\N	2020-09-17 09:30:00	2020-09-17 11:00:00	2020-09-17 12:13:50	2020-09-18 17:16:20	18	0	\N	\N
489036	COM_ENQUETE	PLENIERE	\N	PANDEMIE	\N	Audition de Mme Roselyne Bachelot, ancienne ministre de la Santé	\N	2020-09-17 11:05:00	2020-09-17 12:30:00	2020-09-17 12:28:58	2020-09-18 17:16:21	18	0	\N	\N
489037	COM_ENQUETE	PLENIERE	\N	PANDEMIE	\N	Table ronde d'anciens directeurs généraux de la santé	\N	2020-09-17 14:00:00	2020-09-17 15:50:00	2020-09-17 15:53:44	2020-09-18 17:16:22	11	0	\N	\N
489038	COM_ENQUETE	PLENIERE	\N	PANDEMIE	\N	Audition de M. Gérald Darmanin, ministre de l'Intérieur	\N	2020-09-17 16:00:00	2020-09-17 17:15:00	2020-09-17 17:15:23	2020-09-18 17:16:24	15	0	\N	\N
489039	MISSION	AUCUNE	\N	DEPARTEMENT	\N	Examen et adoption du rapport de la mission.	Examen et adoption du rapport de la mission.	2020-09-15 11:05:00	2020-09-15 12:20:00	2020-09-15 12:56:26	2020-09-15 17:25:54	4	0	\N	\N
489040	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Prévention de la perte d'autonomie - Audition de la CNAM	\N	2020-09-08 09:30:00	2020-09-08 10:30:00	\N	\N	1	0	\N	\N
489346	DELEGATION	AUCUNE	\N	\N	211	Evénement sur l'engagement des femmes dans la Résistance	Evénement sur l'engagement des femmes dans la Résistance	2020-09-15 14:30:00	2020-09-15 17:30:00	\N	\N	11	0	\N	\N
489363	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	211	Cérémonie de remise des prix 2020 de la délégation	Cérémonie de remise des prix 2020 de la délégation	2020-09-15 18:00:00	2020-09-15 19:00:00	\N	\N	7	0	\N	\N
489553	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - Les ambassadeurs thématiques - SG MEAE	Contrôle 2020 - Les ambassadeurs thématiques - SG MEAE	2020-09-18 15:00:00	2020-09-18 16:00:00	\N	\N	2	0	\N	\N
489592	GIA	AUCUNE	\N	\N	\N	Entretien avec SE RAmi ADWAN, ambassadeur du Liban à Paris	Entretien avec SE RAmi ADWAN, ambassadeur du Liban à Paris	2020-09-16 12:30:00	2020-09-16 14:30:00	\N	\N	4	0	597	\N
489597	GIA	AUCUNE	\N	\N	\N	Auditions de François BOUSTANI et du COLIF	Auditions de François BOUSTANI et du Conseil des Libanais de France	2020-09-15 15:00:00	2020-09-15 17:20:00	\N	\N	5	0	597	\N
489603	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Fuad HUSSEIN, ministre des affaires étrangères de l'Irak 	Entretien avec une délégation conduite par M. Fuad HUSSEIN, ministre des affaires étrangères de l'Irak 	2020-09-18 10:45:00	2020-09-18 11:30:00	\N	\N	1	0	615	\N
494748	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2021 - Assurance maladie - Audition du LEEM	\N	2020-10-20 17:30:00	2020-10-20 19:00:00	\N	\N	1	0	\N	\N
488152	CMP	AUTRE	\N	SURETE	\N	PPL Mesures de sûreté contre les auteurs d'infractions terroristes	PPL Mesures de sûreté contre les auteurs d'infractions terroristes	2020-07-22 17:19:00	2020-07-22 18:03:00	\N	\N	8	0	\N	\N
489605	GIA	AUCUNE	\N	\N	\N	Auditions de M. Ziad MAJED et de représentants du collectif IIIe République	Auditions de M. Ziad MAJED et de représentants du collectif IIIe République	2020-09-09 16:30:00	2020-09-09 18:00:00	\N	\N	4	0	597	\N
489759	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL LPPR	\N	2020-09-22 10:00:00	2020-09-22 11:45:00	\N	\N	4	0	\N	\N
489764	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL LPPR	\N	2020-09-22 15:00:00	2020-09-22 16:45:00	\N	\N	4	0	\N	\N
379039	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI responsabilité civile	\N	2019-05-15 14:30:00	2019-05-15 18:00:00	\N	\N	3	0	\N	\N
379961	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	PROS	Conférence de presse 	Conférence de presse de présentation du rapport "Adaptation de la France aux dérèglements climatiques à l'horizon 2050"	2019-05-16 10:30:00	2019-05-16 12:00:00	\N	\N	2	0	\N	\N
384217	ETUDES	AUCUNE	\N	\N	\N	Table ronde PMU	Table ronde PMU	2019-05-28 18:00:00	2019-05-28 19:00:00	\N	\N	4	0	\N	912
385979	GIA	AUCUNE	\N	\N	\N	Audition Ahmet Insel	\N	2019-06-05 08:30:00	2019-06-05 10:00:00	\N	\N	4	0	624	\N
387799	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Le numérique à l'école - Educapital	Contrôle 2019 - Le numérique à l'école - Educapital	2019-06-07 13:15:00	2019-06-07 14:00:00	\N	\N	1	0	\N	\N
389034	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-06-12 09:35:00	2019-06-12 12:00:00	2019-06-14 10:48:25	2019-06-14 10:54:06	37	0	\N	\N
391472	DELEGATION	DEPLACEMENT	\N	\N	206	Visite du Salon international de l'aéronautique et de l'espace au Bourget 	Visite du Salon international de l'aéronautique et de l'espace au Bourget	2019-06-20 09:00:00	2019-06-20 14:15:00	\N	\N	6	0	\N	\N
391473	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière - Auditions IRSN et CNE2	Réunion plénière - Auditions IRSN et CNE2	2019-06-27 09:45:00	2019-06-27 13:05:00	\N	\N	11	0	\N	\N
395445	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ambassadeur de Mongolie en France, son Excellence Avirmid BATTUR	ntretien avec l'ambassadeur de Mongolie en France, son Excellence Avirmid BATTUR	2019-06-26 08:25:00	2019-06-26 09:30:00	\N	\N	2	0	612	\N
400241	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 2019 - Pilotage des opérateurs de l'action extérieure de l'État - Cour des comptes	58-2 2019 - Pilotage des opérateurs de l'action extérieure de l'État - Cour des comptes	2019-07-10 10:30:00	2019-07-10 11:30:00	\N	\N	2	0	\N	\N
400244	MISSION	AUCUNE	\N	FONDS	\N	Réunion du 11 juillet 2019	\N	2019-07-11 14:00:00	2019-07-11 15:35:00	2019-07-11 16:02:57	2019-07-11 17:44:18	5	0	\N	\N
400273	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-07-16 14:05:00	2019-07-16 14:35:00	2019-07-16 15:05:58	2019-07-16 17:50:12	26	1	\N	\N
400285	COM_PERMANENTE	AUTRE	\N	FINC	\N	Contrôles budgétaires Cohésion des territoires et Aff. Euro - Audition 58-2 TGIR	Contrôles budgétaires Cohésion des territoires et Aff. Euro - Audition 58-2 TGIR	2019-07-17 09:05:00	2019-07-17 12:45:00	2019-07-17 16:41:34	2019-07-17 18:22:01	33	0	\N	\N
410835	COM_ENQUETE	PLENIERE	\N	SOUVERAINETE	\N	\N	\N	2019-10-01 18:35:00	2019-10-01 19:55:00	2019-10-07 15:38:00	2019-10-07 15:40:00	12	0	\N	\N
425522	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Economie	PLF pour 2020 - Economie	2019-12-02 10:00:00	2019-12-02 12:17:00	\N	\N	39	0	\N	\N
425592	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Remboursements et dégrèvements	PLF pour 2020 - Remboursement	2019-12-02 12:18:00	2019-12-02 13:35:00	\N	\N	30	0	\N	\N
425603	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Remboursements et dégrèvements	PLF pour 2020 - Remboursements	2019-12-02 18:00:00	2019-12-02 18:23:00	\N	\N	28	0	\N	\N
425611	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Gestion des finances publiques	PLF pour 2020 - Gestion des finances publiques	2019-12-02 18:24:00	2019-12-02 20:07:00	\N	\N	48	0	\N	\N
425613	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Travail et emploi	PLF pour 2020 - Travail et emploi	2019-12-06 09:30:00	2019-12-06 11:53:00	\N	\N	36	0	\N	\N
425616	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Défense	PLF pour 2020 - Défense	2019-12-02 21:40:00	2019-12-02 23:58:00	\N	\N	44	0	\N	\N
425619	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2019-12-03 09:30:00	2019-12-03 12:36:00	\N	\N	40	0	\N	\N
425623	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Cohésion des territoires	PLF pour 2020 - Cohésion des territoires	2019-12-03 14:30:00	2019-12-03 19:09:00	\N	\N	167	0	\N	\N
425625	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Agriculture, alimentation, forêt et affaires rurales	PLF pour 2020 - Agriculture	2019-12-03 19:10:00	2019-12-03 20:02:00	\N	\N	50	0	\N	\N
425630	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Agriculture, alimentation, forêt et affaires rurales	PLF pour 2020 - Agriculture	2019-12-03 21:30:00	2019-12-04 00:25:00	\N	\N	76	0	\N	\N
425636	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Relations avec les collectivités territoriales	PLF pour 2020 - RCT	2019-12-04 14:45:00	2019-12-04 20:30:00	\N	\N	121	0	\N	\N
425655	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Outre-mer	PLF pour 2020 - Outre-mer	2019-12-05 10:30:00	2019-12-05 12:58:00	\N	\N	59	0	\N	\N
425659	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Culture	PLF pour 2020 - Culture	2019-12-05 15:48:00	2019-12-05 17:45:00	\N	\N	57	0	\N	\N
425661	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Médias, livre et industries culturelles	PLF pour 2020 - Médias	2019-12-05 17:46:00	2019-12-05 19:47:00	\N	\N	49	0	\N	\N
400276	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-07-17 09:45:00	2019-07-17 10:25:00	2019-07-17 15:00:19	2019-07-17 18:22:00	33	2	\N	\N
425664	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Justice	PLF pour 2020 - Justice	2019-12-05 21:30:00	2019-12-05 23:30:00	\N	\N	23	0	\N	\N
428273	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Relations avec les collectivités territoriales	PLF pour 2020 - Relations avec les collectivités territoriales	2019-12-04 10:30:00	2019-12-04 13:16:00	\N	\N	110	0	\N	\N
433965	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-12-04 09:22:00	2019-12-04 11:50:00	2019-12-04 15:03:06	2019-12-04 15:15:17	28	0	\N	\N
438299	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Juan Salazar Sparks, ambassadeur du Chili	Entretien avec M. Juan Salazar Sparks, ambassadeur du Chili	2019-12-11 08:00:00	2019-12-11 09:15:00	\N	\N	8	0	978	\N
439719	BUREAU	AUCUNE	\N	\N	\N	Bureau	Bureau	2019-12-12 09:00:00	2019-12-12 11:30:00	\N	\N	18	0	\N	\N
439787	COM_ENQUETE	PLENIERE	\N	LUBRIZOL	\N	auditions commission d'enquête	auditions commission d'enquête	2019-12-12 14:30:00	2019-12-12 15:35:00	2019-12-12 18:04:34	2019-12-13 12:11:31	7	0	\N	\N
443898	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PJL Economie circulaire	Conclusions de la commission mixte paritaire sur le projet de loi relatif à la lutte contre le gaspillage et à l'économi	2020-01-30 14:30:00	2020-01-30 15:33:00	\N	\N	21	0	\N	\N
444150	DELEGATION	AUDRAP	\N	\N	206	Audition Production d'énergie dans le secteur agricole	Audition Production d'énergie dans le secteur agricole	2020-01-14 10:00:00	2020-01-14 12:00:00	\N	\N	1	0	\N	\N
492448	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Conférence interparlementaire article 13 du TSCG en Visioconférence	Conférence interparlementaire article 13 du TSCG en Visioconférence	2020-10-12 14:45:00	2020-10-12 16:15:00	\N	\N	1	0	\N	\N
492451	DELEGATION	AUCUNE	\N	\N	211	Audition de Mme Brigitte Grésy - présidente du HCE	Audition de Mme Brigitte Grésy - présidente du HCE	2020-11-19 09:00:00	2020-11-19 10:55:00	2020-11-19 12:12:09	\N	17	0	\N	\N
492688	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Mise sur le marché de certains produits phytopharmaceutiques	\N	2020-09-29 10:45:00	2020-09-29 13:00:00	\N	\N	1	0	\N	\N
492691	DELEGATION	AUCUNE	\N	\N	211	Audition de MM. Arnaud Bazin et Éric Bocquet	Audition de MM. Arnaud Bazin et Éric Bocquet	2020-12-10 09:00:00	2020-12-10 10:30:00	2020-12-10 11:00:25	\N	19	0	\N	\N
492692	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	auditions restitutions	\N	2020-10-14 14:30:00	2020-10-14 15:20:00	\N	\N	3	0	\N	\N
492698	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2020-10-21 09:00:00	2020-10-21 09:50:00	2020-10-21 12:10:23	2020-10-22 18:43:04	31	0	\N	\N
492699	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2020-10-21 08:30:00	2020-10-21 08:55:00	2020-10-21 12:09:44	2020-10-22 18:43:06	27	0	\N	\N
492903	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2020-10-21 09:55:00	2020-10-21 11:00:00	2020-10-21 12:10:51	2020-10-22 18:43:03	34	0	\N	\N
492924	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-10-20 17:30:00	2020-10-20 19:05:00	2020-10-20 19:14:09	2020-10-22 18:43:06	34	0	\N	\N
492999	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Mise sur le marché de certains produits phytopharmaceutiques	\N	2020-10-01 09:00:00	2020-10-01 10:30:00	\N	\N	1	0	\N	\N
493001	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Mise sur le marché de certains produits phytopharmaceutiques	\N	2020-10-06 09:30:00	2020-10-06 11:00:00	\N	\N	1	0	\N	\N
493004	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Mise sur le marché de certains produits phytopharmaceutiques	\N	2020-10-12 17:00:00	2020-10-12 20:30:00	\N	\N	5	0	\N	\N
493010	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Mise sur le marché de certains produits phytopharmaceutiques	\N	2020-10-13 08:30:00	2020-10-13 09:30:00	\N	\N	7	0	\N	\N
493017	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2021 - Branche Famille	\N	2020-10-14 16:30:00	2020-10-14 17:45:00	\N	\N	1	0	\N	\N
493022	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Mise sur le marché de certains produits phytopharmaceutiques	\N	2020-10-13 09:30:00	2020-10-13 11:00:00	\N	\N	16	0	\N	\N
493052	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PROG Programmation de la recherche pour les années 2021 à 2030	PROG Programmation de la recherche pour les années 2021 à 2030	2020-10-05 09:00:00	2020-10-05 12:30:00	\N	\N	1	0	\N	\N
493054	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PROG Programmation de la recherche pour les années 2021 à 2030	PROG Programmation de la recherche pour les années 2021 à 2030	2020-10-05 14:45:00	2020-10-05 17:00:00	\N	\N	1	0	\N	\N
493056	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PROG Programmation de la recherche pour les années 2021 à 2030	PROG Programmation de la recherche pour les années 2021 à 2030	2020-10-06 09:00:00	2020-10-06 10:00:00	\N	\N	1	0	\N	\N
493058	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PROG Programmation de la recherche pour les années 2021 à 2030	PROG Programmation de la recherche pour les années 2021 à 2030	2020-10-07 16:00:00	2020-10-07 19:00:00	\N	\N	1	0	\N	\N
493059	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PROG Programmation de la recherche pour les années 2021 à 2030	PROG Programmation de la recherche pour les années 2021 à 2030	2020-10-08 15:30:00	2020-10-08 17:45:00	\N	\N	1	0	\N	\N
493063	COM_PERMANENTE	AUDRAP	\N	CAE	\N	A	PROG Programmation de la recherche pour les années 2021 à 2030	2020-10-12 16:30:00	2020-10-12 17:15:00	\N	\N	1	0	\N	\N
493184	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Mise sur le marché de certains produits phytopharmaceutiques	PJL Mise sur le marché de certains produits phytopharmaceutiques	2020-10-13 18:30:00	2020-10-13 19:00:00	\N	\N	6	0	\N	\N
493949	DELEGATION	AUCUNE	\N	\N	COLTER	Réunion constitutive de la délégation	Réunion constitutive de la délégation	2020-10-22 09:15:00	2020-10-22 09:40:00	\N	\N	22	0	\N	\N
494531	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2020-10-29 16:00:00	2020-10-29 18:00:00	\N	\N	0	0	\N	\N
494732	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Audition PJL Restitutions	Audition de M. Debie, avocat	2020-10-20 10:30:00	2020-10-20 11:00:00	\N	\N	4	0	\N	\N
494737	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Audition PJL Restitutions	Audition Ambassade du Sénégal	2020-10-20 15:30:00	2020-10-20 16:30:00	\N	\N	3	0	\N	\N
494741	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2021 - Branche autonomie - Audition de l'ADF	\N	2020-10-20 13:30:00	2020-10-20 14:30:00	\N	\N	2	0	\N	\N
494742	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2021 - Branche autonomie - Audition de la DGCS	\N	2020-10-20 14:30:00	2020-10-20 15:30:00	\N	\N	2	0	\N	\N
494743	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2021 - Branche autonomie - Audition du Synerpa	\N	2020-10-20 15:30:00	2020-10-20 16:30:00	\N	\N	2	0	\N	\N
494744	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFS 2021 - Branche autonomie - Audition de la CNSA	\N	2020-10-20 16:30:00	2020-10-20 17:30:00	\N	\N	1	0	\N	\N
494745	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2021 - Branche autonomie - Audition de Collectif handicaps	\N	2020-10-20 17:30:00	2020-10-20 18:30:00	\N	\N	1	0	\N	\N
494746	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2021 - Branche autonomie - Audition de Groupe SOS	\N	2020-10-20 18:30:00	2020-10-20 19:30:00	\N	\N	1	0	\N	\N
494747	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2021 - Assurance maladie - Audition conjointe des fédérations hospitalières	\N	2020-10-20 15:30:00	2020-10-20 17:15:00	\N	\N	3	0	\N	\N
502349	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2021	PLF pour 2021	2020-12-03 14:30:00	2020-12-03 20:10:00	\N	\N	98	0	\N	\N
492923	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-10-21 09:30:00	2020-10-21 12:00:00	2020-10-21 14:55:29	2020-10-21 15:10:24	40	0	\N	\N
494749	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2021 - Assurance maladie - Audition du Collectif des maisons de naissance	\N	2020-10-21 14:15:00	2020-10-21 15:00:00	\N	\N	1	0	\N	\N
494750	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2021 - Assurance maladie - Audition conjointe des syndicats de médecins libéraux	\N	2020-10-21 17:00:00	2020-10-21 18:15:00	\N	\N	1	0	\N	\N
495112	COM_EURO	AUTRE	\N	AFEU	\N	Audition de M. Clément Beaune	\N	2020-10-28 16:30:00	2020-10-28 18:20:00	2020-10-28 18:22:33	2020-10-29 18:28:16	25	0	\N	\N
495213	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT subsidiarité	Groupe de travail Subsidiarité	2020-10-22 08:35:00	2020-10-22 09:00:00	\N	\N	8	0	\N	\N
495254	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Action logement - PEEC	Action logement - PEEC	2020-10-20 14:30:00	2020-10-20 15:30:00	\N	\N	4	0	\N	\N
495259	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Action logement - PEEC	Action logement - PEEC	2020-10-20 15:30:00	2020-10-20 16:00:00	\N	\N	4	0	\N	\N
495264	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Action logement - PEEC	Action logement - PEEC	2020-10-20 16:00:00	2020-10-20 16:30:00	\N	\N	3	0	\N	\N
495266	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Prorogation de l'état d'urgence sanitaire (rapport et texte de la commission)	PJL Prorogation de l'état d'urgence sanitaire (rapport et texte de la commission)	2020-10-27 15:10:00	2020-10-27 16:50:00	2020-10-27 17:37:06	2020-10-28 12:13:03	27	0	\N	\N
495268	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJLO Simplification des expérimentations de l'article 72 de la Constitution (rapport)	PJLO Simplification des expérimentations de l'article 72 de la Constitution (rapport)	2020-10-28 09:30:00	2020-10-28 10:15:00	2020-10-28 11:57:32	2020-10-28 12:19:03	29	0	\N	\N
495269	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Prorogation de l'état d'urgence sanitaire (amendements de séance)	PJL Prorogation de l'état d'urgence sanitaire (amendements de séance)	2020-10-29 18:25:00	2020-10-29 19:10:00	\N	\N	24	0	\N	\N
495273	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Action logement - PEEC - Medef	Action logement - PEEC - Medef	2020-10-20 16:30:00	2020-10-20 17:00:00	\N	\N	4	0	\N	\N
495288	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Base aérienne d'Evreux	Base aérienne d'Evreux	2020-10-15 07:00:00	2020-10-15 18:30:00	\N	\N	9	0	\N	\N
495298	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLO Simplification des expérimentations de l'article 72 de la Constitution	PJLO Simplification des expérimentations art.72 C	2020-10-22 14:00:00	2020-10-22 16:45:00	\N	\N	4	0	\N	\N
495305	BUREAU	AUCUNE	\N	\N	\N	Bureau du Sénat	Bureau du Sénat	2020-10-22 10:30:00	2020-10-22 12:00:00	\N	\N	22	0	\N	\N
495438	DELEGATION	AUCUNE	\N	\N	PROS	Audition de Futuribles sur l'utilité et les méthodes de la prospective	Audition de MM. Yannick Blanc, président, et François de Jouvenel, délégué général, Futuribles	2020-11-12 08:30:00	2020-11-12 10:00:00	\N	\N	20	0	\N	\N
376901	COM_ENQUETE	PLENIERE	\N	SOUVERAINETE	\N	Réunion constitutive	Réunion constitutive	2019-05-07 13:30:00	2019-05-07 14:00:00	2019-05-10 10:43:47	2019-05-10 16:56:41	17	0	\N	\N
378424	ETUDES	AUCUNE	\N	\N	\N	Audition de M. Roland SUSSE	Audition de M. Roland SUSSE	2019-05-15 08:00:00	2019-05-15 09:30:00	\N	\N	10	0	\N	948
392682	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT Stratégie industrielle de l'UE	GT Stratégie industrielle de l'UE	2019-06-19 15:00:00	2019-06-19 16:30:00	\N	\N	2	0	\N	\N
405447	DELEGATION	AUCUNE	\N	\N	DSOM	Nomination de rapporteurs et audition de la ministre des outre-mer	\N	2019-10-17 08:45:00	2019-10-17 11:40:00	\N	\N	17	0	\N	\N
405450	MISSION	AUCUNE	\N	AERIEN	\N	Réunion plénière	\N	2019-09-24 09:02:00	2019-09-24 10:21:00	2019-09-24 11:12:16	2019-09-24 15:34:46	14	0	\N	\N
405468	MISSION	DEPLACEMENT	\N	MARITIME	\N	MCI Sauvetage en mer - Déplacement Côtes d'Armor - Ille-et-Vilaine	MCI Sauvetage en mer - Déplacement Côtes d'Armor - Ille-et-Vilaine	2019-09-23 06:30:00	2019-09-23 21:30:00	\N	\N	4	0	\N	\N
405615	MISSION	AUCUNE	\N	TRANSPORTS	\N	Examen et adoption du rapport	\N	2019-09-25 13:35:00	2019-09-25 14:40:00	2019-09-25 14:40:37	2019-09-25 15:39:41	15	1	\N	\N
426884	ETUDES	AUTRE	\N	\N	\N	Audition plénière	Audition FEVS	2019-11-13 14:00:00	2019-11-13 15:00:00	\N	\N	18	0	\N	909
428269	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Cohésion des territoires - DMAT	PLF pour 2020 - Cohésion des territoires - DMAT	2019-11-12 16:00:00	2019-11-12 17:00:00	\N	\N	1	0	\N	\N
428271	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Solidarité - Observatoire violences femmes / FFC	PLF pour 2020 - Solidarité - Observatoire violences femmes / FFC	2019-11-13 16:00:00	2019-11-13 18:00:00	\N	\N	1	0	\N	\N
428274	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Solidarité - ADF	PLF pour 2020 - Solidarité - ADF	2019-11-14 17:00:00	2019-11-14 18:00:00	\N	\N	1	0	\N	\N
428276	COM_SPECIALE	PLENIERE	\N	BIOETHIQUE	\N	Audition commune des professionnels de l'étude et de la conservation des oeufs	Audition commune des professionnels de l'étude et de la conservation des oeufs	2019-11-20 13:50:00	2019-11-20 15:00:00	2019-11-20 15:03:49	2019-11-20 16:18:04	21	0	\N	\N
428277	COM_SPECIALE	PLENIERE	\N	BIOETHIQUE	\N	CS Bioéthique - Audition commune sur la recherche sur l'embryon	CS Bioéthique - Audition commune sur la recherche sur l'embryon	2019-11-21 10:15:00	2019-11-21 11:50:00	2019-11-21 11:54:33	2019-11-21 16:31:05	20	0	\N	\N
428278	GIA	AUCUNE	\N	\N	\N	Institut Choiseul	Rencontre avec les lauréats du classement Choiseul 100 Russie	2019-11-14 18:30:00	2019-11-14 19:30:00	\N	\N	1	0	608	\N
428280	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	CETA	\N	2019-11-13 16:00:00	2019-11-13 17:00:00	\N	\N	1	0	\N	\N
428282	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Négociations commerciales	\N	2019-11-13 13:00:00	2019-11-13 14:30:00	\N	\N	1	0	\N	\N
428284	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Sport	PLF 2020 - Crédits Sport	2019-11-13 17:30:00	2019-11-13 18:30:00	\N	\N	1	0	\N	\N
428358	GIA	AUCUNE	\N	\N	\N	Déjeuner de travail - Délégation du Conseil fédéral d'Autriche	\N	2019-11-14 12:30:00	2019-11-14 14:30:00	\N	\N	5	0	579	\N
428364	GIA	AUCUNE	\N	\N	\N	Accueil délégation Conseil fédéral d'Autriche	\N	2019-11-14 14:30:00	2019-11-14 15:45:00	\N	\N	1	0	579	\N
428507	ETUDES	AUCUNE	\N	\N	\N	Déplacement en Normandie	Déplacement en Normandie	2019-11-18 08:00:00	2019-11-18 20:00:00	\N	\N	5	0	\N	1007
429074	GIA	AUCUNE	\N	\N	\N	Coopé - Visite d'une délégation de sénateurs cambodgiens	Coopé - Visite d'une délégation de sénateurs cambodgiens	2019-11-19 12:30:00	2019-11-19 14:00:00	\N	\N	1	0	577	\N
429076	GIA	AUCUNE	\N	\N	\N	Coopé - Visite d'une délégation de sénateurs cambodgiens	Coopé - Visite d'une délégation de sénateurs cambodgiens	2019-11-19 15:45:00	2019-11-19 16:45:00	\N	\N	0	0	577	\N
431449	DELEGATION	AUDRAP	\N	\N	PROS	Audition du WWF	\N	2019-12-12 10:20:00	2019-12-12 11:50:00	\N	\N	1	0	\N	\N
431450	DELEGATION	AUDRAP	\N	\N	PROS	Audition du Museum national d'histoire naturelle	\N	2019-12-10 13:30:00	2019-12-10 14:30:00	\N	\N	1	0	\N	\N
431548	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 28 novembre 2019	Réunion du 28 novembre 2019	2019-11-28 10:45:00	2019-11-28 13:00:00	2019-11-28 15:13:00	2019-11-28 15:29:53	10	0	\N	\N
502350	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2021	PLF pour 2021	2020-12-03 21:40:00	2020-12-04 02:00:00	\N	\N	54	0	\N	\N
431549	COM_EURO	AUTRE	\N	AFEU	\N	Auditions de la commission des affaires européennes - Audition plénière	\N	2019-11-28 10:00:00	2019-11-28 11:30:00	\N	\N	0	0	\N	\N
431563	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Usages dangereux du protoxyde d'azote	\N	2019-11-20 16:30:00	2019-11-20 18:40:00	\N	\N	1	0	\N	\N
431564	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Usages dangereux du protoxyde d'azote	\N	2019-11-21 14:30:00	2019-11-21 15:30:00	\N	\N	1	0	\N	\N
431575	COM_SPECIALE	AUDRAP	\N	BIOETHIQUE	\N	Audition M. Jomier - Dons d'organes et greffes	\N	2019-11-21 14:00:00	2019-11-21 14:45:00	\N	\N	4	0	\N	\N
431576	COM_SPECIALE	AUDRAP	\N	BIOETHIQUE	\N	Audition M. Jomier - Dons d'organes et greffes	\N	2019-11-21 14:45:00	2019-11-21 16:00:00	\N	\N	3	0	\N	\N
434777	GIA	AUCUNE	\N	\N	\N	audition de M. Michel Testot, ambassadeur de France auprès du Yémen	\N	2019-11-27 11:00:00	2019-11-27 12:30:00	\N	\N	1	0	627	\N
435332	COM_PERMANENTE	AUTRE	\N	CAE	\N	GE Énergie - Table ronde "Nucléaire"	GE Énergie - Table ronde sur "L'innovation dans le secteur du nucléaire"	2019-11-27 13:30:00	2019-11-27 15:00:00	\N	\N	7	0	\N	\N
435735	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Pastoralisme	GT Pastoralisme	2019-11-28 13:30:00	2019-11-28 15:30:00	\N	\N	7	0	\N	\N
440427	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-12-18 09:35:00	2019-12-18 11:20:00	2019-12-18 17:56:51	2019-12-19 15:16:49	32	0	\N	\N
440931	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe interparlementaire d'amitié France-Finlande	Assemblée générale du groupe interparlementaire d'amitié France-Finlande	2019-12-18 14:30:00	2019-12-18 15:00:00	\N	\N	7	0	640	\N
440941	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de commission du 18/12/2019	\N	2019-12-18 13:30:00	2019-12-18 15:00:00	2019-12-18 15:38:20	2019-12-18 17:42:13	14	0	\N	\N
441219	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition PPL Droits sociaux des travailleurs numériques - DGT et DGEFP	\N	2019-12-17 14:45:00	2019-12-17 15:45:00	\N	\N	1	0	\N	\N
441220	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition PPL Droits sociaux des travailleurs numérique - CG Scop	\N	2019-12-17 15:45:00	2019-12-17 16:45:00	\N	\N	1	0	\N	\N
441230	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition PPL Droits sociaux des travailleurs numériques - Plateformes	\N	2019-12-17 16:45:00	2019-12-17 17:45:00	\N	\N	2	0	\N	\N
441588	GIA	AUCUNE	\N	\N	\N	Coopé - Visite du SG du Sénat ivoirien et du SGA du Gouvernement ivoirien	Coopé - Visite du SG du Sénat ivoirien et du SGA du Gouvernement ivoirien	2019-12-17 12:30:00	2019-12-17 14:30:00	\N	\N	1	0	573	\N
441657	GIA	AUCUNE	\N	\N	\N	dîner à la résidence de l'ambassadeur de Corée du Sud en France	\N	2019-12-11 19:30:00	2019-12-11 22:30:00	\N	\N	2	0	613	\N
441660	GIA	AUCUNE	\N	\N	\N	déjeuner avec le secrétaire général de la Ligue islamique mondiale	\N	2019-12-12 13:00:00	2019-12-12 14:30:00	\N	\N	2	0	661	\N
441663	GIA	AUCUNE	\N	\N	\N	colloque sur la femme omanaise	\N	2019-12-19 12:15:00	2019-12-19 16:00:00	\N	\N	1	0	661	\N
441665	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition difficultés de recrutement et évolution des métiers	Audition difficultés de recrutement et évolution des métiers - OPCO	2019-12-19 09:05:00	2019-12-19 10:45:00	\N	\N	2	0	\N	\N
441807	DELEGATION	AUCUNE	\N	\N	211	Audition de Mme Hélène Furnon-Petrescu, cheffe de service du droit des femmes	Audition de Mme Hélène Furnon-Petrescu, cheffe de service du droit des femmes	2020-01-14 16:45:00	2020-01-14 18:05:00	2020-01-14 18:21:50	\N	5	0	\N	\N
441808	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes - Autre	\N	2020-01-15 13:30:00	2020-01-15 14:00:00	\N	\N	0	0	\N	\N
441809	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes - Autre	\N	2020-01-15 14:30:00	2020-01-15 15:00:00	\N	\N	0	0	\N	\N
441810	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 14 janvier 2020	Audition de Mme Sandrine Gaudin	2020-01-14 17:00:00	2020-01-14 18:30:00	2020-01-14 18:31:04	2020-01-15 09:32:41	14	0	\N	\N
441811	COM_EURO	AUTRE	\N	AFEU	\N	Auditions de la commission des affaires européennes - Audition plénière	\N	2020-01-14 16:00:00	2020-01-14 17:30:00	\N	\N	0	0	\N	\N
441812	DELEGATION	AUCUNE	\N	\N	DSOM	Audition de la FEDOM	\tDélégation sénatoriale aux outre-mer - Audition de la FEDOM	2020-02-04 16:15:00	2020-02-04 18:10:00	\N	\N	12	0	\N	\N
441813	COM_ENQUETE	AUTRE	\N	LUBRIZOL	\N	Audition plénière	\N	2020-01-14 09:00:00	2020-01-14 10:00:00	\N	\N	0	0	\N	\N
489769	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL LPPR	\N	2020-09-23 10:45:00	2020-09-23 13:00:00	\N	\N	4	0	\N	\N
489774	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL LPPR	\N	2020-09-23 14:45:00	2020-09-23 17:30:00	\N	\N	4	0	\N	\N
489808	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLO Conseil économique, social et environnemental	\N	2020-09-24 15:00:00	2020-09-24 15:45:00	\N	\N	1	0	\N	\N
489810	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLO Conseil économique, social et environnemental	\N	2020-09-23 16:30:00	2020-09-23 18:15:00	\N	\N	2	0	\N	\N
489813	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLO Conseil économique, social et environnemental	\N	2020-09-23 14:00:00	2020-09-23 15:00:00	\N	\N	1	0	\N	\N
489831	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Terr	\N	2020-10-01 10:00:00	2020-10-01 11:00:00	\N	\N	2	0	\N	\N
489832	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Santé environnementale - Table ronde SFSE/SFSP	\N	2020-09-25 09:00:00	2020-09-25 11:00:00	\N	\N	1	0	\N	\N
489834	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Santé environnementale - Audition de Mme Stéphane Horel	\N	2020-09-25 11:00:00	2020-09-25 12:00:00	\N	\N	1	0	\N	\N
489847	GIA	AUCUNE	\N	\N	\N	Entretien avec S.E.M. KET Sophann, Ambassadeur du Cambodge	Entretien avec S.E.M. KET Sophann, Ambassadeur du Cambodge	2020-09-23 13:00:00	2020-09-23 14:30:00	\N	\N	2	0	577	\N
489889	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Audition MI restitutions	\N	2020-09-28 10:00:00	2020-09-28 12:30:00	\N	\N	2	0	\N	\N
489947	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	\N	2020-09-29 11:15:00	2020-09-29 12:15:00	\N	\N	4	0	\N	\N
489952	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	\N	2020-09-29 16:10:00	2020-09-29 17:10:00	\N	\N	3	0	\N	\N
489987	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition MM. Bruno Le Maire et Olivier Dussopt sur le PLF pour 2021	Audition MM. Bruno Le Maire et Olivier Dussopt sur le PLF pour 2021	2020-09-30 17:05:00	2020-09-30 18:55:00	2020-10-01 11:09:31	2020-10-01 16:28:54	31	0	\N	\N
489992	DELEGATION	AUCUNE	\N	\N	211	Échange de vues sur l'organisation du travail de la délégation	Échange de vues sur l'organisation du travail de la délégation	2020-10-29 08:30:00	2020-10-29 10:00:00	\N	\N	18	0	\N	\N
490056	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Prévention de la perte d'autonomie - Audition de AG2R La Mondiale	\N	2020-09-29 15:00:00	2020-09-29 16:00:00	\N	\N	2	0	\N	\N
490057	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Prévention de la perte d'autonomie - Audition du Pr Bruno Vellas	\N	2020-09-29 16:00:00	2020-09-29 17:00:00	\N	\N	2	0	\N	\N
490487	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 7 octobre 2020	Réunion du 7 octobre 2020	2020-10-07 15:45:00	2020-10-07 16:30:00	2020-10-07 17:22:45	2020-10-07 18:03:45	34	0	\N	\N
439532	CMP	AUTRE	\N	PROXIMITE	\N	PJL Engagement et proximité	PJL Engagement et proximité	2019-12-11 17:06:00	2019-12-11 18:56:00	\N	\N	11	0	\N	\N
439548	CMP	AUTRE	\N	PLF2020	\N	PLF pour 2020	PLF pour 2020	2019-12-11 17:30:00	2019-12-11 17:50:00	\N	\N	9	0	\N	\N
490769	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - PPLC/PPLO libertés locales	\N	2020-10-06 19:00:00	2020-10-06 20:15:00	\N	\N	5	0	\N	\N
491002	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL LPPR	\N	2020-10-05 10:30:00	2020-10-05 11:30:00	\N	\N	3	0	\N	\N
491377	DELEGATION	AUDRAP	\N	\N	PROS	Audition de la FUB	Audition de M. Olivier Schneider, président de la Fédération des Usagers de la Bicyclette	2020-10-22 09:15:00	2020-10-22 10:00:00	\N	\N	1	0	\N	\N
491378	DELEGATION	AUDRAP	\N	\N	PROS	Audition de l'AMF	Audition de l'AMF	2020-10-22 10:00:00	2020-10-22 10:45:00	\N	\N	1	0	\N	\N
491379	DELEGATION	AUCUNE	\N	\N	PROS	Réunion constitutive de la délégation	Réunion constitutive de la délégation	2020-10-22 10:45:00	2020-10-22 11:15:00	\N	\N	22	0	\N	\N
491439	DELEGATION	AUDRAP	\N	\N	PROS	Audition de l'ARF	\N	2020-10-22 11:45:00	2020-10-22 12:45:00	\N	\N	1	0	\N	\N
491441	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 14/10/2020	Réunion du 14/10/2020 - Débat préalable au Conseil européen	2020-10-14 18:00:00	2020-10-14 20:30:00	2020-10-15 10:48:33	2020-10-15 14:55:36	29	0	\N	\N
491869	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2020-09-09 09:40:00	2020-09-09 12:55:00	\N	\N	1	0	\N	\N
493370	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPLC et PPLO Pour le plein exercice des libertés locales - amendements de séance	PPLC et PPLO Pour le plein exercice des libertés locales - amendements de séance	2020-10-20 09:30:00	2020-10-20 10:00:00	2020-10-20 10:04:46	2020-10-21 14:38:49	23	0	\N	\N
494099	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2021 - EFE - AFT	PLF pour 2021 - EFE - AFT	2020-10-20 16:40:00	2020-10-20 18:45:00	\N	\N	1	0	\N	\N
494103	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2020-10-21 15:00:00	2020-10-21 16:30:00	\N	\N	193	0	\N	\N
494295	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Assassinat de Samuel Paty - Audition de Jean-Michel Blanquer et Gérald Darmanin	Assassinat de Samuel Paty - Audition de Jean-Michel Blanquer et Gérald Darmanin	2020-10-22 11:30:00	2020-10-22 13:30:00	2020-10-22 18:47:20	2020-10-23 17:26:47	42	0	\N	\N
494596	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2021 - Accidents du travail - Maladies professionnelles - Audition de la FIVA	\N	2020-10-21 14:15:00	2020-10-21 15:00:00	\N	\N	1	0	\N	\N
494838	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Table ronde - situation salle de spectacle - COVID	\N	2020-10-27 17:20:00	2020-10-27 18:55:00	2020-10-27 20:09:41	2020-10-28 12:12:53	16	0	\N	\N
494845	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Prévention de la perte d'autonomie - Auditions Danemark	\N	2020-10-21 16:30:00	2020-10-21 17:15:00	\N	\N	2	0	\N	\N
494846	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Prévention de la perte d'autonomie - Audition de Mme Anne Smetana	\N	2020-10-22 10:15:00	2020-10-22 11:30:00	\N	\N	2	0	\N	\N
494847	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Prévention de la perte d'autonomie - Audition de M. Jakob Krogh	\N	2020-10-22 09:00:00	2020-10-22 10:00:00	\N	\N	2	0	\N	\N
494848	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Prévention de la perte d'autonomie - Audition du Ministère de la Santé danois	\N	2020-10-22 14:00:00	2020-10-22 15:15:00	\N	\N	2	0	\N	\N
494849	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Prévention de la perte d'autonomie - Audition de Mme Marianne Lundsgaard	\N	2020-10-22 15:30:00	2020-10-22 16:15:00	\N	\N	1	0	\N	\N
494918	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Auditions plénières	\N	2020-10-28 09:30:00	2020-10-28 12:15:00	2020-10-28 12:16:00	2020-10-28 14:33:12	36	0	\N	\N
494919	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de Mme Brigitte Bourguignon	\N	2020-10-27 17:30:00	2020-10-27 18:35:00	2020-10-27 18:48:19	2020-10-28 12:12:45	22	0	\N	\N
494943	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-10-27 14:00:00	2020-10-27 14:25:00	2020-10-27 16:41:26	2020-10-27 17:12:13	25	0	\N	\N
494946	COM_PERMANENTE	AUTRE	\N	CAE	\N	Chantiers de l'Atlantique - Examen de rapport d¿information	\N	2020-10-28 09:35:00	2020-10-28 10:30:00	2020-10-28 12:32:38	2020-10-28 14:33:15	35	0	\N	\N
495106	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Deux conventions, auditions du général Thierry Burkhard et amiral Pierre Vandier	\N	2020-10-28 09:30:00	2020-10-28 13:00:00	2020-10-28 15:01:04	2020-10-28 15:21:21	32	0	\N	\N
495107	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de M. Clément Beaune	\N	2020-10-28 16:35:00	2020-10-28 18:20:00	2020-10-29 11:16:59	2020-10-29 18:26:39	37	0	\N	\N
495240	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJLF pour 2021 - p 146	PJLF pour 2021 - p 146	2020-10-21 18:00:00	2020-10-21 19:00:00	\N	\N	2	0	\N	\N
495407	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2021 - Programme Hébergement	\N	2020-10-22 15:00:00	2020-10-22 18:00:00	\N	\N	1	0	\N	\N
495409	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2021 - Programme Hébergement	\N	2020-10-26 14:30:00	2020-10-26 16:15:00	\N	\N	1	0	\N	\N
495430	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	\N	2020-10-21 16:40:00	2020-10-21 18:10:00	\N	\N	3	0	\N	\N
495436	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL échange de permis de conduire avec le Qatar et la Chine	PJL échange de permis de conduire avec le Qatar et la Chine	2020-10-26 15:30:00	2020-10-26 16:15:00	\N	\N	1	0	\N	\N
495579	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2020-10-28 09:03:00	2020-10-28 12:14:00	2020-10-28 14:22:23	2020-10-28 14:33:09	32	0	\N	\N
497172	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJLO Article 72 Constitution	PJLO Article 72 Constitution	2020-11-03 14:30:00	2020-11-03 17:00:00	\N	\N	76	0	\N	\N
497173	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJLO Article 72 Constitution	PJLO Article 72 Constitution	2020-11-03 21:30:00	2020-11-03 23:30:00	\N	\N	0	0	\N	\N
497174	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2020-11-04 15:00:00	2020-11-04 16:20:00	\N	\N	207	0	\N	\N
497179	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Produits phytopharmaceutiques	CMP Produits phytopharmaceutiques	2020-11-04 17:45:00	2020-11-04 19:00:00	\N	\N	70	0	\N	\N
497197	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PPL Zéro chômeur	CMP PPL Zéro chômeur	2020-11-04 19:00:00	2020-11-04 20:05:00	\N	\N	47	0	\N	\N
386389	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Organisation système de santé	PJL Organisation système de santé	2019-06-07 09:30:00	2019-06-07 13:05:00	\N	\N	38	0	\N	\N
386615	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-06-12 11:25:00	2019-06-12 11:50:00	2019-06-12 16:37:31	2019-06-12 16:55:40	32	0	\N	\N
386795	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière	Réunion plénière	2019-06-05 12:30:00	2019-06-05 14:00:00	\N	\N	15	0	\N	\N
386828	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition de l'Autorité de la Concurrence	Audition de l'Autorité de la Concurrence - Isabelle DE SILVA, Présidente	2019-06-05 14:30:00	2019-06-05 15:30:00	\N	\N	2	0	\N	\N
497007	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2021 - Programme 178	\N	2020-10-27 14:00:00	2020-10-27 15:45:00	\N	\N	2	0	\N	\N
386613	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-06-12 09:35:00	2019-06-12 11:25:00	2019-06-12 15:02:49	2019-06-12 16:55:39	43	0	\N	\N
386838	DELEGATION	DEPLACEMENT	\N	\N	ENTREPRISES	Déplacement à Station F	Déplacement à Station F - table ronde sur la transformation numérique des PME	2019-06-06 08:30:00	2019-06-06 11:30:00	\N	\N	4	0	\N	\N
394813	GIA	AUCUNE	\N	\N	\N	Visite de M. Meraneh Daher Maraneh de Djibouti (coopé)	Visite de M. Meraneh Daher Maraneh de Djibouti (coopé)	2019-06-18 12:30:00	2019-06-18 14:30:00	\N	\N	1	0	588	\N
394871	GIA	AUCUNE	\N	\N	\N	Visite d'une délégation de 20 sénateurs américains (coopé)	Visite d'une délégation de 20 sénateurs américains (coopé)	2019-06-07 11:00:00	2019-06-07 11:45:00	\N	\N	1	0	590	\N
394875	GIA	AUCUNE	\N	\N	\N	Visite de M. Iddrisu HARUNA, parlementaire ghanéen (coopé)	Visite de M. Iddrisu HARUNA, parlementaire ghanéen (coopé)	2019-05-21 11:30:00	2019-05-21 12:30:00	\N	\N	1	0	573	\N
397607	GIA	AUCUNE	\N	\N	\N	Réunion du groupe	Réunion du groupe	2019-07-03 08:30:00	2019-07-03 09:30:00	\N	\N	3	0	627	\N
397612	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation de députés de Corée du Sud	Accueil d'une délégation de députés de Corée du Sud	2019-07-02 12:30:00	2019-07-02 14:30:00	\N	\N	9	0	613	\N
397623	GIA	AUCUNE	\N	\N	\N	Entretien avec une délégation de députés de Corée du Sud	Entretien avec une délégation de députés de Corée du Sud	2019-07-02 15:00:00	2019-07-02 16:00:00	\N	\N	4	0	613	\N
397628	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation de députés de Corée du Sud	Accueil d'une délégation de députés de Corée du Sud	2019-07-02 16:15:00	2019-07-02 17:00:00	\N	\N	4	0	613	\N
397633	GIA	AUCUNE	\N	\N	\N	Entretien avec une délégation de députés de Corée du Sud	Entretien avec une délégation de députés de Corée du Sud	2019-07-02 17:15:00	2019-07-02 18:15:00	\N	\N	4	0	613	\N
397638	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation de députés de Corée du Sud	Accueil d'une délégation de députés de Corée du Sud	2019-07-01 14:30:00	2019-07-01 18:30:00	\N	\N	2	0	613	\N
401365	GIA	AUCUNE	\N	\N	\N	Audition d'une délégation de parlementaires irakiens	Audition d'une délégation de parlementaires irakiens	2019-07-16 15:30:00	2019-07-16 16:45:00	\N	\N	15	0	CHRETORIENT	CHRETORIENT
404947	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	\N	\N	2019-09-06 15:30:00	2019-09-06 17:00:00	\N	\N	0	0	\N	\N
404948	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	Réunion du vendredi 6 septembre 2019	\N	2019-09-06 15:30:00	2019-09-06 17:00:00	\N	\N	0	0	\N	\N
404949	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-09-10 16:05:00	2019-09-10 18:35:00	2019-09-11 09:14:25	2019-09-12 15:33:54	26	0	\N	\N
416957	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2019-10-15 19:35:00	2019-10-15 19:55:00	\N	\N	22	0	\N	\N
420601	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution plastique	Audition rapporteurs Pollution plastique (PlasticsEurope)	2019-11-05 16:30:00	2019-11-05 18:00:00	\N	\N	2	0	\N	\N
420608	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution plastique 	Audition rapporteurs Pollution plastique (Groupe Michelin)	2019-11-12 14:30:00	2019-11-12 15:30:00	\N	\N	2	0	\N	\N
420615	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution plastique	Audition rapporteurs Pollution plastique (Table ronde Cosmétiques)	2019-11-12 15:45:00	2019-11-12 17:30:00	\N	\N	2	0	\N	\N
420618	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution plastique	Audition rapporteurs Pollution plastique (L'Occitane en Provence)	2019-11-12 17:30:00	2019-11-12 18:30:00	\N	\N	2	0	\N	\N
420623	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution plastique	Audition rapporteurs Pollution plastique (ministère des outre-mer)	2019-11-21 09:15:00	2019-11-21 10:15:00	\N	\N	2	0	\N	\N
420626	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution plastique	Audition rapporteurs Pollution plastique (Table ronde Restauration)	2019-11-21 10:30:00	2019-11-21 12:00:00	\N	\N	2	0	\N	\N
421479	GIA	AUCUNE	\N	\N	\N	Coopé - Visite de Mme Ksenia Svetlova, journaliste israélienne	Coopé - Visite de Mme Ksenia Svetlova, journaliste israélienne	2019-10-29 17:00:00	2019-10-29 18:00:00	\N	\N	1	0	595	\N
423596	GIA	AUCUNE	\N	\N	\N	Accueil de délégation chypriote	Accueil de délégation chypriote - Accueil	2019-06-18 09:45:00	2019-06-18 11:00:00	\N	\N	1	0	585	\N
423598	GIA	AUCUNE	\N	\N	\N	Accueil de délégation chypriote	Accueil de délégation chypriote - Déjeuner AN	2019-06-18 13:00:00	2019-06-18 14:30:00	\N	\N	1	0	585	\N
423600	GIA	AUCUNE	\N	\N	\N	Accueil de délégation chypriote	Accueil de délégation chypriote - Accueil par le VP	2019-06-18 15:00:00	2019-06-18 16:00:00	\N	\N	2	0	585	\N
423603	GIA	AUCUNE	\N	\N	\N	Accueil de délégation chypriote	Accueil de délégation chypriote - Slutation en tribune	2019-06-18 16:00:00	2019-06-18 16:30:00	\N	\N	1	0	585	\N
423605	GIA	AUCUNE	\N	\N	\N	Accueil de délégation chypriote	Accueil de délégation chypriote - Dîner	2019-06-18 20:00:00	2019-06-19 00:00:00	\N	\N	3	0	585	\N
423610	GIA	AUCUNE	\N	\N	\N	Accueil de délégation chypriote	Accueil de délégation chypriote - Déjeuner	2019-06-19 13:00:00	2019-06-19 15:00:00	\N	\N	3	0	585	\N
423614	GIA	AUCUNE	\N	\N	\N	Accueil de délégation chypriote	Accueil de délégation chypriote - Entretien avec MM. Cambon et Bizet	2019-06-18 17:00:00	2019-06-18 18:30:00	\N	\N	1	0	585	\N
423616	GIA	AUCUNE	\N	\N	\N	Accueil de délégation chypriote	Accueil de délégation chypriote - Déjeuner	2019-06-20 13:00:00	2019-06-20 15:00:00	\N	\N	1	0	585	\N
431979	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition GS Stratégie industrielle de l'UE	Audition DG Trésor	2019-11-26 10:15:00	2019-11-26 11:30:00	\N	\N	6	0	\N	\N
437745	COM_SPECIALE	AUDRAP	\N	BIOETHIQUE	\N	Audition Mme Jourda Chancellerie - DACS	\N	2019-12-04 09:30:00	2019-12-04 11:30:00	\N	\N	2	0	\N	\N
437746	COM_SPECIALE	AUDRAP	\N	BIOETHIQUE	\N	Audition Mme Jourda pédopsychiatres art. 1 et 2	\N	2019-12-04 15:15:00	2019-12-04 16:15:00	\N	\N	3	0	\N	\N
437747	COM_SPECIALE	AUDRAP	\N	BIOETHIQUE	\N	Audition Mme Jourda Table ronde Juristes art. 4 	\N	2019-12-04 16:15:00	2019-12-04 18:00:00	\N	\N	1	0	\N	\N
437846	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2020 - Examen AMDTS de coordination	PLF pour 2020 - Examen AMDTS de coordination	2019-12-09 20:10:00	2019-12-09 20:15:00	2019-12-10 09:47:37	2019-12-10 17:06:06	13	0	\N	\N
443787	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution plastique	Audition rapporteurs Pollution plastique (DGPR)	2020-01-30 16:30:00	2020-01-30 17:30:00	\N	\N	2	0	\N	\N
443790	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution plastique	Audition rapporteurs Pollution plastique - Table ronde 	2020-02-04 15:30:00	2020-02-04 17:30:00	\N	\N	2	0	\N	\N
443793	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution plastique	Audition rapporteurs Pollution plastique (Loom)	2020-02-04 17:45:00	2020-02-04 18:45:00	\N	\N	2	0	\N	\N
443796	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteur Phagothérapie	Audition rapporteur Phagothérapie - Dr Alain Dublanchet	2020-01-14 15:30:00	2020-01-14 16:45:00	\N	\N	1	0	\N	\N
443798	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteur Phagothérapie	Audition rapporteur Phagothérapie - ANSM	2020-01-15 14:00:00	2020-01-15 15:00:00	\N	\N	1	0	\N	\N
433943	CMP	AUTRE	\N	FAMILLE	\N	PPL Agir contre les violences au sein de la famille	PPL Agir contre les violences au sein de la famille	2019-11-27 19:05:00	2019-11-27 22:15:00	\N	\N	9	0	\N	\N
497839	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL Convention Inde stupéfiants	\N	2020-10-27 09:45:00	2020-10-27 10:30:00	\N	\N	1	0	\N	\N
497981	GIA	AUCUNE	\N	\N	\N	Remise de la médaille du Sénat à S.E.M. Jong-Moon Choi, Ambassadeur de Corée du Sud	\N	2020-10-30 10:00:00	2020-10-30 10:30:00	\N	\N	1	0	613	\N
497983	COM_PERMANENTE	AUTRE	\N	ETRD	\N	PLF 2021 - Audition M. JY Le Drian	\N	2020-11-03 17:45:00	2020-11-03 19:40:00	2020-11-04 14:15:26	2020-11-04 15:59:18	33	0	\N	\N
497984	COM_PERMANENTE	AUTRE	\N	ETRD	\N	PLF 2021 - Auditions François Delattre puis SGDSN et ANSSI	\N	2020-11-04 09:35:00	2020-11-04 12:30:00	2020-11-04 14:14:46	2020-11-04 15:59:20	34	0	\N	\N
498011	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF 2021 - Programmes 844 et 847	\N	2020-10-27 14:30:00	2020-10-27 16:30:00	\N	\N	2	0	\N	\N
498060	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Convention France-Inde produits illicites	PJL Convention France-Inde produits illicites	2020-11-04 16:35:00	2020-11-04 17:45:00	\N	\N	0	0	\N	\N
498191	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2021 - Auditon fédération addictions	PLF 2021 - Audition fédération addictions	2020-11-02 17:00:00	2020-11-02 18:00:00	\N	\N	3	0	\N	\N
498192	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2021 - Audition  de l'OFDT	PLF 2021 - Audition de l'OFDT	2020-11-02 16:00:00	2020-11-02 17:00:00	\N	\N	3	0	\N	\N
498193	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2021 - Auditions du Dr Nicolas Prisse, Président de la MILDECA	PLF 2021 - Auditions du Dr Nicolas Prisse, Président de la MILDECA	2020-11-02 15:00:00	2020-11-02 16:00:00	\N	\N	3	0	\N	\N
498205	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Amendements de séance PJL restitutions	\N	2020-11-04 09:30:00	2020-11-04 10:15:00	2020-11-04 12:47:45	2020-11-04 16:52:50	38	0	\N	\N
498477	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2020-10-28 14:05:00	2020-10-28 14:55:00	\N	\N	24	0	\N	\N
498503	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2020-11-03 17:30:00	2020-11-03 18:48:00	2020-11-04 10:19:12	2020-11-04 12:44:28	26	0	\N	\N
498721	BUREAU	AUCUNE	\N	\N	\N	Bureau du Sénat	Bureau du Sénat	2020-11-04 09:00:00	2020-11-04 11:30:00	\N	\N	25	0	\N	\N
498985	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Prorogation de l'état d'urgence sanitaire (NL) (rapport et texte de la commission)	PJL Prorogation de l'état d'urgence sanitaire (NL) (rapport et texte de la commission)	2020-11-05 14:00:00	2020-11-05 14:10:00	2020-11-05 16:28:44	2020-11-05 17:28:50	26	0	\N	\N
499452	DELEGATION	AUDRAP	\N	\N	PROS	Audition de M. Eric Charmes	\N	2020-11-09 17:15:00	2020-11-09 18:30:00	\N	\N	1	0	\N	\N
499974	COM_PERMANENTE	AUTRE	\N	AFCL	\N	PLF 2021 - Enseignement agricole	\N	2020-11-10 09:30:00	2020-11-10 10:33:00	2020-11-10 11:26:58	2020-11-12 16:29:47	29	0	\N	\N
499975	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Plf 2021 - Crédits de l'audiovisuel public	Table ronde syndicats Radio France	2020-11-10 15:30:00	2020-11-10 17:00:00	\N	\N	2	0	\N	\N
499976	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Plf 2021 - Crédits de l'audiovisuel public	Table ronde syndicats FT	2020-11-12 16:30:00	2020-11-12 18:00:00	\N	\N	3	0	\N	\N
499978	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2021 - Avis Justice judiciaire	PLF pour 2021 - Avis Justice judiciaire	2020-11-04 14:30:00	2020-11-04 17:00:00	\N	\N	2	0	\N	\N
500029	COM_EURO	AUTRE	\N	AFEU	\N	Audition de Mme Dunja Mijatovic, Commissaire aux droits de l'Homme du Conseil de l'Europe	\N	2020-11-12 08:30:00	2020-11-12 10:15:00	\N	\N	0	0	\N	\N
500050	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2021 - Mission Solidarité	\N	2020-11-05 09:30:00	2020-11-05 10:45:00	\N	\N	3	0	\N	\N
500116	COM_PERMANENTE	AUTRE	\N	AFCL	\N	PLF 2021 - Audition Roselyne Bachelot	\N	2020-11-10 17:00:00	2020-11-10 19:25:00	2020-11-12 08:43:28	2020-11-12 16:56:32	32	0	\N	\N
500170	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2021 - programme 129	\N	2020-11-03 14:30:00	2020-11-03 16:15:00	\N	\N	2	0	\N	\N
500173	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2021 Mission Solidarité	\N	2020-11-05 13:45:00	2020-11-05 14:30:00	\N	\N	3	0	\N	\N
500189	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF 2021 Avis Recherche - Université Gustave Eiffel	PLF 2021 Avis Recherche - Université Gustave Eiffel	2020-11-02 10:00:00	2020-11-02 10:45:00	\N	\N	1	0	\N	\N
500190	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2021 - programme 151	\N	2020-11-04 13:45:00	2020-11-04 15:00:00	\N	\N	2	0	\N	\N
500194	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL 2021 Avis Recherche - IRSN	PJL 2021 Avis Recherche - Université Gustave Eiffel	2020-11-02 11:00:00	2020-11-02 12:00:00	\N	\N	1	0	\N	\N
500196	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Recherche - Auditions de M. Marchand	PJL 2021 Avis Recherche - Inéris	2020-11-03 16:00:00	2020-11-03 16:45:00	\N	\N	1	0	\N	\N
500232	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJLF 2021 Avis Recherche - Université Gustave Eiffel	PJLF 2021 Avis Recherche - Université Gustave Eiffel	2020-11-03 16:45:00	2020-11-03 17:30:00	\N	\N	1	0	\N	\N
500234	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Avis Cohésion des territoires - Logement - Mme Estrosi Sassone - USH	Avis Cohésion des territoires - Logement - Mme Estrosi Sassone - USH	2020-11-04 17:00:00	2020-11-04 17:30:00	\N	\N	1	0	\N	\N
500235	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Avis cohésion des territoires - Logement - Mme Estrosi Sassone - Action logement PACA	Avis cohésion des territoires - Logement - Mme Estrosi Sassone - Action logement PACA	2020-11-04 17:30:00	2020-11-04 18:00:00	\N	\N	1	0	\N	\N
500241	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Règles de passation des marchés publics locaux (rapport et texte de la commission)	PPL Règles de passation des marchés publics locaux (rapport et texte de la commission)	2020-11-10 09:30:00	2020-11-10 10:05:00	2020-11-10 10:35:25	2020-11-10 10:45:23	26	0	\N	\N
500242	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Réforme Action logement - PEEC - JL Borloo	Réforme Action logement - PEEC - JL Borloo	2020-11-03 14:00:00	2020-11-03 15:00:00	\N	\N	4	0	\N	\N
500243	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Réforme Action logement - PEEC - CFDT	Réforme Action logement - PEEC - CFDT	2020-11-03 15:00:00	2020-11-03 15:30:00	\N	\N	2	0	\N	\N
500244	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Réforme Action logement - PEEC - CFE-CGC	Réforme Action logement - PEEC - CFE-CGC	2020-11-03 15:30:00	2020-11-03 16:00:00	\N	\N	2	0	\N	\N
500245	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Réforme Action logement - PEEC - CPME	Réforme Action logement - PEEC - CPME	2020-11-03 16:00:00	2020-11-03 16:30:00	\N	\N	2	0	\N	\N
500246	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Réforme Action logement - PEEC - CGT	Réforme Action logement - PEEC - CGT	2020-11-03 16:30:00	2020-11-03 17:00:00	\N	\N	2	0	\N	\N
459607	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2019-10-08 08:30:00	2019-10-08 10:00:00	\N	\N	4	0	\N	\N
500247	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Réforme Action logement - PEEC - CFTC	Réforme Action logement - PEEC - CFTC	2020-11-03 17:00:00	2020-11-03 17:30:00	\N	\N	2	0	\N	\N
500248	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Réforme Action logement - PEEC - Action logement immobilier	Réforme Action logement - PEEC - Action logement immobilier	2020-11-03 17:30:00	2020-11-03 18:00:00	\N	\N	3	0	\N	\N
500249	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Réforme Action logement - PEEC - Action logement services	Réforme Action logement - PEEC - Action logement services	2020-11-03 18:00:00	2020-11-03 18:30:00	\N	\N	3	0	\N	\N
500250	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Réforme Action logement - PEEC - ALG	Réforme Action logement - PEEC - ALG	2020-11-04 11:00:00	2020-11-04 11:30:00	\N	\N	1	0	\N	\N
500267	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2021 - Avis Outre-mer	\N	2020-11-05 14:40:00	2020-11-05 16:00:00	\N	\N	1	0	\N	\N
500275	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Règles de passation des marchés publics locaux	\N	2020-11-04 16:30:00	2020-11-04 19:30:00	\N	\N	1	0	\N	\N
500279	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2021	Projet de loi de financement de la sécurité sociale pour 2021	2020-11-09 16:00:00	2020-11-09 19:15:00	\N	\N	66	0	\N	\N
500280	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2021	Projet de loi de financement de la sécurité sociale pour 2021	2020-11-09 21:30:00	2020-11-10 01:05:00	\N	\N	66	0	\N	\N
500281	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2021	Projet de loi de financement de la sécurité sociale pour 2021	2020-11-10 14:30:00	2020-11-10 17:55:00	\N	\N	95	0	\N	\N
500282	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2021	Projet de loi de financement de la sécurité sociale pour 2021	2020-11-12 10:30:00	2020-11-12 12:30:00	\N	\N	85	0	\N	\N
373899	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-04-30 09:00:00	2019-04-30 10:35:00	2019-04-30 11:58:54	2019-04-30 17:33:07	39	3	\N	\N
373900	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-04-30 13:45:00	2019-04-30 16:35:00	2019-04-30 17:51:51	2019-05-02 10:19:14	42	2	\N	\N
373901	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-04-30 18:05:00	2019-04-30 19:40:00	2019-04-30 20:54:58	2019-05-02 10:19:15	29	2	\N	\N
378819	ETUDES	AUCUNE	\N	\N	\N	Réunion du Bureau	Réunion du Bureau	2019-05-15 16:00:00	2019-05-15 16:50:00	\N	\N	7	0	\N	919
378827	ETUDES	AUCUNE	\N	\N	\N	Audition Mme Snipes	Audition Mme Snipes	2019-05-16 08:00:00	2019-05-16 10:00:00	\N	\N	20	0	\N	919
378933	COM_PERMANENTE	DEPLACEMENT	\N	CAE	\N	PPL Lutte contre l'habitat insalubre	PPL Lutte contre l'habitat insalubre - Déplacement en Guadeloupe	2019-05-09 11:00:00	2019-05-11 12:00:00	\N	\N	2	0	\N	\N
378936	COM_PERMANENTE	DEPLACEMENT	\N	CAE	\N	PPL Lutte contre l'habitat insalubre	PPL Lutte contre l'habitat insalubre - Déplacement en Martinique	2019-05-11 14:30:00	2019-05-13 17:00:00	\N	\N	3	0	\N	\N
379056	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	« Conséquences économiques des gilets jaunes »	« Conséquences économiques des gilets jaunes »	2019-05-15 14:30:00	2019-05-15 16:00:00	\N	\N	7	0	\N	\N
379099	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	« Conséquences économiques des gilets jaunes »	« Conséquences économiques des gilets jaunes »	2019-05-15 16:15:00	2019-05-15 17:45:00	\N	\N	4	0	\N	\N
405187	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - CGLLS - BPCE	Contrôle 2019 - CGLLS - BPCE	2019-09-09 16:00:00	2019-09-09 17:00:00	\N	\N	1	0	\N	\N
405191	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - CGLLS - Crédit Agricole	Contrôle 2019 - CGLLS - Crédit Agricole	2019-09-10 17:30:00	2019-09-10 18:30:00	\N	\N	1	0	\N	\N
405193	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2019 - Lutte contre les feux de forêt - Déplacement Marseille	Contrôle 2019 - Lutte contre les feux de forêt - Déplacement Marseille	2019-09-11 08:30:00	2019-09-11 20:00:00	\N	\N	1	0	\N	\N
405195	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2019 - ZRR - Déplacement Cantal	Contrôle 2019 - ZRR - Déplacement Cantal	2019-09-09 09:00:00	2019-09-10 15:00:00	\N	\N	3	0	\N	\N
412275	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL AVIA	\N	2019-10-09 14:00:00	2019-10-09 15:00:00	\N	\N	2	0	\N	\N
412750	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-10-16 09:30:00	2019-10-16 11:20:00	\N	\N	0	0	\N	\N
412751	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-10-16 11:15:00	2019-10-16 11:25:00	\N	\N	0	0	\N	\N
412752	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-10-16 11:20:00	2019-10-16 11:30:00	\N	\N	0	0	\N	\N
412790	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénièe CATDD	\N	2019-10-16 09:30:00	2019-10-16 11:20:00	2019-10-16 11:33:22	2019-10-16 17:31:06	33	1	\N	\N
413747	GIA	AUCUNE	\N	\N	\N	réunion du groupe	réunion du groupe d'amitié en vu de préparer le déplacement en Andorre des 11 et 12 octobre 2019	2019-10-01 10:00:00	2019-10-01 11:00:00	\N	\N	6	0	963	\N
413756	GIA	AUCUNE	\N	\N	\N	réunion avec l'Ambassadrice d'Andorre	réunion avec l'Ambassadrice d'Andorre	2019-10-01 09:00:00	2019-10-01 10:00:00	\N	\N	1	0	963	\N
431010	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	PLF pour 2020 - avis PJJ - déplacement établissement pour mineurs Porcheville	\N	2019-11-07 08:00:00	2019-11-07 14:00:00	\N	\N	1	0	\N	\N
431013	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2020 - avis PJJ - auditions rapporteur	\N	2019-11-07 15:00:00	2019-11-07 17:15:00	\N	\N	1	0	\N	\N
431016	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2020 - avis PJJ - Audition de la CFDT	\N	2019-11-21 15:00:00	2019-11-21 15:45:00	\N	\N	1	0	\N	\N
431018	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	PLF pour 2020 - avis PJJ - déplacement quartier mineurs Fleury-Mérogis	\N	2019-11-21 09:30:00	2019-11-21 12:00:00	\N	\N	1	0	\N	\N
431047	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Prévention du suicide des agriculteurs	Auditions Mme Férat - PPL prévention du suicide des agriculteurs	2019-11-20 14:00:00	2019-11-20 15:00:00	\N	\N	2	0	\N	\N
431058	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Logement - Mme Estrosi Sassone	PJLF 2020 Audition Mme Estrosi Sassone avis logement	2019-11-21 09:00:00	2019-11-21 10:00:00	\N	\N	1	0	\N	\N
378808	CMP	AUTRE	\N	SANTE	\N	PPL Résiliation des contrats de complémentaire santé	PPL Résiliation des contrats de complémentaire santé	2019-05-15 18:15:00	2019-05-15 18:40:00	\N	\N	7	0	\N	\N
397739	CMP	AUTRE	\N	FONCTION	\N	PJL Transformation de la fonction publique	PJL Transformation de la fonction publique	2019-07-04 09:35:00	2019-07-04 10:40:00	\N	\N	9	0	\N	\N
431063	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2020 - Examen Amdts séance sur les Missions 	PLF pour 2020 - Examen Amdts séance sur les missions 	2019-11-29 09:05:00	2019-11-29 09:15:00	2019-12-03 12:43:02	2019-12-03 14:19:13	14	0	\N	\N
431079	COM_SPECIALE	PLENIERE	\N	BIOETHIQUE	\N	Audition commune sur l'assistance médicale à la procréation	\N	2019-11-27 16:55:00	2019-11-27 18:35:00	2019-11-28 09:42:41	2019-11-28 11:18:53	23	0	\N	\N
431081	COM_SPECIALE	PLENIERE	\N	BIOETHIQUE	\N	CS Bioéthique - Table ronde d'universitaires	\N	2019-11-28 10:12:00	2019-11-28 12:10:00	2019-11-28 12:14:31	2019-11-28 12:15:48	15	0	\N	\N
442167	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution plastique 	Audition rapporteurs Pollution plastique - L'Oréal	2020-01-14 14:30:00	2020-01-14 15:30:00	\N	\N	2	0	\N	\N
442169	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution plastique	Audition rapporteurs Pollution plastique - INERIS	2020-01-14 15:45:00	2020-01-14 16:45:00	\N	\N	2	0	\N	\N
442174	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution plastique	Audition rapporteurs Pollution plastique - Bpifrance	2020-01-14 17:00:00	2020-01-14 18:30:00	\N	\N	2	0	\N	\N
442180	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution plastique	Audition rapporteurs Pollution plastique - UMIH	2020-01-23 14:00:00	2020-01-23 15:00:00	\N	\N	2	0	\N	\N
442183	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution plastique	Audition rapporteurs Pollution plastique - Henkel	2020-01-23 15:15:00	2020-01-23 16:15:00	\N	\N	2	0	\N	\N
442186	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution plastique	Audition rapporteurs Pollution plastique - WWF France	2020-01-23 16:30:00	2020-01-23 17:30:00	\N	\N	2	0	\N	\N
442189	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution plastique	Audition rapporteurs Pollution plastique - IFREMER	2020-01-29 16:00:00	2020-01-29 18:00:00	\N	\N	2	0	\N	\N
442693	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition entreprises responsables et engagées	Audition entreprises responsables et engagées - AUTORITÉ DES NORMES COMPTABLES	2020-01-07 15:00:00	2020-01-07 16:15:00	\N	\N	2	0	\N	\N
442766	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition entreprises responsables et engagées	Audition entreprises responsables et engagées - Martin Richer	2020-01-07 16:15:00	2020-01-07 17:00:00	\N	\N	2	0	\N	\N
442775	GIA	AUCUNE	\N	\N	\N	Audition de Mgr Antoine de Romanet, évêque aux armées françaises	Le discours du Pape à Hiroshima sur l'arme nucléaire : quelles implications pour la France ?	2020-01-08 13:30:00	2020-01-08 15:00:00	\N	\N	11	0	629	\N
444822	COM_PERMANENTE	DEPLACEMENT	\N	AFCL	\N	VISITE MUSEE DU LOUVRE	VISITE MUSEE DU LOUVRE	2020-01-14 16:00:00	2020-01-14 18:30:00	\N	\N	16	0	\N	\N
445943	DELEGATION	AUCUNE	\N	\N	DSOM	Audition d'Eurodom	\N	2020-01-30 09:35:00	2020-01-30 11:05:00	\N	\N	8	0	\N	\N
445946	DELEGATION	AUCUNE	\N	\N	PROS	Tables rondes sur le thème "Qu'y aura-t-il dans nos assiettes en 2050 ?"	Tables rondes sur le thème "Qu'y aura-t-il dans nos assiettes en 2050 ?"	2020-02-06 09:05:00	2020-02-06 11:25:00	\N	\N	8	0	\N	\N
497218	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Restitution de biens culturels	PPL Restitution de biens culturels	2020-11-04 21:35:00	2020-11-05 00:00:00	\N	\N	42	0	\N	\N
497235	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2020-11-05 09:30:00	2020-11-05 13:20:00	\N	\N	49	0	\N	\N
497255	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	NL PJL Prorogation de l'état d'urgence sanitaire	NL PJL Prorogation de l'état d'urgence sanitaire	2020-11-05 19:00:00	2020-11-05 21:20:00	\N	\N	42	0	\N	\N
497311	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Sécurités - DSR	PLF pour 2021 - Sécurités - DSR	2020-10-26 15:00:00	2020-10-26 17:00:00	\N	\N	1	0	\N	\N
497671	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJLO Simplification des expérimentations de l'article 72 de la Constitution (amendements)	PJLO Simplification des expérimentations de l'article 72 de la Constitution (amendements)	2020-11-03 14:00:00	2020-11-03 14:05:00	2020-11-03 14:41:35	2020-11-03 17:51:23	19	0	\N	\N
497672	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désignation de rapporteurs	Désignation de rapporteurs	2020-11-04 16:30:00	2020-11-04 16:50:00	2020-11-04 17:53:25	2020-11-04 17:55:19	22	0	\N	\N
497674	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Prorogation de l'état d'urgence sanitaire (NL) (amendements de séance)	PJL Prorogation de l'état d'urgence sanitaire (NL) (amendements de séance)	2020-11-05 20:10:00	2020-11-05 20:15:00	2020-11-05 20:26:47	2020-11-06 09:33:43	19	0	\N	\N
498014	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Écologie - Air France	PLF pour 2021 - Écologie - Air France	2020-10-26 11:30:00	2020-10-26 12:30:00	\N	\N	1	0	\N	\N
498016	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Écologie - SER	PLF pour 2021 - Écologie - SER	2020-10-26 14:00:00	2020-10-26 15:00:00	\N	\N	1	0	\N	\N
498018	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Écologie - DGEC	PLF pour 2021 - Écologie - DGEC	2020-10-26 18:00:00	2020-10-26 19:00:00	\N	\N	1	0	\N	\N
498020	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Investissements d'avenir - Bpifrance/Kalray	PLF pour 2021 - Investissements d'avenir - Bpifrance/Kalray	2020-10-26 14:00:00	2020-10-26 16:00:00	\N	\N	1	0	\N	\N
498022	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - MIRES - DB bureau recherche	PLF pour 2021 - MIRES - DB bureau recherche	2020-10-29 09:00:00	2020-10-29 10:00:00	\N	\N	1	0	\N	\N
498024	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Sécurités - Sécurité Civile - DGSCGC	PLF pour 2021 - Sécurités - Sécurité Civile - DGSCGC	2020-10-27 09:15:00	2020-10-27 10:15:00	\N	\N	1	0	\N	\N
498026	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Enseignement scolaire - Dgesco	PLF pour 2021 - Enseignement scolaire - Dgesco	2020-10-27 17:00:00	2020-10-27 18:00:00	\N	\N	1	0	\N	\N
498028	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2021 - Enseignement scolaire - Cabinet Ministre EN	PLF pour 2021 - Enseignement scolaire - Cabinet Ministre EN	2020-10-28 13:30:00	2020-10-28 15:30:00	\N	\N	1	0	\N	\N
498030	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - APD - DG Trésor	PLF pour 2021 - APD - DG Trésor	2020-10-27 09:30:00	2020-10-27 10:30:00	\N	\N	2	0	\N	\N
498033	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Affaires Européennes - DG Trésor	PLF pour 2021 - Affaires Européennes - DG Trésor	2020-10-28 14:00:00	2020-10-28 15:00:00	\N	\N	1	0	\N	\N
498035	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2021 - AGTE - Table ronde des syndicats de la fonction publique d'Etat	PLF pour 2021 - AGTE - Table ronde des syndicats de la fonction publique d'Etat	2020-10-29 09:05:00	2020-10-29 10:25:00	\N	\N	2	0	\N	\N
498038	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Rapport général - Axa France	PLF pour 2021 - Rapport général - Axa France	2020-10-27 17:00:00	2020-10-27 18:00:00	\N	\N	2	0	\N	\N
498041	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Rapport général - FFA	PLF pour 2021 - Rapport général - FFA	2020-10-28 16:00:00	2020-10-28 17:00:00	\N	\N	2	0	\N	\N
498044	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Rapport général - CDC	PLF pour 2021 - Rapport général - CDC	2020-10-28 18:30:00	2020-10-28 19:30:00	\N	\N	2	0	\N	\N
498047	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Justice - SG Min Justice	PLF pour 2021 - Justice - SG Min Justice	2020-10-27 15:15:00	2020-10-27 17:00:00	\N	\N	1	0	\N	\N
498049	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Justice - DSJ	PLF pour 2021 - Justice - DSJ	2020-10-28 17:30:00	2020-10-28 18:30:00	\N	\N	1	0	\N	\N
498051	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Écologie - DGPR	PLF pour 2021 - Écologie - DGPR	2020-10-29 15:00:00	2020-10-29 16:00:00	\N	\N	1	0	\N	\N
498053	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Cohésion des territoires - Logement-Urbanisme - USH/FFB	PLF pour 2021 - Cohésion des territoires - Logement-Urbanisme - USH/FFB	2020-10-29 09:00:00	2020-10-29 11:00:00	\N	\N	1	0	\N	\N
498055	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Cohésion des territoires - Logement-Urbanisme - Action Logement	PLF pour 2021 - Cohésion des territoires - Logement-Urbanisme - Action Logement	2020-10-29 17:00:00	2020-10-29 18:10:00	\N	\N	1	0	\N	\N
498057	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Travail et emploi - Union nationale des missions locales	PLF pour 2021 - Travail et emploi - Union nationale des missions locales	2020-10-20 15:00:00	2020-10-20 16:00:00	\N	\N	2	0	\N	\N
498061	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Travail et emploi - DGEFP	PLF pour 2021 - Travail et emploi - DGEFP	2020-10-22 11:00:00	2020-10-22 12:00:00	\N	\N	2	0	\N	\N
498064	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Travail et emploi - UDES	PLF pour 2021 - Travail et emploi - UDES	2020-10-22 14:00:00	2020-10-22 15:00:00	\N	\N	2	0	\N	\N
498067	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Travail et emploi - Table ronde "acteurs de l'insertion"	PLF pour 2021 - Travail et emploi - Table ronde "acteurs de l'insertion"	2020-10-28 15:00:00	2020-10-28 16:00:00	\N	\N	2	0	\N	\N
498070	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Solidarité - DFAS	PLF pour 2021 - Solidarité - DFAS	2020-10-29 09:00:00	2020-10-29 10:00:00	\N	\N	2	0	\N	\N
498073	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Travail et emploi - DFAS/DGT	PLF pour 2021 - Travail et emploi - DFAS/DGT	2020-10-29 10:00:00	2020-10-29 12:00:00	\N	\N	2	0	\N	\N
498076	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Rapport général - Régions de France	PLF pour 2021 - Rapport général - Régions de France	2020-10-29 11:30:00	2020-10-29 12:30:00	\N	\N	1	0	\N	\N
498078	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Solidarité - TR "Egalité femmes-hommes" / ADF	PLF pour 2021 - Solidarité - TR "Egalité femmes-hommes" / ADF	2020-10-30 09:30:00	2020-10-30 12:00:00	\N	\N	2	0	\N	\N
498081	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Solidarité - Table ronde "Aide alimentaire"	PLF pour 2021 - Solidarité - Table ronde "Aide alimentaire"	2020-10-30 17:00:00	2020-10-30 19:30:00	\N	\N	2	0	\N	\N
498084	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteur Production de l'hydrogène	Audition rapporteur Production de l'hydrogène	2020-11-05 14:45:00	2020-11-05 17:00:00	\N	\N	1	0	\N	\N
498085	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Rapport général - DGE et DG Trésor	PLF pour 2021 - Rapport général - DGE et DG Trésor	2020-10-28 15:00:00	2020-10-28 16:00:00	\N	\N	1	0	\N	\N
498087	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2021 - Défense - CEMAT	PLF pour 2021 - Défense - CEMAT	2020-10-29 07:45:00	2020-10-29 09:30:00	\N	\N	1	0	\N	\N
498089	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Culture - SG Min Culture	PLF pour 2021 - Culture - SG Min Culture	2020-10-28 16:45:00	2020-10-28 17:30:00	\N	\N	2	0	\N	\N
498092	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2021 - Pouvoirs publics - Conseil constitutionnel	PLF pour 2021 - Pouvoirs publics - Conseil constitutionnel	2020-10-28 08:45:00	2020-10-28 10:15:00	\N	\N	1	0	\N	\N
498094	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Pouvoirs publics - Questeur Sénat	PLF pour 2021 - Pouvoirs publics - Questeur Sénat	2020-10-28 14:15:00	2020-10-28 14:50:00	\N	\N	1	0	\N	\N
498096	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2021 - Pouvoirs publics - Dir Cab PR	PLF pour 2021 - Pouvoirs publics - Dir Cab PR	2020-10-28 15:10:00	2020-10-28 16:50:00	\N	\N	1	0	\N	\N
498098	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - EFE - Société Générale	PLF pour 2021 - EFE - Société Générale	2020-10-30 09:00:00	2020-10-30 10:10:00	\N	\N	1	0	\N	\N
498850	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Table ronde sur les travailleurs indépendants	Table ronde sur les travailleurs indépendants	2020-11-12 09:30:00	2020-11-12 11:30:00	2020-11-12 12:06:24	\N	16	0	\N	\N
376798	MISSION	AUCUNE	\N	AERIEN	\N	Réunion plénière MI Transports aériens	\N	2019-05-14 16:02:00	2019-05-14 16:51:00	2019-05-15 10:46:53	2019-05-15 11:28:04	19	0	\N	\N
376816	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Organisation du système de santé	PJL Organisation du système de santé	2019-05-07 08:00:00	2019-05-07 08:45:00	\N	\N	3	0	\N	\N
376820	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Organisation du système de santé	\N	2019-05-09 14:30:00	2019-05-09 16:30:00	\N	\N	1	0	\N	\N
376822	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Organisation du système de santé	PJL Organisation du système de santé	2019-05-07 08:45:00	2019-05-07 09:45:00	\N	\N	3	0	\N	\N
376826	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Organisation du système de santé	PJL Organisation du système de santé	2019-05-07 09:45:00	2019-05-07 10:25:00	\N	\N	3	0	\N	\N
376830	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Organisation du système de santé	PJL Organisation du système de santé	2019-05-09 09:15:00	2019-05-09 10:05:00	\N	\N	3	0	\N	\N
376835	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Organisation du système de santé	PJL Organisation du système de santé	2019-05-09 10:30:00	2019-05-09 11:20:00	\N	\N	3	0	\N	\N
376839	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Organisation du système de santé	PJL Organisation du système de santé	2019-05-09 11:20:00	2019-05-09 12:50:00	\N	\N	3	0	\N	\N
376843	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Organisation du système de santé	PJL Organisation du système de santé	2019-05-09 14:30:00	2019-05-09 15:30:00	\N	\N	2	0	\N	\N
376885	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Organisation du système de santé	PJL Organisation du système de santé	2019-05-09 15:30:00	2019-05-09 16:20:00	\N	\N	2	0	\N	\N
377745	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-05-15 09:35:00	2019-05-15 12:25:00	2019-05-17 10:20:12	2019-05-17 10:30:21	39	0	\N	\N
378103	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Audition de Paris Turf	\N	2019-05-15 08:00:00	2019-05-15 09:00:00	\N	\N	0	0	\N	\N
378191	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Mme Gruny M. Artano MI Santé au travail	\N	2019-05-14 14:00:00	2019-05-14 14:45:00	\N	\N	2	0	\N	\N
378350	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2019-05-14 14:45:00	2019-05-14 15:30:00	\N	\N	2	0	\N	\N
378353	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Mme Gruny M. Artano MI Santé au travail	\N	2019-05-14 15:45:00	2019-05-14 16:45:00	\N	\N	2	0	\N	\N
378423	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion de commission 	\N	2019-05-16 11:30:00	2019-05-16 13:30:00	2019-05-17 10:19:08	2019-05-17 10:30:19	16	0	\N	\N
378435	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Mme Gruny M. Artano MI Santé au travail	\N	2019-05-14 16:45:00	2019-05-14 17:45:00	\N	\N	2	0	\N	\N
379991	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2019-05-14 19:30:00	2019-05-14 20:00:00	\N	\N	25	0	\N	\N
382616	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Transformation de la fonction publique	\N	2019-05-22 14:30:00	2019-05-22 15:50:00	\N	\N	5	0	\N	\N
382622	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Transformation de la fonction publique	\N	2019-05-22 15:50:00	2019-05-22 17:15:00	\N	\N	4	0	\N	\N
382627	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Transformation de la fonction publique	\N	2019-05-22 17:15:00	2019-05-22 18:45:00	\N	\N	4	0	\N	\N
383134	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL 5G	PPL 5G	2019-05-28 11:00:00	2019-05-28 12:00:00	\N	\N	1	0	\N	\N
383137	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL 5G	PPL 5G	2019-05-28 10:00:00	2019-05-28 11:00:00	\N	\N	2	0	\N	\N
391393	MISSION	AUDRAP	\N	AERIEN	\N	transpors aériens	\N	2019-06-12 16:30:00	2019-06-12 17:30:00	\N	\N	2	0	\N	\N
396516	GIA	AUCUNE	\N	\N	\N	GIA France-Balkans : entretien avec M. Ramush Haradina, Premier ministre du Kosovo	GIA France-Balkans : entretien avec M. Ramush Haradina, Premier ministre du Kosovo	2019-07-01 11:00:00	2019-07-01 11:40:00	\N	\N	1	0	674	\N
400516	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF 2020 - Écologie - Air France	PLF 2020 - Écologie - Air France	2019-07-08 16:45:00	2019-07-08 17:45:00	\N	\N	1	0	\N	\N
400524	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - CNCCFP - Anticor	Contrôle 2019 - CNCCFP - Anticor	2019-07-09 14:45:00	2019-07-09 16:15:00	\N	\N	1	0	\N	\N
400528	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	auditions rapporteurs	\N	2019-07-16 16:00:00	2019-07-16 18:00:00	\N	\N	0	0	\N	\N
400529	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	auditions rapporteurs	\N	2019-07-17 14:00:00	2019-07-17 15:30:00	\N	\N	0	0	\N	\N
400530	MECSS	AUDRAP	\N	\N	MECSS	Accès précoce à l'innovation dans le domaine des produits de santé	\N	2019-07-16 16:00:00	2019-07-16 18:00:00	\N	\N	5	0	\N	\N
400531	MECSS	AUDRAP	\N	\N	MECSS	Accès précoce à l'innovation dans le domaine des produits de santé	\N	2019-07-17 14:00:00	2019-07-17 16:00:00	\N	\N	4	0	\N	\N
400541	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2020 - Sécurités - Déplacement Paris	PLF pour 2020 - Sécurités - Déplacement Paris	2019-07-12 10:30:00	2019-07-12 13:30:00	\N	\N	1	0	\N	\N
405222	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Masse salariale du MEAE - Mercer France	Contrôle 2019 - Masse salariale du MEAE - Mercer France	2019-09-03 10:00:00	2019-09-03 11:30:00	\N	\N	2	0	\N	\N
416429	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Énergie - M. Daniel Gremillet	PJLF 2020 - Auditions M. Gremillet - Avis énergie	2019-10-16 16:00:00	2019-10-16 18:30:00	\N	\N	1	0	\N	\N
416431	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission (LEC)	Réunion de commission (LEC)	2019-10-17 10:45:00	2019-10-17 12:45:00	2019-10-17 14:19:39	2019-10-17 15:56:24	34	4	\N	\N
416434	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Travailleurs indépendants	\N	2019-10-16 16:30:00	2019-10-16 17:30:00	\N	\N	3	0	\N	\N
416464	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Travailleurs indépendants	\N	2019-10-16 17:30:00	2019-10-16 18:30:00	\N	\N	3	0	\N	\N
416469	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Travailleurs indépendants	\N	2019-10-16 18:30:00	2019-10-16 19:30:00	\N	\N	3	0	\N	\N
416477	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Assurance maladie	\N	2019-10-16 18:00:00	2019-10-16 19:00:00	\N	\N	2	0	\N	\N
416552	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJLF 2020 - Avis Transports aériens-Audition de Mme Nicole Bonnefoy	PJLF 2020 - Avis Transports aériens-Audition de Mme Nicole Bonnefoy	2019-10-15 15:00:00	2019-10-15 16:00:00	\N	\N	2	0	\N	\N
416559	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJLF 2020 - Avis Transports aériens-Audition de Mme Nicole Bonnefoy	PJLF 2020 - Avis Transports aériens-Audition de Mme Nicole Bonnefoy	2019-10-16 16:30:00	2019-10-16 19:30:00	\N	\N	1	0	\N	\N
417485	SEANCE_PLENIERE	SCRUSOL	1241	\N	\N	Scrutin solennel - PJL Engagement et proximite	Scrutin solennel - PJL Engagement et proximite	2019-10-22 15:20:00	2019-10-22 15:39:00	\N	\N	0	0	\N	\N
419507	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Culture (Création, Transmission, Démocratisation)	PLF 2020 - Crédits Culture (Création, Transmission, Démocratisation)	2019-10-22 15:30:00	2019-10-22 16:30:00	\N	\N	3	0	\N	\N
419891	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2020 - Programme 212	\N	2019-10-23 14:00:00	2019-10-23 15:00:00	\N	\N	2	0	\N	\N
427766	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJLO PJL Art. 13 Constitution	PJLO PJL Art. 13 Constitution	2019-12-17 14:30:00	2019-12-17 16:45:00	\N	\N	96	0	\N	\N
427769	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Lutte contenus haineux sur Internet	PPL Lutte contenus haineux sur Internet	2019-12-17 16:46:00	2019-12-17 19:52:00	\N	\N	99	0	\N	\N
427770	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Lutte contenus haineux sur Internet	PPL Lutte contenus haineux sur Internet	2019-12-17 21:30:00	2019-12-18 00:00:00	\N	\N	45	0	\N	\N
427774	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2019-12-18 15:00:00	2019-12-18 16:15:00	\N	\N	241	0	\N	\N
427777	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	NL PLF pour 2020	Nouvelle lecture PLF pour 2020	2019-12-18 16:35:00	2019-12-18 17:42:00	\N	\N	48	0	\N	\N
427778	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PPL Violences au sein de la famille	CMP PPL Violences au sein de la famille	2019-12-18 17:50:00	2019-12-18 18:50:00	\N	\N	44	0	\N	\N
427781	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Conseil européeen 12 et 13/12/19	Débat Conseil européeen 12 et 13/12/19	2019-12-18 21:33:00	2019-12-19 23:33:00	\N	\N	17	0	\N	\N
500284	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2020-11-12 15:00:00	2020-11-12 16:15:00	\N	\N	134	0	\N	\N
500285	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2021	Projet de loi de financement de la sécurité sociale pour 2021	2020-11-12 16:30:00	2020-11-12 20:00:00	\N	\N	78	0	\N	\N
500286	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2021	Projet de loi de financement de la sécurité sociale pour 2021	2020-11-12 21:30:00	2020-11-13 00:35:00	\N	\N	60	0	\N	\N
500287	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2021	Projet de loi de financement de la sécurité sociale pour 2021	2020-11-13 09:35:00	2020-11-13 13:00:00	\N	\N	73	0	\N	\N
500288	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2021	Projet de loi de financement de la sécurité sociale pour 2021	2020-11-13 14:30:00	2020-11-13 20:00:00	\N	\N	71	0	\N	\N
500289	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2021	Projet de loi de financement de la sécurité sociale pour 2021	2020-11-13 21:30:00	2020-11-14 01:00:00	\N	\N	51	0	\N	\N
500291	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2020-11-03 14:35:00	2020-11-03 17:00:00	\N	\N	3	0	\N	\N
500407	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2020-11-09 10:35:00	2020-11-09 12:45:00	2020-11-09 14:01:14	2020-11-09 17:59:15	35	0	\N	\N
500408	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2020-11-09 14:20:00	2020-11-09 15:55:00	2020-11-09 17:31:52	2020-11-09 17:59:16	36	0	\N	\N
500409	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes - Audition plénière	\N	2020-11-12 08:30:00	2020-11-12 10:30:00	2020-11-12 16:23:57	2020-11-12 17:56:31	25	0	\N	\N
500677	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Avis Energie  PJLF 2021	Auditions de M. Daniel Gremillet	2020-11-04 11:30:00	2020-11-04 13:00:00	\N	\N	1	0	\N	\N
500410	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2020-11-09 19:25:00	2020-11-09 20:30:00	2020-11-09 20:45:27	2020-11-10 09:32:32	37	0	\N	\N
500411	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2020-11-10 09:00:00	2020-11-10 10:35:00	2020-11-10 16:36:20	2020-11-10 17:36:37	40	0	\N	\N
500418	DELEGATION	AUDRAP	\N	\N	PROS	Audition de M. Jean-Baptiste Baud	\N	2020-11-09 10:00:00	2020-11-09 11:00:00	\N	\N	1	0	\N	\N
500455	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2021 - Administration générale et territoriale de l'Etat	\N	2020-11-05 10:00:00	2020-11-05 12:20:00	\N	\N	2	0	\N	\N
500457	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2021 - Direction de l'action du Gouvernement	\N	2020-11-06 09:15:00	2020-11-06 12:15:00	\N	\N	1	0	\N	\N
500458	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2021 - Travail et emploi - Audition de Pôle emploi	\N	2020-11-03 11:00:00	2020-11-03 12:15:00	\N	\N	1	0	\N	\N
500459	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2021 - Travail et emploi - Audition de la DGEFP	\N	2020-11-03 17:00:00	2020-11-03 18:00:00	\N	\N	1	0	\N	\N
500460	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2021 - Travail et emploi - Audition de CMA France	\N	2020-11-03 18:00:00	2020-11-03 19:00:00	\N	\N	1	0	\N	\N
500461	DELEGATION	AUDRAP	\N	\N	PROS	Audition de M. Nicolas Tcheng	Audition de M. Nicolas Tcheng, Groupe Renault	2020-11-12 10:10:00	2020-11-12 11:00:00	\N	\N	1	0	\N	\N
500462	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2021 - Direction de l'action du Gouvernement	\N	2020-11-06 15:00:00	2020-11-06 16:30:00	\N	\N	1	0	\N	\N
500463	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2021 - Travail et emploi - Audition de France compétences	\N	2020-11-04 13:30:00	2020-11-04 14:50:00	\N	\N	1	0	\N	\N
500465	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2021 - Anciens combattants - Table ronde d'anciens combattants	\N	2020-11-03 09:30:00	2020-11-03 10:30:00	\N	\N	3	0	\N	\N
500466	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2021 - Anciens combattants - Audition de l'ONACVG	\N	2020-11-12 09:00:00	2020-11-12 09:45:00	\N	\N	1	0	\N	\N
500476	COM_PERMANENTE	AUTRE	\N	FINC	\N	Ddadue : Examen Rapport Nlle lec.- PLF pour 2021 : Rapports GFP-CnR-TFP-AEE-APD-Solidarité	Ddadue : Examen Rapport Nlle lec.- PLF pour 2021 : Examen Rapports «GFP»-«CnR»-«TFP»-«AEE»-«APD»-«Solidarité»	2020-11-10 14:05:00	2020-11-10 17:35:00	2020-11-10 17:50:13	2020-11-10 18:10:15	38	1	\N	\N
500477	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF2021 : Rapport Tome II  - PLFR2020 (4) : Examen Rapport - PLF2021 : Missions ES et DAG	PLF2021 : Rapport Tome II  - PLFR2020 (4) : Examen Rapport - PLF2021 : Missions ES et DAG et designation CMP PLFR 4 2020	2020-11-12 09:05:00	2020-11-12 12:35:00	2020-11-12 13:02:44	2020-11-12 16:56:38	38	0	\N	\N
500478	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2021 : Mission Outre-Mer	PLF pour 2021 : Mission Outre-Mer	2020-11-12 14:05:00	2020-11-12 14:50:00	2020-11-12 15:08:25	2020-11-12 16:56:38	24	0	\N	\N
500479	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - DAG - DSAF Premier Ministre / DILA	PLF pour 2021 - DAG - DSAF Premier Ministre / DILA	2020-11-02 16:00:00	2020-11-02 18:10:00	\N	\N	1	0	\N	\N
500481	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2021 - Avis asile, immigration, intégration et nationalité	PLF pour 2021 - Avis asile, immigration, intégration et nationalité	2020-11-04 17:30:00	2020-11-04 18:30:00	\N	\N	3	0	\N	\N
500485	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2021 - Avis asile, immigration, intégration et nationalité	PLF pour 2021 - Avis asile, immigration, intégration et nationalité	2020-11-04 18:30:00	2020-11-04 19:15:00	\N	\N	3	0	\N	\N
500489	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2021 - Avis asile, immigration, intégration et nationalité	PLF pour 2021 - Avis asile, immigration, intégration et nationalité	2020-11-05 09:30:00	2020-11-05 10:00:00	\N	\N	3	0	\N	\N
500493	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2021 - Avis asile, immigration, intégration et nationalité	PLF pour 2021 - Avis asile, immigration, intégration et nationalité	2020-11-05 10:00:00	2020-11-05 10:45:00	\N	\N	3	0	\N	\N
500497	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2021 - Avis asile, immigration, intégration et nationalité	PLF pour 2021 - Avis asile, immigration, intégration et nationalité	2020-11-05 10:45:00	2020-11-05 12:00:00	\N	\N	3	0	\N	\N
500501	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-11-10 17:50:00	2020-11-10 19:40:00	2020-11-12 16:08:35	2020-11-12 16:27:43	34	0	\N	\N
500502	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-11-10 15:30:00	2020-11-10 17:45:00	2020-11-12 16:23:39	2020-11-12 17:58:10	64	0	\N	\N
500507	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 -  RCT - DGCL	PLF pour 2021 -  RCT - DGCL	2020-10-29 11:30:00	2020-10-29 12:30:00	\N	\N	2	0	\N	\N
500510	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 -  RCT - GART	PLF pour 2021 -  RCT - GART	2020-10-29 17:00:00	2020-10-29 18:00:00	\N	\N	1	0	\N	\N
500512	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 -  AEE - FAPEE	PLF pour 2021 -  AEE - FAPEE	2020-11-02 16:00:00	2020-11-02 17:00:00	\N	\N	1	0	\N	\N
500514	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 -  AEE - DGM / Cabinet Ministre	PLF pour 2021 -  AEE - DGM / Cabinet Ministre	2020-11-05 15:00:00	2020-11-05 17:00:00	\N	\N	2	0	\N	\N
500517	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 -  GFP - SG Ministères économiques et financiers	PLF pour 2021 -  GFP - SG Ministères économiques et financiers	2020-11-03 11:00:00	2020-11-03 12:20:00	\N	\N	2	0	\N	\N
500520	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 -  GFP - DGFiP	PLF pour 2021 -  GFP - DGFiP	2020-11-03 14:00:00	2020-11-03 15:10:00	\N	\N	2	0	\N	\N
500523	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 -  GFP - DG Douanes	PLF pour 2021 -  GFP - DG Douanes	2020-11-03 16:00:00	2020-11-03 17:00:00	\N	\N	2	0	\N	\N
500526	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - TFP - Ministre	PLF pour 2021 - TFP - Ministre	2020-11-04 16:15:00	2020-11-04 17:15:00	\N	\N	2	0	\N	\N
500529	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - CAS Gestion patrimoine immobilier - Immobilier de l'État	PLF pour 2021 - CAS Gestion patrimoine immobilier - Immobilier de l'État	2020-11-04 18:30:00	2020-11-04 19:30:00	\N	\N	1	0	\N	\N
500531	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - MIRES - CPU	PLF pour 2021 - MIRES - CPU	2020-11-04 10:30:00	2020-11-04 11:30:00	\N	\N	1	0	\N	\N
500533	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - MIRES - DGESIP	PLF pour 2021 - MIRES - DGESIP	2020-11-05 11:00:00	2020-11-05 12:00:00	\N	\N	1	0	\N	\N
500535	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - MIRES - DGRI / CNRS / CEA	PLF pour 2021 - MIRES - DGRI / CNRS / CEA	2020-11-05 14:00:00	2020-11-05 17:00:00	\N	\N	1	0	\N	\N
500538	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Défense - DGA	PLF pour 2021 - Défense - DGA	2020-11-04 14:45:00	2020-11-04 16:00:00	\N	\N	1	0	\N	\N
500540	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Défense - MG EMM	PLF pour 2021 - Défense - MG EMM	2020-11-05 10:00:00	2020-11-05 11:00:00	\N	\N	1	0	\N	\N
500542	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Défense - EMA	PLF pour 2021 - Défense - EMA	2020-11-05 14:00:00	2020-11-05 15:00:00	\N	\N	1	0	\N	\N
500544	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Défense - EMAA	PLF pour 2021 - Défense - EMAA	2020-11-05 15:15:00	2020-11-05 16:30:00	\N	\N	1	0	\N	\N
459612	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2019-10-10 09:15:00	2019-10-10 13:30:00	\N	\N	3	0	\N	\N
500546	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Cohésion des territoires - DGCL	PLF pour 2021 - Cohésion des territoires - DGCL	2020-11-04 14:00:00	2020-11-04 15:00:00	\N	\N	1	0	\N	\N
376702	GIA	AUCUNE	\N	\N	\N	Entretien avec la ministre de la justice d'Albanie	Entretien avec Mme Etilda Gjonaj, ministre de la justice d'Albanie	2019-05-07 11:30:00	2019-05-07 12:30:00	\N	\N	4	0	571	\N
376709	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Territoires d'outre-mer soumis à une pression migratoire	\N	2019-05-09 08:30:00	2019-05-09 09:30:00	\N	\N	2	0	\N	\N
376712	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Territoires d'outre-mer soumis à une pression migratoire	\N	2019-05-09 09:30:00	2019-05-09 10:10:00	\N	\N	1	0	\N	\N
384485	GIA	AUCUNE	\N	\N	\N	\N	Entretien avec M. Jean-Pierre RAFFARIN, ancien Premier ministre, représentant spécial du Gouvernement pour la Chine	2019-05-29 13:00:00	2019-05-29 14:30:00	\N	\N	17	0	584	\N
401920	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion de la commission des affaires européennes du jeudi 18 juillet 2019	Réunion de la commission des affaires européennes du jeudi 18 juillet 2019	2019-07-18 08:35:00	2019-07-18 09:55:00	2019-07-18 10:45:52	2019-07-18 17:39:11	16	0	\N	\N
417384	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJLF pour 2020 - p 146	PJLF pour 2020 - P 146	2019-10-16 17:50:00	2019-10-16 19:15:00	\N	\N	2	0	\N	\N
422723	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - MIRES - Enseignement supérieur et recherche - CPU	PLF pour 2020 - MIRES - Enseignement supérieur et recherche - CPU	2019-10-30 16:30:00	2019-10-30 17:30:00	\N	\N	2	0	\N	\N
422726	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - MIRES - Enseignement supérieur - CGE	PLF pour 2020 - MIRES - Enseignement supérieur - CGE	2019-10-30 17:30:00	2019-10-30 18:30:00	\N	\N	1	0	\N	\N
422736	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Cohésion des territoires - Logement et urbanisme - USH	PLF pour 2020 - Cohésion des territoires - Logement et urbanisme - USH	2019-10-30 17:15:00	2019-10-30 18:15:00	\N	\N	1	0	\N	\N
422751	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Solidarité - Délégué interministériel à la pauvreté / DFAS	PLF pour 2020 - Solidarité - Délégué interministériel à la pauvreté / DFAS	2019-10-29 15:00:00	2019-10-29 17:00:00	\N	\N	2	0	\N	\N
422753	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJLF 2020 - Avis Prévention des risques - Auditions M.  Médevielle	PJLF 2020 - Avis Prévention des risques - Auditions M.  Médevielle	2019-10-29 14:30:00	2019-10-29 15:30:00	\N	\N	1	0	\N	\N
422756	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJLF 2020 -Auditions Cohésion des territoires - M. de Nicolaÿ	PJLF 2020 -Auditions Cohésion des territoires - M. de Nicolaÿ	2019-10-23 14:00:00	2019-10-23 15:00:00	\N	\N	1	0	\N	\N
422759	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJLF 2020 -Auditions Cohésion des territoires - M. de Nicolaÿ	PJLF 2020 -Auditions Cohésion des territoires - M. de Nicolaÿ	2019-10-23 16:30:00	2019-10-23 17:30:00	\N	\N	1	0	\N	\N
422761	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJLF 2020 -Auditions Cohésion des territoires - M. de Nicolaÿ	PJLF 2020 -Auditions Cohésion des territoires - M. de Nicolaÿ	2019-10-24 17:00:00	2019-10-24 18:00:00	\N	\N	1	0	\N	\N
422763	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Solidarité - DGCS	PLF pour 2020 - Solidarité - DGCS	2019-10-29 17:30:00	2019-10-29 18:30:00	\N	\N	2	0	\N	\N
422764	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 Culture (Patrimoine)	PLF 2020 Culture (Patrimoine)	2019-10-30 17:00:00	2019-10-30 18:40:00	\N	\N	5	0	\N	\N
422772	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Solidarité - FNSF	PLF pour 2020 - Solidarité - FNSF	2019-10-30 14:00:00	2019-10-30 15:00:00	\N	\N	2	0	\N	\N
422776	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Enseignement supérieur	PLF 2020 - Crédits Enseignement supérieur	2019-10-30 11:00:00	2019-10-30 12:00:00	\N	\N	2	0	\N	\N
422777	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	algorithmes locaux dans Parcoursup	algorithmes locaux dans Parcoursup	2019-10-30 14:00:00	2019-10-30 15:00:00	\N	\N	4	0	\N	\N
422778	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	algorithmes locaux dans Parcoursup	algorithmes locaux dans Parcoursup	2019-10-30 16:30:00	2019-10-30 17:30:00	\N	\N	4	0	\N	\N
422779	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Cohésion des territoires - CGET	PLF pour 2020 - Cohésion des territoires - CGET	2019-10-29 11:30:00	2019-10-29 13:00:00	\N	\N	1	0	\N	\N
422783	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Economie - CCI France	PLF pour 2020 - Economie - CCI France	2019-10-30 17:45:00	2019-10-30 18:30:00	\N	\N	1	0	\N	\N
422789	ETUDES	AUTRE	\N	\N	\N	Audition de EDF hydroélectricité	Audition de M. GIRAUD et Mme LOY	2019-10-29 18:00:00	2019-10-29 19:30:00	\N	\N	7	0	\N	906
422801	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Auditions M. Gremillet - Avis énergie	PJLF 2020 - Auditions M. Gremillet - Avis énergie	2019-10-29 09:30:00	2019-10-29 11:00:00	\N	\N	1	0	\N	\N
422802	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Auditions M. Gremillet - Avis énergie	PJLF 2020 - Auditions M. Gremillet - Avis énergie	2019-10-29 15:30:00	2019-10-29 16:15:00	\N	\N	1	0	\N	\N
422803	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Auditions M. Gremillet - Avis énergie	PJLF 2020 - Auditions M. Gremillet - Avis énergie	2019-10-29 16:15:00	2019-10-29 17:00:00	\N	\N	1	0	\N	\N
422804	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Auditions M. Gremillet - Avis énergie	PJLF 2020 - Auditions M. Gremillet - Avis énergie	2019-10-29 17:00:00	2019-10-29 17:45:00	\N	\N	1	0	\N	\N
422809	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2020 - Sécurités - Direction générale de la police nationale	PLF pour 2020 - Sécurités - Direction générale de la police nationale	2019-10-29 14:00:00	2019-10-29 15:30:00	\N	\N	1	0	\N	\N
422810	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2020 - Sécurités - Alliance police nationale	PLF pour 2020 - Sécurités - Alliance police nationale	2019-10-29 15:50:00	2019-10-29 17:00:00	\N	\N	1	0	\N	\N
422811	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2020 - Sécurités - Direction générale de la gendarmerie nationale	PLF pour 2020 - Sécurités - Direction générale de la gendarmerie nationale	2019-10-29 17:00:00	2019-10-29 18:30:00	\N	\N	1	0	\N	\N
422812	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2020 - Sécurités - Table ronde APNM (AG&C - GendXXI)	PLF pour 2020 - Sécurités - Table ronde APNM (AG&C - GendXXI)	2019-10-29 18:30:00	2019-10-29 19:15:00	\N	\N	1	0	\N	\N
422815	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Enseignement scolaire	PLF 2020 - Crédits Enseignement scolaire	2019-10-30 17:30:00	2019-10-30 18:30:00	\N	\N	2	0	\N	\N
422816	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Sites naturels - Auditions Jérôme Bignon	\N	2019-10-31 09:30:00	2019-10-31 11:45:00	\N	\N	2	0	\N	\N
422817	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Enseignement scolaire	PLF 2020 - Crédits Enseignement scolaire	2019-10-31 09:00:00	2019-10-31 10:00:00	\N	\N	2	0	\N	\N
422828	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Auditions M. Gremillet - Avis énergie	PJLF 2020 - Auditions M. Gremillet - Avis énergie	2019-10-31 09:00:00	2019-10-31 10:20:00	\N	\N	1	0	\N	\N
428157	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	DSOM	Conférence de presse - adoption durapport Risques naturels majeurs outre-mer	Conférence de presse - adoption durapport Risques naturels majeurs outre-mer	2019-11-14 14:40:00	2019-11-14 16:00:00	\N	\N	5	0	\N	\N
434041	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Lutte contre la haine sur internet	\N	2019-11-27 10:30:00	2019-11-27 12:30:00	\N	\N	1	0	\N	\N
434043	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Lutte contre la haine sur internet	\N	2019-11-27 16:30:00	2019-11-27 17:30:00	\N	\N	1	0	\N	\N
445947	DELEGATION	AUCUNE	\N	\N	PROS	Audition de M. Bill Mitchell, professeur à l'Université de Newcastle (Australie)	Audition de M. Bill Mitchell, professeur à l'Université de Newcastle (Australie)	2020-02-20 08:30:00	2020-02-20 09:40:00	\N	\N	7	0	\N	\N
446006	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteur Phagothérapie	Audition rapporteur Phagothérapie - Dr. David Lebeaux	2020-01-28 14:30:00	2020-01-28 15:30:00	\N	\N	1	0	\N	\N
446008	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteur Phagothérapie	Audition rapporteur Phagothérapie (ANSM)	2020-01-30 14:30:00	2020-01-30 15:30:00	\N	\N	1	0	\N	\N
446010	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteur Pollution plastique	Audition rapporteur Pollution plastique (Veolia)	2020-01-30 13:45:00	2020-01-30 15:00:00	\N	\N	2	0	\N	\N
446013	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteur Pollution plastique	Audition rapporteur Pollution plastique (Cerema)	2020-01-30 15:15:00	2020-01-30 16:15:00	\N	\N	2	0	\N	\N
498100	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Rapport général - MEDEF	PLF pour 2021 - Rapport général - MEDEF	2020-10-27 09:30:00	2020-10-27 10:30:00	\N	\N	1	0	\N	\N
498102	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Rapport général - DLF - DGCL - DB	PLF pour 2021 - Rapport général - DLF - DGCL - DB	2020-10-27 18:00:00	2020-10-27 19:15:00	\N	\N	2	0	\N	\N
498105	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Rapport général - TR Associations d'élus	PLF pour 2021 - Rapport général - TR Associations d'élus	2020-10-28 17:30:00	2020-10-28 18:45:00	\N	\N	3	0	\N	\N
498109	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Rapport général - Délégation collectivités territoriale AN	PLF pour 2021 - Rapport général - Délégation collectivités territoriale AN	2020-10-29 13:30:00	2020-10-29 14:30:00	\N	\N	3	0	\N	\N
498113	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2020-11-04 08:30:00	2020-11-04 12:30:00	2020-11-04 12:38:25	2020-11-04 12:44:31	42	0	\N	\N
498114	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	211	Réunion de bureau DDF	Réunion de bureau DDF	2020-11-02 14:00:00	2020-11-02 14:40:00	\N	\N	13	0	\N	\N
498216	GIA	AUCUNE	\N	\N	\N	visioconférence de l'Institut d'études de géopolitique appliquée (EGA)	Intervention sur l'EVFTA	2020-09-04 09:00:00	2020-09-04 12:00:00	\N	\N	1	0	626	\N
498234	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Plf 2021 - Crédits de l'audiovisuel public	Audition TV5 Monde	2020-11-03 14:00:00	2020-11-03 15:00:00	\N	\N	3	0	\N	\N
498243	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Plf 2021 - Crédits de l'audiovisuel public	Audition Radio France	2020-11-09 15:30:00	2020-11-09 16:40:00	\N	\N	6	0	\N	\N
498244	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Plf 2021 - Crédits de l'audiovisuel public	Audition FMM	2020-11-03 16:00:00	2020-11-03 17:15:00	\N	\N	5	0	\N	\N
498245	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Plf 2021 - Crédits de l'audiovisuel public	Audition de l'INA	2020-11-03 17:15:00	2020-11-03 18:10:00	\N	\N	3	0	\N	\N
498247	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Plf 2021 - Crédits de l'audiovisuel public	Audition de FT	2020-11-09 14:00:00	2020-11-09 15:20:00	\N	\N	7	0	\N	\N
498249	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Plf 2021 - Crédits de l'audiovisuel public	Audition DGMIC	2020-11-10 14:30:00	2020-11-10 15:30:00	\N	\N	0	0	\N	\N
498252	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Plf 2021 - Crédits de l'audiovisuel public	Audition d'Arte France	2020-11-18 16:30:00	2020-11-18 17:30:00	\N	\N	2	0	\N	\N
498254	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2021 - Crédits Sport	Audition Union Sport & Cycle	2020-10-29 13:30:00	2020-10-29 14:30:00	\N	\N	1	0	\N	\N
498255	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2021 - Crédits Sport	Audition INSEP	2020-11-05 15:00:00	2020-11-05 16:00:00	\N	\N	3	0	\N	\N
498256	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2021 - Crédits Sport	Cabinet ministère Sports	2020-11-05 16:00:00	2020-11-05 17:30:00	\N	\N	3	0	\N	\N
498257	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2021 - Crédits Sport	Audition de Solidéo	2020-11-05 17:35:00	2020-11-05 18:40:00	\N	\N	2	0	\N	\N
498263	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2021 - Crédits Sport	Audition Observatoire économie du Sport	2020-10-27 09:00:00	2020-10-27 10:15:00	\N	\N	1	0	\N	\N
498265	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2021 - Crédits Sport	Audition AFLD	2020-10-27 14:30:00	2020-10-27 15:30:00	\N	\N	1	0	\N	\N
498267	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2021 - Crédits Sport	Audition Sporsora	2020-10-27 17:00:00	2020-10-27 18:00:00	\N	\N	1	0	\N	\N
498268	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2021 - Crédits Sport	Audition ANS	2020-10-28 14:00:00	2020-10-28 15:00:00	\N	\N	1	0	\N	\N
498289	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2021 - Crédits Sport	Audition CNOSF	2020-10-20 14:30:00	2020-10-20 15:30:00	\N	\N	4	0	\N	\N
498293	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2021 - Crédits Sport	Audition ANDES	2020-10-21 14:00:00	2020-10-21 15:00:00	\N	\N	3	0	\N	\N
498311	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL restitutions	Audition restitution	2020-10-21 14:00:00	2020-10-21 15:00:00	\N	\N	3	0	\N	\N
498634	DELEGATION	AUTRE	\N	\N	ENTREPRISES	Réunion plénière	\N	2020-11-05 10:00:00	2020-11-05 12:00:00	2020-11-05 18:36:24	\N	23	0	\N	\N
498855	DELEGATION	AUDRAP	\N	\N	PROS	Audition de M. Jean-Marc OFFNER, directeur d'a'urba, agence d'urbanisme	\N	2020-11-10 15:00:00	2020-11-10 16:15:00	\N	\N	1	0	\N	\N
499122	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Coopération franco-britannique de défense	visioconférence avec les présidents des commissions chargées de la défense de l'Assemblée nationale, de la chambre des c	2020-10-29 10:30:00	2020-10-29 12:00:00	\N	\N	1	0	\N	\N
499408	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe	Assemblée générale du groupe	2020-11-04 14:30:00	2020-11-04 14:55:00	\N	\N	36	0	CHRETORIENT	CHRETORIENT
500174	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2021 - Programme 185 	\N	2020-11-03 14:15:00	2020-11-03 15:45:00	\N	\N	2	0	\N	\N
500177	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2021 - Programme 185	\N	2020-11-04 16:30:00	2020-11-04 19:30:00	\N	\N	2	0	\N	\N
500180	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2021 - Programme 185	\N	2020-11-05 10:00:00	2020-11-05 13:00:00	\N	\N	2	0	\N	\N
500186	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJLF pour 2021 - p 146	PJLF pour 2021 - p 146	2020-11-03 16:30:00	2020-11-03 17:30:00	\N	\N	2	0	\N	\N
500318	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2021 - Avis juridictions administratives et financières	PLF 2021 - Avis juridictions administratives et financières	2020-11-04 14:00:00	2020-11-04 14:35:00	\N	\N	1	0	\N	\N
500320	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2021 - Avis juridictions administratives et financières	PLF 2021 - Avis juridictions administratives et financières	2020-11-04 14:35:00	2020-11-04 15:10:00	\N	\N	1	0	\N	\N
500322	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2021 - Avis juridictions administratives et financières	PLF pour 2021 - Avis juridictions administratives et financières	2020-11-04 17:45:00	2020-11-04 18:20:00	\N	\N	1	0	\N	\N
459618	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2019-11-07 11:00:00	2019-11-07 15:00:00	\N	\N	3	0	\N	\N
500324	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2021 - Avis juridictions administratives et financières	PLF pour 2021 - Avis juridictions administratives et financières	2020-11-04 18:20:00	2020-11-04 19:00:00	\N	\N	1	0	\N	\N
500326	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2021 - Avis juridictions administratives et financières	\N	2020-11-05 10:15:00	2020-11-05 11:00:00	\N	\N	1	0	\N	\N
500328	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2021 - Avis juridictions administratives et financières	PLF pour 2021 - Avis juridictions administratives et financières	2020-11-05 11:30:00	2020-11-05 12:45:00	\N	\N	1	0	\N	\N
500431	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2020-11-05 08:30:00	2020-11-05 11:10:00	\N	\N	6	0	\N	\N
500573	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Rapport général - APE	PLF pour 2021 - Rapport général - APE	2020-11-03 17:00:00	2020-11-03 18:00:00	\N	\N	1	0	\N	\N
500576	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - CAS PFE - SUEZ	PLF pour 2021 - CAS PFE - SUEZ	2020-11-04 14:30:00	2020-11-04 15:30:00	\N	\N	1	0	\N	\N
500578	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - CAS PFE - APE / ENGIE / VEOLIA	PLF pour 2021 - CAS PFE - APE / ENGIE / VEOLIA	2020-11-06 15:00:00	2020-11-06 18:00:00	\N	\N	1	0	\N	\N
500580	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Rapport général - SUEZ	PLF pour 2021 - Rapport général - SUEZ	2020-11-06 16:00:00	2020-11-06 16:40:00	\N	\N	1	0	\N	\N
500582	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Écologie - VNF / DAM	PLF pour 2021 - Écologie - VNF / DAM	2020-11-03 14:30:00	2020-11-03 16:30:00	\N	\N	2	0	\N	\N
500585	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Écologie - DGTIM	PLF pour 2021 - Écologie - DGTIM	2020-11-03 18:30:00	2020-11-03 19:30:00	\N	\N	2	0	\N	\N
500588	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Écologie - AFITF	PLF pour 2021 - Écologie - AFITF	2020-11-04 17:30:00	2020-11-04 18:30:00	\N	\N	2	0	\N	\N
500591	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Écologie - UAF	PLF pour 2021 - Écologie - UAF	2020-11-05 14:30:00	2020-11-05 15:30:00	\N	\N	1	0	\N	\N
500593	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Écologie - CRE	PLF pour 2021 - Écologie - CRE	2020-11-06 11:30:00	2020-11-06 12:30:00	\N	\N	1	0	\N	\N
500702	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Politique de la ville - Cohésion des territoire - ANCT	Politique de la ville - Cohésion des territoire - ANCT	2020-11-05 13:30:00	2020-11-05 14:30:00	\N	\N	1	0	\N	\N
500703	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Politique de la ville - Cohésion des territoires - ANRU	Politique de la ville - Cohésion des territoires - ANRU	2020-11-05 14:30:00	2020-11-05 15:30:00	\N	\N	1	0	\N	\N
500704	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2021 - Mission Plan de relance-Bpifrance	PJLF 2021 - Mission Plan de relance-Bpifrance	2020-11-04 14:00:00	2020-11-04 15:00:00	\N	\N	1	0	\N	\N
373894	GIA	AUCUNE	\N	\N	\N	Petit déjeuner interparlementaire	\N	2019-04-01 08:30:00	2019-04-01 10:30:00	\N	\N	3	0	626	\N
375455	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2019-05-14 16:40:00	2019-05-14 19:15:00	2019-05-14 19:13:27	2019-05-15 11:27:47	43	0	\N	\N
375457	COM_PERMANENTE	AUTRE	\N	SOCI	\N	réunion plénière	\N	2019-05-15 09:00:00	2019-05-15 12:05:00	2019-05-15 16:54:17	2019-05-15 17:21:50	36	0	\N	\N
375458	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-05-07 14:50:00	2019-05-07 15:15:00	2019-05-07 15:47:28	2019-05-07 17:22:39	32	0	\N	\N
376746	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Notre-Dame de Paris	PJL Notre-Dame de Paris	2019-05-27 16:00:00	2019-05-27 20:20:00	\N	\N	66	0	\N	\N
376747	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Notre-Dame de Paris	PJL Notre-Dame de Paris	2019-05-27 21:50:00	2019-05-28 01:20:00	\N	\N	45	0	\N	\N
379722	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2019 - La Prime d'activité - Secrétaire d'état solidarités et de la santé	Contrôle 2019 - La Prime d'activité - Secrétaire d'état solidarités et de la santé	2019-05-16 10:00:00	2019-05-16 12:00:00	\N	\N	2	0	\N	\N
379755	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Controle 2019 - Le numérique à l'école - Déplacement Lunéville	Controle 2019 - Le numérique à l'école - Déplacement Lunéville	2019-05-10 07:40:00	2019-05-10 15:05:00	\N	\N	1	0	\N	\N
379771	COM_ENQUETE	PLENIERE	\N	SOUVERAINETE	\N	Auditions P. Bellanger	\N	2019-05-16 17:05:00	2019-05-16 18:15:00	2019-05-16 19:42:51	2019-05-17 10:17:08	12	0	\N	\N
385959	MECSS	AUCUNE	\N	\N	MECSS	MECSS	MECSS	2019-06-12 09:30:00	2019-06-12 11:40:00	2019-06-12 11:38:26	2019-06-12 16:55:41	24	0	\N	\N
394369	DELEGATION	AUDRAP	\N	\N	PROS	Audition de M. Rodolphe Gélin	\N	2019-07-02 15:45:00	2019-07-02 16:45:00	\N	\N	2	0	\N	\N
394816	MISSION	AUTRE	\N	FONDS	\N	Auditions plénières - SGAE et ADF	\N	2019-06-25 14:05:00	2019-06-25 16:30:00	2019-06-25 17:50:49	2019-06-26 18:39:11	9	0	\N	\N
428464	DELEGATION	AUCUNE	\N	\N	211	Table ronde sur les violences sexuelles dans les territoires en crise	Table ronde sur les violences sexuelles dans les territoires en crise	2019-11-28 08:30:00	2019-11-28 10:55:00	2019-11-28 12:00:27	\N	6	0	\N	\N
428540	GIA	AUCUNE	\N	\N	\N	Rencontre avec le nouvel ambassadeur d'Irak	Rencontre entre le sénateur Bernard Cazeau et le nouvel ambassadeur d'Irak, M. Nazar Kheirallah	2019-11-20 17:00:00	2019-11-20 17:45:00	\N	\N	1	0	615	\N
428542	GIA	AUCUNE	\N	\N	\N	Colloque Irak	Colloque organisé par le réseau des ambassadeurs de la jeunesse, parrainé par le sénateur Bernard Cazeau	2020-04-27 09:00:00	2020-04-27 18:00:00	\N	\N	1	0	615	\N
394040	CMP	AUTRE	\N	ARTICLE13	\N	PJLO Application du 5ème alinéa de l'article 13 de la Constitution	PJLO Application du 5ème alinéa de l'article 13 de la Constitution	2019-06-25 11:50:00	2019-06-25 11:55:00	\N	\N	9	0	\N	\N
394075	CMP	AUTRE	\N	OFBC	\N	PJL Création de l'Office français de la biodiversité	PJL Création de l'Office français de la biodiversité	2019-06-25 09:05:00	2019-06-25 11:50:00	\N	\N	10	0	\N	\N
422959	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion 20191106 - PPL Agir contre les violences au sein de la famille	Réunion 20191106 - PPL Agir contre les violences au sein de la famille	2019-11-06 10:00:00	2019-11-06 11:00:00	2019-11-06 16:30:43	2019-11-06 17:28:37	39	0	\N	\N
428544	GIA	AUCUNE	\N	\N	\N	Séminaire Afghanistan	Séminaire organisé par le président du GIA, M. Tourenne	2020-01-16 09:30:00	2020-01-16 13:00:00	\N	\N	2	0	648	\N
428691	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT Stratégie industrielle de l'UE	Audition de M. Heinz	2019-11-19 10:00:00	2019-11-19 11:00:00	\N	\N	1	0	\N	\N
434187	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLO et PJL Application du 5ème alinéa de l'article 13 de la Constitution	\N	2019-11-26 14:30:00	2019-11-26 18:00:00	\N	\N	1	0	\N	\N
434315	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière - table ronde - nouvelles technologiques et évolution des métiers	L'impact des nouvelles technologies, en particulier de l¿IA, sur l'évolution des métiers et des besoins de formation	2019-11-28 10:30:00	2019-11-28 12:40:00	2019-11-28 17:34:28	\N	10	0	\N	\N
435850	COM_EURO	DEPLACEMENT	\N	AFEU	\N	Audition rapporteur	Adhésion de l'UE à la CEDH 	2019-12-09 07:55:00	2019-12-09 17:35:00	\N	\N	2	0	\N	\N
435852	COM_SPECIALE	AUDRAP	\N	BIOETHIQUE	\N	Table ronde M. Jomier - Mme Jourda sociétés savantes / médecins art 1, 2 et 20 à 22	\N	2019-12-03 14:30:00	2019-12-03 16:30:00	\N	\N	6	0	\N	\N
436353	ETUDES	AUCUNE	\N	\N	\N	GE Élevage - Audition CNE	GE Élevage - Audition CNE	2019-12-04 08:00:00	2019-12-04 09:00:00	\N	\N	11	0	\N	911
437462	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	CETA	CETA	2019-12-02 17:30:00	2019-12-02 18:30:00	\N	\N	1	0	\N	\N
437464	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	CETA	CETA	2019-12-03 09:30:00	2019-12-03 10:30:00	\N	\N	1	0	\N	\N
437469	GIA	AUCUNE	\N	\N	\N	Coopé - Visite de Mme Nie Ching TEO, membre de la chambre basse du Parlement malaisien	Coopé - Visite de Mme Nie Ching TEO, membre de la chambre basse du Parlement malaisien	2019-12-04 12:30:00	2019-12-04 13:45:00	\N	\N	2	0	609	\N
442696	COM_SPECIALE	PLENIERE	\N	BIOETHIQUE	\N	Examen du rapport et établissement du texte	\N	2020-01-08 13:30:00	2020-01-08 15:00:00	2020-01-08 15:01:08	2020-01-08 17:59:52	28	1	\N	\N
442845	COM_ENQUETE	AUDRAP	\N	RADICALI	\N	Céline Pina - Anne Sugier et Linda Weil-Curiel (Ligue du droit international des femmes)	Céline Pina - Anne Sugier et Linda Weil-Curiel (Ligue du droit international des femmes)	2020-01-09 10:35:00	2020-01-09 12:30:00	\N	\N	3	0	\N	\N
443155	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Cour d'appel de Paris	Cour d'appel de Paris	2020-01-08 13:45:00	2020-01-08 14:45:00	\N	\N	1	0	\N	\N
443429	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2020-01-08 16:30:00	2020-01-08 18:50:00	2020-01-08 19:00:43	2020-01-09 15:08:09	23	0	\N	\N
443800	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteur Phagothérapie	Audition rapporteur Phagothérapie - Institut Pasteur/Centre hospitalier René Dubos Pontoise	2020-01-27 14:30:00	2020-01-27 16:00:00	\N	\N	1	0	\N	\N
444715	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition difficultés de recrutement et évolution des métiers	Audition difficultés de recrutement et évolution des métiers - France Stratégie	2020-01-14 10:05:00	2020-01-14 11:25:00	\N	\N	3	0	\N	\N
444727	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition entreprises responsables et engagées	Audition entreprises responsables et engagées -  \tInstitut français des administrateurs	2020-01-14 15:00:00	2020-01-14 16:00:00	\N	\N	2	0	\N	\N
444730	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition entreprises responsables et engagées	Audition entreprises responsables et engagées -  \tCercle d'éthique des affaires	2020-01-14 16:10:00	2020-01-14 17:00:00	\N	\N	2	0	\N	\N
498211	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2021 - Mission Solidarité	\N	2020-11-03 09:00:00	2020-11-03 10:05:00	\N	\N	2	0	\N	\N
498214	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2021 - Mission Solidarité	\N	2020-11-03 10:05:00	2020-11-03 10:45:00	\N	\N	1	0	\N	\N
498218	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2020-10-27 18:05:00	2020-10-27 19:55:00	\N	\N	3	0	\N	\N
500548	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Cohésion des territoires - DMAT	PLF pour 2021 - Cohésion des territoires - DMAT	2020-11-04 16:30:00	2020-11-04 17:15:00	\N	\N	1	0	\N	\N
500550	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Cohésion des territoires - ANCT	PLF pour 2021 - Cohésion des territoires - ANCT	2020-11-05 11:30:00	2020-11-05 12:30:00	\N	\N	1	0	\N	\N
500553	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Avis Biodiversité - France nature environnement - Greenpeace	Avis Biodiversité - France nature environnement - Greenpeace	2020-11-03 10:25:00	2020-11-03 11:00:00	\N	\N	1	0	\N	\N
500554	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Solidarité - DGCS	PLF pour 2021 - Solidarité - DGCS	2020-11-04 15:00:00	2020-11-04 16:30:00	\N	\N	2	0	\N	\N
500555	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Avis Biodiversité - Agences de l'eau	Avis Biodiversité - Agences de l'eau	2020-10-27 09:00:00	2020-10-27 10:15:00	\N	\N	1	0	\N	\N
500556	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Avis Biodiversité - Cabinet Mme Abba, secrétaire d'État chargée de la biodiversité	Avis Biodiversité - Cabinet Mme Abba, secrétaire d'État chargée de la biodiversité	2020-10-28 14:00:00	2020-10-28 14:45:00	\N	\N	1	0	\N	\N
500557	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Avis Biodiversité - Parcs nationaux français	Avis Biodiversité - Parcs nationaux français	2020-11-03 09:45:00	2020-11-03 10:25:00	\N	\N	2	0	\N	\N
500563	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Rapport général et Plan de relance - DGEC	PLF pour 2021 - Rapport général et Plan de relance - DGEC	2020-11-04 14:00:00	2020-11-04 15:00:00	\N	\N	2	0	\N	\N
500567	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - MIRES - CGE	PLF pour 2021 - MIRES - CGE	2020-11-05 17:30:00	2020-11-05 18:30:00	\N	\N	1	0	\N	\N
500571	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2020-11-10 09:00:00	2020-11-10 11:01:00	2020-11-10 12:10:35	2020-11-10 17:46:06	32	0	\N	\N
500572	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2020-11-10 15:30:00	2020-11-10 17:45:00	2020-11-13 13:51:04	2020-11-13 14:28:04	64	0	\N	\N
500667	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Avis Energie	Auditions de M. Daniel Gremillet	2020-10-29 09:45:00	2020-10-29 10:30:00	\N	\N	1	0	\N	\N
500669	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Avis Energie PJLF 2021	Auditions de M. Daniel Gremillet	2020-10-29 10:30:00	2020-10-29 12:15:00	\N	\N	1	0	\N	\N
500671	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Avis Energie PJLF 2021	\N	2020-10-28 11:00:00	2020-10-28 12:30:00	\N	\N	1	0	\N	\N
500673	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Avis Energie PJLF 2021	Auditions de M. Daniel Gremillet	2020-11-03 09:31:00	2020-11-03 11:15:00	\N	\N	1	0	\N	\N
500675	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Avis Energie  PJLF 2021	Auditions de M. Daniel Gremillet	2020-11-03 17:00:00	2020-11-03 18:45:00	\N	\N	1	0	\N	\N
500679	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Solidarité - NEXEM	PLF pour 2021 - Solidarité - NEXEM	2020-11-06 10:00:00	2020-11-06 11:00:00	\N	\N	2	0	\N	\N
500680	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Avis Prévention des risques - Autorité de sûreté nucléaire	Avis Prévention des risques - Autorité de sûreté nucléaire	2020-11-04 17:00:00	2020-11-04 18:00:00	\N	\N	1	0	\N	\N
500683	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Avis Prévention des risques - Ademe	Avis Prévention des risques - Ademe	2020-11-04 18:00:00	2020-11-04 19:00:00	\N	\N	1	0	\N	\N
500684	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Avis Prévention des risques - Direction générale de prévention des risques	Avis Prévention des risques - Direction générale de prévention des risques	2020-11-05 09:30:00	2020-11-05 10:30:00	\N	\N	1	0	\N	\N
500685	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Avis Prévention des risques - Ineris	Avis Prévention des risques - Ineris	2020-11-05 13:45:00	2020-11-05 14:45:00	\N	\N	1	0	\N	\N
500686	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Avis Energie PJLF 2021	Auditions de M. Daniel Gremillet	2020-11-04 15:45:00	2020-11-04 16:45:00	\N	\N	1	0	\N	\N
500690	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Avis Energie  PJLF 2021	Auditions de M. Daniel Gremillet	2020-11-04 18:30:00	2020-11-04 20:30:00	\N	\N	1	0	\N	\N
500694	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Avis Energie PJLF 2021	Auditions de M. Daniel Gremillet	2020-11-05 09:00:00	2020-11-05 12:00:00	\N	\N	1	0	\N	\N
500695	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Avis Transports aériens	Avis Transports aériens	2020-11-03 14:00:00	2020-11-03 16:30:00	\N	\N	1	0	\N	\N
500698	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Avis Transports aériens	Avis Transports aériens	2020-11-05 10:00:00	2020-11-05 13:00:00	\N	\N	1	0	\N	\N
500700	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2021 - Mission Plan de relance - Direction générale des entreprises	PJLF 2021 - Mission Plan de relance - Direction générale des entreprises	2020-11-03 09:40:00	2020-11-03 10:30:00	\N	\N	1	0	\N	\N
500841	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Avis Industrie PJLF 2021	Auditions de M. Franck Montaugé	2020-11-05 18:15:00	2020-11-05 19:00:00	\N	\N	1	0	\N	\N
500860	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2021 Création	\N	2020-11-05 10:00:00	2020-11-05 11:00:00	\N	\N	3	0	\N	\N
501112	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Avis transports  M. Tabarot	PJLF 2021 Avis transports Auditions M. Tabarot	2020-11-04 17:00:00	2020-11-04 17:50:00	\N	\N	4	0	\N	\N
501142	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Avis Transports M. Tabarot	PJLF 2021 Avis transports Auditions M. Tabarot	2020-11-05 11:00:00	2020-11-05 11:40:00	\N	\N	1	0	\N	\N
501151	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Avis transports  M. Tabarot	PJLF 2021 Avis transports Auditions M. Tabarot	2020-11-09 15:15:00	2020-11-09 16:00:00	\N	\N	1	0	\N	\N
501581	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2021 - Avis Sécurités	PLF 2021 - Avis Sécurités	2020-11-10 13:50:00	2020-11-10 17:50:00	\N	\N	4	0	\N	\N
502080	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF2021  Enseignement scolaire	\N	2020-11-02 10:00:00	2020-11-02 11:00:00	\N	\N	1	0	\N	\N
502082	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF2021 Enseignement agricole	\N	2020-10-29 09:00:00	2020-10-29 10:00:00	\N	\N	2	0	\N	\N
502085	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF2021 Enseignement agricole	\N	2020-10-29 10:00:00	2020-10-29 11:00:00	\N	\N	1	0	\N	\N
502087	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF2021 Enseignement agricole	\N	2020-10-29 13:45:00	2020-10-29 14:45:00	\N	\N	1	0	\N	\N
502647	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2021 - Programme 178	\N	2020-11-10 14:00:00	2020-11-10 16:15:00	\N	\N	2	0	\N	\N
502650	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2021 - ¨Programme 105	\N	2020-11-10 16:30:00	2020-11-10 17:00:00	\N	\N	1	0	\N	\N
502652	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2021 - Programme 105	\N	2020-11-10 17:05:00	2020-11-10 18:00:00	\N	\N	2	0	\N	\N
502655	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2021 - Programme 105	\N	2020-11-12 17:00:00	2020-11-12 18:10:00	\N	\N	2	0	\N	\N
502658	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2021 - Programme 105	\N	2020-11-12 18:10:00	2020-11-12 19:20:00	\N	\N	1	0	\N	\N
502840	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Écologie - ADEME	PLF pour 2021 - Écologie - ADEME	2020-11-06 14:00:00	2020-11-06 15:00:00	\N	\N	1	0	\N	\N
502842	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Écologie - SG Min Eco / OFB	PLF pour 2021 - Écologie - SG Min Eco / OFB	2020-11-06 16:30:00	2020-11-06 18:30:00	\N	\N	1	0	\N	\N
502861	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJLF POUR 2020 - P. 144	\N	2020-11-10 16:10:00	2020-11-10 17:15:00	\N	\N	2	0	\N	\N
502864	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - MIRES - INSERM	PLF pour 2021 - MIRES - INSERM	2020-11-10 10:00:00	2020-11-10 11:00:00	\N	\N	1	0	\N	\N
502866	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - MIRES - CNES	PLF pour 2021 - MIRES - CNES	2020-11-10 13:30:00	2020-11-10 14:30:00	\N	\N	1	0	\N	\N
502868	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - MIRES - CNOUS	PLF pour 2021 - MIRES - CNOUS	2020-11-10 17:30:00	2020-11-10 18:30:00	\N	\N	1	0	\N	\N
502870	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - MIRES - TR Enseignement privé	PLF pour 2021 - MIRES - TR Enseignement privé	2020-11-12 10:00:00	2020-11-12 11:00:00	\N	\N	1	0	\N	\N
502872	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - MIRES - ANR	PLF pour 2021 - MIRES - ANR	2020-11-12 11:30:00	2020-11-12 12:30:00	\N	\N	1	0	\N	\N
375459	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-05-07 09:00:00	2019-05-07 10:05:00	2019-05-07 14:35:59	2019-05-07 17:23:13	28	3	\N	\N
375460	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	\N	2019-05-07 14:05:00	2019-05-07 15:05:00	2019-05-07 15:24:19	2019-05-07 17:23:13	15	0	\N	\N
375498	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	\N	\N	2019-05-28 15:30:00	2019-05-28 16:30:00	\N	\N	0	0	\N	\N
375499	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	\N	\N	2019-06-11 17:45:00	2019-06-11 18:45:00	\N	\N	0	0	\N	\N
375500	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	\N	\N	2019-06-12 16:30:00	2019-06-12 17:15:00	\N	\N	0	0	\N	\N
375501	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	\N	\N	2019-06-18 14:30:00	2019-06-18 15:15:00	\N	\N	0	0	\N	\N
375546	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Organisation du système de santé	PJL Organisation du système de santé	2019-05-06 14:00:00	2019-05-06 15:00:00	\N	\N	3	0	\N	\N
375566	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Organisation du système de santé	PJL Organisation du système de santé	2019-05-06 17:15:00	2019-05-06 18:00:00	\N	\N	2	0	\N	\N
378105	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2019-04-30 14:45:00	2019-04-30 16:40:00	\N	\N	3	0	\N	\N
378110	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2019-05-07 14:35:00	2019-05-07 16:30:00	\N	\N	3	0	\N	\N
379341	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Pastoralisme	GT Pastoralisme	2019-05-16 13:50:00	2019-05-16 15:00:00	\N	\N	8	0	\N	\N
382934	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI S	\N	2019-05-23 15:55:00	2019-05-23 16:45:00	\N	\N	6	0	\N	\N
382942	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Sécurité des ponts	\N	2019-05-14 18:30:00	2019-05-14 19:15:00	\N	\N	3	0	\N	\N
448841	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-01-29 09:30:00	2020-01-29 12:40:00	2020-01-29 18:05:26	2020-01-29 18:11:56	45	0	\N	\N
387591	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Luis VASSY, nouvel Ambassadeur de France aux Pays-Bas	Entretien avec M. Luis VASSY, nouvel Ambassadeur de France aux Pays-Bas	2019-06-06 16:15:00	2019-06-06 17:00:00	\N	\N	1	0	599	\N
410629	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Statut de citoyen sauveteur	\N	2019-10-02 14:00:00	2019-10-02 15:00:00	\N	\N	1	0	\N	\N
410675	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Statut de citoyen sauveteur	\N	2019-10-02 16:40:00	2019-10-02 17:20:00	\N	\N	1	0	\N	\N
410691	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Statut de citoyen sauveteur	\N	2019-10-03 09:00:00	2019-10-03 12:30:00	\N	\N	1	0	\N	\N
411925	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL AVIA	\N	2019-10-08 10:00:00	2019-10-08 11:00:00	\N	\N	1	0	\N	\N
411926	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL AVIA	\N	2019-10-08 15:00:00	2019-10-08 17:00:00	\N	\N	1	0	\N	\N
411929	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL AVIA	\N	2019-10-09 10:00:00	2019-10-09 11:45:00	\N	\N	1	0	\N	\N
414432	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Nouveaux territoires du sport	MI Nouveaux territoires du sport	2019-10-15 17:00:00	2019-10-15 17:35:00	\N	\N	5	0	\N	\N
414438	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Jeunesse et vie associative	PLF 2020 - Crédits Jeunesse et vie associative	2019-10-15 15:30:00	2019-10-15 16:45:00	\N	\N	2	0	\N	\N
424190	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 6 novembre 2019	Réunion de la commission des affaires européennes du 6 novembre 2019	2019-11-06 14:05:00	2019-11-06 14:55:00	2019-11-06 15:16:11	2019-11-06 15:17:01	23	0	\N	\N
430759	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution Plastique	Audition rapporteurs Pollution Plastique (CGDD)	2019-11-26 15:45:00	2019-11-26 16:45:00	\N	\N	2	0	\N	\N
430766	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	206	Rencontre avec une délégation de parlementaires russes	Rencontre avec une délégation de parlementaires russes	2019-11-27 16:10:00	2019-11-27 18:20:00	\N	\N	8	0	\N	\N
430777	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière - Audition publique 	Réunion plénière - Audition publique sur les enjeux du conseil scientifique aux institutions politiques	2019-11-28 10:45:00	2019-11-28 13:00:00	\N	\N	8	0	\N	\N
437895	SEANCE_PLENIERE	SCRUSOL	1281	\N	\N	Scrutin solennel - PLF 2020	Scrutin solennel - PLF 2020	2019-12-10 15:29:00	2019-12-10 16:23:00	\N	\N	0	0	\N	\N
439976	GIA	AUCUNE	\N	\N	\N	Petit déjeuner en l'honneur de M. Senèze	\N	2019-12-12 08:30:00	2019-12-12 09:30:00	\N	\N	5	0	629	\N
446022	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2020-01-14 14:35:00	2020-01-14 15:50:00	\N	\N	3	0	\N	\N
446361	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe d'amitié pour préparer la mission en Jordanie	Assemblée générale du groupe d'amitié pour préparer la mission en Jordanie	2020-01-14 17:30:00	2020-01-14 18:15:00	\N	\N	3	0	659	\N
446366	GIA	AUCUNE	\N	\N	\N	Réunion de travail pour préparer le déplacement en Egypte 	Réunion de travail pour préparer le déplacement en Egypte 	2020-01-16 10:30:00	2020-01-16 11:30:00	\N	\N	1	0	617	\N
446794	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-01-22 09:39:00	2020-01-22 13:00:00	2020-01-22 12:56:25	2020-01-22 15:46:35	40	0	\N	\N
447249	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition MI Gouvernance des ports maritimes	Audition MI Gouvernance des ports maritimes - Présidente Mme Filleul, Rapporteur M. Vaspart	2020-01-21 08:30:00	2020-01-21 09:40:00	\N	\N	5	0	\N	\N
447255	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition MI Gouvernance des ports maritimes	Audition MI Gouvernance des ports maritimes - Présidente Mme Filleul, Rapporteur M. Vaspart	2020-01-21 14:30:00	2020-01-21 15:25:00	\N	\N	6	0	\N	\N
447262	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition MI Gouvernance des ports maritimes	Audition MI Gouvernance des ports maritimes - Présidente Mme Filleul, Rapporteur M. Vaspart	2020-01-21 15:25:00	2020-01-21 16:20:00	\N	\N	3	0	\N	\N
447581	COM_ENQUETE	PLENIERE	\N	RADICALI	\N	Auditions - Nicolas Lerner, DGSI - Thomas Campeaux, DLPAJ	Auditions - Nicolas Lerner, DGSI - Thomas Campeaux, DLPAJ	2020-01-28 15:05:00	2020-01-28 18:00:00	2020-01-28 18:28:01	2020-01-29 18:06:57	17	0	\N	\N
447583	COM_ENQUETE	PLENIERE	\N	RADICALI	\N	Auditions plénières - Médéric Chapitaux - Mohamed Louizi	Auditions plénières - Médéric Chapitaux - Mohamed Louizi	2020-01-29 16:35:00	2020-01-29 18:40:00	2020-01-29 18:46:12	2020-01-30 09:52:21	4	0	\N	\N
448601	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	\N	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne 	2020-01-21 17:15:00	2020-01-21 18:30:00	2020-01-23 15:49:44	\N	8	0	\N	\N
448637	GIA	AUCUNE	\N	\N	\N	entretien avec M. Jean-Louis Falconi, ambassadeur de France en Serbie	entretien avec M. Jean-Louis Falconi, ambassadeur de France en Serbie	2020-01-23 08:30:00	2020-01-23 10:00:00	\N	\N	3	0	674	\N
448735	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Droit au transport	PPL Droit au transport	2020-02-04 15:50:00	2020-02-04 20:12:00	\N	\N	148	0	\N	\N
448737	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2020-02-05 15:01:00	2020-02-05 16:15:00	\N	\N	301	0	\N	\N
448738	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR Enfants francà-japonais	PPR Enfants francà-japonais	2020-02-05 16:32:00	2020-02-05 17:41:00	\N	\N	50	0	\N	\N
448739	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Sécurité sanitaire	PPL Sécurité sanitaire	2020-02-05 17:41:00	2020-02-05 19:43:00	\N	\N	57	0	\N	\N
448740	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Accès à l'énergie	PPL Accès à l'énergie	2020-02-06 09:01:00	2020-02-06 11:09:00	\N	\N	50	0	\N	\N
448741	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Privatisation ADP	Débat Privatisation ADP	2020-02-06 11:16:00	2020-02-06 12:42:00	\N	\N	50	0	\N	\N
448742	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Simplification propagande électorale	PPL Simplification propagande électorale	2020-02-06 14:33:00	2020-02-06 16:30:00	\N	\N	36	0	\N	\N
448743	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat sur le foncier agricole	Débat sur le foncier agricole	2020-02-06 16:33:00	2020-02-06 18:04:00	\N	\N	24	0	\N	\N
448837	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-01-28 18:05:00	2020-01-28 19:30:00	2020-01-28 19:31:18	2020-01-29 18:04:02	24	0	\N	\N
459623	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2019-11-19 16:45:00	2019-11-19 17:40:00	\N	\N	3	0	\N	\N
447997	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PPL Sécurité sanitaire et effectivité du droit au transport et PPL - Rapport et texte	\N	2020-01-29 09:05:00	2020-01-29 11:05:00	2020-01-29 18:13:11	2020-01-29 18:13:47	38	2	\N	\N
500705	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Politique de la ville - Cohésion des territoires - Mme Hai	Politique de la ville - Cohésion des territoires - Mme Hai	2020-11-05 15:30:00	2020-11-05 16:30:00	\N	\N	1	0	\N	\N
500706	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2021 - Mission Plan de relance-France Industrie	PJLF 2021 - Mission Plan de relance-France Industrie	2020-11-03 17:00:00	2020-11-03 18:00:00	\N	\N	1	0	\N	\N
500707	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Politique de la ville - Cohésion des territoires - Nexity	Politique de la ville - Cohésion des territoires - Nexity	2020-11-05 17:30:00	2020-11-05 18:00:00	\N	\N	1	0	\N	\N
500708	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Solidarité - APF France Handicap / Ministre Égalité	PLF pour 2021 - Solidarité - APF France Handicap / Ministre Égalité	2020-11-06 14:00:00	2020-11-06 16:30:00	\N	\N	2	0	\N	\N
500716	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Politique de la ville - Cohésion des territoires - Auteurs Insee et Inst.de Paris	Politique de la ville - Cohésion des territoires - Auteurs Insee et Inst.de Paris	2020-11-05 16:30:00	2020-11-05 17:30:00	\N	\N	1	0	\N	\N
500719	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - AGTE - ANTS	PLF pour 2021 - AGTE - ANTS	2020-11-05 11:30:00	2020-11-05 12:30:00	\N	\N	1	0	\N	\N
500721	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Action logement - PEEC - M. Fançois Jolivet, député	Action logement - PEEC - M. Fançois Jolivet, député	2020-11-06 09:30:00	2020-11-06 10:00:00	\N	\N	2	0	\N	\N
500722	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Action logement - PEEC - M. Cédric Loret	Action logement - PEEC - M. Cédric Loret	2020-11-06 10:00:00	2020-11-06 10:30:00	\N	\N	2	0	\N	\N
500723	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Avis Energie PJLF 2021	Auditions de M. Daniel Gremillet	2020-11-05 15:15:00	2020-11-05 16:45:00	\N	\N	1	0	\N	\N
500729	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Cohésion des territoires - Logement-Urbanisme - DGCS	PLF pour 2021 - Cohésion des territoires - Logement-Urbanisme - DGCS	2020-11-05 08:30:00	2020-11-05 09:30:00	\N	\N	1	0	\N	\N
500730	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJLF 2021 - Avis transports routiers - Réseau Action Climat	PJLF 2021 - Avis transports routiers - Réseau Action Climat	2020-11-05 11:30:00	2020-11-05 13:00:00	\N	\N	1	0	\N	\N
500733	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Cohésion des territoires - Logement-Urbanisme - CDC / MEDEF	PLF pour 2021 - Cohésion des territoires - Logement-Urbanisme - CDC / MEDEF	2020-11-06 09:00:00	2020-11-06 11:00:00	\N	\N	1	0	\N	\N
500736	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Culture - DGCA	PLF pour 2021 - Culture - DGCA	2020-11-04 14:15:00	2020-11-04 15:20:00	\N	\N	2	0	\N	\N
500739	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Culture - TR salles de spectacles	PLF pour 2021 - Culture - TR salles de spectacles	2020-11-04 16:30:00	2020-11-04 17:45:00	\N	\N	1	0	\N	\N
500744	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Mission industrie PJLF 2021	Auditions de M. Franck Montaugé	2020-11-03 09:40:00	2020-11-03 10:30:00	\N	\N	1	0	\N	\N
500745	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Médias - CNC / France Télévisions	PLF pour 2021 - Médias - CNC / France Télévisions	2020-11-05 14:00:00	2020-11-05 15:30:00	\N	\N	1	0	\N	\N
500798	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Mission industrie PJLF 2021	Auditions de M. Franck Montaugé	2020-11-03 17:00:00	2020-11-03 18:00:00	\N	\N	1	0	\N	\N
500800	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Mission industrie PJLF 2021	Auditions de M. Franck Montaugé	2020-11-04 14:00:00	2020-11-04 15:00:00	\N	\N	1	0	\N	\N
500803	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PJLF 2021 industrie	Auditions de M. Franck Montaugé	2020-11-04 16:30:00	2020-11-04 17:30:00	\N	\N	1	0	\N	\N
500837	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PJLF 2021 industrie	Auditions de M. Franck Montaugé	2020-11-05 16:00:00	2020-11-05 16:45:00	\N	\N	1	0	\N	\N
500838	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Cohésion des territoires - Logement - DHUP	Cohésion des territoires - Logement - DHUP	2020-11-05 10:30:00	2020-11-05 11:15:00	\N	\N	1	0	\N	\N
500840	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Avis Cohésion des territoires - Logement - ANAH	Avis Cohésion des territoires - Logement - ANAH	2020-11-05 11:15:00	2020-11-05 12:00:00	\N	\N	1	0	\N	\N
500864	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2021 Création	\N	2020-11-05 11:00:00	2020-11-05 11:45:00	\N	\N	3	0	\N	\N
500870	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Mission Economie M. Babary	Audition CCI France	2020-11-05 11:15:00	2020-11-05 12:15:00	\N	\N	1	0	\N	\N
500872	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Mission Economie M. Babary	Audition DGE	2020-11-06 10:00:00	2020-11-06 11:00:00	\N	\N	1	0	\N	\N
500875	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Mission Economie M. Babary	Audition CMA France et CPME	2020-11-09 10:00:00	2020-11-09 12:00:00	\N	\N	1	0	\N	\N
501087	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Avis transports  M. Tabarot	PJLF 2021 Avis transports Auditions M. Tabarot	2020-10-28 14:00:00	2020-10-28 15:15:00	\N	\N	3	0	\N	\N
501101	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Avis transports  M. Tabarot	PJLF 2021 Avis transports Auditions M. Tabarot	2020-11-03 16:30:00	2020-11-03 17:20:00	\N	\N	3	0	\N	\N
501108	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Avis Transports M. Tabarot	PJLF 2021 Avis transports Auditions M. Tabarot	2020-11-04 14:00:00	2020-11-04 15:00:00	\N	\N	3	0	\N	\N
501132	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Avis Transports M. Tabarot	PJLF 2021 Avis transports Auditions M. Tabarot	2020-11-04 18:00:00	2020-11-04 19:00:00	\N	\N	4	0	\N	\N
501139	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Avis Transports FFT M. Tabarot	PJLF 2021 Avis transports Auditions M. Tabarot	2020-11-05 09:00:00	2020-11-05 11:00:00	\N	\N	2	0	\N	\N
501144	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Avis Transports M. Tabarot	PJLF 2021 Avis transports Auditions M. Tabarot	2020-11-05 13:45:00	2020-11-05 15:15:00	\N	\N	2	0	\N	\N
501147	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Avis Transports M. Tabarot	PJLF 2021 Avis transports Auditions M. Tabarot	2020-11-09 14:00:00	2020-11-09 15:15:00	\N	\N	3	0	\N	\N
501273	DELEGATION	AUCUNE	\N	\N	211	Audition de M. Adrien Taquet, secrétaire d'État chargé de l'enfance et des familles	Audition de M. Adrien Taquet, secrétaire d'État chargé de l'enfance et des familles	2020-11-26 08:30:00	2020-11-26 10:00:00	2020-11-26 13:20:30	\N	22	0	\N	\N
501342	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2021-Mission Plan de relance-Région Île-de-France	PJLF 2021-Mission Plan de relance-Région Île-de-France	2020-11-09 10:00:00	2020-11-09 11:00:00	\N	\N	1	0	\N	\N
501385	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2021-Mission Plan de relance-Conseil départemental Essonne	PJLF 2021-Mission Plan de relance-Conseil départemental Essonne	2020-11-09 11:30:00	2020-11-09 12:30:00	\N	\N	1	0	\N	\N
501433	DELEGATION	AUDRAP	\N	\N	206	Audition Production d'hydrogène - Marc Fontecave	Audition Production d'hydrogène - Marc Fontecave	2020-11-12 16:00:00	2020-11-12 17:15:00	\N	\N	1	0	\N	\N
501437	DELEGATION	AUDRAP	\N	\N	206	Audition Production d'hydrogène - Philippe Haffner	Audition Production d'hydrogène - Philippe Haffner	2020-11-12 17:15:00	2020-11-12 18:15:00	\N	\N	1	0	\N	\N
501502	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Avis Cohésion des territoires - Logement - Fédération française du bâtiment	Avis Cohésion des territoires - Logement - Fédération française du bâtiment	2020-11-10 09:00:00	2020-11-10 09:30:00	\N	\N	1	0	\N	\N
501540	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2021 - Mission Solidarité	\N	2020-11-10 11:00:00	2020-11-10 11:45:00	\N	\N	1	0	\N	\N
501542	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Avis Transports M. Tabarot	PJLF 2021 Avis transports Auditions M. Tabarot	2020-11-10 13:30:00	2020-11-10 15:00:00	\N	\N	3	0	\N	\N
501543	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Avis Transports M. Tabarot	PJLF 2021 Avis transports Auditions M. Tabarot	2020-11-10 16:00:00	2020-11-10 17:30:00	\N	\N	2	0	\N	\N
501596	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	206	Réunion du Bureau	Réunion du Bureau	2020-11-12 10:05:00	2020-11-12 11:35:00	\N	\N	5	0	\N	\N
501761	DELEGATION	AUCUNE	\N	\N	COLTER	Table ronde associations d'élus	\N	2020-11-19 09:30:00	2020-11-19 11:30:00	\N	\N	26	0	\N	\N
501778	COM_PERMANENTE	AUTRE	\N	CAE	\N	\N	\N	2020-11-18 09:35:00	2020-11-18 11:25:00	2020-11-18 17:09:48	2020-11-19 17:37:20	43	0	\N	\N
501779	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-11-18 16:35:00	2020-11-18 18:35:00	2020-11-18 18:55:27	2020-11-19 17:37:21	40	0	\N	\N
501780	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-11-17 16:30:00	2020-11-17 19:10:00	2020-11-17 19:43:15	2020-11-18 16:05:57	42	0	\N	\N
501793	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Avis Recherche - IFPEN	Avis Recherche - IFPEN	2020-11-12 10:00:00	2020-11-12 11:00:00	\N	\N	1	0	\N	\N
501794	COM_PERMANENTE	AUDRAP	\N	CDD	\N	CGDD	\N	2020-11-12 11:00:00	2020-11-12 12:00:00	\N	\N	1	0	\N	\N
501815	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFR 2020	PLFR 2020	2020-11-16 16:00:00	2020-11-16 20:05:00	\N	\N	68	0	\N	\N
501816	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFR 2020	PLFR 2020	2020-11-16 21:35:00	2020-11-17 02:10:00	\N	\N	67	0	\N	\N
378657	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Ecole de la Confiance	PJL Ecole de la Confiance	2019-05-17 09:30:00	2019-05-17 13:00:00	\N	\N	47	0	\N	\N
378658	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Ecole de la Confiance	PJL Ecole de la Confiance	2019-05-17 14:30:00	2019-05-17 19:50:00	\N	\N	42	0	\N	\N
378659	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Ecole de la Confiance	PJL Ecole de la Confiance	2019-05-17 21:30:00	2019-05-18 00:00:00	\N	\N	0	0	\N	\N
384710	GIA	AUCUNE	\N	\N	\N	Petit déjeuner - Ambassadrice de Suisse	\N	2019-05-29 08:30:00	2019-05-29 09:30:00	\N	\N	10	0	610	\N
390980	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	Réunion plénière CATDD	2019-06-19 11:10:00	2019-06-19 12:45:00	\N	2019-06-24 09:59:40	41	1	\N	\N
390982	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Fraude aux fonds européens - ASP	Contrôle 2019 - Fraude aux fonds européens - ASP	2019-06-11 14:00:00	2019-06-11 15:00:00	\N	\N	1	0	\N	\N
390984	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Évaluation transformation ISF en IFI et création PFU - France Invest	Contrôle 2019 - Évaluation transformation ISF en IFI et création PFU - France Invest	2019-06-11 18:00:00	2019-06-11 19:00:00	\N	\N	2	0	\N	\N
390987	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Stade de France - Direction des sports	Contrôle 2019 - Stade de France - Direction des sports	2019-06-11 14:30:00	2019-06-11 15:30:00	\N	\N	1	0	\N	\N
390989	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Stade de France - FFT	Contrôle 2019 - Stade de France - FFT	2019-06-12 14:00:00	2019-06-12 14:45:00	\N	\N	1	0	\N	\N
402787	ETUDES	AUCUNE	\N	\N	\N	GEAC - Audition GIFAS	GEAC - Audition GIFAS	2019-07-18 08:30:00	2019-07-18 10:00:00	\N	\N	6	0	\N	933
405154	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Engagement et proximité	\N	2019-09-11 14:00:00	2019-09-11 15:30:00	\N	\N	4	0	\N	\N
405159	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Engagement et proximité	\N	2019-09-11 17:00:00	2019-09-11 18:30:00	\N	\N	4	0	\N	\N
405164	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Engagement et proximité	\N	2019-09-12 09:00:00	2019-09-12 10:00:00	\N	\N	2	0	\N	\N
405167	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Engagement et proximité	\N	2019-09-12 11:00:00	2019-09-12 12:00:00	\N	\N	0	0	\N	\N
410102	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-10-09 10:10:00	2019-10-09 12:45:00	2019-10-09 14:41:40	2019-10-09 17:38:43	37	0	\N	\N
410604	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Pastoralisme	GT Pastoralisme	2019-10-03 13:45:00	2019-10-03 15:00:00	\N	\N	7	0	\N	\N
418273	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2020 - Avis direction de l'action du Gouvernement	\N	2019-10-22 15:30:00	2019-10-22 16:30:00	\N	\N	1	0	\N	\N
436547	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 27 novembre 2019	\N	2019-11-27 13:40:00	2019-11-27 15:00:00	\N	\N	0	0	\N	\N
436625	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition M. Mandelli	\N	2019-12-03 15:20:00	2019-12-03 16:05:00	\N	\N	1	0	\N	\N
436808	DELEGATION	AUTRE	\N	\N	211	Résultats de l'enquête Virage Dom en Guadeloupe et en Martinique	\N	2019-12-12 09:30:00	2019-12-12 11:00:00	\N	\N	0	0	\N	\N
436811	DELEGATION	AUCUNE	\N	\N	211	Audition de Mme Brigitte Grésy	Audition de Mme Brigitte Grésy	2020-01-16 09:00:00	2020-01-16 10:45:00	2020-01-16 11:33:02	\N	11	0	\N	\N
444736	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition entreprises responsables et engagées	Audition entreprises responsables et engagées - Forum pour l'investissement responsable	2020-01-14 17:00:00	2020-01-14 18:00:00	\N	\N	2	0	\N	\N
445109	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Chantiers de l'Atlantique	Audition de représentants de l'Institut Montaigne	2020-01-07 16:15:00	2020-01-07 17:15:00	\N	\N	4	0	\N	\N
445988	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière - Auditions SDHI	Réunion plénière - Auditions SDHI	2020-01-23 09:40:00	2020-01-23 13:15:00	\N	\N	10	0	\N	\N
445989	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Sécurité sanitaire	\N	2020-01-22 09:00:00	2020-01-22 11:00:00	\N	\N	2	0	\N	\N
445992	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2020-01-23 10:00:00	2020-01-23 12:00:00	\N	\N	1	0	\N	\N
445994	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion 20200122a	\N	2020-01-22 11:00:00	2020-01-22 11:15:00	2020-01-22 14:16:53	2020-01-22 15:46:40	44	0	\N	\N
446001	DELEGATION	AUCUNE	\N	\N	211	Table ronde	\N	2020-02-06 08:30:00	2020-02-06 10:40:00	2020-02-06 11:27:52	\N	8	0	\N	\N
446002	DELEGATION	AUCUNE	\N	\N	211	Table ronde Pékin+25	Table ronde Pékin+25	2020-03-05 09:30:00	2020-03-05 12:00:00	2020-03-05 12:51:02	\N	7	0	\N	\N
448591	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Horaires d'ouverture des bibliothèques	Horaires d'ouverture des bibliothèques	2020-01-21 14:00:00	2020-01-21 16:00:00	\N	\N	2	0	\N	\N
448594	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Horaires d'ouverture des bibliothèques	Horaires d'ouverture des bibliothèques	2020-01-23 10:00:00	2020-01-23 12:00:00	\N	\N	2	0	\N	\N
503724	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Avis outre-mer - CDC	Avis outre-mer - CDC	2020-11-17 16:00:00	2020-11-17 17:00:00	\N	\N	1	0	\N	\N
410097	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-10-09 09:05:00	2019-10-09 10:10:00	2019-10-09 14:42:40	2019-10-09 17:38:39	44	0	\N	\N
445995	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Propagande électorale	\N	2020-01-22 11:15:00	2020-01-22 12:10:00	2020-01-22 14:17:07	2020-01-22 15:46:41	44	0	\N	\N
449046	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PPL Libre choix du consommateur dans le cyberespace	Auditions PPL Libre choix du consommateur dans le cyberespace	2020-01-28 14:45:00	2020-01-28 15:50:00	\N	\N	3	0	\N	\N
449077	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Déplacement en France (Evreux)	Déplacement à Evreux	2020-01-20 10:00:00	2020-01-20 17:00:00	\N	\N	1	0	\N	\N
449095	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Horaires d'ouverture des bibliothèques	Horaires d'ouverture des bibliothèques	2020-01-28 15:15:00	2020-01-28 16:15:00	\N	\N	2	0	\N	\N
450612	COM_PERMANENTE	AUTRE	\N	FINC	\N	Agence française de développement - Audition de M. Rémy RIOUX, directeur général	Agence française de développement - Audition de M. Rémy RIOUX, directeur général	2020-02-05 10:35:00	2020-02-05 12:15:00	2020-02-05 15:00:28	2020-02-05 17:12:57	29	0	\N	\N
450659	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition SILT	\N	2020-01-29 13:45:00	2020-01-29 14:35:00	\N	\N	1	0	\N	\N
450711	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Examen rapport d'information Obligation de signalement	Examen rapport d'information Obligation de signalement	2020-02-05 11:20:00	2020-02-05 12:20:00	2020-02-05 14:23:24	2020-02-05 17:12:55	48	1	\N	\N
450784	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Investissements d'avenir  - Pr MOUROU	PLF pour 2020 - Investissements d'avenir  - Pr MOUROU	2020-01-28 17:30:00	2020-01-28 18:30:00	\N	\N	1	0	\N	\N
450811	COM_ENQUETE	PLENIERE	\N	AUTOROUT	\N	Réunion constitutive de la Commission d'enquête sur les concessions autoroutières	Réunion constitutive de la Commission d'enquête sur les concessions autoroutières	2020-02-04 15:45:00	2020-02-04 16:15:00	2020-02-04 17:49:38	2020-02-05 17:12:28	17	0	\N	\N
450814	ETUDES	AUDRAP	\N	\N	\N	GEAC - Audition M. Thomas JUIN-UAF & FA	GEAC - Audition M. Thomas JUIN-UAF & FA	2020-01-30 08:30:00	2020-01-30 09:45:00	\N	\N	5	0	\N	933
450821	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 - L'enseignement supérieur artistique - Cour des comptes	58-2 - L'enseignement supérieur artistique - Cour des comptes	2020-01-28 16:30:00	2020-01-28 18:00:00	\N	\N	1	0	\N	\N
450837	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2020-02-05 09:33:00	2020-02-05 11:45:00	2020-02-05 11:59:37	2020-02-05 17:13:08	37	0	\N	\N
450887	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Production de l'énergie dans le secteur agricole (déplacement à Lyon)	Audition rapporteurs Production de l'énergie dans le secteur agricole (déplacement à Lyon)	2020-02-03 12:00:00	2020-02-03 13:55:00	\N	\N	2	0	\N	\N
450890	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Production de l'énergie dans le secteur agricole (déplacement à Lyon)	Audition rapporteurs Production de l'énergie dans le secteur agricole (déplacement à Lyon)	2020-02-03 14:00:00	2020-02-03 14:45:00	\N	\N	2	0	\N	\N
502291	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière - Table ronde hydrogène	Réunion plénière - Table ronde hydrogène	2020-11-18 17:00:00	2020-11-18 19:05:00	\N	\N	12	0	\N	\N
502845	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2021 - Mission RCT	PLF pour 2021 - Mission RCT	2020-11-10 14:00:00	2020-11-10 15:30:00	\N	\N	2	0	\N	\N
502848	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2021 - Mission RCT	PLF pour 2021 - Mission RCT	2020-11-10 16:30:00	2020-11-10 18:15:00	\N	\N	2	0	\N	\N
502851	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2021  - Mission RCT	PLF pour 2021  - Mission RCT	2020-11-12 09:00:00	2020-11-12 10:00:00	\N	\N	2	0	\N	\N
503259	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2021 - Programmes 844 et 847	\N	2020-11-12 17:00:00	2020-11-12 18:15:00	\N	\N	2	0	\N	\N
503264	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Explications de vote PLFSS 2021	Explications de vote PLFSS 2021	2020-11-17 14:30:00	2020-11-17 15:40:00	\N	\N	218	0	\N	\N
503484	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Direction de l'administration pénitentiaire	\N	2020-11-16 11:00:00	2020-11-16 12:45:00	\N	\N	2	0	\N	\N
503529	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2021 - Avis juridictions administratives et financières	PLF pour 2021 - Avis juridictions administratives et financières	2020-11-16 16:30:00	2020-11-16 17:40:00	\N	\N	1	0	\N	\N
503532	DELEGATION	AUDRAP	\N	\N	206	Audition Production d'hydrogène - IFPEN	Audition Production d'hydrogène - IFPEN	2020-11-19 15:15:00	2020-11-19 17:00:00	\N	\N	1	0	\N	\N
503538	DELEGATION	AUDRAP	\N	\N	206	Audition Production d'hydrogène - CEA	Audition Production d'hydrogène - CEA	2020-11-19 17:00:00	2020-11-19 18:45:00	\N	\N	1	0	\N	\N
503543	DELEGATION	AUDRAP	\N	\N	206	Audition Production d'hydrogène - France Hydrogène	Audition Production d'hydrogène - France Hydrogène	2020-11-20 15:00:00	2020-11-20 17:00:00	\N	\N	1	0	\N	\N
503555	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Création d'un pôle public du médicament et des produits médicaux	\N	2020-11-17 09:30:00	2020-11-17 10:30:00	\N	\N	1	0	\N	\N
503557	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI Restitution des oeuvres d'art	\N	2020-11-13 13:30:00	2020-11-13 14:10:00	\N	\N	6	0	\N	\N
503564	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL2021 Création	\N	2020-11-10 14:00:00	2020-11-10 15:00:00	\N	\N	4	0	\N	\N
503569	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL2021 Création	\N	2020-11-10 16:00:00	2020-11-10 17:00:00	\N	\N	5	0	\N	\N
503631	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2021 Création	\N	2020-11-06 09:00:00	2020-11-06 10:00:00	\N	\N	3	0	\N	\N
503647	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2021 Création	\N	2020-11-06 10:00:00	2020-11-06 11:00:00	\N	\N	4	0	\N	\N
503683	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2021 Création	\N	2020-11-05 14:30:00	2020-11-05 15:30:00	\N	\N	7	0	\N	\N
503700	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Avis outre-mer - Cabinet OM et DGOM	Avis outre-mer - Cabinet OM et DGOM	2020-11-16 11:00:00	2020-11-16 12:30:00	\N	\N	1	0	\N	\N
503702	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Avis outre-mer - Ladom	Avis outre-mer - Ladom	2020-11-16 12:30:00	2020-11-16 13:00:00	\N	\N	1	0	\N	\N
503704	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Avis outre-mer - USHOM	Avis outre-mer - USHOM	2020-11-16 14:00:00	2020-11-16 15:00:00	\N	\N	1	0	\N	\N
503707	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Avis outre-mer - Action logement	Avis outre-mer - Action logement	2020-11-16 16:00:00	2020-11-16 17:00:00	\N	\N	1	0	\N	\N
503710	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Avis outre-mer - USHOM	Avis outre-mer - USHOM	2020-11-16 17:00:00	2020-11-16 18:00:00	\N	\N	1	0	\N	\N
503712	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2021 Création	\N	2020-11-05 15:30:00	2020-11-05 16:15:00	\N	\N	4	0	\N	\N
450609	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen rapport et texte PPRE 273 - Saisine et nomination rapporteur PPL 179	Examen rapport et texte PPRE 273 - Saisine et nomination rapporteur PPL 179	2020-02-05 09:40:00	2020-02-05 10:35:00	2020-02-05 15:00:09	2020-02-05 17:13:07	43	0	\N	\N
450709	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Propagande electorale Examens amdts - Lutte contre la haine sur internet Nvlle lecture	Propagande electorale Examens amdts -Lutte contre la haine sur internet Nvlle lecture	2020-02-05 09:05:00	2020-02-05 09:50:00	2020-02-05 11:52:17	2020-02-05 17:13:10	40	1	\N	\N
503742	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Avis outre-mer - Fedom	Avis outre-mer - Fedom	2020-11-16 10:00:00	2020-11-16 11:00:00	\N	\N	1	0	\N	\N
503791	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2021 Cinéma	\N	2020-11-10 09:30:00	2020-11-10 10:30:00	\N	\N	1	0	\N	\N
503805	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2021 Cinéma	\N	2020-11-12 10:00:00	2020-11-12 11:00:00	\N	\N	2	0	\N	\N
503845	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 18 novembre - Audition de Mme Valérie Hayer, députée européenne	\N	2020-11-18 14:05:00	2020-11-18 15:00:00	2020-11-18 15:37:43	2020-11-19 17:36:30	24	0	\N	\N
503846	COM_EURO	AUTRE	\N	AFEU	\N	Audition de Mme Valérie Hayer, députée européenne	\N	2020-11-18 13:00:00	2020-11-18 14:00:00	\N	\N	0	0	\N	\N
504084	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2021 LIC	\N	2020-11-03 15:00:00	2020-11-03 16:00:00	\N	\N	1	0	\N	\N
504091	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2021 LIC	\N	2020-11-05 17:15:00	2020-11-05 18:15:00	\N	\N	1	0	\N	\N
504112	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2021 LIC	\N	2020-11-10 15:00:00	2020-11-10 16:00:00	\N	\N	2	0	\N	\N
504120	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2021 LIC	\N	2020-11-12 17:00:00	2020-11-12 18:00:00	\N	\N	2	0	\N	\N
504167	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2021 Patrimoines	\N	2020-11-03 14:30:00	2020-11-03 15:30:00	\N	\N	5	0	\N	\N
504173	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2021 Patrimoines	\N	2020-11-03 17:00:00	2020-11-03 18:00:00	\N	\N	2	0	\N	\N
504176	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2021 Patrimoines	\N	2020-11-03 18:00:00	2020-11-03 18:45:00	\N	\N	4	0	\N	\N
504207	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2021 Patrimoines	\N	2020-11-04 11:45:00	2020-11-04 12:35:00	\N	\N	2	0	\N	\N
504212	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2021 Patrimoines	\N	2020-11-04 14:00:00	2020-11-04 14:45:00	\N	\N	4	0	\N	\N
504222	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2021 Patrimoines	\N	2020-11-04 16:15:00	2020-11-04 17:00:00	\N	\N	2	0	\N	\N
504236	COM_EURO	AUDRAP	\N	AFEU	\N	Allégations nutritionnelles et allégations de santé	Allégations nutritionnelles et allégations de santé	2020-11-03 09:30:00	2020-11-03 10:50:00	\N	\N	1	0	\N	\N
504237	COM_EURO	AUDRAP	\N	AFEU	\N	Allégations nutritionnelles et allégations de santé	Allégations nutritionnelles et allégations de santé	2020-11-03 16:00:00	2020-11-03 16:50:00	\N	\N	1	0	\N	\N
504241	COM_EURO	AUDRAP	\N	AFEU	\N	Allégations nutritionnelles et allégations de santé	Allégations nutritionnelles et allégations de santé	2020-11-04 16:30:00	2020-11-04 17:30:00	\N	\N	1	0	\N	\N
504243	COM_EURO	AUDRAP	\N	AFEU	\N	Allégations nutritionnelles et allégations de santé	Allégations nutritionnelles et allégations de santé	2020-11-09 16:00:00	2020-11-09 17:00:00	\N	\N	1	0	\N	\N
504256	COM_EURO	AUDRAP	\N	AFEU	\N	Allégations nutritionnelles et allégations de santé	Allégations nutritionnelles et allégations de santé	2020-11-12 09:30:00	2020-11-12 10:50:00	\N	\N	1	0	\N	\N
504536	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Plf 2021 - Crédits de l'audiovisuel public	Audition DGMIC	2020-11-10 14:30:00	2020-11-10 15:30:00	\N	\N	1	0	\N	\N
504743	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2021 Enseignement supérieur	\N	2020-11-10 14:00:00	2020-11-10 14:50:00	\N	\N	1	0	\N	\N
504745	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2021 Enseignement supérieur	\N	2020-11-10 15:00:00	2020-11-10 16:00:00	\N	\N	1	0	\N	\N
504747	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2021 Enseignement supérieur	\N	2020-11-10 16:00:00	2020-11-10 16:50:00	\N	\N	1	0	\N	\N
504750	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	plf 2021	\N	2020-11-10 09:00:00	2020-11-10 10:10:00	\N	\N	1	0	\N	\N
504752	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Plf 2021	\N	2020-11-10 10:10:00	2020-11-10 11:00:00	\N	\N	1	0	\N	\N
504754	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2021 Enseignement supérieur	\N	2020-11-04 14:00:00	2020-11-04 15:00:00	\N	\N	4	0	\N	\N
504759	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	plf 2021	\N	2020-11-04 15:00:00	2020-11-04 15:50:00	\N	\N	3	0	\N	\N
504763	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	plf 2021 AEF	\N	2020-11-17 14:30:00	2020-11-17 16:20:00	\N	\N	4	0	\N	\N
504768	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	plf 2021	\N	2020-11-17 16:20:00	2020-11-17 17:00:00	\N	\N	3	0	\N	\N
504772	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	plf 2021 AEF	\N	2020-11-18 16:00:00	2020-11-18 17:00:00	\N	\N	4	0	\N	\N
504774	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	plf 2021 Recherche	\N	2020-11-12 08:50:00	2020-11-12 10:00:00	\N	\N	3	0	\N	\N
504778	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	plf 2021	\N	2020-11-12 10:00:00	2020-11-12 11:00:00	\N	\N	4	0	\N	\N
504783	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	plf 2021	\N	2020-11-12 11:00:00	2020-11-12 12:10:00	\N	\N	3	0	\N	\N
504787	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	plf 2021 Recherche	\N	2020-11-12 16:30:00	2020-11-12 17:50:00	\N	\N	1	0	\N	\N
504789	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	plf 2021	\N	2020-11-12 18:00:00	2020-11-12 19:00:00	\N	\N	4	0	\N	\N
504794	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	plf 2021	\N	2020-11-13 09:00:00	2020-11-13 11:40:00	\N	\N	3	0	\N	\N
377412	BUREAU	AUCUNE	\N	\N	\N	Délégation statut et conditions d'exercice du mandat de sénateur	Délégation statut et conditions d'exercice du mandat de sénateur	2019-05-14 15:00:00	2019-05-14 15:30:00	\N	\N	1	0	\N	\N
420310	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Lutte contre la haine sur internet	\N	2019-10-09 16:15:00	2019-10-09 19:15:00	\N	\N	1	0	\N	\N
420332	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Lutte contre la haine s	\N	2019-10-10 16:00:00	2019-10-10 17:00:00	\N	\N	1	0	\N	\N
441767	GIA	AUCUNE	\N	\N	\N	audience ambassadeur de Biélorussie	rencontre avec SE. M. Fissenko , ambassadeur de Biélorussie à Paris 	2019-12-18 10:00:00	2019-12-18 11:00:00	\N	\N	1	0	852	\N
449791	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Stratégie industrielle de l'Union européenne	Audition de Mme de Silva, présidente de l'Autorité de la concurrence	2020-01-28 14:30:00	2020-01-28 16:00:00	\N	\N	10	0	\N	\N
449968	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteur Phagothérapie	Audition rapporteur Phagothérapie	2020-02-04 16:30:00	2020-02-04 18:00:00	\N	\N	1	0	\N	\N
450008	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteur Phagothérapie (déplacement à Lyon)	Audition rapporteur Phagothérapie (déplacement à Lyon) Hôpital de la Croix Rousse	2020-02-03 08:30:00	2020-02-03 14:00:00	\N	\N	1	0	\N	\N
450065	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteur Phagothérapie (déplacement à Lyon)	Audition rapporteur Phagothérapie (déplacement à Lyon) Phages sans frontières	2020-02-03 14:15:00	2020-02-03 15:30:00	\N	\N	1	0	\N	\N
450626	GIA	AUCUNE	\N	\N	\N	Assemblée générale	Assemblée générale	2020-01-28 17:00:00	2020-01-28 17:45:00	\N	\N	6	0	963	\N
450723	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2020-02-05 09:45:00	2020-02-05 12:30:00	2020-02-05 18:16:44	2020-02-06 16:10:49	44	0	\N	\N
450728	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2020-02-05 16:28:00	2020-02-05 18:50:00	2020-02-06 10:04:48	2020-02-06 16:09:44	52	0	\N	\N
450886	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière	Audition publique sur les enjeux scientifiques et technologiques de la prévention et la gestion des risques accidentels 	2020-02-06 09:45:00	2020-02-06 13:10:00	\N	\N	4	0	\N	\N
450899	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Système universel de retraite	\N	2020-01-30 14:00:00	2020-01-30 16:30:00	\N	\N	3	0	\N	\N
450900	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Système universel de retraite	\N	2020-01-30 11:40:00	2020-01-30 12:55:00	\N	\N	5	0	\N	\N
450717	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2020-02-05 09:20:00	2020-02-05 09:45:00	2020-02-17 11:55:20	2020-02-17 11:55:53	42	1	\N	\N
450943	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-02-05 16:30:00	2020-02-05 18:50:00	2020-02-06 09:36:34	2020-02-06 16:09:42	51	0	\N	\N
450945	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	GT Laïcité	GT Laïcité	2020-01-29 14:00:00	2020-01-29 15:00:00	\N	\N	8	0	\N	\N
451946	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Système universel de retraite	\N	2020-02-04 15:45:00	2020-02-04 16:25:00	\N	\N	4	0	\N	\N
451951	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Système universel de retraite	\N	2020-02-04 16:25:00	2020-02-04 17:05:00	\N	\N	4	0	\N	\N
451956	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Système universel de retraite	\N	2020-02-04 17:05:00	2020-02-04 18:10:00	\N	\N	3	0	\N	\N
451960	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Système universel de retraite	\N	2020-02-04 18:10:00	2020-02-04 19:10:00	\N	\N	1	0	\N	\N
452544	COM_PERMANENTE	DEPLACEMENT	\N	CDD	\N	MI Gouvernance et performance des ports maritimes - Mme Filleul et M. Vaspart	MI Gouvernance et performance des ports maritimes - Mme Filleul et M. Vaspart	2020-01-23 10:30:00	2020-01-23 17:00:00	\N	\N	2	0	\N	\N
452562	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT 2019 Nouvelles formes de commerce	GT 2019 Nouvelles formes de commerce	2020-02-04 16:30:00	2020-02-04 17:15:00	\N	\N	2	0	\N	\N
452565	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT 2019 Nouvelles formes de commerce	GT 2019 Nouvelles formes de commerce	2020-02-04 17:15:00	2020-02-04 18:00:00	\N	\N	3	0	\N	\N
452569	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT 2019 Nouvelles formes de commerce	GT 2019 Nouvelles formes de commerce	2020-02-04 18:00:00	2020-02-04 18:45:00	\N	\N	2	0	\N	\N
453675	GIA	AUCUNE	\N	\N	\N	Déjeuner du GIA avec l'Ambassadeur d'Afrique du Sud	Déjeuner du groupe d'amitié avec S. E. M. Tebego SEOKOLO, ambassadeur d'Afrique du Sud en France	2020-02-05 12:35:00	2020-02-05 14:15:00	\N	\N	4	0	574	\N
453916	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	CDD	\N	Mission d'information sur l'empreinte environnementale du numérique	MI sur l'empreinte environnementale du numérique - Audition de représentants de EcoInfo	2020-02-05 14:00:00	2020-02-05 14:45:00	\N	\N	8	0	\N	\N
453926	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	CDD	\N	Mission d'information sur l'empreinte environnementale du numérique	MI sur l'empreinte environnementale du numérique - Audition de représentants de la Fondation internet nouvelle génératio	2020-02-05 16:30:00	2020-02-05 17:30:00	\N	\N	8	0	\N	\N
454138	COM_PERMANENTE	DEPLACEMENT	\N	CDD	\N	MI Gouvernance et performance des ports maritimes - Mme Filleul et M. Vaspart	MI Gouvernance et performance des ports maritimes - Mme Filleul et M. Vaspart	2020-02-06 10:40:00	2020-02-06 15:40:00	\N	\N	2	0	\N	\N
454141	COM_PERMANENTE	DEPLACEMENT	\N	CDD	\N	MI Gouvernance et performance des ports maritimes - Mme Filleul et M. Vaspart	MI Gouvernance et performance des ports maritimes - Mme Filleul et M. Vaspart	2020-02-07 10:00:00	2020-02-07 15:15:00	\N	\N	2	0	\N	\N
454169	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Parquet européen et justice 	\N	2020-02-11 10:00:00	2020-02-11 12:20:00	\N	\N	2	0	\N	\N
454171	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Parquet européen et justice pénale spécialisée	\N	2020-02-11 14:00:00	2020-02-11 18:30:00	\N	\N	1	0	\N	\N
454174	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Parquet eur	\N	2020-02-12 09:15:00	2020-02-12 12:30:00	\N	\N	1	0	\N	\N
454176	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Parquet européen et justice pénale spécialisée	\N	2020-02-12 14:00:00	2020-02-12 14:45:00	\N	\N	1	0	\N	\N
454256	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Parquet européen et justice pénale spécialisée	\N	2020-02-17 09:00:00	2020-02-17 10:00:00	\N	\N	1	0	\N	\N
454258	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion de la commission	Réunion de la commission	2020-02-19 09:05:00	2020-02-19 10:15:00	2020-02-19 14:31:47	2020-02-19 16:09:45	42	0	\N	\N
454259	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Examemen rapport  d'information délégation en Guyane	Examemen rapport  d'information délégation en Guyane	2020-02-19 12:10:00	2020-02-19 12:55:00	2020-02-19 14:32:26	2020-02-19 16:09:39	42	0	\N	\N
454867	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2020-02-19 09:36:00	2020-02-19 11:11:00	2020-02-19 14:05:43	2020-02-19 16:09:41	33	0	\N	\N
455076	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-02-19 10:00:00	2020-02-19 11:10:00	2020-02-19 17:14:11	2020-02-19 17:20:20	44	0	\N	\N
455105	COM_ENQUETE	PLENIERE	\N	RADICALI	\N	Table ronde des fédérations sportives nationales	Table ronde des fédérations sportives nationales	2020-02-25 15:05:00	2020-02-25 16:30:00	2020-02-26 09:02:23	2020-02-26 11:21:37	9	0	\N	\N
455106	COM_ENQUETE	PLENIERE	\N	RADICALI	\N	Audition commune des recteurs des académies d'Île-de-France	Audition commune des recteurs des académies d'Île-de-France	2020-02-26 16:30:00	2020-02-26 18:20:00	2020-02-26 18:51:39	2020-02-27 14:42:18	10	0	\N	\N
455304	COM_PERMANENTE	DEPLACEMENT	\N	CDD	\N	MI Gouvernance et performance des ports maritimes - Mme Filleul et M. Vaspart	MI Gouvernance et performance des ports maritimes - Mme Filleul et M. Vaspart	2020-02-17 10:45:00	2020-02-17 16:15:00	\N	\N	4	0	\N	\N
455379	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition MI Gouvernance des ports maritimes -Présidente Mme Filleul, Rapporteur M. Vaspart	Audition MI Gouvernance des ports maritimes -Présidente Mme Filleul, Rapporteur M. Vaspart	2020-02-18 08:30:00	2020-02-18 10:10:00	\N	\N	4	0	\N	\N
455384	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition MI Gouvernance des ports maritimes -Présidente Mme Filleul, Rapporteur M. Vaspart	Audition MI Gouvernance des ports maritimes -Présidente Mme Filleul, Rapporteur M. Vaspart	2020-02-18 14:30:00	2020-02-18 15:30:00	\N	\N	2	0	\N	\N
455397	COM_ENQUETE	PLENIERE	\N	LUBRIZOL	\N	Réunion de commission	Audition de M. Loïc Le Dréau, représetnant légal de FM Insurance Europe SA	2020-02-26 16:30:00	2020-02-26 17:00:00	2020-02-26 17:32:53	2020-02-27 14:42:17	9	0	\N	\N
501818	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Alimentation durable et locale	Débat sur l'alimentation durable et locale	2020-11-17 15:50:00	2020-11-17 17:50:00	\N	\N	82	0	\N	\N
501819	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	NL PJL DADDUE en matière économique et financière	NL PJL DADDUE en matière économique et financière	2020-11-17 21:30:00	2020-11-17 23:10:00	\N	\N	49	0	\N	\N
501820	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2020-11-18 15:00:00	2020-11-18 16:20:00	\N	\N	95	0	\N	\N
459628	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2019-11-28 09:30:00	2019-11-28 11:30:00	\N	\N	2	0	\N	\N
450942	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-02-05 09:30:00	2020-02-05 10:45:00	2020-02-05 11:03:41	2020-02-05 17:13:10	49	0	\N	\N
454260	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Parquet européen et justice pénale spécialisée - Examen rapport et texte commission	PJL Parquet européen et justice pénale spécialisée - Examen rapport et texte commission	2020-02-19 10:15:00	2020-02-19 12:00:00	2020-02-19 14:32:11	2020-02-19 16:09:39	42	0	\N	\N
501821	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Agence nationale de la cohésion des territoires	Débat portant sur l'Agence nationale de la cohésion des territoires, un an après sa création	2020-11-18 16:30:00	2020-11-18 18:05:00	\N	\N	59	0	\N	\N
501822	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat « La France champion de l'énergie hydrogène ? »	Débat :« La France peut-elle devenir un champion de l'énergie hydrogène ? »	2020-11-18 18:10:00	2020-11-18 19:45:00	\N	\N	53	0	\N	\N
501823	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Forêt française	Débat "La forêt française face aux défis climatiques, économiques et sociétaux"	2020-11-19 09:00:00	2020-11-19 10:45:00	\N	\N	43	0	\N	\N
501824	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat "Contenus haineux sur internet"	Débat " Contenus haineux sur internet : en ligne ou hors ligne, la loi doit être la même"	2020-11-19 10:55:00	2020-11-19 12:30:00	\N	\N	49	0	\N	\N
501825	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2021	PLF pour 2021	2020-11-19 14:30:00	2020-11-19 20:00:00	\N	\N	112	0	\N	\N
501827	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2021	PLF pour 2021	2020-11-20 16:00:00	2020-11-20 20:10:00	\N	\N	64	0	\N	\N
501828	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2021	PLF pour 2021	2020-11-20 21:40:00	2020-11-21 00:30:00	\N	\N	51	0	\N	\N
501829	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2021	PLF pour 2021	2020-11-21 09:30:00	2020-11-21 13:00:00	\N	\N	57	0	\N	\N
501830	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2021	PLF pour 2021	2020-11-21 14:30:00	2020-11-21 20:00:00	\N	\N	60	0	\N	\N
501831	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2021	PLF pour 2021	2020-11-21 21:35:00	2020-11-22 00:10:00	\N	\N	47	0	\N	\N
501835	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PJL Recherche et enseignement supérieur	CMP PJL Recherche et enseignement supérieur	2020-11-20 11:00:00	2020-11-20 12:30:00	\N	\N	29	0	\N	\N
501910	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2020-11-18 09:30:00	2020-11-18 12:40:00	2020-11-18 13:17:55	2020-11-18 16:06:53	41	0	\N	\N
501911	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de Mme Elisabeth Borne	\N	2020-11-18 16:30:00	2020-11-18 18:10:00	2020-11-18 18:09:04	2020-11-19 17:37:20	28	0	\N	\N
502267	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Table ronde - Le soutien aux entreprises françaises à l'étranger	\N	2020-11-19 09:30:00	2020-11-19 11:00:00	\N	\N	16	0	\N	\N
502288	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition d'Eric Dupond-Moretti, garde des sceaux, ministre de la justice	Audition d'Eric Dupond-Moretti, garde des sceaux, ministre de la justice	2020-11-17 17:45:00	2020-11-17 19:40:00	2020-11-17 19:48:57	2020-11-18 16:06:09	29	0	\N	\N
502289	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désignation de rapporteurs - Examen d'avis budgétaires - Création d'une mission d'info	Désignation de rapporteurs - Examen d'avis budgétaires - Création d'une mission d'info	2020-11-18 09:00:00	2020-11-18 11:25:00	\N	\N	37	0	\N	\N
502296	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2021 - Avis Protection judiciaire de la jeunesse	\N	2020-11-10 14:00:00	2020-11-10 15:00:00	\N	\N	1	0	\N	\N
502300	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2021 - Avis Protection judiciaire de la jeunesse	\N	2020-11-12 09:00:00	2020-11-12 11:15:00	\N	\N	1	0	\N	\N
502310	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2021	PLFSS 2021	2020-11-14 10:00:00	2020-11-14 13:05:00	\N	\N	44	0	\N	\N
502311	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2021	PLFSS 2021	2020-11-14 14:35:00	2020-11-14 19:20:00	\N	\N	42	0	\N	\N
502313	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2021	PLF pour 2021	2020-11-23 10:00:00	2020-11-23 13:05:00	\N	\N	52	0	\N	\N
502315	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2021	PLF pour 2021	2020-11-23 14:35:00	2020-11-23 20:00:00	\N	\N	68	0	\N	\N
502316	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2021	PLF pour 2021	2020-11-23 21:30:00	2020-11-24 00:35:00	\N	\N	75	0	\N	\N
502318	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2021	PLF pour 2021	2020-11-24 15:30:00	2020-11-24 19:45:00	\N	\N	164	0	\N	\N
502319	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2021	PLF pour 2021	2020-11-24 21:30:00	2020-11-25 00:40:00	\N	\N	120	0	\N	\N
502321	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2021	PLF pour 2021	2020-11-25 11:00:00	2020-11-25 13:10:00	\N	\N	85	0	\N	\N
502322	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR Haut-Karabagh	PPR 34-1 reconnaître la République du Haut-Karabagh	2020-11-25 16:30:00	2020-11-25 18:15:00	\N	\N	136	0	\N	\N
502323	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2021	PLF pour 2021	2020-11-25 18:20:00	2020-11-25 19:30:00	\N	\N	84	0	\N	\N
502324	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	 NL PLFSS 2021	NL PLFSS 2021	2020-11-26 10:30:00	2020-11-26 11:55:00	\N	\N	46	0	\N	\N
502325	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2021	PLF pour 2021	2020-11-26 14:30:00	2020-11-26 19:20:00	\N	\N	123	0	\N	\N
502326	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2021	PLF pour 2021	2020-11-26 21:05:00	2020-11-27 00:35:00	\N	\N	72	0	\N	\N
502327	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2021	PLF pour 2021	2020-11-27 09:35:00	2020-11-27 13:10:00	\N	\N	80	0	\N	\N
502328	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2021	PLF pour 2021	2020-11-27 14:45:00	2020-11-27 20:10:00	\N	\N	73	0	\N	\N
502329	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2021	PLF pour 2021	2020-11-27 21:40:00	2020-11-27 23:00:00	\N	\N	36	0	\N	\N
502330	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2021	PLF pour 2021	2020-11-28 09:30:00	2020-11-28 13:05:00	\N	\N	63	0	\N	\N
502331	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2021	PLF pour 2021	2020-11-28 14:35:00	2020-11-28 20:15:00	\N	\N	63	0	\N	\N
502332	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2021	PLF pour 2021	2020-11-28 21:45:00	2020-11-29 00:30:00	\N	\N	44	0	\N	\N
502333	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2021	PLF pour 2021	2020-11-29 09:30:00	2020-11-29 13:30:00	\N	\N	0	0	\N	\N
502334	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2021	PLF pour 2021	2020-11-29 14:30:00	2020-11-29 20:30:00	\N	\N	0	0	\N	\N
502335	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2021	PLF pour 2021	2020-11-29 21:30:00	2020-11-30 00:30:00	\N	\N	0	0	\N	\N
502336	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2021	PLF pour 2021	2020-11-30 10:00:00	2020-11-30 13:00:00	\N	\N	62	0	\N	\N
502337	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2021	PLF pour 2021	2020-11-30 14:30:00	2020-11-30 20:00:00	\N	\N	86	0	\N	\N
502338	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2021	PLF pour 2021	2020-11-30 21:30:00	2020-12-01 00:10:00	\N	\N	58	0	\N	\N
502340	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2020-11-25 15:00:00	2020-11-25 16:15:00	\N	\N	214	0	\N	\N
502352	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2021	PLF pour 2021	2020-12-04 11:00:00	2020-12-04 13:45:00	\N	\N	57	0	\N	\N
502354	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2021	PLF pour 2021	2020-12-04 15:15:00	2020-12-04 19:35:00	\N	\N	75	0	\N	\N
502355	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2021	PLF pour 2021	2020-12-04 21:05:00	2020-12-05 00:15:00	\N	\N	46	0	\N	\N
386734	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Energie - Auditions M. Gremillet	PJL Energie - Auditions M. Gremillet	2019-06-05 16:30:00	2019-06-05 19:30:00	\N	\N	1	0	\N	\N
391428	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition PME et Numérique	Audition PME et Numérique - ARCEP	2019-06-12 13:30:00	2019-06-12 14:45:00	\N	\N	1	0	\N	\N
392726	MISSION	AUCUNE	\N	SIDERURGIE	\N	Audition de dirigeants d'entreprises sidérurgiques de la "Metal'Valley"	\N	2019-06-19 14:00:00	2019-06-19 15:25:00	2019-06-20 10:11:54	2019-06-20 16:08:33	7	0	\N	\N
393383	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2019-07-02 09:30:00	2019-07-02 12:45:00	\N	\N	12	0	\N	\N
393390	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL JO 2024	PJL JO 2024	2019-07-02 14:30:00	2019-07-02 18:30:00	\N	\N	126	0	\N	\N
393392	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Interdiction des violences éducatives ordinaires	PPL Interdiction des violences éducatives ordinaires	2019-07-02 18:30:00	2019-07-02 19:50:00	\N	\N	46	0	\N	\N
393394	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Convention France-Allemagne	PJL Convention France-Allemagne	2019-07-03 14:30:00	2019-07-03 16:35:00	\N	\N	96	0	\N	\N
393396	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Agences et éditeurs de presse	PPL Agences et éditeurs de presse	2019-07-03 16:40:00	2019-07-03 19:00:00	\N	\N	65	0	\N	\N
397657	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-07-10 09:30:00	2019-07-10 11:50:00	2019-07-10 15:18:08	2019-07-11 11:26:40	37	1	\N	\N
397658	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-07-10 17:00:00	2019-07-10 18:35:00	2019-07-11 11:00:10	2019-07-11 11:26:34	29	0	\N	\N
397698	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 4 juillet 2019	Réunion de la commission des affaires européennes du 4 juillet 2019	2019-07-04 08:35:00	2019-07-04 09:35:00	2019-07-04 10:44:06	2019-07-04 16:30:37	9	0	\N	\N
409078	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	algorithmes locaux dans Parcoursup	algorithmes locaux dans Parcoursup	2019-10-01 15:00:00	2019-10-01 17:00:00	\N	\N	4	0	\N	\N
410833	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Service public de l'éducation et neutralité religieuse	PPL Service public de l'éducation et neutralité religieuse	2019-10-07 10:00:00	2019-10-07 11:00:00	\N	\N	1	0	\N	\N
418808	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Assurance maladie	\N	2019-10-22 15:30:00	2019-10-22 16:15:00	\N	\N	4	0	\N	\N
418813	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition assurance maladie	\N	2019-10-22 16:15:00	2019-10-22 17:00:00	\N	\N	3	0	\N	\N
418820	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Assurance maladie	\N	2019-10-22 18:00:00	2019-10-22 19:00:00	\N	\N	4	0	\N	\N
419010	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2020 - Mission Solidarité	\N	2019-10-22 14:00:00	2019-10-22 14:45:00	\N	\N	1	0	\N	\N
419123	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS Budget 2020 - Equilibres financiers généraux	\N	2019-10-22 17:00:00	2019-10-22 17:45:00	\N	\N	1	0	\N	\N
419131	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2020 - Missions Enseignement scolaire et Justice	PLF pour 2020 - Missions Enseignement scolaire et Justice	2019-10-29 15:10:00	2019-10-29 16:50:00	2019-10-29 17:17:21	2019-10-29 17:49:54	28	0	\N	\N
429055	GIA	AUCUNE	\N	\N	\N	Coopé - Visite d'une délégation de sénateurs cambodgiens	Coopé - Visite d'une délégation de sénateurs cambodgiens	2019-11-18 09:00:00	2019-11-18 19:00:00	\N	\N	1	0	577	\N
429066	GIA	AUCUNE	\N	\N	\N	Coopé - Visite d'une délégation de sénateurs cambodgiens	Coopé - Visite d'une délégation de sénateurs cambodgiens	2019-11-19 17:00:00	2019-11-19 17:30:00	\N	\N	1	0	577	\N
429068	GIA	AUCUNE	\N	\N	\N	Coopé - Visite d'une délégation de sénateurs cambodgiens	Coopé - Visite d'une délégation de sénateurs cambodgiens	2019-11-19 17:30:00	2019-11-19 18:00:00	\N	\N	1	0	577	\N
438244	COM_SPECIALE	AUDRAP	\N	BIOETHIQUE	\N	Audition rapporteur	\N	2019-12-10 16:00:00	2019-12-10 16:45:00	\N	\N	1	0	\N	\N
438246	COM_SPECIALE	AUDRAP	\N	BIOETHIQUE	\N	Audition rapporteur	\N	2019-12-10 16:45:00	2019-12-10 17:30:00	\N	\N	5	0	\N	\N
446026	GIA	AUCUNE	\N	\N	\N	réunion avec l'ambassadrice de Macédoine du Nord	réunion avec l'ambassadrice de Macédoine du Nord	2020-01-15 12:30:00	2020-01-15 14:30:00	\N	\N	8	0	674	\N
450893	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Production de l'énergie dans le secteur agricole	Audition rapporteurs Production de l'énergie dans le secteur agricole	2020-02-03 14:45:00	2020-02-03 16:15:00	\N	\N	2	0	\N	\N
450896	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution Plastique	Audition rapporteurs Pollution Plastique (FIEEC)	2020-02-04 14:00:00	2020-02-04 15:30:00	\N	\N	1	0	\N	\N
452214	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ambassadeur de Finlande, S. Exc. Teemu Tanner	Entretien avec l'ambassadeur de Finlande, S. Exc. Teemu Tanner	2020-02-05 08:30:00	2020-02-05 09:20:00	\N	\N	9	0	640	\N
452572	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Transparence	\N	2020-02-04 18:00:00	2020-02-04 19:30:00	\N	\N	2	0	\N	\N
453506	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition MI Travailleurs indépendants	\N	2020-02-05 13:45:00	2020-02-05 15:00:00	\N	\N	2	0	\N	\N
453854	COM_PERMANENTE	DEPLACEMENT	\N	CAE	\N	Mission "Chantiers de l'Atlantique"	Déplacement à Saint-Nazaire	2020-02-03 10:00:00	2020-02-03 16:45:00	\N	\N	5	0	\N	\N
454147	ETUDES	AUCUNE	\N	\N	\N	Déplacement Salon Wine Paris	Déplacement Salon Wine Paris	2020-02-11 10:00:00	2020-02-11 14:00:00	\N	\N	6	0	\N	909
503230	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Mission Plan de relance - Mme Chain-Larché	\N	2020-11-12 09:29:00	2020-11-12 13:00:00	\N	\N	1	0	\N	\N
396097	CMP	AUTRE	\N	GAFA	\N	PJL Création d'une taxe sur les services numériques	\N	2019-06-26 18:37:00	2019-06-26 19:16:00	\N	\N	7	0	\N	\N
454154	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution plastique (déplacement Le Mans)	Audition rapporteurs Pollution plastique (déplacement Le Mans) IMMM	2020-03-05 08:00:00	2020-03-05 09:50:00	\N	\N	2	0	\N	\N
454157	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution plastique (déplacement Le Mans)	Audition rapporteurs Pollution plastique (déplacement Le Mans) Ligepack	2020-03-05 10:00:00	2020-03-05 13:00:00	\N	\N	2	0	\N	\N
454160	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution plastique (déplacement Angers)	Audition rapporteurs Pollution plastique (déplacement Angers) Bouvard-INPA	2020-03-05 14:30:00	2020-03-05 16:15:00	\N	\N	2	0	\N	\N
454163	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution plastique (déplacement Angers)	Audition rapporteurs Pollution plastique (déplacement Angers) Global Recov	2020-03-05 16:30:00	2020-03-05 18:00:00	\N	\N	2	0	\N	\N
454166	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution Plastique (déplacement à Angers)	Audition rapporteurs Pollution Plastique (déplacement à Angers) ADEME	2020-03-06 08:45:00	2020-03-06 15:15:00	\N	\N	2	0	\N	\N
454187	COM_ENQUETE	PLENIERE	\N	RADICALI	\N	Audition plénière  (huis clos)	Audition plénière  (huis clos)	2020-02-20 10:35:00	2020-02-20 12:05:00	2020-02-20 14:21:34	2020-02-20 16:26:31	6	0	\N	\N
454188	COM_ENQUETE	PLENIERE	\N	RADICALI	\N	Audition plénière (huis clos)	Audition plénière (huis clos)	2020-02-18 14:30:00	2020-02-18 15:30:00	2020-02-18 15:42:30	2020-02-18 17:28:44	6	0	\N	\N
454190	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-02-20 10:30:00	2020-02-20 12:20:00	2020-02-20 15:02:02	2020-02-20 16:26:06	24	1	\N	\N
454193	COM_ENQUETE	AUTRE	\N	LUBRIZOL	\N	Réunion de commission	\N	2020-02-26 14:00:00	2020-02-26 15:00:00	2020-02-26 16:46:38	2020-02-26 17:29:50	9	0	\N	\N
454195	DELEGATION	AUCUNE	\N	\N	DSOM	Audition du conseil régional de la Guadeloupe	\N	2020-02-27 17:10:00	2020-02-27 18:30:00	\N	\N	4	0	\N	\N
454203	GIA	AUCUNE	\N	\N	\N	Coopé - Visite de M. Khalid SBIA, ex-député marocain	Coopé - Visite de M. Khalid SBIA, ex-député marocain	2020-02-12 11:30:00	2020-02-12 12:00:00	\N	\N	1	0	598	\N
503109	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2021 - Avis Justice judiciaire	PLF pour 2021 - Avis Justice judiciaire	2020-11-12 10:30:00	2020-11-12 12:00:00	\N	\N	3	0	\N	\N
503112	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2021 - Avis Justice judiciaire	PLF pour 2021 - Avis Justice judiciaire	2020-11-12 14:30:00	2020-11-12 16:30:00	\N	\N	2	0	\N	\N
503115	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2021 - Avis Justice judiciaire	PLF pour 2021 - Avis Justice judiciaire	2020-11-12 17:00:00	2020-11-12 18:00:00	\N	\N	3	0	\N	\N
503127	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - AGTE - SG-CIPDR	PLF pour 2021 - AGTE - SG-CIPDR	2020-11-09 10:30:00	2020-11-09 11:30:00	\N	\N	1	0	\N	\N
503129	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - AGTE - SG Min INT	PLF pour 2021 - AGTE - SG Min INT	2020-11-09 15:00:00	2020-11-09 16:30:00	\N	\N	1	0	\N	\N
503131	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Rapport général - CMA France	PLF pour 2021 - Rapport général - CMA France	2020-11-10 20:10:00	2020-11-10 20:30:00	\N	\N	1	0	\N	\N
503133	COM_PERMANENTE	AUTRE	\N	AFCL	\N	PLF 2021 avis audiovisuel et concours financier audiovisuel public	\N	2020-11-17 09:00:00	2020-11-17 10:30:00	2020-11-17 12:11:21	2020-11-17 14:40:14	25	0	\N	\N
503134	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Enseignement scolaire - Audition plénière	\N	2020-11-17 17:05:00	2020-11-17 19:50:00	2020-11-18 12:12:01	2020-11-18 16:06:00	33	0	\N	\N
503135	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Écologie - ART	PLF pour 2021 - Écologie - ART	2020-11-10 13:30:00	2020-11-10 14:30:00	\N	\N	2	0	\N	\N
503138	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Écologie - SNCF	PLF pour 2021 - Écologie - SNCF	2020-11-10 16:15:00	2020-11-10 17:30:00	\N	\N	2	0	\N	\N
503141	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Écologie - SGP	PLF pour 2021 - Écologie - SGP	2020-11-10 18:00:00	2020-11-10 19:00:00	\N	\N	2	0	\N	\N
503144	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Avis Transports M. Tabarot	PJLF 2021 Avis transports Auditions M. Tabarot	2020-11-12 16:00:00	2020-11-12 17:00:00	\N	\N	2	0	\N	\N
503147	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Rapport général - Air France KLM 	PLF pour 2021 - Rapport général - Air France KLM 	2020-11-10 19:15:00	2020-11-10 20:00:00	\N	\N	1	0	\N	\N
503149	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJLF 2021 - Avis Numérique - Fédération française des télécoms	PJLF 2021 - Avis Numérique - Fédération française des télécoms	2020-11-10 09:45:00	2020-11-10 10:30:00	\N	\N	1	0	\N	\N
503150	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJLF 2021 - Avis Numérique - Avicca	PJLF 2021 - Avis Numérique - Avicca	2020-11-10 14:00:00	2020-11-10 14:45:00	\N	\N	1	0	\N	\N
503151	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJLF 2021 - Avis Aménagement numérique du territoire - ANCT	PJLF 2021 - Avis Aménagement numérique du territoire - ANCT	2020-11-12 11:00:00	2020-11-12 11:45:00	\N	\N	1	0	\N	\N
503156	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJLF 2021 - Avis Cohésion des territoires - ANCT	PJLF 2021 - Avis Cohésion des territoires - ANCT	2020-11-10 14:30:00	2020-11-10 15:30:00	\N	\N	1	0	\N	\N
503157	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2020-11-17 09:01:00	2020-11-17 12:03:00	2020-11-17 17:04:52	2020-11-17 17:24:15	36	1	\N	\N
503158	COM_PERMANENTE	AUTRE	\N	CDD	\N	\N	\N	2020-11-18 09:31:00	2020-11-18 10:36:00	2020-11-18 11:10:38	2020-11-18 16:07:00	39	1	\N	\N
503159	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2020-11-17 17:30:00	2020-11-17 20:25:00	2020-11-18 10:28:54	2020-11-18 16:06:04	39	0	\N	\N
503161	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJLF 2021 - Avis transports routiers - Autorité de régulation des transports	PJLF 2021 - Avis transports routiers - Autorité de régulation des transports	2020-11-09 14:00:00	2020-11-09 15:15:00	\N	\N	1	0	\N	\N
503162	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJLF 2021 - Avis transports routiers - DGITM	PJLF 2021 - Avis transports routiers - DGITM	2020-11-10 16:00:00	2020-11-10 17:30:00	\N	\N	1	0	\N	\N
503163	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJLF 2021 - Avis transports routiers - AFITF	PJLF 2021 - Avis transports routiers - AFITF	2020-11-12 16:00:00	2020-11-12 17:00:00	\N	\N	1	0	\N	\N
503167	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJLF 2021 - Avis transports routiers - FUB	PJLF 2021 - Avis transports routiers - Fédération française des usagers de la bicyclette	2020-11-12 17:00:00	2020-11-12 18:00:00	\N	\N	1	0	\N	\N
503170	COM_PERMANENTE	AUTRE	\N	CDD	\N	\N	\N	2020-11-25 11:00:00	2020-11-25 12:27:00	2020-11-25 18:08:03	2020-11-25 18:43:20	26	1	\N	\N
503195	COM_EURO	AUDRAP	\N	AFEU	\N	PPRE Localisation des données - CEPD	PPRE Localisation des données - CEPD	2020-11-12 10:30:00	2020-11-12 12:30:00	\N	\N	2	0	\N	\N
503196	COM_EURO	AUDRAP	\N	AFEU	\N	PPRE Localisation des données - DG Connect	PPRE Localisation des données - DG Connect	2020-11-10 13:00:00	2020-11-10 14:00:00	\N	\N	2	0	\N	\N
503197	COM_EURO	AUDRAP	\N	AFEU	\N	PPRE Localisation des données - Syntec numérique	PPRE Localisation des données - Syntec numérique	2020-11-09 16:00:00	2020-11-09 18:00:00	\N	\N	2	0	\N	\N
503206	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2021 - Mission Économie-Numérique - La Poste	PJLF 2021 - Mission Économie-Numérique - La Poste	2020-11-12 11:00:00	2020-11-12 12:00:00	\N	\N	2	0	\N	\N
503231	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2021 - Mission Plan de relance - FFB / CAPEB	PJLF 2021 - Mission Plan de relance - FFB / CAPEB	2020-11-12 14:00:00	2020-11-12 15:00:00	\N	\N	1	0	\N	\N
503284	DELEGATION	AUDRAP	\N	\N	206	Audition Phagothérapie - G.C. Fanneau de La Horie	Audition Phagothérapie - G.C. Fanneau de La Horie	2020-11-17 16:30:00	2020-11-17 17:15:00	\N	\N	1	0	\N	\N
503286	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Avis agriculture - audition MM. Duplomb, Tissot et Mme Férat	\N	2020-11-12 09:30:00	2020-11-12 11:00:00	\N	\N	4	0	\N	\N
503291	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Avis Agriculture - audition MM.Duplomb, Tissot et Mme Férat	\N	2020-11-03 14:00:00	2020-11-03 14:45:00	\N	\N	3	0	\N	\N
503295	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Avis Agriculture - audition MM. Duplomb, Tissot et Mme Férat	\N	2020-11-03 18:00:00	2020-11-03 18:45:00	\N	\N	3	0	\N	\N
503301	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Avis agriculture - audition MM. Duplomb, Tissot et Mme Férat	\N	2020-11-05 08:30:00	2020-11-05 09:00:00	\N	\N	3	0	\N	\N
503305	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Avis agriculture - audition MM. Duplomb, Tissot et Mme Férat	\N	2020-11-10 14:00:00	2020-11-10 15:30:00	\N	\N	3	0	\N	\N
503315	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Réforme Action Logement -PEEC - directeur adjoint du cabinet du ministre de l'économie	Réforme Action Logement -PEEC - directeur adjoint du cabinet du ministre de l'économie	2020-11-16 10:30:00	2020-11-16 11:00:00	\N	\N	3	0	\N	\N
503492	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Déplacement au tribunal judiciaire de Paris	\N	2020-11-19 14:00:00	2020-11-19 18:15:00	\N	\N	5	0	\N	\N
503614	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2020-11-10 14:35:00	2020-11-10 15:55:00	\N	\N	3	0	\N	\N
504106	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Bienvenu Liyota Ndjoli, député de l'Assemblée nationale de RDC	Entretien avec M. Bienvenu Liyota Ndjoli, député de l'Assemblée nationale de RDC, ancien ministre de l'environnement	2020-11-17 14:00:00	2020-11-17 15:10:00	\N	\N	1	0	572	\N
504467	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2020-11-18 09:00:00	2020-11-18 11:55:00	2020-11-18 17:42:21	2020-11-19 17:34:06	39	0	\N	\N
504749	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière - Audition Académie nationale de médecine	Réunion plénière - Désignations rapporteurs - Audition Académie nationale de médecine	2020-11-19 09:40:00	2020-11-19 11:20:00	\N	\N	9	0	\N	\N
504955	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Auditions Christian Rodriguez, Olivier Brochet et examen 2 avis.	PLF 2021 - Auditions Christian Rodriguez, Olivier Brochet et examen avis.	2020-11-18 09:30:00	2020-11-18 13:05:00	2020-11-18 17:24:08	2020-11-19 17:37:23	39	0	\N	\N
505228	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Création d'un pôle public du médicament et des produits médicaux	\N	2020-11-17 17:00:00	2020-11-17 18:00:00	\N	\N	4	0	\N	\N
505239	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Création d'un pôle public du médicament et des produits médicaux	\N	2020-11-17 18:00:00	2020-11-17 19:00:00	\N	\N	7	0	\N	\N
505264	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Direction générale de la sécurité civile et de la gestion des crises	\N	2020-11-18 15:30:00	2020-11-18 16:35:00	\N	\N	1	0	\N	\N
505379	DELEGATION	AUDRAP	\N	\N	206	Audition Phagothérapie - Ministère des solidarités et de la santé	Audition Phagothérapie - Ministère des solidarités et de la santé	2020-11-20 10:30:00	2020-11-20 11:30:00	\N	\N	1	0	\N	\N
378924	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-05-21 18:10:00	2019-05-21 20:00:00	2019-05-22 14:55:16	2019-05-22 17:38:17	21	0	\N	\N
378929	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-05-22 09:30:00	2019-05-22 13:00:00	2019-05-22 15:36:46	2019-05-22 17:38:10	73	0	\N	\N
378930	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-05-22 16:40:00	2019-05-22 18:00:00	2019-05-23 10:24:38	2019-05-23 17:08:04	28	0	\N	\N
391481	MECSS	AUDRAP	\N	\N	MECSS	GT Réforme des retraites	\N	2019-07-10 11:30:00	2019-07-10 12:15:00	\N	\N	1	0	\N	\N
392615	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-06-26 09:35:00	2019-06-26 12:30:00	2019-06-26 12:53:08	2019-06-26 18:36:12	38	0	\N	\N
393384	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	« Conséquences économiques des gilets jaunes »	GT « Conséquences économiques des gilets jaunes » - Présentation des conclusions du rapport 	2019-06-20 13:45:00	2019-06-20 15:00:00	\N	\N	4	0	\N	\N
396852	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-07-02 17:35:00	2019-07-02 19:35:00	2019-07-02 19:55:59	2019-07-03 10:41:47	65	0	\N	\N
396936	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Création d'un droit voisin au profit des agences et éditeurs de presse	PPL Création d'un droit voisin au profit des agences et éditeurs de presse	2019-07-02 14:30:00	2019-07-02 15:15:00	\N	\N	2	0	\N	\N
396937	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Création d'un droit voisin au profit des agences et éditeurs de presse	PPL Création d'un droit voisin au profit des agences et éditeurs de presse	2019-07-02 15:15:00	2019-07-02 16:00:00	\N	\N	1	0	\N	\N
397181	COM_ENQUETE	PLENIERE	\N	SOUVERAINETE	\N	CE "Souverainement numérique"	CE "Souveraineté numérique"	2019-07-02 17:30:00	2019-07-02 18:30:00	2019-07-03 09:58:47	2019-07-03 15:57:38	3	0	\N	\N
404849	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Vie locale et action publique	\N	2019-09-03 16:00:00	2019-09-03 19:00:00	\N	\N	5	0	\N	\N
404855	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Vie locale et action publique	\N	2019-09-04 09:30:00	2019-09-04 12:00:00	\N	\N	3	0	\N	\N
404859	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Vie locale et action publique	\N	2019-09-04 14:00:00	2019-09-04 15:30:00	\N	\N	0	0	\N	\N
405347	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Nouveaux territoires de la culture	MI Nouveaux territoires de la culture	2019-09-18 10:30:00	2019-09-18 11:30:00	\N	\N	2	0	\N	\N
405350	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Nouveaux territoires de la culture	MI Nouveaux territoires de la culture	2019-09-18 11:30:00	2019-09-18 12:30:00	\N	\N	4	0	\N	\N
405355	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Nouveaux territoires de la culture	MI Nouveaux territoires de la culture	2019-09-18 14:30:00	2019-09-18 16:30:00	\N	\N	2	0	\N	\N
405358	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Nouveaux territoires de la culture	MI Nouveaux territoires de la culture	2019-09-18 16:30:00	2019-09-18 17:30:00	\N	\N	4	0	\N	\N
405363	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Nouveaux territoires de la culture	MI Nouveaux territoires de la culture	2019-09-18 17:30:00	2019-09-18 18:30:00	\N	\N	2	0	\N	\N
405411	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Nouveaux territoires de la culture	MI Nouveaux territoires de la culture	2019-09-17 17:00:00	2019-09-17 18:00:00	\N	\N	2	0	\N	\N
423928	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs PNGMDR	Audition rapporteurs PNGMDR	2019-11-21 09:30:00	2019-11-21 11:00:00	\N	\N	3	0	\N	\N
386130	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPR règlement NON LEC	\N	2019-06-05 11:45:00	2019-06-05 12:08:00	2019-06-05 16:44:56	2019-06-05 16:52:15	29	0	\N	\N
428176	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Avis Économie - Audition de M. Babary	PJLF 2020 - Avis Économie - Audition de M. Babary	2019-11-14 08:30:00	2019-11-14 09:30:00	\N	\N	1	0	\N	\N
428178	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Avis Économie - Audition de M. Babary	PJLF 2020 - Avis Économie - Audition de M. Babary	2019-11-14 10:00:00	2019-11-14 11:00:00	\N	\N	1	0	\N	\N
444530	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	Audition MI Gouvernance des ports maritimes	Audition MI Gouvernance des ports maritimes - Présidente Mme Filleul, Rapporteur M. Vaspart	2020-01-14 14:30:00	2020-01-14 17:00:00	\N	\N	3	0	\N	\N
449743	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 4 février 2020	\N	2020-02-04 16:35:00	2020-02-04 17:30:00	2020-02-04 19:23:44	2020-02-05 18:11:29	16	0	\N	\N
449749	COM_EURO	AUTRE	\N	AFEU	\N	Réunion conjointe affaires européennes, étrangères et économiques	\N	2020-02-05 16:30:00	2020-02-05 18:30:00	\N	\N	0	0	\N	\N
455746	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2020-02-26 09:40:00	2020-02-26 12:37:00	2020-02-26 15:15:53	2020-02-26 17:33:05	41	0	\N	\N
456226	COM_PERMANENTE	AUTRE	\N	FINC	\N	Controle CNCCC - Compte rendu conf Art 13 - Nomination Rapp. PJL 314 - Audition M. LAMBERT	Controle CNCCC - Compte rendu conf Art 13 - Nomination Rapp. PJL 314 - Audition M. LAMBERT DITP	2020-02-26 09:40:00	2020-02-26 12:30:00	2020-02-26 12:47:18	2020-02-26 17:33:08	32	0	\N	\N
456484	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI SCAF	\N	2020-02-19 16:30:00	2020-02-19 18:30:00	\N	\N	3	0	\N	\N
456491	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2020-02-26 09:50:00	2020-02-26 13:05:00	2020-02-26 15:04:52	2020-02-26 17:33:06	41	0	\N	\N
456492	DELEGATION	DEPLACEMENT	\N	\N	COLTER	Visite DGGN - Direction générale de la gendarmerie nationale (Issy-les-Moulineaux)	\N	2020-02-27 09:30:00	2020-02-27 12:30:00	\N	\N	10	0	\N	\N
456566	COM_EURO	AUTRE_NON_PLENIERE	\N	AFEU	\N	Délégation française  à l'APCE - Réunion plénière	APCE - Réunion sur l'évolution du fonctionnement et des méthodes de travail de l'APCE	2020-02-19 16:25:00	2020-02-19 17:05:00	\N	\N	5	0	\N	\N
456635	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI  Coopération France Russie	RI  Coopération France Russie	2020-02-19 17:00:00	2020-02-19 18:15:00	\N	\N	4	0	\N	\N
456642	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Français établis hors de France	PPL Français établis hors de France	2020-02-20 09:00:00	2020-02-20 10:45:00	\N	\N	1	0	\N	\N
456643	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Horaires d'ouverture des bibliothèques	Horaires d'ouverture des bibliothèques	2020-02-20 10:00:00	2020-02-20 12:00:00	\N	\N	2	0	\N	\N
456647	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Français établis hors de France	PPL Français établis hors de France	2020-02-20 11:30:00	2020-02-20 12:15:00	\N	\N	1	0	\N	\N
456661	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Français établis hors de France	PPL Français établis hors de France	2020-02-20 14:00:00	2020-02-20 17:50:00	\N	\N	1	0	\N	\N
456663	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Français établis hors de France	PPL Français établis hors de France	2020-02-21 09:30:00	2020-02-21 10:30:00	\N	\N	1	0	\N	\N
456667	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Réduire le coût du foncier	Auditions PPL Réduire le coût du foncier	2020-02-18 14:30:00	2020-02-18 16:00:00	\N	\N	2	0	\N	\N
456670	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Réduire le coût du foncier	Auditions PPL Réduire le coût du foncier	2020-02-19 16:45:00	2020-02-19 17:30:00	\N	\N	2	0	\N	\N
456673	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Réduire le coût du foncier	Auditions PPL Réduire le coût du foncier	2020-02-19 18:15:00	2020-02-19 19:00:00	\N	\N	1	0	\N	\N
456678	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Réduire le coût du foncier	Auditions PPL Réduire le coût du foncier	2020-02-20 09:15:00	2020-02-20 10:00:00	\N	\N	2	0	\N	\N
456707	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion 20200225	\N	2020-02-25 09:05:00	2020-02-25 10:20:00	2020-02-26 12:09:17	2020-02-26 17:30:30	20	0	\N	\N
456710	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Examen rapport information misssion SILT	Examen rapport information misssion SILT	2020-02-26 10:25:00	2020-02-26 12:00:00	2020-02-26 12:15:58	2020-02-26 17:33:04	39	0	\N	\N
502356	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2021	PLF pour 2021	2020-12-05 09:30:00	2020-12-05 13:10:00	\N	\N	76	0	\N	\N
502357	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2021	PLF pour 2021	2020-12-05 14:40:00	2020-12-05 20:00:00	\N	\N	61	0	\N	\N
502359	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2021	PLF pour 2021	2020-12-05 21:30:00	2020-12-05 23:50:00	\N	\N	39	0	\N	\N
502363	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2021	PLF pour 2021	2020-12-07 10:00:00	2020-12-07 13:00:00	\N	\N	44	0	\N	\N
502364	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2021	PLF pour 2021	2020-12-07 14:30:00	2020-12-07 20:00:00	\N	\N	65	0	\N	\N
502365	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2021	PLF pour 2021	2020-12-07 21:30:00	2020-12-07 23:50:00	\N	\N	53	0	\N	\N
502367	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2021	PLF pour 2021	2020-12-08 14:30:00	2020-12-08 15:45:00	\N	\N	214	0	\N	\N
502368	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Ports maritimes français	PPL Ports maritimes français	2020-12-08 16:00:00	2020-12-08 19:00:00	\N	\N	104	0	\N	\N
502369	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJLO PJL Délais d'organisation des élections	PJLO PJL Délais d'organisation des élections	2020-12-08 19:00:00	2020-12-08 20:35:00	\N	\N	55	0	\N	\N
502370	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2020-12-09 15:00:00	2020-12-09 16:20:00	\N	\N	214	0	\N	\N
502371	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Pôle public du médicament	PPL Pôle public du médicament	2020-12-09 16:30:00	2020-12-09 19:00:00	\N	\N	87	0	\N	\N
502372	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PL	\N	2020-11-03 10:00:00	2020-11-03 11:00:00	\N	\N	3	0	\N	\N
439635	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2020 - Examen rapport Nlle Lecture et PPL n° 154 - Nomination rapporteur	PLF pour 2020 - Examen rapport Nlle Lecture et PPL n° 154 - Nomination rapporteur	2019-12-18 11:00:00	2019-12-18 11:40:00	2019-12-18 12:40:42	2019-12-18 14:52:01	34	0	\N	\N
456490	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2020-02-26 09:35:00	2020-02-26 09:45:00	2020-02-26 15:02:22	2020-02-26 17:33:09	41	1	\N	\N
502374	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR Aménagement numérique des territoires	PPR Aménagement numérique des territoires	2020-12-09 19:00:00	2020-12-09 20:25:00	\N	\N	47	0	\N	\N
502377	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Offre de rachat entreprise	PPL Offre de rachat entreprise	2020-12-10 10:30:00	2020-12-10 12:10:00	\N	\N	68	0	\N	\N
502378	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Langues régionales	PPL Langues régionales	2020-12-10 12:10:00	2020-12-10 13:05:00	\N	\N	65	0	\N	\N
502379	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Action logement - PEEC - FO	Action logement - PEEC - FO	2020-11-10 15:00:00	2020-11-10 15:30:00	\N	\N	1	0	\N	\N
502380	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Action logement - PEEC - Mme Wargon	Action logement - PEEC - Mme Wargon	2020-11-10 15:30:00	2020-11-10 16:00:00	\N	\N	3	0	\N	\N
502381	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPLC Biens communs	PPLC Biens communs	2020-12-10 16:05:00	2020-12-10 17:55:00	\N	\N	63	0	\N	\N
502383	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF2021  Enseignement scolaire	\N	2020-10-29 15:00:00	2020-10-29 16:00:00	\N	\N	2	0	\N	\N
502386	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Contribution exceptionnelle sur assurances	PPL Contribution exceptionnelle sur assurances	2020-12-10 17:55:00	2020-12-10 19:35:00	\N	\N	39	0	\N	\N
502387	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Langues régionales	PPL Langues régionales	2020-12-10 14:35:00	2020-12-10 16:00:00	\N	\N	20	0	\N	\N
502391	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2021 - JVA	\N	2020-11-05 09:00:00	2020-11-05 10:00:00	\N	\N	3	0	\N	\N
502395	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2021 - JVA	\N	2020-11-05 10:00:00	2020-11-05 11:00:00	\N	\N	3	0	\N	\N
502396	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Réforme Action logement - Mme Cosse - USH	Réforme Action logement - Mme Cosse - USH	2020-11-12 10:30:00	2020-11-12 11:00:00	\N	\N	2	0	\N	\N
502400	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Réforme Action logement - M. Apparu	Réforme Action logement - M. Apparu	2020-11-12 11:00:00	2020-11-12 11:30:00	\N	\N	2	0	\N	\N
502403	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2021 - JVA	\N	2020-11-05 11:30:00	2020-11-05 12:30:00	\N	\N	4	0	\N	\N
502410	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2021 - JVA	\N	2020-11-06 09:00:00	2020-11-06 10:00:00	\N	\N	3	0	\N	\N
502415	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2021 - JVA	\N	2020-11-06 10:00:00	2020-11-06 11:00:00	\N	\N	2	0	\N	\N
502418	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2021 - JVA	\N	2020-11-06 11:30:00	2020-11-06 12:30:00	\N	\N	2	0	\N	\N
502421	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF2021  Enseignement scolaire	\N	2020-11-06 14:00:00	2020-11-06 14:45:00	\N	\N	5	0	\N	\N
502429	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF2021  Enseignement scolaire	\N	2020-11-06 15:00:00	2020-11-06 16:00:00	\N	\N	3	0	\N	\N
502433	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF2021  Enseignement scolaire	\N	2020-11-09 10:30:00	2020-11-09 11:30:00	\N	\N	4	0	\N	\N
502438	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF2021  Enseignement scolaire	\N	2020-11-09 11:30:00	2020-11-09 12:30:00	\N	\N	1	0	\N	\N
502440	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF2021  Enseignement scolaire	\N	2020-11-09 15:00:00	2020-11-09 16:00:00	\N	\N	1	0	\N	\N
502442	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF2021  Enseignement scolaire	\N	2020-11-12 09:30:00	2020-11-12 10:30:00	\N	\N	2	0	\N	\N
502446	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLFR pour 2020 (4) - Examen AMDTS séance - PLF pour 2021 : Mission AGTE	PLFR pour 2020 (4) - Examen AMDTS séance - PLF pour 2021 : Mission AGTE	2020-11-16 14:05:00	2020-11-16 15:40:00	2020-11-17 11:06:56	2020-11-17 11:07:59	31	0	\N	\N
502447	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2021 - Mission Participations financières de l'État	PLF pour 2021 - Mission Participations financières de l'État	2020-11-17 09:35:00	2020-11-17 10:30:00	2020-11-17 14:32:53	2020-11-17 14:40:15	21	0	\N	\N
502448	COM_PERMANENTE	AUTRE	\N	FINC	\N	Ddadue:Examen AMDTS séance-PLF2021:Missions Agriculture-Cohésion des territoires et MIRES	Ddadue:Examen AMDTS séance-PLF2021:Missions Agriculture-Cohésion des territoires et MIRES	2020-11-17 15:40:00	2020-11-17 18:50:00	2020-11-17 21:51:34	2020-11-18 16:05:39	31	0	\N	\N
502449	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2021 - Missions Plan de relance et Écologie	PLF pour 2021 - Missions Plan de relance et Écologie	2020-11-18 09:05:00	2020-11-18 12:35:00	2020-11-18 13:25:58	2020-11-18 16:06:47	41	0	\N	\N
502450	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2021 : Missions précédemment examinées et réservées - RCT et Défense	PLF pour 2021 : Missions précédemment examinées et réservées - RCT et Défense	2020-11-18 16:40:00	2020-11-18 18:35:00	2020-11-18 18:55:31	2020-11-19 17:37:21	35	0	\N	\N
502451	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2021 : Missions Culture-Médias-Examen définitif de l'équilibre et Désignations	PLF pour 2021 : Missions Culture-Médias-Examen définitif de l'équilibre et Désignations rapporteurs	2020-11-19 09:05:00	2020-11-19 11:50:00	2020-11-19 12:07:02	2020-11-19 17:37:22	32	0	\N	\N
502453	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2021 - AMDTS de séance sur la première partie	PLF pour 2021 - AMDTS de séance sur la première partie	2020-11-20 13:35:00	2020-11-20 15:45:00	2020-11-20 16:28:01	2020-11-20 18:12:16	33	0	\N	\N
502678	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 19 novembre 2020	\N	2020-11-19 08:00:00	2020-11-19 10:00:00	2020-11-19 10:03:25	2020-11-19 17:36:31	19	0	\N	\N
502679	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Supprimer la possibilité de rachat par le dirigeant après le dépôt de bilan	PPL Supprimer la possibilité de rachat par le dirigeant après le dépôt de bilan	2020-11-10 16:00:00	2020-11-10 16:45:00	\N	\N	2	0	\N	\N
502750	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2021 - Mission Sécurités	PLF pour 2021 - Mission Sécurités	2020-11-12 09:00:00	2020-11-12 11:00:00	\N	\N	2	0	\N	\N
502756	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2021 - Mission Sécurités	PLF pour 2021 - Mission Sécurités	2020-11-12 16:30:00	2020-11-12 17:20:00	\N	\N	2	0	\N	\N
502810	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Cohésion des territoires - Logement-Urbanisme - DHUP	PLF pour 2021 - Cohésion des territoires - Logement-Urbanisme - DHUP	2020-11-09 10:00:00	2020-11-09 11:45:00	\N	\N	1	0	\N	\N
502815	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Cohésion des territoires - Logement-Urbanisme - Fond.Abbé Pierre/FPI	PLF pour 2021 - Cohésion des territoires - Logement-Urbanisme - Fond.Abbé Pierre/FPI	2020-11-10 08:45:00	2020-11-10 10:55:00	\N	\N	1	0	\N	\N
502818	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Défense - SGA Min Arm	PLF pour 2021 - Défense - SGA Min Arm	2020-11-12 11:30:00	2020-11-12 13:00:00	\N	\N	1	0	\N	\N
393999	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2019-06-19 19:35:00	2019-06-19 20:15:00	\N	\N	22	0	\N	\N
400278	GIA	AUCUNE	\N	\N	\N	entretien avec l'ambassadeur d'Iran, S.E. Bahran Ghasemi	\N	2019-06-25 10:00:00	2019-06-25 11:30:00	\N	\N	1	0	627	\N
405369	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Convention Djibouti Prévôté	Convention Djibouti Prévôté	2019-09-18 14:30:00	2019-09-18 15:30:00	\N	\N	1	0	\N	\N
400507	DELEGATION	AUDRAP	\N	\N	206	Audition de Mme Martine Cador (CNRS) (Neurosciences)	Audition de Mme Martine Cador (CNRS) (Neurosciences)	2019-07-24 14:00:00	2019-07-24 15:00:00	\N	\N	1	0	\N	\N
400509	DELEGATION	AUDRAP	\N	\N	206	Audition Ministère de l'agriculture (Production énergie secteur agricole)	Audition de M. S. Réallon, sous-dir. au Ministère de l'agriculture (Production de l'énergie dans le secteur agricole)	2019-07-16 15:00:00	2019-07-16 16:15:00	\N	\N	1	0	\N	\N
400512	DELEGATION	AUDRAP	\N	\N	206	Audition FNSEA/APCA (Production énergie secteur agricole)	Audition FNSEA/APCA (Production de l'énergie dans le secteur agricole)	2019-07-16 16:15:00	2019-07-16 17:15:00	\N	\N	1	0	\N	\N
400513	DELEGATION	AUDRAP	\N	\N	206	Audition Coop de France (Production énergie secteur agricole)	Audition Coop de France (Production de l'énergie dans le secteur agricole)	2019-07-16 17:15:00	2019-07-16 18:15:00	\N	\N	1	0	\N	\N
400518	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Prestation de compensation du handicap	\N	2019-07-18 09:45:00	2019-07-18 18:15:00	\N	\N	1	0	\N	\N
400520	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Prestation de compensation du handicap	\N	2019-07-23 15:00:00	2019-07-23 16:30:00	\N	\N	1	0	\N	\N
400522	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Prestation de compensation du handicap	\N	2019-07-30 14:00:00	2019-07-30 15:30:00	\N	\N	1	0	\N	\N
405042	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Engagement et proximité	\N	2019-09-10 09:00:00	2019-09-10 12:00:00	\N	\N	5	0	\N	\N
405048	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Engagement et proximité	\N	2019-09-10 14:00:00	2019-09-10 18:00:00	\N	\N	6	0	\N	\N
405056	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Engagement et proximité	\N	2019-09-11 09:00:00	2019-09-11 11:00:00	\N	\N	3	0	\N	\N
428367	GIA	AUCUNE	\N	\N	\N	visite du Sénat et déjeuner avec les maires des communes du Maroc	\N	2019-11-18 11:30:00	2019-11-18 14:30:00	\N	\N	1	0	598	\N
428477	GIA	AUCUNE	\N	\N	\N	entretien avec l'ambassadeur de France en Serbie 	entretien avec l'ambassadeur de France en Serbie 	2019-11-18 11:30:00	2019-11-18 12:30:00	\N	\N	1	0	674	\N
430543	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	PLF pour 2020 - Avis Sécurités - Visite de l'Ecole de gendarmerie	PLF pour 2020 - Avis Sécurités - Visite de l'Ecole de gendarmerie	2019-11-12 07:00:00	2019-11-12 22:00:00	\N	\N	1	0	\N	\N
430545	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Déplacement en Guyane (Sécurité, immigration, organisation judiciaire et territoriale)	Déplacement en Guyane (Sécurité, immigration, organisation judiciaire et territoriale)	2019-11-04 08:00:00	2019-11-11 22:00:00	\N	\N	5	0	\N	\N
430647	DELEGATION	AUCUNE	\N	\N	211	Table ronde à l'occasion du "Grenelle des violences conjugales"	Table ronde à l'occasion du "Grenelle des violences conjugales"	2019-11-26 17:00:00	2019-11-26 19:40:00	2019-11-27 14:54:13	\N	11	0	\N	\N
430662	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Recherche - M. Moga	\N	2019-11-18 15:00:00	2019-11-18 19:30:00	\N	\N	1	0	\N	\N
430664	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Recherche - M. Moga	\N	2019-11-20 16:45:00	2019-11-20 17:30:00	\N	\N	1	0	\N	\N
430767	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion 20191126a	\N	2019-11-26 09:30:00	2019-11-26 11:30:00	\N	\N	1	0	\N	\N
430768	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PLF pour 2020 - Avis Justice - Audition Mme Nicole Belloubet	PLF pour 2020 - Avis Justice - Audition Mme Nicole Belloubet	2019-11-26 18:10:00	2019-11-26 19:50:00	2019-11-27 15:44:04	2019-11-27 15:53:38	18	0	\N	\N
430776	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PLF pour 2020 - Audition de Mme Gourault et de M. Lecornu	PLF pour 2020 - Audition de Mme Gourault et de M. Lecornu	2019-11-27 16:40:00	2019-11-27 18:30:00	2019-11-29 10:16:59	2019-11-29 10:49:58	18	0	\N	\N
430837	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-11-27 09:00:00	2019-11-27 12:17:00	\N	\N	0	0	\N	\N
430843	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-11-26 17:00:00	2019-11-26 18:40:00	2019-11-26 18:54:24	2019-11-27 15:06:03	30	0	\N	\N
430845	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-11-27 09:30:00	2019-11-27 11:30:00	\N	\N	0	0	\N	\N
431387	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE 71	\N	2019-11-25 10:05:00	2019-11-25 10:30:00	2019-11-25 21:48:08	2019-11-26 17:34:46	15	0	\N	\N
431452	DELEGATION	AUDRAP	\N	\N	206	Audition Production de l'énergie dans le secteur agricole	Audition Production de l'énergie dans le secteur agricole	2019-11-26 09:30:00	2019-11-26 11:45:00	\N	\N	2	0	\N	\N
431728	GIA	AUCUNE	\N	\N	\N	Rencontre avec le vice-ministre des affaires étrangères d'Irak	Rencontre entre le sénateur Bernard Cazeau et M. Abdolkarim Hashim, vice-ministre des affaires étrangères d'Irak	2019-11-26 16:30:00	2019-11-26 17:30:00	\N	\N	1	0	615	\N
433961	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL UE-Arménie	\N	2019-11-27 17:30:00	2019-11-27 18:30:00	\N	\N	2	0	\N	\N
433986	ETUDES	AUCUNE	\N	\N	\N	Audition FNCOFOR	Audition GE Forêt FNCOFOR	2019-11-27 08:00:00	2019-11-27 09:00:00	\N	\N	16	0	\N	948
434561	COM_SPECIALE	AUDRAP	\N	BIOETHIQUE	\N	Audition Mme Jourda Centres privés AMP art 1 et 2	\N	2019-11-28 09:00:00	2019-11-28 10:10:00	\N	\N	2	0	\N	\N
434564	COM_SPECIALE	AUDRAP	\N	BIOETHIQUE	\N	Audition M. Jomier Médecins, sages-femmes Art 20 et 21	\N	2019-11-28 14:00:00	2019-11-28 15:00:00	\N	\N	3	0	\N	\N
434570	COM_ENQUETE	PLENIERE	\N	RADICALI	\N	Auditions de M. Youssef Chiheb et de M. Pierre Vermeren	Auditions de M. Youssef Chiheb et de M. Pierre Vermeren	2019-12-03 17:00:00	2019-12-03 19:10:00	2019-12-03 19:35:57	2019-12-04 14:10:50	14	0	\N	\N
434571	COM_SPECIALE	AUDRAP	\N	BIOETHIQUE	\N	Audition M. Jomier et Mme Jourda Art 1, 2, 20 à 22 Sociétés savantes	\N	2019-11-28 15:00:00	2019-11-28 17:00:00	\N	\N	4	0	\N	\N
431070	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2020 - Avis Justice judiciaire	\N	2019-11-21 10:30:00	2019-11-21 12:10:00	\N	\N	2	0	\N	\N
430770	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Examens des rapports pour avis	Examen des rapports ppour avis	2019-11-27 08:30:00	2019-11-27 12:30:00	2019-11-27 12:49:38	2019-11-27 15:06:05	40	0	\N	\N
430836	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-11-27 09:05:00	2019-11-27 12:20:00	2019-11-27 12:24:55	2019-11-27 15:06:00	47	0	\N	\N
430844	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-11-27 09:30:00	2019-11-27 11:00:00	2019-11-29 10:06:04	2019-11-29 10:06:09	40	0	\N	\N
434580	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2020 - Examen Amdts séance sur les Missions 	PLF pour 2020 - Examen Amdts séance sur les Missions 	2019-12-02 09:00:00	2019-12-02 09:30:00	2019-12-02 12:06:41	2019-12-02 14:02:55	18	0	\N	\N
434667	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2020 - Examen Art non rattachés-Examen Amdts Missions Cohésion terr-Agriculture	PLF pour 2020 - Examen Art non rattachés-Examen Amdts Missions Cohésion terr-Agriculture	2019-12-03 09:10:00	2019-12-03 10:15:00	2019-12-03 11:13:50	2019-12-03 16:48:57	27	0	\N	\N
434671	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2020 - Examen Amdts séance sur les Missions 	PLF pour 2020 - Examen Amdts séance sur les Missions 	2019-12-05 09:35:00	2019-12-05 10:00:00	2019-12-05 10:25:27	2019-12-05 14:22:10	22	0	\N	\N
434672	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2020 - Examen Amendements de séance sur Articles non rattachés aux missions	PLF pour 2020 - Examen Amendements de séance sur Articles non rattachés aux missions	2019-12-05 19:55:00	2019-12-05 21:00:00	2019-12-06 17:18:34	2019-12-09 17:05:27	17	0	\N	\N
434673	GIA	AUCUNE	\N	\N	\N	Colloque du 70ème anniversaire du groupe France - Pays-Bas	Colloque du 70ème anniversaire du groupe France - Pays-Bas	2019-12-03 16:30:00	2019-12-03 21:30:00	\N	\N	5	0	599	\N
376744	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Synergies entre les conseils municipaux et communautaires	PPL Synergies entre les conseils municipaux et communautaires	2019-05-09 14:00:00	2019-05-09 14:25:00	2019-05-09 14:55:42	2019-05-09 17:08:23	0	0	\N	\N
393000	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Energie - Auditions M. Gremillet	\N	2019-06-19 14:00:00	2019-06-19 15:00:00	\N	\N	3	0	\N	\N
393563	COM_ENQUETE	PLENIERE	\N	SOUVERAINETE	\N	Audition de Cédric O	Audition de Cédric O	2019-06-20 13:50:00	2019-06-20 14:55:00	2019-06-20 16:41:22	2019-06-20 16:48:53	9	0	\N	\N
393574	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteur (Neurosciences) M. Jean-Luc Martinot, INSERM	Audition rapporteur (Neurosciences) M. Jean-Luc Martinot, INSERM	2019-07-09 15:00:00	2019-07-09 16:00:00	\N	\N	1	0	\N	\N
393575	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteur (Neurosciences) Mme Marie-Hélène Grosbras, Univ. Aix/Marseille/CNRS	Audition rapporteur (Neurosciences) Mme Marie-Hélène Grosbras, Univ. Aix/Marseille/CNRS	2019-07-03 15:00:00	2019-07-03 16:00:00	\N	\N	1	0	\N	\N
395156	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions MI responsabilité civile	\N	2019-06-25 14:15:00	2019-06-25 16:45:00	\N	\N	2	0	\N	\N
395159	COM_PERMANENTE	AUTRE	\N	SOCI	\N	réunion plénière - auditions	\N	2019-07-03 09:05:00	2019-07-03 12:00:00	2019-07-03 11:56:21	2019-07-03 15:56:32	30	0	\N	\N
395478	MISSION	AUCUNE	\N	SIDERURGIE	\N	Audition de Christel BORIES	\N	2019-06-25 14:00:00	2019-06-25 15:15:00	2019-06-27 10:01:49	2019-06-27 11:45:11	5	0	\N	\N
395479	MISSION	AUCUNE	\N	SIDERURGIE	\N	Audition de M. Philippe CROUZET	\N	2019-06-25 17:45:00	2019-06-25 19:15:00	2019-06-27 10:02:00	2019-06-27 11:45:12	8	0	\N	\N
395569	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2019 - Le Conseil supérieur de l'audiovisuel - Déplacement au CSA	Contrôle 2019 - Le Conseil supérieur de l'audiovisuel - Déplacement au CSA	2019-06-25 14:00:00	2019-06-25 17:00:00	\N	\N	1	0	\N	\N
395594	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Lutte contre les feux de forêt - ONF	Contrôle 2019 - Lutte contre les feux de forêt - ONF	2019-06-25 09:00:00	2019-06-25 10:15:00	\N	\N	1	0	\N	\N
395792	MISSION	AUCUNE	\N	TRANSPORTS	\N	MIGT - Table ronde internationale	\N	2019-06-25 14:10:00	2019-06-25 16:25:00	2019-06-26 18:36:42	2019-06-26 18:39:12	9	0	\N	\N
395794	MISSION	AUDRAP	\N	TRANSPORTS	\N	Audition rappoteur MI Gratuité transports	\N	2019-06-25 18:10:00	2019-06-25 19:10:00	\N	\N	3	0	\N	\N
395796	MISSION	AUCUNE	\N	TRANSPORTS	\N	MIGT - Réunion de cadrage rapport	\N	2019-06-26 17:10:00	2019-06-26 18:10:00	2019-06-26 18:44:32	2019-06-27 12:01:22	9	0	\N	\N
395797	MISSION	AUDRAP	\N	TRANSPORTS	\N	Audition rapporteur MI Gratuité transports	\N	2019-06-26 14:00:00	2019-06-26 17:00:00	\N	\N	3	0	\N	\N
397530	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Nouveaux territoires de l'éducation	\N	2019-07-03 14:00:00	2019-07-03 15:00:00	\N	\N	1	0	\N	\N
397581	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Nouveaux territoires de l'éducation	\N	2019-07-02 10:00:00	2019-07-02 11:00:00	\N	\N	2	0	\N	\N
397583	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Nouveaux territoires de l'éducation	\N	2019-07-03 17:00:00	2019-07-03 19:00:00	\N	\N	1	0	\N	\N
405429	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Évaluation transformation ISF en IFI et création PFU - IPP	Contrôle 2019 - Évaluation transformation ISF en IFI et création PFU - IPP	2019-09-18 14:30:00	2019-09-18 15:30:00	\N	\N	2	0	\N	\N
405432	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de M. Jean-Marie Bockel	Audition de M. Jean-Marie Bockel	2019-09-24 18:05:00	2019-09-24 19:30:00	2019-09-24 20:40:46	2019-09-25 15:38:52	10	0	\N	\N
421729	DELEGATION	AUCUNE	\N	\N	COLTER	Audition S. Bourron, nouveau DGCL	\N	2019-11-07 09:30:00	2019-11-07 11:00:00	2019-11-07 11:47:04	\N	9	0	\N	\N
426324	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJLF 2020-Auditions M. MANDELLI-M. CORBISEZ	\N	2019-11-12 16:30:00	2019-11-12 18:45:00	\N	\N	2	0	\N	\N
427428	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	\N	2019-11-14 10:30:00	2019-11-14 12:30:00	2019-11-14 12:03:33	2019-11-14 15:31:36	24	3	\N	\N
427446	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion pleinière CATDD	\N	2019-11-19 18:30:00	2019-11-19 20:43:00	2019-11-21 17:42:02	2019-11-21 17:46:16	32	0	\N	\N
427447	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-11-20 12:00:00	2019-11-20 12:40:00	\N	\N	0	0	\N	\N
445971	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Implantation des services de l'État dans les territoires - DITP	Contrôle 2019 - Implantation des services de l'État dans les territoires - DITP	2020-01-07 14:30:00	2020-01-07 15:30:00	\N	\N	1	0	\N	\N
445973	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Implantation des services de l'État dans les territoires - ANEM	Contrôle 2019 - Implantation des services de l'État dans les territoires - ANEM	2020-01-07 17:30:00	2020-01-07 18:30:00	\N	\N	1	0	\N	\N
445975	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Implantation des services de l'État dans les territoires - DMAT/INSEE/ANCT	Contrôle 2019 - Implantation des services de l'État dans les territoires - DMAT,DGPN et DGGN / INSEE / ANCT	2020-01-14 16:00:00	2020-01-14 19:00:00	\N	\N	1	0	\N	\N
454346	DELEGATION	AUCUNE	\N	\N	211	Audition d'économistes sur les retraites des femmes	Audition d'économistes sur les retraites des femmes	2020-02-25 17:00:00	2020-02-25 18:00:00	2020-02-25 18:44:54	\N	10	0	\N	\N
454411	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL congé pour le deuil d'un enfant - Mme Doineau/DGT	PPL congé pour le deuil d'un enfant - Mme Doineau/DGT	2020-02-17 14:00:00	2020-02-17 15:00:00	\N	\N	1	0	\N	\N
454509	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL congé pour le deuil d'un enfant - Mme Doineau/FO	PPL congé pour le deuil d'un enfant - Mme Doineau/FO	2020-02-17 15:00:00	2020-02-17 15:30:00	\N	\N	1	0	\N	\N
459633	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2019-12-04 17:00:00	2019-12-04 18:00:00	\N	\N	2	0	\N	\N
454510	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL congé pour le deuil d'un enfant - Mme Doineau/associations	PPL congé pour le deuil d'un enfant - Mme Doineau/associations	2020-02-17 16:30:00	2020-02-17 18:00:00	\N	\N	1	0	\N	\N
454530	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL congé pour le deuil d'un enfant - Mme Doineau/UNAF	PPL congé pour le deuil d'un enfant - Mme Doineau/UNAF	2020-02-18 10:00:00	2020-02-18 10:45:00	\N	\N	1	0	\N	\N
456273	COM_SPECIALE	AUDRAP	\N	ASAP	\N	Auditions CS ASAP	\N	2020-02-18 15:30:00	2020-02-18 16:30:00	\N	\N	14	0	\N	\N
470955	GIA	AUCUNE	\N	\N	\N	Visioconférence avec l'ambassade de France au Vanuatu 	Visioconférence avec l'ambassade de France au Vanuatu 	2020-05-15 09:00:00	2020-05-15 10:00:00	\N	\N	6	0	651	\N
470963	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition GT Agriculteurs en détresse	Audition GT Agriculteurs en détresse	2020-05-18 10:00:00	2020-05-18 11:00:00	\N	\N	8	0	\N	\N
471022	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - Centre de sociologie des organisations	Audition Pollution plastique - Centre de sociologie des organisations	2020-05-18 14:00:00	2020-05-18 15:30:00	\N	\N	2	0	\N	\N
471025	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - Queen's University, Canada	Audition Pollution plastique - Queen's University, Canada	2020-05-18 15:30:00	2020-05-18 17:30:00	\N	\N	2	0	\N	\N
471028	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - Université de Bordeaux	Audition Pollution plastique - Université de Bordeaux	2020-05-18 17:30:00	2020-05-18 19:05:00	\N	\N	1	0	\N	\N
476189	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLFR pour 2020 (3) - Audition de M. Pierre MOSCOVICI, PDT du HCFP	PLFR pour 2020 (3) - Audition de M. Pierre MOSCOVICI, Président du Haut Conseil des finances publiques	2020-06-10 16:40:00	2020-06-10 18:00:00	2020-06-10 19:09:28	2020-06-11 09:01:11	27	0	\N	\N
476190	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLFR pour 2020 (3) - Audition de MM. Bruno LE MAIRE et Olivier DUSSOPT	PLFR pour 2020 (3) - Audition de MM. Bruno LE MAIRE, ministre et Olivier DUSSOPT, secrétaire d¿État	2020-06-11 10:40:00	2020-06-11 12:40:00	2020-06-11 13:16:01	2020-06-11 14:30:39	30	0	\N	\N
476191	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFR pour 2020 (2) "MIRES et IA" - Suivi mesures crise covid-19 - INSERM	PLFR pour 2020 (2) "MIRES et IA" - Suivi mesures crise covid-19 - INSERM	2020-06-04 14:00:00	2020-06-04 15:00:00	\N	\N	2	0	\N	\N
476194	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFR pour 2020 (2) "Travail et emploi" - DG Travail 	PLFR pour 2020 (2) "Travail et emploi" - DG Travail	2020-06-04 16:00:00	2020-06-04 17:00:00	\N	\N	2	0	\N	\N
476197	DELEGATION	AUCUNE	\N	\N	DSOM	Table ronde sur le numérique	\N	2020-06-11 14:00:00	2020-06-11 16:30:00	\N	\N	7	0	\N	\N
445711	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Propagande électorale	\N	2020-01-15 11:30:00	2020-01-15 13:00:00	\N	\N	1	0	\N	\N
445713	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Propagande électorale	\N	2020-01-15 16:00:00	2020-01-15 17:00:00	\N	\N	1	0	\N	\N
445719	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Propagande électorale	\N	2020-01-16 09:00:00	2020-01-16 10:45:00	\N	\N	2	0	\N	\N
450932	DELEGATION	AUCUNE	\N	\N	206	Présentation du numéro de la revue du CNRS Histoire de la recherche contemporaine	Présentation du numéro de la revue du CNRS Histoire de la recherche contemporaine consacré à l'OPECST	2020-02-04 18:10:00	2020-02-04 20:10:00	\N	\N	6	0	\N	\N
457216	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Système universel de retraite	\N	2020-02-25 15:00:00	2020-02-25 15:45:00	\N	\N	3	0	\N	\N
457762	ETUDES	AUCUNE	\N	\N	\N	Audition FNTF	Audition FNTF	2020-02-26 08:00:00	2020-02-26 09:00:00	\N	\N	19	0	\N	907
458654	COM_PERMANENTE	AUTRE	\N	FINC	\N	Communication OEP - Nomination PPL 339 et Audition Rémy WEBER de La Banque Postale	Communication OEP - Nomination PPL 339 et Audition Rémy WEBER de La Banque Postale	2020-03-04 10:00:00	2020-03-04 12:00:00	2020-03-04 12:21:27	2020-03-04 16:20:01	42	0	\N	\N
458655	COM_PERMANENTE	AUTRE	\N	FINC	\N	58-2 2019 - Arrêt et démantèlement des installations nucléaires civiles	58-2 2019 - Arrêt et démantèlement des installations nucléaires civiles	2020-03-04 16:35:00	2020-03-04 18:00:00	2020-03-05 14:56:52	2020-03-05 15:34:36	14	0	\N	\N
458656	COM_ENQUETE	PLENIERE	\N	AUTOROUT	\N	Audition de l'Autorité de régulation des transports	Audition de l'Autorité de régulation des transports	2020-03-04 16:40:00	2020-03-04 18:25:00	2020-03-04 18:25:34	2020-03-05 15:38:33	13	0	\N	\N
458679	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Réduire le coût du foncier	\N	2020-02-25 14:30:00	2020-02-25 19:30:00	\N	\N	2	0	\N	\N
458682	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Réduire le coût du foncier	\N	2020-02-26 10:30:00	2020-02-26 11:00:00	\N	\N	1	0	\N	\N
458684	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Réduire le coût du foncier	\N	2020-02-26 11:00:00	2020-02-26 12:30:00	\N	\N	2	0	\N	\N
458687	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Réduire le coût du foncier	\N	2020-02-26 16:30:00	2020-02-26 18:00:00	\N	\N	2	0	\N	\N
458695	COM_PERMANENTE	AUTRE	\N	CDD	\N	Mission d'information sur l'empreinte environnementale du numérique	Audition de représentants d'Ubisoft	2020-02-26 16:30:00	2020-02-26 17:15:00	\N	\N	5	0	\N	\N
458701	COM_PERMANENTE	AUTRE	\N	CDD	\N	Mission d'information sur l'empreinte environnementale du numérique	Audition de représentants d'Ecosystem	2020-02-26 17:30:00	2020-02-26 18:15:00	\N	\N	6	0	\N	\N
458708	COM_PERMANENTE	AUTRE	\N	CDD	\N	Mission d'information sur l'empreinte environnementale du numérique	Audition de représentants de l'Arcep	2020-02-26 18:15:00	2020-02-26 19:00:00	\N	\N	6	0	\N	\N
458727	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Système universel de retraite	\N	2020-02-26 16:30:00	2020-02-26 17:30:00	\N	\N	1	0	\N	\N
458729	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT infrastructures de transport - Septième chambre Cour des comptes	GT infrastructures de transport - Septième chambre Cour des comptes	2020-02-26 16:30:00	2020-02-26 17:30:00	\N	\N	10	0	\N	\N
458753	COM_EURO	AUDRAP	\N	AFEU	\N	Audition à Strasbourg - Adhésion de l'UE à la CEDH	\N	2020-02-10 10:45:00	2020-02-10 11:40:00	\N	\N	2	0	\N	\N
458754	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Strasbourg - Adhésion de l'UE à la CEDH	\N	2020-02-10 11:45:00	2020-02-10 12:45:00	\N	\N	2	0	\N	\N
458755	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Strasbourg - Adhésion de l'UE à la CEDH	\N	2020-02-10 14:30:00	2020-02-10 15:15:00	\N	\N	2	0	\N	\N
458763	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition MI Gouvernance des ports maritimes -Présidente Mme Filleul, Rapporteur M. Vaspart	Audition MI Gouvernance des ports maritimes -Présidente Mme Filleul, Rapporteur M. Vaspart	2020-02-26 17:00:00	2020-02-26 18:15:00	\N	\N	4	0	\N	\N
458773	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition MI Gouvernance des ports maritimes -Présidente Mme Filleul, Rapporteur M. Vaspart	Audition MI Gouvernance des ports maritimes -Présidente Mme Filleul, Rapporteur M. Vaspart	2020-02-26 18:15:00	2020-02-26 19:30:00	\N	\N	2	0	\N	\N
458653	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen rapport pour avis PPL n° 179 Français établis hors de France	Examen rapport pour avis PPL n° 179 Français établis hors de France	2020-03-04 09:10:00	2020-03-04 10:00:00	2020-03-04 12:29:14	2020-03-04 16:20:05	43	0	\N	\N
459176	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GS lutte contre la fraude et l'évasion fiscales - 2020 - DGFiP	GS lutte contre la fraude et l'évasion fiscales - 2020 - DGFiP	2020-02-28 15:00:00	2020-02-28 19:00:00	\N	\N	2	0	\N	\N
460139	COM_EURO	CONTROLE	\N	AFEU	\N	Audition PAC	Audition PAC	2020-03-03 09:30:00	2020-03-03 11:00:00	2020-03-03 17:57:02	\N	2	0	\N	\N
462399	GIA	AUCUNE	\N	\N	\N	entretien avec Cheikh Mohamed Bin Abdulrahman Al-Thani, Vice PM du Qatar	\N	2020-03-05 12:00:00	2020-03-05 13:00:00	\N	\N	3	0	661	\N
462415	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Système universel de retraite	\N	2020-03-04 17:15:00	2020-03-04 18:00:00	\N	\N	2	0	\N	\N
462418	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Système universel de retraite	\N	2020-03-04 18:00:00	2020-03-04 19:10:00	\N	\N	3	0	\N	\N
462694	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2020-03-19 14:56:00	2020-03-19 15:45:00	\N	\N	76	0	\N	\N
462695	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL PJLO Urgence Covid 19	PJL PJLO Urgence Covid 19	2020-03-19 17:51:00	2020-03-19 20:00:00	\N	\N	72	0	\N	\N
462696	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL PJLO Urgence Covid 19	PJL PJLO Urgence Covid 19	2020-03-19 21:33:00	2020-03-20 04:12:00	\N	\N	53	0	\N	\N
463727	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Jean-Claude Lumaret, directeur général de Carbios	\N	2020-04-06 10:00:00	2020-04-06 11:30:00	\N	\N	2	0	\N	\N
463729	DELEGATION	AUDRAP	\N	\N	206	Audition de Mme Nadia Auclair, présidente de Carbiolice	\N	2020-04-06 16:00:00	2020-04-06 17:00:00	\N	\N	2	0	\N	\N
463734	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLFR pour 2020 - Échange de vues par visioconférence sur la mise en oeuvre des mesures	PLFR pour 2020 - Échange de vues par visioconférence sur la mise en oeuvre des mesures face à la crise du covid-19	2020-04-08 09:35:00	2020-04-08 11:40:00	\N	\N	38	0	\N	\N
463755	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-04-07 19:00:00	2020-04-07 21:00:00	\N	\N	35	0	\N	\N
466811	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi Covid-19 - Juridictions judiciaires et administratives	Audition du tribunal judiciaire de Nanterre	2020-04-27 14:00:00	2020-04-27 15:15:00	\N	\N	4	0	\N	\N
466816	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Groupe de travail Décentralisation	Audition de l'AMRF	2020-04-27 11:00:00	2020-04-27 12:00:00	\N	\N	4	0	\N	\N
466821	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Groupe de travail Décentralisation	Audition de l'AMF et de l'ADF	2020-04-27 15:00:00	2020-04-27 17:00:00	\N	\N	4	0	\N	\N
466826	DELEGATION	AUCUNE	\N	\N	211	Audition de Maître Isabelle Steyer	\N	2020-05-04 11:00:00	2020-05-04 12:55:00	2020-05-04 14:55:22	\N	9	0	\N	\N
466827	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi urgence Covid-19 - Forces de sécurité intérieure	Audition DGGN	2020-04-24 10:00:00	2020-04-24 11:00:00	\N	\N	4	0	\N	\N
385939	DELEGATION	AUCUNE	\N	\N	211	Examen d'un rapport d'information - Coupe de monde féminine de football	Examen d'un rapport d'information - Coupe de monde féminine de football	2019-06-06 08:30:00	2019-06-06 10:30:00	2019-06-06 08:13:58	\N	7	0	\N	\N
385941	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT États généraux de l'alimentation	GT États généraux de l'alimentation	2019-06-04 14:00:00	2019-06-04 14:45:00	\N	\N	4	0	\N	\N
385954	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT États généraux de l'alimentation	GT États généraux de l'alimentation	2019-06-04 14:45:00	2019-06-04 16:00:00	\N	\N	4	0	\N	\N
386194	ETUDES	AUCUNE	\N	\N	\N	Audition d'AgroParisTech	Audition d'AgroParisTech	2019-06-05 08:00:00	2019-06-05 09:30:00	\N	\N	21	0	\N	919
387551	MISSION	AUDRAP	\N	AERIEN	\N	transports aériens	\N	2019-06-04 09:00:00	2019-06-04 10:00:00	\N	\N	5	0	\N	\N
387560	MISSION	AUDRAP	\N	AERIEN	\N	\N	\N	2019-06-04 10:00:00	2019-06-04 11:00:00	\N	\N	3	0	\N	\N
387566	MISSION	AUDRAP	\N	AERIEN	\N	\N	\N	2019-06-05 16:30:00	2019-06-05 17:45:00	\N	\N	10	0	\N	\N
391707	COM_EURO	AUTRE	\N	AFEU	\N	Audition plénière - Auditions de la commission des affaires européennes	Audition de M. Jean Arthuis (Erasmus des apprentis)	2019-06-27 09:10:00	2019-06-27 10:30:00	2019-06-27 10:56:35	2019-06-27 11:44:25	7	0	\N	\N
391709	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Création du Centre national de la musique	PPL Création du Centre national de la musique	2019-06-18 09:15:00	2019-06-18 11:00:00	\N	\N	2	0	\N	\N
391710	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Création du Centre national de la musique	PPL Création du Centre national de la musique	2019-06-18 14:30:00	2019-06-18 17:00:00	\N	\N	3	0	\N	\N
397287	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 11 juillet 2019	Réunion du jeudi 11 juillet 2019	2019-07-11 08:40:00	2019-07-11 11:10:00	2019-07-11 15:59:04	2019-07-11 17:44:31	16	0	\N	\N
397297	MISSION	AUCUNE	\N	CLIMATIQUE	\N	Examen et adoption du rapport d'information	Examen et adoption du rapport d'information	2019-07-03 14:03:00	2019-07-03 15:47:00	2019-07-03 20:00:38	2019-07-04 16:31:02	17	0	\N	\N
401159	GIA	AUCUNE	\N	\N	\N	Entretien avec Mme Marie-Christine BUTEL, future ambassadrice de France au Kosovo	Entretien avec Mme Marie-Christine BUTEL, future ambassadrice de France au Kosovo	2019-06-26 17:00:00	2019-06-26 18:00:00	\N	\N	1	0	674	\N
401161	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion conjointe avec le groupe interparlementaire d'amitié France-Royaume-Uni	Réunion conjointe de la Délégation aux entreprises et du groupe interparlementaire d'amitié France-Royaume-Uni	2019-07-16 14:45:00	2019-07-16 16:15:00	2019-07-16 16:47:28	\N	11	0	\N	\N
405324	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT Stratégie industrielle de l'UE	Audition 	2019-09-18 10:00:00	2019-09-18 11:00:00	\N	\N	2	0	\N	\N
405366	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2020 - Programme 129	PLF pour 2020 - Programme 129	2019-09-17 18:30:00	2019-09-17 20:15:00	\N	\N	2	0	\N	\N
385866	CMP	AUTRE	\N	NOTREDAME	\N	PJL Restauration et conservation de Notre-Dame de Paris	PJL Restauration et conservation de Notre-Dame de Paris	2019-06-04 17:00:00	2019-06-04 17:45:00	\N	\N	13	0	\N	\N
400889	CMP	AUTRE	\N	COMPTES2018	\N	PJLG Règlement du budget et approbation des comptes de l'année 2018	PJLG Règlement du budget et approbation des comptes de l'année 2018	2019-07-16 14:17:00	2019-07-16 14:24:00	\N	\N	9	0	\N	\N
445952	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Tourisme - audition Alliance France tourisme 	GT Tourisme - audition Alliance France tourisme 	2020-01-15 16:15:00	2020-01-15 17:15:00	\N	\N	3	0	\N	\N
459021	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GS stratégie industrielle de l'UE	GS stratégie industrielle de l'UE	2020-01-14 12:30:00	2020-01-14 13:45:00	\N	\N	1	0	\N	\N
459023	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GS stratégie industrielle de l'UE	GS stratégie industrielle de l'UE	2020-01-14 15:15:00	2020-01-14 16:30:00	\N	\N	1	0	\N	\N
459025	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GS stratégie industrielle de l'UE	GS stratégie industrielle de l'UE	2020-01-14 16:30:00	2020-01-14 17:30:00	\N	\N	1	0	\N	\N
462278	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL n° 368 - Système universel de retraite - ERAFP / DB	PJL n° 368 - Système universel de retraite - ERAFP / DB	2020-03-04 17:15:00	2020-03-04 19:15:00	\N	\N	1	0	\N	\N
462389	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2020 - L'IHEDN et L'INHESJ - SGDSN	Contrôle 2020 - L'IHEDN et L'INHESJ - SGDSN	2020-03-05 12:30:00	2020-03-05 14:30:00	\N	\N	1	0	\N	\N
462396	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL n° 368 - Système universel de retraite - DG Trésor	PJL n° 368 - Système universel de retraite - DG Trésor	2020-03-04 16:00:00	2020-03-04 16:45:00	\N	\N	1	0	\N	\N
462412	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PPL Mineurs vulnérables sur le territoire français - Examen du rapport pour avis	\N	2020-03-24 14:00:00	2020-03-24 14:30:00	\N	\N	0	0	\N	\N
462413	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Système universel de retraite	\N	2020-03-04 16:30:00	2020-03-04 17:15:00	\N	\N	1	0	\N	\N
462422	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Système universel de retraite	\N	2020-03-05 14:30:00	2020-03-05 15:00:00	\N	\N	1	0	\N	\N
462425	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - Financement politiques lutte contre violences femmes - Associations	Contrôle 2020 - Financement politiques lutte contre violences femmes - Associations	2020-03-04 16:15:00	2020-03-04 17:45:00	\N	\N	2	0	\N	\N
462428	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - Financement politiques lutte contre violences femmes - DGCS / MIPROF	Contrôle 2020 - Financement politiques lutte contre violences femmes - DGCS / MIPROF	2020-03-05 14:00:00	2020-03-05 17:00:00	\N	\N	2	0	\N	\N
462443	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PJL Système universel de retraite - Auditions	\N	2020-03-24 14:30:00	2020-03-24 19:30:00	\N	\N	0	0	\N	\N
464986	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2020-04-07 18:05:00	2020-04-07 19:50:00	\N	\N	28	0	\N	\N
465833	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de Mme Florence LUSTMAN, présidente de la Fédération Française de l'Assurance FFA	Audition de Mme Florence LUSTMAN, présidente de la Fédération Française de l'Assurance (FFA)	2020-04-28 16:10:00	2020-04-28 17:40:00	\N	\N	20	0	\N	\N
465835	COM_PERMANENTE	AUTRE	\N	FINC	\N	Bilan Appleg 2020 Puis Audition FBF et BPIFrance	Bilan Appleg 2020 Puis Audition FBF et BPIFrance	2020-04-29 10:40:00	2020-04-29 13:00:00	2020-04-29 15:16:39	\N	29	0	\N	\N
481508	MISSION	AUCUNE	\N	ILLECTRONISM	\N	Audition de Mme Salomé Berlioux, présidente de l'association Chemins d'Avenirs	Audition de Mme Salomé Berlioux, présidente de l'association Chemins d'Avenirs	2020-06-29 15:00:00	2020-06-29 16:00:00	\N	\N	6	0	\N	\N
497988	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJLF 2021 - Mission santé - Audition CPAM Seine-Saint-Denis	PJLF 2021 - Mission santé - Audition CPAM Seine-Saint-Denis	2020-11-05 16:00:00	2020-11-05 17:00:00	\N	\N	1	0	\N	\N
497991	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJLF 2021 - Mission santé - Audition direction de la sécurité sociale	PJLF 2021 - Mission santé - Audition direction de la sécurité sociale	2020-11-05 17:00:00	2020-11-05 18:00:00	\N	\N	1	0	\N	\N
497992	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion pénière	\N	2020-11-06 08:30:00	2020-11-06 10:00:00	2020-11-06 11:44:39	\N	21	0	\N	\N
497993	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2021 - Mission Solidarité	\N	2020-10-29 11:30:00	2020-10-29 12:30:00	\N	\N	1	0	\N	\N
497994	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2021 - Mission Solidarité	\N	2020-10-29 13:30:00	2020-10-29 14:30:00	\N	\N	2	0	\N	\N
498007	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-11-02 16:45:00	2020-11-02 18:20:00	2020-11-02 18:37:58	2020-11-03 11:12:32	40	0	\N	\N
498008	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-11-04 09:30:00	2020-11-04 11:55:00	2020-11-04 15:42:30	2020-11-04 15:59:20	38	0	\N	\N
498009	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-11-03 15:00:00	2020-11-03 16:40:00	2020-11-04 19:06:26	2020-11-05 09:33:22	66	0	\N	\N
498010	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-11-04 16:30:00	2020-11-04 18:30:00	2020-11-05 16:24:10	2020-11-05 16:38:50	50	0	\N	\N
436894	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions de M. Montaugé et Mme Noël-PPL Libre choix du consommateur dans le cyberespace	Audition de représentants du Conseil supérieur de l'audiovisuel	2019-12-03 14:45:00	2019-12-03 15:30:00	\N	\N	2	0	\N	\N
436895	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions de M. Montaugé et Mme Noël-PPL Libre choix du consommateur dans le cyberespace	Audition de représentants de Facebook France	2019-12-04 14:00:00	2019-12-04 14:45:00	\N	\N	2	0	\N	\N
436896	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions de M. Montaugé et Mme Noël-PPL Libre choix du consommateur dans le cyberespace	Audition de représentants de La Quadrature du Net	2019-12-04 14:45:00	2019-12-04 15:30:00	\N	\N	1	0	\N	\N
436897	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions de M. Montaugé et Mme Noël-PPL Libre choix du consommateur dans le cyberespace	Audition de représentants de Paylib Services	2019-12-04 15:30:00	2019-12-04 16:15:00	\N	\N	2	0	\N	\N
436898	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions de M. Montaugé et Mme Noël-PPL Libre choix du consommateur dans le cyberespace	Audition de représentants de eDreams ODIGEO France	2019-12-04 17:15:00	2019-12-04 17:40:00	\N	\N	1	0	\N	\N
436943	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition Service central du renseignement territorial - Mission de suivi loi SILT	\N	2019-12-04 11:00:00	2019-12-04 12:15:00	\N	\N	2	0	\N	\N
436978	COM_SPECIALE	PLENIERE	\N	BIOETHIQUE	\N	CS Bioéthique - Audition CNAOP	\N	2019-12-11 13:45:00	2019-12-11 14:40:00	2019-12-11 15:06:10	2019-12-11 15:48:18	16	0	\N	\N
436980	COM_SPECIALE	PLENIERE	\N	BIOETHIQUE	\N	CS Bioéthique - Audition plénière - Fondation Jérôme Lejeune	\N	2019-12-11 19:00:00	2019-12-11 19:45:00	2019-12-13 14:24:53	2019-12-13 14:25:07	8	0	\N	\N
436982	COM_SPECIALE	AUTRE	\N	BIOETHIQUE	\N	CS bioéthique - Audition Agence de la biomédecine	\N	2019-12-12 10:20:00	2019-12-12 11:20:00	2019-12-12 14:26:56	2019-12-12 16:22:57	10	0	\N	\N
436991	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Outre-mer	PLF pour 2020 - Outre-mer	2019-12-05 14:30:00	2019-12-05 15:45:00	\N	\N	47	0	\N	\N
436992	ETUDES	AUTRE	\N	\N	\N	Audition plénière	Réunion du bureau	2019-12-04 13:30:00	2019-12-04 15:00:00	\N	\N	6	0	\N	909
437079	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-12-10 14:00:00	2019-12-10 14:40:00	2019-12-10 14:51:22	2019-12-10 17:06:36	22	0	\N	\N
437085	COM_SPECIALE	AUTRE	\N	BIOETHIQUE	\N	Audition Institut Famille et République	\N	2019-12-10 13:45:00	2019-12-10 14:30:00	2019-12-10 16:21:19	2019-12-10 17:07:32	18	0	\N	\N
437190	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-12-11 09:34:00	2019-12-11 11:50:00	2019-12-11 14:54:23	2019-12-11 15:55:47	31	0	\N	\N
437203	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-12-10 10:04:00	2019-12-10 10:20:00	2019-12-10 11:22:02	2019-12-10 17:06:53	21	3	\N	\N
437897	COM_SPECIALE	AUDRAP	\N	BIOETHIQUE	\N	Audition Mme Jourda CSN 	\N	2019-12-10 08:30:00	2019-12-10 09:15:00	\N	\N	2	0	\N	\N
437900	COM_SPECIALE	AUDRAP	\N	BIOETHIQUE	\N	Audition rapporteur	\N	2019-12-10 09:15:00	2019-12-10 10:25:00	\N	\N	3	0	\N	\N
437905	DELEGATION	AUDRAP	\N	\N	PROS	Audition de l'Assemblée des Communes de France	\N	2020-01-28 16:30:00	2020-01-28 17:30:00	\N	\N	0	0	\N	\N
437906	DELEGATION	AUDRAP	\N	\N	PROS	Audition du groupe Avril	\N	2020-01-23 10:00:00	2020-01-23 11:00:00	\N	\N	1	0	\N	\N
437907	DELEGATION	AUDRAP	\N	\N	PROS	Audition de la Fédération des Banques alimentaires	\N	2020-01-23 11:00:00	2020-01-23 12:00:00	\N	\N	0	0	\N	\N
437908	COM_EURO	AUDRAP	\N	AFEU	\N	\N	\N	2019-12-09 10:30:00	2019-12-09 11:30:00	\N	\N	0	0	\N	\N
437909	COM_EURO	AUDRAP	\N	AFEU	\N	audition rapporteur - Bruxelles - Adhésion UE à la CEDH	\N	2019-12-09 10:30:00	2019-12-10 12:30:00	\N	\N	0	0	\N	\N
438239	DELEGATION	AUCUNE	\N	\N	211	Réunion plénière - Echange de vues	Réunion plénière - Echange de vues	2019-12-17 17:30:00	2019-12-17 18:30:00	2019-12-18 09:41:12	\N	8	0	\N	\N
438242	COM_SPECIALE	AUDRAP	\N	BIOETHIQUE	\N	Auditions rapporteur	\N	2019-12-10 15:00:00	2019-12-10 16:00:00	\N	\N	1	0	\N	\N
439395	GIA	AUCUNE	\N	\N	\N	Entretien avec des représentants du secteur bancaire	Entretien avec des représentants du secteur bancaire	2019-12-11 08:00:00	2019-12-11 09:00:00	\N	\N	3	0	608	\N
439507	COM_ENQUETE	PLENIERE	\N	LUBRIZOL	\N	Réunion de commission	\N	2019-12-12 09:00:00	2019-12-12 11:30:00	2019-12-12 11:35:05	2019-12-12 16:22:58	9	0	\N	\N
439606	COM_SPECIALE	PLENIERE	\N	BIOETHIQUE	\N	Audition de Mme Nicole Belloubet, Mme Frédérique Vidal, ministres et M. Adrien Taquet	\N	2019-12-18 16:30:00	2019-12-18 19:00:00	2019-12-19 15:19:12	2019-12-19 16:30:45	25	0	\N	\N
439607	COM_SPECIALE	PLENIERE	\N	BIOETHIQUE	\N	Audition commune d'associations - CS Bioéthique	\N	2019-12-19 10:20:00	2019-12-19 12:20:00	2019-12-19 13:36:52	2019-12-19 15:17:15	12	0	\N	\N
439610	DELEGATION	AUDRAP	\N	\N	PROS	Audition de la Direction générale de la Santé (DGS)	\N	2020-01-14 14:30:00	2020-01-14 15:40:00	\N	\N	2	0	\N	\N
439631	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Avenir des Transports express régionaux	Débat Avenir des Transports express régionaux	2020-01-07 14:31:00	2020-01-07 15:53:00	\N	\N	85	0	\N	\N
439632	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat plan action territoires ruraux	Débat plan d'action en faveur des territoires ruraux	2020-01-07 15:54:00	2020-01-07 17:26:00	\N	\N	104	0	\N	\N
439633	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat réforme des retraites	Débat sur la réforme des retraites	2020-01-07 17:32:00	2020-01-07 19:34:00	\N	\N	135	0	\N	\N
439634	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat CCL RI Sauvetage en mer	Débat CCL RI Sauvetage en mer	2020-01-07 21:32:00	2020-01-07 22:48:00	\N	\N	40	0	\N	\N
439637	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2020-01-08 15:00:00	2020-01-08 16:18:00	\N	\N	264	0	\N	\N
439638	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR 34-1 Violences faites aux femmes	PPR 34-1 Violences faites aux femmes en situation de handicap	2020-01-08 16:30:00	2020-01-08 17:55:00	\N	\N	51	0	\N	\N
439639	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Pédopsychiatrie en France	Débat Pédopsychiatrie en France	2020-01-08 21:30:00	2020-01-08 23:01:00	\N	\N	18	0	\N	\N
439640	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat CCL RI Demain les robots	Débat CCL RI Demain les robots	2020-01-09 10:32:00	2020-01-09 12:04:00	\N	\N	30	0	\N	\N
439641	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2020-01-14 09:31:00	2020-01-14 12:47:00	\N	\N	40	0	\N	\N
439642	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Explications de vote _PPL_Mitage espaces forestiers	Explications de vote _PPL_Mitage espaces forestiers	2020-01-14 14:31:00	2020-01-14 15:19:00	\N	\N	73	0	\N	\N
439716	DELEGATION	AUCUNE	\N	\N	211	Réunion plénière	Réunion plénière	2020-01-07 12:30:00	2020-01-07 13:45:00	\N	\N	14	0	\N	\N
439798	COM_ENQUETE	AUTRE	\N	LUBRIZOL	\N	Réunion de commission	\N	2019-12-12 14:30:00	2019-12-12 15:35:00	\N	\N	0	0	\N	\N
439891	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-12-18 09:05:00	2019-12-18 11:25:00	2019-12-19 14:27:38	2019-12-19 15:16:49	34	2	\N	\N
439894	COM_ENQUETE	PLENIERE	\N	LUBRIZOL	\N	Audition de Mme Isabelle Striga,MM. Laurent Bonvallet et Christophe Pierard	\N	2019-12-18 16:30:00	2019-12-18 17:50:00	2019-12-18 17:58:02	2019-12-19 15:17:03	11	0	\N	\N
439895	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 -  Culture - IGAC et IGF	PLF pour 2020 -  Culture - IGAC et IGF	2019-12-12 11:00:00	2019-12-12 12:15:00	\N	\N	2	0	\N	\N
439898	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 -  Culture - Fondation du patrimoine	PLF pour 2020 -  Culture - Fondation du patrimoine	2019-12-12 14:30:00	2019-12-12 15:30:00	\N	\N	1	0	\N	\N
440082	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Nouveaux territoires de la culture	MI Nouveaux territoires de la culture	2019-12-17 14:30:00	2019-12-17 16:00:00	\N	\N	5	0	\N	\N
373711	DELEGATION	AUDRAP	\N	\N	PROS	Audition du LAAS/CNRS Toulouse	\N	2019-04-30 14:00:00	2019-04-30 15:00:00	\N	\N	1	0	\N	\N
382563	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Mme Saint-Pé PPL Précarité énergétique	\N	2019-05-22 11:15:00	2019-05-22 12:45:00	\N	\N	3	0	\N	\N
382569	COM_PERMANENTE	AUDRAP	\N	CAE	\N	ARCEP	\N	2019-05-21 11:00:00	2019-05-21 11:50:00	\N	\N	1	0	\N	\N
397362	MISSION	AUDRAP	\N	AERIEN	\N	\N	\N	2019-07-02 09:00:00	2019-07-02 10:10:00	\N	\N	4	0	\N	\N
397367	MISSION	AUDRAP	\N	AERIEN	\N	\N	\N	2019-07-02 10:10:00	2019-07-02 11:00:00	\N	\N	6	0	\N	\N
397384	MISSION	AUDRAP	\N	AERIEN	\N	\N	\N	2019-07-02 14:45:00	2019-07-02 15:55:00	\N	\N	7	0	\N	\N
439892	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-12-18 11:25:00	2019-12-18 12:05:00	2019-12-19 14:28:45	2019-12-19 15:16:50	34	2	\N	\N
402123	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière	Réunion plénière	2019-07-18 08:30:00	2019-07-18 09:30:00	\N	\N	8	0	\N	\N
402987	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2019-07-17 18:04:00	2019-07-17 18:36:00	\N	\N	26	0	\N	\N
404212	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-07-24 09:35:00	2019-07-24 11:45:00	2019-07-24 12:01:26	2019-07-24 12:08:31	20	0	\N	\N
404247	MISSION	DEPLACEMENT	\N	AERIEN	\N	Déplacement à Aurillac	\N	2019-07-11 10:30:00	2019-07-11 22:00:00	\N	\N	5	0	\N	\N
404248	MISSION	DEPLACEMENT	\N	AERIEN	\N	Déplacement à Rodez	\N	2019-07-12 08:00:00	2019-07-12 19:30:00	\N	\N	4	0	\N	\N
404307	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - CSA - Olivier SCHRAMECK	Contrôle 2019 - CSA - Olivier SCHRAMECK	2019-07-23 18:15:00	2019-07-23 19:00:00	\N	\N	1	0	\N	\N
404556	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Qualité frauduleuse de steaks hachés	Audition de Mme Christelle DUBOS, secrétaire d'État auprès de la ministre des solidarités et de la santé	2019-07-24 08:30:00	2019-07-24 09:30:00	\N	\N	1	0	\N	\N
404768	GIA	AUCUNE	\N	\N	\N	Accueil du député tibétain Thubten Wangchen	Accueil du député tibétain Thubten Wangchen	2019-09-09 10:00:00	2019-09-09 12:00:00	\N	\N	1	0	634	\N
405371	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	LOIS	\N	\N	\N	2019-09-17 14:00:00	2019-09-17 15:00:00	\N	\N	2	0	\N	\N
405374	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Engagement et proximité	PJL Engagement et proximité - Auditions rapporteurs	2019-09-17 15:00:00	2019-09-17 19:15:00	\N	\N	6	0	\N	\N
405383	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Engagement et proximité	\N	2019-09-18 14:00:00	2019-09-18 16:00:00	\N	\N	4	0	\N	\N
405388	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	LOIS	\N	\N	\N	2019-09-18 16:00:00	2019-09-18 17:00:00	\N	\N	2	0	\N	\N
405394	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion de la commission des affaires européennes du jeudi 19 septembre 2019	Réunion de la commission des affaires européennes du jeudi 19 septembre 2019	2019-09-19 11:00:00	2019-09-19 12:05:00	2019-09-19 13:06:16	2019-09-19 17:56:43	3	0	\N	\N
409014	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Fondation du patrimoine	PPL Fondation du patrimoine	2019-10-01 09:30:00	2019-10-01 11:00:00	\N	\N	3	0	\N	\N
409018	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Fondation du patrimoine	PPL Fondation du patrimoine	2019-10-01 14:00:00	2019-10-01 15:10:00	\N	\N	4	0	\N	\N
413275	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	CAE	\N	Débat - Société du Grand Paris	Débat - Société du Grand Paris	2019-10-09 08:00:00	2019-10-09 09:30:00	\N	\N	16	0	\N	\N
416129	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	NL PJL Mobilité	NL PJL Mobilité	2019-11-05 14:29:00	2019-11-05 15:36:00	\N	\N	108	0	\N	\N
425265	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Art. 1ère partie	PLF pour 2020 - Art. 1ère partie	2019-11-26 14:31:00	2019-11-26 19:55:00	\N	\N	207	0	\N	\N
425275	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Art. 1ère partie	PLF pour 2020 - Art. 1ère partie	2019-11-26 21:30:00	2019-11-26 22:24:00	\N	\N	46	0	\N	\N
425276	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CCL CMP PLFR pour 2019	CCL CMP PLFR pour 2019	2019-11-26 22:24:00	2019-11-26 23:15:00	\N	\N	35	0	\N	\N
425280	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Mission anciens combattants	PLF pour 2020 - Mission anciens combattants	2019-11-27 11:31:00	2019-11-27 13:17:00	\N	\N	82	0	\N	\N
425283	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2019-11-27 15:00:00	2019-11-27 16:15:00	\N	\N	300	0	\N	\N
425287	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Mission Ecologie	PLF pour 2020 - Mission Ecologie	2019-11-27 16:31:00	2019-11-27 20:01:00	\N	\N	119	0	\N	\N
425294	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Mission Enseignement scolaire	PLF pour 2020 - Mission Enseignement scolaire	2019-11-27 23:26:00	2019-11-28 01:48:00	\N	\N	36	0	\N	\N
425295	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Mission Ecologie	PLF pour 2020 - Mission Ecologie	2019-11-27 21:31:00	2019-11-27 23:26:00	\N	\N	63	0	\N	\N
425297	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Mission sport jeunesse	PLF pour 2020 - Mission sport jeunesse	2019-11-28 10:52:00	2019-11-28 12:59:00	\N	\N	62	0	\N	\N
425305	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	NL PLFSS pour 2020	NL PLFSS pour 2020	2019-11-30 10:30:00	2019-11-30 13:04:00	\N	\N	43	0	\N	\N
425306	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Mission sécurités	PLF pour 2020 - Mission sécurités	2019-11-28 14:31:00	2019-11-28 16:39:00	\N	\N	80	0	\N	\N
425307	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Mission immigration	PLF pour 2020 - Mission immigration	2019-11-28 16:40:00	2019-11-28 18:43:00	\N	\N	64	0	\N	\N
425312	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Mission pouvoirs publics	PLF pour 2020 - Mission pouvoirs publics	2019-11-28 21:35:00	2019-11-29 23:25:00	\N	\N	27	0	\N	\N
428378	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2019-10-22 15:00:00	2019-10-22 18:35:00	\N	\N	3	0	\N	\N
467547	DELEGATION	AUCUNE	\N	\N	206	Veille sur l'épidémie de coronavirus	\N	2020-04-30 09:40:00	2020-04-30 11:30:00	\N	\N	17	0	\N	\N
467580	DELEGATION	AUCUNE	\N	\N	COLTER	Audition : «Les élus à l¿action dans les foyers épidémiques de Covid-19»	\N	2020-04-30 09:30:00	2020-04-30 11:30:00	\N	\N	21	0	\N	\N
467606	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFR pour 2020 (2) "Engagements financiers de l'État" - Standard & Poor's	PLFR pour 2020 (2) "Engagements financiers de l'État" - Suivi mesures crise covid-19 - Standard & Poor's	2020-04-30 10:00:00	2020-04-30 10:40:00	\N	\N	1	0	\N	\N
485072	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT subsidiarité	Réunion du groupe de travail sur la subsidiarité	2020-07-15 14:35:00	2020-07-15 15:15:00	\N	\N	4	0	\N	\N
488727	COM_PERMANENTE	AUTRE	\N	FINC	\N	Plan de relance - Audition de MM. Bruno Le Maire et Olivier Dussopt, ministre délégué	Plan de relance - Audition de MM. Bruno Le Maire et Olivier Dussopt, ministre délégué auprès du ministre	2020-09-10 09:00:00	2020-09-10 11:20:00	2020-09-10 11:58:53	2020-09-10 16:02:09	19	0	\N	\N
489649	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Prévention de la perte d'autonomie - Audition de la DGS	\N	2020-09-22 11:00:00	2020-09-22 12:00:00	\N	\N	2	0	\N	\N
489650	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Prévention de la perte d'autonomie - Audition de MM. Piveteau et Wolfrom	\N	2020-09-22 16:30:00	2020-09-22 17:30:00	\N	\N	2	0	\N	\N
489737	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	auditions restitutions	\N	2020-09-24 15:00:00	2020-09-24 18:00:00	\N	\N	0	0	\N	\N
495005	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2021 - Branche Équilibres financiers	\N	2020-10-21 16:45:00	2020-10-21 18:20:00	\N	\N	1	0	\N	\N
495007	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2021 - Branche Famille	\N	2020-10-22 09:30:00	2020-10-22 10:30:00	\N	\N	2	0	\N	\N
404214	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion 24072019	\N	2019-07-24 10:10:00	2019-07-24 10:40:00	\N	2019-07-24 11:33:09	21	0	\N	\N
495117	SEANCE_PLENIERE	ELOGE_FUNEBRE	\N	\N	\N	Éloge funèbre	Éloge funèbre - GIUDICELLI	2020-10-27 14:30:00	2020-10-27 14:50:00	\N	\N	0	0	\N	\N
495118	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP ASAP	CMP ASAP	2020-10-27 15:15:00	2020-10-27 16:20:00	\N	\N	88	0	\N	\N
495119	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL produits phytopharmaceutiques	PJL produits phytopharmaceutiques en cas de danger sanitaire pour les betteraves sucrières	2020-10-27 22:15:00	2020-10-28 00:45:00	\N	\N	83	0	\N	\N
495120	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2020-10-28 15:00:00	2020-10-28 16:20:00	\N	\N	197	0	\N	\N
446341	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	Priorités 2020 dans l'espace OSCE	Priorités 2020 dans l'espace OSCE - petit déjeuner de travail	2020-02-05 08:15:00	2020-02-05 09:00:00	\N	\N	2	0	\N	\N
463407	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2020-04-08 15:01:00	2020-04-08 16:05:00	\N	\N	18	0	\N	\N
466830	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi urgence Covid-19 - Forces de sécurité intérieure	Audition DGPN	2020-04-24 14:30:00	2020-04-24 15:30:00	\N	\N	2	0	\N	\N
466833	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition par visioconférence de M. Pierre Razoux, directeur de recherche à l'IRSEM	\N	2020-04-28 15:00:00	2020-04-28 16:35:00	\N	\N	30	0	\N	\N
466834	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de l'ambassadeur de France aux États-Unis & communication application des lois	\N	2020-04-30 15:30:00	2020-04-30 17:35:00	\N	\N	37	0	\N	\N
466864	COM_ENQUETE	AUDRAP	\N	AUTOROUT	\N	CE concessions autoroutières - DAJ	CE concessions autoroutières - DAJ	2020-04-28 11:20:00	2020-04-28 12:05:00	\N	\N	4	0	\N	\N
467219	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Etat d'urgence sanitaire	PJL Prorogeant l'état d'urgence sanitaire	2020-05-04 18:20:00	2020-05-04 20:20:00	\N	\N	53	0	\N	\N
467220	SEANCE_PLENIERE	DECL_GVT	\N	\N	\N	Déclaration du Gouvernement	Déclaration du Gouvernement	2020-05-04 14:30:00	2020-05-04 18:05:00	\N	\N	63	0	\N	\N
467221	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Urgence sanitaire	PJL Prorogeant l'état d'urgence sanitaire	2020-05-04 22:00:00	2020-05-05 02:45:00	\N	\N	57	0	\N	\N
467222	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL prorogeant l'état d'urgence sanitaire	PJL prorogeant l'état d'urgence sanitaire	2020-05-05 14:30:00	2020-05-05 20:05:00	\N	\N	60	0	\N	\N
467223	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL prorogeant l'état d'urgence sanitaire	PJL prorogeant l'état d'urgence sanitaire	2020-05-05 21:35:00	2020-05-06 01:05:00	\N	\N	41	0	\N	\N
467224	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2020-05-06 15:00:00	2020-05-06 16:00:00	\N	\N	39	0	\N	\N
467225	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Urgence sanitaire	CMP PJL prorogation de l'état d'urgence sanitaire	2020-05-09 15:30:00	2020-05-09 17:45:00	\N	\N	20	0	\N	\N
467279	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de Mme Geneviève Chêne - Santé publique France (téléconférence)	\N	2020-05-06 10:00:00	2020-05-06 12:25:00	2020-05-12 17:01:37	\N	39	0	\N	\N
467280	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de Mme Florence Ader - Essai clinique européen Discovery (téléconférence)	\N	2020-05-06 17:00:00	2020-05-06 19:00:00	\N	\N	32	0	\N	\N
467281	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition des ARS Auvergne-Rhône-Alpes et Bourgogne-Franche-Comté (téléconférence)	\N	2020-05-07 15:00:00	2020-05-07 16:25:00	2020-05-12 17:15:30	\N	19	0	\N	\N
467282	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de Mme Françoise Barré-Sinoussi, présidente du CARE (téléconférence)	\N	2020-05-07 17:00:00	2020-05-07 17:55:00	2020-05-12 17:21:01	\N	18	0	\N	\N
467359	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Alain Thirion, préfet, directeur général de la sécurité civile et de la gestion des crises	\N	2020-04-30 17:30:00	2020-04-30 18:30:00	\N	\N	3	0	\N	\N
467494	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Enjeux sanitaires - Audition CCIL (Mme Deroche)	\N	2020-04-29 18:00:00	2020-04-29 19:00:00	\N	\N	7	0	\N	\N
467532	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Prorogation de l'état d'urgence sanitaire - Examen rapport et établissement texte	PJL Prorogation de l'état d'urgence sanitaire - Examen rapport et établissement texte	2020-05-04 10:15:00	2020-05-04 14:15:00	2020-05-12 19:11:42	\N	42	1	\N	\N
467533	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de M. Jean Castex	Audition de M. Jean Castex	2020-05-06 09:34:00	2020-05-06 11:08:00	2020-05-12 19:02:56	\N	36	0	\N	\N
467534	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de Mme Jacqueline Gourault	Audition de Mme Jacqueline Gourault	2020-05-06 17:00:00	2020-05-06 18:50:00	2020-05-12 19:03:20	\N	26	0	\N	\N
467707	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition de Mme Mme Gabrielle Hoppé (DGEFP)	Audition de Mme Mme Gabrielle Hoppé (DGEFP)	2020-04-30 09:45:00	2020-04-30 10:55:00	\N	\N	4	0	\N	\N
467712	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition de M. Mikael Charbit (FRANCE COMPETENCES)	Audition de M. Mikael Charbit (FRANCE COMPETENCES)	2020-04-30 11:00:00	2020-04-30 12:10:00	\N	\N	2	0	\N	\N
467727	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLFR pour 2020 (2) - Audition de Jacqueline GOURAULT et de Sébastien LECORNU, ministres	PLFR pour 2020 (2) - Audition de Jacqueline GOURAULT et de Sébastien LECORNU, ministres	2020-05-05 09:00:00	2020-05-05 11:20:00	\N	\N	33	0	\N	\N
467728	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLFR pour 2020 (2) - Audition de M. Jérôme FOURNEL DGFiP	PLFR pour 2020 (2) - Audition de M. Jérôme FOURNEL DGFiP	2020-05-07 17:35:00	2020-05-07 18:55:00	\N	\N	26	0	\N	\N
467801	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2020-05-06 10:00:00	2020-05-06 11:50:00	\N	\N	33	0	\N	\N
467802	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2020-05-06 16:30:00	2020-05-06 18:30:00	\N	\N	24	0	\N	\N
467817	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audition d'ACTED (ONG)	\N	2020-04-30 10:30:00	2020-04-30 12:00:00	\N	\N	2	0	\N	\N
467821	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Prorogation de l'état d'urgence sanitaire	PJL Prorogation de l'état d'urgence sanitaire	2020-05-04 18:12:00	2020-05-04 18:15:00	2020-05-12 19:03:34	\N	13	1	\N	\N
468473	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi urgence Covid-19 - Prisons et autres lieux privatifs de liberté	Audition DPJJ	2020-05-05 17:20:00	2020-05-05 18:40:00	\N	\N	2	0	\N	\N
468946	DELEGATION	AUCUNE	\N	\N	COLTER	Audition J. Gourault, ministre cohésion territoires et relations collectivités	\N	2020-05-13 17:00:00	2020-05-13 18:45:00	2020-05-14 12:01:41	\N	19	0	\N	\N
469657	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Groupe de travail Décentralisation	\N	2020-05-12 16:00:00	2020-05-12 17:00:00	\N	\N	4	0	\N	\N
470567	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	ONISEP Bretagne	\N	2020-05-14 09:45:00	2020-05-14 11:15:00	\N	\N	3	0	\N	\N
470578	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	DASEN du Finistère	\N	2020-05-18 09:30:00	2020-05-18 10:50:00	\N	\N	2	0	\N	\N
470579	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL role des assurances crise sanitaire majeure	PPL définir et à coordonner les rôles respectifs des assurances et de la solidarité nationale dans le soutien des entrep	2020-06-02 14:30:00	2020-06-02 16:30:00	\N	\N	42	0	\N	\N
470580	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFR pour 2020 "Écologie" - Suivi mesures crise covid-19 - FNTR	PLFR pour 2020 "Écologie" - Suivi mesures crise covid-19 - FNTR	2020-04-17 10:00:00	2020-04-17 11:00:00	\N	\N	1	0	\N	\N
470581	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Incendie Lubrizol	Débat Incendie Lubrizol	2020-06-30 15:35:00	2020-06-30 17:05:00	\N	\N	89	0	\N	\N
470583	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2020-06-03 15:00:00	2020-06-03 15:55:00	\N	\N	96	0	\N	\N
470584	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL statut des travailleurs des plateformes numériques	PPL statut des travailleurs des plateformes numériques	2020-06-04 09:00:00	2020-06-04 11:10:00	\N	\N	32	0	\N	\N
470585	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL garantir l'efficacité des aides personnelles au logement	PPL visant à garantir l'efficacité des aides personnelles au logement	2020-06-04 11:10:00	2020-06-04 12:55:00	\N	\N	24	0	\N	\N
470586	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL création de Points d'accueil pour soins immédiats	PPL visant à répondre à la demande des patients par la création de Points d'accueil pour soins immédiats	2020-06-04 14:30:00	2020-06-04 16:05:00	\N	\N	23	0	\N	\N
470587	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL encadrer le démarchage téléphonique et à lutter contre les appels frauduleux 	PPL  visant à encadrer le démarchage téléphonique et à lutter contre les appels frauduleux 	2020-06-04 16:10:00	2020-06-04 18:35:00	\N	\N	14	0	\N	\N
470588	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2020-05-27 14:00:00	2020-05-27 15:00:00	\N	\N	0	0	\N	\N
470589	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Chefs de cour des cours d'appel de Douai et Lyon	\N	2020-05-15 10:00:00	2020-05-15 11:30:00	\N	\N	5	0	\N	\N
470616	COM_ENQUETE	PLENIERE	\N	SOLS	\N	Réunion de commission	\N	2020-05-19 16:30:00	2020-05-19 18:45:00	2020-05-25 15:24:54	2020-05-25 16:29:22	7	0	\N	\N
470619	COM_ENQUETE	PLENIERE	\N	SOLS	\N	Réunion de commission	\N	2020-05-20 16:45:00	2020-05-20 19:00:00	2020-05-25 15:38:19	2020-05-25 16:29:23	7	0	\N	\N
470674	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule PME CCI France	Audition cellule PME commerce artisanat	2020-04-03 14:40:00	2020-04-03 15:30:00	\N	\N	4	0	\N	\N
387773	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Mission innovation et défense	\N	2019-06-05 08:30:00	2019-06-05 09:30:00	\N	\N	2	0	\N	\N
391635	COM_PERMANENTE	AUTRE	\N	SOCI	\N	RI hébergement d'urgence	RI hébergement d'urgence	2019-06-26 09:30:00	2019-06-26 10:40:00	2019-06-26 10:41:43	2019-06-26 18:35:58	31	0	\N	\N
391636	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de M. Gérald Darmanin	Audition de M. Gérald Darmanin	2019-06-26 16:35:00	2019-06-26 17:55:00	2019-06-26 18:01:03	2019-06-26 18:36:28	30	0	\N	\N
396240	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteur de Mme Peggy Larrieu (Neurosciences)	Audition rapporteur de Mme Peggy Larrieu (Neurosciences)	2019-07-10 14:00:00	2019-07-10 15:00:00	\N	\N	1	0	\N	\N
396241	DELEGATION	AUCUNE	\N	\N	206	Audition plénière sur l'EPR de Flamanville	Audition plénière sur l'EPR de Flamanville	2019-07-17 17:35:00	2019-07-17 20:00:00	\N	\N	8	0	\N	\N
397418	GIA	AUCUNE	\N	\N	\N	Table ronde "La Chine, défis économiques et opportunités commerciales pour la France"	\N	2019-07-03 14:30:00	2019-07-03 15:45:00	\N	\N	9	0	584	\N
408286	SEANCE_PLENIERE	HOMMAGE	\N	\N	\N	Hommage	Hommage	2019-10-02 15:00:00	2019-10-02 15:25:00	\N	\N	297	0	\N	\N
416673	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2020 - Missions Pouvoirs Publics et Remboursements et dégrevements	PLF pour 2020 - Missions Pouvoirs Publics et Remboursements et dégrevements	2019-10-22 15:45:00	2019-10-22 17:10:00	2019-10-22 17:49:53	2019-10-22 18:23:50	29	1	\N	\N
416760	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Travailleurs indépendants	\N	2019-10-17 09:30:00	2019-10-17 10:30:00	\N	\N	2	0	\N	\N
416780	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Travailleurs indépendants	\N	2019-10-17 10:30:00	2019-10-17 11:30:00	\N	\N	2	0	\N	\N
416834	COM_PERMANENTE	AUTRE	\N	FINC	\N	 Communication Gouvernance économique et financière de l¿Union européenne	 Communication Gouvernance économique et financière de l¿Union européenne	2019-10-23 11:10:00	2019-10-23 11:20:00	2019-10-23 11:37:07	2019-10-23 11:46:15	27	1	\N	\N
416903	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL AVIA - 	\N	2019-10-16 14:00:00	2019-10-16 15:00:00	\N	\N	0	0	\N	\N
416932	DELEGATION	AUDRAP	\N	\N	PROS	Audition de l'ADEME	\N	2019-10-22 16:00:00	2019-10-22 18:00:00	\N	\N	1	0	\N	\N
416944	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 -  Culture - CNRS	PLF pour 2020 -  Culture - CNRS	2019-10-08 16:00:00	2019-10-08 17:00:00	\N	\N	1	0	\N	\N
416988	COM_ENQUETE	PLENIERE	\N	LUBRIZOL	\N	Réunion de commission	\N	2019-10-22 15:40:00	2019-10-22 17:25:00	2019-10-23 11:35:06	2019-10-23 11:43:04	18	0	\N	\N
417107	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFSS pour 2020 - CADES	PLFSS pour 2020 - CADES	2019-10-14 10:00:00	2019-10-14 10:45:00	\N	\N	1	0	\N	\N
417109	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 -  Médias, livre et industries culturelles - DGMIC-CNC	PLF pour 2020 -  Médias, livre et industries culturelles - DGMIC-CNC	2019-10-14 16:00:00	2019-10-14 17:15:00	\N	\N	1	0	\N	\N
417111	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - DAG - CNIL	PLF pour 2020 - DAG - CNIL	2019-10-15 14:30:00	2019-10-15 15:30:00	\N	\N	1	0	\N	\N
417114	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Justice - DB	PLF pour 2020 - Justice - DB	2019-10-15 10:00:00	2019-10-15 11:00:00	\N	\N	1	0	\N	\N
417117	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Justice - DPJJ - DSJ	PLF pour 2020 - Justice - DPJJ - DSJ	2019-10-15 17:00:00	2019-10-15 19:00:00	\N	\N	1	0	\N	\N
417121	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Justice - NEXEM	PLF pour 2020 - Justice - NEXEM	2019-10-17 10:30:00	2019-10-17 11:00:00	\N	\N	1	0	\N	\N
417125	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Écologie - FNTR	PLF pour 2020 - Écologie - FNTR	2019-10-15 09:30:00	2019-10-15 10:30:00	\N	\N	1	0	\N	\N
417127	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Écologie - SNCF Réseau	PLF pour 2020 - Écologie - SNCF Réseau	2019-10-17 10:30:00	2019-10-17 11:45:00	\N	\N	1	0	\N	\N
417129	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Conseil et contrôle de l'État - Cour des comptes	PLF pour 2020 - Conseil et contrôle de l'État - Cour des comptes	2019-10-15 08:00:00	2019-10-15 09:00:00	\N	\N	1	0	\N	\N
417131	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Service public de l'éducation et neutralité religieuse	PPL Service public de l'éducation et neutralité religieuse	2019-10-16 17:00:00	2019-10-16 18:00:00	\N	\N	3	0	\N	\N
417132	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Service public de l'éducation et neutralité religieuse	PPL Service public de l'éducation et neutralité religieuse	2019-10-16 18:00:00	2019-10-16 19:15:00	\N	\N	5	0	\N	\N
417133	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Service public de l'éducation et neutralité religieuse	PPL Service public de l'éducation et neutralité religieuse	2019-10-15 11:00:00	2019-10-15 12:00:00	\N	\N	1	0	\N	\N
417138	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Conseil et contrôle de l'État - CESE	PLF pour 2020 - Conseil et contrôle de l'État - CESE	2019-10-15 16:45:00	2019-10-15 17:45:00	\N	\N	1	0	\N	\N
417156	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Sécurités - Sécurité Civile - CNSIS 	PLF pour 2020 - Sécurités - Sécurité Civile - CNSIS 	2019-10-15 17:30:00	2019-10-15 18:20:00	\N	\N	1	0	\N	\N
417160	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS Budget 2020	\N	2019-10-16 16:30:00	2019-10-16 18:45:00	\N	\N	3	0	\N	\N
417161	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS Budget 2020	\N	2019-10-16 14:00:00	2019-10-16 15:00:00	\N	\N	4	0	\N	\N
417169	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Rapport Général - U2P	PLF pour 2020 - Rapport Général - U2P	2019-10-15 10:15:00	2019-10-15 11:00:00	\N	\N	1	0	\N	\N
417171	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - CAS PFE - EDF	PLF pour 2020 - CAS PFE - EDF	2019-10-16 14:00:00	2019-10-16 15:00:00	\N	\N	1	0	\N	\N
417173	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - CAS PFE - FDJ	PLF pour 2020 - CAS PFE - FDJ	2019-10-16 16:30:00	2019-10-16 17:30:00	\N	\N	1	0	\N	\N
417175	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - CAS PFE - ADP	PLF pour 2020 - CAS PFE - ADP	2019-10-17 12:00:00	2019-10-17 13:00:00	\N	\N	1	0	\N	\N
417177	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Rapport général - DGCL	PLF pour 2020 - Rapport général - DGCL	2019-10-14 17:00:00	2019-10-14 18:00:00	\N	\N	1	0	\N	\N
417179	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020  - Rapport général - FEPEM	PLF pour 2020 - Rapport général - FEPEM	2019-10-16 16:20:00	2019-10-16 16:50:00	\N	\N	1	0	\N	\N
417181	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - GFPRH - DGFiP	PLF pour 2020 - GFPRH - DGFiP	2019-10-17 08:00:00	2019-10-17 09:40:00	\N	\N	2	0	\N	\N
417184	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Pouvoirs publics - Questeurs du Sénat	PLF pour 2020 - Pouvoirs publics - Questeurs du Sénat	2019-10-09 11:30:00	2019-10-09 12:30:00	\N	\N	1	0	\N	\N
417186	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Rapport général - AFILOG	PLF pour 2020 - Rapport général - AFILOG	2019-10-10 16:35:00	2019-10-10 17:20:00	\N	\N	1	0	\N	\N
417190	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 -Investissements d'avenir - ADEME	PLF pour 2020 -Investissements d'avenir - ADEME	2019-10-16 17:00:00	2019-10-16 18:00:00	\N	\N	1	0	\N	\N
417192	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2020 - Pouvoirs publics - Déplacement AN	PLF pour 2020 - Pouvoirs publics - Déplacement AN	2019-10-17 10:30:00	2019-10-17 12:30:00	\N	\N	1	0	\N	\N
417194	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Investissements d'avenir - BPIfrance - SGI	PLF pour 2020 - Investissements d'avenir - BPIfrance - SGI	2019-10-17 14:00:00	2019-10-17 16:00:00	\N	\N	1	0	\N	\N
417240	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Sécurités - Syndicats	PLF pour 2020 - Sécurités - Syndicats	2019-10-15 14:30:00	2019-10-15 16:00:00	\N	\N	1	0	\N	\N
417242	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Défense - EMAT	PLF pour 2020 - Défense - EMAT	2019-10-17 10:30:00	2019-10-17 11:30:00	\N	\N	1	0	\N	\N
417244	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Défense - EMAA	PLF pour 2020 - Défense - EMAA	2019-10-18 11:00:00	2019-10-18 12:15:00	\N	\N	1	0	\N	\N
417246	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - AEE - Cabinet MEAE	PLF pour 2020 - AEE - Cabinet MEAE	2019-10-16 11:40:00	2019-10-16 12:40:00	\N	\N	2	0	\N	\N
417249	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - AEE - MACP - DB	PLF pour 2020 - AEE - MACP - DB	2019-10-16 17:00:00	2019-10-16 18:00:00	\N	\N	1	0	\N	\N
417251	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - AEE - MEAE - Atout France	PLF pour 2020 - AEE - MEAE - Atout France	2019-10-17 11:00:00	2019-10-17 12:00:00	\N	\N	1	0	\N	\N
438470	DELEGATION	AUCUNE	\N	\N	COLTER	Table ronde "Alimentation saine et durable"	\N	2019-12-19 09:30:00	2019-12-19 11:30:00	2019-12-19 12:11:07	\N	5	0	\N	\N
441407	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PJL Engagement & proximité	commission mixte paritaire sur le projet de loi relatif à l'engagement dans la vie locale et à la proximité de l'action 	2019-12-18 18:52:00	2019-12-18 19:51:00	\N	\N	49	0	\N	\N
441590	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2020-01-08 09:45:00	2020-01-08 12:05:00	2020-01-08 15:33:06	2020-01-09 15:07:56	32	1	\N	\N
441593	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Ports	MI Ports	2019-12-18 16:30:00	2019-12-18 18:10:00	\N	\N	7	0	\N	\N
441618	COM_SPECIALE	PLENIERE	\N	BIOETHIQUE	\N	Examen rapport et texte	\N	2020-01-07 14:05:00	2020-01-07 17:15:00	2020-01-07 17:20:52	2020-01-08 10:39:18	29	1	\N	\N
441619	COM_SPECIALE	PLENIERE	\N	BIOETHIQUE	\N	PJL Bioéthique - Suite examen du rapport et établissement du texte	\N	2020-01-07 21:05:00	2020-01-08 00:00:00	2020-01-08 00:05:27	2020-01-08 10:39:19	25	1	\N	\N
441620	COM_SPECIALE	PLENIERE	\N	BIOETHIQUE	\N	Suite examen  rapport et texte	\N	2020-01-08 16:45:00	2020-01-08 17:15:00	2020-01-08 17:14:54	2020-01-08 17:59:53	23	1	\N	\N
441629	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Améliorer les droits des usagers des transports en cas de grève	\N	2019-12-18 09:30:00	2019-12-18 10:30:00	\N	\N	1	0	\N	\N
441631	ETUDES	AUTRE	\N	\N	\N	Audition plénière	Audition M. François OMNES - ONCFS	2019-12-18 08:00:00	2019-12-18 09:00:00	\N	\N	25	0	\N	907
441690	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions de M. Montaugé et Mme Noël-PPL Libre choix du consommateur dans le cyberespace	\N	2019-12-18 14:00:00	2019-12-18 20:00:00	\N	\N	2	0	\N	\N
441722	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Nouvelles formes de commerce	Auditions plénières	2019-12-17 13:30:00	2019-12-17 14:15:00	\N	\N	4	0	\N	\N
441727	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Nouvelles formes de commerce	Auditions plénières	2019-12-17 14:15:00	2019-12-17 17:35:00	\N	\N	3	0	\N	\N
441732	COM_SPECIALE	PLENIERE	\N	BIOETHIQUE	\N	Réunion de travail	\N	2019-12-17 17:00:00	2019-12-17 19:30:00	\N	\N	1	0	\N	\N
441734	COM_SPECIALE	PLENIERE	\N	BIOETHIQUE	\N	Réunion de travail	\N	2019-12-18 09:00:00	2019-12-18 12:30:00	\N	\N	5	0	\N	\N
441747	DELEGATION	AUCUNE	\N	\N	DSOM	Audition du Secrétariat général aux affaires européennes (SGAE)	\N	2020-01-16 09:30:00	2020-01-16 11:10:00	\N	\N	10	0	\N	\N
441792	DELEGATION	AUCUNE	\N	\N	COLTER	Table ronde ADF + examen rapport "Ruralités"	\N	2020-01-16 09:30:00	2020-01-16 12:00:00	2020-01-16 12:39:42	\N	15	0	\N	\N
441793	DELEGATION	AUCUNE	\N	\N	COLTER	Table ronde "Patrimoine historique des collectivités"	\N	2020-01-23 09:30:00	2020-01-23 11:00:00	2020-01-23 11:38:37	\N	8	0	\N	\N
443747	DELEGATION	AUDRAP	\N	\N	PROS	Audition de l'APCA (Chambres d'agriculture France)	\N	2020-01-14 16:50:00	2020-01-14 18:00:00	\N	\N	1	0	\N	\N
443770	DELEGATION	AUDRAP	\N	\N	PROS	Audition de Terres en ville	\N	2020-01-16 10:00:00	2020-01-16 11:00:00	\N	\N	2	0	\N	\N
443771	DELEGATION	AUCUNE	\N	\N	211	Examen d'un rapport d¿information	Examen d'un rapport d¿information	2020-01-30 08:45:00	2020-01-30 09:45:00	2020-01-30 12:29:23	\N	6	0	\N	\N
443772	DELEGATION	AUCUNE	\N	\N	DSOM	Déplacement à Bruxelles - Étude sur les enjeux européens en 2020 pour les outre-mer	\N	2020-01-23 08:00:00	2020-01-23 20:00:00	\N	\N	11	0	\N	\N
444140	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Améliorer les droits des usagers des transports en cas de grève	\N	2020-01-14 13:45:00	2020-01-14 15:15:00	\N	\N	1	0	\N	\N
444359	ETUDES	AUTRE	\N	\N	\N	Audition plénière Service numérique ANCT	Audition plénière Service numérique ANCT	2020-01-14 14:00:00	2020-01-14 15:00:00	\N	\N	3	0	\N	918
444363	ETUDES	AUTRE	\N	\N	\N	Audition plénière FFT	Audition plénière FFT	2020-01-14 15:00:00	2020-01-14 16:00:00	\N	\N	1	0	\N	918
444383	COM_SPECIALE	PLENIERE	\N	BIOETHIQUE	\N	Examen des amendements de séance	\N	2020-01-21 08:30:00	2020-01-21 10:30:00	2020-01-21 14:47:52	2020-01-21 14:57:45	28	0	\N	\N
444384	COM_SPECIALE	PLENIERE	\N	BIOETHIQUE	\N	PJL Bioéthique - Suite de l'examen des amendements de séance	\N	2020-01-21 13:30:00	2020-01-21 14:20:00	2020-01-21 14:23:50	2020-01-21 14:41:19	26	0	\N	\N
444385	COM_SPECIALE	PLENIERE	\N	BIOETHIQUE	\N	PJL Bioéthique - Suite de l'examen des amendements de séance	\N	2020-01-21 19:30:00	2020-01-21 20:30:00	2020-01-22 15:49:21	2020-01-22 16:59:13	28	0	\N	\N
444387	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de Mme Myriam El Khomri sur l'attractivité des métiers du grand-âge	\N	2020-01-15 10:00:00	2020-01-15 12:10:00	2020-01-15 13:15:09	2020-01-15 17:49:13	44	0	\N	\N
444487	ETUDES	AUTRE	\N	\N	\N	GE Cheval - Audition IFCE	\N	2020-01-15 08:00:00	2020-01-15 09:20:00	\N	\N	5	0	\N	912
444710	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Améliorer les droits des usagers des transports en cas de grève	\N	2020-01-14 17:50:00	2020-01-14 18:50:00	\N	\N	1	0	\N	\N
444733	DELEGATION	AUCUNE	\N	\N	211	Table ronde sur l¿égalité femmes-hommes, enjeu de l¿aide publique au développement.	Table ronde sur l¿égalité femmes-hommes, enjeu de l¿aide publique au développement.	2020-01-23 08:30:00	2020-01-23 10:45:00	2020-01-23 12:32:27	\N	4	0	\N	\N
444734	COM_ENQUETE	PLENIERE	\N	RADICALI	\N	Audition de Zineb El Rhazoui	Audition de Zineb El Rhazoui	2020-01-23 11:00:00	2020-01-23 12:25:00	2020-01-24 09:55:51	2020-01-24 10:25:06	7	0	\N	\N
444735	COM_ENQUETE	PLENIERE	\N	RADICALI	\N	Auditions plénières	Auditions plénières	2020-01-21 15:05:00	2020-01-21 18:50:00	2020-01-21 19:16:01	2020-01-22 11:12:19	16	0	\N	\N
445098	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions de M. Montaugé et Mme Noël-PPL Libre choix du consommateur dans le cyberespace	\N	2020-01-14 15:30:00	2020-01-14 17:45:00	\N	\N	1	0	\N	\N
445116	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - Mission SILT - DLPAJ	\N	2020-01-15 11:30:00	2020-01-15 12:45:00	\N	\N	1	0	\N	\N
445118	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - Mission SILT - Préfecture de police	\N	2020-01-15 13:45:00	2020-01-15 14:45:00	\N	\N	1	0	\N	\N
445136	ETUDES	AUTRE	\N	\N	\N	Audition plénière	Audition M. CAMOIN ANDCTG	2020-01-15 13:30:00	2020-01-15 15:00:00	\N	\N	12	0	\N	907
445137	ETUDES	AUTRE	\N	\N	\N	GE Élevage et GE Agriculture et alimentation - Audition Olivier Dauvers	\N	2020-01-15 14:00:00	2020-01-15 15:00:00	\N	\N	15	0	\N	911
445140	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Améliorer les droits des usagers des transports en cas de grève	\N	2020-01-15 11:30:00	2020-01-15 12:30:00	\N	\N	1	0	\N	\N
445169	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion de la commission des affaires européenes du 22 janvier 2020	Réunion de la commission des affaires européenes du 22 janvier 2020	2020-01-22 13:30:00	2020-01-22 14:50:00	2020-01-22 15:15:26	2020-01-22 15:46:53	18	0	\N	\N
445170	COM_EURO	AUTRE	\N	AFEU	\N	Audition de Mme Amélie de Montchalin, secrétaire d'État	\N	2020-01-23 08:50:00	2020-01-23 10:20:00	2020-01-23 11:30:34	2020-01-23 17:49:52	9	0	\N	\N
445594	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Améliorer les droits des usagers des transports en cas de grève	\N	2020-01-15 16:30:00	2020-01-15 17:30:00	\N	\N	1	0	\N	\N
445707	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2020-01-22 10:05:00	2020-01-22 11:55:00	2020-01-22 12:09:54	2020-01-22 15:46:38	37	0	\N	\N
445715	COM_PERMANENTE	AUTRE	\N	FINC	\N	Programme de contrôle - 2020 - Communication de M. Vincent Éblé	Programme de contrôle - 2020 - Communication de M. Vincent Éblé	2020-01-22 10:30:00	2020-01-22 11:00:00	2020-01-22 12:07:19	2020-01-22 15:46:40	43	0	\N	\N
445801	DELEGATION	AUDRAP	\N	\N	DSOM	Réunion avec le directeur général de l'Agence qualité construction (AQC)	\N	2020-01-16 11:45:00	2020-01-16 12:45:00	\N	\N	1	0	\N	\N
445802	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions de M. Montaugé et Mme Noël-PPL Libre choix du consommateur dans le cyberespace	\N	2020-01-15 16:30:00	2020-01-15 17:30:00	\N	\N	3	0	\N	\N
382798	COM_ENQUETE	PLENIERE	\N	SOUVERAINETE	\N	Audition plénière - Commission d'enquête sur la souveraineté numérique	\N	2019-05-23 11:30:00	2019-05-23 12:50:00	2019-05-25 13:09:17	2019-05-27 14:50:54	9	0	\N	\N
382799	COM_ENQUETE	PLENIERE	\N	SOUVERAINETE	\N	Auditions	\N	2019-05-23 14:05:00	2019-05-23 17:35:00	2019-05-25 15:03:25	2019-05-27 14:50:55	9	0	\N	\N
393395	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Communication fin de vie	\N	2019-06-19 11:18:00	2019-06-19 12:45:00	2019-06-20 17:53:52	2019-06-24 09:59:36	42	0	\N	\N
393857	MECSS	AUDRAP	\N	\N	MECSS	GT Réforme des retraites	\N	2019-07-09 14:30:00	2019-07-09 15:15:00	\N	\N	1	0	\N	\N
395202	MECSS	AUCUNE	\N	\N	MECSS	loi de financement de la sécurité sociale pour 2018	loi de financement de la sécurité sociale pour 2018	2019-07-02 14:35:00	2019-07-02 15:20:00	2019-07-02 15:25:25	2019-07-02 16:18:49	9	0	\N	\N
396283	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Energie - Auditions M. Gremillet	PJL Energie - Auditions M. Gremillet	2019-06-25 14:00:00	2019-06-25 16:00:00	\N	\N	2	0	\N	\N
396286	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Energie - Auditions M. Gremillet	PJL Energie - Auditions M. Gremillet	2019-06-25 16:00:00	2019-06-25 17:00:00	\N	\N	4	0	\N	\N
396291	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Energie - Auditions M. Gremillet	PJL Energie - Auditions M. Gremillet	2019-06-25 17:00:00	2019-06-25 18:15:00	\N	\N	1	0	\N	\N
396439	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Mme Gruny M. Artano MI Santé au travail	\N	2019-06-27 14:30:00	2019-06-27 15:15:00	\N	\N	2	0	\N	\N
396454	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Nouveaux territoires de l'éducation	MI Nouveaux territoires de l'éducation	2019-06-18 14:00:00	2019-06-18 15:00:00	\N	\N	3	0	\N	\N
396458	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Nouveaux territoires de l'éducation	MI Nouveaux territoires de l'éducation	2019-06-19 14:00:00	2019-06-19 15:00:00	\N	\N	3	0	\N	\N
444386	COM_SPECIALE	AUTRE	\N	BIOETHIQUE	\N	PJL Bioéthique - Suite de l'examen des amendements de séance	\N	2020-01-22 08:35:00	2020-01-22 10:30:00	2020-01-22 10:24:56	2020-01-22 11:13:33	27	0	\N	\N
444388	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Examen des amendements de séance	\N	2020-01-15 09:30:00	2020-01-15 09:50:00	2020-01-15 11:17:40	2020-01-15 11:48:55	43	0	\N	\N
396463	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Nouveaux territoires de l'éducation	MI Nouveaux territoires de l'éducation	2019-06-19 16:00:00	2019-06-19 17:00:00	\N	\N	4	0	\N	\N
396469	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Nouveaux territoires de l'éducation	MI Nouveaux territoires de l'éducation	2019-06-20 14:00:00	2019-06-20 15:00:00	\N	\N	2	0	\N	\N
396472	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Nouveaux territoires de l'éducation	MI Nouveaux territoires de l'éducation	2019-07-25 09:00:00	2019-07-25 10:30:00	\N	\N	3	0	\N	\N
396476	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Nouveaux territoires de l'éducation	MI Nouveaux territoires de l'éducation	2019-06-25 14:45:00	2019-06-25 15:30:00	\N	\N	2	0	\N	\N
396479	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Nouveaux territoires de l'éducation	MI Nouveaux territoires de l'éducation	2019-06-25 17:45:00	2019-06-25 19:15:00	\N	\N	2	0	\N	\N
396483	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Nouveaux territoires de l'éducation	MI Nouveaux territoires de l'éducation	2019-05-20 14:00:00	2019-05-20 18:00:00	\N	\N	2	0	\N	\N
396486	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Nouveaux territoires de l'éducation	MI Nouveaux territoires de l'éducation	2019-05-22 15:30:00	2019-05-22 17:30:00	\N	\N	2	0	\N	\N
396489	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Nouveaux territoires de l'éducation	MI Nouveaux territoires de l'éducation	2019-05-23 10:30:00	2019-05-23 11:30:00	\N	\N	2	0	\N	\N
403014	MISSION	DEPLACEMENT	\N	MARITIME	\N	MCI Sauvetage en mer - Déplacement Vendée-Les Sables-d'Olonne	MCI Sauvetage en mer - Déplacement Vendée-Les Sables-d'Olonne	2019-07-22 08:43:00	2019-07-22 21:17:00	\N	\N	9	0	\N	\N
403025	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	\N	\N	2019-10-01 13:30:00	2019-10-01 14:30:00	\N	\N	0	0	\N	\N
406863	ETUDES	AUCUNE	\N	\N	\N	Audition	Audition GE Agriculture Alimentation	2019-09-25 08:00:00	2019-09-25 09:40:00	\N	\N	28	0	\N	919
407167	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Nouveaux territoires du sport	MI Nouveaux territoires du sport	2019-09-25 14:30:00	2019-09-25 15:30:00	\N	\N	4	0	\N	\N
407172	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Nouveaux territoires du sport	MI Nouveaux territoires du sport	2019-09-25 15:30:00	2019-09-25 16:30:00	\N	\N	3	0	\N	\N
410829	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	PLF 2020 - Pouvoirs publics - Déplacement au Conseil constitutionnel	PLF 2020 - Pouvoirs publics - Déplacement au Conseil constitutionnel	2019-10-09 11:00:00	2019-10-09 12:00:00	\N	\N	1	0	\N	\N
411758	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition difficultés de recrutement et évolution des métiers	Audition difficultés de recrutement et évolution des métiers - APEC	2019-10-08 10:00:00	2019-10-08 11:25:00	\N	\N	1	0	\N	\N
411760	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion conjointe avec le Groupe d'étude sur le numérique	Réunion conjointe avec le Groupe d'étude sur le numérique - " Comment garantir l'accès des PME à des réseaux et services	2019-10-08 15:00:00	2019-10-08 18:00:00	2019-10-09 10:07:36	\N	5	0	\N	\N
413958	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJLF pour 2020 - P 105	PJLF pour 2020 - P 105	2019-10-07 10:00:00	2019-10-07 11:00:00	\N	\N	1	0	\N	\N
417294	DELEGATION	DEPLACEMENT	\N	\N	ENTREPRISES	Déplacement à Citéco	Déplacement à Citéco, Cité de l'Economie et de la Monnaie	2019-10-16 11:30:00	2019-10-16 15:00:00	\N	\N	14	0	\N	\N
417312	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition difficultés de recrutement et évolution des métiers	Audition difficultés de recrutement et évolution des métiers - DARES	2019-10-17 09:00:00	2019-10-17 10:00:00	\N	\N	2	0	\N	\N
417316	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition difficultés de recrutement et évolution des métiers	Audition difficultés de recrutement et évolution des métiers - Entreprise & Personnel	2019-10-17 10:00:00	2019-10-17 11:00:00	\N	\N	2	0	\N	\N
417322	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition difficultés de recrutement et évolution des métiers	Audition difficultés de recrutement et évolution des métiers - CEREQ	2019-10-17 11:00:00	2019-10-17 12:00:00	\N	\N	1	0	\N	\N
417472	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution plastique	Audition rapporteurs Pollution plastique (Table ronde Cosmétiques)	2019-11-05 14:30:00	2019-11-05 16:15:00	\N	\N	2	0	\N	\N
420660	ETUDES	AUCUNE	\N	\N	\N	GE numérique	\N	2019-10-22 15:30:00	2019-10-22 19:00:00	\N	\N	6	0	\N	1008
420667	ETUDES	AUCUNE	\N	\N	\N	GE numérique	\N	2019-10-23 16:30:00	2019-10-23 17:30:00	\N	\N	2	0	\N	1008
422949	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2020 - Asile, immigration, intégration et nationalité	\N	2019-10-30 14:00:00	2019-10-30 15:00:00	\N	\N	1	0	\N	\N
422951	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2020 - Mission Immigration, asile et intégration	\N	2019-10-30 16:30:00	2019-10-30 17:15:00	\N	\N	2	0	\N	\N
422954	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2020 - Mission Relations avec les collectivités territoriales	\N	2019-10-29 15:15:00	2019-10-29 17:00:00	\N	\N	2	0	\N	\N
426642	ETUDES	AUCUNE	\N	\N	\N	Réunion examen PJLF 2020	Réunion examen PJLF 2020	2019-11-13 14:10:00	2019-11-13 14:40:00	\N	\N	2	0	\N	998
433554	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution plastique	Audition rapporteurs Pollution plastique - Première table ronde avec chercheurs américains	2019-12-11 09:00:00	2019-12-11 12:00:00	\N	\N	2	0	\N	\N
433558	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution plastique 	Audition rapporteurs Pollution plastique  - Seconde table ronde avec chercheurs américains	2019-12-11 14:00:00	2019-12-11 16:15:00	\N	\N	2	0	\N	\N
449162	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2020-01-28 14:20:00	2020-01-28 14:55:00	\N	\N	21	0	\N	\N
475047	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule Énergie - Commission de régulation de l'énergie	\N	2020-06-14 18:00:00	2020-06-14 19:00:00	\N	\N	5	0	\N	\N
445784	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière	Réunion plénière	2020-01-16 08:30:00	2020-01-16 10:00:00	2020-01-16 14:17:36	\N	14	0	\N	\N
445815	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Table ronde sur les difficultés de recrutement et la formation	" Formateurs et employeurs face aux défis du recrutement et de l'évolution des métiers"	2020-01-16 10:00:00	2020-01-16 12:25:00	2020-01-16 14:24:13	\N	7	0	\N	\N
448728	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI  Coopération France Russie	RI Coopération France Russie	2020-01-23 10:15:00	2020-01-23 11:15:00	\N	\N	1	0	\N	\N
456200	DELEGATION	DEPLACEMENT	\N	\N	PROS	Salon de l'agriculture	Visite du salon de l'agriculture	2020-02-27 08:30:00	2020-02-27 11:30:00	\N	\N	4	0	\N	\N
424936	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-11-13 09:30:00	2019-11-13 12:00:00	2019-11-13 14:47:19	2019-11-13 14:50:26	46	1	\N	\N
437428	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PLJ & PJLO Article 13 - PPL Haine sur internet - Rapports et textes de la commission	PLJ & PJLO Article 13 - PPL Haine sur internet - Rapports et textes de la commission	2019-12-11 10:20:00	2019-12-11 12:30:00	2019-12-11 17:34:21	2019-12-12 16:22:17	36	0	\N	\N
466584	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi urgence Covid-19 - Prisons et autres lieux privatifs de liberté	\N	2020-04-24 10:45:00	2020-04-24 11:45:00	\N	\N	5	0	\N	\N
466594	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi urgence Covid-19 - Juridictions judiciaires et administratives	Audition du Conseil d'État	2020-04-23 09:30:00	2020-04-23 10:30:00	\N	\N	3	0	\N	\N
470470	MISSION	AUDRAP	\N	ILLECTRONISM	\N	Audition de l'Agence nationale de la Cohésion des territoires (ANCT)	Audition de l'Agence nationale de la Cohésion des territoires (ANCT)	2020-05-28 10:00:00	2020-05-28 11:10:00	\N	\N	6	0	\N	\N
470492	MISSION	AUCUNE	\N	ILLECTRONISM	\N	Audition de l'Agence nationale de lutte contre l'illettrisme (ANLCI)	Audition de l'Agence nationale de lutte contre l'illettrisme (ANLCI)	2020-05-18 17:00:00	2020-05-18 18:30:00	2020-05-18 18:35:03	2020-05-19 18:17:45	13	0	\N	\N
470675	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule PME CAMF	Audition cellule PME commerce artisanat	2020-04-06 17:00:00	2020-04-06 18:00:00	\N	\N	8	0	\N	\N
470676	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule PME FDUC	Audition cellule PME commerce artisanat	2020-04-07 16:30:00	2020-04-07 17:30:00	\N	\N	4	0	\N	\N
470677	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule PME CAPEB	Audition cellule PME commerce artisanat	2020-04-08 17:00:00	2020-04-08 18:00:00	\N	\N	9	0	\N	\N
470678	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule PME MEDEF 77	\N	2020-04-09 10:30:00	2020-04-09 11:30:00	\N	\N	5	0	\N	\N
470679	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule PME CMA France	Audition cellule PME commerce artisanat	2020-04-09 17:00:00	2020-04-09 18:00:00	\N	\N	4	0	\N	\N
470680	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule PME Procos	Audition cellule PME commerce artisanat	2020-04-10 14:30:00	2020-04-10 15:45:00	\N	\N	6	0	\N	\N
470721	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PME FCD	Audition cellule PME commerce artisanat	2020-04-10 15:45:00	2020-04-10 16:45:00	\N	\N	7	0	\N	\N
470729	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule PME CPME	Audition cellule PME commerce artisanat	2020-04-14 14:00:00	2020-04-14 15:00:00	\N	\N	6	0	\N	\N
470730	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule PME Brasseurs de France	Audition cellule PME commerce artisanat	2020-04-16 10:30:00	2020-04-16 11:30:00	\N	\N	5	0	\N	\N
470731	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule PME CNCC	Audition cellule PME commerce artisanat	2020-04-16 14:00:00	2020-04-16 15:00:00	\N	\N	7	0	\N	\N
470732	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule PME U2P	\N	2020-04-16 17:30:00	2020-04-16 18:30:00	\N	\N	7	0	\N	\N
470733	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule PME CGT commerce	Audition cellule PME commerce artisanat	2020-04-17 14:30:00	2020-04-17 15:45:00	\N	\N	7	0	\N	\N
470770	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule PME CFDT commerce	Audition cellule PME commerce artisanat	2020-04-17 15:45:00	2020-04-17 16:45:00	\N	\N	7	0	\N	\N
470778	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule PME Buralistes	Audition cellule PME commerce artisanat	2020-04-22 16:30:00	2020-04-22 17:30:00	\N	\N	4	0	\N	\N
470779	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule PME UNAPL	Audition cellule PME commerce artisanat	2020-04-27 15:00:00	2020-04-27 16:00:00	\N	\N	3	0	\N	\N
470780	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule PME FNAE	Audition cellule PME commerce artisanat	2020-05-04 10:10:00	2020-05-04 11:00:00	\N	\N	3	0	\N	\N
470792	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition GT Agriculteurs en détresse	Audition GT Agriculteurs en détresse	2020-04-06 15:00:00	2020-04-06 16:00:00	\N	\N	5	0	\N	\N
470814	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Disp. urgentes face à  l'épidémie de covid-19 - SOC ("Urgence 3")	\N	2020-05-14 09:45:00	2020-05-14 10:45:00	\N	\N	8	0	\N	\N
470815	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Disp.	\N	2020-05-14 11:00:00	2020-05-14 12:05:00	\N	\N	7	0	\N	\N
470816	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Disp. urgentes face à  l'épidémie de covid-19 - SOC ("Urgence 3")	\N	2020-05-14 15:00:00	2020-05-14 15:50:00	\N	\N	5	0	\N	\N
470817	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Disp. urgentes face à  l'épidémie de covid-19 - SOC ("Urgence 3")	\N	2020-05-14 16:15:00	2020-05-14 17:00:00	\N	\N	4	0	\N	\N
470827	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Examen de deux rapports pour avis, avec amendements au fond, et d'un rapport d'information	Examen de deux rapports pour avis, avec amendements au fond, et d'un rapport d'information	2020-05-20 08:30:00	2020-05-20 11:10:00	2020-05-20 14:52:34	2020-05-20 15:16:46	45	2	\N	\N
470891	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi Covid-19 - Administration, collectivités, fonction publique	\N	2020-04-23 17:00:00	2020-04-23 18:00:00	\N	\N	5	0	\N	\N
470897	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi Covid-19 - Administration, collectivités, fonction publique	\N	2020-04-23 18:00:00	2020-04-23 19:30:00	\N	\N	3	0	\N	\N
470901	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi Covid-19 - Administration, collectivités, fonction publique	\N	2020-04-28 15:30:00	2020-04-28 16:15:00	\N	\N	5	0	\N	\N
470907	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi Covid-19 - Administration, collectivités, fonction publique	\N	2020-04-28 16:15:00	2020-04-28 17:00:00	\N	\N	6	0	\N	\N
470914	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi Covid-19 - Administration, collectivités, fonction publique	\N	2020-04-29 16:30:00	2020-04-29 17:30:00	\N	\N	3	0	\N	\N
470918	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi Covid-19 - Administration, collectivités, fonction publique	\N	2020-04-29 17:30:00	2020-04-29 18:15:00	\N	\N	2	0	\N	\N
470921	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi Covid-19 - Administration, collectivités, fonction publique	\N	2020-04-30 15:15:00	2020-04-30 16:00:00	\N	\N	3	0	\N	\N
470925	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi Covid-19 - Administration, collectivités, fonction publique	\N	2020-05-06 14:00:00	2020-05-06 15:00:00	\N	\N	5	0	\N	\N
470931	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi Covid-19 - Administration, collectivités, fonction publique	\N	2020-05-11 17:00:00	2020-05-11 18:00:00	\N	\N	3	0	\N	\N
470935	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi Covid-19 - Administration, collectivités, fonction publique	\N	2020-05-12 14:00:00	2020-05-12 15:00:00	\N	\N	7	0	\N	\N
470943	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi Covid-19 - Administration, collectivités, fonction publique	\N	2020-05-14 15:00:00	2020-05-14 16:00:00	\N	\N	6	0	\N	\N
471018	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi Covid-19 - Administration, collectivités, fonction publique	\N	2020-05-18 16:00:00	2020-05-18 17:00:00	\N	\N	3	0	\N	\N
471030	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Dispositions urgentes face à l'épidémie de covid-19	\N	2020-05-15 18:00:00	2020-05-15 18:40:00	\N	\N	1	0	\N	\N
471368	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Création de Points d'accueil pour soins immédiats	\N	2020-05-19 09:30:00	2020-05-19 10:45:00	\N	\N	4	0	\N	\N
471373	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Création de Points d'accueil pour soins immédiats	\N	2020-05-19 15:30:00	2020-05-19 16:45:00	\N	\N	2	0	\N	\N
471467	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-05-20 09:00:00	2020-05-20 11:15:00	2020-05-21 09:05:37	2020-05-25 10:19:41	33	0	\N	\N
471500	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Enjeux sanitaires - Audition syndicats infirmiers (Mme Deroche)	\N	2020-05-28 17:00:00	2020-05-28 18:15:00	\N	\N	4	0	\N	\N
471547	DELEGATION	AUCUNE	\N	\N	DSOM	Table ronde sur le transport aérien à destination des outre-mer	\N	2020-05-19 17:00:00	2020-05-19 19:55:00	\N	\N	16	0	\N	\N
471568	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-05-20 11:20:00	2020-05-20 13:10:00	2020-05-21 09:55:14	2020-05-25 10:19:37	28	0	\N	\N
459636	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2020-01-16 09:30:00	2020-01-16 12:15:00	\N	\N	1	0	\N	\N
471687	DELEGATION	AUCUNE	\N	\N	COLTER	Table ronde ARS + rapport inflation immobilier	\N	2020-05-28 09:30:00	2020-05-28 11:50:00	2020-05-28 12:22:55	\N	15	0	\N	\N
472200	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - Université de Versailles-Saint-Quentin-en-Yvelines	Audition Pollution plastique - Université de Versailles-Saint-Quentin-en-Yvelines	2020-05-26 09:00:00	2020-05-26 10:30:00	\N	\N	2	0	\N	\N
386236	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-06-12 10:00:00	2019-06-12 11:05:00	2019-06-12 11:26:11	2019-06-12 16:55:38	42	0	\N	\N
386250	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJLR pour 2018 - Aide publique au développement - DB	PJLR pour 2018 - Aide publique au développement - DB	2019-06-04 14:30:00	2019-06-04 15:45:00	\N	\N	2	0	\N	\N
386291	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Conseillers techniques et sportifs	Conseillers techniques et sportifs	2019-06-05 11:30:00	2019-06-05 13:00:00	\N	\N	5	0	\N	\N
396521	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion commission des lois	\N	2019-07-02 10:00:00	2019-07-02 10:05:00	2019-07-02 10:18:07	2019-07-02 16:18:48	9	0	\N	\N
398226	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2019-06-19 14:30:00	2019-06-19 17:10:00	\N	\N	3	0	\N	\N
398563	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition Mission SILT	\N	2019-07-09 14:30:00	2019-07-09 15:40:00	\N	\N	2	0	\N	\N
398603	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Audition de M. Jean-Luc Dermarty, ancien directeur général du commerce à la Commission	\N	2019-07-09 15:15:00	2019-07-09 17:00:00	\N	\N	0	0	\N	\N
399329	MISSION	AUCUNE	\N	SIDERURGIE	\N	Examen et adoption du rapport de la mission	\N	2019-07-09 17:55:00	2019-07-09 19:30:00	2019-07-10 10:24:55	2019-07-11 11:27:30	14	0	\N	\N
401713	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Polynésie française PPL Communes nouvelles   PJL Collectivité européenne d'Alsace	PPL Polynésie française & PPL Communes nouvelles (rapports et textes)-  PJL Collectivité européenne d'Alsace (C¨MP)	2019-07-18 10:35:00	2019-07-18 11:40:00	2019-07-18 12:48:23	2019-07-18 17:38:47	19	0	\N	\N
401714	COM_PERMANENTE	AUTRE	\N	SOCI	\N	réunion plénière	\N	2019-07-17 09:05:00	2019-07-17 11:28:00	2019-07-17 17:13:10	2019-07-17 18:22:02	25	0	\N	\N
402874	COM_ENQUETE	PLENIERE	\N	SOUVERAINETE	\N	C.E. "Souverainté numérique"	C.E. "Souveraineté numérique"	2019-07-18 14:15:00	2019-07-18 15:00:00	2019-07-19 09:37:10	2019-07-19 12:34:46	3	0	\N	\N
402878	COM_ENQUETE	PLENIERE	\N	SOUVERAINETE	\N	C.E. "Souveraineté numérique"	C.E. "Souveraineté numérique"	2019-07-18 16:00:00	2019-07-19 17:30:00	2019-07-19 09:40:57	2019-07-19 12:34:47	5	0	\N	\N
404558	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions PJL Économie circulaire	\N	2019-07-24 09:30:00	2019-07-24 12:30:00	\N	\N	2	0	\N	\N
404561	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Engagements financiers de l'État - Économiste	PLF pour 2020 - Engagements financiers de l'État - Économiste	2019-07-24 17:00:00	2019-07-24 18:00:00	\N	\N	1	0	\N	\N
404563	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions PJL Économie circulaire	\N	2019-07-22 09:30:00	2019-07-22 10:00:00	\N	\N	2	0	\N	\N
404568	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions Mme de CIDRAC	\N	2019-07-22 14:30:00	2019-07-22 18:30:00	\N	\N	1	0	\N	\N
404570	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions PJL Économie circulaire	\N	2019-07-23 09:30:00	2019-07-23 12:30:00	\N	\N	2	0	\N	\N
404573	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Économie circulaire - Auditions Mme de Cidrac 	\N	2019-07-23 15:00:00	2019-07-23 16:45:00	\N	\N	1	0	\N	\N
404574	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Économie circulaire - Auditions Mme de Cidrac 	\N	2019-07-24 14:30:00	2019-07-24 17:15:00	\N	\N	3	0	\N	\N
417253	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - AEE - MEAE - Institut français de Paris	PLF pour 2020 - AEE - MEAE - Institut français de Paris	2019-10-18 09:30:00	2019-10-18 10:30:00	\N	\N	1	0	\N	\N
417255	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - AEE - MEAE - Campus France	PLF pour 2020 - AEE - MEAE - Campus France	2019-10-18 11:00:00	2019-10-18 12:00:00	\N	\N	1	0	\N	\N
417257	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Avis Agriculture - Auditions MM. Duplomb, Tissot et Mme Férat	PJLF 2020 - Avis Agriculture - Auditions MM. Duplomb, Tissot et Mme Férat	2019-10-15 15:00:00	2019-10-15 15:30:00	\N	\N	6	0	\N	\N
417264	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Avis Agriculture - Auditions MM. Duplomb, Tissot et Mme Férat	PJLF 2020 - Avis Agriculture - Auditions MM. Duplomb, Tissot et Mme Férat	2019-10-15 16:00:00	2019-10-15 16:30:00	\N	\N	5	0	\N	\N
417270	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Enseignement scolaire - DGESCO - Cabinet Ministre Éducation	PLF pour 2020 - Enseignement scolaire - DGESCO - Cabinet Ministre Éducation	2019-10-17 14:30:00	2019-10-17 16:30:00	\N	\N	1	0	\N	\N
417271	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Avis Agriculture - Auditions MM. Duplomb, Tissot et Mme Férat	PJLF 2020 - Avis Agriculture - Auditions MM. Duplomb, Tissot et Mme Férat	2019-10-15 16:45:00	2019-10-15 17:15:00	\N	\N	4	0	\N	\N
417277	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Avis Agriculture - Auditions MM. Duplomb, Tissot et Mme Férat	PJLF 2020 - Avis Agriculture - Auditions MM. Duplomb, Tissot et Mme Férat	2019-10-15 18:15:00	2019-10-15 19:00:00	\N	\N	3	0	\N	\N
417281	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Avis Agriculture - Auditions MM. Duplomb, Tissot et Mme Férat	PJLF 2020 - Avis Agriculture - Auditions MM. Duplomb, Tissot et Mme Férat	2019-10-16 16:30:00	2019-10-16 17:30:00	\N	\N	3	0	\N	\N
417285	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Avis Agriculture - Auditions MM. Duplomb, Tissot et Mme Férat	PJLF 2020 - Avis Agriculture - Auditions MM. Duplomb, Tissot et Mme Férat	2019-10-16 17:30:00	2019-10-16 18:30:00	\N	\N	3	0	\N	\N
417289	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Avis Agriculture - Auditions MM. Duplomb, Tissot et Mme Férat	PJLF 2020 - Avis Agriculture - Auditions MM. Duplomb, Tissot et Mme Férat	2019-10-16 18:30:00	2019-10-16 19:00:00	\N	\N	3	0	\N	\N
417293	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Avis Économie - MM. Serge Babary et Martial Bourquin	PJLF 2020 - Avis Économie - MM. Serge Babary et Martial Bourquin	2019-10-17 10:00:00	2019-10-17 10:55:00	\N	\N	2	0	\N	\N
417311	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Avis Économie - Auditions M. Bourquin	PJLF 2020 - Auditions Économie - M. Bourquin	2019-10-17 11:05:00	2019-10-17 12:00:00	\N	\N	1	0	\N	\N
417314	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Avis Économie - Auditions M. Bourquin	PJLF 2020 - Auditions Économie - M. Bourquin	2019-10-17 12:00:00	2019-10-17 12:45:00	\N	\N	1	0	\N	\N
385587	COM_PERMANENTE	AUTRE	\N	LOIS	\N	\N	\N	2019-06-05 09:15:00	2019-06-05 10:25:00	2019-06-05 14:21:58	2019-06-05 16:52:17	39	0	\N	\N
386234	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-06-12 09:35:00	2019-06-12 10:00:00	2019-06-12 11:26:24	2019-06-12 16:55:37	42	0	\N	\N
391317	CMP	AUTRE	\N	ECOLE	\N	PJL Pour une école de la confiance	PJL Pour une école de la confiance	2019-06-13 13:05:00	2019-06-13 16:10:00	\N	\N	13	0	\N	\N
417321	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	plf 2020 - Crédits enseignement agricole	plf 2020 - Crédits enseignement agricole	2019-10-17 16:45:00	2019-10-17 18:30:00	\N	\N	1	0	\N	\N
417391	ETUDES	AUCUNE	\N	\N	\N	GE numérique	GE numérique	2019-10-08 15:00:00	2019-10-08 18:00:00	\N	\N	5	0	\N	1008
417397	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	plf 2020 - Crédits enseignement agricole	\N	2019-10-21 09:45:00	2019-10-21 12:00:00	\N	\N	1	0	\N	\N
417403	ETUDES	AUCUNE	\N	\N	\N	GE numérique	\N	2019-10-16 18:15:00	2019-10-16 19:10:00	\N	\N	8	0	\N	1008
422697	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Sites naturels - Auditions Jérôme Bignon	\N	2019-10-29 17:30:00	2019-10-29 18:15:00	\N	\N	3	0	\N	\N
423843	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Carte Vitale biométrique	\N	2019-11-05 10:00:00	2019-11-05 11:00:00	\N	\N	3	0	\N	\N
423844	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Carte Vitale biométrique	\N	2019-11-05 16:00:00	2019-11-05 17:00:00	\N	\N	2	0	\N	\N
423852	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2019-11-12 13:35:00	2019-11-12 15:39:00	2019-11-12 17:35:06	2019-11-13 14:50:30	44	1	\N	\N
423891	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PLFSS pour 2020 - Examen des amendements de séance	\N	2019-11-12 19:35:00	2019-11-12 20:10:00	2019-11-13 18:55:52	2019-11-14 15:31:49	35	1	\N	\N
423895	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Mission Santé	\N	2019-11-05 15:45:00	2019-11-05 18:00:00	\N	\N	1	0	\N	\N
423897	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJLF Budget 2020 - Outre-mer	\N	2019-11-20 14:00:00	2019-11-20 15:00:00	\N	\N	1	0	\N	\N
423923	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-11-12 14:15:00	2019-11-12 16:20:00	2019-11-12 16:20:06	2019-11-12 17:34:05	39	0	\N	\N
423924	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-11-12 17:35:00	2019-11-12 19:25:00	2019-11-12 19:25:40	2019-11-13 14:50:32	32	0	\N	\N
423925	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-11-13 09:35:00	2019-11-13 11:35:00	2019-11-13 12:12:15	2019-11-13 14:50:25	46	1	\N	\N
423927	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-11-13 16:30:00	2019-11-13 18:20:00	2019-11-15 16:14:43	2019-11-15 16:50:26	30	0	\N	\N
424071	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Audiovisuel	PLF 2020 - Crédits Audiovisuel	2019-11-06 14:00:00	2019-11-06 15:00:00	\N	\N	1	0	\N	\N
424661	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2020 - Travail et emploi	\N	2019-11-05 12:00:00	2019-11-05 12:50:00	\N	\N	2	0	\N	\N
424679	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteurs	Adhésion de l'UE à la CEDH - Audition CEDH	2019-11-06 16:10:00	2019-11-06 17:35:00	\N	\N	2	0	\N	\N
444712	GIA	AUCUNE	\N	\N	\N	entretien avec S.E. M. Buddhi K. Athauda, ambassadeur du Sri Lanka	\N	2020-01-15 08:30:00	2020-01-15 10:00:00	\N	\N	2	0	550	\N
444719	GIA	AUCUNE	\N	\N	\N	bilan des activités 2019 et perspectives 2020	\N	2020-01-14 14:30:00	2020-01-14 15:30:00	\N	\N	7	0	661	\N
445809	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions de M. Montaugé et Mme Noël-PPL Libre choix du consommateur dans le cyberespace	\N	2020-01-15 13:00:00	2020-01-15 14:00:00	\N	\N	2	0	\N	\N
445814	COM_PERMANENTE	AUDRAP	\N	FINC	\N	CVN Accord fiscal France-Botswana - DLF	CVN Accord fiscal France-Botswana - DLF	2020-01-16 10:00:00	2020-01-16 10:30:00	\N	\N	1	0	\N	\N
445862	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Implantation des services de l'État dans les territoires - DGFiP	Contrôle 2019 - Implantation des services de l'État dans les territoires - DGFiP	2020-01-14 15:00:00	2020-01-14 16:00:00	\N	\N	2	0	\N	\N
448267	ETUDES	AUTRE	\N	\N	\N	Audition plénière CNIEL	\N	2020-01-21 15:00:00	2020-01-21 15:45:00	\N	\N	2	0	\N	918
448270	COM_ENQUETE	AUTRE	\N	LUBRIZOL	\N	Réunion de commission	\N	2020-01-23 09:05:00	2020-01-23 10:15:00	2020-01-24 16:20:37	2020-01-24 16:39:37	6	0	\N	\N
448283	COM_PERMANENTE	PLEIN_NON_JO	\N	CDD	\N	Mission d'information sur l'empreinte environnementale du numérique	Réunion constitutive - Programme des travaux	2020-01-22 16:30:00	2020-01-22 17:00:00	\N	\N	11	0	\N	\N
448370	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2020-01-29 09:35:00	2020-01-29 11:20:00	2020-01-29 12:19:52	2020-01-29 18:04:05	35	0	\N	\N
448617	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Inde	\N	2020-01-21 10:00:00	2020-01-21 11:00:00	\N	\N	2	0	\N	\N
448623	DELEGATION	AUCUNE	\N	\N	COLTER	Audition F. Rose, préfet, secrétaire du CIPDR	\N	2020-01-30 09:30:00	2020-01-30 11:00:00	2020-01-30 12:03:33	\N	12	0	\N	\N
448744	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2020-02-18 09:31:00	2020-02-18 12:42:00	\N	\N	39	0	\N	\N
448745	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Politique familiale	Débat Politique familiale	2020-02-18 14:30:00	2020-02-18 16:02:00	\N	\N	86	0	\N	\N
448746	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Irresponsabilité pénale	Débat Irresponsabilité pénale	2020-02-18 16:07:00	2020-02-18 17:23:00	\N	\N	76	0	\N	\N
448747	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Risques naturels majeurs outre-mer	Débat Risques naturels majeurs outre-mer	2020-02-18 17:23:00	2020-02-18 19:02:00	\N	\N	60	0	\N	\N
448748	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Maintien de l'ordre	Débat Maintien de l'ordre	2020-02-18 19:03:00	2020-02-18 20:49:00	\N	\N	57	0	\N	\N
448750	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2020-02-19 15:01:00	2020-02-19 16:15:00	\N	\N	292	0	\N	\N
448751	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Choix consommateur dans le cyberespace	PPL Choix consommateur dans le cyberespace	2020-02-19 16:32:00	2020-02-19 19:12:00	\N	\N	73	0	\N	\N
448753	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Action du Gouvernement en faveur de l'agriculture	Débat Action du Gouvernement en faveur de l'agriculture	2020-02-20 14:30:00	2020-02-20 16:07:00	\N	\N	43	0	\N	\N
448754	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat politique spatiale de l'UE	Débat politique spatiale de l'UE	2020-02-20 16:11:00	2020-02-20 17:39:00	\N	\N	27	0	\N	\N
448755	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Parquet européen et justice pénale spécialisée	PJL Parquet européen et justice pénale spécialisée	2020-02-25 14:32:00	2020-02-25 19:29:00	\N	\N	120	0	\N	\N
448757	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2020-02-26 15:00:00	2020-02-26 16:12:00	\N	\N	280	0	\N	\N
469642	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Enjeux sanitaires - Audition CNAM (Mme Deroche)	\N	2020-05-25 15:45:00	2020-05-25 16:45:00	\N	\N	1	0	\N	\N
423926	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-11-13 11:35:00	2019-11-13 12:05:00	2019-11-13 12:11:43	2019-11-13 14:50:24	47	1	\N	\N
448760	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	EV PPL Prestation de compensation du handicap	EV PPL Prestation de compensation du handicap	2020-02-26 16:30:00	2020-02-26 17:19:00	\N	\N	0	0	\N	\N
448762	SEANCE_PLENIERE	DEBAT	\N	\N	\N	CMP PJLO PJL article 13 Constitution et droits sur internet	CMP PJLO PJL article 13 Constitution et droits sur internet	2020-02-26 19:30:00	2020-02-26 20:25:00	\N	\N	29	0	\N	\N
448769	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2020-03-03 09:30:00	2020-03-03 13:00:00	\N	\N	40	0	\N	\N
448770	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	1321	\N	\N	Explications de vote PJL Parquet européen et justice  pénale spécialisée	Explications de vote PJL Parquet européen et justice  pénale spécialisée	2020-03-03 14:30:00	2020-03-03 15:45:00	\N	\N	279	0	\N	\N
448771	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Accélération et simplification de l'action publique	PJL Accélération et simplification de l'action publique	2020-03-03 18:00:00	2020-03-03 20:00:00	\N	\N	90	0	\N	\N
448772	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Accélération et simplification de l'action publique	PJL Accélération et simplification de l'action publique	2020-03-03 21:30:00	2020-03-04 01:20:00	\N	\N	78	0	\N	\N
448773	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2020-03-04 15:00:00	2020-03-04 16:25:00	\N	\N	279	0	\N	\N
448774	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	EV PPL Transparence de l'information produits agricoles et alimentaires	EV PPL Transparence de l'information produits agricoles et alimentaires	2020-03-04 16:35:00	2020-03-04 17:20:00	\N	\N	46	0	\N	\N
448777	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Accélération et simplification de l'action publique	PJL Accélération et simplification de l'action publique	2020-03-05 10:30:00	2020-03-05 13:00:00	\N	\N	64	0	\N	\N
448778	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Accélération et simplification de l'action publique	PJL Accélération et simplification de l'action publique	2020-03-05 14:30:00	2020-03-05 19:05:00	\N	\N	51	0	\N	\N
448847	GIA	AUCUNE	\N	\N	\N	Entretien avec Xavier Breton	Entretien avec Xavier Breton, député, président du GEVI France-Vatican de l'Assemblée nationale	2020-01-28 13:00:00	2020-01-28 14:30:00	\N	\N	1	0	629	\N
449403	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2020-01-29 09:32:00	2020-01-29 11:59:00	2020-01-30 11:30:33	2020-01-30 12:07:58	33	2	\N	\N
449505	GIA	AUCUNE	\N	\N	\N	réunion du groupe	petit déjeuner de travail sur les relations transfrontalières franco-luxembourgeoises	2020-01-29 08:30:00	2020-01-29 09:30:00	\N	\N	10	0	580	\N
391304	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Transformation de la fonction publique	\N	2019-06-11 17:45:00	2019-06-11 19:00:00	\N	\N	2	0	\N	\N
397929	MISSION	AUCUNE	\N	MARITIME	\N	Réunion constitutive de la MCI Sauvetage en mer	Réunion constitutive de la MCI Sauvetage en mer	2019-07-09 15:50:00	2019-07-09 16:35:00	2019-07-11 11:29:30	2019-07-11 11:32:35	17	0	\N	\N
397947	COM_PERMANENTE	AUTRE	\N	FINC	\N	Désignation CMP PJLR2018-Examen Rapport DOFP et Contrôles GFPRH et Défense	Désignation CMP PJLR2018-Examen Rapport DOFP et Contrôles GFPRH et Défense	2019-07-10 09:35:00	2019-07-10 11:40:00	2019-07-12 15:00:45	2019-07-12 16:13:15	31	0	\N	\N
397993	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Examen du rapport  d'information du groupe de travail sur la justice prud'homale	Examen du rapport  d'information du groupe de travail sur la justice prud'homale	2019-07-10 09:30:00	2019-07-10 10:53:00	2019-07-10 14:16:38	2019-07-11 11:26:41	59	0	\N	\N
397995	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Examen du rapport d'information sur la thanatopraxie	\N	2019-07-10 11:02:00	2019-07-10 11:58:00	2019-07-10 14:20:13	2019-07-11 11:26:35	22	0	\N	\N
397999	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion du 20190709	\N	2019-07-09 09:45:00	2019-07-09 10:05:00	2019-07-09 10:21:43	2019-07-09 14:20:54	8	0	\N	\N
398200	GIA	AUCUNE	\N	\N	\N	Rencontre avec M. Fabrice Balanche, géorgaphe, spécialiste de la Syrie	Rencontre avec M. Fabrice Balanche, géorgaphe, spécialiste de la Syrie	2019-06-27 11:00:00	2019-06-27 13:30:00	\N	\N	2	0	644	\N
405323	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	\N	\N	2019-09-18 10:00:00	2019-09-18 11:00:00	\N	\N	0	0	\N	\N
405327	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2019-09-25 09:30:00	2019-09-25 12:25:00	2019-09-25 15:25:04	2019-09-25 15:38:52	38	0	\N	\N
469643	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Enjeux sanitaires - Audition JY GRALL	\N	2020-05-25 17:00:00	2020-05-25 18:00:00	\N	\N	3	0	\N	\N
405333	COM_PERMANENTE	AUTRE	\N	CDD	\N	Examen des motions et amendements de séance - PJL Économie circulaire	\N	2019-09-24 14:15:00	2019-09-24 14:35:00	2019-09-25 16:19:18	2019-09-26 16:34:45	32	0	\N	\N
405334	COM_EURO	AUTRE	\N	AFEU	\N	Communication - Conférences interparlementaires	\N	2019-09-26 09:50:00	2019-09-26 10:30:00	2019-09-26 10:41:36	2019-09-26 16:36:53	7	0	\N	\N
405335	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-09-25 09:35:00	2019-09-25 11:00:00	2019-09-25 16:19:52	2019-09-26 16:34:43	34	0	\N	\N
405338	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	\N	\N	2019-09-25 17:00:00	2019-09-25 18:30:00	\N	\N	0	0	\N	\N
405339	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	Réunion du 25 septembre 2019	\N	2019-09-25 17:00:00	2019-09-25 18:30:00	\N	\N	0	0	\N	\N
405340	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	\N	\N	2019-09-26 08:30:00	2019-09-26 09:30:00	\N	\N	0	0	\N	\N
405341	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	Réunion du 26 septembre 2019	\N	2019-09-26 08:30:00	2019-09-26 09:30:00	\N	\N	0	0	\N	\N
407378	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion pléière CATDD	\N	2019-10-02 09:50:00	2019-10-02 12:10:00	2019-10-02 13:56:09	2019-10-02 16:04:07	35	0	\N	\N
407391	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2020 - Audition de MM. Bruno LE MAIRE, Gérald DARMANIN et Olivier DUSSOPT	PLF pour 2020 - Audition de MM. Bruno LE MAIRE, Gérald DARMANIN et Olivier DUSSOPT	2019-10-01 18:05:00	2019-10-01 20:25:00	2019-10-02 10:20:53	2019-10-02 16:04:02	41	0	\N	\N
407418	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2020 et PLFSS pour 2020 - Auditions Didier MIGAUD PDT HCFP - Jérôme FOURNEL DGFiP	PLF pour 2020 et PLFSS pour 2020 - Auditions de M. Didier MIGAUD, président HCFP, avis HCFP et M. Jérôme FOURNEL DGFiP	2019-10-02 09:30:00	2019-10-02 12:50:00	2019-10-02 14:52:03	2019-10-02 16:04:06	34	0	\N	\N
407420	MISSION	AUCUNE	\N	MARITIME	\N	MCI Sauvetage en Mer - M. Thierry Coquil, Directeur des affaires maritimes	MCI Sauvetage en Mer - M. Thierry Coquil, Directeur des affaires maritimes	2019-10-02 14:00:00	2019-10-02 15:00:00	2019-10-02 15:01:01	2019-10-02 16:04:20	12	0	\N	\N
407449	DELEGATION	AUCUNE	\N	\N	211	Audition de Mme Michaëla Rusnac - Grenelle des violences conjugales	Audition de Mme Michaëla Rusnac - Grenelle des violences conjugales	2019-10-03 10:30:00	2019-10-03 11:40:00	2019-10-03 16:27:18	\N	22	0	\N	\N
416841	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion conjointe Délégation aux entreprises - Groupe d'étude sur le numérique	Réunion conjointe Délégation aux entreprises - Groupe d'étude sur le numérique - Audition ARCEP	2019-10-16 18:15:00	2019-10-16 19:10:00	2019-10-17 15:19:46	\N	8	0	\N	\N
417145	DELEGATION	AUCUNE	\N	\N	COLTER	Audition O. Dussopt, secrétaire d'Etat	\N	2019-10-30 13:30:00	2019-10-30 14:45:00	2019-10-30 16:09:15	\N	20	0	\N	\N
419132	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions PLF pour 2020 - avis AGTE	\N	2019-10-22 08:00:00	2019-10-22 12:45:00	\N	\N	2	0	\N	\N
419463	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Avis Agriculture - Auditions MM. Duplomb, Tissot et Mme Férat	PJLF 2020 - Avis Agriculture - Auditions MM. Duplomb, Tissot et Mme Férat	2019-10-22 15:45:00	2019-10-22 16:30:00	\N	\N	3	0	\N	\N
419464	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF pour 2020 - Avis Agriculture - Auditions MM. Duplomb, Tissot et Mme Férat	PJLF 2020 - Avis Agriculture - Auditions MM. Duplomb, Tissot et Mme Férat	2019-10-22 16:30:00	2019-10-22 17:00:00	\N	\N	3	0	\N	\N
419465	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Avis Agriculture - Auditions MM. Duplomb, Tissot et Mme Férat	PJLF 2020 - Avis Agriculture - Auditions MM. Duplomb, Tissot et Mme Férat	2019-10-22 17:00:00	2019-10-22 17:30:00	\N	\N	2	0	\N	\N
419466	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Avis Agriculture - Auditions MM. Duplomb, Tissot et Mme Férat	PJLF 2020 - Avis Agriculture - Auditions MM. Duplomb, Tissot et Mme Férat	2019-10-22 17:30:00	2019-10-22 18:00:00	\N	\N	2	0	\N	\N
419469	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Avis Agriculture - Auditions MM. Duplomb, Tissot et Mme Férat	Avis Agriculture - Auditions MM. Duplomb, Tissot et Mme Férat	2019-10-22 18:00:00	2019-10-22 19:30:00	\N	\N	2	0	\N	\N
419493	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Presse	PLF 2020 - Crédits Presse	2019-10-22 09:00:00	2019-10-22 10:00:00	\N	\N	2	0	\N	\N
419494	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Livre et Industries culturelles	PLF 2020 - Crédits Livre et Industries culturelles	2019-10-22 10:00:00	2019-10-22 11:30:00	\N	\N	1	0	\N	\N
419495	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Livre et Industries culturelles	PLF 2020 - Crédits Livre et Industries culturelles	2019-10-22 15:30:00	2019-10-22 16:30:00	\N	\N	1	0	\N	\N
419501	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	plf 2020 - Crédits enseignement agricole	plf 2020 - Crédits enseignement agricole	2019-10-21 16:15:00	2019-10-21 17:00:00	\N	\N	1	0	\N	\N
419503	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Jeunesse et vie associative	PLF 2020 - Crédits Jeunesse et vie associative	2019-10-22 16:00:00	2019-10-22 17:00:00	\N	\N	1	0	\N	\N
419804	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2020 - Avis juridictions administratives et juridictions financières	PLF pour 2020 - Avis juridictions administratives et juridictions financières	2019-10-22 17:00:00	2019-10-22 18:15:00	\N	\N	1	0	\N	\N
419854	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2019-10-23 14:00:00	2019-10-23 15:00:00	\N	\N	0	0	\N	\N
419889	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Avis Outre-Mer - Auditions M. Magras	PJLF 2020 - Avis Outre-Mer - Auditions M. Magras	2019-10-21 17:00:00	2019-10-21 18:00:00	\N	\N	1	0	\N	\N
443681	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-01-15 09:30:00	2020-01-15 11:20:00	2020-01-15 11:36:43	2020-01-15 11:48:56	39	0	\N	\N
443683	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-01-14 14:15:00	2020-01-14 14:30:00	2020-01-14 15:07:32	2020-01-14 17:36:54	18	0	\N	\N
443730	DELEGATION	AUDRAP	\N	\N	PROS	Audition de M. Benoît Bordat	\N	2020-02-04 16:30:00	2020-02-04 17:30:00	\N	\N	2	0	\N	\N
443731	COM_ENQUETE	PLENIERE	\N	LUBRIZOL	\N	Audition plénière	\N	2020-01-21 10:00:00	2020-01-21 11:20:00	2020-01-21 12:12:35	2020-01-21 14:23:37	10	0	\N	\N
443733	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2020-01-15 14:31:00	2020-01-15 14:43:00	2020-01-15 17:54:37	2020-01-16 12:14:58	38	0	\N	\N
450479	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 29 janvier 2020	Réunion du 29 janvier 2020	2020-01-29 13:35:00	2020-01-29 14:55:00	2020-01-29 16:34:23	2020-01-29 18:04:56	15	0	\N	\N
457399	GIA	AUCUNE	\N	\N	\N	Président de la commission européenne du Parlement de Géorgie	Entretien avec M. David Songulashvili, président de la commission de l'intégration européenne du Parlement de Géorgie	2020-01-22 16:00:00	2020-01-22 17:00:00	\N	\N	3	0	534	\N
405336	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-09-25 11:00:00	2019-09-25 11:35:00	2019-09-25 16:20:17	2019-09-26 16:34:40	35	0	\N	\N
419820	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2020 - Missions Défense - Outre-Mer - DAG et CCE	PLF pour 2020 - Missions Défense - Outre-Mer - DAG et CCE	2019-10-30 09:30:00	2019-10-30 12:15:00	2019-10-30 17:11:39	2019-10-30 17:49:36	49	0	\N	\N
457406	GIA	AUCUNE	\N	\N	\N	térieure des collectivités territoriales	Entretien avec Mme Christine Moro, ambassadeur, déléguée à l'action extérieure des collectivités territoriales	2020-02-19 08:30:00	2020-02-19 09:30:00	\N	\N	4	0	641	\N
472203	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - SRP	Audition Pollution plastique - SRP	2020-05-26 10:30:00	2020-05-26 12:15:00	\N	\N	2	0	\N	\N
472206	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - LNE	Audition Pollution plastique - LNE	2020-05-28 14:00:00	2020-05-28 15:00:00	\N	\N	2	0	\N	\N
472209	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - INRAE	Audition Pollution plastique - INRAE	2020-05-28 15:15:00	2020-05-28 16:15:00	\N	\N	2	0	\N	\N
472213	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - SYCTOM	Audition Pollution plastique - SYCTOM	2020-05-28 16:30:00	2020-05-28 17:50:00	\N	\N	2	0	\N	\N
472216	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - IFREMER	Audition Pollution plastique - IFREMER	2020-06-04 14:00:00	2020-06-04 16:15:00	\N	\N	2	0	\N	\N
472219	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - CNRS	Audition Pollution plastique - CNRS	2020-06-04 16:15:00	2020-06-04 17:05:00	\N	\N	2	0	\N	\N
472222	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - Reseaclons	Audition Pollution plastique - Reseaclons	2020-06-04 17:30:00	2020-06-04 19:15:00	\N	\N	2	0	\N	\N
472225	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - The Ocean Cleanup	Audition Pollution plastique - The Ocean Cleanup	2020-06-05 08:00:00	2020-06-05 09:30:00	\N	\N	2	0	\N	\N
472228	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - Groupe français des Polymères	Audition Pollution plastique - Groupe français des Polymères	2020-06-05 09:45:00	2020-06-05 11:15:00	\N	\N	2	0	\N	\N
472231	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - Schweitzer SAS	Audition Pollution plastique - Schweitzer SAS	2020-06-08 14:00:00	2020-06-08 15:00:00	\N	\N	2	0	\N	\N
472234	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - Innovation Plasturgie Composites	Audition Pollution plastique - Innovation Plasturgie Composites	2020-06-08 15:15:00	2020-06-08 16:15:00	\N	\N	2	0	\N	\N
472237	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - Université Paul Sabatier de Toulouse	Audition Pollution plastique - Université Paul Sabatier de Toulouse	2020-06-08 16:30:00	2020-06-08 18:00:00	\N	\N	2	0	\N	\N
472240	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - François-Michel LAMBERT, député	Audition Pollution plastique - François-Michel LAMBERT, député	2020-06-09 09:00:00	2020-06-09 10:00:00	\N	\N	2	0	\N	\N
472243	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - Ville de Paris	Audition Pollution plastique - Ville de Paris	2020-06-09 10:00:00	2020-06-09 12:00:00	\N	\N	2	0	\N	\N
472246	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - Ifremer Tahiti	Audition Pollution plastique - Ifremer Tahiti	2020-06-12 08:00:00	2020-06-12 09:00:00	\N	\N	2	0	\N	\N
472249	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - Yann WEHRLING, ambassadeur de France	Audition Pollution plastique - Yann WEHRLING, ambassadeur de France	2020-06-12 09:15:00	2020-06-12 10:15:00	\N	\N	2	0	\N	\N
472252	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - France chimie	Audition Pollution plastique - France chimie	2020-06-12 10:30:00	2020-06-12 12:30:00	\N	\N	2	0	\N	\N
472442	GIA	AUCUNE	\N	\N	\N	Entretien avec SEM CHEM Widhya, ambassadeur du Cambodge	Entretien avec SEM CHEM Widhya, ambassadeur du Cambodge	2020-05-26 11:00:00	2020-05-26 11:45:00	\N	\N	1	0	577	\N
472453	GIA	AUCUNE	\N	\N	\N	colloque 	La mer de Chine méridionale	2020-02-27 14:00:00	2020-02-27 19:00:00	\N	\N	2	0	626	\N
472456	GIA	AUCUNE	\N	\N	\N	Entretien	Entretien avec une délégation du groupe d'amitié Vietnam-France	2020-02-03 14:00:00	2020-02-03 15:00:00	\N	\N	3	0	626	\N
472733	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Pôle Emploi	\N	2020-06-08 17:15:00	2020-06-08 18:50:00	2020-06-08 20:41:51	\N	6	0	\N	\N
472986	COM_PERMANENTE	AUTRE	\N	CAE	\N	\N	\N	2020-06-03 11:50:00	2020-06-03 12:00:00	2020-06-05 18:18:21	2020-06-05 18:29:16	22	0	\N	\N
472987	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-06-03 09:00:00	2020-06-03 11:40:00	2020-06-03 15:15:10	2020-06-05 18:00:41	32	0	\N	\N
472990	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-06-04 15:00:00	2020-06-04 17:20:00	2020-06-04 17:24:12	2020-06-05 18:00:36	31	0	\N	\N
473071	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2020-06-03 16:15:00	2020-06-03 18:15:00	\N	\N	25	0	\N	\N
473398	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Alimentation durable-M. Stéphane LINOU	Covid-19-Alimentation durable-M. Stéphane LINOU	2020-05-11 09:05:00	2020-05-11 10:10:00	\N	\N	13	0	\N	\N
473411	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Alimentation durable-CESE	Covid-19-Alimentation durable-CESE	2020-05-12 15:00:00	2020-05-12 16:00:00	\N	\N	14	0	\N	\N
473417	COM_PERMANENTE	AUTRE	\N	FINC	\N	PPL n°402  Soutien entreprises - Examen amendements de séance	PPL n°402 (2019-2020) Soutien entreprises - Examen amendements de séance	2020-06-02 14:05:00	2020-06-02 14:20:00	2020-06-02 15:10:58	2020-06-02 18:30:18	15	0	\N	\N
473424	COM_PERMANENTE	AUTRE	\N	FINC	\N	Nominations article 13 - Audition de Mme Isabelle FALQUE-PIERROTIN, candidate PSDTE ANJ	Nominations article 13 - Audition de Mme Isabelle FALQUE-PIERROTIN, candidate PSDTE ANJ	2020-06-03 11:20:00	2020-06-03 12:40:00	2020-06-03 13:23:19	2020-06-05 18:29:11	25	0	\N	\N
473438	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Alimentation durable et locale-Terre de liens	Covid-19-Alimentation durable et locale-Terre de liens	2020-05-14 10:30:00	2020-05-14 11:30:00	\N	\N	15	0	\N	\N
473440	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Alimentation durable et locale-FNSEA	Covid-19-Alimentation durable et locale-FNSEA	2020-05-15 14:30:00	2020-05-15 15:45:00	\N	\N	14	0	\N	\N
473441	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Aménagement territoire-Association des maires ruraux de France	Covid-19-Aménagement territoire-Association des maires ruraux de France	2020-04-20 14:30:00	2020-04-20 15:40:00	\N	\N	15	0	\N	\N
473442	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Aménagement territoire-Association des maires de France	Covid-19-Aménagement territoire-Association des maires de France	2020-04-24 09:30:00	2020-04-24 10:30:00	\N	\N	13	0	\N	\N
473443	COM_PERMANENTE	AUDRAP	\N	CDD	\N	CCMSA	\N	2020-05-07 10:30:00	2020-05-07 11:30:00	\N	\N	5	0	\N	\N
473449	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Accès Santé-Groupe Chaîne thermale du Soleil	Covid-19-Accès Santé-Groupe Chaîne thermale du Soleil	2020-05-26 14:00:00	2020-05-26 14:40:00	\N	\N	7	0	\N	\N
473452	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Eau et biodiversité-Fédération professionnelle des entreprises de l'eau	Covid-19-Eau et biodiversité-Fédération professionnelle des entreprises de l'eau	2020-04-23 17:45:00	2020-04-23 18:45:00	\N	\N	1	0	\N	\N
473453	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Eau Biodiversité-Union internationale pour la conservation de la nature (UICN)	Covid-19-Eau Biodiversité-Union internationale pour la conservation de la nature (UICN)	2020-05-04 10:30:00	2020-05-04 11:30:00	\N	\N	9	0	\N	\N
473454	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Eau Biodiversité-Fédération nationale des collectivités concédantes et régies	Covid-19-Eau Biodiversité-Fédération nationale des collectivités concédantes et régies	2020-05-06 18:45:00	2020-05-06 19:45:00	\N	\N	4	0	\N	\N
473455	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Eau Biodiversité-Iddri	Covid-19-Eau Biodiversité-Iddri	2020-05-07 11:30:00	2020-05-07 13:00:00	\N	\N	10	0	\N	\N
473462	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Gestions des déchets - Amorce	Gestions des déchets - Amorce	2020-04-01 10:00:00	2020-04-01 10:45:00	\N	\N	2	0	\N	\N
473463	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Gestion des déchets-FEDEREC	Covid-19-Gestion des déchets-FEDEREC	2020-04-17 11:00:00	2020-04-17 12:10:00	\N	\N	21	0	\N	\N
380333	DELEGATION	AUCUNE	\N	\N	PROS	Point d'étape	Point d'étape sur l'actualisation du rapport "Une crise en quête de fin - Quand l'Histoire bégaie"	2019-06-06 08:30:00	2019-06-06 09:45:00	\N	\N	10	0	\N	\N
380626	MISSION	AUTRE	\N	TRANSPORTS	\N	Table ronde Ademe-Ifsttar-Réseau Action Climat	\N	2019-05-21 13:30:00	2019-05-21 15:15:00	2019-05-21 15:33:22	2019-05-21 17:55:14	13	0	\N	\N
384108	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion de commission	Audition médiateur du crédit	2019-05-29 09:20:00	2019-05-29 10:40:00	2019-05-29 12:09:35	2019-05-29 15:09:16	36	0	\N	\N
395028	COM_PERMANENTE	AUTRE	\N	CDD	\N	Audition plénière - Changement climatique	\N	2019-07-03 10:30:00	2019-07-03 12:00:00	\N	\N	0	0	\N	\N
395188	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Acoss	\N	2019-07-02 14:30:00	2019-07-02 15:30:00	\N	\N	0	0	\N	\N
395442	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition SILT	\N	2019-06-25 14:30:00	2019-06-25 15:20:00	\N	\N	2	0	\N	\N
395720	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-07-02 17:35:00	2019-07-02 19:35:00	2019-07-03 09:13:06	2019-07-03 10:41:48	65	0	\N	\N
400552	COM_ENQUETE	PLENIERE	\N	SOUVERAINETE	\N	CE souveraineté numérique	\N	2019-07-11 14:00:00	2019-07-11 16:00:00	2019-07-12 17:44:41	2019-07-12 19:01:17	4	0	\N	\N
401817	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Ganbold Ganbayar, membre du gouvernement mongol	Entretien avec M. Ganbold Ganbayar, vice-ministre de la culture, de l'éducation, des sciences et des sports de Mongolie	2019-07-16 15:00:00	2019-07-16 17:15:00	\N	\N	5	0	612	\N
402258	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Conclusions CMP Transformation fonction publique	Conclusions CMP Transformation fonction publique	2019-07-23 18:20:00	2019-07-23 19:25:00	\N	\N	65	0	\N	\N
402265	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL lutte contre le gaspillage	PJL lutte contre le gaspillage	2019-09-24 15:00:00	2019-09-24 16:35:00	\N	\N	173	0	\N	\N
402266	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL lutte contre le gaspillage	PJL lutte contre le gaspillage	2019-09-24 17:50:00	2019-09-24 19:25:00	\N	\N	95	0	\N	\N
402267	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL lutte contre le gaspillage	PJL lutte contre le gaspillage	2019-09-24 21:30:00	2019-09-25 00:30:00	\N	\N	79	0	\N	\N
402268	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL lutte contre le gaspillage	PJL lutte contre le gaspillage	2019-09-25 15:00:00	2019-09-25 19:30:00	\N	\N	145	0	\N	\N
402269	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL lutte contre le gaspillage	PJL lutte contre le gaspillage	2019-09-25 21:30:00	2019-09-26 01:05:00	\N	\N	72	0	\N	\N
402270	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PJL Modernisation de la presse	CMPPJL Modernisation de la presse	2019-09-26 12:25:00	2019-09-26 13:25:00	\N	\N	28	0	\N	\N
402272	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Économie circulaire	PJL Économie circulaire	2019-09-26 21:30:00	2019-09-27 00:25:00	\N	\N	37	0	\N	\N
402273	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Place agriculture française	Débat Place agriculture française	2019-10-01 14:30:00	2019-10-01 16:05:00	\N	\N	137	0	\N	\N
402274	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Adoption de règlements locaux de publicité intercommunaux	PPL Adoption de règlements locaux de publicité intercommunaux	2019-10-01 16:10:00	2019-10-01 17:00:00	\N	\N	96	0	\N	\N
402295	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Entraves à des libertés, à des évènements et activités légales	PPL Entraves à des libertés, à des évènements et activités légales	2019-10-01 17:00:00	2019-10-01 19:25:00	\N	\N	107	0	\N	\N
402297	SEANCE_PLENIERE	DECL_GVT	\N	\N	\N	Déclaration du Gouvernement et débat Politique migratoire de la France et de l'Europe	Déclaration du Gouvernement et débat Politique migratoire de la France et de l'Europe	2019-10-09 16:35:00	2019-10-09 19:10:00	\N	\N	192	0	\N	\N
402300	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Sécurité des ponts	Débat Sécurité des ponts	2019-10-02 17:00:00	2019-10-02 18:20:00	\N	\N	75	0	\N	\N
402303	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Intelligence artificielle	Débat Intelligence artificielle	2019-10-02 18:25:00	2019-10-02 20:00:00	\N	\N	42	0	\N	\N
402304	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat conclusions rapport Adapter la France aux dérèglements climatiques	Débat	2019-10-03 10:30:00	2019-10-03 12:10:00	\N	\N	48	0	\N	\N
402305	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2019-10-02 15:25:00	2019-10-02 16:45:00	\N	\N	297	0	\N	\N
402306	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Violences sexuelles sur mineurs en institutions	Débat Violences sexuelles sur mineurs en institutions	2019-10-03 14:30:00	2019-10-03 16:10:00	\N	\N	50	0	\N	\N
402307	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Santé en Guyane	Débat Santé en Guyane	2019-10-03 16:15:00	2019-10-03 17:35:00	\N	\N	30	0	\N	\N
384107	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion de commission	 Rapport accès PME commande publique	2019-05-29 08:30:00	2019-05-29 09:20:00	2019-05-29 12:06:26	2019-05-29 15:09:11	34	0	\N	\N
384109	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion de commission	Rapport statut élu communal	2019-05-29 10:40:00	2019-05-29 11:45:00	2019-06-03 15:44:22	2019-06-24 09:59:45	32	0	\N	\N
395029	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-06-26 09:35:00	2019-06-26 12:05:00	2019-06-26 12:18:11	2019-06-26 18:36:07	37	3	\N	\N
410887	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPR CE Usine Lubrizol (rapporteur) -  PJL Engagement et proximité (Amdts séance)	PPR CE Usine Lubrizol (rapporteur) -  PJL Engagement et proximité (Amdts séance)	2019-10-08 09:05:00	2019-10-08 09:45:00	2019-10-09 18:26:27	2019-10-10 14:55:45	19	0	\N	\N
414835	ETUDES	AUTRE	\N	\N	\N	Audition plénière - GE Vigne et Vin - 2018	Audition de Mme Irène Tolleret	2019-10-15 17:00:00	2019-10-15 18:00:00	\N	\N	14	0	\N	909
415001	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-10-23 09:30:00	2019-10-23 10:55:00	2019-10-24 10:00:06	2019-10-24 11:00:57	41	0	\N	\N
415010	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS Budget 2020 - Equilibres financiers généraux	PLFSS Budget 2020	2019-10-15 15:00:00	2019-10-15 16:40:00	\N	\N	2	0	\N	\N
415030	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Travailleurs indépendants	\N	2019-10-15 17:00:00	2019-10-15 18:00:00	\N	\N	3	0	\N	\N
415523	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Sport	PLF 2020 - Crédits Sport	2019-10-16 14:00:00	2019-10-16 15:00:00	\N	\N	1	0	\N	\N
415868	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Avis énergie - Auditions M. Gremillet	PJLF 2020 - Avis énergie - Auditions M. Gremillet	2019-10-15 16:00:00	2019-10-15 16:45:00	\N	\N	1	0	\N	\N
415869	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Avis énergie - Auditions M. Gremillet	PJLF 2020 - Avis énergie - Auditions M. Gremillet	2019-10-15 16:45:00	2019-10-15 17:30:00	\N	\N	1	0	\N	\N
415892	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2020 - Auditions mission DAG	\N	2019-10-15 17:00:00	2019-10-15 18:00:00	\N	\N	1	0	\N	\N
415895	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2020 - Auditions mission DAG	\N	2019-10-15 14:30:00	2019-10-15 16:30:00	\N	\N	1	0	\N	\N
415908	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Auditions M. Gremillet - Avis énergie	PJLF 2020 - Auditions M. Gremillet - Avis énergie	2019-10-15 17:30:00	2019-10-15 18:15:00	\N	\N	1	0	\N	\N
415922	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Auditions M. Gremillet - Avis énergie	PJLF 2020 - Auditions M. Gremillet - Avis énergie	2019-10-15 18:15:00	2019-10-15 19:00:00	\N	\N	1	0	\N	\N
415924	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2020 - Auditions mission DAG	\N	2019-10-14 15:00:00	2019-10-14 18:00:00	\N	\N	1	0	\N	\N
439686	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat sur la laïcité	Débat sur la laïcité	2020-01-08 17:59:00	2020-01-08 19:34:00	\N	\N	37	0	\N	\N
439687	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR 34-1 Barrière écologique aux frontières	PPR 34-1 Barrière écologique aux frontières	2020-01-14 15:20:00	2020-01-14 16:51:00	\N	\N	95	0	\N	\N
439688	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Rrelations commerciales secteur agricole et alimentaire	PPL Equilibre des relations commerciales secteur agricole et alimentaire	2020-01-14 16:57:00	2020-01-14 18:54:00	\N	\N	85	0	\N	\N
441616	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Créer un droit à l'erreur des collectivités locales	PPL Droit à l'erreur collectivités locales	2019-12-19 09:45:00	2019-12-19 10:30:00	\N	\N	1	0	\N	\N
449593	DELEGATION	AUDRAP	\N	\N	211	Audition de représentantes de la CFDT	Audition de représentantes de la CFDT	2020-02-04 16:00:00	2020-02-04 17:30:00	\N	\N	6	0	\N	\N
449594	DELEGATION	AUDRAP	\N	\N	211	Audition de représentantes de l'IPS	Audition de représentantes de l'IPS	2020-02-04 18:30:00	2020-02-04 19:50:00	\N	\N	5	0	\N	\N
449597	COM_EURO	AUDRAP	\N	AFEU	\N	Convergence sociale - CLEISS	Convergence sociale - CLEISS	2020-01-28 13:45:00	2020-01-28 14:45:00	\N	\N	2	0	\N	\N
449598	COM_EURO	AUDRAP	\N	AFEU	\N	Convergence sociale - DSS	Convergence sociale - DSS	2020-01-28 16:00:00	2020-01-28 17:00:00	\N	\N	2	0	\N	\N
449601	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Audition de M. Pierre Buhler, président de l¿Institut français, sur le projet de contrat d¿objectifs et de moyens 2020-2	2020-01-29 11:00:00	2020-01-29 12:30:00	2020-01-30 09:07:13	2020-01-30 09:52:47	33	0	\N	\N
449603	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Examen amendements de séance PPL Droit au transport	\N	2020-02-04 13:30:00	2020-02-04 13:45:00	2020-02-04 14:13:00	2020-02-04 17:48:23	26	1	\N	\N
449605	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de M. Adrien Taquet	\N	2020-02-05 09:05:00	2020-02-05 10:45:00	2020-02-05 18:13:54	2020-02-06 16:10:47	40	1	\N	\N
449606	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Examen rapport d'information Obligation de signalement	\N	2020-02-05 11:15:00	2020-02-05 12:20:00	2020-02-05 18:18:53	2020-02-06 16:09:40	50	1	\N	\N
450148	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution Plastique (déplacement à Angers)	Audition rapporteurs Pollution Plastique (déplacement à Angers) Centre de traitement de dépollution d'eau	2020-02-11 09:30:00	2020-02-11 11:30:00	\N	\N	2	0	\N	\N
450151	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution Plastique (déplacement à Angers)	Audition rapporteurs Pollution Plastique (déplacement à Angers) Restoria	2020-02-11 11:30:00	2020-02-11 12:00:00	\N	\N	2	0	\N	\N
450154	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution Plastique (déplacement à Angers)	Audition rapporteurs Pollution Plastique (déplacement à Angers) Fédération régionale des producteurs de fruits	2020-02-11 12:00:00	2020-02-11 12:45:00	\N	\N	2	0	\N	\N
450157	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution Plastique (déplacement à Angers)	Audition rapporteurs Pollution Plastique (déplacement à Angers) Angers Loire Métropole	2020-02-11 12:45:00	2020-02-11 14:15:00	\N	\N	2	0	\N	\N
450160	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution Plastique (déplacement à Angers)	Audition rapporteurs Pollution Plastique (déplacement à Angers) Veolia	2020-02-11 14:30:00	2020-02-11 16:30:00	\N	\N	2	0	\N	\N
450163	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution Plastique (déplacement à Angers)	Audition rapporteurs Pollution Plastique (déplacement à Angers) Université catholique de l'Ouest	2020-02-11 16:45:00	2020-02-11 17:45:00	\N	\N	2	0	\N	\N
450166	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution Plastique (déplacement à Angers)	Audition rapporteurs Pollution Plastique (déplacement à Angers) Université catholique de l'Ouest	2020-02-11 17:45:00	2020-02-11 18:30:00	\N	\N	2	0	\N	\N
450169	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution plastique (déplacement à Nantes)	Audition rapporteurs Pollution plastique (déplacement à Nantes) Conseil régional des Pays de la Loire	2020-02-12 08:00:00	2020-02-12 09:00:00	\N	\N	2	0	\N	\N
450172	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution plastique (déplacement à Nantes)	Audition rapporteurs Pollution plastique (déplacement à Nantes) 1ère table ronde scientifique	2020-02-12 09:00:00	2020-02-12 11:30:00	\N	\N	2	0	\N	\N
450175	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution plastique (déplacement à Nantes)	Audition rapporteurs Pollution plastique (déplacement à Nantes) Seconde table ronde scientifique	2020-02-12 11:30:00	2020-02-12 13:00:00	\N	\N	2	0	\N	\N
415006	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-10-23 10:55:00	2019-10-23 11:25:00	2019-10-24 10:01:52	2019-10-24 11:00:54	42	1	\N	\N
450178	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution plastique (déplacement à Nantes)	Audition rapporteurs Pollution plastique (déplacement à Nantes) Conseil régional des Pays de la Loire	2020-02-12 13:00:00	2020-02-12 14:30:00	\N	\N	2	0	\N	\N
450181	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution plastique (déplacement à Nantes)	Audition rapporteurs Pollution plastique (déplacement à Nantes) DREAL Pays de la Loire	2020-02-12 14:30:00	2020-02-12 15:30:00	\N	\N	2	0	\N	\N
450184	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution plastique (déplacement à Nantes)	Audition rapporteurs Pollution plastique (déplacement à Nantes) Arc-en-Ciel	2020-02-12 15:45:00	2020-02-12 17:30:00	\N	\N	2	0	\N	\N
450190	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution Plastique (déplacement à Angers)	Audition rapporteurs Pollution Plastique (déplacement à Angers) Trioplast	2020-02-13 08:45:00	2020-02-13 11:00:00	\N	\N	2	0	\N	\N
450193	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution Plastique (déplacement à Angers)	Audition rapporteurs Pollution Plastique (déplacement à Angers) Paprec Plastiques	2020-02-13 11:00:00	2020-02-13 14:00:00	\N	\N	2	0	\N	\N
450608	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2020-02-05 09:35:00	2020-02-05 11:20:00	2020-02-05 11:31:42	2020-02-05 17:13:08	39	0	\N	\N
450611	MISSION	AUCUNE	\N	BREXIT2	\N	Audition Mme Colonna	Audition Mme Colonna, ambassadrice de France au RU	2020-01-29 16:35:00	2020-01-29 18:00:00	2020-01-30 12:24:08	\N	8	0	\N	\N
450830	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition GT Nouvelles formes de commerce - Rapporteur M. Babary	Audition GT Nouvelles formes de commerce - Rapporteur M. Babary	2020-01-28 13:45:00	2020-01-28 14:30:00	\N	\N	1	0	\N	\N
450832	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition GT Nouvelles formes de commerce - Rapporteur M. Babary	Audition GT Nouvelles formes de commerce - Rapporteur M. Babary	2020-01-28 15:45:00	2020-01-28 18:00:00	\N	\N	1	0	\N	\N
450834	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition GT Nouvelles formes de commerce - Rapporteur M. Babary	Audition GT Nouvelles formes de commerce - Rapporteur M. Babary	2020-01-29 16:30:00	2020-01-29 17:30:00	\N	\N	2	0	\N	\N
450839	GIA	AUCUNE	\N	\N	\N	Assemblée générale 	\N	2020-01-29 13:45:00	2020-01-29 14:15:00	\N	\N	3	0	626	\N
450843	GIA	AUCUNE	\N	\N	\N	Entretien avec une délégation d'associations	Pétition sur la mer de Chine	2020-01-29 14:15:00	2020-01-29 14:45:00	\N	\N	3	0	626	\N
450847	GIA	AUCUNE	\N	\N	\N	Réunion avec l'ambassadeur au Vanuatu	Réunion avec M. Fournier, ambassadeur au Vanuatu, et Mme Giron, chef de la mission Océanie	2020-01-30 08:20:00	2020-01-30 09:45:00	\N	\N	6	0	651	\N
450927	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Porte-avions	\N	2020-01-29 15:30:00	2020-01-29 17:30:00	\N	\N	3	0	\N	\N
452281	GIA	AUCUNE	\N	\N	\N	Réunion de travail avec l'Ambassadrice de France au Portugal	Petit-déjeuner de travail avec Mme Florence Mangin, Ambassadrice de France à Lisbonne	2020-02-05 08:15:00	2020-02-05 09:45:00	\N	\N	6	0	601	\N
452575	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Assurance récolte	GT Assurance récolte	2020-02-04 16:30:00	2020-02-04 17:30:00	\N	\N	5	0	\N	\N
373727	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Emploi des seniors	\N	2019-06-11 14:00:00	2019-06-11 14:45:00	\N	\N	2	0	\N	\N
373729	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Emploi des seniors	\N	2019-05-23 14:00:00	2019-05-23 15:30:00	\N	\N	1	0	\N	\N
373730	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Emploi des seniors	\N	2019-05-21 18:00:00	2019-05-21 18:45:00	\N	\N	2	0	\N	\N
373731	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Emploi des seniors	\N	2019-05-21 14:00:00	2019-05-21 14:45:00	\N	\N	3	0	\N	\N
373732	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Emploi des seniors	\N	2019-05-07 14:00:00	2019-05-07 16:15:00	\N	\N	2	0	\N	\N
376955	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Organisation du système de santé	\N	2019-05-10 14:00:00	2019-05-10 16:00:00	\N	\N	1	0	\N	\N
376958	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	pjl restauration et conservation Notre-Dame	\N	2019-05-09 14:30:00	2019-05-09 16:15:00	\N	\N	3	0	\N	\N
376962	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	pjl restauration et conservation Notre-Dame	\N	2019-05-09 16:15:00	2019-05-09 17:15:00	\N	\N	4	0	\N	\N
376967	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	pjl restauration et conservation Notre-Dame	\N	2019-05-09 17:15:00	2019-05-09 19:15:00	\N	\N	2	0	\N	\N
384721	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Hébergement d'urgence	Hébergement d'urgence	2019-06-06 14:00:00	2019-06-06 15:00:00	\N	\N	2	0	\N	\N
384722	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Hébergement d'urgence	Hébergement d'urgence	2019-06-06 16:15:00	2019-06-06 17:15:00	\N	\N	2	0	\N	\N
384727	MISSION	AUCUNE	\N	SIDERURGIE	\N	Plénière - Auditions	\N	2019-05-29 14:00:00	2019-05-29 16:00:00	2019-06-06 16:31:55	\N	5	0	\N	\N
384744	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Le recouvrement des amendes de circulation - France Urbaine/GART	Contrôle 2019 - Le recouvrement des amendes de circulation - France Urbaine/GART	2019-05-28 15:30:00	2019-05-28 16:30:00	\N	\N	2	0	\N	\N
384748	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Masse salariale MEAE - MEAE	Contrôle 2019 - Masse salariale MEAE - MEAE	2019-05-28 09:00:00	2019-05-28 10:00:00	\N	\N	2	0	\N	\N
384751	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Masse salariale du MEAE - MEAE	Contrôle 2019 - Masse salariale du MEAE - MEAE	2019-05-29 15:00:00	2019-05-29 16:00:00	\N	\N	1	0	\N	\N
384753	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - ZRR - Table ronde Élus	Contrôle 2019 - ZRR - Table ronde Élus	2019-05-28 14:30:00	2019-05-28 16:30:00	\N	\N	3	0	\N	\N
384757	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - ZRR -  Auditions députées	Contrôle 2019 - ZRR - Auditions députées	2019-05-28 18:30:00	2019-05-28 19:30:00	\N	\N	3	0	\N	\N
384761	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Agriculture biologique - Ministère de l'agriculture	Contrôle 2018 - Agriculture biologique - Ministère de l'agriculture	2019-05-28 14:30:00	2019-05-28 16:30:00	\N	\N	2	0	\N	\N
384764	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Fraude fonds européens - FranceAgriMer	Contrôle 2019 - Fraude fonds européens - FranceAgriMer	2019-05-28 14:30:00	2019-05-28 15:30:00	\N	\N	1	0	\N	\N
387797	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PJL Organisation du système de santé	PJL Organisation du système de santé	2019-06-11 15:15:00	2019-06-11 15:50:00	2019-06-12 09:36:15	2019-06-12 16:55:42	44	0	\N	\N
392414	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Coopération franco-britannique de défense	\N	2019-06-18 13:00:00	2019-06-18 17:30:00	\N	\N	5	0	\N	\N
392420	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Salon du Bourget 	\N	2019-06-19 07:30:00	2019-06-19 16:15:00	\N	\N	20	0	\N	\N
396565	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Conclusions CMP Système de santé	Conclusions CMP Système de santé	2019-07-16 14:33:00	2019-07-16 15:52:00	\N	\N	109	0	\N	\N
469644	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Enjeux sanitaires - Audition FCD	\N	2020-05-26 14:15:00	2020-05-26 15:00:00	\N	\N	2	0	\N	\N
398208	MISSION	AUCUNE	\N	FONDS	\N	Audition plénière - Sous-utilisation chronique des fonds européens en France	\N	2019-07-10 15:05:00	2019-07-10 18:10:00	2019-07-10 18:15:17	2019-07-11 11:27:31	11	0	\N	\N
398209	ETUDES	AUCUNE	\N	\N	\N	GEAC - Audition Air France KLM	GEAC - Audition Air France KLM	2019-07-04 08:30:00	2019-07-04 10:00:00	\N	\N	9	0	\N	933
398210	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	\N	\N	2019-07-04 08:30:00	2019-07-04 10:00:00	\N	\N	0	0	\N	\N
398220	MISSION	AUDRAP	\N	TRANSPORTS	\N	MIGT	Audition rapporteur Mission gratuité transports	2019-07-03 16:15:00	2019-07-03 17:25:00	\N	\N	1	0	\N	\N
398221	MISSION	AUDRAP	\N	TRANSPORTS	\N	Audition de Mme Cohen	\N	2019-07-04 14:05:00	2019-07-04 15:00:00	\N	\N	3	0	\N	\N
398234	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-07-11 10:35:00	2019-07-11 12:05:00	2019-07-11 12:03:51	2019-07-11 17:45:14	11	0	\N	\N
398247	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Fraude aux fonds européens - DGFIP	Contrôle 2019 - Fraude aux fonds européens - DGFIP	2019-07-02 08:45:00	2019-07-02 09:30:00	\N	\N	1	0	\N	\N
398260	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Sécurité informatiques des pouvoirs public - Conseil constitutionnel	Contrôle 2019 - Sécurité informatiques des pouvoirs public - Conseil constitutionnel	2019-07-03 15:00:00	2019-07-03 15:45:00	\N	\N	1	0	\N	\N
398263	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Masse salariale du MEAE - MEAE	Contrôle 2019 - Masse salariale du MEAE - MEAE	2019-07-03 15:30:00	2019-07-03 17:00:00	\N	\N	1	0	\N	\N
398265	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Inspection du travail - DGT	Contrôle 2019 - Inspection du travail - DGT	2019-07-02 14:30:00	2019-07-02 15:45:00	\N	\N	2	0	\N	\N
398270	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Évaluation ISF en IFI et création PFU - BdF / Table ronde Immobilier	Contrôle 2019 - Évaluation transformation ISF en IFI et création PFU - BdF / Table ronde Immobilier	2019-07-02 15:00:00	2019-07-02 16:45:00	\N	\N	2	0	\N	\N
398294	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	Professionnels hospitaliers	\N	2019-07-09 15:00:00	2019-07-09 16:30:00	\N	\N	0	0	\N	\N
398295	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	\N	\N	2019-07-09 15:00:00	2019-07-09 16:30:00	\N	\N	0	0	\N	\N
398300	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-07-09 09:05:00	2019-07-09 10:25:00	2019-07-10 11:41:52	2019-07-10 14:25:39	19	0	\N	\N
398301	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-07-09 14:30:00	2019-07-09 15:45:00	2019-07-10 11:42:43	2019-07-10 14:25:41	21	0	\N	\N
398302	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-07-09 17:50:00	2019-07-09 18:40:00	2019-07-10 13:46:56	2019-07-11 11:26:42	27	2	\N	\N
398303	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-07-10 09:35:00	2019-07-10 11:30:00	2019-07-10 13:43:59	2019-07-11 11:26:38	32	0	\N	\N
398306	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	Auditions 	\N	2019-07-18 08:30:00	2019-07-18 10:15:00	\N	\N	0	0	\N	\N
398915	COM_ENQUETE	PLENIERE	\N	SOUVERAINETE	\N	C.E. "Souveraineté numérique"	C.E. "Souveraineté numérique"	2019-07-09 15:00:00	2019-07-09 16:30:00	2019-07-09 17:26:38	2019-07-09 17:36:30	8	0	\N	\N
404687	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution plastique	Audition rapporteurs Pollution plastique (table ronde Recyclage)	2019-09-18 14:30:00	2019-09-18 16:00:00	\N	\N	2	0	\N	\N
404690	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution plastique	Audition rapporteurs Pollution plastique (table ronde Pêche/Aquaculture)	2019-10-01 14:30:00	2019-10-01 16:00:00	\N	\N	2	0	\N	\N
454008	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Transparence	\N	2020-02-06 10:00:00	2020-02-06 11:30:00	\N	\N	2	0	\N	\N
454068	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	Test Kairos	\N	2016-02-07 11:00:00	2016-02-07 13:00:00	\N	\N	0	0	\N	\N
454069	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - Le franc CFA - économiste	Contrôle 2020 - Le franc CFA - économiste	2020-02-03 11:00:00	2020-02-03 12:15:00	\N	\N	1	0	\N	\N
454071	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - Le franc CFA - Banque de France et DG trésor	Contrôle 2020 - Le franc CFA - Banque de France et DG trésor	2020-02-04 17:30:00	2020-02-04 19:00:00	\N	\N	2	0	\N	\N
454074	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - Le franc CFA - Universitaire	Contrôle 2020 - Le franc CFA - Universitaire	2020-02-05 16:30:00	2020-02-05 17:45:00	\N	\N	2	0	\N	\N
454077	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - Le franc CFA - Universitaire	Contrôle 2020 - Le franc CFA - Universitaire	2020-02-05 17:45:00	2020-02-05 18:35:00	\N	\N	1	0	\N	\N
454079	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 2019 - Arrêt et démantèlement installations nucléaires civiles - Cour des comptes	58-2 2019 - Arrêt et démantèlement installations nucléaires civiles - Cour des comptes	2020-02-04 18:00:00	2020-02-04 19:30:00	\N	\N	1	0	\N	\N
439595	GIA	AUCUNE	\N	\N	\N	Coopé - Visite de M. José Manuel OLIVARES MARQUINA, député vénézuélien	Coopé - Visite de M. José Manuel OLIVARES MARQUINA, député vénézuélien	2019-12-11 09:00:00	2019-12-11 09:50:00	\N	\N	1	0	979	\N
439602	GIA	AUCUNE	\N	\N	\N	Coopé - Visite de M. José Manuel OLIVARES MARQUINA, député vénézuélien	Coopé - Visite de M. José Manuel OLIVARES MARQUINA, député vénézuélien	2019-12-12 07:45:00	2019-12-12 07:55:00	\N	\N	1	0	979	\N
454011	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des présidents	Conférence des Présidents	2020-01-22 19:35:00	2020-01-22 20:15:00	\N	\N	20	0	\N	\N
454032	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2020-01-28 14:20:00	2020-01-28 14:55:00	\N	\N	21	0	\N	\N
454056	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Déplacement Base aérienne Mérignac	\N	2020-02-06 07:00:00	2020-02-06 19:00:00	\N	\N	9	0	\N	\N
468403	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid 19 Patrimoine	Audition DG Patrimoines	2020-05-05 15:30:00	2020-05-05 16:45:00	\N	\N	5	0	\N	\N
469624	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Médico-social/M. Bonne - Audition de la FFAMCO (visioconférence)	\N	2020-05-12 10:15:00	2020-05-12 11:15:00	\N	\N	3	0	\N	\N
469625	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - Mission de contrôle liée à l'épidémie de Covid-19 - Audition CFCM	Audition rapporteur - Mission de contrôle liée à l'épidémie de Covid-19 - Audition CFCM	2020-05-12 15:00:00	2020-05-12 16:00:00	\N	\N	4	0	\N	\N
469626	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Médico-social/M. Bonne - Audition de la DGCS (visioconférence)	\N	2020-05-12 11:30:00	2020-05-12 12:30:00	\N	\N	1	0	\N	\N
469637	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Enjeux sanitaires - Audition Pr RENOLLEAU et Dr HENTGEN (Mme Deroche)	\N	2020-05-19 14:00:00	2020-05-19 15:00:00	\N	\N	7	0	\N	\N
469639	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Enjeux sanitaires - Audition LOGSanté (Mme Deroche)	\N	2020-05-19 15:15:00	2020-05-19 16:15:00	\N	\N	3	0	\N	\N
469641	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Enjeux sanitaires - Audition Pr HOUSSIN (Mme Deroche)	\N	2020-05-25 14:30:00	2020-05-25 15:30:00	\N	\N	4	0	\N	\N
398232	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-07-10 09:05:00	2019-07-10 12:40:00	2019-07-10 15:37:49	2019-07-11 11:26:43	40	1	\N	\N
469645	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Enjeux sanitaires - Audition ACCOR (Mme Deroche)	\N	2020-05-26 15:15:00	2020-05-26 16:15:00	\N	\N	1	0	\N	\N
469646	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Enjeux sanitaires - Audition INRIA/HOANG (Mme Deroche)	\N	2020-05-28 14:30:00	2020-05-28 15:30:00	\N	\N	3	0	\N	\N
469775	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions cellule agriculture	Auditions cellule agriculture	2020-04-03 09:00:00	2020-04-03 10:30:00	\N	\N	4	0	\N	\N
469780	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Cellule agriculture FNPHP	Auditions cellule agriculture	2020-04-06 10:15:00	2020-04-06 11:15:00	\N	\N	11	0	\N	\N
469781	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions cellule agriculture	Auditions cellule agriculture	2020-04-07 09:00:00	2020-04-07 10:00:00	\N	\N	10	0	\N	\N
469782	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule agriculture	Auditions cellule agriculture	2020-04-09 09:45:00	2020-04-09 10:45:00	\N	\N	5	0	\N	\N
469783	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Enjeux sanitaires - Audition Pr PELISSOLO (Mme Deroche)	\N	2020-05-28 15:45:00	2020-05-28 16:45:00	\N	\N	6	0	\N	\N
469821	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule agriculture ANVOL	Auditions cellule agriculture	2020-04-14 09:30:00	2020-04-14 10:30:00	\N	\N	4	0	\N	\N
469822	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule agriculture et vin CNAOC	Auditions cellule agriculture	2020-04-16 10:00:00	2020-04-16 11:00:00	\N	\N	17	0	\N	\N
469823	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule agriculture et vin	Auditions cellule agriculture	2020-04-16 14:00:00	2020-04-16 15:00:00	\N	\N	14	0	\N	\N
469824	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule agriculture et vin	Auditions cellule agriculture	2020-04-16 15:30:00	2020-04-16 16:30:00	\N	\N	13	0	\N	\N
469884	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule agriculture	Auditions cellule agriculture	2020-04-21 09:00:00	2020-04-21 10:00:00	\N	\N	5	0	\N	\N
469885	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule agriculture	Auditions cellule agriculture	2020-04-23 10:00:00	2020-04-23 10:45:00	\N	\N	5	0	\N	\N
469887	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule agriculture	Auditions cellule agriculture	2020-04-24 09:00:00	2020-04-24 10:30:00	\N	\N	7	0	\N	\N
469905	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions cellule agriculture	\N	2020-04-30 08:45:00	2020-04-30 09:45:00	\N	\N	9	0	\N	\N
469906	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule agriculture et vin	Auditions cellule agriculture	2020-04-30 15:00:00	2020-04-30 16:30:00	\N	\N	13	0	\N	\N
469951	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule agriculture et vin	\N	2020-05-05 17:00:00	2020-05-05 19:00:00	\N	\N	17	0	\N	\N
469952	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule agriculture	Auditions cellule agriculture	2020-05-07 09:00:00	2020-05-07 10:00:00	\N	\N	6	0	\N	\N
469953	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule agriculture	Auditions cellule agriculture	2020-05-07 13:45:00	2020-05-07 15:00:00	\N	\N	8	0	\N	\N
469985	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule agriculture	Auditions cellule agriculture	2020-05-12 09:00:00	2020-05-12 10:00:00	\N	\N	10	0	\N	\N
469996	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition de la Haute Autorité pour la transparence de la vie publique	Audition de la Haute Autorité pour la transparence de la vie publique	2020-05-13 16:30:00	2020-05-13 17:00:00	\N	\N	9	0	\N	\N
470115	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission (visioconférence)	Réunion de commission (visioconférence)	2020-05-13 16:35:00	2020-05-13 18:25:00	2020-05-13 18:35:37	2020-05-14 16:54:59	26	0	\N	\N
473465	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Transports-Union des transports publics et ferroviaires (UTP)	Covid-19-Transports-Union des transports publics et ferroviaires (UTP)	2020-04-07 10:20:00	2020-04-07 11:00:00	\N	\N	2	0	\N	\N
473466	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Transports-Union nationale des industries de la manutention (UNIM)	Covid-19-Transports-Union nationale des industries de la manutention (UNIM)	2020-04-08 09:10:00	2020-04-08 09:50:00	\N	\N	6	0	\N	\N
473467	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Transports-Groupe SNCF	Covid-19-Transports-Groupe SNCF	2020-04-08 14:30:00	2020-04-08 15:30:00	\N	\N	2	0	\N	\N
473468	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-TRansports-Association des utilisateurs de transport de fret (AUTF)	Covid-19-TRansports-Association des utilisateurs de transport de fret (AUTF)	2020-04-09 08:30:00	2020-04-09 09:15:00	\N	\N	5	0	\N	\N
473469	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Transports-Voies navigables de France (VNF)	Covid-19-Transports-Voies navigables de France (VNF)	2020-04-09 09:25:00	2020-04-09 10:10:00	\N	\N	6	0	\N	\N
473470	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Transports-Fédération nationale de transporteurs de voyageurs (FNTV)	Covid-19-Transports-Fédération nationale de transporteurs de voyageurs (FNTV)	2020-04-09 10:20:00	2020-04-09 11:05:00	\N	\N	6	0	\N	\N
473471	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Transports-TLF - FNTR - OTRE	Covid-19-Transports-TLF - FNTR - OTRE	2020-04-09 11:10:00	2020-04-09 11:55:00	\N	\N	6	0	\N	\N
473472	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Transports-Association française du Rail (AFRA)	Covid-19-Transports-Association française du Rail (AFRA)	2020-04-15 08:30:00	2020-04-15 09:15:00	\N	\N	9	0	\N	\N
473473	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Transports-Armateurs de France	Covid-19-Transports-Armateurs de France	2020-04-16 09:15:00	2020-04-16 10:00:00	\N	\N	9	0	\N	\N
473475	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Transports-Plateforme de la filière automobile et des mobilités (PFA)	Covid-19-Transports-Plateforme de la filière automobile et des mobilités (PFA)	2020-04-23 16:30:00	2020-04-23 17:30:00	\N	\N	9	0	\N	\N
473477	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Transports-Conseil national des professions de l'automobile (CNPA)	Covid-19-Transports-Conseil national des professions de l'automobile (CNPA)	2020-04-30 14:00:00	2020-04-30 15:00:00	\N	\N	9	0	\N	\N
380040	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	RI Mission innovation et défense	Visite à la base aérienne de Salon de Provence	2019-05-14 06:00:00	2019-05-14 19:00:00	\N	\N	2	0	\N	\N
380043	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI mission innovation et défense	\N	2019-05-15 14:00:00	2019-05-15 17:00:00	\N	\N	2	0	\N	\N
380046	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Mission innovation et défense	\N	2019-05-16 10:30:00	2019-05-16 11:30:00	\N	\N	2	0	\N	\N
384208	DELEGATION	AUCUNE	\N	\N	COLTER	Examen rapport d'information "Réduire le poids des normes en aval de leur production"	\N	2019-06-06 09:00:00	2019-06-06 10:00:00	2019-06-06 11:14:46	\N	13	0	\N	\N
388504	MISSION	AUDRAP	\N	AERIEN	\N	transports aériens	\N	2019-06-11 10:00:00	2019-06-11 11:00:00	\N	\N	4	0	\N	\N
388515	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	1122	\N	\N	Explications de vote sur l'ensemble- PJL Santé	Explications de vote sur l'ensemble- PJL Santé	2019-06-11 18:10:00	2019-06-11 19:05:00	\N	\N	263	0	\N	\N
400115	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Qualité frauduleuse de steaks hachés-Audition de M. LE HELLOCO - Voldis (Côtes-d'Armor)	Audition de M. LE HELLOCO - Voldis (Côtes-d'Armor)	2019-07-09 08:30:00	2019-07-09 09:30:00	\N	\N	1	0	\N	\N
400116	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Qualité frauduleuse de steaks hachés-Audition de M. PROUX - Société Marcel Proux	Audition de M. PROUX - Société Marcel Proux	2019-07-09 15:00:00	2019-07-09 16:00:00	\N	\N	1	0	\N	\N
400117	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Qualité frauduleuse de steaks hachés-Audition de Mme BARTHÉLÉMY - Voldis (Côtes-d'Armor)	Audition de Mme BARTHÉLÉMY - Société Voldis (Côtes-d'Armor)	2019-07-10 14:30:00	2019-07-10 15:30:00	\N	\N	2	0	\N	\N
400118	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Qualité frauduleuse de steaks hachés-udition de Mme PANNIER-RUNACHER, secrétaire d'État	Audition de Mme PANNIER-RUNACHER, secrétaire d'État auprès du ministre de l'économie et des finances	2019-07-10 15:30:00	2019-07-10 16:30:00	\N	\N	2	0	\N	\N
400150	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Le financement de l'audiovisuel extérieur - DGMIC / DB	Contrôle 2019 - Le financement de l'audiovisuel extérieur - DGMIC / DB	2019-07-08 14:30:00	2019-07-08 16:00:00	\N	\N	1	0	\N	\N
400152	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Culture - COFAC	PLF pour 2020 - Culture - COFAC	2019-07-09 15:00:00	2019-07-09 16:00:00	\N	\N	1	0	\N	\N
400184	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2019 - La prime d'activité - Déplacement Lille	Contrôle 2019 - La prime d'activité - Déplacement Lille	2019-07-08 07:45:00	2019-07-08 15:15:00	\N	\N	2	0	\N	\N
400187	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2019 - La prime d'activité - Déplacement Cergy Pontoise	Contrôle 2019 - La prime d'activité - Déplacement Cergy Pontoise	2019-07-09 12:40:00	2019-07-09 17:00:00	\N	\N	2	0	\N	\N
400225	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Lutte contre les feux de forêt - MI 2015 Évaluation DFCI	Contrôle 2019 - Lutte contre les feux de forêt - MI 2015 Évaluation DFCI	2019-07-09 09:00:00	2019-07-09 10:40:00	\N	\N	1	0	\N	\N
401664	ETUDES	AUCUNE	\N	\N	\N	Table ronde sur l'UE et le Mercosur	Table ronde sur l'UE et le Mercosur	2019-07-17 08:00:00	2019-07-17 09:40:00	\N	\N	46	0	\N	919
405168	COM_EURO	AUTRE	\N	AFEU	\N	Audition plénière - Auditions de la commission des affaires européennes	\N	2019-09-19 11:00:00	2019-09-19 12:30:00	\N	\N	0	0	\N	\N
405169	MISSION	AUDRAP	\N	MARITIME	\N	MCI Sauvetage en Mer - FFA	MCI Sauvetage en Mer - FFA	2019-09-26 09:00:00	2019-09-26 10:00:00	\N	\N	1	0	\N	\N
405170	MISSION	AUDRAP	\N	MARITIME	\N	MCI Sauvetage en Mer - ANEL	MCI Sauvetage en Mer - ANEL	2019-09-25 12:00:00	2019-09-25 13:00:00	\N	\N	1	0	\N	\N
415225	GIA	AUCUNE	\N	\N	\N	Coopé - Visite de fonctionnaires allemands de l'administration fédérale des Länder	Coopé - Visite de fonctionnaires allemands de l'administration fédérale des Länder	2019-10-15 15:30:00	2019-10-15 16:30:00	\N	\N	1	0	604	\N
415937	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Auditions plénières et nominations de rapporteurs	\N	2019-10-23 08:35:00	2019-10-23 13:30:00	2019-10-23 16:27:15	2019-10-23 16:36:03	34	0	\N	\N
415938	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de Mme Genevière Chêne	\N	2019-10-23 16:35:00	2019-10-23 17:30:00	2019-10-24 09:41:18	2019-10-24 11:00:55	12	0	\N	\N
415987	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Auditions AT-MP	\N	2019-10-23 17:30:00	2019-10-23 18:30:00	\N	\N	2	0	\N	\N
415999	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Prestation de compensation du handicap	\N	2019-10-16 14:15:00	2019-10-16 14:45:00	\N	\N	1	0	\N	\N
416166	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-10-23 09:35:00	2019-10-23 10:40:00	2019-10-23 11:45:23	2019-10-23 11:52:45	41	1	\N	\N
416668	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2020 - Programme 178	\N	2019-10-17 09:00:00	2019-10-17 10:00:00	\N	\N	2	0	\N	\N
417448	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Avis Outre-Mer - Auditions M. Magras	PJLF 2020 - Avis Outre-Mer - Auditions M. Magras	2019-10-11 10:30:00	2019-10-11 12:00:00	\N	\N	1	0	\N	\N
417450	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Avis Outre-Mer - Auditions M. Magras	PJLF 2020 - Avis Outre-Mer - Auditions M. Magras	2019-10-18 14:00:00	2019-10-18 15:00:00	\N	\N	1	0	\N	\N
417451	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Avis Outre-Mer - Auditions M. Magras	PJLF 2020 - Avis Outre-Mer - Auditions M. Magras	2019-10-18 15:30:00	2019-10-18 17:00:00	\N	\N	1	0	\N	\N
418120	GIA	AUCUNE	\N	\N	\N	déjeuner avec une délégation du conseil de la Choura d'Arabie saoudite	déjeuner avec une délégation du conseil de la Choura d'Arabie saoudite	2019-10-22 12:45:00	2019-10-22 14:30:00	\N	\N	3	0	661	\N
421447	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-10-30 09:05:00	2019-10-30 10:05:00	2019-10-30 12:27:55	2019-10-30 14:57:26	32	0	\N	\N
421664	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-10-30 10:30:00	2019-10-30 12:10:00	2019-10-30 12:29:15	2019-10-30 14:57:24	24	0	\N	\N
421713	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Anciens combattants, mémoire et liens avec la Nation	\N	2019-10-29 15:30:00	2019-10-29 16:15:00	\N	\N	1	0	\N	\N
422451	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Examen des amendements PPL PCH	\N	2019-11-05 13:40:00	2019-11-05 13:45:00	2019-11-05 13:49:31	2019-11-05 15:35:13	20	0	\N	\N
422453	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition HAS	\N	2019-11-06 17:05:00	2019-11-06 18:00:00	2019-11-08 17:04:22	2019-11-08 17:07:17	8	0	\N	\N
422485	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLFSS pour 2020-Examen Rapport pour Avis - PLF pour 2020-Mission Santé	PLFSS pour 2020-Examen Rapport pour Avis - PLF pour 2020-Mission Santé	2019-11-05 15:05:00	2019-11-05 16:40:00	2019-11-05 17:51:44	2019-11-06 14:36:24	24	0	\N	\N
422486	COM_ENQUETE	DEPLACEMENT	\N	LUBRIZOL	\N	Déplacement à Rouen	\N	2019-10-24 08:00:00	2019-10-24 18:00:00	\N	\N	12	0	\N	\N
393983	CMP	AUTRE	\N	SYSTEME	\N	PJL Organisation du système de santé	PJL Organisation du système de santé	2019-06-20 10:30:00	2019-06-20 12:50:00	\N	\N	10	0	\N	\N
416167	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-10-23 10:45:00	2019-10-23 10:55:00	2019-10-23 11:39:07	2019-10-23 11:46:17	41	1	\N	\N
422494	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2020 - CAS Participations financ. de l'État et Mission Investissements d'avenir	PLF pour 2020 - CAS Participations financ. de l'État et Mission Investissements d'avenir	2019-11-06 16:35:00	2019-11-06 17:42:00	2019-11-07 09:57:46	2019-11-07 10:53:22	20	0	\N	\N
422509	ETUDES	AUTRE	\N	\N	\N	Audition plénière - GE Vigne et Vin - 2018	\N	2019-10-30 13:30:00	2019-10-30 15:00:00	\N	\N	11	0	\N	909
422589	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 Culture (Patrimoine)	PLF 2020 Culture (Patrimoine)	2019-10-29 17:00:00	2019-10-29 18:20:00	\N	\N	2	0	\N	\N
422594	COM_ENQUETE	PLENIERE	\N	LUBRIZOL	\N	Réunion de commission	\N	2019-11-07 09:45:00	2019-11-07 12:00:00	2019-11-07 14:47:49	2019-11-07 16:37:46	12	0	\N	\N
424587	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL Convention  UE-Arménie	\N	2019-11-06 14:00:00	2019-11-06 15:00:00	\N	\N	1	0	\N	\N
424720	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Travail et emploi	\N	2019-11-05 15:30:00	2019-11-05 16:15:00	\N	\N	1	0	\N	\N
440275	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition difficultés de recrutement et évolution des métiers	Audition difficultés de recrutement et évolution des métiers -FFB	2019-12-17 10:00:00	2019-12-17 11:00:00	\N	\N	2	0	\N	\N
440278	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition entreprises responsables et engagées	Audition entreprises responsables et engagées - METI	2019-12-17 14:30:00	2019-12-17 15:30:00	\N	\N	3	0	\N	\N
440283	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition entreprises responsables et engagées	Audition entreprises responsables et engagées - COOP FR	2019-12-17 15:45:00	2019-12-17 16:45:00	\N	\N	2	0	\N	\N
440286	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition entreprises responsables et engagées	Audition entreprises responsables et engagées - Prophil	2019-12-17 17:00:00	2019-12-17 18:00:00	\N	\N	2	0	\N	\N
448809	CONF_PRES	AUCUNE	\N	\N	\N	Conf. des Présidents	Conférences des Présidents	2020-01-22 19:35:00	2020-01-22 20:15:00	\N	\N	20	0	\N	\N
453805	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Système universel de retraite	\N	2020-02-05 16:30:00	2020-02-05 17:15:00	\N	\N	2	0	\N	\N
453809	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Système universel de retraite	\N	2020-02-05 17:15:00	2020-02-05 18:15:00	\N	\N	3	0	\N	\N
453813	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Système universel de retraite	\N	2020-02-05 18:15:00	2020-02-05 19:00:00	\N	\N	3	0	\N	\N
453952	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution Plastique (déplacement à Angers)	Audition rapporteurs Pollution Plastique (déplacement à Angers) ATE	2020-02-13 14:00:00	2020-02-13 16:30:00	\N	\N	2	0	\N	\N
453955	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution Plastique (déplacement à Angers)	Audition rapporteurs Pollution Plastique (déplacement à Angers) Versoo	2020-02-13 16:30:00	2020-02-13 18:00:00	\N	\N	2	0	\N	\N
453958	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteur Pollution plastique (déplacement Région parisienne)	Audition rapporteur Pollution plastique (déplacement Région parisienne) SYCTOM	2020-02-18 14:30:00	2020-02-18 17:00:00	\N	\N	2	0	\N	\N
453961	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution plastique 	Audition rapporteurs Pollution plastique -H&M France-Eco TLC	2020-02-20 14:00:00	2020-02-20 16:00:00	\N	\N	2	0	\N	\N
453964	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution Plastique	Audition rapporteurs Pollution Plastique (table ronde Sport/Jouets)	2020-02-27 14:00:00	2020-02-27 16:00:00	\N	\N	2	0	\N	\N
453968	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition difficultés de recrutement et évolution des métiers	Audition difficultés de recrutement et évolution des métiers - DG Emploi Commission européenne	2020-02-04 10:00:00	2020-02-04 11:00:00	\N	\N	2	0	\N	\N
453971	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition entreprises responsables et engagées	Audition entreprises responsables et engagées - AMF	2020-02-04 16:05:00	2020-02-04 17:10:00	\N	\N	2	0	\N	\N
453974	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition entreprises responsables et engagées	Audition entreprises responsables et engagées - Novethic	2020-02-04 17:10:00	2020-02-04 18:00:00	\N	\N	2	0	\N	\N
453977	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition entreprises responsables et engagées	Audition entreprises responsables et engagées - Groupe MAIF	2020-02-04 18:00:00	2020-02-04 19:00:00	\N	\N	2	0	\N	\N
453980	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition entreprises responsables et engagées	Audition entreprises responsables et engagées - C3D	2020-02-05 11:00:00	2020-02-05 12:20:00	\N	\N	2	0	\N	\N
453984	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition difficultés de recrutement et évolution des métiers	Audition difficultés de recrutement et évolution des métiers - Unédic	2020-02-06 10:00:00	2020-02-06 11:20:00	\N	\N	2	0	\N	\N
453987	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition difficultés de recrutement et évolution des métiers	Audition difficultés de recrutement et évolution des métiers - Ambassades du Canada et d'Allemagne	2020-02-06 11:20:00	2020-02-06 12:50:00	\N	\N	2	0	\N	\N
454127	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI  Coopération France Russie	RI Coopération France Russie	2020-02-05 16:30:00	2020-02-05 18:00:00	\N	\N	2	0	\N	\N
454130	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI  Coopération France Russie	RI Coopération France Russie	2020-02-06 10:00:00	2020-02-06 11:00:00	\N	\N	3	0	\N	\N
454134	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution plastique (déplacement à Orléans)	Audition rapporteurs Pollution plastique (déplacement à Orléans) LSDH	2020-02-28 09:15:00	2020-02-28 14:00:00	\N	\N	2	0	\N	\N
454144	GIA	AUCUNE	\N	\N	\N	Rencontre avec l'ambassadeur du Tadjikistan	Rencontre avec l'ambassadeur du Tadjikistan	2020-02-18 13:30:00	2020-02-18 14:30:00	\N	\N	1	0	556	\N
455761	COM_EURO	CONTROLE	\N	AFEU	\N	Audition de Mme Amélie de Montchalin, secrétaire d'État chargée des affaires européennes	Audition de Mme Amélie de Montchalin, secrétaire d'État chargée des affaires européennes	2020-02-19 13:35:00	2020-02-19 15:00:00	2020-02-20 12:53:53	2020-02-20 16:26:59	39	0	\N	\N
456242	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 19 février 2020	Réunion de la commission des affaires européennes du 19 février 2020	2020-02-19 17:05:00	2020-02-19 18:15:00	2020-02-20 12:55:29	2020-02-20 16:26:59	15	0	\N	\N
456289	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Français établis hors de France	PPL Français établis hors de France	2020-02-18 15:00:00	2020-02-18 15:45:00	\N	\N	1	0	\N	\N
457143	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	Expertises psychiatriques en matière pénale	\N	2020-02-25 15:00:00	2020-02-25 16:00:00	\N	\N	1	0	\N	\N
457145	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	Expertises spsychiatriques en matière pénale	\N	2020-02-25 17:30:00	2020-02-25 18:30:00	\N	\N	1	0	\N	\N
457403	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL congés de deuil pour le décès d'un enfant	PPL congés de deuil pour le décès d'un enfant	2020-03-03 15:50:00	2020-03-03 18:00:00	\N	\N	131	0	\N	\N
457407	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Cour des comptes	Débat Cour des comptes	2020-03-04 18:00:00	2020-03-04 20:10:00	\N	\N	99	0	\N	\N
457451	GIA	AUCUNE	\N	\N	\N	Entretien avec Mme Sylvie BERMANN, Ambassadeur de France	Entretien avec Mme Sylvie BERMANN, Ambassadeur de France	2020-02-26 08:00:00	2020-02-26 09:30:00	\N	\N	11	0	608	\N
458431	COM_PERMANENTE	AUTRE	\N	CDD	\N	Mission d'information sur l'empreinte environnementale du numérique	Audition de représentants du Conseil national du numérique	2020-02-26 13:30:00	2020-02-26 14:20:00	\N	\N	7	0	\N	\N
458489	COM_PERMANENTE	AUTRE	\N	CDD	\N	Mission d'information sur l'empreinte environnementale du numérique	Audition de représentants de Alliance Green IT	2020-02-26 14:25:00	2020-02-26 15:00:00	\N	\N	6	0	\N	\N
458498	ETUDES	AUTRE	\N	\N	\N	Auditions	Auditions industriels du sucre	2020-02-26 13:45:00	2020-02-26 15:00:00	\N	\N	14	0	\N	919
458747	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2020-03-03 18:00:00	2020-03-03 19:20:00	2020-03-04 14:32:25	2020-03-04 16:20:04	28	0	\N	\N
458748	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2020-03-04 10:30:00	2020-03-04 12:30:00	2020-03-04 14:37:09	2020-03-04 16:19:59	31	1	\N	\N
458749	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2020-03-04 16:35:00	2020-03-04 17:55:00	2020-03-05 15:16:01	2020-03-05 15:34:36	25	0	\N	\N
458750	COM_EURO	AUDRAP	\N	AFEU	\N	audition rapporteur - Strasbourg - Adhésion UE à la CEDH	Adhésion de l'UE à la CEDH - audition Mme Benoît-Rohmer	2020-02-10 10:45:00	2020-02-10 11:40:00	\N	\N	2	0	\N	\N
459015	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GS stratégie industrielle de l'UE	GS stratégie industrielle de l'UE	2020-01-14 08:30:00	2020-01-14 09:45:00	\N	\N	1	0	\N	\N
459017	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GS stratégie industrielle de l'UE	GS stratégie industrielle de l'UE	2020-01-14 09:45:00	2020-01-14 11:15:00	\N	\N	1	0	\N	\N
459019	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GS stratégie industrielle de l'UE	GS stratégie industrielle de l'UE	2020-01-14 11:15:00	2020-01-14 12:30:00	\N	\N	1	0	\N	\N
459251	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Coronavirus	Débat Coronavirus	2020-03-04 21:40:00	2020-03-04 23:50:00	\N	\N	92	0	\N	\N
459262	COM_PERMANENTE	DEPLACEMENT	\N	CDD	\N	MI Gouvernance des ports maritimes	Visite du Grand Port Maritime de Marseille-Fos	2020-02-27 11:00:00	2020-02-27 17:15:00	\N	\N	5	0	\N	\N
375556	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Organisation du système de santé	PJL Organisation du système de santé	2019-05-06 15:00:00	2019-05-06 16:00:00	\N	\N	3	0	\N	\N
375560	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Organisation du système de santé	PJL Organisation du système de santé	2019-05-06 16:00:00	2019-05-06 17:15:00	\N	\N	3	0	\N	\N
376000	MISSION	AUCUNE	\N	TRANSPORTS	\N	Audition plénière - MI Gratuité des transports collectifs	\N	2019-05-07 14:05:00	2019-05-07 16:05:00	2019-05-07 16:47:32	2019-05-09 17:08:57	12	0	\N	\N
376282	DELEGATION	AUCUNE	\N	\N	DSOM	Table ronde avec les assureurs dans le cadre de l'étude sur les risques naturels majeurs	\N	2019-05-15 17:05:00	2019-05-15 18:40:00	2019-05-16 15:52:18	\N	7	0	\N	\N
376283	DELEGATION	AUCUNE	\N	\N	DSOM	Audition du CEREMA dans le cadre de l'étude sur les risques naturels outre-mer	\N	2019-05-16 09:05:00	2019-05-16 11:20:00	2019-05-16 12:52:09	\N	8	0	\N	\N
376284	DELEGATION	AUCUNE	\N	\N	DSOM	Audition du BRGM dans le cadre de l'étude sur les risques naturels outre-mer	\N	2019-05-23 09:05:00	2019-05-23 11:00:00	\N	\N	6	0	\N	\N
376285	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Santé au travail	MI Santé au travail	2019-05-07 14:00:00	2019-05-07 15:45:00	\N	\N	2	0	\N	\N
376603	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition - Suivi loi ELAN	\N	2019-05-07 13:55:00	2019-05-07 14:45:00	\N	\N	1	0	\N	\N
376605	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-05-15 09:35:00	2019-05-15 11:50:00	2019-05-17 09:47:23	2019-05-17 10:16:09	37	0	\N	\N
382594	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 22 mai 2019	Réunion de la commission des affaires européennes du 22 mai 2019	2019-05-22 14:50:00	2019-05-22 16:40:00	2019-05-22 19:37:40	2019-05-23 17:08:33	11	0	\N	\N
390967	MISSION	AUCUNE	\N	AERIEN	\N	Réunion plénière	\N	2019-06-18 15:30:00	2019-06-18 17:20:00	2019-06-21 16:36:28	2019-06-21 17:34:36	14	0	\N	\N
390969	MISSION	AUCUNE	\N	AERIEN	\N	Réunion plénière	\N	2019-06-19 16:00:00	2019-06-19 17:40:00	2019-06-21 16:39:07	2019-06-21 17:34:34	13	0	\N	\N
390972	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Inspection du travail - DIRECCTE IDF	Contrôle 2019 - Inspection du travail - DIRECCTE IDF	2019-06-12 14:30:00	2019-06-12 15:45:00	\N	\N	2	0	\N	\N
390975	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Fraude aux fonds européens - CCCOP	Contrôle 2019 - Fraude aux fonds européens - CCCOP	2019-06-11 08:45:00	2019-06-11 10:15:00	\N	\N	1	0	\N	\N
390977	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2019 - Fraude aux fonds européens - Déplacement Bruxelles	Contrôle 2019 - Fraude aux fonds européens - Déplacement Bruxelles	2019-06-13 07:25:00	2019-06-13 19:35:00	\N	\N	1	0	\N	\N
390979	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion de commission	\N	2019-06-13 14:05:00	2019-06-13 14:17:00	2019-06-13 15:50:38	2019-06-13 16:25:16	7	0	\N	\N
391251	DELEGATION	AUDRAP	\N	\N	PROS	Audition de Marc-Eric BOBILLIER CHAUMON - CNAM	\N	2019-07-02 15:00:00	2019-07-02 15:45:00	\N	\N	2	0	\N	\N
391300	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion de commission	\N	2019-06-18 09:10:00	2019-06-18 09:55:00	2019-06-18 11:27:20	2019-06-18 17:50:28	17	0	\N	\N
391308	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-06-19 10:40:00	2019-06-19 12:25:00	2019-06-19 14:33:22	2019-06-19 18:02:54	65	0	\N	\N
391333	DELEGATION	AUDRAP	\N	\N	PROS	Audition de l'OCDE	\N	2019-06-26 14:00:00	2019-06-26 15:00:00	\N	\N	2	0	\N	\N
391334	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI Nouveaux territoires de la culture	MI Nouveaux territoires de la culture	2019-06-12 16:15:00	2019-06-12 17:00:00	\N	\N	3	0	\N	\N
391349	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Redevances aéroportuaires et régulation - DTA	Contrôle 2019 - Redevances aéroportuaires et régulation - DTA	2019-06-13 14:30:00	2019-06-13 16:00:00	\N	\N	1	0	\N	\N
391356	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de Sébastien LECORNU ministre chargé des collectivités territoriales sur PJLR2018	Audition de Sébastien LECORNU, ministre chargé des collectivités territoriales sur le PJLR pour 2018	2019-06-18 17:00:00	2019-06-18 18:40:00	2019-06-18 18:47:51	2019-06-19 18:03:02	24	0	\N	\N
391358	COM_PERMANENTE	AUTRE	\N	FINC	\N	Compte rendu déplacement délégation du Bureau de la commission Danemark, Suède et Estonie	Compte rendu déplacement délégation du Bureau de la commission au Danemark, en Suède et en Estonie	2019-06-19 09:40:00	2019-06-19 10:30:00	2019-06-19 10:51:06	2019-06-19 18:02:54	27	0	\N	\N
391359	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de M. Éric LOMBARD, directeur général de la Caisse des dépôts et consignations	Audition de M. Éric LOMBARD, directeur général de la Caisse des dépôts et consignations	2019-06-19 10:40:00	2019-06-19 12:30:00	2019-06-19 19:39:54	2019-06-20 14:56:56	62	0	\N	\N
391303	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion de commission	\N	2019-06-19 09:09:00	2019-06-19 11:17:00	2019-06-24 16:10:52	2019-06-24 16:11:56	42	0	\N	\N
391360	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de Emmanuelle WARGON, secrétaire d'État près du ministre d'État sur le PJLR 2018	Audition de Emmanuelle WARGON, secrétaire d'État auprès du ministre d'État sur le PJLR pour 2018	2019-06-19 16:35:00	2019-06-19 17:30:00	2019-06-19 19:40:16	2019-06-20 14:56:55	17	0	\N	\N
391363	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Emploi des seniors	\N	2019-06-19 14:00:00	2019-06-19 17:45:00	\N	\N	3	0	\N	\N
416557	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJLF 2020 - Avis Transports aériens-Audition de Mme Nicole Bonnefoy	PJLF 2020 - Avis Transports aériens-Audition de Mme Nicole Bonnefoy	2019-10-15 16:00:00	2019-10-15 19:00:00	\N	\N	1	0	\N	\N
428370	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJLF pour 2020 - P 212	PJLF pour 2020- P 212	2019-11-13 16:30:00	2019-11-13 17:30:00	\N	\N	1	0	\N	\N
432678	DELEGATION	AUCUNE	\N	\N	PROS	Audition de France Stratégie	Audition de M. Gilles de Margerie, commissaire général de France Stratégie	2019-12-12 09:05:00	2019-12-12 10:15:00	\N	\N	12	0	\N	\N
432800	COM_ENQUETE	AUTRE	\N	LUBRIZOL	\N	Réunion commission	\N	2019-11-27 14:00:00	2019-11-27 15:00:00	2019-11-29 10:09:28	2019-11-29 10:12:33	9	0	\N	\N
433168	COM_SPECIALE	AUDRAP	\N	BIOETHIQUE	\N	Audition rapporteur	\N	2019-11-26 15:00:00	2019-11-26 16:30:00	\N	\N	2	0	\N	\N
433185	COM_EURO	AUTRE	\N	AFEU	\N	\N	\N	2019-11-27 13:40:00	2019-11-27 15:00:00	2019-11-29 18:06:02	2019-12-02 14:04:00	12	0	\N	\N
433574	COM_ENQUETE	AUTRE	\N	LUBRIZOL	\N	Réunion de commission	\N	2019-12-03 16:30:00	2019-12-03 17:45:00	2019-12-03 18:40:16	2019-12-04 14:10:48	11	0	\N	\N
450978	COM_ENQUETE	PLENIERE	\N	LUBRIZOL	\N	Réunion de commission	Réunion de la commision d'enquête	2020-02-04 16:34:00	2020-02-04 17:28:00	2020-02-04 18:02:45	2020-02-05 17:12:28	16	0	\N	\N
451300	DELEGATION	AUCUNE	\N	\N	DSOM	Audition du délégué interministériel à la transformation agricole des outre-mer	\N	2020-02-20 09:30:00	2020-02-20 10:45:00	\N	\N	10	0	\N	\N
451323	DELEGATION	AUCUNE	\N	\N	211	Table ronde sur la place des femmes dans les médias audiovisuels	Table ronde sur la place des femmes dans les médias audiovisuels	2020-02-27 09:30:00	2020-02-27 12:00:00	2020-02-27 12:52:54	\N	11	0	\N	\N
451356	COM_ENQUETE	PLENIERE	\N	RADICALI	\N	Auditions plénières - SCRT - AMIF	Auditions plénières - SCRT - AMIF	2020-02-04 15:40:00	2020-02-04 18:50:00	2020-02-04 19:21:29	2020-02-05 17:12:27	10	0	\N	\N
454081	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 (Suite) - La masse salariale du MEAE - MEAE	Contrôle 2019 (Suite) - La masse salariale du MEAE - MEAE	2020-02-05 16:30:00	2020-02-05 17:30:00	\N	\N	2	0	\N	\N
454084	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - L'IHEDN et L'INHESJ - AA-IHEDN / ANA-INHESJ	Contrôle 2020 - L'IHEDN et L'INHESJ - AA-IHEDN / ANA-INHESJ	2020-02-06 15:00:00	2020-02-06 17:30:00	\N	\N	1	0	\N	\N
454086	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58°2 2019 - Pilotage par l'État grands projets informatiques - Cour des comptes	58°2 2019 - Pilotage par l'État grands projets informatiques - Cour des comptes	2020-02-04 16:00:00	2020-02-04 17:15:00	\N	\N	1	0	\N	\N
454088	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 2020 - Article 55 de la loi SRU - Cour des comptes	58-2 2020 - Article 55 de la loi SRU - Cour des comptes	2020-02-06 17:00:00	2020-02-06 18:00:00	\N	\N	1	0	\N	\N
454090	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - Les aides à la presse - Table ronde distribution	Contrôle 2020 - Les aides à la presse - Table ronde distribution	2020-02-07 10:30:00	2020-02-07 11:15:00	\N	\N	1	0	\N	\N
435244	GIA	AUCUNE	\N	\N	\N	Coopé - Visite de M. Matej Tonin, député slovène	Coopé - Visite de M. Matej Tonin, député slovène	2019-11-27 17:30:00	2019-11-27 19:00:00	\N	\N	2	0	529	\N
437314	GIA	AUCUNE	\N	\N	\N	Audition de Thierry MATHOU, Directeur Asie et Océnaie du MEAE	Audition de Thierry MATHOU, Directeur Asie et Océnaie du MEAE	2019-12-03 15:00:00	2019-12-03 16:00:00	\N	\N	8	0	609	\N
456288	COM_SPECIALE	AUDRAP	\N	ASAP	\N	Auditions CS ASAP	\N	2020-02-18 16:30:00	2020-02-18 18:30:00	\N	\N	0	0	\N	\N
473478	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de Benoît Vallet en vue de sa nomination à l'Anses (en téléconférence)	\N	2020-06-04 11:10:00	2020-06-04 12:15:00	2020-06-08 15:41:02	2020-06-08 16:33:57	20	0	\N	\N
473479	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Transports-Mobivia	Covid-19-Transports-Mobivia	2020-05-25 14:00:00	2020-05-25 14:50:00	\N	\N	10	0	\N	\N
473480	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Transports-Europcar	Covid-19-Transports-Europcar	2020-05-25 15:00:00	2020-05-25 15:50:00	\N	\N	7	0	\N	\N
473498	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition de Mme Féret (associations de victimes de maladies professionnelles)	\N	2020-05-29 09:00:00	2020-05-29 10:00:00	\N	\N	2	0	\N	\N
473499	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Transports-FIEV	Covid-19-Transports-FIEV	2020-05-26 15:00:00	2020-05-26 16:00:00	\N	\N	4	0	\N	\N
473500	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition de Mme Féret (associations de représentants de victimes du covid-19)	\N	2020-05-29 10:15:00	2020-05-29 11:20:00	\N	\N	2	0	\N	\N
473501	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition de Mme Féret (CNAM)	\N	2020-06-02 09:00:00	2020-06-02 09:50:00	\N	\N	2	0	\N	\N
473502	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition de Mme Féret (DSS)	\N	2020-06-04 14:30:00	2020-06-04 15:25:00	\N	\N	2	0	\N	\N
473504	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition de Mme Féret (CFDT)	\N	2020-06-05 09:00:00	2020-06-05 10:00:00	\N	\N	2	0	\N	\N
473506	COM_EURO	AUTRE	\N	AFEU	\N	Audition de Mme Emily O'Reilly, médiatrice européenne	\N	2020-05-28 10:30:00	2020-05-28 11:30:00	\N	\N	12	0	\N	\N
473519	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Transports-Com'Publics	Covid-19-Transports-Com'Publics	2020-05-27 10:00:00	2020-05-27 11:00:00	\N	\N	8	0	\N	\N
473520	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Accès au numérique-Fédération française des télécoms	Covid-19-Accès au numérique-Fédération française des télécoms	2020-05-15 11:00:00	2020-05-15 12:40:00	\N	\N	11	0	\N	\N
473566	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Statut des travailleurs des plateformes - Audition FNAE (visioconférence)	\N	2020-05-25 11:45:00	2020-05-25 12:45:00	\N	\N	2	0	\N	\N
473567	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Prévention risques-Syndicats des inspecteurs des IPCE	Covid-19-Prévention risques-Syndicats des inspecteurs des IPCE	2020-04-24 10:30:00	2020-04-24 11:30:00	\N	\N	4	0	\N	\N
473568	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Statut des travailleurs des plateformes - Audition de la DGT (visioconférence)	\N	2020-05-25 14:15:00	2020-05-25 15:00:00	\N	\N	2	0	\N	\N
473569	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Prévention risques-IRSN	Covid-19-Prévention risques-IRSN	2020-04-24 11:30:00	2020-04-24 12:30:00	\N	\N	8	0	\N	\N
376987	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-05-16 11:35:00	2019-05-16 13:20:00	2019-05-16 15:11:15	2019-05-17 10:16:06	30	0	\N	\N
473570	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Prévention risques-Direction générale de la prévention des risques	Covid-19-Prévention risques-Direction générale de la prévention des risques	2020-04-24 13:30:00	2020-04-24 14:30:00	\N	\N	7	0	\N	\N
473571	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Prévention des risques-Électricité de France	Covid-19-Prévention des risques-Électricité de France	2020-05-13 10:45:00	2020-05-13 12:00:00	\N	\N	13	0	\N	\N
473572	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Statut des travailleurs des plateformes - Table ronde organisations syndicales (visio)	\N	2020-05-25 15:00:00	2020-05-25 16:00:00	\N	\N	2	0	\N	\N
473573	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Transports aériens-Fédération nationale de l'aviation marchande (FNAM)	Covid-19-Transports aériens-Fédération nationale de l'aviation marchande (FNAM)	2020-04-08 11:00:00	2020-04-08 12:00:00	\N	\N	1	0	\N	\N
473574	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Transports aériens-Air France	Covid-19-Transports aériens-Air France	2020-04-14 17:00:00	2020-04-14 18:00:00	\N	\N	1	0	\N	\N
473575	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Transports aériens-Aéroports de Paris	Covid-19-Transports aériens-Aéroports de Paris	2020-04-16 17:15:00	2020-04-16 18:45:00	\N	\N	15	0	\N	\N
473576	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Statut des travailleurs des plateformes - Audition de sociologues (visioconférence)	\N	2020-05-25 09:45:00	2020-05-25 10:45:00	\N	\N	2	0	\N	\N
473578	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Transports aériens-Union des aéroports français	Covid-19-Transports aériens-Union des aéroports français	2020-04-23 14:30:00	2020-04-23 16:00:00	\N	\N	8	0	\N	\N
473602	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Statut des travailleurs des plateformes - Table ronde Clap & Coursiers Gironde (visio)	\N	2020-05-25 10:45:00	2020-05-25 11:45:00	\N	\N	3	0	\N	\N
473605	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Gestion des déchets-CNRS	Covid-19-Gestion des déchets-CNRS	2020-05-28 11:30:00	2020-05-28 12:30:00	\N	\N	10	0	\N	\N
473926	MISSION	AUDRAP	\N	GUYANE	\N	Audition de Mme Reguer-Petit	\N	2020-05-28 15:45:00	2020-05-28 16:45:00	\N	\N	14	0	\N	\N
473928	COM_ENQUETE	PLENIERE	\N	RADICALI	\N	Audition de M. Jérôme HARNOIS et Mme Nathalie GONDARD, RATP (visioconférence)	\N	2020-06-04 16:00:00	2020-06-04 17:15:00	2020-06-04 19:53:57	2020-06-05 15:57:44	6	0	\N	\N
474184	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Procurations électorales - Exmen amendements séance	PPL Procurations électorales - Exmen amendements séance	2020-06-02 17:00:00	2020-06-02 19:00:00	\N	\N	0	0	\N	\N
474192	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi Covid-19 - Sécurité civile - Olivier RICHEFOU, président de la CNIS	\N	2020-05-28 11:00:00	2020-05-28 12:00:00	\N	\N	2	0	\N	\N
474195	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Procurations électorales - Exmen amendements séance	PPL Procurations électorales - Exmen amendements séance	2020-06-02 13:40:00	2020-06-02 14:10:00	2020-06-02 14:38:41	2020-06-02 18:30:18	15	0	\N	\N
474210	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFR pour 2020 (2) "Travail et emploi" - DGEFP	PLFR pour 2020 (2) "Travail et emploi" - DGEFP	2020-05-18 17:00:00	2020-05-18 18:00:00	\N	\N	2	0	\N	\N
474213	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFR pour 2020 (2) "Travail et emploi" - OFCE	PLFR pour 2020 (2) "Travail et emploi" - OFCE	2020-05-20 17:00:00	2020-05-20 18:00:00	\N	\N	2	0	\N	\N
474216	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n°312 - Création d'un fonds d'urgence - Cabinet MEAE	PPL n°312 - Création d'un fonds d'urgence - Cabinet MEAE	2020-05-19 18:45:00	2020-05-19 19:30:00	\N	\N	1	0	\N	\N
474218	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n°402 - Soutien des entreprises - DG Trésor	PPL n°402 - Soutien des entreprises - DG Trésor	2020-05-19 16:00:00	2020-05-19 17:00:00	\N	\N	1	0	\N	\N
474220	COM_ENQUETE	AUDRAP	\N	RADICALI	\N	Lieutenant-colonel David MAITROT, gendarmerie nationale	\N	2020-05-29 10:00:00	2020-05-29 11:05:00	\N	\N	5	0	\N	\N
474226	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n°402 - Soutien des entreprises - FFA	PPL n°402 - Soutien des entreprises - FFA	2020-05-20 11:00:00	2020-05-20 12:00:00	\N	\N	1	0	\N	\N
474228	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n°402 - Soutien des entreprises - CPME	PPL n°402 - Soutien des entreprises - CPME	2020-05-20 15:00:00	2020-05-20 16:00:00	\N	\N	1	0	\N	\N
474262	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n° 339 - Frais bancaires - UNAF / BdF	PPL n° 339 - Frais bancaires - UNAF / BdF	2020-05-05 14:30:00	2020-05-05 16:30:00	\N	\N	1	0	\N	\N
474264	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n° 339 - Frais bancaires - FBF / Banque Postale	PPL n° 339 - Frais bancaires - FBF / Banque Postale	2020-05-12 14:30:00	2020-05-12 16:30:00	\N	\N	1	0	\N	\N
474272	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n° 339 - Frais bancaires - DG Trésor	PPL n° 339 - Frais bancaires - DG Trésor	2020-05-13 18:00:00	2020-05-13 19:00:00	\N	\N	1	0	\N	\N
474276	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Examen d'amendements sur deux PPL, nomination d'un membre du bureau et de rapporteurs 	\N	2020-06-03 11:05:00	2020-06-03 11:25:00	2020-06-08 15:33:25	2020-06-08 16:33:58	38	1	\N	\N
474294	DELEGATION	AUCUNE	\N	\N	DSOM	Table ronde sur l'agriculture et la pêche	\N	2020-06-04 14:00:00	2020-06-04 17:30:00	\N	\N	11	0	\N	\N
474295	DELEGATION	AUDRAP	\N	\N	206	Audition Production de l'énergie dans le secteur agricole	Audition Production de l'énergie dans le secteur agricole - J.M. Most	2020-05-29 10:00:00	2020-05-29 11:15:00	\N	\N	1	0	\N	\N
376954	MISSION	AUDRAP	\N	TRANSPORTS	\N	Auditions MI Gratuité des transports	\N	2019-05-15 16:00:00	2019-05-15 19:00:00	\N	\N	7	0	\N	\N
376957	MISSION	AUCUNE	\N	TRANSPORTS	\N	Audition plénière MI Gratuité des transports	\N	2019-05-16 13:30:00	2019-05-16 15:00:00	2019-05-17 11:06:55	2019-05-17 15:02:23	7	0	\N	\N
376972	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Taxe sur les services numériques - Amazon	PJL Taxe sur les services numériques - Amazon	2019-04-30 14:00:00	2019-04-30 15:30:00	\N	\N	2	0	\N	\N
376976	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 -Ressources humaines du ministère des armées - DRH Armée de l'air	Contrôle 2019 -Ressources humaines du ministère des armées - DRH Armée de l'air	2019-04-30 15:45:00	2019-04-30 16:45:00	\N	\N	1	0	\N	\N
376978	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2019 - Recouvrement des amendes de stationnement - Déplacement Limoges	Contrôle 2019 - Recouvrement des amendes de stationnement - Déplacement Limoges	2019-05-06 06:30:00	2019-05-06 18:30:00	\N	\N	2	0	\N	\N
376981	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Sécurité informatiques des pouvoirs public - ANSSI	Contrôle 2019 - Sécurité informatique des pouvoirs publics - ANSSI	2019-05-07 14:30:00	2019-05-07 16:00:00	\N	\N	1	0	\N	\N
376983	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Mobilisation financements régionaux - Région Hauts-de-France	Contrôle 2019 - Mobilisation financements régionaux - Région Hauts-de-France	2019-05-07 15:00:00	2019-05-07 16:00:00	\N	\N	1	0	\N	\N
376985	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-05-14 09:00:00	2019-05-14 10:00:00	2019-05-14 10:17:14	2019-05-14 10:31:18	36	3	\N	\N
459638	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2020-02-20 09:30:00	2020-02-20 10:45:00	\N	\N	2	0	\N	\N
376990	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Déplacement d'une délégation du Bureau de la commission des finances - Danemark	Déplacement d'une délégation du Bureau de la commission des finances - Danemark	2019-05-05 17:50:00	2019-05-07 13:10:00	\N	\N	6	0	\N	\N
376997	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Déplacement d'une délégation du Bureau de la commission des finances - Suède	Déplacement d'une délégation du Bureau de la commission des finances - Suède	2019-05-07 14:20:00	2019-05-09 11:30:00	\N	\N	6	0	\N	\N
377004	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Déplacement d'une délégation du Bureau de la commission des finances - Estonie 	Déplacement d'une délégation du Bureau de la commission des finances - Estonie 	2019-05-09 15:45:00	2019-05-10 17:55:00	\N	\N	6	0	\N	\N
377015	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition commune sur le risque cyber dans les domaines économique et financier 	Audition commune sur le risque cyber dans les domaines économique et financier 	2019-05-15 10:55:00	2019-05-15 12:30:00	2019-05-15 12:51:49	2019-05-15 14:31:14	19	0	\N	\N
377016	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de M. Didier MIGAUD Puis de M. Gérald DARMANIN - Résultats et gestion budget 2018	Audition de M. Didier MIGAUD Puis de M. Gérald DARMANIN - Résultats et gestion budget 2018	2019-05-15 15:35:00	2019-05-15 18:20:00	2019-05-17 11:41:13	2019-05-17 15:02:04	33	0	\N	\N
382198	ETUDES	AUCUNE	\N	\N	\N	Rapport d'information auditions 2018/2019	Rapport d'information auditions 2018/2019	2019-05-21 14:00:00	2019-05-21 15:05:00	\N	\N	21	0	\N	919
383668	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Instituer un médiateur territorial dans certaines collectivités	PPL Instituer un médiateur territorial dans certaines collectivités	2019-05-28 09:30:00	2019-05-28 11:20:00	\N	\N	2	0	\N	\N
391388	DELEGATION	AUCUNE	\N	\N	DSOM	Audition dans le cadre de l'étude sur les risques naturels majeurs	\N	2019-06-19 14:45:00	2019-06-19 16:15:00	2019-06-19 18:00:28	\N	5	0	\N	\N
391436	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Création d'un droit voisin au profit des agences et éditeurs de presse	PPL Création d'un droit voisin au profit des agences et éditeurs de presse	2019-06-17 10:30:00	2019-06-17 13:00:00	\N	\N	1	0	\N	\N
391438	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Création d'un droit voisin au profit des agences et éditeurs de presse	PPL Création d'un droit voisin au profit des agences et éditeurs de presse	2019-06-17 15:30:00	2019-06-17 16:30:00	\N	\N	1	0	\N	\N
391440	COM_ENQUETE	PLENIERE	\N	SOUVERAINETE	\N	Auditions Claire Mathieu, Eric Leandri	\N	2019-06-12 16:25:00	2019-06-12 18:15:00	\N	\N	8	0	\N	\N
393941	ETUDES	AUCUNE	\N	\N	\N	Audition de Mme Evelyne Decorps, Préfète, administratrice supérieure des TAAF	\N	2019-06-19 11:30:00	2019-06-19 13:00:00	\N	\N	7	0	\N	938
394891	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2019-06-20 12:10:00	2019-06-20 12:30:00	\N	\N	3	0	\N	\N
400599	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Qualité frauduleuse de steaks hachés-Audition de M. TEYSSIER (Mérieux NutriSciences)	Audition de M. TEYSSIER - Silliker SAS (Groupe Mérieux NutriSciences)	2019-07-11 15:30:00	2019-07-11 16:15:00	\N	\N	1	0	\N	\N
400601	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Qualité frauduleuse de steaks hachés-Audition de MM. BAZIN et BOCQUET, sénateurs	Audition de MM. BAZIN et BOCQUET, sénateurs	2019-07-11 16:15:00	2019-07-11 17:15:00	\N	\N	1	0	\N	\N
400603	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-07-16 14:15:00	2019-07-16 14:24:00	2019-07-16 15:49:10	2019-07-16 17:50:14	29	1	\N	\N
400604	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF 2020 - Écologie - Société du Grand Paris	PLF 2020 - Écologie - Société du Grand Paris	2019-07-09 10:00:00	2019-07-09 11:00:00	\N	\N	1	0	\N	\N
400606	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions Mme de CIDRAC	\N	2019-07-11 15:20:00	2019-07-11 16:45:00	\N	\N	2	0	\N	\N
400614	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Les redevances aéroportuaires et leur régulation	Contrôle 2019 - Les redevances aéroportuaires et leur régulation - Thales / Syndicats contrôleurs	2019-07-09 14:15:00	2019-07-09 16:30:00	\N	\N	1	0	\N	\N
400616	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions Mme de CIDRAC	\N	2019-07-11 09:30:00	2019-07-11 10:00:00	\N	\N	6	0	\N	\N
400638	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions Mme de CIDRAC	\N	2019-07-12 11:00:00	2019-07-12 12:30:00	\N	\N	1	0	\N	\N
400644	DELEGATION	AUTRE	\N	\N	211	Réunion plénière	\N	2019-09-26 08:30:00	2019-09-26 10:00:00	2019-09-26 09:45:13	\N	8	0	\N	\N
400646	DELEGATION	AUCUNE	\N	\N	211	Examen du rapport d'information sur les violences faites aux femmes handicapées	Examen du rapport d'information sur les violences faites aux femmes 	2019-10-03 08:30:00	2019-10-03 10:15:00	2019-10-03 16:17:15	\N	13	0	\N	\N
400647	DELEGATION	AUCUNE	\N	\N	211	Événement - célébration du vingtième anniversaire de la délégation	Événement - célébration du vingtième anniversaire de la délégation	2019-10-10 09:30:00	2019-10-10 13:00:00	2019-10-10 17:35:02	\N	25	0	\N	\N
405061	COM_ENQUETE	PLENIERE	\N	SOUVERAINETE	\N	Auditions Amazon et Apple	\N	2019-09-03 16:15:00	2019-09-03 17:40:00	\N	\N	10	0	\N	\N
405062	COM_ENQUETE	PLENIERE	\N	SOUVERAINETE	\N	Audition de B. Le Maire	\N	2019-09-10 09:05:00	2019-09-10 10:35:00	2019-09-12 10:08:24	2019-09-12 15:34:47	6	0	\N	\N
405110	COM_PERMANENTE	AUTRE	\N	FINC	\N	Contrôles budgétaires Masse salariale MEAE et Financement logement social	Contrôles budgétaires Masse salariale MEAE et Financement logement social	2019-09-18 09:35:00	2019-09-18 11:10:00	2019-09-18 11:26:40	2019-09-18 11:29:21	28	0	\N	\N
405111	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-09-17 15:30:00	2019-09-17 19:45:00	2019-09-17 20:26:20	2019-09-18 11:29:21	25	1	\N	\N
405112	MISSION	DEPLACEMENT	\N	MARITIME	\N	MCI Sauvetage en mer - Déplacement Nouvelle-Calédonie	MCI Sauvetage en mer - Déplacement Nouvelle-Calédonie	2019-09-06 09:00:00	2019-09-06 12:00:00	\N	\N	1	0	\N	\N
405114	MISSION	DEPLACEMENT	\N	MARITIME	\N	MCI Sauvetage en mer - Déplacement Polynésie française	MCI Sauvetage en mer - Déplacement Polynésie française	2019-09-07 07:30:00	2019-09-07 17:00:00	\N	\N	2	0	\N	\N
405117	MISSION	DEPLACEMENT	\N	MARITIME	\N	MCI Sauvetage en mer - Déplacement Manche	MCI Sauvetage en mer - Déplacement Manche	2019-08-27 07:30:00	2019-08-27 13:00:00	\N	\N	1	0	\N	\N
405120	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Adoption de règlements locaux de publicité intercommunaux - Auditions Mme Estrosi	PPL Adoption de règlements locaux de publicité intercommunaux	2019-09-11 15:15:00	2019-09-11 16:05:00	\N	\N	1	0	\N	\N
450880	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Déplacement dans l'Aube	Déplacement dans l'Aube - Visite d'un site de production du groupe Avril	2020-01-31 09:30:00	2020-01-31 13:30:00	\N	\N	4	0	\N	\N
377013	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen Rapport et texte Taxe GAFA et Nomination Rapp Avis PJL Notre-Dame	Examen Rapport et texte Taxe GAFA et Nomination Rapp Avis PJL Notre-Dame	2019-05-15 09:10:00	2019-05-15 10:50:00	2019-05-15 12:50:46	2019-05-15 14:31:17	44	0	\N	\N
459268	COM_PERMANENTE	DEPLACEMENT	\N	CDD	\N	MI Gouvernance des ports maritimes	Visite du Grand Port Maritime de Bordeaux	2020-02-28 10:00:00	2020-02-28 16:30:00	\N	\N	4	0	\N	\N
460086	GIA	AUCUNE	\N	\N	\N	AG groupe d'amitié France-Allemagne	Assemblée générale du groupe d'amitié France-Allemagne	2020-03-03 13:45:00	2020-03-03 14:15:00	\N	\N	7	0	604	\N
460596	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2020-03-04 09:35:00	2020-03-04 12:05:00	2020-03-04 12:16:03	2020-03-04 16:20:01	36	0	\N	\N
460617	COM_PERMANENTE	AUDRAP	\N	FINC	\N	GT Réforme de la LOLF - DB	GT Réforme de la LOLF - Direction du Budget	2020-03-03 15:40:00	2020-03-03 17:00:00	\N	\N	8	0	\N	\N
460756	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL convention franco-belge sur l'aménagement de la Lys	\N	2020-03-04 08:30:00	2020-03-04 09:30:00	\N	\N	1	0	\N	\N
460822	ETUDES	AUCUNE	\N	\N	\N	Audition Mme Cattelot	Audition Mme Cattelot	2020-03-04 08:00:00	2020-03-04 09:30:00	\N	\N	10	0	\N	948
460834	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition GT Agriculteurs en détresse	Audition GT Agriculteurs en détresse - Audition ministère de l'agriculture	2020-03-03 16:20:00	2020-03-03 17:30:00	\N	\N	9	0	\N	\N
460844	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition GT Agriculteurs en détresse	Audition GT Agriculteurs en détresse - Audition CCMSA	2020-03-03 17:30:00	2020-03-03 18:40:00	\N	\N	8	0	\N	\N
461880	GIA	AUCUNE	\N	\N	\N	Rencontre Consul général de France à Jérusalem (M. René Troccaz)	\N	2020-03-04 16:00:00	2020-03-04 17:00:00	\N	\N	6	0	632	\N
461910	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Muktar Djumaliev, ambassadeur du Kirghizstan	\N	2020-03-04 12:30:00	2020-03-04 13:15:00	\N	\N	2	0	556	\N
461919	GIA	AUCUNE	\N	\N	\N	entretien avec S. E. Zaynal MANTAHA, Ambassadeur de Singapour à Paris	\N	2020-03-04 16:30:00	2020-03-04 17:30:00	\N	\N	3	0	609	\N
462507	GIA	AUCUNE	\N	\N	\N	Entretien avec l'Ambassadrice	Entretien avec l'Ambassadrice	2020-03-09 09:30:00	2020-03-09 10:00:00	\N	\N	3	0	610	\N
462511	DELEGATION	AUDRAP	\N	\N	211	Audition de représentants du MEDEF	Audition de représentants du MEDEF	2020-03-04 18:00:00	2020-03-04 19:00:00	\N	\N	3	0	\N	\N
462521	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de commission du 25 mars 2020	\N	2020-03-25 13:30:00	2020-03-25 15:00:00	\N	\N	0	0	\N	\N
462522	COM_EURO	AUTRE	\N	AFEU	\N	2e réunion du 25 mars	\N	2020-03-25 16:30:00	2020-03-25 18:00:00	\N	\N	0	0	\N	\N
462523	COM_EURO	AUDRAP	\N	AFEU	\N	Audition - P.Chamboredon	Audition - Mobilité des professionnels de santé	2020-03-03 10:00:00	2020-03-03 11:50:00	\N	\N	1	0	\N	\N
462525	COM_EURO	AUDRAP	\N	AFEU	\N	Audition - Conseil national des pharmaciens	Audition - Mobilité des professionnels de santé	2020-03-03 16:00:00	2020-03-03 17:40:00	\N	\N	1	0	\N	\N
462629	COM_ENQUETE	AUDRAP	\N	SOLS	\N	CE Pollution des sols	CE Pollution des sols	2020-03-17 09:30:00	2020-03-17 11:00:00	\N	\N	0	0	\N	\N
462657	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI SCAF	\N	2020-03-10 17:30:00	2020-03-10 18:45:00	\N	\N	1	0	\N	\N
462659	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI SCAF	\N	2020-03-11 11:00:00	2020-03-11 12:30:00	\N	\N	2	0	\N	\N
462662	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI SCAF	\N	2020-03-12 10:15:00	2020-03-12 12:15:00	\N	\N	1	0	\N	\N
462664	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI SCAF	\N	2020-03-12 15:30:00	2020-03-12 17:00:00	\N	\N	1	0	\N	\N
462908	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2020-03-25 15:01:00	2020-03-25 16:05:00	\N	\N	17	0	\N	\N
462909	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2020-04-01 15:00:00	2020-04-01 16:00:00	\N	\N	17	0	\N	\N
463181	CONF_PRES	AUCUNE	\N	\N	\N	Conf. Prés.	Conférence des Présidents	2020-03-19 14:15:00	2020-03-19 14:45:00	\N	\N	22	0	\N	\N
463408	COM_PERMANENTE	AUTRE	\N	CAE	\N	\N	\N	2020-03-27 11:00:00	2020-03-27 13:20:00	\N	\N	34	0	\N	\N
463587	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de Mm Belloubet sur les mesures d'urgence prises par le Gouvernement	Audition de Mm Belloubet sur les mesures d'urgence prises par le Gouvernement 	2020-04-09 16:00:00	2020-04-09 18:30:00	\N	\N	37	0	\N	\N
463588	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2020-04-10 15:30:00	2020-04-10 17:30:00	\N	\N	32	0	\N	\N
463589	DELEGATION	AUCUNE	\N	\N	DSOM	Réunion sur la crise sanitaire dans les outre-mer	\N	2020-04-09 16:00:00	2020-04-09 17:30:00	\N	\N	12	0	\N	\N
463592	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition du Conseil national des achats	\N	2020-04-03 16:30:00	2020-04-03 17:15:00	\N	\N	2	0	\N	\N
463595	DELEGATION	AUCUNE	\N	\N	COLTER	Audition de Sébastien Lecornu	\N	2020-04-09 10:00:00	2020-04-09 11:45:00	\N	\N	27	0	\N	\N
464188	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Cybersécurité en période de crise sanitaire	\N	2020-04-08 11:00:00	2020-04-08 12:25:00	\N	\N	2	0	\N	\N
464191	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Rapatriement des Français bloqués à l'étranger	\N	2020-03-30 16:30:00	2020-03-30 17:45:00	\N	\N	2	0	\N	\N
464287	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFR pour 2020 - FFA	PLFR pour 2020 - FFA	2020-04-10 17:00:00	2020-04-10 18:00:00	\N	\N	1	0	\N	\N
466648	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	GT Covid19 Création	Audition Prodiss	2020-04-24 15:30:00	2020-04-24 17:00:00	\N	\N	5	0	\N	\N
466671	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	GT Covid19 Création	Audition B. Munin - MCC	2020-04-27 14:30:00	2020-04-27 15:30:00	\N	\N	3	0	\N	\N
466874	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid 19 Sport	Echanges entre membres du GT	2020-04-24 09:00:00	2020-04-24 09:45:00	\N	\N	6	0	\N	\N
467705	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PJL - Prorogation de l'état d'urgence sanitaire	\N	2020-05-04 09:00:00	2020-05-04 10:00:00	2020-05-05 16:08:48	2020-05-05 16:37:24	12	0	\N	\N
467706	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Prorogation de l'état d'urgence sanitaire - Examdes motions et amendements de seance	PJL Prorogation de l'état d'urgence sanitaire - Examdes motions et amendements de seance	2020-05-04 20:30:00	2020-05-04 21:10:00	2020-05-12 19:26:01	\N	22	1	\N	\N
468161	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi urgence Covid-19 - Prisons et autres lieux privatifs de liberté	Audition du directeur interrégional des services pénitentiaires de la région Grand Est	2020-05-05 09:00:00	2020-05-05 10:30:00	\N	\N	4	0	\N	\N
468212	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi Covid-19 - Juridictions judiciaires et administratives	Audition du tribunal judiciaire de Montpellier et de Strasbourg	2020-04-30 14:00:00	2020-04-30 17:00:00	\N	\N	4	0	\N	\N
468525	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid 19 Jeunesse et Vie associative	Table ronde Colonies	2020-05-06 09:00:00	2020-05-06 10:30:00	\N	\N	2	0	\N	\N
468529	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi Covid-19 - Juridictions judiciaires et administratives	Audition du secrétariat général du ministère de la justice et de la direction des services judiciaires	2020-05-06 11:00:00	2020-05-06 12:00:00	\N	\N	4	0	\N	\N
468580	DELEGATION	AUCUNE	\N	\N	COLTER	Audition S. Bern + présentation rapport Patrimoine	\N	2020-05-07 09:30:00	2020-05-07 12:30:00	2020-05-07 14:59:07	\N	21	0	\N	\N
468583	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Droit du travail - Audition ANDRH (visio-conf)	\N	2020-04-30 14:00:00	2020-04-30 15:00:00	\N	\N	3	0	\N	\N
468588	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Droit du travail - Audition Direction générale travail (audio-conf)	\N	2020-05-05 14:00:00	2020-05-05 15:00:00	\N	\N	4	0	\N	\N
468628	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid19 Création	Audition Audiens	2020-05-06 18:00:00	2020-05-06 19:45:00	\N	\N	5	0	\N	\N
468967	COM_PERMANENTE	AUTRE	\N	FINC	\N	PJL de règlement 20169-Audition Gérald Darmanin - Nominations Rapporteurs 402-312-2907	PJL de règlement 20169-Audition Gérald Darmanin - Nominations Rapporteurs PPL 402-312 et saisine PJL 2907(AN)	2020-05-13 16:40:00	2020-05-13 18:35:00	2020-05-13 20:49:50	2020-05-14 16:55:00	32	0	\N	\N
468968	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de M. Robert OPHÈLE, président de l'Autorité des marchés financiers (AMF)	Audition de M. Robert OPHÈLE, président de l'Autorité des marchés financiers (AMF)	2020-05-14 14:35:00	2020-05-14 16:00:00	2020-05-14 16:41:52	2020-05-14 16:55:17	27	0	\N	\N
468972	DELEGATION	AUCUNE	\N	\N	DSOM	Audition de Mme Annick Girardin	\N	2020-05-14 15:00:00	2020-05-14 17:30:00	\N	\N	20	0	\N	\N
468976	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFR pour 2020 (2) "Travail et emploi" - Cabinet ministre du travail	PLFR pour 2020 (2) "Travail et emploi" - Suivi mesures crise covid-19 - Cabinet ministre du travail 	2020-05-06 17:00:00	2020-05-06 18:00:00	\N	\N	2	0	\N	\N
373993	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion de commission	\N	2019-04-30 16:00:00	2019-04-30 16:40:00	2019-04-30 17:16:59	2019-04-30 17:33:04	25	2	\N	\N
374549	MISSION	AUDRAP	\N	INFRACTIONS	\N	Ministère des armées	\N	2019-04-30 10:00:00	2019-04-30 10:50:00	\N	\N	3	0	\N	\N
374856	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion de commission	\N	2019-05-02 10:30:00	2019-05-02 11:50:00	2019-05-02 12:37:35	2019-05-02 13:51:26	17	0	\N	\N
377904	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Cannabis et santé publique	Débat Cannabis et santé publique	2019-05-29 16:15:00	2019-05-29 17:30:00	\N	\N	28	0	\N	\N
377905	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Organisation système de santé	PJL Organisation système de santé	2019-06-03 15:00:00	2019-06-03 19:35:00	\N	\N	69	0	\N	\N
377916	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Organisation système de santé	PJL Organisation système de santé	2019-06-03 21:30:00	2019-06-04 00:25:00	\N	\N	61	0	\N	\N
377917	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2019-06-04 09:30:00	2019-06-04 12:45:00	\N	\N	36	0	\N	\N
377918	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Organisation système de santé	PJL Organisation système de santé	2019-06-04 14:30:00	2019-06-04 20:05:00	\N	\N	183	0	\N	\N
377919	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Organisation système de santé	PJL Organisation système de santé	2019-06-04 21:35:00	2019-06-05 00:55:00	\N	\N	114	0	\N	\N
377920	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Organisation système de santé	PJL Organisation système de santé	2019-06-05 14:30:00	2019-06-05 20:00:00	\N	\N	187	0	\N	\N
377922	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Organisation système de santé	PJL Organisation système de santé	2019-06-05 21:30:00	2019-06-06 01:45:00	\N	\N	103	0	\N	\N
377925	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Organisation système de santé	PJL Organisation système de santé	2019-06-06 10:30:00	2019-06-06 13:30:00	\N	\N	103	0	\N	\N
377926	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2019-06-06 15:00:00	2019-06-06 16:10:00	\N	\N	255	0	\N	\N
377927	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Organisation système de santé	PJL Organisation système de santé	2019-06-06 16:20:00	2019-06-06 19:55:00	\N	\N	81	0	\N	\N
377928	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Organisation système de santé	PJL Organisation système de santé	2019-06-06 21:30:00	2019-06-07 00:30:00	\N	\N	40	0	\N	\N
377975	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2019-06-11 16:55:00	2019-06-11 18:10:00	\N	\N	311	0	\N	\N
377976	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Conseillers métropole Lyon élections sénatoriales	PPL Conseillers métropole Lyon élections sénatoriales	2019-06-11 19:10:00	2019-06-11 19:55:00	\N	\N	94	0	\N	\N
377978	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL habitat insalubre	PPL habitat insalubre	2019-06-11 21:30:00	2019-06-12 01:05:00	\N	\N	52	0	\N	\N
377979	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Statut élu communal	PPL Statut élu communal	2019-06-12 16:45:00	2019-06-12 20:45:00	\N	\N	113	0	\N	\N
377992	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR Règlement du Sénat	PPR Règlement du Sénat	2019-06-18 14:35:00	2019-06-18 19:00:00	\N	\N	153	0	\N	\N
377995	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL médiateur territorial	PPL médiateur territorial	2019-06-13 14:30:00	2019-06-13 15:55:00	\N	\N	36	0	\N	\N
378003	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Transformation fonction publique	PJL Transformation fonction publique	2019-06-18 19:01:00	2019-06-18 20:05:00	\N	\N	71	0	\N	\N
378004	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Transformation fonction publique	PJL Transformation fonction publique	2019-06-18 21:35:00	2019-06-19 00:20:00	\N	\N	70	0	\N	\N
378005	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Transformation fonction publique	PJL Transformation fonction publique	2019-06-19 14:30:00	2019-06-19 19:25:00	\N	\N	145	0	\N	\N
378006	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Transformation fonction publique	PJL Transformation fonction publique	2019-06-19 21:30:00	2019-06-20 00:25:00	\N	\N	69	0	\N	\N
378052	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Agence nationale cohésion des territoires	PPL Agence nationale cohésion des territoires	2019-06-20 11:35:00	2019-06-20 13:25:00	\N	\N	59	0	\N	\N
378053	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2019-06-20 15:00:00	2019-06-20 16:05:00	\N	\N	219	0	\N	\N
378054	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Transformation fonction publique	PJL Transformation fonction publique	2019-06-20 16:15:00	2019-06-20 20:05:00	\N	\N	47	0	\N	\N
378055	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Transformation fonction publique	PJL Transformation fonction publique	2019-06-20 21:35:00	2019-06-21 00:00:00	\N	\N	29	0	\N	\N
378091	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Transformation fonction publique	PJL Transformation fonction publique	2019-06-25 14:30:00	2019-06-25 16:20:00	\N	\N	108	0	\N	\N
378092	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Transformation fonction publique	PJL Transformation fonction publique	2019-06-25 21:30:00	2019-06-26 00:35:00	\N	\N	77	0	\N	\N
378093	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2019-06-25 16:45:00	2019-06-25 17:45:00	\N	\N	282	0	\N	\N
378095	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat suite conseil européen des 20 et 21 juin	Débat suite conseil européen des 20 et 21 juin	2019-06-25 17:55:00	2019-06-25 20:00:00	\N	\N	68	0	\N	\N
378096	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL et PPLO Dispositions du droit électoral	PPL et PPLO Dispositions du droit électoral	2019-06-26 14:30:00	2019-06-26 16:30:00	\N	\N	28	0	\N	\N
378098	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Exploitation des réseaux radioélectriques mobiles	PPL Exploitation des réseaux radioélectriques mobiles	2019-06-26 16:30:00	2019-06-26 19:20:00	\N	\N	81	0	\N	\N
378100	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Transformation fonction publique	PJL Transformation fonction publique	2019-06-27 10:30:00	2019-06-27 13:10:00	\N	\N	47	0	\N	\N
378101	SEANCE_PLENIERE	DEBAT	\N	\N	\N	PJL Transformation fonction publique	PJL Transformation fonction publique	2019-06-26 19:20:00	2019-06-26 20:25:00	\N	\N	34	0	\N	\N
445120	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion de la commisison des affaires européennes du 15 janvier 2020	Réunion de la commisison des affaires européennes du 15 janvier 2020	2020-01-15 13:35:00	2020-01-15 14:55:00	2020-01-15 16:06:18	2020-01-15 17:47:49	14	0	\N	\N
445780	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	\N	\N	2020-01-16 10:45:00	2020-01-16 12:15:00	\N	\N	2	0	\N	\N
457643	QUESTURE	AUCUNE	\N	\N	\N	Consiel de Questure	Conseil de Questure	2020-01-21 14:35:00	2020-01-21 15:55:00	\N	\N	3	0	\N	\N
472060	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de M. Cédric O par visioconférence	Audition de M. Cédric O par visioconférence	2020-05-27 11:30:00	2020-05-27 12:45:00	2020-05-28 15:31:31	2020-05-28 15:34:59	27	0	\N	\N
474297	DELEGATION	AUDRAP	\N	\N	206	Audition Production de l'énergie dans le secteur agricole	Audition Production de l'énergie dans le secteur agricole - Akuo Energy	2020-05-29 14:00:00	2020-05-29 16:00:00	\N	\N	1	0	\N	\N
474299	DELEGATION	AUDRAP	\N	\N	206	Audition Production de l'énergie dans le secteur agricole	Audition Production de l'énergie dans le secteur agricole - CNRS	2020-06-03 08:30:00	2020-06-03 09:30:00	\N	\N	1	0	\N	\N
474301	DELEGATION	AUDRAP	\N	\N	206	Audition Production de l'énergie dans le secteur agricole	Audition Production de l'énergie dans le secteur agricole - CRITT-GPTE	2020-06-05 14:00:00	2020-06-05 15:30:00	\N	\N	1	0	\N	\N
474303	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière	Veille sur l'épidémie de Covid-19	2020-06-04 09:40:00	2020-06-04 11:05:00	\N	\N	12	0	\N	\N
474414	DELEGATION	AUDRAP	\N	\N	211	Audition du CNC	Audition du CNC	2020-06-15 15:00:00	2020-06-15 15:55:00	\N	\N	5	0	\N	\N
474482	DELEGATION	AUCUNE	\N	\N	211	Audition de M. François Molins	Audition de M. François Molins	2020-06-11 09:30:00	2020-06-11 11:15:00	2020-06-11 12:21:45	\N	20	0	\N	\N
474483	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule tourisme	\N	2020-04-30 14:30:00	2020-04-30 16:10:00	\N	\N	18	0	\N	\N
474848	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de la commission	2020-06-03 10:05:00	2020-06-03 12:15:00	2020-06-03 12:15:22	2020-06-04 18:59:25	35	0	\N	\N
475167	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule Énergie - Syndicat des énergies renouvelables	\N	2020-04-16 18:00:00	2020-04-16 19:00:00	\N	\N	4	0	\N	\N
475186	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule Énergie - Union française des industries pétrolières	\N	2020-04-17 18:50:00	2020-04-17 19:40:00	\N	\N	4	0	\N	\N
475193	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	2ème Webinaire de l'AP-OTAN	\N	2020-06-02 16:00:00	2020-06-02 17:15:00	\N	\N	2	0	\N	\N
475200	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule Énergie - Fedene	\N	2020-04-21 18:20:00	2020-04-21 19:30:00	\N	\N	2	0	\N	\N
475221	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule Énergie - FF3C	\N	2020-04-23 18:15:00	2020-04-23 19:00:00	\N	\N	1	0	\N	\N
475229	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule Énergie - FOP	\N	2020-04-24 18:20:00	2020-04-24 19:30:00	\N	\N	5	0	\N	\N
475235	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule Énergie - Convention citoyenne pour le climat	\N	2020-04-28 17:00:00	2020-04-28 18:30:00	\N	\N	11	0	\N	\N
475368	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule Énergie - CSCEE	\N	2020-04-28 18:30:00	2020-04-28 19:30:00	\N	\N	3	0	\N	\N
473215	MISSION	AUCUNE	\N	ILLECTRONISM	\N	Audition de Capgemini	Audition  de MM. Paul Hermelin, président-directeur général, et de Jérôme Buvat, directeur de l'Institut de recherche, d	2020-06-03 16:30:00	2020-06-03 17:25:00	2020-06-03 17:28:27	2020-06-04 18:27:09	10	0	\N	\N
475457	MISSION	AUDRAP	\N	FEDERATION	\N	Audition Fabien Canu et Olivier Keraudren	Audition Fabien Canu et Olivier Keraudren	2020-06-03 16:30:00	2020-06-03 17:40:00	\N	\N	13	0	\N	\N
476018	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière - Examen note scientifique - Audition de l'IRSN	Réunion plénière - Examen note scientifique - Audition de l'IRSN	2020-06-25 08:45:00	2020-06-25 10:55:00	\N	\N	12	0	\N	\N
476049	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI SCAF	\N	2020-06-03 13:30:00	2020-06-03 14:30:00	\N	\N	2	0	\N	\N
476207	DELEGATION	AUDRAP	\N	\N	DSOM	Rencontre avec Rodolphe Alexandre	\N	2020-06-05 16:00:00	2020-06-05 17:20:00	\N	\N	2	0	\N	\N
476210	DELEGATION	AUDRAP	\N	\N	DSOM	Rencontre avec Édouard Fritch, président de la Polynésie française	\N	2020-06-05 19:00:00	2020-06-05 20:15:00	\N	\N	2	0	\N	\N
476213	DELEGATION	AUDRAP	\N	\N	DSOM	Renconttre avec M. Kolokilagi, président de l'Assemblée de Wallis-et-Futuna	Renconttre avec M. Kolokilagi, président de l'Assemblée de Wallis-et-Futuna	2020-06-02 23:00:00	2020-06-03 00:20:00	\N	\N	2	0	\N	\N
476507	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Examen du rapport Recrutement et Formation	\N	2020-06-18 09:40:00	2020-06-18 10:55:00	2020-06-18 12:03:21	\N	7	0	\N	\N
476508	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Audition de Mme Agnès Pannier-Runacher, Secrétaire d'État	\N	2020-07-01 16:35:00	2020-07-01 18:00:00	2020-07-01 19:14:37	\N	15	0	\N	\N
476509	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Examen de rapports	\N	2020-06-25 09:00:00	2020-06-25 10:15:00	2020-06-25 15:42:01	\N	9	0	\N	\N
476533	DELEGATION	AUCUNE	\N	\N	PROS	Audition du Professeur Philippe Juvin, chef du service des urgences de l'Hôpital Pompidou	Audition du Professeur Philippe Juvin, chef du service des urgences de l'Hôpital européen Georges Pompidou	2020-06-25 09:30:00	2020-06-25 10:30:00	\N	\N	12	0	\N	\N
476535	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	\N	2020-06-02 14:40:00	2020-06-02 15:55:00	\N	\N	3	0	\N	\N
476540	COM_EURO	AUDRAP	\N	AFEU	\N	Lutte contre la cybercriminalité	Lutte contre la cybercriminalité - Eurojust	2020-06-26 14:25:00	2020-06-26 15:40:00	\N	\N	2	0	\N	\N
476591	MISSION	AUDRAP	\N	ILLECTRONISM	\N	Audition de M. Jean Deydier	\N	2020-06-16 16:00:00	2020-06-16 16:45:00	\N	\N	6	0	\N	\N
476592	MISSION	AUCUNE	\N	ILLECTRONISM	\N	Table ronde des associations	Table ronde des associations	2020-06-17 16:35:00	2020-06-17 18:25:00	2020-06-18 12:38:33	2020-06-18 17:29:09	8	0	\N	\N
476595	MISSION	AUCUNE	\N	ILLECTRONISM	\N	Audition Caisse des dépôts et consignations	Audition Caisse des dépôts et consignations	2020-06-25 10:00:00	2020-06-25 11:35:00	2020-06-25 12:02:08	2020-06-25 15:14:50	6	0	\N	\N
476598	COM_EURO	AUDRAP	\N	AFEU	\N	Respect de l'Etat de droit en Europe dans le contexte de l'épidémie de Covid-19	Respect de l'Etat de droit en Europe dans le contexte de l'épidémie de Covid-19	2020-04-16 10:00:00	2020-04-16 11:00:00	\N	\N	1	0	\N	\N
476601	COM_EURO	AUDRAP	\N	AFEU	\N	Respect de l'Etat de droit en Europe dans le contexte de l'épidémie de Covid-19	Respect de l'Etat de droit en Europe dans le contexte de l'épidémie de Covid-19	2020-04-20 10:00:00	2020-04-20 11:20:00	\N	\N	1	0	\N	\N
476603	COM_EURO	AUDRAP	\N	AFEU	\N	Respect de l'Etat de droit en Europe dans le contexte de l'épidémie de Covid-19	Respect de l'Etat de droit en Europe dans le contexte de l'épidémie de Covid-19	2020-04-22 14:00:00	2020-04-22 14:55:00	\N	\N	1	0	\N	\N
476606	COM_EURO	AUDRAP	\N	AFEU	\N	Respect de l'Etat de droit en Europe dans le contexte de l'épidémie de Covid-19	Respect de l'Etat de droit en Europe dans le contexte de l'épidémie de Covid-19	2020-04-23 17:00:00	2020-04-23 18:00:00	\N	\N	1	0	\N	\N
476608	COM_EURO	AUDRAP	\N	AFEU	\N	Respect de l'Etat de droit en Europe dans le contexte de l'épidémie de Covid-19	Respect de l'Etat de droit en Europe dans le contexte de l'épidémie de Covid-19	2020-04-24 16:30:00	2020-04-24 17:20:00	\N	\N	1	0	\N	\N
476610	COM_EURO	AUDRAP	\N	AFEU	\N	Respect de l'Etat de droit en Europe dans le contexte de l'épidémie de Covid-19	Respect de l'Etat de droit en Europe dans le contexte de l'épidémie de Covid-19	2020-04-30 16:30:00	2020-04-30 17:00:00	\N	\N	1	0	\N	\N
476642	COM_EURO	AUTRE	\N	AFEU	\N	PPRE révision du Cadre financier pluriannuel 2021-2027 et instrument de relance	\N	2020-06-09 17:05:00	2020-06-09 18:50:00	2020-06-10 14:44:38	2020-06-10 16:12:03	15	0	\N	\N
476727	COM_EURO	AUDRAP	\N	AFEU	\N	Union européenne et la santé, à la suite de la pandémie de COVID-19	Union européenne et la santé, à la suite de la pandémie de COVID-19 - INSERM	2020-06-12 11:00:00	2020-06-12 12:20:00	\N	\N	2	0	\N	\N
476792	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2020-06-10 09:30:00	2020-06-10 12:41:00	2020-06-10 18:25:41	2020-06-10 18:37:57	33	0	\N	\N
476907	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Gestion des déchets-Association RCube	Covid-19-Gestion des déchets-Association RCube	2020-06-08 09:00:00	2020-06-08 10:00:00	\N	\N	12	0	\N	\N
476908	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Gestion des déchets-Fédération ENVIE	Covid-19-Gestion des déchets-Fédération ENVIE	2020-06-08 10:00:00	2020-06-08 11:00:00	\N	\N	11	0	\N	\N
476909	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Eau et biodiversité-FNSEA	Covid-19-Eau et biodiversité-FNSEA	2020-06-09 16:45:00	2020-06-09 17:40:00	\N	\N	10	0	\N	\N
476953	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 11 juin 2020 de la commission des affaires européennes	Réunion du 11 juin 2020 	2020-06-11 09:00:00	2020-06-11 10:55:00	2020-06-15 21:21:16	2020-06-16 14:51:58	30	0	\N	\N
476988	DELEGATION	AUCUNE	\N	\N	DSOM	Table ronde sur le tourisme dans les outre-mer	\N	2020-06-25 14:00:00	2020-06-25 17:00:00	\N	\N	11	0	\N	\N
373752	GIA	AUCUNE	\N	\N	\N	Dîner annuel France-Irlande	Dîner des groupes d'amitié France-Irlande du Sénat et de l'Assemblée nationale en présence de l'ambassadeur  d'Irlande	2019-04-10 20:00:00	2019-04-10 22:00:00	\N	\N	7	0	594	\N
373760	DELEGATION	AUCUNE	\N	\N	206	Audition de l'Autorité de sûreté nucléaire	Audition de l'Autorité de sûreté nucléaire	2019-05-16 10:15:00	2019-05-16 12:30:00	\N	\N	11	0	\N	\N
375055	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI mission innovation et défense	\N	2019-04-30 14:30:00	2019-04-30 16:30:00	\N	\N	1	0	\N	\N
376559	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT "Gilets jaunes" - Réunion constitutive	GT "Gilets jaunes" - Réunion constitutive	2019-05-07 13:45:00	2019-05-07 14:30:00	\N	\N	6	0	\N	\N
376584	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT stratégie industrielle de l'UE	GT stratégie industrielle de l'UE	2019-05-07 14:30:00	2019-05-07 15:10:00	\N	\N	2	0	\N	\N
376652	DELEGATION	AUCUNE	\N	\N	211	Audition de Mme Henriques vice-présidente déléguée de la FFF	Audition de Mme Henriques vice-présidente déléguée de la FFF	2019-05-07 14:00:00	2019-05-07 15:30:00	\N	\N	6	0	\N	\N
377420	GIA	AUCUNE	\N	\N	\N	Audition de Sa Béatitude Joseph ABSI, Patriarche melkite d'Antioche et de tout l'Orient	Audition de Sa Béatitude Joseph ABSI, Patriarche melkite d'Antioche et de tout l'Orient	2019-05-14 17:00:00	2019-05-14 18:00:00	\N	\N	20	0	CHRETORIENT	CHRETORIENT
380297	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	1101	\N	\N	Explications de vote sur l'ensemble du ¨PJL Ecole de la confiance	Explications de vote sur l'ensemble du ¨PJL Ecole de la confiance	2019-05-21 15:05:00	2019-05-21 16:00:00	\N	\N	312	0	\N	\N
380298	SEANCE_PLENIERE	SCRUSOL	1101	\N	\N	Scrutin solennel PJL Ecole de la confiance	Scrutin solennel PJL Ecole de la confiance	2019-05-21 16:00:00	2019-05-21 16:30:00	\N	\N	0	0	\N	\N
381988	COM_PERMANENTE	AUTRE	\N	LOIS	\N	réunion de commission	\N	2019-05-22 09:35:00	2019-05-22 12:00:00	2019-05-22 15:31:29	2019-05-22 17:38:09	30	1	\N	\N
382505	DELEGATION	AUCUNE	\N	\N	DSOM	Audition dans le cadre de l'étude sur le risques naturels outre-mer	\N	2019-05-29 17:00:00	2019-05-29 18:40:00	\N	\N	3	0	\N	\N
393089	DELEGATION	AUCUNE	\N	\N	211	Audition plénière - Réunion du G7	Audition plénière - Réunion du G7	2019-06-20 09:00:00	2019-06-20 11:10:00	\N	\N	11	0	\N	\N
404627	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT États généraux de l'alimentation	Malongo	2019-07-23 14:00:00	2019-07-23 14:30:00	\N	\N	4	0	\N	\N
404632	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT États généraux de l'alimentation	Société Jean Larnaudie	2019-07-23 14:30:00	2019-07-23 15:15:00	\N	\N	6	0	\N	\N
404639	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT États généraux de l'alimentation	Laiterie de Saint-Denis-de-l'Hôtel	2019-07-23 15:20:00	2019-07-23 15:50:00	\N	\N	6	0	\N	\N
404646	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT États généraux de l'alimentation	Agro'nove	2019-07-23 15:50:00	2019-07-23 16:15:00	\N	\N	6	0	\N	\N
404653	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT États généraux de l'alimentation	Lobodis	2019-07-23 16:15:00	2019-07-23 16:45:00	\N	\N	5	0	\N	\N
404660	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT États généraux de l'alimentation	Pâtisserie Baillon /Conserverie Chancelle /UFC-Que choisir /Syndicat national de la restauration collective / Restau'Co	2019-07-24 14:30:00	2019-07-24 17:25:00	\N	\N	4	0	\N	\N
404665	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT États généraux de l'alimentation	\N	2019-07-24 17:25:00	2019-07-24 18:15:00	\N	\N	3	0	\N	\N
405121	MISSION	AUCUNE	\N	FONDS	\N	Réunion du 11 septembre 2019	\N	2019-09-11 15:04:00	2019-09-11 17:30:00	2019-09-12 17:29:17	2019-09-13 15:01:32	6	0	\N	\N
405136	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Adoption de règlements locaux de publicité intercommunaux - Auditions Mme Estrosi	PPL Adoption de règlements locaux de publicité intercommunaux	2019-09-11 14:45:00	2019-09-11 15:15:00	\N	\N	1	0	\N	\N
405138	MISSION	DEPLACEMENT	\N	MARITIME	\N	MCI Sauvetage en mer - Déplacement Martinique	MCI Sauvetage en mer - Déplacement Martinique	2019-07-23 15:30:00	2019-07-23 18:00:00	\N	\N	1	0	\N	\N
405140	MISSION	DEPLACEMENT	\N	MARITIME	\N	MCI Sauvetage en mer - Déplacement Martinique	MCI Sauvetage en mer - Déplacement Martinique	2019-07-24 15:30:00	2019-07-24 17:30:00	\N	\N	1	0	\N	\N
405142	MISSION	DEPLACEMENT	\N	MARITIME	\N	MCI Sauvetage en mer - Déplacement Pas-de-Calais	MCI Sauvetage en mer - Déplacement Pas-de-Calais	2019-09-10 06:45:00	2019-09-10 19:30:00	\N	\N	10	0	\N	\N
405225	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2019 - Finances locales italiennes - Déplacement Rome	Contrôle 2019 - Finances locales italiennes - Déplacement Rome	2019-09-09 10:30:00	2019-09-10 20:30:00	\N	\N	1	0	\N	\N
405276	DELEGATION	AUCUNE	\N	\N	211	Audition de Mme Marlène SCHIAPPA	Audition de Mme Marlène SCHIAPPA, secrétaire d¿Étatchargée de l¿Égalité entre les femmes et les hommes	2019-10-15 17:30:00	2019-10-15 19:30:00	2019-10-16 11:58:16	\N	16	0	\N	\N
405277	DELEGATION	AUCUNE	\N	\N	PROS	Programme de travail de la délégation pour la session 2019-2020	\N	2019-10-03 08:30:00	2019-10-03 09:30:00	\N	\N	19	0	\N	\N
407001	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Conseil européen 17-18 octobre 2019	Débat Conseil européen 17-18 octobre 2019	2019-10-22 21:31:00	2019-10-22 23:43:00	\N	\N	45	0	\N	\N
407533	ETUDES	AUTRE	\N	\N	\N	Election d'un nouveau président	\N	2019-09-25 15:00:00	2019-09-25 16:00:00	\N	\N	13	0	\N	928
407791	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Lutte contre les feux de forêt - DGSCGC	Contrôle 2019 - Lutte contre les feux de forêt - DGSCGC	2019-09-24 09:00:00	2019-09-24 10:45:00	\N	\N	1	0	\N	\N
407856	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Réforme des retraites - Comité de suivi des retraites	Contrôle 2018 - Réforme des retraites - Comité de suivi des retraites	2019-09-24 17:50:00	2019-09-24 19:10:00	\N	\N	1	0	\N	\N
408155	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	GT Obligation de signalement	\N	2019-10-01 14:30:00	2019-10-01 18:30:00	\N	\N	5	0	\N	\N
408160	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	GT Obligation de signalement	\N	2019-10-02 19:00:00	2019-10-02 20:00:00	\N	\N	4	0	\N	\N
408165	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	GT Obligation de signalement	\N	2019-10-03 10:30:00	2019-10-03 12:30:00	\N	\N	4	0	\N	\N
409085	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Service public de l'éducation et neutralité religieuse	PPL Service public de l'éducation et neutralité religieuse	2019-10-01 15:15:00	2019-10-01 16:00:00	\N	\N	5	0	\N	\N
409091	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Service public de l'éducation et neutralité religieuse	PPL Service public de l'éducation et neutralité religieuse	2019-10-01 16:10:00	2019-10-01 17:00:00	\N	\N	4	0	\N	\N
409096	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Service public de l'éducation et neutralité religieuse	PPL Service public de l'éducation et neutralité religieuse	2019-10-01 17:00:00	2019-10-01 17:45:00	\N	\N	5	0	\N	\N
409102	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Livre et Industries culturelles	PLF 2020 - Crédits Livre et Industries culturelles	2019-10-01 17:30:00	2019-10-01 18:30:00	\N	\N	1	0	\N	\N
410752	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2019-07-03 14:45:00	2019-07-03 17:45:00	\N	\N	3	0	\N	\N
410756	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2019-07-10 14:40:00	2019-07-10 17:05:00	\N	\N	3	0	\N	\N
410760	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2019-07-17 15:35:00	2019-07-17 18:00:00	\N	\N	3	0	\N	\N
410764	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2019-07-24 14:30:00	2019-07-24 17:35:00	\N	\N	3	0	\N	\N
410827	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Autre - Audition commission (contrôle)	\N	2019-10-03 09:00:00	2019-10-03 11:00:00	\N	\N	0	0	\N	\N
410828	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Attaque Préfecture de police - Audition de Christophe Castaner, ministre de l'intérieur	Attaque Préfecture de police - Audition de Christophe Castaner, ministre de l'intérieur	2019-10-10 09:00:00	2019-10-10 10:55:00	2019-10-10 11:11:31	2019-10-10 14:55:51	30	0	\N	\N
410831	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Auditions médico-social	\N	2019-10-08 16:30:00	2019-10-08 18:30:00	\N	\N	1	0	\N	\N
443719	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Auditions Nouvelles formes de commerce	Auditions GT Nouvelles formes de commerce  - CPME	2020-01-08 10:00:00	2020-01-08 10:45:00	\N	\N	3	0	\N	\N
443724	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Auditions Nouvelles formes de commerce	Auditions GT Nouvelles formes de commerce  - CCI	2020-01-08 10:45:00	2020-01-08 11:30:00	\N	\N	5	0	\N	\N
448833	GIA	AUCUNE	\N	\N	\N	Coopé - Visite de M. David SONGULASHVILI, député géorgien	Coopé - Visite de M. David SONGULASHVILI, député géorgien	2020-01-22 16:00:00	2020-01-22 17:00:00	\N	\N	2	0	534	\N
448836	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Porte-avions	\N	2020-01-21 17:00:00	2020-01-21 18:00:00	\N	\N	4	0	\N	\N
382001	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Examen des motions et amendements de séance - PJL Organisation du système de santé	\N	2019-05-29 10:30:00	2019-05-29 12:30:00	2019-05-29 12:35:04	2019-05-29 15:17:44	41	0	\N	\N
449855	DELEGATION	AUCUNE	\N	\N	DSOM	Auditions - Étude sues les enjeux européens en 2020 pour les outre-mer	\N	2020-02-06 09:35:00	2020-02-06 10:45:00	\N	\N	8	0	\N	\N
455387	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Congé pour le décès d'un enfant	\N	2020-02-18 16:30:00	2020-02-18 19:45:00	\N	\N	1	0	\N	\N
455389	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	\N	GT Expertise psychiatrique en matière pénale	2020-02-18 14:00:00	2020-02-18 16:00:00	\N	\N	1	0	\N	\N
455463	DELEGATION	DEPLACEMENT	\N	\N	206	Petit déjeuner à l'Académie des sciences	Petit déjeuner à l'Académie des sciences sur le thème de la robotique	2020-02-19 08:30:00	2020-02-19 10:00:00	\N	\N	3	0	\N	\N
456887	DELEGATION	AUCUNE	\N	\N	DSOM	Synthèse des travaux communs aux délégations aux droits des femmes et aux outre-mer	\N	2020-03-03 17:00:00	2020-03-03 17:50:00	\N	\N	8	0	\N	\N
456889	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL congé pour le deuil d'un enfant - Mme Doineau/Cabinets ministériels	\N	2020-02-20 18:00:00	2020-02-20 19:30:00	\N	\N	1	0	\N	\N
456891	COM_ENQUETE	PLENIERE	\N	SOLS	\N	Réunion de commission	\N	2020-02-25 14:34:00	2020-02-25 17:21:00	2020-02-26 16:11:01	2020-02-26 17:29:51	13	0	\N	\N
456966	COM_EURO	AUDRAP	\N	AFEU	\N	Audition de Mme Valérie HAYER, députée européenne	Avenir et gouvernance de la zone euro - Audition de Mme Valérie HAYER, députée européenne	2020-02-19 08:30:00	2020-02-19 09:30:00	\N	\N	1	0	\N	\N
457099	COM_SPECIALE	PLENIERE	\N	ASAP	\N	Réunion LEC partielle	Réunion LEC partielle	2020-02-26 16:15:00	2020-02-26 17:35:00	2020-02-26 22:52:03	2020-02-27 14:42:17	30	1	\N	\N
457100	COM_SPECIALE	PLENIERE	\N	ASAP	\N	Réunion de commission	Réunion de commission	2020-02-26 17:35:00	2020-02-26 19:55:00	2020-02-26 22:53:22	2020-02-27 14:42:19	23	3	\N	\N
458799	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2020-02-25 19:35:00	2020-02-25 20:15:00	\N	\N	25	0	\N	\N
462471	COM_PERMANENTE	AUTRE	\N	CAE	\N	MI "Chantiers de l'Atlantique"	MI "Chantiers de l'Atlantique"	2020-03-03 09:00:00	2020-03-03 10:10:00	\N	\N	2	0	\N	\N
462474	COM_PERMANENTE	AUTRE	\N	CAE	\N	MI "Chantiers de l'Atlantique"	MI "Chantiers de l'Atlantique"	2020-03-03 10:10:00	2020-03-03 11:10:00	\N	\N	1	0	\N	\N
462476	COM_PERMANENTE	AUTRE	\N	CAE	\N	MI "Chantiers de l'Atlantique"	MI "Chantiers de l'Atlantique"	2020-03-03 16:00:00	2020-03-03 17:40:00	\N	\N	1	0	\N	\N
468979	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFR pour 2020 (2) "MIRES et IA" - Suivi mesures crise covid-19 - Xenothera	PLFR pour 2020 (2) "MIRES et IA" - Suivi mesures crise covid-19 - Xenothera	2020-05-07 14:30:00	2020-05-07 15:30:00	\N	\N	2	0	\N	\N
468984	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Association nationale des apprentis de France (ANAF)	Association nationale des apprentis de France (ANAF)	2020-05-11 09:45:00	2020-05-11 10:55:00	\N	\N	5	0	\N	\N
468992	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Région Grand Est	\N	2020-05-14 11:15:00	2020-05-14 12:55:00	\N	\N	2	0	\N	\N
469033	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière - CNAJMJ	Audition de Maître Christophe Basse, président du Conseil national des administrateurs judiciaires et des mandataires ju	2020-05-11 15:30:00	2020-05-11 16:40:00	2020-05-11 17:12:24	\N	11	0	\N	\N
469053	DELEGATION	AUCUNE	\N	\N	206	Veille sur l'épidémie de Covid-19	Veille sur l'épidémie de Covid-19	2020-05-14 09:45:00	2020-05-14 11:30:00	\N	\N	16	0	\N	\N
469321	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - Association MerTerre - ODEMA	Audition Pollution plastique - Association MerTerre - ODEMA	2020-05-12 09:00:00	2020-05-12 10:30:00	\N	\N	2	0	\N	\N
469324	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - WWF France	Audition Pollution plastique - WWF France	2020-05-12 10:30:00	2020-05-12 12:00:00	\N	\N	2	0	\N	\N
469334	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - Université de Versailles-Saint-Quentin-en-Yvelines	Audition Pollution plastique - Université de Versailles-Saint-Quentin-en-Yvelines	2020-05-12 12:00:00	2020-05-12 13:45:00	\N	\N	2	0	\N	\N
469558	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Régions de France	\N	2020-05-18 17:05:00	2020-05-18 18:20:00	2020-05-19 09:27:05	\N	4	0	\N	\N
469610	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière - Audition de M. Guillaume Poupard	Réunion plénière - Audition de M. Guillaume Poupard, directeur général de l'ANSSI	2020-05-12 17:10:00	2020-05-12 18:10:00	\N	\N	13	0	\N	\N
470167	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audtion rapporteur de la Fédération protestante de France (En visioconférence)	Audtion rapporteur de la Fédération protestante de France (En visioconférence)	2020-05-14 09:35:00	2020-05-14 10:15:00	\N	\N	3	0	\N	\N
470178	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur de Conférence des évêques de France (En visioconférence)	\N	2020-05-14 10:15:00	2020-05-14 10:50:00	\N	\N	4	0	\N	\N
470221	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rappporteur du Grand rabbinat de France (En visioconférence)	\N	2020-05-14 11:00:00	2020-05-14 11:45:00	\N	\N	4	0	\N	\N
470352	COM_ENQUETE	AUDRAP	\N	AUTOROUT	\N	CE concessions autoroutières - Departement PPP Ministère de l'Écologie	CE concessions autoroutières - Departement PPP Ministère de l'Écologie	2020-05-14 10:15:00	2020-05-14 10:55:00	\N	\N	3	0	\N	\N
470401	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Cour d'appel de Saint-Denis-de-La-Réunion	\N	2020-05-14 11:15:00	2020-05-14 12:30:00	\N	\N	2	0	\N	\N
470438	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition APD en Afrique + communication PJL dispositions urgentes covid-19	\N	2020-05-20 09:30:00	2020-05-20 11:45:00	2020-05-22 11:22:37	2020-05-25 10:19:40	33	0	\N	\N
470531	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Français établis hors de France 	PPL Français établis hors de France 	2020-05-19 10:05:00	2020-05-19 10:25:00	2020-05-20 08:07:25	2020-05-20 11:31:50	21	0	\N	\N
470532	COM_PERMANENTE	AUTRE	\N	LOIS	\N	\N	\N	2020-05-20 10:05:00	2020-05-20 13:05:00	2020-05-28 07:05:29	\N	44	1	\N	\N
470543	COM_PERMANENTE	AUTRE	\N	FINC	\N	PJL n°440 DDU Covid 19 - Examen rapport et PPL n°179 - Examen AMDTS séance	PJL n°440 DDU Covid 19 - Examen rapport et PPL n°179 - Examen AMDTS séance	2020-05-19 14:35:00	2020-05-19 15:30:00	2020-05-19 18:18:58	2020-05-20 11:31:49	28	0	\N	\N
470545	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de M. Éric LOMBARD, directeur général de la Caisse des dépôts et consignations	Audition de M. Éric LOMBARD, directeur général de la Caisse des dépôts et consignations	2020-05-20 11:20:00	2020-05-20 13:10:00	2020-05-20 15:04:24	2020-05-20 16:54:38	52	0	\N	\N
459643	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2020-02-26 16:15:00	2020-02-26 17:30:00	\N	\N	3	0	\N	\N
470544	COM_PERMANENTE	AUTRE	\N	FINC	\N	PPL n° 339 frais bancaires - Examen du rapport et établissement du texte	PPL n° 339 frais bancaires - Examen du rapport et établissement du texte	2020-05-20 09:55:00	2020-05-20 11:00:00	2020-05-20 15:04:11	2020-05-20 16:54:36	30	0	\N	\N
470546	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFR pour 2020 (2) "Écologie" - Suivi mesures crise covid-19 - Air France-KLM	PLFR pour 2020 (2) "Écologie" - Suivi mesures crise covid-19 - Air France-KLM	2020-05-05 19:00:00	2020-05-05 20:00:00	\N	\N	1	0	\N	\N
470548	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFR pour 2020 (2) "Écologie" - Suivi mesures crise covid-19 - GIFAS	PLFR pour 2020 (2) "Écologie" - Suivi mesures crise covid-19 - GIFAS	2020-05-12 19:00:00	2020-05-12 19:30:00	\N	\N	1	0	\N	\N
470626	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Création de Points d'accueil pour soins immédiats	\N	2020-05-13 14:00:00	2020-05-13 15:00:00	\N	\N	1	0	\N	\N
470628	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Création de Points d'accueil pour soins immédiats	\N	2020-05-13 16:30:00	2020-05-13 17:30:00	\N	\N	2	0	\N	\N
376898	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition PME et Numérique	Audition PME et Numérique - Kosc Télécom	2019-05-15 14:00:00	2019-05-15 15:00:00	\N	\N	2	0	\N	\N
378104	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Transformation fonction publique	PJL Transformation fonction publique	2019-06-26 21:55:00	2019-06-27 00:35:00	\N	\N	40	0	\N	\N
378109	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Transformation fonction publique	PJL Transformation fonction publique	2019-06-27 14:40:00	2019-06-27 16:20:00	\N	\N	30	0	\N	\N
378405	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	\N	\N	2019-05-15 17:30:00	2019-05-15 18:55:00	2019-05-15 17:37:20	2019-05-15 17:40:29	9	0	\N	\N
384770	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2019 - Mobilisation financements régionaux - Déplacement Bordeaux-Lyon-Grenoble	Contrôle 2019 - Mobilisation financements régionaux - Déplacement Bordeaux - Lyon - Grenoble	2019-06-04 07:45:00	2019-06-05 20:20:00	\N	\N	1	0	\N	\N
391309	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	« Conséquences économiques des gilets jaunes »	« Conséquences économiques des gilets jaunes »	2019-06-13 14:00:00	2019-06-13 15:15:00	\N	\N	3	0	\N	\N
392219	DELEGATION	AUDRAP	\N	\N	PROS	Audition de Anne Thessard	\N	2019-10-22 16:00:00	2019-10-22 16:45:00	\N	\N	2	0	\N	\N
392395	MISSION	AUCUNE	\N	SIDERURGIE	\N	Table ronde - Syndicats	\N	2019-06-18 15:00:00	2019-06-18 17:25:00	2019-06-20 19:01:56	2019-06-21 16:34:56	11	0	\N	\N
392412	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-06-26 09:05:00	2019-06-26 10:45:00	2019-06-28 11:53:38	2019-06-28 11:54:18	40	0	\N	\N
392631	BUREAU	AUCUNE	\N	\N	\N	Délégation du Bureau statut du sénateur	Délégation du Bureau statut et conditions d'exercice du mandat de sénateur	2019-06-19 11:45:00	2019-06-19 12:00:00	\N	\N	2	0	\N	\N
397596	COM_ENQUETE	AUDRAP	\N	SOUVERAINETE	\N	\N	\N	2019-07-03 15:30:00	2019-07-03 17:30:00	2019-07-03 17:54:06	\N	4	0	\N	\N
398288	MISSION	AUDRAP	\N	AERIEN	\N	\N	\N	2019-07-03 11:00:00	2019-07-03 12:00:00	\N	\N	5	0	\N	\N
398296	MECSS	AUDRAP	\N	\N	MECSS	Accès précoce à l'innovation dans le domaine des produits de santé	\N	2019-07-09 15:00:00	2019-07-09 16:30:00	\N	\N	3	0	\N	\N
398307	ETUDES	AUCUNE	\N	\N	\N	\N	\N	2019-07-18 08:30:00	2019-07-18 10:15:00	\N	\N	3	0	\N	1004
398444	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Énergie - Auditions M. Gremillet	\N	2019-07-03 17:00:00	2019-07-03 18:00:00	\N	\N	1	0	\N	\N
398446	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Énergie - Auditions M. Gremillet	\N	2019-07-03 18:00:00	2019-07-03 18:45:00	\N	\N	2	0	\N	\N
398449	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Énergie - Auditions M. Gremillet	\N	2019-07-03 18:45:00	2019-07-03 19:30:00	\N	\N	1	0	\N	\N
398454	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Énergie - Auditions M. Gremillet	\N	2019-07-02 14:45:00	2019-07-02 16:45:00	\N	\N	5	0	\N	\N
398460	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Énergie - Auditions M. Gremillet	\N	2019-07-02 17:15:00	2019-07-02 18:15:00	\N	\N	4	0	\N	\N
398468	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Énergie - Auditions Mme Bories	\N	2019-07-03 16:50:00	2019-07-03 17:50:00	\N	\N	1	0	\N	\N
404669	MECSS	AUDRAP	\N	\N	MECSS	Accès précoce à l'innovation dans le domaine des produits de santé	\N	2019-10-01 13:30:00	2019-10-01 14:30:00	\N	\N	3	0	\N	\N
405448	DELEGATION	AUCUNE	\N	\N	DSOM	Programme de travail de la délégation et audition Mme Rusnac	Programme de travail de la délégation et audition Mme Rusnac	2019-10-03 09:35:00	2019-10-03 11:40:00	\N	\N	22	0	\N	\N
405449	DELEGATION	AUCUNE	\N	\N	COLTER	Audition Mme Gourault, ministre cohésion territoires et relations avec les collectivités	\N	2019-10-03 10:00:00	2019-10-03 12:00:00	2019-10-03 12:12:12	\N	16	0	\N	\N
406964	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Encadrement rave-parties	PPL Encadrement rave-parties	2019-10-22 17:18:00	2019-10-22 19:44:00	\N	\N	89	0	\N	\N
407450	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Andrei KOLESNIKOV, directeur du programme « Politique intérieure et inst	Entretien avec M. Andrei KOLESNIKOV, directeur du programme « Politique intérieure et institutions politiques » du Carne	2019-09-26 08:00:00	2019-09-26 09:00:00	\N	\N	7	0	608	\N
407544	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-10-02 09:35:00	2019-10-02 12:45:00	2019-10-02 16:24:51	2019-10-02 16:26:03	38	1	\N	\N
408189	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Urbanisme Sain-Martin (nomination) - PLF 2020 (nominations) - PPL Entraves (amdts)	PJL Urbanisme Sain-Martin (nomination) - PLF 2020 (nominations) - PPL Entraves (amdts)	2019-10-01 09:35:00	2019-10-01 09:55:00	2019-10-01 10:26:19	2019-10-01 16:35:39	21	0	\N	\N
408229	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	Conséquences de l'incendie de l'usine Lubrizol à Rouen - Examen des amendements	2019-10-08 17:18:00	2019-10-08 17:46:00	2019-10-09 13:55:27	2019-10-09 17:38:37	30	0	\N	\N
408237	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	Incendie de l¿usine Lubrizol à Rouen - Audition de Mme Élisabeth Borne, Ministre de la Transition écologique et solidair	2019-10-08 18:01:00	2019-10-08 20:10:00	2019-10-09 13:54:35	2019-10-09 17:38:38	33	0	\N	\N
408325	DELEGATION	AUCUNE	\N	\N	PROS	Audition de M. Jean-François Soussana 	Audition de M. Jean-François Soussana, vice-président de l'Inra 	2019-10-17 08:30:00	2019-10-17 09:50:00	\N	\N	15	0	\N	\N
416986	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-10-22 17:20:00	2019-10-22 18:45:00	2019-10-23 15:03:19	2019-10-23 16:36:02	36	0	\N	\N
418247	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 30 octobre 2019 commune avec l'AN et les députés européens français	\N	2019-10-30 16:30:00	2019-10-30 18:00:00	\N	\N	0	0	\N	\N
421260	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition difficultés de recrutement et évolution des métiers	Audition difficultés de recrutement et évolution des métiers - U2P	2019-10-29 10:10:00	2019-10-29 11:35:00	\N	\N	3	0	\N	\N
421264	DELEGATION	DEPLACEMENT	\N	\N	ENTREPRISES	Déplacement dans l'Aisne	Déplacement dans l'Aisne	2019-10-24 07:34:00	2019-10-24 19:26:00	\N	\N	6	0	\N	\N
421272	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition difficultés de recrutement et évolution des métiers	Audition difficultés de recrutement et évolution des métiers - France Compétences	2019-10-15 10:00:00	2019-10-15 11:00:00	\N	\N	2	0	\N	\N
425050	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF 2020 - Programme 129	\N	2019-11-06 14:00:00	2019-11-06 15:20:00	\N	\N	2	0	\N	\N
392413	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-06-26 10:45:00	2019-06-26 11:00:00	2019-06-28 11:53:08	2019-06-28 11:54:17	40	0	\N	\N
425053	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF 2020 - Programmes 844 et 847	\N	2019-11-06 16:40:00	2019-11-06 18:00:00	\N	\N	1	0	\N	\N
428503	COM_PERMANENTE	AUDRAP	\N	CDD	\N	\N	PJLF 2020 - Avis recherche	2019-10-23 17:30:00	2019-10-23 18:30:00	\N	\N	1	0	\N	\N
428504	COM_PERMANENTE	AUDRAP	\N	CDD	\N	\N	PJLF 2020 - Avis recherche	2019-11-07 11:00:00	2019-11-07 12:30:00	\N	\N	1	0	\N	\N
428505	COM_PERMANENTE	AUDRAP	\N	CDD	\N	\N	PJLF 2020 - Avis recherche	2019-11-12 16:00:00	2019-11-12 17:00:00	\N	\N	1	0	\N	\N
428506	COM_PERMANENTE	AUDRAP	\N	CDD	\N	\N	PJLF 2020 - Avis recherche	2019-11-04 10:30:00	2019-11-04 11:30:00	\N	\N	1	0	\N	\N
428524	DELEGATION	AUDRAP	\N	\N	PROS	Audition de l'APCMA	\N	2019-12-03 14:30:00	2019-12-03 15:30:00	\N	\N	1	0	\N	\N
428528	COM_SPECIALE	AUDRAP	\N	BIOETHIQUE	\N	\N	\N	2019-11-20 18:30:00	2019-11-20 20:00:00	\N	\N	1	0	\N	\N
428529	COM_SPECIALE	AUDRAP	\N	BIOETHIQUE	\N	\N	\N	2019-11-21 08:30:00	2019-11-21 10:00:00	\N	\N	3	0	\N	\N
428530	COM_SPECIALE	AUDRAP	\N	BIOETHIQUE	\N	\N	\N	2019-11-28 08:30:00	2019-11-28 10:00:00	\N	\N	3	0	\N	\N
428531	COM_SPECIALE	AUDRAP	\N	BIOETHIQUE	\N	\N	\N	2019-12-04 17:00:00	2019-12-04 18:30:00	\N	\N	1	0	\N	\N
428547	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PPL Carte Vitale biométrique - Examen des amendements	\N	2019-11-19 14:00:00	2019-11-19 14:10:00	2019-11-19 15:02:05	2019-11-19 15:04:37	23	0	\N	\N
428705	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Culture (Création, Transmission, Démocratisation)	PLF 2020 - Crédits Culture (Création, Transmission, Démocratisation)	2019-11-19 13:30:00	2019-11-19 14:30:00	\N	\N	5	0	\N	\N
428720	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Usages dangereux du protoxyde d'azote	\N	2019-11-19 11:00:00	2019-11-19 11:40:00	\N	\N	1	0	\N	\N
428807	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Audiovisuel	PLF 2020 - Crédits Audiovisuel	2019-11-19 14:30:00	2019-11-19 16:10:00	\N	\N	4	0	\N	\N
428897	COM_SPECIALE	AUDRAP	\N	BIOETHIQUE	\N	Table ronde associations articles 1 et 2	\N	2019-11-19 15:30:00	2019-11-19 17:05:00	\N	\N	8	0	\N	\N
435823	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	GT 2019 Exercice du droit de retrait	\N	2019-12-03 14:00:00	2019-12-03 15:15:00	\N	\N	3	0	\N	\N
435882	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL Conventions Burkina Faso et Niger	\N	2019-12-03 14:35:00	2019-12-03 16:40:00	\N	\N	1	0	\N	\N
440653	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2020 - Suite Examen rapport Nlle Lecture	PLF pour 2020 - Suite Examen rapport Nlle Lecture	2019-12-18 14:35:00	2019-12-18 14:40:00	2019-12-18 16:05:41	2019-12-18 17:42:12	22	0	\N	\N
441281	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition PPL Droits sociaux des travailleurs numériques - Institut Montaigne	\N	2019-12-17 17:45:00	2019-12-17 18:45:00	\N	\N	2	0	\N	\N
441288	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition PPL Droits sociaux des travailleurs numériques - 	\N	2019-12-18 13:30:00	2019-12-18 14:30:00	\N	\N	1	0	\N	\N
454228	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière	Réunion plénière	2020-02-20 09:40:00	2020-02-20 11:35:00	\N	\N	12	0	\N	\N
460747	GIA	AUCUNE	\N	\N	\N	Réunion 	Réunion sur le projet de déplacement en Andorre	2020-01-28 17:00:00	2020-01-28 17:45:00	\N	\N	7	0	963	\N
461298	COM_EURO	AUTRE_NON_PLENIERE	\N	AFEU	\N	Colloque réunification Europe	Colloque"Réunification Europe 30 ans après la chute du mur de Berlin"	2020-02-18 14:00:00	2020-02-18 18:30:00	\N	\N	5	0	\N	\N
461608	GIA	AUCUNE	\N	\N	\N	Rencontre avec le Dr Sima Samar	Rencontre avec le Dr Sima Samar, présidente de la commission afghane indépendante des droits de l'homme	2020-03-05 15:30:00	2020-03-05 16:30:00	\N	\N	1	0	648	\N
471957	COM_PERMANENTE	AUTRE	\N	CAE	\N	\N	\N	2020-05-27 11:05:00	2020-05-27 11:55:00	2020-05-27 17:51:04	2020-05-28 14:34:46	32	0	\N	\N
477083	DELEGATION	AUDRAP	\N	\N	DSOM	Réunion avec M. Ary Chalus, président du conseil régional de la Guadeloupe	\N	2020-06-08 17:00:00	2020-06-08 18:30:00	\N	\N	4	0	\N	\N
477109	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Audition de Mme Jeanne-Marie Prost, médiatrice des loyers commerciaux	\N	2020-06-17 14:00:00	2020-06-17 15:00:00	2020-06-17 15:47:08	\N	6	0	\N	\N
477114	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2020-06-10 09:30:00	2020-06-10 12:00:00	2020-06-10 16:13:19	2020-06-10 18:43:05	34	0	\N	\N
477254	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule logement - Direction de l'habitat, de l'urbanisme et des paysages	\N	2020-06-08 09:30:00	2020-06-08 10:30:00	\N	\N	1	0	\N	\N
477260	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule logement - La frabrique de la cité	\N	2020-06-08 10:30:00	2020-06-08 11:30:00	\N	\N	1	0	\N	\N
477262	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule logement - CDC habitat	\N	2020-06-09 14:00:00	2020-06-09 15:00:00	\N	\N	2	0	\N	\N
477267	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule logement - Samu social	\N	2020-06-09 15:00:00	2020-06-09 16:00:00	\N	\N	2	0	\N	\N
477463	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL exploitation commerciale enfants moins de seize ans sur plateformes en ligne	PPL exploitation commerciale enfants moins de seize ans sur plateformes en ligne	2020-06-08 10:00:00	2020-06-08 11:00:00	\N	\N	5	0	\N	\N
477466	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule logement - Union nationale des aménageurs (UNAM)	\N	2020-06-09 16:00:00	2020-06-09 16:45:00	\N	\N	2	0	\N	\N
477471	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL exploitation commerciale enfants moins de seize ans sur plateformes en ligne	PPL exploitation commerciale enfants moins de seize ans sur plateformes en ligne	2020-06-08 11:15:00	2020-06-08 12:15:00	\N	\N	2	0	\N	\N
477477	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL exploitation commerciale enfants moins de seize ans sur plateformes en ligne	PPL exploitation commerciale enfants moins de seize ans sur plateformes en ligne	2020-06-08 16:00:00	2020-06-08 17:00:00	\N	\N	4	0	\N	\N
477494	COM_ENQUETE	PLENIERE	\N	SOLS	\N	Audition de M. Sidi Soilmi, directeur du projet "Bâti scolaire" (MENJ) 	\N	2020-06-16 16:30:00	2020-06-16 17:15:00	2020-06-22 10:08:06	2020-06-24 10:55:37	7	0	\N	\N
477495	COM_ENQUETE	PLENIERE	\N	SOLS	\N	Table ronde sur la reconversion des friches industrielles en région lilloise	\N	2020-06-16 17:45:00	2020-06-16 18:45:00	2020-06-22 10:08:28	2020-06-24 10:55:38	5	0	\N	\N
477496	COM_ENQUETE	PLENIERE	\N	SOLS	\N	Audition de la société Brownfields	\N	2020-06-17 16:45:00	2020-06-17 18:00:00	2020-06-22 10:08:45	2020-06-24 10:56:28	5	0	\N	\N
477505	COM_ENQUETE	PLENIERE	\N	SOLS	\N	Réunion plénière	\N	2020-06-10 18:00:00	2020-06-10 19:05:00	2020-06-10 19:51:19	2020-06-11 08:59:25	4	0	\N	\N
477527	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Porte-avions	\N	2020-06-10 13:00:00	2020-06-10 15:00:00	\N	\N	5	0	\N	\N
477708	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Fonds de garantie des victimes des actes de terrorisme	\N	2020-06-10 14:00:00	2020-06-10 14:45:00	\N	\N	1	0	\N	\N
477710	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Fonds de garantie des victimes des actes de terrorisme	\N	2020-06-10 16:30:00	2020-06-10 17:15:00	\N	\N	1	0	\N	\N
477752	COM_EURO	AUDRAP	\N	AFEU	\N	Action européenne pour le Climat	\N	2020-04-15 16:30:00	2020-04-15 18:45:00	\N	\N	2	0	\N	\N
459647	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2019-12-04 18:30:00	2019-12-04 19:30:00	\N	\N	1	0	\N	\N
477755	COM_EURO	AUDRAP	\N	AFEU	\N	Action européenne pour le Climat	Action européenne pour le climat - I4CE	2020-04-15 17:30:00	2020-04-15 18:45:00	\N	\N	2	0	\N	\N
477767	COM_EURO	AUDRAP	\N	AFEU	\N	Action européenne pour le climat	Action européenne pour le climat - Commission européenne - DG Climat	2020-04-16 11:00:00	2020-04-16 12:15:00	\N	\N	2	0	\N	\N
477779	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	Réunion GT Subsidiarité	Réunion du Groupe de Travail sur la  Subsidiarité	2020-04-17 10:30:00	2020-04-17 10:45:00	\N	\N	2	0	\N	\N
477782	COM_EURO	AUTRE	\N	AFEU	\N	Audition de M. Philippe Léglise-Costa	Audition de M. Philippe Léglise-Costa, Représentant Permanent de la France auprès de l'UE	2020-04-17 11:00:00	2020-04-17 12:35:00	2020-06-11 17:18:33	\N	16	0	\N	\N
477799	COM_ENQUETE	AUDRAP	\N	AUTOROUT	\N	CE concessions autoroutières - SGI/Frontier Economics/Fin Infra	CE concessions autoroutières - SGI/Frontier Economics/Fin Infra	2020-06-11 09:00:00	2020-06-11 12:00:00	\N	\N	4	0	\N	\N
477800	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur Dette sociale et autonomie (PJLO et PJL)	\N	2020-06-16 14:30:00	2020-06-16 15:30:00	\N	\N	9	0	\N	\N
477805	COM_ENQUETE	AUDRAP	\N	AUTOROUT	\N	CE concessions autoroutières - Université Paris 1 / APE	CE concessions autoroutières - Université Paris 1 / APE	2020-06-11 15:00:00	2020-06-11 17:00:00	\N	\N	4	0	\N	\N
477837	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-06-16 13:05:00	2020-06-16 15:15:00	2020-06-16 15:38:27	2020-06-16 18:11:48	18	0	\N	\N
477838	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-06-17 09:30:00	2020-06-17 12:35:00	2020-06-17 12:42:23	2020-06-17 18:15:16	39	0	\N	\N
477839	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Examen des amendements de séance sur la PPL Don de chèques-vacances	\N	2020-06-16 13:35:00	2020-06-16 13:45:00	2020-06-16 14:04:51	2020-06-16 14:51:00	24	0	\N	\N
477841	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Examen d'un rapport et d'un texte et audition plénière	\N	2020-06-17 09:35:00	2020-06-17 12:30:00	2020-06-17 12:35:50	2020-06-17 18:15:12	37	0	\N	\N
477842	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition plénière de M. Rémi Pellet	\N	2020-06-18 10:35:00	2020-06-18 12:30:00	2020-06-18 16:28:23	2020-06-18 17:27:50	17	0	\N	\N
477843	DELEGATION	AUDRAP	\N	\N	DSOM	Réunion avec MM. Jean-Paul Virapoullé et Jack Gautier, Conseil régional de La Réunion	\N	2020-06-12 12:00:00	2020-06-12 13:50:00	\N	\N	2	0	\N	\N
477844	DELEGATION	AUDRAP	\N	\N	DSOM	Réunion ave M. Daniel Gibbs, président du conseil territorial de Saint-Martin	\N	2020-06-12 16:30:00	2020-06-12 17:55:00	\N	\N	2	0	\N	\N
477845	DELEGATION	AUDRAP	\N	\N	DSOM	Réunion avec Josette Borel-Lincertin, présidente du Conseil départemental de la Guadeloupe	\N	2020-06-10 17:00:00	2020-06-10 18:30:00	\N	\N	3	0	\N	\N
477849	DELEGATION	AUDRAP	\N	\N	DSOM	Réunion avec M. Alfred Marie-Jeanne	\N	2020-06-10 19:00:00	2020-06-10 19:50:00	\N	\N	1	0	\N	\N
477851	DELEGATION	AUDRAP	\N	\N	DSOM	Réunion avec M. Stéphane Lenormand, Conseil territorial de Saint-Pierre-et-Miquelon	\N	2020-06-12 15:00:00	2020-06-12 15:55:00	\N	\N	2	0	\N	\N
477988	COM_ENQUETE	AUDRAP	\N	AUTOROUT	\N	CE concessions autoroutières - Juriste Université Paris 1/Ancien Pdt CNMSCAOA	CE concessions autoroutières - Juriste Université Paris 1/Ancien Pdt CNMSCAOA	2020-06-18 09:00:00	2020-06-18 10:50:00	\N	\N	4	0	\N	\N
478018	DELEGATION	AUDRAP	\N	\N	211	Audition France Médias Monde	Audition France Médias Monde	2020-06-15 16:30:00	2020-06-15 17:40:00	\N	\N	5	0	\N	\N
478024	MISSION	AUCUNE	\N	FEDERATION	\N	Réunion plénière - Audition Cour des comptes	Réunion plénière - Audition Cour des comptes	2020-06-15 14:30:00	2020-06-15 16:10:00	2020-06-15 18:31:58	2020-06-16 14:50:37	10	0	\N	\N
382339	BUREAU	AUCUNE	\N	\N	\N	Bureau	Bureau	2019-05-22 08:30:00	2019-05-22 11:45:00	\N	\N	21	0	\N	\N
391398	CONF_PRES	AUCUNE	\N	\N	\N	Cionférence des Présidents	Conférence des Présidents	2019-06-11 14:15:00	2019-06-11 14:30:00	\N	\N	26	0	\N	\N
399677	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Économie circulaire - Auditions Mme de CIDRAC	\N	2019-07-09 14:35:00	2019-07-09 15:30:00	\N	\N	4	0	\N	\N
399686	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Économie circulaire - Auditions Mme de CIDRAC	\N	2019-07-08 09:00:00	2019-07-08 12:30:00	\N	\N	2	0	\N	\N
399687	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Économie circulaire - Auditions Mme de CIDRAC	\N	2019-07-08 14:30:00	2019-07-08 18:30:00	\N	\N	2	0	\N	\N
406862	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Santé au travail	Santé au travail	2019-10-02 10:15:00	2019-10-02 11:40:00	2019-10-02 13:16:34	2019-10-02 16:04:08	41	0	\N	\N
407126	MISSION	AUCUNE	\N	MARITIME	\N	MCI Sauvetage en Mer - Réunion de bureau	MCI Sauvetage en Mer - Réunion de bureau	2019-09-25 14:05:00	2019-09-25 14:55:00	2019-09-25 16:05:54	2019-09-26 16:37:59	4	0	\N	\N
410851	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Auditions branche Famille	\N	2019-10-15 17:30:00	2019-10-15 18:30:00	\N	\N	2	0	\N	\N
410852	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Auditions branche Famille	\N	2019-10-16 16:45:00	2019-10-16 17:45:00	\N	\N	1	0	\N	\N
410853	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Auditions branche Famille	\N	2019-10-22 15:30:00	2019-10-22 19:00:00	\N	\N	2	0	\N	\N
410857	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Auditions programme Hébergement	\N	2019-10-23 14:00:00	2019-10-23 15:00:00	\N	\N	1	0	\N	\N
410858	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Auditions programme Hébergement	\N	2019-10-23 16:30:00	2019-10-23 18:00:00	\N	\N	1	0	\N	\N
410859	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Auditions programme Hébergement	\N	2019-10-29 10:15:00	2019-10-29 12:00:00	\N	\N	1	0	\N	\N
410860	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Auditions programme Hébergement	\N	2019-10-29 14:30:00	2019-10-29 17:00:00	\N	\N	1	0	\N	\N
410861	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Auditions programme Hébergement	\N	2019-10-30 14:00:00	2019-10-30 15:00:00	\N	\N	1	0	\N	\N
410862	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Auditions programme Hébergement	\N	2019-10-30 16:30:00	2019-10-30 18:30:00	\N	\N	1	0	\N	\N
410869	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	algorithmes locaux dans Parcoursup	algorithmes locaux dans Parcoursup	2019-10-02 13:30:00	2019-10-02 14:30:00	\N	\N	3	0	\N	\N
410873	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Presse	PLF 2020 - Crédits Presse	2019-10-03 09:00:00	2019-10-03 10:00:00	\N	\N	1	0	\N	\N
410875	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Fondation du patrimoine	PPL Fondation du patrimoine	2019-10-02 11:00:00	2019-10-02 11:45:00	\N	\N	3	0	\N	\N
410879	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Fondation du patrimoine	PPL Fondation du patrimoine	2019-10-02 16:30:00	2019-10-02 18:00:00	\N	\N	3	0	\N	\N
410912	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Engagement et proximité - Suite de l'examen des amendements de séance	PJL Engagement et proximité - Suite de l'examen des amendements de séance	2019-10-08 20:10:00	2019-10-08 20:35:00	2019-10-09 09:53:05	2019-10-09 17:38:38	0	0	\N	\N
459650	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2019-12-05 14:30:00	2019-12-05 16:00:00	\N	\N	1	0	\N	\N
404254	CMP	AUTRE	\N	AGENCESPORT	\N	PJL Jeux Olympiques et Paralympiques de 2024	PJL Jeux Olympiques et Paralympiques de 2024	2019-07-23 08:35:00	2019-07-23 09:25:00	\N	\N	12	0	\N	\N
410920	DELEGATION	AUCUNE	\N	\N	211	Échange de vues sur la proposition de loi visant à agir contre les violences faites aux fe	Échange de vues sur la proposition de loi visant à agir contre les violences faites aux femmes.	2019-10-22 16:45:00	2019-10-22 17:30:00	2019-10-23 15:08:33	\N	11	0	\N	\N
410921	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Auditions médico-social	\N	2019-10-15 16:30:00	2019-10-15 19:30:00	\N	\N	1	0	\N	\N
410922	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition médico-social	\N	2019-10-16 19:00:00	2019-10-16 20:00:00	\N	\N	2	0	\N	\N
410923	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Auditions médico-social	\N	2019-10-17 09:30:00	2019-10-17 11:30:00	\N	\N	1	0	\N	\N
410924	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition médico-social	\N	2019-10-17 15:00:00	2019-10-17 16:00:00	\N	\N	1	0	\N	\N
410925	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition médico-social	\N	2019-10-22 11:00:00	2019-10-22 12:00:00	\N	\N	1	0	\N	\N
410926	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS Budget 2020 Médico-social	\N	2019-10-29 15:00:00	2019-10-29 16:00:00	\N	\N	1	0	\N	\N
410951	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Service public de l'éducation et neutralité religieuse	PPL Service public de l'éducation et neutralité religieuse	2019-10-07 10:00:00	2019-10-07 11:00:00	\N	\N	1	0	\N	\N
411100	COM_PERMANENTE	AUTRE	\N	FINC	\N	Contrôle budgétaire Évaluation transformation ISF en IFI et création PFU	Contrôle budgétaire Évaluation transformation ISF en IFI et création PFU	2019-10-09 10:50:00	2019-10-09 12:25:00	2019-10-09 19:20:50	2019-10-10 14:55:52	25	0	\N	\N
411209	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-10-09 09:35:00	2019-10-09 12:20:00	2019-10-09 12:30:13	2019-10-09 17:38:41	37	0	\N	\N
411524	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	GT Obligation de signalement	\N	2019-10-08 14:30:00	2019-10-08 18:00:00	\N	\N	4	0	\N	\N
413611	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Lutte contre la haine sur internet	\N	2019-10-09 14:05:00	2019-10-09 15:10:00	\N	\N	2	0	\N	\N
413623	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT États généraux de l'alimentation	DGCCRF	2019-10-09 11:00:00	2019-10-09 11:45:00	\N	\N	8	0	\N	\N
413679	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT États généraux de l'alimentation	Ministère de l'Agriculture	2019-10-10 09:00:00	2019-10-10 10:00:00	\N	\N	4	0	\N	\N
413694	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT États généraux de l'alimentation	Synabio 	2019-10-10 10:00:00	2019-10-10 10:30:00	\N	\N	3	0	\N	\N
413701	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT États généraux de l'alimentation	La Brosse et Dupont	2019-10-10 10:30:00	2019-10-10 11:15:00	\N	\N	2	0	\N	\N
413706	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT États généraux de l'alimentation	Gimbert Océan	2019-10-10 11:15:00	2019-10-10 12:00:00	\N	\N	2	0	\N	\N
413713	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT États généraux de l'alimentation	Médiateur des relations commerciales agricoles	2019-10-09 14:15:00	2019-10-09 15:00:00	\N	\N	5	0	\N	\N
413771	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJLF POUR 2020 - P. 144	PJLF POUR 2020 - ¨P. 144	2019-10-09 16:30:00	2019-10-09 17:30:00	\N	\N	2	0	\N	\N
413798	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJLF pour 2020 - P 105	PJLF pour 2020 - P 105	2019-10-08 16:30:00	2019-10-08 18:45:00	\N	\N	2	0	\N	\N
413801	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJLF pour 2020 - P 178	PJLF pour 2020 - P 178	2019-10-08 14:30:00	2019-10-08 15:30:00	\N	\N	2	0	\N	\N
413804	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJLF pour 2020 - p 178	PJLF pour 2020 - p 178	2019-10-09 18:30:00	2019-10-09 19:30:00	\N	\N	2	0	\N	\N
416296	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL code de l'urbanisme de Saint-Martin	PJL code de l'urbanisme de Saint-Martin	2019-11-05 15:37:00	2019-11-05 16:55:00	\N	\N	72	0	\N	\N
416297	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL prestation de compensation du handicap	PPL prestation de compensation du handicap	2019-11-05 17:00:00	2019-11-05 18:40:00	\N	\N	91	0	\N	\N
416301	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2019-11-06 15:00:00	2019-11-06 16:15:00	\N	\N	293	0	\N	\N
416302	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL agir contre les violences faites aux femmes	PPL agir contre les violences faites aux femmes	2019-11-06 17:15:00	2019-11-06 20:10:00	\N	\N	81	0	\N	\N
416303	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL agir contre les violences faites aux femmes	PPL agir contre les violences faites aux femmes	2019-11-06 21:41:00	2019-11-07 01:35:00	\N	\N	56	0	\N	\N
416304	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2019-11-12 09:30:00	2019-11-12 12:50:00	\N	\N	36	0	\N	\N
449111	GIA	AUCUNE	\N	\N	\N	Entretien avec les chefs de service économiques de Stockholm et d'Helsinki	Entretien avec les chefs de service économiques de Stockholm et d'Helsinki	2019-11-07 09:30:00	2019-11-07 11:00:00	\N	\N	4	0	640	\N
456499	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition GT Nouvelles formes de commerce - Rapporteur M. Babary	Audition GT Nouvelles formes de commerce - Rapporteur M. Babary	2020-02-20 09:10:00	2020-02-20 10:30:00	\N	\N	1	0	\N	\N
458213	MISSION	AUCUNE	\N	BREXIT2	\N	Audition de Mme Patricia O'Brien, ambassadeur d'Irlande à Paris	Audition de Mme Patricia O'Brien, ambassadeur d'Irlande à Paris	2020-02-25 15:35:00	2020-02-25 16:55:00	2020-02-26 16:22:16	\N	9	0	\N	\N
470631	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Création de Points d'accueil pour soins immédiats	\N	2020-05-14 09:30:00	2020-05-14 10:40:00	\N	\N	3	0	\N	\N
470800	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid19 Presse	Audition SEPM	2020-05-15 14:00:00	2020-05-15 15:00:00	\N	\N	3	0	\N	\N
470804	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi Covid-19 - Juridictions judiciaires et administratives	\N	2020-05-14 11:30:00	2020-05-14 12:30:00	\N	\N	2	0	\N	\N
470807	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi Covid-19 - Juridictions judiciaires et administratives	\N	2020-05-15 10:00:00	2020-05-15 11:00:00	\N	\N	6	0	\N	\N
470847	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid 19 Enseign Sup	Echanges entre membres du GT	2020-05-12 14:00:00	2020-05-12 14:40:00	\N	\N	5	0	\N	\N
410914	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPR CE Incendie Lubrizol (recevabilité) - PJL Engagement et proximité (amdts séance)	PPR CE Incendie Lubrizol (recevabilité) - PJL Engagement et proximité (amdts séance)	2019-10-09 09:35:00	2019-10-09 09:50:00	2019-10-09 11:00:50	2019-10-09 17:38:41	39	1	\N	\N
470853	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid 19 AEF	Echanges entre membres du GT	2020-05-14 09:00:00	2020-05-14 09:40:00	\N	\N	3	0	\N	\N
470867	DELEGATION	AUDRAP	\N	\N	206	Audition Production de l'énergie dans le secteur agricole	Audition Production de l'énergie dans le secteur agricole - Engie	2020-05-15 10:00:00	2020-05-15 11:40:00	\N	\N	1	0	\N	\N
470869	DELEGATION	AUDRAP	\N	\N	206	Audition Production de l'énergie dans le secteur agricole	Audition Production de l'énergie dans le secteur agricole - Groupe Avril	2020-05-15 11:40:00	2020-05-15 13:20:00	\N	\N	1	0	\N	\N
470871	DELEGATION	AUDRAP	\N	\N	206	Entretien avec M. Lothar Wieler, président du Robert-Koch Institut (Berlin)	Entretien avec M. Lothar Wieler, président du Robert-Koch Institut (Berlin)	2020-05-20 17:00:00	2020-05-20 18:00:00	\N	\N	2	0	\N	\N
470887	DELEGATION	AUDRAP	\N	\N	211	Audition de Mme Carole Bienaimé-Besse	\N	2020-05-28 15:00:00	2020-05-28 16:45:00	\N	\N	10	0	\N	\N
470972	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Aditions Mme Estrosi Sassone	Audition PPL efficacité des APL	2020-05-18 10:00:00	2020-05-18 11:30:00	\N	\N	1	0	\N	\N
470985	COM_ENQUETE	AUDRAP	\N	SOLS	\N	Table ronde d'avocats spécialisés dans le droit de l'environnement (Gisèle Jourda)	\N	2020-05-15 15:15:00	2020-05-15 16:50:00	\N	\N	4	0	\N	\N
470986	COM_ENQUETE	AUDRAP	\N	SOLS	\N	Audition de l'AFITE (Gisèle Jourda)	\N	2020-05-15 14:00:00	2020-05-15 15:05:00	\N	\N	7	0	\N	\N
471087	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition oenotourisme	Audition oenotourisme Vin et Société	2020-05-19 09:00:00	2020-05-19 10:30:00	\N	\N	15	0	\N	\N
471173	DELEGATION	AUCUNE	\N	\N	PROS	Examen du rapport sur se nourrir en 2050	Examen du rapport sur se nourrir en 2050	2020-05-28 09:30:00	2020-05-28 11:00:00	\N	\N	15	0	\N	\N
471796	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid19 Création	Audition SAS Pass Culture	2020-05-19 18:30:00	2020-05-19 19:30:00	\N	\N	3	0	\N	\N
471997	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid19 Création	table ronde art visuels:Cipac, Fraap, Platform, Caap	2020-05-20 13:30:00	2020-05-20 15:00:00	\N	\N	3	0	\N	\N
472014	COM_ENQUETE	PLENIERE	\N	RADICALI	\N	Audition conjointe de Mmes Razika ADNANI et Djemila BENHABIB	Audition conjointe de Mmes Razika ADNANI et Djemila BENHABIB	2020-05-28 11:00:00	2020-05-28 12:40:00	2020-05-28 14:10:29	2020-05-28 14:44:37	5	0	\N	\N
472015	COM_ENQUETE	PLENIERE	\N	RADICALI	\N	Audition de Mme Nadia REMADNA	\N	2020-05-29 11:10:00	2020-05-29 11:50:00	\N	\N	5	0	\N	\N
472051	COM_ENQUETE	PLENIERE	\N	RADICALI	\N	Audition conjointe de MM. Mohamed-Ali ADRAOUI et Haoues SENIGUER	\N	2020-05-28 14:00:00	2020-05-28 15:45:00	2020-05-28 16:17:46	2020-05-28 18:13:54	7	0	\N	\N
472052	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Audition de France Stratégie	\N	2020-05-25 17:00:00	2020-05-25 18:30:00	2020-05-26 11:13:41	\N	9	0	\N	\N
472053	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion 20200526a	\N	2020-05-26 09:35:00	2020-05-26 10:25:00	2020-05-26 11:58:30	2020-05-26 14:16:10	26	0	\N	\N
472056	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion de la commission	Réunion de la commission	2020-05-27 08:30:00	2020-05-27 08:55:00	2020-05-28 15:30:21	2020-05-28 15:34:56	32	1	\N	\N
472057	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition M. Steinmetz candidat à la HATVP	Audition M. Steinmetz candidat à la HATVP	2020-05-27 08:55:00	2020-05-27 10:00:00	2020-05-28 15:30:59	2020-05-28 15:34:56	36	1	\N	\N
472058	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion de la commission	Réunion de la commission	2020-05-27 10:00:00	2020-05-27 11:30:00	2020-05-28 15:31:19	2020-05-28 15:34:58	35	1	\N	\N
472063	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Examen des amendements de séance du PJL dispositions urgentes Covid-19	\N	2020-05-26 13:35:00	2020-05-26 14:15:00	2020-06-08 15:21:59	2020-06-08 16:34:04	30	0	\N	\N
472064	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PPL Mineurs vulnérables, PPL PASI et PPL Travailleurs plateformes numériques	\N	2020-05-27 09:05:00	2020-05-27 11:35:00	2020-06-08 15:21:19	2020-06-08 16:34:02	38	1	\N	\N
472299	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2020-05-19 14:40:00	2020-05-19 16:50:00	\N	\N	2	0	\N	\N
472390	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 4 juin 2020	Réunion du 4 juin 2020	2020-06-04 09:15:00	2020-06-04 11:53:00	2020-06-08 20:50:38	2020-06-10 16:12:01	16	0	\N	\N
472418	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2020-05-26 17:02:00	2020-05-26 18:36:00	2020-05-27 14:39:00	2020-05-27 17:08:59	27	0	\N	\N
473366	MISSION	AUDRAP	\N	ILLECTRONISM	\N	Audition de France Stratégie	M. Vincent Aussilloux, directeur du département économie, France Stratégie	2020-06-02 15:00:00	2020-06-02 16:00:00	\N	\N	8	0	\N	\N
473369	MISSION	AUDRAP	\N	ILLECTRONISM	\N	Audition de l'INSEE	M. Stéphane Legleye, chef de la division "Conditions de vie des ménages", INSEE	2020-06-04 15:00:00	2020-06-04 15:50:00	\N	\N	5	0	\N	\N
473557	DELEGATION	AUCUNE	\N	\N	COLTER	Audition C. Castaner, ministre de l'Intérieur	\N	2020-06-04 09:30:00	2020-06-04 11:20:00	2020-06-04 11:20:37	\N	24	0	\N	\N
473474	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Transports-Transdev	Covid-19-Transports-Transdev	2020-04-17 10:30:00	2020-04-17 11:15:00	\N	\N	2	0	\N	\N
473476	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Transports-Groupement des autorités responsables de transport (GART)	Covid-19-Transports-Groupement des autorités responsables de transport (GART)	2020-04-24 15:00:00	2020-04-24 16:00:00	\N	\N	10	0	\N	\N
473456	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Eau Biodiversité-M. Gilles BOEUF, scientifique	Covid-19-Eau Biodiversité-M. Gilles BOEUF, scientifique	2020-05-07 17:00:00	2020-05-07 17:45:00	\N	\N	6	0	\N	\N
473400	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Alimentation durable-Table ronde scientifiques	Covid-19-Alimentation durable-Table ronde scientifiques	2020-05-11 10:15:00	2020-05-11 11:40:00	\N	\N	12	0	\N	\N
474185	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI SCAF	\N	2020-05-25 16:30:00	2020-05-25 17:45:00	\N	\N	2	0	\N	\N
474188	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI SCAF	\N	2020-05-26 09:00:00	2020-05-26 10:00:00	\N	\N	3	0	\N	\N
474308	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	2020 - Application de la LFSS	\N	2020-05-29 11:00:00	2020-05-29 12:10:00	\N	\N	14	0	\N	\N
474428	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Protéger les victimes de violences conjugales	\N	2020-05-28 14:30:00	2020-05-28 15:30:00	\N	\N	1	0	\N	\N
474431	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Protéger les victimes de violences conjugales	\N	2020-05-29 09:30:00	2020-05-29 12:30:00	\N	\N	2	0	\N	\N
474434	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Protéger les victimes de violences conjugales	\N	2020-05-29 14:30:00	2020-05-29 18:30:00	\N	\N	2	0	\N	\N
474552	MISSION	AUDRAP	\N	GUYANE	\N	\N	\N	2020-06-02 14:30:00	2020-06-02 17:15:00	\N	\N	13	0	\N	\N
474577	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 -cellule logement - OPH fédération nationale - FNAIM Alpes maritimes	\N	2020-04-03 17:30:00	2020-04-03 18:30:00	\N	\N	2	0	\N	\N
474581	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule logement - CAPEB	\N	2020-04-24 09:00:00	2020-04-24 10:00:00	\N	\N	2	0	\N	\N
380217	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Mme Gruny M. Artano MI Santé au travail	\N	2019-05-16 10:00:00	2019-05-16 11:00:00	\N	\N	2	0	\N	\N
380221	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Mme Gruny M. Artano MI Santé au travail	\N	2019-05-16 11:00:00	2019-05-16 11:45:00	\N	\N	2	0	\N	\N
380225	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-05-21 09:30:00	2019-05-21 11:00:00	2019-05-21 11:36:47	2019-05-21 17:55:45	30	5	\N	\N
382283	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Création d'un statut de l'élu communal	\N	2019-05-22 11:30:00	2019-05-22 12:10:00	\N	\N	1	0	\N	\N
384439	GIA	AUCUNE	\N	\N	\N	Entretien avec A. Lefèvre et des membres du GIA  d'une délégation de six staffers du Congr	Entretien avec A. Lefèvre et des membres du GIA  d'une délégation de six staffers du Congrès américain	2019-05-28 17:45:00	2019-05-28 18:00:00	\N	\N	6	0	590	\N
385258	GIA	AUCUNE	\N	\N	\N	Rencontre du président Tourenne avec M. Reza Jafari	Rencontre entre le président du GIA et M. Reza Jafari, porteur d'un projet de centre culturel afghan	2019-06-12 16:00:00	2019-06-12 17:00:00	\N	\N	1	0	648	\N
385260	GIA	AUCUNE	\N	\N	\N	Rencontre avec M. Jamal al-Dhari	Entretien avec M. Jamal al-Dhari, homme politique irakien, président de l'ONG Iraqi National Project	2019-06-18 16:00:00	2019-06-18 17:00:00	\N	\N	2	0	615	\N
389738	COM_EURO	AUTRE	\N	AFEU	\N	Débat préalable au Conseil européen	Débat préalable au Conseil européen	2019-06-19 14:20:00	2019-06-19 17:00:00	2019-06-20 14:51:43	2019-06-20 14:58:51	18	0	\N	\N
389965	DELEGATION	AUDRAP	\N	\N	PROS	Audition de l'ANDRH	\N	2019-06-20 10:00:00	2019-06-20 11:00:00	\N	\N	2	0	\N	\N
389977	DELEGATION	AUDRAP	\N	\N	PROS	Audition de l'INRIA	\N	2019-07-02 14:00:00	2019-07-02 15:00:00	\N	\N	2	0	\N	\N
389980	DELEGATION	AUDRAP	\N	\N	PROS	Audition de M. Degryse	\N	2019-07-03 14:00:00	2019-07-03 15:00:00	\N	\N	2	0	\N	\N
389981	DELEGATION	AUDRAP	\N	\N	PROS	Audition du CEREQ	\N	2019-07-03 15:00:00	2019-07-03 16:00:00	\N	\N	2	0	\N	\N
390060	MISSION	AUTRE	\N	FONDS	\N	CGET	\N	2019-06-18 17:35:00	2019-06-18 19:10:00	2019-06-18 19:20:35	2019-06-19 18:04:03	11	0	\N	\N
390061	MISSION	AUTRE	\N	FONDS	\N	Audition plénière - Sous-utilisation chronique des fonds européens en France	\N	2019-06-19 17:35:00	2019-06-19 18:45:00	2019-06-19 18:48:56	2019-06-20 16:08:29	5	0	\N	\N
390062	MISSION	AUTRE	\N	FONDS	\N	Audition plénière - Sous-utilisation chronique des fonds européens en France	\N	2019-06-20 14:00:00	2019-06-20 14:55:00	2019-06-20 14:59:49	2019-06-20 16:08:30	6	0	\N	\N
390068	DELEGATION	AUDRAP	\N	\N	PROS	Audition de M. Philippe Coiffet	\N	2019-06-20 11:00:00	2019-06-20 12:00:00	\N	\N	1	0	\N	\N
394139	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Énergie - Auditions Mme Bories	\N	2019-06-25 10:00:00	2019-06-25 11:00:00	\N	\N	2	0	\N	\N
394145	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Energie - Auditions M. Gremillet	\N	2019-06-25 10:00:00	2019-06-25 11:00:00	\N	\N	2	0	\N	\N
394170	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Jeux Olympiques et Paralympiques de 2024	\N	2019-06-25 13:45:00	2019-06-25 14:45:00	\N	\N	8	0	\N	\N
395948	GIA	AUCUNE	\N	\N	\N	Audition Ambassadeur de Turquie en France	Audition de l'Ambassadeur de Turquie en France, SE M. Ismail Hakki Musa	2019-06-26 13:00:00	2019-06-26 14:30:00	\N	\N	8	0	624	\N
404673	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions PJL Économie circulaire	\N	2019-07-26 10:00:00	2019-07-26 12:15:00	\N	\N	1	0	\N	\N
404675	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions PJL Économie circulaire	Auditions	2019-07-26 14:30:00	2019-07-26 15:00:00	\N	\N	1	0	\N	\N
404677	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions PJL Économie circulaire	Auditions	2019-07-26 15:30:00	2019-07-26 18:30:00	\N	\N	1	0	\N	\N
414149	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL AVIA	\N	2019-10-15 09:30:00	2019-10-15 11:00:00	\N	\N	2	0	\N	\N
414857	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR Turquie	PPR Turquie	2019-10-22 15:47:00	2019-10-22 17:17:00	\N	\N	111	0	\N	\N
417326	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2020 - Mildeca	PLF pour 2020 - Mildeca	2019-10-24 11:30:00	2019-10-24 12:30:00	\N	\N	1	0	\N	\N
417328	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2020 - Mildeca	PLF pour 2020 - Mildeca	2019-10-30 14:00:00	2019-10-30 15:00:00	\N	\N	0	0	\N	\N
417329	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2020 - Mildeca	PLF pour 2020 - Mildeca	2019-10-30 16:30:00	2019-10-30 17:15:00	\N	\N	1	0	\N	\N
417331	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS Budget 2020 - Assurance vieillesse	PLFSS Budget 2020 - Assurance vieillesse	2019-10-22 15:15:00	2019-10-22 16:00:00	\N	\N	1	0	\N	\N
422667	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2020 - Programmes 844/847	\N	2019-10-30 16:30:00	2019-10-30 17:35:00	\N	\N	1	0	\N	\N
422669	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2020 - Programmes 844/847	\N	2019-10-30 17:35:00	2019-10-30 19:15:00	\N	\N	2	0	\N	\N
422908	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2020 - Avis Outre-mer	\N	2019-10-30 14:00:00	2019-10-30 15:00:00	\N	\N	1	0	\N	\N
422910	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2020 - Avis Outre-mer	\N	2019-10-31 15:00:00	2019-10-31 17:30:00	\N	\N	1	0	\N	\N
424896	DELEGATION	AUCUNE	\N	\N	COLTER	Audition E. Morvan, DGPN	\N	2019-11-14 09:30:00	2019-11-14 11:30:00	2019-11-14 12:19:31	\N	10	0	\N	\N
430308	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Examen rapport nouvelle lecture PLFSS 2020	\N	2019-11-27 13:35:00	2019-11-27 14:30:00	2019-11-27 15:28:30	2019-11-27 15:53:36	36	0	\N	\N
431915	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition difficultés de recrutement et évolution des métiers	Audition difficultés de recrutement et évolution des métiers - rexecode	2019-11-26 10:00:00	2019-11-26 11:00:00	\N	\N	4	0	\N	\N
433887	GIA	AUCUNE	\N	\N	\N	Audition  de Mgr Nicolas BAALBAKI, Métropolite de Hama 	Audition  de Mgr Nicolas BAALBAKI, Métropolite de Hama 	2019-11-26 17:00:00	2019-11-26 18:00:00	\N	\N	13	0	CHRETORIENT	CHRETORIENT
433901	GIA	AUCUNE	\N	\N	\N	Déjeuner de travail avec des députés jordaniens	Déjeuner de travail avec une délégation de députés de Jordanie et l'ambassadeur de Jordanie à Paris	2019-11-27 12:45:00	2019-11-27 14:30:00	\N	\N	4	0	659	\N
433918	GIA	AUCUNE	\N	\N	\N	Déjeuner de travail avec des députés jordaniens (Ass. nationale)	Déjeuner de travail avec des députés jordaniens  à l'invitation de Valérie BOYER présidente du groupe d'amitié (AN)	2019-11-26 12:30:00	2019-11-26 14:00:00	\N	\N	1	0	659	\N
436957	GIA	AUCUNE	\N	\N	\N	Grande Commission France-Chine	Grande Commission France-Chine avec des représentants de l'Assemblée populaire nationale	2019-12-03 16:00:00	2019-12-03 19:00:00	\N	\N	9	0	584	\N
380226	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-05-22 09:35:00	2019-05-22 12:15:00	2019-05-22 14:08:10	2019-05-22 17:38:08	43	2	\N	\N
389606	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion de commission	\N	2019-06-12 09:30:00	2019-06-12 12:51:00	2019-06-13 15:48:58	2019-06-13 16:25:17	44	2	\N	\N
422672	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-11-06 09:30:00	2019-11-06 11:35:00	2019-11-06 14:20:42	2019-11-06 14:36:20	42	1	\N	\N
439342	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Nomination de rapporteurs - MI Sapeurs-pompiers (rapport d'information)	Nomination de rapporteurs - MI Sapeurs-pompiers (rapport d'information)	2019-12-11 09:15:00	2019-12-11 10:20:00	2019-12-12 14:11:26	2019-12-12 16:22:19	34	0	\N	\N
439930	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution Plastique	Audition rapporteurs Pollution Plastique - AFISE	2019-12-17 17:00:00	2019-12-17 18:00:00	\N	\N	2	0	\N	\N
441689	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions de M. Montaugé et Mme Noël-PPL Libre choix du consommateur dans le cyberespace	\N	2019-12-17 10:00:00	2019-12-17 11:00:00	\N	\N	0	0	\N	\N
441694	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions de M. Montaugé et Mme Noël-PPL Libre choix du consommateur dans le cyberespace	\N	2019-12-19 09:30:00	2019-12-19 10:15:00	\N	\N	2	0	\N	\N
448857	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition MI Gouvernance des ports maritimes -Présidente Mme Filleul, Rapporteur M. Vaspart	Audition MI Gouvernance des ports maritimes - Présidente Mme Filleul, Rapporteur M. Vaspart	2020-01-28 08:30:00	2020-01-28 10:10:00	\N	\N	7	0	\N	\N
448870	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition MI Gouvernance des ports maritimes -Présidente Mme Filleul, Rapporteur M. Vaspart	Audition MI Gouvernance des ports maritimes -Présidente Mme Filleul, Rapporteur M. Vaspart	2020-01-28 10:10:00	2020-01-28 11:10:00	\N	\N	3	0	\N	\N
451696	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Pastoralisme	GT Pastoralisme	2020-02-04 13:30:00	2020-02-04 14:30:00	\N	\N	7	0	\N	\N
451850	COM_PERMANENTE	AUDRAP	\N	CDD	\N	\N	Audition MI Gouvernance des ports maritimes -Présidente Mme Filleul, Rapporteur M. Vaspart	2020-02-04 08:30:00	2020-02-04 09:15:00	\N	\N	6	0	\N	\N
451859	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition MI Gouvernance des ports maritimes -Présidente Mme Filleul, Rapporteur M. Vaspart	Audition MI Gouvernance des ports maritimes -Présidente Mme Filleul, Rapporteur M. Vaspart	2020-02-04 09:15:00	2020-02-04 10:00:00	\N	\N	7	0	\N	\N
451867	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition MI Gouvernance des ports maritimes -Présidente Mme Filleul, Rapporteur M. Vaspart	Audition MI Gouvernance des ports maritimes -Présidente Mme Filleul, Rapporteur M. Vaspart	2020-02-04 10:00:00	2020-02-04 11:00:00	\N	\N	3	0	\N	\N
462391	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2020-03-05 10:00:00	2020-03-05 11:35:00	\N	\N	3	0	\N	\N
469805	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions cellule agriculture	Auditions cellule agriculture	2020-04-07 10:00:00	2020-04-07 11:00:00	\N	\N	10	0	\N	\N
469916	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule agriculture	Auditions cellule agriculture	2020-04-30 09:45:00	2020-04-30 10:15:00	\N	\N	7	0	\N	\N
469924	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule agriculture	Auditions cellule agriculture	2020-04-30 10:15:00	2020-04-30 10:45:00	\N	\N	6	0	\N	\N
469931	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule agriculture	Auditions cellule agriculture	2020-04-30 10:45:00	2020-04-30 11:30:00	\N	\N	6	0	\N	\N
470010	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition GT Agriculteurs en détresse	Audition GT Agriculteurs en détresse	2020-04-02 10:00:00	2020-04-02 11:00:00	\N	\N	2	0	\N	\N
470057	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition GT Agriculteurs en détresse	Audition GT Agriculteurs en détresse	2020-04-07 14:00:00	2020-04-07 15:30:00	\N	\N	8	0	\N	\N
470066	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition GT Agriculteurs en détresse	Audition GT Agriculteurs en détresse	2020-04-08 13:30:00	2020-04-08 14:30:00	\N	\N	6	0	\N	\N
470073	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition GT Agriculteurs en détresse	Audition GT Agriculteurs en détresse	2020-04-10 13:45:00	2020-04-10 15:30:00	\N	\N	6	0	\N	\N
473464	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Gestion des déchets-Haut conseil de la santé publique	Covid-19-Gestion des déchets-Haut conseil de la santé publique	2020-05-28 10:30:00	2020-05-28 11:30:00	\N	\N	12	0	\N	\N
478025	MISSION	AUDRAP	\N	FEDERATION	\N	Auditions MI FFS	Auditions MI FFS	2020-06-15 16:20:00	2020-06-15 17:20:00	\N	\N	6	0	\N	\N
479028	GIA	AUCUNE	\N	\N	\N	Rencontre du président Tourenne avec M. Reza Jafari	\N	2020-06-18 11:30:00	2020-06-18 12:30:00	\N	\N	1	0	648	\N
479407	DELEGATION	AUDRAP	\N	\N	206	Entretien en visioconférence avec M. Nicolas Revel, directeur général de la CNAM	Entretien en visioconférence avec M. Nicolas Revel, directeur général de la CNAM	2020-06-10 18:00:00	2020-06-10 19:00:00	\N	\N	3	0	\N	\N
479575	COM_EURO	AUDRAP	\N	AFEU	\N	Union européenne et la santé, à la suite de la pandémie de COVID-19	Union européenne et la santé, à la suite de la pandémie de COVID-19 - EMA	2020-06-23 09:30:00	2020-06-23 11:00:00	\N	\N	2	0	\N	\N
479620	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteurs PPL Revalorisation des pensions de retraite agricoles	\N	2020-06-23 13:45:00	2020-06-23 14:10:00	\N	\N	8	0	\N	\N
479638	DELEGATION	AUCUNE	\N	\N	DSOM	Examen du rapport d'information sur l'urgence économique dans les outre-mer	\N	2020-07-09 14:00:00	2020-07-09 15:30:00	\N	\N	9	0	\N	\N
479744	COM_ENQUETE	PLENIERE	\N	SOLS	\N	Réunion plénière 	\N	2020-06-23 15:00:00	2020-06-23 18:05:00	2020-06-26 15:33:04	2020-06-26 18:12:07	7	0	\N	\N
479755	COM_EURO	AUTRE	\N	AFEU	\N	Audition de M. Fabrice Leggeri, directeur exécutif de Frontex	\N	2020-04-08 16:10:00	2020-04-08 17:45:00	\N	\N	0	0	\N	\N
480620	DELEGATION	AUDRAP	\N	\N	211	Audition de M. Riquier et Mme Kennedy - MAE	Audition de M. Riquier et Mme Kennedy - MAE	2020-06-24 16:00:00	2020-06-24 17:00:00	\N	\N	2	0	\N	\N
480818	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2020-07-01 09:35:00	2020-07-01 12:25:00	2020-07-01 14:59:55	\N	30	2	\N	\N
480835	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Marc-Antoine EYL MAZZEGA, chercheur à l'IFRI	Entretien avec M. Marc-Antoine EYL MAZZEGA, chercheur à l'IFRI	2020-06-25 08:30:00	2020-06-25 09:30:00	\N	\N	4	0	608	\N
480873	DELEGATION	AUCUNE	\N	\N	COLTER	Rapport d'information Ingénierie territoriale	\N	2020-07-02 09:15:00	2020-07-02 10:30:00	2020-07-02 11:32:02	\N	8	0	\N	\N
481127	MISSION	AUCUNE	\N	ILLECTRONISM	\N	Audition du Conseil national du numérique	Audition du Conseil national du numérique	2020-07-02 11:00:00	2020-07-02 11:45:00	2020-07-02 11:48:08	2020-07-02 18:19:22	4	0	\N	\N
481128	COM_EURO	AUTRE	\N	AFEU	\N	Table-ronde franco-allemande à l¿occasion de la présidence allemande de l¿UE	\N	2020-07-02 11:00:00	2020-07-02 13:00:00	\N	\N	5	0	\N	\N
481129	COM_EURO	AUTRE	\N	AFEU	\N	Audition commune - M. Wojciechowski, commissaire européen à l'agriculture	\N	2020-07-02 09:00:00	2020-07-02 11:10:00	2020-07-02 17:21:53	2020-07-02 18:18:35	17	0	\N	\N
481130	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT subsidiarité	GT subsidiarité	2020-05-12 10:00:00	2020-05-12 10:20:00	\N	\N	5	0	\N	\N
481136	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Bilan de la session et de la mandature	\N	2020-07-01 12:45:00	2020-07-01 14:00:00	2020-07-01 19:09:01	\N	20	0	\N	\N
481175	COM_ENQUETE	PLENIERE	\N	SOLS	\N	Réunion plénière 	\N	2020-06-24 16:45:00	2020-06-24 19:14:00	2020-06-26 15:37:19	2020-06-26 18:12:07	5	0	\N	\N
481181	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes	\N	2020-05-06 11:45:00	2020-05-06 13:05:00	\N	\N	0	0	\N	\N
441687	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-01-08 08:35:00	2020-01-08 09:00:00	2020-01-08 09:55:47	2020-01-08 10:38:22	38	0	\N	\N
481198	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule tourisme Reed Expositions France	\N	2020-04-07 11:30:00	2020-04-07 12:00:00	\N	\N	6	0	\N	\N
481211	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions tourisme	\N	2020-04-08 14:30:00	2020-04-08 16:30:00	\N	\N	3	0	\N	\N
481224	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions ADN et CCI France	\N	2020-04-09 11:00:00	2020-04-09 12:30:00	\N	\N	3	0	\N	\N
481231	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Accor	\N	2020-04-15 14:00:00	2020-04-15 14:45:00	\N	\N	7	0	\N	\N
481238	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Auditions SCAF	\N	2020-06-25 09:00:00	2020-06-25 10:00:00	\N	\N	0	0	\N	\N
481268	COM_PERMANENTE	AUDRAP	\N	CAE	\N	auditions cellule tourisme Expedia et air bnb	\N	2020-04-17 14:00:00	2020-04-17 15:30:00	\N	\N	5	0	\N	\N
481285	ETUDES	AUDRAP	\N	\N	\N	Audition GE cancer	\N	2020-06-26 14:30:00	2020-06-26 15:30:00	\N	\N	3	0	\N	1004
481296	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition tourisme ANETT	\N	2020-04-20 14:00:00	2020-04-20 14:45:00	\N	\N	5	0	\N	\N
481344	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition tourisme UNAT	\N	2020-04-22 14:00:00	2020-04-22 15:00:00	\N	\N	4	0	\N	\N
481353	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions tourisme	\N	2020-04-22 16:15:00	2020-04-22 17:15:00	\N	\N	6	0	\N	\N
481367	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions tourisme MAE, DGE et UFC Que choisir	\N	2020-04-24 14:00:00	2020-04-24 17:00:00	\N	\N	4	0	\N	\N
481378	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule tourisme In extenso	\N	2020-04-27 15:00:00	2020-04-27 15:45:00	\N	\N	3	0	\N	\N
481398	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule tourisme Unesco	\N	2020-05-13 14:00:00	2020-05-13 14:45:00	\N	\N	4	0	\N	\N
481404	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule tourisme IFT	\N	2020-05-13 17:00:00	2020-05-13 17:45:00	\N	\N	3	0	\N	\N
481408	COM_ENQUETE	PLENIERE	\N	SOLS	\N	Réunion plénière - Audition E. Borne	\N	2020-07-01 16:45:00	2020-07-01 18:25:00	2020-07-03 17:47:14	2020-07-03 18:34:52	8	0	\N	\N
481412	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions cellule tourisme	\N	2020-05-18 14:00:00	2020-05-18 17:00:00	\N	\N	0	0	\N	\N
481413	COM_EURO	AUTRE	\N	AFEU	\N	Audition de Mme de Montchalin 	Audition de Mme de Montchalin - débat post conseil européen	2020-04-24 10:30:00	2020-04-24 11:50:00	2020-06-26 17:23:05	\N	18	0	\N	\N
481414	DELEGATION	AUDRAP	\N	\N	DSOM	Rencontre avec Mme de Palmas (FEDOM)	\N	2020-06-26 11:30:00	2020-06-26 12:20:00	\N	\N	1	0	\N	\N
481434	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule tourisme	\N	2020-05-26 17:00:00	2020-05-26 17:50:00	\N	\N	4	0	\N	\N
481439	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions cellule tourisme	\N	2020-06-03 14:00:00	2020-06-03 15:30:00	\N	\N	2	0	\N	\N
481442	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Ademe	\N	2020-06-24 14:00:00	2020-06-24 14:45:00	\N	\N	4	0	\N	\N
382735	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	« Conséquences économiques des gilets jaunes »	« Conséquences économiques des gilets jaunes »	2019-05-22 14:00:00	2019-05-22 16:00:00	\N	\N	5	0	\N	\N
382741	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	« Conséquences économiques des gilets jaunes »	« Conséquences économiques des gilets jaunes »	2019-05-22 16:00:00	2019-05-22 17:45:00	\N	\N	4	0	\N	\N
385613	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-06-05 09:30:00	2019-06-05 10:10:00	2019-06-05 12:16:53	2019-06-05 12:22:47	29	0	\N	\N
385940	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Audition plénière - Application de la loi de financement de la sécurité sociale pour 2018	\N	2019-06-12 09:30:00	2019-06-12 13:00:00	\N	\N	0	0	\N	\N
385946	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Réunion plénière	\N	2019-06-12 09:30:00	2019-06-12 12:30:00	\N	\N	0	0	\N	\N
385960	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Energie - Auditions M. Gremillet	\N	2019-06-04 18:00:00	2019-06-04 20:15:00	\N	\N	3	0	\N	\N
385964	MISSION	AUCUNE	\N	SIDERURGIE	\N	Plénière - Table ronde sur les politiques publiques	\N	2019-06-04 14:00:00	2019-06-04 16:10:00	2019-06-05 15:56:56	2019-06-05 16:33:21	10	0	\N	\N
386076	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions MI responsabilité civile	\N	2019-06-04 14:30:00	2019-06-04 17:00:00	\N	\N	2	0	\N	\N
386221	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-06-11 19:30:00	2019-06-11 19:40:00	2019-06-11 20:24:16	2019-06-12 16:55:36	24	1	\N	\N
387195	ETUDES	AUCUNE	\N	\N	\N	G.E. "Elevage"	G.E. "Elevage"	2019-06-06 13:45:00	2019-06-06 15:00:00	\N	\N	2	0	\N	911
387793	SEANCE_PLENIERE	EXAMEN	1122	\N	\N	PJL Santé - seconde délibération	PJL Santé - seconde délibération	2019-06-11 15:00:00	2019-06-11 16:55:00	\N	\N	309	0	\N	\N
387794	SEANCE_PLENIERE	SCRUSOL	1122	\N	\N	Scrutin solennel	Scrutin solennel	2019-06-11 19:00:00	2019-06-11 19:30:00	\N	\N	0	0	\N	\N
393790	MISSION	AUDRAP	\N	AERIEN	\N	\N	\N	2019-06-18 09:30:00	2019-06-18 11:00:00	\N	\N	5	0	\N	\N
393796	MISSION	AUDRAP	\N	AERIEN	\N	\N	\N	2019-06-18 14:30:00	2019-06-18 15:20:00	\N	\N	7	0	\N	\N
393804	MISSION	AUDRAP	\N	AERIEN	\N	\N	\N	2019-06-20 14:10:00	2019-06-20 14:50:00	\N	\N	4	0	\N	\N
393809	MISSION	AUDRAP	\N	AERIEN	\N	\N	\N	2019-06-20 16:30:00	2019-06-20 17:10:00	\N	\N	2	0	\N	\N
399761	COM_PERMANENTE	AUTRE	\N	SOCI	\N	loi de financement de la sécurité sociale pour 2018	\N	2019-07-10 10:55:00	2019-07-10 11:35:00	2019-07-10 15:18:05	2019-07-11 11:26:36	33	0	\N	\N
400154	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL aérodrome Polynésie	PPL aérodrome Polynésie	2019-07-23 14:30:00	2019-07-23 15:35:00	\N	\N	92	0	\N	\N
400155	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Conclusions CMP Transformation fonction publique	Conclusions CMP Transformation fonction publique	2019-07-23 15:00:00	2019-07-23 16:45:00	\N	\N	0	0	\N	\N
400170	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Conclusions CMP Collectivité européenne d'Alsace	Conclusions CMP Collectivité européenne d'Alsace	2019-07-23 15:40:00	2019-07-23 16:35:00	\N	\N	127	0	\N	\N
400173	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Conclusions CMP Réglement budget	Conclusions CMP Réglement budget	2019-07-23 19:25:00	2019-07-23 20:20:00	\N	\N	47	0	\N	\N
400175	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Conclusions CMP PPL Réseaux radioélectriques	Conclusions CMP PPL Réseaux radioélectriques	2019-07-24 14:30:00	2019-07-24 15:25:00	\N	\N	51	0	\N	\N
385893	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPR clarifier le règlement du Sénat LEC	\N	2019-06-05 10:30:00	2019-06-05 11:45:00	2019-06-05 16:48:58	2019-06-05 16:52:14	51	0	\N	\N
385894	COM_PERMANENTE	AUTRE	\N	LOIS	\N	\N	\N	2019-06-05 12:08:00	2019-06-05 12:45:00	2019-06-05 16:45:26	2019-06-05 16:52:15	29	0	\N	\N
400177	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Conclusions CMP PJL JO 2024	Conclusions CMP PJL JO 2024	2019-07-24 15:30:00	2019-07-24 16:40:00	\N	\N	61	0	\N	\N
400181	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Deuxième lecture PPL Communes nouvelles	Deuxième lecture PPL Communes nouvelles	2019-07-24 16:50:00	2019-07-24 18:10:00	\N	\N	44	0	\N	\N
416305	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS pour 2020	PLFSS pour 2020	2019-11-12 16:00:00	2019-11-12 19:30:00	\N	\N	164	0	\N	\N
416306	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS pour 2020	PLFSS pour 2020	2019-11-12 22:15:00	2019-11-13 00:35:00	\N	\N	76	0	\N	\N
416307	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2019-11-13 15:00:00	2019-11-13 16:15:00	\N	\N	307	0	\N	\N
416308	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS pour 2020	PLFSS pour 2020	2019-11-13 21:30:00	2019-11-14 00:40:00	\N	\N	94	0	\N	\N
416322	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS pour 2020	PLFSS pour 2020	2019-11-13 16:35:00	2019-11-13 20:00:00	\N	\N	136	0	\N	\N
416329	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS pour 2020	PLFSS pour 2020	2019-11-14 10:30:00	2019-11-14 12:45:00	\N	\N	103	0	\N	\N
416333	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS pour 2020	PLFSS pour 2020	2019-11-14 14:30:00	2019-11-14 20:00:00	\N	\N	105	0	\N	\N
416945	ETUDES	AUCUNE	\N	\N	\N	Audition Safer viticoles	Rencontre avec le réseau national des Safer viticoles	2019-10-17 13:30:00	2019-10-17 15:15:00	\N	\N	8	0	\N	909
417481	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	1241	\N	\N	Explications de vote sur l'ensemble	Explications de vote sur l'ensemble	2019-10-22 14:35:00	2019-10-22 15:39:00	\N	\N	296	0	\N	\N
418302	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Sport	PLF 2020 - Crédits Sport	2019-10-22 15:00:00	2019-10-22 16:00:00	\N	\N	2	0	\N	\N
418303	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Sport	PLF 2020 - Crédits Sport	2019-10-22 16:00:00	2019-10-22 17:00:00	\N	\N	3	0	\N	\N
420064	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2020 - Asile, immigration, intégration et nationalité	\N	2019-10-23 16:30:00	2019-10-23 18:50:00	\N	\N	2	0	\N	\N
420607	GIA	AUCUNE	\N	\N	\N	Déjeuner avec M.SOLOCH	Déjeuner avec M.SOLOCH, Secrétaire d'Etat polonais	2019-10-24 12:30:00	2019-10-24 14:30:00	\N	\N	6	0	600	\N
420629	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2020 - Programme 185	\N	2019-10-22 18:40:00	2019-10-22 19:30:00	\N	\N	2	0	\N	\N
420632	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2020 - Programme 185	\N	2019-10-23 16:30:00	2019-10-23 18:00:00	\N	\N	2	0	\N	\N
420635	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2020 - Programme 212	\N	2019-10-24 09:30:00	2019-10-24 10:30:00	\N	\N	2	0	\N	\N
420638	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Auditions M. Gremillet - Avis énergie	PJLF 2020 - Auditions M. Gremillet - Avis énergie	2019-10-22 10:00:00	2019-10-22 11:00:00	\N	\N	1	0	\N	\N
420640	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Auditions M. Gremillet - Avis énergie	PJLF 2020 - Auditions M. Gremillet - Avis énergie	2019-10-22 16:45:00	2019-10-22 19:00:00	\N	\N	1	0	\N	\N
420642	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Auditions M. Gremillet - Avis énergie	PJLF 2020 - Auditions M. Gremillet - Avis énergie	2019-10-23 14:00:00	2019-10-23 15:00:00	\N	\N	1	0	\N	\N
420644	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Auditions M. Gremillet - Avis énergie	PJLF 2020 - Auditions M. Gremillet - Avis énergie	2019-10-23 16:30:00	2019-10-23 18:15:00	\N	\N	1	0	\N	\N
420646	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2019-10-30 08:35:00	2019-10-30 11:10:00	2019-10-30 12:42:01	2019-10-30 14:57:27	36	1	\N	\N
420648	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Cnam, GIE SESAM-Vitale	\N	2019-10-29 08:30:00	2019-10-29 10:30:00	\N	\N	2	0	\N	\N
420649	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Carte Vitale biométrique	\N	2019-10-29 15:00:00	2019-10-29 16:00:00	\N	\N	1	0	\N	\N
456327	COM_SPECIALE	AUDRAP	\N	ASAP	\N	Auditions CS ASAP	\N	2020-02-20 08:00:00	2020-02-20 09:00:00	\N	\N	13	0	\N	\N
456355	COM_SPECIALE	AUDRAP	\N	ASAP	\N	Auditions CS ASAP	\N	2020-02-20 10:00:00	2020-02-20 10:30:00	\N	\N	7	0	\N	\N
456367	COM_SPECIALE	AUDRAP	\N	ASAP	\N	Auditions CS ASAP	\N	2020-02-20 09:00:00	2020-02-20 09:30:00	\N	\N	12	0	\N	\N
456391	COM_SPECIALE	AUDRAP	\N	ASAP	\N	Auditions CS ASAP	\N	2020-02-20 09:30:00	2020-02-20 10:00:00	\N	\N	8	0	\N	\N
460103	COM_ENQUETE	PLENIERE	\N	RADICALI	\N	Audition de Michel Aubouin, ancien préfet	Audition de Michel Aubouin, ancien préfet	2020-03-03 16:55:00	2020-03-03 18:10:00	2020-03-03 19:50:43	2020-03-05 15:38:32	9	0	\N	\N
460332	COM_ENQUETE	PLENIERE	\N	RADICALI	\N	Audition de François Héran, professeur au Collège de France	Audition de François Héran, professeur au Collège de France	2020-03-03 18:10:00	2020-03-03 19:25:00	2020-03-03 19:50:31	2020-03-05 15:38:32	9	0	\N	\N
474644	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule logement - Fondation abbé Pierre	\N	2020-04-24 10:00:00	2020-04-24 11:00:00	\N	\N	0	0	\N	\N
474649	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule logement - Table ronde d'élus locaux	\N	2020-04-24 11:00:00	2020-04-24 13:00:00	\N	\N	0	0	\N	\N
474654	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule agriculture Fleury Michon	\N	2020-05-26 09:00:00	2020-05-26 10:15:00	\N	\N	8	0	\N	\N
474655	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions cellule agriculture Groupe Bigard	Auditions cellule agriculture	2020-05-27 08:30:00	2020-05-27 10:15:00	\N	\N	11	0	\N	\N
474657	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule agriculture Soufflet	Auditions cellule agriculture	2020-05-29 09:00:00	2020-05-29 10:30:00	\N	\N	8	0	\N	\N
474692	MISSION	AUCUNE	\N	FEDERATION	\N	Réunion constitutive	Réunion constitutive	2020-06-02 15:00:00	2020-06-02 15:45:00	\N	2020-06-02 18:33:36	15	0	\N	\N
474785	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Alimentation durable-Agence nationale de la cohésion des territoires (ANCT)	Covid-19-Alimentation durable-Agence nationale de la cohésion des territoires (ANCT)	2020-06-02 16:00:00	2020-06-02 17:15:00	\N	\N	8	0	\N	\N
474787	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Alimentation durable et locale-Association des maires de France	Covid-19-Alimentation durable et locale-Association des maires de France	2020-05-28 15:00:00	2020-05-28 16:00:00	\N	\N	8	0	\N	\N
420647	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2019-10-30 11:10:00	2019-10-30 11:40:00	2019-10-30 12:43:21	2019-10-30 14:57:23	37	1	\N	\N
476059	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - B. Deflesselles - C. Janvier, députés	Audition Pollution plastique - B. Deflesselles - C. Janvier, députés	2020-06-19 09:45:00	2020-06-19 10:45:00	\N	\N	2	0	\N	\N
476088	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Protéger les victimes de violences conjugales	\N	2020-06-04 09:00:00	2020-06-04 10:00:00	\N	\N	1	0	\N	\N
476105	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule logement - Fondation abbé Pierre	\N	2020-04-24 10:00:00	2020-04-24 11:00:00	\N	\N	2	0	\N	\N
476108	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule logement - Table ronde d'élus locaux	\N	2020-04-24 11:00:00	2020-04-24 13:00:00	\N	\N	2	0	\N	\N
476115	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule logement - Table ronde associations hébergement Alpes-Maritimes	\N	2020-04-24 16:00:00	2020-04-24 17:30:00	\N	\N	3	0	\N	\N
476122	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule logement - Habitat et humanisme	\N	2020-05-04 17:30:00	2020-05-04 18:30:00	\N	\N	2	0	\N	\N
476247	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule industrie - CNPA	\N	2020-06-04 14:00:00	2020-06-04 14:45:00	\N	\N	4	0	\N	\N
476252	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule industrie - Régions de France	\N	2020-06-05 16:00:00	2020-06-05 17:20:00	\N	\N	4	0	\N	\N
476258	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - ONERA - DGAC/CNES/GIFAS	Contrôle 2020 - ONERA - DGAC/CNES/GIFAS	2020-06-05 09:00:00	2020-06-05 12:00:00	\N	\N	1	0	\N	\N
476260	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - ONERA - MDBA/Armée de l'Air	Contrôle 2020 - ONERA - MDBA/Armée de l'Air	2020-06-05 14:00:00	2020-06-05 16:00:00	\N	\N	1	0	\N	\N
476262	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT 2020 Le Grand Paris Express - M. Gilles CARREZ	GT 2020 Le Grand Paris Express - M. Gilles CARREZ, auteur rapport sur les ressources de la Société du Grand Paris	2020-06-08 14:05:00	2020-06-08 15:05:00	\N	\N	10	0	\N	\N
476273	MISSION	AUDRAP	\N	GUYANE	\N	Auditions des collectivités territoriales, du CESECE et du GCC	\N	2020-06-08 14:30:00	2020-06-08 17:00:00	\N	\N	12	0	\N	\N
476324	COM_ENQUETE	PLENIERE	\N	SOLS	\N	Réunion plénière CE	\N	2020-06-02 16:36:00	2020-06-02 18:15:00	2020-06-08 15:23:37	2020-06-08 15:48:51	6	0	\N	\N
476349	COM_ENQUETE	PLENIERE	\N	SOLS	\N	Réunion plénière CE	\N	2020-06-03 16:36:00	2020-06-03 18:12:00	2020-06-08 16:20:45	2020-06-08 16:34:20	6	0	\N	\N
476351	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL 2nd tour municipales (rapport) - PPL Violence conjugales (amendements)	PJL 2nd tour municipales (rapport) - PPL Violence conjugales (amendements)	2020-06-09 09:05:00	2020-06-09 10:55:00	2020-06-09 11:16:40	2020-06-11 09:01:17	21	0	\N	\N
476356	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL 2nd tour municipales (nomination CMP) - PJLO Report sénatoriales (rapport)	PJL 2nd tour municipales (nomination CMP) - PJLO Report sénatoriales (rapport)	2020-06-10 09:50:00	2020-06-10 13:15:00	2020-06-10 13:27:54	2020-06-11 09:01:15	35	0	\N	\N
476357	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Second tour des municipales (amendements de séance)	PJL Second tour des municipales (amendements de séance)	2020-06-10 13:50:00	2020-06-10 14:20:00	2020-06-10 15:14:21	2020-06-11 09:01:13	8	0	\N	\N
476429	DELEGATION	AUDRAP	\N	\N	206	Audition de Pascal TROMPETTE, sociologue	Audition de Pascal TROMPETTE, sociologue	2020-06-22 09:00:00	2020-06-22 10:00:00	\N	\N	1	0	\N	\N
476430	DELEGATION	AUDRAP	\N	\N	206	Audition de  Gaelle CLAVANDIER, sociologue	Audition de  Gaelle CLAVANDIER, sociologue	2020-06-22 10:00:00	2020-06-22 11:00:00	\N	\N	1	0	\N	\N
476431	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Mohammed MOUSSAOUI, président du CFCM	Audition de M. Mohammed MOUSSAOUI, président du CFCM	2020-06-22 11:30:00	2020-06-22 12:30:00	\N	\N	2	0	\N	\N
476432	DELEGATION	AUDRAP	\N	\N	206	Audition de Damien LE GUAY, philosophe 	Damien LE GUAY, philosophe et président du Comité national d¿éthique du funéraire 	2020-06-15 09:00:00	2020-06-15 10:00:00	\N	\N	2	0	\N	\N
476433	DELEGATION	AUDRAP	\N	\N	206	Audition de Mgr Matthieu ROUGE, évêque de Nanterre	Audition de Mgr Matthieu ROUGE, évêque de Nanterre	2020-06-15 10:00:00	2020-06-15 11:00:00	\N	\N	2	0	\N	\N
476434	DELEGATION	AUDRAP	\N	\N	206	Audition de Jean-François MAYER	Audition de Jean-François MAYER, historien des religions et rédacteur en chef de Religioscope	2020-06-15 11:00:00	2020-06-15 12:00:00	\N	\N	2	0	\N	\N
476435	DELEGATION	AUDRAP	\N	\N	206	Audition de Catherine KINTZLER, philosophe et essayiste	Audition de Catherine KINTZLER, philosophe et essayiste	2020-06-15 12:00:00	2020-06-15 13:00:00	\N	\N	2	0	\N	\N
476436	DELEGATION	AUDRAP	\N	\N	206	Audition de Tanguy CHATEL, sociologue du deuil	Audition de Tanguy CHATEL, sociologue du deuil, cofondateur du cercle « Cercle vulnérabilités et société »	2020-06-08 09:00:00	2020-06-08 10:00:00	\N	\N	4	0	\N	\N
476437	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteur de Frère Eric SALOBIR, prêtre dominicain	Audition de Frère Eric SALOBIR, prêtre dominicain et président du think tank Optic Technology	2020-06-08 10:00:00	2020-06-08 11:00:00	\N	\N	3	0	\N	\N
476438	DELEGATION	AUDRAP	\N	\N	206	Audition de Nicolas BALZAMO, historien des religions	Audition de Nicolas BALZAMO, historien des religions	2020-06-08 11:00:00	2020-06-08 12:00:00	\N	\N	2	0	\N	\N
476439	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Protéger les victimes de violences conjugales	\N	2020-06-08 13:30:00	2020-06-08 14:30:00	\N	\N	1	0	\N	\N
476467	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPRE n° 273 CFP UE (2021-2027) - DB	PPRE n° 273 CFP UE (2021-2027) - Direction du Budget	2020-06-04 16:00:00	2020-06-04 17:30:00	\N	\N	1	0	\N	\N
373766	ETUDES	AUCUNE	\N	\N	\N	Audition commune "Concilier maladie et travail"	\N	2019-06-06 08:30:00	2019-06-06 10:30:00	\N	\N	1	0	\N	1004
384618	MISSION	AUDRAP	\N	INFRACTIONS	\N	\N	MCI répression infractions sexuelles sur mineurs (Mme Anne-Claude Ambroise Rendu)	2019-05-23 10:00:00	2019-05-23 11:00:00	\N	\N	5	0	\N	\N
384625	MISSION	AUDRAP	\N	INFRACTIONS	\N	\N	MCI répression infractions sexuelles sur mineurs (M. Frédéric Martel)	2019-05-23 11:00:00	2019-05-23 12:00:00	\N	\N	6	0	\N	\N
396628	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Déplacement à Istres	Déplacement sur la base aérienne d'Istres	2019-07-04 07:00:00	2019-07-04 15:00:00	\N	\N	14	0	\N	\N
402892	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	MI Sécurité Sapeurs-pompiers	\N	2019-07-17 14:00:00	2019-07-17 16:00:00	\N	\N	3	0	\N	\N
402896	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	MI Sécurité Sapeurs-pompiers	\N	2019-07-18 14:00:00	2019-07-18 17:00:00	\N	\N	3	0	\N	\N
402902	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Économie circulaire - Auditions Mme de CIDRAC	\N	2019-07-17 14:30:00	2019-07-17 15:00:00	\N	\N	2	0	\N	\N
402909	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Économie circulaire - Auditions Mme de CIDRAC	\N	2019-07-18 10:30:00	2019-07-18 12:15:00	\N	\N	2	0	\N	\N
402913	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Économie circulaire - Auditions Mme de CIDRAC	\N	2019-07-18 18:00:00	2019-07-18 18:30:00	\N	\N	1	0	\N	\N
402916	ETUDES	AUCUNE	\N	\N	\N	Audition Mme Brune Poirson	Audition Mme Brune Poirson	2019-07-18 16:00:00	2019-07-18 16:50:00	\N	\N	6	0	\N	922
402945	COM_ENQUETE	PLENIERE	\N	SOUVERAINETE	\N	C.E. "Souveraineté numérique"	C.E. "Souveraineté numérique"	2019-07-17 16:00:00	2019-07-17 19:10:00	2019-07-19 15:24:46	2019-07-19 16:01:16	7	0	\N	\N
402953	COM_ENQUETE	PLENIERE	\N	SOUVERAINETE	\N	C.E. "Souveraineté numérique"	C.E. "Souveraineté numérique"	2019-07-18 09:50:00	2019-07-18 12:50:00	2019-07-19 15:27:32	2019-07-19 16:01:15	8	0	\N	\N
413273	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Assurance maladie	\N	2019-10-09 18:45:00	2019-10-09 19:45:00	\N	\N	2	0	\N	\N
413300	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL AVIA	\N	2019-10-10 09:00:00	2019-10-10 10:00:00	\N	\N	0	0	\N	\N
413301	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Engagement et proximité - Suite de l'examen des motions et amendements de séance	PJL Engagement et proximité - Suite de l'examen des motions et amendements de séance	2019-10-10 00:10:00	2019-10-10 00:20:00	2019-10-10 10:23:08	2019-10-10 14:55:50	17	0	\N	\N
413405	COM_PERMANENTE	AUTRE	\N	FINC	\N	Auditions sur le rapport relatif au Green Budgeting : proposition méthode budgét. envir.	Auditions sur le rapport relatif au Green Budgeting : proposition de méthode pour une budgétisation environnementale	2019-10-15 15:05:00	2019-10-15 16:50:00	2019-10-15 18:41:19	2019-10-16 17:30:42	18	0	\N	\N
413425	COM_PERMANENTE	AUTRE	\N	FINC	\N	Contrôle budgét. suites données rapports modernis. navigation aérienne et compétitivité	Contrôle budgétaire suites données rapports modernisation navigation aérienne et compétitivité du transport aérien	2019-10-16 10:35:00	2019-10-16 11:30:00	2019-10-16 14:56:25	2019-10-16 17:31:07	36	1	\N	\N
413464	COM_PERMANENTE	AUTRE	\N	FINC	\N	Fiscalité environnementale : audition de M. Didier MIGAUD, président du CPO	Fiscalité environnementale : audition de M. Didier MIGAUD, président du CPO	2019-10-16 17:00:00	2019-10-16 18:25:00	2019-10-16 19:06:29	2019-10-17 15:56:24	19	0	\N	\N
413506	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2019-10-16 09:00:00	2019-10-16 11:15:00	2019-10-16 11:22:02	2019-10-16 17:30:45	38	0	\N	\N
413507	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PLFSS pour 2020 - Audition de Mme Buzyn et M. Dussopt	\N	2019-10-15 21:05:00	2019-10-15 23:30:00	2019-10-16 17:31:50	2019-10-16 17:45:52	33	0	\N	\N
413531	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Assurance maladie	\N	2019-10-10 10:30:00	2019-10-10 11:30:00	\N	\N	3	0	\N	\N
413532	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Assurance maladie	\N	2019-10-10 11:30:00	2019-10-10 12:30:00	\N	\N	3	0	\N	\N
413613	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	\N	\N	2019-10-09 11:00:00	2019-10-09 11:45:00	\N	\N	0	0	\N	\N
416863	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation parlementaire Slovène	Accueil d'une délégation parlementaire Slovène	2019-10-02 10:00:00	2019-10-02 15:00:00	\N	\N	1	0	529	\N
416879	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation parlementaire Slovène	Accueil d'une délégation parlementaire Slovène	2019-10-02 11:30:00	2019-10-02 13:00:00	\N	\N	1	0	529	\N
416893	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation parlementaire Slovène	Accueil d'une délégation parlementaire Slovène	2019-10-02 13:00:00	2019-10-02 15:00:00	\N	\N	1	0	529	\N
416896	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation parlementaire slovène	Accueil d'une délégation parlementaire slovène	2019-10-02 19:30:00	2019-10-02 23:55:00	\N	\N	1	0	529	\N
416901	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation parlementaire Slovène	Accueil d'une délégation parlementaire Slovène	2019-10-02 16:00:00	2019-10-02 23:59:00	\N	\N	1	0	529	\N
416905	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation parlementaire Slovène	Accueil d'une délégation parlementaire Slovène	2019-10-03 08:30:00	2019-10-03 23:59:00	\N	\N	1	0	529	\N
422987	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Sites naturels - Auditions Jérôme Bignon	\N	2019-11-04 17:00:00	2019-11-04 18:00:00	\N	\N	1	0	\N	\N
422989	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Sites naturels - Auditions Jérôme Bignon	\N	2019-10-31 14:00:00	2019-10-31 18:00:00	\N	\N	2	0	\N	\N
422992	DELEGATION	AUCUNE	\N	\N	211	Audition du Professeur Jean-Marc Ayoubi	Audition du Professeur Jean-Marc Ayoubi	2019-11-14 08:45:00	2019-11-14 10:15:00	\N	\N	10	0	\N	\N
422993	DELEGATION	AUCUNE	\N	\N	DSOM	Audition de M. Jacques Toubon	\N	2019-11-21 09:05:00	2019-11-21 11:05:00	\N	\N	5	0	\N	\N
422994	DELEGATION	AUCUNE	\N	\N	DSOM	Examen du rapport d'information sur les risques naturels	\N	2019-11-14 09:00:00	2019-11-14 10:35:00	\N	\N	14	0	\N	\N
422995	DELEGATION	AUTRE	\N	\N	DSOM	Échanges avec des maires d'outre-mer	\N	2019-11-18 09:30:00	2019-11-18 12:00:00	\N	\N	19	0	\N	\N
423002	DELEGATION	AUDRAP	\N	\N	PROS	Audition de l'Inserm	\N	2019-11-12 15:30:00	2019-11-12 16:20:00	\N	\N	1	0	\N	\N
423003	DELEGATION	AUDRAP	\N	\N	PROS	Audition de l'ANSES	\N	2019-11-12 16:30:00	2019-11-12 17:45:00	\N	\N	2	0	\N	\N
423004	DELEGATION	AUDRAP	\N	\N	PROS	Audition de l'INRA	\N	2019-11-26 16:40:00	2019-11-26 17:40:00	\N	\N	1	0	\N	\N
423006	DELEGATION	AUCUNE	\N	\N	PROS	Examen du rapport sur robotisation et emplois de service	\N	2019-11-28 08:35:00	2019-11-28 09:40:00	\N	\N	13	0	\N	\N
423007	COM_SPECIALE	PLENIERE	\N	BIOETHIQUE	\N	Audition du CCNE	\N	2019-11-05 14:00:00	2019-11-05 15:50:00	2019-11-05 16:32:44	2019-11-05 16:52:09	25	0	\N	\N
423408	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Culture (Création, Transmission, Démocratisation)	PLF 2020 - Crédits Culture (Création, Transmission, Démocratisation)	2019-11-04 10:00:00	2019-11-04 11:20:00	\N	\N	1	0	\N	\N
423510	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-11-05 17:30:00	2019-11-05 19:30:00	2019-11-05 19:38:50	2019-11-06 14:36:24	28	0	\N	\N
423588	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Enseignement scolaire	PLF 2020 - Crédits Enseignement scolaire	2019-11-05 14:00:00	2019-11-05 14:45:00	\N	\N	1	0	\N	\N
423589	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Enseignement scolaire	PLF 2020 - Crédits Enseignement scolaire	2019-11-05 14:45:00	2019-11-05 15:30:00	\N	\N	3	0	\N	\N
423590	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Jeunesse et vie associative	PLF 2020 - Crédits Jeunesse et vie associative	2019-11-05 15:45:00	2019-11-05 17:30:00	\N	\N	1	0	\N	\N
428159	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Pastoralisme	GT Pastoralisme	2019-11-14 13:30:00	2019-11-14 15:00:00	\N	\N	6	0	\N	\N
441273	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Créer un droit à l'erreur des collectivités locales	PPL Droit à l'erreur collectivités locales	2019-12-18 10:30:00	2019-12-18 11:45:00	\N	\N	1	0	\N	\N
441865	COM_ENQUETE	AUDRAP	\N	RADICALI	\N	Naëm Bestandji - Mehdi Aifa (Amicale des Jeunes du Refuge)	Naëm Bestandji - Mehdi Aifa (Amicale des Jeunes du Refuge)	2020-01-07 15:40:00	2020-01-07 17:35:00	\N	\N	3	0	\N	\N
442208	DELEGATION	AUDRAP	\N	\N	PROS	Audition de la CGAAER	\N	2020-01-14 15:40:00	2020-01-14 16:50:00	\N	\N	2	0	\N	\N
442327	DELEGATION	AUCUNE	\N	\N	PROS	Audition de M. David Caubel, directeur et coordinateur France Mobilités	Audition de M. David Caubel, directeur et coordinateur France Mobilités	2020-01-23 08:30:00	2020-01-23 09:50:00	\N	\N	12	0	\N	\N
442331	DELEGATION	AUDRAP	\N	\N	PROS	Audition de l'Union des Industries de Protection des Plantes	\N	2020-01-21 15:30:00	2020-01-21 16:30:00	\N	\N	1	0	\N	\N
447043	ETUDES	AUCUNE	\N	\N	\N	Audition de représentants de la Commission de régulation de l'énergie	\N	2020-01-22 08:00:00	2020-01-22 09:30:00	\N	\N	17	0	\N	906
448844	DELEGATION	AUDRAP	\N	\N	206	Audition Production de l'énergie dans le secteur agricole	Audition Production de l'énergie dans le secteur agricole - Ministère transition écologique et solidaire	2020-01-28 10:00:00	2020-01-28 12:30:00	\N	\N	1	0	\N	\N
458796	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PPL Congé de deuil pour le décès d'un enfant - Examen des amendements de séance	\N	2020-03-03 13:30:00	2020-03-03 13:40:00	2020-03-03 15:40:42	2020-03-03 17:21:58	22	1	\N	\N
458797	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Auditions - Prise en charge insuffisance rénale chronique et système universel retraites	\N	2020-03-04 09:05:00	2020-03-04 12:30:00	2020-03-04 15:45:06	2020-03-04 16:20:04	31	0	\N	\N
458798	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de M. Sébastien Leloup candidat à la direction générale de l'ONIAM	\N	2020-03-04 16:40:00	2020-03-04 17:40:00	2020-03-06 11:04:07	2020-03-06 11:25:00	9	0	\N	\N
458887	COM_ENQUETE	AUTRE	\N	SOLS	\N	Réunion CE Pollution des sols	\N	2020-03-04 17:47:00	2020-03-04 19:04:00	\N	\N	6	0	\N	\N
458888	COM_ENQUETE	PLENIERE	\N	SOLS	\N	Réunion CE Pollution des sols	\N	2020-03-03 15:48:00	2020-03-03 18:00:00	2020-03-04 13:36:01	2020-03-05 15:36:06	9	0	\N	\N
461745	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition entreprises responsables et engagées	Audition entreprises responsables et engagées - TK Blue	2020-02-25 16:05:00	2020-02-25 17:05:00	\N	\N	2	0	\N	\N
461748	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition entreprises responsables et engagées 	Audition entreprises responsables et engagées  - AG2R	2020-02-25 17:05:00	2020-02-25 18:05:00	\N	\N	2	0	\N	\N
461751	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition entreprises responsables et engagées 	Audition entreprises responsables et engagées  - BPIFrance	2020-02-26 16:35:00	2020-02-26 17:35:00	\N	\N	1	0	\N	\N
461753	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition entreprises responsables et engagées 	Audition entreprises responsables et engagées - Union des employeurs de l'économie sociale et solidaire	2020-02-26 17:35:00	2020-02-26 18:15:00	\N	\N	1	0	\N	\N
461757	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition entreprises responsables et engagées	Audition entreprises responsables et engagées - AFNOR	2020-02-26 18:15:00	2020-02-26 18:50:00	\N	\N	1	0	\N	\N
461759	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition entreprises responsables et engagées	Audition entreprises responsables et engagées - RHSF et Groupe MUL	2020-02-27 16:05:00	2020-02-27 17:10:00	\N	\N	1	0	\N	\N
461761	DELEGATION	DEPLACEMENT	\N	\N	ENTREPRISES	Déplacement à Station F	Déplacement à Station F	2020-02-27 10:00:00	2020-02-27 12:15:00	\N	\N	6	0	\N	\N
461770	DELEGATION	DEPLACEMENT	\N	\N	ENTREPRISES	Déplacement CUISINE MODE D¿EMPLOI(S) 	Déplacement CUISINE MODE D¿EMPLOI(S) ¿ LA FORMATION AUX MÉTIERS DE LA RESTAURATION AVEC THIERRY MARX	2020-02-27 12:45:00	2020-02-27 15:30:00	\N	\N	6	0	\N	\N
461777	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition difficultés de recrutement et évolution des métiers	Audition difficultés de recrutement et évolution des métiers - Haut-commissariat aux compétences et à l'inclusion	2020-02-28 09:00:00	2020-02-28 10:00:00	\N	\N	1	0	\N	\N
461790	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition difficultés de recrutement et évolution des métiers	Audition difficultés de recrutement et évolution des métiers- DGESCO	2020-02-28 10:00:00	2020-02-28 11:20:00	\N	\N	1	0	\N	\N
461792	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition difficultés de recrutement et évolution des métiers	Audition difficultés de recrutement et évolution des métiers - régions de France	2020-02-28 11:20:00	2020-02-28 12:30:00	\N	\N	1	0	\N	\N
461794	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Table ronde1 sur : « Les PME et la RSE »	Dans le cadre de la mission sur le thème : « Comment encourager l'entreprise responsable et engagée ? », table ronde1 su	2020-03-03 16:30:00	2020-03-03 18:40:00	2020-03-04 17:50:41	\N	9	0	\N	\N
461839	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière	Réunion plénière	2020-03-04 12:40:00	2020-03-04 14:25:00	2020-03-04 17:56:31	\N	13	0	\N	\N
465367	DELEGATION	AUDRAP	\N	\N	206	Audition de représentants de l'Université de Perpignan - CEFREM	\N	2020-04-17 15:00:00	2020-04-17 18:00:00	\N	\N	2	0	\N	\N
479033	MISSION	AUCUNE	\N	ILLECTRONISM	\N	Table ronde consacrée à l'Université	Table ronde consacrée à l'Université	2020-06-22 15:00:00	2020-06-22 16:25:00	2020-06-22 16:27:44	2020-06-22 18:59:17	8	0	\N	\N
479034	MISSION	AUCUNE	\N	ILLECTRONISM	\N	Audition de M.Philippe Wahl, PDG de la Poste	Audition de M.Philippe Wahl, PDG de la Poste	2020-06-23 15:00:00	2020-06-23 16:15:00	2020-06-23 17:45:51	2020-06-24 11:41:42	7	0	\N	\N
479035	MISSION	AUDRAP	\N	ILLECTRONISM	\N	Audition de la Fédération de la formation professionnelle	Audition de la Fédération de la formation professionnelle	2020-06-24 16:30:00	2020-06-24 17:25:00	\N	\N	5	0	\N	\N
479036	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Cellule tourisme - commission européenne	Cellule tourisme - commission européenne	2020-06-18 10:00:00	2020-06-18 11:15:00	\N	\N	4	0	\N	\N
479041	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFR pour 2020 (3) - Rapport Général - AFEP	PLFR pour 2020 (3) - Rapport Général - AFEP	2020-06-16 10:00:00	2020-06-16 10:30:00	\N	\N	1	0	\N	\N
479053	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de l'Unédic	\N	2020-06-25 14:00:00	2020-06-25 15:00:00	2020-06-25 15:40:59	2020-06-25 15:57:36	17	0	\N	\N
479055	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de la CADES et de l'Agence France-Trésor	\N	2020-06-23 15:30:00	2020-06-23 16:55:00	2020-06-23 17:29:13	2020-06-24 11:56:40	28	1	\N	\N
479058	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de M. Olivier Véran	\N	2020-06-23 18:10:00	2020-06-23 19:25:00	2020-06-24 15:28:20	2020-06-24 15:41:34	31	0	\N	\N
479072	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2020-06-24 09:35:00	2020-06-24 12:35:00	2020-06-24 17:03:30	2020-06-24 17:40:45	39	2	\N	\N
479082	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 25 juin -8h30 de la commission des affaires européennes	Réunion du 25 juin -8h30 de la commission des affaires européennes	2020-06-25 08:35:00	2020-06-25 10:00:00	2020-06-26 16:13:53	2020-06-26 17:58:09	13	0	\N	\N
479093	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur PPL Revalorisation des pensions de retraite agricoles	\N	2020-06-18 09:35:00	2020-06-18 10:05:00	\N	\N	4	0	\N	\N
479125	COM_EURO	AUDRAP	\N	AFEU	\N	Lutte contre la cybercriminalité	Lutte contre la cybercriminalité - Enisa	2020-06-18 14:00:00	2020-06-18 15:00:00	\N	\N	2	0	\N	\N
481447	COM_PERMANENTE	AUDRAP	\N	CAE	\N	ANCV	\N	2020-06-24 18:15:00	2020-06-24 19:00:00	\N	\N	3	0	\N	\N
481452	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Orange	\N	2020-06-17 14:30:00	2020-06-17 15:15:00	\N	\N	1	0	\N	\N
481454	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition application PPL 5G	\N	2020-06-18 11:15:00	2020-06-18 12:45:00	\N	\N	1	0	\N	\N
481456	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions suivi application PPL 5G	\N	2020-06-18 14:30:00	2020-06-18 16:45:00	\N	\N	1	0	\N	\N
481458	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions suivi application PPL 5G	\N	2020-06-19 10:45:00	2020-06-19 12:15:00	\N	\N	1	0	\N	\N
481460	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Nokia	\N	2020-06-24 13:00:00	2020-06-24 14:00:00	\N	\N	1	0	\N	\N
481462	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Bouygues	\N	2020-06-25 09:30:00	2020-06-25 11:00:00	\N	\N	1	0	\N	\N
481464	MISSION	AUCUNE	\N	FEDERATION	\N	Audition plénière	Réunion plénière - Audition Conseil d'État	2020-06-26 15:15:00	2020-06-26 16:20:00	2020-06-26 17:43:15	2020-06-26 18:12:31	9	0	\N	\N
382632	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 23 mai 2019	Réunion de la commission des affaires européennes du 23 mai 2019	2019-05-23 08:05:00	2019-05-23 09:05:00	2019-05-23 10:28:17	2019-05-23 17:08:33	4	0	\N	\N
382859	DELEGATION	AUCUNE	\N	\N	206	Présentation travaux des auditeurs promotion 2019 IHEST, examen conclusions Notre-Dame    	Présentation travaux des auditeurs de la promotion 2019 de l'IHEST, examen conclusions Notre-Dame, désign. rapporteurs	2019-06-06 09:05:00	2019-06-06 12:25:00	\N	\N	11	0	\N	\N
384149	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions responsabilité civile	MI responsabilité civile	2019-05-28 14:30:00	2019-05-28 16:45:00	\N	\N	2	0	\N	\N
384150	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions responsabilité civile	MI responsabilité civile	2019-05-28 17:45:00	2019-05-28 19:00:00	\N	\N	3	0	\N	\N
384447	DELEGATION	AUCUNE	\N	\N	DSOM	Audition Risques naturels majeurs et projet RESCCUE	Audition Risques naturels majeurs et projet RESCCUE	2019-06-25 14:35:00	2019-06-25 16:15:00	2019-06-25 17:17:14	\N	7	0	\N	\N
384448	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de Julien DENORMANDIE ministre de la ville et du logement sur le PJLR pour 2018	Audition de M. Julien DENORMANDIE ministre chargé de la ville et du logement sur le Projet de loi de règlement pour 2018	2019-06-05 16:40:00	2019-06-05 18:20:00	2019-06-06 10:01:28	2019-06-06 10:20:03	29	0	\N	\N
384596	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Suite examen amendements séance PJL Santé	\N	2019-06-03 13:30:00	2019-06-03 14:45:00	2019-06-03 16:52:07	2019-06-03 17:30:55	22	0	\N	\N
384597	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Suite examen amendements séance PJL Santé	\N	2019-06-03 19:40:00	2019-06-03 20:25:00	2019-06-03 20:28:50	2019-06-04 17:18:47	28	0	\N	\N
384598	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Suite examen amendements séance PJL Santé	\N	2019-06-04 13:35:00	2019-06-04 14:25:00	2019-06-04 14:26:06	2019-06-04 17:18:48	33	0	\N	\N
384602	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Rapport fraude documentaire	\N	2019-06-05 09:55:00	2019-06-05 11:05:00	2019-06-05 11:48:33	2019-06-05 11:49:09	41	0	\N	\N
384613	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Commission de vérification des fonds spéciaux - Rapport  2017	Commission de vérification des fonds spéciaux - Rapport  2017	2019-05-28 14:30:00	2019-05-28 15:15:00	\N	\N	3	0	\N	\N
384632	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Ressources humaines du ministère des armées - DRH de l'armée de terre	Contrôle 2019 - Ressources humaines du ministère des armées - DRH de l'armée de terre	2019-05-29 14:00:00	2019-05-29 15:30:00	\N	\N	1	0	\N	\N
384634	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Lutte contre les feux de forêt - Sabena 	Contrôle 2019 - Lutte contre les feux de forêt - Sabena 	2019-05-28 09:00:00	2019-05-28 10:15:00	\N	\N	1	0	\N	\N
384636	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Mission "Recherche et enseignement supérieur" - C-VaLo	PLF pour 2020 - Mission "Recherche et enseignement supérieur" - C-VaLo	2019-05-28 14:55:00	2019-05-28 16:05:00	\N	\N	1	0	\N	\N
384637	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL pour la restauration et la conservation de Notre-Dame de Paris	PJL pour la restauration et la conservation de Notre-Dame de Paris	2019-05-16 09:30:00	2019-05-16 10:30:00	\N	\N	10	0	\N	\N
384638	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL pour la restauration et la conservation de Notre-Dame de Paris	PJL pour la restauration et la conservation de Notre-Dame de Paris	2019-05-16 10:30:00	2019-05-16 11:30:00	\N	\N	6	0	\N	\N
392653	MISSION	AUCUNE	\N	FONDS	\N	Direction générale des Finances publiques	\N	2019-06-26 15:05:00	2019-06-26 16:15:00	2019-06-26 17:58:37	2019-06-26 18:39:12	7	0	\N	\N
404549	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution plastique	Audition rapporteurs Pollution plastique (table ronde Associations)	2019-09-11 14:30:00	2019-09-11 16:00:00	\N	\N	2	0	\N	\N
404553	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution plastique	Audition rapporteurs Pollution plastique (table ronde Associations)	2019-09-11 16:15:00	2019-09-11 17:45:00	\N	\N	2	0	\N	\N
409209	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Renforcer l'encadrement des rave-parties	\N	2019-10-01 14:00:00	2019-10-01 18:10:00	\N	\N	1	0	\N	\N
420652	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2020 - Mission Solidarité	\N	2019-10-23 17:30:00	2019-10-23 18:30:00	\N	\N	1	0	\N	\N
479088	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-06-24 09:00:00	2020-06-24 10:30:00	2020-06-24 11:35:05	2020-06-25 16:12:08	39	0	\N	\N
384600	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Suite PJL Santé 	\N	2019-06-05 09:35:00	2019-06-05 09:55:00	2019-06-05 11:01:50	2019-06-05 11:49:10	41	0	\N	\N
420655	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS Budget 2020 - Equilibres financiers généraux	\N	2019-10-23 16:30:00	2019-10-23 18:15:00	\N	\N	3	0	\N	\N
422673	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - APD - AFD	PLF pour 2020 - APD - AFD	2019-10-29 17:00:00	2019-10-29 18:00:00	\N	\N	2	0	\N	\N
422676	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2020 - Travail et emploi	\N	2019-10-30 13:30:00	2019-10-30 14:15:00	\N	\N	1	0	\N	\N
422678	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Affaires Européennes - DG Trésor	PLF pour 2020 - Affaires Européennes - DG Trésor	2019-10-30 11:30:00	2019-10-30 12:30:00	\N	\N	1	0	\N	\N
422680	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2018 - Réforme des retraites - DB	Contrôle 2018 - Réforme des retraites - DB	2019-10-29 15:00:00	2019-10-29 16:05:00	\N	\N	1	0	\N	\N
422682	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Travail et emploi - CHEOPS	PLF pour 2020 - Travail et emploi - CHEOPS	2019-10-29 18:00:00	2019-10-29 19:00:00	\N	\N	2	0	\N	\N
422685	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Culture - Direction générale des patrimoines	PLF pour 2020 - Culture - Direction générale des patrimoines	2019-10-30 14:00:00	2019-10-30 15:15:00	\N	\N	1	0	\N	\N
422687	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-10-31 10:35:00	2019-10-31 12:55:00	2019-10-31 13:12:57	2019-10-31 14:33:41	23	0	\N	\N
422688	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Sites naturels - Auditions Jérôme Bignon	\N	2019-10-29 14:30:00	2019-10-29 15:30:00	\N	\N	2	0	\N	\N
422689	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJLF 2020 -Auditions Biodiversité - M. Chevrollier	PJLF 2020 -Auditions Biodiversité - M. Chevrollier	2019-10-29 15:30:00	2019-10-29 17:30:00	\N	\N	1	0	\N	\N
422690	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Rapport général - AFEP	PLF pour 2020 - Rapport général - AFEP	2019-10-30 12:15:00	2019-10-30 13:00:00	\N	\N	1	0	\N	\N
422693	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Sport - AFLD	PLF pour 2020 - Sport - AFLD	2019-10-30 14:15:00	2019-10-30 15:00:00	\N	\N	1	0	\N	\N
422833	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2020 - Fonction publique - Centre national de la fonction publique territoriale	PLF pour 2020 - Fonction publique - Centre national de la fonction publique territoriale	2019-11-05 17:00:00	2019-11-05 17:45:00	\N	\N	1	0	\N	\N
422834	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2020 - Fonction publique - DGAFP	PLF pour 2020 - Fonction publique - DGAFP	2019-11-05 18:10:00	2019-11-05 20:15:00	\N	\N	1	0	\N	\N
422835	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2020 - Fonction publique - Fédération hospitalière de France	PLF pour 2020 - Fonction publique - Fédération hospitalière de France	2019-11-05 19:00:00	2019-11-05 19:45:00	\N	\N	1	0	\N	\N
422836	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2020 - Fonction publique - DGCL	PLF pour 2020 - Fonction publique - DGCL	2019-11-07 14:30:00	2019-11-07 15:45:00	\N	\N	1	0	\N	\N
422837	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2020 - Sécurités - UNSA-FASMI	PLF pour 2020 - Sécurités - UNSA-FASMI	2019-11-05 11:00:00	2019-11-05 11:45:00	\N	\N	1	0	\N	\N
422838	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2020 - Sécurités - SCSI-CFDT	PLF pour 2020 - Sécurités - SCSI-CFDT	2019-11-05 11:45:00	2019-11-05 12:30:00	\N	\N	1	0	\N	\N
422839	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2020 - Sécurités - Conseil de la fonction militaire de la gendarmerie	PLF pour 2020 - Sécurités - Conseil de la fonction militaire de la gendarmerie	2019-11-13 14:00:00	2019-11-13 15:00:00	\N	\N	1	0	\N	\N
477621	DELEGATION	AUCUNE	\N	\N	COLTER	Table ronde universitaires - Décentralisation	\N	2020-06-18 09:30:00	2020-06-18 11:00:00	2020-06-18 12:24:45	\N	12	0	\N	\N
477867	MISSION	AUDRAP	\N	FEDERATION	\N	Auditions MI FFS	Auditions MI FFS	2020-06-11 14:30:00	2020-06-11 15:55:00	\N	\N	10	0	\N	\N
477921	MISSION	AUDRAP	\N	GUYANE	\N	Auditions : SPIP - centres pénitentiaires- TJ Créteil - MRS et MLG	\N	2020-06-15 14:30:00	2020-06-15 18:00:00	\N	\N	8	0	\N	\N
477923	COM_ENQUETE	PLENIERE	\N	AUTOROUT	\N	Commission d'enquête Concessions autoroutières - Audition Autorité de la concurrence	Commission d'enquête Concessions autoroutières - Audition Autorité de la concurrence	2020-06-16 14:30:00	2020-06-16 15:30:00	2020-06-16 16:39:09	2020-06-16 18:14:38	10	0	\N	\N
477924	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - ONERA - DGA	Contrôle 2020 - ONERA - DGA	2020-06-08 16:00:00	2020-06-08 17:00:00	\N	\N	1	0	\N	\N
477933	MISSION	AUDRAP	\N	GUYANE	\N	audition du SMA	\N	2020-06-17 14:30:00	2020-06-17 15:30:00	\N	\N	4	0	\N	\N
477934	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Don de congés sous forme de chèques-vacances - Audition du Groupe Pasteur Mutualité	\N	2020-06-08 09:00:00	2020-06-08 10:00:00	\N	\N	1	0	\N	\N
477935	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Prévention de la perte d'autonomie - Audition de la HAS	\N	2020-06-10 09:00:00	2020-06-10 10:00:00	\N	\N	4	0	\N	\N
477936	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Prévention de la perte d'autonomie - Audition de la DGCS	\N	2020-06-12 09:00:00	2020-06-12 10:10:00	\N	\N	2	0	\N	\N
477937	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Prévention de la perte d'autonomie - Audition de la SFGG	\N	2020-06-12 10:30:00	2020-06-12 11:10:00	\N	\N	2	0	\N	\N
477949	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	M Prévention de la perte d'autonomie - Audition de la CNSA	\N	2020-06-09 16:00:00	2020-06-09 17:00:00	\N	\N	4	0	\N	\N
477967	DELEGATION	AUDRAP	\N	\N	DSOM	Réunion avec M. Clause Lise, président de l'assemblée de Martinique	\N	2020-06-13 17:00:00	2020-06-13 19:00:00	\N	\N	3	0	\N	\N
479069	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2020-06-24 09:35:00	2020-06-24 12:25:00	2020-06-30 15:35:06	2020-06-30 17:04:01	35	3	\N	\N
479070	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2020-06-25 10:35:00	2020-06-25 12:00:00	2020-06-26 15:43:38	2020-06-26 18:05:17	34	0	\N	\N
479227	MISSION	AUDRAP	\N	ILLECTRONISM	\N	Audition de M. Luc Gateau, président et de Mme Juliette Sançois - UNAPEI	\N	2020-06-22 10:05:00	2020-06-22 11:00:00	\N	\N	4	0	\N	\N
479234	MISSION	AUDRAP	\N	GUYANE	\N	Audition ambassade de France aux Pays-Bas et de M. Rodolphe Alexandre	\N	2020-06-22 15:45:00	2020-06-22 18:30:00	\N	\N	11	0	\N	\N
479244	COM_ENQUETE	AUDRAP	\N	AUTOROUT	\N	CE concessions autoroutières - CPT / ATMB - SFTRF	CE concessions autoroutières - CPT / ATMB - SFTRF	2020-07-02 09:00:00	2020-07-02 10:50:00	\N	\N	2	0	\N	\N
479263	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Echanges Russie	\N	2020-06-19 10:00:00	2020-06-19 12:35:00	\N	\N	13	0	\N	\N
479281	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT 2020 Le Grand Paris Express - M. Yves CROZET économiste	GT 2020 Le Grand Paris Express - M. Yves CROZET économiste	2020-06-22 10:05:00	2020-06-22 11:00:00	\N	\N	3	0	\N	\N
479282	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT 2020 Le Grand Paris Express - M. Michel CADOT, préfet de la région Île-de-France	GT 2020 Le Grand Paris Express - M. Michel CADOT, préfet de la région Île-de-France	2020-06-24 16:35:00	2020-06-24 18:00:00	\N	\N	7	0	\N	\N
479283	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT 2020 Le Grand Paris Express - M. Marc PAPINUTTI DGTIM	GT 2020 Le Grand Paris Express - M. Marc PAPINUTTI DGTIM	2020-06-26 14:00:00	2020-06-26 15:10:00	\N	\N	4	0	\N	\N
479284	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PJL DADUE	Auditions PJL DADUE	2020-06-19 08:45:00	2020-06-19 11:10:00	\N	\N	1	0	\N	\N
479304	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	GT Covid 19 Patrimoine	\N	2020-06-19 09:30:00	2020-06-19 10:20:00	\N	\N	4	0	\N	\N
479315	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL n° 314 DDADUE - DGDDI	PJL n° 314 DDADUE - DGDDI	2020-06-19 09:30:00	2020-06-19 10:30:00	\N	\N	1	0	\N	\N
479317	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL n° 314 DDADUE - DG Trésor	PJL n° 314 DDADUE - DG Trésor	2020-06-19 11:00:00	2020-06-19 12:00:00	\N	\N	1	0	\N	\N
479331	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Prévention de la perte d'autonomie - Audition de la FFMKR	\N	2020-06-16 17:00:00	2020-06-16 18:00:00	\N	\N	4	0	\N	\N
479332	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Prévention de la perte d'autonomie - Audition de Jérôme Guedj	\N	2020-06-16 18:00:00	2020-06-16 19:20:00	\N	\N	5	0	\N	\N
479333	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Prévention de la perte d'autonomie - Audition de la DGOS	\N	2020-06-19 09:00:00	2020-06-19 10:00:00	\N	\N	3	0	\N	\N
479367	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Organiser la sortie de l'état d'urgence sanitaire - Réunion commisssion	PJL Organiser la sortie de l'état d'urgence sanitaire - Réunion commisssion	2020-06-22 10:10:00	2020-06-22 11:20:00	2020-06-24 12:12:16	2020-06-24 12:15:18	19	0	\N	\N
479384	MISSION	AUCUNE	\N	GUYANE	\N	Audition de M. Jean-Bernard Nilam et Mme Myriam Aflalo	\N	2020-06-22 14:30:00	2020-06-22 15:30:00	2020-06-22 16:09:04	2020-06-22 18:59:16	9	0	\N	\N
479400	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion de la commissin	\N	2020-06-22 19:05:00	2020-06-22 19:40:00	2020-06-22 20:03:23	2020-06-24 11:55:39	10	0	\N	\N
479468	MISSION	AUDRAP	\N	FEDERATION	\N	Auditions MI FFS	Auditions MI FFS	2020-06-22 14:30:00	2020-06-22 15:30:00	\N	\N	8	0	\N	\N
479568	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - Aix Marseille Université	Audition Pollution plastique - Aix Marseille Université	2020-06-23 09:00:00	2020-06-23 10:00:00	\N	\N	2	0	\N	\N
479571	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - ASTEE	Audition Pollution plastique - ASTEE	2020-06-23 10:15:00	2020-06-23 11:35:00	\N	\N	2	0	\N	\N
479644	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi Covid-19 - Administration, collectivités, fonction publique	\N	2020-06-04 17:00:00	2020-06-04 18:00:00	\N	\N	2	0	\N	\N
479770	DELEGATION	AUDRAP	\N	\N	206	Audition  de Mme Florence FRESSE - Fédération française des pompes funèbres	Audition  de Mme Florence FRESSE - la Fédération française des pompes funèbres	2020-06-22 12:30:00	2020-06-22 13:30:00	\N	\N	1	0	\N	\N
479772	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Arnaud ESQUERRE, sociologue	Audition de M. Arnaud ESQUERRE, sociologue	2020-06-22 14:30:00	2020-06-22 15:30:00	\N	\N	1	0	\N	\N
479774	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Martin JULIER-COSTES, sociologue	Audition de M. Martin JULIER-COSTES, sociologue	2020-06-22 15:30:00	2020-06-22 16:30:00	\N	\N	1	0	\N	\N
479776	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Dominique CASTEX, anthropologue biologique	Audition de M. Dominique CASTEX, anthropologue biologique	2020-06-22 16:30:00	2020-06-22 17:30:00	\N	\N	1	0	\N	\N
479880	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion de la commission	Réunion de la commission	2020-06-24 10:30:00	2020-06-24 12:30:00	2020-06-24 14:36:25	2020-06-24 15:07:02	29	1	\N	\N
479988	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Suivi urgence Covid-19 - Prisons et autres lieux privatifs de liberté	Audition de la fédération d'associations Citoyens et Justice 	2020-06-23 10:00:00	2020-06-23 10:50:00	\N	\N	2	0	\N	\N
480469	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2020-06-24 16:15:00	2020-06-24 18:00:00	2020-06-30 15:20:21	2020-06-30 15:24:10	19	0	\N	\N
480585	GIA	AUCUNE	\N	\N	\N	RDV avec le nonce	Entretien avec Mgr Celestino Migliore, nonce apostolique en France	2020-06-24 10:45:00	2020-06-24 11:30:00	\N	\N	1	0	629	\N
481216	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions tourisme	\N	2020-04-08 00:00:00	2020-04-08 17:30:00	\N	\N	5	0	\N	\N
481243	COM_PERMANENTE	AUDRAP	\N	CAE	\N	audition cellule tourisme FFA	\N	2020-04-15 14:45:00	2020-04-15 15:30:00	\N	\N	11	0	\N	\N
481255	COM_PERMANENTE	AUDRAP	\N	CAE	\N	audition cellule tourisme Booking	\N	2020-04-15 15:30:00	2020-04-15 16:15:00	\N	\N	6	0	\N	\N
481262	COM_PERMANENTE	AUDRAP	\N	CAE	\N	audition cellule tourisme IGH	\N	2020-04-15 16:15:00	2020-04-15 17:30:00	\N	\N	5	0	\N	\N
481274	COM_PERMANENTE	AUDRAP	\N	CAE	\N	auditions cellule tourisme FNHPA et UNPLV	\N	2020-04-17 15:30:00	2020-04-17 17:00:00	\N	\N	4	0	\N	\N
481280	COM_PERMANENTE	AUDRAP	\N	CAE	\N	audition cellule tourisme Casinos	\N	2020-04-17 17:00:00	2020-04-17 17:45:00	\N	\N	3	0	\N	\N
481304	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule tourisme Entreprises du voyage	\N	2020-04-20 14:45:00	2020-04-20 15:30:00	\N	\N	4	0	\N	\N
481315	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule tourisme Fédération des gîtes de France	\N	2020-04-20 15:30:00	2020-04-20 16:15:00	\N	\N	4	0	\N	\N
481326	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule tourisme ANMSM	\N	2020-04-20 16:15:00	2020-04-20 17:00:00	\N	\N	5	0	\N	\N
384258	DELEGATION	AUDRAP	\N	\N	206	Audition ADEME/INRA	Audition ADEME/INRA sur les nouvelles tendances de la recherche sur les énergies renouvelables	2019-05-28 15:30:00	2019-05-28 17:50:00	\N	\N	2	0	\N	\N
389676	GIA	AUCUNE	\N	\N	\N	Assemblée générale du GIA France-Afghanistan	\N	2019-06-20 12:30:00	2019-06-20 14:00:00	\N	\N	2	0	648	\N
391338	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI Nouveaux territoires de la culture	MI Nouveaux territoires de la culture	2019-06-12 17:45:00	2019-06-12 18:30:00	\N	\N	2	0	\N	\N
391341	ETUDES	AUCUNE	\N	\N	\N	GE Numérique	\N	2019-06-12 17:30:00	2019-06-12 20:30:00	\N	\N	7	0	\N	1008
391351	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Centre national de la musique	\N	2019-06-13 15:45:00	2019-06-13 16:30:00	\N	\N	2	0	\N	\N
393592	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Ecole de la confiance	CMP Ecole de la confiance	2019-07-04 10:30:00	2019-07-04 11:50:00	\N	\N	70	0	\N	\N
393593	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Résiliation de contrats de complémentaire santé	CMP Résiliation de contrats de complémentaire santé	2019-07-04 11:50:00	2019-07-04 12:45:00	\N	\N	44	0	\N	\N
393594	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2019-07-04 15:00:00	2019-07-04 16:05:00	\N	\N	167	0	\N	\N
393595	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Trésorerie des associations	PPL Trésorerie des associations	2019-07-09 14:30:00	2019-07-09 16:35:00	\N	\N	91	0	\N	\N
393596	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2019-07-09 16:45:00	2019-07-09 17:50:00	\N	\N	262	0	\N	\N
393597	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Trésorerie des associations	PPL Trésorerie des associations	2019-07-09 18:00:00	2019-07-09 20:05:00	\N	\N	62	0	\N	\N
393600	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Centre national de musique	PPL Centre national de musique	2019-07-09 21:35:00	2019-07-10 00:40:00	\N	\N	42	0	\N	\N
393604	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Restauration ND de Paris	PJL Restauration ND de Paris	2019-07-10 14:30:00	2019-07-10 18:25:00	\N	\N	111	0	\N	\N
459654	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2019-12-17 17:00:00	2019-12-17 18:00:00	\N	\N	2	0	\N	\N
479408	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	\N	2020-06-24 09:30:00	2020-06-24 10:30:00	\N	\N	0	0	\N	\N
479409	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	\N	2020-06-24 09:30:00	2020-06-24 12:30:00	\N	\N	0	0	\N	\N
393608	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Taxe sur les services numériques ou NL	CMP Taxe sur les services numériques ou NL	2019-07-11 10:30:00	2019-07-11 13:30:00	\N	\N	34	0	\N	\N
393609	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	DOB et PJL budget 2018	DOB et PJL budget 2018	2019-07-11 14:30:00	2019-07-11 21:30:00	\N	\N	54	0	\N	\N
393610	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	DOB et PJL budget 2018	DOB et PJL budget 2018	2019-07-11 21:30:00	2019-07-12 00:00:00	\N	\N	0	0	\N	\N
393611	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2019-07-16 09:30:00	2019-07-16 12:45:00	\N	\N	40	0	\N	\N
393612	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Conclusions CMP PJL Office biodiversité	Conclusions CMP PJL Office biodiversité	2019-07-16 15:54:00	2019-07-16 17:30:00	\N	\N	61	0	\N	\N
393614	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Energie et climat	PJL Energie et climat	2019-07-16 17:45:00	2019-07-16 19:55:00	\N	\N	110	0	\N	\N
393615	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Energie et climat	PJL Energie et climat	2019-07-16 21:30:00	2019-07-17 00:30:00	\N	\N	78	0	\N	\N
393617	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Energie et climat	PJL Energie et climat	2019-07-17 15:09:00	2019-07-17 19:30:00	\N	\N	156	0	\N	\N
393618	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Energie et climat	PJL Energie et climat	2019-07-17 21:31:00	2019-07-18 01:20:00	\N	\N	78	0	\N	\N
393620	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Energie et climat	PJL Energie et climat	2019-07-18 10:30:00	2019-07-18 13:30:00	\N	\N	96	0	\N	\N
393625	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2019-07-18 15:00:00	2019-07-18 16:00:00	\N	\N	167	0	\N	\N
393628	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Energie et climat	PJL Energie et climat	2019-07-18 16:15:00	2019-07-18 19:55:00	\N	\N	59	0	\N	\N
393635	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Energie et climat	PJL Energie et climat	2019-07-18 21:30:00	2019-07-19 01:10:00	\N	\N	27	0	\N	\N
393655	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2019-07-23 16:45:00	2019-07-23 17:45:00	\N	\N	203	0	\N	\N
393826	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteur (Neurosciences) M. Olivier Houdé	Audition rapporteur (Neurosciences) M. Olivier Houdé	2019-07-10 15:00:00	2019-07-10 16:00:00	\N	\N	1	0	\N	\N
396300	MISSION	AUDRAP	\N	AERIEN	\N	\N	\N	2019-06-25 09:00:00	2019-06-25 10:40:00	\N	\N	4	0	\N	\N
403730	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Suite CMP Alsace	Suite CMP Alsace	2019-07-23 17:55:00	2019-07-23 18:20:00	\N	\N	52	0	\N	\N
409990	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL accord transports transfrontaliers Luxembourg	\N	2019-10-01 09:30:00	2019-10-01 10:20:00	\N	\N	1	0	\N	\N
426910	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs Pollution plastique	Audition rapporteurs Pollution plastique (SOS Mal de Seine)	2019-11-26 14:30:00	2019-11-26 15:30:00	\N	\N	2	0	\N	\N
428525	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs (Production de l'énergie dans le secteur agricole)	Audition rapporteurs (Production de l'énergie dans le secteur agricole) (Syndicat des énergies renouvelables)	2019-11-19 09:30:00	2019-11-19 11:20:00	\N	\N	2	0	\N	\N
431687	COM_ENQUETE	PLENIERE	\N	LUBRIZOL	\N	Réunion de commission	\N	2019-11-26 09:05:00	2019-11-26 10:30:00	2019-11-26 17:21:08	2019-11-26 17:35:26	7	0	\N	\N
431693	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJLF Budget 2020 -  Rapport pour avis sur la mission ravec les collectivités territoriales	PJLF Budget 2020 -  Rapport pour avis sur la mission ravec les collectivités territoriales	2019-11-26 09:30:00	2019-11-26 10:40:00	2019-11-26 11:26:22	2019-11-26 17:34:47	18	0	\N	\N
431714	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJLF Budget 2020 - Examen du rapport pour avis	\N	2019-11-26 09:30:00	2019-11-26 10:30:00	\N	\N	0	0	\N	\N
431727	DELEGATION	AUCUNE	\N	\N	DSOM	Audition de Mmes Sandrine Dauphin et Justine Dupuis	\N	2019-12-12 09:30:00	2019-12-12 11:10:00	\N	\N	11	0	\N	\N
431731	COM_ENQUETE	PLENIERE	\N	LUBRIZOL	\N	Réunion de commission	\N	2019-11-26 14:00:00	2019-11-26 16:30:00	2019-11-26 18:37:11	2019-11-27 15:28:41	9	0	\N	\N
440508	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Petit déjeuner ambassadeur de Chypre	Petit déjeuner ambassadeur de Chypre	2019-12-18 08:30:00	2019-12-18 10:00:00	\N	\N	20	0	\N	\N
440681	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Déclaration de naissances au lieu de résidence des parents	\N	2019-12-18 09:45:00	2019-12-18 12:00:00	\N	\N	1	0	\N	\N
452557	GIA	AUCUNE	\N	\N	\N	Entretien avec S. Exc. M. Dylan VERNON, ambassadeur du Belize en France	Entretien avec S. Exc. M. Dylan VERNON, ambassadeur du Belize en France	2020-01-28 12:30:00	2020-01-28 15:00:00	\N	\N	3	0	643	\N
466893	DELEGATION	AUCUNE	\N	\N	211	Réunion plénière	\N	2020-05-07 10:00:00	2020-05-07 12:35:00	2020-05-07 17:42:02	\N	15	0	\N	\N
486751	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Prévention de la perte d'autonomie - Audition de l'ADF	\N	2020-07-17 10:00:00	2020-07-17 11:00:00	\N	\N	2	0	\N	\N
423853	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2019-11-13 08:35:00	2019-11-13 12:25:00	2019-11-14 16:24:57	2019-11-14 16:59:06	47	0	\N	\N
466950	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Fédération nationale des sapeurs-pompiers de France	Fédération nationale des sapeurs-pompiers de France	2020-04-28 19:30:00	2020-04-28 20:30:00	\N	\N	3	0	\N	\N
475689	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2020-06-10 09:30:00	2020-06-10 11:55:00	2020-06-11 10:31:50	2020-06-12 11:17:10	36	2	\N	\N
475690	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2020-06-10 17:00:00	2020-06-10 18:45:00	2020-06-11 10:35:19	2020-06-12 11:17:06	26	0	\N	\N
476463	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Second tour des municipales	\N	2020-06-08 16:00:00	2020-06-08 16:30:00	\N	\N	3	0	\N	\N
476469	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Second tour des municipales	\N	2020-06-08 17:00:00	2020-06-08 17:30:00	\N	\N	4	0	\N	\N
481465	MISSION	AUDRAP	\N	FEDERATION	\N	Auditions MI FFS	Auditions MI FFS	2020-06-26 14:00:00	2020-06-26 15:15:00	\N	\N	7	0	\N	\N
482059	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GS Stratégie industrielle de l'UE	\N	2020-06-30 15:00:00	2020-06-30 16:15:00	\N	\N	4	0	\N	\N
482233	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-07-01 09:35:00	2020-07-01 11:25:00	2020-07-01 18:02:58	2020-07-02 18:18:16	34	0	\N	\N
482465	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - L'IHEDN et L'INHESJ - INHESJ	Contrôle 2020 - L'IHEDN et L'INHESJ - INHESJ	2020-06-30 15:30:00	2020-06-30 16:30:00	\N	\N	1	0	\N	\N
482484	MISSION	AUDRAP	\N	ILLECTRONISM	\N	Audition consacrée aux écrivains publics et médiateurs numériques	Audition consacrée aux écrivains publics et médiateurs numériques	2020-07-15 14:00:00	2020-07-15 14:55:00	\N	\N	1	0	\N	\N
482485	MISSION	AUDRAP	\N	ILLECTRONISM	\N	Audition de M. Pierre Mazet, sociologue	Audition de M. Pierre Mazet, sociologue	2020-07-15 16:30:00	2020-07-15 17:45:00	\N	\N	1	0	\N	\N
482898	COM_ENQUETE	PLENIERE	\N	AUTOROUT	\N	CE Concessions autoroutières - Audition de M. Philippe NOURRY puis de M. Christian ECKERT	CE Concessions autoroutières - Audition de M. Philippe NOURRY puis de M. Christian ECKERT	2020-07-01 16:35:00	2020-07-01 18:50:00	2020-07-01 18:53:04	2020-07-02 18:19:21	5	0	\N	\N
483057	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2020-07-08 09:30:00	2020-07-08 12:30:00	2020-07-08 14:28:37	2020-07-08 17:02:42	27	0	\N	\N
483164	COM_PERMANENTE	AUTRE	\N	FINC	\N	PJL 314 DADDUE Examen AMDTS Séance	PJL 314 DADDUE Examen AMDTS Séance	2020-07-07 14:05:00	2020-07-07 14:20:00	2020-07-07 17:22:56	2020-07-07 18:22:58	17	1	\N	\N
483166	COM_PERMANENTE	AUTRE	\N	FINC	\N	PJLR pour 2019 AMDTS Séance-Rapport PLFR(3) 2020 - Comm.	PJLR pour 2019 AMDTS Séance-Rapport PLFR(3) 2020 - Comm.	2020-07-08 09:35:00	2020-07-08 12:00:00	2020-07-09 09:43:28	2020-07-09 11:40:18	31	0	\N	\N
483190	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière Rapport Intégrité et publications scientifiques	Réunion plénière Rapport Intégrité et publications scientifiques	2020-07-09 09:45:00	2020-07-09 11:05:00	\N	\N	4	0	\N	\N
483191	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière - Rapport annuel CNE2	Réunion plénière - Rapport annuel CNE2	2020-07-08 17:15:00	2020-07-08 18:50:00	\N	\N	5	0	\N	\N
483202	COM_ENQUETE	PLENIERE	\N	AUTOROUT	\N	CE Concessions autoroutières - Cour des comptes puis de M. Jean-Baptiste DJEBBARI	CE Concessions autoroutières - Audition de la Cour des comptes puis de M. Jean-Baptiste DJEBBARI	2020-07-02 14:40:00	2020-07-02 17:25:00	2020-07-02 17:29:00	2020-07-02 18:19:23	6	0	\N	\N
483230	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-07-07 14:00:00	2020-07-07 14:30:00	\N	\N	0	0	\N	\N
483231	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-07-08 09:30:00	2020-07-08 11:00:00	2020-07-08 12:10:07	2020-07-08 17:02:42	41	3	\N	\N
483243	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 8 juillet	\N	2020-07-08 09:30:00	2020-07-08 11:00:00	2020-07-09 11:42:38	2020-07-09 14:38:39	12	0	\N	\N
483244	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 9 juillet	\N	2020-07-09 08:30:00	2020-07-09 12:05:00	2020-07-09 12:39:34	2020-07-09 14:38:40	10	0	\N	\N
483245	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Examen de rapports d'information MECSS	\N	2020-07-08 10:05:00	2020-07-08 11:25:00	2020-07-08 16:50:28	2020-07-08 17:02:40	35	0	\N	\N
483246	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2020-07-02 14:30:00	2020-07-02 17:30:00	\N	\N	1	0	\N	\N
483352	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Programme 144 : financement de la BITD 	RI Programme 144 : financement de la BITD	2020-06-30 14:00:00	2020-06-30 16:00:00	\N	\N	2	0	\N	\N
483355	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Programme 144 : financement de la BITD 	RI Programme 144 : financement de la BITD	2020-07-01 08:30:00	2020-07-01 09:30:00	\N	\N	2	0	\N	\N
483358	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Programme 144 : financement de la BITD 	RI Programme 144 : financement de la BITD	2020-07-01 14:00:00	2020-07-01 15:00:00	\N	\N	2	0	\N	\N
483482	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2020-07-07 14:30:00	2020-07-07 17:30:00	\N	\N	1	0	\N	\N
484663	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	DSOM	Conférence de presse : adoption d'un rapport sur l'urgence économique outre-mer	\N	2020-07-09 15:30:00	2020-07-09 16:45:00	\N	\N	6	0	\N	\N
484898	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PJLO et PJL Dette sociale et autonomie - Examen nvelle lecture rapport et texte	\N	2020-07-21 10:00:00	2020-07-21 10:20:00	2020-07-21 11:02:44	2020-07-21 15:44:03	19	2	\N	\N
485846	DELEGATION	AUDRAP	\N	\N	206	Audition Coronavirus - Thomas Campeaux et Clément Rouchouse	Audition Coronavirus - Thomas Campeaux et Clément Rouchouse	2020-06-26 17:00:00	2020-06-26 18:00:00	\N	\N	1	0	\N	\N
485857	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	GT Expertise psychiatrique en matière pénale	GT Expertise psychiatrique en matière pénale	2020-07-15 15:00:00	2020-07-15 15:45:00	\N	\N	1	0	\N	\N
485859	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	GT Expertise psychiatrique en matière pénale	GT Expertise psychiatrique en matière pénale	2020-07-16 09:00:00	2020-07-16 09:45:00	\N	\N	1	0	\N	\N
486747	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	M. Michel Guiraud, directeur général délégué - Muséum national d¿Histoire naturelle	\N	2020-01-21 14:30:00	2020-01-21 15:15:00	\N	\N	0	0	\N	\N
486748	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Prévention perte d'autonomie - Audition de l'Association française des aidants	\N	2020-07-15 10:00:00	2020-07-15 11:00:00	\N	\N	1	0	\N	\N
486749	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Prévention de la perte d'autonomie - Audition de la DSS	\N	2020-07-15 14:00:00	2020-07-15 15:00:00	\N	\N	2	0	\N	\N
486750	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Prévention de la dépendance - Audition du projet Oldyssey	\N	2020-07-17 09:00:00	2020-07-17 10:00:00	\N	\N	2	0	\N	\N
484626	CMP	AUTRE	\N	APPROBATION	\N	PJLG Règlement du budget et approbation des comptes de 2019	projet de loi de règlement du budget et d'approbation des comptes de l'année 2019	2020-07-09 14:02:00	2020-07-09 14:10:00	\N	\N	7	0	\N	\N
484645	CMP	AUTRE	\N	CONJUGALE	\N	PPL Protéger les victimes de violences conjugales	\N	2020-07-09 14:05:00	2020-07-09 14:40:00	\N	\N	8	0	\N	\N
486759	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Prévention de la perte d'autonomie - Audition de M. Luc Broussy	\N	2020-07-20 09:00:00	2020-07-20 10:00:00	\N	\N	1	0	\N	\N
486760	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Prévention de perte d'autonomie - Audition du RFVAA	\N	2020-07-20 10:00:00	2020-07-20 11:00:00	\N	\N	1	0	\N	\N
373786	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition PME et Numérique	Audition PME et Numérique - BPI France	2019-03-20 15:00:00	2019-03-20 16:00:00	\N	\N	1	0	\N	\N
373790	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition PME et Numérique	Audition PME et Numérique - Google France	2019-03-26 13:30:00	2019-03-26 14:30:00	\N	\N	1	0	\N	\N
373792	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition PME et Numérique	Audition PME et Numérique - BDO France	2019-03-26 17:45:00	2019-03-26 18:45:00	\N	\N	1	0	\N	\N
380213	COM_PERMANENTE	DEPLACEMENT	\N	SOCI	\N	Déplacement Meuse	Visite Maison de santé Revigny Présentation GHT Coeur grand Est et E Meuse	2019-05-06 07:55:00	2019-05-06 19:00:00	\N	\N	3	0	\N	\N
394215	BUREAU	AUCUNE	\N	\N	\N	Bureau 	Bureau du Sénat	2019-06-20 09:45:00	2019-06-20 12:00:00	\N	\N	18	0	\N	\N
398361	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Norman QUIJANO, Président de l¿Assemblée législative d¿El Salvador	Entretien avec M. Norman QUIJANO, Président de l¿Assemblée législative d¿El Salvador	2019-05-22 08:30:00	2019-05-22 10:30:00	\N	\N	3	0	643	\N
399485	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de la commission	Réunion de la commission	2019-07-10 09:35:00	2019-07-10 11:25:00	2019-07-12 16:15:39	2019-07-12 16:19:49	22	0	\N	\N
399906	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de la commission	Réunion de la commission	2019-07-10 16:10:00	2019-07-10 16:30:00	2019-07-10 16:44:37	2019-07-11 11:26:35	21	3	\N	\N
405419	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Espace - Auditions	GT Espace - Auditions	2019-09-18 16:00:00	2019-09-18 17:30:00	\N	\N	5	0	\N	\N
405425	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Espace - Audition	GT Espace - Audition	2019-09-18 17:30:00	2019-09-18 18:30:00	\N	\N	3	0	\N	\N
405690	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2019-09-24 16:45:00	2019-09-24 17:45:00	\N	\N	274	0	\N	\N
414042	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Enseignement supérieur	PLF 2020 - Crédits Enseignement supérieur	2019-10-10 09:00:00	2019-10-10 10:00:00	\N	\N	3	0	\N	\N
414049	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Fondation du Patrimoine	PPL Fondation du patrimoine	2019-10-09 08:45:00	2019-10-09 10:15:00	\N	\N	3	0	\N	\N
414050	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Fondation du Patrimoine	PPL Fondation du Patrimoine	2019-10-09 11:00:00	2019-10-09 11:45:00	\N	\N	3	0	\N	\N
414057	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Livre et Industries culturelles	PLF 2020 - Crédits Livre et Industries culturelles	2019-10-09 17:15:00	2019-10-09 18:15:00	\N	\N	1	0	\N	\N
414058	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Livre et Industries culturelles	PLF 2020 - Crédits Livre et Industries culturelles	2019-10-10 15:00:00	2019-10-10 17:00:00	\N	\N	1	0	\N	\N
414062	MISSION	AUCUNE	\N	MARITIME	\N	Examen et adoption du rapport	Examen et adoption du rapport	2019-10-22 13:35:00	2019-10-22 14:35:00	2019-10-22 15:05:46	2019-10-22 16:02:06	16	0	\N	\N
422847	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Présentation des orientations du premier bilan du titre Ier de la loi EGALIM	\N	2019-10-22 11:00:00	2019-10-22 12:00:00	\N	\N	0	0	\N	\N
422848	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Réunion d'arbitrage Mme Loisier, MM. Raison et Gremillet	\N	2019-10-22 13:00:00	2019-10-22 14:30:00	\N	\N	0	0	\N	\N
422865	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2020 - Mission Solidarité	\N	2019-10-30 14:15:00	2019-10-30 15:00:00	\N	\N	1	0	\N	\N
422867	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - CAS Gestion du patrimoine immobilier de l'État - CPU	PLF pour 2020 - CAS Gestion du patrimoine immobilier de l'État - CPU	2019-10-31 09:35:00	2019-10-31 10:20:00	\N	\N	2	0	\N	\N
422870	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - GFPRH - Syndicat DGFiP	PLF pour 2020 - GFPRH - Syndicat DGFiP	2019-10-31 10:40:00	2019-10-31 12:00:00	\N	\N	2	0	\N	\N
422873	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 -  Médias, livre et industries culturelles et Culture - Ministre Culture	PLF pour 2020 -  Médias, livre et industries culturelles et Culture - Ministre Culture	2019-10-31 10:00:00	2019-10-31 12:30:00	\N	\N	2	0	\N	\N
422876	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2020 - Mission Solidarité	\N	2019-10-29 16:00:00	2019-10-29 17:00:00	\N	\N	1	0	\N	\N
422878	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Culture - Secrétariat général ministère de la culture	PLF pour 2020 - Culture - Secrétariat général ministère de la culture	2019-10-31 12:00:00	2019-10-31 13:15:00	\N	\N	1	0	\N	\N
422880	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Avis Économie - Audition de M. Babary	PJLF 2020 - Avis Économie - Audition de M. Babary	2019-10-30 09:00:00	2019-10-30 10:00:00	\N	\N	1	0	\N	\N
422881	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Avis Économie - Audition de M. Babary	PJLF 2020 - Avis Économie - Audition de M. Babary	2019-10-30 17:00:00	2019-10-30 18:00:00	\N	\N	1	0	\N	\N
422882	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Avis Économie - Audition de M. Babary	PJLF 2020 - Avis Économie - Audition de M. Babary	2019-10-31 10:00:00	2019-10-31 11:00:00	\N	\N	1	0	\N	\N
422886	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJLF 2020 - Avis Transports ferroviaires - Audition de M. Mandelli	PJLF 2020 - Avis Transports ferroviaires - Audition de M. Mandelli	2019-10-29 09:30:00	2019-10-29 10:15:00	\N	\N	1	0	\N	\N
422887	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJLF 2020 - Avis Transports ferroviaires - Audition de M. Mandelli	PJLF 2020 - Avis Transports ferroviaires - Audition de M. Mandelli	2019-10-29 16:00:00	2019-10-29 17:00:00	\N	\N	1	0	\N	\N
422888	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJLF 2020 - Avis Transports ferroviaires - Audition de M. Mandelli	PJLF 2020 - Avis Transports ferroviaires - Audition de M. Mandelli	2019-10-29 17:00:00	2019-10-29 17:45:00	\N	\N	1	0	\N	\N
422889	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJLF 2020 - Avis Transports ferroviaires - Audition de M. MandelliPJLF 2020 - Avis Transpo	PJLF 2020 - Avis Transports ferroviaires - Audition de M. Mandelli	2019-10-29 17:45:00	2019-10-29 18:30:00	\N	\N	1	0	\N	\N
422894	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Écologie - CRE	PLF pour 2020 - Écologie - CRE	2019-10-29 09:30:00	2019-10-29 10:30:00	\N	\N	1	0	\N	\N
422896	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Écologie - DGITM	PLF pour 2020 - Écologie - DGITM	2019-10-29 15:00:00	2019-10-29 16:00:00	\N	\N	1	0	\N	\N
422898	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Écologie - DGEC	PLF pour 2020 - Écologie - DGEC	2019-10-30 17:00:00	2019-10-30 18:00:00	\N	\N	1	0	\N	\N
422900	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Rapport général - DGCL, DLF et DGFIP	PLF pour 2020 - Rapport général - DGCL, DLF et DGFIP	2019-10-29 14:00:00	2019-10-29 15:00:00	\N	\N	5	0	\N	\N
422912	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2020 - Travail et emploi	\N	2019-10-31 11:30:00	2019-10-31 12:15:00	\N	\N	1	0	\N	\N
422913	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2020 - Travail et emploi	\N	2019-10-31 12:15:00	2019-10-31 13:00:00	\N	\N	1	0	\N	\N
488095	CMP	AUTRE	\N	PLFR3	\N	PLFR pour 2020	PLFR pour 2020	2020-07-21 09:00:00	2020-07-21 10:22:00	\N	\N	9	0	\N	\N
422914	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Travailleurs indépendants	\N	2019-10-30 16:30:00	2019-10-30 17:30:00	\N	\N	3	0	\N	\N
422915	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Travailleurs indépendants	\N	2019-10-30 17:30:00	2019-10-30 18:30:00	\N	\N	3	0	\N	\N
422916	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Travailleurs indépendants	\N	2019-10-30 18:30:00	2019-10-30 19:30:00	\N	\N	2	0	\N	\N
422917	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Travailleurs indépendants	\N	2019-10-31 09:30:00	2019-10-31 10:30:00	\N	\N	2	0	\N	\N
422918	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Travalleurs indépendants	\N	2019-10-31 10:30:00	2019-10-31 11:30:00	\N	\N	2	0	\N	\N
422962	GIA	AUCUNE	\N	\N	\N	Rencontre avec des députés arméniens	Dîner en l'honneur d'une délégation de l'Assemblée nationale d'Arménie	2019-10-15 19:45:00	2019-10-15 22:30:00	\N	\N	6	0	641	\N
422969	GIA	AUCUNE	\N	\N	\N	Accueil de députés arméniens	DDéjeuner en l'honneur d'une délégation de l'Assemblée nationale d'Arménieie	2019-10-16 13:15:00	2019-10-16 14:50:00	\N	\N	10	0	641	\N
423210	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ambassadeur de Finlande, M. Teemu Tanner à l'Ambassade de Finlande	Entretien à l'Ambassade de Finlande	2019-10-29 12:45:00	2019-10-29 14:15:00	\N	\N	6	0	640	\N
424257	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Nouvelles formes de commerce	GT Nouvelles formes de commerce - réunion constitutive	2019-11-06 14:00:00	2019-11-06 15:00:00	\N	\N	11	0	\N	\N
436815	COM_EURO	CONTROLE	\N	AFEU	\N	Débat préalable au Conseil européen des 12 et 13 décembre 2019	Débat préalable au Conseil européen des 12 et 13 décembre 2019	2019-12-04 13:35:00	2019-12-04 15:50:00	2019-12-04 16:22:03	2019-12-04 16:48:53	17	0	\N	\N
439853	COM_SPECIALE	AUDRAP	\N	BIOETHIQUE	\N	\N	\N	2019-12-11 17:10:00	2019-12-11 17:45:00	\N	\N	2	0	\N	\N
439856	COM_SPECIALE	AUDRAP	\N	BIOETHIQUE	\N	\N	\N	2019-12-11 17:45:00	2019-12-11 19:30:00	\N	\N	1	0	\N	\N
439858	COM_SPECIALE	AUDRAP	\N	BIOETHIQUE	\N	\N	\N	2019-12-12 12:45:00	2019-12-12 14:00:00	\N	\N	1	0	\N	\N
446385	COM_PERMANENTE	AUTRE	\N	CDD	\N	Exposition du quotidien aux perturbateurs endocriniens - Table ronde	\N	2020-01-22 09:48:00	2020-01-22 12:02:00	2020-01-23 14:49:52	2020-01-23 17:49:06	37	0	\N	\N
454197	DELEGATION	AUCUNE	\N	\N	COLTER	Table ronde "Grand Paris"	\N	2020-02-20 10:00:00	2020-02-20 12:00:00	2020-02-20 12:25:07	\N	7	0	\N	\N
469647	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	Réunion plénière CATDD	2020-05-13 08:30:00	2020-05-13 10:34:00	2020-05-13 12:12:34	2020-05-13 18:07:57	30	0	\N	\N
481336	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule tourisme Domaines skiables de France	\N	2020-04-20 17:00:00	2020-04-20 17:45:00	\N	\N	3	0	\N	\N
481372	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule tourisme Cneth	\N	2020-04-24 17:00:00	2020-04-24 17:45:00	\N	\N	5	0	\N	\N
481383	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule tourisme Unimev	\N	2020-04-27 15:45:00	2020-04-27 16:30:00	\N	\N	4	0	\N	\N
481389	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule tourisme Anel	\N	2020-04-27 16:30:00	2020-04-27 17:15:00	\N	\N	4	0	\N	\N
481394	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule tourisme GNI	\N	2020-04-27 17:15:00	2020-04-27 18:00:00	\N	\N	3	0	\N	\N
481485	MISSION	AUDRAP	\N	FEDERATION	\N	Auditions MI FFS	Auditions MI FFS	2020-06-26 16:20:00	2020-06-26 17:20:00	\N	\N	6	0	\N	\N
481522	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Suivi PJL Notre Dame - Comité de suivi	Suivi PJL Notre Dame - Comité de suivi	2020-06-22 16:00:00	2020-06-22 17:30:00	\N	\N	1	0	\N	\N
481524	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFR pour 2020 (3) - "Rapport Général" - MEDEF / Axa France	PLFR pour 2020 (3) - "Rapport Général" - MEDEF / Axa France	2020-06-24 16:30:00	2020-06-24 17:45:00	\N	\N	1	0	\N	\N
481526	COM_ENQUETE	PLENIERE	\N	SOLS	\N	Table ronde Démarches innovantes en gestion de sites et sols pollués	\N	2020-07-02 16:45:00	2020-07-02 18:00:00	2020-07-03 12:13:43	2020-07-03 18:37:12	4	0	\N	\N
481530	MISSION	AUDRAP	\N	ILLECTRONISM	\N	Audition de la MEDNUM	Audition de la MEDNUM	2020-07-01 10:00:00	2020-07-01 11:00:00	\N	\N	2	0	\N	\N
481531	MISSION	AUCUNE	\N	ILLECTRONISM	\N	Table ronde des associations d'élus	Table ronde des associations d'élus	2020-06-30 15:00:00	2020-06-30 16:50:00	2020-06-30 17:18:41	2020-07-02 18:19:25	8	0	\N	\N
481553	MISSION	AUDRAP	\N	ILLECTRONISM	\N	Audition de la CNAF et de Pôle Emploi	\N	2020-07-01 11:00:00	2020-07-01 12:00:00	\N	\N	3	0	\N	\N
481555	MISSION	AUDRAP	\N	DEPARTEMENT	\N	Audition rapporteur MM. Prieur et Reulet	Audition rapporteur MM. Prieur et Reulet	2020-07-01 14:20:00	2020-07-01 14:55:00	\N	\N	6	0	\N	\N
481557	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition M. Jean-Philippe Vachia -Présidence CNCCFP - Article 13	Audition M. Jean-Philippe Vachia -Présidence CNCCFP - Article 13	2020-07-01 09:05:00	2020-07-01 10:20:00	2020-07-01 15:29:46	2020-07-02 18:18:16	21	1	\N	\N
481559	MISSION	AUDRAP	\N	ILLECTRONISM	\N	Audition du MEDEF	Audition du MEDEF	2020-07-01 17:00:00	2020-07-01 17:40:00	\N	\N	3	0	\N	\N
481560	MISSION	AUDRAP	\N	ILLECTRONISM	\N	Audition de la Caisse des Dépôts et Consignations	Audition de M. Olivier Sichel, Directeur général adjoint de la Caisse des Dépôts et Consignations	2020-07-07 15:30:00	2020-07-07 16:20:00	\N	\N	2	0	\N	\N
481561	COM_ENQUETE	PLENIERE	\N	RADICALI	\N	Examen du projet de rapport de la commission d'enquête	Examen du projet de rapport de la commission d'enquête	2020-07-07 14:30:00	2020-07-07 17:00:00	2020-07-07 17:26:57	2020-07-07 18:16:00	14	1	\N	\N
481562	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition M. Veaux -  PJL Organiser la sortie de l'état d'urgence sanitaire nvlle lecture	Audition M. Veaux -  PJL Organiser la sortie de l'état d'urgence sanitaire nvlle lecture	2020-07-01 10:35:00	2020-07-01 12:30:00	\N	\N	16	1	\N	\N
481565	MISSION	AUCUNE	\N	ILLECTRONISM	\N	Echanges de vues sur les travaux en cours de la mission d'information	Echanges de vues sur les travaux en cours de la mission d'information	2020-07-09 11:30:00	2020-07-09 12:30:00	2020-07-09 12:14:30	2020-07-09 14:39:10	8	0	\N	\N
481575	DELEGATION	AUCUNE	\N	\N	DSOM	Présentation des conclusions du président au groupe de travail Décentralisation	\N	2020-07-03 14:00:00	2020-07-03 16:00:00	\N	\N	9	0	\N	\N
481608	DELEGATION	AUCUNE	\N	\N	211	Examen du rapport d¿information sur la place des femmes dans les médias audiovisuels 	Examen du rapport d¿information sur la place des femmes dans les médias audiovisuels 	2020-07-09 09:00:00	2020-07-09 09:40:00	2020-07-09 10:23:57	\N	7	0	\N	\N
481610	DELEGATION	AUCUNE	\N	\N	211	Examen du bilan de l¿activité de la délégation depuis le dernier renouvellement sénatorial	Examen du bilan de l¿activité de la délégation depuis le dernier renouvellement sénatorial	2020-07-15 12:30:00	2020-07-15 13:10:00	2020-07-15 14:32:23	\N	12	0	\N	\N
481611	MISSION	AUDRAP	\N	FEDERATION	\N	Auditions MI FFS	Auditions MI FFS	2020-06-29 15:30:00	2020-06-29 17:30:00	\N	\N	6	0	\N	\N
481626	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2020-07-01 09:00:00	2020-07-01 12:51:00	2020-07-01 14:46:00	2020-07-02 18:18:13	32	4	\N	\N
481701	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 20 avril 2020	\N	2020-04-20 14:00:00	2020-04-20 15:55:00	\N	\N	0	0	\N	\N
481711	COM_EURO	AUDRAP	\N	AFEU	\N	Union européenne et la santé, à la suite de la pandémie de COVID-19	Union européenne et la santé, à la suite de la pandémie de COVID-19	2020-06-30 13:30:00	2020-06-30 14:45:00	\N	\N	2	0	\N	\N
481910	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 30 avril 2002	\N	2020-04-30 14:30:00	2020-04-30 16:00:00	\N	\N	0	0	\N	\N
482043	MISSION	AUDRAP	\N	FEDERATION	\N	Auditions MI FFS	Auditions MI FFS	2020-06-30 15:00:00	2020-06-30 16:50:00	\N	\N	6	0	\N	\N
482053	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	\N	2020-07-01 08:00:00	2020-07-01 11:15:00	2020-07-01 12:23:20	\N	30	0	\N	\N
482055	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Examen du rapport	\N	2020-06-30 15:00:00	2020-06-30 16:15:00	\N	\N	0	0	\N	\N
482271	BUREAU	AUCUNE	\N	\N	\N	Bureau du Sénat	Bureau du Sénat	2020-07-01 09:00:00	2020-07-01 11:00:00	\N	\N	24	0	\N	\N
482911	DELEGATION	AUCUNE	\N	\N	211	Désignation des lauréats du prix 2020 de la DDF	Désignation des lauréats du prix 2020 de la DDF	2020-06-30 17:30:00	2020-06-30 18:30:00	\N	\N	10	0	\N	\N
483047	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-07-02 09:00:00	2020-07-02 11:05:00	2020-07-02 11:42:21	2020-07-02 18:18:19	26	0	\N	\N
483050	GIA	AUCUNE	\N	\N	\N	Entretien avec S.E. le Dr Ismaïl Hakki MUSA, Ambassadeur de Turquie en France	Entretien avec S.E. le Dr Ismaïl Hakki MUSA, Ambassadeur de Turquie en France	2020-07-01 12:30:00	2020-07-01 14:00:00	\N	\N	5	0	624	\N
483058	COM_ENQUETE	AUTRE	\N	PANDEMIE	\N	Réunion constitutive	\N	2020-07-01 10:00:00	2020-07-01 12:00:00	\N	\N	0	0	\N	\N
483075	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	GT Covid-19 Médias audiovisuels	GT Covid-19 Médias audiovisuels	2020-07-02 09:30:00	2020-07-02 10:30:00	\N	\N	3	0	\N	\N
483079	COM_ENQUETE	PLENIERE	\N	PANDEMIE	\N	\N	\N	2020-07-02 10:00:00	2020-07-02 11:10:00	2020-07-02 11:08:58	2020-07-02 18:19:22	22	0	\N	\N
483112	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - Fonds européen - Cour des comptes / DGEFP	Contrôle 2020 - Fonds européen - Cour des comptes / DGEFP	2020-06-30 10:00:00	2020-06-30 11:45:00	\N	\N	1	0	\N	\N
483204	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - UIT	Audition Pollution plastique - UIT	2020-07-02 14:00:00	2020-07-02 15:30:00	\N	\N	2	0	\N	\N
483207	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - IFP Energies nouvelles	Audition Pollution plastique - IFP Energies nouvelles	2020-07-02 15:45:00	2020-07-02 17:15:00	\N	\N	2	0	\N	\N
483211	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - Laboratoire Regards	Audition Pollution plastique - Laboratoire Regards	2020-07-02 17:30:00	2020-07-02 18:30:00	\N	\N	2	0	\N	\N
483267	DELEGATION	AUCUNE	\N	\N	COLTER	Table ronde Iles métropolitaines + rapport étape sécurité intérieure	\N	2020-07-09 09:30:00	2020-07-09 11:30:00	2020-07-09 12:20:01	\N	6	0	\N	\N
483411	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule tourisme Grape Hospitality	\N	2020-07-03 10:30:00	2020-07-03 11:15:00	\N	\N	3	0	\N	\N
483420	COM_PERMANENTE	AUDRAP	\N	CAE	\N	auditions tourisme	\N	2020-07-01 17:15:00	2020-07-01 18:30:00	\N	\N	3	0	\N	\N
483424	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions cellule tourisme	\N	2020-06-30 15:15:00	2020-06-30 17:30:00	\N	\N	3	0	\N	\N
483428	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions 5G	\N	2020-06-30 18:30:00	2020-06-30 19:30:00	\N	\N	1	0	\N	\N
483430	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions 5G	\N	2020-07-01 14:00:00	2020-07-01 15:00:00	\N	\N	2	0	\N	\N
373698	GIA	AUCUNE	\N	\N	\N	Entretien de MM. REICHARDT et LECONTE avec  M. Mamadou Aliou BAH, enseignant et président 	Entretien de MM. REICHARDT et LECONTE avec  M. Mamadou Aliou BAH, enseignant et président du "Model" (coopé)	2019-03-12 16:00:00	2019-03-12 16:30:00	\N	\N	2	0	573	\N
373701	GIA	AUCUNE	\N	\N	\N	Entretien de M. Lefèvre avec les auditeurs du MEGA (coopé)	Entretien de M. Lefèvre avec les auditeurs du MEGA (coopé)	2019-03-26 14:30:00	2019-03-26 15:15:00	\N	\N	1	0	604	\N
373703	GIA	AUCUNE	\N	\N	\N	Entretien de Mme ROSSIGNOL avec Mme Evon IDAHOSA, Directrice d'ONG (coopé)	Entretien de Mme ROSSIGNOL avec Mme Evon IDAHOSA, Directrice d'ONG (coopé)	2019-03-28 12:10:00	2019-03-28 12:55:00	\N	\N	1	0	573	\N
373705	GIA	AUCUNE	\N	\N	\N	Entretien avec le Père Iyad TWAL, de Jérusalem (coopé)	Entretien avec le Père Iyad TWAL, de Jérusalem (coopé)	2019-03-09 15:30:00	2019-03-09 16:30:00	\N	\N	1	0	CHRETORIENT	CHRETORIENT
392563	GIA	AUCUNE	\N	\N	\N	Déjeuner de travail avec des représentants du MAE 	Déjeuner de travail avec la sous-directrice Asie du Sud-Est au ministère des affaires étrangères - point d'actualiteé	2019-06-19 13:00:00	2019-06-19 14:15:00	\N	\N	5	0	653	\N
393013	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Energie - Auditions M. Gremillet	\N	2019-06-19 15:00:00	2019-06-19 16:00:00	\N	\N	4	0	\N	\N
393028	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Energie - Auditions M. Gremillet	\N	2019-06-19 16:00:00	2019-06-19 17:00:00	\N	\N	3	0	\N	\N
393034	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Energie - Auditions M. Gremillet	\N	2019-06-19 17:00:00	2019-06-19 18:25:00	\N	\N	3	0	\N	\N
402812	MISSION	AUDRAP	\N	AERIEN	\N	\N	\N	2019-07-23 15:30:00	2019-07-23 16:50:00	\N	\N	4	0	\N	\N
411554	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Presse	\N	2019-10-08 09:30:00	2019-10-08 10:30:00	\N	\N	1	0	\N	\N
411556	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Presse	\N	2019-10-08 16:00:00	2019-10-08 18:00:00	\N	\N	1	0	\N	\N
418829	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Travailleurs indépendants	\N	2019-10-22 16:00:00	2019-10-22 19:00:00	\N	\N	3	0	\N	\N
418881	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJLF 2020 - Avis Prévention des risques - Auditions M.  Médevielle	PJLF 2020 - Avis Prévention des risques - Auditions M.  Médevielle	2019-10-21 09:30:00	2019-10-21 10:30:00	\N	\N	1	0	\N	\N
418884	DELEGATION	AUDRAP	\N	\N	PROS	Audition de la FNSEA	Audition de la FNSEA	2019-10-29 16:30:00	2019-10-29 17:45:00	\N	\N	1	0	\N	\N
419055	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJLF 2020 - Avis Transports ferroviaires - Audition de M. Mandelli	PJLF 2020 - Avis Transports ferroviaires - Audition de M. Mandelli	2019-10-22 09:30:00	2019-10-22 10:15:00	\N	\N	1	0	\N	\N
419095	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Avis Économie - Auditions M. Bourquin	PJLF 2020 - Avis Économie - Auditions M. Bourquin	2019-10-22 13:30:00	2019-10-22 14:30:00	\N	\N	1	0	\N	\N
419097	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Avis Économie - Auditions M. Bourquin	PJLF 2020 - Avis Économie - Auditions M. Bourquin	2019-10-22 16:00:00	2019-10-22 16:45:00	\N	\N	1	0	\N	\N
419098	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Avis Économie - Auditions M. Bourquin	PJLF 2020 - Auditions Économie - M. Bourquin	2019-10-22 16:45:00	2019-10-22 17:40:00	\N	\N	1	0	\N	\N
419099	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Avis Économie - Auditions M. Bourquin	PJLF 2020 - Auditions Économie - M. Bourquin	2019-10-22 17:40:00	2019-10-22 18:25:00	\N	\N	1	0	\N	\N
483014	CMP	AUTRE	\N	DEMARCHAGE	\N	PPL Démarchage téléphonique et lutte contre les appels frauduleux	PPL Démarchage téléphonique et lutte contre les appels frauduleux	2020-07-01 18:00:00	2020-07-01 19:05:00	\N	\N	8	0	\N	\N
423901	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Audiovisuel	PLF 2020 - Crédits Audiovisuel	2019-11-05 14:30:00	2019-11-05 15:30:00	\N	\N	6	0	\N	\N
423902	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Audiovisuel	PLF 2020 - Crédits Audiovisuel	2019-11-05 15:30:00	2019-11-05 16:30:00	\N	\N	5	0	\N	\N
423905	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Audiovisuel	PLF 2020 - Crédits Audiovisuel	2019-11-05 16:30:00	2019-11-05 17:30:00	\N	\N	4	0	\N	\N
423938	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2020 - Avis Sécurité civile	PLF 2020 - Avis Sécurité civile	2019-11-05 15:30:00	2019-11-05 17:50:00	\N	\N	1	0	\N	\N
423947	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2020 - Avis Relations avec les collectivités territoriales	PLF 2020 - Avis Relations avec les collectivités territoriales	2019-11-05 17:00:00	2019-11-05 18:45:00	\N	\N	4	0	\N	\N
423958	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 Culture (Patrimoine)	PLF 2020 Culture (Patrimoine)	2019-11-06 14:00:00	2019-11-06 14:50:00	\N	\N	5	0	\N	\N
424280	COM_PERMANENTE	AUDRAP	\N	CAE	\N	CAS Participations financières de l'Etat	CAS Participations financières de l'Etat - Audition M. Chatillon	2019-11-06 11:00:00	2019-11-06 12:15:00	\N	\N	1	0	\N	\N
424284	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020	PLF 2020 - Crédits Enseignement scolaire	2019-11-06 14:30:00	2019-11-06 15:30:00	\N	\N	2	0	\N	\N
424290	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition PJLF 2020 DAG	\N	2019-11-05 09:00:00	2019-11-05 09:50:00	\N	\N	1	0	\N	\N
429148	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2019-11-14 18:25:00	2019-11-14 18:55:00	\N	\N	15	0	\N	\N
431971	COM_SPECIALE	AUDRAP	\N	BIOETHIQUE	\N	Audition Mme Jourda Sociologue / Philosophe	\N	2019-11-26 09:45:00	2019-11-26 11:15:00	\N	\N	2	0	\N	\N
432075	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Usages dangereux du protoxyde d'azote	\N	2019-11-26 09:40:00	2019-11-26 10:30:00	\N	\N	1	0	\N	\N
432076	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Usages dangereux du protoxyde d'azote	\N	2019-11-26 14:00:00	2019-11-26 14:40:00	\N	\N	1	0	\N	\N
432085	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2020 - Examen de l'amendement sur l'article 37	PLF pour 2020 - Examen de l'amendement sur l'article 37	2019-11-26 19:00:00	2019-11-26 19:20:00	2019-11-27 08:41:31	2019-11-27 15:06:03	16	0	\N	\N
432090	COM_SPECIALE	AUDRAP	\N	BIOETHIQUE	\N	Audition M. Jomier et Mme Jourda Associations art 1 à 4	\N	2019-11-26 16:30:00	2019-11-26 18:30:00	\N	\N	6	0	\N	\N
436343	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL accord UE-Arménie	\N	2019-12-03 15:00:00	2019-12-03 17:00:00	\N	\N	1	0	\N	\N
436346	GIA	AUCUNE	\N	\N	\N	Rencontre avec des historiens	petit déjeuner avec les historiens Maurice PONTHIEUX et  Mathieu GEAGEA	2019-12-04 08:30:00	2019-12-04 09:30:00	\N	\N	4	0	852	\N
438465	COM_SPECIALE	AUDRAP	\N	BIOETHIQUE	\N	Auditions rapporteur	\N	2019-12-10 17:30:00	2019-12-10 18:30:00	\N	\N	2	0	\N	\N
438474	COM_SPECIALE	AUDRAP	\N	BIOETHIQUE	\N	Audition Mme Jourda CNB et Barreau de Paris art 4	\N	2019-12-10 10:35:00	2019-12-10 11:10:00	\N	\N	3	0	\N	\N
438476	COM_SPECIALE	AUDRAP	\N	BIOETHIQUE	\N	Audition Mme Jourda Dr Jousselme art 1 et 2	\N	2019-12-10 16:20:00	2019-12-10 17:00:00	\N	\N	3	0	\N	\N
438613	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions de M. Montaugé et Mme Noël-PPL Libre choix du consommateur dans le cyberespace	Audition de représentants de UFC - Que Choisir	2019-12-10 10:00:00	2019-12-10 10:30:00	\N	\N	1	0	\N	\N
438614	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions de M. Montaugé et Mme Noël-PPL Libre choix du consommateur dans le cyberespace	Audition de représentants de la Direction générale des entreprises (MINEF)	2019-12-11 08:30:00	2019-12-11 09:30:00	\N	\N	2	0	\N	\N
435580	GIA	AUCUNE	\N	\N	\N	Déjeuner avec une délégation du groupe d'amitié Estonie-France du Riigikogu	Déjeuner avec une délégation du groupe d'amitié Estonie-France du Riigikogu	2019-11-21 12:30:00	2019-11-21 14:20:00	\N	\N	4	0	616	\N
435590	GIA	AUCUNE	\N	\N	\N	Entretien avec la commission des affaires étrangères du Riigikogu estonien	Entretien avec une délégation de la commission des affaires étrangères du Riigikogu estonien	2019-11-28 12:30:00	2019-11-28 14:45:00	\N	\N	1	0	616	\N
456747	COM_PERMANENTE	AUTRE	\N	CDD	\N	Mission d'information sur l'empreinte environnementale du numérique	MI sur l'empreinte environnementale du numérique - Audition de Mme LEMERCIER-DUGARIN et M. STORA	2020-02-19 16:30:00	2020-02-19 17:15:00	\N	\N	6	0	\N	\N
456748	COM_PERMANENTE	AUTRE	\N	CDD	\N	Mission d'information sur l'empreinte environnementale du numérique	MI sur l'empreinte environnementale du numérique - Audition de M. BIHOUIX	2020-02-19 17:45:00	2020-02-19 18:30:00	\N	\N	5	0	\N	\N
458756	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Strasbourg - Adhésion de l'UE à la CEDH	\N	2020-02-10 15:25:00	2020-02-10 16:10:00	\N	\N	2	0	\N	\N
458757	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Audition Mme Maricineanu, ministre de ssports	2020-02-27 11:07:00	2020-02-27 12:34:00	2020-02-27 16:59:48	2020-02-27 17:18:50	21	0	\N	\N
458758	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Strasbourg - Adhésion de l'UE à la CEDH	\N	2020-02-10 16:15:00	2020-02-10 17:15:00	\N	\N	2	0	\N	\N
463298	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PJL COVID 19	CMP PJL COVID 19	2020-03-22 15:32:00	2020-03-22 18:13:00	\N	\N	34	0	\N	\N
488407	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2020-07-07 14:35:00	2020-07-07 17:00:00	\N	\N	3	0	\N	\N
423940	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-11-13 09:34:00	2019-11-13 11:28:00	2019-11-14 14:50:55	2019-11-14 15:31:45	42	2	\N	\N
428373	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PLF pour 2020 (Examen de rapports pour avis) - PPL Violences au sein de la famille (CMP)	PLF pour 2020 (Examen de rapports pour avis) - PPL Violences au sein de la famille (CMP)	2019-11-20 09:05:00	2019-11-20 12:20:00	2019-11-20 12:40:12	2019-11-20 16:36:40	36	1	\N	\N
429138	CMP	AUTRE	\N	PLFSS2020	\N	PLFSS pour 2020	PLFSS pour 2020	2019-11-19 18:33:00	2019-11-19 18:47:00	\N	\N	7	0	\N	\N
488427	COM_ENQUETE	PLENIERE	\N	PANDEMIE	\N	Table ronde sur les prises en charge à domicile	\N	2020-09-01 10:33:00	2020-09-01 12:47:00	2020-09-01 14:00:45	2020-09-01 17:36:12	20	0	\N	\N
488428	COM_ENQUETE	PLENIERE	\N	PANDEMIE	\N	Table ronde sur la situation dans les EHPAD	\N	2020-09-01 14:30:00	2020-09-01 17:10:00	2020-09-01 17:09:54	2020-09-01 17:36:13	24	0	\N	\N
488429	COM_ENQUETE	PLENIERE	\N	PANDEMIE	\N	Table ronde sur les aspects éthiques	\N	2020-09-02 09:35:00	2020-09-02 12:35:00	2020-09-02 12:55:41	2020-09-02 19:14:50	22	0	\N	\N
488430	COM_ENQUETE	PLENIERE	\N	PANDEMIE	\N	Table ronde avec les ordres des professions de santé	\N	2020-09-02 14:30:00	2020-09-02 17:35:00	2020-09-02 17:36:48	2020-09-02 19:14:50	21	0	\N	\N
488431	COM_ENQUETE	PLENIERE	\N	PANDEMIE	\N	Table ronde avec des fédérations hospitalières et médico-sociales	\N	2020-09-03 09:30:00	2020-09-03 12:10:00	2020-09-03 12:11:13	2020-09-04 18:44:32	19	0	\N	\N
488432	COM_ENQUETE	PLENIERE	\N	PANDEMIE	\N	Audition de la directrice générale de l'offre de soins	\N	2020-09-03 14:00:00	2020-09-03 16:00:00	\N	\N	17	0	\N	\N
489072	MISSION	AUTRE	\N	FEDERATION	\N	Réunion plénière	\N	2020-09-08 09:37:00	2020-09-08 10:27:00	2020-09-14 17:32:59	2020-09-14 17:59:22	8	0	\N	\N
489169	GIA	AUCUNE	\N	\N	\N	célébration anniversaire Dalai Lama	célébration anniversaire Dalai Lama	2020-09-08 17:00:00	2020-09-08 19:00:00	\N	\N	3	0	634	\N
489487	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Territoire zéro chômeur de longue durée	\N	2020-09-16 10:00:00	2020-09-16 11:00:00	\N	\N	2	0	\N	\N
489490	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Territoire zéro chômeur de longue durée	\N	2020-09-16 11:00:00	2020-09-16 12:00:00	\N	\N	3	0	\N	\N
489494	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Territoire zéro chômeur de longue durée	\N	2020-09-16 14:30:00	2020-09-16 15:30:00	\N	\N	2	0	\N	\N
489497	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Territoire zéro chômeur de longue durée	\N	2020-09-16 15:30:00	2020-09-16 16:30:00	\N	\N	1	0	\N	\N
489499	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL LPPR	\N	2020-09-16 10:00:00	2020-09-16 13:00:00	\N	\N	4	0	\N	\N
489504	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL LPPR	\N	2020-09-17 14:30:00	2020-09-17 17:30:00	\N	\N	4	0	\N	\N
490448	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Constitution - Nominations - Examen de rapports	Constitution - Nominations - Examen de rapports	2020-10-07 09:30:00	2020-10-07 12:30:00	2020-10-07 15:39:28	2020-10-07 18:04:35	44	0	\N	\N
490453	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Reconstitution du Bureau 	Reconstitution du Bureau de la commission 	2020-10-07 12:00:00	2020-10-07 13:10:00	2020-10-07 18:11:34	2020-10-08 18:30:30	41	0	\N	\N
491468	COM_PERMANENTE	AUTRE	\N	ETRD	\N	PLF 2021 - Audition  Mme Parly	PLF 2021 - Audition Mme Parly	2020-10-13 17:00:00	2020-10-13 18:30:00	2020-10-14 14:51:07	2020-10-14 18:25:42	28	0	\N	\N
491469	COM_PERMANENTE	AUTRE	\N	ETRD	\N	PLF 2021 - Audition M. Rémy Rioux puis Général Lecointre	PLF 2021 - Audition M. Rémy Rioux puis Général Lecointre	2020-10-14 09:45:00	2020-10-14 11:15:00	2020-10-14 16:39:43	2020-10-14 18:25:39	34	0	\N	\N
491485	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désignation candidats CMP  - PJL Régime transitoire fin EUS (amendements séance)	Désignation candidats CMP  - PJL Régime transitoire fin EUS (amendements séance)	2020-10-13 09:30:00	2020-10-13 10:30:00	2020-10-13 15:12:27	2020-10-13 15:52:49	28	0	\N	\N
491486	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de Dominique Simonnot, candidate aux fonctions de CGLPL	Audition de Dominique Simonnot, candidate aux fonctions de CGLPL	2020-10-13 15:30:00	2020-10-13 16:30:00	2020-10-13 18:33:05	2020-10-14 18:26:51	16	0	\N	\N
491487	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	LOIS	\N	Audition de Dominique Simonnot - Dépouillement des scrutins	Audition de Dominique Simonnot - Dépouillement des scrutins	2020-10-13 19:00:00	2020-10-13 19:05:00	\N	\N	6	0	\N	\N
491488	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Nomination rapporteur - Examen d'amendements, rapports et textes	Nomination rapporteur - Examen d'amendements, rapports et textes	2020-10-14 09:30:00	2020-10-14 12:00:00	2020-10-14 12:48:41	2020-10-14 18:26:46	39	0	\N	\N
493330	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL échange de permis de conduire avec le Qatar et la Chine	\N	2020-10-15 14:25:00	2020-10-15 16:05:00	\N	\N	1	0	\N	\N
493355	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPLC Lois République	PPLC Lois République	2020-10-19 17:00:00	2020-10-19 19:40:00	\N	\N	48	0	\N	\N
493357	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPLC/PPLO Libertés locales	PPLC/PPLO Libertés locales	2020-10-20 14:30:00	2020-10-20 19:35:00	\N	\N	159	0	\N	\N
493361	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Déshérence des contrats de retraite	PPL Déshérence des contrats de retraite	2020-10-21 16:40:00	2020-10-21 18:15:00	\N	\N	75	0	\N	\N
493363	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Conseil européen	Débat Conseil européen	2020-10-21 21:30:00	2020-10-21 23:40:00	\N	\N	45	0	\N	\N
493364	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Cybersécurité	PPL Cybersécurité	2020-10-22 14:30:00	2020-10-22 16:30:00	\N	\N	53	0	\N	\N
493368	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Equipement territoires ruraux	PPL Equipement territoires ruraux	2020-10-22 16:30:00	2020-10-22 18:30:00	\N	\N	50	0	\N	\N
493408	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2021 - Branche accidents du travail - Maladies professionnelles - Audition CATMP	PLFSS 2021 - Branche accidents du travail - Maladies professionnelles - Audition CATMP	2020-10-20 15:30:00	2020-10-20 16:15:00	\N	\N	2	0	\N	\N
380094	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI défense européenne	\N	2019-05-14 16:00:00	2019-05-14 17:00:00	\N	\N	2	0	\N	\N
380098	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Mission défense européenne	\N	2019-05-15 15:30:00	2019-05-15 16:30:00	\N	\N	2	0	\N	\N
493410	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Examen rapport/texte PJL Restitutions et amendements de séance PJL Recherche	\N	2020-10-28 09:00:00	2020-10-28 12:00:00	2020-10-28 12:36:47	2020-10-28 14:33:08	38	0	\N	\N
380142	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Négociations commerciales	Groupe de suivi sur les négociations commerciales	2019-05-14 15:00:00	2019-05-14 16:00:00	\N	\N	3	0	\N	\N
382489	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Instituer un médiateur territorial dans certaines collectivités	PPL Médiateur territorial	2019-05-21 09:30:00	2019-05-21 11:10:00	\N	\N	2	0	\N	\N
382558	QUESTURE	AUCUNE	\N	\N	\N	Questure	Conseil de Questure	2019-05-15 14:45:00	2019-05-15 17:35:00	\N	\N	3	0	\N	\N
408086	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-09-27 12:45:00	2019-09-27 13:00:00	2019-09-27 19:22:41	\N	12	0	\N	\N
408087	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-09-27 16:45:00	2019-09-27 16:54:00	2019-09-27 19:25:02	\N	8	0	\N	\N
410936	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT Stratégie industrielle de l'UE	Auditions du MEDEF et CPME	2019-10-08 09:00:00	2019-10-08 10:30:00	\N	\N	2	0	\N	\N
411140	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR CE incendie LUBRIZOL	PPR CE incendie LUBRIZOL	2019-10-10 10:30:00	2019-10-10 10:50:00	\N	\N	38	0	\N	\N
424722	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2020 - Travail et emploi	\N	2019-11-05 16:15:00	2019-11-05 17:00:00	\N	\N	1	0	\N	\N
424728	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Travail et emploi	\N	2019-11-05 18:00:00	2019-11-05 19:00:00	\N	\N	2	0	\N	\N
424740	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Anciens combattants, mémoire et liens avec la Nation	\N	2019-11-05 14:30:00	2019-11-05 15:15:00	\N	\N	1	0	\N	\N
424868	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL 2020 - DG	\N	2019-11-21 14:31:00	2019-11-21 18:21:00	\N	\N	108	0	\N	\N
424869	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Art. liminaire et 36	PLF pour 2020 - Art. liminaire et 36	2019-11-21 18:30:00	2019-11-21 19:38:00	\N	\N	37	0	\N	\N
424870	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Art. 36	PLF pour 2020 - Art. 36	2019-11-21 18:21:00	2019-11-21 18:30:00	\N	\N	42	0	\N	\N
424871	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Art. 1ere partie	PLF pour 2020 - Art. 1ere partie	2019-11-22 14:31:00	2019-11-22 19:57:00	\N	\N	51	0	\N	\N
424872	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Art. 1ere partie	PLF pour 2020 - Art. 1ere partie	2019-11-22 21:31:00	2019-11-23 00:33:00	\N	\N	41	0	\N	\N
424873	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Art. 1ere partie	PLF pour 2020 - Art. 1ere partie	2019-11-23 09:36:00	2019-11-23 12:06:00	\N	\N	48	0	\N	\N
424874	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Art. 1ere partie	PLF pour 2020 - Art. 1ere partie	2019-11-23 14:45:00	2019-11-23 20:05:00	\N	\N	52	0	\N	\N
424875	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Art. 1ere partie	PLF pour 2020 - Art. 1ere partie	2019-11-23 21:38:00	2019-11-24 00:41:00	\N	\N	24	0	\N	\N
424878	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Art. 1ere partie	PLF pour 2020 - Art. 1ere partie	2019-11-24 09:30:00	2019-11-24 13:00:00	\N	\N	0	0	\N	\N
424879	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Art. 1ere partie	PLF pour 2020 - Art. 1ere partie	2019-11-24 14:30:00	2019-11-24 20:00:00	\N	\N	0	0	\N	\N
424880	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Art. 1ere partie	PLF pour 2020 - Art. 1ere partie	2019-11-24 21:30:00	2019-11-25 00:00:00	\N	\N	0	0	\N	\N
424881	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Art. 1ere partie	PLF pour 2020 - Art. 1ere partie	2019-11-25 10:01:00	2019-11-25 13:01:00	\N	\N	44	0	\N	\N
424882	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Art. 1ere partie	PLF pour 2020 - Art. 1ere partie	2019-11-25 14:31:00	2019-11-25 19:57:00	\N	\N	71	0	\N	\N
424883	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2020 - Art. 1ere partie	PLF pour 2020 - Art. 1ere partie	2019-11-25 21:31:00	2019-11-26 00:56:00	\N	\N	51	0	\N	\N
424897	COM_SPECIALE	PLENIERE	\N	BIOETHIQUE	\N	Audition de représentants de courants de pensée	\N	2019-11-07 10:15:00	2019-11-07 12:25:00	2019-11-07 12:29:16	2019-11-07 14:03:24	17	0	\N	\N
424934	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Lutte contre la haine sur internet	\N	2019-11-06 17:40:00	2019-11-06 18:50:00	\N	\N	1	0	\N	\N
424961	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2020 - Mission Solidarité	\N	2019-11-07 09:00:00	2019-11-07 09:45:00	\N	\N	1	0	\N	\N
424962	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2020 - Mission Solidarité	\N	2019-11-06 14:00:00	2019-11-06 14:45:00	\N	\N	1	0	\N	\N
424963	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2020 - Mission Solidarité	\N	2019-11-06 16:45:00	2019-11-06 19:50:00	\N	\N	1	0	\N	\N
424982	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Enseignement scolaire	PLF 2020 - Crédits Enseignement scolaire	2019-11-07 09:15:00	2019-11-07 10:00:00	\N	\N	2	0	\N	\N
424992	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Audiovisuel	PLF 2020 - Crédits Audiovisuel	2019-11-06 16:30:00	2019-11-06 17:30:00	\N	\N	2	0	\N	\N
424993	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Audiovisuel	PLF 2020 - Crédits Audiovisuel	2019-11-06 17:30:00	2019-11-06 18:30:00	\N	\N	1	0	\N	\N
424997	ETUDES	AUCUNE	\N	\N	\N	GE numérique	\N	2019-11-05 18:25:00	2019-11-05 19:30:00	\N	\N	5	0	\N	1008
425005	COM_ENQUETE	AUTRE	\N	LUBRIZOL	\N	Réunion de commission	\N	2019-11-12 14:30:00	2019-11-12 15:55:00	2019-11-12 16:33:04	2019-11-12 17:34:38	11	0	\N	\N
425006	COM_ENQUETE	AUTRE	\N	LUBRIZOL	\N	Réunion de commission	\N	2019-11-12 09:05:00	2019-11-12 11:05:00	2019-11-12 11:22:05	2019-11-12 17:34:37	13	0	\N	\N
425029	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PPL draperie tricolore sur cercueils	\N	2019-11-05 17:30:00	2019-11-05 18:30:00	\N	\N	1	0	\N	\N
425031	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PPL draperie tricolore sur cercueils	\N	2019-11-07 08:45:00	2019-11-07 11:30:00	\N	\N	1	0	\N	\N
425038	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat gestion des milieux aquatiques	Débat gestion des milieux aquatiques	2019-11-19 18:04:00	2019-11-19 19:30:00	\N	\N	67	0	\N	\N
425088	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Auditions Économie - MM. Serge Babary et Martial Bourquin	PJLF 2020 - Auditions Économie - MM. Serge Babary et Martial Bourquin	2019-11-06 10:00:00	2019-11-06 11:30:00	\N	\N	2	0	\N	\N
425091	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Industrie - M. Martial Bourquin	\N	2019-11-06 14:00:00	2019-11-06 14:45:00	\N	\N	1	0	\N	\N
425093	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Industrie - M. Martial Bourquin	\N	2019-11-07 11:30:00	2019-11-07 12:15:00	\N	\N	1	0	\N	\N
425095	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Industrie - M. Martial Bourquin	\N	2019-11-07 14:00:00	2019-11-07 14:50:00	\N	\N	1	0	\N	\N
425097	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Industrie - M. Martial Bourquin	\N	2019-11-07 14:55:00	2019-11-07 15:30:00	\N	\N	1	0	\N	\N
425099	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2020 - Missions Sécurités et AGTE	PLF pour 2020 - Missions Sécurités et AGTE	2019-11-12 14:35:00	2019-11-12 17:10:00	2019-11-12 19:48:21	2019-11-13 14:50:30	35	0	\N	\N
425101	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Avis Agriculture - M. Duplomb, Mme Férat, M. Tissot	PJLF 2020 - Avis Agriculture - M. Duplomb, Mme Férat, M. Tissot	2019-11-05 16:30:00	2019-11-05 17:15:00	\N	\N	0	0	\N	\N
437594	GIA	AUCUNE	\N	\N	\N	Ministère de l'Europe et des affaires étrangères	\N	2019-12-04 08:00:00	2019-12-04 09:00:00	\N	\N	3	0	851	\N
425102	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Avis Agriculture - M. Duplomb, Mme Férat, M. Tissot	PJLF 2020 - Avis Agriculture - M. Duplomb, Mme Férat, M. Tissot	2019-11-05 15:45:00	2019-11-05 16:30:00	\N	\N	5	0	\N	\N
425103	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Avis Agriculture - M. Duplomb, Mme Férat, M. Tissot	PJLF 2020 - Avis Agriculture - M. Duplomb, Mme Férat, M. Tissot	2019-11-06 14:00:00	2019-11-06 15:00:00	\N	\N	5	0	\N	\N
425104	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Avis Agriculture - M. Duplomb, Mme Férat, M. Tissot	PJLF 2020 - Avis Agriculture - M. Duplomb, Mme Férat, M. Tissot	2019-11-06 16:30:00	2019-11-06 17:30:00	\N	\N	4	0	\N	\N
425106	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Avis Agriculture - M. Duplomb, Mme Férat, M. Tissot	PJLF 2020 - Avis Agriculture - M. Duplomb, Mme Férat, M. Tissot	2019-11-06 17:00:00	2019-11-06 17:30:00	\N	\N	4	0	\N	\N
425127	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	PLF pour 2020 - Avis AGTE - Déplacement en Haute-Garonne 	PLF pour 2020 - Avis AGTE - Déplacement en Haute-Garonne 	2019-11-04 08:30:00	2019-11-04 19:00:00	\N	\N	1	0	\N	\N
425129	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2020 - Avis Administration pénitentiaire	PLF pour 2020 - Avis Administration pénitentiaire	2019-11-12 18:00:00	2019-11-12 19:00:00	\N	\N	1	0	\N	\N
425130	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2020 - Mission Travail et Emploi	PLF pour 2020 - Mission Travail et Emploi	2019-11-13 16:35:00	2019-11-13 17:40:00	2019-11-14 09:32:18	2019-11-14 15:31:39	22	0	\N	\N
425131	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition PLF 2020 - avis administration pénitentiaire	\N	2019-10-30 14:00:00	2019-10-30 15:00:00	\N	\N	1	0	\N	\N
425132	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition PLF 2020 - avis administration pénitentiaire	\N	2019-10-30 16:00:00	2019-10-30 19:15:00	\N	\N	1	0	\N	\N
483603	COM_PERMANENTE	AUTRE	\N	CAE	\N	\N	\N	2020-07-08 11:05:00	2020-07-08 11:20:00	2020-07-08 12:08:59	2020-07-08 17:02:38	32	3	\N	\N
483672	COM_ENQUETE	PLENIERE	\N	AUTOROUT	\N	CE Concessions autoroutières - Ségolène ROYAL / Dominique de VILLEPIN	CE Concessions autoroutières - Audition de Mme Ségolène ROYAL puis de M. Dominique de VILLEPIN	2020-07-09 14:05:00	2020-07-09 17:20:00	2020-07-13 10:37:30	\N	8	0	\N	\N
483916	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition médiateur des relations comerciales agricoles	GS EGALIM - Audition médiateur des relations commerciales agricoles	2020-07-08 13:30:00	2020-07-08 15:00:00	\N	\N	7	0	\N	\N
484141	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questurec	Conseil de Questure	2020-06-30 14:20:00	2020-06-30 15:55:00	\N	\N	3	0	\N	\N
484505	COM_ENQUETE	AUDRAP	\N	AUTOROUT	\N	CE concessions autoroutières - ASCA	CE concessions autoroutières - ASCA	2020-07-16 11:00:00	2020-07-16 11:40:00	\N	\N	1	0	\N	\N
484506	COM_ENQUETE	AUDRAP	\N	AUTOROUT	\N	CE concessions autoroutières - Observatoire MAP / Spie Batignolles	CE concessions autoroutières - Observatoire MAP / Spie Batignolles	2020-07-16 16:45:00	2020-07-16 18:05:00	\N	\N	1	0	\N	\N
484555	SEANCE_PLENIERE	DECL_GVT	\N	\N	\N	Déclaration de politique générale	Déclaration de politique générale	2020-07-15 15:00:00	2020-07-15 15:55:00	\N	\N	160	0	\N	\N
484556	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLFR pour 2020 (3) - Examen Amendements de séance	PLFR pour 2020 (3) - Examen Amendements de séance	2020-07-17 09:00:00	2020-07-17 10:35:00	2020-07-17 12:17:08	2020-07-17 18:42:49	24	1	\N	\N
484558	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLFR pour 2020 (3)-Examen Rapport - CNV France-Luxembourg-Examen Rapport -Controles comm.	PLFR pour 2020 (3)-Examen Rapport - CNV France-Luxembourg-Examen Rapport -Controles comm.	2020-07-15 09:30:00	2020-07-15 12:00:00	2020-07-16 17:59:14	2020-07-17 18:42:48	26	2	\N	\N
484559	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2020-07-15 11:01:00	2020-07-15 11:26:00	\N	\N	12	0	\N	\N
484566	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2020-07-15 10:00:00	2020-07-15 11:35:00	2020-07-15 16:01:41	2020-07-15 18:38:42	16	0	\N	\N
484567	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule tourisme  UCPA	\N	2020-07-08 14:00:00	2020-07-08 15:00:00	\N	\N	2	0	\N	\N
484570	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions cellule tourisme	\N	2020-07-08 16:30:00	2020-07-08 18:45:00	\N	\N	2	0	\N	\N
484596	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - L'IHEDN et L'INHESJ - IHEDN	Contrôle 2020 - L'IHEDN et L'INHESJ - IHEDN	2020-07-07 16:30:00	2020-07-07 18:00:00	\N	\N	1	0	\N	\N
484818	COM_PERMANENTE	AUTRE	\N	CAE	\N	\N	\N	2020-07-15 11:05:00	2020-07-15 11:15:00	2020-07-15 11:28:49	2020-07-15 18:38:43	11	2	\N	\N
484872	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du jeudi 16 juillet 2020	\N	2020-07-16 08:35:00	2020-07-16 10:05:00	2020-07-16 10:20:43	2020-07-16 17:10:56	13	0	\N	\N
484873	COM_EURO	AUTRE	\N	AFEU	\N	2e réunion du 16 juillet	\N	2020-07-16 12:35:00	2020-07-16 13:45:00	2020-07-16 15:52:49	2020-07-16 17:10:57	8	0	\N	\N
484900	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFR pour 2020 (3) - Mission "AEE" - AEFE	PLFR pour 2020 (3) - Mission "AEE" - AEFE	2020-07-06 09:30:00	2020-07-06 10:30:00	\N	\N	1	0	\N	\N
484906	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - DGRI	Audition Pollution plastique - DGRI	2020-07-16 15:45:00	2020-07-16 16:45:00	\N	\N	1	0	\N	\N
484909	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - LEEM	Audition Pollution plastique - LEEM	2020-07-16 16:45:00	2020-07-16 17:45:00	\N	\N	1	0	\N	\N
486043	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2020-07-15 11:05:00	2020-07-15 12:40:00	\N	\N	2	0	\N	\N
486046	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière - Audition de M. Jean-Pierre Bourguignon	Réunion plénière - Audition de M. Jean-Pierre Bourguignon	2020-07-23 09:40:00	2020-07-23 11:15:00	\N	\N	5	0	\N	\N
486047	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - SERAMM	Audition Pollution plastique - SERAMM	2020-07-17 08:30:00	2020-07-17 09:30:00	\N	\N	2	0	\N	\N
486050	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - Groupe ADP	Audition Pollution plastique - Groupe ADP	2020-07-17 14:00:00	2020-07-17 15:00:00	\N	\N	2	0	\N	\N
486053	DELEGATION	AUDRAP	\N	\N	206	Audition Pollution plastique - Table ronde	Audition Pollution plastique - Table ronde	2020-07-17 15:00:00	2020-07-17 17:00:00	\N	\N	2	0	\N	\N
486396	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLeniere impromptue	\N	2020-07-18 18:55:00	2020-07-18 19:20:00	2020-07-18 23:09:01	2020-07-20 16:30:22	20	0	\N	\N
487038	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	GT Expertise psychiatrique en matière pénale	GT Expertise psychiatrique en matière pénale	2020-07-28 09:15:00	2020-07-28 10:00:00	\N	\N	2	0	\N	\N
487170	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Restitution des oeuvres d'art	MI Restitution des oeuvres d'art	2020-07-21 14:30:00	2020-07-21 15:45:00	\N	\N	6	0	\N	\N
487177	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	MI Restitution des oeuvres d'art	MI Restitution des oeuvres d'art	2020-07-21 16:15:00	2020-07-21 17:45:00	\N	\N	4	0	\N	\N
488066	ETUDES	AUCUNE	\N	\N	\N	Présentation rapport de mission déplacement îles éparses	Présentation rapport de mission déplacement îles éparses	2020-07-22 16:30:00	2020-07-22 17:30:00	\N	\N	6	0	\N	938
488687	COM_ENQUETE	PLENIERE	\N	PANDEMIE	\N	Audition des associations de patients	\N	2020-09-08 10:30:00	2020-09-08 13:00:00	2020-09-08 14:32:58	2020-09-09 17:42:14	21	0	\N	\N
488688	COM_ENQUETE	PLENIERE	\N	PANDEMIE	\N	Audition du Conseil national professionnel de gériatrie	\N	2020-09-08 17:30:00	2020-09-08 18:40:00	2020-09-09 16:58:05	2020-09-09 17:42:13	18	0	\N	\N
488689	COM_ENQUETE	PLENIERE	\N	PANDEMIE	\N	Audition sur la situation en Asie	\N	2020-09-09 09:05:00	2020-09-09 12:00:00	2020-09-09 17:03:02	2020-09-09 17:42:11	18	0	\N	\N
488690	COM_ENQUETE	PLENIERE	\N	PANDEMIE	\N	Audition du colonel Bruno Cunat, ancien commandant de la base aérienne 110 de Creil	\N	2020-09-09 14:30:00	2020-09-09 15:35:00	2020-09-09 15:39:52	2020-09-09 17:42:10	13	0	\N	\N
488691	COM_ENQUETE	PLENIERE	\N	PANDEMIE	\N	Table ronde sur la politique de dépistage	\N	2020-09-10 10:05:00	2020-09-10 12:45:00	2020-09-10 12:43:25	2020-09-10 16:13:37	15	0	\N	\N
488692	COM_ENQUETE	PLENIERE	\N	PANDEMIE	\N	Table ronde sur les équipements de protection	\N	2020-09-10 14:00:00	2020-09-10 15:55:00	2020-09-10 15:57:26	2020-09-10 16:13:38	14	0	\N	\N
488693	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition Cour des comptes	\N	2020-09-08 14:30:00	2020-09-08 15:55:00	2020-09-08 15:57:10	2020-09-09 17:39:40	17	0	\N	\N
489228	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Territoire zéro chômeur de longue durée	\N	2020-09-15 10:00:00	2020-09-15 12:00:00	\N	\N	2	0	\N	\N
489231	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Territoire zéro chômeur de longue durée	\N	2020-09-15 15:30:00	2020-09-15 17:30:00	\N	\N	3	0	\N	\N
489264	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT 2020 Le Grand Paris Express - M. Thierry DALLARD - Directoire Société du Grand Paris	GT 2020 Le Grand Paris Express - M. Thierry DALLARD - Directoire Société du Grand Paris	2020-09-16 10:00:00	2020-09-16 12:00:00	\N	\N	9	0	\N	\N
489274	MISSION	AUCUNE	\N	ILLECTRONISM	\N	Examen du rapport d'information	\N	2020-09-17 14:10:00	2020-09-17 14:51:00	2020-09-17 15:58:33	2020-09-18 17:16:23	4	0	\N	\N
489339	COM_ENQUETE	PLENIERE	\N	PANDEMIE	\N	Audition de M. Xavier Bertrand, ancien ministre des solidarités et de la santé	\N	2020-09-22 09:10:00	2020-09-22 10:30:00	2020-09-22 10:39:20	2020-09-22 17:20:49	22	0	\N	\N
489340	COM_ENQUETE	PLENIERE	\N	PANDEMIE	\N	Table ronde sur les aspects numériques	\N	2020-09-22 10:35:00	2020-09-22 12:10:00	2020-09-22 12:14:37	2020-09-22 17:20:49	13	0	\N	\N
489341	COM_ENQUETE	PLENIERE	\N	PANDEMIE	\N	Audition de Mme Florence Parly, ministre des armées	\N	2020-09-22 15:00:00	2020-09-22 16:45:00	2020-09-22 16:46:57	2020-09-22 17:20:48	20	0	\N	\N
489342	COM_ENQUETE	PLENIERE	\N	PANDEMIE	\N	Audition de M. Christophe Castaner, ancien ministre de l'Intérieur	\N	2020-09-22 17:30:00	2020-09-22 18:50:00	2020-09-22 18:48:38	2020-09-23 16:47:40	14	0	\N	\N
489343	COM_ENQUETE	PLENIERE	\N	PANDEMIE	\N	Table ronde sur la communication de crise	\N	2020-09-23 09:30:00	2020-09-23 12:15:00	2020-09-23 12:14:07	2020-09-23 16:47:41	20	0	\N	\N
489344	COM_ENQUETE	PLENIERE	\N	PANDEMIE	\N	Audition de Mme Agnès Buzyn, ancienne ministre des solidarités et de la santé	\N	2020-09-23 15:00:00	2020-09-23 18:40:00	2020-09-28 09:13:27	2020-09-28 18:08:53	24	0	\N	\N
489345	COM_ENQUETE	PLENIERE	\N	PANDEMIE	\N	Audition de M. Olivier Véran, ministre des solidarités et de la santé	\N	2020-09-24 10:00:00	2020-09-24 13:10:00	2020-09-24 13:11:38	2020-09-24 16:42:03	23	0	\N	\N
489444	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Prévention de la perte d'autonomie - Audition de Présanse	\N	2020-09-16 11:00:00	2020-09-16 12:00:00	\N	\N	1	0	\N	\N
376741	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-05-15 09:50:00	2019-05-15 12:55:00	2019-05-15 14:37:00	2019-05-15 17:21:54	43	0	\N	\N
376743	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-05-15 17:00:00	2019-05-15 18:55:00	2019-05-16 09:52:01	2019-05-16 15:00:10	27	0	\N	\N
379888	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPRE Clarifier et actualiser le Règlement du Sénat	PPRE Clarifier et actualiser le Règlement du Sénat	2019-05-14 17:00:00	2019-05-14 17:10:00	\N	\N	1	0	\N	\N
379890	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPRE Clarifier et actualiser le Règlement du Sénat	PPRE Clarifier et actualiser le Règlement du Sénat	2019-05-14 17:40:00	2019-05-14 18:10:00	\N	\N	1	0	\N	\N
379892	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPRE Clarifier et actualiser le Règlement du Sénat	PPRE Clarifier et actualiser le Règlement du Sénat	2019-05-15 14:45:00	2019-05-15 15:15:00	\N	\N	2	0	\N	\N
379895	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPRE Clarifier et actualiser le Règlement du Sénat	PPRE Clarifier et actualiser le Règlement du Sénat	2019-05-15 15:15:00	2019-05-15 17:30:00	\N	\N	1	0	\N	\N
391367	GIA	AUCUNE	\N	\N	\N	célébration anniversaire Dalaï Lama	célébration anniversaire Dalaï Lama	2019-07-03 17:00:00	2019-07-03 19:00:00	\N	\N	2	0	634	\N
393066	ETUDES	AUCUNE	\N	\N	\N	Application loi ELAN	Application loi ELAN	2019-06-20 08:00:00	2019-06-20 10:00:00	\N	\N	13	0	\N	908
393776	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteur (Neurosciences) M. Olivier Oullier	Audition rapporteur (Neurosciences) M. Olivier Oullier	2019-07-03 17:00:00	2019-07-03 18:00:00	\N	\N	1	0	\N	\N
393777	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière - Examen de notes scientifiques	Réunion plénière - Examen de notes scientifiques	2019-07-18 09:15:00	2019-07-18 12:25:00	\N	\N	9	0	\N	\N
406928	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-09-25 19:40:00	2019-09-25 20:00:00	2019-09-25 20:08:55	2019-09-26 16:34:39	24	1	\N	\N
407151	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de Mme Anne-Claire Rafflegeau, porte-parole du collectif inter urgences	\N	2019-10-03 10:35:00	2019-10-03 11:50:00	2019-10-03 11:49:27	2019-10-03 15:58:42	20	0	\N	\N
407184	DELEGATION	AUDRAP	\N	\N	DSOM	Rencontre des représentants de l'audiovisuel privé	\N	2019-09-25 16:15:00	2019-09-25 17:15:00	\N	\N	2	0	\N	\N
410128	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière	Réunion plénière	2019-10-03 08:30:00	2019-10-03 10:00:00	2019-10-03 12:32:22	\N	16	0	\N	\N
410160	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Difficultés de recrutement et formation	Difficultés de recrutement et formation - Le Bon Coin	2019-09-26 09:05:00	2019-09-26 10:15:00	\N	\N	3	0	\N	\N
410164	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Difficultés de recrutement et formation	Difficultés de recrutement et formation - M. Patrice  PAGNY	2019-09-26 10:40:00	2019-09-26 11:40:00	\N	\N	3	0	\N	\N
410168	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Difficultés de recrutement et formation	Difficultés de recrutement et formation - Pôle Emploi	2019-10-03 11:40:00	2019-10-03 13:10:00	\N	\N	3	0	\N	\N
427836	ETUDES	AUCUNE	\N	\N	\N	Visite Mémorial de la Shoah	Visite Mémorial de la Shoah	2019-11-14 08:30:00	2019-11-14 10:30:00	\N	\N	5	0	\N	928
375512	CMP	AUTRE	\N	POLYNESIE3	\N	PJL Dispositions institutionnelles en Polynésie française	PJL Dispositions institutionnelles en Polynésie française	2019-05-07 09:46:00	2019-05-07 09:55:00	\N	\N	9	0	\N	\N
438976	COM_ENQUETE	PLENIERE	\N	RADICALI	\N	Audition de M. Bernard ROUGIER	\N	2019-12-17 14:35:00	2019-12-17 16:30:00	2019-12-17 16:06:49	2019-12-17 16:50:33	12	0	\N	\N
438997	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions de M. Montaugé et Mme Noël-PPL Libre choix du consommateur dans le cyberespace	Audition de représentants de Syntec Numérique et Tech in France	2019-12-11 14:00:00	2019-12-11 14:45:00	\N	\N	2	0	\N	\N
439006	ETUDES	AUTRE	\N	\N	\N	Audition plénière - GE 2018 Énergie	\N	2019-12-11 12:30:00	2019-12-11 14:00:00	\N	\N	0	0	\N	906
439298	COM_ENQUETE	PLENIERE	\N	LUBRIZOL	\N	Réunion de commission	\N	2019-12-11 16:30:00	2019-12-11 18:55:00	2019-12-11 18:59:53	2019-12-12 16:23:00	11	0	\N	\N
439491	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe d'amitié France-Mexique-Pays d'Amérique centrale	Assemblée générale du groupe d'amitié France-Mexique-Pays d'Amérique centrale	2019-12-11 14:00:00	2019-12-11 14:45:00	\N	\N	9	0	643	\N
441311	ETUDES	AUCUNE	\N	\N	\N	Réunion	Réunion	2019-12-18 08:30:00	2019-12-18 09:30:00	\N	\N	11	0	\N	934
441695	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition de M. Montaugé et Mme Noël-PPL Libre choix du consommateur dans le cyberespace	\N	2019-12-19 10:15:00	2019-12-19 11:00:00	\N	\N	2	0	\N	\N
441701	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition PPL Droits sociaux des travailleurs numériques - Coopératives	\N	2019-12-18 16:30:00	2019-12-18 17:30:00	\N	\N	1	0	\N	\N
441702	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition PPL Droits sociaux des travailleurs numériques - Metalaw	\N	2019-12-18 17:30:00	2019-12-18 18:30:00	\N	\N	1	0	\N	\N
441703	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition PPL Droits sociaux des travailleurs numériques - P. Vion-Dury	\N	2019-12-18 18:30:00	2019-12-18 19:30:00	\N	\N	1	0	\N	\N
441704	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition PPL Droits sociaux des travailleurs numériques - S. Vernac	\N	2019-12-19 10:30:00	2019-12-19 11:30:00	\N	\N	1	0	\N	\N
441705	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition PPL Droits sociaux des travailleurs numériques - Conseil national du numérique	\N	2019-12-19 11:45:00	2019-12-19 12:45:00	\N	\N	1	0	\N	\N
441706	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition PPL Droits sociaux des travailleurs numériques - Anact	\N	2019-12-19 16:30:00	2019-12-19 17:30:00	\N	\N	1	0	\N	\N
441707	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition PPL Droits sociaux des travailleurs numériques - Avocats	\N	2019-12-20 09:15:00	2019-12-20 10:00:00	\N	\N	1	0	\N	\N
441708	COM_SPECIALE	AUDRAP	\N	BIOETHIQUE	\N	Audition Mme Jourda - M. François Molins	\N	2019-12-19 08:00:00	2019-12-19 08:40:00	\N	\N	1	0	\N	\N
441709	COM_SPECIALE	AUDRAP	\N	BIOETHIQUE	\N	Audition Mme Jourda - Cour de cassation	\N	2019-12-19 08:45:00	2019-12-19 09:30:00	\N	\N	1	0	\N	\N
441717	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition PPL Droits sociaux des travailleurs numériques - FX Oliveau	\N	2019-12-19 15:30:00	2019-12-19 16:30:00	\N	\N	1	0	\N	\N
441731	DELEGATION	AUCUNE	\N	\N	211	Audition de Mme Sylvie Pierre-Brossolette	Audition de Mme Sylvie Pierre-Brossolette	2020-01-30 09:45:00	2020-01-30 11:00:00	2020-01-30 12:33:15	\N	4	0	\N	\N
443160	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Améliorer les droits des usagers des transports en cas de grève	\N	2020-01-07 17:00:00	2020-01-07 18:00:00	\N	\N	1	0	\N	\N
443162	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Améliorer les droits des usagers des transports en cas de grève	\N	2020-01-08 13:30:00	2020-01-08 14:30:00	\N	\N	1	0	\N	\N
443676	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de M. François VILLEROY de GALHAU gouverneur de la Banque de France	Audition de M. François VILLEROY de GALHAU gouverneur de la Banque de France	2020-01-15 10:10:00	2020-01-15 12:05:00	2020-01-15 15:46:34	2020-01-15 17:49:11	33	0	\N	\N
443748	QUESTURE	AUCUNE	\N	\N	\N	Cconseil de Questure	Conseil de Questure	2019-10-29 15:05:00	2019-10-29 18:40:00	\N	\N	3	0	\N	\N
443752	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2019-11-12 15:00:00	2019-11-12 16:20:00	\N	\N	3	0	\N	\N
443756	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questire	2019-11-05 14:40:00	2019-11-05 16:45:00	\N	\N	3	0	\N	\N
443839	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition de M. Montaugé et Mme Noël-PPL Libre choix du consommateur dans le cyberespace	\N	2020-01-08 14:00:00	2020-01-08 15:00:00	\N	\N	2	0	\N	\N
443840	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions de M. Montaugé et Mme Noël-PPL Libre choix du consommateur dans le cyberespace	\N	2020-01-08 16:30:00	2020-01-08 18:30:00	\N	\N	3	0	\N	\N
454928	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2020-02-19 09:30:00	2020-02-19 11:35:00	2020-02-19 12:38:56	2020-02-19 16:09:42	33	0	\N	\N
455350	ETUDES	AUTRE	\N	\N	\N	Table ronde "Les usages de l'hydrogène"	\N	2020-02-19 08:00:00	2020-02-19 09:30:00	\N	\N	18	0	\N	906
455456	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 26 février 2020 - 13h30	Réunion du 26 février 2020 - 13h30	2020-02-26 13:30:00	2020-02-26 14:55:00	2020-02-26 16:03:58	2020-02-26 17:30:09	15	0	\N	\N
455457	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission du 26 février 2020	\N	2020-02-26 16:37:00	2020-02-26 18:26:00	2020-02-27 11:13:59	2020-02-27 14:39:39	13	0	\N	\N
456093	COM_ENQUETE	PLENIERE	\N	SOLS	\N	Réunion plénière CE Pollution des sols	\N	2020-02-19 16:51:00	2020-02-19 17:37:00	2020-02-21 11:44:54	2020-02-21 11:45:27	15	0	\N	\N
456221	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	GT Métier d'enseignant	GT Métier d'enseignant	2020-02-19 16:30:00	2020-02-19 17:30:00	\N	\N	4	0	\N	\N
456228	COM_PERMANENTE	DEPLACEMENT	\N	AFCL	\N	Déplacement au Mexique	Déplacement de la commission au Mexique	2019-09-07 08:00:00	2019-09-12 20:00:00	\N	\N	6	0	\N	\N
456406	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Auditions rapporteurs - MI Travailleurs indépendants	\N	2020-02-18 16:00:00	2020-02-18 18:45:00	\N	\N	2	0	\N	\N
456407	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Auditions rapporteurs - MI Travailleurs indépendants	\N	2020-02-18 14:00:00	2020-02-18 16:00:00	\N	\N	3	0	\N	\N
456413	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL congé pour le deuil d'un enfant - Mme Doineau/Organisations patronales	\N	2020-02-19 13:30:00	2020-02-19 14:30:00	\N	\N	2	0	\N	\N
456414	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL congé pour le deuil d'un enfant - Mme Doineau/Guy Bricout	\N	2020-02-19 16:30:00	2020-02-19 17:30:00	\N	\N	2	0	\N	\N
457006	GIA	AUCUNE	\N	\N	\N	Déplacement Jordanie 8-14 février 2020	Déplacement en Jordanie du GIA France-Jordanie du 8 au 14 février 2020	2020-02-08 15:35:00	2020-02-14 14:10:00	\N	\N	4	0	659	\N
459588	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2019-10-03 09:30:00	2019-10-03 12:30:00	\N	\N	2	0	\N	\N
459593	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2019-11-13 17:30:00	2019-11-13 18:45:00	\N	\N	2	0	\N	\N
441700	COM_PERMANENTE	AUTRE	\N	FINC	\N	PPL n°154 Régime des catastrophes naturelles - Examen Rapport et établissement texte	PPL n°154 Régime des catastrophes naturelles - Examen Rapport et établissement texte	2020-01-08 10:05:00	2020-01-08 11:20:00	2020-01-08 11:49:29	2020-01-08 12:03:34	38	0	\N	\N
459659	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2020-02-18 12:30:00	2020-02-18 16:30:00	\N	\N	1	0	\N	\N
489107	MISSION	AUCUNE	\N	GUYANE	\N	Examen du projet de rapport MI Guyane	\N	2020-09-15 11:00:00	2020-09-15 11:50:00	2020-09-15 11:48:14	2020-09-15 17:25:54	9	0	\N	\N
489108	MISSION	AUDRAP	\N	GUYANE	\N	Direction générale des outre-mer	\N	2020-09-15 09:30:00	2020-09-15 11:00:00	\N	\N	5	0	\N	\N
489173	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière	\N	2020-09-23 14:30:00	2020-09-23 16:25:00	2020-09-25 10:35:14	\N	10	0	\N	\N
493174	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Mise sur le marché de certains produits phytopharmaceutiques	PJL Mise sur le marché de certains produits phytopharmaceutiques	2020-10-13 18:00:00	2020-10-13 18:30:00	\N	\N	9	0	\N	\N
493192	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2021 - Branche autonomie - Audition de la FHF	\N	2020-10-13 14:30:00	2020-10-13 15:30:00	\N	\N	2	0	\N	\N
493193	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2021 - Branche autonomie - Audition de la Fehap	\N	2020-10-13 15:30:00	2020-10-13 16:30:00	\N	\N	2	0	\N	\N
493194	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2021 - Branche autonomie - Audition de l'UNIOPSS	\N	2020-10-13 17:30:00	2020-10-13 18:30:00	\N	\N	2	0	\N	\N
493227	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF2021 Nomination RS / Designation CMP Ddadue / Examen AMDTS DETR / PLF 2021 Rapports	PLF2021 Nomination RS / Designation CMP Ddadue / Examen AMDTS DETR / PLF 2021 Rapports AC et Sports et Audition Économie	2020-10-21 09:05:00	2020-10-21 12:55:00	2020-10-21 19:21:09	2020-10-22 18:43:04	42	0	\N	\N
493289	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Sécurités - Sécurité Civile - CNSIS 	PLF pour 2021 - Sécurités - Sécurité Civile - CNSIS 	2020-10-14 15:45:00	2020-10-14 16:45:00	\N	\N	1	0	\N	\N
493294	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2021 - Branche Famille	\N	2020-10-15 09:00:00	2020-10-15 11:00:00	\N	\N	1	0	\N	\N
493309	DELEGATION	AUDRAP	\N	\N	PROS	Audition du Comité des constructeurs français d'automobiles (CCFA)	Audition de Mme Louise d'Harcourt	2020-10-22 15:30:00	2020-10-22 16:30:00	\N	\N	1	0	\N	\N
493310	DELEGATION	AUDRAP	\N	\N	PROS	Audition du Club des Villes et territoires cyclables	Audition du Club des Villes et territoires cyclables	2020-10-22 14:30:00	2020-10-22 15:30:00	\N	\N	1	0	\N	\N
493311	DELEGATION	AUDRAP	\N	\N	PROS	Audition de Mme Poulot Moreau	\N	2020-10-22 14:30:00	2020-10-22 15:30:00	\N	\N	1	0	\N	\N
493315	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2021 - Branche autonomie - Audition de l'UNAPEI	\N	2020-10-15 13:30:00	2020-10-15 14:30:00	\N	\N	2	0	\N	\N
493316	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2021 - Branche autonomie - Audition de l'UNA	\N	2020-10-15 14:30:00	2020-10-15 15:30:00	\N	\N	1	0	\N	\N
493327	COM_ENQUETE	PLENIERE	\N	PANDEMIE	\N	Audition de l'ANSM et de l'ANR	\N	2020-10-22 09:30:00	2020-10-22 11:00:00	2020-10-22 18:48:06	2020-10-22 18:48:12	16	0	\N	\N
493328	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Reconstitution du Bureau de la commission	\N	2016-10-07 12:03:00	2016-10-07 13:09:00	\N	\N	0	0	\N	\N
493329	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Reconstitution du Bureau de la commission des affaires étrangères	\N	2016-10-07 10:03:00	2016-10-07 11:09:00	\N	\N	0	0	\N	\N
493332	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2021 - Branche Équilibres financiers	\N	2020-10-13 17:00:00	2020-10-13 18:00:00	\N	\N	2	0	\N	\N
493335	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2021 - Branche Famille	\N	2020-10-15 14:30:00	2020-10-15 16:30:00	\N	\N	1	0	\N	\N
493411	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition Roselyne Bachelot (PJL Restitutions)	\N	2020-10-20 17:00:00	2020-10-20 18:30:00	2020-10-20 19:21:00	2020-10-21 14:42:13	29	0	\N	\N
493690	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2021 - Branche accidents du travail - Maladies professionnelles - Audition de l'ASMT	PLFSS 2021 - Branche accidents du travail - Maladies professionnelles - Audition de l'ASMT	2020-10-20 16:15:00	2020-10-20 17:00:00	\N	\N	2	0	\N	\N
493694	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2021 - Branche accidents du travail - Maladies professionnelles - Audition CCMSA	PLFSS 2021 - Branche accidents du travail - Maladies professionnelles - Audition CCMSA	2020-10-20 14:45:00	2020-10-20 15:30:00	\N	\N	2	0	\N	\N
493696	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2021 - Branche accidents du travail - Maladies professionnelles - Audition DSS	PLFSS 2021 - Branche accidents du travail - Maladies professionnelles - Audition DSS	2020-10-20 14:00:00	2020-10-20 14:45:00	\N	\N	2	0	\N	\N
494532	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière - Renouvellement du bureau de l'Office	Réunion plénière - Renouvellement du bureau de l'Office	2020-10-22 11:35:00	2020-10-22 12:30:00	\N	\N	15	0	\N	\N
494913	COM_ENQUETE	PLENIERE	\N	PANDEMIE	\N	Audition de M. Édouard Philippe	\N	2020-10-29 10:30:00	2020-10-29 12:40:00	2020-10-29 13:09:11	2020-10-30 18:13:38	14	0	\N	\N
495010	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition Blanquer Darmanin	\N	2020-10-22 11:30:00	2020-10-22 13:30:00	2020-10-22 16:41:11	2020-10-23 17:26:48	22	0	\N	\N
495035	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2021 - Mission R&D et Participation France Budget UE (Art31)	PLF pour 2021 - Mission R&D et Participation France Budget UE (Art31)	2020-10-27 15:00:00	2020-10-27 16:25:00	2020-10-27 17:25:21	2020-10-28 12:13:06	31	0	\N	\N
384261	ETUDES	AUCUNE	\N	\N	\N	Situation et avenir de l¿Office national des forêts	Situation et avenir de l¿Office national des forêts	2019-05-29 08:00:00	2019-05-29 09:30:00	\N	\N	11	0	\N	948
385068	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Transformation de la fonction publique	\N	2019-06-03 13:30:00	2019-06-03 17:00:00	\N	\N	2	0	\N	\N
396507	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Améliorer la trésorerie des associations	\N	2019-06-25 09:00:00	2019-06-25 10:30:00	\N	\N	1	0	\N	\N
398198	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Rencontre franco-allemande des présidents des commissions chargées de la défense	Rencontre franco-allemande des présidents des commissions chargées de la défense	2019-07-08 20:00:00	2019-07-09 18:00:00	\N	\N	1	0	\N	\N
425133	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLFR pour 2019-Examen Rapport - PLF pour 2020 Missions Culture, Médias et désignation CMP	PLFR pour 2019-Examen Rapport - PLF pour 2020 Missions Culture et Médias et désignation CMP	2019-11-14 14:35:00	2019-11-14 17:00:00	2019-11-14 17:11:14	2019-11-14 17:40:40	21	0	\N	\N
425138	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJLF 2020 - Avis Transports maritimes et fluviaux - Audition de M. Vaspart	PJLF 2020 - Avis Transports maritimes et fluviaux - Audition de M. Vaspart	2019-11-04 15:10:00	2019-11-04 16:30:00	\N	\N	1	0	\N	\N
425139	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJLF 2020 - Avis Transports maritimes et fluviaux - Audition de M. Vaspart	PJLF 2020 - Avis Transports maritimes et fluviaux - Audition de M. Vaspart	2019-11-04 16:30:00	2019-11-04 17:30:00	\N	\N	1	0	\N	\N
425144	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Avis Prévention des risques - M. Médevielle	\N	2019-11-04 14:30:00	2019-11-04 17:00:00	\N	\N	2	0	\N	\N
425147	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Prévention des risques - Auditions de M. Pierre Médevielle	\N	2019-11-05 16:30:00	2019-11-05 18:30:00	\N	\N	1	0	\N	\N
425150	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLF 2020 - Avis Fonction publique	PJLF 2020 - Avis Fonction publique	2019-11-05 17:00:00	2019-11-05 20:00:00	\N	\N	1	0	\N	\N
425151	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Première partie - Auditions Longeot	\N	2019-11-06 17:30:00	2019-11-06 18:30:00	\N	\N	1	0	\N	\N
425154	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Première partie - Auditions M. Longeot	\N	2019-11-07 09:00:00	2019-11-07 10:00:00	\N	\N	1	0	\N	\N
425156	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Première partie - Auditions M. Longeot	\N	2019-11-07 16:30:00	2019-11-07 17:15:00	\N	\N	1	0	\N	\N
425159	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - MIRES - Enseignement supérieur - Enseignement privé	PLF pour 2020 - MIRES - Enseignement supérieur - Enseignement privé	2019-11-05 09:30:00	2019-11-05 11:00:00	\N	\N	1	0	\N	\N
425161	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - MIRES - Recherche - DGE / CGDD / DGRI	PLF pour 2020 - MIRES - Recherche - DGE / CGDD / DGRI	2019-11-05 16:30:00	2019-11-05 18:45:00	\N	\N	1	0	\N	\N
425163	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - MIRES - Recherche - CNES	PLF pour 2020 - MIRES - Recherche - CNES	2019-11-07 15:30:00	2019-11-07 16:15:00	\N	\N	1	0	\N	\N
425165	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - MIRES - Recherche - CNRS	PLF pour 2020 - MIRES - Recherche - CNRS	2019-11-07 16:30:00	2019-11-07 17:15:00	\N	\N	1	0	\N	\N
425167	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Écologie - SER	PLF pour 2020 - Écologie - SER	2019-11-05 15:00:00	2019-11-05 16:00:00	\N	\N	1	0	\N	\N
425169	GIA	AUCUNE	\N	\N	\N	entretien avec MM. Albain Kurti, député, et Gashi Qendrim, ambassadeur du Kosovo	\N	2019-11-08 18:00:00	2019-11-08 18:30:00	\N	\N	0	0	674	\N
425225	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Écologie - Société du Grand Paris	PLF pour 2020 - Écologie - Société du Grand Paris	2019-11-05 17:00:00	2019-11-05 18:00:00	\N	\N	1	0	\N	\N
425227	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Rapport général - Air France-KLM	PLF pour 2020 - Rapport général - Air France-KLM	2019-11-07 09:00:00	2019-11-07 10:10:00	\N	\N	1	0	\N	\N
425229	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Écologie - Météo-France	PLF pour 2020 - Écologie - Météo-France	2019-11-07 14:30:00	2019-11-07 15:30:00	\N	\N	1	0	\N	\N
425231	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Sécurité routière - ANTAI	PLF pour 2020 - Sécurité routière - ANTAI	2019-11-06 14:00:00	2019-11-06 15:30:00	\N	\N	1	0	\N	\N
425235	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - APD - DG Trésor	PLF pour 2020 - APD - DG Trésor	2019-11-05 15:00:00	2019-11-05 16:30:00	\N	\N	2	0	\N	\N
425241	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - APD - Cabinet MEAE	PLF pour 2020 - APD - Cabinet MEAE	2019-11-05 17:30:00	2019-11-05 18:45:00	\N	\N	2	0	\N	\N
425244	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Rapport général - DGEC	PLF pour 2020 - Rapport général - DGEC	2019-11-06 18:45:00	2019-11-06 20:00:00	\N	\N	1	0	\N	\N
425247	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Écologie - ADEME	PLF pour 2020 - Écologie - ADEME	2019-11-05 17:00:00	2019-11-05 18:00:00	\N	\N	1	0	\N	\N
425249	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Écologie - DGALN	PLF pour 2020 - Écologie - DGALN	2019-11-06 14:00:00	2019-11-06 15:00:00	\N	\N	1	0	\N	\N
425251	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Écologie - OFB	PLF pour 2020 - Écologie - OFB	2019-11-06 18:00:00	2019-11-06 19:00:00	\N	\N	1	0	\N	\N
425257	ETUDES	AUCUNE	\N	\N	\N	Rencontre AN/Sénat Forêt	Rencontre AN / Sénat "la forêt en état d'urgence"	2019-11-07 14:00:00	2019-11-07 18:00:00	\N	\N	7	0	\N	948
425266	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Rapport général - Total	PLF pour 2020 - Rapport général - Total	2019-11-07 11:45:00	2019-11-07 12:45:00	\N	\N	1	0	\N	\N
425268	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Écologie - DGPR	PLF pour 2020 - Écologie - DGPR	2019-11-07 18:00:00	2019-11-07 19:00:00	\N	\N	1	0	\N	\N
425273	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 -  Médias - FNPS	PLF pour 2020 -  Médias - FNPS	2019-11-08 09:30:00	2019-11-08 10:30:00	\N	\N	1	0	\N	\N
425277	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Rapport général - Vinci	PLF pour 2020 - Rapport général - Vinci	2019-11-07 18:00:00	2019-11-07 19:00:00	\N	\N	1	0	\N	\N
425279	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJLF 2020 - Avis Transports maritimes et fluviaux - Audition de M. Vaspart	PJLF 2020 - Avis Transports maritimes et fluviaux - Audition de M. Vaspart	2019-11-07 17:00:00	2019-11-07 18:00:00	\N	\N	1	0	\N	\N
425281	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJLF 2020 - Avis Transports maritimes et fluviaux - Audition de M. Vaspart	PJLF 2020 - Avis Transports maritimes et fluviaux - Audition de M. Vaspart	2019-11-07 18:00:00	2019-11-07 19:00:00	\N	\N	1	0	\N	\N
425286	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Rapport général - Associations d'Élus	PLF pour 2020 - Rapport général - Associations d'Élus	2019-11-07 10:00:00	2019-11-07 11:30:00	\N	\N	4	0	\N	\N
425296	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Travail et emploi - ARF	PLF pour 2020 - Travail et emploi - ARF	2019-11-05 18:00:00	2019-11-05 19:00:00	\N	\N	2	0	\N	\N
425300	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJLF 2020 -Auditions Cohésion des territoires - M. de Nicolaÿ	PJLF 2020 -Auditions Cohésion des territoires - M. de Nicolaÿ	2019-11-08 18:00:00	2019-11-08 18:30:00	\N	\N	1	0	\N	\N
425301	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Travail et emploi - Cabinet Ministre Travail	PLF pour 2020 - Travail et emploi - Cabinet Ministre Travail	2019-11-06 11:00:00	2019-11-06 12:00:00	\N	\N	2	0	\N	\N
425308	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Rapport général - FBF	PLF pour 2020 - Rapport général - FBF	2019-11-05 18:30:00	2019-11-05 19:30:00	\N	\N	1	0	\N	\N
425317	ETUDES	DEPLACEMENT	\N	\N	\N	Déplacement en Alsace	Déplacement en Alsace	2019-11-06 20:00:00	2019-11-08 12:00:00	\N	\N	7	0	\N	909
425330	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Auditions Ville - Mme Annie Guillemot	PJLF 2020 - Auditions Ville - Mme Annie Guillemot	2019-11-06 17:30:00	2019-11-06 18:30:00	\N	\N	1	0	\N	\N
425336	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Auditions Ville - Mme Annie Guillemot	PJLF 2020 - Auditions Ville - Mme Annie Guillemot	2019-11-05 14:00:00	2019-11-05 15:00:00	\N	\N	1	0	\N	\N
425337	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Auditions Ville - Mme Annie Guillemot	PJLF 2020 - Auditions Ville - Mme Annie Guillemot	2019-11-05 16:00:00	2019-11-05 17:00:00	\N	\N	1	0	\N	\N
425339	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Auditions Ville - Mme Annie Guillemot	PJLF 2020 - Auditions Ville - Mme Annie Guillemot	2019-11-12 09:30:00	2019-11-12 12:30:00	\N	\N	1	0	\N	\N
425341	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2020 - Auditions Ville - Mme Annie Guillemot	PJLF 2020 - Auditions Ville - Mme Annie Guillemot	2019-11-05 10:30:00	2019-11-05 12:30:00	\N	\N	1	0	\N	\N
448496	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition GT Nouvelles formes de commerce - Rapporteur M. Babary	\N	2020-01-23 09:00:00	2020-01-23 10:30:00	\N	\N	2	0	\N	\N
452894	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Transparence - Auditions	\N	2020-02-05 13:45:00	2020-02-05 15:00:00	\N	\N	2	0	\N	\N
452902	COM_ENQUETE	DEPLACEMENT	\N	RADICALI	\N	Déplacement à la Préfecture de police de Paris	\N	2020-02-11 11:30:00	2020-02-11 15:00:00	\N	\N	4	0	\N	\N
453247	DELEGATION	AUCUNE	\N	\N	DSOM	Audition du directeur général des outre-mer	\N	2020-02-27 09:00:00	2020-02-27 10:30:00	\N	\N	4	0	\N	\N
453250	DELEGATION	AUCUNE	\N	\N	DSOM	Auditions Étude sur les enjeux financiers européens pour les outre-mer	\N	2020-03-05 08:35:00	2020-03-05 09:55:00	\N	\N	6	0	\N	\N
464194	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition par visioconférence de Mmes Florence Parly et Geneviève Darrieussecq	\N	2020-04-10 16:15:00	2020-04-10 18:05:00	\N	\N	43	0	\N	\N
464195	DELEGATION	AUDRAP	\N	\N	206	Audition de Mme Magali REGHEZZA	\N	2020-04-10 11:00:00	2020-04-10 12:20:00	\N	\N	2	0	\N	\N
464198	DELEGATION	AUDRAP	\N	\N	206	Audition de Institut de chimie de Clermont-Ferrand (ICCF) ¿ SIGMA Clermont	\N	2020-04-09 15:00:00	2020-04-09 18:10:00	\N	\N	2	0	\N	\N
464201	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de M. Nicolas Revel, directeur général de la CNAM (téléconférence)	\N	2020-04-15 10:00:00	2020-04-15 12:00:00	2020-04-15 16:44:38	\N	41	0	\N	\N
464202	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de Mme Muriel Pénicaud, ministre du travail (téléconférence)	\N	2020-04-07 17:00:00	2020-04-07 19:00:00	2020-04-15 17:31:51	\N	27	0	\N	\N
464203	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de Mme Marie-Anne Montchamp, présidente de la CNSA (téléconférence)	\N	2020-04-08 10:00:00	2020-04-08 12:00:00	2020-04-15 17:32:16	\N	31	0	\N	\N
464204	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de Sophie Cluzel, secrétaire d'État chargée des personnes handicapées (téléconf.)	\N	2020-04-10 11:00:00	2020-04-10 13:00:00	2020-04-15 17:00:05	\N	34	0	\N	\N
476868	MISSION	AUDRAP	\N	ILLECTRONISM	\N	Audition de l'ANDRH	Audition de l'ANDRH	2020-06-16 15:05:00	2020-06-16 15:55:00	\N	\N	6	0	\N	\N
477388	COM_EURO	AUTRE	\N	AFEU	\N	Audition de Mme A.de Montchalin, réunion post-conseil européen du 26 mars	Audition de Mme A.de Montchalin, réunion post-conseil européen du 26 mars	2020-03-27 10:00:00	2020-03-27 11:10:00	2020-06-11 11:39:58	\N	12	0	\N	\N
477419	COM_EURO	AUTRE	\N	AFEU	\N	Audition de M. Fabrice Leggeri, directeur exécutif de Frontex	Audition de M. Fabrice Leggeri, directeur exécutif de Frontex	2020-04-08 16:10:00	2020-04-08 17:30:00	2020-06-11 11:40:29	\N	12	0	\N	\N
489446	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Prévention de la perte d'autonomie - Audition du HCFPS	\N	2020-09-16 14:00:00	2020-09-16 15:00:00	\N	\N	1	0	\N	\N
489467	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2020-09-17 09:30:00	2020-09-17 17:00:00	\N	\N	1	0	\N	\N
489718	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLO Conseil économique, social et environnemental	\N	2020-09-22 10:00:00	2020-09-22 12:30:00	\N	\N	1	0	\N	\N
489720	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLO Conseil économique, social et environnemental	\N	2020-09-22 14:00:00	2020-09-22 15:30:00	\N	\N	1	0	\N	\N
489802	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Audition MI restitutions	\N	2020-09-22 17:00:00	2020-09-22 19:30:00	\N	\N	2	0	\N	\N
489805	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Audition MI restitutions	\N	2020-09-24 15:00:00	2020-09-24 16:30:00	\N	\N	1	0	\N	\N
489867	SEANCE_PLENIERE	OUV_SESSION	\N	\N	\N	Election du Président du Sénat	Ouverture de session	2020-10-01 15:00:00	2020-10-01 17:30:00	\N	\N	333	0	\N	\N
489907	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT 2020 Le Grand Paris Express - Valérie Pécresse Pdte Région IdF	GT 2020 Le Grand Paris Express - Valérie Pécresse Pdte Région IdF	2020-10-05 10:30:00	2020-10-05 12:00:00	\N	\N	7	0	\N	\N
489908	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT 2020 Le Grand Paris Express - Amélie Verdier Directrice du Budget 	GT 2020 Le Grand Paris Express - Amélie Verdier Directrice du Budget 	2020-10-01 11:00:00	2020-10-01 12:00:00	\N	\N	7	0	\N	\N
489909	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - "MIRES et IA" - Suivi mesures crise covid-19 - DGRI	Contrôle 2020 - "MIRES et IA" - Suivi mesures crise covid-19 - DGRI	2020-09-24 15:00:00	2020-09-24 16:00:00	\N	\N	2	0	\N	\N
489912	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Projet de loi de programmation pour la recherche - DGRI	Projet de loi de programmation pour la recherche - DGRI	2020-09-24 16:00:00	2020-09-24 16:30:00	\N	\N	1	0	\N	\N
489914	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Projet de loi de programmation pour la recherche - CNRS	Projet de loi de programmation pour la recherche - CNRS	2020-09-28 11:00:00	2020-09-28 12:00:00	\N	\N	1	0	\N	\N
489917	DELEGATION	AUCUNE	\N	\N	211	Audition de Mme Élisabeth Moreno, ministre déléguée	Audition de Mme Élisabeth Moreno, ministre déléguée	2020-11-05 09:00:00	2020-11-05 10:50:00	2020-11-05 12:25:42	\N	27	0	\N	\N
489933	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Auditions LPPR	\N	2020-10-01 09:00:00	2020-10-01 10:00:00	\N	\N	6	0	\N	\N
489938	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Auditions LPPR	\N	2020-09-29 14:00:00	2020-09-29 16:30:00	\N	\N	6	0	\N	\N
489939	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI Restitution des oeuvres d'art	\N	2020-09-30 14:30:00	2020-09-30 15:45:00	\N	\N	1	0	\N	\N
489988	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Territoire zéro chômeur de longue durée	\N	2020-09-29 10:00:00	2020-09-29 12:00:00	\N	\N	1	0	\N	\N
489990	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Territoire zéro chômeur de longue durée	\N	2020-09-29 14:30:00	2020-09-29 17:00:00	\N	\N	1	0	\N	\N
490017	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI Restitution des oeuvres d'art	\N	2020-09-30 10:00:00	2020-09-30 11:15:00	\N	\N	2	0	\N	\N
490021	GIA	AUCUNE	\N	\N	\N	test	test	2020-09-30 20:00:00	2020-09-30 22:00:00	\N	\N	0	0	641	\N
490476	SEANCE_PLENIERE	AUTRE	\N	\N	\N	Renouvellement des instances	Renouvellement des instances du Sénat	2020-10-06 14:34:00	2020-10-06 14:42:00	\N	\N	107	0	\N	\N
490477	SEANCE_PLENIERE	AUTRE	\N	\N	\N	Renouvellement des instances	Annonce et ratification des listes des groupes	2020-10-06 18:38:00	2020-10-06 18:41:00	\N	\N	107	0	\N	\N
490707	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2020-10-07 11:50:00	2020-10-07 13:15:00	\N	\N	48	0	\N	\N
491141	SEANCE_PLENIERE	AUTRE	\N	\N	\N	Renouvellement des instances	Annonce et ratification des listes CS/Delegations	2020-10-07 14:37:00	2020-10-07 14:38:00	\N	\N	4	0	\N	\N
491185	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion constitutive	Réunion constitutive	2020-10-22 10:00:00	2020-10-22 10:35:00	2020-10-22 11:37:05	\N	17	0	\N	\N
491261	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2020-10-14 11:05:00	2020-10-14 12:41:00	2020-10-14 18:13:43	2020-10-15 11:06:11	60	0	\N	\N
491262	COM_PERMANENTE	AUTRE	\N	ETRD	\N	 Saisine éventuelle pour avis PJL 669  et examen du rapport	Saisine éventuelle pour avis PJL 669  et examen du rapport	2020-10-07 13:10:00	2020-10-07 13:25:00	2020-10-07 18:11:06	2020-10-08 18:30:30	42	0	\N	\N
491367	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - PPLC/PPLO libertés locales	\N	2020-10-07 15:00:00	2020-10-07 15:55:00	\N	\N	4	0	\N	\N
491372	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - PPLC/PPLO libertés locales	\N	2020-10-07 16:30:00	2020-10-07 17:45:00	\N	\N	4	0	\N	\N
491410	SEANCE_PLENIERE	HOMMAGE	\N	\N	\N	Hommage à PONCELET	Hommage solennel à Christian PONCELET, ancien Président du Sénat	2020-10-13 14:34:00	2020-10-13 15:02:00	\N	\N	152	0	\N	\N
491412	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL territoires zéro chômeur	PPL renforcement de l'inclusion dans l'emploi par l'activité économique et à l'expérimentation « territoires zéro chômeu	2020-10-13 15:15:00	2020-10-13 20:40:00	\N	\N	152	0	\N	\N
491414	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL sortie de l'état d'urgence sanitaire	PJL prorogeant le régime transitoire institué à la sortie de l'état d'urgence sanitaire 	2020-10-13 22:11:00	2020-10-14 00:46:00	\N	\N	66	0	\N	\N
491415	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2020-10-14 15:02:00	2020-10-14 16:32:00	\N	\N	194	0	\N	\N
375545	COM_PERMANENTE	AUTRE	\N	LOIS	\N	\N	\N	2019-05-07 14:00:00	2019-05-07 14:25:00	2019-05-07 17:45:33	2019-05-09 17:08:23	22	0	\N	\N
379985	DELEGATION	AUCUNE	\N	\N	206	Audition publique  Apports des sciences et technologies à la restauration de Notre-Dame 	Audition publAudition publique Apports des sciences et technologies à la restauration de Notre-Dame de Paris	2019-05-23 09:40:00	2019-05-23 13:45:00	\N	\N	11	0	\N	\N
384584	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Colombie	\N	2019-05-28 15:00:00	2019-05-28 16:15:00	\N	\N	2	0	\N	\N
384588	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	RI Colombie	\N	2019-05-29 12:30:00	2019-05-29 14:15:00	\N	\N	4	0	\N	\N
384773	DELEGATION	DEPLACEMENT	\N	\N	ENTREPRISES	Déplacement en Charente-Maritime	Déplacement en Charente-Maritime	2019-05-23 09:00:00	2019-05-23 22:00:00	\N	\N	10	0	\N	\N
384829	DELEGATION	DEPLACEMENT	\N	\N	ENTREPRISES	Déplacement en Charente	Déplacement en Charente	2019-05-24 08:15:00	2019-05-24 18:26:00	\N	\N	10	0	\N	\N
391238	GIA	AUCUNE	\N	\N	\N	Remise du prix Nathalie Pasternak 2018-2019	Remise du prix Nathalie Pasternak 2018-2019	2019-06-13 12:15:00	2019-06-13 13:15:00	\N	\N	2	0	530	\N
391291	MISSION	PLEIN_NON_JO	\N	BREXIT2	\N	Brexit	Brexit	2019-06-12 17:08:00	2019-06-12 18:31:00	\N	\N	4	0	\N	\N
391857	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Coopération sanitaire transfrontalière	PJL Coopération sanitaire transfrontalière	2019-06-20 10:35:00	2019-06-20 11:35:00	\N	\N	48	0	\N	\N
392896	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-06-26 09:35:00	2019-06-26 11:00:00	2019-06-26 14:41:26	2019-06-26 18:36:00	29	0	\N	\N
395394	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-06-26 11:00:00	2019-06-26 11:30:00	2019-06-28 11:53:49	2019-06-28 11:54:16	40	0	\N	\N
396128	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteur M. Jacques Dayan (Neurosciences)	Audition rapporteur M. Jacques Dayan (Neurosciences)	2019-07-02 14:00:00	2019-07-02 15:00:00	\N	\N	1	0	\N	\N
398329	DELEGATION	DEPLACEMENT	\N	\N	ENTREPRISES	Déplacement dans les Alpes-Maritimes	Déplacement dans les Alpes-Maritimes	2019-07-04 16:30:00	2019-07-05 19:05:00	\N	\N	8	0	\N	\N
398347	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Claude Blanchemaison, ancien ambassadeur de France en Russie	Entretien avec M. Claude Blanchemaison, ancien ambassadeur de France en Russie	2019-07-03 08:00:00	2019-07-03 09:15:00	\N	\N	10	0	608	\N
432086	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	GT 2019 Exercice du droit de retrait	\N	2019-11-26 14:00:00	2019-11-26 15:30:00	\N	\N	3	0	\N	\N
432091	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	GT 2019 Exercice du droit de retrait	\N	2019-11-26 15:30:00	2019-11-26 16:30:00	\N	\N	3	0	\N	\N
432099	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	GT 2019 Exercice du droit de retrait	\N	2019-11-26 17:30:00	2019-11-26 18:20:00	\N	\N	2	0	\N	\N
443871	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Sécurité sanitaire	\N	2020-01-14 10:00:00	2020-01-14 11:00:00	\N	\N	2	0	\N	\N
443872	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Sécurité sanitaire	\N	2020-01-14 16:00:00	2020-01-14 17:00:00	\N	\N	2	0	\N	\N
443873	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Sécurité sanitaire	\N	2020-01-15 11:30:00	2020-01-15 12:30:00	\N	\N	2	0	\N	\N
443874	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Sécurité sanitaire	\N	2020-01-15 14:00:00	2020-01-15 16:00:00	\N	\N	2	0	\N	\N
443875	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Sécurité sanitaire	\N	2020-01-16 09:00:00	2020-01-16 11:00:00	\N	\N	1	0	\N	\N
443877	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Sécurité sanitaire	\N	2020-01-16 14:00:00	2020-01-16 16:00:00	\N	\N	1	0	\N	\N
445770	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition GT Nouvelles formes de commerce	Audition GT Nouvelles formes de commerce	2020-01-15 11:00:00	2020-01-15 11:45:00	\N	\N	2	0	\N	\N
445773	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition GT Nouvelles formes de commerce	Audition GT Nouvelles formes de commerce	2020-01-15 14:15:00	2020-01-15 15:00:00	\N	\N	2	0	\N	\N
445776	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition GT Nouvelles formes de commerce	Audition GT Nouvelles formes de commerce	2020-01-15 16:30:00	2020-01-15 17:15:00	\N	\N	3	0	\N	\N
445783	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition GT Nouvelles formes de commerce	Audition GT Nouvelles formes de commerce	2020-01-15 17:15:00	2020-01-15 18:15:00	\N	\N	2	0	\N	\N
445807	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions de M. Montaugé et Mme Noël-PPL Libre choix du consommateur dans le cyberespace	Auditions de M. Montaugé et Mme Noël	2020-01-15 17:45:00	2020-01-15 18:30:00	\N	\N	1	0	\N	\N
446070	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs (Production de l'énergie dans le secteur agricole)	Audition rapporteurs (Production de l'énergie dans le secteur agricole) Association agriculteurs méthaniseurs de France	2020-01-21 10:00:00	2020-01-21 11:30:00	\N	\N	2	0	\N	\N
495350	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Justice - CNB	PLF pour 2021 - Justice - CNB	2020-10-22 14:30:00	2020-10-22 15:30:00	\N	\N	1	0	\N	\N
392897	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-06-26 11:00:00	2019-06-26 12:20:00	2019-06-26 14:45:05	2019-06-26 18:36:02	29	3	\N	\N
446073	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs (Production de l'énergie dans le secteur agricole)	Audition rapporteurs (Production de l'énergie dans le secteur agricole) CNRS	2020-01-21 11:30:00	2020-01-21 12:30:00	\N	\N	2	0	\N	\N
446076	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteurs (Production de l'énergie dans le secteur agricole)	Audition rapporteurs (Production de l'énergie dans le secteur agricole) Green Lighthouse	2020-01-21 12:30:00	2020-01-21 13:15:00	\N	\N	2	0	\N	\N
446374	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition GT Nouvelles formes de commerce	Audition GT Nouvelles formes de commerce	2020-01-21 10:00:00	2020-01-21 10:45:00	\N	\N	2	0	\N	\N
446411	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition difficultés de recrutement et évolution des métiers	Audition difficultés de recrutement et évolution des métiers - CCI France	2020-01-21 10:00:00	2020-01-21 11:15:00	\N	\N	2	0	\N	\N
446414	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition entreprises responsables et engagées	Audition entreprises responsables et engagées 	2020-01-21 14:35:00	2020-01-21 15:35:00	\N	\N	1	0	\N	\N
446416	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition entreprises responsables et engagées 	Audition entreprises responsables et engagées -  Medef	2020-01-21 15:35:00	2020-01-21 16:50:00	\N	\N	2	0	\N	\N
448017	ETUDES	AUCUNE	\N	\N	\N	Réunion	Réunion	2020-01-22 08:30:00	2020-01-22 09:45:00	\N	\N	13	0	\N	934
448045	GIA	AUCUNE	\N	\N	\N	Entretien avec S. Exc. M. Francisco GROSS, Ambassadeur du Guatemala en France	Entretien avec S. Exc. M. Francisco GROSS, Ambassadeur du Guatemala en France	2020-01-21 12:30:00	2020-01-21 14:30:00	\N	\N	4	0	643	\N
448050	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Sébastien JAUNET, Ministère de l'Europe et des affaires étrangères	Entretien avec M. Sébastien JAUNET, Chef de la Mission du Mexique de l¿Amérique centrale (MAE)	2020-01-22 14:00:00	2020-01-22 15:00:00	\N	\N	4	0	643	\N
449485	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL "Transport aérien tactique"	PJL "Transport aérien tactique"	2020-01-27 17:00:00	2020-01-27 18:00:00	\N	\N	1	0	\N	\N
450867	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Inde	\N	2020-01-27 10:00:00	2020-01-27 12:00:00	\N	\N	1	0	\N	\N
450869	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Inde	\N	2020-01-30 14:00:00	2020-01-30 15:00:00	\N	\N	3	0	\N	\N
450873	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Inde	\N	2020-01-30 15:00:00	2020-01-30 16:00:00	\N	\N	2	0	\N	\N
450876	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Inde	\N	2020-01-30 17:00:00	2020-01-30 18:00:00	\N	\N	1	0	\N	\N
450967	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	1301	\N	\N	Explications de vote sur l'ensemble	Explications de vote sur l'ensemble	2020-02-04 14:32:00	2020-02-04 15:40:00	\N	\N	328	0	\N	\N
450968	SEANCE_PLENIERE	SCRUSOL	1301	\N	\N	Scrutin solennel Bioéthique	Scrutin solennel Bioéthique	2020-02-04 14:30:00	2020-02-04 15:45:00	\N	\N	0	0	\N	\N
458324	COM_EURO	AUDRAP	\N	AFEU	\N	audition rapporteur - Strasbourg - Adhésion UE à la CEDH	Adhésion de l'UE à la CEDH	2020-02-10 09:00:00	2020-02-10 17:00:00	\N	\N	2	0	\N	\N
495038	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2021 - Missions Sécurités - EFE - IA	PLF pour 2021 - Missions Sécurités - EFE - IA	2020-10-28 09:35:00	2020-10-28 12:20:00	2020-10-28 14:45:38	2020-10-28 14:48:07	36	0	\N	\N
495093	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition Roxana Maracineanu	\N	2020-10-27 15:35:00	2020-10-27 17:10:00	2020-10-27 20:04:08	2020-10-28 12:12:59	22	0	\N	\N
495121	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL prorogation État d'urgence sanitaire 	PJL  autorisant la prorogation de l'état d'urgence sanitaire 	2020-10-29 17:15:00	2020-10-29 18:20:00	\N	\N	75	0	\N	\N
495122	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL prorogation État d'urgence sanitaire	PJL  autorisant la prorogation de l'état d'urgence sanitaire 	2020-10-30 09:30:00	2020-10-30 12:20:00	\N	\N	47	0	\N	\N
495123	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL prorogation État d'urgence sanitaire	PJL  autorisant la prorogation de l'état d'urgence sanitaire	2020-10-29 21:45:00	2020-10-30 00:30:00	\N	\N	45	0	\N	\N
495125	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Programmation Recherche	PJL  Programmation Recherche pour les années 2020 à 2030	2020-10-28 16:30:00	2020-10-28 19:50:00	\N	\N	88	0	\N	\N
495126	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Programmation Recherche	PJL  Programmation Recherche pour les années 2020 à 2030	2020-10-28 21:30:00	2020-10-29 01:30:00	\N	\N	55	0	\N	\N
495128	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Programmation Recherche	PJL  Programmation Recherche pour les années 2020 à 2030	2020-10-29 10:30:00	2020-10-29 13:00:00	\N	\N	57	0	\N	\N
495130	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Programmation Recherche	PJL  Programmation Recherche pour les années 2020 à 2030	2020-10-30 14:30:00	2020-10-30 17:25:00	\N	\N	31	0	\N	\N
495303	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Écologie - DGAC	PLF pour 2021 - Écologie - DGAC	2020-10-19 14:00:00	2020-10-19 15:30:00	\N	\N	1	0	\N	\N
495328	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Écologie - Cerema	PLF pour 2021 - Écologie - Cerema	2020-10-22 14:00:00	2020-10-22 15:00:00	\N	\N	1	0	\N	\N
495330	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Écologie - ADP	PLF pour 2021 - Écologie - ADP	2020-10-22 16:00:00	2020-10-22 17:00:00	\N	\N	1	0	\N	\N
495332	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Écologie - IGN	PLF pour 2021 - Écologie - IGN	2020-10-23 09:00:00	2020-10-23 10:00:00	\N	\N	1	0	\N	\N
495334	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Santé - Direction de la sécurité sociale	PLF pour 2021 - Santé - Direction de la sécurité sociale	2020-10-20 10:30:00	2020-10-20 11:30:00	\N	\N	1	0	\N	\N
495336	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFSS pour 2021 - CNAM - AT-MP et ACOSS	PLFSS pour 2021 - CNAM - AT-MP et ACOSS	2020-10-21 09:00:00	2020-10-21 11:00:00	\N	\N	1	0	\N	\N
495338	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Santé - DGS	PLF pour 2021 - Santé - DGS	2020-10-22 11:00:00	2020-10-22 12:00:00	\N	\N	1	0	\N	\N
495340	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Investissements d'avenir - SGPI	PLF pour 2021 - Investissements d'avenir - SGPI	2020-10-20 14:00:00	2020-10-20 15:00:00	\N	\N	1	0	\N	\N
495342	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Investissements d'avenir - Caisse des dépôts et consignations	PLF pour 2021 - Investissements d'avenir - Caisse des dépôts et consignations	2020-10-21 09:00:00	2020-10-21 10:00:00	\N	\N	1	0	\N	\N
495344	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière	\N	2020-10-29 08:05:00	2020-10-29 09:05:00	\N	\N	13	0	\N	\N
495345	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2021 -  Accidents du travail - Maladies professionnelles - Audition de l'IGAS	PLFSS 2021 -  Accidents du travail - Maladies professionnelles - Audition de l'IGAS	2020-10-29 09:30:00	2020-10-29 10:30:00	\N	\N	2	0	\N	\N
495346	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Justice - DAP	PLF pour 2021 - Justice - DAP	2020-10-20 17:00:00	2020-10-20 18:00:00	\N	\N	1	0	\N	\N
495348	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Justice - DB	PLF pour 2021 - Justice - DB	2020-10-21 16:45:00	2020-10-21 17:30:00	\N	\N	1	0	\N	\N
439813	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Bioéthique	PJL Bioéthique	2020-01-21 14:30:00	2020-01-21 19:30:00	\N	\N	241	0	\N	\N
492088	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2020-10-14 09:32:00	2020-10-14 12:16:00	2020-10-15 16:04:40	2020-10-15 16:42:33	35	0	\N	\N
495352	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Rapport général - Plan de relance - DB / Bpifrance	PLF pour 2021 - Rapport général - Plan de relance - DB / Bpifrance	2020-10-22 11:00:00	2020-10-22 12:30:00	\N	\N	2	0	\N	\N
495354	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Rapport général - Plan de relance - Comité de suivi Covid 2019 / FFB / FI	PLF pour 2021 - Rapport général - Plan de relance - Comité de suivi Covid 2019 / FFB / France Industrie	2020-10-20 14:00:00	2020-10-20 16:45:00	\N	\N	2	0	\N	\N
495358	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - EFE - S&P Global Ratings	PLF pour 2021 - EFE - S&P Global Ratings	2020-10-22 09:00:00	2020-10-22 10:00:00	\N	\N	1	0	\N	\N
495360	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - EFE - FitchRatings	PLF pour 2021 - EFE - FitchRatings	2020-10-22 15:00:00	2020-10-22 15:40:00	\N	\N	1	0	\N	\N
495362	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Affaires européennes - DB	PLF pour 2021 - Affaires européennes - DB	2020-10-22 10:00:00	2020-10-22 11:00:00	\N	\N	1	0	\N	\N
495364	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2021 - Sécurités - DGGN	PLF pour 2021 - Sécurités - DGGN	2020-10-21 17:00:00	2020-10-21 19:00:00	\N	\N	1	0	\N	\N
495366	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Sécurités - DPGN	PLF pour 2021 - Sécurités - DPGN	2020-10-23 15:00:00	2020-10-23 16:00:00	\N	\N	1	0	\N	\N
495368	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Rapport général - CGPME / AFEP	PLF pour 2021 - Rapport général - CGPME / AFEP	2020-10-22 13:30:00	2020-10-22 16:00:00	\N	\N	1	0	\N	\N
495370	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2021 - CCE - Cour des comptes	PLF pour 2021 - CCE - Cour des comptes	2020-10-20 16:00:00	2020-10-20 18:00:00	\N	\N	1	0	\N	\N
495372	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - CCE - Conseil d'État et CNDA	PLF pour 2021 - CCE - Conseil d'État et CNDA	2020-10-21 16:15:00	2020-10-21 17:00:00	\N	\N	1	0	\N	\N
495374	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Enseignement scolaire - Ministère de l'éducation nationale 	PLF pour 2021 - Enseignement scolaire - Ministère de l'éducation nationale 	2020-10-22 08:30:00	2020-10-22 09:45:00	\N	\N	1	0	\N	\N
495376	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - CCE - CESE	PLF pour 2021 - CCE - CESE	2020-10-22 11:30:00	2020-10-22 12:20:00	\N	\N	1	0	\N	\N
495378	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - AEE - DB	PLF pour 2021 - AEE - DB	2020-10-23 15:00:00	2020-10-23 16:00:00	\N	\N	2	0	\N	\N
495387	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Action logement - PEEC -Union sociale de l'habitat	Action logement - PEEC -Union sociale de l'habitat	2020-10-21 16:30:00	2020-10-21 17:00:00	\N	\N	2	0	\N	\N
495390	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Action logement - PEEC - Auteurs de la partie logement du rapport CAP 2022	Action logement - PEEC - Auteurs de la partie logement du rapport CAP 2022	2020-10-21 17:00:00	2020-10-21 17:45:00	\N	\N	2	0	\N	\N
495393	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Action logement - PEEC - M. F. Paul, ancien directeur général de l'USH	Action logement - PEEC - M. F. Paul, ancien directeur général de l'USH	2020-10-23 09:30:00	2020-10-23 10:15:00	\N	\N	2	0	\N	\N
495427	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2021 - Programme Hébergement	\N	2020-10-27 09:30:00	2020-10-27 10:10:00	\N	\N	2	0	\N	\N
495473	COM_PERMANENTE	AUTRE	\N	CAE	\N	PJL Mise sur le marché de certains produits phytopharmaceutiques - Désignation de CMP	\N	2020-10-28 08:30:00	2020-10-28 08:35:00	\N	\N	0	0	\N	\N
495678	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL produits phytopharmaceutiques en cas de danger sanitaire pour les betteraves sucrières	PJL produits phytopharmaceutiques en cas de danger sanitaire pour les betteraves sucrières	2020-10-27 16:20:00	2020-10-27 20:40:00	\N	\N	94	0	\N	\N
495984	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2021 - Branche Equilibres financiers	\N	2020-10-27 16:30:00	2020-10-27 17:30:00	\N	\N	3	0	\N	\N
373747	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition PME et Numérique	Audition PME et Numérique - M. Jean-Daniel WEISZ	2019-04-10 11:15:00	2019-04-10 12:15:00	\N	\N	0	0	\N	\N
373748	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition PME et Numérique	Audition PME et Numérique - M. Jean-Daniel WEISZ	2019-04-10 11:15:00	2019-04-10 12:15:00	\N	\N	1	0	\N	\N
373750	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition PME et Numérique	Audition PME et Numérique - Conseil supérieur de l'Ordre des Experts-comptables (CSOEC)	2019-04-10 12:15:00	2019-04-10 13:00:00	\N	\N	1	0	\N	\N
379970	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Accès des PME à la commande publique	\N	2019-05-14 15:00:00	2019-05-14 17:15:00	\N	\N	1	0	\N	\N
379972	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Accès des PME à la commande publique	\N	2019-05-14 13:45:00	2019-05-14 14:30:00	\N	\N	1	0	\N	\N
380663	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Création d'un statut de l'élu communal	\N	2019-05-21 10:00:00	2019-05-21 11:00:00	\N	\N	3	0	\N	\N
380667	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Accès des PME à la commande publique	\N	2019-05-21 09:30:00	2019-05-21 11:00:00	\N	\N	1	0	\N	\N
381242	COM_PERMANENTE	DEPLACEMENT	\N	CAE	\N	PPL Lutte contre l'habitat insalubre	PPL Lutte contre l'habitat insalubre - Déplacement dans la Somme	2019-05-20 08:00:00	2019-05-20 20:00:00	\N	\N	3	0	\N	\N
382690	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PPL réseaux radioélectriques	\N	2019-05-21 11:00:00	2019-05-21 12:00:00	\N	\N	1	0	\N	\N
382692	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PPL réseaux radioélectriques	\N	2019-05-23 09:00:00	2019-05-23 10:00:00	\N	\N	1	0	\N	\N
382698	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Territoires d'outre-mer soumis à une pression migratoire	\N	2019-05-22 14:40:00	2019-05-22 16:40:00	\N	\N	1	0	\N	\N
382704	MISSION	AUDRAP	\N	AERIEN	\N	\N	\N	2019-05-23 10:00:00	2019-05-23 11:45:00	\N	\N	7	0	\N	\N
384210	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Transformation de la fonction publique	\N	2019-05-28 14:30:00	2019-05-28 15:50:00	\N	\N	1	0	\N	\N
384212	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Transformation de la fonction publique	\N	2019-05-28 18:10:00	2019-05-28 19:50:00	\N	\N	2	0	\N	\N
400443	GIA	AUCUNE	\N	\N	\N	Entretien avec l'Ambassadeur d'Australie	Entretien des membres du bureau du groupe d'amitié avec l'Ambassadeur d'Australie	2019-07-09 12:00:00	2019-07-09 14:20:00	\N	\N	6	0	578	\N
400450	GIA	AUCUNE	\N	\N	\N	Entretien avec une délégation du PArlement égyptien	Entretien avec une délégation du groupe d'amitié du Parlelent égyptien	2019-06-26 12:45:00	2019-06-26 14:30:00	\N	\N	7	0	617	\N
402725	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Prestation de compensation du handicap	Prestation de compensation du handicap	2019-07-22 10:00:00	2019-07-22 15:45:00	\N	\N	1	0	\N	\N
405382	COM_PERMANENTE	AUTRE	\N	FINC	\N	Contrôles budgétaires Feux de Forêts-Recherche-Inspection du travail et Nom. Rapp. PPL710	Contrôles budgétaires Feux de Forêts-Recherche-Inspection du travail et Nomination Rapporteur PPL 710	2019-09-25 09:45:00	2019-09-25 12:00:00	2019-09-25 18:22:48	2019-09-26 16:34:42	32	0	\N	\N
405391	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-09-24 18:00:00	2019-09-24 19:55:00	2019-09-25 11:34:37	2019-09-25 15:38:53	30	0	\N	\N
405392	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-09-26 09:35:00	2019-09-26 10:20:00	2019-09-26 11:38:13	2019-09-26 16:34:38	26	0	\N	\N
439814	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Bioéthique	PJL Bioéthique	2020-01-21 21:30:00	2020-01-22 00:00:00	\N	\N	168	0	\N	\N
405393	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-09-26 10:25:00	2019-09-26 10:30:00	2019-09-26 11:38:27	2019-09-26 16:34:38	26	0	\N	\N
405409	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2018 - Performance établissements ens. sup - Déplacement à Lausanne et Genève	Contrôle 2018 - Performance établissements ens. sup - Déplacement à Lausanne et Genève	2019-09-05 07:55:00	2019-09-06 17:50:00	\N	\N	1	0	\N	\N
405414	MISSION	AUTRE	\N	FONDS	\N	Réunion du 25 septembre 2019	\N	2019-09-25 14:05:00	2019-09-25 16:00:00	2019-09-25 20:09:06	2019-09-26 16:38:00	16	0	\N	\N
405416	DELEGATION	AUCUNE	\N	\N	211	Audition de Mme Sylviane AGACINSKI, philosophe	Audition de Mme Sylviane AGACINSKI, philosophe, dans la perspective de l¿examen du projet de loi relatif à la bioéthique	2019-10-22 18:00:00	2019-10-22 19:15:00	2019-10-23 15:04:19	\N	11	0	\N	\N
405417	DELEGATION	AUDRAP	\N	\N	DSOM	Audition de l'Agence française de développement	\N	2019-09-26 10:00:00	2019-09-26 11:45:00	\N	\N	7	0	\N	\N
407197	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Fabrice Balanche, géorgaphe, spécialiste de la Syrie	Entretien avec M. Fabrice Balanche, géorgaphe, spécialiste de la Syrie	2019-09-25 09:30:00	2019-09-25 11:00:00	\N	\N	2	0	644	\N
407806	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL Macédoine du Nord	\N	2019-09-25 15:00:00	2019-09-25 17:00:00	\N	\N	1	0	\N	\N
423462	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Culture (Création, Transmission, Démocratisation)	PLF 2020 - Crédits Culture (Création, Transmission, Démocratisation)	2019-11-04 11:20:00	2019-11-04 12:20:00	\N	\N	2	0	\N	\N
423465	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Culture (Création, Transmission, Démocratisation)	PLF 2020 - Crédits Culture (Création, Transmission, Démocratisation)	2019-11-04 13:00:00	2019-11-04 17:00:00	\N	\N	2	0	\N	\N
424978	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	GT 2019 Exercice du droit de retrait	\N	2019-11-05 12:00:00	2019-11-05 12:50:00	\N	\N	2	0	\N	\N
425420	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Logement - Mme Estrosi Sassone	PJLF 2020 Audition Mme Estrosi Sassone avis logement	2019-11-05 15:00:00	2019-11-05 16:00:00	\N	\N	1	0	\N	\N
425421	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	\N	2019-11-05 15:00:00	2019-11-05 16:00:00	\N	\N	0	0	\N	\N
425423	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Logement - Mme Estrosi Sassone	PJLF 2020 Audition Mme Estrosi Sassone avis logement	2019-11-06 11:00:00	2019-11-06 12:00:00	\N	\N	1	0	\N	\N
425424	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-11-12 17:30:00	2019-11-12 18:45:00	2019-11-12 18:55:57	2019-11-13 14:50:31	28	0	\N	\N
425429	DELEGATION	AUDRAP	\N	\N	PROS	Audition du Cirad	\N	2019-11-26 15:30:00	2019-11-26 16:40:00	\N	\N	1	0	\N	\N
425431	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Logement - Mme Estrosi Sassone	PJLF 2020 Audition Mme Estrosi Sassone avis logement	2019-11-06 16:30:00	2019-11-06 17:30:00	\N	\N	1	0	\N	\N
425742	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Recherche - M. Moga	\N	2019-11-12 09:00:00	2019-11-12 10:30:00	\N	\N	1	0	\N	\N
425749	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Recherche - M. Moga	\N	2019-11-12 16:30:00	2019-11-12 17:15:00	\N	\N	1	0	\N	\N
425753	COM_ENQUETE	AUTRE	\N	LUBRIZOL	\N	Réunion de commission	\N	2019-11-12 18:00:00	2019-11-12 18:20:00	2019-11-13 15:01:51	2019-11-13 17:04:03	7	0	\N	\N
426123	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2020 - Avis juridictions administratives et juridictions financières	PLF pour 2020 - Avis juridictions administratives et juridictions financières	2019-11-12 16:30:00	2019-11-12 17:30:00	\N	\N	1	0	\N	\N
426127	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-11-13 16:50:00	2019-11-13 19:25:00	2019-11-13 19:41:37	2019-11-14 15:31:38	29	0	\N	\N
426311	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Agriculture - M. Duplomb, Mme Férat, M. Tissot	\N	2019-10-15 15:00:00	2019-10-15 19:00:00	\N	\N	0	0	\N	\N
426471	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2020 - Avis Relations avec les collectivités territoriales	\N	2019-11-12 14:00:00	2019-11-12 15:40:00	\N	\N	2	0	\N	\N
427858	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-11-19 17:40:00	2019-11-19 18:05:00	2019-11-20 14:44:19	2019-11-20 17:04:12	28	0	\N	\N
428042	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-11-13 11:28:00	2019-11-13 12:19:00	2019-11-14 15:01:12	2019-11-14 15:31:43	42	0	\N	\N
428104	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière	Réunion plénière	2019-11-14 08:30:00	2019-11-14 10:00:00	2019-11-14 15:07:14	\N	8	0	\N	\N
443806	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Nouveau code de la justice pénale des mineurs - Auditions plénières	Nouveau code de la justice pénale des mineurs - Auditions plénières	2020-01-15 10:45:00	2020-01-15 13:10:00	2020-01-15 14:16:27	2020-01-15 17:49:12	37	0	\N	\N
443807	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Auditions  sur la restitution des biens culturels	2020-01-15 09:40:00	2020-01-15 12:30:00	2020-01-15 13:58:59	2020-01-15 17:49:15	38	0	\N	\N
451967	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Nouveau code de justice pénale des mineurs	PJL Nouveau code de justice pénale des mineurs	2020-02-05 10:10:00	2020-02-05 11:10:00	2020-02-05 11:59:03	2020-02-05 17:12:58	40	1	\N	\N
458691	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition GT Nouvelles formes de commerce - Rapporteur M. Babary	Audition GT Nouvelles formes de commerce - Rapporteur M. Babary	2020-02-26 16:30:00	2020-02-26 19:15:00	\N	\N	1	0	\N	\N
458693	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition GT Nouvelles formes de commerce - Rapporteur M. Babary	Audition GT Nouvelles formes de commerce - Rapporteur M. Babary	2020-02-26 16:30:00	2020-02-26 18:15:00	\N	\N	1	0	\N	\N
471601	DELEGATION	AUCUNE	\N	\N	DSOM	Audition de l'ADIE	\N	2020-05-20 16:15:00	2020-05-20 17:45:00	\N	\N	7	0	\N	\N
471686	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission (visioconférence)	Réunion de commission (visioconférence)	2020-05-20 09:30:00	2020-05-20 12:00:00	2020-05-20 13:55:31	2020-05-20 14:34:59	35	0	\N	\N
471904	DELEGATION	AUCUNE	\N	\N	DSOM	Table ronde sur le bâtiment et le logement social dans les outre-mer	\N	2020-05-28 14:00:00	2020-05-28 17:00:00	\N	\N	11	0	\N	\N
471912	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Pôle Emploi	\N	2020-06-08 17:00:00	2020-06-08 19:00:00	\N	\N	0	0	\N	\N
382180	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-05-28 15:05:00	2019-05-28 16:30:00	2019-05-28 16:48:37	2019-05-28 17:02:59	43	0	\N	\N
425346	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Délégations parlementaires aux droits des enfants - PLF pour 2020 pour avis : examen d	Réunion de la commission	2019-11-13 09:30:00	2019-11-13 11:20:00	2019-11-13 13:34:57	2019-11-13 14:50:28	40	1	\N	\N
491417	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL  code de la sécurité intérieure	PJL prorogation des chapitres VI à X du titre II du livre II et de l'article L. 851-3 du code de la sécurité intérieure	2020-10-14 17:15:00	2020-10-14 19:25:00	\N	\N	62	0	\N	\N
491419	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJLO Conseil économique, social et environnemental 	PJLO relatif au Conseil économique, social et environnemental	2020-10-14 23:01:00	2020-10-15 00:17:00	\N	\N	45	0	\N	\N
491420	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJLO Conseil économique, social et environnemental	PJLO relatif au Conseil économique, social et environnemental	2020-10-15 10:32:00	2020-10-15 13:02:00	\N	\N	53	0	\N	\N
491442	GIA	AUCUNE	\N	\N	\N	Entretien avec Simon ABIRAMIA, Président du groupe d'amitié Liban-France	Entretien avec Simon ABIRAMIA, Président du groupe d'amitié Liban-France	2020-10-07 15:30:00	2020-10-07 16:30:00	\N	\N	6	0	597	\N
491608	DELEGATION	AUCUNE	\N	\N	211	Réunion constitutive de la délégation aux droits des femmes	Réunion constitutive de la délégation aux droits des femmes	2020-10-22 08:30:00	2020-10-22 09:15:00	\N	\N	15	0	\N	\N
491905	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLC Garantir la prééminence des lois de la République	\N	2020-10-13 15:00:00	2020-10-13 16:00:00	\N	\N	2	0	\N	\N
491908	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLC Garantir la prééminence des lois de la République	\N	2020-10-13 16:30:00	2020-10-13 19:00:00	\N	\N	2	0	\N	\N
493161	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2020-10-08 16:10:00	2020-10-08 17:35:00	\N	\N	3	0	\N	\N
493166	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2020-09-29 14:45:00	2020-09-29 17:30:00	\N	\N	3	0	\N	\N
493170	QUESTURE	AUCUNE	\N	\N	\N	conseil de Questure	Conseil de Questure	2020-10-06 15:10:00	2020-10-06 16:55:00	\N	\N	3	0	\N	\N
493272	COM_PERMANENTE	AUTRE	\N	ETRD	\N	PLF pour 2021 - Auditions du CEMA et du DGA	\N	2020-10-21 10:20:00	2020-10-21 12:45:00	2020-10-21 13:57:56	2020-10-21 15:17:05	26	0	\N	\N
493273	COM_PERMANENTE	AUTRE	\N	ETRD	\N	PLF pour 2021 - Audition de M. Jean-Yves Le Drian	\N	2020-10-21 16:40:00	2020-10-21 18:25:00	2020-10-22 10:25:52	2020-10-22 18:46:51	24	0	\N	\N
493347	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Action logement - PEEC	Action logement - PEEC	2020-10-15 14:30:00	2020-10-15 15:00:00	\N	\N	2	0	\N	\N
493350	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Action logement - PEEC	Action logement - PEEC	2020-10-15 15:00:00	2020-10-15 15:45:00	\N	\N	2	0	\N	\N
493353	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Justice - Syndicat de la magistrature	PLF pour 2021 - Justice - Syndicat de la magistrature	2020-10-15 10:00:00	2020-10-15 11:00:00	\N	\N	1	0	\N	\N
493365	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPLC Garantir la prééminence des lois de la République - amendements de séance	PPLC Garantir la prééminence des lois de la République - amendements de séance	2020-10-19 16:30:00	2020-10-19 16:35:00	2020-10-19 16:45:56	2020-10-19 18:16:25	11	0	\N	\N
493367	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PLF pour 2021 - désignation des rapporteurs pour avis - Désignation de CMP	PLF pour 2021 - désignation des rapporteurs pour avis - Désignation de CMP	2020-10-21 11:30:00	2020-10-21 11:40:00	2020-10-21 12:37:02	2020-10-21 14:50:11	27	0	\N	\N
493371	DELEGATION	AUDRAP	\N	\N	PROS	Audition de M. Xavier Desjardins	Audition de M. Xavier Desjardins	2020-10-29 09:45:00	2020-10-29 10:45:00	\N	\N	1	0	\N	\N
493372	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Écologie - Météo France	PLF pour 2021 - Écologie - Météo France	2020-10-15 17:00:00	2020-10-15 18:30:00	\N	\N	1	0	\N	\N
493374	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Écologie - FNAM	PLF pour 2021 - Écologie - FNAM	2020-10-16 09:30:00	2020-10-16 11:00:00	\N	\N	1	0	\N	\N
493388	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Sécurités - Syndicats APN et FSMI FO	PLF pour 2021 - Sécurités - Syndicats APN et FSMI FO	2020-10-16 10:00:00	2020-10-16 12:00:00	\N	\N	1	0	\N	\N
493390	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes	\N	2020-10-22 09:05:00	2020-10-22 09:50:00	2020-10-22 18:48:22	2020-10-23 17:54:21	27	0	\N	\N
493391	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2020-10-20 17:34:00	2020-10-20 18:28:00	2020-10-20 18:42:19	2020-10-22 18:43:06	32	0	\N	\N
493392	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2020-10-21 09:45:00	2020-10-21 12:31:00	2020-10-21 14:32:27	2020-10-21 15:10:16	33	0	\N	\N
493393	DELEGATION	AUDRAP	\N	\N	206	Audition de l¿ANSSI	\N	2020-10-19 17:00:00	2020-10-19 18:00:00	\N	\N	0	0	\N	\N
493395	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2020-10-13 17:05:00	2020-10-13 18:05:00	\N	\N	3	0	\N	\N
493399	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL restitutions	\N	2020-10-16 09:00:00	2020-10-16 09:50:00	\N	\N	1	0	\N	\N
493511	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2021 - Cohésion des territoires - Logement et urbanisme - Ministère du Logement	PLF pour 2021 - Cohésion des territoires - Logement et urbanisme - Ministère du Logement	2020-10-15 09:30:00	2020-10-15 12:00:00	\N	\N	1	0	\N	\N
494978	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2021 - Branches Équilibres financiers et Assurance vieillesse 	\N	2020-10-20 14:30:00	2020-10-20 16:45:00	\N	\N	2	0	\N	\N
494994	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2021 - Branche Assurance vieillesse 	\N	2020-10-21 14:15:00	2020-10-21 15:00:00	\N	\N	1	0	\N	\N
375323	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	groupe de travail justice prud'homale	groupe de travail justice prud'homale	2019-05-28 14:00:00	2019-05-28 16:00:00	\N	\N	3	0	\N	\N
375326	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	groupe de travail justice prud'homale	groupe de travail justice prud'homale	2019-05-29 16:30:00	2019-05-29 18:30:00	\N	\N	2	0	\N	\N
382179	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-05-28 14:05:00	2019-05-28 15:00:00	2019-05-29 15:22:45	2019-05-29 15:48:17	25	0	\N	\N
382177	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-05-29 09:35:00	2019-05-29 12:00:00	2019-05-29 12:26:17	2019-05-29 15:15:12	40	2	\N	\N
382285	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition de représentants du ministère de l'agriculture et de l'alimentation	Audition de représentants du ministère de l'agriculture et de l'alimentation sur la situation de l'ONF	2019-05-22 11:45:00	2019-05-22 12:45:00	\N	\N	1	0	\N	\N
382287	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Examen d¿un rapport et établissement du texte - PJL Organisation du système de santé	\N	2019-05-22 14:30:00	2019-05-22 18:00:00	\N	\N	0	0	\N	\N
382288	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Examen d¿un rapport et établissement du texte - PJL Organisation du système de santé	\N	2019-05-22 14:30:00	2019-05-22 18:00:00	\N	\N	0	0	\N	\N
382289	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Examen d'un rapport et établissement du texte - PJL Organisation du système de santé	\N	2019-05-22 14:35:00	2019-05-22 18:05:00	2019-05-22 18:10:22	2019-05-23 17:08:03	28	1	\N	\N
382747	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen Amdts Séance PJL Restauration et conservation de Notre-Dame de Paris	Examen Amdts Séance PJL Restauration et conservation de Notre-Dame de Paris	2019-05-27 15:35:00	2019-05-27 15:55:00	2019-05-28 17:50:06	2019-05-29 15:08:18	16	0	\N	\N
382748	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition Robert OPHÈLE sur le rapport annuel de l'AMF et Désignation CMP Taxe GAFA	Audition Robert OPHÈLE sur le rapport annuel de l'AMF et Désignation CMP Taxe GAFA	2019-05-29 10:35:00	2019-05-29 12:05:00	2019-05-29 15:24:01	2019-05-29 15:48:43	25	0	\N	\N
382750	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2019 - Recouvrement des amendes de circulation - Déplacement trésorerie amendes	Contrôle 2019 - Recouvrement des amendes de circulation  - Déplacement dans une trésorerie amendes	2019-05-23 09:15:00	2019-05-23 12:00:00	\N	\N	2	0	\N	\N
382754	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Fraude fonds européens - CICC	Contrôle 2019 - Fraude fonds européens - CICC	2019-05-21 09:30:00	2019-05-21 10:45:00	\N	\N	1	0	\N	\N
382756	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Fraude fonds européens - CGET	Contrôle 2019 - Fraude fonds européens - CGET	2019-05-21 11:30:00	2019-05-21 12:45:00	\N	\N	1	0	\N	\N
382758	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Ressources humaines du ministère des armées - HCRR	Contrôle 2019 - Ressources humaines du ministère des armées - Haut-Commissariat réforme retraites	2019-05-21 14:00:00	2019-05-21 14:30:00	\N	\N	1	0	\N	\N
382760	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Ressources humaines du ministère des armées - Ministère des Armées	Contrôle 2019 - Ressources humaines du ministère des armées - Ministère des Armées	2019-05-21 18:30:00	2019-05-21 20:15:00	\N	\N	1	0	\N	\N
382762	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Le numérique à l'école - Caisse des dépôts	Contrôle 2019 - Le numérique à l'école - Caisse des dépôts	2019-05-21 09:30:00	2019-05-21 10:30:00	\N	\N	1	0	\N	\N
382765	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PJL Notre Dame - Déplacement à Notre-Dame	PJL Notre Dame - Déplacement à Notre-Dame	2019-05-23 08:30:00	2019-05-23 11:00:00	\N	\N	2	0	\N	\N
382775	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions MI responsabilité civile	\N	2019-05-22 14:30:00	2019-05-22 16:00:00	\N	\N	2	0	\N	\N
382778	MISSION	AUTRE	\N	FONDS	\N	01-Réunion constitutive	\N	2019-05-28 17:50:00	2019-05-28 18:20:00	2019-05-28 19:23:39	2019-05-29 15:26:35	16	0	\N	\N
382779	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Redevances aéroportuaires et régulation - DSNA	Contrôle 2019 - Redevances aéroportuaires et régulation - DSNA	2019-05-23 14:30:00	2019-05-23 16:00:00	\N	\N	1	0	\N	\N
382781	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Redevances aéroportuaires et régulation - DGAC	Contrôle 2019 - Redevances aéroportuaires et régulation - DGAC	2019-05-23 16:30:00	2019-05-23 18:00:00	\N	\N	1	0	\N	\N
382857	MISSION	AUCUNE	\N	TRANSPORTS	\N	MIGT - Auditions Transdev et Kéolis	\N	2019-05-28 14:25:00	2019-05-28 16:05:00	2019-05-29 15:58:37	2019-05-31 14:44:16	14	0	\N	\N
382858	MISSION	AUDRAP	\N	TRANSPORTS	\N	MI Gratuité transports audition rapporteur	\N	2019-05-29 13:30:00	2019-05-29 15:40:00	\N	\N	3	0	\N	\N
385352	MISSION	AUDRAP	\N	CLIMATIQUE	\N	Audition de l'OHM du Grand Nancy	Audition de l'OHM du Grand Nancy	2019-06-04 14:00:00	2019-06-04 15:20:00	\N	\N	8	0	\N	\N
385363	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Conseillers techniques et sportifs	Conseillers techniques et sportifs	2019-06-04 15:00:00	2019-06-04 17:00:00	\N	\N	5	0	\N	\N
385369	MISSION	DEPLACEMENT	\N	CLIMATIQUE	\N	MI Risques climatiques - Déplacement dans l'Aude	MI Risques climatiques - Déplacement dans l'Aude	2019-06-02 15:50:00	2019-06-03 21:50:00	\N	\N	5	0	\N	\N
387747	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Visite délégation sénateurs américains	\N	2019-06-07 10:45:00	2019-06-07 11:45:00	\N	\N	9	0	\N	\N
396775	COM_ENQUETE	PLENIERE	\N	SOUVERAINETE	\N	C..E. "Souveraineté numérique"	C.E."Souveraineté numérique"	2019-07-02 14:35:00	2019-07-02 16:35:00	2019-07-03 11:16:28	2019-07-03 15:57:37	9	0	\N	\N
396945	COM_PERMANENTE	DEPLACEMENT	\N	AFCL	\N	Nouveaux territoire de l'éducation	\N	2019-07-02 13:00:00	2019-07-02 18:00:00	\N	\N	3	0	\N	\N
428231	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2020 - Avis Justice judiciaire	PLF pour 2020 - Avis Justice judiciaire	2019-11-14 15:00:00	2019-11-14 19:00:00	\N	\N	1	0	\N	\N
431932	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	\N	2019-11-26 16:05:00	2019-11-26 17:25:00	2019-11-26 17:39:58	2019-11-26 17:43:32	23	0	\N	\N
431967	COM_SPECIALE	AUDRAP	\N	BIOETHIQUE	\N	\N	\N	2019-11-21 09:45:00	2019-11-21 11:15:00	\N	\N	0	0	\N	\N
431969	COM_SPECIALE	AUDRAP	\N	BIOETHIQUE	\N	Audition Mme Jourda Sociologues/Philosophes	\N	2019-11-21 09:45:00	2019-11-21 11:15:00	\N	\N	0	0	\N	\N
432011	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 4 décembre 2019 - débat préalable au Conseil européen	\N	2019-12-04 13:30:00	2019-12-04 16:30:00	\N	\N	0	0	\N	\N
432126	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2020 - Examen d'un sous AMDT à l'aticle d'équilibre	PLF pour 2020 - Examen d'un sous AMDT à l'aticle d'équilibre	2019-11-26 21:15:00	2019-11-26 21:25:00	2019-11-27 10:33:39	2019-11-27 15:06:05	13	0	\N	\N
439808	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2020-01-15 15:01:00	2020-01-15 16:16:00	\N	\N	292	0	\N	\N
439809	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Réformer le régime des catastrophes naturelles	PPL Réformer le régime des catastrophes naturelles	2020-01-15 16:32:00	2020-01-15 19:07:00	\N	\N	96	0	\N	\N
439810	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Droits sociaux des travailleurs numériques	PPL Droits sociaux des travailleurs numériques	2020-01-15 19:12:00	2020-01-15 20:31:00	\N	\N	43	0	\N	\N
439811	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Droit à l'erreur des collectivités locales	PPL Droit à l'erreur des collectivités locales	2020-01-16 14:30:00	2020-01-16 15:53:00	\N	\N	35	0	\N	\N
439812	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Déclaration de naissance lieu de résidence des parents	PPL Déclaration de naissance lieu de résidence des parents	2020-01-16 15:55:00	2020-01-16 17:22:00	\N	\N	21	0	\N	\N
432047	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-11-27 09:05:00	2019-11-27 12:45:00	2019-11-27 12:55:36	2019-11-27 15:05:59	45	4	\N	\N
445754	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2020-01-22 10:00:00	2020-01-22 11:25:00	2020-01-22 12:06:10	2020-01-22 15:46:37	44	1	\N	\N
448849	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Nomination Didier Migaud - Présidence HATVP	\N	2020-01-28 13:55:00	2020-01-28 15:15:00	2020-01-28 15:23:32	2020-01-28 17:59:00	31	0	\N	\N
448850	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Article 13 - Audition de Mme Anne Levade (HATPV)	Article 13 - Audition de Mme Anne Levade (HATPV)	2020-01-28 17:00:00	2020-01-28 18:10:00	2020-01-28 18:40:18	2020-01-29 18:04:01	23	1	\N	\N
448851	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion 20200129	Réunion de la commission	2020-01-29 09:38:00	2020-01-29 11:22:00	2020-01-29 14:00:15	2020-01-29 18:04:05	36	1	\N	\N
449143	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	GT Métier d'enseignant	GT Métier d'enseignant	2020-01-28 16:30:00	2020-01-28 18:00:00	\N	\N	3	0	\N	\N
458965	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	Commission d'Apuration des Comptes	Commission d'Apuration des Comptes	2020-02-19 14:00:00	2020-02-19 14:45:00	2020-02-28 11:15:27	\N	5	0	\N	\N
458983	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2019-11-26 14:45:00	2019-11-26 17:25:00	\N	\N	3	0	\N	\N
458987	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2019-12-17 14:55:00	2019-12-17 18:00:00	\N	\N	3	0	\N	\N
458991	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2020-02-04 14:10:00	2020-02-04 16:40:00	\N	\N	3	0	\N	\N
458995	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2019-11-19 14:30:00	2019-11-19 17:35:00	\N	\N	3	0	\N	\N
458999	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2019-12-04 14:35:00	2019-12-04 17:50:00	\N	\N	3	0	\N	\N
459003	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2019-12-10 14:50:00	2019-12-10 16:55:00	\N	\N	3	0	\N	\N
459007	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2020-01-28 15:00:00	2020-01-28 16:45:00	\N	\N	3	0	\N	\N
462480	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Mineurs vulnérables sur le territoire français	\N	2020-03-03 17:00:00	2020-03-03 17:30:00	\N	\N	2	0	\N	\N
462483	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Mineurs vulnérables sur le territoire français	\N	2020-03-03 17:30:00	2020-03-03 18:15:00	\N	\N	3	0	\N	\N
462487	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Mineurs vulnérables sur le territoire français	\N	2020-03-03 18:15:00	2020-03-03 19:00:00	\N	\N	1	0	\N	\N
462489	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	\N	\N	2020-03-04 09:30:00	2020-03-04 10:15:00	\N	\N	2	0	\N	\N
462492	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	\N	\N	2020-03-03 16:00:00	2020-03-03 17:00:00	\N	\N	1	0	\N	\N
462529	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ambassadeur de Libye en France	Entretien avec l'ambassadeur de Libye en France  Son Excellence M. Hamed A. ELHOUDERI 	2020-03-03 16:00:00	2020-03-03 16:15:00	\N	\N	4	0	657	\N
462534	GIA	AUCUNE	\N	\N	\N	Entretien téléphonique Première urgence internationale	Entretien téléphonique Première urgence internationale - Benjamin Gaudin chef de mission et de programme Libye 	2019-06-04 15:00:00	2019-06-04 16:00:00	\N	\N	1	0	657	\N
462536	GIA	AUCUNE	\N	\N	\N	Entretien avec une délégation de députés libyens	Entretien avec une délégation de députés libyens	2019-06-12 17:00:00	2019-06-12 18:00:00	\N	\N	3	0	657	\N
462540	GIA	AUCUNE	\N	\N	\N	Entretien DG Trésor 	Entretien DG Trésor - Fanny Labarthe, chef du bureau Méditerranée et Proche-Orient  et Garance de Orador adjointe	2019-07-02 15:00:00	2019-07-02 16:00:00	\N	\N	4	0	657	\N
462545	GIA	AUCUNE	\N	\N	\N	Entretien ambassadeur de Libye en France	Entretien ambassadeur de Libye en France	2019-07-03 14:00:00	2019-07-03 15:00:00	\N	\N	6	0	657	\N
475896	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Don de congés sous forme de chèques-vacances - Audition de la DGT	\N	2020-06-04 08:00:00	2020-06-04 09:00:00	\N	\N	1	0	\N	\N
475897	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Don de congés sous forme de chèques-vacances - Audition de l'ANCV	\N	2020-06-04 13:00:00	2020-06-04 14:00:00	\N	\N	1	0	\N	\N
475944	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule logement - UNIS	\N	2020-04-08 17:00:00	2020-04-08 18:00:00	\N	\N	1	0	\N	\N
475946	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule logement - Union scoail pour l'habitat (USH)	\N	2020-04-09 09:00:00	2020-04-09 10:00:00	\N	\N	3	0	\N	\N
475950	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule logement - Lyon métropole - Aliade habitat	\N	2020-04-09 11:45:00	2020-04-09 13:00:00	\N	\N	2	0	\N	\N
475953	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule logement -FPI	\N	2020-04-09 16:30:00	2020-04-09 17:30:00	\N	\N	2	0	\N	\N
475956	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule logement - Fnaim	\N	2020-04-09 17:45:00	2020-04-09 18:45:00	\N	\N	2	0	\N	\N
475959	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule logement - Fédérations BTP Alpes-Maritimes et Rhône	\N	2020-04-10 10:00:00	2020-04-10 11:00:00	\N	\N	2	0	\N	\N
475962	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule logement - Conseil nationale de l'ordre des architectes (CNOA)	\N	2020-04-10 14:30:00	2020-04-10 15:30:00	\N	\N	2	0	\N	\N
475965	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule logement - Caisse des dépôts	\N	2020-04-10 15:30:00	2020-04-10 16:30:00	\N	\N	2	0	\N	\N
475968	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule logement - Côte d'azur habitat - Erilia	\N	2020-04-10 17:00:00	2020-04-10 18:00:00	\N	\N	2	0	\N	\N
475971	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule logement - Fédération des acteurs de la solidarité	\N	2020-04-14 09:00:00	2020-04-14 10:15:00	\N	\N	2	0	\N	\N
475974	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule logement - Foyer Notre-Dame des sans-abris	\N	2020-04-14 10:15:00	2020-04-14 11:15:00	\N	\N	1	0	\N	\N
475990	COM_EURO	AUDRAP	\N	AFEU	\N	Lutte contre la cybercriminalité - Europol	Lutte contre la cybercriminalité - Europol	2020-06-03 16:30:00	2020-06-03 17:55:00	\N	\N	2	0	\N	\N
475991	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT 2020 Le Grand Paris Express - Didier KLING - PDT CCI Paris IdF	GT 2020 Le Grand Paris Express - Didier KLING - PDT CCI Paris IdF	2020-06-04 17:00:00	2020-06-04 18:05:00	\N	\N	6	0	\N	\N
475999	MISSION	AUDRAP	\N	ILLECTRONISM	\N	Audition de Emmaüs Connect	\N	2020-06-10 18:05:00	2020-06-10 18:50:00	\N	\N	4	0	\N	\N
476002	COM_EURO	AUDRAP	\N	AFEU	\N	Luttre contre la cybercriminalité - Gendarmerie nationale	Lutte contre la cybercriminalité - Gendarmerie nationale	2020-06-03 18:00:00	2020-06-03 19:30:00	\N	\N	2	0	\N	\N
476012	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule logement - Action logement	\N	2020-04-15 10:00:00	2020-04-15 11:00:00	\N	\N	2	0	\N	\N
445753	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2020-01-22 09:30:00	2020-01-22 09:55:00	2020-01-22 12:05:38	2020-01-22 15:46:34	43	1	\N	\N
476015	COM_EURO	AUDRAP	\N	AFEU	\N	Lutte contre la cybercriminalité - DACG	Lutte contre la cybercriminalité - DACG	2020-05-28 09:05:00	2020-05-28 10:40:00	\N	\N	2	0	\N	\N
476020	MISSION	AUDRAP	\N	FEDERATION	\N	Auditions MI FFS	Auditions MI FFS	2020-06-04 14:30:00	2020-06-04 17:50:00	\N	\N	12	0	\N	\N
478717	MISSION	AUDRAP	\N	GUYANE	\N	Audition de M. Antoine Joly, ambassadeur au Suriname et au Guyana	\N	2020-06-17 16:45:00	2020-06-17 17:45:00	\N	\N	4	0	\N	\N
479171	GIA	AUCUNE	\N	\N	\N	audition de l'ONG Portes ouvertes	Présentation de l'indice de persécutiondes chrétiens dans le monde	2020-06-18 10:00:00	2020-06-18 11:15:00	\N	\N	11	0	CHRETORIENT	CHRETORIENT
496188	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat 50-1	Débat 50-1 de la Constitution, relative à l'évolution de la situation sanitaire	2020-10-29 14:30:00	2020-10-29 17:00:00	\N	\N	142	0	\N	\N
496190	SEANCE_PLENIERE	DEBAT	\N	\N	\N	PJL Programmation Recherche	PJL Programmation Recherche pour les années 2020 à 2030	2020-10-30 12:30:00	2020-10-30 13:00:00	\N	\N	28	0	\N	\N
496310	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	PROS	Réunion du bureau de la délégation	Réunion du bureau de la délégation	2020-11-05 08:30:00	2020-11-05 09:20:00	\N	\N	12	0	\N	\N
382234	ETUDES	AUCUNE	\N	\N	\N	Audition de représentants de France Hydro Électricité	Audition de représentants de France Hydro Électricité	2019-05-22 08:15:00	2019-05-22 09:20:00	\N	\N	16	0	\N	906
397778	DELEGATION	AUCUNE	\N	\N	211	Enquête Virage - Violences faites aux femmes dans les outre-mer	Enquête Virage - Violences faites aux femmes dans les outre-mer	2019-07-04 09:00:00	2019-07-04 10:45:00	\N	\N	11	0	\N	\N
397798	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière	Réunion plénière 	2019-07-04 08:30:00	2019-07-04 10:00:00	2019-07-04 11:37:37	\N	13	0	\N	\N
404611	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière	Réunion plénière - Conclusions audition EPR Flamanville - Désignation membre - audition Bertrand Pailhès	2019-07-26 10:00:00	2019-07-26 12:00:00	\N	\N	0	0	\N	\N
408149	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Travailleurs indépendants	\N	2019-10-09 14:00:00	2019-10-09 15:00:00	\N	\N	3	0	\N	\N
408170	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Services de l'Etat dans les territoires - AdCF	Contrôle 2019 - Services de l'Etat dans les territoires - AdCF	2019-09-24 09:30:00	2019-09-24 10:30:00	\N	\N	1	0	\N	\N
408172	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Services de l'Etat dans les territoires - AMF	Contrôle 2019 - Services de l'Etat dans les territoires - AMF	2019-09-24 16:30:00	2019-09-24 17:30:00	\N	\N	1	0	\N	\N
408174	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2019 - Services de l'Etat dans les territoires - Déplacement Saint-Quentin	Contrôle 2019 - Services de l'Etat dans les territoires - Déplacement Saint-Quentin	2019-10-02 12:30:00	2019-10-02 19:30:00	\N	\N	1	0	\N	\N
408179	COM_PERMANENTE	AUTRE	\N	CDD	\N	Audition plénière - Qualité de l'air	\N	2019-10-03 13:00:00	2019-10-03 15:00:00	\N	\N	0	0	\N	\N
408829	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de la commission	Réunion de la commission	2019-10-02 09:05:00	2019-10-02 11:35:00	2019-10-02 11:53:41	2019-10-02 16:04:05	39	1	\N	\N
408953	COM_PERMANENTE	DEPLACEMENT	\N	CDD	\N	Déplacement en Nouvelle-Calédonie	\N	2019-09-01 08:00:00	2019-09-07 19:00:00	\N	\N	6	0	\N	\N
408954	COM_PERMANENTE	DEPLACEMENT	\N	CAE	\N	Déplacement en Inde	Mission annuelle d'information en Inde	2019-09-09 09:00:00	2019-09-13 21:30:00	\N	\N	6	0	\N	\N
409125	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Engagement et proximité - Suite de l'examen des amendements et adoption du texte	PJL Engagement et proximité - Suite de l'examen des amendements et adoption du texte	2019-10-02 17:00:00	2019-10-02 20:30:00	2019-10-02 21:36:17	2019-10-03 15:58:42	31	0	\N	\N
409128	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition FFA	Audition de représentants de la Fédération française de l'assurance	2019-10-02 10:00:00	2019-10-02 11:00:00	\N	\N	3	0	\N	\N
425325	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2020 - Avis Justice judiciaire	PLF pour 2020 - Avis Justice judiciaire	2019-11-12 10:30:00	2019-11-12 12:15:00	\N	\N	1	0	\N	\N
428136	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition difficultés de recrutement et évolution des métiers	Audition difficultés de recrutement et évolution des métiers - MEDEF	2019-11-14 10:10:00	2019-11-14 11:20:00	\N	\N	4	0	\N	\N
428143	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition difficultés de recrutement et évolution des métiers	Audition difficultés de recrutement et évolution des métiers - Centre INFFO	2019-11-14 11:20:00	2019-11-14 12:20:00	\N	\N	2	0	\N	\N
428185	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Culture (Création, Transmission, Démocratisation)	PLF 2020 - Crédits Culture (Création, Transmission, Démocratisation)	2019-11-12 16:30:00	2019-11-12 17:30:00	\N	\N	2	0	\N	\N
428188	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Audiovisuel	PLF 2020 - Crédits Audiovisuel	2019-11-12 14:15:00	2019-11-12 15:15:00	\N	\N	2	0	\N	\N
428189	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Audiovisuel	PLF 2020 - Crédits Audiovisuel	2019-11-12 15:15:00	2019-11-12 16:15:00	\N	\N	1	0	\N	\N
428190	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Audiovisuel	PLF 2020 - Crédits Audiovisuel	2019-11-12 16:15:00	2019-11-12 17:15:00	\N	\N	1	0	\N	\N
428195	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2020 - Crédits Audiovisuel	PLF 2020 - Crédits Audiovisuel	2019-11-13 15:30:00	2019-11-13 16:30:00	\N	\N	2	0	\N	\N
428198	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLFR pour 2019 - Examen des amendements de séance	PLFR pour 2019 - Examen des amendements de séance	2019-11-18 16:05:00	2019-11-18 16:30:00	2019-11-19 09:31:29	2019-11-19 15:04:38	22	0	\N	\N
428199	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2020 - Missions MIRES, RSR et Immigration	PLF pour 2020 - Missions MIRES, RSR et Immigration	2019-11-19 15:35:00	2019-11-19 18:25:00	2019-11-19 18:54:22	2019-11-20 16:35:23	39	0	\N	\N
428286	GIA	AUCUNE	\N	\N	\N	Semaine de la gastronomie marocaine au Sénat 	Réception 	2019-11-12 19:00:00	2019-11-12 21:00:00	\N	\N	2	0	598	\N
428354	GIA	AUCUNE	\N	\N	\N	Semaine de la gastronomie marocaine au Sénat 	Déjeuner de travail avec le ministre de l'éducation nationale du Maroc	2019-11-13 12:30:00	2019-11-13 14:30:00	\N	\N	1	0	598	\N
428356	GIA	AUCUNE	\N	\N	\N	Entretien avec le ministre de l'éducation nationale du Maroc	Entretien avec le ministre de l'éducation nationale du Maroc	2019-11-13 12:30:00	2019-11-13 13:00:00	\N	\N	1	0	598	\N
428202	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2020 - Examen Art 20 et Avis 1ère Partie - Missions Écologie et RCT	PLF pour 2020 - Examen Art 20 et Avis 1ère Partie - Missions Écologie et RCT	2019-11-20 08:35:00	2019-11-20 12:35:00	2019-11-20 13:38:33	2019-11-20 16:36:43	46	0	\N	\N
428497	DELEGATION	AUDRAP	\N	\N	PROS	Audition de la Fédération française de nutrition (FFN)	\N	2019-11-28 10:00:00	2019-11-28 11:30:00	\N	\N	2	0	\N	\N
428871	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PPL prévention suicide agriculteurs	Auditions Mme Férat - PPL prévention du suicide des agriculteurs	2019-11-19 12:30:00	2019-11-19 13:40:00	\N	\N	1	0	\N	\N
428941	COM_SPECIALE	AUDRAP	\N	BIOETHIQUE	\N	Maladies rares du développement génital - Médecins - M. Jomier	\N	2019-12-12 14:00:00	2019-12-12 15:30:00	\N	\N	3	0	\N	\N
429086	ETUDES	AUTRE	\N	\N	\N	Audition plénière	GE Développement économique de la montagne - Application de la loi Montagne II	2019-11-19 16:40:00	2019-11-19 17:40:00	\N	\N	6	0	\N	918
429475	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Économie - Mme Loisier	\N	2019-11-05 15:30:00	2019-11-05 19:30:00	\N	\N	1	0	\N	\N
429477	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Économie - Mme Loisier	\N	2019-11-06 16:30:00	2019-11-06 17:15:00	\N	\N	1	0	\N	\N
429531	ETUDES	AUTRE	\N	\N	\N	ONACVG	\N	2019-11-20 13:45:00	2019-11-20 15:00:00	\N	\N	7	0	\N	928
429840	COM_ENQUETE	PLENIERE	\N	RADICALI	\N	Réunion constitutive	Réunion constitutive	2019-11-26 17:00:00	2019-11-26 17:45:00	2019-11-26 18:20:24	2019-11-27 15:28:42	18	0	\N	\N
429872	GIA	AUCUNE	\N	\N	\N	Rencontre avec M. Roman Sushchenko	Rencontre avec M. Roman Sushchenko, journaliste et ancien détenu en Russie	2019-11-20 14:30:00	2019-11-20 15:00:00	\N	\N	1	0	530	\N
430180	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de Mme Muriel Pénicaud, ministre du travail, sur le PJLF pour 2020.	\N	2019-11-20 16:35:00	2019-11-20 18:25:00	2019-11-20 18:44:43	2019-11-21 10:29:20	26	0	\N	\N
430310	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Examen amdts, en nouvelle lecture, PLFSS pour 2020	\N	2019-11-29 20:10:00	2019-11-29 20:45:00	2019-11-29 20:56:54	2019-12-02 14:04:34	21	1	\N	\N
430494	COM_EURO	AUDRAP	\N	AFEU	\N	Adhésion de l'UE à la CEDH - Audition Ministère de l'Europe et des Affaires étrangères	\N	2019-11-20 18:05:00	2019-11-20 19:05:00	\N	\N	1	0	\N	\N
430530	GIA	AUCUNE	\N	\N	\N	audition de Mme Wafa¿a Al-Saidy, directrice Yémen de Médecins du Monde	\N	2019-11-20 16:30:00	2019-11-20 18:00:00	\N	\N	4	0	627	\N
439851	DELEGATION	AUDRAP	\N	\N	PROS	Audition du Club Demeter	Audition de M. Sébastien Abis	2020-01-21 16:30:00	2020-01-21 17:30:00	\N	\N	1	0	\N	\N
456649	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Inde	\N	2020-02-18 09:00:00	2020-02-18 10:00:00	\N	\N	1	0	\N	\N
456651	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Inde	\N	2020-02-18 10:00:00	2020-02-18 11:10:00	\N	\N	2	0	\N	\N
456654	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Inde	\N	2020-02-18 17:30:00	2020-02-18 18:45:00	\N	\N	2	0	\N	\N
456657	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Inde	\N	2020-02-20 09:00:00	2020-02-20 12:15:00	\N	\N	1	0	\N	\N
456659	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Inde	\N	2020-02-20 14:30:00	2020-02-20 16:10:00	\N	\N	1	0	\N	\N
458981	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Mineurs vulnérables sur le territoire français	PPL Mineurs vulnérables sur le territoire français	2020-03-03 15:45:00	2020-03-03 16:45:00	\N	\N	2	0	\N	\N
462649	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteure	\N	2020-03-11 09:15:00	2020-03-11 12:00:00	\N	\N	1	0	\N	\N
462650	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteure	\N	2020-03-11 14:30:00	2020-03-11 17:00:00	\N	\N	1	0	\N	\N
462653	COM_ENQUETE	AUTRE	\N	RADICALI	\N	Audition de Mmes Razika Adnani et Djemila Benhabib	\N	2020-03-17 12:00:00	2020-03-17 13:00:00	\N	\N	0	0	\N	\N
462654	COM_ENQUETE	PLENIERE	\N	RADICALI	\N	Audition de Mme Marie-Anne Lévêque	Audition de Mme Marie-Anne Lévêque	2020-03-18 10:00:00	2020-03-18 11:00:00	\N	\N	0	0	\N	\N
462655	COM_ENQUETE	AUTRE	\N	RADICALI	\N	Audition de MM. Haoues Seniguer et Mohamed-Ali Adraoui	\N	2020-03-18 11:00:00	2020-03-18 12:15:00	\N	\N	0	0	\N	\N
462656	COM_ENQUETE	AUTRE	\N	RADICALI	\N	Audition de Mme Nadia Remadna	\N	2020-03-18 12:15:00	2020-03-18 14:00:00	\N	\N	0	0	\N	\N
462687	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion 20200319b	\N	2020-03-19 20:10:00	2020-03-19 21:10:00	2020-03-19 21:51:40	2020-03-20 14:23:07	9	0	\N	\N
462688	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion de la commission	Réunion de la commission	2020-03-19 11:15:00	2020-03-19 13:33:00	2020-03-19 14:31:56	2020-03-20 14:23:07	18	0	\N	\N
462689	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission PJL d¿urgence pour faire face à l¿épidémie de Covid-19	\N	2020-03-19 09:35:00	2020-03-19 10:40:00	2020-03-19 11:49:20	2020-03-20 14:23:06	9	0	\N	\N
462690	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PJL Urgence - Epidémie Covid-19	\N	2020-03-19 09:45:00	2020-03-19 11:05:00	2020-03-19 12:17:30	2020-03-20 14:23:07	10	0	\N	\N
462692	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLFR pour 2020 - Examen rapport et désignation CMP	PLFR pour 2020 - Examen rapport et désignation CMP	2020-03-20 11:10:00	2020-03-20 12:35:00	2020-03-20 12:53:20	2020-03-20 14:23:08	15	1	\N	\N
462693	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLFR pour 2020 - Examen des amendements de séance	PLFR pour 2020 - Examen des amendements de séance	2020-03-20 16:40:00	2020-03-20 17:05:00	2020-03-20 20:38:10	2020-03-26 15:17:03	14	1	\N	\N
463427	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion de la commission en visioconférence	\N	2020-04-02 14:30:00	2020-04-02 15:55:00	\N	\N	38	0	\N	\N
476052	COM_EURO	AUDRAP	\N	AFEU	\N	Lutte contre la cybercriminalité - Police nationale	Lutte contre la cybercriminalité - Police nationale - M. Penalba	2020-04-15 16:30:00	2020-04-15 17:55:00	\N	\N	2	0	\N	\N
476054	MISSION	AUDRAP	\N	ILLECTRONISM	\N	Audition de la DINUM	Audition de M. Nadi BOU HANNA, directeur interministériel	2020-06-15 14:05:00	2020-06-15 14:55:00	\N	\N	7	0	\N	\N
476055	MISSION	AUDRAP	\N	ILLECTRONISM	\N	Audition de Mme Divina Frau-Meigs	Audition de Mme Divina Frau-Meigs	2020-06-10 17:05:00	2020-06-10 18:00:00	\N	\N	0	0	\N	\N
476065	COM_EURO	AUDRAP	\N	AFEU	\N	Lutte contre la cybercriminalité - Anssi	Lutte contre la cybercriminalité - Anssi - M. Poupard	2020-04-22 16:30:00	2020-04-22 18:00:00	\N	\N	2	0	\N	\N
476070	MISSION	AUDRAP	\N	ILLECTRONISM	\N	Audition du Conseil national consultatif des Personnes Handicapées (CNCPH) 	Audition de M. Jérémie Boroy, président, et de M. Fernando PINTO DA SILVA, vice-président en charge de l¿accessibilité	2020-06-18 15:00:00	2020-06-18 15:50:00	\N	\N	2	0	\N	\N
429197	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PLF pour 2020 - Examen d'avis budgétaires	\N	2019-11-20 09:00:00	2019-11-20 11:35:00	2019-11-21 15:47:06	2019-11-21 16:32:09	46	0	\N	\N
476072	COM_EURO	AUDRAP	\N	AFEU	\N	Lutte contre la cybercriminalité - GIP ACYMA	Lutte contre la cybercriminalité - GIP ACYMA - M. Notin	2020-04-23 10:00:00	2020-04-23 11:10:00	\N	\N	2	0	\N	\N
476075	COM_EURO	AUDRAP	\N	AFEU	\N	Lutte contre la cybercriminalité - SGAE	Lutte contre la cybercriminalité - SGAE	2020-05-07 09:30:00	2020-05-07 11:00:00	\N	\N	2	0	\N	\N
476078	COM_EURO	AUDRAP	\N	AFEU	\N	Lutte contre la cybercriminalité - Tracfin	Lutte contre la cybercriminalité - Tracfin	2020-05-07 11:00:00	2020-05-07 12:00:00	\N	\N	2	0	\N	\N
476082	COM_EURO	AUDRAP	\N	AFEU	\N	Lutte contre la cybercriminalité - Cour d'Appel de Paris	Lutte contre la cybercriminalité - Cour d'Appel de Paris	2020-05-15 09:30:00	2020-05-15 10:50:00	\N	\N	2	0	\N	\N
476085	COM_EURO	AUDRAP	\N	AFEU	\N	Lutte contre la cybercriminalité - FireEye	Lutte contre la cybercriminalité - FireEye	2020-05-18 18:05:00	2020-05-18 19:20:00	\N	\N	2	0	\N	\N
476090	COM_EURO	AUDRAP	\N	AFEU	\N	Lutte contre la cybercriminalité - Ministère de la Justice	Lutte contre la cybercriminalité - FireEye	2020-05-20 18:00:00	2020-05-20 19:35:00	\N	\N	2	0	\N	\N
476094	COM_EURO	AUDRAP	\N	AFEU	\N	Lutte contre la cybercriminalité - Parquet de Paris	Lutte contre la cybercriminalité - Parquet de Paris	2020-06-05 14:00:00	2020-06-05 15:30:00	\N	\N	2	0	\N	\N
476097	COM_EURO	AUDRAP	\N	AFEU	\N	Lutte contre la cybercriminalité - Ministère de l'intérieur 	\N	2020-06-12 15:00:00	2020-06-12 17:00:00	\N	\N	2	0	\N	\N
476102	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule logement - Ignes	\N	2020-04-20 10:00:00	2020-04-20 10:35:00	\N	\N	2	0	\N	\N
476111	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule logement - ANRU	\N	2020-04-24 14:30:00	2020-04-24 15:30:00	\N	\N	2	0	\N	\N
476119	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule logement - Real Estech	\N	2020-05-04 16:30:00	2020-05-04 17:30:00	\N	\N	2	0	\N	\N
476125	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule logement - GIE La ville autrement	\N	2020-05-11 15:30:00	2020-05-11 16:30:00	\N	\N	2	0	\N	\N
476128	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule logement - Nexity	\N	2020-05-11 16:30:00	2020-05-11 17:30:00	\N	\N	2	0	\N	\N
476131	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule logement - Métropole de Lyon	\N	2020-05-11 17:30:00	2020-05-11 18:30:00	\N	\N	2	0	\N	\N
476132	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de M. Olivier Véran, ministre des solidarités et de la santé	\N	2020-06-10 16:20:00	2020-06-10 18:25:00	2020-06-12 10:39:31	2020-06-12 11:17:07	36	1	\N	\N
476135	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule logement -Think tank Léonard	\N	2020-05-11 17:30:00	2020-05-11 18:30:00	\N	\N	2	0	\N	\N
476138	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule logement - IDEHAL	\N	2020-05-18 15:00:00	2020-05-18 16:00:00	\N	\N	2	0	\N	\N
476141	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule logement - OFCE	\N	2020-05-18 16:00:00	2020-05-18 17:00:00	\N	\N	3	0	\N	\N
476142	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Examen d'un rapport et d'un texte sur une PPL et nomination de rapporteurs	\N	2020-06-10 10:05:00	2020-06-10 11:30:00	2020-06-12 10:16:18	2020-06-12 11:17:12	40	1	\N	\N
476146	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Covid-19 - cellule logement - EPFL pays basque - EPFL PACA - EPFL de l'Oise	\N	2020-05-18 17:00:00	2020-05-18 18:15:00	\N	\N	3	0	\N	\N
476150	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	GT Covid 19 Sport	Audition T. Braillard	2020-06-05 11:00:00	2020-06-05 12:00:00	\N	\N	5	0	\N	\N
476157	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule PME UPSE	Audition cellule PME commerce artisanat	2020-06-05 14:00:00	2020-06-05 15:00:00	\N	\N	5	0	\N	\N
476163	MISSION	AUCUNE	\N	DEPARTEMENT	\N	Audition de l'association des départements de France	\N	2020-06-09 15:05:00	2020-06-09 16:30:00	2020-06-09 19:49:21	2020-06-10 10:48:04	12	0	\N	\N
476164	COM_ENQUETE	PLENIERE	\N	SOLS	\N	Réunion plénière	\N	2020-06-09 16:30:00	2020-06-09 18:00:00	2020-06-10 17:08:15	2020-06-10 18:02:57	5	0	\N	\N
476165	COM_ENQUETE	PLENIERE	\N	SOLS	\N	Réunion plénière	\N	2020-06-10 16:45:00	2020-06-10 17:45:00	2020-06-10 19:49:22	2020-06-11 08:59:24	5	0	\N	\N
476167	ETUDES	AUTRE	\N	\N	\N	Auditions SNAFAM - ETANGS - SMGPF	Auditions GE Chasse et pêche	2020-06-05 09:30:00	2020-06-05 11:45:00	\N	\N	14	0	\N	907
476188	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition 58-2 Le pilotage stratégique par le MEAE des opérateurs de l'AEE	Audition 58-2 sur le pilotage stratégique par le MEAE des opérateurs de l'action extérieure de l'État	2020-06-10 10:35:00	2020-06-10 12:25:00	2020-06-10 15:25:12	2020-06-10 18:43:02	30	0	\N	\N
379744	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Programme 129	Programme 129 - Audition mission interministérielle sur cartographie capacités numérique de l'Etat	2019-05-14 14:30:00	2019-05-14 15:30:00	\N	\N	2	0	\N	\N
380020	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PPL Précarité énergétique	Auditions PPL Précarité énergétique	2019-05-16 09:00:00	2019-05-16 12:15:00	\N	\N	2	0	\N	\N
380025	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PPL Précarité énergétique	Auditions PPL Précarité énergétique	2019-05-15 15:00:00	2019-05-15 17:30:00	\N	\N	1	0	\N	\N
380207	COM_EURO	AUDRAP	\N	AFEU	\N	CGET - Marc Laget	\N	2019-05-15 17:20:00	2019-05-15 18:05:00	\N	\N	0	0	\N	\N
386343	GIA	AUCUNE	\N	\N	\N	Entretien avec la ministre de la Défense de Macédoine du Nord	Entretien avec la ministre de la Défense de Macédoine du Nord	2019-06-05 14:55:00	2019-06-05 16:10:00	\N	\N	2	0	674	\N
402731	MISSION	AUCUNE	\N	TRANSPORTS	\N	Réunion rapport	\N	2019-07-18 13:58:00	2019-07-18 14:55:00	2019-07-19 16:17:20	2019-07-19 16:21:46	13	0	\N	\N
402779	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	GEAC - Audition GIFAS	\N	2019-07-18 08:30:00	2019-07-18 10:00:00	\N	\N	0	0	\N	\N
404795	COM_ENQUETE	PLENIERE	\N	SOUVERAINETE	\N	Audition de C. Castaner et INRIA	\N	2019-09-02 14:00:00	2019-09-02 16:30:00	2019-09-12 10:01:29	2019-09-12 15:34:46	9	0	\N	\N
404796	COM_ENQUETE	PLENIERE	\N	SOUVERAINETE	\N	Auditions N. Belloubet, F. Parly	\N	2019-09-03 09:30:00	2019-09-03 12:35:00	2019-09-12 10:00:50	2019-09-12 15:34:46	12	0	\N	\N
409431	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de M. Didier Migaud, premier président de la Cour des comptes	Audition de M. Didier Migaud, premier président de la Cour des comptes	2019-10-09 09:35:00	2019-10-09 12:35:00	2019-10-09 17:57:00	2019-10-09 17:57:02	43	0	\N	\N
411908	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Tourisme	\N	2019-10-08 14:00:00	2019-10-08 14:30:00	\N	\N	9	0	\N	\N
413495	MISSION	AUCUNE	\N	BREXIT2	\N	réunion du 9 octobre 2019	réunion du 9 octobre 2019	2019-10-09 18:35:00	2019-10-09 19:45:00	2019-10-11 09:09:03	\N	10	0	\N	\N
414027	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-10-15 09:30:00	2019-10-15 10:30:00	2019-10-15 11:36:46	2019-10-15 17:52:04	27	0	\N	\N
414028	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-10-15 15:00:00	2019-10-15 16:35:00	2019-10-16 09:44:19	2019-10-16 17:30:41	35	0	\N	\N
414029	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-10-16 09:00:00	2019-10-16 12:50:00	2019-10-16 15:09:29	2019-10-16 17:31:00	41	0	\N	\N
400567	CMP	AUTRE	\N	ALSACE	\N	PJL Collectivité européenne d'Alsace	PJL Collectivité européenne d'Alsace	2019-07-11 14:05:00	2019-07-11 14:50:00	\N	\N	8	0	\N	\N
417482	COM_SPECIALE	PLENIERE	\N	BIOETHIQUE	\N	Réunion constitutive	\N	2019-10-24 10:15:00	2019-10-24 11:05:00	2019-10-24 11:24:02	2019-10-24 17:38:24	25	0	\N	\N
421829	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Agir contre les violences au sein de la famille	PPL Violences au sein de la famille	2019-10-29 15:20:00	2019-10-29 16:10:00	\N	\N	1	0	\N	\N
427728	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition budgétaire du ministère de l'intérieur et nomination d'un rapporteur	Audition budgétaire du ministère de l'intérieur et nomination d'un rapporteur (PJL article 13 Constitution)	2019-11-14 10:45:00	2019-11-14 13:00:00	2019-11-14 15:34:06	2019-11-14 16:59:20	24	0	\N	\N
427737	COM_EURO	AUDRAP	\N	AFEU	\N	Adhésion de l'UE à la CEDH - Audition Secrétariat Général des Affaires Européennes	\N	2019-11-13 17:05:00	2019-11-13 18:40:00	\N	\N	2	0	\N	\N
427783	ETUDES	AUTRE	\N	\N	\N	Audition plénière	Audition Pierre Dubreuil OFB	2019-11-14 08:00:00	2019-11-14 09:15:00	\N	\N	10	0	\N	907
427797	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 21 novembre - Audition	\N	2019-11-21 08:35:00	2019-11-21 10:20:00	2019-11-21 15:07:07	2019-11-21 15:13:14	11	0	\N	\N
428147	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Anciens combattants, mémoire et liens avec la Nation	\N	2019-11-13 14:00:00	2019-11-13 15:00:00	\N	\N	2	0	\N	\N
439815	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2020-01-22 15:00:00	2020-01-22 16:15:00	\N	\N	292	0	\N	\N
439816	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Bioéthique	PJL Bioéthique	2020-01-22 16:30:00	2020-01-22 19:30:00	\N	\N	148	0	\N	\N
439817	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Bioéthique	PJL Bioéthique	2020-01-22 21:30:00	2020-01-23 00:00:00	\N	\N	88	0	\N	\N
439818	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Bioéthique	PJL Bioéthique	2020-01-23 10:30:00	2020-01-23 13:00:00	\N	\N	89	0	\N	\N
439819	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Bioéthique	PJL Bioéthique	2020-01-23 14:30:00	2020-01-23 19:00:00	\N	\N	81	0	\N	\N
439820	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Bioéthique	PJL Bioéthique	2020-01-23 21:35:00	2020-01-24 00:10:00	\N	\N	40	0	\N	\N
439821	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Bioéthique	PJL Bioéthique	2020-01-28 15:02:00	2020-01-28 20:05:00	\N	\N	174	0	\N	\N
439822	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Bioéthique	PJL Bioéthique	2020-01-28 21:36:00	2020-01-29 00:03:00	\N	\N	99	0	\N	\N
439823	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2020-01-29 15:01:00	2020-01-29 16:19:00	\N	\N	281	0	\N	\N
439824	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Bioéthique	PJL Bioéthique	2020-01-29 16:33:00	2020-01-29 19:06:00	\N	\N	104	0	\N	\N
439826	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL France-Burkina Faso	PJL France-Burkina Faso	2020-01-30 10:33:00	2020-01-30 11:34:00	\N	\N	29	0	\N	\N
439827	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL France-Botswana	PJL France-Botswana	2020-01-30 11:35:00	2020-01-30 12:24:00	\N	\N	21	0	\N	\N
439828	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	NL PPL Lutter contre les contenus haineux sur internet 	NL PPL Lutter contre les contenus haineux sur internet 	2020-02-26 17:19:00	2020-02-26 19:28:00	\N	\N	60	0	\N	\N
449526	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Assurance récolte	GT Assurance récolte	2020-01-28 10:00:00	2020-01-28 11:15:00	\N	\N	6	0	\N	\N
449536	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Assurance récolte	GT Assurance récolte	2020-01-28 13:40:00	2020-01-28 14:20:00	\N	\N	4	0	\N	\N
449583	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Assurance récolte	GT Assurance récolte	2020-01-28 14:20:00	2020-01-28 15:15:00	\N	\N	4	0	\N	\N
449745	ETUDES	AUCUNE	\N	\N	\N	GE Élevage - Audition ONV	GE Élevage - Audition ONV	2020-01-29 08:00:00	2020-01-29 09:00:00	\N	\N	9	0	\N	911
450969	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Convention européenne d'extradition	Convention européenne d'extradition	2020-02-04 09:00:00	2020-02-04 09:30:00	\N	\N	1	0	\N	\N
452811	GIA	AUCUNE	\N	\N	\N	Audition du P. Jean-Marie Carrière sj sur les migrants	Audition du P. Jean-Marie Carrière sj sur "Migrants : Peut-on accueillir tout le monde ?"	2020-02-05 13:30:00	2020-02-05 15:00:00	\N	\N	9	0	629	\N
452906	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL Convention franco-suisse reconnaissance des poinçons officiels	\N	2020-02-04 15:55:00	2020-02-04 16:25:00	\N	\N	1	0	\N	\N
452908	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL Convention franco-suisse reconnaissance des poinçons officiels	\N	2020-02-05 13:55:00	2020-02-05 14:50:00	\N	\N	1	0	\N	\N
453223	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 5 février 2020 - 14h	Réunion du 5 février 2020 - 14h	2020-02-05 14:00:00	2020-02-05 14:50:00	2020-02-05 16:28:59	2020-02-05 18:11:30	12	0	\N	\N
453493	COM_PERMANENTE	GROUPE_TRAVAIL	\N	AFCL	\N	Horaires d'ouverture des bibliothèques	Horaires d'ouverture des bibliothèques	2020-02-05 11:30:00	2020-02-05 12:30:00	\N	\N	3	0	\N	\N
454092	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - Les aides à la presse - SNDP	Contrôle 2020 - Les aides à la presse - SNDP	2020-02-07 17:00:00	2020-02-07 18:00:00	\N	\N	1	0	\N	\N
454632	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-02-18 17:30:00	2020-02-18 19:30:00	2020-02-18 20:41:34	2020-02-19 16:09:46	33	0	\N	\N
454721	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Système universel de retraite	\N	2020-02-18 14:30:00	2020-02-18 15:15:00	\N	\N	1	0	\N	\N
450934	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Déplacement au Cenzub (Sissonne)	Déplacement au centre d'entraînement en zone urbaine CENZUB à Sissonne	2020-01-23 08:00:00	2020-01-23 18:00:00	\N	\N	7	0	\N	\N
454055	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2020-02-19 10:00:00	2020-02-19 11:30:00	2020-02-19 12:20:22	2020-02-19 16:09:40	41	1	\N	\N
454065	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2020-02-19 13:35:00	2020-02-19 15:00:00	2020-02-19 15:54:57	2020-02-19 16:09:38	39	0	\N	\N
454067	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2020-02-19 17:05:00	2020-02-19 18:15:00	2020-02-20 15:22:41	2020-02-20 16:26:05	29	0	\N	\N
473405	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Alimentation durable et locale-CNRS	Covid-19-Alimentation durable et locale-CNRS	2020-05-12 16:00:00	2020-05-12 17:00:00	\N	\N	15	0	\N	\N
473413	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Alimentation durable et locale-Confédération paysanne	Covid-19-Alimentation durable et locale-Confédération paysanne	2020-05-12 17:00:00	2020-05-12 18:00:00	\N	\N	17	0	\N	\N
454054	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2020-02-19 09:30:00	2020-02-19 10:00:00	2020-02-19 12:14:26	2020-02-19 16:09:44	41	1	\N	\N
473439	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Alimentation durable et locale-FNAB	Covid-19-Alimentation durable et locale-FNAB	2020-05-14 11:30:00	2020-05-14 12:30:00	\N	\N	13	0	\N	\N
473451	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Covid-19-Accès aux services de santé-Secteur du thermalisme	Covid-19-Accès aux services de santé-Secteur du thermalisme	2020-05-19 14:30:00	2020-05-19 16:00:00	\N	\N	7	0	\N	\N
481194	COM_ENQUETE	AUDRAP	\N	SOLS	\N	Audition rapportrice	\N	2020-06-25 15:00:00	2020-06-25 15:50:00	\N	\N	3	0	\N	\N
481200	COM_ENQUETE	AUDRAP	\N	SOLS	\N	Audition rapportrice	\N	2020-06-25 16:00:00	2020-06-25 17:15:00	\N	\N	2	0	\N	\N
481286	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Prévention de la perte d'autonomie - Audition de la CNAV	\N	2020-06-26 09:00:00	2020-06-26 10:00:00	\N	\N	6	0	\N	\N
481297	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 25 juin -10h30 de la commission des affaires européennes	Réunion du 25 juin -10h30 de la commission des affaires européennes	2020-06-25 10:35:00	2020-06-25 12:00:00	2020-06-26 17:54:25	2020-06-30 15:30:05	34	0	\N	\N
483408	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	\N	2020-07-02 17:30:00	2020-07-02 19:00:00	\N	\N	1	0	\N	\N
483415	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition cellule tourisme table ronde guides	\N	2020-07-03 11:15:00	2020-07-03 12:15:00	\N	\N	4	0	\N	\N
485084	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Mesures de sûreté contre les auteurs d'infractions terroristes	PPL Mesures de sûreté contre les auteurs d'infractions terroristes	2020-07-07 17:00:00	2020-07-07 18:15:00	\N	\N	3	0	\N	\N
485088	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Mesures de sûreté contre les auteurs d'infractions terroristes	PPL Mesures de sûreté contre les auteurs d'infractions terroristes	2020-07-07 18:15:00	2020-07-07 18:50:00	\N	\N	4	0	\N	\N
485095	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Mesures de sûreté contre les auteurs d'infractions terroristes	PPL Mesures de sûreté contre les auteurs d'infractions terroristes	2020-07-07 18:50:00	2020-07-07 19:40:00	\N	\N	3	0	\N	\N
485099	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Mesures de sûreté contre les auteurs d'infractions terroristes	PPL Mesures de sûreté contre les auteurs d'infractions terroristes	2020-07-08 14:00:00	2020-07-08 14:50:00	\N	\N	2	0	\N	\N
485102	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Mesures de sûreté contre les auteurs d'infractions terroristes	PPL Mesures de sûreté contre les auteurs d'infractions terroristes	2020-07-08 16:05:00	2020-07-08 17:50:00	\N	\N	2	0	\N	\N
485106	DELEGATION	AUDRAP	\N	\N	206	Audition Coronavirus - Haïm Korsia	Audition Coronavirus - Haïm Korsia	2020-06-15 17:00:00	2020-06-15 18:00:00	\N	\N	3	0	\N	\N
485110	DELEGATION	AUDRAP	\N	\N	206	Audition Coronavirus - Groupe Funecap	Audition Coronavirus - Groupe Funecap	2020-06-15 16:00:00	2020-06-15 17:00:00	\N	\N	2	0	\N	\N
485123	DELEGATION	AUDRAP	\N	\N	206	Audition Coronavirus - Jean-Pierre Sakoun et Gilbert Abergel	Audition Coronavirus - Jean-Pierre Sakoun et Gilbert Abergel	2020-06-24 18:30:00	2020-06-24 19:30:00	\N	\N	1	0	\N	\N
490467	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion de commission	\N	2020-10-07 11:05:00	2020-10-07 11:50:00	2020-10-07 12:09:32	2020-10-07 18:04:32	49	0	\N	\N
490470	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de MM. Véran et Dussopt	\N	2020-10-07 18:30:00	2020-10-07 20:20:00	2020-10-07 20:40:02	2020-10-08 18:30:31	32	0	\N	\N
490471	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de la Cour des comptes	\N	2020-10-08 10:30:00	2020-10-08 12:25:00	2020-10-08 12:28:45	2020-10-08 18:30:32	23	0	\N	\N
490472	COM_ENQUETE	PLENIERE	\N	PANDEMIE	\N	Audition M. Cédrtic O	\N	2020-10-08 14:30:00	2020-10-08 16:05:00	2020-10-08 16:04:45	2020-10-08 18:30:45	13	0	\N	\N
490473	COM_SPECIALE	AUTRE	\N	BIOETHIQUE	\N	Réunion constitutive	\N	2020-10-07 16:15:00	2020-10-07 16:20:00	2020-10-07 18:23:20	2020-10-08 18:30:44	20	0	\N	\N
490474	COM_ENQUETE	PLENIERE	\N	PANDEMIE	\N	Consitution du bureau de la commission	\N	2020-10-07 17:20:00	2020-10-07 17:50:00	2020-10-07 18:24:18	2020-10-08 18:30:45	18	0	\N	\N
490475	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	LPPR	\N	2020-09-24 14:30:00	2020-09-24 17:30:00	\N	\N	0	0	\N	\N
496311	DELEGATION	AUCUNE	\N	\N	PROS	Audition de M. Erik Orsenna	Audition de M. Erik Orsenna	2020-11-26 08:30:00	2020-11-26 10:00:00	\N	\N	18	0	\N	\N
496375	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2021 - Assurance maladie - Audition conjointe de la DGOS et de la DSS	\N	2020-10-27 15:00:00	2020-10-27 16:40:00	\N	\N	4	0	\N	\N
496382	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2021 - Autonomie - Audition de APF France handicap	\N	2020-10-27 14:00:00	2020-10-27 15:00:00	\N	\N	1	0	\N	\N
497010	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLFSS2021-Examen Rapport - PLF2021-Missions Santé/RSR/CCE et PP	PLFSS2021-Examen Rapport - PLF2021-Missions Santé/RSR/CCE et PP	2020-11-03 14:35:00	2020-11-03 17:00:00	2020-11-03 17:17:00	2020-11-03 17:51:22	36	0	\N	\N
497011	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF 2021-Missions Justice et Immigration, Asile et intégration, Économie et Travail Emploi	PLF pour 2021-Missions Justice et Immigration, Asile et intégration, Économie et Travail et emploi, 	2020-11-04 09:00:00	2020-11-04 12:05:00	2020-11-04 13:06:40	2020-11-04 15:46:34	44	0	\N	\N
497039	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLFR pour 2020 (4) - Audition Olivier DUSSOPT, ministre délégué - PLF 2021 - Examen Tome 1	PLFR pour 2020 (4) - Audition de M. Olivier DUSSOPT, ministre délégué Puis - PLF pour 2021 - Examen Tome 1	2020-11-05 09:35:00	2020-11-05 12:25:00	2020-11-05 12:53:52	2020-11-05 14:56:36	37	0	\N	\N
497087	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2021 - mission Outre-mer	\N	2020-10-28 16:00:00	2020-10-28 18:00:00	\N	\N	4	0	\N	\N
497817	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2020-11-03 15:00:00	2020-11-03 19:00:00	\N	\N	66	0	\N	\N
497834	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2021 - Accidents du travail - Maladies professionnellees - Audition CNPMT	PLFSS 2021 - Accidents du travail - Maladies professionnellees - Audition CNPMT	2020-10-29 10:35:00	2020-10-29 11:30:00	\N	\N	1	0	\N	\N
497844	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2020-11-05 15:30:00	2020-11-05 17:54:00	2020-11-05 18:06:49	2020-11-05 18:15:38	35	0	\N	\N
497845	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2020-11-04 09:30:00	2020-11-04 11:40:00	2020-11-04 16:24:10	2020-11-04 16:50:55	34	0	\N	\N
497846	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2020-11-04 16:30:00	2020-11-04 18:30:00	2020-11-05 16:24:37	2020-11-05 16:38:50	50	0	\N	\N
497979	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 4/11/2020 Audition Laura Kovesi	\N	2020-11-04 13:30:00	2020-11-04 15:00:00	2020-11-04 15:36:01	2020-11-04 15:59:28	23	0	\N	\N
497980	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 5/11/2020	Réunion du 5/11/2020 - Audition de Mme Ylva Johansson	2020-11-05 08:35:00	2020-11-05 10:20:00	2020-11-05 12:11:56	2020-11-05 15:52:16	18	0	\N	\N
497987	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJLF 2021 - Mission Santé - Audition de la DGS	PJLF 2021 - Mission Santé - Audition de la DGS	2020-11-05 15:00:00	2020-11-05 16:00:00	\N	\N	2	0	\N	\N
376551	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	Contrôle des comptes	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne 	2019-05-07 14:30:00	2019-05-07 15:45:00	2019-05-07 17:50:44	2019-05-09 17:08:58	7	0	\N	\N
377785	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition plénière	\N	2019-05-15 10:30:00	2019-05-15 12:30:00	2019-05-15 17:59:56	2019-05-16 15:00:11	32	0	\N	\N
378460	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Mme Gruny M. Artano MI Santé au travail	\N	2019-05-14 17:45:00	2019-05-14 19:00:00	\N	\N	2	0	\N	\N
379350	DELEGATION	AUCUNE	\N	\N	211	Table ronde "Rayonnement de la coupe du monde 2019"	Table ronde "Rayonnement de la coupe du monde 2019"	2019-05-16 09:30:00	2019-05-16 12:40:00	\N	\N	10	0	\N	\N
379917	MISSION	AUCUNE	\N	CLIMATIQUE	\N	Echanges de vue sur les orientations du rapport	Echanges de vue sur les orientations du rapport	2019-05-15 16:40:00	2019-05-15 17:30:00	2019-05-17 09:58:37	2019-05-17 10:17:07	11	0	\N	\N
379951	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Sources de financement du logement social - DHUP / DB	Contrôle 2019 - Sources de financement du logement social - DHUP / DB	2019-05-14 09:00:00	2019-05-14 11:00:00	\N	\N	1	0	\N	\N
379957	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Sources de financement du logement social - EPL	Contrôle 2019 - Sources de financement du logement social - EPL	2019-05-16 14:15:00	2019-05-16 15:00:00	\N	\N	1	0	\N	\N
379966	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Sources de financement du logement social - Action logement / ESH	Contrôle 2019 - Sources de financement du logement social - Action logement / ESH	2019-05-16 16:00:00	2019-05-16 18:20:00	\N	\N	1	0	\N	\N
380023	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL pour la restauration et la conservation de Notre-Dame de Paris	PJL pour la restauration et la conservation de Notre-Dame de Paris	2019-05-13 14:30:00	2019-05-13 15:30:00	\N	\N	4	0	\N	\N
380024	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL pour la restauration et la conservation de Notre-Dame de Paris	PJL pour la restauration et la conservation de Notre-Dame de Paris	2019-05-13 15:30:00	2019-05-13 19:30:00	\N	\N	6	0	\N	\N
380037	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL pour la restauration et la conservation de Notre-Dame de Paris	PJL pour la restauration et la conservation de Notre-Dame de Paris	2019-05-16 16:30:00	2019-05-16 19:00:00	\N	\N	1	0	\N	\N
380101	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Taxe sur les services numériques -  OCDE	PJL Taxe sur les services numériques - OCDE	2019-05-13 16:30:00	2019-05-13 17:30:00	\N	\N	2	0	\N	\N
380104	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Notre-Dame - Association des biens français du patrimoine mondial	PJL Notre-Dame - Association des biens français du patrimoine mondial	2019-05-13 14:30:00	2019-05-13 15:30:00	\N	\N	1	0	\N	\N
380106	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Notre-Dame - Compagnie des ACMH	PJL Notre-Dame - Compagnie des ACMH	2019-05-13 16:30:00	2019-05-13 17:30:00	\N	\N	1	0	\N	\N
380120	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Notre-Dame - Direction générale du patrimoine	PJL Notre-Dame - Direction générale du patrimoine	2019-05-13 17:30:00	2019-05-13 19:00:00	\N	\N	2	0	\N	\N
380123	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Notre Dame - Fondation du patrimoine	PJL Notre Dame - Fondation du patrimoine	2019-05-15 14:45:00	2019-05-15 15:30:00	\N	\N	2	0	\N	\N
380128	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Notre Dame - Ministre de la Culture	PJL Notre Dame - Ministre de la Culture	2019-05-16 11:30:00	2019-05-16 13:15:00	\N	\N	2	0	\N	\N
380132	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Notre Dame - Centre des monuments nationaux	PJL Notre Dame - Centre des monuments nationaux	2019-05-16 16:00:00	2019-05-16 16:45:00	\N	\N	2	0	\N	\N
380149	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	\N	\N	2019-05-14 15:00:00	2019-05-14 16:00:00	\N	\N	0	0	\N	\N
380150	COM_PERMANENTE	DEPLACEMENT	\N	SOCI	\N	Déplacement de MM. Morisset et Arnell	\N	2019-05-22 14:30:00	2019-05-22 16:15:00	\N	\N	2	0	\N	\N
380156	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2020 - Immigration, asile et intégration - DGEF	PLF pour 2020 - Immigration, asile et intégration - DGEF	2019-05-16 08:30:00	2019-05-16 10:30:00	\N	\N	1	0	\N	\N
380158	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2020 - Sécurités - Déplacement DCPAF	PLF pour 2020 - Sécurités - Déplacement DCPAF	2019-05-17 10:30:00	2019-05-17 13:15:00	\N	\N	1	0	\N	\N
386231	DELEGATION	DEPLACEMENT	\N	\N	COLTER	Réunions Auditions "hors les murs" Mâcon : irritants de la loi NOTRe	\N	2019-06-17 09:50:00	2019-06-17 21:15:00	\N	\N	0	0	\N	\N
386240	DELEGATION	AUCUNE	\N	\N	COLTER	Réunion plénière "hors les murs" Mâcon : irritants de la loi NOTRe	\N	2019-06-17 14:45:00	2019-06-17 17:00:00	2019-06-18 15:48:51	\N	6	0	\N	\N
387736	DELEGATION	AUCUNE	\N	\N	206	Petit-déjeuner avec les Académies sur le thème de la cybersécurité	Petit-déjeuner avec les Académies sur le thème de la cybersécurité	2019-06-19 08:30:00	2019-06-19 10:10:00	\N	\N	9	0	\N	\N
393757	COM_PERMANENTE	AUTRE	\N	FINC	\N	Contrôle avenir Stade de France et Audition Didier MIGAUD perspectives finances publiques	Contrôle avenir Stade de France et Audition Didier MIGAUD perspectives des finances publiques	2019-06-26 10:05:00	2019-06-26 13:00:00	2019-06-26 15:05:29	2019-06-26 18:36:20	37	0	\N	\N
393770	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition Mmes Agnès BUZYN, ministre et Christelle DUBOS, secrétaire d'État sur le PJLR2018	Audition de Mmes Agnès BUZYN, ministre et Christelle DUBOS, secrétaire d'État sur le PJLR pour 2018	2019-06-26 16:35:00	2019-06-26 17:55:00	2019-06-27 11:50:51	2019-06-27 12:02:23	21	0	\N	\N
393772	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Stade de France - Direction du budget	Contrôle 2019 - Stade de France - Direction du budget	2019-06-18 14:30:00	2019-06-18 15:30:00	\N	\N	1	0	\N	\N
393774	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Stade de France - Solidéo	Contrôle 2019 - Stade de France - Solidéo	2019-06-19 14:00:00	2019-06-19 15:00:00	\N	\N	1	0	\N	\N
393778	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - L'inspection du travail - Table-ronde syndicats salariés	Contrôle 2019 - L'inspection du travail - Table-ronde syndicats salariés	2019-06-19 14:45:00	2019-06-19 16:00:00	\N	\N	2	0	\N	\N
393781	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - L'inspection du travail - OIT	Contrôle 2019 - L'inspection du travail - OIT	2019-06-20 12:00:00	2019-06-20 12:45:00	\N	\N	1	0	\N	\N
393783	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - ZRR - Député	Contrôle 2019 - ZRR - Député	2019-06-19 11:30:00	2019-06-19 12:30:00	\N	\N	3	0	\N	\N
393787	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - ZRR - Acteurs médico-sociaux	Contrôle 2019 - ZRR - Acteurs médico-sociaux	2019-06-20 16:30:00	2019-06-20 18:00:00	\N	\N	2	0	\N	\N
393812	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Fraude aux fonds européens - ARF / DGPE	Contrôle 2019 - Fraude aux fonds européens - ARF / DGPE	2019-06-20 13:30:00	2019-06-20 15:00:00	\N	\N	1	0	\N	\N
377784	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion de commission	\N	2019-05-15 09:30:00	2019-05-15 10:30:00	2019-05-15 17:58:08	2019-05-16 15:00:12	44	0	\N	\N
393816	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Évaluation transf. ISF en IFI et création PFU - Terra Nova & Jean Jaurès	Contrôle 2019 - Évaluation transformation ISF en IFI et création PFU - Terra Nova et Fondation Jean Jaurès	2019-06-19 15:00:00	2019-06-19 16:30:00	\N	\N	2	0	\N	\N
393819	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2019 - Évaluation transformation ISF en IFI et création PFU - Université Harvard	Contrôle 2019 - Évaluation transformation ISF en IFI et création PFU - Université Harvard	2019-06-19 18:30:00	2019-06-19 19:10:00	\N	\N	2	0	\N	\N
393822	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Prestation de compensation du handicap	\N	2019-07-16 14:00:00	2019-07-16 18:45:00	\N	\N	1	0	\N	\N
393824	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Prestation de compensation du handicap	\N	2019-06-25 08:00:00	2019-06-25 09:00:00	\N	\N	1	0	\N	\N
393856	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	UMF	\N	2019-07-09 14:30:00	2019-07-09 15:15:00	\N	\N	0	0	\N	\N
393859	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Emploi des seniors	\N	2019-06-26 18:00:00	2019-06-26 19:00:00	\N	\N	2	0	\N	\N
393862	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Jeux Olympiques et Paralympiques de 2024	PJL Jeux Olympiques et Paralympiques de 2024	2019-06-19 16:30:00	2019-06-19 17:30:00	\N	\N	3	0	\N	\N
393863	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Jeux Olympiques et Paralympiques de 2024	PJL Jeux Olympiques et Paralympiques de 2024	2019-06-19 18:00:00	2019-06-19 19:00:00	\N	\N	3	0	\N	\N
393864	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Jeux Olympiques et Paralympiques de 2024	PJL Jeux Olympiques et Paralympiques de 2024	2019-06-20 11:00:00	2019-06-20 12:00:00	\N	\N	2	0	\N	\N
519128	DELEGATION	AUDRAP	\N	\N	PROS	Audition de l'ANCT	Audition de M. Yves Le Breton, directeur général de l'ANCT	2021-01-21 17:30:00	2021-01-21 18:40:00	\N	\N	1	0	\N	\N
519130	DELEGATION	AUDRAP	\N	\N	PROS	Audition fédération des SCoT	Audition de Mme Stella GASS, directrice de la Fédération nationale des SCoT	2021-02-10 16:30:00	2021-02-10 17:30:00	\N	\N	1	0	\N	\N
519135	DELEGATION	AUCUNE	\N	\N	211	Échange de vues - audition de M. Cyprien Canivenc et de Mme Emma Rouvet	Échange de vues - audition de M. Cyprien Canivenc et de Mme Emma Rouvet	2021-01-14 08:30:00	2021-01-14 11:15:00	2021-01-14 12:32:59	\N	22	0	\N	\N
519136	DELEGATION	AUCUNE	\N	\N	211	Audition de Mme Salomé Berlioux	Audition de Mme Salomé Berlioux	2021-02-04 09:00:00	2021-02-04 10:25:00	2021-02-04 11:33:36	\N	11	0	\N	\N
519137	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition commune CNAJEP et UNHAJ	\N	2021-01-04 14:30:00	2021-01-04 15:30:00	\N	\N	1	0	\N	\N
519138	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Table ronde associations	\N	2021-01-04 15:30:00	2021-01-04 16:30:00	\N	\N	2	0	\N	\N
519139	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Observatoire des inégalités	\N	2021-01-05 14:30:00	2021-01-05 16:15:00	\N	\N	4	0	\N	\N
519307	DELEGATION	AUDRAP	\N	\N	206	Audition de Mme  Agnès Pannier-Runacher, ministre déléguée chargée de l'industrie	Audition Stratégie vaccinale de Mme Agnès Pannier-Runacher, ministre déléguée chargée de l'industrie	2021-01-12 17:15:00	2021-01-12 18:20:00	\N	\N	12	0	\N	\N
519602	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière - Audition du Haut Conseil pour le Climat	Réunion plénière - Audition du Haut Conseil pour le Climat	2021-01-21 09:35:00	2021-01-21 11:00:00	\N	\N	15	0	\N	\N
526514	GIA	AUCUNE	\N	\N	\N	Assemblée générale GIA France-Canada	Assemblée générale GIA France-Canada	2021-01-20 14:00:00	2021-01-20 14:25:00	\N	\N	18	0	583	\N
532383	GIA	AUCUNE	\N	\N	\N	Audition de représentants de l'ONG Portes Ouvertes sur la situation des Chrétiens au MO	Audition de représentants de l'ONG Portes Ouvertes sur la situation des Chrétiens au Moyen-Orient 	2021-02-16 15:30:00	2021-02-16 16:30:00	\N	\N	30	0	CHRETORIENT	CHRETORIENT
532438	GIA	AUCUNE	\N	\N	\N	Audition de Mgr GOLLNISCH, sur les actions de l'oeuvre d'Orient	Audition  de Mgr GOLLNISCH, sur la situation des Chrétiens au Moyen-Orient et les actions de l¿¿uvre d¿Orient	2021-02-16 16:30:00	2021-02-16 17:30:00	\N	\N	30	0	CHRETORIENT	CHRETORIENT
534663	ETUDES	AUTRE	\N	\N	\N	Audition de l'Institut national du cancer (INCa)	\N	2021-03-02 14:00:00	2021-03-02 15:35:00	\N	\N	12	0	\N	1004
534905	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-03-09 17:30:00	2021-03-09 18:38:00	2021-03-10 12:36:04	2021-03-10 17:11:56	23	0	\N	\N
534915	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-03-10 10:08:00	2021-03-10 12:10:00	2021-03-10 12:40:24	2021-03-10 17:12:04	41	0	\N	\N
542816	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition AFD et Expertise France	\N	2021-03-24 09:30:00	2021-03-24 11:30:00	2021-03-24 14:35:46	2021-03-24 17:39:16	34	0	\N	\N
542978	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL développement solidaire	PJL développement solidaire	2021-03-18 14:00:00	2021-03-18 15:00:00	\N	\N	2	0	\N	\N
542981	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL Dév	PJL Développement solidaire	2021-03-18 15:15:00	2021-03-18 16:15:00	\N	\N	2	0	\N	\N
543487	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	Webinaire, organisé conjointement par l¿UIP et la Commission économique des Nations Unies 	Webinaire, organisé conjointement par l¿UIP et la Commission économique des Nations Unies pour l¿Europe (CEE-ONU)	2021-03-09 14:30:00	2021-03-09 16:00:00	\N	\N	3	0	\N	\N
544762	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-03-24 18:49:00	2021-03-24 20:00:00	2021-03-26 09:50:26	2021-03-26 15:15:11	22	0	\N	\N
551735	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2021-04-14 15:00:00	2021-04-14 16:15:00	\N	\N	212	0	\N	\N
551736	SEANCE_PLENIERE	DECL_GVT	\N	\N	\N	Déclaration du Gouvernement	Déclaration du Gouvernement	2021-04-14 16:30:00	2021-04-14 18:45:00	\N	\N	196	0	\N	\N
555253	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Dérèglement climatique et résilience - Auditions de M. Pascal Martin	PJL Dérèglement climatique et résilience - Auditions de M. Pascal Martin	2021-04-27 08:30:00	2021-04-27 11:05:00	\N	\N	1	0	\N	\N
555265	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de M. Olivier DUSSOPT sur le PNRR	Audition de M. Olivier DUSSOPT sur le PNRR	2021-04-27 19:20:00	2021-04-27 20:10:00	2021-04-27 20:24:04	2021-04-28 10:39:37	24	0	\N	\N
555270	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PJL Climat Forêt	\N	2021-04-27 15:00:00	2021-04-27 16:00:00	\N	\N	1	0	\N	\N
555276	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PJL Climat Forêt	Auditions PJL Climat Forêt	2021-04-27 10:15:00	2021-04-27 11:00:00	\N	\N	1	0	\N	\N
555279	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PJL Climat Forêt	Auditions PJL Climat Forêt	2021-04-26 14:45:00	2021-04-26 17:30:00	\N	\N	1	0	\N	\N
555281	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PJL Climat Forêt	Auditions PJL Climat Forêt	2021-04-26 09:30:00	2021-04-26 12:00:00	\N	\N	1	0	\N	\N
555291	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PJL Climat Volet Consommer	Auditions PJL Climat Volet Consommer	2021-04-22 09:30:00	2021-04-22 10:30:00	\N	\N	1	0	\N	\N
555292	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PJL Climat Volet Consommer	Auditions PJL Climat Volet Consommer	2021-04-22 14:30:00	2021-04-22 15:15:00	\N	\N	1	0	\N	\N
559845	MISSION	AUCUNE	\N	CONF	\N	TR Gestion économique Covid-19 : conséquences pour les territoires	\N	2021-05-20 14:05:00	2021-05-20 15:30:00	2021-05-20 16:56:11	2021-05-20 17:06:49	7	0	\N	\N
566532	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Climat	PJL Climat	2021-06-16 21:30:00	2021-06-17 00:30:00	\N	\N	82	0	\N	\N
559849	MISSION	AUCUNE	\N	CONF	\N	TR "L'après Covid-19" : mutations pour les territoires ; le PJL "4D"	\N	2021-05-27 09:35:00	2021-05-27 11:15:00	2021-05-27 15:35:22	2021-05-27 17:04:07	9	0	\N	\N
582572	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PPL Protéger la rémunération des agriculteurs	Auditions PPL Protéger la rémunération des agriculteurs	2021-07-30 09:30:00	2021-07-30 10:00:00	\N	\N	3	0	\N	\N
582576	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PPL Protéger la rémunération des agriculteurs	Auditions PPL Protéger la rémunération des agriculteurs	2021-07-30 10:00:00	2021-07-30 10:30:00	\N	\N	3	0	\N	\N
582580	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PPL Protéger la rémunération des agriculteurs	Auditions PPL Protéger la rémunération des agriculteurs	2021-07-30 10:30:00	2021-07-30 11:00:00	\N	\N	2	0	\N	\N
586307	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2020 -  ENAP - Déplacement à Agen	Contrôle 2020 -  ENAP - Déplacement à Agen	2021-09-23 08:50:00	2021-09-24 15:10:00	\N	\N	1	0	\N	\N
586311	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - CERT - DMAT	Contrôle 2021 - CERT - DMAT	2021-09-21 14:30:00	2021-09-21 16:00:00	\N	\N	1	0	\N	\N
586313	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - CERT - ANTS/Syndicats Min INT	Contrôle 2021 - CERT - ANTS/Syndicats Min INT	2021-09-23 09:30:00	2021-09-23 13:00:00	\N	\N	1	0	\N	\N
586316	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Médias, Livre et industries culturelles - CNM	PLF pour 2022 - Médias, Livre et industries culturelles - CNM	2021-09-27 09:30:00	2021-09-27 10:20:00	\N	\N	1	0	\N	\N
586319	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Situation et perspectives SNCF - PDG SNCF	Contrôle 2021 - Situation et perspectives SNCF - PDG SNCF	2021-09-22 19:00:00	2021-09-22 20:00:00	\N	\N	2	0	\N	\N
586713	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-10-06 10:00:00	2021-10-06 12:30:00	2021-10-06 20:18:04	2021-10-07 09:46:59	36	2	\N	\N
587181	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Travailleurs indépendants 	\N	2021-09-28 14:15:00	2021-09-28 15:30:00	\N	\N	1	0	\N	\N
587182	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Travailleurs indépendants 	\N	2021-09-28 15:30:00	2021-09-28 16:30:00	\N	\N	1	0	\N	\N
587186	DELEGATION	AUDRAP	\N	\N	206	Audition de rapporteur	\N	2021-10-27 16:30:00	2021-10-27 18:00:00	\N	\N	1	0	\N	\N
587190	DELEGATION	AUDRAP	\N	\N	206	Audition de rapporteur	\N	2021-09-28 15:45:00	2021-09-28 17:15:00	\N	\N	1	0	\N	\N
587212	DELEGATION	AUDRAP	\N	\N	206	Audition de rapporteur 	\N	2021-09-28 17:30:00	2021-09-28 19:00:00	\N	\N	1	0	\N	\N
587214	DELEGATION	AUDRAP	\N	\N	206	Audition de rapporteur 	\N	2021-09-29 16:30:00	2021-09-29 17:30:00	\N	\N	1	0	\N	\N
587258	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Droit de visite pour les malades en établissements	\N	2021-09-28 16:00:00	2021-09-28 16:45:00	\N	\N	2	0	\N	\N
587321	DELEGATION	AUDRAP	\N	\N	206	Audition de rapporteur	\N	2021-09-29 15:00:00	2021-09-29 16:00:00	\N	\N	1	0	\N	\N
587327	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI répartition 	\N	2021-09-28 16:00:00	2021-09-28 17:30:00	\N	\N	7	0	\N	\N
551287	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de M. Pierre MOSCOVICI, Premier président de la Cour des comptes	Audition de M. Pierre MOSCOVICI, Premier président de la Cour des comptes	2021-04-15 09:05:00	2021-04-15 10:20:00	2021-04-15 10:52:58	2021-04-15 11:58:08	24	0	\N	\N
551445	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Respect des principes de la République	PJL Respect des principes de la République	2021-04-12 17:00:00	2021-04-12 21:30:00	\N	\N	67	0	\N	\N
551447	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2021-04-13 09:30:00	2021-04-13 12:45:00	\N	\N	42	0	\N	\N
551448	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat loi EGALIM	Débat loi EGALIM	2021-04-13 14:30:00	2021-04-13 16:10:00	\N	\N	64	0	\N	\N
551449	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL hydroélectricité	PPL hydroélectricité	2021-04-13 16:15:00	2021-04-13 20:45:00	\N	\N	127	0	\N	\N
551451	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL lutte contre l'illectronisme	PPL lutte contre l'illectronisme	2021-04-14 18:55:00	2021-04-14 20:05:00	\N	\N	50	0	\N	\N
551453	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL expropriation de biens en état d'abandon	PPL expropriation de biens en état d'abandon	2021-04-14 23:00:00	2021-04-15 00:10:00	\N	\N	34	0	\N	\N
551455	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL épargne des Français	PPL épargne des Français	2021-04-15 10:30:00	2021-04-15 12:05:00	\N	\N	64	0	\N	\N
551456	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL RSA	PPL RSA	2021-04-15 12:10:00	2021-04-15 13:20:00	\N	\N	55	0	\N	\N
551458	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL RSA	PPL RSA	2021-04-15 14:50:00	2021-04-15 16:05:00	\N	\N	60	0	\N	\N
551459	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR CETA	PPR CETA	2021-04-15 16:10:00	2021-04-15 17:45:00	\N	\N	41	0	\N	\N
551460	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Droit à l'eau	PPL Droit à l'eau	2021-04-15 17:50:00	2021-04-15 19:20:00	\N	\N	23	0	\N	\N
552383	GIA	AUCUNE	\N	\N	\N	Audition de M. Pierre Manent	Lecture philosophique et politique de l'encyclique Fratelli tutti	2021-04-13 13:30:00	2021-04-13 14:45:00	\N	\N	12	0	629	\N
552424	ETUDES	AUDRAP	\N	\N	\N	GE arts de la scène - Prodiss	Audition PRODISS	2021-04-14 12:05:00	2021-04-14 13:12:00	\N	\N	14	0	\N	966
554250	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2021-04-15 09:30:00	2021-04-15 12:30:00	\N	\N	7	0	\N	\N
555082	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Dérèglement climatique et résilience - Auditions de M. Pascal Martin	PJL Dérèglement climatique et résilience - Auditions de M. Pascal Martin	2021-04-21 14:45:00	2021-04-21 19:30:00	\N	\N	1	0	\N	\N
555083	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Dérèglement climatique et résilience - Auditions de M. Pascal Martin	PJL Dérèglement climatique et résilience - Auditions de M. Pascal Martin	2021-04-22 08:30:00	2021-04-22 10:10:00	\N	\N	1	0	\N	\N
555094	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 -  Enseignants matières scientifiques - DGESCO	Contrôle 2021 -  Enseignants matières scientifiques - DGESCO	2021-04-22 17:00:00	2021-04-22 18:15:00	\N	\N	1	0	\N	\N
555096	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Dérèglement climatique et résilience - Auditions de M. Pascal Martin	PJL Dérèglement climatique et résilience - Auditions de M. Pascal Martin	2021-04-22 14:00:00	2021-04-22 17:20:00	\N	\N	1	0	\N	\N
555123	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Auditions diverses - Audition de S.E.M. Daniel Saada et de M. Ran Balicer	\N	2021-05-06 15:00:00	2021-05-06 15:55:00	2021-05-06 16:02:55	2021-05-06 17:43:01	17	0	\N	\N
555162	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Climat - Audition CITEO	PJL Climat - Audition CITEO	2021-04-21 08:30:00	2021-04-21 09:15:00	\N	\N	5	0	\N	\N
555163	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Climat - Audition Zero Waste France	PJL Climat - Audition Zero Waste France	2021-04-21 09:15:00	2021-04-21 10:00:00	\N	\N	3	0	\N	\N
555164	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Climat - Audition Syndicat régie internet	PJL Climat - Audition Syndicat régie internet	2021-04-21 10:00:00	2021-04-21 10:45:00	\N	\N	1	0	\N	\N
555165	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Climat - Réseau Vrac -Réseau Consigne - Reconcil	PJL Climat - Réseau Vrac -Réseau Consigne - Reconcil	2021-04-21 10:45:00	2021-04-21 12:30:00	\N	\N	3	0	\N	\N
555166	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Climat - Audition M. Jacques Vernier	PJL Climat - Audition M. Jacques Vernier	2021-04-21 14:00:00	2021-04-21 14:45:00	\N	\N	2	0	\N	\N
555167	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Climat - Table ronde "Commerce et distribution"	PJL Climat - Table ronde "Commerce et distribution"	2021-04-21 14:45:00	2021-04-21 16:15:00	\N	\N	3	0	\N	\N
555168	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Climat - Table ronde "Secteurs des boissons"	PJL Climat - Table ronde "Secteurs des boissons"	2021-04-21 16:15:00	2021-04-21 17:15:00	\N	\N	1	0	\N	\N
555169	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Climat - Ministère de la transition écologique et solidaire	PJL Climat - Ministère de la transition écologique et solidaire	2021-04-21 17:15:00	2021-04-21 18:00:00	\N	\N	1	0	\N	\N
555170	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Climat - SPECT et SNPTV et représentants d'autres chaînes tv	PJL Climat - SPECT et SNPTV et représentants d'autres chaînes tv	2021-04-21 18:00:00	2021-04-21 18:45:00	\N	\N	1	0	\N	\N
555171	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL CLimat - Fédération professionnelle des entreprises du recyclage	PJL CLimat - Fédération professionnelle des entreprises du recyclage	2021-04-21 18:45:00	2021-04-21 19:15:00	\N	\N	1	0	\N	\N
555193	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJLC Climat - Auditions Uber Eats et Deliveroo	PJLC Climat - Auditions Uber Eats et Deliveroo	2021-04-22 14:00:00	2021-04-22 15:00:00	\N	\N	1	0	\N	\N
555194	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Climat - Table ronde "affichage environnemental"	PJL Climat - Table ronde "affichage environnemental"	2021-04-22 15:45:00	2021-04-22 17:15:00	\N	\N	2	0	\N	\N
555195	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL CLimat - Audition Mme Valérie Cabanes - Notre affaire à tous	PJL CLimat - Audition Mme Valérie Cabanes - Notre affaire à tous	2021-04-22 17:15:00	2021-04-22 18:00:00	\N	\N	1	0	\N	\N
555196	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Climat - Association négaWatt	PJL Climat - Association négaWatt	2021-04-22 18:00:00	2021-04-22 18:45:00	\N	\N	1	0	\N	\N
555233	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Dérèglement climatique et résilience - Auditions de M. Philippe Tabarot	PJL Dérèglement climatique et résilience - Auditions de M. Philippe Tabarot	2021-04-21 10:45:00	2021-04-21 12:15:00	\N	\N	2	0	\N	\N
555239	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Dérèglement climatique et résilience - Auditions de M. Philippe Tabarot	PJL Dérèglement climatique et résilience - Auditions de M. Philippe Tabarot	2021-04-21 15:30:00	2021-04-21 17:00:00	\N	\N	3	0	\N	\N
555243	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Dérèglement climatique et résilience - Auditions de M. Philippe Tabarot	PJL Dérèglement climatique et résilience - Auditions de M. Philippe Tabarot	2021-04-21 18:00:00	2021-04-21 19:30:00	\N	\N	2	0	\N	\N
555246	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2021-04-15 11:10:00	2021-04-15 13:25:00	\N	\N	3	0	\N	\N
555410	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Dérèglement climatique - Auditions	PJL Dérèglement climatique - Auditions	2021-04-20 11:00:00	2021-04-20 13:00:00	\N	\N	1	0	\N	\N
556364	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Lutte contre l'indépendance fictive	\N	2021-05-04 15:30:00	2021-05-04 18:00:00	\N	\N	1	0	\N	\N
556695	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT Réforme de la PAC	GT Réforme de la PAC - Audition de Mme Valérie METRICH HECQUET	2021-05-04 14:15:00	2021-05-04 16:00:00	\N	\N	14	0	\N	\N
556980	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Dérèglement climatique et résilience - Auditions Mme de Cidrac, MM. Martin et Tabarot	PJL Dérèglement climatique et résilience - Auditions Mme de Cidrac, MM. Martin et Tabarot	2021-05-05 14:00:00	2021-05-05 15:00:00	\N	\N	40	2	\N	\N
556986	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Dérèglement climatique et résilience - Auditions de Mme Marta de Cidrac	PJL Dérèglement climatique et résilience - Auditions de Mme Marta de Cidrac	2021-05-04 10:00:00	2021-05-04 10:45:00	\N	\N	1	0	\N	\N
556989	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Dérèglement climatique et résilience - Auditions de M. Pascal Martin	PJL Dérèglement climatique et résilience - Auditions de M. Pascal Martin	2021-05-04 08:30:00	2021-05-04 09:15:00	\N	\N	1	0	\N	\N
506859	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF pour 2021 - Avis Cohésion des territoires - Cabinet MCTRCT	PLF pour 2021 - Avis Cohésion des territoires - Cabinet de la ministre de la cohésion des territoires	2020-11-18 18:30:00	2020-11-18 19:30:00	\N	\N	1	0	\N	\N
507831	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2020-11-25 08:45:00	2020-11-25 12:35:00	2020-11-25 18:51:51	2020-11-26 11:15:01	40	0	\N	\N
508038	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT conjoint sur le suivi de la réforme de la PAC	GT conjoint sur le suivi de la réforme de la PAC -  Audition de 3 députés	2020-11-25 16:00:00	2020-11-25 18:00:00	\N	\N	15	0	\N	\N
509029	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Examen avis budgétaires - PLF 2021	\N	2020-11-26 10:45:00	2020-11-26 12:15:00	2020-11-26 16:03:56	2020-11-26 16:54:26	29	0	\N	\N
511207	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI Restitution des oeuvres d'art	\N	2020-12-01 09:00:00	2020-12-01 10:00:00	\N	\N	6	0	\N	\N
511214	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI Restitution des oeuvres d'art	\N	2020-12-01 10:00:00	2020-12-01 10:30:00	\N	\N	6	0	\N	\N
511221	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI Restitution des oeuvres d'art	\N	2020-12-01 14:30:00	2020-12-01 15:40:00	\N	\N	1	0	\N	\N
511229	DELEGATION	AUDRAP	\N	\N	206	Audition Production d'hydrogène - RTE	Audition Production d'hydrogène - RTE	2020-12-03 15:00:00	2020-12-03 16:00:00	\N	\N	1	0	\N	\N
511231	DELEGATION	AUDRAP	\N	\N	206	Audition Production d'hydrogène - CEA 	Audition Production d'hydrogène - CEA	2020-12-03 16:15:00	2020-12-03 17:30:00	\N	\N	1	0	\N	\N
512245	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2021 - Programme 144	\N	2020-11-18 16:30:00	2020-11-18 17:30:00	\N	\N	2	0	\N	\N
518415	GIA	AUCUNE	\N	\N	\N	AG 	Assemblée générale reconstitutive	2020-12-16 14:30:00	2020-12-16 14:55:00	\N	\N	10	0	592	\N
524047	GIA	AUCUNE	\N	\N	\N	Entretien avec Son Excellence Ghazi Alrawas, Ambassadeur du Sultanat d¿Oman en France	\N	2021-01-19 12:15:00	2021-01-19 13:15:00	\N	\N	2	0	661	\N
524050	GIA	AUCUNE	\N	\N	\N	Entretien avec S. E. M. Fahad Al Ruwaily, Ambassadeur d¿Arabie saoudite en France	\N	2021-01-19 14:00:00	2021-01-19 15:00:00	\N	\N	2	0	661	\N
524053	GIA	AUCUNE	\N	\N	\N	Audition de S.E. M Calixte Batossie Madjoulba, Ambassadeur du Togo en France 	\N	2021-01-19 18:00:00	2021-01-19 19:00:00	\N	\N	15	0	573	\N
530801	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Service public d'eau potable et d'assainissement en Guadeloupe	PPL Service public d'eau potable et d'assainissement en Guadeloupe	2021-02-09 15:00:00	2021-02-09 16:00:00	\N	\N	2	0	\N	\N
530805	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Service public d'eau potable et d'assainissement en Guadeloupe	PPL Service public d'eau potable et d'assainissement en Guadeloupe	2021-02-10 14:00:00	2021-02-10 15:00:00	\N	\N	2	0	\N	\N
531085	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Principes de la République	\N	2021-02-10 16:30:00	2021-02-10 17:30:00	\N	\N	3	0	\N	\N
531089	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Principes de la République	\N	2021-02-10 17:30:00	2021-02-10 18:30:00	\N	\N	2	0	\N	\N
511258	COM_PERMANENTE	AUTRE	\N	CAE	\N	PPL REEN - Auditions	\N	2020-11-30 16:45:00	2020-11-30 17:30:00	\N	\N	2	0	\N	\N
531092	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Principes de la République	\N	2021-02-10 18:30:00	2021-02-10 19:30:00	\N	\N	5	0	\N	\N
550112	COM_PERMANENTE	GROUPE_TRAVAIL	\N	ETRD	\N	Groupe de travail Drones	Groupe de travail DroNES	2021-04-06 14:30:00	2021-04-06 16:45:00	\N	\N	4	0	\N	\N
551520	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Haut Karabakh	\N	2021-04-07 13:45:00	2021-04-07 14:45:00	\N	\N	4	0	\N	\N
551647	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLC Article 1er de la Constitution et préservation de l'environnement	PJLC Article 1er de la Constitution et préservation de l'environnement	2021-03-29 16:00:00	2021-03-29 17:00:00	\N	\N	1	0	\N	\N
551649	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLC Article 1er de la Constitution et préservation de l'environnement	PJLC Article 1er de la Constitution et préservation de l'environnement	2021-04-12 15:00:00	2021-04-12 17:15:00	\N	\N	1	0	\N	\N
556158	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Haut Conseil pour le Climat - Services financiers Premier Ministre	Contrôle 2021 - Haut Conseil pour le Climat - Services financiers Premier Ministre	2021-05-04 14:30:00	2021-05-04 15:15:00	\N	\N	1	0	\N	\N
556188	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Haut Conseil pour le Climat - DGEC	Contrôle 2021 - Haut Conseil pour le Climat - DGEC	2021-05-04 15:30:00	2021-05-04 16:15:00	\N	\N	1	0	\N	\N
556277	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Mission évaluation SRU	Auditions Mission évaluation SRU	2021-05-04 16:30:00	2021-05-04 17:30:00	\N	\N	2	0	\N	\N
556319	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PJL Climat "Forêt"	Auditions PJL Climat "Forêt"	2021-05-04 17:15:00	2021-05-04 17:45:00	\N	\N	1	0	\N	\N
556324	DELEGATION	AUCUNE	\N	\N	PROS	Audition de M. François Bayrou, Haut-Commissaire au Plan	Audition de M. François Bayrou, Haut-Commissaire au Plan	2021-05-20 08:40:00	2021-05-20 10:30:00	\N	\N	15	0	\N	\N
556389	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2021-05-12 09:30:00	2021-05-12 12:40:00	2021-05-12 12:49:19	2021-05-12 15:27:46	43	0	\N	\N
557069	MISSION	AUDRAP	\N	ENSAGRIC	\N	Inspection générale de l'éducation, du sport et de la recherche (IGESR)	Audition de M. Jérôme Teillard	2021-05-05 11:35:00	2021-05-05 12:40:00	\N	\N	8	0	\N	\N
557070	MISSION	AUDRAP	\N	ENSAGRIC	\N	Association nationale des industries alimentaires	Audition de Mme Boucheron, directrice des affaires sociales	2021-05-05 12:45:00	2021-05-05 13:30:00	\N	\N	6	0	\N	\N
557089	COM_EURO	AUTRE	\N	AFEU	\N	Réunion conjointe avec la commission des affaires européennes du Sénat roumain	\N	2021-05-12 13:30:00	2021-05-12 15:05:00	2021-05-12 16:02:02	2021-05-12 18:10:19	14	0	\N	\N
557101	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Lutte contre le dérèglement climatique - Audition MTES	PJL Lutte contre le dérèglement climatique - Audition MTES	2021-05-04 19:30:00	2021-05-04 20:30:00	\N	\N	3	0	\N	\N
557215	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition UFIP et Anode - PJL Lutte contre le dérèglement climatique	Audition UFIP et Anode - PJL Lutte contre le dérèglement climatique	2021-05-04 09:00:00	2021-05-04 10:00:00	\N	\N	3	0	\N	\N
557229	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Conservatoire du littoral PJL Lutte contre le dérèglement climatique	Conservatoire du littoral PJL Lutte contre le dérèglement climatique	2021-05-04 14:30:00	2021-05-04 15:15:00	\N	\N	1	0	\N	\N
557231	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Cese PJL Lutte contre le dérèglement climatique	Cese PJL Lutte contre le dérèglement climatique	2021-05-04 15:15:00	2021-05-04 16:30:00	\N	\N	2	0	\N	\N
557251	MISSION	AUCUNE	\N	CONF	\N	Audition de M. Roland Theis,  Secrétaire d'Etat aux affaires européennes du Land de Sarre	Audition de M. Roland Theis,  Secrétaire d'Etat aux affaires européennes du Land de Sarre (GIA France-Allemagne)	2021-05-12 14:00:00	2021-05-12 15:00:00	\N	\N	19	0	\N	\N
561613	GIA	AUCUNE	\N	\N	\N	Audition du coprésident du Groupe de Minsk (OSCE)	Audition de M. Stéphane Visconti, coprésident français du Groupe de Minsk (OSCE)	2021-05-19 13:30:00	2021-05-19 14:50:00	\N	\N	4	0	641	\N
561619	GIA	AUCUNE	\N	\N	\N	Audition du coprésident du Groupe de Minsk (OSCE)	Audition de M. Stéphane Visconti, coprésident français du Groupe de Minsk (OSCE)	2021-05-19 13:30:00	2021-05-19 14:50:00	\N	\N	4	0	534	\N
562178	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT Boussole stratégique	\N	2021-05-18 17:00:00	2021-05-18 18:00:00	\N	\N	2	0	\N	\N
562181	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT Boussole stratégique	\N	2021-05-18 16:00:00	2021-05-18 17:00:00	\N	\N	3	0	\N	\N
566523	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition France Assos santé et FNATH	\N	2021-06-09 17:00:00	2021-06-09 18:00:00	\N	\N	2	0	\N	\N
566524	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition organisations patronales	\N	2021-06-09 18:30:00	2021-06-09 20:00:00	\N	\N	2	0	\N	\N
566525	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audiition Mme Leboyer - Pr Pelissolo	\N	2021-06-08 17:00:00	2021-06-08 18:30:00	\N	\N	3	0	\N	\N
566539	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Différenciation, décentralisation, déconcentration et simplification - Audition DG-ARS	\N	2021-06-08 13:30:00	2021-06-08 14:30:00	\N	\N	8	0	\N	\N
566540	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Table ronde financement établissements Île de France	\N	2021-06-08 14:30:00	2021-06-08 15:30:00	\N	\N	6	0	\N	\N
566541	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Table ronde Fédérations hospitalières	\N	2021-06-08 15:30:00	2021-06-08 16:15:00	\N	\N	7	0	\N	\N
566542	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Table ronde d'associations d'élus	\N	2021-06-10 09:00:00	2021-06-10 10:30:00	\N	\N	4	0	\N	\N
566543	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition DGCS	\N	2021-06-15 16:30:00	2021-06-15 17:15:00	\N	\N	0	0	\N	\N
566544	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Table ronde Outre-mer	\N	2021-06-15 17:15:00	2021-06-15 18:45:00	\N	\N	0	0	\N	\N
559839	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Accès des jeunes dans la fonction publique et les entreprises	PPL Accès des jeunes dans la fonction publique et les entreprises	2021-05-17 10:00:00	2021-05-17 11:30:00	\N	\N	1	0	\N	\N
559841	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2021-05-17 15:30:00	2021-05-17 16:30:00	\N	\N	2	0	\N	\N
562202	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2021-05-26 15:00:00	2021-05-26 16:20:00	\N	\N	200	0	\N	\N
562203	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL réponse solidaire et juste face à la crise	PPL réponse solidaire et juste face à la crise	2021-05-26 16:35:00	2021-05-26 17:50:00	\N	\N	59	0	\N	\N
562204	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL  élevage éthique	PPL élevage éthique, juste socialement et soucieux du bien-être animal	2021-05-26 17:55:00	2021-05-26 20:15:00	\N	\N	57	0	\N	\N
562206	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Jeunes dans la fonction publique	PPL Jeunes dans la fonction publique	2021-05-27 10:30:00	2021-05-27 13:00:00	\N	\N	15	0	\N	\N
562207	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL lutter contre l'indépendance fictive 	PPL lutter contre l'indépendance fictive 	2021-05-27 14:30:00	2021-05-27 16:05:00	\N	\N	34	0	\N	\N
562208	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Assitants maternels	PPL sécuriser les droits à protection sociale des assistants maternels	2021-05-27 16:05:00	2021-05-27 17:05:00	\N	\N	28	0	\N	\N
562209	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PP¨L Maladies chroniques	PPL Maladies chroniques	2021-05-27 17:05:00	2021-05-27 18:30:00	\N	\N	28	0	\N	\N
562210	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PJL Sortie de crise sanitaire	CMP PJL Sortie de crise sanitaire	2021-05-27 18:35:00	2021-05-27 19:30:00	\N	\N	16	0	\N	\N
562213	GIA	AUCUNE	\N	\N	\N	Audition de M. Simon Abi Ramia, président du groupe d'amitié Liban-France 	Audition de M. Simon Abi Ramia, député du caza de Jbeil,  président du groupe d'amitié Liban-France 	2021-05-20 10:00:00	2021-05-20 11:15:00	\N	\N	6	0	597	\N
562339	MISSION	AUDRAP	\N	PAUP	\N	CSN	\N	2021-05-25 13:00:00	2021-05-25 14:00:00	\N	\N	2	0	\N	\N
562340	MISSION	AUDRAP	\N	PAUP	\N	UNAF	\N	2021-05-25 16:15:00	2021-05-25 17:20:00	\N	\N	2	0	\N	\N
562554	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Rapport pour avis PJL Dérèglement climatique	\N	2021-05-26 09:42:00	2021-05-26 11:04:00	2021-05-26 15:01:54	2021-05-26 17:31:18	33	0	\N	\N
562556	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Protection sociale globale - Audition de M. Rachid Temal	\N	2021-05-25 15:30:00	2021-05-25 15:50:00	\N	\N	1	0	\N	\N
562573	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition de professionnels de la prévention et de la santé au travail	\N	2021-05-25 14:00:00	2021-05-25 15:30:00	\N	\N	2	0	\N	\N
562574	MECSS	AUDRAP	\N	\N	MECSS	Réserves des régimes de retraite - CCMSA	\N	2021-05-26 08:30:00	2021-05-26 09:00:00	\N	\N	3	0	\N	\N
562576	MECSS	AUDRAP	\N	\N	MECSS	Réserves des régimes de retraite - CNAVPL	\N	2021-05-27 09:15:00	2021-05-27 09:50:00	\N	\N	3	0	\N	\N
562579	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition commune sur la médecine du travail	\N	2021-05-25 15:30:00	2021-05-25 17:00:00	\N	\N	3	0	\N	\N
562646	MECSS	AUDRAP	\N	\N	MECSS	Réserves des régimes de retraite - CNBF	\N	2021-05-25 17:15:00	2021-05-25 18:15:00	\N	\N	1	0	\N	\N
562649	MECSS	AUDRAP	\N	\N	MECSS	Réserves des régimes de retraite - CNAV	\N	2021-05-25 18:30:00	2021-05-25 19:20:00	\N	\N	3	0	\N	\N
562654	MECSS	AUDRAP	\N	\N	MECSS	Réserves des régimes de retraite - Service des retraites de l'État	\N	2021-05-27 08:30:00	2021-05-27 09:00:00	\N	\N	2	0	\N	\N
562708	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Protection sociale globale - Audition de l'ODENORE	\N	2021-05-25 17:30:00	2021-05-25 18:30:00	\N	\N	2	0	\N	\N
562720	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Santé mentale et covid-19 - SNP et FFPP	\N	2021-05-26 16:15:00	2021-05-26 17:30:00	\N	\N	3	0	\N	\N
562722	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Santé mentale et covid-19 - Psychologues	\N	2021-05-26 17:30:00	2021-05-26 18:40:00	\N	\N	2	0	\N	\N
562732	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-06-02 21:30:00	2021-06-02 23:59:00	\N	\N	0	0	\N	\N
562859	COM_EURO	AUTRE_NON_PLENIERE	\N	AFEU	\N	Réunion du Bureau - Ambassade de Hongrie	Réunion du Bureau - rencontre avec l'Ambassadeur de Hongrie	2021-05-25 15:30:00	2021-05-25 16:30:00	\N	\N	3	0	\N	\N
562942	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2021-05-20 11:40:00	2021-05-20 12:35:00	\N	\N	3	0	\N	\N
563251	GIA	AUCUNE	\N	\N	\N	Audition de M. Muhammad Qazi, chargé d'affaires de l'ambassade du Pakistan	\N	2021-05-26 13:30:00	2021-05-26 14:30:00	\N	\N	3	0	619	\N
563262	MISSION	AUCUNE	\N	HARCEL	\N	Réunion du 26 mai 2021	Réunion constitutive du 26 mai 2021	2021-05-26 14:00:00	2021-05-26 14:35:00	2021-05-26 16:19:39	2021-05-26 16:26:49	15	0	\N	\N
563920	GIA	AUCUNE	\N	\N	\N	Visioconférence avec l'Ambassadeur et le Consul général	\N	2021-05-04 09:30:00	2021-05-04 10:30:00	\N	\N	10	0	626	\N
563940	GIA	AUCUNE	\N	\N	\N	Entretien avec les députés égyptiens du groupe d'amitié 	Entretien en visioconférence avec les députés égyptiens du groupe d'amitié 	2021-05-25 14:30:00	2021-05-25 15:30:00	\N	\N	7	0	617	\N
563948	GIA	AUCUNE	\N	\N	\N	Audition de l'ambassadeur d'Ukraine 	Audition de l'ambassadeur d'Ukraine	2021-05-25 18:00:00	2021-05-25 19:00:00	\N	\N	6	0	530	\N
563974	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition PJL Climat - La fabrique écologique	Audition PJL Climat - La fabrique écologique	2021-05-20 10:45:00	2021-05-20 11:30:00	\N	\N	1	0	\N	\N
563983	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition PJL Climat - France industrie	Audition PJL Climat - France industrie	2021-05-20 11:30:00	2021-05-20 12:15:00	\N	\N	1	0	\N	\N
563987	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition PJL Climat - La Poste	Audition PJL Climat - La Poste	2021-05-20 14:00:00	2021-05-20 14:45:00	\N	\N	1	0	\N	\N
563989	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition PJL Climat - DGAC	Audition PJL Climat - DGAC	2021-05-20 16:45:00	2021-05-20 17:30:00	\N	\N	1	0	\N	\N
563991	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition PJL Climat - Afep	Audition PJL Climat - Afep	2021-05-20 18:00:00	2021-05-20 18:45:00	\N	\N	1	0	\N	\N
564038	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Haut Karabakh	\N	2021-05-25 15:00:00	2021-05-25 16:30:00	\N	\N	2	0	\N	\N
564042	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Haut Karabakh	\N	2021-05-25 16:30:00	2021-05-25 17:30:00	\N	\N	3	0	\N	\N
564047	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Haut Karabakh	\N	2021-05-26 13:45:00	2021-05-26 14:45:00	\N	\N	1	0	\N	\N
564379	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur - M. Lalliot	Audition Patrimoine et Culture - M. Philippe Lalliot, Ambassadeur	2021-05-28 12:30:00	2021-05-28 13:45:00	\N	\N	2	0	\N	\N
564382	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Rapporteur - Mme Gloanec-Maurin	Audition Patrimoine et Culture - Mme Gloanec-Maurin	2021-05-27 14:15:00	2021-05-27 15:30:00	\N	\N	2	0	\N	\N
564385	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen rapport PJL 551 Lutte contre le dérèglement climatique	Examen rapport PJL 551 Lutte contre le dérèglement climatique	2021-06-01 16:30:00	2021-06-01 17:45:00	2021-06-01 18:10:59	2021-06-02 18:40:58	32	0	\N	\N
564386	COM_PERMANENTE	AUTRE	\N	FINC	\N	Contrôles budgétaires NexSIS 18-112 et Services Économiques DG Trésor	Contrôles budgétaires NexSIS 18-112 et Services Économiques DG Trésor	2021-06-02 10:00:00	2021-06-02 11:20:00	2021-06-02 12:33:06	2021-06-02 18:41:04	33	0	\N	\N
564387	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLFR pour 2021 : Audition de M. Bruno LE MAIRE et de M. Olivier DUSSOPT	PLFR pour 2021 : Audition de M. Bruno LE MAIRE et de M. Olivier DUSSOPT	2021-06-02 17:00:00	2021-06-02 18:30:00	2021-06-02 19:03:38	2021-06-03 15:05:54	30	0	\N	\N
564388	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLFR pour 2021 : Audition de M. Pierre MOSCOVICI, président du HCFP	PLFR pour 2021 : Audition de M. Pierre MOSCOVICI, président du HCFP	2021-06-03 11:05:00	2021-06-03 12:05:00	2021-06-03 15:57:37	2021-06-04 17:56:57	19	0	\N	\N
564390	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - IRE - Cabinet MEAE	Contrôle 2021 - IRE - Cabinet MEAE	2021-05-20 12:00:00	2021-05-20 13:00:00	\N	\N	2	0	\N	\N
564393	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - Direction générale du Trésor - Service économique régional Mexico	Contrôle 2020 - Direction générale du Trésor - Service économique régional Mexico	2021-05-20 17:00:00	2021-05-20 18:00:00	\N	\N	1	0	\N	\N
508042	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	MI méthode d'interpellation Police et Gendarmerie	MI méthode d'interpellation Police et Gendarmerie	2020-11-19 09:00:00	2020-11-19 09:45:00	\N	\N	3	0	\N	\N
566533	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Climat	PJL Climat	2021-06-17 10:30:00	2021-06-17 13:15:00	\N	\N	78	0	\N	\N
508046	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	MI méthode d'interpellation Police et Gendarmerie	MI méthode d'interpellation Police et Gendarmerie	2020-11-19 09:55:00	2020-11-19 10:45:00	\N	\N	1	0	\N	\N
508049	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	MI méthode d'interpellation Police et Gendarmerie	MI méthode d'interpellation Police et Gendarmerie	2020-11-19 10:45:00	2020-11-19 11:35:00	\N	\N	1	0	\N	\N
508052	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	MI méthode d'interpellation Police et Gendarmerie	MI méthode d'interpellation Police et Gendarmerie	2020-11-19 11:35:00	2020-11-19 12:40:00	\N	\N	2	0	\N	\N
508055	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	MI méthode d'interpellation Police et Gendarmerie	MI méthode d'interpellation Police et Gendarmerie	2020-11-19 14:30:00	2020-11-19 15:30:00	\N	\N	2	0	\N	\N
508059	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	MI méthode d'interpellation Police et Gendarmerie	\N	2020-11-19 16:00:00	2020-11-19 16:55:00	\N	\N	2	0	\N	\N
508081	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLC Liberté d'entreprendre, propriété privée et intérêt général	PPLC Liberté d'entreprendre, propriété privée et intérêt général	2020-11-20 09:00:00	2020-11-20 13:00:00	\N	\N	1	0	\N	\N
508083	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLC Liberté d'entreprendre, propriété privée et intérêt général	PPLC Liberté d'entreprendre, propriété privée et intérêt général	2020-11-20 14:00:00	2020-11-20 14:30:00	\N	\N	1	0	\N	\N
508085	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLC Liberté d'entreprendre, propriété privée et intérêt général	PPLC Liberté d'entreprendre, propriété privée et intérêt général	2020-11-20 16:00:00	2020-11-20 17:45:00	\N	\N	1	0	\N	\N
508087	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLC Liberté d'entreprendre, propriété privée et intérêt général	PPLC Liberté d'entreprendre, propriété privée et intérêt général	2020-11-24 09:00:00	2020-11-24 10:00:00	\N	\N	1	0	\N	\N
508089	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLC Liberté d'entreprendre, propriété privée et intérêt général	PPLC Liberté d'entreprendre, propriété privée et intérêt général	2020-11-24 10:00:00	2020-11-24 11:00:00	\N	\N	2	0	\N	\N
508092	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLC Liberté d'entreprendre, propriété privée et intérêt général	PPLC Liberté d'entreprendre, propriété privée et intérêt général	2020-11-24 15:30:00	2020-11-24 16:15:00	\N	\N	1	0	\N	\N
508094	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLC Liberté d'entreprendre, propriété privée et intérêt général	PPLC Liberté d'entreprendre, propriété privée et intérêt général	2020-11-24 16:30:00	2020-11-24 17:30:00	\N	\N	2	0	\N	\N
518591	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière - adoption du rapport EFE	Réunion plénière - adoption du rapport EFE	2020-12-17 09:00:00	2020-12-17 09:50:00	2020-12-17 12:43:33	\N	14	0	\N	\N
518808	GIA	AUCUNE	\N	\N	\N	\N	\N	2020-12-16 13:45:00	2020-12-16 14:15:00	\N	\N	4	0	852	\N
519047	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition Mme Estrosi Sassone PPL Le respect de la propriété immobilière contre le squat	Audition Mme Estrosi Sassone PPL Le respect de la propriété immobilière contre le squat	2020-12-22 10:00:00	2020-12-22 11:10:00	\N	\N	1	0	\N	\N
524214	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 2020 - Renouvellement urbains - SRU - Commission nationale SRU	58-2 2020 - Renouvellement urbains - SRU - Commission nationale SRU	2021-01-21 16:30:00	2021-01-21 17:30:00	\N	\N	1	0	\N	\N
524216	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Système des ressources propres UE - Économiste	PJL Système des ressources propres UE - Économiste	2021-01-19 15:00:00	2021-01-19 16:00:00	\N	\N	1	0	\N	\N
524235	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Système des ressources propres UE - DG Trésor	PJL Système des ressources propres UE - DG Trésor	2021-01-20 15:00:00	2021-01-20 16:00:00	\N	\N	1	0	\N	\N
524243	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Système des ressources propres UE - Direction du Budget / SG MEAE	PJL Système des ressources propres UE - Direction du Budget / SG MEAE	2021-01-20 18:00:00	2021-01-20 19:30:00	\N	\N	1	0	\N	\N
524245	MISSION	AUCUNE	\N	PAUP	\N	MI Précarisation - Réunion constitutive	\N	2021-01-26 17:00:00	2021-01-26 17:15:00	2021-01-26 17:56:53	2021-01-26 18:25:48	20	0	\N	\N
526450	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	AG constitutive GIA France Croatie 	AG constitutive GIA France Croatie	2021-01-12 14:30:00	2021-01-12 15:15:00	\N	\N	5	0	\N	\N
526474	GIA	AUCUNE	\N	\N	\N	Assemblée générale	Assemblée générale	2021-01-12 14:00:00	2021-01-12 14:30:00	\N	\N	2	0	611	\N
531202	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2021-02-11 09:00:00	2021-02-11 13:00:00	\N	\N	4	0	\N	\N
534069	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT sur l'avenir de La Poste	GT sur l'avenir de La Poste	2021-02-18 11:30:00	2021-02-18 13:00:00	\N	\N	3	0	\N	\N
534073	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT sur l'avenir de La Poste	GT sur l'avenir de La Poste	2021-02-18 14:00:00	2021-02-18 15:30:00	\N	\N	5	0	\N	\N
534098	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Création d'une vignette « collection » pour les véhicules d'époque	Auditions PPL Création d'une vignette « collection » pour les véhicules d'époque	2021-02-17 13:30:00	2021-02-17 14:30:00	\N	\N	2	0	\N	\N
534101	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Création d'une vignette « collection » pour les véhicules d'époque	Auditions PPL Création d'une vignette « collection » pour les véhicules d'époque	2021-02-17 17:15:00	2021-02-17 18:45:00	\N	\N	2	0	\N	\N
534104	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Sécurité globale	Auditions rapporteur pour avis PPL Sécurité globale	2021-02-17 09:00:00	2021-02-17 12:30:00	\N	\N	1	0	\N	\N
534106	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Sécurité globale	Auditions rapporteur pour avis PPL Sécurité globale	2021-02-18 09:00:00	2021-02-18 10:00:00	\N	\N	1	0	\N	\N
536048	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Transport de marchandises - Parlement européen	MI Transport de marchandises - Parlement européen - Mme Karima DELLI	2021-03-02 14:30:00	2021-03-02 15:45:00	\N	\N	11	0	\N	\N
536061	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Transport de marchandises - IFSTTAR	MI Transport de marchandises - IFSTTAR	2021-03-02 15:45:00	2021-03-02 16:40:00	\N	\N	9	0	\N	\N
536072	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Transport de marchandises - Transport&Environment	MI Transport de marchandises - Transport&Environment	2021-03-02 16:45:00	2021-03-02 17:30:00	\N	\N	3	0	\N	\N
536110	GIA	AUCUNE	\N	\N	\N	Rencontre ambassadeur Afghanistan	Rencontre avec M. Homayoon Azizi, ambassadeur d'Afghanistan en France	2021-03-09 14:30:00	2021-03-09 16:00:00	\N	\N	2	0	648	\N
536112	GIA	AUCUNE	\N	\N	\N	Rencontre Khiari	Rencontre avec Mme Bariza Khiari, vice-présidente de la fondation Aliph	2021-05-04 13:30:00	2021-05-04 14:30:00	\N	\N	4	0	615	\N
536558	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Respect des principes de la République	\N	2021-03-02 08:30:00	2021-03-02 11:15:00	\N	\N	2	0	\N	\N
536561	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Respect des principes de la République	\N	2021-03-02 14:00:00	2021-03-02 15:30:00	\N	\N	2	0	\N	\N
536564	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Respect des principes de la République	\N	2021-03-02 15:30:00	2021-03-02 16:30:00	\N	\N	3	0	\N	\N
536568	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Respect des principes de la République	\N	2021-03-02 16:30:00	2021-03-02 17:30:00	\N	\N	3	0	\N	\N
536573	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Respect des principes de la République	\N	2021-03-03 14:15:00	2021-03-03 15:20:00	\N	\N	1	0	\N	\N
536575	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Respect des principes de la République	\N	2021-03-04 10:30:00	2021-03-04 11:30:00	\N	\N	4	0	\N	\N
536580	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Respect des principes de la République	\N	2021-03-04 12:00:00	2021-03-04 12:45:00	\N	\N	2	0	\N	\N
539536	GIA	AUCUNE	\N	\N	\N	Audition de SE Mme Elisabeth Beton Delègue	Ambassadrice près le Saint-Siège	2021-03-11 14:00:00	2021-03-11 15:30:00	\N	\N	8	0	629	\N
539619	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Auditions groupe de travail "Objectif de zéro artificialisation nette"	Auditions groupe de travail "Objectif de zéro artificialisation nette"	2021-03-10 16:35:00	2021-03-10 17:40:00	\N	\N	5	0	\N	\N
539625	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Auditions groupe de travail "Objectif de zéro artificialisation nette"	Auditions groupe de travail "Objectif de zéro artificialisation nette"	2021-03-10 17:45:00	2021-03-10 18:45:00	\N	\N	4	0	\N	\N
557867	GIA	AUCUNE	\N	\N	\N	Audition de M. Jean-Louis Falconi, Ambassadeur de France en Serbie 	Audition de M. Jean-Louis Falconi Ambassadeur de France en Serbie 	2021-05-06 14:00:00	2021-05-06 15:30:00	\N	\N	8	0	674	\N
557876	GIA	AUCUNE	\N	\N	\N	Audition de M. Cyril Piquemal, directeur adjoint de l'Union européenne 	Audition de M. Cyril Piquemal, directeur adjoint de la DUE au ministère de l'Europe et des affaires étrangères	2021-05-06 10:30:00	2021-05-06 12:00:00	\N	\N	6	0	674	\N
557898	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PJL Climat "Forêt"	\N	2021-05-06 09:00:00	2021-05-06 10:00:00	\N	\N	1	0	\N	\N
557899	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PJL Climat "Forêt"	Auditions PJL Climat "Forêt"	2021-05-06 10:45:00	2021-05-06 11:30:00	\N	\N	1	0	\N	\N
557915	MISSION	AUDRAP	\N	VIETUDIA	\N	Audition Université La Rochelle	\N	2021-05-10 16:00:00	2021-05-10 18:00:00	\N	\N	7	0	\N	\N
557918	COM_PERMANENTE	AUDRAP	\N	FINC	\N	GS 2020 - Lutte contre la fraude et l'évasion fiscales - DG TAXUD CE	GS 2020 - Lutte contre la fraude et l'évasion fiscales - DG TAXUD CE	2021-05-05 18:00:00	2021-05-05 19:15:00	\N	\N	7	0	\N	\N
557926	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Syndication - Monde académique	Contrôle 2021 - Syndication - Monde académique	2021-05-06 14:30:00	2021-05-06 15:30:00	\N	\N	1	0	\N	\N
557928	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Syndication - SFL/Monde académique	Contrôle 2021 - Syndication - SFL/Monde académique	2021-05-06 16:30:00	2021-05-06 18:35:00	\N	\N	1	0	\N	\N
557930	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Météo France - DB/Auteurs rapport Météo-France	Contrôle 2021 - Météo France - DB/Auteurs rapport Météo-France	2021-05-06 14:30:00	2021-05-06 17:15:00	\N	\N	1	0	\N	\N
557933	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL 535 - DDADUE transports - DG Trésor/ACPR/AMF	PJL 535 - DDADUE transports - DG Trésor/ACPR/AMF	2021-05-03 14:00:00	2021-05-03 18:00:00	\N	\N	1	0	\N	\N
557951	COM_EURO	AUDRAP	\N	AFEU	\N	Audition commission européenne 04/05/21	Audition DSA/DMA. DG de la commission européenne	2021-05-04 17:00:00	2021-05-04 18:30:00	\N	\N	1	0	\N	\N
557953	MISSION	AUDRAP	\N	ENSAGRIC	\N	Audition Direction du budget	\N	2021-05-12 16:35:00	2021-05-12 17:30:00	\N	\N	4	0	\N	\N
557955	MISSION	AUCUNE	\N	METHANIS	\N	Réunion plénière MI Méthanisation	\N	2021-05-04 16:30:00	2021-05-04 19:00:00	2021-05-07 15:37:18	2021-05-07 18:24:36	13	0	\N	\N
557969	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - MDPH - AdF/DGCS	Contrôle 2021 - MDPH - AdF/DGCS	2021-05-04 10:00:00	2021-05-04 12:00:00	\N	\N	2	0	\N	\N
557972	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - MDPH - DITP	Contrôle 2021 - MDPH - DITP	2021-05-04 16:00:00	2021-05-04 17:00:00	\N	\N	2	0	\N	\N
557975	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Gestion de la sortie de crise sanitaire - Audition d'Olivier Véran	PJL Gestion de la sortie de crise sanitaire - Audition d'Olivier Véran	2021-05-11 10:00:00	2021-05-11 11:00:00	2021-05-11 12:38:58	2021-05-11 15:54:38	23	0	\N	\N
557976	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition JM Blanquer - R Maracineanu	\N	2021-05-11 17:35:00	2021-05-11 19:39:00	2021-05-11 20:21:05	2021-05-12 15:27:51	28	0	\N	\N
557978	MISSION	AUCUNE	\N	ENSAGRIC	\N	Audition UNREP	\N	2021-05-12 13:35:00	2021-05-12 14:49:00	2021-05-12 14:51:55	2021-05-12 15:29:06	8	0	\N	\N
557979	MISSION	AUCUNE	\N	ENSAGRIC	\N	Audition APCA	\N	2021-05-12 17:47:00	2021-05-12 18:47:00	2021-05-12 18:52:19	2021-05-14 15:18:11	4	0	\N	\N
559012	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL Kenya	\N	2021-05-10 10:30:00	2021-05-10 11:30:00	\N	\N	1	0	\N	\N
560867	ETUDES	AUTRE	\N	\N	\N	Audition Fédération nationale des courses hippiques	Audition Fédération nationale des courses hippiques	2021-05-19 08:15:00	2021-05-19 09:15:00	\N	\N	4	0	\N	912
560952	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL Climat et résilience - Table ronde AMF / AdCF	Audition PJL Climat et résilience - Table ronde AMF / AdCF	2021-05-18 14:45:00	2021-05-18 15:30:00	\N	\N	1	0	\N	\N
560953	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL Climat et résilience - France Stratégie / ANIL / IEC4	Audition PJL Climat et résilience - France Stratégie / ANIL / IEC4	2021-05-18 15:30:00	2021-05-18 16:30:00	\N	\N	1	0	\N	\N
560954	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLC Climat et résilience - Table ronde négaWatt / CCC	PJLC Climat et résilience - Table ronde négaWatt / CCC	2021-05-18 16:45:00	2021-05-18 17:30:00	\N	\N	1	0	\N	\N
560955	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLC Climat et résilience - Saint-Gobain	PJLC Climat et résilience - Saint-Gobain	2021-05-18 17:30:00	2021-05-18 18:15:00	\N	\N	1	0	\N	\N
560956	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL Climat et résilience - Direction de l'habitat, de l'urbanisme et des paysages	Audition PJL Climat et résilience - Direction de l'habitat, de l'urbanisme et des paysages	2021-05-18 18:15:00	2021-05-18 19:00:00	\N	\N	1	0	\N	\N
560970	MISSION	AUDRAP	\N	ENSAGRIC	\N	Point d'étape	\N	2021-05-19 13:42:00	2021-05-19 14:31:00	\N	\N	8	0	\N	\N
561943	BUREAU	AUCUNE	\N	\N	\N	Bureau du Sénat	Bureau du Sénat	2021-05-20 08:30:00	2021-05-20 11:30:00	\N	\N	23	0	\N	\N
562387	DELEGATION	AUDRAP	\N	\N	DSOM	Audition du cabinet du ministre des outre-mer	Audition du cabinet du ministre des outre-mer	2021-05-19 17:00:00	2021-05-19 18:40:00	\N	\N	3	0	\N	\N
563676	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteurs Culture et patrimoine	\N	2021-05-26 16:30:00	2021-05-26 17:45:00	\N	\N	2	0	\N	\N
563691	DELEGATION	AUDRAP	\N	\N	COLTER	Rapport santé : cabines de téléconsultation	\N	2021-05-20 14:00:00	2021-05-20 15:00:00	\N	\N	0	0	\N	\N
563692	DELEGATION	AUDRAP	\N	\N	COLTER	Rapport métropoles	\N	2021-05-19 13:30:00	2021-05-19 14:30:00	\N	\N	0	0	\N	\N
563702	DELEGATION	AUDRAP	\N	\N	COLTER	Rapport santé : cabines de téléconsultation	\N	2021-05-20 17:00:00	2021-05-20 18:00:00	\N	\N	0	0	\N	\N
563704	DELEGATION	AUDRAP	\N	\N	COLTER	Rapport métropoles - table ronde avec universitaires	\N	2021-05-12 13:30:00	2021-05-12 14:30:00	\N	\N	0	0	\N	\N
563705	DELEGATION	AUDRAP	\N	\N	COLTER	Rapport métropole - audition de la métropole de Toulouse	\N	2021-05-12 17:00:00	2021-05-12 18:00:00	\N	\N	0	0	\N	\N
563706	DELEGATION	AUDRAP	\N	\N	COLTER	Audition rapporteur - table ronde intercommunalités	\N	2021-05-06 14:00:00	2021-05-06 15:30:00	\N	\N	0	0	\N	\N
563707	DELEGATION	AUDRAP	\N	\N	COLTER	Rapport santé - audition centres municipaux de santé	\N	2021-05-06 15:30:00	2021-05-06 16:30:00	\N	\N	0	0	\N	\N
557977	COM_PERMANENTE	AUTRE	\N	AFCL	\N	PPL Engagement associatif	\N	2021-05-12 09:01:00	2021-05-12 09:47:00	2021-05-12 11:21:59	2021-05-12 15:27:50	26	0	\N	\N
563708	DELEGATION	AUDRAP	\N	\N	COLTER	Rapport santé - auditions "échecs"	\N	2021-05-06 16:30:00	2021-05-06 17:30:00	\N	\N	0	0	\N	\N
563709	DELEGATION	AUDRAP	\N	\N	COLTER	Rapport DECI - audition fédération française de l'assurance	\N	2021-05-05 16:30:00	2021-05-05 17:30:00	\N	\N	0	0	\N	\N
563710	DELEGATION	AUDRAP	\N	\N	COLTER	Rapport DECI - audition Institut national de l¿information géographique et forestière	\N	2021-05-05 17:30:00	2021-05-05 19:00:00	\N	\N	0	0	\N	\N
563711	DELEGATION	AUDRAP	\N	\N	COLTER	Audition rapporteur - DGALN	\N	2021-03-10 16:45:00	2021-03-10 17:30:00	\N	\N	0	0	\N	\N
563712	DELEGATION	AUDRAP	\N	\N	COLTER	Audition rapporteur - DGCL	\N	2021-03-10 17:30:00	2021-03-10 18:30:00	\N	\N	0	0	\N	\N
563713	DELEGATION	AUDRAP	\N	\N	COLTER	Audition rapporteur (visioconférence)	\N	2021-02-17 17:30:00	2021-02-17 18:00:00	\N	\N	0	0	\N	\N
563714	DELEGATION	AUDRAP	\N	\N	COLTER	Audition rapporteur	\N	2021-02-17 16:30:00	2021-02-17 17:30:00	\N	\N	0	0	\N	\N
563715	ETUDES	AUCUNE	\N	\N	\N	Table ronde sur les plateformes numériques coopératives - 2e session	Table ronde sur les plateformes numériques coopératives - 2e session	2021-05-26 08:30:00	2021-05-26 09:30:00	\N	\N	7	0	\N	998
563724	DELEGATION	AUDRAP	\N	\N	COLTER	Défense extérieure contre l'incendie	\N	2021-02-03 16:30:00	2021-02-03 18:15:00	\N	\N	0	0	\N	\N
563729	DELEGATION	AUDRAP	\N	\N	COLTER	Audition rapporteur - défense extérieure contre l'incendie	\N	2021-01-27 16:30:00	2021-01-27 17:15:00	\N	\N	0	0	\N	\N
563730	DELEGATION	AUDRAP	\N	\N	COLTER	Audition rapporteur - défense extérieure contre l'incendie	\N	2021-01-27 17:15:00	2021-01-27 18:15:00	\N	\N	0	0	\N	\N
563731	DELEGATION	AUDRAP	\N	\N	COLTER	Audition rapporteur - défense extérieure contre l'incendie	\N	2021-01-27 18:15:00	2021-01-27 19:00:00	\N	\N	0	0	\N	\N
563732	DELEGATION	AUDRAP	\N	\N	COLTER	Audition Jean-Philippe VINCENTINI	\N	2021-01-21 14:00:00	2021-01-21 15:15:00	\N	\N	0	0	\N	\N
563733	DELEGATION	AUDRAP	\N	\N	COLTER	Audition Général Olivier KIM (Gendarmerie nationale)	\N	2020-12-09 14:00:00	2020-12-09 15:15:00	\N	\N	0	0	\N	\N
516781	BUREAU	AUCUNE	\N	\N	\N	Bureau du Sénat	Bureau du Sénat	2020-12-10 09:00:00	2020-12-10 12:00:00	\N	\N	22	0	\N	\N
521211	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	COM Audiovisuel public	DGMIC	2021-01-13 16:10:00	2021-01-13 17:30:00	\N	\N	1	0	\N	\N
521212	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	COM Audiovisuel public	France Télévisions	2021-01-14 16:15:00	2021-01-14 17:25:00	\N	\N	5	0	\N	\N
521213	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	COM Audiovisuel public	Table ronde syndicats FT	2021-01-15 10:00:00	2021-01-15 11:15:00	\N	\N	2	0	\N	\N
521234	COM_PERMANENTE	AUTRE	\N	FINC	\N	PJL 225 CVN UM ouest-africaine: Rapport et texte et désignations rapporteurs	PJL 225 CVN UM ouest-africaine: Rapport et texte et désignations rapporteurs	2021-01-20 10:30:00	2021-01-20 11:30:00	2021-01-20 13:03:37	2021-01-20 14:48:01	36	0	\N	\N
521235	COM_PERMANENTE	AUTRE	\N	FINC	\N	58-2 2019 - L'enseignement supérieur artistique : Audition plénière 	58-2 2019 - L'enseignement supérieur artistique : Audition plénière 	2021-01-20 16:35:00	2021-01-20 18:30:00	2021-01-20 19:02:04	2021-01-21 10:15:38	17	0	\N	\N
521237	COM_PERMANENTE	AUTRE	\N	FINC	\N	Résultats de l'exercice 2020 - Audition de M. Olivier DUSSOPT, ministre délégué	Résultats de l'exercice 2020 - Audition de M. Olivier DUSSOPT, ministre délégué	2021-01-21 09:30:00	2021-01-21 10:40:00	2021-01-21 12:52:02	2021-01-22 15:32:05	26	0	\N	\N
521239	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	COM Audiovisuel public	Table ronde syndicats FMM	2021-01-18 09:30:00	2021-01-18 10:40:00	\N	\N	2	0	\N	\N
521240	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	COM Audiovisuel public	Audition FMM	2021-01-21 14:30:00	2021-01-21 15:50:00	\N	\N	2	0	\N	\N
521293	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Antidopage	AFLD	2021-01-13 17:30:00	2021-01-13 18:30:00	\N	\N	4	0	\N	\N
521370	DELEGATION	AUCUNE	\N	\N	211	Table ronde sur l¿application de la loi Copé-Zimmermann	Table ronde sur l¿application de la loi Copé-Zimmermann	2021-01-21 08:30:00	2021-01-21 11:15:00	2021-01-21 12:19:39	\N	15	0	\N	\N
521400	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition d'Olivier Véran, ministre des solidarités et de la santé	Audition d'Olivier Véran, ministre des solidarités et de la santé	2021-01-21 10:45:00	2021-01-21 11:45:00	2021-01-21 11:58:38	2021-01-22 15:32:06	15	0	\N	\N
521401	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Respect contre le squat & PPL Gens du voyage (amendements de séance)	PPL Respect contre le squat & PPL Gens du voyage (amendements de séance)	2021-01-19 14:00:00	2021-01-19 14:10:00	2021-01-19 14:20:53	2021-01-19 17:50:18	20	0	\N	\N
521420	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plenière CATDD	\N	2021-01-20 09:30:00	2021-01-20 10:58:00	2021-01-22 15:22:58	2021-01-22 15:31:52	72	0	\N	\N
521421	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion planière CATDD	\N	2021-01-20 16:45:00	2021-01-20 17:54:00	2021-01-21 09:24:07	2021-01-21 10:15:41	20	0	\N	\N
521430	COM_EURO	AUTRE	\N	AFEU	\N	Communication	\N	2021-01-21 09:00:00	2021-01-21 10:00:00	2021-01-21 13:16:14	2021-01-22 15:36:05	22	0	\N	\N
521431	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Code de la justice pénale des mineurs	\N	2021-01-14 16:00:00	2021-01-14 18:00:00	\N	\N	2	0	\N	\N
521432	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière	Difficultés  des  TPE  et  PME  dans  la  crise  : comment  franchir  le   cap  du  1er  semestre   2021?	2021-01-21 09:00:00	2021-01-21 11:15:00	2021-01-21 17:20:24	\N	11	0	\N	\N
521435	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Santé environnementale - Audition de Mme Béatrice Parance	\N	2021-01-13 14:00:00	2021-01-13 15:00:00	\N	\N	2	0	\N	\N
523562	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	GT Alimentation durable et locale	GT Alimentation durable et locale - Réunion de travail	2021-01-19 16:00:00	2021-01-19 17:00:00	\N	\N	6	0	\N	\N
536029	GIA	AUCUNE	\N	\N	\N	La place de la femme dans l'Eglise et la société selon le Pape François	Audition de Mme Laetitia Calmeyn, consulteur auprès de la Congrégation pour la Doctrine de la Foi	2021-03-03 13:30:00	2021-03-03 14:45:00	\N	\N	8	0	629	\N
558577	GIA	AUCUNE	\N	\N	\N	Entretien avec le Sénat d'Ouzbékistan	Entretien avec une délégation du Sénat d'Ouzbékistan conduite par M. SAFAYEV, vice-président	2021-05-11 09:00:00	2021-05-11 10:05:00	\N	\N	7	0	556	\N
558585	GIA	AUCUNE	\N	\N	\N	Enttretien avec le Cardinal L. Raffaël SAKO (Irak)	Entretien avec le Cardinal L. Raffaël SAKo sur la siutuation e,n Irak 	2021-05-11 17:00:00	2021-05-11 18:00:00	\N	\N	18	0	CHRETORIENT	CHRETORIENT
559686	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne 	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne 	2021-05-11 15:45:00	2021-05-11 16:15:00	2021-05-14 17:12:36	\N	7	0	\N	\N
559694	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne 	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne 	2021-05-11 17:00:00	2021-05-11 19:00:00	2021-05-14 17:15:56	\N	8	0	\N	\N
559703	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne 	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne 	2021-05-12 14:00:00	2021-05-12 14:45:00	2021-05-14 17:18:07	\N	8	0	\N	\N
559712	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne 	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne 	2021-05-12 16:30:00	2021-05-12 17:10:00	2021-05-14 17:20:31	\N	6	0	\N	\N
559722	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Accès des jeunes dans la fonction publique et les entreprises	PPL Accès des jeunes dans la fonction publique et les entreprises	2021-05-11 14:30:00	2021-05-11 16:15:00	\N	\N	1	0	\N	\N
559724	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Accès des jeunes dans la fonction publique et les entreprises	PPL Accès des jeunes dans la fonction publique et les entreprises	2021-05-14 10:30:00	2021-05-14 12:45:00	\N	\N	1	0	\N	\N
560363	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Irresponsabilité pénale	Audition rapporteur - PPL irresponsabilité pénale	2021-05-17 09:00:00	2021-05-17 11:45:00	\N	\N	2	0	\N	\N
560366	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	Audition rapporteur - PPL irresponsabilité pénale	2021-05-17 13:30:00	2021-05-17 14:15:00	\N	\N	1	0	\N	\N
560381	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Irresponsabilité pénale	Audition rapporteur - PPL irresponsabilité pénale	2021-05-10 14:00:00	2021-05-10 15:30:00	\N	\N	2	0	\N	\N
560391	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Irresponsabilité pénale	Audition rapporteur - PPL irresponsabilité pénale	2021-05-11 14:00:00	2021-05-11 15:00:00	\N	\N	5	0	\N	\N
560397	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Irresponsabilité pénale	Audition rapporteur - PPL irresponsabilité pénale	2021-05-12 13:30:00	2021-05-12 14:00:00	\N	\N	2	0	\N	\N
560400	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Irresponsabilité pénale	Audition rapporteur - PPL irresponsabilité pénale	2021-05-12 00:00:00	2021-05-12 00:00:00	\N	\N	5	0	\N	\N
561262	ETUDES	AUCUNE	\N	\N	\N	Audition ESS France - M. Jérôme Saddier	Audition ESS France - M. Jérôme Saddier	2021-05-12 08:30:00	2021-05-12 09:30:00	\N	\N	2	0	\N	998
563235	GIA	AUCUNE	\N	\N	\N	Entretien avec SE M. Maurice Kouakou BANDAMAN, Ambassadeur de Côte d'Ivoire en France	\N	2021-05-26 14:00:00	2021-05-26 14:55:00	\N	\N	5	0	573	\N
565925	GIA	AUCUNE	\N	\N	\N	Audition du recteur de l'UFAR	Audition de M. Bertrand Venard, recteur de l'Université française en Arménie	2021-06-02 13:30:00	2021-06-02 14:45:00	\N	\N	3	0	641	\N
571290	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de Mme Anne Grillo	Audition de Mme Anne Grillo	2021-06-22 16:35:00	2021-06-22 18:35:00	2021-06-23 10:48:37	2021-06-24 18:15:17	16	0	\N	\N
571298	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Examen RI "drones dans les forces armées"	Examen RI "drones dans les forces armées"	2021-06-23 10:00:00	2021-06-23 11:00:00	2021-06-23 14:42:30	2021-06-24 18:15:14	21	3	\N	\N
581930	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Mme Chain Larché	\N	2021-07-22 08:30:00	2021-07-22 11:00:00	\N	\N	1	0	\N	\N
581932	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Mme Chain Larché	\N	2021-07-22 15:00:00	2021-07-22 18:00:00	\N	\N	1	0	\N	\N
581934	ETUDES	AUCUNE	\N	\N	\N	Visite de DATA4 à Marcoussis	\N	2021-07-22 09:30:00	2021-07-22 11:30:00	\N	\N	6	0	\N	1008
564395	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - BA "CEA" - Mission CGEDD - IGF	PLF pour 2022 - BA "CEA" - Mission CGEDD - IGF	2021-05-20 17:00:00	2021-05-20 18:15:00	\N	\N	1	0	\N	\N
564410	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Dérèglement Climatique et résilience - GNTC/CITEPA/RTE	PJL Dérèglement Climatique et résilience - GNTC/CITEPA/RTE	2021-05-27 09:30:00	2021-05-27 12:00:00	\N	\N	1	0	\N	\N
564412	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - IHU - Institut Gustave Roussy	Contrôle 2021 - IHU - Institut Gustave Roussy	2021-05-25 11:00:00	2021-05-25 12:00:00	\N	\N	2	0	\N	\N
564415	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Dérèglement Climatique et résilience - FNSEA	PJL Dérèglement Climatique et résilience - FNSEA	2021-05-25 09:00:00	2021-05-25 09:45:00	\N	\N	1	0	\N	\N
564417	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Dérèglement Climatique et résilience - Cour des comptes	PJL Dérèglement Climatique et résilience - Cour des comptes	2021-05-27 14:30:00	2021-05-27 15:00:00	\N	\N	1	0	\N	\N
564419	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Rapport général - ENGIE	PLF pour 2022 - Rapport général - ENGIE	2021-05-25 09:50:00	2021-05-25 10:35:00	\N	\N	1	0	\N	\N
564441	COM_PERMANENTE	GROUPE_TRAVAIL	\N	ETRD	\N	GT Drones militaires	GT Drones miitaires	2021-05-25 14:30:00	2021-05-25 17:30:00	\N	\N	4	0	\N	\N
564446	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Lemoine, ambassadeur en Papouasie-Nouvelle-Guinée	Entretien avec M. Guillaume Lemoine, ambassadeur de France en Papouasie-Nouvelle-Guinée 	2021-05-28 09:30:00	2021-05-28 11:05:00	\N	\N	8	0	651	\N
564488	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-06-09 08:17:00	2021-06-09 11:32:00	2021-06-09 11:43:58	2021-06-09 12:27:31	39	1	\N	\N
564520	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2021 - NexSIS - Déplacement SDIS de Seine-et-Marne	Contrôle 2021 - NexSIS - Déplacement SDIS de Seine-et-Marne	2021-05-19 12:30:00	2021-05-19 16:00:00	\N	\N	1	0	\N	\N
566282	DELEGATION	AUCUNE	\N	\N	COLTER	Audition de M. VICENTINI - Table ronde Nouvelles technologies	\N	2021-06-03 09:35:00	2021-06-03 11:45:00	\N	\N	21	0	\N	\N
566412	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT Puissance chinoise en Europe	Audition de SEM. Alexey Meschkov, ambassadeur de Russie en France	2021-06-01 14:00:00	2021-06-01 15:00:00	\N	\N	3	0	\N	\N
566416	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT Puissance chinoise en Europe	\N	2021-06-01 16:00:00	2021-06-01 17:00:00	\N	\N	4	0	\N	\N
566421	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT Puissance chinoise en Europe	\N	2021-06-01 17:00:00	2021-06-01 18:00:00	\N	\N	3	0	\N	\N
566425	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT Puissance chinoise en Europe	\N	2021-06-02 16:30:00	2021-06-02 17:30:00	\N	\N	2	0	\N	\N
566428	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Actualisation LPM	\N	2021-06-02 11:30:00	2021-06-02 12:15:00	\N	\N	2	0	\N	\N
566431	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL terrorisme et renseignement	\N	2021-06-03 11:00:00	2021-06-03 12:00:00	\N	\N	1	0	\N	\N
566433	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Conseil européen	Débat Conseil européen	2021-06-08 14:30:00	2021-06-08 16:55:00	\N	\N	69	0	\N	\N
566434	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Économie du livre	PPL Économie du livre	2021-06-08 17:00:00	2021-06-08 19:15:00	\N	\N	67	0	\N	\N
566436	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2021-06-09 15:00:00	2021-06-09 16:20:00	\N	\N	178	0	\N	\N
566437	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Bibliothèques	PPL Bibliothèques	2021-06-09 16:35:00	2021-06-09 17:50:00	\N	\N	51	0	\N	\N
566438	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Protection sociale globale	PPL Protection sociale globale	2021-06-09 17:50:00	2021-06-09 19:20:00	\N	\N	42	0	\N	\N
566439	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Ticket restaurant étudiant	PPL Ticket restaurant étudiant	2021-06-10 10:30:00	2021-06-10 11:45:00	\N	\N	35	0	\N	\N
566440	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Enfants nés sans vie	PPL Enfants nés sans vie	2021-06-10 12:00:00	2021-06-10 13:15:00	\N	\N	28	0	\N	\N
566443	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Revitalisation des centres-villes	Débat Revitalisation des centres-villes	2021-06-10 15:15:00	2021-06-10 16:50:00	\N	\N	31	0	\N	\N
566444	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Parlement PLF	Débat Parlement PLF	2021-06-10 17:15:00	2021-06-10 18:15:00	\N	\N	20	0	\N	\N
566448	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - Les aides à la presse - Ministère de la Culture	Contrôle 2020 - Les aides à la presse - Ministère de la Culture (S/direction presse écrite et métiers de l¿information)	2021-05-31 17:00:00	2021-05-31 17:45:00	\N	\N	1	0	\N	\N
566456	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Situation et perspectives SNCF - AFRA	Contrôle 2021 - Situation et perspectives SNCF - AFRA	2021-06-01 08:30:00	2021-06-01 09:30:00	\N	\N	2	0	\N	\N
566473	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - Direction générale du Trésor - Service économique régional Washington	Contrôle 2020 - Direction générale du Trésor - Service économique régional Washington	2021-05-25 15:00:00	2021-05-25 16:00:00	\N	\N	1	0	\N	\N
566475	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - Direction générale du Trésor - SER Pékin et La Ha ye	Contrôle 2020 - Direction générale du Trésor - Service économique régional Pékin et La Ha ye	2021-05-26 10:00:00	2021-05-26 12:00:00	\N	\N	2	0	\N	\N
566478	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Programme de contrôle - 2021 - Conseil supérieur Cour des comptes	Programme de contrôle - 2021 - Conseil supérieur Cour des comptes	2021-06-02 15:00:00	2021-06-02 15:30:00	\N	\N	1	0	\N	\N
566480	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Missions locales - DGEFP	Contrôle 2021 - Missions locales - DGEFP	2021-05-31 14:00:00	2021-05-31 15:00:00	\N	\N	2	0	\N	\N
566483	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - FPIC - Banque Postale	Contrôle 2021 - FPIC - Banque Postale	2021-06-01 14:00:00	2021-06-01 15:00:00	\N	\N	2	0	\N	\N
566486	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - FPIC - Prefet  région Île-de-France	Contrôle 2021 - FPIC - Prefet  région Île-de-France	2021-06-03 09:00:00	2021-06-03 10:00:00	\N	\N	2	0	\N	\N
566489	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Missions locales - MLA et ML Innovam	Contrôle 2021 - Missions locales - MLA et ML Innovam	2021-06-03 10:00:00	2021-06-03 11:00:00	\N	\N	2	0	\N	\N
566492	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - MDPH - CNSA	Contrôle 2021 - MDPH - CNSA	2021-06-02 11:00:00	2021-06-02 12:00:00	\N	\N	2	0	\N	\N
566495	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Immobilier universitaire - CDC Banque des territoires	Contrôle 2021 - Immobilier universitaire - CDC Banque des territoires	2021-06-03 10:00:00	2021-06-03 11:30:00	\N	\N	1	0	\N	\N
566497	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Soins palliatifs - Table ronde sur la HAD	\N	2021-06-01 14:30:00	2021-06-01 15:45:00	\N	\N	7	0	\N	\N
566498	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Soins palliatifs - Table ronde d'associations	\N	2021-06-01 16:00:00	2021-06-01 18:00:00	\N	\N	4	0	\N	\N
567847	GIA	AUCUNE	\N	\N	\N	Réunion des présidents de l'AIFC et GIA	Réunion des présidents de l'AIFC et GIA	2021-05-10 14:00:00	2021-05-10 15:00:00	\N	\N	1	0	583	\N
568066	DELEGATION	AUTRE	\N	\N	ENTREPRISES	Examen Cybersécurité	\N	2021-06-10 09:00:00	2021-06-10 10:30:00	2021-06-10 16:18:48	\N	11	0	\N	\N
568159	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Rapport Général - Syndicat des indépendants	PLF pour 2022 - Rapport Général - Syndicat des indépendants	2021-06-08 10:00:00	2021-06-08 11:00:00	\N	\N	1	0	\N	\N
568170	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Table ronde des organisations professionnelles de policiers sur l'exercice de leur mission	Table ronde des organisations professionnelles de policiers sur l'exercice de leur mission	2021-06-15 14:00:00	2021-06-15 16:00:00	2021-06-16 08:49:30	2021-06-16 18:10:49	11	0	\N	\N
568171	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL 4D - Audition de Jacqueline Gourault	PJL 4D - Audition de Jacqueline Gourault	2021-06-15 17:35:00	2021-06-15 19:05:00	2021-06-16 08:49:39	2021-06-16 18:10:52	17	0	\N	\N
568172	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Prévention d'actes de terrorisme et renseignement (rapport et texte de la commission)	PJL Prévention d'actes de terrorisme et renseignement (rapport et texte de la commission)	2021-06-16 09:05:00	2021-06-16 11:30:00	2021-06-16 12:18:08	2021-06-16 18:10:53	31	0	\N	\N
568173	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition d'Eric Dupond-Moretti et Amélie de Montchalin sur la numérisation de la justice	Audition d'Eric Dupond-Moretti et Amélie de Montchalin sur la numérisation de la justice	2021-06-16 16:35:00	2021-06-16 18:40:00	2021-06-16 19:55:56	2021-06-17 12:32:17	16	0	\N	\N
568176	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL 4D - Audition d'Amélie de Montchalin	PJL 4D - Audition d'Amélie de Montchalin	2021-06-17 10:30:00	2021-06-17 11:25:00	2021-06-17 11:49:11	2021-06-17 12:32:19	10	0	\N	\N
568239	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Mineurs non accompagnés - Table ronde préfectures	\N	2021-06-08 15:00:00	2021-06-08 16:10:00	\N	\N	4	0	\N	\N
513912	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2021 - Examen des amendements de séance déposés en seconde délibération	PLF pour 2021 - Examen des amendements de séance déposés en seconde délibération	2020-12-07 21:00:00	2020-12-07 21:30:00	2020-12-07 22:01:31	2020-12-08 18:00:39	23	0	\N	\N
515112	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Comité de suivi Veolia-Suez - syndicats des eaux	Comité de suivi Veolia-Suez - syndicats des eaux	2020-12-08 16:00:00	2020-12-08 17:30:00	\N	\N	6	0	\N	\N
515121	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Comité de suivi Veolia-Suez - syndicats des déchets	Comité de suivi Veolia-Suez - syndicats des déchets	2020-12-08 18:05:00	2020-12-08 19:15:00	\N	\N	6	0	\N	\N
518758	GIA	AUCUNE	\N	\N	\N	AG du groupe d'amitié France-Albanie	Assemblée générale reconstitutive du groupe d'amitié France-Albanie	2020-12-17 10:00:00	2020-12-17 10:30:00	\N	\N	1	0	571	\N
520047	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteurs - Frontex - Nouveau Pacte migration et asile	\N	2021-01-12 15:30:00	2021-01-12 16:50:00	\N	\N	2	0	\N	\N
520051	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteurs - EASO - Nouveau Pacte migration et asile	Audition rapporteurs - EASO - Nouveau Pacte migration et asile	2021-01-12 16:55:00	2021-01-12 18:05:00	\N	\N	2	0	\N	\N
520136	COM_SPECIALE	PLENIERE	\N	BIOETHIQUE	\N	Audition de MM. Olivier Véran et Adrien Taquet	\N	2021-01-13 16:45:00	2021-01-13 18:00:00	2021-01-14 09:48:36	2021-01-14 16:26:09	23	0	\N	\N
521540	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Renouvellement des conseils départementaux et régionaux	PJL Renouvellement des conseils départementaux et régionaux	2021-01-14 09:30:00	2021-01-14 10:15:00	\N	\N	2	0	\N	\N
521543	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Renouvellement des conseils départementaux et régionaux	PJL Renouvellement des conseils départementaux et régionaux	2021-01-14 10:15:00	2021-01-14 11:00:00	\N	\N	1	0	\N	\N
521545	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Renouvellements des conseils généraux et des conseils régionaux	PJL Renouvellement des conseils départementaux et régionaux	2021-01-14 11:00:00	2021-01-14 11:45:00	\N	\N	2	0	\N	\N
521548	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Renouvellement des conseils départementaux et régionaux	PJL Renouvellement des conseils départementaux et régionaux	2021-01-14 18:30:00	2021-01-14 19:15:00	\N	\N	1	0	\N	\N
524123	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	COM Audiovisuel public	Audition Bureau de la Radio	2021-01-22 10:00:00	2021-01-22 11:00:00	\N	\N	1	0	\N	\N
526492	BUREAU	AUCUNE	\N	\N	\N	Bureau du Sénat	\N	2021-01-28 09:00:00	2021-01-28 11:00:00	\N	\N	20	0	\N	\N
529289	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Etat de droit dans l'Union européenne	Audition Etat de droit dans l'Union européenne	2021-02-10 16:35:00	2021-02-10 19:45:00	\N	\N	1	0	\N	\N
529295	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-02-16 16:30:00	2021-02-16 17:30:00	2021-02-21 12:20:21	2021-03-01 11:33:38	29	0	\N	\N
529296	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-02-17 09:33:00	2021-02-17 12:18:00	2021-02-18 16:59:59	2021-02-19 15:34:54	71	0	\N	\N
529297	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Sécurité globale	PPL Sécurité globale	2021-02-10 14:00:00	2021-02-10 15:00:00	\N	\N	3	0	\N	\N
529298	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Sécurité globale	PPL Sécurité globale	2021-02-09 16:30:00	2021-02-09 17:30:00	\N	\N	4	0	\N	\N
529621	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Rapporteur - M. Boucher, directeur de l'OFPRA	Audition Rapporteur - M. Boucher, directeur de l'OFPRA - Nouveau Pacte asile et migration	2021-02-09 14:00:00	2021-02-09 15:45:00	\N	\N	1	0	\N	\N
534205	GIA	AUCUNE	\N	\N	\N	audition ambassadeur	VIsioconférence avec l'ambassadeur du Royaume-Uni en France	2021-02-16 16:30:00	2021-02-16 17:30:00	\N	\N	11	0	581	\N
539630	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Auditions groupe de travail "Objectif de zéro artificialisation nette"	Auditions groupe de travail "Objectif de zéro artificialisation nette"	2021-03-11 11:10:00	2021-03-11 12:10:00	\N	\N	3	0	\N	\N
539634	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Auditions groupe de travail "Objectif de zéro artificialisation nette"	Auditions groupe de travail "Objectif de zéro artificialisation nette"	2021-03-11 12:15:00	2021-03-11 13:20:00	\N	\N	3	0	\N	\N
539638	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Auditions groupe de travail "Objectif de zéro artificialisation nette"	Auditions groupe de travail "Objectif de zéro artificialisation nette"	2021-03-11 14:35:00	2021-03-11 15:35:00	\N	\N	2	0	\N	\N
539641	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Auditions groupe de travail "Objectif de zéro artificialisation nette"	Auditions groupe de travail "Objectif de zéro artificialisation nette"	2021-03-11 15:35:00	2021-03-11 17:10:00	\N	\N	4	0	\N	\N
539646	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Auditions groupe de travail "Objectif de zéro artificialisation nette"	Auditions groupe de travail "Objectif de zéro artificialisation nette"	2021-03-11 17:10:00	2021-03-11 18:00:00	\N	\N	4	0	\N	\N
539673	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Groupe de travail sur l'avenir de La Poste	Groupe de travail sur l'avenir de La Poste	2021-03-11 14:00:00	2021-03-11 15:15:00	\N	\N	3	0	\N	\N
539677	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Groupe de travail sur l'avenir de La Poste	Groupe de travail sur l'avenir de La Poste	2021-03-11 18:00:00	2021-03-11 19:20:00	\N	\N	4	0	\N	\N
543201	GIA	AUCUNE	\N	\N	\N	Audition du directeur de l'INP	Audition du directeur de l'Institut national du patrimoine	2021-03-23 08:30:00	2021-03-23 09:35:00	\N	\N	5	0	641	\N
543268	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Lutte contre l'illectronisme et pour l'inclusion numérique	\N	2021-03-22 10:00:00	2021-03-22 12:00:00	\N	\N	1	0	\N	\N
543274	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Lutte contre l'illectronisme et pour l'inclusion numérique	\N	2021-03-22 14:00:00	2021-03-22 16:00:00	\N	\N	1	0	\N	\N
551464	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Tourisme	GT Tourisme	2021-04-06 13:30:00	2021-04-06 15:00:00	\N	\N	11	0	\N	\N
558007	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-05-12 09:30:00	2021-05-12 12:42:00	2021-05-12 20:14:05	2021-05-14 15:17:57	34	0	\N	\N
558037	MISSION	AUDRAP	\N	PAUP	\N	Audition communauté de communes du Kreiz Breizh	\N	2021-05-10 10:00:00	2021-05-10 11:00:00	\N	\N	2	0	\N	\N
558038	MISSION	AUDRAP	\N	PAUP	\N	Association tous vers l'emploi	\N	2021-05-10 11:00:00	2021-05-10 12:00:00	\N	\N	2	0	\N	\N
558039	MISSION	AUDRAP	\N	PAUP	\N	Audition de M. Thierry Mosimann	\N	2021-05-10 16:30:00	2021-05-10 18:00:00	\N	\N	3	0	\N	\N
558117	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Négociation collective - Audition de M. Jean-Denis Combrexelle	\N	2021-05-05 14:00:00	2021-05-05 15:00:00	\N	\N	1	0	\N	\N
559798	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Jean-Marc Grosgurin, ambassadeur de France en République centrafricaine	Entretien avec M. Jean-Marc Grosgurin, ambassadeur de France en République centrafricaine	2021-05-17 14:30:00	2021-05-17 15:35:00	\N	\N	3	0	572	\N
562229	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de B. Lortholary + dde saisine et désignation rapporteur	\N	2021-05-26 10:00:00	2021-05-26 11:35:00	2021-05-26 14:15:44	2021-05-26 17:31:16	30	0	\N	\N
562254	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT Drones militaires	GT Drones militaires	2021-05-18 17:00:00	2021-05-18 18:20:00	\N	\N	3	0	\N	\N
562258	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Suivi rapport Colombie de 2019	Suivi rapport Colombie de 2019	2021-05-21 15:00:00	2021-05-21 16:15:00	\N	\N	1	0	\N	\N
563221	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Nommer les enfants nés sans vie	Audition rapporteur - PPL nommer les enfants nés sans vie	2021-05-25 15:30:00	2021-05-25 16:00:00	\N	\N	1	0	\N	\N
563734	DELEGATION	AUDRAP	\N	\N	COLTER	Audition des associations d'élus locaux	\N	2020-12-10 10:30:00	2020-12-10 12:00:00	\N	\N	0	0	\N	\N
563735	DELEGATION	AUDRAP	\N	\N	COLTER	DECI - audition AMRF (M. Jean-Paul CARTERET)	\N	2021-01-13 16:30:00	2021-01-13 17:15:00	\N	\N	0	0	\N	\N
563736	DELEGATION	AUDRAP	\N	\N	COLTER	Audition de Joseph CARLES, VP Toulouse Métropol	\N	2021-01-14 13:00:00	2021-01-14 13:50:00	\N	\N	0	0	\N	\N
563738	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition CIGREF	\N	2021-05-27 15:45:00	2021-05-27 16:45:00	\N	\N	0	0	\N	\N
563741	DELEGATION	AUDRAP	\N	\N	COLTER	Audition des membres du bureau de la conférence nationale des procureurs de la République	\N	2021-01-14 14:00:00	2021-01-14 15:30:00	\N	\N	0	0	\N	\N
563742	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition commune handicap	\N	2021-05-26 16:30:00	2021-05-26 18:00:00	\N	\N	2	0	\N	\N
563743	DELEGATION	AUDRAP	\N	\N	COLTER	Rapport santé - audition DGCL	\N	2021-05-27 16:30:00	2021-05-27 17:30:00	\N	\N	0	0	\N	\N
565248	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	PJL Prévention d'actes de terrorisme et renseignement - Déplacement au PAIRS	PJL Prévention d'actes de terrorisme et renseignement - Déplacement au PAIRS	2021-06-01 14:00:00	2021-06-01 16:15:00	\N	\N	4	0	\N	\N
565253	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Prévention d'actes de terrorisme et renseignement	\N	2021-06-01 17:30:00	2021-06-01 19:30:00	\N	\N	2	0	\N	\N
565258	GIA	AUCUNE	\N	\N	\N	Rencontre avec Me JAKUBOWICZ	Audition	2021-06-02 13:30:00	2021-06-02 14:45:00	\N	\N	6	0	595	\N
565481	GIA	AUCUNE	\N	\N	\N	Audience de M. Nikol PACHINIAN, Premier ministre de la République d'Arménie	Audience de M. Nikol PACHINIAN, Premier ministre de la République d'Arménie	2021-06-01 16:00:00	2021-06-01 17:00:00	\N	\N	1	0	641	\N
565483	GIA	AUCUNE	\N	\N	\N	Audience de M. Nikol PACHINIAN, Premier ministre de la République d'Arménie	Audience de M. Nikol PACHINIAN, Premier ministre de la République d'Arménie	2021-06-01 16:00:00	2021-06-01 17:00:00	\N	\N	3	0	CHRETORIENT	CHRETORIENT
565488	GIA	AUCUNE	\N	\N	\N	AG suivie d'un Entretien avec des membres de l¿ONG « Baroudeurs de l¿Espoir »	Assemblée générale du groupe suivie d'un Entretien avec des membres de l¿ONG « Baroudeurs de l¿Espoir »	2021-06-02 13:15:00	2021-06-02 14:55:00	\N	\N	4	0	644	\N
566154	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Prévention d'actes de terrorisme et renseignement	\N	2021-06-03 09:30:00	2021-06-03 11:30:00	\N	\N	1	0	\N	\N
566556	MISSION	AUDRAP	\N	ENSAGRIC	\N	Auditions rapporteure	\N	2021-06-09 13:32:00	2021-06-09 14:43:00	\N	\N	5	0	\N	\N
566571	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Pjl terrorisme	Pjl terrorisme	2021-06-07 10:00:00	2021-06-07 11:00:00	\N	\N	2	0	\N	\N
566573	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Amendements de séance - PPL économie du livre	\N	2021-06-08 15:00:00	2021-06-08 15:10:00	2021-06-08 17:33:59	2021-06-09 12:27:32	21	0	\N	\N
566574	DELEGATION	AUTRE	\N	\N	COLTER	Table ronde "Les nouvelles technologies comme outils de lutte contre les déserts médicaux"	\N	2021-06-03 11:00:00	2021-06-03 12:30:00	\N	\N	0	0	\N	\N
566575	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2022 - Mission "Sécurités" - Déplacement à Grenoble	PLF pour 2022 - Mission "Sécurités" - Déplacement à Grenoble	2021-06-03 07:45:00	2021-06-04 20:20:00	\N	\N	1	0	\N	\N
566632	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteurs - DG prévention des risques - ministère de l'écologie	\N	2021-06-07 11:30:00	2021-06-07 12:15:00	\N	\N	2	0	\N	\N
566636	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur - Institut droit de l'environnement Lyon (M.Billet)	\N	2021-06-09 11:00:00	2021-06-09 12:00:00	\N	\N	2	0	\N	\N
566637	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteurs - SGAE (Mme Deler)	\N	2021-06-10 14:00:00	2021-06-10 15:00:00	\N	\N	2	0	\N	\N
566638	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur - LVR Consulting (Mme Verdier)	\N	2021-06-14 10:30:00	2021-06-14 11:15:00	\N	\N	1	0	\N	\N
566641	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteurs - DG Environnement Commission européenne  (Mme Manfredi)	\N	2021-06-16 10:30:00	2021-06-16 11:15:00	\N	\N	2	0	\N	\N
566670	ETUDES	AUTRE	\N	\N	\N	Audition M. Claude Atcher, Rugby France 2023	\N	2021-06-08 14:00:00	2021-06-08 16:00:00	\N	\N	21	0	\N	934
566936	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Accord-cadre UE-Australie	Accord-cadre UE-Australie	2021-06-08 18:00:00	2021-06-08 19:15:00	\N	\N	1	0	\N	\N
567854	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 17 juin 2021	\N	2021-06-17 08:45:00	2021-06-17 12:10:00	2021-06-18 18:04:17	2021-06-18 18:52:48	14	0	\N	\N
567855	COM_EURO	AUTRE	\N	AFEU	\N	2e réunion du 17 juin 2021	2e réunion du 17 juin 2021	2021-06-17 15:40:00	2021-06-17 17:45:00	2021-06-18 10:15:13	2021-06-18 18:52:49	5	0	\N	\N
567917	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Situation et perspectives SNCF - Direction du budget	Contrôle 2021 - Situation et perspectives SNCF - Direction du budget	2021-06-09 08:30:00	2021-06-09 09:00:00	\N	\N	2	0	\N	\N
567923	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Rapport général - CSOEC	PLF pour 2022 - Rapport général - CSOEC	2021-06-09 16:30:00	2021-06-09 17:00:00	\N	\N	1	0	\N	\N
567926	MISSION	AUDRAP	\N	METHANIS	\N	Audition préfecture Finistère	Audition préfecture Finistère	2021-06-08 09:00:00	2021-06-08 10:00:00	\N	\N	2	0	\N	\N
567927	MISSION	AUDRAP	\N	METHANIS	\N	\N	Audition du maire de Corcoué sur Logne	2021-06-09 16:30:00	2021-06-09 17:30:00	\N	\N	2	0	\N	\N
567946	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2021-06-10 09:00:00	2021-06-10 11:45:00	\N	\N	5	0	\N	\N
568181	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Différenciation, décentralisation, déconcentration et simplification	PJL Différenciation, décentralisation, déconcentration et simplification	2021-06-02 16:15:00	2021-06-02 17:30:00	\N	\N	4	0	\N	\N
568190	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Différenciation, décentralisation, déconcentration et simplification	PJL Différenciation, décentralisation, déconcentration et simplification	2021-06-03 16:00:00	2021-06-03 16:45:00	\N	\N	4	0	\N	\N
568195	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Différenciation, décentralisation, déconcentration et simplification	PJL Différenciation, décentralisation, déconcentration et simplification	2021-06-03 16:45:00	2021-06-03 17:30:00	\N	\N	4	0	\N	\N
568200	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Différenciation, décentralisation, déconcentration et simplification	PJL Différenciation, décentralisation, déconcentration et simplification	2021-06-03 17:30:00	2021-06-03 19:00:00	\N	\N	6	0	\N	\N
568207	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Différenciation, décentralisation, déconcentration et simplification	PJL Différenciation, décentralisation, déconcentration et simplification	2021-06-07 11:00:00	2021-06-07 13:15:00	\N	\N	1	0	\N	\N
568209	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Différenciation, décentralisation, déconcentration et simplification	PJL Différenciation, décentralisation, déconcentration et simplification	2021-06-07 14:30:00	2021-06-07 16:30:00	\N	\N	3	0	\N	\N
568213	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Différenciation, décentralisation, déconcentration et simplification	PJL Différenciation, décentralisation, déconcentration et simplification	2021-06-07 17:30:00	2021-06-07 18:30:00	\N	\N	1	0	\N	\N
568215	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Différenciation, décentralisation, déconcentration et simplification	PJL Différenciation, décentralisation, déconcentration et simplification	2021-06-08 14:00:00	2021-06-08 15:00:00	\N	\N	4	0	\N	\N
568220	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Différenciation, décentralisation, déconcentration et simplification	PJL Différenciation, décentralisation, déconcentration et simplification	2021-06-08 15:00:00	2021-06-08 16:00:00	\N	\N	4	0	\N	\N
568225	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Différenciation, décentralisation, déconcentration et simplification	PJL Différenciation, décentralisation, déconcentration et simplification	2021-06-08 16:00:00	2021-06-08 17:30:00	\N	\N	3	0	\N	\N
568254	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition plénière - Audition de M. Broussy	\N	2021-06-16 16:35:00	2021-06-16 17:50:00	2021-06-16 18:03:54	2021-06-16 18:11:06	15	0	\N	\N
568255	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI santé mentale covid	\N	2021-06-15 16:00:00	2021-06-15 17:00:00	\N	\N	3	0	\N	\N
568265	MISSION	AUDRAP	\N	HARCEL	\N	Audition Rapporteure - Fondation pour l'Enfance (V. Dennery, Directeur)	\N	2021-06-23 10:00:00	2021-06-23 11:00:00	\N	\N	0	0	\N	\N
568276	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - MDPH - MDPH Yonne/Association directeurs MDPH	Contrôle 2021 - MDPH - MDPH Yonne/Association directeurs MDPH	2021-06-09 10:00:00	2021-06-09 12:00:00	\N	\N	2	0	\N	\N
519254	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL patrimoine sensoriel	\N	2021-01-06 16:00:00	2021-01-06 17:00:00	\N	\N	5	0	\N	\N
519260	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL patromoine sensoriel	\N	2021-01-07 09:00:00	2021-01-07 09:45:00	\N	\N	3	0	\N	\N
519264	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL patrimoine	\N	2021-01-07 10:00:00	2021-01-07 10:45:00	\N	\N	3	0	\N	\N
526649	GIA	AUCUNE	\N	\N	\N	\N	Renouvellement du groupe	2021-01-19 14:30:00	2021-01-19 15:00:00	\N	\N	2	0	624	\N
526653	MISSION	AUCUNE	\N	CONF	\N	Définition du programme de travail de la mission	Définition du programme de travail de la mission	2021-02-04 10:35:00	2021-02-04 11:25:00	2021-02-04 15:12:58	2021-02-05 15:34:09	10	0	\N	\N
526654	ETUDES	AUCUNE	\N	\N	\N	Réunion reconstitutive	Réunion reconstitutive	2021-01-27 14:00:00	2021-01-27 15:00:00	\N	\N	21	0	\N	906
526709	COM_PERMANENTE	AUDRAP	\N	CAE	\N	RE 2020 - FF3C / Équilibre et avenir	RE 2020 - FF3C / Équilibre et avenir	2021-01-26 15:35:00	2021-01-26 16:35:00	\N	\N	2	0	\N	\N
529054	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Audition ARP	\N	2021-02-10 13:30:00	2021-02-10 14:30:00	\N	\N	1	0	\N	\N
534050	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Auditions GT "objectif de zéro artificialisation nette"	Auditions GT "objectif de zéro artificialisation nette"	2021-02-18 11:00:00	2021-02-18 12:00:00	\N	\N	7	0	\N	\N
534058	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Auditions GT "objectif de zéro artificialisation nette"	Auditions GT "objectif de zéro artificialisation nette"	2021-02-18 12:00:00	2021-02-18 13:00:00	\N	\N	8	0	\N	\N
542571	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ambassadeur de France à Varsovie	Entretien avec l'ambassadeur de France à Varsovie	2021-03-18 09:00:00	2021-03-18 10:00:00	\N	\N	1	0	600	\N
545942	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière - Note viande rouge - Audition publique "Covid long"	Réunion plénière - Note viande rouge - Audition publique "Covid long"	2021-04-08 09:10:00	2021-04-08 12:30:00	\N	\N	13	0	\N	\N
545943	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière - Note Hydrogène - Reconnaissance faciale  - Nomination	Réunion plénière - Note Hydrogène - Reconnaissance faciale  - Nomination	2021-04-15 10:10:00	2021-04-15 12:15:00	\N	\N	15	0	\N	\N
545944	DELEGATION	AUCUNE	\N	\N	206	Audition publique Recherche polaire - Nomination - Désignation rapporteurs	Audition publique Recherche polaire - Nomination - Désignation rapporteurs	2021-05-06 09:00:00	2021-05-06 13:55:00	\N	\N	16	0	\N	\N
545945	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière -  Audition de Thierry Coulhon	Réunion plénière -Audition de Thierry Coulhon	2021-05-20 11:00:00	2021-05-20 12:25:00	\N	\N	7	0	\N	\N
545946	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière - Audition chercherche traitements Covid - examen conclusions NBT	Rééunion plénière - Audition chercherche traitunion plénière - Examen note Outils de webconférence - Stratégie vaccinale	2021-06-03 09:10:00	2021-06-03 13:00:00	\N	\N	13	0	\N	\N
546820	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2021-03-25 14:35:00	2021-03-25 16:55:00	\N	\N	3	0	\N	\N
553976	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Tourisme	GT Tourisme	2021-04-14 13:30:00	2021-04-14 14:15:00	\N	\N	4	0	\N	\N
553982	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Tourisme	GT Tourisme	2021-04-14 14:15:00	2021-04-14 15:00:00	\N	\N	6	0	\N	\N
554015	ETUDES	AUCUNE	\N	\N	\N	GE Animal et société - Constitutive	GE Animal et société - Constitutive	2021-04-13 13:30:00	2021-04-13 15:00:00	\N	\N	14	0	\N	1011
554041	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions PJL Climat	Auditions PJL Climat	2021-04-13 09:30:00	2021-04-13 10:15:00	\N	\N	7	0	\N	\N
554049	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions PJL Climat	Auditions PJL Climat	2021-04-13 10:15:00	2021-04-13 11:00:00	\N	\N	4	0	\N	\N
554064	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions PJL Climat	Auditions PJL Climat	2021-04-13 15:30:00	2021-04-13 16:30:00	\N	\N	7	0	\N	\N
554072	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions PJL Climat	Auditions PJL Climat	2021-04-13 16:45:00	2021-04-13 17:45:00	\N	\N	2	0	\N	\N
554076	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions PJL Climat	Auditions PJL Climat	2021-04-13 17:45:00	2021-04-13 18:30:00	\N	\N	3	0	\N	\N
554080	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions PJL Climat	Auditions PJL Climat	2021-04-13 18:30:00	2021-04-13 19:30:00	\N	\N	3	0	\N	\N
554738	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Engagement associatif	\N	2021-04-14 18:30:00	2021-04-14 19:15:00	\N	\N	1	0	\N	\N
554740	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL engagement associatif	\N	2021-04-15 09:30:00	2021-04-15 10:30:00	\N	\N	3	0	\N	\N
554744	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL ère numérique	\N	2021-04-15 09:25:00	2021-04-15 10:40:00	\N	\N	3	0	\N	\N
554748	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL ère numérique	\N	2021-04-15 11:00:00	2021-04-15 12:15:00	\N	\N	4	0	\N	\N
554753	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL ère numérique	\N	2021-04-15 14:30:00	2021-04-15 15:20:00	\N	\N	4	0	\N	\N
554758	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL ère numérique	Audition SACD	2021-04-15 16:00:00	2021-04-15 16:55:00	\N	\N	1	0	\N	\N
554760	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Mi Cvec	\N	2021-04-06 12:30:00	2021-04-06 13:45:00	\N	\N	3	0	\N	\N
554764	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Mi Cvec	\N	2021-04-06 13:45:00	2021-04-06 14:45:00	\N	\N	3	0	\N	\N
554768	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI Cvec	\N	2021-04-13 12:30:00	2021-04-13 13:36:00	\N	\N	3	0	\N	\N
555255	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Dérèglement climatique et résilience - Auditions de M. Pascal Martin	PJL Dérèglement climatique et résilience - Auditions de M. Pascal Martin	2021-04-27 11:05:00	2021-04-27 12:15:00	\N	\N	2	0	\N	\N
556366	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	GT drones militaires	GT drones militaires	2021-05-04 14:15:00	2021-05-04 19:45:00	\N	\N	4	0	\N	\N
556379	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	LPM 2019 - 2025	LPM 2019-2025	2021-05-03 18:00:00	2021-05-03 19:30:00	\N	\N	2	0	\N	\N
564856	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	France Stratégie	\N	2021-06-03 14:30:00	2021-06-03 15:30:00	\N	\N	0	0	\N	\N
564857	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Haut Comité Juridique de la Place de Paris	\N	2021-06-03 15:45:00	2021-06-03 17:00:00	\N	\N	0	0	\N	\N
564859	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Auditions	\N	2021-06-03 09:05:00	2021-06-03 11:05:00	2021-06-03 12:11:12	\N	14	0	\N	\N
564887	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition OPPBTP	\N	2021-06-02 13:30:00	2021-06-02 14:30:00	\N	\N	3	0	\N	\N
567168	GIA	AUCUNE	\N	\N	\N	audition de Mgr Eric de Moulins-Beaufort, président de la conférence des évêques de France	\N	2021-06-08 18:30:00	2021-06-08 19:45:00	\N	\N	12	0	629	\N
574298	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition 58-2 : Bilan de l'intégration de la gendarmerie au ministère de l'intérieur	Audition 58-2 : Bilan de l'intégration de la gendarmerie au ministère de l'intérieur	2021-06-30 11:00:00	2021-06-30 12:45:00	2021-06-30 17:50:10	2021-06-30 18:40:59	28	0	\N	\N
577894	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT subsidiarité	Réunion du Groupe de travail subsidiarité	2021-07-08 08:15:00	2021-07-08 08:30:00	\N	\N	4	0	\N	\N
571146	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2021-06-23 15:00:00	2021-06-23 16:20:00	\N	\N	184	0	\N	\N
581943	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PPL Protéger la rémunération des agriculteurs	Auditions PPL Protéger la rémunération des agriculteurs	2021-07-22 10:30:00	2021-07-22 11:00:00	\N	\N	1	0	\N	\N
581945	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PPL Protéger la rémunération des agriculteurs	Auditions PPL Protéger la rémunération des agriculteurs	2021-07-22 15:00:00	2021-07-22 15:30:00	\N	\N	2	0	\N	\N
581948	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PPL Protéger la rémunération des agriculteurs	Auditions PPL Protéger la rémunération des agriculteurs	2021-07-22 16:00:00	2021-07-22 16:30:00	\N	\N	2	0	\N	\N
582005	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPLO et PPL finances publiques - Professeur Droit public / Direction du Budget	PPLO et PPL finances publiques - Professeur Droit public / Direction du Budget	2021-07-22 09:30:00	2021-07-22 11:30:00	\N	\N	2	0	\N	\N
582008	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPLO et PPL finances publiques - Association Finances publiques	PPLO et PPL finances publiques - Association Finances publiques	2021-07-27 10:00:00	2021-07-27 11:00:00	\N	\N	2	0	\N	\N
582011	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2021 - Immobilier universitaire - Déplacement à Reims	Contrôle 2021 - Immobilier universitaire - Déplacement à Reims	2021-07-22 08:25:00	2021-07-22 15:00:00	\N	\N	1	0	\N	\N
582013	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Météo France - Syndicats Météo France	Contrôle 2021 - Météo France - Syndicats Météo France	2021-07-22 15:15:00	2021-07-22 17:20:00	\N	\N	1	0	\N	\N
582557	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Gestion de la crise sanitaire (CMP) - Examen de l'amendement gouvernemental	PJL Gestion de la crise sanitaire (CMP) - Examen de l'amendement gouvernemental	2021-07-25 22:10:00	2021-07-25 22:15:00	2021-07-25 22:27:12	2021-07-28 10:30:17	7	0	\N	\N
568245	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Prévention d'actes de terrorisme et renseignement	\N	2021-06-10 14:00:00	2021-06-10 15:30:00	\N	\N	3	0	\N	\N
568249	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Prévention d'actes de terrorisme et renseignement	\N	2021-06-10 15:30:00	2021-06-10 18:15:00	\N	\N	2	0	\N	\N
568252	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Prévention d'actes de terrorisme et renseignement	\N	2021-06-10 18:15:00	2021-06-10 18:45:00	\N	\N	1	0	\N	\N
570042	GIA	AUCUNE	\N	\N	\N	Réunion commune DDF - GIA France-Pologne	Réunion commune DDF - GIA France-Pologne	2021-06-09 17:00:00	2021-06-09 19:00:00	\N	\N	1	0	600	\N
570846	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de Dominique Simonnot, contrôleure générale des lieux de privation des libertés	Audition de Dominique Simonnot, contrôleure générale des lieux de privation des libertés	2021-06-22 17:00:00	2021-06-22 17:55:00	2021-06-22 18:02:56	2021-06-24 18:15:17	7	0	\N	\N
570847	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de Jean-Baptiste Djebbari, ministre délégué chargé des transports	Audition de Jean-Baptiste Djebbari, ministre délégué chargé des transports	2021-06-23 16:35:00	2021-06-23 17:20:00	2021-06-23 17:37:20	2021-06-24 18:15:13	9	0	\N	\N
570848	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Table ronde sur le PJL Confiance dans l'institution judiciaire	Table ronde sur le PJL Confiance dans l'institution judiciaire	2021-06-23 09:25:00	2021-06-23 12:20:00	2021-06-23 12:42:53	2021-06-24 18:15:18	17	0	\N	\N
570849	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de Didier Migaud, président de la HATVP	Audition de Didier Migaud, président de la HATVP	2021-06-23 18:05:00	2021-06-23 19:15:00	2021-06-23 19:26:49	2021-06-24 18:15:12	1	0	\N	\N
570964	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition conjointe de représentants de Google France et Facebook France	\N	2021-06-23 09:35:00	2021-06-23 11:45:00	\N	\N	21	0	\N	\N
570966	MISSION	AUDRAP	\N	EGALCHAN	\N	Audition rapporteure	\N	2021-06-17 14:30:00	2021-06-17 16:00:00	\N	\N	2	0	\N	\N
570985	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Innovation en santé - Audition des personnalités qualifiées CSIS	\N	2021-06-16 18:10:00	2021-06-16 20:05:00	\N	\N	2	0	\N	\N
571360	ETUDES	AUTRE	\N	\N	\N	GEAC - Audition de M. Paul Chiambaretto, Professeur de stratégie et marketing	GEAC - Audition de M. Paul Chiambaretto, Professeur de stratégie et marketing	2021-07-21 08:00:00	2021-07-21 09:15:00	\N	\N	7	0	\N	933
571438	MISSION	AUDRAP	\N	ENSAGRIC	\N	Audition commune DGEFP/OPCO	\N	2021-06-22 14:30:00	2021-06-22 16:10:00	\N	\N	3	0	\N	\N
571447	MISSION	AUDRAP	\N	ENSAGRIC	\N	Mutualité sociale agricole (MSA)	\N	2021-06-23 16:35:00	2021-06-23 17:23:00	\N	\N	3	0	\N	\N
571526	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-06-29 13:30:00	2021-06-29 14:08:00	2021-06-29 14:39:41	2021-06-29 17:17:19	22	2	\N	\N
571785	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Pjl terrorisme	Pjl terrorisme	2021-06-07 11:00:00	2021-06-07 11:45:00	\N	\N	1	0	\N	\N
571787	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Pjl terrorisme	Pjl terrorisme	2021-06-07 11:45:00	2021-06-07 12:30:00	\N	\N	1	0	\N	\N
571789	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Pjl terrorisme	Pjl terrorisme	2021-06-09 16:30:00	2021-06-09 17:00:00	\N	\N	1	0	\N	\N
571792	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Pjl terrorisme	Pjl terrorisme	2021-06-09 17:15:00	2021-06-09 17:55:00	\N	\N	1	0	\N	\N
571794	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Pjl terrorisme	Pjl terrorisme	2021-06-10 09:00:00	2021-06-10 09:50:00	\N	\N	1	0	\N	\N
571796	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Pjl terrorisme	Pjl terrorisme	2021-06-10 10:00:00	2021-06-10 11:00:00	\N	\N	1	0	\N	\N
572006	GIA	AUCUNE	\N	\N	\N	Entretien avec S.E. M. Henok TEFERRA, Ambassadeur d¿Éthiopie en France	Entretien avec S.E. M. Henok TEFERRA, Ambassadeur d¿Éthiopie en France	2021-06-23 08:30:00	2021-06-23 09:30:00	\N	\N	5	0	588	\N
572013	SEANCE_PLENIERE	DECL_GVT	\N	\N	\N	Déclaration du Gouvernement 50-1 Programmation militaire	Déclaration du Gouvernement 50-1 Programmation militaire	2021-06-23 16:35:00	2021-06-23 19:30:00	\N	\N	106	0	\N	\N
572216	GIA	AUCUNE	\N	\N	\N	\N	GIA Afrique de l'Ouest - Réunion du Bureau	2021-06-23 14:00:00	2021-06-23 14:45:00	\N	\N	6	0	573	\N
572225	GIA	AUCUNE	\N	\N	\N	Entretien avec Philippe Crouzet	Entretien avec Philippe Crouzet, Haut-Représentant pour la coopération du nucléaire civil en Pologne	2021-06-23 15:00:00	2021-06-23 16:00:00	\N	\N	1	0	600	\N
572526	GIA	AUCUNE	\N	\N	\N	GIA-Entretien avec Mme Aminata Touré	GIA-Entretien avec Mme Aminata Touré	2021-06-22 16:00:00	2021-06-22 17:00:00	\N	\N	1	0	604	\N
572729	MISSION	AUCUNE	\N	UBER	\N	Audition plénière	\N	2021-06-24 11:00:00	2021-06-24 12:05:00	2021-06-24 12:07:32	2021-06-24 18:16:50	6	0	\N	\N
572736	MISSION	AUCUNE	\N	CONF	\N	Réunion plénière - présentation de rapport	\N	2021-06-24 09:05:00	2021-06-24 09:45:00	2021-06-24 11:57:41	2021-06-24 18:16:50	7	0	\N	\N
572776	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2021-06-29 16:00:00	2021-06-29 18:15:00	2021-06-29 18:18:05	2021-06-30 18:40:54	34	0	\N	\N
572778	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2021-06-30 09:30:00	2021-06-30 12:10:00	2021-06-30 14:23:28	2021-06-30 18:40:57	35	0	\N	\N
572779	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2021-06-30 16:30:00	2021-06-30 17:40:00	\N	\N	13	0	\N	\N
572787	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLFR pour 2021 : Examen Amdts de séance et désignation CMP	PLFR pour 2021 : Examen Amdts de séance et désignation CMP	2021-06-30 09:00:00	2021-06-30 09:40:00	2021-06-30 10:32:37	2021-06-30 18:40:56	30	0	\N	\N
572788	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Réunion avec Mme Jacqueline Gourault et Mme Emmanuelle Wargon et cabinets	Réunion avec Mme Jacqueline Gourault et Mme Emmanuelle Wargon et cabinets	2021-06-23 09:00:00	2021-06-23 10:00:00	\N	\N	0	0	\N	\N
572789	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Différenciation, décentralisation, déconcentration et simplification - Audition DHUP	PJL Différenciation, décentralisation, déconcentration et simplification - Audition DHUP	2021-06-22 08:30:00	2021-06-22 09:30:00	\N	\N	0	0	\N	\N
572798	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Différenciation, décentralisation, déconcentration et simplification - Audition AdCF	PJL Différenciation, décentralisation, déconcentration et simplification - Audition AdCF	2021-06-23 10:30:00	2021-06-23 11:00:00	\N	\N	0	0	\N	\N
572985	DELEGATION	AUCUNE	\N	\N	COLTER	Audition sur la situation et l¿avenir des services préfectoraux et déconcentrés	\N	2021-06-24 09:30:00	2021-06-24 11:45:00	\N	\N	18	0	\N	\N
573138	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Suite rapport "retraits et rappels de produits à base de sésame importé d'Inde"	Audition de la DGCCRF - Suite rapport "retraits et rappels de produits à base de sésame importé d'Inde"	2021-06-22 17:30:00	2021-06-22 18:45:00	\N	\N	1	0	\N	\N
573149	DELEGATION	AUDRAP	\N	\N	206	Audition relative au stockage de données sous la forme de l ADN	Audition relative au stockage de données sous la forme de l ADN	2021-06-23 13:00:00	2021-06-23 14:00:00	\N	\N	1	0	\N	\N
573921	MISSION	AUDRAP	\N	EGALCHAN	\N	Audition M. Disa	\N	2021-07-15 14:00:00	2021-07-15 15:00:00	\N	\N	1	0	\N	\N
573931	MISSION	AUDRAP	\N	EGALCHAN	\N	Échange de vues avec sénateurs ultramarins	\N	2021-06-15 15:00:00	2021-06-15 16:30:00	\N	\N	1	0	\N	\N
574357	GIA	AUCUNE	\N	\N	\N	entretien avec S.E. M. Dae Jong YOO, ambassadeur de la République de Corée en France	\N	2021-06-30 08:30:00	2021-06-30 09:30:00	\N	\N	7	0	613	\N
574883	GIA	AUCUNE	\N	\N	\N	Rencontre avec M. Manuel Muniz, Secrétaire d'Etat à l'Espagne globale 	Rencontre avec M. Manuel Muniz, Secrétaire d'Etat à l'Espagne globale 	2021-06-28 18:00:00	2021-06-28 19:15:00	\N	\N	4	0	589	\N
574888	GIA	AUCUNE	\N	\N	\N	rencontre avec Mme Iliana Iliotova, vice présidente de la République 	rencontre avec Mme Iliana Iliotova, vice présidente de la République 	2021-06-29 15:00:00	2021-06-29 16:00:00	\N	\N	4	0	582	\N
574899	MISSION	AUCUNE	\N	HARCEL	\N	MI Harcèlement	\N	2021-06-30 16:35:00	2021-06-30 18:05:00	2021-06-30 20:58:53	2021-07-01 17:47:58	8	0	\N	\N
575191	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2021-06-30 17:00:00	2021-06-30 19:30:00	\N	\N	3	0	\N	\N
575196	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2021-07-01 08:30:00	2021-07-01 10:00:00	\N	\N	7	0	\N	\N
575204	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2021-07-01 10:00:00	2021-07-01 13:00:00	\N	\N	3	0	\N	\N
518565	GIA	AUCUNE	\N	\N	\N	Assemblée générale du GIA France-Espagne	Assemblée générale du GIA France-Espagne	2020-12-17 09:30:00	2020-12-17 09:45:00	\N	\N	11	0	589	\N
518674	DELEGATION	AUCUNE	\N	\N	COLTER	Audition Olivier Dussopt, ministre ; Audition Jean-René Cazeneuve, Assemblée nationale	\N	2021-01-14 09:30:00	2021-01-14 12:15:00	2021-01-14 16:48:25	\N	23	0	\N	\N
525881	GIA	AUCUNE	\N	\N	\N	Audition de Paul TEBOUL (DG Trésor)  sur la réforme du France CFA	Audition de Paul TEBOUL (DG Tresor) sur la réforme du Franc CFA en Afrique de  l'ouest	2021-01-27 14:15:00	2021-01-27 15:00:00	\N	\N	10	0	573	\N
538662	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	CDD	\N	Examen des amendements de séance par la rapporteure	Examen des amendements de séance par la rapporteure	2021-03-09 13:30:00	2021-03-09 14:00:00	\N	\N	1	0	\N	\N
542314	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Respect des principes de la République (rapport et texte de la commission - suite)	PJL Respect des principes de la République (rapport et texte de la commission - suite)	2021-03-18 08:30:00	2021-03-18 09:25:00	2021-03-18 10:33:23	2021-03-18 17:52:18	19	0	\N	\N
542926	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR Politique énergétique	PPR Politique énergétique	2021-03-23 14:30:00	2021-03-23 16:00:00	\N	\N	101	0	\N	\N
542927	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Aménagement du territoire	Débat Aménagement du territoire	2021-03-23 16:00:00	2021-03-23 17:40:00	\N	\N	93	0	\N	\N
542928	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat liaisons trans-Manche	Débat liaisons trans-Manche	2021-03-23 17:40:00	2021-03-23 19:20:00	\N	\N	69	0	\N	\N
542930	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2021-03-24 15:00:00	2021-03-24 16:25:00	\N	\N	197	0	\N	\N
542934	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Cour des comptes	Débat Cour des comptes	2021-03-24 16:50:00	2021-03-24 18:50:00	\N	\N	78	0	\N	\N
542935	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Rôle Préfet	Débat Rôle Préfet	2021-03-24 18:55:00	2021-03-24 20:30:00	\N	\N	44	0	\N	\N
542936	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Pratique sportive	Débat Pratique sportive	2021-03-24 22:00:00	2021-03-24 23:35:00	\N	\N	20	0	\N	\N
542938	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat  Veolia-Suez	Débat Veolia-Suez	2021-03-25 14:30:00	2021-03-25 16:05:00	\N	\N	47	0	\N	\N
542945	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Mineurs crimes sexuels	PPL Mineurs crimes sexuels	2021-03-25 16:10:00	2021-03-25 19:40:00	\N	\N	39	0	\N	\N
542947	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PPL Dignité en détention	CMP PPL Dignité en détention	2021-03-25 19:45:00	2021-03-25 20:40:00	\N	\N	17	0	\N	\N
556333	GIA	AUCUNE	\N	\N	\N	Audition du président de la fondation Mérieux	Audition de M. Alain Mérieux, président de la fondation Mérieux, du docteur Georges Képénékian et de M. Khélil Aïtout, r	2021-05-04 14:00:00	2021-05-04 15:30:00	\N	\N	9	0	641	\N
556343	ETUDES	AUCUNE	\N	\N	\N	Audition Benjamin Stora	\N	2021-05-04 18:00:00	2021-05-04 19:00:00	\N	\N	17	0	\N	928
557456	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI "Difficultés des entreprises et crise de la Covid-19"	Audition rapporteur - MI "Difficultés des entreprises et crise de la Covid-19"	2021-05-03 09:00:00	2021-05-03 09:45:00	\N	\N	2	0	\N	\N
557459	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI "Difficultés des entreprises et crise de la Covid-19"	Audition rapporteur - MI "Difficultés des entreprises et crise de la Covid-19"	2021-05-03 09:45:00	2021-05-03 10:30:00	\N	\N	2	0	\N	\N
557463	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI "Difficultés des entreprises et crise de la Covid-19"	Audition rapporteur - MI "Difficultés des entreprises et crise de la Covid-19"	2021-05-03 10:30:00	2021-05-03 11:15:00	\N	\N	2	0	\N	\N
557466	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI "Difficultés des entreprises et crise de la Covid-19"	Audition rapporteur - MI "Difficultés des entreprises et crise de la Covid-19"	2021-05-03 11:15:00	2021-05-03 12:15:00	\N	\N	2	0	\N	\N
557729	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Examen Rapport pour avis DADUE + Amendements de séance développement	\N	2021-05-11 09:00:00	2021-05-11 10:45:00	2021-05-11 12:23:56	2021-05-11 15:54:38	30	0	\N	\N
557733	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Examen amendements de séance pjl développement	\N	2021-05-12 11:00:00	2021-05-12 13:00:00	\N	\N	0	0	\N	\N
560622	COM_EURO	CONTROLE	\N	AFEU	\N	Auditions DSA/DMA 	Audition DSA/DMA - Open internet project (OIP)	2021-05-18 17:30:00	2021-05-18 18:30:00	\N	\N	2	0	\N	\N
563808	DELEGATION	AUCUNE	\N	\N	COLTER	Audition JP. Vicentini, procureur de la République + TR Nouvelles technologies	\N	2021-06-03 09:30:00	2021-06-03 12:30:00	\N	\N	5	0	\N	\N
564327	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT Puissance chinoise en Europe	\N	2021-05-25 15:00:00	2021-05-25 18:00:00	\N	\N	3	0	\N	\N
564331	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT Puissance chinoise en Europe	\N	2021-05-26 16:30:00	2021-05-26 17:30:00	\N	\N	3	0	\N	\N
564335	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Coût collectivités territoriales	Débat Coût collectivités territoriales	2021-06-01 14:30:00	2021-06-01 16:10:00	\N	\N	80	0	\N	\N
564336	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR Règlement du Sénat	PPR Règlement du Sénat	2021-06-01 16:15:00	2021-06-01 19:55:00	\N	\N	122	0	\N	\N
564338	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2021-06-02 15:00:00	2021-06-02 16:25:00	\N	\N	203	0	\N	\N
564339	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Débat Application des lois	Débat Application des lois	2021-06-02 16:45:00	2021-06-02 18:15:00	\N	\N	45	0	\N	\N
564340	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Pacte vert	Débat Pacte vert	2021-06-02 18:20:00	2021-06-02 19:55:00	\N	\N	38	0	\N	\N
564341	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Reprise et relance des activités culturelles	Débat Reprise et relance des activités culturelles	2021-06-02 21:30:00	2021-06-02 23:10:00	\N	\N	31	0	\N	\N
564342	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2021-06-03 09:30:00	2021-06-03 12:45:00	\N	\N	39	0	\N	\N
564343	SEANCE_PLENIERE	DEBAT	\N	\N	\N	PPL Lisibilité du droit	PPL Lisibilité du droit	2021-06-03 14:30:00	2021-06-03 15:25:00	\N	\N	25	0	\N	\N
564344	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Régulation des GAFAM	Débat Régulation des GAFAM	2021-06-03 15:25:00	2021-06-03 17:00:00	\N	\N	38	0	\N	\N
564345	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Contrôle aux frontières	Débat Contrôle aux frontières	2021-06-03 17:05:00	2021-06-03 18:25:00	\N	\N	23	0	\N	\N
564357	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Nommer les enfants nés sans vie	Audition rapporteur - PPL nommer les enfants nés sans vie	2021-05-28 14:40:00	2021-05-28 16:30:00	\N	\N	1	0	\N	\N
565123	MISSION	AUCUNE	\N	ENSAGRIC	\N	Déplacement dans le Nord	\N	2021-05-27 08:00:00	2021-05-27 22:00:00	\N	\N	3	0	\N	\N
565173	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Conseil général  de Seine-Saint-Denis	\N	2021-06-03 15:30:00	2021-06-03 16:15:00	\N	\N	6	0	\N	\N
565174	MISSION	AUCUNE	\N	ENSAGRIC	\N	Déplacement dans la Drôme	\N	2021-05-28 08:00:00	2021-05-28 22:00:00	\N	\N	2	0	\N	\N
570619	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	Réunion du GT subsidiarité	Réunion du GT subsidiarité	2021-06-17 08:30:00	2021-06-17 08:45:00	\N	\N	3	0	\N	\N
571299	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de Gérald Darmanin, ministre de l'intérieur	Audition de Gérald Darmanin, ministre de l'intérieur	2021-06-23 08:00:00	2021-06-23 09:20:00	2021-06-23 09:49:20	2021-06-24 18:15:18	32	0	\N	\N
571300	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2021 - Immobilier universitaire - Déplacement à Troyes	Contrôle 2021 - Immobilier universitaire - Déplacement à Troyes	2021-06-24 08:45:00	2021-06-24 16:15:00	\N	\N	1	0	\N	\N
571301	MISSION	AUDRAP	\N	HARCEL	\N	Audition Rapporteure - association Phare Enfants-Parents (Mme Thérèse Hannier)	Audition Rapporteure - association Phare Enfants-Parents (Mme Thérèse Hannier)	2021-06-18 10:00:00	2021-06-18 10:45:00	\N	\N	2	0	\N	\N
571304	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-06-22 08:30:00	2021-06-22 09:10:00	2021-06-22 09:29:31	2021-06-22 14:11:12	16	2	\N	\N
571306	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-06-24 10:30:00	2021-06-24 12:30:00	\N	\N	0	0	\N	\N
571307	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion pleinière CATDD	\N	2021-06-24 19:00:00	2021-06-24 21:00:00	\N	\N	0	0	\N	\N
568279	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - MDPH - MMPH Martinique	Contrôle 2021 - MDPH - MMPH Martinique	2021-06-09 15:00:00	2021-06-09 16:00:00	\N	\N	2	0	\N	\N
568282	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2021 - MDPH - Déplacement MDPH de Paris	Contrôle 2021 - MDPH - Déplacement MDPH de Paris	2021-06-09 16:00:00	2021-06-09 18:00:00	\N	\N	2	0	\N	\N
568285	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition DGOS	\N	2021-06-16 13:30:00	2021-06-16 14:00:00	\N	\N	2	0	\N	\N
568298	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Actualisation LPM	\N	2021-06-09 14:00:00	2021-06-09 15:00:00	\N	\N	1	0	\N	\N
568390	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Différenciation, décentralisation, déconcentration et simplification	Audition rapporteur - PJL dit « 3DS »	2021-06-14 14:30:00	2021-06-14 16:50:00	\N	\N	1	0	\N	\N
568777	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Haut Karabakh	\N	2021-06-15 15:00:00	2021-06-15 16:00:00	\N	\N	4	0	\N	\N
568782	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Haut Karabakh	\N	2021-06-15 16:00:00	2021-06-15 16:30:00	\N	\N	3	0	\N	\N
569823	ETUDES	AUCUNE	\N	\N	\N	Audition cycle Santé I	Audition cycle Santé I	2021-06-16 08:30:00	2021-06-16 09:30:00	\N	\N	4	0	\N	998
569828	MISSION	AUCUNE	\N	HARCEL	\N	Réunion du 16 juin 2021	Réunion du 16 juin 2021	2021-06-16 16:35:00	2021-06-16 18:05:00	2021-06-16 19:08:38	2021-06-18 18:53:34	8	0	\N	\N
569838	MISSION	AUTRE	\N	HARCEL	\N	Audition plénière	\N	2021-06-17 10:30:00	2021-06-17 12:30:00	\N	\N	0	0	\N	\N
570219	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 24 juin 2021	\N	2021-06-24 09:00:00	2021-06-24 10:00:00	2021-06-24 10:05:02	2021-06-24 18:15:57	11	0	\N	\N
570390	ETUDES	AUTRE	\N	\N	\N	Audition de la Maison des agriculteurs d'Algérie (MAFA)	\N	2021-06-15 18:00:00	2021-06-15 19:10:00	\N	\N	6	0	\N	928
570597	GIA	AUCUNE	\N	\N	\N	Déjeuner à l'occasion de la Journée mondiale des abeilles	Déjeuner à l'occasion de la Journée mondiale des abeilles	2021-06-16 12:30:00	2021-06-16 14:00:00	\N	\N	4	0	529	\N
570970	MISSION	AUDRAP	\N	EGALCHAN	\N	Audition rapporteure	\N	2021-06-17 16:00:00	2021-06-17 17:00:00	\N	\N	1	0	\N	\N
570975	GIA	AUCUNE	\N	\N	\N	\N	Entretien avec Mme Jane Coombs, ambassadrice de Nouvelle-Zélande en France	2021-06-17 10:00:00	2021-06-17 11:10:00	\N	\N	5	0	663	\N
571144	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Climat	PJL Climat	2021-06-22 14:30:00	2021-06-22 20:05:00	\N	\N	123	0	\N	\N
571145	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Climat	PJL Climat	2021-06-22 21:35:00	2021-06-23 01:30:00	\N	\N	91	0	\N	\N
579557	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	c	2021-07-08 10:05:00	2021-07-08 12:55:00	\N	\N	3	0	\N	\N
571305	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-06-23 10:03:00	2021-06-23 10:18:00	2021-06-23 12:04:55	2021-06-24 18:15:14	25	1	\N	\N
571148	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Climat	PJL Climat	2021-06-23 21:00:00	2021-06-24 01:45:00	\N	\N	72	0	\N	\N
571152	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL NL Bioéthique	PJL NL Bioéthique	2021-06-24 10:45:00	2021-06-24 12:15:00	\N	\N	57	0	\N	\N
571153	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Climat	PJL Climat	2021-06-24 12:20:00	2021-06-24 13:05:00	\N	\N	52	0	\N	\N
571154	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Climat	PJL Climat	2021-06-24 14:35:00	2021-06-24 20:00:00	\N	\N	73	0	\N	\N
571155	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Climat	PJL Climat	2021-06-24 21:30:00	2021-06-25 00:40:00	\N	\N	46	0	\N	\N
571156	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Climat	PJL Climat	2021-06-25 09:40:00	2021-06-25 13:00:00	\N	\N	46	0	\N	\N
571157	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Climat	PJL Climat	2021-06-25 14:30:00	2021-06-25 19:20:00	\N	\N	50	0	\N	\N
571276	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT Puissance chinoise en Europe	\N	2021-06-15 14:00:00	2021-06-15 15:00:00	\N	\N	3	0	\N	\N
571560	MISSION	AUDRAP	\N	EGALCHAN	\N	MI Égalité des chances - Audition du recteur académie de Guyane	\N	2021-06-22 16:00:00	2021-06-22 17:00:00	\N	\N	2	0	\N	\N
572790	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ambassadeur de Thaïlande	Déjeuner 	2021-06-22 12:30:00	2021-06-22 14:15:00	\N	\N	8	0	609	\N
572806	ETUDES	AUCUNE	\N	\N	\N	\N	\N	2021-06-09 13:30:00	2021-06-09 14:50:00	\N	\N	12	0	\N	1010
572835	GIA	AUCUNE	\N	\N	\N	Entretien avec l'Ambassdaeur d'Oman	Déjeuner	2021-06-23 12:30:00	2021-06-23 14:30:00	\N	\N	3	0	661	\N
572939	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJLR pour 2020 - Conseil d'État	PJLR pour 2020 - Conseil d'État	2021-06-22 17:15:00	2021-06-22 18:15:00	\N	\N	1	0	\N	\N
572961	COM_PERMANENTE	AUTRE	\N	CAE	\N	Examen avis PJL 3DS	\N	2021-06-29 16:05:00	2021-06-29 18:50:00	2021-06-30 18:39:09	2021-06-30 18:40:55	32	0	\N	\N
572988	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Prévention d'actes de terrorisme et renseignement (amendements)	PJL Prévention d'actes de terrorisme et renseignement (amendements)	2021-06-29 09:00:00	2021-06-29 09:58:00	2021-06-29 10:13:31	2021-06-29 17:17:18	14	0	\N	\N
573011	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJLC Préservation de l'environnement (rapport) - PJL 4D (rapport et texte)	PJLC Préservation de l'environnement (rapport) - PJL 4D (rapport et texte)	2021-06-30 08:35:00	2021-06-30 12:20:00	2021-06-30 16:24:36	2021-06-30 18:40:56	35	0	\N	\N
573014	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Différenciation, décentralisation, déconcentration et simplification (suite et fin)	PJL Différenciation, décentralisation, déconcentration et simplification (suite et fin)	2021-06-30 13:35:00	2021-06-30 14:55:00	2021-06-30 16:24:47	2021-06-30 18:41:00	16	0	\N	\N
573137	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 17 juin 2021	\N	2021-06-17 08:45:00	2021-06-17 12:00:00	\N	\N	0	0	\N	\N
573151	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Différenciation, décentralisation, déconcentration et simplification - Audition Cerema	PJL Différenciation, décentralisation, déconcentration et simplification - Audition Cerema	2021-06-08 14:00:00	2021-06-08 14:45:00	\N	\N	1	0	\N	\N
573153	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Différenciation, décentralisation, déconcentration et simplification - Audition AMRF	PJL Différenciation, décentralisation, déconcentration et simplification - Audition AMRF	2021-06-08 15:30:00	2021-06-08 16:15:00	\N	\N	1	0	\N	\N
573155	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Différenciation, décentralisation, déconcentration et simplification - Audition ADF	PJL Différenciation, décentralisation, déconcentration et simplification - Audition ADF	2021-06-09 14:45:00	2021-06-09 15:30:00	\N	\N	1	0	\N	\N
573157	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Différenciation, décentralisation, déconcentration et simplification - Audition ADF	PJL Différenciation, décentralisation, déconcentration et simplification - Audition ADF	2021-06-09 15:30:00	2021-06-09 16:15:00	\N	\N	1	0	\N	\N
573159	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Différenciation, décentralisation, déconcentration et simplification - Audition AFSA	PJL Différenciation, décentralisation, déconcentration et simplification - Audition AFSA	2021-06-10 09:00:00	2021-06-10 10:00:00	\N	\N	1	0	\N	\N
573161	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Différenciation, décentralisation, déconcentration et simplification - Audition Région	PJL Différenciation, décentralisation, déconcentration et simplification - Audition Régions de France	2021-06-10 11:30:00	2021-06-10 12:15:00	\N	\N	1	0	\N	\N
573163	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Différenciation, décentralisation, déconcentration et simplification - Audition ANCT	PJL Différenciation, décentralisation, déconcentration et simplification - Audition ANCT	2021-06-10 14:00:00	2021-06-10 14:45:00	\N	\N	1	0	\N	\N
573165	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Différenciation, décentralisation, déconcentration et simplification - Agence de l'eau	PJL Différenciation, décentralisation, déconcentration et simplification - Agence de l'eau	2021-06-10 14:45:00	2021-06-10 15:30:00	\N	\N	1	0	\N	\N
573167	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Différenciation, décentralisation, déconcentration et simplification - Audition  DEB	PJL Différenciation, décentralisation, déconcentration et simplification - Audition  DEB	2021-06-10 15:30:00	2021-06-10 16:15:00	\N	\N	1	0	\N	\N
573169	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Différenciation, décentralisation, déconcentration et simplification - Audition ART	PJL Différenciation, décentralisation, déconcentration et simplification - Audition ART	2021-06-15 14:00:00	2021-06-15 14:45:00	\N	\N	1	0	\N	\N
573171	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Différenciation, décentralisation, déconcentration et simplification - Audition DGCL	PJL Différenciation, décentralisation, déconcentration et simplification - Audition DGCL	2021-06-15 14:45:00	2021-06-15 15:30:00	\N	\N	1	0	\N	\N
515740	GIA	AUCUNE	\N	\N	\N	Assemblée générale constitutive	Assemblée générale constitutive	2020-12-09 17:30:00	2020-12-09 18:05:00	\N	\N	8	0	580	\N
515756	GIA	AUCUNE	\N	\N	\N	AG France-Autriche	Assemblée générale France-Autriche	2020-12-09 13:45:00	2020-12-09 14:15:00	\N	\N	9	0	579	\N
516806	DELEGATION	AUCUNE	\N	\N	206	Conférence de presse Pollution plastique	Conférence de presse Pollution plastique	2020-12-14 11:00:00	2020-12-14 12:30:00	\N	\N	0	0	\N	\N
582726	GIA	AUCUNE	\N	\N	\N	Entretien avec Mme Blutel, ambassadrice de France au Kosovo	\N	2021-09-02 12:00:00	2021-09-02 13:00:00	\N	\N	4	0	674	\N
516807	DELEGATION	AUCUNE	\N	\N	206	Conférence de presse - Conclusions étude sur la stratégie vaccinale	Conférence de presse - Conclusions étude sur la stratégie vaccinale	2020-12-15 17:15:00	2020-12-15 18:30:00	\N	\N	0	0	\N	\N
517047	GIA	AUCUNE	\N	\N	\N	Assemblée générale	AG reconstitutive	2020-12-15 14:00:00	2020-12-15 14:15:00	\N	\N	14	0	629	\N
517067	ETUDES	AUCUNE	\N	\N	\N	Assemblée générale	AG reconstitutive	2020-12-16 08:00:00	2020-12-16 09:00:00	\N	\N	26	0	\N	907
521666	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	\N	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne - Commission d'Apuration des comptes	2021-01-13 16:30:00	2021-01-13 18:00:00	2021-01-19 11:44:43	2021-01-22 15:38:07	10	0	\N	\N
528634	ETUDES	AUCUNE	\N	\N	\N	Audition RTE	Audition RTE	2021-02-03 08:15:00	2021-02-03 09:15:00	\N	\N	21	0	\N	906
534323	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de Mme Catherine MacGregor	\N	2021-03-03 09:35:00	2021-03-03 11:00:00	2021-03-03 18:32:49	2021-03-04 17:56:53	43	0	\N	\N
534353	COM_PERMANENTE	AUTRE	\N	FINC	\N	Tables rondes :  Transformation des services bancaires et Évolution du modèle bancaire	Tables rondes :  Transformation des services bancaires et Évolution du modèle bancaire	2021-03-03 09:00:00	2021-03-03 12:00:00	2021-03-03 14:26:53	2021-03-03 17:06:03	41	0	\N	\N
534354	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de Mme Mairead McGUINNESS, commissaire européenne chargée des services financiers	Audition de Mme Mairead McGUINNESS, commissaire européenne chargée des services financiers	2021-03-04 11:30:00	2021-03-04 12:35:00	2021-03-05 09:41:18	2021-03-05 16:21:45	21	0	\N	\N
534355	MISSION	AUCUNE	\N	ENSAGRIC	\N	Audition de Mme Valérie Baduel (DGER)	\N	2021-03-03 16:35:00	2021-03-03 18:32:00	2021-03-04 13:10:40	2021-03-04 17:59:29	19	0	\N	\N
534356	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur	\N	2021-03-01 15:30:00	2021-03-01 16:30:00	\N	\N	1	0	\N	\N
536841	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT conjoint sur le suivi de la réforme de la PAC	Réunion du GT conjoint sur le suivi de la réforme de la PAC - Audition de M. Andrieu	2021-03-04 14:00:00	2021-03-04 15:15:00	\N	\N	11	0	\N	\N
547643	DELEGATION	AUDRAP	\N	\N	211	Audition de Mme Marie-Pierre Rixain, présidente de la DDF de l'Assemblée nationale	Audition de Mme Marie-Pierre Rixain, présidente de la DDF de l'Assemblée nationale	2021-03-31 17:00:00	2021-03-31 18:15:00	\N	\N	8	0	\N	\N
558429	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition M. Pascal Martin	\N	2021-05-11 14:45:00	2021-05-11 15:45:00	\N	\N	5	0	\N	\N
558474	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Haut Conseil pour le Climat - Réseau action climat	Contrôle 2021 - Haut Conseil pour le Climat - Réseau action climat	2021-05-11 15:30:00	2021-05-11 16:00:00	\N	\N	1	0	\N	\N
558477	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Dérèglement Climatique et résilience - AVERE-France	PJL Dérèglement Climatique et résilience - AVERE-France	2021-05-10 10:00:00	2021-05-10 11:00:00	\N	\N	1	0	\N	\N
558480	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Dérèglement Climatique et résilience - DGAC	PJL Dérèglement Climatique et résilience - DGAC	2021-05-10 11:00:00	2021-05-10 12:00:00	\N	\N	2	0	\N	\N
558486	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Dérèglement Climatique et résilience - CNPA	PJL Dérèglement Climatique et résilience - CNPA	2021-05-10 14:30:00	2021-05-10 15:00:00	\N	\N	1	0	\N	\N
558490	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Dérèglement Climatique et résilience - CSIAM	PJL Dérèglement Climatique et résilience - CSIAM	2021-05-10 15:00:00	2021-05-10 16:00:00	\N	\N	2	0	\N	\N
558494	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Situation et perspectives SNCF - Économiste transports	Contrôle 2021 - Situation et perspectives SNCF - Économiste transports	2021-05-11 10:00:00	2021-05-11 11:00:00	\N	\N	2	0	\N	\N
558527	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réforme des études de santé	\N	2021-05-12 10:31:00	2021-05-12 11:53:00	2021-05-12 17:20:51	2021-05-12 18:10:08	22	0	\N	\N
558529	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition R. Bachelot	\N	2021-05-12 16:32:00	2021-05-12 18:00:00	2021-05-12 20:00:36	2021-05-14 15:17:58	19	0	\N	\N
558978	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Responsabilité pénale des auteurs de crimes et délits	\N	2021-05-11 16:00:00	2021-05-11 16:35:00	\N	\N	1	0	\N	\N
558980	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Irresponsabilité pénale	\N	2021-05-11 16:00:00	2021-05-11 16:35:00	\N	\N	1	0	\N	\N
564954	COM_PERMANENTE	AUTRE	\N	CDD	\N	\N	\N	2021-06-02 09:00:00	2021-06-02 13:03:00	2021-06-04 17:57:58	2021-06-04 17:58:02	45	1	\N	\N
565247	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition recherche en santé mentale	\N	2021-06-03 16:00:00	2021-06-03 17:30:00	\N	\N	1	0	\N	\N
565256	COM_EURO	AUTRE	\N	AFEU	\N	Auditions de la commission des affaires européennes - Audition plénière	\N	2021-06-10 09:35:00	2021-06-10 12:00:00	2021-06-11 14:48:49	\N	14	0	\N	\N
565265	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition CCMSA	\N	2021-06-08 13:45:00	2021-06-08 14:45:00	\N	\N	2	0	\N	\N
565268	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2021-06-09 09:35:00	2021-06-09 11:25:00	2021-06-11 14:38:25	2021-06-11 14:45:22	32	0	\N	\N
565471	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2021-06-09 09:30:00	2021-06-09 09:41:00	2021-06-09 11:27:11	2021-06-09 12:27:30	25	0	\N	\N
565714	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-06-02 16:30:00	2021-06-02 18:25:00	2021-06-03 19:30:02	2021-06-04 17:56:57	36	1	\N	\N
565771	GIA	AUCUNE	\N	\N	\N	Entretien avec le P. Hugues de Woillemont, secrétaire général de la conférence des évêques	\N	2021-06-02 16:30:00	2021-06-02 17:15:00	\N	\N	1	0	629	\N
565800	DELEGATION	AUCUNE	\N	\N	211	Table ronde sur le thème : La mobilité au c¿ur de l¿articulation des temps de vie 	Table ronde sur le thème : « La mobilité au c¿ur de l¿articulation des temps de vie des femmes dans les territoires rura	2021-06-24 08:30:00	2021-06-24 10:40:00	\N	\N	10	0	\N	\N
565801	DELEGATION	AUCUNE	\N	\N	211	Audition de Mme Brigitte Grésy, présidente du HCE	Audition de Mme Brigitte Grésy, présidente du Haut conseil à l'égalité entre les femmes et les hommes	2021-07-01 09:30:00	2021-07-01 11:05:00	\N	\N	9	0	\N	\N
565891	GIA	AUCUNE	\N	\N	\N	Entretien avec Antoine Bondaz, chercheur à la Fondation pour la recherche stratégique	\N	2021-06-02 16:30:00	2021-06-02 17:45:00	\N	\N	5	0	584	\N
565931	COM_EURO	AUTRE	\N	AFEU	\N	réunion du 3 juin 2021	\N	2021-06-03 08:35:00	2021-06-03 09:35:00	2021-06-07 17:50:24	2021-06-08 12:00:52	15	0	\N	\N
570925	GIA	AUCUNE	\N	\N	\N	Audition de M. Philippe Merlin, Ambassadeur de France en Mongolie 	Audition de M. Philippe Merlin, Ambassadeur de France en Mongolie 	2021-06-16 08:00:00	2021-06-16 09:00:00	\N	\N	6	0	612	\N
583469	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2021-09-22 10:00:00	2021-09-22 12:00:00	2021-09-22 17:50:21	2021-09-22 18:40:18	34	2	\N	\N
583471	GIA	AUCUNE	\N	\N	\N	Déplacement à Djibouti	Déplacement d'une délégation du groupe d'amitié à Djibouti 	2021-09-11 18:30:00	2021-09-16 06:15:00	\N	\N	3	0	588	\N
585831	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI répartition des moyens alloués à la création	\N	2021-09-20 14:00:00	2021-09-20 15:00:00	\N	\N	3	0	\N	\N
585837	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI répartition des moyens alloués à la création	\N	2021-09-20 15:00:00	2021-09-20 15:40:00	\N	\N	1	0	\N	\N
585912	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition R-O Maistre - CSA	\N	2021-09-29 09:30:00	2021-09-29 11:49:00	2021-09-29 12:11:05	2021-09-29 18:17:45	33	0	\N	\N
586005	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n° 383 Dons et adhésions aux associations - DLF	PPL n° 383 Dons et adhésions aux associations - DLF	2021-09-21 10:30:00	2021-09-21 11:30:00	\N	\N	1	0	\N	\N
586006	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n° 383 Dons et adhésions aux associations - DB	PPL n° 383 Dons et adhésions aux associations - DB	2021-09-23 15:00:00	2021-09-23 16:00:00	\N	\N	1	0	\N	\N
586009	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n° 383 Dons et adhésions aux associations - DGFiP	PPL n° 383 Dons et adhésions aux associations - DGFiP	2021-09-21 16:30:00	2021-09-21 17:30:00	\N	\N	1	0	\N	\N
586018	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Jeunesse au plein air	\N	2021-09-27 16:00:00	2021-09-27 17:00:00	\N	\N	1	0	\N	\N
575315	DELEGATION	AUDRAP	\N	\N	PROS	Auditions de M. Benjamin Lemoine et de M. Raul Sampognaro	\N	2021-06-30 16:30:00	2021-06-30 17:30:00	\N	\N	1	0	\N	\N
575316	DELEGATION	AUDRAP	\N	\N	PROS	Audition de M. François Ecalle	\N	2021-06-30 17:30:00	2021-06-30 18:30:00	\N	\N	35	0	\N	\N
575320	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2021 - IHU - Déplacement IHU FOReSIGHT Paris	Contrôle 2021 - IHU - Déplacement IHU FOReSIGHT Paris	2021-06-29 07:40:00	2021-06-29 11:20:00	\N	\N	2	0	\N	\N
575323	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - IHU - SGPI	Contrôle 2021 - IHU - SGPI	2021-06-30 16:30:00	2021-06-30 17:30:00	\N	\N	2	0	\N	\N
575326	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - MIRES - UGEI	PLF pour 2022 - MIRES - UGEI	2021-06-30 14:00:00	2021-06-30 14:30:00	\N	\N	1	0	\N	\N
575763	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Audition M. Jagorel	\N	2021-07-05 15:00:00	2021-07-05 16:00:00	\N	\N	1	0	\N	\N
575820	MISSION	AUDRAP	\N	METHANIS	\N	Audition préfecture Loire-Atlantique	Audition préfecture Loire-Atlantique	2021-07-02 11:00:00	2021-07-02 12:00:00	\N	\N	1	0	\N	\N
575865	DELEGATION	AUCUNE	\N	\N	206	Examen du rapport sur la lutte contre l'épidémie de Covid-19	\N	2021-07-06 13:35:00	2021-07-06 15:30:00	\N	\N	8	0	\N	\N
575940	MISSION	AUCUNE	\N	VIETUDIA	\N	présentation rapport d'information	\N	2021-07-06 17:05:00	2021-07-06 18:25:00	2021-07-07 11:53:01	2021-07-07 17:53:09	16	0	\N	\N
576104	ETUDES	AUCUNE	\N	\N	\N	Audition FNCOFOR	Audition FNCOFOR	2021-07-07 08:15:00	2021-07-07 09:15:00	\N	\N	21	0	\N	948
576166	ETUDES	AUCUNE	\N	\N	\N	Audition de M. Bernard Accoyer	Audition de M. Bernard Accoyer	2021-07-07 08:15:00	2021-07-07 09:15:00	\N	\N	16	0	\N	906
577322	COM_PERMANENTE	AUTRE	\N	LOIS	\N	MI Dysfonctionnements élections juin 2021 - Audition La Poste et ministère de l'intérieur	MI Dysfonctionnements élections juin 2021 - Audition La Poste et ministère de l'intérieur	2021-07-12 14:00:00	2021-07-12 17:00:00	2021-07-12 17:47:08	2021-07-12 18:18:51	16	0	\N	\N
577323	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteur sur les neurotechnologies	\N	2021-07-07 14:45:00	2021-07-07 16:45:00	\N	\N	1	0	\N	\N
577325	COM_PERMANENTE	AUTRE	\N	LOIS	\N	MI Dysfonctionnements élections juin 2021 - Audition Koba et Diffusion Plus	MI Dysfonctionnements élections juin 2021 - Audition Koba et Diffusion Plus	2021-07-13 09:00:00	2021-07-13 10:30:00	2021-07-13 10:54:14	2021-07-13 20:21:45	13	0	\N	\N
577328	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL 4D (suite et fin de l'examen des amendements)	PJL 4D (suite et fin de l'examen des amendements)	2021-07-15 09:10:00	2021-07-15 09:40:00	2021-07-15 10:05:30	2021-07-15 17:57:43	13	0	\N	\N
577371	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteur	\N	2021-07-07 17:30:00	2021-07-07 18:45:00	\N	\N	1	0	\N	\N
577372	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteur	\N	2021-07-07 16:45:00	2021-07-07 17:30:00	\N	\N	1	0	\N	\N
577396	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Adoption de rapport d'information	Adoption de rapport d'information	2021-07-08 09:00:00	2021-07-08 10:00:00	2021-07-08 17:01:45	\N	14	0	\N	\N
577397	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	ENTREPRISES	Réunion de travail - bilan annuel des travaux	Réunion de travail - bilan annuel des travaux	2021-07-08 08:00:00	2021-07-08 09:00:00	\N	\N	17	0	\N	\N
577914	MISSION	AUDRAP	\N	INFLUENCES	\N	Audition Campus France	\N	2021-07-08 16:00:00	2021-07-08 17:07:00	\N	\N	7	0	\N	\N
577930	MISSION	AUCUNE	\N	INFLUENCES	\N	Réunion plénière MI influences étatiques	\N	2021-07-13 15:00:00	2021-07-13 16:35:00	2021-07-16 08:58:14	2021-07-16 17:48:58	9	0	\N	\N
577955	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	ENTREPRISES	Conférence de presse	Conférence de presse	2021-07-08 11:05:00	2021-07-08 11:50:00	\N	\N	4	0	\N	\N
577989	COM_PERMANENTE	AUTRE	\N	FINC	\N	PJLR pour 2020 : AMDTS Séance et Communication RG sur le DOFP pour 2022	PJLR pour 2020 : AMDTS Séance et Communication RG sur le DOFP pour 2022	2021-07-12 15:00:00	2021-07-12 15:50:00	2021-07-12 16:04:59	2021-07-12 16:37:34	27	0	\N	\N
577997	MECSS	AUDRAP	\N	\N	MECSS	Audition de la CNAV	\N	2021-07-08 09:30:00	2021-07-08 10:30:00	\N	\N	2	0	\N	\N
577998	MECSS	AUDRAP	\N	\N	MECSS	Audition de l'Urssaf Caisse nationale	\N	2021-07-08 10:30:00	2021-07-08 11:30:00	\N	\N	2	0	\N	\N
577999	MECSS	AUDRAP	\N	\N	MECSS	Audition de l'Agirc-Arrco	\N	2021-07-08 14:30:00	2021-07-08 15:30:00	\N	\N	3	0	\N	\N
578000	MECSS	AUDRAP	\N	\N	MECSS	Audition de la DSS	\N	2021-07-08 15:30:00	2021-07-08 16:30:00	\N	\N	3	0	\N	\N
578060	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Mineurs non accompagnés - Table ronde d'associations	\N	2021-07-07 14:00:00	2021-07-07 15:00:00	\N	\N	3	0	\N	\N
578061	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Mineurs non accompagnés - Table ronde d'associations	\N	2021-07-06 15:30:00	2021-07-06 17:00:00	\N	\N	3	0	\N	\N
578062	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Mineurs non accompagnés - Audition de la Défenseure des droits	\N	2021-07-07 17:00:00	2021-07-07 18:00:00	\N	\N	3	0	\N	\N
578063	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Soins palliatifs - Table ronde sur les formations	\N	2021-07-08 14:00:00	2021-07-08 15:30:00	\N	\N	3	0	\N	\N
578124	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Volontariat des sapeurs-pompiers	Audition rapporteur - PPL volontariat des sapeurs-pompiers	2021-07-08 14:00:00	2021-07-08 17:00:00	\N	\N	3	0	\N	\N
578543	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL 3D S	PJL 3D S	2021-07-12 21:30:00	2021-07-13 00:30:00	\N	\N	74	0	\N	\N
578662	MISSION	AUTRE	\N	UBER	\N	Audition commune L. Guardiola, J. Lavaud et H. Novelli	\N	2021-07-13 08:30:00	2021-07-13 10:05:00	2021-07-13 10:14:00	2021-07-13 20:21:53	3	0	\N	\N
578867	GIA	AUCUNE	\N	\N	\N	Audition de M. Yves Arnoldy, CICR	Audition de M. Yves Arnoldy, chef de délégation France et Europe du Sud du Comité international de la Croix-Rouge (CICR)	2021-07-13 13:30:00	2021-07-13 14:45:00	\N	\N	5	0	597	\N
582765	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	MI Sécurité à Mayotte - Déplacement à Mayotte	MI Sécurité à Mayotte - Déplacement à Mayotte	2021-09-06 18:00:00	2021-09-10 09:00:00	\N	\N	4	0	\N	\N
582766	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	PPL Volontariat des sapeurs-pompiers - Déplacement à Annecy 	PPL Volontariat des sapeurs-pompiers - Déplacement à Annecy 	2021-09-07 08:00:00	2021-09-07 22:00:00	\N	\N	4	0	\N	\N
582768	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2021-09-15 09:30:00	2021-09-15 10:40:00	2021-09-15 10:42:55	2021-09-15 17:27:00	34	0	\N	\N
582769	MISSION	AUCUNE	\N	PAUP	\N	Réunion plénière	\N	2021-09-14 15:00:00	2021-09-14 16:05:00	2021-09-14 16:06:09	2021-09-15 17:27:27	13	0	\N	\N
582828	COM_PERMANENTE	AUCUNE	\N	LOIS	\N	Déplacement à Rennes	\N	2021-07-28 08:00:00	2021-07-28 22:00:00	\N	\N	0	0	\N	\N
582849	MISSION	AUDRAP	\N	METHANIS	\N	Audition La Coopération agricole	Audition La Coopération agricole	2021-09-01 15:00:00	2021-09-01 16:00:00	\N	\N	2	0	\N	\N
583492	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL éélection des juges consulaires 	PPL éélection des juges consulaires 	2021-09-21 14:30:00	2021-09-21 15:30:00	\N	\N	68	0	\N	\N
583493	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PJL/PJLO Oeuvres culturelles	CMP PJL/PJLO Oeuvres culturelles	2021-09-21 15:30:00	2021-09-21 16:45:00	\N	\N	66	0	\N	\N
583494	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PJL DADUE	CMP PJL DADUE	2021-09-21 16:45:00	2021-09-21 17:35:00	\N	\N	68	0	\N	\N
583495	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL rémunération des agriculteurs	PPL rémunération des agriculteurs	2021-09-21 17:35:00	2021-09-21 20:00:00	\N	\N	98	0	\N	\N
583496	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL rémunération des agriculteurs	PPL rémunération des agriculteurs	2021-09-21 21:30:00	2021-09-22 00:40:00	\N	\N	81	0	\N	\N
583497	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2021-09-22 15:00:00	2021-09-22 16:20:00	\N	\N	247	0	\N	\N
507475	DELEGATION	AUDRAP	\N	\N	206	Audition Production d'hydrogène - Claude Heller	Audition Production d'hydrogène - Claude Heller	2020-11-26 15:00:00	2020-11-26 16:00:00	\N	\N	1	0	\N	\N
507477	DELEGATION	AUDRAP	\N	\N	206	Audition Production d'hydrogène - Florence Lambert	Audition Production d'hydrogène - Florence Lambert	2020-11-26 16:00:00	2020-11-26 17:00:00	\N	\N	1	0	\N	\N
507480	DELEGATION	AUDRAP	\N	\N	206	Audition Production d'hydrogène - McPhy	Audition Production d'hydrogène - McPhy	2020-11-26 17:00:00	2020-11-26 18:30:00	\N	\N	1	0	\N	\N
514757	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière - Audition publique Pr. Alain Fischer	Réunion plénière - Audition publique Pr. Alain Fischer	2020-12-10 11:35:00	2020-12-10 13:15:00	\N	\N	16	0	\N	\N
514758	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière - Audition publique HAS	Réunion plénière - Audition publique HAS	2020-12-09 11:05:00	2020-12-09 12:45:00	\N	\N	8	0	\N	\N
519091	DELEGATION	AUCUNE	\N	\N	DSOM	Audition de la Cour des comptes	Audition de la Cour des comptes	2021-02-04 09:00:00	2021-02-04 11:30:00	\N	\N	17	0	\N	\N
525289	ETUDES	AUCUNE	\N	\N	\N	Réunion reconstitutive	Réunion reconstitutive	2021-01-26 10:00:00	2021-01-26 10:40:00	\N	\N	21	0	\N	918
534319	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Eau potable et assainissement en Guadeloupe	\N	2021-02-25 14:00:00	2021-02-25 14:25:00	\N	\N	1	0	\N	\N
534321	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Eau potable et assainissement en Guadeloupe	\N	2021-02-26 14:00:00	2021-02-26 14:45:00	\N	\N	1	0	\N	\N
534324	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Droit au respect de la dignité en détention	\N	2021-02-26 15:45:00	2021-02-26 16:15:00	\N	\N	2	0	\N	\N
534327	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Droit au respect de la dignité en détention	\N	2021-02-26 16:15:00	2021-02-26 16:45:00	\N	\N	3	0	\N	\N
536312	ETUDES	AUTRE	\N	\N	\N	Audition Afidol	\N	2021-03-03 13:45:00	2021-03-03 15:00:00	\N	\N	16	0	\N	1005
538612	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Transport de marchandises - M. Michel SAVY, professeur	MI Transport de marchandises - M. Michel SAVY, professeur	2021-03-09 14:40:00	2021-03-09 15:45:00	\N	\N	9	0	\N	\N
538613	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Transport de marchandises -AFILOG	MI Transport de marchandises - AFILOG	2021-03-09 15:45:00	2021-03-09 16:30:00	\N	\N	9	0	\N	\N
538614	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Transport de marchandises - ADEME	MI Transport de marchandises - ADEME	2021-03-09 16:30:00	2021-03-09 17:15:00	\N	\N	5	0	\N	\N
538641	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition DGEC	Audition DGEC	2021-03-09 14:15:00	2021-03-09 15:15:00	\N	\N	4	0	\N	\N
538646	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition DGCOMP	Audition DGCOMP	2021-03-09 15:15:00	2021-03-09 16:00:00	\N	\N	3	0	\N	\N
538649	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition associations de consommateurs	Audition associations de consommateurs	2021-03-09 16:00:00	2021-03-09 16:45:00	\N	\N	3	0	\N	\N
538655	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition APE	Audition APE	2021-03-09 16:45:00	2021-03-09 17:30:00	\N	\N	3	0	\N	\N
538659	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition RTE	\N	2021-03-09 18:30:00	2021-03-09 19:15:00	\N	\N	1	0	\N	\N
542529	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Groupe de travail sur l'avenir de La Poste	Groupe de travail sur l'avenir de La Poste	2021-03-16 13:30:00	2021-03-16 14:30:00	\N	\N	4	0	\N	\N
560588	COM_PERMANENTE	AUTRE	\N	CDD	\N	\N	\N	2021-05-19 09:31:00	2021-05-19 10:45:00	2021-05-19 11:02:13	2021-05-19 15:31:19	35	1	\N	\N
560589	COM_PERMANENTE	AUTRE	\N	CDD	\N	\N	\N	2021-05-19 11:36:00	2021-05-19 12:34:00	2021-05-19 14:55:39	2021-05-19 15:31:17	44	2	\N	\N
560614	COM_EURO	AUDRAP	\N	AFEU	\N	Auditions DSA/DMA	\N	2021-05-18 14:30:00	2021-05-18 17:30:00	\N	\N	1	0	\N	\N
560950	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Rapport Général - SNCF	PLF pour 2022 - Rapport Général - SNCF	2021-05-12 17:45:00	2021-05-12 18:45:00	\N	\N	1	0	\N	\N
561186	COM_PERMANENTE	AUDRAP	\N	CAE	\N	TR Conservatoire espace littoral et rivages lacustres - Conservatoire d'espaces naturels	\N	2021-05-19 13:30:00	2021-05-19 14:40:00	\N	\N	2	0	\N	\N
561190	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition AMF ADF ARF	\N	2021-05-17 14:00:00	2021-05-17 15:00:00	\N	\N	1	0	\N	\N
561195	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Plan de relance européen - SGAE/DB	Contrôle 2021 - Plan de relance européen - SGAE/DB	2021-05-18 15:00:00	2021-05-18 17:00:00	\N	\N	1	0	\N	\N
561202	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Plan de relance européen - ANCT	Contrôle 2021 - Plan de relance européen - ANCT	2021-05-19 08:30:00	2021-05-19 09:30:00	\N	\N	1	0	\N	\N
561204	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Situation et perspectives SNCF - Commissaire comptes SNCF/Transdev	Contrôle 2021 - Situation et perspectives SNCF - Commissaire comptes SNCF/Transdev	2021-05-18 08:30:00	2021-05-18 10:45:00	\N	\N	2	0	\N	\N
561209	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Dérèglement Climatique et résilience - CR Ile de France	PJL Dérèglement Climatique et résilience - CR Ile de France	2021-05-18 18:00:00	2021-05-18 18:40:00	\N	\N	1	0	\N	\N
561234	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Services dédiés à la recherche patrimoniale -  INRAP	Contrôle 2021 - Services dédiés à la recherche patrimoniale -  INRAP	2021-05-19 14:00:00	2021-05-19 15:00:00	\N	\N	2	0	\N	\N
561265	ETUDES	AUTRE	\N	\N	\N	Table ronde "Batteries électriques"	Table ronde "Batteries électriques"	2021-05-19 13:30:00	2021-05-19 15:00:00	\N	\N	14	0	\N	906
561567	MISSION	AUCUNE	\N	VIETUDIA	\N	Audition plénière	Table ronde Etudiants français à l'étranger	2021-05-19 13:30:00	2021-05-19 15:19:00	2021-05-19 17:05:44	2021-05-21 17:26:51	15	0	\N	\N
561724	MISSION	AUCUNE	\N	VIETUDIA	\N	Table ronde : "emploi étudiant, salariat, apprentissage	\N	2021-05-20 16:32:00	2021-05-20 17:52:00	\N	\N	4	0	\N	\N
563821	MISSION	AUCUNE	\N	VIETUDIA	\N	Mice: table ronde « Campus de demain » 	\N	2021-05-31 14:32:00	2021-05-31 16:37:00	2021-06-08 07:58:24	2021-06-08 12:01:07	10	0	\N	\N
563959	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPR Modification du Règlement du Sénat (examen des amendements de séance)	PPR Modification du Règlement du Sénat (examen des amendements de séance)	2021-06-01 14:00:00	2021-06-01 14:10:00	2021-06-01 14:25:18	2021-06-01 16:34:26	12	0	\N	\N
563961	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL 3DS - Audition de Guy Geoffroy, représentant de l'AMF	PJL 3DS - Audition de Guy Geoffroy, représentant de l'AMF	2021-06-02 10:15:00	2021-06-02 11:40:00	2021-06-02 14:39:17	2021-06-02 18:41:07	33	0	\N	\N
563962	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition PJL Climat - Fédération des entreprises d'insertion	Audition PJL Climat - Fédération des entreprises d'insertion	2021-05-20 17:15:00	2021-05-20 18:00:00	\N	\N	1	0	\N	\N
563967	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Nommer les enfants nés sans vie (rapport et texte de la commission)	PPL Nommer les enfants nés sans vie (rapport et texte de la commission)	2021-06-02 09:30:00	2021-06-02 10:05:00	2021-06-02 10:43:20	2021-06-02 18:41:02	26	0	\N	\N
564202	DELEGATION	AUCUNE	\N	\N	DSOM	Audition dans le cadre de l'étude sur le logement	\N	2021-06-01 16:00:00	2021-06-01 17:20:00	\N	\N	10	0	\N	\N
564250	COM_PERMANENTE	AUTRE	\N	CAE	\N	Examen avis PJL Climat	\N	2021-05-31 14:30:00	2021-05-31 19:50:00	2021-06-01 14:01:50	2021-06-01 16:34:27	27	0	\N	\N
564251	COM_PERMANENTE	AUTRE	\N	CAE	\N	Examen avis PJL Climat	\N	2021-06-01 09:05:00	2021-06-01 10:30:00	2021-06-02 16:29:18	2021-06-02 18:40:53	32	0	\N	\N
564252	COM_PERMANENTE	AUTRE	\N	CAE	\N	Examen avis PJL Climat	\N	2021-06-01 14:30:00	2021-06-01 19:00:00	2021-06-02 16:39:06	2021-06-02 18:40:57	31	0	\N	\N
564254	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de M. Bompard, PDG de Carrefour	\N	2021-06-02 09:30:00	2021-06-02 11:40:00	2021-06-02 16:29:41	2021-06-02 18:41:03	33	0	\N	\N
564255	COM_PERMANENTE	AUTRE	\N	CAE	\N	PPL "Améliorer l'économie du livre"	\N	2021-06-02 08:35:00	2021-06-02 09:20:00	2021-06-02 16:31:02	2021-06-02 18:40:59	26	0	\N	\N
564262	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Protection sociale globale - Audition de la DGCS	\N	2021-05-27 14:30:00	2021-05-27 15:30:00	\N	\N	1	0	\N	\N
564263	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Protection sociale globale - Audition Secours catholique-Caritas France	\N	2021-05-27 15:30:00	2021-05-27 16:05:00	\N	\N	1	0	\N	\N
564264	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Protection sociale globale - Audition CNSA	\N	2021-05-27 17:30:00	2021-05-27 18:45:00	\N	\N	1	0	\N	\N
564266	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Soins palliatifs - Table ronde d'organisations de médecins et d'infirmiers libéraux	\N	2021-05-25 17:00:00	2021-05-25 18:30:00	\N	\N	6	0	\N	\N
564305	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Mineurs non accompagnés - Audition de l'ADF	\N	2021-05-25 15:30:00	2021-05-25 16:50:00	\N	\N	5	0	\N	\N
573173	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Différenciation, décentralisation, déconcentration et simplification - Audition DGTIM	PJL Différenciation, décentralisation, déconcentration et simplification - Audition DGTIM	2021-06-15 15:30:00	2021-06-15 16:15:00	\N	\N	1	0	\N	\N
573175	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Différenciation, décentralisation, déconcentration et simplification - Audition AGIFI	PJL Différenciation, décentralisation, déconcentration et simplification - Audition AGIFI	2021-06-15 16:15:00	2021-06-15 17:00:00	\N	\N	1	0	\N	\N
573177	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Différenciation, décentralisation, déconcentration et simplification - Audition DGOS	PJL Différenciation, décentralisation, déconcentration et simplification - Audition DGOS	2021-06-16 14:00:00	2021-06-16 14:45:00	\N	\N	1	0	\N	\N
573179	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Différenciation, décentralisation, déconcentration et simplification - Audition VNF	PJL Différenciation, décentralisation, déconcentration et simplification - Audition VNF	2021-06-17 16:00:00	2021-06-17 16:45:00	\N	\N	1	0	\N	\N
573181	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Différenciation, décentralisation, déconcentration et simplification - Audition SNCF	PJL Différenciation, décentralisation, déconcentration et simplification - Audition SNCF	2021-06-17 16:45:00	2021-06-17 17:30:00	\N	\N	1	0	\N	\N
573324	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Climat	PJL Climat	2021-06-28 15:00:00	2021-06-28 19:40:00	\N	\N	58	0	\N	\N
573326	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Climat - EV	PJL Climat - EV	2021-06-29 14:30:00	2021-06-29 15:45:00	\N	\N	167	0	\N	\N
573327	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Terrorisme et renseignement	PJL Terrorisme et renseignement	2021-06-29 16:00:00	2021-06-29 20:05:00	\N	\N	91	0	\N	\N
573329	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2021-06-30 15:00:00	2021-06-30 16:20:00	\N	\N	182	0	\N	\N
573334	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFR 2021	PLFR 2021	2021-07-01 10:30:00	2021-07-01 13:00:00	\N	\N	55	0	\N	\N
573335	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFR 2021	PLFR 2021	2021-07-01 14:30:00	2021-07-01 20:45:00	\N	\N	55	0	\N	\N
573339	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition M. Dominik Stillhart (CICR)	\N	2021-06-30 09:30:00	2021-06-30 10:30:00	2021-07-01 12:04:48	2021-07-01 17:47:43	23	0	\N	\N
573340	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de membres du gvt et du parlement birman en exil	\N	2021-06-30 10:49:00	2021-06-30 12:00:00	2021-07-01 12:05:17	2021-07-01 17:47:42	17	0	\N	\N
573348	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLO Confiance dans l'institution judiciaire	\N	2021-06-24 14:00:00	2021-06-24 15:00:00	\N	\N	3	0	\N	\N
573352	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Confiance dans l'institution judiciaire	\N	2021-06-24 15:00:00	2021-06-24 18:25:00	\N	\N	4	0	\N	\N
573357	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLO Confiance dans l'institution judiciaire	\N	2021-06-24 17:25:00	2021-06-24 20:00:00	\N	\N	2	0	\N	\N
573360	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2021-06-23 17:00:00	2021-06-23 19:30:00	\N	\N	2	0	\N	\N
573363	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2021-06-24 09:00:00	2021-06-24 10:45:00	\N	\N	4	0	\N	\N
573541	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFR 2021	Projet de loi de finances rectificative pour 2021	2021-06-30 21:00:00	2021-07-01 00:35:00	\N	\N	59	0	\N	\N
574352	ETUDES	AUCUNE	\N	\N	\N	Audition cycle Santé II	Audition cycle Santé II	2021-06-30 08:30:00	2021-06-30 09:30:00	\N	\N	3	0	\N	998
574378	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition Mme angrand Service civique	\N	2021-06-30 09:35:00	2021-06-30 11:00:00	2021-07-02 10:19:45	2021-07-02 16:04:15	24	0	\N	\N
574433	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 8 juillet 2021	Réunion du 8 juillet 2021	2021-07-08 08:30:00	2021-07-08 11:05:00	2021-07-08 13:17:38	2021-07-08 16:19:38	17	0	\N	\N
574628	MISSION	AUDRAP	\N	UBER	\N	MI Ubérisation	\N	2021-06-28 14:00:00	2021-06-28 16:00:00	\N	\N	2	0	\N	\N
574632	MISSION	AUDRAP	\N	UBER	\N	MI Ubérisation	\N	2021-06-30 14:00:00	2021-06-30 15:00:00	\N	\N	4	0	\N	\N
574645	MISSION	AUCUNE	\N	EGALCHAN	\N	Réunion plénière MI égalité des chances	\N	2021-06-30 16:41:00	2021-06-30 17:44:00	2021-06-30 17:51:37	2021-06-30 18:43:47	6	0	\N	\N
574851	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	Réunion plénière	2021-07-07 09:30:00	2021-07-07 11:20:00	2021-07-08 16:16:02	2021-07-08 16:16:06	39	0	\N	\N
574852	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition plénière	\N	2021-07-06 13:30:00	2021-07-06 14:20:00	2021-07-06 15:00:28	2021-07-06 18:19:43	16	0	\N	\N
574853	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2021-07-05 14:30:00	2021-07-05 15:25:00	2021-07-05 15:34:37	2021-07-05 17:25:31	13	0	\N	\N
575244	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Examen de deux conventions et de deux rapports d'information	Examen de deux conventions et de deux rapports d'information	2021-07-07 09:30:00	2021-07-07 12:05:00	\N	2021-07-12 14:58:17	34	5	\N	\N
575245	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de M. Jean-Yves Le Drian	Audition de M. Jean-Yves Le Drian	2021-07-07 16:37:00	2021-07-07 18:07:00	2021-07-12 17:39:56	2021-07-12 18:18:46	38	0	\N	\N
575328	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	DSOM	Conférence de presse "Logement dans les outre-mer"	Conférence de presse "Logement dans les outre-mer"	2021-07-01 16:30:00	2021-07-01 17:45:00	\N	\N	4	0	\N	\N
575375	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	Groupe d'études Statut rôle et place des Français établis hors de France	Table ronde sur « La retraite des Français expatriés »	2021-06-30 13:30:00	2021-06-30 15:30:00	\N	\N	6	0	\N	\N
575412	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	Groupe d'études Statut rôle et place des Français établis hors de France	Table ronde sur « La retraite des Français expatriés »	2021-06-30 13:30:00	2021-06-30 15:30:00	\N	\N	6	0	\N	\N
575493	GIA	AUCUNE	\N	\N	\N	Table ronde sur la préservation du patrimoine au Moyen-Orient	Table ronde sur la préservation du patrimoine au Moyen-Orient	2021-06-30 17:30:00	2021-06-30 20:00:00	\N	\N	12	0	CHRETORIENT	CHRETORIENT
575506	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Association des DRAC de France	\N	2021-07-05 11:00:00	2021-07-05 12:00:00	\N	\N	4	0	\N	\N
575533	MISSION	AUCUNE	\N	CONF	\N	Réunion plénière - adoption de rapport	\N	2021-07-05 14:37:00	2021-07-05 15:07:00	2021-07-05 16:19:10	2021-07-05 17:25:39	6	0	\N	\N
575544	MISSION	AUCUNE	\N	INFLUENCES	\N	Réunion constitutive	\N	2021-07-06 15:00:00	2021-07-06 15:30:00	2021-07-07 11:51:23	2021-07-07 17:53:08	14	0	\N	\N
575594	MISSION	AUTRE	\N	HARCEL	\N	Audition plénière	\N	2021-07-07 12:30:00	2021-07-07 14:15:00	\N	\N	0	0	\N	\N
575595	MISSION	AUTRE	\N	HARCEL	\N	Audition plénière	\N	2021-07-07 16:30:00	2021-07-07 18:00:00	\N	\N	0	0	\N	\N
576879	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Volontariat des sapeurs-pompiers	Audition rapporteur - PPL volontariat des sapeurs-pompiers	2021-07-05 10:30:00	2021-07-05 11:15:00	\N	\N	3	0	\N	\N
576885	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Volontariat des sapeurs-pompiers	Audition rapporteur - PPL volontariat des sapeurs-pompiers	2021-07-05 14:00:00	2021-07-05 15:00:00	\N	\N	3	0	\N	\N
576891	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Volontariat des sapeurs-pompiers	Audition rapporteur - PPL volontariat des sapeurs-pompiers	2021-07-06 14:30:00	2021-07-06 16:00:00	\N	\N	4	0	\N	\N
576896	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Volontariat des sapeurs-pompiers	Audition rapporteur - PPL volontariat des sapeurs-pompiers	2021-07-07 11:00:00	2021-07-07 13:30:00	\N	\N	3	0	\N	\N
576968	MISSION	AUCUNE	\N	HARCEL	\N	Mission harcèlement	Mission harcèlement scolaire	2021-07-07 16:35:00	2021-07-07 17:42:00	2021-07-07 18:32:02	2021-07-08 16:20:56	14	0	\N	\N
512647	GIA	AUCUNE	\N	\N	\N	Assemblée générale de renouvellement 2020 - 2023	AG 2 décembre 2020	2020-12-02 15:00:00	2020-12-02 15:45:00	\N	\N	21	0	602	\N
522714	MISSION	AUCUNE	\N	CONF	\N	Réunion constitutive	\N	2021-01-26 15:05:00	2021-01-26 15:30:00	2021-01-27 16:30:49	2021-01-28 18:29:03	14	0	\N	\N
524287	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2021-01-21 09:00:00	2021-01-21 10:50:00	\N	\N	3	0	\N	\N
527931	GIA	AUCUNE	\N	\N	\N	Assemblée générale 2021	Assemblée générale 2021	2021-02-03 14:30:00	2021-02-03 15:00:00	\N	\N	14	0	979	\N
534250	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur - Commission des affaires sociales - PPL Lutter contre les fraudes soc	Audition rapporteur - Commission des affaires sociales - PPL Lutter contre les fraudes sociales	2021-02-23 11:00:00	2021-02-23 12:15:00	\N	\N	1	0	\N	\N
534268	MISSION	AUCUNE	\N	EGALCHAN	\N	Réunion plénière MI Jeunes	\N	2021-03-03 17:00:00	2021-03-03 18:41:00	2021-03-18 09:31:45	2021-03-18 17:11:23	11	0	\N	\N
534269	MISSION	AUCUNE	\N	EGALCHAN	\N	Réunion plénière MI Jeunes	\N	2021-03-04 10:34:00	2021-03-04 11:58:00	2021-03-04 14:27:20	2021-03-04 17:59:30	9	0	\N	\N
545724	GIA	AUCUNE	\N	\N	\N	Audition de l'ambassadeur de France à Dublin	Audition de M. Vincent Guérend, ambassdeur de France en Irlande	2021-03-30 09:30:00	2021-03-30 10:30:00	\N	\N	8	0	594	\N
552769	GIA	AUCUNE	\N	\N	\N	Audition de M. Christophe Bigot  et Omar El Kachtoul (DAOI - MEAE)	Audition de M. Christophe Bigot et Omar El Kachtoul, sous-directeur de l'Afrique centrale, du MEAE   	2021-04-14 13:15:00	2021-04-14 14:25:00	\N	\N	8	0	572	\N
552846	GIA	AUCUNE	\N	\N	\N	Audition de SE M. Eusèbe Agbangla, ambassadeur du Bénin en France	Audition de SE M. Eusèbe Agbangla, ambassadeur du Bénin en France	2021-04-14 14:00:00	2021-04-14 14:55:00	\N	\N	7	0	573	\N
553311	ETUDES	AUCUNE	\N	\N	\N	Réunion du bureau	Réunion du bureau	2021-04-13 16:00:00	2021-04-13 16:30:00	\N	\N	3	0	\N	998
558324	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Olivier Brochenin, ambassadeur de France en Guinée équatoriale	Merci de rajouter  :  Jeudi 6 mai, 15 heures  GIA France - Afrique centrale  - Entretien avec M. Olivier Broche	2021-05-11 10:50:00	2021-05-11 11:30:00	\N	\N	1	0	572	\N
558557	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Suivi des condamnés terroristes sortant de détention	PPL Suivi des condamnés terroristes sortant de détention	2021-05-05 15:45:00	2021-05-05 16:45:00	\N	\N	2	0	\N	\N
558562	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Suivi des condamnés terroristes sortant de détention	PPL Suivi des condamnés terroristes sortant de détention	2021-05-05 16:45:00	2021-05-05 18:30:00	\N	\N	1	0	\N	\N
561762	COM_PERMANENTE	AUTRE	\N	FINC	\N	Projet de loi de règlement de 2020 : Audition de M. Jean-Baptiste DJEBBARI	Projet de loi de règlement de 2020 : Audition de M. Jean-Baptiste DJEBBARI	2021-05-25 16:35:00	2021-05-25 17:45:00	2021-05-25 18:14:31	2021-05-26 17:31:20	29	0	\N	\N
561763	COM_PERMANENTE	AUTRE	\N	FINC	\N	Contrôles budgétaires Hébergement d'urgence et financement lutte Algues verte	Contrôles budgétaires Hébergement d'urgence et financement lutte Algues verte	2021-05-26 10:00:00	2021-05-26 11:40:00	2021-05-26 12:04:45	2021-05-26 17:31:16	33	0	\N	\N
561764	COM_PERMANENTE	AUTRE	\N	FINC	\N	Projet de loi de règlement de 2020 : Audition de Mme Barbara POMPILI	Projet de loi de règlement de 2020 : Audition de Mme Barbara POMPILI	2021-05-26 18:00:00	2021-05-26 19:15:00	2021-05-26 19:35:45	2021-05-27 17:04:48	25	0	\N	\N
561765	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Volet ZAN PJL Climat	Auditions Volet ZAN PJL Climat	2021-05-19 10:30:00	2021-05-19 13:00:00	\N	\N	1	0	\N	\N
561875	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes	\N	2021-05-27 09:15:00	2021-05-27 11:00:00	2021-05-27 10:03:37	2021-05-27 17:04:45	15	0	\N	\N
561876	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes	\N	2021-05-27 10:00:00	2021-05-27 11:15:00	2021-05-28 15:21:29	2021-05-28 16:32:34	13	0	\N	\N
561883	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Dérèglement Climatique et résilience - France Nature Environnement	PJL Dérèglement Climatique et résilience - France Nature Environnement	2021-05-19 13:00:00	2021-05-19 13:40:00	\N	\N	1	0	\N	\N
561886	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - IHU - ANR	Contrôle 2021 - IHU - ANR	2021-05-18 12:00:00	2021-05-18 13:00:00	\N	\N	2	0	\N	\N
561887	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - IHU - ex-délégué ministériel innovation	Contrôle 2021 - IHU - ex-délégué ministériel innovation	2021-05-18 14:00:00	2021-05-18 15:00:00	\N	\N	2	0	\N	\N
561977	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Améliorer la lisibilité du droit (2) (législation en commission) (rapport)	PPL Améliorer la lisibilité du droit (2) (législation en commission) (rapport)	2021-05-25 09:00:00	2021-05-25 09:40:00	2021-05-25 09:55:58	2021-05-25 16:15:14	18	0	\N	\N
561978	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Suivi des terroristes sortant de détention - PPL Irresponsabilité pénale (amendements)	PPL Suivi des condamnés terroristes sortant de détention - PPL Irresponsabilité pénale (amendements)	2021-05-25 14:00:00	2021-05-25 14:30:00	2021-05-25 14:40:41	2021-05-25 16:15:14	17	0	\N	\N
561979	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPR Modification Règlement du Sénat (rapport) - PJL Lutte dérèglement climat. (avis)	PPR Modification du Règlement du Sénat (rapport) - PJL Lutte contre le dérèglement climatique (avis)	2021-05-26 09:00:00	2021-05-26 11:45:00	2021-05-26 14:20:51	2021-05-26 17:31:20	33	0	\N	\N
561980	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audtion d'Amélie de Montchalin, ministre de la transformation et de la fonction publiques	Audtion d'Amélie de Montchalin, ministre de la transformation et de la fonction publiques	2021-05-26 17:05:00	2021-05-26 18:40:00	2021-05-26 19:04:30	2021-05-27 17:04:49	17	0	\N	\N
561981	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Accès des jeunes dans la fonction publique et les entreprises (amendements)	PPL Accès des jeunes dans la fonction publique et les entreprises (amendements)	2021-05-27 10:00:00	2021-05-27 10:05:00	2021-05-27 10:22:49	2021-05-27 17:04:47	8	0	\N	\N
562022	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition Bpifrance	\N	2021-05-27 14:30:00	2021-05-27 15:30:00	\N	\N	0	0	\N	\N
562025	COM_PERMANENTE	AUTRE	\N	CAE	\N	Amendements PPL "Bien-être animal"	\N	2021-05-26 09:45:00	2021-05-26 10:15:00	2021-05-27 11:21:18	2021-05-27 17:04:50	31	0	\N	\N
562038	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PPL Maltraitance	\N	2021-05-18 14:30:00	2021-05-18 15:30:00	\N	\N	1	0	\N	\N
562046	ETUDES	AUTRE	\N	\N	\N	GEAC - Audition de M. Éric TRAPPIER, président du GIFAS	GEAC - Audition de M. Éric TRAPPIER, président du GIFAS	2021-06-02 08:00:00	2021-06-02 09:10:00	\N	\N	14	0	\N	933
562047	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition PJL Climat : Shift Project	Audition PJL Climat : Shift Project	2021-05-19 14:00:00	2021-05-19 15:00:00	\N	\N	4	0	\N	\N
562052	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition PJL Climat - Biocoop	Audition PJL Climat - Biocoop	2021-05-19 17:15:00	2021-05-19 18:00:00	\N	\N	2	0	\N	\N
562055	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition de M. Jean-Yves Froin	\N	2021-05-03 16:00:00	2021-05-03 17:30:00	\N	\N	3	0	\N	\N
562056	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition PJL Climat - I4CE	Audition PJL Climat - I4CE	2021-05-18 08:30:00	2021-05-18 09:15:00	\N	\N	3	0	\N	\N
562057	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition CybelAngel	\N	2021-05-06 14:30:00	2021-05-06 15:30:00	\N	\N	2	0	\N	\N
562058	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition Thales	\N	2021-05-06 15:45:00	2021-05-06 16:45:00	\N	\N	2	0	\N	\N
562062	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Cybersécurité	\N	2021-05-20 14:30:00	2021-05-20 16:45:00	\N	\N	0	0	\N	\N
562063	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Cybersécurité	\N	2021-05-20 14:30:00	2021-05-20 16:45:00	\N	\N	0	0	\N	\N
562064	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Cybersécurité	\N	2021-05-20 14:30:00	2021-05-20 16:45:00	\N	\N	0	0	\N	\N
562065	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Cybersécurité	\N	2021-05-20 14:30:00	2021-05-20 16:45:00	\N	\N	0	0	\N	\N
562070	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions PJL Climat - CGDD et DGCL	\N	2021-05-18 17:00:00	2021-05-18 19:00:00	\N	\N	2	0	\N	\N
562073	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Dérèglement Climatique et résilience - UNIFA	PJL Dérèglement Climatique et résilience - UNIFA	2021-05-19 14:00:00	2021-05-19 14:30:00	\N	\N	1	0	\N	\N
562110	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Accords de Bâle - Déplacement Banque de France	Accords de Bâle - Déplacement Banque de France	2021-05-18 16:30:00	2021-05-18 18:30:00	\N	\N	2	0	\N	\N
562116	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Missions locales - Monde académique/UNML	Contrôle 2021 - Missions locales - Monde académique/UNML	2021-05-17 14:00:00	2021-05-17 16:00:00	\N	\N	2	0	\N	\N
562120	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - FPIC - OFGL	Contrôle 2021 - FPIC - OFGL	2021-05-20 10:30:00	2021-05-20 11:30:00	\N	\N	2	0	\N	\N
583498	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL rémunération des agriculteurs	PPL rémunération des agriculteurs	2021-09-22 16:35:00	2021-09-22 19:45:00	\N	\N	116	0	\N	\N
583499	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL valoriser le volontariat des sapeurs-pompiers	PPL valoriser le volontariat des sapeurs-pompiers	2021-09-22 21:30:00	2021-09-23 00:30:00	\N	\N	70	0	\N	\N
583500	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL valoriser le volontariat des sapeurs-pompiers	PPL valoriser le volontariat des sapeurs-pompiers	2021-09-23 10:30:00	2021-09-23 13:00:00	\N	\N	66	0	\N	\N
583506	GIA	AUCUNE	\N	\N	\N	Déjeuner de travail avec M. Graham Paul, ambassadeur de France en République de Moldavie	Déjeuner de travail avec M. Graham Paul, ambassadeur de France en République de Moldavie	2021-09-15 12:45:00	2021-09-15 14:00:00	\N	\N	1	0	851	\N
583508	GIA	AUCUNE	\N	\N	\N	Entretien en visioconférence avec M. Pascal LE DEUNFF, Ambassadeur de France en Moldavie 	\N	2021-07-21 14:00:00	2021-07-21 15:00:00	\N	\N	1	0	851	\N
583585	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Les contributions internationales	Contrôle 2021 - Les contributions internationales	2021-09-14 14:00:00	2021-09-14 15:00:00	\N	\N	2	0	\N	\N
583588	MISSION	DEPLACEMENT	\N	METHANIS	\N	Déplacement à Nancy	Déplacement à Nancy	2021-09-06 08:00:00	2021-09-06 19:00:00	\N	\N	2	0	\N	\N
583589	MISSION	AUDRAP	\N	METHANIS	\N	Visite de la station d'épuration de la Métropole du Grand Nancy	Visite de la station d'épuration de la Métropole du Grand Nancy	2021-09-06 10:00:00	2021-09-06 11:00:00	\N	\N	2	0	\N	\N
583594	MISSION	AUDRAP	\N	METHANIS	\N	Déjeuner de travail	Déjeuner de travail	2021-09-06 12:00:00	2021-09-06 14:00:00	\N	\N	2	0	\N	\N
583597	MISSION	AUDRAP	\N	METHANIS	\N	Visite de l'ENSAIA et de la ferme de la Bouzule	Visite de l'ENSAIA et de la ferme de la Bouzule	2021-09-06 15:00:00	2021-09-06 17:00:00	\N	\N	2	0	\N	\N
583600	MISSION	AUCUNE	\N	METHANIS	\N	Visite de l'unité de méthanisation des frères Quaak à Chaumes-en Brie	\N	2021-06-11 10:00:00	2021-06-11 16:00:00	\N	\N	0	0	\N	\N
583601	MISSION	AUDRAP	\N	METHANIS	\N	Visite de l'unité de méthanisation de Chaumes-en-Brie	Visite de l'unité de méthanisation de Chaumes-en-Brie	2021-06-11 10:00:00	2021-06-11 16:00:00	\N	\N	1	0	\N	\N
583603	MISSION	AUDRAP	\N	METHANIS	\N	Visite de la ferme du P'tit Gallo 	Visite de la ferme du P'tit Gallo 	2021-06-14 14:30:00	2021-06-14 16:30:00	\N	\N	1	0	\N	\N
583604	MISSION	AUDRAP	\N	METHANIS	\N	Visite de la Centrale Biogaz de l'Aumaillerie	Visite de la Centrale Biogaz de l'Aumaillerie	2021-06-14 10:00:00	2021-06-14 12:00:00	\N	\N	1	0	\N	\N
583607	DELEGATION	AUCUNE	\N	\N	211	1. Désignation des lauréats du Prix 2021 de la DDF 2. Adoption du programme 2021-2022	1. Désignation des lauréats du Prix 2021 de la DDF 2. Adoption du programme 2021-2022	2021-10-07 08:30:00	2021-10-07 10:00:00	\N	\N	12	0	\N	\N
583608	DELEGATION	AUCUNE	\N	\N	COLTER	Audition sur les services préfectoraux	\N	2021-10-06 17:00:00	2021-10-06 18:30:00	\N	\N	16	0	\N	\N
583609	DELEGATION	AUDRAP	\N	\N	COLTER	Audition de M. SCHENFEIGEL	\N	2021-10-05 17:00:00	2021-10-05 17:45:00	\N	\N	0	0	\N	\N
583610	GIA	AUCUNE	\N	\N	\N	Fête nationale à l'Ambassade	\N	2021-09-15 18:30:00	2021-09-15 20:00:00	\N	\N	1	0	626	\N
583613	DELEGATION	AUDRAP	\N	\N	COLTER	Table ronde sur les services déconcentrés et préfectoraux	\N	2021-10-05 15:00:00	2021-10-05 16:30:00	\N	\N	0	0	\N	\N
583833	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Réforme de l'adoption	\N	2021-09-21 11:00:00	2021-09-21 12:00:00	\N	\N	1	0	\N	\N
583836	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Réforme de l'adoption	\N	2021-09-21 14:35:00	2021-09-21 15:50:00	\N	\N	2	0	\N	\N
585723	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Intégration des jeunes majeurs étrangers	Audition rapporteur - PPL Intégration des jeunes majeurs étrangers	2021-09-22 16:00:00	2021-09-22 16:30:00	\N	\N	1	0	\N	\N
585725	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Réforme de l'adoption	\N	2021-09-23 14:30:00	2021-09-23 16:00:00	\N	\N	2	0	\N	\N
585728	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	\N	2021-09-23 16:00:00	2021-09-23 16:45:00	\N	\N	1	0	\N	\N
586019	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Table ronde avec les acteurs des colonies de vacances et centres de loisirs	\N	2021-09-27 14:30:00	2021-09-27 16:00:00	\N	\N	1	0	\N	\N
589457	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Réforme de l'adoption	\N	2021-10-05 20:30:00	2021-10-05 21:15:00	\N	\N	2	0	\N	\N
601187	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2022 - Avis "Relations avec les collectivités territoriales"	PLF pour 2022 - Avis "Relations avec les collectivités territoriales"	2021-11-02 09:00:00	2021-11-02 11:00:00	\N	\N	1	0	\N	\N
601189	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2022 - Avis "Relations avec les collectivités territoriales"	PLF pour 2022 - Avis "Relations avec les collectivités territoriales"	2021-11-04 08:15:00	2021-11-04 10:30:00	\N	\N	1	0	\N	\N
601193	GIA	AUCUNE	\N	\N	\N	Petit-déjeuner en l'honneur du groupe d'amitié Vietnam-France	\N	2021-11-04 08:00:00	2021-11-04 09:00:00	\N	\N	3	0	626	\N
601198	GIA	AUCUNE	\N	\N	\N	Audience à la présidence du Premier ministre vietnamien	\N	2021-11-03 17:30:00	2021-11-03 18:30:00	\N	\N	1	0	626	\N
601200	GIA	AUCUNE	\N	\N	\N	Visioconférence avec le directeur de l'AFD à Hanoi	\N	2021-10-29 10:00:00	2021-10-29 11:00:00	\N	\N	1	0	626	\N
601202	GIA	AUCUNE	\N	\N	\N	Interview avec les journalistes de la presse vietnamienne	\N	2021-10-28 09:00:00	2021-10-28 09:30:00	\N	\N	1	0	626	\N
601204	GIA	AUCUNE	\N	\N	\N	Entretien avec Mme le Pr. Bach-Nga Pham	\N	2021-10-19 10:30:00	2021-10-19 11:30:00	\N	\N	2	0	626	\N
601207	GIA	AUCUNE	\N	\N	\N	Petit-déjeuner avec l'ambassadeur du Vietnam	\N	2021-10-07 08:30:00	2021-10-07 09:30:00	\N	\N	7	0	626	\N
601215	GIA	AUCUNE	\N	\N	\N	Fête nationale du Vietnam à l'ambassade du Vietnam	\N	2021-09-15 18:30:00	2021-09-15 19:30:00	\N	\N	2	0	626	\N
603177	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2022 - Programme 212	PLF pour 2022 - Programme 212	2021-11-09 16:30:00	2021-11-09 19:00:00	\N	\N	1	0	\N	\N
603180	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2022 - Programme 212	PLF pour 2022 - Programme 212	2021-11-10 16:45:00	2021-11-10 18:00:00	\N	\N	1	0	\N	\N
606223	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2022 - Avis "Protection judiciaire de la jeunesse"	\N	2021-11-16 16:15:00	2021-11-16 17:00:00	\N	\N	1	0	\N	\N
613305	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2021-12-14 09:35:00	2021-12-14 12:40:00	\N	\N	46	0	\N	\N
613306	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Nouvelle lecture PLF pour 2022	Nouvelle lecture PLF pour 2022	2021-12-14 14:30:00	2021-12-14 15:35:00	\N	\N	124	0	\N	\N
613307	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Protection des enfants	PJL Protection des enfants	2021-12-14 15:40:00	2021-12-14 20:00:00	\N	\N	118	0	\N	\N
613310	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Protection des enfants	PJL Protection des enfants	2021-12-14 21:30:00	2021-12-15 00:30:00	\N	\N	55	0	\N	\N
613311	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2021-12-15 15:00:00	2021-12-15 16:15:00	\N	\N	284	0	\N	\N
601186	COM_PERMANENTE	AUTRE	\N	AFCL	\N	PJLF 2022 - Avis Enseignement scolaire, Enseignement technique agricole, Presse	PJLFF 2022 - Avis Enseignement scolaire, Enseignement technique agricole, Presse	2021-11-10 09:00:00	2021-11-10 11:25:00	2021-11-12 08:58:07	2021-11-12 19:00:42	42	2	\N	\N
613312	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Protection des enfants	PJL Protection des enfants	2021-12-15 16:30:00	2021-12-15 19:55:00	\N	\N	75	0	\N	\N
613313	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Protection des enfants	PJL Protection des enfants	2021-12-15 21:30:00	2021-12-16 01:10:00	\N	\N	40	0	\N	\N
613314	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	EV Économie du livre	EV Économie du livre	2021-12-16 10:30:00	2021-12-16 11:25:00	\N	\N	30	0	\N	\N
613315	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	EV Bibliothèques et lecture publique	EV Bibliothèques et lecture publique	2021-12-16 11:25:00	2021-12-16 12:15:00	\N	\N	32	0	\N	\N
613316	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Egalité économique et professionnelle	CMP Egalité économique et professionnelle	2021-12-16 12:30:00	2021-12-16 13:20:00	\N	\N	22	0	\N	\N
613318	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP catastrophes naturelles	CMP catastrophes naturelles	2021-12-16 14:50:00	2021-12-16 15:45:00	\N	\N	19	0	\N	\N
613319	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Responsabilité pénale	CMP Responsabilité pénale	2021-12-16 15:45:00	2021-12-16 16:40:00	\N	\N	21	0	\N	\N
509543	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2021 - Programme 178	\N	2020-11-27 14:30:00	2020-11-27 15:30:00	\N	\N	2	0	\N	\N
514118	GIA	AUCUNE	\N	\N	\N	Assemblée générale 	Assemblée générale du GIA France-Pays du Cône Sud	2020-12-08 09:00:00	2020-12-08 09:30:00	\N	\N	8	0	978	\N
515440	DELEGATION	AUCUNE	\N	\N	206	Audition publique des URPS	Audition publique des Unions régionales des professionnels de santé 	2020-12-09 16:05:00	2020-12-09 17:30:00	\N	\N	5	0	\N	\N
517788	GIA	AUCUNE	\N	\N	\N	Réunion constitutive 	\N	2020-12-16 12:05:00	2020-12-16 12:25:00	\N	\N	8	0	633	\N
519131	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	PJL Code de la justice pénale des mineurs - Déplacement au tribunal judiciaire d'Evry	PJL Code de la justice pénale des mineurs - Déplacement au tribunal judiciaire d'Evry	2021-01-06 08:00:00	2021-01-06 13:00:00	\N	\N	3	0	\N	\N
531690	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Service public d'eau potable et d'assainissement en Guadeloupe	PPL Service public d'eau potable et d'assainissement en Guadeloupe	2021-02-11 14:30:00	2021-02-11 16:30:00	\N	\N	1	0	\N	\N
534231	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Transport de marchandises - FNE/The Shift Project	MI Transport de marchandises - France Nature Environnement/The Shift Project	2021-02-16 14:30:00	2021-02-16 15:30:00	\N	\N	9	0	\N	\N
534241	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Transport de marchandises - IDDRI	MI Transport de marchandises - IDDRI	2021-02-16 15:30:00	2021-02-16 16:20:00	\N	\N	8	0	\N	\N
542774	GIA	AUCUNE	\N	\N	\N	Réunion du GIA France-Syrie	Réunion du GIA France-Syrie	2021-03-18 09:00:00	2021-03-18 10:30:00	\N	\N	5	0	644	\N
542797	GIA	AUCUNE	\N	\N	\N	Réunion du groupe conjointe avec le groupe de l'Assemblée nationale	\N	2021-03-17 14:00:00	2021-03-17 15:00:00	\N	\N	3	0	628	\N
547406	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat 50-1 Evolution covid	Débat 50-1 Evolution de la situation sanitaire	2021-04-01 15:00:00	2021-04-01 17:25:00	\N	\N	164	0	\N	\N
548265	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière - Conclusions AP Recherche polaire - Audition ASN	Réunion plénière - Conclusions AP Recherche polaire - Audition ASN	2021-05-27 08:40:00	2021-05-27 12:25:00	\N	\N	13	0	\N	\N
555326	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Dérèglement climatique et résilience - Auditions de M. Pascal Martin	PJL Dérèglement climatique et résilience - Auditions de M. Pascal Martin	2021-04-27 18:45:00	2021-04-27 19:35:00	\N	\N	1	0	\N	\N
555339	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Dérèglement climatique et résilience - Auditions de M. Pascal Martin	PJL Dérèglement climatique et résilience - Auditions de M. Pascal Martin	2021-04-28 09:00:00	2021-04-28 09:50:00	\N	\N	1	0	\N	\N
555341	COM_PERMANENTE	AUTRE	\N	FINC	\N	PJL 404 : Examen projets Amdts-Désignation Rapporteur PPL 531 et Audition Benoît COEURÉ	PJL 404 : Examen projets Amdts-Désignation Rapporteur PPL 531 et Audition Benoît COEURÉ sur le soutien aux entreprises	2021-05-04 14:50:00	2021-05-04 16:25:00	2021-05-04 16:55:08	2021-05-06 17:43:08	30	0	\N	\N
555342	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition Pascal SAINT-AMANS sur BEPS - Communications RG:PNRR et PDT:Application des lois	Audition Pascal SAINT-AMANS sur BEPS - Communications RG:PNRR et PDT:Application des lois	2021-05-05 09:35:00	2021-05-05 12:00:00	2021-05-05 15:51:53	2021-05-06 17:43:03	40	0	\N	\N
555344	MISSION	AUCUNE	\N	VIETUDIA	\N	Echange de vues travaux de la mission	\N	2021-05-06 11:07:00	2021-05-06 12:21:00	2021-05-06 13:17:27	2021-05-06 17:43:48	13	0	\N	\N
555345	MISSION	AUCUNE	\N	VIETUDIA	\N	¿\tTable ronde « Crise sanitaire et Aide alimentaire pour les étudiants »	\N	2021-05-06 14:38:00	2021-05-06 16:20:00	2021-05-06 18:01:23	2021-05-07 14:25:18	11	0	\N	\N
555346	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Dérèglement climatique et résilience - Auditions de M. Pascal Martin	PJL Dérèglement climatique et résilience - Auditions de M. Pascal Martin	2021-04-28 11:30:00	2021-04-28 12:15:00	\N	\N	1	0	\N	\N
555353	MISSION	AUCUNE	\N	EGALCHAN	\N	Réunion plénière	\N	2021-05-04 16:02:00	2021-05-04 17:14:00	2021-05-10 09:32:56	\N	6	0	\N	\N
555354	COM_PERMANENTE	AUTRE	\N	CAE	\N	Application des lois et audition DG Tresor	\N	2021-05-05 09:35:00	2021-05-05 13:15:00	2021-05-06 11:25:02	2021-05-06 17:43:02	40	0	\N	\N
555398	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de M. Marc Baréty	Audition de M. Marc Baréty	2021-05-05 10:00:00	2021-05-05 11:45:00	2021-05-05 16:33:36	2021-05-06 17:43:01	33	0	\N	\N
557980	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Olivier Brochenin, ambassadeur de France en Guinée équatoriale	Entretien à distance avec M. Olivier Brochenin, ambassadeur de France en Guinée équatoriale	2021-05-06 15:00:00	2021-05-06 16:05:00	\N	\N	2	0	572	\N
557983	ETUDES	AUCUNE	\N	\N	\N	Audition Sowine	Audition Sowine	2021-05-05 13:30:00	2021-05-05 14:30:00	\N	\N	23	0	\N	909
558971	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	gt	GT Drones militaires	2021-05-11 14:00:00	2021-05-11 17:45:00	\N	\N	2	0	\N	\N
560216	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Lutte contre le dérèglement climatique	\N	2021-05-17 16:00:00	2021-05-17 17:00:00	\N	\N	1	0	\N	\N
564057	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT Boussole stratégique	\N	2021-05-25 16:00:00	2021-05-25 17:30:00	\N	\N	2	0	\N	\N
564306	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Mineurs non accompagnés - Audition de la DPJJ	\N	2021-05-26 16:40:00	2021-05-26 17:40:00	\N	\N	4	0	\N	\N
566526	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Climat	PJL Climat	2021-06-14 16:00:00	2021-06-14 20:00:00	\N	\N	58	0	\N	\N
566527	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Climat	PJL Climat	2021-06-14 21:30:00	2021-06-15 00:35:00	\N	\N	61	0	\N	\N
566528	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Climat	PJL Climat	2021-06-15 14:30:00	2021-06-15 20:00:00	\N	\N	138	0	\N	\N
566529	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Climat	PJL Climat	2021-06-15 21:30:00	2021-06-16 00:20:00	\N	\N	98	0	\N	\N
566530	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Climat	PJL Climat	2021-06-16 16:35:00	2021-06-16 20:00:00	\N	\N	107	0	\N	\N
566531	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2021-06-16 15:00:00	2021-06-16 16:20:00	\N	\N	163	0	\N	\N
566534	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Climat	PJL Climat	2021-06-17 14:45:00	2021-06-17 20:00:00	\N	\N	87	0	\N	\N
566535	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Climat	PJL Climat	2021-06-17 21:30:00	2021-06-18 00:25:00	\N	\N	52	0	\N	\N
566536	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Climat	PJL Climat	2021-06-18 09:30:00	2021-06-18 13:00:00	\N	\N	51	0	\N	\N
566537	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Climat	PJL Climat	2021-06-18 14:30:00	2021-06-18 18:00:00	\N	\N	44	0	\N	\N
568549	GIA	AUCUNE	\N	\N	\N	entretien avec lMme Bolkvadze, Présidente de la commission culture du Parlement de Géorgie	Entretien avec Mme Elissa BOLKVADZE, Présidente de la commission des affiares culturelles du Parlement géorgien	2021-06-09 16:00:00	2021-06-09 17:30:00	\N	\N	2	0	534	\N
568552	GIA	AUCUNE	\N	\N	\N	Entretien avec le conseiller du ministre de l'Europe et des Affaires étrangères 	Entretien avec le conseiller du ministre de l'Europe et des Affaires étrangères	2021-06-09 11:00:00	2021-06-09 11:45:00	\N	\N	2	0	617	\N
568555	GIA	AUCUNE	\N	\N	\N	Entretien avec Mme Mandiola-Rau, Chargée d'Affiares de l'ambassade des Philippines	Entretien avec Mme Mandiola-Rau, Chargée d'affaires de l'ambassade des Philippines avec le conseiller politique	2021-06-10 12:30:00	2021-06-10 14:30:00	\N	\N	3	0	609	\N
568559	GIA	AUCUNE	\N	\N	\N	Audition de l'ONG Les Baroudeurs de l'Espoir (Laurent Clerc- Diane Takli)	AG suivie de l'audition de l'ONG Les Baroudeurs de l'Espoir	2021-06-02 13:15:00	2021-06-02 14:30:00	\N	\N	5	0	644	\N
570283	ETUDES	AUTRE	\N	\N	\N	GE Agriculture et alimentation - Section cultures traditionnelles et spécialisées	GE Agriculture et alimentation - Section cultures traditionnelles et spécialisées	2021-06-16 13:30:00	2021-06-16 15:00:00	\N	\N	12	0	\N	1005
570329	COM_PERMANENTE	AUTRE	\N	CAE	\N	Avis amendements PJL Climat	\N	2021-06-16 20:00:00	2021-06-16 20:05:00	2021-06-17 10:41:23	2021-06-17 12:32:18	14	0	\N	\N
570332	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2021-06-23 09:30:00	2021-06-23 12:40:00	2021-06-23 12:43:08	2021-06-24 18:15:19	35	0	\N	\N
576986	GIA	AUCUNE	\N	\N	\N	Entretien conseiller Pdt	Entretien avec M. Shirwan Waeli, conseiller du Président de la République d'Irak	2021-07-08 09:30:00	2021-07-08 10:15:00	\N	\N	1	0	615	\N
577921	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2021-07-08 09:30:00	2021-07-08 13:00:00	\N	\N	3	0	\N	\N
578721	MISSION	AUDRAP	\N	INFLUENCES	\N	Audition M. Balaudé président campus Condorcet	\N	2021-07-13 09:30:00	2021-07-13 10:32:00	\N	\N	1	0	\N	\N
578723	MISSION	AUCUNE	\N	UBER	\N	Audition commune MM. Stéphane Le Lay et Fabien Lemozy, IPT	\N	2021-07-13 14:00:00	2021-07-13 15:30:00	2021-07-13 15:29:41	2021-07-13 20:21:54	3	0	\N	\N
578724	GIA	AUCUNE	\N	\N	\N	GIA - Entretien avec Mme Nina GABRYS	GIA - Entretien avec Mme Nina GABRYS	2021-07-12 17:00:00	2021-07-12 18:30:00	\N	\N	1	0	600	\N
578747	DELEGATION	AUDRAP	\N	\N	211	Audition du groupe de travail de femmes élues de l'AMRF	Audition du groupe de travail de femmes élues de l'AMRF	2021-07-13 14:00:00	2021-07-13 15:15:00	\N	\N	4	0	\N	\N
578987	BUREAU	AUCUNE	\N	\N	\N	Bureau du Sénat	Bureau du Sénat	2021-07-13 13:30:00	2021-07-13 17:00:00	\N	\N	21	0	\N	\N
579095	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	COM AF	\N	2021-07-13 14:00:00	2021-07-13 15:00:00	\N	\N	1	0	\N	\N
579097	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	COM AFD	\N	2021-07-13 16:15:00	2021-07-13 17:15:00	\N	\N	1	0	\N	\N
579132	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désignations -  PJL Prévention d'actes de terrorisme et renseignement (NL) (rapport)	Désignations -  PJL Prévention d'actes de terrorisme et renseignement (NL) (rapport)	2021-07-20 09:05:00	2021-07-20 09:50:00	2021-07-20 10:43:42	2021-07-20 18:01:29	24	0	\N	\N
579135	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désignation - MI Dysfonctionnements élections juin 2021 - PPL Volontariat sapeurs-pompiers	Désignation - MI Dysfonctionnements élections juin 2021 - PPL Volontariat sapeurs-pompiers	2021-07-21 08:35:00	2021-07-21 11:05:00	2021-07-21 14:00:05	2021-07-21 15:54:21	30	0	\N	\N
579136	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Confiance dans l'institution judiciaire - Audition d'Eric Dupond-Moretti	PJL Confiance dans l'institution judiciaire - Audition d'Eric Dupond-Moretti	2021-07-21 13:35:00	2021-07-21 14:55:00	2021-07-21 15:21:25	2021-07-21 15:54:23	20	0	\N	\N
579137	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Prévention d'actes de terrorisme et renseignement (NL) (amendements)	PJL Prévention d'actes de terrorisme et renseignement (NL) (amendements)	2021-07-21 21:55:00	2021-07-21 22:00:00	2021-07-21 22:12:18	2021-07-22 18:16:34	12	0	\N	\N
579243	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2021-07-24 08:30:00	2021-07-24 09:05:00	2021-07-24 09:15:45	2021-07-28 10:30:15	23	0	\N	\N
579244	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PJL Gestion de la crise sanitaire - Examen des amendements de commission délégués au fond	\N	2021-07-23 13:30:00	2021-07-23 14:40:00	2021-07-23 14:53:33	2021-07-23 19:19:57	18	0	\N	\N
579245	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2021-07-21 11:00:00	2021-07-21 12:15:00	\N	\N	32	0	\N	\N
579598	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Révision tarifs contrats photovoltaïques - CRE	Contrôle 2021 - Révision tarifs contrats photovoltaïques - CRE	2021-07-13 10:30:00	2021-07-13 11:30:00	\N	\N	1	0	\N	\N
579600	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Révision tarifs contrats photovoltaïques - DGEC	Contrôle 2021 - Révision tarifs contrats photovoltaïques - DGEC	2021-07-16 14:00:00	2021-07-16 15:00:00	\N	\N	1	0	\N	\N
579602	COM_PERMANENTE	AUTRE	\N	FINC	\N	PJLR budget de l'année 2020 - Examen Rapport Nlle Lecture	PJLR budget de l'année 2020 - Examen Rapport Nlle Lecture	2021-07-21 11:00:00	2021-07-21 11:10:00	2021-07-21 11:25:39	2021-07-21 15:54:22	28	0	\N	\N
579604	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Médias, Livre et industries culturelles - France Messagerie	PLF pour 2022 - Médias, Livre et industries culturelles - France Messagerie	2021-07-12 10:00:00	2021-07-12 10:35:00	\N	\N	1	0	\N	\N
579606	MISSION	AUCUNE	\N	INFLUENCES	\N	Audition Mme Bird Ambassadrice d"Australie	\N	2021-07-21 17:32:00	2021-07-21 18:36:00	2021-07-21 18:39:04	2021-07-22 18:16:44	8	0	\N	\N
580054	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Crise sanitaire	PJL  Crise sanitaire	2021-07-23 21:30:00	2021-07-23 23:35:00	\N	\N	66	0	\N	\N
580071	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Crise sanitaire	PJL Crise sanitaire	2021-07-24 14:30:00	2021-07-24 20:05:00	\N	\N	103	0	\N	\N
580107	GIA	AUCUNE	\N	\N	\N	Entretien avec une délégation du Conseil démocratique syrien	Entretien avec une délégation du Conseil démocratique syrien	2021-07-20 15:30:00	2021-07-20 16:30:00	\N	\N	3	0	644	\N
580401	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Confiance dans l'institution judiciaire	PJL Confiance dans l'institution judiciaire	2021-07-20 14:45:00	2021-07-20 18:00:00	\N	\N	2	0	\N	\N
580404	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Confiance dans l'institution judiciaire	PJL Confiance dans l'institution judiciaire	2021-07-20 18:00:00	2021-07-20 19:10:00	\N	\N	3	0	\N	\N
580598	MISSION	AUDRAP	\N	INFLUENCES	\N	Audition M. Antoine Bondaz Fondation pour la recherche stratégique	Audition rapporteur - MI Influences étatiques - Audition M. Antoine Bondaz Fondation pour la recherche stratégique	2021-07-20 16:05:00	2021-07-20 17:07:00	\N	\N	5	0	\N	\N
580607	MISSION	AUDRAP	\N	INFLUENCES	\N	Auditionb M. Emanuel VERON INALCO	\N	2021-07-20 17:10:00	2021-07-20 18:35:00	\N	\N	5	0	\N	\N
580620	MISSION	AUDRAP	\N	INFLUENCES	\N	Audition Mickael COLE Institut Mac Donald Taiwan	\N	2021-07-22 11:00:00	2021-07-22 12:30:00	\N	\N	0	0	\N	\N
580621	MISSION	AUDRAP	\N	INFLUENCES	\N	Audition François GODEMENT Institut Montaigne	\N	2021-07-22 14:05:00	2021-07-22 15:10:00	\N	\N	4	0	\N	\N
580622	MISSION	AUDRAP	\N	INFLUENCES	\N	Table ronde DCESS -MAE	\N	2021-07-22 15:15:00	2021-07-22 16:17:00	\N	\N	3	0	\N	\N
580718	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Gestion de la crise sanitaire - Table ronde des fédérations hospitalières	\N	2021-07-20 14:30:00	2021-07-20 15:15:00	\N	\N	4	0	\N	\N
580719	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Gestion de la crise sanitaire - Table ronde des conseils de l'ordre	\N	2021-07-20 15:20:00	2021-07-20 16:30:00	\N	\N	7	0	\N	\N
580720	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Gestion de la crise sanitaire - Audition de l'AP-HP	\N	2021-07-20 16:30:00	2021-07-20 17:00:00	\N	\N	2	0	\N	\N
580723	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Protection des enfants - Audition de la Fnadepape	\N	2021-07-20 17:15:00	2021-07-20 18:00:00	\N	\N	1	0	\N	\N
580724	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Protection des enfants - Audition de la CNAPE	\N	2021-07-20 16:15:00	2021-07-20 17:15:00	\N	\N	1	0	\N	\N
580726	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Protection des enfants - Audition de l'association Repairs!	\N	2021-07-20 15:15:00	2021-07-20 16:15:00	\N	\N	3	0	\N	\N
580767	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PJL Gestion de la crise sanitaire (SOC) - Audition 	\N	2021-07-22 10:30:00	2021-07-22 12:00:00	\N	\N	0	0	\N	\N
580772	ETUDES	AUDRAP	\N	\N	\N	Petit déjeuner GE Sport	Réunion des membres du Bureau	2021-07-21 08:00:00	2021-07-21 09:00:00	\N	\N	11	0	\N	934
580992	GIA	AUCUNE	\N	\N	\N	entretien avec S.E. M. Ainal Arif Mantaha, ambassadeur de Singapour en France	\N	2021-07-20 20:00:00	2021-07-20 22:00:00	\N	\N	8	0	609	\N
581019	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ambassadeur de Djibouti en France	Entretien avec SE M. Ayeid Mousseid YAHYA, Ambassadeur de Djibouti en France	2021-07-21 12:45:00	2021-07-21 14:10:00	\N	\N	3	0	588	\N
581279	CONF_PRES	AUCUNE	\N	\N	\N	Conf Prés	Conférence des Présidents	2021-07-20 14:05:00	2021-07-20 14:40:00	\N	\N	24	0	\N	\N
520108	DELEGATION	AUDRAP	\N	\N	206	Audition Production d'hydrogène - ENGIE	Audition Production d'hydrogène - ENGIE	2021-01-14 15:00:00	2021-01-14 16:00:00	\N	\N	1	0	\N	\N
520134	DELEGATION	AUDRAP	\N	\N	206	Audition Production d'hydrogène - CEA	Audition Production d'hydrogène - CEA	2021-01-14 16:00:00	2021-01-14 17:00:00	\N	\N	1	0	\N	\N
520137	DELEGATION	AUDRAP	\N	\N	206	Audition Production d'hydrogène - Ecole des mines	Audition Production d'hydrogène - Ecole des mines	2021-01-14 17:00:00	2021-01-14 18:00:00	\N	\N	1	0	\N	\N
521267	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Auditions Sésame	Auditions Sésame	2021-01-12 14:00:00	2021-01-12 15:00:00	\N	\N	3	0	\N	\N
521271	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Auditions Sésame	Auditions Sésame	2021-01-12 15:00:00	2021-01-12 17:00:00	\N	\N	2	0	\N	\N
521291	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Auditions Sésame	Auditions Sésame	2021-01-12 17:00:00	2021-01-12 19:15:00	\N	\N	1	0	\N	\N
521325	ETUDES	AUCUNE	\N	\N	\N	Assemblée générale	Assemblée générale GE Vigne et vin	2021-01-13 13:30:00	2021-01-13 14:30:00	\N	\N	34	0	\N	909
526275	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	GT Enjeux internationaux Climat - Environnement - Développement	GT Enjeux internationaux Climat - Environnement - Développement	2021-01-27 13:30:00	2021-01-27 15:00:00	\N	\N	6	0	\N	\N
529005	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière - Audition sur les New Breeding Techniques (NBT)	Réunion plénière - Audition sur les New Breeding Techniques (NBT)	2021-03-18 09:05:00	2021-03-18 13:50:00	\N	\N	12	0	\N	\N
529070	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2021-02-09 09:30:00	2021-02-09 13:30:00	\N	\N	43	0	\N	\N
529071	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat sur l'« Opération Barkhane	Débat sur l'« Opération Barkhane	2021-02-09 14:30:00	2021-02-09 17:40:00	\N	\N	161	0	\N	\N
529076	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Cartes communales LEC	PPL Cartes communales LEC	2021-02-09 17:40:00	2021-02-09 18:50:00	\N	\N	78	0	\N	\N
529077	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat sur les mineurs non accompagnés	Débat sur les mineurs non accompagnés	2021-02-09 18:50:00	2021-02-09 20:30:00	\N	\N	72	0	\N	\N
529080	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat sur l'avenir de la Métropole du Grand Paris	Débat sur l'avenir de la Métropole du Grand Paris	2021-02-09 22:00:00	2021-02-09 23:40:00	\N	\N	33	0	\N	\N
529081	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2021-02-10 15:00:00	2021-02-10 16:15:00	\N	\N	211	0	\N	\N
529082	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat conclusions CE Grandes pandémies	Débat conclusions CE Grandes pandémies	2021-02-10 16:30:00	2021-02-10 18:40:00	\N	\N	77	0	\N	\N
529083	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat  fonctionnement des universités en temps covid et le malaise étudiant	Débat  fonctionnement des universités en temps covid et le malaise étudiant	2021-02-10 18:50:00	2021-02-10 20:30:00	\N	\N	38	0	\N	\N
529084	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Respect des libertés publiques	Débat Respect des libertés publiques, protection de la vie privée	2021-02-10 22:00:00	2021-02-11 23:25:00	\N	\N	20	0	\N	\N
529093	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Agriculteurs en détresse - Déplacement en Saône-et-Loire	GT Agriculteurs en détresse - Déplacement en Saône-et-Loire	2021-02-04 10:00:00	2021-02-04 12:15:00	\N	\N	3	0	\N	\N
529098	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Agriculteurs en détresse - Déplacement dans l'Ain	GT Agriculteurs en détresse - Déplacement dans l'Ain	2021-02-04 13:30:00	2021-02-04 15:00:00	\N	\N	2	0	\N	\N
529101	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Agriculteurs en détresse - Déplacement dans l'Ain	GT Agriculteurs en détresse - Déplacement dans l'Ain	2021-02-04 15:20:00	2021-02-04 17:20:00	\N	\N	5	0	\N	\N
529107	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition GT Agriculteurs en détresse	Audition GT Agriculteurs en détresse	2021-02-03 16:30:00	2021-02-03 18:00:00	\N	\N	9	0	\N	\N
542592	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Droit au respect de la dignité en détention (désignation des membres de la CMP)	PPL Droit au respect de la dignité en détention (désignation des membres de la CMP)	2021-03-18 14:20:00	2021-03-18 14:25:00	2021-03-18 14:34:26	2021-03-18 17:52:18	5	0	\N	\N
542796	DELEGATION	AUCUNE	\N	\N	DSOM	Table ronde sur le logement dans les outre-mer	\N	2021-04-01 14:30:00	2021-04-01 17:25:00	\N	\N	8	0	\N	\N
542801	MISSION	AUCUNE	\N	ENSAGRIC	\N	Audition de l'APREFA	\N	2021-03-23 13:34:00	2021-03-23 14:58:00	2021-03-23 16:42:47	2021-03-23 17:21:00	15	0	\N	\N
542808	MISSION	AUCUNE	\N	CONF	\N	Table ronde de représentants d'institutions culturelles internationales	\N	2021-03-23 09:05:00	2021-03-23 10:35:00	2021-03-23 11:33:35	2021-03-23 17:21:00	8	0	\N	\N
542822	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Protéger les mineurs des crimes et délits sexuels et de l'inceste (rapport et texte)	PPL Protéger les mineurs des crimes et délits sexuels et de l'inceste (rapport et texte)	2021-03-23 09:00:00	2021-03-23 10:00:00	2021-03-23 10:41:49	2021-03-23 17:20:30	21	0	\N	\N
542823	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJLC Article 1er Constitution et environnement - Auditions d'universitaires	PJLC Article 1er Constitution et environnement - Auditions d'universitaires	2021-03-24 10:15:00	2021-03-24 12:40:00	2021-03-26 15:21:28	2021-03-26 15:28:56	35	0	\N	\N
542826	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJLC Article 1er Constitution et environnement - Audition d'Eric Dupond-Moretti	PJLC Article 1er Constitution et environnement - Audition d'Eric Dupond-Moretti	2021-03-24 16:45:00	2021-03-24 18:05:00	2021-03-25 10:48:25	2021-03-26 15:15:09	53	0	\N	\N
542828	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de Claire Hédon, défenseure des droits	Audition de Claire Hédon, défenseure des droits	2021-03-24 18:30:00	2021-03-24 19:40:00	2021-03-24 20:00:18	2021-03-26 15:15:11	12	0	\N	\N
542833	DELEGATION	AUDRAP	\N	\N	PROS	Audition de la DNS	Audition de Mme Laura Letourneau, ingénieure des mines,  déléguée ministérielle au numérique en santé	2021-04-12 09:00:00	2021-04-12 10:00:00	\N	\N	3	0	\N	\N
542848	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Négociation collective - Audition de l'U2P	\N	2021-03-16 10:30:00	2021-03-16 11:30:00	\N	\N	1	0	\N	\N
542849	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Négociation collective - Audition de la CFDT	\N	2021-03-17 13:00:00	2021-03-17 14:00:00	\N	\N	1	0	\N	\N
555046	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Assistants maternels et salariés des particuliers employeurs	\N	2021-05-06 16:30:00	2021-05-06 17:10:00	\N	\N	3	0	\N	\N
555047	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Assistants maternels et salariés des particuliers employeurs	\N	2021-05-06 17:30:00	2021-05-06 18:10:00	\N	\N	3	0	\N	\N
555048	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Assistants maternels et salariés des particuliers employeurs	\N	2021-05-11 16:30:00	2021-05-11 17:25:00	\N	\N	1	0	\N	\N
555052	MISSION	AUDRAP	\N	VIETUDIA	\N	Audition Etudaints Nouvelle caledonie	\N	2021-04-21 10:06:00	2021-04-21 10:56:00	\N	\N	4	0	\N	\N
555055	MISSION	AUDRAP	\N	VIETUDIA	\N	Audition Université Champollion Albi	\N	2021-04-20 14:00:00	2021-04-20 16:00:00	\N	\N	4	0	\N	\N
555064	MISSION	AUDRAP	\N	VIETUDIA	\N	Audition AMF	\N	2021-04-21 11:00:00	2021-04-21 12:15:00	\N	\N	3	0	\N	\N
555068	MISSION	AUDRAP	\N	PAUP	\N	Odenore	\N	2021-04-27 10:15:00	2021-04-27 11:30:00	\N	\N	2	0	\N	\N
555069	MISSION	AUDRAP	\N	PAUP	\N	Cnaf	\N	2021-04-29 10:00:00	2021-04-29 11:00:00	\N	\N	2	0	\N	\N
555070	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Assistants maternels et salariés des particuliers employeurs	\N	2021-05-07 14:30:00	2021-05-07 15:30:00	\N	\N	3	0	\N	\N
555086	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Dérèglement climatique et résilience - Auditions de M. Pascal Martin	PJL Dérèglement climatique et résilience - Auditions de M. Pascal Martin	2021-04-22 11:00:00	2021-04-22 12:30:00	\N	\N	1	0	\N	\N
555088	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Dérèglement climatique et résilience - Auditions de M. Pascal Martin	PJL Dérèglement climatique et résilience - Auditions de M. Pascal Martin	2021-04-21 08:30:00	2021-04-21 10:30:00	\N	\N	3	0	\N	\N
555092	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Dérèglement climatique et résilience - Auditions de M. Pascal Martin	PJL Dérèglement climatique et résilience - Auditions de M. Pascal Martin	2021-04-21 11:00:00	2021-04-21 12:25:00	\N	\N	1	0	\N	\N
555098	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Dérèglement climatique et résilience - Auditions de M. Pascal Martin	PJL Dérèglement climatique et résilience - Auditions de M. Pascal Martin	2021-04-22 17:25:00	2021-04-22 18:15:00	\N	\N	2	0	\N	\N
590021	GIA	AUCUNE	\N	\N	\N	accueil d'une délégation du Conseil de la Shoura saoudienne	\N	2021-10-06 11:00:00	2021-10-06 12:00:00	\N	\N	1	0	661	\N
592128	GIA	AUCUNE	\N	\N	\N	Entretien avec la Déléguée générale du Québec en France	entretien avec Mme Michèle Boisvert à l'occasion du 60ème anniversaire de la présence officielle de la représentation du	2021-10-13 12:30:00	2021-10-13 15:00:00	\N	\N	17	0	602	\N
593331	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2022	\N	2021-10-13 17:30:00	2021-10-13 18:30:00	\N	\N	2	0	\N	\N
602567	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Désignations au sein d'OEP	\N	2021-11-17 10:58:00	2021-11-17 10:58:00	2021-11-17 11:39:44	2021-11-19 19:32:17	38	0	\N	\N
616237	COM_ENQUETE	PLENIERE	\N	CABINETS	\N	Auditions plénières - Syntec Conseil - SGG	Auditions plénières - Syntec Conseil - SGG	2022-01-05 16:30:00	2022-01-05 19:00:00	2022-01-10 14:41:04	2022-01-10 14:54:09	12	0	\N	\N
616305	COM_ENQUETE	PLENIERE	\N	HOPITAL	\N	Réunion plénière	\N	2022-01-04 14:00:00	2022-01-04 18:30:00	2022-01-04 18:29:43	2022-01-05 17:10:22	15	0	\N	\N
616309	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Audition de M. Belin - Confédération des buralistes	\N	2021-12-14 16:00:00	2021-12-14 16:50:00	\N	\N	0	0	\N	\N
616310	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Audition de M. Belin - Association les 1000 cafés	\N	2021-12-14 16:50:00	2021-12-14 17:30:00	\N	\N	0	0	\N	\N
616328	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	LSA	\N	2021-12-15 17:50:00	2021-12-15 18:30:00	\N	\N	0	0	\N	\N
602566	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Examen de 5 avis budgétaires	\N	2021-11-17 09:00:00	2021-11-17 11:00:00	2021-11-17 11:38:16	2021-11-19 19:32:19	38	3	\N	\N
616308	COM_PERMANENTE	AUTRE	\N	AFCL	\N	PPL Sport (rapport+texte) - PPL harcelement scolaire (rapport+texte)	\N	2022-01-05 09:30:00	2022-01-05 12:00:00	\N	\N	39	2	\N	\N
616376	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Audition plénière - Nominations de rapporteurs	\N	2022-01-06 08:30:00	2022-01-06 10:25:00	\N	\N	24	0	\N	\N
616377	AUTRE_TEMPORAIRE	AUCUNE	\N	\N	\N	Déplacement dans l'Ain	\N	2021-12-20 09:00:00	2021-12-20 16:30:00	\N	\N	0	0	\N	\N
626799	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-02-02 08:30:00	2022-02-02 11:35:00	2022-02-02 11:42:23	2022-02-02 15:43:39	41	0	\N	\N
626853	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-02-03 11:35:00	2022-02-03 12:55:00	2022-02-03 12:56:51	2022-02-03 18:19:09	13	0	\N	\N
626855	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	GT Climat	GT Climat	2022-01-26 13:45:00	2022-01-26 14:55:00	\N	\N	5	0	\N	\N
626870	COM_EURO	AUDRAP	\N	AFEU	\N	Paquet Climat - Volet Transports	Paquet Climat - Volet Transports - Air France	2022-01-27 15:30:00	2022-01-27 16:40:00	\N	\N	2	0	\N	\N
626885	COM_ENQUETE	PLENIERE	\N	CABINETS	\N	Auditions plénières - Mme Parly, ministre des armées - M. Bontemps, Nos Services Publics	Auditions plénières - Mme Parly, ministre des armées - M. Bontemps, Porte-parole de Nos Services Publics	2022-02-01 16:30:00	2022-02-01 18:50:00	2022-02-01 18:52:46	2022-02-02 15:44:32	8	0	\N	\N
626886	COM_ENQUETE	PLENIERE	\N	CABINETS	\N	Auditions plénières- M. O, secrétaire d'Etat - M. Véran, ministre solidarités et santé	Auditions plénières- M. O, secrétaire d'Etat - M. Véran, ministre solidarités et santé	2022-02-02 16:30:00	2022-02-02 19:30:00	2022-02-02 19:32:27	2022-02-03 10:40:19	10	0	\N	\N
627005	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Situation et perspectives SNCF - AGIFI	Contrôle 2021 - Situation et perspectives SNCF - AGIFI	2022-01-25 08:00:00	2022-01-25 08:45:00	\N	\N	2	0	\N	\N
627008	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Situation et perspectives SNCF - Alpha Trains France	Contrôle 2021 - Situation et perspectives SNCF - Alpha Trains France	2022-01-26 16:30:00	2022-01-26 17:30:00	\N	\N	2	0	\N	\N
627014	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2022-02-09 16:30:00	2022-02-09 17:51:00	2022-02-15 15:47:40	2022-02-15 17:25:58	25	0	\N	\N
627015	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition Antoine PETIT - article 13	\N	2022-02-02 09:00:00	2022-02-02 10:15:00	2022-02-02 11:32:34	2022-02-02 15:43:38	37	0	\N	\N
627016	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteurs - Duty free - RP France auprès de l'UE	Audition rapporteurs - Duty free - RP France auprès de l'UE	2022-02-02 14:00:00	2022-02-02 14:35:00	\N	\N	2	0	\N	\N
627017	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Duty Free Eurotunnel - SGAE M. Stéphane Dupuis	Audition Duty Free Eurotunnel - SGAE 	2022-02-02 14:50:00	2022-02-02 15:15:00	\N	\N	2	0	\N	\N
627018	COM_ENQUETE	PLENIERE	\N	MEDIA	\N	audition	\N	2022-02-02 16:45:00	2022-02-02 18:50:00	2022-02-02 21:10:40	2022-02-03 10:40:20	15	0	\N	\N
627019	DELEGATION	AUCUNE	\N	\N	211	Audition de journalistes ayant enquêté sur le milieu de la pornographie	Audition de journalistes ayant enquêté sur le milieu de la pornographie	2022-02-17 09:00:00	2022-02-17 10:45:00	2022-02-17 12:39:29	\N	8	0	\N	\N
627020	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Salaires Minimaux - Mme Sylvie Guillaume	\N	2022-02-01 16:00:00	2022-02-01 17:00:00	\N	\N	0	0	\N	\N
627021	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Chasse	Auditions du mercredi 26 janvier	2022-01-26 16:30:00	2022-01-26 19:25:00	\N	\N	8	0	\N	\N
627030	MISSION	AUCUNE	\N	RECHINNO	\N	Audition ANR/Ademe	\N	2022-01-25 17:00:00	2022-01-25 18:20:00	2022-01-31 16:10:24	2022-01-31 17:43:23	6	0	\N	\N
627038	MISSION	AUDRAP	\N	RECHINNO	\N	Audition Cour des Comptes	\N	2022-01-25 15:00:00	2022-01-25 16:50:00	\N	\N	9	0	\N	\N
627048	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Rapporteur - M. Alain Le Roy	\N	2022-02-11 09:00:00	2022-02-11 10:00:00	\N	\N	0	0	\N	\N
627070	COM_EURO	AUDRAP	\N	AFEU	\N	Les relations entre l'UE et la Turquie	Les relations entre l'UE et la Turquie - Commission européenne	2022-01-28 11:00:00	2022-01-28 12:20:00	\N	\N	1	0	\N	\N
627071	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteurs - I.D.E.A. Bauhaus Mme Reichstein	\N	2022-02-10 15:00:00	2022-02-10 16:00:00	\N	\N	0	0	\N	\N
627075	COM_ENQUETE	PLENIERE	\N	MEDIA	\N	audition	\N	2022-02-03 11:00:00	2022-02-03 12:10:00	2022-02-03 17:43:42	2022-02-03 18:54:56	10	0	\N	\N
627076	COM_ENQUETE	PLENIERE	\N	MEDIA	\N	audition	\N	2022-02-03 14:00:00	2022-02-03 16:45:00	2022-02-03 17:49:09	2022-02-03 18:54:56	13	0	\N	\N
627379	MISSION	AUCUNE	\N	FONDSMER	\N	Table ronde de scientifiques	Table ronde de scientifiques	2022-02-01 17:00:00	2022-02-01 18:35:00	2022-02-01 18:39:25	2022-02-02 15:44:33	7	0	\N	\N
627830	ETUDES	AUDRAP	\N	\N	\N	Echanges avec Tony Estanguet, Cojop	Déjeuner avec Tony Estanguet	2022-01-27 12:30:00	2022-01-27 14:30:00	\N	\N	13	0	\N	934
627851	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Association nationale des étudiants en médecine	Audition de M. Lunel et Mme Brajon	2022-02-01 14:00:00	2022-02-01 15:15:00	\N	\N	1	0	\N	\N
627852	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Université de Strasbourg	Audition de M. le Doyen Sibilia	2022-02-01 15:00:00	2022-02-01 15:40:00	\N	\N	1	0	\N	\N
627853	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Collectif national PASS/LAS	\N	2022-02-01 16:00:00	2022-02-01 17:50:00	\N	\N	2	0	\N	\N
627925	MISSION	AUCUNE	\N	RECHINNO	\N	Auditions plénières	M. Thierry COULHON, président du collège du Haut Conseil de l¿évaluation de la recherche et de l¿enseignement supérieur	2022-02-01 15:05:00	2022-02-01 16:10:00	2022-02-08 16:59:33	2022-02-08 17:02:25	7	0	\N	\N
627941	MISSION	AUCUNE	\N	CULTURE	\N	Réunion 20220202a	\N	2022-02-02 13:30:00	2022-02-02 14:55:00	2022-02-02 14:58:38	2022-02-02 15:44:33	10	0	\N	\N
627944	MISSION	AUCUNE	\N	CULTURE	\N	Réunion 20220202b	\N	2022-02-02 16:45:00	2022-02-02 17:30:00	2022-02-02 17:32:07	2022-02-02 18:07:22	4	0	\N	\N
627955	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	MCC Sécurisation chasse - Auditions diverses	\N	2022-02-01 15:35:00	2022-02-01 19:40:00	\N	\N	0	0	\N	\N
628641	COM_ENQUETE	AUDRAP	\N	HOPITAL	\N	CE Hôpital - Audition de l'Ordre national des infirmiers	\N	2022-02-01 19:15:00	2022-02-01 20:15:00	\N	\N	6	0	\N	\N
628668	COM_PERMANENTE	AUTRE	\N	FINC	\N	Contrôle suivi rapport Algues vertes en Bretagne et Audition de M. Éric LOMBARD, DG CdC	Contrôle suivi rapport Algues vertes en Bretagne et Audition de M. Éric LOMBARD, DG CdC	2022-02-09 09:50:00	2022-02-09 12:30:00	2022-02-09 13:55:45	2022-02-10 18:02:33	37	0	\N	\N
506209	DELEGATION	AUDRAP	\N	\N	206	Audition Phagothérapie - Pr Claude Soussy	Audition Phagothérapie - Pr Claude Soussy	2020-11-23 16:00:00	2020-11-23 17:00:00	\N	\N	1	0	\N	\N
506211	DELEGATION	AUDRAP	\N	\N	206	Audition Phagothérapie - Dr Grégory Resch	Audition Phagothérapie - Dr Grégory Resch	2020-11-26 14:30:00	2020-11-26 15:30:00	\N	\N	1	0	\N	\N
515913	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe	Assemblée générale du groupe	2020-12-09 14:15:00	2020-12-09 14:45:00	\N	\N	15	0	609	\N
515929	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe	Assemblée générale du groupe	2020-12-09 16:30:00	2020-12-09 16:50:00	\N	\N	6	0	556	\N
516991	GIA	AUCUNE	\N	\N	\N	AG GIA France-Jordanie	Assemblée générale du GIA France-Jordanie	2020-12-15 14:10:00	2020-12-15 14:20:00	\N	\N	4	0	659	\N
529946	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Transport de marchandises - Groupe Michelin	MI Transport de marchandises - Groupe Michelin	2021-02-09 14:30:00	2021-02-09 15:15:00	\N	\N	10	0	\N	\N
529959	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Transport de marchandises - Renault Trucks	MI Transport de marchandises - Renault Trucks	2021-02-09 15:15:00	2021-02-09 16:10:00	\N	\N	11	0	\N	\N
529971	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Transport de marchandises - Plateforme de la filière automobile	MI Transport de marchandises - Plateforme de la filière automobile	2021-02-09 16:10:00	2021-02-09 16:50:00	\N	\N	4	0	\N	\N
530409	GIA	AUCUNE	\N	\N	\N	Réunion constitutive	Réunion constitutive du groupe d'amitié	2021-02-10 14:15:00	2021-02-10 14:35:00	\N	\N	2	0	603	\N
531115	GIA	AUCUNE	\N	\N	\N	Audition de l'ambassadeur de France en Birmanie 	Audition de Christian LECHERVY, ambassadeur de France en Birmanie	2021-02-11 11:30:00	2021-02-11 12:30:00	\N	\N	7	0	609	\N
531213	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2021-02-10 14:05:00	2021-02-10 14:30:00	\N	\N	22	0	\N	\N
536656	MISSION	AUCUNE	\N	EGALCHAN	\N	Réunion plénière MI égalité des chances	\N	2021-03-10 17:00:00	2021-03-10 18:58:00	2021-03-10 19:00:03	2021-03-11 18:52:28	12	0	\N	\N
536880	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Respect principes de la République - Auditions	DGESCO	2021-03-04 14:00:00	2021-03-04 15:10:00	\N	\N	2	0	\N	\N
536882	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Audition conjointe CNOSF/CPSF	\N	2021-03-09 10:00:00	2021-03-09 11:00:00	\N	\N	4	0	\N	\N
536883	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Région Île-de France	\N	2021-03-09 13:30:00	2021-03-09 14:30:00	\N	\N	3	0	\N	\N
536884	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Conférence des Présidents d'université	\N	2021-03-09 16:30:00	2021-03-09 17:30:00	\N	\N	4	0	\N	\N
536885	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Fédération nationale de l'enseignement privé musulman (FNEM)	\N	2021-03-10 14:00:00	2021-03-10 15:00:00	\N	\N	1	0	\N	\N
536886	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Association Nationale Pour les Enfants Intellectuellement Précoces	\N	2021-02-18 09:15:00	2021-02-18 10:00:00	\N	\N	2	0	\N	\N
536887	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Respect principes de la République	Audition Direction des affaires financières	2021-02-18 14:00:00	2021-02-18 15:00:00	\N	\N	2	0	\N	\N
536888	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Syndicat national de l'éducation physique	\N	2021-02-18 16:00:00	2021-02-18 16:45:00	\N	\N	1	0	\N	\N
536889	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Respect principes de la République	SNPDEN	2021-02-17 18:00:00	2021-02-17 19:00:00	\N	\N	2	0	\N	\N
536892	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Académie de Créteil	\N	2021-02-16 10:00:00	2021-02-16 11:00:00	\N	\N	0	0	\N	\N
536893	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Ministère de l'éducation nationale - DG Affaires juridiques MENJS	\N	2021-02-16 15:15:00	2021-02-16 16:45:00	\N	\N	0	0	\N	\N
536894	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Table ronde Présidents université (Paris 13 et Lille)	\N	2021-02-16 17:00:00	2021-02-16 18:30:00	\N	\N	0	0	\N	\N
536895	MISSION	AUCUNE	\N	PAUP	\N	Auditions plénières	\N	2021-03-09 15:30:00	2021-03-09 19:00:00	2021-03-11 16:38:54	2021-03-11 18:52:26	14	0	\N	\N
536913	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 11 mars 2021	\N	2021-03-11 08:30:00	2021-03-11 10:10:00	2021-03-11 10:19:05	2021-03-11 18:49:37	20	0	\N	\N
539583	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI "Difficultés des entreprises et crise de la Covid-19"	Audition rapporteur - MI "Difficultés des entreprises et crise de la Covid-19"	2021-03-11 12:00:00	2021-03-11 13:00:00	\N	\N	2	0	\N	\N
540081	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	aliment	Auditions GT Alimentation durable et locale	2021-03-16 15:00:00	2021-03-16 17:05:00	\N	\N	7	0	\N	\N
540091	GIA	AUCUNE	\N	\N	\N	Entretien parlementaire irakien	Entretien avec M. Haitham al-Oweidi, président de la commission des finances du Parlement irakien	2021-03-18 10:00:00	2021-03-18 11:30:00	\N	\N	2	0	615	\N
540094	GIA	AUCUNE	\N	\N	\N	Entretien Ahmad Massoud	Entretien avec M. Ahmad Massoud, fils du commandant Massoud	2021-03-24 12:15:00	2021-03-24 13:45:00	\N	\N	3	0	648	\N
541666	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - NexSIS - Mission préfiguration NexSIS	Contrôle 2021 - NexSIS - Mission préfiguration NexSIS	2021-03-16 09:30:00	2021-03-16 10:45:00	\N	\N	1	0	\N	\N
541668	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - NexSIS - CNSIS & AdF / FNSPF	Contrôle 2021 - NexSIS - CNSIS & AdF / FNSPF	2021-03-17 09:00:00	2021-03-17 10:30:00	\N	\N	1	0	\N	\N
541670	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n°389 Hydroélectricité - Fédération des moulins de France & France hydroélectricité	PPL n°389 Hydroélectricité - Fédération des moulins de France & France hydroélectricité	2021-03-15 15:30:00	2021-03-15 17:30:00	\N	\N	1	0	\N	\N
541673	COM_PERMANENTE	AUTRE	\N	FINC	\N	PJL 701 CVN France-Argentine : Examen Rapport et Texte	PJL 701 CVN France-Argentine : Examen Rapport et Texte	2021-03-24 09:45:00	2021-03-24 10:10:00	2021-03-24 11:28:07	2021-03-24 17:39:13	26	0	\N	\N
544993	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Suivi loi SRU	Auditions Suivi loi SRU	2021-03-23 16:30:00	2021-03-23 19:45:00	\N	\N	1	0	\N	\N
544995	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Expérimenter le retour à l'emploi des bénéficiaires du RSA	\N	2021-03-25 09:00:00	2021-03-25 09:45:00	\N	\N	3	0	\N	\N
545015	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Expérimenter le retour à l'emploi des bénéficiaires du RSA	\N	2021-03-17 16:30:00	2021-03-17 17:20:00	\N	\N	3	0	\N	\N
545016	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Expérimenter le retour à l'emploi des bénéficiaires du RSA	\N	2021-03-18 09:30:00	2021-03-18 11:30:00	\N	\N	1	0	\N	\N
547767	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Haut Karabakh	\N	2021-03-31 13:45:00	2021-03-31 14:45:00	\N	\N	4	0	\N	\N
548971	COM_PERMANENTE	GROUPE_TRAVAIL	\N	ETRD	\N	Groupe de travail Drones	Groupe de travail Drones	2021-04-01 10:00:00	2021-04-02 11:00:00	\N	\N	4	0	\N	\N
555348	MISSION	AUDRAP	\N	CONF	\N	Entretien avec Mme Roselyne Bachelot, ministre de la Culture	\N	2021-04-26 11:30:00	2021-04-26 12:20:00	\N	\N	2	0	\N	\N
555351	DELEGATION	AUCUNE	\N	\N	COLTER	Audition MM. Gérard, directeur ENA, et Périnet, directeur INET + Communication F. Gatel	\N	2021-05-06 09:30:00	2021-05-06 11:35:00	\N	\N	15	0	\N	\N
555405	MISSION	AUCUNE	\N	ENSAGRIC	\N	Déplacement en Gironde	\N	2021-04-02 09:30:00	2021-04-02 18:30:00	\N	\N	2	0	\N	\N
555408	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Dérèglement climatique - Audition Sels de France	PJL Dérèglement climatique - Audition Sels de France	2021-04-20 09:00:00	2021-04-20 10:15:00	\N	\N	1	0	\N	\N
562101	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT Puissance chinoise en Europe	\N	2021-05-18 16:00:00	2021-05-18 18:15:00	\N	\N	4	0	\N	\N
562106	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT Puissance chinoise en Europe	\N	2021-05-19 15:00:00	2021-05-19 16:15:00	\N	\N	3	0	\N	\N
567776	MISSION	AUCUNE	\N	HARCEL	\N	Harcèement scolaire	Mission harcèlement scolaire	2021-06-09 16:33:00	2021-06-09 19:07:00	2021-06-10 09:48:28	2021-06-10 11:57:29	11	0	\N	\N
570333	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de M. Olivier Véran, ministre des solidarités et de la santé	\N	2021-06-23 16:30:00	2021-06-23 18:05:00	2021-06-23 19:22:02	2021-06-24 18:15:14	28	0	\N	\N
570376	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Mineurs non accompagnés - Audition commune de l'UNML et de l'UNHAJ	\N	2021-06-15 16:00:00	2021-06-15 17:00:00	\N	\N	2	0	\N	\N
570388	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Mineurs non accompagnés - Audition de MSF	\N	2021-06-15 17:00:00	2021-06-15 18:00:00	\N	\N	3	0	\N	\N
570389	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Mineurs non accompagnés - Audition de la DGCS	\N	2021-06-16 14:00:00	2021-06-16 15:00:00	\N	\N	4	0	\N	\N
581319	ETUDES	AUTRE	\N	\N	\N	Réunion constitutive	Réunion constitutive	2021-07-20 17:00:00	2021-07-20 17:45:00	\N	\N	12	0	\N	908
581739	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	COM AFD	\N	2021-07-20 08:30:00	2021-07-20 09:30:00	\N	\N	2	0	\N	\N
582585	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	Groupe d'études Statut rôle et place des Français établis hors de France	Table ronde sur la situation des étudiants français à l'étranger et l'impact de la crise sanitaire	2021-05-19 13:30:00	2021-05-19 15:30:00	\N	\N	2	0	\N	\N
582629	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Urgence sanitaire outre-mer	Prorogation de l'état d'urgence sanitaire dans les outre-mer	2021-09-09 09:30:00	2021-09-09 12:00:00	\N	\N	95	0	\N	\N
582630	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2021-09-09 14:30:00	2021-09-09 15:55:00	\N	\N	102	0	\N	\N
582685	MISSION	AUTRE	\N	INFLUENCES	\N	Audition établissements d'enseignement supérieur	\N	2021-09-01 10:00:00	2021-09-01 12:00:00	\N	\N	0	0	\N	\N
582686	MISSION	AUDRAP	\N	INFLUENCES	\N	Audition SGDSN	Aiudition Reynold de la Boutetière (SGDSN)	2021-09-01 14:30:00	2021-09-01 15:35:00	\N	\N	4	0	\N	\N
582687	MISSION	AUDRAP	\N	INFLUENCES	\N	Audition Mme SCHMID (IFRI)	Audition Mme SCHMID (IFRI)	2021-09-01 15:41:00	2021-09-01 16:48:00	\N	\N	3	0	\N	\N
582775	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Réforme de l'adoption	\N	2021-09-07 09:30:00	2021-09-07 12:50:00	\N	\N	1	0	\N	\N
582777	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	\N	2021-09-07 14:30:00	2021-09-07 17:15:00	\N	\N	1	0	\N	\N
582837	MISSION	PLEIN_NON_JO	\N	INFLUENCES	\N	Audition de M. James Paterson	\N	2021-09-07 12:30:00	2021-09-07 13:25:00	\N	\N	3	0	\N	\N
582841	MISSION	AUDRAP	\N	INFLUENCES	\N	Audition de M. Nicolas Lerner	\N	2021-09-07 15:00:00	2021-09-07 16:20:00	\N	\N	3	0	\N	\N
582845	MISSION	AUDRAP	\N	INFLUENCES	\N	Audition de M. Alloncle et Mme Beer	\N	2021-09-07 16:55:00	2021-09-07 18:10:00	\N	\N	3	0	\N	\N
582878	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Lutte contre la maltraitance animale	PPL Lutte contre la maltraitance animale	2021-09-07 09:45:00	2021-09-07 10:15:00	\N	\N	2	0	\N	\N
582881	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Lutte contre la maltraitance animale	PPL Lutte contre la maltraitance animale	2021-09-07 10:15:00	2021-09-07 12:00:00	\N	\N	1	0	\N	\N
582883	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Lutte contre la maltraitance animale	PPL Lutte contre la maltraitance animale	2021-09-07 13:00:00	2021-09-07 15:30:00	\N	\N	1	0	\N	\N
582885	COM_PERMANENTE	AUTRE	\N	CAE	\N	\N	\N	2021-09-15 09:30:00	2021-09-15 12:00:00	2021-09-16 10:29:56	2021-09-16 20:49:06	41	0	\N	\N
582887	COM_PERMANENTE	DEPLACEMENT	\N	CAE	\N	PPL Lutte contre la maltraitance animale PPL Lutte contre la maltraitance animale	Déplacement Hauts-de-Seine et Seine-Saint-Denis	2021-09-22 09:00:00	2021-09-22 13:00:00	\N	\N	1	0	\N	\N
583172	COM_PERMANENTE	AUTRE	\N	FINC	\N	GT Réforme de la LOLF - Réunion de travail	GT Réforme de la LOLF - Réunion de travail	2021-09-10 09:30:00	2021-09-10 10:45:00	\N	\N	11	0	\N	\N
583184	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPLO Finances publiques - Auteurs rapport CGEDD-IGF sur BACEA	PPLO Finances publiques - Auteurs rapport CGEDD-IGF sur BACEA	2021-09-09 10:30:00	2021-09-09 12:30:00	\N	\N	1	0	\N	\N
583185	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPLO Finances publiques - DB (art. 4 quinquiès)	PPLO Finances publiques - DB (art. 4 quinquiès)	2021-09-09 16:30:00	2021-09-09 18:30:00	\N	\N	1	0	\N	\N
583206	DELEGATION	AUCUNE	\N	\N	211	Audition de Mme Élisabeth Moreno, ministre déléguée, chargée de l¿égalité entre les F et H	Audition de Mme Élisabeth Moreno, ministre déléguée, chargée de l¿égalité entre les F et H	2021-10-06 17:00:00	2021-10-06 18:50:00	\N	\N	12	0	\N	\N
583207	DELEGATION	AUCUNE	\N	\N	211	Audition de Mme Élisabeth Borne, Ministre du Travail, de l¿Emploi et de l¿Insertion	Audition de Mme Élisabeth Borne, Ministre du Travail, de l¿Emploi et de l¿Insertion	2021-10-05 17:30:00	2021-10-05 18:40:00	\N	\N	13	0	\N	\N
583217	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2021 - Financement aires protégées - Déplacement à Rue	Contrôle 2021 - Financement aires protégées - Déplacement à Rue	2021-09-10 07:30:00	2021-09-10 19:30:00	\N	\N	1	0	\N	\N
583219	MISSION	AUTRE	\N	HARCEL	\N	Examen de rapport d¿information	\N	2021-06-22 11:30:00	2021-06-22 14:00:00	\N	\N	0	0	\N	\N
583220	MISSION	AUTRE	\N	HARCEL	\N	Examen de rapport d¿information	\N	2021-09-22 11:30:00	2021-09-22 14:00:00	\N	\N	0	0	\N	\N
583221	DELEGATION	AUCUNE	\N	\N	211	Audition de M. CyriL Cosme, directeur pour la France de l'OIT	Audition de M. CyriL Cosme, directeur pour la France de l'OIT	2021-09-21 16:30:00	2021-09-21 17:35:00	2021-09-21 18:18:13	\N	11	0	\N	\N
583222	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2021 - Immobilier universitaire - Déplacement à Cergy	Contrôle 2021 - Immobilier universitaire - Déplacement à Cergy	2021-09-08 07:45:00	2021-09-08 13:00:00	\N	\N	1	0	\N	\N
583224	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Ministère de l'éducation nationale, de la jeunesse et des sports - Direction des sports	Audition de M. Quénéhervé	2021-09-14 14:30:00	2021-09-14 16:30:00	\N	\N	5	0	\N	\N
583225	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Agence nationale du sport	Audition de M. Sanaur, directeur général	2021-09-14 16:30:00	2021-09-14 17:40:00	\N	\N	2	0	\N	\N
583226	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Table ronde "représentants de l'économie du sport"	\N	2021-09-15 15:30:00	2021-09-15 17:30:00	\N	\N	4	0	\N	\N
583227	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Table ronde "représentants des collectivités territoriales"	\N	2021-09-16 14:00:00	2021-09-16 16:00:00	\N	\N	3	0	\N	\N
583246	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	58-2 2020 - Couverture mobile du territoire - Déplacement au Mans	58-2 2020 - Couverture mobile du territoire - Déplacement au Mans	2021-09-14 09:35:00	2021-09-14 22:30:00	\N	\N	2	0	\N	\N
583478	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI répartition des moyens alloués à la création	\N	2021-09-09 15:30:00	2021-09-09 16:30:00	\N	\N	2	0	\N	\N
583481	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI répartition des moyens alloués à la création	\N	2021-09-09 16:30:00	2021-09-09 17:30:00	\N	\N	1	0	\N	\N
583483	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI répartition des moyens alloués à la création	\N	2021-09-09 17:30:00	2021-09-09 18:20:00	\N	\N	1	0	\N	\N
583485	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI répartition des moyens alloués à la création	\N	2021-09-15 16:00:00	2021-09-15 17:00:00	\N	\N	3	0	\N	\N
583489	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI répartition des moyens alloués à la création	\N	2021-09-15 17:00:00	2021-09-15 18:00:00	\N	\N	2	0	\N	\N
583503	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Visite du Breizh Park de Pont-Scorff	\N	2021-09-16 10:15:00	2021-09-16 12:15:00	\N	\N	2	0	\N	\N
583510	COM_EURO	AUTRE	\N	AFEU	\N	Table ronde UE dans les médias	\N	2021-09-23 09:00:00	2021-09-23 13:00:00	2021-09-23 17:13:04	2021-09-23 18:32:24	12	0	\N	\N
583511	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPLO Finances publiques - DGAC (art. 4 quinquiès)	PPLO Finances publiques - DGAC (art. 4 quinquiès)	2021-09-13 15:00:00	2021-09-13 16:40:00	\N	\N	1	0	\N	\N
583513	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	58-2 2020 - Couverture mobile du territoire - Déplacement à Pau	58-2 2020 - Couverture mobile du territoire - Déplacement à Pau	2021-09-16 07:20:00	2021-09-16 21:15:00	\N	\N	2	0	\N	\N
583518	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL n° 535 (2020-2021) Adaptation droit UE domaine des transports - Mme BONO-VANDORME	PJL n° 535 (2020-2021) Adaptation droit UE domaine des transports - Mme BONO-VANDORME	2021-09-10 19:00:00	2021-09-10 19:30:00	\N	\N	1	0	\N	\N
583520	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 -  ENAP - DB	Contrôle 2020 -  ENAP - DB	2021-09-14 17:00:00	2021-09-14 17:45:00	\N	\N	1	0	\N	\N
583522	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Immobilier universitaire - DGESIP	Contrôle 2021 - Immobilier universitaire - DGESIP	2021-09-15 15:30:00	2021-09-15 17:00:00	\N	\N	1	0	\N	\N
583524	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Mineurs non accompagnés - Table ronde de conseils départementaux	\N	2021-09-15 15:00:00	2021-09-15 16:30:00	\N	\N	5	0	\N	\N
583525	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Protection des enfants - Table ronde d'organisations gérant des établissements ASE	\N	2021-09-14 11:00:00	2021-09-14 12:30:00	\N	\N	2	0	\N	\N
583526	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Protection des enfants - Audition de NEXEM	\N	2021-09-14 14:30:00	2021-09-14 15:15:00	\N	\N	2	0	\N	\N
583527	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Protection des enfants - Audition commune du COD3S et de l'ANDASS	\N	2021-09-14 15:15:00	2021-09-14 16:15:00	\N	\N	2	0	\N	\N
583528	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Protection des enfants - Audition de l'Asemblée des départements de France (AdF)	\N	2021-09-14 16:30:00	2021-09-14 17:15:00	\N	\N	3	0	\N	\N
583529	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Protection des enfants - Audition de l'ANPF	\N	2021-09-15 09:00:00	2021-09-15 09:45:00	\N	\N	1	0	\N	\N
512714	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2020-11-30 16:00:00	2020-11-30 17:30:00	\N	\N	3	0	\N	\N
512718	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2020-12-03 09:00:00	2020-12-03 11:00:00	\N	\N	4	0	\N	\N
521363	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL patrimoine sensoriel	\N	2021-01-08 10:00:00	2021-01-08 10:45:00	\N	\N	4	0	\N	\N
521368	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL patrimoine sensoriel	\N	2021-01-08 11:00:00	2021-01-08 11:45:00	\N	\N	1	0	\N	\N
521467	DELEGATION	AUCUNE	\N	\N	COLTER	TR associations élus actualité des collectivités ; Examen rapport sécurité intérieure	\N	2021-01-28 09:30:00	2021-01-28 12:00:00	\N	\N	29	0	\N	\N
521470	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Une convention et audition de Mme Saragosse	\N	2021-01-20 09:30:00	2021-01-20 12:30:00	2021-01-20 16:11:05	2021-01-20 17:04:22	36	0	\N	\N
521471	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de Mme Florence Parly	\N	2021-01-20 16:35:00	2021-01-20 18:45:00	2021-01-21 09:43:11	2021-01-21 10:15:39	28	0	\N	\N
521472	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2021-01-19 09:30:00	2021-01-19 13:00:00	\N	\N	42	0	\N	\N
521473	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Propriété immobilière	PPL Propriété immobilière	2021-01-19 14:30:00	2021-01-19 16:50:00	\N	\N	121	0	\N	\N
521475	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Accueil gens du voyage	PPL Accueil gens du voyage	2021-01-19 16:55:00	2021-01-19 19:10:00	\N	\N	112	0	\N	\N
521476	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL renforcer le droit à l'avortement	PPL renforcer le droit à l'avortement	2021-01-20 16:45:00	2021-01-20 18:15:00	\N	\N	107	0	\N	\N
521477	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL droits nouveaux dès dix-huit ans	PPL droits nouveaux dès dix-huit ans	2021-01-20 18:50:00	2021-01-20 20:40:00	\N	\N	78	0	\N	\N
521478	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL patrimoine sensoriel des campagnes françaises	PPL patrimoine sensoriel des campagnes françaises	2021-01-21 15:35:00	2021-01-21 16:10:00	\N	\N	42	0	\N	\N
521479	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL protéger les jeunes mineurs	PPL protéger les jeunes mineurs des crimes sexuels	2021-01-21 10:30:00	2021-01-21 13:00:00	\N	\N	95	0	\N	\N
521480	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL protéger les jeunes mineurs	PPL protéger les jeunes mineurs des crimes sexuels	2021-01-21 14:30:00	2021-01-21 15:35:00	\N	\N	56	0	\N	\N
521481	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2021-01-20 15:00:00	2021-01-20 16:25:00	\N	\N	214	0	\N	\N
521489	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	COM Audiovisuel public	Arte France	2021-01-14 17:30:00	2021-01-14 18:15:00	\N	\N	3	0	\N	\N
521494	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	COM Audiovisuel public	Audition Radio France	2021-01-21 16:00:00	2021-01-21 17:00:00	\N	\N	2	0	\N	\N
521495	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	COM Audiovisuel public	Table ronde syndicats Radio France	2021-01-18 11:00:00	2021-01-18 12:15:00	\N	\N	2	0	\N	\N
521496	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	COM Audiovisuel public	SIRTI	2021-01-15 15:30:00	2021-01-15 16:30:00	\N	\N	0	0	\N	\N
521497	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	COM Audiovisuel public	Audition de l'INA	2021-01-15 16:30:00	2021-01-15 17:30:00	\N	\N	0	0	\N	\N
521498	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Antidopage	Agence du sport - Claude ONESTA	2021-01-14 14:00:00	2021-01-14 14:40:00	\N	\N	3	0	\N	\N
521499	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Antidopage	Régions de France - M. OMEYER	2021-01-14 15:00:00	2021-01-14 15:40:00	\N	\N	3	0	\N	\N
521501	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Antidopage	Fédérations sportives	2021-01-19 14:30:00	2021-01-19 16:00:00	\N	\N	5	0	\N	\N
521502	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Antidopage	Université Paris-Saclay	2021-01-19 16:00:00	2021-01-19 16:45:00	\N	\N	5	0	\N	\N
521513	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	GT Alimentation durable et locale	GT Alimentation durable et locale	2021-01-13 14:15:00	2021-01-13 15:00:00	\N	\N	3	0	\N	\N
521517	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	GT Alimentation durable et locale	GT Alimentation durable et locale	2020-11-04 14:00:00	2020-11-04 14:45:00	\N	\N	3	0	\N	\N
521841	GIA	AUCUNE	\N	\N	\N	Assemblée générale 2021	Assemblée générale de reconstitution du groupe	2021-01-14 11:00:00	2021-01-14 11:45:00	\N	\N	2	0	532	\N
521844	GIA	AUCUNE	\N	\N	\N	Assemblée générale 2021	Assemblée générale de reconstitution du groupe	2021-01-13 12:00:00	2021-01-13 13:00:00	\N	\N	21	0	622	\N
522817	GIA	AUCUNE	\N	\N	\N	Assemblée générale	Assemblée générale	2021-01-20 14:30:00	2021-01-20 14:55:00	\N	\N	6	0	851	\N
524115	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Renouvt Conseils départ. et régionaux	PJL Renouvt Conseils départ. et régionaux	2021-01-26 14:30:00	2021-01-26 19:10:00	\N	\N	174	0	\N	\N
524116	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Justice pénale des mineurs	PJL Justice pénale des mineurs	2021-01-26 19:20:00	2021-01-26 20:00:00	\N	\N	67	0	\N	\N
524117	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Justice pénale des mineurs	PJL Justice pénale des mineurs	2021-01-26 21:35:00	2021-01-27 00:30:00	\N	\N	49	0	\N	\N
524118	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2021-01-27 15:00:00	2021-01-27 16:20:00	\N	\N	199	0	\N	\N
524119	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Etat d'urgence sanitaire	PJL Etat d'urgence sanitaire	2021-01-27 16:30:00	2021-01-27 20:00:00	\N	\N	99	0	\N	\N
524121	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Etat d'urgence sanitaire	PJL Etat d'urgence sanitaire	2021-01-27 21:30:00	2021-01-27 22:15:00	\N	\N	51	0	\N	\N
524122	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Justice pénale des mineurs	PJL Justice pénale des mineurs	2021-01-27 22:20:00	2021-01-28 00:00:00	\N	\N	48	0	\N	\N
524129	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Union monétaire ouest-africaine	PJL Union monétaire ouest-africaine	2021-01-28 10:30:00	2021-01-28 12:15:00	\N	\N	31	0	\N	\N
528632	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL "Achmea"	PJL "Achmea"	2021-02-03 16:25:00	2021-02-03 17:30:00	\N	\N	1	0	\N	\N
532431	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	Auditions GT Alimentation durable et locale	Auditions GT Alimentation durable et locale	2021-02-16 15:00:00	2021-02-16 17:00:00	\N	\N	6	0	\N	\N
538911	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Respect des principes de la République	\N	2021-03-10 18:00:00	2021-03-10 19:00:00	\N	\N	2	0	\N	\N
539257	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Groupe de travail sur l'avenir de La Poste	Groupe de travail sur l'avenir de La Poste	2021-03-10 14:00:00	2021-03-10 15:00:00	\N	\N	3	0	\N	\N
539308	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Tourisme	GT Tourisme	2021-03-10 14:15:00	2021-03-10 15:00:00	\N	\N	7	0	\N	\N
539667	GIA	AUCUNE	\N	\N	\N	Audience de M. Jaroslaw Gowin,  Vice-président du Conseil des ministres Pologne	Audience de M. Jaroslaw Gowin,  Vice-président du Conseil des ministres, Ministre du développement, du travail et de la 	2021-03-11 17:00:00	2021-03-11 18:00:00	\N	\N	1	0	600	\N
539669	GIA	AUCUNE	\N	\N	\N	Visite officielle du Président de la République de Djibouti 	Visite officielle du Président de la République de Djibouti 	2021-02-11 12:45:00	2021-02-11 14:15:00	\N	\N	2	0	588	\N
555101	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Dérèglement climatique et résilience - Auditions de M. Pascal Martin	PJL Dérèglement climatique et résilience - Auditions de M. Pascal Martin	2021-04-22 18:15:00	2021-04-22 18:55:00	\N	\N	1	0	\N	\N
556458	ETUDES	AUCUNE	\N	\N	\N	Audition UDES	Audition UDES	2021-05-05 08:30:00	2021-05-05 09:30:00	\N	\N	9	0	\N	998
556468	ETUDES	AUCUNE	\N	\N	\N	Audition CNPF - Fransylva	Audition CNPF - Fransylva	2021-05-05 08:15:00	2021-05-05 09:25:00	\N	\N	14	0	\N	948
557744	GIA	AUCUNE	\N	\N	\N	Audition de M. Riester, en commun avec l'Assemblée nationale, sur le CETA	\N	2021-05-05 17:00:00	2021-05-05 18:00:00	\N	\N	2	0	583	\N
557810	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2021-05-06 09:00:00	2021-05-06 11:30:00	\N	\N	3	0	\N	\N
590567	BUREAU	AUCUNE	\N	\N	\N	Bureau du Sénat	Bureau du Sénat	2021-10-07 08:30:00	2021-10-07 11:00:00	\N	\N	21	0	\N	\N
590641	GIA	AUCUNE	\N	\N	\N	Déplacement en Slovénie du 28 septembre au 1er octobre 2021	Déplacement en Slovénie du 28 septembre au 1er octobre 2021	2021-09-28 08:00:00	2021-10-01 16:00:00	\N	\N	3	0	529	\N
590810	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT Puissance chinoise en Europe	\N	2021-09-22 11:30:00	2021-09-22 13:00:00	\N	\N	2	0	\N	\N
590813	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	\N	GT Puissance chinoise en Europe	2021-09-29 14:30:00	2021-09-29 15:45:00	\N	\N	2	0	\N	\N
590816	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2022 - Programme 178	\N	2021-10-05 14:00:00	2021-10-05 16:30:00	\N	\N	2	0	\N	\N
591742	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2021-10-20 09:00:00	2021-10-20 12:35:00	2021-10-20 16:04:04	2021-10-20 17:17:55	36	0	\N	\N
591805	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition Mme des Cars - PPL directeiur d'école amendements de séance	\N	2021-10-20 09:30:00	2021-10-20 11:31:00	2021-10-20 12:06:10	2021-10-20 17:17:56	38	1	\N	\N
592150	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Enseignement scolaire - Think-tanks/DGESCO	PLF pour 2022 - Enseignement scolaire - Think-tanks/DGESCO	2021-10-12 08:30:00	2021-10-12 11:15:00	\N	\N	1	0	\N	\N
592517	COM_PERMANENTE	AUTRE	\N	CAE	\N	\N	\N	2021-10-20 09:35:00	2021-10-20 12:25:00	2021-10-21 15:56:33	2021-10-21 15:56:45	44	1	\N	\N
592881	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition Mme des Cars - PPL directeiur d'école amendements de séance	\N	2021-10-20 09:30:00	2021-10-20 11:45:00	\N	\N	0	0	\N	\N
592898	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Ministère chargé des sports - Cabinet de la ministre déléguée en charge des Sports	\N	2021-10-13 16:30:00	2021-10-13 17:40:00	\N	\N	2	0	\N	\N
592902	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur  PJL Dialogue social avec les plateformes	\N	2021-10-13 13:30:00	2021-10-13 14:15:00	\N	\N	1	0	\N	\N
592904	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur PJL Dialogue social avec les plateformes	\N	2021-10-13 14:15:00	2021-10-13 15:00:00	\N	\N	1	0	\N	\N
592917	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur PJL Dialogue social avec les plateformes	\N	2021-10-14 09:00:00	2021-10-14 10:00:00	\N	\N	1	0	\N	\N
592918	DELEGATION	AUDRAP	\N	\N	206	Audition de rapporteur	\N	2021-10-14 10:10:00	2021-10-14 11:00:00	\N	\N	1	0	\N	\N
592930	DELEGATION	AUDRAP	\N	\N	206	Audition de rapporteur	\N	2021-10-14 11:00:00	2021-10-14 11:30:00	\N	\N	1	0	\N	\N
592942	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur - PLFSS 2022 - 1è partie	\N	2021-10-13 17:00:00	2021-10-13 18:00:00	\N	\N	1	0	\N	\N
592944	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur - PLFSS 2022 - 1è partie	\N	2021-10-13 18:00:00	2021-10-13 19:00:00	\N	\N	1	0	\N	\N
592948	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Responsabilité pénale et sécurité intérieure (amendements)	PJL Responsabilité pénale et sécurité intérieure (amendements)	2021-10-18 15:00:00	2021-10-18 15:45:00	2021-10-18 16:14:37	2021-10-19 11:04:42	12	0	\N	\N
592950	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Réforme de l'adoption (amendements)	PPL Réforme de l'adoption (amendements)	2021-10-20 10:30:00	2021-10-20 11:10:00	2021-10-20 17:01:06	2021-10-20 17:18:02	28	0	\N	\N
592995	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 21 octobre 2021	\N	2021-10-21 08:30:00	2021-10-21 10:00:00	2021-10-21 10:23:43	2021-10-21 18:34:56	15	0	\N	\N
593085	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 20 octobre 2021	\N	2021-10-20 13:45:00	2021-10-20 14:25:00	2021-10-20 14:32:45	2021-10-20 17:22:18	16	0	\N	\N
595453	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLC Respect des principes de la démocratie représentative	\N	2021-10-20 17:30:00	2021-10-20 18:30:00	\N	\N	2	0	\N	\N
595480	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2021-10-27 09:40:00	2021-10-27 12:35:00	2021-10-27 14:29:22	2021-10-27 19:08:44	29	0	\N	\N
600425	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2022 - Avis Outre-mer - Audition par Mme Micheline Jacques	PLF 2022 - Avis Outre-mer - Ministère des outre-mer (cabinet et direction générale) - Audition par Mme Micheline Jacques	2021-10-29 13:00:00	2021-10-29 14:00:00	\N	\N	1	0	\N	\N
603122	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLFR pour 2021 (2) - Examen du rapport et désignation CMP	PLFR pour 2021 (2) - Examen du rapport et désignation CMP	2021-11-16 09:05:00	2021-11-16 09:45:00	2021-11-16 10:22:50	2021-11-16 17:17:12	28	0	\N	\N
603124	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2022 : Missions «Cohésion des territoires»«Médias»«Culture»et«RES»	PLF pour 2022 : Missions «Cohésion des territoires»«Médias»«Culture»et«RES»	2021-11-16 15:45:00	2021-11-16 18:30:00	2021-11-16 19:15:14	2021-11-19 19:32:22	36	0	\N	\N
603130	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLFR pour 2021 (2) - Examen des amendements de séance	PLFR pour 2021 (2) - Examen des amendements de séance	2021-11-17 14:00:00	2021-11-17 14:35:00	2021-11-17 16:41:55	2021-11-19 19:32:17	20	0	\N	\N
603131	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF 2022 Avis Politique des territoires - Audition DGCL	PLF 2022 Avis Politique des territoires - Audition DGCL	2021-11-09 14:30:00	2021-11-09 15:45:00	\N	\N	1	0	\N	\N
603132	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF 2022 Avis Politique des territoires - Audition DMAT	PLF 2022 Avis Politique des territoires - Audition DMAT	2021-11-08 18:15:00	2021-11-08 19:00:00	\N	\N	1	0	\N	\N
603133	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2022 : Mission «APD»-missions réservées-Examen définitif Équilibre et dés. CMP	PLF pour 2022 : Mission «APD»-missions réservées-Examen définitif Équilibre et dés. CMP	2021-11-18 10:05:00	2021-11-18 11:40:00	2021-11-18 13:42:57	2021-11-19 19:32:14	27	0	\N	\N
603144	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2022 - Examen des amendements de séance sur la première partie	PLF pour 2022 - Examen des amendements de séance sur la première partie	2021-11-19 13:30:00	2021-11-19 14:15:00	2021-11-19 14:51:39	2021-11-19 19:32:13	21	0	\N	\N
603198	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PJLF 2022 - Participations financières de l'État - Mme Berthet	Auditions PJLF 2022 - Participations financières de l'État - Mme Berthet	2021-11-05 16:00:00	2021-11-05 17:00:00	\N	\N	1	0	\N	\N
603201	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2022 Travail et emploi - Audition de la DGT	\N	2021-11-10 13:00:00	2021-11-10 14:00:00	\N	\N	2	0	\N	\N
603355	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Rapport général - CPME	PLF pour 2022 - Rapport général - CPME	2021-11-09 17:40:00	2021-11-09 18:10:00	\N	\N	1	0	\N	\N
603357	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Économie - ARCEP	PLF pour 2022 - Économie - ARCEP	2021-11-09 10:00:00	2021-11-09 11:00:00	\N	\N	2	0	\N	\N
603360	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - MIRES - TR Enseignement privé	PLF pour 2022 - MIRES - TR Enseignement privé	2021-11-09 14:30:00	2021-11-09 16:00:00	\N	\N	1	0	\N	\N
603362	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - MIRES - CPU	PLF pour 2022 - MIRES - CPU	2021-11-10 14:15:00	2021-11-10 15:00:00	\N	\N	1	0	\N	\N
603365	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2022 Travail et emploi - Audition de la DGEFP	\N	2021-11-10 14:00:00	2021-11-10 15:00:00	\N	\N	2	0	\N	\N
603369	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Cohésion des territoires - Logement-Urbanisme - Fond. Abbé Pierre/FPI	PLF pour 2022 - Cohésion des territoires - Logement-Urbanisme - Fond. Abbé Pierre/FPI	2021-11-10 16:30:00	2021-11-10 18:30:00	\N	\N	1	0	\N	\N
516820	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Sécurité globale	PPL Sécurité globale	2020-12-08 14:00:00	2020-12-08 16:00:00	\N	\N	5	0	\N	\N
516826	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Sécurité globale	PPL Sécurité globale	2020-12-08 16:00:00	2020-12-08 17:00:00	\N	\N	7	0	\N	\N
516834	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Sécurité globale	PPL Sécurité globale	2020-12-08 17:00:00	2020-12-08 18:00:00	\N	\N	2	0	\N	\N
516837	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Sécurité globale	PPL Sécurité globale	2020-12-08 18:00:00	2020-12-08 19:00:00	\N	\N	3	0	\N	\N
516841	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Sécurité globale	PPL Sécurité globale	2020-12-08 19:00:00	2020-12-08 20:00:00	\N	\N	5	0	\N	\N
516847	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Sécurité globale	PPL Sécurité globale	2020-12-09 11:00:00	2020-12-09 12:00:00	\N	\N	3	0	\N	\N
516851	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Sécurité globale	PPL Sécurité globale	2020-12-09 14:00:00	2020-12-09 15:00:00	\N	\N	2	0	\N	\N
516856	GIA	AUCUNE	\N	\N	\N	Réunion constitutive et audition ambassadeur Pierre Duquesne	Réunion constitutive et audition ambassadeur Pierre Duquesne	2020-12-09 13:30:00	2020-12-09 14:45:00	\N	\N	18	0	597	\N
518947	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Blackout énergétique	Débat Blackout énergétique	2021-01-12 14:30:00	2021-01-12 16:00:00	\N	\N	96	0	\N	\N
603054	COM_PERMANENTE	AUTRE	\N	AFCL	\N	PLF 2022 - avis Audiovisuel, livres et Jeunesse	\N	2021-11-17 09:00:00	2021-11-17 11:15:00	2021-11-17 11:45:40	2021-11-19 19:32:18	39	2	\N	\N
603129	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2022 : Missions «Écologie» et «Relations avec les collectivités territoriales»	PLF pour 2022 : Missions «Écologie» et «Relations avec les collectivités territoriales»	2021-11-17 09:05:00	2021-11-17 12:15:00	2021-11-17 14:03:40	2021-11-19 19:32:18	41	0	\N	\N
518948	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Montagne	Débat Montagne	2021-01-12 16:00:00	2021-01-12 17:45:00	\N	\N	94	0	\N	\N
518949	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Empreinte environnementale	PPL Empreinte environnementale	2021-01-12 17:50:00	2021-01-12 20:00:00	\N	\N	84	0	\N	\N
518950	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Empreinte environnementale	PPL Empreinte environnementale	2021-01-12 21:30:00	2021-01-13 00:20:00	\N	\N	56	0	\N	\N
518951	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2021-01-13 15:00:00	2021-01-13 16:30:00	\N	\N	231	0	\N	\N
518952	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Pollutions des sols	Débat Pollutions des sols	2021-01-13 16:45:00	2021-01-13 18:25:00	\N	\N	67	0	\N	\N
518953	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Illectronisme	Débat Illectronisme	2021-01-13 18:25:00	2021-01-13 20:00:00	\N	\N	43	0	\N	\N
518954	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat EDF - Projet Hercule	Débat EDF - Projet Hercule	2021-01-13 20:20:00	2021-01-13 21:55:00	\N	\N	29	0	\N	\N
523928	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PPL Cartes communales	\N	2021-01-20 08:15:00	2021-01-20 09:15:00	\N	\N	1	0	\N	\N
523932	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PPL Cartes communales	\N	2021-01-20 11:00:00	2021-01-20 12:30:00	\N	\N	1	0	\N	\N
523934	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PPL Cartes communales	\N	2021-01-20 14:00:00	2021-01-20 14:45:00	\N	\N	1	0	\N	\N
524036	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Améliorer le système de santé par la confiance et la simplification	Audition rapporteur - Améliorer le système de santé par la confiance et la simplification	2021-01-21 10:40:00	2021-01-21 12:30:00	\N	\N	4	0	\N	\N
524041	DELEGATION	AUCUNE	\N	\N	211	Table ronde sur la santé des femmes dans les territoires ruraux	Table ronde sur la santé des femmes dans les territoires ruraux	2021-01-28 08:30:00	2021-01-28 11:15:00	\N	\N	17	0	\N	\N
524042	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Améliorer le système de santé par la confiance et la simplification	\tAudition rapporteur - Commission des affaires sociales - Améliorer le système de santé par la confiance et la simplific	2021-01-21 14:30:00	2021-01-21 16:00:00	\N	\N	4	0	\N	\N
524068	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Prorogation de l'état d'urgence sanitaire (rapport) - PJL Renouv. conseils (amdts)	PJL Prorogation de l'état d'urgence sanitaire (rapport) - PJL Renouv. conseils (amdts)	2021-01-26 09:00:00	2021-01-26 10:15:00	2021-01-29 10:55:43	2021-01-29 10:58:36	34	0	\N	\N
524069	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Code de la justice pénale des mineurs (amendements de séance)	PJL Code de la justice pénale des mineurs (amendements de séance)	2021-01-26 14:00:00	2021-01-26 14:15:00	2021-01-26 14:34:43	2021-01-26 18:25:29	22	0	\N	\N
524071	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Principes de la République - Audition de représentants de culte	PJL Principes de la République - Audition de représentants de culte	2021-01-27 10:00:00	2021-01-27 12:20:00	2021-01-27 14:56:02	2021-01-27 15:51:06	38	0	\N	\N
524073	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen rapport et texte PJL 688 Accord France-Monaco et Examen Motion texte 290 UM O-A	Examen rapport et texte PJL 688 Accord France-Monaco et Examen Motion texte 290 UM ouest-africaine	2021-01-26 14:05:00	2021-01-26 14:25:00	2021-01-26 19:44:27	2021-01-27 15:51:00	29	0	\N	\N
524074	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Prorogation de l'état d'urgence sanitaire (amendements de séance)	PJL Prorogation de l'état d'urgence sanitaire (amendements de séance)	2021-01-27 18:05:00	2021-01-27 18:20:00	2021-01-27 18:38:53	2021-01-28 18:27:08	17	0	\N	\N
524076	COM_PERMANENTE	AUTRE	\N	FINC	\N	Communication de M. Claude RAYNAL - Examen rapport et texte PJL ressources propres UE	Communication de M. Claude RAYNAL - Examen rapport et texte PJL ressources propres UE	2021-01-27 09:05:00	2021-01-27 10:30:00	2021-01-27 10:41:12	2021-01-27 15:51:02	36	0	\N	\N
524077	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de M. François VILLEROY de GALHAU, gouverneur de la Banque de France	Audition de M. François VILLEROY de GALHAU, gouverneur de la Banque de France	2021-01-27 11:05:00	2021-01-27 13:05:00	2021-01-27 15:24:52	2021-01-27 15:51:08	35	0	\N	\N
524078	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de M. Bruno LE MAIRE  mise en oeuvre mesures de soutien et relance économie	Audition de M. Bruno LE MAIRE sur la mise en oeuvre des mesures de soutien et de relance de l¿économie	2021-01-27 16:30:00	2021-01-27 18:15:00	2021-01-27 18:36:20	2021-01-28 18:27:07	29	0	\N	\N
524086	ETUDES	AUTRE	\N	\N	\N	Audition de MM. Chaussade et Marion	\N	2021-01-21 14:30:00	2021-01-21 15:45:00	\N	\N	9	0	\N	922
524096	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition plénière	\N	2021-01-27 09:30:00	2021-01-27 11:05:00	2021-01-27 11:05:36	2021-01-27 15:51:03	35	0	\N	\N
524097	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PPL Cartes communales	\N	2021-01-21 16:15:00	2021-01-21 17:20:00	\N	\N	1	0	\N	\N
524207	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière - Audition du Pr Jean-François Delfraissy	Réunion plénière - Audition du Pr Jean-François Delfraissy	2021-01-28 18:05:00	2021-01-28 19:55:00	\N	\N	23	0	\N	\N
526405	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Bertrand LORTHOLARY, Directeur Asie au Ministère des Affaires étrangères	\N	2021-01-28 11:00:00	2021-01-28 12:30:00	\N	\N	7	0	584	\N
528657	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition conjointe sur la Soutenabilité de la dette publique	Audition conjointe sur la Soutenabilité de la dette publique	2021-02-10 10:30:00	2021-02-10 13:00:00	2021-02-10 13:34:26	2021-02-10 17:51:35	40	0	\N	\N
528669	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition FIB	Audition FIB	2021-02-03 10:00:00	2021-02-03 10:45:00	\N	\N	5	0	\N	\N
528670	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Fédération nationale du bois	Audition Fédération nationale du bois	2021-02-03 10:45:00	2021-02-03 11:15:00	\N	\N	3	0	\N	\N
528696	COM_PERMANENTE	AUDRAP	\N	CAE	\N	FNCCR	\N	2021-02-02 15:30:00	2021-02-02 16:30:00	\N	\N	2	0	\N	\N
528697	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition ANAH	Audition ANAH	2021-02-03 11:00:00	2021-02-03 12:00:00	\N	\N	3	0	\N	\N
528698	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Afhypac	Audition Afhypac	2021-02-03 12:15:00	2021-02-03 13:20:00	\N	\N	1	0	\N	\N
528705	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Diverses mesures de justice sociale	\N	2021-02-03 17:30:00	2021-02-03 18:20:00	\N	\N	1	0	\N	\N
528706	ETUDES	AUTRE	\N	\N	\N	Audition Georges Walter	\N	2021-02-03 08:30:00	2021-02-03 09:25:00	\N	\N	12	0	\N	922
528772	ETUDES	AUTRE	\N	\N	\N	Réunion constitutive	Réunion constitutive	2021-02-04 09:30:00	2021-02-04 10:00:00	\N	\N	23	0	\N	1008
528819	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Financement de la recherche biomédicale en France - SANOFI	Contrôle 2021 - Financement de la recherche biomédicale en France - SANOFI	2021-02-03 19:30:00	2021-02-03 20:30:00	\N	\N	1	0	\N	\N
528835	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur - Conseil national du numérique	\N	2021-02-02 15:30:00	2021-02-02 16:30:00	\N	\N	2	0	\N	\N
583530	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Protection des enfants - Audition de la HAS	\N	2021-09-15 09:45:00	2021-09-15 10:30:00	\N	\N	1	0	\N	\N
583531	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Protection des enfants - Audition du SNMPMI	\N	2021-09-15 15:00:00	2021-09-15 15:45:00	\N	\N	2	0	\N	\N
583532	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Protection des enfants - Audition de l'ADMIE	\N	2021-09-15 15:45:00	2021-09-15 16:30:00	\N	\N	3	0	\N	\N
583533	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Protection des enfants - Audition de l'AFMJF	\N	2021-09-15 16:45:00	2021-09-15 17:30:00	\N	\N	3	0	\N	\N
583534	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Protection des enfants - Audition de la CNPR	\N	2021-09-16 09:45:00	2021-09-16 10:30:00	\N	\N	3	0	\N	\N
583535	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Protection des enfants - Audition commune du CVM et de la SFPML	\N	2021-09-16 10:45:00	2021-09-16 11:45:00	\N	\N	3	0	\N	\N
583536	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Protection des enfants - Table ronde Gouvernance de la protection de l'enfance	\N	2021-09-16 14:00:00	2021-09-16 15:30:00	\N	\N	1	0	\N	\N
583537	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Protection des enfants - Audition de juges des enfants	\N	2021-09-16 09:00:00	2021-09-16 09:45:00	\N	\N	2	0	\N	\N
583547	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Protection des enfants - Audition du CNB	\N	2021-09-14 17:15:00	2021-09-14 18:30:00	\N	\N	2	0	\N	\N
583689	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Réforme de l'encadrement supérieur de la fonction publique de l'État	\N	2021-09-20 15:00:00	2021-09-20 16:30:00	\N	\N	1	0	\N	\N
584611	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2021-09-15 15:30:00	2021-09-15 18:35:00	\N	\N	3	0	\N	\N
585491	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2021-09-22 15:00:00	2021-09-22 18:00:00	\N	\N	3	0	\N	\N
585495	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLO Implantation locale des parlementaires	\N	2021-09-22 16:30:00	2021-09-22 18:30:00	\N	\N	1	0	\N	\N
585730	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPLO et PPL Gestion des finances publiques	PPLO et PPL Gestion des finances publiques	2021-09-27 16:00:00	2021-09-27 20:00:00	\N	\N	40	0	\N	\N
585734	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPLO Gestion des finances publiques	PPLO Gestion des finances publiques	2021-09-27 21:30:00	2021-09-28 22:55:00	\N	\N	43	0	\N	\N
585741	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPLO et PPL Financement de la SS	PPLO et PPL Financement de la SS	2021-09-27 23:00:00	2021-09-28 00:30:00	\N	\N	28	0	\N	\N
585744	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2021-09-28 09:30:00	2021-09-28 12:30:00	\N	\N	38	0	\N	\N
585747	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPLO et PPL Financement de la SS	PPLO et PPL Financement de la SS	2021-09-28 14:30:00	2021-09-28 17:15:00	\N	\N	114	0	\N	\N
585749	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL et PJLO Institution judiciaire	PJL et PJLO Institution judiciaire	2021-09-28 17:25:00	2021-09-28 20:00:00	\N	\N	96	0	\N	\N
585751	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Institution judiciaire	PJL Institution judiciaire	2021-09-28 21:30:00	2021-09-29 00:30:00	\N	\N	65	0	\N	\N
585752	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2021-09-29 15:00:00	2021-09-29 16:20:00	\N	\N	230	0	\N	\N
585753	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Institution judiciaire	PJL Institution judiciaire	2021-09-29 16:40:00	2021-09-29 20:00:00	\N	\N	74	0	\N	\N
585755	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Institution judiciaire	PJL Institution judiciaire	2021-09-29 21:30:00	2021-09-30 00:25:00	\N	\N	51	0	\N	\N
585756	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJLO Institution judiciaire	PJLO Institution judiciaire	2021-09-29 00:15:00	2021-09-30 00:30:00	\N	\N	33	0	\N	\N
585759	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Maltraitance animale	PPL Maltraitance animale	2021-09-30 10:30:00	2021-09-30 12:55:00	\N	\N	59	0	\N	\N
585762	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Maltraitance animale	PPL Maltraitance animale	2021-09-30 14:30:00	2021-09-30 19:50:00	\N	\N	55	0	\N	\N
585806	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Convention protocole de Göteborg	\N	2021-09-23 10:00:00	2021-09-23 11:00:00	\N	\N	1	0	\N	\N
585808	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Convention protocole de Göteborg	\N	2021-09-23 16:30:00	2021-09-23 17:15:00	\N	\N	1	0	\N	\N
585810	MISSION	AUCUNE	\N	UBER	\N	\N	\N	2021-09-29 11:30:00	2021-09-29 12:30:00	2021-10-04 12:29:37	2021-10-06 15:18:02	13	0	\N	\N
585811	QUESTURE	AUCUNE	\N	\N	\N	Réunion de Questure	Réunion de Questure	2021-09-23 14:45:00	2021-09-23 15:45:00	\N	\N	3	0	\N	\N
585816	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2022 - Programme 185	\N	2021-09-22 14:00:00	2021-09-22 15:00:00	\N	\N	1	0	\N	\N
585818	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2022 - Programme 185	\N	2021-09-23 09:30:00	2021-09-23 12:15:00	\N	\N	2	0	\N	\N
585821	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI « Sécurité à Mayotte »	Audition rapporteur - MI « Sécurité à Mayotte »	2021-09-14 17:30:00	2021-09-14 18:30:00	\N	\N	3	0	\N	\N
587383	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteurs : CGT Police aux Frontières - Roissy et Le Bourget	Audition rapporteurs : CGT Police aux Frontières -(M. Simon LAPLACE)	2021-09-27 10:00:00	2021-09-27 11:00:00	\N	\N	2	0	\N	\N
589034	DELEGATION	AUDRAP	\N	\N	206	Audition de rapporteur	\N	2021-10-14 11:30:00	2021-10-14 12:20:00	\N	\N	1	0	\N	\N
590925	GIA	AUCUNE	\N	\N	\N	Accueil du Juriste Michael van Walt van Praag	Accueil du Juriste Michael van Walt van Praag	2021-10-05 14:00:00	2021-10-05 15:30:00	\N	\N	2	0	634	\N
606771	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Commémoration de la répression d'Algériens le 17 octobre 1961	Audition rapporteur - PPL Commémoration de la répression d'Algériens le 17 octobre 1961	2021-11-22 10:05:00	2021-11-22 12:15:00	\N	\N	1	0	\N	\N
606773	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Commémoration de la répression d'Algériens le 17 octobre 1961	Audition rapporteur - PPL Commémoration de la répression d'Algériens le 17 octobre 1961	2021-11-22 14:30:00	2021-11-22 15:30:00	\N	\N	1	0	\N	\N
609606	GIA	AUCUNE	\N	\N	\N	Rencontre avec une délégation du bureau exécutif de lutte contre le blanchiment d'argent e	\N	2021-12-01 14:00:00	2021-12-01 15:00:00	\N	\N	4	0	661	\N
609888	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Mauricio Vargas, ambassadeur de Colombie en France	\N	2021-12-01 13:00:00	2021-12-01 15:00:00	\N	\N	2	0	979	\N
506666	DELEGATION	AUCUNE	\N	\N	206	Entretien, en visioconférence, avec M. Jean-Brice Dumont, vice-président exécutif Ingénier	Entretien, en visioconférence, avec M. Jean-Brice Dumont, vice-président exécutif Ingénierie groupe Airbus           	2020-11-24 09:00:00	2020-11-24 11:00:00	\N	\N	0	0	\N	\N
506668	DELEGATION	AUCUNE	\N	\N	206	Entretien, en visioconférence, avec M. Bernard Laponche (Global Chance)	Entretien, en visioconférence, avec M. Bernard Laponche (Global Chance)	2020-11-26 09:30:00	2020-11-26 11:05:00	\N	\N	12	0	\N	\N
506669	DELEGATION	AUCUNE	\N	\N	206	Rencontre Office-Académies sur le thème de la psychiatrie	Rencontre Office-Académies sur le thème de la psychiatrie	2020-12-02 08:30:00	2020-12-02 10:30:00	\N	\N	0	0	\N	\N
506679	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2020-11-18 14:05:00	2020-11-18 14:45:00	\N	\N	25	0	\N	\N
513758	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Sécurité globale	PPL Sécurité globale	2020-11-26 13:30:00	2020-11-26 16:20:00	\N	\N	2	0	\N	\N
513768	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Sécurité globale	PPL Sécurité globale	2020-12-02 14:00:00	2020-12-02 15:30:00	\N	\N	2	0	\N	\N
513773	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Sécurité globale	PPL Sécurité globale	2020-12-02 16:30:00	2020-12-02 17:30:00	\N	\N	4	0	\N	\N
513778	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Sécurité globale	PPL Sécurité globale	2020-12-03 10:50:00	2020-12-03 13:00:00	\N	\N	2	0	\N	\N
513781	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Sécurité globale	PPL Sécurité globale	2020-12-04 09:30:00	2020-12-04 11:00:00	\N	\N	2	0	\N	\N
514127	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLO Délais d'organisation des élections législatives et sénatoriales	\N	2020-12-03 18:30:00	2020-12-03 19:15:00	\N	\N	1	0	\N	\N
516132	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PLJLO PJL Délais organisation élections	CMP PLJLO PJL Délais organisation élections	2020-12-10 19:35:00	2020-12-10 20:15:00	\N	\N	16	0	\N	\N
518677	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI Restitution des oeuvres d'art	\N	2020-12-15 16:00:00	2020-12-15 17:00:00	\N	\N	5	0	\N	\N
521578	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Coinseil de Questure	2021-01-12 14:35:00	2021-01-12 16:35:00	\N	\N	3	0	\N	\N
521584	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Sécurité globale	PPL Sécurité globale	2021-01-12 15:00:00	2021-01-12 17:00:00	\N	\N	9	0	\N	\N
521594	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Sécurité globale	PPL Sécurité globale	2021-01-12 17:00:00	2021-01-12 18:00:00	\N	\N	4	0	\N	\N
521599	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Sécurité globale	PPL Sécurité globale	2021-01-13 16:30:00	2021-01-13 17:30:00	\N	\N	3	0	\N	\N
521603	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Sécurité globale	PPL Sécurité globale	2021-01-14 14:30:00	2021-01-14 15:30:00	\N	\N	1	0	\N	\N
523487	GIA	AUCUNE	\N	\N	\N	Entretien entre les présidents des groupes d'amitié France-Allemagne et France-Pologne	Entretien entre les présidents des groupes d'amitié France-Allemagne et France-Pologne	2021-01-13 14:00:00	2021-01-13 15:00:00	\N	\N	2	0	600	\N
523776	GIA	AUCUNE	\N	\N	\N	Audition de S.E.M. Anguel Tcholakov	Audition de S.E.M. Anguel Tcholakov	2021-01-13 18:30:00	2021-01-13 19:45:00	\N	\N	5	0	582	\N
526538	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Bioéthique 2e lect.	PJL Bioéthique 2e lect.	2021-02-02 14:30:00	2021-02-02 20:35:00	\N	\N	193	0	\N	\N
526539	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Bioéthique 2e lect.	PJL Bioéthique 2e lect.	2021-02-02 22:10:00	2021-02-03 00:30:00	\N	\N	120	0	\N	\N
526540	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2021-02-03 15:00:00	2021-02-03 16:20:00	\N	\N	212	0	\N	\N
526541	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Bioéthique 2e lect.	PJL Bioéthique 2e lect.	2021-02-03 16:30:00	2021-02-03 20:10:00	\N	\N	144	0	\N	\N
526542	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Bioéthique 2e lect.	PJL Bioéthique 2e lect.	2021-02-03 21:40:00	2021-02-04 01:40:00	\N	\N	85	0	\N	\N
526543	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Euratom	PJL Euratom	2021-02-04 10:30:00	2021-02-04 12:25:00	\N	\N	59	0	\N	\N
526544	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL France-Monaco	PJL France-Monaco	2021-02-04 12:25:00	2021-02-04 13:00:00	\N	\N	21	0	\N	\N
526545	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL NL Urgence sanitaire	PJL NL Urgence sanitaire	2021-02-04 14:35:00	2021-02-04 16:00:00	\N	\N	39	0	\N	\N
526547	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Bioéthique 2e lect.	PJL Bioéthique 2e lect.	2021-02-04 14:35:00	2021-02-04 20:05:00	\N	\N	0	0	\N	\N
527015	ETUDES	AUCUNE	\N	\N	\N	Réunion reconstitutive	Réunion reconstitutive	2021-02-02 13:45:00	2021-02-02 14:45:00	\N	\N	7	0	\N	912
536918	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI "Difficultés des entreprises et crise de la Covid-19"	Audition rapporteur - MI "Difficultés des entreprises et crise de la Covid-19"	2021-03-04 10:00:00	2021-03-04 10:45:00	\N	\N	2	0	\N	\N
536921	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI "Difficultés des entreprises et crise de la Covid-19"	Audition rapporteur - MI "Difficultés des entreprises et crise de la Covid-19"	2021-03-04 10:45:00	2021-03-04 11:30:00	\N	\N	2	0	\N	\N
536924	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI "Difficultés des entreprises et crise de la Covid-19"	Audition rapporteur - MI "Difficultés des entreprises et crise de la Covid-19"	2021-03-04 11:30:00	2021-03-04 12:30:00	\N	\N	2	0	\N	\N
536927	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI "Difficultés des entreprises et crise de la Covid-19"	Audition rapporteur - MI "Difficultés des entreprises et crise de la Covid-19"	2021-03-04 14:00:00	2021-03-04 15:00:00	\N	\N	2	0	\N	\N
536930	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI "Difficultés des entreprises et crise de la Covid-19"audition	Audition rapporteur - MI "Difficultés des entreprises et crise de la Covid-19"	2021-03-04 16:00:00	2021-03-04 17:00:00	\N	\N	2	0	\N	\N
540097	MISSION	AUCUNE	\N	VIETUDIA	\N	TR CPU, Univ Lorraine, Alliance Sorbonne Paris Cité	\N	2021-03-18 11:05:00	2021-03-18 12:15:00	2021-03-19 07:58:27	2021-03-19 16:03:18	14	0	\N	\N
542664	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Transport de marchandises - Réunion d'étape	MI Transport de marchandises - Réunion d'étape	2021-03-16 14:30:00	2021-03-16 15:30:00	\N	\N	10	0	\N	\N
542675	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Transport de marchandises - Groupe La Poste	MI Transport de marchandises - Groupe La Poste	2021-03-16 15:30:00	2021-03-16 16:30:00	\N	\N	8	0	\N	\N
542685	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Transport de marchandises - Association des maires de France	MI Transport de marchandises - Association des maires de France	2021-03-16 16:30:00	2021-03-16 17:15:00	\N	\N	5	0	\N	\N
549694	MISSION	AUCUNE	\N	ENSAGRIC	\N	MI EA - Audition association des directeurs d'EPLEFPA	\N	2021-04-07 13:30:00	2021-04-07 14:50:00	2021-04-07 18:10:41	2021-04-08 14:31:53	13	0	\N	\N
549789	COM_PERMANENTE	AUDRAP	\N	CAE	\N	France Stratégie	\N	2021-04-06 08:45:00	2021-04-06 09:30:00	\N	\N	1	0	\N	\N
549790	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MM. Kevin Beaubrun et Tristan-Pierre Maury	\N	2021-04-06 09:30:00	2021-04-06 10:15:00	\N	\N	2	0	\N	\N
557794	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT Boussole stratégique	\N	2021-05-03 15:00:00	2021-05-03 16:30:00	\N	\N	2	0	\N	\N
557818	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT Boussole stratégique	\N	2021-05-06 11:00:00	2021-05-06 12:00:00	\N	\N	2	0	\N	\N
557835	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2021-05-05 14:00:00	2021-05-05 14:55:00	\N	\N	23	0	\N	\N
558061	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Accès à certaines professions et maladies chroniques	\N	2021-05-10 10:00:00	2021-05-10 12:00:00	\N	\N	2	0	\N	\N
591617	ETUDES	AUTRE	\N	\N	\N	Audition ANMSM-ANEM-DSF	Audition ANMSM-ANEM-DSF	2021-10-12 16:00:00	2021-10-12 17:30:00	\N	\N	15	0	\N	918
591640	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Olympique Lyonnais	\N	2021-10-12 17:00:00	2021-10-12 18:00:00	\N	\N	4	0	\N	\N
591699	ETUDES	AUTRE	\N	\N	\N	Association nationale des élus du littoral (ANEL)	Association nationale des élus du littoral (ANEL)	2021-10-12 15:15:00	2021-10-12 16:00:00	\N	\N	13	0	\N	908
591701	ETUDES	AUTRE	\N	\N	\N	Union des ports de France (UPF)	Union des ports de France (UPF)	2021-10-12 16:15:00	2021-10-12 17:00:00	\N	\N	8	0	\N	908
597859	GIA	AUCUNE	\N	\N	\N	Exposition Paris-Athènes	Visite de l'exposition "Paris-Athènes, Naissance de la Grèce moderne" au musée du Louvre	2021-10-28 11:00:00	2021-10-28 12:45:00	\N	\N	5	0	591	\N
598656	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - BA CEA - FNAM	\N	2021-10-27 11:00:00	2021-10-27 12:30:00	\N	\N	1	0	\N	\N
598661	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Écologie - CRE	PLF pour 2022 - Écologie - CRE	2021-10-27 13:30:00	2021-10-27 14:30:00	\N	\N	1	0	\N	\N
598663	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Outre-mer - DB	PLF pour 2022 - Outre-mer - DB	2021-10-25 17:00:00	2021-10-25 18:30:00	\N	\N	2	0	\N	\N
598667	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Outre-mer - ACCIOM/FEOM	PLF pour 2022 - Outre-mer - ACCIOM/FEOM	2021-10-26 17:00:00	2021-10-26 18:30:00	\N	\N	2	0	\N	\N
598671	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Cohésion des territoires - TR associations d'élus	PLF pour 2022 - Cohésion des territoires - TR associations d'élus	2021-10-27 15:30:00	2021-10-27 16:45:00	\N	\N	1	0	\N	\N
598673	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Cohésion des territoires - ANCT	PLF pour 2022 - Cohésion des territoires - ANCT	2021-10-27 18:30:00	2021-10-27 19:30:00	\N	\N	1	0	\N	\N
598675	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF 2022 - Justice - DAP	PLF 2022 - Justice - DAP	2021-10-26 10:00:00	2021-10-26 11:00:00	\N	\N	1	0	\N	\N
598678	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF 2022 - Justice - DB	PLF 2022 - Justice - DB	2021-10-27 14:15:00	2021-10-27 15:00:00	\N	\N	1	0	\N	\N
598680	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF 2022 - Justice - CNB	PLF 2022 - Justice - CNB	2021-10-28 14:00:00	2021-10-28 14:30:00	\N	\N	1	0	\N	\N
598681	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF 2022 - Justice - SG MIN Justice	PLF 2022 - Justice - SG MIN Justice	2021-10-28 15:15:00	2021-10-28 16:15:00	\N	\N	1	0	\N	\N
598684	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Rapport Général - Paris Notaires	PLF pour 2022 - Rapport Général - Paris Notaires	2021-10-26 16:50:00	2021-10-26 17:25:00	\N	\N	1	0	\N	\N
598686	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Rapport général - FEPEM	PLF pour 2022 - Rapport général - FEPEM	2021-10-26 16:15:00	2021-10-26 16:50:00	\N	\N	1	0	\N	\N
598688	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Rapport général - UNIDEN	PLF pour 2022 - Rapport général - UNIDEN	2021-10-27 19:30:00	2021-10-27 20:15:00	\N	\N	1	0	\N	\N
598690	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Rapport général - Économiste énergie	PLF pour 2022 - Rapport général - Économiste énergie	2021-10-26 17:30:00	2021-10-26 18:40:00	\N	\N	1	0	\N	\N
598692	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Rapport général - DG Trésor	PLF pour 2022 - Rapport général - DG Trésor	2021-10-27 18:30:00	2021-10-27 19:30:00	\N	\N	1	0	\N	\N
598694	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - AGTE - DMAT	PLF pour 2022 - AGTE - DMAT	2021-10-15 18:30:00	2021-10-15 20:00:00	\N	\N	1	0	\N	\N
598696	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Économie - BpiFrance/La Poste/DGE/AVICCA/ANCT	PLF pour 2022 - Économie - BpiFrance/La Poste/DGE/AVICCA/ANCT	2021-10-26 14:00:00	2021-10-26 19:30:00	\N	\N	2	0	\N	\N
598699	DELEGATION	AUDRAP	\N	\N	COLTER	Audition de M Yves LE BRETON - ANCT	\N	2021-11-09 16:00:00	2021-11-09 17:00:00	\N	\N	0	0	\N	\N
598703	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Agriculture - DGPE	PLF pour 2022 - Agriculture - DGPE	2021-10-26 15:15:00	2021-10-26 17:00:00	\N	\N	2	0	\N	\N
598706	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Agriculture - SG MIN Agriculture	PLF pour 2022 - Agriculture - SG MIN Agriculture	2021-10-27 16:45:00	2021-10-27 17:45:00	\N	\N	2	0	\N	\N
505548	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL langues régionales	\N	2020-11-18 14:00:00	2020-11-18 15:00:00	\N	\N	4	0	\N	\N
598711	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Agriculture - DGAL	PLF pour 2022 - Agriculture - DGAL	2021-10-27 18:00:00	2021-10-27 19:00:00	\N	\N	2	0	\N	\N
599064	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - MIRES - CNOUS	PLF pour 2022 - MIRES - CNOUS	2021-10-26 10:15:00	2021-10-26 11:15:00	\N	\N	1	0	\N	\N
599066	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - IA - SGPI	PLF pour 2022 - IA - SGPI	2021-10-26 11:45:00	2021-10-26 12:30:00	\N	\N	1	0	\N	\N
599068	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - MIRES - HCERES	PLF pour 2022 - MIRES - HCERES	2021-10-26 14:00:00	2021-10-26 15:00:00	\N	\N	1	0	\N	\N
599070	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - MIRES - CEA	PLF pour 2022 - MIRES - CEA	2021-10-26 16:00:00	2021-10-26 17:00:00	\N	\N	1	0	\N	\N
599072	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - MIRES - DGRI/INRIA	PLF pour 2022 - MIRES - DGRI/INRIA	2021-10-27 17:00:00	2021-10-27 18:45:00	\N	\N	1	0	\N	\N
599074	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Défense - DGA	PLF pour 2022 - Défense - DGA	2021-10-27 11:00:00	2021-10-27 12:00:00	\N	\N	1	0	\N	\N
599076	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Écologie - Transports - AFITF	PLF pour 2022 - Écologie - Transports - AFITF	2021-11-02 09:45:00	2021-11-02 10:45:00	\N	\N	2	0	\N	\N
599366	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL  Accès foncier agricole	PPL  Accès foncier agricole	2021-11-03 22:00:00	2021-11-04 00:10:00	\N	\N	54	0	\N	\N
603327	GIA	AUCUNE	\N	\N	\N	Entretien avec Mme SHEIKH Hasina, ¨Première ministre du Bangladesh	Entretien avec Mme SHEIKH Hasina, PM du Bangladesh	2021-11-10 15:50:00	2021-11-10 17:00:00	\N	\N	11	0	609	\N
603339	GIA	AUCUNE	\N	\N	\N	Entretien avec une ONG en charge des Droits de l'Homme 	Entretien avec 4 représentants d'ONG Droits de l'Homme	2021-11-10 11:30:00	2021-11-10 12:10:00	\N	\N	1	0	617	\N
603342	GIA	AUCUNE	\N	\N	\N	Audition de Mme Laurence NARDON, IRIS	Audition de Mme Laurence NARDON, Chercheur à l'IRIS	2021-11-09 18:15:00	2021-11-09 19:15:00	\N	\N	6	0	590	\N
607520	GIA	AUCUNE	\N	\N	\N	Entretien sur le projet Terra Sancta Museum	Entretien avec la Fondation Amici Terrae Sanctae et Fondation Mansart	2021-11-24 10:00:00	2021-11-24 10:45:00	\N	\N	3	0	CHRETORIENT	CHRETORIENT
608508	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2021-11-30 09:30:00	2021-11-30 12:40:00	\N	\N	49	0	\N	\N
608510	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat contribution des politiques d'appui aux collectivités 	Débat contribution des politiques d'appui aux collectivités 	2021-11-30 14:30:00	2021-11-30 16:45:00	\N	\N	94	0	\N	\N
608513	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat action de la France enjeu environnemental	Débat action de la France enjeu environnemental	2021-11-30 16:50:00	2021-11-30 18:25:00	\N	\N	67	0	\N	\N
608514	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat perte de puissance économique de la France	Débat perte de puissance économique de la France	2021-11-30 18:35:00	2021-11-30 20:15:00	\N	\N	49	0	\N	\N
608515	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat action du Gouvernement en matière de justice	Débat action du Gouvernement en matière de justice	2021-11-30 21:45:00	2021-11-30 23:15:00	\N	\N	31	0	\N	\N
608516	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2021-12-01 15:00:00	2021-12-01 16:20:00	\N	\N	248	0	\N	\N
608518	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat situation dans les outre-mer	Débat situation dans les outre-mer	2021-12-01 16:35:00	2021-12-01 18:20:00	\N	\N	53	0	\N	\N
608521	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Éducation, jeunesse : quelles politiques 	Débat Éducation, jeunesse : quelles politiques 	2021-12-01 18:20:00	2021-12-01 19:55:00	\N	\N	40	0	\N	\N
608522	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Situation des comptes publics et réforme de l'État 	Débat Situation des comptes publics et réforme de l'État 	2021-12-01 21:30:00	2021-12-01 23:05:00	\N	\N	25	0	\N	\N
608559	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Table ronde avec les fédérations non olympiques	\N	2021-11-25 10:00:00	2021-11-25 11:30:00	\N	\N	2	0	\N	\N
608560	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Audition commune des services ministériels ESMS et sport-santé	\N	2021-11-24 16:45:00	2021-11-24 18:30:00	\N	\N	3	0	\N	\N
518866	GIA	AUCUNE	\N	\N	\N	Assemblée Générale 	Assemblée Générale	2020-12-15 12:45:00	2020-12-15 13:30:00	\N	\N	15	0	673	\N
519067	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Table ronde sur les projets de contrats d'objectifs et de moyens 	\N	2021-01-12 17:05:00	2021-01-12 19:23:00	2021-01-13 14:25:41	2021-01-13 14:39:37	28	0	\N	\N
528837	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur - la quatrature du net	\N	2021-02-02 16:30:00	2021-02-02 17:30:00	\N	\N	2	0	\N	\N
528843	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur - SGAE	\N	2021-02-03 16:30:00	2021-02-03 17:30:00	\N	\N	2	0	\N	\N
528961	MISSION	AUCUNE	\N	PAUP	\N	Audition plénière	\N	2021-02-09 14:30:00	2021-02-09 17:35:00	2021-02-10 17:43:10	2021-02-10 17:51:38	16	0	\N	\N
528964	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-02-10 09:30:00	2021-02-10 11:05:00	2021-02-10 12:06:37	2021-02-10 17:51:33	34	0	\N	\N
529002	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Justice de proximité et réponse pénale - PJLO Élection du Président de la République	PPL Justice de proximité et réponse pénale - PJLO Élection du Président de la République (rapports et textes)	2021-02-10 09:05:00	2021-02-10 10:35:00	2021-02-10 14:57:15	2021-02-10 17:51:32	37	0	\N	\N
529003	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Principes de la République - Audition de représentants de culte	PJL Principes de la République - Audition de représentants de culte	2021-02-10 10:45:00	2021-02-10 12:10:00	2021-02-10 14:57:49	2021-02-10 17:51:35	24	0	\N	\N
529006	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions	\N	2021-02-04 09:00:00	2021-02-04 12:00:00	\N	\N	0	0	\N	\N
529007	DELEGATION	AUCUNE	\N	\N	DSOM	Audition de l'AFD et de la Banque des territoires	\N	2021-02-11 09:00:00	2021-02-11 10:55:00	\N	\N	14	0	\N	\N
529009	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - FPIC - DGCL	Contrôle 2021 - FPIC - DGCL	2021-02-02 17:15:00	2021-02-02 20:00:00	\N	\N	2	0	\N	\N
529012	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-02-10 17:30:00	2021-02-10 19:30:00	\N	\N	0	0	\N	\N
529013	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2021-02-10 10:05:00	2021-02-10 12:10:00	2021-02-10 17:42:44	2021-02-10 17:51:34	41	0	\N	\N
529014	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur	\N	2021-02-04 10:00:00	2021-02-04 12:00:00	\N	\N	7	0	\N	\N
529043	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLO Élection du Président de la République	PJLO Élection du Président de la République	2021-02-04 09:00:00	2021-02-04 10:05:00	\N	\N	1	0	\N	\N
529044	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLO Élection du Président de la République	PJLO Élection du Président de la République	2021-02-04 10:05:00	2021-02-04 11:15:00	\N	\N	1	0	\N	\N
529045	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLO Élection du Président de la République	PJLO Élection du Président de la République	2021-02-04 11:15:00	2021-02-04 12:00:00	\N	\N	1	0	\N	\N
534219	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2021-02-16 14:35:00	2021-02-16 18:45:00	\N	\N	3	0	\N	\N
536824	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL respect de la dignité en détention	respect de la dignité en détention	2021-03-08 16:00:00	2021-03-08 18:55:00	\N	\N	24	0	\N	\N
536826	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2021-03-09 09:30:00	2021-03-09 12:35:00	\N	\N	36	0	\N	\N
536827	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL monde combattant	PPL relative au monde combattant	2021-03-09 14:30:00	2021-03-09 15:25:00	\N	\N	80	0	\N	\N
536828	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL diverses mesures de justice sociale 	PPL diverses mesures de justice sociale 	2021-03-09 15:30:00	2021-03-09 17:45:00	\N	\N	97	0	\N	\N
536829	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2021-03-10 15:00:00	2021-03-10 16:15:00	\N	\N	222	0	\N	\N
536830	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL service public d'eau potable Guadeloupe 	PPL service public d'eau potable et d'assainissement en Guadeloupe 	2021-03-10 16:30:00	2021-03-10 18:25:00	\N	\N	79	0	\N	\N
536831	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL directeur d'école	PPL directeur d'école	2021-03-10 18:30:00	2021-03-10 20:30:00	\N	\N	70	0	\N	\N
536832	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL mourir dans la dignité	PPL mourir dans la dignité	2021-03-11 10:30:00	2021-03-11 13:15:00	\N	\N	102	0	\N	\N
536833	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL lutter contre le plastique	PPL lutter contre le plastique	2021-03-11 14:45:00	2021-03-11 15:55:00	\N	\N	49	0	\N	\N
536834	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL vignette « collection » 	PPL vignette « collection » 	2021-03-11 16:00:00	2021-03-11 17:20:00	\N	\N	41	0	\N	\N
536835	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL lutter contre les fraudes sociales	PPL lutter contre les fraudes sociales	2021-03-11 17:20:00	2021-03-11 19:20:00	\N	\N	42	0	\N	\N
536836	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP élection du Président de la République	CMP élection du Président de la République	2021-03-11 19:20:00	2021-03-11 20:15:00	\N	\N	19	0	\N	\N
536837	COM_PERMANENTE	AUTRE	\N	ETRD	\N	2 conventions et audition E. Trappier, Pdg de Dassault Aviation	\N	2021-03-10 09:45:00	2021-03-10 11:30:00	2021-03-10 15:58:43	2021-03-10 17:12:02	37	0	\N	\N
536853	GIA	AUCUNE	\N	\N	\N	\N	\N	2021-03-05 10:30:00	2021-03-05 11:30:00	\N	\N	1	0	613	\N
537787	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	MI Difficultés des entreprises et covid-19 - Déplacement à Lille	MI Difficultés des entreprises et covid-19 - Déplacement à Lille	2021-03-01 07:00:00	2021-03-01 19:00:00	\N	\N	2	0	\N	\N
538123	MISSION	AUCUNE	\N	CONF	\N	Table ronde "Festivals"	\N	2021-03-18 11:00:00	2021-03-18 12:30:00	2021-03-18 14:34:21	2021-03-18 17:53:09	9	0	\N	\N
543574	GIA	AUCUNE	\N	\N	\N	Audition de l'Ambassadeur de Roumanie en France	\N	2021-03-23 16:00:00	2021-03-23 17:00:00	\N	\N	6	0	605	\N
545159	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Respect des principes de la République (amendements de séance)	PJL Respect des principes de la République (amendements de séance)	2021-03-30 09:05:00	2021-03-30 10:30:00	2021-03-30 11:42:27	2021-03-30 16:53:33	32	0	\N	\N
545160	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Formation des élus locaux (rapport et texte) - PJL Respect des principes (suite)	PJL Formation des élus locaux (rapport et texte) - PJL Respect des principes (suite)	2021-03-31 09:00:00	2021-03-31 12:25:00	2021-03-31 16:03:01	2021-03-31 18:03:12	37	0	\N	\N
545161	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Respect des principes de la République (amendements de séance, suite)	PJL Respect des principes de la République (amendements de séance, suite)	2021-03-31 14:00:00	2021-03-31 14:50:00	2021-03-31 16:03:09	2021-03-31 18:03:08	16	0	\N	\N
545287	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Négociation collective - Audition de la CGT	\N	2021-03-23 10:00:00	2021-03-23 11:00:00	\N	\N	2	0	\N	\N
545288	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Négociation collective - Audition de FO	\N	2021-03-24 13:00:00	2021-03-24 14:00:00	\N	\N	1	0	\N	\N
545290	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Négociation collective - Audition de la CFE-CGC	\N	2021-03-24 14:00:00	2021-03-24 15:00:00	\N	\N	2	0	\N	\N
545330	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2021-03-31 09:00:00	2021-03-31 09:20:00	2021-03-31 10:13:06	2021-03-31 18:03:12	34	0	\N	\N
545331	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition plénière 	Audition plénière 	2021-03-31 09:30:00	2021-03-31 12:10:00	2021-03-31 15:04:42	2021-03-31 18:03:09	38	0	\N	\N
545393	MISSION	AUDRAP	\N	VIETUDIA	\N	audition M. Canivenc DTGE	\N	2021-03-29 09:30:00	2021-03-29 10:51:00	\N	\N	4	0	\N	\N
545394	MISSION	AUDRAP	\N	VIETUDIA	\N	audition M. Maxime Renault (BNEI)	\N	2021-03-29 11:04:00	2021-03-29 11:56:00	\N	\N	4	0	\N	\N
545395	MISSION	AUDRAP	\N	VIETUDIA	\N	audition M. .Merisse (UNEDESEP)	\N	2021-03-29 11:59:00	2021-03-29 12:52:00	\N	\N	2	0	\N	\N
545397	MISSION	AUTRE	\N	VIETUDIA	\N	Table ronde logement étudiant	\N	2021-03-29 15:00:00	2021-03-29 17:30:00	\N	\N	0	0	\N	\N
545438	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur - commission européenne (DSA/DMA)	\N	2021-03-24 16:30:00	2021-03-24 17:30:00	\N	\N	2	0	\N	\N
545440	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur - commission européenne (DSA/DMA)	\N	2021-03-24 17:30:00	2021-03-24 18:45:00	\N	\N	2	0	\N	\N
545466	MISSION	AUDRAP	\N	EGALCHAN	\N	Table ronde de sociologues spécialistes de la jeunesse	\N	2021-03-23 16:30:00	2021-03-23 18:15:00	\N	\N	4	0	\N	\N
545467	MISSION	AUDRAP	\N	EGALCHAN	\N	MI Égalité des chances - Audition de l'INJEP	\N	2021-03-25 13:30:00	2021-03-25 14:45:00	\N	\N	2	0	\N	\N
589642	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2021 - CERT - Déplacement à Lille	Contrôle 2021 - CERT - Déplacement à Lille	2021-10-05 08:45:00	2021-10-05 15:45:00	\N	\N	1	0	\N	\N
589646	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Rapport et texte commission  PPl footbal - 5 mai	\N	2021-10-06 09:35:00	2021-10-06 10:45:00	2021-10-06 16:05:24	2021-10-06 16:05:34	30	0	\N	\N
589756	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Médias, Livre et industries culturelles - AFP	PLF pour 2022 - Médias, Livre et industries culturelles - AFP	2021-10-04 10:00:00	2021-10-04 10:30:00	\N	\N	1	0	\N	\N
589758	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Médias, Livre et industries culturelles - CNC	PLF pour 2022 - Médias, Livre et industries culturelles - CNC	2021-10-04 11:30:00	2021-10-04 12:15:00	\N	\N	1	0	\N	\N
589760	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Médias, Livre et industries culturelles - Radio France	PLF pour 2022 - Médias, Livre et industries culturelles - Radio France	2021-10-04 15:15:00	2021-10-04 16:10:00	\N	\N	1	0	\N	\N
589762	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Culture - DGCA	PLF pour 2022 - Culture - DGCA	2021-10-05 14:40:00	2021-10-05 15:30:00	\N	\N	1	0	\N	\N
589764	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Culture - OPPIC	PLF pour 2022 - Culture - OPPIC	2021-10-05 16:30:00	2021-10-05 17:30:00	\N	\N	2	0	\N	\N
589767	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Financement aires protégées - Mission Inspection générale	Contrôle 2021 - Financement aires protégées - Mission Inspection générale	2021-10-04 09:30:00	2021-10-04 10:30:00	\N	\N	1	0	\N	\N
589769	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n° 325 Catastrophes naturelles - DG Trésor	PPL n° 325 Catastrophes naturelles - DG Trésor	2021-10-04 08:45:00	2021-10-04 09:30:00	\N	\N	1	0	\N	\N
589771	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n° 325 Catastrophes naturelles - DGSCGC	PPL n° 325 Catastrophes naturelles - DGSCGC	2021-10-04 17:00:00	2021-10-04 17:45:00	\N	\N	1	0	\N	\N
589813	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Foncier agricole - Drouot avocats	PPL Foncier agricole - Drouot avocats	2021-10-06 12:00:00	2021-10-06 13:00:00	\N	\N	2	0	\N	\N
590298	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur - PJL Travailleurs indépendants	\N	2021-10-06 13:00:00	2021-10-06 14:00:00	\N	\N	1	0	\N	\N
590299	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur - PJL Travailleurs indépendants	\N	2021-10-06 14:00:00	2021-10-06 14:45:00	\N	\N	1	0	\N	\N
590351	DELEGATION	AUCUNE	\N	\N	DSOM	Table ronde "Gaston Monnerville - l'héritage"	\N	2021-10-07 14:30:00	2021-10-07 18:30:00	\N	\N	13	0	\N	\N
590392	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	Exaen des amendements de séance	2021-10-12 14:00:00	2021-10-12 14:05:00	2021-10-12 14:13:46	2021-10-13 14:21:45	24	0	\N	\N
590394	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2021-10-13 08:30:00	2021-10-13 13:05:00	2021-10-13 13:07:41	2021-10-13 14:21:48	44	0	\N	\N
590397	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition plénière	\N	2021-10-14 11:05:00	2021-10-14 13:00:00	2021-10-14 13:02:43	2021-10-14 14:58:06	32	0	\N	\N
590913	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation du parlement suisse	Accueil d'une délégation du parlement suisse	2021-10-13 12:00:00	2021-10-13 14:30:00	\N	\N	12	0	610	\N
596446	GIA	AUCUNE	\N	\N	\N	Déjeuner protocolaire 	Déjeuner à la questure autour du représentant de Taipei (retour sur la mission sénatoriale )	2021-10-27 12:30:00	2021-10-27 14:00:00	\N	\N	4	0	623	\N
596453	GIA	AUCUNE	\N	\N	\N	Compte rendu de la mission à Taiwan au groupe	Compte rendu de la mission à Taiwan au groupe	2021-10-20 08:30:00	2021-10-20 09:30:00	\N	\N	8	0	623	\N
597574	COM_EURO	AUDRAP	\N	AFEU	\N	Auditions taxonomie européenne	Auditions taxonomie européenne	2021-10-27 16:30:00	2021-10-27 18:30:00	\N	\N	2	0	\N	\N
602131	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition DAG	\N	2021-11-08 11:00:00	2021-11-08 12:00:00	\N	\N	1	0	\N	\N
602132	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions DAG	\N	2021-11-05 09:30:00	2021-11-05 12:00:00	\N	\N	1	0	\N	\N
602133	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition DAG	\N	2021-11-05 14:00:00	2021-11-05 15:00:00	\N	\N	1	0	\N	\N
602241	MISSION	AUCUNE	\N	CONF	\N	Examen de rapport	\N	2021-11-18 10:30:00	2021-11-18 11:20:00	2021-11-18 12:17:00	2021-11-22 11:17:58	5	0	\N	\N
602254	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur - PLF mission "Solidarité"	\N	2021-11-10 14:00:00	2021-11-10 14:50:00	\N	\N	1	0	\N	\N
602256	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PLF pour 2022 - Audition de Marlène Schiappa	PLF pour 2022 - Audition de Marlène Schiappa	2021-11-16 17:35:00	2021-11-16 18:40:00	2021-11-22 11:20:57	2021-11-22 11:51:45	20	0	\N	\N
602477	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Tables rondes sur la cybersécurité et sur le commerce extérieur	Tables rondes sur la cybersécurité et sur le commerce extérieur	2021-11-25 08:35:00	2021-11-25 11:50:00	\N	\N	9	0	\N	\N
602908	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2021-11-15 16:00:00	2021-11-15 16:15:00	2021-11-15 16:14:59	2021-11-16 17:17:11	10	0	\N	\N
602925	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Arte France	\N	2021-11-09 16:00:00	2021-11-09 17:00:00	\N	\N	2	0	\N	\N
602969	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 18 novembre 2021	Réunion du 18 novembre 2021	2021-11-18 08:30:00	2021-11-18 10:00:00	2021-11-19 11:39:43	2021-11-19 19:30:21	13	0	\N	\N
602971	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2022 - Audition DAG	PLF pour 2022 - Audition DAG	2021-11-10 11:30:00	2021-11-10 12:00:00	\N	\N	1	0	\N	\N
602973	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Écologie - OFB	PLF pour 2022 - Écologie - OFB	2021-11-08 11:00:00	2021-11-08 12:00:00	\N	\N	1	0	\N	\N
602978	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL 20-527 - Audition DHUP	PPL 20-527 - Audition DHUP	2021-11-10 09:00:00	2021-11-10 09:45:00	\N	\N	1	0	\N	\N
602979	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL 20-527 - Audition FNSAFER	PPL 20-527 - Audition FNSAFER	2021-11-10 14:00:00	2021-11-10 14:45:00	\N	\N	1	0	\N	\N
602980	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL 20-527 - Table ronde organisations agricoles	PPL 20-527 - Table ronde organisations agricoles	2021-11-10 16:00:00	2021-11-10 17:00:00	\N	\N	2	0	\N	\N
602981	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Agriculture - FNSEA/Jeunes Agriculteurs	PLF pour 2022 - Agriculture - FNSEA/Jeunes Agriculteurs	2021-11-09 15:00:00	2021-11-09 18:00:00	\N	\N	2	0	\N	\N
602997	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Écologie - Transports - VNF	PLF pour 2022 - Écologie - Transports - VNF	2021-11-09 08:00:00	2021-11-09 09:00:00	\N	\N	2	0	\N	\N
603017	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Écologie - Transports - DAM/ART/SNCF	PLF pour 2022 - Écologie - Transports - DAM/ART/SNCF	2021-11-09 16:30:00	2021-11-09 19:30:00	\N	\N	2	0	\N	\N
603020	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Météo - CGDD	PLF pour 2022 - Météo - CGDD	2021-11-09 14:30:00	2021-11-09 15:30:00	\N	\N	1	0	\N	\N
603374	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Agence pour l'enseignement français à l'étranger (AEFE)	\N	2021-11-10 14:00:00	2021-11-10 15:00:00	\N	\N	3	0	\N	\N
603610	SEANCE_PLENIERE	SCRUSOL	1564	\N	\N	Scrutin solennel - PLFSS 2022	Scrutin solennel - PLFSS 2022	2021-11-16 14:30:00	2021-11-16 16:00:00	\N	\N	0	0	\N	\N
602258	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désignation - ENQ Système de santé en France (recevabilité) - PLF pour 2022 (avis)	Désignation - ENQ Système de santé en France (recevabilité) - PLF pour 2022 (avis)	2021-11-17 08:30:00	2021-11-17 11:05:00	2021-11-17 11:51:45	2021-11-19 19:32:20	42	0	\N	\N
602939	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2021-11-17 09:00:00	2021-11-17 11:00:00	2021-11-17 17:46:16	2021-11-19 19:32:21	42	0	\N	\N
606138	GIA	AUCUNE	\N	\N	\N	rencontre avec Dhondup Wangchen (à l'AN)	rencontre avec Dhondup Wangchen (à l'AN)	2021-11-23 17:00:00	2021-11-23 18:30:00	\N	\N	1	0	634	\N
606181	GIA	AUCUNE	\N	\N	\N	Tibet Talk 	Tibet Talk 	2021-12-01 15:00:00	2021-12-01 16:30:00	\N	\N	1	0	634	\N
606197	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2021-11-18 09:05:00	2021-11-18 10:35:00	\N	\N	3	0	\N	\N
606303	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2022	PLF pour 2022	2021-11-22 10:30:00	2021-11-22 13:00:00	\N	\N	48	0	\N	\N
513088	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Examen PJL "OMS" et auditions de MM. Marc Conruyt et Joël Meyer 	\N	2020-12-09 09:28:00	2020-12-09 12:40:00	2020-12-09 14:34:15	2020-12-09 17:19:47	29	0	\N	\N
513095	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de S.E. M. Hector Michel Mujica Ricardo	\N	2020-12-09 16:35:00	2020-12-09 17:50:00	2020-12-10 10:27:56	2020-12-10 17:37:18	16	0	\N	\N
534229	GIA	AUCUNE	\N	\N	\N	Entretien avec Juan González-Barba Pera, Secrétaire d'Etat aux affaires européennes	Entretien avec Juan González-Barba Pera, Secrétaire d'Etat aux affaires européennes	2021-03-02 09:00:00	2021-03-02 10:00:00	\N	\N	9	0	589	\N
534230	GIA	AUCUNE	\N	\N	\N	Entretien avec José Manuel Albares Bueno, ambassadeur 	Entretien avec José Manuel Albares Bueno, ambassadeur 	2021-03-04 09:00:00	2021-03-04 10:00:00	\N	\N	7	0	589	\N
547781	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL développement solidaire	PJL développement solidaire	2021-03-30 14:00:00	2021-03-30 18:00:00	\N	\N	4	0	\N	\N
547886	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	GT drones militaires	GT drones militaires	2021-04-01 13:00:00	2021-04-01 17:30:00	\N	\N	2	0	\N	\N
548223	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT Boussole stratégique	\N	2021-03-30 15:00:00	2021-03-30 16:00:00	\N	\N	3	0	\N	\N
548236	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT Boussole stratégique	\N	2021-04-01 10:00:00	2021-04-01 11:30:00	\N	\N	3	0	\N	\N
554657	MISSION	AUDRAP	\N	EGALCHAN	\N	MI Égalité des chances - Table ronde d'associations d'éducation populaire	\N	2021-04-13 16:00:00	2021-04-13 18:15:00	\N	\N	3	0	\N	\N
554658	MISSION	AUDRAP	\N	EGALCHAN	\N	MI Égalité des chances - Audition du COJ	\N	2021-04-14 17:00:00	2021-04-14 18:30:00	\N	\N	2	0	\N	\N
554659	DELEGATION	AUCUNE	\N	\N	DSOM	Table ronde sur la situation du logement en Guyane	\N	2021-05-06 14:30:00	2021-05-06 16:40:00	\N	\N	11	0	\N	\N
554660	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Négociation collective - Audition de la DGT	\N	2021-04-14 13:50:00	2021-04-14 15:05:00	\N	\N	1	0	\N	\N
554661	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Négociation collective - Audition de l'INTEFP	\N	2021-04-14 13:00:00	2021-04-14 13:50:00	\N	\N	1	0	\N	\N
554670	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désignations CMP et rapporteurs - Rapport PJLC Environnement - Bilan application des lois	Désignations CMP et rapporteurs - Rapport PJLC Environnement - Bilan application des lois	2021-05-05 09:30:00	2021-05-05 11:35:00	2021-05-05 13:21:07	2021-05-06 17:43:06	43	0	\N	\N
554674	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2021 - Financement lutte algues vertes Bretagne - Déplacement Bretagne	Contrôle 2021 - Financement lutte algues vertes Bretagne - Déplacement Bretagne	2021-04-12 07:00:00	2021-04-13 20:05:00	\N	\N	1	0	\N	\N
554676	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Douane face au trafic de stupéfiants - DGDDI/DR douanes Guadeloupe/SEJF	Contrôle 2021 - Douane face au trafic de stupéfiants - DGDDI/DR douanes Guadeloupe/SEJF	2021-04-13 14:30:00	2021-04-13 17:25:00	\N	\N	2	0	\N	\N
554679	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Transformation et fonction publiques - Cabinet MIN Transformation	Contrôle 2021 - Transformation et fonction publiques - Cabinet MIN Transformation	2021-04-13 17:30:00	2021-04-13 18:25:00	\N	\N	2	0	\N	\N
554682	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - NexSIS - Représentants SDIS	Contrôle 2021 - NexSIS - Représentants SDIS	2021-04-13 09:00:00	2021-04-13 10:15:00	\N	\N	1	0	\N	\N
554684	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du GT subsidiarité	\N	2021-04-15 08:30:00	2021-04-15 09:00:00	\N	\N	0	0	\N	\N
554685	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	Réunion GT Subsidiarité	Réunion GT Subsidiarité	2021-04-15 08:30:00	2021-04-15 08:45:00	\N	\N	3	0	\N	\N
554689	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - MDPH - Cour des comptes/Table ronde associations	Contrôle 2021 - MDPH - Cour des comptes/Table ronde associations	2021-04-13 09:00:00	2021-04-13 11:45:00	\N	\N	2	0	\N	\N
554708	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Immobilier universitaire - Amue	Contrôle 2021 - Immobilier universitaire - Amue	2021-04-14 15:30:00	2021-04-14 16:30:00	\N	\N	1	0	\N	\N
555399	MISSION	AUCUNE	\N	CONF	\N	Table ronde "Associations d'élus"	\N	2021-05-06 09:05:00	2021-05-06 12:05:00	2021-05-06 15:57:30	2021-05-06 17:43:48	11	0	\N	\N
562134	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	ANACT	\N	2021-01-14 09:00:00	2021-01-14 10:00:00	\N	\N	0	0	\N	\N
562135	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	ANDRH	\N	2021-01-14 10:00:00	2021-01-14 11:00:00	\N	\N	0	0	\N	\N
562136	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Cybersécurité	\N	2021-02-18 14:30:00	2021-02-18 16:30:00	\N	\N	2	0	\N	\N
562137	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Tech In France - Syntec - Hexatrust	\N	2021-03-04 14:30:00	2021-03-04 16:30:00	\N	\N	2	0	\N	\N
562138	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	CLUSIF - Orange Cyberdéfense	\N	2021-03-11 14:30:00	2021-03-11 16:30:00	\N	\N	2	0	\N	\N
562139	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	AMRAE	\N	2021-03-18 14:30:00	2021-03-18 15:30:00	\N	\N	2	0	\N	\N
562140	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Cybersécurité	\N	2021-03-25 14:30:00	2021-03-25 16:30:00	\N	\N	0	0	\N	\N
562141	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	FFA - Wavestone	\N	2021-04-08 14:30:00	2021-04-08 17:00:00	\N	\N	2	0	\N	\N
562142	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Amazon - M. Quemener	\N	2021-04-15 14:30:00	2021-04-15 16:45:00	\N	\N	2	0	\N	\N
562146	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition de l'Observatoire du Travail Indépendant (OTI)	\N	2021-04-27 15:00:00	2021-04-27 16:00:00	\N	\N	3	0	\N	\N
562152	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Fédération européenne de l¿actionnariat salarié	\N	2021-04-28 09:00:00	2021-04-28 09:45:00	\N	\N	3	0	\N	\N
562153	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition Bloom at Work	\N	2021-04-28 09:50:00	2021-04-28 10:35:00	\N	\N	0	0	\N	\N
562154	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition de la Fédération des Entreprises de Portage Salarial	\N	2021-04-28 10:40:00	2021-04-28 11:25:00	\N	\N	0	0	\N	\N
562161	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition de La Mutuelle générale	\N	2021-04-28 11:30:00	2021-04-28 12:15:00	\N	\N	0	0	\N	\N
562198	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	EV PPL Protoxyde d'azote	EV PPL prévenir les usages dangereux du protoxyde d'azote	2021-05-25 14:30:00	2021-05-25 15:25:00	\N	\N	44	0	\N	\N
562199	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL suivi des condamnés terroristes	PPL renforçant le suivi des condamnés terroristes sortant de détention	2021-05-25 15:30:00	2021-05-25 17:20:00	\N	\N	72	0	\N	\N
562200	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL responsabilité pénale	PPL responsabilité pénale des auteurs de crimes et délits	2021-05-25 18:15:00	2021-05-25 20:40:00	\N	\N	76	0	\N	\N
588585	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Activité professionnelle indépendante	Audition rapporteur - PJL Activité professionnelle indépendante	2021-10-01 14:30:00	2021-10-01 18:30:00	\N	\N	1	0	\N	\N
588587	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Activité professionnelle indépendante	Audition rapporteur - PJL Activité professionnelle indépendante	2021-09-30 14:45:00	2021-09-30 16:30:00	\N	\N	1	0	\N	\N
588589	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Activité professionnelle indépendante	Audition rapporteur - PJL Activité professionnelle indépendante	2021-09-30 17:30:00	2021-09-30 18:30:00	\N	\N	1	0	\N	\N
588591	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Activité professionnelle indépendante	Audition rapporteur - PJL Activité professionnelle indépendante	2021-09-29 18:00:00	2021-09-29 19:00:00	\N	\N	1	0	\N	\N
598073	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR COP26	PPR COP26	2021-11-02 14:30:00	2021-11-02 16:15:00	\N	\N	97	0	\N	\N
598074	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Empreinte numérique	\N	2021-11-02 16:25:00	2021-11-02 18:15:00	\N	\N	95	0	\N	\N
598075	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2021-11-03 15:00:00	2021-11-03 16:30:00	\N	\N	256	0	\N	\N
598076	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Accès foncier agricole	PPL Accès foncier agricole	2021-11-03 16:30:00	2021-11-03 20:30:00	\N	\N	106	0	\N	\N
598078	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPLC respect des principes de la démocratie	PPLC respect des principes de la démocratie	2021-11-04 12:00:00	2021-11-04 13:35:00	\N	\N	49	0	\N	\N
598084	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Présence partentale 	PPL Présence partentale 	2021-11-04 16:00:00	2021-11-04 17:10:00	\N	\N	34	0	\N	\N
598089	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Administration et usagers	PPL Administration au service des usagers	2021-11-04 17:15:00	2021-11-04 18:55:00	\N	\N	32	0	\N	\N
598090	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	NL PJL Vigilance sanitaire	NL PJL Vigilance sanitaire	2021-11-04 19:00:00	2021-11-04 20:30:00	\N	\N	20	0	\N	\N
601092	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2022 - Avis "Immigration, asile et intégration"	\N	2021-11-03 14:00:00	2021-11-03 15:00:00	\N	\N	3	0	\N	\N
601162	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-11-16 09:32:00	2021-11-16 09:38:00	2021-11-16 11:11:27	2021-11-16 17:17:12	24	0	\N	\N
601163	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-11-16 13:45:00	2021-11-16 14:45:00	2021-11-16 14:23:37	2021-11-16 17:17:13	23	0	\N	\N
601164	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-11-17 16:30:00	2021-11-17 18:30:00	2021-11-17 18:12:29	2021-11-19 19:32:15	28	0	\N	\N
616240	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Tourisme	GT Tourisme	2021-12-08 14:00:00	2021-12-08 15:00:00	\N	\N	4	0	\N	\N
616246	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Aménagement du territoire	MI Aménagement du territoire	2021-12-07 17:15:00	2021-12-07 18:30:00	\N	\N	13	0	\N	\N
616262	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Aménagement du territoire - B. Rojouan	MI Aménagement du territoire - B. Rojouan	2021-12-14 15:45:00	2021-12-14 18:30:00	\N	\N	3	0	\N	\N
622984	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	MCC Sécurisation de la chasse	MCC Sécurisation de la chasse - Table ronde fédérations et général gendarmerie	2022-01-18 14:30:00	2022-01-18 17:40:00	\N	\N	12	0	\N	\N
624083	GIA	AUCUNE	\N	\N	\N	entretien avec S.E. Mme Hend ALOtaiba, Ambassadrice des Émirats arabes unis en France	\N	2022-01-20 15:00:00	2022-01-20 15:45:00	\N	\N	2	0	661	\N
624088	GIA	AUCUNE	\N	\N	\N	entretien avec S.E. Monsieur Fahad Alruwaily, Ambassadeur d'Arabie Saoudite en France	\N	2022-01-17 14:00:00	2022-01-17 15:00:00	\N	\N	2	0	661	\N
625287	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Obésité - Table ronde prévention nutritionnelle au niveau territorial	\N	2022-01-25 14:00:00	2022-01-25 15:30:00	\N	\N	3	0	\N	\N
625291	COM_ENQUETE	AUDRAP	\N	HOPITAL	\N	CE Hôpital - Table ronde de syndicats de sages-femmes	\N	2022-01-25 14:45:00	2022-01-25 15:45:00	\N	\N	8	0	\N	\N
625300	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPRE Pacte vert - Audition CLER - Réseau pour la transition énergétique	PPRE Pacte vert - Audition CLER - Réseau pour la transition énergétique	2022-01-21 14:00:00	2022-01-21 15:00:00	\N	\N	2	0	\N	\N
625301	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPRE Pacte vert - TR Transporteurs	PPRE Pacte vert - TR Transporteurs	2022-01-21 15:00:00	2022-01-21 16:00:00	\N	\N	4	0	\N	\N
625302	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPRE Pacte vert - Fédération Nationale de l'Aviation Marchande	PPRE Pacte vert - Fédération Nationale de l'Aviation Marchande	2022-01-21 16:00:00	2022-01-21 17:00:00	\N	\N	4	0	\N	\N
625303	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPRE Pacte vert - Audition Direction générale de l'aviation civile	PPRE Pacte vert - Audition Direction générale de l'aviation civile	2022-01-21 17:00:00	2022-01-21 18:00:00	\N	\N	2	0	\N	\N
627963	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	CHASSE	M. Pierrick LE CUNFF, président de Melckone	2022-02-01 15:35:00	2022-02-01 16:00:00	\N	\N	12	0	\N	\N
627986	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	MCC Sécurisation de la chasse	M. Pierre DUBREUIL, directeur général de l¿Office français de la biodiversité	2022-02-01 16:05:00	2022-02-01 18:00:00	\N	\N	12	0	\N	\N
628012	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	mcc	M. Willy SCHRAEN, président de la Fédération nationale des chasseurs	2022-02-01 18:00:00	2022-02-01 19:40:00	\N	\N	12	0	\N	\N
628566	MISSION	AUCUNE	\N	FONDSMER	\N	Audition M. Vallat	Audition M. Vallat	2022-02-02 17:00:00	2022-02-02 18:30:00	2022-02-03 10:05:38	2022-02-03 10:40:20	5	0	\N	\N
628890	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Choix du nom issu de la filiation	\N	2022-02-02 14:15:00	2022-02-02 14:50:00	\N	\N	2	0	\N	\N
628893	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL choix du nom i	\N	2022-02-02 16:30:00	2022-02-02 18:00:00	\N	\N	2	0	\N	\N
628898	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Choix du nom issu de la filiation	\N	2022-02-02 18:00:00	2022-02-02 19:00:00	\N	\N	3	0	\N	\N
628965	COM_PERMANENTE	AUDRAP	\N	CDD	\N	MI Aménagement du territoire - Audition Mme Patricia Demas	MI Aménagement du territoire - Audition Mme Patricia Demas	2022-02-01 15:00:00	2022-02-01 16:00:00	\N	\N	1	0	\N	\N
628992	COM_PERMANENTE	AUDRAP	\N	CDD	\N	MI Aménagement du territoire - Audition Mme Demas	MI Aménagement du territoire - Audition Mme Demas	2022-02-02 14:00:00	2022-02-02 15:15:00	\N	\N	1	0	\N	\N
629021	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-02-08 15:30:00	2022-02-08 17:35:00	2022-02-08 17:43:05	2022-02-09 10:41:42	29	0	\N	\N
629022	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-02-09 09:05:00	2022-02-09 12:55:00	2022-02-09 12:54:38	2022-02-10 18:02:30	34	0	\N	\N
629066	DELEGATION	AUCUNE	\N	\N	206	Audition publique sur l¿évolution du virus SARS-Cov-2	\N	2022-02-03 09:05:00	2022-02-03 12:45:00	\N	\N	12	0	\N	\N
629117	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition PPRE Pacte vert	Audition PPRE Pacte vert	2022-02-01 18:15:00	2022-02-01 19:00:00	\N	\N	1	0	\N	\N
629205	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Choix du nom issu de la filiation (désignation CMP-rapport) - PJL 4D (amdts texte CMP)	PPL Choix du nom issu de la filiation (désignation CMP-rapport) - PJL 4D (amdts texte CMP)	2022-02-09 09:35:00	2022-02-09 10:40:00	2022-02-09 14:46:10	2022-02-10 18:02:32	40	1	\N	\N
629206	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de Jean-Denis Combrexelle, président du comité de liaison Covid	Audition de Jean-Denis Combrexelle, président du comité de liaison Covid	2022-02-09 10:45:00	2022-02-09 11:40:00	2022-02-09 15:15:15	2022-02-10 18:02:34	25	0	\N	\N
629207	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de Marlène Schiappa sur l'organisation des élections présidentielle et législ.	Audition de Marlène Schiappa sur l'organisation des élections et législ.	2022-02-09 14:00:00	2022-02-09 14:55:00	2022-02-09 18:14:31	2022-02-10 18:02:35	17	0	\N	\N
629208	COM_EURO	AUDRAP	\N	AFEU	\N	Paquet climat - Secteur énergie - DG Enegie	Paquet climat - Secteur énergie - DG Enegie	2022-02-03 11:00:00	2022-02-03 11:45:00	\N	\N	1	0	\N	\N
629302	COM_PERMANENTE	AUTRE	\N	CAE	\N	Amendements séance PPL Contrôle parental / PPL Experts forestiers	\N	2022-02-09 09:05:00	2022-02-09 11:00:00	2022-02-09 11:51:44	2022-02-10 18:02:29	44	1	\N	\N
629305	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2022-02-09 09:36:00	2022-02-09 10:20:00	2022-02-09 10:59:08	2022-02-11 16:48:14	34	4	\N	\N
629321	MISSION	AUCUNE	\N	CULTURE	\N	Réunion 20220208	\N	2022-02-08 15:00:00	2022-02-08 16:30:00	2022-02-08 16:31:15	2022-02-09 10:41:03	6	0	\N	\N
511628	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Comité de suivi Suez-Veolia - Syndicats Veolia	Comité de suivi Suez-Veolia - Syndicats Veolia	2020-12-01 16:10:00	2020-12-01 17:10:00	\N	\N	5	0	\N	\N
511666	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Comité de suivi Suez-Veolia - AMF-AdCF	Comité de suivi Suez-Veolia - AMF-AdCF	2020-12-01 18:00:00	2020-12-01 19:00:00	\N	\N	4	0	\N	\N
516363	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Réunion plénière	\N	2020-12-15 14:30:00	2020-12-15 16:00:00	\N	\N	0	0	\N	\N
516381	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJLO CESE -  PJL Code de la sécurité intérieure - Motion et amendements de séance	PJLO CESE -  PJL Code de la sécurité intérieure - Motion et amendements de séance	2020-12-14 14:30:00	2020-12-14 14:45:00	2020-12-14 15:05:47	2020-12-14 16:41:24	11	0	\N	\N
516382	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désignation rapporteurs - MI Vote à distance et MI Elections consulaires (rapports)	Désignation rapporteurs - MI Vote à distance et MI Elections consulaires (rapports)	2020-12-16 09:30:00	2020-12-16 12:35:00	2020-12-16 13:56:17	2020-12-16 18:00:31	34	0	\N	\N
516534	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur - Etat de droit dans l'UE	Audition rapporteur - Etat de droit dans l'UE	2020-12-10 10:00:00	2020-12-10 13:00:00	\N	\N	2	0	\N	\N
518778	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition GT Agriculteurs en détresse	Audition GT Agriculteurs en détresse	2020-12-16 13:30:00	2020-12-16 14:45:00	\N	\N	8	0	\N	\N
526735	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Audition ARCEP	\N	2021-02-01 09:00:00	2021-02-01 10:00:00	\N	\N	1	0	\N	\N
526739	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Audition FNPS	\N	2021-02-02 14:00:00	2021-02-02 15:00:00	\N	\N	1	0	\N	\N
531047	DELEGATION	AUCUNE	\N	\N	DSOM	Table ronde sur la situation du logement à Mayotte	\N	2021-02-18 09:00:00	2021-02-18 11:45:00	\N	\N	14	0	\N	\N
531075	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions DGPR - Zero Waste France et Surfrider Foundation Europe	Auditions DGPR - Zero Waste France et Surfrider Foundation Europe	2021-02-10 16:30:00	2021-02-10 18:00:00	\N	\N	1	0	\N	\N
531099	MISSION	AUCUNE	\N	PAUP	\N	Auditions plénières	\N	2021-02-16 15:30:00	2021-02-16 18:25:00	2021-02-16 18:37:48	2021-02-17 18:09:56	14	0	\N	\N
531146	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examens Amdts séance textes n°330 Diverses ordonnances covid19 et n°332 courtage assurance	Examens Amdts séance des textes n°330 Diverses ordonnances covid 19 et n°332 Réforme du courtage de l¿assurance	2021-02-16 14:30:00	2021-02-16 14:50:00	2021-02-16 16:06:07	2021-02-17 18:09:06	29	0	\N	\N
531147	COM_PERMANENTE	AUTRE	\N	FINC	\N	Auditions Art 13-Patrick de CAMBOURG et Épargne financière des ménages liée à la crise	Auditions Art 13-Patrick de CAMBOURG et Épargne financière des ménages liée à la crise	2021-02-17 09:05:00	2021-02-17 12:30:00	2021-02-17 15:44:33	2021-02-17 18:09:03	36	0	\N	\N
531148	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition SER, FGR, Enerplan	Audition SER, FGR, Enerplan	2021-02-09 10:00:00	2021-02-09 11:00:00	\N	\N	2	0	\N	\N
531149	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Médiateur national de l'énergie	Audition Médiateur national de l'énergie	2021-02-09 13:45:00	2021-02-09 14:45:00	\N	\N	3	0	\N	\N
531150	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Haut Conseil pour le climat	Audition Haut Conseil pour le climat	2021-02-09 14:45:00	2021-02-09 15:45:00	\N	\N	1	0	\N	\N
531151	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition EDF	\N	2021-02-09 15:45:00	2021-02-09 16:30:00	\N	\N	1	0	\N	\N
531159	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Respect principes de la République - Auditions	Audition Mme Coffinier	2021-02-09 10:00:00	2021-02-09 11:00:00	\N	\N	5	0	\N	\N
531160	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Respect principes de la République - Auditions	TR Fédérations sportives	2021-02-09 14:00:00	2021-02-09 15:30:00	\N	\N	6	0	\N	\N
531161	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Respect principes de la République - Auditions	mme Lefebvre	2021-02-10 14:00:00	2021-02-10 15:00:00	\N	\N	6	0	\N	\N
531162	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Respect principes de la République - Auditions	TR Instruction en famille	2021-02-10 16:30:00	2021-02-10 18:00:00	\N	\N	9	0	\N	\N
531163	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Respect principes de la République - Auditions	Phobie scolaire	2021-02-11 10:00:00	2021-02-11 10:45:00	\N	\N	2	0	\N	\N
531164	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Fondation du Patrimoine	Audition Commissaires aux comptes	2021-02-10 16:30:00	2021-02-10 17:30:00	\N	\N	2	0	\N	\N
531195	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 16 février 2021	\N	2021-02-16 17:35:00	2021-02-16 19:15:00	2021-02-17 17:00:59	2021-02-17 18:09:28	70	0	\N	\N
531196	COM_EURO	AUTRE	\N	AFEU	\N	réunion du 18 février 2021	\N	2021-02-18 08:30:00	2021-02-18 09:45:00	2021-02-18 15:37:30	2021-02-18 16:41:29	14	0	\N	\N
531197	COM_EURO	AUTRE	\N	AFEU	\N	Communications APCE (1ère partie de session) 	\N	2021-02-18 08:35:00	2021-02-18 09:15:00	\N	\N	0	0	\N	\N
531199	COM_EURO	AUDRAP	\N	AFEU	\N	\N	\N	2021-02-09 17:00:00	2021-02-09 18:00:00	\N	\N	0	0	\N	\N
531200	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur - CSA	\N	2021-02-09 17:00:00	2021-02-09 18:00:00	\N	\N	1	0	\N	\N
531201	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur - CEPD	\N	2021-02-09 18:00:00	2021-02-09 19:15:00	\N	\N	2	0	\N	\N
531207	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur - commission européenne DG connect	\N	2021-02-10 14:00:00	2021-02-10 15:00:00	\N	\N	2	0	\N	\N
531236	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière	\N	2021-02-11 09:30:00	2021-02-11 11:15:00	2021-02-11 15:46:24	\N	19	0	\N	\N
531245	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Gazel Énergie	Audition Gazel Énergie	2021-02-10 14:00:00	2021-02-10 14:45:00	\N	\N	2	0	\N	\N
531246	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Symbiote	Audition Symbiote	2021-02-10 14:45:00	2021-02-10 15:30:00	\N	\N	2	0	\N	\N
531286	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de M. Michel Barnier	\N	2021-02-16 17:35:00	2021-02-16 19:15:00	2021-02-17 17:13:27	2021-02-17 18:09:04	70	0	\N	\N
531287	COM_PERMANENTE	AUTRE	\N	CAE	\N	Rapport d'information sur les graines de sésames	\N	2021-02-17 08:35:00	2021-02-17 09:30:00	2021-02-17 17:15:49	2021-02-17 18:09:03	23	0	\N	\N
531288	COM_PERMANENTE	AUTRE	\N	CAE	\N	Auditions de Meridiam et Ardian	\N	2021-02-17 09:35:00	2021-02-17 12:20:00	2021-02-18 10:11:55	2021-02-18 16:41:27	71	0	\N	\N
531317	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Justice de proximité - PJLO Élection du Président de la République (rapports)	PPL Justice de proximité - PJLO Élection du Président de la République (rapports)	2021-02-17 09:30:00	2021-02-17 11:00:00	2021-02-17 16:18:15	2021-02-17 18:09:02	39	0	\N	\N
531319	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Respect des principes de la République - Audition de Dominique Schnapper	PJL Respect des principes de la République - Audition de Dominique Schnapper	2021-02-17 16:30:00	2021-02-17 17:45:00	2021-02-17 18:30:39	2021-02-18 16:41:28	38	0	\N	\N
531320	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Respect des principes de la République - Audition de Bernard Rougier	PJL Respect des principes de la République - Audition de Bernard Rougier	2021-02-17 17:50:00	2021-02-17 18:55:00	2021-02-17 19:18:00	2021-02-18 16:41:28	14	0	\N	\N
531323	COM_EURO	AUDRAP	\N	AFEU	\N	Auditions sur l'Etat de droit dans l'Union européenne	Auditions sur l'Etat de droit dans l'UE - Parlement européen	2021-02-11 14:30:00	2021-02-11 15:30:00	\N	\N	2	0	\N	\N
531329	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Négociation collective - Audition de MM. Simonpoli et Gateau	\N	2021-02-10 13:00:00	2021-02-10 14:00:00	\N	\N	1	0	\N	\N
531474	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Principes de la République	\N	2021-02-11 11:00:00	2021-02-11 12:00:00	\N	\N	3	0	\N	\N
531478	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Principes de la République	\N	2021-02-11 14:00:00	2021-02-11 15:00:00	\N	\N	7	0	\N	\N
531486	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Principes de la République	\N	2021-02-11 15:00:00	2021-02-11 17:00:00	\N	\N	9	0	\N	\N
531495	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Principes de la République	\N	2021-02-11 17:00:00	2021-02-11 18:00:00	\N	\N	5	0	\N	\N
531554	COM_PERMANENTE	GROUPE_TRAVAIL	\N	SOCI	\N	GT Expertise psychiatrique en matière pénale	\N	2021-02-16 10:00:00	2021-02-16 10:50:00	\N	\N	3	0	\N	\N
537071	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2021-03-04 09:05:00	2021-03-04 11:00:00	\N	\N	3	0	\N	\N
542843	GIA	AUCUNE	\N	\N	\N	Rencontre entre présidents GIA/AIFC - Sénat/AN	Rencontre entre présidents GIA/AIFC - Sénat/AN	2021-03-17 14:00:00	2021-03-17 14:30:00	\N	\N	1	0	583	\N
590490	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-10-13 18:00:00	2021-10-13 19:08:00	2021-10-13 19:10:48	2021-10-14 14:58:06	18	0	\N	\N
590492	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-10-12 17:30:00	2021-10-12 18:30:00	2021-10-12 19:00:49	2021-10-13 14:21:47	34	0	\N	\N
590495	ETUDES	AUTRE	\N	\N	\N	Audition Ademe	\N	2021-10-06 17:00:00	2021-10-06 18:15:00	\N	\N	7	0	\N	922
590540	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désignations - Amendements de séance - Rapports	Désignations - Amendements de séance - Rapports	2021-10-13 08:30:00	2021-10-13 12:10:00	2021-10-13 14:40:44	2021-10-14 14:58:05	40	0	\N	\N
590541	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPLO Implantation locale des parlementaires (amendements)	PPLO Implantation locale des parlementaires (amendements)	2021-10-12 15:00:00	2021-10-12 15:10:00	2021-10-12 15:33:27	2021-10-13 14:21:46	12	0	\N	\N
590544	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Recours des parlementaires pour excès de pouvoir (amendements)	PPL Recours des parlementaires pour excès de pouvoir (amendements)	2021-10-14 14:00:00	2021-10-14 14:15:00	2021-10-14 14:24:39	2021-10-14 14:58:07	6	0	\N	\N
590571	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 14 octobre 2021	\N	2021-10-14 09:00:00	2021-10-14 11:00:00	\N	\N	0	0	\N	\N
590603	DELEGATION	AUCUNE	\N	\N	PROS	Audition contradictoire sur l'avenir des dettes publiques	\N	2021-10-07 08:30:00	2021-10-07 10:00:00	2021-10-07 12:51:03	\N	14	0	\N	\N
590629	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 2021 -Soutien industrie aéronautique - Cour des comptes	58-2 2021 -Soutien industrie aéronautique - Cour des comptes	2021-10-06 16:30:00	2021-10-06 17:45:00	\N	\N	1	0	\N	\N
590631	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Culture - DG2TDC	PLF pour 2022 - Culture - DG2TDC	2021-10-06 14:00:00	2021-10-06 14:50:00	\N	\N	2	0	\N	\N
590634	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - FPIC - Associations d'Élus	Contrôle 2021 - FPIC - Associations d'Élus	2021-10-05 17:00:00	2021-10-05 19:15:00	\N	\N	2	0	\N	\N
590649	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL n° 806 MES - DG Trésor / FBF	PJL n° 806 MES - DG Trésor / FBF	2021-10-06 16:30:00	2021-10-06 18:30:00	\N	\N	1	0	\N	\N
590651	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Solidarité - DFAS	PLF pour 2022 - Solidarité - DFAS	2021-10-06 16:40:00	2021-10-06 17:40:00	\N	\N	2	0	\N	\N
590657	DELEGATION	AUDRAP	\N	\N	PROS	Audition de rapporteur	\N	2021-10-05 17:30:00	2021-10-05 18:30:00	\N	\N	3	0	\N	\N
590659	DELEGATION	AUDRAP	\N	\N	PROS	Audition de rapporteur	\N	2021-10-06 16:15:00	2021-10-06 17:15:00	\N	\N	3	0	\N	\N
590664	DELEGATION	AUDRAP	\N	\N	PROS	audition de rapporteur	\N	2021-10-06 17:15:00	2021-10-06 18:15:00	\N	\N	3	0	\N	\N
590797	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de M. Frédéric Gonand	\N	2021-10-13 09:35:00	2021-10-13 12:15:00	2021-10-13 12:23:30	2021-10-13 14:21:43	41	0	\N	\N
590800	COM_PERMANENTE	AUTRE	\N	CAE	\N	Avis PJL indépendants	\N	2021-10-12 16:05:00	2021-10-12 16:55:00	2021-10-12 17:21:05	2021-10-13 14:21:47	30	0	\N	\N
590804	DELEGATION	AUCUNE	\N	\N	COLTER	Table ronde sur la médecine préventive dans la fonction publique territoriale	\N	2021-11-04 09:00:00	2021-11-04 10:15:00	\N	\N	19	0	\N	\N
590805	DELEGATION	AUTRE	\N	\N	COLTER	Table ronde avec la délégation aux entreprises sur cyber sécurité	\N	2021-10-28 09:00:00	2021-10-28 12:00:00	2021-10-28 16:10:09	\N	29	0	\N	\N
590806	DELEGATION	AUTRE	\N	\N	COLTER	Audition de Joël GIRAUD, secrétaire d'Etat chargé de la ruralité 	\N	2021-10-21 09:00:00	2021-10-21 10:15:00	\N	\N	30	0	\N	\N
590807	DELEGATION	AUCUNE	\N	\N	COLTER	Audition de M. Baroin, président de l'association des maires de France	\N	2021-10-21 08:45:00	2021-10-21 11:40:00	\N	\N	29	0	\N	\N
590808	DELEGATION	AUCUNE	\N	\N	COLTER	Audition de Monsieur LAMBERT Thierry, Délégué Ministèriel à la transformation publique	\N	2021-10-14 10:30:00	2021-10-14 11:35:00	\N	\N	15	0	\N	\N
590809	DELEGATION	AUCUNE	\N	\N	COLTER	Examen du rapport d'information initiatives des CT en matière d'accès aux soins	\N	2021-10-14 09:30:00	2021-10-14 10:30:00	\N	\N	15	0	\N	\N
591256	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2021-10-07 10:55:00	2021-10-07 12:20:00	\N	\N	3	0	\N	\N
593329	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Convention n° 190 de l'OIT	\N	2021-10-13 16:30:00	2021-10-13 18:30:00	\N	\N	1	0	\N	\N
593334	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Convention n° 190 de l'OIT	\N	2021-10-14 14:00:00	2021-10-14 16:15:00	\N	\N	1	0	\N	\N
599364	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Vigilance sanitaire (nouvelle lecture - rapport et texte)	PJL Vigilance sanitaire (nouvelle lecture - rapport et texte)	2021-11-04 16:00:00	2021-11-04 16:25:00	2021-11-04 17:03:03	2021-11-04 18:01:47	13	1	\N	\N
599368	DELEGATION	AUTRE	\N	\N	DSOM	Auditions	\N	2021-11-04 09:30:00	2021-11-04 12:30:00	\N	\N	13	0	\N	\N
599377	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - AEE - FAPEE	PLF pour 2022 - AEE - FAPEE	2021-10-26 14:00:00	2021-10-26 15:00:00	\N	\N	2	0	\N	\N
599380	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - APD - DG Trésor	PLF pour 2022 - APD - DG Trésor	2021-10-26 15:00:00	2021-10-26 16:00:00	\N	\N	2	0	\N	\N
599383	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - AEE - DGAPS	PLF pour 2022 - AEE - DGAPS	2021-10-26 16:15:00	2021-10-26 17:15:00	\N	\N	2	0	\N	\N
599423	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - APD - DGM	PLF pour 2022 - APD - DGM	2021-11-02 15:00:00	2021-11-02 16:00:00	\N	\N	2	0	\N	\N
599426	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - APD - Cabinet MEAE	PLF pour 2022 - APD - Cabinet MEAE	2021-11-02 17:00:00	2021-11-02 18:00:00	\N	\N	2	0	\N	\N
599429	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - AEE - AEFE	PLF pour 2022 - AEE - AEFE	2021-11-03 16:00:00	2021-11-03 17:00:00	\N	\N	2	0	\N	\N
599430	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - AEE - Cabinet MEAE	PLF pour 2022 - AEE - Cabinet MEAE	2021-11-03 18:15:00	2021-11-03 19:15:00	\N	\N	2	0	\N	\N
599454	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PJLF 2022 - Avis Écologie	Auditions PJLF 2022 - Avis Écologie	2021-11-02 16:00:00	2021-11-02 20:00:00	\N	\N	0	0	\N	\N
599647	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2022 Anciens combattants Audition de l'ONACVG	\N	2021-11-02 14:30:00	2021-11-02 15:30:00	\N	\N	3	0	\N	\N
599672	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2022 Anciens combattants - Table ronde d'associations d'anciens combattants	\N	2021-11-02 15:45:00	2021-11-02 17:15:00	\N	\N	3	0	\N	\N
599678	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF 2022 - Avis Aménagement numérique - Audition M. Jean-Michel Houllegatte	PLF 2022 - Avis Aménagement numérique - Audition M. Jean-Michel Houllegatte	2021-10-28 14:00:00	2021-10-28 16:00:00	\N	\N	1	0	\N	\N
599681	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF 2022 - Avis Aménagement numérique - Audition Banque des territoires /CDC	PLF 2022 - Avis Aménagement numérique - Audition Banque des territoires /CDC	2021-11-03 09:00:00	2021-11-03 10:00:00	\N	\N	1	0	\N	\N
599742	COM_PERMANENTE	DEPLACEMENT	\N	SOCI	\N	PLF 2022 - Prog Hébergt - M° Cohésion territoires - Visite centre hébergt + table ronde	\N	2021-11-04 08:30:00	2021-11-04 12:30:00	\N	\N	1	0	\N	\N
599749	DELEGATION	AUDRAP	\N	\N	206	Audition de rapporteur	\N	2021-11-02 15:00:00	2021-11-02 16:00:00	\N	\N	1	0	\N	\N
600065	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2022 - Avis agriculture - Audition M. Duplomb, Mme Férat, M.Tissot	PLF 2022 - Avis agriculture - Audition M. Duplomb, Mme Férat, M.Tissot	2021-10-26 16:30:00	2021-10-26 18:45:00	\N	\N	5	0	\N	\N
600074	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2022 - Avis agriculture - Auditions M. Duplomb, Mme Férat et M. Tissot	PLF 2022 - Avis agriculture - Auditions M. Duplomb, Mme Férat et M. Tissot	2021-11-03 13:30:00	2021-11-03 15:00:00	\N	\N	2	0	\N	\N
505709	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2020-11-17 14:30:00	2020-11-17 16:25:00	\N	\N	3	0	\N	\N
506188	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJLF POUR 2020 - P. 144	\N	2020-11-17 16:00:00	2020-11-17 18:30:00	\N	\N	2	0	\N	\N
506191	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJLF POUR 2020 - P. 144	\N	2020-11-18 16:30:00	2020-11-18 18:30:00	\N	\N	2	0	\N	\N
506194	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJLF POUR 2020 - P. 144	\N	2020-11-19 11:00:00	2020-11-19 12:30:00	\N	\N	2	0	\N	\N
512910	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2020-11-26 10:20:00	2020-11-26 12:30:00	\N	\N	3	0	\N	\N
550927	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Association nationale des étudiants en médecine (ANEMF)	\N	2021-04-01 17:42:00	2021-04-01 18:40:00	\N	\N	1	0	\N	\N
599751	COM_PERMANENTE	AUTRE	\N	CAE	\N	Examen des amenendements de séance 	\N	2021-11-03 10:50:00	2021-11-03 12:25:00	2021-11-03 16:11:05	2021-11-03 16:47:38	37	0	\N	\N
519205	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Protéger les jeunes mineurs des crimes sexuels	\N	2021-01-06 14:30:00	2021-01-06 16:25:00	\N	\N	4	0	\N	\N
536469	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Groupe de travail sur l'avenir de La Poste	Groupe de travail sur l'avenir de La Poste	2021-03-03 17:00:00	2021-03-03 19:45:00	\N	\N	8	0	\N	\N
536483	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Groupe de travail sur l'avenir de La Poste	Groupe de travail sur l'avenir de La Poste	2021-03-02 16:30:00	2021-03-02 17:30:00	\N	\N	3	0	\N	\N
536496	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Groupe de travail sur l'avenir de La Poste	Groupe de travail sur l'avenir de La Poste	2021-03-02 18:00:00	2021-03-02 19:00:00	\N	\N	4	0	\N	\N
538963	MISSION	AUDRAP	\N	METHANIS	\N	Audition DGEC	Audition DGEC	2021-03-08 14:00:00	2021-03-08 15:00:00	\N	\N	10	0	\N	\N
539057	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière de la CATDD	\N	2021-03-17 09:30:00	2021-03-17 12:37:00	2021-03-17 13:53:38	2021-03-17 16:58:59	34	0	\N	\N
539061	MISSION	AUTRE	\N	EGALCHAN	\N	Réunion plénière MI Jeunes	\N	2021-03-18 11:00:00	2021-03-18 12:30:00	\N	\N	0	0	\N	\N
539062	MISSION	AUTRE	\N	EGALCHAN	\N	Réunion plénière MI Jeunes	\N	2021-03-18 14:30:00	2021-03-18 16:30:00	\N	\N	0	0	\N	\N
539063	COM_PERMANENTE	AUTRE	\N	FINC	\N	PJL n°369 Principes République : Examen rapport pour avis-Communication conf. ART13 TSCG	PJL n°369 Principes République : Examen rapport pour avis-Communication conf. ART13 TSCG	2021-03-16 16:35:00	2021-03-16 17:25:00	2021-03-16 18:29:50	2021-03-17 16:58:53	29	0	\N	\N
539069	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition Art 13-Mme Florence PEYBERNES (Psdte  H3C)	Audition Art 13-Mme Florence PEYBERNES (Psdte  H3C)	2021-03-17 11:00:00	2021-03-17 12:20:00	2021-03-17 12:40:12	2021-03-17 16:59:01	34	0	\N	\N
539075	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 -  Enseignants matières scientifiques - Grenelle de l'éducation/OCDE	Contrôle 2021 -  Enseignants matières scientifiques - Grenelle de l'éducation/OCDE	2021-03-09 14:00:00	2021-03-09 16:30:00	\N	\N	1	0	\N	\N
539139	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audition pour le PJL Extradition Algérie	\N	2021-03-03 17:00:00	2021-03-03 18:00:00	\N	\N	0	0	\N	\N
539144	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audition pour le PJL Extradition Algérie	\N	2021-03-03 17:00:00	2021-03-03 18:00:00	\N	\N	0	0	\N	\N
539147	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Hébergement d'urgence - Fédération des acteurs de la solidarité (FAS)	Contrôle 2021 - Hébergement d'urgence - Fédération des acteurs de la solidarité (FAS)	2021-03-09 08:45:00	2021-03-09 09:45:00	\N	\N	1	0	\N	\N
539151	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Hébergement d¿urgence - Croix Rouge Française/DRIHL	Contrôle 2021 - Hébergement d¿urgence - Croix Rouge Française/DRIHL	2021-03-10 13:30:00	2021-03-10 15:25:00	\N	\N	1	0	\N	\N
539160	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Situation et perspectives SNCF - PDG SNCF	Contrôle 2021 - Situation et perspectives SNCF - PDG SNCF	2021-03-09 09:00:00	2021-03-09 10:00:00	\N	\N	2	0	\N	\N
539173	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 2021 - Mesures de soutien Industrie aéronautique - Cour des comptes	58-2 2021 - Mesures de soutien Industrie aéronautique - Cour des comptes	2021-03-10 16:30:00	2021-03-10 17:45:00	\N	\N	1	0	\N	\N
539181	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - PGE - OCDE	Contrôle 2021 - PGE - OCDE	2021-03-10 16:10:00	2021-03-10 17:15:00	\N	\N	1	0	\N	\N
540544	MISSION	AUDRAP	\N	METHANIS	\N	Audition Amorce	Audition Amorce	2021-03-15 14:00:00	2021-03-15 14:45:00	\N	\N	4	0	\N	\N
540557	MISSION	AUDRAP	\N	METHANIS	\N	Audition Chambres d'agriculture de France	Audition Chambres d'agriculture de France	2021-03-15 15:30:00	2021-03-15 16:15:00	\N	\N	5	0	\N	\N
541391	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition CDC	\N	2021-03-16 17:05:00	2021-03-16 18:15:00	\N	\N	6	0	\N	\N
541398	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition CIAM	Audition CIAM	2021-03-16 18:15:00	2021-03-16 19:00:00	\N	\N	6	0	\N	\N
545333	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Commission des affaires étrangères	Table ronde sur les Etats-Unis et désignation de rapporteurs	2021-03-31 10:00:00	2021-03-31 11:35:00	2021-03-31 16:45:15	2021-03-31 18:03:09	29	0	\N	\N
545526	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2021-03-24 14:00:00	2021-03-24 14:45:00	\N	\N	27	0	\N	\N
546514	GIA	AUCUNE	\N	\N	\N	Entretien avec Thomas Gomart, directeur de l'IFRI	Entretien avec Thomas Gomart, directeur de l'Institut français des relations internationales	2021-03-31 08:00:00	2021-03-31 09:30:00	\N	\N	9	0	608	\N
550141	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Transport de marchandises - DGITM	MI Transport de marchandises - Direction générale des infrastructures, des transports et de la mer	2021-04-06 14:35:00	2021-04-06 16:00:00	\N	\N	10	0	\N	\N
550154	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Transport de marchandises - Amazon France	MI Transport de marchandises - Amazon France	2021-04-06 16:00:00	2021-04-06 17:05:00	\N	\N	7	0	\N	\N
555071	GIA	AUCUNE	\N	\N	\N	Audition Mme Rispal, ambassadrice de France au Canada	Audition Mme Rispal, ambassadrice de France au Canada	2021-04-21 16:00:00	2021-04-21 17:30:00	\N	\N	10	0	583	\N
557303	COM_PERMANENTE	AUTRE	\N	FINC	\N	Projet de décret d'avance - Audition de M. Olivier DUSSOPT, ministre délégué	Projet de décret d'avance - Audition de M. Olivier DUSSOPT, ministre délégué	2021-05-11 19:00:00	2021-05-11 20:00:00	2021-05-11 20:44:27	2021-05-12 15:27:51	26	0	\N	\N
557305	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examens Rapports PJL 535 et PPL 531 - Com RG projet décret d'avance et Controle PGE	Examens Rapports PJL 535 et PPL 531 - Com RG projet décret d'avance et Controle PGE	2021-05-12 09:00:00	2021-05-12 11:50:00	2021-05-12 14:35:57	2021-05-12 15:27:48	35	0	\N	\N
557326	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Dérèglement climatique et résilience - Auditions de M. Pascal Martin	PJL Dérèglement climatique et résilience - Auditions de M. Pascal Martin	2021-05-05 18:45:00	2021-05-05 19:35:00	\N	\N	4	0	\N	\N
557462	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PJL Climat "Forêt"	Auditions PJL Climat "Forêt"	2021-05-05 14:05:00	2021-05-05 15:05:00	\N	\N	1	0	\N	\N
557553	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Lutte contre l'indépendance fictive	\N	2021-05-05 16:30:00	2021-05-05 18:00:00	\N	\N	1	0	\N	\N
557556	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - Protection des épargnants -  FBF	Contrôle 2020 - Protection des épargnants -  FBF	2021-05-04 09:30:00	2021-05-04 10:40:00	\N	\N	2	0	\N	\N
557562	MECSS	AUDRAP	\N	\N	MECSS	Audition réserves des régimes de retraite	\N	2021-05-05 13:45:00	2021-05-05 14:45:00	\N	\N	4	0	\N	\N
557569	DELEGATION	AUTRE	\N	\N	PROS	Audition de Mme Amélie de MONTCHALIN	\N	2021-06-17 09:00:00	2021-06-17 10:30:00	\N	\N	0	0	\N	\N
557590	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Situation et perspectives SNCF - Cour des comptes/Commission Européenne	Contrôle 2021 - Situation et perspectives SNCF - Cour des comptes/Commission Européenne	2021-05-04 08:30:00	2021-05-04 10:30:00	\N	\N	2	0	\N	\N
557640	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Météo France - CEPMMT	Contrôle 2021 - Météo France - CEPMMT	2021-05-04 16:30:00	2021-05-04 17:30:00	\N	\N	1	0	\N	\N
557662	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Dérèglement Climatique et résilience - DGEC	PJL Dérèglement Climatique et résilience - DGEC	2021-05-04 18:15:00	2021-05-04 19:20:00	\N	\N	1	0	\N	\N
557695	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Dérèglement Climatique et résilience - DGPE	PJL Dérèglement Climatique et résilience - DGPE	2021-05-04 16:30:00	2021-05-04 17:30:00	\N	\N	1	0	\N	\N
595585	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2022 - Programme 144	\N	2021-10-19 17:00:00	2021-10-19 18:00:00	\N	\N	2	0	\N	\N
595588	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2022 - 	\N	2021-10-13 17:30:00	2021-10-13 18:30:00	\N	\N	2	0	\N	\N
595600	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Sapeurs-pompiers	CMP Sapeurs-pompiers	2021-10-26 14:30:00	2021-10-26 15:25:00	\N	\N	78	0	\N	\N
595601	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Activité professionnelle indépendante	PJL Activité professionnelle indépendante	2021-10-26 15:25:00	2021-10-26 19:10:00	\N	\N	124	0	\N	\N
595603	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2021-10-27 15:00:00	2021-10-27 16:15:00	\N	\N	235	0	\N	\N
595604	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Accélérer l'égalité	PPL Accélérer l'égalité	2021-10-27 16:30:00	2021-10-27 20:25:00	\N	\N	93	0	\N	\N
595605	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Accélérer l'égalité	PPL Accélérer l'égalité	2021-10-27 21:55:00	2021-10-28 23:35:00	\N	\N	44	0	\N	\N
595607	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Convention OIT	PJL Convention OIT	2021-10-28 10:30:00	2021-10-28 11:35:00	\N	\N	33	0	\N	\N
595608	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Mécanisme européen de stabilité	PJL Mécanisme européen de stabilité	2021-10-28 11:35:00	2021-10-28 12:40:00	\N	\N	47	0	\N	\N
595613	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Vigilance sanitaire	PJL Vigilance sanitaire	2021-10-28 12:40:00	2021-10-28 13:10:00	\N	\N	46	0	\N	\N
595614	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Vigilance sanitaire	PJL Vigilance sanitaire	2021-10-28 15:15:00	2021-10-28 19:55:00	\N	\N	91	0	\N	\N
606304	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2022	PLF pour 2022	2021-11-22 14:30:00	2021-11-22 19:30:00	\N	\N	69	0	\N	\N
606306	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2022	PLF pour 2022	2021-11-23 14:30:00	2021-11-23 15:50:00	\N	\N	227	0	\N	\N
606658	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Nouveau pacte de citoyenneté avec la jeunesse	PPL Nouveau pacte de citoyenneté avec la jeunesse	2021-11-18 09:30:00	2021-11-18 10:15:00	\N	\N	2	0	\N	\N
606661	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Nouveau pacte de citoyenneté avec la jeunesse	PPL Nouveau pacte de citoyenneté avec la jeunesse	2021-11-18 10:15:00	2021-11-18 11:45:00	\N	\N	1	0	\N	\N
606828	COM_PERMANENTE	AUTRE	\N	CAE	\N	PJLF 2022 - Examen rapport pour avis Economie	\N	2021-11-23 09:30:00	2021-11-23 10:40:00	2021-11-23 10:50:00	2021-11-23 17:19:44	29	0	\N	\N
606854	COM_PERMANENTE	AUTRE	\N	CAE	\N	PJLF 2022 - rapport pour avis "Recherche"	\N	2021-11-23 17:00:00	2021-11-23 19:50:00	2021-11-24 09:36:49	2021-11-24 16:38:29	38	0	\N	\N
606857	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition Mme Pompili	\N	2021-11-24 16:35:00	2021-11-24 18:25:00	2021-11-24 19:06:14	2021-11-25 17:02:15	19	0	\N	\N
606896	ETUDES	AUDRAP	\N	\N	\N	SE Pêche et produits de la mer - Audition M. Philippe Musquar	SE Pêche et produits de la mer - Audition M. Philippe Musquar	2021-11-16 13:30:00	2021-11-16 15:30:00	\N	\N	2	0	\N	919
606897	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	Auditions M. Alain Cadec	\N	2021-11-16 13:30:00	2021-11-16 15:30:00	\N	\N	0	0	\N	\N
606898	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	Audition de l'Union du mareyage français	\N	2021-10-28 09:30:00	2021-10-28 10:10:00	\N	\N	0	0	\N	\N
607170	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PPL Habitat en ZRR : Cabinet ministère de l'agriculture	Audition PPL Habitat en ZRR : Cabinet ministère de l'agriculture	2021-11-17 16:00:00	2021-11-17 16:30:00	\N	\N	1	0	\N	\N
607171	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PPL habitat ZRR : Fnaim-FFCMI	Auditions PPL habitat ZRR : Fnaim-FFCMI	2021-11-18 10:00:00	2021-11-18 11:00:00	\N	\N	2	0	\N	\N
607205	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PPL Habitat en ZRR : Cabinet ministère du logement	Audition PPL Habitat en ZRR : Cabinet ministère du logement	2021-11-23 12:15:00	2021-11-23 13:00:00	\N	\N	1	0	\N	\N
607206	GIA	AUCUNE	\N	\N	\N	Entretien avec une délégation djiboutienne	Entretien avec une délégation djiboutienne (ministre de la décentralisation et cinq présidents de conseils régionaux)	2021-11-23 15:45:00	2021-11-23 16:30:00	\N	\N	1	0	588	\N
607218	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Retraites agricoles - Audition Caisse centrale de la Mutualité sociale agricole	\N	2021-11-23 10:30:00	2021-11-23 12:10:00	\N	\N	1	0	\N	\N
607219	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Retraites agricoles - Audition Député A. Chassaigne, auteur PPL	\N	2021-11-23 13:45:00	2021-11-23 14:45:00	\N	\N	5	0	\N	\N
610747	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Foncier agricole	CMP Foncier agricole	2021-12-07 14:30:00	2021-12-07 15:30:00	\N	\N	71	0	\N	\N
610748	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Orientation sexuelle	PPL Orientation sexuelle	2021-12-07 15:35:00	2021-12-07 17:55:00	\N	\N	63	0	\N	\N
606855	COM_PERMANENTE	AUTRE	\N	CAE	\N	Examen rapport PPL habitat en ZRR 	\N	2021-11-24 09:30:00	2021-11-24 11:50:00	2021-11-24 12:20:32	2021-11-24 16:38:26	45	0	\N	\N
607183	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLFR pour 2021 (2) - Examen du rapport en nouvelle lecture et designation CMP CATNAT	PLFR pour 2021 (2) - Examen du rapport en nouvelle lecture et designation CMP catastrophes naturelles 	2021-11-24 09:30:00	2021-11-24 10:05:00	2021-11-24 10:57:10	2021-11-24 16:38:26	34	0	\N	\N
610750	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2021-12-08 15:00:00	2021-12-08 16:15:00	\N	\N	295	0	\N	\N
610751	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Pathologie enfant	PPL Pathologie enfant	2021-12-08 16:35:00	2021-12-08 17:45:00	\N	\N	71	0	\N	\N
610752	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Zones de revitalisation rurale	PPL Zones de revitalisation rurale	2021-12-08 17:45:00	2021-12-08 20:35:00	\N	\N	76	0	\N	\N
610753	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Débat Conseil européen des 16 et 17  décembre 2021	Débat Conseil européen des 16 et 17  décembre 2021	2021-12-08 22:05:00	2021-12-09 00:40:00	\N	\N	29	0	\N	\N
610754	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Revalorisation des pensions de retraites agricoles	PPL Revalorisation des pensions de retraites agricoles	2021-12-09 10:30:00	2021-12-09 12:00:00	\N	\N	56	0	\N	\N
610755	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR Israël	PPR Israël	2021-12-09 12:00:00	2021-12-09 13:30:00	\N	\N	48	0	\N	\N
610758	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Commémoration de la répression d'Algériens	PPL Commémoration de la répression d'Algériens	2021-12-09 16:00:00	2021-12-09 18:25:00	\N	\N	49	0	\N	\N
610759	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Nouveau pacte de citoyenneté	PPL Nouveau pacte de citoyenneté	2021-12-09 18:30:00	2021-12-09 20:05:00	\N	\N	30	0	\N	\N
611292	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	MCC sécurisation de la chasse	MCC sécurisation de la chasse	2021-12-07 16:35:00	2021-12-07 17:35:00	\N	\N	14	0	\N	\N
511871	COM_PERMANENTE	AUTRE	\N	CDD	\N	\N	\N	2020-12-16 09:38:00	2020-12-16 11:29:00	2020-12-16 11:59:14	2020-12-16 18:00:33	38	0	\N	\N
511900	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2020-12-08 09:03:00	2020-12-08 09:09:00	2020-12-09 14:30:03	2020-12-09 17:15:32	20	2	\N	\N
511901	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2020-12-09 10:30:00	2020-12-09 12:55:00	2020-12-09 14:33:24	2020-12-09 17:20:15	35	1	\N	\N
511986	COM_ENQUETE	PLENIERE	\N	PANDEMIE	\N	Examen du rapport	\N	2020-12-08 16:05:00	2020-12-08 18:45:00	2020-12-08 18:50:20	2020-12-09 11:59:47	30	0	\N	\N
512264	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PPL Création d'un pôle public du médicament et des produits médicaux - Amdts séance	PPL Création d'un pôle public du médicament et des produits médicaux - Amdts séance	2020-12-09 11:00:00	2020-12-09 11:30:00	2020-12-09 11:43:23	2020-12-09 17:20:34	44	0	\N	\N
512268	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2020-12-09 09:30:00	2020-12-09 11:25:00	2020-12-09 11:42:22	2020-12-09 17:19:54	44	0	\N	\N
526689	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition du Parlement  grec et nominations OEP	\N	2021-02-02 15:10:00	2021-02-02 16:45:00	2021-02-02 17:50:54	2021-02-02 18:27:08	29	0	\N	\N
526690	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition M. Dolamari et nominations OEP	\N	2021-02-03 10:00:00	2021-02-03 11:25:00	2021-02-03 12:30:44	2021-02-03 16:44:12	29	0	\N	\N
531048	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT subsidiarité	Réunion du GT subsidiarité	2021-02-11 08:30:00	2021-02-11 08:50:00	\N	\N	7	0	\N	\N
531077	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	\tCommission spéciale chargée du contrôle des comptes et de l'évaluation interne 	\tCommission spéciale chargée du contrôle des comptes et de l'évaluation interne 	2021-02-10 16:30:00	2021-02-10 17:45:00	2021-02-11 10:26:17	2021-02-11 18:28:53	6	0	\N	\N
534423	DELEGATION	AUCUNE	\N	\N	COLTER	TR initiatives santé des collectivités  + Rapport Grand Paris	\N	2021-03-11 09:30:00	2021-03-11 12:15:00	2021-03-11 17:23:40	\N	35	0	\N	\N
536900	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Groupe de travail sur l'avenir de La Poste	Groupe de travail sur l'avenir de La Poste	2021-03-04 14:00:00	2021-03-04 15:30:00	\N	\N	3	0	\N	\N
536904	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Groupe de travail sur l'avenir de La Poste	Groupe de travail sur l'avenir de La Poste	2021-03-04 16:00:00	2021-03-04 17:30:00	\N	\N	4	0	\N	\N
541642	ETUDES	AUCUNE	\N	\N	\N	Réunion GE Vigne et Vin	Réunion GE Vigne et Vin	2021-03-17 13:30:00	2021-03-17 15:00:00	\N	\N	24	0	\N	909
542852	ETUDES	AUCUNE	\N	\N	\N	Réunion GE Agriculture et alimentation	Réunion GE Agriculture et alimentation	2021-03-17 14:00:00	2021-03-17 15:00:00	\N	\N	34	0	\N	919
543064	MISSION	AUCUNE	\N	VIETUDIA	\N	Table ronde "santé psychologique"	\N	2021-03-25 14:35:00	2021-03-25 17:05:00	2021-03-26 09:04:33	2021-03-26 15:18:12	11	0	\N	\N
543076	DELEGATION	AUDRAP	\N	\N	PROS	Audition Commission européenne	Audition de M. Baudouin BAUDRU - Chef de la Représentation à Paris	2021-03-29 14:30:00	2021-03-29 15:30:00	\N	\N	2	0	\N	\N
543077	COM_PERMANENTE	DEPLACEMENT	\N	CDD	\N	Projet Canal Seine-Nord Europe-Visite de la plateforme multi-modale Delta 3 Dourges (62)	Projet Canal Seine-Nord Europe-Visite de la plateforme multi-modale Delta 3 Dourges (62)	2021-03-18 08:30:00	2021-03-18 16:00:00	\N	\N	10	0	\N	\N
544987	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT Institutions	Groupe de Travail Institutions	2021-03-24 16:15:00	2021-03-24 17:30:00	\N	\N	5	0	\N	\N
545020	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Expérimenter le retour à l'emploi des bénéficiaires du RSA	\N	2021-03-17 17:20:00	2021-03-17 18:00:00	\N	\N	4	0	\N	\N
545033	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Expérimenter le retour à l'emploi des bénéficiaires du RSA	\N	2021-03-24 15:45:00	2021-03-24 16:30:00	\N	\N	2	0	\N	\N
545048	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Expérimenter le retour à l'emploi des bénéficiaires du RSA	\N	2021-03-24 16:30:00	2021-03-24 17:30:00	\N	\N	3	0	\N	\N
545118	GIA	AUCUNE	\N	\N	\N	Audition de l'Ambassadeur de France au Sri Lanka	\N	2021-03-25 11:30:00	2021-03-25 12:50:00	\N	\N	5	0	550	\N
545468	MISSION	AUDRAP	\N	EGALCHAN	\N	Audition commune de sociologues spécialistes des inégalités scolaires	\N	2021-03-25 15:00:00	2021-03-25 16:45:00	\N	\N	2	0	\N	\N
545497	MISSION	AUCUNE	\N	METHANIS	\N	Table ronde avec les professionnels de la recherche agronome	\N	2021-04-06 16:30:00	2021-04-06 18:30:00	2021-04-06 19:37:36	2021-04-07 14:55:56	16	0	\N	\N
545582	DELEGATION	AUDRAP	\N	\N	211	Audition de l'Agence française de développement	Audition de l'Agence française de développement	2021-03-26 16:00:00	2021-03-26 16:50:00	\N	\N	1	0	\N	\N
545597	DELEGATION	AUDRAP	\N	\N	211	Audition de OXFAM France	Audition de OXFAM France	2021-03-26 15:00:00	2021-03-26 15:40:00	\N	\N	1	0	\N	\N
547778	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Respect des principes de la République (amendements de séance, suite)	PJL Respect des principes de la République (amendements de séance, suite)	2021-04-06 14:00:00	2021-04-06 14:30:00	2021-04-06 15:17:16	2021-04-06 18:00:04	20	0	\N	\N
505565	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Langues régionales	\N	2020-11-18 16:30:00	2020-11-18 17:30:00	\N	\N	3	0	\N	\N
547779	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Formation des élus - Lutte contre l'illectronisme - Expropriation des bien à l'abandon	Formation des élus - Lutte contre l'illectronisme - Expropriation des bien à l'abandon	2021-04-07 09:05:00	2021-04-07 11:15:00	2021-04-07 16:33:37	2021-04-07 16:47:43	32	0	\N	\N
547780	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJLC Article 1er de la Constitution et préservation de l'environnement - Audition Les 150	PJLC Article 1er de la Constitution et préservation de l'environnement - Audition Les 150	2021-04-07 11:15:00	2021-04-07 12:30:00	2021-04-07 16:33:48	2021-04-07 16:47:43	22	0	\N	\N
547801	MISSION	AUDRAP	\N	EGALCHAN	\N	MI Égalité des chances - Table ronde d'associations de communes	\N	2021-03-31 17:00:00	2021-03-31 18:45:00	\N	\N	3	0	\N	\N
547818	MISSION	AUCUNE	\N	EGALCHAN	\N	Réunion plénière MI Jeunes	\N	2021-04-01 11:00:00	2021-04-01 12:00:00	2021-04-01 12:03:10	2021-04-01 17:49:28	9	0	\N	\N
547839	ETUDES	AUTRE	\N	\N	\N	Table ronde éolienne	\N	2021-03-31 14:00:00	2021-03-31 15:00:00	\N	\N	7	0	\N	922
547892	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	Audition de M.Bouselmi et du Dr Sarah Dauchy	2021-04-07 09:30:00	2021-04-07 10:50:00	2021-04-07 11:07:24	2021-04-07 14:55:45	41	0	\N	\N
547893	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière PPL Expérimenter le retour à l'emploi des bénéficiaires du RSA	\N	2021-04-07 10:50:00	2021-04-07 12:15:00	2021-04-07 12:13:46	2021-04-07 14:55:41	36	0	\N	\N
547911	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur - commission européenne (DSA/DMA)	\N	2021-03-31 17:30:00	2021-03-31 18:50:00	\N	\N	2	0	\N	\N
547927	MISSION	AUCUNE	\N	VIETUDIA	\N	table ronde associations et su=yndicats étudiants	table ronde associations et su=yndicats étudiants	2021-04-08 11:00:00	2021-04-08 12:40:00	2021-04-19 13:19:14	\N	12	0	\N	\N
548248	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions évaluation SRU	\N	2021-03-30 08:45:00	2021-03-30 10:15:00	\N	\N	2	0	\N	\N
548251	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions évaluation SRU	\N	2021-03-31 17:45:00	2021-03-31 18:30:00	\N	\N	1	0	\N	\N
548253	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Suivi loi SRU	Auditions Suivi loi SRU	2021-04-01 11:15:00	2021-04-01 12:15:00	\N	\N	2	0	\N	\N
548285	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Rapporteur - M. Sébastien Thierry, agence Erasmus +	Audition de M. Sébastien Thierry, directeur adjoint de l'agence Erasmus + volet education et formation	2021-03-31 11:00:00	2021-03-31 12:15:00	\N	\N	2	0	\N	\N
548488	ETUDES	AUTRE	\N	\N	\N	Audition FNB	\N	2021-03-31 13:45:00	2021-03-31 15:00:00	\N	\N	20	0	\N	911
548512	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	CCR	\N	2021-04-06 15:30:00	2021-04-06 16:30:00	\N	\N	1	0	\N	\N
548649	MISSION	AUDRAP	\N	METHANIS	\N	Audition Agences de l'eau	Audition Agences de l'eau	2021-04-01 13:45:00	2021-04-01 14:30:00	\N	\N	9	0	\N	\N
550892	MISSION	AUCUNE	\N	EGALCHAN	\N	Réunion plénière MI Jeunes	\N	2021-04-08 14:30:00	2021-04-08 15:35:00	2021-04-08 16:23:23	2021-04-08 17:29:41	5	0	\N	\N
550893	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI Réforme du 1er cycle des études de santé	Conférence des doyens des facultés de médecine	2021-04-01 13:30:00	2021-04-01 14:30:00	\N	\N	1	0	\N	\N
550923	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Conférence des présidents d'université (CPU)	\N	2021-04-01 14:30:00	2021-04-01 15:30:00	\N	\N	2	0	\N	\N
587386	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteurs - Seimas de Lituanie	Audition rapporteurs - Seimas de Lituanie	2021-09-28 16:15:00	2021-09-28 17:30:00	\N	\N	3	0	\N	\N
587615	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Droit de visite pour les malades en établissements	\N	2021-09-29 14:00:00	2021-09-29 14:45:00	\N	\N	1	0	\N	\N
587618	MISSION	AUCUNE	\N	METHANIS	\N	Réunion plénière MI Méthanisation	\N	2021-09-29 16:30:00	2021-09-29 18:11:00	2021-09-29 19:10:05	2021-09-30 18:42:23	16	0	\N	\N
587935	COM_PERMANENTE	AUTRE	\N	CAE	\N	Examen PPL Barrages hydroélectriques	\N	2021-10-06 09:30:00	2021-10-06 10:40:00	2021-10-07 11:21:15	2021-10-08 18:04:52	43	0	\N	\N
587936	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de M. Alain Griset	\N	2021-10-05 15:00:00	2021-10-05 16:40:00	2021-10-06 12:16:19	2021-10-06 16:05:37	71	0	\N	\N
587948	ETUDES	AUTRE	\N	\N	\N	Audition filière professionnelle gibier	\N	2021-09-29 08:00:00	2021-09-29 09:30:00	\N	\N	19	0	\N	907
587977	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Table ronde avec les spécialistes du droit du sport	\N	2021-09-29 17:00:00	2021-09-29 19:40:00	\N	\N	2	0	\N	\N
595558	GIA	AUCUNE	\N	\N	\N	entretien avec S.E. M. Sami ALSULAIMAN, ambassadeur du Koweït	\N	2021-10-21 15:00:00	2021-10-21 16:15:00	\N	\N	1	0	661	\N
602929	GIA	AUCUNE	\N	\N	\N	Audition association Zemus et fondation Maat	Audition des représentants de l'association Zemus et de la fondation Maat	2021-11-10 08:30:00	2021-11-10 09:40:00	\N	\N	9	0	641	\N
610617	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Protection des lanceurs d'alerte PPLO Rôle du Défenseur des droits	\N	2021-12-01 17:00:00	2021-12-01 19:00:00	\N	\N	1	0	\N	\N
610675	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Auditions de M. Fabrice Leggeri puis de M. Nicolas de Lacoste	\N	2021-12-08 09:55:00	2021-12-08 12:45:00	2021-12-08 15:36:04	2021-12-08 17:01:14	41	0	\N	\N
612311	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Protection des lanceurs d'alerte PPLO Rôle du Défenseur des droits	\N	2021-12-07 15:00:00	2021-12-07 18:00:00	\N	\N	1	0	\N	\N
612318	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière, examen de notes scientifiques	Réunion plénière, examen de notes scientifiques 	2021-12-09 09:35:00	2021-12-09 12:40:00	\N	\N	13	0	\N	\N
613152	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Alexandre Orlov, secrétaire général exécutif du Dialogue de Trianon	Entretien avec M. Alexandre Orlov, secrétaire général exécutif du Dialogue de Trianon	2021-12-08 08:30:00	2021-12-08 09:30:00	\N	\N	10	0	608	\N
613179	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2021-12-09 09:00:00	2021-12-09 10:00:00	\N	\N	3	0	\N	\N
613183	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2021-12-09 10:00:00	2021-12-09 12:30:00	\N	\N	3	0	\N	\N
613191	COM_ENQUETE	PLENIERE	\N	CABINETS	\N	Auditions des Administrations de santé et des Cabinets de conseil	Auditions des Administrations de santé et des Cabinets de conseil	2021-12-15 16:30:00	2021-12-15 19:10:00	2021-12-15 19:12:32	2021-12-16 17:04:32	12	0	\N	\N
618874	GIA	AUCUNE	\N	\N	\N	accueil Tashi Phuntsok	accueil Tashi Phuntsok	2022-01-18 14:45:00	2022-01-18 16:00:00	\N	\N	7	0	634	\N
620685	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteurs - M. Stéphane BERN	Audition rapporteurs - culture et patrimoine - M. Stéphane BERN	2022-01-20 11:00:00	2022-01-20 12:30:00	\N	\N	2	0	\N	\N
620742	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition M.E. Leclerc	\N	2022-01-19 09:10:00	2022-01-19 11:40:00	2022-01-19 13:59:58	2022-01-24 15:28:52	44	0	\N	\N
620743	COM_PERMANENTE	AUTRE	\N	CAE	\N	\N	\N	2022-01-19 11:45:00	2022-01-19 12:50:00	2022-01-19 15:55:02	2022-01-24 15:28:51	45	0	\N	\N
505583	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Langues régionales	\N	2020-11-18 17:30:00	2020-11-18 18:15:00	\N	\N	2	0	\N	\N
610674	COM_PERMANENTE	AUTRE	\N	ETRD	\N	2 examens de rapports et textes	\N	2021-12-08 09:35:00	2021-12-08 09:55:00	2021-12-08 15:21:41	2021-12-08 17:01:15	35	3	\N	\N
620888	COM_PERMANENTE	AUTRE	\N	FINC	\N	PPL 225 Marché de l'assurance emprunteur : Examen du rapport pour avis	PPL 225 Marché de l'assurance emprunteur : Examen du rapport pour avis	2022-01-18 16:35:00	2022-01-18 17:25:00	2022-01-18 17:52:09	2022-01-19 17:06:58	25	0	\N	\N
620889	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition sur "Taux réduits : anticiper la transposition de la nouvelle directive TVA"	Audition sur "Taux réduits : anticiper la transposition de la nouvelle directive TVA"	2022-01-19 10:35:00	2022-01-19 12:15:00	2022-01-19 12:48:57	2022-01-19 17:06:55	36	0	\N	\N
621280	MISSION	AUDRAP	\N	JUDI	\N	\N	Audition rapporteur - MI Judiciarisation	2022-01-12 16:30:00	2022-01-12 18:40:00	\N	\N	2	0	\N	\N
622378	GIA	AUCUNE	\N	\N	\N	Entretien avec des chercheurs de l'IFRI	Entretien avec les auteurs d'une étude de l'IFRI sur les influences chinoises en Afrique	2022-01-19 08:30:00	2022-01-19 09:40:00	\N	\N	13	0	573	\N
625180	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Sébastien Surun, ambassadeur de France en Mongolie	Entretien avec M. Sébastien Surun, ambassadeur de France en Mongolie	2022-01-26 08:05:00	2022-01-26 09:00:00	\N	\N	9	0	612	\N
626143	GIA	AUCUNE	\N	\N	\N	Audition de l'Ambassadeur de France au Kazakhstan	Audiotn de M. Didier CANESSE, Ambassadeur au Kazakhstan	2022-01-26 14:00:00	2022-01-26 15:00:00	\N	\N	6	0	556	\N
629322	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Echange de vues entre les membres de la commission d¿enquête	\N	2022-02-08 18:00:00	2022-02-08 19:00:00	\N	\N	0	0	\N	\N
629325	MISSION	AUCUNE	\N	CULTURE	\N	Réunion 20220209b	\N	2022-02-09 16:45:00	2022-02-09 18:00:00	2022-02-09 17:59:11	2022-02-10 18:00:48	7	0	\N	\N
629326	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Auditions plénières - TR Écoles service public - TR Syndicats fonction publique	\N	2022-02-09 16:30:00	2022-02-09 19:30:00	\N	\N	0	0	\N	\N
629327	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	Audition rapporteure - M. Martin Vial DG APE - M. Michaël Nathan, directeur SIG	\N	2022-02-10 10:30:00	2022-02-10 12:30:00	\N	\N	0	0	\N	\N
629329	MISSION	AUCUNE	\N	CULTURE	\N	Réunion 20220210	\N	2022-02-10 11:15:00	2022-02-10 12:15:00	2022-02-10 15:02:04	2022-02-10 18:00:50	5	0	\N	\N
629330	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL 350 Risques climatiques en agriculture - DB	PJL 350 Risques climatiques en agriculture - DB	2022-02-03 14:30:00	2022-02-03 15:00:00	\N	\N	1	0	\N	\N
629332	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - "Investir pour la France de 2030" - CSIA	PLF pour 2023 - "Investir pour la France de 2030" - CSIA	2022-02-01 09:30:00	2022-02-01 10:30:00	\N	\N	1	0	\N	\N
629337	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	audition biens spoliés	\N	2022-01-25 14:30:00	2022-01-25 15:35:00	\N	\N	2	0	\N	\N
629355	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	biens spoliés	\N	2022-01-27 14:00:00	2022-01-27 15:30:00	\N	\N	3	0	\N	\N
629359	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	biens spoliés	\N	2022-02-01 16:45:00	2022-02-01 17:45:00	\N	\N	1	0	\N	\N
629363	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	biens spoliés	\N	2022-02-03 14:15:00	2022-02-03 16:45:00	\N	\N	2	0	\N	\N
629368	COM_ENQUETE	AUDRAP	\N	HOPITAL	\N	CE Hôpital - Audition de l'EHESP	\N	2022-02-03 17:30:00	2022-02-03 18:30:00	\N	\N	4	0	\N	\N
629410	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Tourisme	GT Tourisme	2022-02-02 13:30:00	2022-02-02 14:30:00	\N	\N	3	0	\N	\N
629414	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Aménagement du territoire - Audition de MM. Belin et Babary	MI Aménagement du territoire - Audition de MM. Belin et Babary	2022-02-01 14:30:00	2022-02-01 18:15:00	\N	\N	2	0	\N	\N
629417	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Aménagement du territoire - Audition de MM. Belin et Babary	MI Aménagement du territoire - Audition de MM. Belin et Babary	2022-02-03 14:00:00	2022-02-03 15:00:00	\N	\N	2	0	\N	\N
629420	GIA	AUCUNE	\N	\N	\N	Entretien avec une délégation du Sénat de Côte d'Ivoire	Entretien avec une délégation du Sénat de Côte d'Ivoire dans le cadre du programme européen de coopération Interpares	2022-02-02 12:30:00	2022-02-02 14:15:00	\N	\N	2	0	573	\N
629766	GIA	AUCUNE	\N	\N	\N	Entretien avec SE M. Henok TEFERA, Ambassadeur d'Ethiopie en France 	Entretien avec SE M. Henok TEFERA, Ambassadeur d'Ethiopie en France	2022-02-08 14:00:00	2022-02-08 15:10:00	\N	\N	7	0	588	\N
630083	COM_PERMANENTE	AUTRE	\N	CDD	\N	\N	\N	2022-02-09 08:30:00	2022-02-09 09:00:00	2022-02-09 17:15:47	2022-02-11 16:48:16	36	2	\N	\N
630502	MISSION	AUDRAP	\N	JUDI	\N	Ministère de l'Europe et des affaires européennes	\N	2022-02-09 12:00:00	2022-02-09 13:00:00	\N	\N	3	0	\N	\N
630526	GIA	AUCUNE	\N	\N	\N	Audition auteurs rapport d'informaqtion de la CAED sur le Haut Karabagh	Audition des sénateurs Cigolotti et Carlotti pour leur rapport d'information sur le Haut Karabaghh	2022-02-09 08:30:00	2022-02-09 09:30:00	\N	\N	12	0	641	\N
630539	MISSION	AUCUNE	\N	CULTURE	\N	Réunion 20220209a	\N	2022-02-09 13:50:00	2022-02-09 14:30:00	2022-02-16 09:42:19	2022-02-16 10:45:32	9	0	\N	\N
514683	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Auditions GT Nouvelles formes de commerce	Auditions GT Nouvelles formes de commerce	2020-12-07 16:15:00	2020-12-07 17:40:00	\N	\N	2	0	\N	\N
514687	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Auditions GT Nouvelles formes de commerce	Auditions GT Nouvelles formes de commerce	2020-12-07 17:45:00	2020-12-07 18:15:00	\N	\N	2	0	\N	\N
526558	MECSS	AUCUNE	\N	\N	MECSS	Réunion plénière	Réunion plénière	2021-02-03 11:00:00	2021-02-03 12:20:00	2021-02-03 12:18:14	2021-02-03 16:44:13	17	0	\N	\N
533418	ETUDES	AUCUNE	\N	\N	\N	Audition FEVS	Audition FEVS	2021-02-17 13:30:00	2021-02-17 15:00:00	\N	\N	26	0	\N	909
534111	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Lutter contre les fraudes sociales	\N	2021-02-18 15:30:00	2021-02-18 16:30:00	\N	\N	1	0	\N	\N
534112	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Lutter contre les fraudes sociales	\N	2021-02-18 16:30:00	2021-02-18 17:30:00	\N	\N	1	0	\N	\N
534115	MISSION	AUCUNE	\N	CONF	\N	Table ronde "Salles de spectacles et de cinéma"	Table ronde "Salles de spectacles et de cinéma"	2021-03-04 10:35:00	2021-03-04 12:23:00	2021-03-04 13:57:58	2021-03-04 17:59:30	10	0	\N	\N
534116	DELEGATION	AUDRAP	\N	\N	PROS	Audition rapporteur de M. Gilles Babinet	\N	2021-02-01 09:00:00	2021-02-01 10:00:00	\N	\N	0	0	\N	\N
534117	DELEGATION	AUDRAP	\N	\N	PROS	Audition de la DINUM	\N	2021-02-08 09:00:00	2021-02-08 10:00:00	\N	\N	0	0	\N	\N
534118	DELEGATION	AUDRAP	\N	\N	PROS	Antoine BUENO, essayiste 	\N	2021-02-08 10:00:00	2021-02-08 11:00:00	\N	\N	0	0	\N	\N
534119	DELEGATION	AUDRAP	\N	\N	PROS	Audition de la CNIL	\N	2021-02-15 09:00:00	2021-02-15 10:00:00	\N	\N	0	0	\N	\N
534120	DELEGATION	AUDRAP	\N	\N	PROS	Audition de l'Institut Montaigne	\N	2021-02-15 10:00:00	2021-02-15 11:00:00	\N	\N	0	0	\N	\N
534121	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - NexSIS - Françoise DUMONT	Contrôle 2021 - NexSIS - Françoise DUMONT	2021-02-16 09:30:00	2021-02-16 10:30:00	\N	\N	1	0	\N	\N
534123	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	 Contrôle 2021 - NexSIS - ANSC	 Contrôle 2021 - NexSIS - ANSC	2021-02-16 14:15:00	2021-02-16 17:45:00	\N	\N	1	0	\N	\N
629334	COM_PERMANENTE	AUTRE	\N	FINC	\N	Contrôle 2021 - IHU - Déplacement A-ICM - Paris	Contrôle 2021 - IHU - Déplacement A-ICM - Paris	2022-02-03 13:30:00	2022-02-03 16:30:00	\N	\N	2	0	\N	\N
534165	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Service public d'eau potable et d'assainissement en Guadeloupe (rapport et texte)	PPL Service public d'eau potable et d'assainissement en Guadeloupe (rapport et texte)	2021-03-02 09:30:00	2021-03-02 10:25:00	2021-03-02 10:42:54	2021-03-03 17:05:59	25	0	\N	\N
534166	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Respect des principes de la République - Auditions d'universitaires	PJL Respect des principes de la République - Auditions d'universitaires	2021-03-02 17:40:00	2021-03-02 19:25:00	2021-03-02 19:41:45	2021-03-03 17:06:00	19	0	\N	\N
534168	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Sécurité globale (rapport et texte)	PPL Sécurité globale (rapport et texte)	2021-03-03 08:30:00	2021-03-03 12:00:00	2021-03-03 12:56:19	2021-03-03 17:06:02	44	0	\N	\N
534169	COM_PERMANENTE	AUTRE	\N	LOIS	\N	 PPL Droit au respect de la dignité en détention (rapport et texte)	 PPL Droit au respect de la dignité en détention (rapport et texte)	2021-03-03 14:00:00	2021-03-03 15:00:00	2021-03-03 15:19:53	2021-03-03 17:06:06	20	0	\N	\N
534170	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Respect des principes de la Rép. - Audition de Gérald Darmanin et Marlène Schiappa	PJL Respect des principes de la Rép. - Audition de Gérald Darmanin et Marlène Schiappa	2021-03-03 16:35:00	2021-03-03 18:40:00	2021-03-04 12:02:39	2021-03-04 17:57:17	28	0	\N	\N
534171	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Respect des principes de la République - Audition d'Eric Dupond-Moretti	PJL Respect des principes de la République - Audition d'Eric Dupond-Moretti	2021-03-03 18:50:00	2021-03-03 19:35:00	2021-03-04 12:02:55	2021-03-04 17:57:17	28	0	\N	\N
534194	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes - Audition plénière	\N	2021-03-04 11:30:00	2021-03-04 12:40:00	2021-03-04 16:20:40	2021-03-04 17:58:26	20	0	\N	\N
534195	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 4 mars 2021	\N	2021-03-04 10:30:00	2021-03-04 11:10:00	2021-03-04 11:37:59	2021-03-04 17:58:25	13	0	\N	\N
534196	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Droit à mourir dans la dignité - Table ronde d'institutions nationales	\N	2021-02-19 09:30:00	2021-02-19 10:40:00	\N	\N	3	0	\N	\N
534197	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Droit à mourir dans la dignité - Table ronde d'associations	\N	2021-02-19 11:00:00	2021-02-19 12:00:00	\N	\N	4	0	\N	\N
539694	GIA	AUCUNE	\N	\N	\N	Réunion du groupe France-Slovénie avec l'ambassadrice de Slovénie	Réunion du groupe France-Slovénie avec l'ambassadrice de Slovénie	2021-03-09 14:00:00	2021-03-09 15:15:00	\N	\N	5	0	529	\N
554032	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions PJL Climat	\N	2021-04-13 08:30:00	2021-04-13 09:30:00	\N	\N	7	0	\N	\N
554056	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions 3 rapporteurs	\N	2021-04-13 14:45:00	2021-04-13 15:30:00	\N	\N	4	0	\N	\N
554244	MISSION	AUCUNE	\N	VIETUDIA	\N	MIVE: Audition Maël DISA, DIOM (salle à renseigner)	MIVE: Audition Maël DISA, DIOM (salle à renseigner)	2021-04-15 08:45:00	2021-04-15 10:15:00	2021-04-15 15:12:57	2021-04-16 09:49:09	11	0	\N	\N
554345	ETUDES	AUTRE	\N	\N	\N	Audition acteurs économiques de la montagne	\N	2021-04-13 14:30:00	2021-04-13 16:30:00	\N	\N	16	0	\N	918
554348	MISSION	AUDRAP	\N	VIETUDIA	\N	Audition ESSEC	\N	2021-04-19 11:00:00	2021-04-19 12:03:00	\N	\N	2	0	\N	\N
554389	MISSION	AUCUNE	\N	VIETUDIA	\N	Audition plénière	\N	2021-04-15 11:00:00	2021-04-15 13:20:00	2021-04-15 15:18:41	2021-04-16 09:49:09	8	0	\N	\N
554405	ETUDES	AUTRE	\N	\N	\N	Audition MM. Giraud et Lemoyne	Audition MM. Giraud et Lemoyne	2021-04-14 08:30:00	2021-04-14 09:45:00	\N	\N	18	0	\N	918
554521	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Prestamed	\N	2021-04-21 14:00:00	2021-04-21 14:45:00	\N	\N	3	0	\N	\N
554536	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Rapporteur	\N	2021-04-22 16:00:00	2021-04-22 17:00:00	\N	\N	4	0	\N	\N
554537	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Rapporteur	Table ronde de professionnels de santé au travail	2021-04-22 15:00:00	2021-04-22 16:00:00	\N	\N	4	0	\N	\N
554538	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Amarok	\N	2021-04-22 14:00:00	2021-04-22 15:00:00	\N	\N	3	0	\N	\N
554539	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Audition FEPS	\N	2021-04-21 15:00:00	2021-04-21 15:45:00	\N	\N	3	0	\N	\N
554542	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition CARPIMKO	\N	2021-04-20 15:00:00	2021-04-20 15:45:00	\N	\N	4	0	\N	\N
554543	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition commune de kinésithérapeutes	\N	2021-04-20 14:00:00	2021-04-20 15:00:00	\N	\N	4	0	\N	\N
554606	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Table ronde RAC	\N	2021-04-15 08:30:00	2021-04-15 10:00:00	\N	\N	8	0	\N	\N
554615	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Régions de France	\N	2021-04-15 10:00:00	2021-04-15 11:00:00	\N	\N	5	0	\N	\N
554621	COM_PERMANENTE	AUDRAP	\N	CDD	\N	U2P	\N	2021-04-15 11:45:00	2021-04-15 12:30:00	\N	\N	4	0	\N	\N
554626	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Table ronde Syndicats	\N	2021-04-15 14:00:00	2021-04-15 15:30:00	\N	\N	4	0	\N	\N
554631	COM_PERMANENTE	AUDRAP	\N	CDD	\N	France urbaine	\N	2021-04-15 15:30:00	2021-04-15 16:30:00	\N	\N	3	0	\N	\N
554635	COM_PERMANENTE	AUDRAP	\N	CDD	\N	ADF	\N	2021-04-15 16:45:00	2021-04-15 17:45:00	\N	\N	3	0	\N	\N
554639	ETUDES	AUTRE	\N	\N	\N	Table ronde sur l'innovation en oncologie	\N	2021-04-14 13:30:00	2021-04-14 15:00:00	\N	\N	9	0	\N	1004
554640	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Innovation en santé - Table ronde sur l'innovation en oncologie	\N	2021-04-14 13:30:00	2021-04-14 15:00:00	\N	\N	6	0	\N	\N
555425	MISSION	AUDRAP	\N	VIETUDIA	\N	Audition	Les études de santé et les défis de la crise sanitaire : témoignages des associations 	2021-05-03 10:05:00	2021-05-03 11:50:00	\N	\N	6	0	\N	\N
555438	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Financement aires protégées - Conservatoire du littoral	Contrôle 2021 - Financement aires protégées - Conservatoire du littoral	2021-04-27 11:30:00	2021-04-27 12:30:00	\N	\N	1	0	\N	\N
555440	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Financement aires protégées - AdF	Contrôle 2021 - Financement aires protégées - AdF	2021-04-29 14:30:00	2021-04-29 15:30:00	\N	\N	1	0	\N	\N
555442	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Financement aires protégées - Inter-réseau Natura 2000	Contrôle 2021 - Financement aires protégées - Inter-réseau Natura 2000	2021-04-29 16:00:00	2021-04-29 17:00:00	\N	\N	1	0	\N	\N
557697	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de Mme Barbara Pompili	\N	2021-05-11 14:35:00	2021-05-11 17:25:00	2021-05-12 09:50:34	2021-05-12 15:27:53	37	0	\N	\N
601484	DELEGATION	AUCUNE	\N	\N	211	Audition de membres du groupe de travail sur la prostitution des mineurs	Audition de membres du groupe de travail sur la prostitution des mineurs	2021-11-18 10:15:00	2021-11-18 12:30:00	2021-11-18 12:29:27	\N	9	0	\N	\N
601486	DELEGATION	AUTRE	\N	\N	DSOM	Audition du Cluster maritime français	\N	2021-11-18 11:00:00	2021-11-18 12:30:00	\N	\N	10	0	\N	\N
601489	DELEGATION	AUCUNE	\N	\N	DSOM	Audition de M. Jean-Marc Ayrault	\N	2021-11-18 14:30:00	2021-11-18 15:35:00	\N	\N	4	0	\N	\N
604401	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Présidence française du Conseil de l'Union européenne	Débat	2021-11-16 17:25:00	2021-11-16 19:00:00	\N	\N	73	0	\N	\N
607452	DELEGATION	AUDRAP	\N	\N	206	Audition de rapporteur sur le déclin des insectes	\N	2021-11-23 15:30:00	2021-11-23 16:30:00	\N	\N	1	0	\N	\N
608579	GIA	AUCUNE	\N	\N	\N	Entretien avec le Club d'affaires France-Vanuatu	Entretien avec le Club d'affaires France-Vanuatu	2021-11-25 08:30:00	2021-11-25 09:45:00	\N	\N	6	0	651	\N
608595	QUESTURE	AUCUNE	\N	\N	\N	Réunion de Questure	Réunion de Questure	2021-11-25 09:10:00	2021-11-25 10:50:00	\N	\N	3	0	\N	\N
608632	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Table ronde des ESMS (Etablissements et services médico-sociaux)	\N	2021-11-25 14:00:00	2021-11-25 15:15:00	\N	\N	2	0	\N	\N
608646	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Commission indépendante prévue à l'article 25 de la Constitution - Audition d'Éric Doligé	Commission indépendante prévue à l'article 25 de la Constitution - Audition d'Éric Doligé	2021-12-08 18:00:00	2021-12-08 18:30:00	2021-12-08 18:35:11	2021-12-09 15:58:07	14	0	\N	\N
608649	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition d'Élisabeth Guigou sur son rapport sur la présomption d¿innocence	Audition d'Élisabeth Guigou sur son rapport sur la présomption d¿innocence	2021-12-01 11:30:00	2021-12-01 12:40:00	2021-12-01 12:39:23	2021-12-01 17:29:45	20	1	\N	\N
609229	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2021-11-30 16:30:00	2021-11-30 19:30:00	\N	\N	3	0	\N	\N
609264	GIA	AUCUNE	\N	\N	\N	Table ronde sur les écoles chrétiennes francophones d'Orient	Table ronde sur les écoles chrétiennes francophones du Moyen-Orient	2021-11-30 15:00:00	2021-11-30 16:30:00	\N	\N	15	0	CHRETORIENT	CHRETORIENT
609281	GIA	AUCUNE	\N	\N	\N	Echanges avec des étudiants américains 	Echanges avec des étudiants de Colgate University (Hamilton, New York)k)	2021-11-30 11:45:00	2021-11-30 12:45:00	\N	\N	3	0	590	\N
610686	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Interdire les pratiques visant à modifier l'orientation sexuelle	Audition rapporteur - PPL Interdire les pratiques visant à modifier l'orientation sexuelle	2021-11-30 18:30:00	2021-11-30 19:30:00	\N	\N	1	0	\N	\N
610729	COM_ENQUETE	PLENIERE	\N	MEDIA	\N	Audition M. Louette et M. Gourdin	Audition M. Louette et M. Gourdin	2021-12-02 14:30:00	2021-12-02 16:35:00	2021-12-03 09:59:11	2021-12-03 18:39:20	10	0	\N	\N
611227	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion pleinière CATDD	\N	2021-12-15 10:30:00	2021-12-15 12:30:00	2021-12-15 12:47:35	2021-12-15 17:07:49	33	1	\N	\N
611228	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Association des directeurs de MDPH	\N	2021-12-07 17:00:00	2021-12-07 18:30:00	\N	\N	2	0	\N	\N
611232	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Conseil national de l'ordre des masseurs-kinésithérapeutes	\N	2021-12-07 15:30:00	2021-12-07 16:30:00	\N	\N	2	0	\N	\N
611233	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Direction générale de la santé	Audition de Mme Laurence Cate	2021-12-07 14:00:00	2021-12-07 15:00:00	\N	\N	3	0	\N	\N
611239	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Audition de Mme Mila Sanchez	\N	2021-12-07 16:35:00	2021-12-07 17:35:00	\N	\N	0	0	\N	\N
611240	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Réunion du GT subsidiarité	\N	2021-12-07 15:30:00	2021-12-07 15:40:00	\N	\N	0	0	\N	\N
611995	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 15 décembre 2021	\N	2021-12-15 10:00:00	2021-12-15 11:05:00	2021-12-15 11:07:12	2021-12-15 17:08:20	39	0	\N	\N
611996	COM_EURO	AUTRE	\N	AFEU	\N	2e réunion du 15 décembre 2021	2e réunion du 15 décembre 2021	2021-12-15 13:50:00	2021-12-15 14:45:00	2021-12-15 17:31:22	2021-12-16 17:04:09	7	0	\N	\N
611997	ETUDES	AUTRE	\N	\N	\N	Afleya	Afleya	2021-11-24 13:45:00	2021-11-24 14:45:00	\N	\N	8	0	\N	922
612540	ETUDES	AUTRE	\N	\N	\N	Echange de vues	Echange de vues	2021-12-08 08:15:00	2021-12-08 09:15:00	\N	\N	9	0	\N	919
612654	ETUDES	AUTRE	\N	\N	\N	Echange de vues et audition M. Damien Lacombe	Echange de vues et audition M. Damien Lacombe	2021-12-08 13:30:00	2021-12-08 15:00:00	\N	\N	4	0	\N	919
612669	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Conseil national de l'ordre des médecins	\N	2021-12-08 13:30:00	2021-12-08 14:30:00	\N	\N	2	0	\N	\N
613190	DELEGATION	AUCUNE	\N	\N	PROS	Audition  sur Les outre-mer et l'Indopacifique	 sur Les outre-mer et l'Indopacifique	2021-12-16 09:00:00	2021-12-16 12:00:00	\N	\N	20	0	\N	\N
613365	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Référencement malades chroniques covid-19 - Entretien avec M. Michel Zumkeller	\N	2021-12-13 10:00:00	2021-12-13 10:20:00	\N	\N	1	0	\N	\N
613385	COM_PERMANENTE	AUTRE	\N	CAE	\N	Présentation RI sécurité d'acheminement des communications d'urgence	\N	2021-12-15 09:05:00	2021-12-15 09:30:00	2021-12-15 16:07:43	2021-12-15 17:07:44	99	0	\N	\N
613386	COM_PERMANENTE	AUTRE	\N	CAE	\N	Présentation rapport Pêche et Brexit	\N	2021-12-15 10:00:00	2021-12-15 11:05:00	2021-12-15 16:09:02	2021-12-15 17:07:48	39	0	\N	\N
613387	COM_ENQUETE	PLENIERE	\N	MEDIA	\N	Rn concentration médias	\N	2021-12-13 15:30:00	2021-12-13 18:10:00	2021-12-13 18:32:13	2021-12-14 17:03:38	7	0	\N	\N
613396	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Référencement malades chroniques covid-19 - Table ronde d'associations	\N	2021-12-13 14:30:00	2021-12-13 15:40:00	\N	\N	2	0	\N	\N
613858	ETUDES	AUCUNE	\N	\N	\N	Audition de Maxime Toubard, président du SGV	Audition de Maxime Toubard, président du SGV	2021-12-14 15:00:00	2021-12-14 16:00:00	\N	\N	16	0	\N	909
614112	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2021-12-15 10:00:00	2021-12-15 11:45:00	2021-12-15 11:59:06	2021-12-15 17:07:48	25	0	\N	\N
614113	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	COLTER	Petit-déjeuner de programmation 2022	Petit-déjeuner de programmation 2022	2021-12-09 09:00:00	2021-12-09 10:00:00	\N	\N	11	0	\N	\N
614666	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2021-12-14 17:15:00	2021-12-14 18:00:00	\N	\N	8	0	\N	\N
614675	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2021-12-14 18:00:00	2021-12-14 18:40:00	\N	\N	3	0	\N	\N
614875	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Audition de Mme Maria Harti, présidente d'Interfaces	\N	2021-12-15 11:10:00	2021-12-15 12:15:00	2021-12-16 11:36:37	\N	8	0	\N	\N
615860	QUESTURE	AUCUNE	\N	\N	\N	Réunion de Questure	Réunion de Questure	2021-12-16 09:10:00	2021-12-16 10:45:00	\N	\N	3	0	\N	\N
550928	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Union nationale des étudiants de France (UNEF)	\N	2021-04-06 17:00:00	2021-04-06 17:45:00	\N	\N	1	0	\N	\N
613157	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI COM AEFE	\N	2021-12-09 14:30:00	2021-12-09 15:30:00	\N	\N	1	0	\N	\N
608647	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPLs Orientation sexuelle - Commémoration répression Algériens - Citoyenneté jeunesse	PPLs Orientation sexuelle - Commémoration répression Algériens - Citoyenneté jeunesse	2021-12-01 09:00:00	2021-12-01 11:30:00	2021-12-01 11:54:24	2021-12-01 17:29:41	37	3	\N	\N
616199	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	\tCommission spéciale chargée du contrôle des comptes et de l'évaluation interne	\tCommission spéciale chargée du contrôle des comptes et de l'évaluation interne	2021-12-15 16:30:00	2021-12-15 17:40:00	2021-12-16 16:49:07	2021-12-16 17:04:32	6	0	\N	\N
616290	GIA	AUCUNE	\N	\N	\N	Rencontre avec des parlementaires de Géorgie	Dîner en l'honneur de députés géorgiens	2021-12-08 20:00:00	2021-12-08 21:45:00	\N	\N	5	0	534	\N
616349	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Référencement malades chroniques covid-19 - Audition du Pr Yazdan Yazdanpanah	\N	2021-12-17 09:30:00	2021-12-17 10:00:00	\N	\N	1	0	\N	\N
616350	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Référencement malades chroniques covid-19 - Audition des Pr Salmon-Céron et Dr Tran	\N	2021-12-17 10:15:00	2021-12-17 11:00:00	\N	\N	1	0	\N	\N
507030	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Avis Cohésion des territoires - Table ronde de maires	Avis Cohésion des territoires - Table ronde de maires	2020-11-23 13:30:00	2020-11-23 14:30:00	\N	\N	6	0	\N	\N
507037	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Pôle public du médicament - Audition rapporteure	\N	2020-11-24 09:30:00	2020-11-24 10:30:00	\N	\N	3	0	\N	\N
522358	GIA	AUCUNE	\N	\N	\N	Entretien avec le représentant de Taipei en France	Entretien avec S.E. François WU, représentant de Taipei en France	2021-01-19 19:15:00	2021-01-19 19:45:00	\N	\N	11	0	623	\N
522374	GIA	AUCUNE	\N	\N	\N	\N	\N	2021-01-19 19:00:00	2021-01-19 19:15:00	\N	\N	11	0	623	\N
524137	DELEGATION	AUDRAP	\N	\N	206	Audition Production d'hydrogène - Table ronde analyse comparée en Allemagne et en France	Audition Production d'hydrogène - Table ronde analyse comparée en Allemagne et en France	2021-01-21 15:00:00	2021-01-21 16:15:00	\N	\N	1	0	\N	\N
524141	CONF_PRES	AUCUNE	\N	\N	\N	Conf. Prés	Conférence des Présidents	2021-01-20 14:05:00	2021-01-20 14:30:00	\N	\N	26	0	\N	\N
524168	GIA	AUCUNE	\N	\N	\N	E,ntretien avec M. Liyota Ndjoli, ancien ministre de la RDC	E,ntretien avec M. Liyota Ndjoli, ancien ministre de l'environnement puis des PME de la République démocratique du Congo	2020-11-17 14:00:00	2020-11-17 14:45:00	\N	\N	1	0	572	\N
524170	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe d'amitié	Assemblée générale du groupe d'amitié	2020-07-23 15:30:00	2020-07-23 16:00:00	\N	\N	4	0	572	\N
524175	GIA	AUCUNE	\N	\N	\N	l¿audition de M. Othman EL KACHTOUL, sous-directeur Afrique centrale au MEAE	l¿audition de M. Othman EL KACHTOUL, sous-directeur Afrique centrale au ministère de l'Europe et des Affaires étrangères	2020-07-23 14:30:00	2020-07-23 15:30:00	\N	\N	4	0	572	\N
525108	ETUDES	AUTRE	\N	\N	\N	Réunion constitutive	\N	2021-01-28 09:30:00	2021-01-28 10:45:00	\N	\N	10	0	\N	928
525137	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Négociation collective - Audition de Mme Christine Erhel	\N	2021-01-26 09:30:00	2021-01-26 10:30:00	\N	\N	1	0	\N	\N
525820	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Négociation collective - Audition de M. Jean-Claude Mailly	\N	2021-01-27 14:00:00	2021-01-27 15:00:00	\N	\N	2	0	\N	\N
525851	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Réunion plénière	\N	2021-02-03 10:30:00	2021-02-03 12:30:00	\N	\N	0	0	\N	\N
525852	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2021-02-03 09:05:00	2021-02-03 11:00:00	2021-02-03 11:01:28	2021-02-03 16:44:08	38	0	\N	\N
530455	ETUDES	AUCUNE	\N	\N	\N	Audition P. Médevielle	Audition P. Médevielle	2021-02-10 08:00:00	2021-02-10 09:00:00	\N	\N	19	0	\N	907
533542	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	Auditions GT Alimentation durable et locale	Auditions GT Alimentation durable et locale	2021-02-17 16:45:00	2021-02-17 17:45:00	\N	\N	2	0	\N	\N
537402	GIA	AUCUNE	\N	\N	\N	\N	Audition de M. Eric LINQUIER, commissaire général de la France à l¿exposition univ. de Dubaï et président de la Cofrex	2021-03-09 16:15:00	2021-03-09 17:15:00	\N	\N	6	0	661	\N
539666	DELEGATION	AUDRAP	\N	\N	PROS	Audition de la CNAM	Audition de la CNAM	2021-03-29 09:00:00	2021-03-29 10:00:00	\N	\N	3	0	\N	\N
539682	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Sécurité globale (amendements de séance)	PPL Sécurité globale (amendements de séance)	2021-03-16 09:00:00	2021-03-16 10:30:00	2021-03-16 11:41:16	2021-03-16 15:31:52	25	0	\N	\N
539685	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Respect des principes de la République (rapport et texte de la commission)	PJL Respect des principes de la République (rapport et texte de la commission)	2021-03-17 08:30:00	2021-03-17 13:10:00	2021-03-17 15:21:03	2021-03-17 16:58:56	41	0	\N	\N
539686	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Sécurité glob. (amdts - suite) - PJL Respect des principes de la République (rapport)	PPL Sécurité globale (amendements de séance - suite) - PJL Respect des principes de la Répulique (rapport et texte)	2021-03-17 14:00:00	2021-03-17 14:50:00	2021-03-17 15:20:34	2021-03-17 16:59:02	19	0	\N	\N
546664	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Drones	Groupe de travail Drones	2021-03-30 14:30:00	2021-03-30 17:00:00	\N	\N	4	0	\N	\N
548790	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Respect des principes de la République	PJL Respect des principes de la République	2021-04-06 14:30:00	2021-04-06 20:00:00	\N	\N	178	0	\N	\N
548791	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2021-04-07 15:00:00	2021-04-07 16:30:00	\N	\N	203	0	\N	\N
548792	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Respect des principes de la République	PJL Respect des principes de la République	2021-04-07 21:40:00	2021-04-08 00:10:00	\N	\N	84	0	\N	\N
548793	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Respect des principes de la République	PJL Respect des principes de la République	2021-04-07 17:50:00	2021-04-07 20:10:00	\N	\N	101	0	\N	\N
548794	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PPL Assainissement Guadeloupe	CMP PPL Assainissement Guadeloupe	2021-04-08 10:30:00	2021-04-08 11:35:00	\N	\N	37	0	\N	\N
548795	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Formation des élus locaux	PJL Formation des élus locaux	2021-04-08 11:35:00	2021-04-08 13:40:00	\N	\N	48	0	\N	\N
548798	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Respect des principes de la République	PJL Respect des principes de la République	2021-04-08 15:10:00	2021-04-08 20:00:00	\N	\N	74	0	\N	\N
548799	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Respect des principes de la République	PJL Respect des principes de la République	2021-04-08 21:30:00	2021-04-09 23:55:00	\N	\N	41	0	\N	\N
548802	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PJL Sécurité globale	CMP PJL Sécurité globale	2021-04-07 16:30:00	2021-04-07 17:45:00	\N	\N	74	0	\N	\N
550924	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Collectif Pass/LAS	\N	2021-04-01 15:30:00	2021-04-01 16:30:00	\N	\N	2	0	\N	\N
550926	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Comité de suivi de la réforme des études de santé	\N	2021-04-01 16:35:00	2021-04-01 17:42:00	\N	\N	2	0	\N	\N
550929	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Direction générale de l'enseignement supérieur et de l'insertion professionnelle (DGESIP)	\N	2021-04-06 18:00:00	2021-04-06 19:20:00	\N	\N	3	0	\N	\N
550930	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Union nationale inter-universitaire (UNI)	\N	2021-04-08 14:00:00	2021-04-08 15:00:00	\N	\N	1	0	\N	\N
550933	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Fédération des associations générales étudiantes(FAGE)	\N	2021-04-09 13:30:00	2021-04-09 14:30:00	\N	\N	2	0	\N	\N
550934	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Université de Bourgogne	\N	2021-04-09 14:30:00	2021-04-09 15:25:00	\N	\N	2	0	\N	\N
550935	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Faculté de médecine de Strasbourg	\N	2021-04-09 15:30:00	2021-04-09 16:40:00	\N	\N	1	0	\N	\N
550936	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Union régionale des médecins libéraux de Normandie	\N	2021-04-09 18:30:00	2021-04-09 19:45:00	\N	\N	2	0	\N	\N
550937	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Collège des directeurs généraux de l'Agence régionale de santé (ARS)	\N	2021-04-13 17:00:00	2021-04-13 17:50:00	\N	\N	1	0	\N	\N
550938	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Université de Paris	\N	2021-04-13 18:00:00	2021-04-13 19:10:00	\N	\N	1	0	\N	\N
550939	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Direction générale de l'offre de soins (DGOS)	\N	2021-04-16 17:30:00	2021-04-16 18:30:00	\N	\N	2	0	\N	\N
551079	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière	Réunion plénière	2021-04-08 08:30:00	2021-04-08 11:30:00	2021-04-08 14:45:17	\N	12	0	\N	\N
551124	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Commission des affaires étrangères	\N	2021-04-14 09:00:00	2021-04-14 11:05:00	2021-04-14 14:51:34	2021-04-14 18:25:17	39	0	\N	\N
551129	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Immobilier universitaire - CNOUS	Contrôle 2021 - Immobilier universitaire - CNOUS	2021-04-06 14:30:00	2021-04-06 15:30:00	\N	\N	1	0	\N	\N
551140	COM_PERMANENTE	AUTRE	\N	CAE	\N	Examen amendements de séance PPL Hydroélectricité	\N	2021-04-13 09:35:00	2021-04-13 09:50:00	2021-04-13 10:22:24	2021-04-14 18:25:20	18	0	\N	\N
603611	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Météo - Météo-France	PLF pour 2022 - Météo - Météo-France	2021-11-10 16:30:00	2021-11-10 17:45:00	\N	\N	1	0	\N	\N
603613	COM_EURO	AUDRAP	\N	AFEU	\N	Subventions étrangères	Subventions étrangères - Audition de M. Christophe Hansen	2021-11-15 16:30:00	2021-11-15 17:30:00	\N	\N	2	0	\N	\N
603619	COM_EURO	AUDRAP	\N	AFEU	\N	Accord d'association avec la Suisse - Commission européenne	Accord d'association avec la Suisse - Commission européenne 	2021-11-15 15:00:00	2021-11-15 15:30:00	\N	\N	2	0	\N	\N
603622	COM_EURO	AUDRAP	\N	AFEU	\N	Accord d'association avec la Suisse - Ambassade de Suisse en France	Accord d'association avec la Suisse - Ambassade de Suisse en France	2021-10-05 17:00:00	2021-10-05 18:00:00	\N	\N	2	0	\N	\N
603625	COM_EURO	AUDRAP	\N	AFEU	\N	Accord d'association avec la Suisse - RP Bruxelles	Accord d'association avec la Suisse - RP Bruxelles	2021-09-28 16:00:00	2021-09-28 16:40:00	\N	\N	2	0	\N	\N
603630	DELEGATION	AUDRAP	\N	\N	206	Audition de rapporteur	\N	2021-11-15 17:00:00	2021-11-15 18:00:00	\N	\N	1	0	\N	\N
603952	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	plf création	\N	2021-11-08 09:30:00	2021-11-08 10:45:00	\N	\N	2	0	\N	\N
603959	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2022 création - SAS Pass culture	\N	2021-11-08 16:30:00	2021-11-08 18:00:00	\N	\N	2	0	\N	\N
603967	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Pascal Martin - PLF pour 2022 - Avis prévention risques 	Auditions M. Pascal Martin - PLF pour 2022 - Avis prévention risques	2021-11-09 08:00:00	2021-11-09 09:00:00	\N	\N	1	0	\N	\N
603971	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Pascal Martin - PLF pour 2022 - Avis prévention risques 	Auditions M. Pascal Martin - PLF pour 2022 - Avis prévention risques 	2021-11-09 09:45:00	2021-11-09 10:45:00	\N	\N	1	0	\N	\N
603975	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Pascal Martin - PLF pour 2022 - Avis prévention risques 	Auditions M. Pascal Martin - PLF pour 2022 - Avis prévention risques 	2021-11-16 08:45:00	2021-11-16 09:45:00	\N	\N	1	0	\N	\N
604405	COM_PERMANENTE	AUTRE	\N	CAE	\N	Examen rapport pour avis crédits "logement"	\N	2021-11-16 17:30:00	2021-11-16 18:25:00	2021-11-16 18:56:53	2021-11-19 19:32:23	26	0	\N	\N
604468	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion planière CATDD	\N	2021-11-22 17:30:00	2021-11-22 20:00:00	2021-11-26 17:12:59	2021-11-29 10:41:33	17	4	\N	\N
604494	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition Bruno Le Maire	\N	2021-11-17 16:35:00	2021-11-17 17:55:00	2021-11-17 18:01:17	2021-11-19 19:32:15	32	0	\N	\N
606426	COM_PERMANENTE	AUTRE	\N	AFCL	\N	LEC PPLécomomie du livre et PPL bibliothèque	\N	2021-11-23 17:05:00	2021-11-23 18:10:00	2021-11-23 18:35:39	2021-11-24 16:38:28	27	4	\N	\N
606429	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2022 Travail et emploi - Audition de la CFTC	\N	2021-11-16 10:00:00	2021-11-16 11:00:00	\N	\N	2	0	\N	\N
606432	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Institut français	\N	2021-11-18 16:30:00	2021-11-18 18:00:00	\N	\N	1	0	\N	\N
606433	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Ministère de l'Europe et des affaires étrangères - DCERS	\N	2021-11-19 10:30:00	2021-11-19 11:30:00	\N	\N	1	0	\N	\N
606436	DELEGATION	AUTRE	\N	\N	DSOM	Table ronde "Ports" - Étude Outre-mer et stratégie maritime nationale	\N	2021-11-25 09:30:00	2021-11-25 12:00:00	\N	\N	13	0	\N	\N
609087	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Accord de sécurité sociale avec l'IESUE	\N	2021-11-30 10:40:00	2021-11-30 11:30:00	\N	\N	1	0	\N	\N
610860	ETUDES	AUTRE	\N	\N	\N	Déjeuner Tour de France	\N	2021-11-30 13:00:00	2021-11-30 15:00:00	\N	\N	23	0	\N	934
610884	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Ministères de la culture et de l'Europe	\N	2021-12-07 09:30:00	2021-12-07 10:45:00	\N	\N	4	0	\N	\N
611521	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Museum national d'histoire naturelle	Audition de M. Van Praët	2021-12-07 14:30:00	2021-12-07 15:15:00	\N	\N	4	0	\N	\N
611522	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Ministère de la justice - Cabinet	\N	2021-12-07 15:30:00	2021-12-07 16:00:00	\N	\N	4	0	\N	\N
611523	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Expert en droit du patrimoine culturel	Audition de M. Vincent Negri	2021-12-07 16:30:00	2021-12-07 17:45:00	\N	\N	4	0	\N	\N
604490	COM_PERMANENTE	AUTRE	\N	CAE	\N	Examen rapports pour avis PLF 2022	\N	2021-11-17 09:00:00	2021-11-17 10:15:00	2021-11-17 10:30:42	2021-11-19 19:32:19	45	0	\N	\N
604905	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-11-17 09:30:00	2021-11-17 11:00:00	2021-11-22 11:24:18	2021-11-22 11:51:44	41	1	\N	\N
606428	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2021-11-24 09:00:00	2021-11-24 11:25:00	2021-12-02 15:34:38	2021-12-08 16:33:49	38	0	\N	\N
612404	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2021-12-15 09:05:00	2021-12-15 09:30:00	2021-12-15 11:27:24	2021-12-15 17:07:45	99	0	\N	\N
612406	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2021-12-14 09:30:00	2021-12-14 10:55:00	2021-12-14 11:10:50	2021-12-14 17:03:16	22	0	\N	\N
612482	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2021-12-01 09:33:00	2021-12-01 11:36:00	2021-12-08 17:30:05	2021-12-08 17:39:53	38	0	\N	\N
613308	GIA	AUCUNE	\N	\N	\N	Coopé - Entretien avec M. John Tennant WRIGHT SOL, député salvadorien	Coopé - Entretien avec M. John Tennant WRIGHT SOL, député salvadorien	2021-12-08 11:00:00	2021-12-08 12:30:00	\N	\N	1	0	643	\N
615149	GIA	AUCUNE	\N	\N	\N	Entretien avec l'Ambassadeur de France au Cap-Vert	Entretien avec M. Olivier SEROT ALMERAS, Ambassadeur de France au Cap-Vert	2021-12-15 14:00:00	2021-12-15 14:50:00	\N	\N	4	0	573	\N
616238	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désignations - Avis PPL Harcèlement scolaire - Rapport PPL Casque à vélo	Désignations - Avis PPL Harcèlement scolaire - Rapport PPL Casque à vélo	2022-01-05 09:00:00	2022-01-05 10:10:00	2022-01-05 10:37:41	2022-01-05 17:10:02	32	1	\N	\N
616245	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Constitutive	\N	2021-12-07 17:15:00	2021-12-07 18:30:00	\N	\N	0	0	\N	\N
616260	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Auditions de M. Rojouan	\N	2021-12-14 15:45:00	2021-12-14 17:15:00	\N	\N	0	0	\N	\N
616266	COM_PERMANENTE	AUDRAP	\N	CAE	\N	M. Jean-Noël Cardoux, président du groupe d'études Chasse et pêche	M. Jean-Noël Cardoux, président du groupe d'études Chasse et pêche	2021-12-16 12:15:00	2021-12-16 13:00:00	\N	\N	3	0	\N	\N
616274	MISSION	AUCUNE	\N	CULTURE	\N	Réunion 20220104	\N	2022-01-04 15:30:00	2022-01-04 17:00:00	2022-01-04 16:59:52	2022-01-04 18:07:25	14	0	\N	\N
616275	MISSION	AUCUNE	\N	JUDI	\N	Auditions de Pierre Steinmetz et Jean-Éric Schoettl	Auditions de Pierre Steinmetz et Jean-Éric Schoettl	2022-01-04 15:00:00	2022-01-04 17:15:00	2022-01-04 17:39:51	2022-01-04 18:07:25	14	0	\N	\N
616277	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2022-01-05 09:35:00	2022-01-05 12:20:00	2022-01-05 17:19:09	2022-01-05 17:24:25	39	0	\N	\N
616280	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition plénière	\N	2022-01-05 16:35:00	2022-01-05 17:25:00	2022-01-05 17:31:18	2022-01-05 17:42:18	17	0	\N	\N
616287	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Association nationale des supporters	\N	2021-12-16 10:00:00	2021-12-16 11:00:00	\N	\N	1	0	\N	\N
616288	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Echanges avec les Députés rapporteur du texte à l'Assemblée nationale	\N	2021-12-16 13:30:00	2021-12-16 14:30:00	\N	\N	0	0	\N	\N
616289	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Club SC Bastia	\N	2021-12-16 15:00:00	2021-12-16 16:30:00	\N	\N	1	0	\N	\N
617520	MISSION	AUDRAP	\N	JUDI	\N	Audition rapporteur - MI Judiciarisation	\N	2022-01-05 13:45:00	2022-01-05 14:00:00	\N	\N	4	0	\N	\N
618413	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2022-01-12 10:00:00	2022-01-12 11:30:00	\N	\N	0	0	\N	\N
514950	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI Restitution des oeuvres d'art	\N	2020-12-08 16:45:00	2020-12-08 17:45:00	\N	\N	5	0	\N	\N
518747	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Sécurité globale	\N	2020-12-16 14:00:00	2020-12-16 15:00:00	\N	\N	2	0	\N	\N
518750	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Sécurité globale	\N	2020-12-18 16:30:00	2020-12-18 18:30:00	\N	\N	1	0	\N	\N
518752	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Assurer un meilleur accueil des gens du voyage	\N	2020-12-17 09:30:00	2020-12-17 12:00:00	\N	\N	2	0	\N	\N
518755	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Assurer un meilleur accueil des gens du voyage	\N	2020-12-17 14:30:00	2020-12-17 15:10:00	\N	\N	1	0	\N	\N
518907	GIA	AUCUNE	\N	\N	\N	AG reconstitutive du bureau du groupe France-Irak	\N	2020-12-09 12:30:00	2020-12-09 13:00:00	\N	\N	8	0	615	\N
518987	GIA	AUCUNE	\N	\N	\N	Assemblée générale	\N	2020-12-10 14:00:00	2020-12-10 15:00:00	\N	\N	31	0	598	\N
519019	GIA	AUCUNE	\N	\N	\N	ASSEMBLEE GENERALE 	\N	2020-12-10 13:30:00	2020-12-10 14:30:00	\N	\N	8	0	674	\N
519028	GIA	AUCUNE	\N	\N	\N	Assemblée générale 	\N	2020-12-08 13:30:00	2020-12-08 14:00:00	\N	\N	13	0	626	\N
521902	GIA	AUCUNE	\N	\N	\N	Entretien ambassadeur de France au Mozambique	Entreteine avec M. David Izzo, ambassadeur de France au Mozambique	2021-01-06 11:00:00	2021-01-06 12:00:00	\N	\N	1	0	622	\N
522101	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Sécurité globale	PPL Sécurité globale	2021-01-19 14:00:00	2021-01-19 15:30:00	\N	\N	3	0	\N	\N
522106	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Sécurité globale	PPL Sécurité globale	2021-01-19 15:30:00	2021-01-19 18:00:00	\N	\N	3	0	\N	\N
524546	GIA	AUCUNE	\N	\N	\N	assemblée générale reconstitutive	\N	2021-01-26 16:30:00	2021-01-26 17:00:00	\N	\N	3	0	627	\N
524764	GIA	AUCUNE	\N	\N	\N	audition de Mme Jocelyne Caballero, ambassadrice de France au Togo	\N	2021-01-26 18:00:00	2021-01-26 19:00:00	\N	\N	9	0	573	\N
530253	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Action Logement groupe	Action Logement groupe	2021-02-09 15:00:00	2021-02-09 17:15:00	\N	\N	3	0	\N	\N
534181	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL fonction	\N	2021-02-19 10:00:00	2021-02-19 11:26:00	\N	\N	4	0	\N	\N
534189	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	ppl fonction 	\N	2021-02-19 12:00:00	2021-02-19 13:09:00	\N	\N	4	0	\N	\N
534289	ETUDES	AUTRE	\N	\N	\N	Audition de M. Christian Prudhomme (ASO)	\N	2021-03-02 14:05:00	2021-03-02 15:45:00	\N	\N	24	0	\N	934
534295	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Syndicat de l'inspection de l'éducation nationale	\N	2021-02-18 15:00:00	2021-02-18 16:00:00	\N	\N	4	0	\N	\N
542956	COM_EURO	AUDRAP	\N	AFEU	\N	Stratégie vaccinale de l'UE - Commission européenne	Stratégie vaccinale de l'UE - Commission européenne	2021-03-19 10:00:00	2021-03-19 11:10:00	\N	\N	2	0	\N	\N
542957	COM_PERMANENTE	AUDRAP	\N	FINC	\N	 Contrôle 2021 - Financement lutte algues vertes Bretagne - CEVA/DMAT	 Contrôle 2021 - Financement lutte algues vertes Bretagne - CEVA/DMAT	2021-03-17 16:45:00	2021-03-17 18:45:00	\N	\N	1	0	\N	\N
542960	COM_EURO	AUDRAP	\N	AFEU	\N	Stratégie vaccinale de l'UE - SGAE	Stratégie vaccinale de l'UE - SGAE	2021-03-18 11:00:00	2021-03-18 12:10:00	\N	\N	2	0	\N	\N
542975	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Protéger les mineurs des crimes et délits sexuels et de l'inceste (amendements)	PPL Protéger les mineurs des crimes et délits sexuels et de l'inceste (amendements)	2021-03-25 17:25:00	2021-03-25 17:50:00	2021-03-25 17:58:04	2021-03-26 15:15:12	12	0	\N	\N
542976	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition de la caisse des dépôts et consignations	\N	2021-03-17 12:55:00	2021-03-17 14:00:00	\N	\N	1	0	\N	\N
542985	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière - Audition CNE2 et examen conclusions audition	Réunion plénière - Audition CNE2  et examen conclusions audition champs électromagnétiques et animaux d'élevage	2021-03-25 09:35:00	2021-03-25 12:45:00	\N	\N	12	0	\N	\N
542986	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PPL Maltraitance animale	\N	2021-03-16 09:30:00	2021-03-16 11:00:00	\N	\N	1	0	\N	\N
542988	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition ministère de la justice	\N	2021-03-16 14:00:00	2021-03-16 15:00:00	\N	\N	1	0	\N	\N
542990	ETUDES	AUTRE	\N	\N	\N	Audition ANVOL et CIFOG	\N	2021-03-10 13:45:00	2021-03-10 15:00:00	\N	\N	14	0	\N	911
543007	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n°389 Hydroélectricité - Electricité autonome française	PPL n°389 Hydroélectricité - Electricité autonome française	2021-03-19 11:30:00	2021-03-19 11:30:00	\N	\N	1	0	\N	\N
543013	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL n° 404 Développement solidaire - Direction du Budget	PJL n° 404 Développement solidaire - Direction du Budget	2021-03-17 09:45:00	2021-03-17 10:45:00	\N	\N	2	0	\N	\N
543016	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - Protection des épargnants - DB/AMF	Contrôle 2020 - Protection des épargnants - DB/AMF	2021-03-17 16:30:00	2021-03-17 19:15:00	\N	\N	2	0	\N	\N
543019	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Hébergement d¿urgence - DGCS	Contrôle 2021 - Hébergement d¿urgence - DGCS	2021-03-16 10:00:00	2021-03-16 11:30:00	\N	\N	1	0	\N	\N
543021	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Hébergement d'urgence - DIHAL/DHUP	Contrôle 2021 - Hébergement d'urgence - DIHAL/DHUP	2021-03-17 14:05:00	2021-03-17 16:10:00	\N	\N	1	0	\N	\N
543023	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions PPL Hydroélectricité	\N	2021-03-17 16:45:00	2021-03-17 19:30:00	\N	\N	1	0	\N	\N
543025	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions PPL Droit à l'eau	\N	2021-03-18 09:30:00	2021-03-18 11:40:00	\N	\N	1	0	\N	\N
543027	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions PPL Droit à l'eau	\N	2021-03-18 14:00:00	2021-03-18 16:10:00	\N	\N	1	0	\N	\N
543029	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Hébergement d'urgence - Adoma	Contrôle 2021 - Hébergement d'urgence - Adoma	2021-03-18 09:30:00	2021-03-18 10:30:00	\N	\N	1	0	\N	\N
543031	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Investissements d'avenir - CdC	PLF pour 2022 - Investissements d'avenir - CdC	2021-03-16 17:30:00	2021-03-16 19:00:00	\N	\N	1	0	\N	\N
543033	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Investissements d'avenir - BPIFrance	PLF pour 2022 - Investissements d'avenir - BPIFrance	2021-03-18 09:30:00	2021-03-18 11:00:00	\N	\N	1	0	\N	\N
543035	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - PGE - AVIVA INVESTORS	Contrôle 2021 - PGE - AVIVA INVESTORS	2021-03-16 18:00:00	2021-03-16 19:00:00	\N	\N	1	0	\N	\N
543037	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n° 385 Fonds souverains régionaux - DG Trésor/FBF/CdC	PPL n° 385 Fonds souverains régionaux - DG Trésor/FBF/CdC	2021-03-18 14:00:00	2021-03-18 17:00:00	\N	\N	1	0	\N	\N
545423	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Lutte contre l'illectronisme et pour l'inclusion numérique	\N	2021-03-26 10:00:00	2021-03-26 12:00:00	\N	\N	1	0	\N	\N
545425	MISSION	AUDRAP	\N	PAUP	\N	MI Lutte contre la précarisation	\N	2021-03-25 16:00:00	2021-03-25 17:00:00	\N	\N	4	0	\N	\N
545430	MISSION	AUDRAP	\N	PAUP	\N	MI Lutte contre la précarisation	\N	2021-03-25 17:00:00	2021-03-25 18:00:00	\N	\N	3	0	\N	\N
545434	MISSION	AUDRAP	\N	PAUP	\N	MI Lutte contre la précarisation	\N	2021-03-26 09:00:00	2021-03-26 10:00:00	\N	\N	1	0	\N	\N
554775	COM_PERMANENTE	AUTRE	\N	AFCL	\N	PJL Oeuvres culturelles à l'ère du numérique et PJLO 5e alinéa art. 13 Constitution	\N	2021-05-05 09:30:00	2021-05-05 12:37:00	2021-05-05 13:39:08	2021-05-06 17:43:04	33	0	\N	\N
554778	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 6 mai	\N	2021-05-06 08:30:00	2021-05-06 10:20:00	2021-05-06 14:53:51	2021-05-06 17:44:07	14	0	\N	\N
554784	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Dérèglement climatique - Audition CSFMM	PJL Dérèglement climatique - Audition CSFMM	2021-04-14 15:45:00	2021-04-14 16:30:00	\N	\N	1	0	\N	\N
554785	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Dérèglement climatique - Table ronde acteurs économiques - Code minier	PJL Dérèglement climatique - Table ronde acteurs économiques - Code minier	2021-04-15 14:00:00	2021-04-15 15:00:00	\N	\N	1	0	\N	\N
554786	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Dérèglement climatique - Audition Orano mining	PJL Dérèglement climatique - Audition Orano mining	2021-04-15 15:00:00	2021-04-15 15:45:00	\N	\N	1	0	\N	\N
554787	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Dérèglement climatique - Audition Fédération nationale de l'environnement	PJL Dérèglement climatique - Audition Fédération nationale de l'environnement	2021-04-15 15:45:00	2021-04-15 16:30:00	\N	\N	1	0	\N	\N
554789	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Dérèglement climatique - Audition M. Tuot	PJL Dérèglement climatique - Audition M. Tuot	2021-04-14 18:30:00	2021-04-14 19:30:00	\N	\N	1	0	\N	\N
596596	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Pouvoirs publics - Questeur Sénat	PLF pour 2022 - Pouvoirs publics - Questeur Sénat	2021-10-26 09:30:00	2021-10-26 10:15:00	\N	\N	1	0	\N	\N
596598	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Pouvoirs publics - PDG Public Sénat	PLF pour 2022 - Pouvoirs publics - PDG Public Sénat	2021-10-27 09:00:00	2021-10-27 10:15:00	\N	\N	1	0	\N	\N
596600	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2022 - Pouvoirs publics - Déplacement Questeur AN	PLF pour 2022 - Pouvoirs publics - Déplacement Questeur AN	2021-10-27 10:40:00	2021-10-27 12:20:00	\N	\N	1	0	\N	\N
596602	COM_EURO	AUDRAP	\N	AFEU	\N	Audition de la RP de la France auprès de l'UE	\N	2021-10-26 16:15:00	2021-10-26 17:15:00	\N	\N	1	0	\N	\N
596604	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Écologie - Météo - IGN	PLF pour 2022 - Écologie - Météo - IGN	2021-10-26 14:30:00	2021-10-26 15:45:00	\N	\N	1	0	\N	\N
596606	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Écologie - Météo - CEREMA	PLF pour 2022 - Écologie - Météo - CEREMA	2021-10-26 17:00:00	2021-10-26 18:15:00	\N	\N	1	0	\N	\N
596608	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Écologie - SER	PLF pour 2022 - Écologie - SER	2021-10-26 18:45:00	2021-10-26 19:45:00	\N	\N	1	0	\N	\N
596610	ETUDES	AUTRE	\N	\N	\N	Auditions de présidents de chambres régionales de l'ESS	Auditions de présidents de chambres régionales de l'ESS	2021-10-27 13:30:00	2021-10-27 15:00:00	\N	\N	3	0	\N	998
596612	ETUDES	AUDRAP	\N	\N	\N	Petit-déjeuner, Echanges avec M. Claude Onesta, ANS	\N	2021-10-27 08:00:00	2021-10-27 09:30:00	\N	\N	32	0	\N	934
596648	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Cohésion des territoires - Logement-Urbanisme - ANCT/AL/ANRU	PLF pour 2022 - Cohésion des territoires - Logement-Urbanisme - ANCT/AL/ANRU	2021-10-26 14:45:00	2021-10-26 17:30:00	\N	\N	1	0	\N	\N
596652	COM_EURO	AUDRAP	\N	AFEU	\N	Audition du SGAE	Audition du SGAE	2021-10-15 14:00:00	2021-10-15 16:00:00	\N	\N	2	0	\N	\N
596653	COM_EURO	AUDRAP	\N	AFEU	\N	Audition de l'Observatoire dép. des violences faites aux femmes en Seine-Saint-Denis	Audition de l'Observatoire dép. des violences faites aux femmes en Seine-Saint-Denis	2021-10-12 15:00:00	2021-10-12 16:20:00	\N	\N	2	0	\N	\N
596656	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Cohésion des territoires - Logement-Urbanisme - CDC	PLF pour 2022 - Cohésion des territoires - Logement-Urbanisme - CDC	2021-10-27 08:45:00	2021-10-27 09:20:00	\N	\N	1	0	\N	\N
596675	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 4 novembre 2021	\N	2021-11-04 09:20:00	2021-11-04 10:25:00	\N	\N	14	0	\N	\N
596677	COM_EURO	AUTRE	\N	AFEU	\N	Résolution européenne - neutralité climatique d'ici à 2035 - M. Pierre Louault	\N	2021-11-04 08:30:00	2021-11-04 09:20:00	\N	\N	14	0	\N	\N
596882	ETUDES	AUTRE	\N	\N	\N	Audition de Jean-Marie FABRE, psdt des Vignerons indépendants	Audition de Jean-Marie FABRE, psdt des Vignerons indépendants	2021-10-27 13:30:00	2021-10-27 15:00:00	\N	\N	20	0	\N	909
596937	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Conseil d'architecture, d'urbanisme et de l'environnement du département du Haut-Rhin	\N	2021-10-27 14:00:00	2021-10-27 15:00:00	\N	\N	1	0	\N	\N
596942	ETUDES	AUTRE	\N	\N	\N	Audition Valobat - UNICEM	Audition Valobat - UNICEM	2021-10-27 13:45:00	2021-10-27 15:00:00	\N	\N	3	0	\N	922
597258	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition de Mme Frédérique Vidal, ministre de l¿enseignement supérieur et de la recherche	\N	2021-10-27 16:30:00	2021-10-27 18:37:00	2021-10-27 18:39:05	2021-10-27 19:08:43	16	0	\N	\N
597287	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF mission "Solidarité"	\N	2021-10-27 13:45:00	2021-10-27 14:30:00	\N	\N	2	0	\N	\N
598385	COM_EURO	AUDRAP	\N	AFEU	\N	Subventions étrangères	Subventions étrangères	2021-10-27 17:30:00	2021-10-27 18:30:00	\N	\N	1	0	\N	\N
598387	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJLF 2022-Auditions-Mission "Enseignement supérieur et recherche"-M. Frédéric Marchand	PJLF 2022 - Auditions - Mission "Enseignement supérieur et recherche"	2021-10-26 14:00:00	2021-10-26 18:00:00	\N	\N	1	0	\N	\N
598417	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Ministère de la culture	\N	2021-10-06 16:30:00	2021-10-06 17:30:00	\N	\N	2	0	\N	\N
598418	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Messageries lyonnaises de presse	PLF presse	2021-10-06 17:30:00	2021-10-06 18:30:00	\N	\N	2	0	\N	\N
598419	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Alliance de la presse d'information générale (APIG)	PLF presse	2021-10-07 10:00:00	2021-10-07 11:00:00	\N	\N	1	0	\N	\N
598420	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Syndicat national des dépositaires de presse (SNDP)	PLF presse	2021-10-13 14:00:00	2021-10-13 15:00:00	\N	\N	1	0	\N	\N
598421	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF presse	\N	2021-10-13 16:30:00	2021-10-13 17:30:00	\N	\N	1	0	\N	\N
598422	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	France Messagerie	PLF presse	2021-10-14 09:30:00	2021-10-14 10:30:00	\N	\N	1	0	\N	\N
598423	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Cour des comptes	PLF presse	2021-10-19 09:00:00	2021-10-19 11:00:00	\N	\N	1	0	\N	\N
598434	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF2022 ES	\N	2021-10-05 16:30:00	2021-10-05 17:30:00	\N	\N	3	0	\N	\N
598435	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF2022 ES	\N	2021-10-07 09:00:00	2021-10-07 11:00:00	\N	\N	1	0	\N	\N
598436	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2022 ES	\N	2021-10-12 14:00:00	2021-10-12 15:00:00	\N	\N	3	0	\N	\N
598437	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2022 ES	\N	2021-10-19 13:30:00	2021-10-19 14:30:00	\N	\N	2	0	\N	\N
598438	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	plf recherche	\N	2021-10-22 09:00:00	2021-10-22 10:00:00	\N	\N	1	0	\N	\N
598450	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	plf cinema	\N	2021-10-26 15:00:00	2021-10-26 16:00:00	\N	\N	1	0	\N	\N
598451	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	pLF cinéma	\N	2021-11-03 14:00:00	2021-11-03 15:00:00	\N	\N	2	0	\N	\N
598452	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2022 cinéma	\N	2021-11-16 13:30:00	2021-11-16 14:20:00	\N	\N	1	0	\N	\N
598456	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	plf LIC	\N	2021-10-07 16:30:00	2021-10-07 17:30:00	\N	\N	2	0	\N	\N
598457	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF LIC	\N	2021-10-08 15:30:00	2021-10-08 16:30:00	\N	\N	1	0	\N	\N
598458	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	plf LIC	\N	2021-10-11 11:00:00	2021-10-11 12:00:00	\N	\N	2	0	\N	\N
598459	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF LIC	\N	2021-10-14 15:00:00	2021-10-14 16:00:00	\N	\N	1	0	\N	\N
598463	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	plf LIC	\N	2021-10-21 15:00:00	2021-10-21 17:30:00	\N	\N	1	0	\N	\N
598471	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJLF 2022 - Écologie	\N	2021-10-26 09:45:00	2021-10-26 10:30:00	\N	\N	1	0	\N	\N
598473	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PJLF 2022 - Écologie	\N	2021-10-26 14:00:00	2021-10-26 19:15:00	\N	\N	1	0	\N	\N
598476	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2022 - Audition Énergie	\N	2021-10-26 19:15:00	2021-10-26 20:00:00	\N	\N	1	0	\N	\N
598478	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	mi répartition des moyens alloués à la création	\N	2021-10-19 15:00:00	2021-10-19 17:00:00	\N	\N	5	0	\N	\N
598483	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Logement - Mme Estrosi Sassone	\N	2021-10-13 17:30:00	2021-10-13 19:15:00	\N	\N	1	0	\N	\N
598487	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Logement - Mme Estrosi Sassone	\N	2021-10-19 17:15:00	2021-10-19 18:15:00	\N	\N	3	0	\N	\N
598495	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Logement - Mme Estrosi Sassone	\N	2021-10-20 18:20:00	2021-10-20 18:45:00	\N	\N	1	0	\N	\N
598504	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Plf enssco	\N	2021-10-18 14:00:00	2021-10-18 15:40:00	\N	\N	1	0	\N	\N
598509	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Direction générale de l'enseignement scolaire	\N	2021-10-13 13:30:00	2021-10-13 14:45:00	\N	\N	4	0	\N	\N
505621	COM_EURO	AUDRAP	\N	AFEU	\N	Union de la Sécurité	Audition rapporteur - Union de la Sécurité	2020-11-23 15:00:00	2020-11-23 16:25:00	\N	\N	2	0	\N	\N
505633	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2021 - Mission régimes sociaux et de retraite	\N	2020-11-18 13:45:00	2020-11-18 14:30:00	\N	\N	3	0	\N	\N
505768	DELEGATION	AUDRAP	\N	\N	PROS	Audition de l'AMRF	Audition de M. Yvan Lubraneski,  maire  de la commune LES MOLIÈRES  (91)	2020-11-26 10:00:00	2020-11-26 11:00:00	\N	\N	1	0	\N	\N
505771	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Langues régionales	\N	2020-11-19 08:30:00	2020-11-19 09:20:00	\N	\N	3	0	\N	\N
505796	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désignation de rapporteurs - Examen d'avis budgétaires	Désignation de rapporteurs - Examen d'avis budgétaires	2020-11-24 09:15:00	2020-11-24 10:00:00	2020-11-24 10:30:35	2020-11-24 15:18:45	18	0	\N	\N
505797	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de Jacqueline Gourault, ministre (examen du PLF pour 2021)	Audition de Jacqueline Gourault, ministre (examen du PLF pour 2021)	2020-11-24 14:30:00	2020-11-24 16:10:00	2020-11-24 17:02:04	2020-11-25 11:48:43	29	0	\N	\N
505798	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Examen d'avis budgétaires	Examen d'avis budgétaires	2020-11-25 08:30:00	2020-11-25 12:00:00	2020-11-25 12:12:49	2020-11-25 15:01:21	37	0	\N	\N
505799	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de Gérald Darmanin, ministre de l'intérieur (examen du PLF pour 2021)	Audition de Gérald Darmanin, ministre de l'intérieur (examen du PLF pour 2021)	2020-11-25 16:30:00	2020-11-25 18:50:00	2020-11-25 19:16:11	2020-11-26 11:15:00	24	0	\N	\N
505803	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-11-24 15:05:00	2020-11-24 17:40:00	2020-11-25 10:52:11	2020-11-25 11:48:44	40	0	\N	\N
505804	COM_PERMANENTE	AUTRE	\N	CAE	\N	\N	\N	2020-11-25 09:35:00	2020-11-25 12:40:00	2020-11-25 17:45:03	2020-11-25 17:48:32	41	0	\N	\N
505805	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-11-26 08:35:00	2020-11-26 10:40:00	2020-11-26 17:56:42	2020-11-26 18:01:10	52	0	\N	\N
505913	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - MIRES - Cab MIN ESR	PLF pour 2021 - MIRES - Cab MIN ESR	2020-11-16 16:30:00	2020-11-16 17:30:00	\N	\N	2	0	\N	\N
505939	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 26 novembre 2020 	Réunion du 26 novembre 2020 - audition M. Denormandie	2020-11-26 08:35:00	2020-11-26 10:40:00	2020-11-26 16:19:18	2020-11-26 16:51:10	53	0	\N	\N
505944	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PFL 2021 - Direction de l'action du Gouvernement	\N	2020-11-23 09:00:00	2020-11-23 12:30:00	\N	\N	1	0	\N	\N
505950	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Fédération nationale des sapeurs-pompiers de France	\N	2020-11-19 14:00:00	2020-11-19 14:45:00	\N	\N	1	0	\N	\N
505951	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Conférence nationale des services d'incendie et de secours	\N	2020-11-18 09:30:00	2020-11-18 10:15:00	\N	\N	1	0	\N	\N
505963	COM_PERMANENTE	AUTRE	\N	CDD	\N	\N	\N	2020-11-25 08:30:00	2020-11-25 10:40:00	2020-11-25 18:04:01	2020-11-25 18:43:18	37	1	\N	\N
505967	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions PPL Empreinte environnementale du numérique	\N	2020-11-19 10:30:00	2020-11-19 12:10:00	\N	\N	2	0	\N	\N
506001	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Défense - Cab MIN ARM	PLF pour 2021 - Défense - Cab MIN ARM	2020-11-16 15:45:00	2020-11-16 16:45:00	\N	\N	1	0	\N	\N
506004	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Ports - audition de M. Mandelli	\N	2020-11-16 14:30:00	2020-11-16 18:30:00	\N	\N	0	0	\N	\N
513283	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLO Délais d'organisation des élections législatives et sénatoriales	Audition rapporteur - DGCL	2020-12-03 18:30:00	2020-12-03 19:15:00	\N	\N	1	0	\N	\N
518447	GIA	AUCUNE	\N	\N	\N	AG France-Allemagne	Assemblée générale du groupe interparlementaire d'amitié France-Allemagne	2020-12-16 14:00:00	2020-12-16 14:45:00	\N	\N	24	0	604	\N
522155	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2021-01-20 09:30:00	2021-01-20 12:40:00	2021-01-29 14:28:52	2021-01-29 15:46:18	70	0	\N	\N
522157	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Table ronde Sport & santé	\N	2021-01-20 09:36:00	2021-01-20 12:38:00	2021-01-20 16:28:07	2021-01-20 17:04:23	69	0	\N	\N
522158	DELEGATION	AUCUNE	\N	\N	DSOM	Audition de M. Stéphane Bijoux, député européen	\N	2021-02-02 16:30:00	2021-02-02 17:45:00	\N	\N	11	0	\N	\N
522844	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition AFG-FGR	Audition AFG-FGR	2021-01-19 17:00:00	2021-01-19 18:00:00	\N	\N	2	0	\N	\N
522845	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition CAPEB-FFB	Audition CAPEB-FFB	2021-01-19 18:00:00	2021-01-19 19:00:00	\N	\N	3	0	\N	\N
522846	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Engie	Audition Engie	2021-01-20 13:30:00	2021-01-20 14:15:00	\N	\N	3	0	\N	\N
522847	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition GrDF	Audition GrDF	2021-01-20 14:15:00	2021-01-20 15:00:00	\N	\N	2	0	\N	\N
522862	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Bernard Benhamou, secrétaire général de l'Institut de la souveraineté numérique	\N	2021-01-19 16:00:00	2021-01-19 18:00:00	\N	\N	2	0	\N	\N
523130	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 28 janvier 2021	Réunion du 28 janvier 2021 - audition ambassadeur du Portugal	2021-01-28 08:30:00	2021-01-28 09:45:00	2021-01-28 15:49:16	2021-01-28 18:29:20	16	0	\N	\N
526222	DELEGATION	AUCUNE	\N	\N	COLTER	TR métropoles + communication Grand Paris	\N	2021-02-04 09:30:00	2021-02-04 11:50:00	\N	\N	13	0	\N	\N
530844	GIA	AUCUNE	\N	\N	\N	Audition de S.E.Mme Kshanika Hirimburegama, Ambassadeur du Sri Lanka en France	\N	2021-02-10 16:30:00	2021-02-10 17:30:00	\N	\N	2	0	550	\N
530848	GIA	AUCUNE	\N	\N	\N	Assemblée générale du GIA France-Sri Lanka	\N	2021-02-10 17:30:00	2021-02-10 18:00:00	\N	\N	2	0	550	\N
531352	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Santé environnementale - Audition de Mme Elisabeth Toutut-Picard	\N	2021-02-10 14:00:00	2021-02-10 15:00:00	\N	\N	2	0	\N	\N
531353	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Santé environnementale - Audition de M. Benoît Vallet	\N	2021-02-11 14:30:00	2021-02-11 15:30:00	\N	\N	2	0	\N	\N
531663	GIA	AUCUNE	\N	\N	\N	Audition de S.E.M. Mohamed Karim Jamoussi, Ambassadeur de Tunisie en France	\N	2021-02-16 13:30:00	2021-02-16 14:30:00	\N	\N	10	0	620	\N
532685	ETUDES	AUCUNE	\N	\N	\N	Audition Office français de la biodiversité	Audition Office français de la biodiversité	2021-02-17 08:00:00	2021-02-17 09:30:00	\N	\N	23	0	\N	907
532973	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Principes de la République	\N	2021-02-16 14:00:00	2021-02-16 14:45:00	\N	\N	4	0	\N	\N
532982	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Principes de la République	\N	2021-02-16 14:45:00	2021-02-16 16:15:00	\N	\N	3	0	\N	\N
533005	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Principes de la République	\N	2021-02-16 16:15:00	2021-02-16 17:00:00	\N	\N	3	0	\N	\N
533009	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Principes de la République	\N	2021-02-16 17:00:00	2021-02-16 18:00:00	\N	\N	2	0	\N	\N
533012	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Principes de la République	\N	2021-02-16 18:00:00	2021-02-16 18:45:00	\N	\N	4	0	\N	\N
533017	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Principes de la République	\N	2021-02-16 18:00:00	2021-02-16 18:45:00	\N	\N	1	0	\N	\N
533021	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Principes de la République	\N	2021-02-16 18:45:00	2021-02-16 19:00:00	\N	\N	2	0	\N	\N
534252	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Fondation du Patrimoine	PPL Fondation du Patrimoine	2021-03-02 14:30:00	2021-03-02 15:20:00	\N	\N	58	0	\N	\N
534253	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat sur la dette publique	Débat sur la dette publique, à l'aune de la crise économique actuelle	2021-03-02 15:30:00	2021-03-02 17:10:00	\N	\N	112	0	\N	\N
534254	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat construire plus et mieux en France 	Débat sur le thème : « Comment construire plus et mieux en France ? »	2021-03-02 17:15:00	2021-03-02 18:50:00	\N	\N	85	0	\N	\N
534255	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat réforme éducation prioritaire »	Débat sur le thème : « La réforme en cours de l'éducation prioritaire »	2021-03-02 18:50:00	2021-03-02 20:30:00	\N	\N	63	0	\N	\N
534256	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat devenir de l'Économie	Débat sur le thème : « Situation et devenir de l'Économie Sociale et Solidaire »	2021-03-02 22:00:00	2021-03-02 23:40:00	\N	\N	44	0	\N	\N
588440	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2022 - Programme 146	\N	2021-09-28 14:30:00	2021-09-28 17:00:00	\N	\N	2	0	\N	\N
588443	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Responsabilité pénale et sécurité intérieure	\N	2021-09-30 15:30:00	2021-09-30 17:00:00	\N	\N	1	0	\N	\N
593175	DELEGATION	AUDRAP	\N	\N	206	Audition de rapporteur	\N	2021-09-23 15:00:00	2021-09-23 16:00:00	\N	\N	1	0	\N	\N
593323	DELEGATION	AUDRAP	\N	\N	206	Audition de rapporteur	\N	2021-10-13 15:00:00	2021-10-13 16:00:00	\N	\N	1	0	\N	\N
593470	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	GT Climat	GT Climat	2021-10-13 17:30:00	2021-10-13 18:00:00	\N	\N	7	0	\N	\N
593479	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2022 - Programme 105	\N	2021-10-14 16:00:00	2021-10-14 17:35:00	\N	\N	1	0	\N	\N
593481	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2022 - Programme 105	\N	2021-10-14 18:00:00	2021-10-14 19:30:00	\N	\N	1	0	\N	\N
593483	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2021-10-13 14:00:00	2021-10-13 14:35:00	\N	\N	24	0	\N	\N
593920	GIA	AUCUNE	\N	\N	\N	Audition de deux ministres du Sri Lanka 	Entretien avec deux ministres du Sri Lanka	2021-10-07 08:45:00	2021-10-07 11:30:00	\N	\N	2	0	550	\N
595297	GIA	AUCUNE	\N	\N	\N	accueil d'une délégation israélienne	\N	2021-10-21 08:45:00	2021-10-21 10:00:00	\N	\N	2	0	595	\N
615662	GIA	AUCUNE	\N	\N	\N	Réunion conjointe Biélorussie, Allemagne, Pays baltes et Pologne 	Réunion conjointe Biélorussie, Allemagne, Pays baltes et Pologne : situation aux frontières de la Biélorussie	2021-12-15 13:45:00	2021-12-15 15:00:00	\N	\N	5	0	852	\N
615671	GIA	AUCUNE	\N	\N	\N	Réunion conjointe Biélorussie, Allemagne, Pays baltes et Pologne sur la Biélorussie	Réunion conjointe Biélorussie, Allemagne, Pays baltes et Pologne sur la situation aux frontières de la Biélorussie	2021-12-15 13:45:00	2021-12-15 15:00:00	\N	\N	9	0	604	\N
615681	GIA	AUCUNE	\N	\N	\N	Réunion conjointe Biélorussie, Allemagne, Pays baltes et Pologne 	Réunion conjointe Biélorussie, Allemagne, Pays baltes et Pologne sur la situation aux frontières de la Biélorussie	2021-12-15 13:45:00	2021-12-15 15:00:00	\N	\N	5	0	600	\N
615687	GIA	AUCUNE	\N	\N	\N	Réunion conjointe Biélorussie, Allemagne, Pays baltes et Pologne	Réunion conjointe Biélorussie, Allemagne, Pays baltes et Pologne sur la situation aux frontières de la Biélorussie	2021-12-15 13:45:00	2021-12-15 15:00:00	\N	\N	3	0	616	\N
616083	GIA	AUCUNE	\N	\N	\N	Grande Commission avec l'Assemblée populaire nationale de Chine	\N	2021-12-16 09:00:00	2021-12-16 11:00:00	\N	\N	7	0	584	\N
616351	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Référencement malades chroniques covid-19 - Table ronde de cellules d'appui covid long	\N	2021-12-17 11:00:00	2021-12-17 12:10:00	\N	\N	1	0	\N	\N
616352	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Référencement malades chroniques covid-19 - Audition de la CNAM	\N	2021-12-17 15:45:00	2021-12-17 16:30:00	\N	\N	1	0	\N	\N
616353	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Référencement malades chroniques covid-19 - Audition de la HAS	\N	2021-12-17 15:00:00	2021-12-17 15:35:00	\N	\N	1	0	\N	\N
616354	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Référencement malades chroniques covid-19 - Audition task force Suivi patients covid	\N	2021-12-17 16:30:00	2021-12-17 17:15:00	\N	\N	1	0	\N	\N
616406	COM_PERMANENTE	AUTRE	\N	CAE	\N	\N	\N	2022-01-05 09:35:00	2022-01-05 10:50:00	2022-01-05 10:58:26	2022-01-05 17:10:04	45	0	\N	\N
616408	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion pleinière CATDD	\N	2022-01-12 10:00:00	2022-01-12 11:25:00	2022-01-12 11:40:56	2022-01-13 18:45:26	28	0	\N	\N
616409	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 12 janvier 2022	\N	2022-01-12 16:35:00	2022-01-12 17:50:00	2022-01-12 17:52:29	2022-01-13 18:46:45	24	0	\N	\N
616410	DELEGATION	AUCUNE	\N	\N	211	Audition de Mme Carole Bienaimé Besse	Audition de Mme Carole Bienaimé Besse	2022-01-27 09:00:00	2022-01-27 10:15:00	\N	\N	14	0	\N	\N
616447	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Protection des épargnants - DG Trésor	Contrôle 2021 - Protection des épargnants - DG Trésor	2021-12-15 14:00:00	2021-12-15 15:00:00	\N	\N	2	0	\N	\N
616795	ETUDES	AUCUNE	\N	\N	\N	Audition CRESS Bretagne et Normandie	Audition CRESS Bretagne et Normandie	2021-12-15 13:30:00	2021-12-15 15:00:00	\N	\N	1	0	\N	998
617203	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Examen PPL AEFE et communications	Examen PPL AEFE et communications Espagne et Italie.	2022-01-05 10:00:00	2022-01-05 11:45:00	2022-01-05 15:16:20	2022-01-05 17:10:05	35	5	\N	\N
618425	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Assurance emprunteur - Audition CCSF (avec Comm finances)	PPL Assurance emprunteur - Audition CCSF (avec Comm finances)	2022-01-04 14:00:00	2022-01-04 15:00:00	\N	\N	1	0	\N	\N
618426	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Assurance emprunteur - Audition Meilleurtaux.com	PPL Assurance emprunteur - Audition Meilleurtaux.com	2022-01-04 15:30:00	2022-01-04 16:15:00	\N	\N	1	0	\N	\N
618427	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL assurance emprunteur - Audition DG Trésor	PPL assurance emprunteur - Audition DG Trésor	2022-01-05 16:30:00	2022-01-05 17:30:00	\N	\N	1	0	\N	\N
618510	COM_ENQUETE	AUDRAP	\N	HOPITAL	\N	Audition Institut de Santé	\N	2022-01-07 17:00:00	2022-01-07 19:00:00	\N	\N	6	0	\N	\N
618626	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Auditions BBelin et CHerzog / JM	\N	2022-01-04 18:15:00	2022-01-04 19:00:00	\N	\N	0	0	\N	\N
621065	MISSION	AUCUNE	\N	SECUECO	\N	PLENIERE - HCSP et La Fabrique Ecologique	\N	2022-01-13 09:30:00	2022-01-13 11:15:00	2022-01-13 16:52:25	2022-01-13 18:48:11	3	0	\N	\N
621066	DELEGATION	AUCUNE	\N	\N	COLTER	Réunion plénière table ronde sur les dépôts suvages et audition de M. David LISNARD	\N	2022-01-13 08:45:00	2022-01-13 11:15:00	\N	\N	24	0	\N	\N
621067	DELEGATION	AUTRE	\N	\N	COLTER	Réunion plénière	\N	2022-01-13 10:00:00	2022-01-13 11:00:00	\N	\N	0	0	\N	\N
621068	DELEGATION	AUTRE	\N	\N	COLTER	Réunion plénière	\N	2022-01-13 11:00:00	2022-01-13 11:15:00	\N	\N	0	0	\N	\N
621079	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Aménagement du Rhône	Auditions Aménagement du Rhône	2022-01-11 18:30:00	2022-01-11 19:30:00	\N	\N	4	0	\N	\N
613173	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PPL AEFE	\N	2021-12-07 16:30:00	2021-12-07 17:30:00	\N	\N	1	0	\N	\N
621102	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 20 janvier 2022	Réunion du 20 janvier 2022	2022-01-20 09:00:00	2022-01-20 10:45:00	2022-01-20 11:11:00	2022-01-20 11:34:07	17	0	\N	\N
621109	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Situation et perspectives SNCF - DGS CR Normandie	Contrôle 2021 - Situation et perspectives SNCF - DGS CR Normandie	2022-01-11 15:00:00	2022-01-11 15:50:00	\N	\N	2	0	\N	\N
621128	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Financement lutte algues vertes Bretagne - Cour des comptes	Contrôle 2021 - Financement lutte algues vertes Bretagne - Cour des comptes	2022-01-11 16:00:00	2022-01-11 17:00:00	\N	\N	1	0	\N	\N
621151	MISSION	AUDRAP	\N	CULTURE	\N	Audition du Centre national d'étude des systèmes scolaires	\N	2022-01-13 11:30:00	2022-01-13 12:45:00	\N	\N	6	0	\N	\N
621178	COM_ENQUETE	PLENIERE	\N	HOPITAL	\N	Auditions	\N	2022-01-18 14:30:00	2022-01-18 19:00:00	2022-01-19 10:58:10	2022-01-19 16:56:39	14	0	\N	\N
621213	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition d'associations familiales	\N	2022-01-12 16:30:00	2022-01-12 17:40:00	\N	\N	1	0	\N	\N
621215	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Association Hyper-Super	\N	2022-01-13 15:00:00	2022-01-13 16:00:00	\N	\N	1	0	\N	\N
621216	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition DGESCO	\N	2022-01-13 16:00:00	2022-01-13 17:00:00	\N	\N	0	0	\N	\N
621374	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	NL PJL Crise sanitaire	NL PJL Crise sanitaire	2022-01-15 16:00:00	2022-01-15 19:50:00	\N	\N	54	0	\N	\N
621375	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	NL PJL Crise sanitaire	NL PJL Crise sanitaire	2022-01-15 21:30:00	2022-01-16 00:30:00	\N	\N	0	0	\N	\N
621725	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Commerce International : La Fabrique de l'exportation	La Fabrique de l'exportation/M. Etienne Vauchez, président	2022-01-04 17:15:00	2022-01-04 18:30:00	\N	\N	8	0	\N	\N
621734	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	\N	\N	2022-01-11 16:00:00	2022-01-11 17:00:00	\N	\N	5	0	\N	\N
621740	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Commerce International : Chambre Franco-Allemande de Commerce et d'Industrie	M. Patrick Brandmaier/Chambre Franco-Allemande de Commerce et d'Industrie	2022-01-11 17:00:00	2022-01-11 18:00:00	\N	\N	5	0	\N	\N
621746	DELEGATION	DEPLACEMENT	\N	\N	ENTREPRISES	Cité de l'économie (Citéco)	Cité de l'économie (Citéco)	2022-01-13 09:00:00	2022-01-13 12:30:00	\N	\N	8	0	\N	\N
621782	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2022-01-13 08:45:00	2022-01-13 11:05:00	\N	\N	2	0	\N	\N
623718	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Table ronde sur l¿analyse économique du déficit commercial français	\N	2022-01-20 09:05:00	2022-01-20 11:05:00	\N	\N	14	0	\N	\N
624024	MISSION	AUCUNE	\N	JUDI	\N	Audition d'Angelika Nussberger et Mattias Wendel	Audition d'Angelika Nussberger et Mattias Wendel	2022-01-25 15:00:00	2022-01-25 16:40:00	2022-01-25 16:53:46	2022-01-25 18:21:18	9	0	\N	\N
512703	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJLO et PJL Délais d'organisation des élections - Examen du rapport et des textes	PJLO et PJL Délais d'organisation des élections - Examen du rapport et des textes	2020-12-08 09:00:00	2020-12-08 09:50:00	2020-12-08 10:18:23	2020-12-08 18:00:48	24	0	\N	\N
512704	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJLO et PJL Délais d'organisation des élections - Examen des amendements de séance	PJLO et PJL Délais d'organisation des élections - Examen des amendements de séance	2020-12-08 20:05:00	2020-12-08 20:10:00	2020-12-08 20:22:23	2020-12-09 11:12:40	10	0	\N	\N
512705	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désignations - Amendements de séance - Rapports	Désignations - Amendements de séance - Rapports	2020-12-09 09:30:00	2020-12-09 10:35:00	2020-12-09 10:56:52	2020-12-09 11:12:41	36	0	\N	\N
512838	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière	\N	2020-12-10 09:00:00	2020-12-10 10:40:00	2020-12-10 15:35:28	\N	19	0	\N	\N
512856	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Sport - Cab MIN SPORT	PLF pour 2021 - Sport - Cab MIN SPORT	2020-12-02 17:00:00	2020-12-02 18:00:00	\N	\N	1	0	\N	\N
512883	DELEGATION	AUTRE	\N	\N	DSOM	Programme de travail de la délégation et audition de la FEDOM	\N	2020-12-10 09:00:00	2020-12-10 11:30:00	\N	\N	17	0	\N	\N
512917	DELEGATION	AUDRAP	\N	\N	PROS	Audition de M. Frédéric Weill, Futuribles	Audition de M. Frédéric Weill, directeur d'études, Futuribles	2020-12-15 15:00:00	2020-12-15 16:00:00	\N	\N	1	0	\N	\N
519093	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Assurer un meilleur accueil des gens du voyage	\N	2021-01-04 14:00:00	2021-01-04 14:45:00	\N	\N	4	0	\N	\N
519098	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière (stratégie vaccinale)	Réunion plénière (stratégie vaccinale)	2021-01-07 09:05:00	2021-01-07 11:10:00	\N	\N	21	0	\N	\N
523896	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Transport de marchandises - France logistique	MI Transport de marchandises - France logistique	2021-01-19 14:00:00	2021-01-19 15:10:00	\N	\N	10	0	\N	\N
523911	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Transport de marchandises - Table ronde	MI Transport de marchandises - Table ronde	2021-01-19 15:10:00	2021-01-19 16:10:00	\N	\N	6	0	\N	\N
530112	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	COM France Médias Monde 2020-2022	\N	2021-01-19 17:00:00	2021-01-19 18:15:00	\N	\N	2	0	\N	\N
532547	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2021-02-11 09:00:00	2021-02-11 10:55:00	\N	\N	3	0	\N	\N
536964	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Contributions internationales - DB / Dap MEAE	Contrôle 2021 - Contributions internationales - DB / Dap MEAE	2021-03-02 17:15:00	2021-03-02 19:30:00	\N	\N	2	0	\N	\N
536967	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Hébergement d¿urgence - Samu social Paris/Fondation Abbé Pierre	Contrôle 2021 - Hébergement d¿urgence - Samu social Paris/Fondation Abbé Pierre	2021-03-02 08:45:00	2021-03-02 10:50:00	\N	\N	1	0	\N	\N
536969	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - PGE - CAE	Contrôle 2021 - PGE - CAE	2021-03-02 14:00:00	2021-03-02 15:00:00	\N	\N	1	0	\N	\N
536971	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - PGE - Économiste	Contrôle 2021 - PGE - Économiste	2021-03-02 18:00:00	2021-03-02 19:00:00	\N	\N	1	0	\N	\N
536973	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - PGE - Banque d'investissement 	Contrôle 2021 - PGE - Banque d'investissement 	2021-03-03 14:00:00	2021-03-03 15:00:00	\N	\N	1	0	\N	\N
536975	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - La protection des épargnants - France Invest	Contrôle 2020 - La protection des épargnants - France Invest	2021-03-02 09:45:00	2021-03-02 10:35:00	\N	\N	2	0	\N	\N
536978	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - La protection des épargnants - AFG	Contrôle 2020 - La protection des épargnants - AFG	2021-03-03 17:30:00	2021-03-03 18:50:00	\N	\N	2	0	\N	\N
536981	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Respect des principes de la République - DGFiP-DLF/DG Trésor	PJL Respect des principes de la République - DGFiP-DLF	2021-03-04 10:30:00	2021-03-04 12:15:00	\N	\N	1	0	\N	\N
536983	DELEGATION	AUDRAP	\N	\N	PROS	Audition RATP	Audition RATP	2021-03-29 10:00:00	2021-03-29 11:00:00	\N	\N	2	0	\N	\N
536984	DELEGATION	AUDRAP	\N	\N	PROS	Audition Kap Code	Audition de M. Stéphane SCHUCK - Président et directeur scientifique de Kap Code	2021-03-29 11:00:00	2021-03-29 12:00:00	\N	\N	2	0	\N	\N
537014	MISSION	AUCUNE	\N	VIETUDIA	\N	Audition acteurs institutionnels Ens sup	\N	2021-03-18 14:00:00	2021-03-18 17:07:00	2021-03-19 08:01:33	2021-03-19 16:03:19	10	0	\N	\N
537912	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Respect des principes de la République	\N	2021-03-09 15:00:00	2021-03-09 16:00:00	\N	\N	2	0	\N	\N
537915	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Respect des principes de la République	\N	2021-03-09 16:00:00	2021-03-09 17:00:00	\N	\N	2	0	\N	\N
537918	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	\N	2021-03-09 17:00:00	2021-03-09 19:15:00	\N	\N	3	0	\N	\N
542002	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	Audition par le groupe d'études Français de l"étranger de Jean-Baptiste LEMOYNE	Audition de Jean-Baptiste LEMOYNE, Secrétaire d'Etat chargé du Tourisme, desFrançais de l'étranger et de la Francophonie	2021-03-17 16:30:00	2021-03-17 18:00:00	\N	\N	14	0	\N	\N
549646	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2021-04-01 09:00:00	2021-04-01 10:25:00	\N	\N	2	0	\N	\N
551632	ETUDES	AUCUNE	\N	\N	\N	Réunion du bureau	Réunion du bureau	2021-04-08 11:00:00	2021-04-08 11:45:00	\N	\N	4	0	\N	1005
551641	GIA	AUCUNE	\N	\N	\N	Echange avec l'ambassadrice de France au Liban	Echange avec Mme Anne Grillo, ambassadrice de France au Liban	2021-04-12 12:00:00	2021-04-12 14:00:00	\N	\N	5	0	597	\N
552859	MECSS	AUDRAP	\N	\N	MECSS	Audition réserves des régimes de retraite	\N	2021-04-14 13:45:00	2021-04-14 14:30:00	\N	\N	6	0	\N	\N
553848	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Haut	\N	2021-04-13 15:00:00	2021-04-13 15:45:00	\N	\N	2	0	\N	\N
553855	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Haut Karabakh	\N	2021-04-13 16:00:00	2021-04-13 17:30:00	\N	\N	4	0	\N	\N
554823	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Enseignement spectacle vivant - CNSMD Lyon/CNAC	Contrôle 2021 - Enseignement spectacle vivant - CNSMD Lyon/CNAC	2021-04-13 14:00:00	2021-04-13 16:30:00	\N	\N	2	0	\N	\N
554826	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Services dédiés à la recherche patrimoniale -  Architectes du Patrimoine	Contrôle 2021 - Services dédiés à la recherche patrimoniale - Architectes du Patrimoine	2021-04-13 16:30:00	2021-04-13 17:30:00	\N	\N	1	0	\N	\N
554828	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Services dédiés à la recherche patrimoniale -  ARC-Nucléart et CICRP	Contrôle 2021 - Services dédiés à la recherche patrimoniale -  ARC-Nucléart et CICRP	2021-04-14 14:00:00	2021-04-14 15:15:00	\N	\N	2	0	\N	\N
554831	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Écologie - Mission IGF et CGEDD	PLF pour 2022 - Écologie - Mission IGF et CGEDD	2021-04-14 09:45:00	2021-04-14 11:15:00	\N	\N	1	0	\N	\N
554833	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Météo France - DGAC	Contrôle 2021 - Météo France - DGAC	2021-04-15 14:15:00	2021-04-15 15:30:00	\N	\N	1	0	\N	\N
554835	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - PGE - CPME	Contrôle 2021 - PGE - CPME	2021-04-13 15:50:00	2021-04-13 16:40:00	\N	\N	1	0	\N	\N
554837	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - PGE - CNAJMJ/MEDEF	Contrôle 2021 - PGE - CNAJMJ/MEDEF	2021-04-15 14:30:00	2021-04-15 16:25:00	\N	\N	1	0	\N	\N
554839	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 2021 - Dépenses État Outre-Mer - Cour des comptes	58-2 2021 - Dépenses État Outre-Mer - Cour des comptes	2021-04-14 09:30:00	2021-04-14 10:30:00	\N	\N	2	0	\N	\N
554842	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Forces de souveraineté - EMM/EMAT	Contrôle 2021 - Forces de souveraineté - EMM/EMAT	2021-04-15 15:00:00	2021-04-15 17:00:00	\N	\N	1	0	\N	\N
554844	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Financement aires protégées - FCEN/ONF	Contrôle 2021 - Financement aires protégées - FCEN/ONF	2021-04-13 09:00:00	2021-04-13 11:00:00	\N	\N	1	0	\N	\N
554846	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - IRE - Direction du Budget	Contrôle 2021 - IRE - Direction du Budget	2021-04-14 09:30:00	2021-04-14 10:30:00	\N	\N	1	0	\N	\N
554848	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PJL Climat volet se nourrir	\N	2021-04-19 14:00:00	2021-04-19 15:00:00	\N	\N	2	0	\N	\N
593451	GIA	AUCUNE	\N	\N	\N	Déjeuner avec l'Ambassadrice de Grèce	Déjeuner avec l'Ambassadrice de Grèce au restaurant du Sénat	2021-07-13 12:45:00	2021-07-13 14:15:00	\N	\N	8	0	591	\N
593463	GIA	AUCUNE	\N	\N	\N	Déjeuner à l'ambassade de Grèce	Déjeuner à l'ambassade de Grèce avec l'ambassadrice et le ministre délégué aux affaires étrangères	2021-03-16 13:30:00	2021-03-16 15:00:00	\N	\N	3	0	591	\N
595705	ETUDES	AUTRE	\N	\N	\N	Audition InVivo	\N	2021-10-20 13:30:00	2021-10-20 15:00:00	\N	\N	5	0	\N	1005
595717	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition M. Thierry Breton	\N	2021-10-28 09:45:00	2021-10-28 11:00:00	2021-10-28 15:23:54	2021-10-28 15:42:57	34	0	\N	\N
595718	MISSION	AUDRAP	\N	CONF	\N	Situation en Nouvelle Calédonie	Situation en Nouvelle Calédonie	2021-10-25 09:00:00	2021-10-25 10:30:00	\N	\N	2	0	\N	\N
595725	DELEGATION	AUDRAP	\N	\N	206	Audition de rapporteur 	\N	2021-10-20 11:00:00	2021-10-20 12:30:00	\N	\N	2	0	\N	\N
596553	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Présentationpar  M. André Gattolin du rapport  « Influences étatiques extra-européennes »	\N	2021-10-27 09:35:00	2021-10-27 11:55:00	2021-10-27 11:52:17	2021-10-27 19:08:45	29	0	\N	\N
599747	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2022 - Programme Hébergement - Mission Cohésion territoires	\N	2021-11-04 14:00:00	2021-11-04 15:00:00	\N	\N	1	0	\N	\N
603493	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Adition DAG	\N	2021-11-09 15:00:00	2021-11-09 16:00:00	\N	\N	1	0	\N	\N
603495	DELEGATION	AUCUNE	\N	\N	211	Audition de M. Adrien Taquet	\N	2021-12-02 09:00:00	2021-12-02 10:40:00	\N	\N	11	0	\N	\N
603524	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2022 - Avis Recherche - Audition M. Jean-Pierre Moga	PLF 2022 - Avis Recherche - Audition M. Jean-Pierre Moga	2021-11-09 08:30:00	2021-11-09 10:45:00	\N	\N	1	0	\N	\N
603526	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2022 - Avis Recherche - Auditions du CNES	PLF 2022 - Avis Recherche - Auditions du CNES	2021-11-09 15:00:00	2021-11-09 16:00:00	\N	\N	1	0	\N	\N
603528	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2022 - Avis Recherche -Auditions M. Jean-Pierre Moga	PLF 2022 - Avis Recherche -Auditions M. Jean-Pierre Moga	2021-11-10 08:00:00	2021-11-10 08:45:00	\N	\N	1	0	\N	\N
603529	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions M. Jean-Pierre Moga	\N	2021-11-10 14:00:00	2021-11-10 14:45:00	\N	\N	0	0	\N	\N
603535	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Mme Anne Catherine Loisier	\N	2021-11-09 17:00:00	2021-11-09 18:00:00	\N	\N	1	0	\N	\N
603537	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Mme Anne-Catherine Loisier	\N	2021-11-16 16:00:00	2021-11-16 19:00:00	\N	\N	0	0	\N	\N
603539	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions M. Jean-Pierre Moga	\N	2021-11-17 11:00:00	2021-11-17 12:00:00	\N	\N	0	0	\N	\N
603544	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions M. Jean-Pierre Moga	\N	2021-11-15 16:30:00	2021-11-15 20:15:00	\N	\N	0	0	\N	\N
603551	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2022 - Audition DAG 	PLF pour 2022 - Audition DAG 	2021-11-15 11:00:00	2021-11-15 12:00:00	\N	\N	0	0	\N	\N
613153	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI COM AEFE	\N	2021-12-07 15:30:00	2021-12-07 16:30:00	\N	\N	2	0	\N	\N
613175	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PPL AEFE	\N	2021-12-09 15:30:00	2021-12-09 16:30:00	\N	\N	1	0	\N	\N
613177	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Entretien avec une délégation géorgienne	\N	2021-12-09 10:00:00	2021-12-09 11:00:00	\N	\N	1	0	\N	\N
616378	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	MCC Sécurisation de la chasse-Déplacement dans l'Ain	MCC Sécurisation de la chasse-Déplacement dans l'Ain	2021-12-20 09:00:00	2021-12-20 16:30:00	\N	\N	5	0	\N	\N
618607	COM_PERMANENTE	AUDRAP	\N	CDD	\N	MI Aménagement du territoire - Audition Mme Demas	MI Aménagement du territoire - Audition Mme Demas	2022-01-04 14:30:00	2022-01-04 17:45:00	\N	\N	1	0	\N	\N
618611	COM_PERMANENTE	AUDRAP	\N	CDD	\N	MI Aménagement du territoire - Audition Mmes Filleul et Herzog	MI Aménagement du territoire - Audition Mmes Filleul et Herzog	2022-01-04 14:30:00	2022-01-04 15:25:00	\N	\N	3	0	\N	\N
618617	COM_PERMANENTE	AUDRAP	\N	CDD	\N	MI Aménagement du territoire - Audition Mmes Filleul et Herzog	MI Aménagement du territoire - Audition Mmes Filleul et Herzog	2022-01-04 17:00:00	2022-01-04 17:45:00	\N	\N	2	0	\N	\N
618621	COM_PERMANENTE	AUDRAP	\N	CDD	\N	MI Aménagement du territoire - Audition M. Belin et Mme Herzog	MI Aménagement du territoire - Audition M. Belin et Mme Herzog	2022-01-04 15:15:00	2022-01-04 16:00:00	\N	\N	3	0	\N	\N
618630	COM_PERMANENTE	AUDRAP	\N	CDD	\N	MI Aménagement du territoire - Auditions M. Belin et Mme Herzog	MI Aménagement du territoire - Auditions M. Belin et Mme Herzog	2022-01-04 18:15:00	2022-01-04 19:00:00	\N	\N	2	0	\N	\N
621285	COM_ENQUETE	PLENIERE	\N	CABINETS	\N	Auditions plénières - Cabinet McKinsey - Table ronde de sociologues	Auditions plénières - Cabinet McKinsey - Table ronde de sociologues	2022-01-18 14:30:00	2022-01-18 17:20:00	2022-01-18 17:41:22	2022-01-19 16:56:39	13	0	\N	\N
621291	COM_ENQUETE	PLENIERE	\N	CABINETS	\N	Auditions plénières - Amélie de Montchalin, Ministre - TR cabinets de conseil	Auditions plénières - Amélie de Montchalin, Ministre - TR cabinets de conseil	2022-01-19 16:30:00	2022-01-19 19:30:00	2022-01-19 19:33:16	2022-01-20 11:34:01	13	0	\N	\N
621343	COM_PERMANENTE	AUTRE	\N	ETRD	\N	1 convention et audition ambassadeur de Russie en France	\N	2022-01-19 10:45:00	2022-01-19 11:55:00	2022-01-19 15:33:32	2022-01-19 17:06:54	34	3	\N	\N
622970	GIA	AUCUNE	\N	\N	\N	Entretien avec le conseil de la CCIFF et S.E. M. Teemu TANNER, ambassadeur de Finlande	Entretien avec le conseil de la CCIF  et S.E. M. Teemu TANNER, ambassadeur de Finlande	2021-11-17 20:00:00	2021-11-17 22:00:00	\N	\N	1	0	640	\N
622972	GIA	AUCUNE	\N	\N	\N	Réception à l¿occasion de la fête nationale finlandaise à l¿ambassade de Finlande en Franc	Réception à l¿occasion de la fête nationale finlandaise à l¿ambassade de Finlande en France 	2021-12-03 12:30:00	2021-12-03 14:30:00	\N	\N	1	0	640	\N
624176	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Conférence IHEDN	Programme 144 - Financement  de la BITD	2022-01-18 14:00:00	2022-01-18 17:00:00	\N	\N	1	0	\N	\N
624342	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Amendements de séance - PPL harcèlement scolaire	\N	2022-01-26 14:00:00	2022-01-26 14:44:00	2022-02-01 17:59:22	2022-02-01 18:06:57	28	1	\N	\N
624394	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2022-02-02 16:30:00	2022-02-02 18:00:00	2022-02-08 18:22:22	2022-02-09 09:59:47	22	0	\N	\N
624491	MISSION	AUCUNE	\N	SECUECO	\N	Audition William DAB	\N	2022-01-26 17:00:00	2022-01-26 18:40:00	2022-02-01 17:55:46	2022-02-01 18:00:46	5	0	\N	\N
624512	COM_EURO	AUDRAP	\N	AFEU	\N	Paquet Climat - Secteur énergie	Paquet Climat - Secteur énergie - TR Gaz 	2022-01-25 14:00:00	2022-01-25 15:00:00	\N	\N	3	0	\N	\N
624520	COM_EURO	AUDRAP	\N	AFEU	\N	Paquet Climat - Secteur Transports - RP France à Bruxelles	Paquet Climat - Secteur Transports - RP France à Bruxelles	2022-01-25 18:45:00	2022-01-25 19:45:00	\N	\N	4	0	\N	\N
624524	MISSION	AUCUNE	\N	CULTURE	\N	Réunion 20220125	\N	2022-01-25 16:05:00	2022-01-25 18:50:00	2022-01-25 18:52:33	2022-01-26 14:26:37	12	0	\N	\N
624528	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteurs - Mme Viviane Hoffmann, DG Adjointe Culture 	\N	2022-02-10 14:00:00	2022-02-10 15:00:00	\N	\N	0	0	\N	\N
624535	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteurs - S.E.Mme Tolmajyan, Ambassadrice d'Arménie	\N	2022-02-22 15:00:00	2022-02-22 16:00:00	\N	\N	0	0	\N	\N
624665	COM_PERMANENTE	AUTRE	\N	CAE	\N	Présentation paquet "Ajustement à l'objectif 55"	\N	2022-01-25 16:30:00	2022-01-25 17:30:00	2022-02-01 17:57:46	2022-02-01 18:00:18	33	0	\N	\N
624667	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition Franck Riester	\N	2022-01-25 17:35:00	2022-01-25 19:00:00	2022-02-01 17:58:16	2022-02-01 18:00:19	42	0	\N	\N
626560	MISSION	AUDRAP	\N	CULTURE	\N	Audition de la Coordination nationale des conseils de développement	\N	2022-01-27 10:20:00	2022-01-27 11:20:00	\N	\N	4	0	\N	\N
626565	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 3 février	\N	2022-02-03 09:00:00	2022-02-03 10:30:00	2022-02-03 11:54:24	2022-02-03 18:19:27	17	0	\N	\N
626651	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de MM. LE MAIRE et DUSSOPT, ministres, Résultats exercice 2021 et exécution 2022	Audition de MM. LE MAIRE et DUSSOPT, ministres, Résultats exercice 2021 et exécution 2022	2022-02-01 16:30:00	2022-02-01 17:50:00	2022-02-01 18:14:41	2022-02-02 15:43:41	28	0	\N	\N
626652	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition sur les piliers 1 et 2 du cadre inclusif de l¿OCDE sur fiscalité multinationales	Audition conjointe sur les piliers 1 et 2 du cadre inclusif de l¿OCDE sur la fiscalité des multinationales	2022-02-02 10:45:00	2022-02-02 12:35:00	2022-02-02 12:54:32	2022-02-02 15:43:36	36	0	\N	\N
512467	DELEGATION	AUCUNE	\N	\N	211	Adoption du programme de travail de la délégation pour 2021	Adoption du programme de travail de la délégation pour 2021	2020-12-03 09:00:00	2020-12-03 10:25:00	2020-12-03 10:55:53	\N	21	0	\N	\N
512505	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLO Report élections sénatoriales, élections législatives partielles/PJL élections munici	Audition rapporteur - DMAT	2020-12-02 14:30:00	2020-12-02 15:30:00	\N	\N	2	0	\N	\N
516755	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2021 - Examen du rapport en nouvelle lecture	PLF pour 2021 - Examen du rapport en nouvelle lecture	2020-12-16 11:35:00	2020-12-16 12:15:00	2020-12-16 13:16:17	2020-12-16 18:00:34	35	0	\N	\N
516756	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2021 - Suite de l'examen du rapport en nouvelle lecture	PLF pour 2021 - Suite de l'examen du rapport en nouvelle lecture	2020-12-16 16:35:00	2020-12-16 16:40:00	2020-12-17 09:31:58	2020-12-17 17:38:36	22	0	\N	\N
516854	COM_EURO	AUTRE	\N	AFEU	\N	Audition de Mme Anne-Marie Descôtes, Ambassadrice de France en Allemagne	Réunion Commission des affaires européennes 1°) Union de la sécurité 2°) audition Ambassadrice de France en Allemagne	2020-12-17 08:15:00	2020-12-17 11:00:00	\N	\N	24	0	\N	\N
516876	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de M. Jean Bassères	\N	2020-12-16 17:05:00	2020-12-16 18:45:00	2020-12-17 17:36:05	2020-12-17 17:38:38	15	0	\N	\N
516877	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2020-12-16 09:05:00	2020-12-16 12:10:00	2020-12-17 17:42:01	2020-12-17 18:27:58	31	0	\N	\N
517767	GIA	AUCUNE	\N	\N	\N	Assemblée générale constitutive	Assemblée générale constitutive	2020-12-16 13:35:00	2020-12-16 14:05:00	\N	\N	7	0	612	\N
517779	GIA	AUCUNE	\N	\N	\N	Assemblée générale constitutive	Assemblée générale constitutive	2020-12-15 14:05:00	2020-12-15 14:35:00	\N	\N	12	0	572	\N
517840	GIA	AUCUNE	\N	\N	\N	Réunion constitutive GIA France-Palestine	Réunion constitutive GIA France-Palestine	2020-12-16 14:20:00	2020-12-16 14:45:00	\N	\N	8	0	632	\N
519210	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de M. Olivier Véran, ministre des solidarités et de la santé	\N	2021-01-12 17:05:00	2021-01-12 18:05:00	2021-01-12 18:06:31	2021-01-13 14:39:36	46	0	\N	\N
519212	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2021-01-13 08:35:00	2021-01-13 12:30:00	2021-01-25 09:50:03	2021-01-25 10:01:28	44	0	\N	\N
519213	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Code de la justice pénale des mineurs	Table ronde syndicats PJJ	2021-01-05 10:30:00	2021-01-05 12:30:00	\N	\N	4	0	\N	\N
519218	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Code de la justice pénale des mineurs	PJL Code de la justice pénale des mineurs	2021-01-05 14:30:00	2021-01-05 17:30:00	\N	\N	5	0	\N	\N
519223	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de Gérald Darmanin, ministre de l'intérieur	Audition de Gérald Darmanin, ministre de l'intérieur	2021-01-12 18:15:00	2021-01-12 19:55:00	2021-01-13 07:38:49	2021-01-13 14:39:37	31	0	\N	\N
519225	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Squat - Gens du voyage - Crimes sexuels sur mineurs (rapports et textes)	PPL Squat - Gens du voyage - Crimes sexuels sur mineurs (rapports et textes)	2021-01-13 08:30:00	2021-01-13 13:00:00	2021-01-13 13:42:16	2021-01-13 15:53:05	39	0	\N	\N
519227	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Auditions : 1° Eric Dupond-Moretti ; 2° Jean-Louis Debré	Auditions : 1° Eric Dupond-Moretti ; 2° Jean-Louis Debré	2021-01-13 16:35:00	2021-01-13 19:50:00	2021-01-13 20:03:23	2021-01-14 16:25:17	23	0	\N	\N
525905	GIA	AUCUNE	\N	\N	\N	Bureau du groupe d'amitié	Réunion du bureau du groupe d'amitié	2021-01-27 14:00:00	2021-01-27 14:50:00	\N	\N	3	0	641	\N
525917	GIA	AUCUNE	\N	\N	\N	Audition de M. Adel Bakawan, chercheur	Audition conjointe avec le GIA France-Irak de M. Adel Bakawan, chercheur associé à l'IFRI, spécialiste de l'Irak	2021-02-02 14:00:00	2021-02-02 15:00:00	\N	\N	3	0	615	\N
525926	GIA	AUCUNE	\N	\N	\N	Rencontre avec M. Damien Syed	Rencontre avec M. Damien Syed, sous-directeur pour l'Asie méridionale au MEAE	2021-02-03 17:00:00	2021-02-03 18:00:00	\N	\N	2	0	648	\N
525928	GIA	AUCUNE	\N	\N	\N	Visioconférence Martinon	Visioconférence avec M. David Martinon, ambassadeur de France en Afghanistan	2021-02-16 15:00:00	2021-02-16 16:00:00	\N	\N	2	0	648	\N
526233	DELEGATION	AUDRAP	\N	\N	206	Audition Production d'hydrogène - EDF	Audition Production d'hydrogène - EDF	2021-01-28 15:00:00	2021-01-28 16:15:00	\N	\N	1	0	\N	\N
526237	DELEGATION	AUDRAP	\N	\N	206	Audition Production d'hydrogène - SYLFEN	Audition Production d'hydrogène - SYLFEN	2021-01-28 16:15:00	2021-01-28 17:00:00	\N	\N	1	0	\N	\N
526239	DELEGATION	AUDRAP	\N	\N	206	Audition Production d'hydrogène - ADEME	Audition Production d'hydrogène - ADEME	2021-01-28 17:00:00	2021-01-28 18:00:00	\N	\N	1	0	\N	\N
529168	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Transport de marchandises-Fédération nationale transports routiers	MI Transport de marchandises-Fédération nationale transports routiers	2021-02-02 14:30:00	2021-02-02 15:30:00	\N	\N	10	0	\N	\N
529179	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Transport de marchandises-Associations de riverains	MI Transport de marchandises-Associations de riverains	2021-02-02 15:35:00	2021-02-02 16:30:00	\N	\N	8	0	\N	\N
529188	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Transport de marchandises - Yves Crozet, économiste	MI Transport de marchandises - Yves Crozet, économiste	2021-02-02 16:35:00	2021-02-02 17:30:00	\N	\N	7	0	\N	\N
531551	DELEGATION	AUCUNE	\N	\N	DSOM	Auditions sur le logement dans les outre-mer	\N	2021-03-04 09:00:00	2021-03-04 11:30:00	\N	\N	15	0	\N	\N
531687	DELEGATION	AUCUNE	\N	\N	DSOM	Audition du BNTEC, du CSTB et du CEREMA	\N	2021-03-11 09:00:00	2021-03-11 11:30:00	\N	\N	11	0	\N	\N
531688	DELEGATION	AUCUNE	\N	\N	DSOM	Audition de CDC Habitat	\N	2021-03-11 14:30:00	2021-03-11 16:10:00	\N	\N	5	0	\N	\N
531715	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Diverses mesures de justice sociale	\N	2021-02-16 14:30:00	2021-02-16 15:30:00	\N	\N	2	0	\N	\N
532011	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Droit à mourir dans la dignité - Table ronde de comités éthiques et sociaux	\N	2021-02-16 15:00:00	2021-02-16 16:30:00	\N	\N	5	0	\N	\N
532012	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Droit à mourir dans la dignité - Table ronde d'associations	\N	2021-02-16 16:30:00	2021-02-16 18:00:00	\N	\N	6	0	\N	\N
532981	ETUDES	AUTRE	\N	\N	\N	GE Cancer - Audition de la société Elekta	\N	2021-02-17 14:00:00	2021-02-17 15:00:00	\N	\N	7	0	\N	1004
533019	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Négociation collective - Audition de Pierre Gattaz	\N	2021-02-17 13:00:00	2021-02-17 14:00:00	\N	\N	1	0	\N	\N
533020	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Lutter contre les fraudes sociales	\N	2021-02-17 11:00:00	2021-02-17 12:15:00	\N	\N	1	0	\N	\N
533028	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Négociation collective - Audition du MEDEF	\N	2021-02-17 14:00:00	2021-02-17 15:00:00	\N	\N	1	0	\N	\N
533383	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Diverses mesures de justice sociale	\N	2021-02-17 14:00:00	2021-02-17 14:30:00	\N	\N	3	0	\N	\N
533386	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Diverses mesures de justice sociale	\N	2021-02-17 16:00:00	2021-02-17 16:40:00	\N	\N	1	0	\N	\N
534257	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2021-03-03 15:00:00	2021-03-03 16:15:00	\N	\N	212	0	\N	\N
534258	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat accord commerce Royaume-Uni/UE	Débat sur l'accord de commerce et de coopération entre le Royaume-Uni et l'Union européenne	2021-03-03 16:30:00	2021-03-03 19:25:00	\N	\N	74	0	\N	\N
598521	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	plf enssco	\N	2021-10-15 14:30:00	2021-10-15 15:30:00	\N	\N	4	0	\N	\N
598524	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	plf enssco	\N	2021-10-18 19:00:00	2021-10-18 20:00:00	\N	\N	1	0	\N	\N
598525	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	plf enssco	\N	2021-10-25 17:00:00	2021-10-25 18:00:00	\N	\N	4	0	\N	\N
598526	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	plf enssco	\N	2021-11-02 16:20:00	2021-11-02 16:50:00	\N	\N	2	0	\N	\N
598545	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	plf patrimoine	\N	2021-10-19 17:30:00	2021-10-19 19:00:00	\N	\N	3	0	\N	\N
598546	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	plf patrimoine	\N	2021-10-22 15:00:00	2021-10-22 16:30:00	\N	\N	2	0	\N	\N
598547	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	plf patrimoine	\N	2021-10-26 14:30:00	2021-10-26 16:30:00	\N	\N	2	0	\N	\N
598548	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	plf patrimoine	\N	2021-10-27 14:00:00	2021-10-27 15:00:00	\N	\N	1	0	\N	\N
598549	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	plf patrimoine	\N	2021-11-02 14:00:00	2021-11-02 14:35:00	\N	\N	1	0	\N	\N
598550	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	plf patrimoine	\N	2021-10-29 16:00:00	2021-10-29 17:00:00	\N	\N	2	0	\N	\N
598560	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	plf patrimoine	\N	2021-11-03 14:00:00	2021-11-03 15:10:00	\N	\N	1	0	\N	\N
598561	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Institut national de recherches archéologiques préventives 	\N	2021-11-10 17:30:00	2021-11-10 18:30:00	\N	\N	2	0	\N	\N
598565	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Mi bilan mesures éducatives	\N	2021-10-12 14:00:00	2021-10-12 17:00:00	\N	\N	4	0	\N	\N
598566	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI bilan des mesures éducatives du quinquennat	\N	2021-10-19 14:00:00	2021-10-19 16:30:00	\N	\N	3	0	\N	\N
598567	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI bilan	\N	2021-11-02 14:00:00	2021-11-02 15:00:00	\N	\N	5	0	\N	\N
598568	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI bilan	\N	2021-11-09 14:00:00	2021-11-09 16:30:00	\N	\N	0	0	\N	\N
598578	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2022 Assurance maladie - Audition de la DGS	\N	2021-10-26 17:00:00	2021-10-26 18:00:00	\N	\N	5	0	\N	\N
598579	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2022 Assurance maladie - Audition du CGLPL	\N	2021-10-26 18:30:00	2021-10-26 19:30:00	\N	\N	2	0	\N	\N
598580	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2022 Assurance maladie - Table ronde de SCMR	\N	2021-10-27 14:00:00	2021-10-27 15:00:00	\N	\N	3	0	\N	\N
598581	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2022 Assurance maladie et équilibres financiers généraux- Audition du CEPS	\N	2021-10-27 16:30:00	2021-10-27 17:30:00	\N	\N	2	0	\N	\N
598582	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2022 Assurance maladie - Audition du CPSTI	\N	2021-10-27 17:30:00	2021-10-27 18:30:00	\N	\N	3	0	\N	\N
598583	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2022 Assurance maladie - Audition de la DSS	\N	2021-10-26 15:30:00	2021-10-26 16:30:00	\N	\N	5	0	\N	\N
598584	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2022 Assurance maladie et Autonomie - Audition de la DGCS	\N	2021-10-27 18:30:00	2021-10-27 19:30:00	\N	\N	4	0	\N	\N
598585	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2022 Branche autonomie - Audition de l'AdF	\N	2021-10-25 18:30:00	2021-10-25 19:30:00	\N	\N	2	0	\N	\N
598586	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2022 Branche autonomie - Audition de la Fepem	\N	2021-10-26 14:00:00	2021-10-26 14:45:00	\N	\N	2	0	\N	\N
598587	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2022 Branche autonomie - Audition de l'Unapei	\N	2021-10-27 17:30:00	2021-10-27 18:30:00	\N	\N	2	0	\N	\N
601660	COM_PERMANENTE	DEPLACEMENT	\N	CAE	\N	PLF 2022 - Avis Cohésion des territoires - Déplacement Chanteloup-les-Vignes	PLF 2022 - Avis Cohésion des territoires - Déplacement Chanteloup-les-Vignes	2021-11-09 09:30:00	2021-11-09 12:00:00	\N	\N	1	0	\N	\N
601685	DELEGATION	AUCUNE	\N	\N	PROS	Examen de rapport	\N	2021-11-09 17:05:00	2021-11-09 18:10:00	\N	\N	11	0	\N	\N
608790	CONF_PRES	AUCUNE	\N	\N	\N	Conf Prés	Conférence des Présidents	2021-11-23 17:30:00	2021-11-23 18:20:00	\N	\N	27	0	\N	\N
608830	CONF_PRES	AUCUNE	\N	\N	\N	Conf Prés	Conférence des Présidents	2021-11-02 18:30:00	2021-11-02 19:00:00	\N	\N	22	0	\N	\N
608882	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Nicolas Roche, directeur de cabinet du ministre Le Drian	\N	2021-11-04 11:00:00	2021-11-04 12:00:00	\N	\N	2	0	623	\N
608885	GIA	AUCUNE	\N	\N	\N	Présentation du palais à une équipe de télévision taïwanaise	Présentation du palais à une équipe de télévision taïwanaise (Set News Channel)	2021-11-15 09:00:00	2021-11-15 11:00:00	\N	\N	1	0	623	\N
608902	MISSION	AUCUNE	\N	CONF	\N	Perspectives d'évolution de l'épidémie de covid-19	Perspectives d'évolution de l'épidémie de covid-19	2021-11-30 15:20:00	2021-11-30 16:45:00	2021-11-30 17:50:03	2021-12-01 17:30:09	10	0	\N	\N
608947	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Réunion constitutive	\N	2021-11-30 16:30:00	2021-11-30 17:30:00	\N	\N	0	0	\N	\N
616281	GIA	AUCUNE	\N	\N	\N	réunion commune de 4 GIA	réunion commune France-Allemagne, France-Biélorussie, France-pays Baltes et France-Pologne	2021-12-15 13:45:00	2021-12-15 15:10:00	\N	\N	5	0	852	\N
618372	COM_PERMANENTE	AUTRE	\N	CAE	\N	PPL Cardoux - examen amendements de séance	\N	2022-01-10 18:00:00	2022-01-10 18:10:00	2022-01-10 18:20:05	2022-01-11 14:21:06	19	2	\N	\N
618373	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition art 13 Autorité de la concurrence	\N	2022-01-12 09:30:00	2022-01-12 11:00:00	2022-01-12 11:25:46	2022-01-13 18:45:29	43	0	\N	\N
618374	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Situation et perspectives SNCF - AFRA	Contrôle 2021 - Situation et perspectives SNCF - AFRA	2022-01-04 09:00:00	2022-01-04 10:10:00	\N	\N	2	0	\N	\N
618408	COM_ENQUETE	AUDRAP	\N	HOPITAL	\N	Audition Pr Granger	\N	2022-01-07 14:45:00	2022-01-07 15:45:00	\N	\N	5	0	\N	\N
618409	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	Audition rapporteure - SG Ministères économiques et financiers - DGPN - DG ANAP	\N	2022-01-11 15:30:00	2022-01-11 18:30:00	\N	\N	0	0	\N	\N
521436	GIA	AUCUNE	\N	\N	\N	AG groupe d'amitié France-Israël	\N	2021-01-12 14:00:00	2021-01-12 14:15:00	\N	\N	30	0	595	\N
618411	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Audition plénière - Directeur général de l'ANSSI - Ministre de la Santé	\N	2022-01-12 16:30:00	2022-01-12 19:00:00	\N	\N	0	0	\N	\N
618824	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition HAS	\N	2022-01-11 10:00:00	2022-01-11 11:00:00	\N	\N	3	0	\N	\N
618825	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition UNAF	Audition UNAF	2022-01-12 14:00:00	2022-01-12 15:00:00	\N	\N	3	0	\N	\N
618827	COM_ENQUETE	AUDRAP	\N	HOPITAL	\N	Audition rapporteure	\N	2022-01-10 19:00:00	2022-01-10 20:05:00	\N	\N	6	0	\N	\N
618834	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteurs culture - M. F. de Mazières, maire de Versailles	Audition rapporteurs culture - M. F. de Mazières, maire de Versailles	2022-01-06 16:30:00	2022-01-06 17:30:00	\N	\N	2	0	\N	\N
618856	COM_ENQUETE	PLENIERE	\N	MEDIA	\N	audition CE médias	\N	2022-01-10 15:30:00	2022-01-10 18:30:00	2022-01-11 11:28:27	2022-01-11 14:21:17	11	0	\N	\N
618857	DELEGATION	AUCUNE	\N	\N	PROS	Audition de M. Jérôme Fourquet	\N	2022-01-13 09:30:00	2022-01-13 11:00:00	2022-01-13 14:11:54	\N	17	0	\N	\N
618873	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2022-01-19 11:34:00	2022-01-19 13:05:00	\N	\N	28	0	\N	\N
619152	MISSION	AUCUNE	\N	RECHINNO	\N	Réunion constitutive	\N	2022-01-11 17:00:00	2022-01-11 17:45:00	2022-01-11 19:07:07	2022-01-13 18:48:09	10	4	\N	\N
620687	GIA	AUCUNE	\N	\N	\N	Audition de l'Ambassadeur du Kazakhstan 	Audition sur la crise au Kazakhstan	2022-01-12 08:45:00	2022-01-12 09:50:00	\N	\N	7	0	556	\N
621376	MISSION	AUCUNE	\N	FONDSMER	\N	Audition Ministre de la Mer	Audition Ministre de la Mer	2022-01-18 17:00:00	2022-01-18 18:10:00	2022-01-18 18:10:01	2022-01-19 16:56:37	11	0	\N	\N
507957	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière	Réunion plénière - Audition du METI	2020-12-03 09:00:00	2020-12-03 10:30:00	2020-12-03 11:19:57	\N	16	0	\N	\N
508189	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2021 - Examen Amdts Gvt article liminaire et article d'équilibre 32	PLF pour 2021 - Examen Amdts Gvt article liminaire et article d'équilibre 32	2020-11-25 14:30:00	2020-11-25 14:55:00	2020-11-25 15:25:02	2020-11-25 16:48:02	28	0	\N	\N
517007	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Nomination rapporteur - Audition Roch-Olivier Maistre (CSA)	\N	2020-12-15 17:00:00	2020-12-15 18:55:00	2020-12-15 19:24:18	2020-12-16 09:53:55	27	0	\N	\N
517036	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Santé environnementale - Audition de Mme Claire Lajaunie	\N	2020-12-09 14:00:00	2020-12-09 15:00:00	\N	\N	3	0	\N	\N
517286	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Droit à l'avortement - Audition du CNSOF	\N	2020-12-15 14:00:00	2020-12-15 14:55:00	\N	\N	2	0	\N	\N
519231	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Brexit	Déplacement à Calais	2021-01-06 06:10:00	2021-01-06 19:20:00	\N	\N	4	0	\N	\N
529023	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Justice de proximité et réponse pénale	PPL Justice de proximité et réponse pénale	2021-02-02 16:00:00	2021-02-02 17:00:00	\N	\N	1	0	\N	\N
529025	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Justice de proximité et réponse pénale	PPL Justice de proximité et réponse pénale	2021-02-02 17:00:00	2021-02-02 19:00:00	\N	\N	2	0	\N	\N
529028	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Justice de proximité et réponse pénale	PPL Justice de proximité et réponse pénale	2021-02-03 14:15:00	2021-02-03 15:00:00	\N	\N	1	0	\N	\N
529030	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Justice de proximité et réponse pénale	PPL Justice de proximité et réponse pénale	2021-02-03 16:30:00	2021-02-03 17:35:00	\N	\N	1	0	\N	\N
529035	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Principes de la République	\N	2021-02-03 16:30:00	2021-02-03 19:40:00	\N	\N	7	0	\N	\N
536625	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Auditions groupe de travail "Objectif de zéro artificialisation nette"	Auditions GT "objectif de zéro artificialisation nette"	2021-03-03 16:30:00	2021-03-03 17:45:00	\N	\N	3	0	\N	\N
536629	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Auditions groupe de travail "Objectif de zéro artificialisation nette"	Auditions GT "objectif de zéro artificialisation nette"	2021-03-03 17:45:00	2021-03-03 19:45:00	\N	\N	2	0	\N	\N
536632	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Auditions groupe de travail "Objectif de zéro artificialisation nette"	Auditions GT "objectif de zéro artificialisation nette"	2021-03-04 11:00:00	2021-03-04 12:10:00	\N	\N	3	0	\N	\N
536636	GIA	AUCUNE	\N	\N	\N	Entretien avec l'Ambassadeur du Turkménistan	Entretien avec l'Ambassadeur du Turkménistan	2021-03-02 15:00:00	2021-03-02 15:50:00	\N	\N	2	0	556	\N
536639	GIA	AUCUNE	\N	\N	\N	Entretien avec l'Ambassadeur du Kazakhstan	Entretien avec l'Ambassadeur du Kazakhstan 	2021-03-02 16:00:00	2021-03-02 17:00:00	\N	\N	2	0	556	\N
536642	GIA	AUCUNE	\N	\N	\N	Entretien avec SE M. Alaa YOUSSEF, Ambassadeur d'Egypte à Paris	Entretetien avec l'Ambassadeur d'Egypte	2021-03-02 19:30:00	2021-03-02 20:15:00	\N	\N	1	0	617	\N
537151	GIA	AUCUNE	\N	\N	\N	entretien avec M. Gérard Araud	entretien avec M. Gérard Araud, ancien ambassadeur de France aux Etats-Unis	2021-03-03 16:30:00	2021-03-03 17:30:00	\N	\N	5	0	590	\N
539702	MISSION	AUDRAP	\N	VIETUDIA	\N	Audition Mme Laurence Marion, DG Ciup	\N	2021-03-15 14:00:00	2021-03-15 15:25:00	\N	\N	7	0	\N	\N
539710	MISSION	AUDRAP	\N	VIETUDIA	\N	MIVE: JP Ferré	\N	2021-03-15 15:35:00	2021-03-15 17:05:00	\N	\N	8	0	\N	\N
539738	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI PCI - audition Bouviers	\N	2021-03-12 17:00:00	2021-03-12 17:45:00	\N	\N	2	0	\N	\N
539739	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI patrimoine culturel immatériel	\N	2021-03-16 14:00:00	2021-03-16 16:00:00	\N	\N	2	0	\N	\N
539740	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Audition Fédération parcs naturels	\N	2021-03-18 17:00:00	2021-03-18 18:00:00	\N	\N	1	0	\N	\N
539753	MISSION	AUCUNE	\N	EGALCHAN	\N	Réunion plénière MI Jeunes	\N	2021-03-18 10:37:00	2021-03-18 11:46:00	2021-03-18 14:20:53	2021-03-18 17:53:08	10	0	\N	\N
539764	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-03-24 09:00:00	2021-03-24 10:45:00	2021-03-24 11:08:07	2021-03-24 17:39:18	35	0	\N	\N
539896	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition Direction de l'eau	\N	2021-03-16 09:45:00	2021-03-16 10:30:00	\N	\N	1	0	\N	\N
539943	MISSION	AUCUNE	\N	METHANIS	\N	Réunion plénière MI Méthanisation	\N	2021-03-16 16:32:00	2021-03-16 18:37:00	2021-03-16 19:04:26	2021-03-17 17:02:12	17	0	\N	\N
540131	MISSION	AUTRE	\N	VIETUDIA	\N	Table ronde santédes étudiants	\N	2021-03-25 11:00:00	2021-03-25 13:00:00	\N	\N	0	0	\N	\N
554849	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL Climat Bureau de recherches géologiques et minières (BRGM)	Audition PJL Climat Bureau de recherches géologiques et minières (BRGM)	2021-04-19 14:00:00	2021-04-19 15:00:00	\N	\N	1	0	\N	\N
554850	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL Climat Cabinet Arnaud Gossement	Audition PJL Climat Cabinet Arnaud Gossement	2021-04-19 15:00:00	2021-04-19 15:30:00	\N	\N	1	0	\N	\N
554851	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL Climat Association des communes minières de France	Audition PJL Climat Association des communes minières de France	2021-04-19 15:30:00	2021-04-19 16:15:00	\N	\N	1	0	\N	\N
554852	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL Climat Fédération des opérateurs miniers de Guyane 	Audition PJL Climat Fédération des opérateurs miniers de Guyane 	2021-04-19 16:15:00	2021-04-19 17:15:00	\N	\N	1	0	\N	\N
554855	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL Climat Association des communes et collectivés d'outre-mer 	Audition PJL Climat Association des communes et collectivés d'outre-mer 	2021-04-19 17:15:00	2021-04-19 18:00:00	\N	\N	1	0	\N	\N
554862	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PJL Climat volet se nourrir	Auditions PJL Climat Volet Se Nourrir	2021-04-19 09:30:00	2021-04-19 10:15:00	\N	\N	2	0	\N	\N
554867	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Mission d'évaluation de la Loi SRU	Audition Mission d'évaluation de la Loi SRU	2021-04-15 09:00:00	2021-04-15 09:45:00	\N	\N	2	0	\N	\N
554870	ETUDES	AUTRE	\N	\N	\N	Audition M. Patrick Pouyanné, P-D.G. de Total	Audition M. Patrick Pouyanné, P-D.G. de Total	2021-04-14 08:00:00	2021-04-14 09:00:00	\N	\N	18	0	\N	906
555219	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Dérèglement climatique et résilience - Auditions de M. Philippe Tabarot	PJL Dérèglement climatique et résilience - Auditions de M. Philippe Tabarot	2021-04-21 08:30:00	2021-04-21 10:00:00	\N	\N	4	0	\N	\N
555221	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Dérèglement climatique et résilience - Auditions de M. Philippe Tabarot	PJL Dérèglement climatique et résilience - Auditions de M. Philippe Tabarot	2021-04-21 14:00:00	2021-04-21 15:30:00	\N	\N	2	0	\N	\N
555222	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL Climat volet Se Nourrir	Auditions PJL Climat Volet Se Nourrir	2021-04-23 09:30:00	2021-04-23 12:15:00	\N	\N	1	0	\N	\N
555226	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PPL Bien-être animal	Auditions PPL Bien-être animal	2021-04-21 10:00:00	2021-04-21 12:30:00	\N	\N	2	0	\N	\N
555230	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PPL Bien-être animal	Auditions PPL Bien-être animal	2021-04-22 14:00:00	2021-04-22 17:00:00	\N	\N	2	0	\N	\N
557699	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Table ronde sur les travailleurs des plateformes numériques	\N	2021-05-06 09:00:00	2021-05-06 11:05:00	2021-05-06 16:36:06	\N	13	0	\N	\N
557712	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Dérèglement Climatique et résilience - ATMO	PJL Dérèglement Climatique et résilience - ATMO	2021-05-06 10:00:00	2021-05-06 11:00:00	\N	\N	1	0	\N	\N
557727	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Financement aires protégées - Parcs Nationaux de France	Contrôle 2021 - Financement aires protégées - Parcs Nationaux de France	2021-05-03 10:00:00	2021-05-03 11:00:00	\N	\N	1	0	\N	\N
557731	COM_PERMANENTE	AUTRE	\N	CAE	\N	PPL Bien-être animal et RI ZAN	\N	2021-05-12 09:35:00	2021-05-12 11:50:00	2021-05-12 17:26:46	2021-05-12 18:10:07	36	0	\N	\N
589348	GIA	AUCUNE	\N	\N	\N	GIA France-Népal	Rencontre avec des associations franco-népalaises	2021-10-05 19:30:00	2021-10-05 21:30:00	\N	\N	2	0	633	\N
589351	GIA	AUCUNE	\N	\N	\N	GIA Corne de l'Afrique 	Entretien sur la situation au Somaliland	2021-10-06 08:00:00	2021-10-06 09:00:00	\N	\N	5	0	588	\N
598786	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF	PLF pour 022 - Programme 129	2021-11-02 10:30:00	2021-11-02 12:00:00	\N	\N	2	0	\N	\N
599317	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2021-10-28 08:35:00	2021-10-28 09:55:00	\N	\N	3	0	\N	\N
602259	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2022 - Avis "sécurités" mission "sécurité civile"	Audition rapporteur - PJLF 2022 - Avis "sécurité civile"	2021-11-09 09:00:00	2021-11-09 10:00:00	\N	\N	1	0	\N	\N
602261	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2022 - Avis "sécurités" mission "sécurité civile"	Audition rapporteur - PJLF 2022 - Avis "sécurité civile"	2021-11-09 16:00:00	2021-11-09 17:00:00	\N	\N	2	0	\N	\N
602264	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2022 - Avis "sécurités" mission "sécurité civile"	Audition rapporteur - PJLF 2022 - Avis "sécurité civile"	2021-11-09 18:00:00	2021-11-09 19:00:00	\N	\N	1	0	\N	\N
602310	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2022 - Outre-mer	PLF pour 2022 - Outre-mer	2021-11-10 12:00:00	2021-11-10 13:10:00	\N	\N	1	0	\N	\N
602457	GIA	AUCUNE	\N	\N	\N	Audition du Pr Lionel Honoré	Audition du Pr Lionel Honoré, auteur du rapport "Religion au travail : croire au dialogue" de l'Institut Montaigne	2021-11-10 13:30:00	2021-11-10 14:45:00	\N	\N	5	0	629	\N
602547	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2022 - Avis "sécurités" mission "sécurité civile"	Audition rapporteur - PJLF 2022 - Avis "sécurité civile"	2021-11-10 14:00:00	2021-11-10 15:00:00	\N	\N	1	0	\N	\N
602985	GIA	AUCUNE	\N	\N	\N	Entretien avec les maires bosniens	Entretien avec les maires de Sarajevo, Mostar, Banja Luca et Bijeljina	2021-11-10 11:00:00	2021-11-10 13:00:00	\N	\N	4	0	674	\N
602991	GIA	AUCUNE	\N	\N	\N	déjeuner avec M. Chakib Benmoussa, Ministre de l'Education nationale, ancien ambassadeur 	déjeuner avec M. Chakib Benmoussa, ministre de l'éducation nationale, ancien ambassadeur	2021-11-09 13:30:00	2021-11-09 15:00:00	\N	\N	16	0	598	\N
607524	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Syndicat des Arbitres du Football d'Elite	\N	2021-11-23 14:00:00	2021-11-23 15:00:00	\N	\N	3	0	\N	\N
607528	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Fédération française Handisport	Audition de Mme Westelynck, présidente	2021-11-23 15:30:00	2021-11-23 16:45:00	\N	\N	2	0	\N	\N
608236	COM_EURO	AUDRAP	\N	AFEU	\N	Audition de Mme Rebekah Tromble 	\N	2021-11-22 17:30:00	2021-11-22 18:30:00	\N	\N	2	0	\N	\N
608313	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Mme Mills Wade	Audition rapporteur stratégie numérique de l'UE - European Publishers Council -Mme Mills Wade	2021-11-24 17:00:00	2021-11-24 18:00:00	\N	\N	2	0	\N	\N
608319	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur - stratégie numérique de l'UE - M. Lahrer  - SGAE	\N	2021-11-24 18:00:00	2021-11-24 19:00:00	\N	\N	2	0	\N	\N
608324	DELEGATION	AUCUNE	\N	\N	211	Réunion plénière - Rencontre avec Mme Valérie Perez-Ennouchi, auteure de Destins de Femmes	Réunion plénière - Rencontre avec Mme Valérie Perez-Ennouchi, auteure de Destins de Femmes	2021-12-08 17:00:00	2021-12-08 18:10:00	2021-12-08 18:06:43	\N	7	0	\N	\N
608650	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de M. Bruno Tertrais	Audition de M. Bruno Tertrais	2021-12-01 09:30:00	2021-12-01 11:00:00	2021-12-01 16:07:19	2021-12-01 17:29:44	25	0	\N	\N
608653	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Retraites agricoles - Audition Secrétaire d'État chargé des retraites	\N	2021-11-24 16:30:00	2021-11-24 17:15:00	\N	\N	6	0	\N	\N
610806	GIA	AUCUNE	\N	\N	\N	Déjeuner de travail avec M. Balzaretti, ambassadeur de Suisse	Déjeuner de travail avec M. Balzaretti, ambassadeur de Suisse	2021-06-23 12:30:00	2021-06-23 14:00:00	\N	\N	4	0	610	\N
611607	GIA	AUCUNE	\N	\N	\N	Entretien avec S.E. M. Dae Jong YOO, Ambassadeur de la République de Corée,	\N	2021-12-07 17:00:00	2021-12-07 18:00:00	\N	\N	4	0	613	\N
618319	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2022-01-06 09:30:00	2022-01-06 11:30:00	\N	\N	4	0	\N	\N
530219	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Sécurité globale	PPL Sécurité globale	2021-02-09 17:30:00	2021-02-09 18:30:00	\N	\N	1	0	\N	\N
608234	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2021-12-01 11:37:00	2021-12-01 12:52:00	2021-12-01 13:40:27	2021-12-08 17:39:55	37	0	\N	\N
622978	GIA	AUCUNE	\N	\N	\N	Rencontre F. Naderi	Rencontre avec Mme Farkhunda Zada Naderi, ancienne députée	2021-10-13 13:30:00	2021-10-13 14:45:00	\N	\N	4	0	648	\N
622999	GIA	AUCUNE	\N	\N	\N	Visioconférence avec des sénatrices afghanes	Rencontre en visionconférence avec un groupe de sénatrices afghanes	2021-05-18 14:00:00	2021-05-18 15:00:00	\N	\N	4	0	648	\N
623004	GIA	AUCUNE	\N	\N	\N	Audition sous-directeur Quai d'Orsay	Audition du sous-directeur pour l'Europe centre-orientale et balte du Quai d'Orsay. 	2022-01-19 13:45:00	2022-01-19 14:45:00	\N	\N	5	0	616	\N
624047	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désignations - PPL Adoption & PPL Harcèlement scolaire (amendements)	Désignations - PPL Adoption & PPL Harcèlement scolaire (amendements)	2022-01-26 09:55:00	2022-01-26 10:05:00	2022-01-26 10:51:33	2022-01-26 14:25:11	30	0	\N	\N
624056	COM_ENQUETE	PLENIERE	\N	MEDIA	\N	Audition2 de M. Bernard Arnault, président-directeur général (LVMH) 	\N	2022-01-20 10:30:00	2022-01-20 12:10:00	2022-01-20 15:45:39	2022-01-24 15:30:21	15	0	\N	\N
624079	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 25 janvier 2022 -16H30	Réunion du 25 janvier 2022 - 16H30	2022-01-25 16:30:00	2022-01-25 17:30:00	2022-01-26 15:36:15	2022-01-26 16:45:37	34	0	\N	\N
624080	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 26 janvier 2022	\N	2022-01-26 09:05:00	2022-01-26 10:10:00	2022-01-26 12:08:17	2022-01-26 14:27:19	41	0	\N	\N
624081	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 27 janvier 2022	\N	2022-01-27 09:00:00	2022-01-27 10:00:00	\N	\N	0	0	\N	\N
624109	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Audition Logicités	\N	2022-01-11 17:30:00	2022-01-11 18:30:00	\N	\N	0	0	\N	\N
624117	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Audition GART	\N	2022-01-18 14:30:00	2022-01-18 15:15:00	\N	\N	0	0	\N	\N
624122	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Audition du GART	\N	2022-01-18 15:15:00	2022-01-18 16:00:00	\N	\N	0	0	\N	\N
624126	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Auditions Métropole du Grand Lyon	\N	2022-01-20 10:00:00	2022-01-20 11:15:00	\N	\N	0	0	\N	\N
624127	COM_PERMANENTE	AUDRAP	\N	CDD	\N	MI Aménagement du territoire - Audition Mme Patricia Demas	MI Aménagement du territoire - Audition Mme Patricia Demas	2022-01-20 10:00:00	2022-01-20 11:15:00	\N	\N	1	0	\N	\N
624129	COM_PERMANENTE	AUDRAP	\N	CDD	\N	MI Aménagement du territoire - Audition Mme Patricia Demas	MI Aménagement du territoire - Audition Mme Patricia Demas	2022-01-20 13:30:00	2022-01-20 14:30:00	\N	\N	1	0	\N	\N
624131	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Audition Sicoval	\N	2022-01-20 13:30:00	2022-01-20 14:30:00	\N	\N	0	0	\N	\N
624132	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Audition Rhin Occ	\N	2022-01-20 14:30:00	2022-01-20 15:30:00	\N	\N	0	0	\N	\N
624133	COM_PERMANENTE	AUDRAP	\N	CDD	\N	MI Aménagement du territoire - Audition Mme Patricia Demas	MI Aménagement du territoire - Audition Mme Patricia Demas	2022-01-20 14:30:00	2022-01-20 15:30:00	\N	\N	1	0	\N	\N
624135	DELEGATION	AUCUNE	\N	\N	DSOM	Table ronde sur les câbles sous-marins	\N	2022-01-27 09:30:00	2022-01-27 12:00:00	\N	\N	16	0	\N	\N
624138	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur PPL TDAH - Audition associations d'autistes	\N	2022-01-21 11:00:00	2022-01-21 12:00:00	\N	\N	2	0	\N	\N
624140	DELEGATION	AUTRE	\N	\N	COLTER	Examen du rapport "numérique, protection des populations et territoires"	\N	2022-01-20 10:00:00	2022-01-20 11:00:00	\N	\N	0	0	\N	\N
624141	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-01-26 08:35:00	2022-01-26 12:55:00	2022-01-26 13:15:15	2022-01-26 14:25:09	35	0	\N	\N
624145	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-01-25 14:10:00	2022-01-25 14:30:00	2022-01-25 15:07:42	2022-01-25 18:21:08	28	0	\N	\N
624152	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion pleinière CATDD	\N	2022-01-26 09:00:00	2022-01-26 12:00:00	2022-01-26 12:15:41	2022-01-26 14:25:10	43	1	\N	\N
624153	COM_PERMANENTE	AUTRE	\N	CAE	\N	\N	\N	2022-01-26 09:00:00	2022-01-26 11:50:00	2022-01-26 14:20:43	2022-01-26 14:25:09	46	0	\N	\N
507454	DELEGATION	AUDRAP	\N	\N	206	Audition Phagothérapie - Eligo Bioscience	Audition Phagothérapie - Eligo Bioscience	2020-12-01 09:30:00	2020-12-01 10:15:00	\N	\N	1	0	\N	\N
522587	ETUDES	AUCUNE	\N	\N	\N	Réunion reconstitutive	Réunion reconstitutive	2021-01-20 08:15:00	2021-01-20 09:15:00	\N	\N	14	0	\N	948
526167	ETUDES	AUTRE	\N	\N	\N	Réunion constitutive	\N	2021-01-27 14:00:00	2021-01-27 15:00:00	\N	\N	15	0	\N	911
526184	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PPL Cartes communales	\N	2021-01-23 11:00:00	2021-01-23 11:45:00	\N	\N	1	0	\N	\N
526186	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PPL Cartes communales	\N	2021-01-25 17:00:00	2021-01-25 17:30:00	\N	\N	1	0	\N	\N
526282	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur - M. Bruno Favel	Audition rapporteurs - Politique culturelle de l'UE au service des petites cités de caractère	2021-01-28 10:40:00	2021-01-28 12:15:00	\N	\N	2	0	\N	\N
526283	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Réunion plénière	\N	2016-02-03 10:58:00	2016-02-03 12:20:00	\N	\N	0	0	\N	\N
526286	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Santé environnementale	\N	2021-01-27 16:30:00	2021-01-27 18:15:00	\N	\N	1	0	\N	\N
526325	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Rapporteur PPL améliorer le système de santé	Audition rapporteur - Commission des affaires sociales - Audition PPL Améliorer le système de santé	2021-01-28 11:00:00	2021-01-28 12:45:00	\N	\N	5	0	\N	\N
526367	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteurs - M. Peltre	Audition rapporteurs - Politique culturelle de l'UE au service des petites cités de caractère	2021-01-28 14:20:00	2021-01-28 15:15:00	\N	\N	2	0	\N	\N
526370	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition PPL améliorer le système de santé	\N	2021-01-28 14:30:00	2021-01-28 15:15:00	\N	\N	4	0	\N	\N
526371	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur PPL Améliorer le système de santé	\N	2021-01-28 15:30:00	2021-01-28 16:15:00	\N	\N	3	0	\N	\N
526393	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-02-03 09:30:00	2021-02-03 12:03:00	2021-02-03 17:31:17	2021-02-05 15:34:03	42	0	\N	\N
526394	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de M. Bruno Le Maire	\N	2021-02-02 17:35:00	2021-02-02 19:30:00	2021-02-03 14:46:03	2021-02-03 16:44:07	35	0	\N	\N
526413	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteurs - M. Brunet	Audition rapporteurs - Politique culturelle de l'UE au service des petites cités de caractère	2021-01-28 15:20:00	2021-01-28 16:20:00	\N	\N	2	0	\N	\N
530187	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions	\N	2021-02-09 15:00:00	2021-02-09 16:30:00	\N	\N	0	0	\N	\N
530188	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions	\N	2021-02-09 16:30:00	2021-02-09 19:30:00	\N	\N	0	0	\N	\N
530189	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition DLPAJ	\N	2021-02-10 14:00:00	2021-02-10 15:00:00	\N	\N	0	0	\N	\N
636245	ETUDES	AUCUNE	\N	\N	\N	France Agrimer	France Agrimer	2022-02-23 13:30:00	2022-02-23 14:30:00	\N	\N	10	0	\N	909
530225	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Sécurité globale	PPL Sécurité globale	2021-02-09 18:30:00	2021-02-09 19:30:00	\N	\N	1	0	\N	\N
530782	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions de représentants de France Nature Environnement	Auditions de représentants de France Nature Environnement	2021-02-10 13:30:00	2021-02-10 14:30:00	\N	\N	20	0	\N	\N
530806	MISSION	AUCUNE	\N	EGALCHAN	\N	Réunion constitutive	\N	2021-02-16 14:00:00	2021-02-16 14:26:00	2021-02-16 17:11:53	2021-02-17 18:09:55	18	0	\N	\N
530821	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2021-02-17 08:30:00	2021-02-17 09:45:00	2021-02-17 09:50:18	2021-02-17 18:09:05	34	0	\N	\N
530826	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2021-02-18 09:00:00	2021-02-18 10:30:00	2021-03-01 09:09:47	2021-03-01 11:33:39	24	0	\N	\N
530831	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition Dominique Schnapper	\N	2021-02-16 16:30:00	2021-02-17 17:45:00	\N	\N	34	0	\N	\N
530832	COM_PERMANENTE	AUTRE	\N	AFCL	\N	PJL code mondial antidopage - Examen des amendements de séance	\N	2021-02-16 14:00:00	2021-02-16 14:20:00	2021-02-17 10:25:50	2021-02-17 18:09:07	22	0	\N	\N
530836	COM_PERMANENTE	AUTRE	\N	AFCL	\N	PPL Fondation du Patrimoine - LEC	\N	2021-02-17 14:00:00	2021-02-17 14:45:00	\N	\N	25	0	\N	\N
530840	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Monde combattant	\N	2021-02-11 10:30:00	2021-02-11 12:00:00	\N	\N	1	0	\N	\N
530841	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Monde combattant	\N	2021-02-18 09:30:00	2021-02-18 10:15:00	\N	\N	3	0	\N	\N
530851	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition Blanquer	\N	2021-03-11 11:05:00	2021-03-11 13:15:00	2021-03-11 16:54:39	2021-03-11 18:44:46	26	0	\N	\N
530857	COM_PERMANENTE	AUTRE	\N	AFCL	\N	PJL Respect des principes de la République	\N	2021-03-16 16:30:00	2021-03-16 19:30:00	2021-03-16 20:27:17	2021-03-17 16:58:51	37	0	\N	\N
530867	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2021-03-03 09:30:00	2021-03-03 10:47:00	2021-03-04 08:29:02	2021-03-05 16:21:40	37	0	\N	\N
530868	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition JP Obin et PPL directeur d'école	\N	2021-03-10 09:30:00	2021-03-10 12:32:00	2021-03-10 13:45:19	2021-03-10 17:12:00	40	0	\N	\N
531347	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Fondation du Patrimoine	\N	2021-02-03 16:30:00	2021-02-03 17:30:00	\N	\N	1	0	\N	\N
531349	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Fondation du Patrimoine	\N	2021-02-04 10:00:00	2021-02-04 12:00:00	\N	\N	1	0	\N	\N
534259	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Mobilités espaces peu denses 2040	Débat sur les conclusions du rapport : « Mobilités dans les espaces peu denses à l'horizon 2040 : un défi à relever dès 	2021-03-03 19:30:00	2021-03-03 21:05:00	\N	\N	35	0	\N	\N
534339	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	GT Climat	GT Enjeux internationaux Climat - Environnement - Développement	2021-02-17 13:45:00	2021-02-17 15:00:00	\N	\N	13	0	\N	\N
539755	GIA	AUCUNE	\N	\N	\N	Rencontre avec l'ambassadeur du Suriname	Rencontre avec S.E.M. Reggy Nelson, ambassadeur du Suriname en France	2021-03-01 14:00:00	2021-03-01 15:00:00	\N	\N	1	0	576	\N
539757	GIA	AUCUNE	\N	\N	\N	Rencontre avec une délégation surinamaise	Rencontre avec M. RAMDIN, Ministre des affaires étrangères du Suriname, et M. AMOKSI, Ministre de la Justice du Suriname	2021-03-16 09:30:00	2021-03-16 10:30:00	\N	\N	6	0	576	\N
539911	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2021-03-11 09:05:00	2021-03-11 10:50:00	\N	\N	3	0	\N	\N
542937	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Zéro	Auditions groupe de travail "Objectif de zéro artificialisation nette"	2021-03-18 12:00:00	2021-03-18 13:15:00	\N	\N	2	0	\N	\N
542941	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	zér	Auditions groupe de travail "Objectif de zéro artificialisation nette"	2021-03-18 15:30:00	2021-03-18 17:30:00	\N	\N	2	0	\N	\N
542950	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PPL Hydroélectricité et transition énergétique	Auditions PPL Hydroélectricité et transition énergétique	2021-03-17 18:30:00	2021-03-17 20:00:00	\N	\N	1	0	\N	\N
542952	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PPL Hydroélectricité et transition énergétique	Auditions PPL Hydroélectricité et transition énergétique	2021-03-18 09:30:00	2021-03-18 12:00:00	\N	\N	1	0	\N	\N
542954	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PPL Hydroélectricité et transition énergétique	Auditions PPL Hydroélectricité et transition énergétique	2021-03-18 15:00:00	2021-03-18 16:00:00	\N	\N	1	0	\N	\N
542965	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Suivi loi SRU	Auditions Suivi loi SRU	2021-03-17 16:45:00	2021-03-17 18:00:00	\N	\N	2	0	\N	\N
542968	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Suivi loi SRU	Auditions Suivi loi SRU	2021-03-18 09:00:00	2021-03-18 10:30:00	\N	\N	2	0	\N	\N
545441	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Groupe de travail sur l'avenir de La Poste	Groupe de travail sur l'avenir de La Poste	2021-03-23 13:30:00	2021-03-23 14:00:00	\N	\N	2	0	\N	\N
546723	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Auditions commune Estanguet et ferrand	\N	2021-03-31 09:30:00	2021-03-31 11:30:00	2021-03-31 12:05:48	2021-03-31 18:03:10	30	0	\N	\N
546824	MECSS	AUDRAP	\N	\N	MECSS	Audition réserves des régimes de retraite	\N	2021-03-31 13:45:00	2021-03-31 14:45:00	\N	\N	6	0	\N	\N
547039	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Situation et perspectives SNCF - SNCF Voyageurs	Contrôle 2021 - Situation et perspectives SNCF - SNCF Voyageurs	2021-03-30 08:30:00	2021-03-30 09:45:00	\N	\N	2	0	\N	\N
547136	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Haut Conseil pour le Climat	Contrôle 2021 - Haut Conseil pour le Climat	2021-03-30 14:00:00	2021-03-30 14:45:00	\N	\N	1	0	\N	\N
547139	ETUDES	AUTRE	\N	\N	\N	GEAC - Audition des représentants du groupe Air France	GEAC - Audition des représentants du groupe Air France	2021-04-07 08:00:00	2021-04-07 09:20:00	\N	\N	23	0	\N	933
547140	DELEGATION	AUDRAP	\N	\N	PROS	Audition de M. Olivier Tesquet	Audition de M. Olivier Tesquet, écrivain, 	2021-04-12 10:00:00	2021-04-12 11:00:00	\N	\N	3	0	\N	\N
588838	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audtion de MMe RIXAIN	\N	2021-10-04 14:30:00	2021-10-04 15:30:00	\N	\N	1	0	\N	\N
588839	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Auditon BPI France	\N	2021-10-04 15:30:00	2021-10-04 16:30:00	\N	\N	1	0	\N	\N
588873	DELEGATION	AUCUNE	\N	\N	211	Remise du Prix 2021 de la délégation	Remise du Prix 2021 de la délégation	2021-10-26 17:00:00	2021-10-26 18:10:00	2021-10-26 18:41:42	\N	14	0	\N	\N
588898	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur - PJL Travailleurs indépendants	\N	2021-10-05 10:00:00	2021-10-05 11:00:00	\N	\N	1	0	\N	\N
588900	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur - PJL Travailleurs indépendants	\N	2021-10-05 11:00:00	2021-10-05 12:30:00	\N	\N	1	0	\N	\N
590844	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Justice sociale	PPL Justice sociale	2021-10-12 15:00:00	2021-10-12 16:20:00	\N	\N	85	0	\N	\N
590845	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Droit de visite	PPL Droit de visite	2021-10-12 16:25:00	2021-10-12 18:10:00	\N	\N	96	0	\N	\N
590846	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Implantation locale parlementaires	PPL Implantation locale parlementaires	2021-10-12 18:15:00	2021-10-12 21:20:00	\N	\N	136	0	\N	\N
590850	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2021-10-13 15:00:00	2021-10-13 16:20:00	\N	\N	254	0	\N	\N
590851	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Vaccination obligatoire	PPL Vaccination obligatoire	2021-10-13 16:35:00	2021-10-13 18:50:00	\N	\N	138	0	\N	\N
590854	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Jeunes majeurs étrangers	PPL Jeunes majeurs étrangers	2021-10-13 18:55:00	2021-10-13 20:35:00	\N	\N	70	0	\N	\N
590856	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Conseil européen	Débat Conseil européen	2021-10-13 22:05:00	2021-10-14 00:50:00	\N	\N	30	0	\N	\N
590857	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Matchs de football du 5 mai	PPL Matchs de football du 5 mai	2021-10-14 10:30:00	2021-10-14 12:10:00	\N	\N	59	0	\N	\N
590858	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Barrages hydroélectriques	PPL Barrages hydroélectriques	2021-10-14 12:15:00	2021-10-14 13:00:00	\N	\N	31	0	\N	\N
590860	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Barrages hydroélectriques	PPL Barrages hydroélectriques	2021-10-14 14:30:00	2021-10-14 15:35:00	\N	\N	44	0	\N	\N
590861	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Recours excès de pouvoir	PPL Recours excès de pouvoir	2021-10-14 16:00:00	2021-10-14 17:20:00	\N	\N	40	0	\N	\N
590862	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Dons aux associations	PPL Dons aux associations	2021-10-14 17:25:00	2021-10-14 18:55:00	\N	\N	27	0	\N	\N
590863	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Rémunération des agriculteurs	CMP Rémunération des agriculteurs	2021-10-14 19:00:00	2021-10-15 19:50:00	\N	\N	16	0	\N	\N
593509	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Baz CHULUNBAATAR,  PDG du groupe Monnis	Entretien avec M. Baz CHULUNBAATAR,  PDG du groupe Monnis et Mme Bulga KJALIUN	2021-10-14 13:00:00	2021-10-14 14:00:00	\N	\N	1	0	612	\N
595368	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	CNOSF	\N	2021-10-20 16:30:00	2021-10-20 18:00:00	\N	\N	2	0	\N	\N
598278	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Vigilance sanitaire	PJL Vigilance sanitaire	2021-10-28 21:30:00	2021-10-28 23:50:00	\N	\N	45	0	\N	\N
598492	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJLF 2022 - Logement	Audition PJLF 2022 - Logement	2021-10-20 17:30:00	2021-10-20 18:20:00	\N	\N	2	0	\N	\N
600203	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2022 - Programme 146	\N	2021-11-03 16:30:00	2021-11-03 17:30:00	\N	\N	2	0	\N	\N
608389	GIA	AUCUNE	\N	\N	\N	Rencontre Ambassadeur Palestine	Rencontre avec S.E. H. Abou Hassira, Ambassadeur, Cheffe de la Mission de Palestine en France	2021-11-24 14:00:00	2021-11-24 15:00:00	\N	\N	6	0	632	\N
608636	GIA	AUCUNE	\N	\N	\N	accueil d'une délégation de trois parlementaires du Conseil des Représentants de Bahreïn	\N	2021-11-25 08:15:00	2021-11-25 09:45:00	\N	\N	2	0	661	\N
608639	GIA	AUCUNE	\N	\N	\N	entretien thématique avec trois parlementaires du Conseil des Représentants de Bahreïn	\N	2021-11-25 09:45:00	2021-11-25 11:00:00	\N	\N	2	0	661	\N
608673	COM_ENQUETE	PLENIERE	\N	CABINETS	\N	Audition DITM et Chargé de recherche CNRS 	Audition du Délégué interministériel à la transformation publique et d'un Chargé de recherche CNRS 	2021-12-02 10:30:00	2021-12-02 12:40:00	2021-12-02 12:50:42	2021-12-03 18:39:19	6	0	\N	\N
608943	GIA	AUCUNE	\N	\N	\N	Rencontre avec M. Motlaq	Rencontre avec M. Jabbar Thejil Motlaq, secrétaire général du ministère de la Défense irakien	2021-12-01 14:00:00	2021-12-01 15:00:00	\N	\N	1	0	615	\N
616386	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Crise du logement	Débat Crise du logement	2022-01-04 14:30:00	2022-01-04 16:10:00	\N	\N	74	0	\N	\N
616387	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Asile et immigration	Débat Asile et immigration	2022-01-04 16:15:00	2022-01-04 17:40:00	\N	\N	88	0	\N	\N
616388	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR Vie étudiante	PPR Vie étudiante	2022-01-04 17:45:00	2022-01-04 19:15:00	\N	\N	48	0	\N	\N
616389	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Souveraineté maritime	Débat Souveraineté maritime	2022-01-04 22:20:00	2022-01-04 23:45:00	\N	\N	20	0	\N	\N
616390	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR Agrivoltaïsme	PPR Agrivoltaïsme	2022-01-04 19:20:00	2022-01-04 20:45:00	\N	\N	48	0	\N	\N
616391	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2022-01-05 15:00:00	2022-01-05 16:20:00	\N	\N	249	0	\N	\N
616392	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR Corée	PPR Corée	2022-01-05 16:50:00	2022-01-05 18:10:00	\N	\N	69	0	\N	\N
616393	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Défense contre l'incendie	Débat Défense contre l'incendie	2022-01-05 18:10:00	2022-01-05 19:45:00	\N	\N	52	0	\N	\N
616394	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Ségur hôpital	Débat Ségur hôpital	2022-01-05 21:30:00	2022-01-05 23:05:00	\N	\N	35	0	\N	\N
616395	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Partage du travail	Débat Partage du travail	2022-01-06 10:30:00	2022-01-06 12:10:00	\N	\N	55	0	\N	\N
616396	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Sûreté installations nucléaires	Débat Sûreté installations nucléaires	2022-01-06 12:10:00	2022-01-06 13:45:00	\N	\N	48	0	\N	\N
621843	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL 225 Assurance emprunteur - Convention AERAS	PPL 225 Assurance emprunteur - Convention AERAS	2022-01-13 16:30:00	2022-01-13 17:15:00	\N	\N	1	0	\N	\N
621847	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Protection des épargnants - France Assureurs	Contrôle 2021 - Protection des épargnants - France Assureurs	2022-01-11 17:00:00	2022-01-11 18:00:00	\N	\N	2	0	\N	\N
621851	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Protection des épargnants - AMF	Contrôle 2021 - Protection des épargnants - AMF	2022-01-14 14:00:00	2022-01-14 15:00:00	\N	\N	2	0	\N	\N
621918	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Association TDAH pour une égalité des chances	\N	2022-01-18 13:00:00	2022-01-18 14:00:00	\N	\N	3	0	\N	\N
621958	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition DSS-DGCS	\N	2022-01-20 16:30:00	2022-01-20 17:15:00	\N	\N	3	0	\N	\N
622039	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Audition auteurs du rapport "Logistique urbaine durable"	\N	2022-01-11 16:30:00	2022-01-11 17:30:00	\N	\N	0	0	\N	\N
622044	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Auditions Mmes Martine Filleul et Christine Herzog	\N	2022-01-11 16:30:00	2022-01-11 18:30:00	\N	\N	0	0	\N	\N
622045	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Audition La Poste	\N	2022-01-12 16:30:00	2022-01-12 17:30:00	\N	\N	0	0	\N	\N
622067	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions Pacte vert	Auditions Pacte vert	2022-01-17 15:00:00	2022-01-17 17:00:00	\N	\N	3	0	\N	\N
622076	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Chèque emploi petites communes	\N	2022-01-18 14:00:00	2022-01-18 14:45:00	\N	\N	1	0	\N	\N
625134	COM_PERMANENTE	PLEIN_NON_JO	\N	LOIS	\N	Sensibilisation au risque numérique - présentation par l'ANSSI	Sensibilisation au risque numérique - présentation par l'ANSSI	2022-01-26 09:05:00	2022-01-26 09:50:00	\N	\N	24	0	\N	\N
626692	COM_ENQUETE	PLENIERE	\N	HOPITAL	\N	Audition plénière	\N	2022-02-03 10:30:00	2022-02-03 11:25:00	2022-02-03 11:27:18	2022-02-03 18:54:57	7	0	\N	\N
626693	COM_ENQUETE	PLENIERE	\N	HOPITAL	\N	Auditions plénières	\N	2022-02-03 14:30:00	2022-02-03 16:55:00	2022-02-03 17:32:25	2022-02-03 18:54:57	10	0	\N	\N
626694	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désignation - PJL Fonction publique des communes de Polynésie française (rapport)	Désignation - PJL Fonction publique des communes de Polynésie française (rapport)	2022-02-02 09:30:00	2022-02-02 10:10:00	2022-02-02 11:06:13	2022-02-02 15:43:37	32	0	\N	\N
510754	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF POUR 2021 - Programme 212	\N	2020-11-26 14:30:00	2020-11-26 15:30:00	\N	\N	2	0	\N	\N
510973	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	\N	Elections des Français de l'étranger	2020-11-30 14:00:00	2020-11-30 19:00:00	\N	\N	3	0	\N	\N
513761	GIA	AUCUNE	\N	\N	\N	Assemblée générale 2020	Assemblée générale de reconstitution du groupe	2020-12-02 08:45:00	2020-12-02 09:20:00	\N	\N	8	0	963	\N
518606	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Rapport général - Courtiers assurances	PLF pour 2021 - Rapport général - Courtiers assurances	2020-12-15 09:30:00	2020-12-15 10:15:00	\N	\N	1	0	\N	\N
518668	DELEGATION	AUTRE	\N	\N	211	Audition de M. Cyprien Canivenc et Mme Emma Bouvet	\N	2021-01-14 10:00:00	2021-01-14 11:30:00	\N	\N	0	0	\N	\N
518683	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur - allégations nutritionnelles et allégations de santé	Audition rapporteur -allégations nutritionnelles et allégations de santé	2020-12-15 16:30:00	2020-12-15 17:30:00	\N	\N	1	0	\N	\N
518685	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur - Allégations nutritionnelles et allégations de santé	\N	2020-12-17 11:00:00	2020-12-17 11:40:00	\N	\N	1	0	\N	\N
518687	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Santé environnementale - Audition de Mme Maria Neira (OMS)	\N	2020-12-16 16:30:00	2020-12-16 17:30:00	\N	\N	2	0	\N	\N
518688	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Droit à l'avortement - Audition du Syngof	\N	2020-12-17 09:00:00	2020-12-17 10:00:00	\N	\N	3	0	\N	\N
518689	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Droit à l'avortement - Audition du CNGOF	\N	2020-12-17 10:00:00	2020-12-17 11:00:00	\N	\N	3	0	\N	\N
518690	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Droit à l'avortement - Audition de Mme Albane Gaillot	\N	2020-12-17 16:30:00	2020-12-17 17:15:00	\N	\N	2	0	\N	\N
518731	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Santé environnementale - Table ronde Atmo France, Airparif et DRIEE Idf	\N	2020-12-17 14:30:00	2020-12-17 16:00:00	\N	\N	3	0	\N	\N
518888	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Droit à l'avortement - Audition de la maison des femmes de Saint-Denis	\N	2020-12-18 10:00:00	2020-12-18 11:00:00	\N	\N	2	0	\N	\N
518889	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Droit à l'avortement - Table ronde ANCIC, Planning familial et ANSFO	\N	2020-12-18 11:00:00	2020-12-18 12:00:00	\N	\N	2	0	\N	\N
519248	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition DGCS	\N	2021-01-07 10:30:00	2021-01-07 11:30:00	\N	\N	1	0	\N	\N
519249	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition de Mme Jeantet	\N	2021-01-07 14:30:00	2021-01-07 15:15:00	\N	\N	2	0	\N	\N
525180	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Négociation collective - Audition de M. Jean-Emmanuel Ray	\N	2021-01-26 10:30:00	2021-01-26 11:30:00	\N	\N	1	0	\N	\N
525245	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition PPL améliorer le système de santé	Audition PPL améliorer le système de santé - Audition Conseil national de gestion	2021-01-27 14:15:00	2021-01-27 15:10:00	\N	\N	3	0	\N	\N
525248	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition PPL Améliorer le système de santé	Audition rapporteur - Commission des affaires sociales - Audition PPL Améliorer le système de santé	2021-01-27 16:45:00	2021-01-27 17:30:00	\N	\N	5	0	\N	\N
525255	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur - Etat de droit dans l'UE	Audition rapporteur - Etat de droit dans l'UE - SGAE - MEAE	2021-01-26 15:00:00	2021-01-26 18:25:00	\N	\N	2	0	\N	\N
525740	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 4 février 2021	\N	2021-02-04 08:35:00	2021-02-04 10:30:00	2021-02-04 12:02:18	2021-02-05 15:34:07	23	0	\N	\N
529480	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	webinaire  sur la cyberguerre (UIP)	webinaire  sur la cyberguerre	2021-01-27 16:00:00	2021-01-27 18:00:00	\N	\N	3	0	\N	\N
529488	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	Conférence ONU	Webinaire sur la réforme du Conseil de Sécurité des Nations Unies	2021-01-20 15:00:00	2021-01-20 16:00:00	\N	\N	1	0	\N	\N
533796	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT sur l'avenir de La Poste	GT sur l'avenir de La Poste	2021-02-16 17:30:00	2021-02-16 18:45:00	\N	\N	4	0	\N	\N
540120	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Suivi loi SRU	Auditions Suivi loi SRU	2021-03-16 09:00:00	2021-03-16 10:30:00	\N	\N	2	0	\N	\N
540123	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Réunion GT Agriculteurs en détresse	Réunion GT Agriculteurs en détresse	2021-03-16 16:30:00	2021-03-16 17:50:00	\N	\N	7	0	\N	\N
551543	DELEGATION	AUCUNE	\N	\N	PROS	Audition de M. Dominique Sciamma	Audition de M. Dominique Sciamma	2021-04-15 08:30:00	2021-04-15 10:00:00	\N	\N	14	0	\N	\N
554671	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT Boussole stratégique	\N	2021-04-16 10:00:00	2021-04-16 11:30:00	\N	\N	2	0	\N	\N
556715	GIA	AUCUNE	\N	\N	\N	Entretien sur le Fonds citoyen franco-allemand	Entretien avec Mme Tallineau, Secrétaire générale de l'OFAJ, et M. Benjamin KURC, Responsable du Fonds citoyen F-ALL	2021-05-05 14:00:00	2021-05-05 15:00:00	\N	\N	9	0	604	\N
556731	GIA	AUCUNE	\N	\N	\N	\N	Entretien avec l'ambassadeur de Hongrie	2021-05-05 13:45:00	2021-05-05 14:50:00	\N	\N	9	0	592	\N
557734	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de Mme Emmanuelle Wargon	\N	2021-05-12 16:30:00	2021-05-12 17:55:00	2021-05-14 20:24:16	\N	23	0	\N	\N
557735	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Rapport de la CVFS - Présentation	Rapport de la CVFS - Présentation	2021-05-05 16:45:00	2021-05-05 17:15:00	\N	\N	2	0	\N	\N
557816	MISSION	AUCUNE	\N	EGALCHAN	\N	Réunion plénière MI Jeunes	\N	2021-05-11 16:45:00	2021-05-11 18:12:00	2021-05-11 18:26:02	2021-05-12 15:29:05	5	0	\N	\N
557861	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Climat et résilience "Se loger" - Audition FAP	PJL Climat et résilience "Se loger" - Audition FAP	2021-05-06 09:00:00	2021-05-06 09:40:00	\N	\N	1	0	\N	\N
557864	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur	Audition rapporteurs - Politique culturelle de l'UE au service des petites cités de caractère - Mme Bouvet et M. Mangin	2021-05-06 15:30:00	2021-05-06 16:55:00	\N	\N	2	0	\N	\N
557883	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJLC Article 1er de la Constitution et préservation de l'environnement (amendements)	PJLC Article 1er de la Constitution et préservation de l'environnement (amendements)	2021-05-10 16:00:00	2021-05-10 16:05:00	2021-05-10 16:46:12	2021-05-11 15:54:37	13	0	\N	\N
557884	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désignation de rapporteurs -  PPL Suivi des terroristes sortant de détention (rapport)	Désignation de rapporteurs -  PPL Suivi des terroristes sortant de détention (rapport)	2021-05-12 09:00:00	2021-05-12 10:00:00	2021-05-12 11:17:27	2021-05-12 15:27:50	29	0	\N	\N
557886	COM_PERMANENTE	PEC_NON_MML	\N	LOIS	\N	PPL Améliorer la trésorerie des associations (examen du rapport et du texte - LEC)	PPL Améliorer la trésorerie des associations (examen du rapport et du texte - LEC)	2021-05-12 10:45:00	2021-05-12 11:10:00	2021-05-12 15:48:22	2021-05-12 18:10:08	21	0	\N	\N
558965	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT Institutions	GT institution : audition Rémy Broc et Théo Verdier, experts associés à l'Institut Jacques Delors	2021-05-11 16:35:00	2021-05-11 17:35:00	\N	\N	3	0	\N	\N
559758	MISSION	AUDRAP	\N	VIETUDIA	\N	Table ronde précarité étudiante en PACA	\N	2021-05-17 14:35:00	2021-05-17 16:30:00	\N	\N	5	0	\N	\N
559764	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Dérèglement Climatique et résilience - PFA	PJL Dérèglement Climatique et résilience - PFA	2021-05-12 17:45:00	2021-05-12 18:45:00	\N	\N	1	0	\N	\N
559802	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Table ronde PJL Climat et Résilience - "Se loger" -  FFB / CAPEB / FPI / Altarea / CNOA	Table ronde PJL Climat et Résilience - "Se loger" -  FFB / CAPEB / FPI / Altarea / CNOA	2021-05-10 14:00:00	2021-05-10 15:00:00	\N	\N	1	0	\N	\N
559805	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL Climat et résilience - "Se loger" Table ronde FNAIM / Plurience / UNIS	Audition PJL Climat et résilience - "Se loger" Table ronde FNAIM / Plurience / UNIS	2021-05-10 15:00:00	2021-05-10 16:00:00	\N	\N	1	0	\N	\N
559814	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL Climat et résilience - "Se logger" Table ronde AFG / Coénove / Fedene / Effy	Audition PJL Climat et résilience - "Se logger" Table ronde AFG / Coénove / Fedene / Effy	2021-05-10 16:00:00	2021-05-10 16:45:00	\N	\N	1	0	\N	\N
559817	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL CLimat et résilience - "Se loger" Table ronde  UFE / EDEN / FIEEC	Audition PJL CLimat et résilience - "Se loger" Table ronde  UFE / EDEN / FIEEC	2021-05-10 16:45:00	2021-05-10 17:30:00	\N	\N	1	0	\N	\N
559819	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL Climat et résilience - Ademe	Audition PJL Climat et résilience - Ademe	2021-05-10 17:30:00	2021-05-10 18:15:00	\N	\N	2	0	\N	\N
559820	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL Climat et résilience - "Se loger" Agence nationale de l'habitat	Audition PJL Climat et résilience - "Se loger" Agence nationale de l'habitat	2021-05-10 18:15:00	2021-05-10 19:00:00	\N	\N	2	0	\N	\N
559821	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL Climat et résilience - "Se loger" - Caisse des dépôts et consignations	Audition PJL Climat et résilience - "Se loger" - Caisse des dépôts et consignations	2021-05-10 19:15:00	2021-05-10 20:00:00	\N	\N	2	0	\N	\N
593836	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Mettre l'administration au service des usagers	PPL Mettre l'administration au service des usagers	2021-10-18 16:00:00	2021-10-18 18:45:00	\N	\N	1	0	\N	\N
595798	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	France Télévisions	Audition de Mme Delphine Ernotte-Cunci	2021-10-26 09:30:00	2021-10-26 10:30:00	\N	\N	6	0	\N	\N
596236	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Conférence des présidents d'université	\N	2021-10-26 14:00:00	2021-10-26 15:00:00	\N	\N	4	0	\N	\N
596237	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Auditions de proviseurs de lycée	\N	2021-10-26 15:00:00	2021-10-26 16:00:00	\N	\N	4	0	\N	\N
596247	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Institut national de l'audiovisuel 	\N	2021-10-26 14:30:00	2021-10-26 15:30:00	\N	\N	2	0	\N	\N
596248	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	France Médias Monde	\N	2021-10-26 15:30:00	2021-10-26 16:30:00	\N	\N	1	0	\N	\N
596261	ETUDES	AUTRE	\N	\N	\N	Audition - M. Chaudière, Président AOC Ventoux	Audition - M. Chaudière, Président AOC Ventoux	2021-10-26 15:30:00	2021-10-26 16:30:00	\N	\N	15	0	\N	909
600750	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Tourisme - Audition Parcs d'attractions	GT Tourisme - Audition Parcs d'attractions	2021-11-03 13:30:00	2021-11-03 14:15:00	\N	\N	5	0	\N	\N
621377	MISSION	AUCUNE	\N	FONDSMER	\N	Audition SGMer	Audition SGMer	2022-01-19 17:00:00	2022-01-19 18:30:00	2022-01-19 18:25:46	2022-01-20 11:34:03	8	0	\N	\N
621719	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Auditions de BBelin et SBabary / VA et LB	\N	2022-01-12 16:30:00	2022-01-12 19:30:00	\N	\N	0	0	\N	\N
621720	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Auditions de BBelin et SBabary/ VA et LB - TR Brico, jouets, vêtements	\N	2022-01-12 17:30:00	2022-01-12 18:45:00	\N	\N	0	0	\N	\N
621721	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Auditions de BBelin et SBabary / VA et LB - FDJ	\N	2022-01-12 18:45:00	2022-01-12 19:25:00	\N	\N	0	0	\N	\N
621755	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition MG France	\N	2022-01-17 14:00:00	2022-01-17 14:30:00	\N	\N	2	0	\N	\N
621757	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Assurance emprunteur	Auditions Assurance emprunteur	2022-01-11 09:45:00	2022-01-11 10:30:00	\N	\N	1	0	\N	\N
621758	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions assurance emprunteur	Auditions assurance emprunteur	2022-01-12 16:30:00	2022-01-12 17:15:00	\N	\N	1	0	\N	\N
621759	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition assurance emprunteur	Auditions Assurance emprunteur	2022-01-13 17:30:00	2022-01-13 18:00:00	\N	\N	1	0	\N	\N
621769	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PPL assurance emprunteur	Auditions PPL assurance emprunteur	2021-12-14 13:45:00	2021-12-14 18:30:00	\N	\N	1	0	\N	\N
621770	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PPL Assurance emprunteur	Audition PPL Assurance emprunteur	2021-12-15 16:30:00	2021-12-15 17:00:00	\N	\N	1	0	\N	\N
621772	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Assurance emprunteur - Assemblée nationale	PPL Assurance emprunteur - Assemblée nationale	2021-12-14 15:30:00	2021-12-14 16:15:00	\N	\N	1	0	\N	\N
621773	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Assurance emprunteur APCADE	PPL Assurance emprunteur APCADE	2021-12-14 16:15:00	2021-12-14 16:45:00	\N	\N	1	0	\N	\N
621774	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Assurance emprunteur UFC-Que choisir	PPL Assurance emprunteur UFC-Que choisir	2021-12-14 17:00:00	2021-12-14 17:30:00	\N	\N	1	0	\N	\N
621775	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Assurance emprunteur - Audition de M. Emmanuel Constans	PPL Assurance emprunteur - Audition de M. Emmanuel Constans	2021-12-14 18:00:00	2021-12-14 18:30:00	\N	\N	1	0	\N	\N
621785	COM_ENQUETE	AUDRAP	\N	HOPITAL	\N	Audition Rapporteure de M. Durrleman	\N	2022-01-19 18:00:00	2022-01-19 19:30:00	\N	\N	2	0	\N	\N
621786	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition DSS	\N	2022-01-20 10:00:00	2022-01-20 10:45:00	\N	\N	1	0	\N	\N
621787	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audtion de M. Thevenon 	\N	2022-01-21 14:00:00	2022-01-21 14:45:00	\N	\N	1	0	\N	\N
621788	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition INSEE	\N	2022-01-20 10:45:00	2022-01-20 11:30:00	\N	\N	1	0	\N	\N
621789	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Associations TDAH	\N	2022-01-20 15:30:00	2022-01-20 16:30:00	\N	\N	4	0	\N	\N
621790	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Rapporteures- Directive Salaires Minimaux - RP France auprès de l'UE	Audition Rapporteures- Directive Salaires Minimaux - Représentation permanente de la France auprès de l'UE	2022-01-17 14:30:00	2022-01-17 15:30:00	\N	\N	2	0	\N	\N
622111	ETUDES	AUTRE	\N	\N	\N	Professeur TEISSEDRE - Université de Bordeaux	Professeur TEISSEDRE - Université de Bordeaux	2022-01-18 14:00:00	2022-01-18 15:45:00	\N	\N	19	0	\N	909
622198	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Contrôle parental	Auditions Contrôle parental	2022-01-12 11:30:00	2022-01-12 13:00:00	\N	\N	1	0	\N	\N
622199	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Contrôle parental	Audition Contrôle parental	2022-01-12 14:00:00	2022-01-12 15:00:00	\N	\N	1	0	\N	\N
622204	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Contrôle parental	Auditions Contrôle parental	2022-01-14 17:00:00	2022-01-14 20:00:00	\N	\N	1	0	\N	\N
622206	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Contrôle parental	Auditions Contrôle parental	2022-01-17 14:00:00	2022-01-17 19:30:00	\N	\N	1	0	\N	\N
622220	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition DG Trésor et CNCEF dans le cadre du rapport sur le commerce extérieur	\N	2022-01-18 16:05:00	2022-01-18 18:05:00	\N	\N	6	0	\N	\N
623939	COM_ENQUETE	PLENIERE	\N	HOPITAL	\N	Audition plénière	\N	2022-01-26 18:30:00	2022-01-26 19:40:00	2022-01-27 10:57:11	2022-01-27 12:35:53	8	0	\N	\N
623940	COM_ENQUETE	PLENIERE	\N	HOPITAL	\N	Audition plénière	\N	2022-01-27 10:35:00	2022-01-27 12:55:00	2022-01-27 12:57:02	2022-01-27 15:35:14	9	0	\N	\N
623942	COM_ENQUETE	PLENIERE	\N	HOPITAL	\N	Audition plénière	\N	2022-01-27 11:30:00	2022-01-27 13:00:00	\N	\N	0	0	\N	\N
627655	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Convention accords Qatar et Maurice relatifs au statut des forces	\N	2022-02-01 16:00:00	2022-02-01 17:30:00	\N	\N	1	0	\N	\N
627800	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Choix du nom issu de la filiation	PPL choix du nom issu de la filiation	2022-02-01 16:10:00	2022-02-01 17:00:00	\N	\N	2	0	\N	\N
627804	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Choix du nom issu de la filiation	PPL choix du nom issu de la filiation	2022-02-01 17:00:00	2022-02-01 17:30:00	\N	\N	2	0	\N	\N
628811	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Auditions de BBelin et SBabary / VA et LB	\N	2022-01-25 14:31:00	2022-01-25 18:30:00	\N	\N	0	0	\N	\N
628813	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Aménagement du territoire - Audition de MM. Belin et Babary	MI Aménagement du territoire - Audition de MM. Belin et Babary	2022-01-25 14:30:00	2022-01-25 18:05:00	\N	\N	4	0	\N	\N
628818	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Aménagement du territoire - Audition de MM. Belin et Babary	MI Aménagement du territoire - Audition de MM. Belin et Babary	2022-01-25 18:05:00	2022-01-25 18:50:00	\N	\N	1	0	\N	\N
628820	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Aménagement du territoire - Audition de MM. Belin et Babary	MI Aménagement du territoire - Audition de MM. Belin et Babary	2022-01-26 16:30:00	2022-01-26 20:00:00	\N	\N	2	0	\N	\N
628823	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Audition du CNAJMJ et table ronde sur la MCC centres-villes, centres-bourgs	\N	2022-02-03 08:30:00	2022-02-03 11:15:00	2022-02-03 11:51:08	\N	37	0	\N	\N
628824	DELEGATION	AUCUNE	\N	\N	COLTER	Table-ronde de la MCC centres-villes, centres-bourgs	\N	2022-02-03 09:45:00	2022-02-03 11:15:00	\N	\N	35	0	\N	\N
628836	MISSION	AUDRAP	\N	CULTURE	\N	Audition du Forum français de la jeunesse	\N	2022-02-03 09:00:00	2022-02-03 10:15:00	\N	\N	3	0	\N	\N
628869	DELEGATION	AUCUNE	\N	\N	PROS	Conclusions de l¿audition sur l¿avenir de l¿Indopacifique 	\N	2022-02-03 08:30:00	2022-02-03 09:25:00	\N	\N	12	0	\N	\N
628902	MISSION	AUCUNE	\N	JUDI	\N	Auditions : André Potocki - Didier-Roland Tabuteau - Bernard Stirn	Auditions : André Potocki - Didier-Roland Tabuteau - Bernard Stirn	2022-02-08 14:45:00	2022-02-08 18:45:00	2022-02-08 18:44:42	2022-02-09 10:41:03	10	0	\N	\N
628913	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 8 février 2022	Audition de M. Sefcovic (commission européennes/commission affaires étrangères)	2022-02-08 15:00:00	2022-02-08 16:20:00	2022-02-08 17:45:56	2022-02-09 10:41:21	23	0	\N	\N
628916	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 10 février 2022	\N	2022-02-10 09:05:00	2022-02-10 10:30:00	2022-02-11 17:46:58	2022-02-11 18:18:36	10	0	\N	\N
628960	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Audition Mme Patricia Demas	\N	2022-02-01 15:00:00	2022-02-01 16:00:00	\N	\N	0	0	\N	\N
628991	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Auditions Mme Patricia Demas	\N	2022-02-02 14:00:00	2022-02-02 15:15:00	\N	\N	0	0	\N	\N
629008	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Table ronde associations du patrimoine	\N	2022-02-02 16:30:00	2022-02-02 18:00:00	\N	\N	5	0	\N	\N
629009	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Chateau de Versailles	\N	2022-02-02 18:00:00	2022-02-02 18:40:00	\N	\N	4	0	\N	\N
516805	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière - Conclusions étude stratégie vaccinale	Réunion plénière - Conclusions étude stratégie vaccinale	2020-12-15 13:30:00	2020-12-15 15:30:00	\N	\N	11	0	\N	\N
516808	DELEGATION	AUDRAP	\N	\N	206	Audition Stratégie vaccinale - Table ronde	Audition Stratégie vaccinale - Table ronde	2020-12-09 14:30:00	2020-12-09 16:00:00	\N	\N	5	0	\N	\N
518863	GIA	AUCUNE	\N	\N	\N	Assemblée générale	Assemblée générale	2020-12-15 16:00:00	2020-12-15 17:00:00	\N	\N	7	0	576	\N
520007	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition de Mme Laurence ENGEL - Rapport PPL patrimoine sensoriel	\N	2021-01-13 09:36:00	2021-01-13 11:43:00	2021-01-13 14:25:42	2021-01-13 15:53:04	36	0	\N	\N
520425	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Convention monétaire France CFA - Auteur rapport franc CFA	Convention monétaire France CFA - Auteur rapport franc CFA	2021-01-12 15:00:00	2021-01-12 15:30:00	\N	\N	1	0	\N	\N
520662	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition Code de justice pénale des mineurs	\N	2021-01-12 16:30:00	2021-01-12 17:45:00	\N	\N	3	0	\N	\N
520681	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 2021 - FDVA - Cour des comptes	58-2 2021 - FDVA - Cour des comptes	2021-01-13 10:00:00	2021-01-13 11:00:00	\N	\N	1	0	\N	\N
545115	BUREAU	AUCUNE	\N	\N	\N	Bureau du Sénat	Bureau du Sénat	2021-03-25 09:00:00	2021-03-25 12:00:00	\N	\N	23	0	\N	\N
547142	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Transformation et fonction publiques - DITP	Contrôle 2021 - Transformation et fonction publiques - DITP	2021-03-30 15:30:00	2021-03-30 16:30:00	\N	\N	2	0	\N	\N
547143	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Douane face au trafic de stupéfiants - DNRED	Contrôle 2021 - Douane face au trafic de stupéfiants - DNRED	2021-03-30 16:30:00	2021-03-30 17:30:00	\N	\N	2	0	\N	\N
547148	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de Mme Isabelle BRAUN-LEMAIRE Directrice générale des douanes et droits indirects	Audition de Mme Isabelle BRAUN-LEMAIRE Directrice générale des douanes et droits indirects	2021-04-06 14:30:00	2021-04-06 16:10:00	2021-04-06 17:13:16	2021-04-06 18:00:05	26	0	\N	\N
547149	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de M. Martin VIAL, commissaire aux participations de l'État et Désignation Rapp.	Audition de M. Martin VIAL, commissaire aux participations de l'État et Désignation Rapporteur PJL Climat	2021-04-07 10:35:00	2021-04-07 12:25:00	2021-04-07 13:26:00	2021-04-07 14:55:42	37	0	\N	\N
547417	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Services dédiés à la recherche patrimoniale -  AGCCPF	Contrôle 2021 - Services dédiés à la recherche patrimoniale -  AGCCPF	2021-03-30 17:00:00	2021-03-30 18:30:00	\N	\N	2	0	\N	\N
547500	MISSION	AUCUNE	\N	PAUP	\N	Réunion plénière	\N	2021-04-06 14:30:00	2021-04-06 17:30:00	2021-04-06 17:30:18	2021-04-06 18:00:06	8	0	\N	\N
547526	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Négociation collective - Audition de la CFTC	\N	2021-03-31 13:00:00	2021-03-31 14:00:00	\N	\N	1	0	\N	\N
547530	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Négociation collective - Audition de M. Jean-Christophe Sciberras	\N	2021-03-31 14:00:00	2021-03-31 15:00:00	\N	\N	1	0	\N	\N
548266	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Transport de marchandises - Syndicat national des transports légers	\N	2021-03-30 14:30:00	2021-03-30 15:15:00	\N	\N	5	0	\N	\N
548272	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Transport de marchandises - Entreprises fluviales de France	MI Transport de marchandises - Entreprises fluviales de France	2021-03-30 15:15:00	2021-03-30 16:00:00	\N	\N	6	0	\N	\N
548279	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Transport de marchandises - Groupement national des transports combinés	MI Transport de marchandises - Groupement national des transports combinés	2021-03-30 16:00:00	2021-03-30 16:45:00	\N	\N	5	0	\N	\N
549315	GIA	AUCUNE	\N	\N	\N	Réunion commune avec la chambre des Conseillers	Réunion commune avec le groupe d'amitié Maroc-France de la chambre des Conseillers du Maroc	2021-04-06 15:00:00	2021-04-06 17:00:00	\N	\N	13	0	598	\N
550931	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Observatoire national de la démographie des professions de santé (ONDPS)	\N	2021-04-08 17:00:00	2021-04-08 18:00:00	\N	\N	2	0	\N	\N
551161	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de M. Éric Lombard	\N	2021-04-14 11:05:00	2021-04-14 13:00:00	2021-04-16 10:58:55	2021-04-16 11:46:14	72	0	\N	\N
551196	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Investissements d'avenir - SGPI/ANR	PLF pour 2022 - Investissements d'avenir - SGPI/ANR	2021-04-06 15:30:00	2021-04-06 18:30:00	\N	\N	1	0	\N	\N
551221	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Enseignement spectacle vivant - CNSAD	Contrôle 2021 - Enseignement spectacle vivant - CNSAD	2021-04-06 13:30:00	2021-04-06 14:30:00	\N	\N	2	0	\N	\N
551222	MISSION	AUDRAP	\N	EGALCHAN	\N	MI Égalité des chances - Table ronde Mentorat	\N	2021-04-08 11:00:00	2021-04-08 12:55:00	\N	\N	4	0	\N	\N
551223	MISSION	AUDRAP	\N	EGALCHAN	\N	MI Égalité des chances - Table ronde Réseau E2C/Epide	\N	2021-04-07 17:00:00	2021-04-07 18:50:00	\N	\N	4	0	\N	\N
551227	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Enseignement spectacle vivant - Anciens Élèves Conservatoires	Contrôle 2021 - Enseignement spectacle vivant - Anciens Élèves Conservatoires 	2021-04-06 16:15:00	2021-04-06 17:20:00	\N	\N	2	0	\N	\N
551235	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Enseignement spectacle vivant - CNSMD Paris	Contrôle 2021 - Enseignement spectacle vivant - CNSMD Paris	2021-04-07 14:00:00	2021-04-07 15:00:00	\N	\N	2	0	\N	\N
551243	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - PGE - Cabinet August Debouzy	Contrôle 2021 - PGE - Cabinet August Debouzy	2021-04-06 09:30:00	2021-04-06 10:35:00	\N	\N	1	0	\N	\N
551246	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - PGE - Institut BRUEGEL/FBF	Contrôle 2021 - PGE - Institut BRUEGEL/FBF	2021-04-06 17:30:00	2021-04-06 19:30:00	\N	\N	1	0	\N	\N
551249	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Accords de Bâle - FBF	Accords de Bâle - FBF	2021-04-06 13:30:00	2021-04-06 14:30:00	\N	\N	2	0	\N	\N
551254	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - PGE - Université de Strasbourg	Contrôle 2021 - PGE - Université de Strasbourg	2021-04-07 15:00:00	2021-04-07 15:35:00	\N	\N	1	0	\N	\N
551256	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Table ronde droits voisins et agences de presse	\N	2021-04-14 09:32:00	2021-04-14 11:26:00	2021-04-14 15:22:48	2021-04-14 18:25:16	28	0	\N	\N
551258	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Douane face au trafic de stupéfiants - DR Guyane/Office Antistup	Contrôle 2021 - Douane face au trafic de stupéfiants - DR Guyane/Office Antistup	2021-04-06 16:30:00	2021-04-06 18:30:00	\N	\N	1	0	\N	\N
551260	DELEGATION	AUCUNE	\N	\N	211	Audition du CESE - Crise sanitaire et inégalités de genre	Audition du CESE - Crise sanitaire et inégalités de genre	2021-04-15 09:00:00	2021-04-15 10:15:00	2021-04-15 11:09:46	\N	16	0	\N	\N
551265	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Expropriation biens à l'abandon - PPL Lutte contre l'illectronisme (amendements)	PPL Expropriation biens à l'abandon - PPL Lutte contre l'illectronisme (amendements)	2021-04-14 10:00:00	2021-04-14 10:20:00	2021-04-14 12:47:10	2021-04-14 18:25:16	31	0	\N	\N
551269	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur	\N	2021-04-13 14:00:00	2021-04-13 15:00:00	\N	\N	5	0	\N	\N
551270	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJLC Préservation de l'environnement - auditions d'associations environnementales	PJLC Préservation de l'environnement - auditions d'associations environnementales	2021-04-14 10:30:00	2021-04-14 11:50:00	2021-04-14 12:47:22	2021-04-14 18:25:14	35	0	\N	\N
551271	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF  pour 2022 - Rapport Général - AdCF-intercommunalités de France	PLF  pour 2022 - Rapport Général - AdCF-intercommunalités de France	2021-04-07 14:00:00	2021-04-07 15:10:00	\N	\N	1	0	\N	\N
551275	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - Protection des épargnants - SCI YOMONI	Contrôle 2020 - Protection des épargnants - SCI YOMONI	2021-04-07 16:30:00	2021-04-07 17:30:00	\N	\N	2	0	\N	\N
551278	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur 	\N	2021-04-15 13:30:00	2021-04-15 14:15:00	\N	\N	2	0	\N	\N
551283	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen AMDTS PPL 389 et 385 et Examen Rapport PJL 404	Examen AMDTS PPL 389 et 385 et Examen Rapport PJL 404	2021-04-13 14:35:00	2021-04-13 15:50:00	2021-04-13 16:37:50	2021-04-14 18:25:18	25	0	\N	\N
551284	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de M. Éric LOMBARD, directeur général de la Caisse des dépôts et consignations	Audition de M. Éric LOMBARD, directeur général de la Caisse des dépôts et consignations	2021-04-14 11:05:00	2021-04-14 13:00:00	2021-04-14 20:13:35	2021-04-15 11:58:07	71	0	\N	\N
551285	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de M. Olivier DUSSOPT, ministre délégué, chargé des comptes publics	Audition de M. Olivier DUSSOPT, ministre délégué, chargé des comptes publics	2021-04-14 18:50:00	2021-04-14 20:00:00	2021-04-15 10:56:42	2021-04-15 11:58:08	42	0	\N	\N
589860	ETUDES	AUCUNE	\N	\N	\N	Auditions de présidents de chambres régionales de l'ESS	Auditions de présidents de chambres régionales de l'ESS	2021-10-06 13:30:00	2021-10-06 14:30:00	\N	\N	5	0	\N	998
590431	MISSION	AUCUNE	\N	INFLUENCES	\N	\N	\N	2021-10-05 15:00:00	2021-10-05 16:45:00	2021-10-07 09:35:21	\N	3	0	\N	\N
605425	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 24 novembre	\N	2021-11-24 13:35:00	2021-11-24 14:55:00	2021-11-24 14:55:35	2021-11-24 16:37:33	16	0	\N	\N
605794	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Confiance dans l'institution judiciaire (CMP) - examen des amendements	PJL Confiance dans l'institution judiciaire (CMP) - examen des amendements	2021-11-18 12:05:00	2021-11-18 12:25:00	2021-11-18 12:54:07	2021-11-19 19:32:14	20	1	\N	\N
605820	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PJLF 2022 - Plan de relance - Mme Anne Chain-Larché	Auditions PJLF 2022 - Plan de relance - Mme Anne Chain-Larché	2021-11-08 08:20:00	2021-11-08 09:40:00	\N	\N	1	0	\N	\N
605821	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PJLF 2022 - Plan de relance - Mme Anne Chain-Larché	\N	2021-11-08 15:40:00	2021-11-08 19:00:00	\N	\N	1	0	\N	\N
605822	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions de Mme Chain-Larché	\N	2021-11-09 08:30:00	2021-11-09 10:30:00	\N	\N	0	0	\N	\N
605823	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions de Mme Chain-Larché	\N	2021-11-10 16:30:00	2021-11-10 19:50:00	\N	\N	0	0	\N	\N
605824	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions de Mme Chain-Larché par visioconférence	\N	2021-11-12 09:40:00	2021-11-12 11:40:00	\N	\N	0	0	\N	\N
607863	GIA	AUCUNE	\N	\N	\N	Coopé - Visite de M. Daniel LAUZON, ancien directeur de cabinet 	Coopé - Visite de M. Daniel LAUZON, ancien directeur de cabinet 	2021-11-24 14:00:00	2021-11-24 15:00:00	\N	\N	1	0	583	\N
607865	GIA	AUCUNE	\N	\N	\N	Coopé - Entretien avec une délégation libyenne	Coopé - Entretien avec une délégation libyenne	2021-11-24 13:00:00	2021-11-24 14:30:00	\N	\N	1	0	657	\N
607873	GIA	AUCUNE	\N	\N	\N	Coopé - Entretien avec M. Vladimir MEDAK, ancien haut fonctionnaire	Coopé - Entretien avec M. Vladimir MEDAK, ancien haut fonctionnaire	2021-11-24 17:30:00	2021-11-24 18:30:00	\N	\N	2	0	674	\N
607877	GIA	AUCUNE	\N	\N	\N	déjeuner à la résidence de l'ambassadeur du Koweït	\N	2021-11-24 12:30:00	2021-11-25 15:00:00	\N	\N	9	0	661	\N
610964	GIA	AUCUNE	\N	\N	\N	Entretien avec la secrétaire générale du Conseil de coopération régionale 	Entretien avec la Secrétaire générale du Conseil de coopération régionale 	2021-12-07 10:00:00	2021-12-07 11:00:00	\N	\N	4	0	674	\N
613802	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Port du casque à vélo et dans le cadre d'autres moyens de transport	PPL Port du casque à vélo et dans le cadre d'autres moyens de transport	2021-12-14 08:30:00	2021-12-14 10:15:00	\N	\N	1	0	\N	\N
613823	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Combattre le harcèlement scolaire	Audition rapporteur - Avis PPL Combattre le harcèlement scolaire	2021-12-14 09:30:00	2021-12-14 10:30:00	\N	\N	2	0	\N	\N
613840	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Combattre le harcèlement scolaire	Audition rapporteur - Avis PPL Combattre le harcèlement scolaire	2021-12-14 13:30:00	2021-12-14 14:45:00	\N	\N	2	0	\N	\N
624172	MISSION	AUCUNE	\N	FONDSMER	\N	Table ronde "Scientifiques"	\N	2022-01-25 17:00:00	2022-01-25 18:55:00	2022-01-25 18:56:07	2022-01-26 14:26:37	10	0	\N	\N
624174	COM_ENQUETE	AUDRAP	\N	CABINETS	\N	Auditions rapporteur - Laure BEDIER, DAJ MIN ECOFIN-Thomas DAUTIEU, Dir. conformité CNIL	Auditions rapporteur - Laure BEDIER, DAJ MIN ECOFIN-Thomas DAUTIEU, Dir. conformité CNIL	2022-01-27 10:30:00	2022-01-27 12:10:00	\N	\N	6	0	\N	\N
624183	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PPL Contrôle parental	Audition PPL Contrôle parental	2022-01-19 10:30:00	2022-01-19 11:00:00	\N	\N	1	0	\N	\N
624184	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PPL Contrôle parental	Audition PPL Contrôle parental	2022-01-20 15:00:00	2022-01-20 18:00:00	\N	\N	1	0	\N	\N
624187	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteurs - Duty free - Eurotunnel/Getlink	Audition rapporteurs - Duty free - Eurotunnel/Getlink	2022-01-31 14:30:00	2022-01-31 15:30:00	\N	\N	2	0	\N	\N
624188	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Rapporteure - Autistes	\N	2022-01-21 10:00:00	2022-01-21 11:00:00	\N	\N	1	0	\N	\N
624194	MISSION	AUCUNE	\N	CULTURE	\N	Réunion 20220127	\N	2022-01-27 11:30:00	2022-01-27 12:55:00	2022-01-27 12:56:21	2022-01-27 15:35:15	6	0	\N	\N
624195	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Financement lutte algues vertes Bretagne - SGAR Bretagne	Contrôle 2021 - Financement lutte algues vertes Bretagne - SGAR Bretagne	2022-01-18 17:30:00	2022-01-18 18:30:00	\N	\N	1	0	\N	\N
624197	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Situation et perspectives SNCF - Régions de France/SNCF Réseau	Contrôle 2021 - Situation et perspectives SNCF - Régions de France/SNCF Réseau	2022-01-19 16:30:00	2022-01-19 18:30:00	\N	\N	2	0	\N	\N
624200	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Protection des épargnants - Plateforme NALO	Contrôle 2021 - Protection des épargnants - Plateforme NALO	2022-01-18 19:00:00	2022-01-18 20:10:00	\N	\N	2	0	\N	\N
624203	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Protection des épargnants - CdC	Contrôle 2021 - Protection des épargnants - CdC	2022-01-18 15:00:00	2022-01-18 16:00:00	\N	\N	2	0	\N	\N
624206	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL 350 Risques climatiques en agriculture - FNSEA/Conf. Paysanne/Can MIN Agric.	PJL 350 Risques climatiques en agriculture - FNSEA/Conf. Paysanne/Can MIN Agric.	2022-01-18 16:40:00	2022-01-18 18:45:00	\N	\N	2	0	\N	\N
624209	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL 350 Risques climatiques en agriculture - FFA/DG Trésor/CCR	PJL 350 Risques climatiques en agriculture - FFA/DG Trésor/CCR	2022-01-19 09:00:00	2022-01-19 11:45:00	\N	\N	2	0	\N	\N
624212	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL 350 Risques climatiques en agriculture - Autorité de la concurrence	PJL 350 Risques climatiques en agriculture - Autorité de la concurrence	2022-01-19 14:10:00	2022-01-19 15:00:00	\N	\N	2	0	\N	\N
624215	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Les contributions internationales - Cabinet MEAE	Contrôle 2021 - Les contributions internationales - Cabinet MEAE	2022-01-19 11:30:00	2022-01-19 12:30:00	\N	\N	2	0	\N	\N
624240	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Lutte contre l'obésité - Audition du Pr Daniel Nizri	\N	2022-01-18 17:15:00	2022-01-18 18:15:00	\N	\N	3	0	\N	\N
624241	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Lutte contre l'obésité - Table ronde Recherche	\N	2022-01-18 15:30:00	2022-01-18 17:00:00	\N	\N	3	0	\N	\N
624242	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Lutte contre l'obésité - Table ronde d'agences sanitaires	\N	2022-01-18 14:00:00	2022-01-18 15:30:00	\N	\N	3	0	\N	\N
624243	COM_ENQUETE	AUDRAP	\N	HOPITAL	\N	Audition de la SRLF	\N	2022-01-20 15:45:00	2022-01-20 16:45:00	\N	\N	7	0	\N	\N
624244	COM_ENQUETE	AUDRAP	\N	HOPITAL	\N	Audition de l'AFASH	\N	2022-01-20 16:45:00	2022-01-20 17:45:00	\N	\N	8	0	\N	\N
624272	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Auditions rapporteurs - AFB et ARF	\N	2022-01-25 16:00:00	2022-01-25 18:00:00	\N	\N	0	0	\N	\N
624273	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Table ronde sur le thème de la transmission d¿entreprise	\N	2022-01-27 09:00:00	2022-01-27 12:15:00	2022-01-27 14:34:06	\N	15	0	\N	\N
624274	COM_EURO	AUDRAP	\N	AFEU	\N	Relation UE/Turquie	Relation UE/Turquie - Audition de M. Patrick Chaumette -  Professeur émérite	2022-01-24 11:00:00	2022-01-24 12:00:00	\N	\N	3	0	\N	\N
624282	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2022-02-02 09:00:00	2022-02-02 10:49:00	2022-02-02 11:55:32	2022-02-02 15:43:38	29	0	\N	\N
624283	COM_ENQUETE	PLENIERE	\N	MEDIA	\N	rn médias	\N	2022-01-24 15:30:00	2022-01-24 18:20:00	2022-01-24 19:39:42	2022-01-25 18:21:17	11	0	\N	\N
625364	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe d'amitié France-Pays Andins	Assemblée générale du groupe d'amitié France-Pays Andins	2022-01-26 11:00:00	2022-01-26 12:00:00	\N	\N	9	0	979	\N
625696	COM_EURO	AUDRAP	\N	AFEU	\N	Paquet Climat - Secteur énergie 	Paquet Climat - Secteur énergie - TR Electricité	2022-01-25 15:00:00	2022-01-25 16:20:00	\N	\N	4	0	\N	\N
626695	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	PJL Fonction publique des communes de Polynésie française	2022-01-26 14:00:00	2022-01-26 15:00:00	\N	\N	2	0	\N	\N
626743	ETUDES	AUCUNE	\N	\N	\N	TR Réparation et réemploi des équipements électriques et électroniques	TR Réparation et réemploi des équipements électriques et électroniques	2022-01-26 16:30:00	2022-01-26 18:00:00	\N	\N	5	0	\N	922
626784	QUESTURE	AUCUNE	\N	\N	\N	Réunion de Questure du 27 janvier 2022	Réunion de Questure du 27 janvier 2022	2022-01-27 09:00:00	2022-01-27 11:30:00	\N	\N	3	0	\N	\N
626795	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-02-01 15:05:00	2022-02-01 18:00:00	2022-02-01 18:28:05	2022-02-02 15:43:41	35	0	\N	\N
567767	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Prévention d'actes de terrorisme et renseignement	\N	2021-06-09 14:00:00	2021-06-09 15:10:00	\N	\N	2	0	\N	\N
568136	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2021-06-15 17:00:00	2021-06-15 18:05:00	2021-06-16 14:20:13	2021-06-16 18:10:51	24	0	\N	\N
568137	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2021-06-16 09:34:00	2021-06-16 12:05:00	2021-06-16 14:41:40	2021-06-16 18:11:05	33	1	\N	\N
568140	DELEGATION	AUCUNE	\N	\N	COLTER	Audition de l'ANCT	\N	2021-06-10 09:30:00	2021-06-10 11:20:00	\N	\N	18	0	\N	\N
570355	GIA	AUCUNE	\N	\N	\N	Entretien du GIA avec l'Ambassadeur de France en Tunisie	Entretien du GIA avec l'Ambassadeur de France en Tunisie	2021-06-10 11:00:00	2021-06-10 12:15:00	\N	\N	3	0	620	\N
570779	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2021-06-17 09:00:00	2021-06-17 11:00:00	\N	\N	5	0	\N	\N
570793	MISSION	AUCUNE	\N	HARCEL	\N	MI Harcèlement	MI Harcèlement scolaire et cyber-harcèlement	2021-06-17 10:35:00	2021-06-17 12:10:00	2021-06-17 13:11:08	2021-06-18 18:53:36	5	0	\N	\N
571149	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2021 - Météo France - Déplacement à Toulouse	Contrôle 2021 - Météo France - Déplacement à Toulouse	2021-06-14 08:00:00	2021-06-14 20:20:00	\N	\N	1	0	\N	\N
571159	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Situation et perspectives SNCF - ART/DRH SNCF	Contrôle 2021 - Situation et perspectives SNCF - ART/DRH SNCF	2021-06-15 08:30:00	2021-06-15 10:45:00	\N	\N	2	0	\N	\N
571162	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - FPIC - Ensembles intercommunaux 	Contrôle 2021 - FPIC - Ensembles intercommunaux 	2021-06-17 09:00:00	2021-06-17 10:00:00	\N	\N	2	0	\N	\N
571166	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJLR pour 2020 - SG MIN Intérieur	PJLR pour 2020 - SG MIN Intérieur	2021-06-15 14:00:00	2021-06-15 15:15:00	\N	\N	1	0	\N	\N
571168	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJLR pour 2020 -  C.N.C.C.F.P.	PJLR pour 2020 -  C.N.C.C.F.P.	2021-06-17 09:00:00	2021-06-17 10:15:00	\N	\N	1	0	\N	\N
571171	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2021 - Immobilier universitaire - Déplacement à Poitiers	Contrôle 2021 - Immobilier universitaire - Déplacement à Poitiers	2021-06-18 08:20:00	2021-06-18 16:40:00	\N	\N	1	0	\N	\N
571228	MISSION	AUCUNE	\N	HARCEL	\N	Réunion du 23/06/2021	Réunion du 23/06/2021	2021-06-23 16:40:00	2021-06-23 18:45:00	2021-06-24 11:47:04	2021-06-24 18:16:51	9	0	\N	\N
571231	MISSION	AUTRE	\N	HARCEL	\N	Audition plénière	\N	2021-06-24 11:15:00	2021-06-24 12:30:00	\N	\N	0	0	\N	\N
571335	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2021-06-16 14:05:00	2021-06-16 14:50:00	\N	\N	22	0	\N	\N
571359	GIA	AUCUNE	\N	\N	\N	rencontre Bureau Tibet et Communauté tibétaine de France	rencontre Bureau Tibet et Communauté tibétaine de France	2021-06-30 08:00:00	2021-06-30 09:30:00	\N	\N	5	0	634	\N
571741	ETUDES	AUDRAP	\N	\N	\N	Groupe d'études Pratiques sportives et grands événements sportifs - Audition Vendée Globe	Réunion plénière	2021-06-22 15:05:00	2021-06-22 16:35:00	\N	\N	11	0	\N	934
571767	COM_SPECIALE	PLENIERE	\N	BIOETHIQUE	\N	\N	\N	2021-06-23 08:30:00	2021-06-23 08:35:00	2021-06-23 08:45:01	2021-06-24 18:16:49	14	0	\N	\N
572014	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Confiance dans l'institution judiciaire	\N	2021-06-22 14:30:00	2021-06-22 15:30:00	\N	\N	3	0	\N	\N
572018	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Confiance dans l'institution judiciaire	\N	2021-06-22 15:30:00	2021-06-22 17:00:00	\N	\N	5	0	\N	\N
572024	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Confiance dans l'institution judiciaire	\N	2021-06-22 17:00:00	2021-06-22 18:00:00	\N	\N	3	0	\N	\N
572028	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLO Confiance dans l'institution judiciaire	\N	2021-06-22 18:00:00	2021-06-22 19:00:00	\N	\N	5	0	\N	\N
572493	GIA	AUCUNE	\N	\N	\N	Rencontre Larcher al-Halbousi	Rencontre entre le Président du Sénat et le Président du parlement irakien, Muhammad al-Halbousi	2021-06-23 11:00:00	2021-06-23 12:00:00	\N	\N	1	0	615	\N
572496	GIA	AUCUNE	\N	\N	\N	Rencontre AFD	Visioconférence avec M. Philippe Michaud et M. Eric Bordes, de l'AFD	2021-06-24 09:30:00	2021-06-24 10:30:00	\N	\N	1	0	615	\N
579388	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2021-07-20 09:30:00	2021-07-20 12:35:00	\N	\N	44	0	\N	\N
579389	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PJL Climat	CMP PJL Climat	2021-07-20 15:00:00	2021-07-20 16:15:00	\N	\N	109	0	\N	\N
579390	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PJL Inégalités mondiales	CMP PJL Inégalités mondiales	2021-07-20 16:20:00	2021-07-21 17:30:00	\N	\N	82	0	\N	\N
579391	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PPL Prévention santé au travail	CMP PPL Prévention santé au travail	2021-07-20 17:30:00	2021-07-20 18:30:00	\N	\N	71	0	\N	\N
579392	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	NL PJL Principes de la République	NL PJL Principes de la République	2021-07-20 18:30:00	2021-07-20 19:40:00	\N	\N	75	0	\N	\N
579400	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL 3D S	PJL 3D S	2021-07-20 21:15:00	2021-07-21 00:30:00	\N	\N	99	0	\N	\N
579404	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2021-07-21 15:00:00	2021-07-21 16:20:00	\N	\N	212	0	\N	\N
579408	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	EV PJL 3D S	EV PJL 3D S	2021-07-21 16:35:00	2021-07-21 17:40:00	\N	\N	130	0	\N	\N
579412	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	NL PJL Règlement du budget	NL PJL Règlement du budget	2021-07-21 17:45:00	2021-07-21 18:40:00	\N	\N	64	0	\N	\N
579423	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	NL PJL Terrorisme	NL PJL Terrorisme	2021-07-21 21:00:00	2021-07-21 23:00:00	\N	\N	46	0	\N	\N
579437	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL 3D S	PJL 3D S	2021-07-19 21:00:00	2021-07-20 00:30:00	\N	\N	88	0	\N	\N
580594	GIA	AUCUNE	\N	\N	\N	Audition de l'ambassadeur de France en Afrique du Sud	Audition d'Aurélien Lechevallier, ambassadeur de France en Afrique du Sud	2021-07-07 13:35:00	2021-07-07 15:00:00	\N	\N	4	0	574	\N
581665	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Gestion de la crise sanitaire - Mme Marie-Laure Denis, présidente de la CNIL	PJL Gestion de la crise sanitaire - Mme Marie-Laure Denis, présidente de la CNIL	2021-07-21 17:30:00	2021-07-21 18:55:00	\N	\N	7	0	\N	\N
582605	MISSION	AUDRAP	\N	HARCEL	\N	Audition rapporteure - Respect Zone	\N	2021-06-22 16:45:00	2021-06-22 17:45:00	\N	\N	0	0	\N	\N
582606	MISSION	AUTRE	\N	HARCEL	\N	Audition de MM. Kerrero et Geffray 	\N	2021-06-02 16:30:00	2021-06-02 18:00:00	\N	\N	0	0	\N	\N
582625	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteur	Audition rapporteur - rapport annuel CSTB	2021-07-27 15:00:00	2021-07-27 16:00:00	\N	\N	1	0	\N	\N
582626	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteur	Audition rapporteur - rapport annuel CSTB	2021-07-27 16:00:00	2021-07-27 17:00:00	\N	\N	1	0	\N	\N
582696	MISSION	AUCUNE	\N	UBER	\N	\N	\N	2021-09-07 10:00:00	2021-09-07 11:30:00	2021-09-07 11:47:47	2021-09-09 13:45:14	6	0	\N	\N
582697	MISSION	PLEIN_NON_JO	\N	UBER	\N	Audition de représentants de syndicats	\N	2021-09-09 14:00:00	2021-09-09 16:00:00	\N	\N	0	0	\N	\N
582698	MISSION	AUDRAP	\N	INFLUENCES	\N	Audition M. Gallou, université Brest	\N	2021-09-02 10:04:00	2021-09-02 10:51:00	\N	\N	4	0	\N	\N
582699	MISSION	AUDRAP	\N	INFLUENCES	\N	Audition Mme Mouroudian (CNRS	\N	2021-09-02 11:10:00	2021-09-02 12:15:00	\N	\N	3	0	\N	\N
506628	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2021 - Examen Amdts séance sur les Missions 	PLF pour 2021 - Examen Amdts séance sur les Missions 	2020-11-26 11:05:00	2020-11-26 11:50:00	2020-11-26 12:47:22	2020-11-26 16:54:26	31	0	\N	\N
506631	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2021 - Examen Amdts séance sur les Missions 	PLF pour 2021 - Examen Amdts séance sur les Missions 	2020-11-27 09:05:00	2020-11-27 09:30:00	2020-11-27 14:17:33	2020-11-27 17:30:26	20	0	\N	\N
506662	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Rapport général - Mairie de Paris	PLF pour 2021 - Rapport général - Mairie de Paris	2020-11-20 11:15:00	2020-11-20 12:00:00	\N	\N	1	0	\N	\N
506851	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJLF 2021 - Avis Cohésion des territoires - DGCL	PJLF 2021 - Avis Cohésion des territoires - Direction générales des collectivités locales	2020-11-17 14:30:00	2020-11-17 15:15:00	\N	\N	1	0	\N	\N
506852	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJLF 2021 - Avis Cohésion des territoires - DMAT	PJLF 2021 - Avis Cohésion des territoires - Direction de la modernisation et de l'action territoriale	2020-11-18 16:30:00	2020-11-18 17:30:00	\N	\N	1	0	\N	\N
506853	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJLF 2021 - Avis Aménagement numérique du territoire - ARCEP	PJLF 2021 - Avis Aménagement numérique du territoire - ARCEP	2020-11-16 10:45:00	2020-11-16 11:30:00	\N	\N	1	0	\N	\N
506863	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2021 - Mission Économie-Numérique - AOTA	PJLF 2021 - Mission Économie-Numérique - Association des opérateurs télécoms alternatifs (AOTA)	2020-11-17 10:00:00	2020-11-17 10:45:00	\N	\N	1	0	\N	\N
506864	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2021 - Mission Économie-Numérique - DGE + ANCT	PJLF 2021 - Mission Économie-Numérique - DGE + ANCT	2020-11-19 17:00:00	2020-11-19 18:00:00	\N	\N	2	0	\N	\N
506865	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2021 - Mission Économie-Numérique	PJLF 2021 - Mission Économie-Numérique	2020-11-20 09:00:00	2020-11-20 11:15:00	\N	\N	1	0	\N	\N
513468	COM_PERMANENTE	AUTRE	\N	FINC	\N	58-2 : Système éducatif dans les académies ultramarines	58-2 : Système éducatif dans les académies ultramarines	2020-12-10 15:00:00	2020-12-10 16:30:00	2020-12-10 16:46:00	2020-12-10 17:37:19	20	0	\N	\N
513500	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - RCT - Cab MIN Cohésion des territoires	PLF pour 2021 - RCT - Cab MIN Cohésion des territoires	2020-12-03 11:30:00	2020-12-03 12:15:00	\N	\N	1	0	\N	\N
516058	DELEGATION	AUCUNE	\N	\N	COLTER	Audition de Jacqueline Gourault, ministre	\N	2020-12-17 10:00:00	2020-12-17 11:40:00	2020-12-17 13:59:09	\N	25	0	\N	\N
519294	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Auditions GT Nouvelles formes de commerce	Auditions GT Nouvelles formes de commerce	2021-01-11 09:30:00	2021-01-11 10:20:00	\N	\N	4	0	\N	\N
519300	GIA	AUCUNE	\N	\N	\N	Rencontre avec M. Pascal Le Deunff, ambassadeur de France en Moldavie	\N	2021-01-11 11:30:00	2021-01-11 12:25:00	\N	\N	1	0	851	\N
519302	GIA	AUCUNE	\N	\N	\N	Réunion ambassadeur	Rencontre du président avec le nouvel ambassadeur de Chypre en France	2021-01-11 09:45:00	2021-01-11 10:30:00	\N	\N	1	0	585	\N
519786	COM_SPECIALE	AUTRE	\N	BIOETHIQUE	\N	PJL Bioéthique - Examen, en deuxième lecture, du rapport et établissement du texte	\N	2021-01-19 13:35:00	2021-01-19 15:25:00	2021-01-19 15:29:47	2021-01-19 17:51:45	29	0	\N	\N
524209	GIA	AUCUNE	\N	\N	\N	Accueil de diplomates et personnels de l'Ambassade des Pays-Bas	Accueil de diplomates et personnels de l'Ambassade des Pays-Bas	2020-01-24 15:00:00	2020-01-24 16:30:00	\N	\N	1	0	599	\N
524211	GIA	AUCUNE	\N	\N	\N	Gala de financement de l'école française d'Extrême-Orient	Gala de financement de l'école française d'Extrême-Orient	2020-03-07 19:30:00	2020-03-07 23:30:00	\N	\N	1	0	577	\N
526403	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	PPL Sécurité globale - Déplacement à l'Institut français de la sécurité	PPL Sécurité globale - Déplacement à l'Institut français de la sécurité	2021-01-28 14:00:00	2021-01-28 16:30:00	\N	\N	1	0	\N	\N
527002	GIA	AUCUNE	\N	\N	\N	Assemblée générale constitutie du gropupe d'amitié France Caraïbes	Assemblée générale constitutie du gropupe d'amitié France Caraïbes	2021-01-26 15:00:00	2021-01-26 16:00:00	\N	\N	7	0	642	\N
531326	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Etat de droit dans l'Union européenne	Audition Etat de droit dans l'Union européenne - CJUE	2021-02-11 16:30:00	2021-02-11 17:30:00	\N	\N	2	0	\N	\N
531659	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Système de santé	PPL Système de santé	2021-02-18 10:30:00	2021-02-18 12:35:00	\N	\N	60	0	\N	\N
534125	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Principes de la République	\N	2021-02-18 09:00:00	2021-02-18 10:00:00	\N	\N	3	0	\N	\N
534129	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Principes de la République	\N	2021-02-18 10:00:00	2021-02-18 11:00:00	\N	\N	3	0	\N	\N
534133	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Principes de la République	\N	2021-02-18 11:00:00	2021-02-18 12:00:00	\N	\N	3	0	\N	\N
534137	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Principes de la République	\N	2021-02-18 12:00:00	2021-02-18 13:00:00	\N	\N	3	0	\N	\N
534141	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Principes de la République	\N	2021-02-18 14:00:00	2021-02-18 15:00:00	\N	\N	3	0	\N	\N
534145	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Principes de la République	\N	2021-02-18 15:00:00	2021-02-18 16:30:00	\N	\N	5	0	\N	\N
534151	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Princi	\N	2021-02-18 16:30:00	2021-02-18 17:30:00	\N	\N	3	0	\N	\N
534156	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Principes de la République	\N	2021-02-18 17:30:00	2021-02-18 18:30:00	\N	\N	4	0	\N	\N
534161	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Principes de la République	\N	2021-02-18 18:30:00	2021-02-18 19:30:00	\N	\N	3	0	\N	\N
536311	ETUDES	AUTRE	\N	\N	\N	Audition Afidol	\N	2021-03-03 12:45:00	2021-03-03 14:00:00	\N	\N	0	0	\N	1005
536313	ETUDES	AUTRE	\N	\N	\N	Audition Afidol	\N	2021-03-03 12:45:00	2021-03-03 14:00:00	\N	\N	0	0	\N	1005
537503	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Déplacement justice Lyon	Déplacement justice Lyon	2021-03-05 07:00:00	2021-03-05 20:00:00	\N	\N	6	0	\N	\N
585846	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Protection des enfants - Audition de l'API	\N	2021-09-23 14:00:00	2021-09-23 14:45:00	\N	\N	2	0	\N	\N
539556	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Groupe de travail sur l'avenir de La Poste	Groupe de travail sur l'avenir de La Poste	2021-03-09 16:00:00	2021-03-09 17:00:00	\N	\N	2	0	\N	\N
539559	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Groupe de travail sur l'avenir de La Poste	Groupe de travail sur l'avenir de La Poste	2021-03-09 17:00:00	2021-03-09 18:00:00	\N	\N	1	0	\N	\N
539561	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Groupe de travail sur l'avenir de La Poste	Groupe de travail sur l'avenir de La Poste	2021-03-09 18:00:00	2021-03-09 19:00:00	\N	\N	2	0	\N	\N
539564	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Groupe de travail sur l'avenir de La Poste	Groupe de travail sur l'avenir de La Poste	2021-03-09 19:00:00	2021-03-09 20:00:00	\N	\N	2	0	\N	\N
539573	GIA	AUCUNE	\N	\N	\N	Réunion avec M. Elio RODRIGUEZ PERDOMO, ambassadeur de Cuba en France	Réunion avec M. Elio RODRIGUEZ PERDOMO, ambassadeur de Cuba en France	2021-03-10 14:00:00	2021-03-10 14:50:00	\N	\N	7	0	642	\N
539581	GIA	AUCUNE	\N	\N	\N	Réunion avc M.Doré, directeur Amérique latine Caraîbes au MEAE	Réunion avc M.Doré, directeur Amérique latine Caraîbes au MEAE	2021-02-11 14:00:00	2021-02-11 15:00:00	\N	\N	1	0	642	\N
543009	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteur Outils de webconférence - M. Jean-Pierre Berthet	Audition rapporteur Outils de webconférence - M. Jean-Pierre Berthet, Sciences Po	2021-04-09 16:00:00	2021-04-09 17:00:00	\N	\N	1	0	\N	\N
543011	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteur Outils de webconférence - Tixeo	Audition rapporteur Outils de webconférence - Tixeo	2021-04-09 10:00:00	2021-04-09 11:00:00	\N	\N	1	0	\N	\N
549183	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-04-13 14:04:00	2021-04-13 14:18:00	2021-04-13 14:48:23	2021-04-14 18:25:19	20	1	\N	\N
549184	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-04-14 10:02:00	2021-04-14 12:11:00	2021-04-14 18:25:15	2021-04-15 11:58:07	33	2	\N	\N
549253	COM_PERMANENTE	AUTRE	\N	AFCL	\N	audition médias	\N	2021-04-07 09:11:00	2021-04-07 12:07:00	2021-04-07 12:38:42	2021-04-07 14:55:45	32	0	\N	\N
552602	MISSION	AUCUNE	\N	VIETUDIA	\N	Table ronde numérique	Table ronde numérique	2021-04-15 16:05:00	2021-04-15 18:02:00	2021-04-19 13:23:28	\N	11	0	\N	\N
568256	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Soins palliatifs - Table ronde Questions éthiques	\N	2021-06-10 09:30:00	2021-06-10 10:45:00	\N	\N	3	0	\N	\N
568260	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Soins palliatifs - Audition de J. Leonetti	\N	2021-06-10 11:15:00	2021-06-10 12:20:00	\N	\N	3	0	\N	\N
568683	DELEGATION	AUCUNE	\N	\N	DSOM	Réunion de la délégation	\N	2021-07-08 15:00:00	2021-07-08 16:00:00	\N	\N	15	0	\N	\N
568748	MISSION	AUDRAP	\N	ENSAGRIC	\N	Audition DGESCO	\N	2021-06-15 15:08:00	2021-06-15 16:24:00	\N	\N	5	0	\N	\N
570370	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	211	Audition d¿un collectif d¿organisations sur la ratification de la Convention 190 -OIT	Audition d¿un collectif d¿organisations sur la ratification de la Convention 190 -OIT	2021-06-16 17:00:00	2021-06-16 18:00:00	\N	\N	4	0	\N	\N
570710	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Pascal Le Deunff, Ambassadeur de France en Moldavie	Entretien avec M. Pascal Le Deunff, Ambassadeur de France en République de Moldavie	2021-06-17 09:00:00	2021-06-17 10:00:00	\N	\N	3	0	851	\N
571280	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Différenciation, décentralisation, déconcentration et simplification	PJL Différenciation, décentralisation, déconcentration et simplification	2021-06-10 17:00:00	2021-06-10 18:00:00	\N	\N	2	0	\N	\N
571285	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Différenciation, décentralisation, déconcentration et simplification	PJL Différenciation, décentralisation, déconcentration et simplification	2021-06-15 09:30:00	2021-06-15 10:15:00	\N	\N	1	0	\N	\N
571287	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Différenciation, décentralisation, déconcentration et simplification	PJL Différenciation, décentralisation, déconcentration et simplification	2021-06-16 18:00:00	2021-06-16 19:00:00	\N	\N	1	0	\N	\N
571291	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Différenciation, décentralisation, déconcentration et simplification	PJL Différenciation, décentralisation, déconcentration et simplification	2021-06-17 14:30:00	2021-06-17 19:30:00	\N	\N	2	0	\N	\N
573190	MISSION	AUCUNE	\N	HARCEL	\N	MI Harcèlement	Mission d'information harcèlement scolaire	2021-06-24 10:30:00	2021-06-24 12:55:00	2021-06-24 18:20:41	2021-06-25 18:45:49	10	0	\N	\N
573462	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière	\N	2021-07-01 09:30:00	2021-07-01 12:30:00	\N	\N	11	0	\N	\N
573522	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-06-28 19:15:00	2021-06-28 19:22:00	2021-06-28 19:40:03	2021-06-29 17:17:18	15	1	\N	\N
574076	DELEGATION	AUDRAP	\N	\N	211	Audition de Mme Sabine Brun-Rageul	Audition de Mme Sabine Brun-Rageul	2021-06-29 17:00:00	2021-06-29 17:45:00	\N	\N	9	0	\N	\N
574105	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Terrorisme et renseignement	PJL Terrorisme et renseignement	2021-06-29 21:35:00	2021-06-30 01:20:00	\N	\N	51	0	\N	\N
574227	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL KOSOVO	PJL KOSOVO	2021-06-29 17:00:00	2021-06-29 17:45:00	\N	\N	1	0	\N	\N
574965	MISSION	AUCUNE	\N	ENSAGRIC	\N	Audition plénière ministérielle	Audition de M. Julien Denormandie, ministre de l'agriculture	2021-06-30 16:35:00	2021-06-30 18:15:00	2021-07-02 10:22:12	2021-07-02 16:05:40	9	0	\N	\N
574984	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Présentation rapports d'information	\N	2021-07-07 09:35:00	2021-07-07 11:30:00	2021-07-07 11:44:15	2021-07-07 17:53:06	27	1	\N	\N
574986	DELEGATION	AUDRAP	\N	\N	PROS	Audition de M. Laurent Cordonnier	\N	2021-06-29 15:00:00	2021-06-29 16:00:00	\N	\N	2	0	\N	\N
574987	DELEGATION	AUDRAP	\N	\N	PROS	Audition de M Eric Chaney	\N	2021-06-29 16:00:00	2021-06-29 17:00:00	\N	\N	2	0	\N	\N
575067	COM_PERMANENTE	AUTRE	\N	CDD	\N	\N	\N	2021-07-07 10:30:00	2021-07-07 10:43:00	2021-07-12 14:53:16	2021-07-12 16:37:08	28	1	\N	\N
575103	COM_PERMANENTE	AUTRE	\N	LOIS	\N	MI Dysfonctionnements élections juin 2021 - Audition Adrexo et Hopps Group	MI Dysfonctionnements élections juin 2021 - Audition Adrexo et Hopps Group	2021-07-05 14:35:00	2021-07-05 16:00:00	2021-07-05 17:39:46	2021-07-06 18:19:44	16	0	\N	\N
575104	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJLC Préservation de l'environnement (2e lecture) - amendements	PJLC Préservation de l'environnement (2e lecture) - amendements	2021-07-05 17:30:00	2021-07-05 17:35:00	2021-07-05 17:50:26	2021-07-06 18:19:43	13	0	\N	\N
575105	COM_PERMANENTE	AUTRE	\N	LOIS	\N	MI Dysfonctionnements élections juin 2021 - Auditions Arcep, Comité de suivi et Gojob	MI Dysfonctionnements élections juin 2021 - Auditions Arcep, Comité de suivi et Gojob	2021-07-06 13:35:00	2021-07-06 17:25:00	2021-07-06 18:00:55	2021-07-06 18:19:42	14	0	\N	\N
509406	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2020-11-26 08:30:00	2020-11-26 09:00:00	\N	\N	4	0	\N	\N
575107	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL 4D (amendements) -  PJL Respect des principes de la République (NL) (rapport)	PJL 4D (amendements) -  PJL Respect des principes de la République (NL) (rapport)	2021-07-07 08:30:00	2021-07-07 10:35:00	2021-07-07 14:13:59	2021-07-07 17:53:02	39	0	\N	\N
575160	MISSION	AUCUNE	\N	HARCEL	\N	Réunion du 1er juillet 2021	Réunion du 1er juillet 2021	2021-07-01 10:35:00	2021-07-01 12:20:00	2021-07-01 17:26:48	2021-07-01 17:47:59	7	0	\N	\N
575162	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLFR pour 2021 : Examen d'un AMDT du GVT à l'article d'équilibre	PLFR pour 2021 : Examen d'un AMDT du GVT à l'article d'équilibre	2021-07-01 14:40:00	2021-07-01 14:45:00	2021-07-01 15:41:27	2021-07-01 17:47:43	16	0	\N	\N
575164	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Différenciation, décentralisation, déconcentration et simplification -Audition CDC	PJL Différenciation, décentralisation, déconcentration et simplification -Audition CDC	2021-07-01 10:30:00	2021-07-01 11:30:00	\N	\N	3	0	\N	\N
575209	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition conjointe sur: Assurer les risques exceptionnels-Quelle couverture et financement	Audition conjointe sur: Assurer les risques exceptionnels-Quelle couverture et financement ?	2021-07-06 16:20:00	2021-07-06 18:15:00	2021-07-07 09:44:47	2021-07-07 17:52:59	20	0	\N	\N
575212	MISSION	AUCUNE	\N	CONF	\N	Réunion plénière d'adoption du rapport "stratégie vaccinale"	\N	2021-07-01 09:05:00	2021-07-01 09:30:00	2021-07-02 09:18:38	2021-07-02 16:05:41	7	0	\N	\N
575224	MISSION	AUCUNE	\N	UBER	\N	\N	\N	2021-07-08 15:35:00	2021-07-08 17:00:00	2021-07-08 17:01:37	2021-07-08 17:56:53	3	0	\N	\N
575233	COM_PERMANENTE	AUTRE	\N	FINC	\N	PJL Règlement 2020 : Examen Rapport - Contrôles Budgétaires TFP et Rôle MDPH -Désignations	PJL Règlement de 2020 : Examen Rapport - Contrôles Budgétaires Projets Transformation et fonction publiques et Rôle MDPH	2021-07-07 09:30:00	2021-07-07 11:20:00	2021-07-08 16:15:49	2021-07-08 16:16:07	37	0	\N	\N
575253	COM_PERMANENTE	AUTRE	\N	CAE	\N	Amendements séance PJL 3DS	\N	2021-07-08 08:30:00	2021-07-08 09:10:00	2021-07-09 16:31:10	2021-07-09 18:38:38	24	1	\N	\N
575255	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Art. 1er Constitution	PJL Art. 1er Constitution	2021-07-05 16:00:00	2021-07-05 18:15:00	\N	\N	44	0	\N	\N
575256	MISSION	AUDRAP	\N	ENSAGRIC	\N	Visite Ecole Vétérinaire d'Alfort	\N	2021-06-24 09:30:00	2021-06-24 12:30:00	\N	\N	0	0	\N	\N
575257	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT Puissance chinoise en Europe	\N	2021-06-23 14:00:00	2021-06-23 15:00:00	\N	\N	2	0	\N	\N
575260	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT Puissance chinoise en Europe	\N	2021-06-29 17:00:00	2021-06-29 18:00:00	\N	\N	2	0	\N	\N
575263	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Prévention Santé au travail	PPL Prévention Santé au travail	2021-07-05 18:15:00	2021-07-05 20:00:00	\N	\N	37	0	\N	\N
575265	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Prévention Santé au travail	PPL Prévention Santé au travail	2021-07-05 21:35:00	2021-07-06 00:35:00	\N	\N	29	0	\N	\N
575266	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Prévention Santé au travail	PPL Prévention Santé au travail	2021-07-06 14:30:00	2021-07-06 18:35:00	\N	\N	121	0	\N	\N
575268	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2021-07-07 15:00:00	2021-07-07 16:25:00	\N	\N	241	0	\N	\N
575269	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL 3D S	PJL 3D S	2021-07-07 16:40:00	2021-07-07 20:00:00	\N	\N	157	0	\N	\N
575270	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL 3D S	PJL 3D S	2021-07-07 21:30:00	2021-07-08 00:50:00	\N	\N	99	0	\N	\N
575271	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL 3D S	PJL 3D S	2021-07-08 10:30:00	2021-07-08 12:50:00	\N	\N	108	0	\N	\N
575272	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL 3D S	PJL 3D S	2021-07-08 14:30:00	2021-07-08 20:00:00	\N	\N	114	0	\N	\N
575273	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL 3D S	PJL 3D S	2021-07-08 21:30:00	2021-07-09 00:25:00	\N	\N	48	0	\N	\N
575274	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL 3D S	PJL 3D S	2021-07-09 09:30:00	2021-07-09 13:05:00	\N	\N	49	0	\N	\N
575275	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL 3D S	PJL 3D S	2021-07-09 14:35:00	2021-07-09 17:15:00	\N	\N	45	0	\N	\N
575276	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL 3D S	PJL 3D S	2021-07-09 21:30:00	2021-07-10 00:00:00	\N	\N	0	0	\N	\N
517469	GIA	AUCUNE	\N	\N	\N	AG Tibet	AG Tibet	2020-12-15 13:00:00	2020-12-15 13:40:00	\N	\N	4	0	634	\N
518473	GIA	AUCUNE	\N	\N	\N	AG du GIA France-Mexique et pays d'Amérique centrale	Assemblée générale du groupe interparlementaire d'amitié France-Mexique et pays d'Amérique centrale	2020-12-16 08:30:00	2020-12-16 09:30:00	\N	\N	11	0	643	\N
526466	GIA	AUCUNE	\N	\N	\N	France - Iran : Assemblée générale	France - Iran : Assemblée générale	2021-01-20 14:30:00	2021-01-20 14:50:00	\N	\N	2	0	628	\N
526469	GIA	AUCUNE	\N	\N	\N	France-Pays baltes : Assemblée générale	France-Pays baltes : Assemblée générale	2021-01-27 14:00:00	2021-01-27 14:15:00	\N	\N	3	0	616	\N
531289	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	GT Alimentation durable et locale - France Stratégie	GT Alimentation durable et locale - France Stratégie	2021-02-10 17:00:00	2021-02-10 18:10:00	\N	\N	6	0	\N	\N
551503	DELEGATION	AUDRAP	\N	\N	211	Audition d'UNICEF France	Audition d'UNICEF France	2021-04-09 14:30:00	2021-04-09 15:35:00	\N	\N	1	0	\N	\N
552870	GIA	AUCUNE	\N	\N	\N	Audition de l'ambassadeur d'Egypte en France 	Audition de SE M. Alaa Youssef 	2021-03-23 15:00:00	2021-03-23 16:15:00	\N	\N	6	0	617	\N
553644	GIA	AUCUNE	\N	\N	\N	Rencontre sur l'archéologie du GIA France-Albanie	Rencontre sur les coopération franco-albanaises en matière de recherche archéologique	2021-04-14 13:30:00	2021-04-14 15:00:00	\N	\N	2	0	571	\N
566023	MISSION	AUCUNE	\N	HARCEL	\N	\N	\N	2021-06-02 16:30:00	2021-06-03 19:00:00	2021-06-08 11:38:51	2021-06-08 12:01:08	14	0	\N	\N
566545	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Différenciation, décentralisation, déconcentration et simplification	PJL Différenciation, décentralisation, déconcentration et simplification	2021-06-01 15:30:00	2021-06-01 16:30:00	\N	\N	2	0	\N	\N
566548	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Différenciation, décentralisation, déconcentration et simplification	PJL Différenciation, décentralisation, déconcentration et simplification	2021-06-01 16:30:00	2021-06-01 18:30:00	\N	\N	1	0	\N	\N
566550	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Différenciation, décentralisation, déconcentration et simplification	PJL Différenciation, décentralisation, déconcentration et simplification	2021-06-01 18:30:00	2021-06-01 19:15:00	\N	\N	2	0	\N	\N
566553	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Différenciation, décentralisation, déconcentration et simplification	PJL Différenciation, décentralisation, déconcentration et simplification	2021-06-01 19:15:00	2021-06-01 20:00:00	\N	\N	2	0	\N	\N
568177	GIA	AUCUNE	\N	\N	\N	Entretien avec la présidente de la commission de la culture du Parlement géorgien	Entretien avec Mme Elisso Bolkvadze, présidente de la commission de la culture du Parlement de Géorgie	2021-06-09 16:00:00	2021-06-09 17:00:00	\N	\N	2	0	534	\N
568186	GIA	AUCUNE	\N	\N	\N	Audition chef de missions humanitaires en Arménie	Audition du docteur Levon Khachatryan, chef de missions humanitaires en Arménie	2021-06-09 14:00:00	2021-06-09 15:00:00	\N	\N	3	0	641	\N
570596	MISSION	AUCUNE	\N	VIETUDIA	\N	Audition Mme Vidal	\N	2021-06-16 16:35:00	2021-06-16 18:15:00	2021-06-17 09:47:37	2021-06-18 18:53:34	10	0	\N	\N
570618	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLFR 2021: Examen rapport et Audition Cour des comptes Perspectives des finances publiques	PLFR 2021: Examen rapport et Audition Cour des comptes Perspectives des finances publiques	2021-06-23 09:30:00	2021-06-23 13:00:00	2021-06-23 14:10:05	2021-06-24 18:15:19	37	0	\N	\N
570632	DELEGATION	AUCUNE	\N	\N	211	Examen du rapport d'information sur le bilan de l'application de la loi Copé-Zimmermann	Examen du rapport d'information sur le bilan de l'application de la loi Copé-Zimmermann	2021-07-08 09:00:00	2021-07-08 09:45:00	2021-07-08 10:31:32	\N	12	0	\N	\N
570633	DELEGATION	AUTRE	\N	\N	211	Audition de M. Éric Dupond-Moretti, garde des Sceaux, ministre de la justice	\N	2021-07-21 16:45:00	2021-07-21 18:45:00	\N	\N	0	0	\N	\N
570634	DELEGATION	AUCUNE	\N	\N	211	Audition de M. Éric Dupond-Moretti, garde des Sceaux, ministre de la justice	Audition de M. Éric Dupond-Moretti, garde des Sceaux, ministre de la justice	2021-07-07 16:45:00	2021-07-07 18:45:00	2021-07-08 10:30:31	\N	25	0	\N	\N
576799	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Révision tarifs contrats photovoltaïques - Photosol/FNSEA	Contrôle 2021 - Révision tarifs contrats photovoltaïques - Photosol/FNSEA	2021-07-06 10:00:00	2021-07-06 11:00:00	\N	\N	1	0	\N	\N
576801	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - IHU - Institut Pasteur	Contrôle 2021 - IHU - Institut Pasteur	2021-07-06 16:00:00	2021-07-06 17:00:00	\N	\N	2	0	\N	\N
579371	MISSION	AUDRAP	\N	INFLUENCES	\N	Auditions de Mme. Van Hoecke - CNRS & Mme Astarita, Science-po Lyon	\N	2021-07-15 10:07:00	2021-07-15 12:20:00	\N	\N	3	0	\N	\N
579464	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Gestion de la crise sanitaire - Auditions d'Olivier Véran et Jean-François Delfraissy	PJL Gestion de la crise sanitaire - Auditions d'Olivier Véran et Jean-François Delfraissy	2021-07-22 09:00:00	2021-07-22 11:45:00	2021-07-22 14:43:29	2021-07-22 18:16:34	59	0	\N	\N
579465	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Respect des principes de la République (NL) (amendements)	PJL Respect des principes de la République (NL) (amendements)	2021-07-20 16:30:00	2021-07-20 18:30:00	\N	\N	0	0	\N	\N
579467	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de M. Olivier Véran	\N	2021-07-22 09:00:00	2021-07-22 11:45:00	2021-07-22 16:52:21	2021-07-22 18:16:35	59	0	\N	\N
579470	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Mme Chain Larché	\N	2021-07-13 09:30:00	2021-07-13 10:30:00	\N	\N	1	0	\N	\N
579472	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Mme Chain Larché	\N	2021-07-13 14:30:00	2021-07-13 19:05:00	\N	\N	1	0	\N	\N
579514	MECSS	AUDRAP	\N	\N	MECSS	Audition de l'INSEE	\N	2021-07-22 16:00:00	2021-07-22 17:30:00	\N	\N	2	0	\N	\N
579540	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition association 2GAP	Audition association 2GAP	2021-07-21 09:00:00	2021-07-21 10:00:00	\N	\N	1	0	\N	\N
579549	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition association FETE	\N	2021-07-21 14:00:00	2021-07-21 15:00:00	\N	\N	1	0	\N	\N
579562	MISSION	AUCUNE	\N	EGALCHAN	\N	Réunion plénière	\N	2021-07-20 17:03:00	2021-07-20 18:11:00	2021-07-20 19:18:21	2021-07-21 15:54:35	3	0	\N	\N
579580	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Mineurs non accompagnés - Audition d'Unicef France	\N	2021-07-13 16:00:00	2021-07-13 17:00:00	\N	\N	2	0	\N	\N
579584	DELEGATION	AUCUNE	\N	\N	206	Présentation des rapports des auditeurs de l'IHEST	\N	2021-07-22 09:30:00	2021-07-22 12:30:00	\N	\N	5	0	\N	\N
579783	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Egalim 2 - FNPL	Auditions Egalim 2 - FNPL	2021-07-19 14:00:00	2021-07-19 15:00:00	\N	\N	2	0	\N	\N
579806	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-07-20 14:30:00	2021-07-20 14:42:00	2021-07-20 14:51:22	2021-07-20 18:01:30	34	1	\N	\N
580133	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Révision tarifs contrats photovoltaïques - SER	Contrôle 2021 - Révision tarifs contrats photovoltaïques - SER	2021-07-20 10:30:00	2021-07-20 11:20:00	\N	\N	1	0	\N	\N
581801	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PPL Protéger la rémunération des agriculteurs	Auditions PPL Protéger la rémunération des agriculteurs	2021-07-21 14:00:00	2021-07-21 14:30:00	\N	\N	4	0	\N	\N
581806	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PPL Protéger la rémunération des agriculteurs	\N	2021-07-21 14:30:00	2021-07-21 15:00:00	\N	\N	2	0	\N	\N
581809	MISSION	AUDRAP	\N	INFLUENCES	\N	Audition Mickael COLE Institut Mac Donald Taiwan	\N	2021-07-22 10:12:00	2021-07-22 12:15:00	\N	\N	4	0	\N	\N
581902	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Protection des enfants - Table ronde d'associations	\N	2021-07-22 09:30:00	2021-07-22 11:00:00	\N	\N	1	0	\N	\N
581903	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Protection des enfants - Audition de Kaotik 747	\N	2021-07-22 11:00:00	2021-07-22 12:00:00	\N	\N	1	0	\N	\N
581904	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Protection des enfants - Table ronde de syndicats d'assistants familiaux	\N	2021-07-22 14:00:00	2021-07-22 15:30:00	\N	\N	3	0	\N	\N
581921	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Gestion de la crise sanitaire (rapport et texte de la commission)	PJL Gestion de la crise sanitaire (rapport et texte de la commission)	2021-07-23 14:35:00	2021-07-23 17:35:00	2021-07-23 18:10:51	2021-07-23 19:19:57	25	1	\N	\N
581922	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Gestion de la crise sanitaire (amendements)	PJL Gestion de la crise sanitaire (amendements)	2021-07-24 08:30:00	2021-07-24 08:55:00	2021-07-24 09:28:16	2021-07-28 10:30:15	15	0	\N	\N
582707	GIA	AUCUNE	\N	\N	\N	Audition Quai d'Orsay	Audition de M. Damien Syed, sous-directeur de l'Asie méridionale du MEAE	2021-09-02 14:00:00	2021-09-02 15:00:00	\N	\N	2	0	648	\N
582731	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2021-07-21 17:00:00	2021-07-21 19:00:00	\N	\N	2	0	\N	\N
582734	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2021-07-27 15:00:00	2021-07-27 16:30:00	\N	\N	5	0	\N	\N
582740	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLO Confiance dans l'institution judiciaire PJL Confiance dans l'institution judiciaire	\N	2021-07-27 14:00:00	2021-07-27 16:00:00	\N	\N	2	0	\N	\N
582743	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLO Confiance dans l'institution judiciaire PJL Confiance dans l'institution judiciaire	\N	2021-07-29 09:30:00	2021-07-29 10:30:00	\N	\N	1	0	\N	\N
582745	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	PJL et PJLO Confiance dans l'institution judiciaire - Déplacement à Rennes	PJL et PJLO Confiance dans l'institution judiciaire - Déplacement à Rennes	2021-07-28 08:00:00	2021-07-28 22:00:00	\N	\N	5	0	\N	\N
582747	GIA	AUCUNE	\N	\N	\N	\N	Entretien avec Mme Aissata TALL SALL, Ministre des affaires étrangères et des Sénégalais de l'extérieur du Sénégal	2021-09-06 13:00:00	2021-09-06 14:30:00	\N	\N	1	0	573	\N
582749	MISSION	AUDRAP	\N	INFLUENCES	\N	Audition de MM. Paul Charon et Jean-Baptiste Jeangène Vilmer IRSEM	\N	2021-09-02 14:30:00	2021-09-02 15:30:00	\N	\N	4	0	\N	\N
582754	MISSION	AUDRAP	\N	INFLUENCES	\N	Audition de M. Alain Labat	\N	2021-09-02 15:30:00	2021-09-02 16:30:00	\N	\N	3	0	\N	\N
583152	COM_PERMANENTE	AUTRE	\N	FINC	\N	Désignation RS - PPLO 780 et PPL 781 : Examen rapport et texte - Désignation Rapp. PPL 383	Désignation RS - PPLO 780 et PPL 781 : Examen rapport et texte - Désignation Rapp. PPL 383	2021-09-15 09:30:00	2021-09-15 12:10:00	2021-09-15 14:52:20	2021-09-15 17:27:02	35	0	\N	\N
583160	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désignation rapporteurs - PPL Réélection  juges consulaires - PJL-PJLO Confiance justice	Désignation rapporteurs - PPL Réélection  juges consulaires - PJL-PJLO Confiance justice	2021-09-15 09:35:00	2021-09-15 12:30:00	2021-09-15 14:09:04	2021-09-15 17:27:02	34	0	\N	\N
583161	MISSION	AUDRAP	\N	INFLUENCES	\N	Audition M. Pastorel	\N	2021-09-09 19:15:00	2021-09-09 20:05:00	\N	\N	1	0	\N	\N
584483	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Réforme de l'encadrement supérieur de la fonction publique de l'État	\N	2021-09-21 17:30:00	2021-09-21 20:15:00	\N	\N	1	0	\N	\N
584494	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Audition conjointe de Mme Élisabeth Borne, avec la Mission d'information "ubérisation"	Audition conjointe de Mme Élisabeth Borne, avec la Mission d'information "ubérisation"	2021-09-21 17:30:00	2021-09-21 18:45:00	2021-09-22 11:00:25	\N	16	0	\N	\N
584533	DELEGATION	AUCUNE	\N	\N	211	Audition de représentantes du Mouvement des entreprises de France (MEDEF)	Audition de représentantes du Mouvement des entreprises de France (MEDEF)	2021-09-29 17:00:00	2021-09-29 18:20:00	2021-09-29 18:20:57	\N	6	0	\N	\N
584715	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Financement aires protégées - DEB	Contrôle 2021 - Financement aires protégées - DEB	2021-09-20 16:15:00	2021-09-20 17:00:00	\N	\N	1	0	\N	\N
584880	MISSION	AUDRAP	\N	ENSAGRIC	\N	Audition Mme Raphaëlle Séguin	Audition de Mme Séguin, conseillère budgétaire au Ministère de la Mer	2021-09-22 14:20:00	2021-09-22 15:00:00	\N	\N	5	0	\N	\N
585253	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Auditions de M. Bélaval, CMN, et du général JL Georgelin, Notre-Dame de Paris	\N	2021-09-22 09:35:00	2021-09-22 12:25:00	2021-09-22 18:12:33	2021-09-22 18:40:16	38	0	\N	\N
585408	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen AMDTS séance textes de la commission n°832 et n° 833  Finances publiques	Examen AMDTS séance textes de la commission n°832 et n° 833  Finances publiques	2021-09-27 15:05:00	2021-09-27 15:25:00	2021-09-27 16:03:19	2021-09-27 18:09:33	23	0	\N	\N
585409	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition pour suite à donner Contrôle 58-2 sur la couverture mobile du territoire	Audition pour suite à donner Contrôle 58-2 sur la couverture mobile du territoire	2021-09-28 17:30:00	2021-09-28 19:15:00	2021-09-28 19:30:13	2021-09-29 18:17:36	28	0	\N	\N
585411	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen rapport et texte PPL 383 Dons et adhésions aux associations - Contrôles budgétaires	Examen rapport et texte PPL 383 Dons et adhésions aux associations - Contrôles budgétaires 	2021-09-29 09:30:00	2021-09-29 12:30:00	2021-09-29 14:19:13	2021-09-29 18:17:47	40	0	\N	\N
585696	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Réforme de l'encadrement supérieur de la fonction publique de l'État	\N	2021-09-23 09:00:00	2021-09-23 10:30:00	\N	\N	1	0	\N	\N
585735	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteur 	\N	2021-09-22 15:00:00	2021-09-22 16:00:00	\N	\N	1	0	\N	\N
585736	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteur	\N	2021-09-22 16:00:00	2021-09-22 17:00:00	\N	\N	1	0	\N	\N
585767	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL n°813 Barrages hydroéléctriques - Audition EDF - EDF hydro	PPL n°813 Barrages hydroéléctriques - Audition EDF - EDF hydro	2021-09-23 09:00:00	2021-09-23 09:30:00	\N	\N	2	0	\N	\N
585770	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL n°813 Barrages hydroélectriques - Auditions Engie - CNR - SHEM	PPL n°813 Barrages hydroélectriques - Auditions Engie - CNR - SHEM	2021-09-23 09:30:00	2021-09-23 10:00:00	\N	\N	6	0	\N	\N
585777	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL n°813 Barrages hydroélectriques - Auditions FHE - EAF	PPL n°813 Barrages hydroélectriques - Auditions FHE - EAF	2021-09-23 10:00:00	2021-09-23 10:30:00	\N	\N	7	0	\N	\N
585785	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL n°813 Barrages hydroélectriques - Audition DGEC	PPL n°813 Barrages hydroélectriques - Audition DGEC	2021-09-23 10:30:00	2021-09-23 11:15:00	\N	\N	7	0	\N	\N
585793	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL n°813 Barrages hydroélectriques - Audition Syndicats d'EDF	PPL n°813 Barrages hydroélectriques - Audition Syndicats d'EDF	2021-09-23 11:15:00	2021-09-23 12:00:00	\N	\N	4	0	\N	\N
585798	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL n°813 Barrages hydroélectriques - Audition AFIEG	PPL n°813 Barrages hydroélectriques - Audition AFIEG	2021-09-23 12:00:00	2021-09-23 12:30:00	\N	\N	1	0	\N	\N
585800	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL n°813 Barrages hydroélectriques - Audition M. Gontard	PPL n°813 Barrages hydroélectriques - Audition M. Gontard	2021-09-23 14:00:00	2021-09-23 14:30:00	\N	\N	2	0	\N	\N
585803	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL n°813 Barrages hydroélectriques - Audition SER	PPL n°813 Barrages hydroélectriques - Audition SER	2021-09-23 14:30:00	2021-09-23 14:50:00	\N	\N	2	0	\N	\N
585815	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Table ronde sur les conditions et les perspectives de la reprise économique 	\N	2021-09-30 09:00:00	2021-09-30 10:30:00	\N	\N	17	0	\N	\N
585825	DELEGATION	AUDRAP	\N	\N	PROS	Audition rapporteur (M. Rodarie Hubert, essayiste, Président de l'AF2I)	\N	2021-09-21 15:00:00	2021-09-21 16:00:00	\N	\N	2	0	\N	\N
585826	DELEGATION	AUDRAP	\N	\N	PROS	Audition de rapporteur (M Rigaudiat, essayiste)	\N	2021-09-21 14:00:00	2021-09-21 15:00:00	\N	\N	2	0	\N	\N
585839	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Protection des enfants - Audition de l'Uniopss	\N	2021-09-21 14:00:00	2021-09-21 15:15:00	\N	\N	5	0	\N	\N
585840	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Protection des enfants - Table ronde de conseils départementaux	\N	2021-09-21 15:15:00	2021-09-21 16:45:00	\N	\N	7	0	\N	\N
585841	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Protection des enfants - Table ronde de conseils départementaux	\N	2021-09-21 17:00:00	2021-09-21 18:30:00	\N	\N	2	0	\N	\N
585842	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Protection des enfants - Audition de psychologues	\N	2021-09-22 17:45:00	2021-09-22 18:30:00	\N	\N	2	0	\N	\N
585843	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Protection des enfants - Audition de la DPJJ	\N	2021-09-23 09:00:00	2021-09-23 09:45:00	\N	\N	2	0	\N	\N
585844	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Protection des enfants - Audition de la DGESCO	\N	2021-09-23 09:45:00	2021-09-23 10:30:00	\N	\N	2	0	\N	\N
585845	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Protection des enfants - Audition de M. Jean-Pierre Rosenczveig	\N	2021-09-23 11:00:00	2021-09-23 12:20:00	\N	\N	3	0	\N	\N
585847	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Protection des enfants - Audition de M. Edouard Durand	\N	2021-09-23 15:00:00	2021-09-23 16:00:00	\N	\N	3	0	\N	\N
516772	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	\N	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne	2020-12-09 16:30:00	2020-12-09 18:00:00	2020-12-11 10:20:47	\N	8	0	\N	\N
519287	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition Réforme de la LOLF - Désignation rapporteurs PJL Ressources propres et 688	Audition Réforme de la LOLF - Désignation rapporteurs PJL Ressources propres et 688	2021-01-13 10:05:00	2021-01-13 12:00:00	2021-01-13 14:01:42	2021-01-13 15:53:04	39	0	\N	\N
519288	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Convention monétaire France CFA - SER DG trésor Afrique de l'ouest	Convention monétaire France CFA - SER DG trésor Afrique de l'ouest	2021-01-05 15:00:00	2021-01-05 16:00:00	\N	\N	1	0	\N	\N
519290	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Convention monétaire France CFA - Banque de France	Convention monétaire France CFA - Banque de France	2021-01-06 10:00:00	2021-01-06 11:15:00	\N	\N	1	0	\N	\N
519304	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-01-13 09:33:00	2021-01-13 11:28:00	2021-01-22 15:35:11	2021-01-22 15:43:21	64	0	\N	\N
519312	DELEGATION	AUCUNE	\N	\N	PROS	Examen du rapport sur les mobilités dans les espaces peu denses à l'horizon 2040	Examen du rapport sur les mobilités dans les espaces peu denses à l'horizon 2040	2021-01-14 08:30:00	2021-01-14 09:40:00	\N	\N	20	0	\N	\N
519320	DELEGATION	AUDRAP	\N	\N	PROS	Audition du CNCC	Audition du Conseil national des centres commerciaux	2021-02-03 16:30:00	2021-02-03 17:30:00	\N	\N	1	0	\N	\N
519321	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-01-12 13:31:00	2021-01-12 13:47:00	2021-01-12 14:19:31	2021-01-12 17:12:20	33	0	\N	\N
519368	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 2020 - Renouvellement urbains - SRU - Cour des comptes	58-2 2020 - Renouvellement urbains - SRU - Cour des comptes	2021-01-07 09:30:00	2021-01-07 10:15:00	\N	\N	1	0	\N	\N
521402	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désignation de rapporteurs - Examen de rapports et textes - Amendements de séance	Désignation de rapporteurs - Examen de rapports et textes - Amendements de séance	2021-01-20 09:15:00	2021-01-20 12:40:00	2021-01-20 13:41:31	2021-01-20 14:47:59	41	0	\N	\N
527568	DELEGATION	AUDRAP	\N	\N	206	Audition Production d'hydrogène - CEA	Audition Production d'hydrogène - CEA	2021-02-04 15:00:00	2021-02-04 16:00:00	\N	\N	1	0	\N	\N
527570	DELEGATION	AUDRAP	\N	\N	206	Audition Production d'hydrogène - Table ronde enseignants-chercheurs	Audition Production d'hydrogène - Table ronde enseignants-chercheurs	2021-02-04 16:00:00	2021-02-04 18:00:00	\N	\N	1	0	\N	\N
531314	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI "Di	Audition rapporteur - CGJCF - MI "Difficultés des entreprises et crise de la Covid-19"	2021-02-11 14:00:00	2021-02-11 15:15:00	\N	\N	2	0	\N	\N
534331	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Droit au respect de la dignité en détention	\N	2021-02-26 16:45:00	2021-02-26 17:15:00	\N	\N	2	0	\N	\N
534334	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Droit au respect de la dignité en détention	\N	2021-02-26 17:15:00	2021-02-26 18:15:00	\N	\N	1	0	\N	\N
537512	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière	\N	2021-03-11 09:00:00	2021-03-11 11:00:00	2021-03-11 11:45:51	\N	15	0	\N	\N
538149	MISSION	AUDRAP	\N	PAUP	\N	Audition rapporteur	Audition de M. Arnaud Leroy président de l'observatoire national de la précarité énergétique	2021-03-11 14:30:00	2021-03-11 15:30:00	\N	\N	4	0	\N	\N
538150	MISSION	AUDRAP	\N	PAUP	\N	Audition rapporteur	Audition de Sandra ROGER , cheffe de projet, statisticienne à l'atelier parisien d¿urbanisme (APUR)	2021-03-11 15:30:00	2021-03-11 16:30:00	\N	\N	0	0	\N	\N
538375	MISSION	AUDRAP	\N	PAUP	\N	Audition de M. Jean-Claude Driant professeur à l'école d'urbanisme de Paris	Audition de M. Jean-Claude Driant professeur à l'école d'urbanisme de Paris	2021-03-17 08:45:00	2021-03-17 09:30:00	\N	\N	2	0	\N	\N
539244	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - Protection des épargnants - FBA	Contrôle 2020 - Protection des épargnants - FBA	2021-03-09 09:35:00	2021-03-09 10:40:00	\N	\N	2	0	\N	\N
539251	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - Protection des épargnants - Assoc. Prof.Cons. Investissements Fin.	Contrôle 2020 - Protection des épargnants - Associations professionnelles agréées de conseillers en investissements fin.	2021-03-09 16:30:00	2021-03-09 17:45:00	\N	\N	2	0	\N	\N
539266	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - Protection des épargnants - ACPR	Contrôle 2020 - Protection des épargnants - ACPR	2021-03-10 15:00:00	2021-03-10 16:05:00	\N	\N	2	0	\N	\N
539275	ETUDES	AUTRE	\N	\N	\N	Audition PV Cycle	\N	2021-03-10 14:00:00	2021-03-10 15:00:00	\N	\N	7	0	\N	922
539283	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition continuité écologique des cours d'eau	\N	2021-03-10 16:10:00	2021-03-10 18:20:00	\N	\N	6	0	\N	\N
539446	ETUDES	AUTRE	\N	\N	\N	GEAC - Réunion constitutive	GEAC - Réunion constitutive	2021-03-17 16:40:00	2021-03-17 17:20:00	\N	\N	20	0	\N	933
539474	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Professeur, signataire du "Manifeste des 100"	\N	2021-03-09 14:30:00	2021-03-09 15:30:00	\N	\N	8	0	\N	\N
553250	DELEGATION	AUCUNE	\N	\N	PROS	Examen du rapport 	Examen du rapport sur Les outils numériques dans la prévention et la gestion des pandémies	2021-05-06 08:30:00	2021-05-06 10:00:00	\N	\N	15	0	\N	\N
553337	COM_EURO	AUTRE	\N	AFEU	\N	Stratégie commerciale de l¿UE : communication	\N	2021-04-08 06:30:00	2021-04-08 07:30:00	\N	\N	0	0	\N	\N
553338	MISSION	AUDRAP	\N	PAUP	\N	DGEFP	\N	2021-04-19 14:00:00	2021-04-19 15:00:00	\N	\N	2	0	\N	\N
553339	MISSION	AUDRAP	\N	PAUP	\N	Ansa	\N	2021-04-21 14:00:00	2021-04-21 15:00:00	\N	\N	3	0	\N	\N
553660	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Mairie de Neuilly	\N	2021-04-13 14:30:00	2021-04-13 15:30:00	\N	\N	1	0	\N	\N
553661	COM_PERMANENTE	AUDRAP	\N	CAE	\N	GECINA	\N	2021-04-13 15:30:00	2021-04-13 16:30:00	\N	\N	2	0	\N	\N
553665	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition M. Berho	\N	2021-04-14 09:00:00	2021-04-14 10:00:00	\N	\N	2	0	\N	\N
555777	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Suivi des condamnés terroristes sortant de détention	PPL Suivi des condamnés terroristes sortant de détention	2021-05-04 08:30:00	2021-05-04 09:30:00	\N	\N	4	0	\N	\N
555800	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Suivi des condamnés terroristes sortant de détention	PPL Suivi des condamnés terroristes sortant de détention	2021-05-04 09:30:00	2021-05-04 10:00:00	\N	\N	5	0	\N	\N
555812	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Suivi des condamnés terroristes sortant de détention	PPL Suivi des condamnés terroristes sortant de détention	2021-05-04 10:00:00	2021-05-04 11:00:00	\N	\N	2	0	\N	\N
555817	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Suivi des condamnés terroristes sortant de détention	PPL Suivi des condamnés terroristes sortant de détention	2021-05-04 14:30:00	2021-05-04 15:45:00	\N	\N	4	0	\N	\N
557367	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	Groupe d'études Statut rôle et place des Français établis hors de France	Audition de Mme Armelle BEUNARDEAU, directrice du CLEISS	2021-05-05 13:30:00	2021-05-05 14:45:00	\N	\N	10	0	\N	\N
539658	GIA	AUCUNE	\N	\N	\N	Audition de M. Yves de Ricaud	Audition de M. Yves de Ricaud	2021-03-11 09:30:00	2021-03-11 10:40:00	\N	\N	5	0	978	\N
557383	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	Groupe d'études Statut rôle et place des Français établis hors de France	Audition de Mme Agnès ARCIER, Directrice de la Direction des Impôts des Non-résidents (DINR)	2021-05-05 16:30:00	2021-05-05 17:40:00	\N	\N	10	0	\N	\N
557401	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Réunion du Bureau	\N	2021-05-05 17:00:00	2021-05-05 19:00:00	\N	\N	15	0	\N	\N
559959	DELEGATION	AUCUNE	\N	\N	PROS	Examen du rapport d'information "numérique et pandémie"	Examen du rapport d'information "numérique et pandémie"	2021-06-03 08:30:00	2021-06-03 10:00:00	\N	\N	15	0	\N	\N
559960	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière	\N	2021-05-20 10:00:00	2021-05-20 11:15:00	2021-05-20 11:24:23	\N	9	0	\N	\N
559961	DELEGATION	AUCUNE	\N	\N	211	Échange avec le Centre polonais des droits des femmes et des sénatrices polonaises 	Échange avec le Centre polonais des droits des femmes et des sénatrices polonaises 	2021-06-09 17:00:00	2021-06-09 19:05:00	2021-06-10 12:40:33	\N	4	0	\N	\N
559965	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Climat et résilience "Se loger" - Table ronde FIDI / LDI / CDI FNAIM	PJL Climat et résilience "Se loger" - Table ronde FIDI / LDI / CDI FNAIM	2021-05-11 09:00:00	2021-05-11 09:45:00	\N	\N	1	0	\N	\N
559966	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL Climat et résilience - Audition Conseil supérieur du notariat	Audition PJL Climat et résilience - Audition Conseil supérieur du notariat	2021-05-11 09:45:00	2021-05-11 10:30:00	\N	\N	1	0	\N	\N
559969	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Climat et résilience "Se loger" - Table ronde UNPI / CLCV	PJL Climat et résilience "Se loger" - Table ronde UNPI / CLCV	2021-05-17 14:00:00	2021-05-17 15:00:00	\N	\N	1	0	\N	\N
575281	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 1er juillet 2021	\N	2021-07-01 09:30:00	2021-07-01 10:30:00	\N	\N	0	0	\N	\N
575282	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 1er juillet 2021	\N	2021-07-01 09:30:00	2021-07-01 10:30:00	\N	\N	0	0	\N	\N
575283	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Soins palliatifs - Audition Plan triennal de développement des soins palliatifs	\N	2021-06-30 16:30:00	2021-06-30 17:45:00	\N	\N	2	0	\N	\N
575284	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Soins pallliatifs - Table ronde Administrations centrales du ministère de la santé	\N	2021-06-30 17:45:00	2021-06-30 19:15:00	\N	\N	2	0	\N	\N
575285	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Soins palliatifs - Table ronde d'institutionnels	\N	2021-06-29 14:30:00	2021-06-29 16:00:00	\N	\N	3	0	\N	\N
575295	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Réunion du groupe d'études TAAF	\N	2021-07-01 10:00:00	2021-07-01 11:30:00	\N	\N	6	0	\N	\N
575302	ETUDES	AUCUNE	\N	\N	\N	GE Arts de la scène, arts de la rue et festivals en régions 	GE Arts de la scène, arts de la rue et festivals en régions 	2021-06-30 12:00:00	2021-06-30 12:50:00	\N	\N	6	0	\N	966
575109	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL 4D (suite amendements)	PJL 4D (suite amendements)	2021-07-08 08:30:00	2021-07-08 08:55:00	2021-07-12 14:54:34	2021-07-12 16:37:15	19	0	\N	\N
575753	GIA	AUCUNE	\N	\N	\N	Visio Afrane-Mères pour la paix	Visioconférence avec Etienne Gille, membre d'Afrane, et Françoise Barthélémy, membre de Mères pour la paix	2021-06-30 16:30:00	2021-06-30 17:30:00	\N	\N	1	0	648	\N
575755	GIA	AUCUNE	\N	\N	\N	Rencontre Luai Jaff	Rencontre avec Luai Jaff, représentant de l'UPK en France	2021-06-29 15:00:00	2021-06-29 16:00:00	\N	\N	1	0	615	\N
575767	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2021-06-24 09:05:00	2021-06-24 12:45:00	\N	\N	3	0	\N	\N
575918	ETUDES	AUCUNE	\N	\N	\N	Réunion constitutive	Réunion constitutive	2021-07-06 13:15:00	2021-07-06 14:15:00	\N	\N	6	0	\N	1012
575223	MISSION	AUCUNE	\N	UBER	\N	\N	\N	2021-07-06 09:20:00	2021-07-06 10:05:00	2021-07-06 10:11:23	2021-07-06 18:19:40	5	0	\N	\N
576002	GIA	AUCUNE	\N	\N	\N	Entretien avec des représentants du groupe TotalEnergie	Entretien avec des représentants du groupe TotalEnergie : présentation des projets et de l'implantation du groupe	2021-07-06 17:00:00	2021-07-06 18:00:00	\N	\N	8	0	651	\N
576253	GIA	AUCUNE	\N	\N	\N	Réunion Bureau	Réunion Bureau du groupe d'amitié	2021-07-06 17:30:00	2021-07-06 18:15:00	\N	\N	5	0	963	\N
576290	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLO Confiance dans l'institution judiciaire	\N	2021-07-06 14:00:00	2021-07-06 15:40:00	\N	\N	2	0	\N	\N
576293	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Confiance dans l'institution judiciaire	\N	2021-07-06 15:40:00	2021-07-06 16:45:00	\N	\N	3	0	\N	\N
578129	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Rapport Général - CNOCP	PLF pour 2022 - Rapport Général - CNOCP	2021-07-07 17:00:00	2021-07-07 17:45:00	\N	\N	1	0	\N	\N
578154	DELEGATION	AUCUNE	\N	\N	206	Audition du CSTB-Examen des conclusions sur la recherche en biologie-santé	Audition du CSTB-Examen des conclusions de l'audition sur la recherche en biologie-santé	2021-07-15 09:35:00	2021-07-15 11:40:00	\N	\N	11	0	\N	\N
578168	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL 3D S	PJL 3D S	2021-07-12 17:00:00	2021-07-12 19:45:00	\N	\N	77	0	\N	\N
578169	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PLFR 2021	CMP PLFR 2021	2021-07-12 16:00:00	2021-07-12 16:55:00	\N	\N	44	0	\N	\N
578170	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2021-07-13 09:30:00	2021-07-13 12:45:00	\N	\N	44	0	\N	\N
578172	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL 3D S	PJL 3D S	2021-07-13 14:30:00	2021-07-13 17:55:00	\N	\N	114	0	\N	\N
578173	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL 3D S	PJL 3D S	2021-07-15 10:30:00	2021-07-15 13:10:00	\N	\N	64	0	\N	\N
578175	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Débat orientation PJL Loi règlement Budget	Débat orientation PJL Loi règlement Budget	2021-07-15 14:40:00	2021-07-15 16:55:00	\N	\N	62	0	\N	\N
578176	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL 3D S	PJL 3D S	2021-07-15 17:00:00	2021-07-15 20:10:00	\N	\N	74	0	\N	\N
578177	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL 3D SPJL 3D S	\N	2021-07-15 21:40:00	2021-07-16 00:30:00	\N	\N	58	0	\N	\N
578179	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL 3D S	PJL 3D S	2021-07-16 09:30:00	2021-07-16 13:00:00	\N	\N	58	0	\N	\N
578180	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL 3D S	PJL 3D S	2021-07-16 14:30:00	2021-07-16 16:45:00	\N	\N	47	0	\N	\N
578191	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Confiance dans l'institution judiciaire	\N	2021-07-07 14:00:00	2021-07-07 19:00:00	\N	\N	2	0	\N	\N
578194	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Confiance dans l'institution judiciaire	\N	2021-07-08 09:00:00	2021-07-08 11:00:00	\N	\N	1	0	\N	\N
578282	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Confiance dans l'institution judiciaire	\N	2021-07-09 09:00:00	2021-07-09 12:30:00	\N	\N	2	0	\N	\N
578285	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Confiance dans l'institution judiciaire	\N	2021-07-09 14:30:00	2021-07-09 17:45:00	\N	\N	2	0	\N	\N
578288	GIA	AUCUNE	\N	\N	\N	Audition de JY LE DRIAN, ministre de l'Europe et des Affaires étrangères	Audition conjointe avec la commission des AE , de la D et des FA	2021-07-07 16:30:00	2021-07-07 18:00:00	\N	\N	27	0	CHRETORIENT	CHRETORIENT
578316	GIA	AUCUNE	\N	\N	\N	Entretien de Philippe MOUILLER, Président, avec son homologue en visio	Entretien de Ph. MOUILLER, Président, avec le Dr. MP J. CHINBUREN, Président du GIA Mongolie-France	2021-07-08 09:00:00	2021-07-08 09:45:00	\N	\N	1	0	612	\N
578802	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	LOIS	\N	MI Dysfonctionnements élections juin 2021 - Echange de vues entre les rapporteurs	MI Dysfonctionnements élections juin 2021 - Echange de vues entre les rapporteurs	2021-07-13 14:25:00	2021-07-13 15:05:00	\N	\N	7	0	\N	\N
578876	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Pjl terrorisme	\N	2021-06-11 10:00:00	2021-06-11 11:00:00	\N	\N	1	0	\N	\N
578878	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Pjl terrorisme	\N	2021-06-11 13:30:00	2021-06-11 14:00:00	\N	\N	2	0	\N	\N
578881	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Pjl terrorisme	\N	2021-06-11 14:00:00	2021-06-11 14:40:00	\N	\N	2	0	\N	\N
578884	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Pjl terrorisme	\N	2021-06-14 09:30:00	2021-06-14 10:00:00	\N	\N	2	0	\N	\N
578887	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Pjl terrorisme	\N	2021-06-22 13:30:00	2021-06-22 14:15:00	\N	\N	4	0	\N	\N
578921	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Examen RI COM AFD	\N	2021-07-21 10:00:00	2021-07-21 10:40:00	2021-07-21 15:50:48	2021-07-21 15:56:17	29	7	\N	\N
579448	GIA	AUCUNE	\N	\N	\N	rencontre avec une délégation de parlementaires serbes	\N	2021-07-15 14:30:00	2021-07-15 15:45:00	\N	\N	4	0	674	\N
579563	GIA	AUCUNE	\N	\N	\N	Dîner délégation polonaise - groupe d'amitié France-Pologne	Dîner délégation polonaise - groupe d'amitié France-Pologne	2021-06-28 20:00:00	2021-06-28 22:30:00	\N	\N	3	0	600	\N
579567	GIA	AUCUNE	\N	\N	\N	Rencontre délégation polonaise - Christian CAMBON	Rencontre délégation polonaise - Christian CAMBON	2021-06-29 09:30:00	2021-06-29 10:30:00	\N	\N	2	0	600	\N
579570	GIA	AUCUNE	\N	\N	\N	Rencontre délégation polonaise - DGRIS ministère des armées	Rencontre délégation polonaise - DGRIS ministère des armées	2021-06-29 11:00:00	2021-06-29 12:00:00	\N	\N	1	0	600	\N
579572	GIA	AUCUNE	\N	\N	\N	Rencontre délégation polonaise - Jean-François RAPIN	Rencontre délégation polonaise - Jean-François RAPIN	2021-06-29 14:45:00	2021-06-29 15:45:00	\N	\N	1	0	600	\N
579574	GIA	AUCUNE	\N	\N	\N	Rencontre délégation polonaise - EDF	Rencontre délégation polonaise - EDF	2021-06-29 16:30:00	2021-06-29 18:00:00	\N	\N	1	0	600	\N
579576	GIA	AUCUNE	\N	\N	\N	Rencontre délégation polonaise - MEDEF	Rencontre délégation polonaise - MEDEF	2021-06-29 18:30:00	2021-06-29 19:30:00	\N	\N	1	0	600	\N
579578	GIA	AUCUNE	\N	\N	\N	Accueil délégation polonaise : Cadarache et Marseille	Accueil délégation polonaise : Cadarache et Marseille	2021-06-30 08:00:00	2021-07-02 14:30:00	\N	\N	1	0	600	\N
581891	GIA	AUCUNE	\N	\N	\N	Entretien avec S. E. M. Fahad Al Ruwaily, Ambassadeur d¿Arabie saoudite en France 	\N	2021-07-22 13:00:00	2021-07-22 14:30:00	\N	\N	1	0	661	\N
582566	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2021-07-22 10:20:00	2021-07-22 12:50:00	\N	\N	3	0	\N	\N
582631	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Prorogation de l'état d'urgence sanitaire dans les outre-mer (rapport et texte)	PJL Prorogation de l'état d'urgence sanitaire dans les outre-mer (rapport et texte)	2021-09-08 15:00:00	2021-09-08 15:35:00	2021-09-08 15:51:15	2021-09-08 17:42:34	21	0	\N	\N
582645	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PPL Protéger la rémunération des agriculteurs	Auditions PPL Protéger la rémunération des agriculteurs	2021-08-31 09:00:00	2021-08-31 10:00:00	\N	\N	11	0	\N	\N
514320	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Transport de marchandises-Réunion constitutive	MI Transport de marchandises face aux impératifs environnementaux-Réunion constitutive	2020-12-08 13:30:00	2020-12-08 14:00:00	\N	\N	11	0	\N	\N
514653	GIA	AUCUNE	\N	\N	\N	AG reconstitutive	\N	2020-12-08 09:45:00	2020-12-08 10:15:00	\N	\N	14	0	661	\N
514670	GIA	AUCUNE	\N	\N	\N	assemblée générale reconstitutive	\N	2020-12-08 14:15:00	2020-12-08 14:35:00	\N	\N	8	0	613	\N
517640	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Sécurité globale	\N	2020-12-15 14:00:00	2020-12-15 18:00:00	\N	\N	5	0	\N	\N
531263	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition FNCCR	Audition FNCCR	2021-02-10 15:30:00	2021-02-10 16:30:00	\N	\N	2	0	\N	\N
531272	GIA	AUCUNE	\N	\N	\N	Entretien avec Bertrand Lortholary, directeur de l'Asie et de l'Océanie au MAE	tretien avec Bertrand Lortholary, directeur de l'Asie et de l'Océanie au ministère des affaires étrangères	2021-02-11 11:00:00	2021-02-11 12:25:00	\N	\N	13	0	651	\N
531296	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de Michel Barnier	\N	2021-02-16 17:35:00	2021-02-16 19:15:00	2021-02-17 09:12:08	2021-02-17 18:09:05	23	0	\N	\N
531297	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition Ambassadeur d'Allemagne en France	\N	2021-02-17 10:05:00	2021-02-17 11:30:00	2021-02-17 15:55:25	2021-02-17 18:09:01	30	0	\N	\N
531298	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition GT Agriculteurs en détresse	Audition GT Agriculteurs en détresse	2021-02-10 13:30:00	2021-02-10 14:45:00	\N	\N	8	0	\N	\N
531307	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Réunion GT Agriculteurs en détresse	Réunion GT Agriculteurs en détresse	2021-02-10 16:30:00	2021-02-10 17:30:00	\N	\N	4	0	\N	\N
531312	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions PPL Sécurité globale	Auditions rapporteur pour avis PPL Sécurité globale	2021-02-11 08:45:00	2021-02-11 10:30:00	\N	\N	1	0	\N	\N
532038	GIA	AUCUNE	\N	\N	\N	Audition de M. Benjamin Stora	Audition de M. Benjamin Stora, autour de son rapport sur la mémoire de la colonisation et de la guerre d'Algérie	2021-02-16 16:30:00	2021-02-16 17:30:00	\N	\N	5	0	575	\N
534260	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	211	Réunion rapporteurs - "Femmes et ruralités"	Réunion rapporteurs - "Femmes et ruralités"	2021-02-17 13:00:00	2021-02-17 14:00:00	\N	\N	6	0	\N	\N
537524	COM_PERMANENTE	GROUPE_TRAVAIL	\N	ETRD	\N	Groupe de travail Drones	Groupe de travail Drones	2021-03-09 16:00:00	2021-03-09 17:00:00	\N	\N	4	0	\N	\N
540471	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition Damien Cuier et Gilles Duffau (Pass Culture)	\N	2021-03-17 09:30:00	2021-03-17 11:15:00	2021-03-17 12:53:52	2021-03-17 16:58:59	26	0	\N	\N
540503	MISSION	AUDRAP	\N	METHANIS	\N	Audition Négawatt	Audition Négawatt	2021-03-15 14:45:00	2021-03-15 15:30:00	\N	\N	4	0	\N	\N
541389	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Respect des principes de la République (rapport et texte de la commission - suite)	PJL Respect des principes de la République (rapport et texte de la commission - suite)	2021-03-17 20:30:00	2021-03-17 21:25:00	2021-03-17 21:50:34	2021-03-18 17:52:17	20	0	\N	\N
541460	MISSION	AUCUNE	\N	ENSAGRIC	\N	Auditions UNMFREO et CNEAP	\N	2021-03-17 16:36:00	2021-03-17 19:05:00	2021-03-17 19:57:18	2021-03-18 17:53:08	13	0	\N	\N
541514	DELEGATION	AUDRAP	\N	\N	PROS	Audition de M. Cyrille Isaac-Sibille, député	Audition de M. Cyrille Isaac-Sibille, député	2021-03-23 16:00:00	2021-03-23 17:00:00	\N	\N	3	0	\N	\N
555420	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière - Audition publique brevets Covid-19	Réunion plénière - Audition publique brevets Covid-19	2021-06-17 10:05:00	2021-06-17 12:45:00	\N	\N	10	0	\N	\N
559988	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL CLimat et résilience - FNCCR	Audition PJL CLimat et résilience - FNCCR	2021-05-03 09:30:00	2021-05-03 10:00:00	\N	\N	1	0	\N	\N
555421	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière - Audition publique recherche en biologie-santé	Réunion plénière - Audition publique recherche en biologie-santé	2021-06-24 10:40:00	2021-06-24 12:45:00	\N	\N	9	0	\N	\N
555422	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière - Audition IRSN	Réunion plénière - Audition IRSN	2021-07-01 09:00:00	2021-07-01 12:00:00	\N	\N	0	0	\N	\N
555423	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière - Examen rapport ASTRID - Audition CNE2	Réunion plénière - Examen rapport ASTRID - Audition CNE2	2021-07-08 09:15:00	2021-07-08 12:20:00	\N	\N	13	0	\N	\N
559421	GIA	AUCUNE	\N	\N	\N	Audition de M. Alexandre Garcia, Ambassadeur de France au Niger	\N	2021-05-12 14:05:00	2021-05-12 14:55:00	\N	\N	2	0	573	\N
562227	MISSION	AUCUNE	\N	VIETUDIA	\N	Audition Président CNPH	\N	2021-05-27 11:06:00	2021-05-27 11:55:00	2021-05-27 13:56:08	2021-05-27 17:04:07	7	0	\N	\N
562228	MISSION	AUDRAP	\N	VIETUDIA	\N	Table ronde Etudiants français à l'étranger	Situation des étudiants français à l'étranger et conséquences de la pandémie de Covid 19	2021-05-19 13:30:00	2021-05-19 15:19:00	\N	\N	15	0	\N	\N
565125	GIA	AUCUNE	\N	\N	\N	Entretien résidence ambassadeur Ghasemi	Entretien à la résidence avec l'ambassadeur d'Iran en France	2021-05-19 12:00:00	2021-05-19 14:15:00	\N	\N	4	0	628	\N
565151	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ambassadeur de France en Suède	Entretien en visioconférence avec l'ambassadeur de France en Suède	2021-05-26 17:30:00	2021-05-26 19:00:00	\N	\N	8	0	625	\N
565161	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ambassadeur de France en Suède en Islande	Entretien en visioconférence avec l'ambassadeur de France en Suède en Islande	2021-06-01 17:10:00	2021-06-01 18:35:00	\N	\N	8	0	625	\N
570738	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	ppl ticket restaurant	\N	2021-05-19 16:30:00	2021-05-19 17:30:00	\N	\N	4	0	\N	\N
570744	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	ppl ticket restaurant	\N	2021-05-19 17:30:00	2021-05-19 18:15:00	\N	\N	5	0	\N	\N
570751	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	ppl ticket restaurant	\N	2021-05-19 18:15:00	2021-05-19 18:48:00	\N	\N	4	0	\N	\N
570756	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	ppl ticket restaurant	\N	2021-05-19 18:48:00	2021-05-19 19:10:00	\N	\N	2	0	\N	\N
570759	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	ppl ticket	\N	2021-05-25 09:30:00	2021-05-25 10:30:00	\N	\N	2	0	\N	\N
570766	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	ppl ticket restaurant	\N	2021-05-25 10:30:00	2021-05-25 11:05:00	\N	\N	2	0	\N	\N
570769	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	ppl ticket restaurant	\N	2021-05-27 09:30:00	2021-05-27 10:45:00	\N	\N	5	0	\N	\N
570775	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	ppl ticket	\N	2021-05-27 10:45:00	2021-05-27 11:10:00	\N	\N	3	0	\N	\N
570786	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	ppl ticket	\N	2021-05-27 11:10:00	2021-05-27 11:30:00	\N	\N	3	0	\N	\N
570790	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	ppl ticket	\N	2021-05-27 11:30:00	2021-05-27 12:10:00	\N	\N	2	0	\N	\N
570914	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI Cvec	\N	2021-04-20 12:30:00	2021-04-20 13:38:00	\N	\N	2	0	\N	\N
570922	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI Cvec	\N	2021-04-20 13:38:00	2021-04-20 14:20:00	\N	\N	2	0	\N	\N
570927	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI Cvec	\N	2021-05-04 12:00:00	2021-05-04 13:15:00	\N	\N	3	0	\N	\N
570934	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI Cv	\N	2021-05-11 12:30:00	2021-05-11 13:50:00	\N	\N	2	0	\N	\N
570943	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI Cvec	\N	2021-05-25 12:30:00	2021-05-25 13:20:00	\N	\N	2	0	\N	\N
570946	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI Cvec	\N	2021-05-25 13:20:00	2021-05-25 14:44:00	\N	\N	4	0	\N	\N
570955	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI Cvec	\N	2021-06-15 12:30:00	2021-06-15 13:30:00	\N	\N	2	0	\N	\N
570958	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI Cvec	\N	2021-06-15 13:30:00	2021-06-15 14:15:00	\N	\N	0	0	\N	\N
573711	MISSION	AUTRE	\N	CONF	\N	Présentation de l'étude de TAJ	\N	2021-06-29 09:10:00	2021-06-29 10:15:00	2021-06-29 15:25:31	2021-06-29 17:17:42	7	0	\N	\N
573760	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition psychiatres	\N	2021-07-08 17:00:00	2021-07-08 18:00:00	\N	\N	4	0	\N	\N
573762	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition associations d'écoute	\N	2021-07-08 16:00:00	2021-07-08 17:00:00	\N	\N	2	0	\N	\N
577247	ETUDES	AUCUNE	\N	\N	\N	Audition Pr Moutou	Audition Pr Moutou	2021-07-07 13:30:00	2021-07-07 14:55:00	\N	\N	11	0	\N	1011
581925	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT Puissance chinoise en Europe	\N	2021-07-21 14:00:00	2021-07-21 16:00:00	\N	\N	1	0	\N	\N
581927	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT Puissance chinoise en Europe	\N	2021-07-21 17:00:00	2021-07-21 18:15:00	\N	\N	2	0	\N	\N
590821	MISSION	AUCUNE	\N	CONF	\N	Audition de M. Sébastien Lecornu, ministre des Outre-mer	Audition de M. Sébastien Lecornu, ministre des Outre-mer	2021-10-08 09:30:00	2021-10-08 11:10:00	2021-10-08 11:22:49	2021-10-08 18:04:50	15	0	\N	\N
585848	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Vaccination obligatoire - Table ronde Politique sanitaire en Nouvelle-Calédonie	\N	2021-09-23 09:00:00	2021-09-23 10:15:00	\N	\N	1	0	\N	\N
588593	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI « Sécurité à Mayotte »	Audition rapporteur - MI « Sécurité à Mayotte »	2021-10-04 09:05:00	2021-10-04 10:15:00	\N	\N	3	0	\N	\N
588597	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI « Sécurité à Mayotte »	Audition rapporteur - MI « Sécurité à Mayotte »	2021-10-04 10:15:00	2021-10-04 11:05:00	\N	\N	2	0	\N	\N
588600	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI « Sécurité à Mayotte »	Audition rapporteur - MI « Sécurité à Mayotte »	2021-10-04 11:05:00	2021-10-04 12:05:00	\N	\N	3	0	\N	\N
590377	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Responsabilité pénale et sécurité intérieure	\N	2021-10-05 14:30:00	2021-10-05 17:00:00	\N	\N	2	0	\N	\N
590381	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Responsabilité pénale et sécurité intérieure	\N	2021-10-05 17:00:00	2021-10-05 17:45:00	\N	\N	1	0	\N	\N
593366	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Convention Traité sur l¿Antarctique relatif à la protection de l¿environnement	\N	2021-10-14 15:00:00	2021-10-14 15:45:00	\N	\N	1	0	\N	\N
593439	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Responsabilité pénale	PJL Responsabilité pénale	2021-10-18 16:00:00	2021-10-18 20:30:00	\N	\N	33	0	\N	\N
593441	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2021-10-19 09:40:00	2021-10-19 12:55:00	\N	\N	51	0	\N	\N
593442	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Responsabilité pénale	PJL Responsabilité pénale	2021-10-19 14:30:00	2021-10-19 16:55:00	\N	\N	94	0	\N	\N
593444	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2021-10-20 15:00:00	2021-10-20 16:20:00	\N	\N	262	0	\N	\N
593446	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Fonction de directrice ou de directeur d'école	PPL fonction de directrice ou de directeur d'école	2021-10-20 16:35:00	2021-10-20 19:10:00	\N	\N	103	0	\N	\N
593447	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Réformer l'adoption	PPL Réformer l'adoption	2021-10-20 19:20:00	2021-10-20 20:00:00	\N	\N	48	0	\N	\N
593449	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Réformer l'adoption	PPL Réformer l'adoption	2021-10-20 21:35:00	2021-10-21 01:10:00	\N	\N	46	0	\N	\N
593460	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Catastrophes naturelles	PPL Catastrophes naturelles	2021-10-21 10:30:00	2021-10-21 13:10:00	\N	\N	57	0	\N	\N
593701	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2022 - Programme 129	\N	2021-10-13 17:30:00	2021-10-13 19:15:00	\N	\N	2	0	\N	\N
593795	GIA	AUCUNE	\N	\N	\N	Audition en visiconférence - Conseil de la Fédération/Sénat	Audition en visiconférence - Conseil de la Fédération/Sénat	2021-10-19 15:00:00	2021-10-19 16:45:00	\N	\N	11	0	608	\N
594525	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur  PJL Dialogue social avec les plateformes	\N	2021-10-20 14:00:00	2021-10-20 15:00:00	\N	\N	2	0	\N	\N
594533	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition PLF - MILDECA - MILDECA	\N	2021-10-26 15:00:00	2021-10-26 16:00:00	\N	\N	1	0	\N	\N
594534	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition PLF MILDECA - OFDT	\N	2021-10-26 16:00:00	2021-10-26 17:00:00	\N	\N	1	0	\N	\N
594908	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2021-10-26 14:00:00	2021-10-26 14:30:00	2021-10-26 14:53:45	2021-10-26 18:03:10	20	0	\N	\N
594909	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition plénière	\N	2021-10-26 09:50:00	2021-10-26 10:50:00	2021-10-26 12:02:17	2021-10-26 18:03:09	50	0	\N	\N
594912	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2021-10-27 09:30:00	2021-10-27 12:35:00	2021-10-28 10:57:48	2021-10-28 15:42:59	38	0	\N	\N
594914	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2021-10-28 10:00:00	2021-10-28 11:45:00	2021-10-28 12:39:11	2021-10-28 15:42:57	35	0	\N	\N
594915	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2021-10-28 14:50:00	2021-10-28 14:55:00	2021-10-28 15:31:28	2021-10-28 15:42:56	6	0	\N	\N
594919	COM_PERMANENTE	AUTRE	\N	CAE	\N	Examen des éventuels amendements de séance	\N	2021-10-26 14:30:00	2021-10-26 14:50:00	2021-10-26 16:48:46	2021-10-26 18:03:11	25	0	\N	\N
594920	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition M. Bernard Bigot 	\N	2021-10-27 09:30:00	2021-10-27 11:30:00	2021-10-27 11:54:14	2021-10-27 19:08:46	42	0	\N	\N
594978	ETUDES	AUTRE	\N	\N	\N	Audition du Médiateur national de l'énergie	Audition du Médiateur national de l'énergie	2021-10-20 13:30:00	2021-10-20 15:00:00	\N	\N	18	0	\N	906
595507	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désignations CMP - Rapports législisatifs - Rapport d'information Sécurité à Mayotte	Désignations CMP - Rapports législisatifs - Rapport d'information Sécurité à Mayotte	2021-10-27 08:30:00	2021-10-27 11:55:00	2021-10-27 19:02:07	2021-10-27 19:08:48	40	0	\N	\N
598994	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2022 - Programme 146	\N	2021-10-26 14:00:00	2021-10-26 15:00:00	\N	\N	2	0	\N	\N
598998	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2022 - Programme 146	\N	2021-10-27 14:00:00	2021-10-27 15:00:00	\N	\N	2	0	\N	\N
599002	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2022 - Programme 146	\N	2021-10-27 16:30:00	2021-10-27 17:30:00	\N	\N	2	0	\N	\N
599700	GIA	AUCUNE	\N	\N	\N	audition de S.E. Mme Hen AL OTAIBA, ambassadrice des Emirats arabes unis en France	\N	2021-11-03 13:00:00	2021-11-03 14:30:00	\N	\N	2	0	661	\N
600416	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR Agenda rural	PPR Agenda rural	2021-11-04 10:30:00	2021-11-04 11:55:00	\N	\N	53	0	\N	\N
600649	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière	Réunion plénière	2021-11-04 09:05:00	2021-11-04 10:15:00	2021-11-04 15:13:13	\N	6	0	\N	\N
602943	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2022 - Avis "Immigration, asile et intégration"	\N	2021-11-09 15:30:00	2021-11-09 16:30:00	\N	\N	2	0	\N	\N
602946	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2022 - Avis "Immigration, asile et intégration"	\N	2021-11-10 10:30:00	2021-11-10 12:00:00	\N	\N	3	0	\N	\N
602951	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2022 - Avis "Immigration, asile et intégration"	\N	2021-11-10 14:00:00	2021-11-10 15:00:00	\N	\N	2	0	\N	\N
602963	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2022 - Avis "Immigration, asile et intégration"	\N	2021-11-10 16:00:00	2021-11-10 17:00:00	\N	\N	2	0	\N	\N
603264	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	LPM	\N	2021-11-09 14:30:00	2021-11-09 16:00:00	\N	\N	7	0	\N	\N
603277	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2022 - Programme 144	\N	2021-11-09 16:00:00	2021-11-09 18:00:00	\N	\N	2	0	\N	\N
603282	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2022 - Programme 151	\N	2021-11-09 18:00:00	2021-11-09 19:00:00	\N	\N	2	0	\N	\N
603285	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2022 - Programme 151	\N	2021-11-10 16:30:00	2021-11-10 17:30:00	\N	\N	2	0	\N	\N
603288	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	PLF pour 2022 - Programme 105	\N	2021-11-08 17:00:00	2021-11-08 18:30:00	\N	\N	1	0	\N	\N
603290	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2022 - Programme 178	\N	2021-11-09 16:00:00	2021-11-09 17:20:00	\N	\N	2	0	\N	\N
512101	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Comité de suivi Suez-Veolia - FNCCR	Comité de suivi Suez-Veolia - FNCCR	2020-12-02 14:05:00	2020-12-02 15:05:00	\N	\N	5	0	\N	\N
512691	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Supprimer la possibilité de rachat par le dirigeant après le dépôt de bilan	PPL Supprimer la possibilité de rachat par le dirigeant après le dépôt de bilan	2020-11-17 16:30:00	2020-11-17 18:15:00	\N	\N	1	0	\N	\N
512696	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Supprimer la possibilité de rachat par le dirigeant après le dépôt de bilan	PPL Supprimer la possibilité de rachat par le dirigeant après le dépôt de bilan	2020-12-18 13:30:00	2020-12-18 14:00:00	\N	\N	2	0	\N	\N
512699	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Supprimer la possibilité de rachat par le dirigeant après le dépôt de bilan	PPL Supprimer la possibilité de rachat par le dirigeant après le dépôt de bilan	2020-11-18 14:15:00	2020-11-18 15:00:00	\N	\N	1	0	\N	\N
512701	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Supprimer la possibilité de rachat par le dirigeant après le dépôt de bilan	PPL Supprimer la possibilité de rachat par le dirigeant après le dépôt de bilan	2020-11-18 16:30:00	2020-11-18 17:30:00	\N	\N	1	0	\N	\N
521574	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de M. Gérard Mestrallet	\N	2021-01-20 09:30:00	2021-01-20 11:00:00	2021-01-22 15:06:42	2021-01-22 15:31:55	72	0	\N	\N
521575	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition article 13 Arcep	\N	2021-01-20 16:35:00	2021-01-20 17:45:00	2021-01-22 15:08:47	2021-01-22 15:32:02	26	0	\N	\N
523462	GIA	AUCUNE	\N	\N	\N	Audition de M. Jean-Baptiste Noé	Audition de M. Jean-Baptiste Noé sur la géopolitique du Vatican	2021-01-20 13:30:00	2021-01-20 14:45:00	\N	\N	21	0	629	\N
526727	COM_SPECIALE	AUTRE	\N	BIOETHIQUE	\N	Réunion 20210202a	\N	2021-02-02 08:00:00	2021-02-02 09:40:00	2021-02-03 11:34:58	2021-02-05 15:34:08	26	0	\N	\N
526730	COM_PERMANENTE	AUTRE	\N	AFCL	\N	PPL Fondation du Patrimoine - LEC	\N	2021-02-17 14:00:00	2021-02-17 14:45:00	2021-02-17 15:55:32	2021-02-17 18:09:01	31	0	\N	\N
526731	DELEGATION	AUDRAP	\N	\N	PROS	Audition de Laetitia Dablanc	\N	2021-02-10 17:30:00	2021-02-10 18:30:00	\N	\N	1	0	\N	\N
537178	MISSION	AUCUNE	\N	ENSAGRIC	\N	Table ronde sur l'orientation vers l'enseignement agricole et son attractivité	\N	2021-03-10 16:35:00	2021-03-10 18:30:00	2021-03-10 18:32:34	2021-03-11 18:52:27	13	0	\N	\N
537338	MISSION	AUTRE	\N	VIETUDIA	\N	Audition Mme Monique Ronzeau OVE	\N	2021-03-10 14:00:00	2021-03-10 17:00:00	\N	\N	0	0	\N	\N
537380	MISSION	AUCUNE	\N	VIETUDIA	\N	Audition de Mme Ronzeau	\N	2021-03-11 14:00:00	2021-03-11 15:55:00	2021-03-11 16:56:15	2021-03-11 18:52:28	16	0	\N	\N
537394	DELEGATION	AUCUNE	\N	\N	211	Audition sur le thème des conditions de vie des jeunes femmes dans les territoires rurau	Audition sur le thème des conditions de vie des jeunes femmes dans les territoires rurau	2021-03-18 09:00:00	2021-03-18 10:25:00	2021-03-18 11:13:34	\N	11	0	\N	\N
537395	DELEGATION	AUCUNE	\N	\N	211	Audition de M. Joël Giraud et de Mme Élisabeth Moreno	Audition de M. Joël Giraud et de Mme Élisabeth Moreno	2021-05-05 17:00:00	2021-05-05 18:30:00	2021-05-05 19:23:54	\N	9	0	\N	\N
537399	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière	\N	2021-03-18 10:05:00	2021-03-18 11:05:00	2021-03-18 11:57:55	\N	17	0	\N	\N
543088	MISSION	AUDRAP	\N	VIETUDIA	\N	Audition Etienne Loos Ecole de Management	\N	2021-03-22 10:00:00	2021-03-22 10:55:00	\N	\N	9	0	\N	\N
543089	MISSION	AUDRAP	\N	VIETUDIA	\N	audition Magali Danican Science O	\N	2021-03-22 11:05:00	2021-03-22 11:56:00	\N	\N	9	0	\N	\N
543090	MISSION	AUDRAP	\N	VIETUDIA	\N	Audition Collectif Etudiants Fantômes	\N	2021-03-22 14:00:00	2021-03-22 15:00:00	\N	\N	6	0	\N	\N
543092	MISSION	AUDRAP	\N	VIETUDIA	\N	Audition Forume de la Jeunesse	\N	2021-03-22 15:00:00	2021-03-22 16:30:00	\N	\N	0	0	\N	\N
543093	MISSION	AUDRAP	\N	VIETUDIA	\N	Audition Zinat Nguyen Ambition campus	\N	2021-03-22 16:15:00	2021-03-22 17:45:00	\N	\N	5	0	\N	\N
543152	COM_PERMANENTE	AUTRE	\N	AFCL	\N	PJL Principes de la République - Amdts de séance	\N	2021-03-30 09:30:00	2021-03-30 10:28:00	2021-03-30 13:16:51	2021-03-30 16:53:33	30	0	\N	\N
543154	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Réforme de la formation des élus locaux - Table ronde association d'élus	PJL Réforme de la formation des élus locaux - Table ronde association d'élus	2021-03-22 15:00:00	2021-03-22 15:55:00	\N	\N	2	0	\N	\N
543157	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Réforme de la formation des élus locaux - FNOFEL	PJL Réforme de la formation des élus locaux - FNOFEL	2021-03-22 16:00:00	2021-03-22 17:05:00	\N	\N	2	0	\N	\N
543160	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	 PJL Réforme de la formation des élus locaux - DGCL	PJL Réforme de la formation des élus locaux - DGCL	2021-03-22 17:05:00	2021-03-22 18:00:00	\N	\N	2	0	\N	\N
543163	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Réforme de la formation des élus locaux - CNFEL	PJL Réforme de la formation des élus locaux - CNFEL	2021-03-22 18:00:00	2021-03-22 18:35:00	\N	\N	1	0	\N	\N
543173	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes	\N	2021-03-31 14:00:00	2021-03-31 15:00:00	2021-03-31 17:16:47	2021-03-31 18:03:23	22	0	\N	\N
543174	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 1er avril 2021	Réunion du 1er avril 2021	2021-04-01 10:40:00	2021-04-01 12:35:00	2021-04-01 17:54:19	2021-04-02 09:22:28	20	0	\N	\N
543175	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes	\N	2021-03-30 15:00:00	2021-03-30 17:00:00	2021-04-02 11:19:43	2021-04-02 14:45:38	57	0	\N	\N
543190	ETUDES	AUTRE	\N	\N	\N	GEAC - Programme des réunions du groupe d'études	GEAC - Programme des réunions du groupe d'études	2021-03-31 08:00:00	2021-03-31 09:00:00	\N	\N	6	0	\N	933
543399	MISSION	AUCUNE	\N	PAUP	\N	Auditions plénières	\N	2021-03-23 14:30:00	2021-03-23 17:10:00	2021-03-24 10:40:49	2021-03-24 17:39:38	9	0	\N	\N
554258	GIA	AUCUNE	\N	\N	\N	Audience de  S.E M. Faure GNASSINGBÉ, Président de la République togolaise	Audience de  S.E M. Faure GNASSINGBÉ, Président de la République togolaise, par le Président Gérard LARCHER	2021-04-09 15:30:00	2021-04-09 16:30:00	\N	\N	1	0	573	\N
559970	MISSION	AUDRAP	\N	ENSAGRIC	\N	Table ronde avec les syndicats de l'enseignement agricole public	\N	2021-05-18 14:30:00	2021-05-18 16:25:00	\N	\N	7	0	\N	\N
559971	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Climat et résilience "Se loger" - Table ronde Amorce / CLER / Flame / FNCAUE	PJL Climat et résilience "Se loger" - Table ronde Amorce / CLER / Flame / FNCAUE	2021-05-17 15:00:00	2021-05-17 16:00:00	\N	\N	1	0	\N	\N
559972	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL Climat et résilience "Se loger" - Union sociale pour l'habitat	Audition PJL Climat et résilience "Se loger" - Union sociale pour l'habitat	2021-05-17 16:00:00	2021-05-17 16:45:00	\N	\N	2	0	\N	\N
559973	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Climat et résilience "Se loger" - Table ronde CSCEE / CSE	PJL Climat et résilience "Se loger" - Table ronde CSCEE / CSE	2021-05-17 16:45:00	2021-05-17 17:30:00	\N	\N	1	0	\N	\N
559974	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL Climat et résilience "Se loger" - Smart avenir green	Audition PJL Climat et résilience "Se loger" - Smart avenir green	2021-05-17 17:30:00	2021-05-17 17:50:00	\N	\N	1	0	\N	\N
559981	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL Climat et résilience "Se loger" - DGEC	Audition PJL Climat et résilience "Se loger" - DGEC	2021-05-18 09:00:00	2021-05-18 09:45:00	\N	\N	1	0	\N	\N
559985	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Climat et résilience - Audition Office national des forêts	PJL Climat et résilience - Audition Office national des forêts	2021-04-20 09:45:00	2021-04-20 10:15:00	\N	\N	0	0	\N	\N
559986	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL CLimat et résilience - Direction des affaires criminelles et des grâces	Audition PJL CLimat et résilience - Direction des affaires criminelles et des grâces	2021-04-20 12:30:00	2021-04-20 13:00:00	\N	\N	1	0	\N	\N
559989	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL Climat - Fédération des entreprises locales de distribution	Audition PJL Climat - Fédération des entreprises locales de distribution	2021-05-03 10:00:00	2021-05-03 10:30:00	\N	\N	1	0	\N	\N
559990	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL Climat - Table ronde élus locaux AMF AdCF RDF	Audition PJL Climat - Table ronde élus locaux AMF AdCF RDF	2021-05-03 10:30:00	2021-05-03 11:00:00	\N	\N	1	0	\N	\N
559991	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL Climat - Union française de l'électricité (UFE)	Audition PJL Climat - Union française de l'électricité (UFE)	2021-05-03 11:00:00	2021-05-03 11:30:00	\N	\N	1	0	\N	\N
582646	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PPL Protéger la rémunération des agriculteurs	Auditions PPL Protéger la rémunération des agriculteurs	2021-08-31 10:00:00	2021-08-31 11:15:00	\N	\N	9	0	\N	\N
583205	MISSION	AUCUNE	\N	UBER	\N	\N	\N	2021-09-14 09:05:00	2021-09-14 10:30:00	2021-09-14 13:55:06	2021-09-15 17:27:26	7	0	\N	\N
583247	MISSION	AUDRAP	\N	INFLUENCES	\N	Audition M. Philippe Le Corre	\N	2021-09-13 16:10:00	2021-09-13 17:15:00	\N	\N	3	0	\N	\N
583251	MISSION	AUDRAP	\N	INFLUENCES	\N	Audition Mme Balme	\N	2021-09-13 17:15:00	2021-09-13 18:30:00	\N	\N	2	0	\N	\N
583340	MISSION	AUCUNE	\N	EGALCHAN	\N	Réunion plénière MI égalité des chances	\N	2021-09-23 15:04:00	2021-09-23 15:56:00	2021-09-23 16:23:45	2021-09-24 18:56:40	5	0	\N	\N
583371	MISSION	AUDRAP	\N	INFLUENCES	\N	 M. Jean-François Huchet, président de l'INALCO	\N	2021-09-15 12:00:00	2021-09-15 13:08:00	\N	\N	4	0	\N	\N
583421	MISSION	AUTRE	\N	HARCEL	\N	Examen de rapport d¿information	\N	2021-09-21 16:00:00	2021-09-21 18:30:00	\N	\N	0	0	\N	\N
583427	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition Mme Laurent, présidente de l'AFLD	Commission de la culture - Audition Mme Laurent, présidente de l'AFLD	2021-09-15 09:30:00	2021-09-15 10:50:00	2021-09-15 17:49:10	2021-09-16 20:49:05	23	0	\N	\N
583454	COM_PERMANENTE	AUTRE	\N	CAE	\N	\N	\N	2021-09-22 09:30:00	2021-09-22 12:30:00	2021-09-23 14:27:43	2021-09-23 18:31:15	44	0	\N	\N
583455	COM_PERMANENTE	AUTRE	\N	CAE	\N	Amendements de séance PPL Egalim 2	\N	2021-09-21 14:05:00	2021-09-21 14:35:00	2021-09-21 15:02:54	2021-09-21 17:24:49	34	0	\N	\N
583456	COM_PERMANENTE	AUTRE	\N	FINC	\N	Contrôles budgétaires Météo-France et Immobilier universitaire et désignation rapporteur	Contrôles budgétaires Météo-France et Immobilier universitaire et désignation rapporteur PPL 325	2021-09-22 09:30:00	2021-09-22 11:20:00	2021-09-22 14:48:22	2021-09-22 18:40:13	36	0	\N	\N
583457	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2022 - Audition de M. Pierre MOSCOVICI, président du HCFP	PLF pour 2022 - Audition de M. Pierre MOSCOVICI, président du HCFP	2021-09-22 11:35:00	2021-09-22 12:45:00	2021-09-22 14:48:33	2021-09-22 18:40:18	31	0	\N	\N
583458	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2022 : Audition de M. Bruno LE MAIRE et de M. Olivier DUSSOPT, Ministres	PLF pour 2022 : Audition de M. Bruno LE MAIRE et de M. Olivier DUSSOPT, Ministres	2021-09-22 17:00:00	2021-09-22 18:20:00	2021-09-22 21:21:59	2021-09-23 18:31:19	29	0	\N	\N
583461	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Réélection des juges consulaires dans les tribunaux de commerce (amendements)	PPL Réélection des juges consulaires dans les tribunaux de commerce (amendements)	2021-09-21 14:00:00	2021-09-21 14:05:00	2021-09-21 14:19:57	2021-09-21 17:24:47	11	0	\N	\N
583462	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de M. Serge Lasvignes, candidat à la présidence de la CNCTR	Audition de M. Serge Lasvignes, candidat à la présidence de la CNCTR	2021-09-22 08:35:00	2021-09-22 09:20:00	2021-09-22 11:01:22	2021-09-22 18:40:11	30	0	\N	\N
583463	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Volontariat des sapeurs-pompiers (amendements) - Communication	PPL Volontariat des sapeurs-pompiers (amendements) - Communication	2021-09-22 09:35:00	2021-09-22 11:00:00	\N	\N	30	0	\N	\N
583464	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Candidature présidence CNCTR - dépouillement des scrutins	Candidature présidence CNCTR - dépouillement des scrutins	2021-09-22 12:00:00	2021-09-22 13:00:00	\N	\N	0	0	\N	\N
583467	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Déplacement Seine-et-Marne	Déplacement Seine-et-Marne	2021-09-10 09:00:00	2021-09-10 13:00:00	\N	\N	1	0	\N	\N
583470	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2021-09-22 09:30:00	2021-09-22 12:35:00	2021-09-22 12:39:52	2021-09-22 18:40:15	40	0	\N	\N
583614	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur - Préfet d'Harcourt	\N	2021-09-15 16:30:00	2021-09-15 17:30:00	\N	\N	2	0	\N	\N
583617	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur - Conseil National des Barreaux	\N	2021-09-16 11:00:00	2021-09-16 12:00:00	\N	\N	2	0	\N	\N
583620	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur	\N	2021-09-16 16:30:00	2021-09-16 18:00:00	\N	\N	2	0	\N	\N
583624	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur - SISTA	\N	2021-09-21 17:00:00	2021-09-21 17:45:00	\N	\N	1	0	\N	\N
583625	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Rapporteur - AFEP	\N	2021-09-21 16:00:00	2021-09-21 17:00:00	\N	\N	1	0	\N	\N
583626	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur	\N	2021-09-17 12:00:00	2021-09-17 12:45:00	\N	\N	2	0	\N	\N
583629	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur - M.Molinos-Cobo	\N	2021-09-17 13:30:00	2021-09-17 14:45:00	\N	\N	2	0	\N	\N
583632	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur à Bruxelles	\N	2021-09-17 15:00:00	2021-09-17 16:45:00	\N	\N	2	0	\N	\N
583635	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur à Bruxelles	\N	2021-09-17 17:00:00	2021-09-17 17:45:00	\N	\N	2	0	\N	\N
583638	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur - députés européens	\N	2021-09-22 18:00:00	2021-09-22 19:00:00	\N	\N	0	0	\N	\N
583639	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Rapporteur - Frontex	\N	2021-09-24 09:30:00	2021-09-24 10:30:00	\N	\N	0	0	\N	\N
583763	MISSION	AUCUNE	\N	UBER	\N	Table ronde d'organisations syndicales	\N	2021-09-21 15:10:00	2021-09-21 17:00:00	2021-09-21 17:19:02	2021-09-21 17:24:53	7	0	\N	\N
583976	MISSION	AUCUNE	\N	UBER	\N	Audition de Mme Elisabeth BORNE	\N	2021-09-21 17:35:00	2021-09-21 18:45:00	2021-09-21 18:48:19	2021-09-22 18:46:09	16	0	\N	\N
584138	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-09-29 09:00:00	2021-09-29 12:09:00	2021-09-29 12:43:00	2021-09-29 18:17:41	37	0	\N	\N
584518	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Audition de M. Alain Griset	\N	2021-10-05 15:00:00	2021-10-05 16:30:00	\N	\N	17	0	\N	\N
584519	DELEGATION	AUCUNE	\N	\N	211	Examen du rapport d'information "Femmes et ruralités"	Examen du rapport d'information "Femmes et ruralités"	2021-10-14 08:30:00	2021-10-14 10:10:00	2021-10-14 10:07:44	\N	16	0	\N	\N
584520	MISSION	AUCUNE	\N	CONF	\N	Échanges de vues autour du programme de travail  	Échanges de vues autour du programme de travail  	2021-09-22 08:40:00	2021-09-22 09:15:00	2021-09-22 11:23:43	2021-09-22 18:46:10	9	0	\N	\N
585715	COM_PERMANENTE	AUTRE	\N	ETRD	\N	2 conventions et 2 auditions sur l'Afghanistan	\N	2021-09-29 09:45:00	2021-09-29 12:45:00	2021-09-29 14:43:01	2021-09-29 18:17:51	36	0	\N	\N
509416	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2020-11-26 09:00:00	2020-11-26 12:15:00	\N	\N	7	0	\N	\N
585716	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de M. Jean-Yves Le Drian	\N	2021-09-29 18:30:00	2021-09-29 20:10:00	2021-09-30 10:47:49	2021-09-30 18:41:55	29	0	\N	\N
585849	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Vaccination obligatoire - Table ronde d'autorités scientifiques	\N	2021-09-23 10:30:00	2021-09-23 11:30:00	\N	\N	1	0	\N	\N
585850	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Vaccination obligatoire - Table ronde enjeux éthiques et sociétaux	\N	2021-09-23 14:00:00	2021-09-23 15:00:00	\N	\N	1	0	\N	\N
585851	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Vaccination obligatoire - Audition du Dr Guillaume Barucq	\N	2021-09-24 10:30:00	2021-09-24 11:15:00	\N	\N	1	0	\N	\N
585852	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Vaccination obligatoire - Table ronde ARS Île-de-France et FHF	\N	2021-09-24 11:15:00	2021-09-24 12:15:00	\N	\N	1	0	\N	\N
586370	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 7 octobre 2021	Réunion du 7 octobre	2021-10-07 09:00:00	2021-10-07 09:55:00	2021-10-08 09:47:55	2021-10-08 18:04:49	14	0	\N	\N
586371	COM_EURO	AUTRE	\N	AFEU	\N	Stratégie numérique de l'UE - Communication	\N	2021-10-07 07:00:00	2021-10-07 08:00:00	\N	\N	0	0	\N	\N
586374	MISSION	AUCUNE	\N	CONF	\N	 Table ronde  spécificités des Outre-mer en matières sanitaire et économiques	 Table ronde  spécificités des Outre-mer en matières sanitaire et économiques	2021-09-28 09:00:00	2021-09-28 11:00:00	2021-09-28 15:17:20	2021-09-28 18:20:40	14	0	\N	\N
586380	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Intégration des jeunes majeurs étrangers	Audition	2021-09-27 15:00:00	2021-09-27 18:00:00	\N	\N	2	0	\N	\N
586490	MISSION	AUCUNE	\N	ENSAGRIC	\N	Examen du projet de rapport et adoption	\N	2021-09-29 16:30:00	2021-09-29 18:25:00	2021-10-01 09:00:37	2021-10-01 18:48:02	16	1	\N	\N
586794	DELEGATION	AUDRAP	\N	\N	PROS	Audition de rapporteur	\N	2021-09-28 15:15:00	2021-09-28 16:15:00	\N	\N	2	0	\N	\N
586797	DELEGATION	AUDRAP	\N	\N	PROS	Audition de rapporteur 	\N	2021-09-28 14:00:00	2021-09-28 15:00:00	\N	\N	2	0	\N	\N
587215	GIA	AUCUNE	\N	\N	\N	Entretien avec l'Ambassadeur d'Allemagne	\N	2021-09-29 08:30:00	2021-09-29 09:45:00	\N	\N	24	0	604	\N
588229	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Activité professionnelle indépendante - Audition d'Alain Griset, ministre délégué	PJL Activité professionnelle indépendante - Audition d'Alain Griset, ministre délégué	2021-10-05 15:00:00	2021-10-05 16:40:00	2021-10-05 19:28:31	2021-10-06 16:05:38	71	0	\N	\N
588230	COM_PERMANENTE	AUTRE	\N	LOIS	\N	MI Sécurité d'acheminement des communications d'urgence - Audition de Stéphane Richard	MI Sécurité d'acheminement des communications d'urgence - Audition de Stéphane Richard, président-directeur d'Orange	2021-10-05 17:15:00	2021-10-05 18:25:00	2021-10-05 19:28:46	2021-10-06 16:05:39	9	0	\N	\N
512952	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	NL PJLO CESE	NL PJLO CESE	2020-12-14 15:00:00	2020-12-14 16:10:00	\N	\N	16	0	\N	\N
512953	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	NL PJL Code de la sécurité intérieure	NL PJL Code de la sécurité intérieure	2020-12-14 16:15:00	2020-12-14 17:20:00	\N	\N	19	0	\N	\N
512995	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Conseillers de Guyane	PPL Conseillers de Guyane	2020-12-14 17:35:00	2020-12-14 18:25:00	\N	\N	14	0	\N	\N
513047	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Biens culturels	PJL Biens culturels	2020-12-15 14:30:00	2020-12-15 15:25:00	\N	\N	56	0	\N	\N
513048	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Conseil européen	Débat  Conseil européen	2020-12-15 15:25:00	2020-12-15 18:05:00	\N	\N	73	0	\N	\N
513049	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2020-12-16 15:00:00	2020-12-16 16:15:00	\N	\N	202	0	\N	\N
513050	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PJL Parquet européen	CMP PJL Parquet européen	2020-12-16 16:30:00	2020-12-16 17:30:00	\N	\N	48	0	\N	\N
513051	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	NL PLF pour 2021	NL PLF pour 2021	2020-12-16 17:30:00	2020-12-16 18:55:00	\N	\N	53	0	\N	\N
513055	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2020-12-15 18:20:00	2020-12-15 20:50:00	\N	\N	51	0	\N	\N
513056	SEANCE_PLENIERE	DECL_GVT	\N	\N	\N	Déclaration du Gouvernement Stratégie vaccinale	Déclaration du Gouvernement Stratégie vaccinale	2020-12-17 10:30:00	2020-12-17 12:45:00	\N	\N	88	0	\N	\N
518632	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2020-12-17 09:00:00	2020-12-17 10:30:00	\N	\N	2	0	\N	\N
531363	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Code mondial antidopage	PJL Code mondial antidopage	2021-02-16 14:30:00	2021-02-16 15:50:00	\N	\N	70	0	\N	\N
531364	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Ordonnances covid-19	PJL Ordonnances covid-19	2021-02-16 15:55:00	2021-02-16 17:40:00	\N	\N	74	0	\N	\N
531365	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Réforme du courtage	PPL Réforme du courtage	2021-02-16 17:45:00	2021-02-16 19:15:00	\N	\N	54	0	\N	\N
531369	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2021-02-17 15:00:00	2021-02-17 16:15:00	\N	\N	217	0	\N	\N
531371	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Système de santé	PPL Système de santé	2021-02-17 16:30:00	2021-02-17 20:05:00	\N	\N	92	0	\N	\N
531372	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PJL Report renouvellement conseils	CMP PJL Report renouvellement conseils	2021-02-16 21:00:00	2021-02-16 22:00:00	\N	\N	38	0	\N	\N
531373	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PJL Justice pénale des mineurs	CMP PJL Justice pénale des mineurs	2021-02-16 22:00:00	2021-02-16 22:55:00	\N	\N	30	0	\N	\N
531374	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Justice de proximité	PPL Justice de proximité	2021-02-18 14:30:00	2021-02-18 16:30:00	\N	\N	49	0	\N	\N
531375	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJLO Election du Pdt de la République	PJLO Election du Pdt de la République	2021-02-18 16:30:00	2021-02-18 20:20:00	\N	\N	42	0	\N	\N
537026	DELEGATION	AUCUNE	\N	\N	206	Rencontre Office-Académies sur le thème du Net zéro	Rencontre Office-Académies sur le thème du Net zéro	2021-03-10 08:30:00	2021-03-10 10:00:00	\N	\N	1	0	\N	\N
537027	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteur Outils de webconférence - Hicham et Nawal Abboub	Audition rapporteur Outils de webconférence - Hicham et Nawal Abboub	2021-03-15 10:00:00	2021-03-15 11:00:00	\N	\N	1	0	\N	\N
537030	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteur Outils de webconférence - Zoom Video Communications	Audition rapporteur Outils de webconférence - Zoom Video Communications	2021-03-15 11:00:00	2021-03-15 12:00:00	\N	\N	1	0	\N	\N
537032	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteur Outils de webconférence	Audition rapporteur Outils de webconférence	2021-03-05 11:00:00	2021-03-05 12:00:00	\N	\N	1	0	\N	\N
539088	MISSION	AUDRAP	\N	METHANIS	\N	Audition DGPE	Audition DGPE	2021-03-08 15:30:00	2021-03-08 16:20:00	\N	\N	7	0	\N	\N
539098	MISSION	AUDRAP	\N	METHANIS	\N	Audition DGPR	Audition DGPR	2021-03-08 17:30:00	2021-03-08 18:30:00	\N	\N	8	0	\N	\N
539586	MISSION	AUCUNE	\N	PAUP	\N	Réunion plénière	\N	2021-03-16 16:00:00	2021-03-16 18:55:00	2021-03-16 19:05:33	2021-03-17 17:02:10	11	0	\N	\N
539588	DELEGATION	AUTRE	\N	\N	DSOM	Réunion commune avec la délégation aux outre-mer de l'Assemblée nationale	\N	2021-03-18 14:30:00	2021-03-18 16:30:00	\N	\N	14	0	\N	\N
539601	DELEGATION	AUCUNE	\N	\N	211	Rencontre avec les skippeuses engagées dans l'édition 2020-2021 du Vendée Globe	Rencontre avec les skippeuses engagées dans l'édition 2020-2021 du Vendée Globe	2021-05-20 09:00:00	2021-05-20 11:00:00	2021-05-20 17:12:45	\N	13	0	\N	\N
539651	DELEGATION	AUDRAP	\N	\N	PROS	Audition d'IATA	\N	2021-03-22 10:00:00	2021-03-22 11:00:00	\N	\N	2	0	\N	\N
539652	MECSS	AUCUNE	\N	\N	MECSS	Réunion plénière - Audition du DG de l'Unédic	\N	2021-03-17 14:00:00	2021-03-17 14:50:00	2021-03-17 16:33:51	2021-03-17 16:59:03	14	0	\N	\N
539654	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Négociation collective - Audition de la CPME	\N	2021-03-10 13:00:00	2021-03-10 14:00:00	\N	\N	1	0	\N	\N
539655	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Négociation collective - Audition de l'ANDRH	\N	2021-03-10 14:00:00	2021-03-10 15:00:00	\N	\N	1	0	\N	\N
543955	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de M. Thierry Breton	\N	2021-03-30 15:00:00	2021-03-30 17:00:00	2021-03-31 18:22:44	2021-04-01 17:49:12	57	0	\N	\N
543958	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	Réunion de commission du 31 mars	2021-03-31 08:30:00	2021-03-31 12:35:00	2021-04-01 13:06:03	2021-04-01 17:49:11	44	0	\N	\N
543999	MISSION	AUDRAP	\N	METHANIS	\N	rapporteur	\N	2021-03-22 14:00:00	2021-03-22 17:30:00	\N	\N	0	0	\N	\N
544000	MISSION	AUDRAP	\N	METHANIS	\N	Audition ATE (ex-ADEME)	Audition ATE (ex-ADEME)	2021-03-22 14:00:00	2021-03-22 14:45:00	\N	\N	4	0	\N	\N
544144	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Transformation et fonction publiques - DIE	Contrôle 2021 - Transformation et fonction publiques - DIE	2021-03-23 18:20:00	2021-03-23 19:10:00	\N	\N	1	0	\N	\N
544157	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL n° 404 Développement solidaire - DACG/DGM	PJL n° 404 Développement solidaire - DACG/DGM	2021-03-23 15:00:00	2021-03-23 17:00:00	\N	\N	2	0	\N	\N
544337	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-03-30 17:35:00	2021-03-30 19:55:00	2021-03-31 12:37:02	2021-03-31 18:03:13	24	1	\N	\N
544339	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-03-31 09:30:00	2021-03-31 12:00:00	2021-03-31 12:34:51	2021-03-31 18:03:10	38	0	\N	\N
544620	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-03-24 16:48:00	2021-03-24 18:04:00	2021-03-25 14:42:35	2021-03-26 15:15:10	53	0	\N	\N
544625	COM_PERMANENTE	AUTRE	\N	FINC	\N	PPL389 : Examen Rapport pour Avis et Amdts au fond - PPL385 : Examen Rapport et Texte	PPL389 : Examen Rapport pour Avis et Amdts au fond - PPL385 : Examen Rapport et Texte	2021-03-31 09:30:00	2021-03-31 11:30:00	2021-03-31 12:25:55	2021-03-31 18:03:11	41	0	\N	\N
603485	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation du parlement suiédois	Accueil de membres du groupe d'amitié Suède-France du Riksdag suédois	2021-11-04 11:00:00	2021-11-04 14:30:00	\N	\N	5	0	625	\N
603491	GIA	AUCUNE	\N	\N	\N	Colloque franco-islandais sur l'hydrogène vert	Colloque franco-islandais sur l'hydrogène vert	2021-11-12 08:15:00	2021-11-12 13:15:00	\N	\N	1	0	625	\N
603632	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2022 - Avis "Juridictions financières et administratives"	\N	2021-11-15 18:15:00	2021-11-15 19:15:00	\N	\N	1	0	\N	\N
603634	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	PLF pour 2022 - Avis "Juridictions administratives et financières"	\N	2021-11-10 13:15:00	2021-11-10 18:30:00	\N	\N	1	0	\N	\N
603636	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	PLF pour 2022 - Avis "Juridictions administratives et financières"	\N	2021-11-16 16:30:00	2021-11-16 18:30:00	\N	\N	1	0	\N	\N
604323	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2022	\N	2021-11-09 09:00:00	2021-11-09 09:30:00	\N	\N	3	0	\N	\N
606020	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	DSOM	Rencontre avec les maires et les élus d'outre-mer	Rencontre avec les maires et les élus d'outre-mer, organisée par la Délégation sénatoriale aux outre-mer	2021-11-15 15:15:00	2021-11-15 18:15:00	\N	\N	17	0	\N	\N
606136	GIA	AUCUNE	\N	\N	\N	Entretien avec un maire népalais	Entretien avec M. Chiri Babu MAHARJAN, maire de Patan au Népal	2021-11-18 08:30:00	2021-11-18 09:45:00	\N	\N	1	0	633	\N
606230	DELEGATION	AUCUNE	\N	\N	206	Audition de la CNE2	\N	2021-11-25 10:30:00	2021-11-25 12:00:00	\N	\N	0	0	\N	\N
606464	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion pleinière CATDD	\N	2021-12-01 11:00:00	2021-12-01 12:30:00	2021-12-03 14:25:58	2021-12-08 16:36:10	32	0	\N	\N
606493	COM_EURO	AUDRAP	\N	AFEU	\N	Audition RP France auprès de l'UE - M. Primot	\N	2021-11-09 16:15:00	2021-11-09 17:15:00	\N	\N	2	0	\N	\N
606606	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2022 - Avis "Protection judiciaire de la jeunesse"	\N	2021-11-18 17:30:00	2021-11-18 17:45:00	\N	\N	1	0	\N	\N
607445	GIA	AUCUNE	\N	\N	\N	Audition de M. Emmanuel Lincot, professeur à l'Institut catholique de Paris	\N	2021-11-24 08:15:00	2021-11-24 09:30:00	\N	\N	4	0	619	\N
607490	GIA	AUCUNE	\N	\N	\N	Colloque sur l'Arménie 	L'Arménie, un an après... Bilan et perspectives 	2021-11-23 18:00:00	2021-11-23 21:00:00	\N	\N	16	0	CHRETORIENT	CHRETORIENT
607507	GIA	AUCUNE	\N	\N	\N	Audition de SE Alaa YOUSSEF	Audition de l'ambassadeur d'Egypte en France 	2021-11-24 08:30:00	2021-11-24 09:50:00	\N	\N	6	0	617	\N
608665	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne 	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne 	2021-11-24 16:30:00	2021-11-24 17:45:00	2021-11-26 11:04:44	2021-11-26 14:51:32	6	0	\N	\N
609063	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	MCC sécurisation de la chasse	MCC sécurisation de la chasse	2021-11-30 16:30:00	2021-11-30 16:55:00	\N	\N	13	0	\N	\N
609453	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ambassadeur de France en Algérie, M. François Gouyette	Entretien avec l'ambassadeur de France en Algérie, M. François Gouyette	2021-11-25 08:30:00	2021-11-25 09:30:00	\N	\N	4	0	575	\N
609895	GIA	AUCUNE	\N	\N	\N	Visioconférence avec l'ambassade de France en Grèce	Visioconférence avec l'ambassade de France en Grèce	2021-12-01 14:15:00	2021-12-01 15:00:00	\N	\N	4	0	591	\N
609922	ETUDES	AUTRE	\N	\N	\N	Audition représentants filière moutarde	\N	2021-12-01 13:30:00	2021-12-01 15:00:00	\N	\N	6	0	\N	1005
609970	MISSION	AUCUNE	\N	CULTURE	\N	Audition de M. Julien Goupil	\N	2021-12-07 16:05:00	2021-12-07 17:30:00	2021-12-08 11:19:53	2021-12-08 17:03:13	11	0	\N	\N
610241	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Protection des lanceurs d'alerte PPLO Rôle du Défenseur des droits	\N	2021-11-30 17:00:00	2021-11-30 19:00:00	\N	\N	1	0	\N	\N
610254	MISSION	AUDRAP	\N	CULTURE	\N	Audition de la Cour des comptes	\N	2022-01-12 13:40:00	2022-01-12 14:50:00	\N	\N	5	0	\N	\N
610276	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Table ronde des représentants du sport scolaire	\N	2021-12-01 16:45:00	2021-12-01 18:30:00	\N	\N	3	0	\N	\N
610282	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2021-12-08 09:35:00	2021-12-08 12:45:00	2021-12-08 12:44:33	2021-12-08 17:01:14	41	0	\N	\N
610361	ETUDES	AUTRE	\N	\N	\N	Table ronde Cancers du sein triple négatifs et cancers gynécologiques métastatiques	\N	2021-11-30 16:45:00	2021-11-30 18:10:00	\N	\N	10	0	\N	1004
610375	ETUDES	AUTRE	\N	\N	\N	Audition commune	\N	2021-12-01 17:00:00	2021-12-01 18:05:00	\N	\N	9	0	\N	1004
610787	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Accord de sécurité sociale avec l'IESUE	Accord de sécurité sociale avec l'IESUE	2021-12-03 14:30:00	2021-12-03 15:00:00	\N	\N	1	0	\N	\N
610790	GIA	AUCUNE	\N	\N	\N	Entretien avec le Président du Botswana Mokgweetsi Masisi	Entretien avec le Président du Botswana Mokgweetsi Masisi et sa délégation	2021-11-10 12:00:00	2021-11-10 14:00:00	\N	\N	3	0	646	\N
610805	GIA	AUCUNE	\N	\N	\N	Audition de Mme Nadia Fanton, Sous-directrice Afrique Australe	Audition de Mme Nadia Fanton, Sous-directrice Afrique Australe - MAEE	2021-11-17 17:45:00	2021-11-17 19:00:00	\N	\N	1	0	646	\N
610811	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2021-12-02 09:05:00	2021-12-02 10:20:00	\N	\N	3	0	\N	\N
610815	GIA	AUCUNE	\N	\N	\N	Audition des présidents de Parlement des Pays baltes	Audition à la Présidence du Sénat des présidents de Parlement des Pays-baltes	2021-11-24 10:00:00	2021-11-24 12:00:00	\N	\N	3	0	616	\N
610830	COM_ENQUETE	AUDRAP	\N	CABINETS	\N	CIRI - Hospices civils de Lyon - Direction du budget	CIRI - Hospices civils de Lyon - Direction du budget	2021-12-06 14:35:00	2021-12-06 17:45:00	\N	\N	3	0	\N	\N
610832	COM_ENQUETE	PLENIERE	\N	CABINETS	\N	Audition plénière - Direction des achats de l'Etat-UGAP	Audition plénière - Direction des achats de l'Etat-UGAP	2021-12-08 16:30:00	2021-12-08 18:10:00	2021-12-08 18:08:48	2021-12-09 16:23:09	7	0	\N	\N
610834	GIA	AUCUNE	\N	\N	\N	Visite de la société HELI-UNION à Toussus-le-Noble 	Visite de la société HELI-UNION à Toussus-le-Noble 	2021-12-07 15:00:00	2021-12-07 17:00:00	\N	\N	2	0	612	\N
610837	GIA	AUCUNE	\N	\N	\N	Réception à l'ambassade de Finlande à l'occasion de la fête nationale finlandaise	\N	2021-12-03 12:30:00	2021-12-03 14:00:00	\N	\N	1	0	640	\N
612414	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition article 13 ANRU	\N	2021-12-08 11:35:00	2021-12-08 12:45:00	2021-12-08 17:08:24	2021-12-09 15:58:05	45	0	\N	\N
612506	GIA	AUCUNE	\N	\N	\N	Audition de l'ambassadeur de France en Ethiopie 	Audition de M. Rémi Maréchaux, Ambassadeur de France en Ethiopie et Délégué de la France auprès de l'Union africaine	2021-12-08 16:00:00	2021-12-08 17:00:00	\N	\N	5	0	588	\N
612780	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Directeur général de l'enseignement scolaire 	\N	2021-12-08 16:30:00	2021-12-08 18:00:00	\N	\N	2	0	\N	\N
612794	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Examen rapport d'information sur la sécurité d'acheminement des communications d'urgence	Examen rapport d'information sur la sécurité d'acheminement des communications d'urgence	2021-12-15 09:05:00	2021-12-15 09:30:00	2021-12-16 09:36:04	2021-12-16 17:03:50	97	0	\N	\N
612796	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de Gérald Darmanin, ministre de l'intérieur, sur la situation migratoire à Calais	Audition de Gérald Darmanin, ministre de l'intérieur, sur la situation migratoire à Calais	2021-12-15 16:30:00	2021-12-15 17:45:00	2021-12-15 17:43:57	2021-12-16 17:03:48	20	0	\N	\N
612874	DELEGATION	AUCUNE	\N	\N	COLTER	Table ronde sur "la parité dans les exécutifs locaux"	\N	2021-12-09 10:30:00	2021-12-09 12:15:00	2021-12-09 18:49:10	\N	14	0	\N	\N
612877	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 2021 - Exécution dépenses État Outre-mer - Cour des comptes	58-2 2021 - Exécution dépenses État Outre-mer - Cour des comptes	2021-12-07 17:00:00	2021-12-07 18:15:00	\N	\N	2	0	\N	\N
612992	MISSION	AUTRE	\N	CULTURE	\N	Réunion 20211214	\N	2021-12-14 16:00:00	2021-12-14 17:25:00	2021-12-15 08:58:39	2021-12-15 17:08:50	14	0	\N	\N
612997	MISSION	AUCUNE	\N	JUDI	\N	Réunion constitutive	Réunion constitutive	2021-12-15 14:05:00	2021-12-15 14:35:00	2021-12-15 14:33:53	2021-12-15 17:08:51	13	0	\N	\N
613035	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Audition M. PACCAUD PPL Harcèlement scolaire	\N	2021-12-09 10:00:00	2021-12-09 11:30:00	\N	\N	7	0	\N	\N
613065	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	comité national olympique et sportif français	Astrid Guyart et Romain Girouille, haut niveau	2021-12-09 13:30:00	2021-12-09 14:45:00	\N	\N	2	0	\N	\N
512157	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe	Assemblée générale du groupe	2020-12-02 14:30:00	2020-12-02 15:00:00	\N	\N	9	0	617	\N
519229	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition Aguila Saleh, président parlement Tobrouk	\N	2021-01-12 16:40:00	2021-01-12 18:00:00	2021-01-13 11:52:51	2021-01-13 14:39:36	21	0	\N	\N
519230	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Table ronde sur l'Arctique	\N	2021-01-13 09:35:00	2021-01-13 11:30:00	2021-01-13 14:12:20	2021-01-13 15:53:03	64	0	\N	\N
536862	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL Extradition France / Algérie	PJL Extradition France / Algérie	2021-03-03 17:00:00	2021-03-03 18:00:00	\N	\N	1	0	\N	\N
537084	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Groupe de travail sur l'avenir de La Poste	Groupe de travail sur l'avenir de La Poste	2021-03-09 09:45:00	2021-03-09 10:45:00	\N	\N	4	0	\N	\N
546106	GIA	AUCUNE	\N	\N	\N	Audition de Bertrand LORTHOLARY, Directeur Asie Océanie MEAE	Audition de Bertrand LORTHOLARY, Directeur Asie et Océanie au ministère  des Affaires étrangères	2021-03-30 15:00:00	2021-03-30 16:30:00	\N	\N	7	0	609	\N
547118	GIA	AUCUNE	\N	\N	\N	Entretien avec S.E. M. Teemu Tanner, ambassadeur de Finlande en France	Entretien avec S.E. M. Teemu Tanner, ambassadeur de Finlande en France	2021-03-31 14:05:00	2021-03-31 14:55:00	\N	\N	2	0	640	\N
547491	GIA	AUCUNE	\N	\N	\N	Rencontre Larcher/Abdullah Abdullah	Rencontre entre Abdullah Abdullah et le président Larcher	2021-02-26 10:00:00	2021-02-26 11:30:00	\N	\N	1	0	648	\N
547493	GIA	AUCUNE	\N	\N	\N	Entretien Hostalier	Entretien entre M. Le Nay et Françoise Hostalier, présidente du club France-Afghanistan	2021-04-01 16:00:00	2021-04-01 17:00:00	\N	\N	1	0	648	\N
555500	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Espace - Réunion reconstitutive	GT Espace - Réunion reconstitutive	2021-05-04 10:00:00	2021-05-04 11:00:00	\N	\N	7	0	\N	\N
556030	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2021-05-04 16:30:00	2021-05-04 18:30:00	\N	\N	3	0	\N	\N
559992	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL Climat - Équilibre des énergies	Audition PJL Climat - Équilibre des énergies	2021-05-03 11:30:00	2021-05-03 12:00:00	\N	\N	1	0	\N	\N
559998	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL Climat - DGEC	Audition PJL Climat - DGEC	2021-05-03 18:15:00	2021-05-03 19:00:00	\N	\N	1	0	\N	\N
559999	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL Climat - Table ronde "énergies renouvelables" SER Enerplan FGR ACDV	Audition PJL Climat - Table ronde "énergies renouvelables" SER Enerplan FGR ACDV	2021-05-03 19:00:00	2021-05-03 19:45:00	\N	\N	1	0	\N	\N
560005	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL Climat et résilience - DGEC	Audition PJL Climat et résilience - DGEC	2021-05-04 08:00:00	2021-05-04 09:30:00	\N	\N	1	0	\N	\N
560006	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL Climat et résilience - EDF	Audition PJL Climat et résilience - EDF	2021-05-04 09:30:00	2021-05-04 10:00:00	\N	\N	1	0	\N	\N
560008	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL Climat et résilience -GRTgaz	Audition PJL Climat et résilience -GRTgaz	2021-05-04 10:00:00	2021-05-04 10:30:00	\N	\N	1	0	\N	\N
560010	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL Climat et résilience - Réseau de transport de l'électricité (RTE)	Audition PJL Climat et résilience - Réseau de transport de l'électricité (RTE)	2021-05-04 10:30:00	2021-05-04 11:00:00	\N	\N	1	0	\N	\N
560066	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL Climat et résilience - Table ronde AFG FF3C Fedene UFIP	Audition PJL Climat et résilience - Table ronde AFG FF3C Fedene UFIP	2021-05-04 14:00:00	2021-05-04 14:45:00	\N	\N	1	0	\N	\N
560068	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL Climat et résilience - Table ronde "professionnels" FCD UMIH Medef FCA	Audition PJL Climat et résilience - Table ronde "professionnels" FCD UMIH Medef FCA	2021-05-04 14:45:00	2021-05-04 15:30:00	\N	\N	1	0	\N	\N
560069	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL Climat et résilience - Table ronde FranceHydro EAF FFASM FDMF	Audition PJL Climat et résilience - Table ronde FranceHydro EAF FFASM FDMF	2021-05-04 15:30:00	2021-05-04 16:15:00	\N	\N	1	0	\N	\N
560071	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL Climat et résilience - Table ronde "électromobilité" Avere Zeplug	Audition PJL Climat et résilience - Table ronde "électromobilité" Avere Zeplug	2021-05-04 16:15:00	2021-05-04 16:45:00	\N	\N	1	0	\N	\N
560332	DELEGATION	AUCUNE	\N	\N	DSOM	Audition dans le cadre de l'étude sur le logement outre-mer	\N	2021-05-27 14:30:00	2021-05-27 15:20:00	\N	\N	9	0	\N	\N
562036	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Améliorer la lisibilité du droit (2)	\N	2021-05-18 09:00:00	2021-05-18 10:00:00	\N	\N	1	0	\N	\N
562040	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Améliorer la lisibilité du droit (2)	\N	2021-05-20 11:00:00	2021-05-20 12:00:00	\N	\N	1	0	\N	\N
562185	DELEGATION	AUCUNE	\N	\N	DSOM	Colloque sur les biodiversités de l'océan Indien	Colloque sur les biodiversités de l'océan Indien	2021-05-20 14:30:00	2021-05-20 18:30:00	\N	\N	9	0	\N	\N
562195	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Actualisation LPM	\N	2021-05-19 16:30:00	2021-05-19 17:30:00	\N	\N	2	0	\N	\N
562220	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT Boussole stratégique	GT Boussole stratégique	2021-05-10 16:00:00	2021-05-10 17:30:00	\N	\N	3	0	\N	\N
562224	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT Boussole stratégique	GT Boussole stratégique	2021-05-12 16:30:00	2021-05-12 17:15:00	\N	\N	2	0	\N	\N
562758	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Fédération nationale des collectivités territoriales pour la culture	\N	2021-05-25 14:00:00	2021-05-25 15:00:00	\N	\N	5	0	\N	\N
562759	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Ministère de la culture	\N	2021-05-25 15:00:00	2021-05-25 15:50:00	\N	\N	6	0	\N	\N
562760	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Table ronde avec les associations des bibliothèques	\N	2021-05-25 16:00:00	2021-05-25 17:00:00	\N	\N	5	0	\N	\N
562770	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-05-26 09:35:00	2021-05-26 10:47:00	2021-05-26 11:12:59	2021-05-26 17:31:18	34	1	\N	\N
562858	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-06-03 13:30:00	2021-06-03 20:00:00	\N	\N	0	0	\N	\N
562866	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2021-05-26 09:30:00	2021-05-26 11:55:00	2021-05-26 16:10:07	2021-05-26 17:31:18	36	0	\N	\N
562939	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL Climat et résilience - Ministère de la transition écologique - cabinet	Audition PJL Climat et résilience - Ministère de la transition écologique - cabinet	2021-05-25 16:00:00	2021-05-25 17:00:00	\N	\N	1	0	\N	\N
562940	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL Climat et résilience - FOHP	Audition PJL Climat et résilience - FOHP	2021-05-25 17:00:00	2021-05-25 17:45:00	\N	\N	1	0	\N	\N
562941	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL Climat et résilience - Valimmo	Audition PJL Climat et résilience - Valimmo	2021-05-20 11:30:00	2021-05-20 12:15:00	\N	\N	1	0	\N	\N
563019	MISSION	AUCUNE	\N	EGALCHAN	\N	Réunion plénière MI Jeunes	\N	2021-06-03 15:00:00	2021-06-03 16:00:00	2021-06-03 16:00:42	2021-06-04 17:57:20	5	0	\N	\N
563024	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2021-06-02 09:00:00	2021-06-02 13:05:00	2021-06-02 13:05:26	2021-06-02 18:41:02	34	0	\N	\N
563025	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition plénière	\N	2021-05-27 10:00:00	2021-05-27 11:10:00	2021-05-27 12:10:45	2021-05-27 17:04:46	19	0	\N	\N
563230	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition commune d'infirmiers	\N	2021-05-26 14:00:00	2021-05-26 15:00:00	\N	\N	3	0	\N	\N
563261	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2021-06-02 09:00:00	2021-06-02 12:00:00	2021-06-04 17:57:43	2021-06-04 17:58:01	32	0	\N	\N
563522	MISSION	AUCUNE	\N	EGALCHAN	\N	Réunion plénière MI Jeunes	\N	2021-05-26 16:49:00	2021-05-26 18:00:00	2021-05-26 18:52:07	2021-05-27 17:04:06	6	0	\N	\N
563552	MISSION	AUDRAP	\N	ENSAGRIC	\N	Table ronde syndicats de l'enseignement agricole privé	\N	2021-05-26 17:05:00	2021-05-26 18:34:00	\N	\N	6	0	\N	\N
563700	DELEGATION	AUDRAP	\N	\N	COLTER	Rapport santé : mutuelles communales	\N	2021-05-20 16:00:00	2021-05-20 17:00:00	\N	\N	0	0	\N	\N
563779	MECSS	AUDRAP	\N	\N	MECSS	Audition réserves des régimes de retraite - DSS	\N	2021-06-02 13:45:00	2021-06-02 14:30:00	\N	\N	3	0	\N	\N
563782	MECSS	AUDRAP	\N	\N	MECSS	Audition réserves des régimes de retraite - CPRPSNCF	\N	2021-06-02 14:30:00	2021-06-02 15:00:00	\N	\N	3	0	\N	\N
563785	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Auditions	\N	2021-05-27 08:45:00	2021-05-27 10:45:00	2021-05-27 16:48:53	\N	11	0	\N	\N
563793	MISSION	AUCUNE	\N	VIETUDIA	\N	Audition rapporteur « La situation des doctorants »	\N	2021-05-31 11:00:00	2021-05-31 12:30:00	\N	\N	5	0	\N	\N
588234	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désignations - Amendements de séance - Rapports	Désignations - Amendements de séance - Rapports	2021-10-06 09:10:00	2021-10-06 11:35:00	2021-10-06 12:02:15	2021-10-06 16:05:36	37	0	\N	\N
588235	COM_PERMANENTE	AUTRE	\N	LOIS	\N	MI Sécurité d'acheminement des communications d'urgence - Audition de Guillaume Poupard	MI Sécurité d'acheminement des communications d'urgence - Audition de Guillaume Poupard, directeur général de l'ANSSI	2021-10-06 13:40:00	2021-10-06 14:30:00	2021-10-06 14:43:45	2021-10-06 16:05:33	6	0	\N	\N
588341	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2021-09-30 10:15:00	2021-09-30 12:15:00	\N	\N	5	0	\N	\N
588379	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLO Implantation locale des parlementaires	\N	2021-09-29 16:30:00	2021-09-29 17:15:00	\N	\N	1	0	\N	\N
588381	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLO Implantation locale des parlementaires	\N	2021-09-30 10:30:00	2021-09-30 11:15:00	\N	\N	1	0	\N	\N
588390	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Réforme de l'adoption	\N	2021-09-30 09:00:00	2021-09-30 09:45:00	\N	\N	3	0	\N	\N
588411	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2021-10-06 09:00:00	2021-10-06 13:00:00	2021-10-07 14:50:31	2021-10-08 18:04:53	33	0	\N	\N
588412	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2021-10-06 16:30:00	2021-10-06 18:00:00	2021-10-07 15:04:21	2021-10-08 18:04:48	27	0	\N	\N
588416	MISSION	PLEIN_NON_JO	\N	INFLUENCES	\N	Examen du rapport de la mission	\N	2021-09-29 16:35:00	2021-09-29 18:05:00	\N	\N	10	0	\N	\N
588427	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	CNOSF / CPSF	\N	2021-09-30 14:00:00	2021-09-30 16:20:00	\N	\N	3	0	\N	\N
588432	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition DGT	\N	2021-09-30 15:00:00	2021-09-30 16:00:00	\N	\N	2	0	\N	\N
588446	COM_PERMANENTE	AUCUNE	\N	SOCI	\N	Déplacement de la mission à Sainte Anne	\N	2021-09-22 16:45:00	2021-09-22 18:45:00	\N	\N	0	0	\N	\N
588498	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Maltraitance animale	PPL Maltraitance animale	2021-09-30 21:30:00	2021-10-01 00:00:00	\N	\N	25	0	\N	\N
589385	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition DSS PPL Accélérer l'égalité économique et professionnelle	\N	2021-10-05 10:00:00	2021-10-05 11:00:00	\N	\N	1	0	\N	\N
589387	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition oragnisations patronales	\N	2021-10-05 14:00:00	2021-10-05 15:30:00	\N	\N	1	0	\N	\N
589400	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Organisations syndicales	\N	2021-10-05 15:45:00	2021-10-05 17:15:00	\N	\N	1	0	\N	\N
589405	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Fédération bancaire française	\N	2021-10-05 17:30:00	2021-10-05 18:15:00	\N	\N	1	0	\N	\N
589450	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur - PJL Travailleurs indépendants	\N	2021-10-05 17:45:00	2021-10-05 19:40:00	\N	\N	1	0	\N	\N
589464	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Foncier agricole - Assemblée permanente des chambres d'agriculture	PPL Foncier agricole - Assemblée permanente des chambres d'agriculture	2021-10-05 14:00:00	2021-10-05 14:45:00	\N	\N	3	0	\N	\N
589467	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Foncier agricole - DRAAF - sous-préfecture de Beaune	PPL Foncier agricole - DRAAF - sous-préfecture de Beaune	2021-10-05 14:45:00	2021-10-05 15:30:00	\N	\N	4	0	\N	\N
589468	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Foncier agricole - Safer de Bourgogne-Franche-Comté	PPL Foncier agricole - Safer de Bourgogne-Franche-Comté	2021-10-05 15:30:00	2021-10-05 16:15:00	\N	\N	2	0	\N	\N
589470	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Foncier agricole - INRAE	PPL Foncier agricole - INRAE	2021-10-05 16:15:00	2021-10-05 17:00:00	\N	\N	3	0	\N	\N
589509	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Foncier agricole - Audition FNSAFER	PPL Foncier agricole - Audition FNSAFER	2021-10-05 08:30:00	2021-10-05 09:15:00	\N	\N	4	0	\N	\N
589510	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Foncier agricole - Association nationale des établissements publics fonciers locaux	PPL Foncier agricole - Association nationale des établissements publics fonciers locaux	2021-10-05 09:15:00	2021-10-05 10:00:00	\N	\N	3	0	\N	\N
589512	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Foncier agricole - Terre de liens	PPL Foncier agricole - Terre de liens	2021-10-05 10:00:00	2021-10-05 10:45:00	\N	\N	1	0	\N	\N
589583	DELEGATION	AUDRAP	\N	\N	206	Audition de rapporteur sur le déclin des insectes 	\N	2021-10-05 17:00:00	2021-10-05 18:00:00	\N	\N	1	0	\N	\N
589593	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition commune DGESIP - DGESCO	\N	2021-10-06 14:00:00	2021-10-06 15:00:00	\N	\N	1	0	\N	\N
589784	COM_PERMANENTE	AUDRAP	\N	CAE	\N	CSN - FNAIM - CNEFAF	\N	2021-10-06 08:30:00	2021-10-06 09:30:00	\N	\N	3	0	\N	\N
589788	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Table ronde syndicats agricoles	\N	2021-10-06 09:30:00	2021-10-06 10:30:00	\N	\N	2	0	\N	\N
589798	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Foncier agricole - Ministère de l'agriculture et de l'alimentation	PPL Foncier agricole - Ministère de l'agriculture et de l'alimentation	2021-10-06 10:30:00	2021-10-06 11:15:00	\N	\N	1	0	\N	\N
589803	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Foncier agricole - Direction départementale des territoires de la Haute-Saône	PPL Foncier agricole - Direction départementale des territoires de la Haute-Saône	2021-10-06 11:15:00	2021-10-06 12:00:00	\N	\N	2	0	\N	\N
590737	GIA	AUCUNE	\N	\N	\N	Audition de Mme María Felisa Herrero PINILLA Magistrate de liaison espagnole à Paris	Audition de Mme María Felisa Herrero PINILLA Magistrate de liaison espagnole à Paris	2021-10-07 10:30:00	2021-10-07 12:30:00	\N	\N	7	0	589	\N
590819	GIA	AUCUNE	\N	\N	\N	Rencontre Nazary	Rencontre avec M. Ali Nazary, responsable des relations internationales du National Resistance Front	2021-10-06 13:00:00	2021-10-06 14:00:00	\N	\N	1	0	648	\N
590829	COM_PERMANENTE	AUTRE	\N	FINC	\N	Désignation rapp. Nom. art 13 - AMDTS PPL383 et rapport PPL325 -Audition «Pandora papers»	Désignation rapporteur Nomination art 13 - Examen AMDTS PPL 383 et rapport PPL 325 et Audition « Pandora papers »	2021-10-13 09:35:00	2021-10-13 12:40:00	2021-10-13 14:17:21	2021-10-13 14:21:43	45	0	\N	\N
590852	COM_EURO	AUTRE	\N	AFEU	\N	Déplacement du GIA France-Slovénie - Communication	\N	2021-10-14 08:00:00	2021-10-14 08:30:00	\N	\N	0	0	\N	\N
590855	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 14 octobre 2021	\N	2021-10-14 09:00:00	2021-10-14 10:15:00	2021-10-14 10:17:14	2021-10-14 14:58:22	14	0	\N	\N
590864	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2022- Défense - Déplacement EMAT	PLF pour 2022- Défense - Déplacement EMAT	2021-10-04 08:15:00	2021-10-04 10:15:00	\N	\N	1	0	\N	\N
590866	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022- Défense - EMMN	PLF pour 2022- Défense - EMMN	2021-10-05 16:00:00	2021-10-05 17:00:00	\N	\N	1	0	\N	\N
590873	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Indemnisation des catastrophes naturelles-DGPR-Sce risques naturels et hydrauliques	\N	2021-10-05 09:15:00	2021-10-05 10:00:00	\N	\N	2	0	\N	\N
590874	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Indemnisation des catastrophes naturelles-DG Sécurité civile Gestion crises	\N	2021-10-06 08:00:00	2021-10-06 08:45:00	\N	\N	2	0	\N	\N
590875	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Indemnisation des catastrophes naturelles-DG Trésor-Bureau marchés/produits assurances	\N	2021-10-06 08:45:00	2021-10-06 09:30:00	\N	\N	2	0	\N	\N
590876	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Indemnisation des catastrophes naturelles-Fédération française de l'assurance	\N	2021-10-07 10:45:00	2021-10-07 11:30:00	\N	\N	1	0	\N	\N
590882	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n° 325 Catastrophes naturelles -  DGPE	PPL n° 325 Catastrophes naturelles -  DGPE	2021-10-07 13:15:00	2021-10-07 14:00:00	\N	\N	1	0	\N	\N
590887	COM_PERMANENTE	AUDRAP	\N	CAE	\N	DG Trésor	DG Trésor	2021-10-07 17:30:00	2021-10-07 18:15:00	\N	\N	2	0	\N	\N
590890	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Sport - Direction des sports	PLF pour 2022 - Sport - Direction des sports	2021-10-05 14:30:00	2021-10-05 15:30:00	\N	\N	1	0	\N	\N
590892	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Sport - Unis-Cité	PLF pour 2022 - Sport - Unis-Cité	2021-10-05 17:00:00	2021-10-05 17:45:00	\N	\N	1	0	\N	\N
590894	COM_PERMANENTE	AUDRAP	\N	CAE	\N	CCI France	\N	2021-10-05 12:15:00	2021-10-05 13:00:00	\N	\N	1	0	\N	\N
590896	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PJL Travailleurs indépendants	\N	2021-10-05 14:30:00	2021-10-05 15:00:00	\N	\N	3	0	\N	\N
590900	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PJL Travailleurs indépendants	\N	2021-10-05 18:00:00	2021-10-05 18:45:00	\N	\N	1	0	\N	\N
516887	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe d'amitié	Assemblée générale du groupe d'amitié	2020-12-09 17:00:00	2020-12-09 18:00:00	\N	\N	5	0	600	\N
516893	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ambassadeur de France à Varsovie	Entretien téléphonique avec l'ambassadeur de France à Varsovie	2020-12-09 12:00:00	2020-12-09 12:45:00	\N	\N	1	0	600	\N
536289	GIA	AUCUNE	\N	\N	\N	Entretien avec les représentantes de l'ambassade de Mongolie 	Entretien avec Mme BAT-ERDENE, chargée d'affaires, et NYAMKHUU, première secrétaire, de l'ambassade de Mongolie	2021-03-04 08:35:00	2021-03-04 09:20:00	\N	\N	5	0	612	\N
539567	GIA	AUCUNE	\N	\N	\N	Entretien avec Harold Parisot, président du Chinese Business Club	\N	2021-03-10 16:30:00	2021-03-10 17:30:00	\N	\N	5	0	584	\N
544751	MISSION	AUCUNE	\N	METHANIS	\N	Réunion plénière MI Méthanisation	\N	2021-03-30 16:30:00	2021-03-30 18:30:00	2021-04-02 14:49:16	2021-04-02 14:50:09	14	0	\N	\N
551047	MECSS	AUDRAP	\N	\N	MECSS	Audition réserves des régimes de retraite	\N	2021-04-07 14:00:00	2021-04-07 14:45:00	\N	\N	4	0	\N	\N
551262	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL développement solidaire	PJL développement solidaire	2021-04-08 10:30:00	2021-04-08 13:30:00	\N	\N	2	0	\N	\N
551289	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GS Egalim - Audition FNSEA	GS Egalim - Audition FNSEA	2021-04-06 16:00:00	2021-04-06 16:30:00	\N	\N	6	0	\N	\N
551296	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GS Egalim - Audition La Coopération agricole	GS Egalim - Audition La Coopération agricole	2021-04-06 16:30:00	2021-04-06 17:00:00	\N	\N	8	0	\N	\N
551305	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GS Egalim - Audition Jeunes Agriculteurs	GS Egalim - Audition Jeunes Agriculteurs	2021-04-06 17:00:00	2021-04-06 17:30:00	\N	\N	8	0	\N	\N
551314	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GS Egalim - Audition Confédération paysanne	GS Egalim - Audition Confédération paysanne	2021-04-06 17:30:00	2021-04-06 18:00:00	\N	\N	8	0	\N	\N
551323	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GS Egalim - Audition Groupement Les Mousquetaires	GS Egalim - Audition Groupement Les Mousquetaires	2021-04-06 18:00:00	2021-04-06 18:30:00	\N	\N	8	0	\N	\N
551333	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GS Egalim - Audition Coordination rurale	GS Egalim - Audition Coordination rurale	2021-04-06 18:30:00	2021-04-06 19:00:00	\N	\N	8	0	\N	\N
551342	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GS Egalim - Audition ANIA	GS Egalim - Audition ANIA	2021-04-06 19:00:00	2021-04-06 19:30:00	\N	\N	8	0	\N	\N
551351	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GS Egalim - Audition ADEPALE	GS Egalim - Audition ADEPALE	2021-04-06 19:30:00	2021-04-06 20:00:00	\N	\N	5	0	\N	\N
553607	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLC Article 1er de la Constitution et préservation de l'environnement	PJLC Article 1er de la Constitution et préservation de l'environnement	2021-04-13 15:30:00	2021-04-13 16:30:00	\N	\N	1	0	\N	\N
553647	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL lutte contre l'illectronisme	PPL lutte contre l'illectronisme	2021-04-14 21:35:00	2021-04-14 23:00:00	\N	\N	39	0	\N	\N
555124	MISSION	AUDRAP	\N	EGALCHAN	\N	Audition rapporteure	\N	2021-04-20 09:30:00	2021-04-20 11:00:00	\N	\N	2	0	\N	\N
555127	MISSION	AUDRAP	\N	EGALCHAN	\N	Audition rapporteure	\N	2021-04-20 11:00:00	2021-04-20 12:00:00	\N	\N	2	0	\N	\N
555130	MISSION	AUDRAP	\N	EGALCHAN	\N	Audition rapporteure	\N	2021-04-20 14:00:00	2021-04-20 15:00:00	\N	\N	3	0	\N	\N
555134	MISSION	AUDRAP	\N	EGALCHAN	\N	Audition rapporteure	\N	2021-04-20 15:00:00	2021-04-20 16:30:00	\N	\N	2	0	\N	\N
555137	MISSION	AUDRAP	\N	EGALCHAN	\N	Audition rapporteure	\N	2021-04-20 18:00:00	2021-04-20 19:25:00	\N	\N	3	0	\N	\N
555141	MISSION	AUDRAP	\N	EGALCHAN	\N	Audition rapporteure	\N	2021-04-21 09:00:00	2021-04-21 11:00:00	\N	\N	1	0	\N	\N
555143	MISSION	AUDRAP	\N	EGALCHAN	\N	Audition rapporteure	\N	2021-04-21 11:00:00	2021-04-21 12:15:00	\N	\N	2	0	\N	\N
555146	MISSION	AUDRAP	\N	EGALCHAN	\N	Audition rapporteure	\N	2021-04-21 14:30:00	2021-04-21 15:40:00	\N	\N	1	0	\N	\N
555148	MISSION	AUDRAP	\N	EGALCHAN	\N	Audition rapporteure	\N	2021-04-21 15:40:00	2021-04-21 17:00:00	\N	\N	2	0	\N	\N
555151	MISSION	AUDRAP	\N	EGALCHAN	\N	Audition rapporteure	\N	2021-04-21 17:00:00	2021-04-21 18:20:00	\N	\N	3	0	\N	\N
555155	MISSION	AUDRAP	\N	EGALCHAN	\N	Audition rapporteure	\N	2021-04-22 09:00:00	2021-04-22 10:10:00	\N	\N	3	0	\N	\N
555159	MISSION	AUDRAP	\N	EGALCHAN	\N	Auditions rapporteure	\N	2021-04-22 10:10:00	2021-04-22 12:05:00	\N	\N	2	0	\N	\N
559677	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition aumôniers des armées, examen amendts séance PJL DADUE + conventions + nominations	Audition aumôniers des armées, aments séance PJL DADUE + conventions + nominations rapporteurs	2021-05-19 09:30:00	2021-05-19 11:30:00	2021-05-19 16:45:55	2021-05-20 15:48:18	35	0	\N	\N
559678	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de M. Franck Riester	Audition de M. Franck Riester	2021-05-19 16:40:00	2021-05-19 18:30:00	2021-05-20 15:30:04	2021-05-20 15:48:14	35	0	\N	\N
559835	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audition ministère des affaires étrangères et ministère de l'interieur	\N	2021-05-10 10:30:00	2021-05-10 11:30:00	\N	\N	0	0	\N	\N
562400	GIA	AUCUNE	\N	\N	\N	Audition de sr Cécile Renouard	Le Pape François : Quelle vision de l'économie et de l'entreprise ?	2021-05-25 13:30:00	2021-05-25 14:30:00	\N	\N	5	0	629	\N
590932	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n° 325 Catastrophes naturelles -  FFA	PPL n° 325 Catastrophes naturelles -  FFA	2021-10-08 10:45:00	2021-10-08 11:30:00	\N	\N	1	0	\N	\N
562526	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition du directeur général de l¿Agence spatiale européenne (ESA)	Audition du directeur général de l¿Agence spatiale européenne (ESA)	2021-05-25 14:00:00	2021-05-25 15:15:00	\N	\N	15	0	\N	\N
566445	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2021-06-03 09:05:00	2021-06-03 10:40:00	\N	\N	2	0	\N	\N
571806	GIA	AUCUNE	\N	\N	\N	Audition de M. Laurent Gayer, directeur de recherche au CNRS	\N	2021-06-23 08:15:00	2021-06-23 09:30:00	\N	\N	3	0	619	\N
571903	COM_EURO	AUDRAP	\N	AFEU	\N	Auditions DSA/DMA	\N	2021-06-22 16:30:00	2021-06-22 17:40:00	\N	\N	1	0	\N	\N
571905	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 30 juin 2021	\N	2021-06-30 13:30:00	2021-06-30 14:55:00	2021-06-30 14:56:09	2021-06-30 18:43:22	17	0	\N	\N
572037	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Examen du rapport d'information sur les drones dans les forces armées	\N	2021-06-23 09:59:00	2021-06-23 10:56:00	\N	\N	0	0	\N	\N
572038	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Examen du rapport d'information sur les drones dans les forces armées	\N	2021-06-23 09:59:00	2021-06-23 10:58:00	\N	\N	0	0	\N	\N
573458	MISSION	AUDRAP	\N	EGALCHAN	\N	Audition de la Philharmonie	\N	2021-06-08 15:45:00	2021-06-08 16:45:00	\N	\N	1	0	\N	\N
573460	MISSION	AUDRAP	\N	EGALCHAN	\N	Audition de R.M. Lagrave	\N	2021-06-10 15:00:00	2021-06-10 16:10:00	\N	\N	1	0	\N	\N
574627	GIA	AUCUNE	\N	\N	\N	Entretien Vice-Président de Tanzanie	Entretien avec M. Philip Mpango, Vice-Président de Tanzanie et visite du Palais	2021-06-30 10:00:00	2021-06-30 11:30:00	\N	\N	1	0	622	\N
577327	COM_PERMANENTE	AUTRE	\N	LOIS	\N	MI Dysfonctionnements élections juin 2021 - Audition syndicat CAT-Adrexo	MI Dysfonctionnements élections juin 2021 - Audition syndicat CAT-Adrexo	2021-07-13 13:30:00	2021-07-13 14:20:00	2021-07-13 15:27:11	2021-07-13 20:21:46	8	0	\N	\N
577870	DELEGATION	AUCUNE	\N	\N	COLTER	Réunion plénière	Examen du rapport d¿information sur la DECI	2021-07-08 09:30:00	2021-07-08 10:30:00	\N	\N	18	0	\N	\N
578409	DELEGATION	AUCUNE	\N	\N	211	Premier échange de vues sur la désignation des lauréats du Prix 2021 de la délégation	Premier échange de vues sur la désignation des lauréats du Prix 2021 de la délégation	2021-07-22 11:00:00	2021-07-22 12:15:00	2021-07-22 12:52:20	\N	13	0	\N	\N
578908	MISSION	AUCUNE	\N	UBER	\N	\N	\N	2021-07-15 09:00:00	2021-07-15 10:15:00	2021-07-15 13:21:13	2021-07-16 17:48:59	5	0	\N	\N
578909	MISSION	AUCUNE	\N	UBER	\N	\N	\N	2021-07-15 11:00:00	2021-07-15 12:15:00	2021-07-15 13:23:51	2021-07-16 17:48:59	4	0	\N	\N
581893	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Crise sanitaire	PJL Crise sanitaire	2021-07-24 09:30:00	2021-07-24 13:00:00	\N	\N	93	0	\N	\N
581894	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL CMP Crise sanitaire	PJL CMP Crise sanitaire	2021-07-24 21:35:00	2021-07-25 04:25:00	\N	\N	72	0	\N	\N
581895	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL CMP Crise sanitaire	PJL CMP Crise sanitaire	2021-07-25 20:45:00	2021-07-25 22:25:00	\N	\N	0	0	\N	\N
583163	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	\N	\N	2021-09-01 11:00:00	2021-09-01 12:30:00	\N	\N	2	0	\N	\N
583166	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT Puissance chinoise en Europe	\N	2021-09-07 10:30:00	2021-09-07 12:00:00	\N	\N	2	0	\N	\N
583169	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT Puissance chinoise en Europe	\N	2021-09-07 14:00:00	2021-09-07 15:00:00	\N	\N	2	0	\N	\N
613068	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2022 : Examen du rapport en nouvelle lecture et désignation	PLF pour 2022 : Examen du rapport en nouvelle lecture et désignation	2021-12-14 09:00:00	2021-12-14 09:50:00	2021-12-14 12:02:24	2021-12-14 17:03:16	21	0	\N	\N
614183	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Port du casque à vélo et dans le cadre d'autres moyens de transport	PPL Port du casque à vélo et dans le cadre d'autres moyens de transport	2021-12-14 15:00:00	2021-12-14 15:15:00	\N	\N	1	0	\N	\N
614185	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Port du casque à vélo et dans le cadre d'autres moyens de transport	PPL Port du casque à vélo et dans le cadre d'autres moyens de transport	2021-12-15 16:45:00	2021-12-15 18:45:00	\N	\N	1	0	\N	\N
620619	MISSION	AUDRAP	\N	JUDI	\N	\N	Audition rapporteur - MI Judiciarisation	2022-01-12 13:30:00	2022-01-12 15:00:00	\N	\N	3	0	\N	\N
621388	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2022-01-18 09:30:00	2022-01-18 12:35:00	\N	\N	46	0	\N	\N
621389	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Démocratiser le sport	PPL Démocratiser le sport	2022-01-18 14:30:00	2022-01-18 20:00:00	\N	\N	124	0	\N	\N
621390	SEANCE_PLENIERE	DEBAT	\N	\N	\N	PPL Démocratiser le sport	PPL Démocratiser le sport	2022-01-18 21:30:00	2022-01-19 01:00:00	\N	\N	54	0	\N	\N
621391	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2022-01-19 15:00:00	2022-01-19 16:20:00	\N	\N	256	0	\N	\N
621392	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Droit à l'avortement 2L	PPL Droit à l'avortement 2L	2022-01-19 16:35:00	2022-01-19 18:20:00	\N	\N	93	0	\N	\N
621393	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Démocratiser le sport (suite)	PPL Démocratiser le sport (suite)	2022-01-19 18:25:00	2022-01-19 20:10:00	\N	\N	77	0	\N	\N
621395	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Démocratiser le sport (suite)	PPL Démocratiser le sport (suite)	2022-01-19 21:40:00	2022-01-20 00:30:00	\N	\N	37	0	\N	\N
621397	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL lanceurs d'alerte et PPLO Défenseur des droits (suite)	PPL lanceurs d'alerte et PPLO Défenseur des droits (suite)	2022-01-20 12:20:00	2022-01-20 13:25:00	\N	\N	42	0	\N	\N
621402	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL lanceurs d'alerte et PPLO Défenseur des droits (suite)	PPL lanceurs d'alerte et PPLO Défenseur des droits (suite)	2022-01-20 15:00:00	2022-01-20 19:05:00	\N	\N	26	0	\N	\N
621407	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL protection des enfants (lecture conclusions CMP)	PJL protection des enfants (lecture conclusions CMP)	2022-01-20 10:30:00	2022-01-20 11:40:00	\N	\N	38	0	\N	\N
621408	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Identité de genre (lecture conclusions CMP)	PJL Identité de genre (lecture conclusions CMP)	2022-01-20 11:40:00	2022-01-20 12:20:00	\N	\N	32	0	\N	\N
629627	MISSION	AUCUNE	\N	FONDSMER	\N	Audition Ambassadeur AIFM	Audition Ambassadeur AIFM	2022-02-08 16:00:00	2022-02-08 17:30:00	2022-02-08 17:26:44	2022-02-09 10:41:04	6	0	\N	\N
631733	COM_PERMANENTE	AUTRE	\N	AFCL	\N	PPL démocratisation sport nouvelle lecture - Rapport et texte de commission	\N	2022-02-15 09:35:00	2022-02-15 10:11:00	2022-02-15 15:09:34	2022-02-15 17:30:59	19	7	\N	\N
631734	COM_ENQUETE	PLENIERE	\N	MEDIA	\N	Auditions Acteurs  Plateforme & internet	\N	2022-02-11 10:05:00	2022-02-11 12:50:00	2022-02-14 12:12:06	2022-02-14 18:17:02	10	0	\N	\N
631766	ETUDES	AUDRAP	\N	\N	\N	GEAC - Audition de M. Patrick KY, PDT de l'AESA	Audition de M. Patrick KY, Président de l'Agence européenne de la sécurité aérienne (AESA)	2022-02-16 08:00:00	2022-02-16 09:10:00	\N	\N	18	0	\N	933
631775	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 -  ENAP - Syndicats DAP	Contrôle 2020 -  ENAP - Syndicats DAP	2022-02-08 14:30:00	2022-02-08 16:30:00	\N	\N	1	0	\N	\N
631777	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n° 325 Indemnisation catastrophes naturelles - DGPR	PPL n° 325 Indemnisation catastrophes naturelles - DGPR	2022-02-09 13:30:00	2022-02-09 14:30:00	\N	\N	1	0	\N	\N
631779	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 2022 - Scénarios financement collectivités territoriales - Cour des comptes	58-2 2022 - Scénarios financement collectivités territoriales - Cour des comptes	2022-02-08 15:00:00	2022-02-08 16:30:00	\N	\N	3	0	\N	\N
631783	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - IHU - Académie de Médecine	Contrôle 2021 - IHU - Académie de Médecine	2022-02-10 14:00:00	2022-02-10 15:00:00	\N	\N	1	0	\N	\N
631793	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion pleinière CATDD	\N	2022-02-23 09:00:00	2022-02-23 11:30:00	2022-02-23 11:30:12	2022-02-23 15:36:00	37	0	\N	\N
631854	GIA	AUCUNE	\N	\N	\N	Accueil de l'Ambassadrice à l'occasion de la Fête de la Culture slovène	Accueil de l'Ambassadrice à l'occasion de la Fête de la Culture slovène	2022-02-08 12:30:00	2022-02-08 14:30:00	\N	\N	7	0	529	\N
632645	GIA	AUCUNE	\N	\N	\N	Point sur l'actualité taïwanaise	Audition de S.E. F. Wu, représentant de Taipei en France, M. A. Bondaz (FRS) et M. M. Duchâtel (Institut Montaigne)	2022-02-15 18:00:00	2022-02-15 19:20:00	\N	\N	9	0	623	\N
634237	MISSION	AUCUNE	\N	RECHINNO	\N	Audition de M. Stéphane SIEBERT, directeur de la recherche technologique du CEA	Audition de M. Stéphane SIEBERT, directeur de la recherche technologique du CEA	2022-02-16 17:45:00	2022-02-16 18:25:00	2022-02-21 16:34:20	2022-02-21 17:14:51	7	0	\N	\N
634252	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	MCC	MCC Sécurisation de la chasse-Audition de M. Manuel Duvinage	2022-02-15 09:45:00	2022-02-15 10:45:00	\N	\N	5	0	\N	\N
634259	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	MCC Sécurisation de la chasse	MCC Sécurisation de la chasse-Audition de M. Louis Schweitzer	2022-02-15 15:15:00	2022-02-15 16:15:00	\N	\N	5	0	\N	\N
634265	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	MCC Sécurisation de la chasse	MCC Sécurisation de la chasse-Audition de l'association Animal Cross	2022-02-15 16:15:00	2022-02-15 17:15:00	\N	\N	5	0	\N	\N
634461	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-02-23 09:05:00	2022-02-23 12:30:00	2022-02-23 12:30:42	2022-02-23 15:36:00	42	0	\N	\N
634528	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Cabinet Cédric O	Audition Cabinet Cédric O	2022-02-10 10:00:00	2022-02-10 10:30:00	\N	\N	1	0	\N	\N
634533	COM_ENQUETE	PLENIERE	\N	MEDIA	\N	9h30: M. Niel, fondateur et actionnaire, gpe Iliad ;  11h30: M. Bouygues, pdt de Bouygues 	\N	2022-02-18 09:30:00	2022-02-18 12:45:00	2022-02-18 17:26:17	2022-02-21 16:24:56	9	0	\N	\N
634534	DELEGATION	AUCUNE	\N	\N	206	Réunion avec le conseil scientifique	\N	2022-02-17 10:15:00	2022-02-17 12:40:00	\N	\N	10	0	\N	\N
634535	DELEGATION	AUCUNE	\N	\N	206	Audition publique sur la chlordécone	\N	2022-02-17 14:10:00	2022-02-17 17:00:00	2022-02-17 18:33:07	\N	6	0	\N	\N
634588	MECSS	AUCUNE	\N	\N	MECSS	Audition plénière	\N	2022-02-23 14:00:00	2022-02-23 14:50:00	2022-02-23 14:57:35	2022-02-23 15:35:54	12	0	\N	\N
634600	COM_ENQUETE	AUDRAP	\N	HOPITAL	\N	CE Hôpital - Audition de France Assos santé	\N	2022-02-15 17:00:00	2022-02-15 18:00:00	\N	\N	1	0	\N	\N
634602	COM_ENQUETE	AUDRAP	\N	HOPITAL	\N	CE Hôpital - Audition du CHRU de Nancy	\N	2022-02-17 09:00:00	2022-02-17 10:00:00	\N	\N	3	0	\N	\N
634645	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Auditions P. 105	Auditions P. 105	2022-02-22 13:00:00	2022-02-22 14:00:00	\N	\N	1	0	\N	\N
634667	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT subsidiarité	GT subsidiarité	2022-02-17 09:00:00	2022-02-17 09:20:00	\N	\N	5	0	\N	\N
634708	DELEGATION	AUDRAP	\N	\N	206	Audition du médiateur du livre	\N	2022-02-17 16:30:00	2022-02-17 17:45:00	\N	\N	3	0	\N	\N
634722	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Bruno FERREIRA	\N	2022-02-17 09:00:00	2022-02-17 10:00:00	\N	\N	2	0	\N	\N
634738	COM_ENQUETE	PLENIERE	\N	MEDIA	\N	rn médias	\N	2022-02-23 16:45:00	2022-02-23 18:25:00	2022-02-23 19:13:25	2022-02-24 14:43:04	12	0	\N	\N
635291	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Aménagement du territoire - Audition de MM. Belin et Babary	MI Aménagement du territoire - Audition de MM. Belin et Babary	2022-02-16 18:30:00	2022-02-16 19:30:00	\N	\N	1	0	\N	\N
505869	DELEGATION	AUCUNE	\N	\N	COLTER	Table ronde Grand Paris	\N	2020-11-26 09:35:00	2020-11-26 11:20:00	\N	\N	21	0	\N	\N
512836	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Accord OMS Statut diplomatique	\N	2020-12-01 14:00:00	2020-12-01 15:00:00	\N	\N	1	0	\N	\N
517643	GIA	AUCUNE	\N	\N	\N	Réunion	Assemblée générale 2020	2020-12-15 13:35:00	2020-12-15 14:10:00	\N	\N	12	0	590	\N
520346	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe	Assemblée générale du groupe	2021-01-13 08:30:00	2021-01-13 09:10:00	\N	\N	21	0	573	\N
521423	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2021-01-14 09:00:00	2021-01-14 14:00:00	\N	\N	6	0	\N	\N
524505	GIA	AUCUNE	\N	\N	\N	Audition ONG israéliennes intrusions	Audition d'ONG israéliennes sur les intrusions de l'armée dans les domiciles palestiniens	2021-01-26 15:00:00	2021-01-26 16:15:00	\N	\N	5	0	632	\N
524585	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Diverses mesures de justice sociale	\N	2021-01-26 14:30:00	2021-01-26 15:00:00	\N	\N	1	0	\N	\N
524587	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Diverses mesures de justice sociale	\N	2021-01-26 15:30:00	2021-01-26 16:30:00	\N	\N	3	0	\N	\N
529088	GIA	AUCUNE	\N	\N	\N	Audition d'Adel Bakawan, chercheur, en commun avec le GIA France-Irak	Audition d'Adel Bakawan	2021-02-02 14:00:00	2021-02-02 15:00:00	\N	\N	2	0	628	\N
529117	GIA	AUCUNE	\N	\N	\N	Visite de Mme Maïa Sandu, Présidente de la République de Moldavie	Visite de Mme Maïa Sandu, Présidente de la République de Moldavie	2021-02-04 17:15:00	2021-02-04 18:30:00	\N	\N	1	0	851	\N
529122	GIA	AUCUNE	\N	\N	\N	Audition de M. Joseph Bahout, directeur de l'Institut Issam Farès (UAB)	Audition de M. Joseph Bahout, directeur de l'Institut Issam Farès de l'Université américaine de Beyrouth	2021-02-02 13:30:00	2021-02-02 14:30:00	\N	\N	4	0	597	\N
529127	GIA	AUCUNE	\N	\N	\N	Entretien avec le Premier ministre sortant du Liban	Entretien en visioconférence avec M. Hassan Diab, Premier ministre sortant du Liban	2021-01-08 13:00:00	2021-01-08 14:00:00	\N	\N	4	0	597	\N
529132	GIA	AUCUNE	\N	\N	\N	Entretien avec le ministre sortant des affaires étrangères du Liban	Entretien en visioconférence avec M. Charbel Wehbé, ministre sortant des affaires étrangères du Liban	2021-01-07 10:15:00	2021-01-07 11:30:00	\N	\N	4	0	597	\N
529137	GIA	AUCUNE	\N	\N	\N	Entretien avec la ministre sortante de la justice du Liban	Entretien en visioconférence avec Mme Marie-Claude NAJM, ministre sortante de la justice du Liban	2021-01-11 09:30:00	2021-01-11 10:45:00	\N	\N	4	0	597	\N
529142	GIA	AUCUNE	\N	\N	\N	Entretien avec le Patriarche maronite	Visioconférence avec Sa Béatitude le Cardinal Béchara Boutros Raï, Patriarche maronite d'Antioche et de tout l'Orient	2021-01-11 08:30:00	2021-01-11 09:30:00	\N	\N	4	0	597	\N
529147	GIA	AUCUNE	\N	\N	\N	Entretien avec les représentants du parti des Forces libanaises en France	Entretien avec les représentants du parti des Forces libanaises en France	2020-11-25 15:30:00	2020-11-25 16:15:00	\N	\N	1	0	597	\N
529149	GIA	AUCUNE	\N	\N	\N	Conférence téléphonique avec l'ambassadrice de France à Beyrouth	Conférence téléphonique avec l'ambassadrice de France à Beyrouth	2020-11-27 13:00:00	2020-11-27 14:00:00	\N	\N	1	0	597	\N
529151	GIA	AUCUNE	\N	\N	\N	Entretien en visioconférence avec le Président du Rassemblement pour le Liban France	Entretien en visioconférence avec le Président du Rassemblement pour le Liban France	2020-12-15 14:30:00	2020-12-15 15:15:00	\N	\N	1	0	597	\N
529153	GIA	AUCUNE	\N	\N	\N	Entretien en visioconférence avec le Consul général de France à Beyrouth	Entretien en visioconférence avec le Consul général de France à Beyrouth	2020-11-13 13:00:00	2020-11-13 14:15:00	\N	\N	1	0	597	\N
533704	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI patrimoine culturel immatériel	\N	2021-02-16 14:45:00	2021-02-16 15:30:00	\N	\N	2	0	\N	\N
533707	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL fonction de directeur d'école	\N	2021-02-15 11:30:00	2021-02-15 13:00:00	\N	\N	3	0	\N	\N
533718	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL fonction de directeur d'école	\N	2021-02-15 15:00:00	2021-02-15 16:50:00	\N	\N	4	0	\N	\N
533724	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL fonction de directeur d'école	\N	2021-02-15 16:50:00	2021-02-15 18:20:00	\N	\N	4	0	\N	\N
536621	MISSION	AUDRAP	\N	PAUP	\N	Audition rapporteur	\N	2021-03-04 11:30:00	2021-03-04 12:45:00	\N	\N	3	0	\N	\N
539188	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL développement solidaire	Audition association Coordination sud, PJL développement solidaire	2021-03-09 15:00:00	2021-03-09 16:30:00	\N	\N	2	0	\N	\N
542362	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de M. Delfraissy	\N	2021-03-24 11:00:00	2021-03-24 12:40:00	2021-03-24 12:36:27	2021-03-24 17:39:12	36	0	\N	\N
542364	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2021-03-24 08:30:00	2021-03-24 10:35:00	2021-03-24 10:39:30	2021-03-24 17:39:17	35	0	\N	\N
542396	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Syndication - Agence France Trésor	Contrôle 2021 - Syndication - Agence France Trésor	2021-03-17 18:00:00	2021-03-17 19:30:00	\N	\N	1	0	\N	\N
542537	DELEGATION	AUDRAP	\N	\N	PROS	Audition de M. Eric Bothorel	\N	2021-03-22 09:00:00	2021-03-22 10:00:00	\N	\N	2	0	\N	\N
542570	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Désignation de rapporteurs et audition Mme Souâd Ayada	\N	2021-03-24 09:32:00	2021-03-24 11:23:00	2021-03-24 13:05:27	2021-03-24 17:39:15	34	0	\N	\N
542589	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de Mme Isabelle de Silva	\N	2021-03-24 09:35:00	2021-03-24 11:30:00	2021-03-24 11:48:40	2021-03-24 17:39:14	44	0	\N	\N
542703	MISSION	AUTRE	\N	VIETUDIA	\N	Table ronde "santé psychologique"	\N	2021-03-25 14:30:00	2021-03-25 17:30:00	\N	\N	11	0	\N	\N
542713	MISSION	AUCUNE	\N	VIETUDIA	\N	Table ronde santé des étudiants	\N	2021-03-25 11:05:00	2021-03-25 13:35:00	2021-03-25 15:19:40	2021-03-26 15:18:11	9	0	\N	\N
543601	GIA	AUCUNE	\N	\N	\N	audition de Mme Hélène Le GAL Ambassadrice de France au Maroc	\N	2021-03-23 15:15:00	2021-03-23 16:45:00	\N	\N	15	0	598	\N
543619	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Conseil européen	Débat  Conseil européen	2021-03-23 21:30:00	2021-03-24 23:55:00	\N	\N	38	0	\N	\N
545404	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Respect des principes de la République	PJL Respect des principes de la République	2021-03-30 14:30:00	2021-03-30 20:35:00	\N	\N	197	0	\N	\N
545405	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Respect des principes de la République	PJL Respect des principes de la République	2021-03-30 22:05:00	2021-03-31 00:30:00	\N	\N	119	0	\N	\N
545406	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2021-03-31 15:00:00	2021-03-31 16:20:00	\N	\N	206	0	\N	\N
545407	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Respect des principes de la République	PJL Respect des principes de la République	2021-03-31 16:30:00	2021-03-31 19:45:00	\N	\N	134	0	\N	\N
545408	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Respect des principes de la République	PJL Respect des principes de la République	2021-03-31 21:30:00	2021-04-01 01:05:00	\N	\N	103	0	\N	\N
545409	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL France-Argentine	PJL France-Argentine	2021-04-01 10:30:00	2021-04-01 11:20:00	\N	\N	38	0	\N	\N
545410	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PPL Courtage	CMP PPL Courtage	2021-04-01 11:25:00	2021-04-01 12:10:00	\N	\N	27	0	\N	\N
545411	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PPL Justice de proximité	CMP PPL Justice de proximité	2021-04-01 12:20:00	2021-04-01 13:10:00	\N	\N	21	0	\N	\N
545412	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	NL PPL Système de santé	NL PPL Système de santé	2021-04-01 17:40:00	2021-04-01 18:40:00	\N	\N	45	0	\N	\N
545414	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Respect des principes de la République	PJL Respect des principes de la République	2021-04-01 21:30:00	2021-04-02 00:30:00	\N	\N	51	0	\N	\N
545415	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Respect des principes de la République	PJL Respect des principes de la République	2021-04-01 18:40:00	2021-04-01 20:00:00	\N	\N	52	0	\N	\N
545416	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Respect des principes de la République	PJL Respect des principes de la République	2021-04-02 10:30:00	2021-04-02 13:10:00	\N	\N	49	0	\N	\N
545417	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Respect des principes de la République	PJL Respect des principes de la République	2021-04-02 14:40:00	2021-04-02 18:15:00	\N	\N	47	0	\N	\N
545418	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Respect des principes de la République	PJL Respect des principes de la République	2021-04-06 21:35:00	2021-04-07 00:35:00	\N	\N	98	0	\N	\N
548998	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - Direction générale du Trésor - Acteurs Export/Business France/BPIFrance	Contrôle 2020 - Direction générale du Trésor - Acteurs Export/Business France/BPIFrance	2021-03-30 13:30:00	2021-03-30 16:30:00	\N	\N	2	0	\N	\N
590902	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PJL Travailleurs indépendants	\N	2021-10-06 14:15:00	2021-10-06 14:45:00	\N	\N	2	0	\N	\N
590905	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Indépendants.co	\N	2021-10-06 16:30:00	2021-10-06 17:00:00	\N	\N	1	0	\N	\N
590907	COM_PERMANENTE	AUDRAP	\N	CAE	\N	U2P	\N	2021-10-07 18:15:00	2021-10-07 18:45:00	\N	\N	1	0	\N	\N
590916	MISSION	AUDRAP	\N	CONF	\N	Table ronde sur la situation en Guyane	Table ronde sur la situation en Guyane	2021-10-14 14:30:00	2021-10-14 16:10:00	\N	\N	5	0	\N	\N
590928	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-10-20 09:00:00	2021-10-20 12:13:00	2021-10-20 13:02:09	2021-10-20 17:17:53	36	0	\N	\N
590931	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-10-19 17:01:00	2021-10-19 17:09:00	2021-10-19 17:33:10	2021-10-20 17:17:52	29	0	\N	\N
590934	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n° 325 Catastrophes naturelles - CCR	PPL n° 325 Catastrophes naturelles - CCR	2021-10-08 15:00:00	2021-10-08 15:45:00	\N	\N	1	0	\N	\N
590947	DELEGATION	AUCUNE	\N	\N	DSOM	Audition Étude stratégie nationale maritime et outre-mer	\N	2021-10-14 09:30:00	2021-10-14 11:45:00	\N	\N	17	0	\N	\N
590949	ETUDES	AUTRE	\N	\N	\N	Audition Filière noisette	Audition Filière noisette	2021-10-13 13:30:00	2021-10-13 15:00:00	\N	\N	11	0	\N	1005
590965	DELEGATION	AUDRAP	\N	\N	COLTER	Audition de M.Cyril COTONAT - AMRF	\N	2021-10-26 14:00:00	2021-10-26 15:00:00	\N	\N	0	0	\N	\N
590967	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Rapporteur Guillaume KLOSSA	\N	2021-10-06 17:00:00	2021-10-06 18:15:00	\N	\N	2	0	\N	\N
590970	DELEGATION	AUDRAP	\N	\N	206	Audition de rapporteur	\N	2021-10-21 15:45:00	2021-10-21 16:45:00	\N	\N	1	0	\N	\N
590971	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteur	\N	2021-10-21 14:30:00	2021-10-21 15:30:00	\N	\N	1	0	\N	\N
590972	COM_EURO	AUDRAP	\N	AFEU	\N	Audition de M. Luc LIOGER	Audition rapporteur culture  M. Luc LIOGER	2021-10-07 10:30:00	2021-10-07 12:00:00	\N	\N	2	0	\N	\N
590975	DELEGATION	AUDRAP	\N	\N	PROS	Audition de rapporteur	\N	2021-10-14 10:45:00	2021-10-14 12:00:00	\N	\N	2	0	\N	\N
590976	DELEGATION	AUDRAP	\N	\N	PROS	Audition de rapporteur	\N	2021-10-12 16:00:00	2021-10-12 17:00:00	\N	\N	2	0	\N	\N
590977	DELEGATION	AUDRAP	\N	\N	PROS	Audition de rapporteur	\N	2021-10-12 14:00:00	2021-10-12 14:45:00	\N	\N	2	0	\N	\N
591080	DELEGATION	AUDRAP	\N	\N	COLTER	Audition de M. Stéphane PINTRE - SNDGCT	\N	2021-10-20 16:30:00	2021-10-20 17:30:00	\N	\N	0	0	\N	\N
591691	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJFS Financement de la sécurité sociale pour 2022 - Branche famille	\N	2021-10-12 16:30:00	2021-10-12 18:00:00	\N	\N	2	0	\N	\N
593093	GIA	AUCUNE	\N	\N	\N	Conférence sur la collaboration bilatérale France-Pologne	Conférence sur la collaboration bilatérale France-Pologne	2021-09-28 18:00:00	2021-09-28 21:00:00	\N	\N	1	0	600	\N
593094	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ambassadeur polonais à Paris	Entretien avec l'ambassadeur polonais à Paris	2021-10-14 16:00:00	2021-10-14 17:30:00	\N	\N	1	0	600	\N
593287	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation de Jérusalem Est	Accueil d'une délégation de Jérusalem Est 	2021-10-12 10:00:00	2021-10-12 11:30:00	\N	\N	3	0	632	\N
593312	QUESTURE	AUCUNE	\N	\N	\N	Réunion de Questure	Réunion de Questure	2021-10-14 09:10:00	2021-10-14 11:10:00	\N	\N	3	0	\N	\N
593321	COM_PERMANENTE	AUTRE	\N	ETRD	\N	2 auditions PLF 2022 et 2 conventions	\N	2021-10-20 09:30:00	2021-10-20 12:22:00	2021-10-20 14:13:00	2021-10-20 17:17:58	37	0	\N	\N
593322	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de M. Jean-Yves Le Drian PLF 2022	\N	2021-10-20 17:00:00	2021-10-20 18:47:00	2021-10-21 14:58:17	2021-10-21 18:34:42	27	0	\N	\N
593436	DELEGATION	AUCUNE	\N	\N	DSOM	Audition de Mme Annick Girardin, ministre de la mer	\N	2021-10-21 10:00:00	2021-10-21 11:45:00	\N	\N	14	0	\N	\N
593511	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2022 Autonomie - Audition du CNCPH	\N	2021-10-13 16:30:00	2021-10-13 17:30:00	\N	\N	2	0	\N	\N
593512	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2022 Autonomie - Audition de l'UNA	\N	2021-10-14 14:00:00	2021-10-14 15:00:00	\N	\N	3	0	\N	\N
593513	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Présence parentale - Table ronde d'associations	\N	2021-10-14 14:00:00	2021-10-14 15:15:00	\N	\N	1	0	\N	\N
593514	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Présence parentale - Audition de la CNAF	\N	2021-10-14 15:30:00	2021-10-14 16:30:00	\N	\N	2	0	\N	\N
593515	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Présence d'un enfant - Audition de la DSS	\N	2021-10-14 16:30:00	2021-10-14 17:30:00	\N	\N	2	0	\N	\N
593526	GIA	AUCUNE	\N	\N	\N	Dîner en l'honneur du Président du Tadjikistan E. RAHMON	Dîner du groupe d'amitié en présence du Président de la Rép. du Tadjikistan et du MAE	2021-10-13 19:00:00	2021-10-13 21:00:00	\N	\N	6	0	556	\N
593533	GIA	AUCUNE	\N	\N	\N	Audition de Farkhunda Naderi avec les GIA Afghanistan et Pakistan	Audition de Farkhunda Naderi ancienne députée afghane	2021-10-13 13:30:00	2021-10-13 14:45:00	\N	\N	7	0	556	\N
593545	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2022 : Dés. RS - Rapports Missions «Immigration, ...», «R&D» et «Anciens combat.»	PLF pour 2022 : Dés. RS - Rapports Missions «Immigration, asile et intégration», «Remboursement & dégrèvement» et «Ancie	2021-10-19 16:05:00	2021-10-19 17:40:00	2021-10-20 08:38:33	2021-10-20 17:17:51	32	0	\N	\N
593547	COM_PERMANENTE	AUTRE	\N	FINC	\N	AMDTS séance PPL383 & Rapport PJL806 - PLF pour 2022 : Rapport Mission « Sport » et FPIC	AMDTS séance PPL 383 & Rapport PJL 806 - PLF pour 2022 : Rapport Mission « Sport » et Contrôle FPIC	2021-10-20 09:35:00	2021-10-20 12:35:00	2021-10-20 15:43:08	2021-10-20 17:18:00	39	0	\N	\N
593548	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition Article 13 de M. François VILLEROY DE GALHAU	Audition Article 13 de M. François VILLEROY DE GALHAU, candidat proposé aux fonctions gouverneur de la Banque de France	2021-10-20 17:10:00	2021-10-20 18:20:00	2021-10-20 18:54:12	2021-10-21 18:34:43	24	0	\N	\N
593549	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 -  Anciens combattants - ONAC VG	PLF pour 2022 -  Anciens combattants - ONAC VG	2021-10-14 11:30:00	2021-10-14 12:45:00	\N	\N	1	0	\N	\N
593551	DELEGATION	AUDRAP	\N	\N	COLTER	Audition organises syndicaux - D.Alphand	\N	2021-11-23 15:00:00	2021-11-23 16:30:00	\N	\N	0	0	\N	\N
593552	DELEGATION	AUDRAP	\N	\N	COLTER	Audition UGAP - Territoires et tehnologies	\N	2021-11-09 14:00:00	2021-11-09 15:00:00	\N	\N	0	0	\N	\N
593553	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Sécurités - DGGN	PLF pour 2022 - Sécurités - DGGN	2021-10-11 09:00:00	2021-10-11 10:00:00	\N	\N	1	0	\N	\N
593555	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2022 - Sécurités - Déplacement DISR	PLF pour 2022 - Sécurités - Déplacement DISR	2021-10-12 14:00:00	2021-10-12 17:00:00	\N	\N	1	0	\N	\N
593557	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - R&D - Chercheurs CIR	PLF pour 2022 - R&D - Chercheurs CIR	2021-10-06 10:30:00	2021-10-06 12:30:00	\N	\N	1	0	\N	\N
593559	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - R&D - France Stratégie	PLF pour 2022 - R&D - France Stratégie	2021-10-11 11:00:00	2021-10-11 12:15:00	\N	\N	1	0	\N	\N
593561	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - R&D - DG Trésor et MIN Mires	PLF pour 2022 - R&D - DG Trésor et MIN Mires	2021-10-12 09:30:00	2021-10-12 11:00:00	\N	\N	1	0	\N	\N
593563	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - AGTE - SG-CIPDR	PLF pour 2022 - AGTE - SG-CIPDR	2021-10-12 14:30:00	2021-10-12 16:00:00	\N	\N	1	0	\N	\N
593565	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - AGTE - Direction du numérique MIN Intérieur	PLF pour 2022 - AGTE - Direction du numérique MIN Intérieur	2021-10-12 16:30:00	2021-10-12 18:00:00	\N	\N	1	0	\N	\N
593567	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 Plan de Transformation Numérique Justice - Cour des comptes	58-2 Plan de Transformation Numérique Justice - Cour des comptes	2021-10-12 15:00:00	2021-10-12 16:00:00	\N	\N	1	0	\N	\N
593569	COM_PERMANENTE	AUTRE	\N	AFCL	\N	PJLF Budget 2022 - Crédits Sport - Audition plénière	PJLF Budget 2022 - Crédits Sport - Audition plénière	2021-10-26 17:10:00	2021-10-26 18:55:00	2021-10-27 11:45:51	2021-10-27 19:08:47	23	0	\N	\N
593570	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur - PJL Ratification travailleurs de plateformes	\N	2021-10-18 15:00:00	2021-10-18 16:30:00	\N	\N	1	0	\N	\N
593576	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur - PJL Ratification travailleurs de plateformes	\N	2021-10-18 17:00:00	2021-10-18 18:00:00	\N	\N	1	0	\N	\N
593579	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n° 325 Catastrophes naturelles - Min ECOFIN	PPL n° 325 Catastrophes naturelles - Min ECOFIN	2021-10-14 12:00:00	2021-10-14 13:00:00	\N	\N	1	0	\N	\N
518034	GIA	AUCUNE	\N	\N	\N	Réunion constitutive	Réunion constitutive	2020-12-16 14:15:00	2020-12-16 14:45:00	\N	\N	7	0	618	\N
520633	GIA	AUCUNE	\N	\N	\N	AG reconstitutive + audition de l'ambassadeur de France en Ukraine	\N	2021-01-13 13:45:00	2021-01-13 15:00:00	\N	\N	6	0	530	\N
533380	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Système de santé	PPL Système de santé	2021-02-17 21:35:00	2021-02-18 00:40:00	\N	\N	51	0	\N	\N
539688	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de M. Jean-Yves Le Drian	Audition de M. Jean-Yves Le Drian	2021-03-16 17:00:00	2021-03-16 18:40:00	2021-03-17 09:59:45	2021-03-17 16:58:54	33	0	\N	\N
539689	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de MM. Antoine Bouvier et Dirk Hoke	Audition de MM. Antoine Bouvier et Dirk Hoke	2021-03-17 10:00:00	2021-03-17 11:50:00	2021-03-17 17:15:43	2021-03-18 17:52:20	34	0	\N	\N
539690	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de Mme Florence Parly	Audition de Mme Florence Parly	2021-03-17 17:00:00	2021-03-17 19:00:00	2021-03-18 10:47:53	2021-03-18 17:52:17	26	0	\N	\N
550905	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne	2021-04-07 16:30:00	2021-04-07 17:45:00	2021-04-08 10:36:47	2021-04-08 14:31:53	6	0	\N	\N
550941	GIA	AUCUNE	\N	\N	\N	Audition de S.E. Mme Natasa Maric, Ambassadrice de Serbie en France 	Audition de S.E. Mme Natasa Maric, Ambassadrice de Serbie en France 	2021-04-08 09:00:00	2021-04-08 10:30:00	\N	\N	6	0	674	\N
583188	MISSION	PLEIN_NON_JO	\N	INFLUENCES	\N	Audition de Mme Frédérique Vidal	\N	2021-09-09 16:35:00	2021-09-09 17:50:00	\N	\N	7	0	\N	\N
585569	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Ministère de l'Éducation nationale, de la Jeunesse et des sports - Direction des sports	\N	2021-09-23 09:30:00	2021-09-23 10:30:00	\N	\N	5	0	\N	\N
585570	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Audition commune Ligue de Football Professionnel / FFF	\N	2021-09-23 10:30:00	2021-09-23 11:30:00	\N	\N	5	0	\N	\N
585571	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Collectif des victimes du 5 mai 1992	\N	2021-09-23 16:00:00	2021-09-23 16:45:00	\N	\N	2	0	\N	\N
585577	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL et PJLO Confiance dans l'institution judiciaire (amendements)	PJL et PJLO Confiance dans l'institution judiciaire (amendements)	2021-09-28 09:05:00	2021-09-28 10:35:00	2021-09-28 11:14:12	2021-09-28 18:20:32	24	0	\N	\N
585578	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Examen du rapport d'information sur les mineurs non accompagnés	Examen du rapport d'information sur les mineurs non accompagnés	2021-09-29 08:35:00	2021-09-29 10:10:00	2021-09-29 13:21:26	2021-09-29 18:17:38	67	0	\N	\N
585579	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désignations - PPL Encadrement fonction publique (rapport) - PJL Confiance justice (amdts)	Désignations - PPL Encadrement fonction publique (rapport) - PJL Confiance justice (amdts)	2021-09-29 10:15:00	2021-09-29 11:00:00	2021-09-29 12:27:50	2021-09-29 18:17:53	25	0	\N	\N
585586	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur - Audition France Assos santé - APF France Handicap	\N	2021-09-22 14:00:00	2021-09-22 14:45:00	\N	\N	2	0	\N	\N
585625	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 29 septembre 2021	Réunion du 29 septembre 2021	2021-09-29 13:35:00	2021-09-29 14:50:00	2021-09-29 14:53:19	2021-09-29 18:20:04	16	0	\N	\N
585637	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur - Collectif Tenir ta main	Audition rapporteur - Collectif Tenir ta main	2021-09-22 16:30:00	2021-09-22 17:15:00	\N	\N	2	0	\N	\N
585650	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2021-09-27 15:00:00	2021-09-27 16:05:00	2021-09-27 16:46:23	2021-09-27 18:09:31	24	0	\N	\N
585653	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2021-09-29 08:35:00	2021-09-29 10:10:00	2021-09-29 13:10:08	2021-09-29 18:17:39	68	0	\N	\N
585658	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2021-09-29 10:15:00	2021-09-29 12:00:00	2021-09-29 13:12:59	2021-09-29 18:17:56	35	0	\N	\N
585659	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition Adrien Taquet	Audition Adrien Taquet	2021-09-29 13:30:00	2021-09-29 15:10:00	2021-09-29 15:09:57	2021-09-29 18:17:57	22	0	\N	\N
585683	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	 PPL Accélérer l'égalité économique et professionnelle - Audition CPU - CGE - FESIC	\N	2021-09-28 18:30:00	2021-09-28 19:45:00	\N	\N	1	0	\N	\N
585684	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Accélérer l'égalité économique et professionnelle - Audition Banque de France	\N	2021-09-29 16:00:00	2021-09-29 16:45:00	\N	\N	1	0	\N	\N
585686	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition UNAF	\N	2021-09-30 16:00:00	2021-09-30 16:45:00	\N	\N	2	0	\N	\N
585690	DELEGATION	AUDRAP	\N	\N	COLTER	Table ronde conclusive avec les associations d'élus locaux	\N	2021-09-30 08:45:00	2021-09-30 11:40:00	\N	\N	0	0	\N	\N
585691	COM_PERMANENTE	AUTRE	\N	CAE	\N	\N	\N	2021-09-29 09:30:00	2021-09-29 10:10:00	2021-10-07 11:30:35	2021-10-07 11:31:11	37	0	\N	\N
585698	DELEGATION	AUDRAP	\N	\N	COLTER	Auditions de régulateurs et financeurs du système de santé	\N	2021-09-30 14:00:00	2021-09-30 15:30:00	\N	\N	0	0	\N	\N
585700	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteur	\N	2021-09-21 15:30:00	2021-09-21 16:30:00	\N	\N	1	0	\N	\N
585702	DELEGATION	AUCUNE	\N	\N	206	Auditions plénières	\N	2021-09-23 09:40:00	2021-09-23 13:25:00	2021-09-24 10:01:25	\N	9	0	\N	\N
585717	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteur	\N	2021-09-21 16:30:00	2021-09-21 17:30:00	\N	\N	1	0	\N	\N
585719	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteur	\N	2021-09-22 16:30:00	2021-09-22 17:30:00	\N	\N	1	0	\N	\N
585720	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteur	\N	2021-09-23 14:30:00	2021-09-23 16:00:00	\N	\N	1	0	\N	\N
585886	CONF_PRES	AUCUNE	\N	\N	\N	Conf Prés	Conférence des Présidents	2021-09-21 18:05:00	2021-09-21 18:45:00	\N	\N	25	0	\N	\N
586384	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Recours des parlementaires pour excès de pouvoir	\N	2021-09-27 17:00:00	2021-09-27 19:00:00	\N	\N	1	0	\N	\N
586386	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Recours des parlementaires pour excès de pouvoir	\N	2021-09-28 09:00:00	2021-09-28 11:00:00	\N	\N	1	0	\N	\N
586402	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLO Implantation locale des parlementaires	\N	2021-09-27 14:00:00	2021-09-27 18:00:00	\N	\N	1	0	\N	\N
586503	GIA	AUCUNE	\N	\N	\N	Déplacement au Bénin et au Togo	Déplacement d'une délégation du groupe d'amitié au Bénin et au Togo	2021-09-20 11:30:00	2021-09-27 00:00:00	\N	\N	4	0	573	\N
586527	GIA	AUCUNE	\N	\N	\N	Rendez-vous avec le Directeur d'Asie	Rendez-vous avec le Directeur d'Asie	2021-09-21 10:30:00	2021-09-21 11:30:00	\N	\N	2	0	623	\N
586530	GIA	AUCUNE	\N	\N	\N	Rendez-vous avec la DG du Trésor	Rendez-vous avec la DG du Trésor	2021-09-30 09:30:00	2021-09-30 10:30:00	\N	\N	4	0	623	\N
586535	GIA	AUCUNE	\N	\N	\N	Déjeuner avec le Représentant de Taipei	Déjeuner avec le Représentant de Taipei	2021-09-28 12:30:00	2021-09-28 14:30:00	\N	\N	3	0	623	\N
588529	SEANCE_PLENIERE	ELOGE_FUNEBRE	\N	\N	\N	Éloge funèbre Patrick Boré	Éloge funèbre Patrick Boré	2021-10-05 14:30:00	2021-10-05 14:55:00	\N	\N	60	0	\N	\N
588530	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR Lutte antisémitime	PPR Lutte antisémitime	2021-10-05 15:15:00	2021-10-05 16:40:00	\N	\N	116	0	\N	\N
588531	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR Reconnaissance UN Birmanie	PPR Reconnaissance UN Birmanie	2021-10-05 16:40:00	2021-10-05 17:55:00	\N	\N	68	0	\N	\N
588532	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Situation sanitaire outre-mer	Débat Situation sanitaire outre-mer	2021-10-05 21:30:00	2021-10-05 23:05:00	\N	\N	35	0	\N	\N
588534	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Pacte européen	Débat Pacte européen	2021-10-05 17:55:00	2021-10-05 19:20:00	\N	\N	51	0	\N	\N
588536	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2021-10-06 15:00:00	2021-10-06 16:15:00	\N	\N	236	0	\N	\N
588539	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Réforme encadrement supérieur FP	PPL Réforme encadrement supérieur FP	2021-10-06 16:30:00	2021-10-06 19:10:00	\N	\N	69	0	\N	\N
613379	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2021-12-09 09:10:00	2021-12-09 11:05:00	\N	\N	3	0	\N	\N
613815	COM_PERMANENTE	PLEIN_NON_JO	\N	ETRD	\N	Conférence des présidents de l'UE à l'AN	Conférence des présidents de l'UE à l'AN	2021-12-09 14:30:00	2021-12-09 16:30:00	\N	\N	1	0	\N	\N
615587	ETUDES	AUCUNE	\N	\N	\N	Audition CNPF	Audition CNPF	2021-12-15 08:15:00	2021-12-15 09:00:00	\N	\N	12	0	\N	948
616185	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	Assemblée générale du groupe d'études Français de l'étranger	Groupe d'études "Statut, rôle et place des Français établis hors de France"	2021-12-14 16:45:00	2021-12-14 17:00:00	\N	\N	6	0	\N	\N
616192	GIA	AUCUNE	\N	\N	\N	Table ronde sur les écoles chrétiennes francophones du Liban	Audition	2021-12-15 16:30:00	2021-12-15 18:30:00	\N	\N	6	0	CHRETORIENT	CHRETORIENT
616205	GIA	AUCUNE	\N	\N	\N	Conférence à l'IMA sur les écoles chrétiennes francophones du Liban	Conférence "Ecoles francophones chrétiennes du Liban"	2021-12-15 19:00:00	2021-12-15 20:30:00	\N	\N	1	0	CHRETORIENT	CHRETORIENT
616270	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Port du casque à vélo et dans le cadre d'autres moyens de transport	PPL Port du casque à vélo et dans le cadre d'autres moyens de transport	2021-12-16 15:00:00	2021-12-16 16:00:00	\N	\N	2	0	\N	\N
616273	MECSS	AUCUNE	\N	\N	MECSS	Réunion plénière	\N	2022-01-04 15:00:00	2022-01-04 15:35:00	2022-01-04 15:36:24	2022-01-04 18:07:02	8	0	\N	\N
616365	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Fédération nationale des Associations et syndicats de sportifs	\N	2021-12-22 10:30:00	2021-12-22 11:40:00	\N	\N	2	0	\N	\N
616366	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Réunion de travail avec l'Insep	\N	2021-12-22 14:30:00	2021-12-22 15:30:00	\N	\N	1	0	\N	\N
616367	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Ministère des sports	Audition de Mme Christèle Gautier	2021-12-20 18:00:00	2021-12-20 19:10:00	\N	\N	3	0	\N	\N
616373	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	comité national olympique et sportif français	Audition de Skander Karaa	2021-12-22 11:30:00	2021-12-22 12:50:00	\N	\N	1	0	\N	\N
618606	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Auditions Mme Patricia Demas	\N	2022-01-04 14:30:00	2022-01-04 17:45:00	\N	\N	0	0	\N	\N
618610	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Audition Mmes Martine Filleul et Christine Herzog	\N	2022-01-04 14:30:00	2022-01-04 15:15:00	\N	\N	0	0	\N	\N
618615	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Auditions Mmes Martine Filleul et Catherine Herzog	\N	2022-01-04 17:00:00	2022-01-04 17:45:00	\N	\N	0	0	\N	\N
618620	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Auditions BBelin et CHerzog	\N	2022-01-04 15:15:00	2022-01-04 16:00:00	\N	\N	0	0	\N	\N
618676	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Audition BBelin et CHertzog / JM	\N	2022-01-05 08:30:00	2022-01-05 09:30:00	\N	\N	0	0	\N	\N
618680	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Auditions Mmes Martine Filleul et Catherine Herzog	\N	2022-01-05 16:30:00	2022-01-05 18:15:00	\N	\N	0	0	\N	\N
618684	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Audition PDemas / CB	\N	2022-01-05 14:00:00	2022-01-05 15:00:00	\N	\N	0	0	\N	\N
618692	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL 225 Assurance emprunteur - CCSF/APCADE/FBF	PPL 225 Assurance emprunteur - CCSF/APCADE/FBF	2022-01-04 14:00:00	2022-01-04 17:35:00	\N	\N	1	0	\N	\N
618694	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL 225 Assurance emprunteur - Association Les Séropotes	PPL 225 Assurance emprunteur - Association Les Séropotes	2022-01-05 09:30:00	2022-01-05 10:30:00	\N	\N	1	0	\N	\N
618696	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL 225 Assurance emprunteur - FFA	PPL 225 Assurance emprunteur - FFA	2022-01-06 10:30:00	2022-01-06 11:15:00	\N	\N	1	0	\N	\N
618698	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 2021 - Plan de relance - Cour des comptes	58-2 2021 - Plan de relance - Cour des comptes	2022-01-05 14:00:00	2022-01-05 15:00:00	\N	\N	1	0	\N	\N
618835	MISSION	AUCUNE	\N	FONDSMER	\N	Réunion constitutive	\N	2022-01-11 14:30:00	2022-01-11 15:10:00	2022-01-11 15:08:40	2022-01-11 16:49:57	12	0	\N	\N
621283	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Audition plénière - Cabinet McKinsey - Table ronde de sociologues	\N	2022-01-18 14:30:00	2022-01-18 17:30:00	\N	\N	0	0	\N	\N
621284	COM_ENQUETE	AUDRAP	\N	HOPITAL	\N	CE Hôpital - Auditions rapporteure	\N	2022-01-13 09:00:00	2022-01-13 11:45:00	\N	\N	5	0	\N	\N
621292	MISSION	AUCUNE	\N	JUDI	\N	Table ronde de spécialistes de droit constitutionnel	Table ronde de spécialistes de droit constitutionnel	2022-01-18 15:00:00	2022-01-18 17:15:00	2022-01-18 18:30:54	2022-01-19 16:56:37	9	0	\N	\N
621308	GIA	AUCUNE	\N	\N	\N	Entretien Ambassadeur République slovaque	Entretien avec S.E. M. Igor SLOBODNIK, Ambassadeur de la République slovaque en France	2021-05-06 20:00:00	2021-05-06 22:30:00	\N	\N	3	0	532	\N
621312	GIA	AUCUNE	\N	\N	\N	Déplacement en Andorre	Déplacement d'une délégation du groupe en Andorre	2021-10-14 20:00:00	2021-10-16 08:00:00	\N	\N	5	0	963	\N
621344	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Aménagement du Rhône : Voies navigables de France	Auditions Aménagement du Rhône : Voies navigables de France	2022-01-12 18:30:00	2022-01-12 19:00:00	\N	\N	1	0	\N	\N
621345	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PPL Aménagement du Rhône : table ronde des syndicats	Audition PPL Aménagement du Rhône : table ronde des syndicats	2022-01-12 19:00:00	2022-01-12 19:45:00	\N	\N	2	0	\N	\N
621346	COM_ENQUETE	PLENIERE	\N	MEDIA	\N	audition CEmédias	\N	2022-01-13 14:30:00	2022-01-13 16:30:00	2022-01-13 18:46:10	2022-01-14 19:15:06	10	0	\N	\N
621348	COM_ENQUETE	PLENIERE	\N	MEDIA	\N	audition CEmédias	\N	2022-01-14 10:30:00	2022-01-14 12:25:00	2022-01-14 17:43:06	2022-01-14 19:15:07	10	0	\N	\N
621351	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Aménagement Rhône : Compagnie nationale du Rhône	Auditions Aménagement Rhône : Compagnie nationale du Rhône	2022-01-13 09:30:00	2022-01-13 11:00:00	\N	\N	1	0	\N	\N
621613	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2022-01-05 18:30:00	2022-01-05 19:00:00	\N	\N	20	0	\N	\N
621763	GIA	AUCUNE	\N	\N	\N	Audition de M. Tebogo SEOKOLO, Ambassadeur d¿Afrique du Sud en France	Audition de M. Tebogo SEOKOLO, Ambassadeur d¿Afrique du Sud en France (Déjeuner au Restaurant du Sénat)	2021-09-28 12:45:00	2021-09-28 14:30:00	\N	\N	3	0	574	\N
622465	COM_EURO	AUDRAP	\N	AFEU	\N	Paquet climat - Ajustement à l'objectif 55 - secteur énergie	Paquet climat - Ajustement à l'objectif 55 - secteur énergie	2022-01-18 18:00:00	2022-01-18 20:10:00	\N	\N	2	0	\N	\N
622482	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition INRAE	\N	2022-01-12 17:00:00	2022-01-12 17:45:00	\N	\N	5	0	\N	\N
622488	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions M. Laurent Duplomb	\N	2022-01-12 14:00:00	2022-01-12 19:00:00	\N	\N	5	0	\N	\N
622495	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Fédération française des producteurs d'oléagineux et de protéagineux	\N	2022-01-13 09:00:00	2022-01-13 09:30:00	\N	\N	5	0	\N	\N
622501	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition de la Fédération nationale des producteurs de lait	\N	2022-01-13 09:30:00	2022-01-13 10:00:00	\N	\N	5	0	\N	\N
622507	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Confédération générale des planteurs de betteraves	\N	2022-01-13 10:00:00	2022-01-13 10:30:00	\N	\N	3	0	\N	\N
622511	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions AGEA	\N	2022-01-13 10:30:00	2022-01-13 11:00:00	\N	\N	3	0	\N	\N
622515	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Fédération nationale bovine	\N	2022-01-13 11:00:00	2022-01-13 11:30:00	\N	\N	3	0	\N	\N
622519	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Direction générale des outre-mer	\N	2022-01-13 11:30:00	2022-01-13 12:00:00	\N	\N	1	0	\N	\N
622521	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Table ronde représentants Vignes et vins	Table ronde représentants Vignes et vins	2022-01-13 15:00:00	2022-01-13 16:30:00	\N	\N	3	0	\N	\N
622525	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Atekka In vivo PJL Outils de gestion des risques climatiques en agriculture	Auditions Atekka In vivo PJL Outils de gestion des risques climatiques en agriculture	2022-01-18 14:00:00	2022-01-18 14:30:00	\N	\N	4	0	\N	\N
622574	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Compagnie assurance l'Etoile	\N	2022-01-18 14:30:00	2022-01-18 15:00:00	\N	\N	4	0	\N	\N
622579	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Caisse centrale de réassurance	\N	2022-01-18 15:00:00	2022-01-18 15:30:00	\N	\N	4	0	\N	\N
622584	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition M. Arnaud Matrenchar	\N	2022-01-18 15:30:00	2022-01-18 16:00:00	\N	\N	5	0	\N	\N
622590	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition APCA	Audition APCA PJL Outils de gestion des risques climatiques en agriculture	2022-01-18 16:00:00	2022-01-18 16:30:00	\N	\N	5	0	\N	\N
622596	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition CA Assurances	Audition CA Assurances PJL Outils de gestion des risques climatiques en agriculture	2022-01-18 16:30:00	2022-01-18 17:00:00	\N	\N	5	0	\N	\N
508434	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	206	Réunion du Bureau de l'Office	Réunion de Bureau de l'Office	2020-11-26 11:10:00	2020-11-26 12:10:00	\N	\N	6	0	\N	\N
515996	DELEGATION	AUDRAP	\N	\N	206	Audition Production d'hydrogène - Table ronde enseignants-chercheurs	Audition Production d'hydrogène - Table ronde enseignants-chercheurs	2020-12-10 16:30:00	2020-12-10 18:30:00	\N	\N	1	0	\N	\N
521361	DELEGATION	AUDRAP	\N	\N	206	Audition ASTRID - M. Jean-Charles Hourcade - CNRS	Audition ASTRID - M. Jean-Charles Hourcade - CNRS	2021-01-20 17:00:00	2021-01-20 18:15:00	\N	\N	1	0	\N	\N
524218	GIA	AUCUNE	\N	\N	\N	Assemblée générale GIA France-Afrique australe	Assemblée générale GIA France-Afrique australe	2020-12-15 13:30:00	2020-12-15 14:00:00	\N	\N	8	0	646	\N
524227	GIA	AUCUNE	\N	\N	\N	Assemblée générale GIA France-Australie	Assemblée générale GIA France-Australie	2020-12-16 13:30:00	2020-12-16 14:30:00	\N	\N	6	0	578	\N
524234	GIA	AUCUNE	\N	\N	\N	Assemblée générale GIA France-Indonésie et Timor Est	Assemblée générale GIA France-Indonésie et Timor Est	2021-01-13 14:00:00	2021-01-13 15:00:00	\N	\N	6	0	653	\N
530201	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Principes de la République	\N	2021-02-09 14:30:00	2021-02-09 16:40:00	\N	\N	6	0	\N	\N
530210	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Principes de la République	\N	2021-02-09 16:40:00	2021-02-09 17:40:00	\N	\N	4	0	\N	\N
530221	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Principes de la République	\N	2021-02-09 17:40:00	2021-02-09 18:40:00	\N	\N	5	0	\N	\N
531071	DELEGATION	AUCUNE	\N	\N	206	Entretien avec François KEPES, membre de l¿Académie des Technologies et de l¿Académie d¿Ag	Entretien avec François KEPES, membre de l¿Académie des Technologies et de l¿Académie d¿Agriculture de France	2021-02-12 15:00:00	2021-02-12 16:00:00	\N	\N	0	0	\N	\N
542814	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - PPL Protéger les mineurs des crimes et délits sexuels et de l'incest	Protéger les mineurs des crimes et délits sexuels et de l'inceste	2021-03-18 15:30:00	2021-03-18 16:25:00	\N	\N	1	0	\N	\N
542824	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI "Difficultés des entreprises et crise de la Covid-19"	Audition rapporteur - MI "Difficultés des entreprises et crise de la Covid-19"	2021-03-16 13:30:00	2021-03-16 14:30:00	\N	\N	2	0	\N	\N
542829	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI "Difficultés des entreprises et crise de la Covid-19"	Audition rapporteur - MI "Difficultés des entreprises et crise de la Covid-19"	2021-03-16 15:30:00	2021-03-16 16:30:00	\N	\N	2	0	\N	\N
542834	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI "Difficultés des entreprises et crise de la Covid-19"	Audition rapporteur - MI "Difficultés des entreprises et crise de la Covid-19"	2021-03-16 16:30:00	2021-03-16 17:15:00	\N	\N	2	0	\N	\N
542837	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI "Difficultés des entreprises et crise de la Covid-19"	\N	2021-03-16 17:15:00	2021-03-16 18:00:00	\N	\N	2	0	\N	\N
549003	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition article 13 CNES	\N	2021-04-07 09:05:00	2021-04-07 10:05:00	2021-04-08 15:47:47	2021-04-08 16:04:10	40	0	\N	\N
549004	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de l'ASN	\N	2021-04-07 11:00:00	2021-04-07 12:50:00	2021-04-08 15:52:35	2021-04-08 16:04:08	43	0	\N	\N
549005	DELEGATION	AUTRE	\N	\N	DSOM	Tables rondes "Logement dans les outre-mer"	\N	2021-04-15 14:30:00	2021-04-15 18:00:00	\N	\N	10	0	\N	\N
549006	DELEGATION	AUCUNE	\N	\N	DSOM	Table ronde sur le logement : La Réunion	\N	2021-04-13 14:30:00	2021-04-13 16:15:00	\N	\N	8	0	\N	\N
549007	DELEGATION	AUCUNE	\N	\N	211	Examen du rapport d'information : l'égalité H/F comme enjeu de l'APD	Examen du rapport d'information : l'égalité H/F comme enjeu de l'APD	2021-05-04 17:00:00	2021-05-04 17:45:00	2021-05-04 18:25:11	\N	9	0	\N	\N
549008	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL n° 404 Développement solidaire - AFD	PJL n° 404 Développement solidaire - AFD	2021-04-01 13:30:00	2021-04-01 14:30:00	\N	\N	2	0	\N	\N
549011	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL n° 404 Développement solidaire - Expertise France	PJL n° 404 Développement solidaire - Expertise France	2021-04-01 17:30:00	2021-04-01 18:30:00	\N	\N	2	0	\N	\N
549014	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL n° 404 Développement solidaire -  Cabinet MEAE/Transparency International	PJL n° 404 Développement solidaire -  Cabinet MEAE/Transparency International	2021-04-02 15:00:00	2021-04-02 16:45:00	\N	\N	2	0	\N	\N
549282	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Convention citoyenne pour le climat - Groupe Consommer	\N	2021-04-06 08:30:00	2021-04-06 09:30:00	\N	\N	8	0	\N	\N
549291	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Comité français de l¿Union internationale pour la conservation de la nature	\N	2021-04-06 09:30:00	2021-04-06 10:30:00	\N	\N	8	0	\N	\N
549300	COM_PERMANENTE	AUDRAP	\N	CDD	\N	UFC - Que choisir	\N	2021-04-06 10:15:00	2021-04-06 11:00:00	\N	\N	7	0	\N	\N
549309	MISSION	AUCUNE	\N	CONF	\N	Réunion plénière Examen des recommandations relatives à la réouverture des lieux culturels	Réunion plénière Examen des recommandations relatives à la réouverture des lieux culturels	2021-04-13 09:00:00	2021-04-13 09:45:00	2021-04-13 11:18:15	2021-04-14 18:26:28	9	0	\N	\N
550815	ETUDES	AUCUNE	\N	\N	\N	Audition M. Douzain-Didier	Audition M. Douzain-Didier	2021-04-07 08:15:00	2021-04-07 09:15:00	\N	\N	19	0	\N	948
550835	ETUDES	AUCUNE	\N	\N	\N	Audition de M. Jérôme Saddier	Audition de M. Jérôme Saddier	2021-04-07 08:30:00	2021-04-07 09:30:00	\N	\N	5	0	\N	998
551506	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT Boussole stratégique	\N	2021-04-09 14:30:00	2021-04-09 15:45:00	\N	\N	2	0	\N	\N
552290	ETUDES	AUCUNE	\N	\N	\N	Audition FNPF	Audition FNPF	2021-04-14 08:00:00	2021-04-14 09:00:00	\N	\N	17	0	\N	907
553341	ETUDES	AUCUNE	\N	\N	\N	Réunion GE Agriculture et alimentation	Réunion GE Agriculture et alimentation	2021-04-14 13:30:00	2021-04-14 15:00:00	\N	\N	47	0	\N	919
554779	DELEGATION	AUDRAP	\N	\N	206	Audition Stratégie vaccinale - Lulla Opatowski, Laura Temime	Audition Stratégie vaccinale - Lulla Opatowski, Laura Temime	2021-04-15 12:30:00	2021-04-15 13:45:00	\N	\N	4	0	\N	\N
554818	GIA	AUCUNE	\N	\N	\N	Audition de M. Marc Baréty, ambassadeur de France au Pakistan	\N	2021-04-14 08:15:00	2021-04-14 09:00:00	\N	\N	4	0	619	\N
554856	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PJL Climat volet se nourrir	Auditions PJL Climat Volet Se Nourrir	2021-04-19 10:15:00	2021-04-19 12:30:00	\N	\N	1	0	\N	\N
555444	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Dérèglement climatique et résilience - Auditions de M. Philippe Tabarot	PJL Dérèglement climatique et résilience - Auditions de M. Philippe Tabarot	2021-04-27 08:30:00	2021-04-27 10:00:00	\N	\N	2	0	\N	\N
555445	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Dérèglement climatique et résilience - Auditions de M. Philippe Tabarot	PJL Dérèglement climatique et résilience - Auditions de M. Philippe Tabarot	2021-04-27 10:00:00	2021-04-27 10:45:00	\N	\N	3	0	\N	\N
555446	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Dérèglement climatique et résilience - Auditions de M. Philippe Tabarot	PJL Dérèglement climatique et résilience - Auditions de M. Philippe Tabarot	2021-04-27 11:00:00	2021-04-27 11:45:00	\N	\N	3	0	\N	\N
555447	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Dérèglement climatique et résilience - Auditions de M. Philippe Tabarot	PJL Dérèglement climatique et résilience - Auditions de M. Philippe Tabarot	2021-04-27 11:45:00	2021-04-27 12:30:00	\N	\N	2	0	\N	\N
555458	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Dérèglement climatique et résilience - Auditions de M. Philippe Tabarot	PJL Dérèglement climatique et résilience - Auditions de M. Philippe Tabarot	2021-04-27 14:03:00	2021-04-27 19:31:00	\N	\N	2	0	\N	\N
555461	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Dérèglement climatique et résilience - Auditions de M. Philippe Tabarot	PJL Dérèglement climatique et résilience - Auditions de M. Philippe Tabarot	2021-04-28 08:30:00	2021-04-28 12:30:00	\N	\N	2	0	\N	\N
555462	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Dérèglement climatique et résilience - Auditions de M. Philippe Tabarot	PJL Dérèglement climatique et résilience - Auditions de M. Philippe Tabarot	2021-04-29 14:45:00	2021-04-29 15:45:00	\N	\N	1	0	\N	\N
555463	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Dérèglement climatique et résilience - Auditions de M. Philippe Tabarot	PJL Dérèglement climatique et résilience - Auditions de M. Philippe Tabarot	2021-04-29 16:00:00	2021-04-29 16:45:00	\N	\N	2	0	\N	\N
593582	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Cohésion des territoires - Logement-Urbanisme - DIHAL	PLF pour 2022 - Cohésion des territoires - Logement-Urbanisme - DIHAL	2021-10-13 17:30:00	2021-10-13 18:30:00	\N	\N	1	0	\N	\N
593584	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Solidarité - ADF	PLF pour 2022 - Solidarité - ADF	2021-10-12 14:00:00	2021-10-12 15:00:00	\N	\N	2	0	\N	\N
593588	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Solidarité - TR aide alimentaire	PLF pour 2022 - Solidarité - TR aide alimentaire	2021-10-12 15:15:00	2021-10-12 16:45:00	\N	\N	2	0	\N	\N
593591	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Solidarité - DGCS	PLF pour 2022 - Solidarité - DGCS	2021-10-12 16:45:00	2021-10-12 18:00:00	\N	\N	2	0	\N	\N
593604	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Culture - SG MIN Culture/TR Opérateurs création	PLF pour 2022 - Culture - SG MIN Culture/TR Opérateurs création	2021-10-12 14:10:00	2021-10-12 16:10:00	\N	\N	2	0	\N	\N
593608	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - RSR - Direction des affaires maritimes	PLF pour 2022 - RSR - Direction des affaires maritimes	2021-10-13 14:00:00	2021-10-13 15:10:00	\N	\N	1	0	\N	\N
593611	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Culture - TR Opérateurs du patrimoine	PLF pour 2022 - Culture - TR Opérateurs du patrimoine	2021-10-13 16:00:00	2021-10-13 17:10:00	\N	\N	2	0	\N	\N
593615	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - RSR - DGITM	PLF pour 2022 - RSR - DGITM	2021-10-14 09:30:00	2021-10-14 10:30:00	\N	\N	1	0	\N	\N
593632	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Médias - Arte France/DGMIC	PLF pour 2022 - Médias - Arte France/DGMIC	2021-10-15 10:00:00	2021-10-15 12:25:00	\N	\N	1	0	\N	\N
593634	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - IA - ADEME	PLF pour 2022 - IA - ADEME	2021-10-11 10:00:00	2021-10-11 11:00:00	\N	\N	1	0	\N	\N
593636	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - IA - SGPI/BPIFrance	PLF pour 2022 - IA - SGPI/BPIFrance	2021-10-14 09:00:00	2021-10-14 11:00:00	\N	\N	1	0	\N	\N
593638	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Pouvoirs publics - CJR	PLF pour 2022 - Pouvoirs publics - CJR	2021-10-14 09:30:00	2021-10-14 10:15:00	\N	\N	1	0	\N	\N
593641	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - BA CEA - Rapporteurs IGF & CGEDD	PLF pour 2022 - BA CEA - Rapporteurs IGF & CGEDD	2021-10-12 14:00:00	2021-10-12 15:20:00	\N	\N	1	0	\N	\N
593680	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Sport - DJEPVA	PLF pour 2022 - Sport - DJEPVA	2021-10-12 10:00:00	2021-10-12 11:00:00	\N	\N	1	0	\N	\N
593684	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Sport - COJOP Paris 2024	PLF pour 2022 - Sport - COJOP Paris 2024	2021-10-12 14:00:00	2021-10-12 15:00:00	\N	\N	2	0	\N	\N
593686	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Sport - COJOP Paris 2024	PLF pour 2022 - Sport - COJOP Paris 2024	2021-10-12 15:00:00	2021-10-12 16:00:00	\N	\N	1	0	\N	\N
593690	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Sport - Agence du service-civique	PLF pour 2022 - Sport - Agence du service-civique	2021-10-13 14:30:00	2021-10-13 15:30:00	\N	\N	1	0	\N	\N
593693	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Écologie - DGEC	PLF pour 2022 - Écologie - DGEC	2021-10-18 08:30:00	2021-10-18 09:30:00	\N	\N	1	0	\N	\N
593697	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - DAG - DILA/DSAF Premier Ministre	PLF pour 2022 - DAG - DILA/DSAF Premier Ministre	2021-10-13 16:30:00	2021-10-13 18:30:00	\N	\N	1	0	\N	\N
593733	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - CCE - SG Conseil d'ÉTAT et CNDA	PLF pour 2022 - CCE - SG Conseil d'ÉTAT et CNDA	2021-10-13 16:15:00	2021-10-13 17:30:00	\N	\N	1	0	\N	\N
593735	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - CCE - CESE	PLF pour 2022 - CCE - CESE	2021-10-14 09:00:00	2021-10-14 10:00:00	\N	\N	1	0	\N	\N
593741	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Association nationale des élus en charge du sport (Andes)	\N	2021-10-19 08:30:00	2021-10-19 09:40:00	\N	\N	3	0	\N	\N
593799	DELEGATION	AUDRAP	\N	\N	COLTER	audition de M.Lambert - services déconcentrés et préfectoraux 	\N	2021-11-09 15:00:00	2021-11-09 16:00:00	\N	\N	0	0	\N	\N
593800	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition FIVP	\N	2021-10-19 16:00:00	2021-10-19 16:50:00	\N	\N	2	0	\N	\N
593811	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-10-27 10:03:00	2021-10-27 11:14:00	2021-10-27 11:32:48	2021-10-27 19:08:44	30	0	\N	\N
593812	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-10-27 17:04:00	2021-10-27 18:47:00	2021-10-27 18:51:01	2021-10-27 19:08:43	21	0	\N	\N
594059	ETUDES	AUCUNE	\N	\N	\N	Audition de représentants de la Société de vènerie	Audition de représentants de la Société de vènerie	2021-10-20 08:00:00	2021-10-20 09:15:00	\N	\N	22	0	\N	907
594084	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition CCMSA	\N	2021-10-19 16:45:00	2021-10-19 18:00:00	\N	\N	2	0	\N	\N
594128	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2022 - Avis Énergie - Audition du Médiateur nationale de l'énergie	PJLF 2022 - Avis Énergie - Audition du Médiateur nationale de l'énergie	2021-10-19 09:45:00	2021-10-19 10:30:00	\N	\N	2	0	\N	\N
594129	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF2022 - Avis Énergie - Audition de l'AFG	PJLF2022 - Avis Énergie - Audition de l'AFG	2021-10-19 14:00:00	2021-10-19 14:45:00	\N	\N	1	0	\N	\N
594130	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL2022 - Avis Énergie - Audition du Syndicat des énergies renouvelables	PJL2022 - Avis Énergie - Audition du Syndicat des énergies renouvelables	2021-10-19 14:45:00	2021-10-19 15:30:00	\N	\N	2	0	\N	\N
594131	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL2022 - Avis Énergie - UNIDEN-Cleee-HEI	PJL2022 - Avis Énergie - UNIDEN-Cleee-HEI	2021-10-19 15:30:00	2021-10-19 16:30:00	\N	\N	2	0	\N	\N
594132	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL2022 - Avis Énergie - Union française de l'électricité	PJL2022 - Avis Énergie - Union française de l'électricité	2021-10-19 16:30:00	2021-10-19 17:15:00	\N	\N	1	0	\N	\N
594313	GIA	AUCUNE	\N	\N	\N	Audition de Jean-Marc Sauvé, président de la CIASE	\N	2021-10-20 13:30:00	2021-10-20 14:45:00	\N	\N	12	0	629	\N
594499	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLC Respect des principes de la démocratie représentative	\N	2021-10-20 11:30:00	2021-10-20 13:00:00	\N	\N	4	0	\N	\N
595194	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur - PJL Ratification travailleurs de plateformes	\N	2021-10-21 09:00:00	2021-10-21 10:00:00	\N	\N	2	0	\N	\N
595197	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PLF 2022 - Avis Énergie : EDF - France hydrogène	Auditions PLF 2022 - Avis Énergie : EDF - France hydrogène	2021-10-20 16:00:00	2021-10-20 17:00:00	\N	\N	2	0	\N	\N
595200	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition PLF 2022 - Mildeca - SCMR	\N	2021-10-27 14:00:00	2021-10-27 15:00:00	\N	\N	3	0	\N	\N
595247	DELEGATION	AUDRAP	\N	\N	206	Audition de rapporteur	\N	2021-10-20 17:00:00	2021-10-20 18:30:00	\N	\N	1	0	\N	\N
595272	ETUDES	AUTRE	\N	\N	\N	Audition de M. Lionel Causse, député et M. Pierre Rifflet, son collaborateur	\N	2021-10-20 16:45:00	2021-10-20 17:45:00	\N	\N	1	0	\N	908
595274	ETUDES	AUTRE	\N	\N	\N	Audition de la Fédération des industries nautiques	\N	2021-10-19 14:45:00	2021-10-19 15:30:00	\N	\N	9	0	\N	908
595276	ETUDES	AUTRE	\N	\N	\N	Audition de l'Union nationale des industries de la manutention	\N	2021-10-19 15:30:00	2021-10-19 16:15:00	\N	\N	7	0	\N	908
595278	ETUDES	AUTRE	\N	\N	\N	Audition d'Armateurs de France	Audition d'Armateurs de France	2021-10-19 16:15:00	2021-10-19 17:00:00	\N	\N	7	0	\N	908
595309	ETUDES	AUTRE	\N	\N	\N	Audition de Mme Annick Girardin, ministre de la mer, sous forme de petit-déjeuner	Audition de Mme Annick Girardin, ministre de la mer, sous forme de petit-déjeuner	2021-10-19 08:30:00	2021-10-19 10:00:00	\N	\N	11	0	\N	908
595324	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Enseignement scolaire - MIN Agriculture-DGER	PLF pour 2022 - Enseignement scolaire - MIN Agriculture-DGER	2021-10-18 16:30:00	2021-10-18 17:30:00	\N	\N	1	0	\N	\N
595327	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Enseignement scolaire - DEPP-OCDE/DGRH Min EN	PLF pour 2022 - Enseignement scolaire - DEPP-OCDE/DGRH Min EN	2021-10-19 08:30:00	2021-10-19 11:15:00	\N	\N	1	0	\N	\N
595328	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur - PLFSS 2022 - Partie 1 - Agirc-Arrco	\N	2021-10-21 11:00:00	2021-10-21 12:15:00	\N	\N	2	0	\N	\N
595333	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Cohésion des territoires - DGCL	PLF pour 2022 - Cohésion des territoires - DGCL	2021-10-19 14:00:00	2021-10-19 15:30:00	\N	\N	1	0	\N	\N
595336	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Cohésion des territoires - DMAT	PLF pour 2022 - Cohésion des territoires - DMAT	2021-10-19 17:45:00	2021-10-19 18:30:00	\N	\N	1	0	\N	\N
595338	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2022 - CCE - Déplacement Cour des comptes	PLF pour 2022 - CCE - Déplacement Cour des comptes	2021-10-20 16:30:00	2021-10-20 18:30:00	\N	\N	1	0	\N	\N
505732	DELEGATION	AUDRAP	\N	\N	206	Audition Phagothérapie - Pr Tristan Ferry, Pr Frédéric Laurent	Audition Phagothérapie - Pr Tristan Ferry, Pr Frédéric Laurent	2020-11-18 17:00:00	2020-11-18 18:00:00	\N	\N	1	0	\N	\N
505735	DELEGATION	AUDRAP	\N	\N	206	Audition Phagothérapie - Charlotte Brives	Audition Phagothérapie - Charlotte Brives	2020-11-19 14:30:00	2020-11-19 15:15:00	\N	\N	1	0	\N	\N
505738	DELEGATION	AUDRAP	\N	\N	206	Audition Phagothérapie - Clean Cells	Audition Phagothérapie - Clean Cells	2020-11-20 14:30:00	2020-11-20 15:15:00	\N	\N	1	0	\N	\N
505740	DELEGATION	AUDRAP	\N	\N	206	Audition Phagothérapie - AVIBEP	Audition Phagothérapie - AVIBEP	2020-11-23 15:00:00	2020-11-23 16:00:00	\N	\N	1	0	\N	\N
509873	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Examen de 4 avis budgétaires	\N	2020-12-02 09:30:00	2020-12-02 11:00:00	2020-12-02 11:56:09	2020-12-02 14:25:08	31	0	\N	\N
509874	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de M. Juan Guaido	\N	2020-12-02 16:30:00	2020-12-02 17:35:00	2020-12-02 18:11:15	2020-12-03 17:14:49	23	0	\N	\N
517090	MECSS	AUCUNE	\N	\N	MECSS	MECSS - Réunion	MECSS - Réunion	2020-12-15 14:30:00	2020-12-16 15:20:00	2020-12-15 17:55:46	2020-12-15 18:02:53	12	0	\N	\N
517102	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2020-12-08 14:50:00	2020-12-08 17:00:00	\N	\N	3	0	\N	\N
518384	GIA	AUCUNE	\N	\N	\N	Assemblée générale	\N	2020-12-15 14:15:00	2020-12-15 14:35:00	\N	\N	5	0	581	\N
521525	GIA	AUCUNE	\N	\N	\N	Assemblée générale	Assemblée générale	2021-01-13 13:55:00	2021-01-13 14:20:00	\N	\N	3	0	574	\N
521529	GIA	AUCUNE	\N	\N	\N	Assemblée générale	Assemblée générale	2021-01-13 16:40:00	2021-01-13 17:25:00	\N	\N	9	0	625	\N
524107	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Commission des affaires étrangères	\N	2021-01-27 10:05:00	2021-01-27 12:20:00	2021-01-27 14:11:01	2021-01-27 15:51:07	37	0	\N	\N
537036	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur - M. Toussaint et M. de Feydeau	Audition rapporteurs - Politique culturelle de l'UE au service des petites cités de caractère	2021-03-04 17:10:00	2021-03-04 18:15:00	\N	\N	2	0	\N	\N
537051	DELEGATION	AUDRAP	\N	\N	PROS	Audition d'Orange	\N	2021-03-22 16:30:00	2021-03-22 17:30:00	\N	\N	3	0	\N	\N
537066	DELEGATION	AUCUNE	\N	\N	DSOM	Audition sur le logement dans les outre-mer	\N	2021-03-25 09:30:00	2021-03-25 10:55:00	\N	\N	7	0	\N	\N
537069	DELEGATION	AUTRE	\N	\N	DSOM	Audition sur le logement dans les outre-mer	\N	2021-03-25 19:00:00	2021-03-25 21:00:00	\N	\N	5	0	\N	\N
537079	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 17 mars 2021	Réunion du 17 mars 2021	2021-03-17 14:00:00	2021-03-17 15:00:00	2021-03-17 16:18:27	2021-03-17 17:00:44	9	0	\N	\N
537080	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 18 mars 2021	\N	2021-03-18 08:30:00	2021-03-18 10:40:00	2021-03-18 10:39:15	2021-03-18 17:51:19	19	0	\N	\N
537081	COM_EURO	AUTRE	\N	AFEU	\N	Etat de droit dans l'UE : rapport d'information, PPRE, avis politique	\N	2021-03-18 08:30:00	2021-03-18 09:30:00	\N	\N	0	0	\N	\N
538129	DELEGATION	AUDRAP	\N	\N	206	Audition rapporteur Outils de webconférence - Marie Lacroix, Dr en Neurosciences	Audition rapporteur Outils de webconférence - Marie Lacroix, Dr en Neurosciences	2021-03-19 09:00:00	2021-03-19 10:00:00	\N	\N	1	0	\N	\N
554097	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière - table ronde cybersécurite	Réunion plénière - table ronde cybersécurite	2021-04-15 09:05:00	2021-04-15 11:10:00	2021-04-15 11:58:55	\N	11	0	\N	\N
557939	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT Institutions	Audition Paul Magnette	2021-05-05 13:00:00	2021-05-05 14:00:00	\N	\N	6	0	\N	\N
557946	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT Institutions	Audition chercheurs (Diane Fromage, Olivier Costa, Christine Verger)	2021-05-06 10:30:00	2021-05-06 12:35:00	\N	\N	4	0	\N	\N
571364	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	pjl climat	\N	2021-05-11 14:30:00	2021-05-11 15:15:00	\N	\N	10	0	\N	\N
571375	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	pjl climat	\N	2021-05-11 15:15:00	2021-05-11 15:50:00	\N	\N	6	0	\N	\N
571400	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	pjl climat	\N	2021-05-19 14:00:00	2021-05-19 14:35:00	\N	\N	2	0	\N	\N
571409	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	pjl cli	\N	2021-05-19 16:40:00	2021-05-19 17:50:00	\N	\N	4	0	\N	\N
571446	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Ppl économie du livre	\N	2021-05-07 14:50:00	2021-05-07 16:00:00	\N	\N	2	0	\N	\N
571451	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Ppl économie du livre	\N	2021-05-07 16:00:00	2021-05-07 17:00:00	\N	\N	2	0	\N	\N
571455	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	ppl économie du livre	\N	2021-05-10 09:30:00	2021-05-10 10:50:00	\N	\N	5	0	\N	\N
571481	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Ppl économie du livre	\N	2021-05-11 16:30:00	2021-05-11 17:40:00	\N	\N	7	0	\N	\N
571490	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Ppl économie du livre	Ppl économie du livre	2021-05-14 09:00:00	2021-05-14 10:00:00	\N	\N	5	0	\N	\N
571496	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Ppl économie du livre	Ppl économie du livre	2021-05-14 10:00:00	2021-05-14 11:25:00	\N	\N	5	0	\N	\N
571502	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Ppl économie du livre	Ppl économie du livre	2021-05-17 10:00:00	2021-05-17 11:10:00	\N	\N	4	0	\N	\N
579585	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2021-07-13 08:35:00	2021-07-13 11:05:00	\N	\N	3	0	\N	\N
588542	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2021-10-07 10:30:00	2021-10-07 12:45:00	\N	\N	0	0	\N	\N
588543	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Droits des personnes handicapées	Débat Droits des personnes handicapées	2021-10-07 14:45:00	2021-10-07 16:00:00	\N	\N	32	0	\N	\N
588544	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Harcèlement scolaire et cyberharcèlement	Débat Harcèlement scolaire et cyberharcèlement	2021-10-07 16:00:00	2021-10-07 17:20:00	\N	\N	24	0	\N	\N
588604	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Démocratisation du sport	Audition Association Siel Bleu	2021-10-01 15:05:00	2021-10-01 15:55:00	\N	\N	2	0	\N	\N
588607	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Démocratisation du sport	Audition M. Mickeler, DNCG	2021-10-01 16:00:00	2021-10-01 17:00:00	\N	\N	2	0	\N	\N
590838	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2021-10-12 15:00:00	2021-10-12 18:00:00	2021-10-13 15:32:48	2021-10-14 14:58:08	30	0	\N	\N
590839	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2021-10-13 10:00:00	2021-10-13 13:00:00	2021-10-13 15:43:58	2021-10-14 14:58:06	31	0	\N	\N
590840	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2022- Programmes 844 et 847	PLF pour 2022 - Programmes 844 et 847	2021-10-07 09:30:00	2021-10-07 11:00:00	\N	\N	1	0	\N	\N
590842	COM_PERMANENTE	AUTRE	\N	ETRD	\N	PJLF pour 2022	PJLF pour 2022	2021-10-07 16:30:00	2021-10-07 17:30:00	\N	\N	1	0	\N	\N
590909	GIA	AUCUNE	\N	\N	\N	Entretien Ambassadrice Andorre	Entretien Ambassadrice de la Principauté d'Andorre en France	2021-10-05 09:15:00	2021-10-05 10:00:00	\N	\N	2	0	963	\N
591328	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI « Sécurité à Mayotte »	Audition rapporteur - MI « Sécurité à Mayotte »	2021-10-12 15:30:00	2021-10-12 16:50:00	\N	\N	4	0	\N	\N
595687	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion  plénière CATDD	\N	2021-11-02 09:01:00	2021-11-02 09:09:00	2021-11-22 11:03:20	2021-11-22 11:05:22	15	1	\N	\N
595689	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-11-03 16:34:00	2021-11-03 17:34:00	2021-11-03 17:38:32	2021-11-04 16:07:13	22	0	\N	\N
598625	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-11-10 08:30:00	2021-11-10 12:28:00	2021-11-10 12:40:48	2021-11-12 19:00:43	38	0	\N	\N
598626	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-11-10 16:30:00	2021-11-10 18:00:00	2021-11-10 18:22:54	2021-11-12 19:00:39	15	0	\N	\N
599079	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	TV5 Monde	Audition de MM. Bigot et Derobe	2021-11-02 15:30:00	2021-11-02 16:45:00	\N	\N	4	0	\N	\N
599120	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - BA CEA - DB/UAF	PLF pour 2022 - BA CEA - DB/UAF	2021-11-02 14:30:00	2021-11-02 16:45:00	\N	\N	1	0	\N	\N
595688	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-11-03 10:33:00	2021-11-03 11:55:00	2021-11-03 12:18:36	2021-11-03 16:47:37	37	1	\N	\N
599122	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - BA CEA - ACNUSA	PLF pour 2022 - BA CEA - ACNUSA	2021-11-02 17:30:00	2021-11-02 18:45:00	\N	\N	1	0	\N	\N
613520	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Déplacement dans l'Orne - Visite d'entreprise	\N	2021-12-09 08:45:00	2021-12-09 10:15:00	\N	\N	5	0	\N	\N
613536	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Déplacement dans l'Orne - Visite d'entreprise	\N	2021-12-09 10:45:00	2021-12-09 12:00:00	\N	\N	5	0	\N	\N
613618	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Déplacement dans l'Orne - Visite d'entreprise	\N	2021-12-09 14:15:00	2021-12-09 15:45:00	\N	\N	5	0	\N	\N
613773	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Défense - SIMu	PLF pour 2022 - Défense - SIMu	2021-12-09 15:00:00	2021-12-09 16:00:00	\N	\N	1	0	\N	\N
613821	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Table ronde Conférences régionales du sport	\N	2021-12-14 16:30:00	2021-12-14 17:45:00	\N	\N	3	0	\N	\N
617126	DELEGATION	AUCUNE	\N	\N	DSOM	Auditions Étude sur la place des outre-mer dans la stratégie maritime nationale	\N	2022-01-13 09:00:00	2022-01-13 11:45:00	\N	\N	12	0	\N	\N
617182	DELEGATION	AUCUNE	\N	\N	DSOM	Audition de M. Dominique Vienne, CESER La Réunion	\N	2022-01-20 09:30:00	2022-01-20 10:55:00	\N	\N	10	0	\N	\N
617194	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Harkis et autres personnes rapatriées d'Algérie - Audition rapporteure 	\N	2022-01-04 14:00:00	2022-01-04 15:10:00	\N	\N	3	0	\N	\N
617195	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Harkis et autres personnes rapatriées d'Algérie - Audition rapporteure 	\N	2022-01-04 17:15:00	2022-01-04 18:45:00	\N	\N	4	0	\N	\N
617480	COM_PERMANENTE	AUTRE	\N	AFCL	\N	PPLE harcelement - Rapport Paccaud et texte	\N	2022-01-05 14:05:00	2022-01-05 14:55:00	2022-01-17 15:22:01	2022-01-17 15:22:03	29	0	\N	\N
621722	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Aménagement du territoire - Audition de MM. Belin et Babary	MI Aménagement du territoire - Audition de MM. Belin et Babary	2022-01-12 17:30:00	2022-01-12 19:25:00	\N	\N	2	0	\N	\N
624278	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2022-01-20 09:12:00	2022-01-20 10:30:00	\N	\N	2	0	\N	\N
625163	ETUDES	AUCUNE	\N	\N	\N	Réunion consacrée à la doctrine incendie de la préfecture de police de Paris	Réunion consacrée à la doctrine incendie de la préfecture de police de Paris	2022-01-25 16:00:00	2022-01-25 17:30:00	\N	\N	9	0	\N	948
625480	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	PPL pour garantir l'égalité et la liberté dans l'attribution et le choix du nom	2022-01-25 15:00:00	2022-01-25 16:00:00	\N	\N	1	0	\N	\N
625483	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	\N	2022-01-25 16:00:00	2022-01-25 16:50:00	\N	\N	1	0	\N	\N
625485	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	PPL pour garantir l'égalité et la liberté dans l'attribution et le choix du nom	2022-01-25 18:45:00	2022-01-25 19:15:00	\N	\N	1	0	\N	\N
631625	GIA	AUCUNE	\N	\N	\N	Audition de Philippe ETIENNE, ambassadeur de France aux USA	Audition de l'ambassadeur de France aux Etats-Unis	2022-02-08 16:30:00	2022-02-08 17:20:00	\N	\N	15	0	590	\N
631668	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Aménagement du territoire - B. Rojouan	MI Aménagement du territoire - B. Rojouan	2022-01-18 14:30:00	2022-01-18 18:30:00	\N	\N	1	0	\N	\N
631670	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Aménagement du territoire - B. Rojouan	MI Aménagement du territoire - B. Rojouan	2022-01-25 17:00:00	2022-01-25 18:45:00	\N	\N	1	0	\N	\N
631672	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Aménagement du territoire - B. Rojouan	MI Aménagement du territoire - B. Rojouan	2022-01-28 09:15:00	2022-01-28 12:00:00	\N	\N	1	0	\N	\N
633959	GIA	AUCUNE	\N	\N	\N	Audition Dr Europe continentale et SD Caucase et Asie centrale (MEAE)	Audition de M. Mondoloni, Dr Europe continentale, et M. Bouallègue, SD Caucase et Asie centrale au MEAE	2022-02-17 08:30:00	2022-02-17 09:35:00	\N	\N	8	0	641	\N
633968	GIA	AUCUNE	\N	\N	\N	Audition Dr Europe continentale et SD Caucase et Asie centrale (MEAE)	Audition de M. Mondoloni, Dr de l'Europe continentale, et M. Bouallègue, SD Caucase et Asie centrale au MEAE	2022-02-17 08:30:00	2022-02-17 09:35:00	\N	\N	3	0	534	\N
633987	MISSION	AUDRAP	\N	SECUECO	\N	Audition Mme Vogel	\N	2022-02-16 16:30:00	2022-02-16 17:30:00	\N	\N	5	0	\N	\N
633998	MISSION	AUDRAP	\N	SECUECO	\N	Auditions MI SSE	\N	2022-02-17 09:00:00	2022-02-17 10:00:00	\N	\N	3	0	\N	\N
634016	DELEGATION	AUCUNE	\N	\N	206	Réunion du Bureau	Réunion du Bureau	2022-02-16 14:15:00	2022-02-16 14:50:00	\N	\N	3	0	\N	\N
634026	MISSION	AUCUNE	\N	SECUECO	\N	Audition du CNI	\N	2022-02-17 11:00:00	2022-02-17 12:30:00	2022-02-17 16:06:02	2022-02-17 16:47:24	2	0	\N	\N
634035	COM_ENQUETE	PLENIERE	\N	MEDIA	\N	Audition de M. Arnaud Lagardère, président-directeur général du groupe Lagardère 	\N	2022-02-17 14:30:00	2022-02-17 16:05:00	2022-02-17 17:03:25	2022-02-18 15:06:15	14	0	\N	\N
634037	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	MCC Sécurisation chasse - Audition	\N	2022-02-15 19:00:00	2022-02-15 20:05:00	\N	\N	0	0	\N	\N
634038	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	MCC Sécurisation de la chasse	MCC Sécurisation de la chasse-Audition de Mme Bérangère Abba	2022-02-15 19:00:00	2022-02-15 20:05:00	\N	\N	8	0	\N	\N
634069	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Aménagement du territoire - Audition commune	MI Aménagement du territoire - Audition commune	2022-02-15 14:30:00	2022-02-15 15:30:00	\N	\N	6	0	\N	\N
634096	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Aménagement du territoire - Audition commune	MI Aménagement du territoire - Audition commune	2022-02-15 16:30:00	2022-02-15 17:30:00	\N	\N	4	0	\N	\N
634106	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Aménagement du territoire - Audition commune	MI Aménagement du territoire - Audition commune	2022-02-15 17:30:00	2022-02-15 18:30:00	\N	\N	2	0	\N	\N
634230	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Gilles BOURBAO, Ambassadeur de France au Népal	Entretien avec M. Gilles BOURBAO, Ambassadeur de France au Népal	2022-02-17 11:05:00	2022-02-17 12:05:00	\N	\N	1	0	633	\N
634531	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de M. René Troccaz et désignations de rapporteurs	Audition de M. René Troccaz et désignations de rapporteurs	2022-02-23 09:30:00	2022-02-23 11:05:00	2022-02-23 16:11:00	2022-02-23 17:47:57	30	0	\N	\N
634625	GIA	AUCUNE	\N	\N	\N	Entretien Ambassadeur de Tunisie	Déjeuner avec l'Ambassadeur de Tunisie en France	2022-02-17 12:30:00	2022-02-17 15:00:00	\N	\N	5	0	620	\N
634631	GIA	AUCUNE	\N	\N	\N	Entretien délégation tunisienne	Entretien avec une délégation tunisienne	2022-02-15 16:00:00	2022-02-15 17:00:00	\N	\N	3	0	620	\N
634705	GIA	AUCUNE	\N	\N	\N	Coopé - Entretien avec M. Cerni ESCALE CABRE	Coopé - Entretien avec M. Cerni ESCALE CABRE	2022-02-16 12:00:00	2022-02-16 14:15:00	\N	\N	2	0	963	\N
634798	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI crédits plan de relance patrimoine	\N	2022-02-23 17:30:00	2022-02-23 18:30:00	\N	\N	0	0	\N	\N
634806	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - IHU - SGPI	Contrôle 2021 - IHU - SGPI	2022-02-15 09:00:00	2022-02-15 10:00:00	\N	\N	2	0	\N	\N
634809	GIA	AUCUNE	\N	\N	\N	petit déjeuner économique	petit déjeuner économique	2022-02-11 08:00:00	2022-02-11 10:30:00	\N	\N	7	0	674	\N
634817	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	déplacement à Londres UIP	déplacement à Londres UIP	2022-02-01 07:00:00	2022-02-03 10:00:00	\N	\N	2	0	\N	\N
635777	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Pôle du conseil indépendant en agriculture	Pôle du conseil indépendant en agriculture	2022-02-22 13:45:00	2022-02-22 14:30:00	\N	\N	2	0	\N	\N
636653	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Garantie à l'emploi pour les chômeurs	PPL Garantie à l'emploi pour les chômeurs	2022-02-23 21:30:00	2022-02-23 22:45:00	\N	\N	48	0	\N	\N
637103	ETUDES	AUCUNE	\N	\N	\N	Audition CRESS Nouvelle-Aquitaine et Occitanie	Audition CRESS Nouvelle-Aquitaine et Occitanie	2022-02-23 08:30:00	2022-02-23 09:30:00	\N	\N	1	0	\N	998
637123	MISSION	AUCUNE	\N	RECHINNO	\N	Psdt France Universités / Psdt Paris-Dauphine PSL	Psdt France Universités / Psdt Paris-Dauphine PSL	2022-02-23 17:30:00	2022-02-23 19:00:00	2022-02-24 09:28:48	2022-02-24 14:43:05	4	0	\N	\N
637131	MISSION	AUCUNE	\N	SECUECO	\N	Haut Conseil pour le climat	\N	2022-02-24 09:35:00	2022-02-24 10:40:00	2022-03-02 10:21:18	2022-03-02 10:29:11	2	0	\N	\N
637165	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Audition BRoujouan AP	\N	2022-02-23 14:30:00	2022-02-23 15:30:00	\N	\N	0	0	\N	\N
637166	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Aménagement du territoire - B. Rojouan	MI Aménagement du territoire - B. Rojouan	2022-02-23 14:35:00	2022-02-23 15:30:00	\N	\N	1	0	\N	\N
637168	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Aménagement du territoire - B. Rojouan	MI Aménagement du territoire - B. Rojouan	2022-02-23 16:40:00	2022-02-23 17:30:00	\N	\N	1	0	\N	\N
637175	COM_EURO	AUDRAP	\N	AFEU	\N	Relations stratégique UE/Afrique - CE	Relations stratégique UE/Afrique - CE	2022-02-24 16:30:00	2022-02-24 17:30:00	\N	\N	2	0	\N	\N
637221	DELEGATION	AUCUNE	\N	\N	PROS	Audition d'Erik Orsenna sur l'avenir de l'eau	\N	2022-02-24 08:35:00	2022-02-24 09:50:00	\N	\N	11	0	\N	\N
531358	COM_EURO	AUDRAP	\N	AFEU	\N	Allégations nutritionnelles et allégations de santé	\N	2020-12-09 15:00:00	2020-12-09 16:00:00	\N	\N	1	0	\N	\N
531360	COM_EURO	AUDRAP	\N	AFEU	\N	Audition sur l'Etat de droit dans l'Union européenne	Audition sur l'Etat de droit dans l'Union européenne	2021-02-12 11:00:00	2021-02-12 11:55:00	\N	\N	2	0	\N	\N
531378	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 2021 - Plan transformation numérique justice - Cour des comptes	58-2 2021 - Plan transformation numérique justice - Cour des comptes	2021-02-09 14:30:00	2021-02-09 15:30:00	\N	\N	1	0	\N	\N
531380	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 2021 - Plan de relance - Cour des comptes	58-2 2021 - Plan de relance - Cour des comptes	2021-02-10 09:00:00	2021-02-10 10:00:00	\N	\N	1	0	\N	\N
531382	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - La protection des épargnants - Alpha & K	Contrôle 2020 - La protection des épargnants - Alpha & K	2021-02-09 09:00:00	2021-02-09 10:00:00	\N	\N	2	0	\N	\N
531385	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - La protection des épargnants - Économistes	Contrôle 2020 - La protection des épargnants - Économistes	2021-02-09 14:00:00	2021-02-09 16:00:00	\N	\N	2	0	\N	\N
531388	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition de représentants de Polyvia et de PlasticsEurope	Audition de représentants de Polyvia et de PlasticsEurope	2021-02-11 14:00:00	2021-02-11 14:45:00	\N	\N	2	0	\N	\N
531391	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Diverses mesures de justice sociale	\N	2021-02-11 16:00:00	2021-02-11 16:50:00	\N	\N	2	0	\N	\N
531393	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Diverses mesures de justice sociale	\N	2021-02-11 17:00:00	2021-02-11 17:30:00	\N	\N	1	0	\N	\N
531408	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Lutter contre les fraudes sociales	\N	2021-02-11 14:30:00	2021-02-11 15:45:00	\N	\N	2	0	\N	\N
531411	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Lutter contre les fraudes sociales	\N	2021-02-11 15:45:00	2021-02-11 16:30:00	\N	\N	2	0	\N	\N
531414	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Droit à mourir dans la dignité - Table ronde de représentants de médecins	\N	2021-02-11 09:30:00	2021-02-11 11:00:00	\N	\N	1	0	\N	\N
531415	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Droit à mourir dans la dignité - Table ronde de sociétés savantes	\N	2021-02-12 09:30:00	2021-02-12 11:00:00	\N	\N	2	0	\N	\N
533774	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Service public d'eau potable et d'assainissement en Guadeloupe	PPL Service public d'eau potable et d'assainissement en Guadeloupe	2021-02-17 12:00:00	2021-02-17 13:05:00	\N	\N	1	0	\N	\N
534218	MISSION	AUTRE	\N	METHANIS	\N	Réunion plénière MI Méthanisation	\N	2021-03-03 16:30:00	2021-03-03 18:00:00	2021-03-03 17:19:02	2021-03-04 17:59:28	19	0	\N	\N
542973	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur PPL Protéger les mineurs des crimes et délits sexuels et de l'inceste	Audition rapporteur - CNB	2021-03-19 09:00:00	2021-03-19 10:10:00	\N	\N	1	0	\N	\N
548035	GIA	AUCUNE	\N	\N	\N	Réunion GIA France-Népal	Audiition de M. Damien Syed, Sous-Directeur Asie méridionale au MEAE	2021-04-01 11:05:00	2021-04-01 12:05:00	\N	\N	2	0	633	\N
548047	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Table ronde sur sur les transformations liées au télétravail.	Table ronde sur sur les transformations liées au télétravail.	2021-04-01 08:30:00	2021-04-01 11:25:00	2021-04-01 15:18:41	\N	24	0	\N	\N
548736	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Financement lutte algues vertes Bretagne - MIRE	Contrôle 2021 - Financement lutte algues vertes Bretagne - MIRE	2021-03-31 10:00:00	2021-03-31 11:30:00	\N	\N	1	0	\N	\N
548742	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Immobilier universitaire - Chancellerie Universités Paris/DIE	Contrôle 2021 - Immobilier universitaire - Chancellerie Universités Paris/DIE	2021-03-30 14:30:00	2021-03-30 16:30:00	\N	\N	1	0	\N	\N
548745	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Immobilier universitaire - CPU	Contrôle 2021 - Immobilier universitaire - CPU	2021-03-31 16:30:00	2021-03-31 17:30:00	\N	\N	1	0	\N	\N
548748	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL n° 404 Développement solidaire - DIE	PJL n° 404 Développement solidaire - DIE	2021-03-30 13:30:00	2021-03-30 14:15:00	\N	\N	2	0	\N	\N
548749	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL n° 404 Développement solidaire - Cour des comptes	PJL n° 404 Développement solidaire - Cour des comptes	2021-03-30 15:00:00	2021-03-30 16:00:00	\N	\N	2	0	\N	\N
548779	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL n° 404 Développement solidaire - OCDE	PJL n° 404 Développement solidaire - OCDE	2021-03-31 13:45:00	2021-03-31 14:45:00	\N	\N	2	0	\N	\N
548783	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Financement aires protégées - OFB	Contrôle 2021 - Financement aires protégées - OFB	2021-03-30 09:00:00	2021-03-30 10:30:00	\N	\N	1	0	\N	\N
548788	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - IGN	Contrôle 2021 - IGN	2021-03-31 17:00:00	2021-03-31 18:00:00	\N	\N	1	0	\N	\N
548800	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - PGE - Cabinet Intervista	Contrôle 2021 - PGE - Cabinet Intervista	2021-03-30 09:30:00	2021-03-30 10:30:00	\N	\N	1	0	\N	\N
548803	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - PGE - DG Trésor	Contrôle 2021 - PGE - DG Trésor	2021-03-30 14:00:00	2021-03-30 15:00:00	\N	\N	1	0	\N	\N
548805	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GT Économie numérique - CPO	GT Économie numérique - Conseil des Prélèvements obligatoires (CPO)	2021-03-30 15:00:00	2021-03-30 16:10:00	\N	\N	7	0	\N	\N
548814	DELEGATION	AUCUNE	\N	\N	DSOM	Table ronde sur le logement indigne dans les outre-mer	\N	2021-04-08 09:00:00	2021-04-08 11:30:00	\N	\N	12	0	\N	\N
548862	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - PGE - France Invest/Cabinet SVZ	Contrôle 2021 - PGE - France Invest/Cabinet SVZ	2021-03-31 16:30:00	2021-03-31 18:30:00	\N	\N	1	0	\N	\N
548865	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - PGE - Bpifrance	Contrôle 2021 - PGE - Bpifrance	2021-04-01 09:00:00	2021-04-01 10:00:00	\N	\N	1	0	\N	\N
524108	COM_PERMANENTE	PEC_NON_MML	\N	CAE	\N	\N	\N	2021-01-27 08:30:00	2021-01-27 10:00:00	2021-01-27 14:42:00	2021-01-27 15:51:01	54	0	\N	\N
548867	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Politique installation agriculteurs - Jeunes Agriculteurs	Contrôle 2021 - Politique installation agriculteurs - Jeunes Agriculteurs	2021-03-31 16:30:00	2021-03-31 18:00:00	\N	\N	2	0	\N	\N
548868	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Politique installation agriculteurs - FNSEA	Contrôle 2021 - Politique installation agriculteurs - FNSEA	2021-04-01 09:30:00	2021-04-01 10:30:00	\N	\N	2	0	\N	\N
548873	ETUDES	AUTRE	\N	\N	\N	Audition en commun avec le groupe d'études "Cheval" de l'Assemblée nationale	Audition en commun avec le groupe d'études "Cheval" de l'Assemblée nationale	2021-03-31 11:30:00	2021-03-31 13:00:00	\N	\N	6	0	\N	912
548874	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Politique installation agriculteurs - MIN Agriculture	Contrôle 2021 - Politique installation agriculteurs - MIN Agriculture	2021-04-01 14:00:00	2021-04-01 15:00:00	\N	\N	2	0	\N	\N
548883	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Météo France - CGDD	Contrôle 2021 - Météo France - CGDD	2021-04-01 11:00:00	2021-04-01 12:00:00	\N	\N	1	0	\N	\N
548967	MISSION	AUDRAP	\N	PAUP	\N	AFPA et Régions de France	\N	2021-04-06 11:45:00	2021-04-06 12:45:00	\N	\N	2	0	\N	\N
552407	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Transport de marchandises - DGEC	MI Transport de marchandises - Ministère de la transition écologique - Direction générale de l'énergie et du climat	2021-04-13 15:05:00	2021-04-13 16:40:00	\N	\N	10	0	\N	\N
552415	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Transport de marchandises - Sociétés de concessions autoroutières	MI Transport de marchandises - Sociétés de concessions autoroutières	2021-04-13 16:00:00	2021-04-13 17:15:00	\N	\N	6	0	\N	\N
554895	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Cabinet de Mme la Ministre de l'enseignement supérieur, de la recherche et de l'innovation	\N	2021-04-19 16:00:00	2021-04-19 17:30:00	\N	\N	1	0	\N	\N
554923	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2021-05-05 09:00:00	2021-05-05 12:20:00	2021-05-05 12:16:39	2021-05-06 17:43:08	39	0	\N	\N
554924	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur	\N	2021-04-20 14:00:00	2021-04-20 15:00:00	\N	\N	0	0	\N	\N
595341	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur - PLFSS - Partie 1 - CCMSA	\N	2021-10-19 16:45:00	2021-10-19 18:00:00	\N	\N	2	0	\N	\N
595344	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur - PLFSS partie 5 - CCMSA	\N	2021-10-19 16:45:00	2021-10-19 18:00:00	\N	\N	2	0	\N	\N
595348	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2022 - Rapports Missions « CCE »  et « DAG » 	PLF pour 2022 - Rapports Missions « CCE »  et « DAG » 	2021-10-26 14:30:00	2021-10-26 15:55:00	2021-10-26 16:40:45	2021-10-26 18:03:11	32	0	\N	\N
595351	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJFS Financement de la sécurité sociale pour 2022 - Branche famille	\N	2021-10-20 16:30:00	2021-10-20 17:30:00	\N	\N	2	0	\N	\N
595352	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2022 - Rapports Missions « IA », « Plan de relance » et budget UE art18	PLF pour 2022 - Rapports Missions « IA », « Plan de relance » et budget UE art18	2021-10-27 09:30:00	2021-10-27 12:00:00	2021-10-27 12:21:51	2021-10-27 19:08:45	42	0	\N	\N
595356	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2022 - Rapports Missions « Défense » et « AGTE »	PLF pour 2022 - Rapports Missions « Défense » et « AGTE »	2021-10-27 16:30:00	2021-10-27 18:00:00	2021-10-27 21:29:40	2021-10-28 15:42:58	25	0	\N	\N
595357	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJFS Financement de la sécurité sociale pour 2022 - Branche famille	\N	2021-10-20 17:30:00	2021-10-20 18:55:00	\N	\N	1	0	\N	\N
595359	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur - PLFSS - Partie 5 - Agirc-Arrco	\N	2021-10-21 11:00:00	2021-10-21 12:15:00	\N	\N	2	0	\N	\N
595365	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Agence nationale du sport	\N	2021-10-21 09:30:00	2021-10-21 10:45:00	\N	\N	2	0	\N	\N
595371	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Agence française de lutte contre le dopage (AFLD)	\N	2021-10-19 15:30:00	2021-10-19 16:30:00	\N	\N	3	0	\N	\N
595372	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Institut national des sports, de l'expertise et de la performance (INSEP)	\N	2021-10-19 16:30:00	2021-10-19 17:30:00	\N	\N	2	0	\N	\N
595461	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - EFE - DG Trésor	PLF pour 2022 - EFE - DG Trésor	2021-10-19 14:30:00	2021-10-19 15:15:00	\N	\N	1	0	\N	\N
595463	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - EFE - Agence France Trésor	PLF pour 2022 - EFE - Agence France Trésor	2021-10-20 16:00:00	2021-10-20 17:00:00	\N	\N	1	0	\N	\N
595465	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Écologie - Transports - SGParis	PLF pour 2022 - Écologie - Transports - SGParis	2021-10-19 08:00:00	2021-10-19 09:00:00	\N	\N	2	0	\N	\N
595468	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - BA CEA - PDG ADP	PLF pour 2022 - BA CEA - PDG ADP	2021-10-19 17:00:00	2021-10-19 18:10:00	\N	\N	1	0	\N	\N
595470	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Écologie - Transports - DGITM	PLF pour 2022 - Écologie - Transports - DGITM	2021-10-19 18:15:00	2021-10-19 19:15:00	\N	\N	2	0	\N	\N
595473	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur - PLFSS - Partie 5	\N	2021-10-21 09:30:00	2021-10-21 10:30:00	\N	\N	1	0	\N	\N
595474	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - CAS Pensions et RSR - SRE/ENIM	PLF pour 2022 - CAS Pensions et RSR - SRE/ENIM	2021-10-19 14:30:00	2021-10-19 16:10:00	\N	\N	1	0	\N	\N
595477	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Culture - DGPA	PLF pour 2022 - Culture - DGPA	2021-10-19 16:40:00	2021-10-19 17:45:00	\N	\N	2	0	\N	\N
595481	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - RSR - ACOSS	PLF pour 2022 - RSR - ACOSS	2021-10-20 11:00:00	2021-10-20 12:00:00	\N	\N	1	0	\N	\N
595483	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Culture - SAS Pass Culture	PLF pour 2022 - Culture - SAS Pass Culture	2021-10-20 16:30:00	2021-10-20 17:15:00	\N	\N	2	0	\N	\N
595486	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 27 octobre	\N	2021-10-27 13:30:00	2021-10-27 15:00:00	2021-10-27 15:28:22	2021-10-27 19:08:15	19	0	\N	\N
595488	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 28 octobre	\N	2021-10-28 08:30:00	2021-10-28 10:45:00	2021-10-28 12:19:10	2021-10-28 15:43:13	34	0	\N	\N
595489	COM_EURO	AUTRE	\N	AFEU	\N	Audition de M. Thierry Breton, commissaire européen responsable du marché intérieur	\N	2021-10-28 07:45:00	2021-10-28 09:15:00	\N	\N	0	0	\N	\N
595490	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Cohésion des territoires - Logement-Urbanisme - Cab Min Logement/Procivis	PLF pour 2022 - Cohésion des territoires - Logement-Urbanisme - Cab Min Logement/Procivis	2021-10-20 15:30:00	2021-10-20 17:15:00	\N	\N	1	0	\N	\N
595492	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Écologie - DGPR/SG MIN ECO	PLF pour 2022 - Écologie - DGPR/SG MIN ECO	2021-10-14 10:00:00	2021-10-14 12:00:00	\N	\N	1	0	\N	\N
595494	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Agriculture - Coordination rurale/Confédération paysanne 	PLF pour 2022 - Agriculture - Coordination rurale/Confédération paysanne 	2021-10-19 17:30:00	2021-10-19 18:30:00	\N	\N	2	0	\N	\N
595497	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Agriculture - CNPF/ONF	PLF pour 2022 - Agriculture - CNPF/ONF	2021-10-20 17:30:00	2021-10-20 19:00:00	\N	\N	2	0	\N	\N
595500	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Sécurités - Sécurité Civile - DGSCGC	PLF pour 2022 - Sécurités - Sécurité Civile - DGSCGC	2021-10-19 09:00:00	2021-10-19 10:00:00	\N	\N	1	0	\N	\N
595502	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Activité professionnelle indépendante (amendements de séance)	PJL Activité professionnelle indépendante (amendements de séance)	2021-10-26 09:00:00	2021-10-26 09:25:00	2021-10-26 09:37:31	2021-10-26 18:03:09	13	0	\N	\N
595503	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Sécurités - Sécurité Civile - CNSIS	PLF pour 2022 - Sécurités - Sécurité Civile - CNSIS	2021-10-20 08:45:00	2021-10-20 09:45:00	\N	\N	1	0	\N	\N
595504	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Vigilance sanit. -  Audition d'Olivier Véran, ministre des solidarités et de la santé	PJL Vigilance sanit. - Audition d'Olivier Véran, ministre des solidarités et de la santé	2021-10-26 09:50:00	2021-10-26 10:50:00	2021-10-26 11:08:59	2021-10-26 18:03:10	50	0	\N	\N
595510	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de Jean-Marc Sauvé, président de la CIASE	Audition de Jean-Marc Sauvé, président de la CIASE	2021-10-28 10:00:00	2021-10-28 11:45:00	\N	\N	36	0	\N	\N
595511	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Vigilance sanitaire (amendements de séance)	PJL Vigilance sanitaire (amendements de séance)	2021-10-28 14:35:00	2021-10-28 15:05:00	2021-10-28 15:49:34	2021-10-28 18:22:42	14	1	\N	\N
595512	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Sécurités - Sécurité Civile - ANSC	PLF pour 2022 - Sécurités - Sécurité Civile - ANSC	2021-10-20 16:00:00	2021-10-20 17:00:00	\N	\N	1	0	\N	\N
595514	DELEGATION	AUCUNE	\N	\N	206	Audition publique sur la stratégie quantique de la France	\N	2021-10-21 09:35:00	2021-10-21 13:35:00	2021-10-21 16:52:13	\N	9	0	\N	\N
595516	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Rapport général - AFEP	PLF pour 2022 - Rapport général - AFEP	2021-10-19 15:00:00	2021-10-19 16:00:00	\N	\N	1	0	\N	\N
595530	DELEGATION	AUCUNE	\N	\N	PROS	Examen du rapport sur l¿avenir du télétravail 	\N	2021-10-21 08:40:00	2021-10-21 09:45:00	2021-10-21 16:51:10	\N	13	0	\N	\N
595531	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n° 325 Catastrophes naturelles - Les Oubliés de la canicule	PPL n° 325 Catastrophes naturelles - Les Oubliés de la canicule	2021-10-19 18:00:00	2021-10-19 19:00:00	\N	\N	1	0	\N	\N
595553	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Affaires européennes - DB	PLF pour 2022 - Affaires européennes - DB	2021-10-19 15:00:00	2021-10-19 16:00:00	\N	\N	1	0	\N	\N
595555	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Affaires européennes - DG Trésor	PLF pour 2022 - Affaires européennes - DG Trésor	2021-10-20 14:00:00	2021-10-20 14:45:00	\N	\N	1	0	\N	\N
595560	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Rapport Général - France Invest	PLF pour 2022 - Rapport Général - France Invest	2021-10-20 16:00:00	2021-10-20 17:00:00	\N	\N	1	0	\N	\N
595562	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Cohésion des territoires - Logement-Urbanisme - DHUP/USH/DB	PLF pour 2022 - Cohésion des territoires - Logement-Urbanisme - DHUP/USH/DB	2021-10-21 09:15:00	2021-10-21 12:30:00	\N	\N	1	0	\N	\N
595564	DELEGATION	AUTRE	\N	\N	COLTER	Audition de Monsieur SAUVADET, président de l'assemblée des départment de France	\N	2021-11-25 09:30:00	2021-11-25 10:30:00	\N	\N	0	0	\N	\N
595565	DELEGATION	AUTRE	\N	\N	COLTER	Audition de madame Carole DELGA	\N	2021-11-25 10:30:00	2021-11-25 11:30:00	\N	\N	0	0	\N	\N
595596	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022  - Écologie - Météo - Air France KLM/Auteurs rapport CEREMA	PLF pour 2022  - Écologie - Météo - Air France KLM/Auteurs rapport CEREMA	2021-10-21 14:00:00	2021-10-21 16:30:00	\N	\N	1	0	\N	\N
513881	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Auditions GT Nouvelles formes de commerce	Auditions GT Nouvelles formes de commerce	2020-12-07 09:00:00	2020-12-07 09:45:00	\N	\N	4	0	\N	\N
515076	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-12-16 09:35:00	2020-12-16 11:30:00	2020-12-16 11:49:22	2020-12-16 18:00:32	38	0	\N	\N
515230	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-12-15 15:05:00	2020-12-15 16:25:00	2020-12-15 16:39:14	2020-12-15 18:02:54	27	0	\N	\N
534172	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Principes de la République	\N	2021-02-17 18:45:00	2021-02-17 19:30:00	\N	\N	3	0	\N	\N
534176	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ambassadrice de France	Entretien avec S.E. Mme Véronique VOULAND-ANEINI, Ambassadrice de France en Jordanie, sur l¿actualité de la Jordanie 	2021-02-18 15:30:00	2021-02-18 16:15:00	\N	\N	4	0	659	\N
535603	DELEGATION	AUTRE	\N	\N	DSOM	Visibilité des outre-mer dans l'audiovisuel public	\N	2021-03-16 17:00:00	2021-03-16 18:30:00	\N	\N	11	0	\N	\N
536235	MISSION	AUCUNE	\N	VIETUDIA	\N	Réunion constitutive	\N	2021-03-03 17:00:00	2021-03-03 18:05:00	2021-03-04 08:22:58	2021-03-04 17:59:29	16	0	\N	\N
536269	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PPL Diverses mesures de justice sociale - Examen des motions et amendements de séance	\N	2021-03-09 14:00:00	2021-03-09 14:06:00	2021-03-09 14:19:57	2021-03-09 18:16:28	18	0	\N	\N
536270	COM_PERMANENTE	AUTRE	\N	SOCI	\N	GT Expertise psychiatrique en matière pénale - Examen de rapport d¿information	\N	2021-03-10 09:05:00	2021-03-10 09:50:00	2021-03-10 11:44:00	2021-03-10 17:11:57	51	0	\N	\N
536275	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	Réunion plénière	2021-03-10 10:05:00	2021-03-10 12:40:00	2021-03-10 13:23:58	2021-03-10 17:12:03	37	0	\N	\N
536276	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière	Examen de la note sur la phagothérapie et du rapport sur l'intégrité scientifique	2021-03-04 10:10:00	2021-03-04 12:20:00	\N	\N	13	0	\N	\N
536286	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition d'Action Logement	\N	2021-03-10 09:35:00	2021-03-10 12:25:00	2021-03-10 19:03:22	2021-03-11 18:44:49	41	0	\N	\N
545500	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-04-06 17:00:00	2021-04-06 18:27:00	2021-04-06 18:56:42	2021-04-07 14:55:44	17	0	\N	\N
545501	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-04-07 09:01:00	2021-04-07 11:46:00	2021-04-07 12:28:11	2021-04-07 14:55:44	29	1	\N	\N
545502	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - Direction générale du Trésor - DG Trésor	Contrôle 2020 - Direction générale du Trésor - DG Trésor	2021-03-23 13:30:00	2021-03-23 15:30:00	\N	\N	2	0	\N	\N
545505	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-04-07 16:30:00	2021-04-07 20:30:00	\N	\N	22	0	\N	\N
545506	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Situation et perspectives SNCF - RLE/DGITM	Contrôle 2021 - Situation et perspectives SNCF - RLE/DGITM	2021-03-23 08:30:00	2021-03-23 10:45:00	\N	\N	2	0	\N	\N
545509	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Situation et perspectives SNCF - SNCF Réseau	Contrôle 2021 - Situation et perspectives SNCF - SNCF Réseau	2021-03-24 16:30:00	2021-03-24 17:40:00	\N	\N	2	0	\N	\N
545512	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Météo France - PDG Météo France	Contrôle 2021 - Météo France - PDG Météo France	2021-03-26 11:00:00	2021-03-26 12:30:00	\N	\N	1	0	\N	\N
545514	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - PGE - Cabinet EY	Contrôle 2021 - PGE - Cabinet EY	2021-03-23 16:05:00	2021-03-23 17:15:00	\N	\N	1	0	\N	\N
545516	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - PGE - Banque de France	Contrôle 2021 - PGE - Banque de France	2021-03-23 17:35:00	2021-03-23 18:35:00	\N	\N	1	0	\N	\N
545518	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Hébergement d'urgence - DB	Contrôle 2021 - Hébergement d'urgence - DB	2021-03-25 14:00:00	2021-03-25 14:45:00	\N	\N	1	0	\N	\N
545520	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - Protection des épargnants - DGCCRF	Contrôle 2020 - Protection des épargnants - DGCCRF	2021-03-23 09:30:00	2021-03-23 10:40:00	\N	\N	2	0	\N	\N
545523	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - Protection des épargnants - AMUNDI	Contrôle 2020 - Protection des épargnants - AMUNDI	2021-03-23 15:00:00	2021-03-23 16:00:00	\N	\N	2	0	\N	\N
545555	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - Protection des épargnants - AEMF	Contrôle 2020 - Protection des épargnants - AEMF	2021-03-24 15:10:00	2021-03-24 16:10:00	\N	\N	2	0	\N	\N
545558	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n°389 Hydroélectricité - DGEC	PPL n°389 Hydroélectricité - DGEC	2021-03-25 10:00:00	2021-03-25 11:00:00	\N	\N	1	0	\N	\N
545560	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n°389 Hydroélectricité - EDF	PPL n°389 Hydroélectricité - EDF	2021-03-25 11:30:00	2021-03-25 12:30:00	\N	\N	1	0	\N	\N
545562	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Forces de souveraineté - Forces armées Antilles	Contrôle 2021 - Forces de souveraineté - Forces armées Antilles	2021-03-24 13:00:00	2021-03-24 14:00:00	\N	\N	1	0	\N	\N
545564	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Forces de souveraineté - EMAA/EMA	Contrôle 2021 - Forces de souveraineté - EMAA/EMA	2021-03-24 16:30:00	2021-03-24 18:30:00	\N	\N	1	0	\N	\N
545566	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Services dédiés à la recherche patrimoniale - C2RMF	Contrôle 2021 - Services dédiés à la recherche patrimoniale - C2RMF	2021-03-24 14:30:00	2021-03-24 16:00:00	\N	\N	2	0	\N	\N
545569	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Immobilier universitaire - DGESIP	Contrôle 2021 - Immobilier universitaire - DGESIP	2021-03-23 14:30:00	2021-03-23 15:30:00	\N	\N	1	0	\N	\N
545571	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 -  Enseignants matières scientifiques - DEPP/Associations enseignants	Contrôle 2021 - Enseignants matières scientifiques - DEPP/Associations enseignants	2021-03-23 14:00:00	2021-03-23 16:45:00	\N	\N	1	0	\N	\N
545574	GIA	AUCUNE	\N	\N	\N	Auditions sur l'expérimentation finlandaise de revenu universel 	Auditions organisées par la mission d'information "Lutte contre la paupérisation et la précarisatition"	2021-03-29 08:05:00	2021-03-29 12:05:00	\N	\N	1	0	640	\N
545576	MISSION	AUDRAP	\N	METHANIS	\N	Audition FNE	Audition FNE	2021-03-25 14:00:00	2021-03-25 14:45:00	\N	\N	5	0	\N	\N
545581	MISSION	AUDRAP	\N	METHANIS	\N	Audition Association nationale des industries alimentaires (ANIA)	Audition Association nationale des industries alimentaires (ANIA)	2021-03-25 14:45:00	2021-03-25 15:30:00	\N	\N	5	0	\N	\N
545590	MISSION	AUDRAP	\N	METHANIS	\N	Audition de l'Institut national de l'environnement industriel et des risques (Ineris)	Audition de l'Institut national de l'environnement industriel et des risques (Ineris)	2021-03-25 15:30:00	2021-03-25 16:30:00	\N	\N	6	0	\N	\N
545610	COM_PERMANENTE	AUDRAP	\N	FINC	\N	GS 2020 - Lutte contre la fraude et l'évasion fiscales - DGFiP	GS 2020 - Lutte contre la fraude et l'évasion fiscales - DGFiP	2021-03-24 18:30:00	2021-03-24 19:45:00	\N	\N	10	0	\N	\N
545622	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n° 385 fonds souverains régionaux - DGCL/ARF	PPL n° 385 fonds souverains régionaux - DGCL/ARF	2021-03-25 09:30:00	2021-03-25 11:30:00	\N	\N	1	0	\N	\N
545624	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n° 385 fonds souverains régionaux - Auteure PPL	PPL n° 385 fonds souverains régionaux - Auteure PPL	2021-03-25 15:45:00	2021-03-25 16:30:00	\N	\N	2	0	\N	\N
546497	MISSION	AUDRAP	\N	METHANIS	\N	Audition Bpifrance	Audition Bpifrance	2021-03-29 14:45:00	2021-03-29 15:30:00	\N	\N	5	0	\N	\N
546499	MISSION	AUDRAP	\N	METHANIS	\N	Audition Collectif scientifique national sur la méthanisation raisonnée	Audition Collectif scientifique national sur la méthanisation raisonnée	2021-03-29 15:30:00	2021-03-29 16:30:00	\N	\N	7	0	\N	\N
562330	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Haut Karabakh	\N	2021-05-19 13:45:00	2021-05-19 14:45:00	\N	\N	2	0	\N	\N
562341	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Prévention d'actes de terrorisme et renseignement	\N	2021-05-25 09:00:00	2021-05-25 11:00:00	\N	\N	1	0	\N	\N
618377	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Harkis et autres personnes rapatriées d'Algérie - Audition rapporteure 	\N	2022-01-06 09:30:00	2022-01-06 11:30:00	\N	\N	4	0	\N	\N
618382	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Harkis et autres personnes rapatriées d'Algérie - Audition rapporteure 	\N	2022-01-06 11:30:00	2022-01-06 12:00:00	\N	\N	5	0	\N	\N
618388	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Harkis et autres personnes rapatriées d'Algérie - Audition rapporteure 	\N	2022-01-06 14:30:00	2022-01-06 16:00:00	\N	\N	5	0	\N	\N
618394	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Harkis et autres personnes rapatriées d'Algérie - Audition rapporteure 	\N	2022-01-06 16:00:00	2022-01-06 17:30:00	\N	\N	3	0	\N	\N
618398	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Harkis et autres personnes rapatriées d'Algérie - Audition rapporteure 	\N	2022-01-06 17:30:00	2022-01-06 18:15:00	\N	\N	2	0	\N	\N
618401	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Harkis et autres personnes rapatriées d'Algérie - Audition rapporteure 	\N	2022-01-05 18:15:00	2022-01-05 20:00:00	\N	\N	5	0	\N	\N
618677	COM_PERMANENTE	AUDRAP	\N	CDD	\N	MI Aménagement du territoire - Audition M. Belin et Mme Herzog	MI Aménagement du territoire - Audition M. Belin et Mme Herzog	2022-01-05 08:30:00	2022-01-05 09:30:00	\N	\N	2	0	\N	\N
618681	COM_PERMANENTE	AUDRAP	\N	CDD	\N	MI Aménagement du territoire - Audition Mmes Filleul et Herzog	MI Aménagement du territoire - Audition Mmes Filleul et Herzog	2022-01-05 16:30:00	2022-01-05 17:30:00	\N	\N	2	0	\N	\N
618685	COM_PERMANENTE	AUDRAP	\N	CDD	\N	MI Aménagement du territoire - Audition Mme Demas	MI Aménagement du territoire - Audition Mme Demas	2022-01-05 14:00:00	2022-01-05 14:50:00	\N	\N	1	0	\N	\N
619132	ETUDES	AUCUNE	\N	\N	\N	Audition M. Rousseau	Audition M. Rousseau	2021-11-10 13:30:00	2021-11-10 15:00:00	\N	\N	1	0	\N	919
619250	DELEGATION	AUCUNE	\N	\N	211	Table ronde avec des associations féministes engagées dans la lutte contre la pornographie	Table ronde avec des associations féministes engagées dans la lutte contre la pornographie	2022-01-20 09:00:00	2022-01-20 11:05:00	2022-01-20 11:19:24	\N	17	0	\N	\N
619252	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Auditions PDemas / CB	\N	2022-01-11 14:30:00	2022-01-11 16:45:00	\N	\N	0	0	\N	\N
619253	COM_PERMANENTE	AUDRAP	\N	CDD	\N	MI Aménagement du territoire - Auditions Mme Patricia Demas	MI Aménagement du territoire - Auditions Mme Patricia Demas	2022-01-11 14:30:00	2022-01-11 16:20:00	\N	\N	1	0	\N	\N
619905	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Jigjidsuren CHINBUREN, président du groupe d'amitié Mongolie-France	Entretien avec M. Jigjidsuren CHINBUREN, président du groupe d'amitié Mongolie-France du Grand Khoural (visio)	2022-01-12 14:00:00	2022-01-12 14:45:00	\N	\N	1	0	612	\N
624086	MISSION	AUDRAP	\N	JUDI	\N	\N	Audition rapporteur - MI Judiciarisation	2022-01-19 14:00:00	2022-01-19 15:00:00	\N	\N	2	0	\N	\N
629403	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Aménagement du territoire - B. Rojouan	MI Aménagement du territoire - B. Rojouan	2022-01-04 14:30:00	2022-01-04 15:55:00	\N	\N	2	0	\N	\N
629406	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Aménagement du territoire - B. Rojouan	MI Aménagement du territoire - B. Rojouan	2022-01-04 16:00:00	2022-01-04 17:30:00	\N	\N	1	0	\N	\N
631445	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Table ronde sur le commerce extérieur avec les représentants des entreprises	\N	2022-02-10 09:00:00	2022-02-10 11:00:00	\N	\N	13	0	\N	\N
631459	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Auditions de M. Bruno Rojouan / AP	\N	2022-01-04 14:30:00	2022-01-04 17:30:00	\N	\N	0	0	\N	\N
631460	MISSION	AUCUNE	\N	JUDI	\N	Table ronde consacrée au droit européen	Table ronde consacrée au droit européen	2022-02-15 14:45:00	2022-02-15 17:00:00	2022-02-15 16:59:58	2022-02-15 17:31:23	8	0	\N	\N
631474	GIA	AUCUNE	\N	\N	\N	Audition du coprésident du Groupe de Minsk	Audition de M. Brice Roquefeuil, ambassadeur, coprésident du Groupe de Minsk (OSCE)	2022-02-10 08:00:00	2022-02-10 09:30:00	\N	\N	11	0	641	\N
631490	GIA	AUCUNE	\N	\N	\N	Audition du coprésident du Groupe de Minsk	Audition de M. Brice Roquefeuil, ambassadeur, coprésident du Groupoe de Minsk (OSCE)	2022-02-10 08:00:00	2022-02-10 09:30:00	\N	\N	3	0	534	\N
631494	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Auditions de M. Rojouan (AP)	\N	2022-01-27 14:30:00	2022-01-27 17:30:00	\N	\N	0	0	\N	\N
631498	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Audition BRojouan AP	\N	2022-02-08 14:30:00	2022-02-08 16:30:00	\N	\N	0	0	\N	\N
631510	ETUDES	AUTRE	\N	\N	\N	Fondation Françoise Sommer	\N	2022-02-09 08:00:00	2022-02-09 09:30:00	\N	\N	23	0	\N	907
631546	MISSION	AUCUNE	\N	CONF	\N	Réunion plénière "Le variant Omicron, et après ?"	\N	2022-02-10 10:30:00	2022-02-10 12:00:00	2022-02-16 10:12:06	2022-02-16 10:45:30	5	0	\N	\N
631562	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Choix du nom issu de la filiation (amendements)	PPL Choix du nom issu de la filiation (amendements)	2022-02-15 14:00:00	2022-02-15 14:15:00	2022-02-15 14:45:13	2022-02-15 14:49:46	18	0	\N	\N
631564	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désignations - PPL Marché de l'art - PPL/PPLO Elections et covid (rapports et textes)	Désignations - PPL Marché de l'art - PPL/PPLO Elections et covid (rapports et textes)	2022-02-16 09:35:00	2022-02-16 10:55:00	2022-02-16 14:20:47	2022-02-17 16:42:21	39	0	\N	\N
631565	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition SGDSN, Comité éthique et scientifique, et Viginum	Audition SGDSN, Comité éthique et scientifique, et Viginum	2022-02-16 11:10:00	2022-02-16 12:15:00	2022-02-16 14:24:32	2022-02-17 16:42:19	25	0	\N	\N
631578	DELEGATION	AUCUNE	\N	\N	PROS	Audition publique sur la gestion de l'eau	\N	2022-02-10 09:20:00	2022-02-10 12:50:00	2022-02-10 14:34:12	\N	10	0	\N	\N
631592	DELEGATION	AUCUNE	\N	\N	206	Audition publique sur la gestion de l'eau	\N	2022-02-10 09:20:00	2022-02-10 12:50:00	\N	\N	7	0	\N	\N
631653	MISSION	AUCUNE	\N	CULTURE	\N	Auditions 20220215	\N	2022-02-15 16:00:00	2022-02-15 19:05:00	2022-02-15 19:03:58	2022-02-16 10:59:20	6	0	\N	\N
631654	MISSION	AUCUNE	\N	CULTURE	\N	Audition 20220216b	\N	2022-02-16 16:45:00	2022-02-16 17:55:00	2022-02-16 17:56:27	2022-02-17 16:47:28	3	0	\N	\N
631655	ETUDES	AUDRAP	\N	\N	\N	audition	\N	2022-02-09 14:30:00	2022-02-09 16:30:00	\N	\N	0	0	\N	1008
631667	MISSION	AUDRAP	\N	CULTURE	\N	Audition du réseau des INSPÉ	\N	2022-02-16 13:30:00	2022-02-16 14:20:00	\N	\N	3	0	\N	\N
631674	MISSION	AUCUNE	\N	RECHINNO	\N	Paris-Dauphine -  PSL / Conseil national du Numérique	Paris-Dauphine -  PSL / Conseil national du Numérique	2022-02-08 15:30:00	2022-02-08 17:30:00	2022-02-16 10:57:37	2022-02-16 11:55:50	8	0	\N	\N
631683	MISSION	AUCUNE	\N	RECHINNO	\N	ANRT	ANRT	2022-02-09 17:05:00	2022-02-09 18:10:00	2022-02-16 10:58:45	2022-02-16 11:55:47	4	0	\N	\N
631981	GIA	AUCUNE	\N	\N	\N	Déjeuner débat avec Mgr Rougé	Déjeuner débat avec Mgr Matthieu Rougé, évêque de Nanterre, autour du document de la CEF en vue des élections 	2022-02-15 12:30:00	2022-02-15 14:15:00	\N	\N	17	0	629	\N
632051	DELEGATION	DEPLACEMENT	\N	\N	206	Visite de la centrale nucléaire de Nogent-sur-Seine	Visite de la centrale nucléaire de Nogent-sur-Seine	2022-02-07 09:30:00	2022-02-07 18:30:00	\N	\N	2	0	\N	\N
634210	QUESTURE	AUCUNE	\N	\N	\N	Réunion de Questure	Réunion de Questure	2022-02-17 11:45:00	2022-02-17 13:00:00	\N	\N	3	0	\N	\N
634647	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL fonction publique des communes de Polynésie française	PJL fonction publique des communes de Polynésie française	2022-02-21 17:00:00	2022-02-21 18:50:00	\N	\N	21	0	\N	\N
634649	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	LEC PPL Implantation de panneaux photovoltaïques	LEC PPL  Implantation de panneaux photovoltaïques	2022-02-22 15:15:00	2022-02-22 16:20:00	\N	\N	88	0	\N	\N
634650	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Régulation du marché de l'art	PPL Régulation du marché de l'art	2022-02-22 16:25:00	2022-02-22 17:20:00	\N	\N	75	0	\N	\N
634651	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat visant à dresser un bilan de la politique éducative française	Débat visant à dresser un bilan de la politique éducative française	2022-02-22 17:30:00	2022-02-22 19:20:00	\N	\N	80	0	\N	\N
634652	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Innovation en santé	PPL Innovation en santé	2022-02-22 19:25:00	2022-02-22 20:00:00	\N	\N	41	0	\N	\N
597324	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2021-11-03 08:35:00	2021-11-03 12:30:00	2021-11-03 14:48:13	2021-11-03 16:47:23	42	0	\N	\N
511011	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de Jean-Christophe Galloux, candidat pour siéger au CSM - Dépouillement et vote	Audition de Jean-Christophe Galloux, candidat pour siéger au CSM - Dépouillement et vote	2020-12-01 17:35:00	2020-12-01 18:45:00	2020-12-01 19:15:11	2020-12-02 09:42:52	19	0	\N	\N
517134	GIA	AUCUNE	\N	\N	\N	Assemblée générale	Assemblée générale reconstitutive	2020-12-15 13:45:00	2020-12-15 14:15:00	\N	\N	14	0	641	\N
517158	GIA	AUCUNE	\N	\N	\N	Réunion constitutive	\N	2020-12-08 14:00:00	2020-12-08 14:20:00	\N	\N	18	0	596	\N
517264	GIA	AUCUNE	\N	\N	\N	AG	Assemblée générale post renouvellement sénatorial	2020-12-15 14:45:00	2020-12-15 15:15:00	\N	\N	7	0	594	\N
517474	DELEGATION	AUDRAP	\N	\N	206	Audition Production d'hydrogène - Groupe Total	Audition Production d'hydrogène - Groupe Total	2020-12-17 15:00:00	2020-12-17 16:35:00	\N	\N	1	0	\N	\N
517476	DELEGATION	AUDRAP	\N	\N	206	Audition Production d'hydrogène - Areva H2Gen	Audition Production d'hydrogène - Areva H2Gen	2020-12-17 16:35:00	2020-12-17 18:00:00	\N	\N	1	0	\N	\N
517607	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Groupe de travail "Agriculteurs en situation de détresse"	Audition GT Agriculteurs en détresse	2020-12-15 16:00:00	2020-12-15 16:50:00	\N	\N	10	0	\N	\N
517621	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Groupe de travail "Agriculteurs en situation de détresse"	Audition GT Agriculteurs en détresse	2020-12-15 16:50:00	2020-12-15 17:35:00	\N	\N	8	0	\N	\N
517632	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Groupe de travail "Agriculteurs en situation de détresse"	Audition GT Agriculteurs en détresse	2020-12-15 17:35:00	2020-12-15 18:15:00	\N	\N	2	0	\N	\N
517635	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Groupe de travail "Nouvelles formes de commerce"	Auditions GT Nouvelles formes de commerce	2020-12-11 09:30:00	2020-12-11 10:15:00	\N	\N	2	0	\N	\N
517638	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Groupe de travail "Nouvelles formes de commerce"	Auditions GT Nouvelles formes de commerce	2020-12-11 17:00:00	2020-12-11 18:00:00	\N	\N	1	0	\N	\N
518553	GIA	AUCUNE	\N	\N	\N	Assemblée générale	\N	2020-12-17 09:45:00	2020-12-17 10:15:00	\N	\N	6	0	584	\N
518779	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2020-12-16 14:05:00	2020-12-16 14:55:00	\N	\N	28	0	\N	\N
533081	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2021-03-03 08:30:00	2021-03-03 11:50:00	2021-03-03 16:07:52	2021-03-03 17:06:01	39	0	\N	\N
533082	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion LEC	\N	2021-03-03 14:00:00	2021-03-03 14:40:00	2021-03-03 14:57:50	2021-03-03 17:06:05	26	0	\N	\N
534079	GIA	AUCUNE	\N	\N	\N	Audition MAE Tanzanie	audition du ministre des affaires étrangères de Tanzanie	2021-02-18 14:30:00	2021-02-18 15:45:00	\N	\N	10	0	622	\N
535298	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur	\N	2021-03-02 16:00:00	2021-03-02 17:00:00	\N	\N	1	0	\N	\N
536653	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Respect des principes de la République	\N	2021-03-04 14:00:00	2021-03-04 19:00:00	\N	\N	2	0	\N	\N
536896	GIA	AUCUNE	\N	\N	\N	Entretien avec S.E. M. Luis VASSY, Ambassadeur de France aux Pays-Bas	Entretien avec S.E. M. Luis VASSY, Ambassadeur de France aux Pays-Bas	2021-03-10 17:00:00	2021-03-10 18:00:00	\N	\N	5	0	599	\N
551359	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Auditions groupe de travail "Objectif de zéro artificialisation nette"	Auditions groupe de travail "Objectif de zéro artificialisation nette"	2021-04-07 18:30:00	2021-04-07 19:30:00	\N	\N	3	0	\N	\N
551363	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Auditions groupe de travail "Objectif de zéro artificialisation nette"	Auditions groupe de travail "Objectif de zéro artificialisation nette"	2021-04-08 14:30:00	2021-04-08 16:00:00	\N	\N	6	0	\N	\N
554937	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	NRJ Groupe	\N	2021-04-20 10:00:00	2021-04-20 10:50:00	\N	\N	2	0	\N	\N
554938	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	TF1	\N	2021-04-20 10:50:00	2021-04-20 11:35:00	\N	\N	1	0	\N	\N
554939	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Altice SFR	\N	2021-04-20 11:35:00	2021-04-20 12:20:00	\N	\N	2	0	\N	\N
554940	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	TDF	\N	2021-04-20 17:00:00	2021-04-20 17:50:00	\N	\N	2	0	\N	\N
554941	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Groupe M6	\N	2021-04-20 17:50:00	2021-04-20 18:55:00	\N	\N	2	0	\N	\N
554942	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Eutelsat	\N	2021-04-21 09:30:00	2021-04-21 10:15:00	\N	\N	1	0	\N	\N
554943	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	CANAL+	\N	2021-04-21 10:15:00	2021-04-21 11:00:00	\N	\N	1	0	\N	\N
554944	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	France télévisions	\N	2021-04-21 11:00:00	2021-04-21 11:45:00	\N	\N	1	0	\N	\N
554945	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	pjl audiovisuel - FFT	\N	2021-04-26 17:30:00	2021-04-26 18:30:00	\N	\N	0	0	\N	\N
554946	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Pjl audiovisuel	\N	2021-04-27 16:00:00	2021-04-27 17:00:00	\N	\N	0	0	\N	\N
554947	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PJL Climat Volet Consommer	\N	2021-04-20 10:45:00	2021-04-20 12:00:00	\N	\N	1	0	\N	\N
554949	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PJL Climat Volet Consommer	Auditions PJL Climat Volet Consommer	2021-04-20 14:00:00	2021-04-20 15:15:00	\N	\N	2	0	\N	\N
554952	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PJL Climat Consommer	Auditions PJL Climat Consommer	2021-04-20 15:15:00	2021-04-20 18:00:00	\N	\N	1	0	\N	\N
554954	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition PJL Climat - ANEL	Audition PJL Climat - ANEL	2021-04-20 08:30:00	2021-04-20 09:30:00	\N	\N	4	0	\N	\N
554955	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition PJL Climat - Accd'OM	Audition PJL Climat - Accd'OM	2021-04-20 09:30:00	2021-04-20 10:30:00	\N	\N	4	0	\N	\N
554956	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition PJL Climat - AMORCE	Audition PJL Climat - AMORCE	2021-04-20 10:30:00	2021-04-20 11:30:00	\N	\N	5	0	\N	\N
554957	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition PJL Climat - ANPP	Audition PJL Climat - ANPP	2021-04-20 11:30:00	2021-04-20 12:30:00	\N	\N	4	0	\N	\N
554958	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition PJL Climat - Association des petites villes de France 	Audition PJL Climat - Association des petites villes de France 	2021-04-20 14:00:00	2021-04-20 15:00:00	\N	\N	6	0	\N	\N
554959	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition PJL Climat - TR Jeunesses	Audition PJL Climat - TR Jeunesses	2021-04-20 15:05:00	2021-04-20 16:40:00	\N	\N	5	0	\N	\N
554960	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditin PJL Climat - MEDEF	Auditin PJL Climat - MEDEF	2021-04-20 16:40:00	2021-04-20 17:40:00	\N	\N	4	0	\N	\N
554961	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition PJL Climat - AMF et AMRF	Audition PJL Climat - AMF et AMRF	2021-04-20 18:20:00	2021-04-20 19:20:00	\N	\N	5	0	\N	\N
554962	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - PGE - ACOSS	Contrôle 2021 - PGE - ACOSS	2021-04-20 11:45:00	2021-04-20 12:30:00	\N	\N	1	0	\N	\N
554964	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - PGE - IPP	Contrôle 2021 - PGE - IPP	2021-04-20 14:00:00	2021-04-20 16:25:00	\N	\N	1	0	\N	\N
554972	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2021 - PGE - Déplacement Nancy	Contrôle 2021 - PGE - Déplacement Nancy	2021-04-21 09:45:00	2021-04-21 17:15:00	\N	\N	1	0	\N	\N
555299	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Dérèglement climatique et résilience - Auditions de Mme Marta de Cidrac	PJL Dérèglement climatique et résilience - Auditions de Mme Marta de Cidrac	2021-04-27 08:30:00	2021-04-27 10:00:00	\N	\N	1	0	\N	\N
632477	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition rapporteur	\N	2022-01-11 17:00:00	2022-01-11 18:00:00	\N	\N	0	0	\N	\N
555302	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Dérèglement climatique et résilience - Auditions de Mme Marta de Cidrac	PJL Dérèglement climatique et résilience - Auditions de Mme Marta de Cidrac	2021-04-27 10:45:00	2021-04-27 11:30:00	\N	\N	4	0	\N	\N
555309	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Dérèglement climatique et résilience - Auditions de Mme Marta de Cidrac	PJL Dérèglement climatique et résilience - Auditions de Mme Marta de Cidrac	2021-04-27 11:30:00	2021-04-27 12:15:00	\N	\N	1	0	\N	\N
555311	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Dérèglement climatique et résilience - Auditions de Mme Marta de Cidrac	PJL Dérèglement climatique et résilience - Auditions de Mme Marta de Cidrac	2021-04-27 18:00:00	2021-04-27 18:45:00	\N	\N	2	0	\N	\N
555314	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Dérèglement climatique et résilience - Auditions de Mme Marta de Cidrac	PJL Dérèglement climatique et résilience - Auditions de Mme Marta de Cidrac	2021-04-27 18:45:00	2021-04-27 19:30:00	\N	\N	1	0	\N	\N
555316	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Dérèglement climatique et résilience - Auditions de M. Pascal Martin	PJL Dérèglement climatique et résilience - Auditions de M. Pascal Martin	2021-04-27 14:45:00	2021-04-27 16:15:00	\N	\N	1	0	\N	\N
595598	DELEGATION	AUCUNE	\N	\N	211	Rencontre avec Mme Valérie Bacot	Rencontre avec Mme Valérie Bacot, auteure de Tout le monde savait, accompagnée de son avocate, Maître Nathalie Tomasini	2021-11-04 09:30:00	2021-11-04 11:35:00	\N	\N	10	0	\N	\N
595599	MISSION	AUDRAP	\N	CONF	\N	Table ronde sur la Réunoin	\N	2021-10-21 14:30:00	2021-10-21 16:15:00	\N	\N	0	0	\N	\N
595609	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2022 - AGTE	PLF pour 2022 - AGTE	2021-10-19 16:00:00	2021-10-19 18:30:00	\N	\N	1	0	\N	\N
595617	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2022 - Crédits Sport	Audition de la Solidéo	2021-10-22 09:00:00	2021-10-22 10:20:00	\N	\N	1	0	\N	\N
595618	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2022 - programme 178	\N	2021-10-19 17:00:00	2021-10-19 18:00:00	\N	\N	1	0	\N	\N
595621	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2022 - Mission régimes sociaux et de retraite	\N	2021-10-28 11:30:00	2021-10-28 12:15:00	\N	\N	2	0	\N	\N
595622	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2022 - Programme Hébergement - Mission Cohésion territoires	\N	2021-10-26 14:00:00	2021-10-26 17:45:00	\N	\N	1	0	\N	\N
595624	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2022 Autonomie - Table ronde d'associations	\N	2021-10-19 15:00:00	2021-10-19 16:00:00	\N	\N	3	0	\N	\N
595625	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2022 Autonomie - Table ronde sur les personnes âgées	\N	2021-10-21 09:00:00	2021-10-21 10:15:00	\N	\N	3	0	\N	\N
595626	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2022 Autonomie - Audition d'APF France Handicap	\N	2021-10-21 10:30:00	2021-10-21 11:30:00	\N	\N	2	0	\N	\N
595627	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Solidarité - TR "Égalité F/H"	PLF pour 2022 - Solidarité - TR "Égalité F/H"	2021-10-19 16:00:00	2021-10-19 17:00:00	\N	\N	2	0	\N	\N
595630	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2022 Assurance maladie - Table ronde des fédérations hospitalières	\N	2021-10-19 16:00:00	2021-10-19 17:00:00	\N	\N	6	0	\N	\N
595631	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2022 Assurance maladie et Equilibres financiers généraux - Audition du LEEM	\N	2021-10-19 09:30:00	2021-10-19 10:30:00	\N	\N	2	0	\N	\N
595632	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2022 Assurance maladie et Equilibres financiers généraux - Audition du Snitem	\N	2021-10-20 14:00:00	2021-10-20 14:45:00	\N	\N	2	0	\N	\N
595633	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2022 Assurance maladie - Audition du CNOP	\N	2021-10-20 16:30:00	2021-10-20 17:30:00	\N	\N	1	0	\N	\N
595634	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2022 Assurance maladie - Audition de la DGOS	\N	2021-10-20 17:30:00	2021-10-20 18:30:00	\N	\N	2	0	\N	\N
595638	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Solidarité - FranceAgriMer et TR "Handicap"	PLF pour 2022 - Solidarité - FranceAgriMer et TR "Handicap"	2021-10-20 15:30:00	2021-10-20 18:10:00	\N	\N	2	0	\N	\N
595659	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Travail et emploi - DGEFP/DFAS	PLF pour 2022 - Travail et emploi - DGEFP/DFAS	2021-10-21 15:00:00	2021-10-21 17:00:00	\N	\N	2	0	\N	\N
595662	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Solidarité - IF-PJM	PLF pour 2022 - Solidarité - IF-PJM	2021-10-21 14:00:00	2021-10-21 15:00:00	\N	\N	2	0	\N	\N
595665	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Travail et emploi - DGT	PLF pour 2022 - Travail et emploi - DGT	2021-10-22 10:45:00	2021-10-22 11:45:00	\N	\N	2	0	\N	\N
595668	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Sécurités - Syndicats APN/FSMI FO	PLF pour 2022 - Sécurités - Syndicats APN/FSMI FO	2021-10-19 13:30:00	2021-10-19 16:30:00	\N	\N	1	0	\N	\N
595670	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Sécurités - DGPN	PLF pour 2022 - Sécurités - DGPN	2021-10-21 09:30:00	2021-10-21 10:30:00	\N	\N	1	0	\N	\N
595672	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022- Défense - Armée de l'Air	PLF pour 2022- Défense - Armée de l'Air	2021-10-21 15:30:00	2021-10-21 16:30:00	\N	\N	1	0	\N	\N
595674	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Rapport général - Économiste Pictet Wealth Management	PLF pour 2022 - Rapport général - Économiste Pictet Wealth Management	2021-10-19 09:30:00	2021-10-19 10:30:00	\N	\N	1	0	\N	\N
595676	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - APD - DB	PLF pour 2022 - APD - DB	2021-10-19 14:00:00	2021-10-19 15:00:00	\N	\N	2	0	\N	\N
595679	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - AEE - DG MEAE	PLF pour 2022 - AEE - DG MEAE	2021-10-20 15:30:00	2021-10-20 16:30:00	\N	\N	2	0	\N	\N
595682	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Rapport général - Banque de France	PLF pour 2022 - Rapport général - Banque de France	2021-10-21 09:30:00	2021-10-21 10:30:00	\N	\N	1	0	\N	\N
595684	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - AEE - DB	PLF pour 2022 - AEE - DB	2021-10-21 11:00:00	2021-10-21 12:00:00	\N	\N	2	0	\N	\N
595711	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2021-10-20 19:05:00	2021-10-20 20:05:00	\N	\N	3	0	\N	\N
595715	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2022 - Avis « Fonction publique »	PLF pour 2022 - Avis « Fonction publique »	2021-10-25 11:00:00	2021-10-25 12:00:00	\N	\N	1	0	\N	\N
596409	GIA	AUCUNE	\N	\N	\N	Petit-déjeuner avec l'ambassadeur de Hongrie	Petit-déjeuner avec l'ambassadeur de Hongrie	2021-10-27 08:30:00	2021-10-27 09:30:00	\N	\N	10	0	592	\N
596545	GIA	AUCUNE	\N	\N	\N	Petit déjeuner avec l'ambassadeur de France en Serbie 	petit déjeuner avec l'ambassadeur de France en Serbie 	2021-10-27 09:00:00	2021-10-27 10:15:00	\N	\N	2	0	674	\N
596548	GIA	AUCUNE	\N	\N	\N	Déplacement du groupe d'amitié en Macédoine du Nord, en Serbie et au Monténégro	Déplacement du groupe d'amitié en Macédoine du Nord, en Serbie et au Monténégro	2021-09-12 08:00:00	2021-09-17 20:00:00	\N	\N	4	0	674	\N
597306	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2022 - Avis « Fonction publique »	PLF pour 2022 - Avis « Fonction publique »	2021-10-27 15:00:00	2021-10-27 16:00:00	\N	\N	1	0	\N	\N
597313	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2022 - Avis « Fonction publique »	PLF pour 2022 - Avis « Fonction publique »	2021-10-27 16:15:00	2021-10-27 17:15:00	\N	\N	1	0	\N	\N
659415	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL LOPMI	PJL LOPMI	2022-10-13 10:30:00	2022-10-13 13:00:00	\N	\N	61	0	\N	\N
597457	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	Assemblée générale du groupe d'études Français de l'étranger	AG du groupe d'études " Français de l'étranger"	2021-10-27 14:30:00	2021-10-27 14:45:00	\N	\N	26	0	\N	\N
597486	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 1è partie "Équilibres financiers"	\N	2021-10-28 09:00:00	2021-10-28 10:05:00	\N	\N	3	0	\N	\N
597490	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition CATMP - Branche ATMP	\N	2021-10-13 17:00:00	2021-10-13 19:00:00	\N	\N	0	0	\N	\N
597538	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Cybersécurité des collectivités territoriales	\N	2021-10-28 09:00:00	2021-10-28 12:00:00	2021-10-28 14:43:34	\N	29	0	\N	\N
597571	COM_EURO	AUDRAP	\N	AFEU	\N	Auditions taxonomie européenne	\N	2021-10-27 14:00:00	2021-10-27 18:30:00	\N	\N	2	0	\N	\N
597588	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 5è partie "Assurance vieillesse"	\N	2021-10-28 10:30:00	2021-10-28 11:30:00	\N	\N	1	0	\N	\N
597599	MISSION	AUDRAP	\N	CONF	\N	Situation en Polynésie française	\N	2021-10-27 19:47:00	2021-10-27 21:10:00	\N	\N	1	0	\N	\N
597695	COM_EURO	AUDRAP	\N	AFEU	\N	Audition UE et Education	Audition UE et Education	2021-10-26 16:15:00	2021-10-26 17:50:00	\N	\N	2	0	\N	\N
597710	COM_PERMANENTE	AUTRE	\N	LOIS	\N	ENQ Influence cabinets conseils privés - ENQ Concentrations média - Avis sur recevabilité	ENQ Influence cabinets conseils privés - ENQ Concentrations média - Avis sur recevabilité	2021-11-02 17:00:00	2021-11-02 17:15:00	2021-11-02 18:06:10	2021-11-03 16:47:22	16	0	\N	\N
597760	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Anglars	\N	2021-10-13 09:30:00	2021-10-13 10:00:00	\N	\N	1	0	\N	\N
597762	COM_PERMANENTE	AUDRAP	\N	CDD	\N	TR Sénateurs	\N	2021-10-13 16:15:00	2021-10-13 17:30:00	\N	\N	3	0	\N	\N
597966	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition PJL Alsace	Audition PJL Alsace	2021-10-18 09:30:00	2021-10-18 11:15:00	\N	\N	2	0	\N	\N
597972	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Alsace 	PJL Alsace 	2021-10-18 17:00:00	2021-10-18 18:00:00	\N	\N	2	0	\N	\N
597980	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition PJL Alsace	Audition PJL Alsace	2021-10-19 09:00:00	2021-10-19 10:00:00	\N	\N	2	0	\N	\N
597987	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition PJL Alsace	Audition PJL Alsace	2021-10-19 14:00:00	2021-10-19 15:00:00	\N	\N	9	0	\N	\N
597999	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition PJL Alsace	Audition PJL Alsace	2021-10-21 18:00:00	2021-10-21 18:45:00	\N	\N	1	0	\N	\N
506841	DELEGATION	AUDRAP	\N	\N	206	Audition Phagothérapie - ANSM	Audition Phagothérapie - ANSM	2020-11-26 16:00:00	2020-11-26 17:00:00	\N	\N	1	0	\N	\N
525239	GIA	AUCUNE	\N	\N	\N	Entretien avec S.E. M. Ubaidullo, Ambassadeur du Tadjikistan en France	\N	2021-01-26 17:00:00	2021-01-26 18:00:00	\N	\N	2	0	556	\N
525242	GIA	AUCUNE	\N	\N	\N	Audition de S. E. M. Rustambaev, Ambassadeur d'Ouzbékistan en France	\N	2021-01-26 18:00:00	2021-01-26 19:00:00	\N	\N	2	0	556	\N
530858	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Réunion GT Nouvelles formes de commerce	Réunion GT Nouvelles formes de commerce	2021-02-09 18:45:00	2021-02-09 20:00:00	\N	\N	5	0	\N	\N
530887	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	Groupe d'études Statut rôle et place des Français établis hors de France	Groupe d'études Français expatriés - réunion de travail 	2021-02-10 13:30:00	2021-02-10 14:30:00	\N	\N	14	0	\N	\N
534279	GIA	AUCUNE	\N	\N	\N	Entretien avec le nouvel ambassadeur de Bulgarie,  S.E.M. Nikolay Milkov	Visite de courtoisie de S.E.M. Nikolay Milkov, ambassadeur de Bulgarie,	2021-02-24 11:45:00	2021-02-24 12:45:00	\N	\N	2	0	582	\N
545419	GIA	AUCUNE	\N	\N	\N	Audience de M. Abdullah Abdullah, Président du Haut Conseil pour la réconciliation nationa	Audience de M. Abdullah Abdullah, Président du Haut Conseil pour la réconciliation nationale de la République islamique 	2021-03-26 10:00:00	2021-03-26 11:00:00	\N	\N	1	0	648	\N
551188	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2021-04-08 09:00:00	2021-04-08 12:00:00	\N	\N	7	0	\N	\N
554919	GIA	AUCUNE	\N	\N	\N	Entretien avec S.E. Mme Gillian BIRD, Ambassadrice d'Australie en France	Entretien avec S.E. Mme Gillian BIRD, Ambassadrice d'Australie en France	2021-04-15 11:00:00	2021-04-15 12:20:00	\N	\N	3	0	578	\N
557307	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Actualisation LPM	\N	2021-05-04 14:00:00	2021-05-04 18:45:00	\N	\N	2	0	\N	\N
557310	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Actualisation LPM	\N	2021-05-05 14:00:00	2021-05-05 15:00:00	\N	\N	2	0	\N	\N
564354	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Prévention d'actes de terrorisme et renseignement	\N	2021-05-27 09:00:00	2021-05-27 12:00:00	\N	\N	2	0	\N	\N
564480	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Différenciation, décentralisation, déconcentration et simplification	PJL Différenciation, décentralisation, déconcentration et simplification	2021-05-27 16:00:00	2021-05-27 16:45:00	\N	\N	3	0	\N	\N
564484	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Différenciation, décentralisation, déconcentration et simplification	PJL Différenciation, décentralisation, déconcentration et simplification	2021-05-27 18:15:00	2021-05-27 18:45:00	\N	\N	1	0	\N	\N
564486	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Différenciation, décentralisation, déconcentration et simplification	PJL Différenciation, décentralisation, déconcentration et simplification	2021-05-28 10:30:00	2021-05-28 11:00:00	\N	\N	1	0	\N	\N
568062	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2021-06-10 09:05:00	2021-06-10 11:25:00	\N	\N	2	0	\N	\N
571572	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2021-06-17 09:05:00	2021-06-17 11:25:00	\N	\N	3	0	\N	\N
574854	ETUDES	AUCUNE	\N	\N	\N	Audition Union des maisons et marques de vin	Audition Union des maisons et marques de vin	2021-06-30 13:30:00	2021-06-30 15:00:00	\N	\N	23	0	\N	909
574881	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT Boussole stratégique	\N	2021-06-21 16:30:00	2021-06-21 17:10:00	\N	\N	1	0	\N	\N
575835	QUESTURE	AUCUNE	\N	\N	\N	\N	\N	2021-06-30 16:40:00	2021-06-30 19:30:00	\N	\N	3	0	\N	\N
577448	GIA	AUCUNE	\N	\N	\N	Audition de représentants de la Banque mondiale	Audition de représentants de la Banque mondiale	2021-07-06 16:00:00	2021-07-06 17:00:00	\N	\N	5	0	597	\N
577457	GIA	AUCUNE	\N	\N	\N	Audition de représentants du Fonds monétaire international	Audition de représentants du Fonds monétaire international	2021-07-07 18:00:00	2021-07-07 19:00:00	\N	\N	5	0	597	\N
579607	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Confiance dans l'institution judiciaire	PJL Confiance dans l'institution judiciaire	2021-07-12 10:00:00	2021-07-12 10:45:00	\N	\N	2	0	\N	\N
579610	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Confiance dans l'institution judiciaire	PJL Confiance dans l'institution judiciaire	2021-07-13 09:15:00	2021-07-13 12:15:00	\N	\N	2	0	\N	\N
659416	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL LOPMI	PJL LOPMI	2022-10-13 14:30:00	2022-10-13 17:45:00	\N	\N	46	0	\N	\N
597484	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Examen des avis budgétaires Rrecherche, Enseignement supérieur et Sport	\N	2021-11-03 09:30:00	2021-11-03 11:45:00	2021-11-04 15:48:14	2021-11-04 16:07:17	35	5	\N	\N
579613	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Confiance dans l'institution judiciaire	PJL Confiance dans l'institution judiciaire	2021-07-13 14:30:00	2021-07-13 15:15:00	\N	\N	4	0	\N	\N
579619	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Confiance dans l'institution judiciaire	PJL Confiance dans l'institution judiciaire	2021-07-13 15:15:00	2021-07-13 16:15:00	\N	\N	3	0	\N	\N
579623	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Confiance dans l'institution judiciaire	PJL Confiance dans l'institution judiciaire	2021-07-13 16:15:00	2021-07-13 19:45:00	\N	\N	2	0	\N	\N
579763	GIA	AUCUNE	\N	\N	\N	Entretien avec le nouvel ambassadeur.	\N	2021-07-20 08:15:00	2021-07-20 09:00:00	\N	\N	1	0	626	\N
579788	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Egalim 2 - FIlière bovine	Auditions Egalim 2 - FIlière bovine	2021-07-19 15:00:00	2021-07-19 15:30:00	\N	\N	2	0	\N	\N
579791	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Egalim 2 - Interprofession fruits et légumes frais	Auditions Egalim 2 - Interprofession fruits et légumes frais	2021-07-19 15:30:00	2021-07-19 16:00:00	\N	\N	3	0	\N	\N
579795	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Egalim 2 - Ministère de l'agriculture	Auditions Egalim 2 - Ministère de l'agriculture	2021-07-19 16:00:00	2021-07-19 16:45:00	\N	\N	2	0	\N	\N
579805	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	LOIS	\N	MI Dysfonctionnements élections juin 2021 - Echange de vues entre les rapporteurs	MI Dysfonctionnements élections juin 2021 - Echange de vues entre les rapporteurs	2021-07-20 15:00:00	2021-07-20 16:00:00	\N	\N	8	0	\N	\N
580803	MISSION	AUCUNE	\N	HARCEL	\N	Mission harcèlement	Mission sur le harcèlement scolaire et le cyber-harcèlement	2021-07-21 14:00:00	2021-07-21 14:48:00	2021-07-21 14:56:25	2021-07-21 15:54:35	8	0	\N	\N
583157	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Jacques PELLET, ambassadeur de France au Cambodge	Entretien avec M. Jacques PELLET, ambassadeur de France au Cambodge	2021-09-10 15:00:00	2021-09-10 16:00:00	\N	\N	1	0	577	\N
583158	GIA	AUCUNE	\N	\N	\N	Accueil de Mme Siv Leng CHHUOR, ambassadrice de France au Laos	Accueil de Mme Siv Leng CHHUOR, ambassadrice de France au Laos	2021-09-14 12:30:00	2021-09-14 14:00:00	\N	\N	3	0	577	\N
584458	MISSION	AUCUNE	\N	HARCEL	\N	MI Harcèlement	Mission d'information sur le harcèlement	2021-09-21 16:00:00	2021-09-21 17:05:00	2021-09-22 10:14:52	2021-09-22 18:46:08	12	0	\N	\N
588291	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2021-09-30 09:05:00	2021-09-30 11:20:00	\N	\N	3	0	\N	\N
591727	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	206	Rencontre « Office-Académies » sur le thème des vaccins et médicaments ARN	Rencontre « Office-Académies » sur le thème des vaccins et médicaments ARN	2021-10-13 08:30:00	2021-10-13 10:00:00	\N	\N	8	0	\N	\N
600402	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2022 - Avis Outre-mer - Audition par Mme Micheline Jacques	PLF 2022 - Avis Outre-mer - Union sociale pour l'habitat - Audition par Mme Micheline Jacques	2021-10-25 10:15:00	2021-10-25 11:15:00	\N	\N	1	0	\N	\N
600405	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2022 - Avis Outre-mer - Audition par Mme Micheline Jacques	PLF 2022 - Avis Outre-mer - L'Agence de l'outre-mer pour la mobilité - Audition par Mme Micheline Jacques	2021-10-25 14:00:00	2021-10-25 15:00:00	\N	\N	1	0	\N	\N
600407	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2022 - Avis Outre-mer - Audition par Mme Micheline Jacques	PLF 2022 - Avis Outre-mer - CDC Habitat - Audition par Mme Micheline Jacques	2021-10-22 17:00:00	2021-10-22 18:00:00	\N	\N	1	0	\N	\N
600410	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2022 - Avis Outre-mer - Audition par Mme Micheline Jacques	PLF 2022 - Avis Outre-mer - ACCIOM et FEDOM - Audition par Mme Micheline Jacques	2021-10-26 17:00:00	2021-10-26 18:30:00	\N	\N	1	0	\N	\N
600413	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2022 - Avis Outre-mer - Audition par Mme Micheline Jacques	PLF 2022 - Avis Outre-mer - Direction du Budget - Audition par Mme Micheline Jacques	2021-10-25 17:00:00	2021-10-25 18:30:00	\N	\N	1	0	\N	\N
600414	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2022 - Avis Outre-mer - Audition par Mme Micheline Jacques	PLF 2022 - Avis Outre-mer - USHOM - Audition par Mme Micheline Jacques	2021-10-29 10:30:00	2021-10-29 11:30:00	\N	\N	1	0	\N	\N
613070	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen rapport d'information sur la sécurité d'acheminement des communications d'urgence	Examen rapport d'information sur la sécurité d'acheminement des communications d'urgence	2021-12-15 09:05:00	2021-12-15 09:30:00	2021-12-15 15:37:12	2021-12-15 17:07:41	97	0	\N	\N
613102	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Rapporteurs - S.E.M. Ivanisevic, Ambassadeur du Monténégro	\N	2021-12-08 11:00:00	2021-12-08 12:00:00	\N	\N	2	0	\N	\N
613119	COM_ENQUETE	PLENIERE	\N	HOPITAL	\N	Réunion plénière	\N	2021-12-16 10:30:00	2021-12-16 12:45:00	2021-12-16 12:52:12	2021-12-16 17:04:34	9	0	\N	\N
613127	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Audition M. PACCAUD PPL Harcèlement scolaire	\N	2021-12-09 14:00:00	2021-12-09 15:30:00	\N	\N	3	0	\N	\N
613133	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Etablissement public du musée du quai Branly-Jacques Chirac	Audition de M. Kasarhérou	2021-12-08 18:30:00	2021-12-08 20:00:00	\N	\N	4	0	\N	\N
613158	GIA	AUCUNE	\N	\N	\N	\N	\N	2021-12-09 00:00:00	2021-12-10 16:30:00	\N	\N	3	0	613	\N
613189	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Auditions plénières - Administrations de santé - Cabinets de conseil	\N	2021-12-15 16:30:00	2021-12-15 19:00:00	\N	\N	0	0	\N	\N
613274	COM_EURO	AUTRE	\N	AFEU	\N	Audition de Mme Girardin, ministre de la Mer	Audition de Mme Girardin, ministre de la Mer, en commun avec la commission des affaires économiques	2021-12-09 10:30:00	2021-12-09 12:00:00	2021-12-09 18:48:01	2021-12-09 19:05:48	14	0	\N	\N
613304	DELEGATION	AUCUNE	\N	\N	COLTER	Table ronde sur la démocratie locale	\N	2021-12-16 09:30:00	2021-12-16 11:00:00	\N	\N	18	0	\N	\N
616385	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2022-01-05 17:30:00	2022-01-05 19:00:00	2022-01-11 12:00:22	2022-01-11 14:13:24	33	0	\N	\N
618083	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Biens culturels	PPL Biens culturels	2022-01-10 17:00:00	2022-01-10 19:00:00	\N	\N	40	0	\N	\N
618084	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Engrillagement	PPL Engrillagement	2022-01-10 19:00:00	2022-01-11 21:00:00	\N	\N	39	0	\N	\N
618088	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Gestion crise sanitaire	PJL Gestion crise sanitaire	2022-01-11 14:30:00	2022-01-11 20:15:00	\N	\N	275	0	\N	\N
618089	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Gestion crise sanitaire	\N	2022-01-11 21:45:00	2022-01-12 00:35:00	\N	\N	183	0	\N	\N
618090	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2022-01-12 15:00:00	2022-01-12 16:25:00	\N	\N	275	0	\N	\N
618091	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Suite PJL Gestion crise sanitaire	Suite PJL Gestion crise sanitaire	2022-01-12 16:35:00	2022-01-12 20:05:00	\N	\N	208	0	\N	\N
618092	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Suite PJL Gestion crise sanitaire	Suite PJL Gestion crise sanitaire	2022-01-12 21:35:00	2022-01-13 02:30:00	\N	\N	157	0	\N	\N
618093	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Port du casque à vélo	PPL Port du casque à vélo	2022-01-13 11:30:00	2022-01-13 12:40:00	\N	\N	39	0	\N	\N
618095	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Plateforme malades Covid	PPL Plateforme malades Covid	2022-01-13 14:30:00	2022-01-13 15:55:00	\N	\N	25	0	\N	\N
618181	COM_ENQUETE	AUDRAP	\N	HOPITAL	\N	Audition SNPHARE	\N	2022-01-06 09:00:00	2022-01-06 10:00:00	\N	\N	8	0	\N	\N
618193	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur - S.E.Mme CHAUSHEVSKA DIMOV, Ambassadrice de Macédoine du Nord	Audition rapporteur - S.E.Mme CHAUSHEVSKA DIMOV, Ambassadrice de Macédoine du Nord	2022-01-12 14:00:00	2022-01-12 15:00:00	\N	\N	2	0	\N	\N
618196	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur - S.E.Mme Natasa MARIC, Ambassadrice de Serbie	Audition rapporteur - S.E.Mme Natasa MARIC, Ambassadrice de Serbie	2022-01-13 15:40:00	2022-01-13 16:45:00	\N	\N	2	0	\N	\N
618201	COM_ENQUETE	AUDRAP	\N	HOPITAL	\N	Audition du Pr Michot	\N	2022-01-06 12:00:00	2022-01-06 13:00:00	\N	\N	5	0	\N	\N
618203	COM_ENQUETE	AUDRAP	\N	HOPITAL	\N	Audition ANCIM	\N	2022-01-06 11:00:00	2022-01-06 12:00:00	\N	\N	5	0	\N	\N
618204	COM_ENQUETE	AUDRAP	\N	HOPITAL	\N	Audition AFDS	\N	2022-01-06 10:00:00	2022-01-06 11:00:00	\N	\N	6	0	\N	\N
618217	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur - M. Christian-Silviu BUSOI	Audition rapporteur- M. Christian Silviu BUSOI, député européen, Président de la commission ITRE	2022-01-10 11:00:00	2022-01-10 12:00:00	\N	\N	2	0	\N	\N
618219	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur - M.Barbéris	Audition rapporteur - M. Jean-Jacques Barbéris, Directeur pôle clients institutionnels et corporates, AMUNDI	2022-01-10 12:00:00	2022-01-10 13:00:00	\N	\N	2	0	\N	\N
618226	MISSION	AUDRAP	\N	CULTURE	\N	Audition du Général Daniel Menaouine	\N	2022-01-11 16:00:00	2022-01-11 17:00:00	\N	\N	3	0	\N	\N
618317	MISSION	AUCUNE	\N	CULTURE	\N	Réunion 20220112	\N	2022-01-12 16:35:00	2022-01-12 17:45:00	2022-01-12 17:46:14	2022-01-13 18:48:10	6	0	\N	\N
618324	COM_PERMANENTE	AUTRE	\N	AFCL	\N	PPL retour biens cultures - amendements éance	\N	2022-01-10 16:30:00	2022-01-10 17:00:00	\N	\N	0	0	\N	\N
618325	COM_PERMANENTE	AUTRE	\N	AFCL	\N	PPL circulation biens culturels - amendements extérieurs	\N	2022-01-10 16:30:00	2022-01-10 17:00:00	\N	\N	0	0	\N	\N
618326	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Communication proposition de législation européenne sur les services numériques (DSA	\N	2022-01-12 09:30:00	2022-01-12 11:00:00	\N	\N	1	0	\N	\N
618351	MISSION	AUCUNE	\N	JUDI	\N	Auditions : Antoine Garapon et Philippe Raynaud - Pascale Joannin et Jacques Ziller	Auditions : Antoine Garapon et Philippe Raynaud - Pascale Joannin et Jacques Ziller	2022-01-11 15:00:00	2022-01-11 17:45:00	2022-01-11 18:20:15	2022-01-11 18:35:18	8	0	\N	\N
618357	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Renforcement des outils de gestion de la crise sanitaire - Auditions d'Olivier Véran	PJL Renforcement des outils de gestion de la crise sanitaire - Auditions d'Olivier Véran	2022-01-10 14:00:00	2022-01-10 15:40:00	2022-01-17 15:21:38	2022-01-17 15:21:43	68	0	\N	\N
618358	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Renforcement des outils de gestion de la crise sanitaire (rapport et texte)	PJL Renforcement des outils de gestion de la crise sanitaire (rapport et texte)	2022-01-10 16:40:00	2022-01-10 19:15:00	2022-01-10 20:15:52	2022-01-11 14:21:05	39	0	\N	\N
618359	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Renforcement des outils de gestion de la crise sanitaire (amendements)	PJL Renforcement des outils de gestion de la crise sanitaire (amendements)	2022-01-11 16:30:00	2022-01-11 17:10:00	2022-01-11 17:15:59	2022-01-11 18:34:27	33	1	\N	\N
618360	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de Didier Leschi, candidat aux fonctions de directeur général de l'Ofii	Audition de Didier Leschi, candidat aux fonctions de directeur général de l'Ofii	2022-01-12 11:15:00	2022-01-12 12:30:00	2022-01-12 15:00:52	2022-01-13 18:45:25	31	1	\N	\N
618361	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désignations - PPL Port du casque à vélo (amendements)	Désignations - PPL Port du casque à vélo (amendements)	2022-01-12 11:00:00	2022-01-12 11:15:00	2022-01-12 14:48:34	2022-01-13 18:45:24	24	1	\N	\N
618363	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition sur les perspectives pour l'union bancaire et la réglementation prudentielle 	Audition sur les perspectives pour l'union bancaire et la réglementation prudentielle 	2022-01-12 16:35:00	2022-01-12 17:50:00	2022-01-12 20:41:04	2022-01-13 18:45:26	24	0	\N	\N
618364	COM_PERMANENTE	AUTRE	\N	FINC	\N	Programme de contrôle 2022 - Audition niveau de l'inflation	Programme de contrôle 2022 - Audition conjointe niveau de l'inflation	2022-01-12 09:40:00	2022-01-12 12:10:00	2022-01-12 13:31:27	2022-01-13 18:45:27	31	0	\N	\N
618365	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Auditon plénière	\N	2022-01-10 14:00:00	2022-01-10 15:40:00	2022-01-10 16:17:28	2022-01-11 16:49:53	68	0	\N	\N
618366	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-01-10 15:40:00	2022-01-10 16:40:00	2022-01-10 16:53:50	2022-01-11 14:21:03	34	0	\N	\N
618367	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-01-11 16:30:00	2022-01-11 17:15:00	2022-01-11 17:18:46	2022-01-11 18:34:26	29	0	\N	\N
618370	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-01-12 09:05:00	2022-01-12 12:15:00	2022-01-12 12:19:49	2022-01-13 18:45:29	43	0	\N	\N
506221	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLC Liberté d'entreprendre, propriété privée et intérêt général	PPLC Liberté d'entreprendre, propriété privée et intérêt général	2020-11-19 15:00:00	2020-11-19 16:00:00	\N	\N	2	0	\N	\N
506223	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLC Liberté d'entreprendre, propriété privée et intérêt général	\N	2020-11-20 09:00:00	2020-11-20 13:00:00	\N	\N	1	0	\N	\N
506225	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLC Liberté d'entreprendre, propriété privée et intérêt général	PPLC Liberté d'entreprendre, propriété privée et intérêt général	2020-11-20 14:00:00	2020-11-20 15:00:00	\N	\N	1	0	\N	\N
506227	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLC Liberté d'entreprendre, propriété privée et intérêt général	PPLC Liberté d'entreprendre, propriété privée et intérêt général	2020-11-20 16:00:00	2020-11-20 17:00:00	\N	\N	1	0	\N	\N
521610	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Antidopage	Cabinet ministère Sports	2021-01-19 17:00:00	2021-01-19 18:00:00	\N	\N	1	0	\N	\N
521611	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Antidopage	Audition INSEP	2021-01-21 11:00:00	2021-01-21 12:00:00	\N	\N	4	0	\N	\N
524110	COM_PERMANENTE	AUTRE	\N	AFCL	\N	nominations rapporteur & COM audiovisuel public 2020-2022	\N	2021-01-27 09:35:00	2021-01-27 10:55:00	2021-01-27 11:55:59	2021-01-27 15:51:06	36	0	\N	\N
524180	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Diverses mesures de justice sociale	\N	2021-01-21 16:00:00	2021-01-21 16:40:00	\N	\N	1	0	\N	\N
524197	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Santé environnementale - Audition commune DGS/DGPR	\N	2021-01-21 17:00:00	2021-01-21 18:30:00	\N	\N	2	0	\N	\N
524198	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Négociation collective - Audition du comité d'évaluation des ordonnances Travail	\N	2021-01-20 13:00:00	2021-01-20 14:00:00	\N	\N	2	0	\N	\N
524199	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Négociation collective - Audition de M. Paul-Henri Antonmattei	\N	2021-01-20 14:00:00	2021-01-20 15:00:00	\N	\N	2	0	\N	\N
526798	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Transport de marchandises-Union des entreprises de transport et de logistique de France	MI Transport de marchandises-Union des entreprises de transport et de logistique de France	2021-01-26 14:30:00	2021-01-26 15:30:00	\N	\N	8	0	\N	\N
526807	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Transport de marchandises-Auditions plénières	MI Transport de marchandises - OTRE / CNPA	2021-01-26 15:30:00	2021-01-26 17:00:00	\N	\N	6	0	\N	\N
529072	DELEGATION	AUDRAP	\N	\N	206	Audition Production d'hydrogène - Avocates	Audition Production d'hydrogène - Avocates	2021-02-11 15:00:00	2021-02-11 16:00:00	\N	\N	1	0	\N	\N
529074	DELEGATION	AUDRAP	\N	\N	206	Audition Production d'hydrogène - GRTgaz	Audition Production d'hydrogène - GRTgaz	2021-02-11 16:00:00	2021-02-11 17:10:00	\N	\N	1	0	\N	\N
529078	DELEGATION	AUDRAP	\N	\N	206	Audition Production d'hydrogène - DGEC	Audition Production d'hydrogène - DGEC	2021-02-11 17:10:00	2021-02-11 18:20:00	\N	\N	1	0	\N	\N
530780	ETUDES	AUCUNE	\N	\N	\N	Réunion constitutive 	Réunion constitutive groupe TAAF 	2021-02-09 14:00:00	2021-02-09 14:30:00	\N	\N	15	0	\N	938
532313	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Amorce/SFCM	Audition Amorce/SFCM	2021-02-16 10:15:00	2021-02-16 11:00:00	\N	\N	3	0	\N	\N
532640	ETUDES	AUTRE	\N	\N	\N	Réunion constitutive	\N	2021-02-16 17:00:00	2021-02-16 17:35:00	\N	\N	22	0	\N	934
534225	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Désignation membres et rapporteurs groupes de travail Audition de S.E. M. Chakib Benmoussa	Désignation membres et rapporteurs groupes de travail -Audition de S.E. M. Chakib Benmoussa	2021-03-03 09:35:00	2021-03-03 11:30:00	2021-03-17 17:03:44	2021-03-17 17:12:10	35	0	\N	\N
537410	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL directeur d'école	PPL directeur d'école	2021-03-10 22:00:00	2021-03-11 23:15:00	\N	\N	35	0	\N	\N
537413	GIA	AUCUNE	\N	\N	\N	Audition de Rémy BOUALLEGUE	Audition du sous-directeur Asie centrale du MEAE	2021-03-09 15:00:00	2021-03-09 16:00:00	\N	\N	7	0	556	\N
545026	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Audition plénière - Quelle cybersécurité pour les ETI-PME-TPE?	Audition plénière - Quelle cybersécurité pour les ETI-PME-TPE?	2021-03-25 09:00:00	2021-03-25 10:50:00	2021-03-25 11:56:30	\N	11	0	\N	\N
545715	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - Les aides à la presse - ARCEP	Contrôle 2020 - Les aides à la presse - ARCEP	2021-03-29 16:00:00	2021-03-29 16:45:00	\N	\N	1	0	\N	\N
545733	COM_EURO	AUDRAP	\N	AFEU	\N	Révision de la stratégie commerciale de l¿Union européenne	\N	2021-04-01 10:00:00	2021-04-01 11:00:00	\N	\N	0	0	\N	\N
545735	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n° 385 fonds souverains régionaux - Cabinet MINECO/RCT	PPL n° 385 fonds souverains régionaux - Cabinet MINECO/RCT	2021-03-29 13:30:00	2021-03-29 14:30:00	\N	\N	1	0	\N	\N
545737	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PPL Maltraitance animale	\N	2021-03-23 09:30:00	2021-03-23 10:30:00	\N	\N	1	0	\N	\N
545738	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Respect des principes de la République (amendements de séance, suite)	PJL Respect des principes de la République (amendements de séance, suite)	2021-03-30 21:20:00	2021-03-30 21:55:00	2021-03-31 00:04:00	2021-03-31 18:03:12	16	0	\N	\N
545739	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PPL Maltraitance animale	\N	2021-03-23 14:30:00	2021-03-23 15:30:00	\N	\N	1	0	\N	\N
545745	COM_EURO	AUTRE	\N	AFEU	\N	« Erasmus + » : communication	\N	2021-04-08 09:30:00	2021-04-08 10:00:00	2021-04-08 22:16:09	2021-04-09 18:02:25	20	0	\N	\N
545746	COM_PERMANENTE	AUTRE	\N	AFCL	\N	audition commune de Thierry Breton	\N	2021-03-30 15:00:00	2021-03-30 17:00:00	2021-03-30 19:07:58	2021-03-31 18:03:13	57	0	\N	\N
555318	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Dérèglement climatique et résilience - Auditions de M. Pascal Martin	PJL Dérèglement climatique et résilience - Auditions de M. Pascal Martin	2021-04-27 16:45:00	2021-04-27 17:45:00	\N	\N	2	0	\N	\N
555321	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Dérèglement climatique et résilience - Auditions de Mme Marta de Cidrac	PJL Dérèglement climatique et résilience - Auditions de Mme Marta de Cidrac	2021-04-27 14:00:00	2021-04-27 14:45:00	\N	\N	1	0	\N	\N
555323	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Dérèglement climatique et résilience - Auditions de Mme Marta de Cidrac	PJL Dérèglement climatique et résilience - Auditions de Mme Marta de Cidrac	2021-04-27 15:30:00	2021-04-27 18:00:00	\N	\N	2	0	\N	\N
555359	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions PJL DDADUE	\N	2021-04-27 10:00:00	2021-04-27 12:00:00	\N	\N	1	0	\N	\N
555360	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions PJL DDADUE	Auditions PJL DDADUE	2021-04-27 14:00:00	2021-04-27 17:00:00	\N	\N	1	0	\N	\N
555361	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions PJL DDADUE	Auditions PJL DDADUE	2021-04-28 09:30:00	2021-04-28 12:30:00	\N	\N	1	0	\N	\N
555362	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions PJL DDADUE	Auditions PJL DDADUE	2021-04-28 16:30:00	2021-04-28 18:30:00	\N	\N	1	0	\N	\N
555367	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Assistants maternels et salariés des particuliers employeurs	\N	2021-05-11 17:30:00	2021-05-11 18:25:00	\N	\N	2	0	\N	\N
555371	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Renforcer la prévention en santé au travail - Audition organisations syndicales	\N	2021-05-18 14:00:00	2021-05-18 15:50:00	\N	\N	3	0	\N	\N
555372	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Renforcer la prévention en santé au travail - Audition DGT 	\N	2021-05-18 15:50:00	2021-05-18 16:50:00	\N	\N	2	0	\N	\N
555373	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Renforcer la prévention en santé au travail - Audition IGAS 	\N	2021-05-18 16:50:00	2021-05-18 17:40:00	\N	\N	2	0	\N	\N
555374	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions PJL DDADUE	\N	2021-04-29 10:00:00	2021-04-29 11:00:00	\N	\N	1	0	\N	\N
555376	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Dérèglement climatique et résilience - Auditions de Mme Marta de Cidrac	PJL Dérèglement climatique et résilience - Auditions de Mme Marta de Cidrac	2021-04-28 09:15:00	2021-04-28 11:30:00	\N	\N	1	0	\N	\N
555378	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Dérèglement climatique et résilience - Auditions de M. Pascal Martin	\N	2021-04-28 16:00:00	2021-04-28 17:00:00	\N	\N	2	0	\N	\N
600213	COM_PERMANENTE	AUTRE	\N	CAE	\N	Examen du rapport pour avis 	\N	2021-11-10 11:00:00	2021-11-10 11:30:00	2021-11-10 11:45:48	2021-11-12 19:00:40	40	1	\N	\N
555469	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Dérèglement climatique et résilience - Auditions de M. Philippe Tabarot	PJL Dérèglement climatique et résilience - Auditions de M. Philippe Tabarot	2021-04-29 16:45:00	2021-04-29 17:30:00	\N	\N	2	0	\N	\N
555470	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PJL Dérèglement climatique et résilience - Auditions de M. Philippe Tabarot	PJL Dérèglement climatique et résilience - Auditions de M. Philippe Tabarot	2021-04-29 17:30:00	2021-04-29 18:30:00	\N	\N	2	0	\N	\N
598001	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition PJL Alsace	Audition PJL Alsace	2021-10-26 17:00:00	2021-10-26 18:00:00	\N	\N	2	0	\N	\N
598005	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de M. François Delattre	Audition de M. François Delattre	2021-11-03 09:30:00	2021-11-03 11:05:00	2021-11-03 17:12:56	2021-11-04 16:07:15	34	0	\N	\N
598014	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2022 : Rapports Mission « Sécurités »	PLF pour 2022 : Rapports Mission « Sécurités »	2021-11-02 09:05:00	2021-11-02 10:25:00	2021-11-02 13:10:05	2021-11-02 17:22:57	19	0	\N	\N
598017	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLFSS pour 2022:Rapport Avis - PLF pour 2022:Missions «Santé»« Solidarité»«RSR»«EFE»et«PP»	PLFSS pour 2022:Rapport Avis - PLF pour 2022:Missions «Santé»« Solidarité»«RSR»«EFE»et«PP»	2021-11-02 14:30:00	2021-11-02 17:45:00	2021-11-02 19:21:17	2021-11-03 16:47:21	33	0	\N	\N
598024	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLFR pour 2021 (2) : Audition de M. Olivier DUSSOPT, ministre	PLFR pour 2021 (2) : Audition de M. Olivier DUSSOPT, ministre	2021-11-03 16:50:00	2021-11-03 18:15:00	2021-11-03 18:32:05	2021-11-04 16:07:14	26	0	\N	\N
598043	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Radio France	Audition de Mme Veil	2021-10-28 11:00:00	2021-10-28 12:30:00	\N	\N	2	0	\N	\N
598059	DELEGATION	AUCUNE	\N	\N	206	Audition de Xavier Piechaczyk, président de RTE	\N	2021-10-28 14:10:00	2021-10-28 16:05:00	\N	\N	8	0	\N	\N
598095	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Tourisme	GT Tourisme	2021-10-27 13:30:00	2021-10-27 15:00:00	\N	\N	7	0	\N	\N
598103	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Logement	\N	2021-10-27 17:00:00	2021-10-27 17:30:00	\N	\N	2	0	\N	\N
598106	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2022	PJLF 2022	2021-10-27 17:30:00	2021-10-27 18:00:00	\N	\N	2	0	\N	\N
598111	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJLF 2022	PJLF 2022	2021-10-27 18:00:00	2021-10-27 18:30:00	\N	\N	1	0	\N	\N
598114	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PJLF 2022 - Politique de la Ville - Mme Artigalas	\N	2021-10-28 09:30:00	2021-10-28 11:30:00	\N	\N	1	0	\N	\N
598117	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition article 13 CNR	\N	2021-11-03 09:30:00	2021-11-03 10:50:00	2021-11-03 16:05:37	2021-11-03 16:47:36	37	0	\N	\N
598119	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2022 - Administration pénitentiaire - CGLPL	\N	2021-10-27 16:30:00	2021-10-27 17:15:00	\N	\N	1	0	\N	\N
598121	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition 	\N	2021-10-27 16:30:00	2021-10-27 18:00:00	\N	\N	0	0	\N	\N
598123	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2022 - Administration pénitentiaire - UFAP UNSa Justice	\N	2021-10-27 17:15:00	2021-10-27 18:00:00	\N	\N	1	0	\N	\N
598207	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2022 - AGTE - DMAT 	PLF pour 2022 - AGTE - DMAT	2021-10-26 17:00:00	2021-10-26 18:30:00	\N	\N	1	0	\N	\N
598224	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition IN Groupe - AGTE PLF 2022	\N	2021-10-26 15:30:00	2021-10-26 16:45:00	\N	\N	1	0	\N	\N
598371	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI répartition des moyens alloués à la création	\N	2021-10-01 09:30:00	2021-10-01 11:00:00	\N	\N	2	0	\N	\N
598406	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	GT Pass culture	\N	2021-10-13 17:30:00	2021-10-13 18:30:00	\N	\N	5	0	\N	\N
598412	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	GT Pass culture	\N	2021-10-13 18:30:00	2021-10-13 19:30:00	\N	\N	4	0	\N	\N
598440	COM_PERMANENTE	DEPLACEMENT	\N	AFCL	\N	plf recherche	Déplacement à l'Institut Pasteur	2021-10-22 11:00:00	2021-10-22 12:00:00	\N	\N	1	0	\N	\N
598442	COM_PERMANENTE	DEPLACEMENT	\N	AFCL	\N	plf recherche	\N	2021-10-22 14:30:00	2021-10-22 16:00:00	\N	\N	1	0	\N	\N
598535	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	plf 2022 enssco	\N	2021-10-15 17:15:00	2021-10-15 18:00:00	\N	\N	2	0	\N	\N
598804	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Écologie - DGALN	PLF pour 2022 - Écologie - DGALN	2021-10-26 13:30:00	2021-10-26 14:30:00	\N	\N	1	0	\N	\N
598806	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Écologie - ADEME	PLF pour 2022 - Écologie - ADEME	2021-10-26 17:45:00	2021-10-26 18:45:00	\N	\N	1	0	\N	\N
599208	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur - PLF mission "Solidarité"	\N	2021-11-02 14:00:00	2021-11-02 14:45:00	\N	\N	1	0	\N	\N
599210	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur - PLF mission "Solidarité"	\N	2021-11-02 15:00:00	2021-11-02 16:15:00	\N	\N	3	0	\N	\N
599246	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur - PLF mission "Solidarité"	\N	2021-11-02 16:30:00	2021-11-02 17:30:00	\N	\N	3	0	\N	\N
599252	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur - PLF mission "Solidarité"	\N	2021-11-03 14:00:00	2021-11-03 14:45:00	\N	\N	1	0	\N	\N
600188	DELEGATION	AUDRAP	\N	\N	206	Audition de rappporteur	\N	2021-11-03 15:00:00	2021-11-03 16:20:00	\N	\N	1	0	\N	\N
600195	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2022 - Administration pénitentiaire 	\N	2021-11-02 15:00:00	2021-11-02 18:00:00	\N	\N	1	0	\N	\N
600200	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2022 - Syndicats de directeurs des services pénitentiaires  	\N	2021-11-03 14:00:00	2021-11-03 15:00:00	\N	\N	1	0	\N	\N
600206	COM_EURO	AUTRE	\N	AFEU	\N	réunion du 10 novembre 2021	\N	2021-11-10 13:35:00	2021-11-10 14:50:00	2021-11-10 15:04:35	2021-11-12 19:01:04	20	0	\N	\N
600207	COM_EURO	AUTRE	\N	AFEU	\N	Union européenne et la santé, à la suite de la pandémie de COVID-19 - Autre	\N	2021-11-10 12:30:00	2021-11-10 13:15:00	\N	\N	0	0	\N	\N
600209	COM_EURO	AUTRE	\N	AFEU	\N	Auditions de la commission des affaires européennes - Audition plénière	\N	2021-11-10 16:30:00	2021-11-10 17:45:00	2021-11-12 09:16:08	2021-11-12 19:01:05	10	0	\N	\N
600211	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition Mme Emmanuelle Wargon	\N	2021-11-09 17:30:00	2021-11-09 18:40:00	2021-11-09 18:54:20	2021-11-12 19:00:45	35	0	\N	\N
600212	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition Jean-Bernard Levy 	\N	2021-11-10 09:05:00	2021-11-10 11:00:00	2021-11-10 11:44:49	2021-11-12 19:00:42	40	1	\N	\N
661758	GIA	AUCUNE	\N	\N	\N	Réunion du groupe d'amitié	\N	2022-10-12 08:30:00	2022-10-12 09:45:00	\N	\N	9	0	622	\N
598004	COM_PERMANENTE	AUTRE	\N	ETRD	\N	PJLF pour 2022 - P. 844 et 847 "Avances à l'audiovisuel public"	PLJL pour 2022 - P. 844 et 847 	2021-11-03 11:10:00	2021-11-03 11:40:00	2021-11-03 17:17:50	2021-11-04 16:07:14	34	3	\N	\N
598018	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2022 : Tome I du RG - Missions « GFP »« TFP »« CNR »et« Justice »	PLF pour 2022 : Tome I du RG - Missions « GFP »« TFP »« CNR »et« Justice »	2021-11-03 09:00:00	2021-11-03 12:25:00	2021-11-03 18:52:12	2021-11-04 16:07:17	43	0	\N	\N
600232	GIA	AUCUNE	\N	\N	\N	réunion	échange avec Mme Ioula Shukan, enseignante-chercheuse au département d'études slaves (Université de Nanterre) 	2021-11-03 01:04:00	2021-11-03 15:00:00	\N	\N	4	0	852	\N
600376	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2022 - Programme 212	\N	2021-11-02 17:00:00	2021-11-02 18:00:00	\N	\N	2	0	\N	\N
600487	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Octavio Ferreira Chargé d¿affaires a.i. Ambassade du Paraguay en France	Entretien avec M. Octavio Ferreira Chargé d¿affaires a.i. Ambassade du Paraguay en France	2021-11-04 12:30:00	2021-11-04 14:00:00	\N	\N	2	0	978	\N
600607	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF 2022 - Avis Transition écologique - Audition par M. François Calvet	PLF 2022 - Avis Transition écologique - ATMO France - Audition par M. François Calvet	2021-10-26 15:30:00	2021-10-26 16:30:00	\N	\N	1	0	\N	\N
600608	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF 2022 - Avis Transition écologique - Audition par M. François Calvet	PLF 2022 - Avis Transition écologique - Syndicat des énergies renouvelables - Audition par M. François Calvet	2021-10-28 09:30:00	2021-10-28 10:30:00	\N	\N	1	0	\N	\N
600609	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF 2022 - Avis Transition écologique - Audition par M. François Calvet	PLF 2022 - Avis Transition écologique - METS DG de l'énergie et du climat - Audition par M. François Calvet	2021-10-28 14:00:00	2021-10-28 15:00:00	\N	\N	1	0	\N	\N
600610	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF 2022 - Avis Transition écologique - Audition par M. François Calvet	\N	2021-11-04 09:00:00	2021-11-04 10:00:00	\N	\N	1	0	\N	\N
600636	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désignations - Audition d'Eric Dupond-Moretti (PLF 2022)	Désignations - Audition d'Eric Dupond-Moretti (PLF 2022)	2021-11-09 17:00:00	2021-11-09 18:30:00	2021-11-09 19:50:58	2021-11-12 19:00:47	24	0	\N	\N
600637	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de Jacqueline Gourault et Joël Giraud (PLF 2022)	Audition de Jacqueline Gourault et Joël Giraud (PLF 2022)	2021-11-09 18:40:00	2021-11-09 19:25:00	2021-11-12 19:27:06	2021-11-15 15:22:13	22	0	\N	\N
600643	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2021-11-04 09:00:00	2021-11-04 12:15:00	\N	\N	3	0	\N	\N
600647	COM_EURO	AUDRAP	\N	AFEU	\N	Subventions étrangères	Subventions étrangères - Direction des achats de l'Etat	2021-11-02 19:15:00	2021-11-02 20:05:00	\N	\N	1	0	\N	\N
600684	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Mi bilan mesures éducatives	\N	2021-11-02 15:00:00	2021-11-02 16:00:00	\N	\N	4	0	\N	\N
505830	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF  pour 2021 - Programme 185	\N	2020-11-17 17:00:00	2020-11-17 18:00:00	\N	\N	2	0	\N	\N
505975	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition ambassadrice d'Arménie en France	\N	2020-11-24 15:00:00	2020-11-24 16:30:00	2020-11-25 13:54:56	2020-11-25 15:01:08	34	0	\N	\N
505976	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition ambassadeur d'Azerbaidjan en France	\N	2020-11-24 16:45:00	2020-11-24 18:20:00	2020-11-25 13:57:01	2020-11-25 15:01:19	33	0	\N	\N
506005	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Examen de 5 avis budgétaires et un rapport d'information	\N	2020-11-25 09:15:00	2020-11-25 11:00:00	2020-11-25 14:33:48	2020-11-25 15:03:09	30	0	\N	\N
506012	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Assemblée de Guyane	Audition rapporteur - PPL Assemblée de Guyane	2020-11-17 16:00:00	2020-11-17 16:30:00	\N	\N	1	0	\N	\N
506014	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Assemblée de Guyane	Audition rapporteur - PPL Assemblée de Guyane	2020-11-18 18:15:00	2020-11-18 19:00:00	\N	\N	1	0	\N	\N
506016	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Assemblée de Guyane	Audition rapporteur - PPL Assemblée de Guyane	2020-11-19 09:45:00	2020-11-19 10:20:00	\N	\N	2	0	\N	\N
506019	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Assemblée de Guyane	Audition rapporteur - PPL Assemblée de Guyane	2020-11-19 15:00:00	2020-11-19 15:15:00	\N	\N	1	0	\N	\N
514892	GIA	AUCUNE	\N	\N	\N	AG France-Tunisie	Assemblée générale France-Tunisie	2020-12-08 13:45:00	2020-12-08 14:30:00	\N	\N	8	0	620	\N
519147	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Protéger les jeunes mineurs des crimes sexuels	\N	2021-01-05 11:00:00	2021-01-05 12:30:00	\N	\N	1	0	\N	\N
519149	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Protéger les jeunes mineurs des crimes sexuels	\N	2021-01-05 14:45:00	2021-01-05 16:15:00	\N	\N	2	0	\N	\N
522147	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2021-01-20 08:35:00	2021-01-20 09:15:00	2021-01-20 09:26:22	2021-01-20 12:10:32	35	0	\N	\N
523221	GIA	AUCUNE	\N	\N	\N	Entretien avec l'Ambassadeur d'Allemagne	Entretien avec S. Exc. M; Hans-Dieter Lucas, Ambassadeur d'Allemagne	2021-01-20 13:45:00	2021-01-20 14:45:00	\N	\N	19	0	604	\N
527439	ETUDES	AUCUNE	\N	\N	\N	Audition M. Charmasson	Audition M. Charmasson	2021-02-03 08:15:00	2021-02-03 09:15:00	\N	\N	21	0	\N	948
527925	ETUDES	AUCUNE	\N	\N	\N	Réunion constitutive GE Agriculture et alimentation	Réunion constitutive GE Agriculture et alimentation	2021-02-03 14:00:00	2021-02-03 15:00:00	\N	\N	62	0	\N	919
531098	DELEGATION	AUCUNE	\N	\N	COLTER	 Audition A. Lambert, président du CNEN ; Audition B. Faure, professeur droit public	\N	2021-02-18 09:00:00	2021-02-18 11:30:00	\N	\N	22	0	\N	\N
536548	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition continuité écologique des cours d'eau	\N	2021-03-03 16:00:00	2021-03-03 18:30:00	\N	\N	9	0	\N	\N
536572	ETUDES	AUTRE	\N	\N	\N	Audition plénière	\N	2021-03-17 13:45:00	2021-03-17 14:45:00	\N	\N	9	0	\N	966
536583	DELEGATION	AUCUNE	\N	\N	211	Audition de Mmes Simone Saillant et Sylviane Le Guyader (ANCT)	Audition de Mmes Simone Saillant et Sylviane Le Guyader (ANCT)	2021-03-11 09:00:00	2021-03-11 10:00:00	2021-03-11 10:35:01	\N	16	0	\N	\N
536584	DELEGATION	AUDRAP	\N	\N	PROS	Audition de l'INSERM	Audition de l'INSERM	2021-03-22 14:30:00	2021-03-22 15:30:00	\N	\N	3	0	\N	\N
536590	MISSION	AUCUNE	\N	ENSAGRIC	\N	MI Enseignement agricole - Audition plénière	\N	2021-03-09 16:39:00	2021-03-09 18:50:00	2021-03-09 18:59:31	2021-03-11 18:52:24	18	0	\N	\N
536607	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition Robert OPHÈLE PDT AMF - Audition 58-2 Application art 55 loi SRU et désignations 	Audition Robert OPHÈLE PDT AMF - Audition 58-2 Application art 55 loi SRU et désignations rapporteurs	2021-03-10 09:05:00	2021-03-10 12:35:00	2021-03-10 16:09:28	2021-03-10 17:11:58	41	0	\N	\N
536608	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Droit au respect de la dignité en détention (amendements de séance)	PPL Droit au respect de la dignité en détention (amendements de séance)	2021-03-08 15:30:00	2021-03-08 15:40:00	2021-03-08 15:52:07	2021-03-08 16:35:41	6	0	\N	\N
536609	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Examen du rapport d'information sur l'expertise psychiatrique en matière pénale	Examen du rapport d'information sur l'expertise psychiatrique en matière pénale	2021-03-10 09:05:00	2021-03-10 09:50:00	2021-03-10 11:18:19	2021-03-10 17:11:58	54	0	\N	\N
536611	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Service public d'eau potable et d'assainissement en Guadeloupe (amendements de séance)	PPL Service public d'eau potable et d'assainissement en Guadeloupe (amendements de séance)	2021-03-10 10:00:00	2021-03-10 10:05:00	2021-03-10 11:18:30	2021-03-10 17:12:02	20	0	\N	\N
536613	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Respect des principes de la République - Audition de J.-L. Bianco et N. Cadène	PJL Respect des principes de la République - Audition de J.-L. Bianco et N. Cadène	2021-03-10 11:00:00	2021-03-10 12:15:00	2021-03-10 12:28:02	2021-03-10 17:12:04	25	0	\N	\N
536614	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Respect des principes de la République - Audition d'Hakim El Karoui	PJL Respect des principes de la République - Audition d'Hakim El Karoui	2021-03-10 12:15:00	2021-03-10 13:20:00	2021-03-10 13:40:24	2021-03-10 17:12:06	20	0	\N	\N
536615	MISSION	AUDRAP	\N	PAUP	\N	Audition rapporteur	\N	2021-03-04 10:30:00	2021-03-04 11:30:00	\N	\N	5	0	\N	\N
557916	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 -  Enseignants matières scientifiques-Plan Mathématiques/DGRH Éduc Nationale	Contrôle 2021 -  Enseignants matières scientifiques - Plan Mathématiques/DGRH Éducation Nationale	2021-05-06 15:00:00	2021-05-06 18:00:00	\N	\N	1	0	\N	\N
562260	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Protection sociale globale - Audition ADF	\N	2021-05-20 14:30:00	2021-05-20 15:30:00	\N	\N	2	0	\N	\N
566141	GIA	AUCUNE	\N	\N	\N	Déjeuner ambassade	Déjeuner à l'ambassade d'Afghanistan	2021-06-30 12:30:00	2021-06-30 14:00:00	\N	\N	3	0	648	\N
566368	MISSION	AUCUNE	\N	HARCEL	\N	Réunion du 3 juin 2021	Réunion du 3 juin 2021 (associations)	2021-06-03 10:40:00	2021-06-03 12:40:00	2021-06-03 17:37:56	2021-06-04 17:57:19	10	0	\N	\N
566382	CONF_PRES	AUCUNE	\N	\N	\N	Conf Prés	Conférence des Présidents	2021-06-02 14:15:00	2021-06-02 14:40:00	\N	\N	23	0	\N	\N
566883	DELEGATION	AUDRAP	\N	\N	206	Mme Muriel DAHAN, pilote du prochain CSIS	Mme Muriel DAHAN, inspectrice générale des Affaires sociales, pilote du prochain Conseil stratégique des industries de s	2021-06-08 17:00:00	2021-06-08 18:00:00	\N	\N	5	0	\N	\N
568565	GIA	AUCUNE	\N	\N	\N	Rencontre avec le Président du groupe d'amitié Pologne-France du Sénat polonais	Rencontre avec le Président du groupe d'amitié Pologne-France du Sénat polonais	2021-06-10 14:00:00	2021-06-10 15:00:00	\N	\N	1	0	600	\N
568567	GIA	AUCUNE	\N	\N	\N	Réunion du groupe d'amitié France-Pologne	Réunion du groupe d'amitié France-Pologne	2021-06-10 15:00:00	2021-06-10 16:30:00	\N	\N	4	0	600	\N
571534	MISSION	AUCUNE	\N	UBER	\N	Constitution de la MI Ubérisation	\N	2021-06-22 14:30:00	2021-06-22 15:10:00	2021-06-22 17:50:41	2021-06-24 18:16:48	11	0	\N	\N
571535	MISSION	AUCUNE	\N	UBER	\N	Audition de M. Bruno Mettling	\N	2021-06-22 15:40:00	2021-06-22 16:50:00	2021-06-22 18:07:15	2021-06-24 18:16:48	4	0	\N	\N
575106	COM_PERMANENTE	AUTRE	\N	LOIS	\N	MI Sécurité d'acheminement des communications d'urgence - Audition de Didier Vidal	MI Sécurité d'acheminement des communications d'urgence - Audition de Didier Vidal	2021-07-06 18:30:00	2021-07-06 19:35:00	2021-07-06 21:15:42	2021-07-07 17:53:01	14	0	\N	\N
591017	DELEGATION	AUDRAP	\N	\N	COLTER	Audition de Mme DELAMARCHE - DGCL	\N	2021-10-19 14:00:00	2021-10-19 15:00:00	\N	\N	0	0	\N	\N
591132	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition Cadot (ANS) - PPl directeur école - PPL gel matchs football	\N	2021-10-13 09:30:00	2021-10-13 12:20:00	\N	\N	37	0	\N	\N
613320	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion pleinière CATDD	\N	2021-12-15 09:00:00	2021-12-15 09:30:00	2021-12-16 17:14:47	2021-12-17 16:11:56	99	1	\N	\N
613321	COM_EURO	AUDRAP	\N	AFEU	\N	Auditions à l'objectif 55	Auditions à l'objectif 55	2021-12-03 09:15:00	2021-12-03 15:00:00	\N	\N	2	0	\N	\N
613325	COM_EURO	DEPLACEMENT	\N	AFEU	\N	Auditions - Ajustement à l'objectif 55	Auditions - Ajustement à l'objectif 55	2021-12-02 19:00:00	2021-12-03 17:00:00	\N	\N	2	0	\N	\N
613326	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Harcèlement scolaire	\N	2021-12-14 14:30:00	2021-12-14 15:15:00	\N	\N	0	0	\N	\N
613327	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Harcèlement scolaire	\N	2021-12-14 15:15:00	2021-12-14 16:00:00	\N	\N	0	0	\N	\N
613455	COM_ENQUETE	AUTRE	\N	MEDIA	\N	audition E. Combes Autorité Concurrence	\N	2021-12-15 17:00:00	2021-12-15 18:00:00	2021-12-15 18:54:59	2021-12-16 17:04:33	10	0	\N	\N
615617	ETUDES	AUTRE	\N	\N	\N	Audition RTE	Audition RTE	2021-12-15 13:30:00	2021-12-15 15:00:00	\N	\N	11	0	\N	906
615634	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Audition de M. Belin - FNSCMF	\N	2021-12-14 15:10:00	2021-12-14 16:00:00	\N	\N	0	0	\N	\N
615646	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Rapporteur - M. Christian Ehler, eurodéputé	\N	2021-12-06 17:00:00	2021-12-06 18:00:00	\N	\N	2	0	\N	\N
615651	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur - JF Hébert, DG Patrimoine Ministère de la culture	Audition rapporteur - JF Hébert, DG Patrimoine Ministère de la culture	2021-12-14 18:00:00	2021-12-14 19:00:00	\N	\N	2	0	\N	\N
615652	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Audition M. Belin	\N	2021-12-14 15:10:00	2021-12-14 17:30:00	\N	\N	0	0	\N	\N
615658	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteurs culture - Jean d'Haussonville, DG Domaine Public de Chambord	\N	2021-12-15 16:30:00	2021-12-15 17:30:00	\N	\N	2	0	\N	\N
615953	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière	\N	2021-12-15 08:30:00	2021-12-15 09:30:00	2021-12-16 11:42:47	\N	21	0	\N	\N
615981	COM_ENQUETE	AUDRAP	\N	CABINETS	\N	Secrétariat généraux de ministères	Secrétariats généraux Ministères chargés des affaires sociales et de l'intérieur	2021-12-16 09:15:00	2021-12-16 11:35:00	\N	\N	4	0	\N	\N
616061	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Protection des épargnants - ACPR	Contrôle 2021 - Protection des épargnants - ACPR	2021-12-14 17:00:00	2021-12-14 18:00:00	\N	\N	2	0	\N	\N
616176	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Associations environnementales de Sologne	Associations environnementales de Sologne	2021-12-15 16:30:00	2021-12-15 17:30:00	\N	\N	3	0	\N	\N
616177	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Fransylva et Association protection propriété privée Centre Val-de-Loire	Fransylva et Association protection propriété privée Centre Val-de-Loire	2021-12-15 17:30:00	2021-12-15 18:15:00	\N	\N	4	0	\N	\N
616178	COM_PERMANENTE	AUDRAP	\N	CAE	\N	One Voice et Association pour la protection des animaux sauvages	One Voice et Association pour la protection des animaux sauvages	2021-12-15 18:15:00	2021-12-15 19:00:00	\N	\N	3	0	\N	\N
616179	COM_PERMANENTE	AUDRAP	\N	CAE	\N	M. Bastien LACHAUD, député	M. Bastien LACHAUD, député	2021-12-15 19:00:00	2021-12-15 19:30:00	\N	\N	2	0	\N	\N
616180	COM_PERMANENTE	AUDRAP	\N	CAE	\N	M. Nicolas VANIER	M. Nicolas VANIER	2021-12-15 19:45:00	2021-12-15 20:15:00	\N	\N	2	0	\N	\N
616181	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Fédération nationale des chasseurs	Fédération nationale des chasseurs	2021-12-14 16:30:00	2021-12-14 17:15:00	\N	\N	3	0	\N	\N
616182	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Fédération nationale des chasses professionnelles	Fédération nationale des chasses professionnelles	2021-12-14 17:15:00	2021-12-14 18:00:00	\N	\N	4	0	\N	\N
616183	COM_PERMANENTE	AUDRAP	\N	CAE	\N	OFB	OFB	2021-12-14 18:00:00	2021-12-14 18:45:00	\N	\N	4	0	\N	\N
536944	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition CRE	Audition CRE	2021-03-02 15:30:00	2021-03-02 16:30:00	\N	\N	5	0	\N	\N
616184	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Mme ABBA, secrétaire d'État à la biodiversité et des représentants de la DGALN	Mme ABBA, secrétaire d'État à la biodiversité et des représentants de la DGALN	2021-12-16 11:30:00	2021-12-16 12:15:00	\N	\N	3	0	\N	\N
616236	DELEGATION	AUCUNE	\N	\N	211	Table ronde de chercheurs et de juristes sur la production de contenus pornographiques	Table ronde de chercheurs et de juristes sur la production de contenus pornographiques	2022-02-03 08:30:00	2022-02-03 10:45:00	2022-02-03 10:54:54	\N	13	0	\N	\N
618410	COM_ENQUETE	AUDRAP	\N	CABINETS	\N	SG Ministères économiques et financiers - DGPN - DG ANAP	SG Ministères économiques et financiers - DGPN - DG ANAP	2022-01-11 15:30:00	2022-01-11 18:35:00	\N	\N	6	0	\N	\N
618412	COM_ENQUETE	PLENIERE	\N	CABINETS	\N	Audition Plénière - Directeur général de l'ANSSI	Audition Plénière - Directeur général de l'ANSSI	2022-01-12 16:30:00	2022-01-12 17:55:00	2022-01-12 18:34:59	2022-01-13 18:48:10	10	0	\N	\N
619638	COM_PERMANENTE	AUTRE	\N	AFCL	\N	comminication - -proposition de législation européenne sur les services numériques (DSA)	\N	2022-01-12 09:33:00	2022-01-12 10:56:00	2022-01-12 11:35:05	2022-01-13 18:45:27	32	0	\N	\N
619707	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Paquet Climat - Objectif 55 - Volet Energie	Audition Paquet Climat - Objectif 55 - Volet Energie - SGAE	2022-01-11 17:15:00	2022-01-11 18:15:00	\N	\N	5	0	\N	\N
620189	COM_PERMANENTE	AUTRE	\N	AFCL	\N	audition M. Zivie	\N	2022-01-19 09:30:00	2022-01-19 11:00:00	2022-01-25 08:34:38	2022-01-25 18:13:12	33	0	\N	\N
620193	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-01-19 09:05:00	2022-01-19 12:10:00	2022-01-25 14:07:14	2022-01-25 18:13:13	42	0	\N	\N
623393	GIA	AUCUNE	\N	\N	\N	Entretien avec Mme Raja RABIA, Ambassadrice de France au Soudan	Entretien avec Mme Raja RABIA, Ambassadrice de France au Soudan	2022-01-19 16:00:00	2022-01-19 17:05:00	\N	\N	6	0	588	\N
625147	ETUDES	AUTRE	\N	\N	\N	Table ronde consacrée à la TVA applicable aux équidés	Table ronde consacrée à la TVA applicable aux équidés	2022-01-26 08:00:00	2022-01-26 09:30:00	\N	\N	4	0	\N	912
625476	MISSION	AUDRAP	\N	CULTURE	\N	Audition du Réseau de la participation enfance jeunesse	\N	2022-01-26 13:30:00	2022-01-26 14:45:00	\N	\N	5	0	\N	\N
625488	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2022-01-26 15:00:00	2022-01-26 16:20:00	\N	\N	254	0	\N	\N
625792	COM_EURO	AUDRAP	\N	AFEU	\N	Paquet Climat - Volet Transports	Paquet Climat - Volet Transports - M. Briand	2022-01-27 14:30:00	2022-01-27 15:30:00	\N	\N	3	0	\N	\N
625811	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Auditions Mme Patricia Demas	\N	2022-01-25 14:30:00	2022-01-25 18:30:00	\N	\N	0	0	\N	\N
625812	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Auditions Pyrénées Atlantiques	\N	2022-01-25 15:30:00	2022-01-25 16:30:00	\N	\N	0	0	\N	\N
625813	COM_EURO	AUDRAP	\N	AFEU	\N	Paquet climat - Volet transports - DG Move	Paquet climat - Volet transports	2022-02-08 14:00:00	2022-02-08 15:15:00	\N	\N	4	0	\N	\N
625816	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PPL Aménagement Rhône	Auditions PPL Aménagement Rhône	2022-01-13 09:30:00	2022-01-13 11:00:00	\N	\N	1	0	\N	\N
625818	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Audition Hub Antilles Guyane	\N	2022-01-25 17:30:00	2022-01-25 18:30:00	\N	\N	0	0	\N	\N
625821	COM_EURO	AUDRAP	\N	AFEU	\N	Paquet climat - Volet Transports - DGITM	Paquet climat - Volet Transports	2022-02-08 17:00:00	2022-02-08 18:00:00	\N	\N	3	0	\N	\N
625846	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Auditions Mmes Filleul et Herzog	\N	2022-01-25 14:30:00	2022-01-25 16:45:00	\N	\N	0	0	\N	\N
626151	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PPL Aménagement du Rhône	Audition PPL Aménagement du Rhône	2022-01-18 14:30:00	2022-01-18 16:00:00	\N	\N	2	0	\N	\N
626152	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Innovation en santé - Table ronde des acteurs de l'innovation	\N	2022-01-26 13:30:00	2022-01-26 15:10:00	\N	\N	4	0	\N	\N
626182	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PPL Aménagement du Rhône	Audition PPL Aménagement du Rhône	2022-01-19 11:15:00	2022-01-19 12:00:00	\N	\N	2	0	\N	\N
505490	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2021 - Avis fonction publique	PLF pour 2021 - Avis fonction publique	2020-11-17 14:00:00	2020-11-17 15:00:00	\N	\N	1	0	\N	\N
506062	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2021 - Programme 105	\N	2020-11-17 17:00:00	2020-11-17 19:30:00	\N	\N	2	0	\N	\N
506065	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2021 - Programme 178	\N	2020-11-17 13:00:00	2020-11-17 15:00:00	\N	\N	2	0	\N	\N
508794	DELEGATION	AUCUNE	\N	\N	COLTER	Audition de M. Martial Foucault, directeur CEVIPOF ; Audition de M. Frédéric Veaux, DGPN	\N	2020-12-03 09:00:00	2020-12-03 11:30:00	2020-12-03 15:52:25	\N	23	0	\N	\N
510568	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	CS Veolia	CS vEOLIA	2020-11-23 10:00:00	2020-11-23 11:00:00	\N	\N	0	0	\N	\N
510805	GIA	AUCUNE	\N	\N	\N	Réception du Nonce à Paris	Audition du Nonce apostolique, Mgr Celestino Migliore	2020-12-16 13:30:00	2020-12-16 14:45:00	\N	\N	13	0	629	\N
517008	GIA	AUCUNE	\N	\N	\N	AG reconstitutive du bureau du groupe France-Roumanie	AG reconstitutive du bureau du groupe France-Roumanie	2020-12-15 09:45:00	2020-12-15 10:30:00	\N	\N	4	0	605	\N
520334	DELEGATION	AUDRAP	\N	\N	206	Audition Stratégie vaccinale - Santé Publique France	Audition Stratégie vaccinale - Santé Publique France	2021-01-14 11:00:00	2021-01-14 12:00:00	\N	\N	4	0	\N	\N
526434	GIA	AUCUNE	\N	\N	\N	Assemblée générale	Assemblée générale	2021-01-27 14:00:00	2021-01-27 14:30:00	\N	\N	6	0	644	\N
526456	GIA	AUCUNE	\N	\N	\N	AG constitutive	Assemblée générale - réunion constitutive	2021-01-19 14:00:00	2021-01-19 14:35:00	\N	\N	9	0	663	\N
536939	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition Engie / SHEM	Audition Engie / SHEM	2021-03-02 09:45:00	2021-03-02 10:30:00	\N	\N	4	0	\N	\N
536950	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition EDF	Audition EDF	2021-03-02 16:30:00	2021-03-02 17:15:00	\N	\N	5	0	\N	\N
536956	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition Anode-AFIEG	Audition Anode-AFIEG	2021-03-02 17:15:00	2021-03-02 18:15:00	\N	\N	4	0	\N	\N
536961	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition CNR	Audition CNR	2021-03-02 18:15:00	2021-03-02 19:00:00	\N	\N	2	0	\N	\N
539170	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Cybersécurité	\N	2021-03-10 16:15:00	2021-03-10 17:30:00	\N	\N	2	0	\N	\N
543065	DELEGATION	AUDRAP	\N	\N	211	Audition de Coordination Sud	Audition de Coordination Sud	2021-03-22 10:00:00	2021-03-22 11:00:00	\N	\N	1	0	\N	\N
543067	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	Commission d'Aputration des Comptes	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne 	2021-03-17 16:30:00	2021-03-17 18:00:00	2021-03-22 17:56:40	\N	8	0	\N	\N
544058	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2021-03-18 09:10:00	2021-03-18 11:05:00	\N	\N	3	0	\N	\N
551528	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - Les aides à la presse - Cour des comptes	Contrôle 2020 - Les aides à la presse - Cour des comptes	2021-04-09 15:30:00	2021-04-09 16:15:00	\N	\N	1	0	\N	\N
551530	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 2020 - Couverture mobile - Cour des comptes	58-2 2020 - Couverture mobile - Cour des comptes	2021-04-06 11:30:00	2021-04-06 12:30:00	\N	\N	1	0	\N	\N
551532	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - Direction générale du Trésor - SG DG Trésor/Inspection DG Trésor	Contrôle 2020 - Direction générale du Trésor - SG DG Trésor/Inspection DG Trésor	2021-04-06 13:30:00	2021-04-06 15:30:00	\N	\N	1	0	\N	\N
551534	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - Direction générale du Trésor - MEAE	Contrôle 2020 - Direction générale du Trésor - MEAE	2021-04-06 15:30:00	2021-04-06 16:30:00	\N	\N	1	0	\N	\N
551537	MISSION	AUDRAP	\N	VIETUDIA	\N	Mive - Campus France	Audition Mme Béatrice Khaiat, directrice générale de Campus France	2021-04-12 11:05:00	2021-04-12 12:10:00	\N	\N	5	0	\N	\N
551556	MISSION	AUCUNE	\N	VIETUDIA	\N	Mive - TR handicap	Table ronde "Handicap et vie étudiante"	2021-04-12 14:30:00	2021-04-12 16:40:00	2021-04-12 16:41:50	2021-04-14 18:26:28	6	0	\N	\N
551563	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition SNPE et de UPE	Audition SNPE et de UPE	2021-04-08 14:00:00	2021-04-08 14:45:00	\N	\N	2	0	\N	\N
551566	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Conseil supérieur de l'audiovisuel	\N	2021-04-08 14:45:00	2021-04-08 15:30:00	\N	\N	2	0	\N	\N
551569	COM_PERMANENTE	AUDRAP	\N	CDD	\N	M. Arnaud Leroy et Mme Agathe Bousquet	\N	2021-04-08 16:30:00	2021-04-08 17:15:00	\N	\N	4	0	\N	\N
551575	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition AACC - UDECAM - Association de la filière communication	\N	2021-04-08 17:45:00	2021-04-08 19:15:00	\N	\N	2	0	\N	\N
555475	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Dérèglement Climatique et résilience - Table ronde Transporteurs	PJL Dérèglement Climatique et résilience - Table ronde Transporteurs	2021-04-21 08:30:00	2021-04-21 10:00:00	\N	\N	1	0	\N	\N
555477	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Dérèglement Climatique et résilience - Délégué Transition énergétique Bretagne	PJL Dérèglement Climatique et résilience - Délégué Transition énergétique Bretagne	2021-05-03 09:00:00	2021-05-03 10:00:00	\N	\N	1	0	\N	\N
555479	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PJL Climat Forêt	Auditions PJL Climat Forêt	2021-04-28 14:00:00	2021-04-28 15:00:00	\N	\N	2	0	\N	\N
555482	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PJL Climat Forêt	Auditions PJL Climat Forêt	2021-04-29 17:30:00	2021-04-29 18:30:00	\N	\N	1	0	\N	\N
555483	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PJL Climat Forêt	Auditions PJL Climat Forêt	2021-04-29 16:00:00	2021-04-29 17:15:00	\N	\N	2	0	\N	\N
555484	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PJL Climat Forêt	Auditions PJL Climat Forêt	2021-04-29 14:00:00	2021-04-29 15:00:00	\N	\N	1	0	\N	\N
555485	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PJL Climat Forêt	Auditions PJL Climat Forêt	2021-04-29 15:00:00	2021-04-29 16:00:00	\N	\N	1	0	\N	\N
555492	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PJL Climat Volet Consommer	Auditions PJL Climat Volet Consommer	2021-04-28 09:30:00	2021-04-28 11:15:00	\N	\N	2	0	\N	\N
555494	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PJL Climat Volet Consommer	Auditions PJL Climat Volet Consommer	2021-04-28 17:30:00	2021-04-28 18:00:00	\N	\N	1	0	\N	\N
555499	ETUDES	AUDRAP	\N	\N	\N	GEAC - Audition de M. BOUVIER Directeur stratégie Groupe Airbus	GEAC - Audition de M. BOUVIER Directeur stratégie Groupe Airbus	2021-05-05 08:00:00	2021-05-05 09:15:00	\N	\N	21	0	\N	933
555602	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	AFEU	\N	Audition de Mme Valérie METRICH HECQUET	\N	2021-05-04 14:15:00	2021-05-04 16:00:00	\N	\N	0	0	\N	\N
555755	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière ATDD	\N	2021-05-04 16:30:00	2021-05-04 18:30:00	2021-05-04 17:51:01	2021-05-06 17:43:07	27	1	\N	\N
555758	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Soins palliatifs - Table ronde sur la recherche en soins palliatifs	\N	2021-05-04 14:30:00	2021-05-04 16:00:00	\N	\N	7	0	\N	\N
558552	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2021-05-11 08:35:00	2021-05-11 10:15:00	\N	\N	3	0	\N	\N
559682	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PPL Maltraitance animale	Auditions PPL Maltraitance animale	2021-05-11 09:30:00	2021-05-11 11:45:00	\N	\N	1	0	\N	\N
559684	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PPL Maltraitance animale	Auditions PPL Maltraitance animale	2021-05-11 16:45:00	2021-05-11 18:00:00	\N	\N	1	0	\N	\N
559720	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Santé mentale - Audition SPF et COVER	\N	2021-05-20 14:30:00	2021-05-20 16:00:00	\N	\N	3	0	\N	\N
559721	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Santé mentale - Audition de pédopsychiatres	\N	2021-05-20 16:00:00	2021-05-20 17:00:00	\N	\N	4	0	\N	\N
559727	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière - LEC	\N	2021-05-19 08:30:00	2021-05-19 09:00:00	2021-05-19 11:51:42	2021-05-19 15:31:23	40	0	\N	\N
600690	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Direction générale des médias et des industries culturelles - ministère de la culture	Audition de M. Gourdin	2021-11-04 11:30:00	2021-11-04 12:30:00	\N	\N	1	0	\N	\N
600692	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition de Mme Roselyne Bachelot	Audition de Mme Roselyne Bachelot	2021-11-09 17:05:00	2021-11-09 19:13:00	2021-11-12 10:13:49	2021-11-12 19:00:45	26	0	\N	\N
600698	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Table ronde avec les syndicats de France Télévisions	\N	2021-11-04 14:00:00	2021-11-04 15:30:00	\N	\N	3	0	\N	\N
600699	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Dédignation CMP directeur d'école Rapport d¿information repartition moyens à la création.	\N	2021-11-02 17:00:00	2021-11-02 18:15:00	2021-11-04 15:58:24	2021-11-04 16:07:19	14	0	\N	\N
600700	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Syndicat Radio France	Audition de l'UNSA	2021-11-09 09:30:00	2021-11-09 10:20:00	\N	\N	3	0	\N	\N
600747	DELEGATION	AUCUNE	\N	\N	206	Audition publique sur la transmission du coronavirus dans les milieux confinés	\N	2021-11-04 09:40:00	2021-11-04 12:20:00	\N	\N	11	0	\N	\N
600765	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Direction du budget - Ministère des comptes et de l'action publique	Audition de Mme Bouillon	2021-11-03 14:00:00	2021-11-03 14:30:00	\N	\N	4	0	\N	\N
600766	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2022 - Audition de Mme Baduel, Dger	\N	2021-11-04 11:30:00	2021-11-04 12:30:00	\N	\N	2	0	\N	\N
600779	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - CAS PFE - APE	PLF pour 2022 - CAS PFE - APE	2021-11-04 10:30:00	2021-11-04 12:00:00	\N	\N	1	0	\N	\N
601110	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2022 - Programme 144	\N	2021-11-02 15:00:00	2021-11-02 16:00:00	\N	\N	1	0	\N	\N
601112	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2022 - Programme 151	\N	2021-11-03 14:00:00	2021-11-03 15:00:00	\N	\N	2	0	\N	\N
601119	GIA	AUCUNE	\N	\N	\N	Réception de l'ambassadrice de France en Albanie	Déjeuner de travail du groupe d'amitié France-Albanie en présence de Mme l'Ambassadrice de France en Albanie	2021-11-04 13:00:00	2021-11-04 14:30:00	\N	\N	9	0	571	\N
601130	QUESTURE	AUCUNE	\N	\N	\N	Réunion de Questure	Réunion de Questure	2021-11-04 09:00:00	2021-11-04 10:30:00	\N	\N	3	0	\N	\N
601165	COM_PERMANENTE	DEPLACEMENT	\N	CAE	\N	PLF 2022 - Cohésion des territoires - Déplacement à Grigny	PLF 2022 - Cohésion des territoires - Déplacement à Grigny	2021-11-03 14:30:00	2021-11-03 16:45:00	\N	\N	1	0	\N	\N
601167	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Économie - DG Trésor/BdF	PLF pour 2022 - Économie - DG Trésor/BdF	2021-11-02 14:30:00	2021-11-02 16:30:00	\N	\N	2	0	\N	\N
601170	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Économie - DGCCRF	PLF pour 2022 - Économie - DGCCRF	2021-11-02 17:30:00	2021-11-02 18:30:00	\N	\N	2	0	\N	\N
601173	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Rapport Général - Les Séropotes	PLF pour 2022 - Rapport Général - Les Séropotes	2021-11-03 16:15:00	2021-11-03 16:50:00	\N	\N	1	0	\N	\N
601175	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Rapport Général - TR GNI-HCR/UMIH	PLF pour 2022 - Rapport Général - TR GNI-HCR/UMIH	2021-11-03 18:25:00	2021-11-03 19:25:00	\N	\N	1	0	\N	\N
601177	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - MIRES - CNRS/ANR/CNES	PLF pour 2022 - MIRES - CNRS/ANR/CNES	2021-11-02 15:00:00	2021-11-02 18:00:00	\N	\N	1	0	\N	\N
601179	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - MIRES - Urbaniste	PLF pour 2022 - MIRES - Urbaniste	2021-11-04 13:30:00	2021-11-04 14:00:00	\N	\N	1	0	\N	\N
601181	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - MIRES - INSERM	PLF pour 2022 - MIRES - INSERM	2021-11-04 14:00:00	2021-11-04 15:00:00	\N	\N	1	0	\N	\N
601183	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - MIRES - DGESIP/CGE	PLF pour 2022 - MIRES - DGESIP/CGE	2021-11-04 15:00:00	2021-11-04 17:00:00	\N	\N	1	0	\N	\N
601185	COM_EURO	AUDRAP	\N	AFEU	\N	Audition de Mme Gatel	\N	2021-11-08 16:00:00	2021-11-08 17:00:00	\N	\N	0	0	\N	\N
601191	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Justice - USM	PLF pour 2022 - Justice - USM	2021-11-03 18:00:00	2021-11-03 19:00:00	\N	\N	1	0	\N	\N
601197	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition PLF 2022 - Mildeca	\N	2021-11-08 16:00:00	2021-11-08 17:00:00	\N	\N	1	0	\N	\N
601218	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - AEE - DFAE	PLF pour 2022 - AEE - DFAE	2021-11-04 11:00:00	2021-11-04 12:00:00	\N	\N	2	0	\N	\N
601221	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - AEE - Atout France	PLF pour 2022 - AEE - Atout France	2021-11-05 15:30:00	2021-11-05 16:30:00	\N	\N	1	0	\N	\N
601223	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition M. Chevrollier - DGALN	Audition M. Chevrollier - DGALN	2021-10-26 09:45:00	2021-10-26 10:45:00	\N	\N	1	0	\N	\N
601224	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition M. Chevrollier	\N	2021-10-26 09:45:00	2021-10-26 10:45:00	\N	\N	0	0	\N	\N
601265	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition de M. Chevrollier -  FP2E	Audition de M. Chevrollier -  FP2E	2021-11-02 09:40:00	2021-11-02 10:45:00	\N	\N	1	0	\N	\N
601269	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition de M. Chevrollier - Agences de l'eau	Audition de M. Chevrollier - Agences de l'eau	2021-11-02 17:20:00	2021-11-02 19:00:00	\N	\N	1	0	\N	\N
601272	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Fondation pour la protection des habitats et de la faune sauvage	Fondation pour la protection des habitats et de la faune sauvage	2021-11-04 09:30:00	2021-11-04 10:30:00	\N	\N	2	0	\N	\N
601276	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Institut national de l'information géographique et forestière (IGN)	Institut national de l'information géographique et forestière (IGN)	2021-11-04 10:30:00	2021-11-04 11:30:00	\N	\N	1	0	\N	\N
601278	COM_PERMANENTE	AUDRAP	\N	CDD	\N	CÉREMA	CÉREMA	2021-11-04 11:30:00	2021-11-04 12:20:00	\N	\N	2	0	\N	\N
601286	COM_PERMANENTE	AUDRAP	\N	CAE	\N	DGEC	DGEC	2021-11-02 17:30:00	2021-11-02 18:30:00	\N	\N	1	0	\N	\N
601311	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Direction générale des entreprises 	Direction générale des entreprises 	2021-11-04 14:30:00	2021-11-04 15:15:00	\N	\N	2	0	\N	\N
601335	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2022 Travail et emploi - Audition de Pôle emploi	\N	2021-11-08 11:30:00	2021-11-08 12:30:00	\N	\N	1	0	\N	\N
601337	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2022 Travail et emploi - Audition de l'U2P	\N	2021-11-08 14:30:00	2021-11-08 15:30:00	\N	\N	1	0	\N	\N
601480	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2022 - Avis juridictions financières et administratives	\N	2021-11-08 14:30:00	2021-11-08 19:00:00	\N	\N	1	0	\N	\N
601707	GIA	AUCUNE	\N	\N	\N	Cinquième anniversaire de la signature des accords de paix en Colombie	Entretien avec MM. Juan Manuel SANTOS et Rodrigo LONDONO, co-signataires des accords de paix	2021-11-10 10:45:00	2021-11-10 12:30:00	\N	\N	4	0	979	\N
602974	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2022 - Avis "Protection judiciaire de la jeunesse"	\N	2021-11-10 16:30:00	2021-11-10 17:30:00	\N	\N	1	0	\N	\N
603089	GIA	AUCUNE	\N	\N	\N	Coopé - Entretien avec une délégation tchèque	Coopé - Entretien avec une délégation tchèque	2021-11-08 12:30:00	2021-11-08 15:00:00	\N	\N	2	0	611	\N
603140	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Travailleurs indépendants	PJL Travailleurs indépendants	2021-11-15 17:00:00	2021-11-15 19:55:00	\N	\N	36	0	\N	\N
603142	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	1564	\N	\N	Explications de vote - PLFSS	Explications de vote - PLFSS	2021-11-16 14:30:00	2021-11-16 15:40:00	\N	\N	295	0	\N	\N
603143	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Souveraineté énergétique française	Débat Souveraineté énergétique française	2021-11-16 15:50:00	2021-11-16 17:25:00	\N	\N	87	0	\N	\N
601156	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	plf création	\N	2021-11-05 11:00:00	2021-11-05 12:30:00	\N	\N	2	0	\N	\N
603145	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Collectivité européenne d'Alsace	PJL Collectivité européenne d'Alsace	2021-11-16 18:00:00	2021-11-16 20:00:00	\N	\N	57	0	\N	\N
603147	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2021-11-17 15:00:00	2021-11-17 16:30:00	\N	\N	287	0	\N	\N
603149	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFR pour 2021	PLFR pour 2021	2021-11-17 16:35:00	2021-11-17 19:55:00	\N	\N	111	0	\N	\N
603150	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFR pour 2021	PLFR pour 2021	2021-11-17 21:30:00	2021-11-18 00:20:00	\N	\N	43	0	\N	\N
603151	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Maltraitance animale	CMP Maltraitance animale	2021-11-18 10:30:00	2021-11-18 11:35:00	\N	\N	47	0	\N	\N
603152	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Confiance institution judiciaire	CMP Confiance institution judiciaire	2021-11-18 11:40:00	2021-11-18 13:30:00	\N	\N	53	0	\N	\N
526785	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière	\N	2021-02-04 09:00:00	2021-02-04 11:30:00	2021-02-04 11:26:32	\N	16	0	\N	\N
526817	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 11 février 2021	\N	2021-02-11 09:00:00	2021-02-11 11:05:00	2021-02-11 14:28:29	2021-02-11 18:27:49	24	0	\N	\N
528026	GIA	AUCUNE	\N	\N	\N	Rencontre GRK	Rencontre avec M. Ali Dolamari, représentant en France du Gouvernement régional du Kurdistan	2021-03-10 17:00:00	2021-03-10 18:00:00	\N	\N	4	0	615	\N
543853	GIA	AUCUNE	\N	\N	\N	Audition de S.E. M. Marc VIZY, Ambassadeur de France au Bénin	Audition de S.E. M. Marc VIZY, Ambassadeur de France au Bénin	2021-03-23 15:15:00	2021-03-23 16:15:00	\N	\N	7	0	573	\N
543910	GIA	AUCUNE	\N	\N	\N	Entretien avec S.E. M. Philippe LALLIOT, Ambassadeur de France au Sénégal	Entretien avec S.E. M. Philippe LALLIOT, Ambassadeur de France au Sénégal	2021-03-23 16:30:00	2021-03-23 18:20:00	\N	\N	10	0	573	\N
548970	DELEGATION	AUCUNE	\N	\N	COLTER	Audition A. de Montchalin, ministre de la transformation et de la fonction publiques	\N	2021-04-15 09:30:00	2021-04-15 11:15:00	\N	\N	14	0	\N	\N
555327	GIA	AUCUNE	\N	\N	\N	Audition de l'AFD	\N	2021-03-25 09:00:00	2021-03-25 10:00:00	\N	\N	10	0	626	\N
557902	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL DADUE	PJL DADUE	2021-05-05 11:30:00	2021-05-05 12:30:00	\N	\N	1	0	\N	\N
557904	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL DADUE	PJL DADUE	2021-05-05 13:30:00	2021-05-05 15:00:00	\N	\N	1	0	\N	\N
557906	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL DADUE	PJL DADUE	2021-05-06 17:00:00	2021-05-07 18:00:00	\N	\N	1	0	\N	\N
558259	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Mission d'évaluation de la Loi SRU	Audition Mission d'évaluation de la Loi SRU	2021-05-05 17:30:00	2021-05-05 18:30:00	\N	\N	1	0	\N	\N
558260	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Réception d'une délégation de maires du Gard - Mission d'évaluation loi SRU	\N	2021-05-05 16:30:00	2021-05-05 17:30:00	\N	\N	2	0	\N	\N
558264	DELEGATION	AUCUNE	\N	\N	211	Échange de vues sur les suites de la table ronde du 8 avril 2021	Échange de vues sur les suites de la table ronde du 8 avril 2021	2021-05-27 09:00:00	2021-05-27 10:00:00	2021-05-27 12:12:16	\N	13	0	\N	\N
558281	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Accès à certaines professions et maladies chroniques	\N	2021-05-11 10:00:00	2021-05-11 11:00:00	\N	\N	3	0	\N	\N
566450	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT Boussole stratégique	\N	2021-05-31 16:00:00	2021-05-31 17:30:00	\N	\N	2	0	\N	\N
566453	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition du Général d'armée François Lecointre	Audition du Général d'armée François Lecointre	2021-06-08 16:40:00	2021-06-08 18:53:00	2021-06-09 12:24:52	2021-06-09 12:27:31	26	0	\N	\N
566454	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de M. René Troccaz	Audition de M. René Troccaz	2021-06-09 10:00:00	2021-06-09 11:20:00	2021-06-09 14:16:27	2021-06-09 14:32:12	31	0	\N	\N
566455	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de M. Stéphane Bouillon	Audition de M. Stéphane Bouillon	2021-06-10 10:30:00	2021-06-10 11:55:00	2021-06-10 14:38:58	2021-06-10 18:07:58	12	0	\N	\N
591140	DELEGATION	AUDRAP	\N	\N	COLTER	Audition de M. Emmanuel ACCHIARDI - DHUP	\N	2021-11-09 17:00:00	2021-11-09 18:00:00	\N	\N	0	0	\N	\N
591278	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition CATMP - PLFSS 2022 -  PJL Dialogue social avec les plateformes	\N	2021-10-18 17:00:00	2021-10-18 18:00:00	\N	\N	2	0	\N	\N
591281	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition DSS - PLFSS 2022	\N	2021-10-19 09:00:00	2021-10-19 09:45:00	\N	\N	2	0	\N	\N
591282	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition FNATH - PLFSS 2022	\N	2021-10-19 15:00:00	2021-10-19 15:45:00	\N	\N	1	0	\N	\N
598064	ETUDES	AUCUNE	\N	\N	\N	Audition du CNPMEM	Audition du CNPMEM	2021-10-28 08:00:00	2021-10-28 09:30:00	\N	\N	6	0	\N	1012
598071	ETUDES	AUCUNE	\N	\N	\N	Audition de l'Union du mareyage Français	Audition de l'Union du mareyage Français	2021-10-28 09:30:00	2021-10-28 10:10:00	\N	\N	1	0	\N	1012
600443	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2022 Avis Cohésion des territoires - Logement - Audition DHUP	PLF 2022 Avis Cohésion des territoires - Logement - Audition DHUP	2021-11-02 17:30:00	2021-11-02 18:15:00	\N	\N	3	0	\N	\N
600444	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2022 - Avis Cohésion des territoires Logement - Audition DIHAL	PLF 2022 - Avis Cohésion des territoires Logement - Audition DIHAL	2021-11-02 18:15:00	2021-11-02 19:15:00	\N	\N	2	0	\N	\N
600465	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2022 - Avis Politique de la ville - Audition DGCL	PLF 2022 - Avis Politique de la ville - Audition DGCL	2021-11-03 11:15:00	2021-11-03 11:55:00	\N	\N	1	0	\N	\N
600466	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2022 - Avis Politique de la ville - Cabinet ministère cohésion des territoires	PLF 2022 - Avis Politique de la ville - Cabinet ministère cohésion des territoires	2021-11-03 11:55:00	2021-11-03 12:30:00	\N	\N	1	0	\N	\N
600490	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - BA CEA - DGAC	PLF pour 2022 - BA CEA - DGAC	2021-11-03 17:00:00	2021-11-03 18:00:00	\N	\N	1	0	\N	\N
600495	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2022 : Missions «Travail et emploi»«Enseignement scolaire»«Économie»et«Outre-mer»	PLF pour 2022 : Missions «Travail et emploi»«Enseignement scolaire»«Économie»et«Outre-mer»	2021-11-09 14:35:00	2021-11-09 17:30:00	2021-11-09 18:36:29	2021-11-12 19:00:45	29	0	\N	\N
600586	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2022 : CAS «PFE» et Mission «Agriculture, AFAR» 	PLF pour 2022 : CAS «PFE» et Mission «Agriculture, AFAR» 	2021-11-10 16:35:00	2021-11-10 17:40:00	2021-11-10 18:46:44	2021-11-12 19:00:39	18	0	\N	\N
600815	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2021-11-08 13:30:00	2021-11-08 15:40:00	2021-11-08 15:41:45	2021-11-08 16:06:43	31	1	\N	\N
601157	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	plf Création	\N	2021-11-05 17:00:00	2021-11-05 18:10:00	\N	\N	2	0	\N	\N
600552	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2022 : Tome II RG-Missions «Action extérieure de l'État»-Vote Missions réservées	PLF pour 2022 : Tome II du RG -Missions «Agriculture, AFAR»et«Action extérieure de l'État»-Vote Missions réservées	2021-11-10 09:35:00	2021-11-10 11:15:00	2021-11-10 15:53:40	2021-11-12 19:00:41	45	0	\N	\N
600817	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2021-11-08 19:50:00	2021-11-08 20:40:00	2021-11-08 20:48:26	2021-11-12 19:00:48	28	1	\N	\N
600819	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2021-11-09 09:30:00	2021-11-09 10:20:00	2021-11-10 11:16:02	2021-11-12 19:00:46	32	0	\N	\N
600821	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2021-11-09 14:15:00	2021-11-09 14:20:00	2021-11-10 11:18:47	2021-11-12 19:00:46	18	0	\N	\N
600843	DELEGATION	AUCUNE	\N	\N	COLTER	Table ronde sur "Les élus aujourd'hui"	\N	2021-11-04 10:30:00	2021-11-04 12:15:00	\N	\N	19	0	\N	\N
600911	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2022 - Avis recherche - Audition de la Direction générale des entreprises	PLF 2022 - Avis recherche - Audition de la Direction générale des entreprises	2021-11-04 09:30:00	2021-11-04 10:30:00	\N	\N	1	0	\N	\N
600914	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2022 - Avis justice judiciaire et accès au droit	PLF pour 2022 - Avis justice judiciaire et accès au droit	2021-11-02 14:30:00	2021-11-02 16:45:00	\N	\N	2	0	\N	\N
600917	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2022 - Avis justice judiciaire et accès au droit	PLF pour 2022 - Avis justice judiciaire et accès au droit	2021-11-02 18:00:00	2021-11-02 19:00:00	\N	\N	2	0	\N	\N
600983	COM_EURO	AUDRAP	\N	AFEU	\N	Politique culturelle de l'UE	Politique culturelle de l'UE - Audition de M. Renaud Donnedieu de Vabres	2021-11-04 12:15:00	2021-11-04 13:15:00	\N	\N	2	0	\N	\N
601007	ETUDES	AUDRAP	\N	\N	\N	Table ronde ¿ Etat des lieux  « Lutte contre l¿illectronisme et inclusion numérique »	Table ronde ¿ Etat des lieux  « Lutte contre l¿illectronisme et inclusion numérique »	2021-11-04 09:05:00	2021-11-04 11:10:00	\N	\N	15	0	\N	1008
601063	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition de M.Jean-Michel Blanquer, et de Mme Sarah El Haïry, 	Audition de M.Jean-Michel Blanquer, et de Mme Sarah El Haïry, 	2021-11-03 16:35:00	2021-11-03 19:10:00	2021-11-05 10:00:08	2021-11-05 16:13:51	24	0	\N	\N
588525	COM_PERMANENTE	AUTRE	\N	FINC	\N	Contrôles budgétaires : Protection des épargnants et Action des missions locales	Contrôles budgétaires : Protection des épargnants et Action des missions locales	2021-10-06 09:30:00	2021-10-06 11:40:00	2021-10-06 14:50:51	2021-10-06 16:05:35	40	0	\N	\N
588526	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2021-10-05 15:00:00	2021-10-05 16:40:00	2021-10-06 09:59:09	2021-10-06 16:05:38	71	0	\N	\N
588527	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2021-10-06 09:30:00	2021-10-06 11:45:00	2021-10-06 11:47:20	2021-10-06 16:05:34	44	0	\N	\N
588528	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition plénière 	\N	2021-10-06 16:30:00	2021-10-06 18:00:00	2021-10-06 18:01:15	2021-10-07 09:47:00	24	0	\N	\N
588533	DELEGATION	AUDRAP	\N	\N	206	Audition de rapporteur	\N	2021-09-29 16:00:00	2021-09-29 17:10:00	\N	\N	1	0	\N	\N
588537	DELEGATION	AUDRAP	\N	\N	206	Audition de rapporteur	\N	2021-09-29 17:10:00	2021-09-29 18:15:00	\N	\N	1	0	\N	\N
588545	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur - Mme Marache	Audition rapporteur - Europe de la Culture - Mme Corinne Marache	2021-09-23 10:30:00	2021-09-23 11:30:00	\N	\N	1	0	\N	\N
588547	DELEGATION	AUDRAP	\N	\N	206	Audition de rapporteur	\N	2021-10-05 12:30:00	2021-10-05 14:00:00	\N	\N	1	0	\N	\N
588548	DELEGATION	AUDRAP	\N	\N	206	Audition de rapporteur	\N	2021-10-07 17:00:00	2021-10-07 18:00:00	\N	\N	1	0	\N	\N
588549	DELEGATION	AUDRAP	\N	\N	206	Audition de rapporteur	\N	2021-10-13 17:00:00	2021-10-13 18:00:00	\N	\N	1	0	\N	\N
588556	DELEGATION	AUDRAP	\N	\N	206	Audition de rapporteur	\N	2021-10-19 15:00:00	2021-10-19 16:00:00	\N	\N	1	0	\N	\N
588557	DELEGATION	AUDRAP	\N	\N	206	Audition de rapporteur	\N	2021-10-19 16:00:00	2021-10-19 17:20:00	\N	\N	1	0	\N	\N
588558	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - RSR - Caisse retraite personnel RATP	PLF pour 2022 - RSR - Caisse retraite personnel RATP	2021-09-29 16:00:00	2021-09-29 16:30:00	\N	\N	1	0	\N	\N
588560	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2022 - Sport - Le Mouvement associatif	PLF pour 2022 - Sport - Le Mouvement associatif	2021-09-28 17:45:00	2021-09-28 18:45:00	\N	\N	1	0	\N	\N
588562	ETUDES	AUTRE	\N	\N	\N	Audition de M. Augustin de ROMANET, Président-directeur général du groupe ADP	Audition de M. Augustin de ROMANET, Président-directeur général du groupe ADP	2021-10-06 08:30:00	2021-10-06 09:40:00	\N	\N	17	0	\N	933
588563	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Vaccination obligatoire contre le SARS-CoV-2 - Audition du Pr Karine Lacombe	\N	2021-09-29 16:30:00	2021-09-29 17:25:00	\N	\N	5	0	\N	\N
588564	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Vaccination obligatoire contre le SARS-CoV-2 - Audition du Pr Arnaud Fontanet	\N	2021-09-29 14:00:00	2021-09-29 14:55:00	\N	\N	4	0	\N	\N
588574	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Protection des enfants - Audition de la DGCS	\N	2021-09-29 16:30:00	2021-09-29 18:00:00	\N	\N	1	0	\N	\N
588575	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Protection des enfants - Audition d'Unicef France	\N	2021-09-30 09:00:00	2021-09-30 09:45:00	\N	\N	2	0	\N	\N
624110	COM_PERMANENTE	AUDRAP	\N	CDD	\N	MI Aménagement du territoire - Audition Mmes Filleul et Herzog	MI Aménagement du territoire - Audition Mmes Filleul et Herzog	2022-01-11 17:30:00	2022-01-11 18:15:00	\N	\N	2	0	\N	\N
624119	COM_PERMANENTE	AUDRAP	\N	CDD	\N	MI Aménagement du territoire - Audition Mmes Filleul et Herzog	MI Aménagement du territoire - Audition Mmes Filleul et Herzog	2022-01-18 14:30:00	2022-01-18 15:30:00	\N	\N	2	0	\N	\N
624123	COM_PERMANENTE	AUDRAP	\N	CDD	\N	MI Aménagement du territoire - Audition M. Belin et Mme Herzog	MI Aménagement du territoire - Audition M. Belin et Mme Herzog	2022-01-18 15:15:00	2022-01-18 16:00:00	\N	\N	2	0	\N	\N
626854	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Audition ambassadrice environnement	\N	2022-01-26 13:45:00	2022-01-26 14:55:00	\N	\N	0	0	\N	\N
626861	COM_ENQUETE	PLENIERE	\N	MEDIA	\N	rn médias	\N	2022-01-28 10:35:00	2022-01-28 13:20:00	2022-01-28 18:31:11	2022-01-28 18:40:56	11	0	\N	\N
626864	COM_ENQUETE	PLENIERE	\N	MEDIA	\N	rn médias	\N	2022-01-28 14:30:00	2022-01-28 17:55:00	2022-01-28 18:33:19	2022-01-28 18:40:57	9	0	\N	\N
626876	COM_ENQUETE	PLENIERE	\N	MEDIA	\N	rn médias	\N	2022-01-27 11:00:00	2022-01-27 12:15:00	2022-01-28 18:26:47	2022-01-28 18:40:56	8	0	\N	\N
626883	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Auditions plénières - Mme Parly, ministre des armées - M. Bontemps, Nos Services Publics	\N	2022-02-01 16:30:00	2022-02-01 19:00:00	\N	\N	0	0	\N	\N
626887	MISSION	AUCUNE	\N	CULTURE	\N	Réunion 20220201	\N	2022-02-01 16:05:00	2022-02-01 18:25:00	2022-02-02 13:36:49	2022-02-02 15:44:32	8	0	\N	\N
626888	DELEGATION	AUCUNE	\N	\N	206	Audition publique Prise en charge du handicap	\N	2022-01-27 09:40:00	2022-01-27 13:50:00	\N	\N	8	0	\N	\N
626897	COM_PERMANENTE	PEC_NON_MML	\N	CAE	\N	\N	\N	2022-02-02 08:30:00	2022-02-02 10:10:00	2022-02-08 16:22:13	2022-02-08 16:57:09	45	0	\N	\N
600825	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2021-11-10 10:30:00	2021-11-10 11:35:00	2021-11-10 11:37:15	2021-11-12 19:00:40	37	0	\N	\N
626898	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition Philippe Baptiste (CNES)	\N	2022-02-02 10:15:00	2022-02-02 11:30:00	2022-02-08 16:23:01	2022-02-08 16:57:07	42	0	\N	\N
626899	DELEGATION	AUCUNE	\N	\N	COLTER	Audition de M. le Garde des Sceaux Eric Dupont-Moretti	\N	2022-02-23 16:45:00	2022-02-23 18:15:00	\N	\N	22	0	\N	\N
626958	COM_ENQUETE	PLENIERE	\N	MEDIA	\N	rn médias	\N	2022-01-31 15:05:00	2022-01-31 16:55:00	2022-01-31 17:32:36	2022-02-01 18:16:09	12	0	\N	\N
626959	COM_ENQUETE	AUDRAP	\N	HOPITAL	\N	CE Hôpital - Audition du SMPS	\N	2022-01-27 09:00:00	2022-01-27 10:00:00	\N	\N	6	0	\N	\N
626960	COM_ENQUETE	AUDRAP	\N	HOPITAL	\N	CE Hôpital - Audition de MM. Collet, Vincent et du Pr Brézin	\N	2022-01-27 15:00:00	2022-01-27 16:00:00	\N	\N	5	0	\N	\N
626961	COM_ENQUETE	AUDRAP	\N	HOPITAL	\N	CE Hôpital - Audition du collectif ICP	\N	2022-01-27 16:00:00	2022-01-27 17:00:00	\N	\N	5	0	\N	\N
626962	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Innovation en santé - Table ronde Experts de l'innovation en oncologie	\N	2022-01-27 14:00:00	2022-01-27 15:45:00	\N	\N	4	0	\N	\N
626963	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Innovation en santé - Table ronde Acteurs de la coordination des CPP	\N	2022-01-27 15:45:00	2022-01-27 17:15:00	\N	\N	2	0	\N	\N
628546	MISSION	AUDRAP	\N	JUDI	\N	\N	Audition rapporteur - MI Judiciarisation	2022-02-02 14:00:00	2022-02-02 15:00:00	\N	\N	3	0	\N	\N
628772	GIA	AUCUNE	\N	\N	\N	Entretien avec S.E. M. Teemu Tanner, ambassadeur de Finlande en France	Entretien avec S.E. M. Teemu Tanner, ambassadeur de Finlande en France	2022-02-02 14:00:00	2022-02-02 15:00:00	\N	\N	10	0	640	\N
629857	MISSION	AUCUNE	\N	RECHINNO	\N	Conférence des grandes écoles, CentraleSupelec et Joint European Disruptive Initiative	Conférence des grandes écoles, CentraleSupelec et Joint European Disruptive Initiative	2022-02-02 16:30:00	2022-02-02 19:00:00	2022-02-16 10:58:06	\N	7	0	\N	\N
631345	ETUDES	AUCUNE	\N	\N	\N	FEDEREC	FEDEREC	2022-02-09 13:55:00	2022-02-09 14:55:00	\N	\N	4	0	\N	922
633220	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Michaël ROUX, Ambassadeur de France au Liberia	Entretien avec M. Michaël ROUX, Ambassadeur de France au Liberia	2022-02-16 14:00:00	2022-02-16 14:40:00	\N	\N	7	0	573	\N
634653	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Innovation en santé	PPL Innovation en santé	2022-02-22 21:30:00	2022-02-23 00:00:00	\N	\N	37	0	\N	\N
634654	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2022-02-23 15:00:00	2022-02-23 16:30:00	\N	\N	265	0	\N	\N
634655	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat 50¿1 Engagement de la France au Sahel	Débat 50¿1 Engagement de la France au Sahel	2022-02-23 16:45:00	2022-02-23 19:25:00	\N	\N	131	0	\N	\N
634656	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Garantie à l'emploi pour les chômeurs	PPL Garantie à l'emploi pour les chômeurs	2022-02-23 19:30:00	2022-02-23 20:00:00	\N	\N	51	0	\N	\N
634658	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Allocation de soutien familial	PPL Allocation de soutien familial	2022-02-23 22:45:00	2022-02-24 00:10:00	\N	\N	44	0	\N	\N
634659	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Dépôt du rapport Cour des comptes	Débat Dépôt du rapport Cour des comptes	2022-02-24 10:30:00	2022-02-24 12:40:00	\N	\N	103	0	\N	\N
634660	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	NL PPL Choix du nom issu de la filiation	NL PPL Choix du nom issu de la filiation	2022-02-24 14:30:00	2022-02-24 15:35:00	\N	\N	37	0	\N	\N
634661	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Monde combattant	PPL Monde combattant	2022-02-24 15:35:00	2022-02-24 16:35:00	\N	\N	46	0	\N	\N
634662	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Cybersécurité des plateformes numériques 	PPL Cybersécurité des plateformes numériques	2022-02-24 16:40:00	2022-02-24 17:35:00	\N	\N	40	0	\N	\N
634663	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PJL Outils de gestion des risques climatiques	CMP PJL Outils de gestion des risques climatiques	2022-02-24 17:35:00	2022-02-24 18:30:00	\N	\N	26	0	\N	\N
509768	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2021 - Programme 144	\N	2020-11-24 11:00:00	2020-11-24 12:00:00	\N	\N	2	0	\N	\N
509771	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2021 - Programme 144	\N	2020-11-24 14:00:00	2020-11-24 15:00:00	\N	\N	2	0	\N	\N
509774	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2021 - Programme 144	\N	2020-11-24 16:30:00	2020-11-24 19:40:00	\N	\N	2	0	\N	\N
510773	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Comité de suivi Suez-Veolia - Syndicats Engie	Comité de suivi Suez-Veolia - Syndicats Engie	2020-11-24 16:10:00	2020-11-24 17:40:00	\N	\N	5	0	\N	\N
510781	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Comité de suivi Suez-Veolia - Syndicats Suez	Comité de suivi Suez-Veolia - Syndicats Suez	2020-11-24 18:00:00	2020-11-24 19:30:00	\N	\N	4	0	\N	\N
515955	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT subsidiarité	Réunion du GT subsidiarité	2020-12-10 08:35:00	2020-12-10 08:50:00	\N	\N	5	0	\N	\N
517072	GIA	AUCUNE	\N	\N	\N	AG	\N	2020-12-15 13:45:00	2020-12-15 14:15:00	\N	\N	8	0	646	\N
522551	GIA	AUCUNE	\N	\N	\N	AG	AG de reconstitution	2021-01-20 13:30:00	2021-01-20 14:00:00	\N	\N	11	0	591	\N
524270	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Système des ressources propres UE - Parlement Européen	PJL Système des ressources propres UE - Parlement Européen	2021-01-22 12:15:00	2021-01-22 13:00:00	\N	\N	1	0	\N	\N
524291	DELEGATION	AUCUNE	\N	\N	211	Table ronde sur les violences faites aux femmes dans les territoires ruraux	Table ronde sur les violences faites aux femmes dans les territoires ruraux	2021-02-11 08:30:00	2021-02-11 11:30:00	2021-02-11 12:20:03	\N	19	0	\N	\N
524591	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audtion PPL Améliorer le système de santé	\N	2021-01-26 14:30:00	2021-01-26 15:30:00	\N	\N	6	0	\N	\N
524599	ETUDES	AUTRE	\N	\N	\N	Réunion constitutive	\N	2021-01-27 14:00:00	2021-01-27 15:00:00	\N	\N	17	0	\N	1004
524606	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition PPL améiorer le système de santé	\tAudition rapporteur - Commission des affaires sociales - Audition PPL améiorer le système de santé	2021-01-26 17:30:00	2021-01-26 19:00:00	\N	\N	3	0	\N	\N
526646	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI patrimoine culturel immatériel	\N	2021-01-26 14:00:00	2021-01-26 14:05:00	\N	\N	2	0	\N	\N
526676	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI patrimoine culturel immatériel	\N	2021-01-26 15:00:00	2021-01-26 15:55:00	\N	\N	2	0	\N	\N
526679	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI patrimoine culturel immatériel	\N	2021-01-26 16:00:00	2021-01-26 17:10:00	\N	\N	2	0	\N	\N
526682	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI patrimoine culturel immatériel	\N	2021-01-27 14:30:00	2021-01-27 15:50:00	\N	\N	2	0	\N	\N
526686	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Mi patrimoi	\N	2021-01-29 09:00:00	2021-01-29 12:20:00	\N	\N	2	0	\N	\N
530720	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	Audition rapporteur - MI "Difficultés des entreprises et crise de la Covid-19"	2021-02-08 16:00:00	2021-02-08 16:45:00	\N	\N	2	0	\N	\N
530723	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI "Difficultés des entreprises et crise de la Covid-19"	Audition rapporteur - MI "Difficultés des entreprises et crise de la Covid-19"	2021-02-08 17:00:00	2021-02-08 18:00:00	\N	\N	2	0	\N	\N
531450	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Respect principes de la République - Auditions	CNIL	2021-02-11 14:00:00	2021-02-11 15:00:00	\N	\N	8	0	\N	\N
531507	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière	\N	2021-02-18 08:30:00	2021-02-18 11:15:00	2021-02-18 11:53:14	\N	17	0	\N	\N
601475	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Test Kairos2	\N	2013-11-09 12:00:00	2013-11-09 13:15:00	\N	\N	0	0	\N	\N
534223	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur - M. Philippe Laurent	Audition rapporteurs - Politique culturelle de l'UE au service des petites cités de caractère	2021-02-18 17:00:00	2021-02-18 18:30:00	\N	\N	1	0	\N	\N
534228	DELEGATION	AUCUNE	\N	\N	PROS	Audition de M. Gilles Babinet	Audition de M. Gilles Babinet	2021-03-18 08:35:00	2021-03-18 09:50:00	\N	\N	31	0	\N	\N
534275	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière	\N	2021-03-04 09:00:00	2021-03-04 11:00:00	2021-03-04 16:51:37	\N	17	0	\N	\N
534276	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-03-02 08:32:00	2021-03-02 09:16:00	2021-03-02 09:59:17	2021-03-03 17:05:58	24	1	\N	\N
534277	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-03-03 08:45:00	2021-03-03 12:36:00	2021-03-18 09:36:05	2021-03-18 17:10:59	40	0	\N	\N
534282	DELEGATION	AUDRAP	\N	\N	PROS	Audition de M. Michel Lussault	Audition de M. Michel Lussault, directeur de l'Ecole urbaine de Lyon	2021-03-09 16:30:00	2021-03-09 17:30:00	\N	\N	1	0	\N	\N
534287	MISSION	AUCUNE	\N	PAUP	\N	Auditions plénières	\N	2021-03-02 14:30:00	2021-03-02 18:30:00	2021-03-17 16:54:53	2021-03-17 16:56:37	16	0	\N	\N
545300	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI "Difficultés des entreprises et crise de la Covid-19"	Audition rapporteur - MI "Difficultés des entreprises et crise de la Covid-19"	2021-03-25 09:00:00	2021-03-25 10:00:00	\N	\N	2	0	\N	\N
545303	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI "Difficultés des entreprises et crise de la Covid-19"	Audition rapporteur - MI "Difficultés des entreprises et crise de la Covid-19"	2021-03-25 10:00:00	2021-03-25 11:00:00	\N	\N	2	0	\N	\N
545306	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI "Difficultés des entreprises et crise de la Covid-19"	Audition rapporteur - MI "Difficultés des entreprises et crise de la Covid-19"	2021-03-25 11:00:00	2021-03-25 12:30:00	\N	\N	2	0	\N	\N
545309	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI "Difficultés des entreprises et crise de la Covid-19"	Audition rapporteur - MI "Difficultés des entreprises et crise de la Covid-19"	2021-03-25 15:00:00	2021-03-25 16:30:00	\N	\N	2	0	\N	\N
545312	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur	Audition rapporteur - M. Édouard Durand	2021-03-22 14:30:00	2021-03-22 15:30:00	\N	\N	1	0	\N	\N
559728	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2021-05-19 09:00:00	2021-05-19 11:00:00	2021-05-19 11:52:52	2021-05-19 15:31:22	40	0	\N	\N
559729	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PPL Irresponsabilité pénale (AFFSOC) - Examen du rapport pour avis	\N	2021-05-18 13:30:00	2021-05-18 14:15:00	2021-05-18 14:55:20	2021-05-18 18:31:28	26	0	\N	\N
559730	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Soins palliatifs - Audition du CNSPFV	\N	2021-05-11 14:30:00	2021-05-11 16:00:00	\N	\N	5	0	\N	\N
559736	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Innovation en santé - Table ronde de pôles de compétitivité en santé	\N	2021-05-10 14:30:00	2021-05-10 15:40:00	\N	\N	3	0	\N	\N
559737	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Innovation en santé - Table ronde sur l'écosystème de la recherche	\N	2021-05-10 15:45:00	2021-05-10 17:45:00	\N	\N	3	0	\N	\N
559744	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Négociation collective - Table ronde de conseillers sociaux des ambassades de France	\N	2021-05-12 13:00:00	2021-05-12 14:30:00	\N	\N	1	0	\N	\N
559746	ETUDES	AUTRE	\N	\N	\N	Audition de l'entreprise AAA	\N	2021-05-12 14:00:00	2021-05-12 15:00:00	\N	\N	5	0	\N	1004
560305	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Bertrand Cochery, ambassadeur de France au Tchad	Entretien avec M. Bertrand Cochery, ambassadeur de France au Tchad	2021-05-18 16:05:00	2021-05-18 17:00:00	\N	\N	3	0	572	\N
564096	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Nommer les enfants nés sans vie	Audition rapporteur - PPL nommer les enfants nés sans vie	2021-05-26 16:30:00	2021-05-26 17:30:00	\N	\N	2	0	\N	\N
564102	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Nommer les enfants nés sans vie	Audition rapporteur - PPL nommer les enfants nés sans vie	2021-05-27 08:30:00	2021-05-27 09:15:00	\N	\N	1	0	\N	\N
564259	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Les enjeux stratégiques du spatial	\N	2021-06-02 10:05:00	2021-06-02 11:55:00	2021-06-02 14:40:46	2021-06-02 18:41:04	27	0	\N	\N
564346	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Actualisation LPM	\N	2021-05-26 13:45:00	2021-05-26 15:00:00	\N	\N	3	0	\N	\N
564350	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Actualisation LPM	\N	2021-05-26 16:30:00	2021-05-26 19:15:00	\N	\N	2	0	\N	\N
565991	MISSION	AUCUNE	\N	VIETUDIA	\N	Visite site universitaire Nanterre	\N	2021-06-03 13:30:00	2021-06-03 17:30:00	\N	\N	3	0	\N	\N
565993	MISSION	AUDRAP	\N	VIETUDIA	\N	Audition "Prostitution dans le monde étudiant"	\N	2021-06-07 15:35:00	2021-06-07 17:20:00	\N	\N	9	0	\N	\N
565994	MISSION	AUDRAP	\N	VIETUDIA	\N	Audition Brémond Gignac	\N	2021-06-07 14:30:00	2021-06-07 15:17:00	\N	\N	4	0	\N	\N
566014	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion 20210609a	\N	2021-06-09 09:00:00	2021-06-09 09:20:00	2021-06-09 10:53:39	2021-06-09 12:27:31	24	0	\N	\N
566016	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion 20210609c	\N	2021-06-09 09:30:00	2021-06-09 10:30:00	2021-06-09 10:56:59	2021-06-09 12:27:29	33	0	\N	\N
566017	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion 20210609d	\N	2021-06-09 18:00:00	2021-06-09 19:10:00	2021-06-09 19:15:02	2021-06-10 11:57:00	17	0	\N	\N
566018	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Réunion 20210610	\N	2021-06-10 09:35:00	2021-06-10 12:00:00	2021-06-10 17:49:22	2021-06-10 18:07:58	14	0	\N	\N
566124	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Présanse	\N	2021-06-08 15:00:00	2021-06-08 16:00:00	\N	\N	2	0	\N	\N
603153	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2022	PLF pour 2022	2021-11-18 15:00:00	2021-11-18 19:35:00	\N	\N	80	0	\N	\N
603155	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2022	PLF pour 2022	2021-11-19 16:00:00	2021-11-19 19:55:00	\N	\N	46	0	\N	\N
603156	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF pour 2022	PLF pour 2022	2021-11-19 21:30:00	2021-11-20 01:20:00	\N	\N	45	0	\N	\N
603164	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Collectivité européenne d'Alsace	PJL Collectivité européenne d'Alsace	2021-11-16 21:30:00	2021-11-17 00:00:00	\N	\N	36	0	\N	\N
603379	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2021-11-12 20:00:00	2021-11-12 20:10:00	2021-11-12 20:14:38	2021-11-15 15:22:12	19	0	\N	\N
601478	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Test Kairos	\N	2013-11-09 10:00:00	2013-11-09 12:20:00	\N	\N	0	0	\N	\N
605761	GIA	AUCUNE	\N	\N	\N	Entretien avec le ministre de l'éducation de PNG	Entretien avec M. Jimmy Uguro, ministre de l'éducation de Papouasie-Nouvelle-Guinée	2021-11-17 14:00:00	2021-11-17 15:00:00	\N	\N	4	0	651	\N
606225	DELEGATION	AUCUNE	\N	\N	PROS	Audition de Mme Amélie de Montchalin	\N	2021-11-25 08:05:00	2021-11-25 09:15:00	\N	\N	8	0	\N	\N
606233	MISSION	AUCUNE	\N	CONF	\N	Conférence de presse	\N	2021-11-18 11:30:00	2021-11-18 12:15:00	2021-11-18 12:19:53	2021-11-22 11:17:56	3	0	\N	\N
606261	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2021-11-23 09:30:00	2021-11-23 10:40:00	2021-11-23 10:42:24	2021-11-23 17:19:42	24	0	\N	\N
606262	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PLF pour 2022 - Audition de Mme Élisabeth Borne 	\N	2021-11-23 17:56:00	2021-11-23 19:20:00	2021-11-23 19:23:40	2021-11-24 16:38:28	23	0	\N	\N
606278	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2021-11-25 11:00:00	2021-11-25 11:20:00	2021-11-25 11:22:56	2021-11-25 17:02:15	15	0	\N	\N
606363	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2021-11-18 09:00:00	2021-11-18 10:30:00	\N	\N	2	0	\N	\N
606366	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2021-11-18 09:00:00	2021-11-18 12:30:00	\N	\N	3	0	\N	\N
606382	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2022 - Programme 152	PLF pour 2022 - Programme 152	2021-11-15 16:30:00	2021-11-15 17:30:00	\N	\N	2	0	\N	\N
606387	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2022 - Programmes 110 et 209	PLF pour 2022 - Programmes 110 et 209	2021-11-16 16:15:00	2021-11-16 17:00:00	\N	\N	2	0	\N	\N
606392	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	PLF 2022 - Programme 144	PLF 2022 - Programme 144	2021-11-16 15:00:00	2021-11-16 19:30:00	\N	\N	1	0	\N	\N
606404	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PLF pour 2022 (avis)	PLF pour 2022 (avis)	2021-11-23 09:00:00	2021-11-23 09:45:00	2021-11-23 09:52:35	2021-11-23 17:19:42	15	0	\N	\N
606411	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	Réunion du GT subsidiarité	Réunion du GT subsidiarité	2021-10-20 14:15:00	2021-10-20 14:45:00	\N	\N	7	0	\N	\N
606420	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Commémoration de la répression d'Algériens le 17 octobre 1961	Audition rapporteur - PPL Commémoration de la répression d'Algériens le 17 octobre 1961	2021-11-17 14:30:00	2021-11-17 15:30:00	\N	\N	1	0	\N	\N
606608	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Météo France	Météo France	2021-11-16 18:00:00	2021-11-16 18:50:00	\N	\N	1	0	\N	\N
606640	COM_PERMANENTE	AUDRAP	\N	CDD	\N	OFB - Visio	OFB - Visio	2021-11-15 15:35:00	2021-11-15 16:20:00	\N	\N	1	0	\N	\N
606651	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Parcs nationaux de France	Parcs nationaux de France	2021-11-18 11:05:00	2021-11-18 11:55:00	\N	\N	1	0	\N	\N
606761	COM_EURO	AUDRAP	\N	AFEU	\N	Audition M. Hilaire Multon	\N	2021-11-22 17:15:00	2021-11-22 18:00:00	\N	\N	1	0	\N	\N
606763	COM_EURO	AUDRAP	\N	AFEU	\N	Audition de Mme Gatel et M. Mazurier	\N	2021-11-22 14:00:00	2021-11-22 15:00:00	\N	\N	1	0	\N	\N
606768	COM_EURO	AUDRAP	\N	AFEU	\N	Audition de M. Damian Collins, Member of Parliament	\N	2021-11-22 15:00:00	2021-11-22 16:30:00	\N	\N	2	0	\N	\N
606777	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition de Mme Descamps - PPL enfants atteints de pathologie chronique ou de cancer	\N	2021-11-23 14:00:00	2021-11-23 16:00:00	\N	\N	1	0	\N	\N
606780	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition DGT - DGESCO	\N	2021-11-24 14:00:00	2021-11-24 15:00:00	\N	\N	1	0	\N	\N
606798	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition associations soutien aux familles	\N	2021-11-24 16:30:00	2021-11-24 18:10:00	\N	\N	2	0	\N	\N
606808	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2022 - Examen d'un amendement de séance à l'article d'équilibre	PLF pour 2022 - Examen d'un amendement de séance à l'article d'équilibre	2021-11-23 14:20:00	2021-11-23 14:25:00	2021-11-23 14:56:50	2021-11-23 17:19:43	27	0	\N	\N
606809	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Réunion constitutive de la CE Cabinets de conseil	\N	2021-11-25 09:30:00	2021-11-25 10:30:00	\N	\N	0	0	\N	\N
606862	GIA	AUCUNE	\N	\N	\N	Conférence "Napoléon et l'Europe d'aujourd'hui"	Conférence "Napoléon et l'Europe d'aujourd'hui" - association Triangle de Weimar	2021-11-22 19:00:00	2021-11-22 20:30:00	\N	\N	1	0	600	\N
607180	COM_ENQUETE	PLENIERE	\N	CABINETS	\N	Réunion constitutive de la commission d'enquête sur l'influence des cabinets de conseil	Réunion constitutive de la commission d'enquête sur l'influence croissante des cabinets de conseil privés	2021-11-25 09:30:00	2021-11-25 09:50:00	2021-11-25 10:24:07	2021-11-25 17:02:30	11	0	\N	\N
607209	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	NL PLFR 2021	NL PLFR 2021	2021-11-24 16:30:00	2021-11-24 17:40:00	\N	\N	49	0	\N	\N
607210	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Haut Conseil finances publiques	CMP Haut Conseil finances publiques	2021-11-24 17:40:00	2021-11-24 18:40:00	\N	\N	42	0	\N	\N
607211	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Directeur école	CMP Directeur école	2021-11-25 11:00:00	2021-11-25 11:50:00	\N	\N	38	0	\N	\N
607212	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	NL PLFSS 2022	NL PLFSS 2022	2021-11-25 14:30:00	2021-11-25 15:45:00	\N	\N	34	0	\N	\N
607213	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2021-11-24 15:00:00	2021-11-24 16:15:00	\N	\N	269	0	\N	\N
607227	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Retraites agricoles - Table ronde syndicats agricoles	\N	2021-11-23 14:45:00	2021-11-23 16:00:00	\N	\N	4	0	\N	\N
607329	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Nouveau pacte de citoyenneté avec la jeunesse	PPL Nouveau pacte de citoyenneté avec la jeunesse	2021-11-23 18:00:00	2021-11-23 19:25:00	\N	\N	2	0	\N	\N
607383	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Commémoration de la répression d'Algériens le 17 octobre 1961	Audition rapporteur - PPL Commémoration de la répression d'Algériens le 17 octobre 1961	2021-11-24 08:30:00	2021-11-24 09:30:00	\N	\N	1	0	\N	\N
602242	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2022 - Avis justice judiciaire et accès au droit	PLF pour 2022 - Avis justice judiciaire et accès au droit	2021-11-10 09:00:00	2021-11-10 10:00:00	\N	\N	2	0	\N	\N
606402	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2021-11-24 09:30:00	2021-11-24 11:10:00	2021-11-24 16:13:39	2021-11-24 16:38:26	34	1	\N	\N
606407	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désignation MI Chasse -  PLF pour 2022 (avis)	Désignation MI Chasse -  PLF pour 2022 (avis)	2021-11-24 08:30:00	2021-11-24 10:45:00	2021-11-29 10:31:41	2021-11-29 10:41:32	32	0	\N	\N
511202	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur sur la stratégie de l'Union de la sécurité 2020-2025	\N	2020-11-30 14:00:00	2020-11-30 15:30:00	\N	\N	2	0	\N	\N
511256	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL REEN - Auditions	\N	2020-11-30 17:30:00	2020-11-30 19:00:00	\N	\N	1	0	\N	\N
511261	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Rapporteur - nouveau Pacte migration et asile	\N	2020-12-01 15:30:00	2020-12-01 16:45:00	\N	\N	2	0	\N	\N
517467	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Nominations, Rapport d'information Restitutions des oeuvres d'art	\N	2020-12-16 09:30:00	2020-12-16 10:50:00	2020-12-16 13:01:47	2020-12-16 18:00:30	32	0	\N	\N
526288	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition GT Agriculteurs en détresse	Audition GT Agriculteurs en détresse	2021-01-27 16:30:00	2021-01-27 17:30:00	\N	\N	11	0	\N	\N
526317	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2021-01-28 08:15:00	2021-01-28 12:30:00	\N	\N	7	0	\N	\N
526359	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	\tCommission spéciale chargée du contrôle des comptes et de l'évaluation interne 	\tCommission spéciale chargée du contrôle des comptes et de l'évaluation interne 	2021-01-27 16:30:00	2021-01-27 17:30:00	2021-01-28 15:11:58	2021-01-28 18:29:04	7	0	\N	\N
527046	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI Patrimoine	\N	2021-02-02 14:00:00	2021-02-02 17:15:00	\N	\N	2	0	\N	\N
534186	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe d'amitié France-Slovénie	Assemblée générale du groupe d'amitié France-Slovénie	2020-12-08 14:15:00	2020-12-08 14:45:00	\N	\N	2	0	529	\N
539548	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Sécurité globale	PPL Sécurité globale	2021-03-16 14:30:00	2021-03-16 20:00:00	\N	\N	199	0	\N	\N
539549	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Sécurité globale	PPL Sécurité globale	2021-03-16 21:30:00	2021-03-17 00:30:00	\N	\N	119	0	\N	\N
539550	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2021-03-17 15:00:00	2021-03-17 16:30:00	\N	\N	208	0	\N	\N
539551	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Sécurité globale	PPL Sécurité globale	2021-03-17 16:40:00	2021-03-17 20:00:00	\N	\N	125	0	\N	\N
539552	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Sécurité globale	PPL Sécurité globale	2021-03-17 21:30:00	2021-03-18 00:45:00	\N	\N	83	0	\N	\N
539553	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Sécurité globale	PPL Sécurité globale	2021-03-18 10:30:00	2021-03-18 13:05:00	\N	\N	97	0	\N	\N
539554	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Sécurité globale	PPL Sécurité globale	2021-03-18 14:35:00	2021-03-18 19:20:00	\N	\N	88	0	\N	\N
543058	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur PPL Protéger les mineurs des crimes et délits sexuels et de l'inceste	Audition rapporteur	2021-03-19 15:30:00	2021-03-19 17:00:00	\N	\N	1	0	\N	\N
543060	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur PPL Protéger les mineurs des crimes et délits sexuels et de l'inceste	Audition rapporteur	2021-03-19 18:15:00	2021-03-19 19:00:00	\N	\N	2	0	\N	\N
557583	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2021-05-05 17:30:00	2021-05-05 19:00:00	\N	\N	6	0	\N	\N
564649	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Nommer les enfants nés sans vie	Audition rapporteur - PPL nommer les enfants nés sans vie	2021-06-01 14:30:00	2021-06-01 15:00:00	\N	\N	1	0	\N	\N
568266	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Haut Karabakh	\N	2021-06-08 15:00:00	2021-06-08 16:00:00	\N	\N	4	0	\N	\N
568271	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Haut Karabakh	\N	2021-06-09 13:45:00	2021-06-09 14:45:00	\N	\N	4	0	\N	\N
570587	DELEGATION	AUDRAP	\N	\N	206	OPECST-Audition de M. Alain Fischer	OPECST-Audition de M. Alain Fischer sur la vaccination des adolescents et des enfants	2021-06-17 09:10:00	2021-06-17 10:00:00	\N	\N	8	0	\N	\N
585980	GIA	AUCUNE	\N	\N	\N	GIA - Entretien avec Mme Elina Valtonen	GIA - Entretien avec Mme Elina Valtonen	2021-09-22 15:55:00	2021-09-22 16:30:00	\N	\N	1	0	640	\N
589586	GIA	AUCUNE	\N	\N	\N	Réunion du bureau	Réunion du bureau du groupe d'amitié	2021-10-06 08:30:00	2021-10-06 09:30:00	\N	\N	6	0	641	\N
601096	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS pour 2022	PLFSS pour 2022	2021-11-08 16:00:00	2021-11-08 19:45:00	\N	\N	56	0	\N	\N
601097	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS pour 2022	PLFSS pour 2022	2021-11-08 21:45:00	2021-11-10 01:25:00	\N	\N	50	0	\N	\N
601098	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS pour 2022	PLFSS pour 2022	2021-11-09 14:30:00	2021-11-09 19:40:00	\N	\N	144	0	\N	\N
601099	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS pour 2022	PLFSS pour 2022	2021-11-09 21:30:00	2021-11-10 01:30:00	\N	\N	92	0	\N	\N
601100	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2021-11-10 15:00:00	2021-11-10 16:15:00	\N	\N	262	0	\N	\N
601102	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS pour 2022	PLFSS pour 2022	2021-11-10 16:35:00	2021-11-10 17:45:00	\N	\N	57	0	\N	\N
601103	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS pour 2022	PLFSS pour 2022	2021-11-12 09:30:00	2021-11-12 13:10:00	\N	\N	54	0	\N	\N
601104	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS pour 2022	PLFSS pour 2022	2021-11-12 14:45:00	2021-11-12 20:00:00	\N	\N	56	0	\N	\N
601105	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS pour 2022	PLFSS pour 2022	2021-11-12 21:30:00	2021-11-13 00:00:00	\N	\N	36	0	\N	\N
601108	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition1 de Mme France Haugen	\N	2021-11-10 16:30:00	2021-11-10 18:00:00	2021-11-15 15:07:10	2021-11-15 15:22:11	25	0	\N	\N
601115	DELEGATION	AUDRAP	\N	\N	206	Audition de rapporteur	\N	2021-11-04 15:00:00	2021-11-04 16:00:00	\N	\N	1	0	\N	\N
601117	DELEGATION	AUDRAP	\N	\N	206	Audition de rapporteur	\N	2021-11-04 16:00:00	2021-11-04 17:20:00	\N	\N	1	0	\N	\N
601129	DELEGATION	AUCUNE	\N	\N	211	Table ronde sur la situation des femmes et des filles en Afghanistan.	Table ronde sur la situation des femmes et des filles en Afghanistan.	2021-11-25 08:30:00	2021-11-25 12:00:00	2021-11-25 11:58:51	\N	11	0	\N	\N
601134	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2022 Anciens combattants - Audition de Mme Darrieussecq	\N	2021-11-03 16:30:00	2021-11-03 18:00:00	\N	\N	2	0	\N	\N
601135	ETUDES	AUTRE	\N	\N	\N	Audition de Mme Geneviève Darrieussecq	\N	2021-11-03 16:30:00	2021-11-03 18:00:00	\N	\N	12	0	\N	928
602245	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2022 - Avis "sécurités"	PLF pour 2022 - Avis "sécurités"	2021-11-09 10:00:00	2021-11-09 11:00:00	\N	\N	2	0	\N	\N
602248	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2022 - Avis "sécurités"	PLF pour 2022 - Avis "sécurités"	2021-11-09 11:00:00	2021-11-09 11:45:00	\N	\N	1	0	\N	\N
602250	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2022 - Avis "sécurités"	PLF pour 2022 - Avis "sécurités"	2021-11-09 18:00:00	2021-11-09 18:45:00	\N	\N	1	0	\N	\N
602252	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2022 - Avis "sécurités"	PLF pour 2022 - Avis "sécurités"	2021-11-15 17:00:00	2021-11-15 18:00:00	\N	\N	1	0	\N	\N
603126	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2022 - Programme 185	\N	2021-11-10 09:30:00	2021-11-10 11:30:00	\N	\N	2	0	\N	\N
603136	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF 2022 Avis Politique des territoires - Audition ANCT	PLF 2022 Avis Politique des territoires - Audition ANCT	2021-11-09 17:00:00	2021-11-09 17:45:00	\N	\N	1	0	\N	\N
603163	ETUDES	AUCUNE	\N	\N	\N	Audition Commission européenne - DG environnement	Audition Commission européenne - DG Environnement	2021-11-10 13:45:00	2021-11-10 15:00:00	\N	\N	10	0	\N	948
603191	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Tourisme - Audition Parcs à thème	GT Tourisme - Audition Parcs à thème	2021-11-10 13:30:00	2021-11-10 15:00:00	\N	\N	6	0	\N	\N
603249	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Déplacement à Evreux	Déplacement à Evreux	2021-11-10 07:00:00	2021-11-10 15:30:00	\N	\N	11	0	\N	\N
587241	ETUDES	AUCUNE	\N	\N	\N	Audition SEFB	Audition SEFB	2021-09-28 16:00:00	2021-09-28 17:30:00	\N	\N	14	0	\N	948
587278	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Droit de visite pour les malades en établissements	\N	2021-09-28 17:00:00	2021-09-28 17:45:00	\N	\N	3	0	\N	\N
587285	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Droit de visite pour les malades en établissements	\N	2021-09-28 18:00:00	2021-09-28 19:00:00	\N	\N	1	0	\N	\N
613106	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Audition préparatoire au déplacement ONU	\N	2021-12-08 17:00:00	2021-12-08 18:30:00	\N	\N	3	0	\N	\N
613120	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2021-12-15 09:30:00	2021-12-15 11:18:00	2021-12-15 17:52:46	2021-12-16 17:03:49	31	2	\N	\N
622471	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Fonction publique des communes de Polynésie française	\N	2022-01-19 08:00:00	2022-01-19 08:45:00	\N	\N	1	0	\N	\N
622476	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Fonction publique des communes de Polynésie française	\N	2022-01-19 08:45:00	2022-01-19 09:30:00	\N	\N	2	0	\N	\N
623421	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen rapport PJL 350 Outils de gestion des risques climatiques en agriculture	Examen rapport PJL 350 Outils de gestion des risques climatiques en agriculture	2022-01-25 17:35:00	2022-01-25 18:35:00	2022-01-25 19:05:38	2022-01-26 14:25:07	31	0	\N	\N
623502	COM_PERMANENTE	AUTRE	\N	FINC	\N	Contrôles Financement organisations internationales-58-2 Transformation numérique justice	Contrôles Financement organisations internationales et 58-2 Transformation numérique de la justice	2022-01-26 09:30:00	2022-01-26 12:00:00	2022-01-26 12:44:32	2022-01-26 14:25:10	39	0	\N	\N
623594	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-01-20 10:20:00	2022-01-20 10:25:00	2022-01-20 10:42:40	2022-01-20 11:34:57	17	0	\N	\N
623816	DELEGATION	AUCUNE	\N	\N	206	Neurotechnologies / Stratégie quantique de la France 	\N	2022-01-20 09:00:00	2022-01-20 10:30:00	\N	\N	11	0	\N	\N
623820	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Directive salaires minimaux - RP Hongrie 	Audition Directive salaires minimaux - RP Hongrie - S.E.M. Gabor Baranay, Ambassadeur	2022-01-20 10:00:00	2022-01-20 11:00:00	\N	\N	2	0	\N	\N
623833	COM_EURO	AUDRAP	\N	AFEU	\N	Audition - Directive salaires minimaux - RP Danemark 	Audition - Directive salaires minimaux - RP Danemark - S.E.M. Per Fabricius Andersen, Ambassadeur	2022-01-20 11:50:00	2022-01-20 12:30:00	\N	\N	2	0	\N	\N
623834	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Directive Salaires Minimaux M. Satouri, Député européen	\N	2022-01-26 14:00:00	2022-01-26 14:45:00	\N	\N	2	0	\N	\N
623835	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Directive salaires minimaux Mme Sander, Députée européen	\N	2022-01-26 16:15:00	2022-01-26 17:15:00	\N	\N	0	0	\N	\N
623836	COM_ENQUETE	AUDRAP	\N	CABINETS	\N	Audition rapporteure - M. Papinutti, DGITM - M. Archer, Cylad consulting	Audition rapporteure - M. Papinutti, DGITM - M. Archer, Cylad consulting	2022-01-20 10:45:00	2022-01-20 12:10:00	\N	\N	7	0	\N	\N
623858	MISSION	AUCUNE	\N	CULTURE	\N	Réunion 20220120	\N	2022-01-20 11:30:00	2022-01-20 12:45:00	2022-01-20 12:47:19	2022-01-24 15:30:22	6	0	\N	\N
624148	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2022-01-25 09:30:00	2022-01-25 12:40:00	\N	\N	49	0	\N	\N
624149	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat sur les agences de l'eau	Débat sur les agences de l'eau	2022-01-25 14:30:00	2022-01-25 16:20:00	\N	\N	101	0	\N	\N
624150	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Reconnaissance des harkis	PJL Reconnaissance des harkis	2022-01-25 16:25:00	2022-01-25 19:55:00	\N	\N	144	0	\N	\N
624151	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Reconnaissance des harkis	PJL Reconnaissance des harkis	2022-01-25 21:30:00	2022-01-26 00:00:00	\N	\N	58	0	\N	\N
624154	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PJL Travailleurs indépendants	CMP PJL Travailleurs indépendants	2022-01-26 16:40:00	2022-01-26 17:40:00	\N	\N	48	0	\N	\N
624155	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Assurance emprunteur	PPL Assurance emprunteur	2022-01-26 17:40:00	2022-01-26 19:55:00	\N	\N	78	0	\N	\N
624156	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Assureur emprunteur	PPL Assureur emprunteur	2022-01-26 21:30:00	2022-01-26 22:55:00	\N	\N	46	0	\N	\N
624158	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	NL PPL Réformer l'adoption	NL PPL Réformer l'adoption	2022-01-26 22:55:00	2022-01-27 00:40:00	\N	\N	32	0	\N	\N
624159	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Harcèlement scolaire	PPL Harcèlement scolaire	2022-01-27 10:30:00	2022-01-27 13:30:00	\N	\N	57	0	\N	\N
624168	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Gouvernance  AEFE	PPL Gouvernance  AEFE	2022-01-27 15:00:00	2022-01-27 18:20:00	\N	\N	47	0	\N	\N
624169	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Harcèlement scolaire	PPL Harcèlement scolaire	2022-01-27 18:20:00	2022-01-27 19:05:00	\N	\N	20	0	\N	\N
625008	GIA	AUCUNE	\N	\N	\N	Audition de Jean-Robert Pitte	\N	2022-01-25 14:15:00	2022-01-25 15:30:00	\N	\N	9	0	629	\N
625263	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 25 janvier 2022 - 17H30	Réunion du 25 janvier 2022 - 17H30	2022-01-25 17:35:00	2022-01-25 19:00:00	2022-01-26 16:01:57	2022-01-26 16:45:37	42	0	\N	\N
625815	COM_PERMANENTE	AUDRAP	\N	CDD	\N	MI Aménagement du territoire - Auditions Mme Patricia Demas	MI Aménagement du territoire - Auditions Mme Patricia Demas	2022-01-25 15:30:00	2022-01-25 16:30:00	\N	\N	1	0	\N	\N
625819	COM_PERMANENTE	AUDRAP	\N	CDD	\N	MI Aménagement du territoire - Auditions Mme Patricia Demas	MI Aménagement du territoire - Auditions Mme Patricia Demas	2022-01-25 17:30:00	2022-01-25 18:30:00	\N	\N	1	0	\N	\N
625847	COM_PERMANENTE	AUDRAP	\N	CDD	\N	MI Aménagement du territoire - Audition Mmes Filleul et Herzog	MI Aménagement du territoire - Audition Mmes Filleul et Herzog	2022-01-25 14:30:00	2022-01-25 16:45:00	\N	\N	2	0	\N	\N
627077	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLO Élection présidentielle dans le contexte lié à l'épidémie de covid-19	Audition rapporteur - PPLO Élection présidentielle dans le contexte lié à l'épidémie de covid-19	2022-01-31 16:00:00	2022-01-31 17:15:00	\N	\N	1	0	\N	\N
627079	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2022-01-19 16:30:00	2022-01-19 17:00:00	\N	\N	19	0	\N	\N
629865	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	GT Climat	GT Climat	2022-02-08 14:40:00	2022-02-08 15:40:00	\N	\N	6	0	\N	\N
630439	ETUDES	AUCUNE	\N	\N	\N	Audition Paris mutuel urbain	Audition Paris mutuel urbain	2022-02-09 08:00:00	2022-02-09 09:10:00	\N	\N	3	0	\N	912
630700	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Emploi pour les chômeurs longue durée Réseaux de l'insertion par l'activité économique	\N	2022-02-08 18:00:00	2022-02-08 19:00:00	\N	\N	3	0	\N	\N
630812	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Emploi pour les chômeurs de longue durée - Audition TZCLD/ETCLD	\N	2022-02-09 13:30:00	2022-02-09 14:30:00	\N	\N	4	0	\N	\N
630825	COM_ENQUETE	PLENIERE	\N	HOPITAL	\N	Réunion plénière	\N	2022-02-14 17:05:00	2022-02-14 18:30:00	2022-02-14 18:29:36	2022-02-15 14:49:14	7	0	\N	\N
630830	COM_ENQUETE	PLENIERE	\N	HOPITAL	\N	Réunion plénière	\N	2022-02-16 16:30:00	2022-02-16 17:50:00	2022-02-16 17:52:07	2022-02-17 16:47:30	9	0	\N	\N
630831	COM_ENQUETE	PLENIERE	\N	HOPITAL	\N	Réunion plénière	\N	2022-02-17 10:30:00	2022-02-17 11:30:00	2022-02-17 11:30:42	2022-02-17 16:47:25	5	0	\N	\N
631111	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2022-02-16 09:05:00	2022-02-16 12:20:00	2022-02-16 15:46:47	2022-02-17 16:42:22	42	1	\N	\N
631112	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-02-16 18:00:00	2022-02-16 19:00:00	\N	\N	0	0	\N	\N
631139	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-02-17 14:30:00	2022-02-17 15:05:00	2022-02-17 19:40:29	2022-02-18 15:05:57	10	0	\N	\N
631185	ETUDES	AUTRE	\N	\N	\N	Audition Compagnie des Alpes	Audition Compagnie des Alpes	2022-02-09 13:50:00	2022-02-09 15:00:00	\N	\N	10	0	\N	918
631213	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition Rapport CPO -Contrôle budgétaire recherche patrimoniale et spectacle vivant	Audition sur le rapport du CPO et Contrôle budgétaire Financement recherche patrimoniale et Spectacle vivant	2022-02-16 09:35:00	2022-02-16 11:40:00	2022-02-16 11:54:43	2022-02-16 11:59:56	32	0	\N	\N
631228	MISSION	AUTRE	\N	SECUECO	\N	Table ronde sur le financement de la sécurité sociale	\N	2022-02-09 17:00:00	2022-02-09 18:30:00	2022-02-10 11:24:41	2022-02-10 18:00:49	4	0	\N	\N
631242	COM_ENQUETE	AUDRAP	\N	CABINETS	\N	Auditions rapporteure - TR associations haute fonction publique - France Stratégie	Auditions rapporteure - TR associations haute fonction publique - France Stratégie	2022-02-17 10:30:00	2022-02-17 12:50:00	\N	\N	6	0	\N	\N
631351	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Innovation en santé - Table ronde sur les données de santé	\N	2022-02-09 13:30:00	2022-02-09 14:30:00	\N	\N	3	0	\N	\N
507022	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2021 - Programme 185	\N	2020-11-23 16:00:00	2020-11-23 17:00:00	\N	\N	2	0	\N	\N
526552	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Santé environnementale - Audition commune de Santé publique France et de l'Anses	\N	2021-01-28 16:30:00	2021-01-28 17:45:00	\N	\N	2	0	\N	\N
526553	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Santé environnementale - Audition du Pr Isabelle Momas	\N	2021-01-28 15:30:00	2021-01-28 16:30:00	\N	\N	2	0	\N	\N
526559	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL n° 320 Diverses ordonnances covid-19 - Bpifrance/DG trésor et APE/CDC	PJL n° 320 Diverses ordonnances covid-19 - Bpifrance/DG trésor et APE/CDC	2021-01-27 14:00:00	2021-01-27 16:30:00	\N	\N	1	0	\N	\N
526563	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL n° 320 Diverses ordonnances covid-19 - ACPR	PJL n° 320 Diverses ordonnances covid-19 - ACPR	2021-01-27 18:00:00	2021-01-27 18:45:00	\N	\N	1	0	\N	\N
526633	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n° 312 Réforme courtage assurance - Planète CSCA	PPL n° 312 Réforme courtage assurance - Planète CSCA	2021-01-25 17:15:00	2021-01-25 18:15:00	\N	\N	1	0	\N	\N
526635	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n° 312 Réforme courtage assurance - DG Trésor "Assurances"	PPL n° 312 Réforme courtage assurance - DG Trésor "Assurances"	2021-01-26 09:30:00	2021-01-26 10:30:00	\N	\N	1	0	\N	\N
526637	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n° 312 Réforme courtage assurance - ANACOFI	PPL n° 312 Réforme courtage assurance - ANACOFI	2021-01-26 17:00:00	2021-01-26 18:00:00	\N	\N	1	0	\N	\N
526639	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n° 312 Réforme courtage assurance - ACPR	PPL n° 312 Réforme courtage assurance - ACPR	2021-01-27 15:00:00	2021-01-27 16:00:00	\N	\N	1	0	\N	\N
526641	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n° 312 Réforme courtage assurance - AMF	PPL n° 312 Réforme courtage assurance - AMF	2021-01-27 17:30:00	2021-01-27 18:30:00	\N	\N	1	0	\N	\N
526643	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n° 312 Réforme courtage assurance - ORIAS	PPL n° 312 Réforme courtage assurance - ORIAS	2021-01-28 18:30:00	2021-01-28 19:30:00	\N	\N	1	0	\N	\N
526691	COM_PERMANENTE	AUDRAP	\N	CAE	\N	RE 2020 - Coénove	RE 2020 - Coénove	2021-01-26 14:00:00	2021-01-26 14:45:00	\N	\N	1	0	\N	\N
526692	COM_PERMANENTE	AUDRAP	\N	CAE	\N	RE 2020 - Uniclima	RE 2020 - Uniclima	2021-01-26 14:45:00	2021-01-26 15:35:00	\N	\N	1	0	\N	\N
526693	COM_PERMANENTE	AUDRAP	\N	CAE	\N	RE 2020 - Professionnel du gaz	RE 2020 - Professionnel du gaz	2021-01-26 18:00:00	2021-01-26 18:45:00	\N	\N	2	0	\N	\N
526694	COM_PERMANENTE	AUDRAP	\N	CAE	\N	RE 2020 - Fedene	RE 2020 - Fedene	2021-01-26 16:35:00	2021-01-26 17:15:00	\N	\N	2	0	\N	\N
526695	COM_PERMANENTE	AUDRAP	\N	CAE	\N	RE 2020 - SER	RE 2020 - SER	2021-01-26 17:15:00	2021-01-26 18:00:00	\N	\N	2	0	\N	\N
526698	COM_PERMANENTE	AUDRAP	\N	CAE	\N	RE 2020 - CSCEE	RE 2020 - CSCEE	2021-01-27 16:00:00	2021-01-27 17:10:00	\N	\N	2	0	\N	\N
526699	COM_PERMANENTE	AUDRAP	\N	CAE	\N	USH-FPI	\N	2021-01-27 17:10:00	2021-01-27 18:00:00	\N	\N	2	0	\N	\N
526700	COM_PERMANENTE	AUDRAP	\N	CAE	\N	RE 2020 - DGEC / DHUP	RE 2020 - DGEC / DHUP	2021-01-27 18:00:00	2021-01-27 19:05:00	\N	\N	2	0	\N	\N
526703	COM_PERMANENTE	AUDRAP	\N	CAE	\N	RE 2020 - UFE	RE 2020 - UFE	2021-01-26 10:00:00	2021-01-26 10:45:00	\N	\N	2	0	\N	\N
531396	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI patrimoine culturel immatériel	\N	2021-02-09 15:00:00	2021-02-09 16:25:00	\N	\N	3	0	\N	\N
531400	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI patrimoine culturel immatériel	\N	2021-02-12 09:00:00	2021-02-12 10:45:00	\N	\N	2	0	\N	\N
531403	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI patrimoine culturel immatériel	\N	2021-02-12 10:45:00	2021-02-12 11:30:00	\N	\N	1	0	\N	\N
531405	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI patrimoine culturel immatériel	\N	2021-02-12 14:15:00	2021-02-12 15:45:00	\N	\N	2	0	\N	\N
544001	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Haut Karabakh	\N	2021-03-23 16:00:00	2021-03-23 18:30:00	\N	\N	2	0	\N	\N
545478	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition FNSafer	Audition FNSafer	2021-03-24 13:45:00	2021-03-24 15:00:00	\N	\N	6	0	\N	\N
545486	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition MEDEF -CPME	Audition MEDEF -CPME	2021-03-24 16:30:00	2021-03-24 17:30:00	\N	\N	2	0	\N	\N
545489	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition USH	Audition USH	2021-03-24 17:30:00	2021-03-24 18:45:00	\N	\N	2	0	\N	\N
545492	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition FCD-CNCC	Audition FCD-CNCC	2021-03-25 11:00:00	2021-03-25 12:15:00	\N	\N	4	0	\N	\N
549666	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de SE M. Junichi Ihara et de M. Joël Barre	\N	2021-04-07 09:30:00	2021-04-07 12:10:00	2021-04-07 17:31:05	2021-04-08 14:15:05	34	0	\N	\N
550096	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Situation et perspectives SNCF - GEODIS/APE	Contrôle 2021 - Situation et perspectives SNCF - GEODIS/APE	2021-04-06 08:30:00	2021-04-06 10:45:00	\N	\N	2	0	\N	\N
550108	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Financement aires protégées - RNF	Contrôle 2021 - Financement aires protégées - RNF	2021-04-06 08:45:00	2021-04-06 09:30:00	\N	\N	1	0	\N	\N
550132	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Agents publics de l'État et le système de retraite -  Retraites de l'État	Contrôle 2021 - Agents publics de l'État et le système de retraite -  Retraites de l'État	2021-04-06 17:30:00	2021-04-06 19:00:00	\N	\N	1	0	\N	\N
550134	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Agents publics de l'État et le système de retraite - IPP	Contrôle 2021 - Agents publics de l'État et le système de retraite - IPP	2021-04-06 15:00:00	2021-04-06 15:50:00	\N	\N	1	0	\N	\N
550138	COM_EURO	AUTRE	\N	AFEU	\N	réunion du 14 avril 2020	\N	2021-04-14 14:00:00	2021-04-14 14:35:00	2021-04-15 09:34:29	2021-04-15 11:59:04	14	0	\N	\N
550139	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 15 avril 2021	\N	2021-04-15 09:05:00	2021-04-15 10:50:00	2021-04-15 11:31:13	2021-04-15 11:59:04	10	0	\N	\N
550156	COM_PERMANENTE	AUDRAP	\N	CDD	\N	CCC - Groupe "produire et travailler"	\N	2021-04-07 14:00:00	2021-04-07 15:00:00	\N	\N	8	0	\N	\N
550473	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2021-04-14 09:30:00	2021-04-14 12:40:00	2021-04-14 12:40:13	2021-04-14 18:25:17	37	0	\N	\N
550481	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de M. Jean-Yves Le Drian	\N	2021-04-07 16:45:00	2021-04-07 18:45:00	2021-04-08 09:34:40	2021-04-08 14:15:07	24	0	\N	\N
550640	DELEGATION	AUDRAP	\N	\N	PROS	Auditions des auteurs de "La ville européenne au XXIème siècle"	Auditions des auteurs de "La ville européenne au XXIème siècle"	2021-04-13 16:30:00	2021-04-13 17:45:00	\N	\N	1	0	\N	\N
554889	GIA	AUCUNE	\N	\N	\N	Entretien avec le ministre des affaires étrangères du Monténégro	\N	2021-04-19 17:45:00	2021-04-19 19:45:00	\N	\N	5	0	674	\N
555382	COM_PERMANENTE	GROUPE_TRAVAIL	\N	ETRD	\N	GT Drones militaires	GT Drones militaires	2021-04-29 14:30:00	2021-04-29 15:45:00	\N	\N	4	0	\N	\N
557220	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	GT Enjeux internationaux - Climat - Environnement - Développement	gt Enjeux internationaux - Climat - Environnement - Développement	2021-05-05 13:45:00	2021-05-05 14:45:00	\N	\N	6	0	\N	\N
558019	DELEGATION	AUCUNE	\N	\N	COLTER	Audition de M. Bruno ACAR, inspecteur général de l'Administration	\N	2021-05-27 09:35:00	2021-05-27 11:05:00	\N	\N	11	0	\N	\N
558912	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 19 mai (conjointe aff euro, éco, étra)	\N	2021-05-19 16:40:00	2021-05-19 18:25:00	2021-05-19 18:31:02	2021-05-20 15:49:38	44	0	\N	\N
558964	MECSS	AUDRAP	\N	\N	MECSS	Audition réserves des régimes de retraite	\N	2021-05-11 15:00:00	2021-05-11 16:15:00	\N	\N	2	0	\N	\N
558969	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Lutte contre l'indépendance fictive	\N	2021-05-11 14:00:00	2021-05-11 15:30:00	\N	\N	1	0	\N	\N
558970	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Lutte contre l'indépendance fictive	\N	2021-05-11 15:30:00	2021-05-11 16:45:00	\N	\N	1	0	\N	\N
559008	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL 531 réponse solidaire dans la crise - Auteures PPL	PPL 531 réponse solidaire dans la crise - Auteures PPL	2021-05-11 16:00:00	2021-05-11 16:30:00	\N	\N	1	0	\N	\N
559011	ETUDES	AUTRE	\N	\N	\N	GEAC - Audition de la direction général de l'aviation civile	GEAC - Audition de la direction général de l'aviation civilesur l'actualité du secteur aérien	2021-05-26 13:30:00	2021-05-26 14:45:00	\N	\N	13	0	\N	933
559203	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Gestion de la sortie de crise sanitaire (rapport et texte de la commission)	PJL Gestion de la sortie de crise sanitaire (rapport et texte de la commission)	2021-05-17 17:10:00	2021-05-17 19:20:00	2021-05-17 19:57:42	2021-05-18 18:31:27	23	0	\N	\N
559204	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Gestion de la sortie de crise sanitaire (amendements de séance)	PJL Gestion de la sortie de crise sanitaire (amendements de séance)	2021-05-18 16:20:00	2021-05-18 16:55:00	2021-05-19 11:55:31	2021-05-19 15:31:23	23	0	\N	\N
607398	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Interdire les pratiques visant à modifier l'orientation sexuelle	Audition rapporteur - PPL Interdire les pratiques visant à modifier l'orientation sexuelle	2021-11-22 15:30:00	2021-11-22 16:30:00	\N	\N	1	0	\N	\N
607401	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Interdire les pratiques visant à modifier l'orientation sexuelle	Audition rapporteur - PPL Interdire les pratiques visant à modifier l'orientation sexuelle	2021-11-22 16:30:00	2021-11-22 17:30:00	\N	\N	2	0	\N	\N
607405	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Interdire les pratiques visant à modifier l'orientation sexuelle	Audition rapporteur - PPL Interdire les pratiques visant à modifier l'orientation sexuelle	2021-11-22 18:00:00	2021-11-22 19:40:00	\N	\N	1	0	\N	\N
608333	COM_ENQUETE	PLENIERE	\N	MEDIA	\N	CE concentration des médias	Commission d'enquête concentration des médias en France	2021-11-24 16:50:00	2021-11-24 17:20:00	2021-11-24 19:03:46	2021-11-25 17:02:29	15	0	\N	\N
608352	GIA	AUCUNE	\N	\N	\N	Petit-déjeuner de travail avec S. Exc. Mme Issamary SANCHEZ ORTEGA, ambassadrice du Panama	Petit-déjeuner de travail avec S. Exc. Mme Issamary SANCHEZ ORTEGA, ambassadrice du Panama en France	2021-11-24 08:30:00	2021-11-24 11:00:00	\N	\N	4	0	643	\N
608357	ETUDES	AUCUNE	\N	\N	\N	Réunion sur le thème de la lucrativité limitée	Réunion sur le thème de la lucrativité limitée	2021-11-24 08:30:00	2021-11-24 09:30:00	\N	\N	4	0	\N	998
608362	ETUDES	AUCUNE	\N	\N	\N	Réunion sur le thème "les perspectives de développement de la filière du nucléaire" 	Réunion sur le thème "les perspectives de développement de la filière du nucléaire" 	2021-11-24 08:00:00	2021-11-24 09:30:00	\N	\N	19	0	\N	906
608570	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Protection des lanceurs d'alerte PPLO Rôle du Défenseur des droits	\N	2021-11-23 16:00:00	2021-11-24 17:00:00	\N	\N	1	0	\N	\N
608660	DELEGATION	AUCUNE	\N	\N	DSOM	Audition de la FEDOM	\N	2021-11-30 16:30:00	2021-11-30 17:20:00	\N	\N	11	0	\N	\N
608661	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition Olivier Roussat -Bouygues	\N	2021-12-01 09:40:00	2021-12-01 11:30:00	2021-12-01 18:37:20	2021-12-03 18:37:21	71	0	\N	\N
608662	DELEGATION	AUCUNE	\N	\N	DSOM	Auditions "Place des outre-mer dans la stratégie nationale maritime"	\N	2021-12-02 09:30:00	2021-12-02 12:20:00	\N	\N	11	0	\N	\N
608663	COM_ENQUETE	PLENIERE	\N	MEDIA	\N	\N	\N	2021-11-30 15:05:00	2021-11-30 16:50:00	2021-11-30 17:06:51	2021-12-01 17:30:08	17	0	\N	\N
608664	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Auditio MM P. Louette et J-B Gourdin	\N	2021-12-02 14:30:00	2021-12-02 16:30:00	\N	\N	0	0	\N	\N
608672	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition "CumEx Files"	Audition "CumEx Files"	2021-12-01 10:35:00	2021-12-01 12:35:00	2021-12-01 13:00:29	2021-12-01 17:29:44	26	0	\N	\N
608674	GIA	AUCUNE	\N	\N	\N	Audition de Médecins du Monde et Première urgence internationale	Audition de Médecins du Monde et Première urgence internationale	2021-11-03 14:00:00	2021-11-03 15:00:00	\N	\N	5	0	632	\N
608680	GIA	AUCUNE	\N	\N	\N	Entretien avec une délégation du Riksdag suédois	Entretien avec une délégation du Riksdag suédois	2021-11-04 11:00:00	2021-11-04 12:00:00	\N	\N	1	0	625	\N
608682	GIA	AUCUNE	\N	\N	\N	Réception en l'honneur d'une délégation du Riksdag suédois	Réception en l'honneur d'une délégation du Riksdag suédois	2021-11-04 12:00:00	2021-11-04 14:30:00	\N	\N	5	0	625	\N
608688	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Interdire les pratiques visant à modifier l'orientation sexuelle	Audition rapporteur - PPL Interdire les pratiques visant à modifier l'orientation sexuelle	2021-11-25 10:00:00	2021-11-25 11:30:00	\N	\N	1	0	\N	\N
608690	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Interdire les pratiques visant à modifier l'orientation sexuelle	Audition rapporteur - PPL Interdire les pratiques visant à modifier l'orientation sexuelle	2021-11-26 10:00:00	2021-11-26 11:30:00	\N	\N	1	0	\N	\N
608692	DELEGATION	AUDRAP	\N	\N	206	Audition de rapporteur sur Science ouverte	\N	2021-11-24 16:30:00	2021-11-24 18:00:00	\N	\N	3	0	\N	\N
608696	DELEGATION	AUDRAP	\N	\N	206	Audition de rapporteur sur Science ouverte	\N	2021-11-26 10:15:00	2021-11-26 12:15:00	\N	\N	3	0	\N	\N
608705	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-12-08 09:33:00	2021-12-08 12:16:00	2021-12-08 12:30:14	2021-12-08 17:01:16	41	0	\N	\N
608706	GIA	AUCUNE	\N	\N	\N	Rencontre gouverneure adjointe Souleymanieh	Rencontre avec Mme Layla Omer, gouverneure adjointe de Souleymanih	2021-11-24 16:30:00	2021-11-24 17:30:00	\N	\N	2	0	615	\N
608709	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition M. Roussat (Bouygues) 	\N	2021-12-01 09:40:00	2021-12-01 11:10:00	2021-12-03 18:09:02	2021-12-03 18:37:21	71	0	\N	\N
608712	DELEGATION	AUTRE	\N	\N	DSOM	Réunion sur la différenciation territoriale	\N	2021-12-13 15:00:00	2021-12-13 16:30:00	\N	\N	9	0	\N	\N
608714	GIA	AUCUNE	\N	\N	\N	Audition de M. Monsieur Juan Francisco Espinosa Palacios	Audition de M. Monsieur Juan Francisco Espinosa Palacios, directeur de l'immigration de la Colombie	2021-11-30 10:30:00	2021-11-30 11:30:00	\N	\N	4	0	979	\N
608720	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Interdire les pratiques visant à modifier l'orientation sexuelle	Audition rapporteur - PPL Interdire les pratiques visant à modifier l'orientation sexuelle	2021-11-26 14:15:00	2021-11-26 16:00:00	\N	\N	1	0	\N	\N
608722	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Interdire les pratiques visant à modifier l'orientation sexuelle	Audition rapporteur - PPL Interdire les pratiques visant à modifier l'orientation sexuelle	2021-11-26 16:00:00	2021-11-26 17:00:00	\N	\N	2	0	\N	\N
608725	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Interdire les pratiques visant à modifier l'orientation sexuelle	Audition rapporteur - PPL Interdire les pratiques visant à modifier l'orientation sexuelle	2021-11-26 17:00:00	2021-11-26 19:15:00	\N	\N	1	0	\N	\N
609039	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI bilan des mesures 	\N	2021-11-23 14:00:00	2021-11-23 15:00:00	\N	\N	5	0	\N	\N
609285	MISSION	AUCUNE	\N	CULTURE	\N	\N	\N	2021-12-01 13:35:00	2021-12-01 14:05:00	2021-12-08 16:44:51	2021-12-08 17:07:16	11	1	\N	\N
609405	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Table ronde avec les Fédérations sportives olympiques	Table ronde des Fédérations sportives olympiques	2021-11-30 16:00:00	2021-11-30 17:30:00	\N	\N	3	0	\N	\N
609567	ETUDES	AUTRE	\N	\N	\N	Association française des équipages de vènerie sous terre	Association française des équipages de vènerie sous terre	2021-12-01 08:00:00	2021-12-01 09:00:00	\N	\N	20	0	\N	907
609930	GIA	AUCUNE	\N	\N	\N	Audition de Mgr Michel Aupetit, archevêque de Paris	Audition de Mgr Michel Aupetit, archevêque de Paris	2021-12-01 13:30:00	2021-12-01 14:45:00	\N	\N	8	0	629	\N
610487	ETUDES	AUTRE	\N	\N	\N	Audition FFE	Audition FFE	2021-12-01 13:30:00	2021-12-01 14:45:00	\N	\N	6	0	\N	912
610494	ETUDES	AUTRE	\N	\N	\N	Table ronde sur la stratégie de la Compagnie des Alpes	Table ronde sur la stratégie de la Compagnie des Alpes	2021-12-01 16:30:00	2021-12-01 17:40:00	\N	\N	10	0	\N	918
610495	MISSION	AUCUNE	\N	SECUECO	\N	Réunion Constitutive de la MI Sécurité sociale écologique	Réunion Constitutive de la MI Sécurité sociale écologique	2021-12-02 10:30:00	2021-12-02 10:55:00	2021-12-02 12:20:43	2021-12-03 18:39:19	6	0	\N	\N
610506	COM_ENQUETE	PLENIERE	\N	HOPITAL	\N	Réunion constitutive de la commission d'enquête Hôpital	\N	2021-12-02 11:30:00	2021-12-02 12:00:00	2021-12-02 16:27:28	2021-12-03 18:39:20	9	0	\N	\N
610523	ETUDES	AUDRAP	\N	\N	\N	Auditions M. Alain Cadec	Auditions M. Alain Cadec	2021-11-30 18:00:00	2021-11-30 20:00:00	\N	\N	2	0	\N	1012
610533	ETUDES	AUDRAP	\N	\N	\N	Auditions M. Alain CADEC	Auditions M. Alain Cadec	2021-12-01 08:30:00	2021-12-01 09:15:00	\N	\N	4	0	\N	1012
610536	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition Annick Girardin	\N	2021-12-09 10:30:00	2021-12-09 12:00:00	2021-12-10 09:59:39	2021-12-10 15:20:35	14	0	\N	\N
610541	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 7 décembre	\N	2021-12-07 14:00:00	2021-12-07 15:25:00	2021-12-07 15:26:37	2021-12-08 17:01:42	25	0	\N	\N
610542	ETUDES	AUDRAP	\N	\N	\N	Auditions M. Alain Cadec	Auditions M. Alain Cadec	2021-12-01 17:00:00	2021-12-01 18:00:00	\N	\N	1	0	\N	919
610544	DELEGATION	AUCUNE	\N	\N	COLTER	Réunion plénière : examen d'un rapport et auditions	Examen du rapport sur la cybersécurité et auditions relatives à la démocratie locale	2021-12-02 09:30:00	2021-12-02 12:00:00	2021-12-02 12:04:10	\N	12	0	\N	\N
505920	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJLF pour 2021 - p 146	\N	2020-11-18 14:00:00	2020-11-18 15:00:00	\N	\N	2	0	\N	\N
505921	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJLF pour 2021 - p 146	\N	2020-11-18 16:30:00	2020-11-18 18:30:00	\N	\N	2	0	\N	\N
505929	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJLF	\N	2020-11-19 08:00:00	2020-11-19 10:00:00	\N	\N	2	0	\N	\N
505957	DELEGATION	AUDRAP	\N	\N	206	Audition Phagothérapie - Hôpital Reine Astrid de Bruxelles	Audition Phagothérapie - Hôpital Reine Astrid de Bruxelles	2020-11-24 15:00:00	2020-11-24 16:00:00	\N	\N	1	0	\N	\N
505959	DELEGATION	AUDRAP	\N	\N	206	Audition Phagothérapie - Vaincre la mucoviscidose	Audition Phagothérapie - Vaincre la mucoviscidose	2020-11-24 16:00:00	2020-11-24 17:00:00	\N	\N	1	0	\N	\N
505970	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition PPL Empreinte environnementale du numérique	Audition PPL Empreinte environnementale du numérique	2020-11-19 12:10:00	2020-11-19 13:10:00	\N	\N	3	0	\N	\N
506028	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJLF pour 2020 - P 212	\N	2020-11-19 16:00:00	2020-11-19 18:00:00	\N	\N	2	0	\N	\N
506034	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Assemblée de Guyane	Audition rapporteur - PPL Assemblée de Guyane	2020-11-19 14:00:00	2020-11-19 14:10:00	\N	\N	1	0	\N	\N
608711	COM_PERMANENTE	AUTRE	\N	CAE	\N	PPRE Taxonomie européenne	\N	2021-12-01 11:15:00	2021-12-01 12:05:00	2021-12-03 18:07:31	2021-12-03 18:37:22	44	0	\N	\N
610534	COM_PERMANENTE	AUTRE	\N	CAE	\N	PPL ZRR (amendements de séance)	\N	2021-12-08 11:00:00	2021-12-08 11:30:00	2021-12-08 17:08:17	2021-12-09 15:58:03	45	1	\N	\N
514080	DELEGATION	AUCUNE	\N	\N	211	Audition de Mme Marie-Pierre Badré, présidente du centre Hubertine Auclert	Audition de Mme Marie-Pierre Badré, présidente du centre Hubertine Auclert	2020-12-17 09:00:00	2020-12-17 10:35:00	2020-12-17 12:29:30	\N	14	0	\N	\N
514129	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière - Pollution plastique - Exposome	Réunion plénière - Pollution plastique - Exposome	2020-12-10 09:05:00	2020-12-10 11:30:00	\N	\N	16	0	\N	\N
514130	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière - Audition publique MM. Rusch, Saout, Raymond	Réunion plénière - Audition publique MM. Rusch, Saout, Raymond	2020-12-11 12:30:00	2020-12-11 14:00:00	\N	\N	4	0	\N	\N
514194	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur 	Audition Rapporteur - nouveau Pacte migration et asile	2020-12-07 10:05:00	2020-12-07 11:40:00	\N	\N	2	0	\N	\N
514298	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur	Audition Rapporteur - nouveau Pacte migration et asile	2020-12-07 13:45:00	2020-12-07 15:40:00	\N	\N	2	0	\N	\N
516373	GIA	AUCUNE	\N	\N	\N	Assemblée générale du Groupe Interparlementaire d'Amitié France-Bulgarie	AG du Groupe France-Bulgarie	2020-12-10 13:00:00	2020-12-10 13:25:00	\N	\N	6	0	582	\N
516644	DELEGATION	AUDRAP	\N	\N	206	Audition Stratégie vaccinale - Table ronde FHF, Synerpa, Fehap	Audition Stratégie vaccinale - Table ronde FHF, Synerpa, Fehap	2020-12-10 16:30:00	2020-12-10 17:30:00	\N	\N	5	0	\N	\N
516652	DELEGATION	AUDRAP	\N	\N	206	Audition Stratégie vaccinale - LEEM	Audition Stratégie vaccinale - LEEM	2020-12-11 14:00:00	2020-12-11 15:00:00	\N	\N	5	0	\N	\N
516658	DELEGATION	AUDRAP	\N	\N	206	Audition Stratégie vaccinale - Delpharm	Audition Stratégie vaccinale - Delpharm	2020-12-11 15:00:00	2020-12-11 16:00:00	\N	\N	5	0	\N	\N
516664	DELEGATION	AUDRAP	\N	\N	206	Audition Stratégie vaccinale - AMF	Audition Stratégie vaccinale - AMF	2020-12-11 16:00:00	2020-12-11 17:30:00	\N	\N	5	0	\N	\N
516674	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe d'amitié France-Vanuatu-Iles du Pacifique 	Assemblée générale du groupe d'amitié France-Vanuatu-Iles du Pacifique 	2020-12-08 14:05:00	2020-12-08 14:40:00	\N	\N	7	0	651	\N
518635	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audition de M. Joachim BOKOBSA	\N	2020-12-17 11:30:00	2020-12-17 12:15:00	\N	\N	1	0	\N	\N
518673	GIA	AUCUNE	\N	\N	\N	Assemblée générale GIA France - Cambodge et Laos	Assemblée générale GIA France - Cambodge et Laos	2021-01-13 14:15:00	2021-01-13 14:45:00	\N	\N	7	0	577	\N
518915	DELEGATION	AUCUNE	\N	\N	DSOM	Audition du ministre des outre-mer	Audition du ministre des outre-mer	2021-01-14 09:30:00	2021-01-14 12:00:00	\N	\N	24	0	\N	\N
518916	DELEGATION	AUCUNE	\N	\N	DSOM	Auditions sur le logement outre-mer	Auditions de l'USH, d'Action logement et de l'USHOM	2021-01-28 09:00:00	2021-01-28 12:25:00	\N	\N	18	0	\N	\N
518927	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 13 janvier 2020	\N	2021-01-13 14:00:00	2021-01-13 15:00:00	2021-01-13 17:43:39	2021-01-14 16:26:06	23	0	\N	\N
518929	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 14 janvier 2020	\N	2021-01-14 09:00:00	2021-01-14 10:30:00	\N	\N	0	0	\N	\N
518930	COM_EURO	AUTRE	\N	AFEU	\N	Auditions de la commission des affaires européennes - Audition plénière	\N	2021-01-14 09:00:00	2021-01-14 10:25:00	2021-01-14 10:42:08	2021-01-14 16:26:06	14	0	\N	\N
521651	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Table ronde	\N	2021-01-28 09:30:00	2021-01-28 11:40:00	2021-01-28 15:42:26	\N	19	0	\N	\N
521656	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-01-27 09:00:00	2021-01-27 11:13:00	2021-01-27 16:21:58	2021-01-28 18:27:10	36	0	\N	\N
521657	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-01-27 11:16:00	2021-01-27 12:48:00	2021-01-27 16:22:07	2021-01-28 18:27:06	32	0	\N	\N
521875	ETUDES	AUTRE	\N	\N	\N	Réunion constitutive	\N	2021-01-19 15:00:00	2021-01-19 15:45:00	\N	\N	12	0	\N	922
522134	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur PPL RIST	Audition rapporteur PPL RIST	2021-01-19 17:00:00	2021-01-19 18:30:00	\N	\N	4	0	\N	\N
523670	GIA	AUCUNE	\N	\N	\N	Réunion constitutive et audition de S.E M. Alexeï MECHKOV, ambassadeur	Réunion constitutive et audition de S.E M. Alexeï MECHKOV, ambassadeur de la Fédération de Russie en France	2021-01-21 08:00:00	2021-01-21 09:30:00	\N	\N	10	0	608	\N
529201	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2021-02-02 14:40:00	2021-02-02 16:50:00	\N	\N	3	0	\N	\N
534270	GIA	AUCUNE	\N	\N	\N	 Entretien avec M. Bujar Osmani, ministre affaires étrangères Macédoine	Visite du ministre des affaires étrangères de Macédoine du Nord	2021-02-23 16:30:00	2021-02-23 17:50:00	\N	\N	4	0	674	\N
536314	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT subsi	Réunion du GT subsidiarité	2021-03-04 10:00:00	2021-03-04 10:20:00	\N	\N	7	0	\N	\N
536360	DELEGATION	AUCUNE	\N	\N	211	Table ronde sur l¿accès des femmes aux responsabilités dans les  territoires ruraux	Table ronde sur l¿accès des femmes aux responsabilités dans les  territoires ruraux	2021-03-04 08:30:00	2021-03-04 11:00:00	2021-03-04 11:49:38	\N	24	0	\N	\N
536864	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Respect principes de la République - Auditions	Professeurs - projet ANR Instruction en famille	2021-03-04 17:00:00	2021-03-04 18:00:00	\N	\N	11	0	\N	\N
536873	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Respect principes de la République - Auditions	Auditions Cabinet ministère sport + EN	2021-03-04 16:00:00	2021-03-04 17:00:00	\N	\N	12	0	\N	\N
547373	GIA	AUCUNE	\N	\N	\N	Audition de l'Ambassadeur de la République de Corée	\N	2021-03-31 15:00:00	2021-03-31 16:00:00	\N	\N	8	0	613	\N
547827	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	GT Enjeux internationaux Climat - Environnement - Développement	GT Enjeux internationaux Climat - Environnement - Développement	2021-03-31 16:30:00	2021-03-31 18:00:00	\N	\N	7	0	\N	\N
550125	ETUDES	AUCUNE	\N	\N	\N	Audition de M. Jean-Roch Gaillet	Audition de M. Jean-Roch Gaillet	2021-04-06 13:35:00	2021-04-06 14:40:00	\N	\N	6	0	\N	912
559649	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL développement solidaire et à la lutte contre les inégalités mondiales	PJL développement solidaire et à la lutte contre les inégalités mondiales	2021-05-17 16:00:00	2021-05-17 19:45:00	\N	\N	41	0	\N	\N
559650	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL développement solidaire et à la lutte contre les inégalités mondiales	PJL développement solidaire et à la lutte contre les inégalités mondiales	2021-05-17 21:30:00	2021-05-18 23:25:00	\N	\N	31	0	\N	\N
559651	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL gestion sortie crise sanitaire	PJL gestion de la sortie de crise sanitaire	2021-05-18 14:30:00	2021-05-18 20:25:00	\N	\N	167	0	\N	\N
559652	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL gestion sortie crise sanitaire	PJL gestion de la sortie de crise sanitaire	2021-05-18 22:00:00	2021-05-19 00:45:00	\N	\N	75	0	\N	\N
514131	COM_PERMANENTE	AUTRE	\N	AFCL	\N	PPL Langues régionales - PJL Biens culturels - Audition Michel Cadot	\N	2020-12-09 09:05:00	2020-12-09 12:12:00	2020-12-09 13:02:18	2020-12-09 17:15:39	39	0	\N	\N
559653	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2021-05-19 15:00:00	2021-05-19 16:25:00	\N	\N	205	0	\N	\N
614718	BUREAU	AUCUNE	\N	\N	\N	Bureau	Bureau	2021-12-15 08:00:00	2021-12-15 10:45:00	\N	\N	24	0	\N	\N
622455	COM_EURO	AUDRAP	\N	AFEU	\N	Paquet climat - Ajustement à l'objectif 55 - secteur énergie	Paquet climat - Ajustement à l'objectif 55 - secteur énergie	2022-01-18 17:00:00	2022-01-18 18:00:00	\N	\N	3	0	\N	\N
624178	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2022-01-20 07:30:00	2022-01-20 21:00:00	\N	\N	4	0	\N	\N
627933	MISSION	AUCUNE	\N	RECHINNO	\N	Audition plénière	Audition de M. Xavier JARAVEL, professeur d¿économie, membre du Conseil d¿analyse économique	2022-02-01 16:15:00	2022-02-01 17:10:00	2022-02-08 16:59:04	2022-02-08 17:02:23	7	0	\N	\N
629194	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	convention du Conseil de l¿Europe contre le trafic d¿organes humains	\N	2022-02-01 17:30:00	2022-02-01 18:30:00	\N	\N	1	0	\N	\N
629197	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL autorisant l¿Accord France-Qatar - Coupe du monde de football de 2022	\N	2022-02-01 15:00:00	2022-02-01 17:15:00	\N	\N	1	0	\N	\N
629340	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	biens spoliés	\N	2022-01-25 15:35:00	2022-01-25 16:05:00	\N	\N	3	0	\N	\N
629344	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	biens spoliés	\N	2022-01-25 16:05:00	2022-01-25 16:35:00	\N	\N	2	0	\N	\N
629347	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	biens spoliés	\N	2022-01-25 16:35:00	2022-01-25 17:05:00	\N	\N	1	0	\N	\N
629349	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	biens spoliés	\N	2022-01-25 17:05:00	2022-01-25 17:35:00	\N	\N	2	0	\N	\N
629352	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	biens spoliés	\N	2022-01-25 17:45:00	2022-01-25 18:30:00	\N	\N	2	0	\N	\N
629361	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	biens spoliés	\N	2022-02-01 17:45:00	2022-02-01 18:30:00	\N	\N	1	0	\N	\N
629366	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	biens spoliés	\N	2022-02-03 16:45:00	2022-02-03 17:20:00	\N	\N	1	0	\N	\N
629428	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Emploi pour les chômeurs de longue durée - Table ronde d'associations	\N	2022-02-08 09:00:00	2022-02-08 10:15:00	\N	\N	2	0	\N	\N
629431	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Fédération syndicale des familles monoparentales	\N	2022-02-08 16:45:00	2022-02-08 17:30:00	\N	\N	1	0	\N	\N
629432	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition DSS	\N	2022-02-08 17:30:00	2022-02-08 18:15:00	\N	\N	1	0	\N	\N
629433	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2022-02-16 09:03:00	2022-02-16 11:08:00	2022-02-16 11:31:31	2022-02-16 11:59:58	31	1	\N	\N
629594	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2022-02-16 16:30:00	2022-02-16 18:00:00	2022-02-16 18:34:24	2022-02-17 16:42:17	25	0	\N	\N
629679	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Emploi pour les chômeurs de longue durée - Audition de la DGFiP	\N	2022-02-08 14:00:00	2022-02-08 15:00:00	\N	\N	2	0	\N	\N
629680	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Emploi pour les chômeurs de longue durée - Audition de France Stratégie	\N	2022-02-08 15:00:00	2022-02-08 16:00:00	\N	\N	3	0	\N	\N
629957	COM_PERMANENTE	PEC_NON_MML	\N	CDD	\N	\N	\N	2022-02-09 09:00:00	2022-02-09 09:30:00	2022-02-09 17:17:27	2022-02-11 16:48:16	44	2	\N	\N
629958	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2022-02-09 09:30:00	2022-02-09 12:00:00	2022-02-09 17:18:41	2022-02-10 18:02:31	33	2	\N	\N
631689	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Innovation en santé - Table ronde Entreprises biopharmaceutiques	\N	2022-02-10 14:00:00	2022-02-10 15:15:00	\N	\N	2	0	\N	\N
631690	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Innovation en santé - Table ronde Oncologie pédiatrique	\N	2022-02-10 15:15:00	2022-02-10 16:30:00	\N	\N	4	0	\N	\N
631697	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Innovation en santé - Audition conjointe Cancers pédiatriques	\N	2022-02-10 11:30:00	2022-02-10 12:30:00	\N	\N	4	0	\N	\N
631702	COM_ENQUETE	PLENIERE	\N	MEDIA	\N	Auditions M. Gilles Pélisson,  TF1, audition1 commune  journalistes	\N	2022-02-14 15:30:00	2022-02-14 18:45:00	2022-02-14 19:11:32	2022-02-15 14:49:14	12	0	\N	\N
631703	ETUDES	AUCUNE	\N	\N	\N	Audition CRESS Corse et délégation aux outre-mer	Audition CRESS Corse et délégation aux outre-mer	2022-02-09 13:30:00	2022-02-09 15:00:00	\N	\N	1	0	\N	998
631705	COM_ENQUETE	PLENIERE	\N	MEDIA	\N	Audition commune de représentants de comités d¿éthique 	\N	2022-02-17 10:30:00	2022-02-17 12:36:00	2022-02-17 16:58:08	2022-02-18 15:06:14	9	0	\N	\N
631706	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de S.E. Mme Hala Abou Hassira et une convention	Audition de S.E. Mme Hala Abou Hassira et une  convention	2022-02-16 10:00:00	2022-02-16 11:34:00	2022-02-16 15:46:39	2022-02-17 16:42:19	29	2	\N	\N
631707	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de M. Jean-Yves Le Drian	Audition de M. Jean-Yves Le Drian	2022-02-16 16:30:00	2022-02-16 18:00:00	2022-02-17 11:30:22	2022-02-17 16:42:16	22	0	\N	\N
631725	GIA	AUCUNE	\N	\N	\N	Assemblée générale	Assemblée générale du groupe d'amitié France - Cambodge et Laos	2022-02-16 14:00:00	2022-02-16 15:00:00	\N	\N	11	0	577	\N
631726	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2022-02-08 14:35:00	2022-02-08 16:30:00	\N	\N	3	0	\N	\N
631730	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Luis VASSY, ambassadeur de France aux Pays-Bas	Entretien avec M. Luis VASSY, ambassadeur de France aux Pays-Bas	2022-02-21 15:30:00	2022-02-21 16:15:00	\N	\N	3	0	599	\N
631731	GIA	AUCUNE	\N	\N	\N	Dîner en l'honneur de M. Pieter de GOOIJER, ambassadeur des Pays-Bas	Dîner en l'honneur de M. Pieter de GOOIJER, ambassadeur des Pays-Bas	2022-02-22 19:30:00	2022-02-22 21:30:00	\N	\N	8	0	599	\N
631732	GIA	AUCUNE	\N	\N	\N	Assemblée générale	Assemblée générale du groupe d'amitié France - Pays-Bas	2022-02-23 14:15:00	2022-02-23 15:00:00	\N	\N	4	0	599	\N
631758	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Frédéric Doré, ambassadeur de France en Colombie	Entretien avec M. Frédéric Doré, ambassadeur de France en Colombie	2022-02-08 19:00:00	2022-02-08 20:00:00	\N	\N	3	0	979	\N
631762	GIA	AUCUNE	\N	\N	\N	Déjeuner de travail avec M. Ivan Duque, Président de la République de Colombie	Déjeuner de travail avec M. Ivan Duque, Président de la République de Colombie	2022-02-12 13:15:00	2022-02-12 16:30:00	\N	\N	3	0	979	\N
633748	COM_ENQUETE	PLENIERE	\N	MEDIA	\N	rn médias	\N	2022-02-16 16:45:00	2022-02-16 18:35:00	2022-02-16 19:18:29	2022-02-17 16:47:27	11	0	\N	\N
633749	ETUDES	AUTRE	\N	\N	\N	Audition de M. Benjamin SMITH, PDG groupe Air France-KLM	Audition de M. Benjamin SMITH, PDG groupe Air France-KLM	2022-04-12 16:30:00	2022-04-12 18:30:00	\N	\N	0	0	\N	933
633757	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2022- Dotations d'investissement aux CT - Déplacement Ministère Cohésion territ.	Contrôle 2022- Dotations d'investissement aux CT - Déplacement Ministère Cohésion des territoires	2022-02-15 12:45:00	2022-02-15 14:45:00	\N	\N	2	0	\N	\N
690718	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL JOP 2024	\N	2023-01-11 18:00:00	2023-01-11 19:00:00	\N	\N	5	0	\N	\N
633888	COM_ENQUETE	PLENIERE	\N	HOPITAL	\N	Audition plénière de M. Olivier Véran	\N	2022-02-24 14:00:00	2022-02-24 15:30:00	2022-03-02 10:37:13	2022-03-02 11:42:19	8	0	\N	\N
633993	MISSION	AUDRAP	\N	SECUECO	\N	Audition Mme Vogel	Audition Mme Vogel	2022-02-16 17:30:00	2022-02-16 18:30:00	\N	\N	3	0	\N	\N
634073	BUREAU	AUCUNE	\N	\N	\N	Bureau du Sénat	Bureau du Sénat	2022-02-17 08:30:00	2022-02-17 11:30:00	\N	\N	23	0	\N	\N
634967	DELEGATION	AUCUNE	\N	\N	206	Examen du rapport sur les développements scientifiques relatifs à la crise de la Covid-19	\N	2022-02-22 13:35:00	2022-02-22 14:50:00	\N	\N	7	0	\N	\N
635095	COM_EURO	AUTRE	\N	AFEU	\N	Audition du juge Bonichot 	\N	2022-02-22 14:50:00	2022-02-22 16:05:00	\N	\N	0	0	\N	\N
635180	MISSION	AUCUNE	\N	FONDSMER	\N	Table ronde ONG	Table ronde ONG	2022-02-22 17:00:00	2022-02-22 18:30:00	2022-02-22 18:24:05	2022-02-23 15:36:30	9	0	\N	\N
635313	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2022-02-24 08:30:00	2022-02-24 10:00:00	2022-02-24 12:53:06	2022-02-24 14:42:25	62	1	\N	\N
635633	COM_PERMANENTE	AUTRE	\N	CAE	\N	Communication sur le paquet "Ajustement à l'objectif 55"	\N	2022-02-23 09:30:00	2022-02-23 10:30:00	2022-02-23 10:42:52	2022-02-23 15:35:57	37	0	\N	\N
635658	DELEGATION	AUCUNE	\N	\N	DSOM	Examen du rapport d'information Place des outre-mer dans la stratégie maritime nationale	\N	2022-02-24 09:30:00	2022-02-24 10:35:00	\N	\N	13	0	\N	\N
635716	ETUDES	AUTRE	\N	\N	\N	Le vin face au défi climatique	Le vin face au défi climatique	2022-02-22 18:00:00	2022-02-22 19:00:00	\N	\N	15	0	\N	909
635757	MISSION	AUDRAP	\N	RECHINNO	\N	Audition de M. Cédric Perrin	Audition de M. Cédric Perrin	2022-02-22 14:30:00	2022-02-22 15:00:00	\N	\N	4	0	\N	\N
509428	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJLF pour 2021 - p 146	\N	2020-11-25 14:00:00	2020-11-25 14:45:00	\N	\N	2	0	\N	\N
509432	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2018 - Programme 146	\N	2020-11-26 10:00:00	2020-11-26 11:30:00	\N	\N	2	0	\N	\N
510712	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL 477 - Contribution Assurances - ACPR	PPL 477 - Contribution Assurances - ACPR	2020-11-30 10:00:00	2020-11-30 10:45:00	\N	\N	1	0	\N	\N
510716	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - RCT - Ministre Cohésion des territoires	PLF pour 2021 - RCT - Ministre Cohésion des territoires	2020-11-26 09:30:00	2020-11-26 10:45:00	\N	\N	3	0	\N	\N
519102	GIA	AUCUNE	\N	\N	\N	Audition de l'ambassadeur d'Ethiopie et Assemblée générale constitutive	Audition de l'ambassadeur d'Ethiopie et Assemblée générale constitutive	2020-12-08 17:30:00	2020-12-08 19:00:00	\N	\N	10	0	588	\N
528391	GIA	AUCUNE	\N	\N	\N	Assemblée générale	Assemblée générale reconstitutive	2021-02-03 14:00:00	2021-02-03 14:30:00	\N	\N	5	0	534	\N
528397	GIA	AUCUNE	\N	\N	\N	entretien en visioconférence avec des membres de la Rada ukrainienne	\N	2021-02-03 17:30:00	2021-02-03 18:30:00	\N	\N	1	0	530	\N
529032	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audition de M. Joël Barre, DGA, sur le programme 146	\N	2021-02-02 17:00:00	2021-02-02 18:30:00	\N	\N	2	0	\N	\N
531429	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Respect principes de la République - Auditions	Collectif Vigilance Universités	2021-02-09 16:00:00	2021-02-09 16:45:00	\N	\N	7	0	\N	\N
531459	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Respect principes de la République - Auditions	Défenseure des Droits	2021-02-11 15:00:00	2021-02-11 16:00:00	\N	\N	6	0	\N	\N
531467	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Respect principes de la République - Auditions	CSA	2021-02-11 16:00:00	2021-02-11 17:00:00	\N	\N	1	0	\N	\N
531470	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Respect principes de la République - Auditions	Fondation pour l'école	2021-02-11 17:00:00	2021-02-11 17:50:00	\N	\N	2	0	\N	\N
534030	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition Paprec	Audition Paprec	2021-02-18 10:35:00	2021-02-18 12:25:00	\N	\N	3	0	\N	\N
534034	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition Enedis	Audition Enedis	2021-02-16 18:45:00	2021-02-16 20:00:00	\N	\N	4	0	\N	\N
534039	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition intersyndicale EDF	Audition intersyndicale EDF	2021-02-16 13:45:00	2021-02-16 15:00:00	\N	\N	4	0	\N	\N
543106	DELEGATION	AUDRAP	\N	\N	206	Audition Outils de webconférence - Jitsi	Audition Outils de webconférence - Jitsi	2021-03-30 16:00:00	2021-03-30 17:00:00	\N	\N	1	0	\N	\N
543108	DELEGATION	AUDRAP	\N	\N	206	Audition Outils de webconférence - Ademe	Audition Outils de webconférence - Ademe	2021-04-09 11:00:00	2021-04-09 12:00:00	\N	\N	1	0	\N	\N
551707	MISSION	AUCUNE	\N	ENSAGRIC	\N	Audition plénière	\N	2021-04-13 16:38:00	2021-04-13 18:20:00	2021-04-13 19:17:46	2021-04-14 18:26:29	13	0	\N	\N
551738	MISSION	AUDRAP	\N	PAUP	\N	Caisse centrale de la mutualité sociale agricole	\N	2021-04-16 14:00:00	2021-04-16 15:00:00	\N	\N	2	0	\N	\N
551739	MISSION	AUDRAP	\N	PAUP	\N	Défenseur des Droits	\N	2021-04-16 15:00:00	2021-04-16 16:00:00	\N	\N	4	0	\N	\N
551740	MISSION	AUDRAP	\N	PAUP	\N	Clara Deville	\N	2021-04-16 16:00:00	2021-04-16 17:00:00	\N	\N	3	0	\N	\N
551741	MISSION	AUDRAP	\N	PAUP	\N	Haut-commissariat aux compétences et à l'inclusion par l'emploi	\N	2021-04-16 17:00:00	2021-04-16 18:00:00	\N	\N	3	0	\N	\N
551743	MISSION	AUDRAP	\N	METHANIS	\N	Audition Régions de France	Audition Régions de France	2021-04-08 14:00:00	2021-04-08 14:45:00	\N	\N	6	0	\N	\N
551744	MISSION	AUDRAP	\N	METHANIS	\N	Audition AILE	Audition AILE	2021-04-08 14:45:00	2021-04-08 15:30:00	\N	\N	6	0	\N	\N
551745	MISSION	AUDRAP	\N	METHANIS	\N	Audition Tryon	Audition Tryon	2021-04-08 15:30:00	2021-04-08 16:15:00	\N	\N	7	0	\N	\N
551746	MISSION	AUDRAP	\N	METHANIS	\N	Audition FranceAgriMer	Audition FranceAgriMer	2021-04-08 16:15:00	2021-04-08 17:00:00	\N	\N	7	0	\N	\N
551747	MISSION	AUDRAP	\N	METHANIS	\N	Audition Nénufar	Audition Nénufar	2021-04-08 17:15:00	2021-04-08 18:00:00	\N	\N	6	0	\N	\N
551782	MISSION	AUDRAP	\N	METHANIS	\N	Audition Sublime énergie	Audition Sublime énergie	2021-04-12 09:00:00	2021-04-12 09:45:00	\N	\N	4	0	\N	\N
551783	MISSION	AUDRAP	\N	METHANIS	\N	Audition Biogaz Vallée	Audition Biogaz Vallée	2021-04-12 09:45:00	2021-04-12 10:30:00	\N	\N	5	0	\N	\N
551784	MISSION	AUDRAP	\N	METHANIS	\N	Audition Observatoire de la méthanisation	Audition Observatoire de la méthanisation	2021-04-12 10:30:00	2021-04-12 11:30:00	\N	\N	5	0	\N	\N
551785	MISSION	AUDRAP	\N	METHANIS	\N	Audition Méthagriloué	Audition Méthagriloué	2021-04-12 17:15:00	2021-04-12 18:00:00	\N	\N	3	0	\N	\N
551786	MISSION	AUDRAP	\N	METHANIS	\N	Audition FNSafer	Audition FNSafer	2021-04-12 18:00:00	2021-04-12 18:45:00	\N	\N	3	0	\N	\N
551812	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Garanties professions de santé - Fédération française de l'assurance 	\N	2021-04-27 14:30:00	2021-04-27 15:45:00	\N	\N	1	0	\N	\N
551955	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition R. Bachelot Maistre	Audiition R. Bachelot et Audition Roch-Olivier Maistre	2021-04-13 14:02:00	2021-04-13 16:46:00	2021-04-13 16:46:56	2021-04-14 18:25:19	30	0	\N	\N
552129	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions 3 rapporteurs	\N	2021-04-07 14:00:00	2021-04-07 15:00:00	\N	\N	8	0	\N	\N
553091	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	Audition par le groupe d'études Français de l'étranger de M. Olivier BROCHET	Audition par le groupe d'étudeM. Olivier BROCHET, Directeur de l'Agence pour l'enseignement français à l'étranger (AEFE)	2021-04-07 13:30:00	2021-04-07 15:00:00	\N	\N	12	0	\N	\N
553104	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	Audition par le groupe d'études Français de l'étranger de M. Eric CHEVALLIER,	Audition par le groupe d'études Français de l'étranger de M. Eric CHEVALLIER, Directeur du Centre de crise et de soutien	2021-04-07 16:15:00	2021-04-07 17:15:00	\N	\N	12	0	\N	\N
553222	GIA	AUCUNE	\N	\N	\N	Audition de responsables de l'AFD conjointement avec le groupe France-Vietnam	Audition de Mme Julie MARSAUDON, directrice adjointe du département Orients à l'AFD, et M. Borin PIN 	2021-03-25 09:00:00	2021-03-25 10:30:00	\N	\N	10	0	609	\N
554703	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT Institutions	Audition de M. Didier Blanc	2021-04-15 11:30:00	2021-04-15 12:15:00	\N	\N	4	0	\N	\N
554710	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT Puissance chinoise en Europe	\N	2021-04-13 14:00:00	2021-04-13 16:00:00	\N	\N	3	0	\N	\N
554714	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT Puissance chinoise en Europe	\N	2021-04-13 16:00:00	2021-04-13 17:15:00	\N	\N	4	0	\N	\N
554719	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT Puissance chinoise en Europe	\N	2021-04-14 13:45:00	2021-04-14 15:00:00	\N	\N	3	0	\N	\N
559205	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Assemblée permanente des chambres d'agriculture	\N	2021-05-06 14:00:00	2021-05-06 14:45:00	\N	\N	4	0	\N	\N
559209	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Irresponsabilité pénale - PPL Accès des jeunes dans la FP (rapport et texte)	PPL Irresponsabilité pénale - PPL Accès des jeunes dans la FP (rapport et texte)	2021-05-19 09:00:00	2021-05-19 11:45:00	2021-05-19 12:29:10	2021-05-19 15:31:21	40	0	\N	\N
559214	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Coordination rurale	\N	2021-05-06 14:45:00	2021-05-06 15:15:00	\N	\N	3	0	\N	\N
559385	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Jeunes Agriculteurs	\N	2021-05-06 15:15:00	2021-05-06 15:45:00	\N	\N	3	0	\N	\N
559389	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Confédération paysanne	\N	2021-05-06 15:45:00	2021-05-06 16:15:00	\N	\N	3	0	\N	\N
559393	COM_PERMANENTE	AUDRAP	\N	CDD	\N	INRAE	\N	2021-05-06 16:15:00	2021-05-06 17:00:00	\N	\N	0	0	\N	\N
559394	COM_PERMANENTE	AUDRAP	\N	CDD	\N	INRAE	\N	2021-05-06 16:15:00	2021-05-06 17:00:00	\N	\N	2	0	\N	\N
559428	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Services dédiés à la recherche patrimoniale -  INHA	Contrôle 2021 - Services dédiés à la recherche patrimoniale -  INHA	2021-05-12 14:00:00	2021-05-12 15:00:00	\N	\N	2	0	\N	\N
559455	COM_PERMANENTE	AUDRAP	\N	CDD	\N	TR Forêt	\N	2021-05-06 17:00:00	2021-05-06 18:30:00	\N	\N	3	0	\N	\N
559458	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-05-12 16:32:00	2021-05-12 17:40:00	2021-05-12 20:17:27	2021-05-14 15:17:57	27	0	\N	\N
559468	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition ONF	\N	2021-05-06 18:30:00	2021-05-06 19:15:00	\N	\N	1	0	\N	\N
559470	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition UNIFA	\N	2021-05-06 19:15:00	2021-05-06 20:00:00	\N	\N	1	0	\N	\N
559473	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Dérèglement Climatique et résilience - DGAL-Sous direction transitions alimentaires	PJL Dérèglement Climatique et résilience - DGAL-Sous direction transitions alimentaires	2021-05-12 15:30:00	2021-05-12 16:15:00	\N	\N	1	0	\N	\N
610593	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition 58-2 sur le fonds pour le développement de la vie associative et désignation PPL 	Audition 58-2 sur le fonds pour le développement de la vie associative et désignation PPL 325	2021-12-07 17:05:00	2021-12-07 18:30:00	2021-12-08 09:37:06	2021-12-08 17:01:19	22	0	\N	\N
610594	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Rapporteur - Mme Stéphanie Balme (Sciences Po)	Audition rapporteur - PPRE influences étatiques extra-européennes dans le monde académique et la recherche	2021-11-15 10:00:00	2021-11-15 11:00:00	\N	\N	1	0	\N	\N
610595	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur - ALLEA	\N	2021-11-15 16:00:00	2021-11-15 17:00:00	\N	\N	1	0	\N	\N
610599	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Table ronde syndicats de professeurs d'EPS	\N	2021-12-02 10:30:00	2021-12-02 12:10:00	\N	\N	3	0	\N	\N
610603	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Musée du Louvre	Audition de M. Martinez	2021-12-01 14:00:00	2021-12-01 14:50:00	\N	\N	4	0	\N	\N
610604	DELEGATION	AUCUNE	\N	\N	206	Examen du rapport sur « Covid-19 et Pollution de l'air »	\N	2021-12-02 10:35:00	2021-12-02 11:25:00	\N	\N	12	0	\N	\N
610605	DELEGATION	AUCUNE	\N	\N	206	Examen de la note scientifique sur les outils de visioconférence	\N	2021-12-02 11:25:00	2021-12-02 12:05:00	\N	\N	12	0	\N	\N
610607	DELEGATION	AUCUNE	\N	\N	206	Examen de la note scientifique sur le biomimétisme	\N	2021-12-02 09:35:00	2021-12-02 10:35:00	\N	\N	12	0	\N	\N
610608	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Auditio MM P. Louette et J-B Gourdin	\N	2021-12-02 14:30:00	2021-12-02 16:35:00	\N	\N	0	0	\N	\N
610610	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur - Scholars at risk	Audition rapporteur - PPRE influences étatiques extra-européennes dans le monde académique et la recherche	2021-12-01 14:00:00	2021-12-01 15:00:00	\N	\N	1	0	\N	\N
610611	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur Commission européenne DG Recherche	\N	2021-12-01 16:30:00	2021-12-01 17:30:00	\N	\N	1	0	\N	\N
610614	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur Commission européenne DG Recherche Mme Russo	\N	2021-12-02 09:00:00	2021-12-02 10:00:00	\N	\N	1	0	\N	\N
610615	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur SEAE	\N	2021-12-02 16:30:00	2021-12-02 17:30:00	\N	\N	1	0	\N	\N
610619	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2021-12-02 09:00:00	2021-12-02 12:30:00	\N	\N	4	0	\N	\N
610668	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Interdire les pratiques visant à modifier l'orientation sexuelle (amendements)	PPL Interdire les pratiques visant à modifier l'orientation sexuelle (amendements)	2021-12-07 09:35:00	2021-12-07 09:50:00	2021-12-07 10:29:39	2021-12-08 17:01:19	11	1	\N	\N
610669	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de Didier Reynders, commissaire européen à la justice	Audition de Didier Reynders, commissaire européen à la justice	2021-12-07 14:00:00	2021-12-07 15:25:00	2021-12-07 15:26:42	2021-12-08 17:01:19	25	0	\N	\N
610670	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de Julien Boucher, directeur général de l'Ofpra	Audition de Julien Boucher, directeur général de l'Ofpra	2021-12-08 09:30:00	2021-12-08 10:35:00	2021-12-10 15:28:12	2021-12-10 15:43:59	37	0	\N	\N
632475	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	M. Xavier Jaravel et Mme Isabelle Méjean	\N	2022-01-11 16:00:00	2022-01-11 17:00:00	\N	\N	0	0	\N	\N
610671	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Commémoration répression d'Algériens 17 octobre 1961 - PPL Nouveau pacte citoyenneté	PPL Commémoration répression d'Algériens 17 octobre 1961 - PPL Nouveau pacte citoyenneté	2021-12-08 10:40:00	2021-12-08 10:50:00	2021-12-10 15:27:04	2021-12-10 15:43:58	33	0	\N	\N
610672	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de Marlène Schiappa sur la nouvelle carte nationale d'identité	Audition de Marlène Schiappa sur la nouvelle carte nationale d'identité	2021-12-08 16:30:00	2021-12-08 17:35:00	2021-12-08 17:43:53	2021-12-09 15:58:06	15	0	\N	\N
610688	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	CE Cabinets de conseil - Journalistes - Acteurs intelligence économique	\N	2021-12-02 15:00:00	2021-12-02 17:25:00	\N	\N	0	0	\N	\N
610689	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Musée de l'Homme	Audition de M. Delpuech	2021-12-02 15:30:00	2021-12-02 17:00:00	\N	\N	3	0	\N	\N
610697	COM_ENQUETE	AUDRAP	\N	CABINETS	\N	CE Cabinets de conseil - Journalistes - Acteurs intelligence économique	CE Cabinets de conseil - Journalistes - Acteurs intelligence économique	2021-12-02 15:00:00	2021-12-02 17:25:00	\N	\N	3	0	\N	\N
610701	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 9 décembre	\N	2021-12-09 08:30:00	2021-12-09 10:30:00	2021-12-09 10:42:31	2021-12-09 16:22:35	13	0	\N	\N
610702	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 8 décembre	\N	2021-12-08 13:30:00	2021-12-08 14:45:00	2021-12-08 15:09:32	2021-12-08 17:01:44	20	0	\N	\N
610703	GIA	AUCUNE	\N	\N	\N	Assemblée générale 2021	Assemblée générale 2021	2021-12-01 16:30:00	2021-12-01 17:15:00	\N	\N	6	0	575	\N
610725	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition Mme de Montchalin	\N	2021-12-08 16:25:00	2021-12-08 17:45:00	2021-12-10 11:18:59	2021-12-10 15:20:34	14	0	\N	\N
610727	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition M. Labrune LFP	\N	2021-12-08 09:33:00	2021-12-08 11:00:00	2021-12-08 11:48:45	2021-12-08 17:01:15	29	0	\N	\N
610728	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Audition M. Louette et M. Gourdin	\N	2021-12-02 14:30:00	2021-12-02 16:30:00	\N	\N	0	0	\N	\N
610740	DELEGATION	AUCUNE	\N	\N	DSOM	Auditions Étude "Place des outre-mer dans la stratégie maritime nationale"	\N	2021-12-09 09:30:00	2021-12-09 11:45:00	\N	\N	12	0	\N	\N
610741	DELEGATION	AUCUNE	\N	\N	DSOM	Table ronde "Guyane" - Étude "Place des outre-mer dans la stratégie maritime nationale"	\N	2021-12-09 14:30:00	2021-12-09 16:20:00	\N	\N	5	0	\N	\N
610746	DELEGATION	AUCUNE	\N	\N	DSOM	Table ronde Indopacifique	\N	2021-12-16 09:00:00	2021-12-16 12:00:00	\N	\N	20	0	\N	\N
610762	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2021-12-01 18:00:00	2021-12-01 19:00:00	\N	\N	21	0	\N	\N
610784	COM_ENQUETE	AUTRE	\N	MEDIA	\N	Table ronde d'association médias audition du président du CSA	\N	2021-12-07 15:00:00	2021-12-07 18:00:00	2021-12-07 19:01:14	2021-12-08 17:03:12	16	0	\N	\N
610785	COM_ENQUETE	AUTRE	\N	MEDIA	\N	 Audition SNJ et Table ronde directeurs de l'information	\N	2021-12-10 10:30:00	2021-12-10 13:00:00	2021-12-10 17:28:50	2021-12-14 14:37:45	7	0	\N	\N
610786	COM_ENQUETE	AUTRE	\N	MEDIA	\N	Table ronde SDJ 	\N	2021-12-10 14:30:00	2021-12-10 16:00:00	2021-12-10 17:30:21	2021-12-14 14:37:46	8	0	\N	\N
610789	COM_ENQUETE	PLENIERE	\N	HOPITAL	\N	Réunion plénière	\N	2021-12-09 14:30:00	2021-12-09 17:55:00	2021-12-14 15:18:40	2021-12-14 15:19:12	16	0	\N	\N
610795	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de M. Jean-Yves Le Drian	\N	2021-12-07 17:50:00	2021-12-07 19:10:00	2021-12-08 14:56:27	2021-12-08 17:01:17	26	0	\N	\N
610822	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Plateforme de la filière automobile et des mobilités (PFA)	Plateforme de la filière automobile et des mobilités (PFA)	2021-11-09 13:30:00	2021-11-09 14:30:00	\N	\N	1	0	\N	\N
610825	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Bpifrance	Bpifrance	2021-11-10 11:30:00	2021-11-10 12:30:00	\N	\N	1	0	\N	\N
610827	COM_PERMANENTE	AUDRAP	\N	CAE	\N	France Stratégie	France Stratégie	2021-11-10 13:30:00	2021-11-10 14:15:00	\N	\N	1	0	\N	\N
610829	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	CE Cabinets de conseil - CIRI - Hospices civils de Lyon - Direction du budget	\N	2021-12-06 14:30:00	2021-12-06 18:00:00	\N	\N	0	0	\N	\N
610831	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	CE Cabinets de conseil audition plénière - Direction des achats de l'Etat	\N	2021-12-08 16:30:00	2021-12-08 18:00:00	\N	\N	0	0	\N	\N
610840	MISSION	AUCUNE	\N	SECUECO	\N	Audition plénière	\N	2021-12-09 10:30:00	2021-12-09 12:05:00	2021-12-14 14:36:33	2021-12-14 14:37:44	5	0	\N	\N
610841	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PLF 2022 Avis Écologie - Commission de régulation de l'énergie	Audition PLF 2022 Avis Écologie - Commission de régulation de l'énergie	2021-10-27 16:00:00	2021-10-27 16:30:00	\N	\N	1	0	\N	\N
611262	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT subsidiarité	GT Subsidiarité	2021-12-07 15:30:00	2021-12-07 15:40:00	\N	\N	3	0	\N	\N
611613	ETUDES	AUCUNE	\N	\N	\N	GE arts de la scène	GE arts de la scène	2021-12-08 11:30:00	2021-12-08 12:20:00	\N	\N	9	0	\N	966
612007	GIA	AUCUNE	\N	\N	\N	entretien à l'invitation de S.E. M. Ghazi Alrawas, Ambassadeur d'Oman en France	\N	2021-12-08 12:00:00	2021-12-08 14:30:00	\N	\N	7	0	661	\N
613029	GIA	AUCUNE	\N	\N	\N	Webinaire crise sanitaire au Brésil	Webinaire relatif à la gestion de la crise sanitaire liée à la Covid-19 au Brésil	2021-11-16 16:30:00	2021-11-16 18:30:00	\N	\N	5	0	576	\N
513080	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-12-09 09:30:00	2020-12-09 11:50:00	2020-12-09 12:21:31	2020-12-09 17:20:04	42	0	\N	\N
513168	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 8 décembre 2020	\N	2020-12-08 08:15:00	2020-12-08 10:25:00	2020-12-08 10:24:25	2020-12-08 18:01:17	27	0	\N	\N
513170	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européenne du 10 décembre 2020	\N	2020-12-10 09:00:00	2020-12-10 10:30:00	2020-12-10 10:36:36	2020-12-10 17:43:54	21	0	\N	\N
513171	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur - union de la sécurité	Audition rapporteur sur la stratégie de l'Union de la sécurité 2020-2025	2020-12-04 09:00:00	2020-12-04 09:55:00	\N	\N	2	0	\N	\N
516507	DELEGATION	AUDRAP	\N	\N	206	Audition de syndicats de médecins sur la vaccination 	Audition de syndicats de médecins sur la vaccination 	2020-12-10 15:10:00	2020-12-10 16:10:00	\N	\N	5	0	\N	\N
516517	DELEGATION	AUDRAP	\N	\N	206	Audition de l'ANSM sur la vaccination	Audition de l'ANSM sur la vaccination	2020-12-10 14:00:00	2020-12-10 15:10:00	\N	\N	5	0	\N	\N
519087	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2020-12-17 14:35:00	2020-12-17 17:20:00	\N	\N	3	0	\N	\N
520672	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe	Assemblée générale du groupe	2021-01-13 14:00:00	2021-01-13 14:30:00	\N	\N	5	0	653	\N
529167	MISSION	AUCUNE	\N	ENSAGRIC	\N	Réunion constitutive MI EA	\N	2021-02-09 18:07:00	2021-02-09 19:08:00	2021-02-10 09:31:13	2021-02-10 17:51:39	21	0	\N	\N
529196	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Etat de droit dans l'Union européenne	Audition Etat de droit dans l'Union européenne - Parlement européen	2021-02-05 10:00:00	2021-02-05 11:00:00	\N	\N	2	0	\N	\N
529205	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Respect principes de la République - Auditions	Audition Youssef Chiheb - Sorbonne Nord	2021-02-04 11:40:00	2021-02-04 12:40:00	\N	\N	7	0	\N	\N
529219	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Respect principes de la République - Auditions	Secrétariat général de l'enseignement catholique	2021-02-04 14:00:00	2021-02-04 15:00:00	\N	\N	6	0	\N	\N
529228	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Table ronde sur l' « avenir des acteurs de la filière du livre » :	\N	2021-02-10 10:01:00	2021-02-10 11:54:00	2021-02-11 13:30:47	2021-02-11 18:29:41	34	0	\N	\N
529229	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition du PDG d'EDF	\N	2021-02-10 09:00:00	2021-02-10 12:30:00	2021-02-11 10:24:40	2021-02-11 18:29:40	45	0	\N	\N
529239	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Sécurité globale	PPL Sécurité globale	2021-02-09 15:00:00	2021-02-09 15:45:00	\N	\N	5	0	\N	\N
529240	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Sécurité globale	PPL Sécurité globale	2021-02-09 15:45:00	2021-02-09 16:30:00	\N	\N	3	0	\N	\N
529993	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition Autorité des marchés financiers	Audition Autorité des marchés financiers	2021-02-09 16:00:00	2021-02-09 17:00:00	\N	\N	5	0	\N	\N
529999	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition Autorité de la concurrence	Audition Autorité de la concurrence	2021-02-09 17:00:00	2021-02-09 18:00:00	\N	\N	5	0	\N	\N
534283	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Service public d'eau potable et d'assainissement en Guadeloupe	PPL Service public d'eau potable et d'assainissement en Guadeloupe	2021-02-18 13:30:00	2021-02-18 17:40:00	\N	\N	1	0	\N	\N
534285	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Service public d'eau potable et d'assainissement en Guadeloupe	PPL Service public d'eau potable et d'assainissement en Guadeloupe	2021-02-23 15:45:00	2021-02-23 17:45:00	\N	\N	1	0	\N	\N
534482	GIA	AUCUNE	\N	\N	\N	audition de M. Christophe Farnaud, directeur Moyen-Orient au Quai d'Orsay	\N	2021-03-02 09:00:00	2021-03-02 10:30:00	\N	\N	7	0	661	\N
534575	GIA	AUCUNE	\N	\N	\N	Audition Consul Jérusalem	Audition de M. René Troccaz, consul général de France à Jérusalem	2021-03-02 14:00:00	2021-03-02 15:00:00	\N	\N	8	0	632	\N
534602	GIA	AUCUNE	\N	\N	\N	Audition J.-P. Chagnollaud	Audition de M. Jean-Paul Chagnollaud, professeur émérite des Universités	2021-03-02 15:00:00	2021-03-02 15:50:00	\N	\N	2	0	632	\N
534870	DELEGATION	AUCUNE	\N	\N	PROS	Table ronde sur sur les transformations liées au télétravail.	Table ronde sur sur les transformations liées au télétravail.	2021-04-01 08:30:00	2021-04-01 11:25:00	\N	\N	25	0	\N	\N
536521	GIA	AUCUNE	\N	\N	\N	Audition de Mme Marie Dumoulin, sous-directrice Russie et Europe orientale , Quai d'Orsay	Audition de Mme Marie Dumoulin, sous-directrice Russie et Europe orientale , MEAE	2021-03-03 16:30:00	2021-03-03 17:45:00	\N	\N	5	0	852	\N
536602	GIA	AUCUNE	\N	\N	\N	Audition de M. François Gouyette	Audition de M. François Gouyette, ambassadeur de France en Algérie	2021-03-03 17:00:00	2021-03-03 18:30:00	\N	\N	4	0	575	\N
538858	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Louis Riquet, sous-directeur Extrême-Orient du MEAE 	Entretien avec M. Louis Riquet, sous-directeur Extrême-Orient, et Mohammed-El-Fatah BADR, rédacteur Mongolie, au MEAE	2021-03-11 08:40:00	2021-03-11 09:25:00	\N	\N	4	0	612	\N
541329	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Groupe de travail Drones	Groupe de travail Drones	2021-03-16 15:00:00	2021-03-16 17:00:00	\N	\N	3	0	\N	\N
545889	GIA	AUCUNE	\N	\N	\N	accueil Thupten Gyatso	accueil Thupten Gyatso	2021-04-01 10:30:00	2021-04-01 11:30:00	\N	\N	4	0	634	\N
547967	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GS Egalim - Auditions DGCCRF / ILEC	GS Egalim - Auditions DGCCRF / ILEC	2021-03-30 15:00:00	2021-03-30 16:30:00	\N	\N	3	0	\N	\N
547974	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GS Egalim - Audition FEEF	GS Egalim - Audition FEEF	2021-03-30 18:00:00	2021-03-30 18:30:00	\N	\N	5	0	\N	\N
547982	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GS Egalim - Auditions FCD / M. Papin	GS Egalim - Auditions FCD / M. Papin	2021-03-30 18:30:00	2021-03-30 19:45:00	\N	\N	7	0	\N	\N
552182	GIA	AUCUNE	\N	\N	\N	Conférence organisée conjointement avec le Parlement grec	Conférenence en présence des Ambassadeurs de France en Grèce et de Grèce en France 	2021-04-13 16:00:00	2021-04-13 18:00:00	\N	\N	3	0	591	\N
559655	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL DADUE transports	PJL DADUE transports, de l'environnement, de l'économie et des finances	2021-05-19 16:40:00	2021-05-19 19:45:00	\N	\N	54	0	\N	\N
559657	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Explications de vote PPL trésorerie des associations	Explications de vote PP trésorerie des associations	2021-05-20 10:30:00	2021-05-20 11:20:00	\N	\N	27	0	\N	\N
559658	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Explications de vote PPL engagement associatif	Explications de vote PPL engagement associatif	2021-05-20 11:20:00	2021-05-20 12:20:00	\N	\N	38	0	\N	\N
559661	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL/PJLO Oeuvres culturelles	PJL/PJLO Oeuvres culturelles	2021-05-20 12:20:00	2021-05-20 13:15:00	\N	\N	27	0	\N	\N
559662	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL/PJLO Oeuvres culturelles	PJL/PJLO Oeuvres culturelles	2021-05-20 14:45:00	2021-05-20 20:20:00	\N	\N	38	0	\N	\N
559666	GIA	AUCUNE	\N	\N	\N	GIA Allemagne - Entretien avec M. Roland THEIS, Secrétaire d'Etat du Land de Sarre	GIA Allemagne - Entretien avec M. Roland THEIS, Secrétaire d'Etat aux Affaires européennes du Land de Sarre	2021-05-12 14:00:00	2021-05-12 15:00:00	\N	\N	9	0	604	\N
560137	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL Climat et résilience - Convention citoyenne pour le climat	Audition PJL Climat et résilience - Convention citoyenne pour le climat	2021-05-11 13:45:00	2021-05-11 14:15:00	\N	\N	1	0	\N	\N
560138	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL Climat et résilience - Commission de régulation de l'énergie (CRE)	Audition PJL Climat et résilience - Commission de régulation de l'énergie (CRE)	2021-05-11 17:00:00	2021-05-11 17:30:00	\N	\N	1	0	\N	\N
613196	GIA	AUCUNE	\N	\N	\N	Coopé - Entretien avec une délégation de députés géorgiens	Coopé - Entretien avec une délégation de députés géorgiens	2021-12-08 18:30:00	2021-12-08 20:00:00	\N	\N	1	0	534	\N
615180	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Combattre le harcèlement scolaire	Audition rapporteur - Avis PPL Combattre le harcèlement scolaire	2021-12-15 14:00:00	2021-12-15 14:30:00	\N	\N	1	0	\N	\N
621409	ETUDES	AUCUNE	\N	\N	\N	Auditions de M. Arnaud LEROY, président l¿ADEME-ATE	Auditions de M. Arnaud LEROY, président l¿ADEME-ATE	2022-01-12 13:30:00	2022-01-12 15:00:00	\N	\N	14	0	\N	906
621503	COM_PERMANENTE	AUDRAP	\N	CDD	\N	MI Aménagement du territoire - Audition Mme Patricia Demas	MI Aménagement du territoire - Auditions Mme Patricia Demas	2022-01-12 14:00:00	2022-01-12 14:55:00	\N	\N	1	0	\N	\N
621508	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PJL Gestion de la crise sanitaire - Réunion plénière	\N	2022-01-15 17:25:00	2022-01-15 17:30:00	2022-01-15 17:33:51	2022-01-17 10:56:57	10	0	\N	\N
621872	GIA	AUCUNE	\N	\N	\N	petit déjeuner Ambassadrice	échanges avec la nouvelle ambassadrice du Royaume-Uni en France	2021-10-13 08:30:00	2021-10-13 10:00:00	\N	\N	7	0	581	\N
622329	GIA	AUCUNE	\N	\N	\N	Rencontre avec la CCI France-Russie	Rencontre avec M. Emmanuel Quidet, président, M. Pavel Chinsky, directeur général, M. Rémi Paul et M. David Lasfargue	2022-01-19 08:15:00	2022-01-19 09:30:00	\N	\N	12	0	608	\N
626689	ETUDES	AUCUNE	\N	\N	\N	Audition Cress Centre-Val de Loire et Cress Pays de la Loire	Audition Cress Centre-Val de Loire et Cress Pays de la Loire	2022-01-26 13:30:00	2022-01-26 15:00:00	\N	\N	1	0	\N	998
626794	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2022-02-02 09:30:00	2022-02-02 12:16:00	2022-02-02 15:25:09	2022-02-02 15:43:37	35	0	\N	\N
627295	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLO Élection présidentielle dans le contexte lié à l'épidémie de covid-19	Audition rapporteur - PPLO Élection présidentielle dans le contexte lié à l'épidémie de covid-19	2022-02-01 14:50:00	2022-02-01 15:50:00	\N	\N	2	0	\N	\N
627723	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Choix du nom issu de la filiation	PPL choix du nom issu de la filiation	2022-02-01 15:00:00	2022-02-01 16:10:00	\N	\N	2	0	\N	\N
631620	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2022-02-10 09:00:00	2022-02-10 11:00:00	\N	\N	4	0	\N	\N
631647	GIA	AUCUNE	\N	\N	\N	Entretien avec l'Ambassadrice des Philippines 	Entretien avec Mme Junever M. MAHILUM-WEST, Ambassadrice des Philippines	2022-02-02 12:45:00	2022-02-02 14:30:00	\N	\N	2	0	609	\N
631862	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Université de Paris	\N	2022-02-14 15:00:00	2022-02-14 16:15:00	\N	\N	2	0	\N	\N
631894	COM_ENQUETE	AUDRAP	\N	HOPITAL	\N	CE Hôpital - Table ronde d'économistes en santé	\N	2022-02-14 14:00:00	2022-02-14 15:30:00	\N	\N	5	0	\N	\N
631895	COM_ENQUETE	AUDRAP	\N	HOPITAL	\N	CE Hôpital - Audition de syndicats de directeurs d'hôpital	\N	2022-02-14 15:30:00	2022-02-14 16:45:00	\N	\N	4	0	\N	\N
631935	COM_PERMANENTE	AUTRE	\N	AFCL	\N	PPL Harcelement scolaire - nouvelle lecture rapport PPL restitution amendements séance	\N	2022-02-15 14:04:00	2022-02-15 14:25:00	2022-02-15 15:14:48	2022-02-15 17:31:00	27	5	\N	\N
631936	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition de Mme Béatrice Gille, présidente du Conseil d'évaluation de l'école	\N	2022-02-16 09:35:00	2022-02-16 11:10:00	2022-02-21 16:58:03	2022-02-21 17:13:59	30	0	\N	\N
632029	DELEGATION	AUDRAP	\N	\N	206	Audition de M. DELFRAISSY	\N	2022-01-06 15:30:00	2022-01-06 17:00:00	\N	\N	2	0	\N	\N
632202	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition rapporteurs de l'U2P	\N	2022-02-09 13:45:00	2022-02-09 14:45:00	\N	\N	0	0	\N	\N
632204	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Auditions sur le thème de la responsabilité sociétale des entreprises 	\N	2022-02-17 09:00:00	2022-02-17 11:00:00	2022-02-17 12:13:54	\N	12	0	\N	\N
632206	DELEGATION	AUDRAP	\N	\N	206	Entretien de Cédric VILLANI avec Athanassia SOTIROPOULOS	\N	2022-01-13 14:00:00	2022-01-13 15:00:00	\N	\N	3	0	\N	\N
632316	MISSION	AUDRAP	\N	SECUECO	\N	Audition Haut Conseil de la Santé Publique	\N	2021-12-15 17:00:00	2021-12-15 18:00:00	\N	\N	2	0	\N	\N
632320	DELEGATION	AUDRAP	\N	\N	206	Audition de Gilles Pijaudier-Cabot (CNE2)	\N	2022-01-18 15:20:00	2022-01-18 16:20:00	\N	\N	4	0	\N	\N
632340	MISSION	AUDRAP	\N	SECUECO	\N	Auditions MI Sécurité sociale écologique	\N	2021-12-16 11:30:00	2021-12-16 12:30:00	\N	\N	2	0	\N	\N
632343	MISSION	AUDRAP	\N	SECUECO	\N	Audition Mme Mélanie Vogel	\N	2022-01-06 11:30:00	2022-01-06 12:30:00	\N	\N	2	0	\N	\N
632344	DELEGATION	AUDRAP	\N	\N	206	Impacts de la crise vis-à-vis des maladies infectieuses en pédiatrie	\N	2022-01-17 16:00:00	2022-01-17 17:00:00	\N	\N	3	0	\N	\N
632351	MISSION	AUDRAP	\N	SECUECO	\N	Anses	\N	2022-01-12 17:00:00	2022-01-12 18:00:00	\N	\N	2	0	\N	\N
632356	MISSION	AUDRAP	\N	SECUECO	\N	Auditions Mme Mélanie Vogel	\N	2022-01-19 17:00:00	2022-01-19 18:00:00	\N	\N	0	0	\N	\N
632358	MISSION	AUDRAP	\N	SECUECO	\N	Auditions Mme Mélanie Vogel	\N	2022-01-19 17:00:00	2022-01-19 18:00:00	\N	\N	0	0	\N	\N
632360	MISSION	AUDRAP	\N	SECUECO	\N	Auditions Mme Mélanie Vogel	\N	2022-01-19 17:00:00	2022-01-19 18:00:00	\N	\N	2	0	\N	\N
632361	DELEGATION	AUDRAP	\N	\N	206	Impacts de la crise liés au déficit de prise en charge du cancer	\N	2022-01-17 17:00:00	2022-01-17 18:00:00	\N	\N	3	0	\N	\N
632364	MISSION	AUDRAP	\N	SECUECO	\N	Auditions Mme Mélanie Vogel	\N	2022-01-20 08:30:00	2022-01-20 10:30:00	\N	\N	2	0	\N	\N
632367	MISSION	AUDRAP	\N	SECUECO	\N	Auditions Mme Mélanie Vogel	\N	2022-01-27 10:30:00	2022-01-27 12:30:00	\N	\N	2	0	\N	\N
632371	MISSION	AUDRAP	\N	SECUECO	\N	Auditions Mi SSE	\N	2022-02-10 10:30:00	2022-02-10 12:30:00	\N	\N	2	0	\N	\N
632381	DELEGATION	AUDRAP	\N	\N	206	Éventuelles conséquences du port du masques par l'adulte sur l'apprentissage du langage	\N	2022-01-20 14:00:00	2022-01-20 15:00:00	\N	\N	2	0	\N	\N
632386	DELEGATION	AUDRAP	\N	\N	206	Conséquences de la crise sanitaire sur l'apprentissage scolaire	\N	2022-01-20 15:00:00	2022-01-20 16:00:00	\N	\N	2	0	\N	\N
632393	DELEGATION	AUDRAP	\N	\N	206	Conséquences de la crise sanitaire sur la santé mentale des enfants et des adolescents	\N	2022-01-20 16:00:00	2022-01-20 17:00:00	\N	\N	2	0	\N	\N
632398	DELEGATION	AUDRAP	\N	\N	206	Conséquences de la crise sanitaire sur la santé physique des enfants et des adolescents	\N	2022-01-20 17:00:00	2022-01-20 17:40:00	\N	\N	2	0	\N	\N
632410	MISSION	AUCUNE	\N	RECHINNO	\N	IFP EN / Comité Richelieu	IFP EN / Comité Richelieu	2022-02-10 10:30:00	2022-02-10 12:30:00	2022-02-16 10:59:14	2022-02-16 11:55:48	4	0	\N	\N
632416	MISSION	AUCUNE	\N	RECHINNO	\N	Réseau SATT/Instituts Carnot - CNES	Réseau SATT/Instituts Carnot - CNES	2022-02-10 14:35:00	2022-02-10 17:00:00	2022-02-16 10:59:32	2022-02-16 11:55:49	4	0	\N	\N
632443	DELEGATION	AUDRAP	\N	\N	206	Table ronde avec les syndicats d'éditeurs spécialisés	\N	2022-01-31 13:00:00	2022-01-31 15:00:00	\N	\N	2	0	\N	\N
632461	DELEGATION	AUCUNE	\N	\N	COLTER	Examen du rapport d'information sur les services préfectoraux et déconcentrés	\N	2022-02-16 16:30:00	2022-02-16 18:00:00	\N	\N	23	0	\N	\N
632462	MISSION	AUDRAP	\N	RECHINNO	\N	Cabinet de conseil Asterès - M. Bouzou	Cabinet de conseil Asterès- M. Bouzou	2022-02-15 15:15:00	2022-02-15 16:05:00	\N	\N	4	0	\N	\N
632465	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition raporteur	\N	2022-02-01 16:00:00	2022-02-01 17:00:00	\N	\N	0	0	\N	\N
632469	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audtion rapporteurs	\N	2022-02-01 17:00:00	2022-02-01 18:00:00	\N	\N	0	0	\N	\N
632470	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition rapporteur	\N	2022-01-18 17:05:00	2022-01-18 18:05:00	\N	\N	0	0	\N	\N
632472	MISSION	AUCUNE	\N	RECHINNO	\N	INRAe	INRAe	2022-02-15 16:15:00	2022-02-15 17:20:00	2022-02-16 11:00:43	2022-02-16 12:00:02	5	0	\N	\N
632473	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	M. Xavier Jaravel et Mme Isabelle Méjean	\N	2022-01-11 16:00:00	2022-01-11 17:00:00	\N	\N	0	0	\N	\N
632480	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	La Fabrique de l'exportation	\N	2022-01-04 17:15:00	2022-01-04 18:30:00	\N	\N	0	0	\N	\N
634664	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PPL Contrôle parental sur internet 	CMP PPL Contrôle parental sur internet 	2022-02-24 18:30:00	2022-02-24 19:15:00	\N	\N	19	0	\N	\N
634665	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL et PPLO Qualité du débat démocratique	PPL et PPLO Qualité du débat démocratique	2022-02-25 09:30:00	2022-02-25 11:10:00	\N	\N	25	0	\N	\N
506033	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2020-11-25 09:05:00	2020-11-25 11:40:00	2020-11-25 11:42:26	2020-11-25 11:48:46	42	0	\N	\N
506069	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Rapport général - ADP	PLF pour 2021 - Rapport général - ADP	2020-11-17 09:15:00	2020-11-17 09:35:00	\N	\N	1	0	\N	\N
506101	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Table ronde - Le soutien aux entreprises françaises à l'étranger	\N	2020-11-26 08:30:00	2020-11-26 10:15:00	2020-11-26 13:13:14	\N	12	0	\N	\N
506198	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Rapport général - Amazon	PLF pour 2021 - Rapport général - Amazon	2020-11-20 10:30:00	2020-11-20 11:10:00	\N	\N	1	0	\N	\N
506213	DELEGATION	AUDRAP	\N	\N	PROS	Audition de l'ADF	Audition de M. Augustin ROSSI, chargé du logement et de la mobilité	2020-11-26 11:00:00	2020-11-26 12:00:00	\N	\N	1	0	\N	\N
506214	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Empreinte environnementale du numérique	\N	2020-11-19 15:30:00	2020-11-19 17:15:00	\N	\N	2	0	\N	\N
506217	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL EEN - Facebook	\N	2020-11-20 14:45:00	2020-11-20 15:30:00	\N	\N	2	0	\N	\N
506280	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Avis cohésion des territoires - logement - DGCS	Avis cohésion des territoires - logement - DGCS	2020-11-19 11:30:00	2020-11-19 12:30:00	\N	\N	1	0	\N	\N
506316	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Avis outre-mer - CCI	Avis outre-mer - CCI	2020-11-20 16:00:00	2020-11-20 16:45:00	\N	\N	1	0	\N	\N
521207	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT subsidiarité	Réunion du GT subsidiarité	2021-01-14 08:30:00	2021-01-14 09:00:00	\N	\N	3	0	\N	\N
521214	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Nouveaux modes de travail - ANACT	Nouveaux modes de travail et de management - Audition ANACT	2021-01-14 09:00:00	2021-01-14 10:00:00	\N	\N	18	0	\N	\N
521274	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Nouveaux modes de travail - ANDRH	Nouveaux modes de travail et de management - audition ANDRH	2021-01-14 10:00:00	2021-01-14 11:00:00	\N	\N	16	0	\N	\N
526487	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Principes de la République - Audition de représentants de culte	PJL Principes de la République - Audition de représentants de culte	2021-02-03 09:00:00	2021-02-03 11:20:00	2021-02-03 15:21:20	2021-02-03 16:44:08	36	0	\N	\N
526489	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Prorogation de l'état d'urgence sanitaire (NL) (rapport)	PJL Prorogation de l'état d'urgence sanitaire (NL) (rapport)	2021-02-03 14:00:00	2021-02-03 14:35:00	2021-02-03 15:21:34	2021-02-03 16:44:15	16	0	\N	\N
526490	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Sécurité globale - Audition de Marie-Laure Denis, présidente de la CNIL	PPL Sécurité globale - Audition de Marie-Laure Denis, présidente de la CNIL	2021-02-03 11:30:00	2021-02-03 12:25:00	2021-02-03 15:21:28	2021-02-03 16:44:14	24	0	\N	\N
526491	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen rapports et textes PJL320 Ordonnances covid19 et PPL312 Réforme courtage assurances	Examen rapports et textes PJL n° 320 Ratification ordonnances covid-19 et PPL n° 312 Réforme du courtage de l'assurance	2021-02-03 10:00:00	2021-02-03 11:05:00	2021-02-03 11:50:28	2021-02-03 16:44:12	35	0	\N	\N
526522	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur - Tariq Krim, entrepreneur du web	\N	2021-01-27 16:30:00	2021-01-27 18:15:00	\N	\N	2	0	\N	\N
526536	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Résultats de l'exercice 2020 - Cour des comptes	Résultats de l'exercice 2020 - Cour des comptes	2021-01-26 09:30:00	2021-01-26 10:40:00	\N	\N	1	0	\N	\N
526549	COM_PERMANENTE	AUTRE	\N	AFCL	\N	auditions Thiellay - Audition CSA- Rapport PJL code mondial antidopage	\N	2021-02-03 09:30:00	2021-02-03 12:00:00	2021-02-03 12:36:11	2021-02-03 16:44:11	40	0	\N	\N
526550	COM_PERMANENTE	AUTRE	\N	AFCL	\N	auditions Thiellay - Audition CSA- Rapport PJL code mondial antidopage	\N	2021-02-03 09:30:00	2021-02-03 12:00:00	\N	\N	0	0	\N	\N
526551	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition CSA	\N	2021-02-02 17:10:00	2021-02-02 18:15:00	2021-02-03 16:42:27	2021-02-03 16:44:06	26	0	\N	\N
526815	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Audition	\N	2021-02-01 14:00:00	2021-02-01 15:00:00	\N	\N	1	0	\N	\N
526921	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2021-01-28 11:00:00	2021-01-28 12:40:00	\N	\N	2	0	\N	\N
529000	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	LOIS	\N	PJLO Élection du Président de la République	PJLO Élection du Président de la République - Réunion de travail	2021-02-04 12:00:00	2021-02-04 12:45:00	\N	\N	1	0	\N	\N
544603	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Transport de marchandises - ATMO	MI Transport de marchandises - ATMO	2021-03-23 14:30:00	2021-03-23 15:25:00	\N	\N	9	0	\N	\N
544616	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Transport de marchandises - Voies navigables de France	MI Transport de marchandises - Voies navigables de France	2021-03-23 15:25:00	2021-03-23 16:15:00	\N	\N	7	0	\N	\N
544626	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Transport de marchandises - Assemblée des départements  de France	MI Transport de marchandises - Assemblée des départements  de France	2021-03-23 16:15:00	2021-03-23 17:05:00	\N	\N	6	0	\N	\N
545152	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	Visio  « Briser la violence en ligne »	Webinaire sur le thème « Briser la violence en ligne »	2021-03-24 15:30:00	2021-03-24 17:00:00	\N	\N	1	0	\N	\N
557421	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne	2021-05-05 16:30:00	2021-05-05 17:40:00	2021-05-06 11:38:51	2021-05-06 17:43:47	7	0	\N	\N
559485	COM_PERMANENTE	AUTRE	\N	CAE	\N	Rapport d'information loi SRU	\N	2021-05-19 10:05:00	2021-05-19 11:25:00	2021-05-19 17:49:18	2021-05-20 15:48:16	34	0	\N	\N
559486	COM_PERMANENTE	AUTRE	\N	CAE	\N	Rapport d'information alimentation durable et locale	\N	2021-05-19 11:35:00	2021-05-19 12:35:00	2021-05-19 17:45:47	2021-05-20 15:48:15	44	0	\N	\N
559487	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de M. Franck Riester	\N	2021-05-19 16:40:00	2021-05-19 18:25:00	2021-05-20 08:59:10	2021-05-20 15:48:14	42	0	\N	\N
559526	DELEGATION	AUCUNE	\N	\N	211	Témoignage de Linda et de Jean Arcelin, co-auteurs du livre l'ange de Pigalle	Témoignage de Linda et de Jean Arcelin, co-auteurs du livre l'ange de Pigalle	2021-05-27 10:00:00	2021-05-27 11:30:00	2021-05-27 12:17:08	\N	13	0	\N	\N
559539	COM_PERMANENTE	AUTRE	\N	FINC	\N	PJL de règlement du budget : Audition de Mme Emmanuelle WARGON, ministre déléguée	PJL de règlement du budget : Audition de Mme Emmanuelle WARGON, ministre déléguée, chargée du logement	2021-05-19 17:35:00	2021-05-19 18:40:00	2021-05-19 20:32:45	2021-05-20 15:48:12	21	0	\N	\N
690727	DELEGATION	AUDRAP	\N	\N	206	Audition de la DHUP	\N	2023-01-09 11:00:00	2023-01-09 12:30:00	\N	\N	1	0	\N	\N
559541	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen AMDTS PJL 535 - Controle Budget. Syndication - Audition finance durable	Examen AMDTS PJL 535 - Controle Budget. Syndication - Audition finance durable	2021-05-19 10:05:00	2021-05-19 12:25:00	2021-05-19 13:21:32	2021-05-19 15:31:20	36	0	\N	\N
559542	COM_PERMANENTE	AUTRE	\N	FINC	\N	PJL Dérèglement Climatique et résilience - Audition conjointe	PJL Dérèglement Climatique et résilience - Audition conjointe	2021-05-18 15:00:00	2021-05-18 16:30:00	2021-05-18 17:00:03	2021-05-18 18:31:29	31	0	\N	\N
559552	ETUDES	AUTRE	\N	\N	\N	Audition Luc Ferry - GE Agriculture et Alimentation - Chasse et Pêche - Elevage	Audition Luc Ferry - GE Agriculture et Alimentation - Chasse et Pêche - Elevage	2021-05-12 13:30:00	2021-05-12 15:00:00	\N	\N	48	0	\N	919
559634	COM_PERMANENTE	AUTRE	\N	AFCL	\N	PJL Oeuvres culturelles à l'ère du numérique et PJLO 5e alinéa art. 13 Constitution	\N	2021-05-18 14:03:00	2021-05-18 14:55:00	2021-05-18 15:56:33	2021-05-18 18:31:28	23	0	\N	\N
559635	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Patrimoine culturel immatériel - PJLO 5e alinéa art. 13 Constitution	\N	2021-05-19 09:32:00	2021-05-19 11:00:00	2021-05-19 17:24:04	2021-05-20 15:48:17	24	0	\N	\N
559636	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Patrimoine culturel immatériel - PJLO 5e alinéa art. 13 Constitution	\N	2021-05-19 09:30:00	2021-05-19 12:00:00	\N	\N	0	0	\N	\N
559637	COM_PERMANENTE	AUDRAP	\N	CAE	\N	DGALN François Bonnet	\N	2021-05-12 13:30:00	2021-05-12 14:40:00	\N	\N	1	0	\N	\N
559639	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Sous-direction du changement climatique et du développement durable	\N	2021-05-12 14:15:00	2021-05-12 15:00:00	\N	\N	1	0	\N	\N
559643	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Office français de la biodiversité	\N	2021-05-12 17:30:00	2021-05-12 18:00:00	\N	\N	1	0	\N	\N
559648	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-05-18 15:01:00	2021-05-18 17:11:00	2021-05-18 18:37:40	2021-05-19 15:31:24	28	0	\N	\N
588610	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Responsabilité pénale et sécurité intérieure	\N	2021-10-04 14:00:00	2021-10-04 18:20:00	\N	\N	1	0	\N	\N
622376	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Sébastien SURUN, ambassadeur de France en Mongolie	Entretien avec M. Sébastien SURUN, ambassadeur de France en Mongolie	2022-01-19 08:15:00	2022-01-19 08:50:00	\N	\N	1	0	612	\N
631798	GIA	AUCUNE	\N	\N	\N	Audition du recteur de l'Université Saint-Joseph de Beyrouth	Audition du Professeur Salim Daccache s.j., Recteur de l'Université Saint-Joseph de Beyrouth	2022-02-01 14:00:00	2022-02-01 15:00:00	\N	\N	7	0	597	\N
634635	MISSION	AUDRAP	\N	RECHINNO	\N	Ministère de l'économie, des finances et de la relance	Ministère de l'économie, des finances et de la relance	2022-02-17 15:00:00	2022-02-17 16:30:00	\N	\N	1	0	\N	\N
634637	MISSION	AUCUNE	\N	RECHINNO	\N	Audition plénière - France Stratégie	Audition plénière - France Stratégie	2022-02-17 16:30:00	2022-02-17 17:40:00	2022-02-18 10:08:27	2022-02-18 15:06:15	4	0	\N	\N
634642	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Audition BBelin et SBabary / VA et LB	\N	2022-02-16 18:30:00	2022-02-16 19:30:00	\N	\N	0	0	\N	\N
634694	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Collège des directeurs généraux de l'Agence régionale de santé	Audition de M. Jean-Yves Grall	2022-02-18 10:00:00	2022-02-18 10:30:00	\N	\N	1	0	\N	\N
634695	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Conférence des doyens des facultés de médecine	\N	2022-02-18 11:00:00	2022-02-18 12:15:00	\N	\N	1	0	\N	\N
634696	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Université de Bourgogne	\N	2022-02-18 12:15:00	2022-02-18 13:00:00	\N	\N	1	0	\N	\N
634697	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Audition de Mme Ammirati	\N	2022-02-17 15:00:00	2022-02-17 15:50:00	\N	\N	1	0	\N	\N
635762	MISSION	AUCUNE	\N	RECHINNO	\N	Audition de M. Emmanuel CHIVA, directeur de l¿Agence de l¿innovation de défense (AID)	Audition de M. Emmanuel CHIVA, directeur de l¿Agence de l¿innovation de défense (AID)	2022-02-22 15:05:00	2022-02-22 16:20:00	2022-02-23 10:19:01	2022-02-23 15:36:29	7	0	\N	\N
635772	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 23 février 2022	\N	2022-02-24 08:35:00	2022-02-24 10:50:00	2022-02-24 12:55:41	2022-02-24 14:42:37	65	0	\N	\N
635773	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	APCA	\N	2022-02-22 16:15:00	2022-02-22 17:00:00	\N	\N	0	0	\N	\N
635774	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Pôle du conseil indépendant en agriculture	\N	2022-02-22 13:45:00	2022-02-22 14:30:00	\N	\N	0	0	\N	\N
635789	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Fédération du négoce agricole	\N	2022-02-22 15:00:00	2022-02-22 15:30:00	\N	\N	0	0	\N	\N
635799	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	CerFrance	\N	2022-02-22 15:30:00	2022-02-22 16:15:00	\N	\N	0	0	\N	\N
635818	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI France compétences - Audition de l'Urssaf caisse nationale	\N	2022-03-01 09:00:00	2022-03-01 09:45:00	\N	\N	3	0	\N	\N
635819	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	GRCETA	\N	2022-02-22 16:30:00	2022-02-22 17:15:00	\N	\N	0	0	\N	\N
635821	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteurs	\N	2022-03-01 17:00:00	2022-03-01 18:00:00	\N	\N	2	0	\N	\N
635838	GIA	AUCUNE	\N	\N	\N	Assemblée générale du GIA France-Mexique-Pays d'Amérique centrale	Assemblée générale du GIA France-Mexique-Pays d'Amérique centrale	2022-02-23 08:15:00	2022-02-23 09:10:00	\N	\N	7	0	643	\N
635844	COM_ENQUETE	AUDRAP	\N	HOPITAL	\N	CE Hôpital - Audition du CNP IPA	\N	2022-02-22 16:30:00	2022-02-22 17:30:00	\N	\N	5	0	\N	\N
635852	COM_ENQUETE	AUDRAP	\N	HOPITAL	\N	CE Hôpital - Audition de la médiatrice nationale des personnels des EPS	\N	2022-02-22 17:30:00	2022-02-22 18:30:00	\N	\N	4	0	\N	\N
635854	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI France compétences - Audition de l'UMIH	\N	2022-03-08 09:00:00	2022-03-08 09:50:00	\N	\N	2	0	\N	\N
636010	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - Enseignants en Europe - Ambassade de France Berlin	Contrôle 2022 - Enseignants en Europe - Ambassade de France Berlin	2022-02-22 14:45:00	2022-02-22 15:30:00	\N	\N	1	0	\N	\N
636091	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 2022 - Adaptation réacteurs nucléaires - Cour des comptes	58-2 2022 - Adaptation réacteurs nucléaires - Cour des comptes	2022-02-14 10:30:00	2022-02-14 11:00:00	\N	\N	1	0	\N	\N
636155	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 2022 -  Installation des agriculteurs - Cour des comptes	58-2 2022 -  Installation des agriculteurs - Cour des comptes	2022-02-22 18:00:00	2022-02-22 19:00:00	\N	\N	2	0	\N	\N
636173	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Situation et perspectives SNCF - SNCF Réseau	Contrôle 2021 - Situation et perspectives SNCF - SNCF Réseau	2022-02-22 15:00:00	2022-02-22 16:00:00	\N	\N	2	0	\N	\N
636185	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Déplacement à l'aéroport d'Orly - MI "Reconnaissance faciale"	Déplacement à l'aéroport d'Orly - MI "Reconnaissance faciale"	2022-02-21 15:45:00	2022-02-21 20:15:00	\N	\N	2	0	\N	\N
636226	ETUDES	AUTRE	\N	\N	\N	Audition France Agrimer	Audition France Agrimer	2022-02-23 13:30:00	2022-02-23 14:30:00	\N	\N	17	0	\N	919
636655	GIA	AUCUNE	\N	\N	\N	Entretien avec Mme Yaël GERMAN, nouvelle Ambassadrice d¿Israël en France	Entretien avec Mme Yaël GERMAN, nouvelle Ambassadrice d¿Israël en France	2022-02-22 08:30:00	2022-02-22 09:30:00	\N	\N	16	0	595	\N
716640	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2023-03-09 10:46:00	2023-03-09 11:44:00	\N	\N	3	0	\N	\N
637241	COM_PERMANENTE	AUTRE	\N	CAE	\N	Communication nucléaire	\N	2022-02-24 10:55:00	2022-02-24 11:50:00	2022-04-26 15:27:47	2022-04-26 15:35:21	17	0	\N	\N
637280	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2022-02-24 08:40:00	2022-02-24 10:25:00	\N	\N	3	0	\N	\N
637284	ETUDES	AUTRE	\N	\N	\N	Audition de la FEDENE	Audition de la FEDENE	2022-02-23 16:40:00	2022-02-23 18:20:00	\N	\N	5	0	\N	906
637292	ETUDES	AUCUNE	\N	\N	\N	Audition de la FEDENE	Audition de la FEDENE	2022-02-23 16:40:00	2022-02-23 18:20:00	\N	\N	6	0	\N	948
637309	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI "Reconnaissance faciale"	MI "Reconnaissance faciale" - Auditions	2022-02-22 09:00:00	2022-02-22 11:00:00	\N	\N	4	0	\N	\N
637314	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI "Reconnaissance faciale"	MI "Reconnaissance faciale" - Auditions	2022-02-22 14:30:00	2022-02-22 17:00:00	\N	\N	3	0	\N	\N
637318	GIA	AUCUNE	\N	\N	\N	Entretien avec l'Ambassadeur de Roumanie en France	Entretien avec l'Ambassadeur de Roumanie en France	2022-02-24 10:30:00	2022-02-24 11:45:00	\N	\N	4	0	605	\N
637456	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2022-02-24 09:00:00	2022-02-24 11:00:00	\N	\N	5	0	\N	\N
637498	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI "Reconnaissance faciale"	MI "Reconnaissance faciale" - Auditions	2022-02-22 17:00:00	2022-02-22 18:00:00	\N	\N	2	0	\N	\N
637507	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	DSOM	Conférence de presse adoption rapport "Outre-mer et stratégie maritime nationale"	Conférence de presse adoption rapport "Outre-mer et stratégie maritime nationale"	2022-02-24 14:30:00	2022-02-24 15:35:00	\N	\N	4	0	\N	\N
637591	SEANCE_PLENIERE	AUTRE	\N	\N	\N	Lecture d'un message du PR	Lecture d'un message du PR	2022-02-25 14:30:00	2022-02-25 14:45:00	\N	\N	65	0	\N	\N
637594	GIA	AUCUNE	\N	\N	\N	Entretien avec une délégation de parlementaires du Monténégro	Entretien avec une délégation du Parlement du Monténégro	2022-02-24 11:45:00	2022-02-24 12:45:00	\N	\N	2	0	674	\N
637604	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	Commission d'Apuration des Comptes	Commission d'Apuration des Comptes	2022-02-23 16:30:00	2022-02-23 17:40:00	2022-02-24 16:08:19	2022-02-24 16:21:15	7	0	\N	\N
637808	DELEGATION	AUCUNE	\N	\N	211	Place des femmes dans l'entreprise : assurer la mixité à tous les échelons (DDF/DAE)	Place des femmes dans l'entreprise : assurer la mixité à tous les échelons (DDF/DAE)	2022-03-08 14:30:00	2022-03-08 17:25:00	2022-03-08 17:30:16	\N	7	0	\N	\N
637809	DELEGATION	AUCUNE	\N	\N	211	Table ronde avec des actrices, réalisatrices et productrices de films pornographiques	Table ronde avec des actrices, réalisatrices et productrices de films pornographiques	2022-03-09 14:30:00	2022-03-09 16:35:00	2022-03-09 16:38:17	\N	6	0	\N	\N
637810	DELEGATION	AUCUNE	\N	\N	211	Audition d¿Ovidie, réalisatrice de documentaires et auteure - Travaux sur la pornographie	Audition d¿Ovidie, réalisatrice de documentaires et auteure - Travaux sur la pornographie	2022-03-29 15:00:00	2022-03-29 16:10:00	\N	\N	8	0	\N	\N
637840	GIA	AUCUNE	\N	\N	\N	Entretien parlementaires andorrans	\N	2022-02-23 08:30:00	2022-02-23 09:45:00	\N	\N	6	0	963	\N
637861	COM_ENQUETE	AUDRAP	\N	HOPITAL	\N	CE Hôpital - Audition du Pr Catherine Paugam-Burtz	\N	2022-02-23 14:00:00	2022-02-23 15:00:00	\N	\N	1	0	\N	\N
637863	COM_ENQUETE	AUDRAP	\N	HOPITAL	\N	CE Hôpital - Audition du CHICAS Gap-Sisteron	\N	2022-02-24 09:15:00	2022-02-24 10:15:00	\N	\N	2	0	\N	\N
637866	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Rapport d'information « bilan des mesures éducatives du quinquennat	\N	2022-02-23 09:00:00	2022-02-23 10:50:00	2022-03-07 17:38:36	2022-03-07 17:59:29	30	0	\N	\N
637893	SEANCE_PLENIERE	DECL_GVT	\N	\N	\N	Déclaration du Gouvernement et débat Russie Ukraine	Déclaration du Gouvernement et débat Russie Ukraine	2022-03-01 19:00:00	2022-03-01 21:00:00	\N	\N	195	0	\N	\N
637894	ETUDES	AUTRE	\N	\N	\N	Echanges avec Marion Rousse, Tour de France Femmes	\N	2022-02-23 08:00:00	2022-02-23 09:15:00	\N	\N	20	0	\N	934
506768	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Création d'un pôle public du médicament et des produits médicaux	\N	2020-11-20 11:30:00	2020-11-20 12:30:00	\N	\N	3	0	\N	\N
506772	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Création d'un pôle public du médicament et des produits médicaux	\N	2020-11-20 16:00:00	2020-11-20 17:15:00	\N	\N	2	0	\N	\N
506775	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Création d'un pôle public du médicament et des produits médicaux	\N	2020-11-20 17:15:00	2020-11-20 18:15:00	\N	\N	4	0	\N	\N
506780	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Création d'un pôle public du médicament et des produits médicaux	\N	2020-11-20 18:15:00	2020-11-20 19:15:00	\N	\N	5	0	\N	\N
509267	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2020-12-02 09:30:00	2020-12-02 10:55:00	2020-12-02 11:53:53	2020-12-02 14:25:07	34	0	\N	\N
509268	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition Article 13 	\N	2020-12-02 11:05:00	2020-12-02 12:10:00	2020-12-02 12:49:23	2020-12-02 14:25:10	27	0	\N	\N
509270	DELEGATION	AUCUNE	\N	\N	DSOM	Réunion constitutive de la délégation	\N	2020-12-03 09:00:00	2020-12-03 10:00:00	\N	\N	29	0	\N	\N
509306	COM_EURO	AUTRE	\N	AFEU	\N	Audition de M. Valdis Dombrovskis - commission européenne	\N	2020-12-03 11:00:00	2020-12-03 12:25:00	2020-12-03 12:27:47	2020-12-03 17:15:26	13	0	\N	\N
509511	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	MI Vote à distance - Néovote	MI Vote à distance - Néovote	2020-11-26 13:30:00	2020-11-26 14:15:00	\N	\N	6	0	\N	\N
509551	COM_EURO	AUDRAP	\N	AFEU	\N	Allégation nutritionnelles et allégations de santé	Allégation nutritionnelles et allégations de santé - Pr. Ambroise MARTIN	2020-11-16 16:00:00	2020-11-16 17:20:00	\N	\N	1	0	\N	\N
509553	COM_EURO	AUDRAP	\N	AFEU	\N	Allégations nutritionnelles et allégations de santé	Allégations nutritionnelles et allégations de santé - Ania	2020-11-24 09:30:00	2020-11-24 10:30:00	\N	\N	1	0	\N	\N
509561	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur - Allégations nutritionnelles et allégations de santé	Allégations nutritionnelles et allégations de santé - FNSEA	2020-11-24 15:00:00	2020-11-24 16:00:00	\N	\N	1	0	\N	\N
509563	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Auditions du DGGN et du DGPN	Auditions du DGGN et du DGPN	2020-12-01 14:00:00	2020-12-01 17:10:00	2020-12-01 19:14:51	2020-12-02 09:42:51	40	0	\N	\N
509565	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désignations CMP - Examen de rapports et textes de la commission	Désignations CMP - Examen de rapports et textes de la commission	2020-12-02 09:00:00	2020-12-02 10:15:00	2020-12-02 11:08:00	2020-12-02 11:25:20	34	0	\N	\N
509572	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2021 - Réunion Examen d'un Amdt de crédit sur la mission « Plan de relance »	PLF pour 2021 - Réunion pour l'examen d'un amendement de crédit sur la mission « Plan de relance »	2020-11-26 17:38:00	2020-11-26 17:44:00	2020-11-27 14:17:41	2020-11-27 17:30:25	23	0	\N	\N
509671	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	MI Vote à distance - Direction de la modernisation et de l'administration territoriale	MI Vote à distance - Direction de la modernisation et de l'administration territoriale	2020-11-26 18:30:00	2020-11-26 19:55:00	\N	\N	8	0	\N	\N
509848	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-12-02 16:00:00	2020-12-02 17:40:00	2020-12-04 11:37:45	2020-12-04 15:10:23	54	0	\N	\N
509855	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2020-12-02 08:00:00	2020-12-02 10:17:00	2020-12-02 11:01:57	2020-12-02 11:25:18	38	1	\N	\N
509857	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2020-12-02 16:01:00	2020-12-02 17:39:00	2020-12-04 11:34:13	2020-12-04 15:10:25	54	1	\N	\N
509878	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Pôle public du médicament - Audition rapporteure	\N	2020-11-27 09:30:00	2020-11-27 10:30:00	\N	\N	3	0	\N	\N
509891	COM_PERMANENTE	AUTRE	\N	AFCL	\N	PPL Langues régionales	\N	2020-12-02 16:30:00	2020-12-02 17:45:00	2020-12-03 11:58:15	2020-12-03 17:14:50	26	0	\N	\N
509892	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition Nathalie Élimas - PLF 2021 examen d'avis budgétaires	\N	2020-12-02 08:45:00	2020-12-02 11:50:00	2020-12-02 13:18:18	2020-12-02 14:25:05	35	0	\N	\N
509898	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	MI Vote à distance - Le Groupe La Poste	MI Vote à distance - Le Groupe La Poste	2020-11-30 18:30:00	2020-11-30 19:45:00	\N	\N	8	0	\N	\N
509961	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	MI Vote à distance - Auditions et tables rondes	MI Vote à distance - Auditions et tables rondes	2020-12-03 14:05:00	2020-12-03 19:30:00	\N	\N	9	0	\N	\N
509962	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	MI Vote à distance - INSEE - Ministère de la transformation et de la fonction publiques	MI Vote à distance - INSEE - Ministère de la transformation et de la fonction publiques	2020-12-09 18:30:00	2020-12-09 19:45:00	\N	\N	7	0	\N	\N
509963	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2021 - Examen Amdts séance sur les Missions	PLF pour 2021 - Examen Amdts séance sur les Missions	2020-11-30 09:05:00	2020-11-30 09:45:00	2020-11-30 10:40:47	2020-11-30 17:53:41	23	0	\N	\N
509964	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2021 - Examen Tome III articles non rattachés	PLF pour 2021 - Examen Tome III articles non rattachés	2020-12-01 09:05:00	2020-12-01 09:30:00	2020-12-01 11:00:04	2020-12-01 15:13:43	21	0	\N	\N
509965	COM_PERMANENTE	AUTRE	\N	FINC	\N	PPL 477-Contribution assurances-Examen rapport - PLF pour 2021 - Amdts séance Mission RCT	PPL 477-Contribution assurances-Examen rapport - PLF pour 2021 - Amdts séance Mission RCT	2020-12-02 09:05:00	2020-12-02 10:10:00	2020-12-02 16:56:08	2020-12-02 17:46:13	33	0	\N	\N
509966	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2021 - Examen Amdts séance sur les Missions	PLF pour 2021 - Examen Amdts séance sur les Missions	2020-12-03 09:35:00	2020-12-03 09:55:00	2020-12-03 11:25:27	2020-12-03 17:14:51	22	0	\N	\N
509967	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2021 - articles non rattachés - Examen Amdts séance	PLF pour 2021 - articles non rattachés - Examen Amdts séance	2020-12-04 08:35:00	2020-12-04 09:15:00	2020-12-04 10:44:02	2020-12-04 11:03:04	19	0	\N	\N
510039	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Sécurités - Préfet de police de Paris	PLF pour 2021 - Sécurités - Préfet de police de Paris	2020-11-25 15:00:00	2020-11-25 16:00:00	\N	\N	1	0	\N	\N
510041	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - Rapport général - DGGN	PLF pour 2021 - Rapport général - DGGN	2020-11-26 08:30:00	2020-11-26 09:15:00	\N	\N	1	0	\N	\N
510044	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2021 - Pouvoirs publics - Questeur AN	PLF pour 2021 - Pouvoirs publics - Questeur AN	2020-11-25 10:45:00	2020-11-25 11:45:00	\N	\N	1	0	\N	\N
510051	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - APD - DGM MEAE	PLF pour 2021 - APD - DGM MEAE	2020-11-03 09:30:00	2020-11-03 10:30:00	\N	\N	2	0	\N	\N
510054	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2021 - APD - AFD	PLF pour 2021 - APD - AFD	2020-11-04 18:00:00	2020-11-04 19:00:00	\N	\N	2	0	\N	\N
510059	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL 477 - Contribution Assurances - FFA	PPL 477 - Contribution Assurances - FFA	2020-11-26 14:00:00	2020-11-26 14:45:00	\N	\N	1	0	\N	\N
510061	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL 477 - Contribution Assurances - DG Trésor	PPL 477 - Contribution Assurances - DG Trésor	2020-11-26 16:30:00	2020-11-26 17:00:00	\N	\N	1	0	\N	\N
510068	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2021 - MIRES - Cab MIN ESR	PLF pour 2021 - MIRES - Cab MIN ESR	2020-11-25 08:45:00	2020-11-25 10:15:00	\N	\N	1	0	\N	\N
510129	DELEGATION	AUCUNE	\N	\N	206	Audition publique sur l'uranium appauvri	Audition publique sur l'uranium appauvri	2020-12-03 09:30:00	2020-12-03 11:35:00	\N	\N	12	0	\N	\N
588286	GIA	AUCUNE	\N	\N	\N	GIA - Entretien avec une délégation kenyane	GIA - Entretien avec une délégation kenyane	2021-09-29 12:30:00	2021-09-29 14:30:00	\N	\N	1	0	622	\N
616311	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Aménagement du territoire - Audition de M. Belin	MI Aménagement du territoire - Audition de M. Belin	2021-12-14 15:10:00	2021-12-14 16:00:00	\N	\N	6	0	\N	\N
616318	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Aménagement du territoire - Audition de M. Belin	MI Aménagement du territoire - Audition de M. Belin	2021-12-14 16:00:00	2021-12-14 16:50:00	\N	\N	4	0	\N	\N
616323	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Aménagement du territoire - Audition de M. Belin	MI Aménagement du territoire - Audition de M. Belin	2021-12-14 16:50:00	2021-12-14 17:30:00	\N	\N	4	0	\N	\N
616329	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Aménagement du territoire - Audition de M. Belin	MI Aménagement du territoire - Audition de M. Belin	2021-12-15 17:50:00	2021-12-15 18:50:00	\N	\N	2	0	\N	\N
616332	GIA	AUCUNE	\N	\N	\N	Rencontre avec des représentant de Human Rights Watch	Human Rights Watch	2021-12-16 09:00:00	2021-12-16 10:00:00	\N	\N	2	0	632	\N
618012	COM_ENQUETE	PLENIERE	\N	HOPITAL	\N	Audition plénière	\N	2022-01-13 16:00:00	2022-01-13 17:35:00	2022-01-13 17:38:01	2022-01-13 18:48:12	12	0	\N	\N
619113	ETUDES	AUCUNE	\N	\N	\N	\N	\N	2022-01-11 15:00:00	2022-01-11 16:30:00	\N	\N	0	0	\N	909
621100	ETUDES	AUCUNE	\N	\N	\N	Audition CRESS Île-de-France et Hauts-de-France	Audition CRESS Île-de-France et Hauts-de-France	2022-01-13 13:30:00	2022-01-13 15:00:00	\N	\N	1	0	\N	998
621913	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2022-01-12 17:00:00	2022-01-12 17:50:00	\N	\N	27	0	\N	\N
621959	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Chèque emploi petites communes	\N	2022-01-17 14:00:00	2022-01-17 18:00:00	\N	\N	1	0	\N	\N
621961	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Chèque emploi petites communes	\N	2022-01-17 18:00:00	2022-01-17 19:00:00	\N	\N	2	0	\N	\N
621964	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Chèque emploi petites communes	\N	2022-01-18 09:30:00	2022-01-18 10:00:00	\N	\N	3	0	\N	\N
621968	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Chèque emploi petites communes	\N	2022-01-18 10:00:00	2022-01-18 10:45:00	\N	\N	4	0	\N	\N
622041	COM_PERMANENTE	AUDRAP	\N	CDD	\N	MI Aménagement du territoire - Audition Mmes Filleul et Herzog	MI Aménagement du territoire - Audition Mmes Filleul et Herzog	2022-01-11 16:30:00	2022-01-11 18:30:00	\N	\N	2	0	\N	\N
622048	COM_PERMANENTE	AUDRAP	\N	CDD	\N	MI Aménagement du territoire - Audition Mmes Filleul et Herzog	MI Aménagement du territoire - Audition Mmes Filleul et Herzog	2022-01-12 16:30:00	2022-01-12 17:30:00	\N	\N	2	0	\N	\N
624170	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de M. Franck Riester	Audition de M. Franck Riester	2022-01-25 17:35:00	2022-01-25 19:00:00	2022-01-26 13:46:26	2022-01-26 14:25:08	42	0	\N	\N
624171	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Examen amendts séance AEFE et communication ONU	Examen amendts séance AEFE et communication ONU	2022-01-26 10:00:00	2022-01-26 12:10:00	2022-01-26 14:03:41	2022-01-26 14:25:12	35	3	\N	\N
624173	COM_ENQUETE	PLENIERE	\N	CABINETS	\N	Auditions plénières - Martin HIRSCH, DG APHP - Didier MIGAUD, Pdt HATVP	Auditions plénières - Martin HIRSCH, Directeur général de l'APHP - Didier MIGAUD, Président de la HATVP	2022-01-26 16:30:00	2022-01-26 19:00:00	2022-01-26 19:00:30	2022-01-27 12:35:52	9	0	\N	\N
624175	COM_ENQUETE	AUDRAP	\N	CABINETS	\N	Auditions rapporteure - Laure BEDIER, DAJ MIN ECOFIN-Thomas DAUTIEU, Dir. conformité CNIL	Auditions rapporteure - Laure BEDIER, DAJ MIN ECOFIN-Thomas DAUTIEU, Dir. conformité CNIL	2022-01-27 10:30:00	2022-01-27 12:30:00	\N	\N	6	0	\N	\N
627099	DELEGATION	AUCUNE	\N	\N	211	Table ronde sur le bilan de l'application de la loi Sauvadet	Table ronde sur le bilan de l'application de la loi Sauvadet	2022-02-24 08:00:00	2022-02-24 10:40:00	\N	\N	7	0	\N	\N
627100	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition PPRE Pacte vert	Audition PPRE Pacte vert	2022-01-27 15:00:00	2022-01-27 16:00:00	\N	\N	2	0	\N	\N
627157	MISSION	AUCUNE	\N	JUDI	\N	Auditions : présidents de la Cour de justice de la République - Cécile Guérin-Bargues	Auditions : présidents de la Cour de justice de la République - Cécile Guérin-Bargues	2022-02-01 15:00:00	2022-02-01 17:20:00	2022-02-01 17:34:42	2022-02-01 18:16:10	9	0	\N	\N
627387	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Association des DRAC de France	\N	2022-02-01 14:00:00	2022-02-01 15:00:00	\N	\N	5	0	\N	\N
627393	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Groupement des entreprises de restauration de monuments historiques (GMH)	\N	2022-02-01 15:00:00	2022-02-01 16:00:00	\N	\N	4	0	\N	\N
628858	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL ratification convention double nationalité Espagne 	PJL ratification convention double nationalité Espagne 	2022-02-02 17:00:00	2022-02-02 18:00:00	\N	\N	1	0	\N	\N
631352	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Innovation en santé - Audition du CEPS	\N	2022-02-09 16:30:00	2022-02-09 17:05:00	\N	\N	4	0	\N	\N
631368	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 17 février 2022	Réunion du 17 février 2022	2022-02-17 09:30:00	2022-02-17 10:40:00	2022-02-17 10:42:19	2022-02-17 16:42:33	14	0	\N	\N
631495	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Aménagement du territoire - B. Rojouan	MI Aménagement du territoire - B. Rojouan	2022-01-27 14:30:00	2022-01-27 17:30:00	\N	\N	1	0	\N	\N
631497	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL France Qatar	PJL France Qatar	2022-02-15 14:30:00	2022-02-15 15:35:00	\N	\N	63	0	\N	\N
631502	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Aménagement du territoire - B. Rojouan	MI Aménagement du territoire - B. Rojouan	2022-02-08 15:30:00	2022-02-08 16:30:00	\N	\N	1	0	\N	\N
631505	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PJL Harkis	CMP PJL Harkis	2022-02-15 15:35:00	2022-02-15 16:40:00	\N	\N	83	0	\N	\N
631506	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Choix du nom	PPL Choix du nom	2022-02-15 16:45:00	2022-02-15 19:15:00	\N	\N	111	0	\N	\N
631507	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Restitution biens culturels	PJL Restitution biens culturels	2022-02-15 19:20:00	2022-02-15 20:45:00	\N	\N	48	0	\N	\N
631534	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Aménagement du territoire - Audition commune	MI Aménagement du territoire - Audition commune	2022-02-09 18:30:00	2022-02-09 19:30:00	\N	\N	3	0	\N	\N
631538	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Aménagement du territoire - Audition de MM. Belin et Babary	MI Aménagement du territoire - Audition de MM. Belin et Babary	2022-02-10 11:00:00	2022-02-10 11:45:00	\N	\N	2	0	\N	\N
631566	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2022-02-16 15:00:00	2022-02-16 16:20:00	\N	\N	248	0	\N	\N
631567	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Lanceurs d'alerte et défenseur des droits	CMP Lanceurs d'alerte et défenseur des droits	2022-02-16 16:35:00	2022-02-16 17:30:00	\N	\N	36	0	\N	\N
631568	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	NL PPL Démocratiser le sport	NL PPL Démocratiser le sport	2022-02-16 17:30:00	2022-02-16 19:20:00	\N	\N	72	0	\N	\N
631569	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	NL PPL Renforcer le droit à l'avortement	NL PPL Renforcer le droit à l'avortement	2022-02-16 19:20:00	2022-02-16 20:25:00	\N	\N	49	0	\N	\N
631571	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	2L PJL Collectivité européenne d'Alsace	2L PJL Collectivité européenne d'Alsace	2022-02-17 10:30:00	2022-02-17 12:00:00	\N	\N	44	0	\N	\N
631572	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	NL PJL Harcèlement scolaire	NL PJL Harcèlement scolaire	2022-02-17 12:00:00	2022-02-17 12:55:00	\N	\N	31	0	\N	\N
631573	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	NL PJL Harcèlement scolaire	NL PJL Harcèlement scolaire	2022-02-17 14:30:00	2022-02-17 15:05:00	\N	\N	28	0	\N	\N
631574	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Aménagement du Rhône	CMP Aménagement du Rhône	2022-02-17 15:05:00	2022-02-17 16:00:00	\N	\N	29	0	\N	\N
631575	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Assurance emprunteur	CMP Assurance emprunteur	2022-02-17 16:00:00	2022-02-17 17:00:00	\N	\N	35	0	\N	\N
631576	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Données cadastrales	PPL Données cadastrales	2022-02-17 17:05:00	2022-02-17 18:10:00	\N	\N	20	0	\N	\N
522795	ETUDES	AUCUNE	\N	\N	\N	Audition FNC	Réunion - audition FNC	2021-01-20 08:00:00	2021-01-20 09:30:00	\N	\N	32	0	\N	907
537374	GIA	AUCUNE	\N	\N	\N	Forum de dialogue sur l¿Etat de droit - Format triangle de Weimar	Forum de dialogue sur l¿Etat de droit - Format triangle de Weimar	2021-02-18 10:00:00	2021-02-18 17:30:00	\N	\N	1	0	600	\N
537733	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes - Examen de rapport d¿information	\N	2021-03-04 10:30:00	2021-03-04 11:30:00	\N	\N	0	0	\N	\N
537745	COM_EURO	AUTRE	\N	AFEU	\N	Audition de Mme Mairead McGuinness	\N	2021-03-04 10:30:00	2021-03-04 11:40:00	\N	\N	0	0	\N	\N
537783	COM_PERMANENTE	AUTRE	\N	CAE	\N	Rapport d'information Suicide des agriculteurs	\N	2021-03-17 08:35:00	2021-03-17 10:25:00	2021-03-18 12:29:01	2021-03-18 17:52:22	37	0	\N	\N
537784	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition du président de Sanofi France	\N	2021-03-17 10:35:00	2021-03-17 12:15:00	2021-03-18 12:03:51	2021-03-18 17:52:21	67	0	\N	\N
537909	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2021-03-17 09:15:00	2021-03-17 10:30:00	2021-03-17 10:27:19	2021-03-17 16:58:58	32	0	\N	\N
537910	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière- Audition M. Bogillot, Président de SANOFI France	Réunion plénière- Audition de M. Bogillot, Président de SANOFI France	2021-03-17 10:35:00	2021-03-17 12:15:00	2021-03-17 17:01:36	2021-03-18 17:52:21	66	0	\N	\N
545188	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2021-03-25 10:00:00	2021-03-25 13:00:00	\N	\N	7	0	\N	\N
546081	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	VISIO APM	Conférence virtuelle conjointe organisée par l'APM et TURKPA, l'Assemblée  parlementaire des pays turcophones	2021-03-30 10:30:00	2021-03-30 13:00:00	\N	\N	1	0	\N	\N
550437	ETUDES	AUCUNE	\N	\N	\N	Audition Section cultures traditionnelles et spécialisées	Audition Section cultures traditionnelles et spécialisées	2021-04-07 13:30:00	2021-04-07 15:00:00	\N	\N	23	0	\N	1005
554246	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2021-04-08 09:05:00	2021-04-08 11:15:00	\N	\N	3	0	\N	\N
554371	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT Boussole stratégique	\N	2021-04-12 15:00:00	2021-04-12 16:30:00	\N	\N	2	0	\N	\N
555031	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR 34-1 Régime de garantie des salaires	PPR 34-1 Régime de garantie des salaires	2021-05-04 14:30:00	2021-05-04 15:50:00	\N	\N	70	0	\N	\N
555032	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Avenir Nouvelle-Calédonie	Débat Avenir Nouvelle-Calédonie	2021-05-04 16:00:00	2021-05-05 17:50:00	\N	\N	117	0	\N	\N
555033	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat sur la souveraineté économique	Débat sur la souveraineté économique	2021-05-04 17:55:00	2021-05-04 18:45:00	\N	\N	59	0	\N	\N
555034	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Future PAC	Débat Future PAC	2021-05-04 21:30:00	2021-05-04 23:15:00	\N	\N	62	0	\N	\N
555035	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2021-05-05 15:00:00	2021-05-05 16:20:00	\N	\N	221	0	\N	\N
555036	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Réponse européenne Covid-19	Débat Réponse européenne Covid-19	2021-05-05 16:30:00	2021-05-05 18:10:00	\N	\N	60	0	\N	\N
555037	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat CRTE	Débat CRTE	2021-05-05 18:10:00	2021-05-05 19:45:00	\N	\N	43	0	\N	\N
555038	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Réduction Loyer Solidarité	Débat Réduction Loyer Solidarité	2021-05-05 21:30:00	2021-05-05 22:55:00	\N	\N	23	0	\N	\N
555039	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2021-05-06 09:30:00	2021-05-06 12:15:00	\N	\N	39	0	\N	\N
555040	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat  concessions autoroutières	Débat  concessions autoroutières	2021-05-06 14:30:00	2021-05-06 16:00:00	\N	\N	44	0	\N	\N
555041	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Écriture inclusive	Débat Écriture inclusive	2021-05-06 16:00:00	2021-05-06 17:30:00	\N	\N	43	0	\N	\N
555042	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	 PPR 34-1 Taïwan	 PPR 34-1 Taïwan	2021-05-06 17:30:00	2021-05-07 18:50:00	\N	\N	23	0	\N	\N
557677	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJLC article 1er de la Constitution préservation de l'environnement	PJLC article 1er de la Constitution et relatif à la préservation de l'environnement	2021-05-10 17:30:00	2021-05-10 19:50:00	\N	\N	75	0	\N	\N
557684	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJLC article 1er de la Constitution préservation de l'environnement	PJLC article 1er de la Constitution et relatif à la préservation de l'environnement	2021-05-10 21:35:00	2021-05-11 23:40:00	\N	\N	68	0	\N	\N
557688	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL développement solidaire et à la lutte contre les inégalités mondiales	PJL développement solidaire et à la lutte contre les inégalités mondiales	2021-05-11 14:30:00	2021-05-11 20:00:00	\N	\N	112	0	\N	\N
557690	SEANCE_PLENIERE	AUTRE	\N	\N	\N	PJL développement solidaire et à la lutte contre les inégalités mondiales	PJL développement solidaire et à la lutte contre les inégalités mondiales	2021-05-11 21:30:00	2021-05-12 00:20:00	\N	\N	57	0	\N	\N
557693	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2021-05-12 15:00:00	2021-05-12 16:20:00	\N	\N	166	0	\N	\N
557694	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL développement solidaire et à la lutte contre les inégalités mondiales	PJL développement solidaire et à la lutte contre les inégalités mondiales	2021-05-12 16:35:00	2021-05-12 19:00:00	\N	\N	65	0	\N	\N
560916	ETUDES	AUCUNE	\N	\N	\N	Table ronde sur les plateformes numériques coopératives	Table ronde sur les plateformes numériques coopératives	2021-05-19 08:30:00	2021-05-19 09:30:00	\N	\N	7	0	\N	998
561545	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL Accord France-Inde pour les migrations et la mobilité	\N	2021-05-12 10:00:00	2021-05-12 11:00:00	\N	\N	1	0	\N	\N
561553	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL Accord France-Inde pour les migrations et la mobilité	Audition de l'ambassadeur d'Inde en France	2021-05-14 15:30:00	2021-05-14 16:30:00	\N	\N	1	0	\N	\N
562268	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Soins palliatifs - Table ronde de professionnels en soins palliatifs	\N	2021-05-20 10:00:00	2021-05-20 12:00:00	\N	\N	6	0	\N	\N
562275	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Soins palliatifs - Table ronde de sociétés savantes	\N	2021-05-19 16:30:00	2021-05-19 18:00:00	\N	\N	4	0	\N	\N
562276	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Innovation en santé - Table ronde de grands groupes pharmaceutiques	\N	2021-05-19 13:30:00	2021-05-19 15:00:00	\N	\N	3	0	\N	\N
562280	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Innovation en santé - Table ronde sur les essais cliniques	\N	2021-05-17 14:30:00	2021-05-17 16:00:00	\N	\N	5	0	\N	\N
562286	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Innovation en santé - Table ronde d'acteurs institutionnels	\N	2021-05-17 16:30:00	2021-05-17 18:15:00	\N	\N	3	0	\N	\N
562291	MISSION	AUDRAP	\N	EGALCHAN	\N	MI Égalité des chances - Audition de l'UNML	\N	2021-05-18 15:30:00	2021-05-18 16:50:00	\N	\N	3	0	\N	\N
562292	MISSION	AUDRAP	\N	EGALCHAN	\N	MI Égalité des chances - Audition de la CNAF	\N	2021-05-18 17:00:00	2021-05-18 18:40:00	\N	\N	2	0	\N	\N
562293	MISSION	AUDRAP	\N	EGALCHAN	\N	MI Égalité des chances - Audition de M. Marc Guillaume, préfet de la région Île-de-France	\N	2021-05-19 17:00:00	2021-05-19 17:45:00	\N	\N	1	0	\N	\N
563544	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	Groupe de travail institutions	Groupe de travail institutions	2021-05-20 15:30:00	2021-05-20 18:35:00	\N	\N	4	0	\N	\N
634643	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Aménagement du territoire - Audition de MM. Belin et Babary	MI Aménagement du territoire - Audition de MM. Belin et Babary	2022-02-17 18:30:00	2022-02-17 19:30:00	\N	\N	1	0	\N	\N
566153	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition sur la sortie des aides aux entreprises et Controle Haut conseil pour le climat	Audition sur la sortie des aides aux entreprises et Controle Haut conseil pour le climat	2021-06-09 09:10:00	2021-06-09 12:00:00	2021-06-09 16:13:01	2021-06-09 17:44:53	30	0	\N	\N
566156	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition MM. Vacher et Benjamin	\N	2021-06-08 16:15:00	2021-06-08 17:15:00	\N	\N	3	0	\N	\N
566176	DELEGATION	AUDRAP	\N	\N	COLTER	Rapport santé - auditions	\N	2021-06-03 14:00:00	2021-06-03 15:30:00	\N	\N	0	0	\N	\N
566179	MISSION	AUTRE	\N	HARCEL	\N	Audition plénière	\N	2021-06-09 16:30:00	2021-06-09 19:30:00	\N	\N	0	0	\N	\N
566180	DELEGATION	AUDRAP	\N	\N	COLTER	Rapport santé - auditions	\N	2021-06-10 14:00:00	2021-06-10 16:30:00	\N	\N	0	0	\N	\N
566181	MISSION	AUCUNE	\N	HARCEL	\N	Réunion du 10 juin 2021	Réunion du 10 juin 2021	2021-06-10 10:35:00	2021-06-10 13:30:00	2021-06-10 15:44:16	2021-06-10 18:08:28	8	0	\N	\N
566205	DELEGATION	AUDRAP	\N	\N	COLTER	Rapport santé - table ronde	\N	2021-06-17 14:00:00	2021-06-17 15:45:00	\N	\N	0	0	\N	\N
621378	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Inspection générale de l'éducation, du sport et de la recherche	Audition de M. Sidokpohou	2022-01-13 11:30:00	2022-01-13 13:00:00	\N	\N	3	0	\N	\N
621379	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Institut national supérieur du professorat et de l'éducation	\N	2022-01-04 15:30:00	2022-01-04 17:00:00	\N	\N	3	0	\N	\N
621399	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteurs - Ambassade d'Albanie S.E.M. Dritan Tola	Audition rapporteurs -processus d'élargissement de l'UE - Ambassade d'Albanie S.E.M. Dritan Tola	2022-01-20 16:30:00	2022-01-20 17:30:00	\N	\N	2	0	\N	\N
621403	MISSION	AUCUNE	\N	RECHINNO	\N	Audition Didier ROUX	\N	2022-01-19 16:30:00	2022-01-19 17:40:00	2022-01-21 19:07:27	2022-01-24 15:30:28	9	0	\N	\N
621404	MISSION	AUCUNE	\N	RECHINNO	\N	Audition ESPCI 	\N	2022-01-18 15:30:00	2022-01-18 16:35:00	2022-01-21 19:04:53	2022-01-24 15:30:26	12	0	\N	\N
621405	MISSION	AUCUNE	\N	RECHINNO	\N	Audition CNRS	\N	2022-01-18 17:00:00	2022-01-18 18:35:00	2022-01-21 19:06:06	2022-01-24 15:30:26	9	0	\N	\N
621406	MISSION	AUCUNE	\N	RECHINNO	\N	Audition M. Patrice CAINE	\N	2022-01-19 17:45:00	2022-01-19 19:00:00	2022-01-21 19:08:08	2022-01-24 15:30:21	7	0	\N	\N
621410	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Gestion de la crise sanitaire (nouvelle lecture) - rapport et texte de la commission	PJL Gestion de la crise sanitaire (nouvelle lecture) - rapport et texte de la commission	2022-01-15 11:35:00	2022-01-15 12:20:00	2022-01-15 12:41:18	2022-01-17 10:56:56	28	1	\N	\N
621411	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Gestion de la crise sanitaire (nouvelle lecture) - amendements de séance	PJL Gestion de la crise sanitaire (nouvelle lecture) - amendements de séance	2022-01-15 17:25:00	2022-01-15 17:45:00	2022-01-15 17:57:11	2022-01-17 10:56:57	18	2	\N	\N
621426	ETUDES	AUTRE	\N	\N	\N	Audition M. Hervé Gaymard	Audition M. Hervé Gaymard	2022-01-12 08:00:00	2022-01-12 09:30:00	\N	\N	30	0	\N	919
621457	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Coordination Rurale	Audition Coordination Rurale	2022-01-11 14:00:00	2022-01-11 14:30:00	\N	\N	3	0	\N	\N
621458	COM_PERMANENTE	AUTRE	\N	AFCL	\N	PPL démocratisation du sport - amendements extérieurs 	\N	2022-01-18 09:00:00	2022-01-18 10:55:00	2022-01-25 08:24:12	2022-01-25 18:13:15	21	1	\N	\N
621462	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition de Confédération paysanne	\N	2022-01-11 14:30:00	2022-01-11 15:00:00	\N	\N	3	0	\N	\N
621466	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Fédération fruits et légumes	Audition Fédération fruits et légumes	2022-01-11 15:00:00	2022-01-11 15:45:00	\N	\N	4	0	\N	\N
621471	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Groupama	\N	2022-01-11 15:45:00	2022-01-11 16:15:00	\N	\N	6	0	\N	\N
621478	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Ministère de l'agriculture, de l'agroalimentaire et de la forêt - DGPE	\N	2022-01-11 16:15:00	2022-01-11 17:00:00	\N	\N	7	0	\N	\N
621486	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Fédération française de l'assurance	\N	2022-01-11 17:45:00	2022-01-11 18:30:00	\N	\N	4	0	\N	\N
621491	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Aviva Abeille assurances	\N	2022-01-11 17:00:00	2022-01-11 17:45:00	\N	\N	4	0	\N	\N
621496	COM_PERMANENTE	AUDRAP	\N	CAE	\N	FNSEA	\N	2022-01-11 18:30:00	2022-01-11 19:00:00	\N	\N	4	0	\N	\N
621501	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition AGPB	Audition AGPB PJL Outils de gestion des risques climatiques en agriculture	2022-01-12 14:00:00	2022-01-12 14:30:00	\N	\N	0	0	\N	\N
621502	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Audition PDemas / CB - CDC	\N	2022-01-12 14:00:00	2022-01-12 14:55:00	\N	\N	0	0	\N	\N
621507	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PJL Gestion de la crise sanitaire - Réunion plénière 	\N	2022-01-15 11:10:00	2022-01-15 11:30:00	2022-01-15 11:39:46	2022-01-17 10:56:55	20	1	\N	\N
621510	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désignations CMP -  PPL Protection lanceurs d'alerte -  PPLO Défenseur des droits (amdts)	Désignations CMP -  PPL Protection lanceurs d'alerte -  PPLO Défenseur des droits (amdts)	2022-01-19 09:40:00	2022-01-19 10:20:00	2022-01-19 10:34:23	2022-01-19 17:06:55	36	0	\N	\N
621511	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Réforme de l'adoption (nouvelle lecture) - rapport	PPL Réforme de l'adoption (nouvelle lecture) - rapport	2022-01-19 17:05:00	2022-01-19 17:20:00	2022-01-19 17:31:14	2022-01-20 11:34:57	15	0	\N	\N
621512	COM_ENQUETE	PLENIERE	\N	MEDIA	\N	Audition M. Eveno (15h30) et M. Liberty (16h30)	\N	2022-01-17 15:30:00	2022-01-17 17:30:00	2022-01-17 19:47:08	2022-01-18 17:41:51	13	0	\N	\N
621513	COM_ENQUETE	PLENIERE	\N	MEDIA	\N	Audition de M. Vincent Bolloré	\N	2022-01-19 16:45:00	2022-01-19 18:45:00	2022-01-19 19:27:43	2022-01-20 11:34:02	19	0	\N	\N
621514	COM_ENQUETE	AUTRE	\N	MEDIA	\N	audition CE Médias	\N	2022-01-20 16:30:00	2022-01-20 18:30:00	\N	\N	0	0	\N	\N
621515	COM_ENQUETE	AUTRE	\N	MEDIA	\N	Audition  de M. Xavier Niel	\N	2022-01-21 10:30:00	2022-01-21 13:30:00	\N	\N	0	0	\N	\N
621516	COM_ENQUETE	PLENIERE	\N	MEDIA	\N	Audition MM. Nicolas Beytout, Éric Fottorino,  Edwy Plenel,  Mme Isabelle Roberts,  	\N	2022-01-21 14:30:00	2022-01-21 17:35:00	2022-01-21 19:18:36	2022-01-24 15:30:23	13	0	\N	\N
626221	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PPL Aménagement du Rhône	Audition PPL Aménagement du Rhône	2022-01-19 12:00:00	2022-01-19 12:45:00	\N	\N	1	0	\N	\N
629122	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de M. Maros Sefcovic	\N	2022-02-08 15:00:00	2022-02-08 16:20:00	2022-02-09 11:58:10	2022-02-10 18:02:27	26	0	\N	\N
629123	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de Mme Florence Parly	\N	2022-02-08 16:30:00	2022-02-08 18:00:00	2022-02-09 12:18:04	2022-02-10 18:02:28	28	0	\N	\N
629124	COM_PERMANENTE	AUTRE	\N	ETRD	\N	4 conventions + audition de M. Eric Danon, ambassadeur	\N	2022-02-09 09:30:00	2022-02-09 11:45:00	2022-02-09 12:17:33	2022-02-10 18:02:30	36	4	\N	\N
632330	MISSION	AUDRAP	\N	FONDSMER	\N	Audition IxBlue	Audition IxBLue	2022-02-15 17:00:00	2022-02-15 18:00:00	\N	\N	5	0	\N	\N
632561	MISSION	AUDRAP	\N	FONDSMER	\N	Audition JL Levet	Audition JL Levet	2022-02-15 18:00:00	2022-02-15 19:15:00	\N	\N	5	0	\N	\N
634712	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ambassadeur d'Albanie	Entretien avec S.E.M. Dritan Tola, ambassadeur d'Albanie en France	2022-02-16 14:00:00	2022-02-16 15:00:00	\N	\N	9	0	571	\N
634820	GIA	AUCUNE	\N	\N	\N	Entretien avec Mme Farkhonda Zahra NADERI, ancienne Députée et militante féministe afghane	Entretien avec Mme Farkhonda Zahra NADERI, ancienne Députée et militante féministe afghane	2022-02-16 19:45:00	2022-02-16 20:30:00	\N	\N	4	0	648	\N
634825	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	206	Réunion du bureau commune avec la direction générale de l'Inrae	Réunion du bureau commune avec la direction générale de l'Inrae	2022-02-02 17:00:00	2022-02-02 18:30:00	\N	\N	6	0	\N	\N
635338	GIA	AUCUNE	\N	\N	\N	déjeuner avec l'ambassadeur du Maroc	déjeuner avec l'ambassadeur du Maroc	2022-02-22 13:00:00	2022-02-22 15:00:00	\N	\N	33	0	598	\N
635632	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion sur la PPRE sur le paquet "Ajustement à l'objectif 55"	\N	2022-02-24 08:35:00	2022-02-24 10:50:00	2022-02-24 17:47:35	2022-02-24 17:54:23	64	0	\N	\N
635785	MISSION	AUDRAP	\N	JUDI	\N	\N	Audition rapporteur - MI Judiciarisation	2022-02-22 16:00:00	2022-02-22 17:40:00	\N	\N	5	0	\N	\N
635790	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	 Fédération du négoce agricole	 Fédération du négoce agricole	2022-02-22 15:00:00	2022-02-22 15:30:00	\N	\N	8	0	\N	\N
635800	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	CerFrance	CerFrance	2022-02-22 15:30:00	2022-02-22 16:15:00	\N	\N	9	0	\N	\N
635811	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	APCA	APCA	2022-02-22 17:30:00	2022-02-22 18:00:00	\N	\N	6	0	\N	\N
635822	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	\N	Groupement de Recherche sur les Cultures et Techniques Agricoles	2022-02-22 16:15:00	2022-02-22 17:00:00	\N	\N	8	0	\N	\N
635881	GIA	AUCUNE	\N	\N	\N	Réunion groupe d'amitié France-Canada - Visio Ambassadrice K.Rispal	Réunion groupe d'amitié France-Canada - Visio Ambassadrice K.Rispal	2022-02-22 14:30:00	2022-02-22 15:45:00	\N	\N	10	0	583	\N
635891	GIA	AUCUNE	\N	\N	\N	Réunion groupe d'amitié France-Canada - petit dej avec Jocelyn Coulon	Réunion groupe d'amitié France-Canada - petit dej avec Jocelyn Coulon, ancien conseiller de J. Trudeau	2022-02-23 08:30:00	2022-02-23 09:45:00	\N	\N	3	0	583	\N
516276	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2020-12-10 13:04:00	2020-12-10 13:10:00	2020-12-11 08:27:12	2020-12-11 11:52:13	15	0	\N	\N
516539	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière - Audition publique Pr. Jérôme Salomon, DG de la santé	Réunion plénière - Audition publique Pr. Jérôme Salomon, DG de la santé	2020-12-10 17:35:00	2020-12-10 19:20:00	\N	\N	9	0	\N	\N
516547	GIA	AUCUNE	\N	\N	\N	Assemblée générale GIA France - Pays-Bas	Assemblée générale GIA France - Pays-Bas	2020-12-15 16:30:00	2020-12-15 17:30:00	\N	\N	4	0	599	\N
518760	GIA	AUCUNE	\N	\N	\N	Assemblée générale	\N	2020-12-15 15:00:00	2020-12-15 15:25:00	\N	\N	6	0	575	\N
518767	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Le respect de la propriété immobilière contre le squat	PPL Le respect de la propriété immobilière contre le squat	2020-12-17 09:00:00	2020-12-17 09:45:00	\N	\N	1	0	\N	\N
518769	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Le respect de la propriété immobilière contre le squat	PPL Le respect de la propriété immobilière contre le squat	2020-12-17 10:45:00	2020-12-17 13:00:00	\N	\N	1	0	\N	\N
518771	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Le respect de la propriété immobilière contre le squat	PPL Le respect de la propriété immobilière contre le squat	2020-12-18 11:15:00	2020-12-18 12:45:00	\N	\N	1	0	\N	\N
518773	GIA	AUCUNE	\N	\N	\N	AG de GIA	Assemblée générale constitutive	2020-12-15 12:00:00	2020-12-15 12:45:00	\N	\N	2	0	585	\N
518776	GIA	AUCUNE	\N	\N	\N	Préparation AG	Préparation de l'assemblée générale constitutive	2020-12-15 11:30:00	2020-12-15 12:00:00	\N	\N	1	0	585	\N
518821	GIA	AUCUNE	\N	\N	\N	AG reconstitutive du bureau du groupe France-Balkans occidentaux	\N	2020-12-10 13:30:00	2020-12-10 14:00:00	\N	\N	9	0	674	\N
518831	GIA	AUCUNE	\N	\N	\N	AG reconstitutive du bureau du groupe France-Maroc	\N	2020-12-09 14:00:00	2020-12-09 14:30:00	\N	\N	30	0	598	\N
519156	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Droit à l'avortement - Audition de Mme Marie-Pierre Rixain	\N	2021-01-05 14:30:00	2021-01-05 15:30:00	\N	\N	2	0	\N	\N
519157	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Droit à l'avortement - Table ronde DGOS et DGS	\N	2021-01-05 15:30:00	2021-01-05 16:30:00	\N	\N	2	0	\N	\N
519162	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2021-01-13 09:30:00	2021-01-13 11:30:00	2021-01-13 17:49:42	2021-01-14 16:25:16	41	0	\N	\N
519163	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Départements solidaires	\N	2021-01-06 14:30:00	2021-01-06 15:30:00	\N	\N	2	0	\N	\N
519164	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Association Jeunes	\N	2021-01-06 15:30:00	2021-01-06 17:00:00	\N	\N	4	0	\N	\N
519165	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition ADF	\N	2021-01-06 17:00:00	2021-01-06 18:00:00	\N	\N	3	0	\N	\N
522114	GIA	AUCUNE	\N	\N	\N	\N	\N	2021-01-19 17:00:00	2021-01-19 19:00:00	\N	\N	0	0	\N	\N
522115	GIA	AUCUNE	\N	\N	\N	Auditions du groupe d'amitié France-Afrique de l'Ouest	Auditions du Directeur Afrique et Océan indien et de l'Ambassadeur du Togo en France par GIA France-Afrique de l'Ouest	2021-01-19 17:00:00	2021-01-19 19:00:00	\N	\N	14	0	573	\N
522571	DELEGATION	AUCUNE	\N	\N	PROS	Audition de M. Olivier Babeau, professeur à l'université de Bordeaux	Audition de M. Olivier Babeau, professeur à l'université de Bordeaux	2021-01-28 08:30:00	2021-01-28 10:00:00	\N	\N	23	0	\N	\N
522659	DELEGATION	AUDRAP	\N	\N	PROS	Audition de Sabine Barles	Audition de Sabine Barles, chercheuse, urbaniste-prospectiviste, à l'Université Paris 1 Panthéon-Sorbonne	2021-02-04 12:00:00	2021-02-04 13:00:00	\N	\N	1	0	\N	\N
523497	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	 Améliorer le système de santé par la confiance et la simplification	\N	2021-01-20 19:00:00	2021-01-20 20:30:00	\N	\N	4	0	\N	\N
523498	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	 Améliorer le système de santé par la confiance et la simplification	\N	2021-01-21 09:00:00	2021-01-21 10:15:00	\N	\N	4	0	\N	\N
524182	COM_PERMANENTE	DEPLACEMENT	\N	CAE	\N	Déplacement GT Agriculteurs en détresse	Déplacement GT Agriculteurs en détresse	2021-01-21 08:30:00	2021-01-21 12:30:00	\N	\N	4	0	\N	\N
524188	COM_PERMANENTE	DEPLACEMENT	\N	CAE	\N	Déplacement GT Agriculteurs en détresse	Déplacement GT Agriculteurs en détresse	2021-01-21 14:00:00	2021-01-21 18:00:00	\N	\N	5	0	\N	\N
524194	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition GT Nouvelles formes de commerce	Auditions GT Nouvelles formes de commerce	2021-01-22 14:00:00	2021-01-22 15:00:00	\N	\N	2	0	\N	\N
529119	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Réunion M. Lamy - HCECM	Réunion M. Lamy - HCECM	2021-02-03 16:30:00	2021-02-03 17:45:00	\N	\N	2	0	\N	\N
529230	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI "Difficultés des entreprises et crise de la Covid-19"	Audition rapporteur - MI "Difficultés des entreprises et crise de la Covid-19"	2021-02-08 09:30:00	2021-02-08 10:30:00	\N	\N	2	0	\N	\N
529233	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI "Difficultés des entreprises et crise de la Covid-19"	Audition rapporteur - MI "Difficultés des entreprises et crise de la Covid-19"	2021-02-08 11:30:00	2021-02-08 12:30:00	\N	\N	2	0	\N	\N
629385	COM_ENQUETE	PLENIERE	\N	MEDIA	\N	rn médias	\N	2022-02-10 10:30:00	2022-02-10 12:40:00	2022-02-10 14:18:35	2022-02-10 18:00:50	10	0	\N	\N
529236	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	LOIS	\N	MI "Difficultés des entreprises et crise de la Covid-19"	Réunion de travail - MI "Difficultés des entreprises et crise de la Covid-19"	2021-02-08 10:30:00	2021-02-08 11:30:00	\N	\N	2	0	\N	\N
531322	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière - Audition publique Impact des champs électromagnétiques 	Réunion plénière - Audition publique Impact des champs électromagnétiques 	2021-02-18 09:00:00	2021-02-18 13:15:00	\N	\N	9	0	\N	\N
531525	GIA	AUCUNE	\N	\N	\N	Réunion Ambassadeur de France en Italie	Réunion avec M. Masset, Ambassadeur de France en Italie	2021-02-08 18:00:00	2021-02-08 19:20:00	\N	\N	24	0	621	\N
533729	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Rapporteur -  PPL améliorer le système de santé	Commission des affaires sociales - Audition PPL Améliorer le système de santé	2021-02-01 16:30:00	2021-02-01 17:30:00	\N	\N	3	0	\N	\N
533928	DELEGATION	AUCUNE	\N	\N	211	Table ronde sur l'entreprenariat des femmes dans les territoires ruraux	Table ronde sur l'entreprenariat des femmes dans les territoires ruraux	2021-03-25 08:30:00	2021-03-25 10:35:00	2021-03-25 11:39:14	\N	14	0	\N	\N
533931	DELEGATION	AUCUNE	\N	\N	211	Table ronde sur la loi  du 13 avril 2016	Table ronde sur la loi  du 13 avril 2016	2021-04-08 08:30:00	2021-04-08 12:20:00	2021-04-08 16:07:55	\N	18	0	\N	\N
534090	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Droit à mourir dans la dignité	\N	2021-02-18 15:30:00	2021-02-18 16:30:00	\N	\N	6	0	\N	\N
534097	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions PPL voitures de collection	\N	2021-02-17 16:30:00	2021-02-17 18:45:00	\N	\N	2	0	\N	\N
535227	ETUDES	AUCUNE	\N	\N	\N	Audition M. Tribon	Audition M. Tribon	2021-03-02 13:30:00	2021-03-02 14:30:00	\N	\N	7	0	\N	912
536075	ETUDES	AUCUNE	\N	\N	\N	Audition M. Jarlier	Audition M. Jarlier	2021-03-03 08:15:00	2021-03-03 09:15:00	\N	\N	22	0	\N	948
536132	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition Séché Environnement	Audition Séché Environnement	2021-03-02 16:00:00	2021-03-02 17:00:00	\N	\N	5	0	\N	\N
536138	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition Saur	Audition Saur	2021-03-02 17:10:00	2021-03-02 18:05:00	\N	\N	4	0	\N	\N
536144	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition Amorce	Audition Amorce	2021-03-02 18:00:00	2021-03-02 19:00:00	\N	\N	2	0	\N	\N
536434	GIA	AUCUNE	\N	\N	\N	audition par visio conférence de l'ambassadeur du Maroc en France 	\N	2021-03-03 10:00:00	2021-03-03 11:30:00	\N	\N	9	0	598	\N
536855	DELEGATION	AUDRAP	\N	\N	211	Audition de Mmes Marine Renard et Claire Caminade de la FNCIDFF, sur « Toutesport ! »	Audition de Mmes Marine Renard et Claire Caminade de la FNCIDFF, sur « Toutesport ! »	2021-03-05 10:30:00	2021-03-05 12:00:00	\N	\N	6	0	\N	\N
543748	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Financement aires protégées - Fédération PNR de France	Contrôle 2021 - Financement aires protégées - Fédération PNR de France	2021-03-23 09:15:00	2021-03-23 10:30:00	\N	\N	1	0	\N	\N
543753	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Financement aires protégées - France nature environnement	Contrôle 2021 - Financement aires protégées - France nature environnement	2021-03-23 13:30:00	2021-03-23 15:00:00	\N	\N	1	0	\N	\N
543755	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Services dédiés à la recherche patrimoniale - LRMH/DRASSM	Contrôle 2021 - Services dédiés à la recherche patrimoniale - LRMH/DRASSM	2021-03-23 14:00:00	2021-03-23 16:00:00	\N	\N	1	0	\N	\N
543758	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Syndication - BdF/Sté Générale	Contrôle 2021 - Syndication - BdF/Sté Générale	2021-03-23 16:00:00	2021-03-23 18:05:00	\N	\N	1	0	\N	\N
615941	DELEGATION	AUDRAP	\N	\N	211	Audition de Mme Nassim Majidi, chercheuse	Audition de Mme Nassim Majidi, chercheuse	2021-12-16 11:00:00	2021-12-16 12:00:00	\N	\N	3	0	\N	\N
616113	DELEGATION	AUCUNE	\N	\N	206	Audition publique sur le Covid long	Audition publique sur le Covid long	2021-12-16 09:10:00	2021-12-16 12:20:00	\N	\N	9	0	\N	\N
618124	COM_EURO	AUTRE	\N	AFEU	\N	Audition de M. Clément Beaune, secrétaire d'État chargé des affaires eruopéennes	Audition de M. Clément Beaune, secrétaire d'État chargé des affaires eruopéennes	2022-01-06 09:00:00	2022-01-06 11:00:00	2022-01-06 10:57:06	2022-01-06 17:49:01	23	0	\N	\N
622073	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Fonction publique des communes de Polynésie française	Audition rapporteur Fonction publique des communes de Polynésie française	2022-01-18 08:30:00	2022-01-18 09:30:00	\N	\N	2	0	\N	\N
622077	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Fonction publique des communes de Polynésie française	\N	2022-01-18 09:30:00	2022-01-18 11:00:00	\N	\N	1	0	\N	\N
625729	MISSION	AUDRAP	\N	JUDI	\N	\N	Audition rapporteur - MI Judiciarisation	2022-01-26 13:55:00	2022-01-26 15:00:00	\N	\N	5	0	\N	\N
626862	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat wokisme	Débat wokisme	2022-02-01 14:30:00	2022-02-01 16:25:00	\N	\N	83	0	\N	\N
626863	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat politique ferroviaire	Débat politique ferroviaire pour assurer un maillage équilibré du territoire	2022-02-01 16:30:00	2022-02-01 18:00:00	\N	\N	61	0	\N	\N
626865	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat sur le suivi des ordonnances	Débat sur le suivi des ordonnances	2022-02-01 18:05:00	2022-02-01 19:35:00	\N	\N	69	0	\N	\N
626866	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Mieux protéger notre patrimoine scientifique et nos libertés académiques	Débat Mieux protéger notre patrimoine scientifique et nos libertés académiques	2022-02-01 21:30:00	2022-02-02 23:05:00	\N	\N	26	0	\N	\N
626873	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2022-02-02 15:00:00	2022-02-02 16:20:00	\N	\N	245	0	\N	\N
626874	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Énergie et pouvoir d'achat	Débat Énergie et pouvoir d'achat	2022-02-02 16:35:00	2022-02-02 17:45:00	\N	\N	48	0	\N	\N
626875	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Allocations familiales	PPL Caractère universel aux allocations familiales	2022-02-02 18:15:00	2022-02-02 19:40:00	\N	\N	58	0	\N	\N
626877	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Trouble du déficit de l¿attention	Débat Trouble du déficit de l¿attention	2022-02-02 19:40:00	2022-02-02 21:00:00	\N	\N	37	0	\N	\N
626880	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2022-02-03 10:30:00	2022-02-03 12:25:00	\N	\N	29	0	\N	\N
626881	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Chanvre	Débat Chanvre	2022-02-03 14:30:00	2022-02-03 16:05:00	\N	\N	42	0	\N	\N
626882	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Violences faites aux femmes	Débat Violences faites aux femmes	2022-02-03 16:10:00	2022-02-03 18:15:00	\N	\N	36	0	\N	\N
626884	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Plan de relance dans le cadre de la crise sanitaire	Débat Plan de relance dans le cadre de la crise sanitaire	2022-02-03 18:15:00	2022-02-03 20:00:00	\N	\N	21	0	\N	\N
629386	COM_ENQUETE	PLENIERE	\N	MEDIA	\N	audition MM Solly et Weill	\N	2022-02-10 14:05:00	2022-02-10 17:00:00	2022-02-11 19:26:41	2022-02-14 18:17:02	14	0	\N	\N
629387	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Innovation en santé - Table ronde Recherche	\N	2022-02-02 13:30:00	2022-02-02 15:00:00	\N	\N	4	0	\N	\N
629388	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Innovation en santé - Audition conjointe DGS/ANSM	\N	2022-02-02 16:30:00	2022-02-02 18:00:00	\N	\N	1	0	\N	\N
629389	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Innovation en santé - Audition de la HAS	\N	2022-02-03 15:00:00	2022-02-03 15:45:00	\N	\N	1	0	\N	\N
629391	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Innovation en santé - Table ronde Recherche en santé observationnelle	\N	2022-02-03 15:45:00	2022-02-03 17:15:00	\N	\N	1	0	\N	\N
629399	COM_PERMANENTE	AUTRE	\N	CAE	\N	PJL Assurance récolte - Examen des amendements de séance 	\N	2022-02-08 14:35:00	2022-02-08 15:15:00	2022-02-08 16:25:57	2022-02-09 10:41:41	29	0	\N	\N
629400	COM_EURO	AUDRAP	\N	AFEU	\N	Paquet climat - Volet transports - FNAM	Paquet climat - Volet transports - FNAM	2022-02-07 10:00:00	2022-02-07 10:50:00	\N	\N	2	0	\N	\N
629408	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Sports d'hiver	\N	2022-02-02 13:30:00	2022-02-02 14:45:00	\N	\N	0	0	\N	\N
629423	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Emploi pour les chômeurs de longue durée - Audition de la DGEFP	\N	2022-02-07 14:00:00	2022-02-07 15:00:00	\N	\N	4	0	\N	\N
634053	MISSION	AUCUNE	\N	RECHINNO	\N	Audition plénière INRIA	Audition plénière de M. Bruno SPORTISSE, président-directeur général de l¿INRIA	2022-02-16 16:45:00	2022-02-16 17:40:00	2022-02-17 14:45:17	2022-02-17 16:47:27	7	0	\N	\N
634066	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Auditions communes 	\N	2022-02-15 14:30:00	2022-02-15 18:30:00	\N	\N	0	0	\N	\N
634153	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition ASN	Audition ASN	2022-02-16 16:30:00	2022-02-16 17:00:00	\N	\N	3	0	\N	\N
634171	DELEGATION	AUCUNE	\N	\N	COLTER	Réunion plénière : Sauvadet et Hazan	Audition de M. SAUVADET (ADF) + examen du rapport d'information sur la démocratie locale + audition de Mme HAZAN	2022-02-17 09:00:00	2022-02-17 12:10:00	\N	\N	24	0	\N	\N
634228	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition RTE et EDF	Audition RTE et EDF	2022-02-17 13:30:00	2022-02-17 14:30:00	\N	\N	3	0	\N	\N
634247	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Audition MCC Sécurisation de la chasse	\N	2022-02-15 09:45:00	2022-02-15 10:45:00	\N	\N	0	0	\N	\N
634248	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	La fondation droit animal, éthique et sciences	\N	2022-02-15 15:15:00	2022-02-15 16:15:00	\N	\N	0	0	\N	\N
634249	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Association Animal Cross	\N	2022-02-15 16:15:00	2022-02-15 17:15:00	\N	\N	0	0	\N	\N
634307	MISSION	AUCUNE	\N	RECHINNO	\N	Audition plénière - Mme F. Vidal, ministre de l'enseignement supérieur	Audition plénière - Mme F. Vidal, ministre de l'enseignement supérieur, de la recherche et de l'innovation	2022-02-17 10:30:00	2022-02-17 11:30:00	2022-02-17 15:15:30	2022-02-17 16:47:24	5	0	\N	\N
634326	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Fonction publique des communes de Polynésie française (amendements)	PJL Fonction publique des communes de Polynésie française (amendements)	2022-02-21 16:30:00	2022-02-21 16:42:00	2022-02-21 16:46:04	2022-02-22 16:39:56	9	0	\N	\N
634329	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désignations - PPL/PPLO Elections et covid (amendements)	Désignations - PPL/PPLO Elections et covid (amendements)	2022-02-23 08:30:00	2022-02-23 08:50:00	2022-02-23 09:10:30	2022-02-23 15:35:59	23	0	\N	\N
634330	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Auditions art. 13 : Julien Boucher (OFPRA) - François Séners - Jacqueline Gourault (CC)	Auditions art. 13 : Julien Boucher (OFPRA) - François Séners - Jacqueline Gourault (CC)	2022-02-23 09:00:00	2022-02-23 12:20:00	2022-02-23 13:48:04	2022-02-23 15:35:58	40	1	\N	\N
634331	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Choix du nom issu de la filiation (nouvelle lecture) (rapport)	PPL Choix du nom issu de la filiation (nouvelle lecture) (rapport)	2022-02-23 14:00:00	2022-02-23 14:20:00	2022-02-23 14:32:17	2022-02-23 15:35:55	10	1	\N	\N
634332	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Choix du nom issu de la filiation (nouvelle lecture) (amendements)	PPL Choix du nom issu de la filiation (nouvelle lecture) (amendements)	2022-02-24 14:00:00	2022-02-24 15:00:00	\N	\N	0	0	\N	\N
634363	MISSION	AUCUNE	\N	CULTURE	\N	Réunion 20220223a	\N	2022-02-23 13:35:00	2022-02-23 14:30:00	2022-02-23 14:31:56	2022-02-23 15:36:30	2	0	\N	\N
634366	MISSION	AUCUNE	\N	CULTURE	\N	Réunion 20220223b	\N	2022-02-23 16:45:00	2022-02-23 18:05:00	2022-02-23 18:05:31	2022-02-24 14:43:04	6	0	\N	\N
634432	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-02-22 15:30:00	2022-02-22 16:00:00	2022-02-22 16:34:22	2022-02-22 16:39:55	22	0	\N	\N
634433	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-02-22 09:00:00	2022-02-22 10:00:00	2022-02-22 10:00:54	2022-02-22 16:39:55	18	0	\N	\N
634459	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de M. Bruno LE MAIRE sur les dossiers de la Présidence française de l'UE	Audition de M. Bruno LE MAIRE sur les dossiers dans le cadre de la Présidence française de l'Union européenne	2022-02-22 16:30:00	2022-02-22 17:55:00	2022-02-23 09:19:37	2022-02-23 15:35:59	38	0	\N	\N
634460	COM_PERMANENTE	AUTRE	\N	FINC	\N	Contrôle budgétaire IHU et Audition 58-2 sur les mesures de soutien à l'aéronautique	Contrôle budgétaire sur les IHU et Audition 58-2 sur les mesures de soutien à l'industrie aéronautique	2022-02-23 10:00:00	2022-02-23 12:40:00	2022-02-23 13:12:38	2022-02-23 15:35:55	30	0	\N	\N
527026	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rappporteurs - M. Malvy	\N	2021-02-04 17:00:00	2021-02-04 18:10:00	\N	\N	2	0	\N	\N
527033	DELEGATION	AUCUNE	\N	\N	PROS	Audition  de Mme Séverine Arsène, chercheuse	Audition  de Mme Séverine Arsène, chercheuse associée au Médialab de Sciences Po et enseignante à l¿Université chinois	2021-02-11 08:35:00	2021-02-11 09:50:00	\N	\N	20	0	\N	\N
529199	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL Achmea	\N	2021-02-05 11:00:00	2021-02-05 11:55:00	\N	\N	1	0	\N	\N
529213	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Respect principes de la République - Auditions	FNEP	2021-02-04 10:30:00	2021-02-04 11:40:00	\N	\N	5	0	\N	\N
531508	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	Visio APM Bureau des Nations Unies contre le terrorisme	Assemblée parlementaire de la Méditerrannée  	2021-02-15 16:00:00	2021-02-15 18:50:00	\N	\N	1	0	\N	\N
532028	DELEGATION	AUCUNE	\N	\N	PROS	Conférence de presse  "mobilités dans les espaces peu denses"	Conférence de presse "mobilités dans les espaces peu denses"	2021-02-16 17:00:00	2021-02-16 17:50:00	\N	\N	2	0	\N	\N
538768	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Table ronde entreprises électro-instensives 	Table ronde entreprises électro-instensives 	2021-03-03 14:00:00	2021-03-03 15:00:00	\N	\N	2	0	\N	\N
538783	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur - Fondation du patrimoine	Audition de M. Giuglaris, Fondation du patrimoine	2021-03-11 17:00:00	2021-03-11 18:00:00	\N	\N	2	0	\N	\N
538784	ETUDES	AUCUNE	\N	\N	\N	Réunion reconstitutive	Réunion reconstitutive	2021-03-10 08:30:00	2021-03-10 09:15:00	\N	\N	11	0	\N	998
538910	DELEGATION	AUDRAP	\N	\N	PROS	Audition du Health Data Hub	Audition du Health Data Hub	2021-03-22 15:30:00	2021-03-22 16:30:00	\N	\N	3	0	\N	\N
542090	ETUDES	AUCUNE	\N	\N	\N	Audition de Mme Olivia Grégoire	Audition de Mme Olivia Grégoire	2021-03-17 08:30:00	2021-03-17 09:30:00	\N	\N	10	0	\N	998
542102	MISSION	PLEIN_NON_JO	\N	METHANIS	\N	Audition ENGIE, GrDF et GRT gaz	Audition ENGIE, GrDF et GRT gaz	2021-03-17 16:30:00	2021-03-17 18:15:00	\N	\N	15	0	\N	\N
542120	ETUDES	AUCUNE	\N	\N	\N	Audition de M. de Chalendar	Audition de M. de Chalendar	2021-03-17 13:30:00	2021-03-17 14:30:00	\N	\N	15	0	\N	906
542160	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Suivi loi SRU	Auditions Suivi loi SRU	2021-03-17 09:45:00	2021-03-17 10:30:00	\N	\N	2	0	\N	\N
542238	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Auditions GT "objectif de zéro artificialisation nette"	Auditions GT "objectif de zéro artificialisation nette"	2021-03-17 13:45:00	2021-03-17 15:00:00	\N	\N	3	0	\N	\N
542242	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Auditions GT "objectif de zéro artificialisation nette"	Auditions GT "objectif de zéro artificialisation nette"	2021-03-17 16:30:00	2021-03-17 19:00:00	\N	\N	3	0	\N	\N
542443	DELEGATION	AUCUNE	\N	\N	COLTER	Auditions simplification normes : B. Lasserre, VP Conseil d'Etat ; C. Landais, SGG	\N	2021-03-25 09:30:00	2021-03-25 12:30:00	2021-03-25 14:40:19	\N	21	0	\N	\N
544108	ETUDES	AUCUNE	\N	\N	\N	Audition ANJ	Audition ANJ	2021-03-23 10:00:00	2021-03-23 10:45:00	\N	\N	1	0	\N	912
563688	GIA	AUCUNE	\N	\N	\N	\N	Entretien avec M. Payadowa BOUKPESSI, ministre d'État, ministre de la décentralisation du Togo	2021-05-26 16:25:00	2021-05-26 17:25:00	\N	\N	2	0	573	\N
563739	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Fathi Bashagha, ancien Ministre libyen	Entretien avec M. Fathi Bashagha, ancien Ministre de l'Intérieur  du Gouvernement d'Accord national (2018-2021)	2021-05-26 16:15:00	2021-05-26 17:15:00	\N	\N	1	0	657	\N
566260	MISSION	AUCUNE	\N	EGALCHAN	\N	Réunion plénière MI Jeunes	\N	2021-06-09 16:51:00	2021-06-09 17:53:00	2021-06-09 17:54:39	2021-06-10 11:57:29	5	0	\N	\N
566272	DELEGATION	AUCUNE	\N	\N	DSOM	Adoption du rapport sur le logement dans les outre-mer	Adoption du rapport sur le logement dans les outre-mer	2021-07-01 15:00:00	2021-07-01 15:55:00	\N	\N	8	0	\N	\N
566306	COM_PERMANENTE	AUTRE	\N	CAE	\N	Amendements rapporteurs PJL Climat	\N	2021-06-09 09:35:00	2021-06-09 10:35:00	2021-06-09 12:08:54	2021-06-09 12:27:29	32	0	\N	\N
566406	DELEGATION	AUDRAP	\N	\N	COLTER	Rapport métropole - auditions	\N	2021-04-15 14:00:00	2021-04-15 15:00:00	\N	\N	0	0	\N	\N
566407	DELEGATION	AUDRAP	\N	\N	COLTER	Rapport métropole - auditions	\N	2021-04-15 15:00:00	2021-04-15 16:00:00	\N	\N	0	0	\N	\N
566408	DELEGATION	AUDRAP	\N	\N	COLTER	Rapport métropoles - table ronde conclusive	\N	2021-06-09 17:00:00	2021-06-09 18:00:00	\N	\N	0	0	\N	\N
566518	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Haut Karabakh	\N	2021-06-01 15:00:00	2021-06-01 16:00:00	\N	\N	1	0	\N	\N
566520	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Haut Karabakh	\N	2021-06-01 16:00:00	2021-06-01 17:00:00	\N	\N	2	0	\N	\N
566878	COM_SPECIALE	PLENIERE	\N	BIOETHIQUE	\N	Examen du rapport en nouvelle lecture	\N	2021-06-15 14:00:00	2021-06-15 14:45:00	2021-06-15 15:52:08	2021-06-18 18:53:33	25	0	\N	\N
567162	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - IHU - DGRI/CNRS/DGOS/INSERM	Contrôle 2021 - IHU - DGRI/CNRS/DGOS/INSERM	2021-06-08 09:00:00	2021-06-08 13:00:00	\N	\N	2	0	\N	\N
567186	GIA	AUCUNE	\N	\N	\N	GIA-Entretien avec M. Muktar Al Assam	GIA-Entretien avec M. Muktar Al Assam	2021-05-19 11:30:00	2021-05-19 12:30:00	\N	\N	2	0	588	\N
567189	ETUDES	AUCUNE	\N	\N	\N	Audition ANCGG	Audition ANCGG	2021-06-09 08:00:00	2021-06-09 09:30:00	\N	\N	11	0	\N	907
567210	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Réunion du groupe de travail du Bureau de l'AP-OTAN sur la résilience démocratique	\N	2021-06-02 15:00:00	2021-06-02 17:00:00	\N	\N	0	0	\N	\N
567376	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-06-14 14:30:00	2021-06-14 16:00:00	2021-06-14 15:46:05	2021-06-14 17:46:25	21	1	\N	\N
567377	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-06-14 20:02:00	2021-06-14 20:09:00	2021-06-14 20:42:20	2021-06-15 12:11:03	19	1	\N	\N
567378	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-06-15 08:30:00	2021-06-15 10:00:00	\N	\N	0	0	\N	\N
567379	COM_PERMANENTE	AUTRE	\N	CDD	\N	\N	\N	2021-06-16 09:32:00	2021-06-16 10:42:00	2021-06-16 11:26:15	2021-06-16 18:11:05	28	2	\N	\N
567380	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2021-06-17 08:30:00	2021-06-17 10:00:00	\N	\N	0	0	\N	\N
567596	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition plénière PPL Renforcer la prévention en santé au travail	\N	2021-06-15 17:00:00	2021-06-15 18:20:00	2021-06-15 18:24:57	2021-06-16 18:10:51	20	0	\N	\N
567611	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Rapport pour avis PJL Prévention d'actes de terrorisme	\N	2021-06-15 14:30:00	2021-06-15 15:21:00	2021-06-15 16:08:59	2021-06-16 18:10:50	23	1	\N	\N
567613	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2021-06-16 09:30:00	2021-06-16 11:05:00	2021-06-16 11:33:05	2021-06-16 18:10:54	27	0	\N	\N
567614	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition P Mathiot/B Bobkiewicz (réforme bac)	\N	2021-06-16 09:30:00	2021-06-16 12:00:00	2021-06-22 14:13:20	\N	24	0	\N	\N
567688	COM_PERMANENTE	AUTRE	\N	FINC	\N	Contrôles budgétaires Attractivité enseignant mathématiques & Aides à la presse écrite	Contrôles budgétaires Attractivité enseignant mathématiques & Aides à la presse écrite	2021-06-16 09:30:00	2021-06-16 10:55:00	2021-06-16 12:09:44	2021-06-16 18:10:53	29	0	\N	\N
567703	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Action Logement	Audition Action Logement	2021-06-08 15:30:00	2021-06-08 16:30:00	\N	\N	3	0	\N	\N
567709	COM_PERMANENTE	AUTRE	\N	CAE	\N	Avis amendements PJL Climat	\N	2021-06-15 09:35:00	2021-06-15 10:10:00	2021-06-15 11:16:56	2021-06-15 12:11:04	19	0	\N	\N
567710	COM_PERMANENTE	AUTRE	\N	CAE	\N	Avis amendements PJL Climat	\N	2021-06-16 09:35:00	2021-06-16 10:40:00	2021-06-16 18:45:28	2021-06-17 12:32:16	30	0	\N	\N
567711	COM_PERMANENTE	AUTRE	\N	CAE	\N	Avis amendements PJL Climat	\N	2021-06-14 15:00:00	2021-06-14 15:30:00	2021-06-15 11:13:08	2021-06-15 12:11:02	15	0	\N	\N
567951	ETUDES	AUCUNE	\N	\N	\N	Audition animaleries	Audition animaleries	2021-06-09 13:15:00	2021-06-09 14:30:00	\N	\N	4	0	\N	1011
568015	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT Puissance chinoise en Europe	\N	2021-06-08 14:00:00	2021-06-08 15:00:00	\N	\N	2	0	\N	\N
568020	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT Puissance chinoise en Europe	\N	2021-06-09 16:30:00	2021-06-09 17:30:00	\N	\N	3	0	\N	\N
568024	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT Puissance chinoise en Europe	\N	2021-06-10 09:30:00	2021-06-10 10:30:00	\N	\N	3	0	\N	\N
568028	DELEGATION	AUCUNE	\N	\N	COLTER	Audition de l'ANCT	\N	2021-06-10 09:30:00	2021-06-10 11:20:00	\N	\N	18	0	\N	\N
692402	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition M. Paul Chalvin	\N	2023-01-20 15:45:00	2023-01-20 16:30:00	\N	\N	1	0	\N	\N
568047	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Mineurs non accompagnés - Audition de la DGEF	\N	2021-06-08 17:00:00	2021-06-08 18:05:00	\N	\N	3	0	\N	\N
568051	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Mineurs non accompagnés - Audition de l'OFPRA	\N	2021-06-09 16:30:00	2021-06-09 17:35:00	\N	\N	5	0	\N	\N
568057	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Mineurs non accompagnés - Audition du Procureur de la République	\N	2021-06-09 17:35:00	2021-06-09 18:35:00	\N	\N	3	0	\N	\N
615517	GIA	AUCUNE	\N	\N	\N	Déjeuner de travail avec l'Ambassadeur de Jordanie	Déjeuner de travail avec l'Ambassadeur de Jordanie	2021-09-21 12:30:00	2021-09-21 14:30:00	\N	\N	12	0	659	\N
615536	GIA	AUCUNE	\N	\N	\N	Entretien avec l'Ambassadrice de France en Jordanie	Entretien avec l'Ambassadrice de France en Jordanie	2021-02-18 15:00:00	2021-02-18 16:00:00	\N	\N	4	0	659	\N
616345	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PPL Enclos	\N	2021-12-22 10:00:00	2021-12-22 10:45:00	\N	\N	2	0	\N	\N
616348	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2022-01-05 10:05:00	2022-01-05 11:52:00	2022-01-05 12:37:13	2022-01-05 17:10:06	44	0	\N	\N
629306	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PJL activité professionnelle indépendante	CMP PJL activité professionnelle indépendante	2022-02-08 14:30:00	2022-02-08 15:25:00	\N	\N	43	0	\N	\N
629307	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	LEC PPL Aménagement du Rhône	LEC PPL Aménagement du Rhône	2022-02-08 15:30:00	2022-02-08 16:25:00	\N	\N	60	0	\N	\N
629308	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Risques climatiques en agriculture	PJL Risques climatiques en agriculture	2022-02-08 17:00:00	2022-02-08 20:00:00	\N	\N	117	0	\N	\N
629309	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Risques climatiques en agriculture	PJL Risques climatiques en agriculture	2022-02-08 21:30:00	2022-02-08 23:45:00	\N	\N	59	0	\N	\N
629310	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2022-02-09 15:00:00	2022-02-09 16:20:00	\N	\N	257	0	\N	\N
629311	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PJL 3DS	CMP PJL 3DS	2022-02-09 16:35:00	2022-02-09 17:40:00	\N	\N	87	0	\N	\N
629312	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	NL PPLO et PPL Financement de la sécurité sociale	NL PPLO et PPL Financement de la sécurité sociale	2022-02-09 17:40:00	2022-02-09 18:45:00	\N	\N	40	0	\N	\N
629313	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Contrôle parental Internet 	PPL Contrôle parental Internet 	2022-02-09 18:50:00	2022-02-09 20:25:00	\N	\N	34	0	\N	\N
629315	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2022-02-02 16:41:00	2022-02-02 17:45:00	\N	\N	3	0	\N	\N
629319	GIA	AUCUNE	\N	\N	\N	Rencontre avec l'ambassadrice de la République de Moldavie en France	Rencontre avec l'ambassadrice de la République de Moldavie en France, S.E.M. Corina Calugaru	2022-02-04 11:00:00	2022-02-04 12:00:00	\N	\N	1	0	851	\N
629323	COM_ENQUETE	PLENIERE	\N	CABINETS	\N	Echange de vues entre les membres de la commission d'enquête	Echange de vues entre les membres de la commission d'enquête	2022-02-08 17:00:00	2022-02-08 17:55:00	2022-02-08 18:17:10	2022-02-09 10:41:04	9	0	\N	\N
629324	COM_ENQUETE	PLENIERE	\N	CABINETS	\N	Auditions plénières - TR Écoles service public - TR Syndicats fonction publique	Auditions plénières - TR Écoles service public - TR Syndicats fonction publique	2022-02-09 16:30:00	2022-02-09 19:00:00	2022-02-10 12:35:27	2022-02-10 18:00:49	10	0	\N	\N
629328	COM_ENQUETE	AUDRAP	\N	CABINETS	\N	Audition rapporteure - M. Martin Vial DG APE - M. Michaël Nathan, Directeur SIG	Audition rapporteure - M. Martin Vial DG APE - M. Michaël Nathan, Directeur SIG	2022-02-10 10:30:00	2022-02-10 12:30:00	\N	\N	7	0	\N	\N
631594	COM_ENQUETE	PLENIERE	\N	CABINETS	\N	Auditions plénières - TR grandes entreprises publiques - TR cabinets de conseil	Auditions plénières - TR grandes entreprises publiques - TR cabinets de conseil	2022-02-16 16:30:00	2022-02-16 19:45:00	2022-02-16 19:48:48	2022-02-17 16:47:29	9	0	\N	\N
631641	DELEGATION	AUCUNE	\N	\N	DSOM	Définition du programme de travail de la délégation	Définition du programme de travail de la délégation	2022-02-17 09:30:00	2022-02-17 10:25:00	\N	\N	14	0	\N	\N
631644	GIA	AUCUNE	\N	\N	\N	Entretien sur le Fonds des Ecoles d'Orient	Entretien du Président avec AMF, ADF, AFD et régions de France sur le soutien aux écoles francophones chrétiennes au MO	2022-02-08 15:30:00	2022-02-08 16:30:00	\N	\N	2	0	CHRETORIENT	CHRETORIENT
631650	COM_PERMANENTE	AUDRAP	\N	CDD	\N	MI Aménagement du territoire - Audition Mmes Filleul et Herzog	MI Aménagement du territoire - Audition Mmes Filleul et Herzog	2022-02-08 14:00:00	2022-02-08 18:15:00	\N	\N	2	0	\N	\N
631656	ETUDES	AUCUNE	\N	\N	\N	Numérique	GE Numérique	2022-02-10 14:30:00	2022-02-10 16:30:00	\N	\N	10	0	\N	1008
631806	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2022-02-15 09:30:00	2022-02-15 12:50:00	\N	\N	47	0	\N	\N
631867	GIA	AUCUNE	\N	\N	\N	Entretien avec Mme Michele Boccoz, ambassadeur	Enetretien en visioconférence avec Mme Michele Boccoz, ambassadeur en Micronésie	2022-02-14 09:30:00	2022-02-14 10:30:00	\N	\N	7	0	651	\N
632335	DELEGATION	AUDRAP	\N	\N	206	Impacts de la crise vis-à-vis des maladies infectieuses en population générale	\N	2022-01-17 15:00:00	2022-01-17 16:00:00	\N	\N	3	0	\N	\N
632407	DELEGATION	AUCUNE	\N	\N	206	Rencontre Office - Académies sur le thème "L'enseignement des sciences"	Rencontre Office - Académies sur le thème "L'enseignement des sciences"	2022-01-26 08:30:00	2022-01-26 10:00:00	\N	\N	9	0	\N	\N
632423	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne	2022-01-26 16:30:00	2022-01-26 17:50:00	2022-02-15 17:47:41	\N	8	0	\N	\N
632448	DELEGATION	AUDRAP	\N	\N	206	Audition du Haut Conseil de l'évaluation de la recherche et de l'enseignement supérieur	Audition du Haut Conseil de l'évaluation de la recherche et de l'enseignement supérieur (Hcéres)	2022-01-31 16:00:00	2022-01-31 18:00:00	\N	\N	2	0	\N	\N
632451	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	MCC sécurisation de la chasse	MCC sécurisation de la chasse	2022-02-08 15:00:00	2022-02-08 18:00:00	\N	\N	9	0	\N	\N
632599	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2022-02-08 18:00:00	2022-02-08 19:30:00	\N	\N	24	0	\N	\N
632714	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition Varin / ppl cybersécurité / ppl experts forestiers	\N	2022-02-16 09:35:00	2022-02-16 11:50:00	2022-02-16 12:02:30	2022-02-17 16:42:20	43	0	\N	\N
632716	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	MI fraude et évasion fiscale - Réunion constitutive	\N	2022-02-15 16:00:00	2022-02-15 16:40:00	\N	\N	0	0	\N	\N
632717	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	MI fraude et évasion fiscale - Réunion constitutive	MI fraude et évasion fiscale - Réunion constitutive	2022-02-15 16:00:00	2022-02-15 16:40:00	\N	\N	13	0	\N	\N
632752	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition article 13 - CEA	\N	2022-02-17 11:20:00	2022-02-17 12:55:00	2022-02-17 18:59:32	2022-02-18 15:05:57	26	0	\N	\N
632754	COM_ENQUETE	DEPLACEMENT	\N	HOPITAL	\N	\N	\N	2022-01-24 08:00:00	2022-01-24 18:00:00	\N	\N	6	0	\N	\N
559766	MISSION	AUCUNE	\N	METHANIS	\N	Réunion de travail	Réunion de travail	2021-05-04 16:30:00	2021-05-04 19:20:00	2021-05-17 15:52:32	\N	11	0	\N	\N
632764	COM_ENQUETE	DEPLACEMENT	\N	HOPITAL	\N	Déplacement à Lamballe - CH du Penthièvre et du Pouduvre	Déplacement à Lamballe - CH du Penthièvre et du Pouduvre	2022-01-31 08:00:00	2022-01-31 19:00:00	\N	\N	3	0	\N	\N
632799	COM_ENQUETE	DEPLACEMENT	\N	HOPITAL	\N	Déplacement au CHU de Strasbourg	Déplacement au CHU de Strasbourg	2022-02-21 09:00:00	2022-02-21 18:00:00	\N	\N	4	0	\N	\N
632810	ETUDES	AUTRE	\N	\N	\N	Audition de Mme Emmanuelle George	Audition de Mme Emmanuelle George	2022-02-15 16:00:00	2022-02-15 17:05:00	\N	\N	10	0	\N	918
632969	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2020 -  ENAP - Déplacement Maison d'arrêt Fleury-Mérogis	Contrôle 2020 -  ENAP - Déplacement Maison d'arrêt Fleury-Mérogis	2022-02-10 09:30:00	2022-02-10 12:30:00	\N	\N	1	0	\N	\N
632971	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - Enseignants en Europe - Commission européenne EACEA	Contrôle 2022 - Enseignants en Europe - Commission européenne EACEA	2022-02-15 14:30:00	2022-02-15 15:30:00	\N	\N	1	0	\N	\N
633245	MISSION	AUDRAP	\N	JUDI	\N	\N	\N	2022-02-16 14:00:00	2022-02-16 15:00:00	\N	\N	2	0	\N	\N
633541	GIA	AUCUNE	\N	\N	\N	Réunion groupe d'amitié France-Canada	Réunion groupe d'amitié France-Canada	2022-01-27 14:00:00	2022-01-27 15:00:00	\N	\N	5	0	583	\N
633654	ETUDES	AUTRE	\N	\N	\N	Audition CRE	Audition CRE	2022-02-16 13:45:00	2022-02-16 15:00:00	\N	\N	15	0	\N	906
633733	COM_EURO	AUTRE	\N	AFEU	\N	Audition du juge Bonichot 	\N	2022-02-22 14:50:00	2022-02-22 16:05:00	2022-02-22 16:32:42	2022-02-22 16:34:41	18	0	\N	\N
633734	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 23 février 2022	\N	2022-02-24 08:45:00	2022-02-24 11:00:00	\N	\N	0	0	\N	\N
633936	MISSION	AUCUNE	\N	JUDI	\N	Audition de Jean-Claude Bonichot, juge à la Cour de justice de l'Union européene	Audition de Jean-Claude Bonichot, juge à la Cour de justice de l'Union européene	2022-02-22 14:50:00	2022-02-22 16:05:00	2022-02-22 16:10:23	2022-02-22 16:40:17	18	0	\N	\N
514891	DELEGATION	AUCUNE	\N	\N	206	Réunion plénière - Audition publique Mme Marie-Paule Kieny	Réunion plénière - Audition publique Mme Marie-Paule Kieny	2020-12-11 09:00:00	2020-12-11 10:45:00	\N	\N	8	0	\N	\N
519268	GIA	AUCUNE	\N	\N	\N	Audition de M. Alain Bifani, ancien directeur général du ministère des finances du Liban	Audition de M. Alain Bifani, ancien directeur général du ministère des finances du Liban	2021-01-05 10:30:00	2021-01-05 11:30:00	\N	\N	10	0	597	\N
521521	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Santé environnementale - Table ronde de villes	\N	2021-01-13 16:05:00	2021-01-13 17:35:00	\N	\N	1	0	\N	\N
521539	DELEGATION	AUCUNE	\N	\N	DSOM	Audition sur le logement outre-mer	Audition sur le logement outre-mer : DHUP et DGOM	2021-01-21 09:00:00	2021-01-21 11:20:00	\N	\N	16	0	\N	\N
521567	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Déplacement GT Agriculteurs en détresse	Déplacement GT Agriculteurs en détresse	2021-01-14 07:00:00	2021-01-14 21:00:00	\N	\N	6	0	\N	\N
529004	COM_PERMANENTE	AUTRE	\N	ETRD	\N	PJL Achmea + audition B. Lortholary + audition C. Lechervy	\N	2021-02-10 09:35:00	2021-02-10 12:00:00	2021-02-10 16:40:56	2021-02-10 17:51:33	32	0	\N	\N
539591	MISSION	AUCUNE	\N	BREXIT2	\N	Réunion du groupe de suivi sur la nouvelle relation euro-britannique	Réunion du groupe de suivi sur la nouvelle relation euro-britannique - réserve d'ajustement "Brexit"	2021-03-09 16:00:00	2021-03-09 16:20:00	2021-03-12 14:13:58	2021-03-12 17:43:32	7	0	\N	\N
539602	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Respect des principes de la République	\N	2021-03-11 14:00:00	2021-03-11 15:00:00	\N	\N	2	0	\N	\N
539605	GIA	AUCUNE	\N	\N	\N	Audition Ambassadrice du Canada 	Audition de l'ambassadrice du Canada en France, Isabelle Hudon	2021-03-11 11:00:00	2021-03-11 12:00:00	\N	\N	13	0	583	\N
543761	ETUDES	AUTRE	\N	\N	\N	Table ronde suivi MI illectronisme	\N	2021-04-01 09:00:00	2021-04-01 11:00:00	\N	\N	0	0	\N	1008
543841	ETUDES	AUTRE	\N	\N	\N	Audition ANCPG	Audition ANCPG	2021-03-24 08:00:00	2021-03-24 09:00:00	\N	\N	21	0	\N	907
543936	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition de M. Jean ARTHUIS, Président de la commission sur l'avenir des finances publique	Audition de M. Jean ARTHUIS, Président de la commission sur l'avenir des finances publiques	2021-03-24 10:30:00	2021-03-24 12:30:00	2021-03-24 13:39:49	2021-03-24 17:39:12	41	0	\N	\N
544046	MISSION	AUDRAP	\N	METHANIS	\N	Audition CRE	Audition CRE	2021-03-22 14:45:00	2021-03-22 15:30:00	\N	\N	4	0	\N	\N
544051	MISSION	AUDRAP	\N	METHANIS	\N	Audition table ronde des professionnels des énergies renouvelables	Audition table ronde des professionnels des énergies renouvelables	2021-03-22 15:30:00	2021-03-22 17:30:00	\N	\N	3	0	\N	\N
544112	MISSION	AUCUNE	\N	PAUP	\N	Auditions	\N	2021-03-30 14:30:00	2021-03-30 18:20:00	2021-03-31 10:09:00	2021-03-31 18:06:06	8	0	\N	\N
551461	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2021 - Syndication - Déplacement Agence France Trésor	Contrôle 2021 - Syndication - Déplacement Agence France Trésor	2021-04-08 09:45:00	2021-04-08 11:45:00	\N	\N	1	0	\N	\N
551479	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition Autorité de régulation professionnelle de la publicité	\N	2021-04-08 09:30:00	2021-04-08 10:15:00	\N	\N	7	0	\N	\N
551487	COM_PERMANENTE	AUDRAP	\N	CDD	\N	DGMIC	\N	2021-04-08 10:15:00	2021-04-08 11:00:00	\N	\N	3	0	\N	\N
551491	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Union des marques	\N	2021-04-08 11:00:00	2021-04-08 11:45:00	\N	\N	5	0	\N	\N
551497	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition FNAIM - UNIS - PLURIENCE	\N	2021-04-08 11:45:00	2021-04-08 12:30:00	\N	\N	1	0	\N	\N
551505	MISSION	AUCUNE	\N	PAUP	\N	Audition plénière	\N	2021-04-13 14:30:00	2021-04-13 17:30:00	2021-04-13 17:30:32	2021-04-14 18:26:29	7	0	\N	\N
553286	GIA	AUCUNE	\N	\N	\N	Réunion conjointe des groupes d'amitié des Parlements français et italien	\N	2021-04-12 18:00:00	2021-04-12 19:00:00	\N	\N	7	0	621	\N
553989	BUREAU	AUCUNE	\N	\N	\N	Bureau du Sénat	Bureau du Sénat	2021-04-15 08:30:00	2021-04-15 11:00:00	\N	\N	25	0	\N	\N
555847	MISSION	AUDRAP	\N	EGALCHAN	\N	Fondation Apprentis d'Auteuil	\N	2021-05-04 18:00:00	2021-05-04 19:30:00	\N	\N	2	0	\N	\N
555857	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière ATDD	\N	2021-05-05 09:30:00	2021-05-05 10:10:00	2021-05-05 10:33:50	2021-05-06 17:43:06	32	1	\N	\N
555858	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière ATDD	\N	2021-05-05 16:49:00	2021-05-05 20:18:00	2021-05-06 08:35:08	2021-05-06 17:43:01	42	2	\N	\N
558010	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Irresponsabilité pénale	Audition rapporteur - PPL irresponsabilité pénale	2021-05-07 10:30:00	2021-05-07 11:15:00	\N	\N	1	0	\N	\N
558012	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Irresponsabilité pénale	Audition rapporteur - PPL irresponsabilité pénale	2021-05-07 11:15:00	2021-05-07 12:00:00	\N	\N	1	0	\N	\N
558014	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Irresponsabilité pénale	\N	2021-05-10 10:00:00	2021-05-10 11:00:00	\N	\N	3	0	\N	\N
558016	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Irresponsabilité pénale	Audition rapporteur - PPL irresponsabilité pénale	2021-05-10 11:00:00	2021-05-10 12:00:00	\N	\N	3	0	\N	\N
560227	DELEGATION	AUCUNE	\N	\N	211	Table ronde sur le thème "Être agricultrice en 2021"	Table ronde sur le thème "Être agricultrice en 2021"	2021-06-03 08:30:00	2021-06-03 11:20:00	\N	\N	15	0	\N	\N
560274	MISSION	AUCUNE	\N	ENSAGRIC	\N	Audition plénière	\N	2021-05-18 16:38:00	2021-05-18 18:06:00	2021-05-18 18:13:38	2021-05-18 18:31:25	7	0	\N	\N
560356	MISSION	AUDRAP	\N	ENSAGRIC	\N	La Coopération agricole	\N	2021-05-19 16:37:00	2021-05-19 17:50:00	\N	\N	4	0	\N	\N
560357	MISSION	AUDRAP	\N	ENSAGRIC	\N	Agence nationale de la cohésion des territoires	\N	2021-05-19 18:05:00	2021-05-19 18:49:00	\N	\N	4	0	\N	\N
562043	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PPL Maltraitance animale	Audition PPL Maltraitance animale	2021-05-18 15:30:00	2021-05-18 17:30:00	\N	\N	2	0	\N	\N
562066	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition PJL Climat - DGEC	Audition PJL Climat - DGEC	2021-05-18 10:00:00	2021-05-18 11:00:00	\N	\N	3	0	\N	\N
562071	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition PJL Climat - DGCCRF	Audition PJL Climat - DGCCRF	2021-05-18 19:00:00	2021-05-18 20:00:00	\N	\N	1	0	\N	\N
563891	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2021-05-26 17:00:00	2021-05-26 20:00:00	\N	\N	4	0	\N	\N
565457	GIA	AUCUNE	\N	\N	\N	\N	Entretien avec M. Marc Fonbaustier, Ambassadeur de France en Guinée	2021-06-02 14:05:00	2021-06-02 15:00:00	\N	\N	6	0	573	\N
566104	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2021-05-27 09:00:00	2021-05-27 11:25:00	\N	\N	3	0	\N	\N
566577	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Prévention d'actes de terrorisme et renseignement	\N	2021-06-07 09:00:00	2021-06-07 10:00:00	\N	\N	1	0	\N	\N
566579	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Prévention d'actes de terrorisme et renseignement	\N	2021-06-07 10:00:00	2021-06-07 11:00:00	\N	\N	3	0	\N	\N
566583	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Prévention d'actes de terrorisme et renseignement	\N	2021-06-07 11:00:00	2021-06-07 12:00:00	\N	\N	4	0	\N	\N
566588	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Prévention d'actes de terrorisme et renseignement	\N	2021-06-07 14:00:00	2021-06-07 15:00:00	\N	\N	2	0	\N	\N
566592	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Prévention d'actes de terrorisme et renseignement	\N	2021-06-07 15:00:00	2021-06-07 16:00:00	\N	\N	4	0	\N	\N
566597	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Prévention d'actes de terrorisme et renseignement	\N	2021-06-07 16:00:00	2021-06-07 18:00:00	\N	\N	2	0	\N	\N
566600	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Prévention d'actes de terrorisme et renseignement	\N	2021-06-08 09:00:00	2021-06-08 11:00:00	\N	\N	3	0	\N	\N
567737	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Prévention d'actes de terrorisme et renseignement	\N	2021-06-08 14:00:00	2021-06-08 15:00:00	\N	\N	4	0	\N	\N
567742	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Prévention d'actes de terrorisme et renseignement	\N	2021-06-08 15:00:00	2021-06-08 16:00:00	\N	\N	5	0	\N	\N
567748	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Prévention d'actes de terrorisme et renseignement	\N	2021-06-08 16:00:00	2021-06-08 17:00:00	\N	\N	8	0	\N	\N
567757	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Prévention d'actes de terrorisme et renseignement	\N	2021-06-08 17:00:00	2021-06-08 18:00:00	\N	\N	4	0	\N	\N
567762	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Prévention d'actes de terrorisme et renseignement	\N	2021-06-08 18:00:00	2021-06-08 19:00:00	\N	\N	4	0	\N	\N
639559	MISSION	AUDRAP	\N	FONDSMER	\N	Audition ECA Group	Audition ECA Group	2022-03-18 10:30:00	2022-03-18 11:45:00	\N	\N	1	0	\N	\N
641142	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Christophe GIGAUDAUT, directeur de l'insitut de France du Cambodge	Entretien avec M. Christophe GIGAUDAUT, directeur de l'insitut de France du Cambodge	2022-04-12 12:15:00	2022-04-12 13:45:00	\N	\N	1	0	577	\N
641143	GIA	AUCUNE	\N	\N	\N	Entretien avec M. KOUSOUM Saroeuth, député cambodgien	Entretien avec M. KOUSOUM Saroeuth, député cambodgien	2022-04-11 11:00:00	2022-04-11 12:00:00	\N	\N	1	0	577	\N
641650	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MIC Delinquance des mineurs	MIC Délinquance des mineurs	2022-04-19 11:00:00	2022-04-19 12:10:00	\N	\N	3	0	\N	\N
642465	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Souveraineté économique - Auditions	MI Souveraineté économique - Auditions	2022-05-10 10:00:00	2022-05-10 11:00:00	\N	\N	3	0	\N	\N
642466	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Souveraineté économique - Auditions	MI Souveraineté économique - Auditions	2022-05-10 14:15:00	2022-05-10 15:00:00	\N	\N	2	0	\N	\N
642467	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Souveraineté économique - Auditions	MI Souveraineté économique - Auditions	2022-05-10 15:00:00	2022-05-10 17:00:00	\N	\N	2	0	\N	\N
642499	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition MI énergie et hydrogène nucléaires	Audition MI énergie et hydrogène nucléaires	2022-05-10 09:45:00	2022-05-10 11:00:00	\N	\N	3	0	\N	\N
643393	DELEGATION	AUDRAP	\N	\N	206	Audition Pitié-Salpétrière	\N	2022-05-30 11:00:00	2022-05-30 12:00:00	\N	\N	3	0	\N	\N
643397	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Stage au tribunal judiciaire de Marseille	Stage au tribunal judiciaire de Marseille	2022-05-12 10:00:00	2022-05-13 17:00:00	\N	\N	2	0	\N	\N
643398	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Stage au tribunal judiciaire de Bordeaux	Stage au tribunal judiciaire de Bordeaux	2022-05-19 10:00:00	2022-05-20 17:00:00	\N	\N	3	0	\N	\N
643404	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	MCC 2022 - Audiovisuel Public - Radio France	\N	2022-05-30 12:00:00	2022-05-30 13:10:00	\N	\N	0	0	\N	\N
643411	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 31/05/22	\N	2022-05-31 15:30:00	2022-05-31 16:00:00	2022-05-31 16:03:05	2022-05-31 18:13:23	8	0	\N	\N
643412	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions M. Fabien Gay, Mmes Françoise Férat et Florence Blatrix-Contat	\N	2022-05-20 14:00:00	2022-05-20 16:30:00	\N	\N	3	0	\N	\N
643416	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur MI Ehpad - TR aspects éthiques de la gestion des Ehpad	\N	2022-06-07 14:00:00	2022-06-07 15:30:00	\N	\N	4	0	\N	\N
643419	DELEGATION	AUDRAP	\N	\N	PROS	Audition France stratégie	\N	2022-05-31 10:00:00	2022-05-31 11:10:00	\N	\N	1	0	\N	\N
647926	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI SPIP	MI SPIP - Auditions	2022-07-08 09:00:00	2022-07-08 11:50:00	\N	\N	2	0	\N	\N
667788	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Médias - DGMIC	PLF pour 2023 - Médias - DGMIC	2022-10-28 09:30:00	2022-10-28 10:30:00	\N	\N	0	0	\N	\N
667789	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Défense - SIMu	PLF pour 2023 - Défense - SIMu	2022-10-25 14:00:00	2022-10-25 15:00:00	\N	\N	1	0	\N	\N
667791	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Défense - CAB MINARM	PLF pour 2023 - Défense - CAB MINARM	2022-10-28 17:00:00	2022-10-28 18:00:00	\N	\N	1	0	\N	\N
667793	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Travail & emploi - Syndicats Pole Emploi	PLF pour 2023 - Travail & emploi - Syndicats Pole Emploi	2022-10-27 16:30:00	2022-10-27 17:30:00	\N	\N	1	0	\N	\N
667795	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - AGTE - DGEF/Syndicats Prefectures/Cour des comptes/DNUM MIN INT/ADMIN TERR	PLF pour 2023 - AGTE - DGEF/Syndicats Prefectures/Cour des comptes/DNUM MIN INT/ADMIN TERR	2022-10-25 14:00:00	2022-10-25 19:00:00	\N	\N	1	0	\N	\N
640829	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Groupe d'amitié France Caraïbes	Groupe d'amitié France Caraïbes	2022-03-15 09:00:00	2022-03-15 10:00:00	\N	\N	2	0	\N	\N
667797	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 -  AGTE - ANTS	PLF pour 2023 -  AGTE - ANTS	2022-10-26 17:30:00	2022-10-26 19:00:00	\N	\N	1	0	\N	\N
667799	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 -  AGTE - SG CIPDR	PLF pour 2023 -  AGTE - SG CIPDR	2022-10-27 09:00:00	2022-10-27 10:00:00	\N	\N	1	0	\N	\N
667801	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Rapport Général - AFEP	PLF pour 2023 - Rapport Général - AFEP	2022-10-27 19:10:00	2022-10-27 19:50:00	\N	\N	1	0	\N	\N
667803	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - RES - France universités	PLF pour 2023 - RES - France universités	2022-10-27 14:30:00	2022-10-27 15:30:00	\N	\N	1	0	\N	\N
667810	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Enseignement supérieur - CNOUS	PLF pour 2023 - Enseignement supérieur - CNOUS	2022-10-27 09:30:00	2022-10-27 10:30:00	\N	\N	1	0	\N	\N
667812	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Justice - DB/SG MIN Justice/DSJ	PLF pour 2023 - Justice - DB/SG MIN Justice/DSJ	2022-10-27 14:45:00	2022-10-27 18:15:00	\N	\N	1	0	\N	\N
667814	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Investir France 2030 - SGPI	PLF pour 2023 - Investir France 2030 - SGPI	2022-10-27 13:30:00	2022-10-27 14:10:00	\N	\N	1	0	\N	\N
670652	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2023 - P 105	\N	2022-11-08 14:30:00	2022-11-08 16:00:00	\N	\N	2	0	\N	\N
670734	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Enseignement professionnel	Débat Enseignement professionnel	2022-11-14 18:00:00	2022-11-14 19:35:00	\N	\N	26	0	\N	\N
670736	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Parcousup	Débat Parcousup	2022-11-14 21:30:00	2022-11-14 23:20:00	\N	\N	21	0	\N	\N
670750	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR Arménie	PPR Arménie	2022-11-15 16:00:00	2022-11-15 17:35:00	\N	\N	103	0	\N	\N
672383	DELEGATION	AUCUNE	\N	\N	DSOM	Programmation des travaux de la délégation	\N	2022-11-17 09:30:00	2022-11-17 10:45:00	\N	\N	9	0	\N	\N
672422	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2023 - Recherche - CNRS	PLF 2023 - Recherche - CNRS	2022-11-08 18:45:00	2022-11-08 19:30:00	\N	\N	1	0	\N	\N
672425	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2023 - Recherche - CEA	PLF 2023 - Recherche - CEA	2022-11-09 11:00:00	2022-11-09 11:45:00	\N	\N	1	0	\N	\N
672428	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2023 - Recherche - Bpifrance	PLF 2023 - Recherche - Bpifrance	2022-11-09 11:45:00	2022-11-09 12:30:00	\N	\N	1	0	\N	\N
672438	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2023 - Ville - Positive Planet France	PLF 2023 - Ville - Positive Planet France	2022-11-09 11:30:00	2022-11-09 12:15:00	\N	\N	1	0	\N	\N
672443	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	comité d'organisation des jeux olympiques et paralympiques de 2024	\N	2022-11-10 11:00:00	2022-11-10 12:30:00	\N	\N	4	0	\N	\N
672499	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-11-16 16:30:00	2022-11-16 17:30:00	\N	\N	0	0	\N	\N
672560	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF AEF	\N	2022-11-09 16:45:00	2022-11-09 17:45:00	\N	\N	2	0	\N	\N
672570	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLFR pour 2022 (2) : Examen du rapport 	PLFR pour 2022 (2) : Examen du rapport 	2022-11-15 09:00:00	2022-11-15 09:55:00	2022-11-15 12:00:26	2022-11-15 14:52:24	26	1	\N	\N
672571	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF 2023 : Missions Chésion territoires-Justice-Investir France2030-Culture et Médias	PLF 2023 : Missions Chésion territoires-Justice-Investir France2030-Culture et Médias	2022-11-15 15:50:00	2022-11-15 18:55:00	2022-11-16 10:33:06	2022-11-16 17:13:17	44	1	\N	\N
672574	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLFR pour 2022 (2) : Examen Amdts séance et PLF 2023 : Mission Outre-Mer	PLFR pour 2022 (2) : Examen Amdts séance et PLF 2023 : Mission Outre-Mer	2022-11-16 14:05:00	2022-11-16 14:45:00	2022-11-16 17:21:40	2022-11-18 11:44:50	25	1	\N	\N
672576	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF 2023 : Vote Missions réservées et Examen définitif Équilibre et Amdts	PLF 2023 : Vote Missions réservées et Examen définitif Équilibre et Amdts	2022-11-17 10:35:00	2022-11-17 11:45:00	2022-11-17 12:07:57	2022-11-18 11:44:53	33	2	\N	\N
687425	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT Retex Ukraine	GT Retex Ukraine	2022-12-06 10:30:00	2022-12-06 12:30:00	\N	\N	2	0	\N	\N
687436	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT Retex Ukraine	GT Retex Ukraine	2022-12-06 17:00:00	2022-12-06 19:30:00	\N	\N	4	0	\N	\N
687441	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT Retex Ukraine	GT Retex Ukraine	2022-12-07 14:00:00	2022-12-07 15:00:00	\N	\N	4	0	\N	\N
688843	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition ambassadeur de Turquie + examen rapport d'information Indopacifique	Audition ambassadeur de Turquie + examen rapport d'information Indopacifique	2023-01-11 09:30:00	2023-01-11 12:56:00	2023-01-11 15:15:20	2023-01-12 17:25:07	34	2	\N	\N
688954	GIA	AUCUNE	\N	\N	\N	Rencontre avec l'ambassdeur d'Irak	Entretien avec le nouvel ambassadeur d'Irak, Wadee Batti	2022-09-15 17:00:00	2022-09-15 18:00:00	\N	\N	3	0	615	\N
690730	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT Retex Ukraine	GR Retex Ukraine	2023-01-10 14:30:00	2023-01-10 18:30:00	\N	\N	4	0	\N	\N
690735	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT Retex Ukraine	GT Retex Ukraine	2023-01-11 14:00:00	2023-01-11 15:00:00	\N	\N	3	0	\N	\N
690755	GIA	AUCUNE	\N	\N	\N	Audition AFD Nigéria	Audition AFD Nigéria	2023-01-12 11:05:00	2023-01-12 12:20:00	\N	\N	3	0	573	\N
690950	DELEGATION	AUCUNE	\N	\N	211	Parentalité outre-mer : audition du HCFEA et de l'INED	Parentalité outre-mer : audition du HCFEA et de l'INED (commune avec la DSOM)	2023-02-02 09:30:00	2023-02-02 11:25:00	\N	\N	14	0	\N	\N
690951	GIA	AUCUNE	\N	\N	\N	audition de S.E. M. Ghazi Alrawas, ambassadeur du Sultanat d¿Oman	\N	2023-01-16 20:00:00	2023-01-16 22:00:00	\N	\N	4	0	661	\N
690956	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	GT institutions	\N	2023-01-04 11:30:00	2023-01-04 12:30:00	\N	\N	1	0	\N	\N
690958	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	GT institutions	\N	2023-01-04 15:00:00	2023-01-04 18:00:00	\N	\N	1	0	\N	\N
691351	GIA	AUCUNE	\N	\N	\N	Audition de l'ambassadeur de France en Mauritanie 	Audition de l'ambassadeur de France en Mauritanie 	2023-01-17 17:30:00	2023-01-17 18:55:00	\N	\N	5	0	573	\N
645585	COM_PERMANENTE	AUDRAP	\N	CAE	\N	IR DSU	IR DSU	2022-06-21 15:00:00	2022-06-21 16:00:00	\N	\N	3	0	\N	\N
672498	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-11-16 09:30:00	2022-11-16 11:00:00	2022-11-16 16:31:41	2022-11-16 17:13:30	46	0	\N	\N
672573	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF 2023 : Vote articles réservés-Missions Écologie et RCT et Désignation CMP PLFR(2)2022	PLF 2023 : Vote articles réservés-Missions Écologie et RCT et Désignation CMP PLFR(2)2022	2022-11-16 09:05:00	2022-11-16 12:55:00	2022-11-16 16:10:10	2022-11-16 17:13:29	43	1	\N	\N
692233	GIA	AUCUNE	\N	\N	\N	Parrainage prisonniers  politiques biélorusses	réunion préparatoire	2023-01-18 12:30:00	2023-01-18 14:15:00	\N	\N	4	0	852	\N
692435	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition de M. Michel Messager	Audition de M. Michel Messager	2023-01-18 13:15:00	2023-01-18 15:00:00	\N	\N	3	0	\N	\N
698943	DELEGATION	AUCUNE	\N	\N	206	Audition de M. Joseph Aschbacher, directeur de l'Agence spatiale européenne	\N	2023-02-08 13:35:00	2023-02-08 15:05:00	\N	\N	24	0	\N	\N
698949	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Centres de santé - Audition Cnam	\N	2023-02-03 10:30:00	2023-02-03 11:30:00	\N	\N	2	0	\N	\N
698952	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Mme Loisier	\N	2023-01-31 15:30:00	2023-01-31 19:30:00	\N	\N	2	0	\N	\N
698955	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Mme Loisier	\N	2023-02-01 11:30:00	2023-02-01 12:30:00	\N	\N	1	0	\N	\N
698957	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Mme Loisier	\N	2023-02-01 16:30:00	2023-02-01 18:00:00	\N	\N	1	0	\N	\N
698959	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Mme Loisier	\N	2023-02-02 08:30:00	2023-02-02 11:00:00	\N	\N	1	0	\N	\N
698961	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Mme Loisier	\N	2023-02-03 11:00:00	2023-02-03 11:30:00	\N	\N	1	0	\N	\N
698963	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Réunion constitutive	\N	2023-02-07 13:45:00	2023-02-07 14:45:00	\N	\N	0	0	\N	\N
698964	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2023-02-07 08:45:00	2023-02-07 08:55:00	2023-02-07 10:02:28	2023-02-07 13:22:45	24	1	\N	\N
698972	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2023-02-15 10:00:00	2023-02-15 12:00:00	2023-02-15 16:52:32	2023-02-15 17:33:37	38	3	\N	\N
698979	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Audition plénière	\N	2023-02-09 15:30:00	2023-02-09 17:00:00	\N	\N	0	0	\N	\N
698994	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI cinéma	\N	2023-02-03 10:00:00	2023-02-03 12:00:00	\N	\N	2	0	\N	\N
700464	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	mi cinéma	\N	2023-02-08 14:00:00	2023-02-08 15:00:00	\N	\N	5	0	\N	\N
700747	MISSION	AUDRAP	\N	BATI	\N	audition	\N	2023-02-08 14:00:00	2023-02-08 15:00:00	\N	\N	8	0	\N	\N
701785	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL fraudes artistiques	\N	2023-02-13 09:00:00	2023-02-13 11:30:00	\N	\N	2	0	\N	\N
701788	COM_ENQUETE	PLENIERE	\N	RENOV	\N	Auditions ministres	\N	2023-02-13 14:00:00	2023-02-13 19:25:00	2023-02-14 09:38:22	2023-02-14 17:15:37	11	0	\N	\N
701789	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition Philippe Wahl (La Poste)	\N	2023-02-15 09:30:00	2023-02-15 11:15:00	2023-02-15 18:32:53	2023-02-16 11:59:37	43	1	\N	\N
701792	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Tourisme	\N	2023-02-08 08:00:00	2023-02-08 09:00:00	\N	\N	11	0	\N	\N
701817	DELEGATION	AUDRAP	\N	\N	206	Auditions recyclage du plastique	\N	2023-02-09 14:00:00	2023-02-09 18:00:00	\N	\N	2	0	\N	\N
703782	ETUDES	AUTRE	\N	\N	\N	Audition plénière	Audition de M. Jérémie Boroy Président du CNCPH	2023-02-15 14:00:00	2023-02-15 15:00:00	\N	\N	15	0	\N	1014
703787	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Immigration et intégration - Audition de Gérald Darmanin et Olivier Dussopt	PJL Immigration et intégration - Audition de Gérald Darmanin et Olivier Dussopt	2023-02-28 17:30:00	2023-02-28 19:50:00	2023-03-01 09:09:16	2023-03-01 16:37:30	25	0	\N	\N
703792	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Organisation de la police judiciaire - Examen du rapport d'information	Organisation de la police judiciaire - Examen du rapport d'information	2023-03-01 14:00:00	2023-03-01 14:35:00	2023-03-01 16:49:48	2023-03-01 18:00:42	14	0	\N	\N
703816	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI TND - Audition du Pr Amaria Baghdadli	\N	2023-02-20 15:00:00	2023-02-20 16:00:00	\N	\N	2	0	\N	\N
703962	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPLO Saint-Barthélemy - Audition ARS-préfecture	\N	2023-02-15 18:15:00	2023-02-15 19:00:00	\N	\N	1	0	\N	\N
703963	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPLO Saint-Barthélemy - Audition hôpital	\N	2023-02-15 19:00:00	2023-02-15 19:45:00	\N	\N	1	0	\N	\N
703967	COM_SPECIALE	AUDRAP	\N	CZAN	\N	Auditions CS ZAN	Auditions CS ZAN	2023-02-15 16:30:00	2023-02-15 17:10:00	\N	\N	6	0	\N	\N
703968	COM_SPECIALE	AUDRAP	\N	CZAN	\N	Auditions CS ZAN	Auditions CS ZAN	2023-02-15 17:10:00	2023-02-15 18:00:00	\N	\N	11	0	\N	\N
703969	COM_SPECIALE	AUDRAP	\N	CZAN	\N	Auditions CS ZAN	Auditions CS ZAN	2023-02-15 18:00:00	2023-02-15 18:45:00	\N	\N	5	0	\N	\N
704049	DELEGATION	AUDRAP	\N	\N	206	Auditions Sobriété énergétique	\N	2023-02-14 16:00:00	2023-02-14 17:00:00	\N	\N	2	0	\N	\N
704052	DELEGATION	AUDRAP	\N	\N	PROS	Audition Air Liquide	\N	2023-02-15 16:30:00	2023-02-15 17:30:00	\N	\N	2	0	\N	\N
704055	DELEGATION	AUDRAP	\N	\N	PROS	Audition M. Weiss	\N	2023-02-15 17:30:00	2023-02-15 18:30:00	\N	\N	2	0	\N	\N
704058	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL fraudes artistiques	\N	2023-02-15 16:30:00	2023-02-15 18:30:00	\N	\N	2	0	\N	\N
704061	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL fraudes artistiques	\N	2023-02-16 09:30:00	2023-02-16 11:00:00	\N	\N	2	0	\N	\N
704071	DELEGATION	AUDRAP	\N	\N	206	Auditions recyclage du plastique	\N	2023-02-16 14:00:00	2023-02-16 18:00:00	\N	\N	2	0	\N	\N
704211	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions Mme Marta de Cidrac	\N	2023-02-21 14:00:00	2023-02-21 19:00:00	\N	\N	1	0	\N	\N
704213	COM_ENQUETE	PLENIERE	\N	MEDIC	\N	Audition plénière	\N	2023-02-28 13:35:00	2023-02-28 14:55:00	2023-02-28 14:53:28	2023-02-28 16:04:32	8	0	\N	\N
704214	COM_ENQUETE	PLENIERE	\N	MEDIC	\N	Audition plénière	\N	2023-02-28 09:00:00	2023-02-28 10:40:00	2023-02-28 11:22:01	2023-02-28 16:04:32	9	0	\N	\N
704215	COM_ENQUETE	PLENIERE	\N	MEDIC	\N	Audtion plénière	\N	2023-03-01 13:30:00	2023-03-01 14:55:00	2023-03-01 14:56:24	2023-03-01 16:39:07	8	0	\N	\N
704216	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-02-28 14:30:00	2023-02-28 16:40:00	2023-02-28 16:51:29	2023-03-01 16:37:31	36	2	\N	\N
704217	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Violences intrafamiliales	PPL Violences intrafamiliales	2023-02-22 14:15:00	2023-02-22 15:15:00	\N	\N	3	0	\N	\N
704218	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-03-02 14:00:00	2023-03-02 14:15:00	2023-03-02 14:24:04	2023-03-02 18:15:35	27	0	\N	\N
704225	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Défense incendie	PPL Défense exétrieur contre l'incendie et territoires ruaux	2023-02-09 15:00:00	2023-02-09 15:30:00	\N	\N	1	0	\N	\N
704227	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-03-04 14:00:00	2023-03-04 14:25:00	2023-03-04 15:02:58	2023-03-08 17:27:52	24	0	\N	\N
701790	COM_PERMANENTE	AUTRE	\N	CAE	\N	Examen des amendements de séance PPL Egalim 3	\N	2023-02-15 11:15:00	2023-02-15 11:25:00	\N	\N	39	0	\N	\N
701791	COM_PERMANENTE	AUTRE	\N	CAE	\N	Examen des amendements de séance PPL Egalim 3	\N	2023-02-15 11:15:00	2023-02-15 11:30:00	2023-02-15 18:31:22	2023-02-16 11:59:44	45	2	\N	\N
703790	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désignations - Rapports et textes	Désignations - Rapports et textes	2023-03-01 09:00:00	2023-03-01 11:05:00	2023-03-01 16:49:17	2023-03-01 18:00:44	40	4	\N	\N
704286	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Immigration et intégration	Audition rapporteur - PJL Immigration et intégration	2023-02-22 08:30:00	2023-02-22 11:45:00	\N	\N	2	0	\N	\N
637993	MISSION	AUCUNE	\N	CULTURE	\N	Réunion 20220309b	\N	2022-03-09 14:35:00	2022-03-09 15:45:00	2022-03-09 16:09:36	2022-03-09 18:05:41	5	0	\N	\N
637994	MISSION	AUDRAP	\N	CULTURE	\N	Audition de représentants de l'association Projet Democratia	\N	2022-03-09 16:05:00	2022-03-09 16:55:00	\N	\N	6	0	\N	\N
637995	MISSION	AUDRAP	\N	CULTURE	\N	Audition de M. Benjamin Sibille	\N	2022-03-09 17:00:00	2022-03-09 17:40:00	\N	\N	6	0	\N	\N
640679	GIA	AUCUNE	\N	\N	\N	Visioconférence avec M. Jacques Pellet, Ambassadeur de France au Cambodge	Visioconférence avec M. Jacques Pellet, Ambassadeur de France au Cambodge	2022-03-31 10:30:00	2022-03-31 11:30:00	\N	\N	3	0	577	\N
644225	DELEGATION	AUCUNE	\N	\N	206	Examen d'un rapport d'étape sur les effets secondaires des vaccins contre la Covid-19 	\N	2022-06-09 10:20:00	2022-06-09 12:00:00	2022-06-09 11:58:55	\N	11	0	\N	\N
644244	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Association des Architectes du Patrimoine	\N	2022-06-08 14:30:00	2022-06-08 15:30:00	\N	\N	2	0	\N	\N
644245	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Conférence des Évêques de France	\N	2022-06-08 15:30:00	2022-06-08 16:30:00	\N	\N	2	0	\N	\N
644246	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	ministère de la culture - direction générale des patrimoines	\N	2022-06-08 17:30:00	2022-06-08 18:10:00	\N	\N	2	0	\N	\N
644368	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - OAT vertes - ANC	Contrôle 2022 - OAT vertes - ANC	2022-06-09 16:30:00	2022-06-09 17:05:00	\N	\N	1	0	\N	\N
644493	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	MCC Délinquance des mineurs - Déplacement à Avignon	MCC Délinquance des mineurs - Déplacement à Avignon	2022-06-14 06:00:00	2022-06-14 20:00:00	\N	\N	4	0	\N	\N
646249	GIA	AUCUNE	\N	\N	\N	entretien avec les ambassadeurs du Koweït, d'Arabie saoudite et d'Oman	entretien avec S.E. M. Sami Mohammad AL-SULAIMAN, S.E. M. Fahad AL-RUWAILY et S.E. M. Ghazi ALRAWAS	2022-07-04 12:30:00	2022-07-05 14:30:00	\N	\N	1	0	661	\N
646315	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Audition MCC Délinquance des mineurs	Audition du CLJ de Strasbourg	2022-06-22 15:30:00	2022-06-22 16:30:00	\N	\N	5	0	\N	\N
646325	GIA	AUCUNE	\N	\N	\N	Audition de M. Luc HALLADE, Ambassadeur de France au Burkina Faso	Audition de M. Luc HALLADE, Ambassadeur de France au Bukina Faso	2022-07-05 15:00:00	2022-07-05 16:30:00	\N	\N	6	0	573	\N
654684	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Réunion plénière MCC délinquance	\N	2022-09-21 11:00:00	2022-09-21 12:30:00	\N	\N	0	0	\N	\N
656358	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PPL Agrivoltaïsme	\N	2022-09-27 10:00:00	2022-09-27 10:30:00	\N	\N	3	0	\N	\N
656370	COM_PERMANENTE	AUDRAP	\N	CAE	\N	DGEC	\N	2022-09-27 13:30:00	2022-09-27 14:30:00	\N	\N	6	0	\N	\N
656402	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Réunion du groupe de travail Subsidiarité	\N	2022-09-27 14:30:00	2022-09-27 14:50:00	\N	\N	0	0	\N	\N
656403	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Ambassadeur du Japon en France	\N	2022-09-27 16:00:00	2022-09-27 17:00:00	\N	\N	13	0	\N	\N
656416	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF Enssco	\N	2022-09-27 09:15:00	2022-09-27 11:30:00	\N	\N	2	0	\N	\N
656424	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteurs PJL Marché du travail - Pôle emploi	\N	2022-09-27 19:00:00	2022-09-27 20:00:00	\N	\N	4	0	\N	\N
661833	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Professionnalisation de la formation des internes - déserts médicaux	PPL Professionnalisation de la formation des internes - déserts médicaux	2022-10-18 15:50:00	2022-10-18 18:50:00	\N	\N	154	0	\N	\N
661834	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat sur les finances locales	Débat sur les finances locales	2022-10-18 18:55:00	2022-10-18 20:30:00	\N	\N	80	0	\N	\N
661835	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL cabinets de conseil privés	PPL cabinets de conseil privés	2022-10-18 22:00:00	2022-10-19 02:10:00	\N	\N	60	0	\N	\N
661836	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2022-10-19 15:00:00	2022-10-19 16:20:00	\N	\N	285	0	\N	\N
661837	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPLC droit fondamental à l'IVG	PPLC droit fondamental à l'IVG	2022-10-19 16:35:00	2022-10-19 18:55:00	\N	\N	101	0	\N	\N
661838	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Formation de sage-femme	PPL Formation de sage-femme	2022-10-19 19:00:00	2022-10-19 20:05:00	\N	\N	50	0	\N	\N
661840	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL victimes de violences conjugales	PPL victimes de violences conjugales	2022-10-20 10:30:00	2022-10-20 12:30:00	\N	\N	58	0	\N	\N
661841	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL comités sociaux et économiques à La Poste	PPL comités sociaux et économiques à La Poste	2022-10-20 12:30:00	2022-10-20 13:00:00	\N	\N	21	0	\N	\N
661842	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Développement de l'agrivoltaïsme	PPL Développement de l'agrivoltaïsme	2022-10-20 16:00:00	2022-10-20 18:00:00	\N	\N	58	0	\N	\N
661843	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Externalités positives de la forêt	PPL Externalités positives de la forêt	2022-10-20 18:00:00	2022-10-20 19:25:00	\N	\N	22	0	\N	\N
668827	DELEGATION	AUDRAP	\N	\N	206	Audition de Mme Sauvajol-Rialland	\N	2022-10-24 09:15:00	2022-10-24 10:15:00	\N	\N	1	0	\N	\N
669513	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	réunion préparatoire AP OTAN	réunion préparatoire AP OTAN	2022-11-02 16:30:00	2022-11-02 18:00:00	\N	\N	5	0	\N	\N
672588	DELEGATION	AUDRAP	\N	\N	206	Audition de Mme Serry et Mme Marie-Malikité	\N	2022-11-10 15:00:00	2022-11-10 16:15:00	\N	\N	1	0	\N	\N
672590	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions de l'Assemblée des départements de France et du ministère de l'intérieur	\N	2022-11-08 08:30:00	2022-11-08 10:45:00	\N	\N	1	0	\N	\N
672591	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions PJLF 2023	\N	2022-11-08 08:30:00	2022-11-08 10:45:00	\N	\N	0	0	\N	\N
690790	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Réunion avec Parlement grec	\N	2023-01-18 11:05:00	2023-01-18 12:40:00	2023-01-18 15:05:29	2023-01-19 11:52:45	44	0	\N	\N
690791	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Communication sur PPRE	\N	2023-01-18 16:40:00	2023-01-18 17:25:00	2023-01-19 09:42:07	2023-01-19 11:52:47	18	0	\N	\N
698942	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition S.E. M. Hans-Dieter Lucas et examen R.I. "Ukraine"	Audition S.E. M. Hans-Dieter Lucas et examen R.I. "Ukraine"	2023-02-08 09:47:00	2023-02-08 12:15:00	2023-02-08 16:06:16	2023-02-09 11:07:25	40	2	\N	\N
704340	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-03-03 15:05:00	2023-03-03 16:25:00	2023-03-03 17:23:27	2023-03-08 17:27:52	27	0	\N	\N
704345	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI TND - Auditon Normandie Pédiatrie	\N	2023-02-28 09:00:00	2023-02-28 10:00:00	\N	\N	2	0	\N	\N
704350	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPLO Saint-Barthélemy - Audition DSS-DGOS	\N	2023-02-28 10:15:00	2023-02-28 11:05:00	\N	\N	2	0	\N	\N
690789	COM_PERMANENTE	AUTRE	\N	ETRD	\N	4 conventions	\N	2023-01-18 10:15:00	2023-01-18 11:05:00	2023-01-18 15:03:22	2023-01-19 11:52:42	44	2	\N	\N
698941	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Examen d'une convention	Examen d'une convention et désignations rapporteurs	2023-02-08 09:30:00	2023-02-08 09:40:00	2023-02-08 16:03:44	2023-02-09 11:07:29	40	2	\N	\N
704363	COM_SPECIALE	PLENIERE	\N	CZAN	\N	Table ronde d'associations d'élus locaux	\N	2023-02-28 16:05:00	2023-02-28 18:00:00	2023-03-01 15:09:26	2023-03-01 16:39:07	25	0	\N	\N
704497	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Producteurs d'emballages ménagers et de papier - Auditions Mme Marta de Cidrac	PPL Producteurs d'emballages ménagers et de papier - Auditions Mme Marta de Cidrac	2023-02-28 14:00:00	2023-02-28 15:00:00	\N	\N	1	0	\N	\N
704520	MISSION	AUDRAP	\N	BATI	\N	MIBS	\N	2023-02-28 16:30:00	2023-02-28 18:30:00	\N	\N	7	0	\N	\N
704587	MISSION	AUDRAP	\N	GEAU	\N	Cercle français de l'eau 	\N	2023-02-28 18:00:00	2023-02-28 19:10:00	\N	\N	8	0	\N	\N
705810	DELEGATION	AUCUNE	\N	\N	211	Colloque "Femmes et ruralités": la parole aux élues de nos territoires (DDF) - 09/03/2023	Colloque "Femmes et ruralités": la parole aux élues de nos territoires (DDF)	2023-03-09 09:30:00	2023-03-09 12:20:00	\N	\N	18	0	\N	\N
705811	DELEGATION	AUCUNE	\N	\N	211	Tables rondes Santé des femmes au travail (Métiers féminisés)	\N	2023-04-06 08:10:00	2023-04-06 11:00:00	\N	\N	4	0	\N	\N
705882	DELEGATION	AUDRAP	\N	\N	206	Auditions recyclage du plastique	\N	2023-02-23 09:30:00	2023-02-23 18:30:00	\N	\N	2	0	\N	\N
706098	COM_SPECIALE	PLENIERE	\N	CZAN	\N	Examen rapport et texte	\N	2023-03-08 16:30:00	2023-03-08 18:55:00	2023-03-08 19:12:59	2023-03-09 14:55:09	25	0	\N	\N
706128	MISSION	AUDRAP	\N	BATI	\N	mi bati	\N	2023-03-02 09:30:00	2023-03-02 10:45:00	\N	\N	5	0	\N	\N
706135	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI cinéma	\N	2023-02-28 15:00:00	2023-02-28 16:00:00	\N	\N	2	0	\N	\N
706136	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI cinéma	\N	2023-03-01 14:00:00	2023-03-01 15:00:00	\N	\N	1	0	\N	\N
676246	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2022-11-17 09:00:00	2022-11-17 12:30:00	\N	\N	1	0	\N	\N
676334	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF2023 - prog. 144 - audition rapporteur	PLF2023 - prog. 144 - audition rapporteur	2022-11-16 16:30:00	2022-11-16 18:30:00	\N	\N	1	0	\N	\N
677304	COM_PERMANENTE	AUTRE	\N	CAE	\N	PLF 2023 - Avis budgétaires	\N	2022-11-22 15:00:00	2022-11-22 16:00:00	2022-11-22 16:15:01	2022-11-22 18:14:08	32	1	\N	\N
677468	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL AESH	\N	2022-11-17 13:30:00	2022-11-17 15:00:00	\N	\N	4	0	\N	\N
677474	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL AESH	\N	2022-11-18 16:00:00	2022-11-18 17:00:00	\N	\N	4	0	\N	\N
678872	GIA	AUCUNE	\N	\N	\N	Visite d'une délégation de maires ukrainiens	Visite d'une délégation de maires ukrainiens	2022-11-23 13:50:00	2022-11-23 14:50:00	\N	\N	15	0	530	\N
682866	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Mission Pouvoirs publics	\N	2022-12-01 14:30:00	2022-12-01 15:50:00	\N	\N	47	0	\N	\N
682953	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Métropole Lyon et Aix-Marseille-Provence	MI Métropole Lyon et Aix-Marseille-Provence	2022-12-01 13:30:00	2022-12-01 14:30:00	\N	\N	5	0	\N	\N
683062	GIA	AUCUNE	\N	\N	\N	Accueil de Ding Gung Rimpoche	Accueil de Ding Gung Rimpoche	2022-06-14 14:00:00	2022-06-14 15:30:00	\N	\N	2	0	634	\N
683220	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2023 Mission Défense	PLF 2023 Mission Défense	2022-12-05 10:30:00	2022-12-05 13:00:00	\N	\N	45	0	\N	\N
683221	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2023 Mission Action extérieure de l'Etat	PLF 2023 Mission Action extérieure de l'Etat	2022-12-05 14:30:00	2022-12-05 18:00:00	\N	\N	65	0	\N	\N
683222	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2023 Mission Aide publique au développement	PLF 2023 Mission Aide publique au développement	2022-12-05 18:00:00	2022-12-05 20:00:00	\N	\N	59	0	\N	\N
683224	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2023 Articles non rattachés	PLF 2023 Articles non rattachés	2022-12-05 21:30:00	2022-12-06 01:35:00	\N	\N	54	0	\N	\N
683227	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Conseil européen	Débat Débat Conseil européen	2022-12-06 21:00:00	2022-12-06 23:25:00	\N	\N	44	0	\N	\N
683228	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2022-12-07 15:00:00	2022-12-07 16:20:00	\N	\N	290	0	\N	\N
683229	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Energie Collectivites territoriales	PPL Energie Collectivites territoriales	2022-12-07 16:35:00	2022-12-07 18:20:00	\N	\N	75	0	\N	\N
683230	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR 34-1 Transport ferroviaire	PPR 34-1 Transport ferroviaire	2022-12-07 18:25:00	2022-12-07 19:35:00	\N	\N	45	0	\N	\N
683231	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Fraude CPF	PPL Fraude CPF	2022-12-08 10:30:00	2022-12-08 11:45:00	\N	\N	46	0	\N	\N
683232	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL délégation aux droits de l'enfant	PPL délégation aux droits de l'enfant	2022-12-08 11:45:00	2022-12-08 13:15:00	\N	\N	48	0	\N	\N
683233	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL précarité des AESH	PPL précarité des AESH	2022-12-08 16:00:00	2022-12-08 17:35:00	\N	\N	58	0	\N	\N
683234	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Equité déserts médicaux	PPL Equité déserts médicaux	2022-12-08 17:40:00	2022-12-08 20:00:00	\N	\N	51	0	\N	\N
683500	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	MI métropoles Lyon Aix-Marseille-Provence	MI métropoles Lyon Aix-Marseille-Provence	2022-12-02 10:00:00	2022-12-02 11:00:00	\N	\N	6	0	\N	\N
683947	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	1781	\N	\N	PLF 2023 Explications de vote et scrutin	PLF 2023 Explications de vote et scrutin	2022-12-06 14:30:00	2022-12-06 16:40:00	\N	\N	318	0	\N	\N
684945	GIA	AUCUNE	\N	\N	\N	Rencontre Ambassadrice NZ	Rencontre avec Mme Caroline Peta Bilkey, ambassadrice de Nouvelle-Zélande en France	2022-12-06 08:45:00	2022-12-06 10:00:00	\N	\N	9	0	663	\N
685015	COM_PERMANENTE	AUTRE	\N	CAE	\N	MCC ZAN	MCC Zéro artificialisation nette	2022-12-06 17:40:00	2022-12-06 19:30:00	\N	\N	15	0	\N	\N
686228	COM_PERMANENTE	AUTRE	\N	CAE	\N	MCC ZAN	MCC Zéro artificialisation nette	2022-12-07 16:30:00	2022-12-07 18:30:00	\N	\N	11	0	\N	\N
659414	SEANCE_PLENIERE	DECL_GVT	\N	\N	\N	Déclaration du Gouvernement	Déclaration du Gouvernement	2022-10-12 21:30:00	2022-10-12 23:50:00	\N	\N	117	0	\N	\N
705855	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désignations -  PPL Violences intrafamiliales - PPLO Saint-Barth - MI Police Gendarmerie	Désignations -  PPL Violences intrafamiliales - PPLO Saint-Barth - MI Police Gendarmerie	2023-03-08 10:00:00	2023-03-08 11:50:00	2023-03-08 13:33:04	2023-03-08 17:31:06	29	2	\N	\N
676319	COM_PERMANENTE	AUTRE	\N	ETRD	\N	PLF 2023 - Examen de 6 avis budgétaires	PLF 2023 - Examen de 6 avis budgétaires	2022-11-23 10:05:00	2022-11-23 11:40:00	2022-11-23 12:12:09	2022-11-23 15:15:10	45	2	\N	\N
677483	COM_PERMANENTE	AUTRE	\N	CAE	\N	PLF 2023 - Avis budgétaires	\N	2022-11-23 09:00:00	2022-11-23 11:50:00	2022-11-23 11:57:38	2022-11-23 15:15:08	48	1	\N	\N
687357	COM_PERMANENTE	AUTRE	\N	CAE	\N	Table ronde sur la relance du nucléaire	\N	2022-12-14 09:35:00	2022-12-14 12:30:00	2022-12-14 12:37:53	2022-12-14 15:55:18	40	0	\N	\N
687362	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion plénière	\N	2022-12-14 09:30:00	2022-12-14 10:40:00	2022-12-15 16:06:01	2022-12-15 17:54:00	34	3	\N	\N
687518	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	GT Décentralisation 	Décentralisation - auditions rapporteurs	2022-12-08 14:00:00	2022-12-08 15:15:00	\N	\N	3	0	\N	\N
688386	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI cinéma	\N	2022-12-14 17:00:00	2022-12-14 18:00:00	\N	\N	4	0	\N	\N
688394	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2023-01-10 17:35:00	2023-01-10 18:40:00	2023-01-11 09:15:58	2023-01-12 17:25:04	33	1	\N	\N
688395	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2023-01-11 09:40:00	2023-01-11 12:00:00	2023-01-12 14:49:41	2023-01-12 17:25:08	38	0	\N	\N
688396	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Pascal Martin et M. Daniel Gremillet	Auditions M. Pascal Martin et M. Daniel Gremillet	2022-12-06 19:15:00	2022-12-06 20:00:00	\N	\N	2	0	\N	\N
688399	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Pascal Martin et M. Daniel Gremillet	Auditions M. Pascal Martin et M. Daniel Gremillet	2022-12-12 09:45:00	2022-12-12 11:30:00	\N	\N	2	0	\N	\N
688402	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Pascal Martin	Auditions M. Pascal Martin	2022-12-13 09:00:00	2022-12-13 10:10:00	\N	\N	1	0	\N	\N
688404	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Pascal Martin et M. Daniel Gremillet	Auditions M. Pascal Martin et M. Daniel Gremillet	2022-12-13 10:15:00	2022-12-13 11:00:00	\N	\N	2	0	\N	\N
688407	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Pascal Martin	Auditions M. Pascal Martin	2022-12-13 14:45:00	2022-12-13 15:30:00	\N	\N	1	0	\N	\N
688409	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Pascal Martin et M. Daniel Gremillet	Auditions M. Pascal Martin et M. Daniel Gremillet	2022-12-13 16:00:00	2022-12-13 18:15:00	\N	\N	2	0	\N	\N
688412	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition M. Pascal Martin et M. Daniel Gremillet	Audition M. Pascal Martin et M. Daniel Gremillet	2022-12-14 16:30:00	2022-12-14 17:00:00	\N	\N	2	0	\N	\N
688415	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Pascal Martin	Auditions M. Pascal Martin	2022-12-14 17:00:00	2022-12-14 19:15:00	\N	\N	1	0	\N	\N
688417	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Pascal Martin	Auditions M. Pascal Martin	2022-12-15 16:15:00	2022-12-15 17:45:00	\N	\N	1	0	\N	\N
688421	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 12 janvier 2023	\N	2023-01-12 09:00:00	2023-01-12 10:40:00	2023-01-12 10:39:12	2023-01-12 17:25:17	11	0	\N	\N
688428	COM_PERMANENTE	DEPLACEMENT	\N	SOCI	\N	Situation de la pédiatrie et de la réanimation pédiatrique - Hôpital Necker	\N	2022-12-15 09:00:00	2022-12-15 10:30:00	\N	\N	4	0	\N	\N
688472	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Installations nucléaires	\N	2022-12-13 10:30:00	2022-12-13 11:00:00	\N	\N	4	0	\N	\N
688477	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Installations nucléaires	\N	2022-12-13 16:00:00	2022-12-13 17:00:00	\N	\N	4	0	\N	\N
688483	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Installations nucléaires	\N	2022-12-13 17:00:00	2022-12-13 17:45:00	\N	\N	4	0	\N	\N
688488	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Installations nucléaires	\N	2022-12-13 17:45:00	2022-12-13 18:15:00	\N	\N	3	0	\N	\N
688492	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Installations nucléaires	\N	2022-12-13 18:15:00	2022-12-13 19:15:00	\N	\N	4	0	\N	\N
688502	COM_PERMANENTE	AUTRE	\N	CAE	\N	\N	\N	2022-12-12 11:30:00	2022-12-12 12:00:00	\N	\N	2	0	\N	\N
688565	GIA	AUCUNE	\N	\N	\N	Rencontre avec le Conseil indigéniste missionnaire du Brésil	Rencontre avec le Conseil indigéniste missionnaire du Brésil (CIMI)	2022-11-22 15:00:00	2022-11-22 16:00:00	\N	\N	1	0	576	\N
688575	COM_PERMANENTE	AUDRAP	\N	CAE	\N	CSE	CSE	2022-12-19 09:15:00	2022-12-19 09:45:00	\N	\N	2	0	\N	\N
640045	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Question migratoire	MI Question migratoire	2022-03-23 18:00:00	2022-03-23 19:00:00	\N	\N	5	0	\N	\N
640690	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2022-03-30 09:40:00	2022-03-30 12:05:00	\N	\N	3	0	\N	\N
640707	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Indopacifique	\N	2022-03-30 10:00:00	2022-03-30 11:30:00	\N	\N	3	0	\N	\N
640765	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MCI Délinquance des mineurs	MCI Délinquance des mineurs	2022-03-31 09:00:00	2022-03-31 11:00:00	\N	\N	4	0	\N	\N
640772	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MCI Déliquance des mineurs	MCI Délinquance des mineurs	2022-03-31 11:00:00	2022-03-31 12:30:00	\N	\N	5	0	\N	\N
640779	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Question migratoire	MI Question migratoire	2022-03-16 19:30:00	2022-03-16 20:15:00	\N	\N	4	0	\N	\N
642624	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Audition de SE M. l'ambassadeur d'Ukraine en France	\N	2022-05-11 15:00:00	2022-05-11 16:45:00	\N	\N	16	0	\N	\N
642645	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Conseil national du notariat (CSN)	\N	2022-05-10 14:00:00	2022-05-10 15:00:00	\N	\N	4	0	\N	\N
642646	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	SOBREFER	\N	2022-05-10 16:00:00	2022-05-10 17:30:00	\N	\N	3	0	\N	\N
642654	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Obésité - Table ronde Aide à la parentalité en matière de nutrition	\N	2022-05-11 14:00:00	2022-05-11 15:30:00	\N	\N	4	0	\N	\N
642671	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 2022 - Les scénarios de financement des CT - Cour des comptes	58-2 2022 - Les scénarios de financement des CT - Cour des comptes	2022-05-11 15:35:00	2022-05-11 17:00:00	\N	\N	3	0	\N	\N
642675	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 -  Régimes des retraites RATP et Marins - DGITM	Contrôle 2022 -  Régimes des retraites RATP et Marins - DGITM	2022-05-11 16:00:00	2022-05-11 17:00:00	\N	\N	1	0	\N	\N
642677	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	MCC 2022 - Audiovisuel Public - APE/France Télévisions	\N	2022-05-12 09:30:00	2022-05-12 11:50:00	\N	\N	0	0	\N	\N
642681	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022- IGN - CNIG/DGFiP	Contrôle 2022- IGN - CNIG/DGFiP	2022-05-12 09:30:00	2022-05-12 11:40:00	\N	\N	1	0	\N	\N
642683	DELEGATION	AUCUNE	\N	\N	211	Table ronde avec des acteurs institutionnels 	Table ronde avec des acteurs institutionnels 	2022-05-18 14:30:00	2022-05-18 16:15:00	\N	\N	8	0	\N	\N
655858	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Orientation et programmation du ministère de l'intérieur	Audition rapporteur - PJL LOPMI	2022-09-20 10:00:00	2022-09-20 10:40:00	\N	\N	3	0	\N	\N
655863	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Orientation et programmation du ministère de l'intérieur	Audition rapporteur - PJL LOPMI	2022-09-20 15:30:00	2022-09-20 16:10:00	\N	\N	4	0	\N	\N
655902	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Orientation et programmation du ministère de l'intérieur	Audition rapporteur - PJL LOPMI	2022-09-20 16:30:00	2022-09-20 17:15:00	\N	\N	5	0	\N	\N
655908	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Orientation et programmation du ministère de l'intérieur	Audition rapporteur - PJL LOPMI	2022-09-20 17:15:00	2022-09-20 18:10:00	\N	\N	6	0	\N	\N
656425	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2022-09-27 15:00:00	2022-09-27 18:00:00	\N	\N	2	0	\N	\N
659410	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL LOPMI	PJL LOPMI	2022-10-11 14:30:00	2022-10-11 20:00:00	\N	\N	199	0	\N	\N
659411	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL LOPMI	PJL LOPMI	2022-10-11 21:30:00	2022-10-12 00:25:00	\N	\N	78	0	\N	\N
659412	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2022-10-12 15:00:00	2022-10-12 16:20:00	\N	\N	293	0	\N	\N
659413	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL LOPMI	PJL LOPMI	2022-10-12 16:30:00	2022-10-12 20:00:00	\N	\N	115	0	\N	\N
662018	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	1721	\N	\N	Explications de vote sur l'ensemble - PJL LOPMI	Explications de vote sur l'ensemble - PJL LOPMI	2022-10-18 14:30:00	2022-10-18 15:30:00	\N	\N	281	0	\N	\N
662019	SEANCE_PLENIERE	SCRUSOL	1721	\N	\N	Scrutin solennel - PJL LOPMI	Scrutin solennel - PJL LOPMI	2022-10-18 14:30:00	2022-10-18 15:45:00	\N	\N	0	0	\N	\N
662261	GIA	AUCUNE	\N	\N	\N	Visite d'une délégation au Brésil	Visite d'une délégation du groupe d'amitié au Brésil	2022-03-12 09:00:00	2022-03-20 12:00:00	\N	\N	3	0	576	\N
662366	GIA	AUCUNE	\N	\N	\N	Déjeuner de travail avec l'ambassadrice de France au Brésil	Déjeuner de travail avec S.E. Mme Brigitte Collet, ambassadrice de France au Brésil	2022-10-18 12:30:00	2022-10-18 14:30:00	\N	\N	11	0	576	\N
662403	GIA	AUCUNE	\N	\N	\N	Rencontre avec la coalition Solidarité Brésil	Rencontre avec la coalition Solidarité Brésil pour la présentation de leur baromètre sur les droits humains au Brésil	2022-10-05 17:00:00	2022-10-05 18:30:00	\N	\N	3	0	576	\N
662417	GIA	AUCUNE	\N	\N	\N	Rencontre avec un député brésilien	Rencontre avec M. David SOARES, député fédéral du Brésil	2022-10-13 16:00:00	2022-10-13 17:00:00	\N	\N	1	0	576	\N
662432	GIA	AUCUNE	\N	\N	\N	Rencontre avec un collectif d'associations franco-brésiliennes	Rencontre avec un collectif d'associations franco-brésiliennes	2022-05-18 17:00:00	2022-05-18 19:00:00	\N	\N	2	0	576	\N
662446	GIA	AUCUNE	\N	\N	\N	Rencontre avec le ministre de l'environnement de l'état du Para	Rencontre avec M. José MAURO DE LIMA O'DE ALMEIDA, Secrétaire d¿État à l'environnement de l'état du Parà	2022-06-24 09:30:00	2022-06-24 10:30:00	\N	\N	1	0	576	\N
662462	GIA	AUCUNE	\N	\N	\N	Déjeuner de travail avec la directice Amériques au MAE	Déjeuner de travail avec Mme Michèle Ramis, directice Amériques au Ministère de l'Europe et des affaires étrangères	2022-07-05 13:00:00	2022-07-05 14:30:00	\N	\N	7	0	576	\N
668113	GIA	AUCUNE	\N	\N	\N	Audition de M. Chritophe BIGOT, Directeur Afrique au MEAE	Audition de M. Christophe BIGOT, Directeur Afrique au MEAE	2022-11-02 12:05:00	2022-11-02 13:10:00	\N	\N	3	0	573	\N
669891	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2023	PLFSS 2023	2022-11-07 16:00:00	2022-11-07 19:25:00	\N	\N	72	0	\N	\N
669892	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2023	PLFSS 2023	2022-11-07 21:30:00	2022-11-08 01:00:00	\N	\N	64	0	\N	\N
669893	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2023	PLFSS 2023	2022-11-08 14:45:00	2022-11-08 19:55:00	\N	\N	183	0	\N	\N
669894	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2023	PLFSS 2023	2022-11-08 21:30:00	2022-11-09 01:15:00	\N	\N	101	0	\N	\N
669895	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2022-11-09 15:00:00	2022-11-09 16:20:00	\N	\N	287	0	\N	\N
669896	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2023	PLFSS 2023	2022-11-09 16:30:00	2022-11-09 20:00:00	\N	\N	106	0	\N	\N
669897	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2023	PLFSS 2023	2022-11-09 21:30:00	2022-11-10 01:20:00	\N	\N	92	0	\N	\N
669898	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2023	PLFSS 2023	2022-11-10 10:30:00	2022-11-10 13:05:00	\N	\N	71	0	\N	\N
669899	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2023	PLFSS 2023	2022-11-10 14:35:00	2022-11-10 18:00:00	\N	\N	53	0	\N	\N
669900	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2023	PLFSS 2023	2022-11-12 09:30:00	2022-11-12 13:15:00	\N	\N	43	0	\N	\N
669901	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2023	PLFSS 2023	2022-11-12 14:45:00	2022-11-12 18:05:00	\N	\N	40	0	\N	\N
728777	QUESTURE	AUCUNE	\N	\N	\N	Réunion de Questure	Réunion de Questure	2023-05-04 09:00:00	2023-05-04 10:36:00	\N	\N	2	0	\N	\N
729261	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2023-05-09 17:00:00	2023-05-09 19:00:00	\N	\N	1	0	\N	\N
729267	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Orientation et programmation du ministère de la justice 2023-2027	PJL Orientation et programmation du ministère de la justice 2023-2027	2023-05-09 14:10:00	2023-05-09 16:00:00	\N	\N	5	0	\N	\N
729276	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Orientation et programmation du ministère de la justice 2023-2027	PJL Orientation et programmation du ministère de la justice 2023-2027	2023-05-09 17:00:00	2023-05-09 18:40:00	\N	\N	5	0	\N	\N
729286	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Orientation et programmation du ministère de la justice 2023-2027	PJL Orientation et programmation du ministère de la justice 2023-2027	2023-05-09 18:40:00	2023-05-09 19:50:00	\N	\N	3	0	\N	\N
729291	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Français de l'étranger	MI Français de l'étranger	2023-05-09 16:00:00	2023-05-09 17:15:00	\N	\N	2	0	\N	\N
704289	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Immigration et intégration	Audition rapporteur - PJL Immigration et intégration	2023-02-22 16:15:00	2023-02-22 18:00:00	\N	\N	2	0	\N	\N
704295	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Immigration et intégration	Audition rapporteur - PJL Immigration et intégration	2023-02-24 09:00:00	2023-02-24 12:00:00	\N	\N	2	0	\N	\N
704316	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de Sébastien Lecornu	Audition de Sébastien Lecornu, ministre des armées	2023-02-28 17:30:00	2023-02-28 19:40:00	2023-03-02 12:10:37	2023-03-02 18:15:36	25	0	\N	\N
704327	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Rapport d'information golfe de Guinée	Rapport d'information "Quelle stratégie française dans le golfe de Guinée"	2023-03-01 10:00:00	2023-03-01 11:15:00	2023-03-01 15:48:19	2023-03-01 16:37:28	24	5	\N	\N
704471	MISSION	AUTRE	\N	BIOCARBU	\N	MI BIOCARBURANTS - 3	\N	2023-02-28 16:30:00	2023-02-28 18:30:00	2023-03-02 09:20:37	2023-03-02 10:08:22	10	0	\N	\N
704808	COM_SPECIALE	AUDRAP	\N	CZAN	\N	Audition CS ZAN	Audition CS ZAN	2023-02-28 08:40:00	2023-02-28 09:00:00	\N	\N	7	0	\N	\N
704870	DELEGATION	AUDRAP	\N	\N	206	Audition sobriété énergétique	\N	2023-02-21 11:00:00	2023-02-21 12:00:00	\N	\N	2	0	\N	\N
706367	COM_SPECIALE	AUDRAP	\N	CZAN	\N	Audition CS ZAN - France urbaine	Audition CS ZAN - France urbaine	2023-03-01 09:30:00	2023-03-01 10:40:00	\N	\N	7	0	\N	\N
706368	COM_SPECIALE	AUDRAP	\N	CZAN	\N	Audition CS ZAN - Société du grand Paris	Audition CS ZAN - Société du grand Paris	2023-03-01 10:40:00	2023-03-01 11:30:00	\N	\N	5	0	\N	\N
706464	DELEGATION	AUDRAP	\N	\N	PROS	Audition M. Dordain	\N	2023-03-08 16:30:00	2023-03-08 17:30:00	\N	\N	2	0	\N	\N
706467	DELEGATION	AUDRAP	\N	\N	206	Audition recyclage du plastique	\N	2023-03-09 14:00:00	2023-03-09 17:45:00	\N	\N	2	0	\N	\N
706470	DELEGATION	AUDRAP	\N	\N	206	Audition recyclage plastique	\N	2023-03-02 13:45:00	2023-03-02 17:45:00	\N	\N	2	0	\N	\N
706473	DELEGATION	AUDRAP	\N	\N	206	Audition sobriété énergétique	\N	2023-03-01 16:30:00	2023-03-01 18:30:00	\N	\N	2	0	\N	\N
706608	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Violences intrafamiliales	\N	2023-03-03 16:30:00	2023-03-03 17:10:00	\N	\N	1	0	\N	\N
708148	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFRSS	Projet de loi de financement rectificative de la sécurité sociale	2023-03-07 14:30:00	2023-03-07 20:00:00	\N	\N	253	0	\N	\N
708155	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2023-03-08 15:00:00	2023-03-08 16:20:00	\N	\N	294	0	\N	\N
708160	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFRSS	Projet de loi de financement rectificative de la sécurité sociale	2023-03-07 21:30:00	2023-03-08 03:20:00	\N	\N	224	0	\N	\N
708161	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFRSS	Projet de loi de financement rectificative de la sécurité sociale	2023-03-08 16:35:00	2023-03-08 20:00:00	\N	\N	218	0	\N	\N
708187	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFRSS	Projet de loi de financement rectificative de la sécurité sociale	2023-03-08 21:30:00	2023-03-09 00:40:00	\N	\N	185	0	\N	\N
708188	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFRSS	Projet de loi de financement rectificative de la sécurité sociale	2023-03-09 10:30:00	2023-03-09 13:30:00	\N	\N	175	0	\N	\N
708191	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFRSS	Projet de loi de financement rectificative de la sécurité sociale	2023-03-09 15:00:00	2023-03-09 20:00:00	\N	\N	182	0	\N	\N
708192	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFRSS	Projet de loi de financement rectificative de la sécurité sociale	2023-03-09 21:30:00	2023-03-10 00:40:00	\N	\N	135	0	\N	\N
708194	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFRSS	Projet de loi de financement rectificative de la sécurité sociale	2023-03-10 09:40:00	2023-03-10 12:50:00	\N	\N	147	0	\N	\N
708195	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFRSS	Projet de loi de financement rectificative de la sécurité sociale	2023-03-10 14:50:00	2023-03-10 20:00:00	\N	\N	156	0	\N	\N
708199	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFRSS	Projet de loi de financement rectificative de la sécurité sociale	2023-03-10 21:30:00	2023-03-11 00:30:00	\N	\N	117	0	\N	\N
708201	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFRSS	Projet de loi de financement rectificative de la sécurité sociale	2023-03-11 09:30:00	2023-03-11 13:00:00	\N	\N	119	0	\N	\N
708202	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFRSS	Projet de loi de financement rectificative de la sécurité sociale	2023-03-11 14:30:00	2023-03-11 19:55:00	\N	\N	141	0	\N	\N
708203	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFRSS	Projet de loi de financement rectificative de la sécurité sociale	2023-03-11 21:30:00	2023-03-11 23:45:00	\N	\N	139	0	\N	\N
708455	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2023-03-02 09:00:00	2023-03-02 11:10:00	\N	\N	3	0	\N	\N
708803	COM_SPECIALE	AUDRAP	\N	CINC	\N	Table ronde FNEDT, Union coopération française forestière et France Bois Forêt 	Table ronde FNEDT, Union coopération française forestière et France Bois Forêt 	2023-03-06 17:45:00	2023-03-06 18:45:00	\N	\N	12	0	\N	\N
708816	COM_SPECIALE	AUDRAP	\N	CINC	\N	Audition DGALN	\N	2023-03-06 18:45:00	2023-03-06 19:30:00	\N	\N	12	0	\N	\N
708829	COM_SPECIALE	AUDRAP	\N	CINC	\N	Office national des forêts	Office national des forêts	2023-03-06 19:30:00	2023-03-06 20:15:00	\N	\N	13	0	\N	\N
708844	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Audition commune IGF / IGESR	\N	2023-03-07 09:00:00	2023-03-07 11:00:00	\N	\N	2	0	\N	\N
708924	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	audition MI autonomie ES	\N	2023-03-07 13:30:00	2023-03-07 14:30:00	\N	\N	4	0	\N	\N
709057	MISSION	AUCUNE	\N	BIOCARBU	\N	MI BIOCARBURANTS - 5	\N	2023-03-14 17:35:00	2023-03-14 19:20:00	2023-03-14 19:20:55	2023-03-16 14:05:00	5	0	\N	\N
709139	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Université Paris 1 Panthéon-Sorbonne	\N	2023-03-07 14:30:00	2023-03-07 15:30:00	\N	\N	2	0	\N	\N
709140	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Sociologues	\N	2023-03-07 15:30:00	2023-03-07 16:30:00	\N	\N	2	0	\N	\N
709156	DELEGATION	AUCUNE	\N	\N	DSOM	Parentalité outre-mer : Audition Croix-Rouge et table ronde Mayotte	\N	2023-03-16 10:30:00	2023-03-16 12:00:00	\N	\N	7	0	\N	\N
709948	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Collectif Inclusion scolaire en danger	\N	2023-03-08 11:00:00	2023-03-08 12:30:00	\N	\N	2	0	\N	\N
709951	COM_SPECIALE	AUDRAP	\N	CINC	\N	TR Forêt privée 	TR Forêt privée	2023-03-07 14:30:00	2023-03-07 15:30:00	\N	\N	13	0	\N	\N
709965	COM_SPECIALE	AUDRAP	\N	CINC	\N	GIP ATGeRI	GIP ATGeRI	2023-03-07 15:30:00	2023-03-07 16:15:00	\N	\N	11	0	\N	\N
709977	COM_SPECIALE	AUDRAP	\N	CINC	\N	FNCOFOR	FNCOFOR	2023-03-07 16:15:00	2023-03-07 17:00:00	\N	\N	11	0	\N	\N
709989	COM_SPECIALE	AUDRAP	\N	CINC	\N	FNSPF	FNSPF	2023-03-07 17:00:00	2023-03-07 17:45:00	\N	\N	6	0	\N	\N
709996	COM_SPECIALE	AUDRAP	\N	CINC	\N	Confédération paysanne	Confédération paysanne	2023-03-07 17:45:00	2023-03-07 18:30:00	\N	\N	7	0	\N	\N
710021	MISSION	AUCUNE	\N	GEAU	\N	Association Nationale des Élus des Bassins 	\N	2023-03-08 14:00:00	2023-03-08 15:00:00	2023-03-08 15:01:42	2023-03-08 17:32:04	7	0	\N	\N
710027	MISSION	AUDRAP	\N	LOCA	\N	MI Finances locales - Audition de l'AMRF	MI Finances locales - Audition de l'AMRF	2023-03-15 17:00:00	2023-03-15 18:00:00	\N	\N	9	0	\N	\N
710323	GIA	AUCUNE	\N	\N	\N	Coopé - Visite de M. Alexandr TRUBCA, Député, Président de la Commission Agriculture et In	Coopé - Visite de M. Alexandr TRUBCA, Député, Président de la Commission Agriculture et Industries alimentaires	2023-03-08 14:00:00	2023-03-08 15:00:00	\N	\N	2	0	851	\N
710339	MISSION	AUTRE	\N	BIOCARBU	\N	MI BIOCARBURANTS - 4	\N	2023-03-08 16:30:00	2023-03-08 17:50:00	2023-03-14 16:16:10	2023-03-14 16:16:44	5	0	\N	\N
710874	COM_ENQUETE	PLENIERE	\N	MEDIC	\N	Réunion plénière	\N	2023-03-14 13:35:00	2023-03-14 15:00:00	2023-03-14 14:24:01	2023-03-16 14:05:01	9	0	\N	\N
711641	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2023-03-09 09:00:00	2023-03-09 12:30:00	\N	\N	4	0	\N	\N
640919	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition MI énergie et hydrogène nucléaires	Audition MI énergie et hydrogène nucléaires	2022-04-29 15:00:00	2022-04-29 16:00:00	\N	\N	4	0	\N	\N
640924	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition MI énergie et hydrogène nucléaires	Audition MI énergie et hydrogène nucléaires	2022-03-29 16:00:00	2022-03-29 17:00:00	\N	\N	3	0	\N	\N
641761	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI SPIP	MI SPIP - Auditions	2022-04-25 14:00:00	2022-04-25 17:30:00	\N	\N	3	0	\N	\N
642185	COM_PERMANENTE	AUTRE	\N	FINC	\N	Bilan Apleg - Comptes-rendus Conférence Art 13 TSCG Bruxelles et Déplacement bureau USA	Bilan Apleg - Comptes-rendus Conférence interparlementaire Art 13 TSCG Bruxelles et Déplacement bureau USA	2022-05-11 09:30:00	2022-05-11 11:30:00	2022-05-11 12:29:03	2022-05-11 17:34:10	29	0	\N	\N
708936	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2023-03-15 09:30:00	2023-03-15 10:55:00	2023-03-15 17:15:35	2023-03-16 14:02:37	40	2	\N	\N
709906	COM_PERMANENTE	AUTRE	\N	CAE	\N	PPL 821 - examen rapport et texte	\N	2023-03-08 11:40:00	2023-03-08 12:10:00	2023-03-08 12:30:18	2023-03-08 17:31:04	35	0	\N	\N
642186	DELEGATION	AUCUNE	\N	\N	DSOM	Auditions de la DGOM et de l'ADEME	\N	2022-05-19 09:30:00	2022-05-19 12:00:00	\N	\N	14	0	\N	\N
642187	DELEGATION	AUDRAP	\N	\N	206	Audition M. Lelièvre	\N	2022-04-25 08:40:00	2022-04-25 09:45:00	\N	\N	3	0	\N	\N
642191	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - FEI - Élus Mayotte / Réunion	Contrôle 2022 - FEI - Élus Mayotte / Réunion	2022-04-27 10:15:00	2022-04-27 11:50:00	\N	\N	2	0	\N	\N
642194	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - FEI - Élus Guadeloupe / Martinique / Guyane	Contrôle 2022 - FEI - Élus Guadeloupe / Martinique / Guyane	2022-04-27 15:00:00	2022-04-27 16:30:00	\N	\N	2	0	\N	\N
642197	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2022 - Maisons France services - Déplacement Nord	Contrôle 2022 - Maisons France services - Déplacement Nord	2022-04-27 07:00:00	2022-04-27 18:00:00	\N	\N	1	0	\N	\N
642199	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - ZAN - ANRU	Contrôle 2022 - ZAN - ANRU	2022-05-04 09:00:00	2022-05-04 10:00:00	\N	\N	1	0	\N	\N
642200	DELEGATION	AUDRAP	\N	\N	206	Audition Institut de cardiologie de la Pitié-Salprêtrière	\N	2022-05-02 09:30:00	2022-05-02 10:30:00	\N	\N	3	0	\N	\N
642205	DELEGATION	AUDRAP	\N	\N	206	Audition CNGOF	\N	2022-05-02 10:30:00	2022-05-02 11:30:00	\N	\N	3	0	\N	\N
642209	DELEGATION	AUDRAP	\N	\N	206	Audition Mme Soave	\N	2022-05-02 11:30:00	2022-05-02 12:30:00	\N	\N	3	0	\N	\N
642210	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - ZAN - AMF/ADCF et Fédération SCOT	Contrôle 2022 - ZAN - AMF/ADCF et Fédération SCOT	2022-05-04 15:30:00	2022-05-04 18:00:00	\N	\N	1	0	\N	\N
642212	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - OAT vertes - TotalEnergies	Contrôle 2022 - OAT vertes - TotalEnergies	2022-05-04 11:10:00	2022-05-04 12:10:00	\N	\N	1	0	\N	\N
642217	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022- IGN - CGDD	Contrôle 2022- IGN - CGDD	2022-05-03 14:30:00	2022-05-03 15:30:00	\N	\N	1	0	\N	\N
642219	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022- IGN - CPOIA/DB	Contrôle 2022- IGN - CPOIA/DB	2022-05-05 10:00:00	2022-05-05 12:30:00	\N	\N	1	0	\N	\N
642221	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022- IGN - Auteurs Rapport analyse IGN	Contrôle 2022- IGN - Auteurs Rapport analyse IGN	2022-05-05 14:30:00	2022-05-05 15:30:00	\N	\N	1	0	\N	\N
642223	DELEGATION	AUDRAP	\N	\N	206	Audition LEEM	\N	2022-04-29 11:45:00	2022-04-29 12:45:00	\N	\N	3	0	\N	\N
642227	DELEGATION	AUDRAP	\N	\N	206	Audition Jean-François Delfraissy	\N	2022-04-29 10:40:00	2022-04-29 11:45:00	\N	\N	3	0	\N	\N
642231	DELEGATION	AUDRAP	\N	\N	206	Audition de François Alla	\N	2022-04-29 09:30:00	2022-04-29 10:40:00	\N	\N	3	0	\N	\N
642235	DELEGATION	AUDRAP	\N	\N	PROS	Audition Arthur Sauzay	\N	2022-05-05 10:00:00	2022-05-05 11:00:00	\N	\N	2	0	\N	\N
642248	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	MCC 2022 - Audiovisuel Public - Personnalités qualifiées	\N	2022-05-09 09:30:00	2022-05-09 11:30:00	\N	\N	0	0	\N	\N
642819	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - Immobilier MEAE - DIE/DB	Contrôle 2022 - Immobilier MEAE - DIE/DB	2022-05-09 16:15:00	2022-05-09 18:30:00	\N	\N	2	0	\N	\N
642822	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - Fusion Expertise France et AFD - CIVIPOL	Contrôle 2022 - Fusion Expertise France et AFD - CIVIPOL	2022-05-10 18:00:00	2022-05-10 19:00:00	\N	\N	2	0	\N	\N
642825	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2021 - Douane face au trafic de stupéfiants - Déplacement à Orly	Contrôle 2021 - Douane face au trafic de stupéfiants - Déplacement à Orly	2022-05-17 06:45:00	2022-05-17 11:45:00	\N	\N	2	0	\N	\N
642826	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2022 - Secrétariats généraux communs - Déplacement à Guéret	Contrôle 2022 - Secrétariats généraux communs - Déplacement à Guéret	2022-05-05 09:00:00	2022-05-05 17:30:00	\N	\N	1	0	\N	\N
642828	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2022 - Secrétariats généraux communs - Déplacement à Épinal	Contrôle 2022 - Secrétariats généraux communs - Déplacement à Épinal	2022-05-09 16:00:00	2022-05-10 20:00:00	\N	\N	1	0	\N	\N
642830	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2022 - Secrétariats généraux communs - Déplacement à Lyon	Contrôle 2022 - Secrétariats généraux communs - Déplacement à Lyon	2022-05-12 09:00:00	2022-05-12 19:30:00	\N	\N	1	0	\N	\N
642832	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - Secrétariats généraux communs - OS Pref. Mayotte/DSGC Mayotte	Contrôle 2022 - Secrétariats généraux communs - OS Pref. Mayotte/DSGC Mayotte	2022-05-06 15:00:00	2022-05-06 17:30:00	\N	\N	1	0	\N	\N
642834	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - Entreprises adaptées - TR service public de l'emploi	Contrôle 2022 - Entreprises adaptées - TR service public de l'emploi	2022-05-12 14:00:00	2022-05-12 15:30:00	\N	\N	2	0	\N	\N
642970	DELEGATION	AUCUNE	\N	\N	211	Table ronde avec des magistrats du Parquet de Paris	Table ronde avec des magistrats du Parquet de Paris	2022-06-15 15:30:00	2022-06-15 16:55:00	\N	\N	9	0	\N	\N
642973	COM_PERMANENTE	AUDRAP	\N	FINC	\N	MI Fraude et évasion fiscales - MICAF/CIF	MI Fraude et évasion fiscales - MICAF/CIF	2022-05-18 14:00:00	2022-05-18 16:00:00	\N	\N	7	0	\N	\N
642981	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - OAT vertes - Caisse des dépôts	Contrôle 2022 - OAT vertes - Caisse des dépôts	2022-05-18 14:35:00	2022-05-18 15:35:00	\N	\N	1	0	\N	\N
642986	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - Entreprises adaptées - UNEA/DGEFP	Contrôle 2022 - Entreprises adaptées - UNEA/DGEFP	2022-05-17 10:00:00	2022-05-17 12:00:00	\N	\N	2	0	\N	\N
642989	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - Entreprises adaptées - TR associations représentants	Contrôle 2022 - Entreprises adaptées - TR associations représentants de personnes en situation de handicap	2022-05-17 15:00:00	2022-05-17 16:00:00	\N	\N	2	0	\N	\N
642992	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - RGA - Auteurs du rapport gestion des dommages	Contrôle 2022 - RGA - Auteurs du rapport gestion des dommages	2022-05-17 14:00:00	2022-05-17 15:15:00	\N	\N	1	0	\N	\N
642995	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI JO Paris 2024	\N	2022-05-18 15:00:00	2022-05-18 16:30:00	\N	\N	2	0	\N	\N
642998	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	LPR	\N	2022-05-18 09:00:00	2022-05-18 10:00:00	\N	\N	3	0	\N	\N
643010	COM_EURO	AUDRAP	\N	AFEU	\N	Devoir de vigilance	\N	2022-05-06 14:00:00	2022-05-06 15:15:00	\N	\N	2	0	\N	\N
643028	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Obésité - Table ronde Fiscalité comportementale	\N	2022-05-18 15:00:00	2022-05-18 16:00:00	\N	\N	3	0	\N	\N
646188	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI SPIP	MI SPIP - Auditions	2022-07-01 09:00:00	2022-07-01 10:00:00	\N	\N	2	0	\N	\N
646191	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI SPIP	MI SPIP - Auditions	2022-07-01 10:00:00	2022-07-01 11:10:00	\N	\N	3	0	\N	\N
646195	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI SPIP	MI SPIP - Auditions	2022-07-01 11:10:00	2022-07-01 11:40:00	\N	\N	2	0	\N	\N
652721	GIA	AUCUNE	\N	\N	\N	Réunion de travail à l'Ambassade d'Autriche	Réunion de travail à l'Ambassade d'Autriche	2022-07-26 19:00:00	2022-07-26 23:00:00	\N	\N	5	0	579	\N
652747	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2022-07-28 09:00:00	2022-07-28 10:00:00	\N	\N	4	0	\N	\N
738759	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	honorabilité	\N	2023-06-06 16:00:00	2023-06-06 17:00:00	\N	\N	2	0	\N	\N
658356	GIA	AUCUNE	\N	\N	\N	Entretien sur la mission relative au renforcement des partenariats bilatéraux de défense 	Entretien sur la mission relative au renforcement des partenariats bilatéraux de défense en Croatie menée par des audite	2022-10-05 08:30:00	2022-10-05 09:50:00	\N	\N	2	0	647	\N
668420	GIA	AUCUNE	\N	\N	\N	Entretien avec une délégation parlementaire du Somaliland	Entretien avec une délégation parlementaire du Somaliland	2022-11-02 14:05:00	2022-11-02 15:00:00	\N	\N	3	0	588	\N
674847	GIA	AUCUNE	\N	\N	\N	entretien avec S.E. M. Ghazi ALRAWAS, ambassadeur d'Oman	\N	2022-11-16 08:00:00	2022-11-16 09:30:00	\N	\N	6	0	661	\N
676100	ETUDES	AUCUNE	\N	\N	\N	GE arts de la scène	\N	2022-11-09 16:30:00	2022-11-09 18:15:00	\N	\N	8	0	\N	966
688578	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	Réunion du Groupe d'études "Français de l'étranger" sur le statut des élus	Audition de représentants de l'Association des Maires de France 	2022-12-15 14:30:00	2022-12-15 15:50:00	\N	\N	2	0	\N	\N
688581	GIA	AUCUNE	\N	\N	\N	Réunion de bilan sur la mission aux Pays-Bas 	Réunion debriefing sur la mission aux Pays-Bas	2022-12-13 12:45:00	2022-12-13 14:20:00	\N	\N	2	0	599	\N
688590	GIA	AUCUNE	\N	\N	\N	Déjeuner de travail avec l'Ambassadeur de Grèce	Déjeuner de travail du Président du groupe avec l'Ambassadeur de Grèce	2022-11-10 12:30:00	2022-11-10 14:30:00	\N	\N	1	0	591	\N
688592	GIA	AUCUNE	\N	\N	\N	Réunion du bureau	Réunion du bureau du groupe d'amitié	2022-12-17 17:30:00	2022-12-17 18:30:00	\N	\N	2	0	591	\N
688595	COM_PERMANENTE	AUDRAP	\N	CAE	\N	TR syndicats EDF	TR syndicats EDF	2022-12-19 14:45:00	2022-12-19 15:45:00	\N	\N	2	0	\N	\N
688598	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Orano	Orano	2022-12-19 15:45:00	2022-12-19 16:30:00	\N	\N	2	0	\N	\N
688601	COM_PERMANENTE	AUDRAP	\N	CAE	\N	TR IDF - ADF	\N	2022-12-19 14:15:00	2022-12-19 14:45:00	\N	\N	0	0	\N	\N
688603	COM_PERMANENTE	AUDRAP	\N	CAE	\N	DGEC - DGPR	DGEC - DGPR	2022-12-20 09:00:00	2022-12-20 10:15:00	\N	\N	2	0	\N	\N
688607	COM_PERMANENTE	AUDRAP	\N	CAE	\N	DHUP - DEB	DHUP - DEB	2022-12-20 10:15:00	2022-12-20 11:30:00	\N	\N	2	0	\N	\N
688610	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Ministère de la Justice - Direction des affaires civiles et du sceau	Ministère de la Justice - Direction des affaires civiles et du sceau	2022-12-20 11:30:00	2022-12-20 12:00:00	\N	\N	2	0	\N	\N
688613	COM_PERMANENTE	AUDRAP	\N	CAE	\N	DLF	DLF	2022-12-20 12:00:00	2022-12-20 12:30:00	\N	\N	2	0	\N	\N
688616	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Egis	Egis	2022-12-20 12:30:00	2022-12-20 13:15:00	\N	\N	2	0	\N	\N
688632	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Communauté de communes de Thonon-Agglomération	Communauté de communes de Thonon-Agglomération	2022-12-13 16:00:00	2022-12-13 16:45:00	\N	\N	1	0	\N	\N
688634	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Préfecture de Haute-Savoie	Préfecture de Haute-Savoie	2022-12-13 16:45:00	2022-12-13 17:15:00	\N	\N	1	0	\N	\N
688636	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Conseil régional Auvergne-Rhône-Alpes	Conseil régional Auvergne-Rhône-Alpes	2022-12-13 17:30:00	2022-12-13 18:00:00	\N	\N	1	0	\N	\N
688638	COM_PERMANENTE	AUDRAP	\N	CAE	\N	DGITM/DAJ	DGITM/DAJ	2022-12-20 14:30:00	2022-12-20 15:00:00	\N	\N	1	0	\N	\N
688640	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Conseil départemental de Haute-Savoie	Conseil départemental de Haute-Savoie	2022-12-20 15:15:00	2022-12-20 16:00:00	\N	\N	1	0	\N	\N
688642	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Table ronde d'élus	Table ronde d'élus	2022-12-20 16:00:00	2022-12-20 17:00:00	\N	\N	1	0	\N	\N
688654	COM_PERMANENTE	AUDRAP	\N	CAE	\N	SIAC	SIAC	2022-12-22 11:00:00	2022-12-22 11:45:00	\N	\N	1	0	\N	\N
688706	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désignations - Avis sur recevabilité PPR	Désignations - Avis sur recevabilité PPR	2023-01-11 10:20:00	2023-01-11 10:30:00	2023-01-11 13:31:11	2023-01-12 17:25:10	36	0	\N	\N
688707	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de Christian Vigouroux et Florian Roussel	Audition de Christian Vigouroux et Florian Roussel	2023-01-11 10:30:00	2023-01-11 11:50:00	2023-01-11 13:31:17	2023-01-12 17:25:10	36	0	\N	\N
688708	COM_PERMANENTE	AUTRE	\N	LOIS	\N	États généraux de la justice - Audition d'Éric Dupond-Moretti	États généraux de la justice - Audition d'Éric Dupond-Moretti	2023-01-11 18:00:00	2023-01-11 19:25:00	2023-01-11 19:34:14	2023-01-12 17:25:11	16	0	\N	\N
688726	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation de l'ANV	Petit-déjeuner et visite de la bibliothèque	2022-11-29 08:00:00	2022-11-29 10:00:00	\N	\N	5	0	626	\N
688734	DELEGATION	AUCUNE	\N	\N	DSOM	Continuité territoriale : Corse	\N	2023-01-12 10:00:00	2023-01-12 11:40:00	\N	\N	10	0	\N	\N
688735	DELEGATION	AUDRAP	\N	\N	206	Auditions sobriété énergétique	\N	2022-12-15 09:00:00	2022-12-15 11:00:00	\N	\N	2	0	\N	\N
688736	DELEGATION	AUDRAP	\N	\N	206	Auditions sobriété énergétique	\N	2022-12-14 16:30:00	2022-12-14 18:30:00	\N	\N	2	0	\N	\N
688878	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Jeux Olympiques et Paralympiques de 2024	PJL Jeux Olympiques et Paralympiques de 2024	2023-01-09 15:00:00	2023-01-09 16:04:00	\N	\N	2	0	\N	\N
688881	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Jeux Olympiques et Paralympiques de 2024	PJL Jeux Olympiques et Paralympiques de 2024	2023-01-09 16:10:00	2023-01-09 17:50:00	\N	\N	3	0	\N	\N
688885	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	\N	\N	2023-01-10 09:00:00	2023-01-10 09:45:00	\N	\N	1	0	\N	\N
688886	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL JOP 2024 - Audition AP-HP	\N	2023-01-10 09:45:00	2023-01-10 10:30:00	\N	\N	1	0	\N	\N
688889	GIA	AUCUNE	\N	\N	\N	AG annuelle du GIA	AG annuelle du GIA	2023-01-11 11:30:00	2023-01-11 12:30:00	\N	\N	3	0	653	\N
688931	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2023-01-18 09:00:00	2023-01-18 12:00:00	\N	\N	43	2	\N	\N
689084	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL JOP 2024 - Audition DGT	\N	2023-01-10 14:00:00	2023-01-10 14:45:00	\N	\N	1	0	\N	\N
689085	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL JOP 2024 - Audition FCD-FECP	\N	2023-01-10 14:45:00	2023-01-10 15:45:00	\N	\N	1	0	\N	\N
690632	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Réunion GT subsidiarité du 12 janvier 2022	\N	2023-01-12 08:35:00	2023-01-12 08:50:00	\N	\N	3	0	\N	\N
690700	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Jeux Olympiques et Paralympiques de 2024 - Audition DGOS	\N	2023-01-11 16:30:00	2023-01-11 17:30:00	\N	\N	1	0	\N	\N
690706	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2023-01-25 09:35:00	2023-01-25 11:59:00	2023-01-25 16:25:54	2023-01-25 17:07:32	35	0	\N	\N
690710	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Communication - Enjeux PESC - Adhésion de l'UE à la CESDH	Communication - Enjeux PESC - Adhésion de l'UE à la CESDH	2023-01-18 16:40:00	2023-01-18 17:25:00	2023-01-20 15:35:17	2023-01-20 17:51:50	18	0	\N	\N
690712	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL JOP	\N	2023-01-10 17:00:00	2023-01-10 18:00:00	\N	\N	5	0	\N	\N
690709	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désignations -  PJL Jeux Olympiques et Paralympiques de 2024 (rapport)	Désignations -  PJL Jeux Olympiques et Paralympiques de 2024 (rapport)	2023-01-18 10:00:00	2023-01-18 11:55:00	2023-01-18 12:22:06	2023-01-19 11:52:40	47	4	\N	\N
690785	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes	\N	2023-01-18 16:40:00	2023-01-18 17:25:00	2023-01-20 11:30:38	2023-01-20 17:51:47	18	0	\N	\N
690786	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition Scénarios Financement CollTer et désignation Rapp PLFRSS pour 2023	Audition Scénarios Financement CollTer et désignation Rapp PLFRSS pour 2023	2023-01-18 10:35:00	2023-01-18 12:40:00	2023-01-18 16:11:10	2023-01-19 11:52:44	40	0	\N	\N
690787	COM_EURO	AUTRE	\N	AFEU	\N	Audition de S.E.M. Håkan Åkesson, Ambassadeur de Suède en France	\N	2023-01-18 13:30:00	2023-01-18 14:10:00	2023-01-18 14:39:19	2023-01-19 11:52:51	15	0	\N	\N
690792	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions M. Olivier Rietmann	\N	2023-01-10 15:30:00	2023-01-10 18:30:00	\N	\N	1	0	\N	\N
690865	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL ratios de soignants - Audition Internes picards	\N	2023-01-16 10:00:00	2023-01-16 11:00:00	\N	\N	3	0	\N	\N
690866	DELEGATION	AUDRAP	\N	\N	PROS	Audition Prospective espace	\N	2023-01-11 16:30:00	2023-01-11 19:30:00	\N	\N	2	0	\N	\N
690872	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Ratios de soignants - Audition DGOS 	\N	2023-01-16 11:00:00	2023-01-16 11:45:00	\N	\N	3	0	\N	\N
690879	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Ratios de spoignants - Audition de pdt de conférence CME et CHU	\N	2023-01-16 14:00:00	2023-01-16 14:45:00	\N	\N	4	0	\N	\N
690884	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition commune FHF et FEHAP	\N	2023-01-16 16:00:00	2023-01-16 16:45:00	\N	\N	2	0	\N	\N
690885	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition de l'ordre des sages-femmes et du syndicat national des sages-femmes	\N	2023-01-16 18:00:00	2023-01-16 18:45:00	\N	\N	3	0	\N	\N
690886	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Retraite de base des non-salariés agricoles - Audition commune DSS-MASA 	\N	2023-01-16 15:00:00	2023-01-16 16:30:00	\N	\N	1	0	\N	\N
690887	COM_PERMANENTE	AUTRE	\N	CAE	\N	PJL Nucléaire - amendements de séance	\N	2023-01-17 09:30:00	2023-01-17 09:55:00	\N	\N	31	1	\N	\N
639282	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Contrôle Ehpad - Audition défenseur des droits	\N	2022-03-15 15:30:00	2022-03-15 17:00:00	\N	\N	3	0	\N	\N
639308	MISSION	AUCUNE	\N	RECHINNO	\N	Auditions plénières	Auditions plénières	2022-03-15 15:15:00	2022-03-15 19:00:00	2022-03-16 15:21:07	2022-03-16 18:00:16	2	0	\N	\N
639316	DELEGATION	AUCUNE	\N	\N	211	Table ronde sur l'accès des mineurs aux contenus pormongraphiques et ses conséquences	Table ronde sur l'accès des mineurs aux contenus pormongraphiques et ses conséquences	2022-03-30 14:30:00	2022-03-30 16:50:00	\N	\N	9	0	\N	\N
639335	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Rapporteur CE EHpad - HAS	\N	2022-03-17 09:00:00	2022-03-17 10:30:00	\N	\N	4	0	\N	\N
639336	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rappporteur CE Ehpad - Dr Laruelle Coordonnateur Ehpad Public	\N	2022-03-17 14:00:00	2022-03-17 15:00:00	\N	\N	1	0	\N	\N
639337	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur CE Ehpad - FNMF	\N	2022-03-17 15:00:00	2022-03-17 16:00:00	\N	\N	2	0	\N	\N
639338	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Stage en immersion au tribunal judiciaire de Paris	Stage en immersion au tribunal judiciaire de Paris	2022-03-07 09:00:00	2022-03-08 16:00:00	\N	\N	2	0	\N	\N
639344	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	MCC Sécurisation chasse - Auditions	\N	2022-03-15 14:00:00	2022-03-15 19:00:00	\N	\N	0	0	\N	\N
639611	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI "Reconnaissance faciale"	MI "Reconnaissance faciale" - Auditions	2022-03-16 15:30:00	2022-03-16 17:00:00	\N	\N	3	0	\N	\N
641156	GIA	AUCUNE	\N	\N	\N	Réunion du 12 avril 2022	\N	2022-04-12 14:15:00	2022-04-12 14:45:00	\N	\N	4	0	603	\N
641175	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Question migratoire	MI Question migratoire	2022-04-11 18:30:00	2022-04-11 18:30:00	\N	\N	3	0	\N	\N
641182	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Question migratoire	MI Question migratoire	2022-04-12 10:30:00	2022-04-12 11:30:00	\N	\N	3	0	\N	\N
642252	COM_PERMANENTE	AUTRE	\N	CAE	\N	Application des lois	\N	2022-05-11 09:30:00	2022-05-11 10:35:00	2022-05-11 10:45:28	2022-05-11 17:34:10	26	0	\N	\N
642259	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2022- Dotations d'investissement aux CT - Déplacement Toulouse et Carcassonne	Contrôle 2022- Dotations d'investissement aux CT - Déplacement Toulouse et Carcassonne	2022-04-26 08:30:00	2022-04-27 20:30:00	\N	\N	2	0	\N	\N
642402	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de l'Ambassadeur de France en Ukraine	\N	2022-05-10 15:00:00	2022-05-10 16:10:00	\N	\N	25	0	\N	\N
642406	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions MI Énegie et hydrogènes nucléaires	Auditions MI Énegie et hydrogènes nucléaires	2022-05-09 09:00:00	2022-05-09 11:15:00	\N	\N	3	0	\N	\N
646413	GIA	AUCUNE	\N	\N	\N	Réunion 246e anniversaire de l'indépenadance américaine	\N	2022-07-05 18:30:00	2022-07-05 19:30:00	\N	\N	18	0	590	\N
648011	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GS Egalim - Intermarché	GS Egalim - Intermarché	2022-07-12 09:00:00	2022-07-12 10:15:00	\N	\N	8	0	\N	\N
664993	COM_PERMANENTE	AUTRE	\N	ETRD	\N	PLF 2023 - Auditions de Mme Anne-Marie Descôte Amiral Pierre Vandier	\N	2022-10-26 09:45:00	2022-10-26 12:30:00	2022-10-26 14:38:55	2022-10-26 15:10:29	41	3	\N	\N
686440	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2022-12-08 09:00:00	2022-12-08 12:30:00	\N	\N	6	0	\N	\N
712217	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle budgétaire CESE - Table ronde universitaires	Contrôle budgétaire CESE - Table ronde universitaires	2023-03-01 13:30:00	2023-03-01 15:00:00	\N	\N	1	0	\N	\N
712245	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Revaloriser le statut secrétaire de mairie	PPL Revaloriser le satut de secrétaire de mairie	2023-03-09 09:30:00	2023-03-09 10:30:00	\N	\N	2	0	\N	\N
712248	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Déplacement Semaine Parlementaire Européenne Bruxelles	Déplacement Semaine Parlementaire Européenne Bruxelles	2023-02-27 09:00:00	2023-02-28 14:30:00	\N	\N	2	0	\N	\N
712261	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Déplacement Centrale nucléaire Golfech	Déplacement Centrale nucléaire Golfech	2023-02-10 08:00:00	2023-02-10 22:00:00	\N	\N	1	0	\N	\N
712272	MISSION	AUCUNE	\N	AVENCOMM	\N	Table ronde de représentants d'associations de maires	Table ronde de représentants d'associations de maires	2023-03-14 08:35:00	2023-03-14 10:15:00	2023-03-14 11:28:51	2023-03-16 14:05:02	11	0	\N	\N
712542	COM_SPECIALE	AUDRAP	\N	CINC	\N	TR Agricole	TR Agricole	2023-03-10 10:00:00	2023-03-10 11:00:00	\N	\N	5	0	\N	\N
712549	COM_SPECIALE	AUDRAP	\N	CINC	\N	Conseil général de l'environnement et du développement durable	Conseil général de l'environnement et du développement durable	2023-03-10 11:00:00	2023-03-10 12:00:00	\N	\N	5	0	\N	\N
715374	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2023-03-14 14:15:00	2023-03-14 15:00:00	\N	\N	2	0	\N	\N
664990	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Examen PJL Centre spatial guyanais et PJL plateforme douanière A35	\N	2022-10-26 09:30:00	2022-10-26 09:45:00	2022-10-26 14:38:12	2022-10-26 15:10:31	41	2	\N	\N
722845	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Permis de conduire	Proposition de loi visant à faciliter le passage et l'obtention de l'examen du permis de conduire	2023-04-11 10:00:00	2023-04-11 10:40:00	\N	\N	1	0	\N	\N
729299	GIA	AUCUNE	\N	\N	\N	Rencontre avec une délégation de députés du Brésil	Rencontre avec une délégation de députés du Brésil	2023-05-05 14:30:00	2023-05-05 16:00:00	\N	\N	3	0	576	\N
734375	MISSION	AUCUNE	\N	GEAU	\N	INRAE	\N	2023-05-24 14:00:00	2023-05-24 15:00:00	2023-05-24 14:57:45	2023-05-24 17:25:41	9	0	\N	\N
734443	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	honorabilite	\N	2023-05-24 14:00:00	2023-05-24 15:00:00	\N	\N	2	0	\N	\N
734694	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Données de santé - Table ronde Cancer	\N	2023-05-23 16:30:00	2023-05-23 18:00:00	\N	\N	7	0	\N	\N
734696	ETUDES	AUTRE	\N	\N	\N	Réunion plénière	\N	2023-05-23 16:30:00	2023-05-23 18:00:00	\N	\N	5	0	\N	1004
735001	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Fin de vie - Audition de M. Jean Leonetti	\N	2023-05-24 13:30:00	2023-05-24 15:00:00	\N	\N	10	0	\N	\N
735072	ETUDES	AUTRE	\N	\N	\N	Audition de M. Cédric Vial	\N	2023-05-24 14:00:00	2023-05-24 15:00:00	\N	\N	8	0	\N	1014
735114	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	patrimoine écologique	\N	2023-05-24 16:30:00	2023-05-24 17:30:00	\N	\N	1	0	\N	\N
735148	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Audition de M. Xavier Gidrol	\N	2023-05-24 13:45:00	2023-05-24 15:00:00	\N	\N	0	0	\N	\N
735159	ETUDES	AUCUNE	\N	\N	\N	Audition de M. Xavier Gidrol (CEA/Inserm)	Audition de M. Xavier Gidrol (CEA/Inserm)	2023-05-24 13:45:00	2023-05-24 15:00:00	\N	\N	3	0	\N	1011
735516	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Audiovisuel public	LFP	2023-05-25 16:30:00	2023-05-25 17:30:00	\N	\N	5	0	\N	\N
735522	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Audiovisuel public	SPECT	2023-05-25 17:30:00	2023-05-25 18:30:00	\N	\N	4	0	\N	\N
735527	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Audiovisuel public	AFNUM	2023-05-25 18:30:00	2023-05-25 19:30:00	\N	\N	2	0	\N	\N
735554	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Registre national des cancers - Audition de la DGS	\N	2023-05-25 10:00:00	2023-05-25 11:00:00	\N	\N	2	0	\N	\N
735555	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Registre national des cancers - Audition de l'Académie de médecine	\N	2023-05-25 13:30:00	2023-05-25 15:00:00	\N	\N	2	0	\N	\N
735556	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Registre national des cancers - Audition du Dr Molinié, directrice du réseau Francim	\N	2023-05-26 09:30:00	2023-05-26 10:30:00	\N	\N	2	0	\N	\N
735557	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Registre national des cancers - Audition du Pr Launoy	\N	2023-05-26 10:30:00	2023-05-26 11:15:00	\N	\N	2	0	\N	\N
735566	COM_PERMANENTE	DEPLACEMENT	\N	SOCI	\N	MI Application des lois Protection de l'enfance - Déplacement en Eure-et-Loir	\N	2023-05-23 09:00:00	2023-05-23 18:00:00	\N	\N	2	0	\N	\N
735570	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Auditions P212	\N	2023-05-24 14:00:00	2023-05-24 15:00:00	\N	\N	0	0	\N	\N
735571	DELEGATION	AUDRAP	\N	\N	206	Audition Recyclage du plastique	\N	2023-05-25 13:30:00	2023-05-25 16:30:00	\N	\N	2	0	\N	\N
735574	ETUDES	DEPLACEMENT	\N	\N	\N	Déplacement au Mémorial du Mont-Valérien	\N	2023-05-23 16:00:00	2023-05-23 19:30:00	\N	\N	9	0	\N	928
735595	SEANCE_PLENIERE	SCRUSOL	1861	\N	\N	Scrutin solennel PJL Douane	Scrutin solennel PJL Douane	2023-05-30 15:30:00	2023-05-30 15:35:00	\N	\N	0	0	\N	\N
735596	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	1861	\N	\N	Explications de vote PJL Douane	Explications de vote PJL Douane	2023-05-30 14:30:00	2023-05-30 15:30:00	\N	\N	286	0	\N	\N
735632	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	NRJ Groupe	\N	2023-05-30 08:30:00	2023-05-30 09:30:00	\N	\N	2	0	\N	\N
735633	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Orange	\N	2023-05-30 09:30:00	2023-05-30 10:30:00	\N	\N	1	0	\N	\N
687523	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	GT Décentralisation 	Décentralisation - groupe de travail	2022-12-13 16:10:00	2022-12-13 19:20:00	\N	\N	3	0	\N	\N
687543	ETUDES	AUCUNE	\N	\N	\N	UNUCR	UNUCR	2022-12-14 08:00:00	2022-12-14 09:30:00	\N	\N	18	0	\N	907
695007	GIA	AUCUNE	\N	\N	\N	Audition de S. Exc. M. Rolando RUIZ ROSAS, ambassadeur du Pérou	Audition de S. Exc. M. Rolando RUIZ ROSAS, ambassadeur du Pérou	2023-01-24 18:00:00	2023-01-24 19:15:00	\N	\N	6	0	979	\N
695554	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Suite PPL occupation illicite	Suite PPL occupation illicite	2023-02-02 16:05:00	2023-02-02 19:15:00	\N	\N	41	0	\N	\N
696042	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Protection des épargnants	\N	2023-01-31 21:30:00	2023-01-31 22:00:00	\N	\N	45	0	\N	\N
699652	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL fraudes artistiques	\N	2023-02-07 17:30:00	2023-02-07 18:45:00	\N	\N	2	0	\N	\N
711794	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne	2023-03-08 16:30:00	2023-03-08 18:00:00	2023-03-09 16:17:41	2023-03-10 17:32:18	6	0	\N	\N
714413	CONF_PRES	AUCUNE	\N	\N	\N	Réunion de la Conférence des Présidents	Réunion de la Conférence des Présidents	2023-03-08 12:00:00	2023-03-08 12:45:00	\N	\N	28	0	\N	\N
715223	MISSION	AUCUNE	\N	GEAU	\N	Audition de Jean Launay, président du CNE	\N	2023-03-16 11:00:00	2023-03-16 12:00:00	2023-03-16 12:07:20	2023-03-16 14:04:59	4	0	\N	\N
715224	COM_ENQUETE	PLENIERE	\N	MEDIC	\N	Réunion plénière	\N	2023-03-21 09:05:00	2023-03-21 10:45:00	2023-03-23 10:38:22	2023-03-24 10:36:22	8	0	\N	\N
715963	MISSION	AUCUNE	\N	BATI	\N	audition MIBS	\N	2023-03-22 13:30:00	2023-03-22 15:00:00	2023-03-22 16:21:00	2023-03-22 17:51:17	10	0	\N	\N
715973	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI cinéma	\N	2023-03-14 17:00:00	2023-03-14 18:00:00	\N	\N	2	0	\N	\N
715977	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI cinéma	\N	2023-03-15 14:00:00	2023-03-15 15:00:00	\N	\N	3	0	\N	\N
715981	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI cinéma	\N	2023-03-15 17:00:00	2023-03-15 18:30:00	\N	\N	2	0	\N	\N
716222	GIA	AUCUNE	\N	\N	\N	Dîner avec le Sénateur polonais Aleksander Pociej	Dîner avec le Sénateur polonais Aleksander Pociej	2023-03-15 20:00:00	2023-03-15 22:45:00	\N	\N	7	0	600	\N
716261	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI LPM programme 144	MI LPM programme 144	2023-03-14 14:10:00	2023-03-14 15:10:00	\N	\N	3	0	\N	\N
716422	BUREAU	AUCUNE	\N	\N	\N	Réunion du Bureau	Réunion du Bureau	2023-03-16 08:05:00	2023-03-16 12:50:00	\N	\N	21	0	\N	\N
717516	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Sciences-Po Paris	\N	2023-03-21 14:30:00	2023-03-21 15:40:00	\N	\N	2	0	\N	\N
717517	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Groupe INSA	\N	2023-03-21 15:30:00	2023-03-21 16:15:00	\N	\N	2	0	\N	\N
717518	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Sociologue, Mme Van Zanten	\N	2023-03-21 16:30:00	2023-03-21 17:00:00	\N	\N	2	0	\N	\N
717526	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2023-03-29 08:52:00	2023-03-29 12:45:00	\N	\N	35	0	\N	\N
717527	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition M. Matthieu Creux, Avisa Partners	\N	2023-03-21 14:30:00	2023-03-21 15:30:00	\N	\N	4	0	\N	\N
717532	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition M. Eric Léandri, Qwant et Alternativ	Audition M. Eric Léandri, Qwant et Alternativ	2023-03-21 16:30:00	2023-03-21 17:15:00	\N	\N	4	0	\N	\N
717002	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2023-03-15 09:45:00	2023-03-15 11:00:00	2023-03-21 15:55:47	2023-03-21 15:57:03	41	0	\N	\N
717533	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Mme Juliette Montero-Lopez	\N	2023-03-21 15:30:00	2023-03-21 16:30:00	\N	\N	4	0	\N	\N
717542	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Général Benoît Durieux	Général Benoît Durieux	2023-03-21 17:15:00	2023-03-21 18:00:00	\N	\N	4	0	\N	\N
717547	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition de M. Bernard Carayon, avocat	Audition de M. Bernard Carayon, avocat	2023-03-21 18:00:00	2023-03-21 19:00:00	\N	\N	3	0	\N	\N
717551	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLC  loi de financement des collectivités territoriales 	PPLC  loi de financement des collectivités territoriales	2023-03-21 14:40:00	2023-03-21 15:30:00	\N	\N	1	0	\N	\N
717667	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE 17 bis	\N	2023-03-22 09:40:00	2023-03-22 11:00:00	2023-03-22 13:58:27	2023-03-22 15:24:38	29	0	\N	\N
717722	MISSION	AUCUNE	\N	GEAU	\N	Audition plénière de l'AMF	\N	2023-03-28 14:40:00	2023-03-28 15:40:00	2023-03-28 16:35:27	2023-03-29 17:19:02	5	0	\N	\N
717742	MISSION	AUDRAP	\N	GEAU	\N	Audition de l'ONG Green Cross France & Territoires	\N	2023-03-29 17:35:00	2023-03-29 18:55:00	\N	\N	5	0	\N	\N
717743	MISSION	AUDRAP	\N	GEAU	\N	Audition de l'association AMORCE 	\N	2023-03-29 16:35:00	2023-03-29 17:35:00	\N	\N	5	0	\N	\N
717744	MISSION	AUCUNE	\N	GEAU	\N	Fédération nationale de la pêche en France 	\N	2023-03-29 14:00:00	2023-03-29 15:00:00	2023-03-29 18:13:08	2023-03-30 11:54:17	7	0	\N	\N
718325	MISSION	AUCUNE	\N	BIOCARBU	\N	MI BIOCARBURANTS - 7	\N	2023-03-28 17:00:00	2023-03-28 18:40:00	2023-04-12 16:19:54	\N	10	0	\N	\N
718340	MISSION	AUCUNE	\N	BIOCARBU	\N	MI BIOCARBURANTS - 6	\N	2023-03-22 17:00:00	2023-03-22 18:55:00	2023-03-22 19:37:18	2023-03-24 10:36:23	6	0	\N	\N
718352	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI cinéma	\N	2023-03-22 14:00:00	2023-03-22 15:00:00	\N	\N	3	0	\N	\N
718357	MISSION	AUDRAP	\N	BATI	\N	bati scolaire	\N	2023-03-21 17:30:00	2023-03-21 19:00:00	\N	\N	3	0	\N	\N
718623	COM_ENQUETE	PLENIERE	\N	TIKTO	\N	Audition de M. Julien Nocetti	\N	2023-03-27 15:10:00	2023-03-27 16:30:00	2023-03-28 16:47:44	2023-03-29 17:19:00	8	0	\N	\N
718668	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de Mmes Michèle Ramis et Myriam Fillaud	Audition de Mmes Michèle Ramis et Myriam Fillaud	2023-03-29 09:30:00	2023-03-29 11:50:00	\N	\N	30	0	\N	\N
718748	GIA	AUCUNE	\N	\N	\N	Entretien avec S.E. M. Matti ANTTONEN, ambassadeur de Finlande en France	Entretien avec S.E. M. Matti ANTTONEN, ambassadeur de Finlande en France	2023-03-22 08:15:00	2023-03-22 09:45:00	\N	\N	5	0	640	\N
718754	GIA	AUCUNE	\N	\N	\N	Entretien avec une délégation de députés du Grand Khoural de Mongolie	Entretien avec une délégation de députés du Grand Khoural de Mongolie conduite par M. Jadamba BAT-ERDENE  	2023-03-08 19:30:00	2023-03-08 21:00:00	\N	\N	3	0	612	\N
718759	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Français de l'étranger	MI Français de l'étranger	2023-03-27 10:30:00	2023-03-27 12:30:00	\N	\N	2	0	\N	\N
718762	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Défenseur des Droits	\N	2023-03-27 10:00:00	2023-03-27 11:30:00	\N	\N	2	0	\N	\N
718763	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	AMF	\N	2023-03-27 11:30:00	2023-03-27 12:30:00	\N	\N	2	0	\N	\N
718768	COM_ENQUETE	PLENIERE	\N	RENOV	\N	Auditions plénières	\N	2023-03-27 15:00:00	2023-03-27 19:45:00	2023-03-27 19:43:28	2023-03-29 17:19:00	6	0	\N	\N
718769	COM_PERMANENTE	AUTRE	\N	CAE	\N	Examen du rapport Blaireaux	\N	2023-03-29 09:30:00	2023-03-29 10:50:00	2023-03-29 12:36:37	2023-03-29 17:17:28	35	3	\N	\N
718788	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	ppl école de la liberté	\N	2023-03-27 14:30:00	2023-03-27 15:30:00	\N	\N	6	0	\N	\N
718795	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL école de la liberté	\N	2023-03-27 15:30:00	2023-03-27 16:30:00	\N	\N	4	0	\N	\N
718801	GIA	AUCUNE	\N	\N	\N	Accueil de SEM Jan Versteeg, ambassadeur des Pays-Bas en France	Accueil de SEM Jan Versteeg, ambassadeur des Pays-Bas en France	2023-03-21 12:30:00	2023-03-21 14:00:00	\N	\N	7	0	599	\N
718809	GIA	AUCUNE	\N	\N	\N	Accueil de M. François Alabrune, Ambassadeur de France aux Pays-Bas	Accueil de M. François Alabrune, Ambassadeur de France aux Pays-Bas	2023-03-30 12:30:00	2023-03-30 14:00:00	\N	\N	0	0	599	\N
718817	DELEGATION	AUDRAP	\N	\N	206	Audition recyclage du plastique	\N	2023-03-23 13:45:00	2023-03-23 18:00:00	\N	\N	2	0	\N	\N
718882	QUESTURE	AUCUNE	\N	\N	\N	Réunion de Questure	Réunion de Questur	2023-03-23 09:00:00	2023-03-23 10:07:00	\N	\N	3	0	\N	\N
718942	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI  Brésil	MI Brésil	2023-03-23 09:30:00	2023-03-23 11:30:00	\N	\N	5	0	\N	\N
719056	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PPL Convivialité en milieu rural	Audition PPL Convivialité en milieu rural	2023-03-28 14:00:00	2023-03-28 16:00:00	\N	\N	1	0	\N	\N
719351	MISSION	AUDRAP	\N	BIOCARBU	\N	Cour des comptes	\N	2023-03-16 14:30:00	2023-03-16 15:30:00	\N	\N	5	0	\N	\N
719367	MISSION	AUDRAP	\N	BIOCARBU	\N	IGEDD / CGE	IGEDD / CGE	2023-03-16 15:30:00	2023-03-16 16:30:00	\N	\N	4	0	\N	\N
719380	MISSION	AUDRAP	\N	BIOCARBU	\N	DG Trésor	DG Trésor	2023-03-21 09:30:00	2023-03-21 10:45:00	\N	\N	1	0	\N	\N
638006	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	MCC Sécurisation de la chasse-Déplacement dans les Yvelines	MCC Sécurisation de la chasse - Déplacement à Marly-leRoy - Rencontre avec des représentants de la FICIF	2022-02-22 11:00:00	2022-02-22 18:00:00	\N	\N	7	0	\N	\N
638014	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de M. Martin Briens	\N	2022-03-01 12:00:00	2022-03-01 13:25:00	2022-03-01 14:44:39	2022-03-02 10:21:59	29	0	\N	\N
638022	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Conférence interparlementaire PESC-PSDC	Conférence interparlementaire PESC-PSDC	2022-02-24 17:00:00	2022-02-24 21:00:00	\N	\N	4	0	\N	\N
638485	GIA	AUCUNE	\N	\N	\N	Réunion du groupe d'amitié France-Pologne	Réunion du groupe d'amitié France-Pologne	2022-03-02 10:00:00	2022-03-02 11:00:00	\N	\N	4	0	600	\N
638638	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	Coopé - Entretien avec Mme Anja MAGER	Coopé - Entretien avec Mme Anja MAGER	2022-02-28 15:00:00	2022-02-28 16:00:00	\N	\N	1	0	\N	\N
638640	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	Coopé - Entretien avec Mme Anja MAGER	Coopé - Entretien avec Mme Anja MAGER	2022-02-28 15:00:00	2022-02-28 16:00:00	\N	\N	1	0	\N	\N
640835	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	MCC Sécurisation de la chasse	MCC Sécurisation de la chasse	2022-03-29 14:00:00	2022-03-29 17:00:00	\N	\N	8	0	\N	\N
640844	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	MCC	MCC Sécurisation de la chasse	2022-03-29 18:00:00	2022-03-29 19:00:00	\N	\N	8	0	\N	\N
640858	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	MCC	MCC Sécurisation de la chasse	2022-04-05 10:00:00	2022-04-05 12:30:00	\N	\N	5	0	\N	\N
717725	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2023-03-29 11:00:00	2023-03-29 11:45:00	2023-04-03 09:56:48	2023-04-03 18:13:37	43	3	\N	\N
719055	COM_PERMANENTE	AUTRE	\N	FINC	\N	PPL 341 -PPLC 869 - PPL 843	PPL 341 -PPLC 869 - PPL 843	2023-03-29 09:05:00	2023-03-29 11:30:00	2023-03-29 15:29:18	2023-03-29 17:17:28	44	6	\N	\N
640864	MISSION	AUCUNE	\N	FONDSMER	\N	Auditions Mme KRAJKA + UICN	Audition Mme KRAJKA + UICN	2022-04-05 17:00:00	2022-04-05 19:30:00	2022-04-05 19:31:10	2022-04-07 18:03:14	6	0	\N	\N
642162	ETUDES	AUCUNE	\N	\N	\N	déplacement Gard	déplacement Gard	2022-04-27 16:00:00	2022-04-29 21:00:00	\N	\N	8	0	\N	1007
642177	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de l'ambassadeur de France en Ukraine	\N	2022-05-10 15:00:00	2022-05-10 16:10:00	2022-05-10 16:38:59	2022-05-11 17:34:07	25	0	\N	\N
655711	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2020 - La DCPJ - Déplacement à Rennes	Contrôle 2020 - La DCPJ - Déplacement à Rennes	2022-09-19 07:30:00	2022-09-19 20:10:00	\N	\N	1	0	\N	\N
655713	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - ONACVG - Secrétaire d'État MIDARM	Contrôle 2022 - ONACVG - Secrétaire d'État MIDARM	2022-09-19 17:30:00	2022-09-19 19:00:00	\N	\N	1	0	\N	\N
655715	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF Enssco	\N	2022-09-20 09:00:00	2022-09-20 11:00:00	\N	\N	6	0	\N	\N
655733	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière	\N	2022-09-20 14:30:00	2022-09-20 16:00:00	\N	\N	7	0	\N	\N
655734	DELEGATION	AUTRE	\N	\N	ENTREPRISES	Réunion plénière	\N	2022-09-20 16:15:00	2022-09-20 18:00:00	2022-09-21 15:04:42	\N	5	0	\N	\N
655742	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition de M. Benoit Coeuré	\N	2022-09-27 17:30:00	2022-09-27 19:15:00	2022-09-28 14:17:26	2022-09-28 16:49:39	16	0	\N	\N
655749	DELEGATION	AUDRAP	\N	\N	PROS	Audition Amorce	\N	2022-09-20 14:00:00	2022-09-20 15:00:00	\N	\N	2	0	\N	\N
655752	DELEGATION	AUDRAP	\N	\N	PROS	Audition France Urbaine	\N	2022-09-20 15:00:00	2022-09-20 15:45:00	\N	\N	3	0	\N	\N
655756	DELEGATION	AUDRAP	\N	\N	PROS	Audition Intercommunalités de France	\N	2022-09-20 15:45:00	2022-09-20 16:30:00	\N	\N	3	0	\N	\N
655764	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Faire évoluer la formation de sage-femme - Auditions rapporteure 	\N	2022-09-20 10:00:00	2022-09-20 12:30:00	\N	\N	1	0	\N	\N
655765	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Faire évoluer la formation de sage-femme - Auditions rapporteure 	\N	2022-09-20 14:30:00	2022-09-20 18:00:00	\N	\N	2	0	\N	\N
656949	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2023 presse	\N	2022-10-04 09:00:00	2022-10-04 10:00:00	\N	\N	2	0	\N	\N
657049	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Intervention des cabinets privés	PPL Intervention des cabinets privés	2022-10-04 10:00:00	2022-10-04 10:45:00	\N	\N	1	0	\N	\N
657403	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2023 - Équilibres financiers généraux - Audition DGDDI	\N	2022-10-04 14:00:00	2022-10-04 15:10:00	\N	\N	2	0	\N	\N
657404	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2023 - Équilibres financiers généraux - Audition CCMSA	\N	2022-10-04 15:10:00	2022-10-04 16:10:00	\N	\N	1	0	\N	\N
657417	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Rencontres avec les entrepreneurs	\N	2022-09-30 11:30:00	2022-09-30 12:30:00	\N	\N	0	0	\N	\N
657524	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition Olivia Grégoire	\N	2022-10-04 18:00:00	2022-10-04 19:55:00	2022-10-05 09:30:18	2022-10-05 17:35:03	40	0	\N	\N
657567	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière conjointe	\N	2022-10-04 18:00:00	2022-10-04 19:30:00	\N	\N	40	0	\N	\N
659399	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Présentation des capacités de l'Armée de terre	Présentation des capacités de l'Armée de terre	2022-10-06 08:30:00	2022-10-06 14:30:00	\N	\N	6	0	\N	\N
659965	GIA	AUCUNE	\N	\N	\N	Audition du général Thierry Marchand, nouvel ambassadeur de France au Cameroun	Audition du général Thierry Marchand, nouvel ambassadeur de France au Cameroun	2022-10-28 19:00:00	2022-10-28 19:45:00	\N	\N	1	0	572	\N
665253	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions Rapporteure	PLF 2023 - Sécurité civile	2022-10-19 16:45:00	2022-10-19 17:45:00	\N	\N	1	0	\N	\N
665254	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 27/10/22	\N	2022-10-27 08:30:00	2022-10-27 10:00:00	2022-10-27 10:20:14	2022-10-27 12:02:58	16	0	\N	\N
665255	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Travail & emploi - France compétences	PLF pour 2023 - Travail & emploi - France compétences	2022-10-21 09:30:00	2022-10-21 10:30:00	\N	\N	2	0	\N	\N
665259	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - TFP - DIE	PLF pour 2023 - TFP - DIE	2022-10-18 18:00:00	2022-10-18 19:10:00	\N	\N	2	0	\N	\N
665262	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur	PLF 2023 - Relations avec les collectivités territoriales	2022-10-20 08:05:00	2022-10-20 09:50:00	\N	\N	1	0	\N	\N
665263	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - TFP - Ministre TFP	PLF pour 2023 - TFP - Ministre TFP	2022-10-19 16:30:00	2022-10-19 17:30:00	\N	\N	2	0	\N	\N
665267	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions rapporteur	PLF 2023 - Relations avec les collectivités territoriales	2022-10-20 11:30:00	2022-10-20 12:50:00	\N	\N	1	0	\N	\N
665269	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 -  EFE - Deutsche Bank	PLF pour 2023 -  EFE - Deutsche Bank	2022-10-20 09:10:00	2022-10-20 10:20:00	\N	\N	1	0	\N	\N
665271	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - BACEA - UAF	PLF pour 2023 - BACEA - UAF	2022-10-20 15:30:00	2022-10-20 16:30:00	\N	\N	1	0	\N	\N
665272	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Céréma-IGN-Météo-France - DB	PLF pour 2023 - Céréma-IGN-Météo-France - DB	2022-10-20 16:30:00	2022-10-20 17:50:00	\N	\N	1	0	\N	\N
665275	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Recherche - DGRI	PLF pour 2023 - Recherche - DGRI	2022-10-20 11:30:00	2022-10-20 12:30:00	\N	\N	1	0	\N	\N
665280	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Enseignement scolaire - CEE	PLF pour 2023 - Enseignement scolaire - CEE	2022-10-20 15:00:00	2022-10-20 16:00:00	\N	\N	1	0	\N	\N
665282	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Recherche - CEA	PLF pour 2023 - Recherche - CEA	2022-10-20 17:00:00	2022-10-20 18:00:00	\N	\N	1	0	\N	\N
665284	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Outre-mer - DGOM et CAB MIN	PLF pour 2023 - Outre-mer - DGOM et CAB MIN	2022-10-18 17:00:00	2022-10-18 19:00:00	\N	\N	2	0	\N	\N
665287	DELEGATION	AUCUNE	\N	\N	206	Audition publique corrosions dans les centrales nucléaires	\N	2022-10-27 10:35:00	2022-10-27 13:00:00	\N	\N	12	0	\N	\N
665290	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Outre-mer - FEDOM et USHOM	PLF pour 2023 - Outre-mer - FEDOM et USHOM	2022-10-20 09:00:00	2022-10-20 10:30:00	\N	\N	2	0	\N	\N
665294	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Écologie - DGALN	PLF pour 2023 - Écologie - DGALN	2022-10-17 15:15:00	2022-10-17 16:15:00	\N	\N	1	0	\N	\N
665296	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Mission Flash 2022 - Dons associations - DACG	Mission Flash 2022 - Dons associations - DACG	2022-10-19 17:15:00	2022-10-19 18:00:00	\N	\N	2	0	\N	\N
665299	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Pouvoirs publics - Questeur Sénat	PLF pour 2023 - Pouvoirs publics - Questeur Sénat	2022-10-19 14:30:00	2022-10-19 15:00:00	\N	\N	1	0	\N	\N
665301	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2023 - Pouvoirs publics - Déplacement PR	PLF pour 2023 - Pouvoirs publics - Déplacement PR	2022-10-19 15:40:00	2022-10-19 17:20:00	\N	\N	1	0	\N	\N
690893	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition président de CME CH	\N	2023-01-17 15:30:00	2023-01-17 16:15:00	\N	\N	4	0	\N	\N
691148	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Enquête 58-2 - Nucléaire - DG ASN	Enquête 58-2 - Nucléaire - DG ASN	2023-01-09 10:00:00	2023-01-09 11:00:00	\N	\N	1	0	\N	\N
645655	COM_PERMANENTE	AUDRAP	\N	CAE	\N	ANCT	ANCT	2022-05-17 14:30:00	2022-05-17 16:00:00	\N	\N	3	0	\N	\N
691184	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	Remise du rapport annuel au Président de la République	Remise du rapport annuel au Président de la République	2023-01-13 17:30:00	2023-01-13 18:30:00	\N	\N	4	0	\N	\N
691189	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Retraite de base des non-salariés agricoles - Audition de Y-G. Amghar 	\N	2023-01-17 09:00:00	2023-01-17 10:00:00	\N	\N	1	0	\N	\N
691190	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL Protection des épargnants - Cab MinEco/DG Trésor/FFA/Orias	PPL Protection des épargnants - Cab MinEco/DG Trésor/FFA/Orias	2023-01-09 09:00:00	2023-01-09 12:15:00	\N	\N	2	0	\N	\N
691205	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Protection sociale des non-salariés agricoles - Table ronde syndicats agricoles 	\N	2023-01-17 13:00:00	2023-01-17 14:30:00	\N	\N	3	0	\N	\N
691220	DELEGATION	AUCUNE	\N	\N	PROS	Audition de M. Jacques Attali sur son ouvrage "Histoires et avenirs de l'éducation"	\N	2023-01-26 08:30:00	2023-01-26 09:25:00	\N	\N	7	0	\N	\N
691237	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Table ronde réalisateurs	\N	2023-01-17 14:00:00	2023-01-17 15:30:00	\N	\N	4	0	\N	\N
691242	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Table ronde distributeurs	\N	2023-01-17 16:30:00	2023-01-17 18:00:00	\N	\N	4	0	\N	\N
691462	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Ratios de soignants - Audition syndicat infirmier hospitalier	\N	2023-01-17 16:30:00	2023-01-17 17:15:00	\N	\N	3	0	\N	\N
691502	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition Mme Véronique Bédague	\N	2023-01-18 09:30:00	2023-01-18 11:05:00	2023-01-18 11:08:45	2023-01-19 11:52:37	44	0	\N	\N
691570	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions M. Olivier Rietmann	\N	2023-01-17 14:00:00	2023-01-17 20:00:00	\N	\N	1	0	\N	\N
691611	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition ARCOM	\N	2023-01-25 08:30:00	2023-01-25 10:00:00	2023-01-26 16:37:10	2023-01-26 17:51:35	27	8	\N	\N
691635	COM_PERMANENTE	AUTRE	\N	AFCL	\N	TR DAB+	\N	2023-01-25 10:00:00	2023-01-25 11:55:00	2023-01-26 16:38:05	2023-01-26 17:51:34	35	7	\N	\N
691670	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition INSERM	\N	2023-01-26 10:30:00	2023-01-26 11:50:00	2023-01-26 16:39:27	2023-01-26 17:51:32	17	0	\N	\N
691842	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL ratios de soignants - Audition AP-HP	\N	2023-01-20 14:00:00	2023-01-20 14:45:00	\N	\N	1	0	\N	\N
691860	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition PPL Ratios de soignants	\N	2023-01-18 10:30:00	2023-01-18 11:30:00	\N	\N	1	0	\N	\N
691861	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL Protection des épargnants - CCSF/ACPR/Faider	PPL Protection des épargnants - CCSF/ACPR/Faider	2023-01-09 14:00:00	2023-01-09 16:15:00	\N	\N	2	0	\N	\N
692177	COM_PERMANENTE	DEPLACEMENT	\N	AFCL	\N	Mobilier National	\N	2023-01-11 09:00:00	2023-01-11 11:45:00	\N	\N	22	0	\N	\N
692238	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Communication PPRE	\N	2023-01-18 16:40:00	2023-01-18 17:25:00	\N	\N	0	0	\N	\N
692239	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Mme Loisier	Auditions Sécuriser l'approvisionnement en produits de grande consommation	2023-01-17 17:00:00	2023-01-17 18:45:00	\N	\N	1	0	\N	\N
692240	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Sécuriser l'approvisionnement en produits de grande consommation	Auditions Sécuriser l'approvisionnement en produits de grande consommation	2023-01-17 14:00:00	2023-01-17 16:45:00	\N	\N	1	0	\N	\N
692262	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Ratios soignants	\N	2023-01-18 11:15:00	2023-01-18 12:00:00	\N	\N	1	0	\N	\N
692272	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Groupe de travail Décentralisation	Décentralisation - auditions rapporteurs	2023-01-17 17:40:00	2023-01-17 18:45:00	\N	\N	6	0	\N	\N
692279	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes	\N	2023-01-19 09:00:00	2023-01-19 10:15:00	2023-01-19 11:27:43	2023-01-19 11:52:53	6	0	\N	\N
692291	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL Protection des épargnants - Association française de la gestion financière (AFG)	PPL Protection des épargnants - Association française de la gestion financière (AFG)	2023-01-11 14:00:00	2023-01-11 14:45:00	\N	\N	2	0	\N	\N
692297	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL Protection des épargnants - AMF	\N	2023-01-11 19:30:00	2023-01-11 21:00:00	\N	\N	2	0	\N	\N
692300	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL Protection des épargnants - Anacofi	PPL Protection des épargnants - Anacofi	2023-01-12 15:30:00	2023-01-12 16:10:00	\N	\N	2	0	\N	\N
692303	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL Protection des épargnants - France Invest/AGEA	PPL Protection des épargnants - France Invest/AGEA	2023-01-17 14:30:00	2023-01-17 16:00:00	\N	\N	2	0	\N	\N
692306	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL Protection des épargnants - France Assureurs	\N	2023-01-17 18:30:00	2023-01-17 19:05:00	\N	\N	1	0	\N	\N
692308	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL Politique du logement - DGCL / MM. DANTEC et BREUILLER	PPL Politique du logement - DGCL / MM. DANTEC et BREUILLER	2023-01-17 16:30:00	2023-01-17 18:30:00	\N	\N	3	0	\N	\N
692312	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Enquête 58-2 - Nucléaire - IRSN/Parc Nucléaire et Thermique	Enquête 58-2 - Nucléaire - IRSN/Parc Nucléaire et Thermique	2023-01-16 10:00:00	2023-01-16 12:00:00	\N	\N	1	0	\N	\N
692314	COM_PERMANENTE	AUDRAP	\N	FINC	\N	contrôle 2022 - RGA M. KRON/M. ADAM	contrôle 2022 - RGA M. KRON/M. ADAM	2023-01-17 09:00:00	2023-01-17 11:00:00	\N	\N	0	0	\N	\N
692316	DELEGATION	AUTRE	\N	\N	DSOM	Continuité territoriale outre-mer : océan Indien	\N	2023-01-26 08:30:00	2023-01-26 10:30:00	\N	\N	9	0	\N	\N
692318	COM_PERMANENTE	AUTRE	\N	AFCL	\N	PJL JOP	\N	2023-01-24 09:00:00	2023-01-24 09:20:00	2023-01-26 16:36:21	2023-01-26 17:51:35	22	7	\N	\N
692319	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Jeux Olympiques et Paralympiques de 2024 (amendements)	PJL Jeux Olympiques et Paralympiques de 2024 (amendements)	2023-01-24 09:30:00	2023-01-24 09:45:00	2023-01-24 10:34:38	2023-01-25 16:23:03	11	0	\N	\N
692325	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions M. Olivier Rietmann	\N	2023-01-19 15:45:00	2023-01-19 16:30:00	\N	\N	3	0	\N	\N
692329	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI cinéma	\N	2023-01-18 16:30:00	2023-01-18 18:30:00	\N	\N	3	0	\N	\N
692333	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Données de santé - Audition de la DNS	\N	2023-01-17 14:30:00	2023-01-17 15:45:00	\N	\N	7	0	\N	\N
692334	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Données de santé - Audition du Health Data Hub	\N	2023-01-17 17:30:00	2023-01-17 18:45:00	\N	\N	4	0	\N	\N
692335	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Fin de vie - Table ronde de professionnels de soins palliatifs	\N	2023-01-17 15:45:00	2023-01-17 17:00:00	\N	\N	8	0	\N	\N
692356	ETUDES	AUDRAP	\N	\N	\N	Petit-déjeuner Tour de France 2023	\N	2023-01-18 08:00:00	2023-01-18 09:30:00	\N	\N	36	0	\N	934
692388	DELEGATION	AUCUNE	\N	\N	206	Adoption de notes scientifiques 	\N	2023-01-26 09:35:00	2023-01-26 11:55:00	\N	\N	15	0	\N	\N
692401	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition PPL Ratios de soignants - Organisations syndicales	\N	2023-01-20 14:45:00	2023-01-20 15:30:00	\N	\N	2	0	\N	\N
692321	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Protéger les logements  - PPL Droit fondamental à l'IVG (rapports)	PPL Protéger les logements  - PPL Droit fondamental à l'IVG (rapports)	2023-01-25 10:00:00	2023-01-25 12:00:00	2023-01-25 14:14:43	2023-01-25 16:22:51	39	6	\N	\N
692403	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition PPL ratios de soignants - CIH	\N	2023-01-20 16:30:00	2023-01-20 17:15:00	\N	\N	2	0	\N	\N
692409	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Ppl ratios de soignants audition de la HAS	\N	2023-01-20 17:15:00	2023-01-20 18:00:00	\N	\N	1	0	\N	\N
638595	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI France compétences -Audition de la FFB	\N	2022-03-08 09:50:00	2022-03-08 10:40:00	\N	\N	2	0	\N	\N
638598	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI France compétences - Audition de l'UIMM	\N	2022-03-08 10:40:00	2022-03-08 11:25:00	\N	\N	3	0	\N	\N
638602	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	MCC sécurisation de la chasse	MCC sécurisation de la chasse	2022-03-08 10:30:00	2022-03-08 12:50:00	\N	\N	6	0	\N	\N
641714	GIA	AUCUNE	\N	\N	\N	Visioconférence avec le Prof Vicente Vérez BENCOMO, directeur Institut Finlay des vaccins	Visioconférence avec le Prof Vicente Vérez BENCOMO, directeur Institut Finlay des vaccins	2022-03-15 09:00:00	2022-03-15 11:00:00	\N	\N	2	0	642	\N
641805	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur MI Ehpad - Mission permanente inspectin-contrôle de l'IGAS	\N	2022-05-11 10:30:00	2022-05-11 11:30:00	\N	\N	7	0	\N	\N
641806	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur MI Ehpad - Société Bastide	\N	2022-05-11 11:30:00	2022-05-11 12:30:00	\N	\N	5	0	\N	\N
641814	MECSS	AUDRAP	\N	\N	MECSS	MI Unification recouvrement - Audition du GIP MDS	\N	2022-04-26 14:00:00	2022-04-26 15:00:00	\N	\N	2	0	\N	\N
641815	MECSS	AUDRAP	\N	\N	MECSS	MI Unification du recouvrement - Audition Maison des artistes/AGESSA	\N	2022-04-26 15:00:00	2022-04-26 16:00:00	\N	\N	3	0	\N	\N
641816	MECSS	AUDRAP	\N	\N	MECSS	MI Unification du recouvrement - Audition de l'ERAFP	\N	2022-04-26 16:00:00	2022-04-26 16:45:00	\N	\N	3	0	\N	\N
641817	MECSS	AUDRAP	\N	\N	MECSS	MI Unification du recouvrement - Audition CIPAV	\N	2022-04-26 17:00:00	2022-04-26 18:10:00	\N	\N	4	0	\N	\N
641818	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière	\N	2022-05-10 15:30:00	2022-05-10 17:10:00	2022-05-11 09:39:36	2022-05-11 17:34:08	27	1	\N	\N
642038	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Auditions du DGA et de l'IFRI	\N	2022-05-04 09:30:00	2022-05-04 12:35:00	2022-05-04 14:30:58	2022-05-09 16:20:04	25	0	\N	\N
642066	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-05-10 16:15:00	2022-05-10 18:15:00	2022-05-10 18:21:56	2022-05-11 17:34:09	25	0	\N	\N
643650	DELEGATION	AUCUNE	\N	\N	211	Table ronde sur la régulation de l'accès aux contenus pornographiques en ligne	Table ronde sur la régulation de l'accès aux contenus pornographiques en ligne	2022-06-08 14:30:00	2022-06-08 16:25:00	\N	\N	11	0	\N	\N
643651	COM_PERMANENTE	AUTRE	\N	FINC	\N	Mission conjointe de contrôle sur le financement de l'audiovisuel public	Mission conjointe de contrôle sur le financement de l'audiovisuel public	2022-06-08 10:50:00	2022-06-08 12:05:00	2022-06-09 17:01:48	2022-06-09 17:34:52	46	2	\N	\N
643652	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-06-08 09:05:00	2022-06-08 11:30:00	2022-06-08 11:31:53	2022-06-08 14:57:32	20	0	\N	\N
643653	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-06-07 15:35:00	2022-06-07 18:20:00	2022-06-07 18:19:55	2022-06-07 19:44:32	28	0	\N	\N
643654	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Obésité - Table ronde Incidence des violences sexuelles	\N	2022-06-01 16:00:00	2022-06-01 17:15:00	\N	\N	3	0	\N	\N
643659	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2022- IGN - Déplacement Saint-Médard-en-Jalles	Contrôle 2022- IGN - Déplacement Saint-Médard-en-Jalles	2022-06-01 07:00:00	2022-06-01 20:00:00	\N	\N	1	0	\N	\N
643661	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	MCC 2022 - Audiovisuel Public - INA/Académie cinéma	\N	2022-06-02 09:30:00	2022-06-02 11:30:00	\N	\N	0	0	\N	\N
643665	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - OAT vertes - Finance for Tomorrow	Contrôle 2022 - OAT vertes - Finance for Tomorrow	2022-06-01 15:00:00	2022-06-01 16:10:00	\N	\N	1	0	\N	\N
643666	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - OAT vertes - Gestionnaire d'actifs	Contrôle 2022 - OAT vertes - Gestionnaire d'actifs	2022-06-01 17:00:00	2022-06-01 18:15:00	\N	\N	1	0	\N	\N
643669	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - Maisons France services - Associations d'Élus	Contrôle 2022 - Maisons France services - Associations d'Élus	2022-05-31 14:30:00	2022-05-31 16:00:00	\N	\N	1	0	\N	\N
643671	DELEGATION	AUDRAP	\N	\N	PROS	Audition M. Martin (IFRI)	\N	2022-05-30 16:00:00	2022-05-30 17:00:00	\N	\N	2	0	\N	\N
643674	ETUDES	AUTRE	\N	\N	\N	GEAC - Audition de M. Olivier ANDRIÈS, directeur général du groupe SAFRAN	GEAC - Audition de M. Olivier ANDRIÈS, directeur général du groupe SAFRAN	2022-06-28 09:00:00	2022-06-28 10:20:00	\N	\N	10	0	\N	933
643685	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions M. Fabien Gay, Mmes Françoise Férat et Florence Blatrix Contat	\N	2022-05-23 11:00:00	2022-05-23 12:00:00	\N	\N	0	0	\N	\N
643686	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Information du consommateur - Auditions FCD	MI Information du consommateur - Auditions FCD	2022-05-23 11:00:00	2022-05-23 12:00:00	\N	\N	3	0	\N	\N
643690	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Information du consommateur - Audi	MI Information du consommateur - Auditions M. Gay, Mmes Férat et Blatrix-Contat	2022-05-23 14:00:00	2022-05-23 18:15:00	\N	\N	4	0	\N	\N
643695	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Information du consommateur - Auditions M. Gay, Mmes Férat et Blatrix-Contat	MI Information du consommateur - Auditions M. Gay, Mmes Férat et Blatrix-Contat	2022-05-24 14:00:00	2022-05-24 16:45:00	\N	\N	3	0	\N	\N
643699	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Information du consommateur - Auditions M. Gay, Mmes Férat et Blatrix-Contat	MI Information du consommateur - Auditions M. Gay, Mmes Férat et Blatrix-Contat	2022-05-31 14:30:00	2022-05-31 16:30:00	\N	\N	2	0	\N	\N
643702	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Information du consommateur - Auditions M. Gay, Mmes Férat et Blatrix-Contat	MI Information du consommateur - Auditions M. Gay, Mmes Férat et Blatrix-Contat	2022-06-02 14:00:00	2022-06-02 15:45:00	\N	\N	2	0	\N	\N
643719	COM_PERMANENTE	AUTRE	\N	LOIS	\N	MI Avenir institutionnel de la Nouvelle-Calédonie - Auditions	MI Avenir institutionnel de la Nouvelle-Calédonie - Auditions	2022-06-07 17:05:00	2022-06-07 18:00:00	2022-06-07 18:17:20	2022-06-07 19:44:32	16	0	\N	\N
718716	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI AESH	\N	2023-03-24 10:35:00	2023-03-24 12:15:00	\N	\N	5	0	\N	\N
643720	COM_PERMANENTE	AUTRE	\N	LOIS	\N	MI Avenir institutionnel de la Nouvelle-Calédonie - Auditions	MI Avenir institutionnel de la Nouvelle-Calédonie - Auditions	2022-06-08 11:05:00	2022-06-08 12:40:00	2022-06-08 13:02:19	2022-06-08 14:57:31	16	0	\N	\N
644949	COM_EURO	AUTRE	\N	AFEU	\N	Mardi 21 juin 2022	\N	2022-06-21 16:00:00	2022-06-21 17:20:00	2022-06-21 17:19:48	2022-06-21 19:11:42	15	0	\N	\N
644950	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Auditions Mégafeux	\N	2022-06-15 14:00:00	2022-06-15 17:30:00	\N	\N	0	0	\N	\N
644955	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Réunion de travail	\N	2022-06-15 08:45:00	2022-06-15 09:05:00	\N	\N	0	0	\N	\N
644963	COM_EURO	AUDRAP	\N	AFEU	\N	Elargissement de l'Union européenne	Elargissement de l'Union européenne	2022-06-15 17:30:00	2022-06-15 18:45:00	\N	\N	2	0	\N	\N
644984	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Audition	\N	2022-06-14 10:00:00	2022-06-14 11:45:00	\N	\N	0	0	\N	\N
645023	DELEGATION	AUTRE	\N	\N	DSOM	Tables rondes Guyane puis Antilles	\N	2022-07-12 15:00:00	2022-07-12 18:00:00	\N	\N	9	0	\N	\N
645028	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Fédération nationale des conseils d'architecture, d'urbanisme et de l'environnement	\N	2022-06-16 14:30:00	2022-06-16 16:00:00	\N	\N	2	0	\N	\N
645031	COM_PERMANENTE	AUTRE	\N	FINC	\N	Contrôle budgétaire sur le fonds exceptionnel d'investissement (FEI)	Contrôle budgétaire sur le fonds exceptionnel d'investissement (FEI)	2022-06-22 09:35:00	2022-06-22 10:20:00	2022-06-22 10:58:38	2022-06-22 17:20:49	27	1	\N	\N
645033	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - OAT vertes - Label ISR	Contrôle 2022 - OAT vertes - Label ISR	2022-06-15 10:30:00	2022-06-15 11:30:00	\N	\N	1	0	\N	\N
645035	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - OAT vertes - AFT	Contrôle 2022 - OAT vertes - AFT	2022-06-15 18:00:00	2022-06-15 19:20:00	\N	\N	1	0	\N	\N
645037	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 -  ONACVG - DSNJ	Contrôle 2022 -  ONACVG - DSNJ	2022-06-15 15:00:00	2022-06-15 16:15:00	\N	\N	1	0	\N	\N
645039	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI Patrimoine religieux	\N	2022-06-16 14:30:00	2022-06-16 16:00:00	\N	\N	0	0	\N	\N
645566	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Pierre-Éric MOUNIER-KUHN	\N	2022-06-22 15:30:00	2022-06-22 16:40:00	\N	\N	1	0	\N	\N
645568	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Serge ABITEBOUL	\N	2022-06-22 16:40:00	2022-06-22 17:45:00	\N	\N	1	0	\N	\N
645576	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Centre Loisirs Jeunesse de Strasbourg	\N	2022-06-22 15:30:00	2022-06-22 16:30:00	\N	\N	0	0	\N	\N
645577	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	ECOLE DES XV	\N	2022-06-22 14:30:00	2022-06-22 15:30:00	\N	\N	0	0	\N	\N
645579	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 28 juin 2022	\N	2022-06-28 16:00:00	2022-06-28 18:15:00	2022-06-28 18:45:04	2022-06-30 12:12:35	16	0	\N	\N
645580	COM_EURO	AUTRE	\N	AFEU	\N	Audition du 29 juin 2022	\N	2022-06-29 13:40:00	2022-06-29 15:20:00	2022-06-29 18:41:55	2022-06-30 12:12:36	31	0	\N	\N
682266	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Adaptation au droit de l'Union européenne	\N	2022-11-24 09:15:00	2022-11-24 10:00:00	\N	\N	1	0	\N	\N
719500	MISSION	AUDRAP	\N	LOCA	\N	Audition de M. Jean-Léonse Dupont - Départements de France	Audition de M. Jean-Léonse Dupont - Départements de France	2023-03-29 17:00:00	2023-03-29 18:00:00	\N	\N	8	0	\N	\N
719507	DELEGATION	AUCUNE	\N	\N	211	Audition et Tables ronde Santé des femmes au travail (Métiers féminisés)	\N	2023-04-13 08:35:00	2023-04-13 11:10:00	\N	\N	10	0	\N	\N
719805	GIA	AUCUNE	\N	\N	\N	Entretien avec SE l'Ambassadeur d'Allemagne	Entretien des membres du Bureau du groupe d'amitié élargi	2023-03-29 13:00:00	2023-03-29 14:35:00	\N	\N	5	0	604	\N
719811	GIA	AUCUNE	\N	\N	\N	Réunion de travail sur le programme du groupe d'amitié	Réunion de travail sur le programme d'activités et le déplacement du groupe	2023-03-28 12:45:00	2023-03-28 14:15:00	\N	\N	1	0	609	\N
719813	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation de députés de l'Assemblée nationale d'Arménie	Accueil d'une délégation de députés de la Commission Santé du parlement arménien	2023-03-28 16:00:00	2023-03-28 18:00:00	\N	\N	4	0	641	\N
719835	ETUDES	AUCUNE	\N	\N	\N	Audition CSF bois	Audition CSF bois	2023-03-29 08:00:00	2023-03-29 09:15:00	\N	\N	9	0	\N	948
720087	GIA	AUCUNE	\N	\N	\N	Coopé - Visite de Mme Alvine Farida YENO ANOTHO, CEO de la plateforme communautaire d'entr	Coopé - Visite de Mme Alvine Farida YENO ANOTHO, CEO de la plateforme communautaire d'entraide au don de sang NTCHINA	2023-03-28 15:00:00	2023-03-28 16:00:00	\N	\N	1	0	572	\N
720155	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI ZFE	\N	2023-03-27 18:00:00	2023-03-27 19:00:00	\N	\N	1	0	\N	\N
720172	ETUDES	AUCUNE	\N	\N	\N	Réunion groupe TAAF	\N	2023-03-30 11:00:00	2023-03-30 12:00:00	\N	\N	5	0	\N	938
720296	COM_ENQUETE	PLENIERE	\N	TIKTO	\N	Auditions CNIL / Laboratoire Sorbonne / DGSI	Auditions CNIL / Laboratoire Sorbonne / DGSI	2023-04-03 14:30:00	2023-04-03 18:35:00	2023-04-04 10:32:57	2023-04-06 17:48:12	10	0	\N	\N
720823	SEANCE_PLENIERE	DEBAT	\N	\N	\N	PPL Lutte contre le risque incendie	PPL Lutte contre le risque incendieat	2023-04-04 21:30:00	2023-04-05 01:35:00	\N	\N	66	0	\N	\N
722865	GIA	AUCUNE	\N	\N	\N	Déjeuner avec les conseillers économiques des ambassades d'Europe du Nord	Déjeuner avec les conseillers économiques des ambassades d'Europe du Nord (Danemark, Finlande, Norvège, Suède)	2023-04-05 12:30:00	2023-04-05 14:30:00	\N	\N	8	0	625	\N
723209	GIA	AUCUNE	\N	\N	\N	Entretien à l'Ambassade de Roumanie en France	Entretien à l'Ambassade de Roumanie en France	2023-04-11 09:00:00	2023-04-11 10:15:00	\N	\N	3	0	605	\N
723239	GIA	AUCUNE	\N	\N	\N	Geopolique de l'Inde avec Jean-Luc Racine	Analyse de la situation géopolitique de l'Inde dans le contexte de guerre en Ukraine avec le chercheur Jean-Luc Racine	2023-04-11 14:00:00	2023-04-11 15:30:00	\N	\N	5	0	618	\N
724038	MISSION	DEPLACEMENT	\N	AVENCOMM	\N	Déplacement en Ille-et-Vilaine	\N	2023-03-20 08:00:00	2023-03-20 22:00:00	\N	\N	4	0	\N	\N
724165	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition de la fédération française des Dys	\N	2023-04-11 16:00:00	2023-04-11 17:00:00	\N	\N	3	0	\N	\N
724197	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Auditions rapporteurs - MI TND - Conseillers techniques rectorat	\N	2023-04-11 17:00:00	2023-04-11 18:00:00	\N	\N	3	0	\N	\N
724318	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Frontex - Ministère de l'Intérieur	\N	2022-11-10 10:00:00	2022-11-10 11:00:00	\N	\N	2	0	\N	\N
724334	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Réforme marché européen de l'électricité - ELE	\N	2022-11-14 11:15:00	2022-11-14 12:00:00	\N	\N	3	0	\N	\N
724339	COM_EURO	AUDRAP	\N	AFEU	\N	Audition réforme marché européen de l'électricité - SGAE	\N	2022-11-14 12:00:00	2022-11-14 12:45:00	\N	\N	3	0	\N	\N
724343	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Réforme marché européen de l'électricité - Engie	\N	2022-11-14 15:00:00	2022-11-14 16:00:00	\N	\N	2	0	\N	\N
724346	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Réforme marché européen de l'électricité - Clara Hubert	\N	2022-11-15 09:30:00	2022-11-15 10:30:00	\N	\N	2	0	\N	\N
724349	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Réforme marché européen de l'électricité	\N	2022-11-16 12:00:00	2022-11-16 12:45:00	\N	\N	3	0	\N	\N
724354	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Réforme marché européen de l'électricité - Commission régulation énergie	\N	2023-03-28 15:00:00	2023-03-28 16:00:00	\N	\N	2	0	\N	\N
724360	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Euro 7 - Eurocities	\N	2023-03-20 10:15:00	2023-03-20 11:00:00	\N	\N	1	0	\N	\N
724362	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Euro 7 - Commission européenne	\N	2023-03-23 10:00:00	2023-03-23 10:45:00	\N	\N	1	0	\N	\N
724364	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Euro 7 - Plateforme Automobile et des Mobilités	\N	2023-03-23 10:45:00	2023-03-23 11:45:00	\N	\N	1	0	\N	\N
724366	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Euro 7 - Association des constructeurs européens d'automobiles	\N	2023-03-23 11:15:00	2023-03-23 11:45:00	\N	\N	1	0	\N	\N
724368	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Euro 7 - Groupe Renault-Nissan	\N	2023-03-30 14:00:00	2023-03-30 15:00:00	\N	\N	1	0	\N	\N
724376	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Réforme du marché de l'électricité - Engie	\N	2023-04-11 16:00:00	2023-04-11 16:45:00	\N	\N	3	0	\N	\N
724381	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Réforme du marché de l'électricité - RPUE	\N	2023-04-11 17:00:00	2023-04-11 18:00:00	\N	\N	3	0	\N	\N
724385	COM_EURO	AUDRAP	\N	AFEU	\N	Audition normes européennes - Ministère Transition écologique	\N	2023-04-03 14:00:00	2023-04-03 14:45:00	\N	\N	2	0	\N	\N
724388	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Réforme du marché de l'électricité	\N	2023-04-04 14:30:00	2023-04-04 15:45:00	\N	\N	3	0	\N	\N
724392	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Réglement emballages et déchets d'emballage - SGAE	\N	2023-04-04 18:00:00	2023-04-04 18:30:00	\N	\N	1	0	\N	\N
724394	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition rapporteur	\N	2023-04-11 14:00:00	2023-04-11 17:45:00	\N	\N	1	0	\N	\N
724400	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Certificat européen de filiation - Minstère Justice	\N	2023-03-16 15:00:00	2023-03-16 16:00:00	\N	\N	1	0	\N	\N
724404	MISSION	DEPLACEMENT	\N	AVENCOMM	\N	Déplacement en Haute-Garonne	\N	2023-04-13 08:00:00	2023-04-13 22:00:00	\N	\N	3	0	\N	\N
724405	MISSION	DEPLACEMENT	\N	AVENCOMM	\N	Déplacemnent dans les Vosges	\N	2023-04-03 08:00:00	2023-04-03 22:00:00	\N	\N	3	0	\N	\N
724414	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Lutte contre abus sexuels sur mineurs - Pharos	\N	2022-11-17 14:00:00	2022-11-17 15:00:00	\N	\N	3	0	\N	\N
725011	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	Réunion du 12 avril 2023	Réunion du 12 avril 2023	2023-04-12 16:30:00	2023-04-12 17:35:00	2023-04-12 18:26:31	2023-04-28 11:38:45	7	0	\N	\N
725201	DELEGATION	AUCUNE	\N	\N	COLTER	Réunion plénière	\N	2023-04-13 09:00:00	2023-04-13 10:30:00	2023-04-13 15:00:58	\N	11	0	\N	\N
725219	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Réunion groupe subsidiarité du 13 avril 2023	\N	2023-04-13 09:00:00	2023-04-13 09:15:00	\N	\N	4	0	\N	\N
725230	MISSION	AUDRAP	\N	BATI	\N	MI bâti	\N	2023-04-12 14:00:00	2023-04-12 15:15:00	\N	\N	3	0	\N	\N
725233	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de Mme Hélène Tréheux-Duchêne	\N	2023-04-13 09:30:00	2023-04-13 10:45:00	2023-04-13 17:26:27	2023-04-28 11:37:02	14	0	\N	\N
725246	COM_ENQUETE	PLENIERE	\N	RENOV	\N	Audition Défenseure des Droits / Table ronde diagnostiqueurs	\N	2023-04-13 10:30:00	2023-04-13 13:25:00	2023-04-13 13:26:36	2023-04-28 11:38:47	7	0	\N	\N
721825	COM_ENQUETE	PLENIERE	\N	MEDIC	\N	Réunion plénière	\N	2023-04-13 11:05:00	2023-04-13 12:25:00	2023-04-13 13:13:37	2023-04-28 11:38:47	5	0	\N	\N
725437	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2023-04-06 09:30:00	2023-04-06 12:40:00	\N	\N	3	0	\N	\N
725479	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Respect du droit à l'image des enfants	PPL Respect du droit à l'image des enfnants	2023-04-11 10:15:00	2023-04-11 11:30:00	\N	\N	1	0	\N	\N
725481	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Respect du droit à l'image des enfants	PPL Respect du droit à l'image des enfnants	2023-04-11 15:30:00	2023-04-11 17:00:00	\N	\N	1	0	\N	\N
725483	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Pass Culture - Audition auteurs jeunesse	Contrôle 2023 - Pass Culture - Audition auteurs jeunesse	2023-04-11 16:00:00	2023-04-11 17:00:00	\N	\N	1	0	\N	\N
725485	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Financement du cinéma - Audition CNC	Contrôle 2023 - Financement du cinéma - Audition CNC	2023-04-13 14:00:00	2023-04-13 15:15:00	\N	\N	1	0	\N	\N
725487	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Financement du cinéma - Audition IFCIC	Contrôle 2023 - Financement du cinéma - Audition IFCIC	2023-04-13 15:15:00	2023-04-13 16:00:00	\N	\N	1	0	\N	\N
725489	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 203 - Formation continue enseignants - Audition Table-ronde recteurs	Contrôle 203 - Formation continue enseignants - Audition Table-ronde recteurs	2023-04-12 16:30:00	2023-04-12 18:00:00	\N	\N	1	0	\N	\N
638958	MISSION	AUCUNE	\N	FONDSMER	\N	Audition de M. Jean-Marc Sornin puis de représentants Pôles mer	\N	2022-03-16 16:00:00	2022-03-16 18:25:00	2022-03-16 18:23:05	2022-03-17 11:57:46	5	0	\N	\N
639561	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 18 mars 2022	\N	2022-03-18 08:30:00	2022-03-18 10:30:00	2022-03-18 10:37:08	2022-03-21 17:07:45	25	0	\N	\N
639587	DELEGATION	AUCUNE	\N	\N	PROS	Audition publique de France stratégie	\N	2022-03-23 13:35:00	2022-03-23 14:45:00	\N	\N	11	0	\N	\N
641800	ETUDES	AUCUNE	\N	\N	\N	Groupe Orange : présentation du plan de fermeture de réseau cuivre	Groupe Orange : présentation du plan de fermeture de réseau cuivre	2022-05-12 15:00:00	2022-05-12 16:45:00	\N	\N	13	0	\N	1008
644507	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	MI Avenir institutionnel de la Nouvelle-Calédonie - Déplacement en Nouvelle-Calédonie	MI Avenir institutionnel de la Nouvelle-Calédonie - Déplacement en Nouvelle-Calédonie	2022-06-22 08:00:00	2022-06-30 00:00:00	\N	\N	3	0	\N	\N
647604	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Indopacifique	\N	2022-06-20 18:30:00	2022-06-20 19:30:00	\N	\N	2	0	\N	\N
647607	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Indopacifique	\N	2022-06-28 14:00:00	2022-06-28 18:00:00	\N	\N	4	0	\N	\N
647612	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Indopacifique	\N	2022-06-29 09:15:00	2022-06-29 10:30:00	\N	\N	4	0	\N	\N
647617	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Indopacifique	\N	2022-07-05 14:30:00	2022-07-05 17:00:00	\N	\N	4	0	\N	\N
647622	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Indopacifique	\N	2022-07-06 14:00:00	2022-07-06 15:00:00	\N	\N	4	0	\N	\N
647627	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Indopacifique	\N	2022-07-06 16:30:00	2022-07-06 19:30:00	\N	\N	2	0	\N	\N
647630	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Indopacifique	\N	2022-07-07 08:30:00	2022-07-07 09:30:00	\N	\N	2	0	\N	\N
647633	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Avenir corps diplomatique	\N	2022-06-24 08:30:00	2022-06-24 09:30:00	\N	\N	1	0	\N	\N
647635	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Avenir corps diplomatique	\N	2022-06-29 11:00:00	2022-06-29 12:00:00	\N	\N	2	0	\N	\N
647638	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Avenir corps diplomatique	\N	2022-07-06 11:30:00	2022-07-06 12:30:00	\N	\N	2	0	\N	\N
649206	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2022-07-12 15:05:00	2022-07-12 16:30:00	\N	\N	3	0	\N	\N
659665	QUESTURE	AUCUNE	\N	\N	\N	Réunion de Questure	Réunion de Questure	2022-10-06 11:20:00	2022-10-06 12:50:00	\N	\N	3	0	\N	\N
659679	COM_EURO	CONTROLE	\N	AFEU	\N	Réunion du 11 octobre 2022	Réunion du 11 octobre 2022	2022-10-11 08:30:00	2022-10-11 10:45:00	2022-10-11 13:49:19	2022-10-11 16:29:28	22	0	\N	\N
659977	GIA	AUCUNE	\N	\N	\N	Entretien avec l'Ambassadeur du JAPON	Entretien avec Son Exc. M. Junichi IHARA	2022-10-11 13:00:00	2022-10-11 14:30:00	\N	\N	8	0	596	\N
659986	GIA	AUCUNE	\N	\N	\N	Fete nationale à la Délégation de Taipei à Paris	Célébration de la fete nationale de Taïwan	2022-10-05 18:30:00	2022-10-05 20:00:00	\N	\N	6	0	623	\N
725016	CMP	AUTRE	\N	RETRAITES	\N	PLFRSS 2023	PLFRSS 2023	2023-03-15 09:00:00	2023-03-15 17:35:00	\N	\N	14	0	\N	\N
660468	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL restructuration de la plateforme douanière	\N	2022-10-12 09:00:00	2022-10-12 10:15:00	\N	\N	1	0	\N	\N
660480	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL Exploitation des lanceurs au Centre spatial guyanais	\N	2022-10-11 15:00:00	2022-10-11 16:00:00	\N	\N	1	0	\N	\N
660484	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	\N	\N	2022-09-12 11:00:00	2022-09-12 12:00:00	\N	\N	1	0	\N	\N
660486	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	\N	\N	2022-09-12 15:00:00	2022-09-12 16:00:00	\N	\N	1	0	\N	\N
660489	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL Convention  pour les aides à la navigation maritime	PJL Convention portant création de l¿Organisation internationale pour les aides à la navigation maritime	2022-09-13 15:00:00	2022-09-13 16:30:00	\N	\N	1	0	\N	\N
660495	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL Convention pour les aides à la navigation maritime	PJL Convention portant création de l¿Organisation internationale pour les aides à la navigation maritime	2022-09-13 17:00:00	2022-09-13 17:30:00	\N	\N	1	0	\N	\N
660497	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL Convention pour les aides à la navigation maritime	PJL Convention portant création de l¿Organisation internationale pour les aides à la navigation maritime	2022-09-14 10:00:00	2022-09-14 11:00:00	\N	\N	1	0	\N	\N
660499	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL Convention pour les aides à la navigation maritime	PJL Convention portant création de l¿Organisation internationale pour les aides à la navigation maritime	2022-09-14 15:00:00	2022-09-14 16:00:00	\N	\N	1	0	\N	\N
665304	COM_PERMANENTE	AUDRAP	\N	FINC	\N	LPFP pour 2023 à 2027 - DG Trésor	LPFP pour 2023 à 2027 - DG Trésor	2022-10-18 18:00:00	2022-10-18 19:10:00	\N	\N	8	0	\N	\N
665313	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - PFUE - SGAE	PLF pour 2023 - PFUE - SGAE	2022-10-19 17:15:00	2022-10-19 19:00:00	\N	\N	1	0	\N	\N
665315	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - AAFAR - SG MIN Agriculture	PLF pour 2023 - AAFAR - SG MIN Agriculture	2022-10-19 13:30:00	2022-10-19 14:30:00	\N	\N	4	0	\N	\N
665320	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - AAFAR - FNAB/ONF	PLF pour 2023 - AAFAR - FNAB/ONF	2022-10-19 16:45:00	2022-10-19 18:45:00	\N	\N	4	0	\N	\N
665331	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Écologie - Transports - Psdte Région IdF	PLF pour 2023 - Écologie - Transports - Psdte Région IdF	2022-10-24 11:00:00	2022-10-24 11:50:00	\N	\N	2	0	\N	\N
665333	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Défense - EMA	PLF pour 2023 - Défense - EMA	2022-10-18 14:00:00	2022-10-18 15:00:00	\N	\N	1	0	\N	\N
665335	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Solidarité - TR aide alimentaire/égalité F-H/Handicap	PLF pour 2023 - Solidarité - TR aide alimentaire/égalité F-H/Handicap	2022-10-20 14:00:00	2022-10-20 18:30:00	\N	\N	2	0	\N	\N
665338	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Défense - DGA	PLF pour 2023 - Défense - DGA	2022-10-21 10:00:00	2022-10-21 11:00:00	\N	\N	1	0	\N	\N
665340	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Défense - EMAAE	PLF pour 2023 - Défense - EMAAE	2022-10-21 15:00:00	2022-10-21 16:00:00	\N	\N	1	0	\N	\N
665342	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Médias - BNF/CNM	PLF pour 2023 - Médias - BNF/CNM	2022-10-24 09:30:00	2022-10-24 11:30:00	\N	\N	1	0	\N	\N
665344	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Auditions P144	\N	2022-10-19 13:45:00	2022-10-19 14:45:00	\N	\N	0	0	\N	\N
665351	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Plf 2023 Patrimoines	Drac de France, M. Roturier	2022-10-24 09:00:00	2022-10-24 10:00:00	\N	\N	3	0	\N	\N
665367	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 -  EFE - Standard & Poor's	PLF pour 2023 -  EFE - Standard & Poor's	2022-10-21 15:30:00	2022-10-21 16:30:00	\N	\N	1	0	\N	\N
665369	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - EFE - DG Trésor/Sociéte Générale	PLF pour 2023 - EFE - DG Trésor/Sociéte Générale	2022-10-24 09:30:00	2022-10-24 12:30:00	\N	\N	1	0	\N	\N
665375	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2023 - JVA	\N	2022-10-24 16:00:00	2022-10-24 17:00:00	\N	\N	2	0	\N	\N
665379	COM_PERMANENTE	AUTRE	\N	CAE	\N	Examen avis PJL ENR	\N	2022-10-25 17:00:00	2022-10-25 19:55:00	2022-10-26 15:05:30	2022-10-26 15:10:35	35	1	\N	\N
665380	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition article 13 EDF	\N	2022-10-26 09:00:00	2022-10-26 10:45:00	2022-10-26 14:06:44	2022-10-26 15:10:33	46	1	\N	\N
665868	GIA	AUCUNE	\N	\N	\N	Rencontre Thupten Tsering (nouveau représentant du Bureau du Tibet à Paris)	Rencontre Thupten Tsering (nouveau représentant du Bureau du Tibet à Paris)	2022-10-26 14:00:00	2022-10-26 15:00:00	\N	\N	3	0	634	\N
669408	ETUDES	AUCUNE	\N	\N	\N	Réunion sur le projet Société à responsabilité sociale (SARS)	Réunion sur le projet Société à responsabilité sociale (SARS)	2022-11-02 13:30:00	2022-11-02 14:30:00	\N	\N	2	0	\N	998
670339	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PLF 2023 - Avis Économie - volet Industrie	Auditions PLF 2023 - Avis Économie - volet Industrie	2022-10-27 13:30:00	2022-10-27 18:50:00	\N	\N	1	0	\N	\N
670725	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur PLF 2023	\N	2022-11-16 14:00:00	2022-11-16 15:00:00	\N	\N	1	0	\N	\N
670737	ETUDES	DEPLACEMENT	\N	\N	\N	Cérémonie de ravivage de la flamme sous l'Arc de Triomphe	\N	2022-10-04 17:30:00	2022-10-04 19:30:00	\N	\N	11	0	\N	928
670786	COM_PERMANENTE	AUTRE	\N	AFCL	\N	PLF 2023 - Patrimoines	\N	2022-11-15 09:30:00	2022-11-15 10:30:00	2022-11-15 17:25:38	2022-11-16 17:13:15	27	7	\N	\N
670793	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2023 - Recherche - CNES	PLF 2023 - Recherche - CNES	2022-11-08 16:00:00	2022-11-08 17:00:00	\N	\N	1	0	\N	\N
670819	COM_PERMANENTE	AUTRE	\N	AFCL	\N	PLF Enseignement agricole	\N	2022-11-17 11:00:00	2022-11-17 12:00:00	2022-11-17 16:45:06	2022-11-18 11:44:54	16	0	\N	\N
692418	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition PPL Ratios personnels soignants	\N	2023-01-18 17:00:00	2023-01-18 18:00:00	\N	\N	3	0	\N	\N
692450	DELEGATION	AUDRAP	\N	\N	PROS	Audition Prospective espace	\N	2023-01-18 16:30:00	2023-01-18 18:30:00	\N	\N	2	0	\N	\N
692453	DELEGATION	AUDRAP	\N	\N	206	Auditions sobriété énergétique	\N	2023-01-16 10:00:00	2023-01-16 12:00:00	\N	\N	2	0	\N	\N
692456	COM_PERMANENTE	AUTRE	\N	CAE	\N	Ppl Squat - rapport pour avis 	\N	2023-01-24 09:30:00	2023-01-24 10:40:00	2023-01-24 18:45:06	2023-01-25 16:23:04	25	3	\N	\N
692458	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition ARCEP	\N	2023-01-25 09:45:00	2023-01-25 11:20:00	2023-01-25 14:36:26	2023-01-25 16:22:55	40	2	\N	\N
692460	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL 217 Politique du logement - Régions de France BAILBE/EON/TISSANDIER	PPL 217 Politique du logement - Régions de France BAILBE/EON/TISSANDIER	2023-01-19 14:30:00	2023-01-19 15:30:00	\N	\N	1	0	\N	\N
692457	COM_PERMANENTE	AUTRE	\N	CAE	\N	Ppl Bas-Chablais	\N	2023-01-25 09:00:00	2023-01-25 09:45:00	2023-01-25 11:30:29	2023-01-25 16:22:58	43	2	\N	\N
692463	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI cinéma	\N	2023-01-20 10:00:00	2023-01-20 11:00:00	\N	\N	3	0	\N	\N
692486	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Table-ronde relative à la simplification des normes et règles applicables aux entreprises	\N	2023-01-26 10:00:00	2023-01-26 11:30:00	2023-01-26 10:39:50	\N	8	0	\N	\N
692487	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Table ronde Formation, compétences et attractivité	\N	2023-01-26 08:30:00	2023-01-26 10:00:00	2023-01-26 10:06:25	\N	8	0	\N	\N
692496	DELEGATION	AUCUNE	\N	\N	DSOM	réunion du 9 février 2023	\N	2023-02-09 08:30:00	2023-02-09 10:20:00	\N	\N	7	0	\N	\N
692497	DELEGATION	AUCUNE	\N	\N	DSOM	réunion du 16 février 2023	\N	2023-02-16 09:30:00	2023-02-16 12:15:00	\N	\N	13	0	\N	\N
692614	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI LPM programme 144	MI LPM programme 144	2023-01-17 16:30:00	2023-01-17 18:15:00	\N	\N	3	0	\N	\N
692618	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI LPM programme 144	MI LPM programme 144	2023-01-17 16:45:00	2023-01-17 18:15:00	\N	\N	1	0	\N	\N
693561	DELEGATION	AUTRE	\N	\N	DSOM	Rapport Continuité territoriale : audition Polynésie française	\N	2023-01-31 19:00:00	2023-01-31 20:30:00	\N	\N	8	0	\N	\N
693586	DELEGATION	AUCUNE	\N	\N	DSOM	Rapport Continuité territoriale : Nouvelle-Calédonie et Wallis-et-Futuna	\N	2023-02-02 08:00:00	2023-02-02 09:05:00	\N	\N	6	0	\N	\N
693587	DELEGATION	AUTRE	\N	\N	DSOM	rapport Parentalité outre-mer : INED et HCFEA	\N	2023-02-02 09:30:00	2023-02-02 11:00:00	\N	\N	14	0	\N	\N
693928	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 5	\N	2023-01-25 11:00:00	2023-01-25 12:10:00	2023-01-25 14:56:11	2023-01-25 16:22:48	27	0	\N	\N
694042	MISSION	AUCUNE	\N	AVENCOMM	\N	Réunion constitutive	Réunion constitutive	2023-01-31 16:05:00	2023-01-31 17:15:00	2023-02-01 08:39:49	2023-02-01 11:50:10	15	0	\N	\N
694646	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI cinéma	\N	2023-01-25 14:00:00	2023-01-25 15:00:00	\N	\N	4	0	\N	\N
694796	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions M. Olivier Rietmann	\N	2023-01-24 13:45:00	2023-01-24 20:45:00	\N	\N	1	0	\N	\N
694798	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Greenpeace	\N	2023-01-24 14:45:00	2023-01-24 15:30:00	\N	\N	1	0	\N	\N
694800	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition d'un auteur essayiste	\N	2023-01-24 15:30:00	2023-01-24 16:45:00	\N	\N	2	0	\N	\N
694803	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Fondation droit animal, OABA et Welfarm	\N	2023-01-24 17:00:00	2023-01-24 18:15:00	\N	\N	3	0	\N	\N
694807	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition M. Didier Rémond, Jean-Louis Peyraud, Nicole Darmon	\N	2023-01-24 19:00:00	2023-01-24 19:45:00	\N	\N	2	0	\N	\N
694810	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Institut national de recherche pour l¿agriculture, l¿alimentation et l¿environnement	\N	2023-01-24 19:45:00	2023-01-24 20:45:00	\N	\N	1	0	\N	\N
695107	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition amiral Pascal Ausseur	Audition amiral Pascal Ausseur	2023-02-01 09:30:00	2023-02-01 11:10:00	2023-02-01 12:23:10	2023-02-01 17:22:59	37	0	\N	\N
695149	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL PLUI Bas Chablais	PPL PLUI Bas Chablais	2023-01-31 15:50:00	2023-01-31 17:10:00	\N	\N	80	0	\N	\N
695150	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Protection des épargnants	PPL Protection des épargnants	2023-01-31 17:10:00	2023-01-31 20:00:00	\N	\N	81	0	\N	\N
695153	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Logements occupation illicite	PPL Logements occupation illicite	2023-01-31 22:00:00	2023-02-01 01:20:00	\N	\N	61	0	\N	\N
695155	SEANCE_PLENIERE	ALLOCUTION	\N	\N	\N	Allocution Rouslan STEFANTCHOUK	Allocution Rouslan STEFANTCHOUK	2023-02-01 14:30:00	2023-02-01 15:00:00	\N	\N	284	0	\N	\N
695156	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2023-02-01 15:15:00	2023-02-01 16:35:00	\N	\N	294	0	\N	\N
695157	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL soignants patient hospitalisé	PPL soignants patient hospitalisé	2023-02-01 16:45:00	2023-02-01 18:20:00	\N	\N	94	0	\N	\N
695158	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPLC IVG	PPLC IVG	2023-02-01 18:20:00	2023-02-01 20:50:00	\N	\N	153	0	\N	\N
695159	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL retraites non-salariés agricoles	PPL retraites non-salariés agricoles	2023-02-01 22:20:00	2023-02-01 23:50:00	\N	\N	43	0	\N	\N
695160	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL colter politique du logement	PPL colter politique du logement	2023-02-02 10:30:00	2023-02-02 12:40:00	\N	\N	68	0	\N	\N
695161	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL militaires fusillés	PPL militaires fusillés	2023-02-02 12:40:00	2023-02-02 12:50:00	\N	\N	38	0	\N	\N
695191	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Mme Loisier	\N	2023-01-24 18:00:00	2023-01-24 19:30:00	\N	\N	1	0	\N	\N
695193	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 6	PLENIERE - 6 : Examen amendements PPL 586 Protection des épargnants	2023-01-31 14:00:00	2023-01-31 14:15:00	2023-01-31 14:37:02	2023-02-01 11:49:09	24	2	\N	\N
695195	COM_PERMANENTE	AUTRE	\N	FINC	\N	Désignation rapporteur art.13 - Contrôle DCPJ - Audition Présidente ANJ	Désignation rapporteur art.13 - Contrôle DCPJ - Audition Présidente ANJ	2023-02-01 10:00:00	2023-02-01 12:00:00	2023-02-01 16:47:16	2023-02-01 17:23:02	42	1	\N	\N
695202	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PPL Occupation illicite	Audition PPL Occupation illicite	2023-01-11 17:00:00	2023-01-11 19:00:00	\N	\N	1	0	\N	\N
695204	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PPL Occupation illicite	Audition PPL Occupation illicite	2023-01-17 14:45:00	2023-01-17 17:05:00	\N	\N	1	0	\N	\N
695206	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PPL Occupation illicite	Audition PPL Occupation illicite	2023-01-18 16:00:00	2023-01-18 17:00:00	\N	\N	1	0	\N	\N
695208	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Occupation illicite	Audition PPL Occupation illicite	2023-01-19 08:30:00	2023-01-19 09:30:00	\N	\N	1	0	\N	\N
697897	ETUDES	AUTRE	\N	\N	\N	Table ronde sur le loup	Table ronde sur le loup	2023-02-01 13:15:00	2023-02-01 14:25:00	\N	\N	9	0	\N	918
697922	DELEGATION	AUCUNE	\N	\N	211	Parentalité outre-mer : Observatoire de la parentalité, FSFM et FNEPE	\N	2023-02-09 08:30:00	2023-02-09 10:20:00	\N	\N	7	0	\N	\N
697966	ETUDES	AUTRE	\N	\N	\N	Audition filière lentilles	\N	2023-02-01 13:30:00	2023-02-01 15:30:00	\N	\N	0	0	\N	1005
697972	ETUDES	AUDRAP	\N	\N	\N	Viticulteurs de Gironde	\N	2023-01-25 13:30:00	2023-01-25 15:00:00	\N	\N	0	0	\N	909
697990	ETUDES	AUTRE	\N	\N	\N	Viticulteurs de Gironde	Viticulteurs de Gironde	2023-01-25 13:30:00	2023-01-25 15:00:00	\N	\N	14	0	\N	909
698015	ETUDES	AUTRE	\N	\N	\N	Fédération française des spiritueux	Fédération française des spiritueux	2023-02-01 13:15:00	2023-02-01 14:30:00	\N	\N	10	0	\N	909
638780	MISSION	AUCUNE	\N	RECHINNO	\N	Audition plénière France Invest / Croissance Plus	Audition plénière France Invest / Croissance Plus	2022-03-08 09:55:00	2022-03-08 11:00:00	2022-03-09 11:06:36	2022-03-09 18:05:39	3	0	\N	\N
638786	MISSION	AUCUNE	\N	RECHINNO	\N	Auditions plénières	Auditions plénières	2022-03-08 15:00:00	2022-03-08 18:30:00	2022-03-09 10:59:41	2022-03-09 18:05:42	6	0	\N	\N
638794	MISSION	AUDRAP	\N	RECHINNO	\N	Audition rapporteur Sofinnova partners/Ibionext/Auriga partners	Audition rapporteur Sofinnova partners/Ibionext/Auriga partners	2022-03-08 11:00:00	2022-03-08 12:00:00	\N	\N	5	0	\N	\N
638807	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2022-03-15 15:30:00	2022-03-15 16:30:00	2022-03-17 10:38:01	2022-03-17 11:58:05	52	1	\N	\N
638869	DELEGATION	AUCUNE	\N	\N	206	Examen du rapport sur la « science ouverte »	\N	2022-03-09 14:45:00	2022-03-09 16:20:00	\N	\N	8	0	\N	\N
638883	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de M. Olivier Dussopt	\N	2022-03-15 15:30:00	2022-03-15 16:20:00	2022-03-15 17:06:48	2022-03-16 10:08:27	27	0	\N	\N
638885	COM_PERMANENTE	AUTRE	\N	SOCI	\N	MI Contrôle des Ehpad - Auditions plénières	\N	2022-03-16 09:05:00	2022-03-16 12:40:00	2022-03-17 19:34:59	2022-03-18 09:34:13	22	0	\N	\N
638959	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Ministère des solidarités et de la santé - Direction générale de l'offre de soins	Audition de la DGOS	2022-03-10 10:30:00	2022-03-10 11:30:00	\N	\N	1	0	\N	\N
638960	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Faculté de médecine de l'Université de Caen Normandie	Audition de M. Touzé	2022-03-10 11:30:00	2022-03-10 12:40:00	\N	\N	1	0	\N	\N
638961	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Souveraineté économique-DG Trésor/Haut-Commissariat au Plan/Conseil d'analyse économique	Souveraineté économique - DG Trésor / Haut-Commissariat au Plan / Conseil d'analyse économique	2022-03-09 14:10:00	2022-03-09 15:45:00	\N	\N	5	0	\N	\N
638962	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Souveraineté économique-Audition Fédération française des télécoms	Audition Fédération française des télécoms	2022-03-09 15:50:00	2022-03-09 16:35:00	\N	\N	3	0	\N	\N
638963	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Souveraineté économique -Audition commune Hosteur / Scaleway	Souveraineté économique -Audition commune Hosteur / Scaleway	2022-03-09 16:40:00	2022-03-09 17:40:00	\N	\N	3	0	\N	\N
638977	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Auditions Mme Filleul et Mme Herzog	\N	2022-03-09 09:00:00	2022-03-09 10:30:00	\N	\N	0	0	\N	\N
638982	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - Enseignants en Europe - OCDE	Contrôle 2022 - Enseignants en Europe - OCDE	2022-03-08 14:30:00	2022-03-08 15:30:00	\N	\N	1	0	\N	\N
638984	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 - Élèves allophones - Cour des comptes	58-2 - Élèves allophones - Cour des comptes	2022-03-08 15:30:00	2022-03-08 16:30:00	\N	\N	1	0	\N	\N
638986	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - OAT vertes - AFT	Contrôle 2022 - OAT vertes - AFT	2022-03-10 10:00:00	2022-03-10 11:20:00	\N	\N	1	0	\N	\N
638990	COM_PERMANENTE	AUTRE	\N	CAE	\N	Présentation du rapport sur l'attractivité commerciale en zone rurale	\N	2022-03-15 15:30:00	2022-03-15 16:25:00	2022-03-17 16:53:21	2022-03-17 17:00:02	52	4	\N	\N
638991	COM_PERMANENTE	AUTRE	\N	CAE	\N	Table ronde Souveraineté alimentaire	\N	2022-03-15 16:35:00	2022-03-15 18:50:00	2022-03-17 16:53:45	2022-03-17 17:00:04	27	1	\N	\N
638992	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - ZAN - UNAM/dixit.net/FFB & FPI	Contrôle 2022 - ZAN - UNAM/dixit.net/FFB & FPI	2022-03-10 09:30:00	2022-03-10 12:30:00	\N	\N	1	0	\N	\N
638994	COM_ENQUETE	PLENIERE	\N	CABINETS	\N	Examen du rapport de la commission d'enquête présenté par Mme Eliane ASSASSI, rapporteure	Examen du rapport de la commission d'enquête présenté par Mme Eliane ASSASSI, rapporteure	2022-03-16 09:30:00	2022-03-16 11:20:00	2022-03-16 11:28:38	2022-03-16 14:47:15	12	0	\N	\N
638995	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Réunion du GT Subsidiarité	\N	2022-03-09 15:45:00	2022-03-09 15:55:00	\N	\N	0	0	\N	\N
641593	GIA	AUCUNE	\N	\N	\N	Échanges avec le groupe d'amitié France-Slovénie de l'université de Ljubljana	Échanges avec le groupe d'amitié France-Slovénie de l'université de Ljubljana en visioconférence	2022-04-19 16:00:00	2022-04-19 17:30:00	\N	\N	1	0	529	\N
642850	DELEGATION	AUCUNE	\N	\N	206	Audition de l'Autorité de sûreté nucléaire sur son rapport annuel pour 2021	\N	2022-05-17 14:30:00	2022-05-17 16:35:00	\N	\N	7	0	\N	\N
642861	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI France compétences - Audition complémentaire France compétences	\N	2022-05-17 09:30:00	2022-05-17 10:30:00	\N	\N	2	0	\N	\N
642864	DELEGATION	AUTRE	\N	\N	DSOM	Tables rondes ONG et opérateurs économiques	\N	2022-06-02 09:30:00	2022-06-02 12:30:00	\N	\N	16	0	\N	\N
642868	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition 58-2 pour suite à donner relative aux financements de l'État en outre-mer	Audition 58-2 pour suite à donner relative aux financements de l'État en outre-mer	2022-05-24 16:00:00	2022-05-24 17:50:00	2022-05-24 18:09:25	2022-05-27 16:46:08	25	0	\N	\N
642869	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2022-05-24 15:30:00	2022-05-24 16:25:00	2022-05-24 16:41:09	2022-05-27 16:46:08	24	0	\N	\N
644061	DELEGATION	AUDRAP	\N	\N	PROS	Audition SHEM / ENGIE	\N	2022-06-07 14:30:00	2022-06-07 15:30:00	\N	\N	3	0	\N	\N
644065	DELEGATION	AUDRAP	\N	\N	PROS	Audition Agence de l'eau Rhône Méditerranée Corse	\N	2022-06-07 18:00:00	2022-06-07 19:00:00	\N	\N	2	0	\N	\N
644068	DELEGATION	AUDRAP	\N	\N	PROS	Audition Domaines skiables de France	\N	2022-06-07 16:30:00	2022-06-07 17:30:00	\N	\N	2	0	\N	\N
644071	DELEGATION	AUDRAP	\N	\N	PROS	Audition de M. DOUVILLE	\N	2022-06-07 15:30:00	2022-06-07 16:30:00	\N	\N	3	0	\N	\N
644090	DELEGATION	AUDRAP	\N	\N	PROS	Audition M. PASCO (FRS)	\N	2022-06-07 16:00:00	2022-06-07 17:00:00	\N	\N	2	0	\N	\N
644093	ETUDES	AUTRE	\N	\N	\N	Réunion plénière	\N	2022-06-07 18:00:00	2022-06-07 19:30:00	\N	\N	10	0	\N	928
644104	COM_EURO	AUDRAP	\N	AFEU	\N	Europe du médicament	Europe du médicament	2022-05-16 09:00:00	2022-05-16 11:00:00	\N	\N	2	0	\N	\N
644141	COM_EURO	AUDRAP	\N	AFEU	\N	Europe du médicament	Europe du médicament	2022-04-01 15:00:00	2022-04-01 16:00:00	\N	\N	2	0	\N	\N
644143	COM_EURO	AUDRAP	\N	AFEU	\N	Europe du médicament	Europe du médicament	2022-04-08 10:15:00	2022-04-08 11:30:00	\N	\N	2	0	\N	\N
644154	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition Didier Lallement	\N	2022-06-09 10:00:00	2022-06-09 12:00:00	2022-06-10 18:14:27	2022-06-14 17:47:31	38	0	\N	\N
644155	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition Steve Rotheram	\N	2022-06-09 16:10:00	2022-06-09 17:15:00	2022-06-10 18:25:14	2022-06-14 17:47:29	23	0	\N	\N
644217	DELEGATION	AUDRAP	\N	\N	PROS	Audition FN CAUE	\N	2022-06-08 13:30:00	2022-06-08 14:30:00	\N	\N	1	0	\N	\N
644219	DELEGATION	AUDRAP	\N	\N	PROS	Audition M. CHARMES	\N	2022-06-08 14:30:00	2022-06-08 15:30:00	\N	\N	1	0	\N	\N
644770	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - Contrats Etat collectivités lutte contre la pauvreté - ADF	Contrôle 2022 - Contrats Etat collectivités lutte contre la pauvreté - ADF	2022-06-13 10:00:00	2022-06-13 12:00:00	\N	\N	2	0	\N	\N
645040	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI patrimoine religieu	\N	2022-06-16 14:30:00	2022-06-16 15:50:00	\N	\N	2	0	\N	\N
645581	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition MI Souveraineté	Audition MI Souveraineté	2022-05-12 08:30:00	2022-05-12 09:15:00	\N	\N	3	0	\N	\N
645589	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Action Logement	Action Logement	2022-06-21 16:00:00	2022-06-21 17:00:00	\N	\N	3	0	\N	\N
645593	COM_PERMANENTE	AUDRAP	\N	CAE	\N	My Creo Academy	My Creo Academy	2022-06-21 17:30:00	2022-06-21 18:30:00	\N	\N	1	0	\N	\N
645599	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition DGCL	Audition DGCL	2022-05-25 10:00:00	2022-05-25 11:45:00	\N	\N	2	0	\N	\N
645602	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Patrick Kanner	Patrick Kanner	2022-04-20 10:00:00	2022-04-20 11:30:00	\N	\N	3	0	\N	\N
645607	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Hakim el Karoui	Hakim el Karoui	2022-04-20 14:00:00	2022-04-20 15:30:00	\N	\N	3	0	\N	\N
645612	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Marie-Christine Jaillet	Marie-Christine Jaillet	2022-04-21 10:00:00	2022-04-21 11:15:00	\N	\N	3	0	\N	\N
645616	COM_PERMANENTE	AUDRAP	\N	CAE	\N	France Urbaine	France Urbaine	2022-04-21 11:15:00	2022-04-21 12:15:00	\N	\N	2	0	\N	\N
645619	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Renaud Epstein	Renaud Epstein	2022-04-13 10:00:00	2022-04-13 11:00:00	\N	\N	2	0	\N	\N
645623	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Thomas Kirszbaum	Thomas Kirszbaum	2022-04-13 11:00:00	2022-04-13 12:00:00	\N	\N	2	0	\N	\N
678938	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	\N	2022-11-23 16:30:00	2022-11-23 17:00:00	\N	\N	2	0	\N	\N
725491	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - IRSN - Audition syndicats IRSN	Contrôle 2023 - IRSN - Audition syndicats IRSN	2023-04-13 16:00:00	2023-04-13 17:00:00	\N	\N	1	0	\N	\N
725493	ETUDES	AUDRAP	\N	\N	\N	GEAC  Audition Mme COUTARD directrice ADP Orly	GEAC  Audition Mme COUTARD directrice ADP Orly	2023-04-12 13:30:00	2023-04-12 14:35:00	\N	\N	15	0	\N	933
725505	DELEGATION	AUDRAP	\N	\N	206	Audition sur les avancées thérapeutiques en cancérologie	\N	2023-04-13 16:00:00	2023-04-13 19:00:00	\N	\N	2	0	\N	\N
725508	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Modernisation DSNA - Audition M. de IZAGUIRRE (FNAM)	Contrôle 2023 - Modernisation DSNA - Audition M. de IZAGUIRRE (FNAM)	2023-04-13 09:00:00	2023-04-13 10:00:00	\N	\N	1	0	\N	\N
725510	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Modernisation DSNA - Audition de l'IATA	Contrôle 2023 - Modernisation DSNA - Audition de l'IATA	2023-04-13 10:00:00	2023-04-13 11:00:00	\N	\N	1	0	\N	\N
725512	MISSION	AUDRAP	\N	BATI	\N	mi bâti	\N	2023-04-12 18:00:00	2023-04-12 19:00:00	\N	\N	4	0	\N	\N
725618	GIA	AUCUNE	\N	\N	\N	Entretien avec  SE M. Jorge JURE ARNOLETTI, ambassadeur d'Uruguay	Entretien avec  SE M. Jorge JURE ARNOLETTI, ambassadeur d'Uruguay	2023-04-18 19:00:00	2023-04-18 21:30:00	\N	\N	1	0	978	\N
725620	GIA	AUCUNE	\N	\N	\N	Entretien avec des étudiants sur le processus constituant chilien	Entretien avec des étudiants sur le processus constituant chilien	2023-04-05 11:00:00	2023-04-05 13:00:00	\N	\N	3	0	978	\N
725624	GIA	AUCUNE	\N	\N	\N	Entretien avec des étudiants sur le processus constituant chilien	Entretien avec des étudiants sur le processus constituant chilien	2023-04-05 16:00:00	2023-04-05 16:30:00	\N	\N	2	0	978	\N
722810	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 12 avril 2023	\N	2023-04-12 14:05:00	2023-04-12 14:45:00	2023-04-14 10:05:52	2023-04-28 11:37:16	14	0	\N	\N
727106	ETUDES	AUTRE	\N	\N	\N	Audition Veraillia	Audition Veraillia	2023-05-03 13:30:00	2023-05-03 14:30:00	\N	\N	18	0	\N	909
727420	MISSION	AUDRAP	\N	GEAU	\N	Fédérations françaises de Golf et d'équitation	\N	2023-05-03 16:30:00	2023-05-03 17:30:00	\N	\N	1	0	\N	\N
727425	COM_ENQUETE	PLENIERE	\N	RENOV	\N	Table ronde certification qualification	\N	2023-05-03 16:30:00	2023-05-03 18:00:00	2023-05-03 20:43:46	2023-05-04 15:53:45	7	0	\N	\N
728041	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière (divers points)	Réunion plénière (divers points)	2023-05-04 09:00:00	2023-05-04 10:30:00	2023-05-04 17:00:03	\N	6	0	\N	\N
728130	DELEGATION	AUTRE	\N	\N	DSOM	Table ronde UE-outre-mer, en commun avec la commission des affaires européennes	\N	2023-05-10 13:30:00	2023-05-10 15:00:00	\N	\N	18	0	\N	\N
728133	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI PreParE - Audition DSS	\N	2023-05-04 14:00:00	2023-05-04 14:45:00	\N	\N	2	0	\N	\N
728136	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI PreParE - Audition Igas	\N	2023-05-04 14:45:00	2023-05-04 15:45:00	\N	\N	2	0	\N	\N
728139	COM_ENQUETE	PLENIERE	\N	MEDIC	\N	Réunion plénière	\N	2023-05-10 16:30:00	2023-05-10 18:35:00	2023-05-11 10:02:31	2023-05-11 16:17:28	4	0	\N	\N
728140	COM_ENQUETE	PLENIERE	\N	MEDIC	\N	Réunion plénière	\N	2023-05-10 13:30:00	2023-05-10 14:40:00	2023-05-11 10:50:43	2023-05-11 16:17:27	4	0	\N	\N
728141	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2023-05-10 09:30:00	2023-05-10 12:00:00	2023-05-10 17:20:49	2023-05-10 17:45:29	28	0	\N	\N
728142	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2023-04-05 18:06:00	2023-04-05 18:39:00	\N	\N	24	0	\N	\N
728176	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-05-10 09:00:00	2023-05-10 10:55:00	2023-05-10 10:55:53	2023-05-10 12:22:49	35	0	\N	\N
728180	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI PreParE - Audition G. Verdugo	\N	2023-05-04 16:00:00	2023-05-04 16:45:00	\N	\N	2	0	\N	\N
728183	COM_ENQUETE	AUDRAP	\N	MEDIC	\N	Audition Rapporteur - Audition Biogaran	\N	2023-05-04 16:00:00	2023-05-04 17:00:00	\N	\N	3	0	\N	\N
728187	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 10 mai 2023	\N	2023-05-10 13:30:00	2023-05-10 14:40:00	2023-05-10 14:43:12	2023-05-10 15:28:53	18	0	\N	\N
728188	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 11 mai 2023	\N	2023-05-11 09:10:00	2023-05-11 10:20:00	2023-05-11 10:49:35	2023-05-11 16:17:10	11	0	\N	\N
728189	MISSION	AUCUNE	\N	AVENCOMM	\N	Régions de France - Assemblée des départements de France	Régions de France - Assemblée des départements de France	2023-05-09 14:35:00	2023-05-09 16:10:00	2023-05-09 16:51:06	2023-05-09 18:09:03	9	0	\N	\N
728190	DELEGATION	AUTRE	\N	\N	DSOM	Table ronde, avec la DAE, attractivité pour les jeunes diplômés des emplois outre-mer	\N	2023-05-11 09:00:00	2023-05-11 12:00:00	\N	\N	13	0	\N	\N
728261	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Ouvertures de casinos	PPL Ouvertures de casinos	2023-05-03 08:15:00	2023-05-03 12:30:00	\N	\N	1	0	\N	\N
728265	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Ouvertures de casinos	PPL Ouvertures de casinos	2023-05-03 14:00:00	2023-05-03 15:00:00	\N	\N	1	0	\N	\N
728267	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Ouvertures de casinos	PPL Ouvertures de casinos	2023-05-03 17:15:00	2023-05-03 18:00:00	\N	\N	1	0	\N	\N
728271	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Français de l'étranger	MI Français de l'étranger	2023-05-05 15:00:00	2023-05-05 17:00:00	\N	\N	2	0	\N	\N
730244	GIA	AUCUNE	\N	\N	\N	Entretien avec des députés de la Knesset	Entretien avec des députés de la Knesset	2023-05-10 08:30:00	2023-05-10 09:30:00	\N	\N	13	0	595	\N
730554	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2023-05-11 09:00:00	2023-05-11 13:00:00	\N	\N	5	0	\N	\N
730567	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Orientation et programmation du ministère de la justice 2023-2027	PJL Orientation et programmation du ministère de la justice 2023-2027	2023-05-16 14:00:00	2023-05-16 15:45:00	\N	\N	3	0	\N	\N
730568	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Orientation et programmation du ministère de la justice 2023-2027	PJL Orientation et programmation du ministère de la justice 2023-2027	2023-05-17 13:40:00	2023-05-17 15:00:00	\N	\N	1	0	\N	\N
645595	COM_PERMANENTE	AUTRE	\N	CAE	\N	Ville d'Allonnes	Ville d'Allonnes	2022-05-24 14:30:00	2022-05-24 17:30:00	2022-06-24 17:33:23	\N	2	0	\N	\N
730569	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Orientation et programmation du ministère de la justice 2023-2027	PJL Orientation et programmation du ministère de la justice 2023-2027	2023-05-17 17:05:00	2023-05-17 20:05:00	\N	\N	1	0	\N	\N
730570	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Orientation et programmation du ministère de la justice 2023-2027	PJL Orientation et programmation du ministère de la justice 2023-2027	2023-05-19 09:00:00	2023-05-19 09:55:00	\N	\N	2	0	\N	\N
730571	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Orientation et programmation du ministère de la justice 2023-2027	PJL Orientation et programmation du ministère de la justice 2023-2027	2023-05-19 14:00:00	2023-05-19 17:00:00	\N	\N	2	0	\N	\N
730572	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Orientation et programmation du ministère de la justice 2023-2027	PJL Orientation et programmation du ministère de la justice 2023-2027	2023-05-22 14:00:00	2023-05-22 15:00:00	\N	\N	1	0	\N	\N
731011	MISSION	AUDRAP	\N	LOCA	\N	Audition DGCL	\N	2023-05-16 15:00:00	2023-05-16 16:00:00	\N	\N	3	0	\N	\N
731133	DELEGATION	AUDRAP	\N	\N	206	Audition ONERA	\N	2023-05-15 16:00:00	2023-05-15 18:00:00	\N	\N	2	0	\N	\N
731720	GIA	AUCUNE	\N	\N	\N	Dîner autour de SER Mgr le cardinal Jean-Marc Aveline, archevêque de Marseille	\N	2023-05-16 19:30:00	2023-05-16 22:30:00	\N	\N	16	0	629	\N
731727	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition MI TND - M. Taquet	\N	2023-05-16 09:30:00	2023-05-16 10:30:00	\N	\N	2	0	\N	\N
731901	DELEGATION	AUCUNE	\N	\N	211	Parentalité outre-mer : Auditions UNICEF/Croix rouge 	\N	2023-05-25 08:30:00	2023-05-25 10:25:00	\N	\N	9	0	\N	\N
731902	MISSION	AUCUNE	\N	GEAU	\N	Audition de l'Anses	\N	2023-05-17 14:00:00	2023-05-17 15:00:00	2023-05-17 15:20:28	2023-05-17 15:57:34	8	0	\N	\N
732013	DELEGATION	AUCUNE	\N	\N	PROS	Avenir de l'espace	\N	2023-05-25 08:35:00	2023-05-25 09:50:00	\N	\N	6	0	\N	\N
732112	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	TV5 Monde	\N	2023-05-17 14:00:00	2023-05-17 15:00:00	\N	\N	2	0	\N	\N
732653	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de M. Eric Trappier et examen de 2 rapports d'information	Audition de M. Eric Trappier et examen de 2 rapports d'information	2023-05-24 09:30:00	2023-05-24 12:00:00	2023-05-24 17:20:12	2023-05-24 17:25:26	37	8	\N	\N
732834	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Orientation et programmation du ministère de la justice 2023-2027	PJL Orientation et programmation du ministère de la justice 2023-2027	2023-05-19 09:55:00	2023-05-19 12:15:00	\N	\N	3	0	\N	\N
732848	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Verdissement concours financiers - Audition Banque des Territoires	Contrôle 2023 - Verdissement concours financiers - Audition Banque des Territoires	2023-05-16 15:30:00	2023-05-16 16:30:00	\N	\N	1	0	\N	\N
639386	GIA	AUCUNE	\N	\N	\N	Audition - Ambassadeur de France en Zambie	Audition de M. Goldblatt, ambassadeur de France en Zambie	2022-03-15 18:00:00	2022-03-15 19:10:00	\N	\N	2	0	646	\N
639389	GIA	AUCUNE	\N	\N	\N	Audition - Ambassadeur de France en Afrique du Sud	Audition - Aurélien Lechevallier - Ambassadeur de France en Afrique du Sud	2022-03-17 09:00:00	2022-03-17 10:00:00	\N	\N	1	0	646	\N
639705	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Rapports information études de santé plan de relance en faveur des patrimoines.  	\N	2022-03-29 15:35:00	2022-03-29 17:00:00	2022-03-30 11:12:45	2022-03-30 17:22:26	21	0	\N	\N
639706	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Air France	Air France	2022-03-15 09:00:00	2022-03-15 09:30:00	\N	\N	1	0	\N	\N
639710	COM_PERMANENTE	AUDRAP	\N	CDD	\N	FNAM	FNAM	2022-03-15 09:30:00	2022-03-15 10:00:00	\N	\N	1	0	\N	\N
639712	COM_PERMANENTE	AUDRAP	\N	CDD	\N	ADP	ADP	2022-03-15 15:00:00	2022-03-15 15:30:00	\N	\N	1	0	\N	\N
639728	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - OAT vertes - VNF/CGDD	Contrôle 2022 - OAT vertes - VNF/CGDD	2022-03-22 14:30:00	2022-03-22 16:30:00	\N	\N	1	0	\N	\N
639731	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Souveraineté économique - Audition commune RTE / CRE	MI Souveraineté économique - Audition commune RTE / CRE	2022-03-16 14:00:00	2022-03-16 15:00:00	\N	\N	3	0	\N	\N
639732	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Souveraineté économique - Audition commune RTE / CRE	MI Souveraineté économique - Audition commune du BRGM et de A3M	2022-03-16 15:00:00	2022-03-16 16:00:00	\N	\N	4	0	\N	\N
639733	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Souveraineté économique - Audition commune RTE / CRE	MI Souveraineté économique - Audition commune du SFEN et du GIFEN	2022-03-16 16:00:00	2022-03-16 17:00:00	\N	\N	3	0	\N	\N
639734	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Souveraineté économique - Audition commune de France Hydrogène, du SER de de AVERE	MI Souveraineté économique - Audition commune de France Hydrogène, du SER de de AVERE	2022-03-16 17:00:00	2022-03-16 18:00:00	\N	\N	2	0	\N	\N
639955	GIA	AUCUNE	\N	\N	\N	Coopé - Entretien avec Mme Tabata AMARAL DE PONTES	Coopé - Entretien avec Mme Tabata AMARAL DE PONTES	2022-03-22 10:30:00	2022-03-22 11:30:00	\N	\N	1	0	576	\N
639957	GIA	AUCUNE	\N	\N	\N	Coopé - Entretien avec Mme Diana GASPARYAN	Coopé - Entretien avec Mme Diana GASPARYAN	2022-03-23 14:00:00	2022-03-23 15:00:00	\N	\N	1	0	641	\N
640968	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	\N	MCI Délinquance des mineurs	2022-04-06 10:00:00	2022-04-06 11:00:00	\N	\N	4	0	\N	\N
640979	COM_PERMANENTE	AUDRAP	\N	FINC	\N	MCC 2022 - Audiovisuel Public - DLF	MCC 2022 - Audiovisuel Public - DLF	2022-04-07 09:15:00	2022-04-07 10:15:00	\N	\N	2	0	\N	\N
641265	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 -  Régimes des retraites RATP et Marins - ORP RATP/CRP RATP	Contrôle 2022 -  Régimes des retraites RATP et Marins - ORP RATP/CRP RATP	2022-04-12 14:15:00	2022-04-12 17:00:00	\N	\N	1	0	\N	\N
641267	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions DGPE	Auditions DGPE	2022-04-12 15:00:00	2022-04-12 15:50:00	\N	\N	3	0	\N	\N
641268	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Table ronde Industries chimiques	Table ronde Industries chimiques	2022-04-12 16:00:00	2022-04-12 17:15:00	\N	\N	2	0	\N	\N
641269	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Groupe Michelin	Audition Groupe Michelin	2022-04-12 17:15:00	2022-04-12 18:30:00	\N	\N	2	0	\N	\N
641354	MECSS	AUDRAP	\N	\N	MECSS	MI Unification du recouvrement - Audition de l'Urssaf	\N	2022-04-12 14:00:00	2022-04-12 15:30:00	\N	\N	4	0	\N	\N
641355	MECSS	AUDRAP	\N	\N	MECSS	MI Unification du recouvrement - Audition de l'Unédic et de Pôle emploi	\N	2022-04-12 17:00:00	2022-04-12 18:00:00	\N	\N	2	0	\N	\N
641356	MECSS	AUDRAP	\N	\N	MECSS	MI Unification du recouvrement - Audition de l'Agirc-Arrco	\N	2022-04-12 15:30:00	2022-04-12 17:00:00	\N	\N	3	0	\N	\N
641357	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur MI Ehpad - Audition IGAS - Igf	\N	2022-04-13 09:00:00	2022-04-13 11:00:00	\N	\N	8	0	\N	\N
641369	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 -  Régimes des retraites RATP et Marins - ORP Marins	Contrôle 2022 -  Régimes des retraites RATP et Marins - ORP Marins	2022-04-13 09:30:00	2022-04-13 11:00:00	\N	\N	1	0	\N	\N
641385	MECSS	AUDRAP	\N	\N	MECSS	MI Unification du recouvrement	\N	2022-04-13 14:00:00	2022-04-13 15:00:00	\N	\N	4	0	\N	\N
641386	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur MI Ehpad - Audition Arpavie	\N	2022-04-13 14:00:00	2022-04-13 15:30:00	\N	\N	5	0	\N	\N
641396	MECSS	AUDRAP	\N	\N	MECSS	MI Unification du recouvrement - Audition de France Recouvrement	\N	2022-04-13 10:30:00	2022-04-13 12:00:00	\N	\N	2	0	\N	\N
641410	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - Enseignants en Europe - Ambassade France Lisbonne	Contrôle 2022 - Enseignants en Europe - Ambassade France Lisbonne	2022-04-12 16:45:00	2022-04-12 17:45:00	\N	\N	1	0	\N	\N
641428	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Association des Maires ruraux de France	\N	2022-04-13 11:30:00	2022-04-13 12:30:00	\N	\N	4	0	\N	\N
641429	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Fondation du patrimoine 	\N	2022-04-13 09:30:00	2022-04-13 10:30:00	\N	\N	2	0	\N	\N
641430	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Assemblée des départements de France	\N	2022-04-13 10:30:00	2022-04-13 11:30:00	\N	\N	3	0	\N	\N
641440	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Table ronde des associations de sauvegarde du patrimoine	\N	2022-04-13 14:30:00	2022-04-13 16:30:00	\N	\N	4	0	\N	\N
641441	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Sites et Cités remarquables de France	\N	2022-04-13 16:30:00	2022-04-13 17:15:00	\N	\N	3	0	\N	\N
641442	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Petites cités de caractère de France	\N	2022-04-13 17:15:00	2022-04-13 18:00:00	\N	\N	3	0	\N	\N
641446	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur MI Ehpad - Audition Synerpa	\N	2022-04-13 17:00:00	2022-04-13 18:30:00	\N	\N	3	0	\N	\N
641447	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur MI Ehpad - DomusVi	\N	2022-04-13 15:30:00	2022-04-13 17:00:00	\N	\N	3	0	\N	\N
641448	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Boussole numérique	\N	2022-03-23 11:00:00	2022-03-23 12:00:00	\N	\N	2	0	\N	\N
641449	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Boussole numérique	\N	2022-03-24 09:00:00	2022-03-24 10:00:00	\N	\N	2	0	\N	\N
641450	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Boussole numérique	\N	2022-04-08 09:00:00	2022-04-08 10:00:00	\N	\N	2	0	\N	\N
643898	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Association des conservateurs des antiquités et objets d'art	Audition de M. Moureau	2022-06-07 16:00:00	2022-06-07 17:00:00	\N	\N	3	0	\N	\N
643902	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Fondation des Bernardins	Audition de M. de Feydeau	2022-06-07 17:00:00	2022-06-07 18:00:00	\N	\N	2	0	\N	\N
643942	DELEGATION	AUCUNE	\N	\N	DSOM	Petit-déjeuner de travail	\N	2022-07-07 08:00:00	2022-07-07 09:30:00	\N	\N	13	0	\N	\N
643944	DELEGATION	AUCUNE	\N	\N	DSOM	Réunion	\N	2022-07-07 09:45:00	2022-07-07 12:35:00	\N	\N	13	0	\N	\N
643951	MISSION	AUCUNE	\N	RECHINNO	\N	Examen du rapport	\N	2022-06-07 10:10:00	2022-06-08 11:30:00	2022-06-08 15:14:16	2022-06-08 17:37:02	9	2	\N	\N
643975	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	MI Fraude et évasion fiscales - Déplacement SJCF et DRFiP Paris	MI Fraude et évasion fiscales - Déplacement SJCF et DRFiP Paris	2022-06-09 08:30:00	2022-06-09 12:00:00	\N	\N	0	0	\N	\N
643989	DELEGATION	AUCUNE	\N	\N	PROS	Audition de M. Sébastien SORIANO, directeur général de l'IGN	\N	2022-06-08 11:20:00	2022-06-08 12:25:00	2022-06-08 14:04:12	\N	7	0	\N	\N
643996	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	MI Fraude et évasion fiscales - Déplacement DGFiP Paris	MI Fraude et évasion fiscales - Déplacement DGFiP Paris	2022-06-08 13:45:00	2022-06-08 18:30:00	\N	\N	0	0	\N	\N
644004	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Incidents Stade de France - Audition de Didier Lallement, préfet de police de Paris	Incidents Stade de France - Audition de Didier Lallement, préfet de police de Paris	2022-06-09 10:00:00	2022-06-09 12:00:00	2022-06-09 12:53:28	2022-06-09 15:12:47	38	0	\N	\N
644005	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Incidents Stade de France - Audition de la Fédération française de football	Incidents Stade de France - Audition de la Fédération française de football	2022-06-09 14:30:00	2022-06-09 16:05:00	2022-06-09 17:56:23	2022-06-10 18:10:21	24	0	\N	\N
644006	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Incidents Stade de France - Audition de Steve Rotheram, maire de Liverpool	Incidents Stade de France - Audition de Steve Rotheram, maire de Liverpool	2022-06-09 16:10:00	2022-06-09 17:15:00	2022-06-09 17:56:31	2022-06-10 18:10:22	23	0	\N	\N
644374	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de Fabrice Leggeri, ancien directeur exécutif de Frontex	Audition de Fabrice Leggeri, ancien directeur exécutif de Frontex	2022-06-14 15:20:00	2022-06-14 16:35:00	2022-06-14 17:32:08	2022-06-14 17:47:28	17	0	\N	\N
644400	COM_EURO	AUDRAP	\N	AFEU	\N	Partenariat oriental	Partenariat oriental	2022-06-08 14:30:00	2022-06-08 18:15:00	\N	\N	2	0	\N	\N
698489	DELEGATION	AUDRAP	\N	\N	206	Audition Ministère de l'agriculture	\N	2023-02-01 09:30:00	2023-02-01 10:05:00	\N	\N	1	0	\N	\N
698490	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Centres de santé - Audition DGOS	\N	2023-02-02 10:15:00	2023-02-02 11:00:00	\N	\N	2	0	\N	\N
698496	DELEGATION	AUDRAP	\N	\N	206	Audition Anses	\N	2023-02-01 18:00:00	2023-02-01 19:30:00	\N	\N	1	0	\N	\N
698559	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Centres de santé - Audition ARS ÎdF et Paca	\N	2023-02-02 11:00:00	2023-02-02 12:15:00	\N	\N	2	0	\N	\N
698745	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-02-08 09:05:00	2023-02-08 10:05:00	2023-02-08 10:13:53	2023-02-09 11:07:28	40	0	\N	\N
698768	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes du mercredi 8 février	\N	2023-02-08 13:30:00	2023-02-08 14:45:00	2023-02-08 14:47:17	2023-02-09 11:09:14	17	0	\N	\N
698772	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Troubles du neurodéveloppement - Audtion HAS	\N	2023-02-02 11:00:00	2023-02-02 12:00:00	\N	\N	3	0	\N	\N
698776	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Mission d'information troubles neurodévelppemement - Audition PEP Pays de la loire	\N	2023-02-02 12:00:00	2023-02-02 13:00:00	\N	\N	3	0	\N	\N
698849	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFRSS - Audition de la DGT et de la DGEFP	\N	2023-02-14 14:30:00	2023-02-14 15:30:00	\N	\N	3	0	\N	\N
698850	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFRSS - Audition de l'Unédic et Pôle emploi	\N	2023-02-14 15:30:00	2023-02-14 16:15:00	\N	\N	2	0	\N	\N
698854	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFRSS - Audition de l'INRS et de l'ANACT	\N	2023-02-14 16:15:00	2023-02-14 17:00:00	\N	\N	1	0	\N	\N
698857	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFRSS - Audition de la DG Trésor	\N	2023-02-14 17:00:00	2023-02-14 17:45:00	\N	\N	2	0	\N	\N
698864	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFRSS - Audition de la CNAM	\N	2023-02-14 18:00:00	2023-02-14 18:45:00	\N	\N	6	0	\N	\N
698867	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFRSS - Audition de l'ANDRH	\N	2023-02-15 16:30:00	2023-02-15 17:15:00	\N	\N	4	0	\N	\N
698870	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFRSS - Audition du CBE Sud 94	\N	2023-02-15 17:15:00	2023-02-15 18:00:00	\N	\N	3	0	\N	\N
698872	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFRSS - Audition de la DSS	\N	2023-02-15 18:00:00	2023-02-15 19:00:00	\N	\N	4	0	\N	\N
698875	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFRSS - Audition de la CRPCEN	\N	2023-02-16 14:15:00	2023-02-16 15:00:00	\N	\N	4	0	\N	\N
698878	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFRSS - Audition de la CNBF	\N	2023-02-16 15:00:00	2023-02-16 15:45:00	\N	\N	4	0	\N	\N
698900	DELEGATION	AUCUNE	\N	\N	DSOM	Continuité territoriale : audition de la CMA-CGM	\N	2023-02-09 11:00:00	2023-02-09 12:30:00	\N	\N	8	0	\N	\N
698914	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Journée au Conseil d'Etat	\N	2023-01-26 09:00:00	2023-01-26 15:00:00	\N	\N	8	0	\N	\N
698926	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJLFRSS - Audition de la CCMSA	\N	2023-02-07 14:00:00	2023-02-07 14:45:00	\N	\N	4	0	\N	\N
698927	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJLFRSS - Audition de la CPSTI	\N	2023-02-07 14:45:00	2023-02-07 15:30:00	\N	\N	4	0	\N	\N
698928	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJLFRSS - Audition de la CNAVPL	\N	2023-02-07 15:30:00	2023-02-07 16:15:00	\N	\N	5	0	\N	\N
698929	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJLFRSS - Audition de la CDC	\N	2023-02-07 16:15:00	2023-02-07 17:15:00	\N	\N	4	0	\N	\N
698930	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJLFRSS - Audition du SRE et de la Direction du budget	\N	2023-02-07 17:45:00	2023-02-07 18:30:00	\N	\N	4	0	\N	\N
698931	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition du SRE et de la Direction du budget	\N	2023-02-07 17:45:00	2023-02-07 18:30:00	\N	\N	0	0	\N	\N
698932	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition du Cor et du CSR	\N	2023-02-08 16:30:00	2023-02-08 17:30:00	\N	\N	0	0	\N	\N
698933	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition du Cor et du CSR	\N	2023-02-08 16:30:00	2023-02-08 17:30:00	\N	\N	4	0	\N	\N
698934	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition de l'Agirc-Arrco	\N	2023-02-08 17:30:00	2023-02-08 18:30:00	\N	\N	3	0	\N	\N
698935	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition de la CPRP SNCF	\N	2023-02-08 18:30:00	2023-02-08 19:15:00	\N	\N	2	0	\N	\N
698938	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Formation policiers et gendarmes - Audition DGPN et DGGN	Formation policiers et gendarmes - Audition DGPN et DGGN	2023-02-08 10:00:00	2023-02-08 11:35:00	2023-02-08 16:31:24	2023-02-09 11:07:25	42	4	\N	\N
698965	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR 34-1 Soutien du Sénat à l'Ukraine	PPR 34-1 Soutien du Sénat à l'Ukraine	2023-02-07 14:30:00	2023-02-07 16:00:00	\N	\N	124	0	\N	\N
698966	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat « Automobile : tout électrique 2035, est-ce réalisable ? »	Débat « Automobile : tout électrique 2035, est-ce réalisable ? »	2023-02-07 16:00:00	2023-02-07 17:45:00	\N	\N	93	0	\N	\N
698967	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PJL accélération de la production d'énergies renouvelables	CMP PJL accélération de la production d'énergies renouvelables	2023-02-07 17:45:00	2023-02-07 18:45:00	\N	\N	81	0	\N	\N
698968	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat sur les conclusions du rapport : Commerce extérieur	Débat sur les conclusions du rapport : Commerce extérieur	2023-02-07 18:50:00	2023-02-07 20:35:00	\N	\N	62	0	\N	\N
698969	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat conclusions du rapport « Compétitivité : urgence pour redresser la ferme France	Débat conclusions du rapport « Compétitivité : urgence pour redresser la ferme France	2023-02-07 22:05:00	2023-02-08 00:05:00	\N	\N	42	0	\N	\N
698970	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2023-02-08 15:00:00	2023-02-08 16:20:00	\N	\N	293	0	\N	\N
698971	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR 34-1 Reconnaissance génocide Assyro¿Chaldéens de 1915-1918 	PPR 34-1 Reconnaissance génocide Assyro¿Chaldéens de 1915-1918	2023-02-08 18:00:00	2023-02-08 19:15:00	\N	\N	57	0	\N	\N
698975	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat d'actualité Mesures protectionnistes américaines	Débat d'actualité Mesures protectionnistes américaines	2023-02-08 16:35:00	2023-02-08 18:00:00	\N	\N	59	0	\N	\N
698976	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPRE Art 73 quinquies Frontex	PPRE Art 73 quinquies Frontex	2023-02-08 21:30:00	2023-02-09 23:45:00	\N	\N	32	0	\N	\N
698977	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2023-02-09 10:30:00	2023-02-09 12:10:00	\N	\N	25	0	\N	\N
698978	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat « L¿État territorial, entre mirage et réalité »	Débat « L¿État territorial, entre mirage et réalité »	2023-02-09 14:30:00	2023-02-09 16:25:00	\N	\N	32	0	\N	\N
698983	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Immigration et intégration	Audition rapporteur - PJL Immigration et intégration	2023-02-02 11:15:00	2023-02-02 12:30:00	\N	\N	2	0	\N	\N
698986	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - PJL Immigration et intégration	Audition rapporteur - PJL Immigration et intégration	2023-02-02 14:00:00	2023-02-02 16:00:00	\N	\N	3	0	\N	\N
698990	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - PJL Immigration et intégration	Audition rapporteur - PJL Immigration et intégration	2023-02-02 16:45:00	2023-02-02 17:45:00	\N	\N	3	0	\N	\N
699100	GIA	AUCUNE	\N	\N	\N	entretien avec M. Yehuda Shaul, directeur de l¿ONG Ofek Center for Public Affairs	\N	2023-02-06 11:00:00	2023-02-06 12:00:00	\N	\N	2	0	632	\N
701624	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	GT Décentralisation 	\N	2023-02-08 17:30:00	2023-02-08 18:30:00	\N	\N	4	0	\N	\N
701630	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteurs	\N	2023-02-08 18:35:00	2023-02-08 19:30:00	\N	\N	3	0	\N	\N
701635	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL DDADUE - Echange entre rapporteurs pour avis	PJL DDADUE - Echange entre rapporteurs pour avis	2023-02-07 09:30:00	2023-02-07 10:15:00	\N	\N	1	0	\N	\N
701637	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle DGFIP - Réunion Avec Cour des Comptes58-2 2023 - Mission "Action de la DGFiP aupr	58-2 2023 - Mission "Action de la DGFiP auprès des collectivités territoriales"	2023-02-07 15:00:00	2023-02-07 15:45:00	\N	\N	1	0	\N	\N
701654	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFRSS pour 2023 - Caisse des Dépôts et Consignation	PLFRSS pour 2023 - Caisse des Dépôts et Consignation	2023-02-07 16:15:00	2023-02-07 17:05:00	\N	\N	1	0	\N	\N
638886	COM_PERMANENTE	AUTRE	\N	SOCI	\N	MI Contrôle des Ehpad - Audition de V. Castanet	\N	2022-03-15 16:45:00	2022-03-15 18:30:00	2022-03-15 18:27:56	2022-03-16 10:08:26	21	0	\N	\N
638889	COM_PERMANENTE	AUDRAP	\N	FINC	\N	MI Fraude et évasion fiscales - CNIL	MI Fraude et évasion fiscales - CNIL	2022-03-08 16:00:00	2022-03-08 17:10:00	\N	\N	9	0	\N	\N
638891	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Audition avec le Groupe d'amitié France-Etats-Unis	\N	2022-03-15 14:30:00	2022-03-15 16:00:00	\N	\N	0	0	\N	\N
638901	COM_PERMANENTE	AUTRE	\N	LOIS	\N	MI Reconnaissance faciale - Audition de Cédric O	MI Reconnaissance faciale - Audition de Cédric O	2022-03-16 10:05:00	2022-03-16 11:00:00	2022-03-16 12:02:51	2022-03-16 14:46:42	14	0	\N	\N
638902	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI France compétences - Audition Régions de France	\N	2022-03-15 16:00:00	2022-03-15 16:45:00	\N	\N	2	0	\N	\N
638903	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI France compétences - Audition VP région chargés formation professionnelle	\N	2022-03-15 16:45:00	2022-03-15 18:15:00	\N	\N	3	0	\N	\N
638904	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI France compétences - Audition France Compétences	\N	2022-03-15 09:00:00	2022-03-15 10:30:00	\N	\N	4	0	\N	\N
659140	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Sites et Cités remarquables de France	\N	2022-10-06 11:00:00	2022-10-06 12:20:00	\N	\N	3	0	\N	\N
698937	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Favoriser les travaux de rénovation énergétique - LEC	PPL Favoriser les travaux de rénovation énergétique - LEC	2023-02-08 08:35:00	2023-02-08 09:35:00	2023-02-08 16:30:53	2023-02-09 11:07:27	39	0	\N	\N
698940	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPR Agence européenne de garde-frontières et de garde-côtes (amendements)	PPR Agence européenne de garde-frontières et de garde-côtes (amendements)	2023-02-08 09:45:00	2023-02-08 09:55:00	2023-02-08 16:31:17	2023-02-09 11:07:26	40	2	\N	\N
639274	GIA	AUCUNE	\N	\N	\N	Entretien avec Mme TRACZ, programme PIPA	Entretien avec Mme TRACZ, programme PIPA	2022-03-14 15:00:00	2022-03-14 16:00:00	\N	\N	1	0	600	\N
640630	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur CE Ehpad - Audition DGCCRF	\N	2022-03-31 09:00:00	2022-03-31 10:30:00	\N	\N	3	0	\N	\N
640662	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 30 mars - 1	\N	2022-03-30 08:20:00	2022-03-30 09:05:00	\N	\N	0	0	\N	\N
640663	DELEGATION	AUDRAP	\N	\N	PROS	Audition France Nature Environnement	\N	2022-03-29 14:00:00	2022-03-29 15:00:00	\N	\N	4	0	\N	\N
640668	DELEGATION	AUDRAP	\N	\N	PROS	Audition Agence de l'eau Artois-Picardie	\N	2022-03-29 15:00:00	2022-03-29 16:15:00	\N	\N	4	0	\N	\N
640684	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Stage en immersion au tribunal judiciaire de Lille	Stage en immersion au tribunal judiciaire de Lille	2022-04-04 07:00:00	2022-04-05 19:00:00	\N	\N	1	0	\N	\N
640686	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Souveraineté économique	MI Souveraineté économique - Auditions	2022-03-29 09:00:00	2022-03-29 11:00:00	\N	\N	3	0	\N	\N
640694	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Souveraineté économique	MI Souveraineté économique - Auditions	2022-03-29 13:30:00	2022-03-29 15:30:00	\N	\N	3	0	\N	\N
640698	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Rencontres à la Métropole de Lyon et la préfecture du Rhône	Rencontres à la Métropole de Lyon et la préfecture du Rhône	2022-03-31 07:00:00	2022-04-01 19:00:00	\N	\N	7	0	\N	\N
640706	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Rapporteur - Commission enquête Ehpad	\N	2022-03-31 11:00:00	2022-03-31 12:00:00	\N	\N	4	0	\N	\N
640711	MISSION	AUCUNE	\N	RECHINNO	\N	Auditions plénières	Auditions plénières	2022-03-30 14:30:00	2022-03-30 18:35:00	2022-03-31 16:59:39	2022-03-31 17:07:28	4	0	\N	\N
640721	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - Maisons France services - CAB MIN Cohésion territoires	Contrôle 2022 - Maisons France services - CAB MIN Cohésion territoires	2022-03-30 14:30:00	2022-03-30 16:15:00	\N	\N	1	0	\N	\N
644622	DELEGATION	AUDRAP	\N	\N	211	Audition, au format « rapporteures », de représentants du groupe Dorcel	Audition, au format « rapporteures », de représentants du groupe Dorcel	2022-06-14 14:00:00	2022-06-14 15:15:00	\N	\N	5	0	\N	\N
644982	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL Autorité bancaire européenne	\N	2022-06-16 10:00:00	2022-06-16 10:45:00	\N	\N	1	0	\N	\N
644985	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition GT tourisme	Audition GT tourisme	2022-06-14 10:00:00	2022-06-14 10:45:00	\N	\N	4	0	\N	\N
644990	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition GT tourisme	Audition GT tourisme	2022-06-14 10:45:00	2022-06-14 11:45:00	\N	\N	1	0	\N	\N
645626	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Xavier de Jarcy	Xavier de Jarcy	2022-04-14 10:00:00	2022-04-14 11:15:00	\N	\N	2	0	\N	\N
645629	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Adil Jazouli / Henri Rey	Adil Jazouli / Henri Rey	2022-04-14 15:00:00	2022-04-14 16:30:00	\N	\N	1	0	\N	\N
645722	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2022 - DGCCRF - Déplacement à Montpellier	Contrôle 2022 - DGCCRF - Déplacement à Montpellier	2022-06-21 10:10:00	2022-06-22 20:00:00	\N	\N	1	0	\N	\N
645739	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2022-07-06 09:30:00	2022-07-06 12:00:00	2022-07-06 15:17:14	2022-07-06 16:05:11	35	2	\N	\N
645740	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion plénière culture	\N	2022-07-06 09:30:00	2022-07-06 11:35:00	2022-07-06 12:00:49	2022-07-06 16:05:12	41	4	\N	\N
645741	MECSS	AUDRAP	\N	\N	MECSS	Application LFSS pour 2021 	\N	2022-06-28 13:30:00	2022-06-28 14:30:00	\N	\N	3	0	\N	\N
645742	MECSS	AUDRAP	\N	\N	MECSS	Application LFSS pour 2021 	\N	2022-06-29 09:00:00	2022-06-29 10:00:00	\N	\N	1	0	\N	\N
645743	MECSS	AUDRAP	\N	\N	MECSS	Application LFSS pour 2021 	\N	2022-06-29 10:00:00	2022-06-29 11:00:00	\N	\N	2	0	\N	\N
645744	MECSS	AUDRAP	\N	\N	MECSS	Application LFSS pour 2021 	\N	2022-06-29 11:00:00	2022-06-29 12:00:00	\N	\N	2	0	\N	\N
645745	MECSS	AUDRAP	\N	\N	MECSS	Application LFSS pour 2021 	\N	2022-06-29 14:30:00	2022-06-29 15:30:00	\N	\N	3	0	\N	\N
645759	ETUDES	AUTRE	\N	\N	\N	GEAC - Audition de M. Benjamin SMITH, PDG groupe Air France-KLM	GEAC - Audition de M. Benjamin SMITH, PDG groupe Air France-KLM	2022-07-20 13:30:00	2022-07-20 15:00:00	\N	\N	18	0	\N	933
645760	COM_PERMANENTE	AUTRE	\N	CAE	\N	Examen de rapports d'information	\N	2022-06-29 09:30:00	2022-06-29 12:00:00	2022-06-29 14:28:00	2022-06-30 12:12:29	32	2	\N	\N
645923	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Pascal GRISET	\N	2022-06-28 16:00:00	2022-06-28 17:10:00	\N	\N	1	0	\N	\N
653055	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	Réunion du GT subsidiarité	\N	2022-07-27 16:30:00	2022-07-27 17:00:00	\N	\N	3	0	\N	\N
655339	COM_EURO	AUDRAP	\N	AFEU	\N	Constellation de connectivité	\N	2022-06-29 15:30:00	2022-06-29 16:30:00	\N	\N	3	0	\N	\N
655343	COM_EURO	AUDRAP	\N	AFEU	\N	Constellation de connectivité	\N	2022-06-30 09:00:00	2022-06-30 10:00:00	\N	\N	3	0	\N	\N
655347	COM_EURO	AUDRAP	\N	AFEU	\N	Constellation de connectivité	\N	2022-06-30 11:00:00	2022-06-30 12:00:00	\N	\N	3	0	\N	\N
655351	COM_EURO	AUDRAP	\N	AFEU	\N	Constellation de connectivité	\N	2022-07-01 15:00:00	2022-07-01 18:00:00	\N	\N	2	0	\N	\N
655354	COM_EURO	AUDRAP	\N	AFEU	\N	Constellation de connectivité	\N	2022-07-05 16:00:00	2022-07-05 17:00:00	\N	\N	1	0	\N	\N
655356	COM_EURO	AUDRAP	\N	AFEU	\N	Constellation de connectivité	\N	2022-07-06 17:30:00	2022-07-06 18:30:00	\N	\N	1	0	\N	\N
655358	COM_EURO	AUDRAP	\N	AFEU	\N	Constellation de connectivité	\N	2022-07-07 09:00:00	2022-07-07 10:00:00	\N	\N	1	0	\N	\N
655405	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	pjlf 2023 enssco	\N	2022-09-12 14:00:00	2022-09-12 17:30:00	\N	\N	5	0	\N	\N
655684	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de M. Rémy Rioux	\N	2022-09-21 10:30:00	2022-09-21 12:30:00	2022-09-23 11:11:32	2022-09-23 12:01:49	28	0	\N	\N
656786	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	MCC ZAN	MCC Zéro artificialisation nette	2022-09-28 16:35:00	2022-09-28 17:40:00	\N	\N	19	0	\N	\N
659058	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	examen du rapport d¿information sur la transmission d¿entreprise	\N	2022-10-06 09:00:00	2022-10-06 10:30:00	\N	\N	9	0	\N	\N
659070	DELEGATION	AUCUNE	\N	\N	206	Audition publique sur la rénovation thermique des bâtiments	\N	2022-10-06 09:40:00	2022-10-06 12:10:00	\N	\N	6	0	\N	\N
659085	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition 58-2 financement CT et Contrôle budgétaire Douane trafic de stupéfiants	Audition 58-2 financement CT et Contrôle budgétaire Douane trafic de stupéfiants	2022-10-12 10:00:00	2022-10-12 12:50:00	2022-10-12 17:07:22	2022-10-12 17:33:53	41	1	\N	\N
659089	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2023 Enssup	\N	2022-10-04 15:00:00	2022-10-04 16:00:00	\N	\N	2	0	\N	\N
659097	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL ENR	\N	2022-10-04 09:00:00	2022-10-04 10:00:00	\N	\N	2	0	\N	\N
659102	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF LIC	\N	2022-10-06 10:00:00	2022-10-06 11:00:00	\N	\N	1	0	\N	\N
659114	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PJL ENR	\N	2022-10-04 14:00:00	2022-10-04 14:45:00	\N	\N	1	0	\N	\N
659122	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PJL ENR	\N	2022-10-04 15:45:00	2022-10-04 16:30:00	\N	\N	3	0	\N	\N
700334	GIA	AUCUNE	\N	\N	\N	Entretien Ambassadeur République slovaque	\N	2023-02-08 08:30:00	2023-02-08 10:00:00	\N	\N	2	0	532	\N
732850	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Verdissement concours financiers - Audition DGALN	Contrôle 2023 - Verdissement concours financiers - Audition DGALN	2023-05-17 16:30:00	2023-05-17 17:45:00	\N	\N	1	0	\N	\N
732852	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Pass culture - Table-ronde Spectacle vivant SNSP et PROFEDIM	Contrôle 2023 - Pass culture - Table-ronde Spectacle vivant SNSP et PROFEDIM	2023-05-17 16:30:00	2023-05-17 17:50:00	\N	\N	2	0	\N	\N
732855	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Risque PGE - Audition Signaux faibles	Contrôle 2023 - Risque PGE - Audition Signaux faibles	2023-05-11 10:30:00	2023-05-11 12:00:00	\N	\N	1	0	\N	\N
732857	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PPL Entrepreneurs	Audition PPL Entrepreneurs	2023-05-19 17:00:00	2023-05-19 17:30:00	\N	\N	1	0	\N	\N
732865	COM_ENQUETE	PLENIERE	\N	RENOV	\N	Tables rondes	\N	2023-05-22 15:05:00	2023-05-22 19:40:00	2023-05-22 19:57:36	2023-05-24 09:42:17	5	0	\N	\N
732866	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition Action Logement 	\N	2023-05-24 10:05:00	2023-05-24 11:50:00	2023-05-25 12:19:24	2023-05-25 12:19:32	41	3	\N	\N
732871	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Orientation et programmation du ministère de la justice 2023-2027	PJL Orientation et programmation du ministère de la justice 2023-2027	2023-05-19 17:30:00	2023-05-19 18:30:00	\N	\N	3	0	\N	\N
733637	COM_ENQUETE	PLENIERE	\N	RENOV	\N	Auditions plénières	\N	2023-05-23 15:50:00	2023-05-23 20:20:00	2023-05-24 09:37:03	2023-05-24 09:42:17	6	0	\N	\N
733765	MISSION	AUDRAP	\N	GEAU	\N	ATEP¿eau de la parcelle 	\N	2023-05-23 17:55:00	2023-05-23 18:40:00	\N	\N	4	0	\N	\N
734154	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2023-05-16 17:00:00	2023-05-16 18:30:00	\N	\N	3	0	\N	\N
735381	GIA	AUCUNE	\N	\N	\N	entretien avec Mme Lolwa Al-Khater, ministre d'Etat à la Coopération internationale du Qat	\N	2023-05-25 10:00:00	2023-05-25 11:00:00	\N	\N	3	0	661	\N
735452	BUREAU	AUCUNE	\N	\N	\N	Réunion du Bureau	Réunion du Bureau	2023-05-25 08:35:00	2023-05-25 12:15:00	\N	\N	18	0	\N	\N
735535	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat sur la France rurale face à la disparition des services au public	Débat sur la France rurale face à la disparition des services au public	2023-05-30 15:45:00	2023-05-30 17:20:00	\N	\N	92	0	\N	\N
735536	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	LEC PPL Bourses d'études et parent en situation de handicap 	LEC PPL Bourses d'études et parent en situation de handicap 	2023-05-30 17:20:00	2023-05-30 18:15:00	\N	\N	56	0	\N	\N
735537	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	 PPL Reconnaître et soutenir les entrepreneurs français à l'étranger	 PPL Reconnaître et soutenir les entrepreneurs français à l'étranger	2023-05-30 18:15:00	2023-05-30 20:45:00	\N	\N	71	0	\N	\N
735539	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2023-05-31 15:00:00	2023-05-31 16:15:00	\N	\N	284	0	\N	\N
735542	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat sur le bilan de l'application des lois	Débat sur le bilan de l'application des lois	2023-05-31 16:30:00	2023-05-31 17:50:00	\N	\N	51	0	\N	\N
735543	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat sur la gestion des déchets dans les outre-mer	Débat sur la gestion des déchets dans les outre-mer	2023-05-31 17:50:00	2023-05-31 19:10:00	\N	\N	35	0	\N	\N
735545	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Accès aux services publics	PPL Accès aux services publics	2023-05-31 19:15:00	2023-05-31 20:35:00	\N	\N	32	0	\N	\N
735546	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2023-06-01 10:35:00	2023-06-01 12:30:00	\N	\N	34	0	\N	\N
735547	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR Importation de produits issus du travail forcé de la population ouïghoure	PPR Importation de produits issus du travail forcé de la population ouïghoure	2023-06-01 15:20:00	2023-06-01 16:35:00	\N	\N	19	0	\N	\N
735548	GIA	AUCUNE	\N	\N	\N	Délégation de députés libanais conduite par Fouad Makhzoumi (Bloc du Renouveau)	Délégation de députés libanais de différents partis politiques conduite par Fouad Makhzoumi (Bloc du Renouveau)	2023-05-23 14:00:00	2023-05-23 15:00:00	\N	\N	3	0	597	\N
735552	GIA	AUCUNE	\N	\N	\N	Entretien avec S.E. Mme Hend AL OTAIBA, ambassadrice des Émirats arabes unis	\N	2023-05-25 15:30:00	2023-05-25 17:30:00	\N	\N	1	0	661	\N
735597	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Industrie verte - Audition direction générale du Trésor	PJL Industrie verte - Audition direction générale du Trésor	2023-05-26 10:40:00	2023-05-26 11:30:00	\N	\N	1	0	\N	\N
735600	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Industrie verte - Audition Autorité des marchés financiers	PJL Industrie verte - Audition Autorité des marchés financiers	2023-05-26 14:00:00	2023-05-26 15:00:00	\N	\N	1	0	\N	\N
735603	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	expertise patr	\N	2023-05-30 09:30:00	2023-05-30 10:30:00	\N	\N	4	0	\N	\N
735609	MISSION	AUDRAP	\N	BATI	\N	Audition DG ANCT	\N	2023-06-06 14:30:00	2023-06-06 15:30:00	\N	\N	3	0	\N	\N
735610	COM_PERMANENTE	AUTRE	\N	CAE	\N	ppl Entrepreneurs - amendements de séance	\N	2023-05-30 14:00:00	2023-05-30 14:10:00	2023-06-07 10:33:22	2023-06-07 11:05:09	21	8	\N	\N
735634	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	M6	\N	2023-05-30 10:30:00	2023-05-30 11:30:00	\N	\N	1	0	\N	\N
735639	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	France Télévisions	\N	2023-05-30 16:00:00	2023-05-30 17:00:00	\N	\N	4	0	\N	\N
736293	COM_PERMANENTE	AUTRE	\N	AFCL	\N	LEC restes humains	\N	2023-06-08 08:30:00	2023-06-08 09:30:00	2023-06-08 09:47:53	2023-06-08 11:18:26	16	5	\N	\N
736308	MISSION	AUCUNE	\N	BIOCARBU	\N	PLENIERE - 20	\N	2023-05-30 16:30:00	2023-05-30 19:20:00	2023-05-30 19:21:26	2023-06-02 16:10:38	9	0	\N	\N
736372	COM_ENQUETE	PLENIERE	\N	MEDIC	\N	Audition de M. Savino	\N	2023-05-30 16:40:00	2023-05-30 17:55:00	2023-05-30 18:05:55	2023-06-02 16:10:39	7	0	\N	\N
736560	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI autonomie	\N	2023-05-30 13:45:00	2023-05-30 14:45:00	\N	\N	2	0	\N	\N
736561	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL restes humains	\N	2023-05-30 18:00:00	2023-05-30 20:00:00	\N	\N	1	0	\N	\N
736564	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	ppl Ciné OM	\N	2023-05-30 16:00:00	2023-05-30 17:00:00	\N	\N	1	0	\N	\N
736566	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL honorabilité	\N	2023-05-30 16:45:00	2023-05-30 19:30:00	\N	\N	2	0	\N	\N
736567	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL restes humains	\N	2023-05-30 12:30:00	2023-05-30 13:30:00	\N	\N	2	0	\N	\N
736578	ETUDES	AUDRAP	\N	\N	\N	audition Barrot	\N	2023-05-30 09:30:00	2023-05-30 11:00:00	\N	\N	9	0	\N	1008
740632	GIA	AUCUNE	\N	\N	\N	Entretien avec S.E. Mme Nyamkhuu ULAMBAYAR, Ambassadrice de Mongolie en France	Entretien avec S.E. Mme Nyamkhuu ULAMBAYAR, Ambassadrice de Mongolie en France, concernant la visite d'Etat	2023-06-06 08:30:00	2023-06-06 09:45:00	\N	\N	7	0	612	\N
642006	MECSS	AUDRAP	\N	\N	MECSS	MI Unification du recouvrement - Audition de la DSS	\N	2022-05-11 15:00:00	2022-05-11 16:45:00	\N	\N	3	0	\N	\N
732868	COM_PERMANENTE	AUTRE	\N	CAE	\N	Ppl Entrepreneurs	\N	2023-05-24 11:50:00	2023-05-24 12:25:00	2023-05-25 12:20:18	2023-05-30 13:06:14	42	3	\N	\N
740735	GIA	AUCUNE	\N	\N	\N	Rencontre avec l'ambassadeur de Pologne à l'occasion de l'accueil d'une délégation	Rencontre avec l'ambassadeur de Pologne à l'occasion de l'accueil d'une délégation du Sénat polonais	2023-05-02 19:30:00	2023-05-02 22:30:00	\N	\N	5	0	600	\N
740770	QUESTURE	AUCUNE	\N	\N	\N	Réunion de Questure	Réunion du Conseil de Questure	2023-06-01 08:30:00	2023-06-01 10:35:00	\N	\N	3	0	\N	\N
744107	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Données de connexion	\N	2023-06-15 09:30:00	2023-06-15 10:30:00	\N	\N	2	0	\N	\N
744111	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Données de connexion	\N	2023-06-15 13:50:00	2023-06-15 15:00:00	\N	\N	2	0	\N	\N
748426	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition de Sylvie Retailleau	\N	2023-07-11 17:30:00	2023-07-11 19:10:00	2023-07-11 19:11:02	2023-07-12 10:30:17	21	0	\N	\N
748428	COM_ENQUETE	AUTRE	\N	TIKTO	\N	Tiktok - Adoption du rapport	\N	2023-07-04 15:40:00	2023-07-04 17:15:00	2023-07-06 17:23:39	2023-07-07 16:16:14	10	2	\N	\N
748445	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Émeutes survenues depuis le 27 juin 2023 - Audition de Gérald Darmanin	Émeutes survenues depuis le 27 juin 2023 - Audition de Gérald Darmanin	2023-07-05 16:40:00	2023-07-05 18:10:00	2023-07-11 14:54:24	2023-07-11 15:07:31	21	0	\N	\N
749894	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2023-07-04 16:00:00	2023-07-04 17:00:00	\N	\N	1	0	\N	\N
750891	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 12 juillet 2023 (3/3)	Réunion du 12 juillet 2023 (3/3)	2023-07-12 16:30:00	2023-07-12 19:00:00	2023-07-12 19:10:08	2023-07-13 11:23:09	11	0	\N	\N
750892	COM_PERMANENTE	AUDRAP	\N	CAE	\N	TR filières animales	TR filières animales	2023-06-20 18:00:00	2023-06-20 19:00:00	\N	\N	2	0	\N	\N
638005	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Rencontre avec des représentants de la FICIF	\N	2022-02-22 12:30:00	2022-02-22 17:00:00	\N	\N	0	0	\N	\N
638015	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 1er mars	\N	2022-03-01 15:30:00	2022-03-01 17:00:00	2022-03-01 17:40:27	2022-03-02 10:22:02	11	0	\N	\N
638386	COM_EURO	AUDRAP	\N	AFEU	\N	Relations UE/Afrique - Parlement européen	\N	2022-03-03 15:00:00	2022-03-03 16:00:00	\N	\N	0	0	\N	\N
638387	COM_EURO	AUDRAP	\N	AFEU	\N	Relations UE/Afrique - Ambassade de France au Sénégal	\N	2022-03-07 15:30:00	2022-03-07 16:30:00	\N	\N	0	0	\N	\N
638388	COM_EURO	AUDRAP	\N	AFEU	\N	Relations UE/Afrique	\N	2022-03-07 09:30:00	2022-03-07 12:00:00	\N	\N	0	0	\N	\N
638389	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI France compétences - Audition de la FNADIR	\N	2022-03-01 16:00:00	2022-03-01 17:00:00	\N	\N	3	0	\N	\N
638395	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition commission enquêt Ehpad - FHF	\N	2022-03-15 14:00:00	2022-03-15 15:30:00	\N	\N	6	0	\N	\N
638396	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition MI Contrôle des Ehpad	\N	2022-03-16 14:30:00	2022-03-16 15:30:00	\N	\N	5	0	\N	\N
638397	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Audition BBelin et SBabary / VA et LB	\N	2022-03-02 16:30:00	2022-03-02 18:30:00	\N	\N	0	0	\N	\N
638403	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Auditions communes	\N	2022-03-03 09:00:00	2022-03-03 10:00:00	\N	\N	0	0	\N	\N
641138	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur MI Ehpad	\N	2022-04-12 14:30:00	2022-04-12 15:30:00	\N	\N	2	0	\N	\N
641139	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur MI Ehpad - Audition France Assos santé	\N	2022-04-12 15:30:00	2022-04-12 16:30:00	\N	\N	3	0	\N	\N
641140	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition MI Epad - ARS Nouvelle aquitaine	\N	2022-04-12 16:30:00	2022-04-12 18:00:00	\N	\N	5	0	\N	\N
641141	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur MI Ehpad - Association Gamme	\N	2022-04-12 18:00:00	2022-04-12 19:00:00	\N	\N	4	0	\N	\N
641146	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Rencontre maires	\N	2022-03-30 09:15:00	2022-03-30 10:30:00	\N	\N	0	0	\N	\N
641147	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Rencontre FDC	\N	2022-03-30 11:30:00	2022-03-30 12:30:00	\N	\N	0	0	\N	\N
641148	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Déjeuner AMRF	\N	2022-03-30 12:45:00	2022-03-30 14:00:00	\N	\N	0	0	\N	\N
641149	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Audition OFB	\N	2022-03-30 14:30:00	2022-03-30 16:45:00	\N	\N	0	0	\N	\N
641220	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	MI Question migratoire - Déplacement en Pologne	MI Question migratoire - Déplacement en Pologne	2022-04-13 07:00:00	2022-04-14 22:00:00	\N	\N	5	0	\N	\N
641247	ETUDES	AUTRE	\N	\N	\N	Auditions sur les dernières innovations dans le traitement des cancers du sein 	\N	2022-04-12 14:30:00	2022-04-12 16:45:00	\N	\N	7	0	\N	1004
641545	GIA	AUCUNE	\N	\N	\N	Déjeuner Ambassadeur de Belgique	Déjeuner Ambassadeur de Belgique	2022-04-12 12:30:00	2022-04-12 14:45:00	\N	\N	3	0	580	\N
641558	COM_PERMANENTE	AUDRAP	\N	FINC	\N	MCC 2022 - Audiovisuel Public - CGEF/DB	MCC 2022 - Audiovisuel Public - CGEF/DB	2022-04-14 10:30:00	2022-04-14 12:10:00	\N	\N	2	0	\N	\N
641570	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	mise en oeuvre LPR	\N	2022-04-12 15:00:00	2022-04-12 17:00:00	\N	\N	5	0	\N	\N
641581	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	mise en oeuvre LPR	\N	2022-04-14 11:00:00	2022-04-14 13:00:00	\N	\N	3	0	\N	\N
641745	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI SPIP	MI SPIP - Auditions	2022-04-20 16:00:00	2022-04-20 17:30:00	\N	\N	2	0	\N	\N
641749	COM_PERMANENTE	AUDRAP	\N	FINC	\N	MCC 2022 - Audiovisuel Public - ARCOM/DGMIC	MCC 2022 - Audiovisuel Public - ARCOM/DGMIC	2022-04-21 11:10:00	2022-04-21 13:10:00	\N	\N	2	0	\N	\N
641807	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI sur la politique étrangère américaine	MI sur la politique étrangère américaine	2022-04-25 14:30:00	2022-04-25 15:30:00	\N	\N	3	0	\N	\N
641811	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI sur la politique étrangère américaine	MI sur la politique étrangère américaine	2022-04-26 17:30:00	2022-04-26 18:40:00	\N	\N	2	0	\N	\N
641985	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Ehpad - Audition rapporteur Thomas Fatôme	\N	2022-05-24 18:00:00	2022-05-24 19:00:00	\N	\N	1	0	\N	\N
641986	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur Laboratoire Hartmann	\N	2022-05-25 10:00:00	2022-05-25 11:00:00	\N	\N	6	0	\N	\N
641987	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Ehpad - Audition rapporteur France Horizon	\N	2022-05-25 15:00:00	2022-05-25 16:00:00	\N	\N	3	0	\N	\N
641988	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur Cofrac	\N	2022-05-25 16:00:00	2022-05-25 17:00:00	\N	\N	3	0	\N	\N
641989	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Ehpad - Audition rapporteur Table ronde d'assocaitions d'aidants	\N	2022-05-25 17:00:00	2022-05-25 18:00:00	\N	\N	6	0	\N	\N
641990	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Énergie et hydrogène nucléaires	\N	2022-04-27 16:00:00	2022-04-27 17:15:00	\N	\N	5	0	\N	\N
641997	COM_EURO	AUDRAP	\N	AFEU	\N	Audition intelligence artificielle	\N	2022-04-22 14:30:00	2022-04-22 15:30:00	\N	\N	3	0	\N	\N
641998	DELEGATION	AUCUNE	\N	\N	211	Auditions dans le cadre du rapport d'information sur la pornographie	Auditions dans le cadre du rapport d'information sur la pornographie	2022-05-11 14:30:00	2022-05-11 16:30:00	\N	\N	8	0	\N	\N
641999	MECSS	AUDRAP	\N	\N	MECSS	MI Unification du recouvrement - Visite de l'Urssaf (Montreuil-sous-Bois)	\N	2022-05-04 09:45:00	2022-05-04 12:30:00	\N	\N	2	0	\N	\N
642000	MECSS	AUDRAP	\N	\N	MECSS	MI Unification du recouvrement - Visite d'un site de gestion AG2R La Mondiale	\N	2022-05-04 14:30:00	2022-05-04 17:15:00	\N	\N	2	0	\N	\N
642001	MECSS	AUDRAP	\N	\N	MECSS	MI Unification du recouvrement - Audition CAVIMAC	\N	2022-05-10 14:15:00	2022-05-10 15:15:00	\N	\N	4	0	\N	\N
642002	MECSS	AUDRAP	\N	\N	MECSS	Audition rapporteurs	\N	2022-05-10 18:00:00	2022-05-10 19:20:00	\N	\N	3	0	\N	\N
642005	MECSS	AUDRAP	\N	\N	MECSS	MI Unification du recouvrement - Audition de la CCMSA	\N	2022-05-11 14:00:00	2022-05-11 15:00:00	\N	\N	3	0	\N	\N
642007	MECSS	AUDRAP	\N	\N	MECSS	MI Unification du recouvrement - Audition de la Caisse des dépôts	\N	2022-05-11 17:00:00	2022-05-11 18:00:00	\N	\N	3	0	\N	\N
642687	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MIC Delinquance des mineurs	MIC Délinquance des mineurs	2022-05-12 10:00:00	2022-05-12 11:35:00	\N	\N	3	0	\N	\N
644403	COM_EURO	AUDRAP	\N	AFEU	\N	Elargissement de l'UE	Elargissement de l'UE	2022-06-09 12:15:00	2022-06-09 13:00:00	\N	\N	1	0	\N	\N
644404	COM_EURO	AUDRAP	\N	AFEU	\N	Partenariat oriental	Partenariat oriental	2022-06-09 10:00:00	2022-06-09 12:15:00	\N	\N	1	0	\N	\N
644407	DELEGATION	AUCUNE	\N	\N	DSOM	Auditions de la délégation	\N	2022-06-16 09:00:00	2022-06-16 11:35:00	\N	\N	12	0	\N	\N
644410	COM_EURO	AUDRAP	\N	AFEU	\N	Intelligence artificielle	Intelligence artificielle	2022-05-31 09:00:00	2022-05-31 10:20:00	\N	\N	3	0	\N	\N
644418	COM_EURO	AUDRAP	\N	AFEU	\N	Partenariat oriental	Partenariat oriental	2022-06-10 11:00:00	2022-06-10 12:15:00	\N	\N	3	0	\N	\N
644422	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Incidents Stade de France - Audition de la RATP et la SNCF	Incidents Stade de France - Audition de la RATP et la SNCF	2022-06-14 09:00:00	2022-06-14 10:25:00	2022-06-14 11:32:59	2022-06-14 17:47:27	26	0	\N	\N
644423	COM_PERMANENTE	AUTRE	\N	LOIS	\N	MI Avenir institutionnel de la Nouvelle-Calédonie - Audition MM. Christnacht et Merle	MI Avenir institutionnel de la Nouvelle-Calédonie - Audition MM. Christnacht et Merle	2022-06-15 10:10:00	2022-06-15 11:40:00	2022-06-15 11:47:09	2022-06-15 14:45:39	13	0	\N	\N
644424	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Incidents Stade de France - Audition de Michel Cadot, DIJOP 2024	Incidents Stade de France - Audition de Michel Cadot, DIJOP 2024	2022-06-16 10:30:00	2022-06-16 12:25:00	2022-06-17 09:16:41	2022-06-17 17:53:43	31	0	\N	\N
645113	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	MI Formation des personnels PN-GN - Ecole nationale de police de Roubaix	MI Formation des personnels PN-GN - Ecole nationale de police de Roubaix	2022-06-23 08:00:00	2022-06-23 20:00:00	\N	\N	4	0	\N	\N
646271	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI  Méditerranée	\N	2022-06-28 10:00:00	2022-06-28 12:00:00	\N	\N	2	0	\N	\N
646274	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI  Méditerranée	\N	2022-06-28 14:30:00	2022-06-28 16:30:00	\N	\N	2	0	\N	\N
646279	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI  Méditerranée	\N	2022-06-29 11:00:00	2022-06-29 12:00:00	\N	\N	1	0	\N	\N
646281	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI  Méditerranée	\N	2022-06-29 14:30:00	2022-06-29 15:30:00	\N	\N	1	0	\N	\N
646285	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI  Méditerranée	\N	2022-06-29 16:30:00	2022-06-29 18:30:00	\N	\N	1	0	\N	\N
650020	GIA	AUCUNE	\N	\N	\N	Audition Syed	Audition de M. Damien Syed, sous-directeur de l'Asie méridionale	2022-07-20 14:00:00	2022-07-20 15:00:00	\N	\N	3	0	648	\N
652897	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Projet de loi de finances rectificative pour 2022	Projet de loi de finances rectificative pour 2022	2022-08-01 15:00:00	2022-08-01 20:00:00	\N	\N	121	0	\N	\N
701659	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFRSS pour 2023 - Direction du Budget et Services des Retraites de l'Etat	PLFRSS pour 2023 - Direction du Budget et Services des Retraites de l'Etat	2023-02-07 17:45:00	2023-02-07 18:30:00	\N	\N	1	0	\N	\N
701661	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFRSS pour 2023 - Direction générale du Trésor	PLFRSS pour 2023 - Direction générale du Trésor	2023-02-08 14:15:00	2023-02-08 15:10:00	\N	\N	1	0	\N	\N
701663	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFRSS pour 2023 - COR et Comité de suivi des retraites	PLFRSS pour 2023 - COR et Comité de suivi des retraites	2023-02-08 16:30:00	2023-02-08 17:40:00	\N	\N	1	0	\N	\N
701665	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFRSS pour 2023 - AGIRC-ARRCO	PLFRSS pour 2023 - AGIRC-ARRCO	2023-02-08 17:45:00	2023-02-08 18:35:00	\N	\N	1	0	\N	\N
701667	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFRSS pour 2023 - Caisse de prévoyance et de retraite du personnel de la SNCF (CPRP SNCF)	PLFRSS pour 2023 - Caisse de prévoyance et de retraite du personnel de la SNCF (CPRP SNCF)	2023-02-08 18:35:00	2023-02-08 19:15:00	\N	\N	1	0	\N	\N
701669	COM_EURO	AUDRAP	\N	AFEU	\N	Audition stratégie pharmaceutique - Groupe BMS	\N	2023-02-10 10:00:00	2023-02-10 11:00:00	\N	\N	2	0	\N	\N
701676	ETUDES	AUDRAP	\N	\N	\N	GEAC - Audition de Monsieur Patrick GANDIL, président de l¿Aéro-Club de France	\N	2023-02-01 13:15:00	2023-02-01 14:20:00	\N	\N	7	0	\N	933
701684	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Mission "Recherche et enseignement supérieur" - IRSN	Contrôle 2023 - Mission "Recherche et enseignement supérieur" - IRSN	2023-02-08 16:00:00	2023-02-08 17:00:00	\N	\N	1	0	\N	\N
701708	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI cinéma	\N	2023-02-10 10:00:00	2023-02-10 12:00:00	\N	\N	4	0	\N	\N
701715	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI fraudes	\N	2023-02-08 14:00:00	2023-02-08 15:00:00	\N	\N	1	0	\N	\N
701717	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	fraudes artistiques	\N	2023-02-08 16:30:00	2023-02-08 18:30:00	\N	\N	2	0	\N	\N
701720	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	fraudes artistiques	\N	2023-02-09 11:00:00	2023-02-09 13:00:00	\N	\N	2	0	\N	\N
701722	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI fraudes artistiques	\N	2023-02-09 15:00:00	2023-02-09 16:00:00	\N	\N	1	0	\N	\N
701724	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 15 février 2023	\N	2023-02-15 14:00:00	2023-02-15 15:00:00	2023-02-15 15:00:37	2023-02-15 17:33:51	12	0	\N	\N
701751	COM_PERMANENTE	DEPLACEMENT	\N	SOCI	\N	MI Données de santé - Déplacement à l'AP-HP	\N	2023-02-07 14:00:00	2023-02-07 17:00:00	\N	\N	5	0	\N	\N
701752	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Fin de vie - Table ronde Cancérologie	\N	2023-02-08 16:15:00	2023-02-08 17:30:00	\N	\N	6	0	\N	\N
702702	ETUDES	AUTRE	\N	\N	\N	FACCC	FACCC	2023-02-15 08:00:00	2023-02-15 09:30:00	\N	\N	11	0	\N	907
702706	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	GT Décentralisation - Auditions rapporteurs	GT Décentralisation - Auditions rapporteurs	2023-02-14 16:30:00	2023-02-14 17:30:00	\N	\N	4	0	\N	\N
702759	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Fraude artistique	\N	2023-02-14 18:00:00	2023-02-14 19:00:00	\N	\N	1	0	\N	\N
702807	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	GT Décentralisation 	GT Décentralisation - Auditions rapporteurs	2023-02-14 18:00:00	2023-02-14 19:10:00	\N	\N	2	0	\N	\N
702905	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Gestion différenciée de la compétence « Eau et Assainissement »	PPL Gestion différenciée de la compétence « Eau et Assainissement »	2023-02-15 11:30:00	2023-02-15 12:15:00	\N	\N	1	0	\N	\N
702922	DELEGATION	AUCUNE	\N	\N	211	Table ronde Santé des femmes au travail (Prévention et santé au travail)	Table ronde Santé des femmes au travail (professionnels de la prévention et santé au travail)	2023-02-16 08:35:00	2023-02-16 10:40:00	\N	\N	7	0	\N	\N
702937	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 15 février 2023	\N	2023-02-15 14:00:00	2023-02-15 15:00:00	\N	\N	0	0	\N	\N
702938	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Réunion GT subsitiarité du 15/02/23	\N	2023-02-15 13:30:00	2023-02-15 13:50:00	\N	\N	3	0	\N	\N
704047	GIA	AUCUNE	\N	\N	\N	Réunion de travail	Programme de travail et présentation du nouveau secrétaire exécutif	2023-02-14 16:15:00	2023-02-14 16:45:00	\N	\N	1	0	586	\N
704156	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PPRE Iran	PPRE Iran	2023-02-14 16:00:00	2023-02-14 17:00:00	\N	\N	1	0	\N	\N
704158	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT 212 LPM 	GT 212 LPM 	2023-02-13 16:00:00	2023-02-13 17:00:00	\N	\N	2	0	\N	\N
704161	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT 212 LPM 	GT 212 LPM	2023-02-13 18:00:00	2023-02-13 19:00:00	\N	\N	2	0	\N	\N
669492	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2023 - Ville - DGCL	PLF 2023 - Ville -DGCL	2022-11-02 18:15:00	2022-11-02 19:00:00	\N	\N	1	0	\N	\N
704207	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Immigration et intégration	Audition rapporteur - PJL Immigration et intégration	2023-02-20 15:00:00	2023-02-20 18:00:00	\N	\N	3	0	\N	\N
704232	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Défense incendie	PPL Défense exétrieur contre l'incendie et territoires ruaux	2023-02-15 08:30:00	2023-02-15 10:00:00	\N	\N	1	0	\N	\N
704233	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Défense incendie	PPL Défense exétrieur contre l'incendie et territoires ruaux	2023-02-15 14:00:00	2023-02-15 14:30:00	\N	\N	1	0	\N	\N
704236	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL coopération de défense avec les Pays-Bas	PJL coopération de défense avec les Pays-Bas	2023-02-23 10:15:00	2023-02-23 11:35:00	\N	\N	1	0	\N	\N
704238	DELEGATION	AUCUNE	\N	\N	PROS	Audition de M. Guillaume Vuillemey sur la démondialisation	\N	2023-03-02 08:30:00	2023-03-02 10:00:00	\N	\N	6	0	\N	\N
704241	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - Service National Universel Audition Mme El HAIRY	Contrôle 2022 - Service National Universel Audition Mme El HAIRY	2023-02-14 16:00:00	2023-02-14 17:00:00	\N	\N	1	0	\N	\N
704243	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - Service national universel Audition Mme TRELLU-KANE, présidente UNIS-CITE	Contrôle 2022 - Service national universel Audition Mme TRELLU-KANE, présidente UNIS-CITE	2023-02-14 10:00:00	2023-02-14 10:30:00	\N	\N	1	0	\N	\N
704245	MISSION	AUCUNE	\N	AVENCOMM	\N	Table rondu sur la crise de vocation des maires	Table rondu sur la crise de vocation des maires	2023-03-01 18:00:00	2023-03-01 19:45:00	2023-03-01 20:32:32	2023-03-02 10:08:23	14	0	\N	\N
704247	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - SNU Audition V. SEGUELA, délégué général Fédération Léo Lagrange	Contrôle 2022 - SNU Audition V. SEGUELA, délégué général Fédération Léo Lagrange	2023-02-14 18:00:00	2023-02-14 19:00:00	\N	\N	1	0	\N	\N
704249	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Financement du cinéma : Table-ronde Exploitants de salle	Contrôle 2023 - Financement du cinéma : Table-ronde Exploitants de salle	2023-02-10 14:45:00	2023-02-10 15:35:00	\N	\N	1	0	\N	\N
704251	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Financement du cinéma : Le film français	Contrôle 2023 - Financement du cinéma : Le film français	2023-02-13 11:00:00	2023-02-13 11:45:00	\N	\N	1	0	\N	\N
704253	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFRSS pour 2023 Audition DG du travail/DG Emploi, formation professionnelle	\N	2023-02-14 14:35:00	2023-02-14 15:30:00	\N	\N	1	0	\N	\N
704255	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFRSS pour 2023 - Audition UNEDIC Pôle Emploi	PLFRSS pour 2023 - Audition UNEDIC Pôle Emploi	2023-02-14 15:30:00	2023-02-14 16:15:00	\N	\N	1	0	\N	\N
704257	DELEGATION	AUTRE	\N	\N	206	Conclusions de l'audition publique sur la réforme du contrôle et de la recherche	\N	2023-02-28 14:00:00	2023-02-28 16:00:00	\N	\N	0	0	\N	\N
704258	DELEGATION	AUCUNE	\N	\N	206	Audition publique sur les innovations technologiques de l'éolien offshore	\N	2023-03-02 10:00:00	2023-03-02 12:30:00	\N	\N	4	0	\N	\N
704268	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFRSS - Audition IGAS et CHRU de Strasbourg	\N	2023-02-23 17:30:00	2023-02-23 18:10:00	\N	\N	2	0	\N	\N
704269	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFRSS pour 2023 - Audition Association nationale des DRH	PLFRSS pour 2023 - Audition Association nationale des DRH	2023-02-15 16:30:00	2023-02-15 17:15:00	\N	\N	1	0	\N	\N
704271	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFRSS pour 2023 - Audition Direction de la sécurité sociale	PLFRSS pour 2023 - Audition Direction de la sécurité sociale	2023-02-15 18:00:00	2023-02-15 19:15:00	\N	\N	1	0	\N	\N
704273	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFRSS pour 2023 - Audition CRPCEN	PLFRSS pour 2023 - Audition CRPCEN	2023-02-16 14:15:00	2023-02-16 15:00:00	\N	\N	1	0	\N	\N
704275	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFRSS pour 2023 - Audition Caisse nationale des Barreaux français	PLFRSS pour 2023 - Audition Caisse nationale des Barreaux français	2023-02-16 15:00:00	2023-02-16 16:00:00	\N	\N	1	0	\N	\N
704277	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - RGA Audition M. LANDAIS Direction Générale du Trésor	Contrôle 2022 - RGA Audition M. LANDAIS Direction Générale du Trésor	2023-02-13 15:00:00	2023-02-13 16:00:00	\N	\N	1	0	\N	\N
704279	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 Cohésion des territoires - ANCT - Audtion Cour des Comptes	58-2 Cohésion des territoires - ANCT - Audtion Cour des Comptes	2023-02-15 13:45:00	2023-02-15 15:00:00	\N	\N	1	0	\N	\N
641403	GIA	AUCUNE	\N	\N	\N	Réunion du groupe d'amitié France-Russie	Réunion du groupe d'amitié France-Russie	2022-04-12 08:30:00	2022-04-12 09:45:00	\N	\N	13	0	608	\N
641420	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2022-04-13 09:00:00	2022-04-13 11:45:00	\N	\N	3	0	\N	\N
641549	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2022- Dotations d'investissement aux CT - Déplacement Chaumont	Contrôle 2022- Dotations d'investissement aux CT - Déplacement Chaumont	2022-04-13 09:00:00	2022-04-13 18:00:00	\N	\N	2	0	\N	\N
641552	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2022- Dotations d'investissement aux CT - Déplacement Strasbourg	Contrôle 2022- Dotations d'investissement aux CT - Déplacement Strasbourg	2022-04-14 09:00:00	2022-04-14 16:00:00	\N	\N	2	0	\N	\N
641555	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022- IGN - AFIGÉO	Contrôle 2022- IGN - AFIGÉO	2022-04-14 10:00:00	2022-04-14 11:30:00	\N	\N	1	0	\N	\N
641557	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	MCC 2022 - Audiovisuel Public - CGEF/DB	\N	2022-04-14 10:30:00	2022-04-14 12:30:00	\N	\N	0	0	\N	\N
641561	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - Maisons France services - Défenseur des droits/Cour des comptes	Contrôle 2022 - Maisons France services - Défenseur des droits/Cour des comptes	2022-04-13 15:45:00	2022-04-13 17:15:00	\N	\N	1	0	\N	\N
641563	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	LPR	\N	2022-05-13 10:30:00	2022-05-13 12:30:00	\N	\N	3	0	\N	\N
641564	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	mise en oeuvre LPR	\N	2022-04-12 14:00:00	2022-04-12 15:00:00	\N	\N	4	0	\N	\N
641576	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	mise en oeuvre LPR	\N	2022-04-14 09:45:00	2022-04-14 10:45:00	\N	\N	4	0	\N	\N
641585	COM_EURO	AUDRAP	\N	AFEU	\N	Audition asile migration	\N	2022-04-06 14:00:00	2022-04-06 15:00:00	\N	\N	2	0	\N	\N
641588	COM_EURO	AUDRAP	\N	AFEU	\N	Audition asile et migration	\N	2022-04-05 09:00:00	2022-04-05 10:00:00	\N	\N	2	0	\N	\N
643205	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2022-05-19 16:30:00	2022-05-19 21:30:00	\N	\N	3	0	\N	\N
643561	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI SPIP	MI SPIP - Auditions	2022-06-01 09:30:00	2022-06-01 10:30:00	\N	\N	2	0	\N	\N
643565	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI SPIP	MI SPIP - Auditions	2022-06-01 10:30:00	2022-06-01 12:30:00	\N	\N	3	0	\N	\N
643569	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI SPIP	MI SPIP - Auditions	2022-06-01 14:30:00	2022-06-01 16:30:00	\N	\N	2	0	\N	\N
643785	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	MCC Délinquance des mineurs - Déplacement à Bordeaux	MCC Délinquance des mineurs - Déplacement à Bordeaux	2022-05-11 06:00:00	2022-05-11 20:00:00	\N	\N	4	0	\N	\N
643790	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Déplacement au centre régional de formation de la police nationale à Draveil	Déplacement au centre régional de formation de la police nationale à Draveil	2022-06-02 09:00:00	2022-06-02 18:00:00	\N	\N	3	0	\N	\N
643794	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI Patrimoine religieux	\N	2022-06-07 09:30:00	2022-06-07 10:45:00	\N	\N	2	0	\N	\N
643797	DELEGATION	AUCUNE	\N	\N	DSOM	Réunion conjointe avec l'AJDOM	\N	2022-06-29 14:00:00	2022-06-29 17:15:00	\N	\N	7	0	\N	\N
643817	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2022-06-15 09:30:00	2022-06-15 11:55:00	2022-07-04 09:54:33	2022-07-04 11:27:25	25	0	\N	\N
643839	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Communication Redevance audiovisuelle	\N	2022-06-08 10:50:00	2022-06-08 12:05:00	2022-06-10 18:02:44	2022-06-10 18:10:22	46	5	\N	\N
644880	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT subsidiarité	GT subsidiarité	2022-06-15 09:45:00	2022-06-15 10:00:00	\N	\N	2	0	\N	\N
659154	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PJL ENR	\N	2022-10-05 14:15:00	2022-10-05 15:00:00	\N	\N	2	0	\N	\N
659159	ETUDES	AUTRE	\N	\N	\N	Audition énergie	\N	2022-10-05 13:30:00	2022-10-05 14:30:00	\N	\N	0	0	\N	906
659166	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Auditions plénières	\N	2022-10-11 14:00:00	2022-10-11 16:40:00	2022-10-11 16:42:46	2022-10-12 09:22:08	31	0	\N	\N
659193	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Auditions plénières	\N	2022-10-12 09:35:00	2022-10-12 11:55:00	2022-10-12 12:18:06	2022-10-12 17:33:54	38	0	\N	\N
659269	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - AEE - DB	PLF pour 2023 - AEE - DB	2022-10-04 15:00:00	2022-10-04 16:00:00	\N	\N	2	0	\N	\N
659275	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 2022 -  Installation des agriculteurs - Cour des comptes	58-2 2022 -  Installation des agriculteurs - Cour des comptes	2022-10-05 17:00:00	2022-10-05 18:30:00	\N	\N	2	0	\N	\N
659278	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2020 - La DCPJ - Déplacement à Paris	Contrôle 2020 - La DCPJ - Déplacement à Paris	2022-10-04 14:30:00	2022-10-04 21:00:00	\N	\N	1	0	\N	\N
659284	ETUDES	AUTRE	\N	\N	\N	GE Montagne - Table ronde Emplois saisonniers	GE Montagne - Table ronde Emplois saisonniers	2022-10-04 16:00:00	2022-10-04 17:35:00	\N	\N	10	0	\N	918
659296	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n° 867 externalités positives forêt - Auteure PPL	PPL n° 867 externalités positives forêt - Auteure PPL	2022-09-28 10:45:00	2022-09-28 11:30:00	\N	\N	1	0	\N	\N
659298	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n° 867 externalités positives forêt - DGPE/DLF/ONF	PPL n° 867 externalités positives forêt - DGPE/DLF/ONF	2022-09-28 14:00:00	2022-09-28 18:30:00	\N	\N	1	0	\N	\N
659354	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n° 867 externalités positives forêt - CNPF	PPL n° 867 externalités positives forêt - CNPF	2022-10-04 08:00:00	2022-10-04 09:00:00	\N	\N	1	0	\N	\N
659355	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL n° 867 externalités positives forêt - Auteure PPL	PPL n° 867 externalités positives forêt - Auteure PPL	2022-10-06 11:00:00	2022-10-06 12:30:00	\N	\N	1	0	\N	\N
659362	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Orientation et programmation du ministère de l'intérieur (amendements)	PJL Orientation et programmation du ministère de l'intérieur (amendements)	2022-10-11 09:05:00	2022-10-11 10:15:00	2022-10-11 10:43:42	2022-10-11 16:29:22	19	2	\N	\N
659369	GIA	AUCUNE	\N	\N	\N	Entretien avec la Communauté colombienne de Paix de San José de Apartado	Entretien avec la Communauté colombienne de Paix de San José de Apartado	2022-10-05 13:30:00	2022-10-05 14:30:00	\N	\N	3	0	979	\N
659423	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL ENR	\N	2022-10-06 09:45:00	2022-10-06 10:30:00	\N	\N	2	0	\N	\N
659426	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL ENR	\N	2022-10-06 10:30:00	2022-10-06 11:00:00	\N	\N	3	0	\N	\N
659430	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL ENR	\N	2022-10-06 11:00:00	2022-10-06 11:45:00	\N	\N	2	0	\N	\N
659434	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL ENR	\N	2022-10-06 16:00:00	2022-10-06 18:30:00	\N	\N	1	0	\N	\N
661619	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PJL ENR	\N	2022-10-11 14:30:00	2022-10-11 18:10:00	\N	\N	2	0	\N	\N
661636	ETUDES	AUTRE	\N	\N	\N	Réunion du Bureau	\N	2022-10-12 14:00:00	2022-10-12 15:00:00	\N	\N	11	0	\N	934
661639	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2023 Autonomie - Audition du CNCPH	\N	2022-10-13 09:00:00	2022-10-13 10:00:00	\N	\N	2	0	\N	\N
661649	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2023 Autonomie - Audition du Synerpa	\N	2022-10-13 10:10:00	2022-10-13 11:00:00	\N	\N	3	0	\N	\N
661650	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du jeudi 13 octobre	\N	2022-10-13 09:00:00	2022-10-13 11:15:00	2022-10-13 11:47:03	2022-10-13 16:15:15	12	0	\N	\N
661670	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PJL ENR	\N	2022-10-12 16:15:00	2022-10-12 17:45:00	\N	\N	2	0	\N	\N
661686	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - DAG - DSAF PM	PLF pour 2023 - DAG - DSAF PM	2022-10-12 11:00:00	2022-10-12 11:45:00	\N	\N	1	0	\N	\N
661689	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - BA POIA - DILA	PLF pour 2023 - BA POIA - DILA	2022-10-12 17:00:00	2022-10-12 17:45:00	\N	\N	1	0	\N	\N
661753	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2023 Autonomie - Audition de la Fnadepa	\N	2022-10-13 11:00:00	2022-10-13 11:55:00	\N	\N	3	0	\N	\N
661788	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2023 LIC	\N	2022-10-13 11:00:00	2022-10-13 12:00:00	\N	\N	1	0	\N	\N
661792	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Delarue	\N	2022-10-13 09:00:00	2022-10-13 10:00:00	\N	\N	1	0	\N	\N
661794	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Menut	\N	2022-10-13 10:00:00	2022-10-13 11:00:00	\N	\N	1	0	\N	\N
661796	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Turck	\N	2022-10-13 11:00:00	2022-10-13 11:50:00	\N	\N	1	0	\N	\N
701615	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI cinéma	\N	2023-02-08 17:30:00	2023-02-08 18:30:00	\N	\N	4	0	\N	\N
738262	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Examen de 3 rapports d'information	\N	2023-06-07 09:50:00	2023-06-07 12:10:00	2023-06-07 15:58:11	2023-06-07 17:26:45	38	7	\N	\N
738263	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de M. Sébastien Lecornu	\N	2023-06-07 16:35:00	2023-06-07 19:00:00	2023-06-08 16:25:31	2023-06-08 16:37:03	30	0	\N	\N
741947	COM_ENQUETE	AUTRE	\N	RENOV	\N	Audition Olivier Klein	\N	2023-06-13 16:00:00	2023-06-13 17:30:00	2023-06-13 19:01:31	2023-06-14 15:28:08	8	0	\N	\N
746091	DELEGATION	AUCUNE	\N	\N	COLTER	Examen du rapport d'information sur les communes nouvelles	\N	2023-06-28 14:00:00	2023-06-28 15:00:00	2023-06-29 12:10:56	\N	19	0	\N	\N
746092	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Réunion du GT subsidiarité du 29 juin 2023	\N	2023-06-29 08:30:00	2023-06-29 09:00:00	\N	\N	0	0	\N	\N
747630	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Premier amendement et protocole à la convention d'Espoo	Premier amendement et protocole à la convention d'Espoo	2023-06-28 14:00:00	2023-06-28 14:50:00	\N	\N	1	0	\N	\N
748094	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Douanes	CMP Douanes	2023-07-03 16:00:00	2023-07-03 17:00:00	\N	\N	32	0	\N	\N
748095	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Code monétaire financier	CMP Code monétaire financier	2023-07-03 17:00:00	2023-07-03 17:45:00	\N	\N	27	0	\N	\N
748098	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Règlement budget et comptes 2021 2022	PJL Règlement budget et comptes 2021 2022	2023-07-03 17:50:00	2023-07-03 19:35:00	\N	\N	38	0	\N	\N
659365	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désignations -  PPL Intervention des cabinets privés - PPLC Droit IVG et contraception	Désignations -  PPL Intervention des cabinets privés - PPLC Droit IVG et contraception	2022-10-12 09:30:00	2022-10-12 11:55:00	2022-10-12 12:25:42	2022-10-12 17:33:54	39	6	\N	\N
748099	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Approbation comptes sécurité sociale 2022	PJL Approbation comptes sécurité sociale 2022	2023-07-03 19:40:00	2023-07-03 21:15:00	\N	\N	36	0	\N	\N
748102	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2023-07-04 09:30:00	2023-07-04 12:40:00	\N	\N	51	0	\N	\N
748103	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Enfants malades 	PPL Enfants malades 	2023-07-04 14:30:00	2023-07-04 16:20:00	\N	\N	95	0	\N	\N
748104	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Espace numérique	PJL Espace numérique	2023-07-04 16:25:00	2023-07-04 19:15:00	\N	\N	110	0	\N	\N
748106	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Espace numérique	PJL Espace numérique	2023-07-04 21:30:00	2023-07-05 00:10:00	\N	\N	50	0	\N	\N
748107	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2023-07-05 15:00:00	2023-07-05 16:25:00	\N	\N	235	0	\N	\N
748108	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Espace numérique	PJL Espace numérique	2023-07-05 16:35:00	2023-07-05 19:25:00	\N	\N	61	0	\N	\N
748110	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Parité dans la haute fonction publique	CMP Parité dans la haute fonction publique	2023-07-06 10:30:00	2023-07-06 11:20:00	\N	\N	7	0	\N	\N
748114	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Espace numérique	PJL Espace numérique	2023-07-07 10:30:00	2023-07-07 13:00:00	\N	\N	0	0	\N	\N
748115	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Espace numérique	PJL Espace numérique	2023-07-07 14:30:00	2023-07-07 20:00:00	\N	\N	0	0	\N	\N
748211	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents 	Conférence des Présidents 	2023-06-14 18:00:00	2023-06-14 18:50:00	\N	\N	23	0	\N	\N
749998	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 224 - Dispositifs Denormandie ancien et Malraux - Audition IGF, IGEDD, IGAC	PLF pour 224 - Dispositifs Denormandie ancien et Malraux - Audition IGF, IGEDD, IGAC	2023-07-05 18:00:00	2023-07-05 19:15:00	\N	\N	1	0	\N	\N
750000	ETUDES	AUDRAP	\N	\N	\N	GEAC - Audition JC. DRAI, directeur France de Volocopter	GEAC - Audition JC. DRAI, directeur France de Volocopter	2023-07-05 13:30:00	2023-07-05 14:30:00	\N	\N	8	0	\N	933
750635	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 59	\N	2023-07-12 09:30:00	2023-07-12 11:29:00	2023-07-12 15:36:47	2023-07-13 11:22:49	28	4	\N	\N
750663	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Ri autonomie établissements scolaires	\N	2023-07-12 09:30:00	2023-07-12 10:40:00	2023-07-12 10:39:51	2023-07-13 11:22:49	24	9	\N	\N
750895	ETUDES	AUCUNE	\N	\N	\N	Audition Marc Fesneau	Audition Marc Fesneau	2023-07-11 17:00:00	2023-07-11 19:00:00	\N	\N	26	0	\N	911
752101	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Déplacement à l'ANTENJ	\N	2023-09-04 14:30:00	2023-09-04 16:30:00	\N	\N	3	0	\N	\N
752105	GIA	AUCUNE	\N	\N	\N	Rencontre avec Etienne de Poncins, ambassadeur de France désigné en Pologne	Rencontre avec Etienne de Poncins, ambassadeur de France désigné en Pologne	2023-09-05 12:30:00	2023-09-05 14:30:00	\N	\N	1	0	600	\N
752232	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI expertise patrimoniale	\N	2023-09-26 09:30:00	2023-09-26 11:45:00	\N	\N	3	0	\N	\N
752236	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI expertise patrimoniale	\N	2023-09-26 13:15:00	2023-09-26 14:00:00	\N	\N	3	0	\N	\N
752240	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI expertise patrimoniale	\N	2023-09-26 15:15:00	2023-09-26 17:45:00	\N	\N	2	0	\N	\N
752285	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Donnée de connexion	Données de connexion	2023-09-26 09:57:00	2023-09-26 10:45:00	\N	\N	1	0	\N	\N
752287	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Données de connexion	\N	2023-09-26 08:30:00	2023-09-26 10:45:00	\N	\N	1	0	\N	\N
753674	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Désignation des rapporteurs budgétaires pour avis	Désignation des rapporteurs budgétaires pour avis	2023-10-11 10:05:00	2023-10-11 10:30:00	2023-10-12 11:53:27	2023-10-12 18:12:59	40	5	\N	\N
753675	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de M. Sébastien Lecornu	Audition de M. Sébastien Lecornu	2023-10-11 16:30:00	2023-10-11 18:30:00	2023-10-12 11:57:10	2023-10-12 18:13:00	34	0	\N	\N
753676	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne 	Réunion constitutive	2023-10-05 12:30:00	2023-10-05 12:50:00	2023-10-06 11:51:25	2023-10-06 16:03:53	8	0	\N	\N
755845	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Audition Binance France Mme CABOSSIORAS et M. PETIT-JEAN	PLF pour 2024 - Audition Binance France Mme CABOSSIORAS et M. PETIT-JEAN	2023-10-11 14:00:00	2023-10-11 15:00:00	\N	\N	1	0	\N	\N
755847	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Audition Assemblée des départements de France	PLF pour 2024 - Audition Assemblée des départements de France	2023-10-11 17:30:00	2023-10-11 18:30:00	\N	\N	1	0	\N	\N
755849	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Audition Association française des entreprises privées (AFEP)	PLF pour 2024 - Audition Association française des entreprises privées (AFEP)	2023-10-10 14:30:00	2023-10-10 15:30:00	\N	\N	1	0	\N	\N
755851	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Audition P. SAINT AMANS	PLF pour 2024 - Audition P. SAINT AMANS ex-directeur du Centre politique et d'administration fiscales de l'OCDE	2023-10-11 16:30:00	2023-10-11 17:30:00	\N	\N	1	0	\N	\N
755853	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Audition Groupama	PLF pour 2024 - Audition Groupama MM. MARTEL et NARBONNE	2023-10-04 09:00:00	2023-10-04 10:00:00	\N	\N	1	0	\N	\N
755855	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Audition M. GARNIER délégué général de l'association AMORCE	PLF pour 2024 - Audition M. GARNIER délégué général de l'association AMORCE	2023-10-10 17:00:00	2023-10-10 18:00:00	\N	\N	1	0	\N	\N
755868	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Ouverture à la concurrence du réseau de bus francilien de la RATP - Audition IDFM	PPL Ouverture à la concurrence du réseau de bus francilien de la RATP - Audition IDFM	2023-10-11 17:50:00	2023-10-11 18:10:00	\N	\N	3	0	\N	\N
755870	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Ouverture à la concurrence du réseau de bus francilien de la RATP - Audition RATP	PPL Ouverture à la concurrence du réseau de bus francilien de la RATP - Audition RATP	2023-10-12 09:35:00	2023-10-12 10:40:00	\N	\N	1	0	\N	\N
755878	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	expertise	\N	2023-10-13 10:15:00	2023-10-13 11:00:00	\N	\N	2	0	\N	\N
755881	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJLF 2024 presse	\N	2023-10-12 08:30:00	2023-10-12 12:30:00	\N	\N	1	0	\N	\N
755882	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJLF cinema	\N	2023-10-11 13:30:00	2023-10-11 14:30:00	\N	\N	1	0	\N	\N
755885	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL écriture inclusive	\N	2023-10-10 09:30:00	2023-10-10 10:30:00	\N	\N	1	0	\N	\N
645004	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Incidents Stade de France - Déplacement au Stade de France	Incidents Stade de France - Déplacement au Stade de France	2022-06-16 13:00:00	2022-06-16 19:00:00	\N	\N	9	0	\N	\N
648432	GIA	AUCUNE	\N	\N	\N	Audition de M. John ILLICH,  CEO SYMBIO	Présentation du projet d'approvisionnement de l'Europe en GNL du Canada	2022-07-12 14:00:00	2022-07-12 15:30:00	\N	\N	4	0	602	\N
648541	GIA	AUCUNE	\N	\N	\N	Petit-déjeuner chargé d'affaires ambassade du Pakistan	\N	2022-07-13 08:15:00	2022-07-13 09:00:00	\N	\N	5	0	619	\N
652898	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Projet de loi de finances rectificative pour 2022 	Projet de loi de finances rectificative pour 2022	2022-08-01 21:30:00	2022-08-02 02:00:00	\N	\N	115	0	\N	\N
652899	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2022-08-02 11:00:00	2022-08-02 12:45:00	\N	\N	26	0	\N	\N
652903	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL de règlement du budget et d'approbation des comptes de l'année 2021	PJL de règlement du budget et d'approbation des comptes de l'année 2021	2022-08-02 14:30:00	2022-08-02 15:30:00	\N	\N	93	0	\N	\N
652904	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Suite du projet de loi de finances rectificative pour 2022	Suite du projet de loi de finances rectificative pour 2022	2022-08-02 21:30:00	2022-08-03 03:50:00	\N	\N	144	0	\N	\N
652906	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Suite du projet de loi de finances rectificative pour 2022	Suite du projet de loi de finances rectificative pour 2022	2022-08-02 15:30:00	2022-08-02 20:00:00	\N	\N	182	0	\N	\N
652907	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Conclusions CMP PJL Fonction publique des communes de Polynésie française	Conclusions CMP PJL Fonction publique des communes de Polynésie française	2022-08-03 14:30:00	2022-08-03 15:25:00	\N	\N	65	0	\N	\N
652908	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Conclusions CMP PJL Mesures d'urgence pour la protection du pouvoir d'achat	Conclusions CMP PJL Mesures d'urgence pour la protection du pouvoir d'achat	2022-08-03 17:30:00	2022-08-03 18:35:00	\N	\N	69	0	\N	\N
652909	SEANCE_PLENIERE	DECL_GVT	\N	\N	\N	Déclaration du Gouvernement - Projet de programme de stabilité pour 2022-2027	Déclaration du Gouvernement - Projet de programme de stabilité pour 2022-2027	2022-08-03 15:25:00	2022-08-03 17:30:00	\N	\N	95	0	\N	\N
652910	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Conclusions CMP PLFR 2022	Conclusions CMP PLFR 2022	2022-08-04 17:00:00	2022-08-04 18:30:00	\N	\N	36	0	\N	\N
652915	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	NL PLFR 2022	NL PLFR 2022	2022-08-06 14:35:00	2022-08-06 20:00:00	\N	\N	0	0	\N	\N
652916	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	NL PLFR 2022	NL PLFR 2022	2022-08-06 21:35:00	2022-08-07 00:00:00	\N	\N	0	0	\N	\N
655233	GIA	AUCUNE	\N	\N	\N	Coopé - Accueil d'une délégation de l'Etat de Californie	Accueil d'une délégation de l'Etat de Californie	2022-07-13 11:00:00	2022-07-13 12:00:00	\N	\N	1	0	590	\N
655235	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Lionel CARRE, Président de l'association France-Finlande	Entretien avec M. Lionel CARRE, Président de l'association France-Finlande	2022-05-24 14:45:00	2022-05-24 15:45:00	\N	\N	1	0	640	\N
655488	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - ONACVG - ONACVG mémoire	Contrôle 2022 - ONACVG - ONACVG mémoire	2022-09-05 14:30:00	2022-09-05 16:00:00	\N	\N	1	0	\N	\N
655496	COM_PERMANENTE	AUTRE	\N	CAE	\N	Examen rapport MCC Chasse	\N	2022-09-14 09:30:00	2022-09-14 10:55:00	2022-09-14 14:21:39	2022-09-19 11:33:39	46	4	\N	\N
655497	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition article 13 ONF	\N	2022-09-14 11:00:00	2022-09-14 12:25:00	2022-09-14 12:44:21	2022-09-19 11:33:38	24	4	\N	\N
656206	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Examen du rapport	\N	2022-09-29 10:30:00	2022-09-29 12:30:00	\N	\N	0	0	\N	\N
656207	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2022 - RGA - Déplacement au Mans	Contrôle 2022 - RGA - Déplacement au Mans	2022-09-27 08:40:00	2022-09-27 17:30:00	\N	\N	1	0	\N	\N
656587	GIA	AUCUNE	\N	\N	\N	Audition de représentants de l'European-American chamber of commerce et de Business France	Audition de représentants de l'European-American chamber of commerce et de Business France Amérique du Nord	2022-09-27 18:00:00	2022-09-27 19:20:00	\N	\N	4	0	590	\N
657997	GIA	AUCUNE	\N	\N	\N	entretien avec S.E. M. Dae Jong YOO, Ambassadeur de la République de Corée	\N	2022-10-05 08:15:00	2022-10-05 09:30:00	\N	\N	6	0	613	\N
659092	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2023 Enssup	\N	2022-10-04 16:00:00	2022-10-04 17:00:00	\N	\N	1	0	\N	\N
662916	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	LOIS	\N	Echange avec les membres du Conseil supérieur de la magistrature	Echange avec les membres du Conseil supérieur de la magistrature	2022-10-18 17:00:00	2022-10-18 19:00:00	\N	\N	1	0	\N	\N
669257	DELEGATION	AUDRAP	\N	\N	206	Audition M. Challeat et M. Lapostolle	\N	2022-10-27 13:30:00	2022-10-27 15:00:00	\N	\N	1	0	\N	\N
669259	DELEGATION	AUDRAP	\N	\N	206	Audition M. Renaud	\N	2022-10-27 15:00:00	2022-10-27 16:00:00	\N	\N	1	0	\N	\N
669261	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Gronfier	\N	2022-10-27 16:00:00	2022-10-27 17:00:00	\N	\N	1	0	\N	\N
669263	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Martinsons	\N	2022-10-27 17:00:00	2022-10-27 18:00:00	\N	\N	1	0	\N	\N
669265	DELEGATION	AUDRAP	\N	\N	206	Audition du CESCO - MNHN	\N	2022-10-21 11:00:00	2022-10-21 12:30:00	\N	\N	1	0	\N	\N
669267	DELEGATION	AUDRAP	\N	\N	206	Audition du Cerema	\N	2022-10-21 14:00:00	2022-10-21 15:30:00	\N	\N	1	0	\N	\N
669269	DELEGATION	AUDRAP	\N	\N	206	Audition de Mme Franchomme	\N	2022-10-21 15:30:00	2022-10-21 16:30:00	\N	\N	1	0	\N	\N
669271	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Vauclair	\N	2022-10-21 16:30:00	2022-10-21 17:30:00	\N	\N	1	0	\N	\N
669274	DELEGATION	AUDRAP	\N	\N	206	Audition de Laurent Bernard	\N	2022-10-20 14:00:00	2022-10-20 15:00:00	\N	\N	2	0	\N	\N
669286	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2022-11-29 16:30:00	2022-11-29 18:30:00	2022-11-29 18:33:58	2022-11-30 17:34:59	31	2	\N	\N
669288	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2022-11-30 09:30:00	2022-11-30 11:00:00	2022-11-30 11:04:59	2022-11-30 17:34:57	31	0	\N	\N
669396	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2023 Recherche	\N	2022-10-25 11:00:00	2022-10-25 12:00:00	\N	\N	1	0	\N	\N
669480	COM_PERMANENTE	AUDRAP	\N	CAE	\N	DIHAL	DIHAL	2022-11-02 16:30:00	2022-11-02 17:15:00	\N	\N	1	0	\N	\N
669486	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2023 - Ville - ANRU	PLF 2023 - Ville - ANRU	2022-11-02 08:00:00	2022-11-02 09:00:00	\N	\N	1	0	\N	\N
669489	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2023 - Ville - ANCT	PLF 2023 - Ville - ANCT	2022-11-02 17:30:00	2022-11-02 18:15:00	\N	\N	1	0	\N	\N
669278	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2022-11-16 09:30:00	2022-11-16 12:30:00	2022-11-16 12:32:56	2022-11-16 17:13:33	40	3	\N	\N
669478	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2022-11-09 09:00:00	2022-11-09 11:30:00	2022-11-09 15:21:06	2022-11-09 17:25:48	43	1	\N	\N
669528	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Association des concessionnaires et prestataires de France	Association des concessionnaires et prestataires de France	2022-11-02 16:00:00	2022-11-02 16:45:00	\N	\N	1	0	\N	\N
669530	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2023 - CGLPL - Syndicat des personnels de l¿administration pénitentiaire	PLF pour 2023 - CGLPL - Syndicat des personnels de l¿administration pénitentiaire	2022-11-02 17:00:00	2022-11-02 19:30:00	\N	\N	2	0	\N	\N
669533	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2023 - Syndicats de directeurs des services pénitentiaires	PLF pour 2023  - Syndicats de directeurs des services pénitentiaires	2022-11-03 09:30:00	2022-11-03 11:10:00	\N	\N	2	0	\N	\N
669534	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2023  - Syndicats des surveillants pénitentiaires	PLF pour 2023  - Syndicats des surveillants pénitentiaires	2022-11-03 13:30:00	2022-11-03 14:45:00	\N	\N	2	0	\N	\N
669545	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition de M. Christophe Mirmand, préfet de la région Provence-Alpes Côte d'Azur	Audition de M. Christophe Mirmand, préfet de la région Provence-Alpes Côte d'Azur	2022-11-03 12:00:00	2022-11-03 12:45:00	\N	\N	1	0	\N	\N
669556	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF 2023 : Missions Agriculture-MIRES-Sécurités et Défense	PLF 2023 : Missions Agriculture-MIRES-Sécurités et Défense	2022-11-08 15:00:00	2022-11-08 18:45:00	2022-11-08 19:28:30	2022-11-09 17:25:43	44	4	\N	\N
701963	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition MI trouble du neurodéveloppement - Audition Pi-PSY	\N	2023-02-14 10:15:00	2023-02-14 11:00:00	\N	\N	2	0	\N	\N
701992	COM_SPECIALE	PLENIERE	\N	CZAN	\N	Audition Régions de France et ministres	\N	2023-02-14 16:15:00	2023-02-14 19:05:00	2023-02-15 09:08:43	2023-02-15 17:33:49	27	0	\N	\N
702016	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2023-03-01 09:30:00	2023-03-01 12:00:00	\N	\N	0	0	\N	\N
704292	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Immigration et intégration	Audition rapporteur - PJL Immigration et intégration	2023-02-23 14:00:00	2023-02-23 18:30:00	\N	\N	2	0	\N	\N
704599	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2023-02-28 16:30:00	2023-02-28 17:00:00	\N	\N	2	0	\N	\N
704752	GIA	AUCUNE	\N	\N	\N	Rencontre avec M. l'Ambassadeur de Grèce	Rencontre avec M. l'Ambassadeur de Grèce en France	2023-03-01 08:30:00	2023-03-01 09:45:00	\N	\N	6	0	591	\N
706137	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI cinéma	\N	2023-03-01 16:30:00	2023-03-01 17:30:00	\N	\N	3	0	\N	\N
706141	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI cinéma	\N	2023-03-01 17:30:00	2023-03-01 19:00:00	\N	\N	3	0	\N	\N
706151	DELEGATION	AUTRE	\N	\N	ENTREPRISES	Table ronde Formation, compétences et attractivité	\N	2023-03-02 09:00:00	2023-03-02 12:45:00	2023-03-02 16:53:11	\N	9	0	\N	\N
706152	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI cinéma	\N	2023-03-07 15:00:00	2023-03-07 17:00:00	\N	\N	2	0	\N	\N
706153	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI cinéma	\N	2023-03-08 14:00:00	2023-03-08 15:00:00	\N	\N	2	0	\N	\N
706156	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI cinéma	\N	2023-03-08 16:30:00	2023-03-08 17:30:00	\N	\N	2	0	\N	\N
706157	MISSION	AUCUNE	\N	LOCA	\N	Audition de M. Alain LAMBERT - Président du CNEN	Audition de M. Alain LAMBERT - Président du CNEN	2023-03-07 16:00:00	2023-03-07 17:20:00	2023-03-14 16:15:20	2023-03-14 16:16:45	19	0	\N	\N
706167	COM_SPECIALE	AUDRAP	\N	CINC	\N	PPL Lutte contre le risque incendie - Auditions Mme Loisier, MM. Rietmann et Martin	PPL Lutte contre le risque incendie - Auditions Mme Loisier, MM. Rietmann et Martin	2023-03-02 09:00:00	2023-03-02 10:00:00	\N	\N	15	0	\N	\N
706193	COM_SPECIALE	AUDRAP	\N	CINC	\N	PPL Lutte contre le risque incendie - Auditions Mme Loisier, MM. Rietmann et Martin	PPL Lutte contre le risque incendie - Auditions Mme Loisier, MM. Rietmann et Martin	2023-03-02 13:30:00	2023-03-02 14:30:00	\N	\N	13	0	\N	\N
706212	COM_SPECIALE	AUDRAP	\N	CINC	\N	PPL Lutte contre le risque incendie - Auditions Mme Loisier, MM. Rietmann et Martin	PPL Lutte contre le risque incendie - Auditions Mme Loisier, MM. Rietmann et Martin	2023-03-02 14:30:00	2023-03-02 15:30:00	\N	\N	7	0	\N	\N
706234	DELEGATION	AUTRE	\N	\N	DSOM	Continuité territoriale : audition de la DGOM, de la DGAC et du ministère de la santé	\N	2023-03-09 08:30:00	2023-03-09 10:30:00	\N	\N	4	0	\N	\N
706238	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-03-03 09:05:00	2023-03-03 09:20:00	2023-03-03 09:19:31	2023-03-03 16:13:33	22	0	\N	\N
706244	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-03-06 09:05:00	2023-03-06 09:25:00	2023-03-06 11:42:55	2023-03-06 17:07:12	12	0	\N	\N
706245	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-03-07 14:00:00	2023-03-07 14:25:00	2023-03-07 14:36:36	2023-03-08 17:31:10	17	1	\N	\N
706384	COM_ENQUETE	PLENIERE	\N	TIKTO	\N	Réunion constitutive	\N	2023-03-08 17:05:00	2023-03-08 18:05:00	2023-03-09 11:25:45	2023-03-09 14:55:10	13	1	\N	\N
706603	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Florent Parmentier, chercheur	Entretien avec M. Florent Parmentier, maître de conférence à Science Po	2023-03-01 13:30:00	2023-03-01 14:15:00	\N	\N	1	0	851	\N
706607	GIA	AUCUNE	\N	\N	\N	Entretien avec S.E. M. Graham Paul	Entretien avec S.E. M. Graham Paul, ambassadeur de France en République de Moldavie	2023-03-01 14:15:00	2023-03-01 15:00:00	\N	\N	1	0	851	\N
710882	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI cinéma	\N	2023-03-08 17:30:00	2023-03-08 18:30:00	\N	\N	2	0	\N	\N
712584	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPLO Compétences de la collectivité de Saint-Barthélemy	PPLO Compétences de la collectivité de Saint-Barthélemy	2023-03-14 14:30:00	2023-03-14 16:05:00	\N	\N	103	0	\N	\N
712585	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Objectifs de « zéro artificialisation nette »	PPL Objectifs de « zéro artificialisation nette »	2023-03-14 16:10:00	2023-03-14 20:00:00	\N	\N	167	0	\N	\N
712587	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Objectifs de « zéro artificialisation nette »	PPL Objectifs de « zéro artificialisation nette »	2023-03-14 21:30:00	2023-03-15 01:30:00	\N	\N	115	0	\N	\N
712588	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2023-03-15 15:00:00	2023-03-15 16:15:00	\N	\N	272	0	\N	\N
712589	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Défense extérieure contre l'incendie et territoires ruraux	PPL Défense extérieure contre l'incendie et territoires ruraux	2023-03-15 16:30:00	2023-03-15 18:45:00	\N	\N	103	0	\N	\N
665144	COM_PERMANENTE	AUDRAP	\N	CDD	\N	GazelÉnergie	GazelÉnergie	2022-10-13 12:15:00	2022-10-13 13:00:00	\N	\N	1	0	\N	\N
706166	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2023-03-08 09:30:00	2023-03-08 10:45:00	2023-03-09 14:24:39	2023-03-09 14:53:59	38	4	\N	\N
706248	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-03-08 11:00:00	2023-03-08 13:00:00	2023-03-08 13:07:39	2023-03-08 17:31:05	35	0	\N	\N
712590	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Représentation des communes au sein des conseils communautaires	PPL Représentation des communes au sein des conseils communautaires	2023-03-15 18:45:00	2023-03-15 20:00:00	\N	\N	60	0	\N	\N
712591	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Conseil européen 23 et 24 mars 2023	Débat Conseil européen 23 et 24 mars 2023	2023-03-15 21:30:00	2023-03-15 23:50:00	\N	\N	31	0	\N	\N
712592	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PLFRSS 2023	CMP PLFRSS 2023	2023-03-16 09:00:00	2023-03-16 10:40:00	\N	\N	186	0	\N	\N
712593	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Allocation logement et habitat non-décent	PPLAllocation logement et habitat non-décent	2023-03-16 10:50:00	2023-03-16 12:10:00	\N	\N	61	0	\N	\N
712594	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Lutte contre la désertification médicale des collectivités	PPL Lutte contre la désertification médicale des collectivités	2023-03-16 14:30:00	2023-03-16 15:20:00	\N	\N	42	0	\N	\N
712595	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Lutte contre la désertification médicale des collectivités	PPL Lutte contre la désertification médicale des collectivités	2023-03-16 12:15:00	2023-03-16 13:00:00	\N	\N	39	0	\N	\N
712596	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Gestion différenciée de la compétence « Eau et Assainissement »	PPL Gestion différenciée de la compétence « Eau et Assainissement »	2023-03-16 16:00:00	2023-03-16 18:00:00	\N	\N	62	0	\N	\N
712597	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Fraudes en matière artistique	PPL Fraudes en matière artistique	2023-03-16 18:00:00	2023-03-16 19:30:00	\N	\N	43	0	\N	\N
713483	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI LPM programme 144	MI LPM programme 144	2023-03-07 17:40:00	2023-03-07 18:40:00	\N	\N	2	0	\N	\N
713829	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Parité dans la fonction publique	Renforcer l'accès des femmes aux responsabilités dans la fonction publique	2023-03-14 11:45:00	2023-03-14 12:30:00	\N	\N	1	0	\N	\N
713859	GIA	AUCUNE	\N	\N	\N	Entretien avec la Délégation pour l'action extérieure des collectivités territoriales 	Entretien avec la Délégation pour l'action extérieure des collectivités territoriales du MEAE	2023-03-14 17:05:00	2023-03-14 18:05:00	\N	\N	5	0	573	\N
713870	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Suite PPL ZAN	\N	2023-03-16 19:30:00	2023-03-16 20:05:00	\N	\N	41	0	\N	\N
714405	COM_ENQUETE	PLENIERE	\N	TIKTO	\N	Audition CE Tiktok	Audition CE Tiktok	2023-03-16 11:00:00	2023-03-16 12:15:00	2023-03-16 15:12:05	2023-03-16 16:20:12	8	0	\N	\N
714829	MISSION	AUDRAP	\N	BATI	\N	TR enseignement catholique	\N	2023-03-14 16:45:00	2023-03-14 18:30:00	\N	\N	4	0	\N	\N
715272	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure du 9 mars 2023	Conseil de Questure du 9 mars 2023	2023-03-09 09:30:00	2023-03-09 10:32:00	\N	\N	3	0	\N	\N
715623	GIA	AUCUNE	\N	\N	\N	Direction d'Asie du MEAE	Entretien avec la direction d'Asie du MEAE	2023-03-15 11:30:00	2023-03-15 12:30:00	\N	\N	3	0	623	\N
716449	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Suite PPL ZAN	\N	2023-03-16 21:35:00	2023-03-17 01:35:00	\N	\N	44	0	\N	\N
661802	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Intervention des cabinets privés (amendements)	PPL Intervention des cabinets privés (amendements)	2022-10-18 14:00:00	2022-10-18 14:20:00	2022-10-18 17:12:31	2022-10-18 17:23:03	16	2	\N	\N
661804	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	ANS	\N	2022-10-13 14:30:00	2022-10-13 16:00:00	\N	\N	2	0	\N	\N
661818	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2023 recherche	\N	2022-10-13 15:00:00	2022-10-13 16:00:00	\N	\N	3	0	\N	\N
661822	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	PLF 2023 - Déplacement au Conseil d'Etat	PLF 2023 - Déplacement au Conseil d'Etat	2022-11-10 12:00:00	2022-11-10 14:00:00	\N	\N	1	0	\N	\N
661845	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2023 - P 178	\N	2022-10-11 10:00:00	2022-10-11 11:15:00	\N	\N	2	0	\N	\N
661848	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2023 - P 178	\N	2022-10-11 15:45:00	2022-10-11 16:30:00	\N	\N	2	0	\N	\N
661851	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2023 - P 178	\N	2022-10-12 11:00:00	2022-10-12 12:00:00	\N	\N	2	0	\N	\N
662930	GIA	AUCUNE	\N	\N	\N	\N	\N	2022-10-12 12:30:00	2022-10-12 13:45:00	\N	\N	1	0	590	\N
664551	DELEGATION	AUTRE	\N	\N	DSOM	Audition de Cyrille Melchior, président du conseil départemental de La Réunion	\N	2022-10-20 16:00:00	2022-10-20 17:00:00	\N	\N	3	0	\N	\N
664554	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Audition UNPLV	\N	2022-10-19 13:30:00	2022-10-19 15:00:00	\N	\N	0	0	\N	\N
664555	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition GT tourisme	\N	2022-10-19 13:30:00	2022-10-19 15:00:00	\N	\N	4	0	\N	\N
664560	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2023 Enssup	\N	2022-10-20 09:00:00	2022-10-20 10:00:00	\N	\N	3	0	\N	\N
664575	ETUDES	AUTRE	\N	\N	\N	TR Filière restauration hors domicile	TR Filière restauration hors domicile	2022-10-20 08:00:00	2022-10-20 10:00:00	\N	\N	10	0	\N	919
664586	DELEGATION	AUTRE	\N	\N	DSOM	Audition de M. Gabriel Serville, président de la collectivité territoriale de Guyane	\N	2022-10-25 16:30:00	2022-10-25 17:30:00	\N	\N	3	0	\N	\N
664634	DELEGATION	AUTRE	\N	\N	DSOM	Auditions sur l'évolution institutionnelle outre-mer	\N	2022-10-27 09:00:00	2022-10-27 10:00:00	\N	\N	5	0	\N	\N
664659	DELEGATION	AUCUNE	\N	\N	206	2ème audition publique sur la chlordécone	\N	2022-10-20 15:05:00	2022-10-20 18:10:00	\N	\N	6	0	\N	\N
664672	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Sécurité des grandes compétitions sportives - Audition de Gérald Darmanin	Sécurité des grandes compétitions sportives - Audition de Gérald Darmanin	2022-10-25 16:30:00	2022-10-25 18:10:00	2022-10-26 10:55:23	2022-10-26 15:10:36	50	0	\N	\N
664676	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions DAP et APIJ	Auditions Direction de l'administration pénitentiaire et Agence publique pour l¿immobilier de la justice	2022-10-17 17:00:00	2022-10-17 19:00:00	\N	\N	1	0	\N	\N
664678	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition 	Audition 	2022-10-19 16:45:00	2022-10-19 18:45:00	\N	\N	2	0	\N	\N
664681	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Audition de la Cour de justice de la République	Audition de la Cour de justice de la République	2022-10-17 18:10:00	2022-10-17 19:30:00	\N	\N	1	0	\N	\N
664754	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2023 Assurance maladie - Audition de la DSS	\N	2022-10-20 11:00:00	2022-10-20 12:00:00	\N	\N	2	0	\N	\N
664874	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Compte-rendu de la JDE - Examen du rapport sur la RSE	\N	2022-10-27 09:30:00	2022-10-27 10:45:00	\N	\N	12	0	\N	\N
664883	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2023 - Équilibres financiers généraux - Audition Cades	\N	2022-10-20 11:00:00	2022-10-20 12:00:00	\N	\N	1	0	\N	\N
665129	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Fédération Environnement Durable / Cérémé	Fédération Environnement Durable / Cérémé	2022-10-12 14:15:00	2022-10-12 15:00:00	\N	\N	3	0	\N	\N
665134	COM_PERMANENTE	AUDRAP	\N	CDD	\N	TR Syndicats agricoles	TR Syndicats agricoles	2022-10-12 18:30:00	2022-10-12 19:30:00	\N	\N	3	0	\N	\N
665139	COM_PERMANENTE	AUDRAP	\N	CDD	\N	TR opérateurs de valorisation énergétique des déchets	TR opérateurs de valorisation énergétique des déchets	2022-10-13 10:30:00	2022-10-13 11:30:00	\N	\N	2	0	\N	\N
665142	COM_PERMANENTE	AUDRAP	\N	CDD	\N	APCA	APCA	2022-10-13 11:30:00	2022-10-13 12:15:00	\N	\N	1	0	\N	\N
665158	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2023 Assurance maladie - Audition de la DGOS	\N	2022-10-20 14:00:00	2022-10-20 15:15:00	\N	\N	2	0	\N	\N
665159	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2023 Assurance maladie - Audition du CNOM	\N	2022-10-20 15:15:00	2022-10-20 16:00:00	\N	\N	2	0	\N	\N
665160	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2023 Assurance maladie - Audition du LEEM	\N	2022-10-20 16:15:00	2022-10-20 17:00:00	\N	\N	3	0	\N	\N
665161	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2023 Assurance maladie - Audition du CEPS	\N	2022-10-20 17:45:00	2022-10-20 18:30:00	\N	\N	1	0	\N	\N
665162	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2023 Assurance maladie - Audition du Snitem	\N	2022-10-20 17:00:00	2022-10-20 17:45:00	\N	\N	2	0	\N	\N
665174	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2023 - Hébergement - Auditions rapporteur	\N	2022-10-25 17:00:00	2022-10-25 19:00:00	\N	\N	1	0	\N	\N
665175	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2023 - Hébergement - Audition rapporteur	\N	2022-10-26 17:00:00	2022-10-26 18:00:00	\N	\N	3	0	\N	\N
665176	COM_PERMANENTE	DEPLACEMENT	\N	SOCI	\N	PLF pour 2023 - Hébergement - Déplacement rapporteur Armée du salut	\N	2022-10-27 10:00:00	2022-10-27 13:00:00	\N	\N	1	0	\N	\N
665177	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Cerema	Cerema	2022-10-21 11:00:00	2022-10-21 12:00:00	\N	\N	1	0	\N	\N
665179	DELEGATION	AUDRAP	\N	\N	206	Audition Inrae	\N	2022-10-14 14:00:00	2022-10-14 15:00:00	\N	\N	1	0	\N	\N
665182	DELEGATION	AUDRAP	\N	\N	206	Audition de la Direction générale de la prévention des risques	\N	2022-10-14 16:00:00	2022-10-14 17:30:00	\N	\N	1	0	\N	\N
665184	DELEGATION	AUDRAP	\N	\N	206	Audition UMR TETIS-INRAE	\N	2022-10-17 14:30:00	2022-10-17 16:00:00	\N	\N	1	0	\N	\N
665186	DELEGATION	AUDRAP	\N	\N	206	Audition ANSES	\N	2022-10-18 17:00:00	2022-10-18 18:00:00	\N	\N	1	0	\N	\N
665188	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Delorme	\N	2022-10-18 18:00:00	2022-10-18 19:00:00	\N	\N	1	0	\N	\N
665190	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Agences de l'eau	Agences de l'eau	2022-10-20 14:00:00	2022-10-20 15:00:00	\N	\N	1	0	\N	\N
665192	COM_PERMANENTE	AUDRAP	\N	CDD	\N	IGN	IGN	2022-10-20 15:00:00	2022-10-20 16:00:00	\N	\N	1	0	\N	\N
665194	DELEGATION	AUDRAP	\N	\N	206	Audition de Mme Dorioz	\N	2022-10-20 09:00:00	2022-10-20 10:00:00	\N	\N	1	0	\N	\N
665196	DELEGATION	AUDRAP	\N	\N	206	Audition de l'ANIA	\N	2022-10-20 10:00:00	2022-10-20 10:45:00	\N	\N	1	0	\N	\N
665198	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Majou et M. Degonde	\N	2022-10-20 11:00:00	2022-10-20 12:15:00	\N	\N	1	0	\N	\N
665200	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Ferreboeuf	\N	2022-10-17 10:15:00	2022-10-17 11:15:00	\N	\N	1	0	\N	\N
665202	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Bouzeghoub	\N	2022-10-17 11:15:00	2022-10-17 12:30:00	\N	\N	1	0	\N	\N
665204	COM_PERMANENTE	AUCUNE	\N	ETRD	\N	Visite salon Euronaval	\N	2022-10-20 07:30:00	2022-10-20 15:10:00	\N	\N	0	0	\N	\N
665205	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLF 2023 - Juridictions administratives et juridictions financières	PJLF 2023 - Juridictions administratives et juridictions financières	2022-10-26 09:00:00	2022-10-26 12:00:00	\N	\N	1	0	\N	\N
665207	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLF 2023 - Juridictions administratives et juridictions financières	PJLF 2023 - Juridictions administratives et juridictions financières	2022-10-26 13:30:00	2022-10-26 15:05:00	\N	\N	1	0	\N	\N
665731	GIA	AUCUNE	\N	\N	\N	entretien avec M. Sujiro SEAM, chef de la délégation de l'Union européenne dans le Pacifiq	entretien avec M. Sujiro SEAM, chef de la délégation de l'Union européenne dans le Pacifique	2022-10-21 10:00:00	2022-10-21 12:00:00	\N	\N	2	0	651	\N
666397	GIA	AUCUNE	\N	\N	\N	Audition Mme Muriel Pernin	Audition de Mme Muriel Pernin, coauteur d'ouvrages sur l'Arménie et le Haut Karabagh	2022-10-26 08:30:00	2022-10-26 09:30:00	\N	\N	9	0	641	\N
667234	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2023 Avis budgétaires "Sécurités"	PLF 2023 Avis budgétaires "Sécurités"	2022-10-26 10:00:00	2022-10-26 11:20:00	\N	\N	2	0	\N	\N
688271	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2022-12-14 17:00:00	2022-12-14 18:00:00	\N	\N	4	0	\N	\N
690394	GIA	AUCUNE	\N	\N	\N	Audition de l'ambassadeur d'Autriche	Audition de SE M. Thomas SCHNOLL	2023-01-11 08:30:00	2023-01-11 10:00:00	\N	\N	6	0	579	\N
690402	GIA	AUCUNE	\N	\N	\N	Réunion de travail sur le programme du groupe d'amitié	\N	2023-01-11 15:20:00	2023-01-11 15:50:00	\N	\N	2	0	609	CHRETORIENT
738335	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	Audition rapporteur - Avis PJL Programmation militaire	2023-06-01 17:00:00	2023-06-01 18:00:00	\N	\N	1	0	\N	\N
738337	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	Audition rapporteur - Avis PJL Programmation militaire	2023-06-01 18:00:00	2023-06-01 19:00:00	\N	\N	1	0	\N	\N
738354	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Auditions P212	Audition P212	2023-05-30 11:00:00	2023-05-30 12:00:00	\N	\N	1	0	\N	\N
738356	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Auditions P212	Auditions P. 212	2023-05-31 14:00:00	2023-05-31 15:00:00	\N	\N	2	0	\N	\N
738386	MISSION	AUDRAP	\N	AVENCOMM	\N	Audition de maires et d'universitaire	Audition de maires et d'universitaire	2023-06-06 08:45:00	2023-06-06 10:50:00	\N	\N	5	0	\N	\N
738387	COM_PERMANENTE	AUTRE	\N	CAE	\N	PPL Plafonnement des indices locatifs	\N	2023-06-06 09:45:00	2023-06-06 10:30:00	2023-06-06 10:37:18	2023-06-06 14:13:37	29	4	\N	\N
738441	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI Expertise	\N	2023-06-06 09:30:00	2023-06-06 10:30:00	\N	\N	2	0	\N	\N
738571	COM_ENQUETE	PLENIERE	\N	RENOV	\N	Table ronde immobilier	\N	2023-06-06 14:15:00	2023-06-06 19:00:00	2023-06-19 18:08:06	2023-06-19 18:10:14	11	0	\N	\N
738671	MISSION	AUDRAP	\N	GEAU	\N	Direction générale de la prévention des risques	\N	2023-06-06 15:40:00	2023-06-06 16:45:00	\N	\N	5	0	\N	\N
738726	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Controle 2023 - Sécurités - Audition Délégation à la sécurité routière	Controle 2023 - Sécurités - Audition Délégation à la sécurité routière	2023-06-01 15:00:00	2023-06-01 17:15:00	\N	\N	1	0	\N	\N
738729	MISSION	AUCUNE	\N	GEAU	\N	Chambres d'agriculture France	\N	2023-06-06 17:00:00	2023-06-06 18:15:00	2023-06-07 11:10:23	2023-06-07 17:26:54	11	0	\N	\N
738738	MISSION	AUCUNE	\N	AVENCOMM	\N	Audition de David Lisnard, président de l'AMF	Audition de David Lisnard, président de l'AMF	2023-06-06 18:20:00	2023-06-06 19:45:00	2023-06-06 20:13:03	2023-06-07 10:34:12	11	0	\N	\N
738757	COM_SPECIALE	PLENIERE	\N	ESNU	\N	Audition de Jean-Noël Barrot, ministre délégué	Audition de Jean-Noël Barrot, ministre délégué	2023-06-08 14:35:00	2023-06-08 16:30:00	2023-06-08 17:55:28	2023-06-19 18:10:15	10	0	\N	\N
665225	COM_PERMANENTE	AUTRE	\N	CDD	\N	\N	\N	2022-11-02 09:15:00	2022-11-02 10:45:00	2022-11-04 12:12:50	2022-11-04 17:52:55	39	1	\N	\N
738440	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Examen de 2 PPL - amdts de séance 	\N	2023-06-14 09:30:00	2023-06-14 09:50:00	2023-06-14 17:11:50	2023-06-15 20:05:47	38	1	\N	\N
738795	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions M. Laurent Somon - PJL Industrie verte	Auditions M. Laurent Somon - PJL Industrie verte	2023-05-25 14:30:00	2023-05-25 16:15:00	\N	\N	1	0	\N	\N
738797	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions M. Laurent Somon - PJL Industrie verte	Auditions M. Laurent Somon - PJL Industrie verte	2023-05-30 09:30:00	2023-05-30 12:45:00	\N	\N	2	0	\N	\N
738800	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions M. Laurent Somon - PJL Industrie verte	Auditions M. Laurent Somon - PJL Industrie verte	2023-05-30 17:15:00	2023-05-30 18:00:00	\N	\N	1	0	\N	\N
738802	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Syndicat des énergies renouvelables - PJL Industrie verte	Syndicat des énergies renouvelables - PJL Industrie verte	2023-05-23 15:00:00	2023-05-23 15:45:00	\N	\N	1	0	\N	\N
738804	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MEDEF - PJL Industrie verte	MEDEF - PJL Industrie verte	2023-05-23 16:15:00	2023-05-23 17:15:00	\N	\N	2	0	\N	\N
738807	COM_PERMANENTE	AUDRAP	\N	CAE	\N	RDV L Somon, S Babary et O Rietmann - PJL Industrie verte	RDV L Somon, S Babary et O Rietmann - PJL Industrie verte	2023-05-23 17:15:00	2023-05-23 18:45:00	\N	\N	1	0	\N	\N
738810	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions M. Laurent Somon  - PJL Industrie verte	Auditions M. Laurent Somon - PJL Industrie verte	2023-05-30 20:00:00	2023-05-30 21:00:00	\N	\N	1	0	\N	\N
738812	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions M. Laurent Somon - PJL Industrie verte	Auditions M. Laurent Somon - PJL Industrie verte	2023-05-31 08:30:00	2023-05-31 10:15:00	\N	\N	1	0	\N	\N
738814	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions M. Laurent Somon - PJL Industrie verte	Auditions M. Laurent Somon - PJL Industrie verte	2023-05-31 14:00:00	2023-05-31 15:00:00	\N	\N	1	0	\N	\N
738816	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition MI Consigne	Audition MI Consigne	2023-05-10 14:00:00	2023-05-10 19:00:00	\N	\N	1	0	\N	\N
738817	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions M. Laurent Somon - PJL Industrie verte	Auditions M. Laurent Somon - PJL Industrie verte	2023-05-31 17:00:00	2023-05-31 18:00:00	\N	\N	1	0	\N	\N
738819	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions M. Laurent Somon - PJL Industrie verte	Auditions M. Laurent Somon - PJL Industrie verte	2023-05-31 20:00:00	2023-05-31 21:00:00	\N	\N	1	0	\N	\N
738827	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions M. Laurent Somon - PJL Industrie verte	Auditions M. Laurent Somon - PJL Industrie verte	2023-06-01 09:00:00	2023-06-01 12:45:00	\N	\N	1	0	\N	\N
738830	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions M. Laurent Somon - PJL Industrie verte	Auditions M. Laurent Somon - PJL Industrie verte	2023-06-01 15:00:00	2023-06-01 18:30:00	\N	\N	1	0	\N	\N
738838	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition CNF - PJL plein emploi	\N	2023-06-06 17:45:00	2023-06-06 18:30:00	\N	\N	4	0	\N	\N
738847	MISSION	AUCUNE	\N	AVENCOMM	\N	Echange de vues sur les orientations du rapport d'information	Echange de vues sur les orientations du rapport d'information	2023-06-07 16:35:00	2023-06-07 18:00:00	2023-06-07 18:02:17	2023-06-08 11:18:14	8	0	\N	\N
747779	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Examen du rapport sur la formation, les compétences et l¿attractivité	\N	2023-06-29 08:30:00	2023-06-29 10:00:00	\N	\N	6	0	\N	\N
747804	DELEGATION	AUCUNE	\N	\N	206	Examen de deux notes scientifiques	\N	2023-06-29 09:05:00	2023-06-29 11:05:00	\N	\N	10	0	\N	\N
747823	COM_ENQUETE	AUTRE	\N	RENOV	\N	Examen du rapport	\N	2023-06-29 10:00:00	2023-06-29 12:00:00	\N	\N	9	1	\N	\N
747854	MISSION	AUCUNE	\N	AVENCOMM	\N	Examen du rapport d'information	Examen du rapport d'information	2023-07-05 16:35:00	2023-07-05 18:20:00	2023-07-05 19:06:09	2023-07-07 16:16:15	12	2	\N	\N
747859	DELEGATION	AUCUNE	\N	\N	206	Audition de l'Institut de radioprotection et de sûreté nucléaire (IRSN) 	\N	2023-06-29 11:15:00	2023-06-29 12:40:00	\N	\N	9	0	\N	\N
747871	COM_SPECIALE	PLENIERE	\N	ESNU	\N	Examen des amendements de séance	Examen des amendements de séance	2023-07-04 13:30:00	2023-07-04 13:50:00	2023-07-04 14:02:54	2023-07-04 14:22:06	0	2	\N	\N
747872	COM_SPECIALE	PLENIERE	\N	ESNU	\N	Suite de l'examen des amendements de séance	Suite de l'examen des amendements de séance	2023-07-04 19:30:00	2023-07-04 21:30:00	\N	\N	0	0	\N	\N
748003	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Agressions dont les enseignants sont victimes - Audtion de Pap Ndiaye	Agressions dont les enseignants sont victimes - Audtion de Pap Ndiaye	2023-07-04 17:30:00	2023-07-04 19:10:00	2023-07-05 12:05:50	2023-07-05 18:21:47	29	0	\N	\N
748004	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Agressions des élus locaux - Audition de Dominique Faure	Agressions des élus locaux - Audition de Dominique Faure	2023-07-05 08:30:00	2023-07-05 09:50:00	2023-07-05 12:29:58	2023-07-05 18:21:46	20	0	\N	\N
748005	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Rapport d'activité de la HATVP - Audition de Didier Migaud	Rapport d'activité de la HATVP - Audition de Didier Migaud	2023-07-05 11:05:00	2023-07-05 12:05:00	2023-07-05 12:30:45	2023-07-05 18:21:43	20	0	\N	\N
748006	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Respect des principes de la République - Audition de Sonia Backès, secrétaire d'État	Respect des principes de la République - Audition de Sonia Backès, secrétaire d'État	2023-07-05 18:10:00	2023-07-05 19:10:00	2023-07-06 15:40:08	2023-07-07 16:14:46	7	0	\N	\N
748064	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Régime juridique des actions de groupe	\N	2023-06-28 17:15:00	2023-06-28 18:00:00	\N	\N	2	0	\N	\N
748092	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-07-03 16:50:00	2023-07-03 17:00:00	2023-07-03 18:03:15	2023-07-04 14:22:04	9	0	\N	\N
748096	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-07-04 14:00:00	2023-07-04 14:05:00	2023-07-04 14:08:50	2023-07-04 14:22:04	9	0	\N	\N
748101	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-07-05 09:05:00	2023-07-05 12:05:00	2023-07-05 12:23:41	2023-07-05 18:21:45	27	0	\N	\N
640005	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Dagia Aka, personnalité d'avenir	Entretien avec M. Dagia Aka, personnalité d'avenir invitée par le Quai d'Orsay	2022-03-24 14:00:00	2022-03-24 15:00:00	\N	\N	1	0	651	\N
642011	COM_PERMANENTE	AUTRE	\N	LOIS	\N	RI Question migratoire - RI Reconnaissance faciale - Bilan de l'application des lois	RI Question migratoire - RI Reconnaissance faciale - Bilan annuel de l'application des lois	2022-05-10 15:30:00	2022-05-10 17:15:00	2022-05-10 17:47:59	2022-05-11 17:34:08	25	3	\N	\N
643065	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2021 - Douane face au trafic de stupéfiants - Déplacement au Havre	Contrôle 2021 - Douane face au trafic de stupéfiants - Déplacement au Havre	2022-05-25 06:15:00	2022-05-25 20:45:00	\N	\N	2	0	\N	\N
643305	GIA	AUCUNE	\N	\N	\N	Rencontre avec M. S. N. QAMAR, ministre du Commerce et de l'Investissement du Pakistan	\N	2022-05-25 10:00:00	2022-05-25 10:30:00	\N	\N	1	0	619	\N
645303	GIA	AUCUNE	\N	\N	\N	Audition de M. Alexandre GARCIA, Ambassadeur de France au Niger	Audition de M. Alexandre GARCIA, Ambassadeur de France au Niger	2022-06-21 15:15:00	2022-06-21 15:45:00	\N	\N	5	0	573	\N
645645	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Hélène Geoffroy, maire de Vaulx-en-Velin	Hélène Geoffroy, maire de Vaulx-en-Velin	2022-05-03 09:30:00	2022-05-03 10:30:00	\N	\N	2	0	\N	\N
645649	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Insee	Insee	2022-05-03 15:00:00	2022-05-03 16:30:00	\N	\N	2	0	\N	\N
645652	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Cerema	Cerema	2022-05-03 16:30:00	2022-05-03 18:00:00	\N	\N	2	0	\N	\N
645660	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Maire de Saint-Dizier	Maire de Saint-Dizier	2022-05-17 16:00:00	2022-05-17 17:30:00	\N	\N	3	0	\N	\N
645664	COM_PERMANENTE	AUDRAP	\N	CAE	\N	USH	USH	2022-05-17 17:30:00	2022-05-17 19:00:00	\N	\N	3	0	\N	\N
645668	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Association Dans6T	Association Dans6T	2022-05-18 09:00:00	2022-05-18 10:00:00	\N	\N	1	0	\N	\N
645670	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Mairie de Tours	Mairie de Tours	2022-05-18 10:00:00	2022-05-18 11:00:00	\N	\N	1	0	\N	\N
645672	COM_PERMANENTE	AUDRAP	\N	CAE	\N	François Lamy	François Lamy	2022-05-18 11:00:00	2022-05-18 12:30:00	\N	\N	1	0	\N	\N
645674	COM_PERMANENTE	AUDRAP	\N	CAE	\N	ANRU	ANRU	2022-05-18 14:00:00	2022-05-18 16:00:00	\N	\N	3	0	\N	\N
645681	COM_EURO	AUDRAP	\N	AFEU	\N	Numérisation de la procédure de visa	Numérisation de la procédure de visa	2022-06-27 10:00:00	2022-06-27 11:00:00	\N	\N	2	0	\N	\N
645706	COM_EURO	AUDRAP	\N	AFEU	\N	Nouveau pacte migration et asile	\N	2022-06-30 14:30:00	2022-06-30 15:30:00	\N	\N	0	0	\N	\N
645811	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	MM. B. Perdreau et G. de Vienne, rapporteurs, JP Chanteau, animateur,Plateforme RSE	\N	2022-07-12 16:00:00	2022-07-12 18:00:00	\N	\N	0	0	\N	\N
645812	COM_PERMANENTE	AUCUNE	\N	AFCL	\N	Visite au Cojop	\N	2022-07-07 15:00:00	2022-07-07 18:00:00	\N	\N	0	0	\N	\N
645917	DELEGATION	AUDRAP	\N	\N	206	Audition de Mme Valérie SCHAFER	\N	2022-06-28 10:00:00	2022-06-28 11:00:00	\N	\N	1	0	\N	\N
645919	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Bruno  STRASSER	\N	2022-06-28 11:00:00	2022-06-28 12:10:00	\N	\N	1	0	\N	\N
645921	DELEGATION	AUDRAP	\N	\N	206	Audition de M. ROUCAIROL et M. LE PAPE-GARDEUX	\N	2022-06-28 15:00:00	2022-06-28 16:00:00	\N	\N	1	0	\N	\N
645992	DELEGATION	AUCUNE	\N	\N	PROS	Audition de l'Insee sur les grands enjeux démographiques de la France	\N	2022-06-29 11:00:00	2022-06-29 12:00:00	2022-06-29 16:13:49	\N	10	0	\N	\N
646253	COM_PERMANENTE	AUTRE	\N	CAE	\N	MCC sécurisation de la chasse	Auditions de représentants allemands et belges	2022-07-01 16:00:00	2022-07-01 18:05:00	2022-07-04 15:58:38	\N	5	0	\N	\N
647951	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Avenir corps diplomatique	\N	2022-05-31 09:00:00	2022-05-31 11:00:00	\N	\N	2	0	\N	\N
660362	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Table ronde sur la situation du Centre national de la musique	\N	2022-10-19 09:30:00	2022-10-19 11:50:00	2022-10-19 12:22:50	2022-10-19 18:04:11	32	0	\N	\N
660365	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition  de Mme Sylvie Retailleau	\N	2022-10-19 16:45:00	2022-10-19 18:30:00	2022-10-20 16:56:02	2022-10-20 17:44:40	19	0	\N	\N
660366	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Engie	Engie	2022-10-11 09:15:00	2022-10-11 10:00:00	\N	\N	2	0	\N	\N
660455	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Sea Shepherd France	Sea Shepherd France	2022-10-11 14:15:00	2022-10-11 15:00:00	\N	\N	1	0	\N	\N
660457	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 -  EFE - DG France Trésor	PLF pour 2023 -  EFE - DG France Trésor	2022-10-10 15:45:00	2022-10-10 17:20:00	\N	\N	1	0	\N	\N
660463	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Recherche - CNRS	PLF pour 2023 - Recherche - CNRS	2022-10-10 11:00:00	2022-10-10 12:00:00	\N	\N	1	0	\N	\N
660465	COM_PERMANENTE	AUDRAP	\N	CDD	\N	TR Entreprises	TR Entreprises	2022-10-11 15:00:00	2022-10-11 16:00:00	\N	\N	2	0	\N	\N
660470	COM_PERMANENTE	AUDRAP	\N	CDD	\N	France Énergie Éolienne	France Énergie Éolienne	2022-10-11 16:00:00	2022-10-11 16:45:00	\N	\N	5	0	\N	\N
660476	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Cohésion des territoires  - DGCL/ANCT/DMAT	PLF pour 2023 - Cohésion des territoires  - DGCL/ANCT/DMAT	2022-10-11 14:00:00	2022-10-11 17:30:00	\N	\N	1	0	\N	\N
660478	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Enseignement supérieur  - UGEI	PLF pour 2023 - Enseignement supérieur  - UGEI	2022-10-12 16:30:00	2022-10-12 17:30:00	\N	\N	1	0	\N	\N
660482	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2023 - Pouvoirs publics - Questeur AN	PLF pour 2023 - Pouvoirs publics - Questeur AN	2022-10-11 13:40:00	2022-10-11 15:20:00	\N	\N	1	0	\N	\N
660675	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Jaureguiberry	\N	2022-10-12 10:30:00	2022-10-12 11:45:00	\N	\N	1	0	\N	\N
661238	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PPL Formation des internes en médecine générale - Réunion plénière	\N	2022-10-18 14:00:00	2022-10-18 14:10:00	2022-10-18 14:12:41	2022-10-18 17:23:03	31	0	\N	\N
661241	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2023 Assurance maladie - Audition de la DGS	\N	2022-10-11 17:00:00	2022-10-11 18:00:00	\N	\N	2	0	\N	\N
661256	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition art 13 de Mme Marie-Anne BARBAT-LAYANI, candidate aux fonctions de présidente AMF	Audition art 13 de Mme Marie-Anne BARBAT-LAYANI, candidate aux fonctions de présidente de l'AMF	2022-10-18 09:05:00	2022-10-18 10:30:00	2022-10-18 12:06:07	2022-10-18 17:23:02	25	0	\N	\N
661259	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PJL Financement de la sécurité sociale pour 2023 - Audition de M. Thomas Fatome	\N	2022-10-19 09:00:00	2022-10-19 10:35:00	2022-10-19 14:36:41	2022-10-19 18:04:12	40	0	\N	\N
661263	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2023 Assurance maladie - Table ronde des fédérations hospitalières	\N	2022-10-12 13:30:00	2022-10-12 15:00:00	\N	\N	12	0	\N	\N
661264	DELEGATION	AUCUNE	\N	\N	211	Cérémonie de remise du Prix 2022 de la délégation aux droits des femmes	Cérémonie de remise du Prix 2022 de la délégation aux droits des femmes	2022-10-25 17:00:00	2022-10-25 18:30:00	\N	\N	13	0	\N	\N
661266	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PJL Financement de la sécurité sociale pour 2023 - Audition de M. Braun	\N	2022-10-19 16:30:00	2022-10-19 18:15:00	2022-10-19 18:21:12	2022-10-20 17:44:37	31	0	\N	\N
661270	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition commune sur les perspectives économiques de la France pour les années 2023 à 2027	Audition commune sur les perspectives économiques de la France pour les années 2023 à 2027	2022-10-19 11:05:00	2022-10-19 12:45:00	2022-10-19 14:12:29	2022-10-19 18:04:09	21	0	\N	\N
645678	COM_PERMANENTE	AUTRE	\N	CAE	\N	Val de Reuil	Val de Reuil	2022-05-10 14:00:00	2022-05-10 18:00:00	2022-06-27 10:55:34	\N	2	0	\N	\N
645682	COM_PERMANENTE	AUTRE	\N	CAE	\N	Valenciennes	Valenciennes	2022-05-19 09:45:00	2022-05-19 17:15:00	2022-06-27 11:20:51	\N	3	0	\N	\N
645691	COM_PERMANENTE	AUTRE	\N	CAE	\N	Nice	Nice	2022-06-14 09:00:00	2022-06-14 16:30:00	2022-06-27 11:26:43	\N	2	0	\N	\N
661261	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-10-19 10:35:00	2022-10-19 12:25:00	2022-10-19 15:51:21	2022-10-19 18:04:10	43	0	\N	\N
661314	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2023 - Équilibres financiers généraux - Audition DSS	\N	2022-10-11 16:00:00	2022-10-11 17:15:00	\N	\N	3	0	\N	\N
716525	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI TND - Audition associations d'autistes	\N	2023-03-20 14:30:00	2023-03-20 16:00:00	\N	\N	3	0	\N	\N
716526	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Mme Chamak	\N	2023-03-21 14:30:00	2023-03-21 15:30:00	\N	\N	3	0	\N	\N
716527	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Auditions associations psychiatrie	\N	2023-03-21 15:30:00	2023-03-21 16:45:00	\N	\N	3	0	\N	\N
716528	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI TND - Audition DGESCO	\N	2023-03-23 09:30:00	2023-03-23 10:30:00	\N	\N	3	0	\N	\N
716529	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI TND - Audition ANECAMSP	\N	2023-03-23 10:30:00	2023-03-23 11:45:00	\N	\N	2	0	\N	\N
716533	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Mission "Recherche et enseignement supérieur" - IRSN Audition CEA	Contrôle 2023 - Mission "Recherche et enseignement supérieur" - IRSN Audition CEA	2023-03-15 16:30:00	2023-03-15 17:30:00	\N	\N	1	0	\N	\N
716535	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Mission "Recherche et enseignement supérieur" - IRSN Audition DGPR	Contrôle 2023 - Mission "Recherche et enseignement supérieur" - IRSN Audition DGPR	2023-03-16 11:30:00	2023-03-16 12:30:00	\N	\N	1	0	\N	\N
716539	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition ARS Pays de la Loire	\N	2023-04-03 15:00:00	2023-04-03 16:00:00	\N	\N	2	0	\N	\N
716547	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Assemblée des départements de France	\N	2023-03-17 11:15:00	2023-03-17 12:45:00	\N	\N	1	0	\N	\N
716549	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Revaloriser le statut de secrétaire de mairie	PPL Revaloriser le statut de secrétaire de mairie	2023-03-16 16:00:00	2023-03-16 18:15:00	\N	\N	2	0	\N	\N
716552	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLC  loi de financement des collectivités territoriales 	PPLC  loi de financement des collectivités territoriales 	2023-03-16 15:30:00	2023-03-16 16:30:00	\N	\N	1	0	\N	\N
716556	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 22 mars 2023	\N	2023-03-22 14:00:00	2023-03-22 15:00:00	2023-03-22 17:49:09	2023-03-22 17:51:12	20	0	\N	\N
716557	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 23 mars 2023	\N	2023-03-23 09:15:00	2023-03-23 11:25:00	2023-03-23 11:24:29	2023-03-24 10:36:11	10	0	\N	\N
716560	MISSION	AUDRAP	\N	GEAU	\N	Audition M. BARRETEAU	\N	2023-03-21 14:30:00	2023-03-21 15:30:00	\N	\N	6	0	\N	\N
716561	MISSION	AUDRAP	\N	GEAU	\N	Table ronde Eau agricole	\N	2023-03-23 11:00:00	2023-03-23 13:00:00	\N	\N	5	0	\N	\N
716562	MISSION	AUDRAP	\N	GEAU	\N	Audition M. Sauquet	\N	2023-03-21 15:30:00	2023-03-21 16:45:00	\N	\N	7	0	\N	\N
716563	MISSION	AUDRAP	\N	GEAU	\N	Audition FNSEA	\N	2023-03-22 14:00:00	2023-03-22 15:00:00	\N	\N	3	0	\N	\N
716564	MISSION	AUDRAP	\N	GEAU	\N	Audition Confédération paysanne	\N	2023-03-22 17:15:00	2023-03-22 18:00:00	\N	\N	3	0	\N	\N
716565	MISSION	AUDRAP	\N	GEAU	\N	Audition Coordination rurale	\N	2023-03-22 18:20:00	2023-03-22 19:05:00	\N	\N	3	0	\N	\N
716567	DELEGATION	AUDRAP	\N	\N	PROS	Audition Espace	\N	2023-03-15 16:30:00	2023-03-15 18:30:00	\N	\N	2	0	\N	\N
717067	GIA	AUCUNE	\N	\N	\N	Déjeuner avec l'Ambassadeur du Pakistan	\N	2023-03-21 13:00:00	2023-03-21 15:00:00	\N	\N	3	0	619	\N
717554	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLC  loi de financement des collectivités territoriales 	PPLC  loi de financement des collectivités territoriales	2023-03-21 16:30:00	2023-03-21 18:30:00	\N	\N	3	0	\N	\N
717570	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLC  loi de financement des collectivités territoriales 	PPLC  loi de financement des collectivités territoriales	2023-03-21 15:30:00	2023-03-21 16:15:00	\N	\N	2	0	\N	\N
718404	GIA	AUCUNE	\N	\N	\N	Réunion de travail avec la DG Trésor	Réunion de travail avec la DgGTrésor	2023-03-22 18:30:00	2023-03-22 19:15:00	\N	\N	2	0	623	\N
718434	GIA	AUCUNE	\N	\N	\N	Audion d'Antoine de Salins	Audition d'Antoine de Salins sur la finance responsable et Mensuram bonam	2023-03-21 19:30:00	2023-03-21 22:15:00	\N	\N	12	0	629	\N
718455	COM_PERMANENTE	AUTRE	\N	AFCL	\N	TR liberté des médias	\N	2023-03-23 09:15:00	2023-03-23 11:25:00	2023-03-23 14:57:21	2023-03-24 10:36:10	10	0	\N	\N
718540	DELEGATION	AUCUNE	\N	\N	PROS	Audition sur ses travaux consacrés à la conversion écologique des Français	\N	2023-03-30 08:35:00	2023-03-30 09:35:00	\N	\N	3	0	\N	\N
718543	DELEGATION	AUCUNE	\N	\N	DSOM	Réunion du jeudi 30 mars 2023	\N	2023-03-30 09:05:00	2023-03-30 11:30:00	\N	\N	12	0	\N	\N
718554	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition d'universitaires sur la réforme de la procédure pénale	Audition d'universitaires sur la réforme de la procédure pénale	2023-03-29 11:15:00	2023-03-29 12:35:00	2023-03-29 12:37:20	2023-03-29 17:17:25	11	0	\N	\N
718557	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Organisation algorithmique du travail - Audition de la DGT	\N	2023-03-21 09:00:00	2023-03-21 09:45:00	\N	\N	1	0	\N	\N
718558	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Organisation algorithmique du travail - Audition de l'Anact	\N	2023-03-21 09:45:00	2023-03-21 10:30:00	\N	\N	1	0	\N	\N
718560	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Organisation algorithmique du travail -  Audition du think tank Leplusimportant	\N	2023-03-21 10:45:00	2023-03-21 11:30:00	\N	\N	1	0	\N	\N
718561	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Organisation algorithmique du travail - Audition de syndicats de livreurs	\N	2023-03-21 16:45:00	2023-03-21 17:45:00	\N	\N	1	0	\N	\N
718562	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Organisation algorithmique du travail - Audition de la Fnae	\N	2023-03-22 13:45:00	2023-03-22 14:30:00	\N	\N	1	0	\N	\N
718563	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Organisation algorithmique du travail - Audition commune de juristes et sociologues	\N	2023-03-22 17:15:00	2023-03-22 18:15:00	\N	\N	1	0	\N	\N
718564	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Fin de vie - Table ronde d'associations	\N	2023-03-21 15:30:00	2023-03-21 17:00:00	\N	\N	4	0	\N	\N
718565	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Fin de vie - Audition d'associations	\N	2023-03-22 13:30:00	2023-03-22 15:00:00	\N	\N	3	0	\N	\N
718582	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Data Act	\N	2023-03-22 17:00:00	2023-03-22 19:15:00	\N	\N	2	0	\N	\N
718587	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Ecole liberté	\N	2023-03-23 09:00:00	2023-03-23 10:00:00	\N	\N	6	0	\N	\N
718606	ETUDES	AUTRE	\N	\N	\N	Table ronde agrivoltaïsme	\N	2023-03-22 08:15:00	2023-03-22 09:30:00	\N	\N	11	0	\N	906
718618	ETUDES	AUTRE	\N	\N	\N	Table logements en montagne	Table logements en montagne	2023-03-22 13:35:00	2023-03-22 14:50:00	\N	\N	5	0	\N	918
718622	MISSION	AUCUNE	\N	AVENCOMM	\N	Tables rondes : maires de la montagne - maires ultramarins	Tables rondes : maires de la montagne - maires ultramarins	2023-03-29 17:00:00	2023-03-29 19:20:00	2023-03-29 19:36:50	2023-03-30 11:54:18	11	0	\N	\N
718627	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Mission Oman/Emirats	\N	2023-03-23 08:30:00	2023-03-23 09:30:00	\N	\N	2	0	\N	\N
718636	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Audition DGRH	\N	2023-03-22 17:30:00	2023-03-22 19:00:00	\N	\N	5	0	\N	\N
718647	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL école de la liberté	\N	2023-03-23 14:00:00	2023-03-23 16:00:00	\N	\N	5	0	\N	\N
718810	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL sécurité sociale-Serbie	\N	2023-03-08 16:00:00	2023-03-08 17:00:00	\N	\N	1	0	\N	\N
718812	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL sécurité sociale-Serbie	\N	2023-03-09 10:15:00	2023-03-09 11:00:00	\N	\N	1	0	\N	\N
718814	GIA	AUCUNE	\N	\N	\N	colloque sur Israël organisé avec Business France 	\N	2023-03-13 09:00:00	2023-03-13 10:00:00	\N	\N	2	0	595	\N
718820	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation de maires ukrainiens	Accueil d'une délégation de maires ukrainiens	2023-03-27 16:00:00	2023-03-27 17:30:00	\N	\N	4	0	530	\N
719010	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL EDF - Audition X. PIECHACZYK, président directoire RTE	PPL EDF - Audition X. PIECHACZYK, président directoire RTE	2023-03-23 09:00:00	2023-03-23 10:00:00	\N	\N	1	0	\N	\N
719038	GIA	AUCUNE	\N	\N	\N	Dîner autour de Christian Chesnot	Dîner autour de Christian Chesnot	2023-03-28 20:00:00	2023-03-28 22:00:00	\N	\N	9	0	597	\N
719048	GIA	AUCUNE	\N	\N	\N	Rencontre avec un expert économique et un représentant du collectif des déposants libanais	Rencontre avec un expert économique et un représentant du collectif des déposants libanais	2023-02-15 13:30:00	2023-02-15 14:30:00	\N	\N	3	0	597	\N
719052	GIA	AUCUNE	\N	\N	\N	rencontre avec Change Lebanon	rencontre avec Change Lebanon	2023-03-16 12:00:00	2023-03-16 13:00:00	\N	\N	1	0	597	\N
719054	GIA	AUCUNE	\N	\N	\N	Audition d'Alain Bifani, économiste, président de la Fondation citoyenne pour le Liban	Audition d'Alain Bifani, économiste,  président de la Fondation citoyenne pour le Liban	2023-04-04 14:00:00	2023-04-04 15:15:00	\N	\N	5	0	597	\N
720145	MISSION	AUDRAP	\N	GEAU	\N	Audition CNRS et Cluster Eau et climat	\N	2023-04-04 16:30:00	2023-04-04 18:30:00	\N	\N	7	0	\N	\N
639006	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	MCC Sécurisation de la chasse-Déplacement en Eure-et-Loir	MCC Sécurisation de la chasse-Déplacement en Eure-et-Loir	2022-03-09 10:00:00	2022-03-09 16:00:00	\N	\N	3	0	\N	\N
641457	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Formation Police Gendarmerie	MI Formation Police Gendarmerie - Auditions	2022-04-12 16:30:00	2022-04-12 19:00:00	\N	\N	3	0	\N	\N
641591	GIA	AUCUNE	\N	\N	\N	M. Sébastien Minot, ambassadeur de France en Namibie	M. Sébastien Minot, ambassadeur de France en Namibie	2022-03-29 17:30:00	2022-03-29 18:45:00	\N	\N	1	0	646	\N
644513	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition MI métropoles Lyon Aix-Marseille-Provence	\N	2022-06-08 09:00:00	2022-06-08 10:00:00	\N	\N	7	0	\N	\N
649253	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	DSOM	Réunion avec M. Jean-François Carenco, ministre des outre-mer	Réunion avec M. Jean-François Carenco, ministre des outre-mer	2022-07-15 15:00:00	2022-07-15 16:00:00	\N	\N	1	0	\N	\N
649286	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	DSOM	Rencontre avec M. Charles Trottmann (AFD)	Rencontre avec M. Charles Trottmann (AFD)	2022-07-19 08:30:00	2022-07-19 09:30:00	\N	\N	5	0	\N	\N
649319	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2022-07-25 14:59:00	2022-07-25 15:55:00	2022-07-25 17:18:25	2022-07-26 17:29:46	25	3	\N	\N
649322	DELEGATION	AUCUNE	\N	\N	206	Réunion constitutive	\N	2022-07-19 17:20:00	2022-07-19 18:25:00	\N	\N	7	0	\N	\N
649348	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions M. Daniel Gremillet	Auditions M. Daniel Gremillet	2022-07-18 16:00:00	2022-07-18 19:30:00	\N	\N	1	0	\N	\N
649434	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 -  ONACVG - ONACVG Solidarité	Contrôle 2022 -  ONACVG - ONACVG Solidarité	2022-07-18 14:30:00	2022-07-18 16:45:00	\N	\N	1	0	\N	\N
649446	COM_PERMANENTE	AUTRE	\N	CAE	\N	Communication inflation - rapport d'information Politique de la ville	\N	2022-07-19 15:40:00	2022-07-19 17:55:00	2022-07-19 18:35:52	2022-07-20 18:40:59	37	2	\N	\N
649448	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL pouvoir d'achat - Institut Montaigne	PJL pouvoir d'achat - Institut Montaigne	2022-07-18 14:30:00	2022-07-18 15:45:00	\N	\N	2	0	\N	\N
651775	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2022-08-02 11:15:00	2022-08-03 12:45:00	2022-08-03 17:34:06	2022-08-03 18:56:32	54	2	\N	\N
652051	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition de M. Roch-Olivier MAISTRE	\N	2022-09-28 09:30:00	2022-09-28 11:30:00	2022-09-28 14:18:03	2022-09-28 16:49:36	23	0	\N	\N
654585	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLFR pour 2022 : Examen amendement du GVT à l'article d'équilibre	PLFR pour 2022 - Examen d'un amendement du Gouvernement à l'article d'équilibre (article 5) 	2022-08-02 21:25:00	2022-08-02 21:30:00	2022-08-03 10:08:57	2022-08-03 18:56:33	21	0	\N	\N
656596	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	Réunion du GT subsidiarité	\N	2022-09-27 14:30:00	2022-09-27 14:50:00	\N	\N	5	0	\N	\N
656877	SEANCE_PLENIERE	OUV_SESSION	\N	\N	\N	Ouverture de la session ordinaire 2022-2023	Ouverture de session ordinaire	2022-10-04 14:30:00	2022-10-04 14:50:00	\N	\N	156	0	\N	\N
656878	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat sur les États généraux de la justice	Débat	2022-10-04 14:50:00	2022-10-04 16:15:00	\N	\N	101	0	\N	\N
656879	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat sur les urgences hospitalières et les soins non programmés	Débat	2022-10-04 16:15:00	2022-10-04 17:45:00	\N	\N	99	0	\N	\N
656880	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat sur la prise en compte des territoires, des savoir-faire et des cultures	Débat	2022-10-04 17:50:00	2022-10-04 19:40:00	\N	\N	51	0	\N	\N
656881	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat sur les conclusions du rapport "Abysses : la dernière frontière ?" 	Débat	2022-10-04 21:30:00	2022-10-04 22:30:00	\N	\N	32	0	\N	\N
656882	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2022-10-05 15:00:00	2022-10-05 16:20:00	\N	\N	305	0	\N	\N
656883	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat d'actualité sur le thème "Atteintes aux droits des femmes et aux droits de l'homme" 	Débat	2022-10-05 16:30:00	2022-10-05 17:45:00	\N	\N	53	0	\N	\N
656884	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat sur la place des outre-mer dans la stratégie maritime nationale	Débat	2022-10-05 17:45:00	2022-10-05 19:20:00	\N	\N	46	0	\N	\N
656885	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL réélection des juges consulaires	PPL réélection des juges consulaires	2022-10-05 19:25:00	2022-10-05 20:05:00	\N	\N	22	0	\N	\N
656886	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat sur les conclusions du rapport "Cinq plans pour reconstruire la souveraineté éco"	Débat sur les conclusions du rapport "Cinq plans pour reconstruire la souveraineté éco"	2022-10-05 21:35:00	2022-10-05 23:40:00	\N	\N	35	0	\N	\N
656887	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2022-10-06 10:30:00	2022-10-06 12:45:00	\N	\N	35	0	\N	\N
656888	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat "Transformer l'essai de l'innovation"	Débat « Transformer l'essai de l'innovation	2022-10-06 14:30:00	2022-10-06 15:50:00	\N	\N	30	0	\N	\N
656889	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat "Quelle place donner aux acteurs du médico-social" 	Débat "Quelle place donner aux acteurs du médico-social" 	2022-10-06 15:55:00	2022-10-06 17:15:00	\N	\N	25	0	\N	\N
656890	CONF_PRES	AUCUNE	\N	\N	\N	\N	\N	2022-10-05 18:30:00	2022-10-05 19:30:00	\N	\N	23	0	\N	\N
656891	CONF_PRES	AUCUNE	\N	\N	\N	\N	\N	2022-09-21 15:00:00	2022-09-21 15:40:00	\N	\N	24	0	\N	\N
661622	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL ENR	\N	2022-10-11 18:10:00	2022-10-11 19:10:00	\N	\N	1	0	\N	\N
661673	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL ENR	\N	2022-10-12 17:45:00	2022-10-12 18:15:00	\N	\N	3	0	\N	\N
661677	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL ENR	\N	2022-10-12 18:30:00	2022-10-12 19:10:00	\N	\N	2	0	\N	\N
664928	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Institut national de l'audiovisuel 	\N	2022-10-20 09:30:00	2022-10-20 10:30:00	\N	\N	2	0	\N	\N
664929	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Radio France	\N	2022-10-20 10:30:00	2022-10-20 11:30:00	\N	\N	1	0	\N	\N
664945	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - AAFAR - DGAL	PLF pour 2023 - AAFAR - DGAL	2022-10-18 16:00:00	2022-10-18 17:15:00	\N	\N	4	0	\N	\N
664977	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - DAG - SGPE	PLF pour 2023 - DAG - SGPE	2022-10-19 14:00:00	2022-10-19 15:00:00	\N	\N	1	0	\N	\N
664982	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Enseignement scolaire - DGRH EN	PLF pour 2023 - Enseignement scolaire - DGRH EN	2022-10-17 14:30:00	2022-10-17 15:30:00	\N	\N	1	0	\N	\N
664987	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Enseignement scolaire - Rectorat de Paris/DGESCO	PLF pour 2023 - Enseignement scolaire - Rectorat de Paris/DGESCO	2022-10-18 14:00:00	2022-10-18 16:00:00	\N	\N	1	0	\N	\N
664991	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2023 - Cohésion des territoires - Déplacement CABMIN Collectivités territoriales	PLF pour 2023 - Cohésion des territoires - Déplacement CABMIN Collectivités territoriales	2022-10-19 13:45:00	2022-10-19 15:00:00	\N	\N	1	0	\N	\N
664998	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - CCE - SJF et AMCC	PLF pour 2023 - CCE - SJF et AMCC	2022-10-19 16:00:00	2022-10-19 16:50:00	\N	\N	1	0	\N	\N
665003	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - BACEA - DGAC/ACNUSA	PLF pour 2023 - BACEA - DGAC/ACNUSA	2022-10-18 15:45:00	2022-10-18 18:00:00	\N	\N	1	0	\N	\N
665008	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Écologie - Transports - SGP/DGAMPA	PLF pour 2023 - Écologie - Transports - SGP/DGAMPA	2022-10-19 16:15:00	2022-10-19 18:00:00	\N	\N	2	0	\N	\N
665013	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Santé - DGS	PLF pour 2023 - Santé - DGS	2022-10-19 16:45:00	2022-10-19 17:50:00	\N	\N	1	0	\N	\N
665015	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2023 Enseignement agricole	\N	2022-10-20 09:00:00	2022-10-20 12:45:00	\N	\N	1	0	\N	\N
665016	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2023 Enseignement agricole	\N	2022-10-20 09:00:00	2022-10-20 12:45:00	\N	\N	0	0	\N	\N
665019	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Travail & emploi - Fnadir et Acteurs compétence/CABMIN Travail	PLF pour 2023 - Travail & emploi - Fnadir et Acteurs compétence/CABMIN Travail	2022-10-20 11:00:00	2022-10-20 13:15:00	\N	\N	2	0	\N	\N
665022	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2023 Presse	\N	2022-10-20 10:30:00	2022-10-20 11:30:00	\N	\N	2	0	\N	\N
665030	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Travail & emploi - DGEFP	PLF pour 2023 - Travail & emploi - DGEFP	2022-10-20 14:30:00	2022-10-20 15:45:00	\N	\N	2	0	\N	\N
694959	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFRSS - Audition CFTC	\N	2023-01-26 15:00:00	2023-01-26 15:45:00	\N	\N	5	0	\N	\N
694960	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFRSS - Audition UNSA	\N	2023-01-26 15:45:00	2023-01-26 17:00:00	\N	\N	3	0	\N	\N
738217	GIA	AUCUNE	\N	\N	\N	Entretien avec Christophe KATSAHIAN	Entretien avec le conseiller politique de l'Ambassade de France en Arménie	2023-05-25 16:00:00	2023-05-25 16:45:00	\N	\N	1	0	1013	CHRETORIENT
738221	GIA	AUCUNE	\N	\N	\N	Entretien avec le ministre des Affaires étrangères de Malaisie	Entretien avec le ministre des Affaires étrangères de Malaisie en présence des ambassadeurs de France et de Malaisie	2023-06-01 12:45:00	2023-06-01 14:15:00	\N	\N	2	0	609	\N
738224	GIA	AUCUNE	\N	\N	\N	Forum économique international sur l'Allemagne 	Forum économique international organisé en partenariat avec Business France	2023-05-25 08:45:00	2023-05-25 15:00:00	\N	\N	2	0	604	\N
738227	GIA	AUCUNE	\N	\N	\N	Déjeuner dans le cadre de la semaine de l'Amérique latine	Déjeuner avec les ambassadeurs et les lauréats des pays de la zone	2023-05-24 12:00:00	2023-05-24 14:15:00	\N	\N	1	0	642	\N
738229	GIA	AUCUNE	\N	\N	\N	Déjeuner dans le cadre de la semaine de l'Amérique latine	Déjeuner avec les ambassadeurs et les lauréats des pays de la zone	2023-05-24 12:00:00	2023-05-24 14:15:00	\N	\N	1	0	576	\N
738231	GIA	AUCUNE	\N	\N	\N	Déjeuner dans le cadre de la semaine de l'Amérique latine	Déjeuner avec les ambassadeurs et les lauréats des pays de la zone	2023-05-24 11:45:00	2023-05-24 14:15:00	\N	\N	3	0	978	\N
738235	GIA	AUCUNE	\N	\N	\N	Déjeuner dans le cadre de la semaine de l'Amérique latine	Déjeuner avec les ambassadeurs et les lauréats des pays de la zone	2023-05-24 11:40:00	2023-05-24 14:15:00	\N	\N	1	0	643	\N
738237	GIA	AUCUNE	\N	\N	\N	Déjeuner dans le cadre de la semaine de l'Amérique latine	Déjeuner avec les ambassadeurs et les lauréats des pays de la zone	2023-05-24 11:40:00	2023-05-24 14:30:00	\N	\N	2	0	979	\N
740445	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Audition commune des représentants du secteur des transports	\N	2023-06-07 16:30:00	2023-06-07 18:00:00	\N	\N	4	0	\N	\N
740517	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation de parlementaires canadiens	Accueil d'une délégation de parlementaires canadiens	2023-06-07 14:00:00	2023-06-07 16:45:00	\N	\N	5	0	583	\N
740538	MECSS	AUDRAP	\N	\N	MECSS	MI Organismes financés par les Robss	\N	2023-06-07 17:30:00	2023-06-07 18:30:00	\N	\N	0	0	\N	\N
740539	MECSS	AUDRAP	\N	\N	MECSS	MI Organismes financés par les Robss	\N	2023-06-07 16:30:00	2023-06-07 17:30:00	\N	\N	0	0	\N	\N
740549	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Réunion du GT subsidiarité du 8 juin 2023	\N	2023-06-08 08:30:00	2023-06-08 09:00:00	\N	\N	0	0	\N	\N
740700	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Transmanche - Audition SEPD	\N	2023-06-08 11:30:00	2023-06-08 12:15:00	\N	\N	2	0	\N	\N
746915	QUESTURE	AUCUNE	\N	\N	\N	Réunion de Questure	Réunion du Conseil de Questure	2023-06-22 09:25:00	2023-06-22 10:15:00	\N	\N	3	0	\N	\N
751761	COM_PERMANENTE	AUTRE	\N	CAE	\N	PJL reconstruction	\N	2023-07-17 16:00:00	2023-07-17 16:45:00	2023-07-17 17:39:01	2023-07-17 18:16:51	13	4	\N	\N
751769	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 60	\N	2023-07-17 15:00:00	2023-07-17 15:20:00	2023-07-17 18:16:55	2023-07-18 17:17:41	10	2	\N	\N
751813	COM_PERMANENTE	AUTRE	\N	CAE	\N	Amendements de séance PJL reconstruction 	\N	2023-07-18 10:00:00	2023-07-18 10:05:00	\N	\N	7	1	\N	\N
751940	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - MI Respect des principes de la République	Audition rapporteur - MI Principes de la République	2023-07-18 15:00:00	2023-07-18 17:00:00	\N	\N	2	0	\N	\N
751943	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Données	MI Données de connexion	2023-07-18 14:00:00	2023-07-18 16:00:00	\N	\N	3	0	\N	\N
751947	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Données de connexion	MI Données de connexion	2023-07-18 16:40:00	2023-07-18 18:40:00	\N	\N	3	0	\N	\N
751976	COM_PERMANENTE	DEPLACEMENT	\N	SOCI	\N	MI Données de santé - Déplacement à Bruxelles	\N	2023-06-08 08:00:00	2023-06-08 20:00:00	\N	\N	2	0	\N	\N
751981	COM_PERMANENTE	DEPLACEMENT	\N	SOCI	\N	MI Données de santé - Déplacement au Health Data Hub	\N	2023-06-19 14:30:00	2023-06-19 17:00:00	\N	\N	1	0	\N	\N
751983	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Données de santé - Audition de M. Jérôme Marchand-Arvier	\N	2023-07-11 10:15:00	2023-07-11 11:00:00	\N	\N	1	0	\N	\N
751997	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2023-07-11 18:00:00	2023-07-11 18:45:00	\N	\N	21	0	\N	\N
752021	QUESTURE	AUCUNE	\N	\N	\N	Réunion de Questure	Réunion du Conseil de Questure	2023-07-13 08:30:00	2023-07-13 10:00:00	\N	\N	0	0	\N	\N
752400	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	session annuelle AP Otan - Copenhague	session annuelle AP Otan - Copenhague	2023-10-06 09:00:00	2023-10-09 23:00:00	\N	\N	4	0	\N	\N
753648	GIA	AUCUNE	\N	\N	\N	réception  à l'occasion de la fête nationale de Taïwan	réception à l'occasion de la fête nationale de Taïwan	2023-10-04 18:00:00	2023-10-04 20:00:00	\N	\N	7	0	623	\N
754527	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition Benoit Bazin (Saint-Gobain)	\N	2023-10-11 09:30:00	2023-10-11 12:00:00	2023-10-25 16:24:11	2023-10-25 16:25:31	41	0	\N	\N
755106	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition AFRA	Audition AFRA	2023-10-10 14:00:00	2023-10-10 14:45:00	\N	\N	2	0	\N	\N
755107	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition SNCF Gares & Connexions	Audition SNCF Gares & Connexions	2023-10-10 14:45:00	2023-10-10 15:30:00	\N	\N	3	0	\N	\N
755108	COM_PERMANENTE	AUDRAP	\N	CDD	\N	France urbaine	\N	2023-10-10 15:30:00	2023-10-10 16:15:00	\N	\N	0	0	\N	\N
755109	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Union des Transports Publics et ferroviaires	\N	2023-10-10 16:15:00	2023-10-10 17:00:00	\N	\N	0	0	\N	\N
755110	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Eurométropole de Strasbourg	\N	2023-10-10 17:00:00	2023-10-10 17:30:00	\N	\N	0	0	\N	\N
755111	COM_PERMANENTE	AUDRAP	\N	CDD	\N	GART - FIF	\N	2023-10-10 17:30:00	2023-10-10 18:00:00	\N	\N	0	0	\N	\N
755424	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-10-17 14:00:00	2023-10-17 14:25:00	2023-10-17 15:14:25	2023-10-17 17:57:41	21	3	\N	\N
755515	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Auditions plénières	\N	2023-10-18 08:30:00	2023-10-18 11:00:00	2023-10-18 11:00:01	2023-10-18 18:17:10	40	2	\N	\N
755702	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Accès aux soins - Table ronde des syndicats infirmiers libéraux	\N	2023-10-05 15:00:00	2023-10-05 16:15:00	\N	\N	1	0	\N	\N
755703	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Accès aux soins - Table ronde des organisations étudiantes	\N	2023-10-05 16:15:00	2023-10-05 17:15:00	\N	\N	2	0	\N	\N
755704	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Accès aux soins - Audition de la DGOS	\N	2023-10-06 14:30:00	2023-10-06 15:30:00	\N	\N	3	0	\N	\N
755705	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Accès aux soins - Audition du SNPadhue	\N	2023-10-06 15:30:00	2023-10-06 16:15:00	\N	\N	2	0	\N	\N
755857	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	NL PJL Programmation des finances publiques pour les années 2023 à 2027 	NL PJL Programmation des finances publiques pour les années 2023 à 2027 	2023-10-16 16:00:00	2023-10-16 20:40:00	\N	\N	59	0	\N	\N
755859	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Partage de la valeur au sein de l'entreprise	PJL Partage de la valeur au sein de l'entreprise	2023-10-17 14:30:00	2023-10-17 20:30:00	\N	\N	180	0	\N	\N
755860	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Partage de la valeur au sein de l'entreprise	PJL Partage de la valeur au sein de l'entreprise	2023-10-17 21:30:00	2023-10-17 23:59:00	\N	\N	0	0	\N	\N
755861	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2023-10-18 15:00:00	2023-10-18 16:20:00	\N	\N	316	0	\N	\N
755887	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL écriture	\N	2023-10-12 11:00:00	2023-10-12 12:30:00	\N	\N	3	0	\N	\N
755888	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL écriture 	\N	2023-10-12 14:00:00	2023-10-12 15:00:00	\N	\N	2	0	\N	\N
755965	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL écriture inclusive	\N	2023-10-16 11:05:00	2023-10-16 11:45:00	\N	\N	3	0	\N	\N
756069	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MCC signalement et le traitement des pressions, menaces et agressions dont les enseignants	\N	2023-10-16 16:10:00	2023-10-16 17:40:00	\N	\N	12	0	\N	\N
642067	MECSS	AUCUNE	\N	\N	MECSS	Audition plénière de T. Fatôme	\N	2022-05-10 15:15:00	2022-05-10 16:15:00	2022-05-10 16:34:27	2022-05-11 17:34:08	17	0	\N	\N
642105	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Auditions rapporteurs sur la responsabilité sociétale des entreprises (RSE)	Auditions rapporteurs sur la responsabilité sociétale des entreprises (RSE)	2022-05-04 09:30:00	2022-05-04 10:30:00	\N	\N	0	0	\N	\N
643969	GIA	AUCUNE	\N	\N	\N	Rencontre avec S E Mme Corina Calugaru, ambassadrice de Moldavie en France	Rencontre avec S E Mme Corina Calugaru, ambassadrice de la République de Moldavie en France	2022-06-08 08:30:00	2022-06-08 10:00:00	\N	\N	2	0	851	\N
645512	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Formation Police Gendarmerie	\N	2022-06-21 15:30:00	2022-06-21 18:30:00	\N	\N	3	0	\N	\N
645515	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Formation Police Gendarmerie	\N	2022-06-22 16:00:00	2022-06-22 18:55:00	\N	\N	2	0	\N	\N
648404	GIA	AUCUNE	\N	\N	\N	Accueil de l'Ambassadrice à l'occasion de la journée mondiale des abeilles	Accueil de l'Ambassadrice à l'occasion de la journée mondiale des abeilles	2022-07-12 14:45:00	2022-07-12 17:30:00	\N	\N	3	0	529	\N
648779	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Veille et sécurité sanitaire contre la covid-19 (désignation CMP et rapport)	PJL Veille et sécurité sanitaire contre la covid-19 (désignation CMP et rapport)	2022-07-19 09:00:00	2022-07-19 10:55:00	2022-07-19 12:27:08	2022-07-19 18:27:36	30	3	\N	\N
648781	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Communication sur les stages en juridictions	Communication sur les stages en juridictions	2022-07-20 10:00:00	2022-07-20 11:20:00	2022-07-20 13:39:36	2022-07-20 18:40:57	35	1	\N	\N
648782	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Nomination article 13 - Présidence de la CADA - Audition de Bruno Lasserre	Nomination article 13 - Présidence de la CADA - Audition de Bruno Lasserre	2022-07-20 11:20:00	2022-07-20 12:25:00	2022-07-20 13:41:39	2022-07-20 18:40:54	29	2	\N	\N
648783	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Veille et sécurité sanitaire en matière de lutte contre la covid-19  (amendements)	PJL Veille et sécurité sanitaire en matière de lutte contre la covid-19  (amendements)	2022-07-20 14:20:00	2022-07-20 14:50:00	2022-07-20 14:55:33	2022-07-20 18:40:53	24	1	\N	\N
648790	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-07-19 09:45:00	2022-07-19 11:05:00	2022-07-19 11:06:28	2022-07-19 18:27:36	29	0	\N	\N
648800	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-07-20 09:05:00	2022-07-20 11:05:00	2022-07-20 11:52:37	2022-07-20 18:40:57	36	0	\N	\N
752026	CMP	AUTRE	\N	PLPM	\N	LPM 2024-2030	LPM 2024-2030	2023-07-10 10:37:00	2023-07-10 16:11:00	\N	\N	9	0	\N	\N
755537	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-10-18 11:00:00	2023-10-18 12:25:00	2023-10-18 12:45:04	2023-10-18 18:17:04	42	3	\N	\N
648811	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - DGCCRF - DG DGCCRF	Contrôle 2022 - DGCCRF - DG DGCCRF	2022-07-12 14:30:00	2022-07-12 16:45:00	\N	\N	2	0	\N	\N
648814	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFR pour 2022 - ARTE France	PLFR pour 2022 - ARTE France	2022-07-12 15:00:00	2022-07-12 16:00:00	\N	\N	1	0	\N	\N
649043	COM_EURO	AUDRAP	\N	AFEU	\N	Audition de l'Agence européenne des médicaments	\N	2022-07-18 10:00:00	2022-07-18 11:00:00	\N	\N	2	0	\N	\N
649046	COM_EURO	AUDRAP	\N	AFEU	\N	Audition de la Commission européenne	\N	2022-07-18 11:00:00	2022-07-18 12:00:00	\N	\N	2	0	\N	\N
649061	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 21 juillet 2022 (2)	\N	2022-07-21 10:05:00	2022-07-21 11:10:00	2022-07-21 17:35:45	2022-07-22 10:42:21	13	0	\N	\N
649065	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du jeudi 21 juillet 2022 (1)	\N	2022-07-21 08:00:00	2022-07-21 09:55:00	2022-07-21 09:56:45	2022-07-21 14:44:39	14	0	\N	\N
649089	COM_PERMANENTE	AUTRE	\N	FINC	\N	Contrôle budgétaire l'intégration d'Expertise France à l¿AFD - PJLR 2021 : Examen rapport	Contrôle budgétaire l'intégration d'Expertise France à l¿AFD - PJLR 2021 : Examen du rapport et désignation CMP	2022-07-19 09:00:00	2022-07-19 10:15:00	2022-07-19 10:43:36	2022-07-19 18:27:35	33	3	\N	\N
649090	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition Inflation et pouvoir d'achat - Contrôles Régimes Marins & RATP-Investissements CT	Audition sur l'inflation et du pouvoir d'achat - Contrôles budgétaires Régimes Marins & RATP et Investissements aux C.T.	2022-07-20 09:00:00	2022-07-20 12:50:00	2022-07-20 13:44:04	2022-07-20 18:40:58	33	1	\N	\N
656120	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Orientation et programmation du ministère de l'intérieur	Audition rapporteur - PJL LOPMI	2022-09-21 15:00:00	2022-09-21 16:00:00	\N	\N	4	0	\N	\N
656125	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	Audition rapporteur - PJL LOPMI	2022-09-21 17:30:00	2022-09-21 18:30:00	\N	\N	3	0	\N	\N
656129	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Orientation et programmation du ministère de l'intérieur	Audition rapporteur - PJL LOPMI	2022-09-21 18:30:00	2022-09-21 19:30:00	\N	\N	4	0	\N	\N
656134	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Orientation et programmation du ministère de l'intérieur	Audition rapporteur - PJL LOPMI	2022-09-22 08:00:00	2022-09-22 09:00:00	\N	\N	5	0	\N	\N
656140	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Orientation et programmation du ministère de l'intérieur	Audition rapporteur - PJL LOPMI	2022-09-22 09:00:00	2022-09-22 10:00:00	\N	\N	6	0	\N	\N
656147	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Orientation et programmation du ministère de l'intérieur	Audition rapporteur - PJL LOPMI	2022-09-22 10:00:00	2022-09-22 11:00:00	\N	\N	4	0	\N	\N
656153	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Orientation et programmation du ministère de l'intérieur	Audition rapporteur - PJL LOPMI	2022-09-22 11:00:00	2022-09-22 11:45:00	\N	\N	3	0	\N	\N
661824	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2023 JVA	\N	2022-10-13 11:00:00	2022-10-13 11:30:00	\N	\N	1	0	\N	\N
661825	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Audition JVA PLF 2023	\N	2022-10-13 10:00:00	2022-10-13 11:00:00	\N	\N	3	0	\N	\N
661826	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2023 Enseignement agricole	\N	2022-10-13 09:00:00	2022-10-13 10:00:00	\N	\N	1	0	\N	\N
661844	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 20 octobre 2022	\N	2022-10-20 08:35:00	2022-10-20 10:30:00	2022-10-20 12:01:05	2022-10-20 17:44:56	13	0	\N	\N
661854	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - AEE - Cab MEAE	PLF pour 2023 - AEE - Cab MEAE	2022-10-10 15:00:00	2022-10-10 16:00:00	\N	\N	2	0	\N	\N
661857	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - APD - DB	PLF pour 2023 - APD - DB	2022-10-13 14:00:00	2022-10-13 15:00:00	\N	\N	2	0	\N	\N
661860	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - APD - Cab SE développement	PLF pour 2023 - APD - Cab SE développement	2022-10-13 16:00:00	2022-10-13 17:00:00	\N	\N	2	0	\N	\N
661863	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Solidarité - DGCS	PLF pour 2023 - Solidarité - DGCS	2022-10-11 14:00:00	2022-10-11 15:30:00	\N	\N	2	0	\N	\N
661866	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Défense - EMM	PLF pour 2023 - Défense - EMM	2022-10-11 16:00:00	2022-10-11 17:00:00	\N	\N	1	0	\N	\N
661868	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Solidarité - FranceAgriMer	PLF pour 2023 - Solidarité - FranceAgriMer	2022-10-12 17:30:00	2022-10-12 18:30:00	\N	\N	2	0	\N	\N
661871	COM_PERMANENTE	AUDRAP	\N	FINC	\N	LPFP pour 2023 à 2027 - TR associations Élus	LPFP pour 2023 à 2027 - TR associations Élus	2022-10-13 10:30:00	2022-10-13 12:00:00	\N	\N	2	0	\N	\N
661874	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Solidarité - DFAS	PLF pour 2023 - Solidarité - DFAS	2022-10-13 16:30:00	2022-10-13 17:30:00	\N	\N	2	0	\N	\N
661877	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - CCE - Syndicats magistrats administratifs	PLF pour 2023 - CCE - Syndicats magistrats administratifs	2022-10-12 16:30:00	2022-10-12 17:30:00	\N	\N	1	0	\N	\N
661879	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2023 - CCE - Déplacement Cour des comptes	PLF pour 2023 - CCE - Déplacement Cour des comptes	2022-10-13 10:45:00	2022-10-13 13:00:00	\N	\N	1	0	\N	\N
661881	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Écologie - SER	PLF pour 2023 - Écologie - SER	2022-10-12 11:50:00	2022-10-12 12:50:00	\N	\N	1	0	\N	\N
661883	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - BACEA - PDG ADP	PLF pour 2023 - BACEA - PDG ADP	2022-10-13 16:30:00	2022-10-13 17:45:00	\N	\N	1	0	\N	\N
661885	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - AAFAR - JA/DGPE/FNSEA/Interfel	PLF pour 2023 - AAFAR - JA/DGPE/FNSEA/Interfel	2022-10-11 14:00:00	2022-10-11 18:00:00	\N	\N	2	0	\N	\N
661888	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	PLF 2023 - Déplacement à la Cour nationale du droit d'asile	PLF 2023 - Déplacement à la Cour nationale du droit d'asile	2022-10-27 10:30:00	2022-10-27 12:30:00	\N	\N	1	0	\N	\N
690693	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Protéger les logements contre l'occupation illicite	PPL Protéger les logements contre l'occupation illicite	2023-01-11 17:00:00	2023-01-11 19:00:00	\N	\N	2	0	\N	\N
690696	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Protéger les logements contre l'occupation illicite	PPL Protéger les logements contre l'occupation illicite	2023-01-13 15:00:00	2023-01-13 16:30:00	\N	\N	1	0	\N	\N
690697	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Protéger les logements contre l'occupation illicite	PPL Protéger les logements contre l'occupation illicite	2023-01-17 14:45:00	2023-01-17 17:05:00	\N	\N	2	0	\N	\N
702333	GIA	AUCUNE	\N	\N	\N	entretien avec la délégation colombienne de défenseurs des droits humains 	\N	2023-02-14 15:00:00	2023-02-14 16:30:00	\N	\N	1	0	979	\N
720146	MISSION	AUDRAP	\N	GEAU	\N	Audition rapporteur	\N	2023-04-05 14:00:00	2023-04-05 15:00:00	\N	\N	8	0	\N	\N
720147	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Mission "Solidarité, insertion et égalité des chances" - Audition DGCS	Contrôle 2023 - Mission "Solidarité, insertion et égalité des chances" - Audition DGCS	2023-03-30 09:30:00	2023-03-30 11:30:00	\N	\N	2	0	\N	\N
720148	MISSION	AUDRAP	\N	GEAU	\N	Auditions rapporteur - Etangs de France et Académie de l'eau	\N	2023-04-05 16:30:00	2023-04-05 19:05:00	\N	\N	5	0	\N	\N
720152	COM_PERMANENTE	AUDRAP	\N	CDD	\N	CMA	\N	2023-03-27 17:00:00	2023-03-27 18:00:00	\N	\N	1	0	\N	\N
720154	MISSION	AUTRE	\N	GEAU	\N	Table ronde Gestion de l'eau et innovation	\N	2023-04-06 11:00:00	2023-04-06 12:30:00	2023-04-06 15:36:39	2023-04-06 17:48:21	3	0	\N	\N
720157	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Secours catholique	\N	2023-03-28 14:30:00	2023-03-28 15:15:00	\N	\N	2	0	\N	\N
720160	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Table ronde Fédération transporteurs	\N	2023-03-28 16:00:00	2023-03-28 17:00:00	\N	\N	2	0	\N	\N
720163	COM_PERMANENTE	AUDRAP	\N	CDD	\N	MOBILIANS	\N	2023-03-28 17:00:00	2023-03-28 17:45:00	\N	\N	2	0	\N	\N
720166	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Programme de contrôle - 2023 - RG rapport public et programmes Cour des comptes	Programme de contrôle - 2023 - RG rapport public et programmes Cour des comptes	2023-03-29 16:30:00	2023-03-29 17:15:00	\N	\N	1	0	\N	\N
720168	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Financement du cinéma : Direction législation fiscale	Contrôle 2023 - Financement du cinéma : Direction législation fiscale	2023-03-27 16:00:00	2023-03-27 16:30:00	\N	\N	1	0	\N	\N
720170	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Financement du cinéma : Direction générale finances publiques	Contrôle 2023 - Financement du cinéma : Direction générale finances publiques	2023-03-27 17:00:00	2023-03-27 17:30:00	\N	\N	1	0	\N	\N
720174	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Mission "Cultur" - Genèse Pass Culture Audition JM. LUCAS	Contrôle 2023 - Mission "Cultur" - Genèse Pass Culture Audition JM. LUCAS	2023-03-29 14:00:00	2023-03-29 14:45:00	\N	\N	2	0	\N	\N
720181	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Financement du cinéma : Association de représentation des SOFICA	Contrôle 2023 - Financement du cinéma : Association de représentation des SOFICA	2023-03-31 11:00:00	2023-03-31 12:00:00	\N	\N	1	0	\N	\N
720185	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 Engagements financiers de l'Etat - Risque PGE Audition Banque de France	Contrôle 2023 Engagements financiers de l'Etat - Risque PGE Audition Banque de France	2023-03-30 14:00:00	2023-03-30 15:30:00	\N	\N	1	0	\N	\N
720187	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 Engagements financiers de l'Etat - Risque PGE Audition Fédération bancaire	Contrôle 2023 Engagements financiers de l'Etat - Risque PGE Audition Fédération bancaire	2023-03-30 15:40:00	2023-03-30 16:30:00	\N	\N	1	0	\N	\N
720189	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 Engagements financiers de l'Etat - Risque PGE Audition Médiation du Crédit	Contrôle 2023 Engagements financiers de l'Etat - Risque PGE Audition Médiation nationale du Crédit	2023-03-30 16:30:00	2023-03-30 17:30:00	\N	\N	1	0	\N	\N
720191	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Jérôme Bourne Branchu	\N	2023-04-11 15:00:00	2023-04-11 16:00:00	\N	\N	3	0	\N	\N
720192	COM_ENQUETE	PLENIERE	\N	RENOV	\N	Auditions plénières	\N	2023-04-03 15:00:00	2023-04-03 18:50:00	2023-04-12 16:18:27	2023-04-12 17:13:53	7	0	\N	\N
720193	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 6 avril 2023	\N	2023-04-06 09:00:00	2023-04-06 10:30:00	2023-04-06 10:49:58	2023-04-06 17:47:37	9	0	\N	\N
720199	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition INRAE	\N	2023-04-05 09:35:00	2023-04-05 12:10:00	2023-04-11 16:43:31	2023-04-12 17:11:42	44	2	\N	\N
720201	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Audition commune DGESCO / DGRH / DEPP	\N	2023-04-03 11:30:00	2023-04-03 13:15:00	\N	\N	2	0	\N	\N
720210	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	MI Antilles - Déplacement Martinique, Guadeloupe, Saint-Barthélemy et Saint-Martin	MI Antilles - Déplacement Martinique, Guadeloupe, Saint-Barthélemy et Saint-Martin	2023-04-10 08:00:00	2023-04-19 22:00:00	\N	\N	5	0	\N	\N
720216	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - COROM - Audition DGOM et Cabinet ministériel	Contrôle 2023 - COROM - Audition DGOM et Cabinet ministériel	2023-03-28 17:30:00	2023-03-28 19:00:00	\N	\N	2	0	\N	\N
720219	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - COROM - Audition AFD	Contrôle 2023 - COROM - Audition AFD	2023-03-29 18:30:00	2023-03-29 19:45:00	\N	\N	2	0	\N	\N
720223	COM_ENQUETE	AUDRAP	\N	RENOV	\N	Audition Cour des comptes	\N	2023-04-03 18:55:00	2023-04-03 19:40:00	\N	\N	3	0	\N	\N
720405	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Financement ORE - Audition France Universités	Contrôle 2023 - Financement ORE - Audition France Universités	2023-03-23 10:00:00	2023-03-23 11:00:00	\N	\N	1	0	\N	\N
720413	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Formation continue des enseignants - Audition Réseau des INSPE	Contrôle 2023 - Formation continue des enseignants - Audition Réseau des INSPE	2023-03-28 10:00:00	2023-03-28 11:00:00	\N	\N	1	0	\N	\N
720429	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - IRSN - Audition ASN	Contrôle 2023 - IRSN - Audition ASN	2023-03-28 17:30:00	2023-03-28 18:30:00	\N	\N	1	0	\N	\N
720434	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Finacement ORE - Table ronde syndicats	Contrôle 2023 - Finacement ORE - Table ronde syndicats	2023-03-30 10:30:00	2023-03-30 11:30:00	\N	\N	1	0	\N	\N
720458	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - EPF et EPA - Audition CEREMA	Contrôle 2023 - EPF et EPA - Audition CEREMA	2023-03-29 16:40:00	2023-03-29 17:45:00	\N	\N	1	0	\N	\N
720468	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - EPF et EPA - Audition AMF	Contrôle 2023 - EPF et EPA - Audition AMF	2023-03-29 17:45:00	2023-03-29 18:45:00	\N	\N	1	0	\N	\N
720521	DELEGATION	AUDRAP	\N	\N	211	Audition rapporteurs Parentalité Outre-mer (sociologues)	\N	2023-04-04 16:00:00	2023-04-04 17:55:00	\N	\N	3	0	\N	\N
720522	MISSION	AUTRE	\N	BIOCARBU	\N	MI BIOCARBURANTS 8	\N	2023-04-04 16:30:00	2023-04-04 18:30:00	2023-04-12 17:17:11	2023-04-12 17:26:24	10	0	\N	\N
720545	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Economiste	Audition de M. Julien Grenet	2023-04-04 16:00:00	2023-04-04 17:00:00	\N	\N	3	0	\N	\N
720743	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Données de santé - Table ronde d'associations	\N	2023-04-04 15:00:00	2023-04-04 16:00:00	\N	\N	9	0	\N	\N
720965	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Pierre Lévy, ambassadeur de France en Russie	Entretien avec M. Pierre Lévy, ambassadeur de France en Russie	2023-04-05 08:00:00	2023-04-05 09:15:00	\N	\N	18	0	608	\N
721264	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition M. VALETTE-VALLA (TRACFIN) - Demande saisine LPM- Désignation rapporteur CMF OM	Audition M. VALETTE-VALLA (TRACFIN) - Demande saisine LPM- Désignation rapporteur CMF Outre-Mer	2023-04-05 11:20:00	2023-04-05 12:30:00	2023-04-06 12:24:03	2023-04-06 17:46:30	38	0	\N	\N
721367	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition Mme Patricia Demas - ANCT	Audition Mme Patricia Demas - ANCT	2023-03-27 17:00:00	2023-03-27 17:45:00	\N	\N	1	0	\N	\N
721371	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Axione	Axione	2023-04-03 13:30:00	2023-04-03 14:15:00	\N	\N	1	0	\N	\N
721373	COM_PERMANENTE	AUDRAP	\N	CDD	\N	FREE	\N	2023-04-03 14:15:00	2023-04-03 15:00:00	\N	\N	2	0	\N	\N
721379	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Direction générale des entreprises	Direction générale des entreprises	2023-04-03 15:00:00	2023-04-03 15:45:00	\N	\N	2	0	\N	\N
721382	COM_PERMANENTE	AUDRAP	\N	CDD	\N	DGCCRF	DGCCRF	2023-04-03 15:45:00	2023-04-03 16:30:00	\N	\N	2	0	\N	\N
721386	COM_PERMANENTE	AUDRAP	\N	CDD	\N	ARCEP	\N	2023-04-03 16:30:00	2023-04-03 17:15:00	\N	\N	2	0	\N	\N
721389	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Fédération française des télécoms	Fédération française des télécoms	2023-04-03 17:15:00	2023-04-03 18:00:00	\N	\N	2	0	\N	\N
721392	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions ARCEP	\N	2023-04-04 11:00:00	2023-04-04 12:00:00	\N	\N	1	0	\N	\N
721798	COM_PERMANENTE	AUDRAP	\N	CAE	\N	TotalEnergies	\N	2023-04-04 16:30:00	2023-04-04 17:00:00	\N	\N	0	0	\N	\N
638814	MISSION	AUCUNE	\N	RECHINNO	\N	Audition AFPC / Systematic Paris-Région	Audition AFPC / Systematic Paris-Région	2022-03-09 08:00:00	2022-03-09 08:30:00	2022-03-09 12:11:24	2022-03-09 18:05:40	4	0	\N	\N
638978	COM_PERMANENTE	AUDRAP	\N	CDD	\N	MI Aménagement du territoire - Audition Mmes Filleul et Herzog et M. Belin	MI Aménagement du territoire - Audition Mmes Filleul et Herzog et M. Belin	2022-03-09 09:00:00	2022-03-09 10:30:00	\N	\N	3	0	\N	\N
640097	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne	2022-03-29 09:30:00	2022-03-29 10:45:00	2022-03-29 11:05:53	2022-03-29 16:52:50	4	0	\N	\N
641666	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation de 14 étudiants de l'université de Chicago	Accueil d'une délégation de 14 étudiants de l'université de Chicago	2022-04-13 10:00:00	2022-04-13 11:00:00	\N	\N	2	0	590	\N
649971	ETUDES	AUTRE	\N	\N	\N	CGAAER / FICT	CGAAER / FICT	2022-07-20 08:00:00	2022-07-20 09:30:00	\N	\N	11	0	\N	907
650112	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Bruno Belin	Auditions M. Bruno Belin	2022-07-19 10:15:00	2022-07-19 11:00:00	\N	\N	1	0	\N	\N
650114	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Bruno Belin	Auditions M. Bruno Belin	2022-07-19 14:30:00	2022-07-19 19:15:00	\N	\N	1	0	\N	\N
650957	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-07-25 18:05:00	2022-07-25 19:55:00	2022-07-25 21:47:08	2022-07-26 17:29:47	32	0	\N	\N
650958	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-07-27 09:35:00	2022-07-27 11:31:00	2022-07-27 11:31:46	2022-07-27 18:10:33	28	0	\N	\N
650959	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-07-28 08:35:00	2022-07-28 09:30:00	2022-07-28 15:32:38	2022-07-28 16:07:42	24	0	\N	\N
650960	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-07-28 13:30:00	2022-07-28 14:30:00	\N	\N	0	0	\N	\N
650987	COM_PERMANENTE	AUTRE	\N	FINC	\N	PJLR 2021: Examen rapport Nlle Lecture - PLFR pour 2022: Examen rapport-Désignation de CMP	PJLR 2021 : Examen du rapport en Nouvelle lecture - PLFR pour 2022 : Examen du rapport et Désignation de CMP	2022-07-28 15:00:00	2022-07-28 17:10:00	2022-07-28 17:50:21	2022-07-28 18:05:39	31	2	\N	\N
650988	COM_PERMANENTE	AUTRE	\N	FINC	\N	PJL n° 817 mesures d'urgence pour la protection du pouvoir d'achat: Examen rapport	PJL n°817 mesures d'urgence pour la protection du pouvoir d'achat : Examen du rapport	2022-07-25 15:05:00	2022-07-25 16:20:00	2022-07-25 17:31:53	2022-07-26 17:29:46	29	2	\N	\N
650991	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2022-07-28 08:30:00	2022-07-28 08:47:00	2022-07-28 09:33:16	2022-07-28 16:07:41	17	3	\N	\N
652197	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2022 - DGCCRF - Déplacement au Mans	Contrôle 2022 - DGCCRF - Déplacement au Mans	2022-07-22 10:30:00	2022-07-22 15:30:00	\N	\N	1	0	\N	\N
652216	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL pouvoir d'achat - AFEP	PJL pouvoir d'achat - AFEP	2022-07-26 10:00:00	2022-07-26 10:45:00	\N	\N	2	0	\N	\N
652375	ETUDES	AUTRE	\N	\N	\N	Audition de M. Hervé Berville, secrétaire d'Etat chargé de la mer	\N	2022-07-27 13:30:00	2022-07-27 15:00:00	\N	\N	9	0	\N	919
652461	COM_PERMANENTE	AUTRE	\N	CAE	\N	Examen des amendements de séance PJL Pouvoir d'achat	\N	2022-07-28 08:15:00	2022-07-28 08:35:00	2022-07-28 08:57:38	2022-07-28 16:07:41	20	2	\N	\N
655237	COM_EURO	AUDRAP	\N	AFEU	\N	Audition PPRE vitraillistes/plomb REACH	\N	2022-06-30 10:00:00	2022-06-30 12:15:00	\N	\N	2	0	\N	\N
655240	COM_EURO	AUDRAP	\N	AFEU	\N	Audition PPRE vitraillistes/plomb REACH	\N	2022-06-30 16:00:00	2022-06-30 17:00:00	\N	\N	2	0	\N	\N
655243	COM_EURO	AUDRAP	\N	AFEU	\N	Audition PPRE vitraillistes/plomb REACH	\N	2022-07-06 17:00:00	2022-07-06 18:30:00	\N	\N	2	0	\N	\N
655246	COM_EURO	AUDRAP	\N	AFEU	\N	Audition PPRE vitraillistes/plomb REACH	\N	2022-07-11 14:30:00	2022-07-11 18:00:00	\N	\N	1	0	\N	\N
655249	COM_EURO	AUDRAP	\N	AFEU	\N	Audition PPRE vitraillistes/plomb REACH	\N	2022-07-13 11:30:00	2022-07-13 19:45:00	\N	\N	2	0	\N	\N
655252	COM_EURO	AUDRAP	\N	AFEU	\N	Audition PPRE vitraillistes/plomb REACH	\N	2022-07-19 10:00:00	2022-07-19 11:00:00	\N	\N	2	0	\N	\N
655255	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Politique médicament	\N	2022-06-29 14:00:00	2022-06-29 15:00:00	\N	\N	1	0	\N	\N
655257	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Europe du médicament	\N	2022-06-30 14:00:00	2022-06-30 16:00:00	\N	\N	2	0	\N	\N
659408	DELEGATION	AUDRAP	\N	\N	DSOM	Évolution institutionnelle outre-mer : Saint-Martin /Saint-Pierre-et-Miquelon	Évolution institutionnelle outre-mer : Saint-Martin /Saint-Pierre-et-Miquelon	2022-10-18 16:30:00	2022-10-18 18:25:00	\N	\N	8	0	\N	\N
659409	DELEGATION	AUCUNE	\N	\N	DSOM	Réunion de la délégation	\N	2022-10-13 09:00:00	2022-10-13 12:15:00	\N	\N	10	0	\N	\N
659417	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 -  Anciens combattants - DG ONAC-VG/ Dir DMCA	PLF pour 2023 -  Anciens combattants - DG ONAC-VG/ Dir DMCA	2022-10-06 15:00:00	2022-10-06 18:40:00	\N	\N	1	0	\N	\N
659419	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PJL ENR	\N	2022-10-06 09:00:00	2022-10-06 09:45:00	\N	\N	3	0	\N	\N
659433	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PJL ENR	\N	2022-10-06 14:30:00	2022-10-06 15:30:00	\N	\N	2	0	\N	\N
659438	COM_PERMANENTE	AUDRAP	\N	CDD	\N	CELRL	CELRL	2022-09-27 09:15:00	2022-09-27 10:00:00	\N	\N	2	0	\N	\N
659441	COM_PERMANENTE	AUDRAP	\N	CDD	\N	UFE	UFE	2022-09-27 10:00:00	2022-09-27 10:45:00	\N	\N	2	0	\N	\N
659444	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Enerplan	Enerplan	2022-09-27 14:45:00	2022-09-27 15:30:00	\N	\N	2	0	\N	\N
659447	COM_PERMANENTE	AUDRAP	\N	CDD	\N	France Hydrogène	France Hydrogène	2022-09-27 15:30:00	2022-09-27 16:15:00	\N	\N	3	0	\N	\N
659451	COM_PERMANENTE	AUDRAP	\N	CDD	\N	WWF France	WWF France	2022-09-27 17:15:00	2022-09-27 18:00:00	\N	\N	1	0	\N	\N
659453	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Association négaWatt	Association négaWatt	2022-09-28 10:30:00	2022-09-28 11:15:00	\N	\N	4	0	\N	\N
659458	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Réseau Action Climat	Réseau Action Climat	2022-09-28 11:15:00	2022-09-28 12:00:00	\N	\N	4	0	\N	\N
659463	COM_PERMANENTE	AUDRAP	\N	CDD	\N	TR Méthanisation	TR Méthanisation	2022-09-28 13:30:00	2022-09-28 14:30:00	\N	\N	4	0	\N	\N
659474	COM_PERMANENTE	AUDRAP	\N	CDD	\N	TR Chaleur renouvelable	TR Chaleur renouvelable	2022-09-28 14:30:00	2022-09-28 15:30:00	\N	\N	5	0	\N	\N
659480	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Ademe	Ademe	2022-09-28 16:30:00	2022-09-28 17:15:00	\N	\N	4	0	\N	\N
659485	COM_PERMANENTE	AUDRAP	\N	CDD	\N	France Nature Environnement	France Nature Environnement	2022-09-28 17:15:00	2022-09-28 18:00:00	\N	\N	4	0	\N	\N
659490	COM_PERMANENTE	AUDRAP	\N	CDD	\N	CESE	CESE	2022-09-29 09:00:00	2022-09-29 10:00:00	\N	\N	2	0	\N	\N
659493	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Équilibre des énergies	Équilibre des énergies	2022-10-03 15:00:00	2022-10-03 15:45:00	\N	\N	1	0	\N	\N
659495	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Ligue de protection des oiseaux (LPO)	Ligue de protection des oiseaux (LPO)	2022-10-03 15:45:00	2022-10-03 16:30:00	\N	\N	1	0	\N	\N
659497	COM_PERMANENTE	AUDRAP	\N	CDD	\N	ANEM	ANEM	2022-10-03 16:30:00	2022-10-03 17:15:00	\N	\N	2	0	\N	\N
659500	COM_PERMANENTE	AUDRAP	\N	CDD	\N	ANEL	ANEL	2022-10-03 17:30:00	2022-10-03 18:15:00	\N	\N	2	0	\N	\N
659503	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Régions de France	Régions de France	2022-10-03 18:15:00	2022-10-03 19:00:00	\N	\N	2	0	\N	\N
659506	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Syndicat des énergies renouvelables	Syndicat des énergies renouvelables	2022-10-04 09:00:00	2022-10-04 09:45:00	\N	\N	3	0	\N	\N
659510	COM_PERMANENTE	AUDRAP	\N	CDD	\N	CRE	CRE	2022-10-04 09:45:00	2022-10-04 10:30:00	\N	\N	3	0	\N	\N
659514	COM_PERMANENTE	AUDRAP	\N	CDD	\N	AMF	AMF	2022-10-04 14:00:00	2022-10-04 14:45:00	\N	\N	4	0	\N	\N
659519	COM_PERMANENTE	AUDRAP	\N	CDD	\N	TotalÉnergies	TotalÉnergies	2022-10-04 14:45:00	2022-10-04 15:30:00	\N	\N	3	0	\N	\N
659523	COM_PERMANENTE	AUDRAP	\N	CDD	\N	FNCCR	FNCCR	2022-10-04 15:30:00	2022-10-04 16:15:00	\N	\N	3	0	\N	\N
659527	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Enedis	Enedis	2022-10-04 16:30:00	2022-10-04 17:15:00	\N	\N	3	0	\N	\N
659531	COM_PERMANENTE	AUDRAP	\N	CDD	\N	EDF	EDF	2022-10-04 17:15:00	2022-10-04 18:00:00	\N	\N	2	0	\N	\N
659534	COM_PERMANENTE	AUDRAP	\N	CDD	\N	GrDF	GrDF	2022-10-05 08:45:00	2022-10-05 09:30:00	\N	\N	2	0	\N	\N
659537	COM_PERMANENTE	AUDRAP	\N	CDD	\N	SNCF	SNCF	2022-10-05 09:30:00	2022-10-05 10:15:00	\N	\N	2	0	\N	\N
659540	COM_PERMANENTE	AUDRAP	\N	CDD	\N	TR producteurs d'énergies renouvelables	TR producteurs d'énergies renouvelables	2022-10-05 13:15:00	2022-10-05 14:15:00	\N	\N	2	0	\N	\N
659543	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Equinor	Equinor	2022-10-05 14:15:00	2022-10-05 15:15:00	\N	\N	2	0	\N	\N
659546	COM_PERMANENTE	AUDRAP	\N	CDD	\N	TR agrivoltaïsme	TR agrivoltaïsme	2022-10-05 18:30:00	2022-10-05 19:30:00	\N	\N	1	0	\N	\N
659549	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 -  Anciens combattants - INI	PLF pour 2023 -  Anciens combattants - INI	2022-10-07 11:00:00	2022-10-07 12:20:00	\N	\N	1	0	\N	\N
659561	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2022-10-19 08:45:00	2022-10-19 12:15:00	2022-10-21 09:39:12	2022-10-21 11:45:35	36	0	\N	\N
699501	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Mme Chain-Larché	\N	2023-02-07 14:15:00	2023-02-07 15:30:00	\N	\N	1	0	\N	\N
736759	GIA	AUCUNE	\N	\N	\N	AG	Assemblée générale du groupe - présentation des conclusions de la mission à Taiïwan	2023-05-30 19:00:00	2023-05-30 20:00:00	\N	\N	9	0	623	\N
738026	GIA	AUCUNE	\N	\N	\N	Entretien avec le ministre des Affaires étrangères de l'Artsakh	\N	2023-05-31 12:00:00	2023-05-31 13:00:00	\N	\N	1	0	1013	CHRETORIENT
739429	MISSION	AUCUNE	\N	BIOCARBU	\N	PLENIERE - 23 - Agnès Pannier-Runacher	\N	2023-06-13 13:30:00	2023-06-13 14:45:00	2023-06-13 14:47:41	2023-06-14 15:28:07	13	0	\N	\N
739461	MISSION	AUCUNE	\N	LOCA	\N	Réunion de présentation du rapport	\N	2023-06-13 17:00:00	2023-06-13 18:00:00	2023-06-14 12:12:42	2023-06-14 15:28:09	14	0	\N	\N
739780	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition organisations patronale - PJL plein emploi	\N	2023-06-07 13:30:00	2023-06-07 15:00:00	\N	\N	1	0	\N	\N
740853	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion CATDD	\N	2023-06-13 16:30:00	2023-06-13 18:10:00	2023-06-13 20:56:56	2023-06-14 15:27:57	34	3	\N	\N
740873	COM_SPECIALE	AUDRAP	\N	ESNU	\N	Audition rapporteur P. CHAIZE	\N	2023-06-12 09:00:00	2023-06-12 12:30:00	\N	\N	3	0	\N	\N
740874	COM_SPECIALE	AUDRAP	\N	ESNU	\N	Audition rapporteur P. CHAIZE	\N	2023-06-12 09:00:00	2023-06-12 10:00:00	\N	\N	3	0	\N	\N
740878	COM_SPECIALE	AUDRAP	\N	ESNU	\N	Direction générale de la concurrence, de la consommation et de la répression des fraudes	\N	2023-06-12 10:00:00	2023-06-12 11:00:00	\N	\N	3	0	\N	\N
740882	COM_SPECIALE	AUDRAP	\N	ESNU	\N	Groupement d'intérêt public Action contre la cybermalveillance	\N	2023-06-12 11:00:00	2023-06-12 12:00:00	\N	\N	3	0	\N	\N
740891	COM_ENQUETE	AUTRE	\N	TIKTO	\N	Audition Reporters sans frontières	\N	2023-06-12 17:00:00	2023-06-12 18:20:00	2023-06-14 10:09:21	2023-06-14 15:28:06	6	0	\N	\N
740898	COM_SPECIALE	AUDRAP	\N	ESNU	\N	Audition Rapporteur P. CHAIZE	\N	2023-06-12 13:30:00	2023-06-12 17:00:00	\N	\N	0	0	\N	\N
740899	COM_SPECIALE	AUDRAP	\N	ESNU	\N	Table ronde - Navigateurs Internet - Rapporteur P. CHAIZE	\N	2023-06-12 13:30:00	2023-06-12 14:30:00	\N	\N	3	0	\N	\N
740903	COM_SPECIALE	AUDRAP	\N	ESNU	\N	Table ronde Télécom - Rapporteur P. CHAIZE	\N	2023-06-12 14:30:00	2023-06-12 15:30:00	\N	\N	2	0	\N	\N
740906	COM_SPECIALE	AUDRAP	\N	ESNU	\N	Table ronde Jeux - Rapporteur P. CHAIZE	\N	2023-06-12 15:30:00	2023-06-12 16:30:00	\N	\N	3	0	\N	\N
740910	COM_SPECIALE	AUDRAP	\N	ESNU	\N	Airbnb	\N	2023-06-12 16:30:00	2023-06-12 17:00:00	\N	\N	4	0	\N	\N
748133	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL régime juridique des actions de groupe	PPL Régime juridique des actions de groupe	2023-06-29 09:30:00	2023-06-29 12:30:00	\N	\N	1	0	\N	\N
748137	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Sécuirté alimentaire - Table-ronde	Contrôle 2023 - Sécuirté alimentaire - Table-ronde	2023-06-28 12:00:00	2023-06-28 13:00:00	\N	\N	2	0	\N	\N
748140	COM_EURO	AUTRE	\N	AFEU	\N	Réunon de la commission du 5 juillet 2023	\N	2023-07-05 13:30:00	2023-07-05 14:45:00	2023-07-05 20:15:04	2023-07-07 16:15:29	18	0	\N	\N
748141	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 6 juillet 2023	\N	2023-07-06 08:30:00	2023-07-06 10:30:00	2023-07-06 16:12:20	2023-07-07 16:15:30	8	0	\N	\N
748142	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Cobtrôle 2023 - Actions écoresponsables - Audition Présidence de la République	Cobtrôle 2023 - Actions écoresponsables - Audition Présidence de la République	2023-06-09 15:30:00	2023-06-09 16:30:00	\N	\N	1	0	\N	\N
748144	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Actions écoresponsables - Audition Questure du Sénat	Contrôle 2023 - Actions écoresponsables - Audition Questure du Sénat	2023-06-06 14:30:00	2023-06-06 15:30:00	\N	\N	1	0	\N	\N
748146	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Actions écoresponsables - Audition I4CE	Contrôle 2023 - Actions écoresponsables - Audition I4CE	2023-06-13 14:00:00	2023-06-13 15:00:00	\N	\N	1	0	\N	\N
748148	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Actions écoresponsables - Audition Questure Assemblée Nationale	Contrôle 2023 - Actions écoresponsables - Audition Questure Assemblée Nationale	2023-06-21 17:00:00	2023-06-21 18:00:00	\N	\N	1	0	\N	\N
749471	BUREAU	AUCUNE	\N	\N	\N	Réunion du Bureau	Réunion du Bureau	2023-07-05 08:30:00	2023-07-05 09:55:00	\N	\N	22	0	\N	\N
750910	COM_PERMANENTE	AUDRAP	\N	CAE	\N	FCD	FCD	2023-06-20 16:15:00	2023-06-20 17:00:00	\N	\N	2	0	\N	\N
750926	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Adepale	Adepale	2023-06-21 18:00:00	2023-06-21 18:45:00	\N	\N	2	0	\N	\N
752862	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Institut du monde arabe (IMA)	\N	2023-10-04 09:00:00	2023-10-04 10:10:00	\N	\N	3	0	\N	\N
753670	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-10-11 08:30:00	2023-10-11 10:25:00	2023-10-11 10:25:46	2023-10-11 18:16:57	45	0	\N	\N
753671	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-10-10 14:30:00	2023-10-10 15:30:00	2023-10-10 18:12:57	2023-10-11 18:16:52	23	0	\N	\N
753685	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition SERM	Audition SERM	2023-10-05 15:00:00	2023-10-05 15:45:00	\N	\N	1	0	\N	\N
753687	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de commission du 12 octobre 2023	\N	2023-10-12 09:00:00	2023-10-12 11:10:00	2023-10-12 11:28:32	2023-10-12 18:13:15	15	0	\N	\N
753669	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-10-11 10:35:00	2023-10-11 11:35:00	2023-10-11 11:49:21	2023-10-11 18:17:04	45	0	\N	\N
755886	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	audition PPL écriture 	\N	2023-10-10 16:30:00	2023-10-10 18:00:00	\N	\N	5	0	\N	\N
756082	DELEGATION	AUCUNE	\N	\N	COLTER	Réunion constitutive de la délégation	\N	2023-10-18 08:30:00	2023-10-18 09:05:00	\N	\N	31	0	\N	\N
756143	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2024 Autonomie - Audition de l'Assemblée des départements de France	\N	2023-10-16 15:45:00	2023-10-16 16:30:00	\N	\N	3	0	\N	\N
756189	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition de Mickaelle Paty	\N	2023-10-17 15:00:00	2023-10-17 16:30:00	2023-10-17 18:02:10	2023-10-18 18:17:09	63	0	\N	\N
756293	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2024 Autonomie - Audition de la FHF	\N	2023-10-16 16:30:00	2023-10-16 17:15:00	\N	\N	1	0	\N	\N
756310	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Agence nationale du sport	ANS	2023-10-17 14:00:00	2023-10-17 15:00:00	\N	\N	1	0	\N	\N
756314	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	comité d'organisation des jeux olympiques et paralympiques de 2024	\N	2023-10-17 17:00:00	2023-10-17 18:00:00	\N	\N	2	0	\N	\N
756326	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2024 - Branche Famille - Audition Fédération française entreprises de crèches	\N	2023-10-19 09:15:00	2023-10-19 10:00:00	\N	\N	1	0	\N	\N
756327	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2024 - Branche Famille - Table ronde associations familiales	\N	2023-10-19 10:30:00	2023-10-19 11:45:00	\N	\N	1	0	\N	\N
756371	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2024 - Branche Famille - Audition Union nationale des associations familiales	\N	2023-10-31 09:00:00	2023-10-31 09:45:00	\N	\N	1	0	\N	\N
756460	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	plf recherche	\N	2023-10-17 14:00:00	2023-10-17 15:20:00	\N	\N	2	0	\N	\N
756466	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL écriture	\N	2023-10-17 09:30:00	2023-10-17 10:45:00	\N	\N	4	0	\N	\N
756517	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	ppl écriture	\N	2023-10-17 18:00:00	2023-10-17 18:30:00	\N	\N	1	0	\N	\N
756525	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2023-10-10 16:00:00	2023-10-10 17:20:00	\N	\N	3	0	\N	\N
756529	GIA	AUCUNE	\N	\N	\N	Audition conjointe du Représentant du Haut-Karabagh et de l'ambassadrice d'Arménie	Audition de SE Mme Hasmik TOLMAJYAN et de M. Hovhannes GUEVORKIAN	2023-10-17 14:30:00	2023-10-17 16:10:00	\N	\N	16	0	641	\N
756548	GIA	AUCUNE	\N	\N	\N	Audition conjointe du Représentant du Haut-Karabagh et de l'ambassadrice d'Arménie	Audition de SE Mme Hasmik TOLMAJYAN et de M. Hovhannes GUEVORKIAN	2023-10-17 14:30:00	2023-10-17 16:10:00	\N	\N	16	0	1013	\N
756786	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLC Abroger l'article 40 de la Constitution	PPLC Abroger l'article 40 de la Constitution	2023-10-17 17:00:00	2023-10-17 17:10:00	\N	\N	1	0	\N	\N
756792	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLC Abroger l'article 40 de la Constitution	PPLC Abroger l'article 40 de la Constitution	2023-10-17 17:40:00	2023-10-17 18:00:00	\N	\N	2	0	\N	\N
756799	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLC Abroger l'article 40 de la Constitution	PPLC Abroger l'article 40 de la Constitution	2023-10-17 18:50:00	2023-10-17 19:10:00	\N	\N	1	0	\N	\N
638363	COM_PERMANENTE	AUDRAP	\N	CDD	\N	MI Aménagement du territoire - Audition Mmes Filleul et Herzog	MI Aménagement du territoire - Audition Mmes Filleul et Herzog	2022-03-24 10:30:00	2022-03-24 11:15:00	\N	\N	2	0	\N	\N
638367	COM_PERMANENTE	AUDRAP	\N	CDD	\N	MI Aménagement du territoire - Audition Mmes Filleul et Herzog et M. Belin	MI Aménagement du territoire - Audition Mmes Filleul et Herzog et M. Belin	2022-03-02 10:30:00	2022-03-02 11:30:00	\N	\N	4	0	\N	\N
638377	GIA	AUCUNE	\N	\N	\N	visite de l' Association des anciens élèves de polytechnique Lausanne/Zurich	visite de l' Association des anciens élèves de polytechnique Lausanne /Zurich	2022-05-24 10:30:00	2022-05-24 12:30:00	\N	\N	1	0	610	\N
638808	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	Coopé - Entretien avec Mme Anja MAGER	Coopé - Entretien avec Mme Anja MAGER	2022-02-28 15:00:00	2022-02-28 16:00:00	\N	\N	1	0	\N	\N
639615	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Mi Question migratoire	MI Question migratoire	2022-03-15 14:30:00	2022-03-15 19:30:00	\N	\N	4	0	\N	\N
639624	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Question migratoire	MI Question migratoire	2022-03-15 15:30:00	2022-03-15 17:30:00	\N	\N	1	0	\N	\N
639628	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Question migratoire	MI Question migratoire	2022-03-15 17:30:00	2022-03-15 19:30:00	\N	\N	1	0	\N	\N
639630	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Question migratoire	MI Question migratoire	2022-03-16 16:30:00	2022-03-16 19:00:00	\N	\N	4	0	\N	\N
639634	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Question migratoire	MI Question migratoire	2022-03-16 16:30:00	2022-03-16 18:00:00	\N	\N	1	0	\N	\N
639954	MISSION	AUCUNE	\N	JUDI	\N	Examen et adoption du rapport d'information	Examen et adoption du rapport d'information	2022-03-29 17:15:00	2022-03-29 18:30:00	2022-03-29 19:05:15	2022-03-30 17:28:53	11	0	\N	\N
639959	MISSION	AUCUNE	\N	RECHINNO	\N	Médaillés de l'innovation du CNRS	Médaillés de l'innovation du CNRS	2022-03-23 16:30:00	2022-03-23 18:00:00	2022-03-24 11:02:39	2022-03-24 15:07:49	3	0	\N	\N
639965	MISSION	AUCUNE	\N	CULTURE	\N	Réunion 20220329	\N	2022-03-29 16:30:00	2022-03-29 19:05:00	2022-03-29 19:07:15	2022-03-30 17:28:52	0	0	\N	\N
639967	MISSION	AUCUNE	\N	CULTURE	\N	Réunion 20220330	\N	2022-03-30 09:00:00	2022-03-30 12:35:00	2022-03-30 14:07:03	2022-03-30 17:28:54	7	0	\N	\N
639968	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 30 mars 2022	\N	2022-03-30 08:20:00	2022-03-30 10:30:00	2022-03-30 15:18:51	2022-04-01 19:02:47	43	0	\N	\N
639969	MISSION	AUDRAP	\N	CULTURE	\N	Audition de Mmes Valérie CHAROLLAIS et Christelle RÉMY	\N	2022-03-29 15:30:00	2022-03-29 16:30:00	\N	\N	2	0	\N	\N
639970	MISSION	AUDRAP	\N	CULTURE	\N	Auditions rapporteur	\N	2022-03-30 14:00:00	2022-03-30 15:45:00	\N	\N	1	0	\N	\N
639971	MISSION	DEPLACEMENT	\N	CULTURE	\N	\N	\N	2022-02-17 08:00:00	2022-02-17 18:00:00	\N	\N	3	0	\N	\N
639975	MISSION	DEPLACEMENT	\N	CULTURE	\N	\N	\N	2022-02-24 07:30:00	2022-02-24 19:00:00	\N	\N	3	0	\N	\N
639979	MISSION	DEPLACEMENT	\N	CULTURE	\N	\N	\N	2022-03-23 15:15:00	2022-03-24 22:00:00	\N	\N	4	0	\N	\N
639995	COM_ENQUETE	PLENIERE	\N	HOPITAL	\N	Réunion plénière	\N	2022-03-29 17:05:00	2022-03-29 18:20:00	2022-03-29 18:23:42	2022-03-30 17:28:52	12	0	\N	\N
640051	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Stage en immersion au tribunal judiciaire de Rouen	Stage en immersion au tribunal judiciaire de Rouen	2022-03-31 07:00:00	2022-04-01 19:00:00	\N	\N	1	0	\N	\N
640053	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - Plan 15000 - DAP	Contrôle 2022 - Plan 15000 - DAP	2022-03-24 09:00:00	2022-03-24 10:00:00	\N	\N	1	0	\N	\N
640058	COM_PERMANENTE	AUTRE	\N	CAE	\N	PPRE Pacte Vert	\N	2022-03-30 09:05:00	2022-03-30 10:25:00	2022-03-30 15:18:39	2022-03-30 17:22:22	40	2	\N	\N
640059	COM_PERMANENTE	AUTRE	\N	CAE	\N	Pénalités logistiques et audition AIE	\N	2022-03-30 10:25:00	2022-03-30 12:25:00	2022-03-30 15:23:28	2022-03-30 17:22:22	27	2	\N	\N
640060	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - Maisons France services - CAF-AR-CCMSA-SADJAV	Contrôle 2022 - Maisons France services - CAF-AR-CCMSA-SADJAV	2022-03-23 09:15:00	2022-03-23 10:45:00	\N	\N	1	0	\N	\N
722352	ETUDES	AUTRE	\N	\N	\N	Réunion plénière	\N	2023-04-05 13:45:00	2023-04-05 15:00:00	\N	\N	5	0	\N	1004
640062	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - Enseignants en Europe - DREIC	Contrôle 2022 - Enseignants en Europe - DREIC	2022-03-17 15:30:00	2022-03-17 16:15:00	\N	\N	1	0	\N	\N
640064	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière	\N	2022-03-29 15:30:00	2022-03-29 17:30:00	\N	\N	30	1	\N	\N
640065	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - Maisons France services - Banque des territoires	Contrôle 2022 - Maisons France services - Banque des territoires	2022-03-23 11:15:00	2022-03-23 12:15:00	\N	\N	1	0	\N	\N
640067	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - Maisons France services - DGCL	Contrôle 2022 - Maisons France services - DGCL	2022-03-23 14:00:00	2022-03-23 14:45:00	\N	\N	1	0	\N	\N
640069	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - France TV  - Producteurs Indépendants/SALTO	Contrôle 2022 - France TV  - Producteurs Indépendants/SALTO	2022-03-24 14:40:00	2022-03-24 16:30:00	\N	\N	1	0	\N	\N
640071	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - France TV  - Représentants du Personnel	Contrôle 2022 - France TV  - Représentants du Personnel	2022-03-25 09:00:00	2022-03-25 10:20:00	\N	\N	1	0	\N	\N
640073	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - France TV  - SACD	Contrôle 2022 - France TV  - SACD	2022-03-28 15:45:00	2022-03-28 16:35:00	\N	\N	1	0	\N	\N
641424	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI SPIP	MI SPIP - Auditions	2022-04-11 14:00:00	2022-04-11 15:00:00	\N	\N	3	0	\N	\N
641651	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition MI métropoles Lyon Aix-Marseille-Provence	\N	2022-04-20 08:45:00	2022-04-20 09:30:00	\N	\N	8	0	\N	\N
641654	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition MI métropoles Lyon Aix-Marseille-Provence	\N	2022-04-20 09:30:00	2022-04-20 10:30:00	\N	\N	12	0	\N	\N
641657	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition MI métropoles Lyon Aix-Marseille-Provence	\N	2022-04-20 10:30:00	2022-04-20 12:00:00	\N	\N	11	0	\N	\N
641660	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition MI métropoles Lyon Aix-Marseille-Provence	\N	2022-04-20 12:00:00	2022-04-20 13:30:00	\N	\N	10	0	\N	\N
641663	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition MI métropoles Lyon Aix-Marseille-Provence	\N	2022-04-20 14:00:00	2022-04-20 14:30:00	\N	\N	5	0	\N	\N
643235	GIA	AUCUNE	\N	\N	\N	Rencontre sénatrice afghane	Rencontre avec Mme Anarkeli Honaryar, ancienne sénatrice afghane	2022-05-24 09:00:00	2022-05-24 10:00:00	\N	\N	1	0	648	\N
643237	GIA	AUCUNE	\N	\N	\N	Réunion préparatoire déplacement	\N	2022-05-24 14:00:00	2022-05-24 15:00:00	\N	\N	4	0	615	\N
643242	GIA	AUCUNE	\N	\N	\N	Audition Ali Dolamari	\N	2022-05-24 16:00:00	2022-05-24 17:00:00	\N	\N	1	0	615	\N
643509	GIA	AUCUNE	\N	\N	\N	Déjeuner avec la Directrice Caraibes du Quai d'Orsay	Déjeuner préparatoire à la mission à Cuba	2022-06-01 13:00:00	2022-06-01 14:30:00	\N	\N	1	0	642	\N
643705	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	Audition MI Mégafeux	Audition MI Mégafeux	2022-05-31 14:00:00	2022-05-31 16:30:00	\N	\N	4	0	\N	\N
643710	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	Audition MI Mégafeux	Audition MI Mégafeux	2022-05-31 16:30:00	2022-05-31 18:00:00	\N	\N	3	0	\N	\N
643714	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	Audition MI Mégafeux	Audition MI Mégafeux	2022-06-01 09:30:00	2022-06-01 11:00:00	\N	\N	4	0	\N	\N
659170	ETUDES	AUCUNE	\N	\N	\N	Audition Filière bois-énergie	Audition Filière bois-énergie	2022-10-04 13:30:00	2022-10-04 14:30:00	\N	\N	12	0	\N	948
659190	ETUDES	AUCUNE	\N	\N	\N	Audition Filière bois-énergie	Audition Filière bois-énergie	2022-10-04 13:30:00	2022-10-04 14:30:00	\N	\N	7	0	\N	906
661890	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Investir France 2030 - ANR/CDC	PLF pour 2023 - Investir France 2030 - ANR/CDC	2022-10-13 09:30:00	2022-10-13 11:30:00	\N	\N	1	0	\N	\N
661892	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 -  EFE - BPIFrance	PLF pour 2023 -  EFE - BPIFrance	2022-10-14 15:25:00	2022-10-14 16:00:00	\N	\N	1	0	\N	\N
661931	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2023 Avis budgétaires "Sécurités"	PLF 2023 Avis budgétaires "Sécurités"	2022-10-26 09:00:00	2022-10-26 10:00:00	\N	\N	1	0	\N	\N
663377	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions M. Laurent Duplomb, Mme Françoise Férat et M. Jean-Claude Tissot	Auditions M. Laurent Duplomb, Mme Françoise Férat et M. Jean-Claude Tissot	2022-10-18 15:15:00	2022-10-18 18:30:00	\N	\N	2	0	\N	\N
663455	COM_PERMANENTE	AUTRE	\N	AFCL	\N	PJL production d'énergies renouvelables	\N	2022-10-25 09:00:00	2022-10-25 10:10:00	2022-10-26 10:12:30	2022-10-26 15:10:39	22	9	\N	\N
663456	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition de M. Gérald Darmanin	\N	2022-10-25 16:30:00	2022-10-25 18:10:00	2022-10-26 10:17:00	2022-10-26 15:10:36	50	2	\N	\N
663457	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition de Mme Rima Abdul Malak	\N	2022-10-25 18:15:00	2022-10-25 20:15:00	2022-10-26 10:17:32	2022-10-26 15:10:35	23	2	\N	\N
663458	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Table ronde piratage évènements sportifs	\N	2022-10-26 09:30:00	2022-10-26 11:30:00	2022-10-26 12:19:34	2022-10-26 15:10:31	32	0	\N	\N
689282	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2023-01-11 08:00:00	2023-01-11 09:40:00	2023-01-12 14:50:41	2023-01-12 17:25:04	65	0	\N	\N
721801	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	MI ARENH	\N	2023-04-04 16:30:00	2023-04-04 19:30:00	\N	\N	4	0	\N	\N
721806	MECSS	AUDRAP	\N	\N	MECSS	MI Solidarité à la source - Audition de Fabrice Lenglart	\N	2023-04-11 15:30:00	2023-04-11 16:30:00	\N	\N	2	0	\N	\N
721807	MECSS	AUDRAP	\N	\N	MECSS	MI Solidarité à la source - Audition de la CNAF	\N	2023-04-11 16:45:00	2023-04-11 17:45:00	\N	\N	3	0	\N	\N
721808	MECSS	AUDRAP	\N	\N	MECSS	MI Solidarité à la source - Audition de la DSS	\N	2023-04-11 17:45:00	2023-04-11 19:00:00	\N	\N	3	0	\N	\N
721813	MECSS	AUDRAP	\N	\N	MECSS	MI Solidarité à la source - Audition de la DGFiP	\N	2023-04-12 16:30:00	2023-04-12 17:00:00	\N	\N	2	0	\N	\N
721815	MECSS	AUDRAP	\N	\N	MECSS	MI Solidarité à la source - Audition de la CNAV	\N	2023-04-12 18:00:00	2023-04-12 19:20:00	\N	\N	1	0	\N	\N
721817	COM_ENQUETE	PLENIERE	\N	MEDIC	\N	Réunion plénière	\N	2023-04-11 09:05:00	2023-04-11 10:15:00	2023-04-11 13:49:07	2023-04-12 17:26:16	6	0	\N	\N
721821	COM_ENQUETE	PLENIERE	\N	MEDIC	\N	Réunion plénière	\N	2023-04-12 13:40:00	2023-04-12 14:55:00	2023-04-12 15:11:29	2023-04-12 17:26:16	8	0	\N	\N
721823	COM_ENQUETE	PLENIERE	\N	MEDIC	\N	Réunion plénière	\N	2023-04-12 17:05:00	2023-04-12 18:20:00	2023-04-12 18:40:43	2023-04-28 11:38:45	7	0	\N	\N
721826	MISSION	AUDRAP	\N	LOCA	\N	Audition de M. Martin MALVY	\N	2023-04-05 16:30:00	2023-04-05 17:45:00	\N	\N	9	0	\N	\N
722144	MISSION	AUTRE	\N	BIOCARBU	\N	MI BIOCARBURANTS 9	\N	2023-04-05 16:30:00	2023-04-05 18:00:00	2023-04-12 16:21:16	2023-04-12 17:13:52	8	0	\N	\N
722147	MISSION	AUCUNE	\N	BIOCARBU	\N	MI BIOCARBURANTS 10	\N	2023-04-05 18:10:00	2023-04-05 19:30:00	2023-04-12 16:21:36	2023-04-12 17:13:52	9	0	\N	\N
722217	ETUDES	AUTRE	\N	\N	\N	Audition du Collectif Handicaps	\N	2023-04-05 14:00:00	2023-04-05 15:00:00	\N	\N	20	0	\N	1014
722321	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	patrimoine transition écologique	\N	2023-04-05 16:30:00	2023-04-05 18:00:00	\N	\N	1	0	\N	\N
722332	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	Réunion Commission spéciale chargée du contrôle des comptes et de l'évaluation interne	Réunion Commission spéciale chargée du contrôle des comptes et de l'évaluation interne	2023-04-05 16:30:00	2023-04-05 17:45:00	2023-04-05 18:14:13	2023-04-06 17:48:17	6	0	\N	\N
722371	DELEGATION	AUCUNE	\N	\N	COLTER	Réunion plénière	\N	2023-04-06 08:30:00	2023-04-06 10:20:00	2023-04-06 16:28:37	\N	11	0	\N	\N
722416	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de l'Institut du droit local alsacien-mosellan	Audition de l'Institut du droit local alsacien-mosellan	2023-04-12 10:00:00	2023-04-12 10:55:00	2023-04-12 14:42:49	2023-04-12 17:24:40	13	0	\N	\N
722473	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI Parcoursup	M. Gilles Roussel Président du CESP	2023-04-06 10:30:00	2023-04-06 11:15:00	\N	\N	2	0	\N	\N
722550	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI  Brésil	MI Brésil	2023-03-28 09:30:00	2023-03-28 10:30:00	\N	\N	5	0	\N	\N
722579	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI  Brésil	MI Brésil	2023-04-05 16:30:00	2023-04-05 18:30:00	\N	\N	5	0	\N	\N
722589	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI 	MI Brésil	2023-04-06 09:15:00	2023-04-06 10:15:00	\N	\N	4	0	\N	\N
722595	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	MI Brésil	MI Brésil	2023-04-06 11:00:00	2023-04-06 12:00:00	\N	\N	3	0	\N	\N
722605	MISSION	AUDRAP	\N	GEAU	\N	Audition 20230411	\N	2023-04-11 16:35:00	2023-04-11 17:40:00	\N	\N	2	0	\N	\N
722607	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	\N	\N	2023-04-06 14:30:00	2023-04-06 15:20:00	\N	\N	1	0	\N	\N
722654	MISSION	AUDRAP	\N	GEAU	\N	Audition 20230412	\N	2023-04-12 16:35:00	2023-04-12 17:45:00	\N	\N	3	0	\N	\N
722662	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Pr Bouvard	\N	2023-04-13 09:30:00	2023-04-13 10:30:00	\N	\N	0	0	\N	\N
722663	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Michel Keisler	\N	2023-04-13 10:30:00	2023-04-13 11:30:00	\N	\N	0	0	\N	\N
722674	MISSION	AUDRAP	\N	BATI	\N	MI bati	\N	2023-04-06 11:00:00	2023-04-06 13:00:00	\N	\N	2	0	\N	\N
722682	DELEGATION	AUTRE	\N	\N	DSOM	Foncier agricole outre-mer : table ronde Guyane	\N	2023-04-13 14:30:00	2023-04-13 16:30:00	\N	\N	7	0	\N	\N
722685	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-04-12 09:00:00	2023-04-12 10:15:00	2023-04-12 14:41:17	2023-04-12 17:24:43	38	0	\N	\N
722686	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Caisse nationale des allocations familiales	\N	2023-04-06 17:00:00	2023-04-06 18:15:00	\N	\N	2	0	\N	\N
722690	GIA	AUCUNE	\N	\N	\N	Entretien avec le Président du Sénat malgache	Entretien avec le Président du Sénat malgache et une délégation de sénateurs	2023-04-05 17:30:00	2023-04-05 19:00:00	\N	\N	11	0	622	\N
722775	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Ministère de la culture - Secrétariat général	Secrétariat général + service des musées de France du ministère de la culture	2023-04-07 10:30:00	2023-04-07 12:00:00	\N	\N	3	0	\N	\N
722776	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Ministère de la culture	MM. Amic et Frigo - Cabinet de la ministre	2023-04-07 09:30:00	2023-04-07 10:30:00	\N	\N	3	0	\N	\N
722783	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Couples confrontés à une fausse couche - Audition FFPP	\N	2023-04-07 10:15:00	2023-04-07 11:00:00	\N	\N	2	0	\N	\N
722784	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Couples confrontés à une fausse couche - Audition DGOS-DSS	\N	2023-04-07 11:15:00	2023-04-07 12:15:00	\N	\N	3	0	\N	\N
722809	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 13 avril 2023	\N	2023-04-13 09:30:00	2023-04-13 10:45:00	2023-04-13 16:35:01	2023-04-28 11:37:17	14	0	\N	\N
722825	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Modernisation DSNA - Audition M. NOTEBAERT (SNNA-FO)	Contrôle 2023 - Modernisation DSNA - Audition M. NOTEBAERT (SNNA-FO)	2023-04-04 09:30:00	2023-04-04 10:30:00	\N	\N	1	0	\N	\N
722826	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL EDF - Audition M. POUYANNE, PDG de TotalEnergies	PPL EDF - Audition M. POUYANNE, PDG de TotalEnergies	2023-04-05 17:10:00	2023-04-05 18:00:00	\N	\N	1	0	\N	\N
722827	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Modernisation DSNA - Audition M. PICHARD, Direction du Budget	Contrôle 2023 - Modernisation DSNA - Audition M. PICHARD, Direction du Budget	2023-04-07 09:00:00	2023-04-07 10:15:00	\N	\N	1	0	\N	\N
722828	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL Accessibilité et inclusion bancaire - Audition MM. FERAUD et TISSOT, auteurs de la PPL	PPL Accessibilité et inclusion bancaire - Audition MM. FERAUD et TISSOT, auteurs de la PPL	2023-04-04 13:15:00	2023-04-04 14:00:00	\N	\N	3	0	\N	\N
722830	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL Accessibilité et inclusion bancaire - Audition La Poste	PPL Accessibilité et inclusion bancaire - Audition La Poste	2023-04-04 17:00:00	2023-04-04 18:00:00	\N	\N	1	0	\N	\N
722831	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL Accessibilité et inclusion bancaire - Audition Banque de France et ACPR	PPL Accessibilité et inclusion bancaire - Audition Banque de France et ACPR	2023-04-05 10:00:00	2023-04-05 11:00:00	\N	\N	1	0	\N	\N
722833	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Risque PGE - Audition d'économistes	Contrôle 2023 - Risque PGE - Audition d'économistes	2023-04-06 14:00:00	2023-04-06 15:00:00	\N	\N	1	0	\N	\N
722834	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Risque PGE - Audition Secteur Hôtellerie/Restauration	Contrôle 2023 - Risque PGE - Audition Secteur Hôtellerie/Restauration	2023-04-06 15:30:00	2023-04-06 16:45:00	\N	\N	1	0	\N	\N
722835	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 Financements extrabudgétaire culture - audition Cour de Comptes	\N	2023-04-05 10:00:00	2023-04-05 10:50:00	\N	\N	0	0	\N	\N
722836	ETUDES	AUCUNE	\N	\N	\N	GE Numérique	\N	2023-04-11 09:30:00	2023-04-11 10:30:00	\N	\N	6	0	\N	1008
722837	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Pass Culture - Table-ronde universitaires	Contrôle 2023 - Pass Culture - Table-ronde universitaires	2023-04-05 16:15:00	2023-04-05 17:35:00	\N	\N	2	0	\N	\N
722838	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Financement du cinéma - Audition MM. PARPEX et MARIN-LAMELLET (BpiFrance)	Contrôle 2023 - Financement du cinéma - Audition MM. PARPEX et MARIN-LAMELLET (BpiFrance)	2023-04-07 09:30:00	2023-04-07 10:15:00	\N	\N	1	0	\N	\N
722839	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Modernisation DSNA - Audition UNSA-DGAC	Contrôle 2023 - Modernisation DSNA - Audition UNSA-DGAC	2023-04-07 10:15:00	2023-04-07 11:10:00	\N	\N	1	0	\N	\N
722840	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Boucliers tarifaires et amortisseurs - Audition Mme WARGON (CRE)	Contrôle 2023 - Boucliers tarifaires et amortisseurs - Audition Mme WARGON (CRE)	2023-04-11 08:30:00	2023-04-11 09:30:00	\N	\N	1	0	\N	\N
722841	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Boucliers tarifaires et amortisseurs - Audition EDF	Contrôle 2023 - Boucliers tarifaires et amortisseurs - Audition EDF	2023-04-11 09:30:00	2023-04-11 10:45:00	\N	\N	1	0	\N	\N
722842	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 12 avril 2023	\N	2023-04-12 14:00:00	2023-04-12 14:45:00	\N	\N	0	0	\N	\N
722843	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 12 avril 2023	\N	2023-04-12 14:00:00	2023-04-12 14:45:00	\N	\N	0	0	\N	\N
722844	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Audition Institute for Climate Economics (I4CE)	PLF pour 2024 - Audition Institute for Climate Economics (I4CE)	2023-04-04 10:15:00	2023-04-04 11:15:00	\N	\N	1	0	\N	\N
639359	ETUDES	AUCUNE	\N	\N	\N	Audition Académie française d'agriculture	Audition Académie française d'agriculture	2022-03-16 08:00:00	2022-03-16 09:30:00	\N	\N	6	0	\N	948
639366	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	MCC Sécurisation de la chasse	MCC Sécurisation de la chasse	2022-03-15 14:00:00	2022-03-15 19:15:00	\N	\N	7	0	\N	\N
722477	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2023-04-12 10:00:00	2023-04-12 12:00:00	2023-04-27 12:05:54	2023-04-28 11:37:05	39	0	\N	\N
639374	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	MCC Sécurisation de la chasse	MCC Sécurisation de la chasse	2022-03-16 10:30:00	2022-03-16 12:30:00	\N	\N	5	0	\N	\N
639380	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	MCC Sécurisation de la chasse	MCC Sécurisation de la chasse	2022-03-16 14:00:00	2022-03-16 18:30:00	\N	\N	5	0	\N	\N
640724	GIA	AUCUNE	\N	\N	\N	Déjeuner de travail coopération énergétique franco-polonaise	Déjeuner de travail coopération énergétique franco-polonaise	2022-03-30 12:30:00	2022-03-30 14:30:00	\N	\N	8	0	600	\N
641957	MISSION	AUCUNE	\N	FONDSMER	\N	Audition Technip FMC	Audition Technip FMC	2022-04-28 14:30:00	2022-04-28 15:40:00	2022-04-28 15:42:28	2022-04-28 17:20:20	9	0	\N	\N
644311	COM_PERMANENTE	AUTRE	\N	CAE	\N	Table ronde Mégafeux	\N	2022-06-15 09:30:00	2022-06-15 11:55:00	2022-06-15 17:19:18	2022-06-16 10:07:27	53	0	\N	\N
644312	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition FFF	\N	2022-06-09 14:30:00	2022-06-09 16:05:00	2022-06-10 18:20:45	2022-06-14 17:47:30	25	0	\N	\N
645198	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI  Méditerranée	RI Méditerranée	2022-06-16 11:00:00	2022-06-16 12:00:00	\N	\N	2	0	\N	\N
649258	DELEGATION	DEPLACEMENT	\N	\N	DSOM	Déplacement La Réunion et Mayotte : étude "Gestion des déchets outre-mer"	Déplacement La Réunion et Mayotte : étude "Gestion des déchets outre-mer"	2022-06-26 19:30:00	2022-07-02 18:30:00	\N	\N	2	0	\N	\N
651293	DELEGATION	AUCUNE	\N	\N	206	Gestion des déchets radioactifs : audition de la CNE2	\N	2022-07-21 09:30:00	2022-07-21 11:05:00	\N	\N	9	0	\N	\N
651305	COM_PERMANENTE	AUTRE	\N	CAE	\N	Examen PPRE connectivité sécurisée	\N	2022-07-21 10:05:00	2022-07-21 11:10:00	\N	\N	13	0	\N	\N
651331	DELEGATION	AUCUNE	\N	\N	206	Sûreté nucléaire et radioprotection : audition de l'IRSN	\N	2022-07-21 11:10:00	2022-07-21 12:15:00	\N	\N	8	0	\N	\N
653503	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 -  ONACVG - ONACVG Rapatriés	Contrôle 2022 -  ONACVG - ONACVG Rapatriés	2022-07-28 17:00:00	2022-07-28 18:30:00	\N	\N	1	0	\N	\N
655264	COM_EURO	AUDRAP	\N	AFEU	\N	Audition devoir de vigilance	\N	2022-05-16 14:00:00	2022-05-16 15:00:00	\N	\N	3	0	\N	\N
655269	COM_EURO	AUDRAP	\N	AFEU	\N	Auditions devoir de vigilance	\N	2022-05-24 09:00:00	2022-05-24 11:00:00	\N	\N	3	0	\N	\N
655273	COM_EURO	AUDRAP	\N	AFEU	\N	Audition devoir de vigilance	\N	2022-05-24 14:00:00	2022-05-24 15:00:00	\N	\N	3	0	\N	\N
656161	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Réunion de travail sur le programme 144	\N	2022-09-20 17:30:00	2022-09-20 18:30:00	\N	\N	2	0	\N	\N
656164	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audition dans le cadre du programme 129	\N	2022-09-22 08:30:00	2022-09-22 11:00:00	\N	\N	1	0	\N	\N
656465	COM_PERMANENTE	AUTRE	\N	CAE	\N	Rapport MI Ferme France	\N	2022-09-28 09:35:00	2022-09-28 11:45:00	2022-09-28 12:11:15	2022-09-28 16:49:34	29	3	\N	\N
656752	DELEGATION	AUCUNE	\N	\N	COLTER	Examen du rapport Services déconcentrés et préfectoraux	\N	2022-09-29 09:00:00	2022-09-29 10:30:00	\N	\N	17	0	\N	\N
656809	COM_PERMANENTE	AUTRE	\N	LOIS	\N	« Revenantes » du djihad - Audition d'Éric Dupond-Moretti	« Revenantes » du djihad - Audition d'Éric Dupond-Moretti	2022-10-05 16:35:00	2022-10-05 17:45:00	2022-10-05 18:26:44	2022-10-06 14:42:34	27	0	\N	\N
656810	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2022 - Contrats Etat collectivités lutte contre la pauvreté - Déplacement Aulnay	Contrôle 2022 - Contrats Etat collectivités lutte contre la pauvreté - Déplacement Aulnay sous bois	2022-10-06 13:45:00	2022-10-06 16:45:00	\N	\N	1	0	\N	\N
656811	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2023 - Mission "Sécurités" Sécurité civile - Déplacement Nîmes et Marseille	PLF pour 2023 - Mission "Sécurités" Sécurité civile - Déplacement Nîmes et Marseille	2022-10-13 08:15:00	2022-10-14 19:30:00	\N	\N	1	0	\N	\N
656812	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Intervention des cabinets privés	PPL Cabinets privés	2022-09-28 14:30:00	2022-09-28 15:15:00	\N	\N	2	0	\N	\N
656818	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteurs PJL Marché du travail - Organisations syndicales	\N	2022-09-29 10:30:00	2022-09-29 12:00:00	\N	\N	3	0	\N	\N
656824	COM_PERMANENTE	AUTRE	\N	FINC	\N	Contrôles budgétaires Forces souveraineté, IGN et entreprises adaptées et nominations rap.	Contrôles budgétaires Forces souveraineté, IGN et entreprises adaptées et nominations rapporteurs	2022-10-05 10:00:00	2022-10-05 11:55:00	2022-10-05 13:30:36	2022-10-05 17:35:19	40	1	\N	\N
656829	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteurs PJL Marché du travail - DGT	\N	2022-09-28 14:00:00	2022-09-28 14:45:00	\N	\N	3	0	\N	\N
656837	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteurs PJL Marché du travail - DGEFP	\N	2022-09-29 14:30:00	2022-09-29 16:00:00	\N	\N	3	0	\N	\N
656838	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteure  - Audition CNAF et CAF du Nord	\N	2022-09-30 10:30:00	2022-09-30 11:30:00	\N	\N	4	0	\N	\N
656839	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	RSE	\N	2022-10-04 16:00:00	2022-10-04 17:00:00	\N	\N	0	0	\N	\N
656842	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 5 octobre 2022	\N	2022-10-05 13:30:00	2022-10-05 15:30:00	2022-10-21 10:01:04	\N	17	0	\N	\N
656843	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Formation des internes en médecine générale - Audition Conférence nationale URPS-ML	\N	2022-09-30 16:00:00	2022-09-30 16:45:00	\N	\N	1	0	\N	\N
656844	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL CSE La Poste - Table ronde des organisations syndicales	\N	2022-09-29 16:00:00	2022-09-29 17:50:00	\N	\N	3	0	\N	\N
656845	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Formation des internes en médecine générale - Audition du CNOM	\N	2022-09-27 10:00:00	2022-09-27 11:00:00	\N	\N	2	0	\N	\N
656846	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Formation des internes en médecine générale - Table ronde de syndicats d'internes	\N	2022-09-27 15:30:00	2022-09-27 17:00:00	\N	\N	6	0	\N	\N
656847	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Formation des internes - Audition de la DGOS	\N	2022-09-27 17:00:00	2022-09-27 17:45:00	\N	\N	4	0	\N	\N
656848	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Formation des internes en médecine générale - Syndicats de médecins généralistes	\N	2022-09-28 14:00:00	2022-09-28 15:00:00	\N	\N	3	0	\N	\N
656849	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL CSE La Poste - Audition du groupe La Poste	\N	2022-09-29 08:30:00	2022-09-29 10:00:00	\N	\N	3	0	\N	\N
656852	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Formation des internes en médecine générale - Audition Conférence des doyens et CNGE	\N	2022-09-27 14:30:00	2022-09-27 15:30:00	\N	\N	5	0	\N	\N
659562	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2022-10-19 16:30:00	2022-10-19 18:00:00	2022-10-20 14:43:27	2022-10-20 17:44:35	66	0	\N	\N
659564	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2022-10-26 16:40:00	2022-10-26 18:35:00	\N	\N	30	0	\N	\N
656808	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Orientation et programmation du ministère de l'intérieur (rapport)	PJL Orientation et programmation du ministère de l'intérieur (rapport)	2022-10-05 09:50:00	2022-10-05 11:40:00	2022-10-05 12:22:33	2022-10-05 17:35:16	45	1	\N	\N
659565	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF LIC	\N	2022-10-06 15:30:00	2022-10-06 16:30:00	\N	\N	2	0	\N	\N
662453	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2023 - Famille - Audition rapporteur	\N	2022-10-18 09:45:00	2022-10-18 10:30:00	\N	\N	2	0	\N	\N
665033	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - RSR - CDC	PLF pour 2023 - RSR - CDC	2022-10-18 15:00:00	2022-10-18 16:00:00	\N	\N	1	0	\N	\N
665035	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Culture - DG2TDC	PLF pour 2023 - Culture - DG2TDC	2022-10-18 16:30:00	2022-10-18 17:15:00	\N	\N	2	0	\N	\N
665038	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - RSR - DGAMPA	PLF pour 2023 - RSR - DGAMPA	2022-10-19 11:35:00	2022-10-19 12:25:00	\N	\N	1	0	\N	\N
665039	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - RSR - Retraites de l'État	PLF pour 2023 - RSR - Retraites de l'État	2022-10-19 14:00:00	2022-10-19 14:30:00	\N	\N	1	0	\N	\N
665043	COM_PERMANENTE	AUDRAP	\N	CDD	\N	USMA / SJA	USMA / SJA	2022-10-12 13:30:00	2022-10-12 14:15:00	\N	\N	1	0	\N	\N
675819	GIA	AUCUNE	\N	\N	\N	Audition PHRI	Audition Physicians for Human Rights Israel	2022-11-16 16:30:00	2022-11-16 17:15:00	\N	\N	2	0	632	\N
675831	GIA	AUCUNE	\N	\N	\N	Audition J.-P. Filiu	Audition du Pr. Jean-Pierre Filiu sur les accords d'Abraham	2022-11-16 17:15:00	2022-11-16 18:20:00	\N	\N	5	0	632	\N
701689	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI Retex Barkhane	\N	2023-02-07 16:00:00	2023-02-07 17:00:00	\N	\N	7	0	\N	\N
701697	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI Retex Barkhane	\N	2023-01-31 16:30:00	2023-01-31 18:30:00	\N	\N	7	0	\N	\N
701705	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	RI LPM P178	\N	2023-02-09 17:00:00	2023-02-10 17:30:00	\N	\N	2	0	\N	\N
738293	QUESTURE	AUCUNE	\N	\N	\N	Réunion de Questure	Réunion de Questure	2023-05-25 12:30:00	2023-05-25 13:30:00	\N	\N	3	0	\N	\N
738375	GIA	AUCUNE	\N	\N	\N	Entretien avec une délégation du Parti communiste chinois	\N	2023-05-26 08:30:00	2023-05-26 09:30:00	\N	\N	4	0	584	\N
738956	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions MI Consigne	Auditions MI Consigne	2023-05-15 10:00:00	2023-05-15 11:00:00	\N	\N	1	0	\N	\N
738998	COM_PERMANENTE	AUTRE	\N	CAE	\N	Rapport application loi maltraitance animale	\N	2023-06-07 09:30:00	2023-06-07 10:00:00	2023-06-19 18:06:11	2023-06-19 18:09:47	46	1	\N	\N
739117	MECSS	AUDRAP	\N	\N	MECSS	MI Organismes financés par les Robss - Audition EFS	\N	2023-06-06 16:00:00	2023-06-06 17:00:00	\N	\N	2	0	\N	\N
739119	MECSS	AUDRAP	\N	\N	MECSS	MI Organismes financés par les Robss - Audition DB	\N	2023-06-06 17:00:00	2023-06-06 18:00:00	\N	\N	2	0	\N	\N
739120	MECSS	AUDRAP	\N	\N	MECSS	MI Organismes financés par les Robss - Audition Cnam	\N	2023-06-06 18:15:00	2023-06-06 19:15:00	\N	\N	2	0	\N	\N
739126	MISSION	AUTRE	\N	LOCA	\N	Reunion de présentation du rapport	\N	2023-06-14 17:00:00	2023-06-14 18:30:00	\N	\N	0	0	\N	\N
739330	COM_ENQUETE	PLENIERE	\N	RENOV	\N	Table ronde Patrimoine	\N	2023-05-30 15:30:00	2023-05-30 18:30:00	2023-06-07 11:52:43	\N	5	0	\N	\N
739474	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - Avis PJL Programmation militaire	Audition rapporteur - Avis PJL Programmation militaire	2023-06-06 09:00:00	2023-06-06 11:00:00	\N	\N	1	0	\N	\N
740161	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-06-14 08:30:00	2023-06-14 10:30:00	2023-06-14 12:40:30	2023-06-14 15:27:58	39	0	\N	\N
740164	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition plénière de G. Attal	\N	2023-06-14 16:30:00	2023-06-14 17:45:00	2023-06-14 18:03:58	2023-06-15 20:05:57	20	0	\N	\N
740204	MISSION	AUCUNE	\N	BATI	\N	Audition de Mme Faure	\N	2023-06-07 16:30:00	2023-06-07 18:00:00	2023-06-07 18:05:20	2023-06-08 11:18:14	8	0	\N	\N
740217	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	autonomie ES	\N	2023-06-07 13:30:00	2023-06-07 14:30:00	\N	\N	4	0	\N	\N
744086	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2023-06-08 08:30:00	2023-06-08 10:06:00	\N	\N	3	0	\N	\N
744542	GIA	AUCUNE	\N	\N	\N	Entretien avec Mme Alenka Bratusec, ministre slovène des infrastructures 	Entretien avec Mme Alenka Bratusec, ministre slovène des infrastructures 	2023-06-20 12:30:00	2023-06-20 14:25:00	\N	\N	6	0	529	\N
744641	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion CATDD	\N	2023-06-21 09:32:00	2023-06-21 10:55:00	2023-06-21 12:17:24	2023-06-21 14:42:39	34	2	\N	\N
744790	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réuniion CATDD	\N	2023-06-28 09:30:00	2023-06-28 10:28:00	2023-06-28 12:06:07	2023-06-29 14:30:57	33	0	\N	\N
745904	GIA	AUCUNE	\N	\N	\N	Entretien avec une délégation de députés sénégalais de haut niveau	Entretien avec une délégation de députés sénégalais de haut niveau	2023-06-22 11:45:00	2023-06-22 12:35:00	\N	\N	1	0	573	\N
748105	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-07-06 11:30:00	2023-07-06 13:45:00	2023-07-06 13:52:47	2023-07-07 16:14:47	17	0	\N	\N
748119	COM_EURO	AUDRAP	\N	AFEU	\N	Audition du SGAE - PPRE Irlande du Nord	\N	2023-06-14 16:00:00	2023-06-14 17:00:00	\N	\N	2	0	\N	\N
748123	COM_EURO	AUDRAP	\N	AFEU	\N	Audition de M. Aurélien Antoine, professeur Droit public - PPRE Irlande du Nord	\N	2023-06-15 11:00:00	2023-06-15 12:00:00	\N	\N	2	0	\N	\N
748130	COM_EURO	AUDRAP	\N	AFEU	\N	Audition de la DUE du ministère des Affaires étrangères - PPRE Irlande de Nord	\N	2023-06-16 09:30:00	2023-06-16 10:30:00	\N	\N	2	0	\N	\N
748135	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Régime juridique des actions de groupe	PPL Régime juridique des actions de groupe	2023-06-29 15:00:00	2023-06-29 17:55:00	\N	\N	2	0	\N	\N
752121	DELEGATION	AUCUNE	\N	\N	211	Cérémonie de remise du prix de la DDF 2023	Cérémonie de remise du prix de la DDF 2023	2023-09-19 15:05:00	2023-09-19 16:20:00	\N	\N	11	0	\N	\N
752204	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur CPME - PJL partage de la valeur	\N	2023-09-26 10:45:00	2023-09-26 12:25:00	\N	\N	3	0	\N	\N
752205	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition organisations syndicales - PJL partage de la valeur	\N	2023-09-26 14:30:00	2023-09-26 16:00:00	\N	\N	2	0	\N	\N
752206	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition CAE - PJL partage de la valeur	\N	2023-09-26 16:15:00	2023-09-26 17:15:00	\N	\N	1	0	\N	\N
752207	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Ambassadeurs de la valeur	\N	2023-09-26 17:15:00	2023-09-26 18:15:00	\N	\N	1	0	\N	\N
752208	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition U2P  PJL partage de la valeur	\N	2023-09-26 18:30:00	2023-09-26 19:30:00	\N	\N	1	0	\N	\N
752210	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Commune DGT - DGS	\N	2023-09-27 09:00:00	2023-09-27 10:30:00	\N	\N	3	0	\N	\N
752211	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition MEDEF - PJL partage de la valeur 	\N	2023-09-27 15:00:00	2023-09-27 16:00:00	\N	\N	2	0	\N	\N
752212	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Données de connexion	MI Données de connexion	2023-09-26 08:30:00	2023-09-26 10:45:00	\N	\N	0	0	\N	\N
752219	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Sécurité des élus locaux et protection des maires	PPL Sécurité des élus locaux et protection des maires	2023-09-26 10:05:00	2023-09-26 11:20:00	\N	\N	1	0	\N	\N
752221	DELEGATION	AUCUNE	\N	\N	206	Examen de deux notes scientifiques	\N	2023-09-26 17:05:00	2023-09-26 19:15:00	\N	\N	15	0	\N	\N
740162	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-06-14 10:30:00	2023-06-14 11:40:00	2023-06-14 12:46:38	2023-06-14 15:28:02	41	1	\N	\N
752376	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - SMV - Audition MM. Y. HORTY et D. ANNE	Contrôle 2023 - SMV - Audition MM. Y. HORTY et D. ANNE	2023-09-27 14:00:00	2023-09-27 15:00:00	\N	\N	1	0	\N	\N
752378	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Audition Gén. BRULON/Lcol. MADRIGAL	Contrôle 2023 - Audition Gén. BRULON/Lcol. MADRIGAL	2023-07-10 09:00:00	2023-07-10 18:00:00	\N	\N	1	0	\N	\N
757778	GIA	AUCUNE	\N	\N	\N	Rencontre parlementaire irakienne	Rencontre avec Mme Vian Sabri, députée irakienne, présidente du groupe d'amitié Irak-France	2023-10-20 11:00:00	2023-10-20 11:45:00	\N	\N	1	0	615	\N
757841	DELEGATION	AUCUNE	\N	\N	211	Désignation de rapporteurs pour 2023-2024	\N	2023-11-09 08:35:00	2023-11-09 09:20:00	\N	\N	17	0	\N	\N
757842	DELEGATION	AUCUNE	\N	\N	211	Audition de M.Edouard Durand, magistrat, co-président de la CIIVISE	\N	2023-11-09 09:20:00	2023-11-09 11:00:00	\N	\N	19	0	\N	\N
757843	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF Patrimoine	\N	2023-10-23 09:30:00	2023-10-23 12:30:00	\N	\N	6	0	\N	\N
757844	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition de Mme Rima Abdul Malak	\N	2023-10-24 18:30:00	2023-10-24 20:45:00	2023-10-25 09:03:51	2023-10-25 16:14:44	30	0	\N	\N
757845	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Accès aux soins - Audition de M. Frédéric Valletoux	\N	2023-10-09 15:30:00	2023-10-09 16:30:00	\N	\N	2	0	\N	\N
757848	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2024 Assurance maladie - Table ronde des syndicats d'infirmiers libéraux	\N	2023-10-05 15:00:00	2023-10-05 16:15:00	\N	\N	0	0	\N	\N
757849	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2024 Assurance maladie - Table ronde des fédérations hospitalières	\N	2023-10-10 09:15:00	2023-10-10 10:45:00	\N	\N	5	0	\N	\N
757850	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2024 Assurance maladie - Audition des conférences des présidents de CME de CH et CHU	\N	2023-10-10 15:45:00	2023-10-10 16:45:00	\N	\N	13	0	\N	\N
757861	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition RTE	\N	2023-10-25 09:30:00	2023-10-25 11:50:00	2023-10-25 14:22:58	2023-10-25 16:14:40	40	2	\N	\N
757864	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2024 Assurance maladie - Audition des ordres professionnels	\N	2023-10-10 18:00:00	2023-10-10 19:30:00	\N	\N	9	0	\N	\N
757865	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2024 Assurance maladie - Audition des conférences des DG de CH et CHU	\N	2023-10-10 16:45:00	2023-10-10 17:45:00	\N	\N	7	0	\N	\N
757867	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2024 Assurance maladie - Audition des syndicats représentatifs des médecins libéraux	\N	2023-10-11 13:30:00	2023-10-11 14:30:00	\N	\N	11	0	\N	\N
639005	AUTRE_TEMPORAIRE	AUCUNE	\N	\N	\N	Déplacement dans l'Eure-et-Loir (28)	\N	2022-03-09 10:00:00	2022-03-09 16:00:00	\N	\N	0	0	\N	\N
639440	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	Réunion du Groupe d'études Français de l'étranger	Audition du bureau exécutif et des présidents des commissions de l'AFE	2022-03-15 18:15:00	2022-03-15 20:00:00	\N	\N	18	0	\N	\N
639503	MISSION	AUDRAP	\N	FONDSMER	\N	Audition Amiral Jean-Marc DURANDAU	Audition Amiral Jean-Marc DURANDAU	2022-03-17 17:00:00	2022-03-17 18:00:00	\N	\N	3	0	\N	\N
639507	MISSION	AUDRAP	\N	FONDSMER	\N	Audition DGA	Audition DGA	2022-03-17 18:00:00	2022-03-17 19:10:00	\N	\N	3	0	\N	\N
639526	MISSION	AUDRAP	\N	FONDSMER	\N	Audition SGDSN	Audition SGDSN	2022-03-17 19:15:00	2022-03-17 20:20:00	\N	\N	2	0	\N	\N
639682	GIA	AUCUNE	\N	\N	\N	Audition de M. Alain Bifani, ancien directeur général du ministère des finances du Liban	audition de M. Alain Bifani, ancien directeur général du ministère des finances du Liban	2022-03-09 14:00:00	2022-03-09 15:30:00	\N	\N	4	0	597	\N
639966	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition du général Thierry Burkhard, CEMA	\N	2022-03-29 18:00:00	2022-03-29 19:42:00	2022-03-30 10:44:53	2022-03-30 17:22:24	18	0	\N	\N
640825	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Mission d'information sur la politique étrangère américaine	Mission d'information sur la politique étrangère américaine	2022-03-29 14:00:00	2022-03-29 16:30:00	\N	\N	3	0	\N	\N
640832	GIA	AUCUNE	\N	\N	\N	Déplacement au Maroc de M. Christian Cambon 	Déplacement au Maroc de M. Christian Cambon 	2022-03-29 07:00:00	2022-04-01 20:00:00	\N	\N	1	0	598	\N
644417	GIA	AUCUNE	\N	\N	\N	Célébration anniversaire du Dalaï Lama	Célébration anniversaire du Dalaï Lama	2022-07-06 17:00:00	2022-07-06 19:00:00	\N	\N	3	0	634	\N
644425	GIA	AUCUNE	\N	\N	\N	Entretien avec SEM Jan Emeryk RO¿CISZEWSKI, ambassadeur de Pologne en France	Entretien avec SEM Jan Emeryk RO¿CISZEWSKI, ambassadeur de Pologne en France	2022-06-10 14:30:00	2022-06-10 16:00:00	\N	\N	1	0	600	\N
645213	COM_EURO	AUDRAP	\N	AFEU	\N	Numérisation de la procédure de visas	Numérisation de la procédure de visas	2022-06-21 14:00:00	2022-06-21 15:15:00	\N	\N	2	0	\N	\N
645312	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2022-06-29 10:00:00	2022-06-29 12:00:00	2022-06-29 12:21:24	2022-06-30 12:12:30	47	0	\N	\N
645335	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition de M. Stéphane Bern	\N	2022-06-29 09:30:00	2022-06-29 11:00:00	2022-07-06 16:10:09	2022-07-06 16:12:39	25	0	\N	\N
645336	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition de Mme Rima Abdul-Malak	\N	2022-06-29 15:00:00	2022-06-29 17:00:00	2022-07-06 16:10:36	2022-07-06 16:12:39	21	0	\N	\N
647947	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de la commission - MCC délinquance des mineurs	\N	2022-07-20 09:00:00	2022-07-20 10:30:00	\N	\N	0	0	\N	\N
647948	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de la commission - PQR	\N	2022-07-20 10:30:00	2022-07-20 11:30:00	2022-07-20 16:59:29	2022-07-20 18:40:55	33	4	\N	\N
647949	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de la commission - Audition de Sylvie Retailleau	\N	2022-07-20 16:32:00	2022-07-20 18:00:00	\N	\N	28	0	\N	\N
647950	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	\N	\N	2022-07-11 10:30:00	2022-07-11 11:25:00	2022-07-11 14:55:33	\N	3	0	\N	\N
647959	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2022-07-20 10:00:00	2022-07-20 12:30:00	2022-07-20 14:58:22	2022-07-20 18:40:56	76	0	\N	\N
647960	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Rapport sur les incidents au Stade de France le 28 mai 2022	\N	2022-07-13 10:05:00	2022-07-13 11:35:00	2022-07-15 09:28:34	2022-07-15 16:50:05	59	5	\N	\N
652088	COM_PERMANENTE	AUTRE	\N	CAE	\N	Table ronde ZAN	\N	2022-07-27 09:35:00	2022-07-27 11:55:00	2022-07-27 14:37:01	2022-07-27 18:10:32	40	0	\N	\N
652165	COM_PERMANENTE	AUTRE	\N	CDD	\N	\N	\N	2022-07-27 11:30:00	2022-07-27 13:27:00	2022-07-28 09:45:45	2022-07-28 16:07:40	35	2	\N	\N
652464	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de Mme Agnès Pannier-Runacher	\N	2022-07-27 16:35:00	2022-07-27 18:55:00	2022-07-27 19:09:00	2022-07-28 16:07:40	32	0	\N	\N
652465	ETUDES	AUTRE	\N	\N	\N	Audition Caisse des dépôts	Audition Caisse des dépôts	2022-07-26 17:00:00	2022-07-26 18:35:00	\N	\N	7	0	\N	918
661905	DELEGATION	AUCUNE	\N	\N	DSOM	Réunion de la délégation	\N	2022-10-20 08:00:00	2022-10-20 11:45:00	\N	\N	9	0	\N	\N
661908	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	¨PLF 2023 JVA	\N	2022-10-17 15:00:00	2022-10-17 16:00:00	\N	\N	2	0	\N	\N
661911	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2023 création	\N	2022-10-17 10:00:00	2022-10-17 10:50:00	\N	\N	2	0	\N	\N
668110	DELEGATION	AUCUNE	\N	\N	COLTER	Réunion plénière	\N	2022-11-17 09:30:00	2022-11-17 11:55:00	\N	\N	23	0	\N	\N
661941	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - La DCPJ - DCPJ/Syndicat Alliance/Syndicat FSMI-FO unité SGP	Contrôle 2020 - La DCPJ - DCPJ/Syndicat Alliance/Syndicat FSMI-FO unité SGP	2022-10-14 14:30:00	2022-10-14 18:45:00	\N	\N	1	0	\N	\N
661943	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - R & D - DGFIP	PLF pour 2023 - R & D - DGFIP	2022-10-13 17:30:00	2022-10-13 19:00:00	\N	\N	1	0	\N	\N
661945	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - CAS PFE - APE	PLF pour 2023 - CAS PFE - APE	2022-10-11 14:00:00	2022-10-11 15:30:00	\N	\N	1	0	\N	\N
661947	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - CAS PFE - Cour des comptes	PLF pour 2023 - CAS PFE - Cour des comptes	2022-10-11 16:30:00	2022-10-11 17:30:00	\N	\N	1	0	\N	\N
661949	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - CAS PFE - Air France	PLF pour 2023 - CAS PFE - Air France	2022-10-12 17:30:00	2022-10-12 18:30:00	\N	\N	1	0	\N	\N
661951	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - CAS PFE - BpiFrance/EDF	PLF pour 2023 - CAS PFE - BpiFrance/EDF	2022-10-13 15:00:00	2022-10-13 17:00:00	\N	\N	1	0	\N	\N
661953	COM_PERMANENTE	AUTRE	\N	FINC	\N	MI Fraude et évasion fiscales - Conclusion de la MI Fraude	MI Fraude et évasion fiscales - Conclusion de la MI Fraude	2022-10-12 16:30:00	2022-10-12 18:00:00	\N	\N	13	0	\N	\N
661967	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Sport - Direction des sports/Agence Service civique	PLF pour 2023 - Sport - Direction des sports/Agence Service civique	2022-10-11 14:00:00	2022-10-11 16:00:00	\N	\N	1	0	\N	\N
661969	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Sport - Le Mouvement associatif 	PLF pour 2023 - Sport - Le Mouvement associatif 	2022-10-12 17:00:00	2022-10-12 18:00:00	\N	\N	1	0	\N	\N
661971	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Mission Flash 2022 - Dons associations - DJEPVA	Mission Flash 2022 - Dons associations - DJEPVA	2022-10-12 18:00:00	2022-10-12 18:45:00	\N	\N	2	0	\N	\N
661974	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Sport - DJEPVA	PLF pour 2023 - Sport - DJEPVA	2022-10-12 18:45:00	2022-10-12 20:00:00	\N	\N	1	0	\N	\N
661976	COM_PERMANENTE	AUDRAP	\N	FINC	\N	LPFP pour 2023 à 2027 - DB et DG Trésor	LPFP pour 2023 à 2027 - DB et DG Trésor	2022-10-12 19:00:00	2022-10-12 20:30:00	\N	\N	12	0	\N	\N
663502	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2023 - AT-MP - Audition CCMSA	\N	2022-10-18 16:30:00	2022-10-18 17:30:00	\N	\N	1	0	\N	\N
663580	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - PFUE - DB	PLF pour 2023 - PFUE - DB	2022-10-18 12:00:00	2022-10-18 13:15:00	\N	\N	1	0	\N	\N
663585	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - PFUE - DG Trésor	PLF pour 2023 - PFUE - DG Trésor	2022-10-19 11:00:00	2022-10-19 12:20:00	\N	\N	1	0	\N	\N
664315	GIA	AUCUNE	\N	\N	\N	Entretien avec le SamuSocial International	Entretien avec le SamuSocial International	2022-10-19 14:00:00	2022-10-19 15:00:00	\N	\N	2	0	979	\N
664337	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLF 2023 - Fonction publique	Audition rapporteur - PJLF 2023 - avis "fonction publique"	2022-10-18 16:35:00	2022-10-18 17:40:00	\N	\N	1	0	\N	\N
666503	GIA	AUCUNE	\N	\N	\N	Audition du général Thierry Marchand, nouvel ambassadeur de France au Cameroun	Audition du général Thierry Marchand, nouvel ambassadeur de France au Cameroun	2022-09-28 18:30:00	2022-09-28 19:15:00	\N	\N	1	0	572	\N
667475	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - EFE - Banque de France	PLF pour 2023 - EFE - Banque de France	2022-10-25 10:30:00	2022-10-25 12:00:00	\N	\N	1	0	\N	\N
667485	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - EFE - École d'économie de Paris	PLF pour 2023 - EFE - École d'économie de Paris	2022-10-26 16:00:00	2022-10-26 17:00:00	\N	\N	1	0	\N	\N
667522	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFS 2023 Autonomie - Audition de l'AdF	\N	2022-10-26 14:00:00	2022-10-26 15:00:00	\N	\N	2	0	\N	\N
667527	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2023 Assurance maladie - Audition du CNOI	\N	2022-10-26 13:30:00	2022-10-26 14:15:00	\N	\N	1	0	\N	\N
667528	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2023 Assurance maladie - Audition de la Mutualité française	\N	2022-10-26 17:00:00	2022-10-26 18:00:00	\N	\N	3	0	\N	\N
672578	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF 2023 : Examen Amdts séance Première Partie	PLF 2023 : Examen Amdts séance Première Partie	2022-11-18 14:05:00	2022-11-18 15:05:00	2022-11-18 15:24:28	2022-11-18 16:03:31	19	3	\N	\N
698980	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT 212 LPM 	GT 212 LPM	2023-01-31 16:00:00	2023-01-31 17:30:00	\N	\N	1	0	\N	\N
722847	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI PreParE - Audition HCFEA	\N	2023-04-11 09:00:00	2023-04-11 09:45:00	\N	\N	2	0	\N	\N
722861	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - EPF et EPA - Audition M. BOURRON (ANCT)	Contrôle 2023 - EPF et EPA - Audition M. BOURRON (ANCT)	2023-04-05 17:00:00	2023-04-05 17:55:00	\N	\N	1	0	\N	\N
722863	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - EPF et EPA - Audition MM. BROUARD-MASSON et VALIERE (ANAH)	Contrôle 2023 - EPF et EPA - Audition MM. BROUARD-MASSON et VALIERE (ANAH)	2023-04-05 17:55:00	2023-04-05 18:35:00	\N	\N	1	0	\N	\N
722904	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 Financements extrabudgétaire culture - audition Cour de Comptes	58-2 Financements extrabudgétaire culture - audition Cour de Comptes	2023-04-05 10:00:00	2023-04-05 10:50:00	\N	\N	3	0	\N	\N
722829	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL Accessibilité et inclusion bancaire - Audition MM. HEIM et IMBERT, La Banque Postale	PPL Accessibilité et inclusion bancaire - Audition MM. HEIM et IMBERT, La Banque Postale	2023-04-04 18:00:00	2023-04-04 19:00:00	\N	\N	1	0	\N	\N
722832	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL Accessibilité et inclusion bancaire - Audition Fédération bancaire française	PPL Accessibilité et inclusion bancaire - Audition Fédération bancaire française	2023-04-05 14:15:00	2023-04-05 15:00:00	\N	\N	1	0	\N	\N
722955	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI PreParE - Audition Cnaf	\N	2023-04-11 14:30:00	2023-04-11 15:30:00	\N	\N	2	0	\N	\N
722970	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Sécurités - Audition SIRASCO et OCLCO	Contrôle 2023 - Sécurités - Audition SIRASCO et OCLCO	2023-04-03 10:30:00	2023-04-03 12:00:00	\N	\N	1	0	\N	\N
723012	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Fonds de garantie de Bpifrance - Audition MM. CHABROL et ROBERT, DG Trésor	Contrôle 2023 - Fonds de garantie de Bpifrance - Audition MM. CHABROL et ROBERT, DG Trésor	2023-04-04 16:30:00	2023-04-04 17:45:00	\N	\N	2	0	\N	\N
723028	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Service de santé des armées - Audition DCSSA	Contrôle 2023 - Service de santé des armées - Audition DCSSA	2023-04-04 17:00:00	2023-04-04 18:30:00	\N	\N	1	0	\N	\N
723037	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Formation continue des enseignants - Audition CNESCO	Contrôle 2023 - Formation continue des enseignants - Audition CNESCO	2023-04-04 10:00:00	2023-04-04 11:00:00	\N	\N	1	0	\N	\N
723043	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 203 - Formation continue enseignants - Audition DEPP	Contrôle 203 - Formation continue enseignants - Audition DEPP	2023-04-04 15:30:00	2023-04-04 16:30:00	\N	\N	1	0	\N	\N
723045	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PPL Influenceurs	\N	2023-04-07 17:00:00	2023-04-07 18:30:00	\N	\N	1	0	\N	\N
668146	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2023 - Solidarité - Audition Uniopss	\N	2022-11-03 09:30:00	2022-11-03 10:30:00	\N	\N	1	0	\N	\N
723057	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL Accessibilité et inclusion bancaire - Audition Mmes MERLE et PAOLONI DG Trésor	PPL Accessibilité et inclusion bancaire - Audition Mmes MERLE et PAOLONI DG Trésor	2023-04-05 13:15:00	2023-04-05 14:15:00	\N	\N	1	0	\N	\N
723059	MISSION	AUTRE	\N	BIOCARBU	\N	MI BIOCARBURANT - 11	\N	2023-04-11 16:30:00	2023-04-11 18:00:00	2023-04-11 18:18:42	2023-04-12 17:26:16	5	0	\N	\N
723065	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI PreParE - Audition Unaf	\N	2023-04-11 15:30:00	2023-04-11 16:15:00	\N	\N	2	0	\N	\N
723192	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - CESE - Audition M. LEVY, directeur délégué Harris Interactive France	Contrôle 2023 - CESE - Audition M. LEVY, directeur délégué Harris Interactive France	2023-04-04 16:15:00	2023-04-04 17:00:00	\N	\N	1	0	\N	\N
723199	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - CESE - Audition M. BUGE, Conseil d'Etat	Contrôle 2023 - CESE - Audition M. BUGE, Conseil d'Etat	2023-04-04 17:25:00	2023-04-04 18:30:00	\N	\N	1	0	\N	\N
725037	ETUDES	AUCUNE	\N	\N	\N	Audition Euroforest	Audition Euroforest	2023-04-12 08:00:00	2023-04-12 09:30:00	\N	\N	8	0	\N	948
725340	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PPL Influenceurs	\N	2023-04-12 17:30:00	2023-04-12 19:45:00	\N	\N	1	0	\N	\N
725343	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PPL Influenceurs	\N	2023-04-12 11:00:00	2023-04-12 13:15:00	\N	\N	1	0	\N	\N
725345	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PPL Influenceurs	\N	2023-04-11 16:45:00	2023-04-11 20:00:00	\N	\N	3	0	\N	\N
725350	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Direction générale des médias et des industries culturelles - ministère de la culture	\N	2023-04-13 09:30:00	2023-04-13 10:15:00	\N	\N	4	0	\N	\N
725351	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Audition commune musée du Louvre + musée d'Orsay	\N	2023-04-13 10:15:00	2023-04-13 11:40:00	\N	\N	4	0	\N	\N
725441	DELEGATION	AUDRAP	\N	\N	PROS	Audition de Mme Viau	\N	2023-04-12 17:30:00	2023-04-12 18:30:00	\N	\N	2	0	\N	\N
725448	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Application des lois Protection de l'enfance - Table ronde d'associations	\N	2023-04-11 17:30:00	2023-04-11 18:30:00	\N	\N	3	0	\N	\N
725449	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Application des lois Protection de l'enfance - Audition de la CNPR	\N	2023-04-11 18:30:00	2023-04-11 19:30:00	\N	\N	2	0	\N	\N
725450	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Application des lois Protection de l'enfance - Table ronde de syndicats	\N	2023-04-12 13:30:00	2023-04-12 14:45:00	\N	\N	3	0	\N	\N
725451	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Fin de vie - Audition de MM. Theo Boer et Michel Bureau	\N	2023-04-11 15:15:00	2023-04-11 16:30:00	\N	\N	3	0	\N	\N
725452	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Données de santé - Audition de la Drees	\N	2023-04-11 16:30:00	2023-04-11 18:00:00	\N	\N	3	0	\N	\N
725627	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-05-03 09:00:00	2023-05-03 11:00:00	2023-05-10 14:19:26	2023-05-10 14:53:33	45	0	\N	\N
725629	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Data act	\N	2023-04-19 09:15:00	2023-04-19 12:00:00	\N	\N	3	0	\N	\N
725633	MISSION	AUCUNE	\N	GEAU	\N	Audition CESE	\N	2023-05-03 14:00:00	2023-05-03 15:00:00	2023-05-03 16:18:37	2023-05-03 18:04:21	12	0	\N	\N
725634	MISSION	AUCUNE	\N	GEAU	\N	Audition de la FNCCR	\N	2023-05-04 11:00:00	2023-05-04 12:10:00	2023-05-04 12:18:00	2023-05-04 15:53:42	4	0	\N	\N
725635	MISSION	AUCUNE	\N	GEAU	\N	Audition de la FP2E	\N	2023-05-04 12:15:00	2023-05-04 13:10:00	2023-05-04 18:03:52	2023-05-05 18:05:26	2	0	\N	\N
725827	MISSION	AUTRE	\N	LOCA	\N	Table ronde conjointe avec la DCT	\N	2023-05-04 10:30:00	2023-05-04 12:00:00	2023-05-10 13:02:20	2023-05-10 14:54:17	18	0	\N	\N
725867	MECSS	AUDRAP	\N	\N	MECSS	Mecss - MI Organismes financés par les Robss - Audition Oniam	\N	2023-04-27 10:00:00	2023-04-27 11:00:00	\N	\N	2	0	\N	\N
725868	MECSS	AUDRAP	\N	\N	MECSS	Mecss - MI Organismes financés par les Robss - Audition EHESP	\N	2023-04-27 11:00:00	2023-04-27 12:00:00	\N	\N	2	0	\N	\N
725882	MISSION	AUTRE	\N	LOCA	\N	Audition De Mme Cécile RAQUIN, DGCT	\N	2023-05-09 09:15:00	2023-05-09 10:15:00	\N	\N	0	0	\N	\N
725883	MISSION	AUDRAP	\N	LOCA	\N	Audition M. HOME, APVF	\N	2023-05-10 16:30:00	2023-05-10 18:00:00	\N	\N	7	0	\N	\N
725884	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Mme Sophie PRIMAS - PPL Ferme France	Auditions Mme Sophie PRIMAS - PPL Ferme France	2023-04-25 09:00:00	2023-04-25 12:15:00	\N	\N	1	0	\N	\N
725886	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Mme Sophie PRIMAS - PPL Ferme France	Auditions Mme Sophie PRIMAS - PPL Ferme France	2023-04-25 14:00:00	2023-04-25 18:30:00	\N	\N	1	0	\N	\N
725888	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Mme Sophie Primas - PPL Ferme France	Auditions Mme Sophie Primas - PPL Ferme France	2023-04-26 09:00:00	2023-04-26 12:30:00	\N	\N	1	0	\N	\N
725890	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Mme Sophie Primas - PPL Ferme France	Auditions Mme Sophie Primas - PPL Ferme France	2023-04-27 09:00:00	2023-04-27 13:15:00	\N	\N	1	0	\N	\N
725892	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Conseil national de l'Eau - PPL Ferme France	Conseil national de l'Eau - PPL Ferme France	2023-04-26 14:45:00	2023-04-26 15:30:00	\N	\N	2	0	\N	\N
725895	COM_PERMANENTE	AUDRAP	\N	CAE	\N	DGPR - PPL Ferme France	DGPR - PPL Ferme France	2023-04-26 15:30:00	2023-04-26 16:30:00	\N	\N	2	0	\N	\N
725898	COM_PERMANENTE	AUDRAP	\N	CAE	\N	France Nature Environnement - PPL Ferme France	France Nature Environnement - PPL Ferme France	2023-04-26 16:45:00	2023-04-26 17:30:00	\N	\N	1	0	\N	\N
639759	SEANCE_PLENIERE	ALLOCUTION	\N	\N	\N	Allocution du Président d'Ukraine	Allocution du Président d'Ukraine	2022-03-23 15:00:00	2022-03-23 15:30:00	\N	\N	157	0	\N	\N
640514	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Rapporteur MI Ehpad - 	\N	2022-03-30 15:30:00	2022-03-30 17:00:00	\N	\N	4	0	\N	\N
640515	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Rapporteur MI Ehpad - ARS Pays de la Loire	\N	2022-03-30 14:00:00	2022-03-30 15:30:00	\N	\N	2	0	\N	\N
640516	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audtion rapporteur MI Epahd - Audition DRIEETS	\N	2022-03-30 18:00:00	2022-03-30 19:00:00	\N	\N	2	0	\N	\N
640517	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Rapporteur MI Ehpad - Audition ADPA	\N	2022-03-30 17:00:00	2022-03-30 18:00:00	\N	\N	3	0	\N	\N
640518	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Rapporteur MI Ehpad - Audition  ARS Grand Est	\N	2022-03-30 15:30:00	2022-03-30 17:00:00	\N	\N	3	0	\N	\N
640538	MISSION	AUCUNE	\N	RECHINNO	\N	Auditions plénières	\N	2022-03-30 10:00:00	2022-03-30 12:00:00	2022-03-30 17:52:42	2022-03-31 16:42:23	3	0	\N	\N
640545	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Souveraineté économique - Table ronde Gaia-X, Cispe, Cigref, OVHcloud	MI Souveraineté économique - Table ronde Gaia-X, Cispe, Cigref, OVHcloud	2022-03-23 10:00:00	2022-03-23 11:30:00	\N	\N	2	0	\N	\N
640573	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Souveraineté économique - Auditions	MI Souveraineté économique - Auditions	2022-03-23 15:45:00	2022-03-23 19:35:00	\N	\N	3	0	\N	\N
640621	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Centra national de recherche scientifique 	Audition de Mme Fornerod	2022-03-30 10:30:00	2022-03-30 11:30:00	\N	\N	3	0	\N	\N
640622	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Dartagnans	\N	2022-03-30 11:30:00	2022-03-30 12:20:00	\N	\N	2	0	\N	\N
725628	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-05-03 11:00:00	2023-05-03 12:20:00	2023-05-10 14:19:10	2023-05-10 14:53:32	45	0	\N	\N
641605	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	MI Question migratoire - déplacement à Angers	MI Question migratoire - déplacement à Angers	2022-04-19 07:00:00	2022-04-19 19:30:00	\N	\N	4	0	\N	\N
641624	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Audition du CMN	\N	2022-04-19 15:00:00	2022-04-19 16:30:00	\N	\N	2	0	\N	\N
645492	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2022-06-21 14:30:00	2022-06-21 16:10:00	\N	\N	3	0	\N	\N
651645	COM_PERMANENTE	AUTRE	\N	CAE	\N	Examen du rapport pour avis PJL pouvoir d'achat	\N	2022-07-25 15:00:00	2022-07-25 16:50:00	2022-07-25 19:26:42	2022-07-26 17:29:46	24	4	\N	\N
651648	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Mission Flash dons associations - DGFiP	Mission Flash dons associations - DGFiP	2022-07-21 16:00:00	2022-07-21 17:00:00	\N	\N	2	0	\N	\N
655365	GIA	AUCUNE	\N	\N	\N	Entretien avec l'Ambassadeur de Roumanie en France	Entretien avec l'Ambassadeur de Roumanie en France	2022-08-03 10:00:00	2022-08-03 11:00:00	\N	\N	6	0	605	\N
655372	GIA	AUCUNE	\N	\N	\N	Entretien avec Mme Oksana POKALCHUK (Amnesty International Ukraine)	Entretien avec Mme Oksana POKALCHUK (Amnesty International Ukraine)	2022-06-29 08:30:00	2022-06-29 09:30:00	\N	\N	6	0	530	\N
655379	GIA	AUCUNE	\N	\N	\N	Rencontre avec le Comité représentatif de la communauté ukrainienne en France 	Rencontre avec le Comité représentatif de la communauté ukrainienne en France 	2022-06-21 10:00:00	2022-06-21 11:00:00	\N	\N	5	0	530	\N
665025	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2023 Presse	\N	2022-10-20 11:30:00	2022-10-20 12:30:00	\N	\N	1	0	\N	\N
665027	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2023 Presse	\N	2022-10-20 14:30:00	2022-10-20 15:30:00	\N	\N	1	0	\N	\N
665358	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2023 - P 178	\N	2022-10-18 13:30:00	2022-10-18 14:20:00	\N	\N	2	0	\N	\N
665361	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2023 - P 178	\N	2022-10-18 16:00:00	2022-10-18 17:30:00	\N	\N	2	0	\N	\N
665364	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI Indopacifique	\N	2022-10-20 17:30:00	2022-10-20 18:30:00	\N	\N	2	0	\N	\N
665371	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure du 13 octobre 2022	Conseil de Questure du 13 octobre 2022	2022-10-13 09:00:00	2022-10-13 11:30:00	\N	\N	3	0	\N	\N
665657	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Avis Outre-mer - Micheline Jacques	\N	2022-10-21 10:30:00	2022-10-21 11:30:00	\N	\N	1	0	\N	\N
665660	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Avis Outre-mer - Micheline Jacques	\N	2022-10-21 14:00:00	2022-10-21 18:00:00	\N	\N	1	0	\N	\N
665663	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Avis Outre-mer - Micheline Jacques	\N	2022-10-24 09:30:00	2022-10-24 10:30:00	\N	\N	1	0	\N	\N
665666	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Avis Outre-mer - Micheline Jacques	\N	2022-10-24 14:00:00	2022-10-24 17:00:00	\N	\N	1	0	\N	\N
665884	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Sécurités - Sécurité Civile  - DGSCGC/FNSPF	PLF pour 2023 - Sécurités - Sécurité Civile  - DGSCGC/FNSPF	2022-10-25 09:30:00	2022-10-25 11:45:00	\N	\N	1	0	\N	\N
665889	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2023 - Équilibres financiers généraux - Audition CDC	\N	2022-10-25 16:00:00	2022-10-25 16:45:00	\N	\N	2	0	\N	\N
665898	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	France Télévisions	\N	2022-10-25 14:00:00	2022-10-25 15:00:00	\N	\N	2	0	\N	\N
665899	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Arte France	\N	2022-10-25 15:00:00	2022-10-25 16:00:00	\N	\N	1	0	\N	\N
665904	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Fondation du patrimoine	\N	2022-10-25 14:00:00	2022-10-25 15:00:00	\N	\N	1	0	\N	\N
666520	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Budget 2023 PLF pour 2023 - Avis "Immigration, asile et intégration	Avis "Immigration, asile et intégration" - DCPAF et OCRIEST	2022-10-26 10:00:00	2022-10-26 11:30:00	2022-10-26 12:25:01	\N	3	0	\N	\N
667237	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2023 Avis budgétaires "Sécurités"	PLF 2023 Avis budgétaires "Sécurités"	2022-10-26 11:20:00	2022-10-26 12:50:00	\N	\N	1	0	\N	\N
667240	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2023 - Direction générale de la gendarmerie nationale	PLF pour 2023 - Direction générale de la gendarmerie nationale	2022-11-02 12:15:00	2022-11-02 13:00:00	\N	\N	2	0	\N	\N
667453	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2023 - Solidarité - Audition DIPLP	\N	2022-10-27 08:30:00	2022-10-27 09:30:00	\N	\N	1	0	\N	\N
667455	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS - Branche ATMP - Audition de la DSS	\N	2022-10-26 14:00:00	2022-10-26 14:45:00	\N	\N	1	0	\N	\N
667697	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF 2023: PSR-UE Art 25-Compte rendu Prague conférence TSCG	PLF 2023: PSR-UE Art 25-Compte rendu Prague conférence TSCG	2022-11-02 14:00:00	2022-11-02 14:50:00	2022-11-02 15:15:07	2022-11-02 17:47:05	19	2	\N	\N
667698	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLFR(2) 2022 Audition Ministre-PLF 2023: Enseignement scolaire	PLFR(2) 2022 Audition Ministre-PLF 2023: Enseignement scolaire	2022-11-03 10:00:00	2022-11-03 12:45:00	2022-11-03 14:46:34	2022-11-03 17:38:02	29	2	\N	\N
667701	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 27/10/22	\N	2022-10-27 08:30:00	2022-10-27 10:00:00	\N	\N	0	0	\N	\N
667730	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Enseignement supérieur - DGESIP	PLF pour 2023 - Enseignement supérieur - DGESIP	2022-10-25 16:00:00	2022-10-25 17:30:00	\N	\N	1	0	\N	\N
667732	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	PLF 2023 - P. 152	PLF 2023 - P. 152	2022-10-27 09:00:00	2022-10-27 13:30:00	\N	\N	2	0	\N	\N
667735	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2023 Assurance maladie - Audition de la Conférence nationale des PCME des CH	\N	2022-10-28 14:00:00	2022-10-28 15:00:00	\N	\N	2	0	\N	\N
667738	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Centre des monuments nationaux	\N	2022-10-28 12:00:00	2022-10-28 13:00:00	\N	\N	3	0	\N	\N
667818	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2022-11-09 16:30:00	2022-11-09 17:30:00	\N	\N	28	0	\N	\N
667913	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition SGPI 	\N	2022-11-02 09:45:00	2022-11-02 11:15:00	2022-11-02 14:42:51	2022-11-02 17:47:08	37	2	\N	\N
668105	DELEGATION	AUCUNE	\N	\N	206	Audition publique sur les enjeux du conseil ministériel de l'Agence spatiale européenne	\N	2022-11-03 09:40:00	2022-11-03 12:10:00	\N	\N	8	0	\N	\N
667696	COM_PERMANENTE	AUTRE	\N	FINC	\N	LPFP:AMDTS séance - PLF 2023:Tome 1-PLFSS:Avis-PLF2023:Santé et Retraite et pensions	LPFP:AMDTS séance - PLF 2023:Tome 1-PLFSS:Avis-PLF2023:Santé et Retraite et pensions	2022-11-02 09:00:00	2022-11-02 12:05:00	2022-11-02 12:23:13	2022-11-02 17:47:10	37	1	\N	\N
667816	COM_PERMANENTE	AUTRE	\N	CDD	\N	\N	\N	2022-11-09 09:00:00	2022-11-09 10:35:00	\N	\N	37	2	\N	\N
667819	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-11-02 08:35:00	2022-11-02 12:55:00	2022-11-02 12:54:38	2022-11-02 17:47:09	39	0	\N	\N
667912	COM_PERMANENTE	AUTRE	\N	CAE	\N	PJL ENR - examen amendements de séance	\N	2022-11-02 09:00:00	2022-11-02 09:20:00	2022-11-02 14:42:08	2022-11-02 17:47:10	37	2	\N	\N
688510	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Raoul M. JENNAR, conseiller diplomatique du Cambodge	Entretien avec M. Raoul M. JENNAR, conseiller diplomatique du Cambodge	2022-12-19 17:30:00	2022-12-19 19:00:00	\N	\N	1	0	577	\N
688526	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2022-12-14 18:04:00	2022-12-14 18:58:00	\N	\N	25	0	\N	\N
688552	GIA	AUCUNE	\N	\N	\N	Audition de democrats abroad France	Audition de democrats abroad France	2022-12-06 18:00:00	2022-12-06 19:30:00	\N	\N	5	0	590	\N
688558	GIA	AUCUNE	\N	\N	\N	Entretien avec Mme Allard, présidente de la COCEF	Entretien avec Mme Allard, présidente de la COCEF	2022-12-09 14:30:00	2022-12-09 16:00:00	\N	\N	1	0	589	\N
688560	GIA	AUCUNE	\N	\N	\N	Entretien avec M. David Leischman, conseiller agriculture de l'ambassade US	Entretien avec M. David Leischman, conseiller agriculture de l'ambassade US	2022-12-06 12:30:00	2022-12-06 14:30:00	\N	\N	1	0	590	\N
694345	GIA	AUCUNE	\N	\N	\N	Audition de l'ambassadeur de France au Ghana 	Audition de l'ambassadeur de France au Ghana	2023-01-25 14:05:00	2023-01-25 15:00:00	\N	\N	5	0	573	\N
694354	GIA	AUCUNE	\N	\N	\N	Situation au Tigré 	Entretien avec des représentants de Amnesty International et Human Rights Watch sur la situation au Tigré	2023-01-25 12:30:00	2023-01-25 14:00:00	\N	\N	3	0	588	\N
694357	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - PPRE Frontex	\N	2023-01-25 14:00:00	2023-01-25 15:00:00	\N	\N	2	0	\N	\N
740752	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Reconnaissance biométrique (amendements)	PPL Reconnaissance biométrique (amendements)	2023-06-12 15:30:00	2023-06-12 15:35:00	2023-06-12 15:41:44	2023-06-12 17:20:35	10	0	\N	\N
740753	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Programmation militaire - PJL Industrie verte (avis)	PJL Programmation militaire - PJL Industrie verte (avis)	2023-06-13 09:00:00	2023-06-13 10:05:00	2023-06-13 15:20:48	2023-06-14 15:27:55	18	1	\N	\N
740755	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de Claire Hédon, Défenseure des droits	Audition de Claire Hédon, Défenseure des droits	2023-06-14 10:40:00	2023-06-14 12:00:00	2023-06-14 12:37:11	2023-06-14 15:28:03	37	0	\N	\N
740756	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Programmation militaire 2024/2030 - Entretien Général BARRERA et M. SAIX	PJL Programmation militaire 2024/2030 - Entretien Général BARRERA et M. SAIX	2023-06-06 18:00:00	2023-06-06 19:45:00	\N	\N	1	0	\N	\N
740758	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Pass Culture - Audition DG2TDC	Contrôle 2023 - Pass Culture - Audition DG2TDC	2023-06-07 16:05:00	2023-06-07 16:45:00	\N	\N	2	0	\N	\N
740761	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - ORE - Audition HCERES	Contrôle 2023 - ORE - Audition HCERES	2023-06-07 14:15:00	2023-06-07 15:00:00	\N	\N	1	0	\N	\N
740766	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - CESE - Audition MM. David DJAIZ et Clément TONON	Contrôle 2023 - CESE - Audition MM. David DJAIZ et Clément TONON	2023-06-06 16:45:00	2023-06-06 17:45:00	\N	\N	1	0	\N	\N
740768	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - EPF/EPA - Audition EPF d'Occitanie	Contrôle 2023 - EPF/EPA - Audition EPF d'Occitanie	2023-06-02 10:00:00	2023-06-02 16:30:00	\N	\N	1	0	\N	\N
741907	COM_SPECIALE	AUDRAP	\N	ESNU	\N	PJL Sécuriser et réguler l'espace numérique	PJL Sécuriser et réguler l'espace numérique	2023-06-12 18:30:00	2023-06-12 19:45:00	\N	\N	2	0	\N	\N
744168	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Industrie verte	PJL Industrie verte	2023-06-20 14:30:00	2023-06-20 20:00:00	\N	\N	147	0	\N	\N
744169	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Conseil européen des 29 et 30 juin 2023	Débat Conseil européen des 29 et 30 juin 2023	2023-06-20 21:30:00	2023-06-20 23:50:00	\N	\N	37	0	\N	\N
744170	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2023-06-21 15:00:00	2023-06-21 16:20:00	\N	\N	264	0	\N	\N
744171	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Dumping social sur le transmanche	PPL Dumping social sur le transmanche	2023-06-21 16:30:00	2023-06-21 19:30:00	\N	\N	81	0	\N	\N
744172	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Industrie verte	PJL Industrie verte	2023-06-21 21:40:00	2023-06-22 01:05:00	\N	\N	47	0	\N	\N
744173	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Industrie verte	PJL Industrie verte	2023-06-21 19:30:00	2023-06-21 20:10:00	\N	\N	36	0	\N	\N
744174	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Industrie verte	PJL Industrie verte	2023-06-22 10:30:00	2023-06-22 13:15:00	\N	\N	48	0	\N	\N
744175	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Industrie verte	PJL Industrie verte	2023-06-22 15:20:00	2023-06-22 18:40:00	\N	\N	41	0	\N	\N
744176	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Industrie verte	PJL Industrie verte	2023-06-22 21:30:00	2023-06-22 23:30:00	\N	\N	0	0	\N	\N
744177	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	NL PPL Indices locatifs	NL PPL Indices locatifs	2023-06-22 14:45:00	2023-06-22 15:15:00	\N	\N	23	0	\N	\N
745677	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2023-06-21 17:00:00	2023-06-21 18:45:00	\N	\N	2	0	\N	\N
749513	ETUDES	AUTRE	\N	\N	\N	Audition de représentants de la filière Noix	Audition de représentants de la filière Noix	2023-07-05 13:30:00	2023-07-05 15:00:00	\N	\N	6	0	\N	1005
749769	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion CATDD	\N	2023-07-05 16:30:00	2023-07-05 17:38:00	2023-07-05 18:04:00	2023-07-05 18:21:42	22	0	\N	\N
750403	GIA	AUCUNE	\N	\N	\N	Déjeuner avec le nouvel ambassadeur du Brésil en France	Déjeuner de travail avec S.E. M. Ricardo Neiva Tavares, ambassadeur du Brésil en France	2023-06-14 13:00:00	2023-06-14 14:00:00	\N	\N	7	0	576	\N
750773	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Données de connexion	MI Données de connexion	2023-07-11 10:00:00	2023-07-11 11:00:00	\N	\N	3	0	\N	\N
751529	GIA	AUCUNE	\N	\N	\N	Entretien avec Mme Mathilde Teruya, Sous-directice d'Asie du Sud-Est du MEAE	Entretien avec Mme Mathilde Teruya, Sous-directice d'Asie du Sud-Est du MEAE	2023-07-12 08:30:00	2023-07-12 09:45:00	\N	\N	6	0	577	\N
751951	GIA	AUCUNE	\N	\N	\N	Dîner en présence d'une délégation du Parlement arménien	Entretien avec une délégation de parlementaires arméniens	2023-07-10 20:30:00	2023-07-10 22:20:00	\N	\N	5	0	641	\N
751957	GIA	AUCUNE	\N	\N	\N	Dîner en présence d'une délégation du Parlement malaisien	Entretien avec une délégation de l'Asemblée nationale de Malaisie	2023-07-11 19:30:00	2023-07-11 22:00:00	\N	\N	10	0	609	\N
751968	GIA	AUCUNE	\N	\N	\N	Audition de la Fédération des Yézidis	Entretien 	2023-07-04 16:45:00	2023-07-04 17:45:00	\N	\N	6	0	CHRETORIENT	CHRETORIENT
752364	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI expertise patrimoniale	\N	2023-09-27 09:30:00	2023-09-27 12:00:00	\N	\N	3	0	\N	\N
752368	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI expertise patrimoniale	\N	2023-09-27 14:15:00	2023-09-27 17:45:00	\N	\N	2	0	\N	\N
752371	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI expertise patrimoniale	\N	2023-09-28 09:30:00	2023-09-28 11:00:00	\N	\N	2	0	\N	\N
756165	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Amnistie	Amnistie des faits commis à l'occasion de mouvements sociaux 	2023-10-17 09:30:00	2023-10-17 09:45:00	\N	\N	2	0	\N	\N
757766	GIA	AUCUNE	\N	\N	\N	Coopé - Entretien avec M. Quinton LUCAS, Maire de Kansas City	Coopé - Entretien avec M. Quinton LUCAS, Maire de Kansas City	2023-10-18 16:30:00	2023-10-18 17:30:00	\N	\N	1	0	590	\N
757790	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL services express régionaux métropolitains	PPL services express régionaux métropolitains	2023-10-23 16:00:00	2023-10-23 20:05:00	\N	\N	50	0	\N	\N
757793	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL RATP	PPL RATP	2023-10-23 21:35:00	2023-10-24 01:10:00	\N	\N	38	0	\N	\N
757795	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Accès aux soins	PPL Accès aux soins	2023-10-24 14:30:00	2023-10-24 17:25:00	\N	\N	161	0	\N	\N
757796	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Accès aux soins	PPL Accès aux soins	2023-10-24 21:00:00	2023-10-25 00:35:00	\N	\N	84	0	\N	\N
757797	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat 50-1 Proche Orient	Débat 50-1 Proche Orient	2023-10-24 17:30:00	2023-10-24 19:25:00	\N	\N	198	0	\N	\N
757798	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2023-10-25 15:00:00	2023-10-25 16:15:00	\N	\N	284	0	\N	\N
641859	MISSION	AUCUNE	\N	FONDSMER	\N	Auditions plénières	Auditions plénières	2022-04-28 09:30:00	2022-04-28 12:30:00	2022-04-28 12:33:23	2022-04-28 15:10:21	9	0	\N	\N
641973	QUESTURE	AUCUNE	\N	\N	\N	Réunion de Questure	Réunion de Questure	2022-04-26 17:30:00	2022-04-26 18:45:00	\N	\N	3	0	\N	\N
643139	ETUDES	AUTRE	\N	\N	\N	Audition Influenza	\N	2022-05-24 14:00:00	2022-05-24 16:00:00	\N	\N	11	0	\N	911
643171	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI patrimoine religieux	\N	2022-05-24 15:30:00	2022-05-24 16:20:00	\N	\N	2	0	\N	\N
643662	COM_PERMANENTE	AUDRAP	\N	FINC	\N	MCC 2022 - Audiovisuel Public - INA	MCC 2022 - Audiovisuel Public - INA	2022-06-02 09:40:00	2022-06-02 10:30:00	\N	\N	2	0	\N	\N
643675	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI sur la politique étrangère américaine	\N	2022-05-31 14:30:00	2022-05-31 16:00:00	\N	\N	4	0	\N	\N
643680	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI sur la politique étrangère américaine	\N	2022-06-01 15:00:00	2022-06-01 17:15:00	\N	\N	4	0	\N	\N
644763	GIA	AUCUNE	\N	\N	\N	Entretien avec Mme Elise Dubreuil - commissaire de l'exposition Gaudi	Entretien avec Mme Elise Dubreuil - commissaire de l'exposition Gaudi	2022-06-13 16:00:00	2022-06-13 17:30:00	\N	\N	5	0	589	\N
651585	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes	\N	2022-07-27 13:30:00	2022-07-27 14:50:00	2022-07-27 14:53:36	2022-07-27 18:10:31	21	0	\N	\N
651598	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022- IGN - Syndicat CGT-IGN	Contrôle 2022- IGN - Syndicat CGT-IGN	2022-07-21 14:45:00	2022-07-21 15:45:00	\N	\N	1	0	\N	\N
651600	DELEGATION	AUCUNE	\N	\N	211	Réunion plénière	Réunion plénière	2022-09-22 09:00:00	2022-09-22 10:40:00	\N	\N	9	0	\N	\N
651601	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFR pour 2022 - Élus locaux	PLFR pour 2022 - Élus locaux	2022-07-20 15:00:00	2022-07-20 16:00:00	\N	\N	1	0	\N	\N
651603	DELEGATION	AUCUNE	\N	\N	211	Examen du rapport d¿information  sur l¿industrie de la pornographie	Examen du rapport d¿information  sur l¿industrie de la pornographie	2022-09-27 16:00:00	2022-09-27 17:20:00	2022-09-27 17:29:29	\N	19	0	\N	\N
651604	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 2022 - Les scénarios de financement des CT - Cour des comptes	58-2 2022 - Les scénarios de financement des CT - Cour des comptes	2022-07-20 18:30:00	2022-07-20 19:45:00	\N	\N	3	0	\N	\N
651608	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	UMIH et GNI	\N	2022-07-20 13:30:00	2022-07-20 15:00:00	\N	\N	0	0	\N	\N
651617	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Pouvoir d'achat - Audition DGEFP-DGCS	\N	2022-07-20 16:30:00	2022-07-20 17:30:00	\N	\N	1	0	\N	\N
651618	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Pouvoir d'achat - Audition Gazel Énergie	\N	2022-07-20 17:30:00	2022-07-20 18:30:00	\N	\N	1	0	\N	\N
651619	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Pouvoir d'achat - Audition CNTR	\N	2022-07-20 18:30:00	2022-07-20 19:30:00	\N	\N	1	0	\N	\N
651620	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Pouvoir d'achat - Audition OP	\N	2022-07-21 09:00:00	2022-07-21 10:15:00	\N	\N	4	0	\N	\N
651621	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Pouvoir d'achat - Audition OS	\N	2022-07-21 10:30:00	2022-07-21 11:45:00	\N	\N	3	0	\N	\N
656369	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	Audition rapporteur - PJL LOPMI	2022-09-26 17:45:00	2022-09-26 18:30:00	\N	\N	1	0	\N	\N
656383	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	Audition rapporteur - PJL LOPMI	2022-09-26 18:30:00	2022-09-26 19:15:00	\N	\N	3	0	\N	\N
661780	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2022-10-13 09:00:00	2022-10-13 12:00:00	\N	\N	6	0	\N	\N
665277	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF 2023 -P. 212	PLF 2023 - P. 212	2022-10-19 13:45:00	2022-10-19 14:45:00	\N	\N	2	0	\N	\N
667534	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Table ronde WWF, UICN et Iddri	\N	2022-10-26 13:50:00	2022-10-26 15:00:00	\N	\N	0	0	\N	\N
667544	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Hervé Gillé et M. Philippe Tabarot	Auditions M. Hervé Gillé et M. Philippe Tabarot	2022-10-18 17:15:00	2022-10-18 18:15:00	\N	\N	1	0	\N	\N
667546	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Philippe Tabarot	Auditions M. Philippe Tabarot	2022-10-18 18:15:00	2022-10-18 19:00:00	\N	\N	1	0	\N	\N
667549	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Philippe Tabarot	\N	2022-10-21 09:45:00	2022-10-21 12:15:00	\N	\N	0	0	\N	\N
667550	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Philippe Tabarot	\N	2022-10-21 09:45:00	2022-10-21 12:15:00	\N	\N	0	0	\N	\N
667551	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Philippe Tabarot	\N	2022-10-21 09:45:00	2022-10-21 12:15:00	\N	\N	0	0	\N	\N
667552	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition Fédération des industries ferroviaires	\N	2022-10-21 09:45:00	2022-10-21 10:30:00	\N	\N	0	0	\N	\N
667553	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Philippe Tabarot	Auditions M. Philippe Tabarot	2022-10-21 09:45:00	2022-10-21 12:15:00	\N	\N	1	0	\N	\N
667555	ETUDES	AUTRE	\N	\N	\N	Audition FNPL et FNB	\N	2022-10-26 13:30:00	2022-10-26 15:00:00	\N	\N	9	0	\N	911
667565	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Hervé Gillé	Auditions M. Hervé Gillé	2022-10-25 16:00:00	2022-10-25 19:00:00	\N	\N	1	0	\N	\N
667567	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Sécurités - Sécurité Civile - ANSC	PLF pour 2023 - Sécurités - Sécurité Civile - ANSC	2022-10-26 14:00:00	2022-10-26 15:00:00	\N	\N	1	0	\N	\N
667568	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Sécurités - Sécurité Civile - CNSIS	PLF pour 2023 - Sécurités - Sécurité Civile - CNSIS	2022-10-26 16:00:00	2022-10-26 16:30:00	\N	\N	1	0	\N	\N
667571	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - BACEA - FNAM	PLF pour 2023 - BACEA - FNAM	2022-10-26 17:00:00	2022-10-26 18:30:00	\N	\N	1	0	\N	\N
667573	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFSS pour 2023 - CADES	PLFSS pour 2023 - CADES	2022-10-25 14:00:00	2022-10-25 15:15:00	\N	\N	1	0	\N	\N
667574	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Santé - DSS	PLF pour 2023 - Santé - DSS	2022-10-26 17:00:00	2022-10-26 18:15:00	\N	\N	1	0	\N	\N
669756	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Philippe Tabarot	Auditions M. Philippe Tabarot	2022-11-03 08:00:00	2022-11-03 10:30:00	\N	\N	1	0	\N	\N
667577	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Cohésion des territoires - Logement-Urbanisme - USH	PLF pour 2023 - Cohésion des territoires - Logement-Urbanisme - USH	2022-10-26 17:30:00	2022-10-26 18:30:00	\N	\N	1	0	\N	\N
667581	DELEGATION	AUCUNE	\N	\N	211	Conférence "Femmes en temps de conflits armés"	Conférence "Femmes en temps de conflits armés"	2022-11-24 08:30:00	2022-11-24 12:30:00	\N	\N	16	0	\N	\N
667582	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2023 Assurance maladie - Table ronde de syndicats de médecins	\N	2022-10-27 09:30:00	2022-10-27 10:45:00	\N	\N	3	0	\N	\N
667587	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2023 Assurance maladie - Audition du Pr Rémi Salomon	\N	2022-10-27 12:00:00	2022-10-27 13:00:00	\N	\N	2	0	\N	\N
667607	DELEGATION	AUCUNE	\N	\N	PROS	Audition sur l'exploitation des ressources de la lune	\N	2022-11-03 08:35:00	2022-11-03 10:10:00	\N	\N	9	0	\N	\N
667620	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Audition du Conseil constitutionnel	Audition du Conseil constitutionnel	2022-10-27 14:30:00	2022-10-27 16:00:00	\N	\N	1	0	\N	\N
667622	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions DAG Jean-Yves Leconte	\N	2022-10-27 09:30:00	2022-10-27 18:00:00	\N	\N	2	0	\N	\N
667625	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Soutien aux édiles victimes d'agression	PJL Soutien aux édiles victimes d'agression	2022-10-27 10:30:00	2022-10-27 11:15:00	\N	\N	2	0	\N	\N
667626	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Déplacement à la sous-préfecture de Largentière (Ardèche)	Déplacement à la sous-préfecture de Largentière (Ardèche)	2022-10-24 11:00:00	2022-10-24 14:00:00	\N	\N	1	0	\N	\N
667630	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Déplacement à la préfecture de Saint-Denis (Seine-Saint-Denis)	Déplacement à la préfecture de Saint-Denis (Seine-Saint-Denis)	2022-10-27 10:00:00	2022-10-27 12:30:00	\N	\N	1	0	\N	\N
667632	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition des syndicats présents au CSFPE	Audition des syndicats présents au Conseil supérieur de la fonction publique de l'Etat	2022-10-25 09:00:00	2022-10-25 10:30:00	\N	\N	1	0	\N	\N
667634	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition de l'Association des maires ruraux de France	\N	2022-10-26 14:00:00	2022-10-26 15:00:00	\N	\N	1	0	\N	\N
667636	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition de l'AMF	udition de l'Association des maires de France et des présidents d'intercommunalités	2022-10-26 16:30:00	2022-10-26 18:00:00	\N	\N	1	0	\N	\N
667655	COM_PERMANENTE	AUDRAP	\N	CDD	\N	M. Marchand - Avis Recherche	\N	2022-10-27 14:05:00	2022-10-27 16:40:00	\N	\N	1	0	\N	\N
667702	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Modalités d'incarcération ou de libération	PPL Modalités d'incarcération ou de libération	2022-10-28 09:00:00	2022-10-28 10:15:00	\N	\N	1	0	\N	\N
669559	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF 2023 : Missions AEE - APD et Économie	PLF 2023 : Missions AEE - APD et Économie	2022-11-09 16:35:00	2022-11-09 19:10:00	2022-11-10 15:54:27	2022-11-10 16:13:07	32	3	\N	\N
676048	GIA	AUCUNE	\N	\N	\N	Visite de M. Hisham AL-OMEISY, invité yéménite pour un séjour d¿études, analyste politique	Coopé - Visite de M. Hisham AL-OMEISY, invité yéménite pour un séjour d¿études, analyste politique, défenseur des droits	2022-11-16 14:30:00	2022-11-16 15:30:00	\N	\N	1	0	627	\N
690670	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI LPM programme 144	MI LPM programme 144	2023-01-10 14:30:00	2023-01-10 15:30:00	\N	\N	2	0	\N	\N
725900	COM_PERMANENTE	AUDRAP	\N	CAE	\N	DGALN et DGPR - PPL Ferme France	DGALN et DGPR - PPL Ferme France	2023-04-26 17:30:00	2023-04-26 18:15:00	\N	\N	1	0	\N	\N
725904	MECSS	AUDRAP	\N	\N	MECSS	Mecss - MI Organismes financés par les Robss - Audition ABM	\N	2023-04-27 14:00:00	2023-04-27 15:00:00	\N	\N	2	0	\N	\N
725905	MECSS	AUDRAP	\N	\N	MECSS	Mecss - MI Organismes financés par les Robss - Audition Fiva	\N	2023-04-27 16:00:00	2023-04-27 17:00:00	\N	\N	2	0	\N	\N
725906	MECSS	AUDRAP	\N	\N	MECSS	Mecss - MI Organismes financés par les Robss - Audition ANDPC	\N	2023-04-27 17:00:00	2023-04-27 18:00:00	\N	\N	2	0	\N	\N
725920	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Construction de places de détention  - Audition Direction du budget	Contrôle 2023 - Justice - Construction de places de détention  - Audition Direction du budget	2023-04-25 14:30:00	2023-04-25 15:45:00	\N	\N	1	0	\N	\N
725922	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Construction places de détention  - Audition Etats généraux de la justice	Contrôle 2023 - Construction places de détention  - Audition Etats généraux de la justice	2023-04-25 15:45:00	2023-04-25 16:25:00	\N	\N	1	0	\N	\N
725932	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Construction places de détention  - Audition Administration péitentiaire	Contrôle 2023 - Construction places de détention  - Audition Direction de l'administration péitentiaire	2023-04-25 16:30:00	2023-04-25 17:30:00	\N	\N	1	0	\N	\N
725934	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Construction places de détention  - Audition Contrôleur général	Contrôle 2023 - Construction places de détention  - Audition Contrôleur général des lieux de privation de liberté	2023-04-26 14:00:00	2023-04-26 15:20:00	\N	\N	1	0	\N	\N
725936	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Construction places de détention  - Audition USM	Contrôle 2023 - Construction places de détention  - Audition Union syndicale des magistrats	2023-04-26 15:20:00	2023-04-26 16:40:00	\N	\N	1	0	\N	\N
725938	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Sécurité civile - Audition FNSPF	Contrôle Sécurité civile - Audition Fédération nationale des sapeurs-pompiers de France (FNSPF)	2023-04-11 10:30:00	2023-04-11 11:30:00	\N	\N	1	0	\N	\N
725940	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Sécurité civile - Audition IGSC	Contrôle Sécurité civile - Audition Inspection générale de la sécurité civile (IGSC)	2023-04-11 11:30:00	2023-04-11 12:30:00	\N	\N	1	0	\N	\N
725943	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Sécurité civile - Audition SDIS 72	Contrôle Sécurité civile - Déplacement Audition SDIS 72	2023-04-18 14:00:00	2023-04-18 16:00:00	\N	\N	1	0	\N	\N
725945	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Sécurité civile - Audition CNSIS	Contrôle Sécurité civile - Audition  Conférence nationale des services d¿incendie et de secours (CNSIS)	2023-04-19 09:00:00	2023-04-19 10:00:00	\N	\N	1	0	\N	\N
725947	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Sécurité civile - Audition Départements de France	Contrôle Sécurité civile - Audition Départements de France	2023-04-19 10:00:00	2023-04-19 11:00:00	\N	\N	1	0	\N	\N
725949	MISSION	AUCUNE	\N	AVENCOMM	\N	Table ronde sur le thème des secrétaires de mairie	Table ronde sur le thème des secrétaires de mairie	2023-05-03 17:30:00	2023-05-03 18:45:00	2023-05-03 19:16:26	2023-05-04 15:53:44	7	0	\N	\N
725950	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Sécurité civile - Audition Airbus	Contrôle Sécurité civile - Audition Airbus	2023-04-19 11:00:00	2023-04-19 12:00:00	\N	\N	1	0	\N	\N
725952	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Sécurité civile - Audition DG Echo Commission européenne	Contrôle Sécurité civile - Audition DG Echo Commission européenne	2023-04-19 14:00:00	2023-04-19 15:00:00	\N	\N	1	0	\N	\N
725954	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Sécurité civile - Audition Roadfour	Contrôle Sécurité civile - Audition Roadfour	2023-04-19 15:00:00	2023-04-19 16:00:00	\N	\N	1	0	\N	\N
725956	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Sécurité civile - Audition DGSCGC	\N	2023-04-19 17:00:00	2023-04-19 18:00:00	\N	\N	0	0	\N	\N
725957	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Financement ORE - Audition Direction du budget	Contrôle Financement ORE - Audition Direction du budget	2023-04-19 14:30:00	2023-04-19 15:30:00	\N	\N	1	0	\N	\N
725959	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Modernisation DSNA - Audition Christian RIVIERRE Thalès	Contrôle 2023 - Modernisation DSNA - Audition Christian RIVIERRE Thalès	2023-04-28 14:00:00	2023-04-28 15:30:00	\N	\N	1	0	\N	\N
725965	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Maj num	\N	2023-05-02 10:30:00	2023-05-02 11:00:00	\N	\N	3	0	\N	\N
725969	COM_PERMANENTE	AUTRE	\N	FINC	\N	Projet de loi de règlement du budget et approbation des cptes 2021/22 - Audition G. ATTAL	Projet de loi de règlement du budget et d'approbation des comptes 2021/22 - Audition G. ATTAL	2023-05-02 17:30:00	2023-05-02 18:30:00	2023-05-02 19:03:03	2023-05-03 18:03:34	24	0	\N	\N
726004	DELEGATION	AUDRAP	\N	\N	211	Audition rapporteures "Santé des femmes au travail"	\N	2023-05-02 14:00:00	2023-05-02 15:40:00	\N	\N	4	0	\N	\N
726066	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition rapporteur	\N	2023-04-25 09:00:00	2023-04-25 09:45:00	\N	\N	0	0	\N	\N
726067	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition	\N	2023-04-25 09:00:00	2023-04-25 09:45:00	\N	\N	1	0	\N	\N
726073	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition Rapporteur	\N	2023-04-18 13:45:00	2023-04-18 18:45:00	\N	\N	1	0	\N	\N
726099	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Déplacement du Bureau en Allemagne (Francfort, Berlin)	Déplacement du Bureau en Allemagne (Francfort, Berlin)	2023-04-25 07:00:00	2023-04-28 22:30:00	\N	\N	5	0	\N	\N
726107	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2023 - EPF/EPA - Déplacement de M. BLANC à Besançon	Contrôle 2023 - EPF/EPA - Déplacement de M. BLANC à Besançon	2023-06-19 09:00:00	2023-06-19 20:45:00	\N	\N	0	0	\N	\N
726109	DELEGATION	DEPLACEMENT	\N	\N	DSOM	Déplacement Président - 38th Space Symposium Colorado Springs	\N	2023-04-17 07:00:00	2023-04-20 22:00:00	\N	\N	0	0	\N	\N
726667	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	\N	\N	2023-05-03 09:00:00	2023-05-03 09:45:00	\N	\N	1	0	\N	\N
727806	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Musée Labenche	\N	2023-05-03 11:30:00	2023-05-03 12:30:00	\N	\N	2	0	\N	\N
727813	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 32PJL Code monétaire, financier, diverses dispositions relatives à l'outre-Mer	PJL Code monétaire, financier, diverses dispositions relatives à l'outre-mer - Examen rapport et texte de la commission	2023-05-04 09:05:00	2023-05-04 10:00:00	2023-05-04 14:58:45	2023-05-04 15:52:12	14	3	\N	\N
727825	COM_ENQUETE	PLENIERE	\N	RENOV	\N	Audition SGPE	\N	2023-05-04 09:00:00	2023-05-04 10:05:00	2023-05-04 10:17:17	2023-05-04 15:53:43	6	0	\N	\N
727833	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Trouble du neurodéveloppement - Audition CNSA	\N	2023-05-03 16:30:00	2023-05-03 17:30:00	\N	\N	2	0	\N	\N
727837	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI PreParE - Table ronde Medef-CPME	\N	2023-05-03 14:00:00	2023-05-03 15:00:00	\N	\N	2	0	\N	\N
727842	DELEGATION	AUCUNE	\N	\N	COLTER	Réunion plénière	\N	2023-05-04 09:00:00	2023-05-04 12:30:00	2023-05-04 15:06:57	\N	22	0	\N	\N
728012	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de Stéphanie Cherbonnier, cheffe de l'Office anti-stupéfiants	Audition de Stéphanie Cherbonnier, cheffe de l'Office anti-stupéfiants	2023-05-10 10:00:00	2023-05-10 11:20:00	2023-05-16 10:11:30	2023-05-16 10:31:40	30	2	\N	\N
728028	DELEGATION	AUCUNE	\N	\N	211	Table ronde Santé des femmes au travail (Partenaires sociaux)	\N	2023-05-11 08:30:00	2023-05-11 10:00:00	\N	\N	5	0	\N	\N
728040	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Couples confrontés à une fausse couche	PPL Couples confrontés à une fausse couche	2023-05-04 14:30:00	2023-05-04 16:00:00	\N	\N	21	0	\N	\N
642984	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition du général Pierre-Joseph Givre	\N	2022-05-24 15:00:00	2022-05-24 17:20:00	2022-05-24 17:57:51	2022-05-27 16:46:07	22	0	\N	\N
642985	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Communication sur le déplacement en Roumanie	\N	2022-05-24 16:30:00	2022-05-24 17:30:00	\N	\N	0	0	\N	\N
642994	GIA	AUCUNE	\N	\N	\N	Accueil Jetsun Pema (soeur du Dalai Lama)	Accueil Jetsun Pema (soeur du Dalai Lama)	2022-10-11 12:30:00	2022-10-11 14:30:00	\N	\N	7	0	634	\N
643213	COM_EURO	CONTROLE	\N	AFEU	\N	Audition intelligence artificielle	\N	2022-05-24 10:00:00	2022-05-24 11:00:00	\N	\N	2	0	\N	\N
643216	COM_EURO	CONTROLE	\N	AFEU	\N	Audition intelligence artificielle	\N	2022-05-24 11:00:00	2022-05-24 12:00:00	\N	\N	1	0	\N	\N
643230	GIA	AUCUNE	\N	\N	\N	Rencontre Abier Al-Masri	Rencontre avec Mme Abier Al-Masri, lauréate de l'initiative Marianne du MAE	2022-05-24 17:30:00	2022-05-24 18:35:00	\N	\N	4	0	632	\N
645703	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	MI Services pénitentiaires d'insertion et de probation - déplacement à Marseille	MI Services pénitentiaires d'insertion et de probation - déplacement à Marseille	2022-06-28 08:00:00	2022-06-28 20:00:00	\N	\N	2	0	\N	\N
646185	SEANCE_PLENIERE	DECL_GVT	\N	\N	\N	Déclaration du Gouvernement	Déclaration du Gouvernement	2022-07-06 15:00:00	2022-07-06 16:10:00	\N	\N	255	0	\N	\N
646186	SEANCE_PLENIERE	DECL_GVT	\N	\N	\N	Déclaration du Gouvernement 50-1	Déclaration du Gouvernement 50-1	2022-07-06 21:00:00	2022-07-06 23:30:00	\N	\N	228	0	\N	\N
649298	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL pouvoir d'achat - Audition Urssaf	\N	2022-07-18 14:00:00	2022-07-18 15:00:00	\N	\N	2	0	\N	\N
649300	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL pouvoir d'achat - Audition DSS	\N	2022-07-18 15:00:00	2022-07-18 16:00:00	\N	\N	2	0	\N	\N
649301	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL pouvoir d'achat - Audition LDLC	\N	2022-07-18 16:00:00	2022-07-18 17:00:00	\N	\N	2	0	\N	\N
653646	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2023 - P. 151	PLF pour 2023 - P. 151	2022-07-27 10:00:00	2022-07-27 11:00:00	\N	\N	2	0	\N	\N
653666	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Audition de Mme Claire Landais, secrétaire générale	Audition de Mme Claire Landais	2022-07-27 17:00:00	2022-07-27 18:00:00	\N	\N	1	0	\N	\N
661557	DELEGATION	AUCUNE	\N	\N	DSOM	Audition de M. Muli'aka'aka (évolution institutionnelle outre-mer)	\N	2022-10-13 16:15:00	2022-10-13 17:00:00	\N	\N	4	0	\N	\N
661602	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - RSR - DB	PLF pour 2023 - RSR - DB	2022-10-11 17:05:00	2022-10-11 18:20:00	\N	\N	1	0	\N	\N
665346	GIA	AUCUNE	\N	\N	\N	Entretien Amnesty International (cas de S. Hamouri)	Entretien avec Amnesty Internation à propos du cas de M. Salah Hamouri	2022-10-24 14:30:00	2022-10-24 15:30:00	\N	\N	4	0	632	\N
665355	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2023	Cerema	2022-10-24 11:00:00	2022-10-24 12:15:00	\N	\N	2	0	\N	\N
668138	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2023 - Solidarité - Audition APF France Handicap	\N	2022-11-02 14:00:00	2022-11-02 15:00:00	\N	\N	1	0	\N	\N
668144	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2023 - Solidarité - Audition FAS	\N	2022-11-02 16:30:00	2022-11-02 17:30:00	\N	\N	1	0	\N	\N
669760	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2022-11-08 17:00:00	2022-11-08 19:00:00	2022-11-09 09:19:37	2022-11-09 17:25:44	33	0	\N	\N
669875	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur 	PPL Soutien aux édiles victimes d'agression	2022-11-03 15:00:00	2022-11-03 15:45:00	\N	\N	2	0	\N	\N
669884	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Travail & emploi - DG Pôle Emploi	PLF pour 2023 - Travail & emploi - DG Pôle Emploi	2022-11-03 09:00:00	2022-11-03 10:00:00	\N	\N	2	0	\N	\N
669887	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Travail & emploi - FEI	PLF pour 2023 - Travail & emploi - FEI	2022-11-04 09:45:00	2022-11-04 10:30:00	\N	\N	2	0	\N	\N
672791	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ambassadeur du Pérou et trois parlementaires péruviens	Entretien avec S. Exc. M. Rolando RUIZ ROSAS, ambassadeur du Pérou en France, et trois parlementaires péruviens	2022-11-09 08:30:00	2022-11-09 10:00:00	\N	\N	5	0	979	\N
672799	COM_PERMANENTE	AUTRE	\N	ETRD	\N	PLF2023 - Audition général Stéphane Mille	PLF2023 - Audition général Stéphane Mille	2022-11-16 09:35:00	2022-11-16 11:10:00	2022-11-16 15:36:27	2022-11-16 17:13:34	41	0	\N	\N
672801	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2022-11-08 15:45:00	2022-11-08 17:30:00	\N	\N	3	0	\N	\N
676364	QUESTURE	AUCUNE	\N	\N	\N	Réunion de Questure	Réunion de Questure	2022-11-17 08:00:00	2022-11-17 09:30:00	\N	\N	3	0	\N	\N
676422	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2023	PLF 2023	2022-11-21 10:30:00	2022-11-21 13:00:00	\N	\N	59	0	\N	\N
676423	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2023	PLF 2023	2022-11-21 14:30:00	2022-11-21 20:00:00	\N	\N	92	0	\N	\N
676424	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2023	PLF 2023	2022-11-21 21:30:00	2022-11-22 02:00:00	\N	\N	86	0	\N	\N
676425	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2023	PLF 2023	2022-11-22 14:30:00	2022-11-22 20:00:00	\N	\N	217	0	\N	\N
676426	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2023	PLF 2023	2022-11-22 21:30:00	2022-11-23 01:05:00	\N	\N	113	0	\N	\N
676427	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2023	PLF 2023	2022-11-23 11:00:00	2022-11-23 13:05:00	\N	\N	113	0	\N	\N
676429	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2022-11-23 15:00:00	2022-11-23 16:25:00	\N	\N	310	0	\N	\N
676431	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2023	PLF 2023	2022-11-23 16:40:00	2022-11-23 20:00:00	\N	\N	159	0	\N	\N
676432	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2023	PLF 2023	2022-11-23 21:30:00	2022-11-24 01:35:00	\N	\N	104	0	\N	\N
676440	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF 2023 : Suite de l'examen Amdts séance Première Partie	PLF 2023 : Suite de l'examen Amdts séance Première Partie	2022-11-21 09:30:00	2022-11-21 10:00:00	2022-11-21 10:26:57	2022-11-21 16:12:54	16	3	\N	\N
676441	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2023 - Examen Amdts séance sur les Missions	PLF pour 2023 - Examen Amdts séance sur les Missions	2022-11-24 09:30:00	2022-11-24 10:05:00	2022-11-24 10:58:33	2022-11-24 11:07:04	20	3	\N	\N
680952	GIA	AUCUNE	\N	\N	\N	Réunion du groupe d'amitié France-Pologne	Réunion du groupe d'amitié France-Pologne	2022-11-29 08:30:00	2022-11-29 10:00:00	\N	\N	6	0	600	\N
681433	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2022-11-29 17:00:00	2022-11-29 19:15:00	\N	\N	4	0	\N	\N
682073	DELEGATION	AUCUNE	\N	\N	206	Examen des conclusions d'une audition publique et d'une note scientifique	\N	2022-12-01 09:30:00	2022-12-01 11:00:00	\N	\N	7	0	\N	\N
682276	ETUDES	AUTRE	\N	\N	\N	Audition de la Commission de régulation de l'énergie	Audition de la Commission de régulation de l'énergie	2022-11-30 13:30:00	2022-11-30 15:00:00	\N	\N	20	0	\N	906
682296	MECSS	AUCUNE	\N	\N	MECSS	Réunion plénière	\N	2022-12-06 16:15:00	2022-12-06 16:35:00	2022-12-06 16:37:32	2022-12-06 17:45:27	9	0	\N	\N
682306	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-12-07 10:05:00	2022-12-07 11:35:00	2022-12-07 12:07:07	2022-12-08 12:00:17	40	0	\N	\N
682357	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Décentralisation	Décentralisation - auditions rapporteurs	2022-11-29 14:00:00	2022-11-29 16:00:00	\N	\N	3	0	\N	\N
682360	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Décentralisation	Décentralisation - auditions rapporteurs	2022-11-29 16:00:00	2022-11-29 18:00:00	\N	\N	3	0	\N	\N
683548	COM_PERMANENTE	AUTRE	\N	CAE	\N	MCC ZAN 	\N	2022-11-29 16:00:00	2022-11-29 18:00:00	\N	\N	10	0	\N	\N
686260	DELEGATION	AUCUNE	\N	\N	COLTER	Réunion plénière	\N	2022-12-08 09:00:00	2022-12-08 12:10:00	2022-12-08 16:06:08	\N	19	0	\N	\N
686343	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Décentralisation - Auditions rapporteurs	\N	2022-12-07 16:40:00	2022-12-07 20:30:00	\N	\N	4	0	\N	\N
686364	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Adaptation au droit de l'Union européenne (amendements)	PJL Adaptation au droit de l'Union européenne (amendements)	2022-12-13 14:00:00	2022-12-13 14:05:00	2022-12-13 14:47:23	2022-12-14 15:55:21	7	1	\N	\N
686365	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désignations - Auditions sur le régime du secours en mer (DGEF et SGMer)	Désignations - Auditions sur le régime du secours en mer (DGEF et SGMer)	2022-12-14 09:05:00	2022-12-14 11:30:00	2023-01-09 11:41:33	2023-01-10 14:56:09	26	1	\N	\N
686428	COM_PERMANENTE	AUTRE	\N	FINC	\N	PJL DDADUE : Examen AMDTS séance sur texte de commission affaires sociales et désignation	PJL DDADUE : Examen AMDTS séance sur le texte de commission affaires sociales et désignation rapporteur Art 13	2022-12-13 09:30:00	2022-12-13 09:45:00	2022-12-13 09:58:02	2022-12-14 15:55:23	15	1	\N	\N
740612	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat France communale et avenir de la commune en France	Débat France communale et avenir de la commune en France	2023-06-13 15:45:00	2023-06-13 17:15:00	\N	\N	90	0	\N	\N
740613	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	LEC PPL Restitution des restes humains appartenant aux collections 	\N	2023-06-13 17:20:00	2023-06-13 18:15:00	\N	\N	48	0	\N	\N
740614	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Suite PPL Réforme de l'audiovisuel public	Suite PPL Réforme de l'audiovisuel public	2023-06-13 17:45:00	2023-06-13 18:45:00	\N	\N	69	0	\N	\N
740615	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Suite PPL Réforme de l'audiovisuel public	Suite PPL Réforme de l'audiovisuel public	2023-06-13 18:15:00	2023-06-13 19:50:00	\N	\N	0	0	\N	\N
740616	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2023-06-14 15:00:00	2023-06-14 16:20:00	\N	\N	301	0	\N	\N
732922	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Lagardère News	\N	2023-05-23 08:30:00	2023-05-23 09:30:00	\N	\N	1	0	\N	\N
672800	COM_PERMANENTE	AUTRE	\N	ETRD	\N	PLF2023 - examen 5 avis budgétaires	PLF2023 - examen 5 avis budgétaires	2022-11-16 11:10:00	2022-11-16 12:30:00	2022-11-16 15:57:32	2022-11-16 17:13:38	41	4	\N	\N
740617	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Revaloriser le métier de secrétaire de mairie	PPL Revaloriser le métier de secrétaire de mairie	2023-06-14 16:30:00	2023-06-14 19:35:00	\N	\N	96	0	\N	\N
740640	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Protéger les logements contre l'occupation illicite 	PPL Protéger les logements contre l'occupation illicite 	2023-06-14 19:35:00	2023-06-14 20:00:00	\N	\N	35	0	\N	\N
740641	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Suite PPL Protéger les logements contre l'occupation illicite 	Suite PPL Protéger les logements contre l'occupation illicite 	2023-06-14 21:30:00	2023-06-15 00:00:00	\N	\N	37	0	\N	\N
740642	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Établissements de spectacles cinématographiques dans les outre-mer 	PPL Établissements de spectacles cinématographiques dans les outre-mer 	2023-06-15 10:30:00	2023-06-15 11:40:00	\N	\N	46	0	\N	\N
740643	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Protection des mineurs et honorabilité dans le sport	PPL Protection des mineurs et honorabilité dans le sport	2023-06-15 11:40:00	2023-06-16 13:15:00	\N	\N	42	0	\N	\N
740644	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Registre national des cancers	PPL Registre national des cancers	2023-06-15 14:45:00	2023-06-15 15:55:00	\N	\N	38	0	\N	\N
740645	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Organisation de la navigation aérienne en cas de mouvement social 	PPL Organisation de la navigation aérienne en cas de mouvement social 	2023-06-15 16:00:00	2023-06-15 17:20:00	\N	\N	30	0	\N	\N
740646	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Mécénat culturel 	PPL Mécénat culturel 	2023-06-15 17:20:00	2023-06-15 18:30:00	\N	\N	23	0	\N	\N
740727	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Reconnaissance biométrique 	PPL Reconnaissance biométrique	2023-06-12 16:00:00	2023-06-12 18:00:00	\N	\N	33	0	\N	\N
740728	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Réforme de l'audiovisuel public 	PPL Réforme de l'audiovisuel public 	2023-06-12 18:05:00	2023-06-12 19:35:00	\N	\N	39	0	\N	\N
740729	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Suite PPL Réforme de l'audiovisuel public	Suite PPL Réforme de l'audiovisuel public	2023-06-12 21:30:00	2023-06-13 00:35:00	\N	\N	30	0	\N	\N
740827	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2022 - Justice - Déplacement CEF Epernay	\N	2023-06-12 08:00:00	2023-06-12 22:00:00	\N	\N	0	0	\N	\N
740828	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Déplacement au SIAE du Bourget	\N	2023-06-20 13:00:00	2023-06-20 19:00:00	\N	\N	0	0	\N	\N
740829	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2022 - Justice - Déplacement centre pénitentiaire Gradignan	\N	2023-06-23 08:00:00	2023-06-23 22:00:00	\N	\N	0	0	\N	\N
740830	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2023 - SMV - Déplacement CSMV à Ambérieu	Contrôle 2023 - SMV - Déplacement CSMV à Ambérieu	2023-07-10 07:00:00	2023-07-10 23:00:00	\N	\N	1	0	\N	\N
740832	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 44 - CE Fonds Marianne Audito M. SIFAOUI	PLENIERE - 44 - CE Fonds Marianne Audito M. SIFAOUI	2023-06-13 09:04:00	2023-06-13 09:06:00	2023-06-13 10:31:55	2023-06-14 15:27:56	12	0	\N	\N
740833	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 45	\N	2023-06-13 16:00:00	2023-06-13 18:35:00	2023-06-15 09:08:38	2023-06-15 20:05:45	26	2	\N	\N
740835	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 47 CE Fonds Marianne Audition Mme SCHIAPPA	\N	2023-06-14 10:00:00	2023-06-14 13:10:00	2023-06-14 15:07:45	2023-06-14 15:28:02	45	8	\N	\N
740836	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 48 CE Fonds Marianne Audition Mme BACKES	\N	2023-06-14 16:30:00	2023-06-14 18:00:00	2023-06-22 17:42:28	2023-06-22 17:43:57	15	0	\N	\N
744944	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2023-06-20 17:00:00	2023-06-20 18:30:00	\N	\N	3	0	\N	\N
749888	GIA	AUCUNE	\N	\N	\N	Coopé - Entretien avec une délégation de députés du Niger	Coopé - Entretien avec une délégation de députés du Niger	2023-07-05 12:45:00	2023-07-05 14:25:00	\N	\N	2	0	573	\N
750022	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - MI Respect des principes de la République	Auditions rapporteur - MI Respect des principes de la République	2023-07-10 09:00:00	2023-07-10 12:00:00	\N	\N	2	0	\N	\N
752406	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2023 - Déplacement à Marseille - Service de santé des armées	Contrôle 2023 - Déplacement à Marseille - Service de santé des armées - Visite hôpital Laveran	2023-09-19 08:00:00	2023-09-19 22:00:00	\N	\N	1	0	\N	\N
752408	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Défense - Visite hôpital Laveran Marseille	Contrôle 2023 - Défense - Visite hôpital Laveran Marseille	2023-09-19 10:30:00	2023-09-19 14:00:00	\N	\N	1	0	\N	\N
753150	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - SSA - Audition Etat major de la Marine	Contrôle 2023 - Service de santé des armées - Audition Etat-major de la Marine	2023-09-22 09:00:00	2023-09-22 11:00:00	\N	\N	1	0	\N	\N
753249	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion CAE	\N	2023-10-05 10:00:00	2023-10-05 11:55:00	2023-10-05 17:16:57	2023-10-05 17:17:15	46	3	\N	\N
753251	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - Réunion constitutive du Bureau de la commission	PLENIERE - Réunion constitutive du Bureau de la commission	2023-10-05 09:05:00	2023-10-05 09:45:00	2023-10-05 17:10:00	2023-10-05 17:16:45	41	2	\N	\N
754619	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Ouverture à la concurrence du réseau de bus francilien de la RATP - Auditions	PPL Ouverture à la concurrence du réseau de bus francilien de la RATP - Auditions	2023-10-10 14:00:00	2023-10-10 19:10:00	\N	\N	1	0	\N	\N
754622	DELEGATION	AUCUNE	\N	\N	211	Réunion constitutive de la Délégation (renouvellement 2023)	\N	2023-10-18 12:35:00	2023-10-18 13:00:00	\N	\N	28	0	\N	\N
755013	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL 549 Conventions fiscales Danemark et Grèce - Audition M. de FILIPPO (DLF)/M. NDRIANA (	PJL 549 Conventions fiscales Danemark et Grèce - Audition M. de FILIPPO (DLF)/M. NDRIANA (MEAE)	2023-10-11 10:30:00	2023-10-11 11:00:00	\N	\N	1	0	\N	\N
755864	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de S.E. M. l'Ambassadeur Raphaël Morav	Audition de S.E. M. l'Ambassadeur Raphaël Morav	2023-10-17 17:00:00	2023-10-17 18:05:00	2023-10-18 11:47:37	2023-10-18 18:17:10	32	0	\N	\N
755865	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de M. Stéphane Bouillon	Audition de M. Stéphane Bouillon	2023-10-18 09:00:00	2023-10-18 10:40:00	2023-10-20 12:18:07	2023-10-23 18:02:58	43	4	\N	\N
755867	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de Mme Catherine Colonna	Audition de Mme Catherine Colonna	2023-10-18 16:30:00	2023-10-18 18:00:00	2023-10-25 16:25:38	2023-10-25 16:26:47	33	0	\N	\N
757799	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Suite PPL Accès aux soins	Suite PPL Accès aux soins	2023-10-25 16:30:00	2023-10-25 19:50:00	\N	\N	81	0	\N	\N
757800	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Suite PPL Accès aux soins	Suite PPL Accès aux soins	2023-10-25 21:30:00	2023-10-25 23:45:00	\N	\N	56	0	\N	\N
757801	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Convention France Danemark Grèce	Convention France Danemark Grèce	2023-10-26 10:30:00	2023-10-26 11:30:00	\N	\N	44	0	\N	\N
725547	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PPL Influenceurs	\N	2023-04-13 09:00:00	2023-04-13 12:00:00	\N	\N	1	0	\N	\N
740834	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 46	\N	2023-06-14 09:45:00	2023-06-14 10:00:00	2023-06-14 15:07:27	2023-06-14 15:28:00	45	5	\N	\N
757802	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Négociations commerciales	PJL Négociations commerciales	2023-10-26 11:30:00	2023-10-26 13:50:00	\N	\N	51	0	\N	\N
641150	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	MCC Sécurisation de la chasse - Déplacement en Ille-et-Vilaine	MCC Sécurisation de la chasse - Déplacement en Ille-et-Vilaine	2022-03-30 09:00:00	2022-03-30 19:00:00	\N	\N	4	0	\N	\N
641161	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	Commission d'Apuration des Comptes	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne 	2022-04-12 14:45:00	2022-04-12 15:45:00	\N	\N	7	0	\N	\N
644111	COM_PERMANENTE	AUTRE	\N	FINC	\N	Contrôles budgétaires - Travail et rémunération Enseignants et France télévisions 	Contrôles budgétaires - Travail et rémunération Enseignants et France télévisions 	2022-06-08 09:05:00	2022-06-08 10:45:00	2022-06-09 15:56:40	2022-06-09 17:34:51	27	0	\N	\N
644516	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	auditions	\N	2022-06-08 11:30:00	2022-06-08 12:30:00	\N	\N	0	0	\N	\N
644523	COM_EURO	AUDRAP	\N	AFEU	\N	Partenariat oriental	Partenariat oriental	2022-06-13 15:00:00	2022-06-13 16:25:00	\N	\N	2	0	\N	\N
644826	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 -  ONACVG - DG ONACVG	Contrôle 2022 -  ONACVG - DG ONACVG	2022-06-14 09:30:00	2022-06-14 11:45:00	\N	\N	1	0	\N	\N
644828	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 -  ONACVG - TR associations mémoire	Contrôle 2022 -  ONACVG - TR associations mémoire	2022-06-14 15:00:00	2022-06-14 17:30:00	\N	\N	1	0	\N	\N
644830	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - DGCCRF - Autorité de la concurrence/DG DDI	Contrôle 2022 - DGCCRF - Autorité de la concurrence/DG DDI	2022-06-14 09:00:00	2022-06-14 11:30:00	\N	\N	2	0	\N	\N
644833	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - DGCCRF - Syndicats DGCCRF	Contrôle 2022 - DGCCRF - Syndicats DGCCRF	2022-06-15 14:30:00	2022-06-15 16:30:00	\N	\N	1	0	\N	\N
644854	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-06-21 15:00:00	2022-06-21 17:00:00	2022-06-21 18:00:53	2022-06-21 19:00:18	24	0	\N	\N
644855	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Ministère de l'intérieur - Direction des libertés publiques et des affaires juridiques	\N	2022-06-15 09:30:00	2022-06-15 10:30:00	\N	\N	4	0	\N	\N
644856	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Association Future for Religious Heritage	Audition de Mme de Lencquesaing	2022-06-15 10:45:00	2022-06-15 11:45:00	\N	\N	2	0	\N	\N
644863	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-06-22 09:40:00	2022-06-22 10:45:00	2022-06-22 11:24:12	2022-06-22 17:20:50	21	0	\N	\N
644900	DELEGATION	AUDRAP	\N	\N	PROS	Audition FNAIM	\N	2022-06-14 15:30:00	2022-06-14 16:30:00	\N	\N	1	0	\N	\N
644903	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Union Nationale des Missions Locales	\N	2022-06-15 14:30:00	2022-06-15 15:30:00	\N	\N	0	0	\N	\N
645694	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI  Méditerranée	RI Méditerranée	2022-06-20 09:00:00	2022-06-20 10:00:00	\N	\N	2	0	\N	\N
645697	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI  Méditerranée	RI Méditerranée	2022-06-20 11:00:00	2022-06-20 12:00:00	\N	\N	2	0	\N	\N
645707	GIA	AUCUNE	\N	\N	\N	déjeuner Ambassade 	Déjeuner avec Theo Rycroft, ministre plénipotentiaire et chef de mission adjointe de l'ambassade du Royaume-Uni 	2022-06-22 12:30:00	2022-06-22 14:30:00	\N	\N	5	0	581	\N
645713	COM_PERMANENTE	AUTRE	\N	CAE	\N	MCC sécurisation de la chasse	MCC sécurisation de la chasse	2022-06-27 09:15:00	2022-06-27 10:40:00	\N	\N	4	0	\N	\N
645718	MECSS	AUDRAP	\N	\N	MECSS	Application LFSS pour 2021 	\N	2022-06-22 15:30:00	2022-06-22 16:30:00	\N	\N	3	0	\N	\N
646068	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	  PPL Diffusion de contenus à caractère terroriste en ligne	PPL Diffusion de contenus à caractère terroriste en ligne	2022-06-29 09:00:00	2022-06-29 10:00:00	\N	\N	5	0	\N	\N
646080	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	  PPL Diffusion de contenus à caractère terroriste en ligne	\N	2022-06-29 10:00:00	2022-06-29 10:40:00	\N	\N	5	0	\N	\N
646086	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	  PPL Diffusion de contenus à caractère terroriste en ligne	\N	2022-06-29 14:30:00	2022-06-29 15:30:00	\N	\N	3	0	\N	\N
646090	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	  PPL Diffusion de contenus à caractère terroriste en ligne	\N	2022-06-29 15:30:00	2022-06-29 16:30:00	\N	\N	4	0	\N	\N
646095	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	  PPL Diffusion de contenus à caractère terroriste en ligne	\N	2022-06-29 16:30:00	2022-06-29 17:15:00	\N	\N	5	0	\N	\N
646144	ETUDES	AUCUNE	\N	\N	\N	Auditions sur les travailleurs en forêt	Auditions sur les travailleurs en forêt	2022-06-29 17:00:00	2022-06-29 18:45:00	\N	\N	7	0	\N	948
646157	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Examen RI politique étrangère américaine + 4 conventions internationales	Examen RI politique étrangère américaine + 4 conventions internationales.	2022-07-06 09:30:00	2022-07-06 11:15:00	2022-07-06 15:07:59	2022-07-06 16:05:12	37	7	\N	\N
646175	GIA	AUCUNE	\N	\N	\N	accueil d'une délégation de parlementaires américains et de leurs équipes	\N	2022-06-30 10:00:00	2022-06-30 14:30:00	\N	\N	1	0	590	\N
646178	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Audition MCC Délinquance des mineurs	Régions de France	2022-06-30 15:00:00	2022-06-30 16:00:00	\N	\N	4	0	\N	\N
651302	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Nouvelle-Calédonie	MI sur l'avenir institutionnel de la Nouvelle-Calédonie	2022-07-21 08:00:00	2022-07-21 09:30:00	\N	\N	2	0	\N	\N
651609	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition GT tourisme	Audition GT tourisme	2022-07-20 13:30:00	2022-07-20 15:00:00	\N	\N	7	0	\N	\N
656815	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Intervention des cabinets privés	PPL Cabinets privés	2022-09-28 16:15:00	2022-09-28 17:15:00	\N	\N	1	0	\N	\N
659653	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Écologie - Total Energies	PLF pour 2023 - Écologie - Total Energies	2022-10-10 16:00:00	2022-10-10 17:00:00	\N	\N	2	0	\N	\N
659866	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition PFA	\N	2022-10-12 09:00:00	2022-10-12 10:35:00	2022-10-12 10:44:30	2022-10-12 17:33:55	38	0	\N	\N
659867	COM_PERMANENTE	AUTRE	\N	CAE	\N	Table ronde sur la politique énergétique de l'UE	\N	2022-10-13 09:05:00	2022-10-13 11:10:00	2022-10-13 14:42:39	2022-10-13 16:13:57	21	0	\N	\N
659875	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Ministère des sports et des jeux olympiques et paralympiques - Cabinet de Mme la ministre	\N	2022-10-11 09:00:00	2022-10-11 10:20:00	\N	\N	2	0	\N	\N
660812	ETUDES	AUCUNE	\N	\N	\N	Audition Railcoop	Audition Railcoop	2022-10-12 13:30:00	2022-10-12 14:30:00	\N	\N	3	0	\N	998
667638	GIA	AUCUNE	\N	\N	\N	Dîner avec u ne délégation du Sénat des Philippines	Entretien avec une délégation de sénateurs philippins conduite par le Président Juan Miguel ZUBIRI	2022-10-25 19:45:00	2022-10-25 21:45:00	\N	\N	8	0	609	\N
667648	GIA	AUCUNE	\N	\N	\N	Entretien avec une délégation du Sénat des Philippines	Entretien avec une délégation de sénateurs philippins conduite par le Président Juan Miguel ZUBIRI	2022-10-25 17:15:00	2022-10-25 18:15:00	\N	\N	8	0	609	\N
667659	GIA	AUCUNE	\N	\N	\N	Entretien avec Muriel PERNIN, journaliste spécialisée sur l'Arménie	Entretien organisé conjointement avec le groupe d'amitié France-Arménie	2022-10-26 08:30:00	2022-10-26 10:00:00	\N	\N	12	0	1013	\N
730545	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2023-05-17 08:30:00	2023-05-17 10:50:00	2023-05-24 09:46:30	2023-05-24 17:29:05	38	0	\N	\N
667672	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	Réunion du Groupe d'études "Français de l'étranger": programme de travail	Réunion du Bureau du groupe d'études "Statut, rôle et place des Français établis hors de France"	2022-10-26 18:00:00	2022-10-26 19:00:00	\N	\N	6	0	\N	\N
667680	GIA	AUCUNE	\N	\N	\N	Petit déjeuner de travail avec les sénateurs philippins et des entreprises françaises	Petit déjeuner économique avec une délégation du Sénat des Philippines 	2022-10-26 09:00:00	2022-10-26 10:15:00	\N	\N	2	0	609	\N
667683	GIA	AUCUNE	\N	\N	\N	Entretien avec une délégation du Sénat égyptien conduite par son président	Echange interparlementaire avec les sénateurs égyptiens	2022-09-27 11:30:00	2022-09-27 12:45:00	\N	\N	9	0	617	\N
669560	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF 2023 : Missions Engagements financiers de l'État et  Travail et Emploi	PLF 2023 : Missions Engagements financiers de l'État et  Travail et Emploi	2022-11-10 09:35:00	2022-11-10 11:30:00	2022-11-10 11:56:29	2022-11-10 16:13:04	23	1	\N	\N
669561	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Justice - DAP	PLF pour 2023 - Justice - DAP	2022-11-03 11:00:00	2022-11-03 12:00:00	\N	\N	1	0	\N	\N
669566	COM_PERMANENTE	AUTRE	\N	LOIS	\N	MI Organisation de la police judiciaire - Audition de Bruno Jockers, MGGN	MI Organisation de la police judiciaire - Audition de Bruno Jockers, MGGN	2022-11-08 17:00:00	2022-11-08 18:15:00	2022-11-08 20:02:37	2022-11-09 17:25:44	21	0	\N	\N
669567	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PLF pour 2023 - Mission Justice - Audition d'Éric Dupond-Moretti	PLF pour 2023 - Mission Justice - Audition d'Éric Dupond-Moretti	2022-11-08 18:15:00	2022-11-08 20:00:00	2022-11-08 20:02:59	2022-11-09 17:25:46	26	0	\N	\N
669570	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PLF pour 2023 -Relations avec les collectivités territ. - Audition de Christophe Béchu	PLF pour 2023 -Relations avec les collectivités territ. - Audition de Christophe Béchu	2022-11-09 16:35:00	2022-11-09 17:55:00	2022-11-09 19:49:18	2022-11-10 16:13:07	18	0	\N	\N
677426	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - MI organisation de la police judiciaire	Audition rapporteur - MI organisation de la police judiciaire	2022-11-18 16:00:00	2022-11-18 17:00:00	\N	\N	1	0	\N	\N
677428	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - MI organisation de la police judiciaire	Audition rapporteur - MI organisation de la police judiciaire	2022-11-22 09:00:00	2022-11-22 10:00:00	\N	\N	2	0	\N	\N
702626	ETUDES	DEPLACEMENT	\N	\N	\N	Salon Wine Paris	Salon Wine Paris	2023-02-14 14:00:00	2023-02-14 17:00:00	\N	\N	8	0	\N	909
702661	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 10	PLENIERE - 10	2023-02-15 10:30:00	2023-02-15 11:45:00	2023-02-15 12:19:34	2023-02-15 17:33:36	31	0	\N	\N
703566	ETUDES	AUDRAP	\N	\N	\N	GEAC - AUdition de M. Franck GOLDNADEL, président Aéroports Côte d'Azur	GEAC - AUdition de M. Franck GOLDNADEL, président Aéroports Côte d'Azur	2023-03-08 13:30:00	2023-03-08 14:30:00	\N	\N	9	0	\N	933
703630	MISSION	AUDRAP	\N	BATI	\N	MI bati	\N	2023-02-15 16:30:00	2023-02-15 17:30:00	\N	\N	6	0	\N	\N
703637	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPLO Saint-Barthélemy - Audition M. Jacques	\N	2023-02-15 14:00:00	2023-02-15 15:00:00	\N	\N	1	0	\N	\N
703638	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI cinéma	\N	2023-02-15 16:30:00	2023-02-15 17:30:00	\N	\N	4	0	\N	\N
703649	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL fraudes artistiques	\N	2023-02-14 15:00:00	2023-02-14 17:00:00	\N	\N	2	0	\N	\N
703654	COM_SPECIALE	AUDRAP	\N	CZAN	\N	Auditions CS ZAN	Auditions CS ZAN	2023-02-14 14:15:00	2023-02-14 15:30:00	\N	\N	14	0	\N	\N
703671	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPLO Saint-Barthélemy - Audition Collectivité	\N	2023-02-15 17:30:00	2023-02-15 18:15:00	\N	\N	1	0	\N	\N
703672	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 2 mars 2023	\N	2023-03-02 09:00:00	2023-03-02 10:35:00	2023-03-02 10:47:45	2023-03-02 18:15:57	12	0	\N	\N
703673	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 1er mars 2023	\N	2023-03-01 17:00:00	2023-03-01 18:20:00	2023-03-02 10:47:27	2023-03-02 18:15:57	21	0	\N	\N
728205	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition M. Emmanuel Chiva + Communication bilan application des lois	\N	2023-05-10 09:35:00	2023-05-10 11:25:00	2023-05-10 14:45:35	2023-05-10 15:28:45	33	4	\N	\N
728207	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Mission Oman/Emirats	Mission Oman/Emirats	2023-05-02 17:00:00	2023-05-02 19:00:00	\N	\N	3	0	\N	\N
728211	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	mi	Mission Oman/Emirats	2023-05-03 08:00:00	2023-05-03 09:00:00	\N	\N	4	0	\N	\N
729230	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion, organisée conjointement avec la délégation aux outre-mer	\N	2023-05-11 09:00:00	2023-05-11 12:00:00	2023-05-11 17:04:08	\N	13	0	\N	\N
729236	ETUDES	AUTRE	\N	\N	\N	Réunion constitutive	\N	2023-05-10 08:30:00	2023-05-10 09:30:00	\N	\N	10	0	\N	1006
729237	DELEGATION	AUCUNE	\N	\N	PROS	Audition de M. Jean-David Zeitoun sur la production de maladies par les activités humaines	\N	2023-05-11 08:30:00	2023-05-11 09:20:00	\N	\N	6	0	\N	\N
729238	DELEGATION	AUCUNE	\N	\N	206	Audition publique sur les enjeux de traité international sur la pollution plastique	\N	2023-05-11 09:35:00	2023-05-11 13:10:00	\N	\N	6	0	\N	\N
729283	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI JOP 2024	Audition du DIJOP	2023-05-09 14:30:00	2023-05-09 16:00:00	\N	\N	3	0	\N	\N
729284	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI JOP 2024	Audition de la Ville de Paris	2023-05-09 16:30:00	2023-05-09 17:50:00	\N	\N	4	0	\N	\N
729290	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition ZFEm	\N	2023-05-09 13:45:00	2023-05-09 15:15:00	\N	\N	1	0	\N	\N
729295	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions ZFE	\N	2023-05-09 16:00:00	2023-05-09 18:45:00	\N	\N	1	0	\N	\N
729373	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition	\N	2023-05-09 14:00:00	2023-05-09 16:25:00	\N	\N	0	0	\N	\N
729374	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition ZRR	\N	2023-05-09 14:00:00	2023-05-09 15:35:00	\N	\N	2	0	\N	\N
729378	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition ZRR - association des maires ruraux de France (AMRF)	\N	2023-05-09 15:35:00	2023-05-09 16:25:00	\N	\N	2	0	\N	\N
729506	MISSION	AUCUNE	\N	BATI	\N	Point d'étapes	\N	2023-05-10 13:45:00	2023-05-10 14:45:00	2023-05-10 14:46:28	2023-05-10 15:29:08	9	0	\N	\N
729876	MISSION	AUDRAP	\N	LOCA	\N	Audtion M. TAVERNIER - DG INSEE	\N	2023-05-16 09:00:00	2023-05-16 10:00:00	\N	\N	4	0	\N	\N
729877	MISSION	AUCUNE	\N	LOCA	\N	Réunion de présentation orientations du rapport	\N	2023-05-16 17:00:00	2023-05-16 18:30:00	2023-05-16 19:06:56	2023-05-17 14:38:54	5	0	\N	\N
729881	ETUDES	AUTRE	\N	\N	\N	ANNLF	ANNLF	2023-05-10 08:00:00	2023-05-10 09:30:00	\N	\N	20	0	\N	907
730266	COM_ENQUETE	PLENIERE	\N	RENOV	\N	Table ronde rénovation du parc social / Schneider	\N	2023-05-10 17:05:00	2023-05-10 20:05:00	2023-05-11 12:34:41	2023-05-11 16:17:28	8	0	\N	\N
730483	COM_ENQUETE	PLENIERE	\N	RENOV	\N	Table ronde collectivités locales	\N	2023-05-11 10:30:00	2023-05-11 12:35:00	2023-05-11 12:36:47	2023-05-11 16:17:30	6	0	\N	\N
669569	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désignations, rapports et avis budgétaires	Désignations, rapports et avis budgétaires	2022-11-09 09:00:00	2022-11-09 11:25:00	2022-11-09 16:09:43	2022-11-09 17:25:50	38	1	\N	\N
730546	COM_ENQUETE	PLENIERE	\N	RENOV	\N	Tables rondes	\N	2023-05-11 14:05:00	2023-05-11 17:05:00	2023-05-11 17:15:33	2023-05-12 18:03:44	6	0	\N	\N
730573	COM_ENQUETE	PLENIERE	\N	MEDIC	\N	Réunion plénière	\N	2023-05-16 09:05:00	2023-05-16 10:30:00	2023-05-16 10:36:58	2023-05-16 15:30:29	7	0	\N	\N
730574	COM_ENQUETE	PLENIERE	\N	MEDIC	\N	Réunion plénière	\N	2023-05-16 13:45:00	2023-05-16 17:50:00	2023-05-16 18:18:18	2023-05-17 14:38:54	8	0	\N	\N
730575	COM_ENQUETE	PLENIERE	\N	MEDIC	\N	Réunion plénière	\N	2023-05-17 13:30:00	2023-05-17 14:55:00	2023-05-17 18:11:01	2023-05-19 16:15:01	11	0	\N	\N
730576	COM_ENQUETE	PLENIERE	\N	MEDIC	\N	Réunion plénière	\N	2023-05-17 16:30:00	2023-05-17 19:15:00	2023-05-17 19:15:23	2023-05-19 16:15:02	6	0	\N	\N
730577	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - EPF/EPA - Audition Réseau national des Aménageurs (RNA)	Contrôle 2023 - EPF/EPA - Audition Réseau national des Aménageurs (RNA)	2023-05-09 15:30:00	2023-05-09 16:30:00	\N	\N	1	0	\N	\N
730579	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - EPF/EPA - Audition EPF Haute Savoie	Contrôle 2023 - EPF/EPA - Audition EPF Haute Savoie	2023-05-09 17:15:00	2023-05-09 18:15:00	\N	\N	1	0	\N	\N
730581	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Modernisation DSNA - Audition USAC-CGT	Contrôle 2023 - Modernisation DSNA - Audition USAC-CGT	2023-05-09 09:00:00	2023-05-09 10:00:00	\N	\N	1	0	\N	\N
730583	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Modernisation DSNA - Audition Mme PEILLAN, DGAC	Contrôle 2023 - Modernisation DSNA - Audition Mme PEILLAN, DGAC	2023-05-09 10:00:00	2023-05-09 11:00:00	\N	\N	1	0	\N	\N
730585	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Modernisation DSNA - Audition M. Thierry PELLE	Contrôle 2023 - Modernisation DSNA - Audition M. Thierry PELLE	2023-05-09 14:30:00	2023-05-09 15:30:00	\N	\N	1	0	\N	\N
730596	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2023 - IRSN - Déplacement au siège IRSN Fontenay-aux-Roses	Contrôle 2023 - IRSN - Déplacement au siège IRSN Fontenay-aux-Roses	2023-05-11 14:00:00	2023-05-11 17:00:00	\N	\N	1	0	\N	\N
730598	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - IRSN - Audition au siège de l'IRSN	Contrôle 2023 - IRSN - Audition au siège de l'IRSN	2023-05-11 14:00:00	2023-05-11 17:00:00	\N	\N	1	0	\N	\N
730604	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - ORE - Audition du rectorat d'Ile de France	Contrôle 2023 - ORE - Audition du rectorat d'Ile de France	2023-05-09 14:00:00	2023-05-09 15:00:00	\N	\N	1	0	\N	\N
730618	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Audition Cour des Comptes 3° chambre	Contrôle 2023 - Audition Cour des Comptes 3° chambre	2023-05-09 15:00:00	2023-05-09 16:00:00	\N	\N	1	0	\N	\N
730632	MISSION	AUCUNE	\N	GEAU	\N	Audition de Météo France	\N	2023-05-11 11:00:00	2023-05-11 12:35:00	2023-05-11 18:10:45	2023-05-12 18:03:43	5	0	\N	\N
730639	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-05-17 09:30:00	2023-05-17 12:00:00	2023-05-17 15:18:36	2023-05-17 15:57:19	29	0	\N	\N
730640	MISSION	AUCUNE	\N	AVENCOMM	\N	Audition d'Olivier Jacob (DMATES)	Audition d'Olivier Jacob (DMATES)	2023-05-16 09:00:00	2023-05-16 10:20:00	2023-05-16 11:51:12	2023-05-16 15:30:28	7	0	\N	\N
730641	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Ouvertures de casinos (amendements)	PPL Ouvertures de casinos (amendements)	2023-05-16 14:15:00	2023-05-16 14:20:00	2023-05-16 15:47:30	2023-05-16 16:24:12	12	1	\N	\N
730642	MISSION	AUCUNE	\N	AVENCOMM	\N	Audition de Stanislas Bourron, directeur général de l'ANCT	Audition de Stanislas Bourron, directeur général de l'ANCT	2023-05-16 17:35:00	2023-05-16 18:40:00	2023-05-16 18:46:00	2023-05-17 14:38:53	5	0	\N	\N
730645	MISSION	AUCUNE	\N	AVENCOMM	\N	Audition de Yannick Morez, maire démissionnaire de Saint-Brévin-les-Pins	Audition de Yannick Morez, maire démissionnaire de Saint-Brévin-les-Pins	2023-05-17 11:20:00	2023-05-17 13:05:00	2023-05-17 14:33:36	2023-05-17 14:38:52	39	0	\N	\N
730646	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de Yannick Morez, maire démissionnaire de Saint-Brévin-les-Pins	Audition de Yannick Morez, maire démissionnaire de Saint-Brévin-les-Pins	2023-05-17 11:20:00	2023-05-17 13:05:00	2023-05-17 14:33:45	2023-05-17 14:38:13	39	1	\N	\N
639288	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Audition rapporteurs MI répartition des moyens alloués au patrimoine	\N	2022-03-15 17:20:00	2022-03-15 18:30:00	\N	\N	2	0	\N	\N
639289	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI répartition des moyens alloués au patrimoine	\N	2022-03-16 09:00:00	2022-03-16 10:50:00	\N	\N	6	0	\N	\N
640605	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	Réunion du GT subsidiarité	GT subsidiarité	2022-03-30 14:15:00	2022-03-30 14:30:00	\N	\N	2	0	\N	\N
641193	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition MI métropoles Lyon Aix-Marseille-Provence	Audition MI métropoles Lyon Aix-Marseille-Provence	2022-04-12 08:30:00	2022-04-12 09:20:00	\N	\N	8	0	\N	\N
641196	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition MI métropoles Lyon Aix-Marseille-Provence	\N	2022-04-12 11:30:00	2022-04-12 12:15:00	\N	\N	6	0	\N	\N
641200	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition MI métropoles Lyon Aix-Marseille-Provence	\N	2022-04-12 14:00:00	2022-04-12 15:45:00	\N	\N	9	0	\N	\N
641203	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition MI métropoles Lyon Aix-Marseille-Provence	\N	2022-04-12 15:45:00	2022-04-12 17:05:00	\N	\N	6	0	\N	\N
641206	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition MI métropoles Lyon Aix-Marseille-Provence	\N	2022-04-12 17:05:00	2022-04-12 18:00:00	\N	\N	5	0	\N	\N
641209	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition MI métropoles Lyon Aix-Marseille-Provence	\N	2022-04-12 18:00:00	2022-04-12 19:30:00	\N	\N	7	0	\N	\N
641212	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition énergie et hydrogène nucléaires	Audition énergie et hydrogène nucléaires	2022-04-12 09:45:00	2022-04-12 12:30:00	\N	\N	4	0	\N	\N
641217	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition MI énergie et hydrogène nucléaires	Audition MI énergie et hydrogène nucléaires	2022-04-12 15:30:00	2022-04-12 16:15:00	\N	\N	2	0	\N	\N
644777	GIA	AUCUNE	\N	\N	\N	Entretien avec M. franck Giaoui	Entretien avec M. franck Giaoui, conseiller en finance et en stratégie	2022-06-14 14:30:00	2022-06-14 16:00:00	\N	\N	4	0	590	\N
649052	GIA	AUCUNE	\N	\N	\N	Réunion du groupe d'amitié France-Syrie	Réunion du groupe d'amitié France-Syrie	2022-07-12 13:30:00	2022-07-12 15:00:00	\N	\N	2	0	644	\N
649066	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI  Méditerranée	\N	2022-07-05 17:30:00	2022-07-05 18:30:00	\N	\N	1	0	\N	\N
649068	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI  Méditerranée	\N	2022-07-07 10:00:00	2022-07-07 12:00:00	\N	\N	1	0	\N	\N
651586	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Conclusions CMP DDADUE prévention terrorisme en ligne	Conclusions CMP DDADUE prévention terrorisme en ligne	2022-07-26 14:30:00	2022-07-26 15:20:00	\N	\N	88	0	\N	\N
651587	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Conclusions CMP sécurité sanitaire covid 9	Conclusions CMP sécurité sanitaire covid 9	2022-07-26 15:30:00	2022-07-26 16:30:00	\N	\N	112	0	\N	\N
730644	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Douane (rapport pour avis et articles délégués au fond)	PJL Douane (rapport pour avis et articles délégués au fond)	2023-05-17 08:30:00	2023-05-17 09:45:00	2023-05-17 14:23:52	2023-05-17 14:38:15	27	1	\N	\N
651588	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2022-07-27 15:00:00	2022-07-27 16:20:00	\N	\N	225	0	\N	\N
651589	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL pouvoir d'achat	PJL pouvoir d'achat	2022-07-28 10:30:00	2022-07-28 12:40:00	\N	\N	133	0	\N	\N
651590	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL pouvoir d'achat	PJL pouvoir d'achat	2022-07-28 14:30:00	2022-07-28 19:55:00	\N	\N	132	0	\N	\N
651591	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL pouvoir d'achat	PJL pouvoir d'achat	2022-07-28 21:30:00	2022-07-29 00:55:00	\N	\N	86	0	\N	\N
651592	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL pouvoir d'achat	PJL pouvoir d'achat	2022-07-29 09:55:00	2022-07-29 13:05:00	\N	\N	82	0	\N	\N
651593	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL pouvoir d'achat	PJL pouvoir d'achat	2022-07-29 14:35:00	2022-07-29 21:25:00	\N	\N	87	0	\N	\N
655385	DELEGATION	AUDRAP	\N	\N	PROS	Audition de M. Laurent CAPPELLETTI	\N	2022-07-27 11:30:00	2022-07-27 12:30:00	\N	\N	1	0	\N	\N
655387	DELEGATION	AUDRAP	\N	\N	PROS	Audition M. Philippe CLERGEAU	\N	2022-07-27 14:00:00	2022-07-27 15:00:00	\N	\N	1	0	\N	\N
655982	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	enssco	\N	2022-09-20 17:00:00	2022-09-20 18:00:00	\N	\N	7	0	\N	\N
656182	GIA	AUCUNE	\N	\N	\N	Conférence sur la situation au Haut-Karabagh	Conférence sur la situation au Haut-Karabagh	2022-09-20 18:00:00	2022-09-20 20:00:00	\N	\N	12	0	641	\N
657977	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Table ronde consacrée aux jeux vidéos	\N	2022-10-12 09:30:00	2022-10-12 11:15:00	2022-10-14 10:03:47	2022-10-14 11:19:42	32	0	\N	\N
657983	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition Amélie Oudéa Castera	\N	2022-10-12 16:50:00	2022-10-12 18:45:00	2022-10-14 10:07:38	2022-10-14 11:19:47	25	0	\N	\N
657984	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions rapporteur - Cabinets de Conseil	\N	2022-09-27 10:15:00	2022-09-27 11:15:00	\N	\N	0	0	\N	\N
658131	ETUDES	AUTRE	\N	\N	\N	Auditions Mme Marie-Pierre Monier	Auditions Mme Marie-Pierre Monier	2022-10-05 13:30:00	2022-10-05 15:00:00	\N	\N	5	0	\N	1005
658887	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	TR Hauts-de-France	\N	2022-10-04 15:00:00	2022-10-04 16:40:00	\N	\N	0	0	\N	\N
670027	DELEGATION	AUCUNE	\N	\N	206	Audition publique sur les conséquences du réchauffement climatique sur la biodiversité	\N	2022-11-10 09:45:00	2022-11-10 12:40:00	\N	\N	7	0	\N	\N
670031	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2023 Mission Anciens combattants - Table ronde d'associations	\N	2022-11-02 16:30:00	2022-11-02 18:00:00	\N	\N	1	0	\N	\N
670032	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2023 Mission Anciens combattants - Audition de Mme Patricia Mirallès	\N	2022-11-03 10:30:00	2022-11-03 12:00:00	\N	\N	3	0	\N	\N
670033	ETUDES	AUTRE	\N	\N	\N	GE Monde combattant et mémoire - Audition de Mme Patricia Mirallès	\N	2022-11-03 10:30:00	2022-11-03 12:00:00	\N	\N	7	0	\N	928
670085	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 10 novembre 2022	\N	2022-11-10 08:30:00	2022-11-10 10:00:00	2022-11-10 10:10:18	2022-11-10 16:13:04	17	0	\N	\N
670331	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition PLF 2023 - Transports aériens	Audition PLF 2023 - Transports aériens	2022-11-02 14:00:00	2022-11-02 15:00:00	\N	\N	3	0	\N	\N
670335	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2023 - Auditions Économie Industrie	\N	2022-10-27 13:30:00	2022-10-27 18:50:00	\N	\N	0	0	\N	\N
670336	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition M. Philippe Tabarot et M. Hervé Gillé	Audition M. Philippe Tabarot et M. Hervé Gillé	2022-10-18 17:15:00	2022-10-18 18:15:00	\N	\N	2	0	\N	\N
670341	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2023 Mission Travail et emploi - Audition de Pôle emploi	\N	2022-11-07 15:00:00	2022-11-07 16:15:00	\N	\N	1	0	\N	\N
670342	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2023 Mission Travail et emploi - Audition de France compétences	\N	2022-11-07 16:15:00	2022-11-07 17:15:00	\N	\N	1	0	\N	\N
670343	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2023 Mission Travail et emploi - Audition de la DGT	\N	2022-11-07 10:30:00	2022-11-07 11:30:00	\N	\N	1	0	\N	\N
670344	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2023 Mission Travail et emploi - Audition de la DGEFP	\N	2022-11-07 11:45:00	2022-11-07 13:00:00	\N	\N	1	0	\N	\N
670347	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2023 - Audition Économie - Industrie	PLF 2023 - Audition Économie - Industrie	2022-11-02 17:15:00	2022-11-02 18:15:00	\N	\N	1	0	\N	\N
670351	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2023 - Audition Économie - Industrie	PLF 2023 - Audition Économie - Industrie	2022-11-07 15:00:00	2022-11-07 15:45:00	\N	\N	1	0	\N	\N
670353	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Hervé Gillé	Auditions M. Hervé Gillé	2022-11-03 08:00:00	2022-11-03 09:30:00	\N	\N	1	0	\N	\N
670355	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Hervé Gillé	Auditions M. Hervé Gillé	2022-11-08 15:30:00	2022-11-08 17:00:00	\N	\N	2	0	\N	\N
670367	DELEGATION	AUDRAP	\N	\N	206	Auditions sur la sobriété énergétique	\N	2022-11-03 14:00:00	2022-11-03 15:00:00	\N	\N	2	0	\N	\N
670530	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Table ronde sur l'exploration lunaire	\N	2022-11-08 14:00:00	2022-11-08 15:00:00	\N	\N	0	0	\N	\N
670551	COM_PERMANENTE	AUDRAP	\N	CAE	\N	ANFR	ANFR	2022-10-26 12:00:00	2022-10-26 12:45:00	\N	\N	1	0	\N	\N
670557	COM_PERMANENTE	AUDRAP	\N	CAE	\N	La Poste	La Poste	2022-10-28 14:00:00	2022-10-28 14:45:00	\N	\N	1	0	\N	\N
670570	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Infranum	Infranum	2022-10-28 14:45:00	2022-10-28 15:30:00	\N	\N	1	0	\N	\N
670572	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2023 - Barreau de Paris	PLF pour 2023 - Barreau de Paris	2022-11-10 11:20:00	2022-11-10 11:40:00	\N	\N	1	0	\N	\N
670573	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Arcep	Arcep	2022-11-07 15:00:00	2022-11-07 15:45:00	\N	\N	1	0	\N	\N
702279	GIA	AUCUNE	\N	\N	\N	Coopé - Visite de Mme Asma ELSAADI, Conseillère parlementaire à la commission des affaires	Coopé - Visite de Mme Asma ELSAADI, Conseillère parlementaire à la commission des affaires	2023-02-14 16:00:00	2023-02-14 17:00:00	\N	\N	1	0	657	\N
738353	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2023 - AGTE - Déplacement préfecture de Rouen	\N	2023-06-08 08:00:00	2023-06-08 19:30:00	\N	\N	0	0	\N	\N
738359	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2023 - AGTE - Déplacement préfecture Limoges	\N	2023-06-26 08:00:00	2023-06-26 21:00:00	\N	\N	0	0	\N	\N
738360	COM_SPECIALE	PLENIERE	\N	CINC	\N	Réunion plénière CS Risque incendie	\N	2023-06-06 14:00:00	2023-06-06 14:10:00	2023-06-06 16:05:23	2023-06-07 10:34:11	18	0	\N	\N
738362	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 41	\N	2023-06-07 10:30:00	2023-06-07 13:10:00	2023-06-19 18:06:28	2023-06-19 18:09:49	29	2	\N	\N
725549	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PPL Influenceurs	\N	2023-04-13 13:00:00	2023-04-13 15:15:00	\N	\N	1	0	\N	\N
738361	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 40 - PPL 69 Mécénat - Examen du rapport et élaboration texte de la commission	PLENIERE - 40 - PPL 69 Mécénat - Examen du rapport et élaboration du texte de la commission	2023-06-07 09:45:00	2023-06-07 10:00:00	2023-06-08 18:26:34	2023-06-19 18:09:47	40	4	\N	\N
738363	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 42	\N	2023-06-07 14:00:00	2023-06-07 14:50:00	2023-06-07 18:29:20	2023-06-08 11:18:27	17	3	\N	\N
738364	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 41	\N	2023-06-07 16:30:00	2023-06-07 18:00:00	2023-06-07 18:29:05	2023-06-08 11:18:27	14	1	\N	\N
738365	DELEGATION	AUTRE	\N	\N	DSOM	Foncier agricole outre-mer : audition de M. Marc Fesneau, ministre de l'agriculture	\N	2023-06-20 17:00:00	2023-06-20 18:30:00	\N	\N	9	0	\N	\N
738366	COM_PERMANENTE	AUTRE	\N	AFCL	\N	PPL audiovisuel public - amdts de séance	\N	2023-06-12 19:30:00	2023-06-12 20:00:00	2023-06-13 14:50:27	2023-06-14 15:27:54	19	6	\N	\N
738369	DELEGATION	AUCUNE	\N	\N	206	Audition publique sur les micropolluants de l'eau	\N	2023-06-08 09:40:00	2023-06-08 12:20:00	\N	\N	6	0	\N	\N
738502	COM_ENQUETE	AUDRAP	\N	TIKTO	\N	Audition du SNEP	Audition du SNEP	2023-06-05 16:00:00	2023-06-05 16:45:00	\N	\N	5	0	\N	\N
738508	COM_ENQUETE	AUDRAP	\N	TIKTO	\N	Audition SACEM	Audition SACEM	2023-05-31 16:30:00	2023-05-31 17:30:00	\N	\N	6	0	\N	\N
739766	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2023-06-06 17:00:00	2023-06-06 19:00:00	\N	\N	2	0	\N	\N
740742	GIA	AUCUNE	\N	\N	\N	audience de M. Shalva Pauashvili, Président du Parlement de Géorgie	\N	2023-06-07 17:00:00	2023-06-07 18:15:00	\N	\N	3	0	534	\N
740746	GIA	AUCUNE	\N	\N	\N	entretien avec une délégation de parlementaires géorgiens	\N	2023-06-07 19:30:00	2023-06-07 22:30:00	\N	\N	4	0	534	\N
740801	GIA	AUCUNE	\N	\N	\N	Coopé - Visite de M. Natan ALBAHARI, député à l'Assemblée nationale de Serbie	Coopé - Visite de M. Natan ALBAHARI, député à l'Assemblée nationale de Serbie	2023-06-07 12:30:00	2023-06-07 14:00:00	\N	\N	3	0	674	\N
742055	GIA	AUCUNE	\N	\N	\N	entretien avec S.E. M. Mohamed Jumeh, ambassadeur du Yémen auprès de l'UNESCO	\N	2023-06-13 16:00:00	2023-06-13 17:00:00	\N	\N	2	0	627	\N
746061	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	Audition rapporteur - MI Principes de la République	2023-06-21 17:00:00	2023-06-21 18:30:00	\N	\N	2	0	\N	\N
746066	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Régime juridique des actions de groupe	PPL Régime juridique des actions de groupe	2023-06-22 09:35:00	2023-06-22 12:30:00	\N	\N	1	0	\N	\N
746068	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Régime juridique des actions de groupe	PPL Régime juridique des actions de groupe	2023-06-22 14:15:00	2023-06-22 18:30:00	\N	\N	1	0	\N	\N
746780	GIA	AUCUNE	\N	\N	\N	Audition de l'American chamber of commerce 	Audition de l'American chamber of commerce 	2023-06-14 17:00:00	2023-06-14 18:35:00	\N	\N	3	0	590	\N
746784	GIA	AUCUNE	\N	\N	\N	Coopé - Entretien avec des Staffers du Congrès US	Coopé - Entretien avec des Staffers du Congrès US	2023-06-27 12:00:00	2023-06-27 15:00:00	\N	\N	2	0	590	\N
748161	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 57	PLENIERE - 57	2023-07-05 09:00:00	2023-07-05 12:10:00	2023-07-05 14:02:09	2023-07-05 18:21:46	29	6	\N	\N
748162	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 53 bis	\N	2023-07-03 15:30:00	2023-07-03 15:40:00	2023-07-03 16:04:05	2023-07-03 16:54:45	12	3	\N	\N
748163	MISSION	AUTRE	\N	BIOCARBU	\N	PLENIERE - 24 - Réunion de remise du rapport	\N	2023-07-03 18:00:00	2023-07-03 20:00:00	2023-07-11 13:55:40	2023-07-11 13:55:47	8	1	\N	\N
748164	ETUDES	AUTRE	\N	\N	\N	Audition CNC	Audition CNC	2023-06-28 16:30:00	2023-06-28 18:00:00	\N	\N	2	0	\N	1012
748167	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 55	\N	2023-07-04 15:00:00	2023-07-04 17:50:00	2023-07-11 13:57:10	2023-07-11 13:57:15	28	6	\N	\N
748986	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition - MI Principes de la République	Audition rapporteur - MI Principes de la République	2023-07-04 14:30:00	2023-07-04 16:00:00	\N	\N	2	0	\N	\N
749971	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Plein emploi 	PJL Plein emploi 	2023-07-10 16:00:00	2023-07-10 20:00:00	\N	\N	58	0	\N	\N
749972	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Plein emploi	PJL Plein emploi	2023-07-10 21:30:00	2023-07-11 00:50:00	\N	\N	51	0	\N	\N
749973	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Plein emploi	PJL Plein emploi	2023-07-11 14:30:00	2023-07-11 20:00:00	\N	\N	142	0	\N	\N
749974	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Plein emploi	PJL Plein emploi	2023-07-11 21:30:00	2023-07-12 01:05:00	\N	\N	71	0	\N	\N
749975	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2023-07-12 15:00:00	2023-07-12 16:25:00	\N	\N	228	0	\N	\N
749976	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Renforcer la protection des familles d'enfants malades 	CMP Renforcer la protection des familles d'enfants malades	2023-07-12 16:35:00	2023-07-12 17:20:00	\N	\N	32	0	\N	\N
749979	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Programmation militaire	CMP Programmation militaire	2023-07-13 10:30:00	2023-07-13 11:35:00	\N	\N	47	0	\N	\N
749980	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Zéro artificialisation nette	CMP Zéro artificialisation nette	2023-07-06 10:35:00	2023-07-06 13:00:00	\N	\N	0	0	\N	\N
749981	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP ZAN	CMP ZAN	2023-07-13 11:40:00	2023-07-13 12:40:00	\N	\N	36	0	\N	\N
749982	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Biens culturels spoliés entre 1933 et 1945	CMP Biens culturels spoliés entre 1933 et 1945	2023-07-13 12:45:00	2023-07-13 13:30:00	\N	\N	19	0	\N	\N
750559	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-07-11 21:15:00	2023-07-11 21:20:00	2023-07-12 09:32:26	2023-07-12 10:30:18	12	0	\N	\N
750754	COM_SPECIALE	AUDRAP	\N	ESNU	\N	Table-ronde Réseaux sociaux	\N	2023-07-11 09:30:00	2023-07-11 11:30:00	\N	\N	4	0	\N	\N
750849	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	E. Leclerc	\N	2023-07-04 17:00:00	2023-07-04 17:45:00	\N	\N	2	0	\N	\N
750854	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Les Mousquetaires	\N	2023-07-04 17:45:00	2023-07-04 18:30:00	\N	\N	2	0	\N	\N
750857	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Ania	\N	2023-07-04 18:30:00	2023-07-04 19:15:00	\N	\N	2	0	\N	\N
750860	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Agence Bio	\N	2023-07-05 16:30:00	2023-07-05 17:15:00	\N	\N	2	0	\N	\N
750871	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Ministère de l'agriculture et de la souveraineté alimentaire	\N	2023-07-05 17:15:00	2023-07-05 18:00:00	\N	\N	2	0	\N	\N
750875	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	TR filières végétales	\N	2023-07-05 18:00:00	2023-07-05 19:00:00	\N	\N	2	0	\N	\N
750878	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Observatoire de la formation des prix et des marges	Observatoire de la formation des prix et des marges	2023-06-27 18:45:00	2023-06-27 19:30:00	\N	\N	2	0	\N	\N
750882	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Observatoire de la restauration collective	\N	2023-06-28 17:45:00	2023-06-28 18:30:00	\N	\N	2	0	\N	\N
750885	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	DGCCRF	\N	2023-06-28 18:30:00	2023-06-28 19:15:00	\N	\N	2	0	\N	\N
750888	COM_PERMANENTE	AUDRAP	\N	CAE	\N	TR industriels de l'hygiène et de la beauté	TR industriels de l'hygiène et de la beauté	2023-06-20 17:00:00	2023-06-20 18:00:00	\N	\N	2	0	\N	\N
638073	GIA	AUCUNE	\N	\N	\N	Visioconférence avec le groupe d'amitié Irlande-France du Parlement irlandais	Visioconférence avec le groupe d'amitié Irlande-France du Parlement irlandais	2022-02-24 11:15:00	2022-02-24 12:00:00	\N	\N	1	0	594	\N
641493	GIA	AUCUNE	\N	\N	\N	Coopé - Entretien avec M. Saroeuth KOUSOUM, député cambodgien	Coopé - Entretien avec M. Saroeuth KOUSOUM, député cambodgien	2022-04-11 11:00:00	2022-04-11 12:00:00	\N	\N	1	0	577	\N
641507	GIA	AUCUNE	\N	\N	\N	Coopé - Entretien avec Mme Nur Qyira YUSRI, personnalité malaisienne	Coopé - Entretien avec Mme Nur Qyira YUSRI, personnalité malaisienne	2022-04-12 12:30:00	2022-04-12 14:00:00	\N	\N	2	0	609	\N
643002	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	LPR	\N	2022-05-18 10:00:00	2022-05-18 11:00:00	\N	\N	4	0	\N	\N
643006	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	LPR	\N	2022-05-18 11:00:00	2022-05-18 12:00:00	\N	\N	2	0	\N	\N
643405	COM_PERMANENTE	AUDRAP	\N	FINC	\N	MCC 2022 - Audiovisuel Public - Radio France	MCC 2022 - Audiovisuel Public - Radio France	2022-05-30 12:00:00	2022-05-30 13:10:00	\N	\N	2	0	\N	\N
643408	COM_PERMANENTE	AUDRAP	\N	FINC	\N	MCC 2022 - Audiovisuel Public - Arte France	MCC 2022 - Audiovisuel Public - Arte France	2022-05-30 17:00:00	2022-05-30 17:55:00	\N	\N	2	0	\N	\N
643446	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2022-05-25 09:00:00	2022-05-25 11:20:00	\N	\N	3	0	\N	\N
656343	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	\N	\N	2022-09-27 14:00:00	2022-09-27 14:50:00	\N	\N	1	0	\N	\N
656546	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteurs PJL Marché du travail - MEDEF	\N	2022-09-27 14:30:00	2022-09-27 15:15:00	\N	\N	0	0	\N	\N
656582	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2023 - Audition de M. Pierre MOSCOVICI, PDT HCFP sur l'avis du Haut Conseil	PLF pour 2023 - Audition de M. Pierre MOSCOVICI, PDT HCFP sur l'avis du Haut Conseil	2022-09-28 11:30:00	2022-09-28 12:30:00	2022-09-28 17:02:56	2022-09-29 14:40:57	23	1	\N	\N
656584	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - MI ZAN	Contrôle 2022 - MI ZAN	2022-09-27 18:30:00	2022-09-27 19:35:00	\N	\N	2	0	\N	\N
656593	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Mission Flash 2022 - Dons associations - Le mouvement associatif	Mission Flash 2022 - Dons associations - Le mouvement associatif	2022-09-27 10:00:00	2022-09-27 11:00:00	\N	\N	2	0	\N	\N
656597	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Mission Flash 2022 - Dons associations - France Générosités	Mission Flash 2022 - Dons associations - France Générosités	2022-09-27 14:00:00	2022-09-27 15:00:00	\N	\N	2	0	\N	\N
656600	AUTRE_TEMPORAIRE	AUCUNE	\N	\N	\N	MCC 2022 - Audiovisuel Public - Déplacement Ministère de la Culture	\N	2022-09-27 10:25:00	2022-09-27 11:50:00	\N	\N	0	0	\N	\N
656686	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur PPL Aide aux victimes violences conjugales	\N	2022-09-28 18:00:00	2022-09-28 19:00:00	\N	\N	1	0	\N	\N
656718	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition plénière	\N	2022-10-05 16:30:00	2022-10-05 17:50:00	\N	\N	19	0	\N	\N
656927	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur - PPL aide violences conjugales - Audition DGCS	\N	2022-09-29 15:00:00	2022-09-29 16:00:00	\N	\N	1	0	\N	\N
656929	DELEGATION	AUCUNE	\N	\N	211	Réunion plénière - Audition de Mme Isabelle Lonvis-Rome - nomination de rapporteurs	Réunion plénière - Audition de Mme Isabelle Lonvis-Rome - nomination de rapporteurs	2022-10-06 09:00:00	2022-10-06 10:45:00	2022-10-06 11:43:08	\N	9	0	\N	\N
656930	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2022-10-12 09:30:00	2022-10-12 11:30:00	2022-10-12 11:45:40	2022-10-12 17:33:56	36	0	\N	\N
656933	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions rapporteur - PPLC IVG	PPLC Droit fondamental à l'IVG et à la contraception	2022-09-28 14:00:00	2022-09-28 15:30:00	\N	\N	2	0	\N	\N
656936	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions rapporteurs - PPLC IVG	\N	2022-09-28 16:00:00	2022-09-28 17:00:00	\N	\N	1	0	\N	\N
656938	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur PPLC IVG	\N	2022-09-29 11:00:00	2022-09-29 12:00:00	\N	\N	1	0	\N	\N
656940	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions rapporteur - PPLC IVG	\N	2022-09-29 14:00:00	2022-09-29 15:30:00	\N	\N	2	0	\N	\N
656943	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions rapporteur PPL IVG	\N	2022-09-29 15:30:00	2022-09-29 16:30:00	\N	\N	1	0	\N	\N
656945	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - PPLC IVG	\N	2022-09-29 16:30:00	2022-09-29 17:30:00	\N	\N	1	0	\N	\N
656947	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2023 Presse	\N	2022-10-03 16:00:00	2022-10-03 18:00:00	\N	\N	1	0	\N	\N
660424	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Agence française de lutte contre le dopage	\N	2022-10-11 15:30:00	2022-10-11 16:30:00	\N	\N	3	0	\N	\N
660425	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	ANDES	\N	2022-10-11 16:30:00	2022-10-11 17:30:00	\N	\N	2	0	\N	\N
660426	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	INSEP	\N	2022-10-11 17:45:00	2022-10-11 18:30:00	\N	\N	4	0	\N	\N
660427	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - CCE - CESE/Conseil d'état-CNDA	PLF pour 2023 - CCE - CESE/Conseil d'état-CNDA	2022-10-11 17:00:00	2022-10-11 19:20:00	\N	\N	1	0	\N	\N
660438	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Association des Architectes du Patrimoine 	\N	2022-10-11 17:00:00	2022-10-11 17:45:00	\N	\N	3	0	\N	\N
660442	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Écologie - DGEC	PLF pour 2023 - Écologie - DGEC	2022-10-11 15:00:00	2022-10-11 16:40:00	\N	\N	2	0	\N	\N
660445	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Céréma-IGN-Météo-France - PDG Météo-France	PLF pour 2023 - Céréma-IGN-Météo-France - PDG Météo-France	2022-10-11 17:00:00	2022-10-11 18:20:00	\N	\N	1	0	\N	\N
660488	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Association des sociétés françaises d'autoroutes	Association des sociétés françaises d'autoroutes	2022-10-11 16:45:00	2022-10-11 17:30:00	\N	\N	4	0	\N	\N
660501	COM_PERMANENTE	AUDRAP	\N	CDD	\N	TR couverture parkings	TR couverture parkings	2022-10-11 17:30:00	2022-10-11 18:30:00	\N	\N	3	0	\N	\N
660703	ETUDES	AUTRE	\N	\N	\N	Section Cheval - Table ronde	Section Cheval - Table ronde	2022-10-12 08:00:00	2022-10-12 09:00:00	\N	\N	7	0	\N	912
660817	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Sordello	\N	2022-10-11 15:30:00	2022-10-11 17:00:00	\N	\N	1	0	\N	\N
661197	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2023 Branche autonomie - Audition de la DGCS	\N	2022-10-11 15:00:00	2022-10-11 16:00:00	\N	\N	2	0	\N	\N
661204	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2023 Autonomie - Audition de la Fehap	\N	2022-10-11 16:00:00	2022-10-11 16:50:00	\N	\N	1	0	\N	\N
669571	COM_PERMANENTE	AUTRE	\N	LOIS	\N	MI Organisation de la police judiciaire - Audition de François Molins, procureur général	MI Organisation de la police judiciaire - Audition de François Molins, procureur général	2022-11-09 18:05:00	2022-11-09 18:50:00	2022-11-09 19:48:49	2022-11-10 16:13:05	18	0	\N	\N
730753	COM_ENQUETE	PLENIERE	\N	RENOV	\N	Tables rondes	\N	2023-05-15 15:05:00	2023-05-15 20:00:00	2023-05-24 09:40:25	2023-05-24 09:43:33	6	0	\N	\N
656717	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-10-05 09:00:00	2022-10-05 12:40:00	2022-10-05 12:42:45	2022-10-05 17:35:05	44	0	\N	\N
669572	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition d'Aija Kalnaja, directrice exécutive de Frontex	Audition d'Aija Kalnaja, directrice exécutive de Frontex	2022-11-10 08:30:00	2022-11-10 10:05:00	2022-11-10 10:10:14	2022-11-10 16:13:05	17	0	\N	\N
669628	GIA	AUCUNE	\N	\N	\N	Entretien avec le Révérend G.B. Ngoussi, président - plateforme sté civile gabonaise	Entretien avec le Révérend Georges Bruno Ngoussi, président de la plateforme nationale de la société civile gabonaise	2022-11-02 16:30:00	2022-11-02 17:30:00	\N	\N	1	0	572	\N
669816	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Wargame	Wargame	2022-11-03 09:30:00	2022-11-03 17:00:00	\N	\N	7	0	\N	\N
670531	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GS Espace - TR Exploration lunaire	GS Espace - TR Exploration lunaire	2022-11-08 14:00:00	2022-11-08 15:00:00	\N	\N	6	0	\N	\N
670919	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF AEF	\N	2022-11-08 09:00:00	2022-11-08 10:50:00	\N	\N	1	0	\N	\N
671209	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2023 - Justice judiciaire et accès au droit	PLF pour 2023 - Justice judiciaire et accès au droit	2022-11-08 09:00:00	2022-11-08 10:30:00	\N	\N	2	0	\N	\N
671212	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2023 - Justice judiciaire et accès au droit	PLF pour 2023 - Justice judiciaire et accès au droit	2022-11-08 14:00:00	2022-11-08 17:15:00	\N	\N	2	0	\N	\N
671238	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions M. Laurent Duplomb, Mme Françoise Férat et M. Jean-Claude Tissot	Auditions M. Laurent Duplomb, Mme Françoise Férat et M. Jean-Claude Tissot	2022-11-08 17:15:00	2022-11-08 21:00:00	\N	\N	3	0	\N	\N
671538	ETUDES	AUTRE	\N	\N	\N	Réunion sur la filière ail	Réunion sur la filière ail	2022-11-09 13:30:00	2022-11-09 15:00:00	\N	\N	4	0	\N	1005
672988	SEANCE_PLENIERE	SCRUSOL	1741	\N	\N	Scrutin solennel - PLFSS	Scrutin solennel - PLFSS	2022-11-15 14:30:00	2022-11-15 16:00:00	\N	\N	0	0	\N	\N
672997	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	1741	\N	\N	Explications de vote PLFSS	Explications de vote PLFSS	2022-11-15 14:30:00	2022-11-15 15:45:00	\N	\N	303	0	\N	\N
690676	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Groupe de travail Décentralisation	Décentralisation - auditions rapporteurs	2023-01-10 14:30:00	2023-01-10 15:35:00	\N	\N	4	0	\N	\N
690681	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Groupe de travail Décentralisation	Décentralisation - auditions rapporteurs	2023-01-10 15:35:00	2023-01-10 16:30:00	\N	\N	3	0	\N	\N
701726	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2023-02-08 18:35:00	2023-02-08 19:16:00	\N	\N	24	0	\N	\N
730647	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Application des lois Protection de l'enfance - Table ronde de juges des enfants	\N	2023-05-09 17:30:00	2023-05-09 19:15:00	\N	\N	2	0	\N	\N
730648	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Fin de vie - Audition du Collectif Handicaps	\N	2023-05-09 17:30:00	2023-05-09 18:15:00	\N	\N	2	0	\N	\N
730649	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Fin de vie - Audition du Conseil national de l'ordre des infirmiers	\N	2023-05-09 18:15:00	2023-05-09 19:00:00	\N	\N	3	0	\N	\N
730650	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Fin de vie - Audition du Conseil national de l'ordre des médecins	\N	2023-05-10 13:30:00	2023-05-10 14:15:00	\N	\N	3	0	\N	\N
730651	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI FIn de vie - Table ronde sur la recherche	\N	2023-05-10 16:30:00	2023-05-10 17:45:00	\N	\N	2	0	\N	\N
730652	ETUDES	AUTRE	\N	\N	\N	Réunion plénière	\N	2023-05-09 14:30:00	2023-05-09 15:30:00	\N	\N	8	0	\N	928
730676	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Pôle d'excellence cyber à Rennes	Pôle d'excellence cyber à Rennes	2023-05-09 07:30:00	2023-05-09 19:00:00	\N	\N	3	0	\N	\N
730680	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Campus cyber Nouvelle Aquitaine à Bordeaux	Campus cyber Nouvelle Aquitaine à Bordeaux	2023-05-12 08:00:00	2023-05-12 18:00:00	\N	\N	1	0	\N	\N
730682	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2023-05-16 09:30:00	2023-05-16 12:35:00	\N	\N	46	0	\N	\N
730683	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Ouvertures de casinos	PPL Ouvertures de casinos	2023-05-16 14:30:00	2023-05-16 16:00:00	\N	\N	83	0	\N	\N
730684	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Ferme France	PPL Ferme France	2023-05-16 16:05:00	2023-05-16 20:00:00	\N	\N	130	0	\N	\N
730685	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Ferme France	PPL Ferme France	2023-05-16 21:30:00	2023-05-17 02:20:00	\N	\N	87	0	\N	\N
730686	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2023-05-17 15:00:00	2023-05-17 16:20:00	\N	\N	249	0	\N	\N
730687	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR Reconnaissance génocide ukrainien	PPR Reconnaissance génocide ukrainien	2023-05-17 16:30:00	2023-05-17 18:00:00	\N	\N	36	0	\N	\N
730689	DELEGATION	AUDRAP	\N	\N	206	Audition recyclage du plastique	\N	2023-05-11 15:00:00	2023-05-11 18:00:00	\N	\N	2	0	\N	\N
730692	DELEGATION	AUDRAP	\N	\N	206	Auditions sur l'innovation thérapeutique en cancérologie	\N	2023-05-03 16:30:00	2023-05-03 19:45:00	\N	\N	2	0	\N	\N
730695	MECSS	AUDRAP	\N	\N	MECSS	MI Solidarité à la source - Audition de la Drees	\N	2023-05-16 14:30:00	2023-05-16 15:30:00	\N	\N	2	0	\N	\N
730697	MECSS	AUDRAP	\N	\N	MECSS	MI Solidarité à la source - Table ronde associations	\N	2023-05-16 16:30:00	2023-05-16 17:30:00	\N	\N	3	0	\N	\N
730698	MECSS	AUDRAP	\N	\N	MECSS	MI Solidarité à la source - Audition de S. Seiller	\N	2023-05-16 17:30:00	2023-05-16 19:00:00	\N	\N	2	0	\N	\N
730699	DELEGATION	AUDRAP	\N	\N	206	Auditions innovation thérapeutique en cancérologie 	\N	2023-05-10 17:10:00	2023-05-10 19:45:00	\N	\N	2	0	\N	\N
730702	DELEGATION	AUDRAP	\N	\N	206	Auditions innovation thérapeutique en cancérologie 	\N	2023-05-12 09:00:00	2023-05-12 12:00:00	\N	\N	2	0	\N	\N
730705	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Verdissement concours financiers - Audition associations bloc communal	Contrôle 2023 - Verdissement concours financiers - Audition associations bloc communal	2023-05-04 10:30:00	2023-05-04 12:00:00	\N	\N	1	0	\N	\N
730725	GIA	AUCUNE	\N	\N	\N	audience de M. Saqr Ghobash, Président du Conseil national fédéral des Emirats arabes unis	\N	2023-05-10 11:00:00	2023-05-10 12:00:00	\N	\N	5	0	661	\N
730731	DELEGATION	AUDRAP	\N	\N	211	Audition rapporteures "Santé des femmes au travail"	\N	2023-05-16 14:15:00	2023-05-16 15:30:00	\N	\N	2	0	\N	\N
730732	DELEGATION	AUDRAP	\N	\N	211	Audition Observatoire VSS Enseignement supérieur	Audition Observatoire VSS Enseignement supérieur	2023-05-16 16:30:00	2023-05-16 18:00:00	\N	\N	4	0	\N	\N
730733	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Mme Marie-Noëlle Lienemann et M. Jean-Baptiste Lemoyne	Auditions Mme Marie-Noëlle Lienemann et M. Jean-Baptiste Lemoyne	2023-05-04 09:00:00	2023-05-04 11:00:00	\N	\N	2	0	\N	\N
730736	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions DGSE	Auditions DGSE	2023-05-11 09:00:00	2023-05-11 10:00:00	\N	\N	2	0	\N	\N
730739	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Secrétariat général de la défense et de la sécurité nationale	Secrétariat général de la défense et de la sécurité nationale	2023-05-11 10:00:00	2023-05-11 11:00:00	\N	\N	3	0	\N	\N
730748	MISSION	DEPLACEMENT	\N	BATI	\N	déplacement Bretagne	\N	2023-05-10 20:00:00	2023-05-11 17:00:00	\N	\N	4	0	\N	\N
722689	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2023-04-12 10:15:00	2023-04-12 11:20:00	2023-04-12 17:47:00	2023-04-28 11:37:04	38	0	\N	\N
730757	COM_PERMANENTE	AUTRE	\N	CAE	\N	PPL Ferme France / Amendements de séance	\N	2023-05-16 14:05:00	2023-05-16 14:15:00	2023-05-17 10:25:43	2023-05-17 14:38:18	27	2	\N	\N
730759	COM_PERMANENTE	AUDRAP	\N	CDD	\N	MI Consigne	MI Consigne	2023-05-09 15:00:00	2023-05-09 18:15:00	\N	\N	1	0	\N	\N
730760	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Modernisation DSNA - Audition national syndicat contrôleurs aériens	Contrôle 2023 - Modernisation DSNA - Audition national syndicat contrôleurs aériens	2023-05-11 11:30:00	2023-05-11 13:20:00	\N	\N	1	0	\N	\N
730762	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Modernisation DSNA - Audition Air France	Contrôle 2023 - Modernisation DSNA - Audition Air France	2023-05-11 14:00:00	2023-05-11 14:30:00	\N	\N	1	0	\N	\N
730764	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Boucliers tarifaires et amortisseurs - Audition ARC-UNARC	Contrôle 2023 - Boucliers tarifaires et amortisseurs - Audition ARC-UNARC	2023-05-12 14:00:00	2023-05-12 14:30:00	\N	\N	1	0	\N	\N
730766	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Verdissement concours financiers - Audition Départements de France	Contrôle 2023 - Verdissement concours financiers - Audition Départements de France	2023-05-12 17:30:00	2023-05-12 18:30:00	\N	\N	1	0	\N	\N
730777	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Douanes - Audition Direction nationale du renseignement et des enquêtes douanières	PJL Douanes - Audition Direction nationale du renseignement et des enquêtes douanières	2023-05-09 14:00:00	2023-05-09 15:00:00	\N	\N	1	0	\N	\N
730779	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Construction places de détention  - AuditionDirection immobilier de l'Etat	Contrôle 2023 - Construction places de détention  - AuditionDirection immobilier de l'Etat	2023-05-09 18:30:00	2023-05-09 19:20:00	\N	\N	1	0	\N	\N
730781	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Construction places de détention  - Audition DGDDI	Contrôle 2023 - Construction places de détention  - Audition DGDDI	2023-05-10 08:30:00	2023-05-10 09:50:00	\N	\N	1	0	\N	\N
730783	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Construction places de détention  - Table-ronde fédérations associatives	Contrôle 2023 - Construction places de détention  - Table-ronde fédérations associatives	2023-05-11 14:00:00	2023-05-11 15:20:00	\N	\N	1	0	\N	\N
730785	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Construction places de détention  - Table-ronde Syndicats	Contrôle 2023 - Construction places de détention  - Table-ronde Syndicats	2023-05-11 15:45:00	2023-05-11 17:30:00	\N	\N	1	0	\N	\N
730787	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 33 MI Fonds Marianne	PLENIERE - 33 MI Fonds Marianne	2023-05-16 14:30:00	2023-05-16 18:30:00	2023-05-24 10:01:16	2023-05-24 17:29:04	21	0	\N	\N
730791	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Entrepreneurs	PPL Entrepreneurs	2023-05-10 16:30:00	2023-05-10 17:30:00	\N	\N	1	0	\N	\N
730826	DELEGATION	AUCUNE	\N	\N	COLTER	Réunion plénière	\N	2023-05-25 09:00:00	2023-05-25 10:30:00	2023-05-25 12:16:19	\N	17	0	\N	\N
639650	GIA	AUCUNE	\N	\N	\N	Audition de M. Jean-Baptiste Jeangène Vilmer, directeur de l'IRSEM	et de M. Jean-Sylvestre Mongrenier, chercheur associé à l'Institut Thomas More	2022-03-15 08:30:00	2022-03-15 10:00:00	\N	\N	7	0	608	\N
639687	MISSION	AUCUNE	\N	FONDSMER	\N	Audition Ministère de la transition écologique	Audition Ministère de la transition écologique	2022-03-22 17:00:00	2022-03-22 18:10:00	2022-03-22 18:07:12	2022-03-23 15:00:18	6	0	\N	\N
640947	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	MCC Sécurisation de la chasse	MCC Sécurisation de la chasse	2022-04-05 14:30:00	2022-04-05 15:55:00	\N	\N	6	0	\N	\N
640954	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	MCC	MCC Sécurisation de la chasse	2022-04-05 16:30:00	2022-04-05 17:30:00	\N	\N	4	0	\N	\N
640961	GIA	AUCUNE	\N	\N	\N	Audition de MM. Florent Parmentier et Julien Arnoult	Audition de MM. Florent Parmentier et Julien Arnoult, chercheurs en science politique	2022-04-07 09:00:00	2022-04-07 10:10:00	\N	\N	5	0	851	\N
642902	BUREAU	AUCUNE	\N	\N	\N	Bureau 	Bureau du Sénat	2022-05-18 08:30:00	2022-05-18 11:00:00	\N	\N	20	0	\N	\N
649186	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Auditions MI Mégafeux	\N	2022-07-12 14:00:00	2022-07-12 18:00:00	\N	\N	0	0	\N	\N
649191	ETUDES	AUTRE	\N	\N	\N	Audition SIFCO	Audition SIFCO	2022-07-13 13:30:00	2022-07-13 15:00:00	\N	\N	14	0	\N	911
649314	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Nouvelle-Calédonie	MI sur l'avenir institutionnel de la Nouvelle-Calédonie	2022-07-19 08:05:00	2022-07-19 08:35:00	\N	\N	4	0	\N	\N
670584	COM_PERMANENTE	AUDRAP	\N	CAE	\N	DGE	DGE	2022-11-07 15:45:00	2022-11-07 16:30:00	\N	\N	1	0	\N	\N
670588	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2023 - Ville - Asso Ville & Banlieue	PLF 2023 - Ville - Asso Ville & Banlieue	2022-11-03 15:00:00	2022-11-03 16:00:00	\N	\N	1	0	\N	\N
670595	COM_PERMANENTE	AUDRAP	\N	CAE	\N	USH	USH	2022-11-03 08:30:00	2022-11-03 09:00:00	\N	\N	1	0	\N	\N
670599	COM_PERMANENTE	AUDRAP	\N	CAE	\N	ANAH	ANAH	2022-11-03 09:00:00	2022-11-03 09:45:00	\N	\N	1	0	\N	\N
670601	COM_PERMANENTE	AUDRAP	\N	CAE	\N	FNAIM 	FNAIM 	2022-11-03 09:45:00	2022-11-03 10:15:00	\N	\N	1	0	\N	\N
670603	COM_PERMANENTE	AUDRAP	\N	CAE	\N	FAS	FAS	2022-11-03 10:15:00	2022-11-03 10:45:00	\N	\N	1	0	\N	\N
670608	DELEGATION	AUDRAP	\N	\N	206	Audition de Mme Roth et Mme Pourpard	\N	2022-11-04 09:00:00	2022-11-04 10:00:00	\N	\N	1	0	\N	\N
670611	DELEGATION	AUDRAP	\N	\N	206	Auditions pollution lumineuse	\N	2022-11-04 10:00:00	2022-11-04 12:00:00	\N	\N	1	0	\N	\N
670616	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2023 - Recherche - DGE	PLF 2023 - Recherche - DGE	2022-11-02 17:00:00	2022-11-02 17:45:00	\N	\N	1	0	\N	\N
670617	DELEGATION	AUDRAP	\N	\N	206	Audition de l'Association Française d'Astronomie	\N	2022-11-04 14:30:00	2022-11-04 15:30:00	\N	\N	1	0	\N	\N
670620	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Joly et Mme Chevalier	\N	2022-11-04 15:30:00	2022-11-04 17:30:00	\N	\N	1	0	\N	\N
670622	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2023 - Recherche - DGRI	PLF 2023 - Recherche - DGRI	2022-11-02 17:45:00	2022-11-02 18:30:00	\N	\N	1	0	\N	\N
670628	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2023 - Recherche - ANR	PLF 2023 - Recherche - ANR	2022-11-07 16:30:00	2022-11-07 17:15:00	\N	\N	1	0	\N	\N
670638	COM_PERMANENTE	DEPLACEMENT	\N	CAE	\N	Déplacement dans la Meuse	\N	2022-10-27 08:00:00	2022-10-27 20:00:00	\N	\N	11	0	\N	\N
670718	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur - PLF 2023 - CPAM Seine-Saint-Denis	\N	2022-11-15 11:00:00	2022-11-15 12:00:00	\N	\N	1	0	\N	\N
670720	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur PJLF 2023 - Branche Santé - DSS	\N	2022-11-15 10:00:00	2022-11-15 11:00:00	\N	\N	1	0	\N	\N
670722	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition M. Olivier Klein	\N	2022-11-08 17:35:00	2022-11-08 19:50:00	2022-11-08 19:59:12	2022-11-09 17:25:45	27	0	\N	\N
670788	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition El Hairy / Schiappa	\N	2022-11-15 16:00:00	2022-11-15 17:45:00	2022-11-15 17:48:29	2022-11-16 17:13:19	29	0	\N	\N
670817	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition Marc Fesneau	\N	2022-11-16 16:45:00	2022-11-16 18:20:00	2022-11-17 16:13:49	2022-11-18 11:44:52	22	2	\N	\N
670921	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF AEF	\N	2022-11-08 15:30:00	2022-11-08 16:30:00	\N	\N	2	0	\N	\N
672500	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2023 - P. 151	\N	2022-11-07 10:45:00	2022-11-07 11:45:00	\N	\N	2	0	\N	\N
672503	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2023 - P. 151	\N	2022-11-08 14:00:00	2022-11-08 15:00:00	\N	\N	2	0	\N	\N
672506	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF 2023 -P. 212	PLF 2023 -P. 212	2022-11-08 15:00:00	2022-11-08 16:30:00	\N	\N	2	0	\N	\N
672509	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF 2023 -P. 212	PLF pour 2023 - P. 212	2022-11-09 13:45:00	2022-11-09 14:45:00	\N	\N	2	0	\N	\N
672985	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2023 - Industrie	PLF 2023 - Industrie	2022-11-09 11:30:00	2022-11-09 12:15:00	\N	\N	1	0	\N	\N
672989	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2023 création	\N	2022-11-14 10:30:00	2022-11-14 12:00:00	\N	\N	3	0	\N	\N
672995	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	plf 2023 création	\N	2022-11-10 14:15:00	2022-11-10 16:30:00	\N	\N	1	0	\N	\N
673028	COM_PERMANENTE	GROUPE_TRAVAIL	\N	LOIS	\N	Décentralisation	Décentralisation - auditions rapporteurs	2022-11-10 14:00:00	2022-11-10 18:00:00	\N	\N	1	0	\N	\N
673030	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 -  Les secrétariats généraux communs - Corps d'inspections	Contrôle 2022 -  Les secrétariats généraux communs - Corps d'inspections	2022-11-08 14:00:00	2022-11-08 16:00:00	\N	\N	1	0	\N	\N
674681	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions M. Laurent Duplomb, Mme Françoise Férat et M. Jean-Claude Tissot	Auditions M. Laurent Duplomb, Mme Françoise Férat et M. Jean-Claude Tissot	2022-11-15 15:30:00	2022-11-15 20:00:00	\N	\N	2	0	\N	\N
674703	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2023 - Solidarité - Table ronde des acteurs de l'aide alimentaire	\N	2022-11-15 16:00:00	2022-11-15 17:15:00	\N	\N	4	0	\N	\N
674704	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2023 - Solidarité - Audition DGCS	\N	2022-11-15 18:00:00	2022-11-15 19:30:00	\N	\N	2	0	\N	\N
686430	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2023 : Examen du rapport en nouvelle lecture	PLF pour 2023 : Examen du rapport en nouvelle lecture	2022-12-15 10:10:00	2022-12-15 10:40:00	2022-12-15 10:56:05	2022-12-15 15:07:52	17	4	\N	\N
686496	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Examen de rapport d'information sur le commerce extérieur	\N	2022-12-08 09:50:00	2022-12-08 11:40:00	2022-12-08 16:03:21	\N	16	0	\N	\N
686566	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Santé hôpital - Audition du CCNE sur l'avis 140 	\N	2022-12-08 09:15:00	2022-12-08 10:15:00	\N	\N	2	0	\N	\N
686749	ETUDES	AUCUNE	\N	\N	\N	\N	Audition d'Olivier Poivre d'Arvor, ambassadeur pour les pôles et les enjeux maritimes	2022-12-08 11:30:00	2022-12-08 12:45:00	\N	\N	5	0	\N	938
686757	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition MCC ZAN	Audition MCC ZAN	2022-12-06 13:15:00	2022-12-06 14:15:00	\N	\N	2	0	\N	\N
687209	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - MI organisation de la police judiciaire	Audition rapporteur - MI organisation de la police judiciaire	2022-12-13 14:00:00	2022-12-13 15:00:00	\N	\N	2	0	\N	\N
687212	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - MI organisation de la police judiciaire	Auditions rapporteur - MI organisation de la police judiciaire	2022-12-13 15:00:00	2022-12-13 16:30:00	\N	\N	4	0	\N	\N
687217	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - MI organisation de la police judiciaire	Audition rapporteur - MI organisation de la police judiciaire	2022-12-13 16:30:00	2022-12-13 17:30:00	\N	\N	2	0	\N	\N
687428	GIA	AUCUNE	\N	\N	\N	Dîner en l'honneur d'une délégation ministérielle grecque	Dîner en marge du Forum économique franco-grec en présence de 6 ministres grecs	2022-12-13 18:45:00	2022-12-13 20:30:00	\N	\N	7	0	591	\N
688356	BUREAU	AUCUNE	\N	\N	\N	Réunion du Bureau	Réunion du Bureau	2022-12-15 08:30:00	2022-12-15 10:55:00	\N	\N	22	0	\N	\N
688709	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Rapporteure	\N	2022-12-13 16:00:00	2022-12-13 18:00:00	\N	\N	0	0	\N	\N
688745	DELEGATION	AUCUNE	\N	\N	DSOM	Petit-déjeuner de travail	\N	2023-01-12 08:00:00	2023-01-12 09:40:00	\N	\N	13	0	\N	\N
688756	ETUDES	AUTRE	\N	\N	\N	Audition de la Commission nationale du débat public	Audition de la Commission nationale du débat public	2022-12-14 08:15:00	2022-12-14 09:15:00	\N	\N	6	0	\N	906
672496	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-11-16 16:30:00	2022-11-16 18:00:00	2022-11-16 18:03:00	2022-11-18 11:44:51	30	0	\N	\N
680273	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF  Mission Sécurités	PLF  Mission Sécurités	2022-11-25 14:35:00	2022-11-25 15:35:00	\N	\N	31	0	\N	\N
686700	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2022-12-13 09:30:00	2022-12-13 12:30:00	\N	\N	45	0	\N	\N
686701	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL DADDUE	\N	2022-12-13 14:30:00	2022-12-13 17:30:00	\N	\N	109	0	\N	\N
686702	SEANCE_PLENIERE	DECL_GVT	\N	\N	\N	Déclaration du Gouvernement immigration	Déclaration du Gouvernement immigration	2022-12-13 17:30:00	2022-12-13 20:05:00	\N	\N	145	0	\N	\N
686703	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL DADDUE	PJL DADDUE	2022-12-13 21:35:00	2022-12-13 22:15:00	\N	\N	25	0	\N	\N
686704	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2022-12-14 15:00:00	2022-12-14 16:20:00	\N	\N	267	0	\N	\N
686705	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Conclusions de la CMP LOPMI	Conclusions de la CMP LOPMI	2022-12-14 16:35:00	2022-12-14 17:25:00	\N	\N	41	0	\N	\N
686706	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	NL PLF 2023	NL PLF 2023	2022-12-15 11:00:00	2022-12-15 12:40:00	\N	\N	46	0	\N	\N
698369	GIA	AUCUNE	\N	\N	\N	Voeux année du Lapin	Cérémonie de voeux au Bureau de Représentation de Taipei en France	2023-02-01 18:30:00	2023-02-01 20:30:00	\N	\N	10	0	623	\N
735641	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	France Médias Monde	\N	2023-05-30 17:00:00	2023-05-30 18:00:00	\N	\N	2	0	\N	\N
735642	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Institut national de l'audiovisuel 	\N	2023-05-30 18:30:00	2023-05-30 19:30:00	\N	\N	3	0	\N	\N
735643	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2023 - Immobilier MEAE - Déplacement à Nantes	\N	2023-06-16 08:00:00	2023-06-16 22:00:00	\N	\N	0	0	\N	\N
735644	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2023 - Construction places détention  - Déplacement Centre pénit. Gradignan	\N	2023-06-22 08:00:00	2023-06-22 22:00:00	\N	\N	0	0	\N	\N
735645	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2023 - EPF/EPA - Déplacement EPF Franche-Comté Besançon	\N	2023-06-26 08:00:00	2023-06-26 22:00:00	\N	\N	0	0	\N	\N
735646	ETUDES	AUTRE	\N	\N	\N	Audition Association chimie du végétal	Audition Association chimie du végétal	2023-05-30 09:30:00	2023-05-30 10:30:00	\N	\N	7	0	\N	919
670816	COM_PERMANENTE	AUTRE	\N	AFCL	\N	PLF 2023	\N	2022-11-16 09:00:00	2022-11-16 12:00:00	2022-11-17 16:12:56	2022-11-18 11:44:47	41	6	\N	\N
735913	COM_PERMANENTE	AUTRE	\N	FINC	\N	CE Fonds Marianne - Audition Fraternité générale, Civic Fab et Conspiracy Watch	CE Fonds Marianne - Audition Fraternité générale, Civic Fab et Conspiracy Watch	2023-05-30 16:00:00	2023-05-30 17:30:00	2023-05-31 10:44:48	2023-06-02 16:09:48	21	0	\N	\N
737844	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2023-05-31 17:00:00	2023-05-31 18:30:00	\N	\N	1	0	\N	\N
738003	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2023-06-06 09:30:00	2023-06-06 12:20:00	\N	\N	42	0	\N	\N
738004	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL et PJLO Justice	PJL et PJLO Justice	2023-06-06 14:30:00	2023-06-06 19:55:00	\N	\N	145	0	\N	\N
738006	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat 50-1 Afrique	Débat 50-1 Afrique	2023-06-06 21:30:00	2023-06-07 00:00:00	\N	\N	49	0	\N	\N
738007	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2023-06-07 15:00:00	2023-06-07 16:15:00	\N	\N	291	0	\N	\N
738008	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Indices locatifs	PPL Indices locatifs	2023-06-07 16:30:00	2023-06-07 18:25:00	\N	\N	56	0	\N	\N
738009	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL et PJLO Justice	PJL et PJLO Justice	2023-06-07 18:30:00	2023-06-07 20:00:00	\N	\N	52	0	\N	\N
738010	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL et PJLO Justice	PJL et PJLO Justice	2023-06-07 21:30:00	2023-06-08 00:55:00	\N	\N	45	0	\N	\N
738012	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL et PJLO Justice	PJL et PJLO Justice	2023-06-08 10:30:00	2023-06-08 13:05:00	\N	\N	47	0	\N	\N
738013	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL et PJLO Justice	PJL et PJLO Justice	2023-06-08 14:35:00	2023-06-08 17:35:00	\N	\N	30	0	\N	\N
740457	GIA	AUCUNE	\N	\N	\N	Audition de Mme Florennes et  M. Ludovic Menès députés sur les actes antireligieux en Fr	Audition de Mme Florennes et M. Ludovic Menès députés sur les actes antireligieux en France	2023-06-07 13:30:00	2023-06-07 15:00:00	\N	\N	8	0	629	\N
740811	GIA	AUCUNE	\N	\N	\N	accueil parlementaires tibétains	accueil parlementaires tibétains	2023-07-04 12:30:00	2023-07-04 14:00:00	\N	\N	3	0	634	\N
740812	GIA	AUCUNE	\N	\N	\N	célébration anniversaire Dalaï Lama	célébration anniversaire Dalaï Lama	2023-07-06 15:00:00	2023-07-06 18:00:00	\N	\N	4	0	634	\N
740813	GIA	AUCUNE	\N	\N	\N	Accueil de son Eminence Ling Rinpoche	Accueil de son Eminence Ling Rinpoche	2023-05-30 17:00:00	2023-05-30 18:30:00	\N	\N	3	0	634	\N
740825	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audition dans le cadre du programme 129	Auditions P. 129	2023-06-06 14:30:00	2023-06-06 16:00:00	\N	\N	1	0	\N	\N
741072	COM_SPECIALE	PLENIERE	\N	ESNU	\N	Audition des régulateurs	\N	2023-06-13 09:00:00	2023-06-13 11:00:00	2023-06-13 11:18:09	2023-06-14 15:28:07	19	0	\N	\N
741131	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Plein emploi - Audition U2P	\N	2023-06-13 09:25:00	2023-06-13 09:55:00	\N	\N	4	0	\N	\N
741132	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Plein emploi - Audition de M. Thierry Guilluy	\N	2023-06-13 09:55:00	2023-06-13 11:00:00	\N	\N	4	0	\N	\N
741137	MECSS	AUDRAP	\N	\N	MECSS	MI Organismes financés par les Robss - Audition SPF	\N	2023-06-13 10:00:00	2023-06-13 11:00:00	\N	\N	3	0	\N	\N
741499	DELEGATION	AUCUNE	\N	\N	211	Echange de vues sur la remise du prix DDF 2023	\N	2023-06-22 09:10:00	2023-06-22 09:50:00	\N	\N	4	0	\N	\N
741500	DELEGATION	AUCUNE	\N	\N	211	Examen du rapport d'information 	\N	2023-06-27 16:35:00	2023-06-27 17:40:00	\N	\N	12	0	\N	\N
741501	DELEGATION	AUCUNE	\N	\N	211	Examen du rapport triennal de la DDF	\N	2023-07-06 08:30:00	2023-07-06 09:10:00	\N	\N	5	0	\N	\N
741502	DELEGATION	AUCUNE	\N	\N	211	Examen du rapport d'information 	\N	2023-07-11 16:00:00	2023-07-11 16:50:00	\N	\N	12	0	\N	\N
741514	MISSION	DEPLACEMENT	\N	GEAU	\N	Déplacement dans les Deux-Sèvres	\N	2023-06-08 09:30:00	2023-06-09 18:30:00	\N	\N	0	0	\N	\N
741518	MISSION	DEPLACEMENT	\N	GEAU	\N	Déplacement dans les Deux-Sèvres	\N	2023-06-08 06:49:00	2023-06-08 18:30:00	\N	\N	0	0	\N	\N
741898	MISSION	DEPLACEMENT	\N	GEAU	\N	Déplacement en Gironde	\N	2023-06-09 08:00:00	2023-06-09 16:30:00	\N	\N	0	0	\N	\N
741945	MISSION	DEPLACEMENT	\N	GEAU	\N	Déplaecment dans le Cher	\N	2023-05-22 10:15:00	2023-05-22 17:30:00	\N	\N	0	0	\N	\N
744396	COM_PERMANENTE	AUTRE	\N	AFCL	\N	CMP majorité numérique	\N	2023-06-20 14:30:00	2023-06-20 15:30:00	\N	\N	13	0	\N	\N
744781	GIA	AUCUNE	\N	\N	\N	accueil d'une délégation de députés coréens pour la candidature de Busan à l'expo  2030	\N	2023-06-21 08:30:00	2023-06-21 09:45:00	\N	\N	4	0	613	\N
746081	COM_SPECIALE	AUTRE	\N	ESNU	\N	Examen rapport	\N	2023-06-27 13:30:00	2023-06-27 16:10:00	\N	\N	26	1	\N	\N
746082	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Fondes de garantie BpiFrance - Audition BpiFrance	Contrôle 2023 - Fondes de garantie BpiFrance - Audition BpiFrance	2023-06-21 17:30:00	2023-06-21 19:00:00	\N	\N	2	0	\N	\N
746085	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2023 - Immigration, asile et intégration - Déplacement Association Coallia	Contrôle 2023 - Immigration, asile et intégration - Déplacement Paris et 93 - Association Coallia	2023-06-22 09:15:00	2023-06-22 13:00:00	\N	\N	1	0	\N	\N
746087	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Immigration, asile et intégration - Audition association Coallia	Contrôle 2023 - Immigration, asile et intégration - Audition association Coallia	2023-06-22 09:15:00	2023-06-22 13:00:00	\N	\N	1	0	\N	\N
746089	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - DCPJ - Direction régionale de la police judiciaire à Paris	Contrôle 2023 - DCPJ - Direction régionale de la police judiciaire à Paris	2023-06-22 16:00:00	2023-06-22 18:00:00	\N	\N	1	0	\N	\N
641635	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MCI Délinquance des mineurs	MCI Délinquance des mineurs	2022-04-13 10:00:00	2022-04-13 11:00:00	\N	\N	5	0	\N	\N
642871	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Obésité - Table ronde Évolution des pratiques alimentaires	\N	2022-05-17 14:15:00	2022-05-17 15:30:00	\N	\N	4	0	\N	\N
642876	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 -  Régimes des retraites RATP et Marins - DB/DSS	Contrôle 2022 -  Régimes des retraites RATP et Marins - DB/DSS	2022-05-17 14:30:00	2022-05-17 16:20:00	\N	\N	1	0	\N	\N
642877	COM_PERMANENTE	DEPLACEMENT	\N	CAE	\N	\N	\N	2022-05-18 10:00:00	2022-05-18 15:30:00	\N	\N	4	0	\N	\N
642878	COM_PERMANENTE	DEPLACEMENT	\N	CAE	\N	Déplacement dans les Vosges	\N	2022-05-19 07:00:00	2022-05-19 19:00:00	\N	\N	6	0	\N	\N
642886	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - ZAN - CPO	Contrôle 2022 - ZAN - CPO	2022-05-17 16:30:00	2022-05-17 17:30:00	\N	\N	1	0	\N	\N
642926	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI politique de la ville - Audition de M. Vassal	MI politique de la ville - Audition de M. Vassal	2022-05-17 09:00:00	2022-05-17 10:15:00	\N	\N	2	0	\N	\N
735924	COM_PERMANENTE	AUTRE	\N	AFCL	\N	PPL audiovisuel + cinéma outre-mer + honorabilité	\N	2023-06-07 08:45:00	2023-06-07 12:05:00	2023-06-07 15:40:35	2023-06-07 17:26:48	42	5	\N	\N
741108	COM_PERMANENTE	AUTRE	\N	CAE	\N	PJL Industrie verte	\N	2023-06-14 09:30:00	2023-06-14 12:10:00	2023-06-14 15:23:48	2023-06-14 15:27:58	48	3	\N	\N
642929	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI politique de la ville - Audition de Mme Lelévrier	MI politique de la ville - Audition de Mme Lelévrier	2022-05-17 10:15:00	2022-05-17 11:15:00	\N	\N	2	0	\N	\N
642932	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI politique de la ville - ANCT	MI politique de la ville - ANCT	2022-05-17 11:15:00	2022-05-17 12:15:00	\N	\N	2	0	\N	\N
642935	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-05-24 15:30:00	2022-05-24 18:45:00	2022-05-24 18:43:19	2022-05-27 16:46:08	24	0	\N	\N
643013	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne	2022-05-10 16:00:00	2022-05-10 18:40:00	\N	\N	8	0	\N	\N
643022	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne	2022-05-11 14:30:00	2022-05-11 15:45:00	\N	\N	5	0	\N	\N
643245	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions MI Énergie et hydrogène nucléaires	Auditions MI Énergie et hydrogène nucléaires	2022-05-24 09:45:00	2022-05-24 11:10:00	\N	\N	4	0	\N	\N
643250	DELEGATION	AUCUNE	\N	\N	206	Audition publique sur les effets secondaires des vaccins contre la Covid-19	\N	2022-05-24 14:10:00	2022-05-24 18:20:00	\N	\N	8	0	\N	\N
643288	DELEGATION	AUCUNE	\N	\N	PROS	Audition du WWF France sur le "jour du dépassement"	\N	2022-05-25 11:00:00	2022-05-25 12:00:00	\N	\N	9	0	\N	\N
643313	MECSS	AUDRAP	\N	\N	MECSS	MI Fraude sociale au sein des caisses - Audition CNAF	\N	2022-06-14 11:00:00	2022-06-14 12:00:00	\N	\N	3	0	\N	\N
643320	DELEGATION	AUDRAP	\N	\N	PROS	Audition de M. Barone	\N	2022-05-24 15:30:00	2022-05-24 16:30:00	\N	\N	3	0	\N	\N
643324	DELEGATION	AUDRAP	\N	\N	PROS	Audition de la Compagnie nationale du Rhône	\N	2022-05-24 16:30:00	2022-05-24 17:45:00	\N	\N	3	0	\N	\N
643328	DELEGATION	AUDRAP	\N	\N	PROS	Audition Fédération nationale de la pêche en France	\N	2022-05-24 17:45:00	2022-05-24 18:45:00	\N	\N	3	0	\N	\N
650963	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Conférence de presse : avenir du corps diplomatique	Conférence de presse : avenir du corps diplomatique	2022-07-19 11:30:00	2022-07-19 12:30:00	\N	\N	3	0	\N	\N
656833	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Balard - Réunion sur Avis budgétaires P212 et P178	\N	2022-09-27 08:30:00	2022-09-27 09:30:00	\N	\N	3	0	\N	\N
659587	DELEGATION	AUDRAP	\N	\N	206	Présentation du rapport d'information "Surpoids et obésité, l'autre pandémie"	\N	2022-10-06 14:00:00	2022-10-06 15:00:00	\N	\N	1	0	\N	\N
659589	DELEGATION	AUDRAP	\N	\N	206	Présentation du rapport d'enquête sur l'alimentation industrielle	\N	2022-10-06 15:00:00	2022-10-06 16:00:00	\N	\N	1	0	\N	\N
659591	DELEGATION	AUDRAP	\N	\N	206	Audition de Mme Godart	\N	2022-10-06 16:00:00	2022-10-06 17:00:00	\N	\N	1	0	\N	\N
659593	DELEGATION	AUDRAP	\N	\N	206	Audition de Mme Margaritis	\N	2022-10-06 17:00:00	2022-10-06 17:50:00	\N	\N	1	0	\N	\N
659595	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Mission Flash 2022 - Dons associations - Coalition libertés associatives	Mission Flash 2022 - Dons associations - Coalition libertés associatives	2022-10-04 10:00:00	2022-10-04 10:30:00	\N	\N	2	0	\N	\N
659598	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Mission Flash 2022 - Dons associations - Opossants chasse/HCVA	Mission Flash 2022 - Dons associations - Opossants chasse/HCVA	2022-10-04 14:30:00	2022-10-04 15:45:00	\N	\N	2	0	\N	\N
659599	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Dufier	\N	2022-10-04 17:00:00	2022-10-04 18:00:00	\N	\N	1	0	\N	\N
659604	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Mission Flash 2022 - Dons associations - FNSEA/DLF	Mission Flash 2022 - Dons associations - FNSEA/DLF	2022-10-05 16:30:00	2022-10-05 18:30:00	\N	\N	2	0	\N	\N
659607	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Écologie - EDF/CRE	PLF pour 2023 - Écologie - EDF/CRE	2022-10-04 16:00:00	2022-10-04 18:00:00	\N	\N	2	0	\N	\N
659610	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 2022 - Adaptation réacteurs nucléaires - Cour des comptes	58-2 2022 - Adaptation réacteurs nucléaires - Cour des comptes	2022-10-07 17:00:00	2022-10-07 18:05:00	\N	\N	1	0	\N	\N
659612	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2020 - La DCPJ - DGPN	Contrôle 2020 - La DCPJ - DGPN	2022-10-07 14:30:00	2022-10-07 16:30:00	\N	\N	1	0	\N	\N
659614	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Conseil national de l'ordre des architectes	\N	2022-10-10 13:30:00	2022-10-10 14:30:00	\N	\N	2	0	\N	\N
659621	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Auditions JVA PLF 2023	\N	2022-10-10 15:00:00	2022-10-10 17:00:00	\N	\N	2	0	\N	\N
661816	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLF 2023 - Fonction publique	PJLF 2023 - avis budgétaire "Fonction publique"	2022-10-13 08:30:00	2022-10-13 10:20:00	\N	\N	1	0	\N	\N
665743	GIA	AUCUNE	\N	\N	\N	entretien avec S.E. Fahad Al Ruwaily, ambassadeur d'Arabie saoudite	\N	2022-10-25 12:30:00	2022-10-25 14:30:00	\N	\N	6	0	661	\N
671832	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PLF 2023 - PFE	\N	2022-10-26 11:00:00	2022-10-26 11:45:00	\N	\N	0	0	\N	\N
672323	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Avis Calvet - Transition énergétique - ANAH	\N	2022-11-09 11:00:00	2022-11-09 11:45:00	\N	\N	1	0	\N	\N
672326	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Avis Transition - M. Calvet	\N	2022-11-09 13:00:00	2022-11-09 14:45:00	\N	\N	1	0	\N	\N
674340	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL  Agression élus	PPL  Agression élus	2022-11-15 21:35:00	2022-11-15 23:25:00	\N	\N	61	0	\N	\N
674485	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	Audition de Laurence HAGUENAUER, Directrice des Français à l'étranger	Réunion du Bureau du groupe d'études "Statut, rôle et place des Français établis hors de France"	2022-11-15 17:30:00	2022-11-15 18:50:00	\N	\N	8	0	\N	\N
674844	COM_PERMANENTE	AUTRE	\N	CAE	\N	Table ronde Ambitions européennes et chocs économiques actuels	\N	2022-11-16 13:30:00	2022-11-16 15:00:00	2022-11-16 16:09:02	2022-11-16 17:13:39	29	0	\N	\N
674941	DELEGATION	AUCUNE	\N	\N	DSOM	Évolution institutionnelle outre-mer : auditions Wallis-et-Futuna et ACCIOM (début)	\N	2022-12-01 08:00:00	2022-12-01 10:35:00	\N	\N	7	0	\N	\N
674944	DELEGATION	AUTRE	\N	\N	DSOM	Évolution institutionnelle outre-mer : M. Ary Chalus (conseil régional de la Guadeloupe)	\N	2022-12-01 14:30:00	2022-12-01 15:30:00	\N	\N	6	0	\N	\N
674946	DELEGATION	AUTRE	\N	\N	DSOM	Adoption du rapport sur la gestion des déchets outre-mer	\N	2022-12-08 09:30:00	2022-12-08 10:30:00	\N	\N	10	0	\N	\N
675945	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions M. Laurent Duplomb, Mme Françoise Férat et M. Jean-Claude Tissot	Auditions M. Laurent Duplomb, Mme Françoise Férat et M. Jean-Claude Tissot	2022-11-16 14:00:00	2022-11-16 15:00:00	\N	\N	1	0	\N	\N
676062	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 17 novembre 2022	\N	2022-11-17 08:30:00	2022-11-17 11:05:00	2022-11-17 11:06:25	2022-11-18 11:44:56	11	0	\N	\N
672322	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PLF pour 2023 - Avis	PLF pour 2023 - Avis	2022-11-16 10:00:00	2022-11-16 12:35:00	2022-11-16 14:07:00	2022-11-16 17:13:37	37	2	\N	\N
674845	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Examen avis budgétaires	\N	2022-11-23 09:00:00	2022-11-23 11:15:00	2022-11-23 16:33:11	2022-11-23 16:36:34	44	4	\N	\N
676070	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2023 - Solidarité - Audition IF-PJM	\N	2022-11-16 14:00:00	2022-11-16 15:00:00	\N	\N	2	0	\N	\N
722661	MISSION	AUCUNE	\N	GEAU	\N	Réunion 20230412	\N	2023-04-12 14:05:00	2023-04-12 15:00:00	2023-04-12 15:28:41	2023-04-12 17:26:15	7	0	\N	\N
730850	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2023-05-16 09:00:00	2023-05-16 10:00:00	\N	\N	7	0	\N	\N
730862	DELEGATION	AUDRAP	\N	\N	206	Audition de Mme Robert	\N	2023-05-15 17:15:00	2023-05-15 18:05:00	\N	\N	2	0	\N	\N
730865	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Amdts ext biens spoliés + majorité numérique	\N	2023-05-23 14:00:00	2023-05-23 14:28:00	2023-05-23 15:52:07	2023-05-24 09:41:57	32	7	\N	\N
730866	COM_PERMANENTE	AUTRE	\N	AFCL	\N	MI cinéma	\N	2023-05-24 09:30:00	2023-05-24 11:30:00	2023-05-24 11:02:00	2023-05-24 11:12:30	32	7	\N	\N
730874	COM_PERMANENTE	AUTRE	\N	AFCL	\N	LEC bourses d'études	\N	2023-05-25 08:15:00	2023-05-25 09:15:00	2023-05-25 10:14:05	2023-05-30 13:06:16	15	5	\N	\N
730875	DELEGATION	AUTRE	\N	\N	DSOM	Foncier agricole outre-mer : aspects notariaux et juridiques	\N	2023-05-23 16:00:00	2023-05-23 18:00:00	\N	\N	8	0	\N	\N
730887	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2023-05-24 09:30:00	2023-05-24 11:25:00	2023-05-24 14:39:24	2023-05-24 17:25:26	38	0	\N	\N
730935	COM_ENQUETE	PLENIERE	\N	RENOV	\N	Auditions plénières	\N	2023-05-16 14:30:00	2023-05-16 16:40:00	2023-05-24 09:38:12	2023-05-24 09:43:32	6	0	\N	\N
730981	GIA	AUCUNE	\N	\N	\N	Petit-déjeuner Eva Nguyen Binh	\N	2023-05-11 08:15:00	2023-05-11 09:30:00	\N	\N	6	0	626	\N
730995	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ambassadeur DINH Toan Thang	\N	2023-04-04 10:00:00	2023-04-04 11:00:00	\N	\N	1	0	626	\N
730997	GIA	AUCUNE	\N	\N	\N	AG du groupe	\N	2023-03-07 13:00:00	2023-03-07 14:00:00	\N	\N	4	0	626	\N
731251	MISSION	AUDRAP	\N	GEAU	\N	Audition de l'European Irrigation Association	\N	2023-05-16 16:30:00	2023-05-16 17:30:00	\N	\N	3	0	\N	\N
731256	MISSION	AUDRAP	\N	GEAU	\N	Audition QUAIROS ENERGIES	\N	2023-05-16 17:30:00	2023-05-16 18:30:00	\N	\N	3	0	\N	\N
731262	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI expertise	\N	2023-05-16 09:30:00	2023-05-16 10:30:00	\N	\N	3	0	\N	\N
731266	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL bourses	\N	2023-05-16 14:00:00	2023-05-16 15:00:00	\N	\N	2	0	\N	\N
731268	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI autonomie	\N	2023-05-16 14:00:00	2023-05-16 17:00:00	\N	\N	3	0	\N	\N
731903	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Revaloriser le métier de secrétaire de mairie	Audition rappoteur - PPL Revaloriser le métier de secrétaire de maire	2023-05-16 17:15:00	2023-05-16 17:35:00	\N	\N	2	0	\N	\N
731945	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Revaloriser le métier de secrétaire de mairie	Audition rapporteur - PPL Revalorise le métier de secrétaire de mairie	2023-05-16 17:45:00	2023-05-16 19:45:00	\N	\N	3	0	\N	\N
732054	GIA	AUCUNE	\N	\N	\N	Rencontre avec le maire de Dunkerque et l'adjoint au maire de Toulouse	Rencontre avec M. Vergriete,  maire de Dunkerque et M. Dardelet, adjoint au maire de Toulouse	2023-05-17 12:30:00	2023-05-17 14:00:00	\N	\N	14	0	530	\N
732760	GIA	AUCUNE	\N	\N	\N	Accueil de la délégation de députés moldaves	Entretien avec la présidente du groupe d'étude Forêt et filières bois	2023-05-17 08:00:00	2023-05-17 09:30:00	\N	\N	2	0	851	\N
732765	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Majorité numérique	PPL Majorité numérique	2023-05-23 18:20:00	2023-05-23 20:35:00	\N	\N	65	0	\N	\N
732766	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Majorité numérique	¨PPL Majorité numérique	2023-05-23 21:30:00	2023-05-24 00:00:00	\N	\N	0	0	\N	\N
732767	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2023-05-24 15:00:00	2023-05-24 16:25:00	\N	\N	288	0	\N	\N
732768	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	4 conventions internationales	4 conventions internationales	2023-05-24 16:30:00	2023-05-24 16:35:00	\N	\N	27	0	\N	\N
732770	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Douanes	PJL Douanes	2023-05-24 16:35:00	2023-05-24 20:00:00	\N	\N	76	0	\N	\N
732771	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Douanes	PJL Douanes	2023-05-24 21:30:00	2023-05-24 22:30:00	\N	\N	22	0	\N	\N
732778	GIA	AUCUNE	\N	\N	\N	Audition du délégué général de RPDC	Audition du délégué général de RPDC	2023-03-29 08:30:00	2023-03-29 10:00:00	\N	\N	2	0	586	\N
732805	CONF_PRES	AUCUNE	\N	\N	\N	Réunion de la Conférence des Présidents	Réunion de la Conférence des Présidents	2023-05-09 18:00:00	2023-05-09 18:40:00	\N	\N	25	0	\N	\N
732894	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Construction places de détention  - Audition syndicat de la magistrature	Contrôle 2023 - Construction places de détention  - Audition syndicat de la magistrature	2023-05-23 15:30:00	2023-05-23 16:30:00	\N	\N	1	0	\N	\N
732896	ETUDES	AUDRAP	\N	\N	\N	GEAC - Audition M. Gilles LEBLANC, ACNUSA	GEAC - Audition M. Gilles LEBLANC, ACNUSA	2023-05-17 08:15:00	2023-05-17 09:20:00	\N	\N	10	0	\N	933
732907	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - CESE - Audition Comité de gouvernance citoyenne sur la fin de vie	Contrôle 2023 - CESE - Audition Comité de gouvernance citoyenne sur la fin de vie	2023-05-17 14:00:00	2023-05-17 15:00:00	\N	\N	1	0	\N	\N
732909	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - EPF/EPA - Audition Grand Paris Aménagement	Contrôle 2023 - EPF/EPA - Audition Grand Paris Aménagement	2023-05-16 14:45:00	2023-05-16 16:30:00	\N	\N	1	0	\N	\N
732911	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2023 - EPF/EPA - Déplacement Grand Paris Aménagement	Contrôle 2023 - EPF/EPA - Déplacement Grand Paris Aménagement	2023-05-16 14:00:00	2023-05-16 16:30:00	\N	\N	1	0	\N	\N
732913	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 203 - Formation continue enseignants - Audition DGESCO	Contrôle 203 - Formation continue enseignants - Audition DGESCO	2023-05-16 09:30:00	2023-05-16 10:30:00	\N	\N	1	0	\N	\N
732916	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 36 - Communication M. RAPIN - Demande saisine pour avis	PLENIERE - 36 - Communication M. RAPIN - Demande saisine pour avis	2023-05-24 09:45:00	2023-05-24 10:41:00	2023-05-24 15:09:34	2023-05-24 17:25:24	42	1	\N	\N
676086	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2022-11-23 09:30:00	2022-11-23 12:45:00	2022-11-23 11:49:02	2022-11-23 15:15:09	44	3	\N	\N
732915	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 35 - PJL Douane	PLENIERE - 35 - PJL Douane	2023-05-24 09:30:00	2023-05-24 09:45:00	2023-05-24 15:09:00	2023-05-24 17:25:28	41	1	\N	\N
732923	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Autorité de régulation de la communication audiovisuelle et numérique	\N	2023-05-23 09:30:00	2023-05-23 11:00:00	\N	\N	4	0	\N	\N
732924	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	GROUPE CANAL+	\N	2023-05-23 11:00:00	2023-05-23 12:00:00	\N	\N	4	0	\N	\N
732925	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Radio France	\N	2023-05-23 16:30:00	2023-05-23 17:30:00	\N	\N	3	0	\N	\N
732926	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	TF1	\N	2023-05-23 18:30:00	2023-05-23 19:45:00	\N	\N	1	0	\N	\N
732927	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	CMA CGM Média	\N	2023-05-23 17:30:00	2023-05-23 18:30:00	\N	\N	2	0	\N	\N
732937	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Stage au tribunal judiciaire de Thionville	\N	2023-05-11 08:00:00	2023-05-11 22:00:00	\N	\N	1	0	\N	\N
732939	COM_PERMANENTE	AUTRE	\N	FINC	\N	Plénière 34	Plénière 34	2023-05-17 09:30:00	2023-05-17 10:50:00	2023-05-23 14:19:55	2023-05-24 09:39:33	42	6	\N	\N
733686	MISSION	AUDRAP	\N	GEAU	\N	Région Occitanie / BRL - présentation du projet Aqua Domitia 	\N	2023-05-23 16:15:00	2023-05-23 17:10:00	\N	\N	5	0	\N	\N
733694	MISSION	AUCUNE	\N	BIOCARBU	\N	PLENIERE - 18	\N	2023-05-23 16:30:00	2023-05-23 18:00:00	2023-05-23 18:32:50	2023-05-24 09:42:18	5	0	\N	\N
733695	MISSION	AUCUNE	\N	BIOCARBU	\N	PLENIERE - 19	\N	2023-05-23 18:00:00	2023-05-23 19:20:00	2023-05-23 19:20:20	2023-05-24 09:42:18	8	0	\N	\N
733710	DELEGATION	AUTRE	\N	\N	DSOM	Foncier agricole : table ronde La Réunion	\N	2023-06-01 08:30:00	2023-06-01 10:30:00	\N	\N	5	0	\N	\N
733712	DELEGATION	AUTRE	\N	\N	DSOM	Foncier agricole : table ronde Guadeloupe	\N	2023-06-01 14:00:00	2023-06-01 16:00:00	\N	\N	6	0	\N	\N
733724	DELEGATION	AUTRE	\N	\N	DSOM	Foncier agricole outre-mer : table ronde ministères et ONF	\N	2023-06-08 10:30:00	2023-06-08 12:30:00	\N	\N	7	0	\N	\N
733728	MISSION	AUDRAP	\N	GEAU	\N	Maison des eaux minérales naturelles 	\N	2023-05-23 17:10:00	2023-05-23 17:55:00	\N	\N	5	0	\N	\N
733755	DELEGATION	AUCUNE	\N	\N	206	Audition de Mme Agnès Pannier-Runacher sur la sobriété énergétique	\N	2023-05-24 13:40:00	2023-05-24 15:10:00	\N	\N	9	0	\N	\N
733756	DELEGATION	AUCUNE	\N	\N	206	Enjeux du projet de traité international sur la pollution plastique	\N	2023-05-25 09:30:00	2023-05-25 10:15:00	\N	\N	4	0	\N	\N
733757	DELEGATION	AUCUNE	\N	\N	206	Audition de l'ASN	\N	2023-05-25 10:30:00	2023-05-25 13:00:00	\N	\N	9	0	\N	\N
638300	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Tables rondes en commun avec la Délégation aux Droits des femmes	\N	2022-03-08 14:30:00	2022-03-08 17:25:00	2022-03-10 15:13:03	\N	8	0	\N	\N
638301	MISSION	AUDRAP	\N	JUDI	\N	Audition de la Chancellerie	\N	2022-03-02 08:30:00	2022-03-02 09:30:00	\N	\N	4	0	\N	\N
638306	COM_ENQUETE	AUDRAP	\N	HOPITAL	\N	Audition rapporteur	\N	2022-03-07 17:00:00	2022-03-07 18:00:00	\N	\N	6	0	\N	\N
638307	COM_ENQUETE	AUDRAP	\N	HOPITAL	\N	Audition Pr Benveniste	\N	2022-03-07 18:00:00	2022-03-07 19:00:00	\N	\N	5	0	\N	\N
638308	COM_ENQUETE	AUDRAP	\N	HOPITAL	\N	Audition UFMICT	\N	2022-03-08 11:00:00	2022-03-08 12:00:00	\N	\N	5	0	\N	\N
638309	MISSION	AUCUNE	\N	SECUECO	\N	Table ronde alimentation	\N	2022-03-02 17:00:00	2022-03-02 18:45:00	2022-03-02 23:12:52	2022-03-03 14:57:11	3	0	\N	\N
638329	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Commission enquête Ehpad - Audition ARS Ile-de-France Amélie Verdier	\N	2022-03-09 09:00:00	2022-03-09 10:30:00	\N	\N	5	0	\N	\N
638330	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Commision enquête Ehpad - Audition VERITAS	\N	2022-03-09 10:30:00	2022-03-09 12:00:00	\N	\N	4	0	\N	\N
638331	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition commission enquête Ehpad - Audition Mme Lasserre	\N	2022-03-09 14:00:00	2022-03-09 15:30:00	\N	\N	5	0	\N	\N
638332	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audtion AdF	\N	2022-03-09 15:30:00	2022-03-09 16:30:00	\N	\N	6	0	\N	\N
638333	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition de M. Libault	\N	2022-03-09 16:30:00	2022-03-09 18:00:00	\N	\N	6	0	\N	\N
638334	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Auditions communes	\N	2022-03-01 14:30:00	2022-03-01 17:30:00	\N	\N	0	0	\N	\N
638344	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Pr Claude Jeandel	\N	2022-03-10 09:00:00	2022-03-10 10:30:00	\N	\N	6	0	\N	\N
638345	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Auditions communes 5 référents	\N	2022-03-02 09:30:00	2022-03-02 12:30:00	\N	\N	0	0	\N	\N
638357	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Table ronde sur le commerce extérieur composée d'économistes	\N	2022-03-02 11:00:00	2022-03-02 12:50:00	2022-03-03 17:08:40	\N	4	0	\N	\N
638362	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Auditions Mmes Filleul et Herzog	\N	2022-02-24 10:30:00	2022-02-24 11:30:00	\N	\N	0	0	\N	\N
638366	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Audition Mmes Filleul, Herzog et M. Belin	\N	2022-03-02 10:30:00	2022-03-02 11:30:00	\N	\N	0	0	\N	\N
638372	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Nexem	Mission d'information sur le contrôle des Ehpad	2022-03-10 10:30:00	2022-03-10 11:30:00	\N	\N	4	0	\N	\N
638373	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition FNADEPA	Audition Mission information  enquête contrôle Ehpad	2022-03-10 14:00:00	2022-03-10 15:30:00	\N	\N	3	0	\N	\N
638374	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition de la FFAMCO	\N	2022-03-10 15:30:00	2022-03-10 17:00:00	\N	\N	4	0	\N	\N
638375	COM_PERMANENTE	DEPLACEMENT	\N	SOCI	\N	\N	\N	2022-03-01 10:30:00	2022-03-05 09:25:00	\N	\N	4	0	\N	\N
638376	COM_PERMANENTE	DEPLACEMENT	\N	SOCI	\N	\N	\N	2022-02-28 09:30:00	2022-03-01 10:30:00	\N	\N	4	0	\N	\N
649159	SEANCE_PLENIERE	ELOGE_FUNEBRE	\N	\N	\N	Éloge funèbre d'Olivier LEONHARDT	Éloge funèbre d'Olivier LEONHARDT	2022-07-19 14:30:00	2022-07-19 15:00:00	\N	\N	1	0	\N	\N
649160	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Convention et PJL QATAR	Convention et PJL QATAR	2022-07-19 15:15:00	2022-07-19 16:10:00	\N	\N	101	0	\N	\N
649161	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL règlement du budget et d'approbation des comptes de l'année 2021	PJL règlement du budget et d'approbation des comptes de l'année 2021	2022-07-19 16:15:00	2022-07-19 18:00:00	\N	\N	93	0	\N	\N
649162	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2022-07-20 15:00:00	2022-07-20 16:20:00	\N	\N	267	0	\N	\N
649163	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL veille et de sécurité sanitaire en matière de lutte contre la covid-19	PJL veille et de sécurité sanitaire en matière de lutte contre la covid-19	2022-07-20 16:30:00	2022-07-20 19:30:00	\N	\N	162	0	\N	\N
649164	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL veille et de sécurité sanitaire en matière de lutte contre la covid-19	PJL veille et de sécurité sanitaire en matière de lutte contre la covid-19	2022-07-20 21:30:00	2022-07-21 01:35:00	\N	\N	106	0	\N	\N
649165	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL OTAN Finlande Suede	PJL OTAN Finlande Suede	2022-07-21 11:00:00	2022-07-21 12:40:00	\N	\N	48	0	\N	\N
657798	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur PJL Marché du travail - Audition U2P	\N	2022-10-04 18:00:00	2022-10-04 19:00:00	\N	\N	0	0	\N	\N
658093	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLC Droit fondamental à l'IVG et à la contraception	PPLC Droit fondamental à l'IVG et à la contraception	2022-10-04 17:00:00	2022-10-04 17:30:00	\N	\N	1	0	\N	\N
658793	DELEGATION	AUCUNE	\N	\N	COLTER	Réunion plénière	\N	2022-10-05 16:45:00	2022-10-05 18:45:00	\N	\N	23	0	\N	\N
657790	COM_PERMANENTE	AUTRE	\N	CAE	\N	PPL Agrivoltaïsme	\N	2022-10-05 09:35:00	2022-10-05 11:20:00	2022-10-05 11:34:00	2022-10-05 17:35:15	39	2	\N	\N
665325	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2023 - P. 144	Audition Agence de l'innovation de défense	2022-10-19 13:45:00	2022-10-19 14:45:00	\N	\N	2	0	\N	\N
665328	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2023 - p. 185	Audition direction générale de la mondialisation, du développement et des partenariats	2022-10-18 17:45:00	2022-10-18 19:00:00	\N	\N	2	0	\N	\N
678407	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Valloire - Exercice Montagne	\N	2022-11-21 14:00:00	2022-11-22 21:00:00	\N	\N	4	0	\N	\N
680943	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2022-12-06 16:30:00	2022-12-06 17:35:00	2022-12-07 13:23:20	2022-12-08 12:00:20	31	2	\N	\N
681008	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL DDADUE - Audition CGefi	\N	2022-11-29 10:15:00	2022-11-29 11:00:00	\N	\N	1	0	\N	\N
681084	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition Orange	\N	2022-11-30 09:30:00	2022-11-30 11:30:00	2022-11-30 18:34:11	2022-12-01 18:08:19	43	1	\N	\N
681087	COM_PERMANENTE	AUTRE	\N	CAE	\N	Table ronde marché de l'énergie	\N	2022-12-01 09:00:00	2022-12-01 11:05:00	2022-12-01 11:21:57	2022-12-01 18:08:16	22	0	\N	\N
681105	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	DDADUE - Audition ANDRH	\N	2022-12-01 09:00:00	2022-12-01 09:45:00	\N	\N	2	0	\N	\N
681117	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Fondation du patrimoine	\N	2022-12-07 10:30:00	2022-12-07 11:55:00	2022-12-08 15:44:53	2022-12-09 15:34:07	43	3	\N	\N
681118	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Table ronde audiovisuel public	\N	2022-12-07 16:30:00	2022-12-07 18:45:00	2022-12-08 16:56:08	2022-12-09 15:34:08	16	0	\N	\N
681249	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Zissis	\N	2022-11-28 14:30:00	2022-11-28 15:30:00	\N	\N	1	0	\N	\N
681308	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2022-12-07 10:30:00	2022-12-07 12:30:00	2022-12-07 13:21:44	2022-12-08 12:00:17	30	0	\N	\N
681316	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition M. Laurent Duplomb	Audition M. Laurent Duplomb	2022-11-29 15:00:00	2022-11-29 17:15:00	\N	\N	1	0	\N	\N
682867	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GT Tourisme	GT Tourisme	2022-11-30 13:30:00	2022-11-30 14:40:00	\N	\N	4	0	\N	\N
688764	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-01-11 09:00:00	2023-01-11 10:00:00	2023-01-18 09:44:59	2023-01-18 09:45:02	36	0	\N	\N
688765	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL JOP 2024 - Audition AFLD	\N	2023-01-04 14:00:00	2023-01-04 15:00:00	\N	\N	1	0	\N	\N
688767	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL JOP 2024	\N	2023-01-04 14:00:00	2023-01-04 17:00:00	\N	\N	3	0	\N	\N
688779	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition article 13 - M.Éric LOMBARD Caisse des Dépôts et Consignations	Audition article 13 - M.Éric LOMBARD Caisse des Dépôts et Consignations	2023-01-10 09:00:00	2023-01-10 10:45:00	2023-01-10 12:09:06	2023-01-12 17:25:02	25	0	\N	\N
688788	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL JOP 2024	\N	2023-01-05 09:30:00	2023-01-05 11:30:00	\N	\N	5	0	\N	\N
688796	COM_PERMANENTE	AUTRE	\N	FINC	\N	PPL 217 : Désignation rapp. - Prog. contrôle 2023 - Audition gouverneur BdF	PPL 217 : Désignation rapp. - Prog. contrôle 2023 - Audition gouverneur BdF	2023-01-11 10:35:00	2023-01-11 12:35:00	2023-01-17 15:38:46	2023-01-17 16:37:56	40	0	\N	\N
688800	DELEGATION	AUDRAP	\N	\N	211	Réunions avec Isabelle ROME, ministre (déplacement en Vendée) 	\N	2023-02-03 10:30:00	2023-02-03 12:30:00	\N	\N	0	0	\N	\N
688802	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Déplacement à la Cour de justice de l'Union européenne (Luxembourg)	Déplacement à la Cour de justice de l'Union européenne (Luxembourg)	2023-02-06 09:30:00	2023-02-07 17:30:00	\N	\N	8	0	\N	\N
700342	GIA	AUCUNE	\N	\N	\N	petit déjeuner débat avec M. Jacques Rupnik, professeur à SciencesPo	petit déjeuner débat avec M. Jacques Rupnik, professeur à SciencesPo	2023-02-08 08:00:00	2023-02-08 09:30:00	\N	\N	7	0	674	\N
704229	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2023-02-16 08:30:00	2023-02-16 11:45:00	\N	\N	2	0	\N	\N
739447	GIA	AUCUNE	\N	\N	\N	Entretien avec l'Ambassadrice du Sri Lanka	Entretien avec l'Ambassadrice du Sri Lanka	2023-06-07 08:30:00	2023-06-07 09:30:00	\N	\N	5	0	550	\N
743935	COM_ENQUETE	AUDRAP	\N	TIKTO	\N	réunion de la commission d'enquête	réunion de la commission d'enquête	2023-06-15 11:00:00	2023-06-15 12:15:00	\N	\N	10	0	\N	\N
746134	GIA	AUCUNE	\N	\N	\N	Entretien avec M. NAKODO NOLO, Président de l'Assemblée provinciale du Sud-Unbangi (RDC)  	Entretien avec M. NAKODO NOLO, Président de l'Assemblée provinciale du Sud-Unbangi (RDC) 	2023-06-26 11:35:00	2023-06-26 12:45:00	\N	\N	1	0	572	\N
746137	GIA	AUCUNE	\N	\N	\N	Entretien avec  M. Jean-Victor NDOUMA MBADINGA,  Sénateur du Gabon	Entretien avec  M. Jean-Victor NDOUMA MBADINGA,  Sénateur du Gabon	2023-06-08 15:00:00	2023-06-08 16:00:00	\N	\N	1	0	572	\N
746140	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Lionel CARRE, Président de l'association France-Filnlande	Entretien avec M. Lionel CARRE, Président de l'association France-Filnlande	2023-05-30 12:35:00	2023-05-30 14:05:00	\N	\N	1	0	640	\N
750213	DELEGATION	AUCUNE	\N	\N	206	Examen du rapport sur le projet de réforme ASN-IRSN	\N	2023-07-11 13:35:00	2023-07-11 15:25:00	\N	\N	15	0	\N	\N
750218	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réuniion CATDD	\N	2023-07-11 14:34:00	2023-07-11 15:46:00	2023-07-11 16:02:25	2023-07-12 10:30:17	23	0	\N	\N
750427	MISSION	AUCUNE	\N	GEAU	\N	Adoption du rapport d'information	\N	2023-07-11 17:10:00	2023-07-11 18:35:00	2023-07-12 11:05:48	2023-07-13 11:22:53	11	0	\N	\N
751567	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2023-07-18 10:00:00	2023-07-18 10:30:00	\N	\N	31	0	\N	\N
751571	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Violences urbaines	PJL Violences urbaines	2023-07-18 10:30:00	2023-07-18 12:35:00	\N	\N	79	0	\N	\N
752358	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Données de connexion	MI Données de connexion	2023-09-28 09:00:00	2023-09-28 09:45:00	\N	\N	2	0	\N	\N
681083	COM_PERMANENTE	AUTRE	\N	CAE	\N	PPL Engrillagement	\N	2022-11-30 08:35:00	2022-11-30 09:30:00	2022-11-30 18:26:49	2022-12-01 18:08:20	49	1	\N	\N
681086	COM_PERMANENTE	AUTRE	\N	CAE	\N	PPL Protéger les collectivités territoriales de la hausse des prix de l'énergie	\N	2022-11-30 11:30:00	2022-11-30 12:15:00	2022-11-30 18:44:41	2022-12-01 18:08:15	43	1	\N	\N
681116	COM_PERMANENTE	AUTRE	\N	AFCL	\N	PPL AESH	\N	2022-12-07 10:15:00	2022-12-07 10:30:00	2022-12-08 16:51:37	2022-12-09 15:34:06	43	3	\N	\N
752361	ETUDES	AUCUNE	\N	\N	\N	Déplacement à l'Assemblée nationale	Déplacement à l'Assemblée nationale	2023-09-27 15:00:00	2023-09-27 16:00:00	\N	\N	2	0	\N	938
756590	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2024 - Audition Cades	\N	2023-10-17 16:00:00	2023-10-17 17:00:00	\N	\N	0	0	\N	\N
756591	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2024 - Audition Leem	\N	2023-10-17 17:00:00	2023-10-17 18:10:00	\N	\N	3	0	\N	\N
756592	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition filière bio	\N	2023-10-18 09:00:00	2023-10-18 10:45:00	2023-10-18 11:53:57	2023-10-18 18:17:07	49	1	\N	\N
756910	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLC Abroger l'article 40 de la Constitution	PPLC Abroger l'article 40 de la Constitution	2023-10-19 08:00:00	2023-10-19 09:30:00	\N	\N	0	0	\N	\N
756911	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLC Abroger l'article 40 de la Constitution	PPLC Abroger l'article 40 de la Constitution	2023-10-18 17:00:00	2023-10-18 19:00:00	\N	\N	1	0	\N	\N
756920	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLC Abroger l'article 40 de la Constitution	PPLC Abroger l'article 40 de la Constitution	2023-10-19 15:30:00	2023-10-19 16:00:00	\N	\N	0	0	\N	\N
757773	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition du Général Thierry Burkhard	Audition du Général Thierry Burkhard	2023-10-24 15:30:00	2023-10-24 17:20:00	2023-10-24 18:19:00	2023-10-25 16:14:43	27	0	\N	\N
757774	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de l'IFRI	Audition de MM. Elie Tenenbaum et Léo Péria-Peigné	2023-10-25 09:00:00	2023-10-25 10:25:00	2023-11-07 17:37:23	\N	29	0	\N	\N
757808	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Déplacement à Evreux	Déplacement à Evreux	2023-10-12 07:00:00	2023-10-12 17:30:00	\N	\N	10	0	\N	\N
757819	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Déplacement à l'Ecole militaire	Déplacement à l'Ecole militaire	2023-10-19 13:30:00	2023-10-19 18:00:00	\N	\N	5	0	\N	\N
757954	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2024 - AT MP - Organisations syndicales	\N	2023-10-24 10:00:00	2023-10-24 11:00:00	\N	\N	3	0	\N	\N
757955	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2024 - AT MP - Audition ANADAVI	\N	2023-10-24 11:00:00	2023-10-24 11:30:00	\N	\N	3	0	\N	\N
757959	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Réunion du Conseil de Questure	2023-10-17 14:15:00	2023-10-17 15:40:00	\N	\N	3	0	\N	\N
757971	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	plf patrimoine	\N	2023-10-23 10:30:00	2023-10-23 11:30:00	\N	\N	5	0	\N	\N
757984	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL écriture inclusive	\N	2023-10-23 18:30:00	2023-10-23 19:30:00	\N	\N	1	0	\N	\N
758149	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2024 - Avis Fonction publique	Audition rapporteur - PLF 2024 - Avis fonction publique	2023-10-24 09:15:00	2023-10-24 10:15:00	\N	\N	1	0	\N	\N
758164	BUREAU	AUCUNE	\N	\N	\N	Réunion de Questure	Réunion du Conseil de Questure	2023-09-28 09:00:00	2023-09-28 11:40:00	\N	\N	3	0	\N	\N
758344	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLF pour 2024 - Mission Sécurité civile	PJLF pour 2024 - Mission Sécurité civile	2023-10-24 11:30:00	2023-10-24 12:30:00	\N	\N	1	0	\N	\N
759181	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2024 - Avis Fonction publique	Audition rapporteur - PLF 2024 - Avis fonction publique	2023-10-24 15:00:00	2023-10-24 16:35:00	\N	\N	1	0	\N	\N
759184	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2024 - Avis Fonction publique	Audition rapporteur - PLF 2024 - Avis fonction publique	2023-10-24 17:15:00	2023-10-24 18:40:00	\N	\N	0	0	\N	\N
759276	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2024 - Audition DSS	\N	2023-10-24 17:30:00	2023-10-24 18:45:00	\N	\N	2	0	\N	\N
759423	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2024 Autonomie - Audition de la Fehap	\N	2023-10-24 15:00:00	2023-10-24 15:45:00	\N	\N	1	0	\N	\N
759424	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2024 Autonomie - Audition du Collectif Handicaps	\N	2023-10-24 15:45:00	2023-10-24 16:30:00	\N	\N	1	0	\N	\N
759468	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2024 Autonomie - Audition de l'Anecamsp	\N	2023-10-24 16:45:00	2023-10-24 17:30:00	\N	\N	1	0	\N	\N
759469	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2024 Autonomie - Audition de l'Association française des aidants	\N	2023-10-24 17:30:00	2023-10-24 18:00:00	\N	\N	1	0	\N	\N
759474	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion CATDD	\N	2023-10-31 16:00:00	2023-10-31 17:40:00	2023-10-31 18:18:23	2023-11-02 12:36:47	26	0	\N	\N
759564	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Audition de la Cour de justice de la République	\N	2023-10-24 15:00:00	2023-10-24 16:30:00	\N	\N	1	0	\N	\N
759600	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Audition du Conseil constitutionnel	\N	2023-11-07 16:00:00	2023-11-07 17:45:00	\N	\N	1	0	\N	\N
759634	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2024 - Audition EFS	\N	2023-10-25 14:00:00	2023-10-25 15:00:00	\N	\N	5	0	\N	\N
759726	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur	\N	2023-10-23 15:00:00	2023-10-23 16:00:00	\N	\N	0	0	\N	\N
759746	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition de l'Arcom	\N	2023-10-23 15:00:00	2023-10-23 16:00:00	\N	\N	1	0	\N	\N
759750	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition du secrétariat général du gouvernement	\N	2023-10-23 16:25:00	2023-10-23 17:10:00	\N	\N	1	0	\N	\N
637992	MISSION	AUCUNE	\N	CULTURE	\N	Réunion 20220309a	\N	2022-03-09 09:30:00	2022-03-09 12:00:00	2022-03-09 15:02:14	2022-03-09 18:05:41	8	0	\N	\N
717235	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Parité dans la fonction publique	Proposition de loi visant à renforcer l'accès des femmes aux responsabilités dans la fonction publique	2023-03-21 15:30:00	2023-03-21 18:00:00	\N	\N	1	0	\N	\N
718381	GIA	AUCUNE	\N	\N	\N	Réunion du bureau	Réunion du bureau	2023-03-22 08:30:00	2023-03-22 09:30:00	\N	\N	8	0	598	\N
718605	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2023-03-29 15:00:00	2023-03-29 16:15:00	\N	\N	283	0	\N	\N
718666	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 29 mars 2023	\N	2023-03-29 14:00:00	2023-03-29 14:50:00	2023-03-29 15:02:12	2023-03-29 17:17:34	19	0	\N	\N
718667	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 30 mars 2023	\N	2023-03-30 09:00:00	2023-03-30 10:30:00	2023-03-30 11:14:13	2023-03-30 11:53:51	13	0	\N	\N
718669	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLC  loi de financement des collectivités territoriales 	PPLC  loi de financement des collectivités territoriales 	2023-03-22 14:00:00	2023-03-22 15:00:00	\N	\N	2	0	\N	\N
718673	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle budgétaire CESE - Audition CESE	Contrôle budgétaire CESE - Audition CESE	2023-03-23 09:30:00	2023-03-23 11:30:00	\N	\N	1	0	\N	\N
718675	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 Engagements financiers de l'Etat - Risque PGE Audition BpiFrance	Contrôle 2023 Engagements financiers de l'Etat - Risque PGE Audition BpiFrance	2023-03-20 09:05:00	2023-03-20 10:35:00	\N	\N	1	0	\N	\N
718677	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 Engagements financiers de l'Etat - Risque PGE Audition DGE/CIRI	Contrôle 2023 Engagements financiers de l'Etat - Risque PGE Audition DGE/CIRI	2023-03-20 10:35:00	2023-03-20 11:55:00	\N	\N	1	0	\N	\N
718679	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Mission "Cohésion des territoires" - EPF et EPA - Audition DHUP	Contrôle 2023 - Mission "Cohésion des territoires" - EPF et EPA - Audition DHUP	2023-03-21 14:00:00	2023-03-21 15:05:00	\N	\N	1	0	\N	\N
718681	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Mission "Cohésion des territoires" - EPF/EPA - Audition ANEPFL	Contrôle 2023 - Mission "Cohésion des territoires" - EPF/EPA - Audition Association Nationale EPFL	2023-03-22 17:00:00	2023-03-22 17:55:00	\N	\N	1	0	\N	\N
718683	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Mission "Cohésion des territoires" - Audition Réseau national EPF d'Etat	Contrôle 2023 - Mission "Cohésion des territoires" - EPF/EPA - Audition Réseau national EPF d'Etat	2023-03-22 17:55:00	2023-03-22 18:40:00	\N	\N	1	0	\N	\N
718685	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL EDF - Audition A. ZAJDENWEBER (APE)	PPL EDF - Audition A. ZAJDENWEBER (APE)	2023-03-14 09:00:00	2023-03-14 10:00:00	\N	\N	1	0	\N	\N
718687	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL EDF - Audition L. REMONT (EDF)	PPL EDF - Audition L. REMONT pdg (EDF)	2023-03-15 11:00:00	2023-03-15 12:00:00	\N	\N	1	0	\N	\N
718689	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL EDF - Audition M. LAIGNEAU (ENEDIS)	PPL EDF - Audition M. LAIGNEAU présidente du directoire (ENEDIS)	2023-03-15 13:00:00	2023-03-15 14:00:00	\N	\N	1	0	\N	\N
718691	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPLC LFCT - Audition E. KERROUCHE sénateur auteur de la PPLC	PPLC LFCT - Audition E. KERROUCHE sénateur auteur de la PPLC	2023-03-21 14:40:00	2023-03-21 15:30:00	\N	\N	2	0	\N	\N
718692	COM_PERMANENTE	AUDRAP	\N	CAE	\N	DGEC	\N	2023-03-21 14:30:00	2023-03-21 15:15:00	\N	\N	3	0	\N	\N
718698	COM_PERMANENTE	AUDRAP	\N	CAE	\N	DGCCRF	\N	2023-03-21 15:15:00	2023-03-21 16:00:00	\N	\N	1	0	\N	\N
718700	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Anode et Afieg	\N	2023-03-21 16:00:00	2023-03-21 17:00:00	\N	\N	2	0	\N	\N
718703	COM_PERMANENTE	AUDRAP	\N	CAE	\N	CRE	\N	2023-03-21 17:30:00	2023-03-21 18:15:00	\N	\N	2	0	\N	\N
718706	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPLC LFCT - Audition P. CHAVY et T. ROULON (Direction du Budget)	PPLC LFCT - Audition P. CHAVY et T. ROULON (Direction du Budget)	2023-03-21 15:30:00	2023-03-21 16:30:00	\N	\N	1	0	\N	\N
718708	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPLC LFCT - Table ronde professeurs finances locales/droit des collectivités territoriales	PPLC LFCT - Table ronde professeurs finances locales/droit des collectivités territoriales	2023-03-21 16:30:00	2023-03-21 18:30:00	\N	\N	1	0	\N	\N
718710	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPLC LFCT - Audition S. BRUNOT, Y. GENESLAY, T. MONTBABUT (DGCL)	PPLC LFCT - Audition S. BRUNOT, Y. GENESLAY, T. MONTBABUT (DGCL)	2023-03-22 14:00:00	2023-03-22 15:00:00	\N	\N	1	0	\N	\N
718712	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI AESH	\N	2023-03-24 09:00:00	2023-03-24 10:35:00	\N	\N	3	0	\N	\N
718722	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI AESH	\N	2023-03-23 14:00:00	2023-03-23 17:00:00	\N	\N	3	0	\N	\N
718758	DELEGATION	AUCUNE	\N	\N	211	Table ronde Parentalité outre-mer (Collectivités du Pacifique)	\N	2023-04-04 08:00:00	2023-04-04 10:00:00	\N	\N	8	0	\N	\N
719935	GIA	AUCUNE	\N	\N	\N	Entretien avec Francisco CAFIERO, Secrétaire d¿état argentin à la défense	Entretien avec Francisco CAFIERO, Secrétaire d¿état aux relations internationales du ministère de la Défense argentin	2023-03-30 08:30:00	2023-03-30 10:00:00	\N	\N	7	0	978	\N
719954	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	Audition du groupe d'études "Statut, rôle et place des Français établis hors de France"	Audition du bureau exécutif et des pdts de commission  de l'AFE	2023-03-29 18:00:00	2023-03-29 19:45:00	\N	\N	13	0	\N	\N
719969	COM_ENQUETE	DEPLACEMENT	\N	TIKTO	\N	Pôle d'expertise de la régulation numérique de Bercy	Pôle d'expertise de la régulation numérique de Bercy	2023-03-30 10:30:00	2023-03-30 13:15:00	\N	\N	8	0	\N	\N
720018	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2023-03-29 09:30:00	2023-03-29 11:00:00	2023-03-30 17:41:58	2023-04-03 09:53:21	43	0	\N	\N
720092	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Evénements de Sainte-Soline - Audition de Gérald Darmanin	Evénements de Sainte-Soline - Audition de Gérald Darmanin	2023-04-05 11:20:00	2023-04-05 13:05:00	2023-04-05 13:03:46	2023-04-06 17:46:31	40	0	\N	\N
720095	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Résidence d'attache pour les Français établis hors de France	PPL Résidence d'attache pour les Français établis hors de France	2023-04-04 14:30:00	2023-04-04 17:00:00	\N	\N	118	0	\N	\N
720096	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2023-04-04 09:30:00	2023-04-04 12:55:00	\N	\N	50	0	\N	\N
720097	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Lutte contre le risque incendie	PPL Lutte contre le risque incendie	2023-04-04 17:00:00	2023-04-04 20:00:00	\N	\N	111	0	\N	\N
720098	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2023-04-05 15:00:00	2023-04-05 16:20:00	\N	\N	298	0	\N	\N
720099	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Ticket restaurant étudiant	PPL Ticket restaurant étudiant	2023-04-05 16:30:00	2023-04-05 17:40:00	\N	\N	47	0	\N	\N
720100	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Parité dans la haute fonction publique	PPL Parité dans la haute fonction publique	2023-04-05 17:45:00	2023-04-05 19:50:00	\N	\N	47	0	\N	\N
720102	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Revaloriser le statut de secrétaire de mairie	PPL Revaloriser le statut de secrétaire de mairie	2023-04-06 10:30:00	2023-04-06 12:50:00	\N	\N	51	0	\N	\N
720103	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Organisation algorithmique du travail	PPL Organisation algorithmique du travail	2023-04-06 12:50:00	2023-04-06 13:20:00	\N	\N	24	0	\N	\N
720104	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Nationalisation du groupe Électricité de France	PPL Nationalisation du groupe Électricité de France	2023-04-06 16:00:00	2023-04-06 18:00:00	\N	\N	40	0	\N	\N
720105	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLLC Loi de financement des collectivités territoriales	PLLC Loi de financement des collectivités territoriales	2023-04-06 18:00:00	2023-04-06 20:05:00	\N	\N	26	0	\N	\N
720107	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-04-05 09:30:00	2023-04-05 12:25:00	2023-04-05 12:25:24	2023-04-06 17:46:24	38	0	\N	\N
720109	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI TND - Audition Assoc directeurs de MDPH	\N	2023-03-30 10:30:00	2023-03-30 11:30:00	\N	\N	4	0	\N	\N
720110	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI TND - Audition GIS autisme et troubles du neurodéveloppement	\N	2023-03-30 09:30:00	2023-03-30 10:30:00	\N	\N	2	0	\N	\N
640468	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Déplacement à Meudon - MI "Reconnaissance faciale"	Déplacement à Meudon - MI "Reconnaissance faciale"	2022-03-29 13:40:00	2022-03-29 18:15:00	\N	\N	2	0	\N	\N
640497	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI "Reconnaissance faciale"	MI "Reconnaissance faciale" - Auditions	2022-03-29 09:00:00	2022-03-29 12:10:00	\N	\N	3	0	\N	\N
641186	MISSION	AUCUNE	\N	FONDSMER	\N	Auditions MESRI  + ERAMET	Auditions MESRI + ERAMET	2022-04-12 17:00:00	2022-04-12 18:40:00	2022-04-12 18:42:35	2022-04-14 15:13:19	4	0	\N	\N
642705	COM_PERMANENTE	AUDRAP	\N	FINC	\N	MI Fraude et évasion fiscales - SJCF/DACG	MI Fraude et évasion fiscales - SJCF/DACG	2022-05-10 16:00:00	2022-05-10 18:20:00	\N	\N	11	0	\N	\N
642717	COM_PERMANENTE	AUDRAP	\N	FINC	\N	MI Fraude et évasion fiscales - DGDDI	MI Fraude et évasion fiscales - DGDDI	2022-05-11 14:30:00	2022-05-11 15:35:00	\N	\N	7	0	\N	\N
642725	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - OAT vertes - Institut Louis Bachelier	Contrôle 2022 - OAT vertes - Institut Louis Bachelier	2022-05-11 11:00:00	2022-05-11 12:00:00	\N	\N	1	0	\N	\N
642727	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2022- IGN - Déplacement Saint-Mandé	Contrôle 2022- IGN - Déplacement Saint-Mandé	2022-05-12 14:00:00	2022-05-12 18:15:00	\N	\N	1	0	\N	\N
642729	ETUDES	AUTRE	\N	\N	\N	Eurodia	Eurodia	2022-05-12 09:30:00	2022-05-12 10:30:00	\N	\N	12	0	\N	909
642742	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition UNICID	Audition UNICID	2022-05-10 10:00:00	2022-05-10 11:00:00	\N	\N	4	0	\N	\N
642747	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition FranceAgriMer	Audition FranceAgriMer	2022-05-11 10:30:00	2022-05-11 11:15:00	\N	\N	2	0	\N	\N
642750	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition de DGPE - Bureau des fruits et légumes	Audition de DGPE - Bureau des fruits et légumes	2022-05-11 11:15:00	2022-05-11 11:45:00	\N	\N	2	0	\N	\N
642753	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Centre technique interprofessionnel des fruits et légumes - Filière Pommes	Audition Centre technique interprofessionnel des fruits et légumes - Filière Pommes	2022-05-11 11:45:00	2022-05-11 12:30:00	\N	\N	2	0	\N	\N
642756	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Table ronde ANPP - GEFEL - FNPF	Table ronde ANPP - GEFEL - FNPF	2022-05-11 14:00:00	2022-05-11 15:00:00	\N	\N	2	0	\N	\N
642759	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Table ronde AFIDEM - FIAC - Unijus	Table ronde AFIDEM - FIAC - Unijus	2022-05-11 15:00:00	2022-05-11 16:00:00	\N	\N	2	0	\N	\N
642762	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition ANEEFEL	Audition ANEEFEL	2022-05-11 16:00:00	2022-05-11 16:30:00	\N	\N	2	0	\N	\N
642765	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition UNCGFL	Audition UNCGFL	2022-05-11 16:30:00	2022-05-11 17:00:00	\N	\N	2	0	\N	\N
642779	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Visite de Journaux	\N	2022-05-19 08:30:00	2022-05-19 17:00:00	\N	\N	0	0	\N	\N
643445	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition Darmanin & Castera	Réunion commune (Commission de la culture, Commission des lois) - Audition Darmanin & Castera	2022-06-01 17:05:00	2022-06-01 20:05:00	2022-06-08 17:02:42	2022-06-08 17:30:31	71	0	\N	\N
643450	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de M. Éric Béranger, PDG de MBDA	\N	2022-06-01 10:00:00	2022-06-01 11:30:00	2022-06-01 12:22:40	2022-06-01 16:47:29	20	0	\N	\N
643472	MECSS	AUDRAP	\N	\N	MECSS	MI Fraude sociale au sein des caisses - Audition DSS	\N	2022-06-14 10:00:00	2022-06-14 11:00:00	\N	\N	4	0	\N	\N
643475	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Obésité - Table ronde sur la situation en outre-mer	\N	2022-05-31 17:15:00	2022-05-31 18:15:00	\N	\N	4	0	\N	\N
643476	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Obésité - Audition de M. Guido Girardi	\N	2022-05-31 16:00:00	2022-05-31 17:00:00	\N	\N	4	0	\N	\N
643533	DELEGATION	AUTRE	\N	\N	211	Table ronde sur les représentations des femmes et des sexualités	\N	2022-06-01 14:35:00	2022-06-01 16:30:00	\N	\N	8	0	\N	\N
643557	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	DGSCGC	\N	2022-05-31 14:00:00	2022-05-31 14:45:00	\N	\N	0	0	\N	\N
643558	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	DGPE	\N	2022-05-31 14:45:00	2022-05-31 15:30:00	\N	\N	0	0	\N	\N
643559	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	DGPR	\N	2022-05-31 15:45:00	2022-05-31 16:30:00	\N	\N	0	0	\N	\N
643560	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	FBF	\N	2022-05-31 16:30:00	2022-05-31 17:15:00	\N	\N	0	0	\N	\N
643562	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	IGN	\N	2022-05-31 17:15:00	2022-05-31 18:00:00	\N	\N	0	0	\N	\N
644236	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2022-06-08 16:00:00	2022-06-08 16:30:00	\N	\N	3	0	\N	\N
644923	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Salon Eurosatory 2022	\N	2022-06-15 08:00:00	2022-06-15 17:10:00	\N	\N	14	0	\N	\N
644951	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	Audition MI Mégafeux	Audition MI Mégafeux	2022-07-15 14:00:00	2022-07-15 17:30:00	\N	\N	3	0	\N	\N
644957	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI Aménagement du territoire	MI Aménagement du territoire	2022-06-15 08:45:00	2022-06-15 09:05:00	\N	\N	4	0	\N	\N
644962	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	Audition MI Mégafeux	Audition MI Mégafeux	2022-06-14 14:30:00	2022-06-14 16:15:00	\N	\N	3	0	\N	\N
644974	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	Audition MI Mégafeux	Audition MI Mégafeux	2022-06-15 16:15:00	2022-06-15 18:00:00	\N	\N	4	0	\N	\N
646108	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 7 juillet 2022	Réunion du 7 juillet 2022	2022-07-07 08:50:00	2022-07-07 10:45:00	2022-07-07 11:15:38	2022-07-07 18:09:48	13	0	\N	\N
646109	DELEGATION	AUCUNE	\N	\N	COLTER	Table ronde dans la Nièvre	\N	2022-06-24 15:45:00	2022-06-24 17:15:00	\N	\N	4	0	\N	\N
646153	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désignations -  PPL Diffusion de contenus à caractère terroriste en ligne (rapport)	Désignations -  PPL Diffusion de contenus à caractère terroriste en ligne (rapport)	2022-07-06 09:10:00	2022-07-06 09:45:00	2022-07-06 16:17:14	2022-07-06 18:31:46	30	2	\N	\N
646154	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de Didier Migaud, président de la HATVP	Audition de Didier Migaud, président de la Haute Autorité pour la transparence de la vie publique	2022-07-06 09:55:00	2022-07-06 11:20:00	2022-07-06 16:17:26	2022-07-06 18:31:45	33	2	\N	\N
646155	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de Claire Hédon, Défenseure des droits	Audition de Claire Hédon, Défenseure des droits	2022-07-06 11:25:00	2022-07-06 12:20:00	2022-07-06 16:17:33	2022-07-06 18:31:45	24	1	\N	\N
646156	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	MCC Revitalisation - Réunion plénière - Bilan d'étape du rapport	MCC Revitalisation - Réunion plénière - Bilan d'étape du rapport	2022-07-07 10:45:00	2022-07-07 12:25:00	\N	\N	31	0	\N	\N
646158	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition FranceAgriMer	Audition FranceAgrimer	2022-06-29 11:45:00	2022-06-29 12:30:00	\N	\N	3	0	\N	\N
646162	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Table ronde syndicats agricoles	Table ronde syndicats agricoles	2022-06-29 14:00:00	2022-06-29 15:30:00	\N	\N	6	0	\N	\N
646169	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition INRAE	Audition INRAE	2022-06-29 15:45:00	2022-06-29 16:30:00	\N	\N	3	0	\N	\N
646177	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	MCC Délinquance mineurs	\N	2022-06-30 11:00:00	2022-06-30 16:00:00	\N	\N	0	0	\N	\N
646402	GIA	AUCUNE	\N	\N	\N	Entretien avec Jean-Marc Fenet, chef du service économique régional de Pékin	\N	2022-07-05 17:30:00	2022-07-05 18:45:00	\N	\N	7	0	584	\N
649070	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition MI métropoles Lyon Aix-Marseille-Provence	\N	2022-07-13 13:00:00	2022-07-13 14:40:00	\N	\N	3	0	\N	\N
649077	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI métropoles Lyon Aix-Marseille-Provence	MI métropoles Lyon Aix-Marseille-Provence	2022-07-12 08:15:00	2022-07-12 08:45:00	\N	\N	3	0	\N	\N
649081	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition MI métropoles Lyon Aix-Marseille-Provence	Audition MI métropoles Lyon Aix-Marseille-Provence	2022-07-12 09:00:00	2022-07-12 10:30:00	\N	\N	3	0	\N	\N
649085	GIA	AUCUNE	\N	\N	\N	Audition de Mme Françoise POMMARET, Consul honoraire de France au Bhoutan 	Audition de Mme Françoise POMMARET, Consul honoraire de France au Bhoutan	2022-07-13 14:00:00	2022-07-13 15:00:00	\N	\N	3	0	633	\N
665458	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Auditions MCC ZAN	Auditions MCC ZAN	2022-10-18 15:50:00	2022-10-18 16:15:00	\N	\N	7	0	\N	\N
665468	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Auditions MCC ZAN	Auditions MCC ZAN	2022-10-18 16:15:00	2022-10-18 17:15:00	\N	\N	8	0	\N	\N
665477	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Auditions MCC ZAN	Auditions MCC ZAN	2022-10-18 17:20:00	2022-10-18 18:05:00	\N	\N	8	0	\N	\N
665487	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Auditions MCC ZAN	Auditions MCC ZAN	2022-10-18 18:10:00	2022-10-18 18:45:00	\N	\N	9	0	\N	\N
665498	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Auditions MCC ZAN	Auditions MCC ZAN	2022-10-19 14:30:00	2022-10-19 15:00:00	\N	\N	4	0	\N	\N
708164	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI LPM programme 144	MI LPM programme 144	2023-02-28 14:30:00	2023-02-28 15:30:00	\N	\N	1	0	\N	\N
708179	GIA	AUCUNE	\N	\N	\N	Déplacement en Côte d'Ivoire et en Sierra Leone 	Déplacement en Côte d'Ivoire et en Sierra Leone 	2023-02-19 14:00:00	2023-02-25 00:00:00	\N	\N	4	0	573	\N
709563	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2023-03-08 01:20:00	2023-03-08 01:40:00	2023-03-08 09:54:39	2023-03-08 17:31:09	35	0	\N	\N
709564	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2023-03-08 02:15:00	2023-03-08 02:25:00	2023-03-14 16:14:26	2023-03-14 16:16:33	31	0	\N	\N
709570	COM_PERMANENTE	AUTRE	\N	CAE	\N	Auditions ASN/IRSN	\N	2023-03-08 09:30:00	2023-03-08 11:40:00	2023-03-08 12:28:56	2023-03-08 17:31:08	30	1	\N	\N
710333	GIA	AUCUNE	\N	\N	\N	Rencontre avec M. Alexandr Trubca, président de la commission Agriculture 	Rencontre avec M. Alexandr Trubca, député moldave	2023-03-08 14:00:00	2023-03-08 15:00:00	\N	\N	2	0	851	\N
710885	GIA	AUCUNE	\N	\N	\N	Entretien avec François Wu, représentant de Taipei en France	Entretien avec François Wu, représentant de Taipei en France	2023-02-28 16:00:00	2023-02-28 16:45:00	\N	\N	1	0	623	\N
711251	DELEGATION	AUTRE	\N	\N	ENTREPRISES	Auditions relatives à la simplification des normes applicables aux entreprises	\N	2023-03-09 08:30:00	2023-03-09 10:30:00	2023-03-09 11:35:28	\N	6	0	\N	\N
711414	MISSION	AUCUNE	\N	GEAU	\N	Délégué interministériel en charge du suivi des conclusions du Varenne agricole de l¿eau 	\N	2023-03-09 11:00:00	2023-03-09 12:15:00	2023-03-09 15:37:30	2023-03-10 17:32:19	7	0	\N	\N
711470	DELEGATION	AUDRAP	\N	\N	206	Audition de Fairphone	\N	2023-03-08 08:30:00	2023-03-08 09:30:00	\N	\N	2	0	\N	\N
711616	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Mme Lienemann et M. Lemoyne	Auditions Mme Lienemann et M. Lemoyne	2023-03-09 09:00:00	2023-03-09 12:30:00	\N	\N	3	0	\N	\N
711622	COM_SPECIALE	AUDRAP	\N	CINC	\N	TR Associations environnementales	TR Associations environnementales	2023-03-09 09:00:00	2023-03-09 10:00:00	\N	\N	14	0	\N	\N
711833	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle budgétaire Immobilier MEAE - Déplacement Barcelone et Madrid	Contrôle budgétaire Immobilier MEAE - Déplacement Barcelone et Madrid	2023-03-06 07:00:00	2023-03-07 22:20:00	\N	\N	1	0	\N	\N
711835	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 15 mars 2023	\N	2023-03-15 13:50:00	2023-03-15 14:55:00	2023-03-15 14:56:48	2023-03-16 14:03:29	11	0	\N	\N
712556	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	intervention du Président auprès des officiers du CHEM	\N	2023-03-02 11:30:00	2023-03-02 12:15:00	\N	\N	1	0	\N	\N
712571	COM_ENQUETE	PLENIERE	\N	TIKTO	\N	Audition CE Tiktok	Audition CE Tiktok	2023-03-13 16:15:00	2023-03-13 17:30:00	2023-03-15 14:45:32	2023-03-16 14:05:02	10	0	\N	\N
713517	COM_SPECIALE	PLENIERE	\N	CZAN	\N	PPL ZAN - Examen des amendements de séance	\N	2023-03-14 14:20:00	2023-03-14 14:50:00	2023-03-15 16:31:32	2023-03-16 14:05:03	25	1	\N	\N
713519	DELEGATION	AUDRAP	\N	\N	206	Audition recyclage plastique	\N	2023-03-13 09:30:00	2023-03-13 12:30:00	\N	\N	2	0	\N	\N
713635	MISSION	AUCUNE	\N	BATI	\N	TR professionnels du bâtiment	\N	2023-03-21 15:30:00	2023-03-21 17:15:00	2023-03-21 18:05:55	2023-03-22 15:24:53	8	0	\N	\N
713834	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Parité dans la fonction publique	Proposition de loi visant à renforcer l'accès des femmes aux responsabilités dans la fonction publique	2023-03-14 14:00:00	2023-03-14 14:30:00	\N	\N	1	0	\N	\N
714162	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE 16 - 58-2 Scolarisation élèves allophones	PLENIERE 16 - 58-2 Scolarisation élèves allophones	2023-03-15 09:30:00	2023-03-15 11:03:00	2023-03-16 10:03:02	2023-03-16 14:02:38	25	0	\N	\N
714163	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 17	\N	2023-03-15 11:05:00	2023-03-15 13:10:00	\N	\N	20	0	\N	\N
714306	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Parité dans la fonction publique	Renforcer l'accès des femmes aux responsabilités dans la fonction publique	2023-03-14 10:15:00	2023-03-14 11:45:00	\N	\N	2	0	\N	\N
714385	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Lycée public Henri Bergson d'Angers	\N	2023-03-14 14:30:00	2023-03-14 15:30:00	\N	\N	2	0	\N	\N
714386	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Lycée public Louis le Grand	\N	2023-03-14 15:30:00	2023-03-14 16:30:00	\N	\N	2	0	\N	\N
714396	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Cour des comptes	\N	2023-03-14 15:30:00	2023-03-14 17:15:00	\N	\N	5	0	\N	\N
714403	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Ballons stratosphériques	\N	2023-03-15 08:30:00	2023-03-15 09:30:00	\N	\N	0	0	\N	\N
714404	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Ballons stratospériques	\N	2023-03-15 08:30:00	2023-03-15 09:30:00	\N	\N	0	0	\N	\N
714409	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Audition CNES	\N	2023-03-15 08:30:00	2023-03-15 09:30:00	\N	\N	0	0	\N	\N
714433	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition CNES	Audition CNES	2023-03-15 08:30:00	2023-03-15 09:30:00	\N	\N	5	0	\N	\N
711614	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Eau Assainissement - DECI - Conseils communautaires - PJL Immigration	PPL Eau Assainissement - DECI - Conseils communautaires (amendements) - PJL Immigration et intégration (rapport)	2023-03-15 08:30:00	2023-03-15 13:05:00	2023-03-15 14:22:56	2023-03-16 14:02:35	44	9	\N	\N
712198	COM_PERMANENTE	AUTRE	\N	ETRD	\N	PJL SS Serbie 	\N	2023-03-15 11:00:00	2023-03-15 11:15:00	2023-03-15 12:15:35	2023-03-16 14:02:33	37	2	\N	\N
713873	COM_PERMANENTE	AUTRE	\N	CAE	\N	Examen amendements de séance Ppl Habitat non-décent	\N	2023-03-15 11:45:00	2023-03-15 13:25:00	2023-03-15 16:27:25	2023-03-16 14:02:33	44	2	\N	\N
714494	MISSION	AUCUNE	\N	GEAU	\N	Audition BRGM	\N	2023-03-15 14:00:00	2023-03-15 15:00:00	2023-03-15 15:05:25	2023-03-16 14:04:59	8	0	\N	\N
714517	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Base navale de Brest	Base navale de Brest	2023-03-15 16:45:00	2023-03-16 20:30:00	\N	\N	13	0	\N	\N
714789	GIA	AUCUNE	\N	\N	\N	Audition de l'Ambassadrice de France au Nigeria 	Audition de Mme Emmanuelle Blatmann, Ambassadrice de France au Nigeria	2023-03-15 14:05:00	2023-03-15 15:00:00	\N	\N	5	0	573	\N
714820	MISSION	AUDRAP	\N	BATI	\N	MIBS	\N	2023-03-14 15:30:00	2023-03-14 16:45:00	\N	\N	7	0	\N	\N
714821	MISSION	AUDRAP	\N	GEAU	\N	Audition UFC-Que choisir	\N	2023-03-15 16:30:00	2023-03-15 17:50:00	\N	\N	5	0	\N	\N
714835	MISSION	AUDRAP	\N	BATI	\N	MIBS	\N	2023-03-15 14:00:00	2023-03-15 15:30:00	\N	\N	4	0	\N	\N
715267	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Violences intrafamiliales (amendements)	PPL Violences intrafamiliales (amendements)	2023-03-21 14:00:00	2023-03-21 14:05:00	2023-03-21 16:04:26	2023-03-21 16:36:44	15	1	\N	\N
715268	COM_PERMANENTE	DEPLACEMENT	\N	SOCI	\N	MI Fin de vie - Déplacement à l'hôpital de la Pitié-Salpêtrière	\N	2023-03-14 15:00:00	2023-03-14 17:20:00	\N	\N	3	0	\N	\N
715270	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition d'universitaires sur la réforme de la procédure pénale	Audition d'universitaires sur la réforme de la procédure pénale	2023-03-22 10:30:00	2023-03-22 11:35:00	2023-03-22 11:46:28	2023-03-22 15:24:39	21	0	\N	\N
715282	COM_ENQUETE	AUDRAP	\N	MEDIC	\N	CE Pénurie de médicaments - Audition commune de de MM. Giorgi et de Mazancourt	\N	2023-03-15 13:30:00	2023-03-15 14:50:00	\N	\N	4	0	\N	\N
715363	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2023-03-15 17:00:00	2023-03-15 18:00:00	\N	\N	1	0	\N	\N
715369	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition MI TND - ARS Ile de France	\N	2023-03-16 10:30:00	2023-03-16 12:00:00	\N	\N	2	0	\N	\N
716494	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2023-03-21 09:30:00	2023-03-21 12:45:00	\N	\N	51	0	\N	\N
716496	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Tiers-financement	\N	2023-03-21 14:30:00	2023-03-21 15:15:00	\N	\N	59	0	\N	\N
716497	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP EGALIM	CMP EGALIM	2023-03-21 15:20:00	2023-03-21 16:15:00	\N	\N	78	0	\N	\N
716498	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL violences intrafamiliales	PPL violences intrafamiliales	2023-03-21 16:20:00	2023-03-21 19:40:00	\N	\N	122	0	\N	\N
716499	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Emballages ménagers	PPL Emballages ménagers	2023-03-21 19:40:00	2023-03-21 20:00:00	\N	\N	24	0	\N	\N
716500	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Emballages ménagers	PPL Emballages ménagers	2023-03-21 21:30:00	2023-03-22 23:20:00	\N	\N	43	0	\N	\N
717073	MISSION	AUCUNE	\N	BATI	\N	MIBS	\N	2023-03-29 13:50:00	2023-03-29 14:50:00	2023-03-30 15:27:59	2023-03-30 17:25:43	9	0	\N	\N
648729	GIA	AUCUNE	\N	\N	\N	Petit déjeuner de travail avec l'Ambassadrice des Philippines	Audition de Son Exc Madame Junever M. Mahilum-West, Ambassadrice  des Philippines à Paris	2022-07-13 08:30:00	2022-07-13 09:30:00	\N	\N	12	0	609	\N
648750	GIA	AUCUNE	\N	\N	\N	Mission du groupe d'amitié à La Haye, Rotterdam et Amsterdam	Mission du groupe d'amitié sur le changement climatique et l'eau	2022-06-27 18:00:00	2022-07-01 19:00:00	\N	\N	3	0	599	CHRETORIENT
653072	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI prévention des incendies	MI prévention des incendies	2022-07-26 16:00:00	2022-07-26 17:00:00	\N	\N	4	0	\N	\N
653077	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI prévention des incendies	MI prévention des incendies	2022-07-22 17:15:00	2022-07-22 19:15:00	\N	\N	3	0	\N	\N
653081	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	MI prévention des incendies	MI prévention des incendies	2022-07-19 14:30:00	2022-07-19 15:30:00	\N	\N	4	0	\N	\N
654685	QUESTURE	AUCUNE	\N	\N	\N	Réunion de Questure	Réunion de Questure	2022-07-28 08:30:00	2022-07-28 10:06:00	\N	\N	3	0	\N	\N
654695	GIA	AUCUNE	\N	\N	\N	Réunion groupe d'amitié France-Canada	Réunion groupe d'amitié France-Canada	2022-07-28 15:15:00	2022-07-28 16:00:00	\N	\N	5	0	583	\N
656245	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL agrivoltaïsme	\N	2022-09-21 16:30:00	2022-09-21 17:45:00	\N	\N	4	0	\N	\N
656250	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL agrivoltaïsme	\N	2022-09-22 09:00:00	2022-09-22 10:00:00	\N	\N	5	0	\N	\N
664751	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL comités sociaux et économique à la Poste	PPL comités sociaux et économique à la Poste	2022-10-20 14:30:00	2022-10-20 15:20:00	\N	\N	38	0	\N	\N
671833	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2023 - Audition CAS Participations financières de l'État	PLF 2023 - Audition CAS Participations financières de l'État	2022-10-26 11:00:00	2022-10-26 11:45:00	\N	\N	1	0	\N	\N
672785	COM_EURO	AUTRE	\N	AFEU	\N	"Ambitions européennes et chocs économiques actuels": table ronde	\N	2022-11-16 13:30:00	2022-11-16 15:00:00	2022-11-16 16:04:46	2022-11-16 17:15:18	29	0	\N	\N
672786	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 17 novembre 2022	\N	2022-11-17 08:30:00	2022-11-17 10:45:00	\N	\N	0	0	\N	\N
672787	DELEGATION	AUDRAP	\N	\N	206	Auditions Sobriété énergétique	\N	2022-11-10 14:00:00	2022-11-10 17:00:00	\N	\N	2	0	\N	\N
672790	DELEGATION	AUTRE	\N	\N	211	Conférence	\N	2022-11-29 18:45:00	2022-11-29 20:15:00	\N	\N	0	0	\N	\N
672797	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2023 - Audition mission Économie - volet Commerce/artisanat	PLF 2023 - Audition mission Économie - volet Commerce/artisanat	2022-11-09 19:15:00	2022-11-09 20:00:00	\N	\N	1	0	\N	\N
672808	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Voleries	Voleries	2022-11-10 11:30:00	2022-11-10 12:15:00	\N	\N	1	0	\N	\N
672809	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2023 - Audition Économie - Industrie	PLF 2023 - Audition Économie - Industrie	2022-11-10 14:00:00	2022-11-10 15:00:00	\N	\N	1	0	\N	\N
672812	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-11-12 14:30:00	2022-11-12 14:40:00	\N	\N	15	0	\N	\N
672817	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Fédération des capacitaires et animaux de spectacle	Fédération des capacitaires et animaux de spectacle	2022-11-10 14:00:00	2022-11-10 14:45:00	\N	\N	1	0	\N	\N
672820	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Delphinariums	Delphinariums	2022-11-10 14:45:00	2022-11-10 15:30:00	\N	\N	1	0	\N	\N
672822	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Bernard de Froment	Bernard de Froment	2022-11-10 15:30:00	2022-11-10 16:15:00	\N	\N	1	0	\N	\N
672835	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Juridictions administratives et financières de Lyon	Juridictions administratives et financières de Lyon	2022-09-15 08:30:00	2022-09-15 18:30:00	\N	\N	1	0	\N	\N
672836	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLF 2023 - DAG	\N	2022-11-14 09:45:00	2022-11-14 15:30:00	\N	\N	1	0	\N	\N
672855	DELEGATION	AUDRAP	\N	\N	206	Audition DGRI	\N	2022-11-14 16:00:00	2022-11-14 16:50:00	\N	\N	2	0	\N	\N
655445	DELEGATION	AUTRE	\N	\N	DSOM	Audition de jean-François Carenco	\N	2022-10-06 09:00:00	2022-10-06 11:30:00	\N	\N	19	0	\N	\N
674549	GIA	AUCUNE	\N	\N	\N	IAudition de republicans overseas et de l' l'nternational Republican Institute	IAudition de republicans overseas et de l' l'nternational Republican Institute	2022-11-15 18:00:00	2022-11-15 19:45:00	\N	\N	4	0	590	\N
676311	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Déroulement des élections sénatoriales	Déroulement des élections sénatoriales	2022-11-16 17:45:00	2022-11-16 18:00:00	\N	\N	2	0	\N	\N
676314	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Déroulement des élections sénatoriales	Déroulement des élections sénatoriales	2022-11-17 09:30:00	2022-11-17 10:45:00	\N	\N	1	0	\N	\N
685293	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2022-12-14 08:30:00	2022-12-14 13:00:00	2022-12-14 13:33:32	2022-12-14 15:55:21	28	2	\N	\N
685294	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2022-12-13 09:30:00	2022-12-13 10:00:00	2022-12-13 10:50:37	2022-12-14 15:55:22	15	0	\N	\N
685741	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 8 décembre 2022	\N	2022-12-08 08:30:00	2022-12-08 09:45:00	2022-12-08 10:05:34	2022-12-08 11:58:48	14	0	\N	\N
686130	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-12-14 09:30:00	2022-12-14 12:00:00	2022-12-14 11:56:20	2022-12-14 15:55:19	27	0	\N	\N
686134	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-12-13 14:00:00	2022-12-13 14:05:00	2022-12-14 16:36:59	2022-12-15 15:07:53	9	0	\N	\N
686135	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-12-14 16:30:00	2022-12-14 18:00:00	2023-01-09 12:03:03	2023-01-10 14:56:11	16	0	\N	\N
699005	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Fin de vie - Table ronde d'associations	\N	2023-01-31 16:00:00	2023-01-31 17:15:00	\N	\N	5	0	\N	\N
699011	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Données de santé - Audition de la Cnam	\N	2023-01-31 17:30:00	2023-01-31 18:45:00	\N	\N	3	0	\N	\N
699015	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Accès aux soins - Audition de la Cnam	\N	2023-01-31 09:30:00	2023-01-31 10:25:00	\N	\N	3	0	\N	\N
699016	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Accès aux soins - Audition de syndicats d'internes	\N	2023-01-31 17:30:00	2023-01-31 18:45:00	\N	\N	5	0	\N	\N
699017	MISSION	AUCUNE	\N	GEAU	\N	Réunion constitutive	\N	2023-02-08 14:05:00	2023-02-08 14:40:00	2023-02-08 15:51:07	2023-02-09 11:09:06	15	1	\N	\N
699018	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Accès aux soins - Table ronde des syndicats de médecins	\N	2023-02-02 09:00:00	2023-02-02 10:35:00	\N	\N	2	0	\N	\N
699019	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Accès aux soins - Table ronde des syndicats de chirurgiens-dentistes	\N	2023-02-02 10:35:00	2023-02-02 11:30:00	\N	\N	2	0	\N	\N
699020	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Accès aux soins - Audition de la DGOS	\N	2023-02-02 11:30:00	2023-02-02 12:30:00	\N	\N	2	0	\N	\N
699021	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Entretien MM. C. FANICHET et B. SOUCHON, SNCF Voyageurs	Entretien MM. C. FANICHET et B. SOUCHON, SNCF Voyageurs	2023-02-01 16:45:00	2023-02-01 18:15:00	\N	\N	1	0	\N	\N
699023	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Accès aux soins - Audition du Conseil national de l'ordre des pédicures-podologues	\N	2023-02-02 14:00:00	2023-02-02 14:45:00	\N	\N	2	0	\N	\N
699024	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Accès aux soins - Audition de l'URPS Médecins libéraux d'Île-de-France	\N	2023-02-02 14:45:00	2023-02-02 15:30:00	\N	\N	2	0	\N	\N
699044	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Financement du cinéma : Table-ronde Auteurs-Réalisateurs	Contrôle 2023 - Financement du cinéma : Table-ronde Auteurs-Réalisateurs	2023-01-30 15:00:00	2023-01-30 16:10:00	\N	\N	1	0	\N	\N
699046	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Financement du cinéma : TR Producteurs	Contrôle 2023 - Financement du cinéma : TR Producteurs	2023-02-06 09:40:00	2023-02-06 10:30:00	\N	\N	1	0	\N	\N
699048	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions M. Olivier Rietmann	\N	2023-01-25 16:15:00	2023-01-25 19:00:00	\N	\N	2	0	\N	\N
699051	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Ministère de l'agriculture et de la souveraineté alimentaire	\N	2023-01-31 14:00:00	2023-01-31 15:00:00	\N	\N	0	0	\N	\N
699052	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition	\N	2023-01-31 14:00:00	2023-01-31 19:00:00	\N	\N	0	0	\N	\N
699054	COM_PERMANENTE	AUDRAP	\N	CAE	\N	FAO	\N	2023-01-31 17:30:00	2023-01-31 18:15:00	\N	\N	0	0	\N	\N
699055	COM_PERMANENTE	AUDRAP	\N	CAE	\N	ACTA - Réseau des instituts des filières animales et végétales	\N	2023-01-31 18:15:00	2023-01-31 19:00:00	\N	\N	0	0	\N	\N
699056	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Table ronde syndicats	\N	2023-02-01 17:00:00	2023-02-01 18:00:00	\N	\N	0	0	\N	\N
699057	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Rapporteur	\N	2023-02-01 18:00:00	2023-02-01 18:45:00	\N	\N	0	0	\N	\N
699058	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition	\N	2023-02-01 16:15:00	2023-02-01 19:30:00	\N	\N	2	0	\N	\N
720111	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI TND - Audition Haut conseil de la famille de l'enfance et de l'âge	\N	2023-03-30 14:30:00	2023-03-30 15:30:00	\N	\N	3	0	\N	\N
720112	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI TND - Aud° Féd° Française Addictologie en charge de la Coord° nationale TDAH Adultes	\N	2023-03-30 15:30:00	2023-03-30 16:30:00	\N	\N	4	0	\N	\N
720126	ETUDES	AUDRAP	\N	\N	\N	Visite de l'Arena Paris-La Défense	\N	2023-03-30 09:30:00	2023-03-30 12:00:00	\N	\N	3	0	\N	934
720130	ETUDES	DEPLACEMENT	\N	\N	\N	Déplacement Championnats du monde de ski 2023	\N	2023-02-05 18:00:00	2023-02-07 10:30:00	\N	\N	0	0	\N	934
720139	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition ARS Nouvelle-Aquitaine	\N	2023-04-03 16:00:00	2023-04-03 17:00:00	\N	\N	2	0	\N	\N
720140	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Cour des comptes	\N	2023-04-04 16:00:00	2023-04-04 17:30:00	\N	\N	1	0	\N	\N
720141	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2023-04-12 09:30:00	2023-04-12 10:00:00	2023-04-28 11:35:10	2023-04-28 11:37:06	39	0	\N	\N
720143	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Table ronde MDPH	\N	2023-04-06 09:30:00	2023-04-06 11:00:00	\N	\N	1	0	\N	\N
720276	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Verdissement concours financiers - Audition DGCL	Contrôle 2023 - Verdissement concours financiers - Audition DGCL	2023-03-30 09:00:00	2023-03-30 10:00:00	\N	\N	2	0	\N	\N
720281	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Couples confrontés à une fausse couche - Audition des associations de victimes	\N	2023-04-04 09:00:00	2023-04-04 10:00:00	\N	\N	3	0	\N	\N
720282	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Couples confrontés à une fausse couche - Audition CNGOF	\N	2023-04-04 10:00:00	2023-04-04 11:00:00	\N	\N	3	0	\N	\N
720289	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Programmes modernisation navigation aérienne - Audition DSNA	Contrôle 2023 - Programmes modernisation navigation aérienne - Audition DSNA	2023-03-28 10:15:00	2023-03-28 12:30:00	\N	\N	1	0	\N	\N
720297	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Boucliers tarifaires et amortisseurs - Audition Total Energies	\N	2023-04-03 11:00:00	2023-04-03 12:10:00	\N	\N	0	0	\N	\N
720298	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Boucliers tarifaires et amortisseurs - Audition Total Energies	Contrôle 2023 - Boucliers tarifaires et amortisseurs - Audition Total Energies	2023-04-03 11:00:00	2023-04-03 12:10:00	\N	\N	1	0	\N	\N
720339	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPLC LFCT - Audition auteur de la PPLC M.KERROUCHE	PPLC LFCT - Audition auteur de la PPLC M.KERROUCHE	2023-03-21 14:00:00	2023-03-21 15:30:00	\N	\N	2	0	\N	\N
655446	DELEGATION	AUDRAP	\N	\N	PROS	Audition de la FENARIVE	\N	2022-07-26 14:00:00	2022-07-26 15:00:00	\N	\N	2	0	\N	\N
720352	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Entretien avec la directrice des douanes (DGDDI)	Entretien avec la directrice des douanes (DGDDI)	2023-03-29 18:00:00	2023-03-29 19:00:00	\N	\N	1	0	\N	\N
720367	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 22	\N	2023-04-04 14:00:00	2023-04-04 14:10:00	2023-04-04 14:48:16	2023-04-06 17:46:18	19	3	\N	\N
720374	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Bilan financement loi ORE - Audition DGESIP	Contrôle 2023 - Bilan financement loi ORE - Audition DGESIP	2023-03-21 16:00:00	2023-03-21 17:00:00	\N	\N	1	0	\N	\N
720390	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - IRSN - Audition Cabinet ministre de la transition énergétique	Contrôle 2023 - IRSN - Audition Cabinet ministre de la transition énergétique	2023-03-21 17:00:00	2023-03-21 18:00:00	\N	\N	1	0	\N	\N
720401	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contröle 2023 - IRSN - Audition IRSN	Contröle 2023 - IRSN - Audition IRSN	2023-03-21 18:00:00	2023-03-21 19:15:00	\N	\N	1	0	\N	\N
720403	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - IRSN - Audition 3° sous-direction Direction du Budget	Contrôle 2023 - IRSN - Audition 3° sous-direction Direction du Budget	2023-03-22 16:30:00	2023-03-22 17:30:00	\N	\N	1	0	\N	\N
721396	CONF_PRES	AUCUNE	\N	\N	\N	Réunion de la Conférence des Présidents	Réunion de la Conférence des Présidents	2023-03-22 19:52:00	2023-03-22 20:17:00	\N	\N	18	0	\N	\N
722149	ETUDES	AUCUNE	\N	\N	\N	ANCM	ANCM	2023-04-05 08:00:00	2023-04-05 09:30:00	\N	\N	15	0	\N	907
722543	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	AP OTAN - rencontre avec la délégation danoise à l'Ap-OTAN 	\N	2023-04-03 11:30:00	2023-04-03 12:30:00	\N	\N	1	0	\N	\N
722547	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Organisation algorithmique du travail	Séance plénière - PPL Organisation algorithmique du travail	2023-04-06 14:50:00	2023-04-06 15:55:00	\N	\N	31	0	\N	\N
722765	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure du 28 mars 2023	Conseil de Questure du 28 mars 2023	2023-03-28 15:00:00	2023-03-28 16:30:00	\N	\N	2	0	\N	\N
723710	COM_PERMANENTE	AUTRE	\N	AFCL	\N	APLEG + AESH	\N	2023-05-03 09:30:00	2023-05-03 11:40:00	2023-05-03 12:53:18	2023-05-03 18:03:32	36	8	\N	\N
723816	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition article 13 de M. Gilles Andréani	\N	2023-04-12 10:25:00	2023-04-12 11:30:00	2023-04-12 15:53:20	2023-04-12 17:24:37	27	0	\N	\N
723862	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Syndicat des industries du médicament et du diagnostic vétérinaire	\N	2023-04-11 16:00:00	2023-04-11 17:30:00	\N	\N	2	0	\N	\N
723945	COM_EURO	AUDRAP	\N	AFEU	\N	Audition règlement Euro 7 - RPUE	\N	2023-03-16 10:00:00	2023-03-16 11:00:00	\N	\N	2	0	\N	\N
724398	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition rapporteur	\N	2023-04-11 17:45:00	2023-04-11 18:30:00	\N	\N	1	0	\N	\N
724421	ETUDES	AUCUNE	\N	\N	\N	Audition M. MORIN	Audition M. MORIN	2023-04-12 13:00:00	2023-04-12 15:00:00	\N	\N	8	0	\N	912
724721	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Permis de conduire	Proposition de loi visant à faciliter le passage et l'obtention de l'examen du permis de conduire	2023-04-12 14:00:00	2023-04-12 15:00:00	\N	\N	1	0	\N	\N
724783	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Règlement européen lutte abus sexuels - ARCOM	\N	2022-11-29 10:00:00	2022-11-29 11:00:00	\N	\N	3	0	\N	\N
724796	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Réglement lutte abus sexuels sur les mineurs - CNIL	\N	2022-11-29 16:00:00	2022-11-29 17:00:00	\N	\N	3	0	\N	\N
724809	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Réglement lutte contre abus sexuels sur les mineurs - Patrick Breyer	\N	2022-11-29 17:00:00	2022-11-29 18:00:00	\N	\N	3	0	\N	\N
724816	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Réglement lutte contra abus sexuels sur les mineurs - Min. Intérieur	\N	2022-11-29 18:00:00	2022-11-29 19:00:00	\N	\N	3	0	\N	\N
724824	MISSION	AUCUNE	\N	BIOCARBU	\N	MI BIOCARBURANTS - 12	\N	2023-04-12 17:30:00	2023-04-12 18:35:00	2023-04-12 18:35:40	2023-04-28 11:38:45	8	0	\N	\N
724948	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Commission d'indemnisation des victimes de spoliations	\N	2023-04-12 16:30:00	2023-04-12 17:45:00	\N	\N	4	0	\N	\N
724983	COM_ENQUETE	PLENIERE	\N	RENOV	\N	Table ronde Fraudes	\N	2023-04-12 17:35:00	2023-04-12 19:45:00	2023-04-13 15:52:29	2023-04-28 11:38:46	5	0	\N	\N
725525	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI LPM programme 144	MI LPM programme 144 	2023-04-11 09:00:00	2023-04-11 10:00:00	\N	\N	2	0	\N	\N
725528	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI LPM programme 144	MI LPM programme 144	2023-04-11 14:15:00	2023-04-11 15:15:00	\N	\N	2	0	\N	\N
725531	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI LPM programme 144	MI LPM programme 144	2023-04-11 15:15:00	2023-04-11 16:15:00	\N	\N	2	0	\N	\N
725534	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI LPM programme 144	MI LPM programme 144	2023-04-11 16:30:00	2023-04-11 17:30:00	\N	\N	1	0	\N	\N
725536	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI LPM programme 144	MI LPM programme 144	2023-04-13 13:30:00	2023-04-13 14:30:00	\N	\N	1	0	\N	\N
725538	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI LPM programme 129	MI LPM programme 129	2023-04-13 14:30:00	2023-04-13 15:30:00	\N	\N	2	0	\N	\N
725541	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI LPM programme 129	MI LPM programme 129	2023-04-13 15:30:00	2023-04-13 16:30:00	\N	\N	2	0	\N	\N
725551	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PPL Influenceurs	\N	2023-04-13 15:15:00	2023-04-13 16:00:00	\N	\N	3	0	\N	\N
725565	COM_ENQUETE	PLENIERE	\N	TIKTO	\N	Audition SACD	Audition SACD	2023-05-02 14:30:00	2023-05-02 15:55:00	2023-05-04 14:05:13	2023-05-04 15:53:49	8	0	\N	\N
725566	COM_ENQUETE	PLENIERE	\N	TIKTO	\N	Audition Chine Labbé 	Audition Chine Labbé 	2023-05-03 16:35:00	2023-05-03 17:40:00	2023-05-04 14:07:17	2023-05-04 15:53:44	6	0	\N	\N
725567	COM_ENQUETE	PLENIERE	\N	TIKTO	\N	Audition ISN et UFC-Que choisir	Audition ISN / UFC-Que choisir	2023-05-04 10:30:00	2023-05-04 13:05:00	2023-05-04 14:09:56	2023-05-04 15:53:42	7	0	\N	\N
725568	DELEGATION	AUDRAP	\N	\N	206	AUdition de Daniel NIZRI	\N	2023-04-17 17:05:00	2023-04-17 18:40:00	\N	\N	2	0	\N	\N
725571	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PPL Influenceurs	\N	2023-04-18 08:30:00	2023-04-18 09:00:00	\N	\N	1	0	\N	\N
725573	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PPL Influenceurs	\N	2023-04-18 09:00:00	2023-04-18 09:30:00	\N	\N	2	0	\N	\N
725576	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	\N	2023-04-18 09:30:00	2023-04-18 11:15:00	\N	\N	1	0	\N	\N
638028	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI France compétences - Audition Caisse des dépôts et consignations	\N	2022-03-01 09:45:00	2022-03-01 10:30:00	\N	\N	4	0	\N	\N
638070	COM_EURO	AUDRAP	\N	AFEU	\N	Relations stratégiques UE/Afrique - RP Bruxelles	Relations stratégiques UE/Afrique - RP Bruxelles	2022-03-01 14:15:00	2022-03-01 15:20:00	\N	\N	2	0	\N	\N
638087	COM_EURO	AUDRAP	\N	AFEU	\N	Rencontre avec les présidents de CAEU des parlements limitrophes à l'Ukraine et la Russie	Rencontre avec les présidents de CAEU des parlements limitrophes à l'Ukraine et la Russie	2022-03-01 14:30:00	2022-03-01 15:30:00	\N	\N	1	0	\N	\N
638382	QUESTURE	AUCUNE	\N	\N	\N	Réunion de Questure	Réunion de Questure	2022-03-02 09:00:00	2022-03-02 10:00:00	\N	\N	3	0	\N	\N
638398	COM_PERMANENTE	AUDRAP	\N	CDD	\N	MI Aménagement du territoire - Audition de MM. Belin et Babary	MI Aménagement du territoire - Audition de MM. Belin et Babary	2022-03-02 16:30:00	2022-03-02 17:30:00	\N	\N	2	0	\N	\N
655458	DELEGATION	AUDRAP	\N	\N	PROS	Audition de M. Lionel BRARD	\N	2022-07-27 17:30:00	2022-07-27 18:30:00	\N	\N	1	0	\N	\N
638401	COM_PERMANENTE	AUDRAP	\N	CDD	\N	MI Aménagement du territoire - Audition de MM. Belin et Babary	MI Aménagement du territoire - Audition de MM. Belin et Babary	2022-03-02 17:30:00	2022-03-02 18:30:00	\N	\N	1	0	\N	\N
638404	COM_PERMANENTE	AUDRAP	\N	CDD	\N	MI Aménagement du territoire - Audition commune	MI Aménagement du territoire - Audition commune	2022-03-03 09:00:00	2022-03-03 10:00:00	\N	\N	3	0	\N	\N
638434	GIA	AUCUNE	\N	\N	\N	Entretien avec S.E. Jorge Luis Jure ANTONETTI, ambassadeur d¿Uruguay en France	Entretien avec S.E. Jorge Luis Jure ANTONETTI, ambassadeur d¿Uruguay en France	2022-03-08 18:30:00	2022-03-08 19:45:00	\N	\N	6	0	978	\N
640946	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Auditions	\N	2022-04-05 14:30:00	2022-04-05 17:30:00	\N	\N	0	0	\N	\N
640959	DELEGATION	AUCUNE	\N	\N	PROS	Audition de la Croix Rouge	\N	2022-04-13 11:20:00	2022-04-13 12:35:00	\N	\N	10	0	\N	\N
640967	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Audition Dgesco	\N	2022-04-06 10:00:00	2022-04-06 11:00:00	\N	\N	0	0	\N	\N
640973	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - OAT vertes - CE OAT vertes/DG Trésor/S&P/SGP	Contrôle 2022 - OAT vertes - CE OAT vertes/DG Trésor/S&P/SGP	2022-04-06 14:15:00	2022-04-06 18:25:00	\N	\N	1	0	\N	\N
640975	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - FEI - CAB MIN Outre-mer	Contrôle 2022 - FEI - CAB MIN Outre-mer	2022-04-06 18:00:00	2022-04-06 19:30:00	\N	\N	2	0	\N	\N
640978	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	MCC 2022 - Audiovisuel Public - DLF	\N	2022-04-07 09:15:00	2022-04-07 10:15:00	\N	\N	0	0	\N	\N
640982	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022- IGN - IGN	Contrôle 2022- IGN - IGN	2022-04-06 09:30:00	2022-04-06 10:40:00	\N	\N	1	0	\N	\N
640984	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022- IGN - CGEFI	Contrôle 2022- IGN - CGEFI	2022-04-06 14:15:00	2022-04-06 15:20:00	\N	\N	1	0	\N	\N
640986	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022- IGN - CA IGN/Gestion PAC	Contrôle 2022- IGN - CA IGN/Gestion PAC	2022-04-07 09:30:00	2022-04-07 11:30:00	\N	\N	1	0	\N	\N
640988	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Table ronde de réseaux de prévention et de prise en charge de l'obésité pédiatrique	\N	2022-04-05 09:30:00	2022-04-05 10:45:00	\N	\N	2	0	\N	\N
640989	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Obésité - Table ronde Expérimentation "Mission : retrouve ton cap !"	\N	2022-04-05 10:45:00	2022-04-05 12:00:00	\N	\N	2	0	\N	\N
640990	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Obésité - Table ronde d'administrations centrales	\N	2022-04-05 14:00:00	2022-04-05 15:30:00	\N	\N	2	0	\N	\N
640991	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Obésité - Table ronde d'associations	\N	2022-04-05 15:45:00	2022-04-05 17:15:00	\N	\N	2	0	\N	\N
640992	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Obésité - Table ronde Applications de conseil nutritionnel	\N	2022-04-06 09:30:00	2022-04-06 10:45:00	\N	\N	3	0	\N	\N
641001	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Obésité - Audition de l'ANIA	\N	2022-04-06 14:00:00	2022-04-06 15:00:00	\N	\N	2	0	\N	\N
641007	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Cour des comptes	\N	2022-04-06 10:00:00	2022-04-06 12:00:00	\N	\N	3	0	\N	\N
641717	GIA	AUCUNE	\N	\N	\N	Rencontre Ambassadeur Palestine	Rencontre Ambassadeur Palestine	2022-04-22 09:00:00	2022-04-22 10:00:00	\N	\N	1	0	632	\N
641722	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	MI Information du consommateur	MI Information du consommateur	2022-04-19 16:15:00	2022-04-19 17:30:00	\N	\N	3	0	\N	\N
641726	GIA	AUCUNE	\N	\N	\N	Audition de Mme Myriam HOUSSAY-HOLZSCHUCH	Audition de Mme Myriam HOUSSAY-HOLZSCHUCH, enseignante-chercheuse à l'université de Grenoble	2022-03-16 14:10:00	2022-03-16 15:55:00	\N	\N	3	0	574	\N
641731	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Mission d'information sur la politique étrangère américaine	\N	2022-04-20 14:15:00	2022-04-20 15:30:00	\N	\N	2	0	\N	\N
642025	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Information du consommateur - Auditions M. Gay, Mmes Férat et Blatrix-Contat	MI Information du consommateur - Auditions M. Gay, Mmes Férat et Blatrix-Contat	2022-04-29 14:00:00	2022-04-29 19:00:00	\N	\N	3	0	\N	\N
642029	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Info du consommateur - Auditions M. Gay, Mmes Férat et Blatrix Contat	MI Info du consommateur - Auditions M. Gay, Mmes Férat et Blatrix Contat	2022-04-22 14:00:00	2022-04-22 18:45:00	\N	\N	2	0	\N	\N
642032	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions M. Fabien Gay, Mmes Françoise Férat et Florence Blatrix Contat	\N	2022-04-25 14:00:00	2022-04-25 15:15:00	\N	\N	2	0	\N	\N
642035	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Présentation rapport Darcous, Ouzoulias, Henrier	\N	2022-05-10 16:00:00	2022-05-10 17:20:00	2022-05-10 17:41:05	2022-05-11 17:34:09	24	0	\N	\N
642178	GIA	AUCUNE	\N	\N	\N	Coopé - Entretien avec une délégation de hauts fonctionnaires arméniens	Coopé - Entretien avec une délégation de hauts fonctionnaires arméniens	2022-05-06 15:10:00	2022-05-06 16:15:00	\N	\N	1	0	641	\N
643199	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI patrimoine religieux	\N	2022-05-24 14:30:00	2022-05-24 15:30:00	\N	\N	3	0	\N	\N
643209	COM_EURO	AUDRAP	\N	AFEU	\N	Audition intelligence artificielle	\N	2022-05-24 09:00:00	2022-05-24 10:00:00	\N	\N	3	0	\N	\N
644542	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - Secrétariats généraux communs - DGAFP/DAE	Contrôle 2022 - Secrétariats généraux communs - DGAFP/DAE	2022-06-07 14:00:00	2022-06-07 16:00:00	\N	\N	1	0	\N	\N
644547	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - Secrétariats généraux communs - DB	Contrôle 2022 - Secrétariats généraux communs - DB	2022-06-07 18:00:00	2022-06-07 19:30:00	\N	\N	1	0	\N	\N
644551	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - Secrétariats généraux communs - Groupement SGC	Contrôle 2022 - Secrétariats généraux communs - Groupement SGC	2022-06-08 14:00:00	2022-06-08 15:30:00	\N	\N	1	0	\N	\N
644553	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - DGCCRF - Service protection consommateur/AMF	Contrôle 2022 - DGCCRF - Service protection consommateur/AMF	2022-06-07 14:00:00	2022-06-07 16:00:00	\N	\N	2	0	\N	\N
644566	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - DGCCRF - Service soutien DGCCRF/ AAPDC	Contrôle 2022 - DGCCRF - Service soutien DGCCRF/ AAPDC	2022-06-08 09:00:00	2022-06-08 11:00:00	\N	\N	2	0	\N	\N
644569	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 14 juin 2022	\N	2022-06-14 15:20:00	2022-06-14 16:35:00	2022-06-14 18:37:01	2022-06-15 14:46:02	10	0	\N	\N
644570	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 14 juin 2022 (2)	\N	2022-06-14 16:50:00	2022-06-14 18:40:00	2022-06-14 18:42:19	2022-06-15 14:46:01	16	0	\N	\N
644572	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 15 juin 2022	Résultat final sur la COFE	2022-06-15 08:30:00	2022-06-15 09:40:00	2022-06-15 09:44:00	2022-06-15 14:46:01	11	0	\N	\N
644590	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Institut du droit local alsacien-mosellan	\N	2022-06-14 09:30:00	2022-06-14 10:30:00	\N	\N	3	0	\N	\N
644613	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition §ichel CADOT - incident stade de France	\N	2022-06-16 10:30:00	2022-06-16 12:30:00	2022-06-17 09:05:58	2022-06-17 17:53:43	28	0	\N	\N
645523	GIA	AUCUNE	\N	\N	\N	Déplacement d'une délégation du groupe en Argentine	Déplacement d'une délégation du groupe en Argentine	2022-06-22 11:30:00	2022-07-01 10:00:00	\N	\N	4	0	978	\N
645528	GIA	AUCUNE	\N	\N	\N	Recontre avec des représentants de l¿International Center for Ukrainian Victory  (ICUV)	Recontre avec des représentants de l¿International Center for Ukrainian Victory  (ICUV)	2022-05-09 09:00:00	2022-05-09 10:00:00	\N	\N	4	0	530	\N
651646	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI  Méditerranée	RI Méditerranée	2022-07-19 15:30:00	2022-07-19 16:30:00	\N	\N	1	0	\N	\N
655449	DELEGATION	AUDRAP	\N	\N	PROS	Audition Cercle français de l'eau	\N	2022-07-26 15:00:00	2022-07-26 16:00:00	\N	\N	3	0	\N	\N
716502	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2023-03-22 15:00:00	2023-03-22 16:15:00	\N	\N	261	0	\N	\N
716503	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Cour des comptes	Débat Cour des comptes	2023-03-22 16:35:00	2023-03-22 18:45:00	\N	\N	86	0	\N	\N
716548	COM_ENQUETE	PLENIERE	\N	TIKTO	\N	Audition IRSEM	Audition IRSEM	2023-03-20 17:00:00	2023-03-20 18:50:00	2023-03-21 09:30:17	2023-03-21 10:21:20	6	0	\N	\N
716686	COM_PERMANENTE	AUTRE	\N	CAE	\N	Examen amendements CMP Egalim 3	\N	2023-03-21 14:15:00	2023-03-21 14:20:00	2023-03-21 14:34:03	2023-03-21 16:36:44	27	2	\N	\N
716703	ETUDES	AUDRAP	\N	\N	\N	numérique	\N	2023-03-21 09:30:00	2023-03-21 11:00:00	\N	\N	9	0	\N	1008
716725	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Ecole liberté	\N	2023-03-16 13:30:00	2023-03-16 16:30:00	\N	\N	6	0	\N	\N
716730	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 16	\N	2023-03-21 14:30:00	2023-03-21 16:00:00	2023-03-21 16:34:44	2023-03-21 16:36:45	22	0	\N	\N
716750	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE-17	\N	2023-03-22 08:30:00	2023-03-22 09:20:00	2023-03-22 14:26:44	2023-03-22 15:24:35	24	0	\N	\N
717060	MISSION	AUCUNE	\N	BATI	\N	MIBS	\N	2023-03-28 16:30:00	2023-03-28 18:00:00	2023-03-29 11:18:34	2023-03-29 17:18:58	8	0	\N	\N
717078	MISSION	AUCUNE	\N	BATI	\N	Table ronde  associations d¿élus représentant l¿échelon municipal	\N	2023-03-30 10:45:00	2023-03-30 12:00:00	\N	\N	2	0	\N	\N
717237	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	expertise patrimoniale	\N	2023-03-21 09:30:00	2023-03-21 11:00:00	\N	\N	3	0	\N	\N
717243	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI cinéma	\N	2023-03-21 17:30:00	2023-03-21 19:00:00	\N	\N	3	0	\N	\N
718372	COM_ENQUETE	PLENIERE	\N	MEDIC	\N	Réunion plénière	\N	2023-03-28 13:35:00	2023-03-28 15:10:00	2023-03-28 15:35:59	2023-03-29 17:19:01	6	0	\N	\N
718374	COM_ENQUETE	PLENIERE	\N	MEDIC	\N	Réunion plénière	\N	2023-03-29 13:35:00	2023-03-29 15:00:00	2023-03-29 15:29:53	2023-03-29 17:18:56	6	0	\N	\N
718375	COM_ENQUETE	PLENIERE	\N	MEDIC	\N	Réunion plénière	\N	2023-03-29 16:30:00	2023-03-29 18:00:00	2023-03-29 18:25:18	2023-03-30 11:54:18	7	0	\N	\N
718393	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-03-29 09:30:00	2023-03-29 11:55:00	2023-03-29 13:04:18	2023-03-29 17:17:26	39	0	\N	\N
718399	DELEGATION	AUCUNE	\N	\N	DSOM	Parentalité outre-mer : table ronde collectivités du Pacifique	\N	2023-04-04 08:00:00	2023-04-04 10:30:00	\N	\N	8	0	\N	\N
718481	GIA	AUCUNE	\N	\N	\N	Dîner avec les ambassadeurs d'Asie du Sud-Est	\N	2023-03-14 19:30:00	2023-03-14 21:30:00	\N	\N	18	0	609	\N
718500	GIA	AUCUNE	\N	\N	\N	Conférence des intellectuels sur l'Arménie et le Haut-Karabagh	Conférence de presse à l'invitation conjointe du GIA Arménie	2023-03-16 09:00:00	2023-03-16 11:30:00	\N	\N	7	0	1013	\N
718509	GIA	AUCUNE	\N	\N	\N	Conférence des intellectuels sur l'Arménie et le Haut-Karabagh	Conférence de presse à l'invitation conjointe du GII Haut-Karabagh	2023-03-16 09:00:00	2023-03-16 11:30:00	\N	\N	8	0	641	\N
718518	GIA	AUCUNE	\N	\N	\N	Conférence "Parrainages de prisonniers politiques biélorusses"	Parrainage par plusieurs sénateurs de prisonniers politiques biélorusses	2023-03-21 18:00:00	2023-03-21 20:30:00	\N	\N	18	0	852	\N
718538	GIA	AUCUNE	\N	\N	\N	Réunion de travail en préparation de l'accueil de la délégation de l'AN arménienne 	Réunion de travail 	2023-03-21 14:30:00	2023-03-21 15:20:00	\N	\N	1	0	641	\N
718726	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Français de l'étranger	MI Français de l'étranger	2023-03-24 11:45:00	2023-03-24 13:00:00	\N	\N	2	0	\N	\N
718729	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Français de l'étranger	MI Français de l'étranger	2023-03-24 15:00:00	2023-03-24 16:00:00	\N	\N	2	0	\N	\N
718745	GIA	AUCUNE	\N	\N	\N	Lancement du club "Midcaps Europa" à l'ambassade de Pologne	Lancement du club "Midcaps Europa" à l'ambassade de Pologne	2023-03-24 09:30:00	2023-03-24 12:30:00	\N	\N	1	0	600	\N
718845	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents 	Conférence des Présidents 	2023-03-10 14:00:00	2023-03-10 14:30:00	\N	\N	19	0	\N	\N
718849	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF 2024 - Prévention des risques	\N	2023-03-21 15:00:00	2023-03-21 16:00:00	\N	\N	8	0	\N	\N
718858	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition ASN	\N	2023-03-21 17:00:00	2023-03-21 17:30:00	\N	\N	6	0	\N	\N
718881	MISSION	AUCUNE	\N	GEAU	\N	Audition AdCF	\N	2023-03-28 16:20:00	2023-03-28 17:20:00	2023-03-28 17:22:57	2023-03-29 17:18:58	3	0	\N	\N
718888	MISSION	AUCUNE	\N	GEAU	\N	Table ronde autour des acteurs de l¿hydroélectricité 	\N	2023-03-30 11:00:00	2023-03-30 12:30:00	2023-03-30 12:31:12	2023-03-30 17:25:44	6	0	\N	\N
718916	COM_ENQUETE	AUDRAP	\N	MEDIC	\N	CE Pénurie de médicaments - Table ronde de journalistes d'investigation	\N	2023-03-28 09:00:00	2023-03-28 10:20:00	\N	\N	7	0	\N	\N
718924	MISSION	AUDRAP	\N	LOCA	\N	Table ronde - Villes de France et intercommunalités de France	\N	2023-03-28 16:00:00	2023-03-28 17:30:00	\N	\N	8	0	\N	\N
718925	COM_PERMANENTE	DEPLACEMENT	\N	SOCI	\N	MI Fin de vie - Déplacement à Bruxelles et Liège	\N	2023-03-27 07:55:00	2023-03-27 20:05:00	\N	\N	4	0	\N	\N
718959	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI LPM programme 144	MI LPM programme 144	2023-03-21 15:40:00	2023-03-21 17:15:00	\N	\N	3	0	\N	\N
718963	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI LPM programme 144	MI LPM programme 144	2023-03-21 15:50:00	2023-03-21 17:05:00	\N	\N	1	0	\N	\N
718970	COM_ENQUETE	AUTRE	\N	TIKTO	\N	Audition SGDSN	\N	2023-03-28 16:30:00	2023-03-28 18:15:00	2023-03-30 17:00:53	2023-03-30 17:25:43	11	0	\N	\N
718990	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Sociologue	\N	2023-03-28 14:30:00	2023-03-28 15:30:00	\N	\N	1	0	\N	\N
718991	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Ecole de management de Normandie	\N	2023-03-28 15:30:00	2023-03-28 16:30:00	\N	\N	1	0	\N	\N
718994	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Mission "Culture" - Genèse Pass Culture Audition C. DANION	Contrôle 2023 - Mission "Culture" - Genèse Pass Culture Audition C. DANION	2023-03-20 14:35:00	2023-03-20 16:00:00	\N	\N	2	0	\N	\N
719008	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL EDF - Audition Henri PROGLIO ancien pdg EDF	PPL EDF - Audition Henri PROGLIO ancien pdg EDF	2023-03-22 11:30:00	2023-03-22 12:30:00	\N	\N	1	0	\N	\N
719012	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL EDF - Audition L. VIGNAUD (CPME)	PPL EDF - Audition L. VIGNAUD (CPME)	2023-03-23 10:00:00	2023-03-23 11:00:00	\N	\N	1	0	\N	\N
719014	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL EDF - Audition N. IDIR (ANODE)	PPL EDF - Audition N. IDIR (ANODE)	2023-03-23 11:00:00	2023-03-23 12:00:00	\N	\N	1	0	\N	\N
719016	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL EDF - Audition G. LECERF (AFIEG)	PPL EDF - Audition G. LECERF (AFIEG)	2023-03-23 14:30:00	2023-03-23 15:30:00	\N	\N	1	0	\N	\N
718395	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-03-29 12:00:00	2023-03-29 12:36:00	2023-03-29 13:05:26	2023-03-29 17:17:25	39	0	\N	\N
719018	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL EDF - Audition C. STOFFAES (Association des ingémieurs du Coprs des Mines)	PPL EDF - Audition C. STOFFAES (Association des ingémieurs du Coprs des Mines)	2023-03-23 15:30:00	2023-03-23 16:30:00	\N	\N	1	0	\N	\N
719020	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL EDF - Audition L. MICHEL (DGEC)	PPL EDF - Audition L. MICHEL (DGEC)	2023-03-25 21:15:00	2023-03-25 22:00:00	\N	\N	1	0	\N	\N
719022	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL EDF - Audition E. WARGON (CRE)	PPL EDF - Audition E. WARGON (CRE)	2023-03-24 10:00:00	2023-03-24 10:40:00	\N	\N	1	0	\N	\N
719024	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI autonomie ES	\N	2023-03-28 14:00:00	2023-03-28 15:00:00	\N	\N	4	0	\N	\N
719029	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	cinéma M6	\N	2023-03-28 16:00:00	2023-03-28 17:00:00	\N	\N	3	0	\N	\N
719035	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2023-04-05 09:30:00	2023-04-05 12:30:00	2023-04-12 16:17:08	2023-04-12 17:11:41	34	0	\N	\N
719036	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 18	\N	2023-03-29 09:00:00	2023-03-29 09:03:00	\N	\N	0	0	\N	\N
719037	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 21	\N	2023-03-29 09:00:00	2023-03-29 09:05:00	\N	\N	26	3	\N	\N
719211	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions Mme Patricia Demas	Auditions Mme Patricia Demas	2023-03-28 14:00:00	2023-03-28 17:00:00	\N	\N	1	0	\N	\N
719215	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions Mme Patricia Demas	Auditions Mme Patricia Demas	2023-03-28 17:15:00	2023-03-28 18:15:00	\N	\N	2	0	\N	\N
719278	MISSION	AUDRAP	\N	BIOCARBU	\N	SGAE	SGAE	2023-02-15 17:00:00	2023-02-15 18:00:00	\N	\N	6	0	\N	\N
719328	MISSION	AUDRAP	\N	BIOCARBU	\N	DGAC	DGAC	2023-03-07 10:00:00	2023-03-07 11:00:00	\N	\N	3	0	\N	\N
719341	MISSION	AUDRAP	\N	BIOCARBU	\N	Académie de l'air et de l'espace	Académie de l'air et de l'espace	2023-03-14 10:00:00	2023-03-14 11:00:00	\N	\N	2	0	\N	\N
638441	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 9 mars 2022	\N	2022-03-09 16:00:00	2022-03-09 17:40:00	2022-03-10 15:25:23	2022-03-10 16:19:07	10	0	\N	\N
638442	MISSION	AUDRAP	\N	RECHINNO	\N	Auditions de la rapporteur	Auditions de la rapporteur	2022-03-01 14:30:00	2022-03-01 17:30:00	\N	\N	3	0	\N	\N
638443	MISSION	AUCUNE	\N	RECHINNO	\N	Audition plénière - Institut Pasteur	Audition plénière - Institut Pasteur	2022-03-01 17:30:00	2022-03-01 18:30:00	2022-03-04 14:57:58	2022-03-07 16:17:42	2	0	\N	\N
638444	MISSION	AUCUNE	\N	RECHINNO	\N	Auditions plénières - Inserm / TR MEDEF - CPME	Auditions plénières - Inserm / TR MEDEF - CPME	2022-03-02 09:30:00	2022-03-02 12:10:00	2022-03-04 14:59:27	2022-03-07 16:17:42	5	0	\N	\N
638445	COM_PERMANENTE	AUTRE	\N	FINC	\N	Contrôles budgétaires : ENAP et SNCF - Audition 58-2 M. Pierre MOSCOVICI : Plan de relance	Contrôles budgétaires : ENAP et SNCF - Audition 58-2 M. Pierre MOSCOVICI : Crédits du plan de relance	2022-03-09 09:00:00	2022-03-09 12:20:00	2022-03-09 13:42:08	2022-03-09 18:04:49	30	1	\N	\N
638446	MISSION	DEPLACEMENT	\N	JUDI	\N	Déplacement à la Cour de cassation	Déplacement à la Cour de cassation	2022-03-03 14:15:00	2022-03-03 17:30:00	\N	\N	5	0	\N	\N
638463	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Auditions de Gérald Darmanin et de Julien Boucher (guerre Ukraine et accueil réfugiés)	Auditions de Gérald Darmanin et de Julien Boucher (guerre Ukraine et accueil réfugiés)	2022-03-08 17:05:00	2022-03-08 18:50:00	2022-03-09 11:41:04	2022-03-09 18:04:49	33	0	\N	\N
638464	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 8 mars 2022	\N	2022-03-08 17:05:00	2022-03-08 18:50:00	2022-03-08 18:58:38	2022-03-09 18:05:08	33	0	\N	\N
639927	MISSION	AUCUNE	\N	RECHINNO	\N	French Tech	French Tech	2022-03-23 14:00:00	2022-03-23 15:00:00	2022-03-23 15:26:29	2022-03-24 15:07:49	4	0	\N	\N
639934	MISSION	AUCUNE	\N	RECHINNO	\N	Auditions plénières	Auditions plénières	2022-03-23 09:00:00	2022-03-23 12:30:00	2022-03-23 15:29:34	2022-03-24 15:07:48	6	0	\N	\N
639941	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-03-30 16:30:00	2022-03-30 17:30:00	2022-03-30 18:11:19	2022-03-31 16:41:54	6	0	\N	\N
639942	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-03-30 09:00:00	2022-03-30 13:00:00	2022-03-30 14:32:10	2022-03-30 17:22:23	28	0	\N	\N
639943	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-03-29 15:30:00	2022-03-29 16:50:00	2022-03-29 17:07:49	2022-03-30 17:22:24	27	0	\N	\N
639944	COM_PERMANENTE	AUTRE	\N	FINC	\N	Décret d'avance : Audition de M. Olivier DUSSOPT, ministre  et désignation Rapporteur H3C	Décret d'avance : Audition de M. Olivier DUSSOPT, ministre  et désignation Rapporteur H3C	2022-03-30 17:00:00	2022-03-30 18:00:00	2022-03-30 18:26:30	2022-03-31 16:41:55	21	0	\N	\N
639945	COM_PERMANENTE	AUTRE	\N	FINC	\N	Décret d'avance : Communication RG et avis commission et Audition Article 13 H3C	Décret d'avance : Communication RG et avis commission et Audition Article 13 H3C	2022-03-31 09:35:00	2022-03-31 11:45:00	2022-03-31 13:02:56	2022-03-31 16:41:56	24	3	\N	\N
640055	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT subsidiarité	GT subsidiarité	2022-03-23 14:30:00	2022-03-23 14:40:00	\N	\N	2	0	\N	\N
641026	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	MCC 2022 - Audiovisuel Public - DLF	\N	2022-04-07 09:15:00	2022-04-07 10:15:00	\N	\N	0	0	\N	\N
641027	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 12 avril 2022	Réunion du 12 avril 2022	2022-04-12 16:30:00	2022-04-12 17:55:00	2022-04-14 10:23:06	2022-04-14 15:13:18	18	0	\N	\N
641031	DELEGATION	AUDRAP	\N	\N	206	Audition M. UMLIL	\N	2022-04-08 09:00:00	2022-04-08 10:10:00	\N	\N	3	0	\N	\N
641035	DELEGATION	AUDRAP	\N	\N	206	Audition Université Aix-Marseille	\N	2022-04-08 10:10:00	2022-04-08 11:10:00	\N	\N	3	0	\N	\N
641039	DELEGATION	AUDRAP	\N	\N	206	Audition HAS	\N	2022-04-08 11:10:00	2022-04-08 12:20:00	\N	\N	3	0	\N	\N
641043	DELEGATION	AUDRAP	\N	\N	206	Audition ONIAM	\N	2022-04-07 09:30:00	2022-04-07 10:35:00	\N	\N	3	0	\N	\N
641047	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Fischer	\N	2022-04-07 10:35:00	2022-04-07 11:35:00	\N	\N	3	0	\N	\N
641051	DELEGATION	AUDRAP	\N	\N	206	Audition Mme Saulnier	\N	2022-04-07 11:35:00	2022-04-07 12:45:00	\N	\N	3	0	\N	\N
641055	DELEGATION	AUDRAP	\N	\N	206	Audition EPI-PHARE	\N	2022-04-06 09:30:00	2022-04-06 10:40:00	\N	\N	3	0	\N	\N
641059	DELEGATION	AUDRAP	\N	\N	206	Audition Association et collectifs	\N	2022-04-06 10:40:00	2022-04-06 12:45:00	\N	\N	3	0	\N	\N
641831	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI SPIP	MI SPIP - Auditions	2022-04-26 15:30:00	2022-04-26 18:00:00	\N	\N	3	0	\N	\N
641835	GIA	AUCUNE	\N	\N	\N	Coopé  Entretien avec Mme Mine ATLI	Coopé  Entretien avec Mme Mine ATLI	2022-04-26 14:15:00	2022-04-26 15:30:00	\N	\N	1	0	585	\N
641856	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT subsidiarité	GT subsidiarité	2022-04-27 09:00:00	2022-04-27 09:10:00	\N	\N	2	0	\N	\N
641868	MISSION	AUTRE	\N	RECHINNO	\N	Présidente Paris-Saclay	\N	2022-04-28 08:00:00	2022-04-28 09:20:00	2022-04-28 10:28:27	2022-04-28 15:10:20	5	0	\N	\N
641899	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Énergie et hydrogène nucléaires	MI Énergie et hydrogène nucléaires	2022-04-26 09:45:00	2022-04-26 11:00:00	\N	\N	4	0	\N	\N
719208	COM_PERMANENTE	AUTRE	\N	AFCL	\N	PPL ticket restau + PPL école de la liberté	\N	2023-04-05 09:30:00	2023-04-05 11:30:00	2023-04-05 12:20:22	2023-04-06 17:46:21	47	1	\N	\N
641906	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Énergie et hydrogène nucléaires	MI Énergie et hydrogène nucléaires	2022-04-26 14:00:00	2022-04-26 14:45:00	\N	\N	3	0	\N	\N
641916	MECSS	AUDRAP	\N	\N	MECSS	MI Unification du recouvrement - Audition CRPCEN	\N	2022-04-27 15:30:00	2022-04-27 16:15:00	\N	\N	3	0	\N	\N
641917	MECSS	AUDRAP	\N	\N	MECSS	MI Unification du recouvrement - Audition ASDDS	\N	2022-04-27 16:15:00	2022-04-27 17:00:00	\N	\N	3	0	\N	\N
641937	MECSS	AUDRAP	\N	\N	MECSS	MI Unification du recouvrement - Audition CPSTI	\N	2022-04-27 17:00:00	2022-04-27 18:00:00	\N	\N	2	0	\N	\N
641946	MISSION	AUCUNE	\N	RECHINNO	\N	Réunion de cadrage	\N	2022-04-28 13:30:00	2022-04-28 14:10:00	\N	\N	5	0	\N	\N
641968	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition M. Cohen	\N	2022-04-28 09:00:00	2022-04-28 10:00:00	\N	\N	4	0	\N	\N
642173	COM_EURO	AUDRAP	\N	AFEU	\N	Devoir de vigilance	\N	2022-05-03 11:00:00	2022-05-03 12:00:00	\N	\N	3	0	\N	\N
643333	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Ehpad - Audition UNCASS	\N	2022-05-25 09:00:00	2022-05-25 10:00:00	\N	\N	7	0	\N	\N
643347	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition MI Ehpad - Audition Observatoire du Grand Age	\N	2022-05-25 11:00:00	2022-05-25 12:00:00	\N	\N	5	0	\N	\N
643725	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Ambassade d'Allemagne	Audition Ambassade d'Allemagne	2022-06-01 09:30:00	2022-06-01 10:15:00	\N	\N	6	0	\N	\N
643726	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Hynamics	Audition Hynamics	2022-06-01 10:15:00	2022-06-01 11:00:00	\N	\N	6	0	\N	\N
643727	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Groupement des industriels français de l'énergie nucléaire	Audition Groupement des industriels français de l'énergie nucléaire	2022-06-01 11:00:00	2022-06-01 11:30:00	\N	\N	5	0	\N	\N
643745	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur MI Ehpad - Audition FNAAS	\N	2022-06-08 09:00:00	2022-06-08 09:50:00	\N	\N	3	0	\N	\N
643746	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Ehpad - Audition de DGCS	\N	2022-06-08 14:30:00	2022-06-08 16:00:00	\N	\N	7	0	\N	\N
643747	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Ehpad - Audition de la DGOS	\N	2022-06-08 17:00:00	2022-06-08 18:00:00	\N	\N	3	0	\N	\N
643748	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	MCC 2022 - Audiovisuel Public - France Médias monde	\N	2022-06-03 10:30:00	2022-06-03 11:40:00	\N	\N	0	0	\N	\N
643752	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	MCC 2022 - Audiovisuel Public - TV5 Monde	\N	2022-06-03 14:10:00	2022-06-03 14:55:00	\N	\N	0	0	\N	\N
643759	MISSION	AUCUNE	\N	CULTURE	\N	Réunion 20220607	\N	2022-06-07 17:05:00	2022-06-07 18:00:00	2022-06-07 18:02:09	2022-06-07 19:44:35	12	2	\N	\N
643760	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Ferme France - Auditions MM. Duplomb, Louault et Mérillou	MI Ferme France - Auditions MM. Duplomb, Louault et Mérillou	2022-05-31 10:00:00	2022-05-31 12:30:00	\N	\N	3	0	\N	\N
643764	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Ferme France - Auditions MM. Laurent Duplomb, Pierre Louault et Serge Merillou	MI Ferme France - Auditions MM. Laurent Duplomb, Pierre Louault et Serge Merillou	2022-05-31 14:00:00	2022-05-31 18:30:00	\N	\N	3	0	\N	\N
643768	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Ferme France - Auditions MM. Laurent Duplomb, Pierre Louault et Serge Merillou	MI Ferme France - Auditions MM. Laurent Duplomb, Pierre Louault et Serge Merillou	2022-06-01 09:00:00	2022-06-01 12:30:00	\N	\N	3	0	\N	\N
643772	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Ferme France - Auditions MM. Laurent Duplomb, Pierre Louault et Serge Merillou	MI Ferme France - Auditions MM. Laurent Duplomb, Pierre Louault et Serge Merillou	2022-06-01 13:30:00	2022-06-01 19:00:00	\N	\N	3	0	\N	\N
643776	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Ferme France - Auditions MM. Laurent Duplomb, Pierre Louault et Serge Merillou	MI Ferme France - Auditions MM. Laurent Duplomb, Pierre Louault et Serge Merillou	2022-06-02 09:00:00	2022-06-02 12:30:00	\N	\N	3	0	\N	\N
725581	MISSION	AUDRAP	\N	GEAU	\N	Ministère de la transition écologique et solidaire	\N	2023-04-18 15:30:00	2023-04-18 16:45:00	\N	\N	1	0	\N	\N
725583	MISSION	AUDRAP	\N	GEAU	\N	AMRF	\N	2023-04-18 16:45:00	2023-04-18 18:10:00	\N	\N	1	0	\N	\N
725600	GIA	AUCUNE	\N	\N	\N	accueil d'une délégation de la mairie de Yongcheon	\N	2023-04-19 08:30:00	2023-04-19 10:00:00	\N	\N	2	0	613	\N
725603	GIA	AUCUNE	\N	\N	\N	entretien avec S.E. M. Ali bin Jasem AL THANI, ambassadeur du Qatar	\N	2023-04-19 11:00:00	2023-04-19 12:00:00	\N	\N	1	0	661	\N
725638	COM_ENQUETE	PLENIERE	\N	TIKTO	\N	Audition Tariq Krim	Audition Tariq Krim	2023-05-03 13:45:00	2023-05-03 14:50:00	2023-05-04 14:06:14	2023-05-04 15:53:47	7	0	\N	\N
725685	DELEGATION	AUDRAP	\N	\N	206	Audition Recyclage du plastique	\N	2023-04-18 14:00:00	2023-04-18 17:00:00	\N	\N	2	0	\N	\N
725688	DELEGATION	AUDRAP	\N	\N	206	Auditions Recyclage du plastique	\N	2023-04-20 14:00:00	2023-04-20 18:30:00	\N	\N	2	0	\N	\N
725691	QUESTURE	AUCUNE	\N	\N	\N	Réunion de Questure	Réunion de Questure	2023-04-11 14:00:00	2023-04-11 16:37:00	\N	\N	3	0	\N	\N
725696	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de M. Sébastien Lecornu	Audition de M. Sébastien Lecornu	2023-05-03 16:30:00	2023-05-03 18:00:00	2023-05-05 16:03:49	2023-05-05 18:04:40	29	0	\N	\N
725697	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Agence européenne du médicament - Commission européenne	\N	2023-04-20 14:00:00	2023-04-20 15:10:00	\N	\N	2	0	\N	\N
725786	GIA	AUCUNE	\N	\N	\N	Dîner  des groupes d'amitié du Sénat et de l'AN à l' Ambassade de Suisse mardi 6 juin 2023	Dîner  des groupes d'amitié du Sénat et de l'AN à l' Ambassade de Suisse mardi 6 juin 2023	2023-06-06 19:30:00	2023-06-06 21:30:00	\N	\N	9	0	610	\N
725805	COM_ENQUETE	PLENIERE	\N	MEDIC	\N	Audition plénière	\N	2023-05-02 09:00:00	2023-05-02 10:10:00	2023-05-02 10:11:40	2023-05-02 18:05:28	7	0	\N	\N
725806	COM_ENQUETE	PLENIERE	\N	MEDIC	\N	Audition plénière	\N	2023-05-02 13:40:00	2023-05-02 19:10:00	2023-05-02 19:35:08	2023-05-03 18:04:23	13	0	\N	\N
725807	COM_ENQUETE	PLENIERE	\N	MEDIC	\N	Audition de Mme Laure Lechertier	\N	2023-05-03 13:40:00	2023-05-03 14:50:00	2023-05-04 15:53:53	2023-05-04 15:53:59	9	0	\N	\N
725808	COM_ENQUETE	PLENIERE	\N	MEDIC	\N	Audition de M. Marc Botenga	\N	2023-05-03 16:35:00	2023-05-03 17:35:00	2023-05-03 17:52:14	2023-05-03 18:04:20	11	0	\N	\N
725809	COM_ENQUETE	PLENIERE	\N	MEDIC	\N	Audition de M. Michel Rao	\N	2023-05-04 11:05:00	2023-05-04 12:25:00	2023-05-04 14:44:38	2023-05-04 15:53:42	3	0	\N	\N
725810	DELEGATION	AUTRE	\N	\N	DSOM	Parentalité outre-mer : tables rondes Guyane et Saint-Pierre-et-Miquelon	\N	2023-05-04 14:00:00	2023-05-04 16:00:00	\N	\N	6	0	\N	\N
725811	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 4 mai 2023	\N	2023-05-04 09:00:00	2023-05-04 09:40:00	2023-05-04 10:50:57	2023-05-04 15:52:18	10	0	\N	\N
725869	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Développement hydrogène	Débat Développement hydrogène	2023-05-02 14:30:00	2023-05-02 15:55:00	\N	\N	73	0	\N	\N
725870	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Fibre optique	PPL Fibre optique	2023-05-02 16:00:00	2023-05-02 18:10:00	\N	\N	85	0	\N	\N
725871	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Fraudes fiscales	Débat Fraudes fiscales	2023-05-02 18:45:00	2023-05-02 20:25:00	\N	\N	37	0	\N	\N
725874	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2023-05-03 15:00:00	2023-05-03 16:20:00	\N	\N	291	0	\N	\N
725875	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Accessibilité et inclusion bancaires	PPL Accessibilité et inclusion bancaires	2023-05-03 16:30:00	2023-05-03 18:50:00	\N	\N	80	0	\N	\N
725878	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Précarité énergétique	PPL Précarité énergétique	2023-05-03 18:30:00	2023-05-03 20:20:00	\N	\N	64	0	\N	\N
725879	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Programme de stabilité	Débat Programme de stabilité	2023-05-03 21:50:00	2023-05-03 23:45:00	\N	\N	28	0	\N	\N
725880	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Retour enfants ukrainiens	Débat Retour enfants ukrainiens	2023-05-04 10:30:00	2023-05-04 11:55:00	\N	\N	34	0	\N	\N
725881	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Couples confrontés à une fausse couche	PPL Couples confrontés à une fausse couche	2023-05-04 11:55:00	2023-05-04 13:00:00	\N	\N	21	0	\N	\N
726206	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2023 - EPF/EPA - Déplacement M. BLANC Montpellier/Nîmes	\N	2023-06-02 09:00:00	2023-06-02 18:00:00	\N	\N	0	0	\N	\N
726235	MISSION	AUDRAP	\N	GEAU	\N	Audition de la FENARIVE	\N	2023-05-02 15:00:00	2023-05-02 16:15:00	\N	\N	7	0	\N	\N
726237	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2023 - Sécurité civile - Déplacement BASC Nîmes	\N	2023-05-23 08:00:00	2023-05-23 22:00:00	\N	\N	0	0	\N	\N
726248	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Déplacement Président EEX AG à Paris	\N	2023-06-06 15:00:00	2023-06-06 18:00:00	\N	\N	0	0	\N	\N
726250	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2023 - Déplacement Nexter à Versailles	Contrôle 2023 - Déplacement Nexter à Versailles	2023-03-28 09:45:00	2023-03-28 14:00:00	\N	\N	1	0	\N	\N
726267	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PPL Influenceurs	Audition PPL Influenceurs	2023-05-02 10:00:00	2023-05-02 10:45:00	\N	\N	1	0	\N	\N
726270	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition	\N	2023-05-02 15:15:00	2023-05-02 16:00:00	\N	\N	0	0	\N	\N
726272	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition	\N	2023-05-02 15:15:00	2023-05-02 16:00:00	\N	\N	2	0	\N	\N
726277	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2023-05-10 10:30:00	2023-05-10 11:30:00	2023-05-10 13:58:18	2023-05-10 15:28:46	36	0	\N	\N
726283	MISSION	AUCUNE	\N	BIOCARBU	\N	MI BIOCARBURANTS - 13	\N	2023-05-02 18:15:00	2023-05-02 19:35:00	2023-05-02 19:35:35	2023-05-03 18:04:22	7	0	\N	\N
726284	MISSION	AUCUNE	\N	BIOCARBU	\N	MI BIOCARBURANTS - 14	\N	2023-05-03 18:00:00	2023-05-03 19:15:00	2023-05-03 19:17:23	2023-05-04 15:53:43	12	0	\N	\N
726798	GIA	AUCUNE	\N	\N	\N	Réunion du groupe d'amitié France-Pays de la Corne de l'Afrique 	Réunion du groupe d'amitié France-Pays de la Corne de l'Afrique	2023-05-03 14:00:00	2023-05-03 14:15:00	\N	\N	2	0	588	\N
727938	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL emploi des conjoints des agents des missions officielles	PJL emploi des conjoints des agents des missions officielles	2023-05-04 09:30:00	2023-05-04 10:05:00	\N	\N	1	0	\N	\N
728178	COM_ENQUETE	PLENIERE	\N	TIKTO	\N	Audition observatoire de la parentalité et de l'éducation numérique	Audition observatoire de la parentalité et de l'éducation numérique	2023-05-11 10:45:00	2023-05-11 12:15:00	2023-05-11 14:55:44	2023-05-11 16:17:31	8	0	\N	\N
728787	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Biens	\N	2023-05-09 16:00:00	2023-05-09 17:00:00	\N	\N	4	0	\N	\N
728796	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Biens	\N	2023-05-09 17:00:00	2023-05-09 18:00:00	\N	\N	4	0	\N	\N
729578	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation de  la commission de la culture du Sénat indonésien	Accueil d'une délégation de  la commission de la culture du Sénat indonésien	2023-03-20 10:00:00	2023-03-20 14:00:00	\N	\N	2	0	653	\N
729581	GIA	AUCUNE	\N	\N	\N	Déplacement en Indonésie	\N	2023-04-16 07:00:00	2023-04-24 13:00:00	\N	\N	3	0	653	\N
729587	GIA	AUCUNE	\N	\N	\N	Accueil Ministre de l'Education, de la Culture	Accueil Ministre indonésien de l'Education, de la culture, de la recherche et des technologies	2023-05-16 16:00:00	2023-05-16 18:00:00	\N	\N	0	0	653	\N
730319	COM_PERMANENTE	AUTRE	\N	AFCL	\N	JOP + biens spoliés	\N	2023-05-17 10:30:00	2023-05-17 11:30:00	2023-05-17 15:56:08	2023-05-19 16:15:24	40	2	\N	\N
730340	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI patrimoine transition éco	\N	2023-05-10 17:00:00	2023-05-10 18:00:00	\N	\N	2	0	\N	\N
730341	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI autonomie	\N	2023-05-10 13:45:00	2023-05-10 14:45:00	\N	\N	3	0	\N	\N
730350	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL bourse	\N	2023-05-10 16:30:00	2023-05-10 18:10:00	\N	\N	2	0	\N	\N
730476	DELEGATION	AUDRAP	\N	\N	206	Audition recyclage du plastique	\N	2023-05-09 16:00:00	2023-05-09 18:00:00	\N	\N	2	0	\N	\N
730479	DELEGATION	AUDRAP	\N	\N	206	Audition recyclage du plastique	\N	2023-05-10 16:30:00	2023-05-10 18:30:00	\N	\N	2	0	\N	\N
730491	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes	\N	2023-05-17 14:00:00	2023-05-17 14:55:00	2023-05-17 15:21:53	2023-05-17 15:57:26	23	0	\N	\N
730498	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	Réunion	Réunion	2023-05-02 16:00:00	2023-05-02 16:50:00	2023-05-11 11:29:45	\N	4	0	\N	\N
730507	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	Audition	Audition	2023-05-09 15:15:00	2023-05-09 17:30:00	2023-05-11 11:32:18	2023-05-11 16:17:26	8	0	\N	\N
730516	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	Audition	Audition	2023-05-10 16:30:00	2023-05-10 18:20:00	2023-05-11 11:34:31	2023-05-11 16:17:27	8	0	\N	\N
638425	GIA	AUCUNE	\N	\N	\N	Audition de Mme Michèle RAMIS, directrice des amériques et des caraïbes 	Audition de Mme Michèle RAMIS, directrice des amériques et des caraïbes 	2022-03-03 08:15:00	2022-03-03 10:15:00	\N	\N	8	0	590	\N
639012	MISSION	AUCUNE	\N	SECUECO	\N	The Shift Project	\N	2022-03-15 16:00:00	2022-03-15 16:45:00	2022-03-15 18:25:36	2022-03-16 10:08:39	4	0	\N	\N
639013	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	Audition rapporteurs	\N	2022-03-15 16:00:00	2022-03-15 18:00:00	\N	\N	0	0	\N	\N
639996	GIA	AUCUNE	\N	\N	\N	Coopé - Entretien avec M. Dagia AKA	Coopé - Entretien avec M. Dagia AKA	2022-03-24 14:00:00	2022-03-24 15:00:00	\N	\N	1	0	651	\N
639998	GIA	AUCUNE	\N	\N	\N	Entretien avec Mme Beau	Entretien avec Mme Laurence Beau, ambassadrice de la France au Botswana	2022-03-24 17:30:00	2022-03-24 18:30:00	\N	\N	2	0	646	\N
653904	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	MCC Délinquance des mineurs  - Déplacement à la maison d'arrêt de Nanterre	MCC Délinquance des mineurs  - Déplacemnet à la maison d'arrêt de Nanterre	2022-07-07 13:00:00	2022-07-07 18:00:00	\N	\N	3	0	\N	\N
653908	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	MI Formation des personnels PN-GN - Ecole de gendarmerie de Chaumont	MI Formation des personnels PN-GN - Ecole de gendarmerie de Chaumont	2022-08-05 06:00:00	2022-08-05 20:00:00	\N	\N	2	0	\N	\N
653921	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	MI Formation des personnels PN-GN - Centre de formation de la gendarmerie de Saint-Astier	MI Formation des personnels PN-GN - Centre de formation de la gendarmerie de Saint-Astier	2022-09-06 08:00:00	2022-09-08 00:00:00	\N	\N	2	0	\N	\N
655453	DELEGATION	AUDRAP	\N	\N	PROS	Audition Entreprises de l'eau (FP2E)	\N	2022-07-26 16:00:00	2022-07-26 17:00:00	\N	\N	1	0	\N	\N
655455	DELEGATION	AUDRAP	\N	\N	PROS	Audition de l'Union des Industries de l'Eau	\N	2022-07-27 16:30:00	2022-07-27 17:30:00	\N	\N	2	0	\N	\N
726276	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2023-05-10 09:30:00	2023-05-10 10:30:00	2023-05-10 13:53:48	2023-05-10 15:28:45	36	2	\N	\N
655760	QUESTURE	AUCUNE	\N	\N	\N	Réunion de Questure 	Réunion de Questure	2022-09-14 15:00:00	2022-09-14 16:30:00	\N	\N	3	0	\N	\N
658091	GIA	AUCUNE	\N	\N	\N	Coopé - Entretien avec M. Paul-Crescent BENINGA, Président fondateur de l¿Institut centr	Coopé - Entretien avec M. Paul-Crescent BENINGA, Président fondateur de l¿Institut centr	2022-09-28 15:30:00	2022-09-28 16:30:00	\N	\N	1	0	572	\N
659360	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de M. Sébastien Lecornu	Audition de M. Sébastien Lecornu	2022-10-11 17:30:00	2022-10-11 19:23:00	2022-10-13 12:25:55	2022-10-13 16:13:58	33	0	\N	\N
659361	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de Mme Catherine Colonna	Audition de Mme Catherine Colonna	2022-10-12 16:32:00	2022-10-12 18:30:00	2022-10-13 12:27:48	2022-10-13 16:13:57	29	0	\N	\N
661291	ETUDES	AUCUNE	\N	\N	\N	Présentation du rapport de la MCC chasse	Présentation du rapport de la MCC chasse	2022-10-12 13:30:00	2022-10-12 15:00:00	\N	\N	22	0	\N	907
663534	GIA	AUCUNE	\N	\N	\N	Patrimoine religieux	Débat autour du rapport du Sénat sur l'état du patrimoine religieux	2022-10-18 19:45:00	2022-10-18 21:30:00	\N	\N	13	0	629	\N
665507	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Auditions MCC ZAN	Auditions MCC ZAN	2022-10-19 16:30:00	2022-10-19 17:30:00	\N	\N	5	0	\N	\N
665517	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Auditions MCC ZAN	Auditions MCC ZAN	2022-10-19 17:50:00	2022-10-19 18:15:00	\N	\N	4	0	\N	\N
665979	GIA	AUCUNE	\N	\N	\N	Entretien avec une délégation du Sénat de Côte d'Ivoire 	Entretien avec M. Jeannot AHOUSSOU-KOUADIO, Président du Sénat de Côte d'Ivoire, et sa délégation 	2022-10-25 15:40:00	2022-10-25 17:15:00	\N	\N	8	0	573	\N
666060	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Conservatoires régionaux des monuments historiques (CRMH)	\N	2022-10-25 15:00:00	2022-10-25 16:10:00	\N	\N	2	0	\N	\N
666192	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2023 Assurance maladie - Audition du LET	\N	2022-10-25 16:15:00	2022-10-25 17:00:00	\N	\N	2	0	\N	\N
666321	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Culture - SG MIN Culture/Musée du Louvre	PLF pour 2023 - Culture - SG MIN Culture/Musée du Louvre	2022-10-25 15:30:00	2022-10-25 17:50:00	\N	\N	2	0	\N	\N
666324	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - GFP - DB/DGDDI	PLF pour 2023 - GFP - DB/DGDDI	2022-10-25 16:30:00	2022-10-25 18:30:00	\N	\N	1	0	\N	\N
666335	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Écologie - SG MIN ÉCO	PLF pour 2023 - Écologie - SG MIN ÉCO	2022-10-24 09:00:00	2022-10-24 10:00:00	\N	\N	1	0	\N	\N
666338	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Écologie - OFB/PFA et ESIAM	PLF pour 2023 - Écologie - OFB/PFA et ESIAM	2022-10-25 17:00:00	2022-10-25 19:00:00	\N	\N	1	0	\N	\N
666525	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2023 - Avis Économie - Audition	PLF 2023 - Avis Économie - Audition	2022-10-25 15:15:00	2022-10-25 16:30:00	\N	\N	1	0	\N	\N
666528	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 25/10/2022	Réunion avec la commission des affaires européennes du Sénat roumain 	2022-10-25 15:00:00	2022-10-25 16:30:00	2022-10-26 14:39:58	2022-10-26 15:08:11	18	0	\N	\N
666570	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2023 Avis budgétaires "Sécurités"	\N	2022-10-26 14:15:00	2022-10-26 15:00:00	\N	\N	1	0	\N	\N
666578	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF 2023 Avis budgétaires "Sécurités"	PLF 2023 Avis budgétaires "Sécurités"	2022-10-26 16:15:00	2022-10-26 17:00:00	\N	\N	1	0	\N	\N
666668	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	\N	\N	2022-10-26 11:45:00	2022-10-26 12:30:00	\N	\N	3	0	\N	\N
667141	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2022 - La DCPJ - Déplacement à Nanterre	Contrôle 2022 - La DCPJ - Déplacement à Nanterre	2022-10-24 13:30:00	2022-10-24 18:50:00	\N	\N	1	0	\N	\N
667155	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Économie - La Poste/DG Trésor/DGCCRF	PLF pour 2023 - Économie - La Poste/DG Trésor/DGCCRF	2022-10-25 15:00:00	2022-10-25 18:00:00	\N	\N	2	0	\N	\N
667176	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Rapport général - CCI France	PLF pour 2023 - Rapport général - CCI France	2022-10-25 18:30:00	2022-10-25 19:30:00	\N	\N	1	0	\N	\N
667226	COM_PERMANENTE	AUTRE	\N	LOIS	\N	MI Nouvelle-Calédonie - PLF 2023 - Audition Gérald Darmanin et Jean-François Carenco	MI Nouvelle-Calédonie - PLF 2023 - Audition Gérald Darmanin et Jean-François Carenco	2022-11-02 16:35:00	2022-11-02 18:40:00	2022-11-02 20:19:01	2022-11-03 17:38:03	19	0	\N	\N
667246	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Culture - DGCA/DGPA	PLF pour 2023 - Culture - DGCA/DGPA	2022-10-26 16:15:00	2022-10-26 18:15:00	\N	\N	1	0	\N	\N
667307	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	TV5 Monde	\N	2022-10-26 16:00:00	2022-10-26 17:00:00	\N	\N	1	0	\N	\N
667308	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Centre national du cinéma et de l'image animée (CNC)	\N	2022-10-26 16:45:00	2022-10-26 18:00:00	\N	\N	1	0	\N	\N
667311	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	France Médias Monde	\N	2022-10-27 10:30:00	2022-10-27 11:30:00	\N	\N	2	0	\N	\N
667312	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Direction générale des médias et des industries culturelles - ministère de la culture	\N	2022-11-04 09:30:00	2022-11-04 11:00:00	\N	\N	1	0	\N	\N
667719	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2022-11-02 15:00:00	2022-11-02 16:15:00	\N	\N	262	0	\N	\N
667720	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJLP Finances Publiques	PJLP Finances Publiques	2022-11-02 16:30:00	2022-11-02 20:00:00	\N	\N	112	0	\N	\N
667721	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJLP Finances Publiques	PJLP Finances Publiques	2022-11-02 21:30:00	2022-11-03 00:00:00	\N	\N	59	0	\N	\N
667724	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Energies Renouvelables	PJL Energies Renouvelables	2022-11-03 10:30:00	2022-11-03 12:45:00	\N	\N	108	0	\N	\N
667725	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Energies Renouvelables	PJL Energies Renouvelables	2022-11-03 14:30:00	2022-11-03 19:55:00	\N	\N	110	0	\N	\N
667726	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Energies Renouvelables	PJL Energies Renouvelables	2022-11-03 21:30:00	2022-11-04 00:30:00	\N	\N	61	0	\N	\N
667727	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Energies Renouvelables	PJL Energies Renouvelables	2022-11-04 09:30:00	2022-11-04 13:05:00	\N	\N	62	0	\N	\N
667728	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Energies Renouvelables	PJL Energies Renouvelables	2022-11-04 14:35:00	2022-11-04 20:00:00	\N	\N	60	0	\N	\N
667729	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Energies Renouvelables	PJL Energies Renouvelables	2022-11-04 21:30:00	2022-11-05 02:50:00	\N	\N	42	0	\N	\N
719383	DELEGATION	AUCUNE	\N	\N	211	Audition plénière - Santé des femmes au travail (Direction générale du travail)	\N	2023-03-30 08:30:00	2023-03-30 09:35:00	\N	\N	6	0	\N	\N
719392	MISSION	AUDRAP	\N	BIOCARBU	\N	DGITM	DGITM	2023-03-28 09:00:00	2023-03-28 10:10:00	\N	\N	5	0	\N	\N
719776	DELEGATION	AUTRE	\N	\N	DSOM	ODEADOM et délégué interministériel transformation agricole	\N	2023-04-06 08:30:00	2023-04-06 10:30:00	\N	\N	7	0	\N	\N
719791	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI TND - Audition Pr Bonnet-Brilhault	\N	2023-03-28 14:30:00	2023-03-28 15:50:00	\N	\N	1	0	\N	\N
640893	DELEGATION	AUDRAP	\N	\N	206	AuditionM. Pitard	\N	2022-04-05 10:40:00	2022-04-05 12:00:00	\N	\N	3	0	\N	\N
719792	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI TND - Audition Association Occitadys	\N	2023-03-28 16:00:00	2023-03-28 17:00:00	\N	\N	3	0	\N	\N
719909	GIA	AUCUNE	\N	\N	\N	déplacement à Dharamsala	déplacement Dharamsala	2023-04-19 08:30:00	2023-04-26 10:00:00	\N	\N	3	0	634	\N
719922	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Réunion du 30 mars 2023	\N	2023-03-30 08:30:00	2023-03-30 09:00:00	\N	\N	3	0	\N	\N
719929	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Institut de formation aux Métiers de la Santé de Montauban	\N	2023-03-30 09:30:00	2023-03-30 10:00:00	\N	\N	2	0	\N	\N
719930	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Ministère de l'enseignement supérieur, de la recherche et de l'Innovation	M. J. Teillard	2023-03-30 10:30:00	2023-03-30 12:00:00	\N	\N	2	0	\N	\N
719933	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	FNASEPH	\N	2023-03-30 14:00:00	2023-03-30 15:00:00	\N	\N	3	0	\N	\N
719934	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Secrétariat général de l'enseignement catholique	\N	2023-03-30 15:00:00	2023-03-30 16:15:00	\N	\N	2	0	\N	\N
719950	MISSION	AUTRE	\N	BATI	\N	MI BS	\N	2023-04-04 16:30:00	2023-04-04 18:30:00	2023-04-12 17:17:31	2023-04-12 17:26:25	5	0	\N	\N
719951	MISSION	AUTRE	\N	BATI	\N	bati scolaire	\N	2023-04-06 15:00:00	2023-04-06 17:00:00	2023-04-06 18:21:41	2023-04-07 11:23:29	2	0	\N	\N
719952	COM_ENQUETE	PLENIERE	\N	MEDIC	\N	Réunion plénière	\N	2023-04-05 13:35:00	2023-04-05 14:45:00	2023-04-05 14:51:08	2023-04-06 17:48:15	8	0	\N	\N
719953	COM_ENQUETE	PLENIERE	\N	MEDIC	\N	Réunion plénière	\N	2023-04-04 13:35:00	2023-04-04 15:00:00	2023-04-04 15:50:13	2023-04-06 17:48:13	10	0	\N	\N
719994	COM_PERMANENTE	AUDRAP	\N	CAE	\N	ENGIE	\N	2023-03-29 16:15:00	2023-03-29 16:45:00	\N	\N	5	0	\N	\N
719998	COM_PERMANENTE	AUDRAP	\N	CAE	\N	RTE	\N	2023-03-29 16:45:00	2023-03-29 17:15:00	\N	\N	5	0	\N	\N
720003	COM_PERMANENTE	AUDRAP	\N	CAE	\N	TR Syndicats (CGT-FNME, FNEM-FO ok, CFE-CGC ok, CFDT, Sud-Energie ok)	\N	2023-03-29 17:15:00	2023-03-29 18:15:00	\N	\N	5	0	\N	\N
720017	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 6 avril 2023	\N	2023-04-06 09:00:00	2023-04-06 10:30:00	\N	\N	0	0	\N	\N
720064	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI FIn de vie - Audition de l'AP-HP	\N	2023-03-29 16:30:00	2023-03-29 18:00:00	\N	\N	5	0	\N	\N
720071	DELEGATION	AUDRAP	\N	\N	206	Audition Recyclage du plastique	\N	2023-03-30 13:30:00	2023-03-30 17:45:00	\N	\N	2	0	\N	\N
720089	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de M. Pierre Lévy	\N	2023-04-04 17:05:00	2023-04-04 18:25:00	2023-04-05 14:03:13	2023-04-06 17:46:19	23	0	\N	\N
720090	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de M. Christophe Jaffrelot	\N	2023-04-05 09:30:00	2023-04-05 11:00:00	2023-04-05 14:05:40	2023-04-06 17:46:20	30	0	\N	\N
720132	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI Balkans occidentaux	\N	2023-03-29 16:30:00	2023-03-29 18:30:00	\N	\N	3	0	\N	\N
720136	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI Balkans occidentaux	\N	2023-03-29 18:30:00	2023-03-29 19:30:00	\N	\N	2	0	\N	\N
720529	GIA	AUCUNE	\N	\N	\N	Coopé - Visite de M. Omar AL-SHAIKHLY, co-fondateur et directeur technique de l¿Iraqi Gree	Coopé - Visite de M. Omar AL-SHAIKHLY, co-fondateur et directeur technique de l¿Iraqi Gree	2023-04-04 10:00:00	2023-04-04 11:00:00	\N	\N	3	0	615	\N
721120	ETUDES	AUTRE	\N	\N	\N	Audition SER	Audition SER	2023-04-05 08:15:00	2023-04-05 09:30:00	\N	\N	18	0	\N	906
721224	COM_PERMANENTE	AUTRE	\N	AFCL	\N	PPL école de la liberté	\N	2023-04-11 14:30:00	2023-04-11 15:10:00	2023-04-11 15:29:59	2023-04-12 17:24:43	31	6	\N	\N
721427	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Conseil national consultatif des Personnes handicapées (CNCPH) 	\N	2023-04-05 13:30:00	2023-04-05 15:00:00	\N	\N	2	0	\N	\N
721446	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition Assemblée Nationale	\N	2023-04-04 13:45:00	2023-04-04 14:45:00	\N	\N	3	0	\N	\N
721458	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition ATMO FRANCE	\N	2023-04-04 14:45:00	2023-04-04 15:30:00	\N	\N	2	0	\N	\N
721501	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition 40 millions d'automobilistes	\N	2023-04-04 15:30:00	2023-04-04 16:15:00	\N	\N	1	0	\N	\N
721518	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition Groupement des autorités responsables de transport	\N	2023-04-04 16:15:00	2023-04-04 16:50:00	\N	\N	3	0	\N	\N
721535	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition Métropole Rouen Normandie	\N	2023-04-04 17:00:00	2023-04-04 17:45:00	\N	\N	2	0	\N	\N
721783	MISSION	AUDRAP	\N	BATI	\N	MI bati - Recteur Mayotte	\N	2023-04-05 14:00:00	2023-04-05 15:00:00	\N	\N	5	0	\N	\N
722535	GIA	AUCUNE	\N	\N	\N	Déjeuner avec les conseillers économiques des ambassades d'Europe du Nord	Déjeuner avec les conseillers économiques des ambassades d'Europe du Nord (Danemark, Finlande, Norvège, Suède)	2023-04-05 12:30:00	2023-04-05 14:30:00	\N	\N	7	0	640	\N
722768	COM_ENQUETE	PLENIERE	\N	TIKTO	\N	Auditions députés européens	Auditions Raphaël Glucksmann et Nathalie Loiseau	2023-04-13 11:30:00	2023-04-13 13:10:00	2023-04-13 14:37:19	2023-04-28 11:38:48	9	0	\N	\N
722790	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat « L¿avenir de la ressource en eau »	Débat « L¿avenir de la ressource en eau »	2023-04-11 14:30:00	2023-04-11 16:30:00	\N	\N	105	0	\N	\N
722791	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat « Harcèlement scolaire »	Débat « Harcèlement scolaire »	2023-04-11 16:35:00	2023-04-11 18:25:00	\N	\N	67	0	\N	\N
722792	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL École de la liberté, de l'égalité des chances et de la laïcité	PPL École de la liberté, de l'égalité des chances et de la laïcité	2023-04-11 18:25:00	2023-04-11 20:00:00	\N	\N	84	0	\N	\N
722793	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL École de la liberté, de l'égalité des chances et de la laïcité	PPL École de la liberté, de l'égalité des chances et de la laïcité	2023-04-11 21:30:00	2023-04-12 01:35:00	\N	\N	76	0	\N	\N
722794	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2023-04-12 15:00:00	2023-04-12 16:15:00	\N	\N	247	0	\N	\N
722795	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat d'actualité	Débat d'actualité	2023-04-12 16:30:00	2023-04-12 17:45:00	\N	\N	53	0	\N	\N
722796	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR 34-1 Forces de l'ordre	PPR 34-1 Forces de l'ordre	2023-04-12 17:45:00	2023-04-12 19:05:00	\N	\N	75	0	\N	\N
722797	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Jeux Olympiques et Paralympiques de 2024	CMP Jeux Olympiques et Paralympiques de 2024	2023-04-12 19:05:00	2023-04-12 20:00:00	\N	\N	37	0	\N	\N
722798	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat sur la pollution lumineuse	Débat sur la pollution lumineuse	2023-04-12 21:30:00	2023-04-12 22:55:00	\N	\N	22	0	\N	\N
722799	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Fusion des filières REP d'emballages ménagers et de papier	CMP Fusion des filières REP d'emballages ménagers et de papier	2023-04-13 14:30:00	2023-04-13 15:20:00	\N	\N	27	0	\N	\N
722800	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2023-04-13 10:30:00	2023-04-13 12:25:00	\N	\N	31	0	\N	\N
732739	COM_ENQUETE	PLENIERE	\N	MEDIC	\N	Audition plénière	\N	2023-05-24 13:35:00	2023-05-24 15:10:00	2023-05-24 15:08:42	2023-05-24 17:25:41	7	0	\N	\N
722801	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat sur l'état de la justice dans les outre-mer	Débat sur l'état de la justice dans les outre-mer	2023-04-13 15:25:00	2023-04-13 16:50:00	\N	\N	25	0	\N	\N
722902	MISSION	AUDRAP	\N	AVENCOMM	\N	Centre national de la fonction publique territoriale	Centre national de la fonction publique territoriale	2023-04-11 13:40:00	2023-04-11 14:40:00	\N	\N	3	0	\N	\N
723207	COM_ENQUETE	PLENIERE	\N	RENOV	\N	Table ronde précarité énergétique	\N	2023-04-11 17:35:00	2023-04-11 19:45:00	2023-04-13 10:34:45	2023-04-28 11:38:44	5	0	\N	\N
723232	COM_PERMANENTE	AUTRE	\N	FINC	\N	PJ Loi de programmation militaire 2024-2030 - Audition P. MOSCOVICI	PJ Loi de programmation militaire 2024-2030 - Audition P. MOSCOVICI	2023-04-12 09:20:00	2023-04-12 10:20:00	2023-04-12 17:15:17	2023-04-12 17:24:42	58	0	\N	\N
723233	COM_PERMANENTE	AUTRE	\N	FINC	\N	58-2 Installation des agriculteurs - Audition P. MOSCOVICI - Désignation rapporteur spécia	58-2 Installation des agriculteurs - Audition P. MOSCOVICI - Désignation rapporteur spécial	2023-04-12 10:20:00	2023-04-12 11:30:00	2023-04-12 17:17:17	2023-04-12 17:24:39	38	1	\N	\N
723257	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Fraude à l'Arenh	\N	2023-04-11 14:30:00	2023-04-11 16:00:00	\N	\N	2	0	\N	\N
723381	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition M. Barrot et PPL Précarité	\N	2023-04-12 09:00:00	2023-04-12 11:25:00	\N	\N	0	1	\N	\N
638996	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT subsidiarité	GT subsidiarité	2022-03-09 15:45:00	2022-03-09 15:55:00	\N	\N	3	0	\N	\N
643780	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Ferme France - Auditions MM. Laurent Duplomb, Pierre Louault et Serge Merillou	MI Ferme France - Auditions MM. Laurent Duplomb, Pierre Louault et Serge Merillou	2022-06-02 14:00:00	2022-06-02 16:15:00	\N	\N	3	0	\N	\N
646693	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Nouvelle-Calédonie	Audition rapporteur - MI Nouvelle-Calédonie	2022-07-06 08:00:00	2022-07-06 09:00:00	\N	\N	3	0	\N	\N
647644	SEANCE_PLENIERE	ELOGE_FUNEBRE	\N	\N	\N	Éloge funèbre - Catherine FOURNIER	Éloge funèbre - Catherine FOURNIER	2022-07-12 14:30:00	2022-07-12 14:55:00	\N	\N	0	0	\N	\N
647645	SEANCE_PLENIERE	DECL_GVT	\N	\N	\N	Déclaration du Gouvernement PFUE	Déclaration du Gouvernement PFUE	2022-07-12 15:15:00	2022-07-12 17:45:00	\N	\N	132	0	\N	\N
647646	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL contenus à caractère terroriste en ligne	PPL contenus à caractère terroriste en ligne	2022-07-12 17:50:00	2022-07-12 19:10:00	\N	\N	64	0	\N	\N
647647	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL contenus à caractère terroriste en ligne	PPL contenus à caractère terroriste en ligne	2022-07-12 21:30:00	2022-07-12 22:00:00	\N	\N	0	0	\N	\N
647648	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2022-07-13 15:00:00	2022-07-13 16:25:00	\N	\N	214	0	\N	\N
651575	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Remise du rapport du Haut Comité d'évaluation de la condition militaire	Remise du rapport du Haut Comité d'évaluation de la condition militaire	2022-07-20 18:30:00	2022-07-20 19:30:00	\N	\N	1	0	\N	\N
655138	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Mission Flash dons associations - FNC	Mission Flash dons associations - FNC	2022-08-04 08:15:00	2022-08-04 09:30:00	\N	\N	2	0	\N	\N
656840	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Examen PJL Singapour et PJL aides navigation maritime + PJL pour avis orientation et prog	\N	2022-10-04 17:00:00	2022-10-04 18:30:00	2022-10-05 11:05:20	2022-10-05 17:35:00	32	6	\N	\N
656841	COM_PERMANENTE	AUTRE	\N	ETRD	\N	PLF 2023 - Audition SGDSN et ANSSI + Audition DG Trésor	\N	2022-10-05 09:30:00	2022-10-05 12:30:00	2022-10-06 17:40:37	2022-10-06 17:56:57	35	0	\N	\N
662023	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition MCC ZAN	Audition MCC ZAN	2022-10-12 17:30:00	2022-10-12 18:30:00	\N	\N	12	0	\N	\N
662061	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Auditions MCC ZAN	Auditions MCC ZAN	2022-10-13 14:00:00	2022-10-13 15:00:00	\N	\N	10	0	\N	\N
662072	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	MCC	Auditions MCC ZAN	2022-10-13 15:00:00	2022-10-13 15:45:00	\N	\N	10	0	\N	\N
662096	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Auditions MCC ZAN	Auditions MCC ZAN	2022-10-13 15:45:00	2022-10-13 16:40:00	\N	\N	10	0	\N	\N
662109	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Auditions MCC ZAN	Auditions MCC ZAN	2022-10-13 16:40:00	2022-10-13 17:35:00	\N	\N	7	0	\N	\N
662120	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Auditions MCC ZAN	Auditions MCC ZAN	2022-10-13 17:40:00	2022-10-13 18:00:00	\N	\N	5	0	\N	\N
664587	GIA	AUCUNE	\N	\N	\N	Accueil de Mme Tiare AGUILERA	Accueil de Mme Tiare AGUILERA	2022-10-13 17:00:00	2022-10-13 18:30:00	\N	\N	1	0	978	\N
668414	DELEGATION	AUTRE	\N	\N	ENTREPRISES	Adoption du rapport JDE - Examen du rapport sur la RSE	\N	2022-10-27 09:30:00	2022-10-27 10:45:00	\N	\N	0	0	\N	\N
668424	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	PLF pour 2023 - Sécurités - Déplacement à Paris -  DG Gendarmerie	PLF pour 2023 - Sécurités - Déplacement à Paris -  DG Gendarmerie	2022-11-02 14:40:00	2022-11-02 16:20:00	\N	\N	1	0	\N	\N
668725	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PLF 2023 UFC - Que choisir	Audition PLF 2023 UFC - Que choisir	2022-10-26 16:30:00	2022-10-26 17:15:00	\N	\N	1	0	\N	\N
668783	DELEGATION	AUDRAP	\N	\N	206	Auditions Sobriété énergétique	\N	2022-10-27 14:00:00	2022-10-27 17:00:00	\N	\N	2	0	\N	\N
669292	ETUDES	AUCUNE	\N	\N	\N	Table ronde sur l'application du Zéro artificialisation nette (ZAN)	Table ronde sur l'application du Zéro artificialisation nette (ZAN)	2022-11-02 13:35:00	2022-11-02 14:55:00	\N	\N	12	0	\N	918
672729	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Culture - Philharmonie de Paris 	PLF pour 2023 - Culture - Philharmonie de Paris 	2022-11-08 14:35:00	2022-11-08 15:35:00	\N	\N	2	0	\N	\N
672732	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - RCT - Associations d'élus	PLF pour 2023 - RCT - Associations d'élus	2022-11-08 09:00:00	2022-11-08 11:00:00	\N	\N	2	0	\N	\N
672735	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Justice - DPJJ	PLF pour 2023 - Justice - DPJJ	2022-11-08 10:10:00	2022-11-08 11:10:00	\N	\N	1	0	\N	\N
672737	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Justice - USM	PLF pour 2023 - Justice - USM	2022-11-10 11:30:00	2022-11-10 12:20:00	\N	\N	1	0	\N	\N
672739	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Justice - CNB/SM/Comité EG Justice	PLF pour 2023 - Justice - CNB/SM/Comité EG Justice	2022-11-10 14:30:00	2022-11-10 18:05:00	\N	\N	1	0	\N	\N
672741	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Ecologie - ADEME	PLF pour 2023 - Ecologie - ADEME	2022-11-08 10:00:00	2022-11-08 11:00:00	\N	\N	1	0	\N	\N
672743	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Rapport Général - CITEO	PLF pour 2023 - Rapport Général - CITEO	2022-11-10 14:30:00	2022-11-10 15:15:00	\N	\N	1	0	\N	\N
732740	COM_ENQUETE	PLENIERE	\N	MEDIC	\N	Audition de M. Roland Lescure	\N	2023-05-25 11:00:00	2023-05-25 12:25:00	2023-06-02 15:58:17	2023-06-02 15:58:24	4	0	\N	\N
723382	COM_PERMANENTE	AUTRE	\N	CAE	\N	PPL Précarité énergétique	\N	2023-04-12 10:25:00	2023-04-12 11:25:00	2023-04-12 17:25:54	2023-04-28 11:37:03	43	0	\N	\N
672745	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Cohésion des territoires - Logement-Urbanisme - Abbé Pierre/CdC	PLF pour 2023 - Cohésion des territoires - Logement-Urbanisme - Abbé Pierre/CdC	2022-11-08 09:15:00	2022-11-08 10:55:00	\N	\N	1	0	\N	\N
672747	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Cohésion des territoires - Logement-Urbanisme - FPI	PLF pour 2023 - Cohésion des territoires - Logement-Urbanisme - FPI	2022-11-08 16:40:00	2022-11-08 17:30:00	\N	\N	1	0	\N	\N
672749	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Cohésion des territoires - Logement-Urbanisme  - CAB MIN Logement	PLF pour 2023 - Cohésion des territoires - Logement-Urbanisme  - CAB MIN Logement	2022-11-09 17:30:00	2022-11-09 18:20:00	\N	\N	1	0	\N	\N
672751	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Rapport général - Action Logement Groupe	PLF pour 2023 - Rapport général - Action Logement Groupe	2022-11-09 18:45:00	2022-11-09 19:15:00	\N	\N	1	0	\N	\N
672753	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - BACEA - Air France KLM	PLF pour 2023 - BACEA - Air France KLM	2022-11-08 10:00:00	2022-11-08 11:30:00	\N	\N	1	0	\N	\N
672755	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Écologie - Transports - DGITM/SNCF	PLF pour 2023 - Écologie - Transports - DGITM/SNCF	2022-11-08 15:30:00	2022-11-08 17:45:00	\N	\N	2	0	\N	\N
672758	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Écologie - Transports - AFIT France	PLF pour 2023 - Écologie - Transports - AFIT France	2022-11-09 08:00:00	2022-11-09 08:45:00	\N	\N	2	0	\N	\N
672761	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Écologie - Transports - ART/KEOLIS	PLF pour 2023 - Écologie - Transports - ART/KEOLIS	2022-11-09 16:15:00	2022-11-09 18:15:00	\N	\N	2	0	\N	\N
672764	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Écologie - Transports - VNF	PLF pour 2023 - Écologie - Transports - VNF	2022-11-09 19:30:00	2022-11-09 20:15:00	\N	\N	1	0	\N	\N
677928	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Lengagne et M. Secondi	\N	2022-11-14 11:00:00	2022-11-14 12:30:00	\N	\N	1	0	\N	\N
677961	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Cabantous	\N	2022-11-14 14:30:00	2022-11-14 15:30:00	\N	\N	1	0	\N	\N
677964	DELEGATION	AUDRAP	\N	\N	206	Audition de Mme Roncigli et Mme Chammat	\N	2022-11-14 15:30:00	2022-11-14 16:30:00	\N	\N	1	0	\N	\N
677966	DELEGATION	AUDRAP	\N	\N	206	Audition de la Mairie de Paris	\N	2022-11-14 16:30:00	2022-11-14 17:30:00	\N	\N	1	0	\N	\N
677969	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Villalba	\N	2022-11-16 16:30:00	2022-11-16 18:00:00	\N	\N	2	0	\N	\N
678336	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Audition France Télévisions	\N	2022-11-23 14:00:00	2022-11-23 15:00:00	\N	\N	3	0	\N	\N
678416	DELEGATION	AUCUNE	\N	\N	DSOM	Évolution institutionnelle outre-mer : audition de l'ACCIOM (fin)	\N	2022-12-01 11:00:00	2022-12-01 12:40:00	\N	\N	4	0	\N	\N
678753	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Équité territoriale face aux déserts médicaux - Audition de la Drees	\N	2022-11-22 15:00:00	2022-11-22 16:00:00	\N	\N	5	0	\N	\N
679245	ETUDES	AUCUNE	\N	\N	\N	Table ronde sur les semences et plants d'arbres	Table ronde sur les semences et plants d'arbres	2022-11-23 13:30:00	2022-11-23 15:00:00	\N	\N	9	0	\N	948
687418	GIA	AUCUNE	\N	\N	\N	Petit-déjeuner d'échange	Petit-déjeuner d'échange avec M. Franck de Bruyn, Président du comité balte des conseillers du commerce extérieur 	2022-12-14 08:30:00	2022-12-14 10:00:00	\N	\N	5	0	616	\N
730525	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	\N	2023-05-10 14:05:00	2023-05-10 15:25:00	\N	\N	4	0	\N	\N
730530	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Orientation et programmation du ministère de la justice 2023-2027	PJL Orientation et programmation du ministère de la justice 2023-2027	2023-05-10 16:00:00	2023-05-10 16:55:00	\N	\N	3	0	\N	\N
730531	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Orientation et programmation du ministère de la justice 2023-2027	PJL Orientation et programmation du ministère de la justice 2023-2027	2023-05-11 08:30:00	2023-05-11 10:20:00	\N	\N	3	0	\N	\N
730532	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Réunion du 11 mai 2023	Réunion GT Subsidiarité	2023-05-11 08:30:00	2023-05-11 09:00:00	\N	\N	2	0	\N	\N
730673	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de représentants de la BITD	\N	2023-05-17 09:00:00	2023-05-17 11:10:00	2023-05-17 14:37:40	2023-05-17 14:43:15	28	0	\N	\N
730675	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de Mme Catherine Colonna, ministre	\N	2023-05-17 16:30:00	2023-05-17 17:30:00	2023-05-24 09:53:30	2023-05-24 17:29:01	14	1	\N	\N
730743	GIA	AUCUNE	\N	\N	\N	entretien avec le VP du Yuan législatif	Visite au sénat d'une délégation de 16 parlementaires taïwanais	2023-04-14 16:00:00	2023-04-14 18:00:00	\N	\N	4	0	623	\N
731228	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Reconnaissance biométrique	Audition rapporteur - PPL Reconnaissance biométrique	2023-05-16 14:30:00	2023-05-16 15:30:00	\N	\N	1	0	\N	\N
731307	MISSION	AUCUNE	\N	GEAU	\N	Table ronde consacrée aux offices de l¿eau dans les outre-mer	\N	2023-05-16 18:30:00	2023-05-16 20:00:00	2023-05-17 11:14:55	2023-05-17 14:38:53	7	0	\N	\N
731643	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Auditions ¨P. 146	Auditions P. 146	2023-05-16 14:30:00	2023-05-16 18:15:00	\N	\N	2	0	\N	\N
732326	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Fin de vie - Audition de sénateurs espagnols	\N	2023-05-16 14:00:00	2023-05-16 15:15:00	\N	\N	2	0	\N	\N
732329	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Application des lois Protection de l'enfance - Audition du CNPE	\N	2023-05-16 14:00:00	2023-05-16 15:30:00	\N	\N	2	0	\N	\N
732330	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Application des lois Protection de l'enfance - Table ronde d'associations	\N	2023-05-16 18:15:00	2023-05-16 19:30:00	\N	\N	1	0	\N	\N
732332	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Application des lois Protection de l'enfance - Table ronde de conseils départementaux	\N	2023-05-16 16:30:00	2023-05-16 18:00:00	\N	\N	2	0	\N	\N
732333	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Données de santé - Table ronde Recherche scientifique et médicale	\N	2023-05-16 17:00:00	2023-05-16 18:30:00	\N	\N	2	0	\N	\N
732628	DELEGATION	AUCUNE	\N	\N	DSOM	Parentalité outre-mer : auditions UNICEF et Croix-Rouge française	\N	2023-05-25 08:30:00	2023-05-25 10:25:00	\N	\N	9	0	\N	\N
732641	MISSION	AUTRE	\N	BIOCARBU	\N	MI BIOCARBURANTS - 16	\N	2023-05-17 16:30:00	2023-05-17 18:00:00	2023-05-17 18:11:20	2023-05-19 16:15:02	5	0	\N	\N
732642	MISSION	AUCUNE	\N	BIOCARBU	\N	MI BIOCARBURANTS - 17	\N	2023-05-17 18:00:00	2023-05-17 19:30:00	2023-05-17 19:35:12	2023-05-19 16:15:02	3	0	\N	\N
732649	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-05-24 09:00:00	2023-05-24 12:15:00	2023-05-24 12:05:28	2023-05-24 17:25:28	33	0	\N	\N
732650	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition plénière	\N	2023-05-24 16:30:00	2023-05-24 18:05:00	2023-05-24 18:04:21	2023-05-30 13:06:15	20	0	\N	\N
732718	ETUDES	AUTRE	\N	\N	\N	Audition CPSF	\N	2023-05-17 14:00:00	2023-05-17 15:00:00	\N	\N	11	0	\N	1014
730674	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Examen de 3 conventions	\N	2023-05-17 11:10:00	2023-05-17 11:45:00	2023-05-17 14:40:00	2023-05-17 14:43:16	33	6	\N	\N
732659	COM_PERMANENTE	AUTRE	\N	FINC	\N	Plénière 34 - PJL Douane	Plénière 34 - PJL Douane	2023-05-17 10:50:00	2023-05-17 12:00:00	2023-05-23 14:04:27	2023-05-24 09:39:34	42	6	\N	\N
732741	COM_ENQUETE	PLENIERE	\N	MEDIC	\N	Audition laboratoires CDM Lavoisier	\N	2023-05-25 13:30:00	2023-05-25 14:45:00	2023-05-25 14:53:47	2023-05-30 13:06:41	3	0	\N	\N
732754	MISSION	AUCUNE	\N	AVENCOMM	\N	Audition Direction générale des collectivités locales	Audition Direction générale des collectivités locales	2023-05-24 14:05:00	2023-05-24 15:05:00	2023-05-24 15:04:39	2023-05-24 17:25:42	8	0	\N	\N
732755	MISSION	AUCUNE	\N	AVENCOMM	\N	Audition Intercommunalités de France	Audition Intercommunalités de France	2023-05-24 17:30:00	2023-05-24 18:35:00	2023-05-25 17:32:07	2023-05-30 13:06:40	4	0	\N	\N
732759	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 24 mai 2023	\N	2023-05-24 13:30:00	2023-05-24 14:45:00	2023-05-24 15:33:22	2023-05-24 17:25:34	17	0	\N	\N
732763	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 25 mai 2023	\N	2023-05-25 09:30:00	2023-05-25 10:15:00	\N	\N	0	0	\N	\N
732776	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition Cnil	Audition Cnil	2023-05-23 17:05:00	2023-05-23 18:00:00	2023-05-23 21:04:07	2023-05-24 09:41:57	13	0	\N	\N
732777	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition d'Eric Dupond-Moretti	Audition d'Eric Dupond-Moretti	2023-05-23 18:35:00	2023-05-23 20:10:00	2023-05-23 21:04:23	2023-05-24 09:41:58	23	0	\N	\N
732845	GIA	AUCUNE	\N	\N	\N	Coopé - Visite de Mme Mia KARAMEHI-ABAZOVIC, députée de l¿Assemblée parlementaire 	Visite de Mme Mia KARAMEHI-ABAZOVIC, députée de l¿Assemblée parlementaire de Bosnie-Herzégovine	2023-05-16 10:00:00	2023-05-16 11:00:00	\N	\N	1	0	674	\N
734147	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition francophonie	\N	2023-05-31 09:30:00	2023-05-31 11:30:00	2023-06-01 10:46:01	2023-06-02 16:09:50	31	0	\N	\N
734153	MISSION	AUTRE	\N	LOCA	\N	Audition de Mme Dominique Faure, Ministre déléguée chargée des collectivités territoriales	\N	2023-05-31 16:30:00	2023-05-31 17:40:00	2023-06-07 10:54:38	2023-06-07 11:05:21	21	0	\N	\N
734162	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 37 - Audition Mme CAMBY, cour des comptes	PLENIERE - 37 - Audition Mme CAMBY, cour des comptes	2023-05-24 11:00:00	2023-05-24 12:25:00	2023-05-24 15:10:13	2023-05-24 17:25:25	21	1	\N	\N
734175	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Transmanche - Audition Getlink et D. Fasquelle	\N	2023-05-23 18:15:00	2023-05-23 19:00:00	\N	\N	1	0	\N	\N
734176	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Transmanche - Table ronde des syndicats	\N	2023-05-23 16:45:00	2023-05-23 18:15:00	\N	\N	2	0	\N	\N
734223	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 24 mai 2023	\N	2023-05-24 13:30:00	2023-05-24 15:00:00	\N	\N	0	0	\N	\N
735265	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Antilles - Auditions rapporteurs	Auditions rapporteurs - MI Antilles	2023-05-24 17:30:00	2023-05-24 19:00:00	\N	\N	2	0	\N	\N
735270	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Reconnaissance biométrique	Audition rapporteur - PPL Reconnaissance biométrique	2023-05-23 16:00:00	2023-05-23 17:00:00	\N	\N	1	0	\N	\N
735471	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Auditions ¨P. 146	Auditions P. 146	2023-05-24 16:30:00	2023-05-24 18:30:00	\N	\N	2	0	\N	\N
735530	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT 212 LPM 	GT 212 LPM	2023-05-24 14:00:00	2023-05-24 15:00:00	\N	\N	2	0	\N	\N
735533	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT 212 LPM 	GT 212 LPM	2023-05-24 16:30:00	2023-05-24 18:00:00	\N	\N	1	0	\N	\N
736576	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL honorabilité	\N	2023-05-30 18:30:00	2023-05-30 19:30:00	\N	\N	1	0	\N	\N
738146	COM_ENQUETE	PLENIERE	\N	TIKTO	\N	Audition Eric Garandeau	Audition Eric Garandeau	2023-06-08 10:30:00	2023-06-08 13:30:00	2023-06-09 11:28:29	2023-06-19 18:10:15	11	0	\N	\N
738147	COM_ENQUETE	PLENIERE	\N	TIKTO	\N	Audition de Mme Marlène Masure	Audition de Mme Marlène Masure	2023-06-08 16:30:00	2023-06-08 17:45:00	2023-06-09 11:30:10	2023-06-19 18:10:16	3	0	\N	\N
740294	GIA	AUCUNE	\N	\N	\N	Réunion préparatoire déplacement à Berlin	Réunion préparatoire déplacement à Berlin	2023-06-07 08:15:00	2023-06-07 09:00:00	\N	\N	9	0	604	\N
740308	COM_SPECIALE	AUDRAP	\N	ESNU	\N	PJL Sécuriser et réguler l'espace numérique	PJL Sécuriser et réguler l'espace numérique	2023-06-12 17:00:00	2023-06-12 18:30:00	\N	\N	3	0	\N	\N
639345	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition MI Contrôle Ehpad - FFIDEC	\N	2022-03-16 15:30:00	2022-03-16 17:00:00	\N	\N	4	0	\N	\N
639346	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition MI Ehpad - SNGIE	\N	2022-03-16 17:00:00	2022-03-16 18:30:00	\N	\N	3	0	\N	\N
639397	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière	\N	2022-03-16 11:05:00	2022-03-16 12:05:00	\N	\N	8	0	\N	\N
639459	DELEGATION	AUCUNE	\N	\N	206	Examen des conclusions de l'audition publique sur la gestion de l'eau	\N	2022-03-17 11:40:00	2022-03-17 12:50:00	\N	\N	7	0	\N	\N
639476	MISSION	AUCUNE	\N	CULTURE	\N	Réunion 20220323a	\N	2022-03-23 11:05:00	2022-03-23 13:00:00	2022-03-23 14:43:41	2022-03-23 15:00:19	7	0	\N	\N
639477	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur CE Ehpad - Dr Seramy médecin coordonnateur à Bouffémont	\N	2022-03-17 16:00:00	2022-03-17 17:00:00	\N	\N	2	0	\N	\N
639478	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI France compétences - Table ronde opérateurs compétences	\N	2022-03-29 09:30:00	2022-03-29 11:20:00	\N	\N	2	0	\N	\N
639479	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI France compétences - Audition de la DGEFP	\N	2022-03-29 16:00:00	2022-03-29 17:00:00	\N	\N	2	0	\N	\N
639480	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI France compétences - Audition DGESCO-DGESIP	\N	2022-03-29 17:00:00	2022-03-29 18:10:00	\N	\N	2	0	\N	\N
639481	MISSION	AUCUNE	\N	CULTURE	\N	Réunion 20220323b	\N	2022-03-23 14:00:00	2022-03-23 14:55:00	2022-03-23 15:11:46	2022-03-24 15:07:49	5	0	\N	\N
639511	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur CE Ehpad - M. Eoche-Duval	\N	2022-03-17 10:30:00	2022-03-17 11:30:00	\N	\N	3	0	\N	\N
639523	MISSION	AUDRAP	\N	SECUECO	\N	Audition Mme Vogel 	\N	2022-03-17 10:00:00	2022-03-17 12:00:00	\N	\N	2	0	\N	\N
725546	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2023-05-03 10:31:00	2023-05-03 12:00:00	2023-05-09 14:35:18	2023-05-09 18:08:13	37	0	\N	\N
732775	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désignations -  PJL Douane (amendements)	Désignations -  PJL Douane (amendements)	2023-05-24 09:30:00	2023-05-24 10:00:00	2023-05-24 10:26:20	2023-05-24 11:12:30	36	1	\N	\N
639605	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	France Universités (Conférence des présidents d'université)	Audition de M. Gellé et Mme Woronoff	2022-03-17 14:00:00	2022-03-17 15:00:00	\N	\N	1	0	\N	\N
639606	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Faculté de pharmacie de Montpellier	Audition de M. Lisowski	2022-03-17 15:00:00	2022-03-17 16:00:00	\N	\N	1	0	\N	\N
639607	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI Réforme études de santé actualisée	Audition de M. Bamas	2022-03-17 16:00:00	2022-03-17 17:00:00	\N	\N	1	0	\N	\N
639623	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Observatoire du patrimoine religieux	\N	2022-03-16 14:45:00	2022-03-16 16:30:00	\N	\N	3	0	\N	\N
639648	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - Maisons France services - Opérateurs France Services/ANCT	Contrôle 2022 - Maisons France services - Opérateurs France Services/ANCT	2022-03-16 09:15:00	2022-03-16 11:40:00	\N	\N	1	0	\N	\N
639658	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Conférence interparlementaire article 13 du TSCG à Bruxelles - Mars 2022	Conférence interparlementaire article 13 du TSCG à Bruxelles - Mars 2022	2022-03-15 10:25:00	2022-03-16 16:15:00	\N	\N	4	0	\N	\N
639663	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - ZAN - Citadia/Revue Urbanisme/Plan Bleu/EPF d'Etat, EPFL et FNAU	Contrôle 2022 - ZAN - Citadia/Revue Urbanisme/Plan Bleu/EPF d'Etat, EPFL et FNAU	2022-03-15 14:30:00	2022-03-15 18:30:00	\N	\N	1	0	\N	\N
639665	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - ZAN - DGALN/ANCT	Contrôle 2022 - ZAN - ANCT	2022-03-16 09:30:00	2022-03-16 11:30:00	\N	\N	1	0	\N	\N
639667	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - ZAN - Cab MIN Logement	Contrôle 2022 - ZAN - Cab MIN Logement	2022-03-16 14:15:00	2022-03-16 15:15:00	\N	\N	1	0	\N	\N
639669	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - France TV - France.tv studio et distribution/ France 2 Cinéma	Contrôle 2022 - France TV - France.tv studio et distribution/ France 2 Cinéma	2022-03-17 09:30:00	2022-03-17 11:30:00	\N	\N	1	0	\N	\N
639671	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - France TV - France 3 Cinéma	Contrôle 2022 - France TV - France 3 Cinéma	2022-03-21 14:00:00	2022-03-21 14:50:00	\N	\N	1	0	\N	\N
639673	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Douane face au trafic de stupéfiants - Ambassade de France Pays-Bas	Contrôle 2021 - Douane face au trafic de stupéfiants - Ambassade de France Pays-Bas	2022-03-15 15:45:00	2022-03-15 16:50:00	\N	\N	1	0	\N	\N
639676	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Douane face au trafic de stupéfiants - OFAST/DGPN	Contrôle 2021 - Douane face au trafic de stupéfiants - OFAST/DGPN	2022-03-16 10:15:00	2022-03-16 12:40:00	\N	\N	2	0	\N	\N
639679	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Douane face au trafic de stupéfiants - TRACFIN	Contrôle 2021 - Douane face au trafic de stupéfiants - TRACFIN	2022-03-16 14:00:00	2022-03-16 14:50:00	\N	\N	2	0	\N	\N
639946	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audition de Mme Alexandra de Hoop Scheffer	Audition de Mme Alexandra de Hoop Scheffer	2022-03-23 13:45:00	2022-03-23 14:45:00	\N	\N	4	0	\N	\N
639951	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audition de M. François Heisbourg	Audition de M. François Heisbourg	2022-03-23 15:45:00	2022-03-23 16:45:00	\N	\N	2	0	\N	\N
640075	COM_ENQUETE	PLENIERE	\N	MEDIA	\N	Présentation du rapport	\N	2022-03-29 18:05:00	2022-03-29 23:30:00	2022-03-30 09:24:46	2022-03-30 17:28:54	18	0	\N	\N
640076	DELEGATION	AUDRAP	\N	\N	PROS	Audition agence de l'eau Loire-Bretagne	\N	2022-03-15 14:30:00	2022-03-15 15:30:00	\N	\N	2	0	\N	\N
640081	DELEGATION	AUDRAP	\N	\N	PROS	Audition agence de l'eau Seine-Normandie	\N	2022-03-15 15:30:00	2022-03-15 16:30:00	\N	\N	3	0	\N	\N
640087	DELEGATION	AUDRAP	\N	\N	PROS	Audition agence de l'eau Adour-Garonne	\N	2022-03-15 16:30:00	2022-03-15 17:30:00	\N	\N	3	0	\N	\N
640092	DELEGATION	AUDRAP	\N	\N	PROS	Audition agence de l'eau Rhin-Meuse	\N	2022-03-15 17:30:00	2022-03-15 18:30:00	\N	\N	3	0	\N	\N
640107	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Fondation de la sauvegarde de l'art français	\N	2022-03-29 14:00:00	2022-03-29 15:10:00	\N	\N	3	0	\N	\N
640126	MISSION	AUCUNE	\N	SECUECO	\N	Adoption du rapport	\N	2022-03-30 09:10:00	2022-03-30 13:15:00	2022-03-30 12:11:36	2022-03-30 17:28:57	7	0	\N	\N
640177	ETUDES	AUDRAP	\N	\N	\N	SE Pêche et produits de la mer - Audition Ifremer	SE Pêche et produits de la mer - Audition Ifremer	2022-03-29 14:15:00	2022-03-29 15:45:00	\N	\N	7	0	\N	1012
640186	COM_EURO	AUDRAP	\N	AFEU	\N	Europe du médicament 	Europe du médicament - Audition Inserm 	2022-03-22 15:00:00	2022-03-22 16:00:00	\N	\N	2	0	\N	\N
640578	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	ENTREPRISES	réunion technique sur les règles juridiques et fiscales en matière de transmission d¿entre	réunion technique sur les règles juridiques et fiscales en matière de transmission d¿entre	2022-03-30 14:20:00	2022-03-30 16:20:00	\N	\N	12	0	\N	\N
640745	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur MI Ehpad - ARS occitanie	\N	2022-03-31 14:00:00	2022-03-31 15:30:00	\N	\N	4	0	\N	\N
640757	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur MI Ehpad	\N	2022-03-31 15:30:00	2022-03-31 17:00:00	\N	\N	4	0	\N	\N
640784	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Francis Abramovici	\N	2022-04-01 09:35:00	2022-04-01 10:35:00	\N	\N	2	0	\N	\N
640787	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Antoine Pariente et M. Bernard Bégaud	\N	2022-03-31 09:35:00	2022-03-31 11:00:00	\N	\N	3	0	\N	\N
640791	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Jérémy Ward et M. Jocelyn Raude	\N	2022-03-31 11:00:00	2022-03-31 12:05:00	\N	\N	3	0	\N	\N
640795	DELEGATION	AUDRAP	\N	\N	206	Audition ANSM	\N	2022-03-28 09:40:00	2022-03-28 12:05:00	\N	\N	4	0	\N	\N
640800	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Audition Dgesco	\N	2022-04-06 10:00:00	2022-04-06 11:00:00	\N	\N	0	0	\N	\N
640801	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Table ronde réseaux de chambres consulaires	\N	2022-04-05 16:00:00	2022-04-05 17:30:00	\N	\N	3	0	\N	\N
723631	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de M. Pierre Moscovici	\N	2023-04-12 09:20:00	2023-04-12 10:20:00	2023-04-12 15:52:07	2023-04-12 17:24:41	56	0	\N	\N
723660	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Table ronde fédérations sportives	\N	2023-04-12 09:30:00	2023-04-12 11:40:00	2023-04-12 14:50:53	2023-04-12 17:24:40	31	0	\N	\N
723712	GIA	AUCUNE	\N	\N	\N	Entretien Ambassadrice d'Italie	Entretien avec Mme Emanuela d'Alessandro, Ambassadrice d'Italie en France	2023-04-12 08:00:00	2023-04-12 09:15:00	\N	\N	6	0	621	\N
724024	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Euro 7 - ONG TRansport et Environnement	\N	2023-03-20 09:30:00	2023-03-20 10:15:00	\N	\N	2	0	\N	\N
724841	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition M. Jean-Noël Barrot	\N	2023-04-12 09:05:00	2023-04-12 10:20:00	2023-04-12 17:37:05	2023-04-28 11:37:07	43	0	\N	\N
725363	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2023-04-13 09:00:00	2023-04-13 12:30:00	\N	\N	4	0	\N	\N
725544	DELEGATION	AUCUNE	\N	\N	211	Table ronde Parentalité outre-mer (Guyane et St-Pierre-et-Miquelon)	\N	2023-05-04 14:00:00	2023-05-04 16:40:00	\N	\N	6	0	\N	\N
725545	DELEGATION	AUCUNE	\N	\N	211	Table ronde Santé des femmes au travail (Violences sexistes et sexuelles))	\N	2023-05-04 08:35:00	2023-05-04 10:40:00	\N	\N	6	0	\N	\N
725555	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2023-05-02 14:00:00	2023-05-02 15:00:00	2023-05-10 12:41:10	2023-05-10 14:53:34	26	0	\N	\N
725556	ETUDES	AUTRE	\N	\N	\N	Audition SNSM	Audition SNSM	2023-04-12 14:05:00	2023-04-12 14:55:00	\N	\N	6	0	\N	908
725585	MISSION	AUDRAP	\N	GEAU	\N	Audition ministère de l'agriculture	\N	2023-04-19 10:00:00	2023-04-19 11:00:00	\N	\N	1	0	\N	\N
725586	MISSION	AUDRAP	\N	GEAU	\N	Voies navigables de France	\N	2023-04-19 11:00:00	2023-04-19 12:00:00	\N	\N	1	0	\N	\N
725587	MISSION	AUDRAP	\N	GEAU	\N	Audition Villes de France	\N	2023-04-19 14:00:00	2023-04-19 15:15:00	\N	\N	2	0	\N	\N
725589	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI patrimoine écologique	\N	2023-04-19 09:00:00	2023-04-19 10:00:00	\N	\N	1	0	\N	\N
725591	MISSION	DEPLACEMENT	\N	BATI	\N	Visite d'une cour "Oasis" à Courbevoie	\N	2023-04-18 17:00:00	2023-04-18 18:30:00	\N	\N	1	0	\N	\N
725593	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Permis de conduire	Audition rapporteur - PPL Permis de conduire	2023-04-18 16:15:00	2023-04-18 17:00:00	\N	\N	1	0	\N	\N
725595	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Permis de conduire	Audition rapporteur - PPL Permis de conduire	2023-04-18 17:45:00	2023-04-18 19:30:00	\N	\N	1	0	\N	\N
725606	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Douane	Audition rapporteur - PJL Douane	2023-04-19 09:00:00	2023-04-19 11:30:00	\N	\N	1	0	\N	\N
725608	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Douane	Audition rapporteur - PJL Douane	2023-04-19 13:30:00	2023-04-19 15:00:00	\N	\N	1	0	\N	\N
725610	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Respect du droit à l'image des enfants	Audition rapporteur - PPL Respect du droit à l'image des enfants	2023-04-19 15:25:00	2023-04-19 17:00:00	\N	\N	1	0	\N	\N
725612	MISSION	DEPLACEMENT	\N	BATI	\N	Déplacement Nancy: TR avec les acteurs du territoire & visites d'établissements scolaires	\N	2023-04-13 09:00:00	2023-04-13 19:00:00	\N	\N	2	0	\N	\N
725639	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions MI Consigne	Auditions MI Consigne	2023-04-18 16:15:00	2023-04-18 18:00:00	\N	\N	1	0	\N	\N
725641	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition MI Consigne	Audition MI Consigne	2023-04-19 10:30:00	2023-04-19 11:15:00	\N	\N	1	0	\N	\N
725643	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition MI Consigne	Audition MI Consigne	2023-04-19 13:15:00	2023-04-19 15:00:00	\N	\N	1	0	\N	\N
725645	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition MI Consigne	Audition MI Consigne	2023-04-20 16:00:00	2023-04-20 16:45:00	\N	\N	1	0	\N	\N
725647	MECSS	AUDRAP	\N	\N	MECSS	Audition de la CCMSA	\N	2023-05-09 14:15:00	2023-05-09 15:00:00	\N	\N	2	0	\N	\N
725648	MECSS	AUDRAP	\N	\N	MECSS	Audition de l'Urssaf Caisse nationale	\N	2023-05-09 15:00:00	2023-05-09 16:00:00	\N	\N	2	0	\N	\N
725650	MECSS	AUDRAP	\N	\N	MECSS	MI Solidarité à la source - Audition de l'Agirc-Arrco	\N	2023-05-10 14:00:00	2023-05-10 15:00:00	\N	\N	2	0	\N	\N
725651	MECSS	AUDRAP	\N	\N	MECSS	MI Solidarité à la source - Audition du HCFiPS	\N	2023-05-10 16:30:00	2023-05-10 17:30:00	\N	\N	2	0	\N	\N
725652	MECSS	AUDRAP	\N	\N	MECSS	Audition de la DGCS	\N	2023-05-10 17:30:00	2023-05-10 18:45:00	\N	\N	2	0	\N	\N
725653	MECSS	AUDRAP	\N	\N	MECSS	MI Solidarité à la source ¿ Audition commune GIP-MDS et ASDDS	\N	2023-05-11 09:15:00	2023-05-11 10:30:00	\N	\N	2	0	\N	\N
725654	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions MI Consigne	Auditions MI Consigne	2023-04-21 10:00:00	2023-04-21 12:00:00	\N	\N	1	0	\N	\N
725656	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition MI Consigne	Audition MI Consigne	2023-04-21 14:45:00	2023-04-21 15:30:00	\N	\N	1	0	\N	\N
725658	COM_ENQUETE	AUDRAP	\N	RENOV	\N	Auditions CERE	Auditions CERE	2023-04-20 08:30:00	2023-04-20 11:45:00	\N	\N	6	0	\N	\N
725705	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Boucliers tarifaires et amortisseurs - Audition Engie	Contrôle 2023 - Boucliers tarifaires et amortisseurs - Audition Engie	2023-04-13 15:20:00	2023-04-13 16:30:00	\N	\N	1	0	\N	\N
725707	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Modernisation DSNA - Audition M. BUCUROIU EuroControl	Contrôle 2023 - Modernisation DSNA - Audition M. BUCUROIU EuroControl	2023-04-14 09:45:00	2023-04-14 11:00:00	\N	\N	1	0	\N	\N
725709	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2023 - Modernisation DSNA - CRNA Reims	Contrôle 2023 - Modernisation DSNA - CRNA Reims	2023-04-24 14:30:00	2023-04-24 17:30:00	\N	\N	1	0	\N	\N
725711	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Risque PGE - Audition URSSAF	Contrôle 2023 - Risque PGE - Audition URSSAF	2023-04-19 09:30:00	2023-04-19 11:00:00	\N	\N	1	0	\N	\N
725714	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Service de santé des armées - Table-ronde Ministère de la Santé	Contrôle 2023 - Service de santé des armées - Table-ronde Ministère de la Santé	2023-04-19 16:30:00	2023-04-19 17:30:00	\N	\N	1	0	\N	\N
725716	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Service de santé des armées - Audition Etat-major armée de l'air	Contrôle 2023 - Service de santé des armées - Audition Etat-major armée de l'air	2023-04-20 10:30:00	2023-04-20 11:30:00	\N	\N	1	0	\N	\N
725718	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Service de santé des armées - Audition SG pour l'administration	Contrôle 2023 - Service de santé des armées - Audition Secrétariat général pour l'administration	2023-04-20 14:00:00	2023-04-20 15:00:00	\N	\N	1	0	\N	\N
725720	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - COROM - Audition Mme REGIS maire Iracoubo	Contrôle 2023 - COROM - Audition Mme REGIS maire Iracoubo	2023-04-11 14:00:00	2023-04-11 15:00:00	\N	\N	2	0	\N	\N
725723	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - COROM - Audition Commune de Sada	Contrôle 2023 - COROM - Audition Commune de Sada	2023-04-12 09:45:00	2023-04-12 10:30:00	\N	\N	2	0	\N	\N
725726	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - COROM - Audition M. SELLY maire de St Benoit	Contrôle 2023 - COROM - Audition M. SELLY maire de St Benoit	2023-04-12 10:30:00	2023-04-12 11:00:00	\N	\N	2	0	\N	\N
725729	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - COROM - Audition M. ATALLAH maire de Basse-Terre	Contrôle 2023 - COROM - Audition M. ATALLAH maire de Basse-Terre	2023-04-12 16:30:00	2023-04-12 17:15:00	\N	\N	2	0	\N	\N
725732	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - COROM - Audition M. DURIMEL maire de Pointe-à-Pitre	Contrôle 2023 - COROM - Audition M. DURIMEL maire de Pointe-à-Pitre	2023-04-12 17:15:00	2023-04-12 18:00:00	\N	\N	2	0	\N	\N
725735	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - COROM - Audition M. LAGUERRE maire de Fort de France	Contrôle 2023 - COROM - Audition M. LAGUERRE maire de Fort de France	2023-04-13 16:00:00	2023-04-13 16:45:00	\N	\N	2	0	\N	\N
640885	DELEGATION	AUDRAP	\N	\N	206	Audition Centre Régional de PharmacoVigilance	\N	2022-04-04 09:30:00	2022-04-04 11:40:00	\N	\N	3	0	\N	\N
640889	DELEGATION	AUDRAP	\N	\N	206	Audition de Mme Cotton	\N	2022-04-05 09:40:00	2022-04-05 10:40:00	\N	\N	3	0	\N	\N
725666	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Respect du droit à l'image des enfants -  PPL Permis de conduire (rapports)	PPL Respect du droit à l'image des enfants -  PPL Permis de conduire (rapports)	2023-05-03 10:00:00	2023-05-03 11:35:00	2023-05-03 11:44:07	2023-05-03 18:03:31	36	2	\N	\N
640897	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Souveraineté economique	Auditions Souveraineté economique	2022-04-05 14:00:00	2022-04-05 18:00:00	\N	\N	4	0	\N	\N
640902	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - OAT vertes - ICMA	Contrôle 2022 - OAT vertes - ICMA	2022-04-05 16:00:00	2022-04-05 17:00:00	\N	\N	1	0	\N	\N
640904	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - OAT vertes - Crédit Agricole/SFIL	Contrôle 2022 - OAT vertes - Crédit Agricole/SFIL	2022-04-06 10:00:00	2022-04-06 12:00:00	\N	\N	1	0	\N	\N
640906	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - France TV - France Télévisions	Contrôle 2022 - France TV - France Télévisions	2022-04-04 13:55:00	2022-04-04 15:05:00	\N	\N	1	0	\N	\N
640908	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 -  Régimes des retraites RATP et Marins - RATP	Contrôle 2022 -  Régimes des retraites RATP et Marins - RATP	2022-04-05 14:30:00	2022-04-05 16:30:00	\N	\N	1	0	\N	\N
640910	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 -  Régimes des retraites RATP et Marins - CSGM	Contrôle 2022 -  Régimes des retraites RATP et Marins - CSGM	2022-04-06 09:50:00	2022-04-06 11:00:00	\N	\N	1	0	\N	\N
640912	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition MI énergie et hydrogène nucléaires	Audition MI énergie et hydrogène nucléaires	2022-03-29 09:45:00	2022-03-29 11:00:00	\N	\N	3	0	\N	\N
640913	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition énergie et hydrogène nucléaires	\N	2022-03-30 15:00:00	2022-03-30 17:00:00	\N	\N	0	0	\N	\N
640914	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Greenpeace France	\N	2022-03-30 16:00:00	2022-03-30 17:00:00	\N	\N	0	0	\N	\N
640915	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition NégaWatt	\N	2022-03-30 15:00:00	2022-03-30 16:00:00	\N	\N	0	0	\N	\N
642012	MISSION	AUCUNE	\N	FONDSMER	\N	Table ronde bassin Atlantique	Table ronde bassin Atlantique	2022-05-02 20:00:00	2022-05-02 21:30:00	2022-05-02 21:57:39	2022-05-09 16:20:25	8	0	\N	\N
655686	GIA	AUCUNE	\N	\N	\N	Déplacement d'une délégation du groupe d'amitié en Pologne	Déplacement d'une délégation du groupe d'amitié en Pologne	2022-09-05 08:00:00	2022-09-06 22:00:00	\N	\N	3	0	600	\N
655690	GIA	AUCUNE	\N	\N	\N	Déplacement d'une délégation du groupe d'amitié en Pologne	Déplacement d'une délégation du groupe d'amitié en Pologne	2022-09-07 08:00:00	2022-09-07 22:00:00	\N	\N	2	0	600	\N
655693	GIA	AUCUNE	\N	\N	\N	Déplacement d'une délégation du groupe d'amitié en Pologne	Déplacement d'une délégation du groupe d'amitié en Pologne	2022-09-09 08:00:00	2022-09-09 17:00:00	\N	\N	1	0	600	\N
655707	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Régime de réélection des juges consulaires	PPL Régime de réélection des juges consulaires	2022-09-16 09:00:00	2022-09-16 10:45:00	\N	\N	1	0	\N	\N
655709	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Régime de réélection des juges consulaires	PPL Régime de réélection des juges consulaires	2022-09-19 10:00:00	2022-09-19 11:30:00	\N	\N	1	0	\N	\N
656177	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2022-10-05 10:15:00	2022-10-05 12:20:00	2022-10-05 16:22:01	2022-10-05 17:35:20	38	0	\N	\N
656178	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2022-10-05 16:30:00	2022-10-05 18:00:00	2022-10-07 17:00:17	2022-10-07 17:25:33	34	0	\N	\N
656179	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Formation sage-femme - Audition rapporteure	\N	2022-09-23 15:00:00	2022-09-23 16:00:00	\N	\N	1	0	\N	\N
656208	GIA	AUCUNE	\N	\N	\N	Réunion du groupe d'amitié France-Russie	Entretien avec M. Vladimir Milov, ancien vice-ministre de l'énergie de la Fédération de Russie	2022-09-21 17:00:00	2022-09-21 18:00:00	\N	\N	6	0	608	\N
659661	GIA	AUCUNE	\N	\N	\N	Coopé - Entretien avec Mme Arielle KAYABAGA, députée fédérale de l¿Ontario	Coopé - Entretien avec Mme Arielle KAYABAGA, députée fédérale de l¿Ontario	2022-10-10 14:00:00	2022-10-10 15:00:00	\N	\N	1	0	583	\N
662932	GIA	AUCUNE	\N	\N	\N	Entretien avec la Présidente du Sénat roumain par interim	Entretien avec la Présidente du Sénat roumain par interim	2022-10-18 15:30:00	2022-10-18 16:15:00	\N	\N	5	0	605	\N
662946	GIA	AUCUNE	\N	\N	\N	Audition des ambassadeurs du Cône Sud	Audition commune de l'ambassadeur du Chili, de l'ambssadrice du paraguay et de la ministre-conseillère d'Argentine'	2022-10-18 18:00:00	2022-10-18 19:45:00	\N	\N	11	0	978	\N
663149	GIA	AUCUNE	\N	\N	\N	Audition de M.  Quentin Teisseire, sous-directeur de l'Afrique centrale au MEAE	Audition de M.  Quentin Teisseire, sous-directeur de l'Afrique centrale au MEAE	2022-10-18 15:45:00	2022-10-18 17:00:00	\N	\N	6	0	572	\N
663156	GIA	AUCUNE	\N	\N	\N	Entretien avec une délégation d'intellectuels et relais d'opinion mongols	Entretien avec une délégation d'intellectuels et relais d'opinion mongols invités par ORANOs	2022-10-17 17:30:00	2022-10-17 20:30:00	\N	\N	1	0	612	\N
663158	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2022-10-18 17:30:00	2022-10-18 19:00:00	\N	\N	3	0	\N	\N
663257	GIA	AUCUNE	\N	\N	\N	Rencontre avec Mme Hina Rabbani Khar, ministre déléguée aux affaires étrangères du Pakista	\N	2022-10-18 18:30:00	2022-10-18 19:30:00	\N	\N	2	0	619	\N
688512	GIA	AUCUNE	\N	\N	\N	Petit déjeuner de travail avec l'Ambassadeur de France au Tadjikistan 	Petit déjeuner de travail avec Michel TARRAN, Ambassadeur de France au Tadijikistan	2022-12-07 08:00:00	2022-12-07 09:15:00	\N	\N	7	0	556	\N
688520	GIA	AUCUNE	\N	\N	\N	Audition de deux représentantes des Démocrates à l'étranger	Audition de Danielle FOLETT, Présidente, et Amy ¨PORTER, chargée de communication de Democrats Abroad France	2022-12-06 18:00:00	2022-12-06 20:30:00	\N	\N	5	0	590	\N
688582	GIA	AUCUNE	\N	\N	\N	Déjeuner avec M. Nicu Popescu, Vice Premier ministre de la République de Moldavie	Déjeuner avec M. Nicu Popescu, Vice Premier ministre de la République de Moldavie, ministre des affaires étrangères	2022-11-10 12:30:00	2022-11-10 14:00:00	\N	\N	2	0	851	\N
688587	GIA	AUCUNE	\N	\N	\N	Déplacement d'une délégation en République de Moldavie	Déplacement d'une délégation en République de Moldavie	2022-05-16 00:00:00	2022-05-20 00:00:00	\N	\N	2	0	851	\N
688644	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Gestion de l'eau	Débat Gestion de l'eau	2023-01-10 14:30:00	2023-01-10 16:10:00	\N	\N	83	0	\N	\N
688645	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat ZFE	Débat ZFE	2023-01-10 16:10:00	2023-01-10 17:45:00	\N	\N	85	0	\N	\N
688646	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Mieux rémunérer le travail	Débat Mieux rémunérer le travail	2023-01-10 17:45:00	2023-01-10 19:25:00	\N	\N	57	0	\N	\N
688647	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat RSE entreprises	Débat RSE entreprises	2023-01-10 21:30:00	2023-01-10 23:20:00	\N	\N	25	0	\N	\N
688648	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2023-01-11 15:00:00	2023-01-11 16:20:00	\N	\N	295	0	\N	\N
688649	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat d'actualité	Débat d'actualité	2023-01-11 16:40:00	2023-01-11 18:20:00	\N	\N	96	0	\N	\N
688650	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Logement Outre-mer	Débat Logement Outre-mer	2023-01-11 21:30:00	2023-01-11 23:15:00	\N	\N	19	0	\N	\N
688651	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2023-01-12 10:30:00	2023-01-12 12:35:00	\N	\N	30	0	\N	\N
688652	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR 34-1 système électrique	PPR 34-1 système électrique	2023-01-12 14:30:00	2023-01-12 15:50:00	\N	\N	23	0	\N	\N
688653	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Évasion fiscale	Débat Évasion fiscale	2023-01-11 18:20:00	2023-01-11 20:00:00	\N	\N	39	0	\N	\N
689113	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Retraite de base des non-salariés agricoles - Audition du député Julien Dive 	\N	2023-01-10 14:15:00	2023-01-10 14:45:00	\N	\N	2	0	\N	\N
689178	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL JOP 2024 - Audition CCI France	\N	2023-01-10 16:30:00	2023-01-10 17:30:00	\N	\N	1	0	\N	\N
689348	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Jeux Olympiques et Paralympiques de 2024	PJL Jeux Olympiques et Paralympiques de 2024	2023-01-10 15:00:00	2023-01-10 16:30:00	\N	\N	4	0	\N	\N
690808	ETUDES	AUDRAP	\N	\N	\N	Visite centre entraînement PSG à Poissy	\N	2023-01-12 09:00:00	2023-01-12 11:30:00	\N	\N	9	0	\N	934
690836	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJLFRSS pour 2023 - Audition du Medef	\N	2023-01-12 09:00:00	2023-01-12 09:45:00	\N	\N	6	0	\N	\N
690837	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJLFRSS pour 2023 - Audition de la CPME	\N	2023-01-12 09:45:00	2023-01-12 10:30:00	\N	\N	6	0	\N	\N
740314	COM_SPECIALE	AUDRAP	\N	ESNU	\N	PJL Sécuriser et réguler l'espace numérique	PJL Sécuriser et réguler l'espace numérique	2023-06-13 16:30:00	2023-06-13 18:00:00	\N	\N	2	0	\N	\N
740318	COM_SPECIALE	AUDRAP	\N	ESNU	\N	PJL Sécuriser et réguler l'espace numérique	PJL Sécuriser et réguler l'espace numérique	2023-06-14 08:00:00	2023-06-14 10:00:00	\N	\N	3	0	\N	\N
745765	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Plein emploi - Audition ADF	\N	2023-06-22 08:30:00	2023-06-22 09:30:00	\N	\N	5	0	\N	\N
745791	COM_PERMANENTE	AUTRE	\N	LOIS	\N	MI Français de l'étranger - Audition d'Olivier Becht, ministre délégué	MI Français de l'étranger - Audition d'Olivier Becht, ministre délégué	2023-06-27 09:35:00	2023-06-27 10:40:00	2023-06-27 13:35:44	2023-06-28 10:16:14	8	0	\N	\N
745794	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Agressions des élus locaux - Audition de la gendarmerie nationale	Agressions des élus locaux - Audition de la gendarmerie nationale	2023-06-28 09:35:00	2023-06-28 10:55:00	2023-06-28 11:42:27	2023-06-29 14:30:55	28	0	\N	\N
745795	COM_PERMANENTE	AUTRE	\N	LOIS	\N	MI Français de l'étranger - Examen du rapport d'information	MI Français de l'étranger - Examen du rapport d'information	2023-06-28 11:00:00	2023-06-28 11:30:00	2023-06-28 11:42:42	2023-06-29 14:30:54	12	0	\N	\N
745808	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Données de santé - Audition commune SGAE et DNS	\N	2023-06-20 15:45:00	2023-06-20 16:45:00	\N	\N	1	0	\N	\N
745809	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Données de santé - Table ronde des fédérations hospitalières	\N	2023-06-20 16:45:00	2023-06-20 17:45:00	\N	\N	2	0	\N	\N
745858	DELEGATION	AUTRE	\N	\N	DSOM	Foncier agricole outre-mer : examen du rapport d'information	\N	2023-06-28 13:30:00	2023-06-28 15:00:00	\N	\N	8	0	\N	\N
745859	DELEGATION	AUCUNE	\N	\N	DSOM	Examen du rapport d'information parentalité outre-mer	\N	2023-07-11 16:00:00	2023-07-11 16:50:00	\N	\N	12	0	\N	\N
745864	MISSION	AUDRAP	\N	AVENCOMM	\N	Émilie Schumacher, maire de Clémensat	Émilie Schumacher, maire de Clémensat	2023-06-22 10:20:00	2023-06-22 10:45:00	\N	\N	1	0	\N	\N
745903	DELEGATION	AUCUNE	\N	\N	PROS	Examen du rapport sur l'occupation de l'espace à l'horizon 2050	\N	2023-06-29 08:35:00	2023-06-29 09:45:00	\N	\N	4	0	\N	\N
745978	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	SIAE du Bourget	SIAE du Bourget	2023-06-20 14:00:00	2023-06-20 18:00:00	\N	\N	8	0	\N	\N
749997	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Examen de 3 rapports d'information + 1 communication	Examen de 3 rapports d'information + 1 communication	2023-07-12 10:00:00	2023-07-12 12:20:00	2023-07-12 15:07:46	2023-07-13 11:22:51	30	5	\N	\N
752214	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Orientation et programmation du ministère de la justice 2023-2027	PJL Orientation et programmation du ministère de la justice 2023-2027	2023-09-26 09:00:00	2023-09-26 09:45:00	\N	\N	2	0	\N	\N
752410	SEANCE_PLENIERE	AUTRE	\N	\N	\N	Renouvellement des instances	Renouvellement des instances	2023-10-04 14:30:00	2023-10-04 15:30:00	\N	\N	192	0	\N	\N
752411	SEANCE_PLENIERE	AUTRE	\N	\N	\N	Renouvellement des instances	Renouvellement des instances	2023-10-04 18:30:00	2023-10-04 19:30:00	\N	\N	97	0	\N	\N
752412	SEANCE_PLENIERE	AUTRE	\N	\N	\N	Renouvellement des instances	Renouvellement des instances	2023-10-05 14:30:00	2023-10-05 15:30:00	\N	\N	1	0	\N	\N
760812	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLC Referendum	PPLC Referendum	2023-10-27 14:00:00	2023-10-27 16:10:00	\N	\N	1	0	\N	\N
761130	COM_PERMANENTE	AUTRE	\N	AFCL	\N	PLF 2024 - Audition de Gabriel Attal	\N	2023-11-08 16:15:00	2023-11-08 18:50:00	2023-11-15 11:38:35	2023-11-15 14:05:11	31	1	\N	\N
761131	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - RS France 2030 - Audition SGPI	PLF pour 2024 - RS France 2030 - Audition du secrétaire général pour l'investissement (SGPI)	2023-10-24 16:00:00	2023-10-24 17:00:00	\N	\N	2	0	\N	\N
761171	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Culture Presse	\N	2023-10-31 09:00:00	2023-10-31 10:00:00	\N	\N	2	0	\N	\N
761172	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Association nationale des écoles supérieures d'art	\N	2023-10-31 09:00:00	2023-10-31 10:05:00	\N	\N	2	0	\N	\N
761181	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE 76 - PLF pour 2024 : examen rapports	PLENIERE 76 - PLF pour 2024 : examen rapports	2023-11-08 16:30:00	2023-11-08 18:00:00	2023-11-14 19:30:26	2023-11-15 11:34:55	19	2	\N	\N
761183	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE 74 - Examen rapport pour avis PLFSS, PLF pour 2024 - examen rapports	PLENIERE 74 - Examen rapport pour avis PLFSS, PLF pour 2024 - examen rapports	2023-11-07 14:35:00	2023-11-07 17:00:00	2023-11-14 19:15:05	2023-11-15 11:34:57	29	6	\N	\N
761184	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - RS CAS Pensions - Audition CRP-RATP	PLF pour 2024 - RS CAS Pensions - Audition Caisse de retraite du personnel de la RATP	2023-10-25 13:30:00	2023-10-25 14:30:00	\N	\N	1	0	\N	\N
761186	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - RS CAS Pensions - Audition Direction du budget	PLF pour 2024 - RS CAS Pensions - Audition de la direction du budget	2023-10-24 14:30:00	2023-10-24 15:30:00	\N	\N	1	0	\N	\N
761189	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - RS MIRES - Audition du CNRS	PLF pour 2024 - RS MIRES - Audition du CNRS	2023-10-25 18:00:00	2023-10-25 19:00:00	\N	\N	1	0	\N	\N
761191	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - RS MIRES - Audition de la DGRI	PLF pour 2024 - RS MIRES - Audition de la direction générale de la recherche et de l'innovation	2023-10-26 19:00:00	2023-10-26 20:00:00	\N	\N	1	0	\N	\N
761194	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - RS MIRES - Audition Cabinet ministre recherche et enseignement supérieur	PLF pour 2024 - RS MIRES - Audition du cabinet du mministre de la recherche et de l'enseignement supérieur	2023-10-27 14:30:00	2023-10-27 15:30:00	\N	\N	1	0	\N	\N
761198	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - RS MIRES - Audition de l'INSERM	PLF pour 2024 - RS MIRES - Audition de l'INSERM	2023-10-28 16:00:00	2023-10-28 17:00:00	\N	\N	1	0	\N	\N
761201	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - RS MIRES - Audition du CNES	PLF pour 2024 - RS MIRES - Audition du Centre national d'études spatiales	2023-10-29 17:00:00	2023-10-29 18:00:00	\N	\N	1	0	\N	\N
762668	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2024 - Audiovisuel	\N	2023-11-07 17:00:00	2023-11-07 18:00:00	\N	\N	2	0	\N	\N
761205	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - RS MIRES - Audition de l'Agence nationale de la recherche	PLF pour 2024 - RS MIRES - Audition de l'Agence nationale de la recherche	2023-10-30 18:00:00	2023-10-30 19:00:00	\N	\N	1	0	\N	\N
761207	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Défense - Audition du service du commissariat des armées	PLF pour 2024 - Défense - Audition du service du commissariat des armées	2023-10-25 14:00:00	2023-10-25 15:00:00	\N	\N	1	0	\N	\N
761212	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Défense - Audition Etat-Major armée de l'air et de l'espace	PLF pour 2024 - Défense - Audition de l'état-major de l'armée de l'air et de l'espace	2023-10-25 16:30:00	2023-10-25 17:30:00	\N	\N	1	0	\N	\N
761223	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Défense - Audition de la Direction générale de l'armement	PLF pour 2024 - Défense - Audition de la Direction générale de l'armement	2023-10-26 09:30:00	2023-10-26 10:30:00	\N	\N	1	0	\N	\N
761225	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Défense - Audition du Secrétariat général pour l'administration	PLF pour 2024 - Défense - Audition du Secrétariat général pour l'administration	2023-10-26 10:30:00	2023-10-26 11:30:00	\N	\N	1	0	\N	\N
761231	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2024 Assurance maladie - Audition de la DGS	\N	2023-10-31 09:30:00	2023-10-31 10:30:00	\N	\N	3	0	\N	\N
761635	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition de la CNIL	\N	2023-10-26 16:05:00	2023-10-26 16:55:00	\N	\N	1	0	\N	\N
761637	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition de la CNCTR	\N	2023-10-26 17:05:00	2023-10-26 17:45:00	\N	\N	1	0	\N	\N
761723	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition M. Fabien Genet	Audition M. Fabien Genet	2023-11-02 08:00:00	2023-11-02 10:30:00	\N	\N	1	0	\N	\N
761725	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions rapporteur	\N	2023-11-08 13:30:00	2023-11-08 15:00:00	\N	\N	0	0	\N	\N
761726	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Budget 2024 - Administration pénitentiaire - Auditions rapporteur	\N	2023-10-31 09:00:00	2023-10-31 11:00:00	\N	\N	1	0	\N	\N
761727	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Budget 2024 - Administration pénitentiaire - Auditions rapporteur	Budget 2024 - Administration pénitentiaire - Auditions rapporteur	2023-11-03 14:00:00	2023-11-03 16:15:00	\N	\N	1	0	\N	\N
761728	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Budget 2024 - Administration pénitentiaire - Auditions rapporteur	Budget 2024 - Administration pénitentiaire - Auditions rapporteur	2023-11-03 09:55:00	2023-11-03 11:45:00	\N	\N	1	0	\N	\N
761732	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - Budget 2024 - AGTE	Audition rapporteur - Budget 2024 - AGTE	2023-10-31 09:00:00	2023-10-31 11:00:00	\N	\N	1	0	\N	\N
640802	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI France compétences - Table ronde organisations professionnelles d'employeurs	\N	2022-04-05 09:00:00	2022-04-05 10:40:00	\N	\N	4	0	\N	\N
641085	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Mission d'information sur la politique étrangère américaine	\N	2022-04-06 14:30:00	2022-04-06 16:45:00	\N	\N	4	0	\N	\N
641090	GIA	AUCUNE	\N	\N	\N	Entretien avec Mme Tatiana KASTOUEVA-JEAN, Directrice du Centre Russie/ NEI de l'IFRI	Entretien avec Mme Tatiana KASTOUEVA-JEAN, Directrice du Centre Russie/ NEI de l'IFRI	2022-02-01 09:00:00	2022-02-01 10:30:00	\N	\N	3	0	530	\N
641094	GIA	AUCUNE	\N	\N	\N	Audition de MM. JEANGÈNE VILMER (IRSEM) et MONGRENIER (Institut français de géopolitique)	Audition de MM. JEANGÈNE VILMER (IRSEM) et MONGRENIER (Institut français de géopolitique)	2022-03-15 08:30:00	2022-03-15 10:00:00	\N	\N	11	0	530	\N
641101	GIA	AUCUNE	\N	\N	\N	Entretien  avec Mme Luidmyla Buimister députée de la Rada	Entretien  avec Mme Luidmyla Buimister députée de la Rada	2022-03-16 09:30:00	2022-03-16 11:00:00	\N	\N	11	0	530	\N
642678	COM_PERMANENTE	AUDRAP	\N	FINC	\N	MCC 2022 - Audiovisuel Public - APE/France Télévisions	MCC 2022 - Audiovisuel Public - APE/France Télévisions	2022-05-12 09:30:00	2022-05-12 11:50:00	\N	\N	2	0	\N	\N
643854	ETUDES	AUDRAP	\N	\N	\N	Audition Gérald Bronner	\N	2022-06-07 15:00:00	2022-06-07 17:00:00	\N	\N	16	0	\N	1008
643875	COM_PERMANENTE	AUDRAP	\N	FINC	\N	MI Fraude et évasion fiscales - SEJF/TR associations	MI Fraude et évasion fiscales - SEJF/TR associations	2022-06-07 14:30:00	2022-06-07 16:40:00	\N	\N	10	0	\N	\N
644240	GIA	AUCUNE	\N	\N	\N	Coopé-Visite de M. Vieng Akhone SOURIYO, DG de l'ONG laotienne  CHIAS	Coopé-Visite de M. Vieng Akhone SOURIYO, DG de l'ONG laotienne  CHIAS	2022-05-31 14:30:00	2022-05-31 15:15:00	\N	\N	2	0	577	\N
645202	MISSION	AUCUNE	\N	FONDSMER	\N	Examen du rapport d'information	Examen du rapport d'information	2022-06-21 14:30:00	2022-06-21 16:00:00	2022-06-21 15:57:18	2022-06-21 19:00:21	13	0	\N	\N
645256	GIA	AUCUNE	\N	\N	\N	Colloque international Business France 's'implanter aux Etats Unis"	Colloque international Business France 's'implanter aux Etats Unis"	2022-06-15 14:00:00	2022-06-15 20:00:00	\N	\N	5	0	590	\N
645276	GIA	AUCUNE	\N	\N	\N	Entretien avec L'ambassadrice de Singapour Madame Teow Lee Foo 	Entretien avec L'ambassadrice de Singapour Madame Teow Lee Foo accompagnée du Premiere Secrétaire Chua Shan Jee 	2022-06-14 12:45:00	2022-06-14 14:00:00	\N	\N	2	0	609	\N
645279	GIA	AUCUNE	\N	\N	\N	 \tEntretien avec M. LEE Yung Te, ministre de la culture 	 \tEntretien avec M. LEE Yung Te, ministre de la culture accompagné de Madame la députée CHIU Yi-Ying et une délégation d	2022-06-20 10:30:00	2022-06-20 12:30:00	\N	\N	1	0	623	\N
646187	COM_PERMANENTE	AUTRE	\N	FINC	\N	Contrôle budgétaire OAT vertes et Audition de M. Robert OPHÈLE sur le rapport annuel 2021 	Contrôle budgétaire OAT vertes et Audition de M. Robert OPHÈLE sur le rapport annuel 2021 de l¿AMF	2022-07-06 10:05:00	2022-07-06 12:20:00	2022-07-06 13:40:30	2022-07-06 16:05:10	35	1	\N	\N
646198	COM_PERMANENTE	AUTRE	\N	FINC	\N	PJLR 2021 et PLFR pour 2022 - Audition de MM. Bruno LE MAIRE, et Gabriel ATTAL, ministres	PJLR 2021 et PLFR pour 2022 - Audition de MM. Bruno LE MAIRE, ministre, et Gabriel ATTAL, ministre délégué	2022-07-08 09:20:00	2022-07-08 11:05:00	2022-07-08 11:45:46	2022-07-08 14:22:08	30	0	\N	\N
646199	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - RGA - DG Trésor/DGPR	Contrôle 2022 - RGA - DG Trésor/DGPR	2022-06-29 16:00:00	2022-06-29 18:15:00	\N	\N	1	0	\N	\N
646201	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - RGA - CCR	Contrôle 2022 - RGA - CCR	2022-06-30 11:15:00	2022-06-30 12:15:00	\N	\N	1	0	\N	\N
646203	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2022 - DGCCRF - Déplacement à Besançon	Contrôle 2022 - DGCCRF - Déplacement à Besançon	2022-07-01 07:00:00	2022-07-01 20:45:00	\N	\N	1	0	\N	\N
646205	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - DGCCRF - TR associations consommateurs	Contrôle 2022 - DGCCRF - TR associations consommateurs	2022-06-28 10:00:00	2022-06-28 12:25:00	\N	\N	2	0	\N	\N
646208	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - DGCCRF - Cour des comptes	Contrôle 2022 - DGCCRF - Cour des comptes	2022-06-28 14:00:00	2022-06-28 15:00:00	\N	\N	2	0	\N	\N
646209	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - DGCCRF - DGAL	Contrôle 2022 - DGCCRF - DGAL	2022-06-28 16:00:00	2022-06-28 17:00:00	\N	\N	2	0	\N	\N
646210	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - DGCCRF - TR Organisations patronales	Contrôle 2022 - DGCCRF - TR Organisations patronales	2022-06-28 18:00:00	2022-06-28 19:30:00	\N	\N	2	0	\N	\N
646211	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - DGCCRF - ACPR	Contrôle 2022 - DGCCRF - ACPR	2022-06-29 16:00:00	2022-06-29 17:00:00	\N	\N	2	0	\N	\N
646218	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - DGCCRF - DACG	Contrôle 2022 - DGCCRF - DACG	2022-06-29 14:00:00	2022-06-29 15:00:00	\N	\N	2	0	\N	\N
647461	DELEGATION	AUCUNE	\N	\N	COLTER	Table-ronde	\N	2022-07-07 09:00:00	2022-07-07 10:40:00	\N	\N	17	0	\N	\N
647508	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière	\N	2022-07-07 09:15:00	2022-07-07 10:15:00	2022-07-07 11:10:21	\N	5	0	\N	\N
647517	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Diffusion de contenus à caractère terroriste en ligne (amendements)	PPL Diffusion de contenus à caractère terroriste en ligne (amendements)	2022-07-12 14:00:00	2022-07-12 14:10:00	2022-07-12 14:14:48	2022-07-12 16:00:35	12	0	\N	\N
647518	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Veille et sécurité sanitaire - Audion du ministre de la santé et de la prévention	PJL Veille et sécurité sanitaire - Audion du ministre de la santé et de la prévention	2022-07-13 08:35:00	2022-07-13 09:40:00	2022-07-13 10:34:34	2022-07-13 19:07:02	32	3	\N	\N
647519	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Incidents au Stade de France - Examen du rapport d'information	Incidents au Stade de France - Examen du rapport d'information	2022-07-13 10:00:00	2022-07-13 11:20:00	2022-07-13 15:52:46	2022-07-13 19:06:59	64	3	\N	\N
647526	COM_EURO	AUTRE	\N	AFEU	\N	Réunion GS relation euro-britannique du 13 juillet	\N	2022-07-13 14:00:00	2022-07-13 15:00:00	2022-07-26 09:58:15	\N	5	0	\N	\N
647527	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Auditions MI Mégafeux	\N	2022-07-05 14:00:00	2022-07-05 17:30:00	\N	\N	0	0	\N	\N
647547	DELEGATION	AUDRAP	\N	\N	PROS	Audition de M. Jean-Marc STÉBÉ	\N	2022-07-06 11:30:00	2022-07-06 12:30:00	\N	\N	1	0	\N	\N
647549	DELEGATION	AUDRAP	\N	\N	PROS	Audition de M. BOUBA-OLGA	\N	2022-07-07 12:00:00	2022-07-07 13:00:00	\N	\N	1	0	\N	\N
647551	DELEGATION	AUDRAP	\N	\N	PROS	Audition de M. BENARD (Amazon France)	\N	2022-07-07 14:30:00	2022-07-07 15:30:00	\N	\N	1	0	\N	\N
655425	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion planière CATDD	\N	2022-09-14 09:00:00	2022-09-14 11:12:00	2022-09-14 11:49:07	2022-09-19 11:33:36	22	0	\N	\N
655465	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désignations - Rapport MCC Sécurisation de la chasse	Désignations - Rapport MCC Sécurisation de la chasse	2022-09-14 09:35:00	2022-09-14 10:55:00	2022-09-14 12:03:13	2022-09-19 11:33:37	46	1	\N	\N
655485	GIA	AUCUNE	\N	\N	\N	Déplacement au Népal	Déplacement au Népal d'une délégation du groupe d'amitié France-Népal	2022-09-05 08:30:00	2022-09-10 17:00:00	\N	\N	2	0	633	\N
655674	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2022-09-14 15:00:00	2022-09-14 17:00:00	\N	\N	2	0	\N	\N
655677	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désignations - Audition des membres du Comité des États généraux de la justice	Désignations - Audition des membres du Comité des États généraux de la justice	2022-09-21 09:00:00	2022-09-21 11:05:00	\N	\N	31	3	\N	\N
655678	COM_PERMANENTE	AUTRE	\N	LOIS	\N	MCC Délinquance des mineurs - Examen du rapport	MCC Délinquance des mineurs - Examen du rapport	2022-09-21 11:15:00	2022-09-21 12:10:00	2022-09-22 10:00:25	2022-09-22 15:26:05	41	3	\N	\N
655679	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOPMI - Etat et moyens de la sécurité civile - Audition de Gérald Darmanin	LOPMI - Etat et moyens de la sécurité civile - Audition de Gérald Darmanin	2022-09-21 16:05:00	2022-09-21 17:55:00	2022-09-22 10:00:52	2022-09-22 15:26:05	25	0	\N	\N
655681	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2021 - Situation et perspectives SNCF - Déplacement Ministère des Transports	Contrôle 2021 - Situation et perspectives SNCF - Déplacement Ministère des Transports	2022-09-07 18:15:00	2022-09-07 19:45:00	\N	\N	2	0	\N	\N
725738	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - COROM - Audition Commune de St Pierre (Martinique)	Contrôle 2023 - COROM - Audition Commune de St Pierre (Martinique)	2023-04-13 16:45:00	2023-04-13 17:30:00	\N	\N	2	0	\N	\N
725741	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - COROM - Audition IGA/CGEFI	Contrôle 2023 - COROM - Audition IGA/CGEFI	2023-04-13 17:30:00	2023-04-13 18:30:00	\N	\N	2	0	\N	\N
725744	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - COROM - Audition Commune de Cayenne	Contrôle 2023 - COROM - Audition Commune de Cayenne	2023-04-14 16:30:00	2023-04-14 17:15:00	\N	\N	2	0	\N	\N
725747	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition de M. Bernard Carayon, avocat	Audition de M. Bernard Carayon, avocat	2023-03-21 18:00:00	2023-03-21 19:00:00	\N	\N	2	0	\N	\N
725750	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Mme Lienemann et M. Lemoyne	Auditions Mme Lienemann et M. Lemoyne	2023-03-09 14:00:00	2023-03-09 18:00:00	\N	\N	2	0	\N	\N
725753	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Fonds de garantie de Bpifrance - Audition BpiFrance	Contrôle 2023 - Fonds de garantie de Bpifrance - Audition BpiFrance	2023-04-11 14:00:00	2023-04-11 15:30:00	\N	\N	2	0	\N	\N
725754	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Mme Lienemann et M. Lemoyne	Auditions Mme Lienemann et M. Lemoyne	2023-03-22 17:00:00	2023-03-22 19:30:00	\N	\N	2	0	\N	\N
725759	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Mme Marie-Noëlle Lienemann et M. Jean-Baptiste Lemoyne	Auditions Mme Marie-Noëlle Lienemann et M. Jean-Baptiste Lemoyne	2023-03-30 10:00:00	2023-03-30 12:30:00	\N	\N	2	0	\N	\N
725762	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Mme Marie-Noëlle Lienemann et M. Jean-Baptiste Lemoyne	Auditions Mme Marie-Noëlle Lienemann et M. Jean-Baptiste Lemoyne	2023-04-06 14:00:00	2023-04-06 18:45:00	\N	\N	2	0	\N	\N
725765	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Mme Marie-Noëlle Lienemann et M. Jean-Baptiste Lemoyne	Auditions Mme Marie-Noëlle Lienemann et M. Jean-Baptiste Lemoyne	2023-04-11 14:30:00	2023-04-11 19:00:00	\N	\N	2	0	\N	\N
725768	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Mme Marie-Noëlle Lienemann et M. Jean-Baptiste Lemoyne	Auditions Mme Marie-Noëlle Lienemann et M. Jean-Baptiste Lemoyne	2023-04-13 09:00:00	2023-04-13 13:10:00	\N	\N	2	0	\N	\N
725771	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL livre VII CMF - Audition DG Trésor	PJL livre VII CMF - Audition DG Trésor	2023-04-11 15:30:00	2023-04-11 16:30:00	\N	\N	1	0	\N	\N
725773	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL livre VII CMF - Audition M. COQUELIN IEDOM/IEOM	PJL livre VII CMF - Audition M. COQUELIN IEDOM/IEOM	2023-04-11 16:30:00	2023-04-11 17:15:00	\N	\N	1	0	\N	\N
725775	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Mission "Solidarité, insertion et égalité chances" - Asso droit des femmes	Contrôle 2023 - Mission "Solidarité, insertion et égalité chances" - Table-ronde associations Droits des femmes	2023-04-18 09:30:00	2023-04-18 11:30:00	\N	\N	2	0	\N	\N
725778	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Mission "Solidarité, insertion et égalité chances" - Asso aide alimentaire	Contrôle 2023 - Mission "Solidarité, insertion et égalité chances" - Table-ronde associations d'aide alimentaire	2023-04-18 14:30:00	2023-04-18 16:30:00	\N	\N	2	0	\N	\N
725781	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Mission "Solidarité, insertion et égalité chances" - Asso droit handicapés	Contrôle 2023 - Mission "Solidarité, insertion et égalité chances" - Table-ronde associations droits pers. handicapés	2023-04-19 09:30:00	2023-04-19 11:30:00	\N	\N	2	0	\N	\N
725784	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Modernisation DSNA - Audition CRNA Reims	Contrôle 2023 - Modernisation DSNA - Audition CRNA Reims	2023-04-24 15:00:00	2023-04-24 18:00:00	\N	\N	1	0	\N	\N
725792	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 2022 - Installation agriculteurs - Audition pour suites à donner	58-2 2022 - Installation agriculteurs - Audition pour suites à donner	2023-04-12 13:30:00	2023-04-12 15:00:00	\N	\N	2	0	\N	\N
725914	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2023-04-25 14:30:00	2023-04-25 17:00:00	\N	\N	3	0	\N	\N
726448	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 30	\N	2023-05-03 09:50:00	2023-05-03 11:00:00	2023-05-03 14:30:58	2023-05-03 18:03:32	40	6	\N	\N
726616	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI PreParE - Table ronde CFDT-CGT-FO-CFE/CGC	\N	2023-05-02 14:30:00	2023-05-02 15:30:00	\N	\N	3	0	\N	\N
726618	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI PreParE - Audition AMF	\N	2023-05-02 15:30:00	2023-05-02 16:30:00	\N	\N	3	0	\N	\N
727566	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Biens spoliés	\N	2023-05-03 17:00:00	2023-05-03 17:55:00	\N	\N	5	0	\N	\N
727567	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL biens spoliés	\N	2023-05-03 18:00:00	2023-05-03 19:00:00	\N	\N	3	0	\N	\N
727707	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	maj num	\N	2023-05-03 10:30:00	2023-05-03 12:00:00	\N	\N	1	0	\N	\N
727709	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Maj num	\N	2023-05-02 16:45:00	2023-05-02 17:45:00	\N	\N	1	0	\N	\N
727710	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	maj num	\N	2023-05-03 14:00:00	2023-05-03 15:00:00	\N	\N	1	0	\N	\N
727711	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	audition haine en ligne	\N	2023-05-03 18:00:00	2023-05-03 19:00:00	\N	\N	1	0	\N	\N
728216	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Influenceurs sur les réseaux sociaux 	PPL Encadrement centres de santé	2023-05-09 17:35:00	2023-05-09 20:05:00	\N	\N	88	0	\N	\N
728217	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Amélioration accès aux soins	CMP Amélioration accès aux soins	2023-05-09 15:30:00	2023-05-09 16:30:00	\N	\N	78	0	\N	\N
728218	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Installations nucléaires	CMP Installations nucléaires	2023-05-09 14:30:00	2023-05-09 15:30:00	\N	\N	61	0	\N	\N
728219	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Encadrement centres de santé	PPL Encadrement centres de santé	2023-05-09 16:30:00	2023-05-09 17:30:00	\N	\N	76	0	\N	\N
728220	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Influenceurs sur les réseaux sociaux	PPL Influenceurs sur les réseaux sociaux	2023-05-09 21:35:00	2023-05-09 23:40:00	\N	\N	57	0	\N	\N
728221	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2023-05-10 15:00:00	2023-05-10 16:30:00	\N	\N	288	0	\N	\N
728222	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Code monétaire et financier	PJL Code monétaire et financier	2023-05-10 16:35:00	2023-05-10 17:25:00	\N	\N	49	0	\N	\N
728224	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Respect droit à l'image des enfants	PPL Respect droit à l'image des enfants	2023-05-10 17:25:00	2023-05-10 19:10:00	\N	\N	43	0	\N	\N
728227	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Permis de conduire	PPL Permis de conduire	2023-05-10 19:15:00	2023-05-10 20:25:00	\N	\N	34	0	\N	\N
728230	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Application des lois Protection de l'enfance - Audition de la Cnape	\N	2023-05-02 16:30:00	2023-05-02 17:15:00	\N	\N	3	0	\N	\N
728231	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Application des lois Protection de l'enfance - Audition de l'Andass	\N	2023-05-02 17:15:00	2023-05-02 18:00:00	\N	\N	3	0	\N	\N
728232	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Application des lois Protection de l'enfance - Audition de M. Léo Mathey	\N	2023-05-02 18:15:00	2023-05-02 19:15:00	\N	\N	3	0	\N	\N
728233	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Données de santé - Audition de l'Inserm	\N	2023-05-02 16:15:00	2023-05-02 17:30:00	\N	\N	4	0	\N	\N
728234	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL entrepreneurs français à l'étranger	PPL entrepreneurs français à l'étranger	2023-05-03 17:15:00	2023-05-03 18:45:00	\N	\N	2	0	\N	\N
728246	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Fin de vie - Table ronde des représentants des cultes	\N	2023-05-02 14:00:00	2023-05-02 16:00:00	\N	\N	6	0	\N	\N
728257	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle Sécurité civile - Audition Etat major de la sécurité civile	Contrôle Sécurité civile - Audition Etat major de la sécurité civile	2023-05-02 11:00:00	2023-05-02 12:00:00	\N	\N	1	0	\N	\N
640007	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Table ronde de sociétés savantes	\N	2022-03-22 09:15:00	2022-03-22 10:45:00	\N	\N	3	0	\N	\N
640008	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Obésité - Table ronde d'organisations professionnelles	\N	2022-03-22 10:45:00	2022-03-22 12:00:00	\N	\N	3	0	\N	\N
640009	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Obésité - Audition de l'Oqali	\N	2022-03-23 10:45:00	2022-03-23 11:45:00	\N	\N	3	0	\N	\N
640010	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Obésité - Table ronde d'associations de consommateurs	\N	2022-03-23 14:00:00	2022-03-23 14:55:00	\N	\N	2	0	\N	\N
640011	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition du Syndicat national de la restauration collective (SNRC)	\N	2022-03-23 15:35:00	2022-03-23 16:45:00	\N	\N	2	0	\N	\N
641481	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur MI Ehpad - Audition FEDEPSAD	\N	2022-04-14 09:30:00	2022-04-14 10:30:00	\N	\N	0	0	\N	\N
641483	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur MI Ehpad	\N	2022-04-14 10:30:00	2022-04-14 12:00:00	\N	\N	4	0	\N	\N
641484	MECSS	AUDRAP	\N	\N	MECSS	MI Unification du recouvrement	\N	2022-04-14 10:00:00	2022-04-14 11:00:00	\N	\N	4	0	\N	\N
641486	MECSS	AUDRAP	\N	\N	MECSS	MI Unification du recouvrement - Audition du HCFiPS	\N	2022-04-13 15:30:00	2022-04-13 16:30:00	\N	\N	5	0	\N	\N
641492	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur MI Ehpad - Audition de Mme Jeandel	\N	2022-04-14 14:00:00	2022-04-14 15:30:00	\N	\N	3	0	\N	\N
641510	DELEGATION	AUDRAP	\N	\N	PROS	Audition Inrae	\N	2022-04-12 14:00:00	2022-04-12 15:00:00	\N	\N	3	0	\N	\N
641514	DELEGATION	AUDRAP	\N	\N	PROS	Audition Office français de la biodiversité (OFB)	\N	2022-04-12 15:30:00	2022-04-12 16:30:00	\N	\N	2	0	\N	\N
641517	DELEGATION	AUDRAP	\N	\N	PROS	Audition Chambres d'agriculture France (APCA)	\N	2022-04-12 16:30:00	2022-04-12 17:30:00	\N	\N	4	0	\N	\N
641522	DELEGATION	AUDRAP	\N	\N	PROS	Audition Voies Navigables de France	\N	2022-04-12 17:30:00	2022-04-12 18:30:00	\N	\N	2	0	\N	\N
644571	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition RATP SNCF incident stade de France	Audition RATP SNCF incident stade de France	2022-06-14 09:00:00	2022-06-14 10:25:00	2022-06-14 11:03:12	2022-06-14 17:49:03	25	0	\N	\N
726447	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 29	\N	2023-05-03 09:30:00	2023-05-03 09:50:00	2023-05-03 14:29:56	2023-05-03 18:03:33	41	6	\N	\N
647641	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-07-13 09:00:00	2022-07-13 12:50:00	2022-07-13 17:10:07	2022-07-13 19:07:00	37	0	\N	\N
647642	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-07-12 13:50:00	2022-07-12 14:20:00	2022-07-12 18:11:57	2022-07-13 19:07:04	33	0	\N	\N
647643	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-07-12 15:15:00	2022-07-12 16:00:00	2022-07-12 18:17:11	2022-07-13 19:07:02	24	0	\N	\N
647669	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLFR2022:Audition M.MOSCOVICI -Contrôles Budgétaires OAT Vertes et Maisons France services	PLFR 2022 et Finances publiques : Audition de M. MOSCOVICI - Contrôles Budgétaires OAT Vertes et Maisons France services	2022-07-13 09:30:00	2022-07-13 12:30:00	2022-07-13 14:48:28	2022-07-13 19:06:59	38	1	\N	\N
647945	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022- IGN - CRIGE-PACA	Contrôle 2022- IGN - CRIGE-PACA	2022-07-07 14:00:00	2022-07-07 15:00:00	\N	\N	1	0	\N	\N
668000	QUESTURE	AUCUNE	\N	\N	\N	Réunion de Questure	Réunion de Questure	2022-10-27 09:15:00	2022-10-27 10:15:00	\N	\N	3	0	\N	\N
671902	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions rapporteur - MI organisation de la police judiciaire	Auditions rapporteur - MI organisation de la police judiciaire	2022-11-08 14:15:00	2022-11-08 17:00:00	\N	\N	4	0	\N	\N
671933	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - MI organisation de la police judiciaire	Audition rapporteur - MI organisation de la police judiciaire	2022-11-09 14:00:00	2022-11-09 15:00:00	\N	\N	3	0	\N	\N
675897	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL aesh	\N	2022-11-16 14:00:00	2022-11-16 16:00:00	\N	\N	1	0	\N	\N
676320	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2023 Énergie - Audition	PLF 2023 Énergie - Audition	2022-11-08 10:15:00	2022-11-08 11:00:00	\N	\N	1	0	\N	\N
676321	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2023 Énergie - Audition	PLF 2023 Énergie - Audition	2022-11-08 14:00:00	2022-11-08 14:45:00	\N	\N	1	0	\N	\N
676322	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2023 - Énergie - Audition	PLF 2023 Énergie - Audition	2022-11-08 16:15:00	2022-11-08 17:00:00	\N	\N	1	0	\N	\N
676323	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2023 -Énergie - Audition	PLF 2023 -Énergie - Audition	2022-11-09 09:45:00	2022-11-09 11:45:00	\N	\N	1	0	\N	\N
676324	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2023 Énergie - Audition	PLF 2023 Énergie - Audition	2022-11-15 15:30:00	2022-11-15 17:15:00	\N	\N	1	0	\N	\N
676325	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PLF 2023 - Énergie - Audition	PLF 2023 Énergie - Audition	2022-11-16 20:00:00	2022-11-16 20:50:00	\N	\N	0	0	\N	\N
680310	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Équité territoriale face aux déserts médicaux - Table ronde Syndicats de médecins/URPS	\N	2022-11-23 17:30:00	2022-11-23 18:30:00	\N	\N	2	0	\N	\N
680315	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Équité territoriale face aux déserts médicaux - Audition commune DGOS/DGESIP	\N	2022-11-23 18:30:00	2022-11-23 19:45:00	\N	\N	2	0	\N	\N
680316	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Équité territoriale face aux déserts médicaux - Audition de Mme Dominique Polton	\N	2022-11-23 19:45:00	2022-11-23 21:00:00	\N	\N	2	0	\N	\N
680347	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition M. Laurent SOMON	\N	2022-11-22 15:15:00	2022-11-22 16:00:00	\N	\N	2	0	\N	\N
680353	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Équité territoriale face aux déserts médicaux - Audition de la Fédération des CPTS	\N	2022-11-24 09:30:00	2022-11-24 10:30:00	\N	\N	2	0	\N	\N
680360	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition PPL Lutte fraude CPF - Audition commune de représentants organismes de formation	\N	2022-11-22 15:00:00	2022-11-22 16:00:00	\N	\N	1	0	\N	\N
680361	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition PPL lutte contre CPF - Audition commune d'organismes de formation	\N	2022-11-22 16:00:00	2022-11-22 17:00:00	\N	\N	1	0	\N	\N
680362	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Équité territoriale face aux déserts médicaux - Table ronde Centres de santé	\N	2022-11-24 10:30:00	2022-11-24 11:45:00	\N	\N	2	0	\N	\N
680363	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Équité territoriale face aux déserts médicaux - Audition de Présence médicale 64	\N	2022-11-24 11:45:00	2022-11-24 13:00:00	\N	\N	3	0	\N	\N
680364	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition PPL Lutte fraude CPF - Audition Caisse des dépôts et consignations	\N	2022-11-22 17:00:00	2022-11-22 18:00:00	\N	\N	1	0	\N	\N
680381	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur PPL lutte fraude CPF	\N	2022-11-23 14:00:00	2022-11-23 14:45:00	\N	\N	1	0	\N	\N
680382	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur PPL lutte fraude CPF - Audition France Compétences	\N	2022-11-23 16:30:00	2022-11-23 17:15:00	\N	\N	1	0	\N	\N
680384	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition PPL Lutte fraude CPF - Audtion DGEFP	\N	2022-11-23 17:30:00	2022-11-23 18:15:00	\N	\N	1	0	\N	\N
680436	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL AESH	\N	2022-11-23 12:00:00	2022-11-23 13:00:00	\N	\N	3	0	\N	\N
680440	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL AESH	\N	2022-11-24 16:30:00	2022-11-24 17:30:00	\N	\N	5	0	\N	\N
680451	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL AESH	\N	2022-11-25 11:00:00	2022-11-25 12:00:00	\N	\N	3	0	\N	\N
680766	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 1er décembre 2022	\N	2022-12-01 09:00:00	2022-12-01 11:00:00	2022-12-02 15:15:18	2022-12-02 15:44:55	22	0	\N	\N
682588	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL DDADUE - Audition DGS-DGOS	\N	2022-11-30 14:00:00	2022-11-30 15:00:00	\N	\N	2	0	\N	\N
682594	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL DDADUE - Audition DGS-DGT	\N	2022-11-30 16:30:00	2022-11-30 17:30:00	\N	\N	2	0	\N	\N
682597	DELEGATION	AUCUNE	\N	\N	COLTER	Actualités collectivités territoriales - Simplification des normes	\N	2022-12-01 09:15:00	2022-12-01 11:45:00	\N	\N	12	0	\N	\N
682768	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL DDADUE - Audition de l'ANSES	\N	2022-12-01 10:30:00	2022-12-01 11:00:00	\N	\N	2	0	\N	\N
682865	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Audition Confédération des acteurs du tourisme	\N	2022-11-30 13:30:00	2022-11-30 14:40:00	\N	\N	0	0	\N	\N
682911	DELEGATION	AUDRAP	\N	\N	206	Audition de Mme Duclay	\N	2022-11-30 17:00:00	2022-11-30 19:00:00	\N	\N	2	0	\N	\N
682944	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL DDADUE - ACPR/DG Trésor/AMF	PJL DDADUE - ACPR/DG Trésor/AMF	2022-12-01 16:00:00	2022-12-01 19:05:00	\N	\N	1	0	\N	\N
741099	SEANCE_PLENIERE	SCRUSOL	1881	\N	\N	Scrutin solennel PJL Justice	Scrutin solennel PJL Justice	2023-06-13 15:30:00	2023-06-13 15:35:00	\N	\N	0	0	\N	\N
741105	SEANCE_PLENIERE	SCRUSOL	1882	\N	\N	Scrutin solennel PJLO Corps judiciaire	Scrutin solennel PJLO Corps judiciaire	2023-06-13 15:35:00	2023-06-13 15:40:00	\N	\N	0	0	\N	\N
741106	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	1881	\N	\N	Explications de vote sur l'ensemble	Explications de vote sur l'ensemble	2023-06-13 14:30:00	2023-06-13 15:25:00	\N	\N	301	0	\N	\N
746016	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-06-27 16:05:00	2023-06-27 17:25:00	2023-06-27 17:25:51	2023-06-28 10:16:14	26	0	\N	\N
675257	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-11-23 09:30:00	2022-11-23 11:40:00	2022-11-23 11:42:39	2022-11-23 15:15:09	48	0	\N	\N
746018	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-06-28 11:45:00	2023-06-28 12:45:00	2023-06-28 13:04:53	2023-06-29 14:30:54	22	1	\N	\N
746019	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-06-28 16:35:00	2023-06-28 18:40:00	2023-06-28 19:02:14	2023-06-29 14:30:53	18	0	\N	\N
746020	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Cybersolidarité - RPEU	Audition Cybersolidarité - RPEU	2023-06-21 17:30:00	2023-06-21 18:30:00	\N	\N	1	0	\N	\N
746022	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Plein emploi - Audition DGCS	\N	2023-06-22 09:30:00	2023-06-22 10:30:00	\N	\N	4	0	\N	\N
746023	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Programmation militaire pour les années 2024 à 2030	PJL Programmation militaire pour les années 2024 à 2030	2023-06-27 14:30:00	2023-06-27 19:55:00	\N	\N	180	0	\N	\N
746024	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Programmation militaire pour les années 2024 à 2030	PJL Programmation militaire pour les années 2024 à 2030	2023-06-27 21:30:00	2023-06-28 00:35:00	\N	\N	80	0	\N	\N
746025	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2023-06-28 15:00:00	2023-06-28 16:25:00	\N	\N	279	0	\N	\N
746026	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Programmation militaire pour les années 2024 à 2030	PJL Programmation militaire pour les années 2024 à 2030	2023-06-28 16:35:00	2023-06-28 19:50:00	\N	\N	94	0	\N	\N
746027	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Programmation militaire pour les années 2024 à 2030	PJL Programmation militaire pour les années 2024 à 2030	2023-06-28 21:30:00	2023-06-29 00:40:00	\N	\N	57	0	\N	\N
746028	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Risque incendie	CMP Risque incendie	2023-06-29 10:30:00	2023-06-29 11:30:00	\N	\N	32	0	\N	\N
746029	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Majorité numérique	CMP Majorité numérique	2023-06-29 11:30:00	2023-06-29 12:30:00	\N	\N	33	0	\N	\N
746030	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Interruption spontanée de grossesse	CMP Interruption spontanée de grossesse	2023-06-29 12:30:00	2023-06-29 13:20:00	\N	\N	15	0	\N	\N
746031	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - SMV - Audition SMV et DSNJ	Contrôle 2023 - SMV - Audition SMV et DSNJ	2023-06-20 17:00:00	2023-06-20 19:00:00	\N	\N	1	0	\N	\N
746033	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Programmation militaire pour les années 2024 à 2030	PJL Programmation militaire pour les années 2024 à 2030	2023-06-29 14:50:00	2023-06-29 17:50:00	\N	\N	48	0	\N	\N
746037	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Plein emploi - Table ronde de collectivités expérimentatrices	\N	2023-06-22 10:30:00	2023-06-22 12:00:00	\N	\N	2	0	\N	\N
746038	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Matières premières critiques	Audition Matières premières critiques - Bruxelles	2023-06-29 09:00:00	2023-06-29 17:00:00	\N	\N	2	0	\N	\N
746041	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Plein emploi - Audition Alliance Villes Emploi	\N	2023-06-22 14:15:00	2023-06-22 15:00:00	\N	\N	2	0	\N	\N
746042	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Plein emploi - Table ronde des réseaux d'insertion par l'activité économique	\N	2023-06-22 15:00:00	2023-06-22 16:00:00	\N	\N	0	0	\N	\N
746043	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Plein emploi - Table ronde des réseaux d'entreprises adaptées	\N	2023-06-22 16:00:00	2023-06-22 17:00:00	\N	\N	1	0	\N	\N
746058	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL PLein emploi - Audition Pôle emploi	\N	2023-06-22 17:00:00	2023-06-22 18:00:00	\N	\N	0	0	\N	\N
746059	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 28 juin	\N	2023-06-28 14:15:00	2023-06-28 15:00:00	2023-06-29 15:17:18	2023-06-29 19:25:14	16	0	\N	\N
746060	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 29 juin	\N	2023-06-29 09:00:00	2023-06-29 10:00:00	2023-06-29 10:10:04	2023-06-29 14:30:52	6	0	\N	\N
746064	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Régime juridique des actions de groupe	PPL Régime juridique des actions de groupe	2023-06-21 14:00:00	2023-06-21 15:20:00	\N	\N	1	0	\N	\N
748016	GIA	AUCUNE	\N	\N	\N	Rencontre Düzen Tekkal	Rencontre avec Mme Düzen Tekkal, militante yézidie, et ses soeurs	2023-07-03 14:30:00	2023-07-03 15:30:00	\N	\N	1	0	615	\N
749831	GIA	AUCUNE	\N	\N	\N	Entretien avec l'association Pour l'Ukraine, pour leur liberté et la nôtre	Entretien avec l'association Pour l'Ukraine, pour leur liberté et la nôtre	2023-07-05 14:00:00	2023-07-05 15:00:00	\N	\N	5	0	530	\N
751536	DELEGATION	AUCUNE	\N	\N	206	Présentation des rapports finaux des auditeurs de l'IHEST	\N	2023-07-13 09:35:00	2023-07-13 11:40:00	\N	\N	5	0	\N	\N
751584	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Reconstruction des bâtiments dégradés - Examen avis et article délégué	PJL Reconstruction des bâtiments dégradés - Examen avis et article délégué	2023-07-17 15:00:00	2023-07-17 15:25:00	2023-07-17 15:30:21	2023-07-17 18:16:51	10	1	\N	\N
751587	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Reconstruction des bâtiments dégradés - Examen amendements à l'article délégué	PJL Reconstruction des bâtiments dégradés - Examen amendements à l'article délégué	2023-07-18 10:00:00	2023-07-18 10:05:00	2023-07-18 10:03:54	2023-07-18 17:17:43	2	0	\N	\N
751986	ETUDES	AUTRE	\N	\N	\N	Vin & Société	Vin & Société	2023-05-31 13:30:00	2023-05-31 15:00:00	\N	\N	10	0	\N	909
761025	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Sites et Cités remarquables de France	\N	2023-10-30 09:30:00	2023-10-30 10:45:00	\N	\N	3	0	\N	\N
761029	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 72	PLENIERE - 72	2023-10-31 08:30:00	2023-10-31 09:55:00	2023-10-31 10:14:12	2023-11-02 12:36:44	26	5	\N	\N
761030	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 73	PLENIERE - 73	2023-10-31 14:30:00	2023-10-31 17:32:00	2023-11-02 17:38:44	2023-11-03 15:16:14	31	3	\N	\N
761561	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2024 - Avis Fonction publique	Audition rapporteur - PLF 2024 - Avis fonction publique	2023-11-02 09:30:00	2023-11-02 10:30:00	\N	\N	1	0	\N	\N
762609	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Engagements financiers - Audition de la direction générale du Trésor	PLF pour 2024 - Engagements financiers - Audition de MM. CASTETS et ROBERT, direction générale du Trésor	2023-11-06 16:00:00	2023-11-06 16:30:00	\N	\N	1	0	\N	\N
762655	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Engagements financiers - Audition de la Société Générale	PLF pour 2024 - Engagements financiers - Audition de la Société Générale	2023-11-06 17:30:00	2023-11-06 18:15:00	\N	\N	1	0	\N	\N
762659	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Engagements financiers - Audition de l'Agence France Trésor	PLF pour 2024 - Engagements financiers - Audition de MM. DERENNES et MARCEAU de l'Agence France Trésor	2023-11-06 18:30:00	2023-11-06 19:15:00	\N	\N	1	0	\N	\N
762671	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - AEE - Audition cabinet MEAE	PLF pour 2024 - AEE - Audition du cabinet du ministre de l'Europe et des Affaires Etrangères	2023-10-30 10:00:00	2023-10-30 11:00:00	\N	\N	2	0	\N	\N
638888	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ambassadeur de France en Pologne	Entretien avec l'ambassadeur de France en Pologne	2022-03-09 19:00:00	2022-03-09 20:00:00	\N	\N	1	0	600	\N
641708	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	CCI	\N	2022-04-26 16:00:00	2022-04-26 16:45:00	\N	\N	0	0	\N	\N
641709	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	CCI	\N	2022-04-26 16:00:00	2022-04-26 16:45:00	\N	\N	0	0	\N	\N
641710	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	CCI	\N	2022-04-26 16:00:00	2022-04-26 16:45:00	\N	\N	0	0	\N	\N
641711	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	CMA France	\N	2022-04-26 16:45:00	2022-04-26 17:30:00	\N	\N	0	0	\N	\N
641712	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	CPME	\N	2022-04-26 17:30:00	2022-04-26 18:15:00	\N	\N	0	0	\N	\N
641713	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	PROCOS	\N	2022-04-26 18:15:00	2022-04-26 19:00:00	\N	\N	0	0	\N	\N
641878	GIA	AUCUNE	\N	\N	\N	Déjeuner de travail	Déjeuner de travail avec l'ambassadeur d'Arménie	2022-04-12 12:00:00	2022-04-12 13:55:00	\N	\N	4	0	641	\N
641883	ETUDES	AUCUNE	\N	\N	\N	Audition I4CE	Audition I4CE	2022-04-27 08:00:00	2022-04-27 09:30:00	\N	\N	12	0	\N	948
641904	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Énergie et hydrogène nucléaires	MI Énergie et hydrogène nucléaires	2022-04-26 11:00:00	2022-04-26 12:00:00	\N	\N	1	0	\N	\N
641911	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Énergie et hydrogène nucléaires	MI Énergie et hydrogène nucléaires	2022-04-26 14:45:00	2022-04-26 15:30:00	\N	\N	4	0	\N	\N
641918	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Énergie et hydrogène nucléaires	MI Énergie et hydrogène nucléaires	2022-04-26 15:30:00	2022-04-26 16:15:00	\N	\N	5	0	\N	\N
641924	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Énergie et hydrogène nucléaires	MI Énergie et hydrogène nucléaires	2022-04-26 16:15:00	2022-04-26 17:00:00	\N	\N	5	0	\N	\N
641930	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Énergie et hydrogène nucléaires	MI Énergie et hydrogène nucléaires	2022-04-26 17:00:00	2022-04-26 18:05:00	\N	\N	5	0	\N	\N
645417	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur - Audition de M. Touboul	\N	2022-06-21 14:00:00	2022-06-21 15:30:00	\N	\N	5	0	\N	\N
645423	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Miission d'information sur le contrôle des Ehpad	\N	2022-06-21 16:30:00	2022-06-21 17:45:00	\N	\N	4	0	\N	\N
645448	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 -  ONACVG - Arboresens	Contrôle 2022 -  ONACVG - Arboresens	2022-06-21 15:00:00	2022-06-21 16:30:00	\N	\N	1	0	\N	\N
645450	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	MI Fraude et évasion fiscales - Déplacement TJ Paris et PNF	MI Fraude et évasion fiscales - Déplacement TJ Paris et PNF	2022-06-21 14:00:00	2022-06-21 19:30:00	\N	\N	8	0	\N	\N
645459	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Tables rondes sur le commerce extérieur	Tables rondes sur le commerce extérieur	2022-06-29 14:15:00	2022-06-29 17:00:00	2022-06-29 16:26:15	\N	5	0	\N	\N
645460	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-06-29 09:30:00	2022-06-29 11:35:00	2022-06-29 11:55:27	2022-06-30 12:12:29	27	0	\N	\N
645490	COM_PERMANENTE	AUTRE	\N	FINC	\N	Contrôles budgétaires SGC et ZAN	Contrôles budgétaires SGC et ZAN	2022-06-29 09:05:00	2022-06-29 11:10:00	2022-06-29 11:59:54	2022-06-30 12:12:29	26	2	\N	\N
645518	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 -  ONACVG - Numérique ONACVG	Contrôle 2022 -  ONACVG - Numérique ONACVG	2022-06-22 16:30:00	2022-06-22 18:00:00	\N	\N	1	0	\N	\N
645520	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2022 -  ONACVG - Déplacement à Caen	Contrôle 2022 -  ONACVG - Déplacement à Caen	2022-06-23 10:00:00	2022-06-23 20:00:00	\N	\N	1	0	\N	\N
645522	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2022 -  ONACVG - Déplacement à Vannes	Contrôle 2022 -  ONACVG - Déplacement à Vannes	2022-07-12 09:00:00	2022-07-12 21:15:00	\N	\N	1	0	\N	\N
645535	ETUDES	AUDRAP	\N	\N	\N	audition Mme Mouton	\N	2022-06-23 14:30:00	2022-06-23 16:00:00	\N	\N	13	0	\N	1008
645549	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - Dépakine - ONIAM	Contrôle 2022 - Dépakine - ONIAM	2022-06-22 14:00:00	2022-06-22 16:00:00	\N	\N	1	0	\N	\N
645551	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - Dépakine - DAJMS et DSS	Contrôle 2022 - Dépakine - DAJMS et DSS	2022-06-23 10:00:00	2022-06-23 11:00:00	\N	\N	1	0	\N	\N
645553	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - Dépakine - APESAC	Contrôle 2022 - Dépakine - APESAC	2022-06-23 14:00:00	2022-06-23 15:00:00	\N	\N	1	0	\N	\N
652614	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	GT subsidiarité	\N	2022-07-27 16:30:00	2022-07-27 17:00:00	\N	\N	0	0	\N	\N
652615	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	GT subsidiarité	\N	2022-06-15 09:45:00	2022-06-15 10:00:00	\N	\N	0	0	\N	\N
652714	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-07-28 14:20:00	2022-07-28 14:25:00	2022-07-28 14:27:23	2022-07-28 16:07:42	15	0	\N	\N
652727	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022- IGN - Google France/DG IGN	Contrôle 2022- IGN - Google France/DG IGN	2022-07-26 14:00:00	2022-07-26 16:45:00	\N	\N	1	0	\N	\N
653089	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLFR pour 2022 : Examen des amendements de séance	PLFR pour 2022 : Examen des amendements de séance	2022-08-01 13:30:00	2022-08-01 14:00:00	2022-08-01 14:41:52	2022-08-01 17:53:15	29	2	\N	\N
655685	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition France Universités	\N	2022-10-05 09:30:00	2022-10-05 11:38:00	2022-10-05 17:43:10	2022-10-06 14:41:43	34	0	\N	\N
658888	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition MCC ZAN	Audition MCC ZAN	2022-10-04 15:05:00	2022-10-04 16:40:00	\N	\N	11	0	\N	\N
667314	DELEGATION	AUCUNE	\N	\N	211	Réunion plénière - Audition HCE	Réunion plénière - Audition HCE	2022-11-17 08:35:00	2022-11-17 10:10:00	2022-11-17 13:08:56	\N	9	0	\N	\N
667315	DELEGATION	AUCUNE	\N	\N	DSOM	Audition de M. Guy Losbar (Conseil départemental de la Guadeloupe)	\N	2022-11-07 17:00:00	2022-11-07 18:00:00	\N	\N	5	0	\N	\N
667316	DELEGATION	AUCUNE	\N	\N	DSOM	Audition de M. Serge Letchimy	\N	2022-11-18 10:00:00	2022-11-18 11:45:00	\N	\N	7	0	\N	\N
667699	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2023 - P. 844-847	PLF pour 2023 - P. 844-847	2022-10-26 16:30:00	2022-10-26 18:30:00	\N	\N	1	0	\N	\N
669550	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - MI organisation de la police judiciaire	Audition rapporteur - MI organisation de la police judiciaire	2022-11-03 09:00:00	2022-11-03 11:45:00	\N	\N	2	0	\N	\N
669553	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - MI organisation de la police judiciaire	Audition rapporteur - MI organisation de la police judiciaire	2022-11-03 14:30:00	2022-11-03 17:00:00	\N	\N	2	0	\N	\N
767557	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditon M. Gillé 	\N	2023-11-14 17:00:00	2023-11-14 17:45:00	\N	\N	1	0	\N	\N
669867	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - PJLF 2023 - Avis fonction publique	Audition rapporteur - PJLF 2023 - avis "fonction publique"	2022-10-25 14:30:00	2022-10-25 15:15:00	\N	\N	1	0	\N	\N
670358	GIA	AUCUNE	\N	\N	\N	Accueil délégation suisse/salut en séance publique	Accueil délégation suisse/salut en séance publique	2022-11-08 14:15:00	2022-11-08 15:00:00	\N	\N	1	0	610	\N
672260	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PLF pour 2023 - Avis AGTE	PLF pour 2023 - Avis AGTE	2022-11-15 09:30:00	2022-11-15 10:20:00	2022-11-15 11:51:00	2022-11-15 14:52:24	19	2	\N	\N
672261	DELEGATION	AUCUNE	\N	\N	206	Examen de conclusions d'auditions publiques	\N	2022-11-17 09:35:00	2022-11-17 11:50:00	\N	\N	7	0	\N	\N
672280	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Soutien aux édiles victimes d'agression (amendements)	PPL Soutien aux édiles victimes d'agression (amendements)	2022-11-15 14:00:00	2022-11-15 14:15:00	\N	\N	16	0	\N	\N
672430	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure du 3 novembre 2022	Conseil de Questure du 3 novembre 2022	2022-11-03 08:30:00	2022-11-03 10:04:00	\N	\N	3	0	\N	\N
672535	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF 2023 - programme 144	PLF 2023 - programme 144	2022-11-08 14:30:00	2022-11-08 15:30:00	\N	\N	1	0	\N	\N
672539	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF 2023 - programme 185	PLF 2023 - programme 185	2022-11-09 16:45:00	2022-11-09 17:45:00	\N	\N	1	0	\N	\N
676369	GIA	AUCUNE	\N	\N	\N	Audition Dr Gyal Lo	Audition Dr Gyal Lo	2022-11-30 08:00:00	2022-11-30 09:30:00	\N	\N	3	0	634	\N
728259	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - IRSN - Audition Cabinet ministre de la recherche	Contrôle 2023 - IRSN - Audition Cabinet ministre de la recherche	2023-05-02 16:00:00	2023-05-02 17:00:00	\N	\N	1	0	\N	\N
728263	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - ORE - Audition ministère recherche	Contrôle 2023 - ORE - Audition ministère recherche	2023-05-03 11:00:00	2023-05-03 12:00:00	\N	\N	1	0	\N	\N
728269	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 CESE - Audition Métropole Grenoble Alpes	Contrôle 2023 CESE - Audition Métropole Grenoble Alpes	2023-05-02 15:00:00	2023-05-02 16:00:00	\N	\N	1	0	\N	\N
728279	COM_PERMANENTE	AUTRE	\N	FINC	\N	58-2 Titres sécurisés - Réunion de cadrage du contrôle	58-2 Titres sécurisés - Réunion de cadrage du contrôle	2023-03-14 16:00:00	2023-03-14 17:30:00	\N	\N	1	0	\N	\N
728281	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Déplacement du bureau en Allemagne - Réunion KFW Francfort	Déplacement du bureau en Allemagne - Réunion KFW Francfort	2023-04-25 10:30:00	2023-04-25 12:00:00	\N	\N	5	0	\N	\N
728287	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Déplacement du bureau en Allemagne - Réunion à la Banque centrale européenne Francfort	Déplacement du bureau en Allemagne - Réunion à la Banque centrale européenne Francfort	2023-04-25 14:00:00	2023-04-25 15:30:00	\N	\N	5	0	\N	\N
728293	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Déplacement du bureau en Allemagne - Réunion à la Deutsche Bank Francfort	Déplacement du bureau en Allemagne - Réunion à la Deutsche Bank Francfort	2023-04-25 16:00:00	2023-04-25 17:30:00	\N	\N	5	0	\N	\N
728299	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Déplacement du bureau en Allemagne - Diner de travail Francfort	Déplacement du bureau en Allemagne - Diner de travail Francfort	2023-04-25 19:30:00	2023-04-25 22:30:00	\N	\N	5	0	\N	\N
728305	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Déplacement du bureau en Allemagne - Visite site industriel Schott Mainz	Déplacement du bureau en Allemagne - Visite site industriel Schott Mainz	2023-04-26 08:30:00	2023-04-26 11:00:00	\N	\N	5	0	\N	\N
728311	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Déplacement du bureau en Allemagne - Entretien Fédération industries allemandes BDI Berlin	Déplacement du bureau en Allemagne - Entretien Fédération des industries allemandes BDI Berlin	2023-04-26 16:00:00	2023-04-26 17:00:00	\N	\N	5	0	\N	\N
728317	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Déplacement du bureau en Allemagne - Entretien M. Jörg secrétaire d'état Berlin	Déplacement du bureau en Allemagne - Entretien M. Jörg secrétaire d'état Berlin	2023-04-26 18:30:00	2023-04-26 19:30:00	\N	\N	5	0	\N	\N
728323	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Déplacement du bureau en Allemagne - Diner de travail M. DELATTRE ambassadeur Berlin	Déplacement du bureau en Allemagne - Diner de travail M. DELATTRE ambassadeur Berlin	2023-04-26 20:00:00	2023-04-26 22:30:00	\N	\N	5	0	\N	\N
728329	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Déplacement du bureau en Allemagne - Entretien Institut Jacques DELORS	Déplacement du bureau en Allemagne - Entretien Institut Jacques DELORS	2023-04-27 08:15:00	2023-04-27 09:30:00	\N	\N	5	0	\N	\N
728335	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Déplacement du bureau en Allemagne - Entretien fondation Konrad ADENAUER	Déplacement du bureau en Allemagne - Entretien fondation Konrad ADENAUER	2023-04-27 09:45:00	2023-04-27 10:45:00	\N	\N	5	0	\N	\N
728341	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Déplacement du bureau en Allemagne - Entretien Deutsche Industrie und Handelskammer DIHK	Déplacement du bureau en Allemagne - Entretien Deutsche Industrie und Handelskammer DIHK	2023-04-27 11:15:00	2023-04-27 12:00:00	\N	\N	5	0	\N	\N
728347	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Déplacement du bureau en Allemagne - Déjeuner de travail cheffe service éco régional	Déplacement du bureau en Allemagne - Déjeuner de travail cheffe service éco régional	2023-04-27 12:00:00	2023-04-27 14:00:00	\N	\N	5	0	\N	\N
728353	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Déplacement du bureau en Allemagne - Entretien VP SPD Wirtschaftsforum	Déplacement du bureau en Allemagne - Entretien VP SPD Wirtschaftsforum (Forum économique)	2023-04-27 15:30:00	2023-04-27 17:00:00	\N	\N	5	0	\N	\N
728359	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Déplacement du bureau en Allemagne - Réunion commission finances Bundestag	Déplacement du bureau en Allemagne - Réunion commission finances Bundestag	2023-04-28 09:30:00	2023-04-28 10:30:00	\N	\N	5	0	\N	\N
728365	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Déplacement du bureau en Allemagne - Réunion commission budget Bundestag	Déplacement du bureau en Allemagne - Réunion commission budget Bundestag	2023-04-28 10:30:00	2023-04-28 11:30:00	\N	\N	5	0	\N	\N
728371	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Déplacement du bureau en Allemagne - Déjeuner travail M KLUTTIG et Mme BOARDWELL	Déplacement du bureau en Allemagne - Déjeuner travail M KLUTTIG et Mme BOARDWELL	2023-04-28 12:00:00	2023-04-28 13:30:00	\N	\N	5	0	\N	\N
728379	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Déplacement du bureau en Allemagne - Réunion M. TONKAR (BMF)	Déplacement du bureau en Allemagne - Réunion M. TONKAR (BMF)	2023-04-28 14:00:00	2023-04-28 15:00:00	\N	\N	5	0	\N	\N
728385	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Construction places de détention  - Audition Agence immob. justice	Contrôle 2023 - Construction places de détention  - Audition Agence pour l'immobilier de la justice (APIJ)	2023-05-02 14:15:00	2023-05-02 15:05:00	\N	\N	1	0	\N	\N
728387	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Construction places de détention  - Audition direction PJJ	Contrôle 2023 - Construction places de détention  - Audition direction PJJ	2023-05-02 15:05:00	2023-05-02 16:05:00	\N	\N	1	0	\N	\N
728389	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Construction places de détention  - Audition SG ministère de la justice	Contrôle 2023 - Construction places de détention  - Audition SG ministère de la justice	2023-05-02 16:05:00	2023-05-02 17:00:00	\N	\N	1	0	\N	\N
728391	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Pass Culture - Table-ronde collectivités territoriales	Contrôle 2023 - Pass Culture - Table-ronde collectivités territoriales	2023-05-02 14:30:00	2023-05-02 15:30:00	\N	\N	2	0	\N	\N
728405	COM_PERMANENTE	AUTRE	\N	CAE	\N	Examen amendements de séance - ppl influenceurs	\N	2023-05-09 14:00:00	2023-05-09 14:10:00	2023-05-09 14:16:46	2023-05-09 18:09:28	25	3	\N	\N
728406	COM_ENQUETE	PLENIERE	\N	RENOV	\N	Table ronde construction	\N	2023-05-09 15:00:00	2023-05-09 16:40:00	2023-05-09 16:58:23	2023-05-09 18:09:04	8	0	\N	\N
728411	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Déplacement à la cour d'appel de Lyon	Déplacement à la cour d'appel de Lyon	2023-05-02 08:00:00	2023-05-02 22:00:00	\N	\N	4	0	\N	\N
728412	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Ecole nationale de la magistrature - Centre pénitentiaire de Bordeaux-Gradignan	Ecole nationale de la magistrature - Centre pénitentiaire de Bordeaux-Gradignan	2023-05-05 08:00:00	2023-05-05 22:00:00	\N	\N	6	0	\N	\N
728423	MISSION	DEPLACEMENT	\N	AVENCOMM	\N	Déplacement dans la Somme	\N	2023-05-04 08:00:00	2023-05-04 22:00:00	\N	\N	2	0	\N	\N
728426	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	déplacement à Douai - RI LPM 178	déplacement à Douai - RI LPM 178	2023-05-05 09:00:00	2023-05-05 16:00:00	\N	\N	2	0	\N	\N
728429	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	déplacement exercice ORION	déplacement exercice ORION	2023-05-04 07:30:00	2023-05-04 18:00:00	\N	\N	9	0	\N	\N
728439	DELEGATION	AUDRAP	\N	\N	206	Audition Recyclage du plastique	\N	2023-05-03 16:30:00	2023-05-03 19:15:00	\N	\N	2	0	\N	\N
728442	DELEGATION	AUDRAP	\N	\N	206	Audition Recyclage Plastique	\N	2023-05-04 09:00:00	2023-05-04 17:45:00	\N	\N	2	0	\N	\N
728445	DELEGATION	AUCUNE	\N	\N	DSOM	Foncier agricole : audition Interco' Outre-mer	\N	2023-05-25 10:30:00	2023-05-25 12:00:00	\N	\N	6	0	\N	\N
728447	DELEGATION	AUCUNE	\N	\N	206	Examen du rapport sur les lois de programmation militaire et l'innovation	\N	2023-05-09 13:35:00	2023-05-09 14:30:00	\N	\N	4	0	\N	\N
728448	DELEGATION	AUCUNE	\N	\N	206	Audition publique sur les perspectives technologiques en matière de batteries	\N	2023-05-04 09:30:00	2023-05-04 12:40:00	\N	\N	9	0	\N	\N
728553	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 Installation agriculteurs - Audition APCA et CA Hauts de France	58-2 Installation agriculteurs - Audition APCA et CA Hauts de France	2023-05-02 14:30:00	2023-05-02 15:30:00	\N	\N	2	0	\N	\N
644537	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - Contrats Etat collectivités lutte contre la pauvreté - IGAS	Contrôle 2022 - Contrats Etat collectivités lutte contre la pauvreté - IGAS	2022-06-10 14:00:00	2022-06-10 15:00:00	\N	\N	2	0	\N	\N
644540	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 -  ONACVG - DPAM	Contrôle 2022 -  ONACVG - DPAM	2022-06-09 11:00:00	2022-06-09 13:00:00	\N	\N	1	0	\N	\N
644649	DELEGATION	AUCUNE	\N	\N	DSOM	Réunion commune avec la délégation aux outre-mer de l'AMF	\N	2022-06-28 09:30:00	2022-06-28 11:15:00	\N	\N	12	0	\N	\N
644650	DELEGATION	AUTRE	\N	\N	DSOM	Table ronde "Filières à responsabilité élargie des producteurs"	\N	2022-06-23 09:30:00	2022-06-23 11:30:00	\N	\N	11	0	\N	\N
644653	DELEGATION	AUTRE	\N	\N	211	Examen d'un rapport d'information	\N	2022-07-20 16:30:00	2022-07-20 18:00:00	\N	\N	0	0	\N	\N
645088	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur - Audition de M. Denis Morin	Audition rapporteur - Audition de M. Denis Morin	2022-06-17 11:00:00	2022-06-17 12:30:00	\N	\N	7	0	\N	\N
645089	COM_PERMANENTE	AUCUNE	\N	AFCL	\N	visie stade de France - évènements du 28 mai	\N	2022-06-16 14:00:00	2022-06-16 18:00:00	\N	\N	0	0	\N	\N
645106	DELEGATION	AUCUNE	\N	\N	211	Examen du rapport d'information sur le bilan d'application de la loi Sauvadet	Examen du rapport d'information sur le bilan d'application de la loi Sauvadet	2022-06-21 13:45:00	2022-06-21 14:35:00	\N	\N	7	0	\N	\N
645107	DELEGATION	AUCUNE	\N	\N	211	Réunion plénière	\N	2022-07-21 11:05:00	2022-07-21 12:30:00	\N	\N	9	0	\N	\N
645110	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Incidents Stade de France - Audition de l¿association Football Supporters Europe (FSE)	Incidents Stade de France - Audition de l¿association Football Supporters Europe (FSE)	2022-06-21 16:30:00	2022-06-21 18:20:00	2022-06-23 12:10:05	2022-06-23 18:02:41	26	0	\N	\N
645111	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Incidents Stade de France - Audition de l'UEFA	Incidents Stade de France - Audition de l'UEFA	2022-06-21 09:30:00	2022-06-21 10:50:00	2022-06-21 18:49:06	2022-06-21 19:00:18	32	0	\N	\N
645112	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Incidents Stade de France - Audition de Mathieu Hanotin, maire de Saint-Denis	Incidents Stade de France - Audition de Mathieu Hanotin, maire de Saint-Denis	2022-06-21 18:30:00	2022-06-21 19:25:00	2022-06-23 12:10:21	2022-06-23 18:02:40	17	0	\N	\N
655490	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL Convention de Macolin	\N	2022-09-13 14:15:00	2022-09-13 16:30:00	\N	\N	1	0	\N	\N
665146	GIA	AUCUNE	\N	\N	\N	Délégation Conseil des Etats Suisse	Délégation Conseil des Etats Suisse: réunion du groupe d'amitié	2022-11-08 15:00:00	2022-11-08 16:15:00	\N	\N	5	0	610	\N
665147	GIA	AUCUNE	\N	\N	\N	Délégation Conseil des Etats Suisse	Entretien abec M Le Président Larcher en présence du Président BONNE	2022-11-08 16:30:00	2022-11-08 17:30:00	\N	\N	1	0	610	\N
665148	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2022-10-25 09:30:00	2022-10-25 12:50:00	\N	\N	54	0	\N	\N
665149	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Fonctionnement du marché du travail en vue du plein emploi	PJL Fonctionnement du marché du travail en vue du plein emploi	2022-10-25 14:30:00	2022-10-25 19:55:00	\N	\N	153	0	\N	\N
665150	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Suite PJL Fonctionnement du marché du travail en vue du plein emploi	Suite PJL Fonctionnement du marché du travail en vue du plein emploi	2022-10-25 21:30:00	2022-10-25 23:10:00	\N	\N	70	0	\N	\N
665151	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2022-10-26 15:00:00	2022-10-26 16:20:00	\N	\N	292	0	\N	\N
665153	SEANCE_PLENIERE	DECL_GVT	\N	\N	\N	Déclaration du Gouvernement 50-1 - Guerre en Ukraine et ses conséquences pour la France	Déclaration du Gouvernement 50-1 - Guerre en Ukraine et ses conséquences pour la France	2022-10-26 21:30:00	2022-10-26 23:40:00	\N	\N	121	0	\N	\N
665154	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Traité de coopération entre la France et l'Italie	PJL Traité de coopération entre la France et l'Italie	2022-10-26 16:30:00	2022-10-26 17:50:00	\N	\N	56	0	\N	\N
728520	COM_PERMANENTE	AUTRE	\N	CAE	\N	Ppl Ferme France	\N	2023-05-10 09:30:00	2023-05-10 11:40:00	2023-05-10 12:02:32	2023-05-10 12:22:48	46	3	\N	\N
669093	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Philippe Tabarot	Auditions M. Philippe Tabarot	2022-11-02 08:30:00	2022-11-02 09:30:00	\N	\N	1	0	\N	\N
669119	DELEGATION	AUDRAP	\N	\N	206	Audition de Mme Peugeot	\N	2022-10-24 10:15:00	2022-10-24 11:15:00	\N	\N	1	0	\N	\N
669121	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Céréma-IGN-Météo-France - Céréma	PLF pour 2023 - Céréma-IGN-Météo-France - Céréma	2022-11-02 16:30:00	2022-11-02 17:30:00	\N	\N	1	0	\N	\N
669128	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - GFP - SG MIN ECOFIN/DGFiP	PLF pour 2023 - GFP - SG MIN ECOFIN/DGFiP	2022-11-02 17:00:00	2022-11-02 19:05:00	\N	\N	2	0	\N	\N
669197	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2023 Patrimoines	\N	2022-11-02 11:30:00	2022-11-02 12:40:00	\N	\N	5	0	\N	\N
669211	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes du jeudi 3 novembre 2022	\N	2022-11-03 09:05:00	2022-11-03 10:55:00	2022-11-03 11:05:55	2022-11-03 17:38:18	12	0	\N	\N
669420	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition Pap Ndiaye	\N	2022-11-08 17:30:00	2022-11-08 20:15:00	2022-11-10 15:51:35	2022-11-10 16:13:09	31	0	\N	\N
671222	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2023 - Justice judiciaire et accès au droit	PLF pour 2023 - Justice judiciaire et accès au droit	2022-11-10 09:00:00	2022-11-10 12:45:00	\N	\N	2	0	\N	\N
683055	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Adaptation au droit de l'Union européenne - Avis et articles délégués au fond	PJL Adaptation au droit de l'Union européenne - Avis et articles délégués au fond	2022-12-06 09:30:00	2022-12-06 09:50:00	2022-12-06 14:22:37	2022-12-06 17:45:26	17	0	\N	\N
683057	COM_PERMANENTE	AUTRE	\N	LOIS	\N	MI Métropoles de Lyon et d'Aix-Marseille-Provence - Rapport d'information	MI Métropoles de Lyon et d'Aix-Marseille-Provence - Rapport d'information	2022-12-07 10:00:00	2022-12-07 11:40:00	2022-12-08 09:25:10	2022-12-08 12:00:18	43	1	\N	\N
683336	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2023 - Examen Amdts séance sur les Missions	PLF pour 2023 - Examen Amdts séance sur les Missions	2022-12-05 09:30:00	2022-12-05 09:50:00	2022-12-05 10:25:46	2022-12-05 16:30:56	12	2	\N	\N
683337	COM_PERMANENTE	AUTRE	\N	FINC	\N	PJL 140 DDADUE : Examen rapport et désignation rapporteur PPL Epargnants	PJL 140 DDADUE : Examen rapport et désignation rapporteur PPL Epargnants	2022-12-06 09:30:00	2022-12-06 10:05:00	2022-12-06 10:31:00	2022-12-06 17:45:29	27	1	\N	\N
683338	COM_PERMANENTE	AUTRE	\N	FINC	\N	Communication Mission Flash dons aux associations et Désignation CMP LPFP	Communication Mission Flash dons aux associations et Désignation CMP LPFP	2022-12-07 10:00:00	2022-12-07 10:50:00	2022-12-07 11:06:42	2022-12-08 12:00:18	35	0	\N	\N
683954	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition de M. Cyril PELLEVAT	\N	2022-12-02 10:00:00	2022-12-02 10:45:00	\N	\N	1	0	\N	\N
683961	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions de M. Cyril PELLEVAT	\N	2022-12-01 13:45:00	2022-12-01 14:30:00	\N	\N	1	0	\N	\N
683969	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition M. Cyril PELLEVAT	\N	2022-11-30 11:00:00	2022-11-30 18:00:00	\N	\N	1	0	\N	\N
742189	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation de Sénateurs polonais - déplacement en Indre-et-Loire	Accueil d'une délégation de Sénateurs polonais - déplacement en Indre-et-Loire	2023-05-04 09:45:00	2023-05-05 17:00:00	\N	\N	1	0	600	\N
744232	QUESTURE	AUCUNE	\N	\N	\N	Réunion de Questure	Réunion de Questure	2023-06-15 09:00:00	2023-06-15 11:58:00	\N	\N	3	0	\N	\N
755823	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition PPL SERM	\N	2023-10-11 14:15:00	2023-10-11 15:00:00	\N	\N	3	0	\N	\N
755831	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition PPL SERM	Audition PPL SERM	2023-10-12 10:00:00	2023-10-12 10:30:00	\N	\N	1	0	\N	\N
755843	COM_PERMANENTE	AUTRE	\N	LOIS	\N	MCC Agressions subies par les enseignants - Audition de Mickaëlle Paty	MCC Agressions subies par les enseignants - Audition de Mickaëlle Paty	2023-10-17 15:00:00	2023-10-17 16:25:00	2023-10-17 18:13:25	2023-10-18 18:17:11	63	0	\N	\N
755844	DELEGATION	AUCUNE	\N	\N	PROS	Réunion constitutive	\N	2023-10-18 08:00:00	2023-10-18 08:15:00	2023-10-18 09:16:10	\N	19	0	\N	\N
765407	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PJL Partage de la valeur	CMP PJL Partage de la valeur	2023-11-16 10:30:00	2023-11-16 11:20:00	\N	\N	38	0	\N	\N
765408	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2024	PLFSS 2024	2023-11-16 11:25:00	2023-11-16 12:55:00	\N	\N	64	0	\N	\N
765409	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2024	PLFSS 2024	2023-11-16 14:35:00	2023-11-16 20:00:00	\N	\N	68	0	\N	\N
765410	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2024	PLFSS 2024	2023-11-16 21:30:00	2023-11-17 00:30:00	\N	\N	49	0	\N	\N
765411	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2024	PLFSS 2024	2023-11-17 09:30:00	2023-11-17 13:05:00	\N	\N	47	0	\N	\N
765412	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2024	PLFSS 2024	2023-11-17 14:35:00	2023-11-17 20:00:00	\N	\N	51	0	\N	\N
765413	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2024	PLFSS 2024	2023-11-17 21:30:00	2023-11-18 00:00:00	\N	\N	0	0	\N	\N
765494	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF2024 - P152 - audition DSF de la gendarmerie nationale	PLF2024 - P152 - audition DSF de la gendarmerie nationale	2023-11-07 16:00:00	2023-11-07 17:00:00	\N	\N	2	0	\N	\N
765505	QUESTURE	AUCUNE	\N	\N	\N	Réunion de Questure	Réunion du Conseil de Questure	2023-11-07 16:00:00	2023-11-07 18:00:00	\N	\N	3	0	\N	\N
765509	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	PLF2024 - P129 - Déplacement à Lyon (Cybercercle)	PLF2024 - P129 - Déplacement à Lyon (Cybercercle)	2023-11-06 08:00:00	2023-11-06 20:00:00	\N	\N	1	0	\N	\N
765511	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF2024 - P144 - audition DGSE	PLF2024 - P144 - audition DGSE	2023-11-07 15:00:00	2023-11-07 16:00:00	\N	\N	1	0	\N	\N
765513	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF2024 - P129 - table ronde Orange groupe et Thales	PLF2024 - P129 - table ronde Orange groupe et Thales	2023-11-08 08:00:00	2023-11-08 09:30:00	\N	\N	2	0	\N	\N
767427	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Ecologie - Audition DG aménagement, logement et nature	PLF pour 2024 - Ecologie - Audition de M. HUET et Mme ESCANDE-VILBOIS, DiG aménagement, logement et nature	2023-11-10 13:30:00	2023-11-10 15:00:00	\N	\N	1	0	\N	\N
767429	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Ecologie - Audition Ministère transition écologique et territoires	PLF pour 2024 - Ecologie - Audition M. LEFORESTIER, Ministère transition écologique et territoires	2023-11-10 15:30:00	2023-11-10 16:30:00	\N	\N	1	0	\N	\N
767431	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Ecologie - Audition ADEME	PLF pour 2024 - Ecologie - Audition de M. PERRISIN FABERT, ADEME	2023-11-10 16:30:00	2023-11-10 17:30:00	\N	\N	1	0	\N	\N
767551	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition M. Tabarot	\N	2023-11-14 13:45:00	2023-11-14 14:30:00	\N	\N	2	0	\N	\N
767554	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition MM. Gillé et Tabarot	\N	2023-11-14 18:45:00	2023-11-14 19:30:00	\N	\N	2	0	\N	\N
767591	COM_ENQUETE	PLENIERE	\N	NARCO	\N	Réunion constitutive	Réunion constitutive	2023-11-21 08:30:00	2023-11-21 09:30:00	2023-11-21 10:13:13	2023-11-21 17:08:01	16	4	\N	\N
767626	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2024 - Enseignement agricole	\N	2023-11-15 13:30:00	2023-11-15 15:00:00	\N	\N	3	0	\N	\N
767711	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition M. Didier Mandelli	Audition M. Didier Mandelli	2023-11-15 14:00:00	2023-11-15 15:00:00	\N	\N	3	0	\N	\N
767790	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur DGEFP	\N	2023-11-15 16:30:00	2023-11-15 17:30:00	\N	\N	2	0	\N	\N
767904	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition Agnès Pannier-Runacher	\N	2023-11-15 16:30:00	2023-11-15 18:25:00	2023-11-15 18:33:48	2023-11-16 18:27:51	25	1	\N	\N
768230	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PLF 2024 - CRE	Audition PLF 2024 - CRE	2023-11-07 14:00:00	2023-11-07 14:45:00	\N	\N	1	0	\N	\N
768232	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLF pour 2024 - Avis justice judiciaire et accès au droit	Audition rapporteur - PLF 2024 - Avis justice judiciaire et accès au droit	2023-11-15 14:15:00	2023-11-15 15:00:00	\N	\N	2	0	\N	\N
768236	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition M. Tabarot	\N	2023-11-14 08:15:00	2023-11-14 09:15:00	\N	\N	1	0	\N	\N
768239	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PLF 2024 - DGEC	Audition PLF 2024 - DGEC	2023-11-08 19:00:00	2023-11-08 20:00:00	\N	\N	1	0	\N	\N
768245	COM_PERMANENTE	AUTRE	\N	AFCL	\N	MCC audition Guerini	\N	2023-11-15 16:30:00	2023-11-15 17:30:00	2023-11-15 17:35:52	2023-11-16 18:27:50	28	0	\N	\N
768431	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de F. Pacoud, candidat à la présidence de l'EFS	\N	2023-11-22 09:00:00	2023-11-22 10:25:00	2023-11-22 10:25:59	2023-11-22 11:50:38	46	0	\N	\N
768443	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF pour 2024 - Audition Direction du budget 	\N	2023-11-22 16:15:00	2023-11-22 17:15:00	\N	\N	2	0	\N	\N
768827	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 22 novembre 2023	\N	2023-11-22 13:30:00	2023-11-22 14:50:00	2023-11-22 15:42:12	2023-11-22 17:39:23	14	0	\N	\N
768933	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PLF pour 2024 - Avis	PLF pour 2024 - Avis	2023-11-21 09:00:00	2023-11-21 10:00:00	2023-11-22 11:03:50	2023-11-22 11:50:39	22	3	\N	\N
768934	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Budget 2024 - Audition de Philippe Vigier, ministre délégué chargé des outre-mer	Budget 2024 - Audition de Philippe Vigier, ministre délégué chargé des outre-mer	2023-11-21 17:30:00	2023-11-21 18:45:00	2023-11-22 11:04:02	2023-11-22 11:50:39	13	0	\N	\N
768946	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MCC enseignants 	\N	2023-11-15 18:00:00	2023-11-15 19:30:00	\N	\N	6	0	\N	\N
768960	BUREAU	AUCUNE	\N	\N	\N	Réunion du Bureau du Sénat	Réunion du Bureau du Sénat	2023-11-16 08:30:00	2023-11-16 10:30:00	\N	\N	21	0	\N	\N
768993	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Table ronde sur le thème "Pénurie de foncier économique : l¿entreprise à terre ?"	\N	2023-11-16 08:30:00	2023-11-16 10:20:00	\N	\N	12	0	\N	\N
769069	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLF pour 2024 - Mission Sécurités	PJLF pour 2024 - Mission Sécurités	2023-11-15 15:15:00	2023-11-15 16:30:00	\N	\N	1	0	\N	\N
769072	DELEGATION	AUCUNE	\N	\N	211	Auditions thématiques : Familles monoparentales	\N	2023-12-14 08:35:00	2023-12-14 10:40:00	\N	\N	9	0	\N	\N
769074	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLF pour 2024 - Avis Juridictions administratives et Juridictions financières	PJLF pour 2024 - Avis Juridictions administratives et Juridictions financières	2023-11-16 14:30:00	2023-11-16 17:00:00	\N	\N	1	0	\N	\N
769077	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF Audiovisuel	\N	2023-11-15 18:30:00	2023-11-15 19:30:00	\N	\N	2	0	\N	\N
769078	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF Audiovisuel public	\N	2023-11-16 09:00:00	2023-11-16 11:30:00	\N	\N	1	0	\N	\N
769387	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF2024 - P144 - audition sous-chef plans-programmes de l'état-major de la marine	PLF2024 - P144 - audition sous-chef plans-programmes de l'état-major de la marine	2023-11-13 17:00:00	2023-11-13 17:45:00	\N	\N	2	0	\N	\N
769390	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF2024 - P144 - audition du directeur de l'Agence de l'innovation de défense	PLF2024 - P144 - audition du directeur de l'Agence de l'innovation de défense	2023-11-15 14:00:00	2023-11-15 15:00:00	\N	\N	2	0	\N	\N
769393	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF2024 - P144 - audition PDG Onera	PLF2024 - P144 - audition PDG Onera	2023-11-16 09:30:00	2023-11-16 10:20:00	\N	\N	2	0	\N	\N
769396	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF2024 - P144 - audition sous-chef plans-programmes de l'état-major de l'armée de l'air	PLF2024 - P144 - audition sous-chef plans-programmes de l'état-major de l'armée de l'air	2023-11-16 10:20:00	2023-11-16 11:20:00	\N	\N	1	0	\N	\N
638758	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	MCC Sécurisation de la chasse	MCC sécurisation de la chasse	2022-03-08 14:00:00	2022-03-08 19:05:00	\N	\N	9	0	\N	\N
638770	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI France compétences - Audition organismes certificateurs	\N	2022-03-08 16:00:00	2022-03-08 17:00:00	\N	\N	3	0	\N	\N
638774	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI France compétences - Audition syndicats	\N	2022-03-08 17:00:00	2022-03-08 18:45:00	\N	\N	3	0	\N	\N
639515	QUESTURE	AUCUNE	\N	\N	\N	Réunion de Questure	Réunion de Questure	2022-03-16 09:00:00	2022-03-16 10:30:00	\N	\N	3	0	\N	\N
639519	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT subsidiarité	GT Subsidiarité	2022-03-17 17:15:00	2022-03-17 17:30:00	\N	\N	3	0	\N	\N
655205	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2022-07-26 18:02:00	2022-07-26 18:21:00	\N	\N	26	0	\N	\N
655819	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL agrivoltaïsme	PPL agrivoltaïsme	2022-09-20 16:30:00	2022-09-20 17:00:00	\N	\N	5	0	\N	\N
655820	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL agrivoltaïsme	PPL agrivoltaïsme	2022-09-20 17:00:00	2022-09-20 18:15:00	\N	\N	1	0	\N	\N
656064	DELEGATION	AUTRE	\N	\N	206	Audition publique sur les impacts de l'alimentation ultra-transformée	\N	2022-09-22 09:05:00	2022-09-22 11:50:00	\N	\N	7	0	\N	\N
656119	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Régime de réélection des juges consulaires (rapport) - Audition du DGPN (MI Org. PJ)	PPL Régime de réélection des juges consulaires (rapport) - Audition du DGPN (MI Org. PJ)	2022-09-28 09:30:00	2022-09-28 11:45:00	2022-09-29 14:41:59	2022-09-29 14:42:05	30	0	\N	\N
656157	DELEGATION	AUCUNE	\N	\N	PROS	Audition de M. Jean Viard sur le thème de l'avenir du tourisme.	\N	2022-09-29 08:35:00	2022-09-29 09:45:00	\N	\N	6	0	\N	\N
656159	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Auditions  plénières	\N	2022-09-28 15:00:00	2022-09-28 18:15:00	2022-09-28 18:15:08	2022-09-29 14:40:58	31	0	\N	\N
650036	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Pouvoir d'achat - Audition commune CPSTI-FNAE	\N	2022-07-19 16:30:00	2022-07-19 17:30:00	\N	\N	2	0	\N	\N
768433	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Examen 2 avis PLF 2024 + désig. rapp. PPL Titres-restau et PPL Erasmus apprentissage	\N	2023-11-22 10:25:00	2023-11-22 11:30:00	2023-11-22 11:31:46	2023-11-22 11:50:36	44	0	\N	\N
769348	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Examen de 5 avis budgétaires	Examen de 5 avis budgétaires	2023-11-22 09:30:00	2023-11-22 11:10:00	2023-11-22 11:35:25	2023-11-22 11:50:37	41	3	\N	\N
656160	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-09-28 09:45:00	2022-09-28 12:25:00	2022-09-28 12:24:32	2022-09-28 16:49:34	31	0	\N	\N
656166	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Formation sage-femme - Audition rapporteure	\N	2022-09-22 15:00:00	2022-09-22 16:15:00	\N	\N	3	0	\N	\N
656724	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2022-09-28 14:30:00	2022-09-28 17:15:00	\N	\N	2	0	\N	\N
671223	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions M. Laurent Duplomb, Mme Françoise Férat et M. Jean-Claude Tissot	\N	2022-11-08 13:30:00	2022-11-08 15:00:00	\N	\N	3	0	\N	\N
671227	DELEGATION	AUDRAP	\N	\N	PROS	Audition de M. Rio	\N	2022-11-08 15:00:00	2022-11-08 16:00:00	\N	\N	1	0	\N	\N
671229	DELEGATION	AUDRAP	\N	\N	PROS	Audition de M. Bonin	\N	2022-11-08 16:00:00	2022-11-08 16:45:00	\N	\N	1	0	\N	\N
671233	DELEGATION	AUDRAP	\N	\N	PROS	Audition de Mme Terrot Dontenwill	\N	2022-11-08 16:45:00	2022-11-08 17:45:00	\N	\N	1	0	\N	\N
671830	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de M. Marc Fesneau	\N	2022-11-09 16:30:00	2022-11-09 19:00:00	2022-11-10 11:46:57	2022-11-10 16:13:07	37	0	\N	\N
676370	GIA	AUCUNE	\N	\N	\N	Célébration des 60 ans de l'arrivée de 20 enfants tibétains en France	Célébration des 60 ans de l'arrivée de 20 enfants tibétains en France	2022-12-07 17:00:00	2022-12-07 20:00:00	\N	\N	4	0	634	\N
676585	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2023	PLF 2023	2022-11-24 10:35:00	2022-11-24 13:20:00	\N	\N	110	0	\N	\N
676586	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2023	PLF 2023	2022-11-24 14:50:00	2022-11-24 19:05:00	\N	\N	119	0	\N	\N
676588	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Mission transformation et fonction publiques	Mission transformation et fonction publiques	2022-11-24 21:30:00	2022-11-24 22:55:00	\N	\N	38	0	\N	\N
676593	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Mission Plan de relance	Mission Plan de relance	2022-11-29 22:30:00	2022-11-30 01:10:00	\N	\N	36	0	\N	\N
676594	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Mission Engagements financiers de l'État	Mission Engagements financiers de l'État	2022-11-25 22:50:00	2022-11-26 00:10:00	\N	\N	17	0	\N	\N
676596	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Conclusions de la CMP sur le PLFR	Conclusions de la CMP sur le PLFR	2022-11-25 10:30:00	2022-11-25 11:30:00	\N	\N	37	0	\N	\N
676597	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Mission Sécurités	Mission Sécurités	2022-11-25 11:30:00	2022-11-25 13:05:00	\N	\N	37	0	\N	\N
676599	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Mission Justice 	Mission Justice	2022-11-25 17:30:00	2022-11-25 19:50:00	\N	\N	36	0	\N	\N
676600	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Mission Administration générale et territoriale de l'État	Mission Administration générale et territoriale de l'État	2022-11-25 21:30:00	2022-11-25 22:50:00	\N	\N	19	0	\N	\N
676608	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Mission Travail et emploi	Mission Travail et emploi	2022-11-28 10:00:00	2022-11-28 12:40:00	\N	\N	35	0	\N	\N
676609	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Mission Anciens combattants, mémoire et liens avec la Nation	Mission Anciens combattants, mémoire et liens avec la Nation	2022-11-28 14:15:00	2022-11-28 15:35:00	\N	\N	37	0	\N	\N
676610	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Mission Culture	Mission Culture	2022-11-28 15:35:00	2022-11-28 18:05:00	\N	\N	54	0	\N	\N
676611	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Mission Médias, livre et industries culturelles	Mission Médias, livre et industries culturelles	2022-11-28 18:05:00	2022-11-28 20:15:00	\N	\N	59	0	\N	\N
676612	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Mission Recherche et enseignement supérieur	Mission Recherche et enseignement supérieur	2022-11-28 21:45:00	2022-11-30 00:30:00	\N	\N	50	0	\N	\N
676613	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2022-11-29 09:30:00	2022-11-29 12:35:00	\N	\N	53	0	\N	\N
676614	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Nouvelle lecture PLFSS pour 2023	Nouvelle lecture PLFSS pour 2023	2022-11-29 14:30:00	2022-11-29 16:25:00	\N	\N	98	0	\N	\N
676615	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Mission Solidarité, insertion et égalité des chances	Mission Solidarité, insertion et égalité des chances	2022-11-29 16:25:00	2022-11-29 19:20:00	\N	\N	133	0	\N	\N
676616	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Mission Santé	Mission Santé	2022-11-29 19:20:00	2022-11-29 20:05:00	\N	\N	58	0	\N	\N
676617	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Mission Relations avec les collectivités territoriales	Mission Relations avec les collectivités territoriales	2022-11-30 10:30:00	2022-11-30 13:05:00	\N	\N	129	0	\N	\N
676618	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Mission Agriculture, alimentation, forêt et affaires rurales	Mission Agriculture, alimentation, forêt et affaires rurales	2022-11-30 21:40:00	2022-12-01 01:45:00	\N	\N	65	0	\N	\N
676619	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Mission Immigration, asile et intégration	Mission Immigration, asile et intégration	2022-12-01 10:45:00	2022-12-01 12:20:00	\N	\N	62	0	\N	\N
676620	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Mission Pouvoirs publics	Mission Pouvoirs publics	2022-12-01 12:20:00	2022-12-01 13:00:00	\N	\N	38	0	\N	\N
676621	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Mission Outre-mer	Mission Outre-mer	2022-12-01 15:50:00	2022-12-01 19:20:00	\N	\N	59	0	\N	\N
676622	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Mission Enseignement scolaire	Mission Enseignement scolaire	2022-12-01 19:20:00	2022-12-01 20:00:00	\N	\N	34	0	\N	\N
676623	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Mission Cohésion des territoires	Mission Cohésion des territoires	2022-12-02 09:45:00	2022-12-02 13:40:00	\N	\N	47	0	\N	\N
728559	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 Installation agriculteurs - Audition Mutuelle sociale agricole (MSA)	58-2 Installation agriculteurs - Audition Mutuelle sociale agricole (MSA)	2023-05-02 15:30:00	2023-05-02 16:30:00	\N	\N	2	0	\N	\N
728564	MECSS	AUDRAP	\N	\N	MECSS	Audition de la DHUP	\N	2023-05-09 16:15:00	2023-05-09 17:30:00	\N	\N	2	0	\N	\N
650037	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Pouvoir d'achat - Audition commune CNAV-CCMSA	\N	2022-07-20 10:00:00	2022-07-20 11:00:00	\N	\N	2	0	\N	\N
728582	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 32 Audition Mmes ATIG, MASSE, SCIALOM et M. MICHAUD	PLENIERE - 32 Audition Mmes ATIG, MASSE, SCIALOM et M. MICHAUD	2023-05-10 10:00:00	2023-05-10 12:10:00	2023-05-10 13:01:36	2023-05-10 15:28:46	31	0	\N	\N
728691	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL Biens spolliés	\N	2023-05-09 14:30:00	2023-05-09 15:30:00	\N	\N	4	0	\N	\N
728891	MISSION	AUDRAP	\N	GEAU	\N	Audiiton de la Cour des Comptes	\N	2023-05-09 16:30:00	2023-05-09 17:30:00	\N	\N	5	0	\N	\N
728895	MISSION	AUDRAP	\N	GEAU	\N	Audition de France Urbaine	\N	2023-05-09 17:30:00	2023-05-09 19:00:00	\N	\N	5	0	\N	\N
728901	MISSION	AUCUNE	\N	GEAU	\N	Audiiton de l'ADF	\N	2023-05-10 14:00:00	2023-05-10 15:00:00	2023-05-10 16:11:08	2023-05-10 17:45:50	9	0	\N	\N
728902	MISSION	AUDRAP	\N	GEAU	\N	Audition du CEREMA	\N	2023-05-10 17:30:00	2023-05-10 18:30:00	\N	\N	5	0	\N	\N
728908	MISSION	AUDRAP	\N	BATI	\N	filiere beton	\N	2023-05-09 14:00:00	2023-05-09 15:00:00	\N	\N	0	0	\N	\N
728909	MISSION	AUDRAP	\N	BATI	\N	Schneider	\N	2023-05-09 18:00:00	2023-05-09 19:00:00	\N	\N	0	0	\N	\N
728910	MISSION	AUDRAP	\N	BATI	\N	Schneider	\N	2023-05-09 18:00:00	2023-05-09 19:00:00	\N	\N	0	0	\N	\N
728918	MISSION	AUTRE	\N	BIOCARBU	\N	Audition de Philippe Mauguin INRAE	\N	2023-05-10 18:30:00	2023-05-10 20:00:00	\N	\N	0	0	\N	\N
728919	MISSION	AUCUNE	\N	BIOCARBU	\N	Audition de Philippe Mauguin INRAE	\N	2023-05-09 19:10:00	2023-05-09 20:55:00	2023-05-09 20:54:11	2023-05-10 12:23:02	9	0	\N	\N
728944	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	expertise patrimoniale	\N	2023-05-09 09:30:00	2023-05-09 10:30:00	\N	\N	2	0	\N	\N
729274	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL emploi des conjoints des agents des missions officielles	PJL emploi des conjoints des agents des missions officielles	2023-05-09 14:00:00	2023-05-09 15:10:00	\N	\N	1	0	\N	\N
730499	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Données de connexion	\N	2023-05-10 17:00:00	2023-05-10 19:00:00	\N	\N	3	0	\N	\N
730560	COM_ENQUETE	PLENIERE	\N	TIKTO	\N	Auditions Sabine Duflo, Servane Mouton et Romain Badouard	Auditions Sabine Duflo, Servane Mouton et Romain Badouard	2023-05-15 15:00:00	2023-05-15 17:50:00	2023-05-16 12:01:54	2023-05-16 15:30:28	4	0	\N	\N
730770	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Orientation et programmation du ministère de la justice 2023-2027	PJL Orientation et programmation du ministère de la justice 2023-2027	2023-05-22 17:00:00	2023-05-22 19:40:00	\N	\N	1	0	\N	\N
730771	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Orientation et programmation du ministère de la justice 2023-2027	PJL Orientation et programmation du ministère de la justice 2023-2027	2023-05-23 08:00:00	2023-05-23 10:00:00	\N	\N	3	0	\N	\N
730793	GIA	AUCUNE	\N	\N	\N	Dîner d'accueil de la délégation du Parlement moldave	Dîner d'accueil de la délégation du groupe d'amitié du Parlement moldave	2023-05-14 19:30:00	2023-05-14 22:00:00	\N	\N	1	0	851	\N
731271	QUESTURE	AUCUNE	\N	\N	\N	Réunion de Questure	Réunion du Conseil de Questure	2023-05-11 09:00:00	2023-05-11 10:20:00	\N	\N	3	0	\N	\N
731272	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Orientation et programmation du ministère de la justice 2023-2027	PJL Orientation et programmation du ministère de la justice 2023-2027	2023-05-16 15:45:00	2023-05-16 17:00:00	\N	\N	4	0	\N	\N
731537	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition CNES	\N	2023-05-17 09:30:00	2023-05-17 11:10:00	2023-05-17 11:18:42	2023-05-17 14:38:14	32	0	\N	\N
732892	SEANCE_PLENIERE	SCRUSOL	1842	\N	\N	Scrutin solennel - PPL Ferme France	Scrutin solennel  - PPL Ferme France	2023-05-23 15:40:00	2023-05-23 15:45:00	\N	\N	0	0	\N	\N
732893	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	1842	\N	\N	Explications de vote sur l'ensemble PPL Ferme France	Explications de vote sur l'ensemble PPL Ferme France	2023-05-23 14:30:00	2023-05-23 15:40:00	\N	\N	268	0	\N	\N
733759	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Données de connexion	\N	2023-05-23 15:30:00	2023-05-23 18:30:00	\N	\N	3	0	\N	\N
733902	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Reconnaissance biométrique	Audition rapporteur - PPL Reconnaissance biométrique	2023-05-23 09:00:00	2023-05-23 11:00:00	\N	\N	1	0	\N	\N
733922	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2023-05-23 17:00:00	2023-05-23 19:30:00	\N	\N	1	0	\N	\N
734148	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	\N	\N	2023-05-23 14:30:00	2023-05-23 17:00:00	\N	\N	4	0	\N	\N
735256	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI JOP	Airbnb	2023-05-24 16:30:00	2023-05-24 17:30:00	\N	\N	3	0	\N	\N
735272	DELEGATION	AUDRAP	\N	\N	PROS	Audition Espace	\N	2023-05-24 16:30:00	2023-05-24 18:30:00	\N	\N	2	0	\N	\N
735273	DELEGATION	AUCUNE	\N	\N	COLTER	Réunion plénière	\N	2023-05-25 10:30:00	2023-05-25 12:15:00	2023-05-25 12:16:01	\N	17	0	\N	\N
735294	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Reconnaissance biométrique (rapport et texte)	PPL Reconnaissance biométrique (rapport et texte)	2023-05-31 13:30:00	2023-05-31 14:20:00	2023-05-31 15:00:31	2023-06-02 16:09:54	18	1	\N	\N
735295	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Soutien au maire de Saint-Brevin - Audition des autorités préfectorales	Soutien au maire de Saint-Brevin - Audition des autorités préfectorales	2023-05-31 18:05:00	2023-05-31 19:50:00	2023-05-31 20:39:41	2023-06-02 16:09:56	17	0	\N	\N
735305	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 1er juin 2023	\N	2023-06-01 08:30:00	2023-06-01 11:00:00	2023-06-01 11:06:07	2023-06-02 16:10:27	14	0	\N	\N
735340	GIA	AUCUNE	\N	\N	\N	Entretien avec Oleksandr Korniyenko, premier vice-président de la Rada	Entretien avec Oleksandr Korniyenko, premier vice-président de la Rada	2023-05-24 18:00:00	2023-05-24 19:00:00	\N	\N	10	0	530	\N
735351	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-05-31 10:30:00	2023-05-31 12:15:00	2023-05-31 12:18:47	2023-06-02 16:09:54	32	0	\N	\N
735373	COM_ENQUETE	PLENIERE	\N	MEDIC	\N	Audition plénière	\N	2023-05-30 09:05:00	2023-05-30 10:50:00	2023-05-30 11:17:57	2023-06-02 16:10:38	9	0	\N	\N
735374	COM_ENQUETE	PLENIERE	\N	MEDIC	\N	Audition de Mme Pannier-Runacher	\N	2023-05-31 13:35:00	2023-05-31 14:55:00	2023-05-31 15:23:11	2023-06-02 16:10:40	9	0	\N	\N
735375	MISSION	AUDRAP	\N	GEAU	\N	Syndicat des eaux d¿Île-de-France (SEDIF) 	\N	2023-05-25 11:00:00	2023-05-25 12:10:00	\N	\N	2	0	\N	\N
735378	MISSION	AUDRAP	\N	GEAU	\N	Syndicat de l¿eau du Dunkerquois 	\N	2023-05-25 12:10:00	2023-05-25 13:00:00	\N	\N	2	0	\N	\N
735385	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 203 - Formation continue enseignants - Audition DGRH	Contrôle 203 - Formation continue enseignants - Audition DGRH	2023-05-24 16:30:00	2023-05-24 17:30:00	\N	\N	1	0	\N	\N
735387	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 203 - Formation continue enseignants - Audition syndicats enseignants	Contrôle 203 - Formation continue enseignants - Audition syndicats enseignants	2023-05-24 17:30:00	2023-05-24 18:30:00	\N	\N	1	0	\N	\N
735389	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - ORE - Audition syndicat étudiant FAGE	Contrôle 2023 - ORE - Audition syndicat étudiant FAGE	2023-05-25 15:30:00	2023-05-25 16:15:00	\N	\N	1	0	\N	\N
735391	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - ORE - Audition du cabinet ministère recherche et enseignement	Contrôle 2023 - ORE - Audition du cabinet ministère recherche et enseignement	2023-05-25 16:15:00	2023-05-25 17:15:00	\N	\N	1	0	\N	\N
735393	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - COROM - Audition commune de Mahina	Contrôle 2023 - COROM - Audition commune de Mahina	2023-05-25 19:00:00	2023-05-25 20:15:00	\N	\N	2	0	\N	\N
735396	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - EPF/EPA - Audition M. GROS, maire de Montreuil (84)	Contrôle 2023 - EPF/EPA - Audition M. GROS, maire de Montreuil (84)	2023-05-23 16:00:00	2023-05-23 16:40:00	\N	\N	1	0	\N	\N
735398	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - EPF/EPA - Audition banque des territoires	Contrôle 2023 - EPF/EPA - Audition banque des territoires	2023-05-23 16:40:00	2023-05-23 17:30:00	\N	\N	1	0	\N	\N
735400	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - EPF/EPA - Audition Régions de France	Contrôle 2023 - EPF/EPA - Audition Régions de France	2023-05-24 17:30:00	2023-05-24 18:30:00	\N	\N	1	0	\N	\N
735402	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - CESE - Audition cabinets de conseil en animation	Contrôle 2023 - CESE - Audition cabinets de conseil en animation	2023-05-24 14:00:00	2023-05-24 14:50:00	\N	\N	1	0	\N	\N
735404	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Boucliers tarifaires et amortisseurs - Audition USH	Contrôle 2023 - Boucliers tarifaires et amortisseurs - Audition USH	2023-05-22 09:00:00	2023-05-22 09:30:00	\N	\N	1	0	\N	\N
735406	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Boucliers tarifaires et amortisseurs - Audition Mme CARON, CPME	Contrôle 2023 - Boucliers tarifaires et amortisseurs - Audition Mme CARON, CPME	2023-05-22 09:30:00	2023-05-22 10:00:00	\N	\N	1	0	\N	\N
638335	COM_PERMANENTE	AUDRAP	\N	CDD	\N	MI Aménagement du territoire - Audition commune	MI Aménagement du territoire - Audition commune	2022-03-01 14:30:00	2022-03-01 15:05:00	\N	\N	4	0	\N	\N
638340	COM_PERMANENTE	AUDRAP	\N	CDD	\N	MI Aménagement du territoire - Audition commune	MI Aménagement du territoire - Audition commune	2022-03-01 16:00:00	2022-03-01 16:45:00	\N	\N	3	0	\N	\N
638346	COM_PERMANENTE	AUDRAP	\N	CDD	\N	MI Aménagement du territoire - Audition commune	MI Aménagement du territoire - Audition commune	2022-03-02 09:30:00	2022-03-02 10:30:00	\N	\N	6	0	\N	\N
638353	COM_PERMANENTE	AUDRAP	\N	CDD	\N	MI Aménagement du territoire - Audition commune	MI Aménagement du territoire - Audition commune	2022-03-02 11:30:00	2022-03-02 12:30:00	\N	\N	3	0	\N	\N
638581	ETUDES	AUTRE	\N	\N	\N	GEAC - Audition de M. Michel WACHENHEIM, Président de l'Académie de l'air et de l'espace	GEAC - Audition de M. Michel WACHENHEIM, Président de l'Académie de l'air et de l'espace	2022-03-15 16:30:00	2022-03-15 17:40:00	\N	\N	11	0	\N	933
638709	COM_ENQUETE	AUDRAP	\N	HOPITAL	\N	CE Hôpital - Table ronde des syndicats de médecins libéraux	\N	2022-03-08 16:00:00	2022-03-08 17:55:00	\N	\N	4	0	\N	\N
638710	COM_ENQUETE	AUDRAP	\N	HOPITAL	\N	Audition de l'Association française de chirurgie ambulatoire	\N	2022-03-08 15:00:00	2022-03-08 16:00:00	\N	\N	3	0	\N	\N
640834	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	MCC Sécurisation chasse - Auditions diverses	\N	2022-03-29 14:00:00	2022-03-29 19:00:00	\N	\N	0	0	\N	\N
640857	DELEGATION	AUCUNE	\N	\N	211	Table ronde sur la protection des mineurs face aux contenus pornographiques	Table ronde sur la protection des mineurs face aux contenus pornographiques	2022-04-27 14:00:00	2022-04-27 15:50:00	\N	\N	7	0	\N	\N
641644	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition Sébastien Cavalier - Pass culture	Audition Sébastien Cavalier - Pass culture	2022-04-26 15:36:00	2022-04-26 16:40:00	2022-04-26 17:30:01	2022-04-27 18:43:25	22	0	\N	\N
641645	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Souveraineté économique - Audition UIMM	MI Souveraineté économique - Audition UIMM	2022-04-19 13:30:00	2022-04-19 14:50:00	\N	\N	4	0	\N	\N
641678	COM_EURO	AUDRAP	\N	AFEU	\N	Audition intelligence artificielle	\N	2022-04-20 10:00:00	2022-04-20 12:00:00	\N	\N	3	0	\N	\N
641679	COM_EURO	AUDRAP	\N	AFEU	\N	Audition intelligence artificielle	\N	2022-04-20 14:45:00	2022-04-20 15:45:00	\N	\N	2	0	\N	\N
641685	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 -  Régimes des retraites RATP et Marins - Asso pensionnés régimes marins	Contrôle 2022 -  Régimes des retraites RATP et Marins - Asso pensionnés régimes marins	2022-04-20 11:15:00	2022-04-20 12:40:00	\N	\N	1	0	\N	\N
641687	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - Régimes des retraites RATP et Marins - ENIM	Contrôle 2022 - Régimes des retraites RATP et Marins - ENIM	2022-04-20 14:25:00	2022-04-20 15:55:00	\N	\N	1	0	\N	\N
641689	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022- Dotations d'investissement aux CT - DGCL	Contrôle 2022- Dotations d'investissement aux CT - DGCL	2022-04-20 14:30:00	2022-04-20 16:00:00	\N	\N	2	0	\N	\N
641719	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	MI Information du consommateur	MI Information du consommateur	2022-04-19 14:00:00	2022-04-19 16:15:00	\N	\N	2	0	\N	\N
642249	COM_PERMANENTE	AUDRAP	\N	FINC	\N	MCC 2022 - Audiovisuel Public - Personnalités qualifiées	MCC 2022 - Audiovisuel Public - Personnalités qualifiées	2022-05-09 09:30:00	2022-05-09 11:00:00	\N	\N	2	0	\N	\N
643385	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - FEI - DGOM	Contrôle 2022 - FEI - DGOM	2022-05-24 18:15:00	2022-05-24 20:00:00	\N	\N	2	0	\N	\N
643392	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Incidents Stade de France - Audition Gérald Darmanin et Amélie Oudéa-Castéra	Incidents Stade de France - Audition Gérald Darmanin et Amélie Oudéa-Castéra	2022-06-01 17:05:00	2022-06-01 20:05:00	2022-06-02 13:27:35	2022-06-07 19:44:31	73	0	\N	\N
644885	COM_PERMANENTE	AUTRE	\N	CAE	\N	MCC sécurisation de la chasse	MCC sécurisation de la chasse	2022-06-15 15:30:00	2022-06-15 16:45:00	2022-06-15 17:00:33	2022-06-15 17:23:29	6	0	\N	\N
644898	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL Autorité bancaire européenne	\N	2022-06-15 15:00:00	2022-06-15 16:30:00	\N	\N	1	0	\N	\N
644902	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MCI Délinquance des mineurs	Auditions rapporteur - MI Délinquance des mineurs	2022-06-15 15:30:00	2022-06-15 17:00:00	\N	\N	5	0	\N	\N
644909	GIA	AUCUNE	\N	\N	\N	Rencontre avec une opposante biélorusse	Rencontre avec Mme Tatsiana Khomich, représentante de  l'opposition biélorussee	2022-06-14 14:00:00	2022-06-14 15:30:00	\N	\N	4	0	852	\N
646225	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2022-06-30 10:00:00	2022-06-30 11:15:00	\N	\N	22	0	\N	\N
649725	COM_PERMANENTE	AUTRE	\N	CAE	\N	Examen RI + Audition CMA CGM	\N	2022-07-20 08:40:00	2022-07-20 10:00:00	2022-07-20 14:22:16	2022-07-20 18:41:00	36	1	\N	\N
649773	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de M. Rodolphe Saadé	\N	2022-07-20 10:05:00	2022-07-20 12:10:00	\N	\N	76	1	\N	\N
649846	COM_EURO	AUDRAP	\N	AFEU	\N	Audition DINUM	\N	2022-07-19 16:00:00	2022-07-19 17:00:00	\N	\N	2	0	\N	\N
650018	ETUDES	AUTRE	\N	\N	\N	Table ronde Stations Tourisme	Table ronde Stations Tourisme	2022-07-13 13:35:00	2022-07-13 14:40:00	\N	\N	7	0	\N	918
650034	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Pouvoir d'achat - Table ronde FEP-AFB-FCD	\N	2022-07-19 14:00:00	2022-07-19 15:15:00	\N	\N	2	0	\N	\N
650035	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Pouvoir d'achat - Audition Gilbert Cette	\N	2022-07-19 15:30:00	2022-07-19 16:15:00	\N	\N	3	0	\N	\N
650038	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Pouvoir d'achat - Audition DGT	\N	2022-07-20 11:00:00	2022-07-20 12:00:00	\N	\N	5	0	\N	\N
650242	DELEGATION	AUCUNE	\N	\N	COLTER	Table-ronde simplification des normes	\N	2022-07-21 09:00:00	2022-07-21 11:30:00	\N	\N	22	0	\N	\N
655724	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Avis budgétaire - Juridictions administratives et juridictions financières 	Avis budget -Juridictions administratives et juridictions financieres (Déplacement à Lyon)	2022-09-15 09:00:00	2022-09-15 18:00:00	\N	\N	1	0	\N	\N
655726	GIA	AUCUNE	\N	\N	\N	entretien avec S.E. Sheikh Ali bin Jassim Al-Thani, ambassadeur du Qatar	\N	2022-09-20 09:30:00	2022-09-20 11:00:00	\N	\N	1	0	661	\N
655859	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Examen RI délinquance des mineurs	\N	2022-09-21 11:10:00	2022-09-21 12:10:00	2022-09-21 15:27:29	2022-09-22 15:26:04	41	4	\N	\N
655977	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF Enssco	\N	2022-09-20 16:00:00	2022-09-20 17:00:00	\N	\N	6	0	\N	\N
656037	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Formation sage-femme - Audition rapporteure	\N	2022-09-21 10:30:00	2022-09-21 11:30:00	\N	\N	1	0	\N	\N
656038	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Formation sage-femme - Audition rapporteure	\N	2022-09-21 11:30:00	2022-09-21 13:00:00	\N	\N	1	0	\N	\N
656039	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Formation sage-femme - Audition rapporteure	\N	2022-09-21 13:45:00	2022-09-21 14:40:00	\N	\N	1	0	\N	\N
656040	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Formation sage-femme - Audition rapporteure	\N	2022-09-21 14:40:00	2022-09-21 15:45:00	\N	\N	1	0	\N	\N
656041	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Formation sage-femme - Audition rapporteure	\N	2022-09-21 15:45:00	2022-09-21 17:10:00	\N	\N	1	0	\N	\N
656042	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2023 - Audition de MM. LE MAIRE et ATTAL - Désignations rapporteur et membres MI 	PLF pour 2023 - Audition de MM. LE MAIRE et ATTAL - Désignations rapporteur et membres MI ZAN	2022-09-26 17:35:00	2022-09-26 19:45:00	2022-09-27 10:09:20	2022-09-27 14:54:33	24	0	\N	\N
656046	COM_PERMANENTE	AUTRE	\N	FINC	\N	Contrôles budgétaires DGCCRF et Victimes Dépakine	Contrôles budgétaires DGCCRF et Victimes Dépakine	2022-09-28 09:30:00	2022-09-28 10:50:00	2022-09-28 11:22:43	2022-09-28 16:49:37	21	1	\N	\N
656052	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 27 septembre 2022	Audition de M. Philippe Leglise -Costa Représentant Permanent de la France auprès de l'Union européenne	2022-09-27 15:00:00	2022-09-27 16:42:00	2022-09-27 17:44:24	2022-09-28 16:49:35	14	0	\N	\N
656063	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2022-09-28 09:00:00	2022-09-28 11:05:00	2022-09-28 17:10:05	2022-09-29 14:40:59	20	0	\N	\N
740726	COM_SPECIALE	AUDRAP	\N	ESNU	\N	PJL Sécuriser et réguler l'espace numérique	PJL Sécuriser et réguler l'espace numérique	2023-06-14 17:30:00	2023-06-14 19:30:00	\N	\N	2	0	\N	\N
740785	COM_EURO	AUDRAP	\N	AFEU	\N	PPR gestion des déchets - Audition rapporteur - RP	PPR gestion des déchets - Audition rapporteur - RP	2023-06-06 17:15:00	2023-06-06 18:15:00	\N	\N	2	0	\N	\N
740788	COM_EURO	AUDRAP	\N	AFEU	\N	Gestion des déchets - Audition rapporteur - DGPR	Gestion des déchets - Audition rapporteur - DGPR	2023-06-07 16:30:00	2023-06-07 17:30:00	\N	\N	2	0	\N	\N
740793	COM_EURO	AUDRAP	\N	AFEU	\N	Réforme de l'électricité	Réforme de l'électricité	2023-05-23 10:00:00	2023-05-23 11:00:00	\N	\N	3	0	\N	\N
740794	COM_EURO	AUDRAP	\N	AFEU	\N	Réforme du marché de l'électricté	Réforme du marché de l'électricté	2023-05-23 16:00:00	2023-05-23 18:00:00	\N	\N	3	0	\N	\N
740804	COM_SPECIALE	PLENIERE	\N	ESNU	\N	Table ronde des opérateurs du numérique	Table ronde des opérateurs du numérique	2023-06-15 16:35:00	2023-06-15 18:45:00	2023-06-16 10:03:00	2023-06-16 15:26:11	7	0	\N	\N
740805	COM_SPECIALE	PLENIERE	\N	ESNU	\N	Audition de Lucas Verney, directeur adjoint du PEReN	Audition de Lucas Verney, directeur adjoint du PEReN	2023-06-13 15:45:00	2023-06-13 16:55:00	2023-06-14 15:25:50	2023-06-14 15:28:08	15	0	\N	\N
740806	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Verdissement des concours financiers - Audition I4CE	Contrôle 2023 - Verdissement des concours financiers - Audition Institute for climate economics (I4CE)	2023-06-07 14:00:00	2023-06-07 15:00:00	\N	\N	1	0	\N	\N
740809	COM_ENQUETE	PLENIERE	\N	MEDIC	\N	Réunion plénière	\N	2023-06-15 09:00:00	2023-06-15 11:40:00	2023-06-15 13:50:54	2023-06-15 20:06:06	5	0	\N	\N
740810	COM_ENQUETE	PLENIERE	\N	MEDIC	\N	Réunion plénière	\N	2023-06-15 13:40:00	2023-06-15 14:35:00	2023-06-15 14:37:02	2023-06-15 20:06:07	2	0	\N	\N
740817	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Application des lois Protection de l'enfance - Audition IRTS Parmentier/ENSEIS	\N	2023-06-06 14:10:00	2023-06-06 15:20:00	\N	\N	1	0	\N	\N
740818	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Données de santé - Table ronde d'industriels	\N	2023-06-06 14:00:00	2023-06-06 15:15:00	\N	\N	2	0	\N	\N
740819	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Données de santé - Table ronde d'assureurs	\N	2023-06-06 15:15:00	2023-06-06 16:15:00	\N	\N	2	0	\N	\N
745870	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	Groupe interparlementaire d'amitié France-Portugal	\N	2023-06-21 08:30:00	2023-06-21 09:30:00	\N	\N	3	0	\N	\N
749912	GIA	AUCUNE	\N	\N	\N	247e anniversaire de l'indépendance américaine	247e anniversaire de l'indépendance américaine	2023-07-05 18:00:00	2023-07-05 20:30:00	\N	\N	8	0	590	\N
751028	GIA	AUCUNE	\N	\N	\N	Entretien avec Nicolas Warnery, futur ambassadeur de France en Roumanie	\N	2023-07-12 14:00:00	2023-07-12 14:30:00	\N	\N	7	0	605	\N
751762	GIA	AUCUNE	\N	\N	\N	Déjeuner avec M. Tebogo SEOKOLO, ambassadeur d'Afrique du Sud en France	Déjeuner avec M. Tebogo SEOKOLO, ambassadeur d'Afrique du Sud en France	2023-06-27 12:35:00	2023-06-27 14:50:00	\N	\N	1	0	574	\N
751764	GIA	AUCUNE	\N	\N	\N	Entretien avec Mme Audrey ROJKOFF, directrice Afrique du Sud de l'AFD	Entretien avec Mme Audrey ROJKOFF, directrice Afrique du Sud de l'AFD	2023-07-05 17:15:00	2023-07-05 17:55:00	\N	\N	1	0	574	\N
751766	GIA	AUCUNE	\N	\N	\N	Entretien avec M. David MARTINON, ambassadeur de France en Afrique du Sud	Entretien avec M. David MARTINON, ambassadeur de France en Afrique du Sud	2023-07-12 11:00:00	2023-07-12 12:10:00	\N	\N	2	0	574	\N
752374	SEANCE_PLENIERE	OUV_SESSION	\N	\N	\N	Élection du Président du Sénat	Ouverture de session	2023-10-02 15:00:00	2023-10-02 17:30:00	\N	\N	338	0	\N	\N
752388	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Bruxelles - Commission européenne	Bruxelles - Commission européenne	2023-10-16 00:00:00	2023-10-16 02:00:00	\N	\N	2	0	\N	\N
752389	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-10-05 11:00:00	2023-10-05 11:40:00	2023-10-05 17:17:04	2023-10-05 17:17:16	48	0	\N	\N
752390	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-10-05 11:40:00	2023-10-05 12:30:00	\N	\N	49	0	\N	\N
752391	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-10-05 11:30:00	2023-10-05 13:05:00	\N	\N	0	0	\N	\N
752395	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition CGE FESIC	\N	2023-10-11 09:30:00	2023-10-11 11:10:00	2023-10-11 11:15:51	2023-10-11 18:17:02	37	7	\N	\N
752396	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition Attal	\N	2023-10-11 16:45:00	2023-10-11 19:45:00	2023-10-12 10:44:26	2023-10-12 18:13:01	32	0	\N	\N
752397	COM_PERMANENTE	AUTRE	\N	AFCL	\N	TR UNESCO	\N	2023-10-18 09:35:00	2023-10-18 11:30:00	2023-10-18 15:09:26	2023-10-18 18:17:07	33	0	\N	\N
752398	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition de Mme Amélie Oudéa-Castéra	\N	2023-10-25 16:45:00	2023-10-25 18:35:00	2023-10-25 18:44:36	2023-10-26 10:46:07	25	0	\N	\N
752405	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion de la CATDD	\N	2023-10-05 11:00:00	2023-10-05 12:15:00	\N	\N	0	0	\N	\N
760199	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2023-10-25 09:00:00	2023-10-25 10:00:00	2023-10-26 10:47:51	2023-10-26 11:07:00	42	0	\N	\N
762243	COM_PERMANENTE	AUTRE	\N	AFCL	\N	PLF 2024 - Audition de Mme Sylvie Retailleau	\N	2023-11-07 15:00:00	2023-11-07 17:05:00	2023-11-07 17:06:16	2023-11-07 17:14:41	26	0	\N	\N
762245	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition de l'AFP	\N	2023-11-14 17:00:00	2023-11-14 18:10:00	2023-11-15 09:03:57	2023-11-15 16:11:41	22	0	\N	\N
762246	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Examen d'avis budgétaires	\N	2023-11-16 10:30:00	2023-11-16 12:15:00	2023-11-16 12:31:36	2023-11-16 18:27:52	22	0	\N	\N
762247	COM_PERMANENTE	AUDRAP	\N	CAE	\N	FNPS	FNPS	2023-10-31 15:30:00	2023-10-31 16:15:00	\N	\N	1	0	\N	\N
762249	COM_PERMANENTE	AUDRAP	\N	CAE	\N	DGE	DGE	2023-10-31 16:15:00	2023-10-31 17:00:00	\N	\N	1	0	\N	\N
762251	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Arcep	Arcep	2023-10-31 17:00:00	2023-10-31 17:45:00	\N	\N	1	0	\N	\N
762277	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Agence nationale de la recherche	Audition Agence nationale de la recherche	2023-11-06 14:30:00	2023-11-06 15:15:00	\N	\N	1	0	\N	\N
762278	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Direction générale de la recherche et de l'innovation	Audition Direction générale de la recherche et de l'innovation	2023-11-06 15:15:00	2023-11-06 16:00:00	\N	\N	1	0	\N	\N
762279	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Institut national de la santé et de la recherche médicale	Audition Institut national de la santé et de la recherche médicale	2023-11-06 16:45:00	2023-11-06 17:30:00	\N	\N	1	0	\N	\N
762286	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Jeunes agriculteurs	\N	2023-11-07 09:00:00	2023-11-07 09:45:00	\N	\N	0	0	\N	\N
762287	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions MM. Duplomb, Menonville et Tissot	Auditions MM. Duplomb, Menonville et Tissot	2023-11-07 09:00:00	2023-11-07 09:45:00	\N	\N	2	0	\N	\N
762293	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF Ens. supérieur	\N	2023-11-07 09:45:00	2023-11-07 10:30:00	\N	\N	2	0	\N	\N
762505	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - AAFAR - Audition Confédération paysanne, Coordination rurale	PLF pour 2024 - AAFAR - Audition Mmes Le FLOC'H, COLAS et BOUTON de la Confédération paysanne et  Coordination rurale	2023-10-24 15:30:00	2023-10-24 16:30:00	\N	\N	2	0	\N	\N
762509	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - AAFAR - Audition secrétariat général du ministère Agriculture	PLF pour 2024 - AAFAR - Audition secrétariat général du ministère Agriculture et souveraineté alimentaire	2023-10-24 16:30:00	2023-10-24 17:45:00	\N	\N	2	0	\N	\N
762515	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - AAFAR - Table-ronde FNSEA/Jeunes agriculteurs	PLF pour 2024 - AAFAR - Table-ronde FNSEA/Jeunes agriculteurs	2023-10-24 19:00:00	2023-10-24 20:15:00	\N	\N	2	0	\N	\N
762521	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - AAFAR - Audition de la Cour des comptes	PLF pour 2024 - AAFAR - Audition de la Cour des comptes	2023-10-25 14:30:00	2023-10-25 15:15:00	\N	\N	2	0	\N	\N
762526	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2024 Solidarité - ADF	\N	2023-11-07 11:30:00	2023-11-07 12:05:00	\N	\N	5	0	\N	\N
762535	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2024 Solidarité - Cécile Tagliana	\N	2023-11-07 15:00:00	2023-11-07 16:00:00	\N	\N	2	0	\N	\N
762541	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - AAFAR - Audition de la DGAL et de la DGPE	PLF pour 2024 - AAFAR - Audition de la DG alimentation et de la DG Performance économique et environnementale des entr.	2023-10-25 16:30:00	2023-10-25 18:00:00	\N	\N	2	0	\N	\N
762546	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2024 Solidarité - IF-PJM	\N	2023-11-07 16:00:00	2023-11-07 17:00:00	\N	\N	1	0	\N	\N
762548	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - AAFAR - Audition des affaires budgétaires et comptables du MASA	PLF pour 2024 - AAFAR - Audition de la sous-direction des affaires budgétaires et comptables du MASA	2023-10-25 18:00:00	2023-10-25 18:45:00	\N	\N	2	0	\N	\N
640443	GIA	AUCUNE	\N	\N	\N	Réunion sur la protection du patrimoine arménien	Réunion sur la protection du patrimoine arménien avec les coordinateurs du projet de la ville de Bandol	2022-03-29 11:00:00	2022-03-29 12:40:00	\N	\N	3	0	641	\N
642450	COM_PERMANENTE	DEPLACEMENT	\N	CAE	\N	MCC sécurisation de la chasse	MCC sécurisation de la chasse	2022-05-04 07:30:00	2022-05-04 20:00:00	\N	\N	3	0	\N	\N
643753	COM_PERMANENTE	AUDRAP	\N	FINC	\N	MCC 2022 - Audiovisuel Public - TV5 Monde	MCC 2022 - Audiovisuel Public - TV5 Monde	2022-06-03 14:10:00	2022-06-03 14:55:00	\N	\N	2	0	\N	\N
643756	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI SPIP	MI SPIP - Auditions	2022-06-02 14:00:00	2022-06-02 16:20:00	\N	\N	2	0	\N	\N
647962	DELEGATION	AUCUNE	\N	\N	DSOM	Table ronde bassin Pacifique et audition sur les TAAF	\N	2022-07-21 08:00:00	2022-07-21 11:00:00	\N	\N	9	0	\N	\N
648009	DELEGATION	AUCUNE	\N	\N	211	Audition de Mme Isabelle Lonvis-Rome	\N	2022-07-27 16:30:00	2022-07-27 18:30:00	\N	\N	18	0	\N	\N
648010	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Intermarché	\N	2022-07-12 09:00:00	2022-07-12 10:15:00	\N	\N	0	0	\N	\N
648164	DELEGATION	AUCUNE	\N	\N	COLTER	Audition de M. Jean-Laurent CASSELY, co-auteur de "La France sous nos yeux"	\N	2022-07-12 16:45:00	2022-07-12 17:35:00	\N	\N	25	0	\N	\N
648189	DELEGATION	AUDRAP	\N	\N	206	Audition Mme Anastasia Ailamaki	\N	2022-07-11 14:00:00	2022-07-11 14:45:00	\N	\N	1	0	\N	\N
648193	DELEGATION	AUDRAP	\N	\N	206	Audition Mme Alizé Papp	\N	2022-07-11 14:45:00	2022-07-11 15:30:00	\N	\N	1	0	\N	\N
648195	DELEGATION	AUDRAP	\N	\N	206	Audition Mme Ioana Manolescu	\N	2022-07-11 15:30:00	2022-07-11 16:15:00	\N	\N	1	0	\N	\N
648197	DELEGATION	AUDRAP	\N	\N	206	Audition M. Michel Kalika	\N	2022-07-11 16:15:00	2022-07-11 17:00:00	\N	\N	1	0	\N	\N
648199	DELEGATION	AUDRAP	\N	\N	206	Audition DATAIKU	\N	2022-07-11 17:00:00	2022-07-11 17:50:00	\N	\N	1	0	\N	\N
649187	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	Audition MI Mégafeux	Audition MI Mégafeux	2022-07-12 16:30:00	2022-07-12 17:30:00	\N	\N	3	0	\N	\N
651528	BUREAU	AUCUNE	\N	\N	\N	\N	Bureau du Sénat	2022-07-21 08:30:00	2022-07-21 11:00:00	\N	\N	19	0	\N	\N
651548	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2022-07-19 18:00:00	2022-07-19 18:40:00	\N	\N	25	0	\N	\N
658004	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Convention d'entraide judiciaire avec Singapour	\N	2022-10-04 14:30:00	2022-10-04 15:45:00	\N	\N	1	0	\N	\N
659464	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Déplacement au centre prénitentiaire de Rennes	Déplacement au centre prénitentiaire de Rennes	2022-09-29 11:00:00	2022-09-29 20:30:00	\N	\N	4	0	\N	\N
659551	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Hendrik Wüst	Entretien avec M. Hendrik Wüst, ministre-président de Rhénanie du Nord-Westphalie	2022-10-05 14:15:00	2022-10-05 15:00:00	\N	\N	9	0	604	\N
667805	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - RES - CAB MIN ES	PLF pour 2023 - RES - CAB MIN ES	2022-10-27 15:30:00	2022-10-27 16:30:00	\N	\N	2	0	\N	\N
667808	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Recherche - INSERM/ANR	PLF pour 2023 - Recherche - INSERM/ANR	2022-10-27 16:30:00	2022-10-27 19:00:00	\N	\N	1	0	\N	\N
676624	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Mission Écologie, développement et mobilités durables	Mission Écologie, développement et mobilités durables	2022-12-02 15:10:00	2022-12-02 20:05:00	\N	\N	52	0	\N	\N
676910	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions de M. Laurent SOMON	\N	2022-11-16 14:00:00	2022-11-16 14:45:00	\N	\N	1	0	\N	\N
678420	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PLFSS pour 2023 - Nvelle lecture - Réunion plénière	\N	2022-11-29 09:30:00	2022-11-29 10:00:00	2022-11-29 10:28:02	2022-11-29 18:06:11	20	0	\N	\N
678421	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PLFSS pour 2023 - Nvelle lecture - Réunion plénière	\N	2022-11-29 15:30:00	2022-11-29 16:30:00	\N	\N	0	0	\N	\N
678423	DELEGATION	AUCUNE	\N	\N	PROS	Examen du rapport sur l'avenir de l'eau	\N	2022-11-24 08:30:00	2022-11-24 09:50:00	\N	\N	12	0	\N	\N
678745	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Équité territoriale face aux déserts médicaux - Table ronde internes et enseignants	\N	2022-11-22 17:00:00	2022-11-22 19:00:00	\N	\N	3	0	\N	\N
678748	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Équité territoriale face aux déserts médicaux - Audition du CNOM	\N	2022-11-22 14:00:00	2022-11-22 15:00:00	\N	\N	5	0	\N	\N
678756	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Équité territoriale face aux déserts médicaux - Audition de l'AMRF	\N	2022-11-22 16:00:00	2022-11-22 17:00:00	\N	\N	4	0	\N	\N
679201	COM_PERMANENTE	AUTRE	\N	AFCL	\N	PPL AESH	\N	2022-12-01 11:00:00	2022-12-01 12:10:00	2022-12-01 15:11:13	2022-12-01 18:08:18	18	1	\N	\N
679389	DELEGATION	AUDRAP	\N	\N	206	Audition de Mme Touvier	\N	2022-11-24 11:30:00	2022-11-24 12:15:00	\N	\N	1	0	\N	\N
679392	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2023 - Examen amdts du gouvernement art équilibre	PLF pour 2023 - Examen amdts du gouvernement art équilibre	2022-11-24 16:30:00	2022-11-24 16:55:00	2022-11-24 17:26:20	2022-11-24 19:01:12	33	0	\N	\N
679492	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition du DGA	\N	2022-11-30 09:30:00	2022-11-30 11:10:00	2022-11-30 16:59:22	2022-11-30 17:34:57	31	0	\N	\N
679535	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2023 - Examen Amdts séance sur les Missions	PLF pour 2023 - Examen Amdts séance sur les Missions	2022-11-28 09:15:00	2022-11-28 09:35:00	2022-11-28 09:50:28	2022-11-28 15:40:18	18	2	\N	\N
679539	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2023 - Examen Amdts séance sur les Missions	PLF pour 2023 - Examen Amdts séance sur les Missions	2022-12-01 09:30:00	2022-12-01 09:45:00	2022-12-01 10:00:16	2022-12-01 18:08:17	14	2	\N	\N
679540	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2023-Examen Amdts séance Mission «Ecologie, développement et mobilités durables»	PLF pour 2023 - Examen Amdts séance Mission «Ecologie, développement et mobilités durables»	2022-12-02 09:00:00	2022-12-02 09:45:00	2022-12-02 10:32:16	2022-12-02 15:44:50	12	2	\N	\N
680123	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - MI organisation de la police judiciaire	Audition rapporteur - MI organisation de la police judiciaire	2022-11-24 09:00:00	2022-11-24 11:30:00	\N	\N	2	0	\N	\N
680300	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe d'amitié France-Algérie	Assemblée générale du groupe d'amitié France-Algérie	2022-11-16 16:45:00	2022-11-16 17:20:00	\N	\N	4	0	575	\N
680305	GIA	AUCUNE	\N	\N	\N	Entetien avec des architectes de Mossoul	Entetien avec des architectes de Mossoul	2022-11-22 17:15:00	2022-11-22 18:30:00	\N	\N	2	0	615	\N
681338	GIA	AUCUNE	\N	\N	\N	Réunion du Bureau du groupe d'amitié 	Réunion du Bureau du groupe d'amitié 	2022-11-29 17:20:00	2022-11-29 18:05:00	\N	\N	5	0	573	\N
681432	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Mission Santé	Mission Santé	2022-11-29 21:35:00	2022-11-29 22:30:00	\N	\N	64	0	\N	\N
735408	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Boucliers tarifaires et amortisseurs - Audition M. LEGER, MEDEF	Contrôle 2023 - Boucliers tarifaires et amortisseurs - Audition M. LEGER, MEDEF	2023-05-22 10:00:00	2023-05-22 10:30:00	\N	\N	1	0	\N	\N
735411	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - RGA - Audition CESE	Contrôle 2022 - RGA - Audition CESE	2023-05-22 10:30:00	2023-05-22 11:00:00	\N	\N	1	0	\N	\N
735413	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Boucliers tarifaires et amortisseurs - Audition M. MICHEL, DGEC	Contrôle 2023 - Boucliers tarifaires et amortisseurs - Audition M. MICHEL, DGEC	2023-05-23 10:00:00	2023-05-23 11:15:00	\N	\N	1	0	\N	\N
735415	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL Ouverture mécénat aux SPL - Audition DGCL	PPL Ouverture mécénat aux SPL - Audition DGCL	2023-05-23 14:00:00	2023-05-23 14:45:00	\N	\N	1	0	\N	\N
735417	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Pass culture - Audition SAS Pass Culture	Contrôle 2023 - Pass culture - Audition SAS Pass Culture	2023-05-23 15:50:00	2023-05-23 17:05:00	\N	\N	2	0	\N	\N
735420	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition du Général Thierry Burkhard	Audition du Général Thierry Burkhard	2023-05-30 16:30:00	2023-05-30 18:35:00	2023-05-31 14:54:24	2023-06-02 16:09:48	29	0	\N	\N
735421	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Auditions de l'Amiral Pierre Vandier et du Général Pierre Schill	Audition de l'Amiral Pierre Vandier et du Général Pierre Schill	2023-05-31 09:30:00	2023-05-31 13:05:00	2023-05-31 14:56:37	2023-06-02 16:09:51	33	0	\N	\N
638515	DELEGATION	AUCUNE	\N	\N	206	Rapports Handicap et PNGMDR	\N	2022-03-03 09:40:00	2022-03-03 11:25:00	\N	\N	10	0	\N	\N
678422	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PPL Fraude au CPF - PPL Équité déserts médicaux - Réunion plénière	\N	2022-11-30 09:35:00	2022-11-30 11:40:00	2022-11-30 11:39:46	2022-11-30 17:34:56	37	0	\N	\N
679178	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Droits de l'enfant - Rapport et texte	PPL Droits de l'enfant - Rapport et texte	2022-11-30 09:00:00	2022-11-30 09:35:00	2022-11-30 10:52:41	2022-11-30 17:35:00	32	0	\N	\N
679179	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Déroulement des élections sénatoriales (LEC) - Rapport et texte	PPL Déroulement des élections sénatoriales (LEC) - Rapport et texte	2022-11-30 09:35:00	2022-11-30 10:25:00	\N	\N	38	0	\N	\N
679538	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2023 - Examen articles non rattachés et des Amdts séance sur les Missions et CMP	PLF pour 2023 - Examen articles non rattachés et des Amdts séance sur les Missions et designation CMP	2022-11-30 09:00:00	2022-11-30 09:55:00	2022-11-30 11:05:23	2022-11-30 17:35:00	38	1	\N	\N
735422	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition du Général Stéphane Mille	Audition du Général Stéphane Mille	2023-05-31 16:30:00	2023-05-31 18:05:00	2023-06-02 10:00:09	2023-06-02 16:09:55	20	0	\N	\N
735423	COM_PERMANENTE	AUDRAP	\N	CDD	\N	FO Syndicat national du personnel navigant commercial	FO Syndicat national du personnel navigant commercial	2023-05-25 11:00:00	2023-05-25 12:00:00	\N	\N	1	0	\N	\N
735429	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Table ronde ANI / partage de la valeur	Table ronde sur l'impact, pour les TPE et PME, de l'ANI sur le partage de la valeur	2023-05-25 09:00:00	2023-05-25 10:30:00	\N	\N	5	0	\N	\N
735476	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Compagnie nationale des commissaires enquêteur	Compagnie nationale des commissaires enquêteur	2023-05-22 09:00:00	2023-05-22 09:45:00	\N	\N	2	0	\N	\N
735479	COM_PERMANENTE	AUDRAP	\N	CDD	\N	DEB/DGALN	DEB/DGALN	2023-05-22 09:45:00	2023-05-22 11:15:00	\N	\N	2	0	\N	\N
735482	COM_PERMANENTE	AUDRAP	\N	CDD	\N	CNDP	CNDP	2023-05-22 11:15:00	2023-05-22 12:00:00	\N	\N	2	0	\N	\N
735485	COM_PERMANENTE	AUDRAP	\N	CDD	\N	DGPR	DGPR	2023-05-22 14:00:00	2023-05-22 14:45:00	\N	\N	1	0	\N	\N
735487	COM_PERMANENTE	AUDRAP	\N	CDD	\N	FNE	FNE	2023-05-22 14:45:00	2023-05-22 15:30:00	\N	\N	1	0	\N	\N
735489	COM_PERMANENTE	AUDRAP	\N	CDD	\N	SER	SER	2023-05-23 09:00:00	2023-05-23 09:45:00	\N	\N	1	0	\N	\N
735491	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Industrie verte	\N	2023-05-24 16:30:00	2023-05-24 18:30:00	\N	\N	1	0	\N	\N
735495	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Medef/CPME	Medef/CPME	2023-05-24 11:15:00	2023-05-24 12:00:00	\N	\N	1	0	\N	\N
735497	COM_PERMANENTE	AUDRAP	\N	CDD	\N	DAJ ministère de l'économie et des finances	DAJ ministère de l'économie et des finances	2023-05-24 16:30:00	2023-05-24 17:15:00	\N	\N	2	0	\N	\N
735501	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Union des groupements d'achats publics	Union des groupements d'achats publics	2023-05-24 17:15:00	2023-05-24 18:00:00	\N	\N	2	0	\N	\N
735504	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Commissariat général au développement durable	Commissariat général au développement durable	2023-05-24 18:00:00	2023-05-24 18:30:00	\N	\N	2	0	\N	\N
735507	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Mission nationale de mobilisation pour le foncier industriel	Mission nationale de mobilisation pour le foncier industriel	2023-05-24 19:15:00	2023-05-24 20:00:00	\N	\N	1	0	\N	\N
735510	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2023-05-31 09:00:00	2023-05-31 11:00:00	2023-05-31 12:19:02	2023-06-02 16:09:49	30	0	\N	\N
735511	ETUDES	AUTRE	\N	\N	\N	Réunion plénière	\N	2023-05-24 13:45:00	2023-05-24 15:00:00	\N	\N	3	0	\N	1004
735512	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL Audiovisuel public	Groupe ILIAD	2023-05-25 15:30:00	2023-05-25 16:30:00	\N	\N	3	0	\N	\N
735934	DELEGATION	AUTRE_NON_PLENIERE	\N	\N	206	Echanges avec des scientifiques sur leurs recomandations dans le cadre du traité internati	Echanges avec des scientifiques sur leurs recomandations dans le cadre du traité international visant à mettre un terme 	2023-05-31 18:45:00	2023-05-31 19:45:00	\N	\N	0	0	\N	\N
736304	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Conclusions CMP Influenceurs sur les réseaux sociaux	Conclusions CMP Influenceurs sur les réseaux sociaux	2023-06-01 14:30:00	2023-06-01 15:20:00	\N	\N	19	0	\N	\N
736593	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 39	\N	2023-05-31 09:00:00	2023-05-31 12:55:00	2023-06-07 10:53:24	2023-06-07 11:05:08	31	0	\N	\N
736608	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition FNSEA	\N	2023-05-31 10:15:00	2023-05-31 12:20:00	2023-05-31 14:29:26	2023-06-02 16:09:53	46	2	\N	\N
736674	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Transmanche - Table ronde des ferries corses	\N	2023-05-30 13:45:00	2023-05-30 14:30:00	\N	\N	1	0	\N	\N
736679	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Transmanche - Table ronde des administrations	\N	2023-05-30 16:00:00	2023-05-30 17:15:00	\N	\N	1	0	\N	\N
736680	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Transmanche - Audition d'Armateurs de France	\N	2023-05-30 17:15:00	2023-05-30 18:00:00	\N	\N	1	0	\N	\N
736738	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Stage au tribunal judiciaire de Montauban	\N	2023-06-01 08:00:00	2023-06-02 22:00:00	\N	\N	1	0	\N	\N
736739	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Stage au tribunal judiciaire de Grasse	Stage au tribunal judiciaire de Grasse	2023-06-01 08:00:00	2023-06-02 22:00:00	\N	\N	2	0	\N	\N
736780	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Service de santé des armées - Audition Agence régionale de santé IDF	Contrôle 2023 - Service de santé des armées - Audition Agence régionale de santé IDF	2023-05-10 14:00:00	2023-05-10 15:00:00	\N	\N	1	0	\N	\N
736784	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Service de santé des armées - Audition Institution nationale des invalides	Contrôle 2023 - Service de santé des armées - Audition Institution nationale des invalides (INI)	2023-05-10 16:15:00	2023-05-10 17:15:00	\N	\N	1	0	\N	\N
736786	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Service de santé des armées - Audition Service interarmées des munitions	Contrôle 2023 - Service de santé des armées - Audition Service interarmées des munitions (SIMu)	2023-05-10 17:15:00	2023-05-10 18:15:00	\N	\N	1	0	\N	\N
736798	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Service de santé des armées - Audition Etat-major de l'armée de Terre	Contrôle 2023 - Service de santé des armées - Audition Etat-major de l'armée de Terre	2023-05-23 14:30:00	2023-05-23 16:00:00	\N	\N	1	0	\N	\N
736800	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - PPL Revaloriser le métier de secrétaire de mairie	Audition rapporteur - PPL Revaloriser le métier de secrétaire de mairie	2023-05-30 15:45:00	2023-05-30 16:30:00	\N	\N	2	0	\N	\N
736808	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - PPL Revaloriser le métier de secrétaire de mairie	Audition rapporteur - PPL Revaloriser le métier de secrétaire de mairie	2023-05-24 18:45:00	2023-05-24 19:30:00	\N	\N	1	0	\N	\N
736843	ETUDES	AUTRE	\N	\N	\N	Batteries et électromobilité : table ronde	Batteries et électromobilité : table ronde	2023-05-31 08:15:00	2023-05-31 09:30:00	\N	\N	19	0	\N	906
736866	DELEGATION	AUCUNE	\N	\N	PROS	Examen du rapport sur l'exploitation des ressources spatiales	\N	2023-06-01 08:45:00	2023-06-01 09:40:00	\N	\N	8	0	\N	\N
736874	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Service de santé des armées - Audition Etat-major de la Marine	Contrôle 2023 - Service de santé des armées - Audition Etat-major de la Marine	2023-05-23 16:00:00	2023-05-23 17:00:00	\N	\N	1	0	\N	\N
736876	ETUDES	AUCUNE	\N	\N	\N	Audition de la Fedene sur l'impact de la directive "RED III"	Audition de la Fedene sur l'impact de la directive "RED III"	2023-05-31 08:00:00	2023-05-31 09:30:00	\N	\N	6	0	\N	948
736884	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Service de santé des armées - Audition Naval Group	Contrôle 2023 - Service de santé des armées - Audition Naval Group	2023-05-23 18:00:00	2023-05-23 19:00:00	\N	\N	1	0	\N	\N
736890	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Service de santé des armées - Audition Nexter	Contrôle 2023 - Service de santé des armées - Audition Nexter	2023-05-24 14:30:00	2023-05-24 15:30:00	\N	\N	1	0	\N	\N
638498	MISSION	AUDRAP	\N	SECUECO	\N	Audition Mme Vogel	\N	2022-03-07 10:00:00	2022-03-07 11:00:00	\N	\N	4	0	\N	\N
638526	COM_ENQUETE	PLENIERE	\N	MEDIA	\N	audition B. Le Maire	\N	2022-03-07 11:15:00	2022-03-07 12:35:00	2022-03-07 16:43:21	2022-03-08 18:20:05	12	0	\N	\N
643317	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI SPIP	MI SPIP - Auditions	2022-05-25 10:00:00	2022-05-25 12:10:00	\N	\N	2	0	\N	\N
643421	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT subsidiarité	Réunion du groupe de travail sur la subsidiarité	2022-05-31 15:20:00	2022-05-31 15:30:00	\N	\N	2	0	\N	\N
644107	QUESTURE	AUCUNE	\N	\N	\N	Réunion de Questure	Réunion de Questure	2022-06-08 09:00:00	2022-06-08 10:45:00	\N	\N	3	0	\N	\N
646266	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - ZAN - CPO	Contrôle 2022 - ZAN - CPO	2022-06-28 18:30:00	2022-06-28 19:30:00	\N	\N	2	0	\N	\N
646269	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - "Écologie" - PFA	PLF pour 2023 - "Écologie" - PFA	2022-06-28 15:30:00	2022-06-28 17:00:00	\N	\N	1	0	\N	\N
646277	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022- IGN - Syndicats IGN	Contrôle 2022- IGN - Syndicats IGN	2022-06-30 10:15:00	2022-06-30 12:00:00	\N	\N	1	0	\N	\N
646283	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - "Rapport général" - Intercommunalités de France	PLF pour 2023 - "Rapport général" - Intercommunalités de France	2022-06-29 16:00:00	2022-06-29 17:15:00	\N	\N	1	0	\N	\N
646287	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022- dotations d'investissement aux CT - TR Élus	Contrôle 2022- dotations d'investissement aux CT - TR Élus	2022-06-30 09:00:00	2022-06-30 10:30:00	\N	\N	2	0	\N	\N
646290	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2022 - SNU - Déplacement à Saint-Maurice-Saint-Germain	Contrôle 2022 - SNU - Déplacement à Saint-Maurice-Saint-Germain	2022-07-07 08:10:00	2022-07-07 17:40:00	\N	\N	1	0	\N	\N
646291	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2022 - SNU - Déplacement à Vaujours	Contrôle 2022 - SNU - Déplacement à Vaujours	2022-07-08 08:30:00	2022-07-08 17:00:00	\N	\N	1	0	\N	\N
646313	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2022 - DGCCRF - Déplacement à Cergy	Contrôle 2022 - DGCCRF - Déplacement à Cergy	2022-07-06 07:45:00	2022-07-06 14:30:00	\N	\N	1	0	\N	\N
646314	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion planière CATDD	\N	2022-07-13 09:30:00	2022-07-13 11:30:00	2022-07-13 15:40:04	2022-07-13 19:07:00	37	0	\N	\N
646321	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Régions de France	\N	2022-06-30 15:00:00	2022-06-30 16:00:00	\N	\N	0	0	\N	\N
646323	COM_PERMANENTE	AUDRAP	\N	FINC	\N	MI Fraude et évasion fiscales - Audition de M. Martin COLLET, professeur d'université 	MI Fraude et évasion fiscales - Audition de M. Martin COLLET, professeur d'université 	2022-07-05 16:35:00	2022-07-05 17:35:00	\N	\N	9	0	\N	\N
646324	COM_PERMANENTE	AUDRAP	\N	FINC	\N	MI Fraude et évasion fiscales - Audition des syndicats de la DGFiP	MI Fraude et évasion fiscales - Audition des syndicats de la DGFiP	2022-07-07 15:15:00	2022-07-07 16:35:00	\N	\N	10	0	\N	\N
649674	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI métropoles Lyon Aix-Marseille-Provence	MI métropoles Lyon Aix-Marseille-Provence	2022-07-19 14:00:00	2022-07-19 15:00:00	\N	\N	2	0	\N	\N
667745	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Cohésion des territoires - Logement-Urbanisme - ANAH	PLF pour 2023 - Cohésion des territoires - Logement-Urbanisme - ANAH	2022-10-27 09:15:00	2022-10-27 10:00:00	\N	\N	1	0	\N	\N
667747	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Cohésion des territoires - Logement-Urbanisme - DHUP/DIHAL/ALG	PLF pour 2023 - Cohésion des territoires - Logement-Urbanisme - DHUP/DIHAL/ALG	2022-10-27 16:00:00	2022-10-27 19:00:00	\N	\N	1	0	\N	\N
667749	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - APD - AFD/DG Trésor et DGM	PLF pour 2023 - APD - AFD/DG Trésor et DGM	2022-10-25 16:30:00	2022-10-25 18:30:00	\N	\N	2	0	\N	\N
667752	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - AEE - AEFE	PLF pour 2023 - AEE - AEFE	2022-10-27 16:00:00	2022-10-27 17:00:00	\N	\N	1	0	\N	\N
667754	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2022 - La DCPJ - Déplacement à Lyon	Contrôle 2022 - La DCPJ - Déplacement à Lyon	2022-10-28 07:30:00	2022-10-28 20:10:00	\N	\N	1	0	\N	\N
669070	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2023 Assurance maladie - Audition du SDA	\N	2022-10-31 15:00:00	2022-10-31 15:45:00	\N	\N	1	0	\N	\N
683979	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition de M. Cyril PELLEVAT	\N	2022-11-29 11:15:00	2022-11-29 16:00:00	\N	\N	1	0	\N	\N
684696	COM_PERMANENTE	DEPLACEMENT	\N	AFCL	\N	Déplacement au village des athlètes	\N	2022-11-30 08:00:00	2022-11-30 13:00:00	\N	\N	18	0	\N	\N
685289	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2022-12-01 10:10:00	2022-12-01 12:10:00	\N	\N	3	0	\N	\N
686720	GIA	AUCUNE	\N	\N	\N	Coopé - Entretien avec M. Didier KAMUNDU, député à l'Assemblée nationale de RDC	 Entretien avec M. Didier KAMUNDU, député à l'Assemblée nationale de RDC	2022-11-22 12:30:00	2022-11-22 14:00:00	\N	\N	1	0	588	\N
686722	GIA	AUCUNE	\N	\N	\N	Coopé - Visite de 12 staffers du Congrès des États-Unis d'Amérique 	Visite de 12 staffers du Congrès des États-Unis d'Amérique 	2022-10-27 13:00:00	2022-10-27 14:45:00	\N	\N	1	0	590	\N
686724	GIA	AUCUNE	\N	\N	\N	Coopé - Visite de Mme Alina-Stefania GORGHIU, Présidente par intérim du Sénat de Roumanie	Visite de Mme Alina-Stefania GORGHIU, Présidente par intérim du Sénat de Roumanie	2022-10-18 15:30:00	2022-10-18 16:30:00	\N	\N	1	0	605	\N
687018	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	AFCL	\N	audition Muratov	\N	2022-12-13 10:00:00	2022-12-13 11:00:00	\N	\N	4	0	\N	\N
690540	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - MI organisation de la police judiciaire	Audition rapporteur - MI organisation de la police judiciaire	2023-01-11 16:30:00	2023-01-11 17:30:00	\N	\N	2	0	\N	\N
690838	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJLFRSS pour 2023 - Audition de l'U2P	\N	2023-01-12 10:30:00	2023-01-12 11:15:00	\N	\N	5	0	\N	\N
690839	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJLFRSS pour 2023 - Audition de la CFDT	\N	2023-01-12 13:30:00	2023-01-12 14:15:00	\N	\N	3	0	\N	\N
690840	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJLFRSS pour 2023 - Audition de la CGT	\N	2023-01-12 14:15:00	2023-01-12 15:00:00	\N	\N	1	0	\N	\N
690841	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJLFRSS pour 2023 - Audition de la CFE-CGC	\N	2023-01-12 15:00:00	2023-01-12 15:45:00	\N	\N	1	0	\N	\N
692322	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de l'ambassadeur de France en Iran	\N	2023-01-25 08:30:00	2023-01-25 10:00:00	2023-01-25 15:43:00	2023-01-25 16:23:06	41	0	\N	\N
692324	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Examen RI Indopacifique	\N	2023-01-25 11:10:00	2023-01-25 12:15:00	2023-01-25 16:18:29	2023-01-25 16:22:47	37	3	\N	\N
693348	SEANCE_PLENIERE	SCRUSOL	1801	\N	\N	Scrutin solennel PJL Installations nucléaires	Scrutin solennel	2023-01-24 15:40:00	2023-01-24 15:45:00	\N	\N	0	0	\N	\N
694841	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Protéger les logements contre l'occupation illicite (amendements)	PPL Protéger les logements contre l'occupation illicite (amendements)	2023-01-31 14:00:00	2023-01-31 14:10:00	2023-01-31 15:54:20	2023-02-01 11:49:08	16	1	\N	\N
763382	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audition P844-847	\N	2023-10-26 16:15:00	2023-10-26 18:15:00	\N	\N	0	0	\N	\N
692323	COM_PERMANENTE	AUTRE	\N	ETRD	\N	PPL visant à réhabiliter les "fusillés pour l'exemple"	\N	2023-01-25 10:00:00	2023-01-25 11:10:00	2023-01-25 15:45:39	2023-01-25 16:22:53	43	3	\N	\N
694847	DELEGATION	AUCUNE	\N	\N	COLTER	Réunion plénière	\N	2023-01-26 09:00:00	2023-01-26 11:00:00	2023-01-26 11:01:53	\N	17	0	\N	\N
694876	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Auditions candidats Conseil supérieur de la magistrature	Auditions candidats Conseil supérieur de la magistrature	2023-02-01 09:30:00	2023-02-01 13:00:00	2023-02-02 15:55:21	2023-02-02 15:57:20	36	3	\N	\N
694877	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de Mattias Guyomar, juge à la Cour européenne des droits de l'homme	Audition de Mattias Guyomar, juge à la Cour européenne des droits de l'homme	2023-02-01 16:45:00	2023-02-01 17:50:00	2023-02-02 12:28:15	2023-02-02 15:51:43	24	0	\N	\N
743849	DELEGATION	AUCUNE	\N	\N	COLTER	Réunion plénière	\N	2023-06-15 09:00:00	2023-06-15 10:30:00	\N	\N	14	0	\N	\N
743873	DELEGATION	AUCUNE	\N	\N	COLTER	Réunion plénière	\N	2023-06-15 10:30:00	2023-06-15 11:30:00	\N	\N	14	0	\N	\N
743960	COM_SPECIALE	AUTRE	\N	ESNU	\N	PJL Espace numérique	\N	2023-06-20 14:30:00	2023-06-20 15:30:00	2023-06-20 16:07:14	2023-06-20 18:18:47	11	0	\N	\N
743969	COM_SPECIALE	PLENIERE	\N	ESNU	\N	PJL espace numérique	\N	2023-06-15 14:45:00	2023-06-15 16:15:00	2023-06-15 16:30:43	2023-06-15 20:06:08	10	0	\N	\N
743989	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-06-21 09:00:00	2023-06-21 11:30:00	2023-06-21 11:36:58	2023-06-21 14:42:39	40	0	\N	\N
743991	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-06-21 13:30:00	2023-06-21 14:55:00	2023-06-21 14:54:12	2023-06-21 18:12:35	25	0	\N	\N
743993	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Régime juridique des actions de groupe	PPL Régime juridique des actions de groupe	2023-06-15 09:35:00	2023-06-15 11:35:00	\N	\N	1	0	\N	\N
743994	COM_SPECIALE	AUDRAP	\N	ESNU	\N	Audition Rapporteur P. CHAIZE	\N	2023-06-15 09:00:00	2023-06-15 10:00:00	\N	\N	1	0	\N	\N
743996	COM_SPECIALE	AUDRAP	\N	ESNU	\N	Numeum	\N	2023-06-15 10:00:00	2023-06-15 10:45:00	\N	\N	2	0	\N	\N
743999	COM_SPECIALE	AUDRAP	\N	ESNU	\N	Audition rapporteur P. CHAIZE	\N	2023-06-15 10:45:00	2023-06-15 11:30:00	\N	\N	2	0	\N	\N
744002	COM_SPECIALE	AUDRAP	\N	ESNU	\N	Fédération du e-commerce et de la vente à distance	\N	2023-06-15 11:30:00	2023-06-15 12:15:00	\N	\N	2	0	\N	\N
744005	COM_SPECIALE	AUDRAP	\N	ESNU	\N	Autorité de la concurrence	\N	2023-06-15 12:15:00	2023-06-15 13:15:00	\N	\N	2	0	\N	\N
744045	COM_ENQUETE	PLENIERE	\N	MEDIC	\N	Réunion plénière	\N	2023-06-20 17:05:00	2023-06-20 18:20:00	2023-06-21 14:33:28	2023-06-21 14:43:18	7	0	\N	\N
753252	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion de la CATDD	Réunion constitutive et ordre du jour complémentaire	2023-10-05 10:30:00	2023-10-05 13:15:00	2023-10-06 17:00:10	2023-10-10 18:02:18	45	2	\N	\N
753253	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion constitutive	\N	2023-10-05 11:30:00	2023-10-05 12:00:00	2023-10-05 17:17:11	2023-10-05 17:17:16	48	0	\N	\N
753642	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Ouverture à la concurrence du réseau de bus francilien de la RATP - Audition DGITM	PPL Ouverture à la concurrence du réseau de bus francilien de la RATP - Audition DGITM	2023-10-05 15:15:00	2023-10-05 16:20:00	\N	\N	1	0	\N	\N
753645	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Sécurité des élus locaux et protection des maires (amendements)	PPL Sécurité des élus locaux et protection des maires (amendements)	2023-10-10 15:00:00	2023-10-10 15:10:00	2023-10-10 16:28:14	2023-10-10 18:01:56	31	0	\N	\N
753658	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Attribution des logements sociaux	PPL Attribution des logements sociaux	2023-10-10 16:10:00	2023-10-10 19:08:00	\N	\N	172	0	\N	\N
753659	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat sur l'accession à la propriété	Débat sur l'accession à la propriété	2023-10-10 14:30:00	2023-10-10 16:05:00	\N	\N	132	0	\N	\N
753660	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Sécurité des élus locaux et protection des maires 	PPL Sécurité des élus locaux et protection des maires 	2023-10-10 19:12:00	2023-10-10 20:00:00	\N	\N	68	0	\N	\N
753661	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Sécurité des élus locaux et protection des maires	PPL Sécurité des élus locaux et protection des maires	2023-10-10 21:30:00	2023-10-10 23:51:00	\N	\N	70	0	\N	\N
753662	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2023-10-11 15:00:00	2023-10-11 16:40:00	\N	\N	306	0	\N	\N
753664	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PJLO PJL Justice	CMP PJLO PJL Justice	2023-10-11 16:45:00	2023-10-11 18:00:00	\N	\N	58	0	\N	\N
753665	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Industrie verte	CMP Industrie verte	2023-10-11 18:00:00	2023-10-11 19:00:00	\N	\N	38	0	\N	\N
753666	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat relatif à l¿augmentation de la taxe foncière	Débat relatif à l¿augmentation de la taxe foncière	2023-10-11 19:00:00	2023-10-11 20:30:00	\N	\N	29	0	\N	\N
753667	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat préalable à la réunion du Conseil européen des 26 et 27 octobre 2023	Débat préalable à la réunion du Conseil européen des 26 et 27 octobre 2023	2023-10-11 22:00:00	2023-10-12 00:15:00	\N	\N	31	0	\N	\N
753668	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2023-10-12 10:30:00	2023-10-12 12:30:00	\N	\N	39	0	\N	\N
760780	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2023-10-26 09:30:00	2023-10-26 11:30:00	\N	\N	7	0	\N	\N
762675	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - AEE - Audition des responsables du programme	PLF pour 2024 - AEE - Audition des responsables du programme	2023-10-30 11:00:00	2023-10-30 12:00:00	\N	\N	2	0	\N	\N
763162	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur PLF pour 2024 - RCT	Audition rapporteur PLF pour 2024 - RCT	2023-11-07 15:00:00	2023-11-07 19:00:00	\N	\N	1	0	\N	\N
763253	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Fabien Genet	Auditions M. Fabien Genet	2023-11-07 15:15:00	2023-11-07 16:00:00	\N	\N	1	0	\N	\N
763298	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audtions M. Fabien Genet	Audtions M. Fabien Genet	2023-11-07 17:30:00	2023-11-07 19:00:00	\N	\N	1	0	\N	\N
763305	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 78	\N	2023-11-14 16:00:00	2023-11-14 19:00:00	\N	\N	29	8	\N	\N
763370	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF Presse	\N	2023-11-07 08:30:00	2023-11-07 09:30:00	\N	\N	1	0	\N	\N
763372	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	creation	\N	2023-11-07 14:00:00	2023-11-07 15:00:00	\N	\N	4	0	\N	\N
694875	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désignations - PPRE Frontex (rapport) - PPLC Droit IVG (amendements) - Communication CSM	Désignations - PPRE Frontex (rapport) - PPLC Droit IVG (amendements) - Communication CSM	2023-02-01 08:30:00	2023-02-01 09:20:00	2023-02-02 15:55:07	2023-02-02 15:57:22	40	5	\N	\N
743990	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-06-21 11:30:00	2023-06-21 11:40:00	2023-06-21 11:48:24	2023-06-21 14:42:40	33	0	\N	\N
763406	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2024 Anciens combattants - Table ronde d'associations	\N	2023-11-07 15:15:00	2023-11-07 16:45:00	\N	\N	2	0	\N	\N
763407	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2024 Anciens combattants - Audition de l'ONaCVG	\N	2023-11-07 18:00:00	2023-11-07 19:00:00	\N	\N	1	0	\N	\N
763512	GIA	AUCUNE	\N	\N	\N	Rencontre GRK	Rencontre avec M. Ali Dolamari, représentant en France du Gouvernement régional du Kurdistan	2023-11-08 17:00:00	2023-11-08 18:00:00	\N	\N	1	0	615	\N
764193	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF2024 - P129 - audition Jérôme Notin (cybermalveillance)	PLF2024 - P129 - audition Jérôme Notin (cybermalveillance)	2023-10-31 15:00:00	2023-10-31 15:45:00	\N	\N	1	0	\N	\N
764997	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Tables rondes "actualité des entreprises" + "défaillances d'entreprises"	\N	2023-11-09 08:00:00	2023-11-09 10:30:00	\N	\N	16	0	\N	\N
765038	DELEGATION	AUCUNE	\N	\N	206	Examen - note scientifique - conclusions d'une audition publique	\N	2023-11-09 09:35:00	2023-11-09 11:00:00	\N	\N	8	0	\N	\N
765102	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PLF 2024 - Industrie	Auditions PLF 2024 - Industrie	2023-11-09 08:30:00	2023-11-09 10:45:00	\N	\N	1	0	\N	\N
765163	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJLF 2024 - Enseignent agricole	\N	2023-11-09 11:00:00	2023-11-09 12:00:00	\N	\N	4	0	\N	\N
765174	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Données de connexion (rapport d'information)	Données de connexion (rapport d'information)	2023-11-15 10:55:00	2023-11-15 11:25:00	2023-11-16 16:43:22	2023-11-16 18:27:49	41	3	\N	\N
765176	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Agressions subies par les enseignants - Audition de Stanislas Guerini	Agressions subies par les enseignants - Audition de Stanislas Guerini	2023-11-15 16:30:00	2023-11-15 17:30:00	2023-11-15 19:09:25	2023-11-16 18:27:50	28	0	\N	\N
765177	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur -SGDSN	\N	2023-11-07 17:30:00	2023-11-07 18:40:00	\N	\N	1	0	\N	\N
765188	DELEGATION	AUCUNE	\N	\N	COLTER	Réunion plénière	\N	2023-11-16 08:15:00	2023-11-16 11:15:00	\N	\N	35	0	\N	\N
765219	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions ONF	Auditions ONF	2023-11-09 09:15:00	2023-11-09 10:00:00	\N	\N	1	0	\N	\N
765221	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Cerema	Cerema	2023-11-09 10:00:00	2023-11-09 10:45:00	\N	\N	1	0	\N	\N
639088	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Zidouh Président du groupe d'amitié Maroc France du Maroc	Entretien avec le président du groupe d'amitié Maroc France de la Chambre des conseillers du Maroc	2022-03-14 13:15:00	2022-03-14 14:45:00	\N	\N	1	0	598	\N
642501	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI sur la politique étrangère américaine	\N	2022-05-09 14:30:00	2022-05-09 15:30:00	\N	\N	3	0	\N	\N
642617	GIA	AUCUNE	\N	\N	\N	Remise du portrait de Desmond TUTU	Remise du portrait de Monseigneur Desmond TUTU par M. Jean-Loup OTHENIN-GIRARD à Mme la présidente Martine BERTHET	2022-05-11 11:00:00	2022-05-11 12:30:00	\N	\N	2	0	574	\N
644375	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MIC Delinquance des mineurs	MIC Délinquance des mineurs	2022-06-08 11:30:00	2022-06-08 12:45:00	\N	\N	3	0	\N	\N
644379	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MIC Delinquance des mineurs	MIC Délinquance des mineurs	2022-06-08 14:30:00	2022-06-08 19:00:00	\N	\N	4	0	\N	\N
644384	GIA	AUCUNE	\N	\N	\N	Accueil de la délégation MoNRE	\N	2022-05-31 11:00:00	2022-05-31 15:30:00	\N	\N	7	0	626	\N
644392	GIA	AUCUNE	\N	\N	\N	Déjeuner à l'ambassade	\N	2022-06-07 12:30:00	2022-06-07 14:30:00	\N	\N	7	0	626	\N
644738	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL Commission océan Indien	\N	2022-06-14 15:00:00	2022-06-14 16:45:00	\N	\N	1	0	\N	\N
645508	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MIC Delinquance des mineurs	MIC Délinquance des mineurs	2022-06-22 14:30:00	2022-06-22 16:30:00	\N	\N	3	0	\N	\N
651397	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions M. Daniel Grémillet	Auditions M. Daniel Grémillet	2022-07-20 16:00:00	2022-07-20 17:30:00	\N	\N	1	0	\N	\N
651403	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière	Réunion plénière	2022-07-21 10:30:00	2022-07-21 12:15:00	\N	\N	14	0	\N	\N
651421	DELEGATION	AUDRAP	\N	\N	206	Audition Etalab	\N	2022-07-21 10:10:00	2022-07-21 10:50:00	\N	\N	1	0	\N	\N
651442	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Bruno Belin	Auditions M. Bruno Belin	2022-07-20 17:30:00	2022-07-20 19:30:00	\N	\N	1	0	\N	\N
651444	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Bruno Belin	Auditions M. Bruno Belin	2022-07-21 08:30:00	2022-07-21 11:00:00	\N	\N	1	0	\N	\N
651445	ETUDES	AUTRE	\N	\N	\N	Audition Inaporc	\N	2022-07-20 13:30:00	2022-07-20 14:50:00	\N	\N	6	0	\N	911
651461	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL pouvoir d'achat - CPME	PJL pouvoir d'achat - CPME	2022-07-19 18:30:00	2022-07-19 19:15:00	\N	\N	2	0	\N	\N
651464	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - RGA - France Assureurs	Contrôle 2022 - RGA - France Assureurs	2022-07-18 09:30:00	2022-07-18 10:30:00	\N	\N	1	0	\N	\N
651466	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 2022 - Adaptation réacteurs nucléaires changement climatique - Cour des comptes	58-2 2022 - Adaptation réacteurs nucléaires changement climatique - Cour des comptes	2022-07-18 10:45:00	2022-07-18 11:45:00	\N	\N	1	0	\N	\N
651468	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL pouvoir d'achat - DGEC	PJL pouvoir d'achat - DGEC	2022-07-18 13:30:00	2022-07-18 14:30:00	\N	\N	2	0	\N	\N
651471	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL pouvoir d'achat - PDG CMA CGM	PJL pouvoir d'achat - PDG CMA CGM	2022-07-20 12:40:00	2022-07-20 13:00:00	\N	\N	2	0	\N	\N
651492	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL pouvoir d"achat - Ambassadeurs intéressement participation auprès du Gouvernement	PJL pouvoir d"achat - Ambassadeurs intéressement participation auprès du Gouvernement	2022-07-19 19:40:00	2022-07-19 20:40:00	\N	\N	2	0	\N	\N
651495	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL pouvoir d'achat - Ministère du Travail	PJL pouvoir d'achat - Ministère du Travail	2022-07-20 13:45:00	2022-07-20 14:30:00	\N	\N	2	0	\N	\N
651525	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL pouvoir d'achat - Engie	PJL pouvoir d'achat - Engie	2022-07-20 13:00:00	2022-07-20 13:30:00	\N	\N	2	0	\N	\N
651574	COM_PERMANENTE	AUTRE	\N	LOIS	\N	MI Avenir institutionnel de la Nouvelle-Calédonie - Examen du rapport d'étape	MI Avenir institutionnel de la Nouvelle-Calédonie - Examen du rapport d'étape	2022-07-27 09:00:00	2022-07-27 10:30:00	2022-07-27 10:33:34	2022-07-27 18:10:33	31	2	\N	\N
667614	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2022-10-20 08:35:00	2022-10-20 10:12:00	\N	\N	3	0	\N	\N
668342	ETUDES	AUCUNE	\N	\N	\N	Audition de M. Prioux, président de la Société de Vènerie	Audition de M. Prioux, président de la Société de Vènerie	2022-11-02 13:30:00	2022-11-02 14:00:00	\N	\N	8	0	\N	907
676237	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - MI organisation de la police judiciaire	\N	2022-11-15 09:00:00	2022-11-15 10:00:00	\N	\N	3	0	\N	\N
676243	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions rapporteur - MI organisation de la police judiciaire	Auditions rapporteur - MI organisation de la police judiciaire	2022-11-15 10:00:00	2022-11-15 12:00:00	\N	\N	2	0	\N	\N
765175	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPLC RIP -  PPL Personnes condamnées pour homosexualité (rapports)	PPLC RIP -  PPL Personnes condamnées pour homosexualité (rapports)	2023-11-15 09:00:00	2023-11-15 10:55:00	2023-11-15 19:07:04	2023-11-16 18:27:54	41	3	\N	\N
676249	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - MI organisation de la police judiciaire	Audition rapporteur - MI organisation de la police judiciaire	2022-11-15 15:45:00	2022-11-15 16:45:00	\N	\N	3	0	\N	\N
676254	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions rapporteur - MI organisation de la police judiciaire	Auditions rapporteur - MI organisation de la police judiciaire	2022-11-15 16:45:00	2022-11-15 18:45:00	\N	\N	2	0	\N	\N
676259	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - MI organisation de la police judiciaire	Audition rapporteur - MI organisation de la police judiciaire	2022-11-16 14:00:00	2022-11-16 15:15:00	\N	\N	3	0	\N	\N
681950	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Adaptation au droit de l'Union européenne	diverses dispositions d'adaptation au droit de l'Union européenne dans les domaines de l'économie, de la santé, du trava	2022-11-29 15:00:00	2022-11-29 18:40:00	\N	\N	1	0	\N	\N
682962	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition général Bruno Clermont - communication déplacement ONU	Audition général Bruno Clermont - communication déplacement ONU	2022-12-07 09:30:00	2022-12-07 11:30:00	2022-12-07 12:21:00	2022-12-08 12:00:21	28	4	\N	\N
683466	GIA	AUCUNE	\N	\N	\N	Entretien avec Mr Alexandre LEVY, directeur du LIFT	Entretien avec Mr Alexandre LEVY, directeur du LIFT	2022-06-29 12:30:00	2022-06-29 14:00:00	\N	\N	2	0	623	\N
683635	DELEGATION	AUDRAP	\N	\N	206	Audition de la Direction centrale de la sécurité publique	\N	2022-12-02 11:00:00	2022-12-02 12:00:00	\N	\N	1	0	\N	\N
683640	COM_PERMANENTE	AUTRE	\N	CAE	\N	PJL DDADUE	\N	2022-12-06 18:00:00	2022-12-06 18:45:00	2022-12-07 09:49:38	2022-12-08 12:00:20	31	1	\N	\N
683642	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition ANAH	\N	2022-12-07 09:35:00	2022-12-07 11:30:00	2022-12-07 12:04:24	2022-12-08 12:00:22	45	0	\N	\N
683655	DELEGATION	AUCUNE	\N	\N	211	Table ronde sur le thème " Santé des femmes et travail "	Table ronde sur le thème « Santé des femmes et travail : une approche historique et sociologique »	2022-12-08 08:30:00	2022-12-08 10:30:00	2022-12-08 10:52:59	\N	8	0	\N	\N
686707	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 14 décembre 2022	\N	2022-12-14 14:00:00	2022-12-14 15:00:00	2023-01-09 23:08:05	2023-01-10 14:56:30	31	0	\N	\N
686708	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 15 décembre 2022	\N	2022-12-15 08:30:00	2022-12-15 10:25:00	2022-12-15 10:41:25	2022-12-15 15:08:04	13	0	\N	\N
686709	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	audition	\N	2022-12-08 14:00:00	2022-12-08 15:00:00	\N	\N	7	0	\N	\N
686746	GIA	AUCUNE	\N	\N	\N	Coopé - Accueil d'une délégation de la Cour des Comptes du Kenya	Accueil d'une délégation de la Cour des Comptes du Kenya	2022-12-12 11:00:00	2022-12-12 12:00:00	\N	\N	1	0	622	\N
688265	GIA	AUCUNE	\N	\N	\N	Entretien avec l'Ambassadeur de Cuba	Entrettien avec l'Ambassadeur de Cuba en France	2022-12-13 15:00:00	2022-12-13 16:00:00	\N	\N	4	0	642	\N
688422	QUESTURE	AUCUNE	\N	\N	\N	Réunion de Questure	Réunion de Questure	2022-12-08 09:00:00	2022-12-08 10:45:00	\N	\N	3	0	\N	\N
688465	GIA	AUCUNE	\N	\N	\N	Coopé - Visite de M. Luis Donaldo COLOSIO, Maire de la ville de Monterrey au Mexique	Visite de M. Luis Donaldo COLOSIO, Maire de la ville de Monterrey au Mexique	2022-12-14 12:30:00	2022-12-14 15:00:00	\N	\N	2	0	643	\N
688571	GIA	AUCUNE	\N	\N	\N	Déplacement d'une délégation	Déplacement d'une délégation en Papouasie-Nouvelle-Guinée et au Vanuatu	2022-09-12 11:00:00	2022-09-21 15:00:00	\N	\N	3	0	651	\N
688710	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure du 13 décembre 2022	Conseil de Questure du 13 décembre 2022	2022-12-13 16:00:00	2022-12-13 17:30:00	\N	\N	0	0	\N	\N
688826	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Jeux Olympiques et Paralympiques de 2024	PJL Jeux Olympiques et Paralympiques de 2024	2023-01-05 11:30:00	2023-01-05 12:10:00	\N	\N	4	0	\N	\N
688831	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Jeux Olympiques et Paralympiques de 2024	PJL Jeux Olympiques et Paralympiques de 2024	2023-01-05 16:00:00	2023-01-05 17:10:00	\N	\N	5	0	\N	\N
736897	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Service de santé des armées - Audition Dassault Aviation	Contrôle 2023 - Service de santé des armées - Audition Dassault Aviation	2023-05-25 09:30:00	2023-05-25 10:30:00	\N	\N	1	0	\N	\N
736899	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Service de santé des armées - Audition Etat-major des armées	Contrôle 2023 - Service de santé des armées - Audition Etat-major des armées	2023-05-25 13:45:00	2023-05-25 14:45:00	\N	\N	1	0	\N	\N
736901	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Programmation militaire 2024/2030 - Audition Etat-major de l'arméée de l'Air	PJL Programmation militaire 2024/2030 - Audition Etat-major de l'arméée de l'Air	2023-05-25 15:45:00	2023-05-25 16:45:00	\N	\N	1	0	\N	\N
736903	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Pass Culture - Audition Direction générale à l'enseignement supérieur	Contrôle 2023 - Pass Culture - Audition Direction générale à l'enseignement supérieur	2023-05-30 15:30:00	2023-05-30 17:30:00	\N	\N	2	0	\N	\N
736989	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2023-05-30 16:30:00	2023-05-30 19:00:00	\N	\N	1	0	\N	\N
737030	DELEGATION	AUCUNE	\N	\N	211	Audition Parentalité outre-mer (administrations d'Etat)	\N	2023-06-08 08:30:00	2023-06-08 10:00:00	\N	\N	6	0	\N	\N
737121	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Antilles	MI Antilles	2023-05-30 16:45:00	2023-05-30 19:00:00	\N	\N	3	0	\N	\N
737337	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Auditions ¨P. 146	Auditions P. 146	2023-05-31 14:00:00	2023-05-31 15:00:00	\N	\N	2	0	\N	\N
737341	MISSION	AUCUNE	\N	GEAU	\N	Audition plénière	\N	2023-05-31 14:00:00	2023-05-31 15:00:00	2023-05-31 16:15:16	2023-06-02 16:10:40	4	0	\N	\N
737710	MISSION	AUDRAP	\N	GEAU	\N	Audition rapporteur	\N	2023-05-31 16:30:00	2023-05-31 17:30:00	\N	\N	3	0	\N	\N
737720	COM_ENQUETE	PLENIERE	\N	MEDIC	\N	Audition plénière	\N	2023-05-31 17:00:00	2023-05-31 19:00:00	2023-05-31 19:30:07	2023-06-02 16:10:41	7	0	\N	\N
737724	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition plénière	\N	2023-06-06 17:05:00	2023-06-06 18:15:00	2023-06-06 18:20:58	2023-06-07 10:34:00	21	0	\N	\N
737731	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition plénière	\N	2023-06-07 09:35:00	2023-06-07 11:10:00	2023-06-07 13:34:53	2023-06-07 17:26:44	39	1	\N	\N
737734	ETUDES	AUTRE	\N	\N	\N	Audition de M. Jean-Christophe Combe	\N	2023-05-31 14:00:00	2023-05-31 15:00:00	\N	\N	19	0	\N	1014
737785	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition Bruno Le Maire et Roland Lescure	\N	2023-05-31 18:00:00	2023-05-31 19:45:00	2023-05-31 20:02:31	2023-06-02 16:09:55	56	0	\N	\N
737800	MISSION	AUCUNE	\N	BIOCARBU	\N	PLENIERE - 21 - GIFAS	\N	2023-05-31 17:45:00	2023-05-31 19:00:00	2023-06-01 11:06:47	2023-06-02 16:10:41	6	0	\N	\N
737972	DELEGATION	AUCUNE	\N	\N	COLTER	Examen du rapport relatif à l'emploi de secrétaire de mairie	\N	2023-06-01 09:00:00	2023-06-01 10:30:00	2023-06-02 15:39:09	\N	7	0	\N	\N
738015	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Orientation et programmation du ministère de la justice 2023-2027 (amendements)	PJL Orientation et programmation du ministère de la justice 2023-2027 (amendements)	2023-06-06 13:30:00	2023-06-06 14:10:00	2023-06-06 16:29:41	2023-06-07 10:34:00	17	1	\N	\N
761753	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur	\N	2023-10-23 16:25:00	2023-10-23 17:10:00	\N	\N	0	0	\N	\N
738020	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL honorabilité	\N	2023-05-31 16:30:00	2023-05-31 19:00:00	\N	\N	1	0	\N	\N
738022	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL cinema outre mer	\N	2023-05-31 14:15:00	2023-05-31 15:30:00	\N	\N	1	0	\N	\N
738023	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	cine OM	\N	2023-05-31 16:30:00	2023-05-31 18:00:00	\N	\N	1	0	\N	\N
738024	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI autonomie	\N	2023-05-31 13:45:00	2023-05-31 14:45:00	\N	\N	4	0	\N	\N
738045	MISSION	AUTRE	\N	BIOCARBU	\N	PLENIERE - 22 - Marc Fesneau	\N	2023-06-01 10:45:00	2023-06-01 11:45:00	2023-06-07 11:02:19	2023-06-07 11:05:21	9	0	\N	\N
738084	DELEGATION	AUDRAP	\N	\N	206	Audition Réforme sûreté nucléaire	\N	2023-05-30 15:00:00	2023-05-30 19:00:00	\N	\N	2	0	\N	\N
738098	DELEGATION	AUDRAP	\N	\N	PROS	Audition Cédric O	\N	2023-05-31 16:30:00	2023-05-31 17:30:00	\N	\N	2	0	\N	\N
738102	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Transmanche - Table ronde des armateurs 	\N	2023-05-31 17:00:00	2023-05-31 18:00:00	\N	\N	2	0	\N	\N
738103	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Transmanche - Audition Pr Chaumette	\N	2023-05-31 11:30:00	2023-05-31 12:15:00	\N	\N	1	0	\N	\N
738104	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Transmanche - Audition d'Irish Ferries	\N	2023-05-31 18:00:00	2023-05-31 18:45:00	\N	\N	2	0	\N	\N
738111	MISSION	AUDRAP	\N	AVENCOMM	\N	Maire de Loubeyrat	\N	2023-06-01 10:00:00	2023-06-01 10:30:00	\N	\N	1	0	\N	\N
738112	MISSION	AUDRAP	\N	AVENCOMM	\N	Maire de Nevoy et président de la communauté de communes giennoises	Maire de Nevoy et président de la communauté de communes giennoises	2023-06-01 10:35:00	2023-06-01 11:20:00	\N	\N	2	0	\N	\N
738113	MISSION	AUDRAP	\N	AVENCOMM	\N	Maires de Vinzieux et Gundershoffen	Maires de Vinzieux et Gundershoffen	2023-06-01 11:20:00	2023-06-01 12:25:00	\N	\N	1	0	\N	\N
738127	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Transmanche - Audition de P&O Ferries	\N	2023-05-31 19:00:00	2023-05-31 19:20:00	\N	\N	2	0	\N	\N
738189	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Audition ministre	Audition de Mme Olivia GRÉGOIRE, Ministre déléguée chargée des Petites et Moyennes Entreprises, du Commerce	2023-06-08 08:45:00	2023-06-08 10:20:00	2023-06-01 16:09:17	\N	7	0	\N	\N
738216	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 8 juin 2023	\N	2023-06-08 09:00:00	2023-06-08 10:40:00	2023-06-08 11:32:48	2023-06-08 16:37:11	10	0	\N	\N
738242	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL honorabilité	\N	2023-06-01 09:00:00	2023-06-01 11:00:00	\N	\N	1	0	\N	\N
738243	COM_PERMANENTE	AUDRAP	\N	CDD	\N	TR Federec/FNADE/Séché	TR Federec/FNADE/Séché	2023-05-25 10:00:00	2023-05-25 11:00:00	\N	\N	1	0	\N	\N
738246	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Chantal Jouanno	Chantal Jouanno	2023-05-25 11:45:00	2023-05-25 12:30:00	\N	\N	1	0	\N	\N
738249	COM_PERMANENTE	AUDRAP	\N	CDD	\N	France Industrie	France Industrie	2023-05-25 16:00:00	2023-05-25 16:45:00	\N	\N	1	0	\N	\N
738252	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Intercommunalités de France	Intercommunalités de France	2023-05-25 16:45:00	2023-05-25 17:30:00	\N	\N	1	0	\N	\N
738257	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Restes humains	\N	2023-05-31 17:45:00	2023-05-31 19:00:00	\N	\N	1	0	\N	\N
738260	DELEGATION	AUTRE	\N	\N	DSOM	Parentalité outre-mer : audition des administrations centrales et Cnaf	\N	2023-06-08 08:30:00	2023-06-08 10:30:00	\N	\N	6	0	\N	\N
738264	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Modernisation DSNA - Audition SPAC-CFDT	Contrôle 2023 - Modernisation DSNA - Audition SPAC-CFDT	2023-05-30 14:15:00	2023-05-30 15:15:00	\N	\N	1	0	\N	\N
738266	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Modernisation DSNA - Audition DGAC et DSNA	Contrôle 2023 - Modernisation DSNA - Audition DGAC et DSNA	2023-06-01 16:15:00	2023-06-01 17:15:00	\N	\N	1	0	\N	\N
738268	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF Industrie verte - Audition Autorité de contrôle prudentiel et de résolution(ACPR)	PLF Industrie verte - Audition Autorité de contrôle prudentiel et de résolution(ACPR)	2023-05-31 19:50:00	2023-05-31 20:40:00	\N	\N	1	0	\N	\N
738270	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Verdissement concours financiers - Audition SGPE	Contrôle 2023 - Verdissement concours financiers - Audition SGPE	2023-06-01 09:40:00	2023-06-01 11:00:00	\N	\N	1	0	\N	\N
738272	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Données de santé - Audition de Santé publique France	\N	2023-05-30 16:30:00	2023-05-30 17:45:00	\N	\N	4	0	\N	\N
738273	MECSS	AUDRAP	\N	\N	MECSS	Mecss - MI Organismes financés par les Robss - Audition ANSM	\N	2023-06-01 17:00:00	2023-06-01 18:00:00	\N	\N	2	0	\N	\N
738276	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Pass Culture - Audition DGES	Contrôle 2023 - Pass Culture - Audition DGES	2023-05-30 16:00:00	2023-05-30 17:00:00	\N	\N	2	0	\N	\N
738279	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL Ouverture mécénat aux SPL - Audition Direction de la législation fiscale (DLF)	PPL Ouverture mécénat aux SPL - Audition Direction de la législation fiscale (DLF)	2023-05-31 16:25:00	2023-05-31 17:00:00	\N	\N	1	0	\N	\N
738281	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL Ouverture mécénat aux SPL - Audition FedEpl	PPL Ouverture mécénat aux SPL - Audition Fédération des élus des entreprises publiques locales (FedEpl)	2023-05-31 17:20:00	2023-05-31 18:00:00	\N	\N	1	0	\N	\N
738283	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 203 - Formation continue enseignants - Audition Ministre de l'éducation nationale	Contrôle 203 - Formation continue enseignants - Audition Pap NDIAYE, ministre de l'éducation nationale	2023-05-30 17:30:00	2023-05-30 18:50:00	\N	\N	1	0	\N	\N
638803	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	entretien avec l'ambassadrice de Bosnie Herzégovine	entretien avec l'ambassadrice de Bosnie Herzégovine	2022-03-08 10:30:00	2022-03-08 11:30:00	\N	\N	0	0	\N	\N
638804	GIA	AUCUNE	\N	\N	\N	entretien avec l'ambassadrice de Bosnie Herzégovine	entretien avec l'ambassadrice de Bosnie Herzégovine	2022-03-08 10:30:00	2022-03-08 11:30:00	\N	\N	2	0	674	\N
640928	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe d'information internationale sur le Haut-Karabagh	Audition du représentant du Haut-Karabagh en France	2022-04-06 15:00:00	2022-04-06 16:15:00	\N	\N	17	0	1013	\N
641748	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	MCC 2022 - Audiovisuel Public - ARCOM/DGMIC	\N	2022-04-21 11:00:00	2022-04-21 13:10:00	\N	\N	0	0	\N	\N
641752	COM_EURO	AUDRAP	\N	AFEU	\N	Audition intelligence artificielle	Audition intelligence artificielle	2022-04-21 11:00:00	2022-04-21 12:00:00	\N	\N	2	0	\N	\N
641755	COM_EURO	AUDRAP	\N	AFEU	\N	Audition intelligence artificielle	Audition intelligence artificielle	2022-04-21 15:15:00	2022-04-21 16:15:00	\N	\N	2	0	\N	\N
641756	COM_EURO	AUDRAP	\N	AFEU	\N	Audition intelligence artificielle	Audition intelligence artificielle	2022-04-21 16:15:00	2022-04-21 17:15:00	\N	\N	2	0	\N	\N
643749	COM_PERMANENTE	AUDRAP	\N	FINC	\N	MCC 2022 - Audiovisuel Public - France Médias monde	MCC 2022 - Audiovisuel Public - France Médias monde	2022-06-03 10:30:00	2022-06-03 11:40:00	\N	\N	2	0	\N	\N
644644	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2022-06-08 09:00:00	2022-06-08 10:36:00	\N	\N	3	0	\N	\N
654299	COM_PERMANENTE	AUTRE	\N	CAE	\N	Table ronde mégafeux	\N	2022-08-03 11:10:00	2022-08-03 12:45:00	2022-08-03 16:22:48	2022-08-03 18:56:34	54	1	\N	\N
654300	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition article 13 CRE	\N	2022-08-03 09:00:00	2022-08-03 10:45:00	2022-08-03 12:56:03	2022-08-03 18:56:33	37	2	\N	\N
654301	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition article 13 CRE	\N	2022-08-03 09:00:00	2022-08-03 11:00:00	\N	\N	0	0	\N	\N
655185	GIA	AUCUNE	\N	\N	\N	Visite de M. Nyam-Osor UCHRAL, député du Grand Khoural	Visite de M. Nyam-Osor UCHRAL, député du Grand Khoural	2022-08-05 11:00:00	2022-08-05 12:30:00	\N	\N	1	0	612	\N
655187	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Didier BOISSIERE, président de Think Capital Mongolia LLC	Entretien avec M. Didier BOISSIERE, président de Think Capital Mongolia LLC	2022-08-03 14:00:00	2022-08-03 14:45:00	\N	\N	2	0	612	\N
655190	GIA	AUCUNE	\N	\N	\N	Entretien avec M. John Bel Edwards Gouverneur de Louisiane 	Entretien avec M. John Bel Edwards Gouverneur de Louisiane 	2022-08-09 17:30:00	2022-08-09 19:30:00	\N	\N	3	0	590	\N
668904	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition PLF 2023 - Transports aériens	Audition PLF 2023 - Transports aériens	2022-10-25 09:00:00	2022-10-25 10:30:00	\N	\N	3	0	\N	\N
668908	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition Groupe Air France-KLM	Audition Groupe Air France-KLM	2022-10-25 15:15:00	2022-10-25 16:00:00	\N	\N	2	0	\N	\N
668911	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition de l'Autorité de contrôle des nuisances aéroportuaires	Audition de l'Autorité de contrôle des nuisances aéroportuaires	2022-10-25 16:00:00	2022-10-25 16:45:00	\N	\N	1	0	\N	\N
668913	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PLF 2023 - Transports aériens - Audition  de Réseau action climat	PLF 2023 - Transports aériens - Audition  de Réseau action climat	2022-10-26 08:45:00	2022-10-26 09:30:00	\N	\N	2	0	\N	\N
668917	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PLFSS pour 2023 - Réunion plénière 	\N	2022-11-07 13:35:00	2022-11-07 15:45:00	2022-11-07 15:46:44	2022-11-07 16:19:29	35	0	\N	\N
668918	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PLFSS pour 2023 - Réunion plénière	\N	2022-11-07 19:35:00	2022-11-07 20:35:00	2022-11-07 20:39:50	2022-11-08 17:26:34	34	0	\N	\N
668919	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PLFSS pour 2023 - Réunion plénière	\N	2022-11-08 13:30:00	2022-11-08 14:10:00	2022-11-08 14:52:23	2022-11-08 17:26:34	23	0	\N	\N
668920	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PLFSS pour 2023 - Réunion plénière	\N	2022-11-08 19:30:00	2022-11-08 21:30:00	\N	\N	0	0	\N	\N
673349	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition M. Béchu	\N	2022-11-16 16:30:00	2022-11-16 18:20:00	2022-11-16 18:22:52	2022-11-18 11:44:52	34	0	\N	\N
676412	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF 2023 - programme 146	PLF 2023 - programme 146	2022-11-08 14:30:00	2022-11-08 18:30:00	\N	\N	2	0	\N	\N
676415	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF 2023 - programme 146	PLF 2023 - Programme 146	2022-11-15 10:30:00	2022-11-15 11:30:00	\N	\N	2	0	\N	\N
676418	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF 2023 - programme 146	PLF 2023 - programme 146	2022-11-15 15:45:00	2022-11-15 19:00:00	\N	\N	2	0	\N	\N
676433	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF 2023	\N	2022-11-15 13:15:00	2022-11-15 14:15:00	\N	\N	2	0	\N	\N
680354	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	\N	2022-11-22 16:30:00	2022-11-22 17:15:00	\N	\N	2	0	\N	\N
680389	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	PLF pour 2023 - Programme 178	Déplacement à Toulon sur la base navale	2022-11-25 12:00:00	2022-11-25 20:00:00	\N	\N	2	0	\N	\N
680446	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL AESH	\N	2022-11-24 17:30:00	2022-11-24 18:30:00	\N	\N	4	0	\N	\N
687352	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Retex Ukraine	Retex Ukraine	2022-12-13 16:00:00	2022-12-13 18:00:00	\N	\N	3	0	\N	\N
693326	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Ambassadrice de l'Unesco	\N	2023-01-24 09:30:00	2023-01-24 11:00:00	\N	\N	4	0	\N	\N
694894	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 26 janvier 2023	\N	2023-01-26 09:00:00	2023-01-26 10:15:00	2023-01-26 10:14:01	2023-01-26 17:50:32	8	0	\N	\N
694937	ETUDES	AUCUNE	\N	\N	\N	Réunion constitutive	\N	2023-01-25 16:45:00	2023-01-25 17:30:00	\N	\N	20	0	\N	1014
694940	DELEGATION	AUCUNE	\N	\N	COLTER	Réunion plénière	\N	2023-02-02 09:00:00	2023-02-02 11:40:00	2023-02-02 13:02:17	\N	21	0	\N	\N
694941	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PPL Retraite de base des non-salariés agricoles - Réunion plénière 	\N	2023-01-31 14:15:00	2023-01-31 14:30:00	2023-01-31 14:30:28	2023-02-01 11:49:10	16	0	\N	\N
694947	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition du Pr Christèle Gras-Le Guen et A. Taquet	\N	2023-02-01 09:00:00	2023-02-01 12:15:00	2023-02-01 17:31:54	2023-02-01 17:35:08	37	0	\N	\N
694949	COM_PERMANENTE	AUTRE	\N	AFCL	\N	TR transition écologiquqe du bati ancien	\N	2023-02-01 09:30:00	2023-02-01 11:45:00	2023-02-02 15:42:15	2023-02-02 15:52:03	37	0	\N	\N
694950	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de Caroline Semaille	\N	2023-02-01 18:30:00	2023-02-01 19:25:00	2023-02-01 19:25:41	2023-02-02 15:51:43	4	0	\N	\N
694953	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Centres de santé - Audition FNCS	\N	2023-01-26 14:00:00	2023-01-26 14:45:00	\N	\N	2	0	\N	\N
694954	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Centres de santé - Audition UCSD	\N	2023-01-26 14:45:00	2023-01-26 15:30:00	\N	\N	1	0	\N	\N
694958	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFRSS - Audition FO	\N	2023-01-26 14:15:00	2023-01-26 15:00:00	\N	\N	5	0	\N	\N
695001	GIA	AUCUNE	\N	\N	\N	entretien avec M. Chen I-Shin	entretien avec M. Chen I-Shin , député, directeur des relations internatioanaes du KMT	2023-01-24 16:30:00	2023-01-24 18:00:00	\N	\N	2	0	623	\N
695005	ETUDES	AUTRE	\N	\N	\N	Audition UNIM	Audition UNIM	2023-01-25 14:00:00	2023-01-25 15:00:00	\N	\N	5	0	\N	908
695006	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Centres de santé - Audition Mutualité française	\N	2023-01-26 15:45:00	2023-01-26 16:30:00	\N	\N	1	0	\N	\N
695033	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Centres de santé - Audition Cnom-ONCD	\N	2023-01-26 16:30:00	2023-01-26 17:15:00	\N	\N	1	0	\N	\N
695059	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Accès aux soins - Audition de l'Ordre national des infirmiers	\N	2023-01-24 10:00:00	2023-01-24 10:45:00	\N	\N	2	0	\N	\N
695062	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Accès aux soins - Audition de l'Ordre national des chirurgiens-dentistes	\N	2023-01-24 11:00:00	2023-01-24 11:45:00	\N	\N	1	0	\N	\N
695063	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Accès aux soins - Audition du Conseil national de l'Ordre des médecins	\N	2023-01-24 11:45:00	2023-01-24 12:30:00	\N	\N	3	0	\N	\N
695064	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Accès aux soins - Audition de la Fédération nationale des orthophonistes	\N	2023-01-24 16:30:00	2023-01-24 17:15:00	\N	\N	4	0	\N	\N
695065	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Accès aux soins - Audition de France Assos santé	\N	2023-01-24 17:15:00	2023-01-24 18:00:00	\N	\N	3	0	\N	\N
673345	COM_PERMANENTE	AUTRE	\N	CAE	\N	PLF 2023 - Missions budgétaires 	\N	2022-11-16 09:00:00	2022-11-16 11:00:00	2022-11-16 11:15:06	2022-11-16 17:13:20	48	1	\N	\N
740404	GIA	AUCUNE	\N	\N	\N	Rencontre avec l'ambassadeur de France à Rabat	Rencontre avec l'ambassadeur de France à Rabat	2023-05-23 12:30:00	2023-05-23 14:30:00	\N	\N	4	0	598	\N
740413	GIA	AUCUNE	\N	\N	\N	Réception à l'occasion de la fête nationale de Pologne	Réception à l'occasion de la fête nationale de Pologne	2023-05-10 12:00:00	2023-05-10 14:00:00	\N	\N	4	0	600	\N
742823	COM_EURO	AUDRAP	\N	AFEU	\N	Audition - CNIL	Espace européen des données de santé - Audition - CNIL	2023-05-30 17:45:00	2023-05-30 19:00:00	\N	\N	2	0	\N	\N
743066	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Table ronde sur les libertés médias audiovisuels en Europe	\N	2023-06-22 09:00:00	2023-06-22 11:00:00	2023-06-22 17:20:57	2023-06-22 17:43:52	17	0	\N	\N
743068	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	autonomie	\N	2023-06-13 13:45:00	2023-06-13 14:30:00	\N	\N	3	0	\N	\N
743069	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	autonomie des ES	\N	2023-06-14 13:45:00	2023-06-14 14:45:00	\N	\N	3	0	\N	\N
743379	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition article 13 - CNR	\N	2023-06-14 16:30:00	2023-06-14 17:30:00	2023-06-14 19:14:25	2023-06-15 20:05:56	26	0	\N	\N
743476	COM_EURO	DEPLACEMENT	\N	AFEU	\N	Espace européen des données de santé - Déplacement à Bruxelles	Espace européen des données de santé - Déplacement à Bruxelles	2023-06-08 08:00:00	2023-06-08 20:00:00	\N	\N	2	0	\N	\N
743482	MECSS	AUCUNE	\N	\N	MECSS	PJL Approbation comptes sécurité sociale 2022 - Audition É. Baseilhac	\N	2023-06-20 14:00:00	2023-06-20 15:05:00	2023-06-20 15:08:36	2023-06-20 18:18:25	7	0	\N	\N
743485	MECSS	AUCUNE	\N	\N	MECSS	PJL Approbation comptes sécurité sociale 2022 - Audition de M. Nicolas Grivel	\N	2023-06-20 17:00:00	2023-06-20 18:10:00	2023-06-21 16:41:58	2023-06-21 18:12:34	5	0	\N	\N
743514	ETUDES	AUTRE	\N	\N	\N	Audition de la Conférence des grandes écoles (CGE)	\N	2023-06-14 14:00:00	2023-06-14 15:00:00	\N	\N	12	0	\N	1014
744275	GIA	AUCUNE	\N	\N	\N	Entretien avec le Premier ministre et la ministre des affaires étrangères du Pérou	Entretien du GIA France-Pays Andins avec le Premier ministre et la ministre des affaires étrangères du Pérou	2023-06-07 12:30:00	2023-06-07 14:00:00	\N	\N	8	0	979	\N
750012	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - MI Respect des principes de la République	Audition rapporteur - MI Principes de la République	2023-07-07 14:00:00	2023-07-07 16:20:00	\N	\N	2	0	\N	\N
750021	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 58	\N	2023-07-11 14:30:00	2023-07-11 16:15:00	2023-07-11 18:10:48	2023-07-12 10:30:16	25	6	\N	\N
759797	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2024 Autonomie - Audition du CNCPH	\N	2023-10-25 14:15:00	2023-10-25 15:00:00	\N	\N	2	0	\N	\N
760193	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Direction générale des patrimoines et de d'architecture	\N	2023-10-25 13:30:00	2023-10-25 15:00:00	\N	\N	2	0	\N	\N
760483	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2024 - Avis Immigration, asile et intégration	Audition rapporteur - PLF 2024 - Avis immigration	2023-10-26 08:00:00	2023-10-26 09:00:00	\N	\N	2	0	\N	\N
761872	DELEGATION	AUCUNE	\N	\N	211	Audition de Bérangère Couillard, ministre de l'égalité femmes-hommes	\N	2023-11-30 09:00:00	2023-11-30 11:00:00	\N	\N	14	0	\N	\N
761901	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - RS CAS Pensions - Audition du Service des retraites de l'Etat	PLF pour 2024 - RS CAS Pensions - Audition du Service des retraites de l'Etat	2023-10-30 18:00:00	2023-10-30 19:00:00	\N	\N	1	0	\N	\N
761904	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - RS CAS Pensions - Audition de l'ÉNIM	PLF pour 2024 - RS CAS Pensions - Audition de l'Établissement National des Invalides de la Marine	2023-10-31 10:00:00	2023-10-31 11:00:00	\N	\N	1	0	\N	\N
761911	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Santé - Audition Direction générale de la sécurité sociale	PLF pour 2024 - Santé - Audition Direction générale de la sécurité sociale	2023-10-24 10:00:00	2023-10-24 11:00:00	\N	\N	1	0	\N	\N
761913	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Santé - Audition de la Direction générale de la Santé	PLF pour 2024 - Santé - Audition de Mmes METZEN-IVARS et ALEONARD, direction générale de la Santé	2023-10-25 16:30:00	2023-10-25 17:30:00	\N	\N	1	0	\N	\N
761915	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Santé - Audition de la Caisse d'amortisement de la dette sociale	PLF pour 2024 - Santé - Audition de M. REY et Mme GAUTHEY, caisse d'amortisement de la dette sociale	2023-10-25 17:30:00	2023-10-25 18:30:00	\N	\N	1	0	\N	\N
761919	DELEGATION	AUCUNE	\N	\N	PROS	IA : quand ChatGPT rêve de l'Empire romain	\N	2023-11-07 18:10:00	2023-11-07 19:35:00	\N	\N	11	0	\N	\N
761931	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition Patrice Vergriete	\N	2023-11-07 17:35:00	2023-11-07 19:35:00	2023-11-08 09:10:43	2023-11-08 17:48:12	33	0	\N	\N
761937	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Solidarité - Table-ronde Associations Droits des femmes	PLF pour 2024 - Solidarité - Table-ronde Associations Droits des femmes	2023-10-26 15:00:00	2023-10-26 16:00:00	\N	\N	2	0	\N	\N
761945	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Solidarité - Table-ronde Associations Droits des personnes handicapées	PLF pour 2024 - Solidarité - Table-ronde Associations Droits des personnes handicapées	2023-10-26 16:30:00	2023-10-26 17:00:00	\N	\N	2	0	\N	\N
761949	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Travail et emploi- Audition DGEFP	PLF pour 2024 - Travail et emploi - Audition délégation générale à l'emploi et à la formation pro	2023-10-30 15:00:00	2023-10-30 16:00:00	\N	\N	2	0	\N	\N
761952	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Travail et emploi - Audition Pôle emploi	PLF pour 2024 - Travail et emploi - Audition Pôle emploi	2023-10-30 16:30:00	2023-10-30 17:00:00	\N	\N	2	0	\N	\N
761955	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Travail et emploi- Audition cabinets des ministères	PLF pour 2024 - Travail et emploi- Audition des cabinets du ministre du travail et de la ministre déléguée à l'enseignem	2023-10-30 17:30:00	2023-10-30 18:30:00	\N	\N	2	0	\N	\N
761964	DELEGATION	AUCUNE	\N	\N	COLTER	Réunion plénière	\N	2023-11-09 09:00:00	2023-11-09 12:00:00	\N	\N	19	0	\N	\N
761973	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2024 Hébergement - Audition Uniopss	\N	2023-11-16 09:00:00	2023-11-16 10:00:00	\N	\N	1	0	\N	\N
761974	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2024 Hébergement - Table ronde d'associations humanitaires	\N	2023-11-14 09:15:00	2023-11-14 10:45:00	\N	\N	1	0	\N	\N
762678	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - AEE - Audition de Mme BOUILLON, direction du budget	PLF pour 2024 - AEE - Audition de Mme BOUILLON, direction du budget	2023-11-06 16:30:00	2023-11-06 17:30:00	\N	\N	2	0	\N	\N
742621	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion CATDD	\N	2023-06-14 10:00:00	2023-06-14 10:48:00	2023-06-15 17:22:29	2023-06-15 20:05:51	41	0	\N	\N
752061	CMP	AUTRE	\N	SPOL	\N	PJL Restitution de biens culturels	PJL Restitution de biens culturels	2023-07-06 11:30:00	2023-07-06 12:15:00	\N	\N	9	0	\N	\N
762681	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Guillaume Chevrollier	Auditions M. Guillaume Chevrollier	2023-11-07 09:00:00	2023-11-07 09:45:00	\N	\N	1	0	\N	\N
762683	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition M. Guillaume Chevrollier	Audition M. Guillaume Chevrollier	2023-11-07 17:00:00	2023-11-07 18:00:00	\N	\N	1	0	\N	\N
762686	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - AEE - Audition Agence pour l'enseignement français à l'étranger	PLF pour 2024 - AEE - Audition Agence pour l'enseignement français à l'étranger	2023-11-06 17:30:00	2023-11-06 18:30:00	\N	\N	2	0	\N	\N
764871	COM_SPECIALE	PLENIERE	\N	DDADUE23	\N	Réunion DDADUE	\N	2023-11-09 11:00:00	2023-11-09 11:25:00	2023-11-09 18:25:36	2023-11-10 14:28:38	17	3	\N	\N
765722	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-11-13 20:10:00	2023-11-13 20:35:00	2023-11-13 21:12:58	2023-11-14 18:04:32	25	0	\N	\N
765745	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2024 Solidarité - Table ronde Droits des femmes	\N	2023-11-13 10:45:00	2023-11-13 12:00:00	\N	\N	2	0	\N	\N
638310	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Conférence interparlementaire PESC-PSDC	\N	2022-02-25 09:00:00	2022-02-25 17:00:00	\N	\N	5	0	\N	\N
638316	GIA	AUCUNE	\N	\N	\N	Présentation de l'index mondiale de persécution des chrétiens 2022	G:\\EVENEMENTS\\PFUE 2022\\Dîner 3 mars	2022-02-01 15:00:00	2022-02-01 16:30:00	\N	\N	12	0	CHRETORIENT	CHRETORIENT
642003	GIA	AUCUNE	\N	\N	\N	Rencontre Tashi Phuntsok et visite Bureau du Tibet (Paris)	Rencontre Tashi Phuntsok et visite Bureau du Tibet (Paris)	2022-05-02 11:30:00	2022-05-02 15:00:00	\N	\N	4	0	634	\N
642004	GIA	AUCUNE	\N	\N	\N	Convention internationale des parlementaires sur le Tibet	Convention internationale des parlementaires sur le Tibet	2022-06-22 08:00:00	2022-06-23 23:00:00	\N	\N	2	0	634	\N
642106	MISSION	AUCUNE	\N	FONDSMER	\N	Table ronde bassin Indien	Table ronde bassin Indien	2022-05-04 08:00:00	2022-05-04 09:50:00	2022-05-04 18:29:29	2022-05-09 16:20:26	12	0	\N	\N
642120	MISSION	AUCUNE	\N	FONDSMER	\N	Table ronde bassin Pacifique	Table ronde bassin Pacifique	2022-05-03 08:00:00	2022-05-03 10:00:00	2022-05-04 18:33:54	2022-05-09 16:20:25	10	0	\N	\N
642538	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions MI Énergie et hydrogène nucléaires	Auditions MI Énergie et hydrogène nucléaires	2022-05-10 13:45:00	2022-05-10 17:15:00	\N	\N	3	0	\N	\N
642555	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022- dotations d'investissement aux CT - Région Grand Est	Contrôle 2022- dotations d'investissement aux CT - Région Grand Est	2022-05-03 11:00:00	2022-05-03 12:00:00	\N	\N	2	0	\N	\N
642558	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - FEI - OPT/FEI	Contrôle 2022 - FEI - OPT/FEI	2022-05-10 19:00:00	2022-05-10 20:00:00	\N	\N	2	0	\N	\N
642561	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2022 - Maisons France services - Déplacement Cantal	Contrôle 2022 - Maisons France services - Déplacement Cantal	2022-05-09 10:00:00	2022-05-10 20:00:00	\N	\N	1	0	\N	\N
642563	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 -  Régimes des retraites RATP et Marins - ORP gens de mer/DGAMPA	Contrôle 2022 -  Régimes des retraites RATP et Marins - ORP gens de mer/DGAMPA	2022-05-10 14:30:00	2022-05-10 17:50:00	\N	\N	1	0	\N	\N
642565	ETUDES	AUTRE	\N	\N	\N	GEAC - Audition de M. David GALLEZOT, president de la société Avions Mauboussin	GEAC - Audition de M. David GALLEZOT, president de la société Avions Mauboussin et de l'association Ailes sud-ouest	2022-05-10 15:30:00	2022-05-10 16:45:00	\N	\N	10	0	\N	933
642597	COM_PERMANENTE	DEPLACEMENT	\N	SOCI	\N	MI France compétences - Déplacement à France compétences	MI France compétences - Déplacement à France compétences	2022-05-10 14:00:00	2022-05-10 18:45:00	\N	\N	2	0	\N	\N
642620	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Patrimoine-Environnement	Audition de M. de Sagazan	2022-05-10 17:45:00	2022-05-10 19:00:00	\N	\N	3	0	\N	\N
642641	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Souveraineté économique - Audition France industrie	MI Souveraineté économique - Audition France industrie	2022-05-11 15:00:00	2022-05-11 16:00:00	\N	\N	3	0	\N	\N
642768	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI sur la politique étrangère américaine	\N	2022-05-13 15:00:00	2022-05-13 16:00:00	\N	\N	4	0	\N	\N
642773	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI sur la politique étrangère américaine	\N	2022-05-11 13:45:00	2022-05-11 14:45:00	\N	\N	2	0	\N	\N
642776	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI sur la politique étrangère américaine	\N	2022-05-11 16:15:00	2022-05-11 17:15:00	\N	\N	2	0	\N	\N
642783	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	LPR	\N	2022-05-13 15:00:00	2022-05-13 18:00:00	\N	\N	3	0	\N	\N
655581	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL Banque des règlements internationaux	\N	2022-09-14 10:00:00	2022-09-14 10:45:00	\N	\N	1	0	\N	\N
655611	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	MCC Sécurisation de la chasse	MCC Sécurisation de la chasse	2022-09-13 16:35:00	2022-09-13 17:50:00	\N	\N	10	0	\N	\N
668427	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition MCC ZAN	Auditions MCC ZAN	2022-10-25 15:00:00	2022-10-25 16:00:00	\N	\N	8	0	\N	\N
668436	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Auditions MCC ZAN	Auditions MCC ZAN	2022-10-25 16:00:00	2022-10-25 16:45:00	\N	\N	8	0	\N	\N
668448	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Auditions MCC ZAN	Auditions MCC ZAN	2022-10-25 16:45:00	2022-10-25 17:30:00	\N	\N	7	0	\N	\N
668457	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Auditions MCC ZAN	Auditions MCC ZAN	2022-10-27 10:15:00	2022-10-27 11:45:00	\N	\N	4	0	\N	\N
685757	GIA	AUCUNE	\N	\N	\N	AG annuelle du GIA	AG annuelle du GIA	2013-01-11 11:30:00	2013-01-11 12:30:00	\N	\N	0	0	653	\N
686659	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ambassadrice d'Islande en France	Entretien avec l'ambassadrice d'Islande en France	2022-12-08 13:00:00	2022-12-08 14:35:00	\N	\N	5	0	625	\N
686668	GIA	AUCUNE	\N	\N	\N	Déjeuner de travail à l'invitation de l'Ambassadeur du Japon Ihara	Déjeuner à l'Ambassade du Japon	2022-11-22 13:00:00	2022-11-22 14:45:00	\N	\N	11	0	596	CHRETORIENT
686683	GIA	AUCUNE	\N	\N	\N	Conférence sur l'Iran avec la Délégation aux Droits des Femmes 	Femmes, vie, iiberté !	2022-11-29 18:45:00	2022-11-29 21:00:00	\N	\N	16	0	CHRETORIENT	CHRETORIENT
688837	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Jeux Olympiques et Paralympiques de 2024	PJL Jeux Olympiques et Paralympiques de 2024	2023-01-05 17:10:00	2023-01-05 18:05:00	\N	\N	3	0	\N	\N
688841	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Jeux Olympiques et Paralympiques de 2024	\N	2023-01-09 14:00:00	2023-01-09 15:00:00	\N	\N	3	0	\N	\N
688842	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Jeux Olympiques et Paralympiques de 2024	PJL Jeux Olympiques et Paralympiques de 2024	2023-01-10 14:00:00	2023-01-10 15:00:00	\N	\N	5	0	\N	\N
689192	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions rapporteur - MI organisation de la police judiciaire	Auditions rapporteur - MI organisation de la police judiciaire	2023-01-10 14:00:00	2023-01-10 18:00:00	\N	\N	2	0	\N	\N
689279	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de Mme Agnès Pannier Runacher	\N	2023-01-11 08:05:00	2023-01-11 09:40:00	2023-01-11 12:12:30	2023-01-12 17:25:05	65	0	\N	\N
689281	COM_PERMANENTE	AUTRE	\N	CAE	\N	\N	\N	2023-01-11 10:00:00	2023-01-11 12:05:00	\N	\N	0	0	\N	\N
690021	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Jeux Olympiques et Paralympiques de 2024 - Audition ARS ÎdF	\N	2023-01-11 14:00:00	2023-01-11 14:45:00	\N	\N	1	0	\N	\N
690386	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition Georgelin	\N	2023-01-18 09:30:00	2023-01-18 11:00:00	2023-01-18 15:24:43	2023-01-19 11:52:35	39	4	\N	\N
690416	COM_PERMANENTE	AUTRE	\N	AFCL	\N	PJL JO	\N	2023-01-17 09:30:00	2023-01-17 10:20:00	2023-01-18 15:22:54	2023-01-19 11:52:25	24	9	\N	\N
690420	COM_EURO	AUDRAP	\N	AFEU	\N	Audition AMLIS : Politique du médicament	\N	2023-01-11 14:00:00	2023-01-11 15:00:00	\N	\N	2	0	\N	\N
690446	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition plénière	\N	2023-01-18 10:00:00	2023-01-18 11:50:00	2023-01-18 11:54:04	2023-01-19 11:52:38	40	0	\N	\N
690455	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Retraite de base des non-salariés agricoles - Audition de la CCMSA 	\N	2023-01-11 16:30:00	2023-01-11 17:15:00	\N	\N	3	0	\N	\N
690798	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL "navigation rhénane"	PJL "navigation rhénane"	2023-01-11 16:30:00	2023-01-11 17:30:00	\N	\N	1	0	\N	\N
692358	GIA	AUCUNE	\N	\N	\N	Rencontre avec M. Livia LEU à l'Ambassade de Suisse	Rencontre avec M. Livia LEU Secrétaire d'Etat aux affaires étrangères/Ambassade de Suisse	2023-02-09 18:30:00	2023-02-09 20:00:00	\N	\N	1	0	610	\N
692416	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	GT 212 LPM 	GT 212 LPM	2023-01-16 16:00:00	2023-01-16 18:00:00	\N	\N	1	0	\N	\N
692423	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2023-01-24 09:30:00	2023-01-24 12:30:00	\N	\N	47	0	\N	\N
738285	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Données de santé - Audition de la CNIL	\N	2023-05-30 17:45:00	2023-05-30 19:00:00	\N	\N	5	0	\N	\N
738286	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Application des lois Protection de l'enfance - Audition de M. Gautier Arnaud-Melchiorre	\N	2023-05-30 16:00:00	2023-05-30 16:45:00	\N	\N	4	0	\N	\N
738287	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Application des lois Protection de l'enfance - Audition commune DGCS/DPJJ	\N	2023-05-30 16:45:00	2023-05-30 17:45:00	\N	\N	3	0	\N	\N
738288	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Application des lois Protection de l'enfance - Audition de M. Adrien Taquet	\N	2023-05-30 18:00:00	2023-05-30 19:30:00	\N	\N	6	0	\N	\N
738289	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Fin de vie - Audition du CNDMV	\N	2023-05-31 14:00:00	2023-05-31 15:00:00	\N	\N	3	0	\N	\N
738290	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Registre national des cancers - Audition de l'INCa	\N	2023-05-31 16:30:00	2023-05-31 17:30:00	\N	\N	2	0	\N	\N
738291	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Registre national des cancers - Audition de Me Jeanne Bossi Malafosse	\N	2023-06-01 10:30:00	2023-06-01 11:30:00	\N	\N	2	0	\N	\N
738292	COM_ENQUETE	PLENIERE	\N	MEDIC	\N	Réunion plénière	\N	2023-06-06 09:30:00	2023-06-06 10:50:00	2023-06-06 10:53:54	2023-06-06 14:13:41	4	0	\N	\N
738297	COM_ENQUETE	PLENIERE	\N	MEDIC	\N	Réunion plénière	\N	2023-06-07 13:40:00	2023-06-07 14:40:00	2023-06-07 15:41:17	2023-06-07 17:26:55	5	0	\N	\N
738333	COM_SPECIALE	PLENIERE	\N	ESNU	\N	Réunion constitutive	Réunion constitutive	2023-06-06 09:30:00	2023-06-06 10:15:00	2023-06-06 16:34:17	2023-06-07 10:34:11	24	1	\N	\N
738334	DELEGATION	AUCUNE	\N	\N	COLTER	Réunion plénière	\N	2023-06-08 09:00:00	2023-06-08 10:30:00	2023-06-08 11:28:05	\N	13	0	\N	\N
738339	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition ZFE	\N	2023-06-02 09:00:00	2023-06-02 09:45:00	\N	\N	1	0	\N	\N
738341	DELEGATION	AUDRAP	\N	\N	206	Audition Recyclage plastique	\N	2023-06-01 13:30:00	2023-06-01 16:30:00	\N	\N	2	0	\N	\N
738519	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Industrie verte - Audition Autorité de Contrôle prudentiel et de Résolution (ACPR)	PJL Industrie verte - Audition Autorité de Contrôle prudentiel et de Résolution (ACPR)	2023-05-31 19:50:00	2023-05-31 20:40:00	\N	\N	1	0	\N	\N
738528	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Industrie verte - Audition Caisse des dépôts et consignations	PJL Industrie verte - Audition Caisse des dépôts et consignations	2023-06-02 09:00:00	2023-06-02 09:45:00	\N	\N	1	0	\N	\N
738530	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Industrie verte - Audition Reclaim Finances	PJL Industrie verte - Audition Reclaim Finances	2023-06-02 09:45:00	2023-06-02 10:30:00	\N	\N	1	0	\N	\N
738532	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Industrie verte - Audition France Assureurs	PJL Industrie verte - Audition France Assureurs	2023-06-02 10:30:00	2023-06-02 11:15:00	\N	\N	1	0	\N	\N
738534	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Industrie verte - Audition Banque populaire-Caisse d'épargne	PJL Industrie verte - Audition Banque populaire-Caisse d'épargne	2023-06-02 11:15:00	2023-06-02 12:00:00	\N	\N	1	0	\N	\N
738536	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Industrie verte - Audition Conseil national de la transition écologique	PJL Industrie verte - Audition Conseil national de la transition écologique	2023-06-02 14:00:00	2023-06-02 14:45:00	\N	\N	1	0	\N	\N
738538	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Industrie verte - Audition Fédération bancaire française	PJL Industrie verte - Audition Fédération bancaire française	2023-06-05 14:00:00	2023-06-05 14:45:00	\N	\N	1	0	\N	\N
738540	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Industrie verte - Audition France Invest	PJL Industrie verte - Audition France Invest	2023-06-05 14:45:00	2023-06-05 15:25:00	\N	\N	1	0	\N	\N
738542	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Industrie verte - Audition Association française de la gestion financière	PJL Industrie verte - Audition Association française de la gestion financière	2023-06-05 15:25:00	2023-06-05 16:00:00	\N	\N	1	0	\N	\N
738548	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Programmation militaire 2024/2030 - Audition Etat-major des armées	PJL Programmation militaire 2024/2030 - Audition Etat-major des armées	2023-05-31 16:15:00	2023-05-31 17:15:00	\N	\N	1	0	\N	\N
738561	DELEGATION	AUDRAP	\N	\N	211	Audition rapporteures "Santé des femmes au travail" (Association La Niaque)	\N	2023-06-06 13:30:00	2023-06-06 14:30:00	\N	\N	3	0	\N	\N
738565	DELEGATION	AUDRAP	\N	\N	211	Audition rapporteur - Karim Bouamrane (Maire de St Ouen)	\N	2023-06-06 14:30:00	2023-06-06 15:25:00	\N	\N	3	0	\N	\N
738809	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions M. Laurent Somon	\N	2023-05-30 20:00:00	2023-05-30 21:00:00	\N	\N	0	0	\N	\N
739777	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Industrie verte	\N	2023-06-07 14:15:00	2023-06-07 15:15:00	\N	\N	1	0	\N	\N
689280	COM_PERMANENTE	AUTRE	\N	CAE	\N	PJL Nucléaire 	\N	2023-01-11 10:00:00	2023-01-11 11:35:00	2023-01-11 12:11:26	2023-01-12 17:25:08	47	0	\N	\N
690432	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-01-18 09:00:00	2023-01-18 09:40:00	2023-01-18 10:02:02	2023-01-19 11:52:26	41	0	\N	\N
738516	COM_PERMANENTE	AUTRE	\N	CAE	\N	PPRE réforme du marché de l'électricité 	\N	2023-06-07 10:00:00	2023-06-07 11:30:00	2023-06-07 11:55:54	2023-06-07 17:26:46	46	1	\N	\N
740118	COM_SPECIALE	AUTRE	\N	ESNU	\N	Audition Pharos	\N	2023-06-07 16:45:00	2023-06-07 18:00:00	2023-06-07 19:34:35	2023-06-08 11:18:15	18	0	\N	\N
740141	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition des organisations syndicales	\N	2023-06-07 16:30:00	2023-06-07 18:00:00	\N	\N	5	0	\N	\N
752022	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2023-07-20 09:00:00	2023-07-20 12:30:00	\N	\N	3	0	\N	\N
752202	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Sécurité des élus locaux et protection des maires	PPL Sécurité des élus locaux et protection des maires	2023-09-26 09:30:00	2023-09-26 10:00:00	\N	\N	2	0	\N	\N
752203	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Sécurité des élus locaux et protection des maires	PPL Sécurité des élus locaux et protection des maires	2023-09-26 14:05:00	2023-09-26 17:00:00	\N	\N	1	0	\N	\N
753497	COM_EURO	AUTRE	\N	AFEU	\N	Constitution du Bureau de la commission des affaires européennes	\N	2023-10-05 15:50:00	2023-10-05 16:25:00	2023-10-05 17:18:38	2023-10-05 17:51:22	36	1	\N	\N
755874	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2023-10-04 15:20:00	2023-10-04 16:30:00	\N	\N	3	0	\N	\N
760870	BUREAU	AUCUNE	\N	\N	\N	Conseil de Questure	Réunion du Conseil de Questure	2023-10-24 16:00:00	2023-10-24 17:16:00	\N	\N	3	0	\N	\N
765223	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition les parcs nationaux	Audition les parcs nationaux	2023-11-09 10:50:00	2023-11-09 11:15:00	\N	\N	1	0	\N	\N
765226	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition OFB	Audition OFB	2023-11-09 11:15:00	2023-11-09 12:00:00	\N	\N	2	0	\N	\N
765229	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Guillaume Chevrollier	Auditions M. Guillaume Chevrollier	2023-11-09 14:30:00	2023-11-09 16:15:00	\N	\N	1	0	\N	\N
765237	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions rapporteur PPL Personnes condamnées pour homosexualité entre 1942 et 1982	Auditions rapporteur PPL Personnes condamnées pour homosexualité entre 1942 et 1982	2023-11-09 14:30:00	2023-11-09 17:10:00	\N	\N	2	0	\N	\N
765241	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur PPL Personnes condamnées pour homosexualité entre 1942 et 1982	Auditions rapporteur PPL Personnes condamnées pour homosexualité entre 1942 et 1982	2023-11-08 14:15:00	2023-11-08 15:15:00	\N	\N	1	0	\N	\N
765252	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL culture citoyenne	\N	2023-11-09 09:30:00	2023-11-09 10:45:00	\N	\N	1	0	\N	\N
765253	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF Presse	\N	2023-11-09 11:00:00	2023-11-09 12:00:00	\N	\N	1	0	\N	\N
765314	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2024 Solidarité - FFBA-Restos du coeur 	\N	2023-11-09 14:30:00	2023-11-09 15:30:00	\N	\N	1	0	\N	\N
765315	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2024 Solidarité - Table ronde Handicap	\N	2023-11-09 15:30:00	2023-11-09 16:30:00	\N	\N	3	0	\N	\N
765316	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2024 Solidarité - DGCS	\N	2023-11-09 16:45:00	2023-11-09 17:45:00	\N	\N	1	0	\N	\N
765422	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2024 - APD	\N	2023-11-07 14:30:00	2023-11-07 16:30:00	\N	\N	2	0	\N	\N
765425	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2024 - Programme 178	\N	2023-11-08 16:30:00	2023-11-08 18:30:00	\N	\N	2	0	\N	\N
765474	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Industrie - Table ronde Afep, CPME, Medef	Auditions Industrie - Table ronde Afep, CPME, Medef	2023-11-09 14:00:00	2023-11-09 14:45:00	\N	\N	1	0	\N	\N
765475	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Industrie - SER	Auditions Industrie - SER	2023-11-09 16:15:00	2023-11-09 17:00:00	\N	\N	1	0	\N	\N
765476	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Industrie - BPI France	Auditions Industrie - BPI France	2023-11-09 17:00:00	2023-11-09 18:00:00	\N	\N	1	0	\N	\N
765486	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2024 - Programme 178	\N	2023-11-09 11:00:00	2023-11-09 12:20:00	\N	\N	2	0	\N	\N
765489	DELEGATION	AUTRE	\N	\N	DSOM	Réunion de programmation des travaux	\N	2023-11-16 08:30:00	2023-11-16 09:30:00	\N	\N	14	0	\N	\N
639551	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Mission d'information sur la politique étrangère américaine	\N	2022-03-16 14:30:00	2022-03-16 16:00:00	\N	\N	3	0	\N	\N
639555	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Mission d'information sur la politique étrangère américaine	Echange de vues sur la mission	2022-03-15 16:30:00	2022-03-15 17:30:00	\N	\N	3	0	\N	\N
640805	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - Plan 15000 - APIJ	Contrôle 2022 - Plan 15000 - APIJ	2022-03-30 14:30:00	2022-03-30 15:30:00	\N	\N	1	0	\N	\N
640807	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - OAT vertes - Vigeo Eiris/CBI/AMF	Contrôle 2022 - OAT vertes - Vigeo Eiris/CBI/AMF	2022-03-29 14:40:00	2022-03-29 19:15:00	\N	\N	1	0	\N	\N
640809	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2021 - Douane face au trafic de stupéfiants - Expert/DGDDI	Contrôle 2021 - Douane face au trafic de stupéfiants - Expert/DGDDI	2022-03-29 16:00:00	2022-03-29 18:10:00	\N	\N	1	0	\N	\N
640811	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - OAT vertes - WWF/Deutsche Bank	Contrôle 2022 - OAT vertes - WWF/Deutsche Bank	2022-03-30 09:00:00	2022-03-30 11:10:00	\N	\N	1	0	\N	\N
640813	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - OAT vertes - Agence France Locale	Contrôle 2022 - OAT vertes - Agence France Locale	2022-03-30 14:20:00	2022-03-30 15:30:00	\N	\N	1	0	\N	\N
640815	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - France TV  - TR Producteurs audiovisuels indépendants 	Contrôle 2022 - France TV  - TR Producteurs audiovisuels indépendants 	2022-03-31 14:30:00	2022-03-31 15:35:00	\N	\N	1	0	\N	\N
640817	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - France TV - DGMIC	Contrôle 2022 - France TV - DGMIC	2022-04-01 09:30:00	2022-04-01 10:35:00	\N	\N	1	0	\N	\N
640819	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - ZAN - DB/DLF	Contrôle 2022 - ZAN - DB/DLF	2022-03-30 14:30:00	2022-03-30 16:00:00	\N	\N	1	0	\N	\N
640821	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	MI Reconnaissance faciale - déplacement à Londres	MI Reconnaissance faciale - déplacement à Londres	2022-04-07 06:00:00	2022-04-08 20:00:00	\N	\N	3	0	\N	\N
642253	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2022-05-10 09:30:00	2022-05-10 11:15:00	\N	\N	5	0	\N	\N
645090	COM_PERMANENTE	DEPLACEMENT	\N	AFCL	\N	Incidents Stade de France - Déplacement au Stade de France	Incidents Stade de France - Déplacement au Stade de France	2022-06-16 14:00:00	2022-06-16 18:00:00	\N	\N	8	0	\N	\N
645108	GIA	AUCUNE	\N	\N	\N	Salon de la culture tibétaine	Salon de la culture tibétaine	2022-07-10 10:00:00	2022-07-10 18:00:00	\N	\N	1	0	634	\N
645439	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Auditions rapporteurs sur la transmission d'entreprises	Auditions rapporteurs sur la transmission d'entreprises	2022-06-21 16:45:00	2022-06-21 17:45:00	\N	\N	3	0	\N	\N
645443	DELEGATION	AUDRAP	\N	\N	ENTREPRISES	Auditions rapporteurs sur la responsabilité sociétale des entreprises (RSE)	Auditions rapporteurs sur la responsabilité sociétale des entreprises (RSE)	2022-06-21 09:00:00	2022-06-21 10:30:00	\N	\N	4	0	\N	\N
646410	DELEGATION	AUDRAP	\N	\N	PROS	Audition de M. DOUGADOS (Capgemini)	\N	2022-07-05 18:30:00	2022-07-05 19:15:00	\N	\N	1	0	\N	\N
646447	DELEGATION	AUDRAP	\N	\N	PROS	Déjeuner-audition Mme IDRAC (France logistique)	\N	2022-07-05 12:30:00	2022-07-05 14:30:00	\N	\N	1	0	\N	\N
646674	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PPRE Action numérique	\N	2022-07-04 10:00:00	2022-07-04 11:00:00	\N	\N	0	0	\N	\N
646675	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PPRE Action numérique	\N	2022-07-04 10:00:00	2022-07-04 11:00:00	\N	\N	1	0	\N	\N
646677	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PPRE Action numérique	\N	2022-07-04 14:00:00	2022-07-04 16:30:00	\N	\N	1	0	\N	\N
646679	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PPRE Action numérique	\N	2022-07-05 17:00:00	2022-07-05 18:00:00	\N	\N	1	0	\N	\N
647522	QUESTURE	AUCUNE	\N	\N	\N	Réunion de Questure	Réunion de Questure	2022-07-07 10:15:00	2022-07-07 12:00:00	\N	\N	3	0	\N	\N
655285	COM_EURO	AUDRAP	\N	AFEU	\N	Audition devoir de vigilance	\N	2022-05-25 10:00:00	2022-05-25 11:00:00	\N	\N	3	0	\N	\N
655289	COM_EURO	AUDRAP	\N	AFEU	\N	Audition devoir de vigilance	\N	2022-06-09 09:00:00	2022-06-09 12:00:00	\N	\N	3	0	\N	\N
655293	COM_EURO	AUDRAP	\N	AFEU	\N	Audition devoir de vigilance	\N	2022-06-10 09:00:00	2022-06-10 11:00:00	\N	\N	3	0	\N	\N
655297	COM_EURO	AUDRAP	\N	AFEU	\N	Audition directive travailleurs de plateformes	\N	2022-05-20 14:00:00	2022-05-20 16:00:00	\N	\N	2	0	\N	\N
655300	COM_EURO	AUDRAP	\N	AFEU	\N	Audition directive travailleurs de plateformes	\N	2022-05-05 14:00:00	2022-05-05 16:00:00	\N	\N	2	0	\N	\N
655303	COM_EURO	AUDRAP	\N	AFEU	\N	Audition directive travailleurs de plateformes	\N	2022-05-10 09:30:00	2022-05-10 10:30:00	\N	\N	2	0	\N	\N
655306	COM_EURO	AUDRAP	\N	AFEU	\N	Audition directive travailleurs de plateformes	\N	2022-05-17 09:00:00	2022-05-17 10:00:00	\N	\N	2	0	\N	\N
655309	COM_EURO	AUDRAP	\N	AFEU	\N	Auditions directive travailleurs plateformes	\N	2022-06-07 09:00:00	2022-06-07 11:00:00	\N	\N	2	0	\N	\N
655312	COM_EURO	AUDRAP	\N	AFEU	\N	Auditions directive travailleurs de plateformes	\N	2022-06-10 10:00:00	2022-06-10 12:00:00	\N	\N	2	0	\N	\N
655315	COM_EURO	AUDRAP	\N	AFEU	\N	Audition directives travailleurs de plateformes	\N	2022-06-13 09:00:00	2022-06-13 11:00:00	\N	\N	2	0	\N	\N
655318	COM_EURO	AUDRAP	\N	AFEU	\N	Audition directive travailleurs de plateformes	\N	2022-06-13 13:00:00	2022-06-13 14:00:00	\N	\N	2	0	\N	\N
655321	COM_EURO	AUDRAP	\N	AFEU	\N	Intelligence artificielle	\N	2022-06-03 10:00:00	2022-06-03 11:30:00	\N	\N	1	0	\N	\N
655323	COM_EURO	AUDRAP	\N	AFEU	\N	Intelligence artificielle	\N	2022-06-15 09:00:00	2022-06-15 10:00:00	\N	\N	3	0	\N	\N
655327	COM_EURO	AUDRAP	\N	AFEU	\N	Auditions Boussole numérique	\N	2022-05-04 14:30:00	2022-05-04 17:30:00	\N	\N	2	0	\N	\N
655330	COM_EURO	AUDRAP	\N	AFEU	\N	Audition boussole numérique	\N	2022-05-06 11:30:00	2022-05-06 12:30:00	\N	\N	2	0	\N	\N
655333	COM_EURO	AUDRAP	\N	AFEU	\N	Audition boussole numérique	\N	2022-05-19 11:30:00	2022-05-19 13:30:00	\N	\N	2	0	\N	\N
655336	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Boussole numérique	\N	2022-05-23 18:00:00	2022-05-23 19:00:00	\N	\N	2	0	\N	\N
656265	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Rapporteur PJL Maché du travail - Auteurs de la note repenser l'assurance chômage	\N	2022-09-27 10:00:00	2022-09-27 11:00:00	\N	\N	3	0	\N	\N
656266	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteurs PJL Marché du travail - Auteurs rapport sur la VAE	\N	2022-09-27 11:00:00	2022-09-27 12:00:00	\N	\N	3	0	\N	\N
656267	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteurs PJL Marché du travail - MEDEF	\N	2022-09-27 14:30:00	2022-09-27 15:15:00	\N	\N	3	0	\N	\N
656268	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteurs PJL Marché du travail - Urssaf caisse nationale	\N	2022-09-27 15:30:00	2022-09-27 16:15:00	\N	\N	3	0	\N	\N
656269	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteurs PJL Marché du travail - Knauf industries	\N	2022-09-27 16:30:00	2022-09-27 17:30:00	\N	\N	3	0	\N	\N
656270	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteurs PJL Marché du travail - Table rondes de représentants industrie	\N	2022-09-27 17:30:00	2022-09-27 19:00:00	\N	\N	5	0	\N	\N
656271	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteurs PJL Marché du travail - CPME	\N	2022-09-28 18:45:00	2022-09-28 19:30:00	\N	\N	3	0	\N	\N
656272	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions MM. Laurent Duplomb, Pierre Louault et Serge Mérillou	\N	2022-09-20 14:00:00	2022-09-20 16:00:00	\N	\N	3	0	\N	\N
656285	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur PPL Aide victimes violences conjugales	\N	2022-09-28 15:00:00	2022-09-28 16:00:00	\N	\N	1	0	\N	\N
661914	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2023 création	\N	2022-10-17 10:50:00	2022-10-17 11:20:00	\N	\N	3	0	\N	\N
661918	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	plf 2023 création	\N	2022-10-17 11:30:00	2022-10-17 12:50:00	\N	\N	4	0	\N	\N
661923	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2023 création	\N	2022-10-17 14:30:00	2022-10-17 15:15:00	\N	\N	3	0	\N	\N
661927	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	plf 2023 création	\N	2022-10-17 15:15:00	2022-10-17 16:00:00	\N	\N	3	0	\N	\N
661933	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	plf 2023 création	\N	2022-10-17 16:00:00	2022-10-17 16:45:00	\N	\N	3	0	\N	\N
661937	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2023 création	\N	2022-10-17 16:45:00	2022-10-17 17:45:00	\N	\N	3	0	\N	\N
662021	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition Agnès Pannier-Runacher	\N	2022-10-19 16:35:00	2022-10-19 19:30:00	2022-10-20 14:59:23	2022-10-20 17:44:38	66	1	\N	\N
662022	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Audition MCC ZAN	\N	2022-10-12 17:30:00	2022-10-12 18:30:00	\N	\N	0	0	\N	\N
662440	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2023 - Famille - Audition rapporteur	\N	2022-10-18 09:00:00	2022-10-18 09:45:00	\N	\N	2	0	\N	\N
743950	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de M. Vincenzo Salvetti	Audition de M. Vincenzo Salvetti	2023-06-21 09:30:00	2023-06-21 11:20:00	2023-06-21 11:42:47	2023-06-21 14:42:39	24	0	\N	\N
744711	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Renforcer la protection des familles d'enfants malades - Table ronde associations	\N	2023-06-20 14:15:00	2023-06-20 15:45:00	\N	\N	3	0	\N	\N
744712	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Renforcer la protection des familles d'enfants malades - Audition conjointe DSS-DGT	\N	2023-06-20 15:45:00	2023-06-20 17:00:00	\N	\N	3	0	\N	\N
744713	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Renforcer la protection des familles d'enfants malades - Audition de la CNAF	\N	2023-06-20 18:15:00	2023-06-20 19:00:00	\N	\N	3	0	\N	\N
745585	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Approbation des comptes de la sécurité sociale pour l'année 2022 - Audition de la CNAF	\N	2023-06-21 16:30:00	2023-06-21 17:30:00	\N	\N	3	0	\N	\N
746959	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Cour des comptes - IA	\N	2023-07-05 09:30:00	2023-07-05 11:05:00	2023-07-05 11:26:07	2023-07-05 18:21:44	22	0	\N	\N
747221	ETUDES	AUTRE	\N	\N	\N	Audition des auteurs du rapport sur les TND	\N	2023-06-28 14:00:00	2023-06-28 15:00:00	\N	\N	7	0	\N	1014
747231	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition pap Ndiaye	\N	2023-07-04 17:30:00	2023-07-04 19:10:00	2023-07-04 19:09:40	2023-07-05 18:21:46	30	0	\N	\N
747512	COM_EURO	AUDRAP	\N	AFEU	\N	Auditions Elargissement de l'UE - Bruxelles	Auditions Elargissement de l'UE - Bruxelles	2023-06-27 08:00:00	2023-06-27 15:30:00	\N	\N	2	0	\N	\N
747513	MISSION	AUCUNE	\N	BATI	\N	Présentation du rapport	\N	2023-06-28 16:30:00	2023-06-28 18:00:00	2023-06-29 17:41:46	2023-06-29 19:25:42	9	0	\N	\N
747517	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Cybersolidarité - Anssi	Audition Cybersolidarité - Anssi	2023-06-27 14:00:00	2023-06-27 15:00:00	\N	\N	1	0	\N	\N
747532	MISSION	AUCUNE	\N	GEAU	\N	Audition du ministre de la Transition écologique	\N	2023-06-28 16:30:00	2023-06-28 18:00:00	2023-06-29 14:39:19	2023-06-29 19:25:42	10	0	\N	\N
744705	COM_PERMANENTE	AUTRE	\N	CAE	\N	PPL Indices locatifs (nouvelle lecture)	\N	2023-06-21 11:35:00	2023-06-21 11:50:00	2023-06-21 11:53:46	2023-06-21 14:42:40	38	5	\N	\N
747534	COM_SPECIALE	PLENIERE	\N	CZAN	\N	Désignation CMP	\N	2023-06-28 16:30:00	2023-06-28 17:30:00	2023-06-28 18:21:19	2023-06-29 14:31:11	14	0	\N	\N
750752	GIA	AUCUNE	\N	\N	\N	Entretien avec l'AFD	Entretien avec MM. Bruno LECLERC et Benjamin NEUMANN, de la Direction régionale Grand Sahel de l'AFD	2023-07-12 08:30:00	2023-07-12 09:45:00	\N	\N	1	0	573	\N
750766	GIA	AUCUNE	\N	\N	\N	Entretien avec Mme Laurence Beau, ambassadrice  	Entretien avec Mme Laurence Beau, ambassadrice accréditée auprès des Iles Cook et de Samoa	2023-07-07 08:30:00	2023-07-07 10:00:00	\N	\N	3	0	651	\N
750968	BUREAU	AUCUNE	\N	\N	\N	Réunion du Bureau	Réunion du Bureau	2023-07-12 08:05:00	2023-07-12 11:15:00	\N	\N	23	0	\N	\N
751727	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Données de connexion	MI Données de connexion	2023-07-12 14:30:00	2023-07-12 15:30:00	\N	\N	2	0	\N	\N
751731	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Données de connexion	MI Données de connexion	2023-07-13 09:30:00	2023-07-13 11:30:00	\N	\N	3	0	\N	\N
751735	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Données de connexion	MI Données de connexion	2023-07-13 14:00:00	2023-07-13 17:00:00	\N	\N	3	0	\N	\N
751739	GIA	AUCUNE	\N	\N	\N	Audition Antoine Bondaz	Audition Antoine Bondaz	2023-07-12 18:00:00	2023-07-12 19:30:00	\N	\N	5	0	623	\N
752201	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE 62 - Contrôle De LEGGE - Service santé des armées	PLENIERE 62 - Contrôle De LEGGE - Service santé des armées	2023-09-27 16:05:00	2023-09-27 16:45:00	2023-09-27 18:47:31	\N	12	0	\N	\N
752253	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE 61 - Audition M. MOSCOVICI HCFP sur le PLF/PLFSS pour 2024 et PLPFP	PLENIERE 61 - Audition M. MOSCOVICI HCFP sur le PLF/PLFSS pour 2024 et PLPFP	2023-09-27 09:15:00	2023-09-27 10:30:00	2023-09-27 13:19:51	\N	30	0	\N	\N
752291	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	Réunion GT subsidiarité	Réunion GT subsidiarité	2023-09-27 09:00:00	2023-09-27 09:20:00	\N	\N	3	0	\N	\N
752327	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE 63 - Audition LE MAIRE/CAZENEUVE PLF	PLENIERE 63 - Audition LE MAIRE/CAZENEUVE PLF	2023-09-27 17:05:00	2023-09-27 18:30:00	2023-09-28 10:35:08	\N	23	0	\N	\N
752380	COM_PERMANENTE	AUDRAP	\N	CAE	\N	USH	\N	2023-09-22 14:30:00	2023-09-22 15:30:00	\N	\N	1	0	\N	\N
752382	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Cabinet du ministre / DHUP	Cabinet du ministre / DHUP	2023-09-22 15:30:00	2023-09-22 16:30:00	\N	\N	1	0	\N	\N
752384	COM_PERMANENTE	AUDRAP	\N	CAE	\N	TR asso d'élus	TR asso d'élus	2023-09-25 12:15:00	2023-09-25 13:15:00	\N	\N	1	0	\N	\N
752386	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Constitution Bureau - PJL-PJLO Justice (désignation CMP) - PPL Sécurité des élus (rapport)	Constitution Bureau - PJL-PJLO Justice (désignation CMP) - PPL Sécurité des élus (rapport)	2023-10-05 09:30:00	2023-10-05 11:40:00	2023-10-05 17:16:52	2023-10-05 17:17:15	48	3	\N	\N
752387	COM_SPECIALE	PLENIERE	\N	ESNU	\N	Réunion constitutive - Désignation CMP	Réunion constitutive - Désignation CMP	2023-10-05 16:15:00	2023-10-05 16:35:00	2023-10-05 19:18:39	2023-10-06 16:03:54	13	0	\N	\N
756449	GIA	AUCUNE	\N	\N	\N	Cérémonie de remise de décoration à M. Philippe Mouiller par le Président de Mongolie	Cérémonie de remise de la décoration de l'Etoile polaire à M. Philippe Mouiller par le Président de Mongolie	2023-10-13 10:00:00	2023-10-13 11:00:00	\N	\N	2	0	612	\N
756453	GIA	AUCUNE	\N	\N	\N	Concert de l'ensemble Morin Khuur à l'Opéra royal de Versailles	Concert de l'ensemble Morin Khuur à l'Opéra royal de Versailles	2023-10-10 19:30:00	2023-10-10 22:30:00	\N	\N	3	0	612	\N
756454	GIA	AUCUNE	\N	\N	\N	Inauguration de l'exposition "Gengis Khan" au château des Ducs de Bretagne à Nantes	Inauguration de l'exposition "Gengis Khan" au château des Ducs de Bretagne à Nantes	2023-10-13 19:00:00	2023-10-13 21:15:00	\N	\N	1	0	612	\N
761709	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Immigration et intégration	PJL Immigration et intégration	2023-11-06 16:00:00	2023-11-06 20:00:00	\N	\N	140	0	\N	\N
761710	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Immigration et intégration	PPL Immigration et intégration	2023-11-06 21:30:00	2023-11-07 01:05:00	\N	\N	133	0	\N	\N
761711	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Immigration et intégration	PPL Immigration et intégration	2023-11-07 14:30:00	2023-11-07 20:10:00	\N	\N	237	0	\N	\N
761712	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Immigration et intégration	PPL Immigration et intégration	2023-11-07 21:40:00	2023-11-08 00:50:00	\N	\N	171	0	\N	\N
761713	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2023-11-08 15:00:00	2023-11-08 16:15:00	\N	\N	298	0	\N	\N
761714	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Immigration et intégration	PPL Immigration et intégration	2023-11-08 16:30:00	2023-11-08 20:00:00	\N	\N	191	0	\N	\N
761715	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Immigration et intégration	PPL Immigration et intégration	2023-11-08 21:30:00	2023-11-09 01:50:00	\N	\N	157	0	\N	\N
761716	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PJL Plein emploi	CMP PJL Plein emploi	2023-11-09 11:00:00	2023-11-09 12:00:00	\N	\N	45	0	\N	\N
761717	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PJL Lutte contre l'inflation	CMP PJL Lutte contre l'inflation	2023-11-09 12:00:00	2023-11-09 12:55:00	\N	\N	41	0	\N	\N
761718	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Immigration et intégration	PPL Immigration et intégration	2023-11-09 14:30:00	2023-11-09 20:10:00	\N	\N	114	0	\N	\N
761719	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Immigration et intégration	PPL Immigration et intégration	2023-11-09 21:40:00	2023-11-10 00:25:00	\N	\N	77	0	\N	\N
761720	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Immigration et intégration	PPL Immigration et intégration	2023-11-10 09:30:00	2023-11-10 12:30:00	\N	\N	55	0	\N	\N
761721	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Immigration et intégration	PPL Immigration et intégration	2023-11-10 13:45:00	2023-11-10 16:30:00	\N	\N	52	0	\N	\N
761741	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Duffourg	\N	2023-10-31 14:45:00	2023-10-31 15:30:00	\N	\N	1	0	\N	\N
761743	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition M. Duffourg	\N	2023-11-02 14:00:00	2023-11-02 14:45:00	\N	\N	1	0	\N	\N
761745	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 8 novembre 2023	\N	2023-11-08 13:30:00	2023-11-08 14:40:00	2023-11-08 17:54:44	2023-11-10 14:28:37	19	0	\N	\N
761746	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 9 novembre 2023	Élargissement de l'Union européenne - Audition du commissaire Varhelyi	2023-11-09 09:40:00	2023-11-09 10:55:00	2023-11-09 11:30:30	2023-11-10 14:28:37	17	0	\N	\N
761748	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions	\N	2023-11-03 10:00:00	2023-11-03 12:00:00	\N	\N	2	0	\N	\N
761751	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions MM. Duplomb, Menonville et Tissot	Auditions MM. Duplomb, Menonville et Tissot	2023-11-03 16:00:00	2023-11-03 18:00:00	\N	\N	1	0	\N	\N
641119	MISSION	AUDRAP	\N	RECHINNO	\N	Didier Pagnoux, Segula Technologies	Didier Pagnoux, Segula Technologies	2022-04-04 16:00:00	2022-04-04 16:45:00	\N	\N	2	0	\N	\N
641122	MISSION	AUCUNE	\N	RECHINNO	\N	Auditions plénières	Auditions plénières	2022-04-06 14:30:00	2022-04-06 17:30:00	2022-04-11 17:50:31	2022-05-09 16:20:29	5	0	\N	\N
641130	MISSION	AUDRAP	\N	RECHINNO	\N	Auditions rapporteur	Auditions rapporteur	2022-04-06 09:45:00	2022-04-06 12:10:00	\N	\N	4	0	\N	\N
761754	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur	\N	2023-10-26 16:05:00	2023-10-26 16:55:00	\N	\N	0	0	\N	\N
761747	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion CATDD	\N	2023-11-08 09:30:00	2023-11-08 10:20:00	2023-11-08 17:37:14	2023-11-08 17:48:08	40	2	\N	\N
641765	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	Commission d'Apuration des Comptes	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne	2020-04-26 15:00:00	2020-04-26 16:00:00	\N	\N	0	0	\N	\N
641766	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne	2022-04-26 15:00:00	2022-04-26 16:00:00	2022-04-26 16:29:36	2022-04-27 18:43:44	9	0	\N	\N
642882	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2022-05-11 08:30:00	2022-05-11 10:25:00	\N	\N	3	0	\N	\N
645125	GIA	AUCUNE	\N	\N	\N	Coopé - Visite d'auditeurs africains dans le cadre du FICA 2022	Coopé - Visite d'auditeurs africains dans le cadre du 22e Forum International sur le Continent Africain (FICA)	2022-06-16 14:30:00	2022-06-16 15:30:00	\N	\N	1	0	573	\N
645127	GIA	AUCUNE	\N	\N	\N	Coopé - Entretien avec Mme Sheila DAVID, vice-présidente d'une fondation familiale (SOICO)	Coopé - Entretien avec Mme Sheila DAVID, vice-présidente d'une fondation familiale (SOICO)	2022-06-16 12:50:00	2022-06-16 14:30:00	\N	\N	1	0	622	\N
645134	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2022 - Contrats Etat collectivités lutte contre la pauvreté - Déplacement Bobigny	Contrôle 2022 - Contrats Etat collectivités lutte contre la pauvreté - Déplacement Bobigny	2022-06-14 14:00:00	2022-06-14 18:30:00	\N	\N	1	0	\N	\N
646102	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MCC Délinquance des mineurs	MCC Délinquance des mineurs	2022-06-30 09:00:00	2022-06-30 11:00:00	\N	\N	5	0	\N	\N
646248	COM_PERMANENTE	AUTRE	\N	CAE	\N	Examen du rapport d'information sur la souveraineté économique	\N	2022-07-06 09:30:00	2022-07-06 12:00:00	2022-07-06 12:27:14	2022-07-06 16:05:11	47	1	\N	\N
646251	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Auditions Allemagne et Belgique	\N	2022-07-01 16:00:00	2022-07-01 18:05:00	\N	\N	0	0	\N	\N
646259	COM_EURO	AUDRAP	\N	AFEU	\N	Procédures judiciaires manifestement infondées ou abusives	\N	2022-06-22 14:30:00	2022-06-22 15:30:00	\N	\N	0	0	\N	\N
646262	COM_EURO	AUTRE	\N	AFEU	\N	réunion du 21 juin 2022	\N	2022-06-21 16:00:00	2022-06-21 17:00:00	\N	\N	0	0	\N	\N
656057	GIA	AUCUNE	\N	\N	\N	Entretien avec une délégation de l'Assemblée nationale de Côte d'Ivoire 	Entretien avec une délégation de l'Assemblée naitonale de Côte d'Ivoire 	2022-09-21 17:00:00	2022-09-21 18:10:00	\N	\N	5	0	573	\N
656116	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Intervention des cabinets privés	\N	2022-09-21 17:30:00	2022-09-21 18:00:00	\N	\N	1	0	\N	\N
683292	QUESTURE	AUCUNE	\N	\N	\N	Réunion de Questure	Réunion de Questure	2022-11-24 09:00:00	2022-11-24 10:45:00	\N	\N	3	0	\N	\N
688665	GIA	AUCUNE	\N	\N	\N	Déjeuner avec une délégation de la Chambre des Conseillers du Maroc	Déjeuner avec une délégation de la Chambre des Conseillers du Maroc	2022-12-14 13:00:00	2022-12-14 14:30:00	\N	\N	24	0	598	\N
688690	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation de la Chambre des Conseillers du Maroc	Accueil d'une délégation de la Chambre des Conseillers du Maroc	2022-12-14 12:00:00	2022-12-16 18:00:00	\N	\N	1	0	598	\N
692427	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL JO 2024	PJL JO 2024	2023-01-24 15:55:00	2023-01-24 20:00:00	\N	\N	143	0	\N	\N
692428	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL JO 2024	PJL JO 2024	2023-01-24 21:30:00	2023-01-24 23:55:00	\N	\N	73	0	\N	\N
692429	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2023-01-25 15:00:00	2023-01-25 16:20:00	\N	\N	286	0	\N	\N
692430	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	3 conventions internationales	3 conventions internationales	2023-01-25 16:30:00	2023-01-25 16:35:00	\N	\N	0	0	\N	\N
692431	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL JO 2024	PJL JO 2024	2023-01-25 16:35:00	2023-01-25 18:10:00	\N	\N	82	0	\N	\N
692529	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-01-24 09:30:00	2023-01-24 09:45:00	2023-01-24 09:48:56	2023-01-24 10:19:42	17	0	\N	\N
692532	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-01-25 09:00:00	2023-01-25 10:20:00	2023-01-25 10:19:45	2023-01-25 16:22:57	37	0	\N	\N
692535	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-01-25 17:30:00	2023-01-25 19:20:00	2023-01-25 19:18:51	2023-01-26 09:58:50	27	0	\N	\N
692638	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	1801	\N	\N	Explications de vote PJL Installations nucléaires	Explications de vote PJL Installations nucléaires	2023-01-24 14:30:00	2023-01-24 15:40:00	\N	\N	281	0	\N	\N
693376	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Mme Loisier	\N	2023-01-19 09:00:00	2023-01-19 10:30:00	\N	\N	2	0	\N	\N
693379	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Mme Loisier	\N	2023-01-24 15:30:00	2023-01-24 16:15:00	\N	\N	1	0	\N	\N
693393	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2023-02-01 16:35:00	2023-02-01 18:35:00	2023-02-01 19:00:45	2023-02-02 15:51:42	20	0	\N	\N
693394	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2023-02-01 09:20:00	2023-02-01 10:30:00	2023-02-09 11:03:24	2023-02-09 11:30:29	30	0	\N	\N
694051	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Réunion constitutive	\N	2023-01-25 16:30:00	2023-01-25 18:30:00	\N	\N	0	0	\N	\N
694085	COM_ENQUETE	PLENIERE	\N	RENOV	\N	Réunion constitutive	\N	2023-01-25 16:30:00	2023-01-25 17:10:00	2023-01-25 17:24:40	2023-01-26 09:59:15	14	0	\N	\N
694652	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audiiton de MM. CHARPY,  PERRIN et Mme SIMONET	Audiiton de MM. CHARPY,  PERRIN et Mme SIMONET	2023-01-25 16:35:00	2023-01-25 18:40:00	2023-01-26 09:53:43	2023-01-26 17:51:33	19	0	\N	\N
694942	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PAC Agence européenne de garde-frontières et de garde-côtes	Audition rapporteur - PPRE Frontex	2023-01-26 11:00:00	2023-01-26 12:00:00	\N	\N	4	0	\N	\N
695185	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI LPM programme 144	MI LPM programme 144	2023-01-24 17:25:00	2023-01-24 18:30:00	\N	\N	2	0	\N	\N
695188	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI LPM programme 144	MI LPM programme 144	2023-01-24 17:45:00	2023-01-24 18:30:00	\N	\N	2	0	\N	\N
692533	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-01-25 10:20:00	2023-01-25 12:00:00	2023-01-25 12:03:27	2023-01-25 16:22:49	39	0	\N	\N
692966	COM_PERMANENTE	AUTRE	\N	FINC	\N	pleniere - 04	\N	2023-01-25 09:00:00	2023-01-25 11:00:00	2023-01-25 11:48:39	2023-01-25 16:22:56	42	0	\N	\N
695215	COM_PERMANENTE	AUTRE	\N	CAE	\N	Examen amendements de séance PPL Bas Chablais	\N	2023-01-31 14:15:00	2023-01-31 14:20:00	2023-01-31 14:26:25	2023-02-01 11:49:09	21	1	\N	\N
695217	COM_PERMANENTE	AUTRE	\N	CAE	\N	Présentation de la PPL ZAN	\N	2023-02-01 09:00:00	2023-02-01 10:45:00	2023-02-01 10:57:43	2023-02-01 11:49:12	37	0	\N	\N
695332	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2023-02-08 10:36:00	2023-02-08 12:18:00	2023-02-08 14:28:27	2023-02-09 11:07:23	43	1	\N	\N
695536	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	MI BIOCARBURANTS 1 - CONSTITUTIVE	\N	2023-01-31 17:30:00	2023-01-31 19:00:00	\N	\N	0	0	\N	\N
695538	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	MI BIOCARBURANTS 1 - CONSTITUTIVE	\N	2023-01-31 17:30:00	2023-01-31 19:00:00	\N	\N	0	0	\N	\N
695557	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI cinéma	\N	2023-01-31 09:00:00	2023-01-31 10:00:00	\N	\N	3	0	\N	\N
695563	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI cinéma	\N	2023-01-31 10:00:00	2023-01-31 11:00:00	\N	\N	4	0	\N	\N
699061	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2023-01-18 18:05:00	2023-01-18 19:00:00	\N	\N	27	0	\N	\N
746014	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Examen amendements de séance sur PPL Programmation militaire	\N	2023-06-27 09:00:00	2023-06-27 11:05:00	\N	\N	29	6	\N	\N
746015	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Suite examen amendements de séance sur PPL programmation militaire	\N	2023-06-27 13:30:00	2023-06-27 14:30:00	\N	\N	0	0	\N	\N
746733	ETUDES	AUCUNE	\N	\N	\N	Audition de M. Arnaud Montebourg sur la filière Amandes	Audition de M. Arnaud Montebourg sur la filière Amandes	2023-06-28 08:00:00	2023-06-28 10:00:00	\N	\N	14	0	\N	1005
753644	GIA	AUCUNE	\N	\N	\N	Fête nationale de Taïwan	\N	2023-10-04 18:30:00	2023-10-04 21:30:00	\N	\N	0	0	623	\N
757833	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Table ronde chefs d'établissement (SGEN-CFDT, SNPDEN-UNSA, ID-FO)	\N	2023-10-23 17:40:00	2023-10-23 19:10:00	\N	\N	8	0	\N	\N
757834	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Radio France	\N	2023-10-24 14:30:00	2023-10-24 15:30:00	\N	\N	0	0	\N	\N
757835	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Arte France	\N	2023-11-02 15:00:00	2023-11-02 16:00:00	\N	\N	1	0	\N	\N
760426	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunon plénière	\N	2023-10-25 19:55:00	2023-10-25 20:05:00	2023-10-26 18:55:26	2023-10-27 19:04:01	19	0	\N	\N
760442	DELEGATION	AUCUNE	\N	\N	COLTER	Désignation de rapporteurs	\N	2023-10-26 08:25:00	2023-10-26 08:30:00	2023-10-26 09:21:11	\N	18	0	\N	\N
760484	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2024 Autonomie - Audition de la DGCS	\N	2023-10-25 19:00:00	2023-10-25 20:00:00	\N	\N	2	0	\N	\N
760490	DELEGATION	AUCUNE	\N	\N	206	Audition de la CNE2	\N	2023-10-26 09:40:00	2023-10-26 11:05:00	\N	\N	10	0	\N	\N
760507	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2024 - Audition Agirc-Arrco	\N	2023-10-25 16:45:00	2023-10-25 17:45:00	\N	\N	4	0	\N	\N
760508	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2024 - Audition CPSTI-FNAE	\N	2023-10-25 17:45:00	2023-10-25 19:00:00	\N	\N	3	0	\N	\N
760515	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	GT subsidiarité du 26 octobre	\N	2023-10-26 08:30:00	2023-10-26 08:45:00	\N	\N	5	0	\N	\N
760560	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Éden	Audition Éden	2023-10-24 09:30:00	2023-10-24 10:00:00	\N	\N	3	0	\N	\N
760561	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Electricité de France	Audition Electricité de France	2023-10-24 14:00:00	2023-10-24 14:45:00	\N	\N	4	0	\N	\N
760562	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Agence de la transition écologique	Audition Agence de la transition écologique	2023-10-24 14:45:00	2023-10-24 15:30:00	\N	\N	4	0	\N	\N
760564	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition France gaz	Audition France gaz	2023-10-24 15:30:00	2023-10-24 16:00:00	\N	\N	4	0	\N	\N
760565	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition France hydrogène	Audition France hydrogène	2023-10-24 16:00:00	2023-10-24 16:30:00	\N	\N	4	0	\N	\N
760566	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Syndicat des énergies renouvelables	Audition Syndicat des énergies renouvelables	2023-10-24 16:30:00	2023-10-24 17:15:00	\N	\N	4	0	\N	\N
760568	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Autorité de sûreté nucléaire	Audition Autorité de sûreté nucléaire	2023-10-24 19:00:00	2023-10-24 19:30:00	\N	\N	1	0	\N	\N
760569	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Institut de radioprotection et de sûreté nucléaire	Audition Institut de radioprotection et de sûreté nucléaire	2023-10-24 19:30:00	2023-10-24 20:00:00	\N	\N	1	0	\N	\N
760609	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition UFE	Audition UFE	2023-10-25 17:00:00	2023-10-25 17:30:00	\N	\N	1	0	\N	\N
765756	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Cohésion territoires - Audition M. BRUNOT et Mme STOLL, DGCL	PLF pour 2024 - Cohésion territoires - Audition M. BRUNOT et Mme STOLL, DGCL	2023-11-09 08:30:00	2023-11-09 09:15:00	\N	\N	1	0	\N	\N
765759	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Cohésion territoires - Audition du cabinet de Mme D. FAURE	PLF pour 2024 - Cohésion territoires - Audition du cabinet de Mme D. FAURE	2023-11-09 10:45:00	2023-11-09 11:30:00	\N	\N	1	0	\N	\N
765762	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Cohésion territoriale - Audition de la MTFP	PLF pour 2024 - Cohésion territoriale - Audition du cabinet du ministre de la transformation et de la fonction publiques	2023-11-09 11:30:00	2023-11-09 12:15:00	\N	\N	1	0	\N	\N
765765	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Cohésion territoires - Audition de la DMAT	PLF pour 2024 - Cohésion territoires - Audition de la sous-direction de l'administration territoriale de  la Direction d	2023-11-09 18:30:00	2023-11-09 19:15:00	\N	\N	1	0	\N	\N
765767	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Cohésion territoires - Audition de M. BOURRON, ANCT	PLF pour 2024 - Cohésion territoires - Audition de M. BOURRON, Agence nationale de la cohésion des territoires (ANCT) 	2023-11-09 20:45:00	2023-11-09 22:00:00	\N	\N	1	0	\N	\N
765790	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - APD - Audition conjointe du MAEA et secrétariat d'état au développement	PLF pour 2024 - APD - Audition conjointe du MAEA et secrétariat d'état au développement	2023-11-07 14:00:00	2023-11-07 15:00:00	\N	\N	2	0	\N	\N
765808	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - APD - Audition de Mme SENAYA, direction générale du trésor	PLF pour 2024 - APD - Audition de Mme SENAYA, direction générale du trésor	2023-11-07 15:00:00	2023-11-07 16:00:00	\N	\N	2	0	\N	\N
765812	COM_EURO	AUDRAP	\N	AFEU	\N	Auditions	\N	2023-11-13 09:30:00	2023-11-13 18:15:00	\N	\N	3	0	\N	\N
765814	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - APD - Audition de la direction générale de la mondialisation	PLF pour 2024 - APD - Audition de M. LECHEVALLIER, direction générale de la mondialisation	2023-11-07 16:00:00	2023-11-07 17:00:00	\N	\N	2	0	\N	\N
765821	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - APD - Audition de l'agence française de développement	PLF pour 2024 - APD - Audition de MM. RIOUX et BAUMEL, agence française de développement	2023-11-07 17:00:00	2023-11-07 18:00:00	\N	\N	0	0	\N	\N
761755	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur	\N	2023-10-26 17:00:00	2023-10-26 18:45:00	\N	\N	0	0	\N	\N
765753	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Avis budgétaire et examen amdts extérieurs PPL culture citoyenne	\N	2023-11-22 09:05:00	2023-11-22 12:00:00	2023-11-22 12:22:18	2023-11-22 17:39:13	41	11	\N	\N
765834	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Sécurité civile - Audition de Départements de France	PLF pour 2024 - Sécurité civile - Audition de MM. ACCARY et ESTACHY, départements de France	2023-10-24 08:30:00	2023-10-24 09:15:00	\N	\N	1	0	\N	\N
765836	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Sécurité civile - Audition de M. FLORES, FNSPF	PLF pour 2024 - Sécurité civile - Audition de M. FLORES, Fédération nationale des sapeurs-pompiers de France	2023-10-24 09:15:00	2023-10-24 10:00:00	\N	\N	1	0	\N	\N
765844	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL culture citoyenne	\N	2023-11-13 12:30:00	2023-11-13 13:00:00	\N	\N	1	0	\N	\N
765845	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	SMAC Creation	\N	2023-11-13 10:00:00	2023-11-13 11:40:00	\N	\N	2	0	\N	\N
765848	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion CATDD	\N	2023-11-15 16:45:00	2023-11-15 18:25:00	2023-11-15 19:21:43	2023-11-16 18:27:51	26	2	\N	\N
765855	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition Marc Fesneau	\N	2023-11-14 15:50:00	2023-11-14 19:55:00	2023-11-15 08:54:53	2023-11-15 16:11:43	44	0	\N	\N
765862	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MCC signalement et le traitement des pressions, menaces et agressions dont les enseignants	MCC signalement et le traitement des pressions, menaces et agressions dont les enseignants	2023-11-13 16:00:00	2023-11-13 18:40:00	\N	\N	3	0	\N	\N
769084	QUESTURE	AUCUNE	\N	\N	\N	Réunion de Questure	Réunion du Conseil de Questure	2023-11-14 16:00:00	2023-11-14 18:16:00	\N	\N	3	0	\N	\N
638465	GIA	AUCUNE	\N	\N	\N	Entretien avec S. Exc. M. Mauricio VARGAS LINARES, ambassadeur de Colombie en France	Entretien avec S. Exc. M. Mauricio VARGAS LINARES, ambassadeur de Colombie en France	2022-02-23 08:30:00	2022-02-23 10:00:00	\N	\N	4	0	979	\N
638470	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation de l'illinois (représentants du secteur agricole)	Accueil d'une délégation de l'illinois (représentants du secteur agricole)	2022-03-02 10:15:00	2022-03-02 12:30:00	\N	\N	1	0	590	\N
656601	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	MCC 2022 - Audiovisuel Public - Déplacement Ministère de la Culture	MCC 2022 - Audiovisuel Public - Déplacement Ministère de la Culture	2022-09-27 10:25:00	2022-09-27 11:50:00	\N	\N	2	0	\N	\N
662441	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2023 - Famille - Audition rapporteur 	\N	2022-10-19 14:00:00	2022-10-19 15:00:00	\N	\N	2	0	\N	\N
662442	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2023 - Famille - Audition rapporteur	\N	2022-10-20 08:30:00	2022-10-20 09:30:00	\N	\N	1	0	\N	\N
662473	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Médias - CNC	PLF pour 2023 - Médias - CNC	2022-10-17 16:00:00	2022-10-17 17:00:00	\N	\N	1	0	\N	\N
662874	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2023 Enssup	\N	2022-10-18 09:00:00	2022-10-18 11:00:00	\N	\N	1	0	\N	\N
662898	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2023 Patrimoines - Table ronde asso. sauvegarde patrimoine	\N	2022-10-18 09:00:00	2022-10-18 10:30:00	\N	\N	3	0	\N	\N
662900	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2023 Patrimoines	Audition GMH	2022-10-18 11:00:00	2022-10-18 12:45:00	\N	\N	3	0	\N	\N
665381	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Fédération nationale des collectivités territoriales pour la culture 	\N	2022-10-24 10:00:00	2022-10-24 11:00:00	\N	\N	3	0	\N	\N
665445	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2023 - Branche AT-MP Audition de la CATMP	\N	2022-10-25 09:30:00	2022-10-25 10:15:00	\N	\N	2	0	\N	\N
665525	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2023 - Équilibres financiers généraux - Audition Fepem	\N	2022-10-25 10:00:00	2022-10-25 11:00:00	\N	\N	1	0	\N	\N
665540	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2023 - Écologie - SG ENGIE	PLF pour 2023 - Écologie - SG ENGIE	2022-10-25 09:30:00	2022-10-25 11:00:00	\N	\N	2	0	\N	\N
665705	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-10-26 09:35:00	2022-10-26 12:50:00	2022-10-26 14:47:37	2022-10-26 15:10:29	41	0	\N	\N
665741	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Audition d'ONG	\N	2022-10-25 16:00:00	2022-10-25 17:00:00	\N	\N	0	0	\N	\N
665808	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions rapporteur	PLF 2023 - Sécurité civile	2022-10-25 15:15:00	2022-10-25 16:00:00	\N	\N	2	0	\N	\N
665809	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions rapporteur PLF pour 2023	PLF 2023 - Sécurité civile	2022-10-25 14:00:00	2022-10-25 15:15:00	\N	\N	1	0	\N	\N
665814	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition Amélie Oudéa-Castéra	\N	2022-11-02 16:45:00	2022-11-02 18:35:00	2022-11-02 18:48:56	2022-11-03 17:38:02	28	0	\N	\N
665863	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2023 Assurance maladie - Table ronde de syndicats de biologistes	\N	2022-10-25 15:00:00	2022-10-25 16:15:00	\N	\N	2	0	\N	\N
666524	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS pour 2023 - Équilibres financiers généraux	\N	2022-10-26 14:00:00	2022-10-26 15:00:00	\N	\N	3	0	\N	\N
666569	COM_PERMANENTE	AUTRE	\N	CAE	\N	Auditions M. Laurent Duplomb, Mme Françoise Férat et M. Jean-Claude Tissot	Auditions M. Laurent Duplomb, Mme Françoise Férat et M. Jean-Claude Tissot	2022-10-25 15:30:00	2022-10-25 16:15:00	\N	\N	3	0	\N	\N
667535	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	GS Climat	\N	2022-10-26 13:50:00	2022-10-26 15:00:00	\N	\N	5	0	\N	\N
667756	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2023 - p. 185	PLF pour  - p. 185	2022-10-24 11:00:00	2022-10-24 12:10:00	\N	\N	1	0	\N	\N
667758	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2023 - p. 185	PLF pour 2023 - p. 185	2022-10-24 16:00:00	2022-10-24 17:00:00	\N	\N	2	0	\N	\N
667761	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2023 - p. 185	PLF pour 2023 - p. 185	2022-10-27 10:00:00	2022-10-27 12:00:00	\N	\N	1	0	\N	\N
667763	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2023 - p. 185	PLF pour 2023 - p. 185	2022-10-27 16:00:00	2022-10-27 18:30:00	\N	\N	1	0	\N	\N
667765	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2023 - P. 144	PLF pour 2023 - P. 144	2022-10-25 14:00:00	2022-10-25 15:00:00	\N	\N	2	0	\N	\N
667768	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Déplacement à Balard : EMA	Déplacement à Balard : EMA	2022-10-25 08:30:00	2022-10-25 10:30:00	\N	\N	2	0	\N	\N
765846	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion CATDD	\N	2023-11-15 09:05:00	2023-11-15 10:05:00	2023-11-15 13:54:47	2023-11-15 16:11:34	43	6	\N	\N
768940	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PLF pour 2024 - Avis	PLF pour 2024 - Avis	2023-11-22 09:00:00	2023-11-22 11:15:00	2023-11-22 11:36:36	2023-11-22 11:50:37	40	3	\N	\N
665806	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Examen des avis budgétaires Enseignement supérieur et Presse 	\N	2022-11-02 09:30:00	2022-11-02 10:45:00	2022-11-02 11:16:22	2022-11-02 17:47:07	38	6	\N	\N
667771	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Déplacement au Campus Cyber (Puteaux)	Déplacement au Campus Cyber (Puteaux)	2022-10-25 15:00:00	2022-10-25 17:00:00	\N	\N	2	0	\N	\N
667774	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audition Ambassade US	\N	2022-10-27 10:00:00	2022-10-27 11:30:00	\N	\N	1	0	\N	\N
667776	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audition Mme Nathalie Kestener	\N	2022-10-28 10:00:00	2022-10-28 11:00:00	\N	\N	1	0	\N	\N
667778	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audition Ambassade GB	\N	2022-10-28 15:00:00	2022-10-28 16:00:00	\N	\N	1	0	\N	\N
667780	GIA	AUCUNE	\N	\N	\N	Visite des Questeurs de la Chambre des Conseillers du Maroc	Visite des Questeurs de la Chambre des Conseillers du Maroc	2022-10-25 12:30:00	2022-10-25 14:30:00	\N	\N	7	0	598	\N
681247	DELEGATION	AUDRAP	\N	\N	206	Audition de Mme Ducroux	\N	2022-11-28 15:30:00	2022-11-28 17:30:00	\N	\N	1	0	\N	\N
683271	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	mission Écologie, développement et mobilités durables	Mission Ecologie	2022-12-02 21:35:00	2022-12-03 02:05:00	\N	\N	35	0	\N	\N
683273	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL 2L Engrillagement	PPL 2L Engrillagement	2022-12-06 16:50:00	2022-12-06 17:50:00	\N	\N	83	0	\N	\N
683276	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Elections sénatoriales	PPL Elections sénatoriales	2022-12-06 17:55:00	2022-12-06 18:45:00	\N	\N	57	0	\N	\N
695066	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Accès aux soins - Audition de Mme Anne-Caroline Sandeau-Gruber (IGAS)	\N	2023-01-26 09:00:00	2023-01-26 10:15:00	\N	\N	4	0	\N	\N
695067	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Accès aux soins - Table ronde de médecins et d'IPA	\N	2023-01-26 10:15:00	2023-01-26 11:15:00	\N	\N	4	0	\N	\N
695068	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Accès aux soins - Audition de Médecins pour demain	\N	2023-01-26 11:45:00	2023-01-26 12:30:00	\N	\N	4	0	\N	\N
695069	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Accès aux soins - Table ronde de syndicats d'infirmiers	\N	2023-01-26 15:00:00	2023-01-26 16:00:00	\N	\N	2	0	\N	\N
695073	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Accès aux soins - Audition de l'Ordre national des masseurs-kinésithérapeutes	\N	2023-01-26 16:00:00	2023-01-26 16:55:00	\N	\N	2	0	\N	\N
695074	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Accès aux soins - Table ronde de syndicats de masseurs-kinésithérapeutes	\N	2023-01-26 14:00:00	2023-01-26 15:00:00	\N	\N	3	0	\N	\N
695112	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI cinéma	\N	2023-01-25 17:00:00	2023-01-25 18:30:00	\N	\N	4	0	\N	\N
695117	GIA	AUCUNE	\N	\N	\N	Coopé - Visite de M. Vico SOTTO, Maire de la ville de PASIG, aux Philippines	Coopé - Visite de M. Vico SOTTO, Maire de la ville de PASIG, aux Philippines	2023-01-24 12:30:00	2023-01-24 14:00:00	\N	\N	2	0	609	\N
695120	GIA	AUCUNE	\N	\N	\N	Entretien avec Diana POGHOSYAN, étudiante à l'UFAR	Entretien avec Diana POGHOSYAN, étudiante à l'UFAR	2023-01-25 16:30:00	2023-01-25 17:00:00	\N	\N	1	0	641	\N
695142	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition de Mme Chain-Larché	\N	2023-01-26 15:30:00	2023-01-26 17:00:00	\N	\N	1	0	\N	\N
695146	DELEGATION	AUDRAP	\N	\N	PROS	Auditions sur l'exploitation des ressources spatiales	\N	2023-01-25 16:30:00	2023-01-25 19:30:00	\N	\N	2	0	\N	\N
695162	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes du mercredi 1er février 2023	\N	2023-02-01 16:45:00	2023-02-01 18:05:00	2023-02-02 09:27:25	2023-02-02 15:51:26	23	0	\N	\N
695163	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes du jeudi 2 février 2023	\N	2023-02-02 08:35:00	2023-02-02 11:10:00	2023-02-02 11:10:52	2023-02-02 15:51:27	18	0	\N	\N
695210	DELEGATION	AUDRAP	\N	\N	206	Audition M. Gérard	\N	2023-01-26 14:00:00	2023-01-26 16:00:00	\N	\N	2	0	\N	\N
745214	GIA	AUCUNE	\N	\N	\N	Audition de l'ambassadeur de France en Guinée-Bissau	Audition de M. Terence WILLS, Ambassadeur de France en Guinée-Bissau	2023-06-21 14:10:00	2023-06-21 14:50:00	\N	\N	2	0	573	\N
757745	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Avis budgétaire Sport	AFLD	2023-10-18 17:30:00	2023-10-18 18:30:00	\N	\N	1	0	\N	\N
759364	GIA	AUCUNE	\N	\N	\N	Entretien avec S.E. M. Carmelo NVONO-NCA, ambassadeur de Guinée équatoriale à Paris	Entretien avec S.E. M. Carmelo NVONO-NCA, ambassadeur de Guinée équatoriale à Paris	2023-10-24 19:15:00	2023-10-24 22:00:00	\N	\N	1	0	572	\N
765499	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audition mission APD	\N	2023-11-07 14:30:00	2023-11-07 15:30:00	\N	\N	0	0	\N	\N
765500	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 80	\N	2023-11-20 15:00:00	2023-11-20 15:15:00	2023-11-20 16:42:04	2023-11-21 17:07:56	14	5	\N	\N
765502	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audition P178	\N	2023-11-08 16:30:00	2023-11-08 17:30:00	\N	\N	0	0	\N	\N
765503	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audition	\N	2023-11-08 17:30:00	2023-11-08 18:30:00	\N	\N	0	0	\N	\N
765504	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audition P178	\N	2023-11-08 11:00:00	2023-11-08 12:20:00	\N	\N	0	0	\N	\N
765516	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	plf Creation	\N	2023-11-09 10:30:00	2023-11-09 12:30:00	\N	\N	3	0	\N	\N
765611	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF 2024  - Cohésion des territoires - Audition Union sociale pour l'habitat (USH)	PLF 2024  - Cohésion des territoires - Audition Mme LOUIS et MM. CANU et GALEWSKI, Union sociale pour l'habitat (USH)	2023-11-07 14:45:00	2023-11-07 15:45:00	\N	\N	1	0	\N	\N
765613	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF 2024  - Cohésion des territoires - Audition de la Caisse des dépôts et consignations	PLF 2024  - Cohésion des territoires - Audition de la Caisse des dépôts et consignations	2023-11-07 15:45:00	2023-11-07 16:45:00	\N	\N	1	0	\N	\N
765617	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF 2024  - Cohésion territoires - Audition Mme AGRESTI-ROUBACHE, secrét. d'état ville	PLF 2024  - Cohésion des territoires - Audition Mme AGRESTI-ROUBACHE, Secrétaire d'état à la ville	2023-11-08 17:00:00	2023-11-08 18:00:00	\N	\N	1	0	\N	\N
765619	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF 2024  - Cohésion territoires - Audition Agence nationale de l'habitat (ANAH)	PLF 2024  - Cohésion territoires - Audition Mme MANCRET-TAYLOR, Agence nationale de l'habitat (ANAH)	2023-11-08 18:00:00	2023-11-08 18:45:00	\N	\N	1	0	\N	\N
765621	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF 2024  - Cohésion territoires - Audition Fédération des promoteurs immobiliers	PLF 2024  - Cohésion territoires - Audition Fédération des promoteurs immobiliers de France (FPI)	2023-11-08 18:45:00	2023-11-08 19:30:00	\N	\N	1	0	\N	\N
765623	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF 2024  - Cohésion territoires - Audition Direction générale des collectivités locales	PLF 2024  - Cohésion territoires - Audition Direction générale des collectivités locales (DGCL)	2023-11-09 09:00:00	2023-11-09 09:45:00	\N	\N	1	0	\N	\N
765627	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF 2024  - Cohésion territoires - Audition de la Fondation Abbé Pierre	PLF 2024  - Cohésion territoires - Audition de M. DOMERGUE et Mme DERDEK, Fondation Abbé Pierre	2023-11-09 09:45:00	2023-11-09 10:30:00	\N	\N	1	0	\N	\N
765497	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 79	\N	2023-11-15 09:00:00	2023-11-15 12:20:00	2023-11-15 13:45:21	2023-11-15 16:11:35	40	4	\N	\N
765631	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Auditions ¨P. 146	Auditions p. 146	2023-10-24 14:00:00	2023-10-24 15:30:00	\N	\N	2	0	\N	\N
765632	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF 2024  - Justice - Audition de la direction des services judiciaires	PLF 2024  - Justice - Audition de MM. de LESQUEN et LEFORT, direction des services judiciaires	2023-11-09 11:00:00	2023-11-09 12:00:00	\N	\N	1	0	\N	\N
765636	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Déplacement au Stade de France	Déplacement au Stade de France	2023-10-28 10:00:00	2023-10-28 13:00:00	\N	\N	1	0	\N	\N
765638	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Auditions ¨P. 146	Auditions P. 146	2023-11-07 15:00:00	2023-11-07 17:00:00	\N	\N	2	0	\N	\N
765641	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Auditions P. 844-847-848	Auditions P. 844-847-848	2023-10-25 16:45:00	2023-10-25 17:45:00	\N	\N	2	0	\N	\N
765644	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audition P844-847	Auditions P. 844-847	2023-10-26 15:15:00	2023-10-26 18:15:00	\N	\N	2	0	\N	\N
765648	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Auditions P. 212	Auditions P. 212	2023-11-08 14:00:00	2023-11-08 15:00:00	\N	\N	2	0	\N	\N
765651	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Auditions P212	Auditions P. 212	2023-11-08 16:30:00	2023-11-08 18:30:00	\N	\N	1	0	\N	\N
765653	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition M. Tabarot	\N	2023-11-07 09:45:00	2023-11-07 10:30:00	\N	\N	2	0	\N	\N
765656	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition M. TABAROT	\N	2023-11-07 16:30:00	2023-11-07 17:15:00	\N	\N	2	0	\N	\N
765659	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Hervé Gillé	\N	2023-11-06 16:00:00	2023-11-06 18:30:00	\N	\N	1	0	\N	\N
765663	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Ecologie - Audition direction générale énergie et climat	PLF pour 2024 - Ecologie - Auditionde Mme MMOURLON, direction générale énergie et climat	2023-11-06 08:00:00	2023-11-06 09:00:00	\N	\N	1	0	\N	\N
765665	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - BACEA - Audition M. CAZE, direction générale de l'aviation civile	PLF pour 2024 - BACEA - Audition M. CAZE, direction générale de l'aviation civile	2023-11-06 17:00:00	2023-11-06 18:30:00	\N	\N	1	0	\N	\N
765668	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Ecologie Transports - Audition M. FARANDOU, PDG de la SNCF	PLF pour 2024 - Ecologie Transports - Audition M. FARANDOU, PDG de la SNCF	2023-11-07 09:00:00	2023-11-07 10:00:00	\N	\N	2	0	\N	\N
765669	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audition P105	\N	2023-11-07 14:30:00	2023-11-07 15:30:00	\N	\N	0	0	\N	\N
765670	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - BACEA - Audition de la fédération nationale de l'aviation marchande	PLF pour 2024 - BACEA - Audition de M. de IZAGUIRRE, fédération nationale de l'aviation marchande (FNAM)	2023-11-07 17:00:00	2023-11-07 18:00:00	\N	\N	1	0	\N	\N
765672	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audition P212	\N	2023-11-08 17:30:00	2023-11-08 18:30:00	\N	\N	0	0	\N	\N
765673	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Ecologie transports - Audition de M. LEMAIGNEN, GART       	PLF pour 2024 - Ecologie transports - Audition de M. LEMAIGNEN, groupement des autorités responsables de transport	2023-11-08 14:15:00	2023-11-08 15:00:00	\N	\N	2	0	\N	\N
765678	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Ecologie transports - Audition de Mme SAUTEJEAU, UTP	PLF pour 2024 - Ecologie transports - Audition de Mme SAUTEJEAU, union des transports publics et ferroviaires	2023-11-08 16:30:00	2023-11-08 17:15:00	\N	\N	2	0	\N	\N
765681	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Ecologie transports - Audition de Mme LE QUELLENEC, DGAMPA	PLF pour 2024 - Ecologie transports - Audition de Mme LE QUELLENEC, DGAMPA	2023-11-08 17:15:00	2023-11-08 18:00:00	\N	\N	2	0	\N	\N
765684	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Ecologie transports - Audition de la DGITM	PLF pour 2024 - Ecologie transports - Audition de M. COQUIL, DG infrastructures, des transports et de la mer	2023-11-08 18:00:00	2023-11-08 19:00:00	\N	\N	2	0	\N	\N
765687	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - BACEA - Audition Mme COUDERC, Air-France KLM	PLF pour 2024 - BACEA - Audition Mme COUDERC, présidente du directoire du groupe Air-France KLM	2023-11-09 11:00:00	2023-11-09 12:00:00	\N	\N	1	0	\N	\N
765689	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Médias - Audtion du Centre national de la musique	PLF pour 2024 - Médias - Audtion de MM. THIELLAY et LALEIX, Centre national de la musique	2023-11-07 10:00:00	2023-11-07 11:00:00	\N	\N	1	0	\N	\N
765693	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Culture - Audtion de directeurs d'opéras	PLF pour 2024 - Culture - Audtion de directeurs d'opéras	2023-11-07 15:00:00	2023-11-07 16:00:00	\N	\N	2	0	\N	\N
765697	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Culture - Audtion de la DGPA	PLF pour 2024 - Culture - Audtion de MM. HEBERT et ABIVEN, direction générale des Patrimoines et de l¿Architecture	2023-11-07 16:00:00	2023-11-07 17:00:00	\N	\N	2	0	\N	\N
765700	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Médias - Audition du Centre national du cinéma et de l'image animée	PLF pour 2024 - Médias - Audition de MM. HENRARD et VILLETE Centre national du cinéma et de l'image animée (CNC)	2023-11-07 17:30:00	2023-11-07 18:30:00	\N	\N	1	0	\N	\N
638952	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Question migratoire	MI Question migratoire	2022-03-08 10:30:00	2022-03-08 12:30:00	\N	\N	3	0	\N	\N
639985	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI "Reconnaissance faciale"	MI "Reconnaissance faciale" - Auditions	2022-03-22 14:15:00	2022-03-22 16:00:00	\N	\N	4	0	\N	\N
639990	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI "Reconnaissance faciale"	MI "Reconnaissance faciale" - Auditions	2022-03-22 17:00:00	2022-03-22 18:50:00	\N	\N	3	0	\N	\N
640421	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Question migratoire	MI Question migratoire	2022-03-29 09:30:00	2022-03-29 10:30:00	\N	\N	5	0	\N	\N
640427	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Question migratoire	MI Question migratoire	2022-03-29 14:30:00	2022-03-29 15:15:00	\N	\N	3	0	\N	\N
640431	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Question migratoire	MI Question migratoire	2022-03-29 15:30:00	2022-03-29 16:15:00	\N	\N	3	0	\N	\N
640435	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Question migratoire	MI Question migratoire	2022-03-29 16:30:00	2022-03-29 17:30:00	\N	\N	4	0	\N	\N
640440	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Question migratoire	MI Question migratoire	2022-03-29 18:00:00	2022-03-29 19:00:00	\N	\N	2	0	\N	\N
641028	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MCC financement de l'audiovisuel public	MCC financement de l'audiovisuel public	2022-04-07 09:00:00	2022-04-07 10:00:00	\N	\N	2	0	\N	\N
641063	DELEGATION	DEPLACEMENT	\N	\N	206	Sommet Franco-américain sur la pollution plastique	Sommet Franco-américain sur la pollution plastique	2022-04-05 08:00:00	2022-04-06 18:00:00	\N	\N	2	0	\N	\N
643831	GIA	AUCUNE	\N	\N	\N	Déjeuner bicentenaire de l'indépendance de l¿Équateur	Déjeuner bicentenaire de l'indépendance de l¿Équateur	2022-05-24 12:30:00	2022-05-24 14:30:00	\N	\N	4	0	979	\N
645129	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 -  ONACVG - TR associations AC	Contrôle 2022 -  ONACVG - TR associations AC	2022-06-16 15:00:00	2022-06-16 17:40:00	\N	\N	1	0	\N	\N
645131	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2022 - Contrats Etat collectivités lutte contre la pauvreté - Déplacement Bobigny	Contrôle 2022 - Contrats Etat collectivités lutte contre la pauvreté - Déplacement Bobigny	2022-06-14 08:00:00	2022-06-14 12:00:00	\N	\N	2	0	\N	\N
645136	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - Entreprises adaptées - ASP/DARES	Contrôle 2022 - Entreprises adaptées - ASP/DARES	2022-06-15 09:30:00	2022-06-15 10:30:00	\N	\N	1	0	\N	\N
645138	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Obésité - Audition de l'ARS Martinique	\N	2022-06-15 16:00:00	2022-06-15 17:15:00	\N	\N	5	0	\N	\N
645145	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition UEFA	\N	2022-06-21 09:30:00	2022-06-21 10:50:00	2022-06-22 17:34:50	2022-06-23 18:02:42	32	0	\N	\N
645146	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition supporters	\N	2022-06-21 16:30:00	2022-06-21 18:20:00	2022-06-23 16:28:28	2022-06-23 18:02:41	26	0	\N	\N
645147	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition M. Hanotin	\N	2022-06-21 18:30:00	2022-06-21 19:25:00	2022-06-23 16:28:42	2022-06-23 18:02:40	17	0	\N	\N
661799	COM_PERMANENTE	AUTRE	\N	ETRD	\N	PLF2023 - Auditions général Thierry Burkhard et général Pierre Schill	PLF2023 - Auditions général Thierry Burkhard et général Pierre Schill	2022-10-19 09:30:00	2022-10-19 12:50:00	2022-10-25 10:40:26	2022-10-27 14:17:46	34	0	\N	\N
674494	GIA	AUCUNE	\N	\N	\N	Entretien avec les parlementaires U4U	Entretien avec les parlementaires du réseau United for Ukraine	2022-11-08 09:00:00	2022-11-08 10:15:00	\N	\N	2	0	530	\N
674497	GIA	AUCUNE	\N	\N	\N	Entretien avec O. Matviichuk	Entretien avec O. Matviichuk, Presidente du Centre pour les libertés civiles	2022-10-29 12:00:00	2022-10-29 13:30:00	\N	\N	2	0	530	\N
674500	GIA	AUCUNE	\N	\N	\N	Entretien avec Tatiana Jean	Entretien avec Tatiana Jean, Directrice Russie /NEI de l'IFRI	2022-11-09 08:30:00	2022-11-09 10:00:00	\N	\N	8	0	530	\N
674509	GIA	AUCUNE	\N	\N	\N	Conférence avec Eastern Circles	Conférence Ukraine avec Eastern Circles et Diplomatie magazine	2022-11-14 15:00:00	2022-11-14 18:30:00	\N	\N	4	0	530	\N
676088	GIA	AUCUNE	\N	\N	\N	entretien avec S.E. Monsieur  Mohammad ALJUDAIE DOB, ambassadeur du Koweït 	\N	2022-11-17 08:30:00	2022-11-17 09:30:00	\N	\N	2	0	661	\N
688725	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition cour des comptes	\N	2023-01-10 14:30:00	2023-01-10 15:45:00	2023-01-11 15:32:58	2023-01-12 17:25:03	21	0	\N	\N
697967	ETUDES	AUCUNE	\N	\N	\N	Audition de représentants de la filière lentillesfilière lentilles	Audition de représentants de la filière lentilles	2023-02-01 13:30:00	2023-02-01 15:00:00	\N	\N	4	0	\N	1005
698485	GIA	AUCUNE	\N	\N	\N	Coopé - Visite d¿une délégation de fonctionnaires de l¿Assemblée nationale d¿Arménie	Coopé - Visite d¿une délégation de fonctionnaires de l¿Assemblée nationale d¿Arménie	2023-02-01 17:30:00	2023-02-01 18:30:00	\N	\N	1	0	641	\N
698512	GIA	AUCUNE	\N	\N	\N	Coopé - Visite de M. Ivan RADIC économiste et maire d'Osijek en Croatie	Coopé - Visite de M. Ivan RADIC, économiste et maire d'Osijek en Croatie	2023-02-01 15:30:00	2023-02-01 16:15:00	\N	\N	1	0	647	\N
699468	COM_SPECIALE	PLENIERE	\N	CZAN	\N	CS ZAN	Commission spéciale Zéro artificialisation nette	2023-02-07 16:00:00	2023-02-07 16:45:00	2023-02-07 17:09:27	2023-02-09 11:09:05	25	0	\N	\N
699857	GIA	AUCUNE	\N	\N	\N	Participation à la rencontre organisée par la CCIPF	Participation à la rencontre organisée par la Chambre de commerce polonaise en France	2023-01-31 08:30:00	2023-01-31 10:30:00	\N	\N	1	0	600	\N
700090	MISSION	AUTRE	\N	BIOCARBU	\N	MI Biocarburants - 2	\N	2023-02-14 16:45:00	2023-02-14 18:15:00	2023-02-17 16:54:00	2023-02-17 17:41:46	11	0	\N	\N
700091	ETUDES	AUCUNE	\N	\N	\N	Audition de la MAIF	Audition de la MAIF	2023-02-08 08:00:00	2023-02-08 09:00:00	\N	\N	3	0	\N	998
700257	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Auditoin rugby 2023	\N	2023-02-15 09:30:00	2023-02-15 11:30:00	2023-02-15 11:29:51	2023-02-15 17:33:39	36	3	\N	\N
700269	MISSION	AUTRE	\N	BATI	\N	Audition L. Jeannin	\N	2023-02-15 17:30:00	2023-02-15 19:00:00	2023-02-16 09:49:41	2023-02-17 16:25:19	9	0	\N	\N
701103	DELEGATION	AUDRAP	\N	\N	206	Auditions Recyclage du plastique	\N	2023-02-02 14:00:00	2023-02-02 18:00:00	\N	\N	2	0	\N	\N
701166	COM_SPECIALE	AUTRE	\N	CINC	\N	Audition des ministres	\N	2023-03-15 16:30:00	2023-03-15 18:30:00	\N	\N	0	0	\N	\N
701179	COM_SPECIALE	PLENIERE	\N	CINC	\N	Examen rapport et élaboration texte commission	\N	2023-03-28 13:50:00	2023-03-28 15:45:00	2023-03-28 17:34:38	2023-03-29 17:18:59	22	1	\N	\N
701180	COM_ENQUETE	PLENIERE	\N	MEDIC	\N	Réunion plénière	\N	2023-02-15 13:35:00	2023-02-15 15:00:00	2023-02-15 15:00:42	2023-02-15 17:33:49	10	0	\N	\N
701182	COM_SPECIALE	PLENIERE	\N	CINC	\N	Examen des amendements de séance	\N	2023-04-04 13:45:00	2023-04-04 14:45:00	2023-04-04 18:25:31	2023-04-06 17:48:14	24	0	\N	\N
701285	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition MI TND	\N	2023-02-08 16:30:00	2023-02-08 18:00:00	\N	\N	3	0	\N	\N
701340	GIA	AUCUNE	\N	\N	\N	Réception offerte en l'honneur de M. Matti Vanhanen, Président du Parlement finlandais	Réception offerte en l'honneur du Président du Parlement finlandais, par S.E. Matti Anttonen, ambassadeur de Finlande	2023-02-08 13:30:00	2023-02-08 15:00:00	\N	\N	4	0	640	\N
701388	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Audition AFLD	\N	2023-02-08 13:45:00	2023-02-08 15:00:00	\N	\N	0	0	\N	\N
701395	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Musée national du sport	\N	2023-02-08 14:00:00	2023-02-08 15:30:00	\N	\N	1	0	\N	\N
701397	DELEGATION	AUCUNE	\N	\N	COLTER	Réunion plénière	\N	2023-02-09 09:15:00	2023-02-09 10:45:00	2023-02-09 11:49:21	\N	20	0	\N	\N
701425	COM_SPECIALE	AUDRAP	\N	CZAN	\N	Audition DHUP	Audition DHUP	2023-02-08 09:30:00	2023-02-08 11:10:00	\N	\N	11	0	\N	\N
701453	GIA	AUCUNE	\N	\N	\N	Audition de SE Mme GULSARA ARYSTANKULOVA	Audition de SE l'ambassadrice du Kazakhstan	2023-02-01 08:30:00	2023-02-01 10:00:00	\N	\N	8	0	556	\N
701462	GIA	AUCUNE	\N	\N	\N	Déjeuner de travail avec l'Ambassadeur de Malaisie	Entretien avec SE Dato' Zamruni, Ambassadeur de Malaisie	2023-02-08 12:15:00	2023-02-08 14:00:00	\N	\N	2	0	609	\N
701472	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	\N	\N	2023-02-01 19:15:00	2023-02-01 22:00:00	\N	\N	6	0	\N	\N
701483	GIA	AUCUNE	\N	\N	\N	Dîner en présence du Président du groupe d'amitié Egypte- France	Entretien avec Hany NEAMATALLA	2023-02-01 19:15:00	2023-02-01 22:00:00	\N	\N	6	0	617	\N
701490	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	Réunion du Bureau du groupe d'études "Français de l'étranger"	Examen des propositions du rapport sur le Statut des élus des Français de l'étranger	2023-02-08 08:30:00	2023-02-08 09:30:00	\N	\N	5	0	\N	\N
701496	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	Examen des propositions du rapport sur le Statut des élus des Français de l'étranger	Réunion du groupe d'études "Statut, rôle et place des Français établis hors de France"	2023-02-08 14:00:00	2023-02-08 14:40:00	\N	\N	8	0	\N	\N
701534	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-02-14 13:30:00	2023-02-14 14:10:00	2023-02-14 14:23:49	2023-02-14 17:14:17	20	0	\N	\N
742164	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Régime juridique des actions de groupe	PPL Régime juridique des actions de groupe	2023-06-13 16:00:00	2023-06-13 17:00:00	\N	\N	2	0	\N	\N
742229	COM_PERMANENTE	AUTRE	\N	CDD	\N	\N	\N	2023-06-14 10:48:00	2023-06-14 12:00:00	2023-06-15 17:23:00	2023-06-15 20:05:55	39	4	\N	\N
743705	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 49	\N	2023-06-15 09:00:00	2023-06-15 11:35:00	2023-06-15 16:00:54	2023-06-15 20:06:00	9	0	\N	\N
701536	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-02-15 09:05:00	2023-02-15 13:10:00	2023-02-15 13:51:00	2023-02-15 17:33:39	41	0	\N	\N
743706	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Examen de rapport et comptes rendus de déplacements	\N	2023-06-15 08:30:00	2023-06-15 10:40:00	\N	\N	9	0	\N	\N
743742	DELEGATION	AUCUNE	\N	\N	206	Examen de la note scientifique sur les avancées thérapeutiques	\N	2023-06-15 09:30:00	2023-06-15 10:15:00	\N	\N	7	0	\N	\N
743785	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Régime juridique des actions de groupe	PPL Régime juridique des actions de groupe	2023-06-14 16:30:00	2023-06-14 18:30:00	\N	\N	1	0	\N	\N
743791	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Données de santé - Audition commune du CNOM et du CNOI	\N	2023-06-13 17:45:00	2023-06-13 18:45:00	\N	\N	5	0	\N	\N
743799	COM_SPECIALE	PLENIERE	\N	ESNU	\N	Table ronde sur la protection de l'enfance	Table ronde sur la protection de l'enfance	2023-06-20 17:05:00	2023-06-20 18:45:00	2023-06-21 13:35:00	2023-06-21 14:43:18	12	0	\N	\N
743802	ETUDES	AUTRE_NON_PLENIERE	\N	\N	\N	Colloque  - Rencontres cancer	\N	2023-06-10 08:30:00	2023-06-10 12:30:00	\N	\N	2	0	\N	1004
744178	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Plein emploi - Audition UNML	\N	2023-06-15 11:30:00	2023-06-15 12:15:00	\N	\N	4	0	\N	\N
744179	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Plein emploi - Audition DGEFP	\N	2023-06-15 14:00:00	2023-06-15 15:30:00	\N	\N	3	0	\N	\N
744180	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Plein emploi - Audition régions de France	\N	2023-06-15 15:30:00	2023-06-15 16:15:00	\N	\N	2	0	\N	\N
744181	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Plein emploi - Audition Collectif Alerte	\N	2023-06-15 16:15:00	2023-06-15 17:15:00	\N	\N	4	0	\N	\N
744182	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Plein emploi - Audition Cheops	\N	2023-06-15 17:15:00	2023-06-15 18:15:00	\N	\N	5	0	\N	\N
744214	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 50	\N	2023-06-20 09:00:00	2023-06-20 09:30:00	2023-06-20 09:55:05	2023-06-20 18:18:23	12	3	\N	\N
744225	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 51	\N	2023-06-21 09:30:00	2023-06-21 11:15:00	2023-06-21 14:41:57	2023-06-21 18:12:34	31	2	\N	\N
744229	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 52	PLENIERE - 52	2023-06-27 15:30:00	2023-06-27 16:40:00	2023-06-28 10:14:57	2023-06-29 14:30:56	16	4	\N	\N
744231	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 54	PLENIERE - 54	2023-06-28 10:40:00	2023-06-28 12:22:00	2023-06-28 15:39:31	2023-06-29 14:30:55	36	6	\N	\N
744236	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Plein emploi - Audition Cnaf - CCMSA	\N	2023-06-21 16:30:00	2023-06-21 17:30:00	\N	\N	5	0	\N	\N
744245	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Plein emploi - Audition AMF - Intercommunalités de France	\N	2023-06-21 17:30:00	2023-06-21 18:15:00	\N	\N	3	0	\N	\N
744453	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Pass Culture - Audition académie de Versailles	Contrôle 2023 - Pass Culture - Audition académie de Versailles	2023-06-14 14:35:00	2023-06-14 15:35:00	\N	\N	2	0	\N	\N
744463	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - SMV - Audition DSNJ et SMV	Contrôle 2023 - SMV - Audition DSNJ et SMV	2023-06-17 17:00:00	2023-06-17 19:00:00	\N	\N	1	0	\N	\N
744467	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - ORE - Audition Sylvie Retailleau, Ministre de la recherche	Contrôle 2023 - ORE - Audition Sylvie Retailleau, Ministre de la recherche	2023-06-16 19:00:00	2023-06-16 19:45:00	\N	\N	1	0	\N	\N
744472	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Fonds de garantis BpiFrance - Table-ronde	Contrôle 2023 - Fonds de garantis BpiFrance - Table-ronde	2023-06-14 17:00:00	2023-06-14 18:00:00	\N	\N	2	0	\N	\N
744519	COM_PERMANENTE	AUTRE	\N	AFCL	\N	une nomination OEP et deux RI	\N	2023-06-28 09:30:00	2023-06-28 11:45:00	2023-06-29 17:40:55	2023-06-29 19:25:44	29	6	\N	\N
749003	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion CATDD	\N	2023-07-05 09:34:00	2023-07-05 11:30:00	2023-07-05 12:57:07	2023-07-05 18:21:43	37	2	\N	\N
749031	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Examen de conventions et de rapports d'info + Audition de Mme Chrysoula Zacharopoulou	Examen de conventions et de rapports d'info + Audition de Mme Chrysoula Zacharopoulou	2023-07-05 09:05:00	2023-07-05 12:10:00	2023-07-05 15:46:33	2023-07-05 18:21:44	31	9	\N	\N
749070	COM_PERMANENTE	AUTRE	\N	CAE	\N	Rapport Arenh	\N	2023-07-05 09:35:00	2023-07-05 11:45:00	2023-07-05 15:26:39	2023-07-05 18:21:43	31	3	\N	\N
749176	COM_EURO	AUDRAP	\N	AFEU	\N	Auditions CRMA et NZIA	\N	2023-07-04 13:30:00	2023-07-04 17:30:00	\N	\N	3	0	\N	\N
752392	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI expertise patrimoniale	\N	2023-10-03 09:00:00	2023-10-03 10:10:00	\N	\N	2	0	\N	\N
755943	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 67	\N	2023-10-17 16:00:00	2023-10-17 17:50:00	2023-10-18 16:40:36	2023-10-18 18:17:09	35	3	\N	\N
755960	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL écriture inclusive	\N	2023-10-16 10:30:00	2023-10-16 11:05:00	\N	\N	4	0	\N	\N
756014	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Accès aux soins - Audition commune des conférences nationales des CME de CH et CHU	\N	2023-10-10 15:45:00	2023-10-10 16:45:00	\N	\N	13	0	\N	\N
756015	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Accès aux soins - Table ronde des fédérations hospitalières	\N	2023-10-10 09:00:00	2023-10-10 10:45:00	\N	\N	5	0	\N	\N
756017	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Accès aux soins - Audition commune des conférences des directeurs de CH et CHU	\N	2023-10-10 16:45:00	2023-10-10 17:45:00	\N	\N	7	0	\N	\N
756018	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Accès aux soins - Audition des ordres professionnels	\N	2023-10-10 18:00:00	2023-10-10 19:30:00	\N	\N	9	0	\N	\N
756019	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Accès aux soins - Audition des syndicats représentatifs des médecins libéraux	\N	2023-10-11 13:30:00	2023-10-11 15:00:00	\N	\N	11	0	\N	\N
756021	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Accès aux soins - Audition de la Fédération nationale des CPTS	\N	2023-10-13 09:30:00	2023-10-13 10:15:00	\N	\N	2	0	\N	\N
757141	BUREAU	AUCUNE	\N	\N	\N	Réunion du Bureau du Sénat	Réunion du Bureau du Sénat	2023-10-18 08:00:00	2023-10-18 09:30:00	\N	\N	25	0	\N	\N
760422	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2024 - Avis Immigration, asile et intégration	Audition rapporteur - PLF 2024 - Avis immigration	2023-10-25 14:15:00	2023-10-25 15:00:00	\N	\N	3	0	\N	\N
760429	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2024 - Avis Immigration, asile et intégration	Audition rapporteur - PLF 2024 - Avis immigration	2023-10-25 16:30:00	2023-10-25 17:30:00	\N	\N	3	0	\N	\N
760433	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2024 - Avis Immigration, asile et intégration	Audition rapporteur - PLF 2024 - Avis immigration	2023-10-25 17:30:00	2023-10-25 19:00:00	\N	\N	2	0	\N	\N
760439	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2024 - Avis Immigration, asile et intégration	Audition rapporteur - PLF 2024 - Avis immigration	2023-10-25 19:30:00	2023-10-25 20:00:00	\N	\N	2	0	\N	\N
744230	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 53	\N	2023-06-28 09:05:00	2023-06-28 10:40:00	2023-06-28 15:30:15	2023-06-29 14:30:57	36	6	\N	\N
755944	COM_PERMANENTE	AUTRE	\N	CAE	\N	PJL négociations commerciales dans la grande distribution	\N	2023-10-18 10:45:00	2023-10-18 11:45:00	2023-10-18 11:54:16	2023-10-18 18:17:05	49	1	\N	\N
761788	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions MM. Duplomb, Menonville et Tissot	Auditions MM. Duplomb, Menonville et Tissot	2023-11-06 14:00:00	2023-11-06 15:00:00	\N	\N	1	0	\N	\N
761920	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Solidarité - Table-ronde Associations d'aide alimentaire	PLF pour 2024 - Solidarité - Table-ronde Associations d'aide alimentaire	2023-10-26 14:00:00	2023-10-26 15:00:00	\N	\N	2	0	\N	\N
639165	GIA	AUCUNE	\N	\N	\N	M. FRON, DG de Boeing,  Mme ROSSI, PDG de Nike et Mme SMAGGHE, VP de Mac Donald's (France)	M. FRON, DG de Boeing,  Mme ROSSI, PDG de Nike et Mme SMAGGHE, VP de Mac Donald's (France)	2022-03-15 14:30:00	2022-03-15 16:10:00	\N	\N	14	0	590	\N
639341	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Stage en immersion au tribunal judiciaire de Lyon	Stage en immersion au tribunal judiciaire de Lyon	2022-03-21 07:00:00	2022-03-22 19:00:00	\N	\N	1	0	\N	\N
639482	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2022-03-15 16:32:00	2022-03-15 16:53:00	2022-03-17 17:03:00	2022-03-17 17:08:20	19	0	\N	\N
642837	ETUDES	AUCUNE	\N	\N	\N	Déplacement en Haute-Saône	Déplacement en Haute-Saône	2022-05-04 09:00:00	2022-05-04 17:00:00	\N	\N	3	0	\N	948
644517	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI délinquance des mineurs	\N	2022-06-08 11:30:00	2022-06-08 12:30:00	\N	\N	2	0	\N	\N
644864	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Neboja STEFANOVIC, Ministre de la Défense de Serbie	Entretien avec M. Neboja STEFANOVIC, Ministre de la Défense de Serbie	2022-06-14 11:00:00	2022-06-14 12:00:00	\N	\N	2	0	674	\N
647528	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	Audition MI Mégafeux	Audition MI Mégafeux	2022-07-05 14:00:00	2022-07-05 17:30:00	\N	\N	3	0	\N	\N
647532	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	Audition MI Mégafeux	Audition MI Mégafeux	2022-07-06 14:00:00	2022-07-06 14:45:00	\N	\N	3	0	\N	\N
649156	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition Mme Catherine Colonna	\N	2022-07-19 16:30:00	2022-07-19 18:35:00	2022-07-20 14:49:35	2022-07-20 18:41:00	31	1	\N	\N
649157	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Examen PJL adhésion OTAN et Aud. délégation parlement européen	\N	2022-07-20 10:50:00	2022-07-20 13:00:00	2022-07-20 14:48:20	2022-07-20 18:40:54	32	6	\N	\N
649158	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de M. Sébastien Lecornu	\N	2022-07-20 16:30:00	2022-07-20 18:40:00	2022-07-21 10:05:40	2022-07-21 14:44:36	30	0	\N	\N
663836	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Association nationale des architectes des bâtiments de France	\N	2022-10-18 11:45:00	2022-10-18 13:00:00	\N	\N	3	0	\N	\N
663841	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	comité national olympique et sportif français	\N	2022-10-19 14:00:00	2022-10-19 15:00:00	\N	\N	3	0	\N	\N
663847	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition budgétaire de M. Serge Babary - DGCCRF - Mission Economie 	Audition budgétaire de M. Serge Babary - DGCCRF - Mission Economie 	2022-10-19 09:30:00	2022-10-19 10:15:00	\N	\N	1	0	\N	\N
663857	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2023 - Équilibres financiers généraux - Audition Cavimac	\N	2022-10-19 14:00:00	2022-10-19 14:30:00	\N	\N	2	0	\N	\N
663860	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-10-25 08:30:00	2022-10-25 09:50:00	2022-10-25 09:49:16	2022-10-25 16:05:26	21	0	\N	\N
663861	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-10-25 13:30:00	2022-10-25 14:15:00	2022-10-25 14:33:13	2022-10-25 16:05:26	21	0	\N	\N
664196	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions M. Laurent Duplomb, Françoise Férat et Jean-Claude Tissot	AuditionAuditions M. Laurent Duplomb, Françoise Férat et Jean- M. Laurent Duplomb, Françoise Férat et Jean-Claude Tissot	2022-10-19 13:00:00	2022-10-19 14:30:00	\N	\N	2	0	\N	\N
664285	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLJ ENR	\N	2022-10-19 14:00:00	2022-10-19 14:50:00	\N	\N	3	0	\N	\N
664288	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2023 Assurance maladie - Audition du CNOSF	\N	2022-10-18 18:45:00	2022-10-18 19:45:00	\N	\N	1	0	\N	\N
664290	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2023 Assurance maladie - Audition du CNOP	\N	2022-10-19 14:00:00	2022-10-19 14:45:00	\N	\N	1	0	\N	\N
664298	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2023 Autonomie - Table ronde d'associations	\N	2022-10-18 09:00:00	2022-10-18 10:30:00	\N	\N	1	0	\N	\N
664322	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2023-Examen rapports Politique du territoire-DAG-CCE-Plan de relance et MI Fraude	PLF pour 2023-Examen rapports Politique du territoire-DAG-CCE-Plan de relance et MI Fraude	2022-10-25 15:00:00	2022-10-25 18:00:00	2022-10-25 18:42:39	2022-10-26 15:10:39	32	1	\N	\N
664325	COM_PERMANENTE	AUTRE	\N	FINC	\N	Audition du CPO sur la fiscalité locale de l'objectif de Zéro artificialisation nette	Audition du CPO sur la fiscalité locale de l'objectif de Zéro artificialisation nette	2022-10-26 11:05:00	2022-10-26 12:25:00	2022-10-26 14:12:40	2022-10-26 15:10:28	29	1	\N	\N
664326	COM_PERMANENTE	AUTRE	\N	FINC	\N	LPFP 2023-2027-Examen rapport - PLF pour 2023-Examen rapport AC et Contrôle ONACVG	LPFP 2023-2027-Examen rapport - PLF pour 2023-Examen rapport Anciens combattant et Contrôle ONACVG	2022-10-27 10:35:00	2022-10-27 12:45:00	2022-10-27 14:21:20	2022-10-27 15:23:48	26	2	\N	\N
664342	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2023 Enssup	\N	2022-10-19 11:30:00	2022-10-19 12:30:00	\N	\N	2	0	\N	\N
664347	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF cinéma	\N	2022-10-19 13:30:00	2022-10-19 14:30:00	\N	\N	3	0	\N	\N
667185	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Budget 2023 PLF pour 2023 - Avis "Immigration, asile et intégration	Avis "Immigration, asile et intégration" - DGEF et CNDA	2022-10-26 13:00:00	2022-10-26 15:00:00	\N	\N	3	0	\N	\N
672580	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2022-11-10 09:00:00	2022-11-10 12:00:00	\N	\N	4	0	\N	\N
676592	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Mission Économie	Mission Économie	2022-11-24 22:55:00	2022-11-25 01:30:00	\N	\N	36	0	\N	\N
676859	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions de M. SOMON	\N	2022-11-16 18:00:00	2022-11-16 18:45:00	\N	\N	1	0	\N	\N
676864	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions de M. SOMON	\N	2022-11-16 18:45:00	2022-11-16 19:30:00	\N	\N	2	0	\N	\N
686581	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Examen RI processus de paix au Proche-Orient	Examen RI processus de paix au Proche-Orient	2022-12-14 10:00:00	2022-12-14 11:45:00	2022-12-14 15:03:11	2022-12-14 15:55:18	36	4	\N	\N
688468	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Installations nucléaires	\N	2022-12-13 10:00:00	2022-12-13 10:30:00	\N	\N	3	0	\N	\N
688497	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Installations nucléaires	\N	2022-12-12 09:45:00	2022-12-12 11:30:00	\N	\N	4	0	\N	\N
688505	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Installations nucléaires	\N	2022-12-12 14:30:00	2022-12-12 17:45:00	\N	\N	1	0	\N	\N
644520	COM_PERMANENTE	AUTRE	\N	AFCL	\N	MI Délinquance des mineurs	\N	2022-06-08 14:30:00	2022-06-08 19:00:00	\N	\N	2	0	\N	\N
663863	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-10-26 09:05:00	2022-10-26 09:35:00	2022-10-26 12:48:06	2022-10-26 15:10:32	41	0	\N	\N
688507	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Installations nucléaires	\N	2022-12-14 16:30:00	2022-12-14 17:15:00	\N	\N	2	0	\N	\N
688619	GIA	AUCUNE	\N	\N	\N	Entretien avec Paul Maurice sur la question énergétique en Allemagne	Entretien avec Paul Maurice sur la question énergétique en Allemagne	2022-10-19 08:15:00	2022-10-19 09:45:00	\N	\N	10	0	604	\N
688630	GIA	AUCUNE	\N	\N	\N	Entretien du président du groupe avec l'Ambassadeur de Tunisie	Entretien du président du groupe avec l'Ambassadeur de Tunisie	2022-12-15 13:00:00	2022-12-15 14:30:00	\N	\N	1	0	620	\N
688692	DELEGATION	AUCUNE	\N	\N	211	Santé des femmes au travail : table ronde avec des chercheuses de l'INED	Table ronde sur la santé des femmes au travail (INED)	2023-01-12 08:35:00	2023-01-12 10:10:00	\N	\N	8	0	\N	\N
692444	GIA	AUCUNE	\N	\N	\N	Rencontre avec des parlementaires marocains	Rencontre avec des parlementaires marocains	2023-01-17 12:30:00	2023-01-17 14:30:00	\N	\N	4	0	598	\N
696398	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition AFP	\N	2023-02-08 10:30:00	2023-02-08 11:45:00	2023-02-08 11:54:00	2023-02-09 11:07:24	27	0	\N	\N
696629	GIA	AUCUNE	\N	\N	\N	Audition de l'Ambassadeur du Grand-Duché de Luxembourg	Audition de S.E. M. Marc UNGEHEUER, ambassadeur du Grand-Duché de Luxembourg	2023-02-01 08:30:00	2023-02-01 09:45:00	\N	\N	11	0	580	\N
696630	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Groupe de travail Décentralisation 	GT Décentralisation - Auditions rapporteurs	2023-01-31 18:00:00	2023-01-31 19:20:00	\N	\N	6	0	\N	\N
696631	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Groupe de travail Décentralisation 	GT Décentralisation - Auditions rapporteurs	2023-01-31 17:05:00	2023-01-31 18:00:00	\N	\N	6	0	\N	\N
696632	COM_ENQUETE	PLENIERE	\N	MEDIC	\N	\N	\N	2023-02-01 13:30:00	2023-02-01 14:20:00	2023-02-01 15:18:10	2023-02-01 17:20:52	14	0	\N	\N
763068	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition CEA	Audition CEA	2023-11-07 16:30:00	2023-11-07 17:15:00	\N	\N	1	0	\N	\N
763155	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLF pour 2024 - Mission Sécurités	PJLF pour 2024 - Mission Sécurités	2023-11-07 14:00:00	2023-11-07 15:30:00	\N	\N	1	0	\N	\N
763156	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur PLF pour 2024 - RCT	Audition rapporteur PLF pour 2024 - RCT	2023-11-07 14:00:00	2023-11-07 15:00:00	\N	\N	2	0	\N	\N
763169	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLF pour 2024 - Mission Sécurités	PJLF pour 2024 - Mission Sécurités	2023-11-07 18:00:00	2023-11-07 19:00:00	\N	\N	1	0	\N	\N
763177	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLC Référendum	PPLC Référendum d'initiative partagée	2023-11-07 09:45:00	2023-11-07 10:40:00	\N	\N	1	0	\N	\N
763476	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF Création	\N	2023-11-07 17:00:00	2023-11-07 18:00:00	\N	\N	2	0	\N	\N
763497	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PLF 2024 - CAE - Outre-mer	Audition PLF 2024 - CAE - Outre-mer	2023-11-06 14:30:00	2023-11-06 17:00:00	\N	\N	1	0	\N	\N
763653	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF Ens. scolaire	\N	2023-11-07 14:00:00	2023-11-07 14:45:00	\N	\N	2	0	\N	\N
763756	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion CATDD	\N	2023-11-08 16:30:00	2023-11-08 18:30:00	2023-11-15 12:17:54	2023-11-15 14:05:11	24	0	\N	\N
763762	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF création	\N	2023-11-08 14:00:00	2023-11-08 15:00:00	\N	\N	2	0	\N	\N
764182	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Immigration et intégration (amendements)	PJL Immigration et intégration (amendements)	2023-11-08 18:20:00	2023-11-08 18:30:00	2023-11-08 18:42:08	2023-11-10 14:28:36	19	3	\N	\N
764240	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 16 novembre 2023	\N	2023-11-16 09:05:00	2023-11-16 11:00:00	2023-11-16 12:40:10	2023-11-16 18:26:50	9	0	\N	\N
764243	DELEGATION	AUTRE	\N	\N	DSOM	Réunion constitutive de la délégation aux outre-mer (renouvellement 2023)	\N	2023-11-09 09:00:00	2023-11-09 10:00:00	\N	\N	26	0	\N	\N
764263	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PLF 2024 - CAE - Recherche	Audition PLF 2024 - CAE - Recherche	2023-11-08 16:30:00	2023-11-08 18:00:00	\N	\N	1	0	\N	\N
764300	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PLF 2024 - Mission Industrie	Auditions PLF 2024 - Mission Industrie	2023-11-08 13:00:00	2023-11-08 14:00:00	\N	\N	1	0	\N	\N
764374	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 77	\N	2023-11-09 10:00:00	2023-11-09 12:30:00	2023-11-14 17:50:43	2023-11-14 18:02:49	28	4	\N	\N
765461	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF2024 - P185- audition Agence pour l'enseignement français à l'étranger	PLF2024 - P185- audition Agence pour l'enseignement français à l'étranger	2023-11-07 16:00:00	2023-11-07 17:00:00	\N	\N	1	0	\N	\N
765463	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF2024 - P185- audition Campus France et Institut français	PLF2024 - P185- audition Campus France et Institut français	2023-11-08 16:30:00	2023-11-08 18:30:00	\N	\N	1	0	\N	\N
765467	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF2024 - P144 - audition Tikehau Capital et chef division cohérence capacitaire	PLF2024 - P144 - audition Tikehau Capital et chef division cohérence capacitaire 	2023-11-09 09:15:00	2023-11-09 11:15:00	\N	\N	2	0	\N	\N
765471	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF2024 - P144 - audition DGRIS	PLF2024 - P144 - audition DGRIS	2023-11-09 11:30:00	2023-11-09 12:30:00	\N	\N	1	0	\N	\N
769073	DELEGATION	AUCUNE	\N	\N	211	Tables ronde État des lieux du droit et de l'accès à l'avortement dans le monde	Tables ronde État des lieux du droit et de l'accès à l'avortement dans le monde	2023-11-23 08:40:00	2023-11-23 11:30:00	\N	\N	16	0	\N	\N
769226	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Audition de la Présidence de la République	\N	2023-11-14 16:30:00	2023-11-14 18:15:00	\N	\N	1	0	\N	\N
769262	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition S. Fagnen	\N	2023-11-16 16:00:00	2023-11-16 19:00:00	\N	\N	1	0	\N	\N
769264	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition S. Fagnen	\N	2023-11-16 08:45:00	2023-11-16 10:15:00	\N	\N	1	0	\N	\N
769267	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PLF 2024 - Outre-mer	Audition PLF 2024 - Outre-mer	2023-11-10 14:30:00	2023-11-10 16:00:00	\N	\N	1	0	\N	\N
769358	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition rapporteur	\N	2023-11-17 15:30:00	2023-11-17 16:30:00	\N	\N	2	0	\N	\N
769361	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Union des Transports Publics et ferroviaires	\N	2023-11-17 18:00:00	2023-11-17 18:45:00	\N	\N	2	0	\N	\N
696275	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Examen amendements de séance PPL fusillés	Examen amendements de séance PPL fusillés	2023-02-01 11:10:00	2023-02-01 11:25:00	2023-02-01 14:02:13	2023-02-01 17:23:02	35	6	\N	\N
763071	COM_PERMANENTE	AUTRE	\N	AFCL	\N	examen d'avis budgétaires	\N	2023-11-15 09:00:00	2023-11-15 11:30:00	2023-11-15 11:28:33	2023-11-15 17:21:53	44	2	\N	\N
763072	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Examen d'avis budgétaire	\N	2023-11-08 09:00:00	2023-11-08 12:00:00	2023-11-09 15:03:01	2023-11-10 14:28:41	45	6	\N	\N
769381	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2024 - APD	\N	2023-11-14 17:20:00	2023-11-14 18:45:00	\N	\N	2	0	\N	\N
769384	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2024 - APD	\N	2023-11-15 18:30:00	2023-11-15 19:30:00	\N	\N	2	0	\N	\N
769398	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF2024 - P144 - audition Général Lardet, état-major de l'armée de terre	PLF2024 - P144 - audition Général Lardet, état-major de l'armée de terre	2023-11-16 11:20:00	2023-11-16 12:20:00	\N	\N	1	0	\N	\N
769400	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF2024 - P144 - audition Weinberg Capital	PLF2024 - P144 - audition Weinberg Capital	2023-11-16 12:20:00	2023-11-16 13:00:00	\N	\N	1	0	\N	\N
769402	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF2024 - P185- audition Yves Bigot, président fondation des Alliances françaises	PLF2024 - P185- audition Yves Bigot, président fondation des Alliances françaises	2023-11-14 17:00:00	2023-11-14 18:00:00	\N	\N	1	0	\N	\N
769404	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF2024 - P185- audition directeur de la diplomatie d'influence au MEAE	PLF2024 - P185- audition directeur de la diplomatie d'influence au MEAE	2023-11-16 11:00:00	2023-11-16 12:00:00	\N	\N	2	0	\N	\N
769407	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF2024 - P144 - audition Général Susnjara	PLF2024 - P144 - audition Général Susnjara	2023-11-14 15:00:00	2023-11-14 15:30:00	\N	\N	2	0	\N	\N
769410	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF2024 - P129 - audition Pascal Chauve, directeur du GIC	PLF2024 - P129 - audition Pascal Chauve, directeur du GIC	2023-11-14 17:30:00	2023-11-14 19:00:00	\N	\N	2	0	\N	\N
769413	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2024 - P. 146	PLF pour 2024 - P. 146	2023-10-24 14:00:00	2023-10-24 15:30:00	\N	\N	2	0	\N	\N
769416	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Stade de France	Stade de France	2023-10-28 10:00:00	2023-10-28 12:30:00	\N	\N	1	0	\N	\N
769418	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF 2024 : P. 146	PLF 2024 : P. 146	2023-11-07 14:00:00	2023-11-07 17:00:00	\N	\N	2	0	\N	\N
769421	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF 2024 : P. 146	PLF 2024 : P. 146	2023-11-14 16:00:00	2023-11-14 18:00:00	\N	\N	2	0	\N	\N
769424	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF 2024 : P. 146	PLF 2024 : P. 146	2023-11-15 16:45:00	2023-11-15 18:45:00	\N	\N	2	0	\N	\N
769427	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF 2024 - P. 844-847	PLF 2024 : P. 844-847	2023-11-25 16:45:00	2023-11-25 17:45:00	\N	\N	2	0	\N	\N
769430	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF 2024 - P. 844-847	PLF 2024 - P. 844-847	2023-10-26 15:15:00	2023-10-26 18:15:00	\N	\N	2	0	\N	\N
769433	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF 2024 - P. 844-847	PLF 2024 - P. 844-847	2023-11-14 09:00:00	2023-11-14 10:00:00	\N	\N	2	0	\N	\N
769436	DELEGATION	AUDRAP	\N	\N	211	Audition de Sylvie Pierre-Brossolette, présidente du HCE	\N	2023-12-13 16:30:00	2023-12-13 17:30:00	\N	\N	5	0	\N	\N
769453	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2024 - Mission Santé	\N	2023-11-20 15:00:00	2023-11-20 16:00:00	\N	\N	1	0	\N	\N
769454	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2024 - Mission santé	\N	2023-11-20 14:00:00	2023-11-20 15:00:00	\N	\N	1	0	\N	\N
769455	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Réunion constitutive de l'AP-OTAN	\N	2023-11-14 09:30:00	2023-11-14 10:30:00	\N	\N	0	0	\N	\N
769456	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2024 - Mission Santé	\N	2023-11-20 16:15:00	2023-11-20 17:30:00	\N	\N	1	0	\N	\N
769457	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	AP Otan - réunion constitutive	AP Otan - réunion constitutive	2023-11-14 09:30:00	2023-11-14 10:30:00	\N	\N	8	0	\N	\N
769507	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audition P146	\N	2023-11-15 17:45:00	2023-11-15 18:45:00	\N	\N	0	0	\N	\N
769514	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	P151	\N	2023-11-13 15:00:00	2023-11-13 17:00:00	\N	\N	0	0	\N	\N
639643	MISSION	AUCUNE	\N	INFLUENCES	\N	Parlement européen - audition M. Raphaël Glucksmann et Mme Nathalie Loiseau	\N	2022-03-14 11:00:00	2022-03-14 12:30:00	\N	\N	2	0	\N	\N
641672	GIA	AUCUNE	\N	\N	\N	Entretien avec les minsitres-conseillers de l'ambassade du Pérou en France	Entretien avec les minsitres-conseillers de l'ambassade du Pérou en France	2022-04-20 09:00:00	2022-04-20 10:15:00	\N	\N	5	0	979	\N
647546	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Examen RI Avenir Corps diplomatique + Aud. OTAN	\N	2022-07-13 09:00:00	2022-07-13 11:15:00	2022-07-13 15:03:28	2022-07-13 19:07:03	32	5	\N	\N
649779	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Nouvelle-Calédonie	MI sur l'avenir institutionnel de la Nouvelle-Calédonie	2022-07-20 08:00:00	2022-07-20 09:15:00	\N	\N	3	0	\N	\N
650494	QUESTURE	AUCUNE	\N	\N	\N	Réunion de Questure	Réunion de Questure	2022-07-20 11:00:00	2022-07-20 12:15:00	\N	\N	3	0	\N	\N
651457	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	RI  Méditerranée	\N	2022-07-12 08:00:00	2022-07-12 09:30:00	\N	\N	1	0	\N	\N
659112	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL ENR	\N	2022-10-04 10:00:00	2022-10-04 10:30:00	\N	\N	1	0	\N	\N
659116	COM_PERMANENTE	AUDRAP	\N	CAE	\N	\N	Audition PJL ENR	2022-10-04 14:45:00	2022-10-04 15:30:00	\N	\N	3	0	\N	\N
659127	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PJL ENR	\N	2022-10-04 16:30:00	2022-10-04 17:20:00	\N	\N	2	0	\N	\N
659131	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PJL ENR	\N	2022-10-04 17:45:00	2022-10-04 18:30:00	\N	\N	2	0	\N	\N
659134	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PJL ENR	\N	2022-10-04 18:30:00	2022-10-04 19:20:00	\N	\N	2	0	\N	\N
659137	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PJL ENR	\N	2022-10-04 19:20:00	2022-10-04 20:00:00	\N	\N	1	0	\N	\N
659157	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL Enr	\N	2022-10-05 16:00:00	2022-10-05 16:30:00	\N	\N	1	0	\N	\N
659160	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL ENR	\N	2022-10-05 16:30:00	2022-10-05 17:15:00	\N	\N	2	0	\N	\N
659163	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL ENR	\N	2022-10-05 17:15:00	2022-10-05 18:00:00	\N	\N	3	0	\N	\N
659173	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL ENR	\N	2022-10-05 18:00:00	2022-10-05 18:45:00	\N	\N	3	0	\N	\N
659180	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL ENR	\N	2022-10-05 18:45:00	2022-10-05 19:30:00	\N	\N	2	0	\N	\N
659368	BUREAU	AUCUNE	\N	\N	\N	Bureau du Sénat	Bureau du Sénat	2022-10-06 08:30:00	2022-10-06 11:15:00	\N	\N	21	0	\N	\N
665245	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Salon Euronaval	Salon Euronaval	2022-10-20 07:30:00	2022-10-20 15:10:00	\N	\N	7	0	\N	\N
668134	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI organisation de la police judiciaire	MI organisation de la police judiciaire	2022-11-02 11:00:00	2022-11-02 12:00:00	\N	\N	3	0	\N	\N
672910	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2022-11-02 18:00:00	2022-11-02 18:45:00	\N	\N	24	0	\N	\N
682107	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	MIssion RCT	Mission RCT	2022-11-30 14:35:00	2022-11-30 20:10:00	\N	\N	178	0	\N	\N
688426	GIA	AUCUNE	\N	\N	\N	Réception à l'occasion de la Fête du Roi à la résidence de l'ambassadeur de Belgique	Réception à l'occasion de la Fête du Roi  à la résidence de l'ambassadeur de Belgique	2022-11-15 12:30:00	2022-11-15 13:30:00	\N	\N	1	0	580	\N
688433	ETUDES	AUCUNE	\N	\N	\N	métiers d'art	\N	2022-12-07 08:30:00	2022-12-07 09:30:00	\N	\N	12	0	\N	1007
692499	QUESTURE	AUCUNE	\N	\N	\N	Réunion de Questure	Réunion de Questure	2023-01-17 16:30:00	2023-01-17 19:04:00	\N	\N	3	0	\N	\N
699436	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2023-02-02 09:00:00	2023-02-02 10:52:00	\N	\N	3	0	\N	\N
701537	COM_EURO	AUDRAP	\N	AFEU	\N	Audition PPRE Iran	\N	2023-01-25 14:00:00	2023-01-25 15:00:00	\N	\N	1	0	\N	\N
701539	COM_EURO	AUDRAP	\N	AFEU	\N	Audition PPRE Iran	\N	2023-01-26 08:30:00	2023-01-26 09:30:00	\N	\N	1	0	\N	\N
701541	COM_EURO	AUDRAP	\N	AFEU	\N	Audition PPRE Iran	\N	2023-01-26 09:45:00	2023-01-26 10:45:00	\N	\N	1	0	\N	\N
701562	COM_EURO	AUDRAP	\N	AFEU	\N	Audition PPRE Iran	\N	2023-01-26 11:00:00	2023-01-26 12:00:00	\N	\N	1	0	\N	\N
701566	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audition commissaires du gouvernement	\N	2023-02-01 16:30:00	2023-02-01 17:30:00	\N	\N	1	0	\N	\N
701567	COM_EURO	AUDRAP	\N	AFEU	\N	Audition PPRE Iran	\N	2023-01-27 10:30:00	2023-01-27 11:00:00	\N	\N	1	0	\N	\N
701575	DELEGATION	AUDRAP	\N	\N	PROS	Audition M. Beigbeder et M. Robert	\N	2023-02-08 16:45:00	2023-02-08 18:15:00	\N	\N	2	0	\N	\N
701579	COM_ENQUETE	PLENIERE	\N	MEDIC	\N	Audition plénière	\N	2023-02-09 15:30:00	2023-02-09 16:45:00	2023-02-09 16:49:48	2023-02-10 14:28:16	9	0	\N	\N
701580	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Vergriete	\N	2023-02-08 17:00:00	2023-02-08 19:00:00	\N	\N	2	0	\N	\N
701597	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFRSS pour 2023 - Direction du Budget	PLFRSS pour 2023 - Direction du Budget	2023-01-24 10:00:00	2023-01-24 11:00:00	\N	\N	1	0	\N	\N
701599	DELEGATION	AUCUNE	\N	\N	206	Examen d'un rapport sur l'impact de la chlordécone dans les Antilles	\N	2023-02-16 09:15:00	2023-02-16 10:25:00	\N	\N	7	0	\N	\N
701600	DELEGATION	AUCUNE	\N	\N	206	Audition publique sur la réforme du système de contrôle de la sûreté nucléaire 	\N	2023-02-16 10:30:00	2023-02-16 12:55:00	\N	\N	15	0	\N	\N
701602	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFRSS pour 2023 - Direction de la Sécurité Sociale	PLFRSS pour 2023 - Direction de la Sécurité Sociale	2023-01-25 14:00:00	2023-01-25 14:50:00	\N	\N	1	0	\N	\N
701607	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 - Financement du cinéma TR Distributeurs	Contrôle 2023 - Financement du cinéma TR Distributeurs	2023-02-06 14:45:00	2023-02-06 15:55:00	\N	\N	1	0	\N	\N
701609	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI cinéma	\N	2023-02-08 16:30:00	2023-02-08 17:30:00	\N	\N	5	0	\N	\N
701620	COM_PERMANENTE	AUTRE	\N	LOIS	\N	MI Organisation de la police judiciaire - Audition de Gérald Darmanin	MI Organisation de la police judiciaire - Audition de Gérald Darmanin	2023-02-14 17:40:00	2023-02-14 18:45:00	2023-02-14 18:45:02	2023-02-15 17:33:40	25	0	\N	\N
701623	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Services pénitentiaires d'insertion et de probation - Examen du rapport d'information	Services pénitentiaires d'insertion et de probation - Examen du rapport d'information	2023-02-15 09:40:00	2023-02-15 10:35:00	2023-02-15 10:36:38	2023-02-15 17:33:37	34	2	\N	\N
701853	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition archi	\N	2023-03-01 09:30:00	2023-03-01 11:30:00	2023-03-01 11:34:42	2023-03-01 16:37:29	28	0	\N	\N
701865	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI expertise patrimoniale	\N	2023-02-14 09:30:00	2023-02-14 10:45:00	\N	\N	3	0	\N	\N
701892	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Troubles du neurodéveloppement	\N	2023-02-14 14:30:00	2023-02-14 16:00:00	\N	\N	3	0	\N	\N
702225	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2023-03-21 08:45:00	2023-03-21 08:50:00	2023-03-21 10:49:32	2023-03-21 16:36:44	17	2	\N	\N
702233	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2023-03-08 10:30:00	2023-03-08 12:30:00	2023-03-08 16:07:26	2023-03-08 17:31:06	36	0	\N	\N
702239	COM_PERMANENTE	AUTRE	\N	CDD	\N	\N	\N	2023-03-15 11:00:00	2023-03-15 13:10:00	2023-03-21 15:55:31	2023-03-21 15:57:03	67	2	\N	\N
702264	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2023-03-22 09:30:00	2023-03-22 11:30:00	\N	\N	0	0	\N	\N
702460	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Gestion différenciée de la compétence « Eau et Assainissement »	PPL Gestion différenciée de la compétence « Eau et Assainissement »	2023-02-15 11:00:00	2023-02-15 11:30:00	\N	\N	2	0	\N	\N
702461	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Gestion différenciée de la compétence « Eau et Assainissement »	PPL Gestion différenciée de la compétence « Eau et Assainissement »	2023-02-15 14:30:00	2023-02-15 15:10:00	\N	\N	2	0	\N	\N
702462	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Gestion différenciée de la compétence « Eau et Assainissement »	PPL Gestion différenciée de la compétence « Eau et Assainissement »	2023-02-16 13:30:00	2023-02-16 14:00:00	\N	\N	0	0	\N	\N
744201	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion CATDD	\N	2023-06-20 09:15:00	2023-06-20 09:42:00	2023-06-20 11:46:52	2023-06-20 18:18:24	25	3	\N	\N
744203	COM_PERMANENTE	AUTRE	\N	CAE	\N	PJL industrie verte - amendements de séance	\N	2023-06-20 13:45:00	2023-06-20 14:00:00	2023-06-20 14:29:04	2023-06-20 18:18:24	21	3	\N	\N
744204	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Plein emploi - Audition Collectif Handicaps	\N	2023-06-20 09:00:00	2023-06-20 09:45:00	\N	\N	4	0	\N	\N
744205	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Plein emploi - Audition Unédic	\N	2023-06-20 09:45:00	2023-06-20 10:30:00	\N	\N	4	0	\N	\N
744206	COM_ENQUETE	AUTRE	\N	TIKTO	\N	Audition de M. Jean-Noël Barrot, ministre	\N	2023-06-19 15:30:00	2023-06-19 17:20:00	\N	\N	3	0	\N	\N
747940	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2023-06-29 08:30:00	2023-06-29 10:00:00	\N	\N	8	0	\N	\N
753594	COM_PERMANENTE	AUTRE	\N	ETRD	\N	réunion constitutive	réunion constitutive	2023-10-05 12:00:00	2023-10-05 12:35:00	2023-10-05 16:34:24	2023-10-05 17:16:45	42	4	\N	\N
760204	DELEGATION	AUCUNE	\N	\N	211	Communication sur le programme de travail 2023-2024	\N	2023-10-26 09:35:00	2023-10-26 10:10:00	\N	\N	21	0	\N	\N
765703	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Culture - Audition de la direction générale de la création artistique	PLF pour 2024 - Culture - Audition de MM. MILES et VILLETTE, direction générale de la création artistique	2023-11-08 14:00:00	2023-11-08 15:00:00	\N	\N	2	0	\N	\N
765706	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Culture - Audition de la DGMIC	PLF pour 2024 - Culture - Audition de la direction générale des médias et des industries culturelles	2023-11-08 16:30:00	2023-11-08 18:30:00	\N	\N	1	0	\N	\N
766040	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-11-14 20:00:00	2023-11-14 20:30:00	2023-11-14 20:38:25	2023-11-15 16:11:41	16	0	\N	\N
766041	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF Presse	\N	2023-11-14 08:00:00	2023-11-14 09:00:00	\N	\N	2	0	\N	\N
766044	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Table ronde assos	\N	2023-11-13 16:00:00	2023-11-13 17:30:00	\N	\N	1	0	\N	\N
701622	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LEC - PPL Élus locaux au sein du service public de l'assainissement francilien	LEC - PPL Élus locaux au sein du service public de l'assainissement francilien	2023-02-15 08:35:00	2023-02-15 09:30:00	2023-02-15 10:29:30	2023-02-15 17:33:40	37	4	\N	\N
766045	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Enseignant	\N	2023-11-13 17:30:00	2023-11-13 18:30:00	\N	\N	3	0	\N	\N
766054	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	TV5 Monde	\N	2023-11-13 17:00:00	2023-11-13 18:00:00	\N	\N	1	0	\N	\N
766057	SEANCE_PLENIERE	SCRUSOL	1961	\N	\N	Scrutin solennel - PJL Immigration	Scrutin solennel - PJL Immigration	2023-11-14 14:45:00	2023-11-14 18:00:00	\N	\N	0	0	\N	\N
766388	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition - PLF 2024 - DGCCRF	Audition - PLF 2024 - DGCCRF	2023-11-07 13:30:00	2023-11-07 14:15:00	\N	\N	1	0	\N	\N
766389	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PLF 2024- Direction générale des entreprises	Audition PLF 2024- Direction générale des entreprises	2023-11-07 15:00:00	2023-11-07 15:45:00	\N	\N	1	0	\N	\N
766390	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PLF 2024 - UFC-Que choisir	Audition PLF 2024 - UFC-Que choisir	2023-11-07 15:45:00	2023-11-07 16:30:00	\N	\N	1	0	\N	\N
766791	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ambassadrice de Jordanie en France	Entretien avec l'ambassadrice de Jordanie en France	2023-10-31 12:30:00	2023-10-31 14:00:00	\N	\N	4	0	659	\N
766801	GIA	AUCUNE	\N	\N	\N	Conférence-débat "Révision constitutionnelle et stabilité démocratique"	Conférence-débat "Révision constitutionnelle et stabilité démocratique : les cas du Bénin et d'Haïti"	2023-11-10 18:00:00	2023-11-10 20:00:00	\N	\N	1	0	642	\N
766832	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2024 - Avis PJJ	Audition rapporteur - PLF 2024 - Avis PJJ	2023-11-13 15:00:00	2023-11-13 18:00:00	\N	\N	1	0	\N	\N
766927	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Table ronde des syndicats d'enseignants	\N	2023-11-14 16:30:00	2023-11-14 18:10:00	\N	\N	1	0	\N	\N
766932	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2024 - Audition raporteur - Audition DGT	\N	2023-11-14 17:00:00	2023-11-14 18:00:00	\N	\N	1	0	\N	\N
766936	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur - Audition Pôle emploi	\N	2023-11-14 18:15:00	2023-11-14 19:00:00	\N	\N	1	0	\N	\N
766938	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Auditin rapporteur - Audition France compétences	\N	2023-11-14 19:00:00	2023-11-14 20:00:00	\N	\N	1	0	\N	\N
766953	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2023-11-14 16:30:00	2023-11-14 18:15:00	\N	\N	4	0	\N	\N
767261	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2024 - Avis AGTE - Audition AMF	PLF pour 2024 - Avis AGTE - Audition AMF	2023-11-14 18:00:00	2023-11-14 18:45:00	\N	\N	1	0	\N	\N
767269	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLF pour 2024 - Avis justice judiciaire et accès au droit	Audition rapporteur - PLF 2024 - Avis justice judiciaire et accès au droit	2023-11-14 16:00:00	2023-11-14 19:05:00	\N	\N	4	0	\N	\N
767291	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion CATDD	\N	2023-11-15 10:05:00	2023-11-15 11:15:00	2023-11-16 17:19:30	2023-11-16 17:19:36	36	8	\N	\N
767299	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Médias - Audition M. THIELLAY, Centre national de la musique	PLF pour 2024 - Médias - Audition M. THIELLAY, Centre national de la musique	2023-11-09 16:30:00	2023-11-09 17:30:00	\N	\N	1	0	\N	\N
767301	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Médias - Table-ronde financement du Centre national de la musique	PLF pour 2024 - Médias - Table-ronde sur le financement du Centre national de la musique	2023-11-09 14:00:00	2023-11-09 15:30:00	\N	\N	2	0	\N	\N
767304	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Médias - Audition de France Télévisions	PLF pour 2024 - Médias - Audition de Mme ERNOTTE CUNCI et M. TARDIEU, France Télévisions	2023-11-14 08:30:00	2023-11-14 09:30:00	\N	\N	2	0	\N	\N
767309	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Ecologie - Audition Mme WARGON, Commission de régulation de l'énergie	PLF pour 2024 - Ecologie - Audition Mme WARGON, Commission de régulation de l'énergie	2023-11-13 11:00:00	2023-11-13 12:00:00	\N	\N	1	0	\N	\N
767312	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Ecologie - Audition M. MORTUREUX, Plateforme filière automobile	PLF pour 2024 - Ecologie - Audition M. MORTUREUX, Plateforme de la filière automobile et des mobilités	2023-11-13 14:00:00	2023-11-13 15:00:00	\N	\N	1	0	\N	\N
767314	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Solidarité - Audition Association des départements de France	PLF pour 2024 - Solidarité - Audition Association des départements de France	2023-11-08 11:00:00	2023-11-08 12:00:00	\N	\N	2	0	\N	\N
767360	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Solidarité - Audition Direction générale de la cohésion sociale	PLF pour 2024 - Solidarité - Audition Direction générale de la cohésion sociale	2023-11-09 15:45:00	2023-11-09 16:45:00	\N	\N	2	0	\N	\N
767363	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Solidarité - Audition FranceAgriMer	PLF pour 2024 - Solidarité - Audition FranceAgriMer	2023-11-09 16:45:00	2023-11-09 17:45:00	\N	\N	2	0	\N	\N
767367	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLFG pour 2023 - Audition Fédération française des banques alimentaires	PLFG pour 2023 - Audition de Mmes CHAMPIER et MAUVILAIN, Fédération française des banques alimentaires	2023-11-14 19:00:00	2023-11-14 19:30:00	\N	\N	2	0	\N	\N
767371	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Sécurité civile - Audition DG sécurité civile et gestion des crises	PLF pour 2024 - Sécurité civile - Audition DG sécurité civile et gestion des crises (DGSCGC)	2023-10-24 10:00:00	2023-10-24 11:00:00	\N	\N	1	0	\N	\N
767375	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Sécurité civile - Audition de la CNSIS	PLF pour 2024 - Sécurité civile - Audition de M. RICHEFOU, Conférence nationale des services d'incendie et de secours	2023-10-25 08:15:00	2023-10-25 09:00:00	\N	\N	1	0	\N	\N
767377	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Ecologie - Audition Office français de la biodiversité	PLF pour 2024 - Ecologie - Audition MM. THIBAULT et CHARISSOUX, Office français de la biodiversité	2023-11-06 09:00:00	2023-11-06 10:00:00	\N	\N	1	0	\N	\N
767425	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Ecologie - Audition DG prévention des risques	PLF pour 2024 - Ecologie - Audition M. SOULE, Direction générale de la prévention des risques	2023-11-06 11:00:00	2023-11-06 12:00:00	\N	\N	1	0	\N	\N
647453	GIA	AUCUNE	\N	\N	\N	Coopé - Entretien avec M. Atte HARJANNE, parlementaire finlandais	Coopé - Entretien avec M. Atte HARJANNE, parlementaire finlandais	2022-07-06 14:00:00	2022-07-06 15:00:00	\N	\N	1	0	640	\N
679652	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Mission transformation et fonction publiques	Mission transformation et fonction publiques	2022-11-24 19:05:00	2022-11-24 20:00:00	\N	\N	50	0	\N	\N
683149	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2023 Mission enseignement scolaire	PLF 2023 Mission enseignement scolaire	2022-12-01 21:30:00	2022-12-02 00:45:00	\N	\N	36	0	\N	\N
683181	GIA	AUCUNE	\N	\N	\N	Entretien avec Guillaume Bazard, ambassadeur de France en Islande	Entretien avec Guillaume Bazard, ambassadeur de France en Islande	2022-11-30 08:10:00	2022-11-30 09:25:00	\N	\N	2	0	625	\N
766052	COM_PERMANENTE	AUTRE	\N	CDD	\N	PLF 2024 - PPL bruits - Désignation rapporteur article 13	\N	2023-11-22 08:30:00	2023-11-22 11:40:00	2023-11-22 12:05:55	2023-11-22 17:39:12	47	2	\N	\N
767176	COM_PERMANENTE	AUTRE	\N	CAE	\N	Avis budgétaires	\N	2023-11-15 09:30:00	2023-11-15 12:00:00	2023-11-16 17:19:09	2023-11-16 17:19:15	45	3	\N	\N
686717	SEANCE_PLENIERE	SCRUSOL	1781	\N	\N	PLF 2023 - Scrutin solennel	PLF 2023 - Scrutin solennel	2022-12-06 16:00:00	2022-12-06 17:00:00	\N	\N	0	0	\N	\N
686745	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Communication sur l'avenir de Frontex	Communication sur l'avenir de Frontex	2022-12-14 14:05:00	2022-12-14 14:55:00	2023-01-09 18:32:22	2023-01-10 14:56:10	31	0	\N	\N
686748	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Réunion du GS nouvelle relation eurobritannique du 7 décembre 2022	\N	2022-12-07 16:30:00	2022-12-07 18:00:00	\N	\N	5	0	\N	\N
686755	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Déjeuner Mme Delga	\N	2022-12-06 13:15:00	2022-12-06 14:15:00	\N	\N	0	0	\N	\N
686756	COM_PERMANENTE	AUTRE	\N	CAE	\N	Pjl DDADUE - Examen des amendements de séance 	\N	2022-12-13 14:05:00	2022-12-13 14:10:00	2022-12-13 15:45:59	2022-12-14 15:55:21	15	1	\N	\N
686799	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Dubard	\N	2022-12-08 11:00:00	2022-12-08 12:00:00	\N	\N	1	0	\N	\N
686800	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition  Installations nucléaires	Audition  Installations nucléaires	2022-12-06 19:15:00	2022-12-06 20:00:00	\N	\N	2	0	\N	\N
686804	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Installations nucléaires	Audition  Installations nucléaires	2022-12-08 16:30:00	2022-12-08 17:15:00	\N	\N	3	0	\N	\N
686805	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Installations nucléaires	Audition Installations nucléaires	2022-12-08 17:15:00	2022-12-08 18:00:00	\N	\N	2	0	\N	\N
686806	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Installations nucléaires	Audition Installations nucléaires	2022-12-08 18:00:00	2022-12-08 18:25:00	\N	\N	3	0	\N	\N
686807	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Installations nucléaires	Audition Installations nucléaires	2022-12-08 18:35:00	2022-12-08 19:30:00	\N	\N	1	0	\N	\N
686819	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Installations nucléaires	Audition Installations nucléaires	2022-12-09 11:15:00	2022-12-09 11:45:00	\N	\N	2	0	\N	\N
686821	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Installations nucléaires	Audition Installations nucléaires	2022-12-09 11:45:00	2022-12-09 12:45:00	\N	\N	3	0	\N	\N
686822	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Installations nucléaires	Audition Installations nucléaires	2022-12-09 16:30:00	2022-12-09 17:00:00	\N	\N	1	0	\N	\N
686824	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Installations nucléaires	Audition Installations nucléaires	2022-12-09 17:00:00	2022-12-09 17:50:00	\N	\N	1	0	\N	\N
687358	GIA	AUCUNE	\N	\N	\N	Petit-déjeuner avec l'ambassadeur du Pakistan	\N	2022-12-14 08:15:00	2022-12-14 09:15:00	\N	\N	3	0	619	\N
687364	GIA	AUCUNE	\N	\N	\N	Rencontre avec M. Lortholary, directeur de l'Asie et de l'Océanie	\N	2022-12-13 16:30:00	2022-12-13 17:30:00	\N	\N	2	0	619	\N
696828	MISSION	AUCUNE	\N	BIOCARBU	\N	\N	\N	2023-01-31 17:30:00	2023-01-31 18:05:00	2023-02-17 16:53:23	\N	12	0	\N	\N
698017	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure du 26 janvier 2023	Conseil de Questure du 26 janvier 2023	2023-01-26 09:00:00	2023-01-26 11:30:00	\N	\N	3	0	\N	\N
698227	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Groupe de travail  décentralisation	Décentralisation - auditions rapporteurs	2023-02-01 17:30:00	2023-02-01 18:30:00	\N	\N	3	0	\N	\N
698753	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Favoriser les travaux de rénovation énergétique	PPL Favoriser les travaux de rénovation énergétique	2023-02-02 09:00:00	2023-02-02 12:15:00	\N	\N	1	0	\N	\N
698755	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Favoriser les travaux de rénovation énergétique	PPL Favoriser les travaux de rénovation énergétique	2023-02-02 14:30:00	2023-02-02 15:00:00	\N	\N	1	0	\N	\N
698758	ETUDES	AUCUNE	\N	\N	\N	Réunion du groupe d'études "Développement économique de la montagne"	Réunion du groupe d'études "Développement économique de la montagne"	2023-01-31 13:45:00	2023-01-31 14:25:00	\N	\N	7	0	\N	918
698973	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI LPM programme 144	MI LPM programme 144	2023-01-31 13:30:00	2023-01-31 14:30:00	\N	\N	1	0	\N	\N
699097	COM_PERMANENTE	AUTRE	\N	CAE	\N	Table ronde Viande in vitro	\N	2023-02-08 09:00:00	2023-02-08 10:45:00	2023-02-08 14:22:11	2023-02-09 11:07:28	37	1	\N	\N
699964	GIA	AUCUNE	\N	\N	\N	Petit-déjeuner Balkans avec Jacques Rupnik	Petit-déjeuner commun avec le groupe d'amitié France-Balkans en présence de M. Jacques Rupnik	2023-02-08 08:00:00	2023-02-08 09:30:00	\N	\N	6	0	571	\N
700270	GIA	AUCUNE	\N	\N	\N	entretien avec S.E. M. Jai-chul CHOI, Ambassadeur de la République de Corée en France 	\N	2023-02-08 08:30:00	2023-02-08 09:30:00	\N	\N	1	0	613	\N
701186	ETUDES	AUCUNE	\N	\N	\N	FFVA - SFVM	FFVA - SFVM	2023-02-08 08:00:00	2023-02-08 09:30:00	\N	\N	18	0	\N	909
701389	ETUDES	AUCUNE	\N	\N	\N	Audition AFLD	Audition AFLD	2023-02-08 13:45:00	2023-02-08 15:00:00	\N	\N	5	0	\N	1011
701688	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de l'ambassadeur de France au Burkina Faso	\N	2023-02-15 11:20:00	2023-02-15 12:50:00	2023-02-15 14:54:00	2023-02-15 17:33:35	40	4	\N	\N
702946	GIA	AUCUNE	\N	\N	\N	Entretien avec le Secrétaire général du MAE de Macédoine du Nord	\N	2023-02-15 12:00:00	2023-02-15 13:30:00	\N	\N	5	0	674	\N
703263	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ambassadrice de la République de Moldavie en France	Entretien avec l'ambassadrice de la République de Moldavie en France, S.E.M.me Corina Calugaru	2023-02-15 14:00:00	2023-02-15 15:00:00	\N	\N	3	0	851	\N
703744	GIA	AUCUNE	\N	\N	\N	Entretien avec l'Ambassadrice d'Andorre	\N	2023-02-15 08:30:00	2023-02-15 09:15:00	\N	\N	7	0	963	\N
704075	ETUDES	AUDRAP	\N	\N	\N	Audition de Mme Darrieusecq	\N	2023-03-01 16:30:00	2023-03-01 18:30:00	\N	\N	23	0	\N	1014
704076	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Violences intrafamiliales 	Violences intrafamiliales 	2023-02-15 18:30:00	2023-02-15 19:30:00	\N	\N	1	0	\N	\N
704113	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI cinéma	\N	2023-02-17 10:00:00	2023-02-17 11:00:00	\N	\N	3	0	\N	\N
704125	COM_ENQUETE	AUDRAP	\N	MEDIC	\N	CE Pénurie de médicaments - Audition commune d'économistes de la santé	\N	2023-02-16 14:15:00	2023-02-16 15:25:00	\N	\N	8	0	\N	\N
704126	COM_ENQUETE	AUDRAP	\N	MEDIC	\N	CE Pénurie de médicaments - Audition de la Cour des comptes	\N	2023-02-16 15:25:00	2023-02-16 16:05:00	\N	\N	4	0	\N	\N
704140	DELEGATION	AUCUNE	\N	\N	211	Table ronde Santé des femmes au travail  (Santé sexuelle et reproductive)	\N	2023-03-02 08:35:00	2023-03-02 11:15:00	\N	\N	8	0	\N	\N
704185	DELEGATION	AUCUNE	\N	\N	COLTER	Réunion plénière	\N	2023-03-02 09:00:00	2023-03-02 12:00:00	2023-03-02 15:24:42	\N	13	0	\N	\N
704186	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Lutte désertification médicale des collectivités - Audition rapporteur	\N	2023-02-20 14:30:00	2023-02-20 15:00:00	\N	\N	3	0	\N	\N
699099	COM_PERMANENTE	AUTRE	\N	CAE	\N	Examen rapport ppl Egalim 3	\N	2023-02-08 10:50:00	2023-02-08 12:25:00	2023-02-08 14:26:23	2023-02-09 11:07:23	42	2	\N	\N
701687	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Examen du rapport et texte sur PPRE Iran	\N	2023-02-15 10:30:00	2023-02-15 11:20:00	2023-02-15 14:53:23	2023-02-15 17:33:36	40	3	\N	\N
704187	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Lutte désertification médicale des collectivités - Audition du SML	\N	2023-02-20 15:00:00	2023-02-20 15:30:00	\N	\N	2	0	\N	\N
704188	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Lutte désertification médicale des collectivités - Table ronde élus locaux	\N	2023-02-21 14:15:00	2023-02-21 15:15:00	\N	\N	3	0	\N	\N
704189	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Lutte désertification médicale des collectivités - Audition de la CSMF	\N	2023-02-21 15:15:00	2023-02-21 15:45:00	\N	\N	2	0	\N	\N
704190	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Lutte désertification médicale des collectivités - Audition commune DGCL-DGOS 	\N	2023-02-23 15:00:00	2023-02-23 15:30:00	\N	\N	4	0	\N	\N
704201	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Mme Jacques	\N	2023-02-21 09:30:00	2023-02-21 10:30:00	\N	\N	1	0	\N	\N
748021	GIA	AUCUNE	\N	\N	\N	Entretien groupes amitié Sénat et Assemblée nationale	Entretien groupes amitié Sénat et Assemblée nationale	2023-03-09 12:00:00	2023-03-09 14:30:00	\N	\N	2	0	590	\N
748024	GIA	AUCUNE	\N	\N	\N	Entretien avec M. David Leishman	\N	2023-04-18 12:00:00	2023-04-18 14:30:00	\N	\N	1	0	590	\N
748077	GIA	AUCUNE	\N	\N	\N	Entretien Jorge Luis Jure Arnoletti ambassadeur Uruguay	Entretien Jorge Luis Jure Arnoletti ambassadeur Uruguay	2023-04-18 19:00:00	2023-04-18 21:30:00	\N	\N	1	0	978	\N
748085	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Jorge Iglesias Mori (Ministre Conseiller Chili)	Entretien avec M. Jorge Iglesias Mori (Ministre Conseiller Chili)	2023-03-16 12:00:00	2023-03-16 14:00:00	\N	\N	2	0	978	\N
749953	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-07-10 14:30:00	2023-07-10 15:50:00	2023-07-11 10:24:43	2023-07-11 15:23:12	15	0	\N	\N
749954	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-07-11 09:45:00	2023-07-11 10:15:00	2023-07-11 10:26:33	2023-07-11 15:23:12	12	0	\N	\N
749955	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-07-12 09:00:00	2023-07-12 11:00:00	\N	\N	0	0	\N	\N
749956	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-07-12 09:00:00	2023-07-12 11:55:00	2023-07-12 11:53:29	2023-07-13 11:22:48	30	0	\N	\N
749958	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Agressions dont les enseignants sont victimes - Audition de Sylvie Retailleau	Agressions dont les enseignants sont victimes - Audition de Sylvie Retailleau	2023-07-11 17:30:00	2023-07-11 19:10:00	2023-07-11 21:00:59	2023-07-12 10:30:17	21	0	\N	\N
749959	COM_PERMANENTE	AUTRE	\N	LOIS	\N	MI Antilles - Examen du rapport d'information	MI Antilles - Examen du rapport d'information	2023-07-12 11:05:00	2023-07-12 12:00:00	2023-07-13 10:00:48	2023-07-13 11:22:51	25	3	\N	\N
749960	COM_PERMANENTE	AUTRE	\N	LOIS	\N	MI Avenir de la Nouvelle-Calédonie - Examen du rapport d'information	MI Avenir de la Nouvelle-Calédonie - Examen du rapport d'information	2023-07-12 14:00:00	2023-07-12 14:45:00	2023-07-13 10:01:26	2023-07-13 11:22:51	12	2	\N	\N
749985	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 12 juillet 2023 (1/3)	Réunion du 12 juillet 2023 (1/3)	2023-07-12 12:30:00	2023-07-12 13:15:00	2023-07-12 13:37:04	2023-07-13 11:23:08	11	0	\N	\N
749986	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 12 juillet 2023 (2/3)	Réunion du 12 juillet 2023 (2/3)	2023-07-12 13:30:00	2023-07-12 14:15:00	2023-07-12 14:15:04	2023-07-13 11:23:09	11	0	\N	\N
749987	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 13 juillet 	\N	2023-07-13 08:35:00	2023-07-13 10:30:00	2023-07-13 11:04:17	2023-07-13 11:23:09	12	0	\N	\N
749988	COM_PERMANENTE	AUTRE	\N	CAE	\N	RI intelligence économique	\N	2023-07-12 09:30:00	2023-07-12 10:35:00	2023-07-12 11:16:28	2023-07-13 11:22:49	29	0	\N	\N
749989	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition Agnès Pannier Runacher	\N	2023-07-12 16:40:00	2023-07-12 18:15:00	2023-07-13 15:02:20	2023-07-13 15:15:36	17	0	\N	\N
749990	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	examen LPM	Audition Caisse des dépôts	2023-07-04 17:30:00	2023-07-04 18:30:00	\N	\N	1	0	\N	\N
749992	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Contrat ojectifs et performance Campus France	Contrat ojectifs et performance Campus France	2023-06-28 14:00:00	2023-06-28 15:00:00	\N	\N	1	0	\N	\N
749994	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Mission Oman/Emirats	Mission Oman/Emirats	2023-07-04 14:30:00	2023-07-04 15:30:00	\N	\N	2	0	\N	\N
752163	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2023-09-12 10:00:00	2023-09-15 21:00:00	\N	\N	3	0	\N	\N
752167	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2023-09-18 18:00:00	2023-09-18 20:00:00	\N	\N	6	0	\N	\N
756623	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2024 Autonomie - Audition du Synerpa	\N	2023-10-17 15:45:00	2023-10-17 16:30:00	\N	\N	2	0	\N	\N
756754	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLC Abroger l'article 40 de la Constitution	PPLC Abroger l'article 40 de la Constitution	2023-10-17 14:00:00	2023-10-17 16:00:00	\N	\N	1	0	\N	\N
757035	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2024 AT-MP - Associations ANDEVA et FNATH	\N	2023-10-18 16:00:00	2023-10-18 17:00:00	\N	\N	4	0	\N	\N
757083	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion de reconstitution de la délégation aux Entreprises	\N	2023-10-18 12:00:00	2023-10-18 12:30:00	\N	\N	29	0	\N	\N
757087	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2024 AT-MP Organisations patronales	\N	2023-10-18 17:00:00	2023-10-18 18:00:00	\N	\N	3	0	\N	\N
757252	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	plf 2024 enssco	\N	2023-10-17 18:00:00	2023-10-17 19:00:00	\N	\N	3	0	\N	\N
757651	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audition des commissaires du gouvernement	\N	2023-10-10 15:30:00	2023-10-10 16:30:00	\N	\N	1	0	\N	\N
757692	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-10-24 14:00:00	2023-10-24 14:25:00	2023-10-24 14:26:55	2023-10-25 16:14:43	27	0	\N	\N
757693	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition plénière	\N	2023-10-25 09:00:00	2023-10-25 09:55:00	2023-10-25 09:57:04	2023-10-25 16:14:46	37	0	\N	\N
757695	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition plénière	\N	2023-10-25 11:02:00	2023-10-25 12:00:00	2023-10-25 12:00:20	2023-10-25 16:14:38	37	0	\N	\N
757696	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition plénière	\N	2023-10-26 10:40:00	2023-10-26 12:45:00	2023-10-26 12:45:45	2023-10-26 14:31:31	29	0	\N	\N
757697	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-10-24 19:30:00	2023-10-24 20:00:00	2023-10-24 20:52:28	2023-10-25 16:14:45	18	0	\N	\N
757698	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	plf recherche	\N	2023-10-18 16:45:00	2023-10-18 18:00:00	\N	\N	4	0	\N	\N
757699	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	plf recherche	\N	2023-10-18 18:00:00	2023-10-18 19:00:00	\N	\N	3	0	\N	\N
758705	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Enseignement scolaire - Audition DGESCO	PLF pour 2024 - Enseignement scolaire - Audition MM. GEFFRAY et GEHIN, DGESCO	2023-10-20 17:15:00	2023-10-20 19:00:00	\N	\N	1	0	\N	\N
761123	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2023-10-31 09:30:00	2023-10-31 12:30:00	\N	\N	55	0	\N	\N
761275	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2024 - Avis Fonction publique	Audition rapporteur - PLF 2024 - Avis fonction publique	2023-10-31 10:00:00	2023-10-31 12:00:00	\N	\N	2	0	\N	\N
769247	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Culture citoyenne 	PPL Culture citoyenne 	2023-11-23 09:00:00	2023-11-23 11:00:00	\N	\N	61	0	\N	\N
749962	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-07-12 11:00:00	2023-07-12 13:00:00	\N	\N	0	0	\N	\N
761589	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition du Général Pierre Schill	Audition du Général Pierre Schill	2023-11-07 09:00:00	2023-11-07 10:30:00	2023-11-07 17:33:42	2023-11-08 17:48:12	10	0	\N	\N
761590	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition du Général Stéphane Mille	Audition du Général Stéphane Mille	2023-11-07 17:00:00	2023-11-07 19:00:00	2023-11-08 16:41:12	2023-11-08 17:48:12	25	1	\N	\N
761591	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition du Général Christian Rodriguez et de M. Emmanuel Chiva, DGA	Audition du Général Christian Rodriguez et de M. Emmanuel Chiva, DGA	2023-11-08 09:30:00	2023-11-08 12:30:00	2023-11-08 16:41:39	2023-11-08 17:48:08	35	1	\N	\N
761978	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2024 Hébergement - Audition de la FAS	\N	2023-11-08 17:00:00	2023-11-08 18:00:00	\N	\N	2	0	\N	\N
761979	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLF 2024 Hébergement - Audition de la Dihal	\N	2023-11-08 18:00:00	2023-11-08 19:20:00	\N	\N	1	0	\N	\N
762552	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - AAFAR - Audition du cabinet du MASA	PLF pour 2024 - AAFAR - Audition du cabinet du ministre de l'agriculture et de la souveraineté alimentaire	2023-10-25 18:45:00	2023-10-25 20:00:00	\N	\N	2	0	\N	\N
762562	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Engagements financiers - Audition DSAF	PLF pour 2024 - Engagements financiers - Audition de la direction des services administratifs et financier (DSAF)s	2023-10-27 11:30:00	2023-10-27 12:30:00	\N	\N	1	0	\N	\N
762567	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Engagements financiers - Audition de la Banque de France	PLF pour 2024 - Engagements financiers - Audition de la Banque de France	2023-11-02 10:00:00	2023-11-02 11:00:00	\N	\N	1	0	\N	\N
762576	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Engagements financiers - Audition de la Deutsche Bank	PLF pour 2024 - Engagements financiers - Audition M. DUCLOS et Mme BEAUMONT-ANTOGNOLI  de la Deutsche Bank	2023-11-02 11:00:00	2023-11-02 12:00:00	\N	\N	1	0	\N	\N
762580	COM_PERMANENTE	AUDRAP	\N	CAE	\N	AFFECO - Logement	\N	2023-11-06 09:45:00	2023-11-06 15:45:00	\N	\N	1	0	\N	\N
762583	COM_PERMANENTE	AUDRAP	\N	CAE	\N	AFFECO - Logement - CDC Habitat	\N	2023-11-07 08:00:00	2023-11-07 08:45:00	\N	\N	1	0	\N	\N
762589	COM_PERMANENTE	AUTRE	\N	CAE	\N	Auditions PLF / EDF	\N	2023-11-08 09:05:00	2023-11-08 12:50:00	2023-11-08 15:33:11	2023-11-08 17:48:10	45	0	\N	\N
762605	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Engagements financiers - Audition Standard & Poor's	PLF pour 2024 - Engagements financiers - Audition Standard & Poor's Global Ratings	2023-11-02 16:45:00	2023-11-02 17:45:00	\N	\N	1	0	\N	\N
638088	GIA	AUCUNE	\N	\N	\N	Audition de M. Graham PAUL, ambassadeur de France en Moldavie	Audition de M. Graham PAUL, ambassadeur de France en Moldavie	2022-03-01 15:30:00	2022-03-01 16:30:00	\N	\N	7	0	851	\N
638097	GIA	AUCUNE	\N	\N	\N	Audition de Mme Corina Calugaru, ambassadrice de Moldavie en France	Audition de Mme Corina Calugaru, ambassadrice de Moldavie en France	2022-03-01 17:45:00	2022-03-01 18:45:00	\N	\N	6	0	851	\N
638988	GIA	AUCUNE	\N	\N	\N	Déjeuner ou cokctail  du groupe d'amitié France Suisse	Déjeuner ou cokctail  du groupe d'amitié France Suisse	2022-05-24 12:00:00	2022-05-24 13:45:00	\N	\N	2	0	610	\N
639472	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	Coopé - Entretien avec Mme Malgorzata TRACZ, députée polonaise	Coopé - Entretien avec Mme Malgorzata TRACZ, députée polonaise	2022-03-15 15:00:00	2022-03-15 16:00:00	\N	\N	1	0	\N	\N
639637	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Déplacement à Nice - MI "Reconnaissance faciale"	Déplacement à Nice - MI "Reconnaissance faciale"	2022-03-17 06:15:00	2022-03-17 22:00:00	\N	\N	3	0	\N	\N
639641	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI "Reconnaissance faciale"	MI "Reconnaissance faciale" - Auditions	2022-03-17 15:00:00	2022-03-17 16:00:00	\N	\N	1	0	\N	\N
639760	MECSS	AUCUNE	\N	\N	MECSS	Auditions plénières	\N	2022-03-30 14:30:00	2022-03-30 16:00:00	2022-03-30 16:04:07	2022-03-30 17:22:22	7	0	\N	\N
641503	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Politique é	\N	2022-04-13 14:30:00	2022-04-13 16:30:00	\N	\N	3	0	\N	\N
655492	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2022-09-13 14:00:00	2022-09-13 16:00:00	\N	\N	3	0	\N	\N
665988	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2022-10-25 17:00:00	2022-10-25 19:00:00	\N	\N	1	0	\N	\N
669087	COM_EURO	GROUPE_TRAVAIL	\N	AFEU	\N	GT subsidiarité	Réunion du groupe de travail sur la subsidiarité	2022-11-03 08:40:00	2022-11-03 08:55:00	\N	\N	3	0	\N	\N
677217	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Déroulement des élections sénatoriales	\N	2022-11-21 18:00:00	2022-11-21 18:30:00	\N	\N	1	0	\N	\N
695035	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	Audition du groupe d'études "Statut, rôle et place des Français établis hors de France"	Audtion des membres de la commission des lois de l'AFE sur le statut des élus des Français de l'étranger	2023-01-24 17:00:00	2023-01-24 18:35:00	\N	\N	11	0	\N	\N
695047	GIA	AUCUNE	\N	\N	\N	Participation au dîner du CCAF	Participation à la soirée du Conseil de coordination des organisations arméniennes de France	2023-01-25 19:45:00	2023-01-25 23:00:00	\N	\N	10	0	641	\N
695058	GIA	AUCUNE	\N	\N	\N	Entretien avec le maire philippin de Pasig, Vico SOTTO	Entretien avec une personnalité identitifiée comme personnalité d'avenir	2023-01-24 13:00:00	2023-01-24 14:25:00	\N	\N	2	0	609	\N
702022	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Gestion différenciée de la compétence « Eau et Assainissement »	PPL Gestion différenciée de la compétence « Eau et Assainissement »	2023-02-14 13:30:00	2023-02-14 14:30:00	\N	\N	1	0	\N	\N
702463	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Représentation des communes au sein des conseils communautaires	PPL Représentation des communes au sein des conseils communautaires	2023-02-15 11:20:00	2023-02-15 11:45:00	\N	\N	3	0	\N	\N
702464	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Représentation des communes au sein des conseils communautaires	PPL Représentation des communes au sein des conseils communautaires	2023-02-15 11:45:00	2023-02-15 13:00:00	\N	\N	1	0	\N	\N
702465	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Représentation des communes au sein des conseils communautaires	PPL Représentation des communes au sein des conseils communautaires	2023-02-15 16:45:00	2023-02-15 17:15:00	\N	\N	1	0	\N	\N
703254	GIA	AUCUNE	\N	\N	\N	Audition de François Mabille	\N	2023-02-15 13:30:00	2023-02-15 14:45:00	\N	\N	7	0	629	\N
703618	GIA	AUCUNE	\N	\N	\N	entretien avec S.E. Dr. Muhammad Abdul Ghaffar, ambassadeur de Bahreïn	\N	2023-02-15 16:00:00	2023-02-15 16:45:00	\N	\N	2	0	661	\N
703817	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI LPM programme 144	MI LPM programme 144	2023-02-08 13:35:00	2023-02-08 14:25:00	\N	\N	2	0	\N	\N
703873	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Violences intrafamiliales	\N	2023-02-15 16:45:00	2023-02-15 18:00:00	\N	\N	1	0	\N	\N
703996	GIA	AUCUNE	\N	\N	\N	Audition de l'ONG Portes ouvertes	Présentation de l'indice de  persécution des Chrétiens dans le monde	2023-02-14 17:30:00	2023-02-14 19:00:00	\N	\N	14	0	CHRETORIENT	CHRETORIENT
704011	GIA	AUCUNE	\N	\N	\N	Audition conjointe avec le GIA France-Arménie	Audition de Hovannhes GUEVORKIAN, Représentant du Haut-Karabagh sur la situation dans la région	2023-02-07 18:00:00	2023-02-07 19:00:00	\N	\N	14	0	1013	\N
704026	GIA	AUCUNE	\N	\N	\N	Audition de l'ONG Portes ouvertes	Présentation de l'indice de  persécution des Chrétiens dans le monde	2023-02-14 17:30:00	2023-02-14 19:00:00	\N	\N	16	0	CHRETORIENT	CHRETORIENT
704045	GIA	AUCUNE	\N	\N	\N	Réunion de travail 	Programme de travail et présentation du nouveau secrétaire exécutif	2023-02-15 16:15:00	2023-02-15 16:35:00	\N	\N	1	0	550	\N
704064	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2023-02-16 08:15:00	2023-02-16 11:30:00	\N	\N	6	0	\N	\N
704078	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2023-03-01 15:00:00	2023-03-01 16:15:00	\N	\N	281	0	\N	\N
704079	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat d'actualité	Débat d'actualité	2023-03-01 16:30:00	2023-03-01 17:50:00	\N	\N	65	0	\N	\N
704080	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR Lutte contre les violences pornographiques	PPR Lutte contre les violences pornographiques	2023-03-01 17:50:00	2023-03-01 19:15:00	\N	\N	84	0	\N	\N
704081	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	EV PPL Assainissement francilien LEC	EV PPL Assainissement francilien LEC	2023-03-01 19:15:00	2023-03-01 20:10:00	\N	\N	40	0	\N	\N
704082	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat sur la mixité sociale à l'école	Débat sur la mixité sociale à l'école	2023-03-01 21:40:00	2023-03-01 23:25:00	\N	\N	37	0	\N	\N
704083	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2023-03-02 10:30:00	2023-03-02 12:15:00	\N	\N	27	0	\N	\N
704084	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFRSS - DG	PLFRSS - DG	2023-03-02 14:30:00	2023-03-02 18:50:00	\N	\N	178	0	\N	\N
704086	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFRSS - DA	PLFRSS - DA	2023-03-03 17:00:00	2023-03-03 20:15:00	\N	\N	119	0	\N	\N
704088	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFRSS - suite DA	PLFRSS - suite DA	2023-03-03 21:45:00	2023-03-04 00:35:00	\N	\N	122	0	\N	\N
704096	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFRSS - suite DA	PLFRSS - suite DA	2023-03-04 09:35:00	2023-03-04 13:00:00	\N	\N	138	0	\N	\N
704097	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFRSS - suite DA	PLFRSS - suite DA	2023-03-04 14:30:00	2023-03-04 20:00:00	\N	\N	148	0	\N	\N
704098	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFRSS - suite DA	PLFRSS - suite DA	2023-03-04 21:30:00	2023-03-05 00:20:00	\N	\N	117	0	\N	\N
704099	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFRSS - suite DA	PLFRSS - suite DA	2023-03-05 09:30:00	2023-03-05 13:00:00	\N	\N	130	0	\N	\N
704100	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFRSS - suite DA	PLFRSS - suite DA	2023-03-05 14:30:00	2023-03-05 20:00:00	\N	\N	139	0	\N	\N
704101	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFRSS - suite DA	PLFRSS - suite DA	2023-03-05 21:30:00	2023-03-06 00:50:00	\N	\N	94	0	\N	\N
704103	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Gestion différenciée de la compétence « Eau et Assainissement »	PPL Gestion différenciée de la compétence « Eau et Assainissement »	2023-02-17 11:30:00	2023-02-17 12:00:00	\N	\N	2	0	\N	\N
704106	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	\tCommission spéciale chargée du contrôle des comptes et de l'évaluation interne	\tCommission spéciale chargée du contrôle des comptes et de l'évaluation interne	2023-02-01 16:45:00	2023-02-01 18:30:00	2023-02-17 16:03:09	\N	8	0	\N	\N
704114	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI cinéma	\N	2023-02-15 17:30:00	2023-02-15 18:30:00	\N	\N	4	0	\N	\N
704145	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI TND - Audition Pr Delorme	\N	2023-02-20 09:00:00	2023-02-20 10:00:00	\N	\N	4	0	\N	\N
704282	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Producteurs d'emballages ménagers et de papier - Auditions Mme Marta de Cidrac	PPL Producteurs d'emballages ménagers et de papier - Auditions Mme Marta de Cidrac	2023-02-23 09:30:00	2023-02-23 12:00:00	\N	\N	1	0	\N	\N
741133	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2023-06-13 08:30:00	2023-06-13 10:30:00	\N	\N	3	0	\N	\N
741397	GIA	AUCUNE	\N	\N	\N	Rencontre délégation polonaise et M. Rapin	Rencontre délégation polonaise et M. Rapin	2023-05-02 12:30:00	2023-05-02 14:30:00	\N	\N	2	0	600	\N
741411	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation de Sénateurs polonais 	Accueil d'une délégation de Sénateurs polonais : salut en séance et entretien Quai d'Orsay	2023-05-02 15:30:00	2023-05-02 18:00:00	\N	\N	1	0	600	\N
741423	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation de Sénateurs polonais : rencontre acteurs économiques	Accueil d'une délégation de Sénateurs polonais : rencontre acteurs économiques	2023-05-03 08:30:00	2023-05-03 10:00:00	\N	\N	1	0	600	\N
741472	GIA	AUCUNE	\N	\N	\N	Rencontre délégation polonaise et M. Allizard	Rencontre délégation polonaise et M. Allizard	2023-05-03 12:30:00	2023-05-03 14:30:00	\N	\N	2	0	600	\N
741477	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation de Sénateurs polonais 	Accueil d'une délégation de Sénateurs polonais 	2023-05-03 15:00:00	2023-05-03 19:00:00	\N	\N	1	0	600	\N
741482	GIA	AUCUNE	\N	\N	\N	Rencontre délégation polonaise et membres du GIA France-Pologne	Rencontre délégation polonaise et membres du GIA France-Pologne	2023-05-03 19:15:00	2023-05-03 22:00:00	\N	\N	5	0	600	\N
751936	QUESTURE	AUCUNE	\N	\N	\N	Réunion de Questure	Réunion de Questure	2023-07-06 09:00:00	2023-07-06 11:05:00	\N	\N	3	0	\N	\N
761388	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition rapporteur - Avis - DE NICOLAY	\N	2023-10-30 14:00:00	2023-10-30 16:15:00	\N	\N	1	0	\N	\N
761500	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJLF 2024 - JVA	\N	2023-10-31 15:00:00	2023-10-31 16:30:00	\N	\N	2	0	\N	\N
769232	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF fin de gestion 2023	Projet de loi de finances de fin de gestion pour 2023	2023-11-20 16:00:00	2023-11-20 20:05:00	\N	\N	49	0	\N	\N
769234	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	1981	\N	\N	Explications de vote sur l'ensemble	Explications de vote sur l'ensemble	2023-11-21 14:30:00	2023-11-21 15:30:00	\N	\N	321	0	\N	\N
769235	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Déclinaison territoriale de la planification écologique	Débat Déclinaison territoriale de la planification écologique	2023-11-21 16:00:00	2023-11-21 17:40:00	\N	\N	96	0	\N	\N
769236	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat rapport sur la situation des finances publique locales	rapport sur la situation des finances publique locales	2023-11-21 17:40:00	2023-11-21 19:10:00	\N	\N	61	0	\N	\N
769237	SEANCE_PLENIERE	DECL_GVT	\N	\N	\N	Déclaration du Gouvernement 50-1 France Afrique	Déclaration du Gouvernement 50-1 France Afrique	2023-11-21 21:30:00	2023-11-21 23:25:00	\N	\N	41	0	\N	\N
769238	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2023-11-22 15:00:00	2023-11-22 16:15:00	\N	\N	320	0	\N	\N
769239	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Personnes condamnées pour homosexualité	PPL Personnes condamnées pour homosexualité	2023-11-22 16:30:00	2023-11-22 18:25:00	\N	\N	114	0	\N	\N
769245	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPLC Référendum d'initiative partagée 	PPLC Référendum d'initiative partagée	2023-11-22 18:35:00	2023-11-22 20:10:00	\N	\N	73	0	\N	\N
769246	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PLF fin de gestion 2023	CMP PLF fin de gestion 2023	2023-11-22 22:10:00	2023-11-22 22:55:00	\N	\N	21	0	\N	\N
799068	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur	\N	2024-02-09 15:00:00	2024-02-09 16:00:00	\N	\N	2	0	\N	\N
769249	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Prévention des risques liés aux bruits	PPL Prévention des risques liés aux bruits	2023-11-23 11:00:00	2023-11-23 12:25:00	\N	\N	44	0	\N	\N
769250	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024	PLF 2024	2023-11-23 14:30:00	2023-11-23 19:40:00	\N	\N	83	0	\N	\N
769251	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024	PLF 2024	2023-11-23 21:30:00	2023-11-24 00:00:00	\N	\N	0	0	\N	\N
769252	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024	PLF 2024	2023-11-24 16:00:00	2023-11-24 20:00:00	\N	\N	51	0	\N	\N
769253	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024	PLF 2024	2023-11-24 21:30:00	2023-11-25 00:30:00	\N	\N	47	0	\N	\N
769254	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024	PLF 2024	2023-11-25 09:30:00	2023-11-25 13:00:00	\N	\N	48	0	\N	\N
769255	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024	PLF 2024	2023-11-25 14:30:00	2023-11-25 19:55:00	\N	\N	67	0	\N	\N
769256	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024	PLF 2024	2023-11-25 21:30:00	2023-11-26 01:55:00	\N	\N	54	0	\N	\N
769260	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024	PLF 2024	2023-11-26 22:00:00	2023-11-27 01:40:00	\N	\N	47	0	\N	\N
769516	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audition P151	\N	2023-11-14 16:00:00	2023-11-14 17:00:00	\N	\N	0	0	\N	\N
769517	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audition P152	\N	2023-11-15 16:30:00	2023-11-15 18:00:00	\N	\N	0	0	\N	\N
769537	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 81	\N	2023-11-21 09:00:00	2023-11-21 10:00:00	2023-12-01 23:07:23	2023-12-05 17:40:47	25	4	\N	\N
769538	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE 82 - PLF pour 2024 - Mission Travail et emploi + art.68/69	PLENIERE 82 - PLF pour 2024 - Mission Travail et emploi + art.68/69	2023-11-21 16:00:00	2023-11-21 17:00:00	2023-12-01 23:07:38	2023-12-05 17:40:48	24	3	\N	\N
769599	SEANCE_PLENIERE	SCRUSOL	1981	\N	\N	Scrutin solennel PLFSS 2024	Scrutin solennel PLFSS 2024	2023-11-21 15:30:00	2023-11-21 15:40:00	\N	\N	0	0	\N	\N
769600	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition M. Hervé Gillé	\N	2023-11-15 14:00:00	2023-11-15 15:00:00	\N	\N	1	0	\N	\N
769602	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition M. Gillé	\N	2023-11-15 11:00:00	2023-11-15 12:00:00	\N	\N	0	0	\N	\N
769604	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF 2024 : P. 212	PLF 2024 : P. 212	2023-11-13 17:00:00	2023-11-13 19:00:00	\N	\N	2	0	\N	\N
769607	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF 2024 - P. 105	PLF 2024 - P. 105	2023-11-14 17:30:00	2023-11-14 18:30:00	\N	\N	2	0	\N	\N
769610	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF 2024 - P. 105	PLF 2024 : P. 105	2023-11-15 16:30:00	2023-11-15 17:30:00	\N	\N	2	0	\N	\N
769613	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF 2024 - P. 105	PLF 2024 : P. 105	2023-11-15 17:30:00	2023-11-15 18:30:00	\N	\N	1	0	\N	\N
769615	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF 2024 - P. 105	PLF 2024 : P. 105	2023-11-15 18:30:00	2023-11-15 19:30:00	\N	\N	2	0	\N	\N
769618	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Conseils des sages de la laïcité	\N	2023-11-20 16:00:00	2023-11-20 17:30:00	\N	\N	2	0	\N	\N
769619	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Table ronde recteurs	\N	2023-11-20 17:30:00	2023-11-20 19:00:00	\N	\N	2	0	\N	\N
769622	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF AEE	\N	2023-11-20 14:30:00	2023-11-20 17:15:00	\N	\N	1	0	\N	\N
769623	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Epargne salariale - Audition Commission consultative des épargnants (AMF)	Epargne salariale - Audition Commission consultative des épargnants (Autorité des marchés financiers)	2023-11-16 09:30:00	2023-11-16 10:30:00	\N	\N	1	0	\N	\N
769626	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - BACEA - Audition M. DECONINCK, DLF	PLF pour 2024 - BACEA - Audition M. DECONINCK, Direction de la législation fiscale	2023-11-15 16:30:00	2023-11-15 17:15:00	\N	\N	1	0	\N	\N
769628	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Ecologie - Audition M. GUIMBAUD, Voies navigables de France	PLF pour 2024 - Ecologie - Audition M. GUIMBAUD, Voies navigables de France	2023-11-15 17:30:00	2023-11-15 18:30:00	\N	\N	2	0	\N	\N
769631	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Ecologie - Audition M. GOLDNADEL, Aéroports Côte Azur	PLF pour 2024 - Ecologie - Audition M. GOLDNADEL, Groupe Aéroports de la Côte d'Azur	2023-11-17 14:30:00	2023-11-17 15:30:00	\N	\N	1	0	\N	\N
769948	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF 2024 : P. 151	PLF 2024 : P. 151	2023-11-13 11:00:00	2023-11-13 12:15:00	\N	\N	2	0	\N	\N
769951	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	PLF 2024 - P. 151	PLF 2024 - P. 151	2023-11-13 15:00:00	2023-11-13 17:00:00	\N	\N	1	0	\N	\N
769963	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF 2024 : P. 151	PLF 2024 : P. 151	2023-11-14 16:00:00	2023-11-14 17:00:00	\N	\N	2	0	\N	\N
769968	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF 2024 : P. 151	PLF 2024 : P. 151	2023-11-17 11:00:00	2023-11-17 12:00:00	\N	\N	2	0	\N	\N
769971	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF 2024 : P. 152	PLF 2024 : P. 152	2023-11-15 16:30:00	2023-11-15 18:00:00	\N	\N	2	0	\N	\N
638064	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Victorio REDONDO, Ambassadeur d'Espagne	Entretien avec M. Victorio REDONDO, Ambassadeur d'Espagne	2022-02-15 13:00:00	2022-02-15 14:00:00	\N	\N	2	0	589	\N
638068	GIA	AUCUNE	\N	\N	\N	Entretien avec Mme Marie-Anne OMNE, Conseillère chargée des questions agricoles, Ambassade	Entretien avec Mme Marie-Anne OMNE, Conseillère en charge des questions agricoles à l'Ambassade des Etats-Unis à Paris	2022-02-24 10:00:00	2022-02-24 11:00:00	\N	\N	1	0	590	\N
638702	MISSION	AUDRAP	\N	FONDSMER	\N	Audition Michael LODGE	Audition Michael LODGE	2022-03-08 18:00:00	2022-03-08 19:00:00	\N	\N	1	0	\N	\N
638734	MISSION	AUDRAP	\N	FONDSMER	\N	Audition GSR	Audition GSR	2022-03-08 19:00:00	2022-03-08 20:00:00	\N	\N	1	0	\N	\N
639118	MISSION	AUCUNE	\N	FONDSMER	\N	Audition Olivier Poivre d'Arvor puis table ronde chercheurs	Audition Olivier Poivre d'Arvor puis table ronde chercheurs	2022-03-15 17:00:00	2022-03-15 19:20:00	2022-03-15 19:22:05	2022-03-16 10:08:39	6	0	\N	\N
640231	MISSION	AUCUNE	\N	FONDSMER	\N	Audition GICAN	Audition GICAN	2022-03-29 18:00:00	2022-03-29 19:10:00	2022-03-29 19:09:13	2022-03-30 17:28:53	6	0	\N	\N
641610	GIA	AUCUNE	\N	\N	\N	Audition de M. Philippe CORI, Directeur adjoint de l'UNICEF en Europe et Asie centrale	Audition de M. Philippe CORI, Directeur adjoint de l'UNICEF en Europe et Asie centrale	2022-04-19 09:30:00	2022-04-19 10:45:00	\N	\N	12	0	530	\N
641627	MISSION	AUCUNE	\N	FONDSMER	\N	Audition ALSEAMAR	Audition ALSEAMAR	2022-04-19 17:00:00	2022-04-19 18:00:00	2022-04-19 17:59:40	2022-04-25 11:06:14	5	0	\N	\N
769539	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 83	PLENIERE - 83	2023-11-22 09:00:00	2023-11-22 12:30:00	2023-12-01 23:08:04	2023-12-05 17:40:49	49	3	\N	\N
769595	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Examen d'avis budgétaires 	\N	2023-11-29 09:00:00	2023-11-29 11:08:00	2023-11-29 11:51:45	2023-11-29 14:30:27	41	11	\N	\N
645014	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Audition MCC Délinquance des mineurs	Audition de l'UNML	2022-06-15 14:30:00	2022-06-15 15:30:00	\N	\N	8	0	\N	\N
647929	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI métropoles Lyon Aix-Marseille-Provence	MI métropoles Lyon Aix-Marseille-Provence	2022-07-06 18:00:00	2022-07-06 19:15:00	\N	\N	2	0	\N	\N
647932	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Métropoles de Lyon et d'Aix-Marseille-Provence	MI Métropoles de Lyon et d'Aix-Marseille-Provence	2022-07-06 19:15:00	2022-07-06 20:30:00	\N	\N	2	0	\N	\N
656256	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL agrivoltaïsme	\N	2022-09-22 10:00:00	2022-09-22 11:00:00	\N	\N	3	0	\N	\N
656260	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL agrivoltaïsme	\N	2022-09-22 11:00:00	2022-09-22 12:00:00	\N	\N	3	0	\N	\N
656367	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions PPL Agrivoltaïsme	\N	2022-09-27 10:30:00	2022-09-27 11:00:00	\N	\N	1	0	\N	\N
656559	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLC  IVG	PPLC Droit fondamental à l'IVG et à la contraception	2022-09-27 09:00:00	2022-09-27 10:30:00	\N	\N	2	0	\N	\N
656574	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLC  IVG	PPLC Droit fondamental à l'IVG et à la contraception	2022-09-27 16:30:00	2022-09-27 17:15:00	\N	\N	3	0	\N	\N
659663	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2023 Enssup	\N	2022-10-11 09:00:00	2022-10-11 10:00:00	\N	\N	1	0	\N	\N
659672	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Conférence interparlementaire article 13 du TSCG à Prague - octobre 2022	Conférence interparlementaire article 13 du TSCG à Prague - octobre 2022	2022-10-10 09:20:00	2022-10-11 17:35:00	\N	\N	3	0	\N	\N
659678	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2022-11-02 16:30:00	2022-11-02 18:30:00	2022-11-02 21:09:17	2022-11-03 17:38:01	36	1	\N	\N
659967	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2023 Presse	\N	2022-10-11 15:30:00	2022-10-11 16:30:00	\N	\N	3	0	\N	\N
659973	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJL ENR	\N	2022-10-11 09:30:00	2022-10-11 11:00:00	\N	\N	1	0	\N	\N
659998	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2023 Recherche	\N	2022-10-11 15:00:00	2022-10-11 18:00:00	\N	\N	2	0	\N	\N
660004	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2023 Recherche	\N	2022-10-10 15:00:00	2022-10-10 18:00:00	\N	\N	2	0	\N	\N
660012	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2023 Creation	\N	2022-10-11 17:45:00	2022-10-11 19:10:00	\N	\N	3	0	\N	\N
667301	GIA	AUCUNE	\N	\N	\N	Coopé - Visite au Sénat de M. Roberto PATIÑO, représentant de l¿opposition vénézuélienne	Coopé - Visite au Sénat de M. Roberto PATIÑO, représentant de l¿opposition vénézuélienne	2022-10-25 18:00:00	2022-10-25 19:00:00	\N	\N	2	0	979	\N
667304	GIA	AUCUNE	\N	\N	\N	Coopé - Visite de M. Xavier ABU EID, conseiller au département des négociations de l¿organ	Visite de M. Xavier ABU EID, conseiller au département des négociations de l¿organisation de libération de la Palestine	2022-10-25 17:30:00	2022-10-25 18:30:00	\N	\N	2	0	632	\N
667611	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition Colonel Michel GOYA et Revue nationale stratégique	\N	2022-11-02 09:35:00	2022-11-02 12:25:00	2022-11-02 14:04:42	2022-11-02 17:47:05	24	0	\N	\N
671029	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Collectivités territoriales	Débat Collectivités territoriales	2022-11-15 17:40:00	2022-11-15 19:20:00	\N	\N	82	0	\N	\N
671030	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL  Agression élus	PPL  Agression élus	2022-11-15 19:20:00	2022-11-15 20:00:00	\N	\N	52	0	\N	\N
671031	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Modalités d'incarcération ou de libération	PPL Modalités d'incarcération ou de libération	2022-11-15 23:25:00	2022-11-16 00:15:00	\N	\N	28	0	\N	\N
671032	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2022-11-16 15:00:00	2022-11-16 16:20:00	\N	\N	293	0	\N	\N
671033	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFR 2022	PLFR 2022	2022-11-16 16:35:00	2022-11-16 21:20:00	\N	\N	116	0	\N	\N
671035	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR Chanvre	PPR Chanvre	2022-11-17 10:35:00	2022-11-17 12:00:00	\N	\N	47	0	\N	\N
671036	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Conclusions CMP PJL Marché du travail	Conclusions CMP PJL Marché du travail	2022-11-17 12:05:00	2022-11-17 13:00:00	\N	\N	30	0	\N	\N
671037	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2023	PLF 2023	2022-11-17 14:30:00	2022-11-17 20:15:00	\N	\N	87	0	\N	\N
671039	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2023	PLF 2023	2022-11-18 16:00:00	2022-11-18 20:15:00	\N	\N	54	0	\N	\N
671040	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2023	PLF 2023	2022-11-18 21:45:00	2022-11-19 00:35:00	\N	\N	45	0	\N	\N
671041	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2023	PLF 2023	2022-11-19 09:35:00	2022-11-19 13:00:00	\N	\N	47	0	\N	\N
671042	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2023	PLF 2023	2022-11-19 14:30:00	2022-11-19 20:10:00	\N	\N	63	0	\N	\N
671043	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2023	PLF 2023	2022-11-19 21:40:00	2022-11-20 02:25:00	\N	\N	52	0	\N	\N
686726	ETUDES	AUCUNE	\N	\N	\N	Cour des comptes	Cour des comptes	2022-12-07 16:30:00	2022-12-07 17:40:00	\N	\N	5	0	\N	922
704203	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Mme Jacques	\N	2023-02-21 14:45:00	2023-02-21 15:15:00	\N	\N	1	0	\N	\N
704205	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Mme Jacques	\N	2023-02-20 09:00:00	2023-02-20 09:45:00	\N	\N	1	0	\N	\N
704222	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Violences intrafamiliales	PPL Violences intrafamiliales	2023-02-22 15:15:00	2023-02-22 16:30:00	\N	\N	1	0	\N	\N
704309	DELEGATION	AUDRAP	\N	\N	211	Audition rapporteures Santé des femmes au travail "Conciliation maladie et travail"	Audition rapporteures "Conciliation maladie et travail"	2023-03-13 10:00:00	2023-03-13 11:00:00	\N	\N	3	0	\N	\N
704312	DELEGATION	AUCUNE	\N	\N	211	Table ronde Santé des femmes au travail (Risques professionnels)	\N	2023-03-23 08:30:00	2023-03-23 10:45:00	\N	\N	3	0	\N	\N
743947	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Mehdi HALIMI, ambassadeur du  Kosovo	Entretien avec M. Mehdi HALIMI, ambassadeur du  Kosovo	2023-06-14 08:00:00	2023-06-14 09:00:00	\N	\N	2	0	674	\N
744078	COM_PERMANENTE	AUDRAP	\N	CAE	\N	FEEF	FEEF	2023-06-14 18:00:00	2023-06-14 18:45:00	\N	\N	3	0	\N	\N
744082	COM_PERMANENTE	AUDRAP	\N	CAE	\N	ILEC	ILEC	2023-06-14 18:45:00	2023-06-14 19:30:00	\N	\N	3	0	\N	\N
744092	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Industrie verte (amendements)	PJL Industrie verte (amendements)	2023-06-20 14:00:00	2023-06-20 14:05:00	2023-06-20 14:40:52	2023-06-20 18:18:25	10	1	\N	\N
744093	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de Dominique Simonnot, contrôleure générale des lieux de privation de liberté	Audition de Dominique Simonnot, contrôleure générale des lieux de privation de liberté	2023-06-21 10:05:00	2023-06-21 11:25:00	2023-06-21 11:51:51	2023-06-21 14:42:40	31	4	\N	\N
744160	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 21 juin 2023	\N	2023-06-21 14:00:00	2023-06-21 14:40:00	2023-06-21 15:01:58	2023-06-22 16:58:54	14	0	\N	\N
744161	COM_EURO	AUTRE	\N	AFEU	\N	Table ronde - Enjeux actuels de la liberté des médias audiovisuels en Europe	\N	2023-06-22 09:00:00	2023-06-22 11:00:00	2023-06-23 14:37:11	2023-06-23 16:26:28	18	0	\N	\N
751681	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Reconstruction des bâtiments suite aux émeutes	PJL Reconstruction des bâtiments suite aux émeutes	2023-07-13 11:00:00	2023-07-13 11:45:00	\N	\N	1	0	\N	\N
755903	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition Région Nouvelle-Aquitaine	Audition Région Nouvelle-Aquitaine	2023-10-13 16:15:00	2023-10-13 16:45:00	\N	\N	4	0	\N	\N
755904	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition Fédération française des usagers de la bicyclette	Audition Fédération française des usagers de la bicyclette	2023-10-13 16:45:00	2023-10-13 17:15:00	\N	\N	2	0	\N	\N
755905	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition Région Grand Est	Audition Région Grand Est	2023-10-13 17:15:00	2023-10-13 18:00:00	\N	\N	1	0	\N	\N
755906	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Assemblée des départements de France (ADF)	\N	2023-10-13 18:00:00	2023-10-13 18:45:00	\N	\N	0	0	\N	\N
755910	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Art.13 Traité UE - Déplacement à Madrid Conférence interparlementaire européenne	Art.13 Traité UE - Déplacement à Madrid Conférence interparlementaire européenne	2023-10-25 14:30:00	2023-10-27 22:00:00	\N	\N	3	0	\N	\N
755920	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 69	\N	2023-10-18 10:05:00	2023-10-18 12:30:00	2023-10-19 14:59:01	2023-10-23 18:02:57	48	2	\N	\N
755921	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 66	\N	2023-10-16 15:00:00	2023-10-16 15:10:00	2023-10-26 11:37:53	2023-10-27 19:01:42	23	5	\N	\N
757708	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLC Abroger l'article 40 de la Constitution	PPLC Abroger l'article 40 de la Constitution	2023-10-18 11:10:00	2023-10-18 11:30:00	\N	\N	2	0	\N	\N
757715	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 25 octobre 2023	\N	2023-10-25 13:30:00	2023-10-25 14:50:00	2023-10-25 16:38:29	2023-10-26 11:07:08	23	0	\N	\N
757716	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 26 octobre 2023	\N	2023-10-26 09:00:00	2023-10-26 10:15:00	2023-10-26 15:04:31	2023-10-27 19:06:35	18	0	\N	\N
757717	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2024 - Audition CEPS	\N	2023-10-18 16:30:00	2023-10-18 17:45:00	\N	\N	3	0	\N	\N
757718	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2024 - Audition Snitem	\N	2023-10-18 17:45:00	2023-10-18 19:00:00	\N	\N	3	0	\N	\N
757727	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 24 Patrimoine	\N	2023-10-18 14:00:00	2023-10-18 15:00:00	\N	\N	1	0	\N	\N
757728	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF Patrimoine	\N	2023-10-18 16:30:00	2023-10-18 19:00:00	\N	\N	3	0	\N	\N
757735	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Emeutes survenues depuis le 27 juin 2023 - Audition des inspections générales	Emeutes survenues depuis le 27 juin 2023 - Audition des inspections générales	2023-10-25 10:45:00	2023-10-25 12:00:00	2023-10-25 16:00:56	2023-10-25 16:14:38	30	1	\N	\N
757736	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MCC Agressions enseignants	\N	2023-10-16 16:00:00	2023-10-16 17:30:00	\N	\N	10	0	\N	\N
757737	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	audition rapporteur MCC agression	\N	2023-10-16 17:30:00	2023-10-16 19:00:00	\N	\N	7	0	\N	\N
757738	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MCC Agressions enseignants	\N	2023-10-23 16:00:00	2023-10-23 19:00:00	\N	\N	0	0	\N	\N
757741	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2024 - Crédits du sport	Andes	2023-10-18 14:00:00	2023-10-18 15:00:00	\N	\N	3	0	\N	\N
757742	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2024 - Crédits du sport	Insep	2023-10-18 16:30:00	2023-10-18 17:30:00	\N	\N	2	0	\N	\N
757751	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Direction des sports - Ministère des sports et des JOP	\N	2023-11-02 09:00:00	2023-11-02 10:30:00	\N	\N	3	0	\N	\N
757752	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Comité paralympique et sportif français	\N	2023-11-02 10:30:00	2023-11-02 11:30:00	\N	\N	2	0	\N	\N
757753	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Union sport et cycle 	\N	2023-11-02 11:30:00	2023-11-02 12:30:00	\N	\N	2	0	\N	\N
757754	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Solideo	\N	2023-11-07 09:00:00	2023-11-07 10:00:00	\N	\N	3	0	\N	\N
757755	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	CNOSF	\N	2023-11-07 14:30:00	2023-11-07 16:00:00	\N	\N	2	0	\N	\N
757756	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Audition Etat-major des armées	PLF pour 2024 - Audition Etat-major des armées	2023-10-18 16:30:00	2023-10-18 17:30:00	\N	\N	1	0	\N	\N
757758	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Audition Action Logement	PLF pour 2024 - Audition Action Logement M. ARCADIPANE et Mmes BOUYER et MAT	2023-10-18 16:15:00	2023-10-18 17:15:00	\N	\N	1	0	\N	\N
757760	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - BACEA - Audition de Mme SCHWARZ Météo-France	PLF pour 2024 - BACEA - Audition de Mme SCHWARZ Météo-France	2023-10-18 16:15:00	2023-10-18 17:15:00	\N	\N	1	0	\N	\N
757762	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - BACEA - Audition Union des Aéroports Français	PLF pour 2024 - BACEA - Audition M. PAULISSEN, Union des Aéroports Français	2023-10-18 17:15:00	2023-10-18 18:15:00	\N	\N	1	0	\N	\N
757764	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - BACEA - Audition M. PICHARD, direction du budget	PLF pour 2024 - BACEA - Audition M. PICHARD, direction du budget	2023-10-19 14:30:00	2023-10-19 15:45:00	\N	\N	1	0	\N	\N
757768	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion CATDD	\N	2023-10-23 14:00:00	2023-10-23 14:30:00	2023-10-26 10:43:08	2023-10-26 10:46:17	10	3	\N	\N
755919	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 68	\N	2023-10-18 09:30:00	2023-10-18 10:05:00	2023-10-19 14:58:10	2023-10-23 18:02:58	48	4	\N	\N
757734	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Amnistie - PPL Abrogration article 40 (rapports)	PPL Amnistie - PPL Abrogration article 40 (rapports)	2023-10-25 09:30:00	2023-10-25 10:15:00	2023-10-25 16:30:50	2023-10-25 16:31:43	42	1	\N	\N
757769	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion CATDD	\N	2023-10-25 10:00:00	2023-10-25 13:00:00	2023-10-26 10:44:33	2023-10-26 10:44:38	38	0	\N	\N
757770	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Outre-mer - Audition DGOM	\N	2023-10-18 18:00:00	2023-10-18 19:30:00	\N	\N	2	0	\N	\N
757775	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Outre-mer - Audition MM. MARITON et RENOUF, FEDOM	PLF pour 2024 - Outre-mer - Audition MM. MARITON et RENOUF, FEDOM	2023-10-19 18:00:00	2023-10-19 19:00:00	\N	\N	2	0	\N	\N
757780	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL Épargnants et exploitations agricoles - Audition M. DUCLAUD, DGPE	PPL Épargnants et exploitations agricoles - Audition M. DUCLAUD, DGPE	2023-10-18 17:30:00	2023-10-18 18:10:00	\N	\N	1	0	\N	\N
757782	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL Épargnants et exploitations agricoles - Audition M. KLINGER, auteur de la PPL	PPL Épargnants et exploitations agricoles - Audition M. KLINGER, auteur de la PPL	2023-10-17 09:30:00	2023-10-17 10:30:00	\N	\N	1	0	\N	\N
757784	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL Épargnants et exploitations agricoles - Audition MM. SALMON et MARX, groupe de travail	PPL Épargnants et exploitations agricoles - Audition MM. SALMON et MARX, co¿présidents du groupe de travail « Installati	2023-10-18 16:30:00	2023-10-18 17:30:00	\N	\N	1	0	\N	\N
757786	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL Épargnants et exploitations agricoles - Audition Jeunes Agriculteurs	PPL Épargnants et exploitations agricoles - Audition MM. ROUGIER, SENE et DEBRIX, Jeunes Agriculteurs	2023-10-18 18:10:00	2023-10-18 19:20:00	\N	\N	1	0	\N	\N
640561	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2022-03-30 11:00:00	2022-03-30 13:30:00	\N	\N	5	0	\N	\N
641307	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI "Reconnaissance faciale"	MI "Reconnaissance faciale" - Auditions	2022-04-12 11:00:00	2022-04-12 12:00:00	\N	\N	3	0	\N	\N
641314	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI "Reconnaissance faciale"	MI "Reconnaissance faciale" - Auditions	2022-04-12 14:00:00	2022-04-12 14:30:00	\N	\N	3	0	\N	\N
641324	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI "Reconnaissance faciale"	MI "Reconnaissance faciale" - Auditions	2022-04-12 16:00:00	2022-04-12 16:45:00	\N	\N	3	0	\N	\N
641328	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	reconn	MI "Reconnaissance faciale" - Auditions	2022-03-30 09:00:00	2022-03-30 12:45:00	\N	\N	5	0	\N	\N
641338	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI "Reconnaissance faciale"	MI "Reconnaissance faciale" - Auditions	2022-03-30 14:00:00	2022-03-30 16:00:00	\N	\N	4	0	\N	\N
641343	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI "Reconnaissance faciale"	MI "Reconnaissance faciale" - Auditions	2022-03-30 16:00:00	2022-03-30 16:45:00	\N	\N	3	0	\N	\N
641348	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	reconn	MI "Reconnaissance faciale" - Auditions	2022-03-30 16:45:00	2022-03-30 19:00:00	\N	\N	3	0	\N	\N
643278	MISSION	AUCUNE	\N	FONDSMER	\N	Auditions OFB et LWNC	Auditions OFB et LWNC	2022-05-25 10:30:00	2022-05-25 12:30:00	2022-05-27 17:02:31	2022-05-27 17:04:22	5	0	\N	\N
649560	GIA	AUCUNE	\N	\N	\N	Déjeuner du GIA France - Afrique du Sud	Déjeuner du GIA France - Afrique du Sud (Compte rendu du déplacement)	2022-07-19 12:30:00	2022-07-19 14:00:00	\N	\N	6	0	574	\N
655360	GIA	AUCUNE	\N	\N	\N	Entretien avec M. OUK Kim Lek, Secrétaire d'Etat 	Entretien avec M. OUK Kim Lek, Secrétaire d'Etat 	2022-07-29 12:00:00	2022-07-29 13:00:00	\N	\N	1	0	577	\N
655362	MISSION	AUCUNE	\N	\N	\N	\N	\N	2022-08-01 00:00:00	2022-08-01 00:00:00	\N	\N	0	0	\N	\N
656356	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Cabinets privés	PPL Cabinets privés	2022-09-27 09:30:00	2022-09-27 11:00:00	\N	\N	1	0	\N	\N
656359	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Cabinets privés	PPL Cabinets privés	2022-09-27 14:00:00	2022-09-27 15:25:00	\N	\N	1	0	\N	\N
668844	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2023 - Avis Immigration, asile et intégration	PLF pour 2023 - Avis Immigration, asile et intégration	2022-11-02 13:00:00	2022-11-02 14:00:00	\N	\N	3	0	\N	\N
668848	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2023 - Avis Immigration, asile et intégration	PLF pour 2023 - Avis Immigration, asile et intégration	2022-11-02 14:00:00	2022-11-02 15:00:00	\N	\N	2	0	\N	\N
673823	GIA	AUCUNE	\N	\N	\N	Assemblée générale du GIA	Assemblée générale du GIA	2022-10-12 14:00:00	2022-10-12 15:00:00	\N	\N	11	0	530	\N
673835	GIA	AUCUNE	\N	\N	\N	Audition de l'ambassadeur de France en Ukraine	Audition de l'Ambassadeur de France en Ukraine	2022-10-18 09:30:00	2022-10-18 10:30:00	\N	\N	10	0	530	\N
690797	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Philippe THIÉBAUD, ancien Ambassadeur de France en Iran 	Entretien avec M. Philippe THIÉBAUD, ancien Ambassadeur de France en Iran 	2023-01-11 08:30:00	2023-01-11 09:55:00	\N	\N	4	0	628	\N
690822	SEANCE_PLENIERE	AUTRE	\N	\N	\N	Désignation membres CE rénovation énergétique	Désignation membres CE rénovation énergétique	2023-01-17 14:30:00	2023-01-17 14:35:00	\N	\N	51	0	\N	\N
690823	SEANCE_PLENIERE	AUTRE	\N	\N	\N	Désignation membres MI Biocarburants	Désignation membres MI Biocarburants	2023-01-17 14:30:00	2023-01-17 14:35:00	\N	\N	48	0	\N	\N
690825	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Installations nucléaires 	PJL Installations nucléaires 	2023-01-17 14:40:00	2023-01-17 18:50:00	\N	\N	187	0	\N	\N
690826	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Installations nucléaires	PJL Installations nucléaires	2023-01-17 21:00:00	2023-01-18 00:45:00	\N	\N	82	0	\N	\N
690827	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2023-01-18 15:00:00	2023-01-18 16:15:00	\N	\N	316	0	\N	\N
704284	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Producteurs d'emballages ménagers et de papier - Auditions Mme Marta de Cidrac	PPL Producteurs d'emballages ménagers et de papier - Auditions Mme Marta de Cidrac	2023-02-23 14:00:00	2023-02-23 19:00:00	\N	\N	1	0	\N	\N
704300	MISSION	AUCUNE	\N	GEAU	\N	Table ronde des agences de l'eau	\N	2023-02-28 14:30:00	2023-02-28 17:00:00	2023-02-28 17:02:43	2023-03-01 16:39:06	11	0	\N	\N
704301	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	PJL Immigration et intégration - Déplacement dans le Haut-Rhin	PJL Immigration et intégration - Déplacement dans le Haut-Rhin	2023-02-21 06:30:00	2023-02-21 21:30:00	\N	\N	2	0	\N	\N
704302	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	PJL Immigration et intégration - Cour nationale du droit d'asile - Tribunal administratif	PJL Immigration et intégration - Cour nationale du droit d'asile - Tribunal administratif	2023-02-23 08:00:00	2023-02-23 13:00:00	\N	\N	0	0	\N	\N
704622	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Immigration et intégration	Audition rapporteur - PJL Immigration et intégration	2023-02-24 15:00:00	2023-02-24 18:00:00	\N	\N	2	0	\N	\N
760928	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Ecriture inclusive	\N	2023-10-30 18:00:00	2023-10-30 18:15:00	2023-10-31 18:15:30	2023-11-02 12:36:43	17	6	\N	\N
704629	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Immigration et intégration	Audition rapporteur - PJL Immigration et intégration	2023-02-28 08:30:00	2023-02-28 11:00:00	\N	\N	4	0	\N	\N
704637	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Immigration et intégration	Audition rapporteur - PJL Immigration et intégration	2023-02-28 15:00:00	2023-02-28 16:00:00	\N	\N	4	0	\N	\N
704642	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Immigration et intégration	Audition rapporteur - PJL Immigration et intégration	2023-02-28 16:00:00	2023-02-28 17:00:00	\N	\N	3	0	\N	\N
704646	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Immigration et intégration	Audition rapporteur - PJL Immigration et intégration	2023-02-08 16:30:00	2023-02-08 18:30:00	\N	\N	3	0	\N	\N
704650	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Immigration et intégration	Audition rapporteur - PJL Immigration et intégration	2023-02-08 18:30:00	2023-02-08 19:30:00	\N	\N	4	0	\N	\N
704776	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	 Compétences de la collectivité de Saint-Barthélemy 	\N	2023-03-28 10:15:00	2023-03-28 11:05:00	\N	\N	3	0	\N	\N
704780	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	 Compétences de la collectivité de Saint-Barthélemy 	\N	2023-02-28 10:15:00	2023-02-28 11:05:00	\N	\N	3	0	\N	\N
704798	COM_SPECIALE	AUDRAP	\N	CZAN	\N	Audition CS ZAN	Audition CS ZAN	2023-02-28 08:00:00	2023-02-28 08:40:00	\N	\N	6	0	\N	\N
704822	MISSION	AUDRAP	\N	GEAU	\N	Audition Mme Haziza	\N	2023-03-01 14:00:00	2023-03-01 15:00:00	\N	\N	5	0	\N	\N
704829	MISSION	AUCUNE	\N	LOCA	\N	Réunion constitutive de la mission d'information Finances locales	Réunion constitutive de la mission d'information "impact des décisions réglementaires et budgétaires sur l'équilibre fin	2023-03-01 17:30:00	2023-03-01 18:05:00	2023-03-01 18:18:35	2023-03-02 10:08:22	15	0	\N	\N
705105	MISSION	AUDRAP	\N	GEAU	\N	Audition Mme Habets	\N	2023-03-01 18:00:00	2023-03-01 19:35:00	\N	\N	8	0	\N	\N
705112	DELEGATION	AUDRAP	\N	\N	206	Audition sobriété énergétique	\N	2023-02-21 15:00:00	2023-02-21 18:00:00	\N	\N	2	0	\N	\N
705122	DELEGATION	AUDRAP	\N	\N	206	Audition sobriété énergétique	\N	2023-02-22 09:00:00	2023-02-22 11:00:00	\N	\N	2	0	\N	\N
705126	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 8 mars 2023	\N	2023-03-08 13:45:00	2023-03-08 14:30:00	2023-03-08 14:28:11	2023-03-08 17:31:48	15	0	\N	\N
705127	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 9 mars 2022	\N	2023-03-09 09:30:00	2023-03-09 11:00:00	2023-03-09 17:27:45	2023-03-10 17:32:37	15	0	\N	\N
705456	MISSION	AUDRAP	\N	BATI	\N	MIBS	\N	2023-03-01 13:45:00	2023-03-01 15:00:00	\N	\N	6	0	\N	\N
706240	GIA	AUCUNE	\N	\N	\N	déplacement à Bruxelles - rencontre de l'Ambassadrice du Dalaï Lama	déplacement à Bruxelles - rencontre de l'Ambassadrice du Dalaï Lama	2023-02-27 08:30:00	2023-02-27 18:30:00	\N	\N	1	0	634	\N
706242	GIA	AUCUNE	\N	\N	\N	Commémoration à Rome du soulèvement des Tibétains à Lhassa	Commémoration à Rome du soulèvement des Tibétains à Lhassa	2023-03-09 23:30:00	2023-03-10 22:00:00	\N	\N	1	0	634	\N
706249	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Motion référendaire	Motion référendaire	2023-03-03 09:30:00	2023-03-03 11:05:00	\N	\N	78	0	\N	\N
745557	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Données de connexion	\N	2023-06-20 17:30:00	2023-06-20 18:30:00	\N	\N	3	0	\N	\N
745798	GIA	AUCUNE	\N	\N	\N	Réception à l'ambassade du Pakistan en France	Réception à l'ambassade du Pakistan en France	2023-06-20 13:00:00	2023-06-20 15:00:00	\N	\N	3	0	619	\N
746007	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Déplacement au Salon du Bourget	\N	2023-06-22 07:30:00	2023-06-22 16:00:00	\N	\N	5	0	\N	\N
746142	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Régime juridique des actions de groupe	PPL Régime juridique des actions de groupe	2023-06-23 11:45:00	2023-06-23 12:45:00	\N	\N	1	0	\N	\N
746147	DELEGATION	AUCUNE	\N	\N	206	Examen du rapport sur la sobriété énergétique	\N	2023-06-27 14:05:00	2023-06-27 15:00:00	\N	\N	7	0	\N	\N
746195	ETUDES	AUTRE	\N	\N	\N	Réunion Hydrogène et mobilité lourde	Réunion Hydrogène et mobilité lourde	2023-06-21 08:15:00	2023-06-21 09:30:00	\N	\N	11	0	\N	906
746498	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Données de santé - Audition commune DGOS/DGS	\N	2023-06-27 15:00:00	2023-06-27 16:00:00	\N	\N	4	0	\N	\N
746773	COM_ENQUETE	PLENIERE	\N	MEDIC	\N	Réunion plénière	\N	2023-07-04 14:05:00	2023-07-04 15:20:00	2023-07-04 15:52:48	2023-07-05 18:21:49	15	0	\N	\N
760615	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Secrétariat général de l'enseignement catholique (SGEC)	\N	2023-10-26 08:30:00	2023-10-26 09:15:00	\N	\N	1	0	\N	\N
760695	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-10-31 14:30:00	2023-10-31 18:10:00	2023-10-31 20:57:14	2023-11-02 12:36:46	25	0	\N	\N
760733	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions rapporteur	PJLF pour 2024 - Mission outre-mer	2023-10-26 11:00:00	2023-10-26 12:15:00	\N	\N	1	0	\N	\N
760734	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions rapporteur	PJLF pour 2024 - Mission outre-mer	2023-10-26 09:30:00	2023-10-26 10:40:00	\N	\N	1	0	\N	\N
760741	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJLF 2024 - JVA	\N	2023-10-24 15:00:00	2023-10-24 16:30:00	\N	\N	2	0	\N	\N
760742	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PJLF 2024 - Enseignement agricole	\N	2023-10-26 09:30:00	2023-10-26 11:50:00	\N	\N	1	0	\N	\N
760765	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Amnistie des faits commis lors de mouvements sociaux - Abrogation article 40 (amdts)	PPL Amnistie des faits commis lors de mouvements sociaux - Abrogation article 40 de la Constitution (amendements)	2023-10-31 14:00:00	2023-10-31 14:10:00	2023-10-31 14:38:22	2023-11-02 12:36:45	19	3	\N	\N
760766	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	France Universités	\N	2023-10-26 14:00:00	2023-10-26 15:00:00	\N	\N	2	0	\N	\N
760767	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Conférence des grandes écoles	\N	2023-10-26 15:00:00	2023-10-26 16:00:00	\N	\N	2	0	\N	\N
760768	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Union des grandes écoles indépendantes (UGEI) 	\N	2023-10-26 16:00:00	2023-10-26 17:00:00	\N	\N	1	0	\N	\N
760775	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2024 Assurance maladie - Audition de l'ANSM	\N	2023-10-26 09:15:00	2023-10-26 10:15:00	\N	\N	1	0	\N	\N
760776	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2024 Assurance maladie - Audition de la DGOS	\N	2023-10-26 13:30:00	2023-10-26 14:30:00	\N	\N	1	0	\N	\N
760823	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 71 - Exam. amendements de séance PPL920, Exam. rapport PLF2024 Pouvoirs publics	PLENIERE - 71 - Exam. amendements de séance PPL920, Exam. rapport PLF2024 Pouvoirs publics	2023-10-30 14:35:00	2023-10-30 15:10:00	2023-10-30 17:00:41	2023-10-30 18:15:53	17	2	\N	\N
760824	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Avis Agriculture - audition MM. Duplomb, Tissot et Menonville	Avis Agriculture - audition MM. Duplomb, Tissot et Menonville	2023-10-24 15:30:00	2023-10-24 17:00:00	\N	\N	3	0	\N	\N
760825	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions MM. Duplomb, Tissot et Menonville	Auditions MM. Duplomb, Tissot et Menonville	2023-10-24 19:00:00	2023-10-24 20:00:00	\N	\N	3	0	\N	\N
799071	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur	\N	2024-02-13 16:15:00	2024-02-13 17:15:00	\N	\N	1	0	\N	\N
760826	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions MM. Duplomb, Tissot et Menonville	Auditions MM. Duplomb, Tissot et Menonville	2023-10-25 14:30:00	2023-10-25 15:30:00	\N	\N	3	0	\N	\N
760827	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Avis Agriculture - audition MM. Duplomb, Tissot et Menonville	Avis Agriculture - audition MM. Duplomb, Tissot et Menonville	2023-10-25 16:30:00	2023-10-25 19:30:00	\N	\N	3	0	\N	\N
760828	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Immigration - Audition M. BOUCHER, directeur général de l'OFPRA	PLF pour 2024 - Immigration - Audition M. BOUCHER, directeur général de l'OFPRA	2023-10-23 11:00:00	2023-10-23 12:00:00	\N	\N	1	0	\N	\N
760830	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Immigration - Audition M. JALON, directeur général de la DGEF	PLF pour 2024 - Immigration - Audition M. JALON, directeur général de la DGEF	2023-10-23 12:00:00	2023-10-23 13:00:00	\N	\N	1	0	\N	\N
760832	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Immigration - Audition M. LESCHI, directeur général de l'OFII	PLF pour 2024 - Immigration - Audition M. LESCHI, directeur général de l'OFII	2023-10-23 15:00:00	2023-10-23 16:00:00	\N	\N	1	0	\N	\N
760834	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Immigration - Audition de la DGPN	PLF pour 2024 - Immigration - Audition de la DGPN	2023-10-24 14:30:00	2023-10-24 15:30:00	\N	\N	1	0	\N	\N
760836	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Sécurités - Audition de la Délégation à la sécurité routière	PLF pour 2024 - Sécurités - Audition de la Délégation à la sécurité routière	2023-10-24 15:30:00	2023-10-24 16:30:00	\N	\N	1	0	\N	\N
760838	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Sécurités - Audition France Universités	PLF pour 2024 - Sécurités - Audition France Universités	2023-10-24 10:00:00	2023-10-24 11:00:00	\N	\N	1	0	\N	\N
760840	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Enseignement supérieur - Audition Mme MARCHAND, présidente du CNOUS	PLF pour 2024 - Enseignement supérieur - Audition Mme MARCHAND, présidente du CNOUS	2023-10-24 14:30:00	2023-10-24 15:30:00	\N	\N	1	0	\N	\N
760991	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Justice - Audition secréatriat général du ministère de la justice	PLF pour 2024 - Justice - Audition secréatriat général du ministère de la justice	2023-10-26 14:30:00	2023-10-26 16:00:00	\N	\N	1	0	\N	\N
760993	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Justice - Audition MM. BARJON et BOUBES, agence Immobilier de la justice	PLF pour 2024 - Justice - Audition MM. BARJON et BOUBES de l'Agence pour l'Immobilier de la justice	2023-10-26 16:00:00	2023-10-26 17:05:00	\N	\N	1	0	\N	\N
760999	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Ecologie, transports - Audition Société du Grand Paris	PLF pour 2024 - Ecologie, transports - Audition M. MONTEILS, président du directoire de la Société du Grand Paris	2023-10-24 09:00:00	2023-10-24 10:00:00	\N	\N	2	0	\N	\N
761002	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Table ronde Collectivités territoriales	\N	2023-10-30 15:30:00	2023-10-30 16:50:00	\N	\N	3	0	\N	\N
761003	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Collège des directeurs des écoles nationales supérieures d¿architecture	\N	2023-10-30 17:00:00	2023-10-30 18:00:00	\N	\N	3	0	\N	\N
761004	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - BACEA - Audition M. ARKWRIGHT, directeur général d'ADP	PLF pour 2024 - BACEA - Audition M. ARKWRIGHT, directeur général d'ADP	2023-10-25 16:30:00	2023-10-25 17:30:00	\N	\N	1	0	\N	\N
761006	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - BACEA - Audition M. SORIANO, directeur général de l'IGN	PLF pour 2024 - BACEA - Audition M. SORIANO, directeur général de l'IGN	2023-10-25 17:30:00	2023-10-25 18:30:00	\N	\N	1	0	\N	\N
761008	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Ministère de la culture -  (DG2TDC)	\N	2023-10-30 10:45:00	2023-10-30 12:00:00	\N	\N	2	0	\N	\N
761009	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - BACEA - Audition M. BERTEAUD, directeur général du CEREMA	PLF pour 2024 - BACEA - Audition M. BERTEAUD, directeur général du CEREMA	2023-10-26 11:30:00	2023-10-26 12:30:00	\N	\N	1	0	\N	\N
761011	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Ministère de la culture - direction générale de la création artistique	\N	2023-10-30 12:00:00	2023-10-30 13:00:00	\N	\N	2	0	\N	\N
761012	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Audition CMA CGM et Image Sept	PLF pour 2024 - Audition CMA CGM et Image Sept	2023-10-24 09:30:00	2023-10-24 10:30:00	\N	\N	1	0	\N	\N
643057	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Réunion sénateurs américains	\N	2022-05-20 14:40:00	2022-05-20 15:50:00	\N	\N	3	0	\N	\N
648466	COM_PERMANENTE	AUTRE	\N	CAE	\N	Table ronde sécurité de l'approvisionnement énergétique	\N	2022-07-13 08:30:00	2022-07-13 10:40:00	2022-07-13 15:51:28	2022-07-13 19:07:02	46	1	\N	\N
648755	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition  de M. Pap Ndiaye, ministre de l'Education nationale et de la jeunesse.	\N	2022-07-13 16:30:00	2022-07-13 19:00:00	2022-07-15 09:42:24	2022-07-15 16:50:22	31	0	\N	\N
655728	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2022-09-20 14:30:00	2022-09-20 17:15:00	\N	\N	4	0	\N	\N
666548	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	ONG Israël Palestine	audition avec des représentants d'ONG Israël Palestine	2022-10-25 16:00:00	2022-10-25 17:15:00	\N	\N	8	0	\N	\N
673034	GIA	AUCUNE	\N	\N	\N	Entreitoe avec M. Alain CHOURAQUI, Président de la Fondation du Camp des Milles	\N	2022-11-15 12:30:00	2022-11-15 14:00:00	\N	\N	19	0	595	\N
682611	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL DDADUE - Audition ANSM	\N	2022-11-30 17:30:00	2022-11-30 18:30:00	\N	\N	2	0	\N	\N
682747	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions M. Laurent Duplomb	Auditions M. Laurent Duplomb	2022-12-01 10:00:00	2022-12-01 11:00:00	\N	\N	1	0	\N	\N
686718	GIA	AUCUNE	\N	\N	\N	Visite au Sénat de Mme Diana MENHEM, économiste libanaise, experte en politiques publiques	Visite au Sénat de Mme Diana MENHEM, économiste libanaise, experte en politiques publiques et directrice exécutive de l'	2022-12-06 14:15:00	2022-12-06 15:00:00	\N	\N	1	0	597	\N
688794	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	\N	\N	2023-01-05 09:30:00	2023-01-05 12:20:00	\N	\N	1	0	\N	\N
690804	ETUDES	AUCUNE	\N	\N	\N	Audition du Centre français des fonds et fondations	Audition du Centre français des fonds et fondations	2023-01-11 13:30:00	2023-01-11 14:30:00	\N	\N	3	0	\N	998
690828	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Jeux Olympiques et Paralympiques de 2024	PJL Jeux Olympiques et Paralympiques de 2024	2023-01-13 14:00:00	2023-01-13 14:50:00	\N	\N	1	0	\N	\N
698656	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL  Militaires fusillés	PPL  Militaires fusillés	2023-02-02 14:30:00	2023-02-02 16:00:00	\N	\N	65	0	\N	\N
698733	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ambassadeur de France au Népal	Entretien avec M. Gilles BOURBAO, Ambassadeur de France au Népal	2023-02-02 12:35:00	2023-02-02 14:10:00	\N	\N	1	0	633	\N
699128	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 8 : Nominations article 13 - M. Nicolas DUFOURCQ, candidat proposé aux fonction	PLENIERE - 8 : Nominations article 13 - M. Nicolas DUFOURCQ, candidat proposé aux fonction	2023-02-08 11:30:00	2023-02-08 12:50:00	2023-02-08 14:59:46	2023-02-09 11:07:22	29	0	\N	\N
699130	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition de Mme Chain-Larché	\N	2023-01-30 16:00:00	2023-01-30 19:30:00	\N	\N	1	0	\N	\N
699132	DELEGATION	AUCUNE	\N	\N	DSOM	Audition de la Fédération nationale des Safer	\N	2023-03-02 08:45:00	2023-03-02 10:30:00	\N	\N	10	0	\N	\N
699133	COM_ENQUETE	PLENIERE	\N	RENOV	\N	Auditions ministres	\N	2023-02-07 18:00:00	2023-02-07 20:00:00	2023-02-08 16:42:29	2023-02-09 11:09:05	15	0	\N	\N
699145	MISSION	AUTRE	\N	BATI	\N	Réunion constitutive	\N	2023-02-07 13:45:00	2023-02-07 14:30:00	2023-02-08 12:20:58	2023-02-09 11:09:04	10	0	\N	\N
699280	AUTRE_TEMPORAIRE	AUTRE	\N	CAE	\N	Réunion constitutive	\N	2023-02-07 16:00:00	2023-02-07 17:00:00	\N	\N	0	0	\N	\N
699284	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Réunion constitutive	\N	2023-02-07 16:00:00	2023-02-07 17:00:00	\N	\N	0	0	\N	\N
699498	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Mme Chain-Larché	\N	2023-02-07 13:00:00	2023-02-07 14:15:00	\N	\N	2	0	\N	\N
699641	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI expertise patrim	\N	2023-02-07 09:30:00	2023-02-07 10:30:00	\N	\N	3	0	\N	\N
699647	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	fraudes artistiques	\N	2023-02-07 16:00:00	2023-02-07 17:30:00	\N	\N	2	0	\N	\N
699814	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 9 Suivi de la conjoncture économique - Audition Pierre-Louis BRAS (COR)	PLENIERE - 9 Suivi de la conjoncture économique - Audition Pierre-Louis BRAS (COR)	2023-02-14 16:30:00	2023-02-14 17:55:00	2023-02-14 18:50:50	2023-02-15 17:33:41	32	0	\N	\N
703668	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	 Compétences de la collectivité de Saint-Barthélemy 	 Compétences de la collectivité de Saint-Barthélemy 	2023-02-15 14:00:00	2023-02-15 15:00:00	\N	\N	1	0	\N	\N
703675	COM_SPECIALE	AUDRAP	\N	CZAN	\N	Auditions CS ZAN	Auditions CS ZAN	2023-02-14 15:30:00	2023-02-14 16:15:00	\N	\N	10	0	\N	\N
703688	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	 Compétences de la collectivité de Saint-Barthélemy 	Compétences de la collectivité de Saint-Barthélemy	2023-02-15 17:30:00	2023-02-15 19:45:00	\N	\N	1	0	\N	\N
703820	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - PJL Immigration et intégration	Audition rapporteur - PJL Immigration et intégration	2023-02-15 14:00:00	2023-02-15 15:00:00	\N	\N	3	0	\N	\N
703823	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - PJL Immigration et intégration	Audition rapporteur - PJL Immigration et intégration	2023-02-15 17:15:00	2023-02-15 18:00:00	\N	\N	3	0	\N	\N
703827	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - PJL Immigration et intégration	Audition rapporteur - PJL Immigration et intégration	2023-02-15 18:00:00	2023-02-15 20:00:00	\N	\N	4	0	\N	\N
704146	GIA	AUCUNE	\N	\N	\N	Entretien avec Maud Joseph, Directrice de la CCI franco-ukrainienne	Entretien avec Maud Joseph, Directrice de la CCI franco-ukrainienne	2023-02-15 14:00:00	2023-02-15 15:00:00	\N	\N	5	0	530	\N
704313	COM_ENQUETE	PLENIERE	\N	RENOV	\N	Auditions	\N	2023-02-27 15:00:00	2023-02-28 19:20:00	2023-02-27 19:31:22	2023-02-28 16:04:31	8	0	\N	\N
704329	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 11 Examen rapport PLFRSS Mme VERMEILLET	PLENIERE - 11 Examen rapport PLFRSS Mme VERMEILLET	2023-02-28 15:00:00	2023-02-28 15:55:00	2023-03-01 09:14:22	2023-03-01 16:37:32	27	4	\N	\N
704330	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Réunion du GT subsidiarité du 2 mars 2022	\N	2023-03-02 08:35:00	2023-03-02 08:50:00	\N	\N	3	0	\N	\N
704331	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 12 Auditions Cryptoactifs	PLENIERE - 12 Auditions Cryptoactifs	2023-03-01 09:30:00	2023-03-01 12:25:00	2023-03-01 15:20:41	2023-03-01 16:37:28	29	0	\N	\N
704582	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Violences intrafamiliales	\N	2023-02-28 14:45:00	2023-02-28 17:00:00	\N	\N	2	0	\N	\N
704585	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Violences intrafamiliales	\N	2023-02-28 17:00:00	2023-02-28 17:15:00	\N	\N	1	0	\N	\N
704762	GIA	AUCUNE	\N	\N	\N	entretien avec Mme Nyamkhuu Ulambayar, Ambassadrice de Mongolie en France	\N	2023-02-28 18:30:00	2023-02-28 22:00:00	\N	\N	8	0	612	\N
708050	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFRSS	PLFRSS	2023-03-06 10:00:00	2023-03-06 13:00:00	\N	\N	123	0	\N	\N
708051	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFRSS	PLFRSS	2023-03-06 14:30:00	2023-03-06 20:00:00	\N	\N	166	0	\N	\N
708052	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFRSS	PLFRSS	2023-03-06 21:30:00	2023-03-07 03:10:00	\N	\N	10	0	\N	\N
708136	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	MI Brésil	MI Brésil	2023-03-01 14:15:00	2023-03-01 15:00:00	\N	\N	5	0	\N	\N
708473	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 13 : Audtion P. MOSCOVICI (CPO)-Contrôle Budgétaire SNU-Désignation rapporteurs	PLENIERE - 13 : Audtion P. MOSCOVICI (CPO)-Contrôle Budgétaire SNU-Désignation rapporteurs	2023-03-08 09:35:00	2023-03-08 11:20:00	2023-03-08 18:03:15	2023-03-09 14:54:34	28	1	\N	\N
709771	GIA	AUCUNE	\N	\N	\N	entretien avec le général Jean-François Morel	\N	2023-03-08 08:30:00	2023-03-08 09:30:00	\N	\N	4	0	661	\N
713465	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI TND - Audition d'associations d'hyperacrifs	\N	2023-03-14 14:30:00	2023-03-14 16:30:00	\N	\N	2	0	\N	\N
713466	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI TND - Audition FDCMPP	\N	2023-03-16 09:30:00	2023-03-16 10:30:00	\N	\N	2	0	\N	\N
713467	DELEGATION	AUDRAP	\N	\N	206	Audition OpenExp	\N	2023-03-09 09:00:00	2023-03-09 12:00:00	\N	\N	2	0	\N	\N
713470	DELEGATION	AUDRAP	\N	\N	206	Audition dans le cadre de la saisine « lois de programmation militaires et innovation »	\N	2023-03-09 09:30:00	2023-03-09 11:00:00	\N	\N	1	0	\N	\N
713475	DELEGATION	AUCUNE	\N	\N	COLTER	Audition de M. Pascal Berteaud, directeur général du CEREMA	\N	2023-03-23 09:00:00	2023-03-23 10:15:00	2023-03-23 13:15:30	\N	8	0	\N	\N
741138	GIA	AUCUNE	\N	\N	\N	Entretien/débat en présence de M. Jean-Arnault DERENS et de M. Laurent GESLIN,	Entretien/débat en présence de M. Jean-Arnault DERENS et de M. Laurent GESLIN,	2023-06-13 08:30:00	2023-06-13 09:30:00	\N	\N	5	0	674	\N
741144	GIA	AUCUNE	\N	\N	\N	Entretien/débat en présence de M. Jean-Arnault DERENS et de M. Laurent GESLIN,	Entretien/débat en présence de M. Jean-Arnault DERENS et de M. Laurent GESLIN,	2023-06-13 08:30:00	2023-06-13 09:30:00	\N	\N	4	0	571	\N
741160	COM_SPECIALE	AUDRAP	\N	ESNU	\N	PJL Sécuriser et réguler l'espace numérique	PJL Sécuriser et réguler l'espace numérique	2023-06-15 13:15:00	2023-06-15 14:45:00	\N	\N	2	0	\N	\N
749387	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2023-06-29 09:45:00	2023-06-29 11:30:00	\N	\N	3	0	\N	\N
753649	GIA	AUCUNE	\N	\N	\N	reunion	\N	2023-10-06 18:00:00	2023-10-06 19:00:00	\N	\N	1	0	556	\N
760868	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2024 - Audition DSS	\N	2023-10-30 11:00:00	2023-10-30 12:00:00	\N	\N	1	0	\N	\N
760914	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Réunion GT subsidiarité du 16 novembre 2023	Réunion GT subsidiarité du 16 novembre 2023	2023-11-16 08:35:00	2023-11-16 08:50:00	\N	\N	2	0	\N	\N
760919	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Médias, livres et industrie culturelle - Audition Radio France	PLF pour 2024 - Médias, livres et industrie culturelle - Audition Mme VEIL et M. BON de Radio France	2023-10-24 19:00:00	2023-10-24 20:00:00	\N	\N	1	0	\N	\N
760925	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Enseignement supérieur - Audition du cabinet de la Ministre	PLF pour 2024 - Enseignement supérieur - Audition du cabinet de la Ministre	2023-10-25 14:30:00	2023-10-25 16:00:00	\N	\N	2	0	\N	\N
760929	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Enseignement supérieur - Audition DGESIP	PLF pour 2024 - Enseignement supérieur - Audition DGESIP	2023-10-26 17:30:00	2023-10-26 18:30:00	\N	\N	1	0	\N	\N
760932	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Enseignement supérieur - Audition Union ds Grandes Ecoles Indépendantes	PLF pour 2024 - Enseignement supérieur - Audition Union ds Grandes Ecoles Indépendantes	2023-10-26 18:30:00	2023-10-26 19:10:00	\N	\N	1	0	\N	\N
760935	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Gestion finances publiques - Audition DGFIP	PLF pour 2024 - Gestion finances publiques - Audition M. MAGNANT et Mme FONTAINE, de la DGFIP	2023-10-24 17:15:00	2023-10-24 18:25:00	\N	\N	1	0	\N	\N
760970	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Gestion finances publiques - Audition SG ministère de l'Economie	PLF pour 2024 - Gestion finances publiques - Audition du secrétariat général du ministère de l'Economie	2023-10-24 18:30:00	2023-10-24 19:20:00	\N	\N	1	0	\N	\N
760985	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Gestion finances publiques - Audition DGDDI	PLF pour 2024 - Gestion finances publiques - Audition Direction générale des douanes et des droits indirects	2023-10-25 14:00:00	2023-10-25 14:50:00	\N	\N	1	0	\N	\N
761553	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions MM. Duplomb, Tissot et Menonville	Auditions MM. Duplomb, Tissot et Menonville	2023-10-31 08:00:00	2023-10-31 09:00:00	\N	\N	1	0	\N	\N
761557	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions MM. Duplomb, Menonville et Tissot	Auditions MM. Duplomb, Menonville et Tissot	2023-11-02 09:00:00	2023-11-02 10:00:00	\N	\N	1	0	\N	\N
761563	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Immigration et intégration (amendements)	PJL Immigration et intégration (amendements)	2023-11-06 14:10:00	2023-11-06 15:40:00	2023-11-07 08:58:12	2023-11-07 17:14:40	23	4	\N	\N
761564	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Immigration et intégration (amendements)	PJL Immigration et intégration (amendements)	2023-11-07 09:00:00	2023-11-07 09:55:00	2023-11-07 10:25:59	2023-11-07 17:14:40	21	3	\N	\N
761567	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Emeutes survenues depuis le 27 juin 2023 - Audition de sociologues	Emeutes survenues depuis le 27 juin 2023 - Audition de sociologues	2023-11-08 11:00:00	2023-11-08 12:30:00	2023-11-08 14:48:39	2023-11-08 17:48:07	13	0	\N	\N
761576	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Fédération des établissements d'enseignement supérieur d'intérêt collectif	\N	2023-11-02 09:00:00	2023-11-02 09:45:00	\N	\N	2	0	\N	\N
761577	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Udice	\N	2023-11-02 09:45:00	2023-11-02 10:30:00	\N	\N	2	0	\N	\N
761578	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Centre national des oeuvres universitaires et scolaires	\N	2023-11-02 10:30:00	2023-11-02 11:15:00	\N	\N	3	0	\N	\N
761579	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Conférence des directeurs des écoles françaises d¿ingénieurs	\N	2023-11-02 11:15:00	2023-11-02 12:00:00	\N	\N	2	0	\N	\N
761596	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Sécurités - Audition Direction générale de la gendarmerie nationale	PLF pour 2024 - Sécurités - Audition Direction générale de la gendarmerie nationale	2023-10-30 10:00:00	2023-10-30 11:00:00	\N	\N	1	0	\N	\N
761599	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Economie - Audition de BpiFrance	PLF pour 2024 - Economie - Audition de BpiFrance	2023-10-31 10:00:00	2023-10-31 11:00:00	\N	\N	2	0	\N	\N
761602	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Economie - Audition de la direction générale des entreprises (DGE)	PLF pour 2024 - Economie - Audition de la direction générale des entreprises (DGE)	2023-10-31 11:00:00	2023-10-31 12:00:00	\N	\N	2	0	\N	\N
761605	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Economie - Audition M. SCHWOB de la DGCCRF	PLF pour 2024 - Economie - Audition M. SCHWOB de la DGCCRF	2023-10-31 12:00:00	2023-10-31 13:00:00	\N	\N	2	0	\N	\N
761608	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - RG - Audition de Régions de France	PLF pour 2024 - RG - Audition de MM. PERRIN-SARZIER et TISSANDIER de Régions de France	2023-10-31 09:30:00	2023-10-31 10:30:00	\N	\N	1	0	\N	\N
761610	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - RG - Audition de l'Association des Maires de France (AMF)	PLF pour 2024 - RG - Audition de l'Association des Maires de France (AMF)	2023-10-31 13:15:00	2023-10-31 14:10:00	\N	\N	1	0	\N	\N
761612	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - RG - Audition de M. MAULIN de Domaines skiables de France (DSF)	PLF pour 2024 - RG - Audition de M. MAULIN de Domaines skiables de France (DSF)	2023-10-31 18:00:00	2023-10-31 18:45:00	\N	\N	1	0	\N	\N
761614	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Justice - Audition MM. CHAULET et HUBERT, DPJJ	PLF pour 2024 - Justice - Audition MM. CHAULET et HUBERT d ela Direction de la protection judiciaire de la jeunesse	2023-11-02 14:10:00	2023-11-02 15:20:00	\N	\N	1	0	\N	\N
761616	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2024 Assurance maladie et Autonomie - Audition de la DSS	\N	2023-10-31 13:30:00	2023-10-31 15:00:00	\N	\N	4	0	\N	\N
761621	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Andra	Audition Andra	2023-10-31 09:30:00	2023-10-31 10:00:00	\N	\N	1	0	\N	\N
761622	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition AVERE-France - Association pour le développement de la mobilité électrique	Audition AVERE-France - Association pour le développement de la mobilité électrique	2023-10-31 10:00:00	2023-10-31 10:30:00	\N	\N	1	0	\N	\N
761623	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Médiateur national de l'énergie	Audition Médiateur national de l'énergie	2023-10-31 13:45:00	2023-10-31 14:30:00	\N	\N	1	0	\N	\N
761624	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Union française des industries pétrolières Énergies et mobilités	Audition Union française des industries pétrolières Énergies et mobilités	2023-10-31 14:30:00	2023-10-31 15:00:00	\N	\N	2	0	\N	\N
761625	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Fédération nationale des collectivités concédantes et régies	Audition Fédération nationale des collectivités concédantes et régies	2023-10-31 15:00:00	2023-10-31 15:30:00	\N	\N	2	0	\N	\N
761626	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition Fédération nationale des collectivités concédantes et régies	Audition Fédération nationale des collectivités concédantes et régies	2023-10-31 15:30:00	2023-10-31 16:00:00	\N	\N	1	0	\N	\N
639010	GIA	AUCUNE	\N	\N	\N	Déjeuner du groupe en présence de S E M Balzaretti	Déjeuner du groupe en présence de S E M Balzaretti	2022-05-10 13:00:00	2022-05-10 15:00:00	\N	\N	10	0	610	\N
642531	GIA	AUCUNE	\N	\N	\N	Petit-déjeuner chargé d'affaires ambassade du Pakistan	\N	2022-05-11 08:15:00	2022-05-11 09:45:00	\N	\N	3	0	619	\N
783498	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Jean-Pierre OBIN	\N	2023-12-18 15:30:00	2023-12-18 16:30:00	\N	\N	5	0	\N	\N
761566	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Immigration et intégration (amendements)	PJL Immigration et intégration (amendements)	2023-11-08 09:40:00	2023-11-08 10:25:00	2023-11-08 14:47:28	2023-11-10 14:28:41	35	4	\N	\N
761593	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-11-08 08:30:00	2023-11-08 13:05:00	2023-11-08 13:26:24	2023-11-08 17:48:10	45	0	\N	\N
643032	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - Secrétariats généraux communs - Ministères bénéficiares	Contrôle 2022 - Secrétariats généraux communs - Ministères bénéficiares	2022-05-17 17:00:00	2022-05-17 18:30:00	\N	\N	1	0	\N	\N
643034	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - Secrétariats généraux communs - TR Syndicats ministère Intérieur	Contrôle 2022 - Secrétariats généraux communs - TR Syndicats ministère Intérieur	2022-05-18 16:00:00	2022-05-18 18:00:00	\N	\N	1	0	\N	\N
643036	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - Secrétariats généraux communs - DMAT et DRHMI/Syndicats FP	Contrôle 2022 - Secrétariats généraux communs - DMAT et DRHMI/Syndicats FP	2022-05-19 09:00:00	2022-05-19 12:45:00	\N	\N	1	0	\N	\N
643038	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2022 - Secrétariats généraux communs - DINUM MI	Contrôle 2022 - Secrétariats généraux communs - DINUM MI	2022-05-19 15:30:00	2022-05-19 17:30:00	\N	\N	1	0	\N	\N
643040	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 25 mai 2022	Réunion du 25 mai 2022	2022-05-25 09:35:00	2022-05-25 11:30:00	2022-05-25 14:05:52	2022-05-27 16:46:29	16	0	\N	\N
643041	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 24 mai 2022	Réunion du 24 mai 2022	2022-05-24 16:00:00	2022-05-24 17:20:00	2022-05-24 17:22:35	2022-05-27 16:46:28	17	0	\N	\N
643042	COM_EURO	AUDRAP	\N	AFEU	\N	Devoir de vigilance	\N	2022-05-03 13:30:00	2022-05-03 14:30:00	\N	\N	3	0	\N	\N
643046	COM_EURO	AUDRAP	\N	AFEU	\N	Devoir de vigilance	\N	2022-05-05 11:15:00	2022-05-05 12:15:00	\N	\N	3	0	\N	\N
643050	COM_EURO	AUDRAP	\N	AFEU	\N	Devoir de vigilance	\N	2022-05-05 12:15:00	2022-05-05 13:15:00	\N	\N	2	0	\N	\N
643053	COM_EURO	AUDRAP	\N	AFEU	\N	Devoir de vigilance	\N	2022-05-05 15:30:00	2022-05-05 16:30:00	\N	\N	3	0	\N	\N
643061	MECSS	AUDRAP	\N	\N	MECSS	MI Unification du recouvrement - Audition CNAF	\N	2022-05-24 14:30:00	2022-05-24 15:30:00	\N	\N	6	0	\N	\N
643062	MECSS	AUDRAP	\N	\N	MECSS	MI Fraude sociale au sein des caisses - Audition CNAV	\N	2022-05-31 14:00:00	2022-05-31 15:00:00	\N	\N	4	0	\N	\N
643063	MECSS	AUDRAP	\N	\N	MECSS	MI Fraude sociale au sein des caisses - Audition Urssaf Caisse nationale	\N	2022-05-31 15:00:00	2022-05-31 16:00:00	\N	\N	3	0	\N	\N
644915	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ambassadeur aux Fidji	Entretien avec François-Xavier Léger, ambassadeur aux Fidji	2022-06-15 08:30:00	2022-06-15 09:40:00	\N	\N	6	0	651	\N
645578	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Audition MCC Délinquance des mineurs	Ecole des XV	2022-06-22 14:30:00	2022-06-22 15:30:00	\N	\N	5	0	\N	\N
645762	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	GE arts de la scène et des festivals	\N	2022-06-28 15:30:00	2022-06-28 17:30:00	\N	\N	4	0	\N	\N
646292	GIA	AUCUNE	\N	\N	\N	Coopé - Entr. Mme Hila Wesa, conseillère politique pour le dossier israélo-palestinien au	Coopé - Entr. Mme Hila Wesa, conseillère politique pour le dossier israélo-palestinien au	2022-07-05 12:30:00	2022-07-05 14:00:00	\N	\N	1	0	648	\N
658045	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2022-09-29 09:00:00	2022-09-29 10:32:00	\N	\N	3	0	\N	\N
669731	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF 2023 - programme 129	PLF 2023 - programme 129	2022-11-02 08:00:00	2022-11-02 09:00:00	\N	\N	2	0	\N	\N
680224	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Misssion Sport	Misssion Sport	2022-11-25 15:35:00	2022-11-25 17:30:00	\N	\N	41	0	\N	\N
687400	GIA	AUCUNE	\N	\N	\N	PDJ Marc Julienne (IFRI)	Petit-déjeuner avec Dr Marc Julienne (IFRI)	2022-12-14 08:30:00	2022-12-14 09:45:00	\N	\N	9	0	623	\N
690765	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Groupe de travail Décentralisation	Décentralisation - auditions rapporteurs	2023-01-12 08:30:00	2023-01-12 09:45:00	\N	\N	4	0	\N	\N
690770	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Groupe de travail Décentralisation	Décentralisation - auditions rapporteurs	2023-01-12 09:45:00	2023-01-12 11:00:00	\N	\N	7	0	\N	\N
690778	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Groupe de travail Décentralisation	Décentralisation - auditions rapporteurs	2023-01-12 11:00:00	2023-01-12 12:20:00	\N	\N	5	0	\N	\N
692467	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI cinéma	\N	2023-01-20 11:00:00	2023-01-20 12:00:00	\N	\N	4	0	\N	\N
695213	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	1821	\N	\N	Explications de vote PJL JO 2024	Explications de vote PJL JOP	2023-01-31 14:30:00	2023-01-31 15:35:00	\N	\N	247	0	\N	\N
695214	SEANCE_PLENIERE	SCRUSOL	1821	\N	\N	Scrutin solennel PJL JO 2024	Scrutin solennel	2023-01-31 15:35:00	2023-01-31 15:45:00	\N	\N	0	0	\N	\N
697954	ETUDES	AUCUNE	\N	\N	\N	Table ronde sur le loup	Table ronde sur le loup	2023-02-01 13:15:00	2023-02-01 14:25:00	\N	\N	12	0	\N	911
700719	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur	Audition rapporteur - PPL Service public de l'assainissement francilien	2023-02-08 13:45:00	2023-02-08 14:45:00	\N	\N	2	0	\N	\N
701641	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2023-02-14 09:30:00	2023-02-14 12:40:00	\N	\N	46	0	\N	\N
701642	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Encadrement des centres de santé	PPL Encadrement des centres de santé	2023-02-14 14:30:00	2023-02-14 16:35:00	\N	\N	124	0	\N	\N
701643	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Accès aux soins	PPL Accès aux soins	2023-02-14 16:35:00	2023-02-14 20:00:00	\N	\N	137	0	\N	\N
701644	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Accès aux soins	PPL Accès aux soins	2023-02-14 21:30:00	2023-02-14 23:10:00	\N	\N	57	0	\N	\N
701645	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2023-02-15 15:00:00	2023-02-15 16:20:00	\N	\N	296	0	\N	\N
701647	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Approvisionnement grande conso	PPL Approvisionnement grande conso	2023-02-15 16:30:00	2023-02-15 20:25:00	\N	\N	86	0	\N	\N
701649	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	2 conventions internationales	2 conventions internationales	2023-02-16 10:30:00	2023-02-16 10:35:00	\N	\N	4	0	\N	\N
701651	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	2e Lect. PPL Victimes violences conjugales	2e Lect. PPL Victimes violences conjugales	2023-02-16 10:35:00	2023-02-16 11:35:00	\N	\N	32	0	\N	\N
701652	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP DDADUE	CMP DDADUE	2023-02-16 11:35:00	2023-02-16 12:30:00	\N	\N	26	0	\N	\N
701653	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	EV PPL rénovation énergétique LEC	EV PPL rénovation énergétique LEC	2023-02-16 12:30:00	2023-02-16 13:20:00	\N	\N	19	0	\N	\N
701672	QUESTURE	AUCUNE	\N	\N	\N	Réunion de Questure	Réunion de Questure	2023-02-08 17:00:00	2023-02-08 18:22:00	\N	\N	3	0	\N	\N
704043	GIA	AUCUNE	\N	\N	\N	Réunion de travail pour préparer la conférence du 21 mars	Réunion de travail sur les prisonniers politiques biélorusses 	2023-02-15 14:15:00	2023-02-15 15:00:00	\N	\N	1	0	852	\N
706385	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de MM. Thomas Gomart et Bruno Tertrais	Audition de MM. Thomas Gomart et Bruno Tertrais	2023-03-08 09:35:00	2023-03-08 11:15:00	2023-03-08 12:16:51	2023-03-08 17:31:08	32	3	\N	\N
708149	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	LPM	\N	2023-03-28 14:30:00	2023-03-28 15:30:00	\N	\N	1	0	\N	\N
708152	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI LPM programme 144	MI LPM programme 144	2023-03-01 17:00:00	2023-03-01 18:00:00	\N	\N	2	0	\N	\N
753741	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL Industrie verte - Echange entre rapporteurs	PJL Industrie verte - Echange entre rapporteurs	2023-10-03 09:00:00	2023-10-03 10:10:00	\N	\N	1	0	\N	\N
753745	COM_PERMANENTE	AUTRE	\N	CAE	\N	PPL Rôle des maires	\N	2023-10-10 14:00:00	2023-10-10 14:25:00	2023-10-10 14:33:44	2023-10-10 18:01:59	32	5	\N	\N
753747	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion de la CATDD	\N	2023-10-11 09:00:00	2023-10-11 12:00:00	2023-10-11 13:39:21	2023-10-11 18:16:59	36	0	\N	\N
753748	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion CATDD	\N	2023-10-11 16:30:00	2023-10-11 17:45:00	2023-10-11 18:37:06	2023-10-12 18:13:00	21	0	\N	\N
757788	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL Épargnants et exploitations agricoles - Audition M. SOURLAS et Mme TERTRAIS, AMF	PPL Épargnants et exploitations agricoles - Audition M. SOURLAS et Mme TERTRAIS, AMF	2023-10-18 19:20:00	2023-10-18 20:10:00	\N	\N	1	0	\N	\N
757825	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2024 Autonomie - Audition de la Fnadepa	\N	2023-10-18 13:30:00	2023-10-18 14:15:00	\N	\N	5	0	\N	\N
757988	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PLF pour 2024 - Avis Fonction publique	Audition rapporteur - PLF 2024 - Avis fonction publique	2023-10-23 15:00:00	2023-10-23 16:00:00	\N	\N	1	0	\N	\N
758121	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Table ronde syndicats d'enseignants	\N	2023-10-23 16:00:00	2023-10-23 17:40:00	\N	\N	10	0	\N	\N
758168	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2024 - Audition CCMSA	\N	2023-10-24 09:00:00	2023-10-24 10:00:00	\N	\N	2	0	\N	\N
758172	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2024 Assurance maladie - Audition de l'APHP	\N	2023-10-24 09:20:00	2023-10-24 10:15:00	\N	\N	4	0	\N	\N
758173	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2024 - Audition HAS	\N	2023-10-24 10:15:00	2023-10-24 11:00:00	\N	\N	2	0	\N	\N
758334	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	plf recherche	\N	2023-10-24 15:30:00	2023-10-24 16:45:00	\N	\N	1	0	\N	\N
758354	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2024 - Audition Unédic	\N	2023-10-24 15:00:00	2023-10-24 16:15:00	\N	\N	2	0	\N	\N
758373	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF 2024 - Crédits du cinéma	\N	2023-10-24 15:00:00	2023-10-24 16:00:00	\N	\N	1	0	\N	\N
758660	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Enseignement scolaire - Audition DGRH	PLF pour 2024 - Enseignement scolaire - Audition MM. MELMOX-EUDES et ESTOURNET et Mme SOUFFLET-CARPENTIER, DGRH	2023-10-20 09:30:00	2023-10-20 11:00:00	\N	\N	1	0	\N	\N
758699	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Enseignement scolaire - Audition Syndicats d'enseignants	PLF pour 2024 - Enseignement scolaire - Audition Mme BARKATE, SGEN-CFDT, et M. GIRARD, SNALC	2023-10-20 15:30:00	2023-10-20 17:00:00	\N	\N	1	0	\N	\N
758704	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLF pour 2024 - Avis Juridictions administratives et Juridictions financières	PJLF pour 2024 - Avis Juridictions administratives et Juridictions financières	2023-10-24 13:30:00	2023-10-24 17:00:00	\N	\N	1	0	\N	\N
758725	DELEGATION	AUCUNE	\N	\N	206	Réunion constitutive	\N	2023-10-24 17:35:00	2023-10-24 18:05:00	\N	\N	19	0	\N	\N
758748	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PLF patrimoine	\N	2023-10-24 16:00:00	2023-10-24 17:00:00	\N	\N	2	0	\N	\N
759801	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PLFSS 2024 Autonomie - Audition de la Plateforme de coordination et d'orientation de Paris	\N	2023-10-25 13:30:00	2023-10-25 14:15:00	\N	\N	2	0	\N	\N
760696	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2023-10-05 18:00:00	2023-10-05 18:59:00	\N	\N	29	0	\N	\N
760737	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Épargnants et exploitations agricoles françaises	PPL Épargnants et exploitations agricoles françaises	2023-10-30 16:00:00	2023-10-30 17:50:00	\N	\N	42	0	\N	\N
760738	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Interdire l'usage de l'écriture inclusive 	PPL Interdire l'usage de l'écriture inclusive 	2023-10-30 21:30:00	2023-10-30 23:55:00	\N	\N	69	0	\N	\N
760739	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Amnistie des faits commis à l'occasion de mouvements sociaux 	PPL Amnistie des faits commis à l'occasion de mouvements sociaux 	2023-10-31 14:30:00	2023-10-31 16:05:00	\N	\N	69	0	\N	\N
760740	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPLC Abroger l'article 40 de la Constitution 	PPLC Abroger l'article 40 de la Constitution 	2023-10-31 16:15:00	2023-10-31 17:50:00	\N	\N	54	0	\N	\N
760788	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition M. Duffourg	\N	2023-10-25 13:45:00	2023-10-25 14:30:00	\N	\N	1	0	\N	\N
760792	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Duffourg	\N	2023-10-26 11:45:00	2023-10-26 13:00:00	\N	\N	1	0	\N	\N
760794	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Duffourg	\N	2023-10-26 14:45:00	2023-10-26 15:45:00	\N	\N	1	0	\N	\N
760796	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition M. Duffourg	\N	2023-10-26 17:00:00	2023-10-26 19:00:00	\N	\N	1	0	\N	\N
760798	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions Mme Chain-Larché	\N	2023-10-23 09:45:00	2023-10-23 15:00:00	\N	\N	1	0	\N	\N
760800	COM_PERMANENTE	AUDRAP	\N	CAE	\N	France urbaine / Ville & Banlieue	France urbaine / Ville & Banlieue	2023-10-24 11:00:00	2023-10-24 12:00:00	\N	\N	1	0	\N	\N
760801	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Politique de la Ville - DGCL	Politique de la Ville - DGCL	2023-10-24 09:00:00	2023-10-24 10:00:00	\N	\N	1	0	\N	\N
760803	COM_PERMANENTE	AUDRAP	\N	CAE	\N	AFFECO - Politique de la Ville - ANCT	AFFECO - Politique de la Ville - ANCT	2023-10-24 10:00:00	2023-10-24 11:00:00	\N	\N	1	0	\N	\N
760806	COM_PERMANENTE	AUDRAP	\N	CAE	\N	AFFECO - Politique de la Ville - ANRU	AFFECO - Politique de la Ville - ANRU	2023-10-24 12:00:00	2023-10-24 13:00:00	\N	\N	1	0	\N	\N
716280	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition de M. Philippe Caduc, ADIT	\N	2023-03-16 16:00:00	2023-03-16 17:00:00	\N	\N	3	0	\N	\N
706386	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Examen d'une convention internationale	Examen d'une convention internationale	2023-03-08 11:15:00	2023-03-08 11:25:00	2023-03-08 12:15:41	2023-03-08 17:31:05	32	3	\N	\N
758135	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2023-10-25 10:00:00	2023-10-25 11:20:00	2023-10-25 17:23:12	2023-10-26 10:46:07	42	3	\N	\N
760808	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Rencontre avec deux personnalités chargées d'une mission par la Première ministre	Rencontre avec deux personnalités chargées d'une mission par la Première ministre	2023-10-25 11:30:00	2023-10-25 12:15:00	\N	\N	1	0	\N	\N
760811	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions rapporteur	\N	2023-10-27 14:00:00	2023-10-27 16:10:00	\N	\N	0	0	\N	\N
763707	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PLF 2024 - CAE - Outre-mer	Audition PLF 2024 - CAE - Outre-mer	2023-11-06 09:00:00	2023-11-06 12:45:00	\N	\N	1	0	\N	\N
764866	COM_PERMANENTE	AUTRE	\N	ETRD	\N	PLF2024 - audition Amiral Nicolas Vaujour	PLF2024 - audition Amiral Nicolas Vaujour	2023-11-15 09:30:00	2023-11-15 11:10:00	2023-11-15 15:54:37	2023-11-15 17:21:57	35	4	\N	\N
764908	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PLFSS pour 2024 - Examen amdts séance	\N	2023-11-13 13:30:00	2023-11-13 15:40:00	2023-11-13 15:36:29	2023-11-14 18:04:32	28	3	\N	\N
764910	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PLFSS pour 2024 - Suite examen amdts séance	\N	2023-11-14 13:30:00	2023-11-14 14:30:00	2023-11-16 16:40:44	2023-11-16 18:27:54	27	0	\N	\N
765398	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2024	PLFSS 2024	2023-11-13 16:00:00	2023-11-13 20:05:00	\N	\N	68	0	\N	\N
765399	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2024	PLFSS 2024	2023-11-13 21:35:00	2023-11-14 00:35:00	\N	\N	62	0	\N	\N
765400	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	1961	\N	\N	Explications de vote sur l'ensemble	Explications de vote sur l'ensemble	2023-11-14 14:30:00	2023-11-14 15:45:00	\N	\N	300	0	\N	\N
765401	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2024	PLFSS 2024	2023-11-14 16:00:00	2023-11-14 20:00:00	\N	\N	139	0	\N	\N
765402	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2024	PLFSS 2024	2023-11-14 21:30:00	2023-11-15 01:05:00	\N	\N	113	0	\N	\N
765403	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2023-11-15 15:00:00	2023-11-15 16:15:00	\N	\N	300	0	\N	\N
765404	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2024	PLFSS 2024	2023-11-15 16:30:00	2023-11-15 20:05:00	\N	\N	125	0	\N	\N
765405	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLFSS 2024	PLFSS 2024	2023-11-15 21:35:00	2023-11-16 01:25:00	\N	\N	72	0	\N	\N
640683	MISSION	AUCUNE	\N	FONDSMER	\N	Audition Mme C. Krajka puis audition de l'UICN	\N	2022-04-05 17:00:00	2022-04-05 19:00:00	\N	\N	0	0	\N	\N
641705	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition MI métropoles Lyon Aix-Marseille-Provence	\N	2022-04-21 11:00:00	2022-04-21 12:15:00	\N	\N	6	0	\N	\N
642036	GIA	AUCUNE	\N	\N	\N	Coopé - Entretien avec M. Timcho MUCUNSKI, député	Coopé - Entretien avec M. Timcho MUCUNSKI, député	2022-05-03 14:30:00	2022-05-03 15:15:00	\N	\N	1	0	674	\N
643066	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2022-05-20 08:30:00	2022-05-20 20:30:00	\N	\N	3	0	\N	\N
656175	COM_PERMANENTE	AUTRE	\N	ETRD	\N	3 conventions - 1 rapport d'information Méditerranée	\N	2022-09-27 15:00:00	2022-09-27 16:21:00	2022-09-28 09:56:57	2022-09-28 16:49:38	18	7	\N	\N
664748	GIA	AUCUNE	\N	\N	\N	Coopé - Visite au Sénat d une délégation d¿auditeurs de la Cour des comptes  du Burundi	Visite au Sénat d une délégation d¿auditeurs de la Cour des comptes  du Burundi	2022-10-19 16:15:00	2022-10-19 17:15:00	\N	\N	1	0	572	\N
692288	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Protéger les logements contre l'occupation illicite	PPL Protéger les logements contre l'occupation illicite	2023-01-18 16:00:00	2023-01-18 17:00:00	\N	\N	2	0	\N	\N
698945	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - PPL Service public de l'assainissement francilien	Audition rapporteur - PPL Service public de l'assainissement francilien	2023-01-31 17:30:00	2023-01-31 18:30:00	\N	\N	1	0	\N	\N
698947	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - PPL Service public de l'assainissement francilien	Audition rapporteur - PPL Service public de l'assainissement francilien	2023-02-01 14:15:00	2023-02-01 14:45:00	\N	\N	1	0	\N	\N
699134	COM_SPECIALE	PLENIERE	\N	CINC	\N	Réunion plénière CS Incendie	Réunion plénière CS Incendie	2023-02-07 13:45:00	2023-02-07 14:45:00	2023-02-07 18:23:29	2023-02-09 11:09:07	26	0	\N	\N
705637	GIA	AUCUNE	\N	\N	\N	Entretien avec M. DITH Tina, ministre de l'agriculture du Cambodge	Entretien avec M. DITH Tina, ministre de l'agriculture du Cambodge	2023-03-02 13:00:00	2023-03-02 14:30:00	\N	\N	2	0	577	\N
708434	COM_ENQUETE	PLENIERE	\N	RENOV	\N	Auditions plénières	\N	2023-03-06 15:00:00	2023-03-06 18:50:00	2023-03-07 18:22:08	2023-03-08 17:32:03	9	0	\N	\N
710016	GIA	AUCUNE	\N	\N	\N	accueil d'une délégation de députés kosovars	M. Alush Gashi, leader de la Ligue Démocratique du Kosovo, et M. Lumir Abdixhiku, député	2023-03-08 12:00:00	2023-03-08 13:00:00	\N	\N	1	0	674	\N
713477	DELEGATION	AUCUNE	\N	\N	211	Parentalité Outremer : Table ronde Mayotte	\N	2023-03-16 10:35:00	2023-03-16 12:15:00	\N	\N	7	0	\N	\N
715210	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de M. Emmanuel Levacher	Audition de M. Emmanuel Levacher	2023-03-22 09:30:00	2023-03-22 10:30:00	2023-03-22 14:28:37	2023-03-22 15:24:37	31	0	\N	\N
715211	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Examen rapport d'information P. 212	Examen rapport d'information P. 212	2023-03-22 10:30:00	2023-03-22 11:30:00	2023-03-22 14:30:16	2023-03-22 15:24:39	31	5	\N	\N
715703	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-03-16 09:30:00	2023-03-16 10:30:00	\N	\N	0	0	\N	\N
715715	ETUDES	AUTRE	\N	\N	\N	TR Rat taupe	\N	2023-03-15 08:00:00	2023-03-15 09:15:00	\N	\N	11	0	\N	911
715733	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-03-16 10:50:00	2023-03-16 10:55:00	2023-03-16 11:24:00	2023-03-16 14:02:32	17	2	\N	\N
716138	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Revaloriser le statut de secrétaire de mairie	PPL Revaloriser le statut de secrétaire de mairie	2023-03-14 14:30:00	2023-03-14 18:15:00	\N	\N	1	0	\N	\N
716157	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Revaloriser le statut de secrétaire de mairie	PPL Revaloriser le satut de secrétaire de mairie	2023-03-15 16:30:00	2023-03-15 17:30:00	\N	\N	2	0	\N	\N
716257	DELEGATION	AUCUNE	\N	\N	DSOM	Foncier agricole outre-mer : table ronde Mayotte	\N	2023-03-23 08:30:00	2023-03-23 10:45:00	\N	\N	8	0	\N	\N
716270	COM_PERMANENTE	AUDRAP	\N	CAE	\N	TR Synfic et CDSE	\N	2023-03-16 14:00:00	2023-03-16 15:00:00	\N	\N	4	0	\N	\N
716275	COM_PERMANENTE	AUDRAP	\N	CAE	\N	CCI	\N	2023-03-16 15:00:00	2023-03-16 16:00:00	\N	\N	4	0	\N	\N
764867	COM_PERMANENTE	AUTRE	\N	ETRD	\N	PLF2024 - examen 2 rapports avis budgétaires	PLF2024 - examen 2 rapports avis budgétaires	2023-11-15 11:15:00	2023-11-15 12:15:00	2023-11-15 15:58:22	2023-11-15 17:22:07	38	5	\N	\N
716286	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Fédération nationale des chasseurs	Fédération nationale des chasseurs	2023-03-14 16:00:00	2023-03-14 17:30:00	\N	\N	1	0	\N	\N
716290	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Charles Stépanoff - Anthropologue	Charles Stépanoff - Anthropologue	2023-03-02 11:30:00	2023-03-02 12:30:00	\N	\N	1	0	\N	\N
716293	COM_PERMANENTE	AUDRAP	\N	CAE	\N	DEB	DEB	2023-03-02 14:30:00	2023-03-02 15:30:00	\N	\N	1	0	\N	\N
716295	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auteure pétition	Auteure pétition	2023-02-23 15:00:00	2023-02-23 16:00:00	\N	\N	1	0	\N	\N
716297	COM_PERMANENTE	AUDRAP	\N	CAE	\N	ASPAS	ASPAS	2023-02-22 15:00:00	2023-02-22 16:30:00	\N	\N	1	0	\N	\N
716302	COM_PERMANENTE	AUDRAP	\N	CAE	\N	TR Évaluation et gestion des dégâts	TR Évaluation et gestion des dégâts	2023-02-22 16:30:00	2023-02-22 17:45:00	\N	\N	1	0	\N	\N
716306	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Arnaud Bazin	Arnaud Bazin	2023-02-20 14:30:00	2023-02-20 15:30:00	\N	\N	1	0	\N	\N
716361	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-03-22 08:30:00	2023-03-22 09:20:00	\N	\N	25	0	\N	\N
716362	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Audition commune Associations liées au Handicap	\N	2023-03-16 09:30:00	2023-03-16 10:30:00	\N	\N	1	0	\N	\N
716363	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	association des maires ruraux de France (AMRF)	\N	2023-03-16 10:30:00	2023-03-16 11:30:00	\N	\N	2	0	\N	\N
716364	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-03-22 09:30:00	2023-03-22 10:45:00	2023-03-22 10:52:14	2023-03-22 15:24:37	24	0	\N	\N
716368	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MASTERCARD France	\N	2023-03-16 09:45:00	2023-03-16 10:45:00	\N	\N	1	0	\N	\N
716369	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	comité d'organisation des jeux olympiques et paralympiques de 2024	\N	2023-03-16 10:45:00	2023-03-16 12:00:00	\N	\N	6	0	\N	\N
716530	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Accueil du SIGEM	Accueil du SIGEM (Séminaire interarmées des grandes écoles militaires)	2023-03-14 14:30:00	2023-03-14 16:30:00	\N	\N	2	0	\N	\N
716585	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition GT tourisme	Audition GT tourisme	2023-03-15 13:30:00	2023-03-15 14:30:00	\N	\N	2	0	\N	\N
716588	COM_PERMANENTE	AUDRAP	\N	CAE	\N	EDF	\N	2023-03-15 16:45:00	2023-03-15 17:15:00	\N	\N	0	0	\N	\N
716589	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	MI Fraude à l'Arenh	MI Fraude à l'Arenh	2023-03-15 17:00:00	2023-03-15 17:30:00	\N	\N	5	0	\N	\N
716595	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	MI Fraude à l'Arenh	MI Fraude à l'Arenh	2023-03-15 17:30:00	2023-03-15 18:00:00	\N	\N	4	0	\N	\N
716600	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	MI Fraude à l'Arenh	MI Fraude à l'Arenh	2023-03-15 18:00:00	2023-03-15 19:00:00	\N	\N	4	0	\N	\N
716605	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPLC Projet de loi de financement CT - Audition B. HAUCHECORNE et L. WAYMEL (AMRF)	PPLC Projet de loi de financement CT - Audition B. HAUCHECORNE et L. WAYMEL (AMRF)	2023-03-16 15:30:00	2023-03-16 17:00:00	\N	\N	1	0	\N	\N
716607	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 Engagements financiers de l'Etat - Risque PGE Audition Cour des Comptes	Contrôle 2023 Engagements financiers de l'Etat - Risque PGE Audition Cour des Comptes	2023-03-16 14:00:00	2023-03-16 15:30:00	\N	\N	1	0	\N	\N
716609	COM_ENQUETE	PLENIERE	\N	RENOV	\N	Auditions plénières 	\N	2023-03-20 15:05:00	2023-03-20 20:15:00	2023-03-21 10:51:09	2023-03-21 16:37:00	7	0	\N	\N
716610	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition Xavier Niel	\N	2023-03-22 09:30:00	2023-03-22 11:05:00	2023-03-22 11:38:48	2023-03-22 15:24:38	40	0	\N	\N
716611	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2023 Engagements financiers de l'Etat - Risque PGE Audition DG Trésor	Contrôle 2023 Engagements financiers de l'Etat - Risque PGE Audition DG Trésor	2023-03-16 15:30:00	2023-03-16 17:20:00	\N	\N	1	0	\N	\N
716613	MISSION	AUTRE	\N	LOCA	\N	Audition de l'AMF et de l'AMPVF	\N	2023-03-21 15:50:00	2023-03-21 18:00:00	\N	\N	11	0	\N	\N
716619	ETUDES	AUTRE	\N	\N	\N	Audition ANEL	Audition ANEL	2023-03-15 14:00:00	2023-03-15 15:00:00	\N	\N	5	0	\N	908
716624	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Audition commune associations nationales des parents d'élèves	\N	2023-03-20 10:00:00	2023-03-20 12:00:00	\N	\N	2	0	\N	\N
717232	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Parité dans la fonction publique	Proposition de loi visant à renforcer l'accès des femmes aux responsabilités dans la fonction publique	2023-03-21 14:30:00	2023-03-21 15:30:00	\N	\N	2	0	\N	\N
773521	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE 89 - PLF pour 2024 - Suite examen amdts sénace 1ère partie	PLENIERE 89 - PLF pour 2024 - Suite examen amdts sénace 1ère partie	2023-11-27 21:00:00	2023-11-27 21:15:00	2023-12-06 14:44:41	2023-12-06 18:22:50	16	4	\N	\N
780021	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE 97 - PLF pour 2024 - Examen amdts missions et non-rattachés	PLENIERE 97 - PLF pour 2024 - Examen amdts missions et non-rattachés	2023-12-11 09:30:00	2023-12-11 10:00:00	2023-12-15 16:35:38	2023-12-15 16:56:40	9	3	\N	\N
780280	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Bien vieillir - Audition de la FHF	\N	2023-12-11 15:00:00	2023-12-11 16:00:00	\N	\N	7	0	\N	\N
780289	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Société du bien-vieillir - Audition du Synerpa	\N	2023-12-11 16:00:00	2023-12-11 17:00:00	\N	\N	5	0	\N	\N
780295	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Société du bien-vieillir - Audition de la Fehap	\N	2023-12-11 17:15:00	2023-12-11 18:15:00	\N	\N	5	0	\N	\N
783102	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Comité interministériel des outre-mer	Débat Comité interministériel des outre-mer	2023-12-14 14:35:00	2023-12-14 15:10:00	\N	\N	34	0	\N	\N
783129	GIA	AUCUNE	\N	\N	\N	Accueil Ministre des RI Norzin Dolma	Accueil Ministre des RI Norzin Dolma	2023-12-14 08:15:00	2023-12-14 09:30:00	\N	\N	4	0	634	\N
789316	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe d'amitié France-Arménie 	Réun,ion des membres du groupe d'amitié France-Arménie	2024-01-16 18:00:00	2024-01-16 18:30:00	\N	\N	16	0	641	\N
789333	GIA	AUCUNE	\N	\N	\N	Réunion de travail France-Arménie 	Réunion préparatoire à l'AG France-Arménie	2024-01-16 09:40:00	2024-01-16 10:10:00	\N	\N	1	0	641	\N
791382	SEANCE_PLENIERE	DECL_GVT	\N	\N	\N	Déclaration du Gouvernement	Déclaration du Gouvernement	2024-01-30 15:00:00	2024-01-30 16:20:00	\N	\N	262	0	\N	\N
791391	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Bâtir la société du bien-vieillir en France	PPL Bâtir la société du bien-vieillir en France	2024-01-30 17:40:00	2024-01-30 20:00:00	\N	\N	108	0	\N	\N
791392	SEANCE_PLENIERE	DECL_GVT	\N	\N	\N	Déclaration du Gouvernement	Déclaration du Gouvernement	2024-01-31 15:00:00	2024-01-31 17:40:00	\N	\N	282	0	\N	\N
791394	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Bâtir la société du bien-vieillir en France	PPL Bâtir la société du bien-vieillir en France	2024-01-31 17:00:00	2024-01-31 20:00:00	\N	\N	65	0	\N	\N
791395	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2024-02-01 09:45:00	2024-02-01 10:25:00	\N	\N	11	0	\N	\N
791423	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Bâtir la société du bien-vieillir en France	PPL Bâtir la société du bien-vieillir en France	2024-01-30 21:30:00	2024-01-31 00:30:00	\N	\N	53	0	\N	\N
791425	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Bâtir la société du bien-vieillir en France	PPL Bâtir la société du bien-vieillir en France	2024-01-31 21:30:00	2024-02-01 00:45:00	\N	\N	39	0	\N	\N
791839	GIA	AUCUNE	\N	\N	\N	Petit-déjeuner de travail avec l'Ambassadrice de Roumanie en France	\N	2024-01-30 08:30:00	2024-01-30 10:30:00	\N	\N	5	0	605	\N
797370	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Garantir la confidentialité des consultations juridiques	Audition rapporteur - PPL Garantir la confidentialité des consultations juridiques	2024-01-30 14:00:00	2024-01-30 15:00:00	\N	\N	3	0	\N	\N
797377	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Garantir la confidentialité des consultations juridiques	Audition rapporteur - PPL Garantir la confidentialité des consultations juridiques	2024-01-30 17:30:00	2024-01-30 18:45:00	\N	\N	1	0	\N	\N
797382	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Garantir la confidentialité des consultations juridiques	Audition rapporteur - PPL Garantir la confidentialité des consultations juridiques	2024-01-31 16:00:00	2024-01-31 18:20:00	\N	\N	1	0	\N	\N
797385	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Garantir la confidentialité des consultations juridiques	Audition rapporteur - PPL Garantir la confidentialité des consultations juridiques	2024-02-02 14:10:00	2024-02-02 14:55:00	\N	\N	1	0	\N	\N
797387	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Garantir la confidentialité des consultations juridiques	Audition rapporteur - PPL Garantir la confidentialité des consultations juridiques	2024-02-02 15:00:00	2024-02-02 17:05:00	\N	\N	3	0	\N	\N
797391	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Garantir la confidentialité des consultations juridiques	Audition rapporteur - PPL Garantir la confidentialité des consultations juridiques	2024-02-02 17:05:00	2024-02-02 18:00:00	\N	\N	2	0	\N	\N
797406	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - MI Respect des principes de la République	rAudition rapporteur - MI Respect des principes de la République	2024-02-07 14:00:00	2024-02-07 15:00:00	\N	\N	2	0	\N	\N
797409	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - MI Respect des principes de la République	Audition rapporteur - MI Respect des principes de la République	2024-02-07 16:30:00	2024-02-07 17:30:00	\N	\N	4	0	\N	\N
797414	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - PJLO Élections provinciales en Nouvelle-Calédonie	Audition rapporteur - PJLO Élections provinciales en Nouvelle-Calédonie	2024-02-06 08:30:00	2024-02-06 10:15:00	\N	\N	1	0	\N	\N
797416	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - PJLO Élections provinciales en Nouvelle-Calédonie	Audition rapporteur - PJLO Élections provinciales en Nouvelle-Calédonie	2024-02-06 17:00:00	2024-02-06 18:00:00	\N	\N	1	0	\N	\N
797418	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - PJLO Élections provinciales en Nouvelle-Calédonie	Audition rapporteur - PJLO Élections provinciales en Nouvelle-Calédonie	2024-02-07 07:30:00	2024-02-07 08:30:00	\N	\N	1	0	\N	\N
797429	GIA	AUCUNE	\N	\N	\N	Dîner du CCACF 	Invitation de la communauité assyro-chaldéenne	2024-02-06 19:00:00	2024-02-06 23:00:00	\N	\N	6	0	1013	\N
797831	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Auditions MI lutte anti-drone	Auditions MI lutte anti-drones	2024-02-07 17:30:00	2024-02-07 19:30:00	\N	\N	2	0	\N	\N
804836	MECSS	AUDRAP	\N	\N	MECSS	MI Fiscalité comportementale - Audition de l'ACT	\N	2024-03-15 15:00:00	2024-03-15 16:00:00	\N	\N	3	0	\N	\N
804837	MECSS	AUDRAP	\N	\N	MECSS	MI Fiscalité comportementale - Audition de l'IREF	\N	2024-03-15 16:00:00	2024-03-15 17:00:00	\N	\N	3	0	\N	\N
804839	MECSS	AUDRAP	\N	\N	MECSS	MI Fiscalité comportementale - Audition de Fabrice Etilé	\N	2024-03-21 10:00:00	2024-03-21 11:00:00	\N	\N	3	0	\N	\N
804984	DELEGATION	AUCUNE	\N	\N	211	Examen du rapport de la mission flash "Familles monoparentales"	\N	2024-03-28 09:00:00	2024-03-28 10:30:00	\N	\N	11	0	\N	\N
814801	BUREAU	AUCUNE	\N	\N	\N	Délégation en charge du travail parlementaire	Délégation en charge du travail parlementaire	2024-03-27 11:00:00	2024-03-27 13:00:00	\N	\N	1	0	\N	\N
815903	GIA	AUCUNE	\N	\N	\N	Audition de l'Ambassadeur de France en Australie	Audition de l'Ambassadeur de France en Australie	2024-03-28 08:15:00	2024-03-28 10:00:00	\N	\N	6	0	578	\N
773653	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2023-11-23 09:00:00	2023-11-23 11:45:00	\N	\N	3	0	\N	\N
777388	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audition sur l'accord d'établissement de la Banque mondiale à Paris	Audition sur l'accord d'établissement de la Banque mondiale à Paris	2023-12-05 14:00:00	2023-12-05 14:50:00	\N	\N	1	0	\N	\N
777995	COM_ENQUETE	PLENIERE	\N	NARCO	\N	Auditions : Mildeca - SGMer - SEJF - OFDT	Auditions : Mildeca - SGMer - SEJF - OFDT	2023-12-11 14:00:00	2023-12-11 18:00:00	2023-12-11 21:08:38	2023-12-12 18:14:03	10	0	\N	\N
777996	COM_ENQUETE	PLENIERE	\N	NARCO	\N	Table ronde de chercheurs	Table ronde de chercheurs	2023-12-12 09:00:00	2023-12-12 10:35:00	2023-12-12 10:36:49	2023-12-12 18:14:04	11	0	\N	\N
778003	COM_EURO	AUDRAP	\N	AFEU	\N	Auditions Europe du médicament	Auditions Europe du médicament	2023-11-29 14:00:00	2023-11-29 15:00:00	\N	\N	3	0	\N	\N
778008	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Europe du médicament	Audition Europe du médicament	2023-11-30 15:00:00	2023-11-30 16:00:00	\N	\N	3	0	\N	\N
778012	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion CATDD	\N	2023-12-06 11:05:00	2023-12-06 12:00:00	2023-12-06 14:18:43	2023-12-06 18:26:19	24	0	\N	\N
778081	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Réforme du Pacte de stabilité et de croissance	Audition Réforme du Pacte de stabilité et de croissance	2023-12-05 16:00:00	2023-12-05 17:00:00	\N	\N	2	0	\N	\N
779382	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024 Mission Culture	PLF 2024 Mission Culture	2023-12-07 21:30:00	2023-12-07 22:20:00	\N	\N	43	0	\N	\N
779560	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Application loi JOP 	Audition rapporteur - MI « JOP »	2023-12-07 10:00:00	2023-12-07 12:00:00	\N	\N	2	0	\N	\N
779563	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Application loi JOP 	Audition rapporteur - MI « JOP »	2023-12-07 14:30:00	2023-12-07 19:30:00	\N	\N	2	0	\N	\N
779642	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024 Mission Sport 	PLF 2024 Mission Sport 	2023-12-11 10:30:00	2023-12-11 12:55:00	\N	\N	43	0	\N	\N
779643	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024 Mission Justice	PLF 2024 Mission Justice	2023-12-11 14:30:00	2023-12-11 17:05:00	\N	\N	60	0	\N	\N
801349	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	MI Atos	\N	2024-02-20 13:30:00	2024-02-20 17:00:00	\N	\N	0	0	\N	\N
779645	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024 Mission Défense	PLF 2024 Mission Défense	2023-12-11 17:10:00	2023-12-11 19:30:00	\N	\N	70	0	\N	\N
779646	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024 Articles non rattachés	PLF 2024 Articles non rattachés	2023-12-11 19:30:00	2023-12-11 20:00:00	\N	\N	50	0	\N	\N
779647	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024 Articles non rattachés	PLF 2024 Articles non rattachés	2023-12-11 21:30:00	2023-12-12 01:10:00	\N	\N	52	0	\N	\N
779650	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR Intitulé commission de la culture	PPR Intitulé commission de la culture	2023-12-12 16:55:00	2023-12-12 17:40:00	\N	\N	41	0	\N	\N
779652	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2023-12-13 15:00:00	2023-12-13 16:15:00	\N	\N	300	0	\N	\N
779653	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Réemploi des véhicules	PPL Réemploi des véhicules	2023-12-13 16:35:00	2023-12-13 18:20:00	\N	\N	30	0	\N	\N
779654	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Allocation autonomie universelle d'études	PPL Allocation autonomie universelle d'études	2023-12-13 18:20:00	2023-12-13 19:50:00	\N	\N	52	0	\N	\N
779655	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Conseil européen 	Débat Conseil européen 	2023-12-13 21:30:00	2023-12-13 23:15:00	\N	\N	26	0	\N	\N
779656	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Transition écologique des bâtiments scolaires	PPL Transition écologique des bâtiments scolaires	2023-12-14 10:30:00	2023-12-14 12:00:00	\N	\N	32	0	\N	\N
779657	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Comité interministériel des outre-mer	Débat Comité interministériel des outre-mer	2023-12-14 12:00:00	2023-12-14 13:05:00	\N	\N	31	0	\N	\N
779658	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPLO Réserve parlementaire	PPLO Réserve parlementaire	2023-12-14 15:10:00	2023-12-14 17:30:00	\N	\N	56	0	\N	\N
779659	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Droits de l'enfant	PPL Droits de l'enfant	2023-12-14 17:30:00	2023-12-14 19:00:00	\N	\N	32	0	\N	\N
794757	GIA	AUCUNE	\N	\N	\N	Entretien avec l'Ambassadrice d'Australie	Entretien avec l'Ambassadrice d'Australie	2024-01-30 15:00:00	2024-01-30 16:00:00	\N	\N	1	0	578	\N
801155	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Thierry PEYROUX, sous-directeur d'Afrique orientale	Entretien avec M. Thierry PEYROUX, sous-directeur d'Afrique orientale	2024-02-13 08:30:00	2024-02-13 09:30:00	\N	\N	9	0	572	\N
801165	GIA	AUCUNE	\N	\N	\N	Entretien avec une délégation du fonds Muskoka/ Unicef	 composée de parlementaires et professionnels de la santé tchadiens et béninois	2024-02-14 08:00:00	2024-02-14 09:20:00	\N	\N	5	0	572	\N
801360	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI Atos	MI Atos	2024-02-20 09:00:00	2024-02-20 12:00:00	\N	\N	2	0	\N	\N
801363	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI Atos	\N	2024-02-20 13:30:00	2024-02-20 17:00:00	\N	\N	1	0	\N	\N
801365	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI Atos	\N	2024-02-20 14:30:00	2024-02-20 17:00:00	\N	\N	1	0	\N	\N
801367	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI Atos	MI Atos	2024-02-21 09:00:00	2024-02-21 11:45:00	\N	\N	2	0	\N	\N
801370	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI Atos	MI Atos	2024-02-21 16:00:00	2024-02-21 20:30:00	\N	\N	2	0	\N	\N
802826	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe	Assemblée générale du groupe	2024-02-07 14:00:00	2024-02-07 14:30:00	\N	\N	4	0	615	\N
802833	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe	Assemblée générale du groupe	2024-02-07 08:30:00	2024-02-07 09:00:00	\N	\N	4	0	648	\N
804102	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Médecine scolaire	Audition rapporteur - PPL Médecine scolaire	2024-02-29 11:30:00	2024-02-29 13:30:00	\N	\N	1	0	\N	\N
812398	COM_ENQUETE	PLENIERE	\N	ELEC	\N	TR flexibilités	\N	2024-03-20 16:30:00	2024-03-20 18:40:00	2024-03-21 14:42:00	2024-03-21 18:32:00	9	0	\N	\N
812484	GIA	AUCUNE	\N	\N	\N	Entretien avec S.E. M. Ahmed Mohammed Nasser AL ARAIMI, ambassadeur d'Oman en France	Entretien avec S.E. M. Ahmed Mohammed Nasser AL ARAIMI, ambassadeur d'Oman en France	2024-03-20 12:00:00	2024-03-20 13:30:00	\N	\N	2	0	661	\N
813235	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - France 2030 - Décarbonation - Audition DALKIA-EDF	Contrôle 2024 - France 2030 - Décarbonation - Audition DALKIA-EDF	2024-03-12 15:00:00	2024-03-12 16:00:00	\N	\N	2	0	\N	\N
813238	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - France 2030 - Décarbonation - Audition Cabinet ministère industrie	Contrôle 2024 - France 2030 - Décarbonation - Audition Cabinet ministère industrie	2024-03-12 16:00:00	2024-03-12 17:00:00	\N	\N	2	0	\N	\N
813241	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Financement recherche spatiale - Audition du GIFAS	Contrôle 2024 - Financement recherche spatiale - Audition du GIFAS	2024-03-15 09:00:00	2024-03-15 10:00:00	\N	\N	1	0	\N	\N
813244	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Financement recherche spatiale - Audition Alliance NewSpace France	Contrôle 2024 - Financement recherche spatiale - Audition Alliance NewSpace France	2024-03-15 10:00:00	2024-03-15 11:00:00	\N	\N	1	0	\N	\N
813248	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Financement recherche spatiale - Audition Fondation recherche stratégique	Contrôle 2024 - Financement recherche spatiale - Audition Fondation recherche stratégique	2024-03-15 11:00:00	2024-03-15 12:00:00	\N	\N	1	0	\N	\N
813261	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Sécurités - Immobilier GN - Audition Association Maires de France	Contrôle 2024 - Sécurités - Immobilier gendramerie nationale - Audition Association Maires de France	2024-03-19 15:00:00	2024-03-19 16:00:00	\N	\N	1	0	\N	\N
770918	BUREAU	AUCUNE	\N	\N	\N	Conseil de Questure	Réunion du Conseil de Questure	2023-11-14 16:00:00	2023-11-14 18:16:00	\N	\N	3	0	\N	\N
772594	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024	PLF 2024	2023-11-27 10:40:00	2023-11-27 13:10:00	\N	\N	59	0	\N	\N
772595	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024	PLF 2024	2023-11-27 14:40:00	2023-11-27 20:00:00	\N	\N	89	0	\N	\N
772596	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024	PLF 2024	2023-11-27 21:30:00	2023-11-28 01:10:00	\N	\N	87	0	\N	\N
772597	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024	PLF 2024	2023-11-28 14:30:00	2023-11-28 20:10:00	\N	\N	182	0	\N	\N
772598	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024	PLF 2024	2023-11-28 21:45:00	2023-11-29 01:45:00	\N	\N	119	0	\N	\N
772599	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024	PLF 2024	2023-11-29 11:00:00	2023-11-29 13:00:00	\N	\N	115	0	\N	\N
772600	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024	PLF 2024	2023-11-29 16:35:00	2023-11-29 19:55:00	\N	\N	127	0	\N	\N
804120	CMP	AUTRE	\N	IFAM	\N	PPL Violences intrafamiliales	PPL Violences intrafamiliales	2024-02-15 14:30:00	2024-02-15 14:45:00	\N	\N	9	0	\N	\N
804131	CMP	AUTRE	\N	SECT	\N	PPL Protection des élus	PPL Protection des élus	2024-02-27 08:34:00	2024-02-27 09:44:00	\N	\N	10	0	\N	\N
772601	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2023-11-29 15:00:00	2023-11-29 16:20:00	\N	\N	278	0	\N	\N
772603	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024	PLF 2024	2023-11-30 14:30:00	2023-11-30 15:55:00	\N	\N	89	0	\N	\N
772604	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024	PLF 2024	2023-11-30 21:00:00	2023-11-30 23:40:00	\N	\N	38	0	\N	\N
772605	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Mission enseignement scolaire	Mission enseignement scolaire	2023-12-01 10:10:00	2023-12-01 13:00:00	\N	\N	57	0	\N	\N
772606	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Mission Recherche	Mission Recherche	2023-12-01 15:15:00	2023-12-01 18:55:00	\N	\N	70	0	\N	\N
772607	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Mission Cohésion des territoires	Mission Cohésion des territoires	2023-12-01 21:30:00	2023-12-02 01:15:00	\N	\N	45	0	\N	\N
772608	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Mission Engagements financiers de l'État	Mission Engagements financiers de l'État	2023-12-02 10:30:00	2023-12-02 12:35:00	\N	\N	40	0	\N	\N
772609	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Mission Économie	Mission Économie	2023-12-02 14:05:00	2023-12-02 20:00:00	\N	\N	52	0	\N	\N
772611	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Mission Pouvoirs publics	Mission Pouvoirs publics	2023-12-02 18:15:00	2023-12-03 20:05:00	\N	\N	29	0	\N	\N
772612	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024	PLF 2024	2023-12-03 10:00:00	2023-12-03 13:00:00	\N	\N	0	0	\N	\N
772614	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024	PLF 2024	2023-12-03 21:30:00	2023-12-04 00:00:00	\N	\N	0	0	\N	\N
772615	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024	PLF 2024	2023-11-29 21:30:00	2023-11-29 23:30:00	\N	\N	97	0	\N	\N
772616	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024	PLF 2024	2023-12-03 14:30:00	2023-12-03 20:00:00	\N	\N	0	0	\N	\N
778545	GIA	AUCUNE	\N	\N	\N	Réception à l'ambassade en l'honneur de la fête nationale de Finlande	Réception à l'ambassade en l'honneur de la fête nationale de Finlande	2023-12-06 12:35:00	2023-12-06 14:15:00	\N	\N	3	0	640	\N
779002	GIA	AUCUNE	\N	\N	\N	Rencontre Croix Rouge ukrainienne	Rencontre avec des repréentants des Croix Rouge ukrainienne et française	2023-12-05 08:30:00	2023-12-05 10:00:00	\N	\N	6	0	530	\N
781245	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Société du bien-vieillir - Audition de Nexem	\N	2023-12-12 09:00:00	2023-12-12 10:00:00	\N	\N	4	0	\N	\N
781261	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Société du bien-vieillir - Audition de l'Uniopss	\N	2023-12-12 10:00:00	2023-12-12 11:00:00	\N	\N	3	0	\N	\N
784553	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	ESH : Mme Magne	\N	2023-12-19 17:30:00	2023-12-19 18:15:00	\N	\N	3	0	\N	\N
786087	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition conseils départementaux	\N	2023-12-20 17:30:00	2023-12-20 19:00:00	\N	\N	8	0	\N	\N
786247	GIA	AUCUNE	\N	\N	\N	Projection du film sur les massacres du 7 octobre en Israël	Projection du film sur les massacres du 7 octobre en Israël	2023-11-21 19:00:00	2023-11-21 20:00:00	\N	\N	42	0	595	\N
797699	COM_ENQUETE	PLENIERE	\N	NARCO	\N	Auditions AFA - IGA-IGF-IGJ - CNPRR	Auditions AFA - IGA-IGF-IGJ - CNPRR	2024-02-12 14:00:00	2024-02-12 18:25:00	2024-02-12 20:24:58	2024-02-13 15:41:27	6	0	\N	\N
797700	COM_ENQUETE	PLENIERE	\N	NARCO	\N	Auditions IGGN-IGPN-ISD	Auditions IGGN-IGPN-ISD	2024-02-13 09:00:00	2024-02-13 10:30:00	2024-02-13 11:58:00	2024-02-13 15:41:29	9	0	\N	\N
797709	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2025 - Audition MM. ROUSSEAU, SMESSEART, CHANDELLIER et JAMET, FNSEA	PLF pour 2025 - Audition MM. ROUSSEAU, SMESSEART, CHANDELLIER et JAMET, FNSEA	2024-02-06 14:15:00	2024-02-06 15:15:00	\N	\N	1	0	\N	\N
797714	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Rénovation de l'habitat dégradé (examen du rapport pour avis)	PJL Rénovation de l'habitat dégradé (examen du rapport pour avis)	2024-02-13 09:00:00	2024-02-13 09:45:00	2024-02-13 10:11:20	2024-02-13 15:39:25	19	6	\N	\N
797715	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJLC Liberté de recourir à l'IVG - Audition d'Eric Dupond-Moretti	PJLC Liberté de recourir à l'IVG - Audition d'Eric Dupond-Moretti	2024-02-13 12:30:00	2024-02-13 13:30:00	2024-02-13 14:17:37	2024-02-13 15:39:25	22	0	\N	\N
797719	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Sûreté dans les transports (amendements)	PPL Sûreté dans les transports (amendements)	2024-02-13 14:00:00	2024-02-13 14:10:00	2024-02-16 15:52:08	2024-02-16 18:31:04	16	5	\N	\N
797721	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJLO/C Congrès et assemblées de la Nouvelle-Calédonie (PJLO) - Audition de Gérald Darmanin	PJLO/C Congrès et assemblées de la Nouvelle-Calédonie (PJLO) - Audition de Gérald Darmanin	2024-02-13 16:10:00	2024-02-13 16:55:00	2024-02-13 17:06:59	2024-02-14 17:57:23	25	0	\N	\N
797750	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPLF pour 2025 - Audition Chambres d'agriculture de France	PPLF pour 2025 - Audition Chambres d'agriculture de France	2024-02-07 08:00:00	2024-02-07 09:00:00	\N	\N	1	0	\N	\N
797761	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GS Egalim - FEEF	GS Egalim - FEEF	2024-02-06 16:30:00	2024-02-06 17:15:00	\N	\N	2	0	\N	\N
797766	DELEGATION	AUDRAP	\N	\N	PROS	IA et santé - Audition du Pr Brigitte Séroussi	\N	2024-02-06 16:30:00	2024-02-06 17:30:00	\N	\N	2	0	\N	\N
797767	DELEGATION	AUDRAP	\N	\N	PROS	IA et santé - Audition de l'Agence de l'innovation en santé	\N	2024-02-06 17:30:00	2024-02-06 18:30:00	\N	\N	2	0	\N	\N
797768	DELEGATION	AUDRAP	\N	\N	PROS	IA et santé - Audition du Pr Jean-Emmanuel Bibault	\N	2024-02-07 14:00:00	2024-02-07 15:00:00	\N	\N	2	0	\N	\N
797769	DELEGATION	AUDRAP	\N	\N	PROS	IA et Finances publiques - Audition de la CNAV	\N	2024-02-06 17:00:00	2024-02-06 18:00:00	\N	\N	2	0	\N	\N
797770	DELEGATION	AUDRAP	\N	\N	PROS	IA et Finances publiques - Audition de la DGDDI	\N	2024-02-06 18:00:00	2024-02-06 19:00:00	\N	\N	2	0	\N	\N
797771	DELEGATION	AUDRAP	\N	\N	PROS	IA et Finances publiques - Audition de l'Urssaf Caisse nationale	\N	2024-02-07 11:00:00	2024-02-07 12:00:00	\N	\N	2	0	\N	\N
797772	DELEGATION	AUDRAP	\N	\N	206	Place des protéines dans l'alimentation - Audition de l'association Assiettes végétales	\N	2024-02-05 16:00:00	2024-02-05 17:00:00	\N	\N	1	0	\N	\N
811598	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2024-03-27 09:30:00	2024-03-27 11:40:00	2024-03-27 11:48:25	2024-03-27 16:03:52	36	0	\N	\N
816120	QUESTURE	AUCUNE	\N	\N	\N	Réunion de Questure	Réunion du Conseil de Questure	2024-03-19 16:45:00	2024-03-19 17:15:00	\N	\N	3	0	\N	\N
775950	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Lutte contre les dérives sectaires	\N	2023-11-29 14:00:00	2023-11-29 14:30:00	\N	\N	1	0	\N	\N
797724	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désignations - Amendements de séance - Rapports	Désignations - Examen de 5 rapports	2024-02-14 09:30:00	2024-02-14 11:10:00	2024-02-14 11:55:47	2024-02-14 17:46:57	42	18	\N	\N
783363	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-12-18 18:30:00	2023-12-18 18:40:00	2023-12-18 18:43:45	2023-12-20 18:10:16	9	0	\N	\N
783366	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-12-20 09:00:00	2023-12-20 11:45:00	2023-12-20 11:47:06	2023-12-20 18:10:19	29	0	\N	\N
783521	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI « JOP »	Audition rapporteur - MI « JOP »	2023-12-14 10:30:00	2023-12-14 12:30:00	\N	\N	2	0	\N	\N
783575	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2023-12-12 16:00:00	2023-12-12 16:50:00	\N	\N	3	0	\N	\N
787257	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe d'information internationale sur le Haut-Karabagh	AG du GII Haut-Karabagh	2024-01-16 18:30:00	2024-01-16 19:00:00	\N	\N	14	0	1013	\N
790090	GIA	AUCUNE	\N	\N	\N	Entretien Amnesty International sur le Soudan 	Entretien avec des représentants d'Amnesty International sur la situation des droits humains au Soudan	2024-01-24 08:30:00	2024-01-24 09:15:00	\N	\N	2	0	588	\N
799457	GIA	AUCUNE	\N	\N	\N	Entretien avec une délégation de parlementaires africains 	Entretien avec une délégation de parlementaires africains en lien avec l'Unicef	2024-02-14 08:00:00	2024-02-14 09:15:00	\N	\N	5	0	573	\N
799591	MECSS	AUDRAP	\N	\N	MECSS	MI Fiscalité comportementale - Audition conjointe DLF-DGDDI	\N	2024-03-01 14:30:00	2024-03-01 16:00:00	\N	\N	3	0	\N	\N
799592	MECSS	AUDRAP	\N	\N	MECSS	MI Fiscalité comportementale - Audition conjointe Addictologue-Nutritionniste	\N	2024-03-01 16:00:00	2024-03-01 17:30:00	\N	\N	4	0	\N	\N
799593	MECSS	AUDRAP	\N	\N	MECSS	MI Fiscalité comportementale - Audition Haut Conseil de la santé publique	\N	2024-03-01 17:30:00	2024-03-01 18:30:00	\N	\N	4	0	\N	\N
801077	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe d'amitié France-Pays du Cône Sud 	Assemblée générale du groupe d'amitié France-Pays du Cône Sud 	2024-02-15 14:00:00	2024-02-15 14:30:00	\N	\N	7	0	978	\N
801093	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Arturo PHILLIPS DÖRR	Entretien avec M. Arturo PHILLIPS DÖRR	2024-02-13 12:45:00	2024-02-13 14:30:00	\N	\N	1	0	978	\N
801095	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Jorge Luis Arnoletti, ambassadeur d'Uruguay 	Entretien avec M. Jorge Luis Arnoletti, ambassadeur d'Uruguay 	2024-02-13 08:30:00	2024-02-13 09:30:00	\N	\N	1	0	978	\N
801097	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLO Congrès et assemblées de province de la Nouvelle-Calédonie (PJLO)	Audition rapporteur - PJLO Élections provinciales en Nouvelle-Calédonie	2024-02-14 08:00:00	2024-02-14 08:30:00	\N	\N	1	0	\N	\N
805995	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Auditions	\N	2024-03-11 16:00:00	2024-03-11 18:30:00	\N	\N	0	0	\N	\N
807359	GIA	AUCUNE	\N	\N	\N	Réception fête nationale ambassade de Bulgarie	\N	2024-03-06 12:30:00	2024-03-06 14:00:00	\N	\N	2	0	582	\N
810332	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Atos	MI Atos	2024-03-13 16:30:00	2024-03-13 18:30:00	\N	\N	2	0	\N	\N
810335	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Atos	MI Atos	2024-03-15 09:00:00	2024-03-15 11:00:00	\N	\N	1	0	\N	\N
810378	GIA	AUCUNE	\N	\N	\N	Entretien avec Eduard Stiprais, Ambassadeur de Lettonie en France	Entretien avec Eduard Stiprais, Ambassadeur de Lettonie en France	2024-03-13 16:30:00	2024-03-13 17:30:00	\N	\N	9	0	616	\N
810387	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Martin Schäfer, Ministre plénipotentiaire de l'Ambassade d'Allemagne	Entretien avec M. Martin Schäfer, Ministre plénipotentiaire de l'Ambassade d'Allemagne	2024-03-13 13:45:00	2024-03-13 15:00:00	\N	\N	14	0	604	\N
813273	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Emeutes	\N	2024-03-21 12:00:00	2024-03-21 12:45:00	\N	\N	2	0	\N	\N
813276	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Personnels admin. MEN - Audition de M. FOTINOS	Contrôle 2024 - Personnels admin. MEN - Audition de M. FOTINOS	2024-03-21 14:45:00	2024-03-21 15:45:00	\N	\N	1	0	\N	\N
813278	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Personnels admin. MEN - Audition de la DGESCO	Contrôle 2024 - Personnels admin. MEN - Audition de MM. GEFFRAY et GEHIN, direction générale de l¿enseignement scolaire	2024-03-21 15:45:00	2024-03-21 16:45:00	\N	\N	1	0	\N	\N
813280	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Commande publique enseignement supérieur - Audition M. THOMAS, UGAP	Contrôle 2024 - Efficacité commande publique enseignement supérieur - Audition M. THOMAS, UGAP	2024-03-19 10:00:00	2024-03-19 11:00:00	\N	\N	1	0	\N	\N
813282	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - CMN - Audition du Centre des monuments nationaux	Contrôle 2024 - CMN - Audition Mme LAVANDIER et MM. LACHUSSEE et FRIGO, Centre des monuments nationaux	2024-03-19 15:30:00	2024-03-19 16:30:00	\N	\N	2	0	\N	\N
813285	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Concessions autoroutes - Audition de M. COPPEY, Vinci autoroutes	Contrôle 2024 - Concessions autoroutes - Audition de M. COPPEY, Vinci autoroutes	2024-03-19 08:30:00	2024-03-19 09:30:00	\N	\N	2	0	\N	\N
813288	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Concessions autoroutes - Audition de M. RICHER, professeur de droit public	Contrôle 2024 - Concessions autoroutes - Audition de M. RICHER, professeur émérite de droit public	2024-03-19 09:30:00	2024-03-19 10:30:00	\N	\N	2	0	\N	\N
813291	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition P. TABAROT	\N	2024-03-22 10:10:00	2024-03-22 10:40:00	\N	\N	2	0	\N	\N
813294	DELEGATION	AUDRAP	\N	\N	PROS	IA et santé - Audition de McKinsey France	\N	2024-03-20 11:00:00	2024-03-20 12:00:00	\N	\N	1	0	\N	\N
813295	DELEGATION	AUDRAP	\N	\N	PROS	IA et santé - Audition de l'INCa	\N	2024-03-20 14:00:00	2024-03-20 15:00:00	\N	\N	2	0	\N	\N
813299	DELEGATION	AUDRAP	\N	\N	206	Place des protéines dans l'alimentation - Audition du CIRAD	\N	2024-03-21 14:30:00	2024-03-21 15:30:00	\N	\N	1	0	\N	\N
813302	DELEGATION	AUDRAP	\N	\N	206	Nouveaux développements de l'IA - Audition d'Angélina Gentaz, OCDE	\N	2024-03-19 15:30:00	2024-03-19 16:45:00	\N	\N	2	0	\N	\N
813303	DELEGATION	AUDRAP	\N	\N	206	Nouveaux développements de l'IA - Audition du Conseil national du numérique	\N	2024-03-21 14:30:00	2024-03-21 16:00:00	\N	\N	2	0	\N	\N
813305	DELEGATION	AUDRAP	\N	\N	206	Nouveaux développements de l'IA - Audition de Claude de Ganay, ancien député	\N	2024-03-19 13:15:00	2024-03-19 15:30:00	\N	\N	2	0	\N	\N
813310	DELEGATION	AUDRAP	\N	\N	206	Nouveaux développements de l'IA - Audition du coordinateur national pour l'IA	\N	2024-03-20 15:30:00	2024-03-20 17:30:00	\N	\N	1	0	\N	\N
813324	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Abrogation réforme des retraites - Audition DSS	\N	2024-03-20 16:30:00	2024-03-20 17:15:00	\N	\N	1	0	\N	\N
813326	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Abrogation réforme des retraites - Audition OS	\N	2024-03-20 17:15:00	2024-03-20 18:45:00	\N	\N	1	0	\N	\N
813328	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Abrogation réforme des retraites - Audition COR	\N	2024-03-22 14:00:00	2024-03-22 15:00:00	\N	\N	1	0	\N	\N
814716	MISSION	AUCUNE	\N	ARCH	\N	Rn constitutive	\N	2024-03-27 13:30:00	2024-03-27 14:00:00	2024-04-03 17:30:12	2024-04-03 18:20:47	13	4	\N	\N
814717	ETUDES	AUTRE	\N	\N	\N	Audition de M. Vincent Chatellier	Audition de M. Vincent Chatellier	2024-03-27 08:00:00	2024-03-27 09:30:00	\N	\N	54	0	\N	919
815054	COM_PERMANENTE	DEPLACEMENT	\N	SOCI	\N	Déplacement en Bretagne	\N	2024-03-28 07:00:00	2024-03-28 19:00:00	\N	\N	3	0	\N	\N
815092	ETUDES	AUTRE	\N	\N	\N	GE Handicap - Audition APHPP	\N	2024-03-27 14:00:00	2024-03-27 15:00:00	\N	\N	15	0	\N	1014
815110	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Audition commune APHP / SAMU de Paris / Brigade des sapeurs-pompiers de Paris	\N	2024-03-26 18:00:00	2024-03-26 19:30:00	\N	\N	4	0	\N	\N
815443	COM_EURO	DEPLACEMENT	\N	AFEU	\N	Auditions à Bruxelles - Euro numérique	Déplacement de Mme Blatrix Contat à Bruxelles dans le cadre de ses travaux sur l'euro-numérique	2024-03-21 07:55:00	2024-03-21 20:15:00	\N	\N	1	0	\N	\N
818331	COM_ENQUETE	PLENIERE	\N	ELEC	\N	Audition M. Benayoun EDF	\N	2024-04-03 16:30:00	2024-04-03 17:55:00	2024-04-03 17:57:21	2024-04-03 18:16:37	7	0	\N	\N
776115	DELEGATION	AUTRE	\N	\N	DSOM	Audition ministre outre-mer	\N	2023-12-07 08:30:00	2023-12-07 10:00:00	\N	\N	23	0	\N	\N
776132	COM_SPECIALE	AUDRAP	\N	DDADUE23	\N	Audition Ddadue - DGGN et DGPN	Audition Ddadue - DGGN et DGPN	2023-11-29 11:30:00	2023-11-29 12:30:00	\N	\N	4	0	\N	\N
776138	COM_SPECIALE	AUDRAP	\N	DDADUE23	\N	Audition Ddadue - DACG	Audition Ddadue - DACG	2023-11-29 14:00:00	2023-11-29 15:00:00	\N	\N	2	0	\N	\N
776140	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition de l'Andea	\N	2023-12-06 09:30:00	2023-12-06 11:15:00	2023-12-15 10:24:21	2023-12-15 16:57:18	31	0	\N	\N
776142	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Emeutes	\N	2023-11-30 18:30:00	2023-11-30 19:10:00	\N	\N	1	0	\N	\N
776144	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Emeutes	\N	2023-11-30 17:30:00	2023-11-30 18:10:00	\N	\N	1	0	\N	\N
776155	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Allocation universelle d'études - Audition Anaf	\N	2023-11-30 18:30:00	2023-11-30 19:15:00	\N	\N	1	0	\N	\N
791822	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe d'amitié France-Espagne	Assemblée générale du groupe d'amitié France-Espagne	2024-01-30 08:30:00	2024-01-30 09:30:00	\N	\N	12	0	589	\N
791845	SEANCE_PLENIERE	SCRUSOL	2021	\N	\N	Scrutin solennel PPL Lutte antiterroriste	Scrutin solennel PPL Lutte antiterroriste	2024-01-30 17:30:00	2024-01-30 17:35:00	\N	\N	0	0	\N	\N
791846	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	2021	\N	\N	EV PPL Lutte antiterroriste	EV PPL Lutte antiterroriste	2024-01-30 16:30:00	2024-01-30 17:30:00	\N	\N	267	0	\N	\N
801099	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Application loi JOP 	Audition rapporteur - MI « JOP »	2024-02-15 10:00:00	2024-02-15 11:00:00	\N	\N	2	0	\N	\N
801102	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Application loi JOP 	Audition rapporteur - MI « JOP »	2024-02-14 18:30:00	2024-02-14 19:30:00	\N	\N	2	0	\N	\N
801105	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Application loi JOP 	Audition rapporteur - MI « JOP »	2024-02-14 08:30:00	2024-02-14 09:30:00	\N	\N	1	0	\N	\N
801107	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - MI Respect des principes de la République	Audition rapporteur - MI Respect des principes de la République	2024-02-13 13:30:00	2024-02-13 14:30:00	\N	\N	2	0	\N	\N
801110	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - MI Respect des principes de la République	Audition rapporteur - MI Respect des principes de la République	2024-02-13 16:00:00	2024-02-13 17:45:00	\N	\N	2	0	\N	\N
801113	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - MI Respect des principes de la République	Audition rapporteur - MI Respect des principes de la République	2024-02-14 16:30:00	2024-02-14 17:30:00	\N	\N	2	0	\N	\N
801465	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Adapter le droit de la responsabilité civile aux enjeux actuels	PPL Adapter le droit de la responsabilité civile aux enjeux actuels	2024-02-21 16:00:00	2024-02-21 16:45:00	\N	\N	1	0	\N	\N
804231	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Justice patrimoniale au sein de la famille	PPL Justice patrimoniale au sein de la famille	2024-02-28 15:10:00	2024-02-28 15:55:00	\N	\N	1	0	\N	\N
804233	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Justice patrimoniale au sein de la famille	PPL Justice patrimoniale au sein de la famille	2024-02-28 15:55:00	2024-02-28 16:35:00	\N	\N	1	0	\N	\N
804235	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Justice patrimoniale au sein de la famille	PPL Justice patrimoniale au sein de la famille	2024-02-28 16:45:00	2024-02-28 17:45:00	\N	\N	1	0	\N	\N
808285	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	Audition DPR	Audition DPR	2024-03-12 17:00:00	2024-03-12 18:20:00	\N	\N	3	0	\N	\N
808304	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI Atos	MI Atos	2024-03-12 17:30:00	2024-03-12 20:30:00	\N	\N	1	0	\N	\N
810043	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	AG du Groupe d'études "Statut, rôle et place des Français établis hors de France	AG du Groupe d'études "Statut, rôle et place des Français établis hors de France"	2024-03-14 09:00:00	2024-03-14 09:30:00	\N	\N	7	0	\N	\N
819512	GIA	AUCUNE	\N	\N	\N	entretien avec M. Laurent Bonnefoy, chercheur	\N	2024-04-09 14:30:00	2024-04-09 15:45:00	\N	\N	3	0	627	\N
776211	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Mission enseignement scolaire	Mission enseignement scolaire	2023-12-01 14:30:00	2023-12-01 15:15:00	\N	\N	46	0	\N	\N
776212	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Mission Cohésion des territoires	Mission Cohésion des territoires	2023-12-01 19:00:00	2023-12-01 20:00:00	\N	\N	44	0	\N	\N
786337	INSTANCE_INTERNATIONALE	AUCUNE	\N	\N	\N	Participation à la cérémonie d'hommage à Jacques Delors	Cérémonie d'hommage aux Invalides	2024-01-05 10:00:00	2024-01-05 12:00:00	\N	\N	6	0	\N	\N
801346	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Atos	MI Atos	2024-02-20 09:00:00	2024-02-20 12:00:00	\N	\N	2	0	\N	\N
801350	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Atos	MI Atos	2024-02-20 13:30:00	2024-02-20 16:00:00	\N	\N	2	0	\N	\N
807301	GIA	AUCUNE	\N	\N	\N	Réunion de travail avec l'ambassadrice SE H. Tolmadjyan	réunion de préparation du colloque du 14 mai 2024	2024-03-06 15:30:00	2024-03-06 17:15:00	\N	\N	1	0	641	\N
807303	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation du Parlement ouzbèk	Accueil d'une délégation conduite par le vice-président de la Chambre législative du Parlement ouzbek A. SAIDOV	2024-03-06 12:45:00	2024-03-06 14:30:00	\N	\N	10	0	556	\N
807314	GIA	AUCUNE	\N	\N	\N	Entretien avec les représentants de l'association des Assyro-chaldéens	Entretien avec Daniel Auguste (AACF)	2024-03-06 18:00:00	2024-03-06 18:45:00	\N	\N	1	0	CHRETORIENT	CHRETORIENT
807316	GIA	AUCUNE	\N	\N	\N	Dîner à l'invitation du AACF (Association des Assyro-chaldéens de France)	Président Tony IDE, Georges OCLIN, vice-président	2024-03-27 19:45:00	2024-03-27 22:00:00	\N	\N	4	0	CHRETORIENT	CHRETORIENT
788817	CMP	AUTRE	\N	IMMI	\N	PJL Immigration	PJL Immigration	2023-12-18 17:00:00	2023-12-19 15:35:00	\N	\N	14	0	\N	\N
807321	GIA	AUCUNE	\N	\N	\N	Dîner de l'Association des Assyro-chaldéens en France	Daniel Auguste, M. Yaramis	2024-02-06 19:30:00	2024-02-06 22:30:00	\N	\N	4	0	CHRETORIENT	CHRETORIENT
809258	ETUDES	AUCUNE	\N	\N	\N	Table ronde sur les SMR et les AMR	Table ronde sur les SMR et les AMR	2024-03-13 13:30:00	2024-03-13 15:00:00	\N	\N	12	0	\N	906
809316	DELEGATION	AUDRAP	\N	\N	211	Audition du CNV	Audition du 	2024-03-18 13:30:00	2024-03-18 14:30:00	\N	\N	4	0	\N	\N
809347	GIA	AUCUNE	\N	\N	\N	Entretien avec Mme Senka Buric, Chargée d¿affaires a.i. de l¿Ambassade de Croatie	\N	2024-03-13 16:30:00	2024-03-13 17:20:00	\N	\N	1	0	647	\N
810282	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Chrysostome KIRIMWINGABO, lauréat burundais de l'initiative Marianne	Entretien avec M. Chrysostome KIRIMWINGABO, lauréat burundais de l'initiative Marianne	2024-03-12 15:00:00	2024-03-12 16:15:00	\N	\N	2	0	572	\N
818566	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Rémy RIOUX, Directeur général de l'AFD	Entretien avec M. Rémy RIOUX, Directeur général de l'AFD	2024-04-03 08:05:00	2024-04-03 09:15:00	\N	\N	10	0	572	\N
819185	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Dématérialisation de l'état civil	Audition rapporteur - PPL Dématérialisation de l'état civil	2024-04-08 12:10:00	2024-04-08 12:30:00	\N	\N	1	0	\N	\N
819187	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Dématérialisation de l'état civil	Audition rapporteur - PPL Dématérialisation de l'état civil	2024-04-08 14:00:00	2024-04-08 17:00:00	\N	\N	1	0	\N	\N
821923	MISSION	AUDRAP	\N	COMP	\N	MI Complémentaires santé - Table ronde 100% santé	\N	2024-04-11 15:00:00	2024-04-11 17:00:00	\N	\N	3	0	\N	\N
821927	DELEGATION	AUDRAP	\N	\N	206	Nouveaux développements de l'IA - Audition de M. Cédric Villani	\N	2024-04-09 15:15:00	2024-04-09 16:45:00	\N	\N	2	0	\N	\N
821929	DELEGATION	AUDRAP	\N	\N	206	Nouveaux développements de l'IA - Audition du CEA	\N	2024-04-09 16:45:00	2024-04-09 18:30:00	\N	\N	2	0	\N	\N
821930	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GS Egalim - FHER-FEBEA	GS Egalim - FHER-FEBEA	2024-04-02 17:00:00	2024-04-02 18:00:00	\N	\N	4	0	\N	\N
821935	DELEGATION	AUDRAP	\N	\N	206	Nouveaux développements de l'IA - Audition de l'Inria	\N	2024-04-11 10:00:00	2024-04-11 11:30:00	\N	\N	2	0	\N	\N
821942	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GS Egalim - Les Mousquetaires	GS Egalim - Les Mousquetaires	2024-04-02 18:00:00	2024-04-02 19:00:00	\N	\N	4	0	\N	\N
821947	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GS Egalim - Cniel	GS Egalim - Cniel	2024-04-02 19:15:00	2024-04-02 20:00:00	\N	\N	3	0	\N	\N
821952	COM_PERMANENTE	AUTRE	\N	FINC	\N	Réunion GS ZAN	Réunion GS ZAN	2024-03-19 16:10:00	2024-03-19 18:25:00	2024-04-12 17:56:10	\N	4	0	\N	\N
821957	COM_PERMANENTE	AUTRE	\N	FINC	\N	Réunion de travail	Réunion de travail	2024-04-09 09:05:00	2024-04-09 10:15:00	2024-04-12 18:18:31	2024-04-15 11:45:03	1	0	\N	\N
821961	GIA	AUCUNE	\N	\N	\N	déjeuner parlementaires britanniques	réception parlementaires de la Chambre des Communes	2024-02-27 12:30:00	2024-02-27 14:30:00	\N	\N	8	0	581	\N
775814	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Emeutes	MI Emeutes	2023-11-30 14:30:00	2023-11-30 15:10:00	\N	\N	2	0	\N	\N
775817	COM_SPECIALE	AUDRAP	\N	DDADUE23	\N	Auditions PJL Ddadue	Auditions PJL Ddadue	2023-11-28 09:30:00	2023-11-28 10:30:00	\N	\N	3	0	\N	\N
775821	COM_SPECIALE	AUDRAP	\N	DDADUE23	\N	Audition PJL Ddadue - Représentants des entreprises	Audition PJL Ddadue - Représentants des entreprises	2023-11-28 14:00:00	2023-11-28 15:00:00	\N	\N	1	0	\N	\N
775822	COM_SPECIALE	AUDRAP	\N	DDADUE23	\N	Audition PJL Ddadue - Acteurs promouvant parité femmes-hommes	Audition PJL Ddadue - Acteurs promouvant parité femmes-hommes	2023-11-28 15:00:00	2023-11-28 16:30:00	\N	\N	2	0	\N	\N
775823	COM_SPECIALE	AUDRAP	\N	DDADUE23	\N	Audition PJL Ddadue - Audition d'universitaires	Audition PJL Ddadue - Audition d'universitaires	2023-11-28 16:45:00	2023-11-28 17:45:00	\N	\N	2	0	\N	\N
775824	COM_SPECIALE	AUDRAP	\N	DDADUE23	\N	Audition PJL Ddadue - Conseil national des barreaux	Audition PJL Ddadue - Conseil national des barreaux	2023-11-28 17:45:00	2023-11-28 18:30:00	\N	\N	2	0	\N	\N
775825	COM_SPECIALE	AUDRAP	\N	DDADUE23	\N	Audition PJL Ddadue - CNPR	Audition PJL Ddadue - CNPR	2023-11-28 18:30:00	2023-11-28 19:15:00	\N	\N	3	0	\N	\N
775925	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Emeutes	MI Emeutes	2023-11-30 15:30:00	2023-11-30 16:20:00	\N	\N	5	0	\N	\N
775939	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Erasmus de l'apprentissage - Audition Anaf 	\N	2023-12-05 17:00:00	2023-12-05 17:45:00	\N	\N	2	0	\N	\N
775940	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	 PPL Erasmus de l'apprentissage - Audition CFA académie de Nice	\N	2023-12-05 17:45:00	2023-12-05 18:45:00	\N	\N	1	0	\N	\N
775941	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Erasmus de l'apprentissage - Audition Fnadir 	\N	2023-12-06 14:15:00	2023-12-06 15:15:00	\N	\N	1	0	\N	\N
775942	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Erasmus de l'apprentissage - Audition DGEFP 	\N	2023-12-06 15:15:00	2023-12-06 16:15:00	\N	\N	1	0	\N	\N
775943	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Erasmus de l'apprentissage - Audition Agence Erasmus+ 	\N	2023-12-06 16:30:00	2023-12-06 17:30:00	\N	\N	1	0	\N	\N
775944	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 6 décembre (1)	\N	2023-12-06 13:35:00	2023-12-06 14:40:00	2023-12-06 16:44:19	2023-12-06 18:26:25	11	0	\N	\N
775945	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 6 décembre (2)	\N	2023-12-06 16:30:00	2023-12-06 17:55:00	2023-12-06 17:54:42	2023-12-06 18:26:26	15	0	\N	\N
775946	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 7 décembre 2023	\N	2023-12-07 09:05:00	2023-12-07 10:40:00	2023-12-07 10:43:24	2023-12-07 17:29:05	13	0	\N	\N
775955	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Allocation universelle d'études - Table ronde précarité	\N	2023-11-30 15:00:00	2023-11-30 16:45:00	\N	\N	2	0	\N	\N
775958	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Allocation universelle d'études - Métropole de Lyon	\N	2023-11-30 16:45:00	2023-11-30 17:05:00	\N	\N	2	0	\N	\N
775961	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Allocation universelle d'études - UNSA Éducation	\N	2023-11-30 17:05:00	2023-11-30 17:30:00	\N	\N	2	0	\N	\N
775969	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Allocation universelle d'études - Audition Cnous	\N	2023-11-30 17:30:00	2023-11-30 18:30:00	\N	\N	1	0	\N	\N
775971	COM_PERMANENTE	AUTRE	\N	LOIS	\N	MCC Agressions subies par les enseignants - Audition de Jean-Michel Blanquer	MCC Agressions subies par les enseignants - Audition de Jean-Michel Blanquer	2023-12-05 17:35:00	2023-12-05 19:00:00	2023-12-05 19:05:19	2023-12-06 18:26:15	33	0	\N	\N
775974	COM_PERMANENTE	AUTRE	\N	LOIS	\N	MI Emeutes de juin 2023 - Table ronde de sociologues	MI Emeutes de juin 2023 - Table ronde de sociologues	2023-12-06 11:20:00	2023-12-06 12:50:00	2023-12-06 22:43:40	2023-12-07 17:28:54	5	0	\N	\N
775973	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Rapports : PPR Commission culture - PPLC Souveraineté - PPL Droits enfant	Rapports : PPR Commission culture - PPLC Souveraineté - PPL Droits enfant	2023-12-06 09:05:00	2023-12-06 11:15:00	2023-12-06 22:41:41	2023-12-07 17:28:53	43	6	\N	\N
775975	DELEGATION	AUCUNE	\N	\N	COLTER	Table-rondes relatives aux travaux sur le statut de l'élu local	\N	2023-12-07 09:00:00	2023-12-07 12:00:00	\N	\N	32	0	\N	\N
799812	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Réunion constitutive	\N	2024-02-14 14:00:00	2024-02-14 14:45:00	\N	\N	0	0	\N	\N
800004	ETUDES	AUTRE	\N	\N	\N	Réunion constitutive	\N	2024-02-13 13:30:00	2024-02-13 15:00:00	\N	\N	7	0	\N	922
800404	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Table ronde Réseaux et acheminement	\N	2024-02-14 16:30:00	2024-02-14 18:30:00	\N	\N	0	0	\N	\N
800611	ETUDES	AUTRE	\N	\N	\N	Réunion constitutive	Réunion constitutive	2024-02-14 09:00:00	2024-02-14 09:25:00	\N	\N	10	0	\N	938
800749	COM_ENQUETE	PLENIERE	\N	TOTA	\N	Réunion CE-TE	\N	2024-02-15 10:35:00	2024-02-15 12:45:00	2024-02-15 19:04:12	2024-02-16 18:29:58	10	0	\N	\N
800750	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJLO Congrès et assemblées de province de la Nouvelle-Calédonie (PJLO) (amendements)	PJLO Congrès et assemblées de province de la Nouvelle-Calédonie (PJLO) (amendements)	2024-02-27 14:15:00	2024-02-27 14:20:00	2024-02-27 15:02:09	2024-02-27 15:16:53	14	3	\N	\N
800752	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de Gérald Darmanin sur la recrudescence des actes antisémites	Audition de Gérald Darmanin sur la recrudescence des actes antisémites	2024-02-27 18:10:00	2024-02-27 19:30:00	2024-02-27 20:08:41	2024-02-28 16:45:29	31	0	\N	\N
800794	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition MI Crise du logement	\N	2024-02-14 16:30:00	2024-02-14 17:30:00	\N	\N	3	0	\N	\N
801136	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Statut de l'élu local	PPL Statut de l'élu local	2024-02-15 14:35:00	2024-02-15 16:30:00	\N	\N	3	0	\N	\N
801140	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Statut de l'élu local	PPL Statut de l'élu local	2024-02-15 17:00:00	2024-02-15 18:00:00	\N	\N	3	0	\N	\N
801254	GIA	AUCUNE	\N	\N	\N	Assemblée Générale	\N	2024-02-14 14:00:00	2024-02-14 14:30:00	\N	\N	4	0	586	\N
778666	GIA	AUCUNE	\N	\N	\N	Assemblée générale reconstitutive	Assemblée générale reconstitutive 	2023-12-06 13:30:00	2023-12-06 14:00:00	\N	\N	8	0	580	\N
778676	GIA	AUCUNE	\N	\N	\N	Audition de l'Ambassadeur du Royaume de Belgique 	Audition de S.E.M. Johan Indekeu, Ambassadeur du Royaume de Belgique en France	2023-12-06 14:00:00	2023-12-06 15:00:00	\N	\N	7	0	580	\N
778775	GIA	AUCUNE	\N	\N	\N	Déjeuner	Déjeuner avec François Wu, Représentant de Taipei suite aux élections du 13 janvier à Taïwan	2024-01-17 12:30:00	2024-01-17 14:00:00	\N	\N	14	0	623	\N
786224	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe	AG du groupe	2023-12-13 14:00:00	2023-12-13 14:30:00	\N	\N	11	0	632	\N
786236	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe	Ag du groupe 	2023-12-13 14:00:00	2023-12-13 15:00:00	\N	\N	8	0	651	\N
787444	GIA	AUCUNE	\N	\N	\N	Assemblée générale du GIA France - Pays-Bas	Assemblée générale du GIA France - Pays-Bas	2024-01-16 17:30:00	2024-01-16 18:15:00	\N	\N	4	0	599	\N
787450	GIA	AUCUNE	\N	\N	\N	Assemblée générale du GIA France - Cambodge et Laos	AG du GIA France - Cambodge et Laos	2024-01-16 14:15:00	2024-01-16 14:45:00	\N	\N	7	0	577	\N
794926	COM_ENQUETE	AUDRAP	\N	NARCO	\N	Audition Rapporteur	\N	2024-02-06 08:00:00	2024-02-06 09:00:00	\N	\N	2	0	\N	\N
794939	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLC IVG	\N	2024-02-01 16:00:00	2024-02-01 17:00:00	\N	\N	1	0	\N	\N
794949	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Habitat dégradé	\N	2024-02-06 09:00:00	2024-02-06 09:30:00	\N	\N	1	0	\N	\N
794951	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Habitat dégradé	\N	2024-02-06 09:30:00	2024-02-06 10:00:00	\N	\N	1	0	\N	\N
804019	GIA	AUCUNE	\N	\N	\N	Audition de M. Brice ROQUEFEUIL, Directeur Europe continentale MEAE	Audition de M. Brice ROQUEFEUIL et de Matthieu COMBE, MEAE	2024-02-28 08:30:00	2024-02-28 10:00:00	\N	\N	10	0	556	\N
812964	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI ATOS	MI ATOS	2024-03-20 18:00:00	2024-03-20 20:00:00	\N	\N	2	0	\N	\N
814803	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ambassadeur du Népal en France	Entretien avec SE M. Shudir BHATTARAI, Ambassadeur du Népal en France	2024-03-27 12:30:00	2024-03-27 14:10:00	\N	\N	3	0	633	\N
779542	GIA	AUCUNE	\N	\N	\N	Déjeuner avec l'Ambassadeur d'Allemagne 	Déjeuner avec l'Ambassadeur d'Allemagne 	2023-11-08 13:00:00	2023-11-08 14:30:00	\N	\N	1	0	604	\N
794070	COM_ENQUETE	PLENIERE	\N	ELEC	\N	Table ronde Ecosystème de l'électricité	\N	2024-01-31 17:30:00	2024-01-31 19:50:00	2024-02-13 15:14:46	2024-02-13 15:27:13	14	0	\N	\N
794671	COM_ENQUETE	PLENIERE	\N	ELEC	\N	\N	\N	2024-02-01 14:30:00	2024-02-01 16:50:00	2024-02-13 15:15:06	2024-02-13 15:27:17	7	0	\N	\N
800497	GIA	AUCUNE	\N	\N	\N	Coopé - Rdv de la Diplomatie des Territoires sur la coop. décentralisée avec l'Arménie	Coopé - Rendez-vous de la Diplomatie des Territoires sur la coopération décentralisée franco-arménienne	2024-02-12 14:00:00	2024-02-12 17:10:00	\N	\N	5	0	641	\N
800503	GIA	AUCUNE	\N	\N	\N	Coopé - Entretien avec M. Arturo PHILLIPS DÖRR, figure politique chilienne	Coopé - Entretien avec M. Arturo PHILLIPS DÖRR, figure politique chilienne	2024-02-13 12:45:00	2024-02-13 14:15:00	\N	\N	1	0	978	\N
801353	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	MI Atos	\N	2024-02-21 09:00:00	2024-02-21 11:45:00	\N	\N	0	0	\N	\N
801373	DELEGATION	AUCUNE	\N	\N	COLTER	Réunion plénière	\N	2024-02-29 09:00:00	2024-02-29 11:50:00	2024-02-29 12:28:40	\N	22	0	\N	\N
806787	DELEGATION	AUCUNE	\N	\N	DSOM	Coopération régionale : Auditions sur les aspects européens	\N	2024-03-07 09:00:00	2024-03-07 11:50:00	\N	\N	10	0	\N	\N
806868	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Auditions Associations protection animales welfaristes	\N	2024-03-05 17:30:00	2024-03-05 19:00:00	\N	\N	0	0	\N	\N
806876	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Auditions de réprésentants de la filière de la noisette	\N	2024-03-06 14:00:00	2024-03-06 15:30:00	\N	\N	0	0	\N	\N
806885	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Audition Mme Lemmet + constitutive	\N	2024-03-06 13:45:00	2024-03-06 15:00:00	\N	\N	0	0	\N	\N
806886	ETUDES	AUTRE	\N	\N	\N	OFB	OFB	2024-03-06 08:00:00	2024-03-06 09:30:00	\N	\N	26	0	\N	907
806936	ETUDES	AUTRE	\N	\N	\N	Audition REP	Audition REP	2024-03-05 14:30:00	2024-03-05 15:30:00	\N	\N	4	0	\N	922
800773	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJLC Liberté de recourir à l'IVG (amdts) -  PPL Statut de l'élu local (rapport)	PJLC Liberté de recourir à l'IVG (amdts) -  PPL Statut de l'élu local (rapport)	2024-02-28 09:00:00	2024-02-28 11:45:00	2024-02-28 12:05:24	2024-02-28 16:38:56	41	18	\N	\N
818837	CMP	AUTRE	\N	DDAD	\N	PJL DDADUE	PJL DDADUE	2024-04-04 09:04:00	2024-04-04 09:44:00	\N	\N	7	0	\N	\N
806952	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL Ratification CETA	Audition PJL Ratification CETA	2024-03-05 08:15:00	2024-03-05 09:15:00	\N	\N	1	0	\N	\N
806961	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	GT subsidiarité du 14 mars 2024	\N	2024-03-14 08:00:00	2024-03-14 08:30:00	\N	\N	0	0	\N	\N
806962	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 14 mars 2024	\N	2024-03-14 08:30:00	2024-03-14 09:20:00	2024-03-14 16:13:00	2024-03-14 16:34:58	10	0	\N	\N
806964	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL Ratification CETA	\N	2024-03-05 10:00:00	2024-03-05 11:00:00	\N	\N	2	0	\N	\N
806965	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL Ratification CETA	\N	2024-03-05 15:00:00	2024-03-05 16:10:00	\N	\N	1	0	\N	\N
806966	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL Ratification CETA	\N	2024-03-05 16:10:00	2024-03-05 16:50:00	\N	\N	3	0	\N	\N
806967	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Ratification CETA	\N	2024-03-05 16:50:00	2024-03-05 17:30:00	\N	\N	0	0	\N	\N
806968	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Ratification CETA	\N	2024-03-05 16:50:00	2024-03-05 17:30:00	\N	\N	0	0	\N	\N
806969	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PJL Ratification CETA	\N	2024-03-05 16:50:00	2024-03-05 17:30:00	\N	\N	3	0	\N	\N
806970	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL Ratification CETA	\N	2024-03-05 17:30:00	2024-03-05 18:10:00	\N	\N	4	0	\N	\N
806971	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL Ratification CETA	\N	2024-03-05 18:10:00	2024-03-05 19:00:00	\N	\N	4	0	\N	\N
806972	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL Ratification CETA	\N	2024-03-05 19:00:00	2024-03-05 19:50:00	\N	\N	3	0	\N	\N
806973	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition PJL Ratification CETA	\N	2024-03-05 19:50:00	2024-03-05 20:30:00	\N	\N	3	0	\N	\N
807005	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Responsabilité civile - Réseau routier non concédé - Tests individuels (amendements)	PPL Responsabilité civile - Réseau routier non concédé - Tests individuels (amendements)	2024-03-12 14:00:00	2024-03-12 14:10:00	2024-03-12 18:09:51	2024-03-13 15:55:55	18	14	\N	\N
807008	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion CATDD	\N	2024-03-13 10:30:00	2024-03-13 12:15:00	2024-03-13 16:36:13	2024-03-13 17:04:03	39	2	\N	\N
807166	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Cancers professionnels des sapeurs-pompiers - DGAFP	\N	2024-03-06 14:00:00	2024-03-06 15:00:00	\N	\N	2	0	\N	\N
807167	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Cancers professionnels des sapeurs-pompiers - Syndicats	\N	2024-03-06 16:30:00	2024-03-06 18:30:00	\N	\N	3	0	\N	\N
807168	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Cancers professionnels des sapeurs-pompiers - Cnam & Inserm	\N	2024-03-07 10:30:00	2024-03-07 12:00:00	\N	\N	2	0	\N	\N
807178	COM_ENQUETE	PLENIERE	\N	NARCO	\N	Auditions Finances publiques - Tribunaux de commerce	Auditions Finances publiques - Tribunaux de commerce	2024-03-11 14:05:00	2024-03-11 16:30:00	2024-03-11 16:35:07	2024-03-12 14:48:16	2	0	\N	\N
807186	COM_ENQUETE	PLENIERE	\N	NARCO	\N	Auditions Réseaux sociaux - Police judiciaire	Auditions Réseaux sociaux - Police judiciaire	2024-03-12 08:00:00	2024-03-12 10:45:00	2024-03-12 10:47:26	2024-03-12 14:49:00	7	0	\N	\N
807188	COM_ENQUETE	PLENIERE	\N	NARCO	\N	Auditions Barreaux - Sécurité intérieure	Auditions Barreaux - Sécurité intérieure	2024-03-14 10:30:00	2024-03-14 13:00:00	2024-03-14 13:04:38	2024-03-14 16:38:57	6	0	\N	\N
807190	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Jean Bacci	Auditions M. Jean Bacci	2024-03-07 09:30:00	2024-03-07 12:30:00	\N	\N	1	0	\N	\N
807192	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Jean Bacci	Auditions M. Jean Bacci	2024-03-07 14:00:00	2024-03-07 17:00:00	\N	\N	1	0	\N	\N
813368	GIA	AUCUNE	\N	\N	\N	Audition du président de la Ligue maronite	Audition de M. Khalil Karam, président de la Ligue maronite	2024-03-19 14:00:00	2024-03-19 15:20:00	\N	\N	6	0	597	\N
775658	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Erasmus de l'apprentissage -Audition Cabinet de la ministre chargée de l'enseignement 	\N	2023-11-28 18:30:00	2023-11-28 19:30:00	\N	\N	1	0	\N	\N
775674	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Direction générale de l'aviation civile	\N	2023-11-21 09:00:00	2023-11-21 09:45:00	\N	\N	4	0	\N	\N
775688	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Yohann La-Corte	\N	2023-11-21 09:45:00	2023-11-21 10:30:00	\N	\N	3	0	\N	\N
777013	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Réunion du Conseil de Questure	2023-11-28 16:26:00	2023-11-28 17:25:00	\N	\N	2	0	\N	\N
789663	GIA	AUCUNE	\N	\N	\N	Assemblée générale	Assemblée générale du groupe d'amitié	2024-01-23 15:05:00	2024-01-23 15:30:00	\N	\N	6	0	633	\N
796085	COM_PERMANENTE	AUTRE	\N	CAE	\N	Auditions Windsor (APCA) / syndicats agricoles	\N	2024-02-07 09:15:00	2024-02-07 12:45:00	2024-02-08 16:47:02	2024-02-09 17:33:11	45	2	\N	\N
796352	COM_EURO	AUDRAP	\N	AFEU	\N	Euro numérique	\N	2024-02-06 16:45:00	2024-02-06 17:30:00	\N	\N	2	0	\N	\N
798794	MECSS	AUDRAP	\N	\N	MECSS	MI Fiscalité comportementale - Audition conjointe Cour comptes-CPO	\N	2024-02-27 09:00:00	2024-02-27 10:30:00	\N	\N	2	0	\N	\N
804538	COM_ENQUETE	PLENIERE	\N	ELEC	\N	TR Coûts de production	\N	2024-03-05 14:30:00	2024-03-05 16:45:00	2024-03-06 10:12:51	2024-03-06 11:41:08	11	0	\N	\N
807828	GIA	AUCUNE	\N	\N	\N	Audition du ministre sortant des affaires sociales du Liban	Audition de M. Hector Hajjar, ministre sortant des affaires sociales du Liban	2024-03-12 13:30:00	2024-03-12 14:40:00	\N	\N	6	0	597	\N
809939	GIA	AUCUNE	\N	\N	\N	Entretien Ambassadeur Slovaquie	\N	2024-03-14 08:30:00	2024-03-14 09:40:00	\N	\N	2	0	532	\N
778933	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne 	\N	2023-12-06 16:35:00	2023-12-06 18:00:00	2023-12-07 10:39:48	2023-12-07 17:29:50	8	0	\N	\N
786203	QUESTURE	AUCUNE	\N	\N	\N	Réunion de Questure	Réunion du Conseil de Questure	2023-12-19 17:00:00	2023-12-19 18:12:00	\N	\N	2	0	\N	\N
786245	GIA	AUCUNE	\N	\N	\N	Réception à l'occasion de la fête nationale de la République de Lettonie	Réception à l'occasion de la fête nationale de la République de Lettonie	2023-11-22 12:30:00	2023-11-22 14:30:00	\N	\N	1	0	616	\N
789511	QUESTURE	AUCUNE	\N	\N	\N	Réunion de Questure	Réunion du Conseil de Questure	2024-01-16 16:00:00	2024-01-16 16:40:00	\N	\N	3	0	\N	\N
807004	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Responsabilité civile - Réseau routier non concédé - Tests individuels (amendements)	PPL Responsabilité civile - Réseau routier non concédé - Tests individuels (amendements)	2024-03-13 09:30:00	2024-03-13 11:30:00	2024-03-13 14:45:11	2024-03-13 15:55:56	44	9	\N	\N
788983	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière - Amdts séance PPL Dépistage TND et PPL Décompte sans abri	\N	2024-01-24 10:00:00	2024-01-24 10:50:00	2024-01-24 11:49:29	2024-01-25 18:33:23	41	0	\N	\N
789010	CMP	AUTRE	\N	SER	\N	PPL SER	PPL SER	2023-11-08 19:40:00	2023-11-08 21:00:00	\N	\N	11	0	\N	\N
790637	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe d'amitié	Assemblée générale du groupe d'amitié	2024-01-24 14:30:00	2024-01-24 15:00:00	\N	\N	8	0	851	\N
809943	COM_ENQUETE	PLENIERE	\N	TOTA	\N	Réunion CE-TE	\N	2024-03-14 10:30:00	2024-03-14 12:20:00	2024-03-22 10:07:08	2024-03-22 16:36:24	10	0	\N	\N
809952	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Auditions	\N	2024-03-19 16:00:00	2024-03-19 18:30:00	\N	\N	0	0	\N	\N
810036	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2024-03-19 14:15:00	2024-03-19 14:20:00	2024-03-19 15:13:57	2024-03-19 17:33:34	15	0	\N	\N
821615	GIA	AUCUNE	\N	\N	\N	Entretien Avec M. Milorad DODIK	Entretien Avec M. Milorad DODIK, Président Serbe de la Bosnie-Herzégovine	2024-04-10 11:00:00	2024-04-10 12:00:00	\N	\N	8	0	674	\N
791783	GIA	AUCUNE	\N	\N	\N	Audition Paul Maurice, Chef de mission Allemagne et Europe alpine et adriatique 	Audition Paul Maurice, Chef de mission Allemagne et Europe alpine et adriatique 	2024-02-28 08:00:00	2024-02-28 09:10:00	\N	\N	5	0	610	\N
794062	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2024-02-06 09:30:00	2024-02-06 12:30:00	\N	\N	53	0	\N	\N
794067	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Violences intrafamiliales	PPL Violences intrafamiliales	2024-02-06 15:35:00	2024-02-06 17:10:00	\N	\N	114	0	\N	\N
794069	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Actions de groupe	PPL Actions de groupe	2024-02-06 17:15:00	2024-02-06 20:00:00	\N	\N	94	0	\N	\N
794073	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Actions de groupe	PPL Actions de groupe	2024-02-06 21:30:00	2024-02-06 22:50:00	\N	\N	28	0	\N	\N
794075	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2024-02-07 15:00:00	2024-02-07 16:15:00	\N	\N	284	0	\N	\N
794081	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Vapotage à usage unique	PPL Vapotage à usage unique	2024-02-07 16:30:00	2024-02-07 17:50:00	\N	\N	62	0	\N	\N
794084	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL et PJLO Nucléaire	PJL et PJLO Nucléaire	2024-02-07 17:55:00	2024-02-07 20:10:00	\N	\N	80	0	\N	\N
794085	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL et PJLO Nucléaire	PJL et PJLO Nucléaire	2024-02-07 21:40:00	2024-02-08 00:45:00	\N	\N	47	0	\N	\N
794086	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL et PJLO Nucléaire	PJL et PJLO Nucléaire	2024-02-08 10:30:00	2024-02-08 11:00:00	\N	\N	0	0	\N	\N
794375	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL et PJLO Nucléaire	PJL et PJLO Nucléaire	2024-02-08 14:30:00	2024-02-08 15:00:00	\N	\N	0	0	\N	\N
794408	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL et PJLO Nucléaire	PJL et PJLO Nucléaire	2024-02-08 21:30:00	2024-02-08 22:00:00	\N	\N	0	0	\N	\N
798344	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL responsabilité civile	PROPOSITION DE LOI VISANT À ADAPTER LE DROIT DE LA RESPONSABILITÉ CIVILE AUX ENJEUX ACTUELS	2024-02-13 08:00:00	2024-02-13 08:45:00	\N	\N	2	0	\N	\N
798347	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Adapter le droit de la responsabilité civile aux enjeux actuels	PPL Adapter le droit de la responsabilité civile	2024-02-13 08:45:00	2024-02-13 09:30:00	\N	\N	1	0	\N	\N
798349	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Adapter le droit de la responsabilité civile aux enjeux actuels	PPL Adapter le droit de la responsabilité civile	2024-02-13 09:30:00	2024-02-13 10:15:00	\N	\N	1	0	\N	\N
801381	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Négociations salariales - Audition Jean-CLaude Mailly	\N	2024-02-27 14:00:00	2024-02-27 14:45:00	\N	\N	3	0	\N	\N
801382	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Négociations salariales - Audition Gilbert Cette	\N	2024-02-27 14:45:00	2024-02-27 15:30:00	\N	\N	3	0	\N	\N
801383	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Négociations salariales - Audition Yves Barou	\N	2024-02-27 15:30:00	2024-02-27 16:15:00	\N	\N	3	0	\N	\N
801384	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Négociations salariales - Audition Philippe Vivien	\N	2024-02-27 16:30:00	2024-02-27 17:15:00	\N	\N	3	0	\N	\N
801385	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Négociations salariales - Audition Stéphane Carcillo	\N	2024-02-27 17:15:00	2024-02-27 18:00:00	\N	\N	3	0	\N	\N
801395	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Négociations salariales	\N	2024-02-29 15:30:00	2024-02-29 16:15:00	\N	\N	4	0	\N	\N
801396	MECSS	AUCUNE	\N	\N	MECSS	Audition sur la fiscalité des produits de tabac	\N	2024-02-27 16:00:00	2024-02-27 18:35:00	2024-02-27 18:33:32	2024-02-28 16:43:17	8	0	\N	\N
804311	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition - MI Principes de la République	Audition rapporteur - MI Respect des principes de la République	2024-03-04 09:00:00	2024-03-04 10:45:00	\N	\N	2	0	\N	\N
814010	DELEGATION	AUTRE	\N	\N	DSOM	Coopération régionale : audition de la FEDOM	\N	2024-04-02 18:00:00	2024-04-02 19:00:00	\N	\N	13	0	\N	\N
814023	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Jean-Yves Roux	Auditions M. Jean-Yves Roux	2024-03-26 10:00:00	2024-03-26 11:20:00	\N	\N	1	0	\N	\N
814044	MISSION	AUCUNE	\N	COMP	\N	Auditions plénières	\N	2024-03-26 16:35:00	2024-03-26 19:20:00	2024-03-26 19:33:38	2024-03-27 16:01:54	9	0	\N	\N
814097	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI Francophonie	\N	2024-03-26 17:30:00	2024-03-26 18:30:00	\N	\N	4	0	\N	\N
814109	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL pharmacies d'officine - DGOS	\N	2024-03-26 15:45:00	2024-03-26 16:45:00	\N	\N	2	0	\N	\N
773373	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Visite du commandement de l'espace	\N	2023-11-23 08:30:00	2023-11-23 13:00:00	\N	\N	12	0	\N	\N
786442	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL ESH sur le temps méridien	\N	2024-01-09 11:00:00	2024-01-09 11:50:00	\N	\N	6	0	\N	\N
798056	ETUDES	AUCUNE	\N	\N	\N	Section Cheval - Réunion constitutive	Section Cheval - Réunion constitutive	2024-02-13 13:45:00	2024-02-13 14:10:00	\N	\N	5	0	\N	912
819117	COM_ENQUETE	AUTRE	\N	TOTA	\N	Audition	\N	2024-04-09 08:30:00	2024-04-09 09:17:00	2024-04-09 10:07:40	2024-04-09 17:39:45	9	0	\N	\N
819372	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Rapport d'information Arabie saoudite	\N	2024-04-03 14:00:00	2024-04-03 15:00:00	\N	\N	0	0	\N	\N
819376	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Rapport d'unformation Arabie Saoudite	\N	2024-04-04 14:00:00	2024-04-04 15:00:00	\N	\N	0	0	\N	\N
789057	CMP	AUTRE	\N	PLF2024	\N	PLF 2024	PLF 2024	2023-12-12 21:04:00	2023-12-12 21:50:00	\N	\N	13	0	\N	\N
789072	CMP	AUTRE	\N	SOINS	\N	PPL Accès aux soins	PPL Accès aux soins	2023-12-07 09:09:00	2023-12-07 10:55:00	\N	\N	9	0	\N	\N
789087	CMP	AUTRE	\N	RATP	\N	PPL RATP	PPL RATP	2023-12-06 18:50:00	2023-12-06 19:25:00	\N	\N	10	0	\N	\N
819430	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition de l'académie nationale de Chirurgie	\N	2024-04-10 16:30:00	2024-04-10 17:30:00	\N	\N	2	0	\N	\N
819432	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition du COnseil national de l'ordre des médecins	\N	2024-04-12 09:00:00	2024-04-12 10:00:00	\N	\N	2	0	\N	\N
819461	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	GT subsidiarité du 11 avril 2024	\N	2024-04-11 08:30:00	2024-04-11 08:45:00	\N	\N	4	0	\N	\N
819531	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Information credits AMAE	\N	2024-04-03 17:30:00	2024-04-03 18:30:00	\N	\N	0	0	\N	\N
819537	ETUDES	AUDRAP	\N	\N	\N	audition	\N	2024-04-09 09:00:00	2024-04-09 10:30:00	\N	\N	6	0	\N	1008
819549	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Commande publique - Audition de MM. FREY et LOUBET, Sorbonne Université	Contrôle 2024 - Commande publique - Audition de MM. FREY et LOUBET, Sorbonne Université	2024-04-03 14:00:00	2024-04-03 15:00:00	\N	\N	1	0	\N	\N
819552	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Commande publique - Audition de France Universités	Contrôle 2024 - Commande publique - Audition de MM. OGIER, BRANCHEREAU et GUERY, France Universités	2024-04-03 16:30:00	2024-04-03 17:30:00	\N	\N	1	0	\N	\N
819555	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - CMN - Audition de la direction du budget	Contrôle 2024 - CMN - Audition deM. NGUYEN-HUY et Mme BRANDIZI de la direction du budget	2024-04-03 17:30:00	2024-04-03 18:30:00	\N	\N	1	0	\N	\N
819691	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Protocoles sociaux DGAC - Audition de M. CAZE, DGAC	Contrôle 2024 - Protocoles sociaux DGAC - Audition de M. CAZE, DGAC	2024-04-02 14:00:00	2024-04-02 15:00:00	\N	\N	1	0	\N	\N
819693	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Concessions autoroutes - Audition de M. CALMETTE	Contrôle 2024 - Concessions autoroutes - Audition de M. CALMETTE, maître de conférences en droit public	2024-04-03 08:15:00	2024-04-03 09:00:00	\N	\N	2	0	\N	\N
819774	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI francophonie	\N	2024-04-09 17:30:00	2024-04-09 18:15:00	\N	\N	3	0	\N	\N
821623	ETUDES	AUTRE	\N	\N	\N	GE Handicap - Bilan DuoDay	\N	2024-04-09 16:30:00	2024-04-09 17:30:00	\N	\N	6	0	\N	1014
821629	ETUDES	AUTRE	\N	\N	\N	GE Handicap - Audition JF Rapin	\N	2024-04-10 14:00:00	2024-04-10 15:00:00	\N	\N	11	0	\N	1014
821646	COM_ENQUETE	PLENIERE	\N	TOTA	\N	Audition	\N	2024-04-11 10:33:00	2024-04-11 12:47:00	2024-04-11 15:16:27	2024-04-12 13:35:39	13	0	\N	\N
821828	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Audition de dirigeants européens d'entreprises de taille intermédiaire	\N	2024-04-10 12:30:00	2024-04-10 14:30:00	\N	\N	16	0	\N	\N
821885	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Visite GIGN et GBGM	\N	2024-04-11 08:30:00	2024-04-11 14:15:00	\N	\N	0	0	\N	\N
780472	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition M. Hanotin et Mme Lutz	\N	2023-12-13 09:35:00	2023-12-13 12:05:00	2023-12-14 09:44:56	2023-12-14 17:48:16	39	0	\N	\N
780475	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Droit d'auteur et IA	\N	2023-12-20 09:30:00	2023-12-20 11:30:00	2023-12-20 16:12:30	2023-12-20 18:10:20	29	0	\N	\N
780802	DELEGATION	AUCUNE	\N	\N	COLTER	Examen du rapport d'information relatif aux volets 2 et 3 du statut de l'élu local	\N	2023-12-14 09:00:00	2023-12-14 11:20:00	2023-12-14 17:44:52	\N	22	0	\N	\N
780814	COM_SPECIALE	PLENIERE	\N	DDADUE23	\N	Réunion CS DDADUE	\N	2023-12-13 18:34:00	2023-12-13 19:55:00	2023-12-13 20:56:39	2023-12-14 17:48:23	27	4	\N	\N
780815	COM_SPECIALE	PLENIERE	\N	DDADUE23	\N	Réunion CS DDADUE	\N	2023-12-13 20:30:00	2023-12-13 21:15:00	2023-12-14 19:32:34	2023-12-15 09:43:30	21	5	\N	\N
786370	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Assemblée des départements de France	\N	2024-01-09 14:00:00	2024-01-09 15:00:00	\N	\N	4	0	\N	\N
786371	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition commune de directeurs généraux d'ARS	\N	2024-01-09 15:00:00	2024-01-09 16:30:00	\N	\N	5	0	\N	\N
786372	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition commune d'acteurs de l'habitat inclusif	\N	2024-01-09 16:30:00	2024-01-09 17:45:00	\N	\N	3	0	\N	\N
786373	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition de M. Laurent Frémont	\N	2024-01-09 17:45:00	2024-01-09 19:00:00	\N	\N	3	0	\N	\N
786374	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition DLPAJ PPL Condamnés terroristes et lutte antiterroriste	Audition DLPAJ PPL Condamnés terroristes et lutte antiterroriste	2024-01-08 10:00:00	2024-01-08 11:00:00	\N	\N	1	0	\N	\N
786375	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition juges pour enfants PPL Condamnés terroristes et lutte antiterroriste	Audition juges pour enfants PPL Condamnés terroristes et lutte antiterroriste	2024-01-08 11:00:00	2024-01-08 12:00:00	\N	\N	1	0	\N	\N
786378	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition CCAS Toulouse	\N	2024-01-10 09:00:00	2024-01-10 10:00:00	\N	\N	4	0	\N	\N
786379	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition du Pr Jeandel	\N	2024-01-10 10:00:00	2024-01-10 11:00:00	\N	\N	3	0	\N	\N
786380	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Fédération 3977 contre les maltraitances	\N	2024-01-10 17:30:00	2024-01-10 18:30:00	\N	\N	3	0	\N	\N
786381	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Décompte annuel personnes sans abri - Audition de la Dihal	\N	2024-01-09 08:45:00	2024-01-09 09:30:00	\N	\N	1	0	\N	\N
786382	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Décompte annuel personnes sans abri - Table ronde d'associations	\N	2024-01-09 09:30:00	2024-01-09 10:45:00	\N	\N	1	0	\N	\N
786383	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Décompte annuel personnes sans abri - Table ronde communes effectuant déjà 1 décompte	\N	2024-01-09 10:45:00	2024-01-09 12:00:00	\N	\N	1	0	\N	\N
786385	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Décompte annuel personnes sans abri - Audition de Julien Damon 	\N	2024-01-11 16:30:00	2024-01-11 17:30:00	\N	\N	1	0	\N	\N
801310	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Groupe Astek	\N	2024-02-15 14:00:00	2024-02-15 15:00:00	\N	\N	0	0	\N	\N
801311	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Groupe Onepoint	\N	2024-02-15 15:00:00	2024-02-15 16:00:00	\N	\N	0	0	\N	\N
801312	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Atos	\N	2024-02-15 16:00:00	2024-02-15 16:45:00	\N	\N	0	0	\N	\N
801313	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Direction générale du Trésor	\N	2024-02-15 16:45:00	2024-02-15 17:30:00	\N	\N	0	0	\N	\N
801314	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Autorité des marchés financiers	\N	2024-02-15 18:00:00	2024-02-15 19:00:00	\N	\N	0	0	\N	\N
801340	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Tests PME	PPL "Tests PME" et création d'un dispositif "Impact Entreprises"	2024-02-19 09:30:00	2024-02-19 10:30:00	\N	\N	1	0	\N	\N
801342	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Tests PME	PPL "Tests PME" et création d'un dispositif "Impact Entreprises"	2024-02-21 10:00:00	2024-02-21 11:35:00	\N	\N	2	0	\N	\N
801345	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	MI Atos	\N	2024-02-20 09:00:00	2024-02-20 12:00:00	\N	\N	0	0	\N	\N
806456	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Cancers professionnels des sapeurs-pompiers - Anamnesis	\N	2024-03-05 16:30:00	2024-03-05 17:30:00	\N	\N	4	0	\N	\N
818893	COM_ENQUETE	PLENIERE	\N	ELEC	\N	Table ronde consommateurs et Lewandowski	\N	2024-04-04 15:30:00	2024-04-04 18:30:00	\N	\N	6	0	\N	\N
819993	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de M. Patrick Martin	\N	2024-04-10 09:35:00	2024-04-10 11:45:00	2024-04-10 18:59:58	2024-04-12 13:33:37	41	0	\N	\N
820298	ETUDES	AUTRE	\N	\N	\N	FNP	FNP	2024-04-03 13:30:00	2024-04-03 15:00:00	\N	\N	11	0	\N	907
820551	ETUDES	AUTRE	\N	\N	\N	Viticulteurs d'Occitanie	Viticulteurs d'Occitanie	2024-04-02 13:30:00	2024-04-02 14:30:00	\N	\N	15	0	\N	909
820607	MISSION	AUTRE	\N	PERI	\N	PLENIERE - 9 - CNAM	\N	2024-04-10 16:30:00	2024-04-10 18:00:00	\N	\N	7	0	\N	\N
820608	MISSION	AUCUNE	\N	ARCH	\N	auditions plénières	\N	2024-04-10 16:30:00	2024-04-10 19:30:00	\N	\N	10	0	\N	\N
820911	ETUDES	AUTRE	\N	\N	\N	Audition du Cluster maritime français	Audition du Cluster maritime français	2024-04-10 13:30:00	2024-04-10 14:30:00	\N	\N	7	0	\N	908
820961	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition conjointe ATOS	\N	2024-04-10 16:35:00	2024-04-10 18:25:00	2024-04-10 18:58:18	2024-04-12 13:33:40	39	0	\N	\N
774332	COM_EURO	AUDRAP	\N	AFEU	\N	Auditions Nouvelles techniques génomiques	CAEU - Auditions Nouvelles techniques génomiques	2023-11-28 15:00:00	2023-11-28 18:30:00	\N	\N	3	0	\N	\N
775947	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF 2	\N	2023-11-23 15:00:00	2023-11-23 16:00:00	\N	\N	2	0	\N	\N
786290	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Retrait de l'UE du traité sur la Charte de l'énergie	\N	2023-12-06 16:30:00	2023-12-06 17:15:00	\N	\N	2	0	\N	\N
786293	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Retrait de l'UE du traité sur la Charte de l'énergie	\N	2023-12-06 17:15:00	2023-12-06 17:45:00	\N	\N	2	0	\N	\N
786296	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Retrait de l'UE du traité sur la Charte de l'énergie	\N	2023-12-06 18:00:00	2023-12-06 18:45:00	\N	\N	2	0	\N	\N
786299	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Retrait de l'UE du traité sur la Charte de l'énergie	\N	2023-12-19 18:30:00	2023-12-19 19:15:00	\N	\N	3	0	\N	\N
786303	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Retrait de l'UE du traité sur la Charte de l'énergie	\N	2023-12-19 19:15:00	2023-12-19 20:00:00	\N	\N	2	0	\N	\N
790648	GIA	AUCUNE	\N	\N	\N	Assemblée générale constitutive du groupe d'amitié France-Afrique centrale	Assemblée générale constitutive du groupe d'amitié France-Afrique centrale	2024-01-17 14:30:00	2024-01-17 14:55:00	\N	\N	10	0	572	\N
790663	GIA	AUCUNE	\N	\N	\N	Assemblée générale constitutive du groupe France-Finlande	Assemblée générale constitutive du groupe France-Finlande	2024-01-24 14:20:00	2024-01-24 14:50:00	\N	\N	4	0	640	\N
790670	GIA	AUCUNE	\N	\N	\N	Assemblée générale constitutive du groupe France-Mongolie	Assemblée générale constitutive du groupe France-Mongolie	2023-12-20 14:30:00	2023-12-20 15:00:00	\N	\N	4	0	612	\N
790679	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Quentin TEISSEIRE, Sous-directeur Afrique centrale du MEAE	Entretien avec M. Quentin TEISSEIRE, Sous-directeur Afrique centrale du MEAE	2024-01-23 08:30:00	2024-01-23 09:45:00	\N	\N	6	0	572	\N
791688	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Société du bien-vieillir en France (amendements)	PPL Société du bien-vieillir en France (amendements)	2024-01-30 14:30:00	2024-01-30 14:35:00	2024-01-30 15:46:12	2024-01-30 17:56:40	16	3	\N	\N
791691	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Contentieux du stationnement payant (LEC)	Contentieux du stationnement payant (LEC)	2024-01-31 14:00:00	2024-01-31 16:00:00	\N	\N	0	0	\N	\N
791692	COM_PERMANENTE	AUDRAP	\N	CDD	\N	 PPL Préserver des sols vivants - Audition M. Arnaud Gossement	 PPL Préserver des sols vivants - Audition M. Arnaud Gossement	2024-01-25 14:00:00	2024-01-25 14:50:00	\N	\N	2	0	\N	\N
791695	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Préserver des sols vivants -Audition M. Philippe Billet	PPL Préserver des sols vivants -Audition M. Philippe Billet	2024-01-25 14:50:00	2024-01-25 16:05:00	\N	\N	2	0	\N	\N
791698	COM_PERMANENTE	AUDRAP	\N	CDD	\N	 PPL Préserver des sols vivants - Audition M. Guidoum	 PPL Préserver des sols vivants - Audition M. Guidoum	2024-01-25 16:05:00	2024-01-25 16:40:00	\N	\N	2	0	\N	\N
791701	COM_PERMANENTE	AUDRAP	\N	CDD	\N	 PPL Préserver des sols vivants - Audition M. Phiilppe Camburet	 PPL Préserver des sols vivants - Audition M. Phiilppe Camburet	2024-01-25 17:30:00	2024-01-25 18:35:00	\N	\N	1	0	\N	\N
791703	COM_PERMANENTE	AUDRAP	\N	CDD	\N	 PPL Préserver des sols vivants - Audition M. Harold Levrel	 PPL Préserver des sols vivants - Audition M. Harold Levrel	2024-01-25 18:35:00	2024-01-25 19:10:00	\N	\N	1	0	\N	\N
791719	DELEGATION	AUTRE	\N	\N	DSOM	Auditions coopération et intégration régionales des outre-mer	\N	2024-02-01 09:30:00	2024-02-01 11:30:00	\N	\N	13	0	\N	\N
791721	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Déplacement à Laval	Déplacement à Laval	2024-02-01 08:00:00	2024-02-01 22:00:00	\N	\N	2	0	\N	\N
791727	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	filière cinéma	\N	2024-01-26 08:00:00	2024-01-26 09:00:00	\N	\N	5	0	\N	\N
791733	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition Bilan mandat présidence CNDP	Audition Bilan mandat présidence CNDP	2024-01-23 14:30:00	2024-01-23 15:30:00	\N	\N	1	0	\N	\N
791734	DELEGATION	AUDRAP	\N	\N	206	Audition du Pr Lescure (hôpital Bichat) et de Mme Yvanie Caillé (Renaloo)	\N	2024-01-26 09:00:00	2024-01-26 10:10:00	\N	\N	2	0	\N	\N
791735	DELEGATION	AUDRAP	\N	\N	206	Audition de Santé publique France	\N	2024-01-26 10:10:00	2024-01-26 11:45:00	\N	\N	2	0	\N	\N
794750	COM_ENQUETE	PLENIERE	\N	NARCO	\N	Table ronde de maires de grande ville	Table ronde de maires de grande ville	2024-02-06 09:10:00	2024-02-06 10:25:00	2024-02-06 10:30:40	2024-02-06 16:36:38	10	0	\N	\N
794752	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2024-02-07 10:30:00	2024-02-07 12:00:00	2024-02-07 12:05:31	2024-02-08 12:31:27	58	3	\N	\N
794754	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2024-02-07 16:30:00	2024-02-07 18:05:00	2024-02-08 11:09:13	2024-02-08 12:31:30	19	0	\N	\N
794769	DELEGATION	AUDRAP	\N	\N	206	Audition de la Cnam	\N	2024-02-02 10:05:00	2024-02-02 11:00:00	\N	\N	2	0	\N	\N
794770	DELEGATION	AUDRAP	\N	\N	206	Audition sur la désinformation en santé	\N	2024-02-02 09:00:00	2024-02-02 10:05:00	\N	\N	2	0	\N	\N
794775	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Santé des femmes au travail - Table ronde administrations	\N	2024-02-01 14:30:00	2024-02-01 15:30:00	\N	\N	1	0	\N	\N
794777	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Santé des femmes au travail - Table ronde OS	\N	2024-02-01 16:00:00	2024-02-01 17:00:00	\N	\N	1	0	\N	\N
818811	CMP	AUTRE	\N	NUCL	\N	PJL Sûreté nucléaire	PJL Sûreté nucléaire	2024-04-03 17:03:00	2024-04-03 18:45:00	\N	\N	11	0	\N	\N
819953	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2024-04-10 11:25:00	2024-04-10 11:40:00	2024-04-10 11:40:59	2024-04-12 13:33:39	42	0	\N	\N
794779	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Santé des femmes au travail - Audition Medef	\N	2024-02-01 17:00:00	2024-02-01 17:45:00	\N	\N	1	0	\N	\N
801268	ETUDES	AUCUNE	\N	\N	\N	Audition Carbone 4 et France bois forêt	Audition Carbone 4 et France bois forêt	2024-02-14 16:30:00	2024-02-14 18:00:00	\N	\N	15	0	\N	948
801287	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GS ZAN	GS ZAN	2024-02-13 16:00:00	2024-02-13 18:30:00	\N	\N	3	0	\N	\N
804087	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Communication déplacement Berlin 28 & 29/01	Communication déplacement Berlin 28 & 29/01	2024-03-06 11:05:00	2024-03-06 11:25:00	2024-03-07 11:47:09	2024-03-07 22:40:59	39	12	\N	\N
804088	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de M. Stéphane Séjourné	Audition de M. Stéphane Séjourné, ministre de l'Europe et des affaires étrangères	2024-03-06 16:30:00	2024-03-06 18:20:00	2024-03-08 14:50:55	2024-03-08 16:09:08	29	0	\N	\N
812646	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	\N	Audition rapporteur - PPL Ordonnance de protection	2024-03-20 14:30:00	2024-03-20 15:00:00	\N	\N	1	0	\N	\N
776154	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Mission Plan de relance	Mission Plan de relance	2023-12-02 14:35:00	2023-12-02 18:15:00	\N	\N	44	0	\N	\N
776157	COM_EURO	AUDRAP	\N	AFEU	\N	Audition - Réforme du Pacte de stabillité et de croissance	Audition - Réforme du Pacte de stabillité et de croissance	2023-12-01 10:00:00	2023-12-01 11:30:00	\N	\N	2	0	\N	\N
781491	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion CATDD	\N	2023-12-13 09:45:00	2023-12-13 11:35:00	2023-12-13 16:38:39	2023-12-14 17:48:17	40	6	\N	\N
786180	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 17 janvier 2024	\N	2024-01-17 13:30:00	2024-01-17 14:50:00	2024-01-17 17:23:42	2024-01-17 18:05:54	10	0	\N	\N
786181	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 17 janvier 2023	\N	2024-01-17 17:10:00	2024-01-17 19:10:00	2024-01-17 19:10:52	2024-01-18 18:02:01	17	0	\N	\N
786182	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du jeudi 18 janvier 2024	\N	2024-01-18 08:40:00	2024-01-18 10:45:00	2024-01-23 15:06:18	2024-01-24 10:31:15	48	0	\N	\N
786183	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	GT institutions	GT Institutions	2023-12-21 09:00:00	2023-12-21 12:30:00	\N	\N	1	0	\N	\N
786185	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions rapporteur	\N	2023-12-21 17:00:00	2023-12-21 18:00:00	\N	\N	1	0	\N	\N
786191	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Société du bien-vieillir en France (avis)	PPL Société du bien-vieillir en France (avis)	2024-01-16 09:30:00	2024-01-16 10:00:00	2024-01-16 10:12:20	2024-01-16 16:23:55	18	4	\N	\N
786192	COM_PERMANENTE	AUTRE	\N	LOIS	\N	MI Emeutes de juin 2023 - Table ronde des réseaux sociaux	MI Emeutes de juin 2023 - Table ronde des réseaux sociaux	2024-01-16 14:30:00	2024-01-16 15:45:00	2024-01-16 19:49:13	2024-01-17 18:05:05	14	0	\N	\N
786193	COM_PERMANENTE	AUTRE	\N	LOIS	\N	MI Emeutes de juin 2023 - Table ronde de sociologues	MI Emeutes de juin 2023 - Table ronde de sociologues	2024-01-16 16:00:00	2024-01-16 17:30:00	2024-01-16 19:49:04	2024-01-17 18:05:05	10	0	\N	\N
786196	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Présidence de la Cnil - Audition de Marie-Laure Denis	Présidence de la Cnil - Audition de Marie-Laure Denis	2024-01-17 11:30:00	2024-01-17 13:30:00	2024-01-18 00:51:24	2024-01-18 18:01:19	46	0	\N	\N
786197	COM_PERMANENTE	PEC_NON_MML	\N	LOIS	\N	PPL Droit applicable aux collectivités locales (rapport LEC)	PPL Droit applicable aux collectivités locales (rapport LEC)	2024-01-17 14:05:00	2024-01-17 14:55:00	2024-01-17 16:25:57	2024-01-17 18:05:01	19	3	\N	\N
786386	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion CE TotalEnergies	\N	2024-01-17 14:00:00	2024-01-17 14:30:00	\N	\N	0	0	\N	\N
786389	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL TND - Audition Dgesco	\N	2024-01-09 09:40:00	2024-01-09 10:45:00	\N	\N	1	0	\N	\N
786391	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL TND - Audition APPEA	\N	2024-01-09 10:45:00	2024-01-09 11:45:00	\N	\N	1	0	\N	\N
786396	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions rapporteurs PPL Condamnés terroristes et lutte antiterroriste	\N	2024-01-09 15:00:00	2024-01-09 16:45:00	\N	\N	2	0	\N	\N
786399	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteurs - MCC Agressions contre les enseignants	Audition rapporteurs - MCC Agressions contre les enseignants	2024-01-09 15:30:00	2024-01-09 17:00:00	\N	\N	4	0	\N	\N
786514	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL TND - Audition HAS	\N	2024-01-10 16:30:00	2024-01-10 17:30:00	\N	\N	1	0	\N	\N
786515	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL TND - Audition DGS-DGOS-ANDPC	\N	2024-01-10 17:30:00	2024-01-10 18:45:00	\N	\N	1	0	\N	\N
786518	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions rapporteur	\N	2024-01-09 14:00:00	2024-01-09 15:20:00	\N	\N	1	0	\N	\N
786530	MECSS	AUCUNE	\N	\N	MECSS	Audition de Mme Laurence Eslous et M. Antoine Magnier	\N	2024-01-17 14:00:00	2024-01-17 15:00:00	2024-01-22 15:50:20	2024-01-22 17:46:41	14	0	\N	\N
786532	COM_EURO	AUDRAP	\N	AFEU	\N	Auditions lutte contre la corruption	\N	2023-11-29 16:30:00	2023-11-29 17:30:00	\N	\N	3	0	\N	\N
786542	COM_EURO	AUDRAP	\N	AFEU	\N	Auditions lutte contre la corruption	\N	2023-12-19 15:00:00	2023-12-19 16:00:00	\N	\N	3	0	\N	\N
786546	COM_EURO	AUDRAP	\N	AFEU	\N	Audition lutte contre la corruption	\N	2023-12-20 16:30:00	2023-12-20 17:30:00	\N	\N	3	0	\N	\N
786550	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL TND - Audition Cnom-FNO	\N	2024-01-11 08:00:00	2024-01-11 09:00:00	\N	\N	1	0	\N	\N
786551	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL TND - Table ronde TDAH	\N	2024-01-11 09:00:00	2024-01-11 10:00:00	\N	\N	1	0	\N	\N
786552	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL TND - Audition sur l'autisme	\N	2024-01-11 10:00:00	2024-01-11 11:00:00	\N	\N	1	0	\N	\N
786553	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL TND - Audition délégué interministériel	\N	2024-01-11 11:00:00	2024-01-11 12:30:00	\N	\N	1	0	\N	\N
786554	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL TND - Audition FFDys	\N	2024-01-11 13:30:00	2024-01-11 14:15:00	\N	\N	1	0	\N	\N
786555	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL TND - Audition Collectif Je t'Aide	\N	2024-01-11 14:15:00	2024-01-11 15:00:00	\N	\N	1	0	\N	\N
786559	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL ESH sur le temps méridien	\N	2024-01-10 16:15:00	2024-01-10 17:00:00	\N	\N	7	0	\N	\N
786587	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Société du bien-vieillir - Audition de France Assos santé	\N	2024-01-10 15:30:00	2024-01-10 16:30:00	\N	\N	6	0	\N	\N
804086	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Examen de 2 conventions internationales	Examen de 2 conventions internationales	2024-03-06 11:25:00	2024-03-06 11:50:00	2024-03-12 15:56:14	2024-03-12 15:56:39	41	12	\N	\N
786195	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Condamnés terroristes et lutte antiterroriste (rapport)	PPL Condamnés terroristes et lutte antiterroriste (rapport)	2024-01-17 10:00:00	2024-01-17 11:25:00	2024-01-18 00:51:38	2024-01-18 18:01:20	46	0	\N	\N
786588	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Société du bien-vieillir - Audition du Collectif Handicaps	\N	2024-01-10 16:30:00	2024-01-10 17:30:00	\N	\N	5	0	\N	\N
786590	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Société du bien-vieillir - Audition du Cercle V&S	\N	2024-01-10 11:00:00	2024-01-10 12:00:00	\N	\N	4	0	\N	\N
792184	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Crise du logement	\N	2024-01-29 15:30:00	2024-01-29 18:15:00	\N	\N	3	0	\N	\N
792504	COM_PERMANENTE	AUDRAP	\N	CDD	\N	 PPL Préserver des sols vivants - Audition ADEME	 PPL Préserver des sols vivants - Audition ADEME	2024-01-30 13:55:00	2024-01-30 14:45:00	\N	\N	2	0	\N	\N
793065	COM_PERMANENTE	AUTRE	\N	CAE	\N	Examen PJL Sûreté nuclaire	\N	2024-01-30 18:00:00	2024-01-30 20:00:00	2024-01-31 09:35:27	2024-01-31 18:48:04	41	3	\N	\N
794605	COM_ENQUETE	PLENIERE	\N	TOTA	\N	Réunion CE TE	\N	2024-02-01 10:28:00	2024-02-01 12:35:00	2024-02-01 18:03:20	2024-02-13 15:27:17	11	0	\N	\N
794632	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Michael Weber	Auditions M. Michael Weber	2024-01-31 17:00:00	2024-01-31 20:30:00	\N	\N	2	0	\N	\N
801237	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2024-02-28 09:00:00	2024-02-28 10:50:00	2024-02-28 10:50:00	2024-02-28 16:39:28	30	0	\N	\N
801238	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Négociations salariales - Audition Afep	\N	2024-02-20 09:30:00	2024-02-20 10:15:00	\N	\N	3	0	\N	\N
801243	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Négociations salariales - Audition représentation de la France à l'UE	\N	2024-02-20 10:15:00	2024-02-20 11:00:00	\N	\N	3	0	\N	\N
801247	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Négociations salariales - Audition ANDRH	\N	2024-02-20 11:00:00	2024-02-20 11:45:00	\N	\N	3	0	\N	\N
801251	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Cancers professionnels des sapeurs-pompiers - Journalistes "Vert de Rage"	\N	2024-02-20 10:00:00	2024-02-20 11:00:00	\N	\N	2	0	\N	\N
801259	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Cancers professionnels des sapeurs-pompiers - Anses	\N	2024-02-20 14:00:00	2024-02-20 15:00:00	\N	\N	3	0	\N	\N
801263	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Cancers professionnels des sapeurs-pompiers - CNRACL	\N	2024-02-20 11:00:00	2024-02-20 12:00:00	\N	\N	3	0	\N	\N
801284	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Dispositions législatives relatives à la santé - Audition conjointe DAJMS-DGS-DGOS 	\N	2024-02-20 16:00:00	2024-02-20 16:45:00	\N	\N	2	0	\N	\N
801285	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Préfet et Pdt Assemblée territoriale Wallis-et-Futuna	\N	2024-02-21 14:00:00	2024-02-21 14:45:00	\N	\N	1	0	\N	\N
810590	COM_SPECIALE	PLENIERE	\N	ESNU	\N	Réunion plénière	\N	2024-03-19 09:05:00	2024-03-19 09:15:00	2024-03-19 10:43:19	2024-03-19 17:28:47	10	0	\N	\N
780741	GIA	AUCUNE	\N	\N	\N	AG du groupe d'amitié France-Chine	Assemblée générale du groupe d'amitié France-Chine	2023-12-12 14:00:00	2023-12-12 14:30:00	\N	\N	14	0	584	\N
782149	QUESTURE	AUCUNE	\N	\N	\N	Réunion de Questure	Réunion du Conseil de Questure	2023-12-05 16:00:00	2023-12-05 17:30:00	\N	\N	3	0	\N	\N
789274	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat sur les pratiques des centrales d'achat	Débat sur les pratiques des centrales d'achat	2024-01-25 10:30:00	2024-01-25 11:40:00	\N	\N	31	0	\N	\N
789275	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Dépistage des troubles du neuro-développement	PPL Dépistage des troubles du neuro-développement	2024-01-25 11:40:00	2024-01-25 13:10:00	\N	\N	22	0	\N	\N
789276	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Droit applicable aux collectivités locales	PPL Droit applicable aux collectivités locales	2024-01-25 14:45:00	2024-01-25 15:40:00	\N	\N	22	0	\N	\N
797701	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	Commission spéciale	Commission spéciale de contrôle des comptes	2024-02-07 16:30:00	2024-02-07 18:30:00	2024-02-08 15:46:25	2024-02-09 17:33:17	6	0	\N	\N
802508	COM_ENQUETE	PLENIERE	\N	INFLU	\N	Audition du Capitaine de Vaisseau Yann Briand (SGDSN)	Audition du Capitaine de Vaisseau Yann Briand (SGDSN)	2024-02-27 15:00:00	2024-02-27 16:15:00	2024-02-28 14:34:10	2024-02-28 16:35:51	14	0	\N	\N
812668	GIA	AUCUNE	\N	\N	\N	Colloque de l'APFA sur les 5 ans du Traité d'Aix-la-Chapelle	Colloque de l'APFA sur les 5 ans du Traité d'Aix-la-Chapelle	2024-03-18 14:30:00	2024-03-18 17:30:00	\N	\N	2	0	604	\N
812672	GIA	AUCUNE	\N	\N	\N	Entretien avec Nerijus Aleksiejunas, Ambassadeur de Lituanie  	Entretien avec Nerijus Aleksiejunas, Ambassadeur de Lituanie  	2024-03-20 16:30:00	2024-03-20 17:45:00	\N	\N	10	0	616	\N
812869	ETUDES	AUCUNE	\N	\N	\N	GE ESS	GE ESS	2024-03-20 13:30:00	2024-03-20 14:15:00	\N	\N	7	0	\N	998
818965	GIA	AUCUNE	\N	\N	\N	Entretien avec Mme Anne Genetet, présidente du GA France-Australie - Assemblée nationale	Entretien avec Mme Anne Genetet, présidente du GA France-Australie - Assemblée nationale	2024-03-07 13:00:00	2024-03-07 14:30:00	\N	\N	1	0	578	\N
772507	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-11-30 10:35:00	2023-11-30 10:50:00	2023-11-30 10:52:20	2023-11-30 17:04:37	21	5	\N	\N
772508	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-12-01 10:30:00	2023-12-01 12:00:00	\N	\N	0	0	\N	\N
772509	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE 86 - PLF pour 2024 - Examen amdts art liminaire et 33	PLENIERE 86 - PLF pour 2024 - Examen amdts art liminaire et 33	2023-11-24 14:00:00	2023-11-24 15:05:00	2023-12-06 14:40:09	2023-12-06 18:22:52	26	8	\N	\N
773755	GIA	AUCUNE	\N	\N	\N	assemblée générale du groupe	\N	2023-11-28 13:30:00	2023-11-28 14:40:00	\N	\N	6	0	661	\N
775650	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Emeutes	MI Emeutes	2023-11-29 17:30:00	2023-11-29 18:30:00	\N	\N	4	0	\N	\N
776015	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Nouvelle lecture PLFSS	Nouvelle lecture PLFSS	2023-12-01 09:00:00	2023-12-01 10:10:00	\N	\N	34	0	\N	\N
777130	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE 94 - PPL Bâtiments scolaire - PPLO Réserve parlementaire 	PLENIERE 94 - PPL Bâtiments scolaire - PPLO Réserve parlementaire 	2023-12-05 09:00:00	2023-12-05 10:35:00	2023-12-05 16:18:37	2023-12-06 18:26:15	20	4	\N	\N
777193	MISSION	AUDRAP	\N	BIOCARBU	\N	FACCO	\N	2023-06-08 13:45:00	2023-06-08 14:30:00	\N	\N	3	0	\N	\N
777200	MISSION	AUDRAP	\N	BIOCARBU	\N	Direction générale des finances publiques - Direction de l'immobilier de l'État	Direction générale des finances publiques - Direction de l'immobilier de l'État	2023-06-08 14:30:00	2023-06-08 15:30:00	\N	\N	3	0	\N	\N
777204	MISSION	AUDRAP	\N	BIOCARBU	\N	Cooperl environnement	Cooperl environnement	2023-06-08 15:30:00	2023-06-08 16:30:00	\N	\N	3	0	\N	\N
777208	MISSION	AUDRAP	\N	BIOCARBU	\N	Tryfil	Tryfil	2023-06-08 16:30:00	2023-06-08 17:30:00	\N	\N	1	0	\N	\N
777217	MISSION	AUDRAP	\N	BIOCARBU	\N	ADF	ADF	2023-06-14 16:20:00	2023-06-14 17:30:00	\N	\N	5	0	\N	\N
777223	MISSION	AUDRAP	\N	BIOCARBU	\N	Européenne de la biomasse	Européenne de la biomasse	2023-06-06 09:00:00	2023-06-06 10:00:00	\N	\N	5	0	\N	\N
777233	MISSION	AUDRAP	\N	BIOCARBU	\N	Direction du budget	Direction du budget	2023-06-06 10:00:00	2023-06-06 11:00:00	\N	\N	5	0	\N	\N
772504	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-11-29 09:00:00	2023-11-29 11:05:00	2023-11-29 11:26:21	2023-11-29 14:30:26	39	0	\N	\N
777240	MISSION	AUDRAP	\N	BIOCARBU	\N	Groupement des autorités responsables de transport 	Groupement des autorités responsables de transport 	2023-05-30 09:00:00	2023-05-30 10:00:00	\N	\N	6	0	\N	\N
777247	MISSION	AUDRAP	\N	BIOCARBU	\N	Fédération nationale des transports de voyageurs	Fédération nationale des transports de voyageurs	2023-05-30 10:00:00	2023-05-30 11:00:00	\N	\N	5	0	\N	\N
777254	MISSION	AUDRAP	\N	BIOCARBU	\N	IATA	IATA	2023-05-23 09:00:00	2023-05-23 10:00:00	\N	\N	4	0	\N	\N
777259	MISSION	AUDRAP	\N	BIOCARBU	\N	Haffneur Energy	Haffneur Energy	2023-05-23 10:00:00	2023-05-23 11:00:00	\N	\N	3	0	\N	\N
777264	MISSION	AUDRAP	\N	BIOCARBU	\N	Groupe Avril	Groupe Avril	2023-05-11 16:00:00	2023-05-11 17:00:00	\N	\N	2	0	\N	\N
777267	MISSION	AUDRAP	\N	BIOCARBU	\N	Lhyfe	Lhyfe	2023-05-11 17:00:00	2023-05-11 18:00:00	\N	\N	2	0	\N	\N
777270	MISSION	AUDRAP	\N	BIOCARBU	\N	Union TLF	Union TLF	2023-04-13 11:10:00	2023-04-13 12:30:00	\N	\N	2	0	\N	\N
777274	MISSION	AUDRAP	\N	BIOCARBU	\N	Neste	Neste	2023-05-02 09:00:00	2023-05-02 10:00:00	\N	\N	2	0	\N	\N
777278	MISSION	AUDRAP	\N	BIOCARBU	\N	Syndicat des énergies renouvelables	Syndicat des énergies renouvelables	2023-05-02 10:00:00	2023-05-02 11:00:00	\N	\N	3	0	\N	\N
777282	MISSION	AUDRAP	\N	BIOCARBU	\N	UFIP Énergies et Mobilités               	UFIP Énergies et Mobilités               	2023-04-27 09:00:00	2023-04-27 10:00:00	\N	\N	2	0	\N	\N
777285	MISSION	AUDRAP	\N	BIOCARBU	\N	Banque des territoires 	Banque des territoires 	2023-04-27 10:00:00	2023-04-27 11:00:00	\N	\N	2	0	\N	\N
777293	MISSION	AUDRAP	\N	BIOCARBU	\N	DGE 	DGE 	2023-04-27 11:00:00	2023-04-27 12:00:00	\N	\N	2	0	\N	\N
777296	MISSION	AUDRAP	\N	BIOCARBU	\N	Fédération nationale des travaux publics (FNTP)	Fédération nationale des travaux publics (FNTP)	2023-04-27 14:30:00	2023-04-27 15:30:00	\N	\N	1	0	\N	\N
777439	MISSION	AUDRAP	\N	BIOCARBU	\N	Équilibre des énergies	Équilibre des énergies	2023-04-11 10:00:00	2023-04-11 11:00:00	\N	\N	3	0	\N	\N
777454	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	GT Institution	GT Institution	2023-12-04 16:30:00	2023-12-04 18:30:00	\N	\N	1	0	\N	\N
777618	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Emeutes	MI Emeutes	2023-12-05 16:30:00	2023-12-05 17:15:00	\N	\N	3	0	\N	\N
777619	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur	\N	2023-12-05 14:30:00	2023-12-05 15:30:00	\N	\N	5	0	\N	\N
777629	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Emeutes	MI Emeutes	2023-12-05 15:30:00	2023-12-05 16:30:00	\N	\N	4	0	\N	\N
777689	COM_PERMANENTE	AUTRE	\N	CAE	\N	Table ronde Logement	\N	2023-12-06 09:35:00	2023-12-06 12:20:00	2023-12-06 12:50:50	2023-12-06 18:26:18	41	0	\N	\N
807996	BUREAU	AUCUNE	\N	\N	\N	Délégation en charge du travail parlementaire	Délégation en charge du travail parlementaire	2024-03-12 14:30:00	2024-03-12 15:30:00	\N	\N	2	0	\N	\N
808003	BUREAU	AUCUNE	\N	\N	\N	Délégation en charge du travail parlementaire	Délégation en charge du travail parlementaire	2024-03-12 15:30:00	2024-03-12 17:00:00	\N	\N	3	0	\N	\N
809327	COM_ENQUETE	PLENIERE	\N	COPRO	\N	TR associations de copropriétaires et de de consommateurs	TR associations de copropriétaires et de de consommateurs	2024-03-12 16:00:00	2024-03-12 17:30:00	2024-03-13 17:22:41	2024-03-14 16:37:32	6	0	\N	\N
810521	DELEGATION	AUDRAP	\N	\N	211	Rencontre avec Justine Masika Bihamba	\N	2024-03-26 09:00:00	2024-03-26 10:10:00	\N	\N	11	0	\N	\N
810522	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Paquet pharmaceutique	\N	2024-02-15 16:30:00	2024-02-15 18:30:00	\N	\N	3	0	\N	\N
810527	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition Rapporteur	\N	2024-03-15 15:00:00	2024-03-15 17:00:00	\N	\N	2	0	\N	\N
810533	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition P. Tabarot	\N	2024-03-14 16:30:00	2024-03-14 17:00:00	\N	\N	1	0	\N	\N
810539	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Réunion constitutive GS Tourisme	\N	2024-03-06 13:15:00	2024-03-06 13:35:00	\N	\N	0	0	\N	\N
810540	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Réunion constitutive GS Tourisme	\N	2024-03-06 13:15:00	2024-03-06 15:00:00	\N	\N	0	0	\N	\N
810556	COM_PERMANENTE	AUTRE	\N	CDD	\N	Table ronde sur l'équité territoriale en matière d'accès aux soins	\N	2024-03-27 09:30:00	2024-03-27 12:05:00	2024-03-27 18:22:37	2024-03-29 15:42:14	32	6	\N	\N
810557	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GS ZAN - Réunion constitutive	GS ZAN - Réunion constitutive	2024-02-06 16:00:00	2024-02-06 17:15:00	\N	\N	5	0	\N	\N
810558	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audition	\N	2024-03-05 10:00:00	2024-03-05 11:00:00	\N	\N	0	0	\N	\N
810559	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audition	\N	2024-03-05 14:00:00	2024-03-05 17:00:00	\N	\N	0	0	\N	\N
810560	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Auditions	\N	2024-03-06 14:00:00	2024-03-06 15:00:00	\N	\N	0	0	\N	\N
810561	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audition	\N	2024-03-08 10:30:00	2024-03-08 11:30:00	\N	\N	0	0	\N	\N
810562	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audition	\N	2024-03-12 09:30:00	2024-03-12 10:30:00	\N	\N	0	0	\N	\N
810564	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audition	\N	2024-03-12 14:30:00	2024-03-12 16:30:00	\N	\N	0	0	\N	\N
810576	COM_PERMANENTE	AUTRE	\N	CDD	\N	Mission d'information sur l'évaluation de la loi portant création de l'OFB 	\N	2024-03-20 09:30:00	2024-03-20 12:00:00	2024-03-20 12:30:06	2024-03-20 17:24:26	37	0	\N	\N
811353	GIA	AUCUNE	\N	\N	\N	Rencontre avec M. Abdulla Al Shehhi, directeur de la « Maison de la famille abrahamique »	Rencontre avec M. Abdulla Al Shehhi, directeur de la « Maison de la famille abrahamique »	2024-03-19 15:30:00	2024-03-19 16:30:00	\N	\N	4	0	661	\N
813243	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJLC Corps électoral Nouvelle-Calédonie	PJLC Corps électoral Nouvelle-Calédonie	2024-03-26 15:35:00	2024-03-26 20:15:00	\N	\N	188	0	\N	\N
813250	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Suite PPL Saisie et avoirs criminels	Suite PPL Saisie et avoirs criminels	2024-03-27 16:30:00	2024-03-27 17:40:00	\N	\N	62	0	\N	\N
773642	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition CNTR	\N	2023-11-28 16:15:00	2023-11-28 17:00:00	\N	\N	2	0	\N	\N
773649	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Auditon DGE et DGCCRF	\N	2023-11-27 16:30:00	2023-11-27 17:30:00	\N	\N	2	0	\N	\N
773657	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE 90 - PLF pour 2024 - Suite examen amendements séance 1ère partie	PLENIERE 90 - PLF pour 2024 - Suite examen amendements séance 1ère partie	2023-11-28 14:00:00	2023-11-28 14:18:00	2023-12-06 14:45:57	2023-12-06 18:22:50	18	5	\N	\N
821970	COM_EURO	AUDRAP	\N	AFEU	\N	Auditions euro numérique	\N	2024-04-09 13:30:00	2024-04-09 16:30:00	\N	\N	2	0	\N	\N
777911	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE 95 - PLF pour 2024_Examen articles non rattachés Tome III - Missions RCT et AGTE	PLENIERE 95 - PLF pour 2024_Examen articles non rattachés Tome III - Missions RCT et AGTE	2023-12-06 09:02:00	2023-12-06 10:10:00	2023-12-07 08:55:21	2023-12-07 17:28:55	34	3	\N	\N
773787	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE 92 - PLF pour 2024 - Examen amdts séance Partie II Missions	PLENIERE 92 - PLF pour 2024 - Examen amdts séance Partie II Missions	2023-12-01 09:00:00	2023-12-01 09:23:00	2023-12-02 00:41:51	2023-12-05 17:44:00	20	4	\N	\N
773849	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition de JM Blanquer	\N	2023-12-05 17:35:00	2023-12-05 19:00:00	2023-12-05 18:59:50	2023-12-06 18:26:16	33	0	\N	\N
773892	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Allocation universelle d'études - Table ronde de chercheurs	\N	2023-11-28 17:30:00	2023-11-28 18:30:00	\N	\N	2	0	\N	\N
787205	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion CATDD	\N	2024-01-17 09:30:00	2024-01-17 12:30:00	2024-01-18 09:47:34	2024-01-18 18:01:22	84	0	\N	\N
787589	DELEGATION	AUTRE	\N	\N	ENTREPRISES	Table ronde "Défis de l'entreprise : le regard des économistes"	\N	2024-01-25 08:00:00	2024-01-25 10:00:00	\N	\N	0	0	\N	\N
787590	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Pascal Martin	Auditions M. Pascal Martin	2024-01-09 09:45:00	2024-01-09 12:00:00	\N	\N	1	0	\N	\N
787592	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Pascal Martin	Auditions M. Pascal Martin	2024-01-09 13:45:00	2024-01-09 14:30:00	\N	\N	1	0	\N	\N
787594	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Pascal Martin	Auditions M. Pascal Martin	2024-01-10 09:00:00	2024-01-10 12:30:00	\N	\N	1	0	\N	\N
787596	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audiition de M. Pascal Martin	Audiition de M. Pascal Martin	2024-01-11 09:00:00	2024-01-11 12:30:00	\N	\N	1	0	\N	\N
787598	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Pascal Martin	Auditions M. Pascal Martin	2024-01-11 13:30:00	2024-01-11 14:30:00	\N	\N	1	0	\N	\N
787600	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Pascal Martin	Auditions M. Pascal Martin	2024-01-16 09:00:00	2024-01-16 10:30:00	\N	\N	1	0	\N	\N
787602	COM_PERMANENTE	AUDRAP	\N	CDD	\N	TR scientifiques (Michaël Mangeon, Mathias Roger, Benoît Journé)	\N	2024-01-16 14:30:00	2024-01-16 15:30:00	\N	\N	3	0	\N	\N
787606	COM_PERMANENTE	AUDRAP	\N	CDD	\N	TR des acteurs SMR (Jimmy, Hexana, Projet Sparta, Stellaria)	\N	2024-01-16 15:30:00	2024-01-16 16:30:00	\N	\N	2	0	\N	\N
787609	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition CEA	\N	2024-01-16 16:30:00	2024-01-16 17:30:00	\N	\N	1	0	\N	\N
807326	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Discriminations par la pratique de tests individuels et statistiques	PPL Discriminations par la pratique de tests individuels et statistiques	2024-03-12 18:20:00	2024-03-12 20:40:00	\N	\N	78	0	\N	\N
807343	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI Atos	MI Atos	2024-03-07 15:00:00	2024-03-07 16:00:00	\N	\N	1	0	\N	\N
807345	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI Atos	MI Atos	2024-03-07 17:00:00	2024-03-07 18:00:00	\N	\N	1	0	\N	\N
807347	GIA	AUCUNE	\N	\N	\N	Réunion de travail à l'Ambassade d'Australie	Réunion de travail à l'Ambassade d'Australie avec l'Ambassadrice	2024-03-06 16:45:00	2024-03-06 18:00:00	\N	\N	5	0	578	\N
818426	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2024-03-20 18:04:00	2024-03-20 18:57:00	\N	\N	27	0	\N	\N
818981	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2024-04-09 09:30:00	2024-04-09 12:50:00	\N	\N	49	0	\N	\N
818982	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL continuité transports	PPL continuité transports	2024-04-09 14:30:00	2024-04-09 18:40:00	\N	\N	188	0	\N	\N
818983	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat carte scolaire	Débat carte scolaire	2024-04-09 18:40:00	2024-04-09 20:15:00	\N	\N	55	0	\N	\N
818984	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL assainissement cadastral	PPL assainissement cadastral	2024-04-09 21:45:00	2024-04-09 23:10:00	\N	\N	38	0	\N	\N
818985	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Nucléaire	CMP Nucléaire	2024-04-09 23:10:00	2024-04-10 00:10:00	\N	\N	41	0	\N	\N
818986	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP DDADUE agricole	CMP DDADUE agricole	2024-04-10 00:10:00	2024-04-10 01:05:00	\N	\N	25	0	\N	\N
818987	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2024-04-10 15:00:00	2024-04-10 16:15:00	\N	\N	300	0	\N	\N
818988	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Abrogation réforme des retraites	PPL Abrogation réforme des retraites	2024-04-10 16:35:00	2024-04-10 18:10:00	\N	\N	74	0	\N	\N
818989	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Service civique	PPL Service civique	2024-04-10 18:30:00	2024-04-10 20:25:00	\N	\N	71	0	\N	\N
818990	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Haut Commissariat au Plan	Débat Haut Commissariat au Plan	2024-04-10 22:00:00	2024-04-10 23:25:00	\N	\N	29	0	\N	\N
818991	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Frelon asiatique	PPL Frelon asiatique	2024-04-11 10:30:00	2024-04-11 12:45:00	\N	\N	54	0	\N	\N
818992	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Pharmacies	PPL Pharmacies	2024-04-11 12:45:00	2024-04-11 13:15:00	\N	\N	24	0	\N	\N
818993	GIA	AUCUNE	\N	\N	\N	Newroz - Nouvel an kurde	Nouvel an kurde, co-organisé avec la représentation du Gouvernement régional du Kurdistan et l'ambassade d'Irak	2024-03-26 18:30:00	2024-03-26 20:30:00	\N	\N	6	0	615	\N
772133	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 30 novembre 2023	\N	2023-11-30 08:30:00	2023-11-30 11:40:00	2023-11-30 14:54:48	2023-11-30 17:04:54	18	0	\N	\N
772136	DELEGATION	AUCUNE	\N	\N	206	La place des start-up dans le développement des réacteurs nucléaires innovants	\N	2023-11-23 09:30:00	2023-11-23 12:10:00	\N	\N	15	0	\N	\N
772197	COM_ENQUETE	PLENIERE	\N	NARCO	\N	Auditions DGPN - DGDDI - DNRED - OFAST - DGGN	Auditions DGPN - DGDDI - DNRED - OFAST - DGGN	2023-11-27 14:05:00	2023-11-27 18:35:00	2023-11-27 18:36:45	2023-11-28 17:12:11	10	0	\N	\N
772198	COM_ENQUETE	PLENIERE	\N	NARCO	\N	Auditions Tracfin - AGRASC	Auditions Tracfin - AGRASC	2023-11-30 10:30:00	2023-11-30 13:00:00	2023-11-30 16:00:52	2023-11-30 17:05:15	10	0	\N	\N
772293	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Le Secours Catholique	Le Secours Catholique	2023-11-09 14:30:00	2023-11-09 15:15:00	\N	\N	1	0	\N	\N
772297	COM_PERMANENTE	AUDRAP	\N	CDD	\N	GART	GART	2023-11-14 17:45:00	2023-11-14 18:30:00	\N	\N	1	0	\N	\N
772299	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PFA	PFA	2023-11-15 14:15:00	2023-11-15 15:00:00	\N	\N	1	0	\N	\N
772302	COM_PERMANENTE	AUDRAP	\N	CDD	\N	France Nature Environnement	France Nature Environnement	2023-11-16 09:00:00	2023-11-16 10:00:00	\N	\N	1	0	\N	\N
772306	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition de Marc Fesneau	\N	2023-11-23 11:30:00	2023-11-23 12:45:00	2023-11-23 16:11:58	2023-11-23 17:48:21	14	0	\N	\N
772361	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 86	PLENIERE - 86	2023-11-23 18:15:00	2023-11-23 18:25:00	2023-11-24 17:10:56	2023-11-27 17:42:58	26	3	\N	\N
772421	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Budget 2024 - Avis	Budget 2024 - Avis	2023-11-28 09:30:00	2023-11-28 10:10:00	2023-11-28 10:40:09	2023-11-28 17:12:07	17	5	\N	\N
787200	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE 1 - PPL 579 EDF - Comm. C. RAYNAL Programmes de contrôle 2024	2024PLENIERE 1 - PPL 579 EDF examen rapport - Communication. C. RAYNAL Programmes de contrôle 2024	2024-01-17 09:35:00	2024-01-17 10:30:00	2024-01-19 17:29:43	2024-01-19 19:18:54	37	4	\N	\N
772429	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Budget 2024 - Audition d'Eric Dupond-Moretti	Budget 2024 - Audition d'Eric Dupond-Moretti	2023-11-28 17:30:00	2023-11-28 19:15:00	2023-11-28 19:50:45	2023-11-29 14:30:26	25	0	\N	\N
772432	COM_PERMANENTE	AUDRAP	\N	CDD	\N	TR garages solidaires	TR garages solidaires	2023-11-16 10:00:00	2023-11-16 11:00:00	\N	\N	2	0	\N	\N
772436	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Communauté de communes Côte Ouest Centre Manche	Communauté de communes Côte Ouest Centre Manche	2023-11-16 11:00:00	2023-11-16 12:00:00	\N	\N	1	0	\N	\N
772438	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Mobilians	Mobilians	2023-11-16 12:00:00	2023-11-16 13:00:00	\N	\N	1	0	\N	\N
772441	DELEGATION	AUCUNE	\N	\N	DSOM	Suivi du CIOM : échange sur le premier bilan d'étape présenté par le Gouvernement	\N	2023-11-30 09:00:00	2023-11-30 10:45:00	\N	\N	20	0	\N	\N
772443	COM_PERMANENTE	AUDRAP	\N	CDD	\N	DGEC	DGEC	2023-11-21 18:15:00	2023-11-21 19:00:00	\N	\N	1	0	\N	\N
772446	COM_PERMANENTE	AUDRAP	\N	CDD	\N	DGPR	DGPR	2023-11-21 16:00:00	2023-11-21 16:45:00	\N	\N	1	0	\N	\N
772449	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Ademe	Ademe	2023-11-22 14:00:00	2023-11-22 14:30:00	\N	\N	1	0	\N	\N
772465	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur	\N	2023-11-23 14:30:00	2023-11-23 15:00:00	\N	\N	1	0	\N	\N
772467	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur	\N	2023-11-23 15:00:00	2023-11-23 15:30:00	\N	\N	1	0	\N	\N
772471	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Cohésion territoires - Audition M. RIEUSSEC, Union nationale aménageurs	PLF pour 2024 - Cohésion territoires - Audition M. RIEUSSEC, Union nationale aménageurs	2023-11-15 18:00:00	2023-11-15 20:00:00	\N	\N	1	0	\N	\N
777919	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-12-06 11:00:00	2023-12-06 12:35:00	2023-12-06 13:11:53	2023-12-06 18:26:18	36	2	\N	\N
778165	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Réforme du Pacte de stabilité et de croissance	Audition Réforme du Pacte de stabilité et de croissance	2023-12-05 09:30:00	2023-12-05 10:45:00	\N	\N	2	0	\N	\N
778688	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	GT subsidiarité du 14 décembre 2023	\N	2023-12-14 08:30:00	2023-12-14 08:50:00	\N	\N	3	0	\N	\N
778693	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Réforme du Pacte de stabilité et de croissance	Audition Réforme du Pacte de stabilité et de croissance	2023-12-06 12:30:00	2023-12-06 13:15:00	\N	\N	2	0	\N	\N
778819	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE 96 - PLF pour 2024 - Examen amdts de séances missions, désignation candidats CMP 	PLENIERE 96 - PLF pour 2024 - Examen amdts de séances missions, désignation candidats CMP  PLF pour 2024	2023-12-07 09:33:00	2023-12-07 10:01:00	2023-12-15 17:26:26	2023-12-20 17:58:50	21	6	\N	\N
789506	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Contentieux du stationnement payant	PPL relative au contentieux du stationnement payant	2024-01-22 16:30:00	2024-01-22 17:30:00	\N	\N	1	0	\N	\N
805481	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Négociations salariales - Audition M. Fabre	\N	2024-03-05 14:30:00	2024-03-05 15:30:00	\N	\N	0	0	\N	\N
805482	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Cancers professionnels des sapeurs-pompiers - Sociologues	\N	2024-03-05 15:30:00	2024-03-05 16:30:00	\N	\N	4	0	\N	\N
805483	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition UIMM - FNTR - AFB	\N	2024-03-05 15:30:00	2024-03-05 16:30:00	\N	\N	0	0	\N	\N
805484	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Medef	\N	2024-03-05 16:45:00	2024-03-05 17:30:00	\N	\N	2	0	\N	\N
805584	COM_PERMANENTE	AUDRAP	\N	CAE	\N	TR élus	\N	2024-02-07 13:30:00	2024-02-07 15:00:00	\N	\N	5	0	\N	\N
805630	COM_PERMANENTE	AUDRAP	\N	CAE	\N	TR Syndics	\N	2024-02-07 17:00:00	2024-02-07 18:30:00	\N	\N	4	0	\N	\N
805635	COM_PERMANENTE	AUDRAP	\N	CAE	\N	CNAJMJ	\N	2024-02-07 18:30:00	2024-02-07 19:00:00	\N	\N	3	0	\N	\N
805780	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Déplacement à Viginum 	\N	2024-03-05 14:30:00	2024-03-05 18:00:00	\N	\N	0	0	\N	\N
813251	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP Habitat dégradé	CMP Habitat dégradé	2024-03-27 17:40:00	2024-03-27 18:35:00	\N	\N	54	0	\N	\N
813252	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PPL Grand âge et autonomie	CMP PPL Grand âge et autonomie	2024-03-27 18:40:00	2024-03-27 19:45:00	\N	\N	49	0	\N	\N
813253	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Homicide routier	PPL Homicide routier	2024-03-27 21:15:00	2024-03-27 23:55:00	\N	\N	48	0	\N	\N
813257	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Aide publique au développement	PPL Aide publique au développement	2024-03-26 21:45:00	2024-03-26 23:45:00	\N	\N	56	0	\N	\N
813259	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Saisie et avoirs criminels	PPL Saisie et avoirs criminels	2024-03-26 23:45:00	2024-03-27 00:55:00	\N	\N	30	0	\N	\N
786206	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Bien-vieillir 	PPL Bien-vieillir	2023-12-15 09:30:00	2023-12-15 12:15:00	\N	\N	1	0	\N	\N
786208	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Bien-vieillir 	PPL Bien-vieillir	2023-12-19 17:45:00	2023-12-19 19:30:00	\N	\N	1	0	\N	\N
788771	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Déplacement à Vénissieux et Saint-Fons	Déplacement à Vénissieux et Saint-Fons	2023-12-07 08:00:00	2023-12-07 22:00:00	\N	\N	5	0	\N	\N
788797	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Réunion constitutive	\N	2024-01-18 11:00:00	2024-01-18 12:00:00	\N	\N	0	0	\N	\N
789218	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Emeutes	MI Emeutes	2024-01-17 16:30:00	2024-01-17 19:00:00	\N	\N	3	0	\N	\N
789225	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Vapotage - Audition Confédération des buralistes	\N	2024-01-17 18:00:00	2024-01-17 19:20:00	\N	\N	1	0	\N	\N
789226	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Vapotage - Audition HCSP-HAS-Anses-OFDT	\N	2024-01-18 08:30:00	2024-01-18 10:00:00	\N	\N	1	0	\N	\N
789227	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Vapotage - Audition DGS-DGCCRF-DAJMS	\N	2024-01-18 10:00:00	2024-01-18 11:30:00	\N	\N	1	0	\N	\N
772428	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Budget 2024 - Avis	Budget 2024 - Avis	2023-11-29 09:05:00	2023-11-29 11:00:00	2023-11-29 13:08:21	2023-11-29 14:30:24	39	5	\N	\N
777918	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-12-06 09:00:00	2023-12-06 10:50:00	2023-12-06 13:11:02	2023-12-06 18:26:17	45	0	\N	\N
781405	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion CATDD	\N	2023-12-13 09:30:00	2023-12-13 09:45:00	2023-12-13 16:43:32	2023-12-14 17:47:45	40	6	\N	\N
789271	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Laurent Cordonier, directeur de la recherche, Fondation Descartes	\N	2024-01-18 14:05:00	2024-01-18 15:15:00	\N	\N	2	0	\N	\N
789277	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Condamnés terroristes et lutte antiterroriste (amendements)	PPL Condamnés terroristes et lutte antiterroriste (amendements)	2024-01-23 13:35:00	2024-01-23 14:10:00	2024-01-23 15:06:28	2024-01-23 17:30:26	16	2	\N	\N
789280	COM_PERMANENTE	AUTRE	\N	LOIS	\N	MI Emeutes de juin 2023 - Audition de la direction nationale du renseignement territorial	MI Emeutes de juin 2023 - Audition de la direction nationale du renseignement territorial	2024-01-24 10:30:00	2024-01-24 11:35:00	2024-01-24 14:41:53	2024-01-25 18:33:21	39	5	\N	\N
789369	COM_ENQUETE	PLENIERE	\N	NARCO	\N	Europol - Eurojust - Table ronde "Politique étrangère"	Europol - Eurojust - Table ronde "Politique étrangère"	2024-01-22 14:30:00	2024-01-22 18:35:00	2024-01-22 18:54:04	2024-01-23 17:30:32	6	0	\N	\N
789881	COM_EURO	AUDRAP	\N	AFEU	\N	Audition euro numérique	\N	2024-01-23 15:00:00	2024-01-23 16:00:00	\N	\N	2	0	\N	\N
790118	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion CATDD	\N	2024-01-24 10:45:00	2024-01-24 12:20:00	2024-01-24 14:41:26	2024-01-25 18:33:20	35	3	\N	\N
790405	ETUDES	AUTRE	\N	\N	\N	GE Cancer - Réunion constitutive	\N	2024-01-24 14:00:00	2024-01-24 14:30:00	\N	\N	16	0	\N	1004
798770	ETUDES	AUCUNE	\N	\N	\N	Réunion constitutive	Réunion constitutive	2024-02-06 13:45:00	2024-02-06 14:30:00	\N	\N	26	0	\N	907
798815	ETUDES	AUCUNE	\N	\N	\N	Réunion constitutive	Réunion constitutive	2024-02-07 14:00:00	2024-02-07 15:00:00	\N	\N	23	0	\N	909
799049	GIA	AUCUNE	\N	\N	\N	Reconstitution du GIA et rencontre avec l'ambassadeur	\N	2024-02-13 17:30:00	2024-02-13 19:00:00	\N	\N	11	0	619	\N
801025	DELEGATION	AUDRAP	\N	\N	PROS	IA et santé - Audition de M. Romain Bey	\N	2024-02-14 11:00:00	2024-02-14 12:00:00	\N	\N	2	0	\N	\N
801116	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Négociations salariales - Audition France stratégie	\N	2024-02-14 16:30:00	2024-02-14 17:15:00	\N	\N	3	0	\N	\N
801117	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Négociations salariales - Audition OIT	\N	2024-02-14 17:15:00	2024-02-14 18:00:00	\N	\N	4	0	\N	\N
801120	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Discrimination par la pratique de tests individuels et statistiques	PPL Discrimination par la pratique de tests individuels et statistiques	2024-02-15 09:30:00	2024-02-15 10:30:00	\N	\N	1	0	\N	\N
801127	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Discrimination par la pratique de tests individuels et statistiques	\N	2024-02-15 11:30:00	2024-02-15 12:30:00	\N	\N	4	0	\N	\N
801408	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2024-02-13 16:45:00	2024-02-13 18:30:00	\N	\N	3	0	\N	\N
804314	COM_PERMANENTE	AUTRE	\N	FINC	\N	MCC Inondations 2023/2024 - Audition M. THOME, Météo-France	MCC Inondations 2023/2024 - Audition M. THOME, Météo-France	2024-03-06 12:00:00	2024-03-06 13:00:00	\N	\N	3	0	\N	\N
804318	COM_PERMANENTE	AUTRE	\N	FINC	\N	MCC Inondations 2023/2024 - Audition Mme PUJO, SCHAPI	MCC Inondations 2023/2024 - Audition Mme PUJO, SCHAPI	2024-02-14 18:30:00	2024-02-14 19:30:00	2024-03-04 17:39:26	\N	3	0	\N	\N
804322	COM_PERMANENTE	AUTRE	\N	FINC	\N	MCC Inondations 2023/2024 - Audition M. THOME, Météo-France	MCC Inondations 2023/2024 - Audition M. THOME, Météo-France	2024-02-06 12:00:00	2024-02-06 13:00:00	2024-03-04 17:38:35	\N	3	0	\N	\N
804326	COM_PERMANENTE	AUTRE	\N	FINC	\N	MCC Inondations 2023/2024 - Audition du CEREMA	MCC Inondations 2023/2024 - Audition du CEREMA	2024-02-27 14:00:00	2024-02-27 15:00:00	2024-03-04 17:39:59	\N	2	0	\N	\N
804329	COM_PERMANENTE	AUTRE	\N	FINC	\N	MCC Inondations 2023/2024 - Audition de France Assureurs	MCC Inondations 2023/2024 - Audition de France Assureurs	2024-02-27 15:00:00	2024-02-27 16:00:00	2024-03-04 17:40:13	\N	3	0	\N	\N
804333	COM_PERMANENTE	AUTRE	\N	FINC	\N	MCC Inondations 2023/2024 - Audition Voies navigables de France (VNF)	MCC Inondations 2023/2024 - Audition Voies navigables de France (VNF)	2024-02-27 16:00:00	2024-02-27 17:00:00	2024-03-04 17:40:26	\N	1	0	\N	\N
804335	COM_PERMANENTE	AUTRE	\N	FINC	\N	MCC Inondations 2023/2024 - Audition de l'INRAE	MCC Inondations 2023/2024 - Audition de l'INRAE	2024-02-27 18:00:00	2024-02-27 19:00:00	2024-03-04 17:40:41	\N	1	0	\N	\N
806673	BUREAU	AUCUNE	\N	\N	\N	Délégation en charge du travail parlementaire	Délégation en charge du travail parlementaire	2024-03-06 11:00:00	2024-03-06 12:00:00	\N	\N	2	0	\N	\N
806676	BUREAU	AUCUNE	\N	\N	\N	Délégation en charge du travail parlementaire	Délégation en charge du travail parlementaire	2024-03-06 13:30:00	2024-03-06 14:00:00	\N	\N	3	0	\N	\N
806679	BUREAU	AUCUNE	\N	\N	\N	Délégation en charge du travail parlementaire	Délégation en charge du travail parlementaire	2024-03-06 14:00:00	2024-03-06 14:30:00	\N	\N	2	0	\N	\N
807171	QUESTURE	AUCUNE	\N	\N	\N	Réunion de Questure	Réunion du Conseil de Questure	2024-03-01 09:15:00	2024-03-01 11:00:00	\N	\N	0	0	\N	\N
815875	MECSS	AUDRAP	\N	\N	MECSS	MI Fiscalité comportementale - Audition chercheurs	\N	2024-03-28 09:00:00	2024-03-28 10:00:00	\N	\N	3	0	\N	\N
815876	MECSS	AUDRAP	\N	\N	MECSS	MI Fiscalité comportementale - Audition Mildeca	\N	2024-03-28 10:00:00	2024-03-28 10:45:00	\N	\N	3	0	\N	\N
815877	MECSS	AUDRAP	\N	\N	MECSS	MI Fiscalité comportementale - Audition Ligue contre le cancer	\N	2024-03-28 11:00:00	2024-03-28 12:10:00	\N	\N	2	0	\N	\N
803965	GIA	AUCUNE	\N	\N	\N	Assemblée générale et audition de l'ambassadeur de France au Liban	Assemblée générale du groupe d'amitié et audition de l'ambassadeur de France au Liban	2023-12-05 14:30:00	2023-12-05 16:00:00	\N	\N	18	0	597	\N
819150	GIA	AUCUNE	\N	\N	\N	Entretien avec Mme Caroline Bilkey	Entretien avec Mme Caroline Bilkey, ambassadrice de Nouvelle-Zélande	2024-03-19 09:30:00	2024-03-19 10:30:00	\N	\N	1	0	663	\N
819153	GIA	AUCUNE	\N	\N	\N	Entretien avec Mme l'ambassadrice Laurence Beau	Entretien avec Mme Laurence Beau, ambassadrice de France en Nouvelle-Zélande	2024-04-09 09:30:00	2024-04-09 10:40:00	\N	\N	6	0	663	\N
821300	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Académie nationale de médecine	\N	2024-04-10 17:30:00	2024-04-10 18:30:00	\N	\N	1	0	\N	\N
821331	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI Foot (rapporteur)	\N	2024-04-10 16:30:00	2024-04-10 18:00:00	\N	\N	4	0	\N	\N
789278	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Avis sur recevabilité commissions d'enquête - PPL Actions de groupe (rapport)	Avis sur recevabilité commissions d'enquête - PPL Actions de groupe (rapport)	2024-01-24 09:00:00	2024-01-24 10:00:00	2024-02-13 15:38:45	2024-02-13 15:38:51	39	5	\N	\N
789892	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE 3 - PPL579 EDF examen texte commission n°248	PLENIERE 3 - PPL579 EDF examen texte commission n°248	2024-01-24 09:30:00	2024-01-24 09:45:00	2024-01-25 08:28:38	2024-01-25 18:33:24	42	3	\N	\N
773413	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2023-11-15 18:00:00	2023-11-15 18:45:00	\N	\N	28	0	\N	\N
787242	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Auditions IFRI et Présidente parlement chypriote -  RI Pologne Ukraine	Auditions IFRI et Présidente parlement chypriote -  RI Pologne Ukraine	2024-01-17 09:30:00	2024-01-17 12:35:00	2024-01-17 17:17:10	2024-01-17 18:05:03	33	4	\N	\N
787249	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition Thierry Breton	Audition Thierry Breton	2024-01-18 09:15:00	2024-01-18 10:45:00	2024-01-22 15:44:40	2024-01-22 17:46:26	8	0	\N	\N
794943	GIA	AUCUNE	\N	\N	\N	Entretien avec l'Ambassadeur de France en Australie	Entretien avec l'Ambassadeur de France en Australie	2024-02-05 08:30:00	2024-02-05 09:30:00	\N	\N	1	0	578	\N
772502	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024	PLF 2024	2023-11-26 14:00:00	2023-11-26 20:30:00	\N	\N	64	0	\N	\N
787021	GIA	AUCUNE	\N	\N	\N	AG 2024 GIA France-Madagascar et pays de l'Océan indien	\N	2024-01-16 16:00:00	2024-01-16 16:20:00	\N	\N	14	0	622	\N
788069	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Contentieux du stationnement payant	PPL Contentieux du stationnement payant	2024-01-15 15:30:00	2024-01-15 17:30:00	\N	\N	1	0	\N	\N
788098	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Vapotage - Audition Ademe	\N	2024-01-17 14:00:00	2024-01-17 14:45:00	\N	\N	3	0	\N	\N
788456	DELEGATION	AUCUNE	\N	\N	211	Audition du HCFEA	\N	2024-01-25 08:30:00	2024-01-25 09:30:00	\N	\N	11	0	\N	\N
788556	GIA	AUCUNE	\N	\N	\N	Assemblée générale 	Assemblée générale du groupe d'amitié 	2024-01-17 16:35:00	2024-01-17 16:55:00	\N	\N	7	0	588	\N
791711	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe	Assemblée générale du groupe	2023-12-20 15:00:00	2023-12-20 15:30:00	\N	\N	7	0	592	\N
791762	GIA	AUCUNE	\N	\N	\N	Audition de SE M L'ambassadeur de Suisse en France	Audition de SE M L'ambassadeur de Suisse en France	2024-01-24 08:30:00	2024-01-24 09:30:00	\N	\N	11	0	610	\N
796132	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE 6 - Table-ronde sur les problèmes assurantiels des CT	PLENIERE 6 - Table-ronde sur les problèmes assurantiels des CT	2024-02-07 10:00:00	2024-02-07 12:00:00	2024-02-08 15:59:28	2024-02-09 17:33:12	30	0	\N	\N
796165	COM_EURO	AUDRAP	\N	AFEU	\N	Audition révision cadre financier pluriannuel	\N	2024-01-24 11:30:00	2024-01-24 13:00:00	\N	\N	2	0	\N	\N
796541	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Examen du rapport relatif à la mission flash sur la directive CSRD	\N	2024-02-07 12:30:00	2024-02-07 14:00:00	\N	\N	16	0	\N	\N
796542	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Réunion constitutive	\N	2024-02-06 16:00:00	2024-02-06 17:15:00	\N	\N	0	0	\N	\N
779263	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Mission Outre-mer	Mission Outre-mer	2023-12-09 00:50:00	2023-12-09 01:40:00	\N	\N	27	0	\N	\N
779359	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	AFCL	\N	\N	\N	2023-12-07 11:00:00	2023-12-07 12:15:00	\N	\N	3	0	\N	\N
786142	COM_EURO	AUDRAP	\N	AFEU	\N	Auditions - Nouvelles techniques génomiques	Auditions - Nouvelles techniques génomiques	2023-12-20 18:00:00	2023-12-20 19:00:00	\N	\N	2	0	\N	\N
786145	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI « JOP »	Audition rapporteur - MI « JOP »	2023-12-21 08:30:00	2023-12-21 13:30:00	\N	\N	2	0	\N	\N
786148	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI « JOP »	Audition rapporteur - MI « JOP »	2023-12-21 14:15:00	2023-12-21 16:30:00	\N	\N	2	0	\N	\N
786158	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL ESH temps méridien	\N	2023-12-21 11:00:00	2023-12-21 11:50:00	\N	\N	4	0	\N	\N
786163	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL ESH	\N	2023-12-21 16:00:00	2023-12-21 16:50:00	\N	\N	4	0	\N	\N
786168	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL ESH	\N	2023-12-21 17:00:00	2023-12-21 17:50:00	\N	\N	3	0	\N	\N
807195	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Homicide routier	PPL Homicide routier	2024-03-07 14:30:00	2024-03-07 15:15:00	\N	\N	2	0	\N	\N
807198	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Homicide routier	PPL Homicide routier	2024-03-07 15:15:00	2024-03-07 16:30:00	\N	\N	1	0	\N	\N
807200	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Homicide routier	PPL Homicide routier	2024-03-07 17:00:00	2024-03-07 18:00:00	\N	\N	1	0	\N	\N
807202	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Homicide routier	PPL Homicide routier	2024-03-07 18:15:00	2024-03-07 19:15:00	\N	\N	1	0	\N	\N
810862	GIA	AUCUNE	\N	\N	\N	Entretien avec Mme Raja RABIA, Ambassadrice de France au Soudan	Entretien avec Mme Raja RABIA, Ambassadrice de France au Soudan	2024-03-19 14:30:00	2024-03-19 15:30:00	\N	\N	3	0	588	\N
815852	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Atos	MI Atos	2024-03-27 16:30:00	2024-03-27 20:30:00	\N	\N	1	0	\N	\N
819000	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Dématérialisation de l'état civil	Audition rapporteur - Dématérialisation de l'état civil	2024-04-05 11:00:00	2024-04-05 11:20:00	\N	\N	1	0	\N	\N
819002	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Ordonnance de protection	Audition rapporteur - PPL Ordonnance de protection	2024-04-05 09:00:00	2024-04-05 09:50:00	\N	\N	3	0	\N	\N
819006	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Ordonnance de protection	Audition rapporteur - PPL Ordonnance de protection	2024-04-05 11:30:00	2024-04-05 12:10:00	\N	\N	1	0	\N	\N
774129	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Lutte contre les dérives sectaires	Audition rapporteur - PJL Lutte contre les dérives sectaires	2023-11-28 15:15:00	2023-11-28 17:30:00	\N	\N	3	0	\N	\N
774133	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Lutte contre les dérives sectaires	Audition rapporteur - PJL Lutte contre les dérives sectaires	2023-11-28 17:30:00	2023-11-28 18:50:00	\N	\N	1	0	\N	\N
781299	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe d'amitié France-Caraïbes	Assemblée générale du groupe d'amitié France-Caraïbes	2023-12-05 16:00:00	2023-12-05 17:00:00	\N	\N	13	0	642	\N
782589	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	AFCL	\N	Réunion du Bureau	\N	2023-12-13 11:15:00	2023-12-13 12:30:00	\N	\N	14	0	\N	\N
783037	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	AFCL	\N	FNCF : MM. Patry et Sebbag	\N	2023-12-14 09:30:00	2023-12-14 10:30:00	\N	\N	1	0	\N	\N
789380	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI « JOP »	Audition rapporteur - MI « JOP »	2024-01-16 14:00:00	2024-01-16 16:00:00	\N	\N	2	0	\N	\N
789383	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI « JOP »	Audition rapporteur - MI « JOP »	2024-01-16 17:00:00	2024-01-16 19:00:00	\N	\N	2	0	\N	\N
789386	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI « JOP »	Audition rapporteur - MI « JOP »	2024-01-17 16:30:00	2024-01-17 19:30:00	\N	\N	2	0	\N	\N
792722	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2024-01-23 16:10:00	2024-01-23 17:36:00	\N	\N	3	0	\N	\N
793164	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Gapili MISSET, Attaché de presse de l'ambassade du Tchad à Paris	Entretien avec M. Gapili MISSET, Attaché de presse de l'ambassade du Tchad à Paris	2024-01-30 08:30:00	2024-01-30 09:40:00	\N	\N	2	0	572	\N
793174	GIA	AUCUNE	\N	\N	\N	Assemblée générale	Assemblée générale du groupe d'amitié	2024-01-30 17:45:00	2024-01-30 18:30:00	\N	\N	7	0	576	\N
793371	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI JOP 2024	\N	2024-01-30 18:00:00	2024-01-30 19:15:00	\N	\N	6	0	\N	\N
818005	MISSION	AUTRE	\N	PERI	\N	PLENIERE - 8 - TR Associations	\N	2024-04-03 16:30:00	2024-04-03 18:30:00	\N	\N	6	0	\N	\N
807208	CMP	AUTRE	\N	DERI	\N	CMP Dérives sectaires	CMP Dérives sectaires	2024-03-07 12:18:00	2024-03-07 12:33:00	\N	\N	9	0	\N	\N
793378	ETUDES	AUCUNE	\N	\N	\N	Réunion constitutive	\N	2024-01-31 08:15:00	2024-01-31 09:00:00	2024-01-31 09:40:08	\N	12	0	\N	966
793457	DELEGATION	AUDRAP	\N	\N	DSOM	Entretien de Mme Micheline JACQUES avec les référents outre-mer	\N	2024-01-31 08:30:00	2024-01-31 10:15:00	\N	\N	9	0	\N	\N
793691	DELEGATION	AUCUNE	\N	\N	PROS	Audition "La prospective : pourquoi et comment ?"	\N	2024-02-01 08:40:00	2024-02-01 10:00:00	\N	\N	6	0	\N	\N
793706	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur	\N	2024-01-30 18:30:00	2024-01-30 19:00:00	\N	\N	0	0	\N	\N
793996	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 7 février 2024	\N	2024-02-07 16:30:00	2024-02-07 18:05:00	2024-02-08 13:17:41	2024-02-09 17:33:13	19	0	\N	\N
793997	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 8 février 2024	\N	2024-02-08 09:30:00	2024-02-08 11:15:00	2024-02-08 13:17:10	2024-02-09 17:33:14	15	0	\N	\N
794000	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audition MI Lutte  anti-drone	\N	2023-12-14 10:00:00	2023-12-14 12:00:00	\N	\N	2	0	\N	\N
794007	DELEGATION	AUCUNE	\N	\N	211	Table ronde thématique "Femmes dans la rue"	\N	2024-03-14 08:40:00	2024-03-14 10:55:00	\N	\N	8	0	\N	\N
794010	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Auditions Mission lutte anti-drone	\N	2024-01-17 16:30:00	2024-01-17 18:30:00	\N	\N	3	0	\N	\N
794012	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Auditions Mission anti-drone	\N	2024-01-23 17:00:00	2024-01-23 19:00:00	\N	\N	2	0	\N	\N
794058	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Maitrise d'ouvrage	 Maîtrise d'ouvrage pour les communes rurales	2024-01-30 15:15:00	2024-01-30 18:45:00	\N	\N	1	0	\N	\N
794068	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Table ronde Ecosystème de l'électricité	\N	2024-01-31 17:30:00	2024-01-31 19:30:00	\N	\N	0	0	\N	\N
797813	GIA	AUCUNE	\N	\N	\N	Entretien avex l'Ambassadeur de Tanzanie en France	\N	2024-02-06 13:00:00	2024-02-06 14:30:00	\N	\N	1	0	622	\N
797819	GIA	AUCUNE	\N	\N	\N	AG du GIA France-Indonésie et Timor-Est	\N	2024-01-23 12:30:00	2024-01-23 13:30:00	\N	\N	6	0	653	\N
813314	GIA	AUCUNE	\N	\N	\N	Rencontre avec l'ambassadrice de Mongolie en France	Rencontre avec l'ambassadrice de Mongolie en France	2024-03-20 08:15:00	2024-03-20 09:30:00	\N	\N	9	0	612	\N
819041	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition MM. Mustier et Saleh	Audition MM. Jean-Pierre Mustier et Paul Saleh	2024-04-10 16:35:00	2024-04-10 18:25:00	2024-04-11 11:27:17	2024-04-12 13:33:41	39	0	\N	\N
820233	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Statut de la Corse	Statut de la Corse	2024-04-08 15:00:00	2024-04-08 17:15:00	\N	\N	1	0	\N	\N
820587	COM_ENQUETE	PLENIERE	\N	ELEC	\N	Audition du PDG d'EDF	\N	2024-04-10 16:30:00	2024-04-10 18:35:00	2024-04-10 18:54:04	2024-04-12 13:35:33	10	0	\N	\N
773155	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE 88 - PLF pour 2024 - Suite examen amdts séance 1ère partie	PLENIERE 88 - PLF pour 2024 - Suite examen amdts séance 1ère partie	2023-11-27 09:30:00	2023-11-27 09:52:00	2023-12-06 14:42:37	2023-12-06 18:22:51	17	5	\N	\N
773230	COM_EURO	AUDRAP	\N	AFEU	\N	Audition paquet pharmaceutique	\N	2023-11-22 14:00:00	2023-11-22 14:55:00	\N	\N	3	0	\N	\N
773236	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - RG - Audition Mobilians	PLF pour 2024 - RG - Audition Mobilians	2023-11-21 19:00:00	2023-11-21 19:45:00	\N	\N	1	0	\N	\N
773241	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - RG - Audition Mme WAYSAN, ENGIE	PLF pour 2024 - RG - Audition Mme WAYSAN, ENGIE	2023-11-22 16:15:00	2023-11-22 16:45:00	\N	\N	1	0	\N	\N
773248	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition PPL titres Restaurant - UMIH	\N	2023-11-27 11:00:00	2023-11-27 12:00:00	\N	\N	2	0	\N	\N
773249	COM_EURO	DEPLACEMENT	\N	AFEU	\N	Déplacement à Bruxelles - Cybersolidarité	Déplacement à Bruxelles - Cybersolidarité	2023-11-28 08:00:00	2023-11-28 19:00:00	\N	\N	2	0	\N	\N
773252	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - RG - Audition Chambres d'agriculture de France	PLF pour 2024 - RG - Audition M. WINDSOR, assemblée permanente des chambres d'agriculture	2023-11-22 12:30:00	2023-11-22 13:00:00	\N	\N	1	0	\N	\N
773257	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Allocation universelle d'études - Audition M. de Marco	\N	2023-11-24 09:00:00	2023-11-24 10:00:00	\N	\N	1	0	\N	\N
773258	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Allocation universelle d'études - Syndicats étudiants	\N	2023-11-24 10:00:00	2023-11-24 11:00:00	\N	\N	1	0	\N	\N
773264	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition FCD	\N	2023-11-27 15:30:00	2023-11-27 16:30:00	\N	\N	2	0	\N	\N
773447	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Allocation universelle d'études	\N	2023-11-27 16:00:00	2023-11-27 17:00:00	\N	\N	1	0	\N	\N
773456	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Allocation universelle d'études	\N	2023-11-27 15:15:00	2023-11-27 16:00:00	\N	\N	1	0	\N	\N
780473	SEANCE_PLENIERE	SCRUSOL	2001	\N	\N	Scrutin public à la tribune PLF 2024	Scrutin public à la tribune de droit PLF 2024	2023-12-12 15:30:00	2023-12-12 17:00:00	\N	\N	0	0	\N	\N
780474	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	2001	\N	\N	Explications de vote PLF 2024	Explications de vote PLF 2024	2023-12-12 14:30:00	2023-12-12 16:45:00	\N	\N	314	0	\N	\N
794635	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe	Assemblée générale du groupe	2024-01-24 17:00:00	2024-01-24 17:30:00	\N	\N	13	0	673	\N
797861	DELEGATION	AUDRAP	\N	\N	206	Place des protéines dans l'alimentation - Audition du Dr Kesse-Guyot	\N	2024-02-08 14:30:00	2024-02-08 15:30:00	\N	\N	1	0	\N	\N
797862	DELEGATION	AUDRAP	\N	\N	206	Place des protéines dans l'alimentation - Audition de l'AVF	\N	2024-02-08 15:30:00	2024-02-08 16:30:00	\N	\N	1	0	\N	\N
797865	ETUDES	AUTRE	\N	\N	\N	Réunion constitutive	Réunion constitutive	2024-01-24 14:00:00	2024-01-24 14:30:00	\N	\N	44	0	\N	919
797914	COM_PERMANENTE	AUTRE	\N	AFCL	\N	TR Associations	\N	2024-02-28 09:30:00	2024-02-28 10:50:00	2024-02-28 14:09:43	2024-02-28 16:37:18	28	0	\N	\N
797915	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Réunion constitutive	\N	2024-02-06 16:00:00	2024-02-06 16:30:00	\N	\N	0	0	\N	\N
797925	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Auditions MI Atos	\N	2024-02-08 09:00:00	2024-02-08 12:00:00	\N	\N	0	0	\N	\N
797929	COM_ENQUETE	PLENIERE	\N	TOTA	\N	Réunion CE-TE	\N	2024-02-12 16:30:00	2024-02-12 19:05:00	2024-02-12 19:06:46	2024-02-13 15:41:28	10	0	\N	\N
797930	DELEGATION	AUDRAP	\N	\N	206	Effets indésirables des vaccins covid-19 - Audition de M. Jérémy Ward, sociologue	\N	2024-02-12 13:30:00	2024-02-12 14:45:00	\N	\N	2	0	\N	\N
799021	MECSS	AUDRAP	\N	\N	MECSS	MI Fiscalité comportementale - Audition de l'Oqali-Inrae-Anses	\N	2024-02-15 09:00:00	2024-02-15 10:00:00	\N	\N	2	0	\N	\N
799024	MECSS	AUDRAP	\N	\N	MECSS	MI Fiscalité comportementale - Audition conjointe CNCT-Addictions France	\N	2024-02-16 17:00:00	2024-02-16 18:30:00	\N	\N	5	0	\N	\N
799027	MECSS	AUDRAP	\N	\N	MECSS	MI Fiscalité comportementale - Audition de l'UFC Que choisir	\N	2024-02-29 09:00:00	2024-02-29 10:00:00	\N	\N	3	0	\N	\N
799028	MECSS	AUDRAP	\N	\N	MECSS	MI Fiscalité comportementale - Audition de l'OCDE	\N	2024-02-29 14:15:00	2024-02-29 15:45:00	\N	\N	2	0	\N	\N
799029	MECSS	AUDRAP	\N	\N	MECSS	MI Fiscalité comportementale - Audition de la DGS	\N	2024-02-29 15:45:00	2024-02-29 17:15:00	\N	\N	2	0	\N	\N
773244	COM_PERMANENTE	AUTRE	\N	CAE	\N	Avis budgétaires	\N	2023-11-29 09:35:00	2023-11-29 11:50:00	2023-11-29 11:57:38	2023-11-29 14:30:23	43	5	\N	\N
801357	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Atos	MI Atos	2024-02-21 16:00:00	2024-02-21 17:00:00	\N	\N	2	0	\N	\N
776809	GIA	AUCUNE	\N	\N	\N	Entretien avec Mme Claire BODONYI, ambassadrice de France au Congo-Brazzavillee	Entretien avec Mme Claire BODONYI, ambassadrice de France au Congo-Brazzaville	2023-07-20 11:00:00	2023-07-20 12:00:00	\N	\N	2	0	572	\N
783372	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2023-12-19 09:30:00	2023-12-19 12:30:00	\N	\N	50	0	\N	\N
783373	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Conclusions CMP Immigration	Conclusions CMP Immigration	2023-12-19 19:05:00	2023-12-19 20:15:00	\N	\N	239	0	\N	\N
783374	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Conclusions CMP SERM	Conclusions CMP SERM	2023-12-18 16:00:00	2023-12-18 17:00:00	\N	\N	26	0	\N	\N
783375	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Conclusions CMP RATP	Conclusions CMP RATP	2023-12-18 17:00:00	2023-12-18 17:55:00	\N	\N	40	0	\N	\N
783376	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Conclusions CMP  Restes humains	Conclusions CMP Restes humains	2023-12-18 18:00:00	2023-12-18 18:50:00	\N	\N	40	0	\N	\N
783377	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Conclusions CMP Secrétaires de mairie	Conclusions CMP Secrétaires de mairie	2023-12-18 18:50:00	2023-12-18 19:50:00	\N	\N	36	0	\N	\N
783379	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Conclusions CMP Accès aux soins	Conclusions CMP Accès aux soins	2023-12-18 21:30:00	2023-12-18 22:25:00	\N	\N	31	0	\N	\N
783380	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Titres restaurants	PPL Titres restaurants	2023-12-18 22:25:00	2023-12-18 23:50:00	\N	\N	30	0	\N	\N
783381	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	NL PLF 2024	NL PLF 2024	2023-12-19 14:30:00	2023-12-19 15:50:00	\N	\N	137	0	\N	\N
783382	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	EV PPL Erasmus	EV PPL Erasmus	2023-12-19 15:55:00	2023-12-19 16:50:00	\N	\N	87	0	\N	\N
783383	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	NL PPL Droit image enfants	NL PPL Droit image enfants	2023-12-19 16:55:00	2023-12-19 17:55:00	\N	\N	80	0	\N	\N
783384	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL dérives sectaires	PJL dérives sectaires	2023-12-19 18:00:00	2023-12-19 19:05:00	\N	\N	134	0	\N	\N
783385	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL dérives sectaires	PJL dérives sectaires	2023-12-19 21:45:00	2023-12-19 23:20:00	\N	\N	44	0	\N	\N
783387	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2023-12-20 15:00:00	2023-12-20 16:15:00	\N	\N	249	0	\N	\N
783389	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Convention France-Luxembourg	Convention France-Luxembourg	2023-12-20 16:30:00	2023-12-20 17:30:00	\N	\N	44	0	\N	\N
783390	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL DDADUE	PJL DDADUE	2023-12-20 17:30:00	2023-12-20 19:45:00	\N	\N	35	0	\N	\N
789421	COM_PERMANENTE	AUTRE	\N	AFCL	\N	MCC agressions enseignants	\N	2024-01-31 16:30:00	2024-01-31 18:00:00	\N	\N	0	0	\N	\N
789422	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Euro numérique	\N	2024-01-16 15:00:00	2024-01-16 16:00:00	\N	\N	1	0	\N	\N
789424	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Contentieux du stationnement payant	PPL relative au contentieux du stationnement payant	2024-01-19 10:00:00	2024-01-19 11:30:00	\N	\N	1	0	\N	\N
789426	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MCC Enseignants	\N	2024-01-22 10:00:00	2024-01-22 11:30:00	\N	\N	5	0	\N	\N
789970	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe France-Etats-Unis	Assemblée générale du groupe France-Etats-Unis	2024-01-23 18:30:00	2024-01-23 19:00:00	\N	\N	13	0	590	\N
791448	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Préserver des sols vivants - Audition DGALN	PPL Préserver des sols vivants - Audition DGALN	2024-01-23 15:05:00	2024-01-23 16:05:00	\N	\N	2	0	\N	\N
791454	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Préserver des sols vivants - Audition Chambre agriculture	PPL Préserver des sols vivants - Audition Chambre agriculture	2024-01-23 16:05:00	2024-01-23 17:00:00	\N	\N	4	0	\N	\N
791459	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Préserver des sols vivants - Audition FNSEA 	PPL Préserver des sols vivants - Audition FNSEA 	2024-01-23 17:00:00	2024-01-23 17:50:00	\N	\N	4	0	\N	\N
791464	COM_PERMANENTE	AUDRAP	\N	CDD	\N	 PPL Préserver des sols vivants - TR Scientifiques	 PPL Préserver des sols vivants - TR Scientifiques	2024-01-23 17:50:00	2024-01-23 19:10:00	\N	\N	4	0	\N	\N
791469	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Préserver des sols vivants - Audition JA	PPL Préserver des sols vivants - Audition JA	2024-01-23 19:10:00	2024-01-23 20:00:00	\N	\N	2	0	\N	\N
791548	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Crise du logement	\N	2024-01-23 14:45:00	2024-01-23 17:15:00	\N	\N	3	0	\N	\N
791552	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Crise du logement	\N	2024-01-24 16:30:00	2024-01-24 17:30:00	\N	\N	3	0	\N	\N
791561	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur PJL Sûreté dans les transports	Audition rapporteur PJL Sûreté dans les transports	2024-01-24 14:00:00	2024-01-24 18:15:00	\N	\N	3	0	\N	\N
791565	DELEGATION	AUCUNE	\N	\N	206	Audition publique (PNGMDR)	\N	2024-01-25 09:00:00	2024-01-25 12:10:00	\N	\N	11	0	\N	\N
791612	COM_ENQUETE	PLENIERE	\N	NARCO	\N	Audition Alain Bauer - Table ronde des bailleurs sociaux	Audition Alain Bauer - Table ronde des bailleurs sociaux	2024-01-29 14:30:00	2024-01-29 17:20:00	2024-01-29 17:20:40	2024-01-30 17:57:17	5	0	\N	\N
791613	COM_ENQUETE	PLENIERE	\N	NARCO	\N	Audition DAP et SNRP	Audition DAP et SNRP	2024-01-30 09:05:00	2024-01-30 10:30:00	2024-01-30 15:46:48	2024-01-30 17:57:17	5	0	\N	\N
791617	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PPL Société du bien-vieillir en France - Examen des amdts de séance	\N	2024-01-30 14:00:00	2024-01-30 14:55:00	2024-01-30 16:10:58	2024-01-30 17:56:40	30	0	\N	\N
791618	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PPL Société du bien-vieillir en France - Suite examen des amdts de séance	\N	2024-01-30 20:05:00	2024-01-30 20:25:00	2024-01-30 20:52:23	2024-01-31 18:48:08	21	0	\N	\N
791619	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de V. Hamayon, présidente de la 6e chambre de la Cour des comptes	\N	2024-01-31 09:30:00	2024-01-31 11:05:00	2024-01-31 16:18:55	2024-01-31 18:48:10	42	0	\N	\N
810358	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 20 mars 2024	\N	2024-03-20 14:00:00	2024-03-20 15:00:00	2024-03-20 16:33:53	2024-03-20 17:23:43	16	0	\N	\N
791620	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière - Examen amdts séance PPL Vapotage + Suite examen amdts PPL Bien-vieillir	\N	2024-01-31 11:05:00	2024-01-31 11:55:00	2024-01-31 16:19:59	2024-01-31 18:48:17	42	0	\N	\N
791621	COM_PERMANENTE	AUDRAP	\N	CDD	\N	 PPL Sûreté dans les transports - Auditions M. Philippe Tabarot	 PPL Sûreté dans les transports - Auditions M. Philippe Tabarot	2024-01-24 14:00:00	2024-01-24 15:00:00	\N	\N	3	0	\N	\N
791625	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Sûreté dans les transports - Audition RATP 	PPL Sûreté dans les transports - Audition RATP 	2024-01-24 16:00:00	2024-01-24 17:00:00	\N	\N	8	0	\N	\N
791638	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Sûreté dans les transports - Audition SNCF 	PPL Sûreté dans les transports - Audition SNCF 	2024-01-24 17:00:00	2024-01-24 18:15:00	\N	\N	8	0	\N	\N
791654	COM_ENQUETE	DEPLACEMENT	\N	NARCO	\N	Déplacement dans la Meuse	\N	2024-02-01 08:00:00	2024-02-01 22:00:00	\N	\N	3	0	\N	\N
791834	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLC IVG	PROJET DE LOI CONSTITUTIONNELLE RELATIF À LA LIBERTÉ DE RECOURIR À L¿INTERRUPTION VOLONTAIRE DE GROSSESSE	2024-01-30 09:00:00	2024-01-30 10:00:00	\N	\N	3	0	\N	\N
803885	GIA	AUCUNE	\N	\N	\N	Entretien avec le Forum pour l'avenir franco-allemand	\N	2024-02-28 13:45:00	2024-02-28 14:45:00	\N	\N	8	0	604	\N
807391	GIA	AUCUNE	\N	\N	\N	Entretien Ambassadrice Andorre	\N	2024-03-05 09:00:00	2024-03-05 10:00:00	\N	\N	3	0	963	\N
820986	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI financiarisation de la santé - Syndicats de biologistes	\N	2024-04-10 14:00:00	2024-04-10 15:00:00	\N	\N	4	0	\N	\N
821110	ETUDES	AUDRAP	\N	\N	\N	ASTP	\N	2024-04-10 16:30:00	2024-04-10 17:30:00	\N	\N	1	0	\N	966
821112	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI LCAP	\N	2024-04-10 14:00:00	2024-04-10 15:00:00	\N	\N	4	0	\N	\N
783355	GIA	AUCUNE	\N	\N	\N	Réception offerte pour le centenaire de la Chambre de commerce franco-finlandaise 	Réception offerte pour le centenaire de la Chambre de commerce franco-finlandaise à l'ambassade de Finlande	2023-12-13 18:20:00	2023-12-13 19:45:00	\N	\N	3	0	640	\N
783359	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Pierre Ngolo, Président du Sénat de la République du Congo	Entretien avec M. Pierre Ngolo, Président du Sénat de la République du Congo	2023-12-13 15:40:00	2023-12-13 16:40:00	\N	\N	3	0	572	\N
786138	COM_EURO	AUDRAP	\N	AFEU	\N	Auditions - Nouvelles techniques génomiques	Auditions - Nouvelles techniques génomiques	2023-12-20 17:00:00	2023-12-20 18:00:00	\N	\N	3	0	\N	\N
786151	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL ESH temps méridien	\N	2023-12-21 10:00:00	2023-12-21 10:50:00	\N	\N	5	0	\N	\N
786152	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	ESH : FNASEPH	\N	2023-12-21 16:00:00	2023-12-21 18:00:00	\N	\N	0	0	\N	\N
786172	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition rapporteur	\N	2023-12-19 15:00:00	2023-12-19 17:45:00	\N	\N	3	0	\N	\N
786176	DELEGATION	AUTRE	\N	\N	DSOM	Action de l'Etat : audition de M. Olivier Jacob, directeur général des outre-mer (DGOM)	\N	2024-01-18 11:00:00	2024-01-18 12:30:00	\N	\N	18	0	\N	\N
786177	DELEGATION	AUCUNE	\N	\N	DSOM	Coopération et intégration régionales : audition de M. Olivier Jacob, DGOM	\N	2024-01-18 10:00:00	2024-01-18 11:00:00	\N	\N	18	0	\N	\N
786210	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Bien-vieillir 	PPL Bien-vieillir	2023-12-20 14:00:00	2023-12-20 14:45:00	\N	\N	1	0	\N	\N
786617	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat sur la réforme du marché de l'électricité	Débat sur la réforme du marché de l'électricité	2024-01-16 17:40:00	2024-01-16 19:05:00	\N	\N	0	0	\N	\N
786618	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat quelles politiques de solidarité pour répondre au choc de la transition écologique	Débat quelles politiques de solidarité pour répondre au choc de la transition écologique	2024-01-16 21:30:00	2024-01-16 22:55:00	\N	\N	37	0	\N	\N
786619	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2024-01-17 15:00:00	2024-01-17 16:25:00	\N	\N	292	0	\N	\N
786620	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR Intégrité territoriale de la République d'Arménie	PPR Intégrité territoriale de la République d'Arménie	2024-01-17 16:30:00	2024-01-17 18:00:00	\N	\N	66	0	\N	\N
786621	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR Ériger la santé mentale des jeunes en grande cause nationale	PPR Ériger la santé mentale des jeunes en grande cause nationale	2024-01-17 18:00:00	2024-01-17 19:15:00	\N	\N	30	0	\N	\N
786622	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat portant sur les violences associées au football	Débat Débat portant sur les violences associées au football	2024-01-17 21:30:00	2024-01-17 22:30:00	\N	\N	24	0	\N	\N
786623	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2024-01-18 10:30:00	2024-01-18 12:25:00	\N	\N	34	0	\N	\N
786624	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat lutte contre l'artificialisation des sols et accompagnement des élus locaux	Débat lutte contre l'artificialisation des sols et accompagnement des élus locaux	2024-01-18 14:30:00	2024-01-18 16:00:00	\N	\N	36	0	\N	\N
799689	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI Atos	MI Atos	2024-02-08 09:00:00	2024-02-08 12:00:00	\N	\N	1	0	\N	\N
804003	GIA	AUCUNE	\N	\N	\N	Entretien avec Anna Vdovychenko - PR Army	Entretien avec Anna Vdovychenko - PR Army	2024-02-27 17:00:00	2024-02-27 18:00:00	\N	\N	2	0	530	\N
804380	COM_PERMANENTE	AUTRE	\N	AFCL	\N	examen rapport MCC	\N	2024-03-05 14:10:00	2024-03-05 15:45:00	2024-03-05 15:52:19	2024-03-05 17:23:59	38	0	\N	\N
804381	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Cancers professionnels des sapeurs-pompiers - DGSCGC	\N	2024-03-05 09:00:00	2024-03-05 10:30:00	\N	\N	3	0	\N	\N
807174	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PPL enfants victimes et covictimes de violences intrafamiliales	CMP PPL enfants victimes et covictimes de violences intrafamiliales	2024-03-12 14:30:00	2024-03-12 15:20:00	\N	\N	64	0	\N	\N
807175	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	Explications de vote  et vote PPL réseau routier national non concédé	Explications de vote  et vote PPL réseau routier national non concédé	2024-03-12 15:25:00	2024-03-12 16:30:00	\N	\N	79	0	\N	\N
807176	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Adapter le droit de la responsabilité civile aux enjeux actuels	PPL Adapter le droit de la responsabilité civile aux enjeux actuels	2024-03-12 16:35:00	2024-03-12 18:20:00	\N	\N	93	0	\N	\N
807253	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI ATOS	MI ATOS	2024-03-06 16:30:00	2024-03-06 19:30:00	\N	\N	2	0	\N	\N
807258	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI Atos	MI Atos	2024-03-06 19:30:00	2024-03-06 20:30:00	\N	\N	1	0	\N	\N
817488	GIA	AUCUNE	\N	\N	\N	AG de reconstitution du Bureau du GIA France-Grèce	Assemblée générale de reconstitution du Bureau du groupe interparlementaire d'amitié France-Grèce	2024-01-16 14:30:00	2024-01-16 15:30:00	\N	\N	9	0	591	\N
817550	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de M. Sébastien Lecornu	Audition de M. Sébastien Lecornu	2024-04-02 17:30:00	2024-04-02 19:30:00	2024-04-03 11:41:31	2024-04-03 16:51:20	32	0	\N	\N
819168	COM_ENQUETE	PLENIERE	\N	COPRO	\N	TR élus locaux	TR élus locaux	2024-04-03 16:30:00	2024-04-03 18:00:00	2024-04-09 11:04:33	2024-04-15 11:47:20	4	0	\N	\N
819177	COM_ENQUETE	PLENIERE	\N	COPRO	\N	DACG	DACG	2024-04-03 18:00:00	2024-04-03 19:30:00	\N	\N	4	0	\N	\N
807639	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI IVG - Drees	\N	2024-03-12 15:00:00	2024-03-12 15:30:00	\N	\N	3	0	\N	\N
791666	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion CATDD	\N	2024-01-31 09:30:00	2024-01-31 11:20:00	2024-01-31 18:34:26	2024-01-31 18:48:10	44	6	\N	\N
776821	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE 93 - PLF pour 2024 - Examen amdts séance Missions	PLENIERE 93 - PLF pour 2024 - Examen amdts séance Missions	2023-12-04 09:04:00	2023-12-04 09:26:00	2023-12-08 11:37:47	2023-12-12 18:09:34	10	0	\N	\N
776875	COM_SPECIALE	AUDRAP	\N	DDADUE23	\N	Audition PJL Ddadue - DGPR	Audition PJL Ddadue - DGPR	2023-11-29 16:30:00	2023-11-29 17:00:00	\N	\N	2	0	\N	\N
776876	COM_SPECIALE	AUDRAP	\N	DDADUE23	\N	Audition PJL Ddadue - Direction des affaires civiles et du sceau	Audition PJL Ddadue - Direction des affaires civiles et du sceau	2023-11-29 17:00:00	2023-11-29 18:00:00	\N	\N	2	0	\N	\N
776976	COM_SPECIALE	AUDRAP	\N	DDADUE23	\N	Audition PJL Ddadue - Fnam	Audition PJL Ddadue - Fnam	2023-12-01 15:45:00	2023-12-01 16:30:00	\N	\N	1	0	\N	\N
776978	COM_SPECIALE	AUDRAP	\N	DDADUE23	\N	Audition PJL Ddadue - Direction générale du Trésor	Audition PJL Ddadue - Direction générale du Trésor	2023-12-01 11:00:00	2023-12-01 12:00:00	\N	\N	2	0	\N	\N
776981	COM_SPECIALE	AUDRAP	\N	DDADUE23	\N	Audition PJL Ddadue - Autorité de contrôle prudentiel et de résolution	Audition PJL Ddadue - Autorité de contrôle prudentiel et de résolution	2023-12-01 13:30:00	2023-12-01 14:15:00	\N	\N	1	0	\N	\N
776982	COM_SPECIALE	AUDRAP	\N	DDADUE23	\N	Audition PJL Ddadue - Autorité des marchés financiers	Audition PJL Ddadue - Autorité des marchés financiers	2023-12-01 14:15:00	2023-12-01 15:00:00	\N	\N	1	0	\N	\N
776983	COM_SPECIALE	AUDRAP	\N	DDADUE23	\N	Audition PJL Ddadue - Direction générale des finances publiques	Audition PJL Ddadue - Direction générale des finances publiques	2023-12-01 15:00:00	2023-12-01 15:45:00	\N	\N	1	0	\N	\N
777002	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 Action de la DGFIP auprès des collectivités territoriales- Audition Cour des comptes	58-2 Action de la DGFIP auprès des collectivités territoriales- Audition de la Cour des comptes	2023-11-30 17:00:00	2023-11-30 18:00:00	\N	\N	1	0	\N	\N
777020	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition MCC - DGPN	\N	2023-12-13 16:30:00	2023-12-13 17:45:00	2023-12-14 15:39:53	2023-12-14 17:48:20	15	0	\N	\N
777021	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition ARCOM	\N	2023-12-13 09:30:00	2023-12-13 11:15:00	2023-12-13 11:14:48	2023-12-13 14:19:07	38	0	\N	\N
789371	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de M. Léo Jarry	Audition de M. Léo Jarry	2024-01-24 09:30:00	2024-01-24 10:50:00	2024-01-24 14:24:12	2024-01-25 18:33:24	36	5	\N	\N
794682	GIA	AUCUNE	\N	\N	\N	Entreien avec S.E. M. Vadym Omelchenko, Ambassadeur d'Ukraine en France	Entreien avec S.E. M. Vadym Omelchenko, Ambassadeur d'Ukraine en France	2024-01-17 13:45:00	2024-01-17 15:00:00	\N	\N	11	0	530	\N
798010	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	 PJLO Nouvelle-Calédonie	 PJLO Nouvelle-Calédonie	2024-02-13 08:00:00	2024-02-13 08:30:00	\N	\N	1	0	\N	\N
801496	COM_ENQUETE	PLENIERE	\N	ELEC	\N	Audition MM. Piquemal et Le Mouroux	\N	2024-02-27 14:00:00	2024-02-27 16:05:00	2024-02-27 16:09:29	2024-02-27 17:17:20	11	0	\N	\N
804055	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Réseau routier national non concédé 	PPL visant à faciliter la mise à disposition aux régions du réseau routier national non concédé	2024-02-26 16:30:00	2024-02-26 17:30:00	\N	\N	1	0	\N	\N
807584	GIA	AUCUNE	\N	\N	\N	Entretien avec l'Ambassadrice de France au Sénégal	Entretien avec Mme Christine FAGES, Ambassadrice de France au Sénégal	2024-03-12 15:00:00	2024-03-12 15:40:00	\N	\N	14	0	573	\N
821126	MISSION	AUCUNE	\N	COMP	\N	Audition plénière	\N	2024-04-10 17:30:00	2024-04-10 19:00:00	\N	\N	5	0	\N	\N
821135	COM_PERMANENTE	AUTRE	\N	FINC	\N	Plénière 22 - Décision sur la déclaration d'irrecevabilité art. 40 	Plénière 22 - Décision sur la déclaration d'irrecevabilité art. 40 	2024-04-10 18:10:00	2024-04-10 18:25:00	2024-04-10 19:56:49	2024-04-12 13:33:42	23	23	\N	\N
821886	ETUDES	DEPLACEMENT	\N	\N	\N	Visite vélodrome+golf nationaux (78)	\N	2024-04-11 09:00:00	2024-04-11 14:00:00	\N	\N	10	0	\N	934
821897	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	mi enseignants	\N	2024-04-11 16:00:00	2024-04-11 17:30:00	\N	\N	4	0	\N	\N
821903	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audition sur le programme 129	\N	2024-03-25 18:15:00	2024-03-25 20:15:00	\N	\N	0	0	\N	\N
821904	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audition sur le programme 129	\N	2024-03-25 18:15:00	2024-03-25 20:15:00	\N	\N	0	0	\N	\N
780819	GIA	AUCUNE	\N	\N	\N	Dejeuner avec une délégation du Parlement du Canada	\N	2023-12-30 13:00:00	2023-12-30 14:30:00	\N	\N	14	0	583	\N
780834	GIA	AUCUNE	\N	\N	\N	Déjeuner avec une délégation du Parlement du Canada	\N	2023-11-30 13:00:00	2023-11-30 14:30:00	\N	\N	14	0	583	\N
793707	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Emeutes	MI Emeutes	2024-01-30 18:30:00	2024-01-30 19:00:00	\N	\N	1	0	\N	\N
794818	QUESTURE	AUCUNE	\N	\N	\N	Réunion de Questure 	Réunion du Conseil de Questure	2024-01-30 17:40:00	2024-01-30 19:05:00	\N	\N	3	0	\N	\N
807969	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Application de la loi « JOP »	Audition rapporteur - MI Application de la loi « JOP »	2024-03-12 15:30:00	2024-03-12 17:00:00	\N	\N	7	0	\N	\N
808727	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GS Espace EutelSat	\N	2024-03-13 13:30:00	2024-03-13 15:00:00	\N	\N	5	0	\N	\N
816064	GIA	AUCUNE	\N	\N	\N	Entretien avec le député libanais Georges Okais	Entretien avec le député libanais Georges Okais	2024-04-02 09:40:00	2024-04-02 10:45:00	\N	\N	1	0	597	\N
821754	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Pharmacies	PPL  Pharmacies	2024-04-11 14:45:00	2024-04-11 16:00:00	\N	\N	35	0	\N	\N
778887	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Lutte contre les dérives sectaires	Audition rapporteur - PJL Lutte contre les dérives sectaires	2023-12-06 11:00:00	2023-12-06 12:00:00	\N	\N	2	0	\N	\N
778890	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Lutte contre les dérives sectaires	Audition rapporteur - PJL Lutte contre les dérives sectaires	2023-12-05 09:00:00	2023-12-05 10:00:00	\N	\N	3	0	\N	\N
778892	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Lutte contre les dérives sectaires	Audition rapporteur - PJL Lutte contre les dérives sectaires	2023-12-05 11:00:00	2023-12-05 12:00:00	\N	\N	1	0	\N	\N
778896	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI « JOP »	Audition rapporteur - MI « JOP »	2023-12-06 16:30:00	2023-12-06 19:30:00	\N	\N	2	0	\N	\N
783936	GIA	AUCUNE	\N	\N	\N	Assemblée générale	Assemblée générale après renouvellement	2023-12-19 14:00:00	2023-12-19 14:30:00	\N	\N	15	0	629	\N
789479	COM_ENQUETE	PLENIERE	\N	ELEC	\N	Réunion constitutive	\N	2024-01-18 11:00:00	2024-01-18 11:50:00	2024-01-23 11:34:02	2024-01-24 10:30:42	11	0	\N	\N
801386	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJLO Congrès et assemblées de province de la Nouvelle-Calédonie 	PJLO Congrès et assemblées de province de la Nouvelle-Calédonie	2024-02-27 14:30:00	2024-02-27 16:25:00	\N	\N	111	0	\N	\N
801387	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Rénovation de l'habitat dégradé	PJL Rénovation de l'habitat dégradé	2024-02-27 16:25:00	2024-02-27 20:00:00	\N	\N	113	0	\N	\N
801388	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Rénovation de l'habitat dégradé	PJL Rénovation de l'habitat dégradé	2024-02-27 21:30:00	2024-02-28 00:35:00	\N	\N	53	0	\N	\N
810440	MISSION	AUDRAP	\N	COMP	\N	Audition FNMF	\N	2024-03-13 16:45:00	2024-03-13 17:45:00	\N	\N	8	0	\N	\N
801389	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2024-02-28 15:00:00	2024-02-28 16:25:00	\N	\N	295	0	\N	\N
801390	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJLC IVG	PJLC IVG	2024-02-28 16:40:00	2024-02-28 20:05:00	\N	\N	265	0	\N	\N
801392	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Rénovation de l'habitat dégradé	PJL Rénovation de l'habitat dégradé	2024-02-28 21:35:00	2024-02-28 23:30:00	\N	\N	51	0	\N	\N
809843	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2024-02-14 18:05:00	2024-02-14 18:49:00	\N	\N	23	0	\N	\N
774509	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2023-10-31 17:04:00	2023-10-31 17:53:00	\N	\N	23	0	\N	\N
777209	GIA	AUCUNE	\N	\N	\N	Dîner offert en l'honneur de la fête nationale de Finlande	Dîner offert en l'honneur de la fête nationale de Finlande	2023-12-04 19:15:00	2023-12-04 22:00:00	\N	\N	6	0	640	\N
789686	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe d'amitié France-Pays Andins	Assemblée générale du groupe d'amitié France-Pays Andins	2024-01-23 14:30:00	2024-01-23 15:15:00	\N	\N	15	0	979	\N
791660	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2024-01-25 09:30:00	2024-01-25 13:00:00	\N	\N	5	0	\N	\N
796417	GIA	AUCUNE	\N	\N	\N	entretien avec S.E. M. SheikhAli bin Jassim Al-Thani, ambassadeur du Qatar en France	\N	2024-02-06 13:00:00	2024-02-06 14:30:00	\N	\N	1	0	661	\N
796419	GIA	AUCUNE	\N	\N	\N	assemblée générale du groupe	\N	2024-02-06 17:30:00	2024-02-06 18:00:00	\N	\N	2	0	627	\N
796436	GIA	AUCUNE	\N	\N	\N	entretien avec S.E. M. Jai-chul CHOI, ambassadeur de Corée du Sud en France	\N	2024-02-07 08:30:00	2024-02-07 09:30:00	\N	\N	9	0	613	\N
797274	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GS Espace - Alliance NewSpace France	GS Espace - Alliance NewSpace France	2024-02-07 14:00:00	2024-02-07 15:00:00	\N	\N	3	0	\N	\N
797438	GIA	AUCUNE	\N	\N	\N	Entretien avec S.E M. François NKULIKYIMFURA, Ambassadeur du Rwanda en France	Entretien avec S.E M. François NKULIKYIMFURA, Ambassadeur du Rwanda en France	2024-02-07 08:30:00	2024-02-07 10:00:00	\N	\N	9	0	572	\N
805354	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2024-03-13 09:30:00	2024-03-13 11:30:00	2024-03-13 11:40:58	2024-03-13 15:59:23	38	0	\N	\N
805365	COM_PERMANENTE	AUDRAP	\N	CAE	\N	DHUP	\N	2024-01-31 13:30:00	2024-01-31 15:00:00	\N	\N	3	0	\N	\N
805374	COM_PERMANENTE	AUDRAP	\N	CAE	\N	TR Plan initiative copropriété	\N	2024-02-01 15:00:00	2024-02-01 17:00:00	\N	\N	4	0	\N	\N
805380	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Banque des territoires	Banque des territoires	2024-02-01 17:00:00	2024-02-01 17:30:00	\N	\N	2	0	\N	\N
805689	MISSION	AUCUNE	\N	PERI	\N	Réunion constitutive	MI Périnatalité - Réunion constitutive	2024-03-06 13:30:00	2024-03-06 14:10:00	2024-03-21 15:14:51	2024-03-21 18:30:08	15	4	\N	\N
805691	MISSION	AUCUNE	\N	COMP	\N	Réunion constitutive	\N	2024-03-06 14:05:00	2024-03-06 14:30:00	2024-03-07 16:15:25	2024-03-07 22:41:39	12	0	\N	\N
808537	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GS ZAN	GS ZAN	2024-03-12 17:15:00	2024-03-12 19:20:00	\N	\N	5	0	\N	\N
815982	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI ATOS	MI ATOS - Audition de JP Morgan	2024-03-27 16:30:00	2024-03-27 17:30:00	\N	\N	2	0	\N	\N
815985	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI ATOS	MI ATOS : Audition Schneider et CIRI	2024-03-27 17:30:00	2024-03-27 19:30:00	\N	\N	3	0	\N	\N
815989	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI ATOS	MI ATOS : Audition CDC	2024-03-27 19:30:00	2024-03-27 20:30:00	\N	\N	2	0	\N	\N
818920	COM_ENQUETE	PLENIERE	\N	INFLU	\N	Auditions Général Aymeric Bonnemaison et Etienne Apaire	Auditions Général Aymeric Bonnemaison et Etienne Apaire	2024-04-04 14:00:00	2024-04-04 16:20:00	2024-04-04 17:30:09	2024-04-05 10:20:18	6	0	\N	\N
818950	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	Auditions	Auditions	2024-04-04 10:00:00	2024-04-04 12:30:00	\N	\N	6	0	\N	\N
818957	GIA	AUCUNE	\N	\N	\N	Forum annuel Track 1.5 France-Finlande organisé par le ministère des armées	Forum annuel Track 1.5 France-Finlande organisé par le ministère des armées	2024-04-03 09:00:00	2024-04-03 11:00:00	\N	\N	1	0	640	\N
818959	GIA	AUCUNE	\N	\N	\N	Rencontre avec une délégation de parlementaires cubains	Rencontre avec une délégation de parlementaires cubains	2024-03-29 13:00:00	2024-03-29 14:30:00	\N	\N	1	0	642	\N
783098	COM_SPECIALE	PLENIERE	\N	DDADUE23	\N	Réunion CS DDADUE	\N	2023-12-19 13:35:00	2023-12-19 13:45:00	2023-12-19 13:53:06	2023-12-20 18:13:22	17	3	\N	\N
783099	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion CATDD	\N	2023-12-20 09:36:00	2023-12-20 10:30:00	2023-12-20 14:34:00	2023-12-20 18:10:22	38	10	\N	\N
802807	GIA	AUCUNE	\N	\N	\N	Entretien avec S.E M. Emile NGOY KASONGO, Ambassadeur à la République démocratique du Cong	Entretien avec S.E M. Emile NGOY KASONGO, Ambassadeur à la République démocratique du Cong	2024-02-28 08:30:00	2024-02-28 10:30:00	\N	\N	5	0	572	\N
807204	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL Evaluation APD	PJL Evaluation APD	2024-03-05 17:30:00	2024-03-05 18:30:00	\N	\N	1	0	\N	\N
807206	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJL Evaluation APD	PJL Evaluation APD	2024-02-29 17:00:00	2024-02-29 18:30:00	\N	\N	1	0	\N	\N
807329	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Négocations salariales - CFDT	\N	2024-03-12 14:00:00	2024-03-12 14:45:00	\N	\N	3	0	\N	\N
807330	DELEGATION	AUDRAP	\N	\N	206	Effets indésirables des vaccins covid-19 - Audition de la Cour des comptes	\N	2024-03-08 09:00:00	2024-03-08 10:00:00	\N	\N	2	0	\N	\N
807331	DELEGATION	AUDRAP	\N	\N	206	Effets indésirables des vaccins covid-19 - Audition de l'HERA	\N	2024-03-08 10:00:00	2024-03-08 11:00:00	\N	\N	2	0	\N	\N
807338	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition FFIDEC	\N	2024-03-14 09:00:00	2024-03-14 09:45:00	\N	\N	3	0	\N	\N
807341	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition FFAMCO	\N	2024-03-14 11:00:00	2024-03-14 11:45:00	\N	\N	2	0	\N	\N
807342	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI sur la situation des Ehpad - Audition ADF	\N	2024-03-21 09:00:00	2024-03-21 09:45:00	\N	\N	3	0	\N	\N
807353	COM_PERMANENTE	AUTRE	\N	CAE	\N	PJL CETA	\N	2024-03-12 15:05:00	2024-03-12 16:15:00	2024-03-12 17:20:03	2024-03-13 15:56:45	30	12	\N	\N
807354	COM_ENQUETE	PLENIERE	\N	TOTA	\N	Réunion CE-TE	\N	2024-03-11 16:00:00	2024-03-11 17:30:00	2024-03-14 10:10:03	2024-03-14 16:38:37	6	0	\N	\N
807358	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI Francophonie	\N	2024-03-26 13:30:00	2024-03-26 14:30:00	\N	\N	3	0	\N	\N
782950	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 14 décembre 2023	\N	2023-12-14 09:00:00	2023-12-14 11:00:00	2023-12-22 17:33:30	2024-01-08 13:18:39	15	0	\N	\N
805275	COM_PERMANENTE	AUTRE	\N	AFCL	\N	PPL bénévolat	\N	2024-03-06 09:30:00	2024-03-06 10:40:00	2024-03-06 11:00:02	2024-03-06 11:42:09	41	7	\N	\N
807362	COM_PERMANENTE	AUDRAP	\N	FINC	\N	MI Problèmes assurantiels des CT - Audition Autorité de la concurrence	MI Problèmes assurantiels des CT - Audition MM. COEURE et SCHALL, Autorité de la concurrence	2024-03-05 09:30:00	2024-03-05 10:30:00	\N	\N	1	0	\N	\N
807373	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Négociations salariales - CGT	\N	2024-03-12 14:45:00	2024-03-12 15:30:00	\N	\N	3	0	\N	\N
807374	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI sur la situation des Ehpad - Audition FEHAP-Nexem-Uniopss	\N	2024-03-21 09:45:00	2024-03-21 11:00:00	\N	\N	2	0	\N	\N
807375	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI sur la situation des Ehpad - Audition Synerpa	\N	2024-03-21 11:00:00	2024-03-21 12:00:00	\N	\N	2	0	\N	\N
807376	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI sur la situation des Ehpad - Audition de la Fnadepa	\N	2024-03-21 14:30:00	2024-03-21 15:45:00	\N	\N	3	0	\N	\N
807377	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PPL commission APD	\N	2024-02-29 17:30:00	2024-02-29 18:30:00	\N	\N	0	0	\N	\N
807379	COM_PERMANENTE	AUDRAP	\N	FINC	\N	MI Problèmes assurantiels des CT - Audition M. LA CORTE, DGPR	MI Problèmes assurantiels des CT - Audition M. LA CORTE, Direction générale de la prévention des risques (DGPR)	2024-03-07 08:30:00	2024-03-07 09:30:00	\N	\N	1	0	\N	\N
807381	COM_PERMANENTE	AUDRAP	\N	FINC	\N	MI Problèmes assurantiels des CT - Audition de la direction générale du Trésor	MI Problèmes assurantiels des CT - Audition de M. LANDAIS et Mme MATEOS, direction générale du Trésor	2024-03-07 10:30:00	2024-03-07 11:30:00	\N	\N	1	0	\N	\N
807383	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PPL commission APD	\N	2024-03-05 17:30:00	2024-03-05 18:30:00	\N	\N	0	0	\N	\N
807384	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audition rapporteur	\N	2024-02-29 15:00:00	2024-02-29 16:30:00	\N	\N	1	0	\N	\N
807385	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	rapport d'information Arabie saoudite	\N	2024-03-05 14:00:00	2024-03-05 15:30:00	\N	\N	0	0	\N	\N
809280	COM_ENQUETE	PLENIERE	\N	COPRO	\N	Réunion constitutive	Réunion constitutive	2024-02-14 12:30:00	2024-02-14 13:15:00	2024-03-13 16:59:32	2024-03-19 16:35:07	9	0	\N	\N
809305	COM_ENQUETE	PLENIERE	\N	COPRO	\N	Audition Olivier Klein	Audition Olivier Klein	2024-03-11 16:00:00	2024-03-11 17:15:00	2024-03-13 17:13:45	2024-03-14 16:37:34	6	0	\N	\N
809315	COM_ENQUETE	PLENIERE	\N	COPRO	\N	Audition Anah	Audition Anah	2024-03-11 17:15:00	2024-03-11 18:00:00	2024-03-13 17:13:32	2024-03-14 16:37:34	6	0	\N	\N
812852	BUREAU	AUCUNE	\N	\N	\N	Délégation en charge du travail parlementaire	Délégation en charge du travail parlementaire	2024-03-20 11:00:00	2024-03-20 12:00:00	\N	\N	2	0	\N	\N
812855	BUREAU	AUCUNE	\N	\N	\N	Délégation en charge du travail parlementaire	Délégation en charge du travail parlementaire	2024-03-20 16:45:00	2024-03-20 18:00:00	\N	\N	1	0	\N	\N
812903	GIA	AUCUNE	\N	\N	\N	Entretien avec l'Ambassadeur de Hongrie en France, S.E.M. Georges de Habsbourg Lorraine	Entretien avec l'Ambassadeur de Hongrie en France, S.E.M. Georges de Habsbourg Lorraine	2024-03-20 08:15:00	2024-03-20 09:20:00	\N	\N	6	0	592	\N
815479	MISSION	AUCUNE	\N	COMP	\N	Audition commune de Que Choisir et France Assos Santé	\N	2024-03-27 17:20:00	2024-03-27 19:00:00	2024-03-27 18:50:06	2024-03-29 15:44:54	6	0	\N	\N
815485	COM_EURO	DEPLACEMENT	\N	AFEU	\N	Auditions à Francfort - BCE - Euro numérique	Déplacement de Mme Blatrix Contat à Francfort dans le cadre de ses travaux sur l'euro-numérique	2024-03-26 09:05:00	2024-03-26 22:55:00	\N	\N	1	0	\N	\N
815489	COM_EURO	AUDRAP	\N	AFEU	\N	Auditions Euro numérique	Auditions de Mme Blatrix Contat à Francfort (BCE et Deutsche Bank) dans le cadre de ses travaux sur l'euro-numérique	2024-03-26 14:00:00	2024-03-26 18:10:00	\N	\N	1	0	\N	\N
815492	COM_EURO	AUDRAP	\N	AFEU	\N	Auditions Euro numérique	Auditions de Mme Blatrix Contat à Bruxelles dans le cadre de ses travaux sur l'euro-numérique	2024-03-21 10:00:00	2024-03-21 18:00:00	\N	\N	1	0	\N	\N
815577	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI Francophonie	\N	2024-03-27 16:30:00	2024-03-27 17:30:00	\N	\N	3	0	\N	\N
815593	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI enseignants	\N	2024-03-27 13:30:00	2024-03-27 14:30:00	\N	\N	5	0	\N	\N
786221	GIA	AUCUNE	\N	\N	\N	Assemblée générale	Assemblée générale	2023-12-19 17:00:00	2023-12-19 17:30:00	\N	\N	2	0	628	\N
789263	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Condamnés terroristes et lutte antiterroriste	PPL Condamnés terroristes et lutte antiterroriste	2024-01-23 14:30:00	2024-01-23 18:00:00	\N	\N	138	0	\N	\N
789265	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Accompagnement humain des élèves en situation de handicap	PPL Accompagnement humain des élèves en situation de handicap	2024-01-23 18:05:00	2024-01-23 19:45:00	\N	\N	57	0	\N	\N
789266	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2024-01-24 15:00:00	2024-01-24 16:15:00	\N	\N	293	0	\N	\N
789267	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Nationalisation du groupe Électricité de France	PPL Nationalisation du groupe Électricité de France	2024-01-24 16:30:00	2024-01-24 18:20:00	\N	\N	92	0	\N	\N
789268	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Décompte annuel des personnes sans abri dans chaque commune	PPL Décompte annuel des personnes sans abri dans chaque commune	2024-01-24 18:25:00	2024-01-24 20:10:00	\N	\N	60	0	\N	\N
791167	GIA	AUCUNE	\N	\N	\N	Accueil présidente du Parlement chypriote	Accueil de la présidente du Parlement chypriote par le président du Sénat	2024-01-17 16:30:00	2024-01-17 17:30:00	\N	\N	2	0	585	\N
791171	GIA	AUCUNE	\N	\N	\N	Salut en séance présidente du Parlement chypriote	Salut en séance pub de la présidente du Parlement chypriote par le président du Sénat	2024-01-17 17:30:00	2024-01-17 18:10:00	\N	\N	1	0	585	\N
791173	GIA	AUCUNE	\N	\N	\N	AG	Assemblée générale	2024-01-24 12:15:00	2024-01-24 12:50:00	\N	\N	7	0	585	\N
791811	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE 5 - Audition 58-2 DGFIP - Désignations rapporteurs PPL191, PJL255 et PJL283	PLENIERE 5 - Audition 58-2 DGFIP - Désignations rapporteurs PPL191, PJL255 et PJL283	2024-01-31 09:30:00	2024-01-31 11:49:00	2024-02-02 14:47:37	2024-02-02 18:51:12	27	0	\N	\N
791812	COM_ENQUETE	AUDRAP	\N	NARCO	\N	Etat-major de la marine nationale	Etat-major de la marine nationale	2024-01-29 17:15:00	2024-01-29 18:55:00	\N	\N	4	0	\N	\N
793152	GIA	AUCUNE	\N	\N	\N	Assemblée générale 	Assemblée générale du groupe d'amitié France-Syrie	2024-01-30 17:45:00	2024-01-30 18:00:00	\N	\N	3	0	644	\N
796545	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GS ZAN	GS ZAN	2024-02-06 16:00:00	2024-02-06 17:15:00	\N	\N	6	0	\N	\N
796592	GIA	AUCUNE	\N	\N	\N	Audition de Jean-Baptiste de Franssu, président de l'IOR	Audition de Jean-Baptiste de Franssu, président de l'Institut pour les Oeuvres de Religion	2024-02-06 17:00:00	2024-02-06 18:15:00	\N	\N	10	0	629	\N
801171	COM_ENQUETE	DEPLACEMENT	\N	NARCO	\N	Déplacement à Dijon, au Creusot et à Lyon	Déplacement à Dijon, au Creusot et à Lyon	2024-02-15 08:00:00	2024-02-16 22:00:00	\N	\N	4	0	\N	\N
802046	COM_PERMANENTE	AUTRE	\N	CAE	\N	PJL Rénovation de l'habitat dégradé - Amdts de séance	\N	2024-02-27 21:20:00	2024-02-27 21:25:00	2024-02-28 11:48:51	2024-02-28 16:40:42	11	0	\N	\N
804035	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Universités européennes	\N	2024-02-26 09:00:00	2024-02-26 10:15:00	\N	\N	2	0	\N	\N
804042	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Réunion plénière	\N	2024-02-29 09:00:00	2024-02-29 11:00:00	\N	\N	8	0	\N	\N
785541	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	Audition ESA	Audition ESA	2023-12-20 14:00:00	2023-12-20 15:00:00	\N	\N	8	0	\N	\N
804043	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Discrimination par la pratique de tests individuels et statistiques	PPL Discrimination par la pratique de tests individuels et statistiques	2024-02-19 11:00:00	2024-02-19 11:45:00	\N	\N	1	0	\N	\N
804044	DELEGATION	AUCUNE	\N	\N	PROS	Colloque "Femmes et IA : briser les codes"	\N	2024-03-07 08:35:00	2024-03-07 11:50:00	\N	\N	20	0	\N	\N
804045	DELEGATION	AUCUNE	\N	\N	206	Colloque "Femmes et IA : briser les codes"	\N	2024-03-07 08:35:00	2024-03-07 11:50:00	\N	\N	21	0	\N	\N
804047	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Tests PME	PPL "Tests PME" et création d'un dispositif "Impact Entreprises"	2024-02-29 17:00:00	2024-02-29 18:15:00	\N	\N	1	0	\N	\N
804049	COM_ENQUETE	PLENIERE	\N	NARCO	\N	Auditions : TJ Marseille - Association d'aide aux consommateurs	Auditions : TJ Marseille - Association d'aide aux consommateurs	2024-03-05 14:15:00	2024-03-05 17:30:00	2024-03-05 17:44:50	2024-03-06 11:41:06	9	0	\N	\N
804050	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Tests PME	PPL "Tests PME" et création d'un dispositif "Impact Entreprises"	2024-02-27 14:30:00	2024-02-27 15:15:00	\N	\N	1	0	\N	\N
804052	COM_ENQUETE	PLENIERE	\N	NARCO	\N	Auditions : Ancienne préfète de police des Bouches-du-Rhône - Cabinet Ruben & Associés	Auditions : Ancienne préfète de police des Bouches-du-Rhône - Cabinet Ruben & Associés	2024-03-06 16:40:00	2024-03-06 19:05:00	2024-03-06 19:09:01	2024-03-07 22:41:41	5	0	\N	\N
804053	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Réseau routier national non concédé 	PPL visant à faciliter la mise à disposition aux régions du réseau routier national non concédé	2024-02-26 14:00:00	2024-02-26 15:15:00	\N	\N	1	0	\N	\N
804058	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Emeutes	MI Emeutes	2024-02-29 14:30:00	2024-02-29 16:05:00	\N	\N	4	0	\N	\N
812717	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL pharmacies d'officine - CNOP	\N	2024-03-21 09:30:00	2024-03-21 10:30:00	\N	\N	2	0	\N	\N
812800	COM_ENQUETE	PLENIERE	\N	TOTA	\N	Réunion CE TE	\N	2024-03-21 10:30:00	2024-03-21 12:35:00	2024-03-21 14:13:30	2024-03-21 14:48:59	10	0	\N	\N
812849	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Négociations salariales - Audition Force ouvrière	\N	2024-03-20 16:30:00	2024-03-20 17:15:00	\N	\N	2	0	\N	\N
812857	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Négociations salariales - Audition CFTC	\N	2024-03-20 17:15:00	2024-03-20 18:15:00	\N	\N	2	0	\N	\N
812885	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI financiarisation de la santé - Sciences Po	\N	2024-03-20 17:00:00	2024-03-20 18:15:00	\N	\N	6	0	\N	\N
812981	MISSION	AUCUNE	\N	COMP	\N	Audition de M. Dominique Libault	\N	2024-03-21 14:30:00	2024-03-21 15:35:00	2024-03-21 16:19:18	2024-03-21 18:33:06	6	0	\N	\N
813065	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Jean Bacci	Auditions M. Jean Bacci	2024-03-18 10:00:00	2024-03-18 11:35:00	\N	\N	1	0	\N	\N
813067	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Jean Bacci	Auditions M. Jean Bacci	2024-03-18 14:00:00	2024-03-18 15:20:00	\N	\N	1	0	\N	\N
813070	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Jean-Yves Roux	Auditions M. Jean-Yves Roux	2024-03-20 13:30:00	2024-03-20 14:35:00	\N	\N	1	0	\N	\N
813077	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Jean-Yves Roux	Auditions M. Jean-Yves Roux	2024-03-20 16:20:00	2024-03-20 17:15:00	\N	\N	1	0	\N	\N
813080	DELEGATION	AUCUNE	\N	\N	211	Table ronde thématique "Femmes dans la rue"	\N	2024-04-04 08:35:00	2024-04-04 10:40:00	\N	\N	11	0	\N	\N
813081	DELEGATION	AUCUNE	\N	\N	211	Audition de M. Marc Guillaume, préfet de la région Ile-de-France	\N	2024-04-11 08:35:00	2024-04-11 09:30:00	\N	\N	6	0	\N	\N
813082	DELEGATION	AUCUNE	\N	\N	211	Audition de M. Jérôme d'Harcourt, DIHAL	\N	2024-04-11 09:35:00	2024-04-11 10:25:00	\N	\N	6	0	\N	\N
813151	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI IVG - Représentants des médecins	\N	2024-03-20 16:30:00	2024-03-20 18:00:00	\N	\N	3	0	\N	\N
813157	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI IVG - REVHO	\N	2024-03-20 18:00:00	2024-03-20 18:45:00	\N	\N	3	0	\N	\N
813182	DELEGATION	AUCUNE	\N	\N	PROS	Audition de la Commission de l'intelligence artificielle	\N	2024-03-26 18:05:00	2024-03-26 19:35:00	\N	\N	21	0	\N	\N
813183	DELEGATION	AUCUNE	\N	\N	206	Audition de la Commission de l'intelligence artificielle	\N	2024-03-26 18:05:00	2024-03-26 19:35:00	\N	\N	23	0	\N	\N
813188	COM_ENQUETE	PLENIERE	\N	NARCO	\N	Audition DGDDI et DNRED	Audition DGDDI et DNRED	2024-03-25 14:30:00	2024-03-25 16:00:00	2024-03-25 17:17:15	2024-03-25 18:11:09	8	0	\N	\N
813189	COM_ENQUETE	PLENIERE	\N	NARCO	\N	Audition de Bruno Le Maire	Audition de Bruno Le Maire	2024-03-26 09:20:00	2024-03-26 10:30:00	2024-03-26 10:27:47	2024-03-26 11:24:16	14	0	\N	\N
813190	COM_ENQUETE	PLENIERE	\N	NARCO	\N	Audition de François Molins	Audition de François Molins	2024-03-27 14:00:00	2024-03-27 15:00:00	2024-03-27 17:42:09	2024-03-29 15:43:31	11	0	\N	\N
813191	COM_ENQUETE	PLENIERE	\N	NARCO	\N	Délibération d'orientation préalable	Délibération d'orientation préalable	2024-03-27 16:40:00	2024-03-27 17:50:00	2024-03-27 21:55:14	2024-03-29 15:43:32	8	0	\N	\N
813203	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Avoirs criminels - PJLC Nouvelle-Calédonie (amendements)	PPL Avoirs criminels - PJLC Nouvelle-Calédonie (amendements)	2024-03-26 13:45:00	2024-03-26 14:10:00	2024-03-26 14:29:17	2024-03-26 15:23:08	22	9	\N	\N
813207	ETUDES	AUTRE	\N	\N	\N	Table ronde Amorce CNR	\N	2024-03-19 15:30:00	2024-03-19 17:00:00	\N	\N	4	0	\N	922
813212	DELEGATION	AUTRE	\N	\N	DSOM	Coopération régionale - Audition Business France	\N	2024-04-02 17:00:00	2024-04-02 18:00:00	\N	\N	13	0	\N	\N
813217	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL pharmacies d'officine - Table ronde communes	\N	2024-03-21 14:00:00	2024-03-21 15:15:00	\N	\N	1	0	\N	\N
813220	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL pharmacies d'officine - Table ronde syndicats	\N	2024-03-21 15:15:00	2024-03-21 16:15:00	\N	\N	1	0	\N	\N
772077	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 85	PLENIERE - 85	2023-11-23 10:30:00	2023-11-23 11:30:00	2023-12-01 23:08:54	2023-12-05 17:40:51	28	3	\N	\N
782847	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Table ronde sur "la responsabilité sociale des entreprises : l¿arnaque du siècle ?"	\N	2023-12-14 08:00:00	2023-12-14 09:20:00	\N	\N	11	0	\N	\N
782848	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Table ronde relative à la directive (UE) 2022/2464, dite « CSRD »	\N	2023-12-14 09:20:00	2023-12-14 10:30:00	\N	\N	11	0	\N	\N
782883	DELEGATION	AUCUNE	\N	\N	211	Auditions de syndicats et associations de familles monoparentales	\N	2024-01-18 09:15:00	2024-01-18 10:40:00	\N	\N	10	0	\N	\N
782897	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE 98 - PPL Bâtiments scolaire et PPLO Réserve parl. - Exam. motions et amdts séance	PLENIERE 98 - PPL Bâtiments scolaire et PPLO Réserve parl. - Exam. motions et amendements séance	2023-12-14 09:30:00	2023-12-14 10:00:00	2023-12-23 15:06:10	2024-01-08 13:18:49	10	1	\N	\N
782945	DELEGATION	AUCUNE	\N	\N	206	Examen de rapports d'information	\N	2023-12-14 09:35:00	2023-12-14 10:55:00	\N	\N	10	0	\N	\N
786063	RENSEIGNEMENT	AUCUNE	\N	\N	CVFS	\N	\N	2023-12-20 18:00:00	2023-12-20 19:00:00	\N	\N	3	0	\N	\N
813206	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Homicide routier (amdts) -  PJL Lutte contre les dérives sectaires (NL - rapport)	PPL Homicide routier (amdts) -  PJL Lutte contre les dérives sectaires (NL - rapport)	2024-03-27 10:55:00	2024-03-27 11:45:00	2024-03-27 13:16:36	2024-03-27 16:02:53	39	16	\N	\N
786735	GIA	AUCUNE	\N	\N	\N	Visio Afrane	Entretien en visio avec M. Etienne Gille, membre d'Afrane (amitié franco-afghane)	2024-01-16 09:30:00	2024-01-16 10:30:00	\N	\N	1	0	648	\N
786744	GIA	AUCUNE	\N	\N	\N	AG 2024 GIA France-Andorre	\N	2024-01-16 09:20:00	2024-01-16 10:10:00	\N	\N	8	0	963	\N
797562	GIA	AUCUNE	\N	\N	\N	Entretien avec l'Ambassadrice d'Israel en France	Rencontre avec l'Ambassadrice d'Israel en France, Alona Fisher Kamm	2024-01-24 08:30:00	2024-01-24 09:30:00	\N	\N	25	0	595	\N
797688	COM_ENQUETE	PLENIERE	\N	ELEC	\N	Tables rondes Nouveau nucléaire et marchés de l'électricité	\N	2024-02-08 14:30:00	2024-02-08 18:20:00	2024-02-08 19:02:49	2024-02-09 17:33:19	8	0	\N	\N
797849	QUESTURE	AUCUNE	\N	\N	\N	Réunion de Questure	Réunion du Conseil de Questure	2024-02-06 16:00:00	2024-02-06 17:20:00	\N	\N	3	0	\N	\N
804282	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Ordonnance santé outre-mer - Audition Polynésie	\N	2024-03-01 18:15:00	2024-03-01 19:00:00	\N	\N	1	0	\N	\N
804285	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Auditions	\N	2024-03-12 16:00:00	2024-03-12 19:00:00	\N	\N	0	0	\N	\N
804286	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE 11 - Examen amdts séance PPL191 Financement industrie défense	PLENIERE 11 - Examen amdts séance PPL191 Financement industrie défense	2024-03-05 14:00:00	2024-03-05 14:05:00	2024-03-08 16:14:20	2024-03-11 14:45:17	22	8	\N	\N
804288	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE 13 - Audition 58-2 M. MOSCOVICI - Délivrance titres d'identité	PLENIERE 13 - Audition 58-2 M. MOSCOVICI - Délivrance titres d'identité	2024-03-06 10:30:00	2024-03-06 12:00:00	\N	\N	0	0	\N	\N
804289	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE 14 - Audition M. LE MAIRE et CAZENAVE	PLENIERE 14 - Audition M. LE MAIRE et CAZENAVE	2024-03-06 17:35:00	2024-03-06 19:55:00	2024-03-08 16:14:55	2024-03-11 14:46:54	30	0	\N	\N
804292	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	MCC Inondations 2023/2024 - Audition M. THOME, Météo-France	\N	2024-02-06 12:00:00	2024-02-06 13:00:00	\N	\N	0	0	\N	\N
804293	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	MCC Inondations 2023/2024 - Audition Mme PUJO, SCHAPI	\N	2024-02-14 18:30:00	2024-02-14 19:30:00	\N	\N	0	0	\N	\N
804294	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Table ronde des associations (Decollaje, Fédération nat. des jardins d'enfants)	\N	2024-03-04 09:30:00	2024-03-04 10:30:00	\N	\N	2	0	\N	\N
804295	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Ville de Paris, direction des familles de la petite enfance	\N	2024-03-04 10:30:00	2024-03-04 11:15:00	\N	\N	2	0	\N	\N
804296	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Direction générale de l'enseignement scolaire	\N	2024-03-04 11:15:00	2024-03-04 12:00:00	\N	\N	2	0	\N	\N
804301	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	MCC Inondations 2023/2024 - Audition du CEREMA	\N	2024-02-27 14:00:00	2024-02-27 15:00:00	\N	\N	0	0	\N	\N
804304	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	MCC Inondations 2023/2024 - Audition de France Assureurs	\N	2024-02-27 15:00:00	2024-02-27 16:00:00	\N	\N	0	0	\N	\N
804305	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	MCC Inondations 2023/2024 - Audition Voies navigables de France (VNF)	\N	2024-02-27 16:00:00	2024-02-27 17:00:00	\N	\N	0	0	\N	\N
804306	AUTRE_TEMPORAIRE	AUDRAP	\N	\N	\N	MCC Inondations 2023/2024	\N	2024-02-27 18:00:00	2024-02-27 19:00:00	\N	\N	0	0	\N	\N
804307	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition Bernard Charlès (Dassault Systems)	\N	2024-03-06 09:30:00	2024-03-06 11:30:00	\N	\N	0	0	\N	\N
804308	COM_EURO	AUDRAP	\N	AFEU	\N	Audition retards de paiement	\N	2024-03-01 09:00:00	2024-03-01 10:20:00	\N	\N	2	0	\N	\N
811533	GIA	AUCUNE	\N	\N	\N	PDJ ambassadeur	Rencontre de l'ambassadeur chypriote autour d'un petit-déjeuner	2024-03-20 08:30:00	2024-03-20 09:35:00	\N	\N	5	0	585	\N
812864	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Atos	MI Atos	2024-03-20 18:00:00	2024-03-20 20:00:00	\N	\N	2	0	\N	\N
813116	GIA	AUCUNE	\N	\N	\N	PDJ de travail France-Arménie en présence de l'Ambassadeur de France en Arménie	Entretien avec M. Olivier DECOTTIGNIES, ambassadeur de France en Arménie	2024-03-20 08:15:00	2024-03-20 09:30:00	\N	\N	21	0	641	\N
813162	GIA	AUCUNE	\N	\N	\N	Entretien avec David VARDANYAN, fils du ministre d'Etat Ruben Vardanyan	Entretien avec David VARDANYAN, représentant des prisonniers politiques du Haut-Karabagh	2024-03-20 12:45:00	2024-03-20 14:15:00	\N	\N	3	0	641	\N
813167	GIA	AUCUNE	\N	\N	\N	Dîner du Conseil de coordiantion des organisations arméniennes de France	Participation au dîner du CCAF en présence de Gabril ATTAL, Premier ministre	2024-03-20 19:30:00	2024-03-20 23:00:00	\N	\N	12	0	641	\N
813180	GIA	AUCUNE	\N	\N	\N	Entretten avec Edmon MARUKIAN, ancien ambassadeur itinérant d'Arménie	Entretien avec Edmon MARUKIAN, représentant du Parti Bright	2024-03-19 16:00:00	2024-03-19 17:00:00	\N	\N	1	0	641	\N
813184	GIA	AUCUNE	\N	\N	\N	Réunion de préparation du colloque sur le plateau himalayen	Réunion de travail avec le secrétaire exécutif et une conseillere de la DRIP	2024-03-19 17:00:00	2024-03-19 18:00:00	\N	\N	1	0	634	\N
813186	GIA	AUCUNE	\N	\N	\N	Réunion de préparation du colloque du 14 mai et du déplacement en Arménie	Réunion de travail avec la secrétaire exécutive	2024-03-19 14:15:00	2024-03-19 15:00:00	\N	\N	1	0	641	\N
813192	GIA	AUCUNE	\N	\N	\N	Entretien avec M. François Alabrune, Ambassadeur de France aux Pays-Bas	Entretien avec M. François Alabrune, Ambassadeur de France aux Pays-Bas	2024-02-28 20:15:00	2024-02-28 21:45:00	\N	\N	4	0	599	\N
813197	GIA	AUCUNE	\N	\N	\N	Entretien avec S.E.M. David LUY, Ambassadeur du Cambodge	Entretien avec S.E.M. David LUY, Ambassadeur du Cambodge	2024-03-20 12:30:00	2024-03-20 14:00:00	\N	\N	5	0	577	\N
813227	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI sur la situation des Ehpad - Audition Mutualité Française	\N	2024-03-21 15:45:00	2024-03-21 16:30:00	\N	\N	2	0	\N	\N
813342	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE 18 - Comm. JF HUSSON + Désign. rapp. PPL attractivité France	PLENIERE 18 - Comm. JF HUSSON MI Pb assurantiels CT + Désign. rapp. PPL attractivité France	2024-03-27 10:00:00	2024-03-27 11:30:00	2024-04-02 16:07:12	2024-04-02 17:02:21	42	10	\N	\N
813343	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	GEAC - Réunion constitutive	\N	2024-03-19 16:00:00	2024-03-19 16:45:00	\N	\N	0	0	\N	\N
813356	COM_ENQUETE	PLENIERE	\N	TOTA	\N	Réunion CE-TE	\N	2024-03-25 16:00:00	2024-03-25 18:00:00	2024-03-25 18:22:40	2024-03-26 11:26:28	4	0	\N	\N
813357	COM_ENQUETE	PLENIERE	\N	TOTA	\N	Réunion CE-TE	\N	2024-03-28 10:30:00	2024-03-28 12:45:00	2024-03-28 15:10:56	2024-03-29 15:45:43	10	0	\N	\N
813358	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions MI Crise du logement	\N	2024-03-18 17:00:00	2024-03-18 19:00:00	\N	\N	2	0	\N	\N
813361	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition MI Crise du logement	\N	2024-03-20 16:30:00	2024-03-20 17:30:00	\N	\N	2	0	\N	\N
813364	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Auditions MI Crise du logement	\N	2024-03-21 08:45:00	2024-03-21 10:15:00	\N	\N	3	0	\N	\N
814365	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition Enedis	\N	2024-03-27 09:40:00	2024-03-27 11:30:00	2024-03-27 11:57:43	2024-03-27 16:03:30	37	0	\N	\N
814395	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition Notre Dame	\N	2024-03-27 09:30:00	2024-03-27 11:30:00	2024-03-27 17:48:57	2024-03-29 15:41:38	30	0	\N	\N
812077	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	AUditin MI Atos	\N	2024-03-19 17:00:00	2024-03-19 18:00:00	\N	\N	0	0	\N	\N
771366	GIA	AUCUNE	\N	\N	\N	Coopé - Visite de M. Augustus J. FLOMO, Vice-ministre, Libéria	Coopé - Visite de M. Augustus J. FLOMO, Vice-ministre en charge de la politique économique, Libéria	2023-02-08 14:00:00	2023-02-08 15:00:00	\N	\N	1	0	573	\N
771370	GIA	AUCUNE	\N	\N	\N	Coopé - Entretien avec Mme Anna ISHCHENKO, conseillère à la Rada d'Ukraine	Coopé - Entretien avec Mme Anna ISHCHENKO, conseillère à la Rada d'Ukraine	2023-03-22 16:30:00	2023-03-22 17:30:00	\N	\N	1	0	530	\N
771762	GIA	AUCUNE	\N	\N	\N	Coopé - 12e Assises de la coopération décentralisée à Hanoi	Coopé - 12e Assises de la coopération décentralisée à Hanoi	2023-04-12 00:00:00	2023-04-17 00:00:00	\N	\N	1	0	626	\N
771790	GIA	AUCUNE	\N	\N	\N	Coopé - Stage de Mme Marija MARAS et visite de Mme Martina DRINCIC	Coopé - Stage de Mme Marija MARAS et visite de Mme Martina DRINCIC, fonctionnaires au Parlement du Monténégro	2023-05-31 12:15:00	2023-05-31 13:30:00	\N	\N	2	0	674	\N
771796	GIA	AUCUNE	\N	\N	\N	Coopé - Visite d'une délégation de diplomates français et italiens	Coopé - Visite d'une délégation de diplomates français et italiens	2023-06-07 16:45:00	2023-06-07 17:45:00	\N	\N	1	0	621	\N
771802	GIA	AUCUNE	\N	\N	\N	Coopé - Entretien avec deux conseillers maîtres de la Cour des comptes sur le Liban	Coopé - Entretien avec deux conseillers maîtres de la Cour des comptes sur le Liban	2023-06-13 10:00:00	2023-06-13 11:00:00	\N	\N	1	0	597	\N
771808	GIA	AUCUNE	\N	\N	\N	Coopé - Visite de M. Enoch WU, Président de l'ONG Forward Alliance à Taïwan	Coopé - Visite de M. Enoch WU, Président de l'ONG Forward Alliance à Taïwan	2023-06-13 16:30:00	2023-06-13 17:30:00	\N	\N	1	0	623	\N
771816	GIA	AUCUNE	\N	\N	\N	Coopé - Visite d'études au Sénat de deux Sénateurs ivoiriens 	Coopé - Visite d'études de deux Sénateurs ivoiriens  sur le thème de la jeunesse et de la participation démocratique	2023-06-21 12:30:00	2023-06-21 14:00:00	\N	\N	1	0	573	\N
771818	GIA	AUCUNE	\N	\N	\N	Coopé - Visite d'études au Sénat de deux Sénateurs ivoiriens	Coopé - Visite d'études de deux Sénateurs ivoiriens  sur le thème de la jeunesse et de la participation démocratique	2023-06-22 12:30:00	2023-06-22 14:00:00	\N	\N	1	0	573	\N
771822	GIA	AUCUNE	\N	\N	\N	Coopé - Stage au Sénat de Mme Joanna GRANOWSKA, fonctionnaire du Sénat de Pologne	Coopé - Stage au Sénat de Mme Joanna GRANOWSKA, fonctionnaire du Sénat de Pologne	2023-07-12 16:15:00	2023-07-12 17:15:00	\N	\N	1	0	600	\N
771825	GIA	AUCUNE	\N	\N	\N	Coopé - Table ronde sur la coopération décentralisée sur l'Ukraine	Coopé - Table ronde sur la coopération décentralisée sur l'Ukraine	2023-07-10 13:15:00	2023-07-10 17:20:00	\N	\N	1	0	530	\N
771831	GIA	AUCUNE	\N	\N	\N	Coopé - Visite d'études d'une délégation du Sénat de Côté d'Ivoire	Coopé - Visite d'études d'une délégation du Sénat de Côté d'Ivoire sur le thème du contrôle de l'action gouvernementale	2023-10-25 12:30:00	2023-10-25 14:00:00	\N	\N	1	0	573	\N
771834	GIA	AUCUNE	\N	\N	\N	Coopé - Visite d'études d'une délégation du Sénat de Côté d'Ivoire	Coopé - Visite d'études d'une délégation du Sénat de Côté d'Ivoire sur le thème du contrôle de l'action gouvernementale	2023-10-23 19:30:00	2023-10-23 21:30:00	\N	\N	1	0	573	\N
771837	GIA	AUCUNE	\N	\N	\N	Coopé - Visite d'études des Présidents des conseils régionaux du Cameroun	Coopé - Visite d'études des Présidents des conseils régionaux du Cameroun	2023-11-21 12:30:00	2023-11-21 14:10:00	\N	\N	2	0	572	\N
791667	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe d'amitié France-Biélorussie	Définition du programme d'activité 	2024-01-24 14:00:00	2024-01-24 14:30:00	\N	\N	3	0	852	\N
791671	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe d'amitié France-Egypte	Définition du programme d'activités 	2024-01-24 17:00:00	2024-01-24 17:30:00	\N	\N	15	0	617	\N
794440	GIA	AUCUNE	\N	\N	\N	Assemblée générale	Assemblée générale	2024-01-31 17:50:00	2024-01-31 18:40:00	\N	\N	14	0	575	\N
794455	GIA	AUCUNE	\N	\N	\N	Entretien avec  M. Cyrille BELLIER, Directeur Orients de l'AFD	Entretien avec  M. Cyrille BELLIER, Directeur Orients de l'AFD	2024-01-31 14:00:00	2024-01-31 14:50:00	\N	\N	6	0	612	\N
795636	ETUDES	AUTRE	\N	\N	\N	Réunion constitutive GE francophonie	\N	2024-02-06 16:30:00	2024-02-06 17:15:00	\N	\N	14	0	\N	1006
795678	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion CATDD	\N	2024-02-06 17:00:00	2024-02-06 18:30:00	2024-02-07 09:47:21	2024-02-08 12:31:21	32	7	\N	\N
795681	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion CATDD AFF SOC	\N	2024-02-07 10:30:00	2024-02-07 12:00:00	2024-02-07 14:03:56	2024-02-08 12:31:27	58	6	\N	\N
804081	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur PJL Modifications du CG3P relatives à la Polynésie française	Auditions rapporteur PJL Modifications du CG3P relatives à la Polynésie française	2024-02-29 19:05:00	2024-02-29 19:45:00	\N	\N	2	0	\N	\N
804085	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Agressions subies par les enseignants (rapport d'information)	Agressions subies par les enseignants (rapport d'information)	2024-03-05 14:10:00	2024-03-05 15:45:00	2024-03-05 16:35:39	2024-03-05 17:22:55	39	13	\N	\N
804096	COM_PERMANENTE	AUDRAP	\N	FINC	\N	MI Problèmes assurantiels des CT - Table-ronde élus locaux	MI Problèmes assurantiels des CT - Table-ronde élus locaux	2024-02-27 15:30:00	2024-02-27 17:00:00	\N	\N	1	0	\N	\N
804098	COM_PERMANENTE	AUDRAP	\N	FINC	\N	MI Problèmes assurantiels des CT - Audition Groupama	MI Problèmes assurantiels des CT - Audition Groupama	2024-02-27 14:30:00	2024-02-27 15:30:00	\N	\N	1	0	\N	\N
804100	COM_PERMANENTE	AUDRAP	\N	FINC	\N	MI Problèmes assurantiels des CT - Audition France Assureurs	MI Problèmes assurantiels des CT - Audition France Assureurs	2024-02-27 17:30:00	2024-02-27 18:30:00	\N	\N	1	0	\N	\N
804103	COM_PERMANENTE	AUDRAP	\N	FINC	\N	MI Problèmes assurantiels des CT - Table-ronde réassureurs	MI Problèmes assurantiels des CT - Table-ronde réassureurs	2024-02-29 09:30:00	2024-02-29 11:00:00	\N	\N	1	0	\N	\N
804106	COM_PERMANENTE	AUDRAP	\N	FINC	\N	MI Problèmes assurantiels des CT - audition AGEA et Planète CSCA	MI Problèmes assurantiels des CT - audition AGEA et Planète CSCA	2024-02-29 11:00:00	2024-02-29 12:00:00	\N	\N	1	0	\N	\N
804108	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	MI Problèmes assurantiels des CT - Déplacement Hauts de Seine et Val de Marne	MI Problèmes assurantiels des CT - Déplacement Hauts de Seine et Val de Marne	2024-03-01 08:00:00	2024-03-01 18:00:00	\N	\N	4	0	\N	\N
804113	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Concessions autoroutes - Audition MM. JEANSANNETAS et DELAHAYE	Contrôle 2024 - Concessions autoroutes - Audition MM. JEANSANNETAS et DELAHAYE	2024-02-27 08:00:00	2024-02-27 10:00:00	\N	\N	2	0	\N	\N
804116	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Protocoles sociaux DGAC - Audition MM. BIDET et SALUSTE, SPAC-CFDT	Contrôle 2024 - Protocoles sociaux DGAC - Audition MM. BIDET et SALUSTE, SPAC-CFDT	2024-02-27 16:15:00	2024-02-27 17:15:00	\N	\N	1	0	\N	\N
804118	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Protocoles sociaux DGAC - Audition M. LACOTE, directeur aéroport CDG	Contrôle 2024 - Protocoles sociaux DGAC - Audition M. LACOTE, directeur aéroport CDG	2024-02-27 17:15:00	2024-02-27 18:15:00	\N	\N	1	0	\N	\N
804130	DELEGATION	AUCUNE	\N	\N	211	Audition d'Aurore Bergé, ministre de l'Egalité entre les femmes et les hommes 	\N	2024-03-21 10:00:00	2024-03-21 11:45:00	\N	\N	16	0	\N	\N
804142	DELEGATION	AUCUNE	\N	\N	211	Colloque "Femmes et IA: briser les codes" 	\N	2024-03-07 08:35:00	2024-03-07 11:50:00	\N	\N	20	0	\N	\N
804143	COM_PERMANENTE	AUTRE	\N	FINC	\N	MI Financement du ZAN - Réunion constitutive	MI Financement du ZAN - Réunion constitutive	2024-02-27 09:30:00	2024-02-27 10:00:00	2024-03-01 16:34:36	2024-03-01 18:11:51	10	0	\N	\N
804157	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Situation des Ehpad- Audition CNSA	\N	2024-02-29 14:30:00	2024-02-29 15:30:00	\N	\N	4	0	\N	\N
804166	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI situation des Ehpad - Audition AMF	\N	2024-02-29 16:15:00	2024-02-29 17:00:00	\N	\N	4	0	\N	\N
804171	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI SItuation des Ehpad	\N	2024-02-29 17:00:00	2024-02-29 17:45:00	\N	\N	4	0	\N	\N
804176	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - CNDA - Table-ronde universitaires spécialistes de l'asile	Contrôle 2024 - CNDA - Table-ronde universitaires spécialistes de l'asile, Mme GATTE, MM. SLAMA et MAUREL	2024-02-27 15:00:00	2024-02-27 16:15:00	\N	\N	1	0	\N	\N
775805	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de M. David Colon	Audition de M. David Colon	2023-12-06 10:00:00	2023-12-06 11:45:00	2023-12-06 15:23:36	2023-12-06 18:26:18	26	0	\N	\N
786427	DELEGATION	AUDRAP	\N	\N	211	Audition rapporteures	\N	2024-01-11 09:00:00	2024-01-11 10:00:00	\N	\N	9	0	\N	\N
786428	DELEGATION	AUDRAP	\N	\N	211	Audition rapporteures	\N	2024-01-11 10:00:00	2024-01-11 10:40:00	\N	\N	9	0	\N	\N
786429	DELEGATION	AUDRAP	\N	\N	211	Audition rapporteures	\N	2024-01-11 14:30:00	2024-01-11 15:25:00	\N	\N	7	0	\N	\N
786430	DELEGATION	AUDRAP	\N	\N	211	Audition rapporteures	\N	2024-01-11 15:30:00	2024-01-11 16:25:00	\N	\N	6	0	\N	\N
786433	DELEGATION	AUDRAP	\N	\N	211	Audition rapporteures	Audition rapporteure Collective mères isolées (Familles monoparentales)	2024-01-16 15:00:00	2024-01-16 16:00:00	\N	\N	7	0	\N	\N
786434	DELEGATION	AUDRAP	\N	\N	211	Audition rapporteures	Audition de la DREES (Familles monoparentales)	2024-01-16 16:00:00	2024-01-16 17:00:00	\N	\N	6	0	\N	\N
786435	DELEGATION	AUDRAP	\N	\N	211	Audition rapporteures	Audition de sociologues (Familles monoparentales)	2024-01-16 17:00:00	2024-01-16 18:00:00	\N	\N	4	0	\N	\N
786436	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL ESH sur le temps méridien	\N	2024-01-09 10:00:00	2024-01-09 11:45:00	\N	\N	5	0	\N	\N
786449	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL TND - Audition Pr Christelle Declercq	\N	2024-01-10 15:30:00	2024-01-10 16:30:00	\N	\N	1	0	\N	\N
786451	COM_PERMANENTE	AUDRAP	\N	CAE	\N	EDF	EDF	2024-01-09 09:00:00	2024-01-09 09:45:00	\N	\N	3	0	\N	\N
786455	COM_PERMANENTE	AUDRAP	\N	CAE	\N	ORANO	ORANO	2024-01-09 09:45:00	2024-01-09 10:15:00	\N	\N	3	0	\N	\N
786460	COM_PERMANENTE	AUDRAP	\N	CAE	\N	TR représentants personnel ASN	TR représentants personnel ASN	2024-01-09 10:15:00	2024-01-09 11:00:00	\N	\N	3	0	\N	\N
786464	COM_ENQUETE	PLENIERE	\N	NARCO	\N	Tables rondes Parquets en zone rurale et Gendarmerie	Tables rondes Parquets en zone rurale et Gendarmerie	2024-01-15 14:30:00	2024-01-15 16:55:00	2024-01-15 17:32:09	2024-01-15 18:21:29	7	0	\N	\N
786465	COM_ENQUETE	PLENIERE	\N	NARCO	\N	Tables rondes Parquets en zone urbaine et Police	Tables rondes Parquets en zone urbaine et Police	2024-01-17 16:30:00	2024-01-17 19:15:00	2024-01-17 21:05:59	2024-01-18 18:01:26	8	0	\N	\N
786466	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Agence nationale pour la gestion des déchets radioactifs 	Agence nationale pour la gestion des déchets radioactifs 	2024-01-09 11:00:00	2024-01-09 11:30:00	\N	\N	3	0	\N	\N
786470	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Conseil supérieur de l'énergie	Conseil supérieur de l'énergie	2024-01-09 11:30:00	2024-01-09 12:00:00	\N	\N	4	0	\N	\N
786475	COM_PERMANENTE	AUDRAP	\N	CAE	\N	OPECST	OPECST	2024-01-09 13:45:00	2024-01-09 14:30:00	\N	\N	5	0	\N	\N
786482	COM_PERMANENTE	AUDRAP	\N	CAE	\N	TR syndicats IRSN	TR syndicats IRSN	2024-01-09 14:30:00	2024-01-09 15:30:00	\N	\N	5	0	\N	\N
786488	COM_PERMANENTE	AUDRAP	\N	CAE	\N	TR filière française du nucléaire	TR filière française du nucléaire	2024-01-09 15:30:00	2024-01-09 16:30:00	\N	\N	3	0	\N	\N
786492	COM_PERMANENTE	AUDRAP	\N	CAE	\N	CEA	CEA	2024-01-09 16:30:00	2024-01-09 17:15:00	\N	\N	3	0	\N	\N
787487	ETUDES	AUCUNE	\N	\N	\N	Réunion constitutive	Réunion constitutive	2024-01-17 08:30:00	2024-01-17 09:00:00	\N	\N	10	0	\N	948
792758	COM_ENQUETE	AUDRAP	\N	NARCO	\N	Table ronde - Attachés douaniers et attachés de sécurité intérieure	Table ronde - Attachés douaniers et attachés de sécurité intérieure	2024-01-23 08:00:00	2024-01-23 09:30:00	\N	\N	2	0	\N	\N
792764	COM_ENQUETE	AUDRAP	\N	NARCO	\N	Narcotrafic - Audition rapporteur - SIAT	Narcotrafic - Audition rapporteur - SIAT	2024-01-30 08:00:00	2024-01-30 09:00:00	\N	\N	2	0	\N	\N
793148	DELEGATION	AUCUNE	\N	\N	COLTER	Réunion plénière	\N	2024-02-01 08:30:00	2024-02-01 10:45:00	\N	\N	23	0	\N	\N
797710	CONF_PRES	AUCUNE	\N	\N	\N	Conférence des Présidents	Conférence des Présidents	2024-01-24 18:00:00	2024-01-24 19:30:00	\N	\N	32	0	\N	\N
799205	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition Sébastien Bazin (Accor)	\N	2024-02-14 09:05:00	2024-02-14 10:45:00	2024-02-14 16:34:49	2024-02-14 17:54:07	44	1	\N	\N
799240	DELEGATION	AUDRAP	\N	\N	211	Audition rapporteures Familles monoparentales	\N	2024-02-16 11:30:00	2024-02-16 12:30:00	\N	\N	0	0	\N	\N
799741	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Réunion  constitutive 	\N	2024-02-14 12:30:00	2024-02-14 13:15:00	\N	\N	0	0	\N	\N
799760	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Auditions MI Atos	\N	2024-02-08 09:00:00	2024-02-08 12:00:00	\N	\N	0	0	\N	\N
799761	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audition commissaires du gouvernement	\N	2024-02-07 16:30:00	2024-02-07 18:00:00	\N	\N	1	0	\N	\N
799779	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Auditions	\N	2024-02-06 09:15:00	2024-02-06 11:15:00	\N	\N	1	0	\N	\N
801196	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Adapter le droit de la responsabilité civile aux enjeux actuels	PPL Adapter le droit de la responsabilité civile aux enjeux actuels	2024-02-08 14:30:00	2024-02-08 16:45:00	\N	\N	1	0	\N	\N
801198	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Rénovation de l'habitat dégradé	PJL Rénovation de l'habitat dégradé	2024-02-06 14:00:00	2024-02-06 14:25:00	\N	\N	1	0	\N	\N
801203	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Statut de l'élu local	PPL Statut de l'élu local	2024-02-19 10:10:00	2024-02-19 10:25:00	\N	\N	3	0	\N	\N
801207	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Statut de l'élu local	PPL Statut de l'élu local	2024-02-19 10:45:00	2024-02-19 11:15:00	\N	\N	3	0	\N	\N
801211	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Statut de l'élu local	PPL Statut de l'élu local	2024-02-19 11:25:00	2024-02-19 11:50:00	\N	\N	3	0	\N	\N
802222	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition Esther Duflo 	\N	2024-02-28 09:30:00	2024-02-28 10:45:00	2024-02-28 11:40:50	2024-02-28 16:37:40	34	0	\N	\N
802502	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition Charles Fries	\N	2024-02-28 16:30:00	2024-02-28 18:00:00	2024-02-29 14:27:28	2024-02-29 14:36:24	13	0	\N	\N
802825	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Discrimination par la pratique de tests individuels et statistiques	PPL Discrimination par la pratique de tests individuels et statistiques	2024-02-27 15:30:00	2024-02-27 18:00:00	\N	\N	0	0	\N	\N
799207	COM_PERMANENTE	AUTRE	\N	CAE	\N	PJL Habitat dégradé	\N	2024-02-14 10:45:00	2024-02-14 12:30:00	2024-02-14 16:35:21	2024-02-14 17:41:26	47	3	\N	\N
802847	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Tests PME	PPL "Tests PME" et création d'un dispositif "Impact Entreprises"	2024-02-23 15:00:00	2024-02-23 15:45:00	\N	\N	1	0	\N	\N
802850	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Tests PME	\N	2024-02-23 09:30:00	2024-02-23 10:15:00	\N	\N	1	0	\N	\N
804819	GIA	AUCUNE	\N	\N	\N	Déjeuner avec l'ambassadeur du Brésil en France	Déjeuner du groupe d'amitié France-Brésil avec son Excellence M. Ricardo Neiva Tavares, ambassadeur du Brésil en France	2024-03-05 13:00:00	2024-03-05 15:00:00	\N	\N	16	0	576	\N
804964	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	 PPL Justice patrimoniale au sein de la famille	PPL Justice patrimoniale au sein de la famille	2024-03-05 15:30:00	2024-03-05 17:00:00	\N	\N	1	0	\N	\N
806924	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	GS Développement durable	GS Développement durable	2024-03-06 13:45:00	2024-03-06 15:00:00	\N	\N	10	0	\N	\N
808075	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de M. Benoit Coeuré	\N	2024-03-13 09:30:00	2024-03-13 11:55:00	2024-03-21 14:39:02	2024-03-21 18:28:00	33	0	\N	\N
808129	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE 15 - Audition Agence France Trésor, CR conférence art.13	PLENIERE 15 - Audition M. DERUENNES,Agence France Trésor + CR conférence art.13 1Bruxelles 2/13 février 2024	2024-03-13 10:00:00	2024-03-13 12:00:00	2024-03-21 16:45:49	2024-03-21 18:27:35	34	0	\N	\N
808184	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition CGC	\N	2024-03-26 17:00:00	2024-03-26 17:45:00	\N	\N	2	0	\N	\N
808394	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2024-03-20 09:30:00	2024-03-20 12:30:00	2024-03-26 15:21:00	2024-03-26 15:23:46	36	0	\N	\N
810342	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	 Entretien avec Anne Grillo, directrice d'ANMO au MEAE	Entretien avec Anne Grillo, directrice d'ANMO au MEAE	2024-03-12 14:45:00	2024-03-12 16:30:00	\N	\N	6	0	\N	\N
810360	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI ATOS	MI Atos	2024-03-13 16:30:00	2024-03-13 18:30:00	\N	\N	1	0	\N	\N
814472	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition Nicole Belloubet	\N	2024-04-03 16:30:00	2024-04-03 19:00:00	2024-04-03 20:06:37	2024-04-04 11:40:25	34	0	\N	\N
814671	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL service civique	\N	2024-03-27 11:30:00	2024-03-27 12:30:00	\N	\N	3	0	\N	\N
779152	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition sur la situation en République démocratique du Congo 	Audition sur la situation en République démocratique du Congo 	2023-12-13 11:00:00	2023-12-13 12:30:00	2023-12-13 15:14:29	2023-12-14 17:48:19	39	6	\N	\N
781273	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe	Assemblée générale du groupe	2023-12-12 17:00:00	2023-12-12 17:30:00	\N	\N	12	0	643	\N
781314	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe d'amitié France-Maroc	Assemblée générale du groupe d'amitié France-Maroc	2023-12-06 14:15:00	2023-12-06 15:00:00	\N	\N	27	0	598	\N
781342	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe d'amitié France-Pologne	Assemblée générale du groupe d'amitié France-Pologne	2023-12-12 08:45:00	2023-12-12 10:00:00	\N	\N	9	0	600	\N
781352	GIA	AUCUNE	\N	\N	\N	Assemblée générale	Assemblée générale	2023-12-12 17:35:00	2023-12-12 18:05:00	\N	\N	4	0	556	\N
788078	GIA	AUCUNE	\N	\N	\N	Déjeuner débat autour du nonce apostolique en France	Déjeuner débat autour de S.E. Mgr Celestino Migliore, nonce apostolique à Paris	2024-01-17 12:45:00	2024-01-17 14:00:00	\N	\N	18	0	629	\N
795611	ETUDES	AUTRE	\N	\N	\N	Réunion du Bureau	\N	2024-02-06 12:00:00	2024-02-06 12:30:00	\N	\N	10	0	\N	934
797609	DELEGATION	AUTRE	\N	\N	DSOM	Coopération régionale : audition de M. Charles TROTTMANN (AFD)	\N	2024-02-15 09:30:00	2024-02-15 11:30:00	\N	\N	9	0	\N	\N
797610	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2024-02-14 09:30:00	2024-02-14 11:00:00	2024-02-14 11:19:40	2024-02-14 17:47:30	36	0	\N	\N
797633	COM_EURO	AUDRAP	\N	AFEU	\N	Auditions "Paquet pharmaceutique" et la pénurie de médicaments	\N	2024-01-11 10:30:00	2024-01-11 18:00:00	\N	\N	3	0	\N	\N
797637	DELEGATION	AUCUNE	\N	\N	COLTER	Réunion plénière	\N	2024-02-08 09:30:00	2024-02-08 11:20:00	\N	\N	20	0	\N	\N
797916	ETUDES	AUCUNE	\N	\N	\N	SE Animal et société - Réunion constitutive	SE Animal et société - Réunion constitutive	2024-02-06 16:00:00	2024-02-06 16:30:00	\N	\N	6	0	\N	1011
797926	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Atos	MI Atos	2024-02-08 09:00:00	2024-02-08 12:00:00	\N	\N	2	0	\N	\N
801464	COM_PERMANENTE	AUTRE	\N	CAE	\N	PJL Rénovation de l'habitat dégradé - Amdts séance	\N	2024-02-27 14:10:00	2024-02-27 14:50:00	2024-03-05 17:25:25	2024-03-05 17:25:31	19	8	\N	\N
801469	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions rapporteur PJL Modifications du CG3P relatives à la Polynésie française	Auditions rapporteur PJL Modifications du CG3P relatives à la Polynésie française	2024-02-21 10:00:00	2024-02-21 11:40:00	\N	\N	1	0	\N	\N
801472	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	TR syndicats agricoles	\N	2023-07-11 13:30:00	2023-07-11 14:30:00	\N	\N	2	0	\N	\N
801483	COM_PERMANENTE	AUDRAP	\N	CAE	\N	TR Collectivités territoriales	\N	2023-07-11 18:30:00	2023-07-11 19:30:00	\N	\N	2	0	\N	\N
801486	ETUDES	AUDRAP	\N	\N	\N	audition Infranum	\N	2024-02-27 09:00:00	2024-02-27 10:30:00	\N	\N	6	0	\N	1008
801571	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion CATDD	\N	2024-02-28 08:30:00	2024-02-28 10:50:00	2024-02-28 19:22:26	2024-02-29 11:38:10	40	4	\N	\N
801625	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	TR restauration collective	\N	2023-07-12 11:00:00	2023-07-12 12:00:00	\N	\N	2	0	\N	\N
801670	MECSS	AUCUNE	\N	\N	MECSS	Audition de la DSS	\N	2024-02-29 10:30:00	2024-02-29 11:35:00	2024-02-29 11:54:14	2024-02-29 14:35:50	9	0	\N	\N
801807	COM_EURO	AUDRAP	\N	AFEU	\N	Audition sur le retard de paiement	\N	2024-02-15 15:00:00	2024-02-15 16:15:00	\N	\N	2	0	\N	\N
801832	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	INAO	\N	2023-07-12 18:30:00	2023-07-12 19:15:00	\N	\N	2	0	\N	\N
801836	ETUDES	AUTRE	\N	\N	\N	Audition	\N	2024-02-27 13:35:00	2024-02-27 14:00:00	\N	\N	11	0	\N	918
801856	COM_PERMANENTE	AUTRE	\N	ETRD	\N	examen rapport pour avis industrie défense + audition Nexter	\N	2024-02-27 17:30:00	2024-02-27 19:00:00	2024-02-28 10:31:40	2024-02-28 16:44:09	29	0	\N	\N
797826	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Retard de paiement	\N	2024-02-09 10:30:00	2024-02-09 12:30:00	\N	\N	2	0	\N	\N
814470	COM_PERMANENTE	AUTRE	\N	AFCL	\N	PPL service civique	\N	2024-04-03 09:30:00	2024-04-03 11:00:00	2024-04-03 11:15:48	2024-04-03 16:53:47	46	4	\N	\N
779151	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Examen de 2 conventions internationales	Examen de 2 conventions internationales	2023-12-13 10:35:00	2023-12-13 11:00:00	2023-12-13 15:13:46	2023-12-14 17:48:18	39	6	\N	\N
797611	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2024-02-14 09:00:00	2024-02-14 09:30:00	2024-02-14 11:19:33	2024-02-14 17:48:41	39	0	\N	\N
801857	COM_PERMANENTE	AUTRE	\N	ETRD	\N	examen rapport pour avis industrie défense + audition Nexter	\N	2024-02-27 17:00:00	2024-02-27 17:30:00	2024-02-28 10:26:05	2024-02-28 16:44:07	30	7	\N	\N
803914	COM_ENQUETE	PLENIERE	\N	TOTA	\N	Réunion CE-TE	\N	2024-02-29 10:30:00	2024-02-29 12:25:00	2024-03-01 09:27:18	2024-03-01 14:37:48	9	0	\N	\N
803926	ETUDES	AUTRE	\N	\N	\N	GE Handicap - Audition I. Saurat	\N	2024-02-28 14:00:00	2024-02-28 15:00:00	\N	\N	10	0	\N	1014
803927	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2024-03-06 09:30:00	2024-03-06 11:00:00	2024-03-06 11:42:21	2024-03-06 17:47:09	45	0	\N	\N
803933	ETUDES	AUTRE	\N	\N	\N	Table ronde INCa, FRM, Institut Curie	\N	2024-02-14 14:00:00	2024-02-14 15:00:00	\N	\N	12	0	\N	1004
803941	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de Mme Sarah El Hairy	\N	2024-03-06 16:35:00	2024-03-06 18:10:00	2024-03-21 14:30:05	2024-03-21 14:31:03	23	0	\N	\N
803984	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Emeutes	MI Emeutes	2024-02-29 09:00:00	2024-02-29 11:00:00	\N	\N	4	0	\N	\N
803996	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Discrimination par la pratique de tests individuels et statistiques	PPL Discrimination par la pratique de tests individuels et statistiques	2024-02-29 08:30:00	2024-02-29 12:15:00	\N	\N	1	0	\N	\N
803998	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 6 mars 2024	\N	2024-03-06 13:35:00	2024-03-06 14:55:00	2024-03-06 14:56:21	2024-03-06 17:44:34	8	0	\N	\N
804006	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Statut de l'élu local (amendements)	PPL Statut de l'élu local (amendements)	2024-03-05 09:30:00	2024-03-05 10:20:00	2024-03-05 14:00:04	2024-03-05 17:21:48	28	5	\N	\N
804007	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI JOP 2024	\N	2024-02-29 10:30:00	2024-02-29 12:30:00	\N	\N	2	0	\N	\N
804010	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Jeux Olympiques et Paralympiques 2024 - Audition de Gérald Darmanin	Jeux Olympiques et Paralympiques 2024 - Audition de Gérald Darmanin	2024-03-05 16:30:00	2024-03-05 18:25:00	2024-03-05 19:03:43	2024-03-06 11:43:21	19	0	\N	\N
804012	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Respect des principes de la République (rapport d'information)	Respect des principes de la République (rapport d'information)	2024-03-06 09:00:00	2024-03-06 10:00:00	2024-03-06 10:33:05	2024-03-06 11:43:22	36	4	\N	\N
804018	COM_PERMANENTE	PEC_NON_MML	\N	LOIS	\N	PPL Réseau routier national non concédé (rapport - LEC)	PPL Réseau routier national non concédé (rapport - LEC)	2024-03-06 14:00:00	2024-03-06 14:30:00	2024-03-06 14:51:16	2024-03-06 17:45:45	23	16	\N	\N
804033	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	discrimin	PPL Discrimination par la pratique de tests individuels et statistiques	2024-02-29 14:00:00	2024-02-29 16:00:00	\N	\N	2	0	\N	\N
804034	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PJL Ordonnance santé outre-mer - Gouvernement et Congrès de Nouvelle-Calédonie	\N	2024-02-28 08:00:00	2024-02-28 09:00:00	\N	\N	1	0	\N	\N
804178	DELEGATION	AUDRAP	\N	\N	206	Nouveaux développements de l'IA - Audition de la DGE	\N	2024-02-20 15:00:00	2024-02-20 16:45:00	\N	\N	1	0	\N	\N
804179	DELEGATION	AUDRAP	\N	\N	206	Nouveaux développements de l'IA - Audition de Mme Nozha Boujemaa	\N	2024-02-20 16:45:00	2024-02-20 17:30:00	\N	\N	1	0	\N	\N
804180	DELEGATION	AUDRAP	\N	\N	206	Nouveaux développements de l'IA - Audition de Meta France	\N	2024-02-29 15:00:00	2024-02-29 15:45:00	\N	\N	2	0	\N	\N
804181	DELEGATION	AUDRAP	\N	\N	206	Nouveaux développements de l'IA - Audition de Google France	\N	2024-02-29 15:45:00	2024-02-29 16:30:00	\N	\N	2	0	\N	\N
804182	DELEGATION	AUDRAP	\N	\N	206	Nouveaux développements de l'IA - Audition d'IBM France	\N	2024-02-29 16:30:00	2024-02-29 17:15:00	\N	\N	2	0	\N	\N
804183	DELEGATION	AUDRAP	\N	\N	206	Nouveaux développements de l'IA - Audition de XXII	\N	2024-02-29 17:15:00	2024-02-29 18:00:00	\N	\N	2	0	\N	\N
804184	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - CNDA - Table-ronde avocats intervenant dans le contentieux de l'asile	Contrôle 2024 - CNDA - Table-ronde avocats intervenant dans le contentieux de l'asile, MM. BEAR, ASLANIAN et Mme ROQUES	2024-02-27 16:30:00	2024-02-27 17:45:00	\N	\N	1	0	\N	\N
804186	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Décarbonation - Audition I4CE	Contrôle 2024 - Décarbonation - Audition I4CE	2024-02-20 10:00:00	2024-02-20 12:00:00	\N	\N	2	0	\N	\N
778996	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	AFCL	\N	Cinéma	\N	2023-12-06 17:30:00	2023-12-06 18:30:00	\N	\N	2	0	\N	\N
780849	GIA	AUCUNE	\N	\N	\N	GIA France Bulgarie	Rencontre avec S. Exc. Mme Iliana IOTOVA, Vice-Présidente de la République de Bulgarie	2023-12-12 09:00:00	2023-12-12 10:30:00	\N	\N	4	0	582	\N
788778	GIA	AUCUNE	\N	\N	\N	GIA France Libye	AG	2024-01-17 14:00:00	2024-01-17 14:30:00	\N	\N	2	0	657	\N
801233	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI Atos	\N	2024-02-15 15:00:00	2024-02-15 19:00:00	\N	\N	1	0	\N	\N
801235	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI Atos	\N	2024-02-15 14:00:00	2024-02-15 19:00:00	\N	\N	1	0	\N	\N
804000	BUREAU	AUCUNE	\N	\N	\N	Délégation en charge du travail parlementaire	Délégation en charge du travail parlementaire	2024-02-27 17:15:00	2024-02-27 18:15:00	\N	\N	2	0	\N	\N
804013	BUREAU	AUCUNE	\N	\N	\N	Délégation en charge du travail parlementaire	Délégation en charge du travail parlementaire	2024-02-28 11:00:00	2024-02-28 11:45:00	\N	\N	2	0	\N	\N
804020	BUREAU	AUCUNE	\N	\N	\N	Délégation en charge du travail parlementaire	\N	2024-02-28 13:30:00	2024-02-28 14:45:00	\N	\N	2	0	\N	\N
813035	BUREAU	AUCUNE	\N	\N	\N	Délégation en charge du travail parlementaire	Délégation en charge du travail parlementaire	2024-03-21 11:00:00	2024-03-21 12:00:00	\N	\N	3	0	\N	\N
813047	BUREAU	AUCUNE	\N	\N	\N	Délégation en charge du travail parlementaire	Délégation en charge du travail parlementaire	2024-03-21 12:00:00	2024-03-21 12:30:00	\N	\N	2	0	\N	\N
815932	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PJL sécuriser et réguler l'espace numérique	CMP PJL sécuriser et réguler l'espace numérique	2024-04-02 15:50:00	2024-04-02 16:55:00	\N	\N	67	0	\N	\N
815933	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PPL engagement bénévole et vie associative	CMP PPL engagement bénévole et vie associative	2024-04-02 16:55:00	2024-04-02 17:40:00	\N	\N	57	0	\N	\N
815934	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	NL PJL Lutte contre les dérives sectaires	NL PJL Lutte contre les dérives sectaires	2024-04-02 17:40:00	2024-04-02 18:50:00	\N	\N	56	0	\N	\N
815935	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat sur la situation de l'hôpital	Débat sur la situation de l'hôpital	2024-04-02 21:30:00	2024-04-02 23:15:00	\N	\N	47	0	\N	\N
815936	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2024-04-03 15:00:00	2024-04-03 16:20:00	\N	\N	302	0	\N	\N
815937	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP PPL Droit de la responsabilité civile 	CMP PPL Droit de la responsabilité civile 	2024-04-03 16:35:00	2024-04-03 17:20:00	\N	\N	47	0	\N	\N
815938	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJLC onvention d'extradition Cambodge	PJLC onvention d'extradition Cambodge	2024-04-03 17:20:00	2024-04-03 18:25:00	\N	\N	41	0	\N	\N
797829	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur	\N	2024-02-08 14:30:00	2024-02-08 15:30:00	\N	\N	0	0	\N	\N
803928	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2024-03-06 11:00:00	2024-03-06 11:30:00	2024-03-06 11:41:53	2024-03-06 17:47:13	45	0	\N	\N
815939	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	3L PPL Protéger Électricité de France d'un démembrement	3L PPL Protéger Électricité de France d'un démembrement	2024-04-03 18:25:00	2024-04-03 19:35:00	\N	\N	40	0	\N	\N
815940	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	3L PPL Protéger Électricité de France d'un démembrement	3L PPL Protéger Électricité de France d'un démembrement	2024-04-03 20:00:00	2024-04-03 20:00:00	\N	\N	0	0	\N	\N
817147	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition DGT	\N	2024-04-02 17:15:00	2024-04-02 18:30:00	\N	\N	2	0	\N	\N
817172	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2024-04-03 09:00:00	2024-04-03 10:00:00	\N	\N	0	0	\N	\N
817173	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2024-04-03 09:05:00	2024-04-03 10:30:00	2024-04-03 10:32:06	2024-04-03 16:53:15	39	0	\N	\N
817255	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2024-04-03 09:30:00	2024-04-03 11:50:00	2024-04-03 14:33:58	2024-04-03 16:54:56	40	0	\N	\N
817284	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition plénière	\N	2024-04-03 09:00:00	2024-04-03 10:30:00	\N	\N	0	0	\N	\N
818014	ETUDES	AUTRE	\N	\N	\N	GE Cancer - Audition de la ligue contre le cancer	\N	2024-04-03 14:00:00	2024-04-03 15:00:00	\N	\N	3	0	\N	1004
818961	COM_EURO	AUDRAP	\N	AFEU	\N	Auditions Paquet pharmaceutique	\N	2024-04-01 16:30:00	2024-04-01 18:30:00	\N	\N	3	0	\N	\N
818977	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI financiarisation de la santé - Syndicats représentatifs des chirurgiens-dentistes 	\N	2024-04-04 16:30:00	2024-04-04 17:30:00	\N	\N	3	0	\N	\N
819013	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition France Assos Santé	\N	2024-04-05 15:00:00	2024-04-05 16:00:00	\N	\N	2	0	\N	\N
819014	DELEGATION	AUCUNE	\N	\N	COLTER	Table-ronde relative à la différenciation dans la décentralisation 	\N	2024-04-11 09:00:00	2024-04-11 11:00:00	\N	\N	19	0	\N	\N
819015	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI enseignants	\N	2024-04-03 13:45:00	2024-04-03 15:00:00	\N	\N	5	0	\N	\N
819022	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Marché locatif - CSN	\N	2024-04-03 13:30:00	2024-04-03 14:15:00	\N	\N	0	0	\N	\N
819029	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 9 avril 2024	\N	2024-04-09 17:35:00	2024-04-09 18:15:00	2024-04-09 18:15:57	2024-04-12 13:34:43	11	0	\N	\N
819030	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 11 avril 2024	\N	2024-04-11 09:00:00	2024-04-11 11:20:00	2024-04-11 11:18:27	2024-04-12 13:34:44	14	0	\N	\N
819031	DELEGATION	AUDRAP	\N	\N	206	Place des protéines dans l'alimentation - Audition d'Agriculture cellulaire France	\N	2024-03-28 15:00:00	2024-03-28 16:00:00	\N	\N	1	0	\N	\N
819032	DELEGATION	AUDRAP	\N	\N	206	Place des protéines dans l'alimentation - Audition de Protéines France	\N	2024-03-28 16:30:00	2024-03-28 18:00:00	\N	\N	1	0	\N	\N
786969	GIA	AUCUNE	\N	\N	\N	Assemblée générale	Assemblée générale du groupe d'amitié 	2024-01-16 15:30:00	2024-01-16 16:10:00	\N	\N	23	0	573	\N
804189	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Décarbonation - Audition CIXTEN	Contrôle 2024 - Décarbonation - Audition CIXTEN	2024-02-20 15:00:00	2024-02-20 16:00:00	\N	\N	2	0	\N	\N
804192	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Décarbonation - Audition ADEME	Contrôle 2024 - Décarbonation - Audition ADEME	2024-02-20 16:00:00	2024-02-20 17:00:00	\N	\N	2	0	\N	\N
804195	DELEGATION	AUDRAP	\N	\N	206	Effets indésirables des vaccins covid-19 - Audition de M. Alain Fischer	\N	2024-03-01 09:00:00	2024-03-01 10:05:00	\N	\N	2	0	\N	\N
804196	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - CMN - Audition M. BELAVAL, ancien président du CMN	Contrôle 2024 - CMN - Audition M. BELAVAL, ancien président du CMN	2024-02-20 14:30:00	2024-02-20 15:30:00	\N	\N	2	0	\N	\N
804197	DELEGATION	AUDRAP	\N	\N	206	Effets indésirables des vaccins covid-19 - Audition de M. Jean-François Delfraissy	\N	2024-02-29 14:00:00	2024-02-29 15:15:00	\N	\N	2	0	\N	\N
804200	DELEGATION	AUDRAP	\N	\N	206	Effets indésirables des vaccins covid-19 - Audition de la DGS	\N	2024-03-01 10:05:00	2024-03-01 11:05:00	\N	\N	2	0	\N	\N
804201	DELEGATION	AUDRAP	\N	\N	PROS	IA et Finances publiques - Audition de la DGFiP	\N	2024-02-27 16:30:00	2024-02-27 18:00:00	\N	\N	7	0	\N	\N
804203	DELEGATION	AUDRAP	\N	\N	PROS	IA et Finances publiques - Audition de la CNAF	\N	2024-02-27 18:00:00	2024-02-27 19:00:00	\N	\N	5	0	\N	\N
807242	COM_PERMANENTE	AUDRAP	\N	CAE	\N	atos	MI Atos	2024-03-06 16:30:00	2024-03-06 20:30:00	\N	\N	2	0	\N	\N
807271	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Atos	MI Atos	2024-03-07 15:00:00	2024-03-07 19:00:00	\N	\N	1	0	\N	\N
810288	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition COD3S et CNDEPAH	\N	2024-03-14 09:45:00	2024-03-14 11:00:00	\N	\N	3	0	\N	\N
810294	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Cancers professionnels des sapeurs-pompiers - CIRC	\N	2024-03-14 16:00:00	2024-03-14 16:40:00	\N	\N	3	0	\N	\N
810295	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Cancers professionnels des sapeurs-pompiers - Table ronde Canada	\N	2024-03-14 17:00:00	2024-03-14 17:50:00	\N	\N	3	0	\N	\N
810314	DELEGATION	AUDRAP	\N	\N	PROS	IA et santé - Audition du Dr Alexandre Loupy, lauréat du Prix Inserm Innovation 2023	\N	2024-03-12 15:00:00	2024-03-12 16:00:00	\N	\N	1	0	\N	\N
810315	DELEGATION	AUDRAP	\N	\N	PROS	IA et santé - Audition de la Direction des services numériques de l'APHP	\N	2024-03-12 17:00:00	2024-03-12 18:00:00	\N	\N	2	0	\N	\N
810316	DELEGATION	AUDRAP	\N	\N	PROS	IA et santé - Audition de l'Ordre des médecins	\N	2024-03-13 11:00:00	2024-03-13 12:00:00	\N	\N	2	0	\N	\N
810317	DELEGATION	AUDRAP	\N	\N	PROS	IA et santé - Audition du Pr Bernard Nordlinger	\N	2024-03-13 14:00:00	2024-03-13 15:00:00	\N	\N	2	0	\N	\N
810321	DELEGATION	AUDRAP	\N	\N	PROS	IA et santé - Audition de la FHF	\N	2024-03-12 18:00:00	2024-03-12 19:00:00	\N	\N	2	0	\N	\N
810328	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Jean Bacci	Auditions M. Jean Bacci	2024-03-15 10:00:00	2024-03-15 12:00:00	\N	\N	1	0	\N	\N
810330	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Personnels admin. MEN -Audition DGRH éducation nationale	Contrôle 2024 - Personnels admin. MEN -Audition DGRH éducation nationale	2024-03-14 15:00:00	2024-03-14 16:30:00	\N	\N	1	0	\N	\N
810337	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Personnels admin. MEN - Audition Mme ICARD et M. CHARDIN, DGAFP	Contrôle 2024 - Personnels admin. MEN - Audition Mme ICARD et M. CHARDIN, DGAFP	2024-03-14 16:30:00	2024-03-14 17:30:00	\N	\N	1	0	\N	\N
810339	DELEGATION	AUDRAP	\N	\N	206	Nouveaux développements de l'IA - Audition de Microsoft France	\N	2024-03-13 16:30:00	2024-03-13 17:45:00	\N	\N	1	0	\N	\N
810340	COM_PERMANENTE	DEPLACEMENT	\N	SOCI	\N	Déjeuner à l'ambassade d'Allemagne	Préparation pour le déplacement Allemagne Danemark	2024-03-14 12:00:00	2024-03-14 14:00:00	\N	\N	4	0	\N	\N
810349	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Personnels admin. MEN - Audition Mmes TOMASINI et BUISSON, DEPP	Contrôle 2024 - Personnels admin. MEN - Audition Mmes TOMASINI et BUISSON, DEPP	2024-03-14 17:30:00	2024-03-14 18:15:00	\N	\N	1	0	\N	\N
810350	DELEGATION	AUDRAP	\N	\N	206	Nouveaux développements de l'IA - Audition de LightOn	\N	2024-03-14 10:30:00	2024-03-14 12:45:00	\N	\N	1	0	\N	\N
817146	COM_PERMANENTE	AUTRE	\N	FINC	\N	PPL EDF - 3ème lecture - Amendements de séance	\N	2024-04-03 09:00:00	2024-04-03 09:10:00	\N	\N	41	4	\N	\N
810359	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2024 - CNDA - Déplacement à la CNDA à Montreuil	Contrôle 2024 - CNDA - Déplacement à la CNDA à Montreuil	2024-03-12 13:30:00	2024-03-12 18:00:00	\N	\N	1	0	\N	\N
810363	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur universités européennes	\N	2024-03-11 09:00:00	2024-03-11 10:00:00	\N	\N	2	0	\N	\N
810366	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur universités européennes	\N	2024-03-11 11:00:00	2024-03-11 12:45:00	\N	\N	2	0	\N	\N
810369	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - CNDA - Auditions à la CNDA à Montreuil	Contrôle 2024 - CNDA - Auditions à la CNDA à Montreuil	2024-03-12 14:00:00	2024-03-12 17:30:00	\N	\N	1	0	\N	\N
810371	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - CNDA - Audition association rapporteurs et juges	Contrôle 2024 - CNDA - Audition association rapporteurs et juges	2024-03-13 14:00:00	2024-03-13 15:00:00	\N	\N	1	0	\N	\N
810373	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur universités européennes	\N	2024-03-12 17:00:00	2024-03-12 18:30:00	\N	\N	2	0	\N	\N
810376	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - CNDA - Audition MM. GIRARDOT et BRUSCHINI, Conseil d'état	Contrôle 2024 - CNDA - Audition MM. GIRARDOT et BRUSCHINI, Conseil d'état	2024-03-13 16:30:00	2024-03-13 17:30:00	\N	\N	1	0	\N	\N
810394	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Contrôle 2024 - Charge de la dette - Déplacement Agence France Trésor - Bercy	Contrôle 2024 - Charge de la dette - Déplacement Agence France Trésor - Bercy	2024-03-11 14:00:00	2024-03-11 16:30:00	\N	\N	1	0	\N	\N
810404	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Charge de la dette - Audition Agence France Trésor - Bercy	Contrôle 2024 - Charge de la dette - Audition Agence France Trésor - Bercy	2024-03-11 14:00:00	2024-03-11 16:30:00	\N	\N	1	0	\N	\N
810406	COM_PERMANENTE	AUDRAP	\N	FINC	\N	MI problèmes assurantiels des CT - Audition de Mme BOUQUOT et M. de l'ESTOILE, AMRAE	MI problèmes assurantiels des CT - Audition de Mme BOUQUOT et M. de l'ESTOILE, AMRAE	2024-03-12 14:30:00	2024-03-12 15:30:00	\N	\N	1	0	\N	\N
810409	COM_PERMANENTE	AUDRAP	\N	FINC	\N	MI problèmes assurantiels des CT - Audition de MM. LEVENEUR et CRESSELY, BCT	MI problèmes assurantiels des CT - Audition de MM. LEVENEUR et CRESSELY, Bureau central de tarification	2024-03-12 18:30:00	2024-03-12 19:30:00	\N	\N	1	0	\N	\N
810421	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition SciencesPo	\N	2024-03-20 16:30:00	2024-03-20 17:45:00	2024-03-26 15:11:14	2024-03-26 15:15:44	20	0	\N	\N
810422	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Concessions autoroutes - Audition DG Trésor et FinInfra	Contrôle 2024 - Concessions autoroutes - Audition DG Trésor et FinInfra	2024-03-12 08:30:00	2024-03-12 09:30:00	\N	\N	2	0	\N	\N
810425	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Concessions autoroutes - Audition M. CROZET, économiste transports	Contrôle 2024 - Concessions autoroutes - Audition M. CROZET, économiste transports	2024-03-12 09:30:00	2024-03-12 10:30:00	\N	\N	2	0	\N	\N
810428	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	PJLC Congrès et assemblées de province de la Nouvelle-Calédonie (PJLC)	PJLC Congrès et assemblées de province de la Nouvelle-Calédonie (PJLC)	2024-03-14 19:00:00	2024-03-18 20:00:00	\N	\N	4	0	\N	\N
810429	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Protocoles sociaux DGAC - Audition M. GUILLERMET, DSNA	Contrôle 2024 - Protocoles sociaux DGAC - Audition M. GUILLERMET, DSNA	2024-03-12 11:00:00	2024-03-12 12:15:00	\N	\N	1	0	\N	\N
810435	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL service civique	\N	2024-03-25 16:00:00	2024-03-25 18:00:00	\N	\N	3	0	\N	\N
810436	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL service civique	\N	2024-03-20 14:00:00	2024-03-20 15:00:00	\N	\N	2	0	\N	\N
810437	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Protocoles sociaux DGAC - Audition du BEA	Contrôle 2024 - Protocoles sociaux DGAC - Audition du Bureau d'enquêtes et d'analyses sécurité aviation civile (BEA)	2024-03-12 14:30:00	2024-03-12 15:30:00	\N	\N	1	0	\N	\N
810439	MISSION	AUDRAP	\N	COMP	\N	Table ronde FHP-Fehap-FHF	\N	2024-03-14 14:30:00	2024-03-14 15:45:00	\N	\N	3	0	\N	\N
783026	GIA	AUCUNE	\N	\N	\N	AG	\N	2023-12-13 14:00:00	2023-12-13 14:35:00	\N	\N	9	0	618	\N
783134	BUREAU	AUCUNE	\N	\N	\N	Réunion du Bureau	Réunion du Bureau	2023-12-14 08:35:00	2023-12-14 11:30:00	\N	\N	21	0	\N	\N
783368	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 19/12/2023	\N	2023-12-19 16:35:00	2023-12-19 17:50:00	2023-12-19 18:19:41	2023-12-20 18:10:26	18	0	\N	\N
783369	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 21/12/2023	\N	2023-12-21 09:00:00	2023-12-21 10:00:00	\N	\N	0	0	\N	\N
783370	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 19/12/2023	\N	2023-12-19 16:30:00	2023-12-19 18:00:00	\N	\N	0	0	\N	\N
783371	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 21/12/2023	\N	2023-12-21 09:05:00	2023-12-21 11:05:00	2023-12-21 11:51:18	2023-12-21 17:52:22	9	1	\N	\N
783394	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE 99 - PLF 2024 - Examen rapport NL + Désignation Rapporteur PPL 579 EDF	PLENIERE 99 - PLF 2024 - Examen rapport NL + Désignation Rapporteur PPL 579 EDF	2023-12-19 09:00:00	2023-12-19 09:40:00	2023-12-19 10:12:36	2023-12-20 18:10:17	26	8	\N	\N
783395	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 99	\N	2023-12-19 16:00:00	2023-12-19 16:15:00	\N	\N	0	0	\N	\N
783396	COM_PERMANENTE	AUTRE	\N	CAE	\N	Table ronde	\N	2023-12-20 09:35:00	2023-12-20 12:10:00	2023-12-20 12:29:34	2023-12-20 18:10:20	31	0	\N	\N
783401	COM_ENQUETE	PLENIERE	\N	NARCO	\N	Tables rondes Antilles et journalistes	Tables rondes Antilles et journalistes	2023-12-18 14:00:00	2023-12-18 18:40:00	2023-12-18 18:44:58	2023-12-20 18:13:21	6	0	\N	\N
783402	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Droit à l'image des enfants - PJL Dérives sectaires (amendements)	PPL Droit à l'image des enfants - PJL Dérives sectaires (amendements)	2023-12-19 14:30:00	2023-12-19 14:40:00	2023-12-19 14:50:19	2023-12-20 18:10:18	14	1	\N	\N
783403	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désignations  de rapporteurs - MI Emeutes : table ronde de maires	Désignations  de rapporteurs - MI Emeutes : table ronde de maires	2023-12-20 10:00:00	2023-12-20 11:40:00	2023-12-20 12:19:27	2023-12-20 18:10:23	26	0	\N	\N
783404	COM_ENQUETE	PLENIERE	\N	NARCO	\N	Tables rondes Guyane	Tables rondes Guyane	2023-12-20 16:30:00	2023-12-20 19:30:00	2023-12-20 21:14:25	2023-12-21 17:52:03	9	0	\N	\N
783405	COM_PERMANENTE	AUTRE	\N	LOIS	\N	MCC Agressions subies par les enseignants - Audition d'Eric Dupond-Moretti	MCC Agressions subies par les enseignants - Audition d'Eric Dupond-Moretti	2023-12-20 16:35:00	2023-12-20 17:55:00	2023-12-20 21:10:42	2023-12-21 17:51:50	26	0	\N	\N
787338	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Vapotage - Audition ACT-CNCT-Addictions France	\N	2024-01-16 13:30:00	2024-01-16 14:50:00	\N	\N	1	0	\N	\N
787342	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Vapotage - Audition Aiduce-Fivape	\N	2024-01-16 15:45:00	2024-01-16 16:45:00	\N	\N	1	0	\N	\N
787343	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Vapotage - Audition France vapotage	\N	2024-01-16 16:45:00	2024-01-16 17:55:00	\N	\N	1	0	\N	\N
788070	GIA	AUCUNE	\N	\N	\N	Audition Direction régionale AFD pour le Pacifique	Audition de Mme Valérie Bleitrach, directrice régionale de l'Agence française de développement (AFD) pour le Pacifique	2024-01-17 14:10:00	2024-01-17 14:55:00	\N	\N	4	0	651	\N
787240	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2024-01-17 11:30:00	2024-01-17 12:30:00	2024-01-22 15:57:55	2024-01-22 17:46:25	39	2	\N	\N
794703	DELEGATION	AUCUNE	\N	\N	DSOM	Action de l'Etat : audition de Mme Brigitte GIRARDIN, ancienne ministre de l'outre-mer	\N	2024-02-07 17:05:00	2024-02-07 18:35:00	\N	\N	13	0	\N	\N
794704	DELEGATION	AUTRE	\N	\N	DSOM	Auditions de Maître Patrick Lingibé (CNB) et du Général Peloux (SMA)	\N	2024-02-08 08:30:00	2024-02-08 11:00:00	\N	\N	15	0	\N	\N
794708	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Violences intrafamiliales -  PPL Régime juridique des actions de groupe (amendements)	PPL Violences intrafamiliales -  PPL Régime juridique des actions de groupe (amendements)	2024-02-06 13:45:00	2024-02-06 14:05:00	2024-02-06 15:15:18	2024-02-06 16:36:26	17	8	\N	\N
794711	COM_PERMANENTE	AUTRE	\N	LOIS	\N	MI Emeutes de juin 2023 - Table ronde de réalisateurs	MI Emeutes de juin 2023 - Table ronde de réalisateurs	2024-02-07 11:40:00	2024-02-07 12:35:00	2024-02-07 15:41:24	2024-02-08 12:31:29	13	0	\N	\N
801443	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Justice patrimoniale au sein de la famille	PPL Justice patrimoniale au sein de la famille	2024-02-26 16:00:00	2024-02-26 17:20:00	\N	\N	1	0	\N	\N
807732	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GS Egalim - Ania	GS Egalim - Ania	2024-03-12 14:15:00	2024-03-12 15:00:00	2024-03-12 16:58:35	\N	5	0	\N	\N
807755	ETUDES	AUTRE	\N	\N	\N	CNIV / CNAOC	\N	2024-03-12 13:30:00	2024-03-12 15:00:00	\N	\N	14	0	\N	909
807771	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE 14 - Audition Enquête 58-2 Délivrance titres d'identité	PLENIERE 14 - 58-2 Délivrance titres d'identité	2024-03-12 17:00:00	2024-03-12 19:00:00	2024-03-21 16:45:34	2024-03-21 18:27:32	19	0	\N	\N
807836	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Jean-Yves Roux	\N	2024-03-12 13:30:00	2024-03-12 14:30:00	\N	\N	0	0	\N	\N
807837	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Muséum national histoire naturel et OFB	Muséum national histoire naturel et OFB	2024-03-12 13:30:00	2024-03-12 14:25:00	\N	\N	1	0	\N	\N
807839	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Réunion constitutive 	\N	2024-02-14 12:30:00	2024-02-14 13:15:00	\N	\N	0	0	\N	\N
807893	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Table ronde "Impact économique et héritage des JOP"	\N	2024-03-12 15:00:00	2024-03-12 17:00:00	\N	\N	4	0	\N	\N
807992	DELEGATION	AUTRE	\N	\N	DSOM	Audition de M. Christian Nussbaum, chef de la mission outre-mer de la DGPN	\N	2024-03-14 09:00:00	2024-03-14 10:30:00	\N	\N	11	0	\N	\N
807993	DELEGATION	AUTRE	\N	\N	DSOM	Réunion avec la délégation outre-mer de l'Association des maires de France (AMF)	\N	2024-03-12 18:00:00	2024-03-12 19:30:00	\N	\N	8	0	\N	\N
810037	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Lutte anti drone VIP DAY BA Villacoublay	\N	2024-03-14 13:00:00	2024-03-14 18:00:00	\N	\N	5	0	\N	\N
811074	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	GS ZAN	GS ZAN	2024-02-06 16:00:00	2024-02-06 17:15:00	\N	\N	5	0	\N	\N
811081	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	GS ZAN	GS ZAN	2024-03-12 17:15:00	2024-03-12 19:20:00	\N	\N	4	0	\N	\N
811089	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	GS ZAN	GS ZAN	2024-02-13 16:00:00	2024-02-13 18:30:00	\N	\N	4	0	\N	\N
817712	GIA	AUCUNE	\N	\N	\N	Réunion du groupe sur la formation du personnel médical en Roumanie	\N	2024-04-03 14:00:00	2024-04-03 14:45:00	\N	\N	7	0	605	\N
817989	GIA	AUCUNE	\N	\N	\N	Entretien avec le Groupe d'amitié Ukraine-France de la Rada	Entretien avec le Groupe d'amitié Ukraine-France de la Rada	2024-04-03 14:00:00	2024-04-03 15:00:00	\N	\N	10	0	530	\N
821319	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Intervention des cabinets privés	PPL Intervention des cabinets privés	2024-04-10 16:30:00	2024-04-10 17:20:00	\N	\N	1	0	\N	\N
776030	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion CATDD	\N	2023-12-06 08:41:00	2023-12-06 10:25:00	2023-12-06 14:12:02	2023-12-06 18:26:16	37	1	\N	\N
776268	COM_SPECIALE	AUDRAP	\N	DDADUE23	\N	Audition PJL Ddadue - UAF	Audition PJL Ddadue - UAF	2023-11-30 11:00:00	2023-11-30 11:45:00	\N	\N	3	0	\N	\N
776277	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Easy Jet	\N	2023-11-22 14:00:00	2023-11-22 15:00:00	\N	\N	1	0	\N	\N
776279	COM_SPECIALE	AUDRAP	\N	DDADUE23	\N	Audition PJL Ddadue - DGPR	Audition PJL Ddadue - DGPR	2023-11-30 14:00:00	2023-11-30 14:45:00	\N	\N	2	0	\N	\N
776280	COM_SPECIALE	AUDRAP	\N	DDADUE23	\N	Audition PJL Ddadue - DGEC et DGAC	Audition PJL Ddadue - DGEC et DGAC	2023-11-30 14:45:00	2023-11-30 15:15:00	\N	\N	3	0	\N	\N
776281	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Didier Mandelli	\N	2023-11-23 09:00:00	2023-11-23 10:00:00	\N	\N	1	0	\N	\N
776367	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	réunion ministre JN Barrot	\N	2023-11-29 08:00:00	2023-11-29 09:30:00	\N	\N	3	0	\N	\N
776368	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL restes humains	\N	2023-11-29 14:00:00	2023-11-29 15:00:00	\N	\N	1	0	\N	\N
776369	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	réunion préparation PJL biens culturels	\N	2023-11-29 17:00:00	2023-11-29 18:00:00	\N	\N	4	0	\N	\N
776370	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Restes humains	\N	2023-11-28 16:00:00	2023-11-28 17:00:00	\N	\N	3	0	\N	\N
784038	GIA	AUCUNE	\N	\N	\N	assemblée générale du groupe	\N	2023-12-19 15:00:00	2023-12-19 15:30:00	\N	\N	12	0	613	\N
786673	GIA	AUCUNE	\N	\N	\N	Assemblée générale	Assemblée générame - Désignation des membres du Bureau 	2023-12-13 16:30:00	2023-12-13 17:15:00	\N	\N	8	0	651	\N
789389	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 25 janvier 2024	\N	2024-01-25 08:40:00	2024-01-25 10:45:00	2024-01-25 10:43:34	2024-01-25 18:33:28	14	0	\N	\N
789390	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	MCC Agressions subies par les enseignants - Visite de groupes scolaires d'Oullins	MCC Agressions subies par les enseignants - Visite de groupes scolaires d'Oullins	2024-01-18 10:00:00	2024-01-18 18:00:00	\N	\N	1	0	\N	\N
789409	DELEGATION	AUDRAP	\N	\N	206	Audition du Réseau français des CRPV	\N	2024-01-19 09:00:00	2024-01-19 10:15:00	\N	\N	2	0	\N	\N
789410	DELEGATION	AUDRAP	\N	\N	206	Audition de Mme Crémieux, présidente de la commission technique des vaccinations de la HAS	\N	2024-01-19 10:15:00	2024-01-19 11:20:00	\N	\N	2	0	\N	\N
789415	DELEGATION	AUTRE	\N	\N	DSOM	Action de l'Etat outre-mer : audition du Général Lionel LAVERGNE	\N	2024-01-25 10:00:00	2024-01-25 11:00:00	\N	\N	9	0	\N	\N
807399	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Crise du logement	\N	2024-03-05 16:00:00	2024-03-05 17:00:00	\N	\N	2	0	\N	\N
807407	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Audition GT Arabie saoudite	\N	2024-03-05 14:00:00	2024-03-05 16:00:00	\N	\N	0	0	\N	\N
807408	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Jean-Yves Roux	\N	2024-03-10 10:00:00	2024-03-10 12:00:00	\N	\N	2	0	\N	\N
807411	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition Rachida Dati	\N	2024-03-12 17:30:00	2024-03-12 19:35:00	2024-03-13 09:24:13	2024-03-13 16:00:43	35	0	\N	\N
807570	COM_ENQUETE	PLENIERE	\N	TOTA	\N	Réunion CE TE	\N	2024-03-18 16:45:00	2024-03-18 19:10:00	2024-03-19 09:11:22	2024-03-19 17:29:22	7	0	\N	\N
807635	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI IVG - Table ronde des associations	\N	2024-03-12 14:00:00	2024-03-12 15:00:00	\N	\N	3	0	\N	\N
794710	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désignations - PPL Sûreté transports - Consultations juridiques - Maîtrise ouvrage	Désignations - PPL Sûreté transports - Consultations juridiques - Maîtrise ouvrage	2024-02-07 09:10:00	2024-02-07 11:30:00	2024-02-07 15:41:12	2024-02-08 12:31:24	39	7	\N	\N
810441	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Protocoles sociaux DGAC - Audition de Mme PILLAN, DGAC	Contrôle 2024 - Protocoles sociaux DGAC - Audition de Mme PILLAN, DGAC	2024-03-12 15:30:00	2024-03-12 16:45:00	\N	\N	1	0	\N	\N
810443	MISSION	AUDRAP	\N	COMP	\N	Audition ONSSF	\N	2024-03-14 15:45:00	2024-03-14 16:20:00	\N	\N	2	0	\N	\N
810444	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Protocoles sociaux DGAC - Audition de USAC-CGT	Contrôle 2024 - Protocoles sociaux DGAC - Audition de USAC-CGT	2024-03-12 16:45:00	2024-03-12 17:45:00	\N	\N	1	0	\N	\N
810446	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Concessions autoroutes - Audition M. NOURRY, Eiffage	Contrôle 2024 - Concessions autoroutes - Audition M. NOURRY, Concessions autoroutières Eiffage	2024-03-13 08:30:00	2024-03-13 09:45:00	\N	\N	2	0	\N	\N
810449	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Protocoles sociaux DGAC - Audition du SNCTA	Contrôle 2024 - Protocoles sociaux DGAC - Audition du Syndicat national des contrôleurs du trafic aérien (SNCTA)	2024-03-13 18:00:00	2024-03-13 19:00:00	\N	\N	1	0	\N	\N
810451	MISSION	AUDRAP	\N	COMP	\N	Table ronde pharmaciens	\N	2024-03-14 17:00:00	2024-03-14 18:00:00	\N	\N	2	0	\N	\N
810461	COM_PERMANENTE	AUDRAP	\N	FINC	\N	MI Problèmes assurantiels des CT - Auditions Mairie de Valenton	MI Problèmes assurantiels des CT - Auditions Mairie de Valenton	2024-03-01 08:45:00	2024-03-01 09:30:00	\N	\N	1	0	\N	\N
810468	COM_PERMANENTE	AUDRAP	\N	FINC	\N	MI Problèmes assurantiels des CT - Table-ronde élus Val-de-Marne	MI Problèmes assurantiels des CT - Table-ronde élus Val-de-Marne	2024-03-01 10:00:00	2024-03-01 12:30:00	\N	\N	1	0	\N	\N
810470	COM_PERMANENTE	AUDRAP	\N	FINC	\N	MI Problèmes assurantiels des CT - Table-ronde élus Hauts-de-Seine	MI Problèmes assurantiels des CT - Table-ronde élus Hauts-de-Seine	2024-03-01 14:00:00	2024-03-01 16:30:00	\N	\N	1	0	\N	\N
810472	COM_PERMANENTE	AUDRAP	\N	FINC	\N	MI Problèmes assurantiels des CT - Audition Direction affaires juridiques (DAJ)	MI Problèmes assurantiels des CT - Audition MM. ARNOUX et DELALOY, Direction affaires juridiques (DAJ)	2024-03-06 20:00:00	2024-03-06 21:00:00	\N	\N	1	0	\N	\N
810474	COM_PERMANENTE	AUDRAP	\N	FINC	\N	MI Problèmes assurantiels des CT - Audition de la DGCL	MI Problèmes assurantiels des CT - Audition de MM. FAUCONNIER et GENESLAY, DGCL	2024-03-07 09:30:00	2024-03-07 10:30:00	\N	\N	1	0	\N	\N
810476	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition rapporteur	\N	2024-03-13 16:30:00	2024-03-13 18:00:00	\N	\N	3	0	\N	\N
810478	MISSION	AUDRAP	\N	COMP	\N	Table ronde médecins	\N	2024-03-15 10:30:00	2024-03-15 12:00:00	\N	\N	3	0	\N	\N
810497	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL255 Convention fiscale Luxembourg - Table-ronde	PJL255 Convention fiscale Luxembourg - Table-ronde	2024-02-28 11:00:00	2024-02-28 12:00:00	\N	\N	1	0	\N	\N
810498	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PJL 283 - Convention fiscale Moldavie - Table-Ronde	PJL 283 - Convention fiscale Moldavie - Table-Ronde	2024-02-29 15:00:00	2024-02-29 16:00:00	\N	\N	1	0	\N	\N
810502	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 2024 - APD Aide multilatérale - Réunion de cadrage Cour des comptes	58-2 2024 - APD Aide multilatérale - Réunion de cadrage Cour des comptes	2024-03-06 08:00:00	2024-03-06 09:00:00	\N	\N	2	0	\N	\N
810541	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GS Tourisme	GS Tourisme	2024-03-06 13:15:00	2024-03-06 15:00:00	\N	\N	8	0	\N	\N
810566	BUREAU	AUCUNE	\N	\N	\N	Délégation en charge du travail parlementaire	Délégation en charge du travail parlementaire	2024-03-13 13:45:00	2024-03-13 14:45:00	\N	\N	2	0	\N	\N
811063	BUREAU	AUCUNE	\N	\N	\N	Délégation en charge du travail parlementaire	Délégation en charge du travail parlementaire	2024-03-19 14:00:00	2024-03-19 15:00:00	\N	\N	2	0	\N	\N
811067	BUREAU	AUCUNE	\N	\N	\N	Délégation en charge du travail parlementaire	Délégation en charge du travail parlementaire	2024-03-19 15:45:00	2024-03-19 16:15:00	\N	\N	2	0	\N	\N
811095	GIA	AUCUNE	\N	\N	\N	Rencontre avec S.E.M. Gilles Pécout, ambassadeur de France en Autriche	Rencontre avec S.E.M. Gilles Pécout, ambassadeur de France en Autriche	2024-03-13 19:30:00	2024-03-13 20:30:00	\N	\N	3	0	579	\N
811748	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GS ZAN	GS ZAN	2024-03-19 16:10:00	2024-03-19 18:25:00	\N	\N	3	0	\N	\N
811760	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	GS ZAN	GS ZAN	2024-03-19 16:10:00	2024-03-19 18:25:00	\N	\N	3	0	\N	\N
813417	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Crise du logement	\N	2024-03-26 08:45:00	2024-03-26 10:00:00	\N	\N	2	0	\N	\N
813444	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Examen des amendements sur la PPL APD	\N	2024-03-26 14:00:00	2024-03-26 14:30:00	2024-03-29 09:44:27	2024-03-29 15:41:13	28	14	\N	\N
815460	GIA	AUCUNE	\N	\N	\N	Projection du documentaire 20 jours à Marioupol	Projection du documentaire 20 jours à Marioupol	2024-03-26 18:00:00	2024-03-26 20:00:00	\N	\N	5	0	530	\N
815825	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition SNGIE	\N	2024-04-05 09:00:00	2024-04-05 10:00:00	\N	\N	2	0	\N	\N
815826	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition FNAAS	\N	2024-04-05 10:00:00	2024-04-05 11:00:00	\N	\N	3	0	\N	\N
782561	GIA	AUCUNE	\N	\N	\N	Assemblée générale	Assemblée générale constitutive du groupe d'amitié	2023-12-13 14:15:00	2023-12-13 14:50:00	\N	\N	8	0	594	\N
782595	GIA	AUCUNE	\N	\N	\N	assemblée générale du groupe	\N	2023-12-13 17:30:00	2023-12-13 18:00:00	\N	\N	4	0	634	\N
782652	GIA	AUCUNE	\N	\N	\N	Assemblée générale	Renouvellement du bureau et assemblée générale 	2023-12-12 13:45:00	2023-12-13 14:30:00	\N	\N	12	0	602	\N
782679	GIA	AUCUNE	\N	\N	\N	Rencontre Mme Michèle Boisvert	Rencontre avec la délégué générale du Québec à Paris	2023-12-13 08:30:00	2023-12-13 09:30:00	\N	\N	10	0	602	\N
783337	GIA	AUCUNE	\N	\N	\N	Entretien avec S.E. M. Carmelo NVONO-NCA, ambassadeur de Guinée équatoriale à Paris	Entretien avec S.E. M. Carmelo NVONO-NCA, ambassadeur de Guinée équatoriale à Paris	2023-12-13 16:30:00	2023-12-13 18:00:00	\N	\N	2	0	572	\N
783347	GIA	AUCUNE	\N	\N	\N	Entretien avec M. Marceau Ferrand, Rédacteur Congo du MEAE	Entretien avec M. Marceau Ferrand, Rédacteur Congo du MEAE	2023-12-12 14:10:00	2023-12-12 14:55:00	\N	\N	0	0	572	\N
783348	GIA	AUCUNE	\N	\N	\N	Réception offerte pour le centenaire de la Chambre de commerce franco-finlandaise	Réception offerte pour le centenaire de la Chambre de commerce franco-finlandaise	2023-12-14 18:20:00	2023-12-14 19:40:00	\N	\N	3	0	640	\N
786606	COM_ENQUETE	PLENIERE	\N	TOTA	\N	Réunion CE TotalEnergies	\N	2024-01-17 14:00:00	2024-01-17 14:45:00	2024-01-17 15:23:20	2024-01-17 18:05:08	14	0	\N	\N
786609	DELEGATION	AUDRAP	\N	\N	206	Audition de l'ANSM	\N	2024-01-12 09:00:00	2024-01-12 10:15:00	\N	\N	2	0	\N	\N
786610	DELEGATION	AUDRAP	\N	\N	206	Audition de M. Mahmoud Zureik, directeur du groupement d'intérêt spécifique EPI-PHARE	\N	2024-01-12 10:15:00	2024-01-12 11:15:00	\N	\N	2	0	\N	\N
786625	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE 2 - Audition M. VILLEROY de GALHAU, gouverneur Banque de France	PLENIERE 2 - Audition M. VILLEROY de GALHAU, gouverneur Banque de France	2024-01-17 10:30:00	2024-01-17 12:15:00	2024-02-02 10:56:49	2024-02-02 11:10:30	31	5	\N	\N
786627	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2024-01-17 08:30:00	2024-01-17 12:25:00	2024-01-17 14:58:02	2024-01-17 18:05:04	46	0	\N	\N
786629	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Décompte annuel personnes sans abri - Aud° délég. interminis. prévention pauvreté	\N	2024-01-12 16:00:00	2024-01-12 16:45:00	\N	\N	1	0	\N	\N
787348	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe	\N	2024-01-16 16:30:00	2024-01-16 17:30:00	\N	\N	8	0	571	\N
787514	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe	Assemblée générale du groupe	2024-01-17 08:30:00	2024-01-17 08:30:00	\N	\N	18	0	604	\N
788696	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition de Thierry Breton	\N	2024-01-18 09:20:00	2024-01-18 11:00:00	2024-01-18 17:05:51	2024-01-18 18:01:18	47	0	\N	\N
788706	COM_ENQUETE	DEPLACEMENT	\N	NARCO	\N	Déplacement au Havre	\N	2024-01-18 08:00:00	2024-01-18 22:00:00	\N	\N	4	0	\N	\N
788710	COM_ENQUETE	DEPLACEMENT	\N	NARCO	\N	Déplacement en Seine-Saint-Denis	\N	2023-12-21 08:00:00	2023-12-21 22:00:00	\N	\N	5	0	\N	\N
788835	DELEGATION	AUCUNE	\N	\N	206	Audition de l'Agence de la biomédecine	\N	2024-01-18 09:30:00	2024-01-18 11:10:00	\N	\N	8	0	\N	\N
818967	GIA	AUCUNE	\N	\N	\N	Entretien avec SE M. Fahad AL-RUWAILY, Ambassadeur d'Arabie Saoudite	Entretien avec l'Ambassadeur d'Arabie Saoudite 	2024-01-24 08:30:00	2024-01-24 09:45:00	\N	\N	9	0	661	\N
777427	MISSION	AUDRAP	\N	BIOCARBU	\N	Syndicat national des producteurs d'alcool agricole (SNPAA) 	Syndicat national des producteurs d'alcool agricole (SNPAA)	2023-04-27 15:30:00	2023-04-27 16:30:00	\N	\N	1	0	\N	\N
777432	MISSION	AUDRAP	\N	BIOCARBU	\N	Voies navigables de France (VNF)	Voies navigables de France (VNF)	2023-04-27 16:30:00	2023-04-27 17:30:00	\N	\N	1	0	\N	\N
787682	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ambassadrice de la République de Moldavie	Entretien avec S.E. Mme Corina Calugaru, ambassadrice de la République de Moldavie	2024-01-17 13:00:00	2024-01-17 14:00:00	\N	\N	1	0	851	\N
794660	DELEGATION	AUDRAP	\N	\N	PROS	IA et santé - Audition du Health Data Hub	\N	2024-01-30 18:30:00	2024-01-30 19:30:00	\N	\N	2	0	\N	\N
794661	DELEGATION	AUDRAP	\N	\N	PROS	IA et santé - Audition de France Biotech	\N	2024-01-31 11:00:00	2024-01-31 12:00:00	\N	\N	2	0	\N	\N
794662	DELEGATION	AUDRAP	\N	\N	PROS	IA et santé - Audition de Doctolib	\N	2024-01-31 14:00:00	2024-01-31 14:50:00	\N	\N	2	0	\N	\N
794663	DELEGATION	AUDRAP	\N	\N	PROS	IA et santé - Audition du Pr Guillaume Assié	\N	2024-01-31 16:30:00	2024-01-31 18:00:00	\N	\N	1	0	\N	\N
794679	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	PJLC Liberté de recourir à l'IVG - Planning familial - Centr	PJLC Liberté de recourir à l'IVG - Planning familial - Centr	2024-02-01 09:30:00	2024-02-01 11:30:00	\N	\N	1	0	\N	\N
794695	DELEGATION	AUTRE	\N	\N	ENTREPRISES	Examen du rapport relatif à la mission flash sur le foncier économique	\N	2024-01-31 12:30:00	2024-01-31 14:00:00	\N	\N	7	0	\N	\N
794714	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ambassadrice du Kazakhstan	PDJ de travail à l'invitation de l'ambassadrice à l'ambassade	2024-01-31 08:00:00	2024-01-31 09:00:00	\N	\N	6	0	556	\N
794721	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe d'amitié France-Afrique australe	Définition du programme de travail 	2024-01-31 14:30:00	2024-01-31 14:50:00	\N	\N	10	0	646	\N
794732	GIA	AUCUNE	\N	\N	\N	Entretien de travail	Préparation des activités du groupe et programme de travail 	2024-02-01 15:00:00	2024-02-01 15:40:00	\N	\N	2	0	641	CHRETORIENT
794850	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Lamassoure et Cinéma 	\N	2024-02-07 09:00:00	2024-02-07 10:40:00	2024-02-07 11:53:32	2024-02-08 12:31:23	39	18	\N	\N
794853	DELEGATION	AUDRAP	\N	\N	211	Audition rapporteures Familles monoparentales	\N	2024-02-09 16:30:00	2024-02-09 17:30:00	\N	\N	4	0	\N	\N
794862	COM_ENQUETE	PLENIERE	\N	TOTA	\N	Audition CE TE	\N	2024-02-08 10:30:00	2024-02-08 12:30:00	2024-02-08 12:57:51	2024-02-09 17:33:18	11	0	\N	\N
794863	COM_ENQUETE	PLENIERE	\N	TOTA	\N	Audition CE TE	\N	2024-02-05 17:00:00	2024-02-05 18:15:00	2024-02-06 10:25:41	2024-02-06 16:36:37	4	0	\N	\N
801085	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	DPR	DPR	2024-02-15 09:00:00	2024-02-15 13:30:00	\N	\N	7	0	\N	\N
808194	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Auditon UMIH-CNBPF-FCD 	\N	2024-03-26 17:45:00	2024-03-26 18:45:00	\N	\N	2	0	\N	\N
808227	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition FEP et Fesp	\N	2024-03-26 18:45:00	2024-03-26 19:45:00	\N	\N	2	0	\N	\N
808399	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition rapporteur	\N	2024-03-12 14:30:00	2024-03-12 15:00:00	\N	\N	1	0	\N	\N
808401	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition rapporteur P. TABAROT	\N	2024-03-12 15:00:00	2024-03-12 15:30:00	\N	\N	1	0	\N	\N
808403	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Île-de-France Mobilités - Syndicat des transports d'Île-de-France	\N	2024-03-12 17:00:00	2024-03-12 17:35:00	\N	\N	4	0	\N	\N
808530	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Table ronde GS ZAN	\N	2024-03-12 16:15:00	2024-03-12 19:20:00	\N	\N	0	0	\N	\N
808584	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Audition	\N	2024-03-13 14:00:00	2024-03-13 15:00:00	\N	\N	0	0	\N	\N
808844	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI financiarisation de la santé - Académies	\N	2024-03-13 14:00:00	2024-03-13 15:00:00	\N	\N	4	0	\N	\N
808856	ETUDES	AUTRE	\N	\N	\N	GE Festivals Table ronde situation pendant les JOP	\N	2024-03-13 13:30:00	2024-03-13 15:00:00	\N	\N	9	0	\N	966
808866	ETUDES	AUTRE	\N	\N	\N	GE Handicap - Audition F. Khattabi, ministre	\N	2024-03-13 14:00:00	2024-03-13 15:00:00	\N	\N	21	0	\N	1014
809335	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GS Egalim - Médiateur des relations commerciales agricoles	GS Egalim - Médiateur des relations commerciales agricoles	2024-03-12 17:30:00	2024-03-12 18:30:00	\N	\N	3	0	\N	\N
809348	ETUDES	AUDRAP	\N	\N	\N	Visite CAO St-Denis	\N	2024-03-14 10:00:00	2024-03-14 11:30:00	\N	\N	6	0	\N	934
809359	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 21 mars 2024	\N	2024-03-21 09:00:00	2024-03-21 12:30:00	2024-03-26 15:26:15	2024-03-26 15:28:25	19	0	\N	\N
810089	GIA	AUCUNE	\N	\N	\N	Visite de parlementaires vietnamiens	visite du groupe Vietnam-France et de la présidente de la commission des affaires sociales du parlement vietnamien	2024-01-23 14:00:00	2024-01-23 15:30:00	\N	\N	1	0	626	\N
794694	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion CATDD	\N	2024-02-07 09:00:00	2024-02-07 10:10:00	2024-02-07 14:00:17	2024-02-08 12:31:22	43	6	\N	\N
794852	COM_PERMANENTE	AUTRE	\N	AFCL	\N	PPL filière cinématographique en France	\N	2024-02-07 10:40:00	2024-02-07 11:15:00	2024-02-07 11:53:18	2024-02-08 12:31:28	39	18	\N	\N
794857	COM_PERMANENTE	AUTRE	\N	CAE	\N	Examen des amendements de séance PJL Sûreté nucléaire	\N	2024-02-07 09:00:00	2024-02-07 09:15:00	2024-02-08 16:46:14	2024-02-09 17:33:09	45	2	\N	\N
794860	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2024-02-14 11:10:00	2024-02-14 11:30:00	2024-02-22 10:20:58	2024-02-22 14:28:07	40	0	\N	\N
810091	GIA	AUCUNE	\N	\N	\N	AG	Assemblée générale reconstitutive	2024-02-07 17:30:00	2024-02-07 18:30:00	\N	\N	8	0	626	\N
810100	GIA	AUCUNE	\N	\N	\N	Rencontre avec l'ambassadeur du Vietnam	Rencontre avec l'ambassadeur du Vietnam	2024-03-13 12:30:00	2024-03-13 14:30:00	\N	\N	1	0	626	\N
810123	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJl CETA	PJL CETA	2024-03-05 10:00:00	2024-03-05 11:00:00	\N	\N	1	0	\N	\N
810126	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJl CETA	PJL CETA	2024-03-05 15:00:00	2024-03-05 16:00:00	\N	\N	1	0	\N	\N
810128	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJl CETA	PJL CETA	2024-03-06 14:00:00	2024-03-06 15:00:00	\N	\N	1	0	\N	\N
810130	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PJl CETA	PJL CETA	2024-03-08 10:30:00	2024-03-08 11:30:00	\N	\N	1	0	\N	\N
811159	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI financiarisation de la santé - Ordres paramédicaux	\N	2024-03-19 15:00:00	2024-03-19 16:00:00	\N	\N	3	0	\N	\N
811166	COM_ENQUETE	DEPLACEMENT	\N	NARCO	\N	Déplacement à Anvers	Déplacement à Anvers	2024-03-20 06:30:00	2024-03-20 20:30:00	\N	\N	2	0	\N	\N
811174	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI financiarisation de la santé - Ordres médicaux	\N	2024-03-19 16:00:00	2024-03-19 17:15:00	\N	\N	3	0	\N	\N
811203	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Abrogation réforme des retraites - Audition M. Zemmour	\N	2024-03-19 16:30:00	2024-03-19 17:15:00	\N	\N	2	0	\N	\N
811214	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Abrogation réforme des retraites - Audition Cnav	\N	2024-03-19 17:30:00	2024-03-19 18:15:00	\N	\N	1	0	\N	\N
811218	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Abrogation réforme des retraites - Audition Agirc-Arrco	\N	2024-03-19 18:15:00	2024-03-19 19:00:00	\N	\N	1	0	\N	\N
811224	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI IVG - Représentants des sages-femmes	\N	2024-03-19 18:00:00	2024-03-19 19:00:00	\N	\N	3	0	\N	\N
815836	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition commune d'associations de famille de résidents	\N	2024-04-05 16:00:00	2024-04-05 17:00:00	\N	\N	2	0	\N	\N
815870	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Lutte contre les dérives sectaires (amendements)	PJL Lutte contre les dérives sectaires (amendements)	2024-04-02 14:15:00	2024-04-02 14:20:00	2024-04-02 16:05:22	2024-04-02 17:43:22	11	10	\N	\N
815873	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Jean-Yves Roux PPL Prolifération du frelon asiatique	Auditions M. Jean-Yves Roux PPL Prolifération du frelon asiatique	2024-03-28 09:15:00	2024-03-28 10:45:00	\N	\N	1	0	\N	\N
815896	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Direction générale du trésor	\N	2024-04-02 16:30:00	2024-04-02 17:15:00	\N	\N	2	0	\N	\N
815897	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Table ronde des DREETS	\N	2024-04-02 18:30:00	2024-04-02 19:30:00	\N	\N	2	0	\N	\N
786213	GIA	AUCUNE	\N	\N	\N	Rencontre avec les groupes France-Haïti et France-République dominicaine à l'Assemblée	Rencontre avec les présidents des groupes France-Haïti et France-République dominicaine à l'assemblée nationale	2023-12-04 12:30:00	2023-12-04 14:00:00	\N	\N	1	0	642	\N
791318	DELEGATION	AUCUNE	\N	\N	ENTREPRISES	Table ronde "Défis de l'entreprise : le regard des économistes"	\N	2024-01-25 08:00:00	2024-01-25 10:00:00	\N	\N	16	0	\N	\N
791365	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2024-01-25 10:30:00	2024-01-25 10:40:00	2024-01-25 11:13:17	2024-01-25 18:33:19	11	0	\N	\N
791848	ETUDES	AUTRE	\N	\N	\N	GE Numérique	\N	2024-01-30 09:30:00	2024-01-30 10:30:00	\N	\N	18	0	\N	1008
797802	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de M. Jean-Pierre Filiu 	Audition de M. Jean-Pierre Filiu 	2024-02-14 10:40:00	2024-02-14 11:15:00	2024-02-14 11:45:40	2024-02-14 17:42:24	41	3	\N	\N
801132	DELEGATION	AUCUNE	\N	\N	211	Audition de Judith Godrèche, artiste interprète, scénariste, réalisatrice	\N	2024-02-29 09:10:00	2024-02-29 11:00:00	\N	\N	20	0	\N	\N
801144	COM_ENQUETE	PLENIERE	\N	NARCO	\N	Auditions de Roberto Saviano et Emile "Milou" Diaz	Auditions de Roberto Saviano et Emile "Milou" Diaz	2024-02-26 14:00:00	2024-02-26 16:35:00	2024-02-27 13:36:08	2024-02-27 15:17:35	5	0	\N	\N
801145	COM_ENQUETE	PLENIERE	\N	NARCO	\N	Audition de la Fédération bancaire française	Audition de la Fédération bancaire française	2024-02-27 08:35:00	2024-02-27 09:40:00	2024-02-27 09:59:03	2024-02-27 15:18:34	6	0	\N	\N
801146	COM_ENQUETE	PLENIERE	\N	NARCO	\N	Table ronde d'associations de maires ruraux	Table ronde d'associations de maires ruraux	2024-02-29 10:35:00	2024-02-29 12:00:00	2024-02-29 12:01:09	2024-02-29 14:34:29	6	0	\N	\N
801147	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 28 février	\N	2024-02-28 16:30:00	2024-02-28 18:00:00	2024-02-28 18:03:23	2024-02-28 18:25:43	15	0	\N	\N
801148	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 29 février	\N	2024-02-29 09:30:00	2024-02-29 11:00:00	\N	\N	0	0	\N	\N
801149	DELEGATION	AUCUNE	\N	\N	206	Audition publique sur la protection de la biodiversité marine en haute mer	\N	2024-02-29 09:10:00	2024-02-29 12:10:00	\N	\N	10	0	\N	\N
802357	COM_ENQUETE	AUTRE	\N	TOTA	\N	Auditions CE TE	\N	2024-03-07 10:30:00	2024-03-07 12:50:00	2024-03-21 19:10:03	2024-03-22 09:58:16	14	0	\N	\N
802358	COM_ENQUETE	AUTRE	\N	TOTA	\N	Auditions CE TE	\N	2024-03-04 16:00:00	2024-03-04 19:30:00	\N	\N	0	0	\N	\N
802368	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Table ronde "organisation des transports"	\N	2024-02-27 18:00:00	2024-02-27 20:15:00	\N	\N	5	0	\N	\N
803410	ETUDES	AUTRE	\N	\N	\N	Réunion constitutive	Réunion constitutive	2024-02-28 14:00:00	2024-02-28 14:45:00	\N	\N	14	0	\N	908
810647	MECSS	AUDRAP	\N	\N	MECSS	MI Fiscalité comportementale - Audition de Santé Publique France	\N	2024-03-15 17:00:00	2024-03-15 18:00:00	\N	\N	3	0	\N	\N
810720	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GS ZAN - Table ronde d'élus locaux	GS ZAN - Table ronde d'élus locaux	2024-02-13 16:00:00	2024-02-13 18:30:00	\N	\N	4	0	\N	\N
810731	COM_PERMANENTE	GROUPE_TRAVAIL	\N	FINC	\N	GS ZAN - Tables rondes	GS ZAN - Tables rondes	2024-03-12 16:15:00	2024-03-12 19:20:00	\N	\N	4	0	\N	\N
810736	COM_PERMANENTE	AUTRE	\N	AFCL	\N	PPL jardins d'enfants	\N	2024-03-19 14:00:00	2024-03-19 14:02:00	2024-03-19 16:07:38	2024-03-19 17:33:33	8	5	\N	\N
810745	MISSION	AUCUNE	\N	PERI	\N	PLENIERE - 1	\N	2024-03-19 14:00:00	2024-03-19 15:15:00	2024-03-19 15:12:25	2024-03-19 17:30:03	11	0	\N	\N
815872	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Assainissement cadastral et résorption du désordre de la propriété (rapport)	PPL Assainissement cadastral et résorption du désordre de la propriété (rapport)	2024-04-03 10:00:00	2024-04-03 10:30:00	2024-04-03 10:50:47	2024-04-03 16:55:39	35	18	\N	\N
797803	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Examen de deux conventions internationales	Examen de deux conventions internationales	2024-02-14 09:15:00	2024-02-14 09:40:00	2024-02-14 11:47:00	2024-02-14 17:52:47	41	3	\N	\N
810779	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE 16 - Auditions 58-2 crédits exceptionnels à la culture	PLENIERE 16 - Auditions 58-2 crédits exceptionnels à la culture	2024-03-20 09:05:00	2024-03-20 11:45:00	2024-03-22 14:14:15	2024-03-22 16:35:42	32	0	\N	\N
770429	COM_EURO	AUDRAP	\N	AFEU	\N	Audition lutte contre la corruption	\N	2023-11-09 11:00:00	2023-11-09 12:00:00	\N	\N	3	0	\N	\N
770523	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audition P105	\N	2023-11-14 17:30:00	2023-11-14 18:30:00	\N	\N	0	0	\N	\N
770533	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audition P105	\N	2023-11-15 16:30:00	2023-11-15 17:30:00	\N	\N	0	0	\N	\N
770552	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Justice - Audition Direction de l'administration pénitentiaire	PLF pour 2024 - Justice - Audition Direction de l'administration pénitentiaire	2023-11-16 17:00:00	2023-11-16 18:00:00	\N	\N	1	0	\N	\N
770566	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Culture - Audition MM. MUNIN et HISTA, DG2TDC	PLF pour 2024 - Culture - Audition MM. MUNIN et HISTA, DG2TDC	2023-11-15 14:00:00	2023-11-15 15:00:00	\N	\N	1	0	\N	\N
770569	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 2023 Crédits exceptionnels culture - Audition de la Cour des comptes	58-2 2023 Crédits exceptionnels culture - Audition de la Cour des comptes	2023-11-15 16:45:00	2023-11-15 18:00:00	\N	\N	2	0	\N	\N
770598	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Audition de Mme MALECAZE-DOUBLET et M. VIEL et BOURGUEIL, PMU	Audition de Mme MALECAZE-DOUBLET et M. VIEL et BOURGUEIL, PMU	2023-11-15 08:00:00	2023-11-15 08:45:00	\N	\N	1	0	\N	\N
770601	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Travail et emploi - Audition Territoire zéro chômeur LD	PLF pour 2024 - Travail et emploi - Audition Association Territoire zéro chômeur longue durée	2023-11-15 14:00:00	2023-11-15 15:00:00	\N	\N	2	0	\N	\N
770604	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Cohésion territoires - Audition Mme PREBAY et M. BARYLA, AirBnB	PLF pour 2024 - Cohésion territoires - Audition Mme PREBAY et M. BARYLA, AirBnB	2023-11-14 16:00:00	2023-11-14 16:45:00	\N	\N	1	0	\N	\N
770606	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2024 - Cohésion territoires - Audition Direction habitat urbanisme et paysages	PLF pour 2024 - Cohésion territoires - Audition de la Direction de l'habitat, de l' urbanisme et des paysages	2023-11-14 16:45:00	2023-11-14 18:00:00	\N	\N	1	0	\N	\N
775552	COM_EURO	AUDRAP	\N	AFEU	\N	Auditions Nouvelles techniques génomiques	Auditions Nouvelles techniques génomiques	2023-11-30 10:30:00	2023-11-30 12:00:00	\N	\N	3	0	\N	\N
775553	COM_EURO	AUDRAP	\N	AFEU	\N	Auditions nouvelles techniques génomiques	Auditions nouvelles techniques génomiques	2023-11-30 13:30:00	2023-11-30 14:30:00	\N	\N	3	0	\N	\N
775554	COM_EURO	AUDRAP	\N	AFEU	\N	Auditions Nouvelles techniques génomiques	Auditions Nouvelles techniques génomiques	2023-12-07 12:15:00	2023-12-07 13:15:00	\N	\N	3	0	\N	\N
775581	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur PPL Droits de l'enfant	Audition rapporteur PPL Droits de l'enfant	2023-11-21 09:15:00	2023-11-21 10:00:00	\N	\N	2	0	\N	\N
775586	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions rapporteur PPL Droits de l'enfant	Auditions rapporteur PPL Droits de l'enfant	2023-11-28 14:10:00	2023-11-28 15:10:00	\N	\N	3	0	\N	\N
775593	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur PPL Droits de l'enfant	Audition rapporteur PPL Droits de l'enfant	2023-11-28 16:00:00	2023-11-28 17:40:00	\N	\N	2	0	\N	\N
775597	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions rapporteur PPL Droits de l'enfant	Auditions rapporteur PPL Droits de l'enfant	2023-11-28 19:00:00	2023-11-28 21:00:00	\N	\N	1	0	\N	\N
775600	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur PPL Droits de l'enfant - AFMJF et AMFJC	Audition rapporteur PPL Droits de l'enfant	2023-11-29 08:00:00	2023-11-29 08:55:00	\N	\N	3	0	\N	\N
775604	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Auditions rapporteur - PPL Droits de l'enfant  - DACS	Auditions rapporteur - PPL Droits de l'enfant  - DACS	2023-11-29 08:55:00	2023-11-29 09:40:00	\N	\N	1	0	\N	\N
775607	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition organisations syndicales	\N	2023-11-28 17:00:00	2023-11-28 18:00:00	\N	\N	2	0	\N	\N
775610	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE 91 - PLF pour 2024 - Examen amdts mission Sécurités + art.63 - Motions et amdts	PLENIERE 91 - PLF pour 2024 - Examen amdts mission Sécurités + art.63 - Motions et amdts séance	2023-11-30 11:30:00	2023-11-30 12:05:00	2023-12-06 14:48:14	2023-12-06 18:22:49	30	7	\N	\N
775639	COM_SPECIALE	AUDRAP	\N	DDADUE23	\N	Auditions PJL Ddadue	Auditions PJL Ddadue	2023-11-24 14:00:00	2023-11-24 15:00:00	\N	\N	3	0	\N	\N
775646	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur	MI Emeutes	2023-11-29 16:30:00	2023-11-29 17:30:00	\N	\N	3	0	\N	\N
775654	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Erasmus de l'apprentissage - Audition Euro App Mobility 	\N	2023-11-28 14:30:00	2023-11-28 16:00:00	\N	\N	3	0	\N	\N
775655	COM_ENQUETE	PLENIERE	\N	NARCO	\N	Audition de la Junalco	Audition de la Junalco	2023-12-07 10:30:00	2023-12-07 11:45:00	2023-12-07 11:47:50	2023-12-07 17:29:50	8	0	\N	\N
775656	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Erasmus de l'apprentissage - Audition S. Maillard, député, auteur de la PPL 	\N	2023-11-28 17:30:00	2023-11-28 18:30:00	\N	\N	1	0	\N	\N
778865	MECSS	AUCUNE	\N	\N	MECSS	Réunion plénière	\N	2023-12-12 17:00:00	2023-12-12 17:45:00	2023-12-12 17:43:56	2023-12-12 18:15:01	12	0	\N	\N
779087	DELEGATION	AUTRE	\N	\N	DSOM	Adaptation des modes d'action de l'Etat : audition Conseil d'Etat	\N	2023-12-12 18:00:00	2023-12-12 20:00:00	\N	\N	16	0	\N	\N
779088	DELEGATION	AUTRE	\N	\N	DSOM	Coopération et intégration régionales : audition de M. Jean-Paul Guihaumé	\N	2023-12-14 09:30:00	2023-12-14 11:00:00	\N	\N	11	0	\N	\N
779254	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 13 décembre 2023	\N	2023-12-13 13:30:00	2023-12-13 14:45:00	2023-12-13 15:42:36	2023-12-14 17:48:21	18	0	\N	\N
779255	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 12 décembre 2023	\N	2023-12-12 17:05:00	2023-12-12 18:15:00	2023-12-13 10:29:06	2023-12-13 14:18:11	17	0	\N	\N
779278	COM_EURO	AUDRAP	\N	AFEU	\N	Auditions nouvelles techniques génomiques	Auditions nouvelles techniques génomiques	2023-12-07 10:00:00	2023-12-07 11:00:00	\N	\N	2	0	\N	\N
779280	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPRE Intitulé de la commission de la culture (amdts)	PPRE Intitulé de la commission de la culture (amdts)	2023-12-12 14:15:00	2023-12-12 14:20:00	2023-12-12 17:59:10	2023-12-12 18:15:01	18	0	\N	\N
779282	COM_PERMANENTE	AUTRE	\N	LOIS	\N	MCC Agressions subies par les enseignants - Audition de la DGPN et la DGGN	MCC Agressions subies par les enseignants - Audition de la DGPN et la DGGN	2023-12-13 16:30:00	2023-12-13 17:45:00	2023-12-14 11:56:24	2023-12-14 17:48:20	15	0	\N	\N
779288	COM_EURO	AUDRAP	\N	AFEU	\N	Auditions nouvelles techniques génomiques	Auditions nouvelles techniques génomiques	2023-12-07 14:30:00	2023-12-07 17:00:00	\N	\N	3	0	\N	\N
770561	COM_PERMANENTE	AUTRE	\N	CAE	\N	Avis budgétaires	\N	2023-11-22 09:35:00	2023-11-22 12:15:00	2023-11-22 18:49:43	2023-11-23 17:48:20	44	0	\N	\N
779301	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-12-13 11:05:00	2023-12-13 12:35:00	2023-12-13 13:24:57	2023-12-13 14:19:05	26	2	\N	\N
784491	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition M. Libault	\N	2023-12-19 15:00:00	2023-12-19 16:00:00	\N	\N	6	0	\N	\N
784494	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Société du bien-vieillir - Table ronde d'organisations syndicales	\N	2023-12-18 14:00:00	2023-12-18 15:00:00	\N	\N	5	0	\N	\N
784504	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Société du bien-vieillir - Audition du CNCPH	\N	2023-12-18 15:00:00	2023-12-18 16:00:00	\N	\N	5	0	\N	\N
784512	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Société du bien-vieillir - Audition de l'Unaf	\N	2023-12-18 16:00:00	2023-12-18 17:00:00	\N	\N	3	0	\N	\N
784517	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Société du bien-vieillir - Audition de la HAS	\N	2023-12-19 09:00:00	2023-12-19 10:00:00	\N	\N	3	0	\N	\N
786306	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition P. CHAIZE	\N	2024-01-04 09:30:00	2024-01-04 12:00:00	\N	\N	2	0	\N	\N
786309	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition P. CHAIZE	\N	2024-01-04 14:00:00	2024-01-04 16:00:00	\N	\N	2	0	\N	\N
774414	COM_EURO	AUDRAP	\N	AFEU	\N	Auditions nouvelles techniques génomiques	Auditions nouvelles techniques génomiques	2023-11-29 16:30:00	2023-11-29 18:00:00	\N	\N	3	0	\N	\N
775198	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Jeux Olympiques et Paralympiques 2024 - Audition de Laurent Nunez	Jeux Olympiques et Paralympiques 2024 - Audition de Laurent Nunez	2023-11-30 16:30:00	2023-11-30 17:50:00	2023-11-30 18:01:57	2023-12-05 17:44:01	10	0	\N	\N
775268	COM_SPECIALE	AUDRAP	\N	DDADUE23	\N	PJL Ddadue - Audition DGCCRF	PJL Ddadue - Audition DGCCRF	2023-11-22 16:30:00	2023-11-22 17:15:00	\N	\N	4	0	\N	\N
775269	COM_SPECIALE	AUDRAP	\N	DDADUE23	\N	PJL Ddadue - Audition DGEC	PJL Ddadue - Audition DGEC	2023-11-22 17:15:00	2023-11-22 17:45:00	\N	\N	2	0	\N	\N
775270	COM_SPECIALE	AUDRAP	\N	DDADUE23	\N	Audition PJL Ddadue - MASA	Audition PJL Ddadue - MASA	2023-11-22 17:45:00	2023-11-22 18:30:00	\N	\N	2	0	\N	\N
775271	COM_SPECIALE	AUDRAP	\N	DDADUE23	\N	Audition PJL Ddadue - APCA	Audition PJL Ddadue - APCA	2023-11-22 18:30:00	2023-11-22 19:00:00	\N	\N	2	0	\N	\N
786110	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe France-Asie du Sud-Est	AG Asie du Sud-Est- Désignation des Vice-présidents et Secrétaires 	2023-12-20 14:30:00	2023-12-20 14:55:00	\N	\N	20	0	609	\N
786641	CONF_PRES	AUCUNE	\N	\N	\N	Conf Prés	Conférence des Présidents	2023-12-13 18:03:00	2023-12-13 18:43:00	\N	\N	25	0	\N	\N
790109	COM_PERMANENTE	DEPLACEMENT	\N	ETRD	\N	Bundestag Berlin	Déplacement Berlin commission affaires étrangères Berlin	2024-01-28 17:00:00	2024-01-29 22:00:00	\N	\N	8	0	\N	\N
798638	COM_ENQUETE	PLENIERE	\N	ELEC	\N	TR Nouveau nucléaire et prix de l'électricité	\N	2024-02-13 16:05:00	2024-02-13 19:50:00	2024-02-22 10:43:15	2024-02-22 14:29:05	10	0	\N	\N
806438	ETUDES	AUTRE	\N	\N	\N	GE Cancer - Audition du Leem	\N	2024-03-06 14:00:00	2024-03-06 15:00:00	\N	\N	9	0	\N	1004
806449	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Cancers professionnels des sapeurs-pompiers - FNSPF	\N	2024-03-05 14:00:00	2024-03-05 15:30:00	\N	\N	2	0	\N	\N
810302	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Retraite agricole	PPL Retraite agricole	2024-03-19 14:30:00	2024-03-19 16:35:00	\N	\N	87	0	\N	\N
810303	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Jardins d'enfants	PPL Jardins d'enfants	2024-03-19 16:40:00	2024-03-19 17:45:00	\N	\N	72	0	\N	\N
810304	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Tests PME	PPL Tests PME	2024-03-19 17:50:00	2024-03-19 19:35:00	\N	\N	65	0	\N	\N
810305	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Conseil européen	Débat Conseil européen	2024-03-19 21:30:00	2024-03-20 23:35:00	\N	\N	33	0	\N	\N
810306	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2024-03-20 15:00:00	2024-03-20 16:20:00	\N	\N	297	0	\N	\N
810307	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Justice patrimoniale	PPL Justice patrimoniale	2024-03-20 16:30:00	2024-03-20 18:50:00	\N	\N	86	0	\N	\N
810308	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Médecine scolaire	PPL Médecine scolaire	2024-03-20 18:55:00	2024-03-20 20:30:00	\N	\N	62	0	\N	\N
810311	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Accord UE Canada	PJL Accord UE Canada	2024-03-21 10:30:00	2024-03-21 13:00:00	\N	\N	149	0	\N	\N
811311	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	COJOP / SOLIDEO sur la livraison, l'aménagement et la gestion des sites olympiques	\N	2024-03-19 15:00:00	2024-03-19 17:00:00	\N	\N	5	0	\N	\N
811317	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition Jean-Dominique Senard	\N	2024-03-20 09:00:00	2024-03-20 12:10:00	2024-03-20 12:14:18	2024-03-20 17:26:20	39	0	\N	\N
811472	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Jean-Yves Roux	Auditions M. Jean-Yves Roux	2024-03-19 09:35:00	2024-03-19 10:35:00	\N	\N	1	0	\N	\N
811512	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Jean-Yves Roux	Auditions M. Jean-Yves Roux	2024-03-19 13:25:00	2024-03-19 14:25:00	\N	\N	1	0	\N	\N
811514	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Jean-Yves Roux	Auditions M. Jean-Yves Roux	2024-03-19 18:05:00	2024-03-19 18:50:00	\N	\N	1	0	\N	\N
811520	COM_EURO	AUDRAP	\N	AFEU	\N	Audition euro numérique	\N	2024-03-19 13:30:00	2024-03-19 15:00:00	\N	\N	2	0	\N	\N
811523	MECSS	AUDRAP	\N	\N	MECSS	MI Branche AT-MP - Audition de journalistes du Monde	\N	2024-03-19 17:00:00	2024-03-19 18:00:00	\N	\N	3	0	\N	\N
811525	MECSS	AUDRAP	\N	\N	MECSS	MI Branche AT-MP - Audition conjointe Fnath-Andeva	\N	2024-03-19 18:00:00	2024-03-19 19:30:00	\N	\N	3	0	\N	\N
811530	COM_EURO	AUDRAP	\N	AFEU	\N	Auditions euro numérique	\N	2024-03-19 17:00:00	2024-03-19 19:30:00	\N	\N	2	0	\N	\N
811535	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GS Egalim - Audition FCD	GS Egalim - Audition FCD	2024-03-19 17:00:00	2024-03-19 17:45:00	\N	\N	3	0	\N	\N
811723	MISSION	AUCUNE	\N	PERI	\N	PLENIERE - 2	\N	2024-03-20 13:30:00	2024-03-20 15:00:00	2024-04-04 12:15:21	2024-04-05 11:51:46	7	0	\N	\N
812068	ETUDES	AUTRE	\N	\N	\N	GE Cancer - Audition de Christophe Grosset	\N	2024-03-20 14:00:00	2024-03-20 15:00:00	\N	\N	4	0	\N	1004
779299	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-12-13 08:35:00	2023-12-13 09:35:00	2023-12-13 10:58:36	2023-12-13 14:19:07	43	1	\N	\N
812083	ETUDES	AUTRE	\N	\N	\N	GE Mer et littoral	GE Mer et littoral	2024-03-20 14:15:00	2024-03-20 15:00:00	\N	\N	10	0	\N	908
812478	MISSION	AUTRE	\N	PERI	\N	Audition de professionnels de santé	\N	2024-03-26 18:30:00	2024-03-26 20:00:00	2024-04-03 19:04:13	2024-04-04 11:34:51	9	0	\N	\N
812482	MISSION	AUCUNE	\N	PERI	\N	auditions	\N	2024-03-27 16:30:00	2024-03-27 18:30:00	2024-04-03 19:10:47	2024-04-04 11:34:52	10	0	\N	\N
812504	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 28 mars 2024	\N	2024-03-28 09:30:00	2024-03-28 11:30:00	2024-03-28 14:09:39	2024-03-29 15:42:49	11	0	\N	\N
812640	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI enseignants	\N	2024-03-20 13:30:00	2024-03-20 14:30:00	\N	\N	2	0	\N	\N
813092	COM_ENQUETE	PLENIERE	\N	INFLU	\N	Audition Céline Berthon, DGSI	Audition Céline Berthon, DGSI	2024-03-21 10:30:00	2024-03-21 12:20:00	2024-03-21 15:56:10	2024-03-21 18:32:38	7	0	\N	\N
813107	COM_ENQUETE	PLENIERE	\N	INFLU	\N	Audition Dr Teija Tiilikainen	Audition Dr Teija Tiilikainen	2024-03-21 14:00:00	2024-03-21 15:10:00	2024-03-21 15:56:52	2024-03-21 18:32:38	6	0	\N	\N
813230	GIA	AUCUNE	\N	\N	\N	Remise des prix sur la colonisation et la guerre d'Algérie	Remise des prix sur la colonisation et la guerre d'Algérie	2024-03-18 09:00:00	2024-03-18 14:00:00	\N	\N	1	0	575	\N
813232	GIA	AUCUNE	\N	\N	\N	Entretien avec Hakan Hakesson, ambassadeur de Suède en France	Entretien avec Hakan Hakesson, ambassadeur de Suède en France	2024-03-12 12:45:00	2024-03-12 14:15:00	\N	\N	2	0	625	\N
813254	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Assainissement cadastral et résorption du désordre de la propriété	\N	2024-03-21 15:45:00	2024-03-21 18:15:00	\N	\N	1	0	\N	\N
791774	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition Sonia Le Gouriellec, chercheuse	Audition Sonia Le Gouriellec, chercheuse	2024-01-31 10:00:00	2024-01-31 11:50:00	2024-01-31 18:04:08	2024-01-31 18:48:12	33	2	\N	\N
791789	GIA	AUCUNE	\N	\N	\N	Assemblée générale	Assemblée générale	2024-01-16 15:00:00	2024-01-16 15:30:00	\N	\N	4	0	529	\N
793369	COM_PERMANENTE	AUTRE	\N	CAE	\N	Audition Alexandre Saubot	\N	2024-01-31 09:30:00	2024-01-31 13:20:00	2024-02-13 15:14:28	2024-02-13 15:25:13	42	0	\N	\N
793370	COM_PERMANENTE	AUTRE	\N	AFCL	\N	pass culture	\N	2024-01-31 09:00:00	2024-01-31 11:00:00	2024-01-31 17:08:28	2024-01-31 18:48:09	34	0	\N	\N
793592	DELEGATION	AUCUNE	\N	\N	211	Audition de M. Eric Dupond-Moretti, garde des Sceaux, ministre de la Justice	\N	2024-02-01 09:00:00	2024-02-01 10:40:00	\N	\N	9	0	\N	\N
793593	DELEGATION	AUDRAP	\N	\N	211	Auditions rapporteures Familles monoparentales - PaF et Maisons Familya	\N	2024-02-02 15:00:00	2024-02-02 16:35:00	\N	\N	3	0	\N	\N
793594	DELEGATION	AUDRAP	\N	\N	211	Audition rapporteures Familles monoparentales - OQVT et UNAF	\N	2024-02-05 15:00:00	2024-02-05 17:00:00	\N	\N	4	0	\N	\N
793595	DELEGATION	AUCUNE	\N	\N	211	Echange de vues sur les orientations du rapport Familles monoparentales	\N	2024-02-08 08:30:00	2024-02-08 10:00:00	\N	\N	9	0	\N	\N
793596	DELEGATION	AUTRE	\N	\N	211	Audition d'Aurore Bergé, ministre de l'égalité entre les femmes et les hommes	\N	2024-02-15 09:00:00	2024-02-15 10:30:00	\N	\N	0	0	\N	\N
793607	COM_PERMANENTE	AUDRAP	\N	CDD	\N	PPL Préserver des sols vivants	PPL Préserver des sols vivants	2024-01-30 13:55:00	2024-01-30 20:20:00	\N	\N	2	0	\N	\N
793846	COM_PERMANENTE	AUDRAP	\N	CDD	\N	 PPL Préserver des sols vivants - Auditions M. Michaël WEBER	 PPL Préserver des sols vivants - Auditions M. Michaël WEBER	2024-01-31 11:30:00	2024-01-31 12:10:00	\N	\N	3	0	\N	\N
794735	GIA	AUCUNE	\N	\N	\N	Assemblée générale	Assemblée générale	2024-01-17 14:05:00	2024-01-17 14:40:00	\N	\N	14	0	625	\N
801215	ETUDES	AUCUNE	\N	\N	\N	Réunion constitutive	Réunion constitutive	2024-02-07 13:30:00	2024-02-07 14:00:00	\N	\N	14	0	\N	906
805014	BUREAU	AUCUNE	\N	\N	\N	Délégation en charge du travail parlementaire	Délégation en charge du travail parlementaire	2024-03-05 16:30:00	2024-03-05 17:30:00	\N	\N	1	0	\N	\N
805020	BUREAU	AUCUNE	\N	\N	\N	Délégation en charge du travail parlementaire	Délégation en charge du travail parlementaire	2024-03-05 17:30:00	2024-03-05 18:45:00	\N	\N	3	0	\N	\N
806430	GIA	AUCUNE	\N	\N	\N	Réunion constitutive	\N	2024-01-23 17:30:00	2024-01-23 17:45:00	\N	\N	2	0	647	\N
806869	ETUDES	AUCUNE	\N	\N	\N	Audition associations de protection animales "welfaristes"	Audition associations de protection animales "welfaristes"	2024-03-05 17:30:00	2024-03-05 18:30:00	\N	\N	6	0	\N	1011
806877	ETUDES	AUCUNE	\N	\N	\N	Audition de représentants de la filière noisettes	Audition de représentants de la filière noisettes	2024-03-06 14:00:00	2024-03-06 15:00:00	\N	\N	7	0	\N	1005
808179	GIA	AUCUNE	\N	\N	\N	Petit-déjeuner de travail avec M. Sébastien SURUN,  ambassadeur de France en Mongolie	\N	2024-03-13 08:15:00	2024-03-13 09:15:00	\N	\N	10	0	612	\N
810141	COM_PERMANENTE	AUTRE	\N	AFCL	\N	francophonie	\N	2024-03-20 09:30:00	2024-03-20 11:00:00	2024-03-20 16:54:06	2024-03-20 17:25:21	28	0	\N	\N
810204	DELEGATION	AUTRE	\N	\N	DSOM	Coopération régionale - Audition de M. Ben Issa OUSSÉNI	\N	2024-03-19 14:00:00	2024-03-19 15:00:00	\N	\N	6	0	\N	\N
810206	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de M. Eric Béranger	\N	2024-03-20 08:30:00	2024-03-20 10:00:00	2024-03-21 10:16:26	2024-03-21 14:47:58	41	7	\N	\N
810209	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL « Tests PME » et  dispositif « Impact Entreprises » (amdts) 	PPL « Tests PME » et  dispositif « Impact Entreprises » (amdts) 	2024-03-19 09:30:00	2024-03-19 09:40:00	2024-03-19 13:35:08	2024-03-19 17:31:08	16	18	\N	\N
810264	COM_ENQUETE	PLENIERE	\N	NARCO	\N	Audition DGGN - DGPN - Ofast	Audition DGGN - DGPN - Ofast	2024-03-18 14:30:00	2024-03-18 18:00:00	2024-03-18 18:17:28	2024-03-19 17:28:12	5	0	\N	\N
810265	DELEGATION	AUCUNE	\N	\N	PROS	Audition du Pr Raphaël Gaillard, psychiatre, auteur de "L'homme augmenté"	\N	2024-03-21 08:40:00	2024-03-21 09:55:00	\N	\N	7	0	\N	\N
810266	COM_ENQUETE	PLENIERE	\N	NARCO	\N	Audition Ine Van Wymersch	Audition Ine Van Wymersch	2024-03-19 08:30:00	2024-03-19 09:30:00	2024-03-19 09:35:02	2024-03-19 17:28:13	4	0	\N	\N
810267	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Jean Bacci	Auditions M. Jean Bacci	2024-03-14 10:10:00	2024-03-14 12:35:00	\N	\N	1	0	\N	\N
810269	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Auditions M. Jean Bacci	Auditions M. Jean Bacci	2024-03-14 14:00:00	2024-03-14 16:50:00	\N	\N	1	0	\N	\N
808296	CMP	AUTRE	\N	AGE	\N	PPL Grand âge 	PPL Grand âge 	2024-03-12 16:30:00	2024-03-12 18:35:00	\N	\N	9	0	\N	\N
810211	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Justice patrimoniale - Nouvelle-Calédonie - Homicide routier	Justice patrimoniale - Nouvelle-Calédonie - Homicide routier - Avoirs criminels (rapports)	2024-03-20 09:00:00	2024-03-20 11:45:00	2024-03-20 14:08:12	2024-03-20 17:26:57	41	11	\N	\N
810281	DELEGATION	AUCUNE	\N	\N	206	Réunion avec le conseil scientifique	\N	2024-03-21 10:10:00	2024-03-21 12:15:00	\N	\N	9	0	\N	\N
810591	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2024-03-19 09:30:00	2024-03-19 12:40:00	\N	\N	43	0	\N	\N
813146	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	Audition DPR	Audition DPR	2024-03-21 08:30:00	2024-03-21 09:50:00	\N	\N	3	0	\N	\N
815854	MISSION	AUCUNE	\N	ARCH	\N	Audition Jean-François Hébert	\N	2024-03-28 11:15:00	2024-03-28 12:50:00	2024-03-28 17:33:39	2024-03-29 15:44:09	10	0	\N	\N
815898	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition FFB	\N	2024-04-03 17:30:00	2024-04-03 18:30:00	\N	\N	2	0	\N	\N
815901	DELEGATION	AUCUNE	\N	\N	206	Examen d'une note scientifique et d'un rapport d'information	\N	2024-04-04 09:30:00	2024-04-04 11:05:00	\N	\N	9	0	\N	\N
815902	DELEGATION	AUCUNE	\N	\N	PROS	Examen du rapport "IA, impôts, prestations sociales et lutte contre la fraude"	\N	2024-04-02 18:00:00	2024-04-02 19:00:00	\N	\N	11	0	\N	\N
815910	GIA	AUCUNE	\N	\N	\N	Déjeuner de travail avec une délégation laotienne	\N	2024-03-28 12:30:00	2024-03-28 14:00:00	\N	\N	2	0	577	\N
815913	GIA	AUCUNE	\N	\N	\N	Entretien avec Tramor Quemeneur, historien de la guerre d'Algérie	Entretien avec Tramor Quemeneur, historien de la guerre d'Algérie	2024-03-27 08:30:00	2024-03-27 09:30:00	\N	\N	3	0	575	\N
815920	DELEGATION	AUCUNE	\N	\N	COLTER	Réunion plénière	\N	2024-04-04 08:30:00	2024-04-04 10:30:00	\N	\N	30	0	\N	\N
815922	COM_ENQUETE	PLENIERE	\N	INFLU	\N	Audition MM. Vacchia et Verdier	 Audition MM. Jean-Philippe Vacchia et Henri Verdier	2024-03-28 14:00:00	2024-03-28 16:10:00	\N	2024-04-15 11:48:20	7	0	\N	\N
815930	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 3 avril 2024	\N	2024-04-03 13:35:00	2024-04-03 14:45:00	2024-04-03 14:51:37	2024-04-03 16:56:47	22	0	\N	\N
815931	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 4 avril 2024	\N	2024-04-04 09:30:00	2024-04-04 10:55:00	2024-04-04 10:55:37	2024-04-04 11:42:22	10	0	\N	\N
815944	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 3 avril 2024	\N	2024-04-03 13:35:00	2024-04-03 15:00:00	\N	\N	22	0	\N	\N
815945	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 4 avril 2024	\N	2024-04-04 09:30:00	2024-04-04 11:00:00	\N	\N	0	0	\N	\N
815946	ETUDES	AUTRE	\N	\N	\N	TR Mobilité en territoires de montagne	TR Mobilité en territoires de montagne	2024-03-27 13:30:00	2024-03-27 14:30:00	\N	\N	6	0	\N	918
815953	GIA	AUCUNE	\N	\N	\N	Audition de la fédération internationale des universités catholiques	Auditions du Pr François Mabille, secrétaire génréal de la FIUC	2024-03-27 13:30:00	2024-03-27 14:45:00	\N	\N	6	0	629	\N
815992	DELEGATION	AUDRAP	\N	\N	206	Effets indésirables des vaccins covid-19 - Audition des Drs Humbert et Fedrizzi	\N	2024-03-29 09:05:00	2024-03-29 09:50:00	\N	\N	1	0	\N	\N
785196	GIA	AUCUNE	\N	\N	\N	Audition et Assemblée générale du GIA France Balkans	Audition et assemblée générale du groupe	2023-12-20 08:00:00	2023-12-20 09:00:00	\N	\N	10	0	674	\N
786201	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition rapporteur Alain DUFFOURG	Audition rapporteur Alain DUFFOURG	2023-12-21 16:30:00	2023-12-21 18:45:00	\N	\N	1	0	\N	\N
786567	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL ESH sur le temps méridien	\N	2024-01-10 17:15:00	2024-01-10 18:00:00	\N	\N	8	0	\N	\N
786739	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Audition rapporteur	\N	2024-01-15 14:30:00	2024-01-15 19:00:00	\N	\N	2	0	\N	\N
787015	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Cour des comptes	\N	2024-01-16 14:30:00	2024-01-16 16:00:00	\N	\N	3	0	\N	\N
787103	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Conseil supérieur des programmes 	\N	2024-01-16 16:45:00	2024-01-16 17:45:00	\N	\N	3	0	\N	\N
787120	COM_PERMANENTE	AUTRE	\N	CAE	\N	Auditions ASN/IRSN	\N	2024-01-17 09:30:00	2024-01-17 12:25:00	2024-01-17 15:04:15	2024-01-17 18:05:04	82	0	\N	\N
789495	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Audition de Mme Catherine Vautrin	\N	2024-01-24 16:30:00	2024-01-24 17:30:00	2024-01-24 17:29:18	2024-01-25 18:33:19	27	0	\N	\N
789497	COM_EURO	AUDRAP	\N	AFEU	\N	Audition révision du cadre financier pluriannuel	\N	2024-01-18 11:30:00	2024-01-18 13:00:00	\N	\N	2	0	\N	\N
789500	COM_EURO	AUDRAP	\N	AFEU	\N	Audition révision cadre financier pluriannuel	\N	2024-01-22 15:00:00	2024-01-22 16:00:00	\N	\N	2	0	\N	\N
789503	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE 4 - Audition commune MM. J. CREEL, F. ECALLE et L. THOLONIAT	PLENIERE 4 - Audition commune MM. J. CREEL, F. ECALLE et L. THOLONIAT	2024-01-24 10:00:00	2024-01-24 12:00:00	2024-01-25 14:15:57	2024-01-25 18:33:22	33	2	\N	\N
789504	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Contentieux du stationnement payant	PPL relative au contentieux du stationnement payant	2024-01-22 14:00:00	2024-01-22 16:15:00	\N	\N	1	0	\N	\N
789508	COM_ENQUETE	DEPLACEMENT	\N	NARCO	\N	Contrôle sur place - Ofast	\N	2024-01-23 14:00:00	2024-01-23 18:00:00	\N	\N	2	0	\N	\N
789515	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audition des commissaires du Gouvernement	\N	2024-01-16 14:00:00	2024-01-16 15:15:00	\N	\N	1	0	\N	\N
789714	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Filière cinéma	\N	2024-01-23 13:30:00	2024-01-23 14:30:00	\N	\N	4	0	\N	\N
789736	COM_ENQUETE	PLENIERE	\N	TOTA	\N	Auditions	\N	2024-01-25 10:30:00	2024-01-25 13:00:00	2024-01-25 15:29:51	2024-01-25 18:33:45	13	0	\N	\N
789830	ETUDES	AUTRE	\N	\N	\N	Réunion constitutive	\N	2024-01-23 15:15:00	2024-01-23 16:15:00	\N	\N	22	0	\N	934
789859	COM_EURO	AUDRAP	\N	AFEU	\N	Audition révision du cadre financier pluriannuel	\N	2024-01-22 18:10:00	2024-01-22 19:00:00	\N	\N	2	0	\N	\N
794592	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	Réunion de la Commission spéciale	Réunion de la Commission spéciale chargée du contrôle des comptes et de l'évaluation interne	2024-01-31 17:45:00	2024-01-31 18:50:00	\N	\N	7	0	\N	\N
795638	COM_ENQUETE	PLENIERE	\N	ELEC	\N	Table ronde sur le parc nucléaire actuel	\N	2024-02-06 16:00:00	2024-02-06 18:20:00	2024-02-08 11:03:20	2024-02-08 12:33:48	13	0	\N	\N
797790	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE 8 - Réforme de l'octroi de mer	PLENIERE 8 - Réforme de l'octroi de mer	2024-02-14 16:34:00	2024-02-14 18:40:00	2024-02-22 10:19:12	2024-02-22 14:28:08	29	0	\N	\N
797804	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Déplacement art.13 Semaine Parlementaire Européenne à Bruxelles	Déplacement art.13 Semaine Parlementaire Européenne à Bruxelles	2024-02-12 08:00:00	2024-02-13 15:30:00	\N	\N	4	0	\N	\N
797811	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Audition M. MASSE, Représentation Permanante auprès de l'UE à Bruxelles	Audition M. MASSE, Représentation Permanante auprès de l'UE à Bruxelles	2024-02-12 07:00:00	2024-02-12 16:00:00	\N	\N	1	0	\N	\N
797815	COM_PERMANENTE	DEPLACEMENT	\N	FINC	\N	Déplacement de Mme BLATRIX CONTAT à Rennes, Nantes et Le Mans	Déplacement de Mme BLATRIX CONTAT à Rennes, Nantes et Le Mans	2024-02-21 08:00:00	2024-02-22 20:00:00	\N	\N	1	0	\N	\N
813406	CMP	AUTRE	\N	CIVI	\N	PPL Droit responsabilité civile	PPL Droit responsabilité civile	2024-03-26 08:31:00	2024-03-26 08:42:00	\N	\N	7	0	\N	\N
815921	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion CATDD	\N	2024-04-03 09:00:00	2024-04-03 11:35:00	2024-04-03 12:28:00	2024-04-03 16:52:02	47	4	\N	\N
797838	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	MI JOP 2024 - Centre de vidéo intelligente de la SNCF - Paris-Gare du Nord	MI JOP 2024 - Centre de visionnage et de stockage de vidéo intelligente de la SNCF - Paris-Gare du Nord	2024-02-08 09:30:00	2024-02-08 12:30:00	\N	\N	3	0	\N	\N
797839	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	MI JOP - Centre de coordination opérationnelle de sécurité - Préfecture de police de Paris	MI JOP - Centre de coordination opérationnelle de sécurité - Préfecture de police de Paris	2024-02-08 15:00:00	2024-02-08 17:00:00	\N	\N	4	0	\N	\N
797848	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Auditions - Lutte anti-drone	\N	2024-02-07 17:30:00	2024-02-07 19:30:00	\N	\N	0	0	\N	\N
803390	COM_ENQUETE	PLENIERE	\N	ELEC	\N	TR Prix électricité industrie	\N	2024-02-28 17:05:00	2024-02-28 18:45:00	2024-02-29 14:37:51	2024-02-29 17:50:16	4	0	\N	\N
807403	GIA	AUCUNE	\N	\N	\N	Entretien avec des représentants du Somaliland 	Entretien avec des représentants du Somaliland	2024-03-12 08:40:00	2024-03-12 09:50:00	\N	\N	3	0	588	\N
807811	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GS Egalim - Adepale	GS Egalim - Adepale	2024-02-06 17:15:00	2024-02-06 18:00:00	\N	\N	2	0	\N	\N
807815	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GS Egalim - La Coopération agricole	GS Egalim - La Coopération agricole	2024-02-06 18:00:00	2024-02-06 18:45:00	\N	\N	2	0	\N	\N
813341	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2024-03-27 15:00:00	2024-03-27 16:20:00	\N	\N	274	0	\N	\N
816061	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	2101	\N	\N	Explications de vote sur l'ensemble	Explications de vote sur l'ensemble	2024-04-02 14:30:00	2024-04-02 15:40:00	\N	\N	283	0	\N	\N
816062	SEANCE_PLENIERE	SCRUSOL	2101	\N	\N	Scrutin solennel PJLC Nouvelle Calédonie	Scrutin solennel PJLC Nouvelle Calédonie	2024-04-02 15:35:00	2024-04-02 15:40:00	\N	\N	0	0	\N	\N
819211	COM_ENQUETE	PLENIERE	\N	COPRO	\N	Professeurs	Professeurs	2024-03-19 16:00:00	2024-03-19 17:45:00	2024-04-09 12:19:14	\N	8	0	\N	\N
819221	COM_ENQUETE	PLENIERE	\N	COPRO	\N	Associations de professionnels de l'immobilier	Associations de professionnels de l'immobilier	2024-03-19 17:45:00	2024-03-19 19:45:00	2024-04-09 12:22:22	\N	7	0	\N	\N
819231	COM_ENQUETE	PLENIERE	\N	COPRO	\N	TR associations d'élus	TR associations d'élus	2024-04-08 16:00:00	2024-04-08 17:30:00	2024-04-09 12:34:05	2024-04-09 17:39:43	4	0	\N	\N
819266	COM_ENQUETE	PLENIERE	\N	ELEC	\N	TR Syndicats, DGEC et DGE	\N	2024-04-09 14:00:00	2024-04-09 18:20:00	2024-04-09 18:38:19	2024-04-12 13:35:22	10	0	\N	\N
786667	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Amdts extérieurs PPL AESH	\N	2024-01-23 14:15:00	2024-01-23 14:25:00	2024-01-23 14:27:40	2024-01-23 17:30:28	22	0	\N	\N
786668	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Audition recherche	\N	2024-01-24 09:10:00	2024-01-24 11:15:00	2024-01-24 11:32:03	2024-01-25 18:33:24	34	0	\N	\N
786685	COM_PERMANENTE	AUDRAP	\N	CAE	\N	DGPR	DGPR	2024-01-11 09:00:00	2024-01-11 10:00:00	\N	\N	3	0	\N	\N
786689	COM_PERMANENTE	AUDRAP	\N	CAE	\N	DGEC / DGE	DGEC / DGE	2024-01-11 10:00:00	2024-01-11 11:00:00	\N	\N	4	0	\N	\N
786694	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Ministère des armées	Ministère des armées	2024-01-11 11:00:00	2024-01-11 11:30:00	\N	\N	3	0	\N	\N
786698	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Délégation interministérielle au nouveau nucléaire	Délégation interministérielle au nouveau nucléaire	2024-01-11 11:30:00	2024-01-11 12:00:00	\N	\N	3	0	\N	\N
786702	COM_PERMANENTE	AUDRAP	\N	CAE	\N	CAE	CAE	2024-01-11 14:00:00	2024-01-11 14:30:00	\N	\N	2	0	\N	\N
786706	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Institut de radioprotection et de sûreté nucléaire	Institut de radioprotection et de sûreté nucléaire	2024-01-11 14:30:00	2024-01-11 15:30:00	\N	\N	3	0	\N	\N
786710	COM_PERMANENTE	AUDRAP	\N	CAE	\N	Asso négaWatt	Asso négaWatt	2024-01-11 15:30:00	2024-01-11 16:15:00	\N	\N	3	0	\N	\N
791742	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	AFCL	\N	Audition du SNPTV	\N	2024-01-16 09:30:00	2024-01-16 10:30:00	\N	\N	2	0	\N	\N
791745	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	AFCL	\N	audition groupe M6	\N	2024-01-16 15:30:00	2024-01-16 16:30:00	\N	\N	2	0	\N	\N
791748	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	AFCL	\N	audition SACD	\N	2024-01-23 09:00:00	2024-01-23 10:00:00	\N	\N	3	0	\N	\N
791752	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	AFCL	\N	Audition CMN	\N	2024-01-25 09:30:00	2024-01-25 10:30:00	\N	\N	1	0	\N	\N
797967	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE 7 - AUdition 58-2  ANCT Audition Mmes DEMIER et RAQUIN et M. BOURRON	PLENIERE 7 - Audition 58-2  ANCT Audition Mmes DEMIER et RAQUIN et M. BOURRON	2024-02-14 10:00:00	2024-02-14 11:45:00	2024-02-15 10:03:25	2024-02-15 17:31:06	31	0	\N	\N
797968	COM_EURO	AUTRE	\N	AFEU	\N	2e réunion du 14 février	\N	2024-02-14 16:30:00	2024-02-14 17:50:00	2024-02-14 17:53:32	2024-02-15 17:28:58	6	0	\N	\N
797969	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 14 février 2023	\N	2024-02-14 13:30:00	2024-02-14 14:35:00	2024-02-14 15:13:36	2024-02-14 17:39:34	16	0	\N	\N
797970	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 15 février 2024	\N	2024-02-15 09:00:00	2024-02-15 10:40:00	2024-02-15 10:39:16	2024-02-15 17:30:03	16	0	\N	\N
797974	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion CATDD	\N	2024-02-14 09:15:00	2024-02-14 10:45:00	2024-02-14 17:11:15	2024-02-14 17:49:39	41	5	\N	\N
798009	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur	\N	2024-02-13 08:00:00	2024-02-13 08:30:00	\N	\N	0	0	\N	\N
798014	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL retraites agricoles - Audition commune CR et CP	\N	2024-02-13 09:50:00	2024-02-13 10:20:00	\N	\N	1	0	\N	\N
798016	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL retraites agricoles - Audition FNSEA	\N	2024-02-13 10:20:00	2024-02-13 12:00:00	\N	\N	3	0	\N	\N
798049	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Réunion constitutive	\N	2024-02-13 13:45:00	2024-02-13 14:30:00	\N	\N	0	0	\N	\N
798331	DELEGATION	AUDRAP	\N	\N	206	Effets indésirables des vaccins contre la covid-19 - Audition du Pr Vincent Maréchal	\N	2024-02-09 09:10:00	2024-02-09 10:05:00	\N	\N	2	0	\N	\N
798333	DELEGATION	AUDRAP	\N	\N	206	Effets indésirables des vaccins contre covid-19 - Audition des Prs Robineau et Bardou	\N	2024-02-09 10:05:00	2024-02-09 11:20:00	\N	\N	2	0	\N	\N
798769	MECSS	AUDRAP	\N	\N	MECSS	MI Fiscalité comportementale - Audition de la DSS	\N	2024-02-13 09:00:00	2024-02-13 10:20:00	\N	\N	2	0	\N	\N
798781	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL retraites agricoles - Audition CCMSA	\N	2024-02-15 14:00:00	2024-02-15 15:15:00	\N	\N	1	0	\N	\N
798784	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL retraites agricoles - Audition commune DSS et MASA	\N	2024-02-15 15:15:00	2024-02-15 16:30:00	\N	\N	1	0	\N	\N
798787	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL retraites agricoles - Audition commune YGA, AP, ET, VS	\N	2024-02-15 16:30:00	2024-02-15 17:45:00	\N	\N	1	0	\N	\N
797973	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion CATDD	\N	2024-02-14 09:00:00	2024-02-14 09:15:00	2024-02-14 17:09:09	2024-02-14 17:54:51	41	5	\N	\N
799826	ETUDES	AUCUNE	\N	\N	\N	SE  Cultures traditionnelles - Réunion constitutive	SE  Cultures traditionnelles - Réunion constitutive	2024-02-14 14:00:00	2024-02-14 14:45:00	\N	\N	6	0	\N	1005
806337	COM_ENQUETE	PLENIERE	\N	ELEC	\N	TR Eolien terrestre et en mer	\N	2024-03-06 16:30:00	2024-03-06 18:40:00	2024-03-06 18:58:04	2024-03-07 22:41:40	10	0	\N	\N
807218	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI Négociations salariales - Auditions 	\N	2024-03-06 17:00:00	2024-03-06 18:30:00	\N	\N	2	0	\N	\N
807232	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - CMN - Audition M. BELAVAL, ancien président du CMN	Contrôle 2024 - CMN - Audition M. BELAVAL, ancien président du CMN	2024-02-27 14:30:00	2024-02-27 15:30:00	\N	\N	2	0	\N	\N
807235	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - CMN - Audition de la DGPA 	Contrôle 2024 - CMN - Audition de la Direction générale des patrimoines et de l'architecture (DGPA)	2024-03-05 17:45:00	2024-03-05 18:45:00	\N	\N	2	0	\N	\N
807238	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Audition Atos	\N	2024-03-06 16:30:00	2024-03-06 17:30:00	\N	\N	0	0	\N	\N
807239	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Airbus Defence & Space (ADS)	\N	2024-03-06 17:30:00	2024-03-06 18:30:00	\N	\N	0	0	\N	\N
807240	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Personnalité	\N	2024-03-06 18:30:00	2024-03-06 19:30:00	\N	\N	0	0	\N	\N
807241	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	EP Equity Investment	\N	2024-03-06 19:30:00	2024-03-06 20:30:00	\N	\N	0	0	\N	\N
807247	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Personnels admin. MEN - Audition Secrétariat général du MEN	Contrôle 2024 - Personnels admin. MEN - Audition Secrétariat général du ministère de l¿éducation nationale 	2024-03-07 17:00:00	2024-03-07 18:00:00	\N	\N	1	0	\N	\N
807249	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Protocoles sociaux DGAC - Audition M. TINLOT, DGAFP	Contrôle 2024 - Protocoles sociaux DGAC - Audition M. TINLOT, DGAFP	2024-03-07 14:30:00	2024-03-07 15:30:00	\N	\N	1	0	\N	\N
807251	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Protocoles sociaux DGAC - Audition d'Air France-KLM	Contrôle 2024 - Protocoles sociaux DGAC - Audition d'Air France-KLM	2024-03-07 15:30:00	2024-03-07 16:30:00	\N	\N	1	0	\N	\N
807254	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Protocoles sociaux DGAC - Audition M. PICHARD, direction du budget	Contrôle 2024 - Protocoles sociaux DGAC - Audition M. PICHARD, direction du budget	2024-03-07 16:30:00	2024-03-07 17:30:00	\N	\N	1	0	\N	\N
807260	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Protocoles sociaux DGAC - Audition M. de IZAGUIRRE, FNAM	Contrôle 2024 - Protocoles sociaux DGAC - Audition M. de IZAGUIRRE, FNAM	2024-03-07 17:30:00	2024-03-07 18:30:00	\N	\N	1	0	\N	\N
807262	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Décarbonation - Audition Direction Générale des Entreprises (DGE)	Contrôle 2024 - Décarbonation - Audition Direction Générale des Entreprises (DGE)	2024-02-29 09:00:00	2024-02-29 10:00:00	\N	\N	2	0	\N	\N
807265	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Décarbonation - Audition de l'Agence Nationale de la Recherche (ANR)	Contrôle 2024 - Décarbonation - Audition de l'Agence Nationale de la Recherche (ANR)	2024-03-07 10:00:00	2024-03-07 11:00:00	\N	\N	2	0	\N	\N
807268	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Décarbonation - Audition du secrétariat général pour l'investissement 	Contrôle 2024 - Décarbonation - Audition du secrétariat général pour l'investissement (SGPI)	2024-03-07 11:00:00	2024-03-07 12:00:00	\N	\N	2	0	\N	\N
785320	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe d'amitié France-Canada	\N	2023-12-20 11:30:00	2023-12-20 12:00:00	\N	\N	16	0	583	\N
790119	GIA	AUCUNE	\N	\N	\N	Entretien avec Benoît Guidée, directeur Asie au ministère des Affaires étrangères	\N	2024-01-24 08:00:00	2024-01-24 09:00:00	\N	\N	12	0	584	\N
790342	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe	Assemblée générale du groupe	2024-01-23 18:00:00	2024-01-23 18:30:00	\N	\N	10	0	578	\N
791011	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe	Assemblée générale du groupe	2024-01-23 17:00:00	2024-01-23 17:30:00	\N	\N	6	0	550	\N
791761	COM_ENQUETE	PLENIERE	\N	TOTA	\N	Réunion CE TE	\N	2024-01-29 16:00:00	2024-01-29 17:33:00	2024-01-29 18:21:54	2024-01-30 17:57:17	8	0	\N	\N
791777	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL cinéma	\N	2024-01-29 10:00:00	2024-01-29 11:00:00	\N	\N	5	0	\N	\N
791794	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2025 - Audition MM. Antoine PETIT et Thomas BOREL, CNRS	PLF pour 2025 - Audition MM. Antoine PETIT et Thomas BOREL, CNRS	2024-01-24 08:00:00	2024-01-24 09:00:00	\N	\N	1	0	\N	\N
791797	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PLF pour 2025 - Audition M. Didier MIGAUD, HATVP	PLF pour 2025 - Audition M. Didier MIGAUD, HATVP	2024-01-24 14:00:00	2024-01-24 15:00:00	\N	\N	1	0	\N	\N
803915	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat sur les finances des départements	Débat sur les finances des départements	2024-03-05 14:30:00	2024-03-05 16:05:00	\N	\N	90	0	\N	\N
803916	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat sur le thème : « JO 2024 : la France est-elle prête ? » 	Débat sur le thème : « JO 2024 : la France est-elle prête ? » 	2024-03-05 16:10:00	2024-03-05 17:00:00	\N	\N	98	0	\N	\N
803917	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL financement des entreprises de l'industrie de défense française	PPL financement des entreprises de l'industrie de défense française	2024-03-05 17:50:00	2024-03-05 20:25:00	\N	\N	122	0	\N	\N
803918	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL création d'un statut de l'élu local	PPL création d'un statut de l'élu local	2024-03-05 21:55:00	2024-03-06 00:40:00	\N	\N	123	0	\N	\N
803919	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2024-03-06 15:00:00	2024-03-06 16:15:00	\N	\N	301	0	\N	\N
803920	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Équité et transparence de Parcoursup	Débat Équité et transparence de Parcoursup	2024-03-06 16:30:00	2024-03-06 18:20:00	\N	\N	61	0	\N	\N
803922	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Enseignement privé sous contrat	Débat Enseignement privé sous contrat	2024-03-06 18:20:00	2024-03-06 20:00:00	\N	\N	56	0	\N	\N
803923	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL création d'un statut de l'élu local	PPL création d'un statut de l'élu local	2024-03-06 21:30:00	2024-03-07 01:30:00	\N	\N	103	0	\N	\N
803924	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2024-03-07 10:30:00	2024-03-07 12:30:00	\N	\N	33	0	\N	\N
803925	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL création d'un statut de l'élu local	PPL création d'un statut de l'élu local	2024-03-07 14:30:00	2024-03-07 19:50:00	\N	\N	80	0	\N	\N
772584	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	MI Emeutes	MI Emeutes	2023-11-23 09:15:00	2023-11-23 10:00:00	\N	\N	2	0	\N	\N
772618	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Avis Administration pénitentiaire - Agence publique pour l'immobilier de la justice	Avis Administration pénitentiaire - Agence publique pour l'immobilier de la justice	2023-11-21 16:00:00	2023-11-21 17:00:00	\N	\N	1	0	\N	\N
772619	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Avis Administration pénitentiaire - Cour des comptes	Avis Administration pénitentiaire - Cour des comptes	2023-11-23 16:00:00	2023-11-23 17:00:00	\N	\N	1	0	\N	\N
776228	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLC souveraineté de la France	Audition rapporteur - PPLC souveraineté de la France	2023-11-29 11:15:00	2023-11-29 12:10:00	\N	\N	2	0	\N	\N
776231	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLC souveraineté de la France	Audition rapporteur - PPLC souveraineté de la France	2023-11-29 12:15:00	2023-11-29 13:10:00	\N	\N	2	0	\N	\N
776236	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLC souveraineté de la France	Audition rapporteur - PPLC souveraineté de la France	2023-11-29 14:15:00	2023-11-29 15:00:00	\N	\N	1	0	\N	\N
776247	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLC souveraineté de la France	Audition rapporteur - PPLC souveraineté de la France	2023-11-29 16:30:00	2023-11-29 17:15:00	\N	\N	2	0	\N	\N
776256	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLC souveraineté de la France	Audition rapporteur - PPLC souveraineté de la France	2023-11-29 17:15:00	2023-11-29 19:30:00	\N	\N	1	0	\N	\N
776259	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLC souveraineté de la France	Audition rapporteur - PPLC souveraineté de la France	2023-11-30 15:30:00	2023-11-30 16:15:00	\N	\N	2	0	\N	\N
776263	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPLC souveraineté de la France	Audition rapporteur - PPLC souveraineté de la France	2023-11-30 18:00:00	2023-11-30 18:40:00	\N	\N	1	0	\N	\N
776542	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024 Mission immigration	PLF 2024 Mission immigration	2023-12-04 10:00:00	2023-12-04 11:50:00	\N	\N	40	0	\N	\N
776543	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024 Mission Ecologie	PLF 2024 Mission Ecologie	2023-12-04 11:50:00	2023-12-04 13:00:00	\N	\N	48	0	\N	\N
776544	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024 Mission Ecologie	PLF 2024 Mission Ecologie	2023-12-04 14:30:00	2023-12-04 20:00:00	\N	\N	71	0	\N	\N
776545	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024 Mission Ecologie	PLF 2024 Mission Ecologie	2023-12-04 21:35:00	2023-12-05 00:15:00	\N	\N	60	0	\N	\N
776546	SEANCE_PLENIERE	QO	\N	\N	\N	Questions orales	Questions orales	2023-12-05 09:30:00	2023-12-05 12:35:00	\N	\N	50	0	\N	\N
776547	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024 Mission Travail	PLF 2024 Mission Travail	2023-12-05 14:05:00	2023-12-05 16:55:00	\N	\N	144	0	\N	\N
776548	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024 Mission Santé	PLF 2024 Mission Santé	2023-12-05 17:00:00	2023-12-05 19:35:00	\N	\N	120	0	\N	\N
776550	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024 Mission Solidarité	PLF 2024 Mission Solidarité	2023-12-05 21:05:00	2023-12-06 00:25:00	\N	\N	78	0	\N	\N
776551	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024 Mission RCT	PLF 2024 Mission RCT	2023-12-06 10:30:00	2023-12-06 13:00:00	\N	\N	99	0	\N	\N
776552	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024 Mission RCT	PLF 2024 Mission RCT	2023-12-06 14:30:00	2023-12-06 19:45:00	\N	\N	171	0	\N	\N
776554	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024 Mission AGTE	PLF 2024 Mission AGTE	2023-12-06 21:15:00	2023-12-06 22:40:00	\N	\N	43	0	\N	\N
776556	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024 Mission Outre mer	PLF 2024 Mission Outre mer	2023-12-07 10:30:00	2023-12-07 12:50:00	\N	\N	68	0	\N	\N
776557	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024 Mission Outre mer	PLF 2024 Mission Outre mer	2023-12-07 14:30:00	2023-12-07 16:15:00	\N	\N	62	0	\N	\N
776558	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024 Mission Transfo FP	PLF 2024 Mission Transfo FP	2023-12-07 16:20:00	2023-12-07 18:20:00	\N	\N	77	0	\N	\N
776560	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024 Mission Culture	PLF 2024 Mission Culture	2023-12-07 18:20:00	2023-12-07 20:00:00	\N	\N	72	0	\N	\N
776561	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024 Mission Médias	PLF 2024 Mission Médias	2023-12-07 22:20:00	2023-12-08 00:20:00	\N	\N	47	0	\N	\N
776562	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024 Mission Anciens combattants	PLF 2024 Mission Anciens combattants	2023-12-08 09:30:00	2023-12-08 11:00:00	\N	\N	53	0	\N	\N
776563	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024 Mission Action extérieure de l'État	PLF 2024 Mission Action extérieure de l'État	2023-12-08 11:00:00	2023-12-08 13:10:00	\N	\N	65	0	\N	\N
776564	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024 Mission Action extérieure de l'État	PLF 2024 Mission Action extérieure de l'État	2023-12-08 16:05:00	2023-12-08 20:00:00	\N	\N	48	0	\N	\N
776565	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024 Mission Aide publique au développement	PLF 2024 Mission Aide publique au développement	2023-12-08 16:05:00	2023-12-08 20:00:00	\N	\N	53	0	\N	\N
776566	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024 Mission Agriculture	PLF 2024 Mission Agriculture	2023-12-08 18:00:00	2023-12-08 20:05:00	\N	\N	44	0	\N	\N
776567	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PLF 2024 Mission Agriculture	PLF 2024 Mission Agriculture	2023-12-08 21:35:00	2023-12-09 00:50:00	\N	\N	38	0	\N	\N
789722	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	PPL filière cinéma	\N	2024-01-23 14:30:00	2024-01-23 17:00:00	\N	\N	5	0	\N	\N
797786	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe d'amitié France - Afrique du Sud	Assemblée générale reconstitutive du groupe d'amitié France - Afrique du Sud, Lesotho, Eswatini	2024-02-06 14:00:00	2024-02-06 14:15:00	\N	\N	3	0	574	\N
797791	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat avenir de notre modèle agricole	Débat avenir de notre modèle agricole	2024-02-13 16:10:00	2024-02-13 18:10:00	\N	\N	135	0	\N	\N
797792	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Sûreté dans les transports 	PPL Sûreté dans les transports 	2024-02-13 18:15:00	2024-02-13 20:00:00	\N	\N	99	0	\N	\N
797793	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Sûreté dans les transports	PPL Sûreté dans les transports	2024-02-13 21:30:00	2024-02-14 00:05:00	\N	\N	76	0	\N	\N
797794	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2024-02-14 15:00:00	2024-02-14 16:20:00	\N	\N	285	0	\N	\N
797795	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Confidentialité des consultations juridiques	PPL Confidentialité des consultations juridiques	2024-02-14 16:30:00	2024-02-14 18:40:00	\N	\N	72	0	\N	\N
797796	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Maîtrise d'ouvrage	PPL Maîtrise d'ouvrage	2024-02-14 18:40:00	2024-02-14 21:40:00	\N	\N	59	0	\N	\N
797797	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Filière cinématographique	PPL Filière cinématographique	2024-02-14 21:40:00	2024-02-15 23:25:00	\N	\N	36	0	\N	\N
797798	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Préserver les sols vivants	PPL Préserver les sols vivants	2024-02-15 10:30:00	2024-02-15 11:30:00	\N	\N	75	0	\N	\N
797799	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Santé et bien-être des femmes au travail	PPL Santé et bien-être des femmes au travail	2024-02-15 11:30:00	2024-02-15 13:00:00	\N	\N	39	0	\N	\N
797800	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL Santé et bien-être des femmes au travail	PPL Santé et bien-être des femmes au travail	2024-02-15 14:30:00	2024-02-15 16:10:00	\N	\N	38	0	\N	\N
801039	DELEGATION	AUCUNE	\N	\N	COLTER	Réunion plénière hors les murs à Sceaux	\N	2024-02-15 09:00:00	2024-02-15 12:15:00	2024-02-15 15:41:02	\N	10	0	\N	\N
801401	COM_EURO	AUDRAP	\N	AFEU	\N	Auditon pour la mission de contrôle des universités européennes	\N	2024-02-19 11:00:00	2024-02-19 12:00:00	\N	\N	2	0	\N	\N
801404	COM_EURO	AUDRAP	\N	AFEU	\N	Audition pour la mission de contrôle des universités européennes	\N	2024-02-23 14:00:00	2024-02-23 15:30:00	\N	\N	2	0	\N	\N
801407	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion CATDD	\N	2024-03-06 09:30:00	2024-03-06 12:00:00	2024-03-06 14:19:35	2024-03-06 17:48:02	35	0	\N	\N
801412	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Concessions autoroutes - Audition M. QUEMARD, DG de SANEF	Contrôle 2024 - Concessions autoroutes - Audition M. QUEMARD, DG de SANEF	2024-02-13 08:30:00	2024-02-13 10:30:00	\N	\N	2	0	\N	\N
801415	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Concessions autoroutes - Audition M. GINTZ, DG DGITM	Contrôle 2024 - Concessions autoroutes - Audition M. GINTZ, DG DGITM	2024-02-14 08:30:00	2024-02-14 10:00:00	\N	\N	2	0	\N	\N
779814	GIA	AUCUNE	\N	\N	\N	Jean-François Roberge ministre de la langue française du Québec	Visite du Palais suivi d'un déjeuner 	2023-10-17 11:00:00	2023-10-17 15:00:00	\N	\N	9	0	602	\N
794759	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe d'amitié 	Assemblée générale du groupe d'amitié 	2024-01-24 16:30:00	2024-01-24 17:10:00	\N	\N	9	0	616	\N
794784	GIA	AUCUNE	\N	\N	\N	GIA France-Japon	GIA France-Japon	2024-01-16 14:15:00	2024-01-16 15:00:00	\N	\N	20	0	596	\N
794806	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - PJLO Élections provinciales en Nouvelle-Calédonie	Audition rapporteur - PJLO Élections provinciales en Nouvelle-Calédonie	2024-01-30 07:00:00	2024-01-30 08:20:00	\N	\N	1	0	\N	\N
794808	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - PJLO Élections provinciales en Nouvelle-Calédonie	Audition rapporteur - PJLO Élections provinciales en Nouvelle-Calédonie	2024-01-30 18:00:00	2024-01-30 18:30:00	\N	\N	1	0	\N	\N
794810	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - PJLO Élections provinciales en Nouvelle-Calédonie	Audition rapporteur - PJLO Élections provinciales en Nouvelle-Calédonie	2024-01-31 10:30:00	2024-01-31 11:30:00	\N	\N	1	0	\N	\N
794812	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur PPL Garantir la confidentialité des consultations juridiques	PPL Garantir la confidentialité des consultations juridiques	2024-01-30 14:00:00	2024-01-30 15:00:00	\N	\N	1	0	\N	\N
794814	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Garantir la confidentialité des consultations juridiques	PPL Garantir la confidentialité des consultations juridiques	2024-01-30 17:00:00	2024-01-30 18:00:00	\N	\N	1	0	\N	\N
794816	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Garantir la confidentialité des consultations juridiques	PPL Garantir la confidentialité des consultations juridiques	2024-01-31 16:00:00	2024-01-31 18:15:00	\N	\N	1	0	\N	\N
799796	GIA	AUCUNE	\N	\N	\N	entretien avec l'ambassadeur des Pays-Bas	\N	2024-02-14 12:15:00	2024-02-14 14:30:00	\N	\N	6	0	599	\N
800023	COM_ENQUETE	PLENIERE	\N	INFLU	\N	Réunion constitutive	Réunion constitutive	2024-02-14 14:00:00	2024-02-14 14:45:00	2024-02-14 15:44:19	2024-02-14 17:37:33	11	0	\N	\N
800408	COM_ENQUETE	PLENIERE	\N	ELEC	\N	Table ronde Réseaux et acheminement électriques	\N	2024-02-14 16:30:00	2024-02-14 18:30:00	2024-02-22 10:45:09	2024-02-22 14:29:06	10	0	\N	\N
807037	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Justice patrimoniale au sein de la famille	PPL Justice patrimoniale au sein de la famille	2024-03-07 10:00:00	2024-03-07 12:00:00	\N	\N	1	0	\N	\N
807040	COM_ENQUETE	PLENIERE	\N	ELEC	\N	Table ronde sur l'énergie solaire	\N	2024-03-07 14:30:00	2024-03-07 16:20:00	2024-03-12 14:35:26	2024-03-12 14:47:18	5	0	\N	\N
807150	COM_ENQUETE	PLENIERE	\N	INFLU	\N	Table ronde sur la caractérisation des opérations d'influence	Table ronde sur la caractérisation des opérations d'influence et résilience des organisations	2024-03-07 14:00:00	2024-03-07 16:00:00	2024-03-07 16:39:56	2024-03-07 22:41:44	8	0	\N	\N
807221	SEANCE_PLENIERE	QAG	\N	\N	\N	Questions d'actualité au gouvernement	Questions d'actualité au gouvernement	2024-03-13 15:00:00	2024-03-13 16:25:00	\N	\N	293	0	\N	\N
807222	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat rapport public annuel de la Cour des comptes	Débat rapport public annuel de la Cour des comptes	2024-03-13 16:30:00	2024-03-13 18:20:00	\N	\N	130	0	\N	\N
807225	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat 50-1	Débat 50-1 sur l'accord de sécurité franco-ukrainien et la situation en Ukraine	2024-03-13 18:25:00	2024-03-13 20:55:00	\N	\N	220	0	\N	\N
807226	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPL soutenir l'engagement bénévole et à simplifier la vie associative	PPL soutenir l'engagement bénévole et à simplifier la vie associative	2024-03-13 22:25:00	2024-03-14 01:25:00	\N	\N	44	0	\N	\N
807227	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	CMP sécurité et protection des maires et des élus locaux 	CMP sécurité et protection des maires et des élus locaux 	2024-03-14 10:30:00	2024-03-14 11:30:00	\N	\N	39	0	\N	\N
807228	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Polynésie française	PJL Polynésie française	2024-03-14 11:30:00	2024-03-14 12:35:00	\N	\N	34	0	\N	\N
807229	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL convention Grand-duché de Luxembourg	PJL convention Grand-duché de Luxembourg	2024-03-14 14:30:00	2024-03-14 15:40:00	\N	\N	28	0	\N	\N
807230	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Convention Moldavie 	PJL Convention Moldavie 	2024-03-14 15:40:00	2024-03-14 16:30:00	\N	\N	27	0	\N	\N
807231	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Santé Polynésie française, Nouvelle-Calédonie et Wallis et Futuna	PJL Santé Polynésie française, Nouvelle-Calédonie et Wallis et Futuna	2024-03-14 16:30:00	2024-03-14 17:25:00	\N	\N	17	0	\N	\N
811546	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2024-03-05 16:00:00	2024-03-05 16:50:00	\N	\N	3	0	\N	\N
811550	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2024-03-12 16:00:00	2024-03-12 17:30:00	\N	\N	3	0	\N	\N
790371	ETUDES	AUTRE	\N	\N	\N	GE Monde combattant - Réunion constitutive	\N	2024-02-07 14:15:00	2024-02-07 15:00:00	\N	\N	19	0	\N	928
790700	COM_ENQUETE	AUDRAP	\N	NARCO	\N	Table ronde - Attachés douaniers et attachés de sécurité intérieure 	Table ronde - Attachés douaniers et attachés de sécurité intérieure 	2024-01-24 13:30:00	2024-01-24 15:10:00	\N	\N	2	0	\N	\N
791010	ETUDES	AUTRE	\N	\N	\N	GE Handicap - Réunion constitutive	\N	2024-01-24 14:30:00	2024-01-24 15:00:00	\N	\N	27	0	\N	1014
791158	DELEGATION	AUCUNE	\N	\N	211	Audition de Nicolas Grivel, directeur général de la CNAF	\N	2024-01-25 09:40:00	2024-01-25 11:00:00	\N	\N	10	0	\N	\N
791521	BUREAU	AUCUNE	\N	\N	\N	Réunion du Bureau	Réunion du Bureau	2024-01-25 08:35:00	2024-01-25 11:05:00	\N	\N	24	0	\N	\N
794841	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe	Assemblée générale du groupe	2024-01-31 17:00:00	2024-01-31 17:30:00	\N	\N	8	0	659	\N
794920	GIA	AUCUNE	\N	\N	\N	AG GIA France-Croatie	Assemblée générale du groupe d'amitié France-Croatie	2024-01-23 17:30:00	2024-01-23 17:45:00	\N	\N	2	0	647	\N
801179	ETUDES	AUTRE	\N	\N	\N	Table ronde hydroélectricité	Table ronde hydroélectricité	2024-02-14 13:30:00	2024-02-14 15:00:00	\N	\N	16	0	\N	906
801200	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur PPL Statut de l'élu local	Audition rapporteur PPL Statut de l'élu local	2024-02-19 09:00:00	2024-02-19 10:05:00	\N	\N	2	0	\N	\N
801230	COM_PERMANENTE	DEPLACEMENT	\N	LOIS	\N	Visite des sites des JOP de Seine-Saint-Denis	\N	2024-02-16 10:00:00	2024-02-16 18:00:00	\N	\N	0	0	\N	\N
801418	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL 191 Financement industrie défense - Audition de BpiFrance	PPL 191 Financement industrie défense - Audition MM. DEMEULENAERE et MMARIN-LAMELLET, BpiFrance	2024-02-13 14:00:00	2024-02-13 14:50:00	\N	\N	1	0	\N	\N
801420	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL 191 Financement industrie défense - Audition Banque de France	PPL 191 Financement industrie défense - Audition Mmes BARUT-ETHERINGTON et BENSAID-COHEN et M. LEVY, Banque de France	2024-02-13 16:30:00	2024-02-13 17:15:00	\N	\N	1	0	\N	\N
801422	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL 191 Financement industrie défense - Audition DG Trésor	PPL 191 Financement industrie défense - Audition M. CUMENGE, Mme LUCAS et M. de LIVONNIERE, DG Trésor	2024-02-13 17:15:00	2024-02-13 18:20:00	\N	\N	1	0	\N	\N
801424	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL 191 Financement industrie défense - Audition DGA	PPL 191 Financement industrie défense - Audition MM. LAHOUSSE et GRANGIER et Mme HERMAN, DGA	2024-02-20 10:20:00	2024-02-20 11:35:00	\N	\N	1	0	\N	\N
801426	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL 191 Financement industrie défense - Audition GICAT	PPL 191 Financement industrie défense - Audition du Groupement des industries françaises de défense et de sécurité,GICAT	2024-02-20 11:35:00	2024-02-20 12:30:00	\N	\N	1	0	\N	\N
801428	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL 191 Financement industrie défense - Audition de la Fédération bancaire française	PPL 191 Financement industrie défense - Audition de Mme ATIG et M. PARDIGON, Fédération bancaire française	2024-02-20 14:30:00	2024-02-20 15:10:00	\N	\N	1	0	\N	\N
801430	COM_PERMANENTE	AUDRAP	\N	FINC	\N	PPL 191 Financement industrie défense - Audition de la Caisse des dépôts et consignations	PPL 191 Financement industrie défense - Audition de la Caisse des dépôts et consignations	2024-02-22 11:20:00	2024-02-22 12:35:00	\N	\N	0	0	\N	\N
801431	COM_PERMANENTE	AUDRAP	\N	FINC	\N	58-2 2024 - Education prioritaire - Audition de la Cour des comptes	58-2 2024 - Education prioritaire - Audition de la Cour des comptes	2024-02-22 15:00:00	2024-02-22 16:00:00	\N	\N	1	0	\N	\N
801433	COM_PERMANENTE	AUDRAP	\N	FINC	\N	MI assurance Coll Terr - Audition M. BLANCHARD (SMACL Assurance) et M. TISSERAND (MAIF)	MI assurance Coll Terr - Audition M. BLANCHARD (SMACL Assurance) et M. TISSERAND (MAIF)	2024-02-13 18:30:00	2024-02-13 20:30:00	\N	\N	1	0	\N	\N
801435	COM_PERMANENTE	AUDRAP	\N	FINC	\N	MI Assurance Coll Terr - Table-ronde assureurs	MI Assurance Coll Terr - Table-ronde assureurs (Caisse centrale de réassurance, Médiateur de l'assurance, ACPR)	2024-02-15 09:30:00	2024-02-15 11:30:00	\N	\N	1	0	\N	\N
801437	COM_ENQUETE	PLENIERE	\N	TOTA	\N	Table ronde "devoir de vigilance"	\N	2024-02-26 16:00:00	2024-02-26 18:20:00	2024-02-27 14:55:22	2024-02-27 15:18:14	9	0	\N	\N
801438	DELEGATION	AUDRAP	\N	\N	206	Place des protéines dans l'alimentation - Audition de l'ONAV	\N	2024-02-23 17:30:00	2024-02-23 18:30:00	\N	\N	1	0	\N	\N
801442	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE 10 - Audition France 2030 de M. BONNELL	PLENIERE 10 - Audition France 2030 de M. BONNELL, secrétaire général pour l'investissement	2024-02-28 10:00:00	2024-02-28 11:45:00	2024-03-19 16:39:40	2024-03-19 16:41:17	38	4	\N	\N
804842	MECSS	AUDRAP	\N	\N	MECSS	MI Fiscalité comportementale - Audition de l'OFDT	\N	2024-03-15 14:00:00	2024-03-15 15:00:00	\N	\N	3	0	\N	\N
807246	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Examen RI "ONU"	Présentation RI "ONU"	2024-03-13 10:00:00	2024-03-13 10:40:00	2024-03-13 15:29:50	2024-03-13 15:57:37	39	7	\N	\N
807277	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - CNDA - Audition de la  CNCDH	Contrôle 2024 - CNDA - Audition de la  Commission nationale consultative des droits de l'homme (CNCDH)	2024-03-06 14:00:00	2024-03-06 15:00:00	\N	\N	1	0	\N	\N
807279	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - CNDA - Audition de la  Direction Générale des Etrangers en France (DGEF)	Contrôle 2024 - CNDA - Audition de la  Direction Générale des Etrangers en France (DGEF)	2024-03-06 16:25:00	2024-03-06 17:25:00	\N	\N	1	0	\N	\N
807286	DELEGATION	AUDRAP	\N	\N	206	Nouveaux développements de l'IA - Audition de la CNIL	\N	2024-03-07 15:30:00	2024-03-07 17:30:00	\N	\N	2	0	\N	\N
814132	GIA	AUCUNE	\N	\N	\N	Audition Marc Revol et Juan Carlos Martinez (Intelligence artificielle)	Audition Marc Revol et Juan Carlos Martinez (Intelligence artificielle)	2024-03-26 18:00:00	2024-03-26 19:50:00	\N	\N	8	0	590	\N
814473	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Assainissement cadastral et résorption du désordre de la propriété	PPL Assainissement cadastral et résorption du désordre de la propriété	2024-03-26 13:30:00	2024-03-26 14:00:00	\N	\N	1	0	\N	\N
783407	COM_EURO	AUDRAP	\N	AFEU	\N	Audition - Nouvelles techniques génomiques (NTG)	Audition - Nouvelles techniques génomiques (NTG)	2023-12-18 17:30:00	2023-12-18 18:30:00	\N	\N	2	0	\N	\N
783408	COM_EURO	AUDRAP	\N	AFEU	\N	Auditions - Nouvelles techniques génomiques (NTG)	Auditions - Nouvelles techniques génomiques (NTG)	2023-12-19 09:30:00	2023-12-19 11:30:00	\N	\N	2	0	\N	\N
783437	COM_EURO	AUDRAP	\N	AFEU	\N	Auditions - Réforme du Pacte de stabilité et de croissance	Auditions - Réforme du Pacte de stabilité et de croissance	2023-12-15 16:30:00	2023-12-15 17:30:00	\N	\N	2	0	\N	\N
783497	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Fondation Jean Jaurès	\N	2023-12-18 14:30:00	2023-12-18 15:30:00	\N	\N	5	0	\N	\N
801440	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE 9 - Examen rapport PPL 191 / actualisation programme de contrôle	\N	2024-02-28 09:00:00	2024-02-28 10:00:00	2024-03-19 16:39:19	2024-03-19 16:41:13	40	4	\N	\N
807245	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Examen PJL "CETA"	Examen du PJL n° 694 accord économique et commercial global UE-Canada	2024-03-13 10:45:00	2024-03-13 12:10:00	2024-03-13 15:32:42	2024-03-13 15:58:36	40	5	\N	\N
786178	GIA	AUCUNE	\N	\N	\N	Coopé - Entretien avec des attachés de l'Institut des études diplomatiques du Caire	Coopé - Entretien avec des attachés de l'Institut des études diplomatiques du Caire	2023-12-19 14:30:00	2023-12-19 15:30:00	\N	\N	1	0	617	\N
786615	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PPR Accord commercial UE Mercosur	PPR Accord commercial UE Mercosur	2024-01-16 14:30:00	2024-01-16 16:00:00	\N	\N	81	0	\N	\N
786616	SEANCE_PLENIERE	DEBAT	\N	\N	\N	Débat Prédation du loup	Débat Prédation du loup	2024-01-16 16:05:00	2024-01-16 17:35:00	\N	\N	84	0	\N	\N
794895	SEANCE_PLENIERE	SCRUSOL	2041	\N	\N	Scrutin solennel PPL Bien-vieillir	Scrutin solennel PPL Bien-vieillir	2024-02-06 15:35:00	2024-02-06 15:45:00	\N	\N	0	0	\N	\N
794896	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	2041	\N	\N	Explications de vote PPL Bien-vieillir	Explications de vote PPL Bien-vieillir	2024-02-06 14:30:00	2024-02-06 15:30:00	\N	\N	266	0	\N	\N
794913	GIA	AUCUNE	\N	\N	\N	Assemblée générale	\N	2024-01-31 14:30:00	2024-01-31 14:55:00	\N	\N	6	0	603	\N
799691	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2024-02-14 09:30:00	2024-02-14 11:10:00	2024-02-14 11:56:19	2024-02-14 17:45:47	40	0	\N	\N
801301	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Statut de l'élu local	PPL Statut de l'élu local	2024-02-20 09:00:00	2024-02-20 09:45:00	\N	\N	4	0	\N	\N
801306	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Statut de l'élu local	PPL Statut de l'élu local	2024-02-20 10:45:00	2024-02-20 13:00:00	\N	\N	3	0	\N	\N
801315	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Atos	MI Atos	2024-02-15 14:00:00	2024-02-15 15:00:00	\N	\N	2	0	\N	\N
801319	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Atos	MI Atos	2024-02-15 15:00:00	2024-02-15 16:00:00	\N	\N	2	0	\N	\N
801324	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Atos	MI Atos	2024-02-15 16:00:00	2024-02-15 16:45:00	\N	\N	2	0	\N	\N
801329	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Atos	MI Atos	2024-02-15 16:45:00	2024-02-15 17:30:00	\N	\N	1	0	\N	\N
801333	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Atos	MI Atos	2024-02-15 18:00:00	2024-02-15 19:00:00	\N	\N	1	0	\N	\N
819173	GIA	AUCUNE	\N	\N	\N	Entretien avec le ministère de la santé et le ministère de l'enseignement supérieur	\N	2024-04-09 09:00:00	2024-04-09 10:00:00	\N	\N	3	0	605	\N
770829	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	action extérieure de l'état	\N	2023-11-14 14:45:00	2023-11-14 15:10:00	\N	\N	1	0	\N	\N
770926	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE 84 - PLF pour 2024 - Examen rapports missions Cohésion Territoires et Justice	PLENIERE 84 - PLF pour 2024 - Examen rapports missions Cohésion Territoires et Justice	2023-11-22 16:30:00	2023-11-22 18:20:00	2023-12-06 14:34:15	2023-12-06 18:22:53	26	6	\N	\N
776068	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF 2024 : P. 151	PLF 2024 - P. 151	2023-11-21 16:00:00	2023-11-21 16:30:00	\N	\N	1	0	\N	\N
776073	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF 2024 : P. 151	PLF 2024 - P. 151	2023-11-22 18:00:00	2023-11-22 18:30:00	\N	\N	2	0	\N	\N
784278	GIA	AUCUNE	\N	\N	\N	Réunion du groupe en assemblée générale	\N	2023-12-19 14:15:00	2023-12-19 14:45:00	\N	\N	10	0	605	\N
789436	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2024-01-17 09:35:00	2024-01-17 11:30:00	2024-01-22 15:30:45	2024-01-22 17:46:24	39	0	\N	\N
807282	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI Atos	MI Atos	2024-03-07 15:00:00	2024-03-07 19:00:00	\N	\N	1	0	\N	\N
808273	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Atos	MI Atos	2024-03-12 17:30:00	2024-03-12 20:30:00	\N	\N	2	0	\N	\N
808742	COM_ENQUETE	PLENIERE	\N	INFLU	\N	Audition Christophe Lemoine, MEAE	Audition Christophe Lemoine, MEAE	2024-03-12 15:00:00	2024-03-12 16:30:00	2024-03-13 15:23:25	2024-03-13 15:52:13	10	0	\N	\N
810909	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Communication lutte anti-drones	Communication lutte anti-drones	2024-03-20 12:10:00	2024-03-20 12:30:00	2024-03-21 10:17:07	2024-03-21 14:48:01	41	7	\N	\N
813415	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	2081	\N	\N	EV PPL Tests PME	EV PPL Tests PME	2024-03-26 14:30:00	2024-03-26 15:25:00	\N	\N	271	0	\N	\N
813416	SEANCE_PLENIERE	SCRUSOL	2081	\N	\N	Scrutin solennel PPL Tests PME	Scrutin solennel PPL Tests PME	2024-03-26 15:25:00	2024-03-26 15:30:00	\N	\N	0	0	\N	\N
814475	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Assainissement cadastral et résorption du désordre de la propriété	PPL Assainissement cadastral et résorption du désordre de la propriété	2024-03-26 18:30:00	2024-03-26 19:15:00	\N	\N	1	0	\N	\N
815994	DELEGATION	AUDRAP	\N	\N	206	Nouveaux développements de l'IA - Audition de Florian Douetteau, Dataiku	\N	2024-03-28 09:00:00	2024-03-28 10:00:00	\N	\N	2	0	\N	\N
815995	DELEGATION	AUDRAP	\N	\N	206	Nouveaux développements de l'IA - Audition du Pr Daniel Andler 	\N	2024-03-28 10:00:00	2024-03-28 11:00:00	\N	\N	2	0	\N	\N
815996	DELEGATION	AUDRAP	\N	\N	206	Nouveaux développements de l'IA - Audition du Dr Laurent Alexandre	\N	2024-03-28 11:00:00	2024-03-28 12:40:00	\N	\N	2	0	\N	\N
816003	MISSION	AUDRAP	\N	COMP	\N	MI complémentaires santé - Table ronde infirmiers	\N	2024-03-29 10:00:00	2024-03-29 10:50:00	\N	\N	2	0	\N	\N
816006	MISSION	AUDRAP	\N	COMP	\N	MI complémentaires santé - Table ronde dentaires	\N	2024-03-29 11:10:00	2024-03-29 12:20:00	\N	\N	2	0	\N	\N
816010	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - CNDA - Table-ronde associations	Contrôle 2024 - CNDA - Table-ronde associations	2024-03-26 15:30:00	2024-03-26 16:30:00	\N	\N	1	0	\N	\N
816012	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Immigration : CIR - Audition de M. LESCHI,OFII	Contrôle 2024 - Immigration : CIR - Audition de M. LESCHI, Office français de l'immigration et de l'intégration	2024-03-27 14:00:00	2024-03-27 14:50:00	\N	\N	1	0	\N	\N
816014	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Immigration : CIR - Audition de la DGEF	Contrôle 2024 - Immigration : CIR - Audition de la DGEF	2024-03-27 16:40:00	2024-03-27 17:40:00	\N	\N	1	0	\N	\N
816016	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Commande publique - Audition ministère enseignement supérieur	Contrôle 2024 - Commande publique - Audition de Mme BOURDAIS-NAIMI, ministère enseignement supérieur SAAM	2024-03-26 09:00:00	2024-03-26 10:00:00	\N	\N	1	0	\N	\N
816018	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Commande publique - Audition direction achats et affaires juridiques	Contrôle 2024 - Commande publique - Audition direction achats et affaires juridiques	2024-03-26 10:00:00	2024-03-26 11:00:00	\N	\N	1	0	\N	\N
816020	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Commande publique - Audition de MM. LARGER et BOURGINE, AMUE	Contrôle 2024 - Commande publique - Audition de MM. LARGER et BOURGINE, AMUE	2024-03-27 14:00:00	2024-03-27 14:50:00	\N	\N	1	0	\N	\N
785504	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	Audition ESA	\N	2023-12-20 14:00:00	2023-12-20 15:00:00	\N	\N	0	0	\N	\N
771033	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion CATDD	\N	2023-11-29 09:00:00	2023-11-29 11:40:00	2023-11-29 12:36:03	2023-11-29 14:30:24	44	0	\N	\N
810408	CMP	AUTRE	\N	HABI	\N	\N	\N	2024-03-14 10:00:00	2024-03-14 11:20:00	\N	\N	10	0	\N	\N
816022	COM_PERMANENTE	AUDRAP	\N	FINC	\N	Contrôle 2024 - Commande publique - Audition de MM. METAYER et COULEON, OECP	Contrôle 2024 - Commande publique - Audition de MM. METAYER et COULEON, OECP	2024-03-27 16:30:00	2024-03-27 17:30:00	\N	\N	1	0	\N	\N
816024	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	MI Financement du ZAN - Audition de M. HASLE, fédération des SCoT	\N	2024-03-26 09:00:00	2024-03-26 10:00:00	\N	\N	0	0	\N	\N
816041	GIA	AUCUNE	\N	\N	\N	Rencontre SEM Alexis Le Cour Grandmaison	Petit-déjeuner avec SEM Alexis Le Cour Grandmaison, ambassadeur de France en Jordanie	2024-03-27 07:50:00	2024-03-27 09:15:00	\N	\N	7	0	659	\N
816049	GIA	AUCUNE	\N	\N	\N	Rencontre Saint-Gobain	Rencontre entre Saint-Gobain et SEM Alexis Le Cour Grandmaison	2024-03-27 09:30:00	2024-03-27 10:30:00	\N	\N	2	0	659	\N
816063	MISSION	AUCUNE	\N	ARCH	\N	Audition de M. Albéric de Montgolfier, Sénateur, Président de la CNPA	\N	2024-04-03 13:30:00	2024-04-03 14:45:00	\N	\N	13	0	\N	\N
816066	MISSION	AUCUNE	\N	PERI	\N	PLENIERE - 5 - INSERM	\N	2024-04-02 13:30:00	2024-04-02 14:30:00	\N	\N	9	0	\N	\N
816083	GIA	AUCUNE	\N	\N	\N	Rencontre avec l'ambassadeur de Grèce en France	Petit déjeuner de travail avec M. l'Ambassadeur de Grèce en France	2024-03-27 08:30:00	2024-03-28 09:30:00	\N	\N	10	0	591	\N
816739	MECSS	AUDRAP	\N	\N	MECSS	MI Fiscalité comportementale - Audition de la DGPE (Ministère de l'agriculture)	\N	2024-04-04 12:00:00	2024-04-04 13:00:00	\N	\N	2	0	\N	\N
816740	MECSS	AUDRAP	\N	\N	MECSS	MI Fiscalité comportementale - Audition Foodwatch	\N	2024-04-04 11:00:00	2024-04-04 12:00:00	\N	\N	2	0	\N	\N
816741	MECSS	AUDRAP	\N	\N	MECSS	MI Fiscalité comportementale - Audition conjointe Fivape-Sovape	\N	2024-04-04 09:45:00	2024-04-04 11:00:00	\N	\N	2	0	\N	\N
816743	MECSS	AUCUNE	\N	\N	MECSS	Audition plénière	\N	2024-04-02 16:30:00	2024-04-02 17:45:00	2024-04-02 17:52:33	2024-04-03 16:50:51	8	0	\N	\N
816766	COM_PERMANENTE	AUTRE	\N	FINC	\N	Plénière 21 - Audition de M. Philippe WAHL, Président-directeur général du Groupe La Poste	Plénière 21 - Audition de M. Philippe WAHL, La Poste/Désignation rapporteur/Demandes saisines	2024-04-10 10:30:00	2024-04-10 12:00:00	2024-04-10 19:56:40	2024-04-12 13:33:39	27	0	\N	\N
816769	COM_PERMANENTE	AUTRE	\N	FINC	\N	Plénière 20 - Audition du DG de l'AFD + Table ronde attractivité financière de la France	\N	2024-04-03 09:15:00	2024-04-03 12:15:00	\N	\N	42	3	\N	\N
816824	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI financiarisation de la santé - Associations d'étudiants	\N	2024-04-02 13:45:00	2024-04-02 14:45:00	\N	\N	2	0	\N	\N
816847	MISSION	AUTRE	\N	PERI	\N	PLENIERE 6 - TR Fédérations	\N	2024-04-02 18:30:00	2024-04-02 20:00:00	\N	\N	12	0	\N	\N
816882	MISSION	AUCUNE	\N	COMP	\N	Auditions plénières	\N	2024-04-02 17:30:00	2024-04-02 18:50:00	2024-04-02 18:50:34	2024-04-03 16:57:24	6	0	\N	\N
816926	MECSS	AUDRAP	\N	\N	MECSS	MI Branche AT-MP - Table ronde Experts du droit de la réparation corporelle	\N	2024-04-04 11:30:00	2024-04-04 12:30:00	\N	\N	3	0	\N	\N
816932	MECSS	AUDRAP	\N	\N	MECSS	MI Branche AT-MP - Audition du Collectif Les oubliés de la réforme 2022-257	\N	2024-04-04 10:30:00	2024-04-04 11:30:00	\N	\N	3	0	\N	\N
817074	GIA	AUCUNE	\N	\N	\N	Accueil à l'Ambassade de Moldavie	Accueil à l'Ambassade de Moldavie par SE Mme Calugaru	2024-04-02 16:30:00	2024-04-02 19:00:00	\N	\N	4	0	851	\N
817125	GIA	AUCUNE	\N	\N	\N	Audition de Kendal NEZAN, Président de l'Institut kurde,  et Béatrice DILLIES	Audition consacrée à la situation des Kurdes et des Yézidis	2024-04-02 17:00:00	2024-04-02 18:00:00	\N	\N	17	0	CHRETORIENT	CHRETORIENT
776125	GIA	AUCUNE	\N	\N	\N	AG Groupe Interparlementaire d'Amitié France-Suisse	AG Groupe Interparlementaire d'Amitié France-Suisse	2024-01-24 08:00:00	2024-01-24 08:30:00	\N	\N	11	0	610	\N
778859	GIA	AUCUNE	\N	\N	\N	Assemblée Générale 	\N	2023-12-05 17:00:00	2023-12-05 17:30:00	\N	\N	4	0	582	\N
788569	GIA	AUCUNE	\N	\N	\N	Consul général de France à Québec	Entretien avec M. Eric Lamouroux, Consul général de France à Québec	2024-01-17 17:00:00	2024-01-17 18:00:00	\N	\N	9	0	602	\N
791705	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	CAEDFA - Visite du Président Ramos-Horta- Timor oriental	CAEDFA - Visite du Président Ramos-Horta- Timor oriental	2024-01-25 16:30:00	2024-01-25 17:30:00	\N	\N	5	0	\N	\N
794753	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de Safran Electronics & Defense	Audition de Mme Hélène Lecoeuche et M. Gilles Perrone	2024-02-07 09:45:00	2024-02-07 11:05:00	2024-02-07 16:11:43	2024-02-08 12:31:26	27	0	\N	\N
804064	COM_ENQUETE	PLENIERE	\N	INFLU	\N	Table ronde sur la guerre informationnelle	Table ronde sur la guerre informationnelle	2024-02-29 14:00:00	2024-03-01 16:10:00	2024-03-01 10:31:20	2024-03-01 14:38:15	12	0	\N	\N
810452	GIA	AUCUNE	\N	\N	\N	AG constitutive	Assemblée générale du GIA	2024-02-07 16:30:00	2024-02-07 17:15:00	\N	\N	13	0	663	\N
812095	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI ATOS	MI Atos	2024-03-19 17:00:00	2024-03-19 18:00:00	\N	\N	2	0	\N	\N
773901	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLF pour 2024 - Avis justice judiciaire et accès au droit	Audition rapporteur - PLF 2024 - Avis justice judiciaire et accès au droit	2023-11-20 17:30:00	2023-11-20 18:15:00	\N	\N	2	0	\N	\N
773904	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLF pour 2024 - Avis justice judiciaire et accès au droit	Audition rapporteur - PLF 2024 - Avis justice judiciaire et accès au droit	2023-11-22 17:30:00	2023-11-22 18:30:00	\N	\N	2	0	\N	\N
773907	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJLF pour 2024 - Avis justice judiciaire et accès au droit	Audition rapporteur - PLF 2024 - Avis justice judiciaire et accès au droit	2023-11-22 18:30:00	2023-11-22 20:00:00	\N	\N	3	0	\N	\N
773911	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PJL Lutte contre les dérives sectaires	Audition rapporteur - PJL Lutte contre les dérives sectaires	2023-11-28 09:30:00	2023-11-28 10:30:00	\N	\N	1	0	\N	\N
773917	GIA	AUCUNE	\N	\N	\N	AG groupe Taïwan	AG groupe Taïwan et Audition en visio de  Franck Paris, Directeur du Bureau Français de Taipei	2023-12-05 15:00:00	2023-12-05 16:00:00	\N	\N	16	0	623	\N
779540	COM_PERMANENTE	AUTRE_NON_PLENIERE	\N	ETRD	\N	Grand prix de l'académie du renseignement	Grand prix de l'académie du renseignement	2023-12-05 18:00:00	2023-12-05 19:30:00	\N	\N	1	0	\N	\N
817295	GIA	AUCUNE	\N	\N	\N	Entretien avec SEM  LU Shaye, Ambassadeur de Chine en France	\N	2024-04-03 08:00:00	2024-04-03 09:00:00	\N	\N	11	0	584	\N
817592	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Audition président LimGroup	\N	2024-04-03 08:00:00	2024-04-03 09:00:00	\N	\N	0	0	\N	\N
817598	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI LCAP	\N	2024-04-02 16:00:00	2024-04-02 17:30:00	\N	\N	6	0	\N	\N
817630	MISSION	AUTRE	\N	PERI	\N	PLENIERE 7 - Infirmières puéricultrices	\N	2024-04-03 13:30:00	2024-04-03 14:45:00	\N	\N	5	0	\N	\N
818753	ETUDES	AUTRE	\N	\N	\N	GE Mer et littoral - Audition UPF	GE Mer et littoral - Audition UPF	2024-04-03 13:30:00	2024-04-03 15:00:00	\N	\N	8	0	\N	908
818763	COM_ENQUETE	PLENIERE	\N	NARCO	\N	Audition d'Eric Dupond-Moretti	Audition d'Eric Dupond-Moretti	2024-04-09 16:40:00	2024-04-09 18:25:00	2024-04-09 19:02:17	2024-04-12 13:35:25	15	0	\N	\N
818764	COM_ENQUETE	PLENIERE	\N	NARCO	\N	Audition de Gérald Darmanin	Audition de Gérald Darmanin	2024-04-10 16:30:00	2024-04-10 18:00:00	\N	\N	11	0	\N	\N
818787	COM_ENQUETE	PLENIERE	\N	TOTA	\N	Réunion CE-TE	\N	2024-04-04 10:30:00	2024-04-04 11:50:00	2024-04-04 19:12:17	2024-04-05 10:21:05	14	0	\N	\N
818788	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI financiarisation de la santé - Médecins et radiologues	\N	2024-04-03 16:30:00	2024-04-03 17:30:00	\N	\N	4	0	\N	\N
818859	COM_EURO	AUTRE	\N	AFEU	\N	Réunion de la commission des affaires européennes du 3 avril 2024	\N	2024-04-03 13:35:00	2024-04-03 14:45:00	\N	\N	0	0	\N	\N
818870	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Crise du logement	\N	2024-04-02 09:00:00	2024-04-02 10:00:00	\N	\N	4	0	\N	\N
818871	MISSION	AUCUNE	\N	COMP	\N	Auditions plénières	\N	2024-04-09 16:35:00	2024-04-09 19:00:00	2024-04-09 19:11:34	2024-04-12 13:35:24	8	0	\N	\N
818879	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Assainissement cadastral (amendements) - Emeutes de juin 2023 (rapport d'information)	PPL Assainissement cadastral (amendements) - Emeutes de juin 2023 (rapport d'information)	2024-04-09 14:00:00	2024-04-09 15:00:00	2024-04-09 16:27:03	2024-04-09 17:39:40	21	16	\N	\N
818880	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Audition de Claire Hédon - JOP 2024 (rapport d'information) - Audition de Pierre Moscovici	Audition de Claire Hédon - JOP 2024 (rapport d'information) - Audition de Pierre Moscovici	2024-04-10 09:10:00	2024-04-10 12:35:00	2024-04-10 14:31:42	2024-04-12 13:33:36	38	8	\N	\N
818881	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteurs surveillance des sols	\N	2024-04-03 17:45:00	2024-04-03 19:15:00	\N	\N	2	0	\N	\N
818915	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion CATDD	\N	2024-04-09 13:30:00	2024-04-09 13:47:00	2024-04-09 16:31:09	2024-04-09 17:39:39	25	14	\N	\N
818918	COM_EURO	AUTRE	\N	AFEU	\N	Réunion du 28 mars 2024	\N	2024-03-28 09:30:00	2024-03-28 11:30:00	\N	\N	0	0	\N	\N
818919	MISSION	AUDRAP	\N	COMP	\N	MI Complémentaires - SPVIE Assurances	\N	2024-04-02 16:30:00	2024-04-02 17:30:00	\N	\N	3	0	\N	\N
818927	MISSION	AUDRAP	\N	COMP	\N	MI Complémentaires santé - Table ronde des kinés	\N	2024-04-04 09:00:00	2024-04-04 10:00:00	\N	\N	2	0	\N	\N
818931	MISSION	AUDRAP	\N	COMP	\N	MI Complémentaires santé - Table ronde des auxiliaires médicaux	\N	2024-04-04 10:15:00	2024-04-04 11:30:00	\N	\N	2	0	\N	\N
818939	COM_EURO	AUDRAP	\N	AFEU	\N	Audition Paquet pharmaceutique	Audition de Mmes Apourceau-Poly et Gruny et M. Jomier dans le cadre de leurs travaux sur le paquet pharmaceutique	2024-01-16 14:00:00	2024-01-16 15:00:00	\N	\N	3	0	\N	\N
818943	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	co-auteurs de plusieurs ouvrages sur "l'argent du football"	\N	2024-04-04 14:30:00	2024-04-04 16:00:00	\N	\N	3	0	\N	\N
818944	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	Audition commune CDES et Fondation Jean Jaurès	\N	2024-04-04 16:00:00	2024-04-04 18:00:00	\N	\N	2	0	\N	\N
819025	QUESTURE	AUCUNE	\N	\N	\N	Conseil de Questure	Conseil de Questure	2024-03-26 16:00:00	2024-03-26 17:30:00	\N	\N	3	0	\N	\N
819042	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI IVG - Table ronde plannings familiaux	\N	2024-03-26 16:00:00	2024-03-26 17:15:00	\N	\N	5	0	\N	\N
819043	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI IVG - Audition AP-HP	\N	2024-03-26 17:15:00	2024-03-26 18:00:00	\N	\N	3	0	\N	\N
819044	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	MI IVG - Audition DGOS-DGS	\N	2024-03-27 16:30:00	2024-03-27 17:30:00	\N	\N	3	0	\N	\N
819058	ETUDES	DEPLACEMENT	\N	\N	\N	Déplacement au Centre relais téléphonique Rogervoice	\N	2024-04-02 17:15:00	2024-04-02 18:15:00	\N	\N	4	0	\N	1014
819063	GIA	AUCUNE	\N	\N	\N	Entretien avec l'ambassadeur de France en Erythrée 	Entretien avec M. Jérôme CAUCHARD, Ambassadeur de France en Erythrée 	2024-04-02 16:00:00	2024-04-02 17:05:00	\N	\N	4	0	588	\N
819078	COM_ENQUETE	DEPLACEMENT	\N	NARCO	\N	Déplacement dans la Drôme	Déplacement dans la Drôme	2024-03-28 06:30:00	2024-03-28 21:00:00	\N	\N	5	0	\N	\N
819088	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2024-04-10 09:05:00	2024-04-10 11:25:00	2024-04-10 11:24:39	2024-04-12 13:33:34	42	0	\N	\N
819095	COM_ENQUETE	PLENIERE	\N	TOTA	\N	Auditions	\N	2024-04-08 16:00:00	2024-04-08 18:00:00	2024-04-09 10:06:48	2024-04-09 17:39:44	6	0	\N	\N
819096	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition Casinos de France	\N	2024-04-08 14:00:00	2024-04-08 14:30:00	\N	\N	1	0	\N	\N
819097	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition GHR	\N	2024-04-08 14:30:00	2024-04-08 15:00:00	\N	\N	1	0	\N	\N
819098	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Auidition Hexopée	\N	2024-04-08 15:00:00	2024-04-08 15:30:00	\N	\N	1	0	\N	\N
819099	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition AEGPIRC	\N	2024-04-08 15:30:00	2024-04-08 16:00:00	\N	\N	2	0	\N	\N
819100	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition DGAFP	\N	2024-04-08 16:00:00	2024-04-08 16:45:00	\N	\N	2	0	\N	\N
819198	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GS ZAN	GS ZAN	2024-04-09 09:05:00	2024-04-09 10:15:00	\N	\N	3	0	\N	\N
819202	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	GS ZA	GS ZAN	2024-04-09 09:05:00	2024-04-09 10:15:00	\N	\N	2	0	\N	\N
820061	GIA	AUCUNE	\N	\N	\N	Entretien avec le lauréat soudanais de l'Initiative Marianne 	Entretien avec le lauréat soudanais de l'Initiative Marianne 	2024-04-10 08:00:00	2024-04-10 09:15:00	\N	\N	2	0	588	\N
820106	COM_ENQUETE	PLENIERE	\N	INFLU	\N	Auditions J. Celestin-Urbain (SISSE) / T. Huchon G. Holubowicz, journalistes	Auditions J. Celestin-Urbain (SISSE) / T. Huchon G. Holubowicz, journalistes	2024-04-09 15:30:00	2024-04-09 19:00:00	2024-04-10 10:39:57	2024-04-12 13:35:23	12	0	\N	\N
820184	GIA	AUCUNE	\N	\N	\N	Entretien avec l'Association des amis de Ghislaine Dupont et Claude Verlon	Entretien avec l'Association des amis de Ghislaine Dupont et Claude Verlon	2024-04-10 08:00:00	2024-04-10 08:55:00	\N	\N	1	0	573	\N
820995	GIA	AUCUNE	\N	\N	\N	Cérémonie en l'honneur de l'empereur du Japon	\N	2024-03-28 18:00:00	2024-03-28 20:00:00	\N	\N	6	0	596	\N
821166	ETUDES	AUCUNE	\N	\N	\N	Le chantier des EPR2 de Penly	Le chantier des EPR2 de Penly	2024-04-10 13:30:00	2024-04-10 15:00:00	\N	\N	13	0	\N	906
785315	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Société du bien-vieillir - Audition de l'IF-PJM	\N	2023-12-19 18:30:00	2023-12-19 19:15:00	\N	\N	2	0	\N	\N
785337	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition DGCS	\N	2023-12-20 16:30:00	2023-12-20 17:30:00	\N	\N	6	0	\N	\N
785363	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audition FNAM	\N	2023-12-13 16:30:00	2023-12-13 17:30:00	\N	\N	1	0	\N	\N
785493	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Société du bien-vieillir - Audition commune de l'Igas et de l'IGF	\N	2023-12-20 14:00:00	2023-12-20 15:00:00	\N	\N	3	0	\N	\N
818916	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion CATDD	\N	2024-04-10 09:06:00	2024-04-10 11:20:00	2024-04-11 09:51:03	2024-04-12 13:33:35	46	8	\N	\N
820028	CMP	AUTRE	\N	TEST	\N	PPL Discriminations tests individuels	PPL Discriminations tests individuels	2024-04-10 08:30:00	2024-04-10 08:50:00	\N	\N	9	0	\N	\N
785885	COM_PERMANENTE	AUTRE	\N	AFCL	\N	MCC agressions enseignants	\N	2023-12-20 16:35:00	2023-12-20 17:50:00	2023-12-20 17:53:32	2023-12-20 18:10:23	26	0	\N	\N
789392	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	\N	\N	2024-01-18 10:00:00	2024-01-18 11:45:00	\N	\N	6	0	\N	\N
795687	ETUDES	AUTRE	\N	\N	\N	Déjeuner Tour de France	\N	2024-02-06 12:30:00	2024-02-06 14:30:00	\N	\N	23	0	\N	934
803989	COM_ENQUETE	PLENIERE	\N	ELEC	\N	TR Fournissuers alternatifs	\N	2024-02-29 14:30:00	2024-02-29 16:30:00	2024-03-04 10:25:06	2024-03-04 14:13:38	5	0	\N	\N
807416	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	Déplacement DPR	déplacement DPR	2024-02-29 10:00:00	2024-02-29 12:30:00	\N	\N	3	0	\N	\N
807420	RENSEIGNEMENT	AUCUNE	\N	\N	RENSEIGNEMEN	Déplacement DPR	déplacement DPR	2024-03-07 09:30:00	2024-03-07 13:15:00	\N	\N	3	0	\N	\N
810273	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation de familles d'otages israéliennes	Témoignages des familles d'otages israéliens	2024-03-14 15:00:00	2024-03-14 16:15:00	\N	\N	4	0	595	\N
810278	GIA	AUCUNE	\N	\N	\N	Accueil d'une délégation conduite par l'Ambassadeur d'Ukraine	Débat sur l¿accord de sécurité franco-ukrainien et la situation en Ukraine	2024-03-13 18:00:00	2024-03-13 20:45:00	\N	\N	2	0	530	\N
812930	SEANCE_PLENIERE	EXAMEN	\N	\N	\N	PJL Accord UE Canada	PJL Accord UE Canada	2024-03-21 14:30:00	2024-03-21 16:20:00	\N	\N	103	0	\N	\N
815972	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Ordonnance de protection	Audition rapporteur - PPL Ordonnance de protection	2024-03-27 08:00:00	2024-03-27 09:00:00	\N	\N	1	0	\N	\N
815974	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Ordonnance de protection	Audition rapporteur - PPL Ordonnance de protection	2024-03-27 14:00:00	2024-03-27 15:00:00	\N	\N	2	0	\N	\N
815977	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	PPL Ordonnance de protection	Audition rapporteur - PPL Ordonnance de protection	2024-03-27 16:30:00	2024-03-27 18:00:00	\N	\N	1	0	\N	\N
815979	COM_PERMANENTE	AUDRAP	\N	LOIS	\N	Audition rapporteur - MI Application de la loi « JOP »	Audition rapporteur - MI Application de la loi « JOP »	2024-03-28 08:30:00	2024-03-28 09:30:00	\N	\N	2	0	\N	\N
818322	COM_EURO	AUDRAP	\N	AFEU	\N	Audition rapporteur euro numérique	\N	2024-04-02 17:30:00	2024-04-02 18:30:00	\N	\N	2	0	\N	\N
818325	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Audition B. Ameye	\N	2024-04-03 16:30:00	2024-04-03 18:00:00	\N	\N	0	0	\N	\N
818326	AUTRE_TEMPORAIRE	AUTRE	\N	\N	\N	Audition de Mme Dominique CONSILLE	\N	2024-04-03 18:00:00	2024-04-03 19:30:00	\N	\N	0	0	\N	\N
818400	MISSION	AUCUNE	\N	COMP	\N	Audition plénière	\N	2024-04-03 16:45:00	2024-04-03 18:10:00	2024-04-04 16:07:12	2024-04-05 10:21:27	6	0	\N	\N
818423	DELEGATION	AUTRE	\N	\N	DSOM	Action de l'Etat : auditions justice	\N	2024-04-11 09:00:00	2024-04-11 11:00:00	\N	\N	15	0	\N	\N
818530	AUTRE_TEMPORAIRE	GROUPE_TRAVAIL	\N	\N	\N	TR Artificialisation, industrie, et logistique	\N	2024-04-02 16:10:00	2024-04-02 18:55:00	\N	\N	0	0	\N	\N
818561	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI Francophonie	\N	2024-04-09 16:30:00	2024-04-09 17:30:00	\N	\N	5	0	\N	\N
818563	COM_PERMANENTE	AUDRAP	\N	AFCL	\N	MI francophonie	\N	2024-04-02 16:30:00	2024-04-02 17:45:00	\N	\N	1	0	\N	\N
819023	COM_PERMANENTE	AUDRAP	\N	CAE	\N	PPL Marché locatif - CSN	PPL Marché locatif - CSN	2024-04-03 13:30:00	2024-04-03 14:15:00	\N	\N	1	0	\N	\N
821585	GIA	AUCUNE	\N	\N	\N	Audition de M. Jean-François PACTET, Ambassadeur de France à Sri Lanka et aux Maldives	Audition de M. Jean-François PACTET, Ambassadeur de France à Sri Lanka et aux Maldives	2024-04-11 08:30:00	2024-04-11 09:30:00	\N	\N	1	0	550	\N
781735	DELEGATION	AUCUNE	\N	\N	PROS	Audition de Gilles Babinet, co-Président du Conseil national du numérique	\N	2023-12-13 13:40:00	2023-12-13 14:40:00	\N	\N	18	0	\N	\N
781770	COM_EURO	AUDRAP	\N	AFEU	\N	Audition - Nouvelles techniques génomiques	Audition - Nouvelles techniques génomiques	2023-12-12 16:00:00	2023-12-12 17:30:00	\N	\N	3	0	\N	\N
781791	COM_EURO	AUDRAP	\N	AFEU	\N	Auditions nouvelles techniques génomiques (NTG)	Auditions - Nouvelles techniques génomiques (NTG)	2023-12-19 15:30:00	2023-12-19 16:30:00	\N	\N	3	0	\N	\N
782692	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur PPL Bien vieillir	\N	2023-12-13 14:00:00	2023-12-13 15:00:00	\N	\N	3	0	\N	\N
782710	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition PPL Bien vieillir	\N	2023-12-13 16:30:00	2023-12-13 17:30:00	\N	\N	2	0	\N	\N
782715	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Audition rapporteur PPL Bien vieillir	\N	2023-12-13 17:45:00	2023-12-13 18:30:00	\N	\N	3	0	\N	\N
783409	GIA	AUCUNE	\N	\N	\N	Remise du Prix Nathalie Pasternak 2023	Remise du Prix Nathalie Pasternak 2023	2023-12-07 16:00:00	2023-12-07 18:00:00	\N	\N	1	0	530	\N
783411	GIA	AUCUNE	\N	\N	\N	Assemblée générale constitutive	Assemblée générale constitutive	2023-12-13 13:45:00	2023-12-13 15:00:00	\N	\N	15	0	530	\N
783427	GIA	AUCUNE	\N	\N	\N	Entretien avec une délégation de think tanks chinois	\N	2023-12-18 11:00:00	2023-12-18 12:00:00	\N	\N	2	0	584	\N
783803	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe d'amitié France-Autriche	Assemblée générale du groupe d'amitié France-Autriche	2023-12-19 09:30:00	2023-12-19 10:30:00	\N	\N	11	0	579	\N
791724	GIA	AUCUNE	\N	\N	\N	AG 2024 GIA France-République slovaque	\N	2024-01-24 17:15:00	2024-01-24 17:40:00	\N	\N	2	0	532	\N
806000	COM_ENQUETE	DEPLACEMENT	\N	INFLU	\N	Déplacement Viginum	Déplacement Viginum	2024-03-05 14:30:00	2024-03-05 17:00:00	\N	\N	12	0	\N	\N
810793	COM_ENQUETE	PLENIERE	\N	ELEC	\N	TR Energie hydraulique	\N	2024-03-19 14:30:00	2024-03-19 16:25:00	2024-03-27 08:55:27	2024-03-27 16:05:51	10	0	\N	\N
810829	DELEGATION	AUCUNE	\N	\N	COLTER	Réunion plénière	\N	2024-03-28 09:30:00	2024-03-28 12:00:00	\N	\N	19	0	\N	\N
810868	ETUDES	AUTRE	\N	\N	\N	Réunion	\N	2024-03-06 13:15:00	2024-03-06 15:00:00	\N	\N	6	0	\N	918
810879	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition P. TABAROT	\N	2024-03-18 14:00:00	2024-03-18 16:00:00	\N	\N	2	0	\N	\N
810902	COM_PERMANENTE	AUDRAP	\N	CDD	\N	Audition P. TABAROT	\N	2024-03-19 14:40:00	2024-03-19 15:15:00	\N	\N	1	0	\N	\N
810905	MECSS	AUCUNE	\N	\N	MECSS	Réunion plénière	\N	2024-03-19 16:30:00	2024-03-19 18:00:00	2024-03-20 11:11:35	2024-03-20 17:27:39	6	0	\N	\N
810911	COM_PERMANENTE	DEPLACEMENT	\N	SOCI	\N	Déjeuner à l'ambassade du Danemark	\N	2024-03-19 12:15:00	2024-03-19 13:45:00	\N	\N	5	0	\N	\N
811044	ETUDES	AUTRE	\N	\N	\N	Table ronde anciens sénateurs	\N	2024-03-27 13:30:00	2024-03-27 15:00:00	\N	\N	4	0	\N	1006
821396	ETUDES	AUCUNE	\N	\N	\N	Réunion constitutive	Réunion constitutive	2024-04-09 16:15:00	2024-04-09 17:15:00	\N	\N	10	0	\N	1007
821418	BUREAU	AUCUNE	\N	\N	\N	Délégation en charge du travail parlementaire	Délégation en charge du travail parlementaire	2024-04-09 14:45:00	2024-04-09 15:30:00	\N	\N	2	0	\N	\N
821421	BUREAU	AUCUNE	\N	\N	\N	Délégation en charge du travail parlementaire	Délégation en charge du travail parlementaire	2024-04-10 11:00:00	2024-04-10 12:45:00	\N	\N	1	0	\N	\N
83272	CMP	AUTRE	\N	BLEUE	\N	BLEUE 	BLEUE 	2016-04-06 18:00:00	2016-04-06 19:15:00	\N	\N	10	0	\N	\N
821783	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	Réunion de la Commission spéciale	Réunion de la Commission spéciale chargée du contrôle des comptes et de l'évaluation interne	2024-04-10 16:35:00	2024-04-10 18:00:00	\N	\N	4	0	\N	\N
821858	BUREAU	AUCUNE	\N	\N	\N	Réunion du Bureau	Réunion du Bureau	2024-04-11 08:40:00	2024-04-11 10:45:00	\N	\N	22	0	\N	\N
773785	GIA	AUCUNE	\N	\N	\N	Déjeuner avec une délégation de députés moldaves	Déjeuner avec une délégation de députés moldaves à l'invitation du groupe d'amitié de l'Assemblée nationale	2023-11-28 12:30:00	2023-11-28 15:00:00	\N	\N	1	0	851	\N
782155	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	PPL Société du bien vieillir - Audition Orpea et LNA Santé	\N	2023-12-12 16:30:00	2023-12-12 17:30:00	\N	\N	6	0	\N	\N
782162	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audition commissaires duu gouvernement	\N	2023-12-06 11:30:00	2023-12-06 12:30:00	\N	\N	1	0	\N	\N
782581	COM_PERMANENTE	AUDRAP	\N	SOCI	\N	Table ronde d'association de directeurs	\N	2023-12-12 17:30:00	2023-12-12 18:30:00	\N	\N	7	0	\N	\N
786312	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe	\N	2023-12-12 17:00:00	2023-12-12 17:30:00	\N	\N	16	0	595	\N
786329	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe	\N	2023-12-14 10:00:00	2023-12-14 10:30:00	\N	\N	2	0	620	\N
786332	GIA	AUCUNE	\N	\N	\N	Assemblée générale du groupe	\N	2023-12-20 13:00:00	2023-12-20 13:30:00	\N	\N	4	0	612	\N
794580	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Auditions MI lutte anti-drone	Auditions MI lutte anti-drone	2024-01-16 09:00:00	2024-01-16 12:15:00	\N	\N	3	0	\N	\N
794584	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	Audition MI Lutte  anti-drone	Auditions MI lutte anti-drone	2024-01-16 14:30:00	2024-01-16 18:30:00	\N	\N	3	0	\N	\N
797964	SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	2061	\N	\N	EV PJL/PJLO Nucléaire	EV PJL/PJLO Nucléaire	2024-02-13 14:30:00	2024-02-13 15:50:00	\N	\N	286	0	\N	\N
797965	SEANCE_PLENIERE	SCRUSOL	2061	\N	\N	Scrutin solennel PJL Nucléaire	Scrutin solennel PJL Nucléaire	2024-02-13 15:50:00	2024-02-13 15:55:00	\N	\N	0	0	\N	\N
797966	SEANCE_PLENIERE	SCRUSOL	2062	\N	\N	Scrutin solennel PJLO Nucléaire	Scrutin solennel PJLO Nucléaire	2024-02-13 15:55:00	2024-02-13 16:00:00	\N	\N	0	0	\N	\N
811752	COM_ENQUETE	PLENIERE	\N	INFLU	\N	Auditions Elsa Pilichowski (OCDE) et Roch-Olivier Maistre (ARCOM)	Auditions Elsa Pilichowski (OCDE) et Roch-Olivier Maistre (ARCOM)	2024-03-19 14:35:00	2024-03-19 17:15:00	2024-03-20 14:46:06	2024-03-20 17:22:34	11	0	\N	\N
812078	COM_PERMANENTE	AUDRAP	\N	CAE	\N	MI Atos	MI Atos	2024-03-19 17:00:00	2024-03-19 18:00:00	\N	\N	2	0	\N	\N
814657	GIA	AUCUNE	\N	\N	\N	entretien avec l'ambassadeur du Laos, S.E. M. Kham-Inh KHITCHADETH	\N	2024-03-27 08:30:00	2024-03-28 09:30:00	\N	\N	2	0	577	\N
817593	ETUDES	AUCUNE	\N	\N	\N	Section Cheval -Audtion M. Laurent Duray, président de LIM Group.	Section Cheval -Audtion M. Laurent Duray, président de LIM Group.	2024-04-03 08:00:00	2024-04-03 09:00:00	\N	\N	4	0	\N	912
818012	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Audition de M. Dragan Krapovic	Audition de M. Dragan Krapovic	2024-04-03 10:15:00	2024-04-03 11:40:00	2024-04-03 16:53:44	2024-04-03 17:26:34	25	0	\N	\N
818533	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GS ZAN	Groupe de travail - GS ZAN	2024-04-02 16:10:00	2024-04-02 17:30:00	\N	\N	4	0	\N	\N
818539	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CAE	\N	GS ZAN	Groupe de travail - GS ZAN	2024-04-02 17:30:00	2024-04-02 18:55:00	\N	\N	4	0	\N	\N
818545	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	GS ZAN	Groupe de travail - GS ZAN	2024-04-02 16:10:00	2024-04-02 17:30:00	\N	\N	5	0	\N	\N
818551	COM_PERMANENTE	GROUPE_TRAVAIL	\N	CDD	\N	GS ZAN	Groupe de travail - GS ZAN	2024-04-02 17:30:00	2024-04-02 18:55:00	\N	\N	5	0	\N	\N
818803	COM_APURATION	AUCUNE	\N	COMSPEAPU	\N	Commission spéciale	Commission spéciale de contrôle des comptes	2024-04-03 16:35:00	2024-04-03 17:50:00	2024-04-04 10:56:55	\N	6	0	\N	\N
819056	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	PLF pour 2023 - p. 185	PLF pour  2023 - p. 185	2024-04-03 17:30:00	2024-04-03 18:30:00	\N	\N	1	0	\N	\N
819068	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI ATOS	MI ATOS	2024-03-19 17:00:00	2024-03-19 18:00:00	\N	\N	2	0	\N	\N
819071	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI ATOS	MI ATOS	2024-03-20 18:00:00	2024-03-20 20:00:00	\N	\N	2	0	\N	\N
819074	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI ATOS	MI ATOS	2024-03-27 17:30:00	2024-03-27 20:30:00	\N	\N	1	0	\N	\N
819076	COM_PERMANENTE	AUDRAP	\N	ETRD	\N	MI ATOS	MI ATPS	2024-03-27 16:30:00	2024-03-27 19:30:00	\N	\N	1	0	\N	\N
39572	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	PLF 2016 - "Ville", "Energie" et " Pêche"	2015-11-25 09:30:00	2015-11-25 12:20:00	2018-05-18 14:20:43	2018-05-18 14:21:22	34	0	\N	\N
26169	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2015-10-21 09:30:00	2015-10-21 10:05:00	2015-10-22 16:01:07	2015-10-22 17:14:45	30	0	\N	\N
27469	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-10-28 09:38:00	2015-10-28 12:24:00	2015-10-28 15:42:14	2015-10-28 17:20:43	46	0	\N	\N
23146	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	Texte 17, 470, 693	2015-10-14 09:00:00	2015-10-14 12:05:00	2015-10-14 17:47:02	2015-10-14 17:55:13	30	0	\N	\N
25476	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-10-21 09:00:00	2015-10-21 12:50:00	2015-10-21 14:59:06	2015-10-21 17:03:31	48	0	\N	\N
48681	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2015-12-16 09:30:00	2015-12-16 11:10:00	2015-12-16 12:58:45	2015-12-16 15:10:22	49	0	\N	\N
48799	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	PPL n° 245	2015-12-16 09:30:00	2015-12-16 11:10:00	2015-12-16 15:22:20	2015-12-16 15:34:28	30	0	\N	\N
48936	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2015-12-16 09:05:00	2015-12-16 10:20:00	2015-12-16 15:23:52	2015-12-16 15:34:29	43	0	\N	\N
49077	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2015-12-16 09:35:00	2015-12-16 12:40:00	2015-12-16 16:35:26	2015-12-16 16:37:01	38	0	\N	\N
53417	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2016-01-20 09:30:00	2016-01-20 11:10:00	2016-01-20 14:43:22	2016-01-20 16:45:48	51	0	\N	\N
62357	COM_PERMANENTE	AUTRE	\N	AFCL	\N	AFCL 	AFCL 	2016-02-10 09:30:00	2016-02-10 10:10:00	2016-02-10 17:16:54	2016-02-10 17:45:10	48	0	\N	\N
65362	COM_PERMANENTE	AUTRE	\N	SOCI	\N	SOCI 	SOCI 	2016-02-17 09:30:00	2016-02-17 11:05:00	2016-02-17 11:32:35	2016-02-17 16:16:10	48	0	\N	\N
72867	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	CAE 	2016-03-16 09:35:00	2016-03-16 11:05:00	2016-03-16 12:16:17	2016-03-16 16:50:11	33	0	\N	\N
72949	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2016-03-16 09:30:00	2016-03-16 10:05:00	2016-03-17 10:01:21	2016-03-17 11:34:56	43	0	\N	\N
73151	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2016-03-16 10:05:00	2016-03-16 10:50:00	2018-05-18 14:37:00	2018-05-18 14:37:05	49	1	\N	\N
76539	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	CAE 	2016-03-23 10:00:00	2016-03-23 10:45:00	2018-05-18 14:38:50	2018-05-18 14:38:57	29	0	\N	\N
76581	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2016-03-23 09:00:00	2016-03-23 09:25:00	2016-03-23 12:24:22	2016-03-23 15:20:10	31	0	\N	\N
76903	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-03-23 09:30:00	2016-03-23 13:00:00	2018-05-18 14:38:16	2018-05-18 14:38:24	45	0	\N	\N
82770	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2016-04-06 09:30:00	2016-04-06 10:10:00	2016-04-07 12:06:52	2016-04-07 12:09:21	27	0	\N	\N
84768	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-04-27 09:10:00	2016-04-27 12:10:00	2018-05-18 14:45:31	2018-05-18 14:45:37	41	0	\N	\N
88554	COM_PERMANENTE	AUTRE	\N	FINC	\N	FINC 	FINC 	2016-05-04 09:30:00	2016-05-04 10:35:00	2018-05-18 14:50:25	2018-05-18 14:50:31	43	0	\N	\N
88703	COM_PERMANENTE	AUTRE	\N	CDD	\N	CDD 	CDD 	2016-05-04 08:30:00	2016-05-04 10:55:00	2016-05-04 15:56:56	2016-05-04 17:46:41	32	0	\N	\N
82830	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-04-06 09:10:00	2016-04-06 13:20:00	2018-05-18 14:43:17	2018-05-18 14:43:20	41	0	\N	\N
90699	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	CAE 	2016-05-11 09:30:00	2016-05-11 10:25:00	2018-05-18 14:52:17	2018-05-18 14:52:22	31	0	\N	\N
90842	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-05-11 09:40:00	2016-05-11 12:05:00	2018-05-18 14:52:38	2018-05-18 14:52:41	42	0	\N	\N
95782	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	CAE 	2016-05-25 11:40:00	2016-05-25 12:25:00	2018-05-18 14:57:57	2018-05-18 14:58:05	31	0	\N	\N
104995	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2016-06-15 09:30:00	2016-06-15 11:20:00	2018-05-18 15:06:45	2018-05-18 15:06:53	48	1	\N	\N
105535	COM_PERMANENTE	AUTRE	\N	LOIS	\N	LOIS 	LOIS 	2016-06-15 08:40:00	2016-06-15 11:15:00	2016-06-15 17:04:45	2016-06-15 17:47:34	37	0	\N	\N
93391	COM_PERMANENTE	AUTRE	\N	CAE	\N	CAE 	CAE 	2016-05-18 11:35:00	2016-05-18 11:40:00	2018-05-18 14:55:27	2018-05-18 14:55:47	32	0	\N	\N
101058	COM_PERMANENTE	AUTRE	\N	ETRD	\N	ETRD 	ETRD 	2016-06-08 09:00:00	2016-06-08 10:30:00	2018-05-18 15:01:44	2018-05-18 15:01:50	46	1	\N	\N
98894	COM_PERMANENTE	AUTRE	\N	ETRD	\N	PPRE sanctions UE contre la Russie	ETRD 	2016-06-01 09:05:00	2016-06-01 10:55:00	2016-06-01 14:45:58	2016-06-01 18:05:07	46	1	\N	\N
129894	COM_PERMANENTE	AUTRE	\N	CDD	\N	PPL Transport public particulier de personnes	PPL Transport public particulier de personnes	2016-10-19 11:15:00	2016-10-19 12:25:00	2016-10-20 14:19:15	2016-10-20 14:59:58	31	0	\N	\N
130942	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2017 - Missions DAG et Médias, livre et industries culturelles	PLF pour 2017 - Missions DAG et Médias, livre et industries culturelles	2016-10-26 09:05:00	2016-10-26 10:30:00	2016-10-26 18:00:27	2016-10-26 18:08:38	43	0	\N	\N
131029	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Action extérieure, PPL Carte intercommunale, PJL Sapin 2+PPLO, PJL Statut Paris	\N	2016-10-26 08:35:00	2016-10-26 12:00:00	2016-10-26 15:03:18	2016-10-26 16:08:13	40	0	\N	\N
133371	COM_PERMANENTE	AUTRE	\N	FINC	\N	Sapin 2 (examen amendements séance) - PJL pour 2017 - Missions Ecologie	Sapin 2 (examen amendements séance) - PJL pour 2017 - Missions Ecologie  - Transports - Météo - Contrôle aérien	2016-11-02 09:35:00	2016-11-02 11:20:00	2016-11-02 15:38:07	2016-11-02 17:16:34	38	0	\N	\N
128852	COM_PERMANENTE	AUTRE	\N	CAE	\N	Mixité sociale autour des gares du Grand Paris Express	Proposition de loi visant à garantir la mixité sociale aux abords des gares du Grand Paris Express	2016-10-19 09:30:00	2016-10-19 10:10:00	2016-10-19 11:20:21	2016-10-19 16:45:41	32	0	\N	\N
131393	COM_PERMANENTE	AUTRE	\N	CDD	\N	Liaison ferroviaire entre Paris et l'aéroport Paris-Charles de Gaulle	Liaison ferroviaire entre Paris et l'aéroport Paris-Charles de Gaulle	2016-10-26 11:25:00	2016-10-26 12:15:00	2018-05-18 15:37:13	2018-05-18 15:37:19	32	0	\N	\N
136959	COM_PERMANENTE	AUTRE	\N	CAE	\N	Examen rapports pour avis budgétaires	Examen rapports pour avis budgétaires	2016-11-09 09:30:00	2016-11-09 11:00:00	2016-11-09 17:20:53	2016-11-09 17:33:25	35	0	\N	\N
143052	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2017 - Missions Égalité des territoires, Enseignement scolaire, Agriculture, AGTE	PLF pour 2017 - Missions Égalité des territoires, Enseignement scolaire, Agriculture, AGTE	2016-11-23 09:00:00	2016-11-23 12:40:00	2016-11-24 18:15:04	2016-11-24 18:18:45	48	0	\N	\N
143160	COM_PERMANENTE	AUTRE	\N	CAE	\N	Examen pour avis PLF 2017, Outre-mer, recherche,logement, ville	Examen pour avis PLF 2017? Outre-mer, recherche et enseignement supérieur, logement, ville	2016-11-23 09:35:00	2016-11-23 12:20:00	2018-05-18 15:41:29	2018-05-18 15:41:49	31	0	\N	\N
143476	COM_PERMANENTE	AUTRE	\N	CDD	\N	Examen PLF 2017, Transports ferroviaires, aériens, maritimes	Examen pour avis sur les crédits : Transports ferroviaires, aériens, maritimes PLF 2017	2016-11-23 10:40:00	2016-11-23 13:00:00	2018-05-18 15:42:07	2018-05-18 15:42:17	33	0	\N	\N
136943	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2017 - Rapport général Tome I  et mission "Investissements d'avenir"	PLF pour 2017 - Rapport général Tome I et mission "Investissements d'avenir"	2016-11-09 09:40:00	2016-11-09 11:10:00	2016-11-10 09:20:06	2016-11-10 09:30:44	45	0	\N	\N
137099	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Statut de Paris + PLF 2017 Avis Protection droits + PLF 2017 Avis Fonction publique	\N	2016-11-09 10:20:00	2016-11-09 11:40:00	2016-11-09 15:35:59	2016-11-09 16:54:00	39	1	\N	\N
143161	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PLF 2017 - Divers avis budgétaires	\N	2016-11-23 09:40:00	2016-11-23 13:00:00	2016-11-23 14:30:45	2016-11-23 17:52:06	43	0	\N	\N
144193	CMP	AUTRE	\N	PLFSS2017	\N	PLFSS 2017	Projet de loi de financement de la sécurité sociale pour 2017	2016-11-22 18:00:00	2016-11-22 18:45:00	\N	\N	8	0	\N	\N
137032	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2016-11-09 10:05:00	2016-11-09 11:30:00	2016-11-09 14:00:24	2016-11-09 15:19:41	43	0	\N	\N
137200	COM_PERMANENTE	AUTRE	\N	CDD	\N	PLF pour 2017	\N	2016-11-09 09:30:00	2016-11-09 10:50:00	2016-11-09 16:01:39	2016-11-09 16:53:57	31	0	\N	\N
143101	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2016-11-23 09:15:00	2016-11-23 11:45:00	2016-11-23 16:04:58	2016-11-23 17:52:12	48	1	\N	\N
139290	COM_PERMANENTE	AUTRE	\N	CDD	\N	\N	\N	2016-11-16 10:15:00	2016-11-16 12:05:00	2018-05-18 15:40:51	2018-05-18 15:40:58	30	0	\N	\N
145572	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Transports scolaires	\N	2016-11-30 10:05:00	2016-11-30 11:05:00	2016-11-30 12:16:54	2016-11-30 16:13:24	31	0	\N	\N
137370	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2016-11-09 09:05:00	2016-11-09 13:15:00	2016-11-09 15:19:50	2016-11-09 16:53:56	48	0	\N	\N
139057	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2016-11-16 09:05:00	2016-11-16 10:30:00	2016-11-16 16:42:54	2016-11-16 17:27:09	47	1	\N	\N
162943	COM_PERMANENTE	AUTRE	\N	LOIS	\N	\N	\N	2017-01-18 09:10:00	2017-01-18 11:50:00	2017-01-18 12:52:09	2017-01-18 17:14:50	41	1	\N	\N
151599	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Prorogation de l'état d'urgence	\N	2016-12-14 10:30:00	2016-12-14 11:55:00	2016-12-14 15:10:43	2016-12-14 15:27:46	28	1	\N	\N
156101	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Cour d'assises spéciale PPLO Autorités administratives indépendantes	\N	2016-12-21 09:15:00	2016-12-21 10:10:00	2016-12-21 12:14:06	2016-12-21 15:07:48	26	0	\N	\N
158545	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Égalité réelle outre-mer +  PPL Devoir de vigilance des sociétés mères	\N	2017-01-11 09:40:00	2017-01-11 12:20:00	2017-01-12 09:51:54	2017-01-12 14:55:31	47	0	\N	\N
163084	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2017-01-18 09:50:00	2017-01-18 10:35:00	2017-01-18 14:48:11	2017-01-18 17:14:54	51	1	\N	\N
147987	COM_PERMANENTE	AUTRE	\N	CAE	\N	ordonnances relatives à la consommation	ordonnances relatives à la consommation	2016-12-07 10:00:00	2016-12-07 10:30:00	2018-05-18 15:44:31	2018-05-18 15:44:38	31	0	\N	\N
151392	COM_PERMANENTE	AUTRE	\N	FINC	\N	Communication ACCIS et Examen de 2 PPRE (n°123 et 124)	Communication propositions de directives ACCIS et Examen des rapports de 2 PPRE (n°123 et 124)	2016-12-14 09:35:00	2016-12-14 10:40:00	2016-12-15 15:33:48	2016-12-15 16:51:22	39	0	\N	\N
156382	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLFR pour 2016 - Examen du rapport en nouvelle lecture - Rapport ACCIS	PLFR pour 2016 - Examen du rapport en nouvelle lecture - Rapport ACCIS	2016-12-21 09:05:00	2016-12-21 09:50:00	2016-12-21 17:47:57	2016-12-21 17:50:29	35	0	\N	\N
162781	CMP	AUTRE	\N	ANSM	\N	PJL Diverses dispositions relatives aux produits de santé	\N	2017-01-17 18:25:00	2017-01-17 18:40:00	\N	\N	8	0	\N	\N
162893	COM_PERMANENTE	AUTRE	\N	FINC	\N	PJL Ordonnances Corse et PLJ Echange déclarations pays par pays - Examen rapport	PJL Ordonnances Corse et PLJ Echange déclarations pays par pays - Examen rapport	2017-01-18 09:30:00	2017-01-18 10:05:00	2017-01-18 16:55:35	2017-01-18 17:14:51	41	0	\N	\N
176225	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2017-02-15 10:00:00	2017-02-15 10:20:00	2017-02-16 09:50:00	2017-02-16 16:43:47	47	1	\N	\N
177613	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Comptes des collectivités territoriales + PPL Compétences eau et assainissement	\N	2017-02-22 10:05:00	2017-02-22 11:00:00	2017-02-22 13:54:24	2017-02-22 15:46:01	34	1	\N	\N
171812	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2017-02-08 09:30:00	2017-02-08 11:15:00	2017-02-08 14:08:53	2017-02-08 15:44:37	47	0	\N	\N
165408	CMP	AUTRE	\N	IVG	\N	PPL Délit d'entrave à l'IVG	PPL Délit d'entrave à l'IVG	2017-01-24 17:00:00	2017-01-24 17:40:00	\N	\N	9	0	\N	\N
169551	COM_PERMANENTE	AUTRE	\N	CAE	\N	lutte contre l'accaparement des terres agricoles	lutte contre l'accaparement des terres agricoles	2017-02-01 09:05:00	2017-02-01 10:00:00	2018-05-18 15:50:31	2018-05-18 15:50:36	36	0	\N	\N
172435	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PPL Délit d'entrave à l'IVG	\N	2017-02-08 09:05:00	2017-02-08 09:30:00	2017-02-08 15:17:51	2017-02-08 15:44:36	50	1	\N	\N
176012	COM_PERMANENTE	AUTRE	\N	CDD	\N	Droit à l'eau potable et à l'assainissement	Droit à l'eau potable et à l'assainissement	2017-02-15 10:00:00	2017-02-15 10:55:00	2018-05-18 15:53:41	2018-05-18 15:53:45	31	0	\N	\N
208443	COM_PERMANENTE	AUTRE	\N	CDD	\N	PPL n° 703 Service public d'eau potable	PPL n° 703 Service public d'eau potable	2017-10-18 09:30:00	2017-10-18 10:10:00	2017-10-18 14:31:09	2017-10-18 16:43:53	39	0	\N	\N
210117	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Accueil des gens du voyage	\N	2017-10-25 10:20:00	2017-10-25 11:45:00	2017-10-25 12:04:11	2017-10-25 14:55:11	42	0	\N	\N
210152	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2018 - Examen missions Immigration-R&D-APD-CCE	PLF pour 2018 - Examen missions Immigration-R&D-APD-CCE	2017-10-25 09:45:00	2017-10-25 12:30:00	2017-10-25 16:54:43	2017-10-25 16:59:23	47	0	\N	\N
210160	COM_PERMANENTE	AUTRE	\N	CDD	\N	PJL n° 21 Fin de la recherche et de l'exploitation des hydrocarbures	PJL n° 21 Fin de la recherche et de l'exploitation des hydrocarbures	2017-10-25 09:05:00	2017-10-25 10:10:00	2017-10-25 14:33:18	2017-10-25 14:55:16	44	0	\N	\N
210161	COM_PERMANENTE	AUTRE	\N	CAE	\N	PJL n° 21 Fin de la recherche et de l'exploitation des hydrocarbures	PJL n° 21 Fin de la recherche et de l'exploitation des hydrocarbures	2017-10-25 09:35:00	2017-10-25 12:00:00	2017-10-25 15:27:13	2017-10-25 15:27:38	46	0	\N	\N
257788	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Protection des mineurs victimes d'infractions sexuelles	\N	2018-03-21 10:10:00	2018-03-21 12:10:00	2018-03-23 11:17:03	2018-03-23 15:17:37	43	0	\N	\N
214549	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	\N	2017-11-08 09:05:00	2017-11-08 13:00:00	2017-11-08 13:10:19	2017-11-08 14:33:09	48	0	\N	\N
221367	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion	Réunion	2017-11-22 09:00:00	2017-11-22 12:25:00	2017-11-22 12:34:13	2017-11-22 15:35:10	46	1	\N	\N
313439	COM_PERMANENTE	AUTRE	\N	SOCI	\N	réunion plénière	\N	2018-10-24 11:15:00	2018-10-24 11:35:00	2018-10-24 11:37:08	2018-10-24 12:15:24	46	0	\N	\N
273624	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2018-05-23 08:35:00	2018-05-23 12:10:00	2018-05-23 17:29:14	2018-05-23 17:40:09	43	2	\N	\N
275756	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen du rapport pour avis PPL n°343 transmission d'entreprise	Examen du rapport pour avis PPL n°343 Modernisation transmission d'entreprise	2018-05-30 09:05:00	2018-05-30 10:40:00	2018-06-01 09:42:38	2018-06-01 09:43:20	44	1	\N	\N
317525	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2018-10-31 10:45:00	2018-10-31 11:50:00	2018-10-31 17:20:24	2018-10-31 17:39:45	36	0	\N	\N
318025	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2018-11-07 09:05:00	2018-11-07 10:25:00	2018-11-07 14:42:39	2018-11-07 15:25:39	39	2	\N	\N
222588	COM_PERMANENTE	AUTRE	\N	CDD	\N	PLF 2018 « Transports maritimes » mission « Écologie, développement et mobilité durables »	PLF 2018 « Transports maritimes » de la mission « Écologie, développement et mobilité durables »	2017-11-29 09:35:00	2017-11-29 11:05:00	2017-11-29 15:49:08	2017-11-29 16:50:33	30	0	\N	\N
223254	COM_PERMANENTE	AUTRE	\N	CAE	\N	PLF 2018,« Énergie » « Politique de la ville »« Recherche et enseignement supérieur »  	PLF 2018,« Énergie » « Politique de la ville »« Recherche et enseignement supérieur » 	2017-11-29 09:35:00	2017-11-29 12:05:00	2017-11-29 17:11:42	2017-11-29 17:11:56	49	0	\N	\N
223266	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PLF 2018 (6 avis budgétaires)	\N	2017-11-29 09:15:00	2017-11-29 11:45:00	2017-11-29 16:36:32	2017-11-29 16:50:36	44	0	\N	\N
287012	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Nom. rapporteurs - Avis Dél° dts femmes + amdts PJL Lutte contre les violences sexuelles	Réunion 2018 06 20	2018-06-20 08:40:00	2018-06-20 12:10:00	2018-06-20 14:39:24	2018-06-20 16:07:14	43	1	\N	\N
214493	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2017-11-08 09:35:00	2017-11-08 12:00:00	2017-11-08 15:44:18	2017-11-08 15:51:12	43	0	\N	\N
214587	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen équilibre PLF pour 2018-Rapport PLFR 2017-Amdts LPFP 2018-2022-PLF 2018 outre-mer	Examen équilibre PLF pour 2018-Rapport PLFR pour 2017-Amdts LPFP 2018-2022-PLF pour 2018 rapport outre-mer	2017-11-08 09:05:00	2017-11-08 12:50:00	2017-11-09 09:49:08	2017-11-09 15:57:20	44	0	\N	\N
241370	CMP	AUTRE	\N	DDADUE	\N	PJL Adaptation dans le domaine de la sécurité au droit de l'UE	PJL Adaptation dans le domaine de la sécurité au droit de l'UE	2018-02-05 18:15:00	2018-02-05 18:25:00	\N	\N	5	0	\N	\N
326521	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2018-11-21 10:00:00	2018-11-21 12:30:00	2018-11-21 12:33:30	2018-11-21 14:52:34	41	0	\N	\N
328229	COM_PERMANENTE	AUTRE	\N	ETRD	\N	PLF pour 2019	PLF 2019 - prog. 152 et 844/847	2018-11-28 09:35:00	2018-11-28 10:50:00	2018-11-28 12:05:55	2018-11-28 12:14:42	39	1	\N	\N
329158	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2018-11-28 09:35:00	2018-11-28 11:45:00	2018-11-28 12:17:32	2018-11-28 16:10:06	46	0	\N	\N
329159	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PLF 2019 - Rapports pour avis	PLF 2019 - Rapports pour avis	2018-11-28 09:05:00	2018-11-28 12:05:00	2018-11-29 15:49:35	2018-11-29 15:52:55	42	0	\N	\N
330074	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2018-11-28 09:35:00	2018-11-28 11:50:00	2018-11-28 12:06:53	2018-11-28 12:14:40	44	0	\N	\N
219487	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2017-11-22 09:35:00	2017-11-22 12:10:00	2017-11-22 14:46:49	2017-11-22 15:30:26	46	0	\N	\N
298591	CMP	AUTRE	\N	EGALIM	\N	PJL Relations commerciales dans le secteur agricole et alimentaire	PJL Relations commerciales dans le secteur agricole et alimentaire	2018-07-10 13:30:00	2018-07-10 15:00:00	\N	\N	10	0	\N	\N
331592	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Funérailles républicaines, Communes nouvelles-Rapport et texte	PPL Funérailles républicaines, Communes nouvelles-Rapport et texte	2018-12-05 08:35:00	2018-12-05 10:50:00	2018-12-05 12:12:10	2018-12-05 16:42:22	40	1	\N	\N
307506	COM_PERMANENTE	AUTRE	\N	SOCI	\N	plénière	\N	2018-10-10 08:30:00	2018-10-10 09:30:00	2018-10-10 12:39:27	2018-10-10 12:46:02	45	0	\N	\N
338719	CMP	AUTRE	\N	ORDONNANCES	\N	PJL Mesures de préparation au retrait du Royaume-Uni de l'UE	PJL Mesures de préparation au retrait du Royaume-Uni de l'UE	2018-12-18 08:39:00	2018-12-18 09:53:00	\N	\N	9	0	\N	\N
308553	CMP	AUTRE	\N	INFORMATION	\N	PPLO Lutte contre la manipulation de l'information	PPLO Lutte contre la manipulation de l'information	2018-09-26 09:23:00	2018-09-26 09:24:00	\N	\N	13	0	\N	\N
308568	CMP	AUTRE	\N	MANIPULATION	\N	PPL Lutte contre la manipulation de l'information	PPL Lutte contre la manipulation de l'information	2018-09-26 09:00:00	2018-09-26 09:22:00	\N	\N	14	0	\N	\N
319275	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2019 - Examen Rapports Tome 1 du RG-Solidarité-AGTE	PLF pour 2019 - Examen Rapports Tome 1 du RG-Solidarité-AGTE	2018-11-07 09:05:00	2018-11-07 12:20:00	2018-11-07 14:37:19	2018-11-07 14:37:48	40	0	\N	\N
262943	COM_PERMANENTE	AUTRE	\N	ETRD	\N	3 conventions	Conventions Nigéria, OIT et Andorre	2018-04-11 09:35:00	2018-04-11 10:00:00	2018-04-12 09:27:37	2018-04-12 10:09:02	41	1	\N	\N
295801	CMP	AUTRE	\N	POLYNESIE	\N	PJL Sanctions en matière de concurrence en Polynésie française	PJL Sanctions en matière de concurrence en Polynésie française	2018-07-04 11:06:00	2018-07-04 11:27:00	\N	\N	10	0	\N	\N
298958	CMP	AUTRE	\N	AVENIR	\N	PJL Liberté de choisir son avenir professionnel	PJL Liberté de choisir son avenir professionnel	2018-07-16 19:33:00	2018-07-16 19:59:00	\N	\N	10	0	\N	\N
320977	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen Rapport Tome II PLF pour 2019 - Rapport PLFR 2018 - Rapport PLF pour 2019 Culture	Examen Rapport Tome II PLF pour 2019 - Rapport PLFR 2018 - Rapport PLF pour 2019 Culture	2018-11-14 08:35:00	2018-11-14 12:15:00	2018-11-14 12:49:01	2018-11-14 14:05:55	44	0	\N	\N
279254	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen Amendements PPL 443 Modernisation transmission d'entreprises	Examen Amendements PPL 443 Modernisation transmission d'entreprises	2018-06-06 10:05:00	2018-06-06 10:50:00	2018-06-08 18:32:46	2018-06-08 19:33:58	37	0	\N	\N
214524	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Représentation des communes déléguées	\N	2017-11-08 10:10:00	2017-11-08 11:55:00	2017-11-08 14:53:37	2017-11-08 15:51:05	40	0	\N	\N
264097	CMP	AUTRE	\N	DONNEES	\N	PJL Protection des données personnelles	PJL Protection des données personnelles	2018-04-06 10:05:00	2018-04-06 10:55:00	\N	\N	8	0	\N	\N
267061	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2018-04-18 10:05:00	2018-04-18 10:55:00	2018-04-18 12:38:27	2018-04-18 16:47:45	41	2	\N	\N
326818	CMP	AUTRE	\N	PLFR2018	\N	PLFR pour 2018	PLFR pour 2018	2018-11-20 18:03:00	2018-11-20 18:14:00	\N	\N	10	0	\N	\N
227892	COM_PERMANENTE	AUTRE	\N	CAE	\N	Fin de la recherche et de l'exploitation des hydrocarbures	Fin de la recherche et de l'exploitation des hydrocarbures	2017-12-13 09:35:00	2017-12-13 10:25:00	2017-12-13 16:49:05	2017-12-13 16:49:50	44	0	\N	\N
228415	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLFR pour 2017 - Examen du rapport	PLFR pour 2017 - Examen du rapport	2017-12-13 09:35:00	2017-12-13 10:55:00	2017-12-14 15:59:08	2017-12-14 16:24:24	42	1	\N	\N
311331	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Violences manifestations (rapport) - PPL & PPLO Fake News (avis et rapport)	PPL Violences manifestations (rapport) - PPL & PPLO Fake News (avis et rapport)	2018-10-17 11:35:00	2018-10-17 12:45:00	2018-10-17 14:52:47	2018-10-17 15:34:18	43	1	\N	\N
354229	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-02-20 10:30:00	2019-02-20 11:35:00	2019-02-20 11:48:08	2019-02-20 15:03:57	40	2	\N	\N
355377	CMP	AUTRE	\N	CROISSENTRE	\N	PJL Croissance et transformation des entreprises	PJL Croissance et transformation des entreprises	2019-02-20 14:33:00	2019-02-20 15:43:00	\N	\N	11	0	\N	\N
244323	COM_PERMANENTE	AUTRE	\N	CAE	\N	accord de libre-échange entre l¿Union européenne l¿Australie et la Nouvelle-Zélande	accord de libre-échange entre l¿Union européenne l¿Australie et la Nouvelle-Zélande	2018-02-14 11:25:00	2018-02-14 12:45:00	2018-02-14 17:56:51	2018-02-14 18:21:44	44	0	\N	\N
214883	COM_PERMANENTE	AUTRE	\N	CDD	\N	PLF 2018, transports routiers, ferroviaires, Écologie	PLF 2018, transports routiers, ferroviaires, Écologie, développement et mobilité durables  	2017-11-08 11:20:00	2017-11-08 12:35:00	2017-11-08 14:58:36	2017-11-08 15:51:01	45	0	\N	\N
361174	COM_PERMANENTE	AUTRE	\N	CDD	\N	Examen des motions et amendements de séance - PJL Orientation des mobilités	\N	2019-03-20 09:35:00	2019-03-20 10:10:00	2019-03-20 14:56:05	2019-03-20 15:55:48	38	0	\N	\N
361271	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-03-20 09:35:00	2019-03-20 10:25:00	2019-03-20 15:53:11	2019-03-20 16:12:54	42	0	\N	\N
230588	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLFR pour 2017-Nlle Lecture  - Examen rapport	PLFR pour 2017-Nlle Lecture  - Examen rapport	2017-12-20 10:05:00	2017-12-20 10:50:00	2017-12-20 17:31:13	2017-12-20 17:35:43	33	1	\N	\N
322291	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	\N	2018-11-14 10:30:00	2018-11-14 12:20:00	2018-11-14 20:02:51	2018-11-15 14:56:24	38	1	\N	\N
273907	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion - Avis Centres-villes et centres-bourgs	Réunion - Avis Centres-villes et centres-bourgs	2018-05-23 10:20:00	2018-05-23 11:50:00	2018-05-23 12:08:07	2018-05-23 16:02:33	36	2	\N	\N
324291	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL-PJLO Justice Nomination mbres CMP - PPLO Election sénateurs Amdts séance - Avis budg	PJL-PJLO Justice Nomination mbres CMP - PPLO Election sénateurs Amdts séance - Avis budg	2018-11-21 08:40:00	2018-11-21 12:05:00	2018-11-21 12:43:29	2018-11-21 14:52:39	42	2	\N	\N
315530	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2018-10-24 11:15:00	2018-10-24 12:05:00	2018-10-24 12:18:52	2018-10-24 13:00:16	41	1	\N	\N
226991	CMP	AUTRE	\N	PHYSICIEN	\N	PJL Physicien médical et qualifications professionnelles	PJL Physicien médical et qualifications professionnelles	2017-12-05 19:05:00	2017-12-05 19:20:00	\N	\N	8	0	\N	\N
227015	CMP	AUTRE	\N	ORDRE	\N	PJL Fonctionnement des ordres des professions de santé	PJL Fonctionnement des ordres des professions de santé	2017-12-05 19:25:00	2017-12-05 19:45:00	\N	\N	8	0	\N	\N
254772	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désign° candidats CMP Nvelle-Calédonie + Communication Pdt + PJL Protection données	\N	2018-03-14 09:05:00	2018-03-14 11:00:00	2018-03-14 11:43:46	2018-03-14 15:31:40	40	0	\N	\N
220240	COM_PERMANENTE	AUTRE	\N	CAE	\N	PLF 2018 « Agriculture, alimentation, forêt et affaires rurales »  	PLF 2018 « Agriculture, alimentation, forêt et affaires rurales »« Participations financières de l¿État »« Logement     	2017-11-22 09:05:00	2017-11-22 12:10:00	2017-11-22 19:35:45	2017-11-23 14:24:07	49	0	\N	\N
226103	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2018 - Examen Amdts séance Missions-Désignations CMP PLF pour 2018-LPFP 2018-2022	PLF pour 2018 - Examen Amdts séance Missions - Désignations CMP PLF pour 2018 et CMP LPFP 2018-2022	2017-12-06 09:05:00	2017-12-06 09:40:00	2017-12-06 16:26:41	2017-12-06 16:28:10	40	1	\N	\N
230014	CMP	AUTRE	\N	PLFP2018	\N	PROG Programmation des finances publiques de 2018 à 2022	PROG Programmation des finances publiques de 2018 à 2022	2017-12-13 16:35:00	2017-12-13 16:50:00	\N	\N	9	0	\N	\N
252853	COM_PERMANENTE	AUTRE	\N	FINC	\N	Demande saisine et désignation rapporteur PJL AN 659 et Examen du rapport sur le PJL 292	Demande saisine et désignation rapporteur PJL AN 659 (LPM 2019-2025) et Examen du rapport sur le PJL 292 (DSP2)	2018-03-14 09:40:00	2018-03-14 10:35:00	2018-03-14 13:03:18	2018-03-14 15:31:46	41	0	\N	\N
347017	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-02-06 09:30:00	2019-02-06 10:30:00	2019-02-06 14:45:03	2019-02-06 17:44:22	41	0	\N	\N
214724	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion	Réunion	2017-11-08 10:00:00	2017-11-08 10:50:00	2017-11-08 11:17:27	2017-11-08 14:33:03	41	0	\N	\N
237922	COM_PERMANENTE	AUTRE	\N	CDD	\N	PPL n° 717 (2016-2017) développement durable des territoires littoraux	PPL n° 717 (2016-2017) développement durable des territoires littoraux	2018-01-24 10:50:00	2018-01-24 12:35:00	2018-01-24 17:07:54	2018-01-24 17:43:03	45	0	\N	\N
273941	CMP	AUTRE	\N	EAU	\N	PPL Transfert des compétences eau et assainissement aux communautés de communes	PPL Transfert des compétences eau et assainissement aux communautés de communes	2018-05-17 11:45:00	2018-05-17 12:35:00	\N	\N	9	0	\N	\N
364269	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen rapport et élaboration texte PPL 109 affectation avoirs issus corruption transnat.	Examen rapport et élaboration texte commission PPL 109 affectation avoirs issus de la corruption transnationale	2019-03-27 09:10:00	2019-03-27 09:50:00	2019-03-27 16:05:32	2019-03-27 17:53:34	33	0	\N	\N
248852	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion 1	Réunion 1	2018-02-21 09:35:00	2018-02-21 10:35:00	2018-02-21 11:04:51	2018-02-21 11:15:14	46	0	\N	\N
367371	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen AMDTS séance PPL 109 affectation avoirs issus de la corruption transnationale	Examen AMDTS séance PPL 109 affectation avoirs issus de la corruption transnationale	2019-04-03 10:05:00	2019-04-03 10:15:00	2019-04-03 15:49:44	2019-04-03 15:50:27	44	0	\N	\N
367210	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-04-03 10:00:00	2019-04-03 12:00:00	2019-04-03 14:50:23	2019-04-03 15:04:16	41	0	\N	\N
217473	COM_PERMANENTE	AUTRE	\N	CAE	\N	PLF 2018, crédits des missions, Économie et Outre-mer	PLF 2018, crédits des missions, Économie et Outre-mer	2017-11-15 09:35:00	2017-11-15 12:00:00	2017-11-15 15:52:49	2017-11-15 16:15:24	47	0	\N	\N
220317	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Modalités de dépôt de candidature aux élections - 4 avis budgétaires	\N	2017-11-22 09:25:00	2017-11-22 12:20:00	2017-11-23 14:48:10	2017-11-23 14:50:25	45	0	\N	\N
220434	CMP	AUTRE	\N	HYDROCARBURE	\N	PJL Fin de la recherche et de l'exploitation des hydrocarbures	PJL Fin de la recherche et de l'exploitation des hydrocarbures	2017-11-21 08:35:00	2017-11-21 09:30:00	\N	\N	13	0	\N	\N
300561	CMP	AUTRE	\N	PORTABLE	\N	PPL Utilisation encadrée du portable dans les écoles et collèges	PPL Utilisation encadrée du portable dans les écoles et collèges	2018-07-18 17:30:00	2018-07-18 18:00:00	\N	\N	7	0	\N	\N
282692	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2018-06-13 09:05:00	2018-06-13 10:00:00	2018-06-13 19:52:45	2018-06-14 09:50:02	48	0	\N	\N
287619	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PJL pour la liberté de choisir son avenir professionnel	PJL pour la liberté de choisir son avenir professionnel	2018-06-27 08:30:00	2018-06-27 12:30:00	2018-06-27 15:46:30	2018-06-27 16:02:52	49	1	\N	\N
305574	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion	Réunion	2018-09-19 09:05:00	2018-09-19 09:07:00	2018-09-19 10:05:52	2018-09-19 17:31:57	12	2	\N	\N
305575	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2018-09-19 09:35:00	2018-09-19 10:55:00	2018-09-19 11:37:38	2018-09-19 17:31:55	34	2	\N	\N
313988	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Conseils d'administration des SDIS - LEC - Examen rapport et élaboration texte	PPL Conseils d'administration des SDIS - Législation en commission - Examen du rapport et élaboration du texte	2018-10-24 08:30:00	2018-10-24 09:35:00	2018-10-24 10:57:48	2018-10-24 12:15:27	36	1	\N	\N
240214	CMP	AUTRE	\N	SOCIAL	\N	PJL Renforcement du dialogue social	PJL Renforcement du dialogue social	2018-01-31 17:00:00	2018-01-31 18:00:00	\N	\N	8	0	\N	\N
281722	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PPL Défibrillateur cardiaque	\N	2018-06-13 10:30:00	2018-06-13 10:50:00	2018-06-13 11:57:39	2018-06-13 14:24:32	40	0	\N	\N
453808	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Examen du rapport et du texte sur la PPL Prestation de compensation du handicap	\N	2020-02-19 08:35:00	2020-02-19 08:55:00	2020-02-19 10:27:47	2020-02-19 16:09:45	38	1	\N	\N
479286	CMP	AUTRE	\N	ELECTIONS	\N	PJL Second tour des municipales	PJL Second tour des municipales	2020-06-15 11:05:00	2020-06-15 12:10:00	\N	\N	8	0	\N	\N
456615	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PPL Congé pour le décès d'un enfant - Examen du rapport et établissement du texte	\N	2020-02-26 09:05:00	2020-02-26 10:25:00	2020-02-27 19:02:13	2020-02-28 16:49:01	40	0	\N	\N
404870	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Nominations de rapporteurs - PPL Entraves à des libertés (examen du rapport)	Nominations de rapporteurs - PPL Entraves à des libertés (examen du rapport)	2019-09-25 10:10:00	2019-09-25 11:15:00	2019-09-25 12:21:22	2019-09-25 15:38:49	28	1	\N	\N
378922	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen Rapport pour avis PJL n° 492 Restauration et conservation de Notre-Dame de Paris	Examen Rapport pour avis PJL n° 492 Restauration et conservation de Notre-Dame de Paris	2019-05-22 08:35:00	2019-05-22 09:50:00	2019-05-22 12:16:04	2019-05-22 17:38:13	36	0	\N	\N
413358	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen rapport et élaboration texte de la commission sur la PPL Fiscalité de la succession	Examen rapport et élaboration texte de la commission sur la PPL Fiscalité de la succession et de la donation n°710 (2018	2019-10-16 08:40:00	2019-10-16 10:35:00	2019-10-16 15:56:28	2019-10-16 17:30:44	48	1	\N	\N
480013	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2020-06-24 09:35:00	2020-06-24 11:55:00	2020-06-24 12:40:41	2020-06-24 15:06:55	36	3	\N	\N
484609	CMP	AUTRE	\N	AUTONOMIE	\N	PJLO Dette sociale et autonomie	PJLO Dette sociale et autonomie	2020-07-08 17:00:00	2020-07-08 17:40:00	\N	\N	8	0	\N	\N
480979	CMP	AUTRE	\N	SORTIE	\N	PJL Organiser la sortie de l'état d'urgence sanitaire	PJL Organiser la sortie de l'état d'urgence sanitaire	2020-06-25 11:33:00	2020-06-25 12:39:00	\N	\N	8	0	\N	\N
483219	CMP	AUTRE	\N	CHEQUEVAC	\N	PPL Offrir des chèques-vacances aux personnels secteurs sanitaire - médico-social	PPL Offrir des chèques-vacances aux personnels secteurs sanitaire - médico-social	2020-07-02 09:00:00	2020-07-02 09:30:00	\N	\N	9	0	\N	\N
435794	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-12-04 11:05:00	2019-12-04 11:55:00	2019-12-04 11:56:37	2019-12-04 14:11:13	44	1	\N	\N
397757	CMP	AUTRE	\N	RADIO	\N	PPL Exploitation des réseaux radioélectriques mobiles	PPL Exploitation des réseaux radioélectriques mobiles	2019-07-03 18:33:00	2019-07-03 18:51:00	\N	\N	9	0	\N	\N
406938	CMP	AUTRE	\N	PRESSE	\N	\N	PJL Modernisation de la distribution de la presse	2019-09-24 18:00:00	2019-09-24 18:25:00	\N	\N	8	0	\N	\N
412749	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-10-16 09:30:00	2019-10-16 10:45:00	2019-10-16 12:24:40	2019-10-16 17:31:01	46	1	\N	\N
431062	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2020 - Examen Amdts de sénace sur les Missions	PLF pour 2020 - Examen Amdts de sénace sur les Missions	2019-11-27 09:35:00	2019-11-27 10:25:00	2019-11-27 10:34:37	2019-11-27 15:05:59	38	0	\N	\N
378234	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Examen d¿un rapport et établissement du texte - PJL Système de santé	\N	2019-05-22 08:30:00	2019-05-22 13:00:00	2019-05-22 14:40:20	2019-05-22 17:38:14	48	1	\N	\N
454191	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2020-02-19 09:30:00	2020-02-19 09:50:00	2020-02-19 17:13:54	2020-02-19 17:20:20	42	0	\N	\N
434669	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2020 - Examen Amdts séance sur la Mission RCT	PLF pour 2020 - Examen Amdts séance sur la Mission RCT	2019-12-04 09:05:00	2019-12-04 09:35:00	2019-12-04 09:57:31	2019-12-04 14:11:17	39	0	\N	\N
427448	COM_PERMANENTE	AUTRE	\N	CDD	\N	\N	\N	2019-11-20 09:04:00	2019-11-20 10:40:00	2019-11-21 17:42:43	2019-11-21 17:46:16	42	0	\N	\N
416795	COM_PERMANENTE	AUTRE	\N	FINC	\N	PPL n°710 : Examen AMDTS séance - PLF pour 2020 Missions AEE et EFE	PPL n°710 : Examen AMDTS séance - PLF pour 2020 Missions AEE et EFE	2019-10-23 09:30:00	2019-10-23 11:10:00	2019-10-23 11:36:43	2019-10-23 11:46:18	45	1	\N	\N
445710	COM_PERMANENTE	AUTRE	\N	FINC	\N	CVN Accord fiscal France-Botswana - Examen du rapport et établissement du texte	CVN Accord fiscal France-Botswana - Examen du rapport et établissement du texte	2020-01-22 10:05:00	2020-01-22 10:30:00	2020-01-22 12:07:04	2020-01-22 15:46:37	41	0	\N	\N
449607	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Examen amdts séance PPL sécurité sanitaire	\N	2020-02-05 10:45:00	2020-02-05 10:55:00	2020-02-05 18:16:31	2020-02-06 16:09:39	41	1	\N	\N
417479	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-10-23 09:00:00	2019-10-23 11:05:00	2019-10-23 11:21:00	2019-10-23 11:46:19	40	4	\N	\N
422452	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PLFSS Budget 2020 - Examen du rapport	\N	2019-11-06 08:35:00	2019-11-06 12:15:00	2019-11-06 14:34:47	2019-11-06 14:36:22	46	1	\N	\N
422488	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2020 - Tome 1 Rapport général et Missions GFPRH - Budget UE et Économie	0 - Tome 1 Rapport général et Missions GFPRH - Budget UE et Économie	2019-11-06 08:35:00	2019-11-06 12:45:00	2019-11-06 13:08:48	2019-11-06 14:36:22	46	0	\N	\N
376986	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-05-15 09:15:00	2019-05-15 12:10:00	2019-05-17 10:28:10	2019-05-17 10:30:23	48	1	\N	\N
450979	CMP	AUTRE	\N	PJLO13	\N	PJLO Modification de la loi organique n° 2010-837 du 23 juillet 2010	PJLO Modification de la loi organique n° 2010-837 du 23 juillet 2010	2020-02-04 09:34:00	2020-02-04 10:04:00	\N	\N	6	0	\N	\N
450986	CMP	AUTRE	\N	HADOPI	\N	PJL Protection des droits sur internet	PJL Protection des droits sur internet	2020-02-04 10:05:00	2020-02-04 10:06:00	\N	\N	6	0	\N	\N
391307	COM_PERMANENTE	AUTRE	\N	CAE	\N	Réunion de commission	\N	2019-06-19 09:05:00	2019-06-19 10:10:00	2019-06-19 14:34:10	2019-06-19 18:02:59	44	0	\N	\N
393891	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2019-06-19 10:45:00	2019-06-19 11:00:00	2019-06-24 09:48:43	2019-06-24 09:59:39	37	0	\N	\N
428662	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-11-20 09:05:00	2019-11-20 10:40:00	2019-11-20 10:52:28	2019-11-20 16:36:42	42	2	\N	\N
441310	COM_PERMANENTE	AUTRE	\N	SOCI	\N	PPL Droits sociaux travailleurs numériques	\N	2020-01-08 10:30:00	2020-01-08 11:10:00	2020-01-08 12:06:47	2020-01-08 15:13:19	39	1	\N	\N
430309	COM_PERMANENTE	AUTRE	\N	SOCI	\N	\N	Avis budgéaires PLF pour 2020 et examen rapport nouvelle lecture PLFSS 2020	2019-11-27 08:35:00	2019-11-27 10:50:00	2019-11-27 11:46:23	2019-11-27 15:06:06	45	1	\N	\N
413451	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2020 - Missions Sport et Anciens combattants	PLF pour 2020 - Missions Sport et Anciens combattants	2019-10-16 11:30:00	2019-10-16 12:30:00	2019-10-16 15:57:01	2019-10-16 17:31:12	43	1	\N	\N
423511	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-11-06 09:35:00	2019-11-06 11:05:00	2019-11-06 11:33:42	2019-11-06 14:36:20	44	0	\N	\N
425100	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2020 - Tome 2 Rapport général et Missions APD et Agriculture	PLF pour 2020 - Tome 2 Rapport général et Missions APD et Agriculture	2019-11-13 08:35:00	2019-11-13 12:15:00	2019-11-15 15:53:40	2019-11-15 15:54:28	45	0	\N	\N
375527	CMP	AUTRE	\N	POLYNESIE2	\N	PJLO Modification du statut d'autonomie de la Polynésie française	PJLO Modification du statut d'autonomie de la Polynésie française	2019-05-07 09:35:00	2019-05-07 09:45:00	\N	\N	9	0	\N	\N
376740	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-05-15 09:30:00	2019-05-15 09:50:00	2019-05-15 14:35:19	2019-05-15 17:21:55	43	0	\N	\N
443667	COM_PERMANENTE	AUTRE	\N	FINC	\N	PPL n°154 Régime des catastrophes naturelles - Examen AMDTS séance	PPL n°154 Régime des catastrophes naturelles - Examen AMDTS séance	2020-01-15 09:05:00	2020-01-15 09:25:00	2020-01-15 15:46:17	2020-01-15 17:49:16	38	0	\N	\N
426125	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Réunion de commission	Réunion de commission	2019-11-13 09:35:00	2019-11-13 11:00:00	2019-11-13 17:01:08	2019-11-13 17:02:28	42	1	\N	\N
427859	COM_PERMANENTE	AUTRE	\N	ETRD	\N	\N	\N	2019-11-20 09:35:00	2019-11-20 12:10:00	2019-11-20 14:49:50	2019-11-20 16:36:40	41	3	\N	\N
443805	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Collectivités locales - PPL Déclaration de naissance -Examen des amendements de séance	PPL Collectivités locales - PPL Déclaration de naissance -Examen des amendements de séance	2020-01-15 10:05:00	2020-01-15 10:45:00	2020-01-15 12:19:27	2020-01-15 12:20:12	37	0	\N	\N
611540	COM_PERMANENTE	AUTRE	\N	AFCL	\N	Rapport et texte commission PPL restitution	\N	2021-12-15 09:35:00	2021-12-15 10:58:00	2021-12-15 11:22:47	2021-12-15 17:07:45	42	1	\N	\N
614101	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2021-12-15 11:45:00	2021-12-15 11:50:00	2021-12-15 11:59:21	2021-12-15 17:07:49	25	0	\N	\N
612793	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Protection des lanceurs d'alerte -  PPLO Rôle Défenseur des droits (rapport et textes)	PPL Protection des lanceurs d'alerte -  PPLO Rôle Défenseur des droits (rapport et textes)	2021-12-15 09:40:00	2021-12-15 10:40:00	2021-12-15 13:36:53	2021-12-15 17:07:47	33	0	\N	\N
597713	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Compétences CE Alsace (avis) - PPLC Principes démocratie et PPL Administration (amdts)	PJL Compétences CE Alsace (avis) - PPLC Principes démocratie et PPL Administration (amdts)	2021-11-03 09:00:00	2021-11-03 09:55:00	2021-11-03 11:14:07	2021-11-03 16:47:24	32	0	\N	\N
559145	COM_PERMANENTE	AUTRE	\N	CAE	\N	Avis PJL DDADUE	\N	2016-05-12 09:00:00	2016-05-12 11:00:00	\N	\N	0	0	\N	\N
698744	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-02-08 10:10:00	2023-02-08 12:55:00	2023-02-08 14:03:17	2023-02-09 11:07:24	45	1	\N	\N
659084	COM_PERMANENTE	AUTRE	\N	FINC	\N	PPL n° 867 externalités positives de la forêt - Examen du rapport	PPL n° 867 externalités positives de la forêt - Examen du rapport	2022-10-12 09:00:00	2022-10-12 09:50:00	2022-10-12 11:36:15	2022-10-12 17:33:55	42	1	\N	\N
661262	COM_PERMANENTE	AUTRE	\N	FINC	\N	PPL 867 examen Amdts séance - PLF pour 2023 CAS PFE et Missions Sport et R&D	PPL 867 examen Amdts séance - PLF pour 2023 CAS PFE et Missions Sport et R&D	2022-10-19 09:15:00	2022-10-19 11:00:00	2022-10-19 11:33:57	2022-10-19 18:04:11	39	0	\N	\N
718556	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPLC Financement des coll. - PPL Secrétaire de mairie - PPL Parité fonction publique	PPLC Financement des coll. - PPL Secrétaire de mairie - PPL Parité fonction publique	2023-03-29 09:00:00	2023-03-29 11:15:00	2023-03-29 15:09:58	2023-03-29 17:17:31	39	2	\N	\N
721236	COM_PERMANENTE	AUTRE	\N	FINC	\N	PPL 341 Examen des amendements	PPL 341 Examen des amendements	2023-04-05 11:00:00	2023-04-05 11:20:00	2023-04-06 12:15:26	2023-04-06 17:46:27	42	1	\N	\N
659563	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière	\N	2022-10-26 09:35:00	2022-10-26 13:00:00	2022-10-27 15:02:13	2022-10-27 15:23:44	43	0	\N	\N
757863	COM_PERMANENTE	AUTRE	\N	CAE	\N	PJL négociations commerciales	\N	2023-10-25 11:50:00	2023-10-25 12:05:00	2023-10-25 14:23:16	2023-10-25 16:14:37	40	3	\N	\N
725826	COM_PERMANENTE	AUTRE	\N	CAE	\N	PPL Influenceurs	\N	2023-05-03 09:30:00	2023-05-03 11:15:00	2023-05-03 11:21:55	2023-05-03 18:03:32	45	0	\N	\N
740754	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Secrétaire de mairie - PPL Protéger les logements contre l'occupation illicite (amdts)	PPL Secrétaire de mairie - PPL Protéger les logements contre l'occupation illicite (amdts)	2023-06-14 10:00:00	2023-06-14 10:35:00	2023-06-14 12:37:24	2023-06-14 15:28:01	37	0	\N	\N
669558	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF 2023 : Tome II RG - Missions Gestion des finances publiques et AGTE	PLF 2023 : Tome II RG - Missions Gestion des finances publiques et AGTE	2022-11-09 09:00:00	2022-11-09 12:50:00	2022-11-09 12:57:22	2022-11-09 17:25:50	45	3	\N	\N
728009	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL Droit à l'image des enfants - Permis de conduire (amdts) - PPL Casinos (rapport)	PPL Droit à l'image des enfants - Permis de conduire (amdts) - PPL Casinos (rapport)	2023-05-10 09:00:00	2023-05-10 09:55:00	2023-05-31 10:06:22	2023-05-31 10:22:01	35	3	\N	\N
682305	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-12-07 09:00:00	2022-12-07 10:05:00	2022-12-07 11:00:15	2022-12-08 12:00:21	42	0	\N	\N
682307	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2022-12-07 11:35:00	2022-12-07 11:55:00	2022-12-07 11:56:54	2022-12-08 12:08:31	41	0	\N	\N
696008	COM_PERMANENTE	AUTRE	\N	FINC	\N	Examen amdts séance PPL 217 : Politique du logement	Examen amdts séance PPL 217 : Politique du logement	2023-02-01 09:45:00	2023-02-01 10:00:00	2023-02-01 16:45:48	2023-02-01 17:23:01	42	1	\N	\N
755866	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Examen de 2 conventions internationales	Examen de 2 conventions internationales	2023-10-18 10:50:00	2023-10-18 11:00:00	2023-10-18 15:23:42	2023-10-18 18:17:04	43	2	\N	\N
728206	COM_PERMANENTE	AUTRE	\N	ETRD	\N	2 conventions internationales	\N	2023-05-10 11:25:00	2023-05-10 11:37:00	2023-05-11 15:22:43	2023-05-11 16:16:51	38	4	\N	\N
752041	CMP	AUTRE	\N	ACCI	\N	PPL Protection des familles	PPL Protection des familles	2023-07-06 10:07:00	2023-07-06 10:26:00	\N	\N	6	0	\N	\N
752071	CMP	AUTRE	\N	PZAN	\N	PPL ZAN	PPL ZAN	2023-07-06 10:05:00	2023-07-06 15:25:00	\N	\N	0	0	\N	\N
752072	CMP	AUTRE	\N	PAFP	\N	PPL Parité fonction publique	PPL Parité fonction publique	2023-06-28 08:02:00	2023-06-28 08:24:00	\N	\N	6	0	\N	\N
752073	CMP	AUTRE	\N	PCMF	\N	PJL CMF DDOM	PJL CMF DDOM	2023-06-28 18:30:00	2023-06-28 18:40:00	\N	\N	0	0	\N	\N
752074	CMP	AUTRE	\N	DOUA	\N	PJL Douane	PJL Douane	2023-06-28 17:03:00	2023-06-28 17:45:00	\N	\N	0	0	\N	\N
730320	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2023-05-17 09:30:00	2023-05-17 10:30:00	2023-05-17 15:55:55	2023-05-17 15:57:19	40	3	\N	\N
720076	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désignations - PPL Parité fonction publique - PPL Secr. mairie - PPLC Financ. CT	Désignations - PPL Parité fonction publique - PPL Secrétaire de mairie - PPLC Financement des collectivités territ.	2023-04-05 10:15:00	2023-04-05 10:40:00	2023-04-05 10:40:35	2023-04-06 17:46:25	38	3	\N	\N
720091	COM_PERMANENTE	AUTRE	\N	ETRD	\N	PPRE transferts forcés enfants ukrainiens	\N	2023-04-05 11:00:00	2023-04-05 11:30:00	2023-04-05 14:58:43	2023-04-06 17:46:28	34	3	\N	\N
723223	COM_PERMANENTE	AUTRE	\N	FINC	\N	PPL Accessibilité et inclusion bancaires - Examen rapport et texte commission	PPL Accessibilité et inclusion bancaires - Examen rapport et texte commission	2023-04-12 11:30:00	2023-04-12 12:45:00	2023-04-12 17:38:41	2023-04-28 11:37:03	42	2	\N	\N
761182	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE 75 -PLF pour 2024 : Examen des éléments d'équilibre Tome I, examen rapports	PLENIERE 75 -PLF pour 2024 : Examen des éléments d'équilibre Tome I, examen rapports	2023-11-08 09:30:00	2023-11-08 12:40:00	2023-11-14 19:17:19	2023-11-15 11:34:56	48	1	\N	\N
676189	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PLF pour 2023 - Avis	PLF pour 2023 - Avis	2022-11-23 08:30:00	2022-11-23 11:00:00	2022-11-23 11:11:18	2022-11-23 15:15:08	36	3	\N	\N
746017	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-06-28 08:30:00	2023-06-28 11:45:00	2023-06-28 12:03:25	2023-06-29 14:30:57	41	1	\N	\N
735293	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL Orientation programmation justice - PJLO Corps judiciaire (rapport et textes)	PJL Orientation programmation justice - PJLO Corps judiciaire (rapport et textes)	2023-05-31 09:50:00	2023-05-31 12:25:00	2023-05-31 13:09:24	2023-06-02 16:09:52	41	5	\N	\N
736607	COM_PERMANENTE	AUTRE	\N	CAE	\N	PPRE Protection de la filière pêche française 	\N	2023-05-31 09:20:00	2023-05-31 10:10:00	2023-05-31 14:28:08	2023-06-02 16:09:50	46	2	\N	\N
736883	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion plénière CATDD	\N	2023-06-07 10:00:00	2023-06-07 10:55:00	2023-06-08 09:58:16	2023-06-08 11:18:28	43	2	\N	\N
737730	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2023-06-07 11:15:00	2023-06-07 12:10:00	2023-06-07 13:41:50	2023-06-07 17:26:46	38	1	\N	\N
738017	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PJL et PJLO Justice (suite amdts) - PPL Occupation illicite - PPL Secrétaire de mairie	PJL et PJLO Justice (suite amdts) - PPL Occupation illicite - PPL Secrétaire de mairie	2023-06-07 09:00:00	2023-06-07 10:30:00	2023-06-07 18:43:16	2023-06-08 11:18:29	36	2	\N	\N
742272	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Examen du rapport sur le PJL de programmation militaire	\N	2023-06-14 09:30:00	2023-06-14 12:20:00	2023-06-14 14:23:36	2023-06-14 15:27:59	45	3	\N	\N
755999	COM_PERMANENTE	AUTRE	\N	CDD	\N	Réunion CATDD	\N	2023-10-18 10:00:00	2023-10-18 12:00:00	2023-10-18 17:20:49	2023-10-18 18:17:06	48	1	\N	\N
664324	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLF pour 2023-Examen rapports Pouvoirs publics-Solidarité-Immigration	PLF pour 2023-Examen rapports Pouvoirs publics-Solidarité-Immigration	2022-10-26 09:00:00	2022-10-26 10:55:00	2022-10-26 11:29:55	2022-10-26 15:10:34	42	2	\N	\N
754136	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE 65 - Examen rapport M. HUSSON et élaboration texte LPFP 2023/2027	PLENIERE 65 - Examen rapport M. HUSSON et élaboration texte LPFP 2023/2027 / Désignation rapp. PPL920	2023-10-11 09:30:00	2023-10-11 10:30:00	2023-10-26 11:37:25	2023-10-27 19:01:43	47	2	\N	\N
758747	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE - 70	\N	2023-10-25 09:00:00	2023-10-25 12:05:00	2023-10-31 10:08:54	\N	41	5	\N	\N
788857	CMP	AUTRE	\N	SECR	\N	PPL Secrétaire de mairie	PPL Secrétaire de mairie	2023-12-13 12:00:00	2023-12-13 12:35:00	\N	\N	10	0	\N	\N
788881	CMP	AUTRE	\N	PARTAGE	\N	PJL Partage de la valeur	PJL Partage de la valeur	2023-11-15 10:32:00	2023-11-15 11:10:00	\N	\N	45	0	\N	\N
772448	COM_PERMANENTE	AUTRE	\N	ETRD	\N	PLF2024 - examen 4 rapports avis budgétaires	PLF2024 - Action extérieure de l'Etat et Aide publique au développement	2023-11-29 09:30:00	2023-11-29 12:00:00	2023-11-29 15:03:15	2023-11-29 17:23:18	31	7	\N	\N
789103	CMP	AUTRE	\N	PLFFG23	\N	PLFFG23	PLFFG23	2023-11-21 21:06:00	2023-11-21 21:32:00	\N	\N	10	0	\N	\N
789118	CMP	AUTRE	\N	PLFSS	\N	PLFSS	PLFSS	2023-11-16 18:00:00	2023-11-16 18:20:00	\N	\N	12	0	\N	\N
789135	CMP	AUTRE	\N	CONSO	\N	PJL grande consommation	PJL grande consommation	2023-11-06 18:05:00	2023-11-06 20:30:00	\N	\N	13	0	\N	\N
789151	CMP	AUTRE	\N	EMPLO	\N	PJL Plein emploi	PJL Plein emploi	2023-10-23 17:00:00	2023-10-23 18:15:00	\N	\N	9	0	\N	\N
789172	CMP	AUTRE	\N	INDUS	\N	PJL Industrie verte	PJL Industrie verte	2023-10-09 20:25:00	2023-10-09 21:55:00	\N	\N	14	0	\N	\N
789188	CMP	AUTRE	\N	PJLO	\N	PJLO Justice	PJLO Justice	2023-10-09 16:33:00	2023-10-09 17:07:00	\N	\N	8	0	\N	\N
789203	CMP	AUTRE	\N	JUST	\N	PJL Justice	PJL Justice	2023-10-05 17:09:00	2023-10-05 18:18:00	\N	\N	9	0	\N	\N
791690	COM_PERMANENTE	AUTRE	\N	LOIS	\N	Désignation de rapporteurs - Violences intrafamiliales (rapport 2e lecture)	Désignation de rapporteurs - Violences intrafamiliales (rapport 2e lecture)	2024-01-31 10:05:00	2024-01-31 10:40:00	2024-02-13 15:14:37	2024-02-13 15:25:12	38	5	\N	\N
794751	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2024-02-07 09:00:00	2024-02-07 10:20:00	2024-02-07 10:55:11	2024-02-08 12:31:23	42	5	\N	\N
789024	CMP	AUTRE	\N	RESTHUM	\N	PPL Restitution des restes humains	PPL Restitution des restes humains	2023-12-06 16:30:00	2023-12-06 18:10:00	\N	\N	13	0	\N	\N
789372	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Examen de deux conventions internationales	Examen de deux conventions internationales	2024-01-24 10:50:00	2024-01-24 11:15:00	2024-01-24 14:26:11	2024-01-25 18:33:20	37	5	\N	\N
812920	CMP	AUTRE	\N	VAPO	\N	PPL Vapotage	PPL visant à interdire les dispositifs électroniques de vapotage à usage unique	2024-03-21 10:30:00	2024-03-21 10:45:00	\N	\N	9	0	\N	\N
804284	COM_PERMANENTE	AUTRE	\N	AFCL	\N	\N	\N	2024-03-13 09:30:00	2024-03-13 11:10:00	2024-03-13 11:14:55	2024-03-13 16:00:44	44	10	\N	\N
804287	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE 12 - Examen rapports conventions fiscales PJL255 Luxembourg et PJL283 Moldavie	PLENIERE 12 - Examen des rapports conventions fiscales PJL255 Luxembourg et PJL283 Moldavie	2024-03-06 09:30:00	2024-03-06 10:31:00	2024-03-12 15:31:52	2024-03-12 16:31:08	42	4	\N	\N
804017	COM_PERMANENTE	AUTRE	\N	LOIS	\N	PPL CG3P Polynésie - Responsabilité civile - Tests individuels (rapports)	PPL CG3P Polynésie - Responsabilité civile - Tests individuels (rapports)	2024-03-06 10:00:00	2024-03-06 12:20:00	2024-03-06 17:42:47	2024-03-06 17:49:24	41	13	\N	\N
817183	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2024-04-03 10:33:00	2024-04-03 12:04:00	\N	\N	41	0	\N	\N
810103	CMP	AUTRE	\N	HABI	\N	PJL Rénovation habitat	PJL Rénovation habitat	2024-03-14 10:00:00	2024-03-14 11:20:00	\N	\N	10	0	\N	\N
807402	COM_PERMANENTE	AUTRE	\N	SOCI	\N	Réunion plénière	\N	2024-03-13 11:30:00	2024-03-13 12:15:00	2024-03-13 12:18:22	2024-03-13 15:59:25	37	0	\N	\N
779281	COM_PERMANENTE	AUTRE	\N	LOIS	\N	ENQ TotalEnergie & Energies (avis) - PPL Droit image & PJL Dérives sectaires (rapports)	ENQ TotalEnergie & Energies (avis) - PPL Droit image & PJL Dérives sectaires (rapports)	2023-12-13 09:45:00	2023-12-13 11:20:00	2023-12-13 13:08:51	2023-12-13 14:19:06	42	2	\N	\N
815960	CMP	AUTRE	\N	ASSO	\N	PPL Engagement bénévole	PPL Engagement bénévole	2024-03-27 19:10:00	2024-03-27 19:58:00	\N	\N	11	0	\N	\N
810904	COM_PERMANENTE	AUTRE	\N	ETRD	\N	Examen amendements PJL CETA - PPL aide publique développement - convention Kazakhstan 	Examen amendements PJL CETA - PPL aide publique développement - convention Kazakhstan 	2024-03-20 10:10:00	2024-03-20 12:10:00	2024-03-21 10:16:48	2024-03-21 14:48:00	41	7	\N	\N
818557	COM_PERMANENTE	AUTRE	\N	AFCL	\N	PPL service civique + MI antisémitisme dans l'enseignement supérieur	\N	2024-04-10 09:30:00	2024-04-10 11:45:00	2024-04-10 12:36:54	2024-04-12 13:33:37	41	6	\N	\N
810883	COM_PERMANENTE	AUTRE	\N	FINC	\N	PLENIERE 17 - 3° lecture PPL370 Protection EDF démembrement	PLENIERE 17 - 3° lecture PPL370 Protection EDF démembrement	2024-03-27 09:30:00	2024-03-27 10:00:00	2024-04-02 16:07:26	2024-04-02 17:02:20	40	6	\N	\N
814477	CMP	AUTRE	\N	NUME	\N	PJL Espace numérique	PJL Espace numérique	2024-03-26 16:25:00	2024-03-26 19:50:00	\N	\N	9	0	\N	\N
818765	CMP	AUTRE	\N	NUCL	\N	PJL Sûreté nucléaire	PJL Sûreté nucléaire	2024-04-03 17:03:00	2024-04-03 18:45:00	\N	\N	11	0	\N	\N
818777	CMP	AUTRE	\N	ARTI	\N	PJLO Article 13	PJLO Article 13	2024-04-03 18:45:00	2024-04-03 18:48:00	\N	\N	9	0	\N	\N
818825	CMP	AUTRE	\N	ARTI	\N	PJLO Article 13	PJLO Article 13	2024-04-03 18:45:00	2024-04-03 18:48:00	\N	\N	11	0	\N	\N
\.


--
-- Data for Name: activite_delegation; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY activite_delegation (delegactid, actid, senmat, senmat_delegue, delegidx) FROM stdin;
28864	767291	21061D	18083K	0
28865	767291	21029D	19701S	0
28866	767291	15197G	14219Q	0
13507	315528	19621T	08039A	0
29689	804085	14069U	05008E	0
24777	638445	20126Y	11048N	0
4322	98894	98005N	95059Q	0
25979	669556	19545Y	20050V	0
28397	750021	20252E	08010L	0
28867	767291	14237S	14031R	0
21961	560588	19826F	14219Q	0
9761	192774	14199E	11088W	0
9084	184453	14215L	14273W	0
29690	804085	19447X	20022R	0
30008	821135	08034U	19711U	0
29691	804085	19729F	04047H	0
12903	295774	80027E	08055A	0
27645	728009	14275Y	14179A	0
3794	84820	98005N	95059Q	0
28870	764866	14193X	19421M	0
9395	189773	98005N	01056V	1
29692	804085	04008A	14053L	0
28398	750021	19741B	11048N	0
4501	101058	07024N	95059Q	0
28044	738366	19621T	19643A	0
28872	764866	17023S	14267Y	0
24955	643839	14030Q	19611R	0
3795	84889	98005N	95059Q	0
9125	185092	10015M	92031P	0
9126	185092	11083R	04054G	0
24956	643839	04033B	19399H	0
8203	169292	10006L	04081K	0
9398	189773	95031C	86044G	1
13510	313989	04047H	07034Q	0
29693	804085	14259Y	14215L	0
30007	821135	19573D	20044X	0
12456	281678	14147R	07034Q	0
27798	732653	19721W	20042V	0
28400	750021	19711U	20044X	0
30009	821135	20126Y	19399H	0
25333	651645	08028W	19707Y	0
4507	101194	07024N	95059Q	0
9402	189773	97011G	77002U	1
25981	669556	19667J	11048N	0
7806	164893	08019V	98050T	0
29695	804085	08018U	21044C	0
29696	804085	21095P	20108W	0
9403	189773	11080N	04036E	1
28873	764866	19721W	11115U	0
7123	151458	07034Q	04074L	0
9163	185152	10015M	04074L	1
11870	256031	04044E	19483C	0
29697	804085	21057H	20114U	0
7883	165832	92020L	01014K	0
29698	804085	18207D	19725B	0
27641	728009	11085T	07004J	0
24959	643839	14073Q	20048C	0
24960	643839	14123H	20058E	0
29699	804085	14151M	19649G	0
28874	764866	19745F	14179A	0
27642	728009	19543W	19749K	0
27799	732653	16685X	01024M	0
30010	821135	08010L	11048N	0
24962	643839	11043H	19533U	0
9162	185152	11072N	04056J	1
29701	804085	11085T	14231L	0
29702	804085	19489J	18231D	0
28401	750021	14253S	01057W	0
27796	732916	14173T	11048N	0
28878	764867	14193X	19421M	0
15503	380225	14059S	08020N	0
16662	420691	08035V	08043V	0
29703	804085	19111A	19749K	0
9167	185152	11084S	11035H	1
27648	726276	19573D	11043H	0
30011	821135	21090J	21072G	0
8212	169232	10006L	04081K	0
27649	726276	19643A	20056C	0
29717	804017	04008A	04047H	0
27797	732653	19669L	01062T	0
29718	804017	21088Q	11056N	0
30012	821135	20024T	20086J	0
27653	728012	19543W	19749K	0
28880	764867	17023S	14267Y	0
27655	728012	14275Y	14179A	0
23368	595687	14237S	20136B	0
5455	119730	01028R	04056J	0
28881	764867	19721W	11115U	0
28402	750021	04071H	07029T	0
30013	821135	14253S	07029T	0
25335	651645	14187A	11090Q	0
9174	185152	11026G	11037K	1
10191	201041	05004A	01027Q	0
30014	821135	08011M	14331P	0
25336	651645	19507S	19705W	0
16664	420691	92040Q	08039A	0
6309	139057	04042C	95059Q	0
27658	728206	19319Q	16685X	0
27659	728206	08061X	11083R	0
14302	334152	19525U	08055A	0
25337	651645	19768N	19383Y	0
27660	728206	08069G	97011G	0
10205	200632	08048B	04081K	0
28882	764867	19745F	14179A	0
30015	821135	14173T	20062A	0
25987	669556	20252E	20086J	0
25477	655465	19729F	20074E	0
28883	764867	14059S	08047A	0
30016	821135	14327T	14083S	0
27662	728206	95041E	14059S	0
30017	821135	11070L	07004J	0
27663	728205	19319Q	16685X	0
30018	821135	08009T	19479G	0
25499	655497	08015R	11090Q	0
27664	728205	08061X	11083R	0
27665	728205	08069G	97011G	0
28885	767904	20144B	19563B	0
28886	765848	15197G	14219Q	0
25504	655497	19707Y	19515S	0
6327	139174	04042C	95059Q	0
25505	655497	19768N	19705W	0
27667	728205	95041E	14059S	0
27802	732653	11080N	97011G	0
13529	315530	19621T	08039A	0
27803	732653	19443T	14193X	0
27804	732653	04035D	19421M	0
27805	732653	08069G	14059S	0
14304	334152	18083K	98023Q	0
25511	655497	01025N	01043Q	0
30019	821135	20150Y	08073C	0
25658	656808	07004J	19543W	0
28403	750021	14173T	19762G	0
30020	821135	11040E	19687N	0
25991	669556	20086J	11048N	0
30021	821135	20050V	19545Y	0
30022	821135	21079P	20134Y	0
27819	732868	20034V	14038Y	0
27820	732868	08028W	11090Q	0
27821	732868	20298U	01043Q	0
27825	732653	14267Y	17023S	0
27823	734162	14173T	11048N	0
28043	738366	20264J	04059M	0
28047	738366	04033B	20058E	0
28048	738366	11043H	19399H	0
28049	738366	20084G	14229S	0
28050	738366	19533U	19766L	0
16451	410914	14275Y	08044W	0
10830	217782	14059S	08039A	0
15525	380226	14061L	08039A	0
16876	423940	19525U	08055A	0
16878	423940	14029X	19733B	0
15540	381988	11085T	08044W	0
10939	221367	19573D	08039A	0
14562	342188	04034C	95037J	0
14564	342919	11049P	07034Q	0
29441	793065	19707Y	14033T	0
28129	742229	11101A	14031R	0
29442	793065	20104S	19768N	0
18254	467821	14275Y	08044W	0
28261	744230	19667J	11048N	0
28130	742229	20140W	18083K	0
9222	187772	86044G	95059Q	0
28131	742229	17637T	19701S	0
28663	760928	11043H	20058E	0
9524	190695	14167V	01031L	0
29296	783371	14033T	14331P	0
28133	742229	19577H	14219Q	0
7470	157818	01034P	11093T	0
7561	158669	95031C	95059Q	0
6441	143101	08065C	07024N	0
25688	659084	08034U	11048N	0
18924	484747	19725B	98035U	0
28263	744230	01048V	11048N	0
7475	157818	10006L	04081K	0
28262	744230	08034U	01057W	0
9721	192774	04055H	01027Q	0
28265	744230	14173T	19741B	0
18925	484747	14053L	19930E	0
28664	760928	20048C	19699S	0
18264	467706	14275Y	08044W	0
16484	413358	14159V	14085U	0
28267	744230	20252E	01057W	0
29444	793065	21093M	20092G	0
28666	760928	08012N	21089R	0
12877	295835	98024R	14087W	0
3829	88496	95031C	95059Q	0
28667	760928	14021P	21077M	0
3307	70716	14253S	95059Q	0
25033	645760	19705W	11090Q	0
29211	781405	19619A	14219Q	0
25877	664326	19741B	11048N	0
29209	779281	14275Y	21038E	0
29210	781405	21068L	18083K	0
29212	781405	21061D	14031R	0
8944	179470	95015C	11091R	0
3849	88803	95031C	95059Q	0
5149	114470	11032E	04056J	0
18932	484558	08010L	96004D	0
16494	412749	14197C	08068F	0
9728	192492	11080N	95059Q	0
16499	412790	19713W	14103D	0
5161	115694	04061F	\N	0
9785	197532	01019Q	04074L	0
18936	484558	08014Q	14085U	0
6197	137099	11037K	04056J	0
8786	174511	08073C	01016M	0
9227	187772	14211G	04036E	0
6225	137353	11037K	04056J	0
16514	413451	14159V	14085U	0
25043	645760	19511N	19441R	0
7876	165792	01028R	04056J	0
9228	187772	95041E	92031P	0
14923	356330	14041T	11049P	0
18945	484818	08062Y	14265W	0
4889	111404	01056V	95059Q	0
18947	484818	04043D	04088S	0
25697	659365	14001X	01028R	0
13447	310421	19657G	14087W	0
8792	174511	08073C	01016M	1
25832	663457	19766L	20056C	0
10467	209616	95015C	08039A	0
4896	111547	01056V	95059Q	0
9786	197532	14275Y	95049N	0
25699	659365	11085T	14231L	0
17156	432047	04033B	08039A	0
25876	664326	08034U	07029T	0
11064	223980	12016W	14085U	0
23639	603054	04033B	19399H	0
25701	659085	08034U	11048N	0
9558	190532	14167V	01031L	1
23643	603054	20084G	11104D	0
9436	189493	16813M	04074L	1
19007	485920	08014Q	14085U	0
23648	604905	19619A	14219Q	0
5510	120453	11037K	04056J	0
25713	659365	07004J	19543W	0
9443	189493	11113E	11084S	1
9444	189493	11072N	11037K	1
14933	356273	14041T	11049P	0
25715	659365	19581D	19675J	0
13648	319339	92040Q	14061L	0
17169	432047	08035V	08043V	0
19014	485540	08045X	14065Q	0
9789	197532	11035H	04056J	0
13651	319339	11043H	04018C	0
9841	197413	04061F	01027Q	0
13652	319339	14249W	08039A	0
23942	610668	14021P	01028R	0
25814	664322	19667J	11048N	0
13656	318025	96004D	98023Q	0
10125	200612	14195A	04081K	0
19019	485540	14259Y	19930E	0
13659	318025	19549D	08055A	0
11070	223695	12016W	14085U	0
24055	611227	19577H	14219Q	0
13708	320098	14061L	08039A	0
10740	205652	14299H	18003S	0
10484	208065	07034Q	19483C	0
24216	618359	07004J	19543W	0
17182	430309	19715Y	14227Q	0
17187	432047	08039A	08020N	0
17188	432047	19621T	04018C	0
19030	485542	14259Y	19930E	0
11083	222384	98005N	98050T	0
6542	143736	01044R	11029K	0
23556	601186	04033B	19693L	0
15482	380225	92040Q	08039A	0
14845	355707	19762G	07034Q	0
25704	659365	19749K	19543W	1
28373	749003	20118Y	19701S	0
29477	794857	19707Y	14033T	0
23561	601186	11109J	11104D	0
24945	643951	20140W	20074E	0
3311	70825	14253S	95059Q	0
29478	794857	20104S	19507S	0
11182	226081	08014Q	14085U	0
17291	432684	19367Y	98024R	0
10364	204352	11035H	04056J	0
28375	749003	17637T	14031R	0
28531	754136	19545Y	20050V	0
29510	794752	20148F	14213J	0
4626	104995	04042C	95059Q	0
28533	752395	14030Q	20048C	0
29511	794752	20090E	14026U	0
28534	752395	14123H	20056C	0
7767	162943	04044E	04074L	0
8611	174510	01019Q	04074L	1
28535	752395	21055F	20172F	0
29513	796085	19707Y	14033T	0
29514	796085	20104S	19507S	0
18705	479072	19727D	08052W	0
28538	752395	19699S	19611R	0
28539	752395	11043H	20026V	0
28540	752395	14073Q	19735D	0
28541	752395	04033B	19533U	0
18708	479072	14217N	98024R	0
23579	600212	19521Q	01043Q	0
24853	640058	19707Y	19515S	0
24854	640058	19705W	19383Y	0
23584	600213	19521Q	01043Q	0
10781	217581	19647E	14085U	0
24941	643651	01057W	11048N	0
15481	380225	11043H	04018C	0
15062	365979	11085T	08044W	0
12681	291185	14249W	08039A	0
8527	174535	08052W	14271U	0
26996	699099	19575F	11090Q	0
18718	478886	07029T	96004D	0
12689	291386	80027E	08055A	0
12691	291386	17637T	98023Q	0
24944	643951	19747H	19515S	0
12693	291395	05008E	07034Q	0
25711	659365	14259Y	20074E	0
18726	479880	19719D	19253P	0
8563	174354	08022Q	11088W	1
5720	125099	97011G	95059Q	0
27002	699099	19707Y	19705W	0
24863	640059	19707Y	19515S	0
12729	289494	19531S	14085U	0
10807	217582	12016W	14085U	0
9024	183096	11049P	14273W	0
8889	177613	11072N	04056J	0
23783	606426	19533U	19399H	0
23784	606426	19621T	19693L	0
23785	606426	20264J	11104D	0
23789	606426	04033B	19766L	0
15485	380225	08012N	08043V	0
17531	441618	11067R	14065Q	0
12736	287619	08048B	14087W	2
12749	289205	19531S	14085U	0
24952	643651	19647E	14225N	0
13022	299311	14061L	95015C	0
18986	484898	17779H	08052W	0
15486	380225	14063N	08035V	0
17564	441590	19319Q	04040A	0
12977	298622	14357A	04088S	0
24872	640059	19705W	19383Y	0
12981	298622	14081Q	08038Y	0
18787	481626	14169X	14157T	0
11136	222386	98005N	98050T	0
3421	73151	01056V	95059Q	0
15497	378919	19551W	08055A	0
18788	481626	05012A	04097T	0
13019	299357	14081Q	08038Y	0
17579	441310	11097X	98024R	0
13029	298280	08014Q	14085U	0
18791	481626	04069P	15447F	0
18792	481557	04047H	19930E	0
15702	384434	14255U	04040A	0
3434	73310	01056V	95059Q	0
18794	481626	14103D	19737F	0
13038	299315	14061L	95015C	0
13927	324297	04044E	07034Q	0
18993	484898	10006L	98024R	0
18995	485543	04008A	19930E	0
11252	226103	12016W	14085U	0
11254	226155	19531S	14085U	0
17613	441620	11067R	14065Q	0
11245	225976	19729F	19483C	0
19039	485542	08045X	14065Q	0
19040	485542	11085T	08044W	0
11267	226156	08014Q	14085U	0
28016	736293	14073Q	19611R	0
29682	804286	11070L	11053K	0
24158	617203	19721W	16685X	0
6070	133700	07024N	95059Q	0
29683	804286	08011M	11048N	0
29684	804286	20086J	20024T	0
28017	736293	20048C	20052X	0
26315	669286	19685L	14219Q	0
28580	755865	04042C	08047A	0
18967	484556	08034U	96004D	0
28019	736293	19693L	19766L	0
28574	755515	20248J	19691J	0
25199	648779	19673G	20074E	0
28020	736293	04033B	20026V	0
28021	736293	19621T	20058E	0
28582	756592	14205J	21050A	0
8721	176225	95035G	95059Q	0
29685	804286	14253S	20044X	0
26320	669286	05012A	20136B	0
8822	179172	11100Y	98050T	0
28585	755537	14355X	14026U	0
11750	244580	19549D	08055A	0
29686	804286	19667J	21090J	0
28587	755537	19367Y	14213J	0
29687	804286	14331P	08034U	0
29688	804286	08009T	19335Q	0
11752	244580	15447F	98023Q	0
6198	137142	04042C	95059Q	0
24160	617203	14097Y	12028B	0
24161	617203	01062T	11054L	0
9882	196738	11069T	11106F	0
25206	649089	01057W	11048N	0
7705	161040	01034P	11093T	0
8474	172226	14039A	01014K	0
25210	648779	20108W	11010L	0
25211	648779	07004J	14231L	0
14748	350901	11010L	07034Q	0
25212	649089	20044X	08011M	0
8741	176366	95035G	95059Q	0
25216	649089	99004R	07029T	0
25220	649156	19319Q	14267Y	0
25438	654300	19747H	11090Q	0
25439	654300	01025N	01043Q	0
6199	137142	01056V	07024N	0
8481	172435	00003C	04053F	0
12283	276036	19549D	08055A	0
8844	177614	11072N	04056J	1
9891	197533	92045V	04074L	0
14983	361175	19503N	08055A	0
7781	163084	11080N	95059Q	0
16824	423852	14355X	98024R	0
8746	176366	11106F	01014K	0
9921	198065	11043H	11091R	0
25904	667696	01057W	11048N	0
7950	167692	95067Q	04074L	0
8501	172512	00003C	04053F	0
25910	665225	19745F	14219Q	0
16845	426125	14059S	08039A	0
9925	198065	14329V	14209N	0
16847	425346	14179A	08044W	0
10981	221368	14061L	08039A	0
11943	258643	19599P	08055A	0
6924	148431	08065C	07024N	0
25916	667912	20054A	11090Q	0
11514	237429	14061L	08039A	0
25943	667697	04071H	11048N	0
25945	667697	08034U	07029T	0
11522	235609	19599P	08055A	0
6926	148431	04035D	95059Q	0
9933	198065	11011M	14363X	0
15046	363577	80027E	08055A	0
9942	197493	04071H	04055H	0
16856	423925	14257W	08068F	0
12962	295772	11043H	04018C	0
9967	198067	11101A	11100Y	0
9983	197952	11023D	12042Y	0
10021	198612	12042Y	04053F	0
10031	198612	11023D	14271U	0
15152	367353	14179A	08044W	0
15223	373899	87003B	08039A	0
10346	202913	10015M	04074L	0
15224	373899	14063N	08043V	0
10349	202913	14275Y	01047U	0
10355	202915	10015M	04074L	0
10358	202915	14275Y	01047U	0
20307	509857	19577H	14219Q	0
16881	423926	14257W	08068F	0
15232	373922	14001X	98035U	0
269	5071	05004A	\N	0
270	5071	11068S	\N	0
271	5071	14167V	\N	0
272	5071	11053K	\N	0
273	5071	14085U	\N	0
274	5071	01048V	\N	0
275	5071	08073C	\N	0
332	6613	11068S	\N	0
333	6613	14167V	\N	0
334	6613	14277B	\N	0
335	6613	11085T	\N	0
336	4448	14209N	\N	0
337	4448	04061F	\N	0
7061	151332	95031C	95059Q	0
9682	190512	14259Y	04074L	0
29475	794751	19367Y	14071N	0
25016	645490	01057W	11048N	0
26616	690887	19707Y	11090Q	0
29479	794710	20098N	08018U	0
27731	730674	07033P	97011G	0
12240	273906	14249W	04018C	0
28162	744201	20118Y	20136B	0
9802	197532	08025T	04079R	0
27732	730674	14059S	14193X	0
9203	187732	14211G	04036E	0
24877	639945	19667J	11048N	0
9204	187732	08065C	92031P	0
27733	730674	16685X	01024M	0
5511	120503	95031C	95059Q	0
29480	794710	10015M	14053L	0
29481	794710	19729F	19447X	0
29482	794710	11085T	14231L	0
9207	187732	95031C	98021N	0
29350	786197	19673G	21044C	0
7063	151332	95035G	07024N	0
9208	187732	95035G	95059Q	0
12241	273906	04033B	08039A	0
13626	319338	11043H	04018C	0
28164	744201	20032T	14031R	0
27736	730674	19721W	20042V	0
23662	602566	20064C	12028B	0
13627	319338	92040Q	14061L	0
9345	188953	08073C	01031L	1
29999	818880	19749K	20036X	0
29483	794710	14275Y	19749K	0
5255	117372	95031C	95059Q	0
23665	602566	14255U	01024M	0
23666	602566	17023S	16685X	0
3621	82431	08016S	\N	0
9347	188953	14167V	11042G	1
27737	730674	14097Y	12028B	0
28917	765500	19399H	07029T	0
27738	730674	14133K	11080N	0
9290	188355	14199E	01027Q	1
28699	761563	04008A	08018U	0
13485	313990	10015M	07034Q	0
30000	818880	11085T	19111A	0
29351	786197	19729F	08018U	0
30001	818557	20264J	14021P	0
10506	210115	11010L	19483C	0
9824	197413	08069G	11088W	0
30002	818916	19685L	14219Q	0
7623	160832	98021N	95059Q	0
14890	355955	19663E	98024R	0
28702	761563	20074E	21044C	0
11612	241163	10015M	19483C	0
30003	818916	05012A	14031R	0
25020	645490	19741B	20086J	0
28167	744201	19826F	14219Q	0
7143	151599	07034Q	04074L	0
11615	241278	07033P	08039A	0
29484	794710	20108W	14215L	0
9294	188355	11042G	01031L	1
7627	160832	08065C	04036E	0
24754	635313	19826F	14219Q	0
29485	794751	01034P	21064G	0
29486	794751	20090E	14026U	0
28170	744203	19707Y	19705W	0
29487	794710	19673G	05008E	0
28172	744203	08028W	11090Q	0
28173	744203	20078J	14038Y	0
25366	652461	19707Y	19705W	0
13493	313988	04047H	07034Q	0
30004	818916	21065H	21070E	0
24882	639945	01057W	07029T	0
7816	164944	01028R	04056J	0
28704	761563	19749K	11085T	0
30005	818916	20076G	20136B	0
18618	477748	19729F	04044E	0
24885	639945	01048V	08011M	0
29489	794694	20040T	17229F	0
21025	534276	05012A	20136B	0
29490	794694	19685L	19826F	0
28706	761563	14189C	21038E	0
29491	794694	21061D	14031R	0
9349	188953	08073C	01031L	2
30006	818880	14275Y	14231L	0
7129	151487	95031C	95059Q	0
26628	690416	19735D	20052X	0
9351	188953	14167V	11042G	2
25368	652461	19768N	11090Q	0
7133	151487	95035G	07024N	0
29492	794850	14073Q	14030Q	0
14905	356853	19663E	98024R	0
26629	690416	20124W	19643A	0
28918	765500	08010L	14331P	0
26630	690416	04033B	19399H	0
29493	794850	20058E	20180F	0
25374	650991	05012A	20136B	0
26631	690416	11104D	08012N	0
26632	690416	04070G	14073Q	0
26633	690416	14030Q	19611R	0
26634	690416	20138D	20980G	0
28180	744092	14275Y	14179A	0
9515	190497	08025T	11035H	1
12258	273907	14249W	04018C	0
9517	190497	01028R	04056J	1
29494	794850	21089R	14229S	0
12259	273907	04033B	08039A	0
28921	765500	19479G	14327T	0
10166	200614	10006L	04081K	0
26639	690416	20058E	20026V	0
26640	690416	19621T	20056C	0
28922	765500	20024T	11048N	0
28924	765500	08034U	20044X	0
29495	794850	21055F	19621T	0
26645	688931	19685L	14219Q	0
26646	690386	04070G	14073Q	0
26647	690386	19735D	20052X	0
29496	794850	14123H	20056C	0
29497	794850	11043H	20026V	0
29498	794850	14109K	20264J	0
29499	794850	08012N	21077M	0
29500	794850	20052X	20048C	0
29501	794852	14073Q	14030Q	0
26653	690709	14275Y	14179A	0
26654	690709	11085T	14231L	0
29502	794852	20058E	20180F	0
29503	794852	21089R	14229S	0
10282	201055	08014Q	01031L	0
29504	794852	21055F	19621T	0
29505	794852	14123H	20056C	0
29506	794852	11043H	20026V	0
10286	200372	04079R	04056J	0
29507	794852	14109K	20264J	0
29508	794852	08012N	21077M	0
26665	690709	19447X	20074E	0
29509	794852	20052X	20048C	0
29516	795681	20040T	17229F	0
10323	202527	14123H	11091R	0
10324	202527	14191V	14363X	0
29517	795681	21061D	14031R	0
10325	202527	14329V	01041N	0
29518	795681	20136B	19701S	0
11973	261092	98053W	14235Q	0
26675	690709	19954N	19581D	1
16527	416431	92040Q	08039A	0
10954	219917	11110B	14085U	0
13631	319338	14249W	08039A	0
16529	416431	11043H	04018C	0
16530	416431	11109J	08043V	0
16538	416431	19621T	08020N	1
28670	761029	20086J	11048N	0
12146	270439	08014Q	14085U	0
28671	761029	12016W	14225N	0
22510	568137	19709B	19421M	0
27678	730641	14275Y	14179A	0
11323	228416	14159V	14085U	0
16561	417388	11026G	98035U	0
28674	761029	20044X	14331P	0
15532	380226	19621T	04018C	0
29122	773787	19667J	20086J	0
27683	730757	19707Y	19705W	0
28197	744705	11099A	20092G	0
27685	730757	20104S	11090Q	0
12771	293441	10015M	07034Q	0
22576	571298	14255U	14267Y	0
11356	230586	08014Q	14085U	0
28676	761029	08009T	19335Q	0
24896	641818	19826F	14219Q	0
24321	621458	11104D	08012N	0
28678	761029	14253S	07029T	0
27743	732659	11053K	14327T	0
28316	748162	19741B	11048N	0
28192	744705	08028W	14038Y	0
13266	305572	14213J	14087W	0
27745	732659	19711U	14331P	0
24901	642011	14089Y	14231L	0
27746	732659	01048V	11048N	0
27747	732659	08009T	19335Q	0
27748	732659	14253S	20044X	0
24904	642011	11085T	19749K	0
11380	230587	12016W	14085U	0
24906	642011	07004J	19543W	0
25318	650988	08011M	11048N	0
27749	732659	14173T	01057W	0
13278	306020	04043D	08039A	0
28193	744705	20078J	11090Q	0
15546	378234	08041T	98024R	1
28194	744705	20298U	01025N	0
14017	325060	08053X	14028W	0
25151	647669	08034U	11048N	0
28318	748162	01048V	07029T	0
25155	647519	11085T	19749K	0
25156	647519	14089Y	14231L	0
15548	382289	08041T	98024R	0
28320	748162	19667J	04071H	0
28323	748163	19762G	11097X	0
25165	647519	19729F	19581D	0
28685	760765	14275Y	19749K	0
14037	326861	04033B	04018C	0
28686	760765	20074E	20098N	0
28687	760765	20022R	21044C	0
28692	761030	19667J	07029T	0
25321	650988	08034U	07029T	0
25324	649319	11101A	18083K	0
25326	649319	19826F	14219Q	0
25328	649319	20020P	20136B	0
29124	773787	21072G	11048N	0
29125	773787	08034U	19573D	0
29127	773787	08011M	20044X	0
13858	322194	14187A	14115H	0
29140	777130	19399H	20086J	0
29141	777130	20126Y	11048N	0
29143	777130	08011M	20044X	0
16835	423891	14355X	98024R	0
29145	777130	21072G	07029T	0
13974	324291	04044E	07034Q	0
17486	439891	19631V	08068F	0
14121	326842	08041T	14087W	0
14686	349223	14061L	08039A	0
17487	439891	14081Q	14197C	0
14137	328229	19709B	98050T	0
15582	382835	11043H	04018C	0
14448	341079	08020N	08039A	0
15583	382835	14061L	08039A	0
14450	341079	08012N	08043V	0
15585	382835	11104D	08043V	0
14687	349223	07033P	04018C	0
14604	345003	08018U	14061L	0
17504	439892	19631V	08068F	0
17505	439892	14081Q	14197C	0
22521	571304	19577H	14219Q	0
22526	571304	20038A	20136B	0
11781	250308	96004D	98023Q	0
25222	649446	01025N	01043Q	0
11783	250308	19599P	08055A	0
26578	688394	11101A	18083K	0
27896	738333	20138D	14038Y	0
11990	263476	15447F	98023Q	0
28218	746014	11115U	97011G	0
12482	282490	19701S	98023Q	0
16503	413425	14159V	14085U	0
22723	575253	20104S	19383Y	0
13009	299062	14081Q	08038Y	0
17923	453808	10006L	98024R	0
25226	649446	08015R	11090Q	0
27929	738017	11010L	20074E	0
27935	737731	11103C	10006L	0
12499	282508	19673G	07034Q	0
27940	738361	19711U	11048N	0
27941	738361	14253S	20044X	0
27942	738361	08011M	01057W	0
27943	738361	11053K	14327T	0
28220	746014	19721W	20042V	0
27947	735924	19621T	19533U	0
27949	735924	11109J	04059M	0
28221	746014	16685X	19319Q	0
27952	735924	14229S	19527W	0
18389	472056	19719D	19253P	0
16391	407544	19319Q	04040A	0
27953	735924	20980G	20056C	0
27954	735924	20180F	19693L	0
24600	631733	20138D	19399H	0
12657	289733	14147R	07034Q	0
27957	738017	14275Y	14179A	0
27958	738362	14253S	20044X	0
27959	738362	08011M	01057W	0
27970	736883	20096L	19701S	0
28222	746014	01058X	14193X	0
27971	736883	19551W	19549D	0
16585	417479	11043H	04018C	0
28223	746014	08069G	14059S	0
28225	746014	07033P	04035D	0
13122	302500	19575F	14087W	0
16586	417479	19693L	08039A	0
28297	747823	11101A	20090E	0
24607	631733	20152B	19693L	0
23824	606402	19319Q	14267Y	0
24604	631733	11109J	08012N	0
23952	610674	14255U	14267Y	0
13401	310257	14331P	98050T	0
14730	346533	18083K	19794Q	0
23953	610674	19319Q	16685X	0
23954	610674	19669L	01062T	0
24605	631733	20052X	20048C	0
23971	610534	01025N	01043Q	0
18398	472064	19415P	98024R	0
24606	631733	14109K	11104D	0
24610	631733	19699S	14073Q	0
24611	631733	20142Y	20134Y	0
24617	631935	14109K	11104D	0
24618	631935	19699S	14073Q	0
16598	416166	19295A	08068F	0
24622	631935	20172F	19693L	0
15214	371214	19673G	11049P	0
24627	631935	20052X	20048C	0
24629	631935	20142Y	20134Y	0
15244	373922	14147R	11049P	0
15248	373899	14201E	08031R	0
18127	458796	19415P	14119M	0
16603	416795	14225N	14085U	0
15263	373900	14201E	08031R	0
15267	373900	14249W	08039A	0
15277	373993	14001X	98035U	0
15281	373993	08018U	11049P	0
18047	456490	14255U	04040A	0
15289	373901	14061L	08039A	0
15608	382613	19551W	08055A	0
15295	373901	14201E	08031R	0
16613	416167	19295A	08068F	0
18417	472058	19719D	19253P	0
15610	382613	17637T	19794Q	0
18066	456617	19663E	98024R	0
16618	415006	14051J	08055A	0
16620	417479	14201E	08031R	0
28568	755943	14173T	20086J	0
11871	255991	19599P	08055A	0
26010	669478	20138D	19693L	0
27756	732939	11053K	14327T	0
26531	687362	14109K	11104D	0
12168	270566	08041T	14087W	0
27758	732939	19711U	14331P	0
26532	687362	20152B	20056C	0
16623	417479	14249W	08020N	0
21781	556980	19577H	14219Q	0
12173	270395	96004D	98023Q	0
28569	755943	08011M	11048N	0
27759	732939	01048V	11048N	0
28597	757768	18083K	14031R	0
27760	732939	08009T	19335Q	0
27761	732939	14253S	20044X	0
27762	732939	14173T	01057W	0
24027	611540	14109K	11104D	0
28572	755943	14083S	07004J	0
13092	301908	19693L	95015C	0
26534	687362	19766L	19693L	0
29322	787200	20062A	11048N	0
28598	757768	20032T	20136B	0
29045	773521	19667J	11048N	0
28599	757768	19619A	14219Q	0
26902	696275	08061X	11083R	0
27387	715211	11041F	19669L	0
28711	761564	20098N	08018U	0
16044	398365	04033B	04018C	0
27389	715211	08056B	97011G	0
25257	647948	19573D	19399H	0
27391	715211	04035D	14193X	0
25258	647948	20124W	20056C	0
29046	773521	20126Y	07029T	0
13095	301908	19399H	08039A	0
13096	301908	14249W	04018C	0
25259	647948	92040Q	19533U	0
12427	279503	04061F	14061L	0
16627	416834	14225N	14085U	0
29325	787200	14173T	20086J	0
25260	647948	04033B	19693L	0
27392	715211	19443T	19421M	0
27393	715211	20064C	01062T	0
28718	761564	19749K	21038E	0
28719	761564	20022R	05008E	0
24046	613320	19577H	14219Q	0
29196	780021	19573D	20044X	0
12439	280937	14147R	07034Q	0
28734	761590	14267Y	17023S	0
28732	761183	20062A	19399H	0
25267	649773	20144B	19441R	0
29048	773521	14173T	20044X	0
29049	773521	21072G	20086J	0
29060	773657	08011M	20044X	0
13103	301909	19693L	95015C	0
29061	773657	21072G	11048N	0
29062	773657	20126Y	14173T	0
13106	301909	19399H	08039A	0
13107	301909	14249W	04018C	0
25637	656840	14133K	97011G	0
26015	667816	17229F	14219Q	0
29063	773657	20086J	19399H	0
29064	773657	08010L	19573D	0
25639	656840	11115U	19443T	0
25640	656840	11027H	12028B	0
25641	656840	11041F	11054L	0
25642	656840	11066Q	01062T	0
25643	656840	19319Q	14267Y	0
29198	780021	20126Y	08010L	0
17363	437203	14169X	15447F	0
26017	669569	14089Y	14231L	0
17364	437203	14157T	19794Q	0
29200	780021	19667J	11048N	0
29327	787200	21072G	20044X	0
29341	787242	14105F	14193X	0
29343	787242	20042V	14267Y	0
15843	391674	14123H	08039A	0
15844	391674	08035V	08043V	0
29345	787242	19709B	08047A	0
16769	422672	19319Q	04040A	0
29346	787242	21036C	14059S	0
29347	786197	19749K	21038E	0
15854	390980	80027E	08055A	0
26037	669559	20044X	20086J	0
26040	669559	20044X	07029T	1
16145	400603	14221J	14103D	0
16073	398302	19599P	08055A	0
16075	398302	04069P	19794Q	0
16245	405111	95062K	19794Q	0
16152	400273	19631V	08068F	0
16165	400276	19631V	08068F	0
16170	400276	19295A	08038Y	0
22409	567376	14237S	20136B	0
16304	404870	19447X	11049P	0
16312	406662	11043H	04018C	0
16313	406662	04033B	08039A	0
17366	437203	17637T	04097T	0
22424	567377	14237S	20136B	0
17521	441789	19713W	19737F	0
18590	477701	95041E	96004D	0
29976	818915	21047F	14237S	0
11373	230595	19729F	19483C	0
29977	818915	20120S	20136B	0
27537	721224	08012N	11104D	0
27538	721224	11109J	14109K	0
28376	747854	19467C	19383Y	0
27539	721224	04033B	19693L	0
29978	818915	05012A	20118Y	0
27006	698941	95041E	14193X	0
22477	567379	19577H	14219Q	0
26090	672260	11085T	14231L	0
29979	818915	20076G	21080G	0
22479	567379	05012A	20136B	0
26177	672576	08010L	11048N	0
14360	339505	14053L	07034Q	0
11397	230588	12016W	14085U	0
29980	818915	20032T	19701S	0
25656	656824	99004R	11048N	0
29981	818915	21068L	20020P	0
29982	818915	19826F	15197G	0
16082	397657	19319Q	04040A	0
16007	396520	87003B	08020N	0
12000	262943	98053W	14235Q	0
29983	818879	04008A	10015M	0
25660	657790	19507S	19383Y	0
25661	657790	20286Q	01043Q	0
29984	818879	21038E	14189C	0
28380	747854	19703U	20172F	0
29985	818879	11085T	19111A	0
29986	818879	05008E	04047H	0
16008	396520	14059S	08039A	0
29987	818879	21044C	19673G	0
29988	818879	19729F	14147R	0
25677	659362	10015M	19581D	0
27668	728520	20298U	01025N	0
29989	818879	14069U	14053L	0
25679	659362	19673G	20074E	0
29990	818879	08018U	14215L	0
17025	427859	12041X	14235Q	0
12316	275757	12016W	14085U	0
27542	721224	19399H	11043H	0
26173	672576	20252E	07029T	0
22812	578921	16685X	14267Y	0
11748	247147	15447F	98023Q	0
17543	441619	11067R	14065Q	0
27543	721224	20180F	20056C	0
26092	670786	20052X	19611R	0
26093	670786	19527W	14109K	0
26094	670786	20264J	11104D	0
26095	670786	11043H	20056C	0
12342	278758	80027E	08055A	0
12345	278758	19383Y	98023Q	0
22817	578921	14191V	19443T	0
12519	281772	11110B	14085U	0
22818	578921	98018T	19421M	0
12531	281773	11110B	14085U	0
26096	670786	19766L	19533U	0
22820	578921	11027H	12028B	0
13243	305522	14157T	98023Q	0
22821	578921	11054L	01062T	0
22822	578921	11041F	11066Q	0
22823	578921	19721W	01024M	0
26098	670786	19399H	19643A	0
26099	670786	04033B	19693L	0
13271	305921	04008A	07034Q	0
17231	430310	19679N	14119M	0
17048	428373	14147R	11049P	0
27544	721224	19766L	19533U	0
27694	730319	08012N	11104D	0
26110	670816	20180F	19693L	0
13363	309053	14259Y	07034Q	0
26112	670816	20058E	11043H	0
26113	670816	19766L	19533U	0
27562	723223	11053K	14327T	0
26114	670816	20152B	20056C	0
14147	328614	19549D	08055A	0
27564	723223	19741B	11048N	0
26371	681086	14329V	11090Q	0
26118	670816	20048C	19611R	0
14159	328614	19733B	98023Q	0
26120	670816	19699S	14073Q	0
26124	669278	20120S	18083K	0
26125	669278	17229F	14219Q	0
27104	704216	19367Y	19415P	0
26128	672573	20086J	11048N	0
17081	428243	08014Q	14085U	0
26132	669278	19525U	19637C	0
14193	330479	14223L	14119M	0
27671	728520	19707Y	14038Y	0
27672	728520	19705W	11090Q	0
27118	704329	20252E	20086J	0
27119	704216	19657G	20148F	1
26147	672574	14331P	07029T	0
27281	709570	14329V	11090Q	0
14493	342001	19581D	07034Q	0
15965	392897	12041X	14235Q	0
27294	706384	14193X	19643A	0
14503	342001	19489J	98035U	0
16128	398232	19705W	14115H	1
27728	730646	14275Y	14179A	0
16133	399906	19399H	14061L	0
16134	399906	11104D	08043V	0
16135	399906	08020N	08039A	0
17590	441788	04008A	11049P	1
17602	442696	11067R	14065Q	0
28404	750635	19667J	11048N	0
28405	750635	99004R	01057W	0
11543	238871	19599P	08055A	0
29722	804017	20022R	20074E	0
26197	672578	14173T	11048N	0
28996	772077	08010L	11048N	0
26199	672578	08034U	07029T	0
27619	727813	08034U	11048N	0
29723	804017	04045F	11072N	0
18737	480013	19533U	04018C	0
28997	772077	11070L	14083S	0
27520	721236	11053K	14327T	0
26204	672578	14189C	14327T	0
29911	810556	21042A	19826F	0
18736	480013	08031R	14241N	0
29714	804287	08011M	21090J	0
28999	772077	14173T	07029T	0
26816	695193	14173T	11048N	0
22019	560589	19826F	14219Q	0
29715	804287	20086J	11048N	0
11560	238968	19621T	08039A	0
29721	804017	19749K	21038E	0
27623	727813	20044X	07029T	0
13182	305413	08018U	07034Q	0
18080	457099	19711U	14079W	0
27624	727813	04071H	20086J	0
26821	694841	14275Y	14179A	0
29724	804017	19729F	19447X	0
27763	730865	19611R	14073Q	0
18738	480013	11043H	08039A	0
29725	804017	14259Y	14215L	0
18083	457100	19711U	14079W	0
27122	703790	14275Y	14179A	0
29726	804017	05008E	08018U	0
27124	703790	19543W	07004J	0
27125	703790	11085T	19749K	0
12627	286236	80027E	08055A	0
27765	730865	20026V	19643A	0
27766	730865	20098N	19533U	0
27127	703790	14179A	14231L	0
22022	560589	14169X	20136B	0
27767	730865	04070G	20052X	0
29727	804087	14267Y	14255U	0
29728	804087	01058X	14059S	0
27346	715733	19723Y	19415P	0
29912	810556	19619A	21053D	0
27768	730865	19399H	19693L	0
27769	730865	11109J	14229S	0
29729	804087	08047A	14133K	0
29910	810556	15197G	17229F	0
12230	273624	19599P	08055A	0
11830	251925	98053W	14235Q	0
29151	775973	21056G	18207D	0
27770	730865	19766L	20056C	0
27350	715733	14355X	20148F	0
27962	738998	14357A	11090Q	0
29913	813206	04008A	20108W	1
29152	775973	14259Y	05008E	0
27965	737730	11103C	10006L	0
29730	804087	14105F	14193X	0
12232	273624	96004D	98023Q	0
29731	804087	19709B	04042C	0
29732	804087	21036C	19421M	0
29914	813206	21095P	20098N	0
29915	813206	10015M	19447X	0
27978	738516	14357A	11090Q	0
27979	738262	11041F	11054L	0
27980	738262	20064C	14097Y	0
12631	287012	14069U	07034Q	2
27981	738262	19721W	20042V	0
29154	777911	14173T	20044X	0
13672	318672	11010L	07034Q	0
29155	777911	19667J	11048N	0
27984	738262	07033P	14059S	0
14641	346252	14061L	08039A	0
27985	738262	14191V	14193X	0
29733	804086	14267Y	14255U	0
27987	738262	11115U	97011G	0
27988	738262	19443T	19421M	0
29916	814716	20058E	20056C	0
29158	777911	19573D	20086J	0
27991	738363	20126Y	11048N	0
15759	386221	19631V	08038Y	0
29734	804086	01058X	14059S	0
29160	775973	14231L	14275Y	0
29735	804086	08047A	14133K	0
27995	738363	14331P	20044X	0
27996	738363	14173T	19762G	0
13681	318859	12041X	14235Q	0
29161	775973	14189C	19749K	0
29736	804086	14105F	14193X	0
29737	804086	19709B	04042C	0
29164	776030	20040T	14219Q	0
28055	740753	19729F	20074E	0
13687	318038	19549D	08055A	0
28060	740833	19667J	11048N	0
15984	396519	08035V	08043V	0
13690	318038	96004D	98023Q	0
29738	804086	21036C	19421M	0
16582	416673	19647E	14085U	0
29917	814716	20032T	20026V	0
29168	775973	08018U	21044C	0
29169	775973	11085T	21038E	1
29170	777919	14195A	21046E	0
29171	777919	20248J	21064G	0
14645	346252	19766L	04018C	0
14759	350700	19549D	08055A	0
20161	503170	19577H	14219Q	0
16052	398366	08012N	08043V	0
15188	370966	04033B	04018C	0
15191	370966	19766L	08039A	0
16700	420646	19723Y	98024R	0
16054	398366	08020N	08039A	0
16002	396050	12041X	14235Q	0
16326	405615	19515S	19794Q	0
16336	406928	04069P	19794Q	0
16720	420647	19723Y	98024R	0
28408	750663	19611R	14030Q	0
29991	818880	04008A	04047H	0
29676	804006	04008A	04047H	0
25121	646157	19669L	12028B	0
11345	230594	04044E	19483C	0
25122	646157	04035D	19421M	0
26338	679538	19667J	11048N	0
25123	646157	19721W	01024M	0
28407	750635	01048V	20044X	0
25352	652165	17637T	20136B	0
29992	818880	19729F	14053L	0
12059	267060	15447F	98023Q	0
27357	702225	19577H	14219Q	0
29677	804006	14089Y	14231L	0
28410	750663	11043H	19693L	0
28507	753252	17229F	14219Q	0
29447	791690	20108W	14147R	0
25125	646157	11041F	01062T	0
29993	818880	21038E	14189C	0
25126	646157	14255U	16685X	0
29445	791690	19729F	14053L	0
28412	750663	20048C	20052X	0
28508	753252	21029D	14031R	0
29446	791690	21044C	19447X	0
25128	646157	14133K	97011G	0
28743	761591	14267Y	17023S	0
28414	750635	14253S	19741B	0
29994	818880	20022R	19447X	0
28415	750663	04033B	19533U	0
28600	758747	19545Y	20050V	0
25130	646157	11027H	11066Q	0
28632	757863	20034V	14033T	0
28416	750663	04070G	19735D	0
29448	791690	11085T	14089Y	0
27362	702225	20068G	11101A	0
29679	804006	14147R	10015M	0
28418	750663	04059M	14109K	0
25346	651574	11085T	19749K	0
28419	750663	19699S	14073Q	0
28420	750663	20138D	20152B	0
29450	791690	14231L	19749K	0
25347	651574	19543W	14231L	0
28421	750663	19527W	14229S	0
29451	791774	17023S	20042V	0
28601	758747	08011M	11048N	0
17271	435793	14197C	08068F	0
23044	586490	19621T	19383Y	0
28602	758747	08009T	07004J	0
28424	749997	07033P	97011G	0
29452	791666	15197G	21053D	0
15403	376985	04033B	08039A	0
28426	749997	04035D	14059S	0
29453	791666	20040T	17229F	0
29454	791666	20118Y	14031R	0
25354	652165	20118Y	18083K	0
28427	749997	14191V	14193X	0
28428	749997	19443T	19421M	0
12074	267061	08060W	08055A	0
29995	818557	19735D	14073Q	0
29680	804006	19729F	19447X	0
12075	267061	15447F	98023Q	0
28431	749959	19675J	14069U	0
29996	818557	14109K	14229S	0
29681	804006	08018U	14053L	0
28604	758747	11053K	14327T	0
28634	757863	20066E	21050A	0
29997	818557	04070G	20052X	0
29998	818557	20172F	19621T	0
28636	757863	14329V	19768N	0
13999	325060	12041X	14235Q	0
28439	749959	19543W	19749K	0
15114	367754	11049P	19794Q	0
28442	749959	14275Y	14179A	0
28443	749997	19319Q	01024M	0
28747	761566	14259Y	14069U	0
26368	681084	14329V	11090Q	0
16023	396050	14079W	98050T	0
28449	749960	19543W	19749K	0
13424	310419	19657G	14087W	0
28452	749960	14275Y	14179A	0
28752	761566	20108W	08018U	0
28754	761566	19749K	21038E	0
28756	761566	20098N	20074E	0
28759	761747	19701S	14031R	0
28761	761747	21029D	18083K	0
16265	404924	80013X	08068F	0
16766	422452	19657G	98024R	0
16266	404924	19295A	08038Y	0
12595	286235	14038Y	98023Q	0
12597	286235	80027E	08055A	0
13410	310543	14133K	08039A	0
15407	376985	14063N	08043V	0
13480	311331	19581D	07034Q	0
15338	371837	14355X	98024R	0
15341	375459	04033B	08039A	0
14027	324291	08018U	07034Q	0
15342	375459	11043H	04018C	0
14043	325790	19705W	14115H	0
14046	325790	19768N	04088S	0
15345	375459	87003B	14061L	0
19934	503158	17229F	14219Q	0
14255	331592	14259Y	07034Q	0
15410	376985	14249W	04018C	0
17278	435787	08020N	04018C	0
15787	389606	11010L	11049P	0
15788	389606	04008A	11049P	1
17286	432904	19745F	19737F	0
17304	435794	14197C	08068F	0
17305	435787	14123H	14061L	0
26138	673345	20286Q	01043Q	0
15418	376986	19533U	08039A	0
16907	424936	98029W	95037J	0
16920	427428	04033B	04018C	0
11293	228415	08014Q	14085U	0
29381	789278	19673G	08018U	0
18810	480818	95067Q	98050T	0
28325	747871	14026U	14038Y	0
26140	672322	14179A	14231L	0
28326	747871	14237S	20152B	0
26141	672322	07004J	19543W	0
24201	618372	08028W	19515S	0
29842	810211	21038E	14231L	0
29843	810904	01058X	07033P	0
29382	789278	19729F	19447X	0
18813	480818	11080N	95030B	0
23874	608647	11026G	14021P	0
29844	810904	95041E	14133K	0
16926	427428	14107H	08031R	0
27109	704329	11053K	14327T	0
11310	228988	04033B	08039A	0
29845	810904	19421M	08047A	0
28329	748167	19335Q	08009T	0
23886	608649	11085T	19543W	0
27031	701622	14089Y	14231L	0
16927	427428	92040Q	08020N	0
12296	275756	12016W	14085U	0
26229	677304	19705W	11090Q	0
29846	810904	14267Y	14255U	0
12300	276033	14249W	95015C	0
29847	810904	08056B	17737W	0
28330	748167	19741B	11048N	0
28530	754136	08011M	11048N	0
12304	276033	14059S	04018C	0
27032	701622	19543W	11085T	0
27033	701622	14275Y	07004J	0
28331	748167	08034U	20044X	0
29206	779299	04092N	14026U	0
28332	748167	20126Y	01057W	0
12337	275758	12016W	14085U	0
29383	789278	11085T	14231L	0
29849	810904	17367Q	19709B	0
29267	783098	19826F	21086N	0
22268	564954	19577H	14219Q	0
27040	700257	20052X	20048C	0
28543	753674	20042V	17023S	0
27041	700257	14030Q	19611R	0
27042	700257	19699S	14073Q	0
14835	354848	05008E	07034Q	0
29456	794708	10015M	14147R	0
27044	701623	17737W	20074E	0
28334	748167	14173T	14331P	0
29851	810904	14179A	19721W	0
24205	618372	01025N	01043Q	0
29270	783098	20086J	14237S	0
29384	789278	14215L	14053L	0
28544	753674	14105F	14193X	0
29385	789278	20108W	10015M	0
28336	748167	08011M	07029T	0
27051	698972	20118Y	11101A	0
23919	609285	19954N	19533U	0
12370	279401	14147R	07034Q	0
17311	435787	04033B	08039A	0
28456	751584	11085T	19749K	0
29386	789892	14173T	11048N	0
27053	698972	20068G	18083K	0
29457	794708	20108W	21044C	0
28545	753674	14191V	19421M	0
29388	789371	95041E	08047A	0
14821	354228	14061L	08039A	0
27058	701623	14089Y	14231L	0
17315	435786	14123H	14061L	0
27059	698972	19577H	14219Q	0
27060	701622	19581D	19675J	0
28546	753674	19721W	14267Y	0
17317	435786	04033B	08039A	0
29389	789371	14105F	14193X	0
29390	789371	01058X	14059S	0
14825	354228	08017T	08043V	0
28547	753674	95041E	08047A	0
12707	289196	19531S	14085U	0
27110	704329	19741B	11048N	0
28462	751769	19711U	07029T	0
29458	794708	19673G	14215L	0
28463	751769	19741B	08010L	0
12720	291186	14249W	08039A	0
27071	701687	19709B	19421M	0
27072	701687	14097Y	11066Q	0
27073	701687	08069G	97011G	0
27075	701789	20298U	19441R	0
14828	354229	14061L	08039A	0
29392	789892	08009T	14083S	0
27077	701791	19575F	11090Q	0
12740	287620	08048B	14087W	0
12741	287620	11097X	14119M	0
27078	701688	11041F	19669L	0
17323	435786	08020N	04018C	0
29393	789892	19335Q	14327T	0
29394	789371	20042V	14255U	0
27083	701688	19709B	19421M	0
27084	701688	14097Y	11066Q	0
27085	701688	08069G	97011G	0
29396	789371	17023S	11115U	0
27113	704329	19762G	07029T	0
29397	789372	95041E	08047A	0
29398	789372	14105F	14193X	0
12794	293442	10015M	07034Q	0
20241	509855	19577H	14219Q	0
29399	789372	01058X	14059S	0
29401	789372	20042V	14255U	0
27286	706386	19721W	20042V	0
29403	789372	17023S	11115U	0
14832	354229	08017T	08043V	0
29461	794708	20098N	08018U	0
12805	293992	95015C	08039A	0
29462	794708	19729F	19447X	0
29464	794708	14275Y	19749K	0
29465	794708	20074E	21095P	0
12816	293993	95015C	08039A	0
12827	293446	19413M	08038Y	0
12835	293445	14197C	08038Y	0
12837	293445	80013X	14081Q	0
13811	322290	14061L	08039A	0
12844	293444	14197C	08038Y	0
12846	293444	80013X	14081Q	0
13207	305577	14069U	07034Q	0
13209	305574	04033B	08039A	0
13213	305574	87003B	08039A	0
13218	305575	14187A	14115H	0
13232	305575	19467C	14115H	0
22325	565714	19577H	14219Q	0
13816	320713	15447F	98023Q	0
12991	294874	14147R	07034Q	0
27451	719055	19667J	08011M	0
24568	629124	11027H	12028B	0
28605	758747	19573D	20044X	0
14854	355708	19762G	07034Q	0
26512	685293	19577H	14219Q	0
27856	735610	19441R	19369B	0
27417	719055	20126Y	07029T	0
28607	758135	19747H	11043H	0
18205	462692	14225N	14085U	0
27857	735610	20078J	14038Y	0
28608	758135	18395Y	21089R	0
27418	718556	11085T	14231L	0
25595	656046	04071H	11048N	0
25448	654299	19747H	11090Q	0
26520	686365	19447X	19581D	0
22848	581921	19729F	19675J	0
27858	735610	14357A	11090Q	0
27859	735610	19707Y	19705W	0
12585	286328	14147R	07034Q	0
18210	462693	14225N	14085U	0
26522	686581	14097Y	12028B	0
25453	651775	20068G	18083K	0
26557	686430	20044X	07029T	0
29039	773155	08010L	20044X	0
29040	773155	20126Y	19573D	0
25457	651775	14237S	20136B	0
14575	343407	04018C	14061L	0
28615	758135	14030Q	14073Q	0
28616	757734	14275Y	14231L	0
29041	773155	14253S	20086J	0
29042	773155	20024T	11048N	0
28626	757861	20066E	21050A	0
13003	298973	14081Q	08038Y	0
17005	428662	14063N	08043V	0
28627	757861	20034V	14033T	0
26527	686581	14191V	14193X	0
26528	686581	95041E	19421M	0
17007	428662	14249W	08039A	0
26529	686581	14255U	16685X	0
24499	630083	19577H	14219Q	0
24501	630083	19251M	19549D	0
24570	629124	19319Q	14267Y	0
29043	773155	19335Q	14083S	0
29050	772421	20022R	05008E	0
13324	307457	14249W	08039A	0
29053	772421	14275Y	14231L	0
26556	686430	19741B	11048N	0
26559	686430	99004R	01048V	0
24515	629957	19251M	19549D	0
20096	505963	19577H	14219Q	0
29056	772421	19673G	20098N	0
27450	719055	20044X	01057W	0
29057	772421	19111A	21038E	0
13847	322291	14061L	08039A	0
29059	772421	08018U	14069U	0
29067	769595	20058E	20056C	0
29068	769595	14030Q	14073Q	0
24523	629957	19577H	14219Q	0
29069	769595	14229S	21089R	0
24526	629205	07004J	19543W	0
29070	769595	19735D	04070G	0
26564	686430	14331P	08011M	0
29071	769595	19747H	11043H	0
24530	629305	19621T	19693L	0
24531	629305	04033B	19399H	0
26725	691611	19621T	20056C	0
24533	629305	19573D	19533U	0
29072	769595	21055F	14123H	0
26726	691611	20098N	20026V	0
29073	769595	19954N	19621T	0
29074	773244	20144B	20066E	0
26728	691611	14073Q	20052X	0
26729	691611	19399H	19693L	0
24539	629305	20138D	19766L	0
29077	773244	21054E	21052C	0
25606	656582	04071H	11048N	0
15658	382177	14257W	14081Q	0
14348	338469	11049P	07034Q	0
24546	629958	19251M	19549D	0
26730	691611	19766L	19533U	0
14112	324910	04044E	07034Q	0
26731	691611	20138D	19643A	0
24552	629958	19577H	14219Q	0
24561	629302	19707Y	19515S	0
26733	691611	04033B	20058E	0
25611	656465	14329V	11090Q	0
24577	629124	11054L	01062T	0
15662	382177	08068F	08038Y	0
24578	629124	19721W	16685X	0
25614	656465	19707Y	19705W	0
14408	338404	08041T	14119M	0
27318	712198	19721W	14267Y	0
21773	555857	19577H	14219Q	0
26739	691611	14123H	20172F	0
25617	656465	14038Y	19383Y	0
14579	343407	04033B	08039A	0
27219	706245	11103C	19415P	0
26748	692457	20144B	19441R	0
26749	692457	08028W	11090Q	0
17036	427859	14211G	14079W	0
26753	692321	19543W	07004J	0
17037	427859	98029W	95037J	0
26756	692323	11041F	11054L	0
26758	692323	19443T	19421M	0
26759	692323	19709B	14193X	0
27320	712198	19443T	19421M	0
15901	395029	19621T	14061L	0
15903	395029	14107H	08031R	0
26798	692458	08028W	11090Q	0
26799	692458	20144B	19441R	0
16372	408829	14249W	08039A	0
26801	692321	11085T	14231L	1
15920	395029	08017T	14063N	0
26802	692321	19543W	14275Y	1
26803	692321	14259Y	20074E	0
15938	392897	19721W	04040A	0
15946	392897	01062T	14028W	0
21782	555858	19577H	14219Q	0
27296	713517	20068G	19399H	0
29179	778819	20024T	11048N	0
28337	748428	19711U	19643A	0
22584	573522	14237S	20136B	0
28516	753745	21086N	20066E	0
29831	810211	20036X	19111A	0
24936	643759	19798U	19693L	0
29832	810211	19673G	20074E	0
28339	748428	14193X	11090Q	0
29002	772361	19667J	11048N	0
27363	715267	14179A	14275Y	0
26503	686364	08018U	20074E	0
28517	753745	21050A	19563B	0
29833	810211	04008A	19447X	0
29834	810211	19729F	08018U	0
17856	450717	08061X	98029W	0
25542	655859	19621T	19643A	0
23067	586713	20120S	20136B	0
29467	795678	20040T	17229F	0
23069	586713	19577H	14219Q	0
28520	753745	19705W	14033T	0
27298	711614	11085T	14231L	0
17864	450709	14275Y	08044W	0
17935	454054	19583F	98005N	0
27299	711614	07004J	14179A	0
28522	753745	14357A	14038Y	0
28523	753745	19507S	19383Y	0
29469	795678	19251M	19820Y	0
29470	795678	21029D	20136B	0
29835	810211	20108W	04047H	0
24937	643759	14215L	19533U	0
26509	686756	20078J	11090Q	0
29246	780815	14031R	14237S	0
29471	795678	19685L	19826F	0
29472	795678	19619A	21042A	0
28594	755866	14105F	14193X	0
29003	772361	19479G	14327T	0
29473	795678	21061D	14031R	0
29247	780815	20286Q	19507S	0
29838	810211	10015M	14053L	0
28593	755866	21036C	19421M	0
29836	810211	14259Y	14215L	0
17899	449607	19663E	98024R	0
29474	795678	21035B	21051B	0
29007	772361	14173T	20044X	0
29178	778819	20086J	07029T	0
29180	778819	19667J	19399H	0
29837	810211	11085T	14089Y	0
29216	779151	17023S	14255U	0
24841	640064	19619A	14219Q	0
29217	779151	19745F	11115U	0
25231	649090	08034U	11048N	0
29218	779151	14267Y	14179A	0
17960	454055	19583F	98005N	0
29219	779151	19709B	08047A	0
27303	711614	19649G	11026G	0
29544	797719	08018U	19447X	0
26596	688843	11027H	12028B	0
23403	597484	19766L	19693L	0
23404	597484	20098N	19533U	0
29221	779151	20042V	19721W	0
29222	779151	14105F	14193X	0
29244	780815	19826F	21086N	0
27400	701179	19701S	20056C	0
29249	780815	08018U	14026U	0
29840	810211	20098N	21095P	0
29251	780815	20022R	20086J	0
29841	810211	14069U	21044C	0
26600	688843	11041F	11054L	0
29256	783394	14253S	07029T	0
27305	711614	01028R	14021P	0
29257	783394	08011M	14331P	0
29258	783394	07004J	14327T	0
23432	595688	19619A	14219Q	0
29536	797714	14215L	21044C	0
27307	711614	14259Y	20074E	0
29538	797714	05008E	21095P	0
29852	810909	01058X	07033P	0
29539	797714	19729F	19447X	0
29853	810909	95041E	14133K	0
29261	783394	19667J	11048N	0
29854	810909	19421M	08047A	0
25242	649725	20144B	19441R	0
29262	783394	21072G	20044X	0
29855	810909	14267Y	14255U	0
25516	655677	07004J	19749K	0
29264	783394	08009T	19335Q	0
27373	716686	14187A	11090Q	0
27311	702239	19577H	14219Q	0
23499	600815	20090E	19663E	0
29265	783394	20086J	19573D	0
27312	702239	17637T	18083K	0
29540	797714	04008A	20074E	0
29266	783394	20062A	08010L	0
29856	810909	08056B	17737W	0
29272	783098	19507S	14026U	0
27316	711614	20114U	01028R	0
27323	711614	14275Y	19749K	0
29541	797714	19749K	14089Y	0
29274	783402	14275Y	19749K	0
27324	708936	20138D	19693L	0
23511	600817	20090E	19663E	0
29542	797714	19673G	14053L	0
29543	797719	19673G	10015M	0
29545	797719	05008E	04047H	0
27327	708936	11109J	14109K	0
29546	797719	21038E	19111A	0
29547	797719	19729F	14215L	0
29858	810909	17367Q	19709B	0
25251	648781	11085T	14231L	0
27555	723233	19741B	11048N	0
29860	810909	14179A	19721W	0
25263	648782	11085T	14231L	0
27330	711614	14231L	19543W	0
29861	810206	01058X	07033P	0
29862	810206	95041E	14133K	0
25276	648783	19673G	20074E	0
29863	810206	19421M	08047A	0
29864	810206	14267Y	14255U	0
29865	810206	08056B	17737W	0
29867	810206	17367Q	19709B	0
27335	713873	14251Q	19563B	0
27375	716686	08028W	19467C	0
27336	713873	20078J	11090Q	0
25524	655677	11085T	14231L	0
29869	810206	14179A	19721W	0
25544	655859	04033B	19533U	0
25545	655859	14073Q	19611R	0
25546	655859	20142Y	20134Y	0
27339	711614	19581D	20074E	1
25549	655678	14151M	01028R	0
25554	655678	07004J	19749K	0
27478	720367	14253S	01057W	0
27480	720367	19711U	11048N	0
21486	544337	19685L	14219Q	0
25563	655678	11085T	14231L	0
27482	720367	04071H	20044X	0
27560	723381	14329V	11090Q	0
22161	562770	19577H	14219Q	0
28564	755424	21071F	14213J	0
27904	738387	19768N	11090Q	0
25362	650991	19745F	14219Q	0
23736	604468	20118Y	20136B	0
22593	571526	19577H	14219Q	0
24999	645031	20086J	11048N	0
28951	769539	08011M	11048N	0
18501	473521	01058X	14079W	0
27908	738387	19467C	20078J	0
17746	448850	14275Y	08044W	0
22598	571526	20038A	20136B	0
29405	790118	19619A	19826F	0
28566	755424	20248J	19691J	0
23739	604468	17229F	14219Q	0
28567	755424	19569H	21064G	0
22964	583469	01062T	12028B	0
18012	454190	19747H	08019V	0
18681	479055	19727D	08052W	0
29079	772448	14105F	17737W	0
26762	692321	14231L	14275Y	0
28953	768940	14275Y	19749K	0
29237	780814	14189C	19826F	0
22966	583469	11054L	11066Q	0
28956	769539	19479G	14327T	0
29239	780814	20286Q	21086N	0
25361	650991	20032T	18083K	0
27912	738387	14038Y	14329V	0
29078	772448	19721W	20042V	0
29406	790118	19685L	21042A	0
25947	659678	20146D	19637C	0
29215	779281	14089Y	19749K	0
23744	604468	08060W	19549D	0
29081	772448	14059S	08047A	0
29082	772448	21036C	01058X	0
29083	772448	19745F	14255U	0
29084	772448	11115U	17023S	0
23745	604468	20106U	19637C	0
29085	772448	14193X	19421M	0
29407	790118	15197G	21053D	0
29408	789503	08009T	14083S	0
29086	773244	20078J	20104S	0
26768	691635	19399H	19693L	0
27916	738387	08028W	19515S	0
29223	779301	20248J	21064G	0
27919	738015	19581D	20074E	0
29088	773244	19707Y	19705W	0
26769	691635	04033B	20058E	0
29410	789503	14173T	11048N	0
29090	772428	14275Y	14231L	0
29091	772428	19111A	21038E	0
25924	667912	14205J	19441R	0
25925	665806	20048C	19611R	0
29092	772428	04008A	05008E	0
23235	592517	19521Q	01043Q	0
29093	772428	21095P	20098N	0
24082	613120	95041E	19443T	0
29242	780814	20022R	20086J	0
24084	613120	14097Y	12028B	0
26772	691635	20138D	19643A	0
29243	780814	14031R	14237S	0
24220	619152	20074E	19515S	0
24221	619152	14213J	19693L	0
29097	772428	14189C	19749K	0
29098	773244	14329V	19507S	1
26773	691635	14030Q	19611R	0
25389	650987	99004R	11048N	0
29225	779301	04092N	14026U	0
29227	779152	17023S	14255U	0
26775	691635	19621T	20056C	0
25395	650987	20126Y	07029T	0
29228	779152	19745F	11115U	0
29229	779152	14267Y	14179A	0
29230	779152	19709B	08047A	0
25926	665806	19621T	19533U	0
25927	665806	20180F	19399H	0
25928	665806	20026V	20056C	0
29232	779152	20042V	19721W	0
29233	779152	14105F	14193X	0
29234	781491	21068L	18083K	0
26777	691635	14123H	20172F	0
25932	665806	14109K	11104D	0
29235	781491	19619A	14219Q	0
29236	781491	21061D	14031R	0
25938	667913	20054A	11090Q	0
25940	667913	14205J	19441R	0
25941	665806	19693L	11043H	0
26079	672570	07029T	11048N	0
21653	549183	19577H	14219Q	0
26780	691635	20098N	20026V	0
26087	672260	14259Y	20074E	0
26782	692321	19749K	14179A	0
26108	672571	20044X	11048N	0
22533	571305	19577H	14219Q	0
28491	753249	19707Y	19768N	0
25796	663455	20180F	20172F	0
26260	676319	01062T	19669L	0
29549	797973	17229F	19826F	0
29769	807004	19749K	14275Y	0
25798	663455	20084G	14109K	0
29770	807004	11085T	14231L	0
28464	751761	14038Y	11090Q	0
25800	663455	04033B	19693L	0
26263	676319	14255U	16685X	0
29550	797973	20118Y	14031R	0
29552	797973	21029D	20136B	0
28465	751761	14205J	01025N	0
28083	740835	11053K	14327T	0
25803	663455	14030Q	19611R	0
26352	681083	14329V	11090Q	0
28084	740835	19479G	19335Q	0
27778	732775	11085T	14231L	0
25805	663455	20052X	14073Q	0
28493	753249	14329V	14038Y	0
17877	451967	14275Y	08044W	0
27779	732915	14173T	11048N	0
27781	730866	14229S	08012N	0
28472	751813	14187A	11090Q	0
28494	753249	19507S	11090Q	0
29771	807004	04008A	14215L	0
29553	797973	18083K	19701S	0
18555	475689	19319Q	04040A	0
22556	571298	20064C	11066Q	0
17892	449605	19663E	98024R	0
23346	595511	14001X	01028R	0
17901	450711	14275Y	08044W	0
25808	663455	08012N	11104D	0
29772	807004	21038E	19111A	0
22558	571298	16685X	01024M	0
25809	663455	20098N	19533U	0
28496	753251	19667J	11048N	0
23447	598004	14191V	19443T	0
25810	663455	14123H	20172F	0
27783	730866	20152B	19643A	0
29554	797973	19681G	20046A	0
25812	663455	19766L	20056C	0
28497	753251	08009T	14327T	0
17913	449606	19663E	98024R	0
23452	598004	19319Q	16685X	0
26853	696008	08011M	11048N	0
27784	730866	11109J	11104D	0
27785	730866	19693L	20056C	0
23456	598004	14193X	19421M	0
29555	797802	01058X	14193X	0
27786	730866	04070G	20052X	0
29773	804284	20180F	19621T	0
28466	751761	19768N	14033T	0
27788	730866	04033B	11043H	0
29774	804284	18395Y	14109K	0
29557	797802	14105F	08047A	0
29775	804284	21059K	21089R	0
26856	695195	08011M	11048N	0
25822	663456	19766L	20056C	0
28468	751761	19563B	14251Q	0
29776	804284	04070G	19699S	0
29558	797803	01058X	14193X	0
28085	740835	19711U	20044X	0
29777	804284	14021P	20264J	0
29560	797803	14105F	08047A	0
23713	605794	14179A	19543W	0
29564	799207	20144B	21086N	0
29778	807004	19719D	21040X	0
28669	760928	20056C	21063F	0
27810	730866	19766L	20058E	0
29779	807004	11056N	21088Q	0
29633	801440	19573D	11048N	0
26859	694876	17737W	19675J	0
28657	760823	12016W	14225N	0
29780	807004	19729F	20098N	0
27813	732866	20034V	14038Y	0
25829	665379	20104S	11090Q	0
23863	608647	11085T	19543W	0
29566	797724	21038E	19111A	0
27814	732866	08028W	11090Q	0
28501	753594	08069G	14059S	0
29781	807246	20042V	14255U	0
24438	624342	14109K	11104D	0
28502	753594	14191V	08047A	0
23879	608647	19675J	19581D	1
27815	732866	20298U	01043Q	0
28086	740835	19667J	11048N	0
29568	797724	14069U	05008E	0
27836	730874	04033B	20152B	0
27837	730874	19621T	19693L	0
27838	730874	20056C	19533U	0
26865	694876	19749K	19543W	0
26866	694876	14275Y	14179A	0
28503	753594	14105F	14193X	0
28504	753594	14211G	14251Q	0
27840	730874	19527W	14229S	0
27841	730874	11104D	08012N	0
29569	797724	14259Y	20098N	1
28661	760823	08034U	07029T	0
28668	760928	14123H	21058J	0
27864	735293	11072N	95063L	0
27865	735293	11085T	14231L	0
28722	761183	07004J	14327T	0
28723	761183	14173T	20044X	0
29783	807246	95041E	08047A	0
28724	761183	07029T	19667J	0
29784	807246	11115U	14179A	0
28104	741108	01043Q	01025N	0
29785	807246	08056B	19421M	0
29571	797724	19729F	14053L	0
29572	797724	04008A	04047H	0
28108	741108	19383Y	11090Q	0
26886	696275	04035D	97011G	0
28110	741108	14037X	19782L	0
28726	761183	14253S	14331P	0
26888	696275	19709B	14193X	0
26889	696275	19443T	19421M	0
26890	696275	01062T	11066Q	0
26891	696275	01024M	19319Q	0
29786	807246	21036C	07033P	0
28112	742272	19709B	14193X	0
28729	761183	21090J	11048N	0
29787	807246	14105F	14193X	0
28837	765497	08009T	07004J	0
29788	807004	05008E	04047H	0
28839	765497	20126Y	11048N	0
28840	765175	20022R	05008E	0
29573	797724	19725B	19649G	0
29574	797724	10015M	19447X	0
29575	797724	20022R	20098N	0
29576	797724	19585H	21076L	0
29577	797724	11085T	14089Y	1
28846	765497	12016W	20070A	0
28847	763071	14021P	14109K	0
29578	797724	14069U	05008E	2
28849	765175	19719D	21040X	0
29789	807246	14133K	14059S	0
28851	765175	14259Y	20074E	0
29579	797724	14275Y	14231L	0
28853	765497	19335Q	14327T	0
29580	797724	20074E	14215L	0
28855	763071	04070G	19735D	0
24420	624152	19577H	14219Q	0
29581	797724	04047H	19447X	0
24422	624171	14097Y	12028B	0
24423	624171	20064C	11054L	0
28856	765846	15197G	14219Q	0
28857	765846	21061D	18083K	0
28858	765846	14237S	14031R	0
28859	767176	21086N	21050A	0
24429	624171	14191V	19421M	0
28861	767176	14205J	20066E	0
29583	797724	14053L	20108W	0
28863	767176	20144B	19563B	0
29584	797724	04045F	21043B	0
29585	797724	04008A	21044C	1
29586	797724	20022R	14147R	1
29594	799207	19707Y	19705W	0
29632	801440	20062A	20086J	0
29634	801440	14173T	20044X	0
29635	801440	08009T	19335Q	0
29637	801442	14173T	20044X	0
29638	801442	08009T	19335Q	0
29640	801442	20062A	20086J	0
29641	801442	19573D	11048N	0
29799	807245	11115U	14179A	0
29800	807245	08056B	19421M	0
29801	807245	21036C	07033P	0
29802	807245	14105F	14193X	0
29803	807245	95041E	08047A	0
29806	807008	15197G	19826F	0
27997	738364	20126Y	11048N	0
28735	763072	20048C	20052X	0
17795	448851	14259Y	11049P	0
28506	753497	08018U	14331P	0
28736	763072	08012N	21089R	0
24797	638807	19826F	14219Q	0
26500	686428	01057W	11048N	0
17800	449403	19739H	19737F	0
17801	449403	17637T	19794Q	0
26696	692318	20058E	20026V	0
25417	653089	04071H	11048N	0
26697	692318	19533U	11043H	0
26698	692318	20180F	20056C	0
28269	744519	20980G	19643A	0
29642	801571	19826F	17229F	0
29817	810209	21038E	14231L	0
26699	692318	19621T	19693L	0
28226	744229	14253S	19762G	0
28227	744229	19667J	11048N	0
25421	653089	08011M	07029T	0
29643	801571	19619A	21042A	0
27406	719037	11053K	14327T	0
29644	800773	21057H	19649G	0
27407	719037	19711U	11048N	0
26701	692318	04033B	19399H	0
25956	667698	04071H	20086J	0
27408	719037	99004R	01057W	0
29275	783099	15197G	19826F	0
28738	763072	04070G	19735D	0
26703	692318	14073Q	20052X	0
18439	472057	19719D	19253P	0
24277	621507	14026U	19663E	0
28229	744229	08034U	01057W	0
24250	618361	14021P	01028R	0
29756	807005	08018U	19447X	0
28739	763072	14073Q	14030Q	0
28270	744519	19533U	11043H	0
27411	719055	11053K	14327T	0
24255	618360	14021P	01028R	0
27412	719055	19711U	11048N	0
26705	692318	11109J	19527W	0
27413	719055	99004R	01057W	0
28232	744229	01048V	20044X	0
28233	746081	19383Y	14038Y	0
28740	763072	14021P	14109K	0
29276	783099	21080G	19701S	0
28741	763072	18395Y	21077M	0
25960	667698	01057W	11048N	0
24283	621410	14089Y	19543W	0
28742	761182	07004J	14327T	0
29277	783099	20076G	14031R	0
29757	807005	04008A	14053L	0
26058	669560	20086J	11048N	0
24673	631706	01062T	11054L	0
28772	761181	19667J	11048N	0
29646	800773	20036X	20266L	0
29647	800773	05008E	10015M	0
29278	783099	21029D	14237S	0
24678	631706	11066Q	12028B	0
27425	718556	14275Y	14179A	0
24804	638990	14187A	19515S	0
24805	638990	14038Y	19707Y	0
28768	761181	20086J	08011M	0
28769	761130	20138D	19954N	0
29648	800773	19729F	14053L	0
29758	807005	05008E	04047H	0
24810	638990	14357A	19705W	0
29649	800773	14275Y	14089Y	0
24812	638990	14205J	01043Q	0
27427	718769	19467C	14329V	0
28254	744519	20152B	19693L	0
28255	744519	19399H	20056C	0
26714	692456	19705W	11090Q	0
27429	718769	19707Y	19515S	0
29818	810209	14215L	20074E	0
29650	800773	10015M	08018U	0
24821	638991	08028W	19383Y	0
26718	692456	19707Y	19515S	0
26719	692456	20144B	19441R	0
29279	783099	20020P	20136B	0
28256	744519	20048C	20052X	0
28775	764182	14259Y	08018U	0
28776	764182	20098N	21044C	0
26934	698940	07004J	19543W	0
29328	787200	12016W	20070A	0
29329	787240	20124W	19621T	0
26938	698940	04008A	20074E	0
28259	744230	14189C	14327T	0
26941	698938	07004J	19543W	0
29759	807005	20074E	14215L	0
29651	800773	20098N	20108W	0
26945	698938	04008A	20074E	0
29816	810209	19729F	19447X	0
29333	786625	12016W	20070A	0
29653	800773	21038E	19111A	0
29334	786625	14173T	20086J	0
27431	718769	08015R	11090Q	0
29819	810209	05008E	14053L	0
28272	744519	04070G	19735D	0
29760	807005	11085T	14231L	0
28784	764182	20022R	05008E	0
29336	786625	21072G	20044X	0
29761	807005	21095P	10015M	0
29337	786625	07004J	14083S	0
29654	800773	14147R	14215L	0
26961	698942	19319Q	14267Y	0
29338	786625	20062A	11048N	0
28799	764871	19711U	20086J	0
28788	764374	14253S	11048N	0
28800	764871	14026U	21044C	0
29655	800773	20098N	21095P	1
29656	800773	14151M	19489J	0
26968	698942	95041E	14193X	0
26969	698938	11085T	14231L	0
28791	764374	07004J	14327T	0
28792	764374	14173T	20044X	0
26970	698938	14275Y	14179A	0
29762	807005	19673G	20022R	0
26972	695332	19577H	14219Q	0
29820	810209	04047H	08018U	0
29657	800773	04008A	04047H	0
26976	699097	19575F	11090Q	0
28796	764374	11053K	14083S	0
28802	764871	19507S	14031R	0
29658	800773	11085T	14231L	0
29659	800773	14259Y	20022R	0
29660	800773	14053L	19447X	0
29661	800773	19729F	20074E	1
27446	717725	11109J	14229S	0
29663	800773	14069U	21044C	0
29664	800773	20114U	18207D	0
26987	698744	20090E	19415P	0
29821	810209	19673G	14259Y	0
29822	810209	20108W	21044C	0
29823	810209	10015M	20098N	0
26991	699017	14237S	20078J	0
29824	810209	11085T	14089Y	0
29825	810736	20052X	19611R	0
29826	810736	20124W	21063F	0
27004	698941	14105F	04035D	1
27448	717725	20138D	19693L	0
27449	717725	20098N	11043H	0
29828	810736	20172F	21091K	0
29829	810736	19699S	14073Q	0
29830	810736	19954N	19621T	0
21698	549184	20118Y	20136B	0
21699	549184	19577H	14219Q	0
18799	481562	04047H	19930E	0
24632	629433	19745F	14219Q	0
29436	791688	21044C	10015M	0
28887	765174	20022R	05008E	0
27636	728405	20298U	01025N	0
25144	647518	14089Y	14231L	0
25145	647518	11085T	19749K	0
28480	752386	20022R	20074E	0
29882	813203	20098N	10015M	0
29438	791688	19729F	14215L	0
26839	694875	11085T	07004J	0
27637	728405	19705W	11090Q	0
29876	813203	19111A	14231L	0
18162	458748	19319Q	04040A	0
29439	791688	05008E	14053L	0
25146	648466	19705W	11090Q	0
26417	683336	19741B	11048N	0
27638	728405	19575F	14038Y	0
23407	597484	20138D	19399H	0
29561	797802	14255U	14179A	0
29562	799205	20144B	21086N	0
29587	797974	17229F	19826F	0
22685	575244	95041E	19443T	0
28481	752386	14259Y	14069U	0
29588	797974	18083K	19701S	0
29877	813203	19673G	19447X	0
22689	575244	11054L	01062T	0
29589	797974	20118Y	14031R	0
18546	475689	01062T	08053X	0
22690	575244	14255U	14267Y	0
22691	575244	19721W	01024M	0
28277	746018	19703U	10006L	0
29591	797974	21029D	20136B	0
29592	797974	19681G	20046A	0
29593	797803	14255U	14179A	0
25169	647960	20026V	20056C	0
28484	752386	19111A	14231L	0
18568	476142	19415P	98024R	0
22698	575067	19745F	14219Q	0
26422	683336	20126Y	07029T	0
18577	476132	19415P	98024R	0
26456	683057	14275Y	14231L	0
23487	599364	14231L	19543W	0
29596	800750	19729F	05008E	0
25170	647960	19699S	19611R	0
28583	755537	20248J	19691J	0
26840	694875	19749K	19543W	0
29597	800750	08018U	10015M	0
29598	800750	04008A	04047H	0
28894	765174	19719D	21040X	0
29878	813203	19729F	04047H	0
29879	813203	14259Y	21095P	0
29017	772509	20062A	20044X	0
29880	813203	04008A	05008E	0
26474	682962	11080N	14105F	0
29600	801464	14357A	08028W	0
28896	765174	14259Y	20074E	0
22712	574984	14123H	19399H	0
28557	755921	14083S	07004J	0
29881	813203	11085T	14089Y	0
28558	755921	14253S	14331P	0
28559	755921	20062A	20044X	0
29602	801464	20078J	20034V	0
28560	755921	19667J	11048N	0
28562	755921	20126Y	07029T	0
24122	616238	08018U	19581D	0
29883	813444	14105F	14193X	0
26477	682962	04035D	14193X	0
26478	682962	11115U	19421M	0
29884	813444	19709B	19421M	0
26480	682962	12028B	01062T	0
23420	597484	04059M	11104D	0
22793	579806	17637T	20136B	0
23421	597484	20264J	08012N	0
29604	801464	19707Y	19768N	0
25175	647960	19693L	19533U	0
29016	772509	19573D	08011M	0
25176	647960	19527W	08012N	0
29018	772509	08034U	11048N	0
25178	647960	20142Y	20134Y	0
29019	772509	20024T	19667J	0
29020	772509	11070L	14083S	0
29885	813444	08069G	08047A	0
26844	694875	14275Y	14179A	0
24144	616308	19766L	19533U	0
29022	772509	08010L	19399H	0
24146	616308	19735D	14073Q	0
29605	801464	21050A	21086N	0
29024	772509	19479G	14327T	0
29025	772509	14253S	07029T	0
26847	694875	19954N	20074E	0
29886	813444	95041E	14059S	0
29887	813444	14191V	99004R	0
29607	801464	19705W	19383Y	0
29608	801464	08015R	20038A	0
24153	617203	14211G	19421M	0
29609	801464	14205J	20066E	0
29610	801464	19507S	20104S	0
24155	617203	19319Q	01024M	0
29888	813444	11115U	14255U	0
26850	694875	17737W	19675J	0
29889	813444	17367Q	07033P	0
29613	801857	14255U	20042V	0
29614	801857	95041E	07033P	0
29615	801857	17737W	14059S	0
29958	815921	05012A	14031R	0
29617	801857	14105F	14193X	0
29618	801857	14179A	19745F	0
29959	815921	20120S	20136B	0
24652	631111	19415P	19663E	0
29619	801857	08069G	19421M	0
29620	801857	14267Y	17023S	0
25185	647546	14105F	14191V	0
27138	704327	11027H	14097Y	0
27139	704327	20064C	19669L	0
27141	704327	19709B	97011G	0
25188	647546	08056B	19443T	0
25189	647546	11115U	19421M	0
25191	647546	11027H	12028B	0
25192	647546	19721W	01024M	0
27143	704327	12028B	11054L	0
27145	704327	19319Q	01024M	0
24360	621343	01024M	16685X	0
28575	755919	14083S	07004J	0
28958	765753	14229S	21089R	0
28576	755919	11053K	14327T	0
28959	765753	19621T	20056C	0
17711	445753	12041X	14235Q	0
27691	730644	14275Y	14179A	0
24291	621411	07004J	19543W	0
25738	661802	11085T	14231L	0
27224	708473	14083S	14327T	0
17716	445754	12041X	14235Q	0
28960	765753	14021P	14109K	0
24293	621411	14275Y	11085T	0
28577	755865	14105F	14193X	0
28578	755865	21036C	19421M	0
28062	740833	20252E	08010L	0
28579	755920	14083S	07004J	0
29890	810883	14331P	19711U	0
25064	646153	11085T	19749K	0
26658	690789	14191V	14193X	0
26239	676189	19543W	07004J	0
29376	789277	20022R	14053L	0
29764	807353	19705W	20034V	0
25066	645739	19685L	14219Q	0
25739	661802	14147R	20074E	0
28590	755944	14205J	21050A	0
29466	794708	04008A	14053L	0
25576	656175	95041E	97011G	0
28962	769539	08009T	07004J	0
28592	755999	21029D	14031R	0
24358	621343	20064C	12028B	0
24359	621343	01062T	11041F	0
26242	674845	04033B	19693L	0
29891	810883	14173T	11048N	0
26462	681116	19766L	20056C	0
21751	555755	19577H	14219Q	0
28963	765753	19735D	04070G	0
27698	730320	08012N	11104D	0
28964	765753	21058J	19954N	0
28965	765753	19747H	14123H	0
28966	765753	20172F	20026V	0
28064	740853	19577H	14219Q	0
26243	674845	19533U	20056C	0
27700	730320	19693L	19533U	0
29765	807353	14038Y	19383Y	0
29766	807353	20078J	19507S	0
29892	810883	19647E	20070A	0
17781	447997	19367Y	98024R	0
27225	706166	19611R	20052X	0
17783	447997	19301E	14239U	0
26244	674845	19621T	20172F	0
28065	740853	20118Y	18083K	0
24736	634330	19543W	19749K	0
25074	645739	19820Y	19549D	0
29767	807353	20104S	08028W	0
26461	681116	04033B	11043H	0
29768	807353	20038A	14033T	0
27704	730320	20052X	20048C	0
28970	768940	20022R	05008E	0
26245	674845	19573D	11043H	0
18744	479069	14079W	95067Q	0
29254	782897	19573D	20044X	0
26246	676189	19749K	14275Y	0
27750	730675	14267Y	17023S	0
24749	634331	19543W	19749K	0
29378	789277	19729F	19447X	0
27867	736607	19441R	19369B	0
29893	810883	11070L	11053K	0
29894	810883	20062A	21090J	0
28066	740853	17367Q	14031R	0
29316	786191	04008A	14053L	0
29413	789280	19673G	08018U	0
29895	813342	19647E	20070A	0
26251	676086	20038A	18083K	0
25084	646154	11085T	19749K	0
18483	474276	14217N	98024R	0
21607	545501	19739H	14219Q	0
25085	646154	14089Y	14231L	0
29414	789280	19729F	19447X	0
26463	681116	19693L	19533U	0
28976	769348	19721W	11115U	0
18748	479069	19319Q	04040A	0
18749	479069	08061X	98029W	0
29896	813342	11070L	11053K	0
18842	483231	14187A	14265W	0
25108	646248	19707Y	11090Q	0
29897	813342	20062A	21090J	0
27869	736607	08028W	11090Q	0
29898	813342	14331P	19711U	0
26252	676086	19577H	14219Q	0
29899	813342	14173T	11048N	0
18849	483387	04047H	19930E	0
27872	735293	07004J	11085T	0
18851	483387	08045X	14065Q	0
18852	483387	19489J	98035U	0
25096	646187	01057W	11048N	0
29319	786191	10015M	20098N	0
27226	706166	11109J	11104D	0
29900	813206	19111A	14231L	0
29901	813206	11085T	14089Y	0
29320	786191	14089Y	21038E	0
27874	735293	19543W	19749K	0
27875	735293	14275Y	14231L	0
18861	483231	08015R	14115H	0
25859	664993	19721W	16685X	0
18863	483231	08019V	04088S	0
28979	769348	14059S	19421M	0
26254	676086	20102Q	20046A	0
29321	786191	08018U	21095P	0
25118	646155	11085T	19749K	0
27876	736608	19441R	19369B	0
29415	789280	11085T	14231L	0
29902	813206	19729F	04047H	0
28980	769348	08069G	14193X	0
29416	789280	14215L	14053L	0
28981	768940	20074E	21044C	0
28982	766052	21047F	18083K	0
29903	813206	19673G	21044C	0
25578	656175	14133K	14105F	0
29904	813206	04008A	21095P	0
25580	656175	19421M	19443T	0
25581	656175	11027H	12028B	0
25582	656175	11054L	01062T	0
27878	736608	08028W	11090Q	0
25584	656175	19721W	16685X	0
25585	656175	11066Q	11041F	0
29417	789280	20108W	10015M	0
29905	813206	14189C	21038E	0
26257	676189	14259Y	20074E	0
25541	655677	14151M	01028R	0
28071	740834	11053K	14327T	0
25862	664993	95041E	19443T	0
29906	813206	14275Y	19749K	0
25864	664993	19319Q	14267Y	0
26003	667816	17637T	18083K	0
28986	766052	20032T	14031R	0
29907	813206	14259Y	20074E	0
29908	813206	14069U	14053L	0
26007	669558	08011M	11048N	0
26008	669558	19545Y	20050V	0
29909	813206	05008E	20022R	0
28989	770926	14173T	20086J	0
28990	770926	19479G	14327T	0
27887	735294	11072N	95063L	0
28072	740834	19479G	19335Q	0
28073	740834	19667J	11048N	0
19796	500476	14331P	96004D	0
28991	770926	20126Y	11048N	0
28992	770926	14253S	20044X	0
26031	669558	14253S	07029T	0
28993	770926	11070L	14083S	0
26039	669559	19667J	11048N	0
28076	738440	14229S	19527W	0
26268	677483	08028W	11090Q	0
28994	770926	19667J	08010L	0
26270	676441	08034U	11048N	0
26271	676441	08009T	14327T	0
19869	503157	17229F	14219Q	0
28079	740834	19711U	20044X	0
26276	676441	08011M	07029T	0
26660	690789	20064C	01062T	0
28088	740162	11103C	10006L	0
26465	681117	04033B	11043H	0
27229	706385	04035D	97011G	0
27230	706385	11080N	19421M	0
26466	681117	19693L	19533U	0
26468	681117	19766L	20056C	0
26838	695215	20054A	11090Q	0
26919	698964	19577H	14219Q	0
27233	706385	20064C	11066Q	0
27236	706166	20264J	14109K	0
27237	706166	19527W	08012N	0
28099	742272	97011G	14059S	0
28100	742272	14191V	19421M	0
27248	705855	11085T	14231L	0
28158	744214	19667J	11048N	0
28159	744214	01048V	20044X	0
28160	744214	14253S	08011M	0
29704	804012	19447X	10015M	0
22733	575244	08047A	19421M	0
20362	511900	20120S	20136B	0
25279	649157	19319Q	14267Y	0
26158	672800	20042V	19721W	0
28689	761030	12016W	14225N	0
18095	457100	19703U	14079W	0
28620	757735	14275Y	14231L	0
28690	761030	14253S	20044X	0
28826	763305	08009T	07004J	0
26166	670817	20048C	19611R	0
26424	683337	19741B	11048N	0
22351	564488	19685L	14219Q	0
18822	483164	08069G	96004D	0
28816	764908	21081H	14026U	0
26167	670817	19699S	14073Q	0
29705	804012	04008A	04047H	0
27497	719208	11109J	14229S	0
25281	649157	14133K	19443T	0
27523	720091	11027H	11066Q	0
25484	655496	19768N	19705W	0
17830	449603	19415P	14119M	0
29706	804012	21088Q	11056N	0
29707	804012	19729F	05008E	0
25282	649157	11041F	11066Q	0
18033	456640	19415P	04097T	0
25059	646153	14089Y	14231L	0
18094	457100	19631V	14085U	0
26216	676440	08009T	14327T	0
28187	744225	20126Y	20044X	0
26161	672800	14097Y	11054L	0
26218	676440	08034U	11048N	0
27583	726447	11053K	14327T	0
18106	457565	19663E	98024R	0
28282	744231	14189C	14327T	0
28819	764908	14223L	19798U	0
27584	726447	19711U	20044X	0
28188	744225	19667J	11048N	0
27585	726447	04071H	11048N	0
18250	467532	14275Y	08044W	0
25098	645740	19766L	19399H	0
25283	649157	11115U	19421M	0
29708	805275	14073Q	14030Q	0
26219	676440	08010L	20086J	0
25101	645740	14123H	19643A	0
28925	767591	21081H	20090E	0
29936	815870	08018U	10015M	0
25104	645740	11109J	11104D	0
25105	645740	14229S	14109K	0
25284	649157	12028B	01062T	0
29709	805275	20180F	11043H	0
25286	649157	04035D	97011G	0
29710	805275	20138D	19621T	0
20370	511900	19577H	14219Q	0
18336	470532	19719D	19253P	0
29937	815870	14215L	04047H	0
29938	815870	20108W	21044C	0
29712	805275	20056C	19533U	0
18340	470827	14213J	14087W	0
18341	470827	10006L	14119M	0
28822	764908	14355X	14213J	0
29713	805275	21055F	20026V	0
29739	805689	19711U	20024T	0
18831	481561	14187A	04044E	0
25490	655496	08015R	11090Q	0
25491	655496	19707Y	19515S	0
29740	805689	20056C	19723Y	0
18870	483603	14187A	14265W	0
28825	763305	08010L	19667J	0
27527	720091	11054L	01062T	0
18873	483603	08015R	14115H	0
28190	744093	14275Y	14179A	0
18875	483603	08019V	04088S	0
28827	763305	20044X	07029T	0
25496	655496	01025N	01043Q	0
28828	763305	08011M	19399H	0
29741	804018	04045F	11072N	0
28829	763305	20126Y	11048N	0
28830	763305	19479G	14083S	0
28191	744093	11085T	14231L	0
28198	744705	20286Q	19369B	0
29742	804018	20098N	21044C	0
28199	744641	19826F	14219Q	0
29743	804018	10015M	20074E	0
28283	744231	19667J	11048N	0
28241	746017	19703U	10006L	0
29744	804018	21095P	20022R	0
28834	763305	12016W	20070A	0
27506	720076	07004J	19543W	0
29105	772507	19703U	19798U	0
29745	804018	19729F	14147R	0
28284	744231	08034U	01057W	0
25774	662021	20078J	11090Q	0
29939	815870	04008A	05008E	0
28836	763305	19335Q	14327T	0
23216	591805	20124W	19399H	0
28926	767591	21072G	20078J	0
26296	679535	20086J	07029T	0
29746	804018	21088Q	11056N	0
27509	720199	20034V	11090Q	0
28928	769537	07029T	20086J	0
28929	769537	14253S	20044X	0
29747	804018	19673G	14053L	0
25835	664324	08034U	11048N	0
20418	511901	19619A	14219Q	0
29748	804018	05008E	14215L	0
27510	720199	19707Y	14038Y	0
28285	744231	01048V	11048N	0
28931	769537	19399H	11048N	0
29940	815870	19673G	19447X	0
29941	817146	20062A	11048N	0
25842	664990	95041E	19443T	0
25843	664990	19319Q	14267Y	0
26300	679535	19741B	11048N	0
28287	744231	20252E	01057W	0
26163	672800	19319Q	14267Y	0
26164	672800	01062T	19669L	0
29942	817146	08034U	21090J	0
29943	817146	19667J	19711U	0
26377	679539	14331P	20086J	0
25852	664324	19545Y	20050V	0
25853	665380	01025N	19441R	0
29944	816769	19667J	19711U	0
25855	664325	08034U	11048N	0
27587	723710	14109K	11104D	0
26378	679539	19711U	11048N	0
27515	720076	14275Y	14179A	0
28935	768933	14275Y	19749K	0
29945	816769	20062A	11048N	0
26389	679201	20056C	19643A	0
26396	679540	19741B	11048N	0
27516	720076	11085T	14231L	0
26398	679540	19667J	20086J	0
28936	768933	20108W	20098N	0
29946	814470	19699S	20052X	0
28938	769537	11070L	14083S	0
27531	720091	14191V	19421M	0
27588	723710	04033B	11043H	0
27589	723710	19621T	19693L	0
29947	814470	08012N	14109K	0
29948	814470	14073Q	14030Q	0
29949	815872	11085T	14089Y	0
26811	692324	19709B	14193X	0
29950	815872	04008A	04047H	0
27591	723710	19533U	20056C	0
28942	768933	20108W	14069U	1
29951	815872	21095P	05008E	0
28943	767591	20252E	20108W	0
27592	723710	20048C	20052X	0
29952	815872	19729F	10015M	0
27593	726447	11110B	14225N	0
29953	815872	14215L	14053L	0
29954	815872	14275Y	19749K	0
29174	778819	11070L	14083S	0
29177	778819	14173T	19573D	0
29955	815872	20074E	19447X	0
26443	680943	14169X	20136B	0
26444	680943	20096L	18083K	0
28291	744231	14173T	19741B	0
27594	726447	12016W	19647E	0
26447	683640	14038Y	11090Q	0
29956	815872	14259Y	08018U	0
29957	815872	21038E	14231L	0
26812	692324	19443T	19421M	0
26813	692324	11041F	11054L	0
27595	726447	01048V	01057W	0
27261	706386	11080N	19421M	0
28343	748161	08034U	01057W	0
27264	706386	20064C	11066Q	0
28344	748161	04071H	20086J	0
28345	748161	99004R	11048N	0
27270	705855	14275Y	14179A	0
28346	748161	19667J	19741B	0
28948	769538	14173T	20044X	0
22445	567611	14109K	08017T	0
28949	769538	11070L	14083S	0
27600	726448	11053K	14327T	0
27601	726448	01048V	01057W	0
28950	769538	21072G	11048N	0
27603	725666	19543W	07004J	0
28348	749031	07033P	14059S	0
28349	749031	11115U	97011G	0
27605	726448	04071H	11048N	0
27606	726448	19711U	20044X	0
27607	726448	11110B	14225N	0
27608	726448	12016W	19647E	0
27609	725666	11085T	14231L	0
29104	772507	20148F	21039F	0
28350	749031	19443T	19421M	0
27613	723710	19699S	14073Q	0
27614	723710	20084G	08012N	0
27615	723710	04059M	14229S	0
28351	749031	14097Y	19669L	0
29108	772507	14213J	14026U	0
28353	749031	20042V	19319Q	0
28354	749031	08056B	14193X	0
28355	749031	17023S	16685X	0
28356	749031	11027H	11066Q	0
29109	772507	01034P	19691J	0
28360	749031	19721W	01024M	0
29110	772507	19679N	21081H	0
28362	749070	14329V	14038Y	0
28363	749070	19707Y	11090Q	0
29111	775610	21072G	14173T	0
28366	749070	20062A	19383Y	0
29112	775610	19667J	20086J	0
28370	748161	01048V	14173T	0
28371	748161	08011M	20044X	0
29115	775610	11070L	19335Q	0
29116	775610	08034U	07029T	0
29117	775610	14331P	19399H	0
29118	775610	08010L	19573D	0
29119	775610	20126Y	11048N	0
29176	778819	08011M	14253S	0
\.


--
-- Data for Name: activite_loi; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY activite_loi (actid, loicod) FROM stdin;
122925	47815       
122925	48866       
122972	49030       
122980	49030       
120021	52644       
119194	53322       
120023	53322       
123975	49030       
127001	53202       
127332	53023       
128851	49030       
128851	51923       
129201	52644       
129201	53383       
129934	53023       
129936	53023       
129938	53023       
129940	53023       
130222	30          
141092	53222       
141094	53222       
141096	53222       
141097	53222       
141100	53222       
141102	53222       
141104	53222       
141108	53222       
141110	53222       
144712	53222       
144714	53222       
144716	53222       
144718	53222       
145572	51743       
149592	53222       
151296	54122       
153621	53672       
155273	53222       
156992	53902       
169292	54983       
174354	55422       
174511	55422       
189354	57002       
189354	56982       
189360	57002       
189360	56982       
200372	57002       
201041	57143       
204352	56982       
206494	52645       
206755	57403       
206755	57402       
210180	56782       
214482	57903       
214488	49477       
217308	58419       
227786	56663       
232498	58369       
232504	58369       
232512	58369       
232517	58369       
232523	58369       
232528	58369       
232726	55762       
233189	58369       
233200	58464       
238606	58464       
238606	52645       
238606	55762       
241278	58464       
241276	58543       
244228	58445       
244232	58445       
244236	58445       
244585	57282       
244590	57282       
244594	57282       
245373	58507       
246170	58605       
246177	58605       
248850	54903       
250225	58605       
250227	58605       
250229	58605       
250231	58605       
254465	58642       
255856	40125       
256031	58605       
256478	58984       
259000	58882       
263235	58875       
263255	58875       
267187	59087       
270579	58875       
273941	58642       
275868	58943       
275895	59063       
275897	59063       
275899	58843       
275901	58843       
279829	59107       
280395	59091       
280395	59302       
280395	58945       
280937	58945       
289510	59145       
289513	59145       
282397	59282       
289587	59282       
289592	59282       
289597	59282       
291185	59186       
292930	59145       
300561	59383       
302441	59442       
302441	59110       
302441	59092       
302441	s86870118   
305413	59608       
305413	59092       
308737	59183       
324291	60102       
313509	60145       
313509	60102       
324291	59259       
324291	60062       
324291	58945       
328576	59462       
328625	47026       
330828	47026       
331337	59644       
331345	59644       
331592	47026       
335069	59462       
335069	47026       
335069	60165       
335069	60166       
337877	60062       
338469	60217       
338469	58577       
339505	60443       
339505	60444       
340177	59644       
340179	59644       
340184	60362       
340460	59963       
340463	59963       
340541	60217       
339988	60165       
339988	60166       
339989	60165       
339989	60166       
341079	59963       
344664	59644       
346571	60174       
346577	60174       
346589	60174       
348334	59584       
348336	59584       
348339	59584       
348345	59584       
348099	59644       
349527	59260       
349527	60443       
349527	60444       
349527	60463       
356618	59608       
356330	60763       
356330	60692       
356330	60228       
356330	60584       
356330	60582       
361647	60306       
361653	60306       
361656	60306       
361659	60306       
361662	60306       
361665	60306       
361670	60306       
361688	60306       
361692	60306       
361695	60306       
362181	60692       
362185	60692       
364269	60245       
356319	60497       
367353	60692       
369086	60687       
369657	60123       
369667	60164       
370720	60903       
371140	60906       
371214	60904       
371214	60905       
371214	60903       
372861	61022       
371214	60906       
372863	61022       
372859	61022       
372868	61022       
372869	61022       
372873	60406       
372898	60643       
373553	61022       
373556	61022       
373777	60466       
373922	60643       
376709	61045       
376712	61045       
376744	60643       
377351	60705       
385587	60177       
385587	60183       
385894	61062       
387797	60705       
391317	60406       
391436	59963       
391438	59963       
391300	61044       
391300	60963       
393862	61403       
393863	61403       
393864	61403       
393951	60964       
393952	60964       
396097	60824       
404254	61403       
404586	61124       
404797	61625       
404799	61625       
404801	61625       
404803	61625       
404849	61668       
404855	61668       
404859	61668       
404870	60462       
404903	61625       
404904	61625       
404905	61625       
404906	61625       
404907	61625       
404902	61625       
404908	61625       
404909	61625       
404910	61625       
404911	61625       
404912	61625       
404870	59982       
404870	61223       
404870	60146       
410910	60919       
410833	61627       
417113	61482       
417119	61482       
417123	60919       
415895	62064       
415924	62064       
415892	62064       
419132	62064       
419463	62064       
419464	62064       
419465	62064       
419466	62064       
419469	62064       
410951	61627       
420649	61283       
420064	62064       
419807	62064       
419809	62064       
421829	61865       
422688	61722       
422697	61722       
422894	62064       
422878	62064       
422873	62064       
422870	62064       
422896	62064       
422898	62064       
422900	62064       
425346	60309       
425346	62064       
427647	62064       
427656	62064       
428231	62064       
428373	61865       
428276	61743       
430543	62064       
425127	62064       
428277	61743       
431010	62064       
431013	62064       
431016	62064       
431018	62064       
431047	62042       
431563	61007       
431564	61007       
431693	62064       
432075	61007       
432076	61007       
432085	62064       
431062	62064       
430770	62064       
432684	61007       
431079	4507        
430768	62064       
433943	61865       
434009	62042       
431081	61743       
124072	53322       
124074	53322       
126285	53023       
126287	53023       
126289	53023       
127021	52305       
131433	50062       
137099	53023       
137353	53662       
137353	53744       
137353	53024       
140862	13327       
143897	53222       
143899	53222       
143904	53222       
147072	53222       
149252	53024       
149254	53024       
151039	53024       
151796	53702       
158312	53902       
159392	a97980621   
160472	53902       
160752	53024       
160890	52102       
162632	54602       
165162	54983       
165164	54983       
165166	54983       
165168	54983       
165792	54782       
165792	53902       
165792	54602       
189804	57002       
176296	53503       
189802	57002       
189802	56982       
189804	56982       
189807	57002       
189807	56982       
189820	57002       
189820	56982       
189988	56663       
190458	57002       
190458	56982       
190497	57082       
192474	56663       
190512	57002       
190512	56982       
190513	57084       
192172	57084       
193252	57084       
197532	57084       
197533	57084       
197533	56663       
205584	57403       
200613	57143       
200614	57143       
200632	57143       
200612	57143       
205584	57402       
205586	57403       
205586	57402       
205589	57403       
205589	57402       
205598	52645       
206480	57403       
206480	57402       
206512	52645       
206517	57084       
208708	57262       
213116	49477       
214524	57262       
214974	57903       
216302	58098       
225446	58502       
225452	58502       
225457	58502       
228446	58353       
228450	58353       
230813	58465       
233248	58464       
233252	58464       
233255	58464       
233259	58464       
233262	58464       
233264	58464       
233267	58464       
233271	58464       
233274	58464       
233276	58464       
233289	58464       
233291	58464       
233293	58464       
235087	55762       
235426	55762       
237429	58507       
238607	58464       
239413	58507       
241370	58505       
241371	58665       
247233	45662       
250553	45662       
250553	57202       
250553	57203       
256012	40125       
254772	58605       
255729	58425       
258883	58577       
257788	58882       
261177	58875       
269453	58605       
270308	58945       
270312	58945       
270563	58843       
274817	58843       
275294	32098       
275296	32098       
275805	59091       
275807	59091       
275809	59091       
275811	59091       
275813	59091       
275815	59091       
275817	59091       
275852	59063       
275866	59257       
275862	59257       
275863	59257       
275913	59257       
276033	58945       
278356	53522       
278357	53522       
278833	59257       
278838	59257       
278840	59257       
279155	59086       
279272	58325       
279274	59107       
279276	59107       
279322	58945       
279330	58945       
278758	59302       
285994	59145       
286679	58875       
287671	59186       
289196	59145       
289275	59107       
289277	59107       
292092	59092       
292092	59110       
292094	59092       
292094	59110       
292395	59092       
292395	59107       
293992	59383       
294871	59107       
303978	59259       
303978	59260       
304007	59259       
304007	59260       
305400	59259       
305406	59259       
305477	59259       
305477	59260       
305400	52182       
305406	59260       
305921	59259       
305921	59260       
307055	59259       
307055	59260       
307058	59259       
307058	59260       
307061	59259       
307061	59260       
307069	59226       
307071	59226       
307072	59226       
307073	59226       
324910	60062       
330686	59644       
330683	59644       
326608	47042       
328252	47042       
328625	47042       
328753	59644       
328751	59644       
331602	60146       
331603	59644       
338719	60125       
339913	60362       
339915	59183       
339918	59183       
340433	60217       
340481	60444       
340474	59963       
345269	60362       
345271	60443       
345273	60443       
345275	60443       
348036	60174       
348038	60174       
350956	60228       
353796	60362       
353878	60362       
353895	59608       
355377	59644       
356227	60306       
356330	59608       
356273	60124       
358901	58976       
361414	60763       
361416	60763       
364581	60306       
366778	58976       
367371	60245       
369160	60903       
370853	60906       
370855	60906       
370858	60906       
370860	60906       
370863	60906       
370866	60906       
370869	60906       
370871	60906       
370874	60906       
374856	60466       
374856	60903       
375443	60705       
375546	60705       
375556	60705       
375560	60705       
375566	60705       
375459	61022       
376932	60705       
378808	60687       
378933	60497       
378936	60497       
356324	60497       
380020	60583       
380025	60583       
380024	61084       
380023	61084       
380037	61084       
382489	59842       
384593	61062       
391691	61403       
391709	60964       
391710	60964       
396507	60177       
396936	59963       
396937	59963       
398365	61084       
400567	60763       
400889	61242       
401713	59462       
401713	61524       
401713	60763       
404805	61625       
404806	61625       
404807	61625       
404808	61625       
404809	61625       
404810	61625       
404811	61625       
404819	61625       
404820	61625       
404821	61625       
404822	61625       
404823	61625       
404824	61625       
404825	61625       
404826	61625       
404827	61625       
404828	61625       
405120	61042       
405136	61042       
405154	61668       
405159	61668       
405164	61668       
405167	61668       
408189	61482       
408189	60146       
410629	60462       
410675	60462       
410691	60462       
409128	61002       
410875	60883       
410879	60883       
410914	62125       
410914	61668       
413301	61668       
413611	60919       
413764	61002       
413765	61002       
413766	61002       
413767	61002       
413770	61002       
417448	62064       
417450	62064       
417451	62064       
420257	61865       
420260	61865       
420524	62064       
420483	62064       
420421	62064       
420405	62064       
420518	62064       
123526	53202       
123531	53202       
121672	53202       
121645	53202       
124946	41282       
124816	52305       
124944	41282       
124993	47815       
124993	48866       
124993	50062       
124993	49030       
127172	51923       
127174	51923       
129202	53023       
129205	53023       
130993	53182       
130995	53182       
131007	53182       
136726	53322       
136731	53322       
146253	52642       
146552	52305       
147016	52102       
147044	53762       
147046	53762       
147048	53762       
147050	53762       
156312	53023       
156455	54122       
157612	a97980621   
157612	53702       
157612	50265       
157612	50264       
162943	a97980621   
162943	54782       
162943	53024       
164974	54983       
164992	54983       
164997	54983       
165953	54622       
169832	53503       
171232	53982       
174282	48274       
174284	48274       
174535	53510       
175155	54782       
175543	54782       
175572	54802       
177613	55122       
177613	53982       
189352	54985       
189493	54985       
189492	57002       
189492	56982       
189493	57062       
192693	57084       
196909	57002       
198612	57143       
205093	52645       
205095	52645       
205520	57403       
205520	57402       
205523	57403       
205523	57402       
208435	49671       
208437	49671       
208439	49671       
225976	58502       
216835	49477       
225976	57903       
228463	58502       
228463	58353       
228463	57903       
228463	58505       
233046	58507       
233979	58507       
233999	58507       
234008	58507       
236006	58464       
236011	58464       
236015	58464       
236023	58464       
236028	58464       
236033	58464       
236039	58464       
236042	58464       
236047	58464       
236052	58464       
236055	58464       
236058	58464       
238968	58464       
241163	58464       
241173	58599       
245644	58543       
247080	58665       
247080	57282       
247080	57202       
247080	57203       
244790	58543       
261386	58984       
261573	58984       
261573	58663       
261573	58577       
261573	58844       
262903	58543       
267329	58922       
264238	58943       
264238	58642       
267404	58943       
267404	58605       
273487	58945       
276036	59086       
279094	59092       
279399	59091       
280165	59145       
280698	59107       
280853	59002       
280855	59002       
280857	59002       
286236	58834       
286278	59107       
287012	59107       
287012	58943       
292933	59447       
293118	59442       
293122	59442       
295826	58425       
293387	58543       
298407	59259       
298407	59260       
298410	59259       
298410	59260       
298412	59259       
298412	59260       
298633	59442       
295772	59383       
301347	59259       
301347	59260       
301349	59259       
301349	59260       
301352	59259       
301352	59260       
301354	59259       
301354	59260       
301357	59259       
301357	59260       
302264	59259       
302264	59260       
302268	59259       
302268	59260       
302272	59259       
302272	59260       
305559	59584       
305751	33552       
305756	s92930332   
306384	59259       
306384	59260       
306387	59259       
306387	59260       
307415	59608       
307419	59608       
308538	59186       
308553	59092       
308568	59110       
309107	s92930332   
309114	59145       
318672	60146       
311331	59608       
318672	47026       
311331	59110       
311331	59092       
318672	59462       
318672	60102       
324877	60262       
329159	60062       
340055	60062       
331592	59462       
334088	59462       
334831	59644       
337676	59259       
337680	59260       
340094	60362       
341062	60139       
341062	59183       
341062	60217       
345291	60443       
345293	60443       
349748	60362       
350391	60139       
350505	60139       
353912	60180       
353913	60180       
353914	60180       
353915	60180       
355789	60124       
355792	60124       
356087	60406       
354222	60406       
354217	60406       
356091	60406       
356092	60406       
356093	60406       
356109	60406       
356114	60406       
358661	60406       
358970	60406       
358974	60406       
359011	60763       
360546	60763       
360549	60763       
360552	60763       
360657	58976       
360711	60763       
361352	60306       
361357	60306       
361362	60306       
361367	60306       
361764	60306       
361767	60306       
361771	60306       
361776	60306       
364263	60763       
364292	60306       
364296	60306       
364407	60763       
372657	60466       
372660	59186       
373688	60824       
375349	60705       
375351	60705       
375353	60705       
375355	60705       
375358	60705       
375363	60705       
375377	60705       
375395	60705       
375423	60705       
375545	59842       
375545	60704       
375460	61022       
375545	61006       
375545	61044       
375545	61045       
375545	61062       
375545	60906       
382640	59842       
382643	59842       
382674	61044       
383668	59842       
385866	61084       
394040	60305       
394075	60306       
394170	61403       
400578	60362       
404673	61625       
404675	61625       
404677	61625       
405042	61668       
405048	61668       
405056	61668       
409085	61627       
409091	61627       
409096	61627       
408815	61668       
413960	59982       
414050	60883       
414049	60883       
413357	61865       
413357	61668       
413357	60904       
413357	60905       
413357	28540       
413357	59982       
413357	60462       
417388	60309       
420514	62064       
417388	62262       
420520	62064       
420407	62064       
420409	62064       
420509	62064       
420419	62064       
417255	62064       
417244	62064       
420535	62064       
420533	62064       
420531	62064       
420537	62064       
420539	62064       
420545	62064       
420543	62064       
420553	62064       
420551	62064       
420556	62064       
420559	62064       
420562	62064       
123956	53023       
123952	53023       
123954	53023       
123958	53023       
123960	53023       
123962	53023       
123964	53023       
123966	53023       
123968	53023       
124106	51203       
124490	53023       
124495	53023       
124520	51923       
130699	51614       
131964	53322       
133270	52305       
133760	53322       
133759	53322       
133824	53322       
133826	53322       
133828	53322       
135637	53023       
147782	53024       
147793	53024       
147799	53024       
147802	53024       
148332	53263       
148332	53510       
149652	53024       
150154	53024       
150252	53322       
153640	53702       
154912	53942       
155312	53263       
155312	52867       
156101	53702       
156101	50265       
159154	54802       
162893	54782       
162893	53742       
163199	53662       
165408	53510       
167672	53672       
167692	53902       
168757	55122       
170887	53024       
172435	53510       
173293	54845       
174792	48866       
190465	a77780157   
192759	57002       
190467	a77780157   
192759	56982       
192760	57002       
192760	57084       
192760	56982       
197952	57143       
208524	56782       
208528	56782       
210115	57403       
210115	57402       
210117	56782       
210164	57822       
210167	57822       
210169	57822       
213049	58098       
213059	58356       
213249	56782       
215509	49477       
220317	49477       
223685	58502       
226015	57903       
226035	58505       
226038	58505       
230002	58101       
230014	58098       
230594	58353       
230595	58505       
232753	58353       
237998	57102       
244306	58665       
244308	58665       
244310	58665       
247273	58605       
247286	58464       
255306	52645       
256869	58642       
258680	58844       
258684	58844       
258692	58844       
258895	42863       
258897	42863       
261498	58875       
264097	58605       
264156	58875       
268488	58663       
264235	58663       
269525	58943       
272519	58945       
273706	59162       
273708	59162       
273711	59162       
275756	59063       
279251	59257       
279252	59257       
279254	s93940473   
279256	59145       
279259	58325       
279259	s88890056   
279261	58325       
279282	59302       
279285	59302       
281719	59110       
279094	59110       
281771	59145       
281772	59257       
284059	59145       
284076	59107       
284078	59107       
288039	59282       
294202	59442       
295778	59164       
295786	58945       
295801	58984       
295834	59282       
295835	59282       
295836	59282       
298958	59282       
301625	58425       
302538	59107       
304982	59107       
304982	58945       
305267	59259       
305267	59260       
305269	59259       
305269	59260       
305271	59259       
305271	59260       
305273	59259       
305273	59260       
308227	59259       
308745	59259       
308745	59260       
310845	59608       
319335	59644       
319336	59644       
320709	59964       
320712	59964       
319829	60062       
321822	60062       
319828	60102       
331414	59462       
331417	59462       
331419	59462       
331422	59462       
335290	60216       
332907	60362       
336152	59644       
337802	60062       
337820	59259       
337847	59260       
339520	59644       
339549	59644       
339983	60443       
339983	60444       
339984	60443       
339984	60444       
339985	60443       
339985	60444       
339986	60443       
339986	60444       
339987	60443       
339987	60444       
340455	59963       
340457	59963       
342125	59963       
343151	60463       
347501	60139       
347502	60139       
347507	60139       
349285	60139       
349286	60139       
349287	60139       
352426	60582       
350815	60180       
350814	60180       
352430	60582       
352455	60582       
353815	59188       
353814	59188       
356119	60406       
356122	60406       
356125	60406       
356129	60406       
356854	59188       
361335	60723       
361318	60723       
361333	60723       
364448	60245       
364446	60245       
364444	60245       
367466	60362       
367467	60362       
369500	60903       
369643	60904       
371837	60687       
373596	60466       
373598	60466       
376816	60705       
376822	60705       
376826	60705       
376830	60705       
376835	60705       
376839	60705       
376843	60705       
376885	60705       
376987	61084       
382283	60704       
383134	60744       
383137	60744       
384107	61006       
384109	60704       
384667	60744       
393983	60705       
404214	59462       
405371	61668       
405374	61668       
405383	61668       
405388	61668       
409209	59982       
410912	61668       
415999	62123       
417133	61627       
417131	61627       
417132	61627       
417257	62064       
417264	62064       
417271	62064       
417277	62064       
417281	62064       
417285	62064       
417289	62064       
417293	62064       
417311	62064       
417314	62064       
417481	61668       
417485	61668       
417482	a91922600   
419341	61865       
419131	62064       
419820	62064       
418273	62064       
419889	62064       
420310	60919       
420332	60919       
420397	62064       
420565	62064       
420567	62064       
420569	62064       
420571	62064       
420573	62064       
420576	62064       
420579	62064       
420581	62064       
420691	61627       
420707	61482       
422810	62064       
420707	61865       
422809	62064       
422811	62064       
422812	62064       
422833	62064       
422834	62064       
422835	62064       
422836	62064       
422837	62064       
422838	62064       
422839	62064       
422867	62064       
423101	62064       
423100	62064       
423843	61283       
423844	61283       
424290	62064       
422959	61865       
424934	60919       
424897	61743       
425099	62064       
425100	62064       
425130	62064       
425161	62064       
425159	62064       
425163	62064       
425165	62064       
426123	62064       
427728	62464       
427728	62463       
428176	62064       
428178	62064       
428242	62064       
428243	62064       
428245	62064       
428254	62064       
428256	62064       
428258	62064       
428261	62064       
428262	62064       
428265	62064       
428267	62064       
428269	62064       
428271	62064       
428274	62064       
428720	61007       
124135	52722       
124133	51363       
124137	52722       
127220	53322       
127222	53322       
131029	49030       
131029	51923       
131029	51402       
131029	51844       
138231	53382       
131029	53023       
133132	51402       
145352	53024       
144193	53382       
146212	53024       
146532	53024       
147235	51743       
147235	53222       
149212	53024       
149215	53024       
150058	53024       
150060	53024       
150062	53024       
150064	53024       
151599	54442       
158545	47815       
158545	53024       
160392	a97980621   
162752	53902       
162772	52644       
162781	53383       
160905	53024       
163953	53902       
163955	53902       
164944	a97980621   
170812	48866       
170932	53982       
170812	53023       
170812	53672       
173633	52602       
174472	53024       
174510	53982       
174510	48866       
174510	55122       
174510	52602       
190534	57084       
190536	57084       
192270	57002       
192270	56982       
205012	52645       
205014	52645       
205332	52645       
205334	52645       
205336	52645       
205352	57403       
205352	57402       
205673	57403       
205673	57402       
208064	52645       
208065	57403       
208065	57402       
210033	57903       
210107	57262       
220434	57822       
221353	57903       
221849	58284       
226089	58502       
226092	58502       
226095	58502       
226991	56303       
227015	56602       
228101	58505       
232733	54542       
233020	58369       
233023	58369       
233026	58369       
233068	58369       
233282	58369       
234842	58464       
234848	58464       
234852	58464       
234860	58507       
234870	57102       
234880	57102       
234882	57102       
233330	58507       
235487	57942       
235489	58369       
235489	55762       
235489	52645       
235518	58507       
235520	57102       
235522	57102       
235527	57102       
235531	58464       
235534	58464       
235537	58464       
238762	57102       
238764	57102       
240214	58102       
244332	48262       
244333	58665       
244333	57282       
247194	57202       
247194	57203       
249718	58543       
244799	58543       
253493	58543       
253494	58543       
253526	58605       
256482	58577       
256486	58577       
256490	58577       
256496	58577       
256498	58577       
260214	58577       
260214	58844       
267420	58875       
270533	59224       
270532	59224       
275059	58945       
275065	58945       
275969	58945       
275974	58945       
275989	58945       
275995	58945       
275999	58945       
276002	58945       
276006	58945       
281803	59107       
278759	58834       
281722	53522       
281824	59107       
282435	59092       
282438	59092       
286284	59145       
286296	59145       
286539	59086       
293134	59442       
298591	58834       
294874	59110       
294874	59092       
298800	59382       
298800	58642       
301908	59110       
305295	59187       
305297	59187       
305299	59187       
305300	59187       
305301	59187       
305305	59187       
309056	59260       
309053	59259       
309056	59259       
309056	56782       
313988	59682       
313990	59608       
319276	60062       
313990	56782       
320359	60062       
321820	60062       
326803	60149       
326818	60262       
331889	47026       
331915	47026       
331918	47026       
333850	59644       
333857	59644       
342919	59183       
342919	60217       
348032	60362       
349527	59259       
348021	60499       
348022	60499       
347854	60499       
348027	60499       
350206	60499       
350214	60499       
350340	60499       
350824	60499       
350883	60582       
350886	60582       
350972	60584       
350974	60584       
350976	60584       
350978	60584       
352979	60463       
353053	60124       
356134	59608       
356136	59608       
355955	59584       
358123	60124       
358123	59608       
361617	60306       
361619	60306       
361623	60306       
361633	60306       
361638	60306       
361753	60692       
366532	60306       
366559	60306       
365979	60904       
365979	60903       
365979	60905       
365979	60763       
365979	60692       
375512	60444       
375527	60443       
376985	60406       
378921	60824       
379888	61044       
379890	61044       
379892	61044       
379895	61044       
379970	61006       
379972	61006       
380225	60705       
380663	60704       
380667	61006       
381242	60497       
382698	61045       
382747	61084       
397739	60963       
397757	60744       
404929	61625       
404927	61625       
404930	61625       
404931	61625       
404932	61625       
404933	61625       
404934	61625       
404935	61625       
404936	61625       
404937	61625       
406938	61022       
405201	60964       
404871	61668       
408075	60146       
408078	60689       
408080	60689       
408082	60689       
408084	60689       
409014	60883       
409018	60883       
409125	61668       
410887	62125       
410887	61668       
410829	62064       
413998	60919       
414000	60919       
417388	59982       
417479	61627       
419095	62064       
419097	62064       
419098	62064       
419099	62064       
419343	62064       
417389	60462       
417389	60689       
417389	60904       
417389	60905       
419804	62064       
420399	61865       
420402	61865       
420306	62123       
420305	62123       
420717	62064       
422751	62064       
420715	62064       
420763	62064       
421882	62064       
420713	62064       
421859	62064       
421861	62064       
422673	62064       
422682	62064       
421915	62064       
422678	62064       
422690	62064       
422685	62064       
422693	62064       
422723	62064       
422726	62064       
422736	62064       
422763	62064       
422772	62064       
422779	62064       
422783	62064       
422494	62064       
422488	62064       
428199	62064       
420710	61743       
428198	62423       
428202	62064       
428373	62064       
428871	62042       
425325	62064       
429138	62189       
422954	62064       
423938	62064       
425150	62064       
423947	62064       
429453	62423       
425837	62064       
426471	62064       
425835	62064       
425129	62064       
436978	61743       
439532	61668       
439548	62064       
439974	62064       
441618	61743       
441619	61743       
444140	62662       
445116	57084       
445118	57084       
448613	62662       
448851	62743       
454256	63143       
460854	60139       
460856	60139       
462692	63645       
464307	63645       
464308	63645       
464309	63645       
465833	63923       
477747	64547       
477750	64547       
477748	62418       
477748	60462       
477800	64544       
493184	65465       
479400	64685       
493174	65465       
495330	65702       
495328	65702       
495303	65702       
494099	65702       
495338	65702       
495340	65702       
495342	65702       
495368	65702       
495370	65702       
495378	65702       
497993	65702       
497994	65702       
500241	64983       
502289	65702       
506859	65702       
505798	65702       
508081	64202       
508083	64202       
508085	64202       
508087	64202       
508089	64202       
508092	64202       
508094	64202       
517286	65386       
518606	65702       
519093	64942       
521473	66064       
541670	67273       
526727	61743       
530782	66463       
542364	66003       
543007	67273       
544625	67273       
544625	67267       
544995	65847       
545015	65847       
545020	65847       
545016	65847       
545033	65847       
545048	65847       
556364	67290       
559008	67483       
561186	67183       
561190	67183       
561981	67042       
561977	66002       
561978	67363       
561978	67395       
561979	67546       
561979	67183       
563221	66582       
564357	66582       
564410	67183       
564415	67183       
564417	67183       
568181	67606       
568190	67606       
568195	67606       
568200	67606       
568207	67606       
568209	67606       
568213	67606       
568215	67606       
568220	67606       
568225	67606       
568285	67606       
570847	67606       
570848	67487       
570848	67485       
572988	67542       
577989	67486       
573011	64920       
573011	66985       
573011	67606       
573348	67485       
573352	67487       
573357	67485       
575164	67606       
578124	64922       
583456	66691       
583467	66663       
583833	64920       
583836	64920       
585637	67523       
588585	68305       
585650	67591       
585650	67589       
588587	68305       
588589	68305       
588591	68305       
593570	67966       
591278	67966       
593576	67966       
593836	66044       
595453	68053       
598656	68297       
598661	68297       
598663	68297       
598667	68297       
598671	68297       
598673	68297       
598675	68297       
598678	68297       
598680	68297       
598681	68297       
598684	68297       
598686	68297       
598688	68297       
598690	68297       
598692	68297       
598694	68297       
598696	68297       
601092	68297       
602258	68297       
602258	68523       
602132	68297       
602133	68297       
602131	68297       
602250	68297       
602256	68297       
606771	68364       
606773	68364       
621213	68602       
628890	68748       
628893	68748       
628898	68748       
631112	65386       
631111	68608       
631111	65386       
631111	62982       
631111	68836       
631111	68403       
634432	68608       
634433	68836       
634433	68403       
650960	69635       
650957	69635       
650959	69635       
652216	69635       
655677	69563       
655677	69922       
655679	69948       
656129	69948       
656134	69948       
656140	69948       
656147	69948       
656153	69948       
655902	69948       
655908	69948       
656120	69948       
656125	69948       
656179	68382       
656686	69945       
656812	69563       
656815	69563       
659084	69863       
663377	70065       
667625	69442       
671209	70065       
671212	70065       
672590	70065       
674681	70065       
676070	70065       
680310	70285       
680315	70285       
680316	70285       
680353	70285       
680362	70285       
680363	70285       
683336	70065       
683337	70522       
683337	69243       
686364	70522       
686365	70565       
690884	70444       
690885	70444       
690886	70233       
696008	70783       
698949	70243       
704253	70066       
709951	70725       
709965	70725       
709977	70725       
704190	70442       
709996	70725       
718669	69864       
720076	71304       
720076	70463       
720076	69262       
720076	69864       
730641	71304       
730644	71927       
731903	72103       
731945	72103       
738015	72123       
744178	72444       
738017	72123       
738017	72124       
738017	70242       
740809	70683       
740810	70683       
744179	72444       
744180	72444       
744181	72444       
744182	72444       
746064	70741       
756015	72083       
756014	72083       
756018	72083       
756021	72083       
756017	72083       
756019	72083       
760765	73206       
760765	73024       
760765	72502       
763155	73065       
765314	73065       
765315	73065       
765316	73065       
772428	73065       
772421	73065       
772429	73065       
773456	73104       
775581	68706       
775586	68706       
775593	68706       
775597	68706       
775600	68706       
775604	68706       
775939	70571       
775940	70571       
775941	70571       
775942	70571       
775943	70571       
786391	72843       
775973	72283       
786380	70745       
787343	70484       
787590	73548       
787592	73548       
787596	73548       
787598	73548       
787600	73548       
787602	73548       
787606	73548       
787609	73548       
788069	71009       
788098	70484       
789225	70484       
789226	70484       
789227	70484       
789277	73503       
789278	71642       
789278	70741       
789424	71009       
789504	71009       
789506	71009       
791365	72843       
791448	73223       
791454	73223       
791459	73223       
791464	73223       
791469	73223       
791561	66983       
791617	70745       
791618	70745       
791621	73603       
791625	73603       
791638	73603       
791692	73223       
791695	73223       
791698	73223       
791701	73223       
791703	73223       
791688	70745       
792504	73223       
793607	73223       
793846	73223       
794058	73083       
794632	73223       
794679	73485       
794708	70760       
794708	70741       
434667	62064       
434669	62064       
434671	62064       
434672	62064       
435632	61743       
441690	62203       
441695	62203       
441694	62203       
441788	61703       
441788	60625       
441788	62602       
449046	62203       
450979	62464       
450986	62463       
455387	59693       
456716	60919       
458981	63282       
462480	63282       
462483	63282       
462487	63282       
462489	63282       
464287	63645       
470626	61982       
470628	61982       
470631	61982       
472058	60139       
472056	64242       
472056	63282       
472053	64242       
474428	62703       
472058	62224       
474184	62224       
474431	62703       
474434	62703       
474195	62224       
476088	62703       
476463	64546       
476469	64546       
485543	63582       
490448	65290       
490448	65291       
490448	63202       
490448	65622       
490448	64762       
490448	65064       
491485	64762       
491485	65622       
491488	63202       
491488	65290       
491488	65064       
491488	65291       
491488	64762       
491488	65286       
491473	63696       
491905	63202       
491908	63202       
495035	65702       
495354	65702       
495358	65702       
495362	65702       
495360	65702       
495269	65985       
501581	65702       
502810	65702       
502815	65702       
502818	65702       
502824	65702       
502829	65702       
502832	65702       
502836	65702       
502840	65702       
502842	65702       
502845	65702       
502848	65702       
502851	65702       
503127	65702       
503129	65702       
503131	65702       
505633	65702       
506221	64202       
506223	64202       
506225	64202       
506227	64202       
509267	65222       
512691	65642       
512696	65642       
512699	65642       
512701	65642       
519213	62363       
519218	62363       
519225	66784       
519225	66064       
519225	64942       
519225	66423       
524585	62885       
524587	62885       
526403	65962       
526370	66003       
528705	62885       
529043	66786       
529044	66786       
529045	66786       
529239	65962       
529240	65962       
531391	62885       
531393	62885       
531408	66703       
531411	66703       
533774	66671       
539682	65962       
539686	66624       
541389	66624       
542973	66423       
543154	67226       
543157	67226       
543160	67226       
543163	67226       
545159	66624       
545160	66624       
545160	67226       
545161	66624       
545312	66423       
545735	67267       
545624	67267       
545622	67267       
551278	66802       
557326	67183       
557462	67183       
557553	67290       
558969	67290       
558970	67290       
558978	62922       
558980	67395       
559214	67183       
559205	67183       
559385	67183       
559389	67183       
559394	67183       
559455	67183       
559468	67183       
559470	67183       
559203	67544       
559204	67544       
559209	60177       
559209	62922       
559209	67395       
559209	67042       
564096	66582       
564102	66582       
564262	67293       
564263	67293       
564264	67293       
566017	67542       
571280	67606       
571285	67606       
571287	67606       
571291	67606       
572788	67606       
572789	67606       
575104	66985       
572787	67782       
572798	67606       
575107	67606       
575107	66624       
575109	67606       
587615	67523       
576290	67485       
576293	67487       
585411	67236       
589450	68305       
590298	68305       
590299	68305       
590377	68022       
590381	68022       
590873	66691       
590874	66691       
590875	66691       
590876	66691       
592902	67966       
592904	67966       
592917	67966       
590544	67864       
594499	68053       
594525	67966       
595502	68305       
595504	68398       
595507	68398       
595507	64920       
595507	66044       
595507	68053       
595511	68398       
597760	65504       
597966	65504       
597972	65504       
597980	65504       
597987	65504       
597999	65504       
598001	65504       
597710	68467       
597710	68470       
599364	68398       
600195	68297       
600200	68297       
598123	68297       
598119	68297       
597313	68297       
597306	68297       
598207	68297       
595715	68297       
595609	68297       
602974	68297       
606262	68297       
606404	68297       
608570	68002       
608570	68047       
616181	68394       
612406	67862       
615180	68505       
616182	68394       
616183	68394       
616176	68394       
616177	68394       
616178	68394       
616179	68394       
616180	68394       
616184	68394       
616238	68505       
616238	67950       
621755	68464       
618824	68464       
620888	68471       
621786	68602       
621788	68602       
621787	68602       
621843	68471       
621510	67606       
621510	68305       
621510	68047       
621510	68002       
621511	64920       
622073	68837       
622077	68837       
624209	68650       
624212	68650       
627295	68841       
648783	69625       
629205	67606       
648779	69625       
656116	69563       
656166	68382       
656717	68922       
656717	68382       
656285	69945       
656717	69945       
656717	69944       
664678	70065       
656808	69948       
656927	69945       
656940	69922       
656838	69945       
656933	69922       
659365	69948       
661238	68922       
666570	70065       
666578	70065       
666524	70066       
665525	70066       
665889	70066       
664754	70066       
663857	70066       
657403	70066       
657404	70066       
661314	70066       
668844	70065       
668848	70065       
668917	70066       
668918	70066       
668919	70066       
668920	70066       
669545	70065       
670341	70065       
670343	70065       
670344	70065       
670342	70065       
670031	70065       
670032	70065       
672280	69442       
688826	70803       
672322	70065       
678938	69882       
681008	70522       
688831	70803       
688837	61403       
688841	61403       
688842	61403       
690865	70444       
690872	70444       
691860	70444       
692401	70444       
692402	70444       
692403	70444       
692409	70444       
694953	70243       
694954	70243       
702460	70089       
702461	70089       
702462	70089       
702463	69812       
702464	69812       
431063	62064       
434187	31428       
434187	60305       
434347	61007       
437085	61743       
439807	62464       
439807	62463       
439933	62542       
439937	62542       
439944	62542       
439956	62542       
439962	62542       
439968	62542       
439972	62542       
441620	61743       
443871	62764       
443872	62764       
443873	62764       
443874	62764       
443877	62764       
443875	62764       
448632	61743       
453664	63243       
454169	63143       
454174	63143       
454176	63143       
454260	63143       
456714	63343       
456729	62743       
456732	62743       
459305	63243       
462243	44665       
462246	44665       
462439	62703       
462441	62703       
471082	61982       
474327	64547       
474327	62418       
474327	60139       
474327	62703       
476356	64546       
476356	64547       
476357	64546       
479286	64546       
479620	54903       
480979	64685       
481507	64545       
481507	64544       
488152	63582       
490769	65290       
490769	65291       
493365	63202       
493367	65702       
493370	65290       
493370	65291       
495407	65702       
495409	65702       
500591	65702       
500593	65702       
500679	65702       
500708	65702       
500719	65702       
500729	65702       
500733	65702       
500736	65702       
500739	65702       
500745	65702       
502679	65642       
502750	65702       
502756	65702       
502864	65702       
502866	65702       
502868	65702       
502870	65702       
502872	65702       
505913	65702       
506001	65702       
505796	65702       
512856	65702       
512264	65222       
513758	65962       
513768	65962       
513773	65962       
513778	65962       
513781	65962       
516820	65962       
516826	65962       
516834	65962       
516837	65962       
516841	65962       
516847	65962       
516851	65962       
518688	65386       
518689	65386       
518690	65386       
519131	62363       
520136	61743       
524068	66902       
521431	62363       
524068	65882       
526489	66902       
524069	62363       
524074	66902       
524068	66784       
526490	65962       
531146	62974       
531146	65183       
531388	66463       
532012	66322       
532011	66322       
542592	67203       
543268	67224       
543274	67224       
545423	67224       
548748	66727       
548749	66727       
548779	66727       
555046	67004       
555047	67004       
555070	67004       
555048	67004       
557305	67483       
555367	67004       
557305	67488       
558477	67183       
557712	67183       
558480	67183       
558486	67183       
558490	67183       
559764	67183       
560216	67183       
571166	67486       
571168	67486       
570618	67782       
570332	66802       
573151	67606       
573153	67606       
573155	67606       
573157	67606       
573159	67606       
573161	67606       
573163	67606       
573165	67606       
573167	67606       
573169	67606       
573171	67606       
573173	67606       
573179	67606       
573175	67606       
573177	67606       
573181	67606       
575233	67486       
577328	67606       
582878	66663       
582881	66663       
582883	66663       
582887	66663       
583461	67802       
583463	64922       
588229	68305       
588234	68053       
588234	66044       
588234	67945       
588234	68082       
588234	67365       
588234	68062       
588234	67864       
599120	68297       
599122	68297       
603524	68297       
603526	68297       
613773	68297       
613802	67950       
613823	68505       
613840	68505       
616277	65873       
616277	68608       
618692	68471       
618694	68471       
618696	68471       
622525	68650       
622579	68650       
622584	68650       
622590	68650       
622596	68650       
621501	68650       
622488	68650       
627800	68748       
627804	68748       
629205	68748       
634461	68836       
646068	68831       
646080	68831       
646086	68831       
646090	68831       
646095	68831       
646153	68831       
655858	69948       
655863	69948       
662440	70066       
662453	70066       
662441	70066       
662442	70066       
664196	70065       
665205	70065       
668138	70065       
665207	70065       
667226	70065       
667453	70065       
668144	70065       
668146	70065       
669528	70065       
669533	70065       
669534	70065       
669530	70065       
669567	70065       
669569	70178       
669569	69882       
669569	69442       
669569	69505       
669569	70065       
669570	70065       
682594	70522       
681105	70522       
682588	70522       
682611	70522       
682747	69748       
682768	70522       
686134	44665       
688765	61403       
690693	70242       
690696	70242       
690697	70242       
690700	61403       
695033	70243       
702465	69812       
703637	70203       
703671	70203       
703962	70203       
703963	70203       
704103	70089       
704629	71145       
704776	70203       
704637	71145       
704642	71145       
698983	71145       
698986	71145       
698990	71145       
704646	71145       
704650	71145       
703820	71145       
703823	71145       
703827	71145       
704207	71145       
704286	71145       
704289	71145       
704292	71145       
704295	71145       
704622	71145       
704780	70203       
712245	69262       
713829	70463       
716549	69262       
717551	69864       
717554	69864       
717570	69864       
718557	69664       
718558	69664       
718560	69664       
718561	69664       
718562	69664       
718563	69664       
723223	70176       
725016	71042       
725479	71028       
725481	71028       
725593	71683       
725595	71683       
730567	72123       
730568	72123       
730569	72123       
730570	72123       
730571	72123       
730572	72123       
731272	72123       
733902	71844       
735293	72123       
735293	72124       
735294	71844       
738757	72203       
740752	71844       
741160	72203       
742164	70741       
740804	72203       
745585	72322       
746017	72322       
746017	72444       
746017	71003       
745765	72444       
746022	72444       
746041	72444       
746043	72444       
746058	72444       
748133	70741       
748135	70741       
753669	72323       
754619	73072       
757708	72502       
757734	69842       
437846	62064       
436980	61743       
439635	62064       
441273	60625       
439606	61743       
443160	62662       
443162	62662       
445814	60907       
445994	63004       
445994	62464       
445994	62463       
448296	57084       
445995	61703       
448486	62203       
458679	62268       
454258	63202       
454258	59693       
456716	62703       
458682	62268       
458684	62268       
458687	62268       
467706	64162       
470544	63406       
471030	64242       
476351	64546       
476351	62703       
477463	62845       
477471	62845       
477477	62845       
484898	64545       
484898	64544       
485084	63582       
485088	63582       
485095	63582       
485099	63582       
485102	63582       
485540	65022       
489718	32634       
489720	32634       
489752	64761       
493367	65064       
495427	65702       
500478	65702       
500477	65702       
500476	65702       
500479	65702       
502446	65702       
502448	65702       
502449	65702       
502450	65702       
502451	65702       
502453	65702       
507037	65222       
506033	65702       
506033	65803       
513500	65702       
513912	65702       
516382	66423       
519147	66423       
519149	66423       
519139	66544       
519156	65386       
519157	65386       
519164	66544       
519163	66544       
520662	62363       
524180	62885       
526325	66003       
534285	66671       
533020	66703       
534283	66671       
543060	66423       
543058	66423       
545560	67273       
545558	67273       
545738	66624       
545330	66003       
547893	65847       
553607	66985       
562260	67293       
562573	66802       
562579	66802       
563230	66802       
564480	67606       
564484	67606       
564486	67606       
563959	67546       
566124	66802       
563967	66582       
563961	67606       
564649	66582       
566156	66802       
566545	67606       
566548	67606       
566550	67606       
566553	67606       
566577	67542       
566579	67542       
566583	67542       
566588	67542       
566592	67542       
566597	67542       
566600	67542       
567596	66802       
568171	67606       
572018	67487       
568176	67606       
568172	67542       
572014	67487       
572024	67487       
572028	67485       
579607	67487       
579610	67487       
579613	67487       
579619	67487       
579623	67487       
579132	67606       
581921	68024       
581922	68024       
582557	68024       
582572	67584       
582576	67584       
582580	67584       
582740	67485       
582740	67487       
582743	67485       
582743	67487       
582745	67485       
582745	67487       
583152	67590       
583152	67567       
583152	67236       
583184	67590       
583185	67590       
585577	67487       
585577	67485       
585579	64922       
585579	67487       
585579	67485       
585579	68082       
588379	68062       
588381	68062       
588390	64920       
588432	67366       
585686	67366       
590392	62885       
590392	67523       
590394	68305       
590394	67366       
590394	68162       
600914	68297       
600917	68297       
602973	68297       
602981	68297       
602997	68297       
603017	68297       
603020	68297       
606606	68297       
610241	68002       
610241	68047       
612793	68047       
612793	68002       
618357	68762       
618358	68762       
618359	68762       
618361	67950       
618377	68485       
618382	68485       
618388	68485       
618394	68485       
618398	68485       
618401	68485       
618825	68602       
620193	65386       
620193	68836       
620193	68403       
620193	68485       
621466	68650       
621457	68650       
621462	68650       
621471	68650       
621478	68650       
621486	68650       
621491	68650       
621496	68650       
621507	68762       
621508	68762       
627723	68748       
631562	68748       
631564	60689       
631564	68841       
631564	68842       
667553	70065       
665809	70065       
665262	70065       
667546	70065       
667565	70065       
670572	70065       
671238	70065       
689084	61403       
689085	61403       
689178	61403       
690455	70233       
690828	61403       
690879	70444       
692303	69243       
692306	69243       
695006	70243       
695059	70244       
695062	70244       
695063	70244       
695064	70244       
695065	70244       
695066	70244       
695067	70244       
695068	70244       
695074	70244       
695069	70244       
695073	70244       
698490	70243       
698937	71026       
698937	69812       
698937	70089       
698937	70569       
698940	70682       
703668	70203       
703688	70203       
704076	70760       
704217	70760       
704222	70760       
704225	71026       
704350	70203       
704582	70760       
704585	70760       
708803	70725       
708816	70725       
708829	70725       
705855	70463       
705855	69262       
705855	69864       
705855	70760       
705855	70203       
725666	71028       
717232	70463       
717235	70463       
725666	71683       
731228	71844       
734176	71684       
734175	71684       
735270	71844       
738795	72265       
738797	72265       
738800	72265       
738802	72265       
738804	72265       
738807	72265       
738810	72265       
738812	72265       
738814	72265       
738817	72265       
738819	72265       
738827	72265       
738830	72265       
740726	72203       
752202	72346       
741131	72444       
741132	72444       
752203	72346       
752386	72346       
752387	72203       
753642	73072       
755868	73072       
755870	73072       
757734	72502       
757734	72125       
757734	73024       
757845	72083       
761726	73065       
761728	73065       
761727	73065       
761732	73065       
762526	73065       
762535	73065       
763156	73065       
763162	73065       
763177	72125       
764182	71145       
765722	73066       
765745	73065       
768933	73065       
768934	73065       
768940	73065       
768940	72125       
768940	69842       
773892	73104       
773911	73326       
774129	73326       
774133	73326       
775654	70571       
775656	70571       
775658	70571       
775950	73326       
778887	73326       
778890	73326       
778892	73326       
779280	72283       
779281	73384       
434041	60919       
434043	60919       
437428	62463       
437428	60919       
436982	61743       
437428	62464       
438997	62203       
441624	60625       
442696	61743       
443805	60625       
450709	61703       
450709	60919       
449603	62662       
456667	62268       
456670	62268       
456673	62268       
456678	62268       
456707	63282       
456707	59693       
456707	63143       
462688	63642       
462687	63642       
462688	63644       
462687	63644       
466208	63642       
466208	63644       
466220	63642       
466220	63644       
470531	62743       
470532	63282       
470532	64242       
483387	61307       
484600	64545       
484609	64544       
491700	65465       
491709	65465       
491718	65465       
489815	65465       
492688	65465       
492999	65465       
493001	65465       
493004	65465       
493010	65465       
493022	65465       
493052	65185       
493054	65185       
493056	65185       
493058	65185       
493059	65185       
493063	65185       
495298	65286       
497039	65702       
498033	65702       
498014	65702       
498020	65702       
498016	65702       
498018	65702       
498024	65702       
498030	65702       
498047	65702       
498026	65702       
498038	65702       
498028	65702       
498041	65702       
498044	65702       
498022	65702       
498049	65702       
498051	65702       
498053	65702       
498055	65702       
498057	65702       
498061	65702       
498064	65702       
498067	65702       
498070	65702       
498073	65702       
498078	65702       
498081	65702       
498085	65702       
498089	65702       
498094	65702       
498096	65702       
498098	65702       
498100	65702       
498102	65702       
498105	65702       
498109	65702       
500275	64983       
501540	65702       
503135	65702       
503138	65702       
503141	65702       
503147	65702       
503555	65222       
506198	65702       
506214	65824       
506628	65702       
506631	65702       
506662	65702       
509572	65702       
512505	64547       
518747	65962       
518750	65962       
518752	64942       
518755	64942       
518889	65386       
518888	65386       
519047	66064       
519205	66423       
521540	66784       
521543	66784       
521545	31539       
521548	66784       
521584	65962       
521594	65962       
521599	65962       
521603	65962       
522101	65962       
522106	65962       
526184	62862       
526186	62862       
529023	65882       
529025	65882       
529028	65882       
529030	65882       
531075	66463       
533383	62885       
533386	62885       
531319	66624       
531320	66624       
536558	66624       
536561	66624       
536564	66624       
536568	66624       
536573	66624       
536575	66624       
536580	66624       
538911	66624       
539685	66624       
539686	65962       
541673	65522       
542314	66624       
542950	67273       
542952	67273       
542954	67273       
542823	66985       
542826	66985       
542822	66423       
542975	66423       
551265	67363       
551265	67224       
551265	60585       
551270	66985       
558061	60338       
558281	60338       
559722	67042       
559724	67042       
559839	67042       
560363	67395       
560381	67395       
560391	67395       
560397	67395       
560400	67395       
562708	67293       
564385	67183       
562556	67293       
568390	67606       
572939	67486       
579244	68024       
579243	68024       
581943	67584       
581945	67584       
581948	67584       
582766	64922       
582631	68163       
582775	64920       
582777	64920       
583511	67590       
583511	67567       
585408	67590       
585408	67567       
585586	67523       
585658	65876       
585659	67862       
585723	67365       
585725	64920       
585728	64920       
588443	68022       
589457	64920       
590541	68062       
590540	67485       
590540	67487       
590540	67365       
590540	68022       
590540	64920       
590540	68305       
594908	68305       
594912	67366       
594912	65876       
598014	68297       
598017	68297       
598018	68297       
598703	68297       
598706	68297       
598017	68355       
598711	68297       
598804	68297       
598806	68297       
599064	68297       
599066	68297       
599068	68297       
599070	68297       
599072	68297       
599074	68297       
601167	68297       
601170	68297       
601173	68297       
601175	68297       
601177	68297       
601179	68297       
601181	68297       
601183	68297       
601191	68297       
601218	68297       
601221	68297       
602259	68297       
602261	68297       
602264	68297       
602310	68297       
602547	68297       
602908	67966       
605794	67487       
606777	67165       
606780	67165       
606798	67165       
606808	68297       
608647	67382       
608647	68364       
608647	67225       
608653	67587       
610617	68002       
610617	68047       
612311	68002       
612311	68047       
617194	68485       
617195	68485       
621410	68762       
621411	68762       
627295	68842       
627077	68842       
658093	69922       
661931	70065       
667234	70065       
667237	70065       
667240	70065       
665175	70065       
665174	70065       
669756	70065       
672812	70066       
676189	70065       
690021	61403       
691189	70233       
691205	67284       
692418	70444       
692460	70783       
694357	70682       
698744	70243       
698744	70244       
698744	69945       
704232	71026       
704233	71026       
704216	71042       
704218	71042       
704340	71042       
704227	71042       
704497	70903       
706167	70725       
706193	70725       
706212	70725       
715267	70760       
718556	69864       
718556	69262       
718556	70463       
718556	70803       
728261	71304       
728265	71304       
728267	71304       
729267	72123       
729276	72123       
729286	72123       
744092	72265       
744236	72444       
744245	72444       
746142	70741       
748064	70741       
752212	72346       
752219	72346       
767261	73065       
775955	73104       
775958	73104       
775961	73104       
775969	73104       
776155	73104       
779281	73247       
779281	68706       
779281	71028       
779281	73326       
782581	70745       
430776	62064       
435787	60919       
436943	57084       
439895	62064       
439898	62064       
440653	62064       
439607	61743       
441616	60625       
443839	62203       
444385	61743       
444386	61743       
443840	62203       
445098	62203       
445809	62203       
445807	62203       
436894	62203       
443849	62203       
445802	62203       
441689	62203       
456289	62743       
458947	62743       
476439	62703       
479093	54903       
479880	60462       
479880	62418       
479880	60139       
479880	64547       
479880	62703       
479880	63582       
484747	63582       
481562	64685       
483014	60139       
484747	65022       
488095	64684       
489988	64761       
489990	64761       
491367	65290       
491367	65291       
491372	65290       
491372	65291       
493017	65803       
493332	65803       
493335	65803       
495346	65702       
495348	65702       
495350	65702       
495352	65702       
497087	65702       
498211	65702       
498214	65702       
500173	65702       
506069	65702       
509565	63143       
509565	64202       
509565	65642       
510712	64564       
510716	65702       
521401	66064       
521401	64942       
521402	66423       
521402	62363       
521402	66784       
525245	66003       
524606	66003       
525248	66003       
529000	66786       
531715	62885       
534111	66703       
534112	66703       
534331	67203       
534334	67203       
534356	66703       
536608	67203       
536611	67226       
536611	67224       
536611	60585       
536611	66671       
536613	66624       
536614	66624       
536653	66624       
542814	66423       
551283	67267       
551283	67273       
551283	66727       
554542	66802       
555777	67363       
555800	67363       
555812	67363       
555817	67363       
557101	67183       
562036	66002       
562040	66002       
562073	67183       
578191	67487       
578282	67487       
578194	67487       
579135	67802       
578285	67487       
579132	67542       
579135	64922       
579136	67487       
579137	67542       
579465	66624       
579540	67366       
579602	67486       
579549	67366       
586384	67864       
586386	67864       
586402	68062       
587258	67523       
587278	67523       
587285	67523       
585683	67366       
585684	67366       
589385	67366       
588839	67366       
589387	67366       
589400	67366       
589405	67366       
589593	67366       
589771	66691       
589769	66691       
590882	66691       
590932	66691       
590934	66691       
595194	67966       
599076	68297       
597713	67945       
597713	68053       
597713	66044       
599377	68297       
599380	68297       
599383	68297       
599423	68297       
599426	68297       
599429	68297       
599430	68297       
600490	68297       
600495	68297       
600552	68297       
600586	68297       
601480	68297       
603124	68297       
603129	68297       
603133	68297       
603355	68297       
603357	68297       
603360	68297       
603362	68297       
603369	68297       
603379	65803       
602252	68297       
602971	68297       
603122	68502       
603551	68297       
606420	68364       
607183	68502       
607218	67587       
607219	67587       
607227	67587       
607329	67225       
607383	68364       
607398	67382       
607401	67382       
607405	67382       
608688	67382       
608690	67382       
608720	67382       
608722	67382       
608725	67382       
610671	68364       
610668	67382       
610671	67225       
613068	68297       
616266	68394       
616270	67950       
621918	68464       
621789	68464       
621958	68464       
621959	64868       
621961	64868       
621964	64868       
621968	64868       
622076	64868       
624047	68047       
624047	68002       
624047	68841       
624047	68842       
624047	64920       
624047	68505       
631777	66691       
651468	69635       
649448	69635       
651471	69635       
651525	69635       
651495	69635       
651461	69635       
651492	69635       
650988	69635       
655465	69948       
655465	69633       
655764	68382       
655765	68382       
659362	69948       
659365	69442       
659365	69505       
659365	69563       
659365	69922       
661802	69563       
661822	70065       
677217	70178       
678420	70066       
678421	70066       
679179	70178       
679178	69882       
688404	70363       
681950	70522       
682944	70522       
688396	70363       
688399	70363       
688402	70363       
688407	70363       
688409	70363       
688412	70363       
688415	70363       
688417	70363       
689113	70233       
690709	70803       
690709	70462       
690709	70682       
691842	70444       
692319	70803       
694875	70203       
692321	70242       
692321	70127       
694841	70242       
694875	70682       
694875	70127       
694942	70682       
695193	43422       
699018	70244       
699019	70244       
699020	70244       
699023	70244       
699024	70244       
700719	70462       
701622	70462       
702022	70089       
703873	70760       
704211	70903       
711622	70725       
711614	71026       
711614	69812       
720281	70976       
711614	71145       
713834	70463       
714306	70463       
720282	70976       
722783	70976       
722784	70976       
725606	71927       
725608	71927       
725610	71028       
725884	71263       
725886	71263       
725888	71263       
725890	71263       
725892	71263       
725895	71263       
725898	71263       
725900	71263       
728009	71844       
728009	71683       
728009	72103       
728009	71028       
728009	71304       
730770	72123       
730771	72123       
735491	72265       
736800	72103       
736808	72103       
738017	72103       
738102	71684       
738103	71684       
738104	71684       
738127	71684       
738333	72203       
739777	72265       
740700	71684       
740753	71802       
740753	72265       
740754	72103       
740754	70242       
747871	72203       
755704	72083       
755705	72083       
755702	72083       
755703	72083       
782692	70745       
784512	70745       
784494	70745       
784504	70745       
784517	70745       
785493	70745       
434580	62064       
439807	61865       
442830	61625       
443667	62706       
443668	60919       
443805	62602       
444710	62662       
445140	62662       
445594	62662       
456642	62743       
456647	62743       
456661	62743       
456663	62743       
458793	62743       
463734	63645       
467532	64162       
471047	64242       
471052	64242       
471055	64242       
471516	61982       
472001	61982       
472003	61982       
472008	61982       
473389	62224       
473391	64484       
473392	62703       
473393	62703       
473426	62845       
480080	62703       
483164	63343       
483219	64435       
489808	32634       
489810	32634       
489813	32634       
489947	64762       
497010	65702       
497011	65702       
497311	65702       
500510	65702       
500507	65702       
500512	65702       
500514	65702       
500517	65702       
500520	65702       
500523	65702       
500526	65702       
500529	65702       
500531	65702       
500533	65702       
500535	65702       
500538	65702       
500540	65702       
500542	65702       
500544	65702       
500546	65702       
500548	65702       
500550	65702       
500554	65702       
500563	65702       
500567	65702       
500573	65702       
500576	65702       
500578	65702       
500580	65702       
500582	65702       
500585	65702       
500588	65702       
511258	65824       
513283	66363       
512703	66364       
512703	66363       
514127	66364       
514127	66363       
516755	65702       
516756	65702       
524097	62862       
526491	65183       
526491	62974       
526641	62974       
526633	62974       
526635	62974       
526637	62974       
526559	65183       
526639	62974       
526563	65183       
526643	62974       
529002	65882       
529002	66786       
529298	65962       
529297	65962       
530219	65962       
530225	65962       
530801	66671       
530805	66671       
530840	62982       
530841	62982       
531317	65882       
531317	66786       
531690	66671       
534090	66322       
534098	66525       
534101	66525       
534104	65962       
534106	65962       
534319	66542       
534321	66542       
534324	67203       
534327	67203       
537912	66624       
537915	66624       
538662	66463       
539063	66624       
539896	67229       
543025	67229       
543027	67229       
551647	66985       
543023	67273       
543037	67267       
551649	66985       
555374	67488       
555361	67488       
555362	67488       
555360	67488       
557215	67183       
557229	67183       
557231	67183       
558557	67363       
558562	67363       
555371	66802       
555372	66802       
555373	66802       
561883	67183       
563024	67293       
563742	66802       
564887	66802       
565173	67606       
566523	66802       
566524	66802       
566539	67606       
566540	67606       
566542	67606       
566543	67606       
566544	67606       
568245	67542       
568249	67542       
568252	67542       
576879	64922       
566878	61743       
573014	67606       
576885	64922       
576891	64922       
576896	64922       
577322	67606       
580401	67487       
580404	67487       
583689	68082       
583624	67366       
583625	67366       
585495	68062       
586005	67236       
586006	67236       
586009	67236       
588898	68305       
588900	68305       
590649	68066       
590829	67236       
590829	66691       
593547	67236       
593547	68066       
601187	68297       
593579	66691       
594915	68398       
601189	68297       
600637	68297       
600636	68297       
606223	68297       
606658	67225       
606661	67225       
606278	68355       
610686	67382       
618365	68762       
618366	68762       
618367	68762       
618370	65873       
618370	68485       
618370	65386       
656037	68382       
656038	68382       
656039	68382       
656040	68382       
656041	68382       
656885	69633       
659296	69863       
659298	69863       
657049	69563       
667620	70065       
667702	69505       
669875	69442       
674703	70065       
674704	70065       
682266	70522       
688878	61403       
688881	61403       
688885	61403       
688886	61403       
691190	69243       
692297	69243       
692291	69243       
702905	70089       
704186	70442       
692300	69243       
704187	70442       
704188	70442       
704189	70442       
704241	68581       
704243	47963       
703787	71145       
703790	70569       
703790	71026       
703790	69812       
703790	70089       
704282	70903       
704284	70903       
704301	71145       
704302	71145       
706608	70760       
712542	70725       
712549	70725       
718372	70683       
718374	70683       
718375	70683       
722845	71683       
732834	72123       
732777	72123       
732777	72124       
732776	71844       
732775	72203       
732775	71927       
732775	71028       
732871	72123       
741907	72203       
743482	72322       
743485	72322       
743991	72444       
743993	70741       
744204	72444       
744205	72444       
744711	71003       
744712	71003       
744713	71003       
756165	73024       
756754	72502       
756786	72502       
756792	72502       
756799	72502       
756910	72502       
756911	37685       
756920	37685       
764908	73066       
764910	73066       
765241	69842       
765175	72125       
765175	69842       
765237	69842       
772618	73065       
772619	73065       
773257	73104       
773258	73104       
768443	73065       
775973	72344       
775973	68706       
780280	70745       
780289	70745       
780295	70745       
782155	70745       
786087	70745       
783402	73326       
785315	70745       
786191	70745       
786195	73503       
786197	71642       
786374	73503       
786375	73503       
786389	72843       
786381	72702       
786382	72702       
786383	72702       
786396	73503       
786449	72843       
786514	72843       
786515	72843       
786550	72843       
786551	72843       
786552	72843       
786553	72843       
786554	72843       
786555	72843       
786590	70745       
786587	70745       
786588	70745       
786385	72702       
786629	72702       
787338	70484       
787342	70484       
438613	62203       
436895	62203       
436896	62203       
436897	62203       
436898	62203       
438614	62203       
439342	60625       
439342	62602       
439807	60919       
445711	61703       
441629	62662       
445710	60907       
445713	61703       
445719	61703       
444384	61743       
462460	44665       
444383	61743       
471368	61982       
467821	64162       
471373	61982       
477708	62418       
477710	62418       
479367	64685       
484626	64163       
484645	62703       
489831	64761       
494994	65803       
493294	65803       
494978	65803       
495005	65803       
495007	65803       
495266	65985       
495268	65286       
495268	64983       
495984	65803       
497671	65286       
497672	64202       
497672	65642       
500050	65702       
497674	65985       
498985	65985       
503492	65702       
505228	65222       
505239	65222       
505970	65824       
506768	65222       
506772	65222       
506775	65222       
506780	65222       
505797	65702       
508189	65702       
509878	65222       
509963	65702       
509964	65702       
509966	65702       
509967	65702       
510039	65702       
510041	65702       
510044	65702       
510051	65702       
510054	65702       
510059	64564       
510061	64564       
510068	65702       
512704	66363       
512704	66364       
512705	64942       
512705	66064       
512705	64202       
512705	65642       
512705	64762       
512705	65886       
512705	65064       
516381	65064       
516381	64762       
517640	65962       
518771	66064       
518767	66064       
518769	66064       
519137	66544       
519138	66544       
519248	66544       
519249	66544       
534250	66703       
519786	61743       
531312	65962       
534165	65882       
534165	67203       
534165	66671       
534166	66624       
534168	65962       
547780	66985       
534169	67203       
534170	66624       
534171	66624       
535298	62885       
539602	66624       
547778	66624       
547779	67226       
547779	67224       
547779	60585       
547779	66985       
554539	66802       
554521	66802       
554543	66802       
554538	66802       
554537	66802       
554536	66802       
555341	66727       
557898	67183       
557899	67183       
558010	67395       
558012	67395       
558016	67395       
557883	66985       
557886	60177       
557884	67546       
557884	66582       
557884	67363       
559542	67183       
559541	67488       
561209	67183       
562071	67183       
561765	67183       
562066	67183       
561978	62922       
567737	67542       
567742	67542       
567748	67542       
567757	67542       
567762	67542       
567767	67542       
572776	67606       
581801	67584       
581806	67584       
582768	2586        
583160	68082       
582768	67589       
582768	68162       
583160	68062       
583160	67864       
583160	67365       
583160	67802       
583160	67487       
583160	67485       
584483	68082       
585696	68082       
586380	67365       
588610	68022       
592948	68022       
592950	64920       
498035	65702       
600779	68297       
600815	68355       
600817	68355       
600819	68355       
600821	68355       
600825	68355       
600825	67966       
600825	67366       
600825	67165       
600825	67587       
602242	68297       
602245	68297       
602943	68297       
602946	68297       
602951	68297       
602963	68297       
603632	68297       
603634	68297       
603636	68297       
603967	68297       
603971	68297       
603975	68297       
606407	68297       
614183	67950       
614185	67950       
622471	68837       
622476	68837       
624188	68464       
624138	68464       
627077	68841       
624206	68650       
623421	68650       
626694	60689       
626694	68837       
634326	68837       
634329	68841       
634329	68842       
634331	68748       
634332	68748       
646675	69548       
646677	69548       
646679	69548       
647517	68831       
650037	69635       
650038	69635       
651617	69635       
651618	69635       
651619	69635       
650034	69635       
650035	69635       
650036	69635       
649298	69635       
649300	69635       
649301	69635       
651620	69635       
651621	69635       
655707	69633       
655709	69633       
656119	69633       
656356	69563       
656359	69563       
656559	69922       
656574	69922       
666520	70065       
667185	70065       
665176	70065       
667632	70065       
667626	70065       
667630	70065       
667634	70065       
667636	70065       
671222	70065       
671223	70065       
672260	70065       
672570	70364       
672573	70364       
672574	70364       
678748	70285       
678753	70285       
678756	70285       
678745	70285       
680360	69892       
680361	69892       
680364	69892       
680381	69892       
680382	69892       
680384	69892       
683055	70178       
683055	70522       
686428	70522       
686430	70065       
688706	70127       
688706	70242       
688706	70683       
689348	61403       
690893	70444       
692262	70444       
691462	70444       
691861	69243       
692288	70242       
694941	70233       
698559	70243       
698753	70569       
698755	70569       
698945	70462       
699134	70725       
716138	69262       
716157	69262       
719211	69744       
719215	69744       
721371	69744       
721373	69744       
721379	69744       
721382	69744       
721386	69744       
721389	69744       
721392	69744       
721367	69744       
724721	71683       
730525	72123       
730530	72123       
730531	72123       
740308	72203       
740314	72203       
740318	72203       
751584	72732       
751587	72732       
752204	72323       
752205	72323       
752206	72323       
752207	72323       
752208	72323       
752210	72323       
752211	72323       
752214	72123       
753645	72346       
760812	72125       
761563	71145       
761564	71145       
761566	71145       
762546	73065       
766040	73066       
773447	73104       
786370	70745       
786371	70745       
786372	70745       
786373	70745       
786378	70745       
786379	70745       
794751	71962       
794751	70484       
801127	72685       
801284	73365       
801465	72799       
804081	73770       
804006	73711       
804017	73711       
804017	73770       
804017	72799       
804017	72685       
804231	73442       
804018	73446       
804102	73404       
804233	73442       
804235	73442       
804286	73484       
807195	73167       
807198	73167       
807200	73167       
807202	73167       
810428	73786       
810209	73487       
810211	73442       
815873	73946       
810211	73786       
810211	73167       
810211	72051       
814473	73128       
814475	73128       
819000	74063       
819002	73431       
819006	73431       
797611	71962       
797714	73486       
797715	73485       
797719	73603       
797721	73785       
797721	73786       
797724	73770       
797724	73786       
797724	73404       
797724	72051       
797724	73487       
797724	73442       
797724	73167       
797724	73342       
797724	73083       
797724	73485       
797724	73785       
804043	72685       
804047	73487       
804050	73487       
810103	73486       
811203	73945       
811214	73945       
811218	73945       
813254	73128       
813203	72051       
813203	73786       
815870	73326       
815872	73128       
794710	73711       
794710	70760       
794710	73603       
794710	73083       
794710	73342       
794775	71962       
794777	71962       
794779	71962       
801120	72685       
801196	72799       
801198	73486       
801200	31947       
801203	31947       
801207	31947       
801211	31947       
804964	73442       
813324	73945       
813326	73945       
813328	73945       
798349	72799       
798344	72799       
798347	72799       
800750	73785       
800773	73326       
800773	73485       
800773	73711       
801301	31947       
801306	31947       
801340	73487       
801342	73487       
802825	72685       
802847	73487       
804033	72685       
804053	73446       
804055	73446       
821319	69563       
798010	73785       
798014	73803       
798016	73803       
801097	73785       
801136	31947       
801140	73711       
801443	73442       
804282	73365       
813206	73167       
813206	73326       
815972	73431       
815974	73431       
815977	73431       
818879	73128       
804034	73365       
819185	74063       
819187	74063       
819430	71303       
821300	71303       
794812	73342       
794814	73342       
794816	73342       
797370	73342       
797377	73342       
797382	73342       
797385	73342       
797387	73342       
797391	73342       
801469	73770       
802850	73487       
803996	72685       
807005	73446       
807005	72799       
807005	72685       
807004	73128       
807004	73770       
807037	73442       
808296	70745       
819432	71303       
\.


--
-- Data for Name: activite_participant; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY activite_participant (actparid, actid, senmat, fapcod, fapidx, typactparcod, teleparticipation) FROM stdin;
658	107	04092N	PARTICIPANT	\N	PRESENT	0
726	108	11076S	PARTICIPANT	\N	PRESENT	0
727	108	01059Y	PARTICIPANT	\N	PRESENT	0
728	108	87003B	PARTICIPANT	\N	PRESENT	0
729	108	14265W	PARTICIPANT	\N	PRESENT	0
730	108	07026Q	PARTICIPANT	\N	PRESENT	0
731	108	11040E	PARTICIPANT	\N	PRESENT	0
732	108	14275Y	PARTICIPANT	\N	PRESENT	0
734	108	95035G	PARTICIPANT	\N	PRESENT	0
735	108	12042Y	PARTICIPANT	\N	PRESENT	0
736	108	04053F	PARTICIPANT	\N	PRESENT	0
737	108	14063N	PARTICIPANT	\N	PRESENT	0
738	108	04043D	PARTICIPANT	\N	PRESENT	0
739	108	07024N	PARTICIPANT	\N	PRESENT	0
740	108	11097X	PARTICIPANT	\N	PRESENT	0
741	108	14083S	PARTICIPANT	\N	PRESENT	0
742	108	14073Q	PARTICIPANT	\N	PRESENT	0
743	108	11083R	PARTICIPANT	\N	PRESENT	0
744	108	11029K	PARTICIPANT	\N	PRESENT	0
745	108	14041T	PARTICIPANT	\N	PRESENT	0
746	108	08017T	PARTICIPANT	\N	PRESENT	0
747	108	08043V	PARTICIPANT	\N	PRESENT	0
748	108	14059S	PARTICIPANT	\N	PRESENT	0
749	108	14042U	PARTICIPANT	\N	PRESENT	0
750	108	14263U	PARTICIPANT	\N	PRESENT	0
751	108	11020A	PARTICIPANT	\N	PRESENT	0
752	108	04070G	PARTICIPANT	\N	PRESENT	0
753	108	11063M	PARTICIPANT	\N	PRESENT	0
754	108	11044J	PARTICIPANT	\N	PRESENT	0
755	108	95015C	PARTICIPANT	\N	PRESENT	0
756	108	04036E	PARTICIPANT	\N	PRESENT	0
757	108	14037X	PARTICIPANT	\N	PRESENT	0
758	108	14159V	PARTICIPANT	\N	PRESENT	0
759	108	14271U	PARTICIPANT	\N	PRESENT	0
760	108	04077P	PARTICIPANT	\N	PRESENT	0
761	108	04095R	PARTICIPANT	\N	PRESENT	0
762	108	04067M	PARTICIPANT	\N	PRESENT	0
763	108	14269B	PARTICIPANT	\N	PRESENT	0
764	724	01007L	PARTICIPANT	\N	PRESENT	0
765	724	04092N	PARTICIPANT	\N	PRESENT	0
766	724	01059Y	PARTICIPANT	\N	PRESENT	0
767	724	87003B	PARTICIPANT	\N	PRESENT	0
768	724	14265W	PARTICIPANT	\N	PRESENT	0
769	724	07026Q	PARTICIPANT	\N	PRESENT	0
770	724	11040E	PARTICIPANT	\N	PRESENT	0
771	724	95035G	PARTICIPANT	\N	PRESENT	0
772	724	12042Y	PARTICIPANT	\N	PRESENT	0
773	724	04053F	PARTICIPANT	\N	PRESENT	0
774	724	14063N	PARTICIPANT	\N	PRESENT	0
775	724	04043D	PARTICIPANT	\N	PRESENT	0
776	724	07024N	PARTICIPANT	\N	PRESENT	0
777	724	11097X	PARTICIPANT	\N	PRESENT	0
778	724	14073Q	PARTICIPANT	\N	PRESENT	0
779	724	11083R	PARTICIPANT	\N	PRESENT	0
780	724	11029K	PARTICIPANT	\N	PRESENT	0
781	724	08017T	PARTICIPANT	\N	PRESENT	0
782	724	08043V	PARTICIPANT	\N	PRESENT	0
783	724	14059S	PARTICIPANT	\N	PRESENT	0
721	108	01007L	PARTICIPANT	\N	PRESENT	0
722	108	04092N	PARTICIPANT	\N	PRESENT	0
784	724	14263U	PARTICIPANT	\N	PRESENT	0
815	724	04042C	PARTICIPANT	\N	PRESENT	0
786	724	04070G	PARTICIPANT	\N	PRESENT	0
787	724	11063M	PARTICIPANT	\N	PRESENT	0
788	724	11044J	PARTICIPANT	\N	PRESENT	0
789	724	95015C	PARTICIPANT	\N	PRESENT	0
790	724	04036E	PARTICIPANT	\N	PRESENT	0
791	724	14037X	PARTICIPANT	\N	PRESENT	0
792	724	14159V	PARTICIPANT	\N	PRESENT	0
793	724	14271U	PARTICIPANT	\N	PRESENT	0
794	724	04077P	PARTICIPANT	\N	PRESENT	0
795	724	04095R	PARTICIPANT	\N	PRESENT	0
796	724	04067M	PARTICIPANT	\N	PRESENT	0
797	724	14269B	PARTICIPANT	\N	PRESENT	0
798	724	14038Y	PARTICIPANT	\N	PRESENT	0
799	724	92045V	PARTICIPANT	\N	PRESENT	0
800	724	01041N	PARTICIPANT	\N	PRESENT	0
801	724	11061K	PARTICIPANT	\N	PRESENT	0
802	724	14041T	PARTICIPANT	\N	PRESENT	0
803	724	98050T	PARTICIPANT	\N	PRESENT	0
804	724	14042U	PARTICIPANT	\N	PRESENT	0
805	724	80013X	PARTICIPANT	\N	PRESENT	0
806	724	10015M	PARTICIPANT	\N	PRESENT	0
807	724	04088S	PARTICIPANT	\N	PRESENT	0
808	724	01048V	PARTICIPANT	\N	PRESENT	0
809	724	11077T	PARTICIPANT	\N	PRESENT	0
810	724	04057K	PARTICIPANT	\N	PRESENT	0
811	724	11071M	PARTICIPANT	\N	PRESENT	0
812	724	11031D	PARTICIPANT	\N	PRESENT	0
813	724	01027Q	PARTICIPANT	\N	PRESENT	0
814	724	14227Q	PARTICIPANT	\N	PRESENT	0
816	724	04085P	PARTICIPANT	\N	PRESENT	0
817	724	98053W	PARTICIPANT	\N	PRESENT	0
818	724	08011M	PARTICIPANT	\N	PRESENT	0
819	724	08061X	PARTICIPANT	\N	PRESENT	0
862	820	11072N	PARTICIPANT	\N	PRESENT	0
875	820	14275Y	PARTICIPANT	\N	PRESENT	0
861	820	95039L	PARTICIPANT	\N	PRESENT	0
656	107	04081K	PARTICIPANT	\N	PRESENT	0
657	107	04043D	PARTICIPANT	\N	PRESENT	0
870	820	11071M	PARTICIPANT	\N	PRESENT	0
869	820	08019V	PARTICIPANT	\N	PRESENT	0
871	820	98005N	PARTICIPANT	\N	PRESENT	0
873	820	08073C	PARTICIPANT	\N	PRESENT	0
876	820	04095R	PARTICIPANT	\N	PRESENT	0
878	820	14239U	PARTICIPANT	\N	PRESENT	0
880	820	04066L	PARTICIPANT	\N	PRESENT	0
3250	2822	08015R	PARTICIPANT	\N	PRESENT	0
3251	2822	14169X	PARTICIPANT	\N	PRESENT	0
3252	2822	14173T	PARTICIPANT	\N	PRESENT	0
3253	2822	14209N	PARTICIPANT	\N	PRESENT	0
3254	2822	11101A	PARTICIPANT	\N	PRESENT	0
3255	2822	14157T	PARTICIPANT	\N	PRESENT	0
3256	2822	04088S	PARTICIPANT	\N	PRESENT	0
3257	2822	04074L	PARTICIPANT	\N	PRESENT	0
3258	2822	14038Y	PARTICIPANT	\N	PRESENT	0
3259	2822	14033T	PARTICIPANT	\N	PRESENT	0
3260	2822	14195A	PARTICIPANT	\N	PRESENT	0
3261	2822	01057W	PARTICIPANT	\N	PRESENT	0
3262	2822	98023Q	PARTICIPANT	\N	PRESENT	0
3263	2822	11097X	PARTICIPANT	\N	PRESENT	0
3264	2822	14031R	PARTICIPANT	\N	PRESENT	0
3265	2822	14175V	PARTICIPANT	\N	PRESENT	0
3266	2822	08047A	PARTICIPANT	\N	PRESENT	0
3267	2822	90003B	PARTICIPANT	\N	PRESENT	0
3268	2822	08041T	PARTICIPANT	\N	PRESENT	0
3269	2822	14253S	PARTICIPANT	\N	PRESENT	0
3270	2822	04041B	PARTICIPANT	\N	PRESENT	0
3271	2822	04033B	PARTICIPANT	\N	PRESENT	0
3272	2822	04042C	PARTICIPANT	\N	PRESENT	0
3273	2822	95059Q	PARTICIPANT	\N	PRESENT	0
3274	2822	01027Q	PARTICIPANT	\N	PRESENT	0
3275	2822	77002U	PARTICIPANT	\N	PRESENT	0
3276	2822	14037X	PARTICIPANT	\N	PRESENT	0
3277	2822	11100Y	PARTICIPANT	\N	PRESENT	0
3278	2822	95037J	PARTICIPANT	\N	PRESENT	0
3279	2822	01031L	PARTICIPANT	\N	PRESENT	0
3280	2822	05008E	PARTICIPANT	\N	PRESENT	0
3281	2822	14065Q	PARTICIPANT	\N	PRESENT	0
3282	2822	04059M	PARTICIPANT	\N	PRESENT	0
3283	2822	08061X	PARTICIPANT	\N	PRESENT	0
3284	2822	01014K	PARTICIPANT	\N	PRESENT	0
3285	2822	14159V	PARTICIPANT	\N	PRESENT	0
3286	2822	14109K	PARTICIPANT	\N	PRESENT	0
3287	2822	11107G	PARTICIPANT	\N	PRESENT	0
3288	2822	08043V	PARTICIPANT	\N	PRESENT	0
3289	2822	11106F	PARTICIPANT	\N	PRESENT	0
3290	2822	01016M	PARTICIPANT	\N	PRESENT	0
3291	2822	09001P	PARTICIPANT	\N	PRESENT	0
3292	2822	95041E	PARTICIPANT	\N	PRESENT	0
3293	2822	11057P	PARTICIPANT	\N	PRESENT	0
3294	2822	11110B	PARTICIPANT	\N	PRESENT	0
3295	2822	14227Q	PARTICIPANT	\N	PRESENT	0
3296	2822	04089T	PARTICIPANT	\N	PRESENT	0
3297	2822	11084S	PARTICIPANT	\N	PRESENT	0
3298	2822	11063M	PARTICIPANT	\N	PRESENT	0
3299	2822	04066L	PARTICIPANT	\N	PRESENT	0
3300	2822	01025N	PARTICIPANT	\N	PRESENT	0
3301	2822	14053L	PARTICIPANT	\N	PRESENT	0
3302	2822	95039L	PARTICIPANT	\N	PRESENT	0
3303	2822	04057K	PARTICIPANT	\N	PRESENT	0
3304	2822	11027H	PARTICIPANT	\N	PRESENT	0
3305	2822	14135M	PARTICIPANT	\N	PRESENT	0
3306	2822	11091R	PARTICIPANT	\N	PRESENT	0
3307	2822	04061F	PARTICIPANT	\N	PRESENT	0
3308	2822	14249W	PARTICIPANT	\N	PRESENT	0
3309	2822	08060W	PARTICIPANT	\N	PRESENT	0
3310	2822	01008M	PARTICIPANT	\N	PRESENT	0
3311	2822	95035G	PARTICIPANT	\N	PRESENT	0
3312	2822	11095V	PARTICIPANT	\N	PRESENT	0
3313	2822	14247U	PARTICIPANT	\N	PRESENT	0
3314	2822	04043D	PARTICIPANT	\N	PRESENT	0
3315	2822	04081K	PARTICIPANT	\N	PRESENT	0
3316	2822	04092N	PARTICIPANT	\N	PRESENT	0
3317	2822	01047U	PARTICIPANT	\N	PRESENT	0
3318	2822	14199E	PARTICIPANT	\N	PRESENT	0
3319	2822	14263U	PARTICIPANT	\N	PRESENT	0
3320	2822	04054G	PARTICIPANT	\N	PRESENT	0
3321	2822	11043H	PARTICIPANT	\N	PRESENT	0
3322	2822	01058X	PARTICIPANT	\N	PRESENT	0
3323	2822	97011G	PARTICIPANT	\N	PRESENT	0
3324	2822	07024N	PARTICIPANT	\N	PRESENT	0
3325	2822	04040A	PARTICIPANT	\N	PRESENT	0
3326	2822	14187A	PARTICIPANT	\N	PRESENT	0
3327	2822	08010L	PARTICIPANT	\N	PRESENT	0
3328	2822	04097T	PARTICIPANT	\N	PRESENT	0
3329	2822	11090Q	PARTICIPANT	\N	PRESENT	0
3330	2822	01061S	PARTICIPANT	\N	PRESENT	0
3331	2822	08024S	PARTICIPANT	\N	PRESENT	0
3332	2822	08012N	PARTICIPANT	\N	PRESENT	0
3333	2822	14014Q	PARTICIPANT	\N	PRESENT	0
3334	2822	14257W	PARTICIPANT	\N	PRESENT	0
3335	2823	86034E	PARTICIPANT	\N	PRESENT	0
3336	2823	11037K	PARTICIPANT	\N	PRESENT	0
3337	2823	07034Q	PARTICIPANT	\N	PRESENT	0
3338	2823	99004R	PARTICIPANT	\N	PRESENT	0
3339	2823	14147R	PARTICIPANT	\N	PRESENT	0
3340	2823	98018T	PARTICIPANT	\N	PRESENT	0
3341	2823	04067M	PARTICIPANT	\N	PRESENT	0
3342	2823	14201E	PARTICIPANT	\N	PRESENT	0
3343	2823	14133K	PARTICIPANT	\N	PRESENT	0
3344	2823	80013X	PARTICIPANT	\N	PRESENT	0
3345	2823	08052W	PARTICIPANT	\N	PRESENT	0
3346	2823	14275Y	PARTICIPANT	\N	PRESENT	0
4348	2825	08062Y	PARTICIPANT	\N	PRESENT	0
4349	2825	12042Y	PARTICIPANT	\N	PRESENT	0
4350	2825	01043Q	PARTICIPANT	\N	PRESENT	0
4351	2825	14033T	PARTICIPANT	\N	PRESENT	0
4352	2825	14217N	PARTICIPANT	\N	PRESENT	0
4353	2825	14207L	PARTICIPANT	\N	PRESENT	0
4354	2825	01016M	PARTICIPANT	\N	PRESENT	0
4355	2825	80013X	PARTICIPANT	\N	PRESENT	0
4356	2825	14107H	PARTICIPANT	\N	PRESENT	0
4357	2825	14159V	PARTICIPANT	\N	PRESENT	0
4358	2825	01025N	PARTICIPANT	\N	PRESENT	0
4359	2825	95062K	PARTICIPANT	\N	PRESENT	0
4360	2825	14079W	PARTICIPANT	\N	PRESENT	0
4361	2825	14213J	PARTICIPANT	\N	PRESENT	0
4362	2825	11095V	PARTICIPANT	\N	PRESENT	0
4363	2825	14205J	PARTICIPANT	\N	PRESENT	0
4364	2825	14065Q	PARTICIPANT	\N	PRESENT	0
4365	2825	14237S	PARTICIPANT	\N	PRESENT	0
4366	2825	01008M	PARTICIPANT	\N	PRESENT	0
4367	2825	14071N	PARTICIPANT	\N	PRESENT	0
4368	2825	14255U	PARTICIPANT	\N	PRESENT	0
4369	2825	14231L	PARTICIPANT	\N	PRESENT	0
4370	2825	14030Q	PARTICIPANT	\N	PRESENT	0
4371	2825	92031P	PARTICIPANT	\N	PRESENT	0
4372	2825	14119M	PARTICIPANT	\N	PRESENT	0
4373	2825	14073Q	PARTICIPANT	\N	PRESENT	0
4374	2825	14083S	PARTICIPANT	\N	PRESENT	0
4375	2825	11100Y	PARTICIPANT	\N	PRESENT	0
4376	2825	95063L	PARTICIPANT	\N	PRESENT	0
4377	2825	14133K	PARTICIPANT	\N	PRESENT	0
4378	2825	92039X	PARTICIPANT	\N	PRESENT	0
4379	2825	01057W	PARTICIPANT	\N	PRESENT	0
4380	2825	14191V	PARTICIPANT	\N	PRESENT	0
4381	2825	14034U	PARTICIPANT	\N	PRESENT	0
4382	2825	11061K	PARTICIPANT	\N	PRESENT	0
4383	2825	11036J	PARTICIPANT	\N	PRESENT	0
4384	2825	11012A	PARTICIPANT	\N	PRESENT	0
4385	2825	14123H	PARTICIPANT	\N	PRESENT	0
4386	2825	08016S	PARTICIPANT	\N	PRESENT	0
4387	2825	04070G	PARTICIPANT	\N	PRESENT	0
4388	2825	92018S	PARTICIPANT	\N	PRESENT	0
5285	4401	01059Y	PARTICIPANT	\N	PRESENT	0
5286	4401	11098Y	PARTICIPANT	\N	PRESENT	0
5287	4401	80013X	PARTICIPANT	\N	PRESENT	0
5288	4401	14207L	PARTICIPANT	\N	PRESENT	0
5289	4401	14159V	PARTICIPANT	\N	PRESENT	0
5290	4401	14231L	PARTICIPANT	\N	PRESENT	0
5291	4401	14031R	PARTICIPANT	\N	PRESENT	0
5292	4401	11100Y	PARTICIPANT	\N	PRESENT	0
5293	4401	14169X	PARTICIPANT	\N	PRESENT	0
5294	4401	14257W	PARTICIPANT	\N	PRESENT	0
5295	4401	04049K	PARTICIPANT	\N	PRESENT	0
5296	4401	14135M	PARTICIPANT	\N	PRESENT	0
5297	4401	95062K	PARTICIPANT	\N	PRESENT	0
5298	4401	01015L	PARTICIPANT	\N	PRESENT	0
5299	4401	04067M	PARTICIPANT	\N	PRESENT	0
5300	4401	14187A	PARTICIPANT	\N	PRESENT	0
5301	4401	10006L	PARTICIPANT	\N	PRESENT	0
5302	4401	07034Q	PARTICIPANT	\N	PRESENT	0
5303	4401	11053K	PARTICIPANT	\N	PRESENT	0
5304	4401	01056V	PARTICIPANT	\N	PRESENT	0
5305	4401	14265W	PARTICIPANT	\N	PRESENT	0
5306	4401	14271U	PARTICIPANT	\N	PRESENT	0
5307	4401	11107G	PARTICIPANT	\N	PRESENT	0
5308	4401	11056N	PARTICIPANT	\N	PRESENT	0
5309	4401	01027Q	PARTICIPANT	\N	PRESENT	0
5310	4401	04053F	PARTICIPANT	\N	PRESENT	0
5311	4401	14079W	PARTICIPANT	\N	PRESENT	0
5312	4401	01024M	PARTICIPANT	\N	PRESENT	0
5313	4401	14193X	PARTICIPANT	\N	PRESENT	0
5314	4401	08010L	PARTICIPANT	\N	PRESENT	0
5315	4401	11077T	PARTICIPANT	\N	PRESENT	0
5284	4401	08024S	PARTICIPANT	\N	PRESENT	0
501212	500411	01034P	PARTICIPANT	\N	PRESENT	0
2786	821	86034E	PARTICIPANT	\N	PRESENT	0
2792	2789	11010L	PARTICIPANT	\N	PRESENT	0
2790	2789	86034E	PARTICIPANT	\N	PRESENT	0
2791	2789	99004R	PARTICIPANT	\N	PRESENT	0
2793	2789	11103C	PARTICIPANT	\N	PRESENT	0
2794	2789	11055M	PARTICIPANT	\N	PRESENT	0
2795	2789	04085P	PARTICIPANT	\N	PRESENT	0
2796	2789	04074L	PARTICIPANT	\N	PRESENT	0
2797	2789	98005N	PARTICIPANT	\N	PRESENT	0
2798	2789	04056J	PARTICIPANT	\N	PRESENT	0
2799	2789	08055A	PARTICIPANT	\N	PRESENT	0
2800	2789	08019V	PARTICIPANT	\N	PRESENT	0
2801	2789	11113E	PARTICIPANT	\N	PRESENT	0
2802	2789	04079R	PARTICIPANT	\N	PRESENT	0
2803	2789	14275Y	PARTICIPANT	\N	PRESENT	0
2804	2789	07034Q	PARTICIPANT	\N	PRESENT	0
2805	2789	04043D	PARTICIPANT	\N	PRESENT	0
2806	2789	14261S	PARTICIPANT	\N	PRESENT	0
2807	2789	01028R	PARTICIPANT	\N	PRESENT	0
2808	2789	11064N	PARTICIPANT	\N	PRESENT	0
2809	2789	08073C	PARTICIPANT	\N	PRESENT	0
2810	2789	95039L	PARTICIPANT	\N	PRESENT	0
2811	2789	14093U	PARTICIPANT	\N	PRESENT	0
2812	2789	05008E	PARTICIPANT	\N	PRESENT	0
2813	2789	14269B	PARTICIPANT	\N	PRESENT	0
2814	2789	14107H	PARTICIPANT	\N	PRESENT	0
2815	2789	04053F	PARTICIPANT	\N	PRESENT	0
2816	2789	04048J	PARTICIPANT	\N	PRESENT	0
501582	501581	19729F	PARTICIPANT	\N	PRESENT	0
501583	501581	04085P	PARTICIPANT	\N	PRESENT	0
501584	501581	20074E	PARTICIPANT	\N	PRESENT	0
501585	501581	14151M	PARTICIPANT	\N	PRESENT	0
502854	500288	20106U	PARTICIPANT	\N	PRESENT	0
502855	500288	14123H	PARTICIPANT	\N	PRESENT	0
502856	500288	17367Q	PARTICIPANT	\N	PRESENT	0
502857	500288	04043D	PARTICIPANT	\N	PRESENT	0
502858	500288	19295A	PARTICIPANT	\N	PRESENT	0
502859	500288	11065P	PARTICIPANT	\N	PRESENT	0
502860	500288	19643A	PARTICIPANT	\N	PRESENT	0
3347	2823	14239U	PARTICIPANT	\N	PRESENT	0
3348	2823	10006L	PARTICIPANT	\N	PRESENT	0
3349	2823	01059Y	PARTICIPANT	\N	PRESENT	0
3350	2823	14191V	PARTICIPANT	\N	PRESENT	0
3351	2823	14215L	PARTICIPANT	\N	PRESENT	0
3352	2823	14273W	PARTICIPANT	\N	PRESENT	0
3353	2823	86044G	PARTICIPANT	\N	PRESENT	0
3354	2823	14051J	PARTICIPANT	\N	PRESENT	0
3355	2823	04086Q	PARTICIPANT	\N	PRESENT	0
3356	2823	08039A	PARTICIPANT	\N	PRESENT	0
3357	2823	14271U	PARTICIPANT	\N	PRESENT	0
3358	2823	14107H	PARTICIPANT	\N	PRESENT	0
3359	2823	11034G	PARTICIPANT	\N	PRESENT	0
3360	2823	01015L	PARTICIPANT	\N	PRESENT	0
3361	2823	14001X	PARTICIPANT	\N	PRESENT	0
3362	2823	04053F	PARTICIPANT	\N	PRESENT	0
3363	2823	14073Q	PARTICIPANT	\N	PRESENT	0
3364	2823	04036E	PARTICIPANT	\N	PRESENT	0
3365	2823	14213J	PARTICIPANT	\N	PRESENT	0
3366	2823	11067R	PARTICIPANT	\N	PRESENT	0
3367	2823	01011G	PARTICIPANT	\N	PRESENT	0
3368	2823	08031R	PARTICIPANT	\N	PRESENT	0
3369	2823	14121F	PARTICIPANT	\N	PRESENT	0
3370	2823	04045F	PARTICIPANT	\N	PRESENT	0
3371	2823	14235Q	PARTICIPANT	\N	PRESENT	0
3372	2823	14013P	PARTICIPANT	\N	PRESENT	0
3373	2823	04085P	PARTICIPANT	\N	PRESENT	0
3374	2823	08053X	PARTICIPANT	\N	PRESENT	0
3375	2823	11031D	PARTICIPANT	\N	PRESENT	0
3376	2823	14281W	PARTICIPANT	\N	PRESENT	0
3377	2823	14028W	PARTICIPANT	\N	PRESENT	0
3378	2823	11036J	PARTICIPANT	\N	PRESENT	0
3379	2823	08016S	PARTICIPANT	\N	PRESENT	0
3380	2823	08055A	PARTICIPANT	\N	PRESENT	0
3381	2823	12042Y	PARTICIPANT	\N	PRESENT	0
3382	2823	11066Q	PARTICIPANT	\N	PRESENT	0
3383	2823	11113E	PARTICIPANT	\N	PRESENT	0
3384	2823	14081Q	PARTICIPANT	\N	PRESENT	0
3385	2823	14097Y	PARTICIPANT	\N	PRESENT	0
3386	2823	14151M	PARTICIPANT	\N	PRESENT	0
3387	2823	01044R	PARTICIPANT	\N	PRESENT	0
3388	2823	11069T	PARTICIPANT	\N	PRESENT	0
3389	2823	01003G	PARTICIPANT	\N	PRESENT	0
3390	2823	11083R	PARTICIPANT	\N	PRESENT	0
3391	2823	14231L	PARTICIPANT	\N	PRESENT	0
3392	2823	04056J	PARTICIPANT	\N	PRESENT	0
3393	2823	98024R	PARTICIPANT	\N	PRESENT	0
3394	2823	14269B	PARTICIPANT	\N	PRESENT	0
3395	2823	95030B	PARTICIPANT	\N	PRESENT	0
3396	2823	11046L	PARTICIPANT	\N	PRESENT	0
3397	2823	96004D	PARTICIPANT	\N	PRESENT	0
3398	2823	11098Y	PARTICIPANT	\N	PRESENT	0
3399	2823	14030Q	PARTICIPANT	\N	PRESENT	0
3400	2823	08017T	PARTICIPANT	\N	PRESENT	0
3401	2823	11010L	PARTICIPANT	\N	PRESENT	0
3402	2823	14211G	PARTICIPANT	\N	PRESENT	0
3403	2823	14229S	PARTICIPANT	\N	PRESENT	0
3404	2823	04077P	PARTICIPANT	\N	PRESENT	0
3405	2823	92040Q	PARTICIPANT	\N	PRESENT	0
3406	2823	14205J	PARTICIPANT	\N	PRESENT	0
4306	2825	07034Q	PARTICIPANT	\N	PRESENT	0
4304	2825	08024S	PARTICIPANT	\N	PRESENT	0
4305	2825	14187A	PARTICIPANT	\N	PRESENT	0
4307	2825	10006L	PARTICIPANT	\N	PRESENT	0
4308	2825	04054G	PARTICIPANT	\N	PRESENT	0
4309	2825	11098Y	PARTICIPANT	\N	PRESENT	0
4310	2825	14109K	PARTICIPANT	\N	PRESENT	0
4311	2825	14097Y	PARTICIPANT	\N	PRESENT	0
4312	2825	08055A	PARTICIPANT	\N	PRESENT	0
4313	2825	11053K	PARTICIPANT	\N	PRESENT	0
4314	2825	14042U	PARTICIPANT	\N	PRESENT	0
4343	2825	01034P	PARTICIPANT	\N	PRESENT	0
4316	2825	14018U	PARTICIPANT	\N	PRESENT	0
4317	2825	07029T	PARTICIPANT	\N	PRESENT	0
4318	2825	08047A	PARTICIPANT	\N	PRESENT	0
4319	2825	14195A	PARTICIPANT	\N	PRESENT	0
4320	2825	04088S	PARTICIPANT	\N	PRESENT	0
4321	2825	14031R	PARTICIPANT	\N	PRESENT	0
4322	2825	04053F	PARTICIPANT	\N	PRESENT	0
4323	2825	08038Y	PARTICIPANT	\N	PRESENT	0
4324	2825	11110B	PARTICIPANT	\N	PRESENT	0
4325	2825	14135M	PARTICIPANT	\N	PRESENT	0
4326	2825	11031D	PARTICIPANT	\N	PRESENT	0
4327	2825	14013P	PARTICIPANT	\N	PRESENT	0
4328	2825	11063M	PARTICIPANT	\N	PRESENT	0
4329	2825	01015L	PARTICIPANT	\N	PRESENT	0
4330	2825	14235Q	PARTICIPANT	\N	PRESENT	0
4331	2825	11097X	PARTICIPANT	\N	PRESENT	0
4332	2825	14215L	PARTICIPANT	\N	PRESENT	0
4333	2825	07032N	PARTICIPANT	\N	PRESENT	0
4334	2825	04049K	PARTICIPANT	\N	PRESENT	0
4335	2825	08058D	PARTICIPANT	\N	PRESENT	0
4336	2825	01046T	PARTICIPANT	\N	PRESENT	0
4337	2825	14265W	PARTICIPANT	\N	PRESENT	0
4338	2825	14169X	PARTICIPANT	\N	PRESENT	0
4339	2825	11048N	PARTICIPANT	\N	PRESENT	0
4340	2825	04067M	PARTICIPANT	\N	PRESENT	0
4341	2825	11105E	PARTICIPANT	\N	PRESENT	0
4342	2825	11094U	PARTICIPANT	\N	PRESENT	0
4344	2825	14026U	PARTICIPANT	\N	PRESENT	0
4345	2825	95030B	PARTICIPANT	\N	PRESENT	0
4346	2825	95049N	PARTICIPANT	\N	PRESENT	0
4347	2825	08015R	PARTICIPANT	\N	PRESENT	0
3143	2822	11037K	PARTICIPANT	\N	PRESENT	0
3144	2822	07034Q	PARTICIPANT	\N	PRESENT	0
3145	2822	99004R	PARTICIPANT	\N	PRESENT	0
3146	2822	14147R	PARTICIPANT	\N	PRESENT	0
3147	2822	98018T	PARTICIPANT	\N	PRESENT	0
3148	2822	04067M	PARTICIPANT	\N	PRESENT	0
3149	2822	14201E	PARTICIPANT	\N	PRESENT	0
3150	2822	14133K	PARTICIPANT	\N	PRESENT	0
3151	2822	80013X	PARTICIPANT	\N	PRESENT	0
3152	2822	08052W	PARTICIPANT	\N	PRESENT	0
3153	2822	14275Y	PARTICIPANT	\N	PRESENT	0
3154	2822	14239U	PARTICIPANT	\N	PRESENT	0
3155	2822	10006L	PARTICIPANT	\N	PRESENT	0
3156	2822	01059Y	PARTICIPANT	\N	PRESENT	0
3157	2822	14191V	PARTICIPANT	\N	PRESENT	0
3158	2822	14215L	PARTICIPANT	\N	PRESENT	0
3159	2822	14273W	PARTICIPANT	\N	PRESENT	0
3160	2822	86044G	PARTICIPANT	\N	PRESENT	0
3161	2822	14051J	PARTICIPANT	\N	PRESENT	0
3162	2822	04086Q	PARTICIPANT	\N	PRESENT	0
3163	2822	08039A	PARTICIPANT	\N	PRESENT	0
3164	2822	14271U	PARTICIPANT	\N	PRESENT	0
3165	2822	14107H	PARTICIPANT	\N	PRESENT	0
3166	2822	11034G	PARTICIPANT	\N	PRESENT	0
3167	2822	01015L	PARTICIPANT	\N	PRESENT	0
3168	2822	14001X	PARTICIPANT	\N	PRESENT	0
3169	2822	04053F	PARTICIPANT	\N	PRESENT	0
3170	2822	14073Q	PARTICIPANT	\N	PRESENT	0
3171	2822	04036E	PARTICIPANT	\N	PRESENT	0
3172	2822	14213J	PARTICIPANT	\N	PRESENT	0
3173	2822	11067R	PARTICIPANT	\N	PRESENT	0
3174	2822	01011G	PARTICIPANT	\N	PRESENT	0
3175	2822	08031R	PARTICIPANT	\N	PRESENT	0
3176	2822	14121F	PARTICIPANT	\N	PRESENT	0
3177	2822	04045F	PARTICIPANT	\N	PRESENT	0
3178	2822	14235Q	PARTICIPANT	\N	PRESENT	0
3179	2822	14013P	PARTICIPANT	\N	PRESENT	0
3180	2822	04085P	PARTICIPANT	\N	PRESENT	0
3181	2822	08053X	PARTICIPANT	\N	PRESENT	0
3182	2822	11031D	PARTICIPANT	\N	PRESENT	0
3183	2822	14281W	PARTICIPANT	\N	PRESENT	0
3184	2822	14028W	PARTICIPANT	\N	PRESENT	0
3185	2822	11036J	PARTICIPANT	\N	PRESENT	0
3186	2822	08016S	PARTICIPANT	\N	PRESENT	0
3187	2822	08055A	PARTICIPANT	\N	PRESENT	0
3188	2822	12042Y	PARTICIPANT	\N	PRESENT	0
3189	2822	11066Q	PARTICIPANT	\N	PRESENT	0
3190	2822	11113E	PARTICIPANT	\N	PRESENT	0
3191	2822	14081Q	PARTICIPANT	\N	PRESENT	0
3192	2822	14097Y	PARTICIPANT	\N	PRESENT	0
3193	2822	14151M	PARTICIPANT	\N	PRESENT	0
3194	2822	01044R	PARTICIPANT	\N	PRESENT	0
3195	2822	11069T	PARTICIPANT	\N	PRESENT	0
3196	2822	01003G	PARTICIPANT	\N	PRESENT	0
3197	2822	11083R	PARTICIPANT	\N	PRESENT	0
3198	2822	14231L	PARTICIPANT	\N	PRESENT	0
3199	2822	04056J	PARTICIPANT	\N	PRESENT	0
3200	2822	98024R	PARTICIPANT	\N	PRESENT	0
3201	2822	14269B	PARTICIPANT	\N	PRESENT	0
3202	2822	95030B	PARTICIPANT	\N	PRESENT	0
3203	2822	11046L	PARTICIPANT	\N	PRESENT	0
3204	2822	96004D	PARTICIPANT	\N	PRESENT	0
3205	2822	11098Y	PARTICIPANT	\N	PRESENT	0
3206	2822	14030Q	PARTICIPANT	\N	PRESENT	0
3207	2822	08017T	PARTICIPANT	\N	PRESENT	0
3208	2822	11010L	PARTICIPANT	\N	PRESENT	0
3209	2822	14211G	PARTICIPANT	\N	PRESENT	0
3210	2822	14229S	PARTICIPANT	\N	PRESENT	0
3211	2822	04077P	PARTICIPANT	\N	PRESENT	0
3212	2822	92040Q	PARTICIPANT	\N	PRESENT	0
3213	2822	14205J	PARTICIPANT	\N	PRESENT	0
3214	2822	08048B	PARTICIPANT	\N	PRESENT	0
3215	2822	14241N	PARTICIPANT	\N	PRESENT	0
3216	2822	11093T	PARTICIPANT	\N	PRESENT	0
3217	2822	14026U	PARTICIPANT	\N	PRESENT	0
3218	2822	14225N	PARTICIPANT	\N	PRESENT	0
3219	2822	92039X	PARTICIPANT	\N	PRESENT	0
3220	2822	11082Q	PARTICIPANT	\N	PRESENT	0
3221	2822	14034U	PARTICIPANT	\N	PRESENT	0
3222	2822	14219Q	PARTICIPANT	\N	PRESENT	0
3223	2822	14261S	PARTICIPANT	\N	PRESENT	0
3224	2822	04038G	PARTICIPANT	\N	PRESENT	0
3225	2822	14267Y	PARTICIPANT	\N	PRESENT	0
3226	2822	11081P	PARTICIPANT	\N	PRESENT	0
3227	2822	08068F	PARTICIPANT	\N	PRESENT	0
3228	2822	14018U	PARTICIPANT	\N	PRESENT	0
3229	2822	08009T	PARTICIPANT	\N	PRESENT	0
3230	2822	11094U	PARTICIPANT	\N	PRESENT	0
3231	2822	14063N	PARTICIPANT	\N	PRESENT	0
3232	2822	11064N	PARTICIPANT	\N	PRESENT	0
3233	2822	08038Y	PARTICIPANT	\N	PRESENT	0
3234	2822	08035V	PARTICIPANT	\N	PRESENT	0
3235	2822	08056B	PARTICIPANT	\N	PRESENT	0
3236	2822	14071N	PARTICIPANT	\N	PRESENT	0
3237	2822	04048J	PARTICIPANT	\N	PRESENT	0
3238	2822	01007L	PARTICIPANT	\N	PRESENT	0
3239	2822	92031P	PARTICIPANT	\N	PRESENT	0
3240	2822	14079W	PARTICIPANT	\N	PRESENT	0
3241	2822	14217N	PARTICIPANT	\N	PRESENT	0
3242	2822	08022Q	PARTICIPANT	\N	PRESENT	0
3243	2822	11088W	PARTICIPANT	\N	PRESENT	0
3244	2822	95015C	PARTICIPANT	\N	PRESENT	0
3245	2822	14055N	PARTICIPANT	\N	PRESENT	0
3246	2822	14059S	PARTICIPANT	\N	PRESENT	0
3247	2822	14061L	PARTICIPANT	\N	PRESENT	0
3248	2822	08069G	PARTICIPANT	\N	PRESENT	0
3249	2822	98050T	PARTICIPANT	\N	PRESENT	0
3843	2821	14263U	PARTICIPANT	\N	PRESENT	0
3846	2821	14133K	PARTICIPANT	\N	PRESENT	0
3847	2821	14239U	PARTICIPANT	\N	PRESENT	0
3856	2821	01031L	PARTICIPANT	\N	PRESENT	0
3868	2821	14261S	PARTICIPANT	\N	PRESENT	0
3878	2821	04085P	PARTICIPANT	\N	PRESENT	0
3884	2821	04059M	PARTICIPANT	\N	PRESENT	0
3893	2821	01008M	PARTICIPANT	\N	PRESENT	0
3895	2821	05008E	PARTICIPANT	\N	PRESENT	0
3904	2821	11036J	PARTICIPANT	\N	PRESENT	0
3917	2821	08055A	PARTICIPANT	\N	PRESENT	0
3918	2821	11081P	PARTICIPANT	\N	PRESENT	0
3919	2821	14065Q	PARTICIPANT	\N	PRESENT	0
3920	2821	14030Q	PARTICIPANT	\N	PRESENT	0
3924	2821	04054G	PARTICIPANT	\N	PRESENT	0
3999	2821	96004D	PARTICIPANT	\N	PRESENT	0
4000	2821	01044R	PARTICIPANT	\N	PRESENT	0
4001	2821	08043V	PARTICIPANT	\N	PRESENT	0
4002	2821	04040A	PARTICIPANT	\N	PRESENT	0
4003	2821	08060W	PARTICIPANT	\N	PRESENT	0
4004	2821	14013P	PARTICIPANT	\N	PRESENT	0
4005	2821	08068F	PARTICIPANT	\N	PRESENT	0
4006	2821	14175V	PARTICIPANT	\N	PRESENT	0
4007	2821	04053F	PARTICIPANT	\N	PRESENT	0
4009	2821	04066L	PARTICIPANT	\N	PRESENT	0
4010	2821	11101A	PARTICIPANT	\N	PRESENT	0
4011	2821	11095V	PARTICIPANT	\N	PRESENT	0
4012	2821	04042C	PARTICIPANT	\N	PRESENT	0
4014	2821	14053L	PARTICIPANT	\N	PRESENT	0
4015	2821	77002U	PARTICIPANT	\N	PRESENT	0
4017	2821	95015C	PARTICIPANT	\N	PRESENT	0
4018	2821	08024S	PARTICIPANT	\N	PRESENT	0
4019	2821	14201E	PARTICIPANT	\N	PRESENT	0
4020	2821	90003B	PARTICIPANT	\N	PRESENT	0
4021	2821	14038Y	PARTICIPANT	\N	PRESENT	0
4022	2821	14195A	PARTICIPANT	\N	PRESENT	0
4023	2821	14267Y	PARTICIPANT	\N	PRESENT	0
4024	2821	11031D	PARTICIPANT	\N	PRESENT	0
4028	2821	11027H	PARTICIPANT	\N	PRESENT	0
4026	2821	04038G	PARTICIPANT	\N	PRESENT	0
4027	2821	14209N	PARTICIPANT	\N	PRESENT	0
4029	2821	98023Q	PARTICIPANT	\N	PRESENT	0
4030	2821	80013X	PARTICIPANT	\N	PRESENT	0
4031	2821	04086Q	PARTICIPANT	\N	PRESENT	0
4032	2821	14079W	PARTICIPANT	\N	PRESENT	0
4033	2821	08052W	PARTICIPANT	\N	PRESENT	0
4034	2821	08038Y	PARTICIPANT	\N	PRESENT	0
4035	2821	01059Y	PARTICIPANT	\N	PRESENT	0
4036	2821	04081K	PARTICIPANT	\N	PRESENT	0
4037	2821	98018T	PARTICIPANT	\N	PRESENT	0
4038	2821	11088W	PARTICIPANT	\N	PRESENT	0
4039	2821	98024R	PARTICIPANT	\N	PRESENT	0
4040	2821	10006L	PARTICIPANT	\N	PRESENT	0
4041	2821	08022Q	PARTICIPANT	\N	PRESENT	0
4042	2821	04067M	PARTICIPANT	\N	PRESENT	0
4043	2821	14217N	PARTICIPANT	\N	PRESENT	0
4044	2821	11113E	PARTICIPANT	\N	PRESENT	0
4045	2821	01015L	PARTICIPANT	\N	PRESENT	0
4046	2821	14215L	PARTICIPANT	\N	PRESENT	0
4047	2821	01027Q	PARTICIPANT	\N	PRESENT	0
4048	2821	04089T	PARTICIPANT	\N	PRESENT	0
4049	2821	11091R	PARTICIPANT	\N	PRESENT	0
4050	2821	14151M	PARTICIPANT	\N	PRESENT	0
4051	2821	14249W	PARTICIPANT	\N	PRESENT	0
4052	2821	12042Y	PARTICIPANT	\N	PRESENT	0
4053	2821	95030B	PARTICIPANT	\N	PRESENT	0
4054	2821	11110B	PARTICIPANT	\N	PRESENT	0
4055	2821	14187A	PARTICIPANT	\N	PRESENT	0
4056	2821	11034G	PARTICIPANT	\N	PRESENT	0
4057	2821	01025N	PARTICIPANT	\N	PRESENT	0
4058	2821	14281W	PARTICIPANT	\N	PRESENT	0
4059	2821	11107G	PARTICIPANT	\N	PRESENT	0
4060	2821	01003G	PARTICIPANT	\N	PRESENT	0
4061	2821	97011G	PARTICIPANT	\N	PRESENT	0
4062	2821	11010L	PARTICIPANT	\N	PRESENT	0
4063	2821	14034U	PARTICIPANT	\N	PRESENT	0
4064	2821	14231L	PARTICIPANT	\N	PRESENT	0
4065	2821	11083R	PARTICIPANT	\N	PRESENT	0
4066	2821	07024N	PARTICIPANT	\N	PRESENT	0
4067	2821	14199E	PARTICIPANT	\N	PRESENT	0
4068	2821	08035V	PARTICIPANT	\N	PRESENT	0
4069	2821	08048B	PARTICIPANT	\N	PRESENT	0
4070	2821	14014Q	PARTICIPANT	\N	PRESENT	0
4071	2821	08041T	PARTICIPANT	\N	PRESENT	0
4072	2821	01011G	PARTICIPANT	\N	PRESENT	0
4073	2821	95035G	PARTICIPANT	\N	PRESENT	0
4074	2821	01007L	PARTICIPANT	\N	PRESENT	0
4075	2821	08056B	PARTICIPANT	\N	PRESENT	0
4077	2821	14211G	PARTICIPANT	\N	PRESENT	0
4078	2821	14033T	PARTICIPANT	\N	PRESENT	0
4079	2821	14026U	PARTICIPANT	\N	PRESENT	0
4080	2821	01057W	PARTICIPANT	\N	PRESENT	0
4081	2821	11064N	PARTICIPANT	\N	PRESENT	0
4082	2821	08016S	PARTICIPANT	\N	PRESENT	0
4083	2821	14081Q	PARTICIPANT	\N	PRESENT	0
4084	2821	95037J	PARTICIPANT	\N	PRESENT	0
4085	2821	04048J	PARTICIPANT	\N	PRESENT	0
4086	2821	08069G	PARTICIPANT	\N	PRESENT	0
4087	2821	04041B	PARTICIPANT	\N	PRESENT	0
4089	2821	04097T	PARTICIPANT	\N	PRESENT	0
4090	2821	95039L	PARTICIPANT	\N	PRESENT	0
4091	2821	14213J	PARTICIPANT	\N	PRESENT	0
4092	2821	14121F	PARTICIPANT	\N	PRESENT	0
4093	2821	09001P	PARTICIPANT	\N	PRESENT	0
4095	2821	14097Y	PARTICIPANT	\N	PRESENT	0
4096	2821	14241N	PARTICIPANT	\N	PRESENT	0
4097	2821	95041E	PARTICIPANT	\N	PRESENT	0
4098	2821	11084S	PARTICIPANT	\N	PRESENT	0
4099	2821	04036E	PARTICIPANT	\N	PRESENT	0
4100	2821	99004R	PARTICIPANT	\N	PRESENT	0
4101	2821	04061F	PARTICIPANT	\N	PRESENT	0
4102	2821	14061L	PARTICIPANT	\N	PRESENT	0
4103	2821	14073Q	PARTICIPANT	\N	PRESENT	0
4104	2821	04077P	PARTICIPANT	\N	PRESENT	0
4106	2821	08031R	PARTICIPANT	\N	PRESENT	0
4107	2821	14159V	PARTICIPANT	\N	PRESENT	0
4108	2821	86034E	PARTICIPANT	\N	PRESENT	0
4109	2821	08015R	PARTICIPANT	\N	PRESENT	0
4110	2821	08010L	PARTICIPANT	\N	PRESENT	0
4111	2821	92031P	PARTICIPANT	\N	PRESENT	0
4112	2821	08039A	PARTICIPANT	\N	PRESENT	0
4113	2821	14037X	PARTICIPANT	\N	PRESENT	0
4114	2821	11100Y	PARTICIPANT	\N	PRESENT	0
4115	2821	08017T	PARTICIPANT	\N	PRESENT	0
4116	2821	01061S	PARTICIPANT	\N	PRESENT	0
4117	2821	11098Y	PARTICIPANT	\N	PRESENT	0
4118	2821	14205J	PARTICIPANT	\N	PRESENT	0
4119	2821	14219Q	PARTICIPANT	\N	PRESENT	0
4120	2821	14059S	PARTICIPANT	\N	PRESENT	0
4121	2821	11106F	PARTICIPANT	\N	PRESENT	0
4122	2821	08012N	PARTICIPANT	\N	PRESENT	0
4128	2821	14031R	PARTICIPANT	\N	PRESENT	0
4125	2821	14018U	PARTICIPANT	\N	PRESENT	0
4126	2821	14063N	PARTICIPANT	\N	PRESENT	0
4129	2821	14001X	PARTICIPANT	\N	PRESENT	0
4130	2821	14273W	PARTICIPANT	\N	PRESENT	0
4131	2821	08009T	PARTICIPANT	\N	PRESENT	0
4132	2821	08053X	PARTICIPANT	\N	PRESENT	0
4133	2821	04057K	PARTICIPANT	\N	PRESENT	0
4134	2821	14147R	PARTICIPANT	\N	PRESENT	0
4135	2821	11067R	PARTICIPANT	\N	PRESENT	0
4136	2821	04092N	PARTICIPANT	\N	PRESENT	0
4137	2821	92039X	PARTICIPANT	\N	PRESENT	0
4138	2821	14109K	PARTICIPANT	\N	PRESENT	0
4139	2821	14071N	PARTICIPANT	\N	PRESENT	0
4140	2821	92040Q	PARTICIPANT	\N	PRESENT	0
4141	2821	11082Q	PARTICIPANT	\N	PRESENT	0
4142	2821	14169X	PARTICIPANT	\N	PRESENT	0
4143	2821	14253S	PARTICIPANT	\N	PRESENT	0
4144	2821	14191V	PARTICIPANT	\N	PRESENT	0
4145	2821	08061X	PARTICIPANT	\N	PRESENT	0
4146	2821	08047A	PARTICIPANT	\N	PRESENT	0
4147	2821	14028W	PARTICIPANT	\N	PRESENT	0
4148	2821	04088S	PARTICIPANT	\N	PRESENT	0
4149	2821	07034Q	PARTICIPANT	\N	PRESENT	0
4150	2821	11069T	PARTICIPANT	\N	PRESENT	0
4151	2821	98050T	PARTICIPANT	\N	PRESENT	0
4152	2821	04074L	PARTICIPANT	\N	PRESENT	0
4153	2821	11090Q	PARTICIPANT	\N	PRESENT	0
4154	2821	04043D	PARTICIPANT	\N	PRESENT	0
4155	2821	14235Q	PARTICIPANT	\N	PRESENT	0
4156	2821	14247U	PARTICIPANT	\N	PRESENT	0
4157	2821	95059Q	PARTICIPANT	\N	PRESENT	0
4158	2821	86044G	PARTICIPANT	\N	PRESENT	0
4159	2821	14135M	PARTICIPANT	\N	PRESENT	0
4160	2821	01016M	PARTICIPANT	\N	PRESENT	0
4161	2821	14055N	PARTICIPANT	\N	PRESENT	0
4162	2821	14225N	PARTICIPANT	\N	PRESENT	0
4163	2821	01014K	PARTICIPANT	\N	PRESENT	0
4164	2821	04033B	PARTICIPANT	\N	PRESENT	0
4165	2821	14271U	PARTICIPANT	\N	PRESENT	0
4166	2821	14229S	PARTICIPANT	\N	PRESENT	0
4168	2821	11093T	PARTICIPANT	\N	PRESENT	0
4633	4622	95015C	PARTICIPANT	\N	PRESENT	0
4635	4622	08024S	PARTICIPANT	\N	PRESENT	0
4636	4622	14201E	PARTICIPANT	\N	PRESENT	0
4637	4622	14209N	PARTICIPANT	\N	PRESENT	0
4638	4622	14079W	PARTICIPANT	\N	PRESENT	0
4639	4622	11091R	PARTICIPANT	\N	PRESENT	0
4640	4622	87003B	PARTICIPANT	\N	PRESENT	0
4642	4622	14249W	PARTICIPANT	\N	PRESENT	0
4643	4622	01041N	PARTICIPANT	\N	PRESENT	0
4644	4622	01025N	PARTICIPANT	\N	PRESENT	0
4646	4622	89029V	PARTICIPANT	\N	PRESENT	0
4647	4622	08035V	PARTICIPANT	\N	PRESENT	0
4649	4622	07026Q	PARTICIPANT	\N	PRESENT	0
4650	4622	14123H	PARTICIPANT	\N	PRESENT	0
7536	7084	08009T	PARTICIPANT	\N	PRESENT	0
4652	4622	04041B	PARTICIPANT	\N	PRESENT	0
4653	4622	14241N	PARTICIPANT	\N	PRESENT	0
4654	4622	14061L	PARTICIPANT	\N	PRESENT	0
4655	4622	14073Q	PARTICIPANT	\N	PRESENT	0
4656	4622	08031R	PARTICIPANT	\N	PRESENT	0
7537	7084	08042U	PARTICIPANT	\N	PRESENT	0
4658	4622	08039A	PARTICIPANT	\N	PRESENT	0
4660	4622	14059S	PARTICIPANT	\N	PRESENT	0
4661	4622	08012N	PARTICIPANT	\N	PRESENT	0
4663	4622	11104D	PARTICIPANT	\N	PRESENT	0
4665	4622	04057K	PARTICIPANT	\N	PRESENT	0
4667	4622	14109K	PARTICIPANT	\N	PRESENT	0
4668	4622	04070G	PRESIDENT	0	PRESENT	0
4669	4622	92040Q	PARTICIPANT	\N	PRESENT	0
4670	4622	14191V	PARTICIPANT	\N	PRESENT	0
7538	7084	98050T	PARTICIPANT	\N	PRESENT	0
4672	4622	14235Q	PARTICIPANT	\N	PRESENT	0
7539	7084	14013P	PARTICIPANT	\N	PRESENT	0
4675	4622	14229S	PARTICIPANT	\N	PRESENT	0
4676	4622	11043H	PARTICIPANT	\N	PRESENT	0
4678	4622	92045V	PARTICIPANT	\N	PRESENT	0
7540	7084	13002U	PARTICIPANT	\N	PRESENT	0
7541	7084	80013X	PARTICIPANT	\N	PRESENT	0
7542	7084	14033T	PARTICIPANT	\N	PRESENT	0
7543	7084	14257W	PARTICIPANT	\N	PRESENT	0
7544	7084	11036J	PARTICIPANT	\N	PRESENT	0
7545	7084	04088S	PARTICIPANT	\N	PRESENT	0
7546	7084	14159V	PARTICIPANT	\N	PRESENT	0
7547	7084	92039X	PARTICIPANT	\N	PRESENT	0
7548	7084	11065P	PARTICIPANT	\N	PRESENT	0
7549	7084	01057W	PARTICIPANT	\N	PRESENT	0
7550	7084	14273W	PARTICIPANT	\N	PRESENT	0
7551	7084	14079W	PARTICIPANT	\N	PRESENT	0
7552	7084	11100Y	PARTICIPANT	\N	PRESENT	0
7553	7084	11048N	PARTICIPANT	\N	PRESENT	0
7554	7084	01058X	PARTICIPANT	\N	PRESENT	0
7555	7084	14281W	PARTICIPANT	\N	PRESENT	0
7556	7084	09001P	PARTICIPANT	\N	PRESENT	0
7557	7084	14219Q	PARTICIPANT	\N	PRESENT	0
7558	7084	14195A	PARTICIPANT	\N	PRESENT	0
7559	7084	11103C	PARTICIPANT	\N	PRESENT	0
7560	7084	14038Y	PARTICIPANT	\N	PRESENT	0
7561	7084	08016S	PARTICIPANT	\N	PRESENT	0
7562	7084	14207L	PARTICIPANT	\N	PRESENT	0
7563	7084	01003G	PARTICIPANT	\N	PRESENT	0
7564	7084	08039A	PARTICIPANT	\N	PRESENT	0
7565	7084	14103D	PARTICIPANT	\N	PRESENT	0
7566	7084	14107H	PARTICIPANT	\N	PRESENT	0
7567	7084	11098Y	PARTICIPANT	\N	PRESENT	0
7568	7084	14073Q	PARTICIPANT	\N	PRESENT	0
7569	7084	11107G	PARTICIPANT	\N	PRESENT	0
7570	7084	11042G	PARTICIPANT	\N	PRESENT	0
7571	7084	01015L	PARTICIPANT	\N	PRESENT	0
7572	7084	11012A	PARTICIPANT	\N	PRESENT	0
7573	7084	14039A	PARTICIPANT	\N	PRESENT	0
7574	7084	14217N	PARTICIPANT	\N	PRESENT	0
7575	7084	14097Y	PARTICIPANT	\N	PRESENT	0
7576	7084	14031R	PARTICIPANT	\N	PRESENT	0
7577	7084	01034P	PARTICIPANT	\N	PRESENT	0
7598	7084	11039M	PARTICIPANT	\N	PRESENT	0
7599	7084	14123H	PARTICIPANT	\N	PRESENT	0
7600	7084	11033F	PARTICIPANT	\N	PRESENT	0
7683	7090	08024S	PARTICIPANT	\N	PRESENT	0
7684	7090	08011M	PARTICIPANT	\N	PRESENT	0
7685	7090	01034P	PARTICIPANT	\N	PRESENT	0
7686	7090	11083R	PARTICIPANT	\N	PRESENT	0
7687	7090	01013J	PARTICIPANT	\N	PRESENT	0
7688	7090	11012A	PARTICIPANT	\N	PRESENT	0
7689	7090	04034C	PARTICIPANT	\N	PRESENT	0
7690	7090	11070L	PARTICIPANT	\N	PRESENT	0
7691	7090	04086Q	PARTICIPANT	\N	PRESENT	0
7692	7090	08052W	PARTICIPANT	\N	PRESENT	0
7693	7090	11042G	PARTICIPANT	\N	PRESENT	0
7694	7090	11040E	PARTICIPANT	\N	PRESENT	0
4738	4680	14239U	PARTICIPANT	\N	PRESENT	0
4739	4680	11055M	PARTICIPANT	\N	PRESENT	0
4740	4680	01046T	PARTICIPANT	\N	PRESENT	0
4741	4680	08055A	PARTICIPANT	\N	PRESENT	0
4742	4680	04053F	PARTICIPANT	\N	PRESENT	0
4743	4680	14255U	PARTICIPANT	\N	PRESENT	0
7695	7090	11057P	PARTICIPANT	\N	PRESENT	0
7696	7090	98046X	PARTICIPANT	\N	PRESENT	0
4746	4680	14053L	PARTICIPANT	\N	PRESENT	0
4747	4680	11103C	PARTICIPANT	\N	PRESENT	0
7697	7090	95035G	PARTICIPANT	\N	PRESENT	0
4749	4680	14195A	PARTICIPANT	\N	PRESENT	0
4750	4680	14267Y	PARTICIPANT	\N	PRESENT	0
7698	7090	11053K	PARTICIPANT	\N	PRESENT	0
4752	4680	11031D	PARTICIPANT	\N	PRESENT	0
4753	4680	08052W	PARTICIPANT	\N	PRESENT	0
4754	4680	01059Y	PARTICIPANT	\N	PRESENT	0
4755	4680	04081K	PARTICIPANT	\N	PRESENT	0
4756	4680	98024R	PARTICIPANT	\N	PRESENT	0
4757	4680	10006L	PARTICIPANT	\N	PRESENT	0
4758	4680	04067M	PARTICIPANT	\N	PRESENT	0
4759	4680	14217N	PARTICIPANT	\N	PRESENT	0
4760	4680	14042U	PARTICIPANT	\N	PRESENT	0
7699	7090	01057W	PARTICIPANT	\N	PRESENT	0
4762	4680	12042Y	PARTICIPANT	\N	PRESENT	0
4763	4680	14087W	PARTICIPANT	\N	EXCUSE	0
4764	4680	01003G	PARTICIPANT	\N	PRESENT	0
7700	7090	99004R	PARTICIPANT	\N	PRESENT	0
4766	4680	14231L	PARTICIPANT	\N	PRESENT	0
7701	7090	04053F	PARTICIPANT	\N	PRESENT	0
7702	7090	01016M	PARTICIPANT	\N	PRESENT	0
4769	4680	08041T	PARTICIPANT	\N	PRESENT	0
4770	4680	01011G	PARTICIPANT	\N	PRESENT	0
4771	4680	14026U	PARTICIPANT	\N	PRESENT	0
4772	4680	14213J	PARTICIPANT	\N	PRESENT	0
4773	4680	14121F	PARTICIPANT	\N	PRESENT	0
4774	4680	11112D	PARTICIPANT	\N	EXCUSE	0
4775	4680	14037X	PARTICIPANT	\N	PRESENT	0
4776	4680	14018U	PARTICIPANT	\N	PRESENT	0
4777	4680	11067R	PARTICIPANT	\N	PRESENT	0
4778	4680	14223L	PARTICIPANT	\N	EXCUSE	0
4779	4680	04092N	PRESIDENT	0	PRESENT	0
4780	4680	14265W	PARTICIPANT	\N	PRESENT	0
4781	4680	14119M	PARTICIPANT	\N	PRESENT	0
4782	4680	14071N	PARTICIPANT	\N	PRESENT	0
4783	4680	07032N	PARTICIPANT	\N	PRESENT	0
4784	4680	04043D	PARTICIPANT	\N	PRESENT	0
4785	4680	14271U	PARTICIPANT	\N	PRESENT	0
7703	7090	11088W	PARTICIPANT	\N	PRESENT	0
4787	4680	11093T	PARTICIPANT	\N	PRESENT	0
4788	4680	11097X	PARTICIPANT	\N	PRESENT	0
4789	4680	04045F	PARTICIPANT	\N	PRESENT	0
4790	4680	14227Q	PARTICIPANT	\N	PRESENT	0
4791	4680	01034P	PARTICIPANT	\N	PRESENT	0
7704	7090	11036J	PARTICIPANT	\N	PRESENT	0
4793	4680	11063M	PARTICIPANT	\N	PRESENT	0
4794	4680	14269B	PARTICIPANT	\N	PRESENT	0
7705	7090	14271U	PARTICIPANT	\N	PRESENT	0
7706	7090	11074Q	PARTICIPANT	\N	PRESENT	0
7707	7090	01031L	PARTICIPANT	\N	PRESENT	0
7711	7090	04055H	PARTICIPANT	\N	PRESENT	0
7709	7090	14273W	PARTICIPANT	\N	PRESENT	0
7710	7090	04071H	PARTICIPANT	\N	PRESENT	0
7712	7090	14219Q	PARTICIPANT	\N	PRESENT	0
7713	7090	08016S	PARTICIPANT	\N	PRESENT	0
7714	7090	04036E	PARTICIPANT	\N	PRESENT	0
3831	2822	89017R	PARTICIPANT	\N	PRESENT	0
3832	2822	11076S	PARTICIPANT	\N	PRESENT	0
3833	2822	11109J	PARTICIPANT	\N	PRESENT	0
3834	2822	08025T	PARTICIPANT	\N	PRESENT	0
3835	2822	11055M	PARTICIPANT	\N	PRESENT	0
3836	2822	11039M	PARTICIPANT	\N	PRESENT	0
3837	2822	01046T	PARTICIPANT	\N	PRESENT	0
3838	2822	05004A	PARTICIPANT	\N	PRESENT	0
3839	2822	01013J	PARTICIPANT	\N	PRESENT	0
3840	2822	11030C	PARTICIPANT	\N	PRESENT	0
3841	2822	11033F	PARTICIPANT	\N	PRESENT	0
3842	2822	11068S	PARTICIPANT	\N	PRESENT	0
3844	2822	14093U	PARTICIPANT	\N	PRESENT	0
3845	2822	11040E	PARTICIPANT	\N	PRESENT	0
3848	2822	14069U	PARTICIPANT	\N	PRESENT	0
3849	2822	14089Y	PARTICIPANT	\N	PRESENT	0
3850	2822	08014Q	PARTICIPANT	\N	PRESENT	0
3851	2822	11060J	PARTICIPANT	\N	PRESENT	0
3852	2822	14105F	PARTICIPANT	\N	PRESENT	0
3853	2822	11029K	PARTICIPANT	\N	PRESENT	0
3854	2822	14167V	PARTICIPANT	\N	PRESENT	0
3855	2822	08058D	PARTICIPANT	\N	PRESENT	0
3857	2822	04047H	PARTICIPANT	\N	PRESENT	0
3858	2822	14207L	PARTICIPANT	\N	PRESENT	0
3859	2822	14255U	PARTICIPANT	\N	PRESENT	0
3860	2822	00003C	PARTICIPANT	\N	PRESENT	0
3861	2822	14083S	PARTICIPANT	\N	PRESENT	0
3862	2822	11053K	PARTICIPANT	\N	PRESENT	0
3863	2822	14085U	PARTICIPANT	\N	PRESENT	0
3864	2822	11103C	PARTICIPANT	\N	PRESENT	0
3865	2822	92015P	PARTICIPANT	\N	PRESENT	0
3866	2822	11032E	PARTICIPANT	\N	PRESENT	0
3867	2822	11044J	PARTICIPANT	\N	PRESENT	0
3869	2822	98029W	PARTICIPANT	\N	PRESENT	0
3870	2822	11080N	PARTICIPANT	\N	PRESENT	0
3871	2822	08028W	PARTICIPANT	\N	PRESENT	0
3872	2822	11042G	PARTICIPANT	\N	PRESENT	0
3873	2822	11023D	PARTICIPANT	\N	PRESENT	0
3874	2822	88008L	PARTICIPANT	\N	PRESENT	0
3875	2822	99002P	PARTICIPANT	\N	PRESENT	0
3876	2822	11114F	PARTICIPANT	\N	PRESENT	0
3877	2822	11056N	PARTICIPANT	\N	PRESENT	0
3879	2822	11065P	PARTICIPANT	\N	PRESENT	0
3880	2822	14259Y	PARTICIPANT	\N	PRESENT	0
3881	2822	04055H	PARTICIPANT	\N	PRESENT	0
3882	2822	11070L	PARTICIPANT	\N	PRESENT	0
3883	2822	11035H	PARTICIPANT	\N	PRESENT	0
3885	2822	08034U	PARTICIPANT	\N	PRESENT	0
3886	2822	92018S	PARTICIPANT	\N	PRESENT	0
3887	2822	08011M	PARTICIPANT	\N	PRESENT	0
3888	2822	14041T	PARTICIPANT	\N	PRESENT	0
3889	2822	01024M	PARTICIPANT	\N	PRESENT	0
3890	2822	14042U	PARTICIPANT	\N	PRESENT	0
3891	2822	04071H	PARTICIPANT	\N	PRESENT	0
3892	2822	98042T	PARTICIPANT	\N	PRESENT	0
3894	2822	14197C	PARTICIPANT	\N	PRESENT	0
3896	2822	92020L	PARTICIPANT	\N	PRESENT	0
3897	2822	01041N	PARTICIPANT	\N	PRESENT	0
3898	2822	11074Q	PARTICIPANT	\N	PRESENT	0
3899	2822	11096W	PARTICIPANT	\N	PRESENT	0
3900	2822	95031C	PARTICIPANT	\N	PRESENT	0
3901	2822	11020A	PARTICIPANT	\N	PRESENT	0
3902	2822	14087W	PARTICIPANT	\N	PRESENT	0
3903	2822	98053W	PARTICIPANT	\N	PRESENT	0
3905	2822	02002K	PARTICIPANT	\N	PRESENT	0
3906	2822	08065C	PARTICIPANT	\N	PRESENT	0
3907	2822	08018U	PARTICIPANT	\N	PRESENT	0
3908	2822	01037S	PARTICIPANT	\N	PRESENT	0
3909	2822	04035D	PARTICIPANT	\N	PRESENT	0
3910	2822	89029V	PARTICIPANT	\N	PRESENT	0
3911	2822	11061K	PARTICIPANT	\N	PRESENT	0
3912	2822	04095R	PARTICIPANT	\N	PRESENT	0
3913	2822	11089X	PARTICIPANT	\N	PRESENT	0
3914	2822	07026Q	PARTICIPANT	\N	PRESENT	0
3915	2822	11015D	PARTICIPANT	\N	PRESENT	0
3916	2822	07004J	PARTICIPANT	\N	PRESENT	0
3921	2822	11049P	PARTICIPANT	\N	PRESENT	0
3922	2822	14123H	PARTICIPANT	\N	PRESENT	0
3923	2822	98022P	PARTICIPANT	\N	PRESENT	0
4170	2821	14107H	PARTICIPANT	\N	PRESENT	0
3926	2822	14179A	PARTICIPANT	\N	PRESENT	0
3927	2822	01022K	PARTICIPANT	\N	PRESENT	0
3928	2822	04078Q	PARTICIPANT	\N	PRESENT	0
3929	2822	11048N	PARTICIPANT	\N	PRESENT	0
3930	2822	08044W	PARTICIPANT	\N	PRESENT	0
3931	2822	14039A	PARTICIPANT	\N	PRESENT	0
3932	2822	11112D	PARTICIPANT	\N	PRESENT	0
3933	2822	11099A	PARTICIPANT	\N	PRESENT	0
3934	2822	07029T	PARTICIPANT	\N	PRESENT	0
3935	2822	04049K	PARTICIPANT	\N	PRESENT	0
3936	2822	04094Q	PARTICIPANT	\N	PRESENT	0
3937	2822	11111C	PARTICIPANT	\N	PRESENT	0
3938	2822	98005N	PARTICIPANT	\N	PRESENT	0
3939	2822	12041X	PARTICIPANT	\N	PRESENT	0
3940	2822	14277B	PARTICIPANT	\N	PRESENT	0
3941	2822	11026G	PARTICIPANT	\N	PRESENT	0
3942	2822	11059R	PARTICIPANT	\N	PRESENT	0
3943	2822	01043Q	PARTICIPANT	\N	PRESENT	0
3944	2822	11077T	PARTICIPANT	\N	PRESENT	0
3945	2822	01048V	PARTICIPANT	\N	PRESENT	0
3946	2822	14103D	PARTICIPANT	\N	PRESENT	0
3947	2822	04079R	PARTICIPANT	\N	PRESENT	0
3948	2822	80027E	PARTICIPANT	\N	PRESENT	0
3949	2822	11104D	PARTICIPANT	\N	PRESENT	0
3950	2822	08019V	PARTICIPANT	\N	PRESENT	0
3951	2822	14251Q	PARTICIPANT	\N	PRESENT	0
3952	2822	98046X	PARTICIPANT	\N	PRESENT	0
3953	2822	14111D	PARTICIPANT	\N	PRESENT	0
3954	2822	11085T	PARTICIPANT	\N	PRESENT	0
3955	2822	83042R	PARTICIPANT	\N	PRESENT	0
4171	2821	11097X	PARTICIPANT	\N	PRESENT	0
3957	2822	08062Y	PARTICIPANT	\N	PRESENT	0
3958	2822	14221J	PARTICIPANT	\N	PRESENT	0
3959	2822	95049N	PARTICIPANT	\N	PRESENT	0
3960	2822	08051V	PARTICIPANT	\N	PRESENT	0
3961	2822	11014C	PARTICIPANT	\N	PRESENT	0
3962	2822	14223L	PARTICIPANT	\N	PRESENT	0
3963	2822	11072N	PARTICIPANT	\N	PRESENT	0
3964	2822	14265W	PARTICIPANT	\N	PRESENT	0
3965	2822	04070G	PARTICIPANT	\N	PRESENT	0
3966	2822	14119M	PARTICIPANT	\N	PRESENT	0
3967	2822	08021P	PARTICIPANT	\N	PRESENT	0
3968	2822	08042U	PARTICIPANT	\N	PRESENT	0
3969	2822	11105E	PARTICIPANT	\N	PRESENT	0
3970	2822	08073C	PARTICIPANT	\N	PRESENT	0
3971	2822	14237S	PARTICIPANT	\N	PRESENT	0
3972	2822	83047W	PARTICIPANT	\N	PRESENT	0
3973	2822	14193X	PARTICIPANT	\N	PRESENT	0
3974	2822	98021N	PARTICIPANT	\N	PRESENT	0
3975	2822	07032N	PARTICIPANT	\N	PRESENT	0
3976	2822	13002U	PARTICIPANT	\N	PRESENT	0
3977	2822	05012A	PARTICIPANT	\N	PRESENT	0
3978	2822	04080J	PARTICIPANT	\N	PRESENT	0
3979	2822	10015M	PARTICIPANT	\N	PRESENT	0
3980	2822	11012A	PARTICIPANT	\N	PRESENT	0
3981	2822	95062K	PARTICIPANT	\N	PRESENT	0
3982	2822	95063L	PARTICIPANT	\N	PRESENT	0
3983	2822	14017T	PARTICIPANT	\N	PRESENT	0
3984	2822	11054L	PARTICIPANT	\N	PRESENT	0
3985	2822	01019Q	PARTICIPANT	\N	PRESENT	0
3986	2822	11071M	PARTICIPANT	\N	PRESENT	0
3987	2822	01028R	PARTICIPANT	\N	PRESENT	0
3988	2822	98035U	PARTICIPANT	\N	PRESENT	0
3989	2822	01056V	PARTICIPANT	\N	PRESENT	0
3990	2822	04044E	PARTICIPANT	\N	PRESENT	0
3991	2822	92044U	PARTICIPANT	\N	PRESENT	0
3992	2822	01034P	PARTICIPANT	\N	PRESENT	0
3993	2822	92045V	PARTICIPANT	\N	PRESENT	0
3994	2822	11011M	PARTICIPANT	\N	PRESENT	0
3995	2822	96003C	PARTICIPANT	\N	PRESENT	0
3996	2822	11025F	PARTICIPANT	\N	PRESENT	0
3997	2822	95067Q	PARTICIPANT	\N	PRESENT	0
3998	2822	04034C	PARTICIPANT	\N	PRESENT	0
4169	2821	11046L	PARTICIPANT	\N	PRESENT	0
4172	2821	11043H	PARTICIPANT	\N	PRESENT	0
4173	2821	04045F	PARTICIPANT	\N	PRESENT	0
4174	2821	01058X	PARTICIPANT	\N	PRESENT	0
4175	2821	11094U	PARTICIPANT	\N	PRESENT	0
4176	2821	04056J	PARTICIPANT	\N	PRESENT	0
4177	2821	14275Y	PARTICIPANT	\N	PRESENT	0
4178	2821	14051J	PARTICIPANT	\N	PRESENT	0
4179	2821	14227Q	PARTICIPANT	\N	PRESENT	0
4180	2821	11037K	PARTICIPANT	\N	PRESENT	0
4181	2821	14157T	PARTICIPANT	\N	PRESENT	0
4182	2821	11066Q	PARTICIPANT	\N	PRESENT	0
4183	2821	11057P	PARTICIPANT	\N	PRESENT	0
4184	2821	14173T	PARTICIPANT	\N	PRESENT	0
4185	2821	11063M	PARTICIPANT	\N	PRESENT	0
4186	2821	14269B	PARTICIPANT	\N	PRESENT	0
4188	2821	01047U	PARTICIPANT	\N	PRESENT	0
4955	4954	11076S	PARTICIPANT	\N	PRESENT	0
4956	4954	04054G	PARTICIPANT	\N	PRESENT	0
4957	4954	04040A	PARTICIPANT	\N	PRESENT	0
4958	4954	08058D	PARTICIPANT	\N	PRESENT	0
4959	4954	04042C	PRESIDENT	0	PRESENT	0
4960	4954	77002U	PARTICIPANT	\N	PRESENT	0
4961	4954	98029W	PARTICIPANT	\N	PRESENT	0
4963	4954	11027H	PARTICIPANT	\N	PRESENT	0
4964	4954	98018T	PARTICIPANT	\N	PRESENT	0
4965	4954	92018S	PARTICIPANT	\N	PRESENT	0
4966	4954	86044G	PARTICIPANT	\N	PRESENT	0
4967	4954	92020L	PARTICIPANT	\N	PRESENT	0
4968	4954	95030B	PARTICIPANT	\N	PRESENT	0
5025	4954	92031P	PARTICIPANT	\N	PRESENT	0
4970	4954	95031C	PARTICIPANT	\N	PRESENT	0
4971	4954	08065C	PARTICIPANT	\N	PRESENT	0
4972	4954	97011G	PARTICIPANT	\N	PRESENT	0
4973	4954	04035D	PARTICIPANT	\N	PRESENT	0
4974	4954	07024N	PRESIDENT	1	PRESENT	0
5029	5028	14261S	PARTICIPANT	\N	PRESENT	0
4976	4954	14014Q	PARTICIPANT	\N	EXCUSE	0
5030	5028	14093U	PARTICIPANT	\N	PRESENT	0
4978	4954	07004J	PARTICIPANT	\N	PRESENT	0
4979	4954	95035G	PARTICIPANT	\N	PRESENT	0
4980	4954	08056B	PARTICIPANT	\N	PRESENT	0
4981	4954	14211G	PARTICIPANT	\N	PRESENT	0
5031	5028	14030Q	PARTICIPANT	\N	PRESENT	0
4983	4954	11064N	PARTICIPANT	\N	PRESENT	0
4984	4954	95037J	PARTICIPANT	\N	PRESENT	0
4986	4954	14097Y	PARTICIPANT	\N	PRESENT	0
4987	4954	95041E	PARTICIPANT	\N	PRESENT	0
4988	4954	04036E	PARTICIPANT	\N	PRESENT	0
5033	5028	08060W	PARTICIPANT	\N	PRESENT	0
4990	4954	04077P	PARTICIPANT	\N	PRESENT	0
10670	10552	14219Q	PARTICIPANT	\N	PRESENT	0
10671	10552	14030Q	PARTICIPANT	\N	PRESENT	0
4993	4954	11106F	PARTICIPANT	\N	PRESENT	0
4994	4954	14251Q	PARTICIPANT	\N	PRESENT	0
4995	4954	83042R	PARTICIPANT	\N	EXCUSE	0
5035	5028	11095V	PARTICIPANT	\N	PRESENT	0
4997	4954	11082Q	PARTICIPANT	\N	EXCUSE	0
4998	4954	11105E	PARTICIPANT	\N	PRESENT	0
4999	4954	14253S	PARTICIPANT	\N	PRESENT	0
5000	4954	08047A	PARTICIPANT	\N	PRESENT	0
5001	4954	14028W	PARTICIPANT	\N	PRESENT	0
5002	4954	14193X	PARTICIPANT	\N	PRESENT	0
5003	4954	98021N	PARTICIPANT	\N	PRESENT	0
10672	10552	08031R	PARTICIPANT	\N	PRESENT	0
5036	5028	14038Y	PARTICIPANT	\N	PRESENT	0
5006	4954	95059Q	PARTICIPANT	\N	EXCUSE	0
5007	4954	01014K	PARTICIPANT	\N	PRESENT	0
5008	4954	11054L	PARTICIPANT	\N	EXCUSE	0
5009	4954	01056V	PARTICIPANT	\N	PRESENT	0
10906	10905	14089Y	PRESIDENT	0	PRESENT	0
10907	10905	14133K	PARTICIPANT	\N	EXCUSE	0
10908	10905	01027Q	PARTICIPANT	\N	PRESENT	0
10909	10905	11112D	PARTICIPANT	\N	EXCUSE	0
10910	10905	14205J	PARTICIPANT	\N	EXCUSE	0
10911	10905	14031R	PARTICIPANT	\N	EXCUSE	0
10912	10905	14237S	PARTICIPANT	\N	EXCUSE	0
10913	10905	14028W	PARTICIPANT	\N	EXCUSE	0
10914	10905	04088S	PARTICIPANT	\N	EXCUSE	0
10915	10905	01016M	PARTICIPANT	\N	PRESENT	0
10916	10905	08068F	PARTICIPANT	\N	PRESENT	0
10918	10917	11055M	PARTICIPANT	\N	PRESENT	0
10922	10917	00003C	PARTICIPANT	\N	PRESENT	0
10920	10917	04053F	PARTICIPANT	\N	PRESENT	0
10921	10917	14255U	PARTICIPANT	\N	EXCUSE	0
10923	10917	14053L	PARTICIPANT	\N	PRESENT	0
10924	10917	11103C	PARTICIPANT	\N	PRESENT	0
10925	10917	14195A	PARTICIPANT	\N	PRESENT	0
10926	10917	11031D	PARTICIPANT	\N	PRESENT	0
10927	10917	08052W	PARTICIPANT	\N	PRESENT	0
5010	4954	92044U	PARTICIPANT	\N	PRESENT	0
10928	10917	98024R	PARTICIPANT	\N	EXCUSE	0
5038	5028	98023Q	PARTICIPANT	\N	PRESENT	0
10929	10917	10006L	PARTICIPANT	\N	PRESENT	0
10930	10917	14217N	PARTICIPANT	\N	PRESENT	0
10931	10917	14042U	PARTICIPANT	\N	PRESENT	0
4404	4403	01008M	PARTICIPANT	\N	PRESENT	0
4405	4403	11036J	PARTICIPANT	\N	PRESENT	0
10932	10917	14151M	PARTICIPANT	\N	PRESENT	0
5072	5071	89017R	PARTICIPANT	\N	PRESENT	0
4408	4403	08068F	PARTICIPANT	\N	PRESENT	0
4409	4403	14207L	PARTICIPANT	\N	PRESENT	0
4410	4403	11101A	PARTICIPANT	\N	PRESENT	0
4411	4403	90003B	PARTICIPANT	\N	PRESENT	0
10933	10917	14034U	PARTICIPANT	\N	PRESENT	0
4413	4403	80013X	PARTICIPANT	\N	PRESENT	0
4414	4403	08038Y	PARTICIPANT	\N	PRESENT	0
4415	4403	04089T	PARTICIPANT	\N	PRESENT	0
10934	10917	14231L	PARTICIPANT	\N	PRESENT	0
4417	4403	11110B	PARTICIPANT	\N	PRESENT	0
4418	4403	14187A	PARTICIPANT	\N	PRESENT	0
4419	4403	14033T	PARTICIPANT	\N	PRESENT	0
5040	5028	14169X	PARTICIPANT	\N	PRESENT	0
4421	4403	04048J	PARTICIPANT	\N	PRESENT	0
4422	4403	11099A	PARTICIPANT	\N	PRESENT	0
4423	4403	04049K	PARTICIPANT	\N	PRESENT	0
5041	5028	01015L	PARTICIPANT	\N	PRESENT	0
5042	5028	14281W	PARTICIPANT	\N	PRESENT	0
4426	4403	08015R	PARTICIPANT	\N	PRESENT	0
4427	4403	11100Y	PRESIDENT	0	PRESENT	0
4428	4403	01061S	PARTICIPANT	\N	PRESENT	0
4429	4403	11098Y	PARTICIPANT	\N	PRESENT	0
4430	4403	01043Q	PARTICIPANT	\N	PRESENT	0
5043	5028	11107G	PARTICIPANT	\N	PRESENT	0
4432	4403	14205J	PARTICIPANT	\N	PRESENT	0
10935	10917	11061K	PARTICIPANT	\N	PRESENT	0
4434	4403	14257W	PARTICIPANT	\N	PRESENT	0
4435	4403	08021P	PARTICIPANT	\N	PRESENT	0
4436	4403	04088S	PARTICIPANT	\N	PRESENT	0
4437	4403	98050T	PARTICIPANT	\N	PRESENT	0
4438	4403	11090Q	PARTICIPANT	\N	PRESENT	0
4439	4403	11046L	PARTICIPANT	\N	PRESENT	0
10936	10917	14213J	PARTICIPANT	\N	PRESENT	0
4441	4403	11094U	PARTICIPANT	\N	PRESENT	0
4442	4403	11066Q	PARTICIPANT	\N	PRESENT	0
10937	10917	14037X	PARTICIPANT	\N	PRESENT	0
5045	5028	02002K	PARTICIPANT	\N	PRESENT	0
10938	10917	11067R	PARTICIPANT	\N	PRESENT	0
5047	5028	04097T	PARTICIPANT	\N	PRESENT	0
5048	5028	09001P	PARTICIPANT	\N	EXCUSE	0
5049	5028	11059R	PARTICIPANT	\N	PRESENT	0
5050	5028	14219Q	PARTICIPANT	\N	PRESENT	0
5051	5028	80027E	PARTICIPANT	\N	PRESENT	0
5052	5028	14031R	PARTICIPANT	\N	PRESENT	0
5053	5028	08009T	PRESIDENT	0	PRESENT	0
5054	5028	08062Y	PARTICIPANT	\N	PRESENT	0
10939	10917	04092N	PRESIDENT	0	PRESENT	0
5056	5028	92039X	PARTICIPANT	\N	PRESENT	0
5057	5028	08042U	PARTICIPANT	\N	PRESENT	0
5058	5028	14237S	PARTICIPANT	\N	PRESENT	0
5059	5028	13002U	PARTICIPANT	\N	PRESENT	0
5060	5028	05012A	PARTICIPANT	\N	PRESENT	0
5073	5071	01031L	PRESIDENT	0	PRESENT	0
5062	5028	14135M	PARTICIPANT	\N	PRESENT	0
5063	5028	95062K	PARTICIPANT	\N	PRESENT	0
5064	5028	14107H	PARTICIPANT	\N	PRESENT	0
10940	10917	14265W	PARTICIPANT	\N	PRESENT	0
5066	5028	14157T	PARTICIPANT	\N	PRESENT	0
10941	10917	14271U	PARTICIPANT	\N	PRESENT	0
5075	5071	01013J	PARTICIPANT	\N	PRESENT	0
10942	10917	11093T	PARTICIPANT	\N	PRESENT	0
5444	5402	14257W	PARTICIPANT	\N	PRESENT	0
5078	5071	08014Q	PARTICIPANT	\N	PRESENT	0
10943	10917	11097X	PARTICIPANT	\N	PRESENT	0
5080	5071	14175V	PARTICIPANT	\N	PRESENT	0
5081	5071	14083S	PARTICIPANT	\N	PRESENT	0
10944	10917	14227Q	PARTICIPANT	\N	PRESENT	0
10945	10917	01034P	PARTICIPANT	\N	PRESENT	0
5084	5071	11042G	PARTICIPANT	\N	PRESENT	0
5085	5071	88008L	PARTICIPANT	\N	EXCUSE	0
5086	5071	04086Q	PARTICIPANT	\N	PRESENT	0
5087	5071	04055H	PARTICIPANT	\N	PRESENT	0
5088	5071	11070L	PARTICIPANT	\N	PRESENT	0
5445	5402	14219Q	PARTICIPANT	\N	PRESENT	0
5090	5071	08034U	PARTICIPANT	\N	PRESENT	0
5091	5071	08011M	PARTICIPANT	\N	PRESENT	0
5092	5071	08022Q	PARTICIPANT	\N	PRESENT	0
5093	5071	01027Q	PARTICIPANT	\N	PRESENT	0
5446	5402	14179A	PARTICIPANT	\N	PRESENT	0
5095	5071	11074Q	PARTICIPANT	\N	PRESENT	0
5096	5071	98053W	PARTICIPANT	\N	EXCUSE	0
5097	5071	11083R	PARTICIPANT	\N	PRESENT	0
5098	5071	14199E	PARTICIPANT	\N	PRESENT	0
5099	5071	01057W	PARTICIPANT	\N	PRESENT	0
5100	5071	08016S	PARTICIPANT	\N	PRESENT	0
5101	5071	08069G	PARTICIPANT	\N	PRESENT	0
5102	5071	11048N	PARTICIPANT	\N	EXCUSE	0
5103	5071	99004R	PARTICIPANT	\N	PRESENT	0
5104	5071	04061F	PARTICIPANT	\N	PRESENT	0
5105	5071	14159V	PARTICIPANT	\N	PRESENT	0
5106	5071	07029T	PARTICIPANT	\N	PRESENT	0
5447	5402	14215L	PARTICIPANT	\N	PRESENT	0
5108	5071	08010L	PARTICIPANT	\N	PRESENT	0
10947	10946	96004D	PRESIDENT	0	PRESENT	0
5110	5071	98046X	PARTICIPANT	\N	PRESENT	0
5111	5071	11085T	PARTICIPANT	\N	EXCUSE	0
11441	11440	11055M	PARTICIPANT	\N	PRESENT	0
5113	5071	08061X	PARTICIPANT	\N	PRESENT	0
5114	5071	01016M	PARTICIPANT	\N	PRESENT	0
5115	5071	14225N	PARTICIPANT	\N	PRESENT	0
5116	5071	11012A	PARTICIPANT	\N	PRESENT	0
5117	5071	11057P	PARTICIPANT	\N	PRESENT	0
5118	5071	14173T	PARTICIPANT	\N	PRESENT	0
5119	5071	04034C	PARTICIPANT	\N	PRESENT	0
5448	5402	14247U	PARTICIPANT	\N	PRESENT	0
5449	5402	08062Y	PARTICIPANT	\N	PRESENT	0
5450	5402	14195A	PARTICIPANT	\N	PRESENT	0
5451	5402	14191V	PARTICIPANT	\N	PRESENT	0
5452	5402	08043V	PARTICIPANT	\N	PRESENT	0
5453	5402	87003B	PARTICIPANT	\N	PRESENT	0
5454	5402	08016S	PARTICIPANT	\N	PRESENT	0
5455	5402	99004R	PARTICIPANT	\N	PRESENT	0
5456	5402	07026Q	PARTICIPANT	\N	PRESENT	0
5457	5402	11040E	PARTICIPANT	\N	PRESENT	0
5458	5402	14063N	PARTICIPANT	\N	PRESENT	0
5459	5402	08052W	PARTICIPANT	\N	PRESENT	0
5460	5402	11067R	PARTICIPANT	\N	PRESENT	0
5461	5402	80013X	PARTICIPANT	\N	PRESENT	0
5462	5402	14201E	PARTICIPANT	\N	PRESENT	0
5463	5402	14030Q	PARTICIPANT	\N	PRESENT	0
5464	5402	14227Q	PARTICIPANT	\N	PRESENT	0
5145	5144	08025T	PARTICIPANT	\N	PRESENT	0
5439	5402	14263U	PARTICIPANT	\N	PRESENT	0
5147	5144	05008E	PRESIDENT	0	PRESENT	0
10949	10946	11035H	PARTICIPANT	\N	PRESENT	0
5440	5402	14239U	PARTICIPANT	\N	PRESENT	0
5150	5144	14065Q	PARTICIPANT	\N	PRESENT	0
10950	10946	95030B	PARTICIPANT	\N	EXCUSE	0
10951	10946	08018U	PARTICIPANT	\N	PRESENT	0
10952	10946	14026U	PARTICIPANT	\N	EXCUSE	0
10953	10946	95037J	PARTICIPANT	\N	EXCUSE	0
5155	5144	04038G	PARTICIPANT	\N	PRESENT	0
5156	5144	11056N	PARTICIPANT	\N	PRESENT	0
10954	10946	14097Y	PARTICIPANT	\N	PRESENT	0
5158	5144	11035H	PARTICIPANT	\N	PRESENT	0
10955	10946	04061F	PARTICIPANT	\N	PRESENT	0
5160	5144	11113E	PARTICIPANT	\N	PRESENT	0
5161	5144	01024M	PARTICIPANT	\N	PRESENT	0
5162	5144	14215L	PARTICIPANT	\N	PRESENT	0
5441	5402	14133K	PARTICIPANT	\N	PRESENT	0
5164	5144	08018U	PARTICIPANT	\N	PRESENT	0
10956	10946	14073Q	PARTICIPANT	\N	PRESENT	0
5442	5402	86034E	PARTICIPANT	\N	PRESENT	0
10957	10946	11026G	PARTICIPANT	\N	PRESENT	0
5168	5144	95039L	PARTICIPANT	\N	PRESENT	0
5443	5402	11029K	PARTICIPANT	\N	PRESENT	0
5170	5144	11084S	PARTICIPANT	\N	PRESENT	0
5171	5144	11026G	PARTICIPANT	\N	PRESENT	0
5172	5144	04079R	PARTICIPANT	\N	PRESENT	0
10958	10946	98046X	PARTICIPANT	\N	EXCUSE	0
5174	5144	14001X	PARTICIPANT	\N	PRESENT	0
5175	5144	14273W	PARTICIPANT	\N	PRESENT	0
11442	11440	01046T	PARTICIPANT	\N	PRESENT	0
5177	5144	95049N	PARTICIPANT	\N	PRESENT	0
5178	5144	14147R	PARTICIPANT	\N	PRESENT	0
10960	10946	08042U	PARTICIPANT	\N	PRESENT	0
10961	10946	14135M	PARTICIPANT	\N	PRESENT	0
5181	5144	07034Q	PARTICIPANT	\N	PRESENT	0
5182	5144	04074L	PARTICIPANT	\N	PRESENT	0
10962	10946	01016M	PARTICIPANT	\N	PRESENT	0
5184	5144	95063L	PARTICIPANT	\N	PRESENT	0
10963	10946	10015M	PARTICIPANT	\N	EXCUSE	0
5186	5144	01028R	PARTICIPANT	\N	PRESENT	0
5187	5144	98035U	PARTICIPANT	\N	PRESENT	0
10964	10946	11012A	PARTICIPANT	\N	PRESENT	0
10965	10946	04045F	PARTICIPANT	\N	EXCUSE	0
10966	10946	04034C	PARTICIPANT	\N	PRESENT	0
11443	11440	04053F	PARTICIPANT	\N	PRESENT	0
11444	11440	14255U	PARTICIPANT	\N	EXCUSE	0
11445	11440	04066L	PARTICIPANT	\N	PRESENT	0
11446	11440	11103C	PARTICIPANT	\N	PRESENT	0
3407	2823	08048B	PARTICIPANT	\N	PRESENT	0
3408	2823	14241N	PARTICIPANT	\N	PRESENT	0
3409	2823	11093T	PARTICIPANT	\N	PRESENT	0
3410	2823	14026U	PARTICIPANT	\N	PRESENT	0
3411	2823	14225N	PARTICIPANT	\N	PRESENT	0
3412	2823	92039X	PARTICIPANT	\N	PRESENT	0
3413	2823	11082Q	PARTICIPANT	\N	PRESENT	0
3414	2823	14034U	PARTICIPANT	\N	PRESENT	0
3415	2823	14219Q	PARTICIPANT	\N	PRESENT	0
3416	2823	14261S	PARTICIPANT	\N	PRESENT	0
3417	2823	04038G	PARTICIPANT	\N	PRESENT	0
3418	2823	14267Y	PARTICIPANT	\N	PRESENT	0
3419	2823	11081P	PARTICIPANT	\N	PRESENT	0
3420	2823	08068F	PARTICIPANT	\N	PRESENT	0
3421	2823	14018U	PARTICIPANT	\N	PRESENT	0
3422	2823	08009T	PARTICIPANT	\N	PRESENT	0
3423	2823	11094U	PARTICIPANT	\N	PRESENT	0
3424	2823	14063N	PARTICIPANT	\N	PRESENT	0
3425	2823	11064N	PARTICIPANT	\N	PRESENT	0
3426	2823	08038Y	PARTICIPANT	\N	PRESENT	0
3427	2823	08035V	PARTICIPANT	\N	PRESENT	0
3428	2823	08056B	PARTICIPANT	\N	PRESENT	0
3429	2823	14071N	PARTICIPANT	\N	PRESENT	0
3430	2823	04048J	PARTICIPANT	\N	PRESENT	0
3431	2823	01007L	PARTICIPANT	\N	PRESENT	0
3432	2823	92031P	PARTICIPANT	\N	PRESENT	0
3433	2823	14079W	PARTICIPANT	\N	PRESENT	0
3434	2823	14217N	PARTICIPANT	\N	PRESENT	0
3435	2823	08022Q	PARTICIPANT	\N	PRESENT	0
3436	2823	11088W	PARTICIPANT	\N	PRESENT	0
3437	2823	95015C	PARTICIPANT	\N	PRESENT	0
3438	2823	14055N	PARTICIPANT	\N	PRESENT	0
3439	2823	14059S	PARTICIPANT	\N	PRESENT	0
3440	2823	14061L	PARTICIPANT	\N	PRESENT	0
3441	2823	08069G	PARTICIPANT	\N	PRESENT	0
3442	2823	98050T	PARTICIPANT	\N	PRESENT	0
3443	2823	08015R	PARTICIPANT	\N	PRESENT	0
3444	2823	14169X	PARTICIPANT	\N	PRESENT	0
3445	2823	14173T	PARTICIPANT	\N	PRESENT	0
3446	2823	14209N	PARTICIPANT	\N	PRESENT	0
3447	2823	11101A	PARTICIPANT	\N	PRESENT	0
3448	2823	14157T	PARTICIPANT	\N	PRESENT	0
3449	2823	04088S	PARTICIPANT	\N	PRESENT	0
3450	2823	04074L	PARTICIPANT	\N	PRESENT	0
3451	2823	14038Y	PARTICIPANT	\N	PRESENT	0
3452	2823	14033T	PARTICIPANT	\N	PRESENT	0
3453	2823	14195A	PARTICIPANT	\N	PRESENT	0
3454	2823	01057W	PARTICIPANT	\N	PRESENT	0
3455	2823	98023Q	PARTICIPANT	\N	PRESENT	0
3456	2823	11097X	PARTICIPANT	\N	PRESENT	0
3457	2823	14031R	PARTICIPANT	\N	PRESENT	0
3458	2823	14175V	PARTICIPANT	\N	PRESENT	0
3459	2823	08047A	PARTICIPANT	\N	PRESENT	0
3460	2823	90003B	PARTICIPANT	\N	PRESENT	0
3461	2823	08041T	PARTICIPANT	\N	PRESENT	0
3462	2823	14253S	PARTICIPANT	\N	PRESENT	0
3463	2823	04041B	PARTICIPANT	\N	PRESENT	0
3464	2823	04033B	PARTICIPANT	\N	PRESENT	0
3465	2823	04042C	PARTICIPANT	\N	PRESENT	0
3466	2823	95059Q	PARTICIPANT	\N	PRESENT	0
3467	2823	01027Q	PARTICIPANT	\N	PRESENT	0
3468	2823	77002U	PARTICIPANT	\N	PRESENT	0
3469	2823	14037X	PARTICIPANT	\N	PRESENT	0
3470	2823	11100Y	PARTICIPANT	\N	PRESENT	0
3471	2823	95037J	PARTICIPANT	\N	PRESENT	0
3472	2823	01031L	PARTICIPANT	\N	PRESENT	0
3473	2823	05008E	PARTICIPANT	\N	PRESENT	0
3474	2823	14065Q	PARTICIPANT	\N	PRESENT	0
3475	2823	04059M	PARTICIPANT	\N	PRESENT	0
3476	2823	08061X	PARTICIPANT	\N	PRESENT	0
3477	2823	01014K	PARTICIPANT	\N	PRESENT	0
3478	2823	14159V	PARTICIPANT	\N	PRESENT	0
3479	2823	14109K	PARTICIPANT	\N	PRESENT	0
3480	2823	11107G	PARTICIPANT	\N	PRESENT	0
3481	2823	08043V	PARTICIPANT	\N	PRESENT	0
3482	2823	11106F	PARTICIPANT	\N	PRESENT	0
3483	2823	01016M	PARTICIPANT	\N	PRESENT	0
3484	2823	09001P	PARTICIPANT	\N	PRESENT	0
3485	2823	95041E	PARTICIPANT	\N	PRESENT	0
3486	2823	11057P	PARTICIPANT	\N	PRESENT	0
3487	2823	11110B	PARTICIPANT	\N	PRESENT	0
3488	2823	14227Q	PARTICIPANT	\N	PRESENT	0
3489	2823	04089T	PARTICIPANT	\N	PRESENT	0
3490	2823	11084S	PARTICIPANT	\N	PRESENT	0
3491	2823	11063M	PARTICIPANT	\N	PRESENT	0
3492	2823	04066L	PARTICIPANT	\N	PRESENT	0
3493	2823	01025N	PARTICIPANT	\N	PRESENT	0
3494	2823	14053L	PARTICIPANT	\N	PRESENT	0
3495	2823	95039L	PARTICIPANT	\N	PRESENT	0
3496	2823	04057K	PARTICIPANT	\N	PRESENT	0
3497	2823	11027H	PARTICIPANT	\N	PRESENT	0
3498	2823	14135M	PARTICIPANT	\N	PRESENT	0
3499	2823	11091R	PARTICIPANT	\N	PRESENT	0
3500	2823	04061F	PARTICIPANT	\N	PRESENT	0
3501	2823	14249W	PARTICIPANT	\N	PRESENT	0
3502	2823	08060W	PARTICIPANT	\N	PRESENT	0
3503	2823	01008M	PARTICIPANT	\N	PRESENT	0
3504	2823	95035G	PARTICIPANT	\N	PRESENT	0
3505	2823	11095V	PARTICIPANT	\N	PRESENT	0
3506	2823	14247U	PARTICIPANT	\N	PRESENT	0
3507	2823	04043D	PARTICIPANT	\N	PRESENT	0
3508	2823	04081K	PARTICIPANT	\N	PRESENT	0
3509	2823	04092N	PARTICIPANT	\N	PRESENT	0
3510	2823	01047U	PARTICIPANT	\N	PRESENT	0
3511	2823	14199E	PARTICIPANT	\N	PRESENT	0
3512	2823	14263U	PARTICIPANT	\N	PRESENT	0
3513	2823	04054G	PARTICIPANT	\N	PRESENT	0
3514	2823	11043H	PARTICIPANT	\N	PRESENT	0
3515	2823	01058X	PARTICIPANT	\N	PRESENT	0
3516	2823	97011G	PARTICIPANT	\N	PRESENT	0
3517	2823	07024N	PARTICIPANT	\N	PRESENT	0
3518	2823	04040A	PARTICIPANT	\N	PRESENT	0
3519	2823	14187A	PARTICIPANT	\N	PRESENT	0
3520	2823	08010L	PARTICIPANT	\N	PRESENT	0
3521	2823	04097T	PARTICIPANT	\N	PRESENT	0
3522	2823	11090Q	PARTICIPANT	\N	PRESENT	0
3523	2823	01061S	PARTICIPANT	\N	PRESENT	0
3524	2823	08024S	PARTICIPANT	\N	PRESENT	0
3525	2823	08012N	PARTICIPANT	\N	PRESENT	0
3526	2823	14014Q	PARTICIPANT	\N	PRESENT	0
3527	2823	14257W	PARTICIPANT	\N	PRESENT	0
3528	2823	14265W	PARTICIPANT	\N	PRESENT	0
3529	2823	07032N	PARTICIPANT	\N	PRESENT	0
3530	2823	07029T	PARTICIPANT	\N	PRESENT	0
3531	2823	11104D	PARTICIPANT	\N	PRESENT	0
3532	2823	14041T	PARTICIPANT	\N	PRESENT	0
3533	2823	00003C	PARTICIPANT	\N	PRESENT	0
3534	2823	11089X	PARTICIPANT	\N	PRESENT	0
3535	2823	11060J	PARTICIPANT	\N	PRESENT	0
3536	2823	11029K	PARTICIPANT	\N	PRESENT	0
3537	2823	95049N	PARTICIPANT	\N	PRESENT	0
3741	2824	01007L	PARTICIPANT	\N	PRESENT	0
3742	2824	11053K	PARTICIPANT	\N	PRESENT	0
3743	2824	07034Q	PARTICIPANT	\N	PRESENT	0
3744	2824	14187A	PARTICIPANT	\N	PRESENT	0
3745	2824	14051J	PARTICIPANT	\N	PRESENT	0
3746	2824	11089X	PARTICIPANT	\N	PRESENT	0
3747	2824	14235Q	PARTICIPANT	\N	PRESENT	0
3748	2824	14121F	PARTICIPANT	\N	PRESENT	0
3749	2824	08014Q	PARTICIPANT	\N	PRESENT	0
3750	2824	11036J	PARTICIPANT	\N	PRESENT	0
3751	2824	14013P	PARTICIPANT	\N	PRESENT	0
3752	2824	01011G	PARTICIPANT	\N	PRESENT	0
3753	2824	14227Q	PARTICIPANT	\N	PRESENT	0
3754	2824	04066L	PARTICIPANT	\N	PRESENT	0
3755	2824	04045F	PARTICIPANT	\N	PRESENT	0
3756	2824	11067R	PARTICIPANT	\N	PRESENT	0
3757	2824	14271U	PARTICIPANT	\N	PRESENT	0
3758	2824	14065Q	PARTICIPANT	\N	PRESENT	0
3759	2824	14014Q	PARTICIPANT	\N	PRESENT	0
3760	2824	14257W	PARTICIPANT	\N	PRESENT	0
3761	2824	14269B	PARTICIPANT	\N	PRESENT	0
3762	2824	14109K	PARTICIPANT	\N	PRESENT	0
3763	2824	13002U	PARTICIPANT	\N	PRESENT	0
3764	2824	14225N	PARTICIPANT	\N	PRESENT	0
3765	2824	04053F	PARTICIPANT	\N	PRESENT	0
3766	2824	14191V	PARTICIPANT	\N	PRESENT	0
3767	2824	12042Y	PARTICIPANT	\N	PRESENT	0
3768	2824	11066Q	PARTICIPANT	\N	PRESENT	0
3769	2824	14133K	PARTICIPANT	\N	PRESENT	0
3770	2824	14081Q	PARTICIPANT	\N	PRESENT	0
3771	2824	11105E	PARTICIPANT	\N	PRESENT	0
3772	2824	14159V	PARTICIPANT	\N	PRESENT	0
3773	2824	08010L	PARTICIPANT	\N	PRESENT	0
3774	2824	04067M	PARTICIPANT	\N	PRESENT	0
3775	2824	01061S	PARTICIPANT	\N	PRESENT	0
3776	2824	11037K	PARTICIPANT	\N	PRESENT	0
3777	2824	14030Q	PARTICIPANT	\N	PRESENT	0
3778	2824	14205J	PARTICIPANT	\N	PRESENT	0
3779	2824	11094U	PARTICIPANT	\N	PRESENT	0
3780	2824	05008E	PARTICIPANT	\N	PRESENT	0
3781	2824	11012A	PARTICIPANT	\N	PRESENT	0
3784	2824	14041T	PARTICIPANT	\N	PRESENT	0
3785	2824	14034U	PARTICIPANT	\N	PRESENT	0
3786	2824	04088S	PARTICIPANT	\N	PRESENT	0
3787	2824	11111C	PARTICIPANT	\N	PRESENT	0
3788	2824	04041B	PARTICIPANT	\N	PRESENT	0
3789	2824	14275Y	PARTICIPANT	\N	PRESENT	0
3790	2824	14273W	PARTICIPANT	\N	PRESENT	0
3791	2824	07032N	PARTICIPANT	\N	PRESENT	0
3792	2824	01047U	PARTICIPANT	\N	PRESENT	0
3793	2824	14215L	PARTICIPANT	\N	PRESENT	0
3794	2824	11043H	PARTICIPANT	\N	PRESENT	0
3795	2824	11084S	PARTICIPANT	\N	PRESENT	0
3796	2824	11042G	PARTICIPANT	\N	PRESENT	0
3797	2824	11100Y	PARTICIPANT	\N	PRESENT	0
3798	2824	11081P	PARTICIPANT	\N	PRESENT	0
3799	2824	14247U	PARTICIPANT	\N	PRESENT	0
3800	2824	04033B	PARTICIPANT	\N	PRESENT	0
3801	2824	14055N	PARTICIPANT	\N	PRESENT	0
3802	2824	08022Q	PARTICIPANT	\N	PRESENT	0
3803	2824	01046T	PARTICIPANT	\N	PRESENT	0
3804	2824	08031R	PARTICIPANT	\N	PRESENT	0
3805	2824	98018T	PARTICIPANT	\N	PRESENT	0
3806	2824	95049N	PARTICIPANT	\N	PRESENT	0
3807	2824	14147R	PARTICIPANT	\N	PRESENT	0
3808	2824	11091R	PARTICIPANT	\N	PRESENT	0
3809	2824	14026U	PARTICIPANT	\N	PRESENT	0
3810	2824	14265W	PARTICIPANT	\N	PRESENT	0
3811	2824	11095V	PARTICIPANT	\N	PRESENT	0
3812	2824	11101A	PARTICIPANT	\N	PRESENT	0
3813	2824	04086Q	PARTICIPANT	\N	PRESENT	0
3814	2824	11090Q	PARTICIPANT	\N	PRESENT	0
3815	2824	14259Y	PARTICIPANT	\N	PRESENT	0
3816	2824	97011G	PARTICIPANT	\N	PRESENT	0
3817	2824	11103C	PARTICIPANT	\N	PRESENT	0
3818	2824	04097T	PARTICIPANT	\N	PRESENT	0
3819	2824	08041T	PARTICIPANT	\N	PRESENT	0
3820	2824	14213J	PARTICIPANT	\N	PRESENT	0
3821	2824	95062K	PARTICIPANT	\N	PRESENT	0
3822	2824	14031R	PARTICIPANT	\N	PRESENT	0
3823	2824	14157T	PARTICIPANT	\N	PRESENT	0
3824	2824	14251Q	PARTICIPANT	\N	PRESENT	0
3825	2824	14083S	PARTICIPANT	\N	PRESENT	0
3826	2824	14261S	PARTICIPANT	\N	PRESENT	0
3827	2824	14175V	PARTICIPANT	\N	PRESENT	0
3828	2824	08038Y	PARTICIPANT	\N	PRESENT	0
3829	2824	04085P	PARTICIPANT	\N	PRESENT	0
3830	2824	11110B	PARTICIPANT	\N	PRESENT	0
4008	2824	08055A	PARTICIPANT	\N	PRESENT	0
4013	2824	14237S	PARTICIPANT	\N	PRESENT	0
4016	2824	95015C	PARTICIPANT	\N	PRESENT	0
4076	2824	95030B	PARTICIPANT	\N	PRESENT	0
4088	2824	95063L	PARTICIPANT	\N	PRESENT	0
4094	2824	08015R	PARTICIPANT	\N	PRESENT	0
4105	2824	14173T	PARTICIPANT	\N	PRESENT	0
4124	2824	90003B	PARTICIPANT	\N	PRESENT	0
4127	2824	08034U	PARTICIPANT	\N	PRESENT	0
4167	2824	14209N	PARTICIPANT	\N	PRESENT	0
4187	2824	11063M	PARTICIPANT	\N	PRESENT	0
4189	2824	08062Y	PARTICIPANT	\N	PRESENT	0
4190	2824	08051V	PARTICIPANT	\N	PRESENT	0
4191	2824	01059Y	PARTICIPANT	\N	PRESENT	0
4192	2824	01058X	PARTICIPANT	\N	PRESENT	0
4193	2824	08065C	PARTICIPANT	\N	PRESENT	0
4194	2824	01034P	PARTICIPANT	\N	PRESENT	0
4195	2824	11098Y	PARTICIPANT	\N	PRESENT	0
4196	2824	08047A	PARTICIPANT	\N	PRESENT	0
4197	2824	99004R	PARTICIPANT	\N	PRESENT	0
4198	2824	08009T	PARTICIPANT	\N	PRESENT	0
4199	2824	11057P	PARTICIPANT	\N	PRESENT	0
4200	2824	14119M	PARTICIPANT	\N	PRESENT	0
4201	2824	14033T	PARTICIPANT	\N	PRESENT	0
4202	2824	14038Y	PARTICIPANT	\N	PRESENT	0
4203	2824	01027Q	PARTICIPANT	\N	PRESENT	0
4204	2824	14069U	PARTICIPANT	\N	PRESENT	0
4205	2824	07004J	PARTICIPANT	\N	PRESENT	0
4206	2824	11064N	PARTICIPANT	\N	PRESENT	0
4207	2824	01008M	PARTICIPANT	\N	PRESENT	0
4208	2824	04049K	PARTICIPANT	\N	PRESENT	0
4209	2824	86044G	PARTICIPANT	\N	PRESENT	0
4210	2824	08061X	PARTICIPANT	\N	PRESENT	0
4211	2824	01043Q	PARTICIPANT	\N	PRESENT	0
4212	2824	11093T	PARTICIPANT	\N	PRESENT	0
4213	2824	14107H	PARTICIPANT	\N	PRESENT	0
4214	2824	01025N	PARTICIPANT	\N	PRESENT	0
4215	2824	14135M	PARTICIPANT	\N	PRESENT	0
4216	2824	98046X	PARTICIPANT	\N	PRESENT	0
4217	2824	14231L	PARTICIPANT	\N	PRESENT	0
4218	2824	08056B	PARTICIPANT	\N	PRESENT	0
4219	2824	14217N	PARTICIPANT	\N	PRESENT	0
4220	2824	92039X	PARTICIPANT	\N	PRESENT	0
4221	2824	11097X	PARTICIPANT	\N	PRESENT	0
4222	2824	14042U	PARTICIPANT	\N	PRESENT	0
4223	2824	04047H	PARTICIPANT	\N	PRESENT	0
4224	2824	01016M	PARTICIPANT	\N	PRESENT	0
4225	2824	11077T	PARTICIPANT	\N	PRESENT	0
4226	2824	08016S	PARTICIPANT	\N	PRESENT	0
4227	2824	01015L	PARTICIPANT	\N	PRESENT	0
4228	2824	04081K	PARTICIPANT	\N	PRESENT	0
4229	2824	14207L	PARTICIPANT	\N	PRESENT	0
4230	2824	80013X	PARTICIPANT	\N	PRESENT	0
4231	2824	11031D	PARTICIPANT	\N	PRESENT	0
4232	2824	14267Y	PARTICIPANT	\N	PRESENT	0
4233	2824	89017R	PARTICIPANT	\N	PRESENT	0
4236	2824	01057W	PARTICIPANT	\N	PRESENT	0
4238	2824	14018U	PARTICIPANT	\N	PRESENT	0
4239	2824	98050T	PARTICIPANT	\N	PRESENT	0
10093	10092	01034P	PRESIDENT	0	PRESENT	0
10094	10092	04053F	PARTICIPANT	\N	PRESENT	0
10095	10092	14255U	PARTICIPANT	\N	PRESENT	0
10096	10092	14195A	PARTICIPANT	\N	PRESENT	0
10097	10092	11031D	PARTICIPANT	\N	PRESENT	0
10098	10092	08052W	PARTICIPANT	\N	PRESENT	0
10099	10092	04081K	PARTICIPANT	\N	EXCUSE	0
10100	10092	14217N	PARTICIPANT	\N	PRESENT	0
10101	10092	08041T	PARTICIPANT	\N	EXCUSE	0
10102	10092	14026U	PARTICIPANT	\N	EXCUSE	0
10103	10092	14213J	PARTICIPANT	\N	PRESENT	0
10104	10092	14223L	PARTICIPANT	\N	EXCUSE	0
10105	10092	04092N	PARTICIPANT	\N	EXCUSE	0
10106	10092	14071N	PARTICIPANT	\N	EXCUSE	0
10107	10092	04045F	PARTICIPANT	\N	PRESENT	0
10108	10092	11025F	PARTICIPANT	\N	PRESENT	0
10114	10111	05008E	PARTICIPANT	0	EXCUSE	0
10115	10111	11030C	PARTICIPANT	\N	PRESENT	0
10116	10111	11033F	PARTICIPANT	\N	PRESENT	0
10123	10111	11056N	PARTICIPANT	\N	EXCUSE	0
10125	10111	11035H	PARTICIPANT	\N	PRESENT	0
10126	10111	14041T	PARTICIPANT	\N	PRESENT	0
10127	10111	11113E	PARTICIPANT	\N	PRESENT	0
10128	10111	01024M	PARTICIPANT	\N	PRESENT	0
10129	10111	14215L	PARTICIPANT	\N	PRESENT	0
10131	10111	08018U	PARTICIPANT	\N	EXCUSE	0
10135	10111	95039L	PARTICIPANT	\N	PRESENT	0
10139	10111	04079R	PARTICIPANT	\N	PRESENT	0
10140	10111	14111D	PARTICIPANT	\N	PRESENT	0
10142	10111	14273W	PARTICIPANT	\N	PRESENT	0
10145	10111	14147R	PARTICIPANT	\N	EXCUSE	0
10148	10111	07034Q	PARTICIPANT	\N	PRESENT	0
10149	10111	04074L	PARTICIPANT	\N	PRESENT	0
3782	2824	07029T	PARTICIPANT	\N	PRESENT	0
3783	2824	10006L	PARTICIPANT	\N	PRESENT	0
10153	10111	01028R	PARTICIPANT	\N	PRESENT	0
4624	4622	14133K	PARTICIPANT	\N	PRESENT	0
4626	4622	04059M	PARTICIPANT	\N	PRESENT	0
10155	10111	04056J	PARTICIPANT	\N	PRESENT	0
4628	4622	01044R	PARTICIPANT	\N	PRESENT	0
4629	4622	08043V	PARTICIPANT	\N	PRESENT	0
10157	10111	04044E	PRESIDENT	0	PRESENT	0
5316	4401	14195A	PARTICIPANT	\N	PRESENT	0
5317	4401	01057W	PARTICIPANT	\N	PRESENT	0
5318	4401	98018T	PARTICIPANT	\N	PRESENT	0
5319	4401	14034U	PARTICIPANT	\N	PRESENT	0
5320	4401	04085P	PARTICIPANT	\N	PRESENT	0
5321	4401	14217N	PARTICIPANT	\N	PRESENT	0
5322	4401	14261S	PARTICIPANT	\N	PRESENT	0
5323	4401	11012A	PARTICIPANT	\N	PRESENT	0
5324	4401	14073Q	PARTICIPANT	\N	PRESENT	0
5325	4401	01016M	PARTICIPANT	\N	PRESENT	0
5326	4401	11036J	PARTICIPANT	\N	PRESENT	0
5327	4401	14065Q	PARTICIPANT	\N	PRESENT	0
5328	4401	05012A	PARTICIPANT	\N	PRESENT	0
5329	4401	14083S	PARTICIPANT	\N	PRESENT	0
5330	4401	14119M	PARTICIPANT	\N	PRESENT	0
5331	4401	08051V	PARTICIPANT	\N	PRESENT	0
5332	4401	08031R	PARTICIPANT	\N	PRESENT	0
5465	5402	08051V	PARTICIPANT	\N	PRESENT	0
5466	5402	07004J	PARTICIPANT	\N	PRESENT	0
5467	5402	14073Q	PARTICIPANT	\N	PRESENT	0
5468	5402	11012A	PARTICIPANT	\N	PRESENT	0
5469	5402	08031R	PARTICIPANT	\N	PRESENT	0
5470	5402	04080J	PARTICIPANT	\N	PRESENT	0
5471	5402	95062K	PARTICIPANT	\N	PRESENT	0
5472	5402	04049K	PARTICIPANT	\N	PRESENT	0
5473	5402	14031R	PARTICIPANT	\N	PRESENT	0
5474	5402	14038Y	PARTICIPANT	\N	PRESENT	0
5475	5402	04033B	PARTICIPANT	\N	PRESENT	0
5476	5402	98046X	PARTICIPANT	\N	PRESENT	0
5477	5402	11107G	PARTICIPANT	\N	PRESENT	0
5478	5402	01015L	PARTICIPANT	\N	PRESENT	0
5479	5402	14013P	PARTICIPANT	\N	PRESENT	0
5480	5402	01011G	PARTICIPANT	\N	PRESENT	0
5481	5402	04056J	PARTICIPANT	\N	PRESENT	0
5482	5402	01016M	PARTICIPANT	\N	PRESENT	0
5483	5402	14271U	PARTICIPANT	\N	PRESENT	0
5484	5402	98035U	PARTICIPANT	\N	PRESENT	0
5485	5402	11036J	PARTICIPANT	\N	PRESENT	0
5486	5402	14121F	PARTICIPANT	\N	PRESENT	0
5487	5402	08068F	PARTICIPANT	\N	PRESENT	0
5488	5402	11112D	PARTICIPANT	\N	PRESENT	0
5489	5402	11089X	PARTICIPANT	\N	PRESENT	0
5490	5402	04067M	PARTICIPANT	\N	PRESENT	0
5491	5402	14255U	PARTICIPANT	\N	PRESENT	0
5492	5402	11042G	PARTICIPANT	\N	PRESENT	0
5493	5402	11053K	PARTICIPANT	\N	PRESENT	0
5494	5402	04040A	PARTICIPANT	\N	PRESENT	0
5495	5402	14261S	PARTICIPANT	\N	PRESENT	0
5496	5402	01025N	PARTICIPANT	\N	PRESENT	0
5497	5402	92031P	PARTICIPANT	\N	PRESENT	0
5498	5402	01027Q	PARTICIPANT	\N	PRESENT	0
5499	5402	04036E	PARTICIPANT	\N	PRESENT	0
5500	5402	96004D	PARTICIPANT	\N	PRESENT	0
5501	5402	95015C	PARTICIPANT	\N	PRESENT	0
5502	5402	11088W	PARTICIPANT	\N	PRESENT	0
5503	5402	14217N	PARTICIPANT	\N	PRESENT	0
5504	5402	14041T	PARTICIPANT	\N	PRESENT	0
5505	5402	11100Y	PARTICIPANT	\N	PRESENT	0
5506	5402	04042C	PARTICIPANT	\N	PRESENT	0
5507	5402	04081K	PARTICIPANT	\N	PRESENT	0
5508	5402	14135M	PARTICIPANT	\N	PRESENT	0
5509	5402	11080N	PARTICIPANT	\N	PRESENT	0
5510	5402	07029T	PARTICIPANT	\N	PRESENT	0
5511	5402	11097X	PARTICIPANT	\N	PRESENT	0
5512	5402	14265W	PARTICIPANT	\N	PRESENT	0
5513	5402	04057K	PARTICIPANT	\N	PRESENT	0
5514	5402	14059S	PARTICIPANT	\N	PRESENT	0
5515	5402	07024N	PARTICIPANT	\N	PRESENT	0
5516	5402	11091R	PARTICIPANT	\N	PRESENT	0
5517	5402	95039L	PARTICIPANT	\N	PRESENT	0
5518	5402	95067Q	PARTICIPANT	\N	PRESENT	0
5519	5402	04048J	PARTICIPANT	\N	PRESENT	0
5520	5402	08034U	PARTICIPANT	\N	PRESENT	0
5521	5402	14259Y	PARTICIPANT	\N	PRESENT	0
5522	5402	04043D	PARTICIPANT	\N	PRESENT	0
5523	5402	05012A	PARTICIPANT	\N	PRESENT	0
5524	5402	98018T	PARTICIPANT	\N	PRESENT	0
5525	5402	14037X	PARTICIPANT	\N	PRESENT	0
5526	5402	04035D	PARTICIPANT	\N	PRESENT	0
5527	5402	11083R	PARTICIPANT	\N	PRESENT	0
5528	5402	11084S	PARTICIPANT	\N	PRESENT	0
5529	5402	08017T	PARTICIPANT	\N	PRESENT	0
5530	5402	04070G	PARTICIPANT	\N	PRESENT	0
5531	5402	11033F	PARTICIPANT	\N	PRESENT	0
5532	5402	11063M	PARTICIPANT	\N	PRESENT	0
5533	5402	11034G	PARTICIPANT	\N	PRESENT	0
5534	5402	04085P	PARTICIPANT	\N	PRESENT	0
5535	5402	11031D	PARTICIPANT	\N	PRESENT	0
5536	5402	11032E	PARTICIPANT	\N	PRESENT	0
5537	5402	04053F	PARTICIPANT	\N	PRESENT	0
5681	4446	11036J	PARTICIPANT	\N	EXCUSE	0
5682	4447	11036J	PARTICIPANT	\N	EXCUSE	0
5684	5683	14030Q	PARTICIPANT	\N	PRESENT	0
5692	5683	14217N	PARTICIPANT	\N	PRESENT	0
5686	5683	11029K	PARTICIPANT	\N	PRESENT	0
5687	5683	11031D	PARTICIPANT	\N	PRESENT	0
5689	5683	80013X	PARTICIPANT	\N	PRESENT	0
5691	5683	14041T	PARTICIPANT	\N	EXCUSE	0
5693	5683	11091R	PARTICIPANT	\N	EXCUSE	0
5695	5683	12042Y	PARTICIPANT	\N	EXCUSE	0
5696	5683	04035D	PARTICIPANT	\N	PRESENT	0
5697	5683	07026Q	PARTICIPANT	\N	PRESENT	0
5698	5683	95035G	PARTICIPANT	\N	EXCUSE	0
5700	5683	08069G	PARTICIPANT	\N	EXCUSE	0
5701	5683	09001P	PARTICIPANT	\N	PRESENT	0
5702	5683	08031R	PARTICIPANT	\N	PRESENT	0
5703	5683	14059S	PARTICIPANT	\N	PRESENT	0
5705	5683	11014C	PARTICIPANT	\N	EXCUSE	0
5706	5683	14109K	PARTICIPANT	\N	EXCUSE	0
5710	4446	01044R	PARTICIPANT	\N	EXCUSE	0
5711	4447	01044R	PARTICIPANT	\N	EXCUSE	0
5712	4237	01044R	PARTICIPANT	\N	EXCUSE	0
5713	4448	01044R	PARTICIPANT	\N	EXCUSE	0
5714	4234	01044R	PARTICIPANT	\N	EXCUSE	0
5870	4402	11077T	PARTICIPANT	0	PRESENT	0
5871	4402	04077P	PARTICIPANT	0	PRESENT	0
5872	4402	14257W	PARTICIPANT	0	PRESENT	0
5873	4402	04059M	PARTICIPANT	0	PRESENT	0
5874	4402	01057W	PARTICIPANT	0	PRESENT	0
5875	4402	87003B	PARTICIPANT	0	PRESENT	0
5876	4402	04049K	PARTICIPANT	0	PRESENT	0
5877	4402	14229S	PARTICIPANT	0	PRESENT	0
5878	4402	14038Y	PARTICIPANT	0	PRESENT	0
5879	4402	05012A	PARTICIPANT	0	PRESENT	0
5880	4402	04044E	PARTICIPANT	0	PRESENT	0
5881	4402	01056V	PARTICIPANT	0	PRESENT	0
5882	4402	04034C	PARTICIPANT	0	PRESENT	0
5883	4402	11039M	PARTICIPANT	0	PRESENT	0
5884	4402	11104D	PARTICIPANT	0	PRESENT	0
5885	4402	14083S	PARTICIPANT	0	PRESENT	0
5886	4402	92031P	PARTICIPANT	0	PRESENT	0
5887	4402	01024M	PARTICIPANT	0	PRESENT	0
5888	4402	07034Q	PARTICIPANT	0	PRESENT	0
5889	4402	11098Y	PARTICIPANT	0	PRESENT	0
5890	4402	08047A	PARTICIPANT	0	PRESENT	0
5891	4402	14031R	PARTICIPANT	0	PRESENT	0
5892	4402	04053F	PARTICIPANT	0	PRESENT	0
5893	4402	11063M	PARTICIPANT	0	PRESENT	0
5894	4402	01015L	PARTICIPANT	0	PRESENT	0
5895	4402	14235Q	PARTICIPANT	0	PRESENT	0
5896	4402	14215L	PARTICIPANT	0	PRESENT	0
5897	4402	14265W	PARTICIPANT	0	PRESENT	0
5898	4402	95063L	PARTICIPANT	0	PRESENT	0
5899	4402	14191V	PARTICIPANT	0	PRESENT	0
5900	4402	11012A	PARTICIPANT	0	PRESENT	0
5901	4402	08055A	PARTICIPANT	0	PRESENT	0
5902	4402	14231L	PARTICIPANT	0	PRESENT	0
5903	4402	14179A	PARTICIPANT	0	PRESENT	0
5904	4402	14273W	PARTICIPANT	0	PRESENT	0
5905	4402	01059Y	PARTICIPANT	0	PRESENT	0
5906	4402	14219Q	PARTICIPANT	0	PRESENT	0
5907	4402	95035G	PARTICIPANT	0	PRESENT	0
5908	4402	11056N	PARTICIPANT	0	PRESENT	0
5909	4402	04033B	PARTICIPANT	0	PRESENT	0
5910	4402	14193X	PARTICIPANT	0	PRESENT	0
5911	4402	01027Q	PARTICIPANT	0	PRESENT	0
5912	4402	04041B	PARTICIPANT	0	PRESENT	0
5913	4402	08041T	PARTICIPANT	0	PRESENT	0
5914	4402	14207L	PARTICIPANT	0	PRESENT	0
5915	4402	14109K	PARTICIPANT	0	PRESENT	0
5916	4402	08068F	PARTICIPANT	0	PRESENT	0
5917	4402	14147R	PARTICIPANT	0	PRESENT	0
5918	4402	11053K	PARTICIPANT	0	PRESENT	0
5919	4402	14187A	PARTICIPANT	0	PRESENT	0
5920	4402	10006L	PARTICIPANT	0	PRESENT	0
5921	4402	01003G	PARTICIPANT	0	PRESENT	0
5922	4402	14065Q	PARTICIPANT	0	PRESENT	0
5923	4402	11036J	PARTICIPANT	0	PRESENT	0
5924	4402	14267Y	PARTICIPANT	0	PRESENT	0
5925	4402	08065C	PARTICIPANT	0	PRESENT	0
5926	4402	04086Q	PARTICIPANT	0	PRESENT	0
5927	4402	08014Q	PARTICIPANT	0	PRESENT	0
5928	4402	04085P	PARTICIPANT	0	PRESENT	0
5929	4402	14211G	PARTICIPANT	0	PRESENT	0
5930	4402	07029T	PARTICIPANT	0	PRESENT	0
5931	4402	11100Y	PARTICIPANT	0	PRESENT	0
5932	4402	08010L	PARTICIPANT	0	PRESENT	0
5933	4402	08043V	PARTICIPANT	0	PRESENT	0
5934	4402	07032N	PARTICIPANT	0	PRESENT	0
5935	4402	01048V	PARTICIPANT	0	PRESENT	0
5936	4402	12041X	PARTICIPANT	0	PRESENT	0
5937	4402	14079W	PARTICIPANT	0	PRESENT	0
5938	4402	04067M	PARTICIPANT	0	PRESENT	0
5939	4402	14001X	PARTICIPANT	0	PRESENT	0
5940	4402	97011G	PARTICIPANT	0	PRESENT	0
5941	4402	08034U	PARTICIPANT	0	PRESENT	0
5942	4402	98029W	PARTICIPANT	0	PRESENT	0
5943	4402	08056B	PARTICIPANT	0	PRESENT	0
5944	4402	14255U	PARTICIPANT	0	PRESENT	0
5945	4402	11107G	PARTICIPANT	0	PRESENT	0
5946	4402	80027E	PARTICIPANT	0	PRESENT	0
5947	4402	14135M	PARTICIPANT	0	PRESENT	0
5948	4402	07004J	PARTICIPANT	0	PRESENT	0
5949	4402	04088S	PARTICIPANT	0	PRESENT	0
5950	4402	14069U	PARTICIPANT	0	PRESENT	0
5951	4402	86044G	PARTICIPANT	0	PRESENT	0
5952	4402	11094U	PARTICIPANT	0	PRESENT	0
5953	4402	11084S	PARTICIPANT	0	PRESENT	0
5954	4402	95062K	PARTICIPANT	0	PRESENT	0
5955	4402	14133K	PARTICIPANT	0	PRESENT	0
5956	4402	08039A	PARTICIPANT	0	PRESENT	0
5957	4402	11093T	PARTICIPANT	0	PRESENT	0
5958	4402	14037X	PARTICIPANT	0	PRESENT	0
5959	4402	14026U	PARTICIPANT	0	PRESENT	0
5960	4402	14034U	PARTICIPANT	0	PRESENT	0
5961	4402	14217N	PARTICIPANT	0	PRESENT	0
5962	4402	98050T	PARTICIPANT	0	PRESENT	0
5963	4402	14159V	PARTICIPANT	0	PRESENT	0
5964	4402	99004R	PARTICIPANT	0	PRESENT	0
5965	4402	01008M	PARTICIPANT	0	PRESENT	0
5966	4402	14201E	PARTICIPANT	0	PRESENT	0
5967	4402	01034P	PARTICIPANT	0	PRESENT	0
5968	4402	08038Y	PARTICIPANT	0	PRESENT	0
5969	4402	01007L	PARTICIPANT	0	PRESENT	0
5970	4402	14213J	PARTICIPANT	0	PRESENT	0
5971	4402	14199E	PARTICIPANT	0	PRESENT	0
5972	4402	04043D	PARTICIPANT	0	PRESENT	0
5973	4402	80013X	PARTICIPANT	0	PRESENT	0
5974	4402	04045F	PARTICIPANT	0	PRESENT	0
5975	4402	04081K	PARTICIPANT	0	PRESENT	0
5976	4402	14030Q	PARTICIPANT	0	PRESENT	0
5977	4402	04047H	PARTICIPANT	0	PRESENT	0
5978	4402	01043Q	PARTICIPANT	0	PRESENT	0
5979	4402	14073Q	PARTICIPANT	0	PRESENT	0
5980	4402	14205J	PARTICIPANT	0	PRESENT	0
5981	4402	89017R	PARTICIPANT	0	PRESENT	0
5982	4402	11103C	PARTICIPANT	0	PRESENT	0
5983	4402	11042G	PARTICIPANT	0	PRESENT	0
5984	4402	01016M	PARTICIPANT	0	PRESENT	0
5985	4402	14121F	PARTICIPANT	0	PRESENT	0
5986	4402	14061L	PARTICIPANT	0	PRESENT	0
5987	4402	11091R	PARTICIPANT	0	PRESENT	0
5988	4402	11043H	PARTICIPANT	0	PRESENT	0
5989	4402	11082Q	PARTICIPANT	0	PRESENT	0
5990	4402	08016S	PARTICIPANT	0	PRESENT	0
5991	4402	04056J	PARTICIPANT	0	PRESENT	0
5992	4402	14195A	PARTICIPANT	0	PRESENT	0
5993	4402	11067R	PARTICIPANT	0	PRESENT	0
5994	4402	01025N	PARTICIPANT	0	PRESENT	0
6042	4237	11036J	PARTICIPANT	\N	PRESENT	0
6000	5996	14013P	PARTICIPANT	\N	PRESENT	0
6001	5996	08068F	PARTICIPANT	\N	PRESENT	0
6002	5996	14207L	PARTICIPANT	\N	PRESENT	0
6003	5996	11101A	PARTICIPANT	\N	PRESENT	0
6006	5996	80013X	PARTICIPANT	\N	PRESENT	0
6007	5996	08038Y	PARTICIPANT	\N	PRESENT	0
6050	5660	11054L	PARTICIPANT	\N	PRESENT	0
6009	5996	14197C	PARTICIPANT	\N	PRESENT	0
6011	5996	14187A	PARTICIPANT	\N	PRESENT	0
6012	5996	14033T	PARTICIPANT	\N	PRESENT	0
6041	5996	14205J	PARTICIPANT	\N	EXCUSE	0
6016	5996	04049K	PARTICIPANT	\N	PRESENT	0
6018	5996	11111C	PARTICIPANT	\N	PRESENT	0
6019	5996	08015R	PARTICIPANT	\N	PRESENT	0
6020	5996	11100Y	PRESIDENT	0	PRESENT	0
6049	5660	89029V	PARTICIPANT	\N	PRESENT	0
6022	5996	11098Y	PARTICIPANT	\N	PRESENT	0
6045	4237	01058X	PARTICIPANT	\N	EXCUSE	0
6027	5996	14257W	PARTICIPANT	\N	PRESENT	0
6029	5996	04088S	PARTICIPANT	\N	PRESENT	0
6030	5996	98050T	PARTICIPANT	\N	PRESENT	0
6031	5996	11090Q	PARTICIPANT	\N	PRESENT	0
6033	5996	01058X	PARTICIPANT	\N	PRESENT	0
6034	5996	11094U	PARTICIPANT	\N	EXCUSE	0
6035	5996	11066Q	PARTICIPANT	\N	PRESENT	0
6051	5660	14207L	PARTICIPANT	\N	PRESENT	0
6052	5660	14109K	PARTICIPANT	\N	PRESENT	0
6053	5660	92020L	PARTICIPANT	\N	PRESENT	0
6054	5660	14225N	PARTICIPANT	\N	PRESENT	0
6055	5660	14085U	PARTICIPANT	\N	PRESENT	0
6056	5660	14159V	PARTICIPANT	\N	PRESENT	0
6057	5660	11033F	PARTICIPANT	\N	PRESENT	0
6058	5660	11029K	PARTICIPANT	\N	PRESENT	0
6059	5660	11037K	PARTICIPANT	\N	PRESENT	0
6060	5660	08021P	PARTICIPANT	\N	PRESENT	0
6061	5660	14103D	PARTICIPANT	\N	PRESENT	0
6062	5660	14205J	PARTICIPANT	\N	PRESENT	0
6063	5660	14063N	PARTICIPANT	\N	PRESENT	0
6064	5660	05008E	PARTICIPANT	\N	PRESENT	0
6065	5660	14179A	PARTICIPANT	\N	PRESENT	0
6066	5660	14275Y	PARTICIPANT	\N	PRESENT	0
6067	5660	14273W	PARTICIPANT	\N	PRESENT	0
6068	5660	14215L	PARTICIPANT	\N	PRESENT	0
6069	5660	14087W	PARTICIPANT	\N	PRESENT	0
6070	5660	04038G	PARTICIPANT	\N	PRESENT	0
6071	5660	14053L	PARTICIPANT	\N	PRESENT	0
6072	5660	14259Y	PARTICIPANT	\N	PRESENT	0
6073	5660	97011G	PARTICIPANT	\N	PRESENT	0
6074	5660	11103C	PARTICIPANT	\N	PRESENT	0
6075	5660	14147R	PARTICIPANT	\N	PRESENT	0
6076	5660	14111D	PARTICIPANT	\N	PRESENT	0
6077	5660	07032N	PARTICIPANT	\N	PRESENT	0
6078	5660	87003B	PARTICIPANT	\N	PRESENT	0
6079	5660	95062K	PARTICIPANT	\N	PRESENT	0
6080	5660	14013P	PARTICIPANT	\N	PRESENT	0
6081	5660	11040E	PARTICIPANT	\N	PRESENT	0
6082	5660	14263U	PARTICIPANT	\N	PRESENT	0
6083	5660	11098Y	PARTICIPANT	\N	PRESENT	0
6084	5660	14211G	PARTICIPANT	\N	PRESENT	0
6085	5660	98050T	PARTICIPANT	\N	PRESENT	0
6086	5660	95015C	PARTICIPANT	\N	PRESENT	0
6087	5660	08069G	PARTICIPANT	\N	PRESENT	0
6088	5660	01028R	PARTICIPANT	\N	PRESENT	0
6089	5660	01043Q	PARTICIPANT	\N	PRESENT	0
6090	5660	14221J	PARTICIPANT	\N	PRESENT	0
6091	5660	14031R	PARTICIPANT	\N	PRESENT	0
6093	5661	89029V	PARTICIPANT	\N	PRESENT	0
6094	5661	11054L	PARTICIPANT	\N	PRESENT	0
6095	5661	14207L	PARTICIPANT	\N	PRESENT	0
6096	5661	14109K	PARTICIPANT	\N	PRESENT	0
6097	5661	92020L	PARTICIPANT	\N	PRESENT	0
6098	5661	14225N	PARTICIPANT	\N	PRESENT	0
6099	5661	14085U	PARTICIPANT	\N	PRESENT	0
6100	5661	14159V	PARTICIPANT	\N	PRESENT	0
6101	5661	11033F	PARTICIPANT	\N	PRESENT	0
6102	5661	11029K	PARTICIPANT	\N	PRESENT	0
6103	5661	11037K	PARTICIPANT	\N	PRESENT	0
6104	5661	08021P	PARTICIPANT	\N	PRESENT	0
6105	5661	14103D	PARTICIPANT	\N	PRESENT	0
6106	5661	14205J	PARTICIPANT	\N	PRESENT	0
6107	5661	14063N	PARTICIPANT	\N	PRESENT	0
5648	5589	14133K	PARTICIPANT	\N	EXCUSE	0
5190	5144	04044E	PARTICIPANT	\N	PRESENT	0
5192	5144	95067Q	PARTICIPANT	\N	PRESENT	0
5193	5144	01047U	PARTICIPANT	\N	PRESENT	0
5649	5589	14089Y	PRESIDENT	0	PRESENT	0
5650	5589	08068F	PARTICIPANT	\N	PRESENT	0
5651	5589	01027Q	PARTICIPANT	\N	PRESENT	0
5652	5589	11112D	PARTICIPANT	\N	PRESENT	0
5653	5589	11099A	PARTICIPANT	\N	PRESENT	0
5654	5589	14031R	PARTICIPANT	\N	PRESENT	0
5655	5589	14028W	PARTICIPANT	\N	PRESENT	0
5656	5589	01016M	PARTICIPANT	\N	PRESENT	0
6108	5661	05008E	PARTICIPANT	\N	PRESENT	0
6109	5661	14179A	PARTICIPANT	\N	PRESENT	0
6110	5661	14275Y	PARTICIPANT	\N	PRESENT	0
6111	5661	14273W	PARTICIPANT	\N	PRESENT	0
6112	5661	14215L	PARTICIPANT	\N	PRESENT	0
6113	5661	14087W	PARTICIPANT	\N	PRESENT	0
6114	5661	04038G	PARTICIPANT	\N	PRESENT	0
6115	5661	14053L	PARTICIPANT	\N	PRESENT	0
6116	5661	14259Y	PARTICIPANT	\N	PRESENT	0
6117	5661	97011G	PARTICIPANT	\N	PRESENT	0
6118	5661	11103C	PARTICIPANT	\N	PRESENT	0
6119	5661	14147R	PARTICIPANT	\N	PRESENT	0
6120	5661	14111D	PARTICIPANT	\N	PRESENT	0
6121	5661	07032N	PARTICIPANT	\N	PRESENT	0
6122	5661	87003B	PARTICIPANT	\N	PRESENT	0
6123	5661	95062K	PARTICIPANT	\N	PRESENT	0
6124	5661	14013P	PARTICIPANT	\N	PRESENT	0
6125	5661	11040E	PARTICIPANT	\N	PRESENT	0
6126	5661	14263U	PARTICIPANT	\N	PRESENT	0
6127	5661	11098Y	PARTICIPANT	\N	PRESENT	0
6128	5661	14211G	PARTICIPANT	\N	PRESENT	0
6129	5661	98050T	PARTICIPANT	\N	PRESENT	0
6130	5661	95015C	PARTICIPANT	\N	PRESENT	0
6131	5661	08069G	PARTICIPANT	\N	PRESENT	0
6132	5661	01028R	PARTICIPANT	\N	PRESENT	0
6133	5661	01043Q	PARTICIPANT	\N	PRESENT	0
6134	5661	14221J	PARTICIPANT	\N	PRESENT	0
6135	5661	14031R	PARTICIPANT	\N	PRESENT	0
6136	5663	89029V	PARTICIPANT	\N	PRESENT	0
6137	5663	11054L	PARTICIPANT	\N	PRESENT	0
6138	5663	14207L	PARTICIPANT	\N	PRESENT	0
6139	5663	14109K	PARTICIPANT	\N	PRESENT	0
6140	5663	92020L	PARTICIPANT	\N	PRESENT	0
6141	5663	14225N	PARTICIPANT	\N	PRESENT	0
6142	5663	14085U	PARTICIPANT	\N	PRESENT	0
6143	5663	14159V	PARTICIPANT	\N	PRESENT	0
6144	5663	11033F	PARTICIPANT	\N	PRESENT	0
6145	5663	11029K	PARTICIPANT	\N	PRESENT	0
6146	5663	11037K	PARTICIPANT	\N	PRESENT	0
6147	5663	08021P	PARTICIPANT	\N	PRESENT	0
6148	5663	14103D	PARTICIPANT	\N	PRESENT	0
6149	5663	14205J	PARTICIPANT	\N	PRESENT	0
6150	5663	14063N	PARTICIPANT	\N	PRESENT	0
6151	5663	05008E	PARTICIPANT	\N	PRESENT	0
6152	5663	14179A	PARTICIPANT	\N	PRESENT	0
6153	5663	14275Y	PARTICIPANT	\N	PRESENT	0
6154	5663	14273W	PARTICIPANT	\N	PRESENT	0
6155	5663	14215L	PARTICIPANT	\N	PRESENT	0
6156	5663	14087W	PARTICIPANT	\N	PRESENT	0
6157	5663	04038G	PARTICIPANT	\N	PRESENT	0
6158	5663	14053L	PARTICIPANT	\N	PRESENT	0
6159	5663	14259Y	PARTICIPANT	\N	PRESENT	0
6160	5663	97011G	PARTICIPANT	\N	PRESENT	0
6161	5663	11103C	PARTICIPANT	\N	PRESENT	0
6162	5663	14147R	PARTICIPANT	\N	PRESENT	0
6163	5663	14111D	PARTICIPANT	\N	PRESENT	0
6164	5663	07032N	PARTICIPANT	\N	PRESENT	0
6165	5663	87003B	PARTICIPANT	\N	PRESENT	0
6166	5663	95062K	PARTICIPANT	\N	PRESENT	0
6167	5663	14013P	PARTICIPANT	\N	PRESENT	0
6168	5663	11040E	PARTICIPANT	\N	PRESENT	0
6169	5663	14263U	PARTICIPANT	\N	PRESENT	0
6170	5663	11098Y	PARTICIPANT	\N	PRESENT	0
5347	5342	11039M	PARTICIPANT	\N	PRESENT	0
6171	5663	14211G	PARTICIPANT	\N	PRESENT	0
5349	5342	08043V	PARTICIPANT	\N	PRESENT	0
5350	5342	14089Y	PARTICIPANT	\N	EXCUSE	0
6172	5663	98050T	PARTICIPANT	\N	PRESENT	0
5352	5342	11029K	PARTICIPANT	\N	PRESENT	0
5353	5342	95015C	PRESIDENT	0	PRESENT	0
6173	5663	95015C	PARTICIPANT	\N	PRESENT	0
5355	5342	08024S	PARTICIPANT	\N	EXCUSE	0
6174	5663	08069G	PARTICIPANT	\N	PRESENT	0
6175	5663	01028R	PARTICIPANT	\N	PRESENT	0
6176	5663	01043Q	PARTICIPANT	\N	PRESENT	0
5359	5342	11091R	PARTICIPANT	\N	PRESENT	0
5360	5342	87003B	PARTICIPANT	\N	PRESENT	0
6177	5663	14221J	PARTICIPANT	\N	PRESENT	0
6178	5663	14031R	PARTICIPANT	\N	PRESENT	0
6179	5663	14267Y	PARTICIPANT	\N	PRESENT	0
6180	5663	04056J	PARTICIPANT	\N	PRESENT	0
5365	5342	01037S	PARTICIPANT	\N	EXCUSE	0
6181	5663	95063L	PARTICIPANT	\N	PRESENT	0
6182	5663	14231L	PARTICIPANT	\N	PRESENT	0
5368	5342	11089X	PARTICIPANT	\N	PRESENT	0
6183	5663	14251Q	PARTICIPANT	\N	PRESENT	0
6184	5663	14033T	PARTICIPANT	\N	PRESENT	0
5371	5342	14179A	PARTICIPANT	\N	PRESENT	0
6185	5663	04088S	PARTICIPANT	\N	PRESENT	0
5373	5342	14241N	PARTICIPANT	\N	EXCUSE	0
6186	5663	14041T	PARTICIPANT	\N	PRESENT	0
5375	5342	14073Q	PARTICIPANT	\N	PRESENT	0
6187	5663	14105F	PARTICIPANT	\N	PRESENT	0
6188	5663	11084S	PARTICIPANT	\N	PRESENT	0
6189	5663	11026G	PARTICIPANT	\N	PRESENT	0
6190	5663	98018T	PARTICIPANT	\N	PRESENT	0
5380	5342	14059S	PARTICIPANT	\N	PRESENT	0
6191	5663	90003B	PARTICIPANT	\N	PRESENT	0
6192	5663	95035G	PARTICIPANT	\N	PRESENT	0
6193	5663	04047H	PARTICIPANT	\N	PRESENT	0
5384	5342	14063N	PARTICIPANT	\N	EXCUSE	0
5385	5342	04057K	PARTICIPANT	\N	PRESENT	0
5386	5342	11014C	PARTICIPANT	\N	EXCUSE	0
6194	5663	11042G	PARTICIPANT	\N	PRESENT	0
5388	5342	04070G	PRESIDENT	1	PRESENT	0
6195	5663	14187A	PARTICIPANT	\N	PRESENT	0
5390	5342	14191V	PARTICIPANT	\N	PRESENT	0
6197	5663	80013X	PARTICIPANT	\N	PRESENT	0
6198	5663	08014Q	PARTICIPANT	\N	PRESENT	0
6199	5663	14257W	PARTICIPANT	\N	PRESENT	0
6200	5664	89029V	PARTICIPANT	\N	PRESENT	0
6201	5664	14085U	PARTICIPANT	\N	PRESENT	0
6202	5664	11033F	PARTICIPANT	\N	PRESENT	0
6245	5664	14205J	PARTICIPANT	\N	PRESENT	0
6204	5664	14103D	PARTICIPANT	\N	PRESENT	0
6205	5664	14063N	PARTICIPANT	\N	PRESENT	0
6206	5664	05008E	PARTICIPANT	\N	PRESENT	0
6207	5664	14179A	PARTICIPANT	\N	PRESENT	0
6246	5664	14147R	PARTICIPANT	\N	PRESENT	0
6209	5664	14273W	PARTICIPANT	\N	PRESENT	0
6210	5664	14215L	PARTICIPANT	\N	PRESENT	0
6247	5664	01024M	PARTICIPANT	\N	PRESENT	0
6250	5664	14081Q	PARTICIPANT	\N	PRESENT	0
6248	5664	01003G	PARTICIPANT	\N	PRESENT	0
6214	5664	97011G	PARTICIPANT	\N	PRESENT	0
6215	5664	11103C	PARTICIPANT	\N	PRESENT	0
6249	5664	14079W	PARTICIPANT	\N	PRESENT	0
6217	5664	14013P	PARTICIPANT	\N	PRESENT	0
6244	5664	14159V	PARTICIPANT	\N	PRESENT	0
6251	5664	14229S	PARTICIPANT	\N	PRESENT	0
6220	5664	11098Y	PARTICIPANT	\N	PRESENT	0
6221	5664	14211G	PARTICIPANT	\N	PRESENT	0
6222	5664	01028R	PARTICIPANT	\N	PRESENT	0
6223	5664	01043Q	PARTICIPANT	\N	PRESENT	0
6243	5664	11056N	PARTICIPANT	\N	PRESENT	0
6252	5664	01061S	PARTICIPANT	\N	PRESENT	0
6253	5664	99004R	PARTICIPANT	\N	PRESENT	0
6254	5664	04047H	PARTICIPANT	\N	PRESENT	0
6228	5664	14033T	PARTICIPANT	\N	PRESENT	0
6229	5664	04088S	PARTICIPANT	\N	PRESENT	0
6230	5664	14041T	PARTICIPANT	\N	PRESENT	0
6231	5664	14105F	PARTICIPANT	\N	PRESENT	0
6232	5664	11084S	PARTICIPANT	\N	PRESENT	0
6233	5664	11026G	PARTICIPANT	\N	PRESENT	0
6255	5664	04085P	PARTICIPANT	\N	PRESENT	0
6256	5664	11012A	PARTICIPANT	\N	PRESENT	0
6236	5664	95035G	PARTICIPANT	\N	PRESENT	0
6257	5664	08018U	PARTICIPANT	\N	PRESENT	0
6238	5664	11042G	PARTICIPANT	\N	PRESENT	0
6239	5664	14187A	PARTICIPANT	\N	PRESENT	0
6240	5664	80013X	PARTICIPANT	\N	PRESENT	0
6258	5664	95063L	PARTICIPANT	\N	PRESENT	0
6242	5664	14257W	PARTICIPANT	\N	PRESENT	0
6259	5664	11034G	PARTICIPANT	\N	PRESENT	0
6260	5664	98050T	PARTICIPANT	\N	PRESENT	0
6261	5664	01048V	PARTICIPANT	\N	PRESENT	0
6262	5664	08039A	PARTICIPANT	\N	PRESENT	0
6263	5664	14197C	PARTICIPANT	\N	PRESENT	0
6264	5658	89029V	PARTICIPANT	0	PRESENT	0
6265	5658	14275Y	PARTICIPANT	0	PRESENT	0
6266	5658	14109K	PARTICIPANT	0	PRESENT	0
6267	5658	13002U	PARTICIPANT	0	PRESENT	0
6268	5658	14179A	PARTICIPANT	0	PRESENT	0
6269	5658	95035G	PARTICIPANT	0	PRESENT	0
6270	5658	01027Q	PARTICIPANT	0	PRESENT	0
6271	5658	14175V	PARTICIPANT	0	PRESENT	0
6272	5658	08043V	PARTICIPANT	0	PRESENT	0
6273	5658	14053L	PARTICIPANT	0	PRESENT	0
6274	5658	11061K	PARTICIPANT	0	PRESENT	0
6275	5658	14273W	PARTICIPANT	0	PRESENT	0
6276	5658	14089Y	PARTICIPANT	0	PRESENT	0
6277	5658	11057P	PARTICIPANT	0	PRESENT	0
6278	5658	14187A	PARTICIPANT	0	PRESENT	0
6279	5658	14197C	PARTICIPANT	0	PRESENT	0
6280	5658	04088S	PARTICIPANT	0	PRESENT	0
6281	5658	01007L	PARTICIPANT	0	PRESENT	0
6282	5658	08010L	PARTICIPANT	0	PRESENT	0
6283	5658	14033T	PARTICIPANT	0	PRESENT	0
6284	5658	14059S	PARTICIPANT	0	PRESENT	0
6285	5658	07004J	PARTICIPANT	0	PRESENT	0
6286	5658	08009T	PARTICIPANT	0	PRESENT	0
6287	5658	11039M	PARTICIPANT	0	PRESENT	0
6288	5658	11055M	PARTICIPANT	0	PRESENT	0
6289	5658	14199E	PARTICIPANT	0	PRESENT	0
6290	5664	92018S	PARTICIPANT	\N	PRESENT	0
6291	5664	11043H	PARTICIPANT	\N	PRESENT	0
6292	5664	14265W	PARTICIPANT	\N	PRESENT	0
6293	5664	08034U	PARTICIPANT	\N	PRESENT	0
6294	5664	11100Y	PARTICIPANT	\N	PRESENT	0
6295	5664	86044G	PARTICIPANT	\N	PRESENT	0
6296	5664	90003B	PARTICIPANT	\N	PRESENT	0
6297	5664	14109K	PARTICIPANT	\N	PRESENT	0
6298	5664	14097Y	PARTICIPANT	\N	PRESENT	0
6299	5664	95049N	PARTICIPANT	\N	PRESENT	0
6300	5664	14217N	PARTICIPANT	\N	PRESENT	0
6302	6301	01008M	PARTICIPANT	\N	PRESENT	0
6341	5664	14199E	PARTICIPANT	\N	PRESENT	0
6305	6301	14013P	PARTICIPANT	\N	PRESENT	0
6306	6301	08068F	PARTICIPANT	\N	PRESENT	0
6307	6301	14207L	PARTICIPANT	\N	PRESENT	0
6308	6301	11101A	PARTICIPANT	\N	PRESENT	0
6309	6301	90003B	PARTICIPANT	\N	PRESENT	0
6310	6301	08028W	PARTICIPANT	\N	PRESENT	0
6311	6301	80013X	PARTICIPANT	\N	PRESENT	0
6342	5664	14213J	PARTICIPANT	\N	PRESENT	0
6313	6301	04089T	PARTICIPANT	\N	PRESENT	0
6314	6301	14197C	PARTICIPANT	\N	PRESENT	0
6343	5664	08015R	PARTICIPANT	\N	PRESENT	0
6316	6301	14187A	PARTICIPANT	\N	PRESENT	0
6317	6301	14033T	PARTICIPANT	\N	PRESENT	0
6318	6301	14081Q	PARTICIPANT	\N	PRESENT	0
6319	6301	04048J	PARTICIPANT	\N	PRESENT	0
6320	6301	11099A	PARTICIPANT	\N	PRESENT	0
6321	6301	04049K	PARTICIPANT	\N	PRESENT	0
6344	5664	14263U	PARTICIPANT	\N	PRESENT	0
6324	6301	08015R	PARTICIPANT	\N	PRESENT	0
6325	6301	11100Y	PRESIDENT	0	PRESENT	0
6345	5664	11067R	PARTICIPANT	\N	PRESENT	0
6328	6301	01043Q	PARTICIPANT	\N	PRESENT	0
9987	9982	11054L	PARTICIPANT	\N	PRESENT	0
6330	6301	14205J	PARTICIPANT	\N	PRESENT	0
9988	9982	07024N	PARTICIPANT	\N	PRESENT	0
6332	6301	14257W	PARTICIPANT	\N	PRESENT	0
6333	6301	08021P	PARTICIPANT	\N	PRESENT	0
6334	6301	04088S	PARTICIPANT	\N	PRESENT	0
6335	6301	98050T	PARTICIPANT	\N	PRESENT	0
6338	6301	01058X	PARTICIPANT	\N	PRESENT	0
6339	6301	11094U	PARTICIPANT	\N	EXCUSE	0
6340	6301	11066Q	PARTICIPANT	\N	PRESENT	0
6346	5664	14121F	PARTICIPANT	\N	PRESENT	0
6347	5664	07034Q	PARTICIPANT	\N	PRESENT	0
6348	5664	14083S	PARTICIPANT	\N	PRESENT	0
6349	5664	08044W	PARTICIPANT	\N	PRESENT	0
6350	5664	08028W	PARTICIPANT	\N	PRESENT	0
6351	5664	01031L	PARTICIPANT	\N	PRESENT	0
6363	6362	14133K	PARTICIPANT	\N	EXCUSE	0
6553	6552	14263U	PARTICIPANT	\N	PRESENT	0
6365	6362	96004D	PRESIDENT	0	PRESENT	0
6514	6512	14093U	PARTICIPANT	\N	PRESENT	0
6367	6362	14089Y	PARTICIPANT	\N	PRESENT	0
6368	6362	90003B	PARTICIPANT	\N	PRESENT	0
6515	6512	14030Q	PARTICIPANT	\N	PRESENT	0
6517	6512	08060W	PARTICIPANT	\N	PRESENT	0
6372	6362	95030B	PARTICIPANT	\N	PRESENT	0
6373	6362	08018U	PARTICIPANT	\N	EXCUSE	0
6375	6362	11083R	PARTICIPANT	\N	PRESENT	0
6376	6362	14026U	PARTICIPANT	\N	PRESENT	0
6519	6512	11095V	PARTICIPANT	\N	PRESENT	0
6520	6512	14038Y	PARTICIPANT	\N	PRESENT	0
6379	6362	14097Y	PARTICIPANT	\N	PRESENT	0
9993	9982	99004R	PARTICIPANT	\N	PRESENT	0
6522	6512	98023Q	PARTICIPANT	\N	PRESENT	0
6382	6362	11026G	PARTICIPANT	\N	EXCUSE	0
6383	6362	98046X	PARTICIPANT	\N	PRESENT	0
6523	6512	11065P	PARTICIPANT	\N	PRESENT	0
6385	6362	04057K	PARTICIPANT	\N	PRESENT	0
6524	6512	14169X	PARTICIPANT	\N	PRESENT	0
6525	6512	01015L	PARTICIPANT	\N	PRESENT	0
6526	6512	14281W	PARTICIPANT	\N	PRESENT	0
6527	6512	11107G	PARTICIPANT	\N	PRESENT	0
6390	6362	04080J	PARTICIPANT	\N	EXCUSE	0
6391	6362	14135M	PARTICIPANT	\N	EXCUSE	0
6392	6362	01016M	PARTICIPANT	\N	PRESENT	0
6529	6512	02002K	PARTICIPANT	\N	PRESENT	0
6396	6362	04045F	PARTICIPANT	\N	PRESENT	0
6556	6552	04059M	PARTICIPANT	\N	PRESENT	0
6531	6512	04097T	PARTICIPANT	\N	PRESENT	0
9999	9982	11085T	PARTICIPANT	\N	PRESENT	0
10000	9982	04043D	PARTICIPANT	\N	PRESENT	0
6534	6512	14219Q	PARTICIPANT	\N	PRESENT	0
6535	6512	80027E	PARTICIPANT	\N	PRESENT	0
6536	6512	14031R	PARTICIPANT	\N	PRESENT	0
6537	6512	08009T	PRESIDENT	0	PRESENT	0
6538	6512	08062Y	PARTICIPANT	0	PRESENT	0
6539	6512	14221J	PARTICIPANT	\N	PRESENT	0
10001	9982	04067M	PARTICIPANT	\N	PRESENT	0
10002	9982	11063M	PARTICIPANT	\N	PRESENT	0
10003	9982	08031R	PARTICIPANT	\N	PRESENT	0
6543	6512	13002U	PARTICIPANT	\N	PRESENT	0
6544	6512	05012A	PARTICIPANT	\N	PRESENT	0
10004	9982	08043V	PARTICIPANT	\N	PRESENT	0
6546	6512	14135M	PARTICIPANT	\N	PRESENT	0
6547	6512	95062K	PARTICIPANT	\N	PRESENT	0
6548	6512	14107H	PARTICIPANT	\N	PRESENT	0
10005	9982	14037X	PARTICIPANT	\N	PRESENT	0
6550	6512	14157T	PARTICIPANT	\N	PRESENT	0
6551	6512	96003C	PARTICIPANT	\N	EXCUSE	0
10006	9982	04045F	PARTICIPANT	\N	PRESENT	0
6559	6552	08043V	PARTICIPANT	\N	PRESENT	0
6560	6552	14089Y	PARTICIPANT	\N	PRESENT	0
6561	6552	14105F	PARTICIPANT	\N	PRESENT	0
6562	6552	11029K	PARTICIPANT	\N	PRESENT	0
6563	6552	95015C	PARTICIPANT	\N	PRESENT	0
10007	9982	14255U	PARTICIPANT	\N	PRESENT	0
6565	6552	08024S	PARTICIPANT	\N	PRESENT	0
10008	9982	11103C	PARTICIPANT	\N	PRESENT	0
10009	9982	00003C	PARTICIPANT	\N	PRESENT	0
6568	6552	14079W	PARTICIPANT	\N	PRESENT	0
10010	9982	12042Y	PARTICIPANT	\N	PRESENT	0
6570	6552	87003B	PARTICIPANT	\N	PRESENT	0
10011	9982	04053F	PARTICIPANT	\N	PRESENT	0
6572	6552	14249W	PARTICIPANT	\N	PRESENT	0
10012	9982	04085P	PARTICIPANT	\N	PRESENT	0
6574	6552	01025N	PARTICIPANT	\N	PRESENT	0
6575	6552	01037S	PARTICIPANT	\N	PRESENT	0
6576	6552	89029V	PARTICIPANT	\N	PRESENT	0
6577	6552	08035V	PARTICIPANT	\N	PRESENT	0
6578	6552	11089X	PARTICIPANT	\N	PRESENT	0
6579	6552	07026Q	PARTICIPANT	\N	PRESENT	0
6580	6552	14123H	PARTICIPANT	\N	PRESENT	0
6581	6552	14179A	PARTICIPANT	\N	PRESENT	0
10013	9982	04056J	PARTICIPANT	\N	PRESENT	0
6583	6552	14241N	PARTICIPANT	\N	PRESENT	0
6584	6552	14061L	PARTICIPANT	\N	PRESENT	0
6585	6552	14073Q	PARTICIPANT	\N	PRESENT	0
6586	6552	08031R	PARTICIPANT	\N	PRESENT	0
10014	9982	11109J	PARTICIPANT	\N	PRESENT	0
6588	6552	08039A	PARTICIPANT	\N	PRESENT	0
10015	9982	14041T	PARTICIPANT	\N	PRESENT	0
10016	9982	95035G	PARTICIPANT	\N	PRESENT	0
10017	9982	04092N	PARTICIPANT	\N	PRESENT	0
10018	9982	08042U	PARTICIPANT	\N	PRESENT	0
10019	9982	08016S	PARTICIPANT	\N	PRESENT	0
10020	9982	89029V	PARTICIPANT	\N	PRESENT	0
10021	9982	14042U	PARTICIPANT	\N	PRESENT	0
6590	6552	14059S	PARTICIPANT	\N	PRESENT	0
6591	6552	08012N	PARTICIPANT	\N	PRESENT	0
6592	6552	14103D	PARTICIPANT	\N	PRESENT	0
6593	6552	11104D	PARTICIPANT	\N	PRESENT	0
6596	6552	11014C	PARTICIPANT	\N	PRESENT	0
6597	6552	14109K	PARTICIPANT	\N	PRESENT	0
6598	6552	04070G	PRESIDENT	0	PRESENT	0
6599	6552	92040Q	PARTICIPANT	\N	PRESENT	0
6602	6552	14235Q	PARTICIPANT	\N	EXCUSE	0
6611	6552	14038Y	PARTICIPANT	\N	PRESENT	0
6604	6552	04033B	PARTICIPANT	\N	PRESENT	0
6605	6552	14229S	PARTICIPANT	\N	PRESENT	0
6606	6552	11043H	PARTICIPANT	\N	PRESENT	0
6608	6552	92045V	PARTICIPANT	\N	PRESENT	0
6612	6552	01058X	PARTICIPANT	\N	PRESENT	0
6614	6613	89017R	PARTICIPANT	\N	PRESENT	0
6615	6613	01031L	PRESIDENT	0	PRESENT	0
6616	6613	01013J	PARTICIPANT	\N	PRESENT	0
6618	6613	11040E	PARTICIPANT	\N	PRESENT	0
6619	6613	08014Q	PARTICIPANT	\N	PRESENT	0
6621	6613	14175V	PARTICIPANT	\N	EXCUSE	0
6622	6613	14083S	PARTICIPANT	\N	PRESENT	0
6623	6613	11053K	PARTICIPANT	\N	PRESENT	0
6624	6613	14085U	PARTICIPANT	\N	PRESENT	0
6625	6613	11042G	PARTICIPANT	\N	PRESENT	0
6626	6613	04086Q	PARTICIPANT	\N	PRESENT	0
6627	6613	04055H	PARTICIPANT	\N	PRESENT	0
6628	6613	11070L	PARTICIPANT	\N	PRESENT	0
6629	6613	11088W	PARTICIPANT	\N	PRESENT	0
6630	6613	08034U	PARTICIPANT	\N	PRESENT	0
6631	6613	08011M	PARTICIPANT	\N	PRESENT	0
6632	6613	08022Q	PARTICIPANT	\N	PRESENT	0
6633	6613	01027Q	PARTICIPANT	\N	PRESENT	0
6634	6613	04071H	PARTICIPANT	\N	PRESENT	0
6635	6613	11074Q	PARTICIPANT	\N	PRESENT	0
6636	6613	98053W	PARTICIPANT	\N	EXCUSE	0
6637	6613	11083R	PARTICIPANT	\N	PRESENT	0
6638	6613	14199E	PARTICIPANT	\N	PRESENT	0
6639	6613	01057W	PARTICIPANT	\N	PRESENT	0
6640	6613	08016S	PARTICIPANT	\N	PRESENT	0
6641	6613	08069G	PARTICIPANT	\N	PRESENT	0
6642	6613	11048N	PARTICIPANT	\N	PRESENT	0
6643	6613	99004R	PARTICIPANT	\N	PRESENT	0
6644	6613	04061F	PARTICIPANT	\N	PRESENT	0
6645	6613	14159V	PARTICIPANT	\N	PRESENT	0
6646	6613	07029T	PARTICIPANT	\N	PRESENT	0
6648	6613	08010L	PARTICIPANT	\N	PRESENT	0
6649	6613	01048V	PARTICIPANT	\N	PRESENT	0
6650	6613	98046X	PARTICIPANT	\N	PRESENT	0
6652	6613	08073C	PARTICIPANT	\N	PRESENT	0
6653	6613	01016M	PARTICIPANT	\N	PRESENT	0
6695	6613	04034C	PARTICIPANT	\N	PRESENT	0
6696	6036	92018S	PARTICIPANT	\N	PRESENT	0
6697	6036	14215L	PARTICIPANT	\N	PRESENT	0
6698	6036	14259Y	PARTICIPANT	\N	PRESENT	0
6699	6036	04036E	PARTICIPANT	\N	PRESENT	0
6700	6036	92020L	PARTICIPANT	\N	PRESENT	0
6701	6036	14039A	PARTICIPANT	\N	PRESENT	0
6702	6036	11106F	PARTICIPANT	\N	PRESENT	0
6703	6036	14273W	PARTICIPANT	\N	PRESENT	0
6704	6036	04035D	PARTICIPANT	\N	PRESENT	0
6705	6036	98018T	PARTICIPANT	\N	PRESENT	0
6706	6036	07024N	PARTICIPANT	\N	PRESENT	0
6707	6036	11054L	PARTICIPANT	\N	PRESENT	0
6708	6036	04040A	PARTICIPANT	\N	PRESENT	0
6709	6036	11103C	PARTICIPANT	\N	PRESENT	0
6710	6036	95035G	PARTICIPANT	\N	PRESENT	0
6711	6036	11012A	PARTICIPANT	\N	PRESENT	0
6712	6036	07026Q	PARTICIPANT	\N	PRESENT	0
6713	6036	14257W	PARTICIPANT	\N	PRESENT	0
6714	6036	08014Q	PARTICIPANT	\N	PRESENT	0
6715	6036	01014K	PARTICIPANT	\N	PRESENT	0
6716	6036	08053X	PARTICIPANT	\N	PRESENT	0
6717	6036	11067R	PARTICIPANT	\N	PRESENT	0
6718	6036	08043V	PARTICIPANT	\N	PRESENT	0
6719	6036	08039A	PARTICIPANT	\N	PRESENT	0
6720	6036	14179A	PARTICIPANT	\N	PRESENT	0
6721	6036	01056V	PARTICIPANT	\N	PRESENT	0
6722	6036	08047A	PARTICIPANT	\N	PRESENT	0
6723	6036	14079W	PARTICIPANT	\N	PRESENT	0
6724	6036	95063L	PARTICIPANT	\N	PRESENT	0
6725	6036	95030B	PARTICIPANT	\N	PRESENT	0
6726	6036	07004J	PARTICIPANT	\N	PRESENT	0
6727	6036	14087W	PARTICIPANT	\N	PRESENT	0
6728	6036	14147R	PARTICIPANT	\N	PRESENT	0
6729	6036	14033T	PARTICIPANT	\N	PRESENT	0
6730	6036	04088S	PARTICIPANT	\N	PRESENT	0
6731	6036	14253S	PARTICIPANT	\N	PRESENT	0
6691	6613	14225N	PARTICIPANT	\N	PRESENT	0
6692	6613	11012A	PARTICIPANT	\N	PRESENT	0
6693	6613	11057P	PARTICIPANT	\N	PRESENT	0
6694	6613	14173T	PARTICIPANT	\N	PRESENT	0
6732	6036	14197C	PARTICIPANT	\N	PRESENT	0
6733	6036	98021N	PARTICIPANT	\N	PRESENT	0
6734	6036	04081K	PARTICIPANT	\N	PRESENT	0
6735	6036	95037J	PARTICIPANT	\N	PRESENT	0
6736	6036	14251Q	PARTICIPANT	\N	PRESENT	0
6737	6036	11053K	PARTICIPANT	\N	PRESENT	0
6738	6036	08058D	PARTICIPANT	\N	PRESENT	0
6739	6036	14265W	PARTICIPANT	\N	PRESENT	0
6740	6036	07029T	PARTICIPANT	\N	PRESENT	0
6741	6036	04077P	PARTICIPANT	\N	PRESENT	0
6742	6036	14207L	PARTICIPANT	\N	PRESENT	0
6743	6036	14038Y	PARTICIPANT	\N	PRESENT	0
6744	6036	95059Q	PARTICIPANT	\N	PRESENT	0
6745	6036	08034U	PARTICIPANT	\N	PRESENT	0
6746	6036	14231L	PARTICIPANT	\N	PRESENT	0
6747	6036	14219Q	PARTICIPANT	\N	PRESENT	0
6748	6036	11096W	PARTICIPANT	\N	PRESENT	0
6749	6036	11036J	PARTICIPANT	\N	PRESENT	0
6750	6036	14001X	PARTICIPANT	\N	PRESENT	0
6751	6036	08010L	PARTICIPANT	\N	PRESENT	0
6752	6036	95015C	PARTICIPANT	\N	PRESENT	0
6753	6036	14073Q	PARTICIPANT	\N	PRESENT	0
6754	6036	14103D	PARTICIPANT	\N	PRESENT	0
6755	6036	14089Y	PARTICIPANT	\N	PRESENT	0
6756	6036	01048V	PARTICIPANT	\N	PRESENT	0
6757	6036	14105F	PARTICIPANT	\N	PRESENT	0
6758	6036	14211G	PARTICIPANT	\N	PRESENT	0
6759	6036	14111D	PARTICIPANT	\N	PRESENT	0
6760	6036	14059S	PARTICIPANT	\N	PRESENT	0
6761	6036	11076S	PARTICIPANT	\N	PRESENT	0
6762	6036	01058X	PARTICIPANT	\N	PRESENT	0
6763	6036	11098Y	PARTICIPANT	\N	PRESENT	0
6764	6036	04097T	PARTICIPANT	\N	PRESENT	0
6765	6036	14267Y	PARTICIPANT	\N	PRESENT	0
6766	6036	08015R	PARTICIPANT	\N	PRESENT	0
6767	6036	11094U	PARTICIPANT	\N	PRESENT	0
6768	6036	14107H	PARTICIPANT	\N	PRESENT	0
6769	6036	86034E	PARTICIPANT	\N	PRESENT	0
6770	6036	11027H	PARTICIPANT	\N	PRESENT	0
6771	6036	14097Y	PARTICIPANT	\N	PRESENT	0
6772	6036	14247U	PARTICIPANT	\N	PRESENT	0
6773	6036	07032N	PARTICIPANT	\N	PRESENT	0
6774	6036	08062Y	PARTICIPANT	\N	PRESENT	0
6775	6036	14013P	PARTICIPANT	\N	PRESENT	0
6776	6036	14263U	PARTICIPANT	\N	PRESENT	0
6777	6036	98029W	PARTICIPANT	\N	PRESENT	0
6778	6036	98050T	PARTICIPANT	\N	PRESENT	0
6779	6036	97011G	PARTICIPANT	\N	PRESENT	0
6780	6036	86044G	PARTICIPANT	\N	PRESENT	0
6781	6036	14205J	PARTICIPANT	\N	PRESENT	0
6782	6036	14159V	PARTICIPANT	\N	PRESENT	0
6783	6036	96004D	PARTICIPANT	\N	PRESENT	0
6784	6036	04047H	PARTICIPANT	\N	PRESENT	0
6785	6036	14187A	PARTICIPANT	\N	PRESENT	0
6786	6552	92015P	PARTICIPANT	\N	EXCUSE	0
6787	6036	11066Q	PARTICIPANT	\N	PRESENT	0
6789	6036	14157T	PARTICIPANT	\N	PRESENT	0
6790	6036	14031R	PARTICIPANT	\N	PRESENT	0
6791	6036	01037S	PARTICIPANT	\N	PRESENT	0
6793	6788	14093U	PARTICIPANT	\N	PRESENT	0
6794	6788	14030Q	PARTICIPANT	\N	PRESENT	0
6796	6788	08060W	PARTICIPANT	\N	PRESENT	0
5403	5341	14133K	PARTICIPANT	\N	PRESENT	0
5404	5341	04054G	PARTICIPANT	\N	PRESENT	0
5405	5341	96004D	PARTICIPANT	\N	PRESENT	0
5406	5341	11040E	PARTICIPANT	\N	PRESENT	0
5407	5341	14089Y	PARTICIPANT	\N	PRESENT	0
6799	6788	14038Y	PARTICIPANT	\N	PRESENT	0
5409	5341	14079W	PARTICIPANT	\N	PRESENT	0
5410	5341	11035H	PARTICIPANT	\N	EXCUSE	0
5411	5341	14249W	PARTICIPANT	\N	EXCUSE	0
5412	5341	95030B	PARTICIPANT	\N	EXCUSE	0
5413	5341	08018U	PARTICIPANT	\N	EXCUSE	0
5414	5341	04035D	PARTICIPANT	\N	EXCUSE	0
5415	5341	11083R	PARTICIPANT	\N	PRESENT	0
5416	5341	14026U	PARTICIPANT	\N	EXCUSE	0
10022	9982	14271U	PARTICIPANT	\N	PRESENT	0
6801	6788	98023Q	PARTICIPANT	\N	PRESENT	0
5419	5341	14097Y	PARTICIPANT	\N	PRESENT	0
6802	6788	11065P	PARTICIPANT	\N	PRESENT	0
5421	5341	14073Q	PARTICIPANT	\N	PRESENT	0
5422	5341	11026G	PARTICIPANT	\N	PRESENT	0
5423	5341	98046X	PARTICIPANT	\N	PRESENT	0
6803	6788	14169X	PARTICIPANT	\N	PRESENT	0
6804	6788	01015L	PARTICIPANT	\N	PRESENT	0
6805	6788	14281W	PARTICIPANT	\N	PRESENT	0
5427	5341	08021P	PARTICIPANT	\N	EXCUSE	0
6806	6788	11107G	PARTICIPANT	\N	PRESENT	0
10024	9982	14281W	PARTICIPANT	\N	PRESENT	0
5430	5341	04080J	PARTICIPANT	\N	PRESENT	0
5431	5341	14135M	PARTICIPANT	\N	PRESENT	0
5432	5341	01016M	PARTICIPANT	\N	PRESENT	0
5433	5341	10015M	PARTICIPANT	\N	EXCUSE	0
5434	5341	11012A	PARTICIPANT	\N	PRESENT	0
6808	6788	02002K	PARTICIPANT	\N	PRESENT	0
10321	10320	14089Y	PRESIDENT	0	PRESENT	0
5437	5341	98035U	PARTICIPANT	\N	PRESENT	0
5438	5341	04034C	PARTICIPANT	\N	PRESENT	0
10159	10111	95067Q	PARTICIPANT	\N	PRESENT	0
10160	10111	01047U	PARTICIPANT	\N	PRESENT	0
10200	10092	11112D	PARTICIPANT	\N	EXCUSE	0
6812	6788	11059R	PARTICIPANT	\N	PRESENT	0
6813	6788	14219Q	PARTICIPANT	\N	PRESENT	0
6814	6788	80027E	PARTICIPANT	\N	PRESENT	0
6815	6788	14031R	PARTICIPANT	\N	PRESENT	0
6816	6788	08009T	PRESIDENT	1	PRESENT	0
6843	6036	99004R	PARTICIPANT	\N	PRESENT	0
10246	10111	10015M	PARTICIPANT	\N	EXCUSE	0
6842	6788	08062Y	PARTICIPANT	\N	PRESENT	0
6839	6036	14119M	PARTICIPANT	\N	PRESENT	0
10322	10320	90003B	PARTICIPANT	\N	PRESENT	0
6822	6788	13002U	PARTICIPANT	\N	PRESENT	0
6823	6788	05012A	PARTICIPANT	\N	PRESENT	0
6844	6036	95062K	PARTICIPANT	\N	PRESENT	0
6825	6788	14135M	PARTICIPANT	\N	PRESENT	0
6826	6788	95062K	PARTICIPANT	\N	PRESENT	0
6827	6788	14107H	PARTICIPANT	\N	PRESENT	0
10323	10320	01027Q	PARTICIPANT	\N	PRESENT	0
6829	6788	14157T	PARTICIPANT	\N	PRESENT	0
6830	6788	96003C	PARTICIPANT	\N	EXCUSE	0
6835	6036	14199E	PARTICIPANT	\N	PRESENT	0
6832	6036	14169X	PARTICIPANT	\N	PRESENT	0
6833	6036	11112D	PARTICIPANT	\N	PRESENT	0
6834	6036	11043H	PARTICIPANT	\N	PRESENT	0
6836	6036	14026U	PARTICIPANT	\N	PRESENT	0
6837	6036	04048J	PARTICIPANT	\N	PRESENT	0
6838	6036	90003B	PARTICIPANT	\N	PRESENT	0
10324	10320	11112D	PARTICIPANT	\N	PRESENT	0
6841	6036	08052W	PARTICIPANT	\N	PRESENT	0
6845	6036	01025N	PARTICIPANT	\N	PRESENT	0
6846	6036	14271U	PARTICIPANT	\N	PRESENT	0
6847	6036	04045F	PARTICIPANT	\N	PRESENT	0
6859	6036	01008M	PARTICIPANT	\N	PRESENT	0
6852	4446	01058X	PARTICIPANT	\N	PRESENT	0
6853	4446	04043D	PARTICIPANT	\N	PRESENT	0
5591	5538	05008E	PRESIDENT	0	PRESENT	0
5592	5538	11030C	PARTICIPANT	\N	PRESENT	0
6854	6036	01043Q	PARTICIPANT	\N	PRESENT	0
10325	10320	14205J	PARTICIPANT	\N	PRESENT	0
5596	5538	04047H	PARTICIPANT	\N	PRESENT	0
10326	10320	14031R	PARTICIPANT	\N	PRESENT	0
6855	6036	98035U	PARTICIPANT	\N	PRESENT	0
5599	5538	04038G	PARTICIPANT	\N	PRESENT	0
5600	5538	11056N	PARTICIPANT	\N	EXCUSE	0
6856	6036	13002U	PARTICIPANT	\N	PRESENT	0
10327	10320	08053X	PARTICIPANT	\N	PRESENT	0
10328	10320	01016M	PARTICIPANT	\N	PRESENT	0
6857	6036	14195A	PARTICIPANT	\N	PRESENT	0
10329	10320	14133K	PARTICIPANT	\N	EXCUSE	0
6860	6036	14213J	PARTICIPANT	\N	PRESENT	0
6861	6036	12042Y	PARTICIPANT	\N	PRESENT	0
6862	6036	04092N	PARTICIPANT	\N	PRESENT	0
5610	5538	01007L	PARTICIPANT	\N	PRESENT	0
5611	5538	11049P	PARTICIPANT	\N	PRESENT	0
10330	10320	08068F	PARTICIPANT	\N	EXCUSE	0
6863	6036	14281W	PARTICIPANT	\N	PRESENT	0
5614	5538	11084S	PARTICIPANT	\N	PRESENT	0
6864	6036	11061K	PARTICIPANT	\N	PRESENT	0
6865	6036	11033F	PARTICIPANT	\N	PRESENT	0
5617	5538	14111D	PARTICIPANT	\N	PRESENT	0
6866	6036	11088W	PARTICIPANT	\N	PRESENT	0
5619	5538	14273W	PARTICIPANT	\N	PRESENT	0
6868	6867	01008M	PARTICIPANT	\N	PRESENT	0
10331	10320	14237S	PARTICIPANT	\N	EXCUSE	0
5622	5538	14147R	PARTICIPANT	\N	PRESENT	0
6869	6867	11036J	PARTICIPANT	\N	PRESENT	0
10332	10320	14028W	PARTICIPANT	\N	EXCUSE	0
5625	5538	07034Q	PARTICIPANT	\N	PRESENT	0
10568	10552	01059Y	PARTICIPANT	\N	PRESENT	0
5627	5538	10015M	PARTICIPANT	\N	PRESENT	0
10569	10552	04081K	PARTICIPANT	\N	PRESENT	0
10570	10552	98024R	PARTICIPANT	\N	EXCUSE	0
5630	5538	01028R	PARTICIPANT	\N	PRESENT	0
5631	5538	98035U	PARTICIPANT	\N	PRESENT	0
6872	6867	08068F	PARTICIPANT	\N	PRESENT	0
6873	6867	14207L	PARTICIPANT	\N	PRESENT	0
10571	10552	10006L	PARTICIPANT	\N	PRESENT	0
6874	6867	11101A	PARTICIPANT	\N	PRESENT	0
5636	5538	95067Q	PARTICIPANT	\N	PRESENT	0
5637	5538	01047U	PARTICIPANT	\N	PRESENT	0
6875	6867	90003B	PARTICIPANT	\N	PRESENT	0
6876	6867	08028W	PARTICIPANT	\N	PRESENT	0
6877	6867	80013X	PARTICIPANT	\N	PRESENT	0
6878	6867	08038Y	PARTICIPANT	\N	PRESENT	0
6880	6867	14197C	PARTICIPANT	\N	PRESENT	0
10573	10552	14217N	PARTICIPANT	\N	PRESENT	0
6882	6867	14187A	PARTICIPANT	\N	PRESENT	0
6883	6867	14033T	PARTICIPANT	\N	PRESENT	0
6884	6867	14081Q	PARTICIPANT	\N	PRESENT	0
10553	10552	14239U	PARTICIPANT	\N	PRESENT	0
10554	10552	11055M	PARTICIPANT	\N	PRESENT	0
6887	6867	04049K	PARTICIPANT	\N	PRESENT	0
10555	10552	01046T	PARTICIPANT	\N	PRESENT	0
6889	6867	11111C	PARTICIPANT	\N	PRESENT	0
6890	6867	08015R	PARTICIPANT	\N	PRESENT	0
6891	6867	11100Y	PRESIDENT	0	PRESENT	0
10556	10552	04053F	PARTICIPANT	\N	PRESENT	0
6893	6867	11098Y	PARTICIPANT	\N	PRESENT	0
6894	6867	01043Q	PARTICIPANT	\N	PRESENT	0
10557	10552	14255U	PARTICIPANT	\N	PRESENT	0
6896	6867	14205J	PARTICIPANT	\N	PRESENT	0
6898	6867	14257W	PARTICIPANT	\N	PRESENT	0
6899	6867	08021P	PARTICIPANT	\N	EXCUSE	0
6900	6867	04088S	PARTICIPANT	\N	PRESENT	0
6901	6867	98050T	PARTICIPANT	\N	PRESENT	0
10559	10552	00003C	PARTICIPANT	\N	PRESENT	0
10560	10552	14053L	PARTICIPANT	\N	PRESENT	0
6904	6867	01058X	PARTICIPANT	\N	PRESENT	0
6905	6867	11094U	PARTICIPANT	\N	PRESENT	0
6906	6867	11066Q	PARTICIPANT	\N	PRESENT	0
6907	6037	92018S	PARTICIPANT	\N	PRESENT	0
6908	6037	14215L	PARTICIPANT	\N	PRESENT	0
6909	6037	04036E	PARTICIPANT	\N	PRESENT	0
6910	6037	92020L	PARTICIPANT	\N	PRESENT	0
6911	6037	11106F	PARTICIPANT	\N	PRESENT	0
6912	6037	14273W	PARTICIPANT	\N	PRESENT	0
6913	6037	04035D	PARTICIPANT	\N	PRESENT	0
6914	6037	07024N	PARTICIPANT	\N	PRESENT	0
6915	6037	11054L	PARTICIPANT	\N	PRESENT	0
6916	6037	04040A	PARTICIPANT	\N	PRESENT	0
6917	6037	95035G	PARTICIPANT	\N	PRESENT	0
6918	6037	11012A	PARTICIPANT	\N	PRESENT	0
6919	6037	07026Q	PARTICIPANT	\N	PRESENT	0
10561	10552	11103C	PARTICIPANT	\N	PRESENT	0
10563	10552	14195A	PARTICIPANT	\N	PRESENT	0
10564	10552	14267Y	PARTICIPANT	\N	PRESENT	0
10566	10552	11031D	PARTICIPANT	\N	PRESENT	0
10567	10552	08052W	PARTICIPANT	\N	PRESENT	0
5210	5209	96004D	PARTICIPANT	\N	PRESENT	0
5211	5209	14133K	PARTICIPANT	\N	PRESENT	0
5212	5209	14079W	PARTICIPANT	\N	PRESENT	0
5213	5209	11083R	PARTICIPANT	\N	PRESENT	0
5214	5209	14026U	PARTICIPANT	\N	PRESENT	0
5215	5209	14097Y	PARTICIPANT	\N	PRESENT	0
5216	5209	98046X	PARTICIPANT	\N	PRESENT	0
5217	5209	14001X	PARTICIPANT	\N	PRESENT	0
5218	5209	04080J	PARTICIPANT	\N	PRESENT	0
5219	5209	01016M	PARTICIPANT	\N	PRESENT	0
5220	5209	04045F	PARTICIPANT	\N	PRESENT	0
5221	5209	04034C	PARTICIPANT	\N	PRESENT	0
5223	5209	11035H	PARTICIPANT	\N	EXCUSE	0
5224	5209	14249W	PARTICIPANT	\N	EXCUSE	0
5225	5209	95030B	PARTICIPANT	\N	EXCUSE	0
5226	5209	08018U	PARTICIPANT	\N	EXCUSE	0
5227	5209	04035D	PARTICIPANT	\N	EXCUSE	0
5228	5209	04061F	PARTICIPANT	\N	EXCUSE	0
5229	5209	08021P	PARTICIPANT	\N	EXCUSE	0
5230	5209	10015M	PARTICIPANT	\N	EXCUSE	0
5400	5342	14038Y	PARTICIPANT	\N	PRESENT	0
5401	5342	01058X	PARTICIPANT	\N	PRESENT	0
5669	4234	83042R	PARTICIPANT	\N	EXCUSE	0
6920	6037	14257W	PARTICIPANT	\N	PRESENT	0
6921	6037	01014K	PARTICIPANT	\N	PRESENT	0
6922	6037	08053X	PARTICIPANT	\N	PRESENT	0
6923	6037	11067R	PARTICIPANT	\N	PRESENT	0
6924	6037	08039A	PARTICIPANT	\N	PRESENT	0
6925	6037	14179A	PARTICIPANT	\N	PRESENT	0
6926	6037	01056V	PARTICIPANT	\N	PRESENT	0
6927	6037	08047A	PARTICIPANT	\N	PRESENT	0
6928	6037	14079W	PARTICIPANT	\N	PRESENT	0
6929	6037	95063L	PARTICIPANT	\N	PRESENT	0
6930	6037	07004J	PARTICIPANT	\N	PRESENT	0
6931	6037	14033T	PARTICIPANT	\N	PRESENT	0
6932	6037	04088S	PARTICIPANT	\N	PRESENT	0
6933	6037	14253S	PARTICIPANT	\N	PRESENT	0
6934	6037	14197C	PARTICIPANT	\N	PRESENT	0
6935	6037	98021N	PARTICIPANT	\N	PRESENT	0
6936	6037	95037J	PARTICIPANT	\N	PRESENT	0
6937	6037	11053K	PARTICIPANT	\N	PRESENT	0
6938	6037	08058D	PARTICIPANT	\N	PRESENT	0
6939	6037	14265W	PARTICIPANT	\N	PRESENT	0
6940	6037	07029T	PARTICIPANT	\N	PRESENT	0
6941	6037	04077P	PARTICIPANT	\N	PRESENT	0
6942	6037	14207L	PARTICIPANT	\N	PRESENT	0
6943	6037	14038Y	PARTICIPANT	\N	PRESENT	0
6944	6037	95059Q	PARTICIPANT	\N	PRESENT	0
6945	6037	08034U	PARTICIPANT	\N	PRESENT	0
6946	6037	14231L	PARTICIPANT	\N	PRESENT	0
6947	6037	14219Q	PARTICIPANT	\N	PRESENT	0
6948	6037	11096W	PARTICIPANT	\N	PRESENT	0
6949	6037	11036J	PARTICIPANT	\N	PRESENT	0
6950	6037	14073Q	PARTICIPANT	\N	PRESENT	0
6951	6037	14103D	PARTICIPANT	\N	PRESENT	0
6952	6037	14089Y	PARTICIPANT	\N	PRESENT	0
6953	6037	14105F	PARTICIPANT	\N	PRESENT	0
6954	6037	14211G	PARTICIPANT	\N	PRESENT	0
6955	6037	11076S	PARTICIPANT	\N	PRESENT	0
6956	6037	11098Y	PARTICIPANT	\N	PRESENT	0
6957	6037	04097T	PARTICIPANT	\N	PRESENT	0
6958	6037	14267Y	PARTICIPANT	\N	PRESENT	0
6959	6037	08015R	PARTICIPANT	\N	PRESENT	0
6960	6037	11094U	PARTICIPANT	\N	PRESENT	0
6961	6037	14107H	PARTICIPANT	\N	PRESENT	0
6962	6037	86034E	PARTICIPANT	\N	PRESENT	0
6963	6037	11027H	PARTICIPANT	\N	PRESENT	0
6964	6037	14097Y	PARTICIPANT	\N	PRESENT	0
6965	6037	14247U	PARTICIPANT	\N	PRESENT	0
6966	6037	07032N	PARTICIPANT	\N	PRESENT	0
6967	6037	08062Y	PARTICIPANT	\N	PRESENT	0
6968	6037	14013P	PARTICIPANT	\N	PRESENT	0
6969	6037	14263U	PARTICIPANT	\N	PRESENT	0
6970	6037	98029W	PARTICIPANT	\N	PRESENT	0
6971	6037	98050T	PARTICIPANT	\N	PRESENT	0
6972	6037	97011G	PARTICIPANT	\N	PRESENT	0
6973	6037	14205J	PARTICIPANT	\N	PRESENT	0
6974	6037	14159V	PARTICIPANT	\N	PRESENT	0
6975	6037	96004D	PARTICIPANT	\N	PRESENT	0
6976	6037	04047H	PARTICIPANT	\N	PRESENT	0
6977	6037	14187A	PARTICIPANT	\N	PRESENT	0
6978	6037	11066Q	PARTICIPANT	\N	PRESENT	0
6979	6037	14157T	PARTICIPANT	\N	PRESENT	0
6980	6037	14031R	PARTICIPANT	\N	PRESENT	0
6981	6037	01037S	PARTICIPANT	\N	PRESENT	0
6982	6037	14169X	PARTICIPANT	\N	PRESENT	0
6983	6037	11112D	PARTICIPANT	\N	PRESENT	0
6984	6037	11043H	PARTICIPANT	\N	PRESENT	0
6985	6037	14199E	PARTICIPANT	\N	PRESENT	0
6986	6037	14026U	PARTICIPANT	\N	PRESENT	0
6987	6037	04048J	PARTICIPANT	\N	PRESENT	0
6988	6037	90003B	PARTICIPANT	\N	PRESENT	0
6989	6037	14119M	PARTICIPANT	\N	PRESENT	0
6990	6037	08052W	PARTICIPANT	\N	PRESENT	0
6991	6037	99004R	PARTICIPANT	\N	PRESENT	0
6992	6037	95062K	PARTICIPANT	\N	PRESENT	0
6993	6037	01025N	PARTICIPANT	\N	PRESENT	0
6994	6037	14271U	PARTICIPANT	\N	PRESENT	0
6995	6037	04045F	PARTICIPANT	\N	PRESENT	0
6996	6037	01043Q	PARTICIPANT	\N	PRESENT	0
6997	6037	98035U	PARTICIPANT	\N	PRESENT	0
6998	6037	13002U	PARTICIPANT	\N	PRESENT	0
6999	6037	14195A	PARTICIPANT	\N	PRESENT	0
7000	6037	01008M	PARTICIPANT	\N	PRESENT	0
7001	6037	14213J	PARTICIPANT	\N	PRESENT	0
7002	6037	12042Y	PARTICIPANT	\N	PRESENT	0
7003	6037	04092N	PARTICIPANT	\N	PRESENT	0
7004	6037	14281W	PARTICIPANT	\N	PRESENT	0
7005	6037	11061K	PARTICIPANT	\N	PRESENT	0
7006	6037	11033F	PARTICIPANT	\N	PRESENT	0
7007	6037	11088W	PARTICIPANT	\N	PRESENT	0
7008	6037	04038G	PARTICIPANT	\N	PRESENT	0
7009	6037	08068F	PARTICIPANT	\N	PRESENT	0
7010	6037	01011G	PARTICIPANT	\N	PRESENT	0
7011	6037	04056J	PARTICIPANT	\N	PRESENT	0
7012	6037	11029K	PARTICIPANT	\N	PRESENT	0
7013	6037	08051V	PARTICIPANT	\N	PRESENT	0
7014	6037	01047U	PARTICIPANT	\N	PRESENT	0
7015	6037	08016S	PARTICIPANT	\N	PRESENT	0
7016	6037	01015L	PARTICIPANT	\N	PRESENT	0
7017	6037	80013X	PARTICIPANT	\N	PRESENT	0
7018	6037	04055H	PARTICIPANT	\N	PRESENT	0
7019	6037	11032E	PARTICIPANT	\N	PRESENT	0
7020	6037	04066L	PARTICIPANT	\N	PRESENT	0
7021	6037	11100Y	PARTICIPANT	\N	PRESENT	0
7022	6037	04033B	PARTICIPANT	\N	PRESENT	0
7023	6037	04086Q	PARTICIPANT	\N	PRESENT	0
7024	6037	95039L	PARTICIPANT	\N	PRESENT	0
7025	6037	08022Q	PARTICIPANT	\N	PRESENT	0
7026	6037	11074Q	PARTICIPANT	\N	PRESENT	0
7027	6037	08012N	PARTICIPANT	\N	PRESENT	0
7028	6037	08031R	PARTICIPANT	\N	PRESENT	0
7029	6037	12041X	PARTICIPANT	\N	PRESENT	0
7030	6037	01013J	PARTICIPANT	\N	PRESENT	0
7031	6037	14083S	PARTICIPANT	\N	PRESENT	0
7032	6037	14042U	PARTICIPANT	\N	PRESENT	0
7033	6037	08009T	PARTICIPANT	\N	PRESENT	0
7034	6037	01034P	PARTICIPANT	\N	PRESENT	0
7035	6037	98046X	PARTICIPANT	\N	PRESENT	0
7036	6037	08018U	PARTICIPANT	\N	PRESENT	0
7037	6037	04071H	PARTICIPANT	\N	PRESENT	0
7038	6037	11064N	PARTICIPANT	\N	PRESENT	0
7039	6037	04054G	PARTICIPANT	\N	PRESENT	0
7040	6037	98022P	PARTICIPANT	\N	PRESENT	0
7041	6037	11107G	PARTICIPANT	\N	PRESENT	0
7042	6037	11083R	PARTICIPANT	\N	PRESENT	0
7043	6037	14241N	PARTICIPANT	\N	PRESENT	0
7044	6037	11097X	PARTICIPANT	\N	PRESENT	0
7045	6037	77002U	PARTICIPANT	\N	PRESENT	0
7046	6037	01007L	PARTICIPANT	\N	PRESENT	0
7047	6037	01028R	PARTICIPANT	\N	PRESENT	0
7048	6037	04061F	PARTICIPANT	\N	PRESENT	0
7049	6037	14030Q	PARTICIPANT	\N	PRESENT	0
7050	6037	08038Y	PARTICIPANT	\N	PRESENT	0
7051	6037	11063M	PARTICIPANT	\N	PRESENT	0
7052	6037	08011M	PARTICIPANT	\N	PRESENT	0
7053	6037	10015M	PARTICIPANT	\N	PRESENT	0
7054	6037	14217N	PARTICIPANT	\N	PRESENT	0
7055	6037	01019Q	PARTICIPANT	\N	PRESENT	0
7056	6037	14085U	PARTICIPANT	\N	PRESENT	0
7057	6037	01046T	PARTICIPANT	\N	PRESENT	0
7058	6037	11040E	PARTICIPANT	\N	PRESENT	0
7059	6037	01031L	PARTICIPANT	\N	PRESENT	0
7060	6037	04053F	PARTICIPANT	\N	PRESENT	0
7061	6037	04059M	PARTICIPANT	\N	PRESENT	0
7062	6037	14014Q	PARTICIPANT	\N	PRESENT	0
7063	6037	14061L	PARTICIPANT	\N	PRESENT	0
7064	6037	01057W	PARTICIPANT	\N	PRESENT	0
5721	4237	83042R	PARTICIPANT	\N	EXCUSE	0
5722	4446	83042R	PARTICIPANT	\N	EXCUSE	0
5723	4447	83042R	PARTICIPANT	\N	EXCUSE	0
5724	4448	83042R	PARTICIPANT	\N	EXCUSE	0
6196	4448	14263U	PARTICIPANT	\N	EXCUSE	0
7124	6037	14041T	PARTICIPANT	\N	PRESENT	0
7065	6037	01027Q	PARTICIPANT	\N	PRESENT	0
7066	6037	04057K	PARTICIPANT	\N	PRESENT	0
7067	6037	05008E	PARTICIPANT	\N	PRESENT	0
7068	6037	14225N	PARTICIPANT	\N	PRESENT	0
7069	6037	86044G	PARTICIPANT	\N	PRESENT	0
7070	6037	89017R	PARTICIPANT	\N	PRESENT	0
7071	6037	98018T	PARTICIPANT	\N	PRESENT	0
7072	6037	08073C	PARTICIPANT	\N	PRESENT	0
7073	6037	14059S	PARTICIPANT	\N	PRESENT	0
7074	6037	08010L	PARTICIPANT	\N	PRESENT	0
7075	6037	01048V	PARTICIPANT	\N	PRESENT	0
7076	6037	08014Q	PARTICIPANT	\N	PRESENT	0
7077	6037	11042G	PARTICIPANT	\N	PRESENT	0
7078	6037	14081Q	PARTICIPANT	\N	PRESENT	0
7079	6037	08024S	PARTICIPANT	\N	PRESENT	0
7080	6037	14034U	PARTICIPANT	\N	PRESENT	0
7081	4447	14209N	PARTICIPANT	\N	EXCUSE	0
7086	4447	11068S	PARTICIPANT	\N	PRESENT	0
7087	4447	01046T	PARTICIPANT	\N	EXCUSE	0
7089	4447	80013X	PARTICIPANT	\N	EXCUSE	0
7091	4447	14263U	PARTICIPANT	\N	EXCUSE	0
7092	4447	11089X	PARTICIPANT	\N	EXCUSE	0
7094	4447	08069G	PARTICIPANT	\N	EXCUSE	0
7096	4447	04061F	PARTICIPANT	\N	EXCUSE	0
7099	4447	08039A	PARTICIPANT	\N	EXCUSE	0
7103	4447	14221J	PARTICIPANT	\N	PRESENT	0
7104	4447	11082Q	PARTICIPANT	\N	PRESENT	0
7106	4447	01048V	PARTICIPANT	\N	EXCUSE	0
7107	6037	08025T	PARTICIPANT	\N	PRESENT	0
7110	4447	04043D	PARTICIPANT	\N	EXCUSE	0
7111	4447	01016M	PARTICIPANT	\N	EXCUSE	0
7112	4447	01058X	PARTICIPANT	\N	EXCUSE	0
7115	6037	04034C	PARTICIPANT	\N	PRESENT	0
7120	6037	01016M	PARTICIPANT	\N	PRESENT	0
10574	10552	14042U	PARTICIPANT	\N	PRESENT	0
7122	6037	14259Y	PARTICIPANT	\N	PRESENT	0
7182	6037	04070G	PARTICIPANT	\N	PRESENT	0
7183	6037	01003G	PARTICIPANT	\N	PRESENT	0
7127	7123	01046T	PARTICIPANT	\N	PRESENT	0
10575	10552	14151M	PARTICIPANT	\N	PRESENT	0
7129	7123	04053F	PARTICIPANT	\N	PRESENT	0
6456	6399	11076S	PARTICIPANT	\N	PRESENT	0
6457	6399	04054G	PARTICIPANT	\N	PRESENT	0
6458	6399	04040A	PARTICIPANT	\N	PRESENT	0
6459	6399	08058D	PARTICIPANT	\N	PRESENT	0
10576	10552	12042Y	PARTICIPANT	\N	PRESENT	0
6461	6399	77002U	PARTICIPANT	\N	PRESENT	0
6462	6399	98029W	PARTICIPANT	\N	PRESENT	0
10577	10552	14281W	PARTICIPANT	\N	PRESENT	0
6464	6399	11027H	PARTICIPANT	\N	PRESENT	0
6465	6399	98018T	PARTICIPANT	\N	PRESENT	0
6466	6399	92018S	PARTICIPANT	\N	PRESENT	0
6467	6399	86044G	PARTICIPANT	\N	PRESENT	0
6468	6399	92020L	PARTICIPANT	\N	PRESENT	0
6469	6399	95030B	PARTICIPANT	\N	PRESENT	0
7130	7123	14255U	PARTICIPANT	\N	PRESENT	0
10578	10552	14087W	PARTICIPANT	\N	PRESENT	0
6472	6399	97011G	PARTICIPANT	\N	PRESENT	0
6474	6399	04035D	PARTICIPANT	\N	PRESENT	0
6475	6399	07024N	PRESIDENT	1	PRESENT	0
10580	10552	14034U	PARTICIPANT	\N	PRESENT	0
10581	10552	14231L	PARTICIPANT	\N	PRESENT	0
10582	10552	11061K	PARTICIPANT	\N	PRESENT	0
6479	6399	07004J	PARTICIPANT	\N	PRESENT	0
10583	10552	08048B	PARTICIPANT	\N	PRESENT	0
10584	10552	08041T	PARTICIPANT	\N	PRESENT	0
6482	6399	14211G	PARTICIPANT	\N	PRESENT	0
6483	6399	98022P	PARTICIPANT	\N	PRESENT	0
6485	6399	95037J	PARTICIPANT	\N	PRESENT	0
10586	10552	14026U	PARTICIPANT	\N	PRESENT	0
6487	6399	14097Y	PARTICIPANT	\N	PRESENT	0
7133	7123	14053L	PARTICIPANT	\N	PRESENT	0
6489	6399	04036E	PARTICIPANT	\N	PRESENT	0
6490	6399	14039A	PARTICIPANT	\N	PRESENT	0
6491	6399	04077P	PARTICIPANT	\N	PRESENT	0
10587	10552	14213J	PARTICIPANT	\N	PRESENT	0
10588	10552	14121F	PARTICIPANT	\N	PRESENT	0
6494	6399	11106F	PARTICIPANT	\N	PRESENT	0
6495	6399	14251Q	PARTICIPANT	\N	PRESENT	0
6496	6399	83042R	PARTICIPANT	\N	PRESENT	0
7134	7123	11103C	PARTICIPANT	\N	PRESENT	0
6498	6399	11082Q	PARTICIPANT	\N	PRESENT	0
10589	10552	11112D	PARTICIPANT	\N	PRESENT	0
6500	6399	14253S	PARTICIPANT	\N	PRESENT	0
6501	6399	08047A	PARTICIPANT	\N	PRESENT	0
10590	10552	14037X	PARTICIPANT	\N	PRESENT	0
10591	10552	14018U	PARTICIPANT	\N	PRESENT	0
6504	6399	98021N	PARTICIPANT	\N	PRESENT	0
10592	10552	11067R	PARTICIPANT	\N	PRESENT	0
10593	10552	14223L	PARTICIPANT	\N	PRESENT	0
6507	6399	95059Q	PRESIDENT	0	PRESENT	0
6508	6399	01014K	PARTICIPANT	\N	PRESENT	0
6509	6399	11054L	PARTICIPANT	\N	PRESENT	0
6510	6399	01056V	PARTICIPANT	\N	PRESENT	0
6511	6399	92044U	PARTICIPANT	\N	PRESENT	0
10594	10552	04092N	PRESIDENT	0	PRESENT	0
7136	7123	14195A	PARTICIPANT	\N	PRESENT	0
7137	7123	14267Y	PARTICIPANT	\N	PRESENT	0
7138	7123	11023D	PARTICIPANT	\N	PRESENT	0
10595	10552	14265W	PARTICIPANT	\N	PRESENT	0
7140	7123	08052W	PARTICIPANT	\N	PRESENT	0
7141	7123	01059Y	PARTICIPANT	\N	PRESENT	0
7142	7123	04081K	PARTICIPANT	\N	PRESENT	0
7143	7123	98024R	PARTICIPANT	\N	PRESENT	0
10596	10552	14119M	PARTICIPANT	\N	PRESENT	0
10597	10552	14071N	PARTICIPANT	\N	PRESENT	0
7146	7123	14217N	PARTICIPANT	\N	PRESENT	0
7147	7123	14042U	PARTICIPANT	\N	PRESENT	0
7148	7123	14151M	PARTICIPANT	\N	EXCUSE	0
7149	7123	12042Y	PARTICIPANT	\N	PRESENT	0
7150	7123	14087W	PARTICIPANT	\N	PRESENT	0
10599	10552	04043D	PARTICIPANT	\N	PRESENT	0
7153	7123	14231L	PARTICIPANT	\N	PRESENT	0
10600	10552	14271U	PARTICIPANT	\N	PRESENT	0
7155	7123	08048B	PARTICIPANT	\N	PRESENT	0
7156	7123	08041T	PARTICIPANT	\N	EXCUSE	0
7157	7123	01011G	PARTICIPANT	\N	PRESENT	0
7158	7123	14026U	PARTICIPANT	\N	PRESENT	0
7159	7123	14213J	PARTICIPANT	\N	PRESENT	0
7160	7123	14121F	PARTICIPANT	\N	PRESENT	0
7161	7123	11112D	PARTICIPANT	\N	PRESENT	0
7162	7123	14037X	PARTICIPANT	\N	PRESENT	0
7163	7123	14018U	PARTICIPANT	\N	PRESENT	0
7164	7123	11067R	PARTICIPANT	\N	PRESENT	0
7165	7123	14223L	PARTICIPANT	\N	PRESENT	0
7166	7123	04092N	PRESIDENT	0	PRESENT	0
7167	7123	14265W	PARTICIPANT	\N	PRESENT	0
7168	7123	14119M	PARTICIPANT	\N	PRESENT	0
7169	7123	14071N	PARTICIPANT	\N	EXCUSE	0
7170	7123	07032N	PARTICIPANT	\N	PRESENT	0
7172	7123	14271U	PARTICIPANT	\N	PRESENT	0
10602	10552	11093T	PARTICIPANT	\N	PRESENT	0
10603	10552	11097X	PARTICIPANT	\N	PRESENT	0
7175	7123	11097X	PARTICIPANT	\N	PRESENT	0
7176	7123	04045F	PARTICIPANT	\N	PRESENT	0
10604	10552	04045F	PARTICIPANT	\N	PRESENT	0
7178	7123	01034P	PARTICIPANT	\N	EXCUSE	0
10605	10552	14227Q	PARTICIPANT	\N	PRESENT	0
7180	7123	11063M	PARTICIPANT	\N	PRESENT	0
10606	10552	01034P	PARTICIPANT	\N	PRESENT	0
10607	10552	11025F	PARTICIPANT	\N	PRESENT	0
8829	8062	14097Y	PARTICIPANT	\N	PRESENT	0
8830	8062	07032N	PARTICIPANT	\N	PRESENT	0
8831	8062	08041T	PARTICIPANT	\N	PRESENT	0
9008	8069	04038G	PARTICIPANT	\N	PRESENT	0
9009	8062	04095R	PARTICIPANT	\N	PRESENT	0
9010	8062	04047H	PARTICIPANT	\N	PRESENT	0
9011	8062	95039L	PARTICIPANT	\N	PRESENT	0
8836	8062	11090Q	PARTICIPANT	\N	PRESENT	0
9016	8062	14263U	PARTICIPANT	\N	PRESENT	0
9013	8062	04080J	PARTICIPANT	\N	PRESENT	0
8839	8062	14199E	PARTICIPANT	\N	PRESENT	0
9014	8062	11034G	PARTICIPANT	\N	PRESENT	0
8841	8062	08068F	PARTICIPANT	\N	PRESENT	0
9015	8062	14013P	PARTICIPANT	\N	PRESENT	0
9017	8062	11084S	PARTICIPANT	\N	PRESENT	0
9018	8062	92039X	PARTICIPANT	\N	PRESENT	0
9019	8062	01008M	PARTICIPANT	\N	PRESENT	0
9020	8062	98021N	PARTICIPANT	\N	PRESENT	0
9190	8065	08055A	PARTICIPANT	\N	PRESENT	0
8848	8062	14257W	PARTICIPANT	\N	PRESENT	0
9191	8065	04077P	PARTICIPANT	\N	PRESENT	0
9192	8065	11106F	PARTICIPANT	\N	PRESENT	0
8851	8062	95030B	PARTICIPANT	\N	PRESENT	0
9193	8065	01028R	PARTICIPANT	\N	PRESENT	0
9194	8065	14235Q	PARTICIPANT	\N	PRESENT	0
8854	8062	90003B	PARTICIPANT	\N	PRESENT	0
9195	8065	11056N	PARTICIPANT	\N	PRESENT	0
9196	8065	01059Y	PARTICIPANT	\N	PRESENT	0
8857	8062	14271U	PARTICIPANT	\N	PRESENT	0
8858	8062	13002U	PARTICIPANT	\N	PRESENT	0
8859	8062	04074L	PARTICIPANT	\N	PRESENT	0
8860	8062	11077T	PARTICIPANT	\N	PRESENT	0
8861	8062	04097T	PARTICIPANT	\N	PRESENT	0
9197	8065	14159V	PARTICIPANT	\N	PRESENT	0
8863	8062	11068S	PARTICIPANT	\N	PRESENT	0
8864	8062	86034E	PARTICIPANT	\N	PRESENT	0
8865	8062	11112D	PARTICIPANT	\N	PRESENT	0
8866	8062	14225N	PARTICIPANT	\N	PRESENT	0
8867	8062	11081P	PARTICIPANT	\N	PRESENT	0
8868	8062	01027Q	PARTICIPANT	\N	PRESENT	0
8869	8062	96004D	PARTICIPANT	\N	PRESENT	0
8870	8062	04042C	PARTICIPANT	\N	PRESENT	0
8871	8062	95067Q	PARTICIPANT	\N	PRESENT	0
8872	8062	11080N	PARTICIPANT	\N	PRESENT	0
8873	8062	04053F	PARTICIPANT	\N	PRESENT	0
8874	8062	92040Q	PARTICIPANT	\N	PRESENT	0
8875	8062	98035U	PARTICIPANT	\N	PRESENT	0
8876	8062	01013J	PARTICIPANT	\N	PRESENT	0
8877	8062	07026Q	PARTICIPANT	\N	PRESENT	0
8878	8062	04034C	PARTICIPANT	\N	PRESENT	0
8879	8062	11026G	PARTICIPANT	\N	PRESENT	0
8880	8062	11055M	PARTICIPANT	\N	PRESENT	0
8881	8062	98046X	PARTICIPANT	\N	PRESENT	0
8965	8069	14069U	PARTICIPANT	\N	PRESENT	0
8966	8069	04047H	PARTICIPANT	\N	PRESENT	0
9198	8065	11026G	PARTICIPANT	\N	PRESENT	0
9199	8065	92039X	PARTICIPANT	\N	PRESENT	0
9200	8065	92020L	PARTICIPANT	\N	PRESENT	0
8971	8069	14259Y	PARTICIPANT	\N	PRESENT	0
9201	8065	14079W	PARTICIPANT	\N	PRESENT	0
8973	8069	14041T	PARTICIPANT	\N	PRESENT	0
9202	8065	07004J	PARTICIPANT	\N	PRESENT	0
8975	8069	01024M	PARTICIPANT	\N	EXCUSE	0
8976	8069	14215L	PARTICIPANT	\N	PRESENT	0
9203	8065	80013X	PARTICIPANT	\N	PRESENT	0
8980	8069	01007L	PARTICIPANT	\N	PRESENT	0
8982	8069	95039L	PARTICIPANT	\N	PRESENT	0
9204	8065	01008M	PARTICIPANT	\N	PRESENT	0
8984	8069	11084S	PARTICIPANT	\N	PRESENT	0
8986	8069	04079R	PARTICIPANT	\N	PRESENT	0
9205	8065	07024N	PARTICIPANT	\N	PRESENT	0
8989	8069	14273W	PARTICIPANT	\N	PRESENT	0
9206	8065	98050T	PARTICIPANT	\N	PRESENT	0
9207	8065	04042C	PARTICIPANT	\N	PRESENT	0
9208	8065	97011G	PARTICIPANT	\N	PRESENT	0
9209	8065	04057K	PARTICIPANT	\N	PRESENT	0
8995	8069	07034Q	PARTICIPANT	\N	PRESENT	0
8996	8069	04074L	PARTICIPANT	\N	PRESENT	0
8997	8069	10015M	PARTICIPANT	\N	PRESENT	0
8998	8069	95063L	PARTICIPANT	\N	PRESENT	0
9000	8069	01028R	PARTICIPANT	\N	PRESENT	0
9001	8069	98035U	PARTICIPANT	\N	PRESENT	0
9210	8065	04088S	PARTICIPANT	\N	PRESENT	0
9211	8065	98018T	PARTICIPANT	\N	PRESENT	0
9004	8069	04044E	PRESIDENT	0	PRESENT	0
9212	8065	01027Q	PARTICIPANT	\N	PRESENT	0
9006	8069	95067Q	PARTICIPANT	\N	PRESENT	0
9213	8065	01056V	PARTICIPANT	\N	PRESENT	0
9214	8065	08068F	PARTICIPANT	\N	PRESENT	0
9215	8065	14033T	PARTICIPANT	\N	PRESENT	0
9216	8065	11012A	PARTICIPANT	\N	PRESENT	0
9217	8065	08062Y	PARTICIPANT	\N	PRESENT	0
9218	8065	14263U	PARTICIPANT	\N	PRESENT	0
9219	8065	08009T	PARTICIPANT	\N	PRESENT	0
9220	8065	14215L	PARTICIPANT	\N	PRESENT	0
9221	8063	08055A	PARTICIPANT	\N	PRESENT	0
9222	8063	04077P	PARTICIPANT	\N	PRESENT	0
9223	8063	11106F	PARTICIPANT	\N	PRESENT	0
9224	8063	01028R	PARTICIPANT	\N	PRESENT	0
9225	8063	14235Q	PARTICIPANT	\N	PRESENT	0
9226	8063	11056N	PARTICIPANT	\N	PRESENT	0
9227	8063	01059Y	PARTICIPANT	\N	PRESENT	0
9228	8063	14159V	PARTICIPANT	\N	PRESENT	0
9229	8063	11026G	PARTICIPANT	\N	PRESENT	0
9230	8063	92039X	PARTICIPANT	\N	PRESENT	0
9231	8063	92020L	PARTICIPANT	\N	PRESENT	0
9232	8063	14079W	PARTICIPANT	\N	PRESENT	0
9233	8063	07004J	PARTICIPANT	\N	PRESENT	0
9234	8063	80013X	PARTICIPANT	\N	PRESENT	0
9235	8063	01008M	PARTICIPANT	\N	PRESENT	0
9236	8063	07024N	PARTICIPANT	\N	PRESENT	0
9237	8063	98050T	PARTICIPANT	\N	PRESENT	0
9238	8063	04042C	PARTICIPANT	\N	PRESENT	0
9239	8063	97011G	PARTICIPANT	\N	PRESENT	0
9240	8063	04057K	PARTICIPANT	\N	PRESENT	0
9241	8063	04088S	PARTICIPANT	\N	PRESENT	0
9242	8063	98018T	PARTICIPANT	\N	PRESENT	0
9243	8063	01027Q	PARTICIPANT	\N	PRESENT	0
9244	8063	01056V	PARTICIPANT	\N	PRESENT	0
9245	8063	08068F	PARTICIPANT	\N	PRESENT	0
9246	8063	14033T	PARTICIPANT	\N	PRESENT	0
9247	8063	11012A	PARTICIPANT	\N	PRESENT	0
9248	8063	08062Y	PARTICIPANT	\N	PRESENT	0
9249	8063	14263U	PARTICIPANT	\N	PRESENT	0
9250	8063	08009T	PARTICIPANT	\N	PRESENT	0
9251	8063	14215L	PARTICIPANT	\N	PRESENT	0
9252	8063	14205J	PARTICIPANT	\N	PRESENT	0
9253	8063	14265W	PARTICIPANT	\N	PRESENT	0
9254	8063	14271U	PARTICIPANT	\N	PRESENT	0
9255	8063	14081Q	PARTICIPANT	\N	PRESENT	0
9256	8063	11067R	PARTICIPANT	\N	PRESENT	0
9257	8063	01014K	PARTICIPANT	\N	PRESENT	0
9258	8063	11081P	PARTICIPANT	\N	PRESENT	0
9259	8063	14217N	PARTICIPANT	\N	PRESENT	0
9260	8063	14195A	PARTICIPANT	\N	PRESENT	0
9261	8063	11114F	PARTICIPANT	\N	PRESENT	0
9262	8063	01022K	PARTICIPANT	\N	PRESENT	0
9263	8063	14051J	PARTICIPANT	\N	PRESENT	0
9264	8063	14097Y	PARTICIPANT	\N	PRESENT	0
9265	8063	14071N	PARTICIPANT	\N	PRESENT	0
9266	8063	14030Q	PARTICIPANT	\N	PRESENT	0
9267	8063	14273W	PARTICIPANT	\N	PRESENT	0
9268	8063	13002U	PARTICIPANT	\N	PRESENT	0
9269	8063	14259Y	PARTICIPANT	\N	PRESENT	0
9270	8063	14255U	PARTICIPANT	\N	PRESENT	0
9271	8063	11076S	PARTICIPANT	\N	PRESENT	0
9272	8063	14169X	PARTICIPANT	\N	PRESENT	0
9273	8063	14219Q	PARTICIPANT	\N	PRESENT	0
9274	8063	01016M	PARTICIPANT	\N	PRESENT	0
9282	8067	14079W	PARTICIPANT	\N	PRESENT	0
7362	5995	14013P	PARTICIPANT	\N	PRESENT	0
7363	5995	01013J	PARTICIPANT	\N	PRESENT	0
7364	5995	04054G	PARTICIPANT	\N	PRESENT	0
7365	5995	07026Q	PARTICIPANT	\N	PRESENT	0
7366	5995	11076S	PARTICIPANT	\N	PRESENT	0
7367	5995	14103D	PARTICIPANT	\N	PRESENT	0
7368	5995	98050T	PARTICIPANT	\N	PRESENT	0
7369	5995	11106F	PARTICIPANT	\N	PRESENT	0
7370	5995	04077P	PARTICIPANT	\N	PRESENT	0
7371	5995	14247U	PARTICIPANT	\N	PRESENT	0
7372	5995	01014K	PARTICIPANT	\N	PRESENT	0
7373	5995	04088S	PARTICIPANT	\N	PRESENT	0
7374	5995	14041T	PARTICIPANT	\N	PRESENT	0
7375	5995	04057K	PARTICIPANT	\N	PRESENT	0
7376	5995	04048J	PARTICIPANT	\N	PRESENT	0
7407	5995	14205J	PARTICIPANT	\N	PRESENT	0
7378	5995	07024N	PARTICIPANT	\N	PRESENT	0
7379	5995	95059Q	PARTICIPANT	\N	PRESENT	0
7380	5995	08034U	PARTICIPANT	\N	PRESENT	0
7381	5995	04035D	PARTICIPANT	\N	PRESENT	0
7382	5995	08047A	PARTICIPANT	\N	PRESENT	0
7383	5995	04036E	PARTICIPANT	\N	PRESENT	0
7384	5995	01056V	PARTICIPANT	\N	PRESENT	0
7385	5995	04033B	PARTICIPANT	\N	PRESENT	0
7386	5995	98021N	PARTICIPANT	\N	PRESENT	0
7387	5995	14253S	PARTICIPANT	\N	PRESENT	0
7406	5995	14033T	PARTICIPANT	\N	PRESENT	0
7408	5995	01057W	PARTICIPANT	\N	PRESENT	0
7409	5995	14265W	PARTICIPANT	\N	PRESENT	0
7410	5995	86044G	PARTICIPANT	\N	PRESENT	0
7411	5995	04040A	PARTICIPANT	\N	PRESENT	0
7412	5995	01024M	PARTICIPANT	\N	PRESENT	0
7413	5995	98018T	PARTICIPANT	\N	PRESENT	0
7414	5995	14219Q	PARTICIPANT	\N	PRESENT	0
7415	5995	14195A	PARTICIPANT	\N	PRESENT	0
7417	5995	11103C	PARTICIPANT	\N	PRESENT	0
7475	5995	11043H	PARTICIPANT	\N	PRESENT	0
7476	5995	92020L	PARTICIPANT	\N	PRESENT	0
7479	5995	11064N	PARTICIPANT	\N	PRESENT	0
7480	5995	92018S	PARTICIPANT	\N	PRESENT	0
7481	5995	14089Y	PARTICIPANT	\N	PRESENT	0
7482	5995	14083S	PARTICIPANT	\N	PRESENT	0
7483	5995	80013X	PARTICIPANT	\N	PRESENT	0
7716	7090	08053X	PARTICIPANT	\N	PRESENT	0
7717	7090	14207L	PARTICIPANT	\N	PRESENT	0
7718	7090	11048N	PARTICIPANT	\N	PRESENT	0
7719	7090	14063N	PARTICIPANT	\N	PRESENT	0
7720	7090	14159V	PARTICIPANT	\N	PRESENT	0
7721	7090	14033T	PARTICIPANT	\N	PRESENT	0
7722	7090	04088S	PARTICIPANT	\N	PRESENT	0
7723	7090	14013P	PARTICIPANT	\N	PRESENT	0
7724	7090	08073C	PARTICIPANT	\N	PRESENT	0
7725	7090	08031R	PARTICIPANT	\N	PRESENT	0
7726	7090	14135M	PARTICIPANT	\N	PRESENT	0
7727	7090	04043D	PARTICIPANT	\N	PRESENT	0
7728	7090	04077P	PARTICIPANT	\N	PRESENT	0
7729	7090	95030B	PARTICIPANT	\N	PRESENT	0
7730	7090	98018T	PARTICIPANT	\N	PRESENT	0
7731	7090	14199E	PARTICIPANT	\N	PRESENT	0
7732	7090	14259Y	PARTICIPANT	\N	PRESENT	0
7733	7090	92018S	PARTICIPANT	\N	PRESENT	0
7734	7090	07004J	PARTICIPANT	\N	PRESENT	0
7735	7090	07024N	PARTICIPANT	\N	PRESENT	0
7736	7090	04057K	PARTICIPANT	\N	PRESENT	0
7737	7090	08018U	PARTICIPANT	\N	PRESENT	0
7738	7090	14039A	PARTICIPANT	\N	PRESENT	0
7739	7090	14175V	PARTICIPANT	\N	PRESENT	0
7793	7116	04057K	PARTICIPANT	\N	PRESENT	0
7794	7116	80013X	PARTICIPANT	\N	PRESENT	0
7795	7116	14013P	PARTICIPANT	\N	PRESENT	0
7796	7116	14219Q	PARTICIPANT	\N	PRESENT	0
7797	7116	11098Y	PARTICIPANT	\N	PRESENT	0
7811	7116	98050T	PARTICIPANT	\N	PRESENT	0
7812	7116	11012A	PARTICIPANT	\N	PRESENT	0
7813	7116	11107G	PARTICIPANT	\N	PRESENT	0
7821	7118	08024S	PARTICIPANT	\N	PRESENT	0
7802	7116	95062K	PARTICIPANT	\N	PRESENT	0
7535	7084	04081K	PARTICIPANT	\N	PRESENT	0
7715	7090	11068S	PARTICIPANT	\N	PRESENT	0
7803	7116	14038Y	PARTICIPANT	\N	PRESENT	0
7804	7116	14159V	PARTICIPANT	\N	PRESENT	0
7805	7116	11071M	PARTICIPANT	\N	PRESENT	0
7806	7116	14033T	PARTICIPANT	\N	PRESENT	0
7814	7116	11065P	PARTICIPANT	\N	PRESENT	0
7360	5995	04081K	PARTICIPANT	\N	PRESENT	0
7361	5995	11054L	PARTICIPANT	\N	PRESENT	0
7808	7116	01003G	PARTICIPANT	\N	PRESENT	0
7809	7116	01015L	PARTICIPANT	\N	PRESENT	0
7815	7116	92039X	PARTICIPANT	\N	PRESENT	0
7816	7116	13002U	PARTICIPANT	\N	PRESENT	0
7817	7116	14175V	PARTICIPANT	\N	PRESENT	0
7818	7116	11048N	PARTICIPANT	\N	PRESENT	0
7819	7116	11100Y	PARTICIPANT	\N	PRESENT	0
7820	7116	08051V	PARTICIPANT	\N	PRESENT	0
7822	7118	14107H	PARTICIPANT	\N	PRESENT	0
7823	7118	04057K	PARTICIPANT	\N	PRESENT	0
7824	7118	80013X	PARTICIPANT	\N	PRESENT	0
7825	7118	14013P	PARTICIPANT	\N	PRESENT	0
7826	7118	14219Q	PARTICIPANT	\N	PRESENT	0
7827	7118	11098Y	PARTICIPANT	\N	PRESENT	0
7828	7118	95062K	PARTICIPANT	\N	PRESENT	0
7829	7118	14038Y	PARTICIPANT	\N	PRESENT	0
7830	7118	14159V	PARTICIPANT	\N	PRESENT	0
7831	7118	11071M	PARTICIPANT	\N	PRESENT	0
7832	7118	14033T	PARTICIPANT	\N	PRESENT	0
7833	7118	01003G	PARTICIPANT	\N	PRESENT	0
7834	7118	01015L	PARTICIPANT	\N	PRESENT	0
7835	7118	98050T	PARTICIPANT	\N	PRESENT	0
7836	7118	11012A	PARTICIPANT	\N	PRESENT	0
7837	7118	11107G	PARTICIPANT	\N	PRESENT	0
7838	7118	11065P	PARTICIPANT	\N	PRESENT	0
7839	7118	92039X	PARTICIPANT	\N	PRESENT	0
7840	7118	13002U	PARTICIPANT	\N	PRESENT	0
7841	7118	14175V	PARTICIPANT	\N	PRESENT	0
7842	7118	11048N	PARTICIPANT	\N	PRESENT	0
7843	7118	11100Y	PARTICIPANT	\N	PRESENT	0
7844	7118	08051V	PARTICIPANT	\N	PRESENT	0
7845	7118	08042U	PARTICIPANT	\N	PRESENT	0
7846	7118	08016S	PARTICIPANT	\N	PRESENT	0
7876	7119	08009T	PARTICIPANT	\N	PRESENT	0
7848	7119	14107H	PARTICIPANT	\N	PRESENT	0
7877	7119	11048N	PARTICIPANT	\N	PRESENT	0
7791	7116	08024S	PARTICIPANT	\N	PRESENT	0
7792	7116	14107H	PARTICIPANT	\N	PRESENT	0
7850	7119	80013X	PARTICIPANT	\N	PRESENT	0
7851	7119	14013P	PARTICIPANT	\N	PRESENT	0
7852	7119	14219Q	PARTICIPANT	\N	PRESENT	0
7853	7119	11098Y	PARTICIPANT	\N	PRESENT	0
7878	7119	08016S	PARTICIPANT	\N	PRESENT	0
7879	7119	01003G	PARTICIPANT	\N	PRESENT	0
7856	7119	14159V	PARTICIPANT	\N	PRESENT	0
7885	7883	11036J	PARTICIPANT	\N	EXCUSE	0
7860	7119	01015L	PARTICIPANT	\N	PRESENT	0
7861	7119	98050T	PARTICIPANT	\N	PRESENT	0
7862	7119	11012A	PARTICIPANT	\N	PRESENT	0
7863	7119	11107G	PARTICIPANT	\N	PRESENT	0
7864	7119	11065P	PARTICIPANT	\N	PRESENT	0
7865	7119	92039X	PARTICIPANT	\N	PRESENT	0
7866	7119	13002U	PARTICIPANT	\N	PRESENT	0
7867	7119	14175V	PARTICIPANT	\N	PRESENT	0
7887	7883	14013P	PARTICIPANT	\N	PRESENT	0
7871	7119	08042U	PARTICIPANT	\N	PRESENT	0
7890	7883	11101A	PARTICIPANT	\N	EXCUSE	0
7873	7119	04066L	PARTICIPANT	\N	PRESENT	0
7874	7119	11100Y	PARTICIPANT	\N	PRESENT	0
7875	7119	95062K	PARTICIPANT	\N	PRESENT	0
7891	7883	90003B	PARTICIPANT	\N	EXCUSE	0
7893	7883	80013X	PARTICIPANT	\N	PRESENT	0
7899	7883	14033T	PARTICIPANT	\N	PRESENT	0
7907	7883	11100Y	PRESIDENT	0	PRESENT	0
7909	7883	11098Y	PARTICIPANT	\N	PRESENT	0
7942	7881	92039X	PARTICIPANT	\N	PRESENT	0
7984	7881	14061L	PARTICIPANT	\N	PRESENT	0
7945	7943	14093U	PARTICIPANT	\N	PRESENT	0
7946	7943	14030Q	PARTICIPANT	\N	EXCUSE	0
7917	7883	98050T	PARTICIPANT	\N	PRESENT	0
7985	7881	99004R	PARTICIPANT	\N	PRESENT	0
8026	7986	01015L	PARTICIPANT	\N	PRESENT	0
8072	8071	89017R	PARTICIPANT	\N	PRESENT	0
8073	8071	01031L	PRESIDENT	0	PRESENT	0
7951	7943	14038Y	PARTICIPANT	\N	PRESENT	0
7923	7881	08024S	PARTICIPANT	\N	PRESENT	0
7924	7881	13002U	PARTICIPANT	\N	PRESENT	0
7925	7881	80013X	PARTICIPANT	\N	PRESENT	0
7926	7881	14107H	PARTICIPANT	\N	PRESENT	0
7927	7881	11107G	PARTICIPANT	\N	PRESENT	0
7928	7881	14039A	PARTICIPANT	\N	PRESENT	0
7929	7881	11098Y	PARTICIPANT	\N	PRESENT	0
7930	7881	01015L	PARTICIPANT	\N	PRESENT	0
7931	7881	11012A	PARTICIPANT	\N	PRESENT	0
7932	7881	09001P	PARTICIPANT	\N	PRESENT	0
7933	7881	98050T	PARTICIPANT	\N	PRESENT	0
7934	7881	11100Y	PARTICIPANT	\N	PRESENT	0
7935	7881	08042U	PARTICIPANT	\N	PRESENT	0
7936	7881	08009T	PARTICIPANT	\N	PRESENT	0
7937	7881	11112D	PARTICIPANT	\N	PRESENT	0
7938	7881	95062K	PARTICIPANT	\N	PRESENT	0
7939	7881	14219Q	PARTICIPANT	\N	PRESENT	0
7940	7881	14159V	PARTICIPANT	\N	PRESENT	0
7941	7881	11065P	PARTICIPANT	\N	PRESENT	0
8074	8071	11040E	PARTICIPANT	\N	PRESENT	0
8075	8071	14083S	PARTICIPANT	\N	PRESENT	0
8076	8071	11053K	PARTICIPANT	\N	PRESENT	0
7955	7943	14169X	PARTICIPANT	\N	PRESENT	0
7956	7943	01015L	PARTICIPANT	\N	PRESENT	0
8077	8071	04086Q	PARTICIPANT	\N	PRESENT	0
7958	7943	11107G	PARTICIPANT	\N	PRESENT	0
8078	8071	11088W	PARTICIPANT	\N	PRESENT	0
8079	8071	01027Q	PARTICIPANT	\N	PRESENT	0
7961	7943	01022K	PARTICIPANT	\N	EXCUSE	0
8080	8071	04071H	PARTICIPANT	\N	PRESENT	0
8081	8071	11074Q	PARTICIPANT	\N	PRESENT	0
7998	7986	11065P	PARTICIPANT	\N	PRESENT	0
8082	8071	98053W	PARTICIPANT	\N	EXCUSE	0
8083	8071	14199E	PARTICIPANT	\N	PRESENT	0
7967	7943	14031R	PARTICIPANT	\N	PRESENT	0
7968	7943	08009T	PRESIDENT	0	PRESENT	0
8001	7986	11107G	PARTICIPANT	\N	PRESENT	0
7970	7943	14221J	PARTICIPANT	\N	EXCUSE	0
7971	7943	92039X	PARTICIPANT	\N	PRESENT	0
7972	7943	08042U	PARTICIPANT	\N	PRESENT	0
8084	8071	99004R	PARTICIPANT	\N	PRESENT	0
7974	7943	13002U	PARTICIPANT	\N	PRESENT	0
7975	7943	05012A	PARTICIPANT	\N	PRESENT	0
8085	8071	04061F	PARTICIPANT	\N	PRESENT	0
7977	7943	14135M	PARTICIPANT	\N	PRESENT	0
7978	7943	95062K	PARTICIPANT	\N	PRESENT	0
7979	7943	14107H	PARTICIPANT	\N	PRESENT	0
8086	8071	14159V	PARTICIPANT	\N	PRESENT	0
8087	8071	07029T	PARTICIPANT	\N	PRESENT	0
7982	7943	96003C	PARTICIPANT	\N	EXCUSE	0
7983	7881	01003G	PARTICIPANT	\N	PRESENT	0
8006	7986	09001P	PARTICIPANT	\N	PRESENT	0
8088	8071	08010L	PARTICIPANT	\N	PRESENT	0
8008	7986	14219Q	PARTICIPANT	\N	PRESENT	0
8090	8071	08011M	PARTICIPANT	\N	EXCUSE	0
8130	8071	08061X	PARTICIPANT	\N	PRESENT	0
8011	7986	08009T	PRESIDENT	0	PRESENT	0
8131	8071	01016M	PARTICIPANT	\N	PRESENT	0
8132	8071	14225N	PARTICIPANT	\N	PRESENT	0
8014	7986	92039X	PARTICIPANT	\N	PRESENT	0
8015	7986	08042U	PARTICIPANT	\N	PRESENT	0
8133	8071	11012A	PARTICIPANT	\N	EXCUSE	0
8017	7986	13002U	PARTICIPANT	\N	PRESENT	0
8134	8071	14173T	PARTICIPANT	\N	PRESENT	0
8135	8071	04034C	PARTICIPANT	\N	EXCUSE	0
8189	8188	01008M	PARTICIPANT	\N	PRESENT	0
8021	7986	95062K	PARTICIPANT	\N	PRESENT	0
8022	7986	14107H	PARTICIPANT	\N	PRESENT	0
8278	8188	08068F	PARTICIPANT	\N	EXCUSE	0
8192	8188	11036J	PARTICIPANT	\N	EXCUSE	0
8351	8061	08009T	PARTICIPANT	\N	PRESENT	0
8195	8188	14013P	PARTICIPANT	\N	PRESENT	0
8345	8061	98021N	PARTICIPANT	\N	PRESENT	0
8349	8061	08068F	PARTICIPANT	\N	PRESENT	0
8198	8188	11101A	PARTICIPANT	\N	PRESENT	0
8199	8188	90003B	PARTICIPANT	\N	PRESENT	0
8200	8188	08028W	PARTICIPANT	\N	EXCUSE	0
8201	8188	80013X	PARTICIPANT	\N	PRESENT	0
8341	8061	14263U	PARTICIPANT	\N	PRESENT	0
8342	8061	07004J	PARTICIPANT	\N	PRESENT	0
8204	8188	14197C	PARTICIPANT	\N	PRESENT	0
8343	8061	01019Q	PARTICIPANT	\N	PRESENT	0
8344	8061	11090Q	PARTICIPANT	\N	PRESENT	0
8207	8188	14033T	PARTICIPANT	\N	PRESENT	0
8346	8061	14018U	PARTICIPANT	\N	PRESENT	0
8209	8188	04048J	PARTICIPANT	\N	PRESENT	0
8347	8061	14199E	PARTICIPANT	\N	PRESENT	0
8348	8061	04057K	PARTICIPANT	\N	PRESENT	0
8350	8061	01024M	PARTICIPANT	\N	PRESENT	0
8213	8188	11111C	PARTICIPANT	\N	PRESENT	0
8214	8188	08015R	PARTICIPANT	\N	PRESENT	0
8215	8188	11100Y	PRESIDENT	0	PRESENT	0
8352	8061	14205J	PARTICIPANT	\N	PRESENT	0
8353	8061	11083R	PARTICIPANT	\N	PRESENT	0
8218	8188	01043Q	PARTICIPANT	\N	EXCUSE	0
8354	8061	04061F	PARTICIPANT	\N	PRESENT	0
8220	8188	14205J	PARTICIPANT	\N	PRESENT	0
8355	8061	14239U	PARTICIPANT	\N	PRESENT	0
8222	8188	14257W	PARTICIPANT	\N	PRESENT	0
8223	8188	08021P	PARTICIPANT	\N	EXCUSE	0
8224	8188	04088S	PARTICIPANT	\N	PRESENT	0
8225	8188	98050T	PARTICIPANT	\N	PRESENT	0
8226	8188	11090Q	PARTICIPANT	\N	PRESENT	0
8356	8061	14257W	PARTICIPANT	\N	PRESENT	0
8228	8188	01058X	PARTICIPANT	\N	EXCUSE	0
8229	8188	11094U	PARTICIPANT	\N	EXCUSE	0
8230	8188	11066Q	PARTICIPANT	\N	PRESENT	0
8357	8061	14053L	PARTICIPANT	\N	PRESENT	0
8358	8061	14083S	PARTICIPANT	\N	PRESENT	0
8359	8061	95030B	PARTICIPANT	\N	PRESENT	0
8360	8061	98023Q	PARTICIPANT	\N	PRESENT	0
8361	8061	95059Q	PARTICIPANT	\N	PRESENT	0
8366	8061	14271U	PARTICIPANT	\N	PRESENT	0
8363	8061	90003B	PARTICIPANT	\N	PRESENT	0
8364	8061	14069U	PARTICIPANT	\N	PRESENT	0
8365	8061	01008M	PARTICIPANT	\N	PRESENT	0
8367	8061	13002U	PARTICIPANT	\N	PRESENT	0
8368	8061	04074L	PARTICIPANT	\N	PRESENT	0
8369	8064	11085T	PARTICIPANT	\N	PRESENT	0
8370	8064	11096W	PARTICIPANT	\N	PRESENT	0
8371	8064	08021P	PARTICIPANT	\N	PRESENT	0
8372	8064	04040A	PARTICIPANT	\N	PRESENT	0
8373	8064	07024N	PARTICIPANT	\N	PRESENT	0
8374	8064	01014K	PARTICIPANT	\N	PRESENT	0
8375	8064	11076S	PARTICIPANT	\N	PRESENT	0
8376	8064	04054G	PARTICIPANT	\N	PRESENT	0
8377	8064	11106F	PARTICIPANT	\N	PRESENT	0
8378	8064	14033T	PARTICIPANT	\N	PRESENT	0
8379	8064	04041B	PARTICIPANT	\N	PRESENT	0
8380	8064	01056V	PARTICIPANT	\N	PRESENT	0
8381	8064	14030Q	PARTICIPANT	\N	PRESENT	0
8382	8064	86044G	PARTICIPANT	\N	PRESENT	0
8383	8064	07034Q	PARTICIPANT	\N	PRESENT	0
8384	8064	14031R	PARTICIPANT	\N	PRESENT	0
8385	8064	14157T	PARTICIPANT	\N	PRESENT	0
8386	8064	04095R	PARTICIPANT	\N	PRESENT	0
8387	8064	14121F	PARTICIPANT	\N	PRESENT	0
8388	8064	14265W	PARTICIPANT	\N	PRESENT	0
8389	8064	14038Y	PARTICIPANT	\N	PRESENT	0
8390	8064	87003B	PARTICIPANT	\N	PRESENT	0
8391	8064	14207L	PARTICIPANT	\N	PRESENT	0
8392	8064	11100Y	PARTICIPANT	\N	PRESENT	0
8393	8064	14059S	PARTICIPANT	\N	PRESENT	0
8394	8064	14215L	PARTICIPANT	\N	PRESENT	0
8395	8064	77002U	PARTICIPANT	\N	PRESENT	0
8396	8064	11066Q	PARTICIPANT	\N	PRESENT	0
8397	8064	11104D	PARTICIPANT	\N	PRESENT	0
8398	8064	14231L	PARTICIPANT	\N	PRESENT	0
8399	8064	95049N	PARTICIPANT	\N	PRESENT	0
8400	8064	95037J	PARTICIPANT	\N	PRESENT	0
8401	8064	14107H	PARTICIPANT	\N	PRESENT	0
8402	8064	92020L	PARTICIPANT	\N	PRESENT	0
8403	8064	08056B	PARTICIPANT	\N	PRESENT	0
8404	8064	01011G	PARTICIPANT	\N	PRESENT	0
8405	8064	80013X	PARTICIPANT	\N	PRESENT	0
8406	8064	11053K	PARTICIPANT	\N	PRESENT	0
8407	8064	09001P	PARTICIPANT	\N	PRESENT	0
8408	8064	04077P	PARTICIPANT	\N	PRESENT	0
8409	8064	01016M	PARTICIPANT	\N	PRESENT	0
8410	8064	11098Y	PARTICIPANT	\N	PRESENT	0
8411	8064	11012A	PARTICIPANT	\N	PRESENT	0
8412	8064	04088S	PARTICIPANT	\N	PRESENT	0
8413	8064	08047A	PARTICIPANT	\N	PRESENT	0
8160	8061	11096W	PARTICIPANT	\N	PRESENT	0
8159	8061	11085T	PARTICIPANT	\N	PRESENT	0
8161	8061	08021P	PARTICIPANT	\N	PRESENT	0
8162	8061	04040A	PARTICIPANT	\N	PRESENT	0
8163	8061	07024N	PARTICIPANT	\N	PRESENT	0
8164	8061	01014K	PARTICIPANT	\N	PRESENT	0
8165	8061	11076S	PARTICIPANT	\N	PRESENT	0
8166	8061	04054G	PARTICIPANT	\N	PRESENT	0
8167	8061	11106F	PARTICIPANT	\N	PRESENT	0
8168	8061	14033T	PARTICIPANT	\N	PRESENT	0
8169	8061	04041B	PARTICIPANT	\N	PRESENT	0
8170	8061	01056V	PARTICIPANT	\N	PRESENT	0
8171	8061	14030Q	PARTICIPANT	\N	PRESENT	0
8172	8061	86044G	PARTICIPANT	\N	PRESENT	0
8173	8061	07034Q	PARTICIPANT	\N	PRESENT	0
8174	8061	14031R	PARTICIPANT	\N	PRESENT	0
8175	8061	14157T	PARTICIPANT	\N	PRESENT	0
8176	8061	04095R	PARTICIPANT	\N	PRESENT	0
8177	8061	14121F	PARTICIPANT	\N	PRESENT	0
8178	8061	14265W	PARTICIPANT	\N	PRESENT	0
8179	8061	14038Y	PARTICIPANT	\N	PRESENT	0
8180	8061	87003B	PARTICIPANT	\N	PRESENT	0
8181	8061	14207L	PARTICIPANT	\N	PRESENT	0
8182	8061	11100Y	PARTICIPANT	\N	PRESENT	0
8183	8061	14059S	PARTICIPANT	\N	PRESENT	0
8184	8061	14215L	PARTICIPANT	\N	PRESENT	0
8185	8061	77002U	PARTICIPANT	\N	PRESENT	0
8186	8061	11066Q	PARTICIPANT	\N	PRESENT	0
8187	8061	11104D	PARTICIPANT	\N	PRESENT	0
8191	8061	14231L	PARTICIPANT	\N	PRESENT	0
8193	8061	95049N	PARTICIPANT	\N	PRESENT	0
8231	8061	95037J	PARTICIPANT	\N	PRESENT	0
8232	8061	14107H	PARTICIPANT	\N	PRESENT	0
8233	8061	92020L	PARTICIPANT	\N	PRESENT	0
8234	8061	08056B	PARTICIPANT	\N	PRESENT	0
8235	8061	01011G	PARTICIPANT	\N	PRESENT	0
8236	8061	80013X	PARTICIPANT	\N	PRESENT	0
8237	8061	11053K	PARTICIPANT	\N	PRESENT	0
8238	8061	09001P	PARTICIPANT	\N	PRESENT	0
8239	8061	04077P	PARTICIPANT	\N	PRESENT	0
8240	8061	01016M	PARTICIPANT	\N	PRESENT	0
8241	8061	11098Y	PARTICIPANT	\N	PRESENT	0
8242	8061	11012A	PARTICIPANT	\N	PRESENT	0
8243	8061	04088S	PARTICIPANT	\N	PRESENT	0
8244	8061	08047A	PARTICIPANT	\N	PRESENT	0
8245	8061	14037X	PARTICIPANT	\N	PRESENT	0
8246	8061	14273W	PARTICIPANT	\N	PRESENT	0
8247	8061	08028W	PARTICIPANT	\N	PRESENT	0
8248	8061	08055A	PARTICIPANT	\N	PRESENT	0
8249	8061	14081Q	PARTICIPANT	\N	PRESENT	0
8250	8061	11040E	PARTICIPANT	\N	PRESENT	0
8251	8061	14105F	PARTICIPANT	\N	PRESENT	0
8252	8061	07029T	PARTICIPANT	\N	PRESENT	0
8253	8061	14093U	PARTICIPANT	\N	PRESENT	0
8254	8061	11042G	PARTICIPANT	\N	PRESENT	0
8255	8061	04045F	PARTICIPANT	\N	PRESENT	0
8256	8061	11113E	PARTICIPANT	\N	PRESENT	0
8257	8061	14237S	PARTICIPANT	\N	PRESENT	0
8258	8061	11091R	PARTICIPANT	\N	PRESENT	0
8259	8061	11088W	PARTICIPANT	\N	PRESENT	0
8260	8061	01058X	PARTICIPANT	\N	PRESENT	0
8261	8061	99004R	PARTICIPANT	\N	PRESENT	0
8262	8061	14217N	PARTICIPANT	\N	PRESENT	0
8263	8061	08034U	PARTICIPANT	\N	PRESENT	0
8264	8061	14197C	PARTICIPANT	\N	PRESENT	0
8265	8061	01022K	PARTICIPANT	\N	PRESENT	0
8266	8061	04081K	PARTICIPANT	\N	PRESENT	0
8267	8061	89017R	PARTICIPANT	\N	PRESENT	0
8268	8061	14253S	PARTICIPANT	\N	PRESENT	0
8269	8061	14195A	PARTICIPANT	\N	PRESENT	0
8270	8061	14135M	PARTICIPANT	\N	PRESENT	0
8271	8061	11103C	PARTICIPANT	\N	PRESENT	0
8272	8061	08042U	PARTICIPANT	\N	PRESENT	0
8273	8061	14071N	PARTICIPANT	\N	PRESENT	0
8274	8061	14041T	PARTICIPANT	\N	PRESENT	0
8275	8061	14159V	PARTICIPANT	\N	PRESENT	0
8276	8061	14039A	PARTICIPANT	\N	PRESENT	0
8277	8061	14051J	PARTICIPANT	\N	PRESENT	0
8279	8061	08061X	PARTICIPANT	\N	PRESENT	0
8280	8061	04036E	PARTICIPANT	\N	PRESENT	0
8281	8061	97011G	PARTICIPANT	\N	PRESENT	0
8282	8061	08065C	PARTICIPANT	\N	PRESENT	0
8283	8061	95063L	PARTICIPANT	\N	PRESENT	0
8284	8061	14241N	PARTICIPANT	\N	PRESENT	0
8285	8061	08017T	PARTICIPANT	\N	PRESENT	0
8286	8061	98050T	PARTICIPANT	\N	PRESENT	0
8287	8061	08010L	PARTICIPANT	\N	PRESENT	0
8288	8061	11054L	PARTICIPANT	\N	PRESENT	0
8289	8061	14235Q	PARTICIPANT	\N	PRESENT	0
8290	8061	01031L	PARTICIPANT	\N	PRESENT	0
8291	8061	11057P	PARTICIPANT	\N	PRESENT	0
8292	8061	11067R	PARTICIPANT	\N	PRESENT	0
8293	8061	04048J	PARTICIPANT	\N	PRESENT	0
8294	8061	11114F	PARTICIPANT	\N	PRESENT	0
8295	8061	98018T	PARTICIPANT	\N	PRESENT	0
8296	8061	83042R	PARTICIPANT	\N	PRESENT	0
8297	8061	14193X	PARTICIPANT	\N	PRESENT	0
8308	8061	05012A	PARTICIPANT	\N	PRESENT	0
8299	8061	04044E	PARTICIPANT	\N	PRESENT	0
8300	8061	04038G	PARTICIPANT	\N	PRESENT	0
8310	8061	08062Y	PARTICIPANT	\N	PRESENT	0
8313	8061	14063N	PARTICIPANT	\N	PRESENT	0
8303	8061	11074Q	PARTICIPANT	\N	PRESENT	0
8304	8061	08058D	PARTICIPANT	\N	PRESENT	0
8305	8061	14013P	PARTICIPANT	\N	PRESENT	0
8306	8061	11034G	PARTICIPANT	\N	PRESENT	0
8307	8061	08022Q	PARTICIPANT	\N	PRESENT	0
8309	8061	14211G	PARTICIPANT	\N	PRESENT	0
8311	8061	04086Q	PARTICIPANT	\N	PRESENT	0
8312	8061	10015M	PARTICIPANT	\N	PRESENT	0
8314	8061	14213J	PARTICIPANT	\N	PRESENT	0
8315	8061	92031P	PARTICIPANT	\N	PRESENT	0
8316	8061	01015L	PARTICIPANT	\N	PRESENT	0
8317	8061	14173T	PARTICIPANT	\N	PRESENT	0
8318	8061	11107G	PARTICIPANT	\N	PRESENT	0
8319	8061	98042T	PARTICIPANT	\N	PRESENT	0
8320	8061	14259Y	PARTICIPANT	\N	PRESENT	0
8321	8061	14251Q	PARTICIPANT	\N	PRESENT	0
8322	8061	11056N	PARTICIPANT	\N	PRESENT	0
8323	8061	14249W	PARTICIPANT	\N	PRESENT	0
8324	8061	14219Q	PARTICIPANT	\N	PRESENT	0
8325	8061	01028R	PARTICIPANT	\N	PRESENT	0
8326	8061	14169X	PARTICIPANT	\N	PRESENT	0
8327	8061	95062K	PARTICIPANT	\N	PRESENT	0
8328	8061	14281W	PARTICIPANT	\N	PRESENT	0
8329	8061	11027H	PARTICIPANT	\N	PRESENT	0
8330	8061	08015R	PARTICIPANT	\N	PRESENT	0
8331	8061	11069T	PARTICIPANT	\N	PRESENT	0
8332	8061	14034U	PARTICIPANT	\N	PRESENT	0
8333	8061	14079W	PARTICIPANT	\N	PRESENT	0
8334	8061	14097Y	PARTICIPANT	\N	PRESENT	0
8335	8061	07032N	PARTICIPANT	\N	PRESENT	0
8336	8061	08041T	PARTICIPANT	\N	PRESENT	0
8337	8061	11048N	PARTICIPANT	\N	PRESENT	0
8414	8064	14037X	PARTICIPANT	\N	PRESENT	0
8415	8064	14273W	PARTICIPANT	\N	PRESENT	0
8416	8064	08028W	PARTICIPANT	\N	PRESENT	0
8417	8064	08055A	PARTICIPANT	\N	PRESENT	0
8418	8064	14081Q	PARTICIPANT	\N	PRESENT	0
8419	8064	11040E	PARTICIPANT	\N	PRESENT	0
8420	8064	14105F	PARTICIPANT	\N	PRESENT	0
8421	8064	07029T	PARTICIPANT	\N	PRESENT	0
8422	8064	14093U	PARTICIPANT	\N	PRESENT	0
8423	8064	11042G	PARTICIPANT	\N	PRESENT	0
8424	8064	04045F	PARTICIPANT	\N	PRESENT	0
8425	8064	11113E	PARTICIPANT	\N	PRESENT	0
8426	8064	14237S	PARTICIPANT	\N	PRESENT	0
8427	8064	11091R	PARTICIPANT	\N	PRESENT	0
8428	8064	11088W	PARTICIPANT	\N	PRESENT	0
8429	8064	01058X	PARTICIPANT	\N	PRESENT	0
8430	8064	99004R	PARTICIPANT	\N	PRESENT	0
8431	8064	14217N	PARTICIPANT	\N	PRESENT	0
8432	8064	08034U	PARTICIPANT	\N	PRESENT	0
8433	8064	14197C	PARTICIPANT	\N	PRESENT	0
8434	8064	01022K	PARTICIPANT	\N	PRESENT	0
8435	8064	04081K	PARTICIPANT	\N	PRESENT	0
8436	8064	89017R	PARTICIPANT	\N	PRESENT	0
8437	8064	14253S	PARTICIPANT	\N	PRESENT	0
8438	8064	14195A	PARTICIPANT	\N	PRESENT	0
8439	8064	14135M	PARTICIPANT	\N	PRESENT	0
8440	8064	11103C	PARTICIPANT	\N	PRESENT	0
8441	8064	08042U	PARTICIPANT	\N	PRESENT	0
8442	8064	14071N	PARTICIPANT	\N	PRESENT	0
8443	8064	14041T	PARTICIPANT	\N	PRESENT	0
8444	8064	14159V	PARTICIPANT	\N	PRESENT	0
8445	8064	14039A	PARTICIPANT	\N	PRESENT	0
8446	8064	14051J	PARTICIPANT	\N	PRESENT	0
8447	8064	08061X	PARTICIPANT	\N	PRESENT	0
8448	8064	04036E	PARTICIPANT	\N	PRESENT	0
8449	8064	97011G	PARTICIPANT	\N	PRESENT	0
8450	8064	08065C	PARTICIPANT	\N	PRESENT	0
8451	8064	95063L	PARTICIPANT	\N	PRESENT	0
7359	7123	11093T	PARTICIPANT	\N	PRESENT	0
7389	7388	11076S	PARTICIPANT	\N	PRESENT	0
7393	7388	11042G	PARTICIPANT	\N	EXCUSE	0
7394	7388	01015L	PARTICIPANT	\N	PRESENT	0
7395	7388	01003G	PARTICIPANT	\N	PRESENT	0
7396	7388	11049P	PARTICIPANT	\N	PRESENT	0
7579	4448	11036J	PARTICIPANT	\N	PRESENT	0
7399	7388	11048N	PRESIDENT	0	PRESENT	0
7401	7388	08042U	PARTICIPANT	\N	EXCUSE	0
7402	7388	04080J	PARTICIPANT	\N	EXCUSE	0
7403	7388	95062K	PARTICIPANT	\N	PRESENT	0
7581	4448	11068S	PARTICIPANT	\N	EXCUSE	0
7405	7388	11057P	PARTICIPANT	\N	PRESENT	0
7582	4448	80013X	PARTICIPANT	\N	PRESENT	0
7584	4448	11089X	PARTICIPANT	\N	EXCUSE	0
7585	4448	08069G	PARTICIPANT	\N	EXCUSE	0
7633	7632	04040A	PRESIDENT	0	PRESENT	0
7589	4448	08039A	PARTICIPANT	\N	PRESENT	0
7590	4448	01048V	PARTICIPANT	\N	PRESENT	0
7591	4448	14221J	PARTICIPANT	\N	EXCUSE	0
7593	4448	11082Q	PARTICIPANT	\N	EXCUSE	0
7594	4448	04043D	PARTICIPANT	\N	EXCUSE	0
7596	4448	01058X	PARTICIPANT	\N	PRESENT	0
7635	7632	04086Q	PARTICIPANT	\N	PRESENT	0
7636	7632	08034U	PARTICIPANT	\N	PRESENT	0
7637	7632	14231L	PARTICIPANT	\N	PRESENT	0
7638	7632	01057W	PARTICIPANT	\N	PRESENT	0
7639	7632	11098Y	PARTICIPANT	\N	PRESENT	0
7640	7632	11048N	PARTICIPANT	\N	PRESENT	0
7641	7632	08009T	PARTICIPANT	\N	EXCUSE	0
7642	7632	08051V	PARTICIPANT	\N	PRESENT	0
7643	7632	14071N	PARTICIPANT	\N	EXCUSE	0
7644	7632	14028W	PARTICIPANT	\N	EXCUSE	0
7645	7632	01027Q	PARTICIPANT	\N	EXCUSE	0
7646	7632	04044E	PARTICIPANT	\N	EXCUSE	0
7676	7650	01027Q	PARTICIPANT	\N	EXCUSE	0
7677	7650	14073Q	PARTICIPANT	\N	PRESENT	0
7678	7650	11112D	PARTICIPANT	\N	PRESENT	0
7679	7650	14031R	PARTICIPANT	\N	PRESENT	0
7680	7650	08053X	PARTICIPANT	\N	PRESENT	0
7681	7650	14237S	PARTICIPANT	\N	EXCUSE	0
7682	7650	14028W	PARTICIPANT	\N	EXCUSE	0
8049	7882	14063N	PARTICIPANT	\N	PRESENT	0
8028	7882	13002U	PARTICIPANT	\N	PRESENT	0
8029	7882	80013X	PARTICIPANT	\N	PRESENT	0
8030	7882	14107H	PARTICIPANT	\N	PRESENT	0
8031	7882	11107G	PARTICIPANT	\N	PRESENT	0
8032	7882	14039A	PARTICIPANT	\N	PRESENT	0
8033	7882	11098Y	PARTICIPANT	\N	PRESENT	0
8034	7882	01015L	PARTICIPANT	\N	PRESENT	0
8035	7882	11012A	PARTICIPANT	\N	PRESENT	0
8036	7882	09001P	PARTICIPANT	\N	PRESENT	0
8037	7882	98050T	PARTICIPANT	\N	PRESENT	0
8038	7882	11100Y	PARTICIPANT	\N	PRESENT	0
8039	7882	08042U	PARTICIPANT	\N	PRESENT	0
8040	7882	08009T	PARTICIPANT	\N	PRESENT	0
8041	7882	11112D	PARTICIPANT	\N	PRESENT	0
8042	7882	95062K	PARTICIPANT	\N	PRESENT	0
7674	7650	14089Y	PARTICIPANT	\N	PRESENT	0
7675	7650	08068F	PARTICIPANT	\N	PRESENT	0
8043	7882	14219Q	PARTICIPANT	\N	PRESENT	0
8044	7882	14159V	PARTICIPANT	\N	PRESENT	0
8045	7882	11065P	PARTICIPANT	\N	PRESENT	0
8046	7882	92039X	PARTICIPANT	\N	PRESENT	0
8047	7882	04066L	PARTICIPANT	\N	PRESENT	0
8048	7882	01003G	PARTICIPANT	\N	PRESENT	0
8050	7882	04080J	PARTICIPANT	\N	PRESENT	0
8051	7882	11069T	PARTICIPANT	\N	PRESENT	0
8452	8064	14241N	PARTICIPANT	\N	PRESENT	0
8453	8064	08017T	PARTICIPANT	\N	PRESENT	0
8093	8089	14093U	PARTICIPANT	\N	PRESENT	0
8094	8089	14030Q	PARTICIPANT	\N	PRESENT	0
8454	8064	98050T	PARTICIPANT	\N	PRESENT	0
8455	8064	08010L	PARTICIPANT	\N	PRESENT	0
8456	8064	11054L	PARTICIPANT	\N	PRESENT	0
8457	8064	14235Q	PARTICIPANT	\N	PRESENT	0
8099	8089	14038Y	PARTICIPANT	\N	PRESENT	0
8100	8089	11114F	PARTICIPANT	\N	PRESENT	0
8101	8089	98023Q	PARTICIPANT	\N	PRESENT	0
8458	8064	01031L	PARTICIPANT	\N	PRESENT	0
8103	8089	14169X	PARTICIPANT	\N	PRESENT	0
8459	8064	11057P	PARTICIPANT	\N	PRESENT	0
8105	8089	11107G	PARTICIPANT	\N	PRESENT	0
8460	8064	11067R	PARTICIPANT	\N	PRESENT	0
8461	8064	04048J	PARTICIPANT	\N	PRESENT	0
8108	8089	01022K	PARTICIPANT	\N	PRESENT	0
8109	8089	04097T	PARTICIPANT	\N	PRESENT	0
8110	8089	09001P	PARTICIPANT	\N	PRESENT	0
8111	8089	11059R	PARTICIPANT	\N	PRESENT	0
8112	8089	14219Q	PARTICIPANT	\N	PRESENT	0
8462	8064	11114F	PARTICIPANT	\N	PRESENT	0
8114	8089	14031R	PARTICIPANT	\N	PRESENT	0
8115	8089	08009T	PRESIDENT	0	PRESENT	0
8116	8089	08062Y	PARTICIPANT	\N	PRESENT	0
8463	8064	98018T	PARTICIPANT	\N	PRESENT	0
8464	8064	83042R	PARTICIPANT	\N	PRESENT	0
8119	8089	08042U	PARTICIPANT	\N	PRESENT	0
8120	8089	14237S	PARTICIPANT	\N	PRESENT	0
8121	8089	13002U	PARTICIPANT	\N	PRESENT	0
8122	8089	05012A	PARTICIPANT	\N	PRESENT	0
8465	8064	14193X	PARTICIPANT	\N	PRESENT	0
8124	8089	14135M	PARTICIPANT	\N	PRESENT	0
8125	8089	95062K	PARTICIPANT	\N	PRESENT	0
8126	8089	14107H	PARTICIPANT	\N	PRESENT	0
8127	8089	14051J	PARTICIPANT	\N	PRESENT	0
8128	8089	14157T	PARTICIPANT	\N	PRESENT	0
8469	8064	08058D	PARTICIPANT	\N	PRESENT	0
8466	8064	04044E	PARTICIPANT	\N	PRESENT	0
8467	8064	04038G	PARTICIPANT	\N	PRESENT	0
8468	8064	11074Q	PARTICIPANT	\N	PRESENT	0
8470	8064	14013P	PARTICIPANT	\N	PRESENT	0
8471	8064	11034G	PARTICIPANT	\N	PRESENT	0
8472	8064	08022Q	PARTICIPANT	\N	PRESENT	0
8473	8064	05012A	PARTICIPANT	\N	PRESENT	0
8474	8064	14211G	PARTICIPANT	\N	PRESENT	0
8475	8064	08062Y	PARTICIPANT	\N	PRESENT	0
8476	8064	04086Q	PARTICIPANT	\N	PRESENT	0
8477	8064	10015M	PARTICIPANT	\N	PRESENT	0
8478	8064	14063N	PARTICIPANT	\N	PRESENT	0
8479	8064	14213J	PARTICIPANT	\N	PRESENT	0
8480	8064	92031P	PARTICIPANT	\N	PRESENT	0
8481	8064	01015L	PARTICIPANT	\N	PRESENT	0
8482	8064	14173T	PARTICIPANT	\N	PRESENT	0
8483	8064	11107G	PARTICIPANT	\N	PRESENT	0
8484	8064	98042T	PARTICIPANT	\N	PRESENT	0
8485	8064	14259Y	PARTICIPANT	\N	PRESENT	0
8486	8064	14251Q	PARTICIPANT	\N	PRESENT	0
8487	8064	11056N	PARTICIPANT	\N	PRESENT	0
8488	8064	14249W	PARTICIPANT	\N	PRESENT	0
8489	8064	14219Q	PARTICIPANT	\N	PRESENT	0
8490	8064	01028R	PARTICIPANT	\N	PRESENT	0
8491	8064	14169X	PARTICIPANT	\N	PRESENT	0
8492	8064	95062K	PARTICIPANT	\N	PRESENT	0
8493	8064	14281W	PARTICIPANT	\N	PRESENT	0
8494	8064	11027H	PARTICIPANT	\N	PRESENT	0
8495	8064	08015R	PARTICIPANT	\N	PRESENT	0
8496	8064	11069T	PARTICIPANT	\N	PRESENT	0
8497	8064	14034U	PARTICIPANT	\N	PRESENT	0
8498	8064	14079W	PARTICIPANT	\N	PRESENT	0
8499	8064	14097Y	PARTICIPANT	\N	PRESENT	0
8500	8064	07032N	PARTICIPANT	\N	PRESENT	0
8501	8064	08041T	PARTICIPANT	\N	PRESENT	0
8502	8064	11048N	PARTICIPANT	\N	PRESENT	0
8503	8064	14263U	PARTICIPANT	\N	PRESENT	0
8504	8064	07004J	PARTICIPANT	\N	PRESENT	0
8505	8064	01019Q	PARTICIPANT	\N	PRESENT	0
8506	8064	11090Q	PARTICIPANT	\N	PRESENT	0
8507	8064	98021N	PARTICIPANT	\N	PRESENT	0
8508	8064	14018U	PARTICIPANT	\N	PRESENT	0
8509	8064	14199E	PARTICIPANT	\N	PRESENT	0
8510	8064	04057K	PARTICIPANT	\N	PRESENT	0
8511	8064	08068F	PARTICIPANT	\N	PRESENT	0
8512	8064	01024M	PARTICIPANT	\N	PRESENT	0
8513	8064	08009T	PARTICIPANT	\N	PRESENT	0
8514	8064	14205J	PARTICIPANT	\N	PRESENT	0
8515	8064	11083R	PARTICIPANT	\N	PRESENT	0
8516	8064	04061F	PARTICIPANT	\N	PRESENT	0
8517	8064	14239U	PARTICIPANT	\N	PRESENT	0
8518	8064	14257W	PARTICIPANT	\N	PRESENT	0
7477	7416	14219Q	PARTICIPANT	\N	PRESENT	0
7419	7416	11055M	PARTICIPANT	\N	PRESENT	0
7420	7416	01046T	PARTICIPANT	\N	PRESENT	0
7478	7416	10015M	PARTICIPANT	\N	PRESENT	0
7422	7416	04053F	PARTICIPANT	\N	PRESENT	0
7423	7416	14255U	PARTICIPANT	\N	EXCUSE	0
8519	8064	14053L	PARTICIPANT	\N	PRESENT	0
8520	8064	14083S	PARTICIPANT	\N	PRESENT	0
7426	7416	14053L	PARTICIPANT	\N	PRESENT	0
7427	7416	11103C	PARTICIPANT	\N	PRESENT	0
8521	8064	95030B	PARTICIPANT	\N	PRESENT	0
7429	7416	14195A	PARTICIPANT	\N	PRESENT	0
8522	8064	98023Q	PARTICIPANT	\N	PRESENT	0
8523	8064	95059Q	PARTICIPANT	\N	PRESENT	0
7432	7416	11031D	PARTICIPANT	\N	PRESENT	0
7433	7416	08052W	PARTICIPANT	\N	PRESENT	0
8524	8064	90003B	PARTICIPANT	\N	PRESENT	0
7435	7416	04081K	PARTICIPANT	\N	PRESENT	0
8525	8064	14069U	PARTICIPANT	\N	PRESENT	0
7437	7416	10006L	PARTICIPANT	\N	PRESENT	0
8526	8064	01008M	PARTICIPANT	\N	PRESENT	0
8527	8064	14271U	PARTICIPANT	\N	PRESENT	0
7440	7416	14042U	PARTICIPANT	\N	PRESENT	0
7441	7416	14151M	PARTICIPANT	\N	EXCUSE	0
7442	7416	12042Y	PARTICIPANT	\N	PRESENT	0
7443	7416	14087W	PARTICIPANT	\N	PRESENT	0
8528	8064	13002U	PARTICIPANT	\N	PRESENT	0
8529	8064	04074L	PARTICIPANT	\N	PRESENT	0
7446	7416	14231L	PARTICIPANT	\N	PRESENT	0
7447	7416	11061K	PARTICIPANT	\N	PRESENT	0
8530	8064	11077T	PARTICIPANT	\N	PRESENT	0
8531	8064	04097T	PARTICIPANT	\N	PRESENT	0
7450	7416	01011G	PARTICIPANT	\N	PRESENT	0
7451	7416	14026U	PARTICIPANT	\N	PRESENT	0
7452	7416	14213J	PARTICIPANT	\N	PRESENT	0
8532	8064	14187A	PARTICIPANT	\N	PRESENT	0
7454	7416	11112D	PARTICIPANT	\N	PRESENT	0
8533	8064	11068S	PARTICIPANT	\N	PRESENT	0
8534	8070	11085T	PARTICIPANT	\N	PRESENT	0
7457	7416	11067R	PARTICIPANT	\N	PRESENT	0
7458	7416	14223L	PARTICIPANT	\N	EXCUSE	0
7459	7416	04092N	PRESIDENT	0	PRESENT	0
7460	7416	14265W	PARTICIPANT	\N	PRESENT	0
7461	7416	14119M	PARTICIPANT	\N	PRESENT	0
7462	7416	14071N	PARTICIPANT	\N	EXCUSE	0
8535	8070	11096W	PARTICIPANT	\N	PRESENT	0
7464	7416	04043D	PARTICIPANT	\N	PRESENT	0
7465	7416	14271U	PARTICIPANT	\N	PRESENT	0
8536	8070	08021P	PARTICIPANT	\N	PRESENT	0
7467	7416	11093T	PARTICIPANT	\N	PRESENT	0
7468	7416	11097X	PARTICIPANT	\N	PRESENT	0
7469	7416	04045F	PARTICIPANT	\N	PRESENT	0
8537	8070	04040A	PARTICIPANT	\N	PRESENT	0
7471	7416	01034P	PARTICIPANT	\N	PRESENT	0
8538	8070	07024N	PARTICIPANT	\N	PRESENT	0
8539	8070	01014K	PARTICIPANT	\N	PRESENT	0
8540	8070	11076S	PARTICIPANT	\N	PRESENT	0
8541	8070	04054G	PARTICIPANT	\N	PRESENT	0
8542	8070	11106F	PARTICIPANT	\N	PRESENT	0
8543	8070	14033T	PARTICIPANT	\N	PRESENT	0
8544	8070	04041B	PARTICIPANT	\N	PRESENT	0
8545	8070	01056V	PARTICIPANT	\N	PRESENT	0
8546	8070	14030Q	PARTICIPANT	\N	PRESENT	0
8547	8070	86044G	PARTICIPANT	\N	PRESENT	0
8548	8070	07034Q	PARTICIPANT	\N	PRESENT	0
8549	8070	14031R	PARTICIPANT	\N	PRESENT	0
8550	8070	14157T	PARTICIPANT	\N	PRESENT	0
8551	8070	04095R	PARTICIPANT	\N	PRESENT	0
8552	8070	14121F	PARTICIPANT	\N	PRESENT	0
8553	8070	14265W	PARTICIPANT	\N	PRESENT	0
8554	8070	14038Y	PARTICIPANT	\N	PRESENT	0
8555	8070	87003B	PARTICIPANT	\N	PRESENT	0
8556	8070	14207L	PARTICIPANT	\N	PRESENT	0
8557	8070	11100Y	PARTICIPANT	\N	PRESENT	0
8558	8070	14059S	PARTICIPANT	\N	PRESENT	0
8559	8070	14215L	PARTICIPANT	\N	PRESENT	0
8560	8070	77002U	PARTICIPANT	\N	PRESENT	0
8561	8070	11066Q	PARTICIPANT	\N	PRESENT	0
8562	8070	11104D	PARTICIPANT	\N	PRESENT	0
8563	8070	14231L	PARTICIPANT	\N	PRESENT	0
8564	8070	95049N	PARTICIPANT	\N	PRESENT	0
8565	8070	95037J	PARTICIPANT	\N	PRESENT	0
8566	8070	14107H	PARTICIPANT	\N	PRESENT	0
8567	8070	92020L	PARTICIPANT	\N	PRESENT	0
8568	8070	08056B	PARTICIPANT	\N	PRESENT	0
8569	8070	01011G	PARTICIPANT	\N	PRESENT	0
8570	8070	80013X	PARTICIPANT	\N	PRESENT	0
8571	8070	11053K	PARTICIPANT	\N	PRESENT	0
8572	8070	09001P	PARTICIPANT	\N	PRESENT	0
8573	8070	04077P	PARTICIPANT	\N	PRESENT	0
8574	8070	01016M	PARTICIPANT	\N	PRESENT	0
8575	8070	11098Y	PARTICIPANT	\N	PRESENT	0
8576	8070	11012A	PARTICIPANT	\N	PRESENT	0
8577	8070	04088S	PARTICIPANT	\N	PRESENT	0
8578	8070	08047A	PARTICIPANT	\N	PRESENT	0
8579	8070	14037X	PARTICIPANT	\N	PRESENT	0
8580	8070	14273W	PARTICIPANT	\N	PRESENT	0
8581	8070	08028W	PARTICIPANT	\N	PRESENT	0
8582	8070	08055A	PARTICIPANT	\N	PRESENT	0
8583	8070	14081Q	PARTICIPANT	\N	PRESENT	0
8584	8070	11040E	PARTICIPANT	\N	PRESENT	0
8585	8070	14105F	PARTICIPANT	\N	PRESENT	0
8586	8070	07029T	PARTICIPANT	\N	PRESENT	0
8587	8070	14093U	PARTICIPANT	\N	PRESENT	0
8588	8070	11042G	PARTICIPANT	\N	PRESENT	0
8589	8070	04045F	PARTICIPANT	\N	PRESENT	0
8590	8070	11113E	PARTICIPANT	\N	PRESENT	0
8591	8070	14237S	PARTICIPANT	\N	PRESENT	0
8592	8070	11091R	PARTICIPANT	\N	PRESENT	0
8593	8070	11088W	PARTICIPANT	\N	PRESENT	0
8594	8070	01058X	PARTICIPANT	\N	PRESENT	0
8595	8070	99004R	PARTICIPANT	\N	PRESENT	0
8596	8070	14217N	PARTICIPANT	\N	PRESENT	0
8597	8070	08034U	PARTICIPANT	\N	PRESENT	0
8598	8070	14197C	PARTICIPANT	\N	PRESENT	0
8599	8070	01022K	PARTICIPANT	\N	PRESENT	0
8600	8070	04081K	PARTICIPANT	\N	PRESENT	0
8601	8070	89017R	PARTICIPANT	\N	PRESENT	0
8602	8070	14253S	PARTICIPANT	\N	PRESENT	0
8603	8070	14195A	PARTICIPANT	\N	PRESENT	0
8604	8070	14135M	PARTICIPANT	\N	PRESENT	0
8605	8070	11103C	PARTICIPANT	\N	PRESENT	0
8606	8070	08042U	PARTICIPANT	\N	PRESENT	0
8607	8070	14071N	PARTICIPANT	\N	PRESENT	0
8608	8070	14041T	PARTICIPANT	\N	PRESENT	0
8609	8070	14159V	PARTICIPANT	\N	PRESENT	0
8610	8070	14039A	PARTICIPANT	\N	PRESENT	0
8611	8070	14051J	PARTICIPANT	\N	PRESENT	0
8612	8070	08061X	PARTICIPANT	\N	PRESENT	0
8613	8070	04036E	PARTICIPANT	\N	PRESENT	0
8614	8070	97011G	PARTICIPANT	\N	PRESENT	0
8615	8070	08065C	PARTICIPANT	\N	PRESENT	0
8616	8070	95063L	PARTICIPANT	\N	PRESENT	0
8617	8070	14241N	PARTICIPANT	\N	PRESENT	0
8618	8070	08017T	PARTICIPANT	\N	PRESENT	0
8619	8070	98050T	PARTICIPANT	\N	PRESENT	0
8620	8070	08010L	PARTICIPANT	\N	PRESENT	0
8621	8070	11054L	PARTICIPANT	\N	PRESENT	0
8622	8070	14235Q	PARTICIPANT	\N	PRESENT	0
8623	8070	01031L	PARTICIPANT	\N	PRESENT	0
8624	8070	11057P	PARTICIPANT	\N	PRESENT	0
8625	8070	11067R	PARTICIPANT	\N	PRESENT	0
8626	8070	04048J	PARTICIPANT	\N	PRESENT	0
8627	8070	11114F	PARTICIPANT	\N	PRESENT	0
8628	8070	98018T	PARTICIPANT	\N	PRESENT	0
8629	8070	83042R	PARTICIPANT	\N	PRESENT	0
8630	8070	14193X	PARTICIPANT	\N	PRESENT	0
8631	8070	04044E	PARTICIPANT	\N	PRESENT	0
8632	8070	04038G	PARTICIPANT	\N	PRESENT	0
8633	8070	11074Q	PARTICIPANT	\N	PRESENT	0
8634	8070	08058D	PARTICIPANT	\N	PRESENT	0
8635	8070	14013P	PARTICIPANT	\N	PRESENT	0
8636	8070	11034G	PARTICIPANT	\N	PRESENT	0
8637	8070	08022Q	PARTICIPANT	\N	PRESENT	0
8638	8070	05012A	PARTICIPANT	\N	PRESENT	0
8639	8070	14211G	PARTICIPANT	\N	PRESENT	0
8640	8070	08062Y	PARTICIPANT	\N	PRESENT	0
8641	8070	04086Q	PARTICIPANT	\N	PRESENT	0
8642	8070	10015M	PARTICIPANT	\N	PRESENT	0
8643	8070	14063N	PARTICIPANT	\N	PRESENT	0
8644	8070	14213J	PARTICIPANT	\N	PRESENT	0
8645	8070	92031P	PARTICIPANT	\N	PRESENT	0
8646	8070	01015L	PARTICIPANT	\N	PRESENT	0
8647	8070	14173T	PARTICIPANT	\N	PRESENT	0
8648	8070	11107G	PARTICIPANT	\N	PRESENT	0
8649	8070	98042T	PARTICIPANT	\N	PRESENT	0
8650	8070	14259Y	PARTICIPANT	\N	PRESENT	0
8651	8070	14251Q	PARTICIPANT	\N	PRESENT	0
8652	8070	11056N	PARTICIPANT	\N	PRESENT	0
8653	8070	14249W	PARTICIPANT	\N	PRESENT	0
8654	8070	14219Q	PARTICIPANT	\N	PRESENT	0
8655	8070	01028R	PARTICIPANT	\N	PRESENT	0
8656	8070	14169X	PARTICIPANT	\N	PRESENT	0
8657	8070	95062K	PARTICIPANT	\N	PRESENT	0
8658	8070	14281W	PARTICIPANT	\N	PRESENT	0
8659	8070	11027H	PARTICIPANT	\N	PRESENT	0
8660	8070	08015R	PARTICIPANT	\N	PRESENT	0
8661	8070	11069T	PARTICIPANT	\N	PRESENT	0
8662	8070	14034U	PARTICIPANT	\N	PRESENT	0
8663	8070	14079W	PARTICIPANT	\N	PRESENT	0
8664	8070	14097Y	PARTICIPANT	\N	PRESENT	0
8665	8070	07032N	PARTICIPANT	\N	PRESENT	0
8666	8070	08041T	PARTICIPANT	\N	PRESENT	0
8667	8070	11048N	PARTICIPANT	\N	PRESENT	0
8668	8070	14263U	PARTICIPANT	\N	PRESENT	0
8669	8070	07004J	PARTICIPANT	\N	PRESENT	0
8670	8070	01019Q	PARTICIPANT	\N	PRESENT	0
8671	8070	11090Q	PARTICIPANT	\N	PRESENT	0
8672	8070	98021N	PARTICIPANT	\N	PRESENT	0
8673	8070	14018U	PARTICIPANT	\N	PRESENT	0
8674	8070	14199E	PARTICIPANT	\N	PRESENT	0
8675	8070	04057K	PARTICIPANT	\N	PRESENT	0
8676	8070	08068F	PARTICIPANT	\N	PRESENT	0
8677	8070	01024M	PARTICIPANT	\N	PRESENT	0
8678	8070	08009T	PARTICIPANT	\N	PRESENT	0
8679	8070	14205J	PARTICIPANT	\N	PRESENT	0
8680	8070	11083R	PARTICIPANT	\N	PRESENT	0
8681	8070	04061F	PARTICIPANT	\N	PRESENT	0
8682	8070	14239U	PARTICIPANT	\N	PRESENT	0
8683	8070	14257W	PARTICIPANT	\N	PRESENT	0
8684	8070	14053L	PARTICIPANT	\N	PRESENT	0
8685	8070	14083S	PARTICIPANT	\N	PRESENT	0
8686	8070	95030B	PARTICIPANT	\N	PRESENT	0
8687	8070	98023Q	PARTICIPANT	\N	PRESENT	0
8688	8070	95059Q	PARTICIPANT	\N	PRESENT	0
8689	8070	90003B	PARTICIPANT	\N	PRESENT	0
8690	8070	14069U	PARTICIPANT	\N	PRESENT	0
8691	8070	01008M	PARTICIPANT	\N	PRESENT	0
8692	8070	14271U	PARTICIPANT	\N	PRESENT	0
8693	8070	13002U	PARTICIPANT	\N	PRESENT	0
8694	8070	04074L	PARTICIPANT	\N	PRESENT	0
8695	8070	11077T	PARTICIPANT	\N	PRESENT	0
8696	8070	04097T	PARTICIPANT	\N	PRESENT	0
8697	8070	14187A	PARTICIPANT	\N	PRESENT	0
8698	8070	11068S	PARTICIPANT	\N	PRESENT	0
8882	8062	14030Q	PARTICIPANT	\N	PRESENT	0
8883	8062	14239U	PARTICIPANT	\N	PRESENT	0
8701	8062	08021P	PARTICIPANT	\N	PRESENT	0
8884	8062	14121F	PARTICIPANT	\N	PRESENT	0
8885	8062	14205J	PARTICIPANT	\N	PRESENT	0
8886	8062	08009T	PARTICIPANT	\N	PRESENT	0
8887	8062	14231L	PARTICIPANT	\N	PRESENT	0
8706	8062	04054G	PARTICIPANT	\N	PRESENT	0
8707	8062	11106F	PARTICIPANT	\N	PRESENT	0
8708	8062	14033T	PARTICIPANT	\N	PRESENT	0
8709	8062	04041B	PARTICIPANT	\N	PRESENT	0
8888	8062	14083S	PARTICIPANT	\N	PRESENT	0
8889	8062	07004J	PARTICIPANT	\N	PRESENT	0
8712	8062	86044G	PARTICIPANT	\N	PRESENT	0
8890	8062	98042T	PARTICIPANT	\N	PRESENT	0
8891	8062	14255U	PARTICIPANT	\N	PRESENT	0
8892	8062	01047U	PARTICIPANT	\N	PRESENT	0
8893	8062	01024M	PARTICIPANT	\N	PRESENT	0
8894	8062	01007L	PARTICIPANT	\N	PRESENT	0
8895	8062	14018U	PARTICIPANT	\N	PRESENT	0
8896	8062	11012A	PARTICIPANT	\N	PRESENT	0
8897	8062	08051V	PARTICIPANT	\N	PRESENT	0
8721	8062	14207L	PARTICIPANT	\N	PRESENT	0
8898	8062	95049N	PARTICIPANT	\N	PRESENT	0
8723	8062	14059S	PARTICIPANT	\N	PRESENT	0
8724	8062	14215L	PARTICIPANT	\N	PRESENT	0
8899	8062	01016M	PARTICIPANT	\N	PRESENT	0
8726	8062	11066Q	PARTICIPANT	\N	PRESENT	0
8727	8062	11104D	PARTICIPANT	\N	PRESENT	0
8900	8062	05004A	PARTICIPANT	\N	PRESENT	0
8901	8062	04048J	PARTICIPANT	\N	PRESENT	0
8902	8062	14211G	PARTICIPANT	\N	PRESENT	0
8731	8062	14107H	PARTICIPANT	\N	PRESENT	0
8732	8062	92020L	PARTICIPANT	\N	PRESENT	0
8903	8062	04077P	PARTICIPANT	\N	PRESENT	0
8734	8062	01011G	PARTICIPANT	\N	PRESENT	0
8735	8062	80013X	PARTICIPANT	\N	PRESENT	0
8904	8062	14157T	PARTICIPANT	\N	PRESENT	0
8905	8062	95063L	PARTICIPANT	\N	PRESENT	0
8906	8062	08010L	PARTICIPANT	\N	PRESENT	0
8907	8062	98023Q	PARTICIPANT	\N	PRESENT	0
8740	8062	11098Y	PARTICIPANT	\N	PRESENT	0
8908	8062	95059Q	PARTICIPANT	\N	PRESENT	0
8742	8062	04088S	PARTICIPANT	\N	PRESENT	0
8909	8062	01031L	PARTICIPANT	\N	PRESENT	0
8910	8062	01057W	PARTICIPANT	\N	PRESENT	0
8745	8062	14273W	PARTICIPANT	\N	PRESENT	0
8911	8062	11088W	PARTICIPANT	\N	PRESENT	0
8747	8062	08055A	PARTICIPANT	\N	PRESENT	0
8748	8062	14081Q	PARTICIPANT	\N	PRESENT	0
8749	8062	11040E	PARTICIPANT	\N	PRESENT	0
8912	8062	10015M	PARTICIPANT	\N	PRESENT	0
8751	8062	07029T	PARTICIPANT	\N	PRESENT	0
8913	8062	14093U	PARTICIPANT	\N	PRESENT	0
8753	8062	11042G	PARTICIPANT	\N	PRESENT	0
8914	8062	14135M	PARTICIPANT	\N	PRESENT	0
8915	8062	14219Q	PARTICIPANT	\N	PRESENT	0
8916	8062	11111C	PARTICIPANT	\N	PRESENT	0
8757	8062	11091R	PARTICIPANT	\N	PRESENT	0
8917	8062	11069T	PARTICIPANT	\N	PRESENT	0
8918	8062	11033F	PARTICIPANT	\N	PRESENT	0
8919	8062	14187A	PARTICIPANT	\N	PRESENT	0
8761	8062	14217N	PARTICIPANT	\N	PRESENT	0
8920	8062	95041E	PARTICIPANT	\N	PRESENT	0
8921	8062	11063M	PARTICIPANT	\N	PRESENT	0
8764	8062	01022K	PARTICIPANT	\N	PRESENT	0
8922	8062	11031D	PARTICIPANT	\N	PRESENT	0
8923	8062	11083R	PARTICIPANT	\N	PRESENT	0
8924	8062	11100Y	PARTICIPANT	\N	PRESENT	0
8768	8062	14195A	PARTICIPANT	\N	PRESENT	0
8925	8062	04033B	PARTICIPANT	\N	PRESENT	0
8770	8062	11103C	PARTICIPANT	\N	PRESENT	0
8771	8062	08042U	PARTICIPANT	\N	PRESENT	0
8926	8062	11107G	PARTICIPANT	\N	PRESENT	0
8927	8062	01014K	PARTICIPANT	\N	PRESENT	0
8774	8062	14159V	PARTICIPANT	\N	PRESENT	0
8775	8062	14039A	PARTICIPANT	\N	PRESENT	0
8928	8062	04079R	PARTICIPANT	\N	PRESENT	0
8777	8062	08061X	PARTICIPANT	\N	PRESENT	0
8929	8062	04045F	PARTICIPANT	\N	PRESENT	0
8930	8062	11113E	PARTICIPANT	\N	PRESENT	0
8931	8062	11039M	PARTICIPANT	\N	PRESENT	0
8932	8062	14051J	PARTICIPANT	\N	PRESENT	0
8933	8062	11054L	PARTICIPANT	\N	PRESENT	0
8783	8062	08017T	PARTICIPANT	\N	PRESENT	0
8784	8062	98050T	PARTICIPANT	\N	PRESENT	0
8934	8062	14151M	PARTICIPANT	\N	PRESENT	0
8935	8062	04071H	PARTICIPANT	\N	PRESENT	0
8787	8062	14235Q	PARTICIPANT	\N	PRESENT	0
8936	8062	14193X	PARTICIPANT	\N	PRESENT	0
8789	8062	11057P	PARTICIPANT	\N	PRESENT	0
8790	8062	11067R	PARTICIPANT	\N	PRESENT	0
8937	8062	08056B	PARTICIPANT	\N	PRESENT	0
8938	8062	04040A	PARTICIPANT	\N	PRESENT	0
8793	8062	98018T	PARTICIPANT	\N	PRESENT	0
8939	8062	12041X	PARTICIPANT	\N	PRESENT	0
8940	8062	04085P	PARTICIPANT	\N	PRESENT	0
8941	8062	01019Q	PARTICIPANT	\N	PRESENT	0
8942	8062	14014Q	PARTICIPANT	\N	PRESENT	0
8798	8062	11074Q	PARTICIPANT	\N	PRESENT	0
8943	8062	11085T	PARTICIPANT	\N	PRESENT	0
8944	8062	97011G	PARTICIPANT	\N	PRESENT	0
8945	8062	07024N	PARTICIPANT	\N	PRESENT	0
8802	8062	08022Q	PARTICIPANT	\N	PRESENT	0
8803	8062	05012A	PARTICIPANT	\N	PRESENT	0
8946	8062	11114F	PARTICIPANT	\N	PRESENT	0
8947	8062	01028R	PARTICIPANT	\N	PRESENT	0
8948	8062	14105F	PARTICIPANT	\N	PRESENT	0
8949	8062	14031R	PARTICIPANT	\N	PRESENT	0
8808	8062	14063N	PARTICIPANT	\N	PRESENT	0
8950	8062	08060W	PARTICIPANT	\N	PRESENT	0
8951	8062	04057K	PARTICIPANT	\N	PRESENT	0
8811	8062	01015L	PARTICIPANT	\N	PRESENT	0
8952	8062	14037X	PARTICIPANT	\N	PRESENT	0
8953	8062	04086Q	PARTICIPANT	\N	PRESENT	0
8954	8062	04061F	PARTICIPANT	\N	PRESENT	0
8815	8062	14259Y	PARTICIPANT	\N	PRESENT	0
8955	8062	12042Y	PARTICIPANT	\N	PRESENT	0
8817	8062	11056N	PARTICIPANT	\N	PRESENT	0
8956	8062	92031P	PARTICIPANT	\N	PRESENT	0
8957	8062	08065C	PARTICIPANT	\N	PRESENT	0
8958	8062	08062Y	PARTICIPANT	\N	PRESENT	0
8822	8062	95062K	PARTICIPANT	\N	PRESENT	0
8823	8062	14281W	PARTICIPANT	\N	PRESENT	0
8825	8062	08015R	PARTICIPANT	\N	PRESENT	0
8963	8069	11033F	PARTICIPANT	\N	PRESENT	0
9501	9492	14133K	PARTICIPANT	\N	EXCUSE	0
9504	9492	14073Q	PARTICIPANT	\N	EXCUSE	0
9508	9492	11112D	PARTICIPANT	\N	PRESENT	0
9511	9492	14205J	PARTICIPANT	\N	EXCUSE	0
9773	9772	96004D	PRESIDENT	0	PRESENT	0
9774	9772	14089Y	PARTICIPANT	\N	PRESENT	0
9775	9772	11035H	PARTICIPANT	\N	PRESENT	0
9776	9772	14249W	PARTICIPANT	\N	PRESENT	0
9777	9772	95030B	PARTICIPANT	\N	PRESENT	0
9778	9772	08018U	PARTICIPANT	\N	PRESENT	0
9296	8067	14215L	PARTICIPANT	\N	PRESENT	0
9779	9772	11083R	PARTICIPANT	\N	PRESENT	0
9780	9772	11026G	PARTICIPANT	\N	PRESENT	0
9781	9772	04080J	PARTICIPANT	\N	PRESENT	0
9782	9772	10015M	PARTICIPANT	\N	PRESENT	0
9783	9772	04034C	PARTICIPANT	\N	PRESENT	0
9786	9772	14133K	PARTICIPANT	\N	EXCUSE	0
9303	8067	14195A	PARTICIPANT	\N	PRESENT	0
9787	9772	14026U	PARTICIPANT	\N	EXCUSE	0
9305	8067	01022K	PARTICIPANT	\N	PRESENT	0
9306	8067	14051J	PARTICIPANT	\N	PRESENT	0
9307	8067	14097Y	PARTICIPANT	\N	PRESENT	0
9788	9772	95037J	PARTICIPANT	\N	EXCUSE	0
9789	9772	95039L	PARTICIPANT	\N	EXCUSE	0
9790	9772	14073Q	PARTICIPANT	\N	EXCUSE	0
9791	9772	04057K	PARTICIPANT	\N	EXCUSE	0
11310	11001	08031R	PARTICIPANT	\N	PRESENT	0
11311	11001	00003C	PARTICIPANT	\N	PRESENT	0
11312	11001	11109J	PARTICIPANT	\N	PRESENT	0
11313	11001	04053F	PARTICIPANT	\N	PRESENT	0
9498	9492	14089Y	PRESIDENT	0	PRESENT	0
9500	9492	08068F	PARTICIPANT	\N	PRESENT	0
11314	11001	98046X	PARTICIPANT	\N	PRESENT	0
11315	11001	14269B	PARTICIPANT	\N	PRESENT	0
11316	11001	01011G	PARTICIPANT	\N	PRESENT	0
11317	11001	08016S	PARTICIPANT	\N	PRESENT	0
11318	11001	11063M	PARTICIPANT	\N	PRESENT	0
11319	11001	11112D	PARTICIPANT	\N	PRESENT	0
11320	11001	11114F	PARTICIPANT	\N	PRESENT	0
11321	11001	04095R	PARTICIPANT	\N	PRESENT	0
11322	11001	11113E	PARTICIPANT	\N	PRESENT	0
11323	11001	11061K	PARTICIPANT	\N	PRESENT	0
11324	11001	04045F	PARTICIPANT	\N	PRESENT	0
11325	11001	11072N	PARTICIPANT	\N	PRESENT	0
11327	11001	01003G	PARTICIPANT	\N	PRESENT	0
11328	11001	14030Q	PARTICIPANT	\N	PRESENT	0
11329	11001	14205J	PARTICIPANT	\N	PRESENT	0
11330	11326	14263U	PARTICIPANT	\N	EXCUSE	0
11331	11001	04070G	PARTICIPANT	\N	PRESENT	0
11332	11001	09001P	PARTICIPANT	\N	PRESENT	0
11333	11001	14217N	PARTICIPANT	\N	PRESENT	0
11481	11326	01044R	PARTICIPANT	\N	EXCUSE	0
11335	11001	01046T	PARTICIPANT	\N	PRESENT	0
11336	11001	10006L	PARTICIPANT	\N	PRESENT	0
11484	11003	01034P	PARTICIPANT	\N	PRESENT	0
11338	11001	05008E	PARTICIPANT	\N	PRESENT	0
11339	11001	14247U	PARTICIPANT	\N	PRESENT	0
11340	11001	14209N	PARTICIPANT	\N	PRESENT	0
11341	11001	01041N	PARTICIPANT	\N	PRESENT	0
11486	11003	11067R	PARTICIPANT	\N	PRESENT	0
11343	11001	14037X	PARTICIPANT	\N	PRESENT	0
11344	11001	04043D	PARTICIPANT	\N	PRESENT	0
11345	11001	04081K	PARTICIPANT	\N	PRESENT	0
11346	11001	95039L	PARTICIPANT	\N	PRESENT	0
11347	11001	04055H	PARTICIPANT	\N	PRESENT	0
11348	11001	14265W	PARTICIPANT	\N	PRESENT	0
11349	11001	11044J	PARTICIPANT	\N	PRESENT	0
11350	11001	08018U	PARTICIPANT	\N	PRESENT	0
11351	11001	08069G	PARTICIPANT	\N	PRESENT	0
11352	11001	14119M	PARTICIPANT	\N	PRESENT	0
11353	11001	11011M	PARTICIPANT	\N	PRESENT	0
11354	11001	08039A	PARTICIPANT	\N	PRESENT	0
11355	11326	92015P	PARTICIPANT	\N	EXCUSE	0
11356	11326	14079W	PARTICIPANT	\N	EXCUSE	0
11483	11003	04066L	PARTICIPANT	\N	PRESENT	0
11358	11326	14249W	PARTICIPANT	\N	EXCUSE	0
11359	11001	96004D	PARTICIPANT	\N	PRESENT	0
11360	11326	08035V	PARTICIPANT	\N	EXCUSE	0
11361	11326	14241N	PARTICIPANT	\N	EXCUSE	0
11362	11326	14061L	PARTICIPANT	\N	EXCUSE	0
11363	11326	92045V	PARTICIPANT	\N	EXCUSE	0
11364	11326	11109J	PARTICIPANT	\N	PRESENT	0
11365	11326	04059M	PARTICIPANT	\N	PRESENT	0
11366	11326	11029K	PARTICIPANT	\N	PRESENT	0
11367	11326	01041N	PARTICIPANT	\N	PRESENT	0
11368	11326	07026Q	PARTICIPANT	\N	PRESENT	0
11369	11326	08031R	PARTICIPANT	\N	PRESENT	0
11370	11326	08039A	PARTICIPANT	\N	PRESENT	0
11371	11326	08017T	PARTICIPANT	\N	PRESENT	0
11372	11326	04057K	PARTICIPANT	\N	PRESENT	0
11373	11326	11014C	PARTICIPANT	\N	PRESENT	0
11374	11326	04070G	PRESIDENT	0	PRESENT	0
11375	11003	86034E	PARTICIPANT	\N	PRESENT	0
11376	11003	04092N	PARTICIPANT	\N	PRESENT	0
11377	11003	14219Q	PARTICIPANT	\N	PRESENT	0
11378	11003	08052W	PARTICIPANT	\N	PRESENT	0
11379	11003	11014C	PARTICIPANT	\N	PRESENT	0
11380	11003	11025F	PARTICIPANT	\N	PRESENT	0
11381	11003	14227Q	PARTICIPANT	\N	PRESENT	0
11382	11003	14042U	PARTICIPANT	\N	PRESENT	0
11383	11003	11031D	PARTICIPANT	\N	PRESENT	0
11384	11003	14213J	PARTICIPANT	\N	PRESENT	0
11385	11003	14175V	PARTICIPANT	\N	PRESENT	0
11386	11003	14195A	PARTICIPANT	\N	PRESENT	0
11387	11003	04057K	PARTICIPANT	\N	PRESENT	0
11388	11003	99004R	PARTICIPANT	\N	PRESENT	0
11389	11003	77002U	PARTICIPANT	\N	PRESENT	0
11390	11003	01059Y	PARTICIPANT	\N	PRESENT	0
11391	11003	11103C	PARTICIPANT	\N	PRESENT	0
11392	11003	14271U	PARTICIPANT	\N	PRESENT	0
11393	11003	14281W	PARTICIPANT	\N	PRESENT	0
11394	11003	11055M	PARTICIPANT	\N	PRESENT	0
11395	11003	11029K	PARTICIPANT	\N	PRESENT	0
11396	11003	11093T	PARTICIPANT	\N	PRESENT	0
11397	11003	14261S	PARTICIPANT	\N	PRESENT	0
11398	11003	08031R	PARTICIPANT	\N	PRESENT	0
11399	11003	00003C	PARTICIPANT	\N	PRESENT	0
11400	11003	11109J	PARTICIPANT	\N	PRESENT	0
11401	11003	04053F	PARTICIPANT	\N	PRESENT	0
11402	11003	98046X	PARTICIPANT	\N	PRESENT	0
11403	11003	14269B	PARTICIPANT	\N	PRESENT	0
11404	11003	01011G	PARTICIPANT	\N	PRESENT	0
11405	11003	08016S	PARTICIPANT	\N	PRESENT	0
11406	11003	11063M	PARTICIPANT	\N	PRESENT	0
11407	11003	11112D	PARTICIPANT	\N	PRESENT	0
11408	11003	11114F	PARTICIPANT	\N	PRESENT	0
11409	11003	04095R	PARTICIPANT	\N	PRESENT	0
11410	11003	11113E	PARTICIPANT	\N	PRESENT	0
11411	11003	11061K	PARTICIPANT	\N	PRESENT	0
11412	11003	04045F	PARTICIPANT	\N	PRESENT	0
11413	11003	11072N	PARTICIPANT	\N	PRESENT	0
11414	11003	01003G	PARTICIPANT	\N	PRESENT	0
11415	11003	14030Q	PARTICIPANT	\N	PRESENT	0
11416	11003	14205J	PARTICIPANT	\N	PRESENT	0
11417	11003	04070G	PARTICIPANT	\N	PRESENT	0
11418	11003	09001P	PARTICIPANT	\N	PRESENT	0
11419	11003	14217N	PARTICIPANT	\N	PRESENT	0
11420	11003	01046T	PARTICIPANT	\N	PRESENT	0
11421	11003	10006L	PARTICIPANT	\N	PRESENT	0
11422	11003	05008E	PARTICIPANT	\N	PRESENT	0
11423	11003	14247U	PARTICIPANT	\N	PRESENT	0
11424	11003	14209N	PARTICIPANT	\N	PRESENT	0
11425	11003	01041N	PARTICIPANT	\N	PRESENT	0
11426	11003	14037X	PARTICIPANT	\N	PRESENT	0
11427	11003	04043D	PARTICIPANT	\N	PRESENT	0
11428	11003	04081K	PARTICIPANT	\N	PRESENT	0
11429	11003	95039L	PARTICIPANT	\N	PRESENT	0
11430	11003	04055H	PARTICIPANT	\N	PRESENT	0
11431	11003	14265W	PARTICIPANT	\N	PRESENT	0
11432	11003	11044J	PARTICIPANT	\N	PRESENT	0
11433	11003	08018U	PARTICIPANT	\N	PRESENT	0
11434	11003	08069G	PARTICIPANT	\N	PRESENT	0
11435	11003	14119M	PARTICIPANT	\N	PRESENT	0
11436	11003	11011M	PARTICIPANT	\N	PRESENT	0
11437	11003	08039A	PARTICIPANT	\N	PRESENT	0
11438	11003	96004D	PARTICIPANT	\N	PRESENT	0
11439	11003	14251Q	PARTICIPANT	\N	PRESENT	0
11487	11003	08068F	PARTICIPANT	\N	PRESENT	0
11458	11003	08017T	PARTICIPANT	\N	PRESENT	0
11465	11003	14071N	PARTICIPANT	\N	PRESENT	0
11478	11003	14157T	PARTICIPANT	\N	PRESENT	0
11480	11003	04085P	PARTICIPANT	\N	PRESENT	0
11482	11326	11091R	PARTICIPANT	\N	EXCUSE	0
11488	11003	14151M	PARTICIPANT	\N	PRESENT	0
11489	11003	12042Y	PARTICIPANT	\N	PRESENT	0
9440	9367	11037K	PARTICIPANT	\N	PRESENT	0
9441	9367	14063N	PARTICIPANT	\N	PRESENT	0
9442	9367	08052W	PARTICIPANT	\N	PRESENT	0
9443	9367	01044R	PARTICIPANT	\N	PRESENT	0
9444	9367	01022K	PARTICIPANT	\N	PRESENT	0
9445	9367	04077P	PARTICIPANT	\N	PRESENT	0
9446	9367	14231L	PARTICIPANT	\N	PRESENT	0
9447	9367	14273W	PARTICIPANT	\N	PRESENT	0
9448	9367	14107H	PARTICIPANT	\N	PRESENT	0
9449	9367	05012A	PARTICIPANT	\N	PRESENT	0
9450	9367	11103C	PARTICIPANT	\N	PRESENT	0
9451	9367	86044G	PARTICIPANT	\N	PRESENT	0
9452	9367	04088S	PARTICIPANT	\N	PRESENT	0
9453	9367	14265W	PARTICIPANT	\N	PRESENT	0
9454	9367	04086Q	PARTICIPANT	\N	PRESENT	0
9455	9367	01007L	PARTICIPANT	\N	PRESENT	0
9456	9367	99004R	PARTICIPANT	\N	PRESENT	0
9457	9367	04036E	PARTICIPANT	\N	PRESENT	0
9458	9367	14037X	PARTICIPANT	\N	PRESENT	0
9459	9367	11063M	PARTICIPANT	\N	PRESENT	0
9460	9367	11031D	PARTICIPANT	\N	PRESENT	0
9461	9367	11042G	PARTICIPANT	\N	PRESENT	0
9462	9367	11113E	PARTICIPANT	\N	PRESENT	0
9463	9367	11076S	PARTICIPANT	\N	PRESENT	0
9464	9367	04056J	PARTICIPANT	\N	PRESENT	0
9465	9367	04089T	PARTICIPANT	\N	PRESENT	0
9466	9367	11066Q	PARTICIPANT	\N	PRESENT	0
9467	9367	04053F	PARTICIPANT	\N	PRESENT	0
9468	9367	11012A	PARTICIPANT	\N	PRESENT	0
9469	9367	01014K	PARTICIPANT	\N	PRESENT	0
9470	9367	11040E	PARTICIPANT	\N	PRESENT	0
9471	9367	07024N	PARTICIPANT	\N	PRESENT	0
9472	9367	08062Y	PARTICIPANT	\N	PRESENT	0
9473	9367	02002K	PARTICIPANT	\N	PRESENT	0
9474	9367	97011G	PARTICIPANT	\N	PRESENT	0
9476	9367	98035U	PARTICIPANT	\N	PRESENT	0
9477	9367	11104D	PARTICIPANT	\N	PRESENT	0
9478	9367	12042Y	PARTICIPANT	\N	PRESENT	0
9479	9367	08068F	PARTICIPANT	\N	PRESENT	0
9480	9367	14031R	PARTICIPANT	\N	PRESENT	0
9481	9367	11035H	PARTICIPANT	\N	PRESENT	0
9482	9367	14187A	PARTICIPANT	\N	PRESENT	0
9483	9367	14271U	PARTICIPANT	\N	PRESENT	0
9484	9367	04040A	PARTICIPANT	\N	PRESENT	0
9485	9367	14259Y	PARTICIPANT	\N	PRESENT	0
9486	9367	95030B	PARTICIPANT	\N	PRESENT	0
9487	9367	14033T	PARTICIPANT	\N	PRESENT	0
9488	9367	92039X	PARTICIPANT	\N	PRESENT	0
9489	9367	08055A	PARTICIPANT	\N	PRESENT	0
9490	9367	08016S	PARTICIPANT	\N	PRESENT	0
9491	9367	98046X	PARTICIPANT	\N	PRESENT	0
9493	9367	08009T	PARTICIPANT	\N	PRESENT	0
9494	9367	11093T	PARTICIPANT	\N	PRESENT	0
9495	9367	14041T	PARTICIPANT	\N	PRESENT	0
9496	9367	14207L	PARTICIPANT	\N	PRESENT	0
9497	9367	14257W	PARTICIPANT	\N	PRESENT	0
9438	9367	14051J	PARTICIPANT	\N	PRESENT	0
9439	9367	11055M	PARTICIPANT	\N	PRESENT	0
9499	9367	14103D	PARTICIPANT	\N	PRESENT	0
9502	9367	11080N	PARTICIPANT	\N	PRESENT	0
9503	9367	10015M	PARTICIPANT	\N	PRESENT	0
9505	9367	04097T	PARTICIPANT	\N	PRESENT	0
9506	9367	11083R	PARTICIPANT	\N	PRESENT	0
9509	9367	09001P	PARTICIPANT	\N	PRESENT	0
9510	9367	04055H	PARTICIPANT	\N	PRESENT	0
9512	9367	11097X	PARTICIPANT	\N	PRESENT	0
9514	9367	11091R	PARTICIPANT	\N	PRESENT	0
9517	9367	01058X	PARTICIPANT	\N	PRESENT	0
9518	9367	11039M	PARTICIPANT	\N	PRESENT	0
9520	9367	01028R	PARTICIPANT	\N	PRESENT	0
9522	9367	14039A	PARTICIPANT	\N	PRESENT	0
9523	9367	08017T	PARTICIPANT	\N	PRESENT	0
9524	9367	04034C	PARTICIPANT	\N	PRESENT	0
9525	9367	11026G	PARTICIPANT	\N	PRESENT	0
9527	9367	11099A	PARTICIPANT	\N	PRESENT	0
9529	9367	14089Y	PARTICIPANT	\N	PRESENT	0
9530	9367	14205J	PARTICIPANT	\N	PRESENT	0
9533	9367	11036J	PARTICIPANT	\N	PRESENT	0
9534	9367	01027Q	PARTICIPANT	\N	PRESENT	0
9535	9367	96004D	PARTICIPANT	\N	PRESENT	0
9536	9367	95062K	PARTICIPANT	\N	PRESENT	0
9537	9367	04033B	PARTICIPANT	\N	PRESENT	0
9538	9367	95059Q	PARTICIPANT	\N	PRESENT	0
9539	9367	08010L	PARTICIPANT	\N	PRESENT	0
9540	9367	01019Q	PARTICIPANT	\N	PRESENT	0
9541	9367	08018U	PARTICIPANT	\N	PRESENT	0
9542	9367	01008M	PARTICIPANT	\N	PRESENT	0
9543	9367	11100Y	PARTICIPANT	\N	PRESENT	0
9546	9367	14038Y	PARTICIPANT	\N	PRESENT	0
9549	9367	14249W	PARTICIPANT	\N	PRESENT	0
9550	9367	04074L	PARTICIPANT	\N	PRESENT	0
9551	9367	98050T	PARTICIPANT	\N	PRESENT	0
9552	9367	14071N	PARTICIPANT	\N	PRESENT	0
9553	9367	95039L	PARTICIPANT	\N	PRESENT	0
9554	9367	04081K	PARTICIPANT	\N	PRESENT	0
9556	9367	04042C	PARTICIPANT	\N	PRESENT	0
9558	9367	98018T	PARTICIPANT	\N	PRESENT	0
9560	9367	04035D	PARTICIPANT	\N	PRESENT	0
9561	9367	07034Q	PARTICIPANT	\N	PRESENT	0
9562	9367	92031P	PARTICIPANT	\N	PRESENT	0
9564	9367	01024M	PARTICIPANT	\N	PRESENT	0
9566	9367	14255U	PARTICIPANT	\N	PRESENT	0
9568	9367	11114F	PARTICIPANT	\N	PRESENT	0
9569	9367	11027H	PARTICIPANT	\N	PRESENT	0
9572	9367	11098Y	PARTICIPANT	\N	PRESENT	0
9573	9367	11034G	PARTICIPANT	\N	PRESENT	0
9575	9367	11054L	PARTICIPANT	\N	PRESENT	0
9576	9367	08061X	PARTICIPANT	\N	PRESENT	0
9578	9367	14085U	PARTICIPANT	\N	PRESENT	0
9579	9367	04085P	PARTICIPANT	\N	PRESENT	0
9580	9367	11056N	PARTICIPANT	\N	PRESENT	0
9581	9367	14013P	PARTICIPANT	\N	PRESENT	0
9583	9367	14235Q	PARTICIPANT	\N	PRESENT	0
9584	9367	08051V	PARTICIPANT	\N	PRESENT	0
9586	9367	04080J	PARTICIPANT	\N	PRESENT	0
9587	9367	04061F	PARTICIPANT	\N	PRESENT	0
9589	9367	14135M	PARTICIPANT	\N	PRESENT	0
9591	9367	04049K	PARTICIPANT	\N	PRESENT	0
9592	9367	86034E	PARTICIPANT	\N	PRESENT	0
9597	9367	14217N	PARTICIPANT	\N	PRESENT	0
9598	9367	11033F	PARTICIPANT	\N	PRESENT	0
9599	9367	04071H	PARTICIPANT	\N	PRESENT	0
9601	9367	04057K	PARTICIPANT	\N	PRESENT	0
9605	9367	05008E	PARTICIPANT	\N	PRESENT	0
9611	9367	01031L	PARTICIPANT	\N	PRESENT	0
9612	9367	92045V	PARTICIPANT	\N	PRESENT	0
9613	9367	11068S	PARTICIPANT	\N	PRESENT	0
9614	9367	04095R	PARTICIPANT	\N	PRESENT	0
9616	9367	04038G	PARTICIPANT	\N	PRESENT	0
9617	9367	14059S	PARTICIPANT	\N	PRESENT	0
9618	9367	14219Q	PARTICIPANT	\N	PRESENT	0
9619	9367	14111D	PARTICIPANT	\N	PRESENT	0
9620	9367	95049N	PARTICIPANT	\N	PRESENT	0
9621	9367	11053K	PARTICIPANT	\N	PRESENT	0
9625	9367	14083S	PARTICIPANT	\N	PRESENT	0
9623	9367	04043D	PARTICIPANT	\N	PRESENT	0
9624	9367	11074Q	PARTICIPANT	\N	PRESENT	0
9626	9367	11085T	PARTICIPANT	\N	PRESENT	0
9765	9368	01028R	PARTICIPANT	\N	PRESENT	0
9766	9368	11085T	PARTICIPANT	\N	PRESENT	0
9629	9368	11037K	PARTICIPANT	\N	PRESENT	0
9767	9368	04089T	PARTICIPANT	\N	PRESENT	0
9768	9368	14273W	PARTICIPANT	\N	PRESENT	0
9632	9368	01044R	PARTICIPANT	\N	PRESENT	0
9769	9368	04038G	PARTICIPANT	\N	PRESENT	0
9770	9368	04088S	PARTICIPANT	\N	PRESENT	0
9771	9368	07024N	PARTICIPANT	\N	PRESENT	0
9784	9368	11100Y	PARTICIPANT	\N	PRESENT	0
9785	9368	95030B	PARTICIPANT	\N	PRESENT	0
9792	9368	01007L	PARTICIPANT	\N	PRESENT	0
9793	9368	11103C	PARTICIPANT	\N	PRESENT	0
9794	9368	01024M	PARTICIPANT	\N	PRESENT	0
9795	9368	11012A	PARTICIPANT	\N	PRESENT	0
9796	9368	04095R	PARTICIPANT	\N	PRESENT	0
9797	9368	14257W	PARTICIPANT	\N	PRESENT	0
9798	9368	14205J	PARTICIPANT	\N	PRESENT	0
9799	9368	01008M	PARTICIPANT	\N	PRESENT	0
9800	9368	04043D	PARTICIPANT	\N	PRESENT	0
9801	9368	11097X	PARTICIPANT	\N	PRESENT	0
9802	9368	01058X	PARTICIPANT	\N	PRESENT	0
9803	9368	04057K	PARTICIPANT	\N	PRESENT	0
9804	9368	04074L	PARTICIPANT	\N	PRESENT	0
9805	9368	01022K	PARTICIPANT	\N	PRESENT	0
9806	9368	14219Q	PARTICIPANT	\N	PRESENT	0
9807	9368	11036J	PARTICIPANT	\N	PRESENT	0
9808	9368	98046X	PARTICIPANT	\N	PRESENT	0
9809	9368	92031P	PARTICIPANT	\N	PRESENT	0
9810	9368	14271U	PARTICIPANT	\N	PRESENT	0
9811	9368	08068F	PARTICIPANT	\N	PRESENT	0
9812	9368	04053F	PARTICIPANT	\N	PRESENT	0
9813	9368	08016S	PARTICIPANT	\N	PRESENT	0
9814	9368	11114F	PARTICIPANT	\N	PRESENT	0
9507	9475	04053F	PARTICIPANT	\N	PRESENT	0
9513	9475	14255U	PARTICIPANT	\N	PRESENT	0
10069	9997	11085T	PARTICIPANT	\N	PRESENT	0
10070	9997	14107H	PARTICIPANT	\N	PRESENT	0
9519	9475	14053L	PARTICIPANT	\N	PRESENT	0
9521	9475	11103C	PARTICIPANT	\N	PRESENT	0
10071	9997	04035D	PARTICIPANT	\N	PRESENT	0
9528	9475	14195A	PARTICIPANT	\N	PRESENT	0
9817	9368	14033T	PARTICIPANT	\N	PRESENT	0
9532	9475	08052W	PARTICIPANT	\N	PRESENT	0
10072	9997	11067R	PARTICIPANT	\N	PRESENT	0
10073	9997	14103D	PARTICIPANT	\N	PRESENT	0
10074	9997	11020A	PARTICIPANT	\N	PRESENT	0
10075	9997	01056V	PARTICIPANT	\N	PRESENT	0
9555	9475	14217N	PARTICIPANT	\N	PRESENT	0
9557	9475	14042U	PARTICIPANT	\N	PRESENT	0
9559	9475	12042Y	PARTICIPANT	\N	PRESENT	0
10076	9997	11025F	PARTICIPANT	\N	PRESENT	0
10077	9997	11026G	PARTICIPANT	\N	PRESENT	0
9567	9475	14231L	PARTICIPANT	\N	PRESENT	0
10078	9997	14281W	PARTICIPANT	\N	PRESENT	0
10079	9997	14063N	PARTICIPANT	\N	PRESENT	0
9574	9475	14213J	PARTICIPANT	\N	PRESENT	0
9577	9475	11112D	PARTICIPANT	\N	PRESENT	0
9582	9475	11067R	PARTICIPANT	\N	PRESENT	0
10080	9997	11109J	PARTICIPANT	\N	PRESENT	0
9588	9475	04092N	PRESIDENT	0	PRESENT	0
9590	9475	14265W	PARTICIPANT	\N	PRESENT	0
9593	9475	14119M	PARTICIPANT	\N	PRESENT	0
9594	9475	14071N	PARTICIPANT	\N	PRESENT	0
10081	9997	11068S	PARTICIPANT	\N	PRESENT	0
9596	9475	04043D	PARTICIPANT	\N	PRESENT	0
9600	9475	14271U	PARTICIPANT	\N	PRESENT	0
10082	9997	14179A	PARTICIPANT	\N	PRESENT	0
9603	9475	11097X	PARTICIPANT	\N	PRESENT	0
10083	9997	14231L	PARTICIPANT	\N	PRESENT	0
10084	9997	11069T	PARTICIPANT	\N	PRESENT	0
9818	9368	14085U	PARTICIPANT	\N	PRESENT	0
10085	9997	04043D	PARTICIPANT	\N	PRESENT	0
9609	9475	11063M	PARTICIPANT	\N	PRESENT	0
10086	9997	14273W	PARTICIPANT	\N	PRESENT	0
10087	9997	14239U	PARTICIPANT	\N	PRESENT	0
9819	9368	11113E	PARTICIPANT	\N	PRESENT	0
9820	9368	04042C	PARTICIPANT	\N	PRESENT	0
9821	9368	14083S	PARTICIPANT	\N	PRESENT	0
9822	9368	08010L	PARTICIPANT	\N	PRESENT	0
9823	9368	14013P	PARTICIPANT	\N	PRESENT	0
9824	9368	01016M	PARTICIPANT	\N	PRESENT	0
9825	9368	14071N	PARTICIPANT	\N	PRESENT	0
9669	9368	11035H	PARTICIPANT	\N	PRESENT	0
9826	9368	14089Y	PARTICIPANT	\N	PRESENT	0
9827	9368	14235Q	PARTICIPANT	\N	PRESENT	0
9828	9368	99004R	PARTICIPANT	\N	PRESENT	0
9673	9368	14259Y	PARTICIPANT	\N	PRESENT	0
9829	9368	04085P	PARTICIPANT	\N	PRESENT	0
10088	9997	98022P	PARTICIPANT	\N	PRESENT	0
10089	9997	11100Y	PARTICIPANT	\N	PRESENT	0
10090	9997	11070L	PARTICIPANT	\N	PRESENT	0
10091	9997	11031D	PARTICIPANT	\N	PRESENT	0
10109	9997	11066Q	PARTICIPANT	\N	PRESENT	0
10110	9997	11039M	PARTICIPANT	\N	PRESENT	0
10161	9997	14213J	PARTICIPANT	\N	PRESENT	0
10165	9997	14199E	PARTICIPANT	\N	PRESENT	0
10166	9997	14055N	PARTICIPANT	\N	PRESENT	0
10254	9998	01059Y	PARTICIPANT	\N	PRESENT	0
10255	9998	11012A	PARTICIPANT	\N	PRESENT	0
10256	9998	14267Y	PARTICIPANT	\N	PRESENT	0
10257	9998	11055M	PARTICIPANT	\N	PRESENT	0
10258	9998	08041T	PARTICIPANT	\N	PRESENT	0
10252	9998	14071N	PARTICIPANT	\N	PRESENT	0
10253	9998	00003C	PARTICIPANT	\N	PRESENT	0
10259	9998	11067R	PARTICIPANT	\N	PRESENT	0
10260	10209	04053F	PARTICIPANT	\N	PRESENT	0
10261	10209	14255U	PARTICIPANT	\N	PRESENT	0
10262	10209	14195A	PARTICIPANT	\N	PRESENT	0
10263	10209	11031D	PARTICIPANT	\N	PRESENT	0
10264	10209	08052W	PARTICIPANT	\N	PRESENT	0
10265	10209	14217N	PARTICIPANT	\N	PRESENT	0
10266	10209	14213J	PARTICIPANT	\N	PRESENT	0
10267	10209	04045F	PARTICIPANT	\N	PRESENT	0
10268	10209	01034P	PARTICIPANT	\N	PRESENT	0
10269	10209	11025F	PARTICIPANT	\N	PRESENT	0
10270	9998	14103D	PARTICIPANT	\N	PRESENT	0
10271	9998	14235Q	PARTICIPANT	\N	PRESENT	0
10272	9998	14263U	PARTICIPANT	\N	PRESENT	0
10273	9998	11103C	PARTICIPANT	\N	PRESENT	0
10274	9998	11091R	PARTICIPANT	\N	PRESENT	0
10275	9998	14041T	PARTICIPANT	\N	PRESENT	0
10276	9998	14213J	PARTICIPANT	\N	PRESENT	0
10277	9998	12042Y	PARTICIPANT	\N	PRESENT	0
10278	9998	14179A	PARTICIPANT	\N	PRESENT	0
10279	9998	14073Q	PARTICIPANT	\N	PRESENT	0
10280	9998	11031D	PARTICIPANT	\N	PRESENT	0
10281	9998	04095R	PARTICIPANT	\N	PRESENT	0
10282	9998	14217N	PARTICIPANT	\N	PRESENT	0
10283	9998	14187A	PARTICIPANT	\N	PRESENT	0
10284	9998	04081K	PARTICIPANT	\N	PRESENT	0
10285	9998	14119M	PARTICIPANT	\N	PRESENT	0
10286	9998	11042G	PARTICIPANT	\N	PRESENT	0
10287	9998	14209N	PARTICIPANT	\N	PRESENT	0
9720	9368	95039L	PARTICIPANT	\N	PRESENT	0
9721	9368	04081K	PARTICIPANT	\N	PRESENT	0
10288	9998	08015R	PARTICIPANT	\N	PRESENT	0
10289	9998	04088S	PARTICIPANT	\N	PRESENT	0
10290	9998	14033T	PARTICIPANT	\N	PRESENT	0
10291	9998	14205J	PARTICIPANT	\N	PRESENT	0
10292	9998	08028W	PARTICIPANT	\N	PRESENT	0
10293	9998	01022K	PARTICIPANT	\N	PRESENT	0
10294	9998	14121F	PARTICIPANT	\N	PRESENT	0
10295	9998	14089Y	PARTICIPANT	\N	PRESENT	0
10296	9998	08047A	PARTICIPANT	\N	PRESENT	0
9732	9368	11034G	PARTICIPANT	\N	PRESENT	0
10297	9998	86044G	PARTICIPANT	\N	PRESENT	0
10298	9998	14207L	PARTICIPANT	\N	PRESENT	0
10299	9998	04053F	PARTICIPANT	\N	PRESENT	0
10300	9998	11100Y	PARTICIPANT	\N	PRESENT	0
10301	9998	01003G	PARTICIPANT	\N	PRESENT	0
10302	9998	80027E	PARTICIPANT	\N	PRESENT	0
10303	9998	11081P	PARTICIPANT	\N	PRESENT	0
9740	9368	08051V	PARTICIPANT	\N	PRESENT	0
10304	9998	88008L	PARTICIPANT	\N	PRESENT	0
10305	9998	08010L	PARTICIPANT	\N	PRESENT	0
10306	9998	97011G	PARTICIPANT	\N	PRESENT	0
10307	9998	11025F	PARTICIPANT	\N	PRESENT	0
10308	9998	08039A	PARTICIPANT	\N	PRESENT	0
10309	9998	11095V	PARTICIPANT	\N	PRESENT	0
10310	9998	11089X	PARTICIPANT	\N	PRESENT	0
10311	9998	11014C	PARTICIPANT	\N	PRESENT	0
10312	9998	11109J	PARTICIPANT	\N	PRESENT	0
9750	9368	05008E	PARTICIPANT	\N	PRESENT	0
10313	9998	14215L	PARTICIPANT	\N	PRESENT	0
10314	9998	14087W	PARTICIPANT	\N	PRESENT	0
10315	9998	14173T	PARTICIPANT	\N	PRESENT	0
10316	9998	14223L	PARTICIPANT	\N	PRESENT	0
10317	9998	14109K	PARTICIPANT	\N	PRESENT	0
10318	9998	11057P	PARTICIPANT	\N	PRESENT	0
10319	9998	95015C	PARTICIPANT	\N	PRESENT	0
10391	10023	01007L	PARTICIPANT	\N	PRESENT	0
9759	9368	95049N	PARTICIPANT	\N	PRESENT	0
10392	10023	14263U	PARTICIPANT	\N	PRESENT	0
10393	10023	08011M	PARTICIPANT	\N	PRESENT	0
10394	10023	01031L	PARTICIPANT	\N	PRESENT	0
10395	10023	11040E	PARTICIPANT	\N	PRESENT	0
10396	10023	01013J	PARTICIPANT	\N	PRESENT	0
9815	9368	11091R	PARTICIPANT	\N	PRESENT	0
9816	9368	04033B	PARTICIPANT	\N	PRESENT	0
10397	10023	98046X	PARTICIPANT	\N	PRESENT	0
10398	10023	11057P	PARTICIPANT	\N	PRESENT	0
10399	10023	14257W	PARTICIPANT	\N	PRESENT	0
10400	10023	11083R	PARTICIPANT	\N	PRESENT	0
10401	10023	01024M	PARTICIPANT	\N	PRESENT	0
10402	10023	11070L	PARTICIPANT	\N	PRESENT	0
10403	10023	14187A	PARTICIPANT	\N	PRESENT	0
10404	10023	14147R	PARTICIPANT	\N	PRESENT	0
10405	10023	11088W	PARTICIPANT	\N	PRESENT	0
10406	10023	08010L	PARTICIPANT	\N	PRESENT	0
10407	10023	01057W	PARTICIPANT	\N	PRESENT	0
10408	10023	98018T	PARTICIPANT	\N	PRESENT	0
10409	10023	14087W	PARTICIPANT	\N	PRESENT	0
10410	10023	04086Q	PARTICIPANT	\N	PRESENT	0
10411	10023	14197C	PARTICIPANT	\N	PRESENT	0
10412	10023	01027Q	PARTICIPANT	\N	PRESENT	0
10413	10023	80013X	PARTICIPANT	\N	PRESENT	0
10414	10023	08022Q	PARTICIPANT	\N	PRESENT	0
10415	10023	01016M	PARTICIPANT	\N	PRESENT	0
10416	10023	11025F	PARTICIPANT	\N	PRESENT	0
10417	10023	01046T	PARTICIPANT	\N	PRESENT	0
10418	10023	11036J	PARTICIPANT	\N	PRESENT	0
10419	10023	96004D	PARTICIPANT	\N	PRESENT	0
10420	10023	01025N	PARTICIPANT	\N	PRESENT	0
10421	10023	14030Q	PARTICIPANT	\N	PRESENT	0
10422	10023	14169X	PARTICIPANT	\N	PRESENT	0
10423	10023	14034U	PARTICIPANT	\N	PRESENT	0
10426	10023	14097Y	PARTICIPANT	\N	PRESENT	0
10427	10023	08015R	PARTICIPANT	\N	PRESENT	0
10428	10023	11068S	PARTICIPANT	\N	PRESENT	0
10429	10023	07029T	PARTICIPANT	\N	PRESENT	0
10430	10023	14265W	PARTICIPANT	\N	PRESENT	0
10431	10023	14033T	PARTICIPANT	\N	PRESENT	0
10432	10023	11042G	PARTICIPANT	\N	PRESENT	0
10433	10023	14217N	PARTICIPANT	\N	PRESENT	0
10434	10023	11097X	PARTICIPANT	\N	PRESENT	0
10435	10023	11053K	PARTICIPANT	\N	PRESENT	0
10482	10481	01007L	PARTICIPANT	\N	PRESENT	0
10483	10481	14263U	PARTICIPANT	\N	PRESENT	0
10662	10481	01016M	PARTICIPANT	\N	PRESENT	0
10663	10481	11025F	PARTICIPANT	\N	PRESENT	0
10664	10481	08024S	PARTICIPANT	\N	PRESENT	0
10665	10481	08047A	PARTICIPANT	\N	PRESENT	0
10666	10481	11100Y	PARTICIPANT	\N	PRESENT	0
10667	10481	11104D	PARTICIPANT	\N	PRESENT	0
10490	10481	14257W	PARTICIPANT	\N	PRESENT	0
10668	10481	14031R	PARTICIPANT	\N	PRESENT	0
10492	10481	01024M	PARTICIPANT	\N	PRESENT	0
10669	10481	11039M	PARTICIPANT	\N	PRESENT	0
10673	10481	14135M	PARTICIPANT	\N	PRESENT	0
10495	10481	14147R	PARTICIPANT	\N	PRESENT	0
10674	10481	14034U	PARTICIPANT	\N	PRESENT	0
10424	10023	88008L	PARTICIPANT	\N	PRESENT	0
10425	10023	08053X	PARTICIPANT	\N	PRESENT	0
10675	10481	07024N	PARTICIPANT	\N	PRESENT	0
10676	10481	98050T	PARTICIPANT	\N	PRESENT	0
10677	10481	14030Q	PARTICIPANT	\N	PRESENT	0
10678	10481	07034Q	PARTICIPANT	\N	PRESENT	0
10679	10481	14157T	PARTICIPANT	\N	PRESENT	0
10502	10481	14197C	PARTICIPANT	\N	PRESENT	0
10680	10481	96004D	PARTICIPANT	\N	PRESENT	0
10681	10661	14239U	PARTICIPANT	\N	PRESENT	0
10682	10661	11055M	PARTICIPANT	\N	PRESENT	0
10683	10661	01046T	PARTICIPANT	\N	PRESENT	0
10684	10661	04053F	PARTICIPANT	\N	PRESENT	0
10685	10661	14255U	PARTICIPANT	\N	PRESENT	0
10509	10481	11036J	PARTICIPANT	\N	PRESENT	0
10686	10661	04066L	PARTICIPANT	\N	PRESENT	0
10511	10481	01025N	PARTICIPANT	\N	PRESENT	0
10687	10661	00003C	PARTICIPANT	\N	PRESENT	0
10513	10481	14169X	PARTICIPANT	\N	PRESENT	0
10688	10661	14053L	PARTICIPANT	\N	PRESENT	0
10515	10481	88008L	PARTICIPANT	\N	PRESENT	0
10689	10661	11103C	PARTICIPANT	\N	PRESENT	0
10517	10481	14097Y	PARTICIPANT	\N	PRESENT	0
10801	10527	08055A	PARTICIPANT	\N	PRESENT	0
10691	10661	14195A	PARTICIPANT	\N	PRESENT	0
10520	10481	07029T	PARTICIPANT	\N	PRESENT	0
10692	10661	14267Y	PARTICIPANT	\N	PRESENT	0
10522	10481	14033T	PARTICIPANT	\N	PRESENT	0
10802	10527	11034G	PARTICIPANT	\N	PRESENT	0
10694	10661	11031D	PARTICIPANT	\N	PRESENT	0
10695	10661	08052W	PARTICIPANT	\N	PRESENT	0
10696	10661	01059Y	PARTICIPANT	\N	PRESENT	0
10613	10481	11037K	PARTICIPANT	\N	PRESENT	0
10614	10481	14038Y	PARTICIPANT	\N	PRESENT	0
10615	10481	14063N	PARTICIPANT	\N	PRESENT	0
10616	10481	14179A	PARTICIPANT	\N	PRESENT	0
10617	10481	14273W	PARTICIPANT	\N	PRESENT	0
10618	10481	14215L	PARTICIPANT	\N	PRESENT	0
10619	10481	07026Q	PARTICIPANT	\N	PRESENT	0
10620	10481	04070G	PARTICIPANT	\N	PRESENT	0
10621	10481	08009T	PARTICIPANT	\N	PRESENT	0
10622	10481	08031R	PARTICIPANT	\N	PRESENT	0
10623	10481	11012A	PARTICIPANT	\N	PRESENT	0
10624	10481	11043H	PARTICIPANT	\N	PRESENT	0
10625	10481	95037J	PARTICIPANT	\N	PRESENT	0
10626	10481	14207L	PARTICIPANT	\N	PRESENT	0
10627	10481	08055A	PARTICIPANT	\N	PRESENT	0
10628	10481	14229S	PARTICIPANT	\N	PRESENT	0
10629	10481	11029K	PARTICIPANT	\N	PRESENT	0
10630	10481	08043V	PARTICIPANT	\N	PRESENT	0
10631	10481	04059M	PARTICIPANT	\N	PRESENT	0
10632	10481	11091R	PARTICIPANT	\N	PRESENT	0
10633	10481	95015C	PARTICIPANT	\N	PRESENT	0
10634	10481	04057K	PARTICIPANT	\N	PRESENT	0
10635	10481	14041T	PARTICIPANT	\N	PRESENT	0
10636	10481	08039A	PARTICIPANT	\N	PRESENT	0
10637	10481	01058X	PARTICIPANT	\N	PRESENT	0
10638	10481	14219Q	PARTICIPANT	\N	PRESENT	0
10639	10481	14089Y	PARTICIPANT	\N	PRESENT	0
10640	10481	14059S	PARTICIPANT	\N	PRESENT	0
10641	10481	14209N	PARTICIPANT	\N	PRESENT	0
10642	10481	04056J	PARTICIPANT	\N	PRESENT	0
10643	10481	11107G	PARTICIPANT	\N	PRESENT	0
10644	10481	80027E	PARTICIPANT	\N	PRESENT	0
10645	10481	05012A	PARTICIPANT	\N	PRESENT	0
10646	10481	14073Q	PARTICIPANT	\N	PRESENT	0
10647	10481	97011G	PARTICIPANT	\N	PRESENT	0
10648	10481	14111D	PARTICIPANT	\N	PRESENT	0
10649	10481	11089X	PARTICIPANT	\N	PRESENT	0
10650	10481	14103D	PARTICIPANT	\N	PRESENT	0
10651	10481	04033B	PARTICIPANT	\N	PRESENT	0
10652	10481	04088S	PARTICIPANT	\N	PRESENT	0
10653	10481	14237S	PARTICIPANT	\N	PRESENT	0
10654	10481	14109K	PARTICIPANT	\N	PRESENT	0
10655	10481	08068F	PARTICIPANT	\N	PRESENT	0
10656	10481	11095V	PARTICIPANT	\N	PRESENT	0
10657	10481	01048V	PARTICIPANT	\N	PRESENT	0
10658	10481	04067M	PARTICIPANT	\N	PRESENT	0
10659	10481	89017R	PARTICIPANT	\N	PRESENT	0
10660	10481	14241N	PARTICIPANT	\N	PRESENT	0
10697	10661	04081K	PARTICIPANT	\N	PRESENT	0
10698	10661	98024R	PARTICIPANT	\N	EXCUSE	0
10699	10661	10006L	PARTICIPANT	\N	PRESENT	0
10700	10661	04067M	PARTICIPANT	\N	PRESENT	0
10701	10661	14217N	PARTICIPANT	\N	PRESENT	0
10702	10661	14042U	PARTICIPANT	\N	PRESENT	0
10703	10661	14151M	PARTICIPANT	\N	PRESENT	0
10704	10661	12042Y	PARTICIPANT	\N	PRESENT	0
10705	10661	14281W	PARTICIPANT	\N	PRESENT	0
10706	10661	14087W	PARTICIPANT	\N	PRESENT	0
10803	10527	07026Q	PARTICIPANT	\N	PRESENT	0
10804	10527	11036J	PARTICIPANT	\N	PRESENT	0
10709	10661	14231L	PARTICIPANT	\N	PRESENT	0
10710	10661	11061K	PARTICIPANT	\N	PRESENT	0
10711	10661	08048B	PARTICIPANT	\N	PRESENT	0
10712	10661	08041T	PARTICIPANT	\N	PRESENT	0
10805	10527	14063N	PARTICIPANT	\N	PRESENT	0
10714	10661	14026U	PARTICIPANT	\N	PRESENT	0
10715	10661	14213J	PARTICIPANT	\N	PRESENT	0
10716	10661	14121F	PARTICIPANT	\N	PRESENT	0
10717	10661	11112D	PARTICIPANT	\N	PRESENT	0
10718	10661	14037X	PARTICIPANT	\N	PRESENT	0
10719	10661	14018U	PARTICIPANT	\N	PRESENT	0
10720	10661	11067R	PARTICIPANT	\N	PRESENT	0
10721	10661	14223L	PARTICIPANT	\N	PRESENT	0
10722	10661	04092N	PRESIDENT	0	PRESENT	0
10723	10661	14265W	PARTICIPANT	\N	PRESENT	0
10724	10661	14119M	PARTICIPANT	\N	PRESENT	0
10725	10661	14071N	PARTICIPANT	\N	PRESENT	0
10806	10527	04044E	PARTICIPANT	\N	PRESENT	0
10727	10661	04043D	PARTICIPANT	\N	PRESENT	0
10728	10661	14271U	PARTICIPANT	\N	PRESENT	0
10807	10527	01047U	PARTICIPANT	\N	PRESENT	0
10730	10661	11093T	PARTICIPANT	\N	PRESENT	0
10731	10661	11097X	PARTICIPANT	\N	PRESENT	0
10732	10661	04045F	PARTICIPANT	\N	PRESENT	0
10733	10661	14227Q	PARTICIPANT	\N	PRESENT	0
10734	10661	01034P	PARTICIPANT	\N	PRESENT	0
10735	10661	11025F	PARTICIPANT	\N	PRESENT	0
10808	10527	11033F	PARTICIPANT	\N	PRESENT	0
10809	10527	11012A	PARTICIPANT	\N	PRESENT	0
10810	10527	14103D	PARTICIPANT	\N	PRESENT	0
10811	10527	14030Q	PARTICIPANT	\N	PRESENT	0
10812	10527	01024M	PARTICIPANT	\N	PRESENT	0
10813	10527	04038G	PARTICIPANT	\N	PRESENT	0
10814	10527	95039L	PARTICIPANT	\N	PRESENT	0
10815	10527	14215L	PARTICIPANT	\N	PRESENT	0
10816	10527	04056J	PARTICIPANT	\N	PRESENT	0
10817	10527	01028R	PARTICIPANT	\N	PRESENT	0
10818	10527	11056N	PARTICIPANT	\N	PRESENT	0
10819	10527	08018U	PARTICIPANT	\N	PRESENT	0
10820	10527	14041T	PARTICIPANT	\N	PRESENT	0
10821	10527	14038Y	PARTICIPANT	\N	PRESENT	0
10874	10527	11026G	PARTICIPANT	\N	PRESENT	0
10872	10527	14265W	PARTICIPANT	\N	PRESENT	0
10873	10527	97011G	PARTICIPANT	\N	PRESENT	0
10875	10527	14073Q	PARTICIPANT	\N	PRESENT	0
10876	10527	01003G	PARTICIPANT	\N	PRESENT	0
10877	10527	14273W	PARTICIPANT	\N	PRESENT	0
10878	10527	14231L	PARTICIPANT	\N	PRESENT	0
10879	10527	11089X	PARTICIPANT	\N	PRESENT	0
10880	10527	04057K	PARTICIPANT	\N	PRESENT	0
10881	10527	11025F	PARTICIPANT	\N	PRESENT	0
10884	10527	14225N	PARTICIPANT	\N	PRESENT	0
10885	10527	95063L	PARTICIPANT	\N	PRESENT	0
10886	10527	99004R	PARTICIPANT	\N	PRESENT	0
10888	10887	04038G	PARTICIPANT	\N	PRESENT	0
10889	10887	14041T	PARTICIPANT	\N	PRESENT	0
10890	10887	01024M	PARTICIPANT	\N	PRESENT	0
10891	10887	14215L	PARTICIPANT	\N	PRESENT	0
10892	10887	11034G	PARTICIPANT	\N	PRESENT	0
10893	10887	05008E	PARTICIPANT	\N	EXCUSE	0
10894	10887	08018U	PARTICIPANT	\N	PRESENT	0
10895	10887	95039L	PARTICIPANT	\N	PRESENT	0
10896	10887	14273W	PARTICIPANT	\N	PRESENT	0
10897	10887	14147R	PARTICIPANT	\N	EXCUSE	0
10898	10887	07034Q	PARTICIPANT	\N	PRESENT	0
10899	10887	10015M	PARTICIPANT	\N	EXCUSE	0
10900	10887	01028R	PARTICIPANT	\N	PRESENT	0
10901	10887	04056J	PARTICIPANT	\N	PRESENT	0
10902	10887	11037K	PARTICIPANT	\N	EXCUSE	0
10903	10887	01047U	PARTICIPANT	\N	PRESENT	0
10904	10887	04044E	PRESIDENT	0	PRESENT	0
11078	11021	92020L	PARTICIPANT	\N	EXCUSE	0
11023	11021	04054G	PARTICIPANT	\N	EXCUSE	0
11024	11021	04040A	PARTICIPANT	\N	PRESENT	0
11025	11021	08058D	PARTICIPANT	\N	EXCUSE	0
11026	11021	04042C	PARTICIPANT	\N	EXCUSE	0
11027	11021	77002U	PARTICIPANT	\N	EXCUSE	0
11028	11021	98029W	PARTICIPANT	\N	PRESENT	0
11080	11079	04054G	PARTICIPANT	\N	EXCUSE	0
11081	11079	04040A	PARTICIPANT	\N	PRESENT	0
10882	10527	08051V	PARTICIPANT	\N	PRESENT	0
10883	10527	14219Q	PARTICIPANT	\N	PRESENT	0
11031	11021	98018T	PARTICIPANT	\N	EXCUSE	0
11082	11079	08058D	PARTICIPANT	\N	EXCUSE	0
11083	11079	04042C	PARTICIPANT	\N	EXCUSE	0
11034	11021	95030B	PARTICIPANT	\N	PRESENT	0
11084	11079	77002U	PARTICIPANT	\N	EXCUSE	0
11085	11079	98029W	PARTICIPANT	\N	PRESENT	0
11037	11021	97011G	PARTICIPANT	\N	PRESENT	0
11086	11079	98018T	PARTICIPANT	\N	EXCUSE	0
11087	11079	92020L	PARTICIPANT	\N	PRESENT	0
11040	11021	07024N	PARTICIPANT	\N	EXCUSE	0
11088	11079	97011G	PARTICIPANT	\N	PRESENT	0
11042	11021	14014Q	PARTICIPANT	\N	PRESENT	0
11043	11021	11015D	PARTICIPANT	\N	PRESENT	0
11044	11021	07004J	PARTICIPANT	\N	PRESENT	0
11045	11021	95035G	PARTICIPANT	\N	EXCUSE	0
11046	11021	08056B	PARTICIPANT	\N	EXCUSE	0
11047	11021	14211G	PARTICIPANT	\N	PRESENT	0
11089	11079	04035D	PARTICIPANT	\N	PRESENT	0
11049	11021	11064N	PARTICIPANT	\N	PRESENT	0
11050	11021	95037J	PARTICIPANT	\N	EXCUSE	0
11051	11021	04078Q	PARTICIPANT	\N	PRESENT	0
11090	11079	07024N	PARTICIPANT	\N	EXCUSE	0
11053	11021	95041E	PARTICIPANT	\N	PRESENT	0
11054	11021	04036E	PARTICIPANT	\N	PRESENT	0
11091	11079	14014Q	PARTICIPANT	\N	PRESENT	0
11092	11079	07004J	PARTICIPANT	\N	PRESENT	0
11093	11079	95035G	PARTICIPANT	\N	EXCUSE	0
11058	11021	92031P	PARTICIPANT	\N	EXCUSE	0
11059	11021	11106F	PARTICIPANT	\N	PRESENT	0
11060	11021	14251Q	PARTICIPANT	\N	PRESENT	0
11094	11079	08056B	PARTICIPANT	\N	EXCUSE	0
11095	11079	11064N	PARTICIPANT	\N	PRESENT	0
11096	11079	95037J	PARTICIPANT	\N	EXCUSE	0
11097	11079	04078Q	PARTICIPANT	\N	PRESENT	0
11065	11021	14253S	PARTICIPANT	\N	PRESENT	0
11066	11021	08047A	PARTICIPANT	\N	PRESENT	0
11098	11079	95041E	PARTICIPANT	\N	PRESENT	0
11068	11021	14193X	PARTICIPANT	\N	PRESENT	0
11069	11021	98021N	PARTICIPANT	\N	EXCUSE	0
11099	11079	04036E	PARTICIPANT	\N	PRESENT	0
11100	11079	04077P	PARTICIPANT	\N	PRESENT	0
11072	11021	95059Q	PRESIDENT	0	PRESENT	0
11073	11021	86044G	PARTICIPANT	\N	PRESENT	0
11074	11021	01014K	PARTICIPANT	\N	PRESENT	0
11075	11021	11054L	PARTICIPANT	\N	PRESENT	0
11076	11021	01056V	PARTICIPANT	\N	EXCUSE	0
11077	11021	92044U	PARTICIPANT	\N	PRESENT	0
11101	11079	92031P	PARTICIPANT	\N	EXCUSE	0
11102	11079	11106F	PARTICIPANT	\N	PRESENT	0
11103	11079	14251Q	PARTICIPANT	\N	PRESENT	0
11104	11079	08053X	PARTICIPANT	\N	PRESENT	0
11105	11079	11105E	PARTICIPANT	\N	EXCUSE	0
11106	11079	08047A	PARTICIPANT	\N	PRESENT	0
11107	11079	98021N	PARTICIPANT	\N	EXCUSE	0
11108	11079	95059Q	PRESIDENT	0	PRESENT	0
11109	11079	86044G	PARTICIPANT	\N	PRESENT	0
11110	11079	01014K	PARTICIPANT	\N	PRESENT	0
11111	11079	11054L	PARTICIPANT	\N	PRESENT	0
11112	11079	01056V	PARTICIPANT	\N	EXCUSE	0
11113	11079	92044U	PARTICIPANT	\N	PRESENT	0
11114	11079	04033B	PARTICIPANT	\N	PRESENT	0
11115	11079	01041N	PARTICIPANT	\N	PRESENT	0
11116	11079	99004R	PARTICIPANT	\N	PRESENT	0
11117	11079	14187A	PARTICIPANT	\N	PRESENT	0
11118	11079	10006L	PARTICIPANT	\N	PRESENT	0
11119	11079	14219Q	PARTICIPANT	\N	PRESENT	0
11120	11079	14167V	PARTICIPANT	\N	PRESENT	0
11121	11079	14265W	PARTICIPANT	\N	PRESENT	0
11122	11079	11085T	PARTICIPANT	\N	PRESENT	0
11123	11079	01015L	PARTICIPANT	\N	PRESENT	0
11124	11079	04086Q	PARTICIPANT	\N	PRESENT	0
11125	11079	01028R	PARTICIPANT	\N	PRESENT	0
11126	11079	04034C	PARTICIPANT	\N	PRESENT	0
11127	11079	01027Q	PARTICIPANT	\N	PRESENT	0
11128	11079	05008E	PARTICIPANT	\N	PRESENT	0
11129	11079	04061F	PARTICIPANT	\N	PRESENT	0
11130	11079	11012A	PARTICIPANT	\N	PRESENT	0
11131	11079	14227Q	PARTICIPANT	\N	PRESENT	0
11132	11079	14105F	PARTICIPANT	\N	PRESENT	0
11133	11079	14225N	PARTICIPANT	\N	PRESENT	0
11134	11079	11066Q	PARTICIPANT	\N	PRESENT	0
11185	11184	89017R	PARTICIPANT	\N	EXCUSE	0
11186	11184	01031L	PRESIDENT	0	PRESENT	0
11188	11184	01013J	PARTICIPANT	\N	EXCUSE	0
11447	11440	11044J	PARTICIPANT	\N	PRESENT	0
11191	11184	08014Q	PARTICIPANT	\N	PRESENT	0
11449	11440	14195A	PARTICIPANT	\N	PRESENT	0
11193	11184	14175V	PARTICIPANT	\N	PRESENT	0
11194	11184	14083S	PARTICIPANT	\N	PRESENT	0
11450	11440	11031D	PARTICIPANT	\N	PRESENT	0
11196	11184	14085U	PARTICIPANT	\N	PRESENT	0
11197	11184	11042G	PARTICIPANT	\N	PRESENT	0
11451	11440	08052W	PARTICIPANT	\N	PRESENT	0
11199	11184	04086Q	PARTICIPANT	\N	PRESENT	0
11452	11440	01059Y	PARTICIPANT	\N	PRESENT	0
11201	11184	11070L	PARTICIPANT	\N	PRESENT	0
11202	11184	11088W	PARTICIPANT	\N	PRESENT	0
11203	11184	08022Q	PARTICIPANT	\N	PRESENT	0
11204	11184	01027Q	PARTICIPANT	\N	PRESENT	0
11453	11440	10006L	PARTICIPANT	\N	PRESENT	0
11454	11440	14217N	PARTICIPANT	\N	PRESENT	0
11455	11440	14042U	PARTICIPANT	\N	PRESENT	0
11208	11184	11083R	PARTICIPANT	\N	PRESENT	0
11209	11184	14199E	PARTICIPANT	\N	EXCUSE	0
11210	11184	01057W	PARTICIPANT	\N	PRESENT	0
11456	11440	14281W	PARTICIPANT	\N	PRESENT	0
11457	11440	14231L	PARTICIPANT	\N	EXCUSE	0
11213	11184	11048N	PARTICIPANT	\N	PRESENT	0
11214	11184	99004R	PARTICIPANT	\N	PRESENT	0
11215	11184	04061F	PARTICIPANT	\N	PRESENT	0
11216	11184	14159V	PARTICIPANT	\N	PRESENT	0
11217	11184	07029T	PARTICIPANT	\N	PRESENT	0
11459	11440	11061K	PARTICIPANT	\N	PRESENT	0
11219	11184	08010L	PARTICIPANT	\N	PRESENT	0
11220	11184	08034U	PARTICIPANT	\N	PRESENT	0
11460	11440	01011G	PARTICIPANT	\N	PRESENT	0
11222	11184	98046X	PARTICIPANT	\N	PRESENT	0
11223	11184	11085T	PARTICIPANT	\N	PRESENT	0
11224	11184	08011M	PARTICIPANT	\N	PRESENT	0
11225	11184	08073C	PARTICIPANT	\N	PRESENT	0
11226	11184	08061X	PARTICIPANT	\N	PRESENT	0
11461	11440	14213J	PARTICIPANT	\N	PRESENT	0
11228	11184	14225N	PARTICIPANT	\N	PRESENT	0
11229	11184	11012A	PARTICIPANT	\N	EXCUSE	0
11230	11184	11057P	PARTICIPANT	\N	PRESENT	0
11462	11440	14121F	PARTICIPANT	\N	EXCUSE	0
11232	11184	04034C	PARTICIPANT	\N	EXCUSE	0
11463	11440	11112D	PARTICIPANT	\N	PRESENT	0
11464	11440	14037X	PARTICIPANT	\N	PRESENT	0
11466	11440	04092N	PRESIDENT	0	PRESENT	0
11467	11440	14265W	PARTICIPANT	\N	PRESENT	0
11468	11440	14119M	PARTICIPANT	\N	PRESENT	0
11469	11440	14071N	PARTICIPANT	\N	PRESENT	0
11470	11440	04043D	PARTICIPANT	\N	PRESENT	0
9880	9381	11076S	PARTICIPANT	\N	PRESENT	0
9881	9381	11054L	PARTICIPANT	\N	PRESENT	0
9882	9381	07024N	PARTICIPANT	\N	PRESENT	0
9883	9381	01014K	PARTICIPANT	\N	PRESENT	0
9884	9381	11012A	PARTICIPANT	\N	PRESENT	0
9885	9381	07004J	PARTICIPANT	\N	PRESENT	0
9886	9381	98018T	PARTICIPANT	\N	PRESENT	0
9887	9381	99004R	PARTICIPANT	\N	PRESENT	0
9888	9381	08034U	PARTICIPANT	\N	PRESENT	0
9889	9381	14051J	PARTICIPANT	\N	PRESENT	0
9917	9381	11027H	PARTICIPANT	\N	PRESENT	0
9964	9963	04053F	PARTICIPANT	\N	PRESENT	0
9965	9963	14255U	PARTICIPANT	\N	PRESENT	0
9966	9963	00003C	PARTICIPANT	\N	PRESENT	0
9967	9963	11103C	PARTICIPANT	\N	PRESENT	0
9968	9963	08052W	PRESIDENT	0	PRESENT	0
9969	9963	04081K	PARTICIPANT	\N	EXCUSE	0
9970	9963	12042Y	PARTICIPANT	\N	PRESENT	0
9971	9963	08041T	PARTICIPANT	\N	EXCUSE	0
9972	9963	14026U	PARTICIPANT	\N	EXCUSE	0
9973	9963	14213J	PARTICIPANT	\N	EXCUSE	0
9974	9963	14121F	PARTICIPANT	\N	EXCUSE	0
9975	9963	14037X	PARTICIPANT	\N	PRESENT	0
9976	9963	04092N	PARTICIPANT	\N	EXCUSE	0
9977	9963	14071N	PARTICIPANT	\N	EXCUSE	0
9978	9963	04043D	PARTICIPANT	\N	PRESENT	0
9979	9963	14271U	PARTICIPANT	\N	PRESENT	0
9980	9963	04045F	PARTICIPANT	\N	PRESENT	0
9981	9963	11063M	PARTICIPANT	\N	PRESENT	0
10450	10449	14089Y	PRESIDENT	0	PRESENT	0
10451	10449	11060J	PARTICIPANT	\N	PRESENT	0
10452	10449	11112D	PARTICIPANT	\N	PRESENT	0
10453	10449	14031R	PARTICIPANT	\N	EXCUSE	0
10454	10449	01016M	PARTICIPANT	\N	PRESENT	0
10455	10449	11037K	PARTICIPANT	\N	PRESENT	0
9878	9381	04066L	PARTICIPANT	\N	PRESENT	0
9879	9381	14235Q	PARTICIPANT	\N	PRESENT	0
10456	10449	01027Q	PARTICIPANT	\N	EXCUSE	0
10983	10981	98042T	PARTICIPANT	\N	PRESENT	0
10982	10981	08022Q	PRESIDENT	0	PRESENT	0
10984	10981	11026G	PARTICIPANT	\N	PRESENT	0
10985	10981	08051V	PARTICIPANT	\N	PRESENT	0
10986	10981	14227Q	PARTICIPANT	\N	PRESENT	0
10987	10981	04038G	PARTICIPANT	\N	EXCUSE	0
10988	10981	14157T	PARTICIPANT	\N	EXCUSE	0
11472	11440	11093T	PARTICIPANT	\N	PRESENT	0
11473	11440	11097X	PARTICIPANT	\N	EXCUSE	0
11474	11440	14227Q	PARTICIPANT	\N	PRESENT	0
11475	11440	11025F	PARTICIPANT	\N	PRESENT	0
11476	11440	11063M	PARTICIPANT	\N	PRESENT	0
11477	11440	14269B	PARTICIPANT	\N	PRESENT	0
11479	11440	14271U	PARTICIPANT	\N	PRESENT	0
11485	11440	08041T	PARTICIPANT	\N	EXCUSE	0
11544	11004	08052W	PARTICIPANT	\N	PRESENT	0
11545	11004	11114F	PARTICIPANT	\N	PRESENT	0
11546	11004	04045F	PARTICIPANT	\N	PRESENT	0
11547	11004	12042Y	PARTICIPANT	\N	PRESENT	0
11548	11004	00003C	PARTICIPANT	\N	PRESENT	0
11549	11004	01037S	PARTICIPANT	\N	PRESENT	0
11550	11004	11067R	PARTICIPANT	\N	PRESENT	0
11551	11004	11055M	PARTICIPANT	\N	PRESENT	0
11552	11004	14151M	PARTICIPANT	\N	PRESENT	0
11553	11004	11063M	PARTICIPANT	\N	PRESENT	0
11554	11004	01059Y	PARTICIPANT	\N	PRESENT	0
11555	11004	11031D	PARTICIPANT	\N	PRESENT	0
11556	11004	11061K	PARTICIPANT	\N	PRESENT	0
11557	11004	14030Q	PARTICIPANT	\N	PRESENT	0
11558	11004	14219Q	PARTICIPANT	\N	PRESENT	0
11559	11004	09001P	PARTICIPANT	\N	PRESENT	0
11560	11004	14209N	PARTICIPANT	\N	PRESENT	0
11561	11004	11110B	PARTICIPANT	\N	PRESENT	0
11562	11004	08031R	PARTICIPANT	\N	PRESENT	0
11563	11004	14261S	PARTICIPANT	\N	PRESENT	0
11564	11004	01046T	PARTICIPANT	\N	PRESENT	0
11565	11004	14265W	PARTICIPANT	\N	PRESENT	0
11566	11004	14213J	PARTICIPANT	\N	PRESENT	0
11567	11004	14157T	PARTICIPANT	\N	PRESENT	0
11568	11004	14071N	PARTICIPANT	\N	PRESENT	0
11569	11004	14269B	PARTICIPANT	\N	PRESENT	0
11571	11004	14227Q	PARTICIPANT	\N	PRESENT	0
11572	11004	14205J	PARTICIPANT	\N	PRESENT	0
11573	11004	04092N	PARTICIPANT	\N	PRESENT	0
11574	11004	14042U	PARTICIPANT	\N	PRESENT	0
11575	11570	14255U	PARTICIPANT	\N	EXCUSE	0
11576	11570	04066L	PARTICIPANT	\N	PRESENT	0
11577	11004	14251Q	PARTICIPANT	\N	PRESENT	0
11578	11004	14217N	PARTICIPANT	\N	PRESENT	0
11579	11570	00003C	PARTICIPANT	\N	PRESENT	0
11580	11570	11103C	PARTICIPANT	\N	PRESENT	0
11581	11004	14037X	PARTICIPANT	\N	PRESENT	0
11582	11570	11044J	PARTICIPANT	\N	PRESENT	0
11583	11570	14195A	PARTICIPANT	\N	PRESENT	0
11584	11570	11031D	PARTICIPANT	\N	PRESENT	0
11585	11570	08052W	PARTICIPANT	\N	PRESENT	0
11586	11570	01059Y	PARTICIPANT	\N	PRESENT	0
11587	11570	04081K	PARTICIPANT	\N	PRESENT	0
11588	11570	10006L	PARTICIPANT	\N	PRESENT	0
11589	11570	14217N	PARTICIPANT	\N	PRESENT	0
11590	11570	14042U	PARTICIPANT	\N	PRESENT	0
11591	11570	14151M	PARTICIPANT	\N	PRESENT	0
11542	11004	98053W	PARTICIPANT	\N	PRESENT	0
11543	11004	11014C	PARTICIPANT	\N	PRESENT	0
11592	11570	12042Y	PARTICIPANT	\N	PRESENT	0
11593	11570	14281W	PARTICIPANT	\N	PRESENT	0
11594	11004	14271U	PARTICIPANT	\N	PRESENT	0
11595	11004	95063L	PARTICIPANT	\N	PRESENT	0
11642	11004	08039A	PARTICIPANT	\N	PRESENT	0
11597	11570	14231L	PARTICIPANT	\N	EXCUSE	0
11598	11570	11061K	PARTICIPANT	\N	PRESENT	0
11599	11570	08041T	PARTICIPANT	\N	EXCUSE	0
11600	11004	11093T	PARTICIPANT	\N	PRESENT	0
11601	11570	01011G	PARTICIPANT	\N	PRESENT	0
11602	11570	14213J	PARTICIPANT	\N	PRESENT	0
11603	11570	14121F	PARTICIPANT	\N	EXCUSE	0
11604	11570	11112D	PARTICIPANT	\N	PRESENT	0
11605	11570	14037X	PARTICIPANT	\N	PRESENT	0
11606	11004	11025F	PARTICIPANT	\N	PRESENT	0
11607	11570	11067R	PARTICIPANT	\N	PRESENT	0
11608	11570	04092N	PRESIDENT	0	PRESENT	0
11609	11570	14265W	PARTICIPANT	\N	PRESENT	0
11610	11570	14119M	PARTICIPANT	\N	PRESENT	0
11611	11570	14071N	PARTICIPANT	\N	PRESENT	0
11612	11570	04043D	PARTICIPANT	\N	PRESENT	0
11613	11570	14271U	PARTICIPANT	\N	PRESENT	0
11614	11004	11109J	PARTICIPANT	\N	PRESENT	0
11615	11570	11093T	PARTICIPANT	\N	PRESENT	0
11616	11570	11097X	PARTICIPANT	\N	EXCUSE	0
11617	11570	04045F	PARTICIPANT	\N	PRESENT	0
11618	11004	14195A	PARTICIPANT	\N	PRESENT	0
11619	11570	14227Q	PARTICIPANT	\N	PRESENT	0
11620	11570	01034P	PARTICIPANT	\N	PRESENT	0
11621	11570	14269B	PARTICIPANT	\N	PRESENT	0
11641	11004	11112D	PARTICIPANT	\N	PRESENT	0
11643	11004	14119M	PARTICIPANT	\N	PRESENT	0
11644	11004	14211G	PARTICIPANT	\N	PRESENT	0
11645	11004	80013X	PARTICIPANT	\N	PRESENT	0
11646	11004	04033B	PARTICIPANT	\N	PRESENT	0
11647	11004	11012A	PARTICIPANT	\N	PRESENT	0
11648	11004	01034P	PARTICIPANT	\N	PRESENT	0
11649	11004	01031L	PARTICIPANT	\N	PRESENT	0
11650	11004	14255U	PARTICIPANT	\N	PRESENT	0
11651	11004	95041E	PARTICIPANT	\N	PRESENT	0
11652	11004	04067M	PARTICIPANT	\N	PRESENT	0
11653	11004	14281W	PARTICIPANT	\N	PRESENT	0
11654	11004	14111D	PARTICIPANT	\N	PRESENT	0
11655	11004	08010L	PARTICIPANT	\N	PRESENT	0
9331	8067	14038Y	PARTICIPANT	\N	PRESENT	0
9332	8067	08009T	PARTICIPANT	\N	PRESENT	0
9333	8067	11012A	PARTICIPANT	\N	PRESENT	0
9334	8067	98050T	PARTICIPANT	\N	PRESENT	0
9335	8067	13002U	PARTICIPANT	\N	PRESENT	0
9336	8067	14107H	PARTICIPANT	\N	PRESENT	0
9337	8067	14031R	PARTICIPANT	\N	PRESENT	0
9338	8067	14169X	PARTICIPANT	\N	PRESENT	0
9339	8067	14235Q	PARTICIPANT	\N	PRESENT	0
9340	8067	11056N	PARTICIPANT	\N	PRESENT	0
9341	8067	14159V	PARTICIPANT	\N	PRESENT	0
9342	8067	14205J	PARTICIPANT	\N	PRESENT	0
9343	8067	01057W	PARTICIPANT	\N	PRESENT	0
9344	8067	14135M	PARTICIPANT	\N	PRESENT	0
9345	8067	04088S	PARTICIPANT	\N	PRESENT	0
9346	8067	14225N	PARTICIPANT	\N	PRESENT	0
9347	8067	11107G	PARTICIPANT	\N	PRESENT	0
9348	8067	14033T	PARTICIPANT	\N	PRESENT	0
9349	8067	12042Y	PARTICIPANT	\N	PRESENT	0
9350	8067	14014Q	PARTICIPANT	\N	PRESENT	0
9351	8067	14219Q	PARTICIPANT	\N	PRESENT	0
9352	8067	11097X	PARTICIPANT	\N	PRESENT	0
9353	8067	05012A	PARTICIPANT	\N	PRESENT	0
9354	8067	08068F	PARTICIPANT	\N	PRESENT	0
9355	8067	14231L	PARTICIPANT	\N	PRESENT	0
9356	8067	01008M	PARTICIPANT	\N	PRESENT	0
9357	8067	14265W	PARTICIPANT	\N	PRESENT	0
9358	8067	08016S	PARTICIPANT	\N	PRESENT	0
9359	8067	01016M	PARTICIPANT	\N	PRESENT	0
9360	8067	11104D	PARTICIPANT	\N	PRESENT	0
9361	8067	14217N	PARTICIPANT	\N	PRESENT	0
9362	8067	11042G	PARTICIPANT	\N	PRESENT	0
9363	8067	08055A	PARTICIPANT	\N	PRESENT	0
9364	8067	14089Y	PARTICIPANT	\N	PRESENT	0
9365	8067	92031P	PARTICIPANT	\N	PRESENT	0
9366	8067	14083S	PARTICIPANT	\N	PRESENT	0
9891	9890	14255U	PARTICIPANT	\N	EXCUSE	0
9892	9890	14053L	PARTICIPANT	\N	PRESENT	0
9893	9890	11103C	PARTICIPANT	\N	PRESENT	0
9897	9890	04081K	PARTICIPANT	\N	PRESENT	0
9895	9890	14195A	PARTICIPANT	\N	PRESENT	0
9896	9890	01059Y	PARTICIPANT	\N	PRESENT	0
9898	9890	10006L	PARTICIPANT	\N	PRESENT	0
9899	9890	14217N	PARTICIPANT	\N	PRESENT	0
9900	9890	14042U	PARTICIPANT	\N	PRESENT	0
9901	9890	14151M	PARTICIPANT	\N	PRESENT	0
9902	9890	14281W	PARTICIPANT	\N	PRESENT	0
9903	9890	14231L	PARTICIPANT	\N	PRESENT	0
9904	9890	08041T	PARTICIPANT	\N	PRESENT	0
9905	9890	14213J	PARTICIPANT	\N	PRESENT	0
9906	9890	11112D	PARTICIPANT	\N	PRESENT	0
9907	9890	14018U	PARTICIPANT	\N	PRESENT	0
9908	9890	04092N	PRESIDENT	0	PRESENT	0
9909	9890	14265W	PARTICIPANT	\N	PRESENT	0
9910	9890	14119M	PARTICIPANT	\N	PRESENT	0
9911	9890	07032N	PARTICIPANT	\N	PRESENT	0
9912	9890	14271U	PARTICIPANT	\N	PRESENT	0
9913	9890	11093T	PARTICIPANT	\N	PRESENT	0
9914	9890	11097X	PARTICIPANT	\N	PRESENT	0
9915	9890	04045F	PARTICIPANT	\N	PRESENT	0
9916	9890	11063M	PARTICIPANT	\N	PRESENT	0
11662	11661	14239U	PARTICIPANT	\N	PRESENT	0
11663	11661	11055M	PARTICIPANT	\N	PRESENT	0
11664	11661	01046T	PARTICIPANT	\N	PRESENT	0
11665	11661	04053F	PARTICIPANT	\N	PRESENT	0
11666	11661	14255U	PARTICIPANT	\N	PRESENT	0
12942	12941	14263U	PARTICIPANT	\N	PRESENT	0
11668	11661	00003C	PARTICIPANT	\N	PRESENT	0
11669	11661	14053L	PARTICIPANT	\N	PRESENT	0
11670	11661	11103C	PARTICIPANT	\N	PRESENT	0
11672	11661	14195A	PARTICIPANT	\N	PRESENT	0
9316	8067	04081K	PARTICIPANT	\N	PRESENT	0
9317	8067	08042U	PARTICIPANT	\N	PRESENT	0
9318	8067	11100Y	PARTICIPANT	\N	PRESENT	0
9319	8067	11098Y	PARTICIPANT	\N	PRESENT	0
9320	8067	14013P	PARTICIPANT	\N	PRESENT	0
9321	8067	80013X	PARTICIPANT	\N	PRESENT	0
9322	8067	11036J	PARTICIPANT	\N	PRESENT	0
9323	8067	14257W	PARTICIPANT	\N	PRESENT	0
9324	8067	14207L	PARTICIPANT	\N	PRESENT	0
9325	8067	92039X	PARTICIPANT	\N	PRESENT	0
9326	8067	11055M	PARTICIPANT	\N	PRESENT	0
9327	8067	11099A	PARTICIPANT	\N	PRESENT	0
9328	8067	11103C	PARTICIPANT	\N	PRESENT	0
9329	8067	08060W	PARTICIPANT	\N	PRESENT	0
9330	8067	95030B	PARTICIPANT	\N	PRESENT	0
12945	12941	04059M	PARTICIPANT	\N	PRESENT	0
12946	12941	11039M	PARTICIPANT	\N	PRESENT	0
11676	11661	08052W	PARTICIPANT	\N	PRESENT	0
11677	11661	01059Y	PARTICIPANT	\N	PRESENT	0
11678	11661	04081K	PARTICIPANT	\N	PRESENT	0
11679	11661	98024R	PARTICIPANT	\N	PRESENT	0
11680	11661	10006L	PARTICIPANT	\N	PRESENT	0
12947	12941	01044R	PARTICIPANT	\N	PRESENT	0
11682	11661	14217N	PARTICIPANT	\N	PRESENT	0
11683	11661	14042U	PARTICIPANT	\N	PRESENT	0
11684	11661	14151M	PARTICIPANT	\N	PRESENT	0
11685	11661	12042Y	PARTICIPANT	\N	PRESENT	0
11686	11661	14281W	PARTICIPANT	\N	PRESENT	0
11687	11661	14087W	PARTICIPANT	\N	PRESENT	0
12948	12941	08043V	PARTICIPANT	\N	EXCUSE	0
12949	12941	14089Y	PARTICIPANT	\N	PRESENT	0
11690	11661	14231L	PARTICIPANT	\N	PRESENT	0
11691	11661	11061K	PARTICIPANT	\N	PRESENT	0
12950	12941	14105F	PARTICIPANT	\N	PRESENT	0
11693	11661	08041T	PARTICIPANT	\N	PRESENT	0
11694	11661	01011G	PARTICIPANT	\N	PRESENT	0
12951	12941	11029K	PARTICIPANT	\N	PRESENT	0
11696	11661	14213J	PARTICIPANT	\N	PRESENT	0
11697	11661	14121F	PARTICIPANT	\N	EXCUSE	0
11698	11661	11112D	PARTICIPANT	\N	PRESENT	0
11699	11661	14037X	PARTICIPANT	\N	PRESENT	0
11700	11661	14018U	PARTICIPANT	\N	PRESENT	0
11701	11661	11067R	PARTICIPANT	\N	PRESENT	0
11702	11661	14223L	PARTICIPANT	\N	PRESENT	0
11703	11661	04092N	PRESIDENT	0	PRESENT	0
11704	11661	14265W	PARTICIPANT	\N	PRESENT	0
11705	11661	14119M	PARTICIPANT	\N	PRESENT	0
11706	11661	14071N	PARTICIPANT	\N	PRESENT	0
11707	11661	07032N	PARTICIPANT	\N	PRESENT	0
12952	12941	95015C	PARTICIPANT	\N	EXCUSE	0
11709	11661	14271U	PARTICIPANT	\N	PRESENT	0
12953	12941	92015P	PARTICIPANT	\N	EXCUSE	0
11711	11661	11093T	PARTICIPANT	\N	PRESENT	0
11712	11661	11097X	PARTICIPANT	\N	EXCUSE	0
11713	11661	04045F	PARTICIPANT	\N	PRESENT	0
11714	11661	14227Q	PARTICIPANT	\N	PRESENT	0
11715	11661	01034P	PARTICIPANT	\N	PRESENT	0
11716	11661	11025F	PARTICIPANT	\N	PRESENT	0
11717	11661	11063M	PARTICIPANT	\N	PRESENT	0
12954	12941	08024S	PARTICIPANT	\N	PRESENT	0
12955	12941	14201E	PARTICIPANT	\N	PRESENT	0
12956	12941	14209N	PARTICIPANT	\N	PRESENT	0
12957	12941	14079W	PARTICIPANT	\N	PRESENT	0
12958	12941	11091R	PARTICIPANT	\N	PRESENT	0
12959	12941	87003B	PARTICIPANT	\N	PRESENT	0
12961	12941	14249W	PARTICIPANT	\N	EXCUSE	0
12963	12941	01025N	PARTICIPANT	\N	EXCUSE	0
12964	12941	01037S	PARTICIPANT	\N	PRESENT	0
12966	12941	08035V	PARTICIPANT	\N	PRESENT	0
12967	12941	11089X	PARTICIPANT	\N	PRESENT	0
12968	12941	07026Q	PARTICIPANT	\N	PRESENT	0
12969	12941	14123H	PARTICIPANT	\N	PRESENT	0
12970	12941	14179A	PARTICIPANT	\N	PRESENT	0
12971	12941	04041B	PARTICIPANT	\N	PRESENT	0
12972	12941	14241N	PARTICIPANT	\N	PRESENT	0
12973	12941	14061L	PARTICIPANT	\N	PRESENT	0
12974	12941	14073Q	PARTICIPANT	\N	PRESENT	0
12975	12941	08031R	PARTICIPANT	\N	PRESENT	0
12977	12941	08039A	PARTICIPANT	\N	PRESENT	0
12978	12941	08017T	PARTICIPANT	\N	PRESENT	0
12979	12941	14059S	PARTICIPANT	\N	PRESENT	0
12980	12941	08012N	PARTICIPANT	\N	PRESENT	0
12981	12941	14103D	PARTICIPANT	\N	PRESENT	0
12982	12941	11104D	PARTICIPANT	\N	PRESENT	0
12983	12941	14063N	PARTICIPANT	\N	PRESENT	0
12984	12941	04057K	PARTICIPANT	\N	PRESENT	0
12985	12941	11014C	PARTICIPANT	\N	PRESENT	0
12986	12941	14109K	PARTICIPANT	\N	PRESENT	0
12987	12941	04070G	PRESIDENT	0	PRESENT	0
12988	12941	92040Q	PARTICIPANT	\N	PRESENT	0
12990	12941	83047W	PARTICIPANT	\N	PRESENT	0
12991	12941	14235Q	PARTICIPANT	\N	PRESENT	0
10210	10209	01031L	PRESIDENT	0	PRESENT	0
10211	10209	01013J	PARTICIPANT	\N	PRESENT	0
10212	10209	11068S	PARTICIPANT	\N	PRESENT	0
10213	10209	11040E	PARTICIPANT	\N	PRESENT	0
10214	10209	11053K	PARTICIPANT	\N	PRESENT	0
10215	10209	11042G	PARTICIPANT	\N	PRESENT	0
10216	10209	04086Q	PARTICIPANT	\N	PRESENT	0
10217	10209	11070L	PARTICIPANT	\N	PRESENT	0
10218	10209	11088W	PARTICIPANT	\N	PRESENT	0
10219	10209	08022Q	PARTICIPANT	\N	PRESENT	0
10220	10209	11074Q	PARTICIPANT	\N	PRESENT	0
10221	10209	11083R	PARTICIPANT	\N	PRESENT	0
10222	10209	14199E	PARTICIPANT	\N	PRESENT	0
10223	10209	08069G	PARTICIPANT	\N	PRESENT	0
10224	10209	11048N	PARTICIPANT	\N	PRESENT	0
10225	10209	99004R	PARTICIPANT	\N	PRESENT	0
10226	10209	14159V	PARTICIPANT	\N	PRESENT	0
10227	10209	14277B	PARTICIPANT	\N	PRESENT	0
10228	10209	08010L	PARTICIPANT	\N	PRESENT	0
10229	10209	08034U	PARTICIPANT	\N	PRESENT	0
10230	10209	98046X	PARTICIPANT	\N	PRESENT	0
10231	10209	08011M	PARTICIPANT	\N	PRESENT	0
10232	10209	08061X	PARTICIPANT	\N	PRESENT	0
10233	10209	01016M	PARTICIPANT	\N	PRESENT	0
10234	10209	11012A	PARTICIPANT	\N	PRESENT	0
10235	10209	14173T	PARTICIPANT	\N	PRESENT	0
10236	10209	89017R	PARTICIPANT	\N	EXCUSE	0
10237	10209	14085U	PARTICIPANT	\N	EXCUSE	0
10238	10209	01027Q	PARTICIPANT	\N	EXCUSE	0
10239	10209	98053W	PARTICIPANT	\N	EXCUSE	0
10240	10209	01057W	PARTICIPANT	\N	EXCUSE	0
10241	10209	07029T	PARTICIPANT	\N	EXCUSE	0
10242	10209	11085T	PARTICIPANT	\N	EXCUSE	0
10243	10209	11057P	PARTICIPANT	\N	EXCUSE	0
10244	10209	04034C	PARTICIPANT	\N	EXCUSE	0
10245	10111	01019Q	PARTICIPANT	\N	PRESENT	0
10529	10528	08055A	PARTICIPANT	\N	PRESENT	0
10530	10528	14030Q	PARTICIPANT	\N	PRESENT	0
10531	10528	08060W	PARTICIPANT	\N	EXCUSE	0
10532	10528	11095V	PARTICIPANT	\N	PRESENT	0
10533	10528	01015L	PARTICIPANT	\N	EXCUSE	0
10534	10528	11107G	PARTICIPANT	\N	PRESENT	0
10535	10528	02002K	PARTICIPANT	\N	PRESENT	0
10536	10528	04097T	PARTICIPANT	\N	PRESENT	0
10537	10528	14219Q	PARTICIPANT	\N	PRESENT	0
10538	10528	80027E	PARTICIPANT	\N	PRESENT	0
10539	10528	14031R	PARTICIPANT	\N	PRESENT	0
10540	10528	08009T	PRESIDENT	0	PRESENT	0
10541	10528	08062Y	PARTICIPANT	\N	EXCUSE	0
10542	10528	14221J	PARTICIPANT	\N	PRESENT	0
10543	10528	08042U	PARTICIPANT	\N	PRESENT	0
10544	10528	14169X	PARTICIPANT	\N	PRESENT	0
10545	10528	14237S	PARTICIPANT	\N	PRESENT	0
10546	10528	13002U	PARTICIPANT	\N	PRESENT	0
10547	10528	05012A	PARTICIPANT	\N	PRESENT	0
10548	10528	14135M	PARTICIPANT	\N	PRESENT	0
10549	10528	95062K	PARTICIPANT	\N	EXCUSE	0
10550	10528	14157T	PARTICIPANT	\N	PRESENT	0
10551	10528	96003C	PARTICIPANT	\N	EXCUSE	0
10610	10528	01022K	PARTICIPANT	\N	EXCUSE	0
10611	10528	92039X	PARTICIPANT	\N	EXCUSE	0
10612	10528	14107H	PARTICIPANT	\N	EXCUSE	0
11136	11135	89017R	PARTICIPANT	\N	EXCUSE	0
11137	11135	01031L	PRESIDENT	0	PRESENT	0
11138	11135	05004A	PARTICIPANT	\N	PRESENT	0
11139	11135	01013J	PARTICIPANT	\N	PRESENT	0
11140	11135	11068S	PARTICIPANT	\N	PRESENT	0
11289	11001	14219Q	PARTICIPANT	\N	PRESENT	0
11142	11135	08014Q	PARTICIPANT	\N	PRESENT	0
11143	11135	14167V	PARTICIPANT	\N	PRESENT	0
11144	11135	14175V	PARTICIPANT	\N	PRESENT	0
11145	11135	14083S	PARTICIPANT	\N	PRESENT	0
11287	11001	86034E	PARTICIPANT	\N	PRESENT	0
11147	11135	14085U	PARTICIPANT	\N	PRESENT	0
11148	11135	11042G	PARTICIPANT	\N	PRESENT	0
11149	11135	88008L	PARTICIPANT	\N	PRESENT	0
11150	11135	04086Q	PARTICIPANT	\N	PRESENT	0
11151	11135	04055H	PARTICIPANT	\N	PRESENT	0
11152	11135	11070L	PARTICIPANT	\N	PRESENT	0
11153	11135	11088W	PARTICIPANT	\N	PRESENT	0
11154	11135	08022Q	PARTICIPANT	\N	PRESENT	0
11155	11135	01027Q	PARTICIPANT	\N	PRESENT	0
11288	11001	04092N	PARTICIPANT	\N	PRESENT	0
11157	11135	11074Q	PARTICIPANT	\N	PRESENT	0
11158	11135	98053W	PARTICIPANT	\N	PRESENT	0
11159	11135	11083R	PARTICIPANT	\N	PRESENT	0
11160	11135	14199E	PARTICIPANT	\N	EXCUSE	0
11161	11135	01057W	PARTICIPANT	\N	PRESENT	0
11162	11135	08016S	PARTICIPANT	\N	PRESENT	0
11163	11135	08069G	PARTICIPANT	\N	PRESENT	0
11164	11135	11048N	PARTICIPANT	\N	PRESENT	0
11165	11135	99004R	PARTICIPANT	\N	PRESENT	0
11166	11135	04061F	PARTICIPANT	\N	PRESENT	0
11167	11135	14159V	PARTICIPANT	\N	PRESENT	0
11168	11135	07029T	PARTICIPANT	\N	PRESENT	0
11290	11001	08052W	PARTICIPANT	\N	PRESENT	0
11170	11135	08010L	PARTICIPANT	\N	PRESENT	0
11171	11135	08034U	PARTICIPANT	\N	PRESENT	0
11172	11135	01048V	PARTICIPANT	\N	PRESENT	0
11173	11135	98046X	PARTICIPANT	\N	PRESENT	0
11174	11135	11085T	PARTICIPANT	\N	PRESENT	0
11175	11135	08011M	PARTICIPANT	\N	PRESENT	0
11176	11135	08073C	PARTICIPANT	\N	PRESENT	0
11177	11135	08061X	PARTICIPANT	\N	PRESENT	0
11178	11135	01016M	PARTICIPANT	\N	PRESENT	0
11179	11135	14225N	PARTICIPANT	\N	PRESENT	0
11180	11135	11012A	PARTICIPANT	\N	PRESENT	0
11181	11135	11057P	PARTICIPANT	\N	PRESENT	0
11291	11001	11014C	PARTICIPANT	\N	PRESENT	0
11183	11135	04034C	PARTICIPANT	\N	PRESENT	0
11292	11001	11025F	PARTICIPANT	\N	PRESENT	0
11293	11001	14227Q	PARTICIPANT	\N	PRESENT	0
11294	11001	14042U	PARTICIPANT	\N	PRESENT	0
11295	11001	11031D	PARTICIPANT	\N	PRESENT	0
11296	11001	14213J	PARTICIPANT	\N	PRESENT	0
11297	11001	14175V	PARTICIPANT	\N	PRESENT	0
11298	11001	14195A	PARTICIPANT	\N	PRESENT	0
11299	11001	04057K	PARTICIPANT	\N	PRESENT	0
11300	11001	99004R	PARTICIPANT	\N	PRESENT	0
11301	11001	77002U	PARTICIPANT	\N	PRESENT	0
11302	11001	01059Y	PARTICIPANT	\N	PRESENT	0
11303	11001	11103C	PARTICIPANT	\N	PRESENT	0
11304	11001	14271U	PARTICIPANT	\N	PRESENT	0
11305	11001	14281W	PARTICIPANT	\N	PRESENT	0
11306	11001	11055M	PARTICIPANT	\N	PRESENT	0
11307	11001	11029K	PARTICIPANT	\N	PRESENT	0
11308	11001	11093T	PARTICIPANT	\N	PRESENT	0
11309	11001	14261S	PARTICIPANT	\N	PRESENT	0
12820	11657	11110B	PARTICIPANT	\N	PRESENT	0
12821	11657	11072N	PARTICIPANT	\N	PRESENT	0
12841	11657	04049K	PARTICIPANT	\N	PRESENT	0
12842	11657	92045V	PARTICIPANT	\N	PRESENT	0
12843	11657	98053W	PARTICIPANT	\N	PRESENT	0
12844	11657	04033B	PARTICIPANT	\N	PRESENT	0
12845	11657	14197C	PARTICIPANT	\N	PRESENT	0
12846	11657	04053F	PARTICIPANT	\N	PRESENT	0
12905	11657	11042G	PARTICIPANT	\N	PRESENT	0
12906	11657	11036J	PARTICIPANT	\N	PRESENT	0
12907	11657	08068F	PARTICIPANT	\N	PRESENT	0
12908	11657	98022P	PARTICIPANT	\N	PRESENT	0
12909	11657	14083S	PARTICIPANT	\N	PRESENT	0
12910	11657	14251Q	PARTICIPANT	\N	PRESENT	0
12911	11657	08010L	PARTICIPANT	\N	PRESENT	0
12912	11657	14255U	PARTICIPANT	\N	PRESENT	0
12913	11657	01015L	PARTICIPANT	\N	PRESENT	0
12914	11657	14111D	PARTICIPANT	\N	PRESENT	0
12915	11657	05012A	PARTICIPANT	\N	PRESENT	0
12916	11657	08051V	PARTICIPANT	\N	PRESENT	0
12917	11657	80013X	PARTICIPANT	\N	PRESENT	0
12918	11657	08024S	PARTICIPANT	\N	PRESENT	0
12919	11657	01028R	PARTICIPANT	\N	PRESENT	0
12920	11657	14014Q	PARTICIPANT	\N	PRESENT	0
12921	11657	14119M	PARTICIPANT	\N	PRESENT	0
12922	11657	14151M	PARTICIPANT	\N	PRESENT	0
12923	11657	14211G	PARTICIPANT	\N	PRESENT	0
12924	11657	14179A	PARTICIPANT	\N	PRESENT	0
12925	11657	95041E	PARTICIPANT	\N	PRESENT	0
12926	11657	07029T	PARTICIPANT	\N	PRESENT	0
12927	11657	14169X	PARTICIPANT	\N	PRESENT	0
12928	11657	14123H	PARTICIPANT	\N	PRESENT	0
12929	11657	14105F	PARTICIPANT	\N	PRESENT	0
12930	11657	14237S	PARTICIPANT	\N	PRESENT	0
12931	11657	14071N	PARTICIPANT	\N	PRESENT	0
12932	11657	14259Y	PARTICIPANT	\N	PRESENT	0
12999	11661	11031D	PARTICIPANT	\N	EXCUSE	0
13059	11719	14107H	PARTICIPANT	\N	PRESENT	0
13060	11719	12042Y	PARTICIPANT	\N	PRESENT	0
13061	11719	04045F	PARTICIPANT	\N	PRESENT	0
13062	11719	08052W	PARTICIPANT	\N	PRESENT	0
13063	11719	01011G	PARTICIPANT	\N	PRESENT	0
13064	11719	14227Q	PARTICIPANT	\N	PRESENT	0
13065	11719	11066Q	PARTICIPANT	\N	PRESENT	0
13066	11719	14081Q	PARTICIPANT	\N	PRESENT	0
13067	11719	11067R	PARTICIPANT	\N	PRESENT	0
13068	11719	04059M	PARTICIPANT	\N	PRESENT	0
13069	11719	11055M	PARTICIPANT	\N	PRESENT	0
13070	11719	11037K	PARTICIPANT	\N	PRESENT	0
13071	11719	14018U	PARTICIPANT	\N	PRESENT	0
13072	11719	11031D	PARTICIPANT	\N	PRESENT	0
13073	11719	01059Y	PARTICIPANT	\N	PRESENT	0
13075	11719	14239U	PARTICIPANT	\N	PRESENT	0
13076	11719	14241N	PARTICIPANT	\N	PRESENT	0
13077	11719	14030Q	PARTICIPANT	\N	PRESENT	0
13078	11719	14219Q	PARTICIPANT	\N	PRESENT	0
13079	11719	14261S	PARTICIPANT	\N	PRESENT	0
13080	11719	14231L	PARTICIPANT	\N	PRESENT	0
13081	11719	11063M	PARTICIPANT	\N	PRESENT	0
13082	11719	14263U	PARTICIPANT	\N	PRESENT	0
13083	11719	14151M	PARTICIPANT	\N	PRESENT	0
13084	11719	14271U	PARTICIPANT	\N	PRESENT	0
13085	11719	00003C	PARTICIPANT	\N	PRESENT	0
13086	11719	14269B	PARTICIPANT	\N	PRESENT	0
13087	11719	07004J	PARTICIPANT	\N	PRESENT	0
13088	11719	14205J	PARTICIPANT	\N	PRESENT	0
13089	11719	14055N	PARTICIPANT	\N	PRESENT	0
13090	11719	14187A	PARTICIPANT	\N	PRESENT	0
13092	11719	14213J	PARTICIPANT	\N	PRESENT	0
13093	11719	08048B	PARTICIPANT	\N	PRESENT	0
13094	11719	14265W	PARTICIPANT	\N	PRESENT	0
13095	13091	89017R	PARTICIPANT	\N	PRESENT	0
13096	13091	01031L	PRESIDENT	0	PRESENT	0
13151	11719	11112D	PARTICIPANT	\N	PRESENT	0
13098	13091	01013J	PARTICIPANT	\N	PRESENT	0
13099	13091	11068S	PARTICIPANT	\N	EXCUSE	0
13100	13091	11040E	PARTICIPANT	\N	PRESENT	0
13101	13091	08014Q	PARTICIPANT	\N	PRESENT	0
13158	11719	14031R	PARTICIPANT	\N	PRESENT	0
13103	13091	14175V	PARTICIPANT	\N	PRESENT	0
13104	13091	14083S	PARTICIPANT	\N	PRESENT	0
13159	11719	14215L	PARTICIPANT	\N	PRESENT	0
13106	13091	14085U	PARTICIPANT	\N	PRESENT	0
13107	13091	11042G	PARTICIPANT	\N	PRESENT	0
13160	11719	08065C	PARTICIPANT	\N	PRESENT	0
13109	13091	04086Q	PARTICIPANT	\N	PRESENT	0
13161	11719	14079W	PARTICIPANT	\N	PRESENT	0
13111	13091	11070L	PARTICIPANT	\N	PRESENT	0
13112	13091	11088W	PARTICIPANT	\N	PRESENT	0
13113	13091	14327T	PARTICIPANT	\N	PRESENT	0
13114	13091	08022Q	PARTICIPANT	\N	PRESENT	0
13115	13091	01027Q	PARTICIPANT	\N	EXCUSE	0
13116	13091	04071H	PARTICIPANT	\N	PRESENT	0
13057	11719	08024S	PARTICIPANT	\N	PRESENT	0
13058	11719	14063N	PARTICIPANT	\N	PRESENT	0
13162	11719	14089Y	PARTICIPANT	\N	PRESENT	0
13118	13091	98053W	PARTICIPANT	\N	PRESENT	0
13163	11719	01025N	PARTICIPANT	\N	PRESENT	0
13120	13091	14199E	PARTICIPANT	\N	PRESENT	0
13121	13091	01057W	PARTICIPANT	\N	PRESENT	0
13122	13091	08016S	PARTICIPANT	\N	PRESENT	0
13123	13091	08069G	PARTICIPANT	\N	PRESENT	0
13124	13091	11048N	PARTICIPANT	\N	PRESENT	0
13164	11719	14253S	PARTICIPANT	\N	PRESENT	0
13126	13091	04061F	PARTICIPANT	\N	PRESENT	0
13165	11719	11101A	PARTICIPANT	\N	PRESENT	0
13128	13091	07029T	PARTICIPANT	\N	PRESENT	0
13129	13091	14277B	PARTICIPANT	\N	PRESENT	0
13130	13091	08010L	PARTICIPANT	\N	PRESENT	0
13131	13091	08034U	PARTICIPANT	\N	PRESENT	0
13132	13091	01048V	PARTICIPANT	\N	PRESENT	0
13133	13091	98046X	PARTICIPANT	\N	PRESENT	0
13134	13091	11085T	PARTICIPANT	\N	PRESENT	0
13135	13091	08011M	PARTICIPANT	\N	PRESENT	0
13137	13091	08061X	PARTICIPANT	\N	PRESENT	0
13138	13091	01016M	PARTICIPANT	\N	PRESENT	0
13139	13091	14225N	PARTICIPANT	\N	PRESENT	0
13140	13091	11012A	PARTICIPANT	\N	PRESENT	0
13141	13091	11057P	PARTICIPANT	\N	PRESENT	0
13142	13091	14173T	PARTICIPANT	\N	PRESENT	0
13143	13091	04034C	PARTICIPANT	\N	PRESENT	0
13144	11719	07029T	PARTICIPANT	\N	PRESENT	0
13145	11719	04041B	PARTICIPANT	\N	PRESENT	0
13146	11719	14169X	PARTICIPANT	\N	PRESENT	0
13147	11719	14223L	PARTICIPANT	\N	PRESENT	0
13148	11719	10015M	PARTICIPANT	\N	PRESENT	0
13149	11719	14037X	PARTICIPANT	\N	PRESENT	0
13150	11719	04053F	PARTICIPANT	\N	PRESENT	0
13152	11719	14207L	PARTICIPANT	\N	PRESENT	0
13153	11719	11054L	PARTICIPANT	\N	PRESENT	0
13154	11719	14041T	PARTICIPANT	\N	PRESENT	0
13155	11719	14033T	PARTICIPANT	\N	PRESENT	0
13156	11719	07032N	PARTICIPANT	\N	PRESENT	0
13167	11719	98023Q	PARTICIPANT	\N	PRESENT	0
13168	11719	01046T	PARTICIPANT	\N	PRESENT	0
13169	11719	11014C	PARTICIPANT	\N	PRESENT	0
13170	11719	11109J	PARTICIPANT	\N	PRESENT	0
13171	11719	08039A	PARTICIPANT	\N	PRESENT	0
13172	11719	10006L	PARTICIPANT	\N	PRESENT	0
13173	11719	01022K	PARTICIPANT	\N	PRESENT	0
13174	11719	14281W	PARTICIPANT	\N	PRESENT	0
13175	11719	14097Y	PARTICIPANT	\N	PRESENT	0
13176	11719	14042U	PARTICIPANT	\N	PRESENT	0
13177	11719	04092N	PARTICIPANT	\N	PRESENT	0
13178	11719	11034G	PARTICIPANT	\N	PRESENT	0
13179	11719	11113E	PARTICIPANT	\N	PRESENT	0
13180	11719	08060W	PARTICIPANT	\N	PRESENT	0
13181	11719	14103D	PARTICIPANT	\N	PRESENT	0
13182	11719	08055A	PARTICIPANT	\N	PRESENT	0
13183	11719	04034C	PARTICIPANT	\N	PRESENT	0
13184	11719	14059S	PARTICIPANT	\N	PRESENT	0
13185	11719	11070L	PARTICIPANT	\N	PRESENT	0
13186	11719	14267Y	PARTICIPANT	\N	PRESENT	0
13187	11719	14028W	PARTICIPANT	\N	PRESENT	0
13188	11719	14197C	PARTICIPANT	\N	PRESENT	0
13189	11719	11089X	PARTICIPANT	\N	PRESENT	0
13190	11719	11061K	PARTICIPANT	\N	PRESENT	0
13191	11719	08017T	PARTICIPANT	\N	PRESENT	0
13192	11719	13002U	PARTICIPANT	\N	PRESENT	0
13193	11719	14257W	PARTICIPANT	\N	PRESENT	0
13194	11719	80013X	PARTICIPANT	\N	PRESENT	0
13195	11719	08069G	PARTICIPANT	\N	PRESENT	0
13197	11719	01003G	PARTICIPANT	\N	PRESENT	0
13198	13196	14239U	PARTICIPANT	\N	PRESENT	0
13199	13196	11055M	PARTICIPANT	\N	PRESENT	0
13200	13196	01046T	PARTICIPANT	\N	PRESENT	0
13201	13196	04053F	PARTICIPANT	\N	PRESENT	0
12994	12941	14229S	PARTICIPANT	\N	PRESENT	0
12995	12941	11043H	PARTICIPANT	\N	PRESENT	0
12996	12941	11071M	PARTICIPANT	\N	PRESENT	0
12997	12941	92045V	PARTICIPANT	\N	PRESENT	0
12998	12941	11011M	PARTICIPANT	\N	PRESENT	0
13202	13196	14255U	PARTICIPANT	\N	PRESENT	0
13258	11719	08044W	PARTICIPANT	\N	PRESENT	0
13204	13196	00003C	PARTICIPANT	\N	PRESENT	0
13205	13196	14053L	PARTICIPANT	\N	PRESENT	0
13206	13196	11103C	PARTICIPANT	\N	PRESENT	0
13207	13196	11044J	PARTICIPANT	\N	PRESENT	0
13208	13196	14195A	PARTICIPANT	\N	PRESENT	0
13209	13196	14267Y	PARTICIPANT	\N	PRESENT	0
13210	13196	11023D	PARTICIPANT	\N	PRESENT	0
13211	13196	11031D	PARTICIPANT	\N	PRESENT	0
13212	13196	08052W	PARTICIPANT	\N	PRESENT	0
13213	13196	01059Y	PARTICIPANT	\N	PRESENT	0
13214	13196	04081K	PARTICIPANT	\N	PRESENT	0
13215	13196	98024R	PARTICIPANT	\N	PRESENT	0
13216	13196	10006L	PARTICIPANT	\N	PRESENT	0
13217	13196	04067M	PARTICIPANT	\N	PRESENT	0
13218	13196	14217N	PARTICIPANT	\N	PRESENT	0
13219	13196	14042U	PARTICIPANT	\N	PRESENT	0
13220	13196	14151M	PARTICIPANT	\N	PRESENT	0
13221	13196	12042Y	PARTICIPANT	\N	PRESENT	0
13222	13196	14281W	PARTICIPANT	\N	PRESENT	0
13223	13196	14087W	PARTICIPANT	\N	PRESENT	0
13259	11719	98050T	PARTICIPANT	\N	PRESENT	0
13260	11719	09001P	PARTICIPANT	\N	PRESENT	0
13226	13196	14231L	PARTICIPANT	\N	PRESENT	0
13227	13196	11061K	PARTICIPANT	\N	PRESENT	0
13261	11719	98046X	PARTICIPANT	\N	PRESENT	0
13229	13196	08041T	PARTICIPANT	\N	PRESENT	0
13262	11719	14229S	PARTICIPANT	\N	PRESENT	0
13231	13196	14026U	PARTICIPANT	\N	PRESENT	0
13232	13196	14213J	PARTICIPANT	\N	PRESENT	0
13233	13196	14121F	PARTICIPANT	\N	EXCUSE	0
13234	13196	11112D	PARTICIPANT	\N	PRESENT	0
13235	13196	14037X	PARTICIPANT	\N	PRESENT	0
13236	13196	14018U	PARTICIPANT	\N	PRESENT	0
13237	13196	11067R	PARTICIPANT	\N	PRESENT	0
13238	13196	14223L	PARTICIPANT	\N	PRESENT	0
13239	13196	04092N	PRESIDENT	0	PRESENT	0
13240	13196	14265W	PARTICIPANT	\N	PRESENT	0
13241	13196	14119M	PARTICIPANT	\N	PRESENT	0
13242	13196	14071N	PARTICIPANT	\N	PRESENT	0
13243	13196	07032N	PARTICIPANT	\N	PRESENT	0
13244	13196	04043D	PARTICIPANT	\N	PRESENT	0
13245	13196	14271U	PARTICIPANT	\N	PRESENT	0
13263	11719	87003B	PARTICIPANT	\N	PRESENT	0
13247	13196	11093T	PARTICIPANT	\N	PRESENT	0
13248	13196	11097X	PARTICIPANT	\N	EXCUSE	0
13249	13196	04045F	PARTICIPANT	\N	PRESENT	0
13250	13196	14227Q	PARTICIPANT	\N	PRESENT	0
13251	13196	01034P	PARTICIPANT	\N	PRESENT	0
13252	13196	11025F	PARTICIPANT	\N	PRESENT	0
13253	13196	11063M	PARTICIPANT	\N	PRESENT	0
13254	13196	14269B	PARTICIPANT	\N	PRESENT	0
13255	11719	08062Y	PARTICIPANT	\N	PRESENT	0
13256	11719	01008M	PARTICIPANT	\N	PRESENT	0
13257	11719	08014Q	PARTICIPANT	\N	PRESENT	0
13264	11719	01016M	PARTICIPANT	\N	PRESENT	0
13265	11719	14034U	PARTICIPANT	\N	PRESENT	0
13266	11719	14038Y	PARTICIPANT	\N	PRESENT	0
13267	11719	14157T	PARTICIPANT	\N	PRESENT	0
13268	11719	14217N	PARTICIPANT	\N	PRESENT	0
13269	11719	08012N	PARTICIPANT	\N	PRESENT	0
13270	11719	14195A	PARTICIPANT	\N	PRESENT	0
13271	11719	01057W	PARTICIPANT	\N	PRESENT	0
13272	11719	11048N	PARTICIPANT	\N	PRESENT	0
13273	11719	04089T	PARTICIPANT	\N	PRESENT	0
13274	11719	14026U	PARTICIPANT	\N	PRESENT	0
13275	13091	11044J	PARTICIPANT	\N	PRESENT	0
13276	11719	11012A	PARTICIPANT	\N	PRESENT	0
13277	11719	14209N	PARTICIPANT	\N	PRESENT	0
13278	11719	01019Q	PARTICIPANT	\N	PRESENT	0
13279	13091	14187A	PARTICIPANT	\N	PRESENT	0
13280	11719	80027E	PARTICIPANT	\N	PRESENT	0
13281	11719	08041T	PARTICIPANT	\N	PRESENT	0
13282	11719	14111D	PARTICIPANT	\N	PRESENT	0
13283	11719	08010L	PARTICIPANT	\N	PRESENT	0
13284	11719	11011M	PARTICIPANT	\N	PRESENT	0
13285	11719	05012A	PARTICIPANT	\N	PRESENT	0
13286	11719	98022P	PARTICIPANT	\N	PRESENT	0
13287	11719	95063L	PARTICIPANT	\N	PRESENT	0
13288	11719	04049K	PARTICIPANT	\N	PRESENT	0
13289	11719	95049N	PARTICIPANT	\N	PRESENT	0
13290	11719	08016S	PARTICIPANT	\N	PRESENT	0
13291	11719	08015R	PARTICIPANT	\N	PRESENT	0
13292	11719	01047U	PARTICIPANT	\N	PRESENT	0
13293	11719	11036J	PARTICIPANT	\N	PRESENT	0
13294	11719	04057K	PARTICIPANT	\N	PRESENT	0
13295	11719	11104D	PARTICIPANT	\N	PRESENT	0
13296	11719	11094U	PARTICIPANT	\N	PRESENT	0
13297	11719	14135M	PARTICIPANT	\N	PRESENT	0
13298	11719	04066L	PARTICIPANT	\N	PRESENT	0
13299	11719	11093T	PARTICIPANT	\N	PRESENT	0
13300	11719	14199E	PARTICIPANT	\N	PRESENT	0
13301	11719	14061L	PARTICIPANT	\N	PRESENT	0
13302	11719	08051V	PARTICIPANT	\N	PRESENT	0
13303	11719	14109K	PARTICIPANT	\N	PRESENT	0
13304	11719	14087W	PARTICIPANT	\N	PRESENT	0
13305	11719	14147R	PARTICIPANT	\N	PRESENT	0
13306	11719	01058X	PARTICIPANT	\N	PRESENT	0
13307	11719	14193X	PARTICIPANT	\N	PRESENT	0
13308	11719	04048J	PARTICIPANT	\N	PRESENT	0
13309	11719	11091R	PARTICIPANT	\N	PRESENT	0
13310	11719	98024R	PARTICIPANT	\N	PRESENT	0
13311	11719	01031L	PARTICIPANT	\N	PRESENT	0
13312	11719	01007L	PARTICIPANT	\N	PRESENT	0
13313	11719	14085U	PARTICIPANT	\N	PRESENT	0
13314	11719	08031R	PARTICIPANT	\N	PRESENT	0
13315	11719	14071N	PARTICIPANT	\N	PRESENT	0
13316	11719	01034P	PARTICIPANT	\N	PRESENT	0
13317	11719	14013P	PARTICIPANT	\N	PRESENT	0
13318	11719	04067M	PARTICIPANT	\N	PRESENT	0
13319	11719	01028R	PARTICIPANT	\N	PRESENT	0
13320	11719	04088S	PARTICIPANT	\N	PRESENT	0
13321	11719	01015L	PARTICIPANT	\N	PRESENT	0
13322	11719	04095R	PARTICIPANT	\N	PRESENT	0
13323	11719	92045V	PARTICIPANT	\N	PRESENT	0
13324	11719	11072N	PARTICIPANT	\N	PRESENT	0
13325	11719	14053L	PARTICIPANT	\N	PRESENT	0
13326	11719	14235Q	PARTICIPANT	\N	PRESENT	0
13327	11719	04038G	PARTICIPANT	\N	PRESENT	0
13328	11719	11114F	PARTICIPANT	\N	PRESENT	0
13329	11719	14211G	PARTICIPANT	\N	PRESENT	0
13330	11719	11098Y	PARTICIPANT	\N	PRESENT	0
13331	11719	11082Q	PARTICIPANT	\N	PRESENT	0
13332	11719	95041E	PARTICIPANT	\N	PRESENT	0
13333	11719	14251Q	PARTICIPANT	\N	PRESENT	0
13334	11719	01048V	PARTICIPANT	\N	PRESENT	0
13335	11719	11103C	PARTICIPANT	\N	PRESENT	0
13336	11719	14255U	PARTICIPANT	\N	PRESENT	0
13337	11719	11090Q	PARTICIPANT	\N	PRESENT	0
13338	11719	04054G	PARTICIPANT	\N	PRESENT	0
13339	11719	08068F	PARTICIPANT	\N	PRESENT	0
13340	11719	11025F	PARTICIPANT	\N	PRESENT	0
13341	11719	89017R	PARTICIPANT	\N	PRESENT	0
13342	11719	02002K	PARTICIPANT	\N	PRESENT	0
13344	13343	14261S	PARTICIPANT	\N	PRESENT	0
13345	13343	08055A	PARTICIPANT	\N	PRESENT	0
13346	13343	14093U	PARTICIPANT	\N	PRESENT	0
13347	13343	14030Q	PARTICIPANT	\N	PRESENT	0
13348	13343	96004D	PARTICIPANT	\N	EXCUSE	0
13349	13343	08060W	PARTICIPANT	\N	PRESENT	0
13352	13343	14038Y	PARTICIPANT	\N	PRESENT	0
13353	13343	11114F	PARTICIPANT	\N	PRESENT	0
13355	13343	11065P	PARTICIPANT	\N	PRESENT	0
13356	13343	01015L	PARTICIPANT	\N	PRESENT	0
13357	13343	11107G	PARTICIPANT	\N	EXCUSE	0
13359	13343	02002K	PARTICIPANT	\N	EXCUSE	0
13360	13343	01022K	PARTICIPANT	\N	PRESENT	0
13361	13343	04097T	PARTICIPANT	\N	EXCUSE	0
13362	13343	09001P	PARTICIPANT	\N	PRESENT	0
13364	13343	14219Q	PARTICIPANT	\N	PRESENT	0
13365	13343	80027E	PARTICIPANT	\N	PRESENT	0
13366	13343	14031R	PARTICIPANT	\N	PRESENT	0
13367	13343	08009T	PARTICIPANT	\N	PRESENT	0
13368	13343	08062Y	PARTICIPANT	\N	PRESENT	0
13369	13343	14221J	PARTICIPANT	\N	PRESENT	0
13370	13343	92039X	PARTICIPANT	\N	EXCUSE	0
13371	13343	08042U	PARTICIPANT	\N	PRESENT	0
13372	13343	14169X	PARTICIPANT	\N	PRESENT	0
13373	13343	14237S	PARTICIPANT	\N	PRESENT	0
12849	12847	11055M	PARTICIPANT	\N	PRESENT	0
12850	12847	01046T	PARTICIPANT	\N	PRESENT	0
13374	13343	13002U	PARTICIPANT	\N	PRESENT	0
13375	13343	05012A	PARTICIPANT	\N	PRESENT	0
13385	11719	14259Y	PARTICIPANT	\N	PRESENT	0
12854	12847	00003C	PARTICIPANT	\N	PRESENT	0
12855	12847	14053L	PARTICIPANT	\N	PRESENT	0
12856	12847	11103C	PARTICIPANT	\N	PRESENT	0
12857	12847	11044J	PARTICIPANT	\N	PRESENT	0
12858	12847	14195A	PARTICIPANT	\N	PRESENT	0
13377	13343	14135M	PARTICIPANT	\N	PRESENT	0
13378	13343	95062K	PARTICIPANT	\N	EXCUSE	0
12861	12847	11031D	PARTICIPANT	\N	PRESENT	0
12862	12847	08052W	PARTICIPANT	\N	PRESENT	0
12863	12847	01059Y	PARTICIPANT	\N	PRESENT	0
13379	13343	14107H	PARTICIPANT	\N	PRESENT	0
13380	13343	14051J	PARTICIPANT	\N	PRESENT	0
12866	12847	10006L	PARTICIPANT	\N	PRESENT	0
13381	13343	14157T	PARTICIPANT	\N	PRESENT	0
12868	12847	14217N	PARTICIPANT	\N	PRESENT	0
12869	12847	14042U	PRESIDENT	0	PRESENT	0
13382	13343	96003C	PARTICIPANT	\N	EXCUSE	0
12871	12847	12042Y	PARTICIPANT	\N	PRESENT	0
12872	12847	14281W	PARTICIPANT	\N	PRESENT	0
12873	12847	14087W	PARTICIPANT	\N	PRESENT	0
13383	11719	14119M	PARTICIPANT	\N	PRESENT	0
13384	11719	08034U	PARTICIPANT	\N	PRESENT	0
12876	12847	14231L	PARTICIPANT	\N	PRESENT	0
12877	12847	11061K	PARTICIPANT	\N	PRESENT	0
13386	11719	11110B	PARTICIPANT	\N	PRESENT	0
12879	12847	08041T	PARTICIPANT	\N	EXCUSE	0
13387	11719	04085P	PARTICIPANT	\N	PRESENT	0
12881	12847	14026U	PARTICIPANT	\N	PRESENT	0
12882	12847	14213J	PARTICIPANT	\N	PRESENT	0
12883	12847	14121F	PARTICIPANT	\N	EXCUSE	0
12884	12847	11112D	PARTICIPANT	\N	PRESENT	0
13388	11719	11044J	PARTICIPANT	\N	PRESENT	0
12886	12847	14018U	PARTICIPANT	\N	PRESENT	0
12887	12847	11067R	PARTICIPANT	\N	PRESENT	0
12888	12847	14223L	PARTICIPANT	\N	PRESENT	0
12889	12847	04092N	PARTICIPANT	\N	PRESENT	0
13389	11719	07034Q	PARTICIPANT	\N	PRESENT	0
12891	12847	14119M	PARTICIPANT	\N	PRESENT	0
13391	13390	08025T	PARTICIPANT	\N	PRESENT	0
13392	13390	04085P	PARTICIPANT	\N	PRESENT	0
13393	13390	05008E	PRESIDENT	0	PRESENT	0
12895	12847	14271U	PARTICIPANT	\N	PRESENT	0
13394	13390	11030C	PARTICIPANT	\N	PRESENT	0
12897	12847	11093T	PARTICIPANT	\N	PRESENT	0
12898	12847	11097X	PARTICIPANT	\N	EXCUSE	0
12899	12847	04045F	PARTICIPANT	\N	PRESENT	0
12900	12847	14227Q	PARTICIPANT	\N	PRESENT	0
13395	13390	11033F	PARTICIPANT	\N	PRESENT	0
13396	13390	14065Q	PARTICIPANT	\N	PRESENT	0
12903	12847	11063M	PARTICIPANT	\N	PRESENT	0
12904	12847	14269B	PARTICIPANT	\N	PRESENT	0
13397	13390	14069U	PARTICIPANT	\N	PRESENT	0
13441	11720	08024S	PARTICIPANT	\N	PRESENT	0
13442	11720	12042Y	PARTICIPANT	\N	PRESENT	0
13400	13390	04038G	PARTICIPANT	\N	PRESENT	0
13443	11720	04045F	PARTICIPANT	\N	PRESENT	0
13402	13390	11056N	PARTICIPANT	\N	EXCUSE	0
13444	11720	08052W	PARTICIPANT	\N	PRESENT	0
13404	13390	11035H	PARTICIPANT	\N	PRESENT	0
13405	13390	14041T	PARTICIPANT	\N	PRESENT	0
13406	13390	11113E	PARTICIPANT	\N	PRESENT	0
13407	13390	01024M	PARTICIPANT	\N	PRESENT	0
13408	13390	14215L	PARTICIPANT	\N	PRESENT	0
13409	13390	11034G	PARTICIPANT	\N	PRESENT	0
13410	13390	08018U	PARTICIPANT	\N	PRESENT	0
13445	11720	14081Q	PARTICIPANT	\N	PRESENT	0
13412	13390	01007L	PARTICIPANT	\N	PRESENT	0
13413	13390	11049P	PARTICIPANT	\N	PRESENT	0
13414	13390	95039L	PARTICIPANT	\N	PRESENT	0
13415	13390	08044W	PARTICIPANT	\N	PRESENT	0
13416	13390	11084S	PARTICIPANT	\N	PRESENT	0
13417	13390	11026G	PARTICIPANT	\N	PRESENT	0
13418	13390	04079R	PARTICIPANT	\N	PRESENT	0
13419	13390	14111D	PARTICIPANT	\N	PRESENT	0
13420	13390	14001X	PARTICIPANT	\N	PRESENT	0
13421	13390	14273W	PARTICIPANT	\N	EXCUSE	0
13423	13390	14147R	PARTICIPANT	\N	PRESENT	0
13424	13390	95049N	PARTICIPANT	\N	PRESENT	0
13425	13390	08051V	PARTICIPANT	\N	PRESENT	0
13426	13390	11072N	PARTICIPANT	\N	PRESENT	0
13427	13390	07034Q	PARTICIPANT	\N	PRESENT	0
13428	13390	04074L	PARTICIPANT	\N	PRESENT	0
13429	13390	10015M	PARTICIPANT	\N	PRESENT	0
13430	13390	95063L	PARTICIPANT	\N	PRESENT	0
13431	13390	01019Q	PARTICIPANT	\N	PRESENT	0
13432	13390	01028R	PARTICIPANT	\N	PRESENT	0
13433	13390	98035U	PARTICIPANT	\N	PRESENT	0
13434	13390	04056J	PARTICIPANT	\N	PRESENT	0
13436	13390	04044E	PARTICIPANT	\N	PRESENT	0
13437	13390	11037K	PARTICIPANT	\N	PRESENT	0
13438	13390	95067Q	PARTICIPANT	\N	PRESENT	0
13439	13390	01047U	PARTICIPANT	\N	PRESENT	0
13448	11720	01059Y	PARTICIPANT	\N	PRESENT	0
13450	11720	14261S	PARTICIPANT	\N	PRESENT	0
13451	11720	14231L	PARTICIPANT	\N	PRESENT	0
13452	11720	11063M	PARTICIPANT	\N	PRESENT	0
13453	11720	00003C	PARTICIPANT	\N	PRESENT	0
13454	11720	14269B	PARTICIPANT	\N	PRESENT	0
13455	11720	07004J	PARTICIPANT	\N	PRESENT	0
13456	11720	14205J	PARTICIPANT	\N	PRESENT	0
13457	11720	14055N	PARTICIPANT	\N	PRESENT	0
13458	11720	14187A	PARTICIPANT	\N	PRESENT	0
13460	11720	14265W	PARTICIPANT	\N	PRESENT	0
13462	11720	14169X	PARTICIPANT	\N	PRESENT	0
13464	11720	11112D	PARTICIPANT	\N	PRESENT	0
13465	11720	11054L	PARTICIPANT	\N	PRESENT	0
13467	11720	14033T	PARTICIPANT	\N	PRESENT	0
13468	11720	14031R	PARTICIPANT	\N	PRESENT	0
13469	11720	14079W	PARTICIPANT	\N	PRESENT	0
13472	11720	11014C	PARTICIPANT	\N	PRESENT	0
13473	11720	11109J	PARTICIPANT	\N	PRESENT	0
13476	11720	14281W	PARTICIPANT	\N	PRESENT	0
13477	11720	14097Y	PARTICIPANT	\N	PRESENT	0
13479	11720	04092N	PARTICIPANT	\N	PRESENT	0
13480	11720	11113E	PARTICIPANT	\N	PRESENT	0
13481	11720	08055A	PARTICIPANT	\N	PRESENT	0
13482	11720	11089X	PARTICIPANT	\N	PRESENT	0
13484	11720	08017T	PARTICIPANT	\N	PRESENT	0
13490	11720	01016M	PARTICIPANT	\N	PRESENT	0
13491	11720	14157T	PARTICIPANT	\N	PRESENT	0
13492	11720	14217N	PARTICIPANT	\N	PRESENT	0
13493	11720	14195A	PARTICIPANT	\N	PRESENT	0
13494	11720	01057W	PARTICIPANT	\N	PRESENT	0
13499	11720	14135M	PARTICIPANT	\N	PRESENT	0
13501	11720	04048J	PARTICIPANT	\N	PRESENT	0
13504	11720	14071N	PARTICIPANT	\N	PRESENT	0
13507	11720	04088S	PARTICIPANT	\N	PRESENT	0
13508	11720	01015L	PARTICIPANT	\N	PRESENT	0
13509	11720	04095R	PARTICIPANT	\N	PRESENT	0
13510	11720	92045V	PARTICIPANT	\N	PRESENT	0
13511	11720	14235Q	PARTICIPANT	\N	PRESENT	0
13512	11720	14211G	PARTICIPANT	\N	PRESENT	0
13515	11720	11090Q	PARTICIPANT	\N	PRESENT	0
13516	11720	04054G	PARTICIPANT	\N	PRESENT	0
11780	11656	14042U	PARTICIPANT	\N	PRESENT	0
11781	11656	04092N	PARTICIPANT	\N	PRESENT	0
11782	11656	11025F	PARTICIPANT	\N	PRESENT	0
11783	11656	14030Q	PARTICIPANT	\N	PRESENT	0
11778	11656	04081K	PARTICIPANT	\N	PRESENT	0
11779	11656	10006L	PARTICIPANT	\N	PRESENT	0
11784	11656	14063N	PARTICIPANT	\N	PRESENT	0
11785	11656	14221J	PARTICIPANT	\N	PRESENT	0
11786	11656	14041T	PARTICIPANT	\N	PRESENT	0
11787	11656	14105F	PARTICIPANT	\N	PRESENT	0
11788	11656	01046T	PARTICIPANT	\N	PRESENT	0
11789	11656	14173T	PARTICIPANT	\N	PRESENT	0
11863	11656	04041B	PARTICIPANT	\N	PRESENT	0
11791	11656	14033T	PARTICIPANT	\N	PRESENT	0
11792	11656	04088S	PARTICIPANT	\N	PRESENT	0
11793	11656	14135M	PARTICIPANT	\N	PRESENT	0
11794	11656	90003B	PARTICIPANT	\N	PRESENT	0
11795	11656	10015M	PARTICIPANT	\N	PRESENT	0
11796	11656	11103C	PARTICIPANT	\N	PRESENT	0
11797	11656	14147R	PARTICIPANT	\N	PRESENT	0
11798	11656	14227Q	PARTICIPANT	\N	PRESENT	0
11799	11656	01059Y	PARTICIPANT	\N	PRESENT	0
11800	11656	07026Q	PARTICIPANT	\N	PRESENT	0
11801	11656	01011G	PARTICIPANT	\N	PRESENT	0
11802	11656	04045F	PARTICIPANT	\N	PRESENT	0
11803	11656	11037K	PARTICIPANT	\N	PRESENT	0
11804	11656	08052W	PARTICIPANT	\N	PRESENT	0
11805	11656	14207L	PARTICIPANT	\N	PRESENT	0
11806	11656	14151M	PARTICIPANT	\N	PRESENT	0
11807	11656	14179A	PARTICIPANT	\N	PRESENT	0
11808	11656	14239U	PARTICIPANT	\N	PRESENT	0
11809	11656	14281W	PARTICIPANT	\N	PRESENT	0
11810	11656	14271U	PARTICIPANT	\N	PRESENT	0
11811	11656	11063M	PARTICIPANT	\N	PRESENT	0
11812	11656	08068F	PARTICIPANT	\N	PRESENT	0
11813	11656	14197C	PARTICIPANT	\N	PRESENT	0
11814	11656	14109K	PARTICIPANT	\N	PRESENT	0
11815	11656	11114F	PARTICIPANT	\N	PRESENT	0
11816	11656	11031D	PARTICIPANT	\N	PRESENT	0
11817	11656	11055M	PARTICIPANT	\N	PRESENT	0
11818	11656	11029K	PARTICIPANT	\N	PRESENT	0
11819	11656	11067R	PARTICIPANT	\N	PRESENT	0
11820	11656	11112D	PARTICIPANT	\N	PRESENT	0
11821	11656	14219Q	PARTICIPANT	\N	PRESENT	0
11822	11656	14269B	PARTICIPANT	\N	PRESENT	0
11823	11656	11066Q	PARTICIPANT	\N	PRESENT	0
11824	11656	11014C	PARTICIPANT	\N	PRESENT	0
11825	11656	14257W	PARTICIPANT	\N	PRESENT	0
11826	11656	00003C	PARTICIPANT	\N	PRESENT	0
11827	11656	80013X	PARTICIPANT	\N	PRESENT	0
11828	11656	12042Y	PARTICIPANT	\N	PRESENT	0
11829	11656	11110B	PARTICIPANT	\N	PRESENT	0
11830	11656	14018U	PARTICIPANT	\N	PRESENT	0
11831	11656	11012A	PARTICIPANT	\N	PRESENT	0
11832	11656	08031R	PARTICIPANT	\N	PRESENT	0
11833	11656	14089Y	PARTICIPANT	\N	PRESENT	0
11834	11656	14205J	PARTICIPANT	\N	PRESENT	0
11835	11656	11093T	PARTICIPANT	\N	PRESENT	0
11836	11656	14061L	PARTICIPANT	\N	PRESENT	0
11837	11656	14217N	PARTICIPANT	\N	PRESENT	0
11838	11656	11023D	PARTICIPANT	\N	PRESENT	0
11839	11656	14103D	PARTICIPANT	\N	PRESENT	0
11840	11656	11109J	PARTICIPANT	\N	PRESENT	0
11841	11656	80027E	PARTICIPANT	\N	PRESENT	0
11842	11656	11081P	PARTICIPANT	\N	PRESENT	0
11843	11656	14087W	PARTICIPANT	\N	PRESENT	0
11844	11656	08056B	PARTICIPANT	\N	PRESENT	0
11845	11656	11053K	PARTICIPANT	\N	PRESENT	0
11846	11656	11054L	PARTICIPANT	\N	PRESENT	0
11847	11656	14263U	PARTICIPANT	\N	PRESENT	0
11848	11656	01013J	PARTICIPANT	\N	PRESENT	0
11849	11656	14071N	PARTICIPANT	\N	PRESENT	0
11850	11656	07029T	PARTICIPANT	\N	PRESENT	0
11851	11656	08069G	PARTICIPANT	\N	PRESENT	0
11852	11656	14231L	PARTICIPANT	\N	PRESENT	0
11853	11656	14267Y	PARTICIPANT	\N	PRESENT	0
11854	11656	14201E	PARTICIPANT	\N	PRESENT	0
11855	11656	01028R	PARTICIPANT	\N	PRESENT	0
11856	11656	08048B	PARTICIPANT	\N	PRESENT	0
11857	11656	11089X	PARTICIPANT	\N	PRESENT	0
11858	11656	14119M	PARTICIPANT	\N	PRESENT	0
11859	11656	14038Y	PARTICIPANT	\N	PRESENT	0
11860	11656	14031R	PARTICIPANT	\N	PRESENT	0
11861	11656	11011M	PARTICIPANT	\N	PRESENT	0
11862	11656	01057W	PARTICIPANT	\N	PRESENT	0
11864	11656	14223L	PARTICIPANT	\N	PRESENT	0
11865	11656	14195A	PARTICIPANT	\N	PRESENT	0
11866	11656	14251Q	PARTICIPANT	\N	PRESENT	0
11867	11656	08015R	PARTICIPANT	\N	PRESENT	0
11868	11656	14213J	PARTICIPANT	\N	PRESENT	0
11869	11656	14059S	PARTICIPANT	\N	PRESENT	0
11870	11656	14053L	PARTICIPANT	\N	PRESENT	0
11871	11656	14026U	PARTICIPANT	\N	PRESENT	0
11872	11656	04043D	PARTICIPANT	\N	PRESENT	0
11873	11656	95041E	PARTICIPANT	\N	PRESENT	0
11874	11656	14327T	PARTICIPANT	\N	PRESENT	0
11875	11656	08041T	PARTICIPANT	\N	PRESENT	0
11876	11656	88008L	PARTICIPANT	\N	PRESENT	0
11877	11656	08016S	PARTICIPANT	\N	PRESENT	0
11878	11656	14235Q	PARTICIPANT	\N	PRESENT	0
11879	11656	14013P	PARTICIPANT	\N	PRESENT	0
11880	11656	11042G	PARTICIPANT	\N	PRESENT	0
11881	11656	14034U	PARTICIPANT	\N	PRESENT	0
11882	11656	87003B	PARTICIPANT	\N	PRESENT	0
11883	11656	08062Y	PARTICIPANT	\N	PRESENT	0
11884	11656	14111D	PARTICIPANT	\N	PRESENT	0
11887	11656	14209N	PARTICIPANT	\N	PRESENT	0
11888	11656	14187A	PARTICIPANT	\N	PRESENT	0
11889	11656	09001P	PARTICIPANT	\N	PRESENT	0
11890	11656	08039A	PARTICIPANT	\N	PRESENT	0
11891	11656	08034U	PARTICIPANT	\N	PRESENT	0
11892	11656	04059M	PARTICIPANT	\N	PRESENT	0
11893	11656	08024S	PARTICIPANT	\N	PRESENT	0
11894	11656	14081Q	PARTICIPANT	\N	PRESENT	0
11895	11656	04053F	PARTICIPANT	\N	PRESENT	0
11896	11656	98024R	PARTICIPANT	\N	PRESENT	0
11897	11656	86044G	PARTICIPANT	\N	PRESENT	0
11898	11656	01034P	PARTICIPANT	\N	PRESENT	0
11899	11656	11036J	PARTICIPANT	\N	PRESENT	0
11900	11656	08042U	PARTICIPANT	\N	PRESENT	0
11901	11656	13002U	PARTICIPANT	\N	PRESENT	0
11902	11656	14037X	PARTICIPANT	\N	PRESENT	0
11962	11656	14028W	PARTICIPANT	\N	PRESENT	0
11965	11656	01008M	PARTICIPANT	\N	PRESENT	0
11967	11656	14065Q	PARTICIPANT	\N	PRESENT	0
11968	11656	07032N	PARTICIPANT	\N	PRESENT	0
11969	11656	08017T	PARTICIPANT	\N	PRESENT	0
11970	11656	11106F	PARTICIPANT	\N	PRESENT	0
11972	11656	01022K	PARTICIPANT	\N	PRESENT	0
11973	11656	92045V	PARTICIPANT	\N	PRESENT	0
11974	11656	11035H	PARTICIPANT	\N	PRESENT	0
11975	11656	95063L	PARTICIPANT	\N	PRESENT	0
11976	11656	14247U	PARTICIPANT	\N	PRESENT	0
11977	11656	07004J	PARTICIPANT	\N	PRESENT	0
11978	11656	08060W	PARTICIPANT	\N	PRESENT	0
11983	11659	11025F	PARTICIPANT	\N	PRESENT	0
11984	11659	14030Q	PARTICIPANT	\N	PRESENT	0
11985	11659	14063N	PARTICIPANT	\N	PRESENT	0
11986	11659	14221J	PARTICIPANT	\N	PRESENT	0
11987	11659	14041T	PARTICIPANT	\N	PRESENT	0
11988	11659	14105F	PARTICIPANT	\N	PRESENT	0
11989	11659	01046T	PARTICIPANT	\N	PRESENT	0
11990	11659	14173T	PARTICIPANT	\N	PRESENT	0
11991	11659	14033T	PARTICIPANT	\N	PRESENT	0
11992	11659	04088S	PARTICIPANT	\N	PRESENT	0
11993	11659	14135M	PARTICIPANT	\N	PRESENT	0
11994	11659	90003B	PARTICIPANT	\N	PRESENT	0
11995	11659	10015M	PARTICIPANT	\N	PRESENT	0
11996	11659	11103C	PARTICIPANT	\N	PRESENT	0
11997	11659	14147R	PARTICIPANT	\N	PRESENT	0
11998	11659	14227Q	PARTICIPANT	\N	PRESENT	0
11999	11659	01059Y	PARTICIPANT	\N	PRESENT	0
12000	11659	07026Q	PARTICIPANT	\N	PRESENT	0
12001	11659	01011G	PARTICIPANT	\N	PRESENT	0
12002	11659	04045F	PARTICIPANT	\N	PRESENT	0
12004	11659	08052W	PARTICIPANT	\N	PRESENT	0
12005	11659	14207L	PARTICIPANT	\N	PRESENT	0
12006	11659	14151M	PARTICIPANT	\N	PRESENT	0
12007	11659	14179A	PARTICIPANT	\N	PRESENT	0
12008	11659	14239U	PARTICIPANT	\N	PRESENT	0
12009	11659	14281W	PARTICIPANT	\N	PRESENT	0
12010	11659	14271U	PARTICIPANT	\N	PRESENT	0
12012	11659	08068F	PARTICIPANT	\N	PRESENT	0
12013	11659	14197C	PARTICIPANT	\N	PRESENT	0
12014	11659	14109K	PARTICIPANT	\N	PRESENT	0
12015	11659	11114F	PARTICIPANT	\N	PRESENT	0
12016	11659	11031D	PARTICIPANT	\N	PRESENT	0
12125	11659	04038G	PARTICIPANT	\N	PRESENT	0
12018	11659	11029K	PARTICIPANT	\N	PRESENT	0
12019	11659	11067R	PARTICIPANT	\N	PRESENT	0
12020	11659	11112D	PARTICIPANT	\N	PRESENT	0
12021	11659	14219Q	PARTICIPANT	\N	PRESENT	0
12022	11659	14269B	PARTICIPANT	\N	PRESENT	0
12023	11659	11066Q	PARTICIPANT	\N	PRESENT	0
12024	11659	11014C	PARTICIPANT	\N	PRESENT	0
12025	11659	14257W	PARTICIPANT	\N	PRESENT	0
12026	11659	00003C	PARTICIPANT	\N	PRESENT	0
12027	11659	80013X	PARTICIPANT	\N	PRESENT	0
12028	11659	12042Y	PARTICIPANT	\N	PRESENT	0
12029	11659	11110B	PARTICIPANT	\N	PRESENT	0
12030	11659	14018U	PARTICIPANT	\N	PRESENT	0
12128	11659	11074Q	PARTICIPANT	\N	PRESENT	0
12032	11659	08031R	PARTICIPANT	\N	PRESENT	0
12033	11659	14089Y	PARTICIPANT	\N	PRESENT	0
12034	11659	14205J	PARTICIPANT	\N	PRESENT	0
12035	11659	11093T	PARTICIPANT	\N	PRESENT	0
12036	11659	14061L	PARTICIPANT	\N	PRESENT	0
12037	11659	14217N	PARTICIPANT	\N	PRESENT	0
12130	11659	04056J	PARTICIPANT	\N	PRESENT	0
12039	11659	14103D	PARTICIPANT	\N	PRESENT	0
12040	11659	11109J	PARTICIPANT	\N	PRESENT	0
12041	11659	80027E	PARTICIPANT	\N	PRESENT	0
12042	11659	11081P	PARTICIPANT	\N	PRESENT	0
12043	11659	14087W	PARTICIPANT	\N	PRESENT	0
12154	11659	14073Q	PARTICIPANT	\N	PRESENT	0
12148	11659	14042U	PARTICIPANT	\N	PRESENT	0
12046	11659	11054L	PARTICIPANT	\N	PRESENT	0
12047	11659	14263U	PARTICIPANT	\N	PRESENT	0
12048	11659	01013J	PARTICIPANT	\N	PRESENT	0
12049	11659	14071N	PARTICIPANT	\N	PRESENT	0
12050	11659	07029T	PARTICIPANT	\N	PRESENT	0
12051	11659	08069G	PARTICIPANT	\N	PRESENT	0
12151	11659	98022P	PARTICIPANT	\N	PRESENT	0
12149	11659	14014Q	PARTICIPANT	\N	PRESENT	0
12054	11659	14201E	PARTICIPANT	\N	PRESENT	0
12055	11659	01028R	PARTICIPANT	\N	PRESENT	0
12178	11659	04048J	PARTICIPANT	\N	PRESENT	0
12057	11659	11089X	PARTICIPANT	\N	PRESENT	0
12058	11659	14119M	PARTICIPANT	\N	PRESENT	0
12167	11659	98018T	PARTICIPANT	\N	PRESENT	0
12060	11659	14031R	PARTICIPANT	\N	PRESENT	0
12061	11659	11011M	PARTICIPANT	\N	PRESENT	0
12062	11659	01057W	PARTICIPANT	\N	PRESENT	0
12063	11659	04041B	PARTICIPANT	\N	PRESENT	0
12064	11659	14223L	PARTICIPANT	\N	PRESENT	0
12065	11659	14195A	PARTICIPANT	\N	PRESENT	0
12066	11659	14251Q	PARTICIPANT	\N	PRESENT	0
12067	11659	08015R	PARTICIPANT	\N	PRESENT	0
12068	11659	14213J	PARTICIPANT	\N	PRESENT	0
12069	11659	14059S	PARTICIPANT	\N	PRESENT	0
12070	11659	14053L	PARTICIPANT	\N	PRESENT	0
12071	11659	14026U	PARTICIPANT	\N	PRESENT	0
12072	11659	04043D	PARTICIPANT	\N	PRESENT	0
12073	11659	95041E	PARTICIPANT	\N	PRESENT	0
12074	11659	14327T	PARTICIPANT	\N	PRESENT	0
12075	11659	08041T	PARTICIPANT	\N	PRESENT	0
12076	11659	88008L	PARTICIPANT	\N	PRESENT	0
12077	11659	08016S	PARTICIPANT	\N	PRESENT	0
12078	11659	14235Q	PARTICIPANT	\N	PRESENT	0
12079	11659	14013P	PARTICIPANT	\N	PRESENT	0
12080	11659	11042G	PARTICIPANT	\N	PRESENT	0
12081	11659	14034U	PARTICIPANT	\N	PRESENT	0
12082	11659	87003B	PARTICIPANT	\N	PRESENT	0
12083	11659	08062Y	PARTICIPANT	\N	PRESENT	0
12084	11659	14111D	PARTICIPANT	\N	PRESENT	0
12085	11659	14209N	PARTICIPANT	\N	PRESENT	0
12086	11659	14187A	PARTICIPANT	\N	PRESENT	0
12087	11659	09001P	PARTICIPANT	\N	PRESENT	0
12088	11659	08039A	PARTICIPANT	\N	PRESENT	0
12089	11659	08034U	PARTICIPANT	\N	PRESENT	0
12129	11659	01037S	PARTICIPANT	\N	PRESENT	0
12091	11659	08024S	PARTICIPANT	\N	PRESENT	0
12092	11659	14081Q	PARTICIPANT	\N	PRESENT	0
12093	11659	04053F	PARTICIPANT	\N	PRESENT	0
12094	11659	98024R	PARTICIPANT	\N	PRESENT	0
12095	11659	86044G	PARTICIPANT	\N	PRESENT	0
12096	11659	01034P	PARTICIPANT	\N	PRESENT	0
12097	11659	11036J	PARTICIPANT	\N	PRESENT	0
12098	11659	08042U	PARTICIPANT	\N	PRESENT	0
12099	11659	13002U	PARTICIPANT	\N	PRESENT	0
12100	11659	14037X	PARTICIPANT	\N	PRESENT	0
12101	11659	14028W	PARTICIPANT	\N	PRESENT	0
12102	11659	01008M	PARTICIPANT	\N	PRESENT	0
12103	11659	14065Q	PARTICIPANT	\N	PRESENT	0
12105	11659	08017T	PARTICIPANT	\N	PRESENT	0
12106	11659	11106F	PARTICIPANT	\N	PRESENT	0
12107	11659	01022K	PARTICIPANT	\N	PRESENT	0
12108	11659	92045V	PARTICIPANT	\N	PRESENT	0
12109	11659	11035H	PARTICIPANT	\N	PRESENT	0
12110	11659	95063L	PARTICIPANT	\N	PRESENT	0
12111	11659	14247U	PARTICIPANT	\N	PRESENT	0
12112	11659	07004J	PARTICIPANT	\N	PRESENT	0
12113	11659	08060W	PARTICIPANT	\N	PRESENT	0
12114	11659	86034E	PARTICIPANT	\N	PRESENT	0
12115	11659	04085P	PARTICIPANT	\N	PRESENT	0
12116	11659	92018S	PARTICIPANT	\N	PRESENT	0
12117	11659	98053W	PARTICIPANT	\N	PRESENT	0
12118	11659	12041X	PARTICIPANT	\N	PRESENT	0
12122	11659	11033F	PARTICIPANT	\N	PRESENT	0
12120	11659	11056N	PARTICIPANT	\N	PRESENT	0
12121	11659	11098Y	PARTICIPANT	\N	PRESENT	0
12123	11659	11069T	PARTICIPANT	\N	PRESENT	0
12124	11659	14261S	PARTICIPANT	\N	PRESENT	0
12126	11659	08051V	PARTICIPANT	\N	PRESENT	0
12127	11659	08049C	PARTICIPANT	\N	PRESENT	0
12132	11659	11015D	PARTICIPANT	\N	PRESENT	0
12133	11659	11027H	PARTICIPANT	\N	PRESENT	0
12134	11659	11077T	PARTICIPANT	\N	PRESENT	0
12135	11659	08012N	PARTICIPANT	\N	PRESENT	0
12136	11659	11076S	PARTICIPANT	\N	PRESENT	0
12137	11659	98046X	PARTICIPANT	\N	PRESENT	0
12138	11659	14001X	PARTICIPANT	\N	PRESENT	0
12139	11659	83042R	PARTICIPANT	\N	PRESENT	0
12140	11659	08061X	PARTICIPANT	\N	PRESENT	0
12141	11659	01016M	PARTICIPANT	\N	PRESENT	0
12142	11659	08055A	PARTICIPANT	\N	PRESENT	0
12143	11659	14225N	PARTICIPANT	\N	PRESENT	0
12144	11659	14107H	PARTICIPANT	\N	PRESENT	0
12145	11659	14051J	PARTICIPANT	\N	PRESENT	0
12146	11659	11057P	PARTICIPANT	\N	PRESENT	0
12147	11659	04040A	PARTICIPANT	\N	PRESENT	0
12150	11659	14241N	PARTICIPANT	\N	PRESENT	0
12152	11659	01007L	PARTICIPANT	\N	PRESENT	0
12153	11659	04066L	PARTICIPANT	\N	PRESENT	0
12155	11659	11111C	PARTICIPANT	\N	PRESENT	0
12156	11659	08009T	PARTICIPANT	\N	PRESENT	0
12157	11659	11082Q	PARTICIPANT	\N	PRESENT	0
12158	11659	11094U	PARTICIPANT	\N	PRESENT	0
12159	11659	01047U	PARTICIPANT	\N	PRESENT	0
12160	11659	05008E	PARTICIPANT	\N	PRESENT	0
12161	11659	11012A	PARTICIPANT	\N	PRESENT	0
12162	11659	11037K	PARTICIPANT	\N	PRESENT	0
12163	11659	14069U	PARTICIPANT	\N	PRESENT	0
12164	11659	11080N	PARTICIPANT	\N	PRESENT	0
12165	11659	14079W	PARTICIPANT	\N	PRESENT	0
12166	11659	01024M	PARTICIPANT	\N	PRESENT	0
12168	11659	04089T	PARTICIPANT	\N	PRESENT	0
12169	11659	11088W	PARTICIPANT	\N	PRESENT	0
12170	11659	14215L	PARTICIPANT	\N	PRESENT	0
12171	11659	14249W	PARTICIPANT	\N	PRESENT	0
12172	11659	01041N	PARTICIPANT	\N	PRESENT	0
12173	11659	08065C	PARTICIPANT	\N	PRESENT	0
12174	11659	07024N	PARTICIPANT	\N	PRESENT	0
12175	11659	14199E	PARTICIPANT	\N	PRESENT	0
12176	11659	95035G	PARTICIPANT	\N	PRESENT	0
12177	11659	14211G	PARTICIPANT	\N	PRESENT	0
12179	11659	95039L	PARTICIPANT	\N	PRESENT	0
12180	11659	04061F	PARTICIPANT	\N	PRESENT	0
12181	11659	01048V	PARTICIPANT	\N	PRESENT	0
12182	11659	04057K	PARTICIPANT	\N	PRESENT	0
12183	11659	14265W	PARTICIPANT	\N	PRESENT	0
12184	11659	04049K	PARTICIPANT	\N	PRESENT	0
12185	11659	98029W	PARTICIPANT	\N	PRESENT	0
12186	11659	92031P	PARTICIPANT	\N	PRESENT	0
12187	11659	04033B	PARTICIPANT	\N	PRESENT	0
12188	11659	95067Q	PARTICIPANT	\N	PRESENT	0
12189	11659	08010L	PARTICIPANT	\N	PRESENT	0
12190	11659	01061S	PARTICIPANT	\N	PRESENT	0
12191	11659	04081K	PARTICIPANT	\N	PRESENT	0
12192	11659	14253S	PARTICIPANT	\N	PRESENT	0
12193	11659	08022Q	PARTICIPANT	\N	PRESENT	0
12194	11659	05012A	PARTICIPANT	\N	PRESENT	0
12195	11659	11048N	PARTICIPANT	\N	PRESENT	0
12196	11659	95059Q	PARTICIPANT	\N	PRESENT	0
12197	11659	01058X	PARTICIPANT	\N	PRESENT	0
12198	11659	01056V	PARTICIPANT	\N	PRESENT	0
12199	11659	04044E	PARTICIPANT	\N	PRESENT	0
12200	11659	01031L	PARTICIPANT	\N	PRESENT	0
12201	11659	04042C	PARTICIPANT	\N	PRESENT	0
12284	11659	11063M	PARTICIPANT	\N	PRESENT	0
12203	11659	01015L	PARTICIPANT	\N	PRESENT	0
12204	11659	11099A	PARTICIPANT	\N	PRESENT	0
12205	11659	11032E	PARTICIPANT	\N	PRESENT	0
12206	11659	98042T	PARTICIPANT	\N	PRESENT	0
12207	11659	11060J	PARTICIPANT	\N	PRESENT	0
12208	11659	11104D	PARTICIPANT	\N	PRESENT	0
12209	11659	08038Y	PARTICIPANT	\N	PRESENT	0
12210	11659	08053X	PARTICIPANT	\N	PRESENT	0
12211	11659	11044J	PARTICIPANT	\N	PRESENT	0
12213	11659	14229S	PARTICIPANT	\N	PRESENT	0
12214	11659	11046L	PARTICIPANT	\N	PRESENT	0
12272	11659	04059M	PARTICIPANT	\N	PRESENT	0
12277	11659	04034C	PARTICIPANT	\N	PRESENT	0
12274	11659	08048B	PARTICIPANT	\N	PRESENT	0
12275	11659	11071M	PARTICIPANT	\N	PRESENT	0
12276	11659	11090Q	PARTICIPANT	\N	PRESENT	0
12278	11659	01044R	PARTICIPANT	\N	PRESENT	0
12282	11659	04054G	PARTICIPANT	\N	PRESENT	0
12280	11659	14169X	PARTICIPANT	\N	PRESENT	0
12286	11659	08018U	PARTICIPANT	\N	PRESENT	0
12283	11659	14231L	PARTICIPANT	\N	PRESENT	0
12285	11659	14083S	PARTICIPANT	\N	PRESENT	0
12287	11659	14097Y	PARTICIPANT	\N	PRESENT	0
12288	11659	04035D	PARTICIPANT	\N	PRESENT	0
12289	11659	11084S	PARTICIPANT	\N	PRESENT	0
12290	11659	14237S	PARTICIPANT	\N	PRESENT	0
12291	11659	99004R	PARTICIPANT	\N	PRESENT	0
12292	11659	07034Q	PARTICIPANT	\N	PRESENT	0
12293	11659	11065P	PARTICIPANT	\N	PRESENT	0
12533	11658	04081K	PARTICIPANT	\N	PRESENT	0
12295	11659	14038Y	PARTICIPANT	\N	PRESENT	0
12296	11659	01025N	PARTICIPANT	\N	PRESENT	0
12534	11658	04092N	PARTICIPANT	\N	PRESENT	0
12535	11658	10006L	PARTICIPANT	\N	PRESENT	0
12536	11658	14042U	PARTICIPANT	\N	PRESENT	0
12537	11658	01059Y	PARTICIPANT	\N	PRESENT	0
12538	11658	11063M	PARTICIPANT	\N	PRESENT	0
12539	11658	01015L	PARTICIPANT	\N	PRESENT	0
12540	11658	14013P	PARTICIPANT	\N	PRESENT	0
12541	11658	14235Q	PARTICIPANT	\N	PRESENT	0
12542	11658	04088S	PARTICIPANT	\N	PRESENT	0
12543	11658	04041B	PARTICIPANT	\N	PRESENT	0
12544	11658	92045V	PARTICIPANT	\N	PRESENT	0
12545	11658	08062Y	PARTICIPANT	\N	PRESENT	0
12546	11658	14033T	PARTICIPANT	\N	PRESENT	0
12547	11658	07029T	PARTICIPANT	\N	PRESENT	0
12548	11658	14030Q	PARTICIPANT	\N	PRESENT	0
12549	11658	14037X	PARTICIPANT	\N	PRESENT	0
12550	11658	90003B	PARTICIPANT	\N	PRESENT	0
12551	11658	14265W	PARTICIPANT	\N	PRESENT	0
12552	11658	14026U	PARTICIPANT	\N	PRESENT	0
12553	11658	14147R	PARTICIPANT	\N	PRESENT	0
12554	11658	11093T	PARTICIPANT	\N	PRESENT	0
12555	11658	14219Q	PARTICIPANT	\N	PRESENT	0
12556	11658	01025N	PARTICIPANT	\N	PRESENT	0
12557	11658	08052W	PARTICIPANT	\N	PRESENT	0
12558	11658	01007L	PARTICIPANT	\N	PRESENT	0
12559	11658	14215L	PARTICIPANT	\N	PRESENT	0
12560	11658	04045F	PARTICIPANT	\N	PRESENT	0
12561	11658	14217N	PARTICIPANT	\N	PRESENT	0
12562	11658	14257W	PARTICIPANT	\N	PRESENT	0
12563	11658	14103D	PARTICIPANT	\N	PRESENT	0
12564	11658	08055A	PARTICIPANT	\N	PRESENT	0
12565	11658	14018U	PARTICIPANT	\N	PRESENT	0
12566	11658	08068F	PARTICIPANT	\N	PRESENT	0
12567	11658	11012A	PARTICIPANT	\N	PRESENT	0
12568	11658	14261S	PARTICIPANT	\N	PRESENT	0
12569	11658	14213J	PARTICIPANT	\N	PRESENT	0
12570	11658	08024S	PARTICIPANT	\N	PRESENT	0
12571	11658	14071N	PARTICIPANT	\N	PRESENT	0
12572	11658	04066L	PARTICIPANT	\N	PRESENT	0
12573	11658	08016S	PARTICIPANT	\N	PRESENT	0
12574	11658	14151M	PARTICIPANT	\N	PRESENT	0
12575	11658	11054L	PARTICIPANT	\N	PRESENT	0
12576	11658	80013X	PARTICIPANT	\N	PRESENT	0
12577	11658	80027E	PARTICIPANT	\N	PRESENT	0
12578	11658	14109K	PARTICIPANT	\N	PRESENT	0
12579	11658	14269B	PARTICIPANT	\N	PRESENT	0
12580	11658	11112D	PARTICIPANT	\N	PRESENT	0
12581	11658	14063N	PARTICIPANT	\N	PRESENT	0
12582	11658	14227Q	PARTICIPANT	\N	PRESENT	0
12583	11658	11099A	PARTICIPANT	\N	PRESENT	0
12584	11658	11055M	PARTICIPANT	\N	PRESENT	0
12585	11658	00003C	PARTICIPANT	\N	PRESENT	0
12586	11658	14271U	PARTICIPANT	\N	PRESENT	0
12587	11658	14281W	PARTICIPANT	\N	PRESENT	0
12588	11658	05012A	PARTICIPANT	\N	PRESENT	0
12589	11658	12042Y	PARTICIPANT	\N	PRESENT	0
12590	11658	14231L	PARTICIPANT	\N	PRESENT	0
12591	11658	11067R	PARTICIPANT	\N	PRESENT	0
12592	11658	14081Q	PARTICIPANT	\N	PRESENT	0
12593	11658	01034P	PARTICIPANT	\N	PRESENT	0
12594	11658	11114F	PARTICIPANT	\N	PRESENT	0
12595	11658	11025F	PARTICIPANT	\N	PRESENT	0
12596	11658	08061X	PARTICIPANT	\N	PRESENT	0
12597	11658	01011G	PARTICIPANT	\N	PRESENT	0
12598	11658	11031D	PARTICIPANT	\N	PRESENT	0
12599	11658	01046T	PARTICIPANT	\N	PRESENT	0
12600	11658	11044J	PARTICIPANT	\N	PRESENT	0
12601	11658	14169X	PARTICIPANT	\N	PRESENT	0
12602	11658	01008M	PARTICIPANT	\N	PRESENT	0
12603	11658	11061K	PARTICIPANT	\N	PRESENT	0
12604	11658	14107H	PARTICIPANT	\N	PRESENT	0
12605	11658	11089X	PARTICIPANT	\N	PRESENT	0
12606	11658	14135M	PARTICIPANT	\N	PRESENT	0
12607	11658	11103C	PARTICIPANT	\N	PRESENT	0
12608	11658	11109J	PARTICIPANT	\N	PRESENT	0
12609	11658	14221J	PARTICIPANT	\N	PRESENT	0
12610	11658	11036J	PARTICIPANT	\N	PRESENT	0
12611	11658	11014C	PARTICIPANT	\N	PRESENT	0
12612	11658	95041E	PARTICIPANT	\N	PRESENT	0
12613	11658	13002U	PARTICIPANT	\N	PRESENT	0
12614	11658	14197C	PARTICIPANT	\N	PRESENT	0
12615	11658	14207L	PARTICIPANT	\N	PRESENT	0
12616	11658	14327T	PARTICIPANT	\N	PRESENT	0
12617	11658	08038Y	PARTICIPANT	\N	PRESENT	0
12618	11658	11066Q	PARTICIPANT	\N	PRESENT	0
12619	11658	04053F	PARTICIPANT	\N	PRESENT	0
12620	11658	14065Q	PARTICIPANT	\N	PRESENT	0
12621	11658	08034U	PARTICIPANT	\N	PRESENT	0
12622	11658	14089Y	PARTICIPANT	\N	PRESENT	0
12623	11658	14079W	PARTICIPANT	\N	PRESENT	0
12624	11658	10015M	PARTICIPANT	\N	PRESENT	0
12625	11658	14205J	PARTICIPANT	\N	PRESENT	0
12626	11658	01057W	PARTICIPANT	\N	PRESENT	0
12627	11658	14119M	PARTICIPANT	\N	PRESENT	0
12628	11658	14157T	PARTICIPANT	\N	PRESENT	0
12629	11658	08069G	PARTICIPANT	\N	PRESENT	0
12630	11658	14034U	PARTICIPANT	\N	PRESENT	0
12631	11658	14051J	PARTICIPANT	\N	PRESENT	0
12632	11658	11094U	PARTICIPANT	\N	PRESENT	0
12633	11658	14038Y	PARTICIPANT	\N	PRESENT	0
12634	11658	14014Q	PARTICIPANT	\N	PRESENT	0
12635	11658	04049K	PARTICIPANT	\N	PRESENT	0
12636	11658	11111C	PARTICIPANT	\N	PRESENT	0
12637	11658	14097Y	PARTICIPANT	\N	PRESENT	0
12638	11658	01016M	PARTICIPANT	\N	PRESENT	0
12639	11658	11053K	PARTICIPANT	\N	PRESENT	0
11885	11326	08043V	PARTICIPANT	\N	EXCUSE	0
11886	11326	95015C	PARTICIPANT	\N	EXCUSE	0
12747	11657	04066L	PARTICIPANT	\N	PRESENT	0
12215	12212	14239U	PARTICIPANT	\N	PRESENT	0
12216	12212	11055M	PARTICIPANT	\N	PRESENT	0
12748	11657	11031D	PARTICIPANT	\N	PRESENT	0
12749	11657	11109J	PARTICIPANT	\N	PRESENT	0
12750	11657	08069G	PARTICIPANT	\N	PRESENT	0
12751	11657	14097Y	PARTICIPANT	\N	PRESENT	0
12752	11657	14227Q	PARTICIPANT	\N	PRESENT	0
12222	12212	14053L	PARTICIPANT	\N	PRESENT	0
12223	12212	11103C	PARTICIPANT	\N	PRESENT	0
12753	11657	14257W	PARTICIPANT	\N	PRESENT	0
12225	12212	14195A	PARTICIPANT	\N	PRESENT	0
12754	11657	00003C	PARTICIPANT	\N	PRESENT	0
12755	11657	04045F	PARTICIPANT	\N	PRESENT	0
12228	12212	11031D	PARTICIPANT	\N	PRESENT	0
12229	12212	08052W	PARTICIPANT	\N	PRESENT	0
12230	12212	01059Y	PARTICIPANT	\N	PRESENT	0
12756	11657	14281W	PARTICIPANT	\N	PRESENT	0
12232	12212	98024R	PARTICIPANT	\N	PRESENT	0
12233	12212	10006L	PARTICIPANT	\N	PRESENT	0
12757	11657	14271U	PARTICIPANT	\N	PRESENT	0
12235	12212	14217N	PARTICIPANT	\N	PRESENT	0
12236	12212	14042U	PARTICIPANT	\N	PRESENT	0
12758	11657	14051J	PARTICIPANT	\N	PRESENT	0
12238	12212	12042Y	PARTICIPANT	\N	PRESENT	0
12239	12212	14281W	PARTICIPANT	\N	PRESENT	0
12240	12212	14087W	PARTICIPANT	\N	PRESENT	0
12759	11657	80027E	PARTICIPANT	\N	PRESENT	0
12242	12212	14034U	PARTICIPANT	\N	PRESENT	0
12243	12212	14231L	PARTICIPANT	\N	PRESENT	0
12760	11657	01059Y	PARTICIPANT	\N	PRESENT	0
12245	12212	08048B	PARTICIPANT	\N	PRESENT	0
12761	11657	11063M	PARTICIPANT	\N	PRESENT	0
12762	11657	14235Q	PARTICIPANT	\N	PRESENT	0
12248	12212	14026U	PARTICIPANT	\N	PRESENT	0
12249	12212	14213J	PARTICIPANT	\N	PRESENT	0
12250	12212	14121F	PARTICIPANT	\N	EXCUSE	0
12251	12212	11112D	PARTICIPANT	\N	PRESENT	0
12763	11657	14263U	PARTICIPANT	\N	PRESENT	0
12253	12212	14018U	PARTICIPANT	\N	PRESENT	0
12254	12212	11067R	PARTICIPANT	\N	PRESENT	0
12255	12212	14223L	PARTICIPANT	\N	PRESENT	0
12256	12212	04092N	PRESIDENT	0	PRESENT	0
12257	12212	14265W	PARTICIPANT	\N	PRESENT	0
12258	12212	14119M	PARTICIPANT	\N	PRESENT	0
12259	12212	14071N	PARTICIPANT	\N	PRESENT	0
12260	12212	07032N	PARTICIPANT	\N	PRESENT	0
12261	12212	04043D	PARTICIPANT	\N	PRESENT	0
12262	12212	14271U	PARTICIPANT	\N	PRESENT	0
12764	11657	08052W	PARTICIPANT	\N	PRESENT	0
12264	12212	11093T	PARTICIPANT	\N	PRESENT	0
12265	12212	11097X	PARTICIPANT	\N	EXCUSE	0
12266	12212	04045F	PARTICIPANT	\N	PRESENT	0
12267	12212	14227Q	PARTICIPANT	\N	PRESENT	0
12268	12212	01034P	PARTICIPANT	\N	PRESENT	0
12765	11657	11061K	PARTICIPANT	\N	PRESENT	0
12766	11657	11067R	PARTICIPANT	\N	PRESENT	0
12271	12212	14269B	PARTICIPANT	\N	PRESENT	0
12767	11657	12042Y	PARTICIPANT	\N	PRESENT	0
12768	11657	11089X	PARTICIPANT	\N	PRESENT	0
12769	11657	11055M	PARTICIPANT	\N	PRESENT	0
12770	11657	14018U	PARTICIPANT	\N	PRESENT	0
12771	11657	14030Q	PARTICIPANT	\N	PRESENT	0
12772	11657	14219Q	PARTICIPANT	\N	PRESENT	0
12773	11657	14089Y	PARTICIPANT	\N	PRESENT	0
12774	11657	11093T	PARTICIPANT	\N	PRESENT	0
12775	11657	14231L	PARTICIPANT	\N	PRESENT	0
12776	11657	14207L	PARTICIPANT	\N	PRESENT	0
12777	11657	01046T	PARTICIPANT	\N	PRESENT	0
12778	11657	14209N	PARTICIPANT	\N	PRESENT	0
12779	11657	14053L	PARTICIPANT	\N	PRESENT	0
12780	11657	11103C	PARTICIPANT	\N	PRESENT	0
12781	11657	14217N	PARTICIPANT	\N	PRESENT	0
12782	11657	14079W	PARTICIPANT	\N	PRESENT	0
12783	11657	14215L	PARTICIPANT	\N	PRESENT	0
12784	11657	14087W	PARTICIPANT	\N	PRESENT	0
12785	11657	08060W	PARTICIPANT	\N	PRESENT	0
12786	11657	14107H	PARTICIPANT	\N	PRESENT	0
12787	11657	11014C	PARTICIPANT	\N	PRESENT	0
12788	11657	04088S	PARTICIPANT	\N	PRESENT	0
12789	11657	14135M	PARTICIPANT	\N	PRESENT	0
12790	11657	14195A	PARTICIPANT	\N	PRESENT	0
12791	11657	14033T	PARTICIPANT	\N	PRESENT	0
12792	11657	14157T	PARTICIPANT	\N	PRESENT	0
12793	11657	14031R	PARTICIPANT	\N	PRESENT	0
12794	11657	11025F	PARTICIPANT	\N	PRESENT	0
12795	11657	14034U	PARTICIPANT	\N	PRESENT	0
12796	11657	14037X	PARTICIPANT	\N	PRESENT	0
12797	11657	14223L	PARTICIPANT	\N	PRESENT	0
12798	11657	11112D	PARTICIPANT	\N	PRESENT	0
12799	11657	11056N	PARTICIPANT	\N	PRESENT	0
12800	11657	04092N	PARTICIPANT	\N	PRESENT	0
12801	11657	14042U	PARTICIPANT	\N	PRESENT	0
12802	11657	10006L	PARTICIPANT	\N	PRESENT	0
12803	11657	14205J	PARTICIPANT	\N	PRESENT	0
12804	11657	11044J	PARTICIPANT	\N	PRESENT	0
12805	11657	08039A	PARTICIPANT	\N	PRESENT	0
12806	11657	08048B	PARTICIPANT	\N	PRESENT	0
12807	11657	14213J	PARTICIPANT	\N	PRESENT	0
12808	11657	14265W	PARTICIPANT	\N	PRESENT	0
12809	11657	14147R	PARTICIPANT	\N	PRESENT	0
12810	11657	14239U	PARTICIPANT	\N	PRESENT	0
12811	11657	14026U	PARTICIPANT	\N	PRESENT	0
12812	11657	11114F	PARTICIPANT	\N	PRESENT	0
12813	11657	08062Y	PARTICIPANT	\N	PRESENT	0
12814	11657	08015R	PARTICIPANT	\N	PRESENT	0
12815	11657	14187A	PARTICIPANT	\N	PRESENT	0
12816	11657	01008M	PARTICIPANT	\N	PRESENT	0
12817	11657	11111C	PARTICIPANT	\N	PRESENT	0
12818	11657	01034P	PARTICIPANT	\N	PRESENT	0
12819	11657	11094U	PARTICIPANT	\N	PRESENT	0
14702	14602	07026Q	PARTICIPANT	\N	PRESENT	0
14708	14602	11025F	PARTICIPANT	\N	PRESENT	0
14721	14602	04066L	PARTICIPANT	\N	PRESENT	0
14722	14602	11114F	PARTICIPANT	\N	PRESENT	0
14723	14602	04085P	PARTICIPANT	\N	PRESENT	0
14724	14602	14261S	PARTICIPANT	\N	PRESENT	0
14741	14603	00003C	PARTICIPANT	\N	PRESENT	0
14742	14603	08052W	PARTICIPANT	\N	PRESENT	0
14781	11963	14042U	PARTICIPANT	0	PRESENT	0
14764	14603	04085P	PARTICIPANT	\N	PRESENT	0
14782	11963	14217N	PARTICIPANT	0	PRESENT	0
14746	14603	11031D	PARTICIPANT	\N	PRESENT	0
14747	14603	01034P	PARTICIPANT	\N	PRESENT	0
14748	14603	04043D	PARTICIPANT	\N	PRESENT	0
14749	14603	04092N	PARTICIPANT	\N	PRESENT	0
14750	14603	14042U	PARTICIPANT	\N	PRESENT	0
14751	14603	10006L	PARTICIPANT	\N	PRESENT	0
14783	11963	14059S	PARTICIPANT	0	PRESENT	0
14753	14603	14269B	PARTICIPANT	\N	PRESENT	0
14784	11963	04043D	PARTICIPANT	0	PRESENT	0
14876	11963	89017R	PARTICIPANT	\N	PRESENT	0
14785	11963	11100Y	PARTICIPANT	0	PRESENT	0
14786	11963	11061K	PARTICIPANT	0	PRESENT	0
14758	14603	07026Q	PARTICIPANT	\N	PRESENT	0
14759	14603	04066L	PARTICIPANT	\N	PRESENT	0
14787	11963	11067R	PARTICIPANT	0	PRESENT	0
14788	11963	14271U	PARTICIPANT	0	PRESENT	0
14762	14603	14261S	PARTICIPANT	\N	PRESENT	0
14763	14603	04067M	PARTICIPANT	\N	PRESENT	0
14789	11963	14195A	PARTICIPANT	0	PRESENT	0
14790	11963	11025F	PARTICIPANT	0	PRESENT	0
14791	11963	12042Y	PARTICIPANT	0	PRESENT	0
14792	11963	14219Q	PARTICIPANT	0	PRESENT	0
14793	11963	11109J	PARTICIPANT	0	PRESENT	0
14794	11963	14107H	PARTICIPANT	0	PRESENT	0
14795	11963	11091R	PARTICIPANT	0	PRESENT	0
14796	11963	10015M	PARTICIPANT	0	PRESENT	0
14797	11963	14071N	PARTICIPANT	0	PRESENT	0
14798	11963	14231L	PARTICIPANT	0	PRESENT	0
14799	11963	14227Q	PARTICIPANT	0	PRESENT	0
14800	11963	14038Y	PARTICIPANT	0	PRESENT	0
14801	11963	11093T	PARTICIPANT	0	PRESENT	0
14802	11963	11072N	PARTICIPANT	0	PRESENT	0
14880	11966	11109J	PARTICIPANT	\N	PRESENT	0
14804	11963	04049K	PARTICIPANT	0	PRESENT	0
14805	11963	14030Q	PARTICIPANT	0	PRESENT	0
14806	11963	08068F	PARTICIPANT	0	PRESENT	0
14807	11963	14089Y	PARTICIPANT	0	PRESENT	0
14808	11963	09001P	PARTICIPANT	0	PRESENT	0
14809	11963	04057K	PARTICIPANT	0	PRESENT	0
14810	11963	04053F	PARTICIPANT	0	PRESENT	0
14811	11963	80013X	PARTICIPANT	0	PRESENT	0
14812	11963	14169X	PARTICIPANT	0	PRESENT	0
14813	11963	14033T	PARTICIPANT	0	PRESENT	0
14814	11963	14257W	PARTICIPANT	0	PRESENT	0
14815	11963	08014Q	PARTICIPANT	0	PRESENT	0
14816	11963	98022P	PARTICIPANT	0	PRESENT	0
14817	11963	01011G	PARTICIPANT	0	PRESENT	0
14818	11963	99004R	PARTICIPANT	0	PRESENT	0
14819	11963	14197C	PARTICIPANT	0	PRESENT	0
14820	11963	14235Q	PARTICIPANT	0	PRESENT	0
14821	11963	14241N	PARTICIPANT	0	PRESENT	0
14822	11963	11014C	PARTICIPANT	0	PRESENT	0
14823	11963	98050T	PARTICIPANT	0	PRESENT	0
14824	11963	14034U	PARTICIPANT	0	PRESENT	0
14825	11963	14209N	PARTICIPANT	0	PRESENT	0
14826	11963	04081K	PARTICIPANT	0	PRESENT	0
14827	11963	11110B	PARTICIPANT	0	PRESENT	0
14683	14602	04092N	PARTICIPANT	\N	PRESENT	0
14684	14602	14042U	PARTICIPANT	\N	PRESENT	0
14685	14602	01046T	PARTICIPANT	\N	PRESENT	0
14686	14602	11055M	PARTICIPANT	\N	PRESENT	0
14687	14602	10006L	PARTICIPANT	\N	PRESENT	0
14688	14602	92045V	PARTICIPANT	\N	PRESENT	0
14689	14602	14213J	PARTICIPANT	\N	PRESENT	0
14690	14602	11072N	PARTICIPANT	\N	PRESENT	0
14691	14602	14269B	PARTICIPANT	\N	PRESENT	0
14692	14602	09001P	PARTICIPANT	\N	PRESENT	0
14693	14602	11109J	PARTICIPANT	\N	PRESENT	0
14694	14602	11011M	PARTICIPANT	\N	PRESENT	0
14695	14602	14041T	PARTICIPANT	\N	PRESENT	0
14696	14602	14209N	PARTICIPANT	\N	PRESENT	0
14697	14602	10015M	PARTICIPANT	\N	PRESENT	0
14698	14602	04053F	PARTICIPANT	\N	PRESENT	0
14828	11963	14083S	PARTICIPANT	0	PRESENT	0
14700	14602	11085T	PARTICIPANT	\N	PRESENT	0
14829	11963	01016M	PARTICIPANT	0	PRESENT	0
14830	11963	14229S	PARTICIPANT	0	PRESENT	0
14831	11963	11054L	PARTICIPANT	0	PRESENT	0
14832	11963	14039A	PARTICIPANT	0	PRESENT	0
14833	11963	04034C	PARTICIPANT	0	PRESENT	0
14834	11963	08017T	PARTICIPANT	0	PRESENT	0
14835	11963	11036J	PARTICIPANT	0	PRESENT	0
14836	11963	01008M	PARTICIPANT	0	PRESENT	0
14837	11963	14103D	PARTICIPANT	0	PRESENT	0
14838	11963	11099A	PARTICIPANT	0	PRESENT	0
14839	11963	01048V	PARTICIPANT	0	PRESENT	0
14840	11963	01007L	PARTICIPANT	0	PRESENT	0
14841	11963	11114F	PARTICIPANT	0	PRESENT	0
14842	11963	14063N	PARTICIPANT	0	PRESENT	0
14843	11963	01059Y	PARTICIPANT	0	PRESENT	0
14844	11963	92045V	PARTICIPANT	0	PRESENT	0
14845	11963	07026Q	PARTICIPANT	0	PRESENT	0
14846	11963	14031R	PARTICIPANT	0	PRESENT	0
14847	11963	14269B	PARTICIPANT	0	PRESENT	0
14848	11963	04088S	PARTICIPANT	0	PRESENT	0
14849	11963	14041T	PARTICIPANT	0	PRESENT	0
14850	11963	14201E	PARTICIPANT	0	PRESENT	0
14851	11963	11012A	PARTICIPANT	0	PRESENT	0
14852	11963	01046T	PARTICIPANT	0	PRESENT	0
14853	11963	87003B	PARTICIPANT	0	PRESENT	0
14854	11963	11112D	PARTICIPANT	0	PRESENT	0
14855	11963	14237S	PARTICIPANT	0	PRESENT	0
14856	11963	14265W	PARTICIPANT	0	PRESENT	0
14857	11963	01022K	PARTICIPANT	0	PRESENT	0
14858	11963	08052W	PARTICIPANT	0	PRESENT	0
14859	11963	04066L	PARTICIPANT	0	PRESENT	0
14860	11963	04045F	PARTICIPANT	0	PRESENT	0
14861	11963	00003C	PARTICIPANT	0	PRESENT	0
14862	11963	11037K	PARTICIPANT	0	PRESENT	0
14863	11963	01015L	PARTICIPANT	0	PRESENT	0
14864	11963	14037X	PARTICIPANT	0	PRESENT	0
14865	11963	11063M	PARTICIPANT	0	PRESENT	0
14866	11963	14105F	PARTICIPANT	0	PRESENT	0
14867	11963	11055M	PARTICIPANT	0	PRESENT	0
14868	11963	07004J	PARTICIPANT	0	PRESENT	0
14869	11963	14053L	PARTICIPANT	0	PRESENT	0
14870	11963	11011M	PARTICIPANT	0	PRESENT	0
14871	11963	14187A	PARTICIPANT	0	PRESENT	0
14872	11963	14211G	PARTICIPANT	0	PRESENT	0
14873	11963	11103C	PARTICIPANT	0	PRESENT	0
14874	11963	04092N	PARTICIPANT	0	PRESENT	0
14875	11963	10006L	PARTICIPANT	0	PRESENT	0
14884	11966	04085P	PARTICIPANT	\N	PRESENT	0
14882	11966	11055M	PARTICIPANT	\N	PRESENT	0
14883	11966	14261S	PARTICIPANT	\N	PRESENT	0
14885	11966	01008M	PARTICIPANT	\N	PRESENT	0
14886	11966	01046T	PARTICIPANT	\N	PRESENT	0
14887	11966	08055A	PARTICIPANT	\N	PRESENT	0
14888	11966	14030Q	PARTICIPANT	\N	PRESENT	0
14889	11966	14089Y	PARTICIPANT	\N	PRESENT	0
14890	11966	14013P	PARTICIPANT	\N	PRESENT	0
14891	11966	04053F	PARTICIPANT	\N	PRESENT	0
14892	11966	14255U	PARTICIPANT	\N	PRESENT	0
14893	11966	00003C	PARTICIPANT	\N	PRESENT	0
14894	11966	14083S	PARTICIPANT	\N	PRESENT	0
14895	11966	11044J	PARTICIPANT	\N	PRESENT	0
14896	11966	14038Y	PARTICIPANT	\N	PRESENT	0
14897	11966	14195A	PARTICIPANT	\N	PRESENT	0
14898	11966	11042G	PARTICIPANT	\N	PRESENT	0
14899	11966	11031D	PARTICIPANT	\N	PRESENT	0
14900	11966	14209N	PARTICIPANT	\N	PRESENT	0
14901	11966	11114F	PARTICIPANT	\N	PRESENT	0
14902	11966	14079W	PARTICIPANT	\N	PRESENT	0
14903	11966	08052W	PARTICIPANT	\N	PRESENT	0
14904	11966	01059Y	PARTICIPANT	\N	PRESENT	0
14905	11966	10006L	PARTICIPANT	\N	PRESENT	0
14906	11966	14041T	PARTICIPANT	\N	PRESENT	0
14907	11966	04067M	PARTICIPANT	\N	PRESENT	0
14908	11966	14042U	PARTICIPANT	\N	PRESENT	0
14909	11966	11089X	PARTICIPANT	\N	PRESENT	0
14910	11966	04095R	PARTICIPANT	\N	PRESENT	0
14911	11966	01011G	PARTICIPANT	\N	PRESENT	0
14912	11966	14179A	PARTICIPANT	\N	PRESENT	0
14913	11966	01022K	PARTICIPANT	\N	PRESENT	0
14914	11966	08069G	PARTICIPANT	\N	PRESENT	0
14703	14701	04053F	PARTICIPANT	\N	PRESENT	0
14704	14701	04066L	PARTICIPANT	\N	PRESENT	0
14705	14701	08052W	PARTICIPANT	\N	PRESENT	0
14706	14701	01059Y	PARTICIPANT	\N	PRESENT	0
14707	14701	10006L	PARTICIPANT	\N	PRESENT	0
14709	14701	14042U	PARTICIPANT	\N	PRESENT	0
14710	14701	14026U	PARTICIPANT	\N	EXCUSE	0
14711	14701	14034U	PARTICIPANT	\N	EXCUSE	0
14712	14701	14213J	PARTICIPANT	\N	PRESENT	0
14713	14701	14121F	PARTICIPANT	\N	EXCUSE	0
14714	14701	04092N	PRESIDENT	0	PRESENT	0
14715	14701	14265W	PARTICIPANT	\N	PRESENT	0
14716	14701	04043D	PARTICIPANT	\N	PRESENT	0
14717	14701	14271U	PARTICIPANT	\N	PRESENT	0
14718	14701	11097X	PARTICIPANT	\N	EXCUSE	0
14719	14701	01034P	PARTICIPANT	\N	PRESENT	0
14720	14701	11025F	PARTICIPANT	\N	PRESENT	0
14915	11966	14213J	PARTICIPANT	\N	PRESENT	0
14916	11966	09001P	PARTICIPANT	\N	PRESENT	0
14917	11966	11099A	PARTICIPANT	\N	PRESENT	0
14918	11966	14037X	PARTICIPANT	\N	PRESENT	0
14919	11966	14219Q	PARTICIPANT	\N	PRESENT	0
14920	11966	01048V	PARTICIPANT	\N	PRESENT	0
14921	11966	14059S	PARTICIPANT	\N	PRESENT	0
14922	11966	14103D	PARTICIPANT	\N	PRESENT	0
14923	11966	14221J	PARTICIPANT	\N	PRESENT	0
14924	11966	11067R	PARTICIPANT	\N	PRESENT	0
14925	11966	04092N	PARTICIPANT	\N	PRESENT	0
14926	11966	11072N	PARTICIPANT	\N	PRESENT	0
14927	11966	14257W	PARTICIPANT	\N	PRESENT	0
14928	11966	14265W	PARTICIPANT	\N	PRESENT	0
14929	11966	14169X	PARTICIPANT	\N	PRESENT	0
14930	11966	14237S	PARTICIPANT	\N	PRESENT	0
14931	11966	04088S	PARTICIPANT	\N	PRESENT	0
14932	11966	98050T	PARTICIPANT	\N	PRESENT	0
14933	11966	04043D	PARTICIPANT	\N	PRESENT	0
14934	11966	10015M	PARTICIPANT	\N	PRESENT	0
14935	11966	11012A	PARTICIPANT	\N	PRESENT	0
14936	11966	14271U	PARTICIPANT	\N	PRESENT	0
14937	11966	11093T	PARTICIPANT	\N	PRESENT	0
14938	11966	11054L	PARTICIPANT	\N	PRESENT	0
14939	11966	04045F	PARTICIPANT	\N	PRESENT	0
14940	11966	14227Q	PARTICIPANT	\N	PRESENT	0
14941	11966	01034P	PARTICIPANT	\N	PRESENT	0
14942	11966	11011M	PARTICIPANT	\N	PRESENT	0
14943	11966	11025F	PARTICIPANT	\N	PRESENT	0
14944	11966	11063M	PARTICIPANT	\N	PRESENT	0
14945	11966	14269B	PARTICIPANT	\N	PRESENT	0
15079	15039	95030B	PARTICIPANT	\N	PRESENT	0
15080	15039	95049N	PARTICIPANT	\N	PRESENT	0
15041	15039	11036J	PARTICIPANT	\N	PRESENT	0
15081	15039	04061F	PARTICIPANT	\N	PRESENT	0
15082	15039	04033B	PARTICIPANT	\N	PRESENT	0
15083	15039	11083R	PARTICIPANT	\N	PRESENT	0
15084	15039	14157T	PARTICIPANT	\N	PRESENT	0
15085	15039	11112D	PARTICIPANT	\N	PRESENT	0
15086	15039	14179A	PARTICIPANT	\N	PRESENT	0
15043	15039	14013P	PARTICIPANT	\N	PRESENT	0
15087	15039	96004D	PARTICIPANT	\N	PRESENT	0
15161	15101	14059S	PARTICIPANT	\N	EXCUSE	0
15044	15039	08068F	PARTICIPANT	\N	PRESENT	0
15164	15163	14261S	PARTICIPANT	\N	EXCUSE	0
15045	15039	14207L	PARTICIPANT	\N	PRESENT	0
15165	15163	14030Q	PARTICIPANT	\N	PRESENT	0
15166	15163	14105F	PARTICIPANT	\N	PRESENT	0
15047	15039	90003B	PARTICIPANT	\N	PRESENT	0
15167	15163	08068F	PARTICIPANT	\N	PRESENT	0
15048	15039	08028W	PARTICIPANT	\N	PRESENT	0
15168	15163	14207L	PARTICIPANT	\N	PRESENT	0
15049	15039	80013X	PARTICIPANT	\N	EXCUSE	0
15169	15163	14255U	PARTICIPANT	\N	PRESENT	0
15170	15163	14083S	PARTICIPANT	\N	PRESENT	0
15171	15163	14079W	PARTICIPANT	\N	PRESENT	0
15172	15163	14039A	PARTICIPANT	\N	PRESENT	0
15173	15163	14061L	PARTICIPANT	\N	PRESENT	0
15174	15163	04049K	PARTICIPANT	\N	PRESENT	0
15175	15163	14265W	PARTICIPANT	\N	PRESENT	0
15176	15163	14253S	PARTICIPANT	\N	PRESENT	0
15177	15163	14157T	PARTICIPANT	\N	PRESENT	0
15051	15039	04089T	PARTICIPANT	\N	PRESENT	0
15052	15039	14197C	PARTICIPANT	\N	EXCUSE	0
15053	15039	11110B	PARTICIPANT	\N	PRESENT	0
15178	15163	14065Q	PARTICIPANT	\N	EXCUSE	0
15055	15039	14033T	PARTICIPANT	\N	PRESENT	0
15056	15039	14081Q	PARTICIPANT	\N	EXCUSE	0
15179	15163	14013P	PARTICIPANT	\N	EXCUSE	0
15058	15039	11099A	PARTICIPANT	\N	EXCUSE	0
15059	15039	04049K	PARTICIPANT	\N	EXCUSE	0
15180	15163	08014Q	PARTICIPANT	\N	EXCUSE	0
15061	15039	11111C	PARTICIPANT	\N	PRESENT	0
15181	15163	04053F	PARTICIPANT	\N	EXCUSE	0
15063	15039	11100Y	PRESIDENT	0	PRESENT	0
15064	15039	01061S	PARTICIPANT	\N	EXCUSE	0
15182	15163	04055H	PARTICIPANT	\N	EXCUSE	0
15066	15039	01043Q	PARTICIPANT	\N	PRESENT	0
15183	15163	11088W	PARTICIPANT	\N	EXCUSE	0
15068	15039	14205J	PARTICIPANT	\N	PRESENT	0
15069	15039	08019V	PARTICIPANT	\N	PRESENT	0
15070	15039	14257W	PARTICIPANT	\N	PRESENT	0
15071	15039	08021P	PARTICIPANT	\N	PRESENT	0
15184	15163	14041T	PARTICIPANT	\N	EXCUSE	0
15073	15039	98050T	PARTICIPANT	\N	PRESENT	0
15074	15039	11090Q	PARTICIPANT	\N	PRESENT	0
15075	15039	11046L	PARTICIPANT	\N	PRESENT	0
15076	15039	01058X	PARTICIPANT	\N	EXCUSE	0
15077	15039	11094U	PARTICIPANT	\N	EXCUSE	0
15078	15039	11066Q	PARTICIPANT	\N	PRESENT	0
15185	15163	04071H	PARTICIPANT	\N	EXCUSE	0
15186	15163	14151M	PARTICIPANT	\N	EXCUSE	0
15190	15188	14263U	PARTICIPANT	\N	EXCUSE	0
15235	14634	11085T	PARTICIPANT	\N	PRESENT	0
15192	15188	11036J	PARTICIPANT	\N	EXCUSE	0
15194	15188	11068S	PARTICIPANT	\N	EXCUSE	0
15195	15188	01044R	PARTICIPANT	\N	EXCUSE	0
15134	15101	08019V	PRESIDENT	0	PRESENT	0
15196	15188	14209N	PARTICIPANT	\N	EXCUSE	0
15197	15188	01046T	PARTICIPANT	\N	EXCUSE	0
15198	15188	11089X	PARTICIPANT	\N	PRESENT	0
15199	15188	11082Q	PARTICIPANT	\N	PRESENT	0
15202	15188	04043D	PARTICIPANT	\N	PRESENT	0
15203	15188	01016M	PARTICIPANT	\N	EXCUSE	0
15204	15188	01058X	PARTICIPANT	\N	PRESENT	0
15206	15188	14221J	PARTICIPANT	\N	EXCUSE	0
15207	15188	83042R	PARTICIPANT	\N	EXCUSE	0
15208	15188	01048V	PARTICIPANT	\N	EXCUSE	0
15209	15188	08039A	PARTICIPANT	\N	EXCUSE	0
15210	15188	04061F	PARTICIPANT	\N	EXCUSE	0
15211	15188	08069G	PARTICIPANT	\N	EXCUSE	0
15212	15188	80013X	PARTICIPANT	\N	EXCUSE	0
15221	14634	08052W	PARTICIPANT	\N	PRESENT	0
15222	14634	11031D	PARTICIPANT	\N	PRESENT	0
15250	14634	10006L	PARTICIPANT	\N	PRESENT	0
15251	14634	14042U	PARTICIPANT	\N	PRESENT	0
15252	14634	11061K	PARTICIPANT	\N	PRESENT	0
15256	14634	11114F	PARTICIPANT	\N	PRESENT	0
15254	14634	14269B	PARTICIPANT	\N	PRESENT	0
15255	14634	11054L	PARTICIPANT	\N	PRESENT	0
15257	14634	04085P	PARTICIPANT	\N	PRESENT	0
15258	14634	01041N	PARTICIPANT	\N	PRESENT	0
15259	14634	80013X	PARTICIPANT	\N	PRESENT	0
15260	14634	11112D	PARTICIPANT	\N	PRESENT	0
15233	14634	11109J	PARTICIPANT	\N	PRESENT	0
15261	14634	04081K	PARTICIPANT	\N	PRESENT	0
15236	14634	11063M	PARTICIPANT	\N	PRESENT	0
15237	14634	11067R	PARTICIPANT	\N	PRESENT	0
15238	14634	11089X	PARTICIPANT	\N	PRESENT	0
15239	14634	14271U	PARTICIPANT	\N	PRESENT	0
15240	14634	01044R	PARTICIPANT	\N	PRESENT	0
15241	14634	11093T	PARTICIPANT	\N	PRESENT	0
15242	14634	01046T	PARTICIPANT	\N	PRESENT	0
15243	14634	14071N	PARTICIPANT	\N	PRESENT	0
15244	14634	04053F	PARTICIPANT	\N	PRESENT	0
15245	14634	14037X	PARTICIPANT	\N	PRESENT	0
15246	14634	14041T	PARTICIPANT	\N	PRESENT	0
15247	14634	04043D	PARTICIPANT	\N	PRESENT	0
15248	14634	14251Q	PARTICIPANT	\N	PRESENT	0
15249	14634	04092N	PARTICIPANT	\N	PRESENT	0
14765	14603	11109J	PARTICIPANT	\N	PRESENT	0
14766	14603	11061K	PARTICIPANT	\N	PRESENT	0
14767	14603	04053F	PARTICIPANT	\N	PRESENT	0
15145	15101	95062K	PARTICIPANT	\N	EXCUSE	0
15262	14634	11103C	PARTICIPANT	\N	PRESENT	0
15303	14646	14041T	PARTICIPANT	\N	PRESENT	0
15304	14646	11012A	PARTICIPANT	\N	PRESENT	0
15305	14646	01027Q	PARTICIPANT	\N	PRESENT	0
15306	14646	01016M	PARTICIPANT	\N	PRESENT	0
15307	14646	11083R	PARTICIPANT	\N	PRESENT	0
15308	14646	08019V	PARTICIPANT	\N	PRESENT	0
15310	14646	01031L	PARTICIPANT	\N	PRESENT	0
15301	14646	04066L	PARTICIPANT	\N	PRESENT	0
15302	14646	11040E	PARTICIPANT	\N	PRESENT	0
15311	14646	11010L	PARTICIPANT	\N	PRESENT	0
15312	14646	08073C	PARTICIPANT	\N	PRESENT	0
15313	14646	98046X	PARTICIPANT	\N	PRESENT	0
15314	14646	04034C	PARTICIPANT	\N	PRESENT	0
15315	14646	11114F	PARTICIPANT	\N	PRESENT	0
15316	14647	04066L	PARTICIPANT	\N	PRESENT	0
15317	14647	11040E	PARTICIPANT	\N	PRESENT	0
15318	14647	14041T	PARTICIPANT	\N	PRESENT	0
15319	14647	11012A	PARTICIPANT	\N	PRESENT	0
15320	14647	01027Q	PARTICIPANT	\N	PRESENT	0
15321	14647	01016M	PARTICIPANT	\N	PRESENT	0
15322	14647	11083R	PARTICIPANT	\N	PRESENT	0
15331	14647	04061F	PARTICIPANT	\N	PRESENT	0
15324	14647	01031L	PARTICIPANT	\N	PRESENT	0
15333	14647	04080J	PARTICIPANT	\N	PRESENT	0
15326	14647	08073C	PARTICIPANT	\N	PRESENT	0
15327	14647	98046X	PARTICIPANT	\N	PRESENT	0
15328	14647	04034C	PARTICIPANT	\N	PRESENT	0
15329	14647	11114F	PARTICIPANT	\N	PRESENT	0
15330	14647	14227Q	PARTICIPANT	\N	PRESENT	0
15332	14647	96004D	PARTICIPANT	\N	PRESENT	0
15334	14647	01041N	PARTICIPANT	\N	PRESENT	0
15339	14647	08052W	PARTICIPANT	\N	PRESENT	0
15340	14647	14271U	PARTICIPANT	\N	PRESENT	0
15341	14647	01046T	PARTICIPANT	\N	PRESENT	0
15342	14647	80013X	PARTICIPANT	\N	PRESENT	0
15343	14647	11031D	PARTICIPANT	\N	PRESENT	0
15344	14647	11067R	PARTICIPANT	\N	PRESENT	0
15345	14647	01057W	PARTICIPANT	\N	PRESENT	0
15346	14647	14042U	PARTICIPANT	\N	PRESENT	0
15347	14647	12042Y	PARTICIPANT	\N	PRESENT	0
15374	14648	12042Y	PARTICIPANT	\N	PRESENT	0
15376	14648	14227Q	PARTICIPANT	\N	PRESENT	0
15377	14648	11031D	PARTICIPANT	\N	PRESENT	0
15378	14648	04092N	PARTICIPANT	\N	PRESENT	0
15379	14648	14042U	PARTICIPANT	\N	PRESENT	0
15380	14648	14071N	PARTICIPANT	\N	PRESENT	0
15381	14648	80013X	PARTICIPANT	\N	PRESENT	0
15384	14648	11112D	PARTICIPANT	\N	PRESENT	0
15386	14648	01059Y	PARTICIPANT	\N	PRESENT	0
15387	14648	11012A	PARTICIPANT	\N	PRESENT	0
15388	14648	01046T	PARTICIPANT	\N	PRESENT	0
15389	14648	14251Q	PARTICIPANT	\N	PRESENT	0
15390	14648	08052W	PARTICIPANT	\N	PRESENT	0
15393	14648	00003C	PARTICIPANT	\N	PRESENT	0
15395	14648	11061K	PARTICIPANT	\N	PRESENT	0
15396	14648	11063M	PARTICIPANT	\N	PRESENT	0
15400	14648	11055M	PARTICIPANT	\N	PRESENT	0
15403	14648	11067R	PARTICIPANT	\N	PRESENT	0
15415	14648	14271U	PARTICIPANT	\N	PRESENT	0
15416	14648	14151M	PARTICIPANT	\N	PRESENT	0
15417	14648	11093T	PARTICIPANT	\N	PRESENT	0
15418	14648	11089X	PARTICIPANT	\N	PRESENT	0
15419	14648	14269B	PARTICIPANT	\N	PRESENT	0
15420	14648	14119M	PARTICIPANT	\N	PRESENT	0
15372	14648	04066L	PARTICIPANT	\N	PRESENT	0
15373	14648	14041T	PARTICIPANT	\N	PRESENT	0
15421	14648	14037X	PARTICIPANT	\N	PRESENT	0
15423	14648	14079W	PARTICIPANT	\N	PRESENT	0
15424	14648	01028R	PARTICIPANT	\N	PRESENT	0
15425	14648	10006L	PARTICIPANT	\N	PRESENT	0
15426	14648	01041N	PARTICIPANT	\N	PRESENT	0
15427	14648	98046X	PARTICIPANT	\N	PRESENT	0
15428	14648	04053F	PARTICIPANT	\N	PRESENT	0
15429	14648	01057W	PARTICIPANT	\N	PRESENT	0
15430	14648	04045F	PARTICIPANT	\N	PRESENT	0
15431	14648	14211G	PARTICIPANT	\N	PRESENT	0
15432	14648	99004R	PARTICIPANT	\N	PRESENT	0
15433	14648	14195A	PARTICIPANT	\N	PRESENT	0
15434	14648	14223L	PARTICIPANT	\N	PRESENT	0
15435	14648	14281W	PARTICIPANT	\N	PRESENT	0
15436	14648	01016M	PARTICIPANT	\N	PRESENT	0
15437	14648	11103C	PARTICIPANT	\N	PRESENT	0
15438	14648	92045V	PARTICIPANT	\N	PRESENT	0
15439	14648	14213J	PARTICIPANT	\N	PRESENT	0
15440	14648	10015M	PARTICIPANT	\N	PRESENT	0
15441	14648	08012N	PARTICIPANT	\N	PRESENT	0
15442	14648	01025N	PARTICIPANT	\N	PRESENT	0
15443	14649	04066L	PARTICIPANT	\N	PRESENT	0
15444	14649	14041T	PARTICIPANT	\N	PRESENT	0
15445	14649	12042Y	PARTICIPANT	\N	PRESENT	0
15446	14649	14227Q	PARTICIPANT	\N	PRESENT	0
15447	14649	11031D	PARTICIPANT	\N	PRESENT	0
15448	14649	04092N	PARTICIPANT	\N	PRESENT	0
15449	14649	14042U	PARTICIPANT	\N	PRESENT	0
15450	14649	14071N	PARTICIPANT	\N	PRESENT	0
15451	14649	11112D	PARTICIPANT	\N	PRESENT	0
15452	14649	01059Y	PARTICIPANT	\N	PRESENT	0
15453	14649	11012A	PARTICIPANT	\N	PRESENT	0
15454	14649	01046T	PARTICIPANT	\N	PRESENT	0
15455	14649	08052W	PARTICIPANT	\N	PRESENT	0
15456	14649	00003C	PARTICIPANT	\N	PRESENT	0
15457	14649	11061K	PARTICIPANT	\N	PRESENT	0
15458	14649	11063M	PARTICIPANT	\N	PRESENT	0
15459	14649	11055M	PARTICIPANT	\N	PRESENT	0
15460	14649	14271U	PARTICIPANT	\N	PRESENT	0
15461	14649	11093T	PARTICIPANT	\N	PRESENT	0
15462	14649	11089X	PARTICIPANT	\N	PRESENT	0
15463	14649	14269B	PARTICIPANT	\N	PRESENT	0
15464	14649	14119M	PARTICIPANT	\N	PRESENT	0
15465	14649	14037X	PARTICIPANT	\N	PRESENT	0
15466	14649	14079W	PARTICIPANT	\N	PRESENT	0
15467	14649	10006L	PARTICIPANT	\N	PRESENT	0
15468	14649	04053F	PARTICIPANT	\N	PRESENT	0
15469	14649	04045F	PARTICIPANT	\N	PRESENT	0
15470	14649	14195A	PARTICIPANT	\N	PRESENT	0
15471	14649	14281W	PARTICIPANT	\N	PRESENT	0
15472	14649	01016M	PARTICIPANT	\N	PRESENT	0
15473	14649	11103C	PARTICIPANT	\N	PRESENT	0
15474	14649	92045V	PARTICIPANT	\N	PRESENT	0
15475	14649	14213J	PARTICIPANT	\N	PRESENT	0
15476	14649	10015M	PARTICIPANT	\N	PRESENT	0
15477	14649	08012N	PARTICIPANT	\N	PRESENT	0
15478	14649	01025N	PARTICIPANT	\N	PRESENT	0
15479	14649	08019V	PARTICIPANT	\N	PRESENT	0
15480	14649	14151M	PARTICIPANT	\N	PRESENT	0
15481	14649	08069G	PARTICIPANT	\N	PRESENT	0
15482	14649	14223L	PARTICIPANT	\N	PRESENT	0
15483	14649	04061F	PARTICIPANT	\N	PRESENT	0
15484	14649	14265W	PARTICIPANT	\N	PRESENT	0
15485	14649	11109J	PARTICIPANT	\N	PRESENT	0
15486	14649	11095V	PARTICIPANT	\N	PRESENT	0
15487	14649	11114F	PARTICIPANT	\N	PRESENT	0
15488	14649	01057W	PARTICIPANT	\N	PRESENT	0
15489	14649	11100Y	PARTICIPANT	\N	PRESENT	0
15490	14649	14237S	PARTICIPANT	\N	PRESENT	0
15491	14649	14255U	PARTICIPANT	\N	PRESENT	0
15492	14649	14111D	PARTICIPANT	\N	PRESENT	0
15502	15501	01046T	PARTICIPANT	\N	PRESENT	0
15503	15501	04053F	PARTICIPANT	\N	PRESENT	0
15504	15501	00003C	PARTICIPANT	\N	PRESENT	0
15505	15501	14053L	PARTICIPANT	\N	PRESENT	0
15506	15501	11103C	PARTICIPANT	\N	PRESENT	0
15507	15501	11044J	PARTICIPANT	\N	PRESENT	0
15508	15501	14195A	PARTICIPANT	\N	PRESENT	0
15509	15501	08052W	PARTICIPANT	\N	PRESENT	0
15510	15501	01059Y	PARTICIPANT	\N	PRESENT	0
15511	15501	10006L	PARTICIPANT	\N	PRESENT	0
15512	15501	14042U	PARTICIPANT	\N	PRESENT	0
15513	15501	14151M	PARTICIPANT	\N	PRESENT	0
15514	15501	12042Y	PARTICIPANT	\N	PRESENT	0
15515	15501	14281W	PARTICIPANT	\N	PRESENT	0
15516	15501	14231L	PARTICIPANT	\N	PRESENT	0
15517	15501	11061K	PARTICIPANT	\N	PRESENT	0
15518	15501	08041T	PARTICIPANT	\N	PRESENT	0
15519	15501	14213J	PARTICIPANT	\N	PRESENT	0
15520	15501	11112D	PARTICIPANT	\N	PRESENT	0
15521	15501	14037X	PARTICIPANT	\N	PRESENT	0
15522	15501	11067R	PARTICIPANT	\N	PRESENT	0
15523	15501	14223L	PARTICIPANT	\N	PRESENT	0
15524	15501	04092N	PRESIDENT	0	PRESENT	0
15525	15501	14265W	PARTICIPANT	\N	PRESENT	0
15526	15501	14119M	PARTICIPANT	\N	PRESENT	0
15527	15501	14071N	PARTICIPANT	\N	PRESENT	0
14467	11964	14281W	PARTICIPANT	\N	PRESENT	0
13980	13978	11055M	PARTICIPANT	\N	PRESENT	0
13981	13978	01046T	PARTICIPANT	\N	PRESENT	0
15146	15101	14201E	PARTICIPANT	\N	EXCUSE	0
15187	15101	96004D	PARTICIPANT	\N	EXCUSE	0
13984	13978	04066L	PARTICIPANT	\N	PRESENT	0
13985	13978	00003C	PARTICIPANT	\N	PRESENT	0
13986	13978	14053L	PARTICIPANT	\N	PRESENT	0
13987	13978	11103C	PARTICIPANT	\N	PRESENT	0
15309	15101	96003C	PARTICIPANT	\N	EXCUSE	0
13989	13978	14195A	PARTICIPANT	\N	PRESENT	0
13993	13978	08052W	PARTICIPANT	\N	PRESENT	0
13994	13978	01059Y	PARTICIPANT	\N	PRESENT	0
15382	15375	04053F	PARTICIPANT	\N	PRESENT	0
13997	13978	10006L	PARTICIPANT	\N	PRESENT	0
15383	15375	00003C	PARTICIPANT	\N	PRESENT	0
13999	13978	14217N	PARTICIPANT	\N	PRESENT	0
14000	13978	14042U	PARTICIPANT	\N	PRESENT	0
15385	15375	11103C	PARTICIPANT	\N	PRESENT	0
14002	13978	12042Y	PARTICIPANT	\N	PRESENT	0
15391	15375	11031D	PARTICIPANT	\N	PRESENT	0
15392	15375	08052W	PARTICIPANT	\N	PRESENT	0
15394	15375	04081K	PARTICIPANT	\N	PRESENT	0
15397	15375	10006L	PARTICIPANT	\N	PRESENT	0
14007	13978	14231L	PARTICIPANT	\N	PRESENT	0
14008	13978	11061K	PARTICIPANT	\N	PRESENT	0
15398	15375	14042U	PARTICIPANT	\N	PRESENT	0
14010	13978	08041T	PARTICIPANT	\N	EXCUSE	0
14011	13978	01011G	PARTICIPANT	\N	PRESENT	0
15399	15375	14151M	PARTICIPANT	\N	PRESENT	0
15401	15375	11061K	PARTICIPANT	\N	PRESENT	0
14014	13978	14121F	PARTICIPANT	\N	EXCUSE	0
14015	13978	11112D	PARTICIPANT	\N	PRESENT	0
14016	13978	14037X	PARTICIPANT	\N	PRESENT	0
15402	15375	08041T	PARTICIPANT	\N	EXCUSE	0
14018	13978	11067R	PARTICIPANT	\N	PRESENT	0
15404	15375	11112D	PARTICIPANT	\N	PRESENT	0
14020	13978	04092N	PRESIDENT	0	PRESENT	0
14021	13978	14265W	PARTICIPANT	\N	PRESENT	0
14022	13978	14119M	PARTICIPANT	\N	PRESENT	0
14023	13978	14071N	PARTICIPANT	\N	PRESENT	0
15405	15375	14037X	PARTICIPANT	\N	PRESENT	0
14025	13978	04043D	PARTICIPANT	\N	PRESENT	0
14026	13978	14271U	PARTICIPANT	\N	PRESENT	0
15406	15375	11067R	PARTICIPANT	\N	PRESENT	0
14028	13978	11093T	PARTICIPANT	\N	PRESENT	0
14029	13978	11097X	PARTICIPANT	\N	EXCUSE	0
14030	13978	04045F	PARTICIPANT	\N	PRESENT	0
15407	15375	04092N	PARTICIPANT	\N	PRESENT	0
15408	15375	14119M	PARTICIPANT	\N	PRESENT	0
14033	13978	11025F	PARTICIPANT	\N	PRESENT	0
15409	15375	14071N	PARTICIPANT	\N	PRESENT	0
15410	15375	14271U	PARTICIPANT	\N	PRESENT	0
15411	15375	11093T	PARTICIPANT	\N	PRESENT	0
15412	15375	11097X	PARTICIPANT	\N	EXCUSE	0
15413	15375	01034P	PARTICIPANT	\N	EXCUSE	0
15414	15375	11063M	PARTICIPANT	\N	PRESENT	0
15528	15501	14271U	PARTICIPANT	\N	PRESENT	0
15529	15501	11093T	PARTICIPANT	\N	PRESENT	0
15530	15501	11097X	PARTICIPANT	\N	EXCUSE	0
15531	15501	01034P	PARTICIPANT	\N	EXCUSE	0
15532	15501	11063M	PARTICIPANT	\N	PRESENT	0
15595	15591	14083S	PARTICIPANT	\N	PRESENT	0
15596	15591	04038G	PARTICIPANT	\N	PRESENT	0
15597	15591	98023Q	PARTICIPANT	\N	PRESENT	0
15600	15591	08022Q	PARTICIPANT	\N	PRESENT	0
15603	15591	01061S	PARTICIPANT	\N	EXCUSE	0
15604	15591	08051V	PARTICIPANT	\N	PRESENT	0
15605	15591	14169X	PARTICIPANT	\N	PRESENT	0
15618	15617	04085P	PARTICIPANT	\N	PRESENT	0
15619	15617	05008E	PRESIDENT	0	PRESENT	0
15620	15617	14069U	PARTICIPANT	\N	PRESENT	0
15621	15617	04047H	PARTICIPANT	\N	PRESENT	0
15622	15617	11056N	PARTICIPANT	\N	EXCUSE	0
15623	15617	14041T	PARTICIPANT	\N	PRESENT	0
15624	15617	01024M	PARTICIPANT	\N	PRESENT	0
15625	15617	08018U	PARTICIPANT	\N	EXCUSE	0
15626	15617	11010L	PARTICIPANT	\N	PRESENT	0
15627	15617	01007L	PARTICIPANT	\N	PRESENT	0
15628	15617	11049P	PARTICIPANT	\N	EXCUSE	0
15629	15617	11026G	PARTICIPANT	\N	PRESENT	0
15630	15617	14111D	PARTICIPANT	\N	PRESENT	0
15631	15617	14273W	PARTICIPANT	\N	EXCUSE	0
15632	15617	14147R	PARTICIPANT	\N	PRESENT	0
15633	15617	08051V	PARTICIPANT	\N	PRESENT	0
15634	15617	07034Q	PARTICIPANT	\N	PRESENT	0
15635	15617	95063L	PARTICIPANT	\N	PRESENT	0
15636	15617	01028R	PARTICIPANT	\N	PRESENT	0
15637	15617	04056J	PARTICIPANT	\N	PRESENT	0
15638	15617	14275Y	PARTICIPANT	\N	PRESENT	0
15639	15617	04044E	PARTICIPANT	\N	EXCUSE	0
15640	15617	11037K	PARTICIPANT	\N	PRESENT	0
15641	15617	95067Q	PARTICIPANT	\N	PRESENT	0
15642	15101	14017T	PARTICIPANT	\N	EXCUSE	0
15688	15266	14267Y	PARTICIPANT	\N	PRESENT	0
15689	15266	14265W	PARTICIPANT	\N	PRESENT	0
15690	15266	14209N	PARTICIPANT	\N	PRESENT	0
15691	15266	08052W	PARTICIPANT	\N	PRESENT	0
15692	15266	14269B	PARTICIPANT	\N	PRESENT	0
15693	15266	14271U	PARTICIPANT	\N	PRESENT	0
15694	15266	14281W	PARTICIPANT	\N	PRESENT	0
15695	15266	14034U	PARTICIPANT	\N	PRESENT	0
15696	15266	04045F	PARTICIPANT	\N	PRESENT	0
15697	15266	12042Y	PARTICIPANT	\N	PRESENT	0
15698	15266	01059Y	PARTICIPANT	\N	PRESENT	0
15699	15266	11031D	PARTICIPANT	\N	PRESENT	0
15700	15266	10006L	PARTICIPANT	\N	PRESENT	0
15701	15266	04092N	PARTICIPANT	\N	PRESENT	0
15702	15266	14042U	PARTICIPANT	\N	PRESENT	0
15703	15266	14217N	PARTICIPANT	\N	PRESENT	0
15704	15266	11093T	PARTICIPANT	\N	PRESENT	0
15705	15266	00003C	PARTICIPANT	\N	PRESENT	0
15706	15266	14195A	PARTICIPANT	\N	PRESENT	0
15707	15266	14041T	PARTICIPANT	\N	PRESENT	0
15708	15266	14105F	PARTICIPANT	\N	PRESENT	0
15709	15266	14033T	PARTICIPANT	\N	PRESENT	0
15710	15266	14026U	PARTICIPANT	\N	PRESENT	0
15711	15266	14087W	PARTICIPANT	\N	PRESENT	0
15712	15266	11061K	PARTICIPANT	\N	PRESENT	0
15713	15266	08051V	PARTICIPANT	\N	PRESENT	0
15714	15266	11067R	PARTICIPANT	\N	PRESENT	0
15715	15266	11114F	PARTICIPANT	\N	PRESENT	0
15716	15266	14135M	PARTICIPANT	\N	PRESENT	0
15717	15266	05012A	PARTICIPANT	\N	PRESENT	0
15718	15266	11103C	PARTICIPANT	\N	PRESENT	0
15719	15266	98024R	PARTICIPANT	\N	PRESENT	0
15720	15266	77002U	PARTICIPANT	\N	PRESENT	0
15724	15266	14213J	PARTICIPANT	\N	PRESENT	0
15722	15266	11100Y	PARTICIPANT	\N	PRESENT	0
15723	15266	14147R	PARTICIPANT	\N	PRESENT	0
15725	15266	11112D	PARTICIPANT	\N	PRESENT	0
15726	15266	08065C	PARTICIPANT	\N	PRESENT	0
15727	15266	14221J	PARTICIPANT	\N	PRESENT	0
15728	15266	11036J	PARTICIPANT	\N	PRESENT	0
15729	15266	11109J	PARTICIPANT	\N	PRESENT	0
15730	15266	14205J	PARTICIPANT	\N	PRESENT	0
15685	15266	08024S	PARTICIPANT	\N	PRESENT	0
15686	15266	14079W	PARTICIPANT	\N	PRESENT	0
15687	15266	14223L	PARTICIPANT	\N	PRESENT	0
15731	15266	14038Y	PARTICIPANT	\N	PRESENT	0
15732	15266	14259Y	PARTICIPANT	\N	PRESENT	0
15733	15266	14255U	PARTICIPANT	\N	PRESENT	0
15734	15266	95015C	PARTICIPANT	\N	PRESENT	0
15735	15266	04053F	PARTICIPANT	\N	PRESENT	0
15736	15266	08022Q	PARTICIPANT	\N	PRESENT	0
15737	15266	11055M	PARTICIPANT	\N	PRESENT	0
15738	15266	11063M	PARTICIPANT	\N	PRESENT	0
15739	15266	08069G	PARTICIPANT	\N	PRESENT	0
15740	15266	11044J	PARTICIPANT	\N	PRESENT	0
15741	15266	14237S	PARTICIPANT	\N	PRESENT	0
15742	15266	14231L	PARTICIPANT	\N	PRESENT	0
13595	13440	00003C	PARTICIPANT	\N	PRESENT	0
13596	13440	11103C	PARTICIPANT	\N	PRESENT	0
13597	13440	14195A	PARTICIPANT	\N	PRESENT	0
13598	13440	11031D	PARTICIPANT	\N	PRESENT	0
13599	13440	08052W	PARTICIPANT	\N	PRESENT	0
13600	13440	01059Y	PARTICIPANT	\N	PRESENT	0
13601	13440	04081K	PARTICIPANT	\N	PRESENT	0
13602	13440	98024R	PARTICIPANT	\N	PRESENT	0
13603	13440	10006L	PARTICIPANT	\N	PRESENT	0
13604	13440	14217N	PARTICIPANT	\N	PRESENT	0
13605	13440	14042U	PARTICIPANT	\N	PRESENT	0
13606	13440	14151M	PARTICIPANT	\N	PRESENT	0
13607	13440	12042Y	PARTICIPANT	\N	PRESENT	0
13608	13440	14281W	PARTICIPANT	\N	PRESENT	0
13612	13440	14213J	PARTICIPANT	\N	PRESENT	0
13610	13440	11061K	PARTICIPANT	\N	PRESENT	0
13611	13440	08041T	PARTICIPANT	\N	EXCUSE	0
13613	13440	14121F	PARTICIPANT	\N	EXCUSE	0
13614	13440	11112D	PARTICIPANT	\N	PRESENT	0
13615	13440	14037X	PARTICIPANT	\N	PRESENT	0
13616	13440	04092N	PRESIDENT	0	PRESENT	0
13617	13440	14265W	PARTICIPANT	\N	PRESENT	0
13618	13440	14119M	PARTICIPANT	\N	PRESENT	0
13619	13440	14071N	PARTICIPANT	\N	PRESENT	0
13621	13440	14271U	PARTICIPANT	\N	PRESENT	0
13622	13440	11097X	PARTICIPANT	\N	EXCUSE	0
13623	13440	04045F	PARTICIPANT	\N	PRESENT	0
13624	13440	11025F	PARTICIPANT	\N	PRESENT	0
13625	13440	14269B	PARTICIPANT	\N	PRESENT	0
13626	13440	11044J	PARTICIPANT	\N	PRESENT	0
14652	14651	00003C	PARTICIPANT	\N	PRESENT	0
14653	14651	08052W	PARTICIPANT	\N	PRESENT	0
14654	14651	10006L	PARTICIPANT	\N	PRESENT	0
14655	14651	14042U	PARTICIPANT	\N	PRESENT	0
14656	14651	11061K	PARTICIPANT	\N	PRESENT	0
14657	14651	14213J	PARTICIPANT	\N	PRESENT	0
14658	14651	14121F	PARTICIPANT	\N	EXCUSE	0
14659	14651	04092N	PRESIDENT	0	PRESENT	0
14660	14651	14265W	PARTICIPANT	\N	PRESENT	0
14661	14651	04043D	PARTICIPANT	\N	PRESENT	0
14662	14651	14271U	PARTICIPANT	\N	PRESENT	0
14663	14651	11097X	PARTICIPANT	\N	EXCUSE	0
14664	14651	01034P	PARTICIPANT	\N	PRESENT	0
14665	14651	11025F	PARTICIPANT	\N	PRESENT	0
14666	14651	11063M	PARTICIPANT	\N	PRESENT	0
15422	15101	14093U	PARTICIPANT	\N	EXCUSE	0
15534	15533	04070G	PRESIDENT	0	PRESENT	0
15535	15533	14263U	PARTICIPANT	\N	PRESENT	0
15613	15533	14209N	PARTICIPANT	\N	PRESENT	0
15537	15533	11109J	PARTICIPANT	\N	PRESENT	0
15538	15533	04059M	PARTICIPANT	\N	PRESENT	0
15614	15533	14249W	PARTICIPANT	\N	EXCUSE	0
15615	15533	01044R	PARTICIPANT	\N	PRESENT	0
15541	15533	08043V	PARTICIPANT	\N	EXCUSE	0
15616	15533	11091R	PARTICIPANT	\N	PRESENT	0
15543	15533	14105F	PARTICIPANT	\N	PRESENT	0
15544	15533	11029K	PARTICIPANT	\N	PRESENT	0
15545	15533	95015C	PARTICIPANT	\N	PRESENT	0
15546	15533	92015P	PARTICIPANT	\N	EXCUSE	0
15547	15533	08024S	PARTICIPANT	\N	PRESENT	0
15743	15266	08015R	PARTICIPANT	\N	PRESENT	0
15744	15266	14219Q	PARTICIPANT	\N	PRESENT	0
15550	15533	14079W	PARTICIPANT	\N	PRESENT	0
15745	15266	08041T	PARTICIPANT	\N	PRESENT	0
15746	15266	11091R	PARTICIPANT	\N	PRESENT	0
15747	15266	92045V	PARTICIPANT	\N	PRESENT	0
15748	15266	14159V	PARTICIPANT	\N	PRESENT	0
15555	15533	01041N	PARTICIPANT	\N	PRESENT	0
15556	15533	01025N	PARTICIPANT	\N	PRESENT	0
15749	15266	14071N	PARTICIPANT	\N	PRESENT	0
15750	15266	14227Q	PARTICIPANT	\N	PRESENT	0
15559	15533	08035V	PARTICIPANT	\N	PRESENT	0
15560	15533	11089X	PARTICIPANT	\N	PRESENT	0
15561	15533	07026Q	PARTICIPANT	\N	PRESENT	0
15562	15533	14123H	PARTICIPANT	\N	PRESENT	0
15751	15266	01046T	PARTICIPANT	\N	PRESENT	0
15752	15266	14111D	PARTICIPANT	\N	PRESENT	0
15565	15533	14241N	PARTICIPANT	\N	PRESENT	0
15566	15533	14061L	PARTICIPANT	\N	PRESENT	0
15567	15533	14073Q	PARTICIPANT	\N	PRESENT	0
15753	15266	08053X	PARTICIPANT	\N	PRESENT	0
15754	15266	98050T	PARTICIPANT	\N	PRESENT	0
15570	15533	08039A	PARTICIPANT	\N	PRESENT	0
15571	15533	08017T	PARTICIPANT	\N	PRESENT	0
15755	15266	14275Y	PARTICIPANT	\N	PRESENT	0
15573	15533	08012N	PARTICIPANT	\N	PRESENT	0
15756	15266	14109K	PARTICIPANT	\N	PRESENT	0
15575	15533	11104D	PARTICIPANT	\N	PRESENT	0
15757	15266	14253S	PARTICIPANT	\N	PRESENT	0
15577	15533	04057K	PARTICIPANT	\N	PRESENT	0
15578	15533	11014C	PARTICIPANT	\N	PRESENT	0
15579	15533	14109K	PARTICIPANT	\N	PRESENT	0
15758	15266	01022K	PARTICIPANT	\N	PRESENT	0
15759	15266	80013X	PARTICIPANT	\N	PRESENT	0
15761	15760	04053F	PARTICIPANT	\N	PRESENT	0
15583	15533	14235Q	PARTICIPANT	\N	EXCUSE	0
15762	15760	14255U	PARTICIPANT	\N	PRESENT	0
15585	15533	04033B	PARTICIPANT	\N	PRESENT	0
15763	15760	04066L	PARTICIPANT	\N	PRESENT	0
15587	15533	11043H	PARTICIPANT	\N	PRESENT	0
15764	15760	00003C	PARTICIPANT	\N	PRESENT	0
15589	15533	92045V	PARTICIPANT	\N	PRESENT	0
15765	15760	14053L	PARTICIPANT	\N	PRESENT	0
15766	15760	11103C	PARTICIPANT	\N	PRESENT	0
15767	15760	14195A	PARTICIPANT	\N	PRESENT	0
15768	15266	14107H	PARTICIPANT	\N	PRESENT	0
15769	15760	14267Y	PARTICIPANT	\N	PRESENT	0
15770	15760	08052W	PARTICIPANT	\N	PRESENT	0
15771	15760	98024R	PARTICIPANT	\N	PRESENT	0
15772	15760	10006L	PARTICIPANT	\N	PRESENT	0
15773	15760	14217N	PARTICIPANT	\N	PRESENT	0
15774	15760	14042U	PARTICIPANT	\N	PRESENT	0
15775	15760	12042Y	PARTICIPANT	\N	PRESENT	0
15776	15760	14281W	PARTICIPANT	\N	PRESENT	0
15777	15760	14034U	PARTICIPANT	\N	PRESENT	0
15778	15760	14231L	PARTICIPANT	\N	PRESENT	0
15779	15760	11061K	PARTICIPANT	\N	PRESENT	0
15780	15760	08041T	PARTICIPANT	\N	PRESENT	0
15781	15760	14026U	PARTICIPANT	\N	PRESENT	0
15782	15760	14213J	PARTICIPANT	\N	PRESENT	0
15783	15760	11067R	PARTICIPANT	\N	PRESENT	0
15784	15760	14223L	PARTICIPANT	\N	PRESENT	0
15785	15760	04092N	PRESIDENT	0	PRESENT	0
15786	15266	14187A	PARTICIPANT	\N	PRESENT	0
15787	15760	14265W	PARTICIPANT	\N	PRESENT	0
15788	15760	14119M	PARTICIPANT	\N	PRESENT	0
15789	15266	14215L	PARTICIPANT	\N	PRESENT	0
15790	15760	07032N	PARTICIPANT	\N	PRESENT	0
15791	15760	04043D	PARTICIPANT	\N	PRESENT	0
15792	15760	14271U	PARTICIPANT	\N	PRESENT	0
15793	15266	08062Y	PARTICIPANT	\N	PRESENT	0
15794	15760	04045F	PARTICIPANT	\N	PRESENT	0
15795	15760	11097X	PARTICIPANT	\N	EXCUSE	0
15796	15760	01034P	PARTICIPANT	\N	EXCUSE	0
15797	15760	14269B	PARTICIPANT	\N	PRESENT	0
15798	15266	14263U	PARTICIPANT	\N	PRESENT	0
15799	15266	08012N	PARTICIPANT	\N	PRESENT	0
15800	15266	14097Y	PARTICIPANT	\N	PRESENT	0
15801	15266	11101A	PARTICIPANT	\N	PRESENT	0
15802	15266	11095V	PARTICIPANT	\N	PRESENT	0
15803	15266	14151M	PARTICIPANT	\N	PRESENT	0
15804	15266	14229S	PARTICIPANT	\N	PRESENT	0
15805	15266	04097T	PARTICIPANT	\N	PRESENT	0
15806	15266	14207L	PARTICIPANT	\N	PRESENT	0
15807	15266	14053L	PARTICIPANT	\N	PRESENT	0
15808	15266	14013P	PARTICIPANT	\N	PRESENT	0
15809	15266	11059R	PARTICIPANT	\N	PRESENT	0
15812	15810	01031L	PRESIDENT	0	PRESENT	0
15814	15810	01013J	PARTICIPANT	\N	EXCUSE	0
15819	15810	14175V	PARTICIPANT	\N	PRESENT	0
15820	15810	14083S	PARTICIPANT	\N	PRESENT	0
15821	15810	11053K	PARTICIPANT	\N	PRESENT	0
15823	15810	11042G	PARTICIPANT	\N	PRESENT	0
15826	15810	04055H	PARTICIPANT	\N	EXCUSE	0
15829	15810	14327T	PARTICIPANT	\N	PRESENT	0
15830	15810	08022Q	PARTICIPANT	\N	PRESENT	0
15831	15810	01027Q	PARTICIPANT	\N	PRESENT	0
14962	14961	04054G	PARTICIPANT	\N	EXCUSE	0
14963	14961	04040A	PARTICIPANT	\N	PRESENT	0
14964	14961	08058D	PARTICIPANT	\N	PRESENT	0
14965	14961	04042C	PARTICIPANT	\N	PRESENT	0
14966	14961	77002U	PARTICIPANT	\N	PRESENT	0
14967	14961	98018T	PARTICIPANT	\N	PRESENT	0
14968	14961	92018S	PARTICIPANT	\N	PRESENT	0
14969	14961	92020L	PARTICIPANT	\N	PRESENT	0
14970	14961	97011G	PARTICIPANT	\N	PRESENT	0
14971	14961	07024N	PARTICIPANT	\N	EXCUSE	0
14972	14961	14014Q	PARTICIPANT	\N	PRESENT	0
14973	14961	11015D	PARTICIPANT	\N	PRESENT	0
14974	14961	07004J	PARTICIPANT	\N	EXCUSE	0
14975	14961	95035G	PARTICIPANT	\N	EXCUSE	0
14976	14961	14211G	PARTICIPANT	\N	PRESENT	0
14977	14961	11064N	PARTICIPANT	\N	PRESENT	0
14978	14961	14097Y	PARTICIPANT	\N	EXCUSE	0
14979	14961	95041E	PARTICIPANT	\N	PRESENT	0
14980	14961	04036E	PARTICIPANT	\N	PRESENT	0
14981	14961	92031P	PARTICIPANT	\N	PRESENT	0
14982	14961	11106F	PARTICIPANT	\N	PRESENT	0
14983	14961	14251Q	PARTICIPANT	\N	PRESENT	0
14984	14961	83042R	PARTICIPANT	\N	PRESENT	0
14985	14961	08053X	PARTICIPANT	\N	PRESENT	0
14986	14961	11082Q	PARTICIPANT	\N	EXCUSE	0
14987	14961	11105E	PARTICIPANT	\N	PRESENT	0
14988	14961	14253S	PARTICIPANT	\N	PRESENT	0
14989	14961	08047A	PARTICIPANT	\N	EXCUSE	0
14990	14961	14028W	PARTICIPANT	\N	EXCUSE	0
14991	14961	14193X	PARTICIPANT	\N	EXCUSE	0
14992	14961	98021N	PARTICIPANT	\N	PRESENT	0
14993	14961	95059Q	PRESIDENT	0	PRESENT	0
14994	14961	86044G	PARTICIPANT	\N	EXCUSE	0
14995	14961	01014K	PARTICIPANT	\N	PRESENT	0
14996	14961	11054L	PARTICIPANT	\N	EXCUSE	0
14997	14961	92044U	PARTICIPANT	\N	PRESENT	0
14998	14961	08049C	PARTICIPANT	\N	EXCUSE	0
15263	14634	04035D	PARTICIPANT	\N	PRESENT	0
15264	14634	01059Y	PARTICIPANT	\N	PRESENT	0
15265	14634	04066L	PARTICIPANT	\N	PRESENT	0
14549	11971	08055A	PARTICIPANT	\N	PRESENT	0
14550	11971	11031D	PARTICIPANT	\N	PRESENT	0
14551	11971	01059Y	PARTICIPANT	\N	PRESENT	0
14552	11971	11109J	PARTICIPANT	\N	PRESENT	0
14553	11971	11055M	PARTICIPANT	\N	PRESENT	0
14554	11971	14209N	PARTICIPANT	\N	PRESENT	0
14555	11971	14255U	PARTICIPANT	\N	PRESENT	0
14556	11971	14037X	PARTICIPANT	\N	PRESENT	0
14557	11971	11072N	PARTICIPANT	\N	PRESENT	0
14558	11971	14261S	PARTICIPANT	\N	PRESENT	0
13927	13925	01031L	PRESIDENT	0	PRESENT	0
14559	11971	08052W	PARTICIPANT	\N	PRESENT	0
13929	13925	01013J	PARTICIPANT	\N	EXCUSE	0
13930	13925	11068S	PARTICIPANT	\N	EXCUSE	0
14560	11971	14269B	PARTICIPANT	\N	PRESENT	0
13932	13925	08014Q	PARTICIPANT	\N	PRESENT	0
14561	11971	11061K	PARTICIPANT	\N	PRESENT	0
13934	13925	14175V	PARTICIPANT	\N	PRESENT	0
14037	13925	11057P	PARTICIPANT	\N	EXCUSE	0
14562	11971	01034P	PARTICIPANT	\N	PRESENT	0
13937	13925	14085U	PARTICIPANT	\N	EXCUSE	0
13938	13925	11042G	PARTICIPANT	\N	PRESENT	0
14563	11971	04092N	PARTICIPANT	\N	PRESENT	0
13940	13925	04086Q	PARTICIPANT	\N	PRESENT	0
13941	13925	04055H	PARTICIPANT	\N	PRESENT	0
14564	11971	10006L	PARTICIPANT	\N	PRESENT	0
13943	13925	11088W	PARTICIPANT	\N	PRESENT	0
13944	13925	14327T	PARTICIPANT	\N	PRESENT	0
14565	11971	14042U	PARTICIPANT	\N	PRESENT	0
13946	13925	01027Q	PARTICIPANT	\N	EXCUSE	0
14566	11971	14213J	PARTICIPANT	\N	PRESENT	0
13948	13925	11074Q	PARTICIPANT	\N	PRESENT	0
14567	11971	14265W	PARTICIPANT	\N	PRESENT	0
13950	13925	11083R	PARTICIPANT	\N	EXCUSE	0
14568	11971	04045F	PARTICIPANT	\N	PRESENT	0
13952	13925	01057W	PARTICIPANT	\N	PRESENT	0
14569	11971	14271U	PARTICIPANT	\N	PRESENT	0
13954	13925	08069G	PARTICIPANT	\N	PRESENT	0
13955	13925	11048N	PARTICIPANT	\N	PRESENT	0
13956	13925	99004R	PARTICIPANT	\N	PRESENT	0
14570	11971	11063M	PARTICIPANT	\N	PRESENT	0
13958	13925	14159V	PARTICIPANT	\N	PRESENT	0
14571	11971	04043D	PARTICIPANT	\N	PRESENT	0
14572	11971	00003C	PARTICIPANT	\N	PRESENT	0
14573	11971	11114F	PARTICIPANT	\N	PRESENT	0
14575	11971	10015M	PARTICIPANT	\N	PRESENT	0
14576	11971	01046T	PARTICIPANT	\N	PRESENT	0
13964	13925	98046X	PARTICIPANT	\N	PRESENT	0
13965	13925	11085T	PARTICIPANT	\N	PRESENT	0
13966	13925	08011M	PARTICIPANT	\N	PRESENT	0
14591	11971	11025F	PARTICIPANT	\N	PRESENT	0
13968	13925	08061X	PARTICIPANT	\N	EXCUSE	0
13969	13925	01016M	PARTICIPANT	\N	PRESENT	0
14592	11971	14089Y	PARTICIPANT	\N	PRESENT	0
14128	11964	86034E	PARTICIPANT	\N	PRESENT	0
14129	11964	14097Y	PARTICIPANT	\N	PRESENT	0
13973	13925	14173T	PARTICIPANT	\N	PRESENT	0
13974	13925	04034C	PARTICIPANT	\N	PRESENT	0
14130	11964	14159V	PARTICIPANT	\N	PRESENT	0
14131	11964	14089Y	PARTICIPANT	\N	PRESENT	0
14132	11964	14055N	PARTICIPANT	\N	PRESENT	0
14133	11964	07034Q	PARTICIPANT	\N	PRESENT	0
14134	11964	14209N	PARTICIPANT	\N	PRESENT	0
14135	11964	14041T	PARTICIPANT	\N	PRESENT	0
14136	11964	08049C	PARTICIPANT	\N	PRESENT	0
14137	11964	14327T	PARTICIPANT	\N	PRESENT	0
14138	11964	04088S	PARTICIPANT	\N	PRESENT	0
14139	11964	14235Q	PARTICIPANT	\N	PRESENT	0
14140	11964	11063M	PARTICIPANT	\N	PRESENT	0
14141	11964	07026Q	PARTICIPANT	\N	PRESENT	0
14142	11964	14227Q	PARTICIPANT	\N	PRESENT	0
14143	11964	08062Y	PARTICIPANT	\N	PRESENT	0
14144	11964	80013X	PARTICIPANT	\N	PRESENT	0
14145	11964	14063N	PARTICIPANT	\N	PRESENT	0
14146	11964	11054L	PARTICIPANT	\N	PRESENT	0
14147	11964	98050T	PARTICIPANT	\N	PRESENT	0
14148	11964	14030Q	PARTICIPANT	\N	PRESENT	0
14149	11964	11012A	PARTICIPANT	\N	PRESENT	0
14150	11964	08022Q	PARTICIPANT	\N	PRESENT	0
14151	11964	14187A	PARTICIPANT	\N	PRESENT	0
14152	11964	14103D	PARTICIPANT	\N	PRESENT	0
14153	11964	01016M	PARTICIPANT	\N	PRESENT	0
14154	11964	14201E	PARTICIPANT	\N	PRESENT	0
14155	11964	14179A	PARTICIPANT	\N	PRESENT	0
14156	11964	14079W	PARTICIPANT	\N	PRESENT	0
14157	11964	11037K	PARTICIPANT	\N	PRESENT	0
14158	11964	14229S	PARTICIPANT	\N	PRESENT	0
14159	11964	11072N	PARTICIPANT	\N	PRESENT	0
14160	11964	04033B	PARTICIPANT	\N	PRESENT	0
14161	11964	04045F	PARTICIPANT	\N	PRESENT	0
14162	11964	11025F	PARTICIPANT	\N	PRESENT	0
14163	11964	00003C	PARTICIPANT	\N	PRESENT	0
14164	11964	14107H	PARTICIPANT	\N	PRESENT	0
14165	11964	08055A	PARTICIPANT	\N	PRESENT	0
14166	11964	08052W	PARTICIPANT	\N	PRESENT	0
14167	11964	08014Q	PARTICIPANT	\N	PRESENT	0
14168	11964	11089X	PARTICIPANT	\N	PRESENT	0
14169	11964	01046T	PARTICIPANT	\N	PRESENT	0
14170	11964	14241N	PARTICIPANT	\N	PRESENT	0
14171	11964	11032E	PARTICIPANT	\N	PRESENT	0
14172	11964	11067R	PARTICIPANT	\N	PRESENT	0
14173	11964	04034C	PARTICIPANT	\N	PRESENT	0
14174	11964	11014C	PARTICIPANT	\N	PRESENT	0
13586	11720	11044J	PARTICIPANT	\N	PRESENT	0
13587	11720	98022P	PARTICIPANT	\N	PRESENT	0
13588	11720	01011G	PARTICIPANT	\N	PRESENT	0
13520	11720	14259Y	PARTICIPANT	\N	PRESENT	0
13589	11720	92031P	PARTICIPANT	\N	PRESENT	0
13522	11720	04085P	PARTICIPANT	\N	PRESENT	0
13590	11720	14241N	PARTICIPANT	\N	PRESENT	0
13591	11720	14255U	PARTICIPANT	\N	PRESENT	0
13525	11720	14151M	PARTICIPANT	\N	PRESENT	0
13526	11720	86034E	PARTICIPANT	\N	PRESENT	0
13527	11720	14327T	PARTICIPANT	\N	PRESENT	0
13528	11720	14107H	PARTICIPANT	\N	PRESENT	0
13529	11720	99004R	PARTICIPANT	\N	PRESENT	0
13530	11720	14053L	PARTICIPANT	\N	PRESENT	0
13531	11720	08016S	PARTICIPANT	\N	PRESENT	0
13532	11720	11072N	PARTICIPANT	\N	PRESENT	0
13533	11720	11067R	PARTICIPANT	\N	PRESENT	0
13534	11720	14103D	PARTICIPANT	\N	PRESENT	0
13535	11720	08049C	PARTICIPANT	\N	PRESENT	0
13536	11720	04053F	PARTICIPANT	\N	PRESENT	0
13537	11720	11098Y	PARTICIPANT	\N	PRESENT	0
13538	11720	11056N	PARTICIPANT	\N	PRESENT	0
13539	11720	92018S	PARTICIPANT	\N	PRESENT	0
13540	11720	07026Q	PARTICIPANT	\N	PRESENT	0
13541	11720	04056J	PARTICIPANT	\N	PRESENT	0
13542	11720	08031R	PARTICIPANT	\N	PRESENT	0
13543	11720	14207L	PARTICIPANT	\N	PRESENT	0
13544	11720	04034C	PARTICIPANT	\N	PRESENT	0
13545	11720	14197C	PARTICIPANT	\N	PRESENT	0
13546	11720	95063L	PARTICIPANT	\N	PRESENT	0
13547	11720	14028W	PARTICIPANT	\N	PRESENT	0
13548	11720	14219Q	PARTICIPANT	\N	PRESENT	0
13549	11720	04078Q	PARTICIPANT	\N	PRESENT	0
13550	11720	04038G	PARTICIPANT	\N	PRESENT	0
13551	11720	08051V	PARTICIPANT	\N	PRESENT	0
13552	11720	01043Q	PARTICIPANT	\N	PRESENT	0
13553	11720	89017R	PARTICIPANT	\N	PRESENT	0
13554	11720	14069U	PARTICIPANT	\N	PRESENT	0
13555	11720	14059S	PARTICIPANT	\N	PRESENT	0
13556	11720	11080N	PARTICIPANT	\N	PRESENT	0
13557	11720	98018T	PARTICIPANT	\N	PRESENT	0
13558	11720	08022Q	PARTICIPANT	\N	PRESENT	0
13559	11720	04047H	PARTICIPANT	\N	PRESENT	0
13560	11720	05008E	PARTICIPANT	\N	PRESENT	0
13561	11720	04035D	PARTICIPANT	\N	PRESENT	0
13562	11720	01031L	PARTICIPANT	\N	PRESENT	0
13563	11720	98046X	PARTICIPANT	\N	PRESENT	0
13564	11720	11042G	PARTICIPANT	\N	PRESENT	0
13565	11720	14257W	PARTICIPANT	\N	PRESENT	0
13566	11720	11033F	PARTICIPANT	\N	PRESENT	0
13567	11720	01058X	PARTICIPANT	\N	PRESENT	0
13568	11720	04033B	PARTICIPANT	\N	PRESENT	0
13569	11720	10015M	PARTICIPANT	\N	PRESENT	0
13570	11720	11100Y	PARTICIPANT	\N	PRESENT	0
13571	11720	08062Y	PARTICIPANT	\N	PRESENT	0
13572	11720	04097T	PARTICIPANT	\N	PRESENT	0
13573	11720	11060J	PARTICIPANT	\N	PRESENT	0
13574	11720	11114F	PARTICIPANT	\N	PRESENT	0
13575	11720	11071M	PARTICIPANT	\N	PRESENT	0
13576	11720	11026G	PARTICIPANT	\N	PRESENT	0
13577	11720	14199E	PARTICIPANT	\N	PRESENT	0
13578	11720	04049K	PARTICIPANT	\N	PRESENT	0
13579	11720	14030Q	PARTICIPANT	\N	PRESENT	0
13580	11720	14271U	PARTICIPANT	\N	PRESENT	0
13581	11720	14209N	PARTICIPANT	\N	PRESENT	0
13582	11720	14034U	PARTICIPANT	\N	PRESENT	0
13583	11720	14061L	PARTICIPANT	\N	PRESENT	0
13584	11720	11110B	PARTICIPANT	\N	PRESENT	0
13585	11720	11025F	PARTICIPANT	\N	PRESENT	0
13592	11720	11093T	PARTICIPANT	\N	PRESENT	0
13593	11720	11103C	PARTICIPANT	\N	PRESENT	0
13594	11720	11048N	PARTICIPANT	\N	PRESENT	0
13620	11720	01046T	PARTICIPANT	\N	PRESENT	0
13627	11720	14179A	PARTICIPANT	\N	PRESENT	0
13628	11720	01008M	PARTICIPANT	\N	PRESENT	0
13629	11720	14037X	PARTICIPANT	\N	PRESENT	0
13630	11720	98024R	PARTICIPANT	\N	PRESENT	0
13631	11720	11012A	PARTICIPANT	\N	PRESENT	0
13632	11720	01048V	PARTICIPANT	\N	PRESENT	0
13633	11720	11061K	PARTICIPANT	\N	PRESENT	0
13634	11720	04081K	PARTICIPANT	\N	PRESENT	0
13635	11720	14042U	PARTICIPANT	\N	PRESENT	0
13636	11720	04067M	PARTICIPANT	\N	PRESENT	0
13637	11720	08069G	PARTICIPANT	\N	PRESENT	0
13638	11720	10006L	PARTICIPANT	\N	PRESENT	0
13639	11720	11031D	PARTICIPANT	\N	PRESENT	0
13640	11720	11085T	PARTICIPANT	\N	PRESENT	0
13641	11720	14083S	PARTICIPANT	\N	PRESENT	0
13642	11720	95041E	PARTICIPANT	\N	PRESENT	0
13780	11721	11048N	PARTICIPANT	\N	PRESENT	0
13644	11721	00003C	PARTICIPANT	\N	PRESENT	0
13781	11721	14265W	PARTICIPANT	\N	PRESENT	0
13782	11721	14213J	PARTICIPANT	\N	PRESENT	0
13647	11721	11109J	PARTICIPANT	\N	PRESENT	0
13783	11721	04095R	PARTICIPANT	\N	PRESENT	0
13784	11721	14033T	PARTICIPANT	\N	PRESENT	0
13785	11721	11044J	PARTICIPANT	\N	PRESENT	0
13651	11721	14053L	PARTICIPANT	\N	PRESENT	0
13786	11721	14205J	PARTICIPANT	\N	PRESENT	0
13787	11721	08031R	PARTICIPANT	\N	PRESENT	0
13788	11721	14281W	PARTICIPANT	\N	PRESENT	0
13655	11721	11072N	PARTICIPANT	\N	PRESENT	0
13789	11721	14119M	PARTICIPANT	\N	PRESENT	0
13657	11721	11067R	PARTICIPANT	\N	PRESENT	0
13790	11721	01016M	PARTICIPANT	\N	PRESENT	0
13791	11721	14135M	PARTICIPANT	\N	PRESENT	0
14177	11964	14255U	PARTICIPANT	\N	PRESENT	0
14178	11964	14237S	PARTICIPANT	\N	PRESENT	0
14179	11964	11036J	PARTICIPANT	\N	PRESENT	0
14180	11964	14207L	PARTICIPANT	\N	PRESENT	0
14181	11964	14109K	PARTICIPANT	\N	PRESENT	0
14182	11964	11099A	PARTICIPANT	\N	PRESENT	0
13666	11721	11063M	PARTICIPANT	\N	PRESENT	0
13667	11721	14235Q	PARTICIPANT	\N	PRESENT	0
14183	11964	08068F	PARTICIPANT	\N	PRESENT	0
14184	11964	14039A	PARTICIPANT	\N	PRESENT	0
13670	11721	11113E	PARTICIPANT	\N	PRESENT	0
13671	11721	14151M	PARTICIPANT	\N	PRESENT	0
14185	11964	14211G	PARTICIPANT	\N	PRESENT	0
14186	11964	04095R	PARTICIPANT	\N	PRESENT	0
14187	11964	11114F	PARTICIPANT	\N	PRESENT	0
13675	11721	14197C	PARTICIPANT	\N	PRESENT	0
13676	11721	01059Y	PARTICIPANT	\N	PRESENT	0
14188	11964	11080N	PARTICIPANT	\N	PRESENT	0
14189	11964	11084S	PARTICIPANT	\N	PRESENT	0
13679	11721	04045F	PARTICIPANT	\N	PRESENT	0
14190	11964	11074Q	PARTICIPANT	\N	PRESENT	0
14191	11964	14013P	PARTICIPANT	\N	PRESENT	0
14192	11964	11034G	PARTICIPANT	\N	PRESENT	0
14193	11964	87003B	PARTICIPANT	\N	PRESENT	0
14194	11964	01015L	PARTICIPANT	\N	PRESENT	0
14195	11964	11056N	PARTICIPANT	\N	PRESENT	0
14196	11964	14105F	PARTICIPANT	\N	PRESENT	0
13687	11721	14261S	PARTICIPANT	\N	PRESENT	0
14197	11964	92018S	PARTICIPANT	\N	PRESENT	0
14198	11964	11015D	PARTICIPANT	\N	PRESENT	0
14199	11964	10015M	PARTICIPANT	\N	PRESENT	0
13691	11721	01043Q	PARTICIPANT	\N	PRESENT	0
13692	11721	12042Y	PARTICIPANT	\N	PRESENT	0
14200	11964	04042C	PARTICIPANT	\N	PRESENT	0
14201	11964	14271U	PARTICIPANT	\N	PRESENT	0
13695	11721	14231L	PARTICIPANT	\N	PRESENT	0
14202	11964	04066L	PARTICIPANT	\N	PRESENT	0
14175	11964	11029K	PARTICIPANT	\N	PRESENT	0
14176	11964	04038G	PARTICIPANT	\N	PRESENT	0
14203	11964	77002U	PARTICIPANT	\N	PRESENT	0
14204	11964	04056J	PARTICIPANT	\N	PRESENT	0
14205	11964	14169X	PARTICIPANT	\N	PRESENT	0
14206	11964	08016S	PARTICIPANT	\N	PRESENT	0
13703	11721	14071N	PARTICIPANT	\N	PRESENT	0
13704	11721	14259Y	PARTICIPANT	\N	PRESENT	0
14207	11964	08017T	PARTICIPANT	\N	PRESENT	0
14208	11964	14038Y	PARTICIPANT	\N	PRESENT	0
14209	11964	04085P	PARTICIPANT	\N	PRESENT	0
14210	11964	01059Y	PARTICIPANT	\N	PRESENT	0
14211	11964	04057K	PARTICIPANT	\N	PRESENT	0
14212	11964	04054G	PARTICIPANT	\N	PRESENT	0
14213	11964	01048V	PARTICIPANT	\N	PRESENT	0
14214	11964	01008M	PARTICIPANT	\N	PRESENT	0
14215	11964	04053F	PARTICIPANT	\N	PRESENT	0
14216	11964	98023Q	PARTICIPANT	\N	PRESENT	0
13715	11721	11033F	PARTICIPANT	\N	PRESENT	0
14217	11964	04059M	PARTICIPANT	\N	PRESENT	0
14218	11964	12042Y	PARTICIPANT	\N	PRESENT	0
14219	11964	08024S	PARTICIPANT	\N	PRESENT	0
13719	11721	10015M	PARTICIPANT	\N	PRESENT	0
13720	11721	11100Y	PARTICIPANT	\N	PRESENT	0
14220	11964	11100Y	PARTICIPANT	\N	PRESENT	0
14223	11964	11109J	PARTICIPANT	\N	PRESENT	0
14224	11964	95039L	PARTICIPANT	\N	PRESENT	0
13724	11721	92045V	PARTICIPANT	\N	PRESENT	0
14225	11964	11091R	PARTICIPANT	\N	PRESENT	0
13726	11721	14195A	PARTICIPANT	\N	PRESENT	0
14226	11964	11048N	PARTICIPANT	\N	PRESENT	0
14276	11964	14261S	PARTICIPANT	\N	PRESENT	0
14228	11964	14265W	PARTICIPANT	\N	PRESENT	0
14229	11964	08011M	PARTICIPANT	\N	PRESENT	0
13731	11721	11114F	PARTICIPANT	\N	PRESENT	0
14230	11964	14221J	PARTICIPANT	\N	PRESENT	0
14231	11964	14119M	PARTICIPANT	\N	PRESENT	0
14232	11964	11026G	PARTICIPANT	\N	PRESENT	0
14233	11964	14269B	PARTICIPANT	\N	PRESENT	0
14234	11964	99004R	PARTICIPANT	\N	PRESENT	0
13737	11721	08052W	PARTICIPANT	\N	PRESENT	0
14235	11964	14217N	PARTICIPANT	\N	PRESENT	0
14236	11964	11071M	PARTICIPANT	\N	PRESENT	0
14237	11964	14069U	PARTICIPANT	\N	PRESENT	0
14238	11964	11049P	PARTICIPANT	\N	PRESENT	0
14239	11964	04074L	PARTICIPANT	\N	PRESENT	0
14240	11964	14031R	PARTICIPANT	\N	PRESENT	0
13744	11721	14271U	PARTICIPANT	\N	PRESENT	0
13745	11721	11112D	PARTICIPANT	\N	PRESENT	0
14241	11964	92045V	PARTICIPANT	\N	PRESENT	0
13747	11721	14269B	PARTICIPANT	\N	PRESENT	0
14242	11964	04049K	PARTICIPANT	\N	PRESENT	0
13749	11721	14034U	PARTICIPANT	\N	PRESENT	0
14243	11964	14219Q	PARTICIPANT	\N	PRESENT	0
14244	11964	11093T	PARTICIPANT	\N	PRESENT	0
13752	11721	11025F	PARTICIPANT	\N	PRESENT	0
14245	11964	11053K	PARTICIPANT	\N	PRESENT	0
14246	11964	14037X	PARTICIPANT	\N	PRESENT	0
13755	11721	01011G	PARTICIPANT	\N	PRESENT	0
14247	11964	07024N	PARTICIPANT	\N	PRESENT	0
14248	11964	04092N	PARTICIPANT	\N	PRESENT	0
14249	11964	95041E	PARTICIPANT	\N	PRESENT	0
13759	11721	11093T	PARTICIPANT	\N	PRESENT	0
13760	11721	11103C	PARTICIPANT	\N	PRESENT	0
14250	11964	92031P	PARTICIPANT	\N	PRESENT	0
13762	11721	01046T	PARTICIPANT	\N	PRESENT	0
13763	11721	14179A	PARTICIPANT	\N	PRESENT	0
13764	11721	01008M	PARTICIPANT	\N	PRESENT	0
13765	11721	14037X	PARTICIPANT	\N	PRESENT	0
14251	11964	14061L	PARTICIPANT	\N	PRESENT	0
13767	11721	11012A	PARTICIPANT	\N	PRESENT	0
14252	11964	98042T	PARTICIPANT	\N	PRESENT	0
13769	11721	11061K	PARTICIPANT	\N	PRESENT	0
13770	11721	04081K	PARTICIPANT	\N	PRESENT	0
14253	11964	89017R	PARTICIPANT	\N	PRESENT	0
13772	11721	04067M	PARTICIPANT	\N	PRESENT	0
14254	11964	09001P	PARTICIPANT	\N	PRESENT	0
14255	11964	14059S	PARTICIPANT	\N	PRESENT	0
13775	11721	11031D	PARTICIPANT	\N	PRESENT	0
14256	11964	11044J	PARTICIPANT	\N	PRESENT	0
13777	11721	14083S	PARTICIPANT	\N	PRESENT	0
14257	11964	11042G	PARTICIPANT	\N	PRESENT	0
13779	11721	14038Y	PARTICIPANT	\N	PRESENT	0
14221	11964	11110B	PARTICIPANT	\N	PRESENT	0
14222	11964	14253S	PARTICIPANT	\N	PRESENT	0
14258	11964	04078Q	PARTICIPANT	\N	PRESENT	0
14259	11964	11069T	PARTICIPANT	\N	PRESENT	0
14260	11964	98022P	PARTICIPANT	\N	PRESENT	0
14261	11964	01057W	PARTICIPANT	\N	PRESENT	0
14262	11964	11085T	PARTICIPANT	\N	PRESENT	0
14263	11964	04067M	PARTICIPANT	\N	PRESENT	0
14264	11964	10006L	PARTICIPANT	\N	PRESENT	0
14265	11964	11011M	PARTICIPANT	\N	PRESENT	0
14269	11964	95063L	PARTICIPANT	\N	PRESENT	0
14267	11964	08051V	PARTICIPANT	\N	PRESENT	0
14268	11964	14173T	PARTICIPANT	\N	PRESENT	0
14270	11964	01031L	PARTICIPANT	\N	PRESENT	0
14271	11964	11065P	PARTICIPANT	\N	PRESENT	0
14272	11964	11033F	PARTICIPANT	\N	PRESENT	0
14273	11964	14157T	PARTICIPANT	\N	PRESENT	0
14274	11964	08031R	PARTICIPANT	\N	PRESENT	0
14275	11964	08073C	PARTICIPANT	\N	PRESENT	0
14277	11964	14195A	PARTICIPANT	\N	PRESENT	0
14278	11964	01011G	PARTICIPANT	\N	PRESENT	0
14279	11964	01022K	PARTICIPANT	\N	PRESENT	0
14280	11964	11077T	PARTICIPANT	\N	PRESENT	0
14281	11964	04043D	PARTICIPANT	\N	PRESENT	0
14282	11964	08069G	PARTICIPANT	\N	PRESENT	0
14436	11966	04066L	PARTICIPANT	\N	PRESENT	0
14486	14485	00003C	PARTICIPANT	\N	PRESENT	0
14487	14485	11044J	PARTICIPANT	\N	PRESENT	0
14489	14485	14195A	PARTICIPANT	\N	PRESENT	0
14491	14485	08052W	PARTICIPANT	\N	PRESENT	0
14492	14485	10006L	PARTICIPANT	\N	PRESENT	0
14493	14485	14217N	PARTICIPANT	\N	PRESENT	0
14494	14485	14042U	PARTICIPANT	\N	PRESENT	0
14495	14485	11067R	PARTICIPANT	\N	PRESENT	0
14496	14485	04092N	PRESIDENT	0	PRESENT	0
14497	14485	14265W	PARTICIPANT	\N	PRESENT	0
14498	14485	14119M	PARTICIPANT	\N	PRESENT	0
14499	14485	14271U	PARTICIPANT	\N	PRESENT	0
14500	14485	04045F	PARTICIPANT	\N	PRESENT	0
14501	14485	11025F	PARTICIPANT	\N	PRESENT	0
14502	14485	14269B	PARTICIPANT	\N	PRESENT	0
14577	14574	00003C	PARTICIPANT	\N	PRESENT	0
14578	14574	08052W	PARTICIPANT	\N	PRESENT	0
14579	14574	10006L	PARTICIPANT	\N	PRESENT	0
14580	14574	14042U	PARTICIPANT	\N	PRESENT	0
14581	14574	11061K	PARTICIPANT	\N	PRESENT	0
14582	14574	14213J	PARTICIPANT	\N	PRESENT	0
14583	14574	08041T	PARTICIPANT	\N	EXCUSE	0
14584	14574	14121F	PARTICIPANT	\N	EXCUSE	0
14585	14574	04092N	PRESIDENT	0	PRESENT	0
14586	14574	04043D	PARTICIPANT	\N	PRESENT	0
14587	14574	14271U	PARTICIPANT	\N	PRESENT	0
14588	14574	11097X	PARTICIPANT	\N	EXCUSE	0
14589	14574	01034P	PARTICIPANT	\N	PRESENT	0
14590	14574	14269B	PARTICIPANT	\N	PRESENT	0
14593	11971	11089X	PARTICIPANT	\N	PRESENT	0
14594	11971	14237S	PARTICIPANT	\N	PRESENT	0
14595	11971	14219Q	PARTICIPANT	\N	PRESENT	0
14596	11971	11099A	PARTICIPANT	\N	PRESENT	0
14597	11971	08009T	PARTICIPANT	\N	PRESENT	0
14598	11971	04035D	PARTICIPANT	\N	PRESENT	0
14645	14601	04053F	PARTICIPANT	\N	PRESENT	0
14605	14601	11031D	PARTICIPANT	\N	PRESENT	0
14606	14601	01059Y	PARTICIPANT	\N	PRESENT	0
14607	14601	11109J	PARTICIPANT	\N	PRESENT	0
14650	14601	04066L	PARTICIPANT	\N	PRESENT	0
14667	14601	11107G	PARTICIPANT	\N	PRESENT	0
14610	14601	11072N	PARTICIPANT	\N	PRESENT	0
14612	14601	08052W	PARTICIPANT	\N	PRESENT	0
14613	14601	14269B	PARTICIPANT	\N	PRESENT	0
14614	14601	11061K	PARTICIPANT	\N	PRESENT	0
14615	14601	01034P	PARTICIPANT	\N	PRESENT	0
14616	14601	04092N	PARTICIPANT	\N	PRESENT	0
14617	14601	10006L	PARTICIPANT	\N	PRESENT	0
14618	14601	14042U	PARTICIPANT	\N	PRESENT	0
14619	14601	14213J	PARTICIPANT	\N	PRESENT	0
14620	14601	14265W	PARTICIPANT	\N	PRESENT	0
14621	14601	14271U	PARTICIPANT	\N	PRESENT	0
14622	14601	04043D	PARTICIPANT	\N	PRESENT	0
14623	14601	00003C	PARTICIPANT	\N	PRESENT	0
14624	14601	11114F	PARTICIPANT	\N	PRESENT	0
14669	14602	00003C	PARTICIPANT	\N	PRESENT	0
14626	14601	01046T	PARTICIPANT	\N	PRESENT	0
14670	14602	08052W	PARTICIPANT	\N	PRESENT	0
14628	14601	11089X	PARTICIPANT	\N	PRESENT	0
14671	14602	11061K	PARTICIPANT	\N	PRESENT	0
14630	14601	14219Q	PARTICIPANT	\N	PRESENT	0
14672	14602	11063M	PARTICIPANT	\N	PRESENT	0
14632	14601	08009T	PARTICIPANT	\N	PRESENT	0
14633	14601	04035D	PARTICIPANT	\N	PRESENT	0
14635	14601	04081K	PARTICIPANT	\N	PRESENT	0
14636	14601	11025F	PARTICIPANT	\N	PRESENT	0
14637	14601	11063M	PARTICIPANT	\N	PRESENT	0
14638	14601	11055M	PARTICIPANT	\N	PRESENT	0
14639	14601	92045V	PARTICIPANT	\N	PRESENT	0
14640	14601	09001P	PARTICIPANT	\N	PRESENT	0
14641	14601	11011M	PARTICIPANT	\N	PRESENT	0
14642	14601	14041T	PARTICIPANT	\N	PRESENT	0
14643	14601	14209N	PARTICIPANT	\N	PRESENT	0
14644	14601	10015M	PARTICIPANT	\N	PRESENT	0
14673	14602	11089X	PARTICIPANT	\N	PRESENT	0
14674	14602	01059Y	PARTICIPANT	\N	PRESENT	0
14675	14602	11031D	PARTICIPANT	\N	PRESENT	0
14676	14602	14271U	PARTICIPANT	\N	PRESENT	0
14677	14602	14219Q	PARTICIPANT	\N	PRESENT	0
14678	14602	08009T	PARTICIPANT	\N	PRESENT	0
14679	14602	01034P	PARTICIPANT	\N	PRESENT	0
14680	14602	14265W	PARTICIPANT	\N	PRESENT	0
14681	14602	04035D	PARTICIPANT	\N	PRESENT	0
14682	14602	04043D	PARTICIPANT	\N	PRESENT	0
15901	15897	01031L	PRESIDENT	0	PRESENT	0
15902	15897	01013J	PARTICIPANT	\N	EXCUSE	0
15903	15897	11040E	PARTICIPANT	\N	PRESENT	0
15904	15897	14175V	PARTICIPANT	\N	EXCUSE	0
15906	15897	14083S	PARTICIPANT	\N	PRESENT	0
15907	15897	14085U	PARTICIPANT	\N	EXCUSE	0
15908	15897	11042G	PARTICIPANT	\N	PRESENT	0
15909	15897	04086Q	PARTICIPANT	\N	PRESENT	0
15910	15897	04055H	PARTICIPANT	\N	EXCUSE	0
15912	15897	01027Q	PARTICIPANT	\N	PRESENT	0
15913	15897	04071H	PARTICIPANT	\N	PRESENT	0
15914	15897	11074Q	PARTICIPANT	\N	PRESENT	0
15915	15897	11083R	PARTICIPANT	\N	PRESENT	0
15916	15897	01057W	PARTICIPANT	\N	PRESENT	0
15917	15897	08069G	PARTICIPANT	\N	PRESENT	0
15918	15897	11048N	PARTICIPANT	\N	PRESENT	0
15919	15897	99004R	PARTICIPANT	\N	PRESENT	0
15920	15897	04061F	PARTICIPANT	\N	PRESENT	0
15921	15897	14159V	PARTICIPANT	\N	PRESENT	0
15922	15897	07029T	PARTICIPANT	\N	EXCUSE	0
15923	15897	08010L	PARTICIPANT	\N	PRESENT	0
15924	15897	08034U	PARTICIPANT	\N	PRESENT	0
15925	15897	08011M	PARTICIPANT	\N	PRESENT	0
15926	15897	08073C	PARTICIPANT	\N	PRESENT	0
15928	15897	11057P	PARTICIPANT	\N	EXCUSE	0
15929	15897	14173T	PARTICIPANT	\N	PRESENT	0
15931	15897	04034C	PARTICIPANT	\N	PRESENT	0
15932	15897	01016M	PARTICIPANT	\N	EXCUSE	0
16296	15591	11026G	PARTICIPANT	\N	PRESENT	0
16591	16590	08025T	PARTICIPANT	\N	PRESENT	0
16592	16590	05008E	PRESIDENT	0	PRESENT	0
16597	16590	04047H	PARTICIPANT	\N	PRESENT	0
16594	16590	04085P	PARTICIPANT	\N	PRESENT	0
16595	16590	14069U	PARTICIPANT	\N	PRESENT	0
16600	16590	14041T	PARTICIPANT	\N	PRESENT	0
16598	16590	04038G	PARTICIPANT	\N	PRESENT	0
16599	16590	11056N	PARTICIPANT	\N	PRESENT	0
16601	16590	11113E	PARTICIPANT	\N	PRESENT	0
16602	16590	01024M	PARTICIPANT	\N	PRESENT	0
16603	16590	14215L	PARTICIPANT	\N	PRESENT	0
16604	16590	11034G	PARTICIPANT	\N	PRESENT	0
16605	16590	08018U	PARTICIPANT	\N	EXCUSE	0
16606	16590	11010L	PARTICIPANT	\N	PRESENT	0
16607	16590	01007L	PARTICIPANT	\N	PRESENT	0
16608	16590	11049P	PARTICIPANT	\N	PRESENT	0
16609	16590	11084S	PARTICIPANT	\N	PRESENT	0
16610	16590	11026G	PARTICIPANT	\N	PRESENT	0
16611	16590	14111D	PARTICIPANT	\N	PRESENT	0
16612	16590	14001X	PARTICIPANT	\N	PRESENT	0
16613	16590	14273W	PARTICIPANT	\N	EXCUSE	0
16614	16590	14147R	PARTICIPANT	\N	PRESENT	0
16615	16590	95049N	PARTICIPANT	\N	PRESENT	0
16616	16590	08051V	PARTICIPANT	\N	PRESENT	0
16617	16590	11072N	PARTICIPANT	\N	PRESENT	0
16618	16590	07034Q	PARTICIPANT	\N	PRESENT	0
16619	16590	04074L	PARTICIPANT	\N	PRESENT	0
16620	16590	10015M	PARTICIPANT	\N	PRESENT	0
16621	16590	95063L	PARTICIPANT	\N	PRESENT	0
16622	16590	01028R	PARTICIPANT	\N	PRESENT	0
16623	16590	04056J	PARTICIPANT	\N	PRESENT	0
16624	16590	14275Y	PARTICIPANT	\N	PRESENT	0
16625	16590	04044E	PARTICIPANT	\N	PRESENT	0
16626	16590	11037K	PARTICIPANT	\N	PRESENT	0
16627	16590	95067Q	PARTICIPANT	\N	PRESENT	0
16628	16590	01047U	PARTICIPANT	\N	PRESENT	0
16669	15862	08055A	PARTICIPANT	\N	PRESENT	0
16670	15862	14026U	PARTICIPANT	\N	PRESENT	0
16671	15862	11106F	PARTICIPANT	\N	PRESENT	0
16672	15862	14063N	PARTICIPANT	\N	PRESENT	0
16673	15862	08058D	PARTICIPANT	\N	PRESENT	0
16674	15862	98029W	PARTICIPANT	\N	PRESENT	0
16675	15862	11114F	PARTICIPANT	\N	PRESENT	0
16676	15862	14219Q	PARTICIPANT	\N	PRESENT	0
16677	15862	14089Y	PARTICIPANT	\N	PRESENT	0
16678	15862	08009T	PARTICIPANT	\N	PRESENT	0
16679	15862	11054L	PARTICIPANT	\N	PRESENT	0
16680	15862	01014K	PARTICIPANT	\N	PRESENT	0
16681	15862	14073Q	PARTICIPANT	\N	PRESENT	0
16682	15862	14179A	PARTICIPANT	\N	PRESENT	0
16683	15862	14231L	PARTICIPANT	\N	PRESENT	0
16684	15862	14187A	PARTICIPANT	\N	PRESENT	0
16685	15862	04088S	PARTICIPANT	\N	PRESENT	0
16686	15862	14199E	PARTICIPANT	\N	PRESENT	0
16687	15862	07004J	PARTICIPANT	\N	PRESENT	0
16688	15862	08044W	PARTICIPANT	\N	PRESENT	0
16689	15862	04040A	PARTICIPANT	\N	PRESENT	0
16690	15862	14267Y	PARTICIPANT	\N	PRESENT	0
16691	15862	14018U	PARTICIPANT	\N	PRESENT	0
16692	15862	08047A	PARTICIPANT	\N	PRESENT	0
16693	15862	98050T	PARTICIPANT	\N	PRESENT	0
16694	15862	08034U	PARTICIPANT	\N	PRESENT	0
16695	15862	01027Q	PARTICIPANT	\N	PRESENT	0
16696	15862	99004R	PARTICIPANT	\N	PRESENT	0
16697	15862	11103C	PARTICIPANT	\N	PRESENT	0
16698	15862	14205J	PARTICIPANT	\N	PRESENT	0
16699	15862	92018S	PARTICIPANT	\N	PRESENT	0
16700	15862	04033B	PARTICIPANT	\N	PRESENT	0
16701	15862	01003G	PARTICIPANT	\N	PRESENT	0
16702	15862	14038Y	PARTICIPANT	\N	PRESENT	0
16703	15862	98021N	PARTICIPANT	\N	PRESENT	0
16704	15862	07032N	PARTICIPANT	\N	PRESENT	0
16705	15862	04042C	PARTICIPANT	\N	PRESENT	0
16706	15862	11100Y	PARTICIPANT	\N	PRESENT	0
16707	15862	13002U	PARTICIPANT	\N	PRESENT	0
16708	15862	11066Q	PARTICIPANT	\N	PRESENT	0
16709	15862	95063L	PARTICIPANT	\N	PRESENT	0
16710	15862	08014Q	PARTICIPANT	\N	PRESENT	0
16711	15862	01056V	PARTICIPANT	\N	PRESENT	0
16712	15862	98022P	PARTICIPANT	\N	PRESENT	0
16713	15862	14259Y	PARTICIPANT	\N	PRESENT	0
16714	15862	11084S	PARTICIPANT	\N	PRESENT	0
16715	15862	11064N	PARTICIPANT	\N	PRESENT	0
16716	15862	14235Q	PARTICIPANT	\N	PRESENT	0
16717	15862	86044G	PARTICIPANT	\N	PRESENT	0
16718	15862	11036J	PARTICIPANT	\N	PRESENT	0
16719	15862	04034C	PARTICIPANT	\N	PRESENT	0
16720	15862	14033T	PARTICIPANT	\N	PRESENT	0
16721	15862	01057W	PARTICIPANT	\N	PRESENT	0
16722	15862	11057P	PARTICIPANT	\N	PRESENT	0
16723	15862	14051J	PARTICIPANT	\N	PRESENT	0
16724	15862	11014C	PARTICIPANT	\N	PRESENT	0
16726	15862	11026G	PARTICIPANT	\N	PRESENT	0
16727	16725	89017R	PARTICIPANT	\N	PRESENT	0
16728	15862	14265W	PARTICIPANT	\N	PRESENT	0
16729	15862	08065C	PARTICIPANT	\N	PRESENT	0
16730	15862	14111D	PARTICIPANT	\N	PRESENT	0
16732	15862	01008M	PARTICIPANT	\N	PRESENT	0
16737	15862	87003B	PARTICIPANT	\N	PRESENT	0
16744	15862	90003B	PARTICIPANT	\N	PRESENT	0
16749	15862	14257W	PARTICIPANT	\N	PRESENT	0
16758	15862	14209N	PARTICIPANT	\N	PRESENT	0
16762	15862	92031P	PARTICIPANT	\N	PRESENT	0
16763	15862	95041E	PARTICIPANT	\N	PRESENT	0
16777	15862	04092N	PARTICIPANT	\N	PRESENT	0
16731	16725	01031L	PRESIDENT	0	PRESENT	0
15892	15890	01028R	PARTICIPANT	\N	EXCUSE	0
15899	15101	01022K	PARTICIPANT	\N	EXCUSE	0
16733	16725	01013J	PARTICIPANT	\N	PRESENT	0
16631	16629	08055A	PARTICIPANT	\N	PRESENT	0
16632	16629	14093U	PARTICIPANT	\N	PRESENT	0
16633	16629	14030Q	PARTICIPANT	\N	PRESENT	0
16634	16629	96004D	PARTICIPANT	\N	PRESENT	0
16635	16629	08060W	PARTICIPANT	\N	PRESENT	0
16734	16725	11068S	PARTICIPANT	\N	PRESENT	0
16637	16629	11095V	PARTICIPANT	\N	PRESENT	0
16638	16629	14038Y	PARTICIPANT	\N	PRESENT	0
16639	16629	11114F	PARTICIPANT	\N	PRESENT	0
16640	16629	98023Q	PARTICIPANT	\N	PRESENT	0
16641	16629	11065P	PARTICIPANT	\N	PRESENT	0
16642	16629	01015L	PARTICIPANT	\N	PRESENT	0
16643	16629	11107G	PARTICIPANT	\N	PRESENT	0
16735	16725	08014Q	PARTICIPANT	\N	PRESENT	0
16736	16725	14175V	PARTICIPANT	\N	PRESENT	0
16646	16629	01022K	PARTICIPANT	\N	PRESENT	0
16647	16629	04097T	PARTICIPANT	\N	PRESENT	0
16648	16629	09001P	PARTICIPANT	\N	EXCUSE	0
16649	16629	11059R	PARTICIPANT	\N	PRESENT	0
16650	16629	14219Q	PARTICIPANT	\N	PRESENT	0
16651	16629	80027E	PARTICIPANT	\N	PRESENT	0
16652	16629	14031R	PARTICIPANT	\N	EXCUSE	0
16653	16629	08009T	PRESIDENT	0	PRESENT	0
16654	16629	08062Y	PARTICIPANT	\N	PRESENT	0
16655	16629	14221J	PARTICIPANT	\N	PRESENT	0
16656	16629	92039X	PARTICIPANT	\N	PRESENT	0
16657	16629	08042U	PARTICIPANT	\N	EXCUSE	0
16738	16725	14083S	PARTICIPANT	\N	PRESENT	0
16659	16629	14237S	PARTICIPANT	\N	PRESENT	0
16660	16629	13002U	PARTICIPANT	\N	PRESENT	0
16661	16629	05012A	PARTICIPANT	\N	PRESENT	0
16739	16725	14085U	PARTICIPANT	\N	PRESENT	0
16663	16629	14135M	PARTICIPANT	\N	PRESENT	0
16664	16629	95062K	PARTICIPANT	\N	EXCUSE	0
16665	16629	14107H	PARTICIPANT	\N	PRESENT	0
16666	16629	14051J	PARTICIPANT	\N	PRESENT	0
16667	16629	14157T	PARTICIPANT	\N	PRESENT	0
16668	16629	96003C	PARTICIPANT	\N	EXCUSE	0
16740	16725	11042G	PARTICIPANT	\N	PRESENT	0
16741	16725	04086Q	PARTICIPANT	\N	PRESENT	0
16742	16725	04055H	PARTICIPANT	\N	EXCUSE	0
16743	16725	11070L	PARTICIPANT	\N	PRESENT	0
16745	16725	11088W	PARTICIPANT	\N	PRESENT	0
16746	16725	14327T	PARTICIPANT	\N	PRESENT	0
16747	16725	08022Q	PARTICIPANT	\N	PRESENT	0
16748	16725	01027Q	PARTICIPANT	\N	PRESENT	0
16750	16725	11074Q	PARTICIPANT	\N	PRESENT	0
16751	16725	11083R	PARTICIPANT	\N	PRESENT	0
16752	16725	14199E	PARTICIPANT	\N	PRESENT	0
16753	16725	01057W	PARTICIPANT	\N	PRESENT	0
16754	16725	08016S	PARTICIPANT	\N	PRESENT	0
16755	16725	08069G	PARTICIPANT	\N	PRESENT	0
16756	16725	11048N	PARTICIPANT	\N	PRESENT	0
16757	16725	99004R	PARTICIPANT	\N	PRESENT	0
16759	16725	04061F	PARTICIPANT	\N	PRESENT	0
16760	16725	14159V	PARTICIPANT	\N	PRESENT	0
16761	16725	07029T	PARTICIPANT	\N	PRESENT	0
16764	16725	08010L	PARTICIPANT	\N	PRESENT	0
16765	16725	08034U	PARTICIPANT	\N	PRESENT	0
16766	16725	01048V	PARTICIPANT	\N	PRESENT	0
16767	16725	11085T	PARTICIPANT	\N	PRESENT	0
16768	16725	08011M	PARTICIPANT	\N	PRESENT	0
16769	16725	08073C	PARTICIPANT	\N	PRESENT	0
16770	16725	08061X	PARTICIPANT	\N	PRESENT	0
16771	16725	01016M	PARTICIPANT	\N	EXCUSE	0
16772	16725	14225N	PARTICIPANT	\N	PRESENT	0
16773	16725	11012A	PARTICIPANT	\N	PRESENT	0
16774	16725	11057P	PARTICIPANT	\N	PRESENT	0
16775	16725	14173T	PARTICIPANT	\N	PRESENT	0
16776	16725	04034C	PARTICIPANT	\N	PRESENT	0
16778	15862	14213J	PARTICIPANT	\N	PRESENT	0
16850	15862	14001X	PARTICIPANT	\N	PRESENT	0
16801	16788	14195A	PARTICIPANT	\N	PRESENT	0
16802	16788	14267Y	PARTICIPANT	\N	PRESENT	0
16803	16788	11023D	PARTICIPANT	\N	PRESENT	0
16804	16788	11031D	PARTICIPANT	\N	PRESENT	0
16805	16788	08052W	PARTICIPANT	\N	PRESENT	0
16806	16788	01059Y	PARTICIPANT	\N	PRESENT	0
16807	16788	04081K	PARTICIPANT	\N	PRESENT	0
16808	16788	98024R	PARTICIPANT	\N	PRESENT	0
16809	16788	10006L	PARTICIPANT	\N	PRESENT	0
16810	16788	04067M	PARTICIPANT	\N	PRESENT	0
16811	16788	14217N	PARTICIPANT	\N	PRESENT	0
16812	16788	14042U	PARTICIPANT	\N	PRESENT	0
16813	16788	14151M	PARTICIPANT	\N	PRESENT	0
16814	16788	12042Y	PARTICIPANT	\N	PRESENT	0
16851	15862	95059Q	PARTICIPANT	\N	PRESENT	0
16816	16788	14087W	PARTICIPANT	\N	PRESENT	0
16852	15862	11107G	PARTICIPANT	\N	PRESENT	0
16853	15862	14133K	PARTICIPANT	\N	PRESENT	0
16819	16788	14231L	PARTICIPANT	\N	PRESENT	0
16820	16788	11061K	PARTICIPANT	\N	PRESENT	0
16854	15862	96004D	PARTICIPANT	\N	PRESENT	0
16822	16788	08041T	PARTICIPANT	\N	PRESENT	0
16823	16788	01011G	PARTICIPANT	\N	PRESENT	0
16824	16788	14026U	PARTICIPANT	\N	PRESENT	0
16825	16788	14213J	PARTICIPANT	\N	PRESENT	0
16855	15862	01031L	PARTICIPANT	\N	PRESENT	0
16827	16788	11112D	PARTICIPANT	\N	PRESENT	0
16828	16788	14037X	PARTICIPANT	\N	PRESENT	0
16856	15862	14097Y	PARTICIPANT	\N	PRESENT	0
16830	16788	11067R	PARTICIPANT	\N	PRESENT	0
16831	16788	14223L	PARTICIPANT	\N	PRESENT	0
16832	16788	04092N	PRESIDENT	0	PRESENT	0
16833	16788	14265W	PARTICIPANT	\N	PRESENT	0
16834	16788	14119M	PARTICIPANT	\N	PRESENT	0
16835	16788	14071N	PARTICIPANT	\N	PRESENT	0
16836	16788	07032N	PARTICIPANT	\N	PRESENT	0
16837	16788	04043D	PARTICIPANT	\N	PRESENT	0
16838	16788	14271U	PARTICIPANT	\N	PRESENT	0
16857	15862	14037X	PARTICIPANT	\N	PRESENT	0
16840	16788	11093T	PARTICIPANT	\N	PRESENT	0
16841	16788	11097X	PARTICIPANT	\N	EXCUSE	0
16858	15862	12042Y	PARTICIPANT	\N	PRESENT	0
16843	16788	14227Q	PARTICIPANT	\N	PRESENT	0
16844	16788	01034P	PARTICIPANT	\N	PRESENT	0
16859	15862	11070L	PARTICIPANT	\N	PRESENT	0
16846	16788	11063M	PARTICIPANT	\N	PRESENT	0
16847	16788	14269B	PARTICIPANT	\N	PRESENT	0
16848	15862	14217N	PARTICIPANT	\N	PRESENT	0
16860	15862	04035D	PARTICIPANT	\N	PRESENT	0
16861	15862	14107H	PARTICIPANT	\N	PRESENT	0
16862	15862	07029T	PARTICIPANT	\N	PRESENT	0
16863	15862	11112D	PARTICIPANT	\N	PRESENT	0
16864	15862	04053F	PARTICIPANT	\N	PRESENT	0
16865	15862	80013X	PARTICIPANT	\N	PRESENT	0
16866	15862	14109K	PARTICIPANT	\N	PRESENT	0
16867	15862	11094U	PARTICIPANT	\N	PRESENT	0
16868	15862	08015R	PARTICIPANT	\N	PRESENT	0
16869	15862	14225N	PARTICIPANT	\N	PRESENT	0
16870	15862	11067R	PARTICIPANT	\N	PRESENT	0
16871	15862	14273W	PARTICIPANT	\N	PRESENT	0
16872	15862	04077P	PARTICIPANT	\N	PRESENT	0
16873	15862	08052W	PARTICIPANT	\N	PRESENT	0
16874	15862	14223L	PARTICIPANT	\N	PRESENT	0
16875	15862	14105F	PARTICIPANT	\N	PRESENT	0
16876	15862	05012A	PARTICIPANT	\N	PRESENT	0
16877	15862	01047U	PARTICIPANT	\N	PRESENT	0
16878	15862	11105E	PARTICIPANT	\N	PRESENT	0
16879	15862	01041N	PARTICIPANT	\N	PRESENT	0
16880	15862	14014Q	PARTICIPANT	\N	PRESENT	0
16881	15862	14087W	PARTICIPANT	\N	PRESENT	0
16882	15862	14241N	PARTICIPANT	\N	PRESENT	0
16883	15862	14221J	PARTICIPANT	\N	PRESENT	0
16884	15862	11015D	PARTICIPANT	\N	PRESENT	0
16885	15862	11082Q	PARTICIPANT	\N	PRESENT	0
16886	15862	14034U	PARTICIPANT	\N	PRESENT	0
16887	15862	01046T	PARTICIPANT	\N	PRESENT	0
16888	15862	14269B	PARTICIPANT	\N	PRESENT	0
16889	15862	14059S	PARTICIPANT	\N	PRESENT	0
16890	15862	10006L	PARTICIPANT	\N	PRESENT	0
16891	15862	14053L	PARTICIPANT	\N	PRESENT	0
16892	15862	14207L	PARTICIPANT	\N	PRESENT	0
16893	15862	14042U	PARTICIPANT	\N	PRESENT	0
16895	16779	08009T	PARTICIPANT	\N	EXCUSE	0
16896	15862	14195A	PARTICIPANT	\N	PRESENT	0
16897	15862	01059Y	PARTICIPANT	\N	PRESENT	0
16898	15862	01048V	PARTICIPANT	\N	PRESENT	0
16899	15862	11061K	PARTICIPANT	\N	PRESENT	0
16482	16481	89017R	PARTICIPANT	\N	PRESENT	0
16483	16481	01031L	PRESIDENT	0	PRESENT	0
16531	16481	11088W	PARTICIPANT	\N	PRESENT	0
16485	16481	01013J	PARTICIPANT	\N	EXCUSE	0
16486	16481	11068S	PARTICIPANT	\N	PRESENT	0
16487	16481	11040E	PARTICIPANT	\N	PRESENT	0
16789	16779	04040A	PRESIDENT	0	PRESENT	0
16849	16779	04044E	PARTICIPANT	\N	EXCUSE	0
16490	16481	14175V	PARTICIPANT	\N	PRESENT	0
16491	16481	14083S	PARTICIPANT	\N	PRESENT	0
16492	16481	11053K	PARTICIPANT	\N	PRESENT	0
16493	16481	14085U	PARTICIPANT	\N	PRESENT	0
16494	16481	11042G	PARTICIPANT	\N	PRESENT	0
17229	15863	14257W	PARTICIPANT	\N	PRESENT	0
16496	16481	04086Q	PARTICIPANT	\N	PRESENT	0
16497	16481	04055H	PARTICIPANT	\N	EXCUSE	0
17230	15863	08052W	PARTICIPANT	\N	PRESENT	0
17231	15863	14107H	PARTICIPANT	\N	PRESENT	0
16500	16481	14327T	PARTICIPANT	\N	PRESENT	0
17232	15863	01059Y	PARTICIPANT	\N	PRESENT	0
16502	16481	01027Q	PARTICIPANT	\N	PRESENT	0
16503	16481	04071H	PARTICIPANT	\N	PRESENT	0
16504	16481	11074Q	PARTICIPANT	\N	PRESENT	0
17233	15863	11063M	PARTICIPANT	\N	PRESENT	0
16506	16481	11083R	PARTICIPANT	\N	PRESENT	0
16507	16481	14199E	PARTICIPANT	\N	PRESENT	0
16508	16481	01057W	PARTICIPANT	\N	PRESENT	0
16509	16481	08016S	PARTICIPANT	\N	PRESENT	0
16510	16481	08069G	PARTICIPANT	\N	PRESENT	0
16511	16481	11048N	PARTICIPANT	\N	PRESENT	0
16512	16481	99004R	PARTICIPANT	\N	PRESENT	0
16513	16481	04061F	PARTICIPANT	\N	PRESENT	0
16514	16481	14159V	PARTICIPANT	\N	PRESENT	0
16515	16481	07029T	PARTICIPANT	\N	PRESENT	0
17234	15863	11055M	PARTICIPANT	\N	PRESENT	0
16517	16481	08010L	PARTICIPANT	\N	PRESENT	0
17235	15863	14037X	PARTICIPANT	\N	PRESENT	0
16519	16481	01048V	PARTICIPANT	\N	PRESENT	0
16520	16481	98046X	PARTICIPANT	\N	PRESENT	0
17236	15863	14187A	PARTICIPANT	\N	PRESENT	0
16522	16481	08011M	PARTICIPANT	\N	PRESENT	0
16523	16481	08073C	PARTICIPANT	\N	PRESENT	0
16524	16481	08061X	PARTICIPANT	\N	PRESENT	0
16525	16481	01016M	PARTICIPANT	\N	EXCUSE	0
16526	16481	14225N	PARTICIPANT	\N	PRESENT	0
16527	16481	11012A	PARTICIPANT	\N	PRESENT	0
16528	16481	11057P	PARTICIPANT	\N	PRESENT	0
17237	15863	14195A	PARTICIPANT	\N	PRESENT	0
16530	16481	04034C	PARTICIPANT	\N	PRESENT	0
17238	15863	11103C	PARTICIPANT	\N	PRESENT	0
17239	15863	11044J	PARTICIPANT	\N	PRESENT	0
17240	15863	14213J	PARTICIPANT	\N	PRESENT	0
17241	15863	11031D	PARTICIPANT	\N	PRESENT	0
17242	15863	14217N	PARTICIPANT	\N	PRESENT	0
17243	15863	14079W	PARTICIPANT	\N	PRESENT	0
17244	15863	14087W	PARTICIPANT	\N	PRESENT	0
17245	15863	08031R	PARTICIPANT	\N	PRESENT	0
17246	15863	14223L	PARTICIPANT	\N	PRESENT	0
17247	15863	04092N	PARTICIPANT	\N	PRESENT	0
17248	15863	10006L	PARTICIPANT	\N	PRESENT	0
17249	15863	98024R	PARTICIPANT	\N	PRESENT	0
17250	15863	10015M	PARTICIPANT	\N	PRESENT	0
17251	15863	14042U	PARTICIPANT	\N	PRESENT	0
17252	15863	11091R	PARTICIPANT	\N	PRESENT	0
17253	15863	01034P	PARTICIPANT	\N	PRESENT	0
17254	15863	14281W	PARTICIPANT	\N	PRESENT	0
17255	15863	14059S	PARTICIPANT	\N	PRESENT	0
17256	15863	14197C	PARTICIPANT	\N	PRESENT	0
17257	15863	11093T	PARTICIPANT	\N	PRESENT	0
17258	15863	01046T	PARTICIPANT	\N	PRESENT	0
17259	15863	04033B	PARTICIPANT	\N	PRESENT	0
17260	15863	14089Y	PARTICIPANT	\N	PRESENT	0
17261	15863	92045V	PARTICIPANT	\N	PRESENT	0
17262	15863	11061K	PARTICIPANT	\N	PRESENT	0
17263	15863	11114F	PARTICIPANT	\N	PRESENT	0
17264	15863	11089X	PARTICIPANT	\N	PRESENT	0
17265	15863	14111D	PARTICIPANT	\N	PRESENT	0
17266	15863	14030Q	PARTICIPANT	\N	PRESENT	0
17267	15863	14033T	PARTICIPANT	\N	PRESENT	0
17268	15863	04053F	PARTICIPANT	\N	PRESENT	0
17269	15863	14151M	PARTICIPANT	\N	PRESENT	0
17270	15863	11112D	PARTICIPANT	\N	PRESENT	0
17271	15863	14271U	PARTICIPANT	\N	PRESENT	0
17272	15863	04049K	PARTICIPANT	\N	PRESENT	0
17273	15863	14053L	PARTICIPANT	\N	PRESENT	0
17274	15863	08022Q	PARTICIPANT	\N	PRESENT	0
17275	15863	14265W	PARTICIPANT	\N	PRESENT	0
17276	15863	14231L	PARTICIPANT	\N	PRESENT	0
17277	15863	11012A	PARTICIPANT	\N	PRESENT	0
17278	15863	14219Q	PARTICIPANT	\N	PRESENT	0
17279	15863	08034U	PARTICIPANT	\N	PRESENT	0
17280	15863	14251Q	PARTICIPANT	\N	PRESENT	0
17281	15863	14191V	PARTICIPANT	\N	PRESENT	0
17282	15863	04066L	PARTICIPANT	\N	PRESENT	0
17283	15863	11067R	PARTICIPANT	\N	PRESENT	0
17284	15863	14119M	PARTICIPANT	\N	PRESENT	0
17285	15863	11026G	PARTICIPANT	\N	PRESENT	0
17286	15863	12042Y	PARTICIPANT	\N	PRESENT	0
17287	15863	14133K	PARTICIPANT	\N	PRESENT	0
17288	15863	04042C	PARTICIPANT	\N	PRESENT	0
17289	15863	14069U	PARTICIPANT	\N	PRESENT	0
17290	15863	14083S	PARTICIPANT	\N	PRESENT	0
17291	15863	80013X	PARTICIPANT	\N	PRESENT	0
17292	15863	14014Q	PARTICIPANT	\N	PRESENT	0
17293	15863	08015R	PARTICIPANT	\N	PRESENT	0
17294	15863	08010L	PARTICIPANT	\N	PRESENT	0
17090	17089	08025T	PARTICIPANT	\N	PRESENT	0
17091	17089	04085P	PARTICIPANT	\N	PRESENT	0
17092	17089	05008E	PRESIDENT	0	PRESENT	0
17093	17089	11030C	PARTICIPANT	\N	PRESENT	0
17094	17089	11033F	PARTICIPANT	\N	PRESENT	0
17095	17089	14069U	PARTICIPANT	\N	PRESENT	0
17096	17089	04047H	PARTICIPANT	\N	PRESENT	0
17097	17089	04038G	PARTICIPANT	\N	PRESENT	0
17098	17089	11056N	PARTICIPANT	\N	PRESENT	0
17099	17089	14259Y	PARTICIPANT	\N	PRESENT	0
17100	17089	14041T	PARTICIPANT	\N	PRESENT	0
17101	17089	11113E	PARTICIPANT	\N	PRESENT	0
17102	17089	01024M	PARTICIPANT	\N	PRESENT	0
17103	17089	14215L	PARTICIPANT	\N	PRESENT	0
17104	17089	11034G	PARTICIPANT	\N	PRESENT	0
17105	17089	08018U	PARTICIPANT	\N	EXCUSE	0
17106	17089	11010L	PARTICIPANT	\N	PRESENT	0
17107	17089	01007L	PARTICIPANT	\N	PRESENT	0
17295	15863	14038Y	PARTICIPANT	\N	PRESENT	0
17109	17089	11049P	PARTICIPANT	\N	EXCUSE	0
17110	17089	95039L	PARTICIPANT	\N	PRESENT	0
17111	17089	08044W	PARTICIPANT	\N	PRESENT	0
17112	17089	11026G	PARTICIPANT	\N	PRESENT	0
17113	17089	04079R	PARTICIPANT	\N	PRESENT	0
17114	17089	14111D	PARTICIPANT	\N	PRESENT	0
17115	17089	14273W	PARTICIPANT	\N	EXCUSE	0
17116	17089	14147R	PARTICIPANT	\N	PRESENT	0
17117	17089	95049N	PARTICIPANT	\N	PRESENT	0
17118	17089	08051V	PARTICIPANT	\N	PRESENT	0
17119	17089	11072N	PARTICIPANT	\N	PRESENT	0
17120	17089	07034Q	PARTICIPANT	\N	PRESENT	0
17121	17089	10015M	PARTICIPANT	\N	PRESENT	0
17122	17089	95063L	PARTICIPANT	\N	PRESENT	0
17123	17089	01019Q	PARTICIPANT	\N	PRESENT	0
17124	17089	01028R	PARTICIPANT	\N	PRESENT	0
17125	17089	04056J	PARTICIPANT	\N	PRESENT	0
17126	17089	14275Y	PARTICIPANT	\N	PRESENT	0
17127	17089	04044E	PARTICIPANT	\N	PRESENT	0
17128	17089	11037K	PARTICIPANT	\N	PRESENT	0
17129	17089	01047U	PARTICIPANT	\N	PRESENT	0
17296	15863	01008M	PARTICIPANT	\N	PRESENT	0
17132	17131	08025T	PARTICIPANT	\N	PRESENT	0
17133	17131	04085P	PARTICIPANT	\N	PRESENT	0
17134	17131	05008E	PRESIDENT	0	PRESENT	0
17135	17131	11030C	PARTICIPANT	\N	PRESENT	0
17136	17131	11033F	PARTICIPANT	\N	PRESENT	0
17137	17131	14065Q	PARTICIPANT	\N	PRESENT	0
17138	17131	14069U	PARTICIPANT	\N	PRESENT	0
17297	15863	14034U	PARTICIPANT	\N	PRESENT	0
17301	15863	14071N	PARTICIPANT	\N	PRESENT	0
17139	17131	04047H	PARTICIPANT	\N	PRESENT	0
17140	17131	04038G	PARTICIPANT	\N	PRESENT	0
17141	17131	11056N	PARTICIPANT	\N	PRESENT	0
17142	17131	14259Y	PARTICIPANT	\N	PRESENT	0
17143	17131	14041T	PARTICIPANT	\N	PRESENT	0
17144	17131	11113E	PARTICIPANT	\N	PRESENT	0
17145	17131	01024M	PARTICIPANT	\N	PRESENT	0
17146	17131	08018U	PARTICIPANT	\N	EXCUSE	0
17147	17131	11010L	PARTICIPANT	\N	PRESENT	0
17148	17131	01007L	PARTICIPANT	\N	PRESENT	0
17149	17131	11049P	PARTICIPANT	\N	EXCUSE	0
17323	15591	98042T	PARTICIPANT	\N	PRESENT	0
17228	15863	04081K	PARTICIPANT	\N	PRESENT	0
16440	15267	14073Q	PARTICIPANT	\N	PRESENT	0
16441	15267	04049K	PARTICIPANT	\N	PRESENT	0
16442	15267	08010L	PARTICIPANT	\N	PRESENT	0
16443	15267	14259Y	PARTICIPANT	\N	PRESENT	0
16444	15267	11093T	PARTICIPANT	\N	PRESENT	0
16445	15267	11063M	PARTICIPANT	\N	PRESENT	0
16446	15267	14013P	PARTICIPANT	\N	PRESENT	0
16447	15267	14151M	PARTICIPANT	\N	PRESENT	0
16448	15267	08051V	PARTICIPANT	\N	PRESENT	0
16449	15267	14042U	PARTICIPANT	\N	PRESENT	0
16450	15267	11114F	PARTICIPANT	\N	PRESENT	0
16451	15267	14053L	PARTICIPANT	\N	PRESENT	0
16452	15267	14219Q	PARTICIPANT	\N	PRESENT	0
16453	15267	14221J	PARTICIPANT	\N	PRESENT	0
16454	15267	04045F	PARTICIPANT	\N	PRESENT	0
16455	15267	14223L	PARTICIPANT	\N	PRESENT	0
16456	15267	11042G	PARTICIPANT	\N	PRESENT	0
16457	15267	14111D	PARTICIPANT	\N	PRESENT	0
16458	15267	14083S	PARTICIPANT	\N	PRESENT	0
16459	15267	14034U	PARTICIPANT	\N	PRESENT	0
16460	15267	14251Q	PARTICIPANT	\N	PRESENT	0
16461	15267	11067R	PARTICIPANT	\N	PRESENT	0
16462	15267	11109J	PARTICIPANT	\N	PRESENT	0
16463	15267	07029T	PARTICIPANT	\N	PRESENT	0
16464	15267	14014Q	PARTICIPANT	\N	PRESENT	0
16465	15267	11036J	PARTICIPANT	\N	PRESENT	0
17152	16779	11044J	PARTICIPANT	\N	EXCUSE	0
17153	17131	04079R	PARTICIPANT	\N	PRESENT	0
17154	17131	08044W	PARTICIPANT	\N	PRESENT	0
17155	17131	11084S	PARTICIPANT	\N	PRESENT	0
17156	17131	11026G	PARTICIPANT	\N	PRESENT	0
17157	17131	14111D	PARTICIPANT	\N	PRESENT	0
17158	17131	14001X	PARTICIPANT	\N	PRESENT	0
17159	17131	14273W	PARTICIPANT	\N	PRESENT	0
17160	17131	14147R	PARTICIPANT	\N	PRESENT	0
17161	17131	95049N	PARTICIPANT	\N	PRESENT	0
17162	17131	08051V	PARTICIPANT	\N	PRESENT	0
17163	17131	11072N	PARTICIPANT	\N	PRESENT	0
17164	17131	07034Q	PARTICIPANT	\N	PRESENT	0
17165	17131	04074L	PARTICIPANT	\N	PRESENT	0
17166	17131	10015M	PARTICIPANT	\N	PRESENT	0
17167	17131	95063L	PARTICIPANT	\N	PRESENT	0
17168	17131	01028R	PARTICIPANT	\N	PRESENT	0
17169	17131	98035U	PARTICIPANT	\N	PRESENT	0
17170	17131	04056J	PARTICIPANT	\N	PRESENT	0
17171	17131	14275Y	PARTICIPANT	\N	PRESENT	0
17172	17131	04044E	PARTICIPANT	\N	PRESENT	0
17173	17131	11037K	PARTICIPANT	\N	PRESENT	0
17174	17131	95067Q	PARTICIPANT	\N	PRESENT	0
17175	17131	01047U	PARTICIPANT	\N	PRESENT	0
17176	17131	14061L	PARTICIPANT	\N	PRESENT	0
17322	16779	14014Q	PARTICIPANT	\N	EXCUSE	0
17178	17131	14215L	PARTICIPANT	\N	PRESENT	0
17324	15591	14227Q	PARTICIPANT	\N	PRESENT	0
17187	17131	11034G	PARTICIPANT	\N	PRESENT	0
17333	17220	98053W	PARTICIPANT	\N	PRESENT	0
17335	17334	89017R	PARTICIPANT	\N	PRESENT	0
17336	17334	01031L	PRESIDENT	0	PRESENT	0
17337	17334	05004A	PARTICIPANT	\N	PRESENT	0
17338	17334	01013J	PARTICIPANT	\N	PRESENT	0
17384	17220	11040E	PARTICIPANT	\N	PRESENT	0
17385	17220	08052W	PARTICIPANT	\N	PRESENT	0
17341	17334	08014Q	PARTICIPANT	\N	PRESENT	0
17342	17334	14167V	PARTICIPANT	\N	PRESENT	0
17343	17334	14175V	PARTICIPANT	\N	PRESENT	0
17344	17334	14083S	PARTICIPANT	\N	PRESENT	0
17345	17334	11053K	PARTICIPANT	\N	PRESENT	0
17346	17334	14085U	PARTICIPANT	\N	PRESENT	0
17347	17334	11042G	PARTICIPANT	\N	PRESENT	0
17386	17220	01031L	PARTICIPANT	\N	PRESENT	0
17349	17334	04086Q	PARTICIPANT	\N	PRESENT	0
17350	17334	04055H	PARTICIPANT	\N	PRESENT	0
17351	17334	11070L	PARTICIPANT	\N	PRESENT	0
17352	17334	11088W	PARTICIPANT	\N	PRESENT	0
17353	17334	14327T	PARTICIPANT	\N	PRESENT	0
17387	17220	14197C	PARTICIPANT	\N	PRESENT	0
17355	17334	01027Q	PARTICIPANT	\N	PRESENT	0
17356	17334	04071H	PARTICIPANT	\N	PRESENT	0
17388	17220	01022K	PARTICIPANT	\N	PRESENT	0
17389	17220	11036J	PARTICIPANT	\N	PRESENT	0
17359	17334	11083R	PARTICIPANT	\N	PRESENT	0
17360	17334	14199E	PARTICIPANT	\N	PRESENT	0
17361	17334	01057W	PRESIDENT	1	PRESENT	0
17427	17220	14069U	PARTICIPANT	\N	PRESENT	0
17428	17220	11055M	PARTICIPANT	\N	PRESENT	0
17364	17334	11048N	PARTICIPANT	\N	PRESENT	0
17429	17220	14097Y	PARTICIPANT	\N	PRESENT	0
17366	17334	04061F	PARTICIPANT	\N	PRESENT	0
17430	17220	04086Q	PARTICIPANT	\N	PRESENT	0
17368	17334	07029T	PARTICIPANT	\N	PRESENT	0
17431	17220	11012A	PARTICIPANT	\N	PRESENT	0
17370	17334	08010L	PARTICIPANT	\N	PRESENT	0
17371	17334	08034U	PARTICIPANT	\N	PRESENT	0
17435	17220	11114F	PARTICIPANT	\N	PRESENT	0
17373	17334	98046X	PARTICIPANT	\N	PRESENT	0
17374	17334	11085T	PARTICIPANT	\N	PRESENT	0
17375	17334	08011M	PARTICIPANT	\N	PRESENT	0
17376	17334	08073C	PARTICIPANT	\N	PRESENT	0
17377	17334	08061X	PARTICIPANT	\N	PRESENT	0
17378	17334	01016M	PARTICIPANT	\N	EXCUSE	0
17379	17334	14225N	PARTICIPANT	\N	PRESENT	0
17380	17334	11012A	PARTICIPANT	\N	PRESENT	0
17381	17334	11057P	PARTICIPANT	\N	EXCUSE	0
17433	17220	14209N	PARTICIPANT	\N	PRESENT	0
17383	17334	04034C	PARTICIPANT	\N	PRESENT	0
17390	17220	04041B	PARTICIPANT	\N	PRESENT	0
17391	17220	14253S	PARTICIPANT	\N	PRESENT	0
17392	17220	01058X	PARTICIPANT	\N	PRESENT	0
17393	17220	98005N	PARTICIPANT	\N	PRESENT	0
17394	17220	08069G	PARTICIPANT	\N	PRESENT	0
17395	17220	95039L	PARTICIPANT	\N	PRESENT	0
17434	17220	11104D	PARTICIPANT	\N	PRESENT	0
17397	17220	14207L	PARTICIPANT	\N	PRESENT	0
17398	17220	08014Q	PARTICIPANT	\N	PRESENT	0
17399	17220	11014C	PARTICIPANT	\N	PRESENT	0
17400	17220	14327T	PARTICIPANT	\N	PRESENT	0
17401	17220	11042G	PARTICIPANT	\N	PRESENT	0
17402	17220	11072N	PARTICIPANT	\N	PRESENT	0
17403	17220	14275Y	PARTICIPANT	\N	PRESENT	0
17404	17220	11046L	PARTICIPANT	\N	PRESENT	0
17405	17220	14259Y	PARTICIPANT	\N	PRESENT	0
17406	17220	08058D	PARTICIPANT	\N	PRESENT	0
17407	17220	14039A	PARTICIPANT	\N	PRESENT	0
17408	17220	08073C	PARTICIPANT	\N	PRESENT	0
17409	17220	11109J	PARTICIPANT	\N	PRESENT	0
17438	17220	98022P	PARTICIPANT	\N	PRESENT	0
17411	17220	14273W	PARTICIPANT	\N	PRESENT	0
17412	17220	11066Q	PARTICIPANT	\N	PRESENT	0
17413	17220	04078Q	PARTICIPANT	\N	PRESENT	0
17414	17220	14103D	PARTICIPANT	\N	PRESENT	0
17415	17220	14219Q	PARTICIPANT	\N	PRESENT	0
17416	17220	11064N	PARTICIPANT	\N	PRESENT	0
17417	17220	14199E	PARTICIPANT	\N	PRESENT	0
17418	17220	11103C	PARTICIPANT	\N	PRESENT	0
17419	17220	11010L	PARTICIPANT	\N	PRESENT	0
17420	17220	11043H	PARTICIPANT	\N	PRESENT	0
17421	17220	04044E	PARTICIPANT	\N	PRESENT	0
17422	17220	08019V	PARTICIPANT	\N	PRESENT	0
17423	17220	14111D	PARTICIPANT	\N	PRESENT	0
17424	17220	01003G	PARTICIPANT	\N	PRESENT	0
17425	17220	04085P	PARTICIPANT	\N	PRESENT	0
17426	17220	01013J	PARTICIPANT	\N	PRESENT	0
17436	17220	04094Q	PARTICIPANT	\N	PRESENT	0
17437	17220	80013X	PARTICIPANT	\N	PRESENT	0
17439	17220	01046T	PARTICIPANT	\N	PRESENT	0
17440	17220	14089Y	PARTICIPANT	\N	PRESENT	0
17441	17220	04067M	PARTICIPANT	\N	PRESENT	0
17442	17220	14257W	PARTICIPANT	\N	PRESENT	0
17443	17220	14223L	PARTICIPANT	\N	PRESENT	0
17444	17220	14107H	PARTICIPANT	\N	PRESENT	0
17445	17220	14221J	PARTICIPANT	\N	PRESENT	0
17446	17220	14231L	PARTICIPANT	\N	PRESENT	0
17447	17220	12042Y	PARTICIPANT	\N	PRESENT	0
17448	17220	01059Y	PARTICIPANT	\N	PRESENT	0
15860	15266	08028W	PARTICIPANT	\N	PRESENT	0
15861	15266	04094Q	PARTICIPANT	\N	PRESENT	0
15864	15266	08068F	PARTICIPANT	\N	PRESENT	0
15865	15266	08031R	PARTICIPANT	\N	PRESENT	0
15866	15266	11094U	PARTICIPANT	\N	PRESENT	0
15867	15266	14014Q	PARTICIPANT	\N	PRESENT	0
15868	15266	98005N	PARTICIPANT	\N	PRESENT	0
15869	15266	07032N	PARTICIPANT	\N	PRESENT	0
15870	15266	11074Q	PARTICIPANT	\N	PRESENT	0
15871	15266	01027Q	PARTICIPANT	\N	PRESENT	0
15872	15266	04089T	PARTICIPANT	\N	PRESENT	0
15873	15266	14030Q	PARTICIPANT	\N	PRESENT	0
15874	15266	14081Q	PARTICIPANT	\N	PRESENT	0
15875	15266	01003G	PARTICIPANT	\N	PRESENT	0
15876	15266	90003B	PARTICIPANT	\N	PRESENT	0
15877	15266	95049N	PARTICIPANT	\N	PRESENT	0
15878	15266	08055A	PARTICIPANT	\N	PRESENT	0
15879	15266	86044G	PARTICIPANT	\N	PRESENT	0
15880	15266	04088S	PARTICIPANT	\N	PRESENT	0
15884	15266	11026G	PARTICIPANT	\N	PRESENT	0
15885	15266	14251Q	PARTICIPANT	\N	PRESENT	0
15883	15266	14197C	PARTICIPANT	\N	PRESENT	0
15886	15266	14069U	PARTICIPANT	\N	PRESENT	0
15887	15266	14037X	PARTICIPANT	\N	PRESENT	0
15888	15266	83047W	PARTICIPANT	\N	PRESENT	0
15889	15266	04049K	PARTICIPANT	\N	PRESENT	0
15893	15266	14051J	PARTICIPANT	\N	PRESENT	0
15894	15266	95041E	PARTICIPANT	\N	PRESENT	0
15895	15266	11107G	PARTICIPANT	\N	PRESENT	0
15896	15266	01008M	PARTICIPANT	\N	PRESENT	0
15898	15266	04057K	PARTICIPANT	\N	PRESENT	0
15900	15266	95035G	PARTICIPANT	\N	PRESENT	0
15905	15266	04066L	PARTICIPANT	\N	PRESENT	0
15911	15266	14059S	PARTICIPANT	\N	PRESENT	0
15930	15266	11066Q	PARTICIPANT	\N	PRESENT	0
15933	15266	08058D	PARTICIPANT	\N	PRESENT	0
16283	15266	01025N	PARTICIPANT	\N	PRESENT	0
16284	15266	14239U	PARTICIPANT	\N	PRESENT	0
16285	15266	80027E	PARTICIPANT	\N	PRESENT	0
16286	15266	14133K	PARTICIPANT	\N	PRESENT	0
16287	15266	14073Q	PARTICIPANT	\N	PRESENT	0
16288	15266	08038Y	PARTICIPANT	\N	PRESENT	0
16289	15266	14103D	PARTICIPANT	\N	PRESENT	0
16290	15266	11111C	PARTICIPANT	\N	PRESENT	0
16291	15266	14083S	PARTICIPANT	\N	PRESENT	0
16292	15266	11012A	PARTICIPANT	\N	PRESENT	0
16293	15266	11064N	PARTICIPANT	\N	PRESENT	0
16294	15266	08044W	PARTICIPANT	\N	PRESENT	0
16295	15266	11014C	PARTICIPANT	\N	PRESENT	0
16306	15266	08034U	PARTICIPANT	\N	PRESENT	0
16385	15267	10006L	PARTICIPANT	\N	PRESENT	0
16386	15267	01059Y	PARTICIPANT	\N	PRESENT	0
16387	15267	11055M	PARTICIPANT	\N	PRESENT	0
16388	15267	14089Y	PARTICIPANT	\N	PRESENT	0
16389	15267	11094U	PARTICIPANT	\N	PRESENT	0
16390	15267	01025N	PARTICIPANT	\N	PRESENT	0
16391	15267	12042Y	PARTICIPANT	\N	PRESENT	0
16392	15267	14271U	PARTICIPANT	\N	PRESENT	0
16393	15267	14281W	PARTICIPANT	\N	PRESENT	0
16394	15267	14257W	PARTICIPANT	\N	PRESENT	0
16395	15267	00003C	PARTICIPANT	\N	PRESENT	0
16396	15267	14269B	PARTICIPANT	\N	PRESENT	0
16397	15267	11031D	PARTICIPANT	\N	PRESENT	0
16398	15267	14209N	PARTICIPANT	\N	PRESENT	0
16399	15267	08019V	PARTICIPANT	\N	PRESENT	0
16400	15267	08052W	PARTICIPANT	\N	PRESENT	0
16401	15267	01046T	PARTICIPANT	\N	PRESENT	0
16402	15267	14037X	PARTICIPANT	\N	PRESENT	0
16403	15267	11044J	PARTICIPANT	\N	PRESENT	0
16404	15267	08034U	PARTICIPANT	\N	PRESENT	0
16405	15267	08015R	PARTICIPANT	\N	PRESENT	0
16406	15267	14195A	PARTICIPANT	\N	PRESENT	0
16407	15267	11043H	PARTICIPANT	\N	PRESENT	0
16408	15267	14147R	PARTICIPANT	\N	PRESENT	0
16409	15267	14133K	PARTICIPANT	\N	PRESENT	0
16410	15267	14087W	PARTICIPANT	\N	PRESENT	0
16411	15267	14069U	PARTICIPANT	\N	PRESENT	0
16412	15267	04035D	PARTICIPANT	\N	PRESENT	0
16413	15267	14239U	PARTICIPANT	\N	PRESENT	0
16414	15267	11112D	PARTICIPANT	\N	PRESENT	0
16415	15267	14265W	PARTICIPANT	\N	PRESENT	0
16416	15267	08028W	PARTICIPANT	\N	PRESENT	0
16417	15267	14071N	PARTICIPANT	\N	PRESENT	0
16418	15267	14033T	PARTICIPANT	\N	PRESENT	0
16419	15267	14079W	PARTICIPANT	\N	PRESENT	0
16420	15267	04042C	PARTICIPANT	\N	PRESENT	0
16421	15267	04088S	PARTICIPANT	\N	PRESENT	0
16422	15267	14105F	PARTICIPANT	\N	PRESENT	0
16423	15267	14215L	PARTICIPANT	\N	PRESENT	0
16424	15267	11012A	PARTICIPANT	\N	PRESENT	0
16425	15267	14018U	PARTICIPANT	\N	PRESENT	0
16426	15267	11105E	PARTICIPANT	\N	PRESENT	0
16427	15267	11061K	PARTICIPANT	\N	PRESENT	0
16428	15267	14135M	PARTICIPANT	\N	PRESENT	0
16429	15267	14267Y	PARTICIPANT	\N	PRESENT	0
16430	15267	14205J	PARTICIPANT	\N	PRESENT	0
16431	15267	04053F	PARTICIPANT	\N	PRESENT	0
16432	15267	14197C	PARTICIPANT	\N	PRESENT	0
16433	15267	14231L	PARTICIPANT	\N	PRESENT	0
16434	15267	14119M	PARTICIPANT	\N	PRESENT	0
16435	15267	08031R	PARTICIPANT	\N	PRESENT	0
16436	15267	10015M	PARTICIPANT	\N	PRESENT	0
16437	15267	14213J	PARTICIPANT	\N	PRESENT	0
16438	15267	14026U	PARTICIPANT	\N	PRESENT	0
16439	15267	14237S	PARTICIPANT	\N	PRESENT	0
16780	15862	14197C	PARTICIPANT	\N	PRESENT	0
16534	16532	04054G	PARTICIPANT	\N	PRESENT	0
16535	16532	04040A	PARTICIPANT	\N	PRESENT	0
16536	16532	08058D	PARTICIPANT	\N	PRESENT	0
16537	16532	04042C	PARTICIPANT	\N	PRESENT	0
16538	16532	77002U	PARTICIPANT	\N	PRESENT	0
16539	16532	98029W	PARTICIPANT	\N	PRESENT	0
16540	16532	11080N	PARTICIPANT	\N	PRESENT	0
16541	16532	11027H	PARTICIPANT	\N	PRESENT	0
16542	16532	98018T	PARTICIPANT	\N	PRESENT	0
16543	16532	92018S	PARTICIPANT	\N	PRESENT	0
16544	16532	92020L	PARTICIPANT	\N	EXCUSE	0
16545	16532	95030B	PARTICIPANT	\N	PRESENT	0
16781	16725	98046X	PARTICIPANT	\N	PRESENT	0
16782	15862	11069T	PARTICIPANT	\N	PRESENT	0
16783	15862	11012A	PARTICIPANT	\N	PRESENT	0
16784	15862	01022K	PARTICIPANT	\N	PRESENT	0
16550	16532	04035D	PARTICIPANT	\N	EXCUSE	0
16551	16532	07024N	PARTICIPANT	\N	EXCUSE	0
16785	15862	14079W	PARTICIPANT	\N	PRESENT	0
16553	16532	14014Q	PARTICIPANT	\N	PRESENT	0
16383	15267	11085T	PARTICIPANT	\N	PRESENT	0
16384	15267	04092N	PARTICIPANT	\N	PRESENT	0
16786	15862	95035G	PARTICIPANT	\N	PRESENT	0
16555	16532	07004J	PARTICIPANT	\N	PRESENT	0
16556	16532	95035G	PARTICIPANT	\N	PRESENT	0
16557	16532	08056B	PARTICIPANT	\N	EXCUSE	0
16558	16532	14211G	PARTICIPANT	\N	PRESENT	0
16787	15862	14271U	PARTICIPANT	\N	PRESENT	0
16560	16532	11064N	PARTICIPANT	\N	PRESENT	0
16790	15862	11088W	PARTICIPANT	\N	PRESENT	0
16562	16532	04078Q	PARTICIPANT	\N	PRESENT	0
16563	16532	14097Y	PARTICIPANT	\N	PRESENT	0
16791	16788	14239U	PARTICIPANT	\N	PRESENT	0
16565	16532	04036E	PARTICIPANT	\N	PRESENT	0
16566	16532	14039A	PARTICIPANT	\N	PRESENT	0
16567	16532	04077P	PARTICIPANT	\N	PRESENT	0
16568	16532	98005N	PARTICIPANT	\N	PRESENT	0
16569	16532	92031P	PARTICIPANT	\N	PRESENT	0
16570	16532	11106F	PARTICIPANT	\N	PRESENT	0
16572	16532	83042R	PARTICIPANT	\N	PRESENT	0
16573	16532	08053X	PARTICIPANT	\N	PRESENT	0
16574	16532	11082Q	PARTICIPANT	\N	PRESENT	0
16575	16532	11105E	PARTICIPANT	\N	PRESENT	0
16576	16532	14253S	PARTICIPANT	\N	PRESENT	0
16577	16532	08047A	PARTICIPANT	\N	PRESENT	0
16578	16532	14028W	PARTICIPANT	\N	PRESENT	0
16579	16532	14193X	PARTICIPANT	\N	PRESENT	0
16580	16532	98021N	PARTICIPANT	\N	PRESENT	0
16793	16788	01046T	PARTICIPANT	\N	PRESENT	0
16794	16788	04053F	PARTICIPANT	\N	PRESENT	0
16583	16532	95059Q	PRESIDENT	0	PRESENT	0
16584	16532	86044G	PARTICIPANT	\N	PRESENT	0
16585	16532	01014K	PARTICIPANT	\N	PRESENT	0
16586	16532	11054L	PARTICIPANT	\N	PRESENT	0
16587	16532	01056V	PARTICIPANT	\N	PRESENT	0
16588	16532	92044U	PARTICIPANT	\N	PRESENT	0
16589	16532	08049C	PARTICIPANT	\N	PRESENT	0
16795	16788	14255U	PARTICIPANT	\N	PRESENT	0
16796	16788	04066L	PARTICIPANT	\N	PRESENT	0
16797	16788	00003C	PARTICIPANT	\N	PRESENT	0
16798	16788	14053L	PARTICIPANT	\N	PRESENT	0
16799	16788	11103C	PARTICIPANT	\N	PRESENT	0
15835	15810	11083R	PARTICIPANT	\N	PRESENT	0
15836	15810	14199E	PARTICIPANT	\N	PRESENT	0
15839	15810	08069G	PARTICIPANT	\N	PRESENT	0
15841	15810	99004R	PARTICIPANT	\N	PRESENT	0
15842	15810	04061F	PARTICIPANT	\N	PRESENT	0
15843	15810	14159V	PARTICIPANT	\N	PRESENT	0
15844	15810	07029T	PARTICIPANT	\N	PRESENT	0
15846	15810	08010L	PARTICIPANT	\N	EXCUSE	0
15847	15810	08034U	PARTICIPANT	\N	PRESENT	0
15849	15810	98046X	PARTICIPANT	\N	PRESENT	0
15851	15810	08011M	PARTICIPANT	\N	PRESENT	0
15854	15810	01016M	PARTICIPANT	\N	EXCUSE	0
15856	15810	11012A	PARTICIPANT	\N	PRESENT	0
15857	15810	11057P	PARTICIPANT	\N	PRESENT	0
15859	15810	04034C	PARTICIPANT	\N	PRESENT	0
18402	18363	04044E	PARTICIPANT	\N	EXCUSE	0
19296	18404	14069U	PARTICIPANT	\N	PRESENT	0
19297	18404	96004D	PARTICIPANT	\N	PRESENT	0
19298	18404	01019Q	PARTICIPANT	\N	PRESENT	0
19299	18404	11060J	PARTICIPANT	\N	PRESENT	0
19300	18404	04036E	PARTICIPANT	\N	PRESENT	0
19301	18404	01027Q	PARTICIPANT	\N	PRESENT	0
19302	18404	08039A	PARTICIPANT	\N	PRESENT	0
19303	18404	95030B	PARTICIPANT	\N	PRESENT	0
19304	18404	98024R	PARTICIPANT	\N	PRESENT	0
19305	18404	95031C	PARTICIPANT	\N	PRESENT	0
19345	18404	04047H	PARTICIPANT	\N	PRESENT	0
19346	18404	90003B	PARTICIPANT	\N	PRESENT	0
19308	18404	08011M	PARTICIPANT	\N	PRESENT	0
19309	18404	95015C	PARTICIPANT	\N	PRESENT	0
19310	18404	01058X	PARTICIPANT	\N	PRESENT	0
19311	18404	14026U	PARTICIPANT	\N	PRESENT	0
19312	18404	92045V	PARTICIPANT	\N	PRESENT	0
19313	18404	14213J	PARTICIPANT	\N	PRESENT	0
19314	18404	04044E	PARTICIPANT	\N	PRESENT	0
19315	18404	08062Y	PARTICIPANT	\N	PRESENT	0
19316	18404	08022Q	PARTICIPANT	\N	PRESENT	0
19317	18404	07029T	PARTICIPANT	\N	PRESENT	0
19318	18404	14217N	PARTICIPANT	\N	PRESENT	0
19319	18404	95041E	PARTICIPANT	\N	PRESENT	0
19320	18404	14079W	PARTICIPANT	\N	PRESENT	0
19321	18404	04071H	PARTICIPANT	\N	PRESENT	0
19322	18404	11091R	PARTICIPANT	\N	PRESENT	0
19323	18404	87003B	PARTICIPANT	\N	PRESENT	0
19324	18404	08034U	PARTICIPANT	\N	PRESENT	0
19325	18404	14059S	PARTICIPANT	\N	PRESENT	0
19326	18404	14249W	PARTICIPANT	\N	PRESENT	0
19327	18404	14105F	PARTICIPANT	\N	PRESENT	0
19328	18404	14175V	PARTICIPANT	\N	PRESENT	0
19329	18404	14253S	PARTICIPANT	\N	PRESENT	0
19330	18404	11101A	PARTICIPANT	\N	PRESENT	0
19331	18404	01057W	PARTICIPANT	\N	PRESENT	0
19332	18404	14111D	PARTICIPANT	\N	PRESENT	0
19333	18404	11048N	PARTICIPANT	\N	PRESENT	0
19334	18404	08069G	PARTICIPANT	\N	PRESENT	0
19335	18404	04048J	PARTICIPANT	\N	PRESENT	0
19336	18404	14123H	PARTICIPANT	\N	PRESENT	0
19337	18404	08028W	PARTICIPANT	\N	PRESENT	0
19338	18404	01061S	PARTICIPANT	\N	PRESENT	0
19339	18404	92040Q	PARTICIPANT	\N	PRESENT	0
19340	18404	11088W	PARTICIPANT	\N	PRESENT	0
19387	18404	98050T	PARTICIPANT	\N	PRESENT	0
19342	18404	04088S	PARTICIPANT	\N	PRESENT	0
19343	18404	14199E	PARTICIPANT	\N	PRESENT	0
19344	18404	77002U	PARTICIPANT	\N	PRESENT	0
19347	18404	04042C	PARTICIPANT	\N	PRESENT	0
19348	18404	14119M	PARTICIPANT	\N	PRESENT	0
19349	18404	14071N	PARTICIPANT	\N	PRESENT	0
19350	18404	14033T	PARTICIPANT	\N	PRESENT	0
19351	18404	10006L	PARTICIPANT	\N	PRESENT	0
19352	18404	14135M	PARTICIPANT	\N	PRESENT	0
19723	18405	86034E	PARTICIPANT	\N	PRESENT	0
19354	18404	98023Q	PARTICIPANT	\N	PRESENT	0
19355	18404	14223L	PARTICIPANT	\N	PRESENT	0
19356	18404	11040E	PARTICIPANT	\N	PRESENT	0
19357	18404	14209N	PARTICIPANT	\N	PRESENT	0
19358	18404	11020A	PARTICIPANT	\N	PRESENT	0
19359	18404	04061F	PARTICIPANT	\N	PRESENT	0
19360	18404	14061L	PARTICIPANT	\N	PRESENT	0
19361	18404	10015M	PARTICIPANT	\N	PRESENT	0
19362	18404	86034E	PARTICIPANT	\N	PRESENT	0
19363	18404	04049K	PARTICIPANT	\N	PRESENT	0
19364	18404	14093U	PARTICIPANT	\N	PRESENT	0
19365	18404	08010L	PARTICIPANT	\N	PRESENT	0
19366	18404	14265W	PARTICIPANT	\N	PRESENT	0
19367	18404	92031P	PARTICIPANT	\N	PRESENT	0
19368	18404	01048V	PARTICIPANT	\N	PRESENT	0
19369	18404	11100Y	PARTICIPANT	\N	PRESENT	0
19370	18404	14031R	PARTICIPANT	\N	PRESENT	0
19371	18404	11090Q	PARTICIPANT	\N	PRESENT	0
19372	18404	04057K	PARTICIPANT	\N	PRESENT	0
19373	18404	04081K	PARTICIPANT	\N	PRESENT	0
19374	18404	04092N	PARTICIPANT	\N	PRESENT	0
19375	18404	11103C	PARTICIPANT	\N	PRESENT	0
19376	18404	14087W	PARTICIPANT	\N	PRESENT	0
19377	18404	02002K	PARTICIPANT	\N	PRESENT	0
19378	18404	97011G	PARTICIPANT	\N	PRESENT	0
19379	18404	14053L	PARTICIPANT	\N	PRESENT	0
19380	18404	05012A	PARTICIPANT	\N	PRESENT	0
19381	18404	98021N	PARTICIPANT	\N	PRESENT	0
19382	18404	11049P	PARTICIPANT	\N	PRESENT	0
19383	18404	95059Q	PARTICIPANT	\N	PRESENT	0
19384	18404	04043D	PARTICIPANT	\N	PRESENT	0
19385	18404	14133K	PARTICIPANT	\N	PRESENT	0
19386	18404	86044G	PARTICIPANT	\N	PRESENT	0
19388	18404	04074L	PARTICIPANT	\N	PRESENT	0
19389	18404	14237S	PARTICIPANT	\N	PRESENT	0
19402	18404	11061K	PARTICIPANT	\N	PRESENT	0
19391	18404	14191V	PARTICIPANT	\N	PRESENT	0
19392	18404	14147R	PARTICIPANT	\N	PRESENT	0
19393	18404	08047A	PARTICIPANT	\N	PRESENT	0
19394	18404	95035G	PARTICIPANT	\N	PRESENT	0
19395	18404	07034Q	PARTICIPANT	\N	PRESENT	0
19396	18404	14017T	PARTICIPANT	\N	PRESENT	0
19397	18404	11071M	PARTICIPANT	\N	PRESENT	0
19398	18404	11043H	PARTICIPANT	\N	PRESENT	0
19399	18404	14157T	PARTICIPANT	\N	PRESENT	0
19400	18404	98053W	PARTICIPANT	\N	PRESENT	0
19401	18404	14193X	PARTICIPANT	\N	PRESENT	0
19403	18404	14225N	PARTICIPANT	\N	PRESENT	0
19404	18404	14195A	PARTICIPANT	\N	PRESENT	0
19405	18404	89017R	PARTICIPANT	\N	PRESENT	0
19406	18404	05008E	PARTICIPANT	\N	PRESENT	0
19407	18404	01056V	PARTICIPANT	\N	PRESENT	0
19408	18404	11085T	PARTICIPANT	\N	PRESENT	0
19409	18404	07032N	PARTICIPANT	\N	PRESENT	0
19410	18404	95067Q	PARTICIPANT	\N	PRESENT	0
19411	18404	11042G	PARTICIPANT	\N	PRESENT	0
19412	18404	01037S	PARTICIPANT	\N	PRESENT	0
19413	18404	14201E	PARTICIPANT	\N	PRESENT	0
19414	18404	08049C	PARTICIPANT	\N	PRESENT	0
19415	18404	01031L	PARTICIPANT	\N	PRESENT	0
19416	18404	07024N	PARTICIPANT	\N	PRESENT	0
19417	18404	92018S	PARTICIPANT	\N	PRESENT	0
19418	18404	14055N	PARTICIPANT	\N	PRESENT	0
19724	18405	08016S	PARTICIPANT	\N	PRESENT	0
19294	18404	98018T	PARTICIPANT	\N	PRESENT	0
19295	18404	14173T	PARTICIPANT	\N	PRESENT	0
19725	18405	11099A	PARTICIPANT	\N	PRESENT	0
19726	18405	14247U	PARTICIPANT	\N	PRESENT	0
19727	18405	08051V	PARTICIPANT	\N	PRESENT	0
19728	18405	11100Y	PARTICIPANT	\N	PRESENT	0
19730	18405	08014Q	PARTICIPANT	\N	PRESENT	0
19731	18405	14207L	PARTICIPANT	\N	PRESENT	0
19732	18405	14257W	PARTICIPANT	\N	PRESENT	0
19734	18405	00003C	PARTICIPANT	\N	PRESENT	0
19735	18405	08055A	PARTICIPANT	\N	PRESENT	0
19736	18405	11068S	PARTICIPANT	\N	PRESENT	0
19764	18405	11111C	PARTICIPANT	\N	PRESENT	0
19738	18405	14085U	PARTICIPANT	\N	PRESENT	0
19739	18405	14219Q	PARTICIPANT	\N	PRESENT	0
19741	18405	01008M	PARTICIPANT	\N	PRESENT	0
19742	18405	98050T	PARTICIPANT	\N	PRESENT	0
19743	18405	14187A	PARTICIPANT	\N	PRESENT	0
19744	18405	14061L	PARTICIPANT	\N	PRESENT	0
19765	18405	14083S	PARTICIPANT	\N	PRESENT	0
19746	18405	14159V	PARTICIPANT	\N	PRESENT	0
19747	18405	12042Y	PARTICIPANT	\N	PRESENT	0
19748	18405	14063N	PARTICIPANT	\N	PRESENT	0
19749	18405	14121F	PARTICIPANT	\N	PRESENT	0
19750	18405	14227Q	PARTICIPANT	\N	PRESENT	0
19752	18405	98046X	PARTICIPANT	\N	PRESENT	0
19753	18405	01022K	PARTICIPANT	\N	PRESENT	0
19754	18405	14263U	PARTICIPANT	\N	PRESENT	0
19755	18405	14103D	PARTICIPANT	\N	PRESENT	0
19756	18405	14205J	PARTICIPANT	\N	PRESENT	0
19757	18405	08060W	PARTICIPANT	\N	PRESENT	0
19758	18405	01031L	PARTICIPANT	\N	PRESENT	0
19759	18405	11095V	PARTICIPANT	\N	PRESENT	0
19760	18405	14051J	PARTICIPANT	\N	PRESENT	0
19761	18405	14109K	PARTICIPANT	\N	PRESENT	0
19762	18405	14107H	PARTICIPANT	\N	PRESENT	0
19763	18405	14030Q	PARTICIPANT	\N	PRESENT	0
19766	18405	04089T	PARTICIPANT	\N	PRESENT	0
19767	18405	04057K	PARTICIPANT	\N	PRESENT	0
19768	18405	05012A	PARTICIPANT	\N	PRESENT	0
19769	18405	14069U	PARTICIPANT	\N	PRESENT	0
19771	18405	96004D	PARTICIPANT	\N	PRESENT	0
17852	17832	04049K	PARTICIPANT	\N	PRESENT	0
17854	17832	04055H	PARTICIPANT	\N	PRESENT	0
17856	17832	08068F	PARTICIPANT	\N	PRESENT	0
17858	17832	14013P	PARTICIPANT	\N	PRESENT	0
17860	17832	11063M	PARTICIPANT	\N	PRESENT	0
17862	17832	14207L	PARTICIPANT	\N	PRESENT	0
17865	17832	14265W	PARTICIPANT	\N	PRESENT	0
17867	17832	14087W	PARTICIPANT	\N	PRESENT	0
17869	17832	14253S	PARTICIPANT	\N	PRESENT	0
17870	17832	01043Q	PARTICIPANT	\N	PRESENT	0
17871	17832	14061L	PARTICIPANT	\N	PRESENT	0
17872	17832	14255U	PARTICIPANT	\N	PRESENT	0
17873	17832	14030Q	PARTICIPANT	\N	PRESENT	0
17874	17832	04053F	PARTICIPANT	\N	PRESENT	0
17876	17832	14151M	PARTICIPANT	\N	PRESENT	0
17877	17832	08055A	PARTICIPANT	\N	PRESENT	0
17878	17832	14157T	PARTICIPANT	\N	PRESENT	0
17879	17832	95041E	PARTICIPANT	\N	PRESENT	0
17880	17832	95067Q	PARTICIPANT	\N	PRESENT	0
17884	17832	11100Y	PARTICIPANT	\N	PRESENT	0
17885	17832	04070G	PARTICIPANT	\N	PRESENT	0
17886	17832	11066Q	PARTICIPANT	\N	PRESENT	0
17887	17832	14197C	PARTICIPANT	\N	PRESENT	0
17888	17832	14033T	PARTICIPANT	\N	PRESENT	0
17889	17832	14187A	PARTICIPANT	\N	PRESENT	0
17890	17832	04088S	PARTICIPANT	\N	PRESENT	0
17893	17832	08015R	PARTICIPANT	\N	PRESENT	0
17895	17832	14195A	PARTICIPANT	\N	PRESENT	0
17896	17832	14231L	PARTICIPANT	\N	PRESENT	0
17898	17832	11046L	PARTICIPANT	\N	PRESENT	0
17899	17832	11036J	PARTICIPANT	\N	PRESENT	0
17902	17832	14257W	PARTICIPANT	\N	PRESENT	0
17904	17832	86034E	PARTICIPANT	\N	PRESENT	0
17905	17832	04033B	PARTICIPANT	\N	PRESENT	0
17906	17832	80013X	PARTICIPANT	\N	PRESENT	0
17907	17832	11110B	PARTICIPANT	\N	PRESENT	0
17915	17832	89017R	PARTICIPANT	\N	EXCUSE	0
17916	17832	14065Q	PARTICIPANT	\N	EXCUSE	0
17917	17832	08014Q	PARTICIPANT	\N	EXCUSE	0
17918	17832	14105F	PARTICIPANT	\N	EXCUSE	0
17920	17832	14079W	PARTICIPANT	\N	EXCUSE	0
17922	17832	11088W	PARTICIPANT	\N	EXCUSE	0
17923	17832	14041T	PARTICIPANT	\N	EXCUSE	0
17924	17832	04071H	PARTICIPANT	\N	EXCUSE	0
17925	17832	02002K	PARTICIPANT	\N	EXCUSE	0
17926	17832	14121F	PARTICIPANT	\N	EXCUSE	0
17927	17832	14018U	PARTICIPANT	\N	EXCUSE	0
17928	17832	11069T	PARTICIPANT	\N	EXCUSE	0
17929	17832	11090Q	PARTICIPANT	\N	EXCUSE	0
17930	17832	10015M	PARTICIPANT	\N	EXCUSE	0
17936	17832	14039A	PARTICIPANT	\N	EXCUSE	0
17945	17832	14034U	PARTICIPANT	\N	EXCUSE	0
18383	18382	04066L	PARTICIPANT	\N	PRESENT	0
18384	18382	07026Q	PARTICIPANT	\N	PRESENT	0
18385	18382	08039A	PARTICIPANT	\N	PRESENT	0
18386	18382	11070L	PARTICIPANT	\N	PRESENT	0
18387	18382	08012N	PARTICIPANT	\N	PRESENT	0
18388	18382	11029K	PARTICIPANT	\N	PRESENT	0
18389	18382	04085P	PARTICIPANT	\N	PRESENT	0
18390	18382	04070G	PARTICIPANT	\N	PRESENT	0
18391	18382	01003G	PARTICIPANT	\N	PRESENT	0
18392	18382	14201E	PARTICIPANT	\N	PRESENT	0
18393	18382	04048J	PARTICIPANT	\N	PRESENT	0
18394	18382	01044R	PARTICIPANT	\N	PRESENT	0
18395	18382	14041T	PARTICIPANT	\N	PRESENT	0
18396	18382	04057K	PARTICIPANT	\N	PRESENT	0
18397	18382	01041N	PARTICIPANT	\N	PRESENT	0
18398	18382	11110B	PARTICIPANT	\N	PRESENT	0
18399	18382	14111D	PARTICIPANT	\N	PRESENT	0
19772	18405	08039A	PARTICIPANT	\N	PRESENT	0
19773	18405	04097T	PARTICIPANT	\N	PRESENT	0
19839	18405	14157T	PARTICIPANT	\N	PRESENT	0
19775	18405	87003B	PARTICIPANT	\N	PRESENT	0
19776	18405	90003B	PARTICIPANT	\N	PRESENT	0
19777	18405	14013P	PARTICIPANT	\N	PRESENT	0
19778	18405	11098Y	PARTICIPANT	\N	PRESENT	0
19779	18405	04049K	PARTICIPANT	\N	PRESENT	0
19780	18405	14147R	PARTICIPANT	\N	PRESENT	0
19781	18405	08047A	PARTICIPANT	\N	PRESENT	0
19782	18405	14265W	PARTICIPANT	\N	PRESENT	0
19783	18405	11091R	PARTICIPANT	\N	PRESENT	0
19784	18405	14093U	PARTICIPANT	\N	PRESENT	0
19785	18405	07032N	PARTICIPANT	\N	PRESENT	0
19786	18405	07029T	PARTICIPANT	\N	PRESENT	0
19787	18405	04088S	PARTICIPANT	\N	PRESENT	0
19788	18405	14033T	PARTICIPANT	\N	PRESENT	0
19789	18405	14105F	PARTICIPANT	\N	PRESENT	0
19840	18405	14087W	PARTICIPANT	\N	PRESENT	0
19791	18405	11101A	PARTICIPANT	\N	PRESENT	0
19792	18405	14031R	PARTICIPANT	\N	PRESENT	0
19793	18405	01043Q	PARTICIPANT	\N	PRESENT	0
19794	18405	11107G	PARTICIPANT	\N	PRESENT	0
19795	18405	11042G	PARTICIPANT	\N	PRESENT	0
19796	18405	11061K	PARTICIPANT	\N	PRESENT	0
19797	18405	11012A	PARTICIPANT	\N	PRESENT	0
19798	18405	01003G	PARTICIPANT	\N	PRESENT	0
19799	18405	14014Q	PARTICIPANT	\N	PRESENT	0
19800	18405	01028R	PARTICIPANT	\N	PRESENT	0
19801	18405	14271U	PARTICIPANT	\N	PRESENT	0
19838	18405	95015C	PARTICIPANT	\N	PRESENT	0
19803	18405	14042U	PARTICIPANT	\N	PRESENT	0
19804	18405	14195A	PARTICIPANT	\N	PRESENT	0
19805	18405	14135M	PARTICIPANT	\N	PRESENT	0
19806	18405	14037X	PARTICIPANT	\N	PRESENT	0
19807	18405	08043V	PARTICIPANT	\N	PRESENT	0
19808	18405	04045F	PARTICIPANT	\N	PRESENT	0
19809	18405	14089Y	PARTICIPANT	\N	PRESENT	0
19810	18405	14237S	PARTICIPANT	\N	PRESENT	0
19837	18405	08052W	PARTICIPANT	\N	PRESENT	0
19812	18405	14235Q	PARTICIPANT	\N	PRESENT	0
19813	18405	14026U	PARTICIPANT	\N	PRESENT	0
19814	18405	14327T	PARTICIPANT	\N	PRESENT	0
19815	18405	11081P	PARTICIPANT	\N	PRESENT	0
19816	18405	08049C	PARTICIPANT	\N	PRESENT	0
19817	18405	14281W	PARTICIPANT	\N	PRESENT	0
19818	18405	08069G	PARTICIPANT	\N	PRESENT	0
19819	18405	01058X	PARTICIPANT	\N	PRESENT	0
19820	18405	08068F	PARTICIPANT	\N	PRESENT	0
19821	18405	14231L	PARTICIPANT	\N	PRESENT	0
19822	18405	04033B	PARTICIPANT	\N	PRESENT	0
19823	18405	08028W	PARTICIPANT	\N	PRESENT	0
19824	18405	11036J	PARTICIPANT	\N	PRESENT	0
19825	18405	08056B	PARTICIPANT	\N	PRESENT	0
19826	18405	01025N	PARTICIPANT	\N	PRESENT	0
19841	18405	14197C	PARTICIPANT	\N	PRESENT	0
19828	18405	11059R	PARTICIPANT	\N	PRESENT	0
19829	18405	14267Y	PARTICIPANT	\N	PRESENT	0
19830	18405	14034U	PARTICIPANT	\N	PRESENT	0
19831	18405	14225N	PARTICIPANT	\N	PRESENT	0
19832	18405	92039X	PARTICIPANT	\N	PRESENT	0
19833	18405	14211G	PARTICIPANT	\N	PRESENT	0
19834	18405	14055N	PARTICIPANT	\N	PRESENT	0
19835	18405	11048N	PARTICIPANT	\N	PRESENT	0
19836	18405	14213J	PARTICIPANT	\N	PRESENT	0
19842	18405	11069T	PARTICIPANT	\N	PRESENT	0
19843	18405	11110B	PARTICIPANT	\N	PRESENT	0
19844	18405	01007L	PARTICIPANT	\N	PRESENT	0
19845	18405	11084S	PARTICIPANT	\N	PRESENT	0
19846	18405	14217N	PARTICIPANT	\N	PRESENT	0
19847	18405	08062Y	PARTICIPANT	\N	PRESENT	0
19848	18405	86044G	PARTICIPANT	\N	PRESENT	0
19849	18404	14273W	PARTICIPANT	\N	PRESENT	0
19850	18405	11071M	PARTICIPANT	\N	PRESENT	0
19855	18405	14241N	PARTICIPANT	\N	PRESENT	0
19852	18404	08042U	PARTICIPANT	\N	PRESENT	0
19853	18405	11094U	PARTICIPANT	\N	PRESENT	0
19854	18405	08041T	PARTICIPANT	\N	PRESENT	0
19856	18405	14199E	PARTICIPANT	\N	PRESENT	0
18441	18403	08021P	PARTICIPANT	\N	PRESENT	0
17559	17557	14133K	PARTICIPANT	\N	PRESENT	0
17560	17557	11109J	PARTICIPANT	\N	PRESENT	0
17561	17557	04059M	PARTICIPANT	\N	PRESENT	0
17562	17557	11039M	PARTICIPANT	\N	PRESENT	0
17563	17557	01044R	PARTICIPANT	\N	PRESENT	0
17564	17557	08043V	PARTICIPANT	\N	EXCUSE	0
17565	17557	14089Y	PARTICIPANT	\N	PRESENT	0
18445	18403	14277B	PARTICIPANT	\N	PRESENT	0
17567	17557	11029K	PARTICIPANT	\N	PRESENT	0
18446	18403	14219Q	PARTICIPANT	\N	PRESENT	0
17569	17557	92015P	PARTICIPANT	\N	EXCUSE	0
17570	17557	08024S	PARTICIPANT	\N	PRESENT	0
17571	17557	14201E	PARTICIPANT	\N	EXCUSE	0
17572	17557	14209N	PARTICIPANT	\N	PRESENT	0
17573	17557	14079W	PARTICIPANT	\N	PRESENT	0
17574	17557	11091R	PARTICIPANT	\N	PRESENT	0
18444	18403	08052W	PARTICIPANT	\N	PRESENT	0
18447	18403	14055N	PARTICIPANT	\N	PRESENT	0
17577	17557	14249W	PARTICIPANT	\N	EXCUSE	0
18448	18403	14267Y	PARTICIPANT	\N	PRESENT	0
18449	18403	07034Q	PARTICIPANT	\N	PRESENT	0
18450	18403	90003B	PARTICIPANT	\N	PRESENT	0
18451	18403	11103C	PARTICIPANT	\N	PRESENT	0
17582	17557	08035V	PARTICIPANT	\N	PRESENT	0
17583	17557	11089X	PARTICIPANT	\N	PRESENT	0
17584	17557	07026Q	PARTICIPANT	\N	PRESENT	0
17585	17557	14123H	PARTICIPANT	\N	PRESENT	0
18452	18403	01025N	PARTICIPANT	\N	PRESENT	0
17587	17557	04041B	PARTICIPANT	\N	PRESENT	0
17588	17557	14241N	PARTICIPANT	\N	PRESENT	0
17589	17557	14061L	PARTICIPANT	\N	PRESENT	0
17590	17557	14073Q	PARTICIPANT	\N	EXCUSE	0
17591	17557	08031R	PARTICIPANT	\N	PRESENT	0
18453	18403	11033F	PARTICIPANT	\N	PRESENT	0
17593	17557	08039A	PARTICIPANT	\N	EXCUSE	0
17594	17557	08017T	PARTICIPANT	\N	PRESENT	0
18454	18403	87003B	PARTICIPANT	\N	PRESENT	0
18455	18403	14211G	PARTICIPANT	\N	PRESENT	0
17597	17557	14103D	PARTICIPANT	\N	PRESENT	0
17598	17557	11104D	PARTICIPANT	\N	PRESENT	0
17599	17557	14063N	PARTICIPANT	\N	PRESENT	0
17600	17557	04057K	PARTICIPANT	\N	EXCUSE	0
17601	17557	11014C	PARTICIPANT	\N	PRESENT	0
17602	17557	14109K	PARTICIPANT	\N	EXCUSE	0
17603	17557	04070G	PRESIDENT	0	PRESENT	0
18456	18403	14191V	PARTICIPANT	\N	PRESENT	0
17605	17557	14191V	PARTICIPANT	\N	PRESENT	0
18457	18403	14223L	PARTICIPANT	\N	PRESENT	0
17607	17557	14235Q	PARTICIPANT	\N	PRESENT	0
18458	18403	04074L	PARTICIPANT	\N	PRESENT	0
17609	17557	04033B	PARTICIPANT	\N	PRESENT	0
17610	17557	14229S	PARTICIPANT	\N	PRESENT	0
17611	17557	11043H	PARTICIPANT	\N	PRESENT	0
18459	18403	14105F	PARTICIPANT	\N	PRESENT	0
17613	17557	92045V	PARTICIPANT	\N	PRESENT	0
18460	18403	11030C	PARTICIPANT	\N	PRESENT	0
18461	18403	01061S	PARTICIPANT	\N	PRESENT	0
18462	18403	14033T	PARTICIPANT	\N	PRESENT	0
18463	18403	08034U	PARTICIPANT	\N	PRESENT	0
18464	18403	14275Y	PARTICIPANT	\N	PRESENT	0
18465	18403	14209N	PARTICIPANT	\N	PRESENT	0
18466	18403	04038G	PARTICIPANT	\N	PRESENT	0
18467	18403	95031C	PARTICIPANT	\N	PRESENT	0
18468	18403	14061L	PARTICIPANT	\N	PRESENT	0
18469	18403	11101A	PARTICIPANT	\N	PRESENT	0
18470	18403	11066Q	PARTICIPANT	\N	PRESENT	0
18471	18403	14221J	PARTICIPANT	\N	PRESENT	0
18472	18403	14081Q	PARTICIPANT	\N	PRESENT	0
18473	18403	00003C	PARTICIPANT	\N	PRESENT	0
18474	18403	11064N	PARTICIPANT	\N	PRESENT	0
18475	18403	14237S	PARTICIPANT	\N	PRESENT	0
18476	18403	11080N	PARTICIPANT	\N	PRESENT	0
18477	18403	14239U	PARTICIPANT	\N	PRESENT	0
18478	18403	01022K	PARTICIPANT	\N	PRESENT	0
18479	18403	14030Q	PARTICIPANT	\N	PRESENT	0
18480	18403	01019Q	PARTICIPANT	\N	PRESENT	0
18481	18403	14042U	PARTICIPANT	\N	PRESENT	0
18482	18403	04081K	PARTICIPANT	\N	PRESENT	0
18483	18403	11100Y	PARTICIPANT	\N	PRESENT	0
18484	18403	14231L	PARTICIPANT	\N	PRESENT	0
18485	18403	01046T	PARTICIPANT	\N	PRESENT	0
18486	18403	11042G	PARTICIPANT	\N	PRESENT	0
18487	18403	11031D	PARTICIPANT	\N	PRESENT	0
18488	18403	04066L	PARTICIPANT	\N	PRESENT	0
18489	18403	14069U	PARTICIPANT	\N	PRESENT	0
18490	18403	04097T	PARTICIPANT	\N	PRESENT	0
18491	18403	01056V	PARTICIPANT	\N	PRESENT	0
18492	18403	98035U	PARTICIPANT	\N	PRESENT	0
18493	18403	13002U	PARTICIPANT	\N	PRESENT	0
18494	18403	11059R	PARTICIPANT	\N	PRESENT	0
18495	18403	14051J	PARTICIPANT	\N	PRESENT	0
18496	18403	08055A	PARTICIPANT	\N	PRESENT	0
18497	18403	95015C	PARTICIPANT	\N	PRESENT	0
18498	18403	08028W	PARTICIPANT	\N	PRESENT	0
18499	18403	14227Q	PARTICIPANT	\N	PRESENT	0
18500	18403	08014Q	PARTICIPANT	\N	PRESENT	0
18501	18403	14059S	PARTICIPANT	\N	PRESENT	0
18503	18403	14253S	PARTICIPANT	\N	PRESENT	0
18504	18403	89029V	PARTICIPANT	\N	PRESENT	0
18505	18403	04080J	PARTICIPANT	\N	PRESENT	0
18506	18403	14265W	PARTICIPANT	\N	PRESENT	0
18507	18403	14195A	PARTICIPANT	\N	PRESENT	0
18508	18403	14147R	PARTICIPANT	\N	PRESENT	0
18509	18403	14087W	PARTICIPANT	\N	PRESENT	0
18511	18403	14053L	PARTICIPANT	\N	PRESENT	0
18512	18403	98023Q	PARTICIPANT	\N	PRESENT	0
18513	18403	07029T	PARTICIPANT	\N	PRESENT	0
18514	18403	07032N	PARTICIPANT	\N	PRESENT	0
18515	18403	14041T	PARTICIPANT	\N	PRESENT	0
18516	18403	77002U	PARTICIPANT	\N	PRESENT	0
18518	18403	05008E	PARTICIPANT	\N	PRESENT	0
18519	18403	14193X	PARTICIPANT	\N	PRESENT	0
18520	18403	92044U	PARTICIPANT	\N	PRESENT	0
18521	18403	04055H	PARTICIPANT	\N	PRESENT	0
18522	18403	08065C	PARTICIPANT	\N	PRESENT	0
18523	18403	14123H	PARTICIPANT	\N	PRESENT	0
18524	18403	11020A	PARTICIPANT	\N	PRESENT	0
18525	18403	14249W	PARTICIPANT	\N	PRESENT	0
18526	18403	08042U	PARTICIPANT	\N	PRESENT	0
18527	18403	14255U	PARTICIPANT	\N	PRESENT	0
18528	18403	08009T	PARTICIPANT	\N	PRESENT	0
18530	18403	14073Q	PARTICIPANT	\N	PRESENT	0
18531	18403	11053K	PARTICIPANT	\N	PRESENT	0
18533	18403	14083S	PARTICIPANT	\N	PRESENT	0
18534	18403	14103D	PARTICIPANT	\N	PRESENT	0
18535	18403	01034P	PARTICIPANT	\N	PRESENT	0
18537	18403	04056J	PARTICIPANT	\N	PRESENT	0
18574	18403	11040E	PARTICIPANT	\N	PRESENT	0
18575	18403	04085P	PARTICIPANT	\N	PRESENT	0
18577	18403	07026Q	PARTICIPANT	\N	PRESENT	0
18579	18403	01059Y	PARTICIPANT	\N	PRESENT	0
18583	18403	01015L	PARTICIPANT	\N	PRESENT	0
18585	18403	01013J	PARTICIPANT	\N	PRESENT	0
18586	18403	12041X	PARTICIPANT	\N	PRESENT	0
18587	18403	95030B	PARTICIPANT	\N	PRESENT	0
18588	18403	14263U	PARTICIPANT	\N	PRESENT	0
18589	18403	04054G	PARTICIPANT	\N	PRESENT	0
18590	18403	14017T	PARTICIPANT	\N	PRESENT	0
18591	18403	11056N	PARTICIPANT	\N	PRESENT	0
18592	18403	11034G	PARTICIPANT	\N	PRESENT	0
18593	18403	14013P	PARTICIPANT	\N	PRESENT	0
18594	18403	11063M	PARTICIPANT	\N	PRESENT	0
18595	18403	14235Q	PARTICIPANT	\N	PRESENT	0
18596	18403	14271U	PARTICIPANT	\N	PRESENT	0
18597	18403	11098Y	PARTICIPANT	\N	PRESENT	0
18598	18403	14038Y	PARTICIPANT	\N	PRESENT	0
18599	18403	11054L	PARTICIPANT	\N	PRESENT	0
18600	18403	83047W	PARTICIPANT	\N	PRESENT	0
18601	18403	14151M	PARTICIPANT	\N	PRESENT	0
18602	18403	05004A	PARTICIPANT	\N	PRESENT	0
18603	18403	11089X	PARTICIPANT	\N	PRESENT	0
18604	18403	04094Q	PARTICIPANT	\N	PRESENT	0
18605	18403	14197C	PARTICIPANT	\N	PRESENT	0
18606	18403	11036J	PARTICIPANT	\N	PRESENT	0
18607	18403	01043Q	PARTICIPANT	\N	PRESENT	0
18608	18403	14028W	PARTICIPANT	\N	PRESENT	0
18609	18403	92040Q	PARTICIPANT	\N	PRESENT	0
18610	18403	01011G	PARTICIPANT	\N	PRESENT	0
18611	18403	08016S	PARTICIPANT	\N	PRESENT	0
18612	18403	86044G	PARTICIPANT	\N	PRESENT	0
18613	18403	98046X	PARTICIPANT	\N	PRESENT	0
18614	18403	08053X	PARTICIPANT	\N	PRESENT	0
18615	18403	14107H	PARTICIPANT	\N	PRESENT	0
18616	18403	14111D	PARTICIPANT	\N	PRESENT	0
18618	18403	14187A	PARTICIPANT	\N	PRESENT	0
18619	18403	11046L	PARTICIPANT	\N	PRESENT	0
17504	17223	14097Y	PARTICIPANT	\N	PRESENT	0
17505	17223	01022K	PARTICIPANT	\N	PRESENT	0
17506	17223	14107H	PARTICIPANT	\N	PRESENT	0
17507	17223	80013X	PARTICIPANT	\N	PRESENT	0
17508	17223	08052W	PARTICIPANT	\N	PRESENT	0
17509	17223	14281W	PARTICIPANT	\N	PRESENT	0
17510	17223	10006L	PARTICIPANT	\N	PRESENT	0
17511	17223	04092N	PARTICIPANT	\N	PRESENT	0
17512	17223	14223L	PARTICIPANT	\N	PRESENT	0
17513	17223	14251Q	PARTICIPANT	\N	PRESENT	0
17514	17223	12042Y	PARTICIPANT	\N	PRESENT	0
17515	17223	98005N	PARTICIPANT	\N	PRESENT	0
17516	17223	11103C	PARTICIPANT	\N	PRESENT	0
17517	17223	14271U	PARTICIPANT	\N	PRESENT	0
17518	17223	11055M	PARTICIPANT	\N	PRESENT	0
17519	17223	14265W	PARTICIPANT	\N	PRESENT	0
17520	17223	14221J	PARTICIPANT	\N	PRESENT	0
17521	17223	14219Q	PARTICIPANT	\N	PRESENT	0
17522	17223	14231L	PARTICIPANT	\N	PRESENT	0
17523	17223	14071N	PARTICIPANT	\N	PRESENT	0
17524	17223	01056V	PARTICIPANT	\N	PRESENT	0
17525	17223	14037X	PARTICIPANT	\N	PRESENT	0
17526	17223	01046T	PARTICIPANT	\N	PRESENT	0
17527	17223	04086Q	PARTICIPANT	\N	PRESENT	0
17528	17223	14273W	PARTICIPANT	\N	PRESENT	0
17529	17223	08069G	PARTICIPANT	\N	PRESENT	0
17530	17223	11015D	PARTICIPANT	\N	PRESENT	0
17531	17223	11114F	PARTICIPANT	\N	PRESENT	0
17532	17223	14042U	PARTICIPANT	\N	PRESENT	0
17533	17223	11061K	PARTICIPANT	\N	PRESENT	0
17534	17223	10015M	PARTICIPANT	\N	PRESENT	0
17535	17223	11067R	PARTICIPANT	\N	PRESENT	0
17536	17223	14269B	PARTICIPANT	\N	PRESENT	0
17537	17223	04053F	PARTICIPANT	\N	PRESENT	0
17538	17223	11081P	PARTICIPANT	\N	PRESENT	0
17539	17223	01003G	PARTICIPANT	\N	PRESENT	0
17540	17223	14195A	PARTICIPANT	\N	PRESENT	0
17541	17223	14119M	PARTICIPANT	\N	PRESENT	0
17542	17223	14089Y	PARTICIPANT	\N	PRESENT	0
17543	17223	14253S	PARTICIPANT	\N	PRESENT	0
17544	17223	11026G	PARTICIPANT	\N	PRESENT	0
17545	17223	92045V	PARTICIPANT	\N	PRESENT	0
17546	17223	14217N	PARTICIPANT	\N	PRESENT	0
17547	17223	01034P	PARTICIPANT	\N	PRESENT	0
17548	17223	11012A	PARTICIPANT	\N	PRESENT	0
17502	17223	98053W	PARTICIPANT	\N	PRESENT	0
17503	17223	01059Y	PARTICIPANT	\N	PRESENT	0
17549	17223	01008M	PARTICIPANT	\N	PRESENT	0
17550	17223	14034U	PARTICIPANT	\N	PRESENT	0
17551	17223	01024M	PARTICIPANT	\N	PRESENT	0
17552	17223	98018T	PARTICIPANT	\N	PRESENT	0
17553	17223	08034U	PARTICIPANT	\N	PRESENT	0
17554	17223	14103D	PARTICIPANT	\N	PRESENT	0
17555	17223	11036J	PARTICIPANT	\N	PRESENT	0
17556	17223	11089X	PARTICIPANT	\N	PRESENT	0
17660	17221	92018S	PARTICIPANT	\N	PRESENT	0
17661	17221	14051J	PARTICIPANT	\N	PRESENT	0
17662	17221	98035U	PARTICIPANT	\N	PRESENT	0
17663	17221	00003C	PARTICIPANT	\N	PRESENT	0
17664	17221	14107H	PARTICIPANT	\N	PRESENT	0
17665	17221	08068F	PARTICIPANT	\N	PRESENT	0
17666	17221	11031D	PARTICIPANT	\N	PRESENT	0
17667	17221	14227Q	PARTICIPANT	\N	PRESENT	0
17668	17221	14001X	PARTICIPANT	\N	PRESENT	0
17669	17221	11105E	PARTICIPANT	\N	PRESENT	0
17670	17221	11107G	PARTICIPANT	\N	PRESENT	0
17671	17221	14257W	PARTICIPANT	\N	PRESENT	0
17672	17221	07026Q	PARTICIPANT	\N	PRESENT	0
17673	17221	01015L	PARTICIPANT	\N	PRESENT	0
17674	17221	01013J	PARTICIPANT	\N	PRESENT	0
17675	17221	08060W	PARTICIPANT	\N	PRESENT	0
17676	17221	11091R	PARTICIPANT	\N	PRESENT	0
17677	17221	11014C	PARTICIPANT	\N	PRESENT	0
17678	17221	04086Q	PARTICIPANT	\N	PRESENT	0
17679	17221	14225N	PARTICIPANT	\N	PRESENT	0
17680	17221	04088S	PARTICIPANT	\N	PRESENT	0
17681	17221	04081K	PARTICIPANT	\N	PRESENT	0
17682	17221	14259Y	PARTICIPANT	\N	PRESENT	0
17683	17221	05004A	PARTICIPANT	\N	PRESENT	0
17684	17221	95030B	PARTICIPANT	\N	PRESENT	0
17685	17221	01057W	PARTICIPANT	\N	PRESENT	0
17686	17221	95059Q	PARTICIPANT	\N	PRESENT	0
17687	17221	99004R	PARTICIPANT	\N	PRESENT	0
17688	17221	08022Q	PARTICIPANT	\N	PRESENT	0
17689	17221	04049K	PARTICIPANT	\N	PRESENT	0
17690	17221	86044G	PARTICIPANT	\N	PRESENT	0
17691	17221	96004D	PARTICIPANT	\N	PRESENT	0
17692	17221	01027Q	PARTICIPANT	\N	PRESENT	0
17693	17221	01058X	PARTICIPANT	\N	PRESENT	0
17694	17221	11098Y	PARTICIPANT	\N	PRESENT	0
17695	17221	02002K	PARTICIPANT	\N	PRESENT	0
17696	17221	14013P	PARTICIPANT	\N	PRESENT	0
17697	17221	11040E	PARTICIPANT	\N	PRESENT	0
17698	17221	14253S	PARTICIPANT	\N	PRESENT	0
17699	17221	04085P	PARTICIPANT	\N	PRESENT	0
17700	17221	11056N	PARTICIPANT	\N	PRESENT	0
17701	17221	01059Y	PARTICIPANT	\N	PRESENT	0
17702	17221	98005N	PARTICIPANT	\N	PRESENT	0
17658	17221	86034E	PARTICIPANT	\N	PRESENT	0
17703	17221	04041B	PARTICIPANT	\N	PRESENT	0
17704	17221	12041X	PARTICIPANT	\N	PRESENT	0
17705	17221	01056V	PARTICIPANT	\N	PRESENT	0
17706	17221	04033B	PARTICIPANT	\N	PRESENT	0
17707	17221	04054G	PARTICIPANT	\N	PRESENT	0
17708	17221	14235Q	PARTICIPANT	\N	PRESENT	0
17709	17221	11069T	PARTICIPANT	\N	PRESENT	0
17710	17221	11029K	PARTICIPANT	\N	PRESENT	0
17711	17221	01008M	PARTICIPANT	\N	PRESENT	0
17712	17221	11055M	PARTICIPANT	\N	PRESENT	0
17713	17221	11080N	PARTICIPANT	\N	PRESENT	0
17714	17221	14038Y	PARTICIPANT	\N	PRESENT	0
17715	17221	11083R	PARTICIPANT	\N	PRESENT	0
17716	17221	14195A	PARTICIPANT	\N	PRESENT	0
17717	17221	11010L	PARTICIPANT	\N	PRESENT	0
17718	17221	08019V	PARTICIPANT	\N	PRESENT	0
17719	17221	14191V	PARTICIPANT	\N	PRESENT	0
17720	17221	04044E	PARTICIPANT	\N	PRESENT	0
17721	17221	08069G	PARTICIPANT	\N	PRESENT	0
17722	17221	04059M	PARTICIPANT	\N	PRESENT	0
17723	17221	92045V	PARTICIPANT	\N	PRESENT	0
17724	17221	14063N	PARTICIPANT	\N	PRESENT	0
17725	17221	04056J	PARTICIPANT	\N	PRESENT	0
17726	17221	08052W	PARTICIPANT	\N	PRESENT	0
17727	17221	98046X	PARTICIPANT	\N	PRESENT	0
17728	17221	95063L	PARTICIPANT	\N	PRESENT	0
17729	17221	95035G	PARTICIPANT	\N	PRESENT	0
17730	17221	14151M	PARTICIPANT	\N	PRESENT	0
17731	17221	01011G	PARTICIPANT	\N	PRESENT	0
17732	17221	14028W	PARTICIPANT	\N	PRESENT	0
17733	17221	14087W	PARTICIPANT	\N	PRESENT	0
17734	17221	01022K	PARTICIPANT	\N	PRESENT	0
17735	17221	14037X	PARTICIPANT	\N	PRESENT	0
17736	17221	11089X	PARTICIPANT	\N	PRESENT	0
17737	17221	14061L	PARTICIPANT	\N	PRESENT	0
17738	17221	11059R	PARTICIPANT	\N	PRESENT	0
17739	17221	80027E	PARTICIPANT	\N	PRESENT	0
17740	17221	14271U	PARTICIPANT	\N	PRESENT	0
17741	17221	11054L	PARTICIPANT	\N	PRESENT	0
17742	17221	14281W	PARTICIPANT	\N	PRESENT	0
17744	17221	04034C	PARTICIPANT	\N	PRESENT	0
17745	17221	14069U	PARTICIPANT	\N	PRESENT	0
17746	17221	08055A	PARTICIPANT	\N	PRESENT	0
17747	17221	04066L	PARTICIPANT	\N	PRESENT	0
17748	17221	95039L	PARTICIPANT	\N	PRESENT	0
17749	17221	80013X	PARTICIPANT	\N	PRESENT	0
17750	17221	11061K	PARTICIPANT	\N	PRESENT	0
17751	17221	14217N	PARTICIPANT	\N	PRESENT	0
17752	17221	11067R	PARTICIPANT	\N	PRESENT	0
17753	17221	14133K	PARTICIPANT	\N	PRESENT	0
17754	17221	14251Q	PARTICIPANT	\N	PRESENT	0
17755	17221	98029W	PARTICIPANT	\N	PRESENT	0
17756	17221	11046L	PARTICIPANT	\N	PRESENT	0
17757	17221	11020A	PARTICIPANT	\N	PRESENT	0
17758	17221	11036J	PARTICIPANT	\N	PRESENT	0
17759	17221	11039M	PARTICIPANT	\N	PRESENT	0
17760	17221	08014Q	PARTICIPANT	\N	PRESENT	0
17761	17221	11088W	PARTICIPANT	\N	PRESENT	0
17762	17221	11095V	PARTICIPANT	\N	PRESENT	0
17763	17221	08058D	PARTICIPANT	\N	PRESENT	0
17764	17221	10006L	PARTICIPANT	\N	PRESENT	0
17765	17221	04079R	PARTICIPANT	\N	PRESENT	0
17766	17221	11074Q	PARTICIPANT	\N	PRESENT	0
17767	17221	14207L	PARTICIPANT	\N	PRESENT	0
17768	17221	08035V	PARTICIPANT	\N	PRESENT	0
17769	17221	95041E	PARTICIPANT	\N	PRESENT	0
17770	17221	08017T	PARTICIPANT	\N	PRESENT	0
17771	17221	08010L	PARTICIPANT	\N	PRESENT	0
17772	17221	14187A	PARTICIPANT	\N	PRESENT	0
17773	17221	13002U	PARTICIPANT	\N	PRESENT	0
17774	17221	08025T	PARTICIPANT	\N	PRESENT	0
17775	17221	92044U	PARTICIPANT	\N	PRESENT	0
17776	17221	14275Y	PARTICIPANT	\N	PRESENT	0
17777	17221	11110B	PARTICIPANT	\N	PRESENT	0
17778	17221	11053K	PARTICIPANT	\N	PRESENT	0
17779	17221	11068S	PARTICIPANT	\N	PRESENT	0
17780	17221	95031C	PARTICIPANT	\N	PRESENT	0
17781	17221	11037K	PARTICIPANT	\N	PRESENT	0
17782	17221	11066Q	PARTICIPANT	\N	PRESENT	0
17783	17221	04071H	PARTICIPANT	\N	PRESENT	0
17784	17221	11065P	PARTICIPANT	\N	PRESENT	0
17785	17221	04077P	PARTICIPANT	\N	PRESENT	0
17786	17221	04042C	PARTICIPANT	\N	PRESENT	0
17787	17221	08061X	PARTICIPANT	\N	PRESENT	0
17788	17221	04053F	PARTICIPANT	\N	PRESENT	0
17789	17221	14135M	PARTICIPANT	\N	PRESENT	0
17790	17221	01028R	PARTICIPANT	\N	PRESENT	0
17791	17221	04074L	PARTICIPANT	\N	PRESENT	0
17792	17221	11104D	PARTICIPANT	\N	PRESENT	0
17793	17221	08038Y	PARTICIPANT	\N	PRESENT	0
17794	17221	08011M	PARTICIPANT	\N	PRESENT	0
17795	17221	08024S	PARTICIPANT	\N	PRESENT	0
17796	17221	92031P	PARTICIPANT	\N	PRESENT	0
17797	17221	11032E	PARTICIPANT	\N	PRESENT	0
17798	17221	08034U	PARTICIPANT	\N	PRESENT	0
17799	17221	11100Y	PARTICIPANT	\N	PRESENT	0
17800	17221	14229S	PARTICIPANT	\N	PRESENT	0
17801	17221	98050T	PARTICIPANT	\N	PRESENT	0
17802	17221	11042G	PARTICIPANT	\N	PRESENT	0
17803	17221	12042Y	PARTICIPANT	\N	PRESENT	0
17804	17221	98018T	PARTICIPANT	\N	PRESENT	0
17805	17221	14039A	PARTICIPANT	\N	PRESENT	0
17806	17221	04094Q	PARTICIPANT	\N	PRESENT	0
17807	17221	14231L	PARTICIPANT	\N	PRESENT	0
17808	17221	11114F	PARTICIPANT	\N	PRESENT	0
17809	17221	11109J	PARTICIPANT	\N	PRESENT	0
17810	17221	11113E	PARTICIPANT	\N	PRESENT	0
17811	17221	14071N	PARTICIPANT	\N	PRESENT	0
17812	17221	14119M	PARTICIPANT	\N	PRESENT	0
17813	17221	14159V	PARTICIPANT	\N	PRESENT	0
17814	17221	14197C	PARTICIPANT	\N	PRESENT	0
17815	17221	11064N	PARTICIPANT	\N	PRESENT	0
17816	17221	14103D	PARTICIPANT	\N	PRESENT	0
17817	17221	01034P	PARTICIPANT	\N	PRESENT	0
17818	17221	14097Y	PARTICIPANT	\N	PRESENT	0
17819	17221	14327T	PARTICIPANT	\N	PRESENT	0
17820	17221	01044R	PARTICIPANT	\N	PRESENT	0
17821	17221	04040A	PARTICIPANT	\N	PRESENT	0
17822	17221	01024M	PARTICIPANT	\N	PRESENT	0
17823	17221	14269B	PARTICIPANT	\N	PRESENT	0
17824	17221	09001P	PARTICIPANT	\N	PRESENT	0
17825	17221	01014K	PARTICIPANT	\N	PRESENT	0
17826	17221	98042T	PARTICIPANT	\N	PRESENT	0
17827	17221	08051V	PARTICIPANT	\N	PRESENT	0
17828	17221	04038G	PARTICIPANT	\N	PRESENT	0
17829	17221	01046T	PARTICIPANT	\N	PRESENT	0
17830	17221	01043Q	PARTICIPANT	\N	PRESENT	0
17831	17221	04078Q	PARTICIPANT	\N	PRESENT	0
17833	17221	11012A	PARTICIPANT	\N	PRESENT	0
17834	17221	08049C	PARTICIPANT	\N	PRESENT	0
17835	17221	14241N	PARTICIPANT	\N	PRESENT	0
17836	17221	08031R	PARTICIPANT	\N	PRESENT	0
17837	17221	11081P	PARTICIPANT	\N	PRESENT	0
17838	17221	08015R	PARTICIPANT	\N	PRESENT	0
17839	17221	98022P	PARTICIPANT	\N	PRESENT	0
17840	17221	77002U	PARTICIPANT	\N	PRESENT	0
17841	17221	14221J	PARTICIPANT	\N	PRESENT	0
17842	17221	04061F	PARTICIPANT	\N	PRESENT	0
17843	17221	07029T	PARTICIPANT	\N	PRESENT	0
17921	17221	04070G	PARTICIPANT	\N	PRESENT	0
17845	17221	14111D	PARTICIPANT	\N	PRESENT	0
17846	17221	07024N	PARTICIPANT	\N	PRESENT	0
17847	17221	95067Q	PARTICIPANT	\N	PRESENT	0
17911	17221	14073Q	PARTICIPANT	\N	PRESENT	0
17849	17221	14199E	PARTICIPANT	\N	PRESENT	0
17931	17221	04092N	PARTICIPANT	\N	PRESENT	0
17897	17221	14255U	PARTICIPANT	\N	PRESENT	0
17912	17221	04067M	PARTICIPANT	\N	PRESENT	0
17855	17221	04057K	PARTICIPANT	\N	PRESENT	0
17857	17221	04035D	PARTICIPANT	\N	PRESENT	0
17859	17221	04043D	PARTICIPANT	\N	PRESENT	0
17861	17221	08073C	PARTICIPANT	\N	PRESENT	0
17863	17221	14147R	PARTICIPANT	\N	PRESENT	0
17864	17221	11076S	PARTICIPANT	\N	PRESENT	0
17866	17221	11026G	PARTICIPANT	\N	PRESENT	0
17868	17221	11027H	PARTICIPANT	\N	PRESENT	0
17875	17221	01031L	PARTICIPANT	\N	PRESENT	0
17943	17221	14273W	PARTICIPANT	\N	PRESENT	0
17900	17221	14093U	PARTICIPANT	\N	PRESENT	0
17894	17221	14030Q	PARTICIPANT	\N	PRESENT	0
17891	17221	14175V	PARTICIPANT	\N	PRESENT	0
17892	17221	14042U	PARTICIPANT	\N	PRESENT	0
17901	17221	11033F	PARTICIPANT	\N	PRESENT	0
17946	17221	11072N	PARTICIPANT	\N	PRESENT	0
17909	17221	11084S	PARTICIPANT	\N	PRESENT	0
17910	17221	07004J	PARTICIPANT	\N	PRESENT	0
17919	17221	14219Q	PARTICIPANT	\N	PRESENT	0
17932	17221	14173T	PARTICIPANT	\N	PRESENT	0
17933	17221	10015M	PARTICIPANT	\N	PRESENT	0
17934	17221	14033T	PARTICIPANT	\N	PRESENT	0
17935	17221	11049P	PARTICIPANT	\N	PRESENT	0
17937	17221	14123H	PARTICIPANT	\N	PRESENT	0
17941	17221	14223L	PARTICIPANT	\N	PRESENT	0
17939	17221	11015D	PARTICIPANT	\N	PRESENT	0
17940	17221	05012A	PARTICIPANT	\N	PRESENT	0
18217	17224	04081K	PARTICIPANT	\N	PRESENT	0
18219	17224	10006L	PARTICIPANT	\N	PRESENT	0
18220	17224	14042U	PARTICIPANT	\N	PRESENT	0
18221	17224	04092N	PARTICIPANT	\N	PRESENT	0
18222	17224	11054L	PARTICIPANT	\N	PRESENT	0
18223	17224	14227Q	PARTICIPANT	\N	PRESENT	0
18224	17224	14051J	PARTICIPANT	\N	PRESENT	0
18225	15163	14087W	PARTICIPANT	\N	EXCUSE	0
18226	15163	02002K	PARTICIPANT	\N	EXCUSE	0
18227	15163	14034U	PARTICIPANT	\N	EXCUSE	0
18228	15163	14121F	PARTICIPANT	\N	EXCUSE	0
18229	15163	95041E	PARTICIPANT	\N	EXCUSE	0
18230	17224	14013P	PARTICIPANT	\N	PRESENT	0
18231	17224	11114F	PARTICIPANT	\N	PRESENT	0
18232	17224	14225N	PARTICIPANT	\N	PRESENT	0
18233	17224	11015D	PARTICIPANT	\N	PRESENT	0
18234	17224	11027H	PARTICIPANT	\N	PRESENT	0
18235	17224	14191V	PARTICIPANT	\N	PRESENT	0
18236	17224	08069G	PARTICIPANT	\N	PRESENT	0
18237	17224	04088S	PARTICIPANT	\N	PRESENT	0
18238	17224	08017T	PARTICIPANT	\N	PRESENT	0
18239	17224	07029T	PARTICIPANT	\N	PRESENT	0
18240	17224	14265W	PARTICIPANT	\N	PRESENT	0
18241	17224	14147R	PARTICIPANT	\N	PRESENT	0
18242	17224	11100Y	PARTICIPANT	\N	PRESENT	0
18243	17224	04057K	PARTICIPANT	\N	PRESENT	0
18244	17224	04043D	PARTICIPANT	\N	PRESENT	0
18245	17224	14273W	PARTICIPANT	\N	PRESENT	0
18246	17224	07004J	PARTICIPANT	\N	PRESENT	0
18247	17224	01034P	PARTICIPANT	\N	PRESENT	0
18248	17224	14103D	PARTICIPANT	\N	PRESENT	0
18249	17224	01028R	PARTICIPANT	\N	PRESENT	0
18250	17224	08052W	PARTICIPANT	\N	PRESENT	0
18251	17224	14269B	PARTICIPANT	\N	PRESENT	0
18252	17224	11067R	PARTICIPANT	\N	PRESENT	0
18253	17224	00003C	PARTICIPANT	\N	PRESENT	0
18254	17224	08014Q	PARTICIPANT	\N	PRESENT	0
18255	17224	11031D	PARTICIPANT	\N	PRESENT	0
18256	17224	11061K	PARTICIPANT	\N	PRESENT	0
18257	17224	98005N	PARTICIPANT	\N	PRESENT	0
18258	17224	14271U	PARTICIPANT	\N	PRESENT	0
18259	17224	04053F	PARTICIPANT	\N	PRESENT	0
18260	17224	14195A	PARTICIPANT	\N	PRESENT	0
18262	17224	11113E	PARTICIPANT	\N	PRESENT	0
18263	17224	11091R	PARTICIPANT	\N	PRESENT	0
18264	17224	04066L	PARTICIPANT	\N	PRESENT	0
18265	17224	95035G	PARTICIPANT	\N	PRESENT	0
18268	17224	01056V	PARTICIPANT	\N	PRESENT	0
18269	17224	14071N	PARTICIPANT	\N	PRESENT	0
18270	17224	04044E	PARTICIPANT	\N	PRESENT	0
18271	17224	01046T	PARTICIPANT	\N	PRESENT	0
18272	17224	11012A	PARTICIPANT	\N	PRESENT	0
18273	17224	10015M	PARTICIPANT	\N	PRESENT	0
18274	15163	04077P	PARTICIPANT	\N	EXCUSE	0
18275	17224	14281W	PARTICIPANT	\N	PRESENT	0
18276	15163	01043Q	PARTICIPANT	\N	EXCUSE	0
18277	15163	11090Q	PARTICIPANT	\N	EXCUSE	0
18278	15163	10015M	PARTICIPANT	\N	EXCUSE	0
18279	17224	14038Y	PARTICIPANT	\N	PRESENT	0
18280	15163	95067Q	PARTICIPANT	\N	EXCUSE	0
18281	15163	11063M	PARTICIPANT	\N	EXCUSE	0
17949	17948	14133K	PARTICIPANT	\N	PRESENT	0
17950	17948	04054G	PARTICIPANT	\N	PRESENT	0
17951	17948	96004D	PRESIDENT	0	PRESENT	0
17952	17948	11040E	PARTICIPANT	\N	PRESENT	0
17953	17948	14089Y	PARTICIPANT	\N	PRESENT	0
17954	17948	90003B	PARTICIPANT	\N	EXCUSE	0
17955	17948	14079W	PARTICIPANT	\N	PRESENT	0
17956	17948	14249W	PARTICIPANT	\N	EXCUSE	0
17957	17948	95030B	PARTICIPANT	\N	PRESENT	0
17958	17948	08018U	PARTICIPANT	\N	EXCUSE	0
17959	17948	11083R	PARTICIPANT	\N	PRESENT	0
17961	17948	14097Y	PARTICIPANT	\N	PRESENT	0
17965	17948	14073Q	PARTICIPANT	\N	EXCUSE	0
17969	17948	98046X	PARTICIPANT	\N	PRESENT	0
17970	17948	14001X	PARTICIPANT	\N	PRESENT	0
17973	17948	04057K	PARTICIPANT	\N	EXCUSE	0
17975	17948	08042U	PARTICIPANT	\N	EXCUSE	0
17977	17948	08073C	PARTICIPANT	\N	PRESENT	0
17978	17948	04080J	PARTICIPANT	\N	PRESENT	0
17980	17948	14135M	PARTICIPANT	\N	PRESENT	0
17981	17948	01016M	PARTICIPANT	\N	EXCUSE	0
17984	17948	11012A	PARTICIPANT	\N	PRESENT	0
17986	17948	95063L	PARTICIPANT	\N	PRESENT	0
17987	17948	04045F	PARTICIPANT	\N	EXCUSE	0
17989	17948	98035U	PARTICIPANT	\N	PRESENT	0
17990	17948	04034C	PARTICIPANT	\N	PRESENT	0
18282	17224	14251Q	PARTICIPANT	\N	PRESENT	0
18283	17224	08010L	PARTICIPANT	\N	PRESENT	0
18284	16779	14071N	PARTICIPANT	\N	PRESENT	0
18285	16779	14063N	PARTICIPANT	\N	PRESENT	0
18286	16779	14051J	PARTICIPANT	\N	PRESENT	0
18287	16779	14028W	PARTICIPANT	\N	PRESENT	0
18288	16779	11098Y	PARTICIPANT	\N	PRESENT	0
18289	16779	08010L	PARTICIPANT	\N	PRESENT	0
18290	16779	95067Q	PARTICIPANT	\N	PRESENT	0
18291	16779	11049P	PARTICIPANT	\N	PRESENT	0
18292	16779	01057W	PARTICIPANT	\N	PRESENT	0
18293	16779	01027Q	PARTICIPANT	\N	PRESENT	0
18294	16779	14069U	PARTICIPANT	\N	PRESENT	0
18295	16779	14217N	PARTICIPANT	\N	PRESENT	0
18296	16779	01043Q	PARTICIPANT	\N	PRESENT	0
18297	17224	14199E	PARTICIPANT	\N	PRESENT	0
18298	17224	14033T	PARTICIPANT	\N	PRESENT	0
18299	17224	11112D	PARTICIPANT	\N	PRESENT	0
18300	17224	01011G	PARTICIPANT	\N	PRESENT	0
18301	17224	11026G	PARTICIPANT	\N	PRESENT	0
18302	17224	14259Y	PARTICIPANT	\N	PRESENT	0
18303	17224	08034U	PARTICIPANT	\N	PRESENT	0
18304	17224	04034C	PARTICIPANT	\N	PRESENT	0
18305	17224	04042C	PARTICIPANT	\N	PRESENT	0
18306	17224	11089X	PARTICIPANT	\N	PRESENT	0
18307	17224	14255U	PARTICIPANT	\N	PRESENT	0
18308	17224	11063M	PARTICIPANT	\N	PRESENT	0
18309	17224	92045V	PARTICIPANT	\N	PRESENT	0
18310	17224	08019V	PARTICIPANT	\N	PRESENT	0
18319	17224	99004R	PARTICIPANT	\N	PRESENT	0
18320	17224	11010L	PARTICIPANT	\N	PRESENT	0
18321	17224	01041N	PARTICIPANT	\N	PRESENT	0
18341	15101	08073C	PARTICIPANT	\N	PRESENT	0
18342	15101	04094Q	PARTICIPANT	\N	PRESENT	0
18343	15101	98005N	PARTICIPANT	\N	PRESENT	0
18344	15101	14219Q	PARTICIPANT	\N	PRESENT	0
18345	15101	14275Y	PARTICIPANT	\N	PRESENT	0
18346	15101	11064N	PARTICIPANT	\N	PRESENT	0
18347	15101	11072N	PARTICIPANT	\N	PRESENT	0
18348	15101	11054L	PARTICIPANT	\N	PRESENT	0
18349	15101	01027Q	PARTICIPANT	\N	PRESENT	0
18350	15101	11020A	PARTICIPANT	\N	PRESENT	0
18351	15101	14097Y	PARTICIPANT	\N	PRESENT	0
18352	15101	14039A	PARTICIPANT	\N	PRESENT	0
18353	15101	11109J	PARTICIPANT	\N	PRESENT	0
18354	15101	14259Y	PARTICIPANT	\N	PRESENT	0
18355	15101	11010L	PARTICIPANT	\N	PRESENT	0
18356	15101	14033T	PARTICIPANT	\N	PRESENT	0
18357	15101	11011M	PARTICIPANT	\N	EXCUSE	0
18358	15101	14053L	PARTICIPANT	\N	EXCUSE	0
18359	15101	11023D	PARTICIPANT	\N	EXCUSE	0
18360	15101	11025F	PARTICIPANT	\N	EXCUSE	0
18361	15101	11113E	PARTICIPANT	\N	EXCUSE	0
18362	15101	11106F	PARTICIPANT	\N	EXCUSE	0
18381	18363	14028W	PARTICIPANT	\N	EXCUSE	0
18408	18407	04085P	PARTICIPANT	\N	PRESENT	0
18409	18407	05008E	PRESIDENT	0	PRESENT	0
18410	18407	11033F	PARTICIPANT	\N	EXCUSE	0
18411	18407	14065Q	PARTICIPANT	\N	PRESENT	0
18412	18407	14069U	PARTICIPANT	\N	PRESENT	0
18413	18407	04047H	PARTICIPANT	\N	PRESENT	0
18414	18407	11032E	PARTICIPANT	\N	PRESENT	0
18415	18407	14041T	PARTICIPANT	\N	PRESENT	0
18416	18407	01024M	PARTICIPANT	\N	PRESENT	0
18417	18407	11010L	PARTICIPANT	\N	PRESENT	0
18418	18407	01007L	PARTICIPANT	\N	PRESENT	0
18419	18407	11084S	PARTICIPANT	\N	PRESENT	0
18420	18407	11026G	PARTICIPANT	\N	PRESENT	0
18421	18407	14111D	PARTICIPANT	\N	PRESENT	0
18422	18407	14273W	PARTICIPANT	\N	PRESENT	0
18423	18407	14147R	PARTICIPANT	\N	PRESENT	0
18424	18407	95049N	PARTICIPANT	\N	PRESENT	0
18425	18407	08051V	PARTICIPANT	\N	PRESENT	0
18426	18407	95063L	PARTICIPANT	\N	PRESENT	0
18427	18407	07034Q	PARTICIPANT	\N	PRESENT	0
18431	18407	98035U	PARTICIPANT	\N	PRESENT	0
18429	18407	01028R	PARTICIPANT	\N	PRESENT	0
18430	18407	04044E	PARTICIPANT	\N	PRESENT	0
18432	18407	04056J	PARTICIPANT	\N	PRESENT	0
18433	18407	14275Y	PARTICIPANT	\N	PRESENT	0
18434	18407	11037K	PARTICIPANT	\N	PRESENT	0
18435	18407	95067Q	PARTICIPANT	\N	PRESENT	0
18438	18407	04074L	PARTICIPANT	\N	PRESENT	0
18440	18363	05012A	PARTICIPANT	\N	EXCUSE	0
18620	18403	80013X	PARTICIPANT	\N	PRESENT	0
18621	18403	14281W	PARTICIPANT	\N	PRESENT	0
18626	18403	08035V	PARTICIPANT	\N	PRESENT	0
18623	18403	08068F	PARTICIPANT	\N	PRESENT	0
18624	18403	11084S	PARTICIPANT	\N	PRESENT	0
18625	18403	14065Q	PARTICIPANT	\N	PRESENT	0
18627	18403	98029W	PARTICIPANT	\N	PRESENT	0
18628	18403	14109K	PARTICIPANT	\N	PRESENT	0
18629	18403	14207L	PARTICIPANT	\N	PRESENT	0
18630	18403	14031R	PARTICIPANT	\N	PRESENT	0
18631	18403	14001X	PARTICIPANT	\N	PRESENT	0
18632	18403	98018T	PARTICIPANT	\N	PRESENT	0
18633	18403	11088W	PARTICIPANT	\N	PRESENT	0
18634	18403	08017T	PARTICIPANT	\N	PRESENT	0
18635	18403	01031L	PARTICIPANT	\N	PRESENT	0
18636	18403	11043H	PARTICIPANT	\N	PRESENT	0
18637	18403	14097Y	PARTICIPANT	\N	PRESENT	0
18638	18403	14121F	PARTICIPANT	\N	PRESENT	0
18639	18403	14063N	PARTICIPANT	\N	PRESENT	0
18640	18403	04071H	PARTICIPANT	\N	PRESENT	0
18641	18403	11112D	PARTICIPANT	\N	PRESENT	0
18642	18403	92039X	PARTICIPANT	\N	PRESENT	0
18643	18403	08011M	PARTICIPANT	\N	PRESENT	0
18644	18403	11074Q	PARTICIPANT	\N	PRESENT	0
18645	18403	11027H	PARTICIPANT	\N	PRESENT	0
18646	18403	04053F	PARTICIPANT	\N	PRESENT	0
18647	18403	01008M	PARTICIPANT	\N	PRESENT	0
18648	18403	04077P	PARTICIPANT	\N	PRESENT	0
18649	18403	96004D	PARTICIPANT	\N	PRESENT	0
18650	18403	11032E	PARTICIPANT	\N	PRESENT	0
18651	18403	04036E	PARTICIPANT	\N	PRESENT	0
18652	18403	01028R	PARTICIPANT	\N	PRESENT	0
18653	18403	99004R	PARTICIPANT	\N	PRESENT	0
18654	18403	04061F	PARTICIPANT	\N	PRESENT	0
18655	18403	11104D	PARTICIPANT	\N	PRESENT	0
18656	18403	11110B	PARTICIPANT	\N	PRESENT	0
18657	18403	11044J	PARTICIPANT	\N	PRESENT	0
18658	18403	08024S	PARTICIPANT	\N	PRESENT	0
18659	18403	01016M	PARTICIPANT	\N	PRESENT	0
18660	18403	99002P	PARTICIPANT	\N	PRESENT	0
18661	18403	11061K	PARTICIPANT	\N	PRESENT	0
18662	18403	08022Q	PARTICIPANT	\N	PRESENT	0
18663	18403	11106F	PARTICIPANT	\N	PRESENT	0
18664	18403	11067R	PARTICIPANT	\N	PRESENT	0
18665	18403	12042Y	PARTICIPANT	\N	PRESENT	0
18666	18403	04048J	PARTICIPANT	\N	PRESENT	0
18667	18403	08069G	PARTICIPANT	\N	PRESENT	0
18668	18403	11090Q	PARTICIPANT	\N	PRESENT	0
18669	18403	11109J	PARTICIPANT	\N	PRESENT	0
18670	18403	04043D	PARTICIPANT	\N	PRESENT	0
18671	18403	11114F	PARTICIPANT	\N	PRESENT	0
18672	18403	11014C	PARTICIPANT	\N	PRESENT	0
18673	18403	04095R	PARTICIPANT	\N	PRESENT	0
18674	18403	01057W	PARTICIPANT	\N	PRESENT	0
18675	18403	04041B	PARTICIPANT	\N	PRESENT	0
18676	18403	11055M	PARTICIPANT	\N	PRESENT	0
18218	17948	10015M	PARTICIPANT	\N	PRESENT	0
18267	17221	11043H	PARTICIPANT	\N	PRESENT	0
18787	18403	11111C	PARTICIPANT	\N	PRESENT	0
18678	18403	11113E	PARTICIPANT	\N	PRESENT	0
18679	18403	01060R	PARTICIPANT	\N	PRESENT	0
18680	18403	08018U	PARTICIPANT	\N	PRESENT	0
18681	18403	11048N	PARTICIPANT	\N	PRESENT	0
18682	18403	11035H	PARTICIPANT	\N	PRESENT	0
18683	18403	08073C	PARTICIPANT	\N	PRESENT	0
18684	18403	14071N	PARTICIPANT	\N	PRESENT	0
18685	18403	14201E	PARTICIPANT	\N	PRESENT	0
18686	18403	14159V	PARTICIPANT	\N	PRESENT	0
18687	18403	14089Y	PARTICIPANT	\N	PRESENT	0
18688	18403	11076S	PARTICIPANT	\N	PRESENT	0
18689	18403	01058X	PARTICIPANT	\N	PRESENT	0
18690	18403	04044E	PARTICIPANT	\N	PRESENT	0
18691	18403	14133K	PARTICIPANT	\N	PRESENT	0
18692	18403	01044R	PARTICIPANT	\N	PRESENT	0
18693	18403	11083R	PARTICIPANT	\N	PRESENT	0
18694	18403	11065P	PARTICIPANT	\N	PRESENT	0
18261	17221	14265W	PARTICIPANT	\N	PRESENT	0
18266	17221	11103C	PARTICIPANT	\N	PRESENT	0
18695	18403	14269B	PARTICIPANT	\N	PRESENT	0
18696	18403	11069T	PARTICIPANT	\N	PRESENT	0
18697	18403	92031P	PARTICIPANT	\N	PRESENT	0
18698	18403	14079W	PARTICIPANT	\N	PRESENT	0
18699	18403	08051V	PARTICIPANT	\N	PRESENT	0
18700	18403	95049N	PARTICIPANT	\N	PRESENT	0
18701	18403	05012A	PARTICIPANT	\N	PRESENT	0
18702	18403	08041T	PARTICIPANT	\N	PRESENT	0
18703	18403	11049P	PARTICIPANT	\N	PRESENT	0
18704	18403	11060J	PARTICIPANT	\N	PRESENT	0
18705	18403	04078Q	PARTICIPANT	\N	PRESENT	0
18706	18403	08031R	PARTICIPANT	\N	PRESENT	0
18707	18403	08049C	PARTICIPANT	\N	PRESENT	0
18708	18403	10015M	PARTICIPANT	\N	PRESENT	0
18709	18403	11012A	PARTICIPANT	\N	PRESENT	0
18710	18403	04033B	PARTICIPANT	\N	PRESENT	0
18711	18403	11081P	PARTICIPANT	\N	PRESENT	0
18712	18403	14018U	PARTICIPANT	\N	PRESENT	0
18713	18403	04057K	PARTICIPANT	\N	PRESENT	0
18714	18403	98022P	PARTICIPANT	\N	PRESENT	0
18715	18403	11037K	PARTICIPANT	\N	PRESENT	0
18716	18403	07024N	PARTICIPANT	\N	PRESENT	0
18717	18403	08061X	PARTICIPANT	\N	PRESENT	0
18718	18403	04049K	PARTICIPANT	\N	PRESENT	0
18719	18403	86034E	PARTICIPANT	\N	PRESENT	0
18720	18403	11070L	PARTICIPANT	\N	PRESENT	0
18721	18403	14157T	PARTICIPANT	\N	PRESENT	0
18722	18403	14034U	PARTICIPANT	\N	PRESENT	0
18723	18403	02002K	PARTICIPANT	\N	PRESENT	0
18724	18403	11010L	PARTICIPANT	\N	PRESENT	0
18725	18403	08056B	PARTICIPANT	\N	PRESENT	0
18726	18403	01003G	PARTICIPANT	\N	PRESENT	0
18727	18403	11071M	PARTICIPANT	\N	PRESENT	0
18728	18403	04040A	PARTICIPANT	\N	PRESENT	0
18729	18403	97011G	PARTICIPANT	\N	PRESENT	0
18730	18403	01041N	PARTICIPANT	\N	PRESENT	0
18731	18403	01047U	PARTICIPANT	\N	PRESENT	0
18732	18403	04070G	PARTICIPANT	\N	PRESENT	0
18733	18403	04047H	PARTICIPANT	\N	PRESENT	0
18734	18403	11082Q	PARTICIPANT	\N	PRESENT	0
18735	18403	09001P	PARTICIPANT	\N	PRESENT	0
18736	18403	92045V	PARTICIPANT	\N	PRESENT	0
18737	18403	98053W	PARTICIPANT	\N	PRESENT	0
18738	18403	98042T	PARTICIPANT	\N	PRESENT	0
18739	18403	14213J	PARTICIPANT	\N	PRESENT	0
18740	18403	14199E	PARTICIPANT	\N	PRESENT	0
18741	18403	14241N	PARTICIPANT	\N	PRESENT	0
18742	18403	08039A	PARTICIPANT	\N	PRESENT	0
18743	18403	14247U	PARTICIPANT	\N	PRESENT	0
18744	18403	14217N	PARTICIPANT	\N	PRESENT	0
18745	18403	01007L	PARTICIPANT	\N	PRESENT	0
18746	18403	11093T	PARTICIPANT	\N	PRESENT	0
18747	18403	14327T	PARTICIPANT	\N	PRESENT	0
18748	18403	95067Q	PARTICIPANT	\N	PRESENT	0
18749	18403	14173T	PARTICIPANT	\N	PRESENT	0
18750	18403	01024M	PARTICIPANT	\N	PRESENT	0
18751	18403	10006L	PARTICIPANT	\N	PRESENT	0
18752	18403	08044W	PARTICIPANT	\N	PRESENT	0
18753	18403	07004J	PARTICIPANT	\N	PRESENT	0
18754	18403	11039M	PARTICIPANT	\N	PRESENT	0
18755	18403	04092N	PARTICIPANT	\N	PRESENT	0
18756	18403	14273W	PARTICIPANT	\N	PRESENT	0
18757	18403	98021N	PARTICIPANT	\N	PRESENT	0
18758	18403	04088S	PARTICIPANT	\N	PRESENT	0
18763	18403	08038Y	PARTICIPANT	\N	PRESENT	0
18760	18403	98024R	PARTICIPANT	\N	PRESENT	0
18761	18403	04045F	PARTICIPANT	\N	PRESENT	0
18762	18403	14026U	PARTICIPANT	\N	PRESENT	0
18764	18403	95035G	PARTICIPANT	\N	PRESENT	0
18765	18403	14135M	PARTICIPANT	\N	PRESENT	0
18766	18403	08010L	PARTICIPANT	\N	PRESENT	0
18767	18403	14251Q	PARTICIPANT	\N	PRESENT	0
18768	18403	95041E	PARTICIPANT	\N	PRESENT	0
18769	18403	08062Y	PARTICIPANT	\N	PRESENT	0
18770	18403	14119M	PARTICIPANT	\N	PRESENT	0
18771	18403	11091R	PARTICIPANT	\N	PRESENT	0
18772	18403	08043V	PARTICIPANT	\N	PRESENT	0
18782	18403	14225N	PARTICIPANT	\N	PRESENT	0
18774	18403	04042C	PARTICIPANT	\N	PRESENT	0
18775	18403	11095V	PARTICIPANT	\N	PRESENT	0
18776	18403	98050T	PARTICIPANT	\N	PRESENT	0
18777	18403	92020L	PARTICIPANT	\N	PRESENT	0
18778	18403	08047A	PARTICIPANT	\N	PRESENT	0
18779	18403	14205J	PARTICIPANT	\N	PRESENT	0
18780	18403	01014K	PARTICIPANT	\N	PRESENT	0
18781	18403	11107G	PARTICIPANT	\N	PRESENT	0
18790	18403	04089T	PARTICIPANT	\N	PRESENT	0
18784	18403	14093U	PARTICIPANT	\N	PRESENT	0
18785	18403	04035D	PARTICIPANT	\N	PRESENT	0
18786	18403	89017R	PARTICIPANT	\N	PRESENT	0
18788	18403	11099A	PARTICIPANT	\N	PRESENT	0
18789	18403	95059Q	PARTICIPANT	\N	PRESENT	0
18791	18403	11094U	PARTICIPANT	\N	PRESENT	0
18801	18363	14014Q	PARTICIPANT	\N	EXCUSE	0
18793	18403	11068S	PARTICIPANT	\N	PRESENT	0
18794	18403	14257W	PARTICIPANT	\N	PRESENT	0
18795	18403	08058D	PARTICIPANT	\N	PRESENT	0
18796	18403	14229S	PARTICIPANT	\N	PRESENT	0
18797	18403	14167V	PARTICIPANT	\N	PRESENT	0
18798	18403	04079R	PARTICIPANT	\N	PRESENT	0
19110	18404	11031D	PARTICIPANT	\N	PRESENT	0
18800	18403	11085T	PARTICIPANT	\N	PRESENT	0
18805	18403	14175V	PARTICIPANT	\N	PRESENT	0
18803	18403	08025T	PARTICIPANT	\N	PRESENT	0
19111	18404	14235Q	PARTICIPANT	\N	PRESENT	0
19112	18404	01013J	PARTICIPANT	\N	PRESENT	0
19113	18404	04054G	PARTICIPANT	\N	PRESENT	0
19114	18404	14013P	PARTICIPANT	\N	PRESENT	0
19115	18404	14263U	PARTICIPANT	\N	PRESENT	0
19116	18404	11098Y	PARTICIPANT	\N	PRESENT	0
19117	18404	01015L	PARTICIPANT	\N	PRESENT	0
19118	18404	07026Q	PARTICIPANT	\N	PRESENT	0
19119	18404	11056N	PARTICIPANT	\N	PRESENT	0
19120	18404	11034G	PARTICIPANT	\N	PRESENT	0
19121	18404	12041X	PARTICIPANT	\N	PRESENT	0
19122	18404	11054L	PARTICIPANT	\N	PRESENT	0
19123	18404	04079R	PARTICIPANT	\N	PRESENT	0
19124	18404	11026G	PARTICIPANT	\N	PRESENT	0
19125	18404	14109K	PARTICIPANT	\N	PRESENT	0
19126	18404	14271U	PARTICIPANT	\N	PRESENT	0
19127	18404	11014C	PARTICIPANT	\N	PRESENT	0
19128	18404	14227Q	PARTICIPANT	\N	PRESENT	0
19129	18404	14121F	PARTICIPANT	\N	PRESENT	0
19130	18404	14063N	PARTICIPANT	\N	PRESENT	0
19131	18404	13002U	PARTICIPANT	\N	PRESENT	0
19132	18404	11074Q	PARTICIPANT	\N	PRESENT	0
19133	18404	98029W	PARTICIPANT	\N	PRESENT	0
19134	18404	14207L	PARTICIPANT	\N	PRESENT	0
19135	18404	08014Q	PARTICIPANT	\N	PRESENT	0
19136	18404	08058D	PARTICIPANT	\N	PRESENT	0
19137	18404	14229S	PARTICIPANT	\N	PRESENT	0
19138	18404	08017T	PARTICIPANT	\N	PRESENT	0
19139	18404	14257W	PARTICIPANT	\N	PRESENT	0
19140	18404	11046L	PARTICIPANT	\N	PRESENT	0
19141	18404	11027H	PARTICIPANT	\N	PRESENT	0
19142	18404	14065Q	PARTICIPANT	\N	PRESENT	0
19143	18404	08043V	PARTICIPANT	\N	PRESENT	0
19144	18404	11089X	PARTICIPANT	\N	PRESENT	0
19145	18404	08025T	PARTICIPANT	\N	PRESENT	0
19146	18404	14197C	PARTICIPANT	\N	PRESENT	0
19147	18404	08012N	PARTICIPANT	\N	PRESENT	0
19148	18404	01022K	PARTICIPANT	\N	PRESENT	0
19149	18404	14028W	PARTICIPANT	\N	PRESENT	0
19150	18404	80013X	PARTICIPANT	\N	PRESENT	0
19151	18404	08060W	PARTICIPANT	\N	PRESENT	0
19152	18404	08055A	PARTICIPANT	\N	PRESENT	0
19153	18404	04066L	PARTICIPANT	\N	PRESENT	0
17960	17947	14030Q	PARTICIPANT	\N	EXCUSE	0
17962	17947	08043V	PARTICIPANT	\N	EXCUSE	0
17963	17947	08060W	PARTICIPANT	\N	EXCUSE	0
17964	17947	11029K	PARTICIPANT	\N	PRESENT	0
17966	17947	11031D	PARTICIPANT	\N	PRESENT	0
17967	17947	80013X	PARTICIPANT	\N	PRESENT	0
17968	17947	11027H	PARTICIPANT	\N	PRESENT	0
17971	17947	14041T	PARTICIPANT	\N	EXCUSE	0
17972	17947	14217N	PARTICIPANT	\N	EXCUSE	0
17974	17947	04035D	PARTICIPANT	\N	PRESENT	0
17976	17947	14014Q	PARTICIPANT	\N	EXCUSE	0
17979	17947	07026Q	PARTICIPANT	\N	PRESENT	0
17982	17947	04036E	PARTICIPANT	\N	PRESENT	0
17983	17947	08031R	PARTICIPANT	\N	PRESENT	0
17985	17947	08017T	PARTICIPANT	\N	PRESENT	0
17988	17947	14059S	PARTICIPANT	\N	EXCUSE	0
17991	17947	11067R	PARTICIPANT	\N	PRESENT	0
17992	17947	11014C	PARTICIPANT	\N	PRESENT	0
18031	17947	14109K	PARTICIPANT	\N	EXCUSE	0
18216	17947	09001P	PRESIDENT	0	PRESENT	0
18312	18311	14083S	PARTICIPANT	\N	PRESENT	0
18313	18311	04038G	PARTICIPANT	\N	PRESENT	0
18314	18311	08022Q	PARTICIPANT	\N	PRESENT	0
18315	18311	98042T	PARTICIPANT	\N	PRESENT	0
18316	18311	01061S	PARTICIPANT	\N	EXCUSE	0
18317	18311	08051V	PARTICIPANT	\N	PRESENT	0
18318	18311	14157T	PARTICIPANT	\N	PRESENT	0
18364	18363	04040A	PRESIDENT	0	PRESENT	0
18365	18363	01057W	PARTICIPANT	\N	EXCUSE	0
19154	18404	14107H	PARTICIPANT	\N	PRESENT	0
19155	18404	01011G	PARTICIPANT	\N	PRESENT	0
19156	18404	11059R	PARTICIPANT	\N	PRESENT	0
19157	18404	14167V	PARTICIPANT	\N	PRESENT	0
19158	18404	08068F	PARTICIPANT	\N	PRESENT	0
19159	18404	14001X	PARTICIPANT	\N	PRESENT	0
19160	18404	08052W	PARTICIPANT	\N	PRESENT	0
19161	18404	98046X	PARTICIPANT	\N	PRESENT	0
19162	18404	95063L	PARTICIPANT	\N	PRESENT	0
19163	18404	11036J	PARTICIPANT	\N	PRESENT	0
19164	18404	14151M	PARTICIPANT	\N	PRESENT	0
19165	18404	14051J	PARTICIPANT	\N	PRESENT	0
19166	18404	04056J	PARTICIPANT	\N	PRESENT	0
19167	18404	14030Q	PARTICIPANT	\N	PRESENT	0
19168	18404	98035U	PARTICIPANT	\N	PRESENT	0
19169	18404	11039M	PARTICIPANT	\N	PRESENT	0
19170	18404	08016S	PARTICIPANT	\N	PRESENT	0
19171	18404	04085P	PARTICIPANT	\N	PRESENT	0
19172	18404	92020L	PARTICIPANT	\N	PRESENT	0
19173	18404	00003C	PARTICIPANT	\N	PRESENT	0
19174	18404	14014Q	PARTICIPANT	\N	PRESENT	0
19175	18404	04070G	PARTICIPANT	\N	PRESENT	0
19176	18404	04080J	PARTICIPANT	\N	PRESENT	0
19177	18404	14097Y	PARTICIPANT	\N	PRESENT	0
19178	18404	11015D	PARTICIPANT	\N	PRESENT	0
19179	18404	08009T	PARTICIPANT	\N	PRESENT	0
19180	18404	04095R	PARTICIPANT	\N	PRESENT	0
19181	18404	11113E	PARTICIPANT	\N	PRESENT	0
19182	18404	11053K	PARTICIPANT	\N	PRESENT	0
19183	18404	11068S	PARTICIPANT	\N	PRESENT	0
19184	18404	14267Y	PARTICIPANT	\N	PRESENT	0
19185	18404	04040A	PARTICIPANT	\N	PRESENT	0
19186	18404	14089Y	PARTICIPANT	\N	PRESENT	0
19187	18404	83047W	PARTICIPANT	\N	PRESENT	0
19188	18404	14255U	PARTICIPANT	\N	PRESENT	0
19189	18404	14083S	PARTICIPANT	\N	PRESENT	0
19190	18404	11063M	PARTICIPANT	\N	PRESENT	0
19191	18404	14042U	PARTICIPANT	\N	PRESENT	0
19192	18404	04089T	PARTICIPANT	\N	PRESENT	0
19193	18404	12042Y	PARTICIPANT	\N	PRESENT	0
19194	18404	11114F	PARTICIPANT	\N	PRESENT	0
19195	18404	98042T	PARTICIPANT	\N	PRESENT	0
19196	18404	92039X	PARTICIPANT	\N	PRESENT	0
19197	18404	05004A	PARTICIPANT	\N	PRESENT	0
19198	18404	08035V	PARTICIPANT	\N	PRESENT	0
19199	18404	11109J	PARTICIPANT	\N	PRESENT	0
19200	18404	01025N	PARTICIPANT	\N	PRESENT	0
19201	18404	04094Q	PARTICIPANT	\N	PRESENT	0
19202	18404	14159V	PARTICIPANT	\N	PRESENT	0
19203	18404	11077T	PARTICIPANT	\N	PRESENT	0
19204	18404	14269B	PARTICIPANT	\N	PRESENT	0
19205	18404	04045F	PARTICIPANT	\N	PRESENT	0
19206	18404	11067R	PARTICIPANT	\N	PRESENT	0
19207	18404	11094U	PARTICIPANT	\N	PRESENT	0
19208	18404	14081Q	PARTICIPANT	\N	PRESENT	0
19209	18404	11084S	PARTICIPANT	\N	PRESENT	0
19210	18404	14281W	PARTICIPANT	\N	PRESENT	0
19211	18404	14085U	PARTICIPANT	\N	PRESENT	0
19212	18404	11106F	PARTICIPANT	\N	PRESENT	0
19213	18404	14231L	PARTICIPANT	\N	PRESENT	0
19214	18404	11066Q	PARTICIPANT	\N	PRESENT	0
19215	18404	11035H	PARTICIPANT	\N	PRESENT	0
19216	18404	99002P	PARTICIPANT	\N	PRESENT	0
19217	18404	08024S	PARTICIPANT	\N	PRESENT	0
19218	18404	01007L	PARTICIPANT	\N	PRESENT	0
19219	18404	11104D	PARTICIPANT	\N	PRESENT	0
19220	18404	08056B	PARTICIPANT	\N	PRESENT	0
19221	18404	11110B	PARTICIPANT	\N	PRESENT	0
19222	18404	04053F	PARTICIPANT	\N	PRESENT	0
19223	18404	08038Y	PARTICIPANT	\N	PRESENT	0
19224	18404	08053X	PARTICIPANT	\N	PRESENT	0
19225	18404	01028R	PARTICIPANT	\N	PRESENT	0
19226	18404	04077P	PARTICIPANT	\N	PRESENT	0
19227	18404	08044W	PARTICIPANT	\N	PRESENT	0
19228	18404	08061X	PARTICIPANT	\N	PRESENT	0
19229	18404	09001P	PARTICIPANT	\N	PRESENT	0
19230	18404	14073Q	PARTICIPANT	\N	PRESENT	0
19231	18404	11111C	PARTICIPANT	\N	PRESENT	0
19232	18404	14277B	PARTICIPANT	\N	PRESENT	0
19233	18404	01043Q	PARTICIPANT	\N	PRESENT	0
19234	18404	11037K	PARTICIPANT	\N	PRESENT	0
19235	18404	01014K	PARTICIPANT	\N	PRESENT	0
19236	18404	11107G	PARTICIPANT	\N	PRESENT	0
19237	18404	11083R	PARTICIPANT	\N	PRESENT	0
19238	18404	14219Q	PARTICIPANT	\N	PRESENT	0
19239	18404	11099A	PARTICIPANT	\N	PRESENT	0
19240	18404	14103D	PARTICIPANT	\N	PRESENT	0
19241	18404	11033F	PARTICIPANT	\N	PRESENT	0
19242	18404	01044R	PARTICIPANT	\N	PRESENT	0
19243	18404	11076S	PARTICIPANT	\N	PRESENT	0
19244	18404	11069T	PARTICIPANT	\N	PRESENT	0
19245	18404	11065P	PARTICIPANT	\N	PRESENT	0
19246	18404	14221J	PARTICIPANT	\N	PRESENT	0
19247	18404	01060R	PARTICIPANT	\N	PRESENT	0
19248	18404	14034U	PARTICIPANT	\N	PRESENT	0
19249	18404	14247U	PARTICIPANT	\N	PRESENT	0
19250	18404	11093T	PARTICIPANT	\N	PRESENT	0
19251	18404	92044U	PARTICIPANT	\N	PRESENT	0
19252	18404	14275Y	PARTICIPANT	\N	PRESENT	0
19253	18404	08021P	PARTICIPANT	\N	PRESENT	0
19254	18404	11112D	PARTICIPANT	\N	PRESENT	0
19255	18404	01034P	PARTICIPANT	\N	PRESENT	0
19256	18404	01047U	PARTICIPANT	\N	PRESENT	0
19257	18404	11064N	PARTICIPANT	\N	PRESENT	0
19258	18404	01046T	PARTICIPANT	\N	PRESENT	0
19259	18404	04038G	PARTICIPANT	\N	PRESENT	0
19260	18404	01008M	PARTICIPANT	\N	PRESENT	0
19261	18404	11030C	PARTICIPANT	\N	PRESENT	0
19262	18404	11032E	PARTICIPANT	\N	PRESENT	0
19263	18404	14251Q	PARTICIPANT	\N	PRESENT	0
19264	18404	11044J	PARTICIPANT	\N	PRESENT	0
19265	18404	04078Q	PARTICIPANT	\N	PRESENT	0
19266	18404	08051V	PARTICIPANT	\N	PRESENT	0
19267	18404	08031R	PARTICIPANT	\N	PRESENT	0
19268	18404	14038Y	PARTICIPANT	\N	PRESENT	0
19269	18404	11012A	PARTICIPANT	\N	PRESENT	0
19270	18404	11081P	PARTICIPANT	\N	PRESENT	0
19271	18404	01003G	PARTICIPANT	\N	PRESENT	0
19272	18404	14018U	PARTICIPANT	\N	PRESENT	0
19273	18404	11082Q	PARTICIPANT	\N	PRESENT	0
19274	18404	95049N	PARTICIPANT	\N	PRESENT	0
19275	18404	14241N	PARTICIPANT	\N	PRESENT	0
19276	18404	14327T	PARTICIPANT	\N	PRESENT	0
19277	18404	14239U	PARTICIPANT	\N	PRESENT	0
19278	18404	98022P	PARTICIPANT	\N	PRESENT	0
19279	18404	11070L	PARTICIPANT	\N	PRESENT	0
19280	18404	01024M	PARTICIPANT	\N	PRESENT	0
19281	18404	04097T	PARTICIPANT	\N	PRESENT	0
19282	18404	07004J	PARTICIPANT	\N	PRESENT	0
19283	18404	04041B	PARTICIPANT	\N	PRESENT	0
19284	18404	14187A	PARTICIPANT	\N	PRESENT	0
19285	18404	14179A	PARTICIPANT	\N	PRESENT	0
19286	18404	14211G	PARTICIPANT	\N	PRESENT	0
19287	18404	14205J	PARTICIPANT	\N	PRESENT	0
19288	18404	08041T	PARTICIPANT	\N	PRESENT	0
19289	18404	04033B	PARTICIPANT	\N	PRESENT	0
19290	18404	11080N	PARTICIPANT	\N	PRESENT	0
19291	18404	11057P	PARTICIPANT	\N	PRESENT	0
19292	18404	99004R	PARTICIPANT	\N	PRESENT	0
19293	18404	01016M	PARTICIPANT	\N	PRESENT	0
21076	21075	11055M	PARTICIPANT	\N	PRESENT	0
21077	21075	01046T	PARTICIPANT	\N	PRESENT	0
21078	21075	04053F	PARTICIPANT	\N	PRESENT	0
21079	21075	14255U	PARTICIPANT	\N	PRESENT	0
21080	21075	04066L	PARTICIPANT	\N	PRESENT	0
21081	21075	00003C	PARTICIPANT	\N	PRESENT	0
21082	21075	11103C	PARTICIPANT	\N	PRESENT	0
21083	21075	14195A	PARTICIPANT	\N	PRESENT	0
21085	21075	11023D	PARTICIPANT	\N	PRESENT	0
21086	21075	08052W	PARTICIPANT	\N	PRESENT	0
21087	21075	14217N	PARTICIPANT	\N	PRESENT	0
21088	21075	14042U	PARTICIPANT	\N	PRESENT	0
21089	21075	12042Y	PARTICIPANT	\N	PRESENT	0
21090	21075	14281W	PARTICIPANT	\N	PRESENT	0
21091	21075	14231L	PARTICIPANT	\N	PRESENT	0
21092	21075	08041T	PARTICIPANT	\N	PRESENT	0
21093	21075	01011G	PARTICIPANT	\N	PRESENT	0
21094	21075	14121F	PARTICIPANT	\N	PRESENT	0
21095	21075	14223L	PARTICIPANT	\N	EXCUSE	0
21096	21075	14265W	PARTICIPANT	\N	PRESENT	0
21097	21075	14119M	PARTICIPANT	\N	PRESENT	0
21098	21075	14071N	PARTICIPANT	\N	PRESENT	0
21099	21075	11097X	PARTICIPANT	\N	EXCUSE	0
21100	21075	04045F	PARTICIPANT	\N	PRESENT	0
21101	21075	14227Q	PARTICIPANT	\N	PRESENT	0
21102	21075	01034P	PRESIDENT	0	PRESENT	0
21103	21075	11063M	PARTICIPANT	\N	PRESENT	0
21110	21075	11093T	PARTICIPANT	\N	EXCUSE	0
21109	21075	04092N	PARTICIPANT	\N	EXCUSE	0
21111	21075	14213J	PARTICIPANT	\N	EXCUSE	0
21354	21352	96004D	PRESIDENT	0	PRESENT	0
21353	21352	14133K	PARTICIPANT	\N	PRESENT	0
21355	21352	04054G	PARTICIPANT	\N	EXCUSE	0
21356	21352	14089Y	PARTICIPANT	\N	EXCUSE	0
21357	21352	90003B	PARTICIPANT	\N	PRESENT	0
21358	21352	14079W	PARTICIPANT	\N	EXCUSE	0
21359	21352	95030B	PARTICIPANT	\N	EXCUSE	0
21360	21352	11083R	PARTICIPANT	\N	PRESENT	0
21361	21352	14026U	PARTICIPANT	\N	EXCUSE	0
21362	21352	14097Y	PARTICIPANT	\N	PRESENT	0
21363	21352	04061F	PARTICIPANT	\N	PRESENT	0
21364	21352	14073Q	PARTICIPANT	\N	PRESENT	0
21365	21352	98046X	PARTICIPANT	\N	PRESENT	0
21366	21352	14001X	PARTICIPANT	\N	EXCUSE	0
21367	21352	04057K	PARTICIPANT	\N	PRESENT	0
21368	21352	95049N	PARTICIPANT	\N	PRESENT	0
21369	21352	04080J	PARTICIPANT	\N	PRESENT	0
21370	21352	14135M	PARTICIPANT	\N	PRESENT	0
21371	21352	01016M	PARTICIPANT	\N	PRESENT	0
21372	21352	10015M	PARTICIPANT	\N	PRESENT	0
21373	21352	11012A	PARTICIPANT	\N	EXCUSE	0
21376	21374	14133K	PARTICIPANT	\N	PRESENT	0
21377	21374	04054G	PARTICIPANT	\N	EXCUSE	0
21379	15890	11029K	PARTICIPANT	\N	EXCUSE	0
21380	15890	11080N	PARTICIPANT	\N	EXCUSE	0
21381	15890	08028W	PARTICIPANT	\N	EXCUSE	0
21382	15890	88008L	PARTICIPANT	\N	EXCUSE	0
21383	15890	04038G	PARTICIPANT	\N	EXCUSE	0
21384	15890	01059Y	PARTICIPANT	\N	EXCUSE	0
21385	15890	11088W	PARTICIPANT	\N	EXCUSE	0
21386	15890	98018T	PARTICIPANT	\N	EXCUSE	0
21387	21374	96004D	PRESIDENT	0	PRESENT	0
21388	15890	01015L	PARTICIPANT	\N	EXCUSE	0
21389	21374	14089Y	PARTICIPANT	\N	EXCUSE	0
21390	15890	14187A	PARTICIPANT	\N	EXCUSE	0
21391	15890	02002K	PARTICIPANT	\N	EXCUSE	0
21392	15890	08048B	PARTICIPANT	\N	EXCUSE	0
21393	15890	11089X	PARTICIPANT	\N	EXCUSE	0
21394	21149	14034U	PARTICIPANT	\N	PRESENT	0
21395	21374	14026U	PARTICIPANT	\N	PRESENT	0
21396	21374	14097Y	PARTICIPANT	\N	PRESENT	0
21397	21149	07029T	PARTICIPANT	\N	PRESENT	0
21398	15890	14026U	PARTICIPANT	\N	EXCUSE	0
21399	21374	14001X	PARTICIPANT	\N	EXCUSE	0
21400	15890	14121F	PARTICIPANT	\N	EXCUSE	0
21401	21374	95030B	PARTICIPANT	\N	EXCUSE	0
21402	15890	11084S	PARTICIPANT	\N	EXCUSE	0
21403	21374	14135M	PARTICIPANT	\N	PRESENT	0
21404	15890	01061S	PARTICIPANT	\N	EXCUSE	0
21405	21374	01016M	PARTICIPANT	\N	PRESENT	0
21406	15890	08062Y	PARTICIPANT	\N	EXCUSE	0
21407	21374	04045F	PARTICIPANT	\N	PRESENT	0
21408	21374	04034C	PARTICIPANT	\N	PRESENT	0
21409	15890	08021P	PARTICIPANT	\N	EXCUSE	0
21410	15890	14229S	PARTICIPANT	\N	EXCUSE	0
21411	15890	11046L	PARTICIPANT	\N	EXCUSE	0
21412	15890	11094U	PARTICIPANT	\N	EXCUSE	0
21413	21374	14249W	PARTICIPANT	\N	EXCUSE	0
21416	21414	11036J	PARTICIPANT	\N	PRESENT	0
21419	21414	08068F	PARTICIPANT	\N	PRESENT	0
21420	21414	14207L	PARTICIPANT	\N	PRESENT	0
21422	21414	90003B	PARTICIPANT	\N	PRESENT	0
21424	21414	80013X	PARTICIPANT	\N	PRESENT	0
21427	21414	14197C	PARTICIPANT	\N	PRESENT	0
21430	21414	14033T	PARTICIPANT	\N	PRESENT	0
21431	21414	14081Q	PARTICIPANT	\N	PRESENT	0
21432	21414	04048J	PARTICIPANT	\N	PRESENT	0
21433	21414	11099A	PARTICIPANT	\N	PRESENT	0
21434	21414	04049K	PARTICIPANT	\N	PRESENT	0
21435	21414	04094Q	PARTICIPANT	\N	PRESENT	0
21438	21414	11100Y	PRESIDENT	0	PRESENT	0
21440	21414	11098Y	PARTICIPANT	\N	PRESENT	0
21442	21414	11077T	PARTICIPANT	\N	PRESENT	0
21443	21414	14205J	PARTICIPANT	\N	PRESENT	0
20154	20153	01008M	PARTICIPANT	\N	PRESENT	0
20155	20153	11036J	PARTICIPANT	\N	PRESENT	0
20156	20153	11081P	PARTICIPANT	\N	PRESENT	0
20157	20153	14013P	PARTICIPANT	\N	PRESENT	0
20158	20153	08068F	PARTICIPANT	\N	PRESENT	0
20159	20153	14207L	PARTICIPANT	\N	PRESENT	0
20160	20153	11101A	PARTICIPANT	\N	PRESENT	0
20161	20153	90003B	PARTICIPANT	\N	PRESENT	0
20162	20153	08028W	PARTICIPANT	\N	PRESENT	0
20163	20153	80013X	PARTICIPANT	\N	PRESENT	0
20193	20153	08019V	PARTICIPANT	\N	EXCUSE	0
20165	20153	04089T	PARTICIPANT	\N	PRESENT	0
20166	20153	14197C	PARTICIPANT	\N	PRESENT	0
20167	20153	11110B	PARTICIPANT	\N	PRESENT	0
20168	20153	14187A	PARTICIPANT	\N	PRESENT	0
20169	20153	14033T	PARTICIPANT	\N	PRESENT	0
20170	20153	14081Q	PARTICIPANT	\N	PRESENT	0
20171	20153	04048J	PARTICIPANT	\N	PRESENT	0
20172	20153	11099A	PARTICIPANT	\N	PRESENT	0
20173	20153	04049K	PARTICIPANT	\N	PRESENT	0
20174	20153	04094Q	PARTICIPANT	\N	PRESENT	0
20175	20153	11111C	PARTICIPANT	\N	PRESENT	0
20176	20153	08015R	PARTICIPANT	\N	PRESENT	0
20177	20153	11100Y	PRESIDENT	0	PRESENT	0
20178	20153	01061S	PARTICIPANT	\N	PRESENT	0
20179	20153	11098Y	PARTICIPANT	\N	PRESENT	0
20180	20153	01043Q	PARTICIPANT	\N	PRESENT	0
20181	20153	11077T	PARTICIPANT	\N	PRESENT	0
20182	20153	14205J	PARTICIPANT	\N	PRESENT	0
20234	20194	92039X	PARTICIPANT	\N	EXCUSE	0
20184	20153	14257W	PARTICIPANT	\N	PRESENT	0
20186	20153	04088S	PARTICIPANT	\N	PRESENT	0
20187	20153	98050T	PARTICIPANT	\N	PRESENT	0
20188	20153	11090Q	PARTICIPANT	\N	PRESENT	0
20189	20153	11046L	PARTICIPANT	\N	PRESENT	0
20196	20194	08055A	PARTICIPANT	\N	PRESENT	0
20191	20153	11094U	PARTICIPANT	\N	PRESENT	0
20192	20153	11066Q	PARTICIPANT	\N	PRESENT	0
20197	20194	14093U	PARTICIPANT	\N	PRESENT	0
20198	20194	14030Q	PARTICIPANT	\N	PRESENT	0
20199	20194	96004D	PARTICIPANT	\N	PRESENT	0
20200	20194	08060W	PARTICIPANT	\N	PRESENT	0
20201	20194	11060J	PARTICIPANT	\N	PRESENT	0
20202	20194	11095V	PARTICIPANT	\N	PRESENT	0
20235	20194	95062K	PARTICIPANT	\N	EXCUSE	0
20329	18401	08055A	PARTICIPANT	\N	PRESENT	0
20205	20194	98023Q	PARTICIPANT	\N	PRESENT	0
20206	20194	11065P	PARTICIPANT	\N	PRESENT	0
20207	20194	01015L	PARTICIPANT	\N	PRESENT	0
20208	20194	11107G	PARTICIPANT	\N	PRESENT	0
20209	20194	11020A	PARTICIPANT	\N	PRESENT	0
20210	20194	02002K	PARTICIPANT	\N	PRESENT	0
20211	20194	01022K	PARTICIPANT	\N	PRESENT	0
20212	20194	04097T	PARTICIPANT	\N	PRESENT	0
20213	20194	09001P	PARTICIPANT	\N	PRESENT	0
20214	20194	11059R	PARTICIPANT	\N	PRESENT	0
20215	20194	14219Q	PARTICIPANT	\N	PRESENT	0
20330	18401	14063N	PARTICIPANT	\N	PRESENT	0
20217	20194	14031R	PARTICIPANT	\N	PRESENT	0
20218	20194	08009T	PRESIDENT	0	PRESENT	0
20219	20194	08062Y	PARTICIPANT	\N	PRESENT	0
20220	20194	14221J	PARTICIPANT	\N	PRESENT	0
20331	18401	07029T	PARTICIPANT	\N	PRESENT	0
20332	18401	14105F	PARTICIPANT	\N	PRESENT	0
20223	20194	14169X	PARTICIPANT	\N	PRESENT	0
20224	20194	14237S	PARTICIPANT	\N	PRESENT	0
20225	20194	13002U	PARTICIPANT	\N	PRESENT	0
20226	20194	05012A	PARTICIPANT	\N	PRESENT	0
20227	20194	14247U	PARTICIPANT	\N	PRESENT	0
20228	20194	14135M	PARTICIPANT	\N	PRESENT	0
20333	18401	08056B	PARTICIPANT	\N	PRESENT	0
20230	20194	14107H	PARTICIPANT	\N	PRESENT	0
20231	20194	14051J	PARTICIPANT	\N	PRESENT	0
20232	20194	14157T	PARTICIPANT	\N	PRESENT	0
20233	20194	96003C	PARTICIPANT	\N	EXCUSE	0
20334	18401	11037K	PARTICIPANT	\N	PRESENT	0
20335	18401	14061L	PARTICIPANT	\N	PRESENT	0
20336	18401	99004R	PARTICIPANT	\N	PRESENT	0
20337	18401	11089X	PARTICIPANT	\N	PRESENT	0
20338	18401	04047H	PARTICIPANT	\N	PRESENT	0
20339	18401	14111D	PARTICIPANT	\N	PRESENT	0
20341	18401	14103D	PARTICIPANT	\N	PRESENT	0
20342	18401	11066Q	PARTICIPANT	\N	PRESENT	0
20343	18401	14229S	PARTICIPANT	\N	PRESENT	0
20401	18401	11040E	PARTICIPANT	\N	PRESENT	0
20402	18401	08047A	PARTICIPANT	\N	PRESENT	0
20403	18401	04038G	PARTICIPANT	\N	PRESENT	0
20404	18401	04085P	PARTICIPANT	\N	PRESENT	0
20406	18401	14235Q	PARTICIPANT	\N	PRESENT	0
20407	18401	11034G	PARTICIPANT	\N	PRESENT	0
20408	18401	14263U	PARTICIPANT	\N	PRESENT	0
20409	18401	04088S	PARTICIPANT	\N	PRESENT	0
20410	18401	14069U	PARTICIPANT	\N	PRESENT	0
20411	18401	13002U	PARTICIPANT	\N	PRESENT	0
20412	18401	14123H	PARTICIPANT	\N	PRESENT	0
20413	18401	14097Y	PARTICIPANT	\N	PRESENT	0
20414	18401	14215L	PARTICIPANT	\N	PRESENT	0
20415	18401	87003B	PARTICIPANT	\N	PRESENT	0
20416	18401	01044R	PARTICIPANT	\N	PRESENT	0
20417	18401	14267Y	PARTICIPANT	\N	PRESENT	0
20418	18401	14147R	PARTICIPANT	\N	PRESENT	0
20419	18401	14219Q	PARTICIPANT	\N	PRESENT	0
20420	18401	14251Q	PARTICIPANT	\N	PRESENT	0
20421	18401	05008E	PARTICIPANT	\N	PRESENT	0
20422	18401	14033T	PARTICIPANT	\N	PRESENT	0
20423	18401	11026G	PARTICIPANT	\N	PRESENT	0
20424	18401	80013X	PARTICIPANT	\N	PRESENT	0
20425	18401	11033F	PARTICIPANT	\N	PRESENT	0
20426	18401	95049N	PARTICIPANT	\N	PRESENT	0
20427	18401	04048J	PARTICIPANT	\N	PRESENT	0
20428	18401	04056J	PARTICIPANT	\N	PRESENT	0
20429	18401	14217N	PARTICIPANT	\N	PRESENT	0
20430	18401	11091R	PARTICIPANT	\N	PRESENT	0
20431	18401	07034Q	PARTICIPANT	\N	PRESENT	0
20432	18401	11113E	PARTICIPANT	\N	PRESENT	0
20491	18401	98024R	PARTICIPANT	\N	PRESENT	0
20492	18401	11094U	PARTICIPANT	\N	PRESENT	0
20493	18401	14107H	PARTICIPANT	\N	PRESENT	0
20494	18401	14265W	PARTICIPANT	\N	PRESENT	0
20496	18401	11060J	PARTICIPANT	\N	PRESENT	0
20497	18401	95030B	PARTICIPANT	\N	PRESENT	0
20499	18401	11014C	PARTICIPANT	\N	PRESENT	0
20502	18401	11056N	PARTICIPANT	\N	PRESENT	0
20520	18401	04095R	PARTICIPANT	\N	PRESENT	0
20521	18401	08068F	PARTICIPANT	\N	PRESENT	0
20522	18401	14269B	PARTICIPANT	\N	PRESENT	0
20536	18401	04033B	PARTICIPANT	\N	PRESENT	0
20543	18401	11084S	PARTICIPANT	\N	PRESENT	0
20544	18401	14031R	PARTICIPANT	\N	PRESENT	0
20606	18401	05012A	PARTICIPANT	\N	PRESENT	0
20603	18401	08069G	PARTICIPANT	\N	PRESENT	0
20604	18401	01047U	PARTICIPANT	\N	PRESENT	0
20605	18401	08062Y	PARTICIPANT	\N	PRESENT	0
20609	20607	08055A	PARTICIPANT	\N	PRESENT	0
20610	20607	14093U	PARTICIPANT	\N	PRESENT	0
20611	20607	14030Q	PARTICIPANT	\N	PRESENT	0
20612	20607	96004D	PARTICIPANT	\N	PRESENT	0
20613	20607	08060W	PARTICIPANT	\N	PRESENT	0
20614	20607	11060J	PARTICIPANT	\N	PRESENT	0
20615	20607	11095V	PARTICIPANT	\N	PRESENT	0
20620	20607	01015L	PARTICIPANT	\N	PRESENT	0
20621	20607	11107G	PARTICIPANT	\N	PRESENT	0
20623	20607	02002K	PARTICIPANT	\N	PRESENT	0
20624	20607	01022K	PARTICIPANT	\N	PRESENT	0
20625	20607	04097T	PARTICIPANT	\N	PRESENT	0
20626	20607	09001P	PARTICIPANT	\N	PRESENT	0
20627	20607	11059R	PARTICIPANT	\N	PRESENT	0
20628	20607	14219Q	PARTICIPANT	\N	PRESENT	0
20630	20607	14031R	PARTICIPANT	\N	PRESENT	0
20631	20607	08009T	PRESIDENT	0	PRESENT	0
20632	20607	08062Y	PARTICIPANT	\N	PRESENT	0
20633	20607	14221J	PARTICIPANT	\N	PRESENT	0
20634	20607	92039X	PARTICIPANT	\N	EXCUSE	0
20636	20607	14169X	PARTICIPANT	\N	PRESENT	0
20637	20607	14237S	PARTICIPANT	\N	PRESENT	0
20638	20607	13002U	PARTICIPANT	\N	PRESENT	0
20639	20607	05012A	PARTICIPANT	\N	PRESENT	0
20640	20607	14247U	PARTICIPANT	\N	PRESENT	0
20642	20607	95062K	PARTICIPANT	\N	EXCUSE	0
20280	20151	89017R	PARTICIPANT	\N	EXCUSE	0
20281	20151	01031L	PRESIDENT	0	PRESENT	0
20282	20151	05004A	PARTICIPANT	\N	PRESENT	0
20283	20151	01013J	PARTICIPANT	\N	PRESENT	0
20405	20151	04047H	RAPPORTEUR_AVIS	\N	PRESENT	0
20285	20151	11040E	PARTICIPANT	\N	PRESENT	0
20286	20151	08014Q	PARTICIPANT	\N	PRESENT	0
20287	20151	14167V	PARTICIPANT	\N	PRESENT	0
20643	20607	14107H	PARTICIPANT	\N	PRESENT	0
20289	20151	14083S	PARTICIPANT	\N	PRESENT	0
20290	20151	11053K	PARTICIPANT	\N	PRESENT	0
20291	20151	14085U	PARTICIPANT	\N	PRESENT	0
20292	20151	11042G	PARTICIPANT	\N	PRESENT	0
20644	20607	14051J	PARTICIPANT	\N	PRESENT	0
20294	20151	04086Q	PARTICIPANT	\N	PRESENT	0
20295	20151	04055H	PARTICIPANT	\N	PRESENT	0
20296	20151	11070L	PARTICIPANT	\N	PRESENT	0
20297	20151	11088W	PARTICIPANT	\N	PRESENT	0
20298	20151	14327T	PARTICIPANT	\N	PRESENT	0
20299	20151	08022Q	PARTICIPANT	\N	PRESENT	0
20300	20151	01027Q	PARTICIPANT	\N	PRESENT	0
20301	20151	04071H	PARTICIPANT	\N	PRESENT	0
20302	20151	11074Q	PARTICIPANT	\N	PRESENT	0
20303	20151	98053W	PARTICIPANT	\N	PRESENT	0
20645	20607	14157T	PARTICIPANT	\N	PRESENT	0
20305	20151	14199E	PARTICIPANT	\N	PRESENT	0
20306	20151	01057W	PARTICIPANT	\N	PRESENT	0
20307	20151	08016S	PARTICIPANT	\N	PRESENT	0
20308	20151	08069G	PARTICIPANT	\N	PRESENT	0
20309	20151	11048N	PARTICIPANT	\N	PRESENT	0
20310	20151	99004R	PARTICIPANT	\N	PRESENT	0
20311	20151	04061F	PARTICIPANT	\N	PRESENT	0
20312	20151	14159V	PARTICIPANT	\N	PRESENT	0
20313	20151	07029T	PARTICIPANT	\N	PRESENT	0
20314	20151	14277B	PARTICIPANT	\N	PRESENT	0
20315	20151	08010L	PARTICIPANT	\N	PRESENT	0
20316	20151	08034U	PARTICIPANT	\N	PRESENT	0
20317	20151	01048V	PARTICIPANT	\N	PRESENT	0
20318	20151	98046X	PARTICIPANT	\N	PRESENT	0
20319	20151	11085T	PARTICIPANT	\N	PRESENT	0
20320	20151	08011M	PARTICIPANT	\N	PRESENT	0
20646	20607	96003C	PARTICIPANT	\N	EXCUSE	0
20322	20151	08061X	PARTICIPANT	\N	PRESENT	0
20323	20151	01016M	PARTICIPANT	\N	PRESENT	0
20324	20151	14225N	PARTICIPANT	\N	PRESENT	0
20325	20151	11012A	PARTICIPANT	\N	PRESENT	0
20326	20151	11057P	PARTICIPANT	\N	PRESENT	0
20327	20151	14173T	PARTICIPANT	\N	PRESENT	0
20647	18401	14169X	PARTICIPANT	\N	PRESENT	0
20648	18401	14109K	PARTICIPANT	\N	PRESENT	0
20649	20607	11114F	PARTICIPANT	\N	PRESENT	0
20650	18401	08061X	PARTICIPANT	\N	PRESENT	0
20651	18401	14133K	PARTICIPANT	\N	PRESENT	0
20652	18401	90003B	PARTICIPANT	\N	PRESENT	0
20705	18401	04034C	PARTICIPANT	\N	PRESENT	0
20708	18401	01008M	PARTICIPANT	\N	PRESENT	0
20711	18401	14193X	PARTICIPANT	\N	PRESENT	0
20712	18401	14071N	PARTICIPANT	\N	PRESENT	0
20713	18401	14195A	PARTICIPANT	\N	PRESENT	0
20714	18401	11081P	PARTICIPANT	\N	PRESENT	0
20716	18401	14038Y	PARTICIPANT	\N	PRESENT	0
20717	18401	08034U	PARTICIPANT	\N	PRESENT	0
20718	18401	14042U	PARTICIPANT	\N	PRESENT	0
20719	18401	08015R	PARTICIPANT	\N	PRESENT	0
20720	18401	11064N	PARTICIPANT	\N	PRESENT	0
20721	18401	11098Y	PARTICIPANT	\N	PRESENT	0
20722	18401	08014Q	PARTICIPANT	\N	PRESENT	0
20723	18401	11107G	PARTICIPANT	\N	PRESENT	0
20724	18401	14213J	PARTICIPANT	\N	PRESENT	0
20725	18401	14121F	PARTICIPANT	\N	PRESENT	0
20784	18401	08022Q	PARTICIPANT	\N	PRESENT	0
20785	18401	10006L	PARTICIPANT	\N	PRESENT	0
20786	18401	14199E	PARTICIPANT	\N	PRESENT	0
20787	18401	01028R	PARTICIPANT	\N	PRESENT	0
20788	18401	14034U	PARTICIPANT	\N	PRESENT	0
20789	18401	14209N	PARTICIPANT	\N	PRESENT	0
20790	18401	11103C	PARTICIPANT	\N	PRESENT	0
20791	18401	11114F	PARTICIPANT	\N	PRESENT	0
20792	18401	14065Q	PARTICIPANT	\N	PRESENT	0
20872	20871	11055M	PARTICIPANT	\N	PRESENT	0
20873	20871	04053F	PARTICIPANT	\N	PRESENT	0
20874	20871	11103C	PARTICIPANT	\N	PRESENT	0
20878	20871	08052W	PARTICIPANT	\N	PRESENT	0
20876	20871	14195A	PARTICIPANT	\N	PRESENT	0
20877	20871	11031D	PARTICIPANT	\N	PRESENT	0
20879	20871	14217N	PARTICIPANT	\N	PRESENT	0
20880	20871	14042U	PARTICIPANT	\N	PRESENT	0
20881	20871	14281W	PARTICIPANT	\N	PRESENT	0
20882	20871	01003G	PARTICIPANT	\N	PRESENT	0
20883	20871	14231L	PARTICIPANT	\N	PRESENT	0
20884	20871	01011G	PARTICIPANT	\N	PRESENT	0
20885	20871	14213J	PARTICIPANT	\N	PRESENT	0
20886	20871	14121F	PARTICIPANT	\N	PRESENT	0
20887	20871	11067R	PARTICIPANT	\N	PRESENT	0
20888	20871	04092N	PRESIDENT	0	PRESENT	0
20889	20871	14265W	PARTICIPANT	\N	PRESENT	0
20890	20871	14119M	PARTICIPANT	\N	PRESENT	0
20891	20871	14071N	PARTICIPANT	\N	PRESENT	0
20892	20871	11097X	PARTICIPANT	\N	EXCUSE	0
20893	20871	01034P	PRESIDENT	1	PRESENT	0
20894	20871	11063M	PARTICIPANT	\N	PRESENT	0
21001	20866	04070G	PRESIDENT	0	PRESENT	0
21033	20149	11026G	PARTICIPANT	\N	PRESENT	0
21034	20149	04034C	PARTICIPANT	\N	PRESENT	0
21035	20149	11042G	PARTICIPANT	\N	PRESENT	0
21036	20149	11033F	PARTICIPANT	\N	PRESENT	0
21037	20149	11076S	PARTICIPANT	\N	PRESENT	0
21038	20149	14089Y	PARTICIPANT	\N	PRESENT	0
21039	20149	04078Q	PARTICIPANT	\N	PRESENT	0
21040	20149	01041N	PARTICIPANT	\N	PRESENT	0
21041	20149	14041T	PARTICIPANT	\N	PRESENT	0
21042	20149	99004R	PARTICIPANT	\N	PRESENT	0
21043	20149	04042C	PARTICIPANT	\N	PRESENT	0
21044	20149	14215L	PARTICIPANT	\N	PRESENT	0
21045	20149	01027Q	PARTICIPANT	\N	PRESENT	0
21046	20150	14063N	PARTICIPANT	\N	PRESENT	0
21047	20150	08055A	PARTICIPANT	\N	PRESENT	0
21031	20149	14063N	PARTICIPANT	\N	PRESENT	0
21032	20149	08055A	PARTICIPANT	\N	PRESENT	0
21048	20150	11026G	PARTICIPANT	\N	PRESENT	0
21049	20150	04034C	PARTICIPANT	\N	PRESENT	0
21050	20150	11042G	PARTICIPANT	\N	PRESENT	0
21051	20150	11033F	PARTICIPANT	\N	PRESENT	0
21052	20150	11076S	PARTICIPANT	\N	PRESENT	0
21053	20150	14089Y	PARTICIPANT	\N	PRESENT	0
21054	20150	04078Q	PARTICIPANT	\N	PRESENT	0
21055	20150	01041N	PARTICIPANT	\N	PRESENT	0
21056	20150	14041T	PARTICIPANT	\N	PRESENT	0
21057	20150	99004R	PARTICIPANT	\N	PRESENT	0
21058	20150	04042C	PARTICIPANT	\N	PRESENT	0
21059	20150	14215L	PARTICIPANT	\N	PRESENT	0
21060	20150	01027Q	PARTICIPANT	\N	PRESENT	0
21061	20150	04085P	PARTICIPANT	\N	PRESENT	0
21062	20150	14103D	PARTICIPANT	\N	PRESENT	0
21063	20150	11037K	PARTICIPANT	\N	PRESENT	0
21064	20150	04047H	PARTICIPANT	\N	PRESENT	0
21065	20150	04086Q	PARTICIPANT	\N	PRESENT	0
21066	20150	11091R	PARTICIPANT	\N	PRESENT	0
21067	20150	04038G	PARTICIPANT	\N	PRESENT	0
21068	20150	14265W	PARTICIPANT	\N	PRESENT	0
21069	20150	11109J	PARTICIPANT	\N	PRESENT	0
21070	20150	13002U	PARTICIPANT	\N	PRESENT	0
21071	20150	14061L	PARTICIPANT	\N	PRESENT	0
21072	20150	05008E	PARTICIPANT	\N	PRESENT	0
21073	20150	11107G	PARTICIPANT	\N	PRESENT	0
21074	20150	04044E	PARTICIPANT	\N	PRESENT	0
21084	20150	11054L	PARTICIPANT	\N	PRESENT	0
21105	20150	14217N	PARTICIPANT	\N	PRESENT	0
21106	20150	01011G	PARTICIPANT	\N	PRESENT	0
21107	20150	08018U	PARTICIPANT	\N	PRESENT	0
21108	20150	08034U	PARTICIPANT	\N	PRESENT	0
21112	20150	04048J	PARTICIPANT	\N	PRESENT	0
21113	20150	07026Q	PARTICIPANT	\N	PRESENT	0
21114	20150	01031L	PARTICIPANT	\N	PRESENT	0
21115	20150	80013X	PARTICIPANT	\N	PRESENT	0
21116	20150	14195A	PARTICIPANT	\N	PRESENT	0
21117	20150	11067R	PARTICIPANT	\N	PRESENT	0
21118	20150	14038Y	PARTICIPANT	\N	PRESENT	0
21119	20150	14133K	PARTICIPANT	\N	PRESENT	0
21120	20150	04033B	PARTICIPANT	\N	PRESENT	0
21121	20150	11036J	PARTICIPANT	\N	PRESENT	0
21122	20150	11084S	PARTICIPANT	\N	PRESENT	0
21123	20150	04088S	PARTICIPANT	\N	PRESENT	0
21125	21124	14030Q	PARTICIPANT	\N	EXCUSE	0
21126	21124	08043V	PARTICIPANT	\N	PRESENT	0
21127	21124	08060W	PARTICIPANT	\N	EXCUSE	0
21128	21124	11029K	PARTICIPANT	\N	PRESENT	0
21129	21124	11031D	PARTICIPANT	\N	PRESENT	0
21130	21124	80013X	PARTICIPANT	\N	PRESENT	0
20102	20101	11076S	PARTICIPANT	\N	PRESENT	0
20103	20101	04054G	PARTICIPANT	\N	PRESENT	0
20104	20101	04040A	PARTICIPANT	\N	PRESENT	0
20105	20101	08058D	PARTICIPANT	\N	PRESENT	0
20106	20101	04042C	PARTICIPANT	\N	PRESENT	0
20107	20101	98029W	PARTICIPANT	\N	PRESENT	0
20108	20101	11080N	PARTICIPANT	\N	EXCUSE	0
20109	20101	11027H	PARTICIPANT	\N	PRESENT	0
20110	20101	98018T	PARTICIPANT	\N	PRESENT	0
20111	20101	92018S	PARTICIPANT	\N	PRESENT	0
20112	20101	92020L	PARTICIPANT	\N	PRESENT	0
20113	20101	95030B	PARTICIPANT	\N	PRESENT	0
20114	20101	97011G	PARTICIPANT	\N	PRESENT	0
20118	20101	14014Q	PARTICIPANT	\N	PRESENT	0
20116	20101	07024N	PARTICIPANT	\N	PRESENT	0
20117	20101	04095R	PARTICIPANT	\N	PRESENT	0
20119	20101	11015D	PARTICIPANT	\N	PRESENT	0
20120	20101	95035G	PARTICIPANT	\N	PRESENT	0
20121	20101	98022P	PARTICIPANT	\N	PRESENT	0
20122	20101	11064N	PARTICIPANT	\N	PRESENT	0
20123	20101	04078Q	PARTICIPANT	\N	PRESENT	0
20124	20101	14097Y	PARTICIPANT	\N	PRESENT	0
20125	20101	04036E	PARTICIPANT	\N	PRESENT	0
20126	20101	14039A	PARTICIPANT	\N	EXCUSE	0
20127	20101	04077P	PARTICIPANT	\N	PRESENT	0
20128	20101	92031P	PARTICIPANT	\N	PRESENT	0
20129	20101	11106F	PARTICIPANT	\N	PRESENT	0
20130	20101	14251Q	PARTICIPANT	\N	PRESENT	0
20131	20101	08053X	PARTICIPANT	\N	PRESENT	0
20132	20101	11082Q	PARTICIPANT	\N	PRESENT	0
20133	20101	11105E	PARTICIPANT	\N	EXCUSE	0
20134	20101	14253S	PARTICIPANT	\N	PRESENT	0
20135	20101	14028W	PARTICIPANT	\N	PRESENT	0
20136	20101	98021N	PARTICIPANT	\N	PRESENT	0
20137	20101	04080J	PARTICIPANT	\N	PRESENT	0
20138	20101	95059Q	PRESIDENT	0	PRESENT	0
20139	20101	86044G	PARTICIPANT	\N	PRESENT	0
20140	20101	01014K	PARTICIPANT	\N	PRESENT	0
20141	20101	11054L	PARTICIPANT	\N	PRESENT	0
20142	20101	01056V	PARTICIPANT	\N	PRESENT	0
20143	20101	92044U	PARTICIPANT	\N	PRESENT	0
20144	20101	08034U	PARTICIPANT	\N	PRESENT	0
20145	20101	14093U	PARTICIPANT	\N	PRESENT	0
20146	20101	08065C	PARTICIPANT	\N	PRESENT	0
20147	20101	14193X	PARTICIPANT	\N	PRESENT	0
20656	20655	89017R	PARTICIPANT	\N	EXCUSE	0
20657	20655	01031L	PRESIDENT	0	PRESENT	0
20658	20655	05004A	PARTICIPANT	\N	PRESENT	0
20659	20655	01013J	PARTICIPANT	\N	PRESENT	0
20715	20655	04047H	PARTICIPANT	\N	PRESENT	0
20661	20655	11040E	PARTICIPANT	\N	PRESENT	0
20662	20655	08014Q	PARTICIPANT	\N	PRESENT	0
20663	20655	14167V	PARTICIPANT	\N	PRESENT	0
20867	20866	14133K	PARTICIPANT	\N	PRESENT	0
20665	20655	14083S	PARTICIPANT	\N	PRESENT	0
20666	20655	11053K	PARTICIPANT	\N	PRESENT	0
20667	20655	14085U	PARTICIPANT	\N	PRESENT	0
20668	20655	11042G	PARTICIPANT	\N	PRESENT	0
20868	20866	11029K	PARTICIPANT	\N	PRESENT	0
20670	20655	04086Q	PARTICIPANT	\N	PRESENT	0
20671	20655	04055H	PARTICIPANT	\N	PRESENT	0
20672	20655	11070L	PARTICIPANT	\N	PRESENT	0
20673	20655	11088W	PARTICIPANT	\N	PRESENT	0
20674	20655	14327T	PARTICIPANT	\N	PRESENT	0
20675	20655	08022Q	PARTICIPANT	\N	PRESENT	0
20676	20655	01027Q	PARTICIPANT	\N	PRESENT	0
20677	20655	04071H	PARTICIPANT	\N	PRESENT	0
20678	20655	11074Q	PARTICIPANT	\N	PRESENT	0
21004	18363	11044J	PARTICIPANT	\N	PRESENT	0
21132	21124	14014Q	PARTICIPANT	\N	EXCUSE	0
20681	20655	14199E	PARTICIPANT	\N	PRESENT	0
20682	20655	01057W	PARTICIPANT	\N	PRESENT	0
20683	20655	08016S	PARTICIPANT	\N	PRESENT	0
20684	20655	08069G	PARTICIPANT	\N	PRESENT	0
20685	20655	11048N	PARTICIPANT	\N	PRESENT	0
20686	20655	99004R	PARTICIPANT	\N	PRESENT	0
20687	20655	04061F	PARTICIPANT	\N	PRESENT	0
20688	20655	14159V	PARTICIPANT	\N	PRESENT	0
20689	20655	07029T	PARTICIPANT	\N	PRESENT	0
20690	20655	14277B	PARTICIPANT	\N	PRESENT	0
20691	20655	08010L	PARTICIPANT	\N	PRESENT	0
20692	20655	08034U	PARTICIPANT	\N	PRESENT	0
20693	20655	01048V	PARTICIPANT	\N	PRESENT	0
20694	20655	98046X	PARTICIPANT	\N	PRESENT	0
20695	20655	11085T	PARTICIPANT	\N	PRESENT	0
20696	20655	08011M	PARTICIPANT	\N	PRESENT	0
21006	18363	11099A	PARTICIPANT	\N	PRESENT	0
20698	20655	08061X	PARTICIPANT	\N	PRESENT	0
20699	20655	01016M	PARTICIPANT	\N	PRESENT	0
20700	20655	14225N	PARTICIPANT	\N	PRESENT	0
20701	20655	11012A	PARTICIPANT	\N	PRESENT	0
20702	20655	11057P	PARTICIPANT	\N	PRESENT	0
20703	20655	14173T	PARTICIPANT	\N	PRESENT	0
21007	18363	11048N	PARTICIPANT	\N	PRESENT	0
21008	18363	08010L	PARTICIPANT	\N	PRESENT	0
21011	18363	11098Y	PARTICIPANT	\N	PRESENT	0
21012	18363	04045F	PARTICIPANT	\N	PRESENT	0
21015	18363	14231L	PARTICIPANT	\N	PRESENT	0
21017	18363	14051J	PARTICIPANT	\N	PRESENT	0
21019	18363	11037K	PARTICIPANT	\N	EXCUSE	0
21022	18363	11035H	PARTICIPANT	\N	EXCUSE	0
21024	18363	11034G	PARTICIPANT	\N	EXCUSE	0
21028	18363	14063N	PARTICIPANT	\N	PRESENT	0
21030	18363	08051V	PARTICIPANT	\N	EXCUSE	0
21131	21124	11091R	PARTICIPANT	\N	PRESENT	0
21133	21124	07026Q	PARTICIPANT	\N	PRESENT	0
21134	21124	95035G	PARTICIPANT	\N	EXCUSE	0
21135	21124	08056B	PARTICIPANT	\N	EXCUSE	0
21136	21124	08069G	PARTICIPANT	\N	PRESENT	0
21137	21124	09001P	PRESIDENT	0	PRESENT	0
21138	21124	04036E	PARTICIPANT	\N	PRESENT	0
21139	21124	07029T	PARTICIPANT	\N	PRESENT	0
21140	21124	08017T	PARTICIPANT	\N	PRESENT	0
21141	21124	11067R	PARTICIPANT	\N	PRESENT	0
21142	21124	14109K	PARTICIPANT	\N	EXCUSE	0
21143	21124	14187A	PARTICIPANT	\N	EXCUSE	0
21144	21124	14259Y	PARTICIPANT	\N	EXCUSE	0
21145	21124	14041T	PARTICIPANT	\N	EXCUSE	0
21146	21124	14237S	PARTICIPANT	\N	EXCUSE	0
21147	20150	14033T	PARTICIPANT	\N	PRESENT	0
21148	20150	11060J	PARTICIPANT	\N	PRESENT	0
21182	20152	14063N	PARTICIPANT	\N	PRESENT	0
21183	20152	13002U	PARTICIPANT	\N	PRESENT	0
21184	20152	14269B	PARTICIPANT	\N	PRESENT	0
21186	20152	11084S	PARTICIPANT	\N	PRESENT	0
21187	20152	04085P	PARTICIPANT	\N	PRESENT	0
21211	20152	80013X	PARTICIPANT	\N	PRESENT	0
21212	20152	11042G	PARTICIPANT	\N	PRESENT	0
21213	20152	14219Q	PARTICIPANT	\N	PRESENT	0
21214	20152	14041T	PARTICIPANT	\N	PRESENT	0
21215	20152	14265W	PARTICIPANT	\N	PRESENT	0
21216	20152	14061L	PARTICIPANT	\N	PRESENT	0
21217	20152	99004R	PARTICIPANT	\N	PRESENT	0
21218	20152	11060J	PARTICIPANT	\N	PRESENT	0
21219	20152	11091R	PARTICIPANT	\N	PRESENT	0
21220	20152	14273W	PARTICIPANT	\N	PRESENT	0
21221	20152	11033F	PARTICIPANT	\N	PRESENT	0
21222	20152	11034G	PARTICIPANT	\N	PRESENT	0
21223	20152	04047H	PARTICIPANT	\N	PRESENT	0
21224	20152	04044E	PARTICIPANT	\N	PRESENT	0
21225	20152	11026G	PARTICIPANT	\N	PRESENT	0
21226	20152	04086Q	PARTICIPANT	\N	PRESENT	0
21227	20152	08043V	PARTICIPANT	\N	PRESENT	0
21228	20152	14157T	PARTICIPANT	\N	PRESENT	0
21229	20152	07034Q	PARTICIPANT	\N	PRESENT	0
21230	20152	04038G	PARTICIPANT	\N	PRESENT	0
21231	20152	14121F	PARTICIPANT	\N	PRESENT	0
21232	20152	01041N	PARTICIPANT	\N	PRESENT	0
21234	20152	04059M	PARTICIPANT	\N	PRESENT	0
21235	20152	04057K	PARTICIPANT	\N	PRESENT	0
21236	20152	07029T	PARTICIPANT	\N	PRESENT	0
21180	20152	08024S	PARTICIPANT	\N	PRESENT	0
21181	20152	11054L	PARTICIPANT	\N	PRESENT	0
21238	20152	11107G	PARTICIPANT	\N	PRESENT	0
21239	20152	11071M	PARTICIPANT	\N	PRESENT	0
21242	20152	04056J	PARTICIPANT	\N	PRESENT	0
21243	20152	14033T	PARTICIPANT	\N	PRESENT	0
21244	20152	04043D	PARTICIPANT	\N	PRESENT	0
21245	20152	04036E	PARTICIPANT	\N	PRESENT	0
21246	20152	07024N	PARTICIPANT	\N	PRESENT	0
21247	20152	14034U	PARTICIPANT	\N	PRESENT	0
21301	20152	14073Q	PARTICIPANT	\N	PRESENT	0
21302	20152	04034C	PARTICIPANT	\N	PRESENT	0
21303	20152	08034U	PARTICIPANT	\N	PRESENT	0
21304	20152	11039M	PARTICIPANT	\N	PRESENT	0
21305	20152	05008E	PARTICIPANT	\N	PRESENT	0
21306	20152	04088S	PARTICIPANT	\N	PRESENT	0
20237	20236	08025T	PARTICIPANT	\N	PRESENT	0
20238	20236	04085P	PARTICIPANT	\N	PRESENT	0
20239	20236	05008E	PRESIDENT	0	PRESENT	0
20240	20236	11030C	PARTICIPANT	\N	PRESENT	0
20241	20236	11033F	PARTICIPANT	\N	EXCUSE	0
20242	20236	14065Q	PARTICIPANT	\N	PRESENT	0
20243	20236	14069U	PARTICIPANT	\N	PRESENT	0
20244	20236	04047H	PARTICIPANT	\N	PRESENT	0
20245	20236	11032E	PARTICIPANT	\N	PRESENT	0
20246	20236	04038G	PARTICIPANT	\N	PRESENT	0
20247	20236	99002P	PARTICIPANT	\N	PRESENT	0
20248	20236	11056N	PARTICIPANT	\N	EXCUSE	0
20249	20236	11035H	PARTICIPANT	\N	PRESENT	0
20250	20236	14041T	PARTICIPANT	\N	PRESENT	0
20251	20236	11113E	PARTICIPANT	\N	PRESENT	0
20252	20236	01024M	PARTICIPANT	\N	PRESENT	0
20253	20236	14215L	PARTICIPANT	\N	PRESENT	0
20254	20236	11034G	PARTICIPANT	\N	PRESENT	0
20255	20236	08018U	PARTICIPANT	\N	PRESENT	0
20256	20236	01007L	PARTICIPANT	\N	PRESENT	0
20257	20236	11049P	PARTICIPANT	\N	PRESENT	0
20258	20236	08044W	PARTICIPANT	\N	PRESENT	0
20259	20236	11084S	PARTICIPANT	\N	PRESENT	0
20260	20236	11026G	PARTICIPANT	\N	PRESENT	0
20261	20236	04079R	PARTICIPANT	\N	PRESENT	0
20262	20236	14111D	PARTICIPANT	\N	PRESENT	0
20263	20236	14001X	PARTICIPANT	\N	PRESENT	0
20434	20433	11076S	PARTICIPANT	\N	PRESENT	0
20265	20236	01060R	PARTICIPANT	\N	PRESENT	0
20266	20236	14147R	PARTICIPANT	\N	PRESENT	0
20267	20236	95049N	PARTICIPANT	\N	PRESENT	0
20268	20236	04074L	PARTICIPANT	\N	PRESENT	0
20269	20236	10015M	PARTICIPANT	\N	PRESENT	0
20270	20236	95063L	PARTICIPANT	\N	PRESENT	0
20271	20236	01019Q	PARTICIPANT	\N	PRESENT	0
20272	20236	01028R	PARTICIPANT	\N	PRESENT	0
20273	20236	98035U	PARTICIPANT	\N	PRESENT	0
20274	20236	04056J	PARTICIPANT	\N	PRESENT	0
20275	20236	14275Y	PARTICIPANT	\N	PRESENT	0
20276	20236	04044E	PARTICIPANT	\N	PRESENT	0
20277	20236	11037K	PARTICIPANT	\N	PRESENT	0
20278	20236	95067Q	PARTICIPANT	\N	PRESENT	0
20279	20236	01047U	PARTICIPANT	\N	PRESENT	0
20344	20340	11076S	PARTICIPANT	\N	PRESENT	0
20345	20340	04054G	PARTICIPANT	\N	PRESENT	0
20346	20340	04040A	PARTICIPANT	\N	PRESENT	0
20347	20340	08058D	PARTICIPANT	\N	PRESENT	0
20348	20340	04042C	PARTICIPANT	\N	PRESENT	0
20349	20340	77002U	PARTICIPANT	\N	PRESENT	0
20350	20340	98029W	PARTICIPANT	\N	PRESENT	0
20351	20340	11080N	PARTICIPANT	\N	PRESENT	0
20352	20340	11027H	PARTICIPANT	\N	PRESENT	0
20353	20340	98018T	PARTICIPANT	\N	PRESENT	0
20354	20340	92018S	PARTICIPANT	\N	PRESENT	0
20355	20340	92020L	PARTICIPANT	\N	PRESENT	0
20356	20340	95030B	PARTICIPANT	\N	PRESENT	0
20435	20433	04054G	PARTICIPANT	\N	PRESENT	0
20358	20340	95031C	PARTICIPANT	\N	PRESENT	0
20359	20340	97011G	PARTICIPANT	\N	PRESENT	0
20360	20340	08065C	PARTICIPANT	\N	PRESENT	0
20361	20340	04035D	PARTICIPANT	\N	PRESENT	0
20362	20340	07024N	PARTICIPANT	\N	PRESENT	0
20363	20340	04095R	PARTICIPANT	\N	PRESENT	0
20364	20340	14014Q	PARTICIPANT	\N	PRESENT	0
20365	20340	11015D	PARTICIPANT	\N	PRESENT	0
20366	20340	07004J	PARTICIPANT	\N	PRESENT	0
20436	20433	04040A	PARTICIPANT	\N	PRESENT	0
20368	20340	08056B	PARTICIPANT	\N	PRESENT	0
20369	20340	14211G	PARTICIPANT	\N	PRESENT	0
20370	20340	98022P	PARTICIPANT	\N	PRESENT	0
20371	20340	11064N	PARTICIPANT	\N	PRESENT	0
20437	20433	08058D	PARTICIPANT	\N	PRESENT	0
20373	20340	04078Q	PARTICIPANT	\N	PRESENT	0
20374	20340	14097Y	PARTICIPANT	\N	PRESENT	0
20375	20340	95041E	PARTICIPANT	\N	PRESENT	0
20376	20340	04036E	PARTICIPANT	\N	PRESENT	0
20377	20340	14039A	PARTICIPANT	\N	EXCUSE	0
20378	20340	04077P	PARTICIPANT	\N	PRESENT	0
20438	20433	04042C	PARTICIPANT	\N	PRESENT	0
20380	20340	92031P	PARTICIPANT	\N	PRESENT	0
20381	20340	11106F	PARTICIPANT	\N	PRESENT	0
20382	20340	14251Q	PARTICIPANT	\N	PRESENT	0
20383	20340	83042R	PARTICIPANT	\N	PRESENT	0
20384	20340	08053X	PARTICIPANT	\N	PRESENT	0
20439	20433	77002U	PARTICIPANT	\N	PRESENT	0
20386	20340	11105E	PARTICIPANT	\N	EXCUSE	0
20387	20340	14253S	PARTICIPANT	\N	PRESENT	0
20388	20340	08047A	PARTICIPANT	\N	PRESENT	0
20389	20340	14028W	PARTICIPANT	\N	PRESENT	0
20390	20340	14193X	PARTICIPANT	\N	PRESENT	0
20391	20340	98021N	PARTICIPANT	\N	PRESENT	0
20440	20433	98029W	PARTICIPANT	\N	PRESENT	0
20393	20340	04080J	PARTICIPANT	\N	PRESENT	0
20394	20340	95059Q	PRESIDENT	0	PRESENT	0
20395	20340	86044G	PARTICIPANT	\N	PRESENT	0
20396	20340	01014K	PARTICIPANT	\N	PRESENT	0
20397	20340	11054L	PARTICIPANT	\N	PRESENT	0
20398	20340	01056V	PARTICIPANT	\N	PRESENT	0
20399	20340	92044U	PARTICIPANT	\N	PRESENT	0
20400	20340	08049C	PARTICIPANT	\N	PRESENT	0
20441	20433	11080N	PARTICIPANT	\N	PRESENT	0
20442	20433	11027H	PARTICIPANT	\N	PRESENT	0
20443	20433	98018T	PARTICIPANT	\N	PRESENT	0
20444	20433	92018S	PARTICIPANT	\N	PRESENT	0
20445	20433	92020L	PARTICIPANT	\N	PRESENT	0
20446	20433	95030B	PARTICIPANT	\N	PRESENT	0
20500	20495	08025T	PARTICIPANT	\N	PRESENT	0
20448	20433	95031C	PARTICIPANT	\N	PRESENT	0
20449	20433	97011G	PARTICIPANT	\N	PRESENT	0
20450	20433	08065C	PARTICIPANT	\N	PRESENT	0
20451	20433	04035D	PARTICIPANT	\N	PRESENT	0
20452	20433	07024N	PARTICIPANT	\N	PRESENT	0
20453	20433	04095R	PARTICIPANT	\N	PRESENT	0
20454	20433	14014Q	PARTICIPANT	\N	PRESENT	0
20455	20433	11015D	PARTICIPANT	\N	PRESENT	0
20456	20433	07004J	PARTICIPANT	\N	PRESENT	0
20501	20495	04085P	PARTICIPANT	\N	PRESENT	0
20458	20433	08056B	PARTICIPANT	\N	PRESENT	0
20459	20433	14211G	PARTICIPANT	\N	PRESENT	0
20460	20433	98022P	PARTICIPANT	\N	PRESENT	0
20461	20433	11064N	PARTICIPANT	\N	PRESENT	0
20503	20495	05008E	PRESIDENT	0	PRESENT	0
20463	20433	04078Q	PARTICIPANT	\N	PRESENT	0
20464	20433	14097Y	PARTICIPANT	\N	PRESENT	0
20465	20433	95041E	PARTICIPANT	\N	PRESENT	0
20466	20433	04036E	PARTICIPANT	\N	PRESENT	0
20467	20433	14039A	PARTICIPANT	\N	EXCUSE	0
20468	20433	04077P	PARTICIPANT	\N	PRESENT	0
20504	20495	11030C	PARTICIPANT	\N	PRESENT	0
20470	20433	92031P	PARTICIPANT	\N	PRESENT	0
20471	20433	11106F	PARTICIPANT	\N	PRESENT	0
20472	20433	14251Q	PARTICIPANT	\N	PRESENT	0
20473	20433	83042R	PARTICIPANT	\N	PRESENT	0
20474	20433	08053X	PARTICIPANT	\N	PRESENT	0
20505	20495	11033F	PARTICIPANT	\N	EXCUSE	0
20476	20433	11105E	PARTICIPANT	\N	EXCUSE	0
20477	20433	14253S	PARTICIPANT	\N	PRESENT	0
20478	20433	08047A	PARTICIPANT	\N	PRESENT	0
20479	20433	14028W	PARTICIPANT	\N	PRESENT	0
20480	20433	14193X	PARTICIPANT	\N	PRESENT	0
20481	20433	98021N	PARTICIPANT	\N	PRESENT	0
20506	20495	14065Q	PARTICIPANT	\N	PRESENT	0
20483	20433	04080J	PARTICIPANT	\N	PRESENT	0
20484	20433	95059Q	PRESIDENT	0	PRESENT	0
20485	20433	86044G	PARTICIPANT	\N	PRESENT	0
20486	20433	01014K	PARTICIPANT	\N	PRESENT	0
20487	20433	11054L	PARTICIPANT	\N	PRESENT	0
20488	20433	01056V	PARTICIPANT	\N	PRESENT	0
20489	20433	92044U	PARTICIPANT	\N	PRESENT	0
20490	20433	08049C	PARTICIPANT	\N	PRESENT	0
20507	20495	14069U	PARTICIPANT	\N	PRESENT	0
20508	20495	04047H	PARTICIPANT	\N	PRESENT	0
20509	20495	04038G	PARTICIPANT	\N	PRESENT	0
20510	20495	99002P	PARTICIPANT	\N	PRESENT	0
20511	20495	11056N	PARTICIPANT	\N	EXCUSE	0
20512	20495	11035H	PARTICIPANT	\N	PRESENT	0
20513	20495	14041T	PARTICIPANT	\N	PRESENT	0
20514	20495	11113E	PARTICIPANT	\N	PRESENT	0
20515	20495	01024M	PARTICIPANT	\N	PRESENT	0
20516	20495	14215L	PARTICIPANT	\N	PRESENT	0
20517	20495	11034G	PARTICIPANT	\N	PRESENT	0
20518	20495	01007L	PARTICIPANT	\N	PRESENT	0
20519	20495	11049P	PARTICIPANT	\N	PRESENT	0
20523	20495	08044W	PARTICIPANT	\N	PRESENT	0
20524	20495	14001X	PARTICIPANT	\N	PRESENT	0
20525	20495	04079R	PARTICIPANT	\N	PRESENT	0
20526	20495	95049N	PARTICIPANT	\N	PRESENT	0
20527	20495	01060R	PARTICIPANT	\N	PRESENT	0
20528	20495	14147R	PARTICIPANT	\N	PRESENT	0
20530	20495	04074L	PARTICIPANT	\N	PRESENT	0
20531	20495	10015M	PARTICIPANT	\N	PRESENT	0
20532	20495	95063L	PARTICIPANT	\N	PRESENT	0
20533	20495	01019Q	PARTICIPANT	\N	PRESENT	0
20534	20495	01028R	PARTICIPANT	\N	PRESENT	0
20535	20495	98035U	PARTICIPANT	\N	PRESENT	0
20537	20495	04056J	PARTICIPANT	\N	PRESENT	0
20538	20495	14275Y	PARTICIPANT	\N	PRESENT	0
20539	20495	04044E	PARTICIPANT	\N	PRESENT	0
20540	20495	11037K	PARTICIPANT	\N	PRESENT	0
20541	20495	95067Q	PARTICIPANT	\N	PRESENT	0
20542	20495	01047U	PARTICIPANT	\N	PRESENT	0
20546	20529	14239U	PARTICIPANT	\N	PRESENT	0
20547	20529	11055M	PARTICIPANT	\N	PRESENT	0
20548	20529	01046T	PARTICIPANT	\N	PRESENT	0
20549	20529	04053F	PARTICIPANT	\N	PRESENT	0
20550	20529	14255U	PARTICIPANT	\N	PRESENT	0
20551	20529	04066L	PARTICIPANT	\N	PRESENT	0
20552	20529	00003C	PARTICIPANT	\N	PRESENT	0
20553	20529	14053L	PARTICIPANT	\N	PRESENT	0
20554	20529	11103C	PARTICIPANT	\N	PRESENT	0
20555	20529	11044J	PARTICIPANT	\N	PRESENT	0
20556	20529	14195A	PARTICIPANT	\N	PRESENT	0
20557	20529	14267Y	PARTICIPANT	\N	PRESENT	0
20558	20529	11023D	PARTICIPANT	\N	PRESENT	0
20653	20495	11074Q	PARTICIPANT	\N	PRESENT	0
20560	20529	08052W	PARTICIPANT	\N	PRESENT	0
20561	20529	01059Y	PARTICIPANT	\N	PRESENT	0
20562	20529	04081K	PARTICIPANT	\N	PRESENT	0
20563	20529	98024R	PARTICIPANT	\N	PRESENT	0
20564	20529	10006L	PARTICIPANT	\N	PRESENT	0
20565	20529	04067M	PARTICIPANT	\N	PRESENT	0
20566	20529	14217N	PARTICIPANT	\N	PRESENT	0
20567	20529	14042U	PARTICIPANT	\N	PRESENT	0
20568	20529	14151M	PARTICIPANT	\N	PRESENT	0
20569	20529	12042Y	PARTICIPANT	\N	PRESENT	0
20570	20529	14281W	PARTICIPANT	\N	PRESENT	0
20571	20529	14087W	PARTICIPANT	\N	PRESENT	0
20572	20529	01003G	PARTICIPANT	\N	PRESENT	0
20573	20529	14034U	PARTICIPANT	\N	PRESENT	0
20574	20529	14231L	PARTICIPANT	\N	PRESENT	0
20575	20529	11061K	PARTICIPANT	\N	PRESENT	0
20654	20495	98053W	PARTICIPANT	\N	PRESENT	0
20577	20529	08041T	PARTICIPANT	\N	PRESENT	0
20706	20495	08018U	PARTICIPANT	\N	PRESENT	0
20579	20529	14026U	PARTICIPANT	\N	PRESENT	0
20580	20529	14213J	PARTICIPANT	\N	PRESENT	0
20581	20529	14121F	PARTICIPANT	\N	PRESENT	0
20582	20529	11112D	PARTICIPANT	\N	PRESENT	0
20583	20529	14037X	PARTICIPANT	\N	PRESENT	0
20584	20529	14018U	PARTICIPANT	\N	PRESENT	0
20585	20529	11067R	PARTICIPANT	\N	PRESENT	0
20586	20529	14223L	PARTICIPANT	\N	PRESENT	0
20587	20529	04092N	PRESIDENT	0	PRESENT	0
20588	20529	14265W	PARTICIPANT	\N	PRESENT	0
20589	20529	14119M	PARTICIPANT	\N	PRESENT	0
20590	20529	14071N	PARTICIPANT	\N	PRESENT	0
20591	20529	07032N	PARTICIPANT	\N	PRESENT	0
20592	20529	04043D	PARTICIPANT	\N	PRESENT	0
20593	20529	14271U	PARTICIPANT	\N	PRESENT	0
20594	20529	14017T	PARTICIPANT	\N	PRESENT	0
20595	20529	11093T	PARTICIPANT	\N	PRESENT	0
20596	20529	11097X	PARTICIPANT	\N	EXCUSE	0
20597	20529	04045F	PARTICIPANT	\N	PRESENT	0
20598	20529	14227Q	PARTICIPANT	\N	PRESENT	0
20599	20529	01034P	PARTICIPANT	\N	EXCUSE	0
20707	20495	11026G	PARTICIPANT	\N	PRESENT	0
20601	20529	11063M	PARTICIPANT	\N	PRESENT	0
20602	20529	14269B	PARTICIPANT	\N	PRESENT	0
20709	20529	07034Q	PARTICIPANT	\N	PRESENT	0
20710	20495	14111D	PARTICIPANT	\N	PRESENT	0
20727	20726	14263U	PARTICIPANT	\N	PRESENT	0
20728	20726	14133K	PARTICIPANT	\N	PRESENT	0
20729	20726	11109J	PARTICIPANT	\N	PRESENT	0
20793	18401	14249W	PARTICIPANT	\N	PRESENT	0
20731	20726	11039M	PARTICIPANT	\N	PRESENT	0
20732	20726	01044R	PARTICIPANT	\N	PRESENT	0
20733	20726	08043V	PARTICIPANT	\N	PRESENT	0
20734	20726	14089Y	PARTICIPANT	\N	PRESENT	0
20735	20726	14105F	PARTICIPANT	\N	PRESENT	0
20736	20726	11029K	PARTICIPANT	\N	PRESENT	0
20737	20726	95015C	PARTICIPANT	\N	PRESENT	0
20794	18401	01013J	PARTICIPANT	\N	PRESENT	0
20739	20726	08024S	PARTICIPANT	\N	PRESENT	0
20740	20726	14201E	PARTICIPANT	\N	EXCUSE	0
20741	20726	14209N	PARTICIPANT	\N	PRESENT	0
20742	20726	14079W	PARTICIPANT	\N	PRESENT	0
20743	20726	11091R	PARTICIPANT	\N	PRESENT	0
20744	20726	87003B	PARTICIPANT	\N	PRESENT	0
20745	20726	98042T	PARTICIPANT	\N	PRESENT	0
20746	20726	14249W	PARTICIPANT	\N	PRESENT	0
20747	20726	01041N	PARTICIPANT	\N	PRESENT	0
20748	20726	01025N	PARTICIPANT	\N	PRESENT	0
20795	18401	14087W	PARTICIPANT	\N	PRESENT	0
20750	20726	89029V	PARTICIPANT	\N	PRESENT	0
20751	20726	08035V	PARTICIPANT	\N	PRESENT	0
20752	20726	11089X	PARTICIPANT	\N	PRESENT	0
20753	20726	07026Q	PARTICIPANT	\N	PRESENT	0
20754	20726	14123H	PARTICIPANT	\N	PRESENT	0
20796	18401	14207L	PARTICIPANT	\N	PRESENT	0
20797	18401	98050T	PARTICIPANT	\N	PRESENT	0
20757	20726	14241N	PARTICIPANT	\N	PRESENT	0
20758	20726	14061L	PARTICIPANT	\N	PRESENT	0
20759	20726	14073Q	PARTICIPANT	\N	PRESENT	0
20760	20726	08031R	PARTICIPANT	\N	PRESENT	0
20798	18401	01027Q	PARTICIPANT	\N	PRESENT	0
20762	20726	08039A	PARTICIPANT	\N	PRESENT	0
20763	20726	08017T	PARTICIPANT	\N	PRESENT	0
20764	20726	14059S	PARTICIPANT	\N	PRESENT	0
20765	20726	08012N	PARTICIPANT	\N	PRESENT	0
20766	20726	14103D	PARTICIPANT	\N	PRESENT	0
20767	20726	11104D	PARTICIPANT	\N	PRESENT	0
20768	20726	14063N	PARTICIPANT	\N	PRESENT	0
20769	20726	04057K	PARTICIPANT	\N	PRESENT	0
20770	20726	11014C	PARTICIPANT	\N	PRESENT	0
20771	20726	14109K	PARTICIPANT	\N	PRESENT	0
20772	20726	04070G	PRESIDENT	0	PRESENT	0
20773	20726	92040Q	PARTICIPANT	\N	PRESENT	0
20799	18401	14059S	PARTICIPANT	\N	PRESENT	0
20775	20726	83047W	PARTICIPANT	\N	PRESENT	0
20776	20726	14235Q	PARTICIPANT	\N	PRESENT	0
20800	18401	11043H	PARTICIPANT	\N	PRESENT	0
20801	18401	04044E	PARTICIPANT	\N	PRESENT	0
20779	20726	14229S	PARTICIPANT	\N	PRESENT	0
20780	20726	11043H	PARTICIPANT	\N	PRESENT	0
20781	20726	11071M	PARTICIPANT	\N	PRESENT	0
20782	20726	92045V	PARTICIPANT	\N	PRESENT	0
20802	18401	11036J	PARTICIPANT	\N	PRESENT	0
20803	18401	01031L	PARTICIPANT	\N	PRESENT	0
20804	18401	11071M	PARTICIPANT	\N	PRESENT	0
20805	18401	14205J	PARTICIPANT	\N	PRESENT	0
20806	18401	11085T	PARTICIPANT	\N	PRESENT	0
20807	18401	14073Q	PARTICIPANT	\N	PRESENT	0
20808	18401	14197C	PARTICIPANT	\N	PRESENT	0
20809	18401	01048V	PARTICIPANT	\N	PRESENT	0
20810	18401	10015M	PARTICIPANT	\N	PRESENT	0
20811	18401	04057K	PARTICIPANT	\N	PRESENT	0
20812	18401	08043V	PARTICIPANT	\N	PRESENT	0
20813	18401	11104D	PARTICIPANT	\N	PRESENT	0
20814	18401	08016S	PARTICIPANT	\N	PRESENT	0
20815	18401	08017T	PARTICIPANT	\N	PRESENT	0
20854	18401	97011G	PARTICIPANT	\N	PRESENT	0
20855	18401	11095V	PARTICIPANT	\N	PRESENT	0
20856	18401	01025N	PARTICIPANT	\N	PRESENT	0
20857	18401	14157T	PARTICIPANT	\N	PRESENT	0
20859	18401	14041T	PARTICIPANT	\N	PRESENT	0
20861	18401	11012A	PARTICIPANT	\N	PRESENT	0
20862	18401	08041T	PARTICIPANT	\N	PRESENT	0
20869	18401	89017R	PARTICIPANT	\N	PRESENT	0
20864	18401	14089Y	PARTICIPANT	\N	PRESENT	0
20865	18401	08051V	PARTICIPANT	\N	PRESENT	0
20870	18401	08010L	PARTICIPANT	\N	PRESENT	0
19977	18406	14061L	PARTICIPANT	\N	PRESENT	0
19978	18406	04085P	PARTICIPANT	\N	PRESENT	0
19979	18406	11034G	PARTICIPANT	\N	PRESENT	0
19980	18406	11056N	PARTICIPANT	\N	PRESENT	0
19981	18406	14097Y	PARTICIPANT	\N	PRESENT	0
20056	18406	14034U	PARTICIPANT	\N	PRESENT	0
19983	18406	04056J	PARTICIPANT	\N	PRESENT	0
19984	18406	11026G	PARTICIPANT	\N	PRESENT	0
20057	18406	08041T	PARTICIPANT	\N	PRESENT	0
20058	18406	11089X	PARTICIPANT	\N	PRESENT	0
20059	18406	11084S	PARTICIPANT	\N	PRESENT	0
20060	18406	01028R	PARTICIPANT	\N	PRESENT	0
19989	18406	95049N	PARTICIPANT	\N	PRESENT	0
19990	18406	14215L	PARTICIPANT	\N	PRESENT	0
20061	18406	14265W	PARTICIPANT	\N	PRESENT	0
20062	18406	14213J	PARTICIPANT	\N	PRESENT	0
19993	18406	14147R	PARTICIPANT	\N	PRESENT	0
20063	18406	14026U	PARTICIPANT	\N	PRESENT	0
20064	18406	08015R	PARTICIPANT	\N	PRESENT	0
20858	20816	98035U	PARTICIPANT	\N	PRESENT	0
20939	20860	11098Y	PARTICIPANT	\N	PRESENT	0
20940	20860	11084S	PARTICIPANT	\N	PRESENT	0
19999	18406	99004R	PARTICIPANT	\N	PRESENT	0
20941	20860	11026G	PARTICIPANT	\N	PRESENT	0
20942	20860	11033F	PARTICIPANT	\N	PRESENT	0
20943	20860	11037K	PARTICIPANT	\N	PRESENT	0
20944	20860	14231L	PARTICIPANT	\N	PRESENT	0
20945	20860	14073Q	PARTICIPANT	\N	PRESENT	0
20005	18406	05008E	PARTICIPANT	\N	PRESENT	0
20006	18406	07029T	PARTICIPANT	\N	PRESENT	0
20007	18406	11113E	PARTICIPANT	\N	PRESENT	0
20946	20860	14059S	PARTICIPANT	\N	PRESENT	0
20022	18406	01007L	PARTICIPANT	\N	PRESENT	0
20947	20860	14061L	PARTICIPANT	\N	PRESENT	0
20948	20860	04057K	PARTICIPANT	\N	PRESENT	0
20949	20860	14269B	PARTICIPANT	\N	PRESENT	0
20950	20860	05008E	PARTICIPANT	\N	PRESENT	0
20951	20860	95049N	PARTICIPANT	\N	PRESENT	0
20028	18406	14033T	PARTICIPANT	\N	PRESENT	0
20952	20860	11060J	PARTICIPANT	\N	PRESENT	0
20030	18406	08051V	PARTICIPANT	\N	PRESENT	0
20953	20860	99004R	PARTICIPANT	\N	PRESENT	0
20032	18406	14087W	PARTICIPANT	\N	PRESENT	0
20954	20860	08010L	PARTICIPANT	\N	PRESENT	0
20034	18406	11060J	PARTICIPANT	\N	PRESENT	0
20955	20860	08041T	PARTICIPANT	\N	PRESENT	0
20956	20860	90003B	PARTICIPANT	\N	PRESENT	0
20037	18406	11012A	PARTICIPANT	\N	PRESENT	0
20957	20860	14089Y	PARTICIPANT	\N	PRESENT	0
20958	20860	04085P	PARTICIPANT	\N	PRESENT	0
20959	20860	14133K	PARTICIPANT	\N	PRESENT	0
20960	20860	04044E	PARTICIPANT	\N	PRESENT	0
20961	20860	14215L	PARTICIPANT	\N	PRESENT	0
20962	20860	04038G	PARTICIPANT	\N	PRESENT	0
20963	20860	11089X	PARTICIPANT	\N	PRESENT	0
20937	20860	08024S	PARTICIPANT	\N	PRESENT	0
20938	20860	04047H	PARTICIPANT	\N	PRESENT	0
20964	20860	14033T	PARTICIPANT	\N	PRESENT	0
20965	20860	14265W	PARTICIPANT	\N	PRESENT	0
20966	20860	14219Q	PARTICIPANT	\N	PRESENT	0
20053	18406	14229S	PARTICIPANT	\N	PRESENT	0
20052	18406	14231L	PARTICIPANT	\N	PRESENT	0
20967	20860	01016M	PARTICIPANT	\N	PRESENT	0
20055	18406	14083S	PARTICIPANT	\N	PRESENT	0
20968	20860	14249W	PARTICIPANT	\N	PRESENT	0
20969	20860	12042Y	PARTICIPANT	\N	PRESENT	0
20970	20860	08031R	PARTICIPANT	\N	PRESENT	0
20818	20816	11036J	PARTICIPANT	\N	PRESENT	0
20819	20816	11033F	PARTICIPANT	\N	EXCUSE	0
20820	20816	14065Q	PARTICIPANT	\N	PRESENT	0
20971	20860	14217N	PARTICIPANT	\N	PRESENT	0
20822	20816	08043V	PARTICIPANT	\N	PRESENT	0
20972	20860	11077T	PARTICIPANT	\N	PRESENT	0
20973	20860	04033B	PARTICIPANT	\N	PRESENT	0
20974	20860	01028R	PARTICIPANT	\N	PRESENT	0
20975	20860	14195A	PARTICIPANT	\N	PRESENT	0
20976	20860	11034G	PARTICIPANT	\N	PRESENT	0
20828	20816	14041T	PARTICIPANT	\N	PRESENT	0
20977	20860	11064N	PARTICIPANT	\N	PRESENT	0
20830	20816	14087W	PARTICIPANT	\N	PRESENT	0
20831	20816	97011G	PARTICIPANT	\N	PRESENT	0
20832	20816	11061K	PARTICIPANT	\N	PRESENT	0
20833	20816	14014Q	PARTICIPANT	\N	PRESENT	0
20834	20816	08041T	PARTICIPANT	\N	PRESENT	0
20835	20816	01011G	PARTICIPANT	0	PRESENT	0
20836	20816	07026Q	PARTICIPANT	\N	PRESENT	0
20837	20816	95035G	PARTICIPANT	\N	EXCUSE	0
20838	20816	14026U	PARTICIPANT	\N	PRESENT	0
20978	20860	92045V	PARTICIPANT	\N	PRESENT	0
20840	20816	09001P	PARTICIPANT	\N	PRESENT	0
20841	20816	04036E	PARTICIPANT	\N	PRESENT	0
20842	20816	08017T	PARTICIPANT	\N	PRESENT	0
20843	20816	04079R	PARTICIPANT	\N	PRESENT	0
20844	20816	11067R	PARTICIPANT	\N	PRESENT	0
20845	20816	14223L	PARTICIPANT	\N	PRESENT	0
20979	20860	04088S	PARTICIPANT	\N	PRESENT	0
20847	20816	11012A	PARTICIPANT	\N	PRESENT	0
20980	20860	14197C	PARTICIPANT	\N	PRESENT	0
20981	20860	14034U	PARTICIPANT	\N	PRESENT	0
19976	18406	04047H	PARTICIPANT	\N	PRESENT	0
20982	20860	10006L	PARTICIPANT	\N	PRESENT	0
20851	20816	04044E	PARTICIPANT	\N	PRESENT	0
20852	20816	95067Q	PRESIDENT	0	PRESENT	0
20983	20860	11048N	PARTICIPANT	\N	PRESENT	0
20984	20860	10015M	PARTICIPANT	\N	PRESENT	0
20987	20860	14069U	PARTICIPANT	\N	PRESENT	0
21309	21149	08024S	PARTICIPANT	\N	PRESENT	0
20988	20860	14097Y	PARTICIPANT	\N	PRESENT	0
21307	20152	98018T	PARTICIPANT	\N	PRESENT	0
21308	20152	11113E	PARTICIPANT	\N	PRESENT	0
21191	21185	14069U	PARTICIPANT	\N	PRESENT	0
21192	21185	14089Y	PRESIDENT	0	PRESENT	0
21310	21149	14063N	PARTICIPANT	\N	PRESENT	0
21194	21185	08068F	PARTICIPANT	\N	PRESENT	0
21195	21185	90003B	PARTICIPANT	\N	PRESENT	0
21196	21185	01027Q	PARTICIPANT	\N	PRESENT	0
21197	21185	14073Q	PARTICIPANT	\N	PRESENT	0
21198	21185	11112D	PARTICIPANT	\N	PRESENT	0
21199	21185	11099A	PARTICIPANT	\N	PRESENT	0
21200	21185	14037X	PARTICIPANT	\N	PRESENT	0
21201	21185	14205J	PARTICIPANT	\N	PRESENT	0
21202	21185	14031R	PARTICIPANT	\N	PRESENT	0
21203	21185	08053X	PARTICIPANT	\N	EXCUSE	0
21311	21149	13002U	PARTICIPANT	\N	PRESENT	0
21312	21149	14269B	PARTICIPANT	\N	PRESENT	0
21313	21149	11084S	PARTICIPANT	\N	PRESENT	0
21207	21185	04088S	PARTICIPANT	\N	PRESENT	0
21208	21185	01016M	PARTICIPANT	\N	PRESENT	0
21314	21149	04085P	PARTICIPANT	\N	PRESENT	0
21210	21185	11037K	PARTICIPANT	\N	PRESENT	0
21315	21149	14041T	PARTICIPANT	\N	PRESENT	0
21316	21149	14265W	PARTICIPANT	\N	PRESENT	0
21317	21149	14061L	PARTICIPANT	\N	PRESENT	0
21318	21149	99004R	PARTICIPANT	\N	PRESENT	0
21319	21149	11060J	PARTICIPANT	\N	PRESENT	0
21320	21149	11091R	PARTICIPANT	\N	PRESENT	0
21321	21149	14273W	PARTICIPANT	\N	PRESENT	0
21322	21149	11033F	PARTICIPANT	\N	PRESENT	0
21323	21149	11034G	PARTICIPANT	\N	PRESENT	0
21324	21149	04047H	PARTICIPANT	\N	PRESENT	0
21325	21149	04044E	PARTICIPANT	\N	PRESENT	0
21326	21149	11026G	PARTICIPANT	\N	PRESENT	0
21327	21149	04086Q	PARTICIPANT	\N	PRESENT	0
21328	21149	04038G	PARTICIPANT	\N	PRESENT	0
21329	21149	14121F	PARTICIPANT	\N	PRESENT	0
21330	21149	01041N	PARTICIPANT	\N	PRESENT	0
21331	21149	11107G	PARTICIPANT	\N	PRESENT	0
21332	21149	11071M	PARTICIPANT	\N	PRESENT	0
21333	21149	04056J	PARTICIPANT	\N	PRESENT	0
21334	21149	14033T	PARTICIPANT	\N	PRESENT	0
21335	21149	04043D	PARTICIPANT	\N	PRESENT	0
21336	21149	04036E	PARTICIPANT	\N	PRESENT	0
21337	21149	07024N	PARTICIPANT	\N	PRESENT	0
21338	21149	14073Q	PARTICIPANT	\N	PRESENT	0
21339	21149	04034C	PARTICIPANT	\N	PRESENT	0
21340	21149	08034U	PARTICIPANT	\N	PRESENT	0
21341	21149	11039M	PARTICIPANT	\N	PRESENT	0
21342	21149	05008E	PARTICIPANT	\N	PRESENT	0
21343	21149	04088S	PARTICIPANT	\N	PRESENT	0
21344	21149	98018T	PARTICIPANT	\N	PRESENT	0
21345	21149	11113E	PARTICIPANT	\N	PRESENT	0
21346	15890	99004R	PRESIDENT	0	PRESENT	0
21347	15890	01041N	PARTICIPANT	\N	PRESENT	0
21348	15890	92045V	PARTICIPANT	\N	PRESENT	0
21349	15890	11066Q	PARTICIPANT	\N	PRESENT	0
21350	15890	04061F	PARTICIPANT	\N	PRESENT	0
21351	15890	14103D	PARTICIPANT	\N	PRESENT	0
21375	15890	01008M	PARTICIPANT	\N	EXCUSE	0
21378	15890	08060W	PARTICIPANT	\N	EXCUSE	0
22024	21612	14159V	PARTICIPANT	\N	PRESENT	0
21858	21612	14257W	PARTICIPANT	\N	PRESENT	0
21957	21612	04053F	PARTICIPANT	\N	PRESENT	0
21860	21612	04077P	PARTICIPANT	\N	PRESENT	0
21996	21612	98053W	PARTICIPANT	\N	PRESENT	0
21862	21612	08061X	PARTICIPANT	\N	PRESENT	0
21863	21612	14215L	PARTICIPANT	\N	PRESENT	0
21864	21612	01037S	PARTICIPANT	\N	PRESENT	0
21865	21612	14265W	PARTICIPANT	\N	PRESENT	0
21866	21612	01028R	PARTICIPANT	\N	PRESENT	0
21867	21612	11061K	PARTICIPANT	\N	PRESENT	0
21868	21612	08041T	PARTICIPANT	\N	PRESENT	0
21869	21612	14063N	PARTICIPANT	\N	PRESENT	0
21870	21612	14109K	PARTICIPANT	\N	PRESENT	0
21871	21612	11104D	PARTICIPANT	\N	PRESENT	0
21872	21612	11049P	PARTICIPANT	\N	PRESENT	0
21873	21612	08060W	PARTICIPANT	\N	PRESENT	0
21874	21612	14271U	PARTICIPANT	\N	PRESENT	0
21875	21612	08025T	PARTICIPANT	\N	PRESENT	0
21876	21612	04042C	PARTICIPANT	\N	PRESENT	0
21877	21612	11109J	PARTICIPANT	\N	PRESENT	0
21878	21612	04071H	PARTICIPANT	\N	PRESENT	0
21879	21612	04045F	PARTICIPANT	\N	PRESENT	0
21880	21612	11106F	PARTICIPANT	\N	PRESENT	0
21881	21612	96004D	PARTICIPANT	\N	PRESENT	0
21882	21612	11067R	PARTICIPANT	\N	PRESENT	0
21883	21612	04061F	PARTICIPANT	\N	PRESENT	0
21884	21612	14081Q	PARTICIPANT	\N	PRESENT	0
21885	21612	11114F	PARTICIPANT	\N	PRESENT	0
21886	21612	14039A	PARTICIPANT	\N	PRESENT	0
21887	21612	11113E	PARTICIPANT	\N	PRESENT	0
21888	21612	08035V	PARTICIPANT	\N	PRESENT	0
21889	21612	02002K	PARTICIPANT	\N	PRESENT	0
21890	21612	11076S	PARTICIPANT	\N	PRESENT	0
21891	21612	97011G	PARTICIPANT	\N	PRESENT	0
21892	21612	08017T	PARTICIPANT	\N	PRESENT	0
21893	21612	11094U	PARTICIPANT	\N	PRESENT	0
21894	21612	08028W	PARTICIPANT	\N	PRESENT	0
21895	21612	11053K	PARTICIPANT	\N	PRESENT	0
21896	21612	11043H	PARTICIPANT	\N	PRESENT	0
21897	21612	04080J	PARTICIPANT	\N	PRESENT	0
21898	21612	98005N	PARTICIPANT	\N	PRESENT	0
21899	21612	04057K	PARTICIPANT	\N	PRESENT	0
21900	21612	08051V	PARTICIPANT	\N	PRESENT	0
21901	21612	08043V	PARTICIPANT	\N	PRESENT	0
21902	21612	14267Y	PARTICIPANT	\N	PRESENT	0
21903	21612	08015R	PARTICIPANT	\N	PRESENT	0
21904	21612	86034E	PARTICIPANT	\N	PRESENT	0
21905	21612	01011G	PARTICIPANT	\N	PRESENT	0
21906	21612	83042R	PARTICIPANT	\N	PRESENT	0
21907	21612	01057W	PARTICIPANT	\N	PRESENT	0
21908	21612	11064N	PARTICIPANT	\N	PRESENT	0
21909	21612	14103D	PARTICIPANT	\N	PRESENT	0
21910	21612	14199E	PARTICIPANT	\N	PRESENT	0
21911	21612	14030Q	PARTICIPANT	\N	PRESENT	0
21912	21612	14221J	PARTICIPANT	\N	PRESENT	0
21913	21612	11037K	PARTICIPANT	\N	PRESENT	0
21914	21612	11082Q	PARTICIPANT	\N	PRESENT	0
21915	21612	04074L	PARTICIPANT	\N	PRESENT	0
21916	21612	08010L	PARTICIPANT	\N	PRESENT	0
21917	21612	83047W	PARTICIPANT	\N	PRESENT	0
21918	21612	04033B	PARTICIPANT	\N	PRESENT	0
21919	21612	14151M	PARTICIPANT	\N	PRESENT	0
21920	21612	14093U	PARTICIPANT	\N	PRESENT	0
21921	21612	14229S	PARTICIPANT	\N	PRESENT	0
21922	21612	11014C	PARTICIPANT	\N	PRESENT	0
21923	21612	11033F	PARTICIPANT	\N	PRESENT	0
21924	21612	08024S	PARTICIPANT	\N	PRESENT	0
21925	21612	12042Y	PARTICIPANT	\N	PRESENT	0
21926	21612	14269B	PARTICIPANT	\N	PRESENT	0
21927	21612	10006L	PARTICIPANT	\N	PRESENT	0
21928	21612	01007L	PARTICIPANT	\N	PRESENT	0
21929	21612	04081K	PARTICIPANT	\N	PRESENT	0
21930	21612	11080N	PARTICIPANT	\N	PRESENT	0
21931	21612	04043D	PARTICIPANT	\N	PRESENT	0
21932	21612	11111C	PARTICIPANT	\N	PRESENT	0
21933	21612	14059S	PARTICIPANT	\N	PRESENT	0
21934	21612	14065Q	PARTICIPANT	\N	PRESENT	0
21935	21612	14089Y	PARTICIPANT	\N	PRESENT	0
21936	21612	14259Y	PARTICIPANT	\N	PRESENT	0
21937	21612	08011M	PARTICIPANT	\N	PRESENT	0
21938	21612	08068F	PARTICIPANT	\N	PRESENT	0
21939	21612	14251Q	PARTICIPANT	\N	PRESENT	0
21940	21612	07024N	PARTICIPANT	\N	PRESENT	0
21941	21612	14209N	PARTICIPANT	\N	PRESENT	0
21942	21612	11039M	PARTICIPANT	\N	PRESENT	0
21943	21612	11070L	PARTICIPANT	\N	PRESENT	0
21944	21612	14105F	PARTICIPANT	\N	PRESENT	0
21945	21612	01059Y	PARTICIPANT	\N	PRESENT	0
21946	21612	11054L	PARTICIPANT	\N	PRESENT	0
21947	21612	11063M	PARTICIPANT	\N	PRESENT	0
21948	21612	04059M	PARTICIPANT	\N	PRESENT	0
21949	21612	11057P	PARTICIPANT	\N	PRESENT	0
21950	21612	11044J	PARTICIPANT	\N	PRESENT	0
21951	21612	14187A	PARTICIPANT	\N	PRESENT	0
21952	21612	04066L	PARTICIPANT	\N	PRESENT	0
21953	21612	92040Q	PARTICIPANT	\N	PRESENT	0
21954	21612	14157T	PARTICIPANT	\N	PRESENT	0
21955	21612	14042U	PARTICIPANT	\N	PRESENT	0
21956	21612	11071M	PARTICIPANT	\N	PRESENT	0
21958	21612	05008E	PARTICIPANT	\N	PRESENT	0
21959	21612	14241N	PARTICIPANT	\N	PRESENT	0
21960	21612	98022P	PARTICIPANT	\N	PRESENT	0
21961	21612	04047H	PARTICIPANT	\N	PRESENT	0
21962	21612	14123H	PARTICIPANT	\N	PRESENT	0
21963	21612	14014Q	PARTICIPANT	\N	PRESENT	0
21964	21612	98046X	PARTICIPANT	\N	PRESENT	0
21965	21612	04035D	PARTICIPANT	\N	PRESENT	0
21966	21612	11100Y	PARTICIPANT	\N	PRESENT	0
21967	21612	08038Y	PARTICIPANT	\N	PRESENT	0
21968	21612	08039A	PARTICIPANT	\N	PRESENT	0
21969	21612	14026U	PARTICIPANT	\N	PRESENT	0
21970	21612	11046L	PARTICIPANT	\N	PRESENT	0
21971	21612	11112D	PARTICIPANT	\N	PRESENT	0
21972	21612	04088S	PARTICIPANT	\N	PRESENT	0
21973	21612	11088W	PARTICIPANT	\N	PRESENT	0
21974	21612	08009T	PARTICIPANT	\N	PRESENT	0
21975	21612	14253S	PARTICIPANT	\N	PRESENT	0
21976	21612	08052W	PARTICIPANT	\N	PRESENT	0
21977	21612	01027Q	PARTICIPANT	\N	PRESENT	0
21978	21612	11032E	PARTICIPANT	\N	PRESENT	0
21979	21612	11090Q	PARTICIPANT	\N	PRESENT	0
21980	21612	14249W	PARTICIPANT	\N	PRESENT	0
21981	21612	05012A	PARTICIPANT	\N	PRESENT	0
21982	21612	14111D	PARTICIPANT	\N	PRESENT	0
21983	21612	08019V	PARTICIPANT	\N	PRESENT	0
21984	21612	11034G	PARTICIPANT	\N	PRESENT	0
21985	21612	01056V	PARTICIPANT	\N	PRESENT	0
21986	21612	14235Q	PARTICIPANT	\N	PRESENT	0
21987	21612	08062Y	PARTICIPANT	\N	PRESENT	0
21988	21612	14195A	PARTICIPANT	\N	PRESENT	0
21989	21612	01034P	PARTICIPANT	\N	PRESENT	0
21990	21612	01024M	PARTICIPANT	\N	PRESENT	0
21991	21612	01025N	PARTICIPANT	\N	PRESENT	0
21992	21612	11048N	PARTICIPANT	\N	PRESENT	0
21993	21612	14034U	PARTICIPANT	\N	PRESENT	0
21994	21612	07004J	PARTICIPANT	\N	PRESENT	0
21995	21612	14205J	PARTICIPANT	\N	PRESENT	0
21997	21612	01047U	PARTICIPANT	\N	PRESENT	0
21998	21612	14213J	PARTICIPANT	\N	PRESENT	0
21999	21612	14083S	PARTICIPANT	\N	PRESENT	0
22000	21612	08044W	PARTICIPANT	\N	PRESENT	0
22002	21612	04036E	PARTICIPANT	\N	PRESENT	0
22003	21612	14033T	PARTICIPANT	\N	PRESENT	0
22004	21612	11010L	PARTICIPANT	\N	PRESENT	0
22010	21612	14167V	PARTICIPANT	\N	PRESENT	0
22006	21612	11068S	PARTICIPANT	\N	PRESENT	0
22007	21612	01043Q	PARTICIPANT	\N	PRESENT	0
22008	21612	14247U	PARTICIPANT	\N	PRESENT	0
22009	21612	11031D	PARTICIPANT	\N	PRESENT	0
22011	21612	11060J	PARTICIPANT	\N	PRESENT	0
22012	21612	92044U	PARTICIPANT	\N	PRESENT	0
22013	21612	04049K	PARTICIPANT	\N	PRESENT	0
22020	21612	14097Y	PARTICIPANT	\N	PRESENT	0
22018	21612	14107H	PARTICIPANT	\N	PRESENT	0
22016	21612	11025F	PARTICIPANT	\N	PRESENT	0
22017	21612	95059Q	PARTICIPANT	\N	PRESENT	0
22023	21612	89029V	PARTICIPANT	\N	PRESENT	0
22021	21612	14119M	PARTICIPANT	\N	PRESENT	0
22022	21612	14071N	PARTICIPANT	\N	PRESENT	0
22025	21612	11072N	PARTICIPANT	\N	PRESENT	0
21502	21501	04061F	PARTICIPANT	\N	EXCUSE	0
21503	21501	08039A	PARTICIPANT	\N	EXCUSE	0
21563	21501	14263U	PARTICIPANT	\N	EXCUSE	0
21651	21650	11055M	PARTICIPANT	\N	PRESENT	0
21652	21650	04053F	PARTICIPANT	\N	PRESENT	0
21654	21650	00003C	PARTICIPANT	\N	PRESENT	0
21655	21650	11103C	PARTICIPANT	\N	PRESENT	0
21656	21650	11031D	PARTICIPANT	\N	PRESENT	0
21657	21650	14042U	PARTICIPANT	\N	PRESENT	0
21658	21650	11061K	PARTICIPANT	\N	EXCUSE	0
21659	21650	11067R	PARTICIPANT	\N	PRESENT	0
21660	21650	04092N	PRESIDENT	0	PRESENT	0
21661	21650	14265W	PARTICIPANT	\N	PRESENT	0
21662	21650	14119M	PARTICIPANT	\N	PRESENT	0
21663	21650	04043D	PARTICIPANT	\N	PRESENT	0
21664	21650	11097X	PARTICIPANT	\N	EXCUSE	0
21665	21650	14227Q	PARTICIPANT	\N	PRESENT	0
21666	21650	14269B	PARTICIPANT	\N	PRESENT	0
22709	22708	89017R	PARTICIPANT	\N	EXCUSE	0
22710	22708	01031L	PRESIDENT	0	PRESENT	0
22711	22708	05004A	PARTICIPANT	\N	PRESENT	0
22715	22708	14167V	PARTICIPANT	\N	PRESENT	0
22713	22708	11040E	PARTICIPANT	\N	PRESENT	0
22714	22708	08014Q	PARTICIPANT	\N	PRESENT	0
22716	22708	14175V	PARTICIPANT	\N	PRESENT	0
22717	22708	14083S	PARTICIPANT	\N	PRESENT	0
22718	22708	11053K	PARTICIPANT	\N	PRESENT	0
22719	22708	14085U	PARTICIPANT	\N	PRESENT	0
22720	22708	11042G	PARTICIPANT	\N	EXCUSE	0
22721	22708	88008L	PARTICIPANT	\N	PRESENT	0
22722	22708	04086Q	PARTICIPANT	\N	PRESENT	0
22723	22708	04055H	PARTICIPANT	\N	PRESENT	0
22724	22708	11070L	PARTICIPANT	\N	PRESENT	0
22725	22708	11088W	PARTICIPANT	\N	PRESENT	0
22726	22708	14327T	PARTICIPANT	\N	PRESENT	0
22727	22708	08022Q	PARTICIPANT	\N	PRESENT	0
22728	22708	01027Q	PARTICIPANT	\N	PRESENT	0
22729	22708	04071H	PARTICIPANT	\N	PRESENT	0
22730	22708	11074Q	PARTICIPANT	\N	PRESENT	0
22731	22708	98053W	PARTICIPANT	\N	PRESENT	0
22732	22708	11083R	PARTICIPANT	\N	PRESENT	0
22733	22708	14199E	PARTICIPANT	\N	PRESENT	0
22734	22708	01057W	PARTICIPANT	\N	PRESENT	0
22735	22708	08016S	PARTICIPANT	\N	PRESENT	0
22736	22708	08069G	PARTICIPANT	\N	PRESENT	0
22737	22708	11048N	PARTICIPANT	\N	PRESENT	0
22738	22708	99004R	PARTICIPANT	\N	PRESENT	0
22739	22708	04061F	PARTICIPANT	\N	PRESENT	0
22740	22708	14159V	PARTICIPANT	\N	PRESENT	0
22741	22708	07029T	PARTICIPANT	\N	PRESENT	0
22742	22708	08010L	PARTICIPANT	\N	PRESENT	0
22743	22708	08034U	PARTICIPANT	\N	PRESENT	0
22744	22708	98046X	PARTICIPANT	\N	PRESENT	0
22745	22708	11085T	PARTICIPANT	\N	PRESENT	0
22746	22708	08011M	PARTICIPANT	\N	PRESENT	0
22747	22708	08061X	PARTICIPANT	\N	PRESENT	0
22748	22708	14225N	PARTICIPANT	\N	PRESENT	0
22749	22708	01016M	PARTICIPANT	\N	PRESENT	0
22750	22708	11012A	PARTICIPANT	\N	PRESENT	0
22751	22708	11057P	PARTICIPANT	\N	PRESENT	0
22752	22708	14173T	PARTICIPANT	\N	PRESENT	0
22753	22708	04034C	PARTICIPANT	\N	PRESENT	0
22754	22708	01013J	PARTICIPANT	\N	PRESENT	0
22819	22813	77002U	PARTICIPANT	\N	PRESENT	0
22820	22813	98029W	PARTICIPANT	\N	PRESENT	0
22821	22813	11080N	PARTICIPANT	\N	PRESENT	0
22822	22813	11027H	PARTICIPANT	\N	PRESENT	0
22823	22813	98018T	PARTICIPANT	\N	EXCUSE	0
22824	22813	92018S	PARTICIPANT	\N	PRESENT	0
22825	22813	92020L	PARTICIPANT	\N	PRESENT	0
22826	22813	95030B	PARTICIPANT	\N	PRESENT	0
22872	22871	14263U	PARTICIPANT	\N	PRESENT	0
22828	22813	95031C	PARTICIPANT	\N	PRESENT	0
22829	22813	97011G	PARTICIPANT	\N	PRESENT	0
22830	22813	08065C	PARTICIPANT	\N	PRESENT	0
22831	22813	04035D	PARTICIPANT	\N	PRESENT	0
22832	22813	07024N	PARTICIPANT	\N	PRESENT	0
22873	22871	14133K	PARTICIPANT	\N	PRESENT	0
22874	22871	11109J	PARTICIPANT	\N	PRESENT	0
22835	22813	11015D	PARTICIPANT	\N	PRESENT	0
22836	22813	07004J	PARTICIPANT	\N	PRESENT	0
22837	22813	95035G	PARTICIPANT	\N	PRESENT	0
22838	22813	08056B	PARTICIPANT	\N	PRESENT	0
22839	22813	14211G	PARTICIPANT	\N	PRESENT	0
22840	22813	98022P	PARTICIPANT	\N	PRESENT	0
22841	22813	11064N	PARTICIPANT	\N	PRESENT	0
22875	22871	04059M	PARTICIPANT	\N	PRESENT	0
22843	22813	04078Q	PARTICIPANT	\N	PRESENT	0
22844	22813	14097Y	PARTICIPANT	\N	PRESENT	0
22876	22871	11039M	PARTICIPANT	\N	PRESENT	0
22846	22813	04036E	PARTICIPANT	\N	PRESENT	0
22847	22813	14039A	PARTICIPANT	\N	PRESENT	0
22877	22871	01044R	PARTICIPANT	\N	PRESENT	0
22849	22813	98005N	PARTICIPANT	\N	PRESENT	0
22850	22813	92031P	PARTICIPANT	\N	PRESENT	0
22851	22813	11106F	PARTICIPANT	\N	PRESENT	0
22852	22813	14251Q	PARTICIPANT	\N	PRESENT	0
22853	22813	83042R	PARTICIPANT	\N	PRESENT	0
22878	22871	08043V	PARTICIPANT	\N	PRESENT	0
22855	22813	11082Q	PARTICIPANT	\N	PRESENT	0
22856	22813	11105E	PARTICIPANT	\N	EXCUSE	0
22857	22813	14253S	PARTICIPANT	\N	PRESENT	0
22858	22813	08047A	PARTICIPANT	\N	PRESENT	0
22859	22813	14028W	PARTICIPANT	\N	PRESENT	0
22860	22813	14193X	PARTICIPANT	\N	PRESENT	0
22861	22813	98021N	PARTICIPANT	\N	PRESENT	0
22862	22813	11069T	PARTICIPANT	\N	PRESENT	0
22863	22813	04080J	PARTICIPANT	\N	PRESENT	0
22864	22813	95059Q	PRESIDENT	0	PRESENT	0
22865	22813	86044G	PARTICIPANT	\N	PRESENT	0
22866	22813	01014K	PARTICIPANT	\N	PRESENT	0
22867	22813	11054L	PARTICIPANT	\N	PRESENT	0
22868	22813	01056V	PARTICIPANT	\N	PRESENT	0
22869	22813	92044U	PARTICIPANT	\N	PRESENT	0
22870	22813	08049C	PARTICIPANT	\N	PRESENT	0
22879	22871	14089Y	PARTICIPANT	\N	PRESENT	0
22880	22871	14105F	PARTICIPANT	\N	PRESENT	0
22881	22871	11029K	PARTICIPANT	\N	PRESENT	0
22882	22871	95015C	PARTICIPANT	\N	PRESENT	0
22980	22979	89017R	PARTICIPANT	\N	EXCUSE	0
22884	22871	08024S	PARTICIPANT	\N	PRESENT	0
22885	22871	14201E	PARTICIPANT	\N	PRESENT	0
22981	22979	01031L	PRESIDENT	0	PRESENT	0
22887	22871	14209N	PARTICIPANT	\N	PRESENT	0
22888	22871	14079W	PARTICIPANT	\N	PRESENT	0
22889	22871	11091R	PARTICIPANT	\N	EXCUSE	0
22890	22871	87003B	PARTICIPANT	\N	PRESENT	0
22891	22871	98042T	PARTICIPANT	\N	PRESENT	0
22892	22871	14249W	PARTICIPANT	\N	PRESENT	0
22893	22871	01041N	PARTICIPANT	\N	EXCUSE	0
22894	22871	01025N	PARTICIPANT	\N	PRESENT	0
22982	22979	05004A	PARTICIPANT	\N	PRESENT	0
22896	22871	89029V	PARTICIPANT	\N	PRESENT	0
22897	22871	08035V	PARTICIPANT	\N	PRESENT	0
22898	22871	11089X	PARTICIPANT	\N	PRESENT	0
22899	22871	07026Q	PARTICIPANT	\N	PRESENT	0
22900	22871	14123H	PARTICIPANT	\N	PRESENT	0
22901	22871	14179A	PARTICIPANT	\N	PRESENT	0
22902	22871	04041B	PARTICIPANT	\N	PRESENT	0
22903	22871	14241N	PARTICIPANT	\N	PRESENT	0
22904	22871	14061L	PARTICIPANT	\N	PRESENT	0
22905	22871	14073Q	PARTICIPANT	\N	PRESENT	0
22983	22979	01013J	PARTICIPANT	\N	PRESENT	0
22907	22871	12041X	PARTICIPANT	\N	PRESENT	0
22908	22871	08039A	PARTICIPANT	\N	PRESENT	0
22909	22871	08017T	PARTICIPANT	\N	PRESENT	0
22910	22871	14059S	PARTICIPANT	\N	PRESENT	0
22911	22871	08012N	PARTICIPANT	\N	PRESENT	0
22912	22871	14103D	PARTICIPANT	\N	PRESENT	0
22913	22871	11104D	PARTICIPANT	\N	PRESENT	0
22914	22871	14063N	PARTICIPANT	\N	PRESENT	0
22915	22871	04057K	PARTICIPANT	\N	PRESENT	0
22916	22871	11014C	PARTICIPANT	\N	PRESENT	0
22917	22871	14109K	PARTICIPANT	\N	PRESENT	0
22918	22871	04070G	PRESIDENT	0	PRESENT	0
22919	22871	92040Q	PARTICIPANT	\N	PRESENT	0
22920	22871	14191V	PARTICIPANT	\N	PRESENT	0
22921	22871	83047W	PARTICIPANT	\N	PRESENT	0
22922	22871	14235Q	PARTICIPANT	\N	PRESENT	0
22984	22979	11068S	PARTICIPANT	\N	PRESENT	0
22924	22871	04033B	PARTICIPANT	\N	PRESENT	0
22925	22871	14229S	PARTICIPANT	\N	PRESENT	0
22926	22871	11043H	PARTICIPANT	\N	PRESENT	0
22927	22871	11071M	PARTICIPANT	\N	PRESENT	0
22985	22979	11040E	PARTICIPANT	\N	PRESENT	0
21455	21414	14013P	PARTICIPANT	\N	EXCUSE	0
21447	21414	04088S	PARTICIPANT	\N	PRESENT	0
21457	21414	08019V	PARTICIPANT	\N	EXCUSE	0
21449	21414	11090Q	PARTICIPANT	\N	PRESENT	0
21450	21414	11046L	PARTICIPANT	\N	PRESENT	0
21451	21414	01058X	PARTICIPANT	\N	PRESENT	0
21456	21414	01061S	PARTICIPANT	\N	EXCUSE	0
21453	21414	11066Q	PARTICIPANT	\N	PRESENT	0
21458	21414	11094U	PARTICIPANT	\N	EXCUSE	0
21459	21414	14133K	PARTICIPANT	\N	PRESENT	0
21460	21414	96004D	PARTICIPANT	\N	PRESENT	0
21461	21414	11083R	PARTICIPANT	\N	PRESENT	0
21462	21414	14097Y	PARTICIPANT	\N	PRESENT	0
21463	21414	04061F	PARTICIPANT	\N	PRESENT	0
21464	21414	14073Q	PARTICIPANT	\N	PRESENT	0
21465	21414	98046X	PARTICIPANT	\N	PRESENT	0
21466	21414	04057K	PARTICIPANT	\N	PRESENT	0
21467	21414	95049N	PARTICIPANT	\N	PRESENT	0
21468	21414	04080J	PARTICIPANT	\N	PRESENT	0
21469	21414	14135M	PARTICIPANT	\N	PRESENT	0
21470	21414	10015M	PARTICIPANT	\N	PRESENT	0
21474	21374	04080J	PARTICIPANT	\N	PRESENT	0
21475	21352	11036J	PARTICIPANT	\N	PRESENT	0
21476	21352	08068F	PARTICIPANT	\N	PRESENT	0
21477	21352	14207L	PARTICIPANT	\N	PRESENT	0
21478	21352	80013X	PARTICIPANT	\N	PRESENT	0
21479	21352	14197C	PARTICIPANT	\N	PRESENT	0
21480	21352	14033T	PARTICIPANT	\N	PRESENT	0
21481	21352	14081Q	PARTICIPANT	\N	PRESENT	0
21482	21352	04048J	PARTICIPANT	\N	PRESENT	0
21483	21352	11099A	PARTICIPANT	\N	PRESENT	0
21484	21352	04049K	PARTICIPANT	\N	PRESENT	0
21485	21352	04094Q	PARTICIPANT	\N	PRESENT	0
21486	21352	11100Y	PARTICIPANT	\N	PRESENT	0
21487	21352	11098Y	PARTICIPANT	\N	PRESENT	0
21488	21352	11077T	PARTICIPANT	\N	PRESENT	0
21489	21352	14205J	PARTICIPANT	\N	PRESENT	0
21490	21352	04088S	PARTICIPANT	\N	PRESENT	0
21491	21352	11090Q	PARTICIPANT	\N	PRESENT	0
21492	21352	11046L	PARTICIPANT	\N	PRESENT	0
21493	21352	01058X	PARTICIPANT	\N	PRESENT	0
21494	21352	11066Q	PARTICIPANT	\N	PRESENT	0
21495	21374	11083R	PARTICIPANT	\N	EXCUSE	0
22934	22564	01007L	PARTICIPANT	\N	PRESENT	0
22935	22564	98005N	PARTICIPANT	\N	PRESENT	0
22936	22564	14105F	PARTICIPANT	\N	PRESENT	0
22937	22564	01056V	PARTICIPANT	\N	PRESENT	0
22938	22564	04088S	PARTICIPANT	\N	PRESENT	0
22939	22564	01015L	PARTICIPANT	\N	PRESENT	0
22940	22564	11054L	PARTICIPANT	\N	PRESENT	0
22941	22564	01022K	PARTICIPANT	\N	PRESENT	0
22942	22564	14051J	PARTICIPANT	\N	PRESENT	0
22943	22564	08009T	PARTICIPANT	\N	PRESENT	0
22944	22564	14157T	PARTICIPANT	\N	PRESENT	0
22945	22564	11107G	PARTICIPANT	\N	PRESENT	0
22946	22564	13002U	PARTICIPANT	\N	PRESENT	0
22947	22564	11025F	PARTICIPANT	\N	PRESENT	0
22948	22564	14219Q	PARTICIPANT	\N	PRESENT	0
22949	22564	14273W	PARTICIPANT	\N	PRESENT	0
22950	22564	14037X	PARTICIPANT	\N	PRESENT	0
22951	22564	14030Q	PARTICIPANT	\N	PRESENT	0
22952	22564	11060J	PARTICIPANT	\N	PRESENT	0
22953	22564	14063N	PARTICIPANT	\N	PRESENT	0
22954	22564	01025N	PARTICIPANT	\N	PRESENT	0
22955	22564	14033T	PARTICIPANT	\N	PRESENT	0
22956	22564	14265W	PARTICIPANT	\N	PRESENT	0
22957	22564	14199E	PARTICIPANT	\N	PRESENT	0
22958	22564	14031R	PARTICIPANT	\N	PRESENT	0
22959	22564	14135M	PARTICIPANT	\N	PRESENT	0
22960	22564	98023Q	PARTICIPANT	\N	PRESENT	0
22961	22564	14042U	PARTICIPANT	\N	PRESENT	0
22962	22564	11065P	PARTICIPANT	\N	PRESENT	0
22963	22564	14253S	PARTICIPANT	\N	PRESENT	0
22964	22564	14083S	PARTICIPANT	\N	PRESENT	0
22965	22564	14241N	PARTICIPANT	\N	PRESENT	0
22966	22564	90003B	PARTICIPANT	\N	PRESENT	0
22967	22564	14121F	PARTICIPANT	\N	PRESENT	0
22968	22564	08056B	PARTICIPANT	\N	PRESENT	0
22969	22564	14237S	PARTICIPANT	\N	PRESENT	0
22970	22564	14041T	PARTICIPANT	\N	PRESENT	0
22971	22564	95015C	PARTICIPANT	\N	PRESENT	0
22972	22564	11036J	PARTICIPANT	\N	PRESENT	0
22976	22564	14087W	PARTICIPANT	\N	PRESENT	0
22974	22564	14223L	PARTICIPANT	\N	PRESENT	0
22975	22564	11114F	PARTICIPANT	\N	PRESENT	0
22977	22564	14133K	PARTICIPANT	\N	PRESENT	0
22978	22564	14217N	PARTICIPANT	\N	PRESENT	0
22986	22979	08014Q	PARTICIPANT	\N	PRESENT	0
22987	22979	14167V	PARTICIPANT	\N	PRESENT	0
22988	22979	14175V	PARTICIPANT	\N	PRESENT	0
22989	22979	14083S	PARTICIPANT	\N	PRESENT	0
22990	22979	11053K	PARTICIPANT	\N	PRESENT	0
22991	22979	14085U	PARTICIPANT	\N	PRESENT	0
22992	22979	11042G	PARTICIPANT	\N	EXCUSE	0
22993	22979	88008L	PARTICIPANT	\N	PRESENT	0
22994	22979	04086Q	PARTICIPANT	\N	PRESENT	0
22995	22979	04055H	PARTICIPANT	\N	PRESENT	0
22996	22979	11070L	PARTICIPANT	\N	PRESENT	0
22997	22979	11088W	PARTICIPANT	\N	PRESENT	0
22998	22979	14327T	PARTICIPANT	\N	PRESENT	0
22999	22979	08022Q	PARTICIPANT	\N	PRESENT	0
23000	22979	01027Q	PARTICIPANT	\N	PRESENT	0
23001	22979	04071H	PARTICIPANT	\N	PRESENT	0
23002	22979	11074Q	PARTICIPANT	\N	PRESENT	0
23003	22979	98053W	PARTICIPANT	\N	PRESENT	0
23004	22979	11083R	PARTICIPANT	\N	PRESENT	0
23005	22979	14199E	PARTICIPANT	\N	PRESENT	0
23006	22979	01057W	PARTICIPANT	\N	PRESENT	0
23007	22979	08016S	PARTICIPANT	\N	PRESENT	0
23008	22979	08069G	PARTICIPANT	\N	PRESENT	0
23009	22979	11048N	PARTICIPANT	\N	PRESENT	0
23010	22979	99004R	PARTICIPANT	\N	PRESENT	0
23011	22979	04061F	PARTICIPANT	\N	PRESENT	0
23012	22979	14159V	PARTICIPANT	\N	PRESENT	0
23013	22979	07029T	PARTICIPANT	\N	PRESENT	0
23045	23044	89017R	PARTICIPANT	\N	EXCUSE	0
23015	22979	08010L	PARTICIPANT	\N	PRESENT	0
23016	22979	08034U	PARTICIPANT	\N	PRESENT	0
23081	23044	08034U	PARTICIPANT	\N	PRESENT	0
23018	22979	98046X	PARTICIPANT	\N	PRESENT	0
23019	22979	11085T	PARTICIPANT	\N	PRESENT	0
23020	22979	08011M	PARTICIPANT	\N	PRESENT	0
23046	23044	01031L	PRESIDENT	0	PRESENT	0
23022	22979	08061X	PARTICIPANT	\N	PRESENT	0
23023	22979	01016M	PARTICIPANT	\N	PRESENT	0
23024	22979	14225N	PARTICIPANT	\N	PRESENT	0
23025	22979	11012A	PARTICIPANT	\N	PRESENT	0
23026	22979	11057P	PARTICIPANT	\N	PRESENT	0
23027	22979	14173T	PARTICIPANT	\N	PRESENT	0
23028	22979	04034C	PARTICIPANT	\N	PRESENT	0
23048	23044	01013J	PARTICIPANT	\N	PRESENT	0
23049	23044	11068S	PARTICIPANT	\N	PRESENT	0
23050	23044	11040E	PARTICIPANT	\N	PRESENT	0
23051	23044	08014Q	PARTICIPANT	\N	PRESENT	0
23053	23044	14175V	PARTICIPANT	\N	PRESENT	0
23054	23044	14083S	PARTICIPANT	\N	PRESENT	0
23055	23044	11053K	PARTICIPANT	\N	PRESENT	0
23056	23044	14085U	PARTICIPANT	\N	PRESENT	0
23057	23044	11042G	PARTICIPANT	\N	EXCUSE	0
23058	23044	88008L	PARTICIPANT	\N	PRESENT	0
23059	23044	04086Q	PARTICIPANT	\N	PRESENT	0
23062	23044	11088W	PARTICIPANT	\N	PRESENT	0
23064	23044	08022Q	PARTICIPANT	\N	PRESENT	0
23065	23044	01027Q	PARTICIPANT	\N	PRESENT	0
23071	23044	01057W	PARTICIPANT	\N	PRESENT	0
23074	23044	11048N	PARTICIPANT	\N	PRESENT	0
23076	23044	04061F	PARTICIPANT	\N	PRESENT	0
23077	23044	14159V	PARTICIPANT	\N	PRESENT	0
23078	23044	07029T	PARTICIPANT	\N	PRESENT	0
23080	23044	08010L	PARTICIPANT	\N	PRESENT	0
23029	22564	14235Q	PARTICIPANT	\N	PRESENT	0
23030	22564	11098Y	PARTICIPANT	\N	PRESENT	0
23031	22564	11037K	PARTICIPANT	\N	PRESENT	0
23032	22564	08062Y	PARTICIPANT	\N	PRESENT	0
23033	22564	07032N	PARTICIPANT	\N	PRESENT	0
23034	22564	97011G	PARTICIPANT	\N	PRESENT	0
23035	22564	14227Q	PARTICIPANT	\N	PRESENT	0
23036	22564	14267Y	PARTICIPANT	\N	PRESENT	0
23037	22564	14191V	PARTICIPANT	\N	PRESENT	0
23038	22564	08044W	PARTICIPANT	\N	PRESENT	0
23039	22564	08068F	PARTICIPANT	\N	PRESENT	0
23040	22564	14053L	PARTICIPANT	\N	PRESENT	0
23041	22564	11104D	PARTICIPANT	\N	PRESENT	0
23042	22564	14111D	PARTICIPANT	\N	PRESENT	0
23043	22564	14069U	PARTICIPANT	\N	PRESENT	0
23099	22564	14073Q	PARTICIPANT	\N	PRESENT	0
23083	23044	98046X	PARTICIPANT	\N	PRESENT	0
23100	22564	01003G	PARTICIPANT	\N	PRESENT	0
23085	23044	08011M	PARTICIPANT	\N	PRESENT	0
23101	22564	11012A	PARTICIPANT	\N	PRESENT	0
23087	23044	08061X	PARTICIPANT	\N	PRESENT	0
23088	23044	01016M	PARTICIPANT	\N	PRESENT	0
23102	22564	14179A	PARTICIPANT	\N	PRESENT	0
23104	23103	01008M	PARTICIPANT	\N	EXCUSE	0
23091	23044	11057P	PARTICIPANT	\N	PRESENT	0
23105	23103	11036J	PARTICIPANT	\N	PRESENT	0
23144	22564	08014Q	PARTICIPANT	\N	PRESENT	0
23094	22564	14147R	PARTICIPANT	\N	PRESENT	0
23095	22564	14093U	PARTICIPANT	\N	PRESENT	0
23096	22564	05012A	PARTICIPANT	\N	PRESENT	0
23097	22564	04059M	PARTICIPANT	\N	PRESENT	0
23098	22564	98022P	PARTICIPANT	\N	PRESENT	0
23107	23103	14013P	PARTICIPANT	\N	EXCUSE	0
23108	23103	08068F	PARTICIPANT	\N	PRESENT	0
23145	22564	11043H	PARTICIPANT	\N	PRESENT	0
23110	23103	11101A	PARTICIPANT	\N	PRESENT	0
23111	23103	90003B	PARTICIPANT	\N	PRESENT	0
23112	23103	08028W	PARTICIPANT	\N	PRESENT	0
23113	23103	80013X	PARTICIPANT	\N	PRESENT	0
23114	23103	08038Y	PARTICIPANT	\N	PRESENT	0
23115	23103	04089T	PARTICIPANT	\N	PRESENT	0
23116	23103	14197C	PARTICIPANT	\N	PRESENT	0
23117	23103	11110B	PARTICIPANT	\N	PRESENT	0
23118	23103	14187A	PARTICIPANT	\N	PRESENT	0
23119	23103	14033T	PARTICIPANT	\N	PRESENT	0
23120	23103	14081Q	PARTICIPANT	\N	PRESENT	0
23147	23146	14261S	PARTICIPANT	\N	PRESENT	0
23122	23103	11099A	PARTICIPANT	\N	PRESENT	0
23123	23103	04049K	PARTICIPANT	\N	PRESENT	0
23148	23146	08055A	PARTICIPANT	\N	PRESENT	0
23125	23103	11111C	PARTICIPANT	\N	PRESENT	0
23126	23103	08015R	PARTICIPANT	\N	PRESENT	0
23127	23103	11100Y	PRESIDENT	0	PRESENT	0
23128	23103	01061S	PARTICIPANT	\N	PRESENT	0
23149	23146	14093U	PARTICIPANT	\N	PRESENT	0
23130	23103	01043Q	PARTICIPANT	\N	EXCUSE	0
23131	23103	11077T	PARTICIPANT	\N	PRESENT	0
23132	23103	14205J	PARTICIPANT	\N	PRESENT	0
23133	23103	08019V	PARTICIPANT	\N	PRESENT	0
23134	23103	14257W	PARTICIPANT	\N	PRESENT	0
23135	23103	08021P	PARTICIPANT	\N	EXCUSE	0
23136	23103	04088S	PARTICIPANT	\N	PRESENT	0
23150	23146	14030Q	PARTICIPANT	\N	PRESENT	0
23186	23146	95062K	PARTICIPANT	\N	EXCUSE	0
23139	23103	11046L	PARTICIPANT	\N	PRESENT	0
23140	23103	01058X	PARTICIPANT	\N	PRESENT	0
23141	23103	11094U	PARTICIPANT	\N	PRESENT	0
23142	23103	11066Q	PARTICIPANT	\N	PRESENT	0
23143	22564	14213J	PARTICIPANT	\N	PRESENT	0
23151	23146	96004D	PARTICIPANT	\N	PRESENT	0
23152	23146	08060W	PARTICIPANT	\N	PRESENT	0
23227	22564	11066Q	PARTICIPANT	\N	PRESENT	0
23154	23146	11095V	PARTICIPANT	\N	PRESENT	0
23155	23146	14038Y	PARTICIPANT	\N	PRESENT	0
23228	22564	11110B	PARTICIPANT	\N	PRESENT	0
23157	23146	98023Q	PARTICIPANT	\N	PRESENT	0
23158	23146	11065P	PARTICIPANT	\N	PRESENT	0
23159	23146	01015L	PARTICIPANT	\N	PRESENT	0
23160	23146	11107G	PARTICIPANT	\N	PRESENT	0
23190	23187	14093U	PARTICIPANT	\N	PRESENT	0
23162	23146	02002K	PARTICIPANT	\N	PRESENT	0
23163	23146	01022K	PARTICIPANT	\N	PRESENT	0
23164	23146	04097T	PARTICIPANT	\N	PRESENT	0
23165	23146	09001P	PARTICIPANT	\N	PRESENT	0
23166	23146	11059R	PARTICIPANT	\N	PRESENT	0
23167	23146	14219Q	PARTICIPANT	\N	PRESENT	0
23191	23187	14030Q	PARTICIPANT	\N	EXCUSE	0
23169	23146	14031R	PARTICIPANT	\N	PRESENT	0
23170	23146	08009T	PRESIDENT	0	PRESENT	0
23171	23146	08062Y	PARTICIPANT	\N	PRESENT	0
23172	23146	14221J	PARTICIPANT	\N	PRESENT	0
23229	22564	14263U	PARTICIPANT	\N	PRESENT	0
23174	23146	08042U	PARTICIPANT	\N	PRESENT	0
23193	23187	08060W	PARTICIPANT	\N	PRESENT	0
23176	23146	14237S	PARTICIPANT	\N	PRESENT	0
23177	23146	13002U	PARTICIPANT	\N	PRESENT	0
23178	23146	05012A	PARTICIPANT	\N	PRESENT	0
23230	22564	14269B	PARTICIPANT	\N	PRESENT	0
23180	23146	14135M	PARTICIPANT	\N	PRESENT	0
23231	22564	14201E	PARTICIPANT	\N	PRESENT	0
23182	23146	14107H	PARTICIPANT	\N	PRESENT	0
23183	23146	14051J	PARTICIPANT	\N	PRESENT	0
23184	23146	14157T	PARTICIPANT	\N	PRESENT	0
23185	23146	96003C	PARTICIPANT	\N	EXCUSE	0
23232	22564	14079W	PARTICIPANT	\N	PRESENT	0
23233	22564	04044E	PARTICIPANT	\N	PRESENT	0
23198	23187	98023Q	PARTICIPANT	\N	PRESENT	0
23234	22564	08055A	PARTICIPANT	\N	PRESENT	0
23200	23187	01015L	PARTICIPANT	\N	PRESENT	0
23201	23187	11107G	PARTICIPANT	\N	PRESENT	0
23235	22564	14257W	PARTICIPANT	\N	PRESENT	0
23236	22564	11109J	PARTICIPANT	\N	PRESENT	0
23204	23187	01022K	PARTICIPANT	\N	PRESENT	0
23237	22564	99004R	PARTICIPANT	\N	PRESENT	0
23206	23187	09001P	PARTICIPANT	\N	PRESENT	0
23238	22564	14259Y	PARTICIPANT	\N	PRESENT	0
23208	23187	14219Q	PARTICIPANT	\N	PRESENT	0
23239	22564	08051V	PARTICIPANT	\N	PRESENT	0
23210	23187	14031R	PARTICIPANT	\N	PRESENT	0
23211	23187	08009T	PRESIDENT	0	PRESENT	0
23212	23187	08062Y	PARTICIPANT	\N	PRESENT	0
23213	23187	14221J	PARTICIPANT	\N	PRESENT	0
23240	22564	14109K	PARTICIPANT	\N	PRESENT	0
23215	23187	08042U	PARTICIPANT	\N	PRESENT	0
23241	22564	95035G	PARTICIPANT	\N	PRESENT	0
23242	22564	95067Q	PARTICIPANT	\N	PRESENT	0
23218	23187	13002U	PARTICIPANT	\N	PRESENT	0
23219	23187	05012A	PARTICIPANT	\N	PRESENT	0
23243	22564	14159V	PARTICIPANT	\N	PRESENT	0
23245	23244	14239U	PARTICIPANT	\N	PRESENT	0
23222	23187	95062K	PARTICIPANT	\N	EXCUSE	0
23223	23187	14107H	PARTICIPANT	\N	PRESENT	0
23224	23187	14051J	PARTICIPANT	\N	PRESENT	0
23225	23187	14157T	PARTICIPANT	\N	PRESENT	0
23246	23244	01046T	PARTICIPANT	\N	PRESENT	0
23247	23244	04053F	PARTICIPANT	\N	PRESENT	0
23248	23244	14255U	PARTICIPANT	\N	PRESENT	0
23249	23244	04066L	PARTICIPANT	\N	PRESENT	0
23250	23244	14053L	PARTICIPANT	\N	PRESENT	0
23251	23244	11103C	PARTICIPANT	\N	PRESENT	0
23252	23244	14195A	PARTICIPANT	\N	PRESENT	0
23253	23244	14267Y	PARTICIPANT	\N	PRESENT	0
23254	23244	11031D	PARTICIPANT	\N	PRESENT	0
23255	23244	08052W	PARTICIPANT	\N	PRESENT	0
23256	23244	01059Y	PARTICIPANT	\N	PRESENT	0
23257	23244	04081K	PARTICIPANT	\N	PRESENT	0
23258	23244	98024R	PARTICIPANT	\N	PRESENT	0
23259	23244	10006L	PARTICIPANT	\N	PRESENT	0
23260	23244	14217N	PARTICIPANT	\N	PRESENT	0
23261	23244	14042U	PARTICIPANT	\N	PRESENT	0
23262	23244	14151M	PARTICIPANT	\N	PRESENT	0
23263	23244	12042Y	PARTICIPANT	\N	PRESENT	0
23264	23244	14087W	PARTICIPANT	\N	PRESENT	0
23265	23244	01003G	PARTICIPANT	\N	PRESENT	0
23266	23244	14231L	PARTICIPANT	\N	PRESENT	0
23267	23244	11061K	PARTICIPANT	\N	PRESENT	0
23268	23244	08041T	PARTICIPANT	\N	PRESENT	0
23269	23244	01011G	PARTICIPANT	\N	PRESENT	0
23270	23244	14026U	PARTICIPANT	\N	PRESENT	0
23271	23244	14213J	PARTICIPANT	\N	PRESENT	0
23272	23244	14121F	PARTICIPANT	\N	PRESENT	0
23273	22564	11067R	PARTICIPANT	\N	PRESENT	0
23274	23244	11112D	PARTICIPANT	\N	PRESENT	0
23275	23244	14037X	PARTICIPANT	\N	PRESENT	0
23276	23244	14018U	PARTICIPANT	\N	PRESENT	0
23277	23244	11067R	PARTICIPANT	\N	EXCUSE	0
23278	23244	14223L	PARTICIPANT	\N	PRESENT	0
23279	23244	04092N	PRESIDENT	0	PRESENT	0
23280	23244	14265W	PARTICIPANT	\N	PRESENT	0
21529	21521	08024S	PARTICIPANT	\N	PRESENT	0
21530	21521	07026Q	PARTICIPANT	\N	PRESENT	0
21531	21521	01025N	PARTICIPANT	\N	PRESENT	0
21532	21521	14123H	PARTICIPANT	\N	PRESENT	0
21533	21521	11104D	PARTICIPANT	\N	PRESENT	0
21534	21521	14028W	PARTICIPANT	\N	PRESENT	0
21535	21521	14247U	PARTICIPANT	\N	PRESENT	0
21536	21521	01003G	PARTICIPANT	\N	PRESENT	0
21537	21521	14263U	PARTICIPANT	\N	PRESENT	0
21538	21521	01044R	PARTICIPANT	\N	PRESENT	0
21539	21521	14111D	PARTICIPANT	\N	PRESENT	0
21540	21521	14249W	PARTICIPANT	\N	PRESENT	0
21541	21521	14261S	PARTICIPANT	\N	PRESENT	0
21542	21501	83042R	PARTICIPANT	\N	EXCUSE	0
21543	21521	14227Q	PARTICIPANT	\N	PRESENT	0
21544	21521	11083R	PARTICIPANT	\N	PRESENT	0
21545	21521	04059M	PARTICIPANT	\N	PRESENT	0
21546	21521	04070G	PARTICIPANT	\N	PRESENT	0
21547	21521	04067M	PARTICIPANT	\N	PRESENT	0
21548	21521	08043V	PARTICIPANT	\N	PRESENT	0
21549	21521	14061L	PARTICIPANT	\N	PRESENT	0
21550	21521	11109J	PARTICIPANT	\N	PRESENT	0
21551	21521	14041T	PARTICIPANT	\N	PRESENT	0
21552	21501	80013X	PARTICIPANT	\N	EXCUSE	0
21553	21501	11089X	PARTICIPANT	\N	EXCUSE	0
21554	21501	14221J	PARTICIPANT	\N	EXCUSE	0
21555	21501	11082Q	PARTICIPANT	\N	EXCUSE	0
21556	21501	04043D	PARTICIPANT	\N	EXCUSE	0
21557	21521	98053W	PARTICIPANT	\N	PRESENT	0
21558	21521	08019V	PARTICIPANT	\N	PRESENT	0
21559	21521	11071M	PARTICIPANT	\N	PRESENT	0
21560	21501	01058X	PARTICIPANT	\N	EXCUSE	0
21561	21521	08025T	PARTICIPANT	\N	PRESENT	0
21562	21521	14259Y	PARTICIPANT	\N	PRESENT	0
21564	21521	11074Q	PARTICIPANT	\N	PRESENT	0
21595	21528	11074Q	PARTICIPANT	\N	PRESENT	0
21596	21528	11109J	PARTICIPANT	\N	PRESENT	0
21597	21528	14227Q	PARTICIPANT	\N	PRESENT	0
21598	21528	01003G	PARTICIPANT	\N	PRESENT	0
21599	21528	14261S	PARTICIPANT	\N	PRESENT	0
21600	21528	11071M	PARTICIPANT	\N	PRESENT	0
21605	21528	05008E	PARTICIPANT	\N	PRESENT	0
21606	21528	08019V	PARTICIPANT	\N	PRESENT	0
21603	21528	14041T	PARTICIPANT	\N	PRESENT	0
21604	21528	07026Q	PARTICIPANT	\N	PRESENT	0
21607	21528	01025N	PARTICIPANT	\N	PRESENT	0
21608	21528	11083R	PARTICIPANT	\N	PRESENT	0
21609	21528	98053W	PARTICIPANT	\N	PRESENT	0
21610	21528	14263U	PARTICIPANT	\N	PRESENT	0
21611	21528	01044R	PARTICIPANT	\N	PRESENT	0
21631	21522	11031D	PARTICIPANT	\N	PRESENT	0
21632	21522	07026Q	PARTICIPANT	\N	PRESENT	0
21633	21522	14227Q	PARTICIPANT	\N	PRESENT	0
21634	21522	00003C	PARTICIPANT	\N	PRESENT	0
21635	21522	08052W	PARTICIPANT	\N	PRESENT	0
21636	21522	04053F	PARTICIPANT	\N	PRESENT	0
21637	21522	11055M	PARTICIPANT	\N	PRESENT	0
21638	21522	14018U	PARTICIPANT	\N	PRESENT	0
21639	21522	11094U	PARTICIPANT	\N	PRESENT	0
21640	21522	08019V	PARTICIPANT	\N	PRESENT	0
21641	21522	14195A	PARTICIPANT	\N	PRESENT	0
21642	21522	14265W	PARTICIPANT	\N	PRESENT	0
21643	21522	11103C	PARTICIPANT	\N	PRESENT	0
21593	21528	08024S	PARTICIPANT	\N	PRESENT	0
21594	21528	08025T	PARTICIPANT	\N	PRESENT	0
21644	21522	14042U	PARTICIPANT	\N	PRESENT	0
21645	21522	04092N	PARTICIPANT	\N	PRESENT	0
21629	21522	98053W	PARTICIPANT	\N	PRESENT	0
21630	21522	11067R	PARTICIPANT	\N	PRESENT	0
21646	21522	07034Q	PARTICIPANT	\N	PRESENT	0
21647	21522	01028R	PARTICIPANT	\N	PRESENT	0
21648	21522	14261S	PARTICIPANT	\N	PRESENT	0
21649	21522	14069U	PARTICIPANT	\N	PRESENT	0
21653	21522	14179A	PARTICIPANT	\N	PRESENT	0
21667	21522	80013X	PARTICIPANT	\N	PRESENT	0
21668	21522	14213J	PARTICIPANT	\N	PRESENT	0
21669	21522	14119M	PARTICIPANT	\N	PRESENT	0
21670	21522	11042G	PARTICIPANT	\N	PRESENT	0
21671	21522	11104D	PARTICIPANT	\N	PRESENT	0
21672	21522	14133K	PARTICIPANT	\N	PRESENT	0
21673	21522	10006L	PARTICIPANT	\N	PRESENT	0
21674	21522	11061K	PARTICIPANT	\N	PRESENT	0
22638	22637	04054G	PARTICIPANT	\N	PRESENT	0
22639	22637	08058D	PARTICIPANT	\N	PRESENT	0
22640	22637	04042C	PARTICIPANT	\N	PRESENT	0
22641	22637	98029W	PARTICIPANT	\N	PRESENT	0
22642	22637	98018T	PARTICIPANT	\N	PRESENT	0
22643	22637	92018S	PARTICIPANT	\N	PRESENT	0
22644	22637	92020L	PARTICIPANT	\N	PRESENT	0
22645	22637	95030B	PARTICIPANT	\N	PRESENT	0
22646	22637	95031C	PARTICIPANT	\N	PRESENT	0
22647	22637	97011G	PARTICIPANT	\N	PRESENT	0
22648	22637	08065C	PARTICIPANT	\N	PRESENT	0
22649	22637	04035D	PARTICIPANT	\N	PRESENT	0
22650	22637	07024N	PARTICIPANT	\N	PRESENT	0
22651	22637	14014Q	PARTICIPANT	\N	PRESENT	0
22652	22637	11015D	PARTICIPANT	\N	PRESENT	0
22653	22637	07004J	PARTICIPANT	\N	PRESENT	0
22654	22637	95035G	PARTICIPANT	\N	EXCUSE	0
22655	22637	08056B	PARTICIPANT	\N	PRESENT	0
22656	22637	98022P	PARTICIPANT	\N	PRESENT	0
22657	22637	14097Y	PARTICIPANT	\N	PRESENT	0
22658	22637	04036E	PARTICIPANT	\N	PRESENT	0
22659	22637	14039A	PARTICIPANT	\N	PRESENT	0
22660	22637	92031P	PARTICIPANT	\N	PRESENT	0
22661	22637	83042R	PARTICIPANT	\N	PRESENT	0
22662	22637	11105E	PARTICIPANT	\N	EXCUSE	0
22663	22637	08047A	PARTICIPANT	\N	PRESENT	0
22664	22637	14028W	PARTICIPANT	\N	PRESENT	0
22665	22637	14193X	PARTICIPANT	\N	PRESENT	0
22666	22637	98021N	PARTICIPANT	\N	PRESENT	0
22667	22637	95059Q	PRESIDENT	0	PRESENT	0
22668	22637	86044G	PARTICIPANT	\N	PRESENT	0
22669	22637	01014K	PARTICIPANT	\N	PRESENT	0
22670	22637	11054L	PARTICIPANT	\N	PRESENT	0
22671	22637	01056V	PARTICIPANT	\N	PRESENT	0
22672	22637	92044U	PARTICIPANT	\N	PRESENT	0
22673	22637	08049C	PARTICIPANT	\N	PRESENT	0
22674	22637	05008E	PARTICIPANT	\N	PRESENT	0
22675	22637	14065Q	PARTICIPANT	\N	PRESENT	0
22676	22637	14069U	PARTICIPANT	\N	PRESENT	0
22677	22637	04047H	PARTICIPANT	\N	PRESENT	0
22678	22637	01024M	PARTICIPANT	\N	PRESENT	0
22679	22637	14215L	PARTICIPANT	\N	PRESENT	0
22680	22637	08018U	PARTICIPANT	\N	PRESENT	0
22681	22637	11010L	PARTICIPANT	\N	PRESENT	0
22682	22637	08044W	PARTICIPANT	\N	PRESENT	0
22683	22637	11026G	PARTICIPANT	\N	PRESENT	0
22684	22637	14111D	PARTICIPANT	\N	PRESENT	0
22685	22637	14001X	PARTICIPANT	\N	PRESENT	0
22686	22637	14147R	PARTICIPANT	\N	PRESENT	0
22687	22637	95049N	PARTICIPANT	\N	PRESENT	0
22688	22637	08051V	PARTICIPANT	\N	PRESENT	0
22689	22637	04074L	PARTICIPANT	\N	PRESENT	0
22690	22637	10015M	PARTICIPANT	\N	PRESENT	0
22691	22637	98035U	PARTICIPANT	\N	PRESENT	0
22692	22637	04056J	PARTICIPANT	\N	PRESENT	0
22693	22637	04044E	PARTICIPANT	\N	PRESENT	0
22694	22637	95067Q	PARTICIPANT	\N	PRESENT	0
22695	22637	87003B	PARTICIPANT	\N	PRESENT	0
22696	22637	14247U	PARTICIPANT	\N	PRESENT	0
22697	22637	14031R	PARTICIPANT	\N	PRESENT	0
22698	22637	14179A	PARTICIPANT	\N	PRESENT	0
22699	22637	99004R	PARTICIPANT	\N	PRESENT	0
22700	22637	11066Q	PARTICIPANT	\N	PRESENT	0
22701	22637	14133K	PARTICIPANT	\N	PRESENT	0
22702	22637	11048N	PARTICIPANT	\N	PRESENT	0
22703	22637	04033B	PARTICIPANT	\N	PRESENT	0
22758	22755	04040A	PARTICIPANT	\N	EXCUSE	0
22759	22755	08058D	PARTICIPANT	\N	PRESENT	0
22761	22755	77002U	PARTICIPANT	\N	PRESENT	0
22762	22755	98029W	PARTICIPANT	\N	PRESENT	0
22763	22755	11080N	PARTICIPANT	\N	PRESENT	0
22764	22755	11027H	PARTICIPANT	\N	PRESENT	0
22765	22755	98018T	PARTICIPANT	\N	EXCUSE	0
22766	22755	92018S	PARTICIPANT	\N	PRESENT	0
22767	22755	92020L	PARTICIPANT	\N	PRESENT	0
22768	22755	95030B	PARTICIPANT	\N	PRESENT	0
22770	22755	95031C	PARTICIPANT	\N	PRESENT	0
22771	22755	97011G	PARTICIPANT	\N	PRESENT	0
22772	22755	08065C	PARTICIPANT	\N	PRESENT	0
22773	22755	04035D	PARTICIPANT	\N	PRESENT	0
22774	22755	07024N	PRESIDENT	0	PRESENT	0
21526	21501	01044R	PARTICIPANT	\N	EXCUSE	0
22313	21524	04092N	PARTICIPANT	\N	PRESENT	0
22314	21524	11054L	PARTICIPANT	\N	PRESENT	0
22315	21524	80013X	PARTICIPANT	\N	PRESENT	0
22316	21524	11061K	PARTICIPANT	\N	PRESENT	0
22317	21524	00003C	PARTICIPANT	\N	PRESENT	0
22318	21524	14014Q	PARTICIPANT	\N	PRESENT	0
22319	21524	08043V	PARTICIPANT	\N	PRESENT	0
22320	21524	14227Q	PARTICIPANT	\N	PRESENT	0
22321	21524	14257W	PARTICIPANT	\N	PRESENT	0
22322	21524	11109J	PARTICIPANT	\N	PRESENT	0
22323	21524	14039A	PARTICIPANT	\N	PRESENT	0
22324	21524	11072N	PARTICIPANT	\N	PRESENT	0
22325	21524	14065Q	PARTICIPANT	\N	PRESENT	0
22326	21524	12042Y	PARTICIPANT	\N	PRESENT	0
22327	21524	11099A	PARTICIPANT	\N	PRESENT	0
22328	21524	14103D	PARTICIPANT	\N	PRESENT	0
22329	21524	14205J	PARTICIPANT	\N	PRESENT	0
22330	21524	14018U	PARTICIPANT	\N	PRESENT	0
22331	21524	11055M	PARTICIPANT	\N	PRESENT	0
22332	21524	01059Y	PARTICIPANT	\N	PRESENT	0
22333	21524	11111C	PARTICIPANT	\N	PRESENT	0
22334	21524	14042U	PARTICIPANT	\N	PRESENT	0
22335	21524	11094U	PARTICIPANT	\N	PRESENT	0
22336	21524	01024M	PARTICIPANT	\N	PRESENT	0
22337	21524	11093T	PARTICIPANT	\N	PRESENT	0
22338	21524	14231L	PARTICIPANT	\N	PRESENT	0
22339	21524	14073Q	PARTICIPANT	\N	PRESENT	0
22340	21524	14087W	PARTICIPANT	\N	PRESENT	0
22341	21524	14063N	PARTICIPANT	\N	PRESENT	0
22342	21524	11025F	PARTICIPANT	\N	PRESENT	0
22343	21524	14069U	PARTICIPANT	\N	PRESENT	0
22344	21524	14241N	PARTICIPANT	\N	PRESENT	0
22345	21524	14209N	PARTICIPANT	\N	PRESENT	0
22346	21524	14059S	PARTICIPANT	\N	PRESENT	0
22347	21524	14061L	PARTICIPANT	\N	PRESENT	0
22348	21524	14213J	PARTICIPANT	\N	PRESENT	0
22349	21524	14223L	PARTICIPANT	\N	PRESENT	0
22350	21524	14187A	PARTICIPANT	\N	PRESENT	0
22351	21524	97011G	PARTICIPANT	\N	PRESENT	0
22352	21524	11103C	PARTICIPANT	\N	PRESENT	0
22353	21524	14147R	PARTICIPANT	\N	PRESENT	0
22354	21524	14265W	PARTICIPANT	\N	PRESENT	0
22355	21524	14111D	PARTICIPANT	\N	PRESENT	0
22356	21524	08018U	PARTICIPANT	\N	PRESENT	0
22357	21524	14195A	PARTICIPANT	\N	PRESENT	0
22358	21524	98005N	PARTICIPANT	\N	PRESENT	0
22359	21524	04041B	PARTICIPANT	\N	PRESENT	0
22360	21524	14173T	PARTICIPANT	\N	PRESENT	0
22361	21524	14271U	PARTICIPANT	\N	PRESENT	0
22362	21524	14081Q	PARTICIPANT	\N	PRESENT	0
22363	21524	14034U	PARTICIPANT	\N	PRESENT	0
22364	21524	14263U	PARTICIPANT	\N	PRESENT	0
22365	21524	11031D	PARTICIPANT	\N	PRESENT	0
22366	21524	01027Q	PARTICIPANT	\N	PRESENT	0
22367	21524	04053F	PARTICIPANT	\N	PRESENT	0
22368	21524	11067R	PARTICIPANT	\N	PRESENT	0
22369	21524	14109K	PARTICIPANT	\N	PRESENT	0
22370	21524	01028R	PARTICIPANT	\N	PRESENT	0
22371	21524	14191V	PARTICIPANT	\N	PRESENT	0
22372	21524	07004J	PARTICIPANT	\N	PRESENT	0
22373	21524	11034G	PARTICIPANT	\N	PRESENT	0
22374	21524	14217N	PARTICIPANT	\N	PRESENT	0
22375	21524	14261S	PARTICIPANT	\N	PRESENT	0
22376	21524	11082Q	PARTICIPANT	\N	PRESENT	0
22377	21524	08051V	PARTICIPANT	\N	PRESENT	0
22378	21524	14026U	PARTICIPANT	\N	PRESENT	0
22379	21524	08017T	PARTICIPANT	\N	PRESENT	0
22380	21524	11098Y	PARTICIPANT	\N	PRESENT	0
22381	21524	01025N	PARTICIPANT	\N	PRESENT	0
22382	21524	14267Y	PARTICIPANT	\N	PRESENT	0
22383	21524	14033T	PARTICIPANT	\N	PRESENT	0
22384	21524	04045F	PARTICIPANT	\N	PRESENT	0
22385	21524	11036J	PARTICIPANT	\N	PRESENT	0
22386	21524	08055A	PARTICIPANT	\N	PRESENT	0
22387	21524	10006L	PARTICIPANT	\N	PRESENT	0
22388	21524	14071N	PARTICIPANT	\N	PRESENT	0
22389	21524	08056B	PARTICIPANT	\N	PRESENT	0
22390	21524	08028W	PARTICIPANT	\N	PRESENT	0
22391	21524	14215L	PARTICIPANT	\N	PRESENT	0
22392	21524	14053L	PARTICIPANT	\N	PRESENT	0
22393	21524	14237S	PARTICIPANT	\N	PRESENT	0
22394	21524	14013P	PARTICIPANT	\N	PRESENT	0
22395	21524	14253S	PARTICIPANT	\N	PRESENT	0
22396	21524	14085U	PARTICIPANT	\N	PRESENT	0
22397	21612	04097T	PARTICIPANT	\N	PRESENT	0
22398	21524	07029T	PARTICIPANT	\N	PRESENT	0
22399	21524	14083S	PARTICIPANT	\N	PRESENT	0
22400	21524	11014C	PARTICIPANT	\N	PRESENT	0
22401	21524	04057K	PARTICIPANT	\N	PRESENT	0
22402	21524	95031C	PARTICIPANT	\N	PRESENT	0
22403	21524	04088S	PARTICIPANT	\N	PRESENT	0
22404	21524	14041T	PARTICIPANT	\N	PRESENT	0
22406	22405	86034E	PARTICIPANT	\N	PRESENT	0
22407	22405	04054G	PARTICIPANT	\N	PRESENT	0
22408	22405	98035U	PARTICIPANT	\N	PRESENT	0
22409	22405	11061K	PARTICIPANT	\N	PRESENT	0
22410	22405	98046X	PARTICIPANT	\N	PRESENT	0
22411	22405	80013X	PARTICIPANT	\N	PRESENT	0
22412	22405	04034C	PARTICIPANT	\N	PRESENT	0
22413	22405	11036J	PARTICIPANT	\N	PRESENT	0
22414	22405	11014C	PARTICIPANT	\N	PRESENT	0
22415	22405	14081Q	PARTICIPANT	\N	PRESENT	0
22416	22405	11083R	PARTICIPANT	\N	PRESENT	0
22417	22405	11026G	PARTICIPANT	\N	PRESENT	0
22418	22405	14261S	PARTICIPANT	\N	PRESENT	0
22419	22405	14103D	PARTICIPANT	\N	PRESENT	0
22420	22405	14205J	PARTICIPANT	\N	PRESENT	0
22421	22405	14089Y	PARTICIPANT	\N	PRESENT	0
22422	22405	04080J	PARTICIPANT	\N	PRESENT	0
22423	22405	14247U	PARTICIPANT	\N	PRESENT	0
22424	22405	14209N	PARTICIPANT	\N	PRESENT	0
22425	22405	14026U	PARTICIPANT	\N	PRESENT	0
22426	22405	14083S	PARTICIPANT	\N	PRESENT	0
22427	22405	04070G	PARTICIPANT	\N	PRESENT	0
22428	22405	14215L	PARTICIPANT	\N	PRESENT	0
22429	22405	14087W	PARTICIPANT	\N	PRESENT	0
22430	22405	14097Y	PARTICIPANT	\N	PRESENT	0
22431	22405	11012A	PARTICIPANT	\N	PRESENT	0
22432	22405	04057K	PARTICIPANT	\N	PRESENT	0
22433	22405	10015M	PARTICIPANT	\N	PRESENT	0
22434	22405	14041T	PARTICIPANT	\N	PRESENT	0
22435	22405	14253S	PARTICIPANT	\N	PRESENT	0
22436	22405	04061F	PARTICIPANT	\N	PRESENT	0
22437	22405	01027Q	PARTICIPANT	\N	PRESENT	0
22438	22405	14235Q	PARTICIPANT	\N	PRESENT	0
22439	22405	14107H	PARTICIPANT	\N	PRESENT	0
22440	22405	11025F	PARTICIPANT	\N	PRESENT	0
22311	21524	04066L	PARTICIPANT	\N	PRESENT	0
22312	21524	07034Q	PARTICIPANT	\N	PRESENT	0
22441	22405	04045F	PARTICIPANT	\N	PRESENT	0
22442	22405	11107G	PARTICIPANT	\N	PRESENT	0
22443	22405	04047H	PARTICIPANT	\N	PRESENT	0
22444	22405	14135M	PARTICIPANT	\N	PRESENT	0
22445	22405	86044G	PARTICIPANT	\N	PRESENT	0
22446	22405	95015C	PARTICIPANT	\N	PRESENT	0
22447	22405	01025N	PARTICIPANT	\N	PRESENT	0
22448	22405	14061L	PARTICIPANT	\N	PRESENT	0
22449	22405	14191V	PARTICIPANT	\N	PRESENT	0
22450	22405	01003G	PARTICIPANT	\N	PRESENT	0
22451	22405	08058D	PARTICIPANT	\N	PRESENT	0
22452	22405	14159V	PARTICIPANT	\N	PRESENT	0
22453	22405	14033T	PARTICIPANT	\N	PRESENT	0
22454	22405	08056B	PARTICIPANT	\N	PRESENT	0
22455	22405	14133K	PARTICIPANT	\N	PRESENT	0
22456	22405	01056V	PARTICIPANT	\N	PRESENT	0
22457	22405	14249W	PARTICIPANT	\N	PRESENT	0
22458	22405	05008E	PARTICIPANT	\N	PRESENT	0
22459	22405	14265W	PARTICIPANT	\N	PRESENT	0
22460	22405	11071M	PARTICIPANT	\N	PRESENT	0
22461	22405	95031C	PARTICIPANT	\N	PRESENT	0
22462	22405	98022P	PARTICIPANT	\N	PRESENT	0
22463	22405	08011M	PARTICIPANT	\N	PRESENT	0
22464	22405	14069U	PARTICIPANT	\N	PRESENT	0
22465	22405	04088S	PARTICIPANT	\N	PRESENT	0
22466	22405	14038Y	PARTICIPANT	\N	PRESENT	0
22467	22405	14187A	PARTICIPANT	\N	PRESENT	0
22468	22405	04033B	PARTICIPANT	\N	PRESENT	0
22469	22405	14001X	PARTICIPANT	\N	PRESENT	0
22470	22405	96004D	PARTICIPANT	\N	PRESENT	0
22471	22405	14217N	PARTICIPANT	\N	PRESENT	0
22472	22405	90003B	PARTICIPANT	\N	PRESENT	0
22473	22405	08069G	PARTICIPANT	\N	PRESENT	0
21454	21149	04080J	PARTICIPANT	\N	PRESENT	0
21471	21149	11089X	PARTICIPANT	\N	PRESENT	0
21472	21149	08055A	PARTICIPANT	\N	PRESENT	0
21473	21149	14157T	PARTICIPANT	\N	PRESENT	0
22496	21525	11067R	PARTICIPANT	\N	PRESENT	0
22497	21525	14147R	PARTICIPANT	\N	PRESENT	0
22498	21525	11103C	PARTICIPANT	\N	PRESENT	0
22499	21525	07034Q	PARTICIPANT	\N	PRESENT	0
22500	21525	11111C	PARTICIPANT	\N	PRESENT	0
22501	21525	98022P	PARTICIPANT	\N	PRESENT	0
22502	21525	11072N	PARTICIPANT	\N	PRESENT	0
22503	21525	01059Y	PARTICIPANT	\N	PRESENT	0
22504	21525	11031D	PARTICIPANT	\N	PRESENT	0
22505	21525	11098Y	PARTICIPANT	\N	PRESENT	0
22506	21525	80013X	PARTICIPANT	\N	PRESENT	0
22507	21525	14269B	PARTICIPANT	\N	PRESENT	0
22508	21525	04067M	PARTICIPANT	\N	PRESENT	0
22509	21525	14018U	PARTICIPANT	\N	PRESENT	0
22510	21525	14271U	PARTICIPANT	\N	PRESENT	0
22494	21525	08055A	PARTICIPANT	\N	PRESENT	0
22495	21525	00003C	PARTICIPANT	\N	PRESENT	0
22511	21525	11093T	PARTICIPANT	\N	PRESENT	0
22512	21525	14042U	PARTICIPANT	\N	PRESENT	0
22513	21525	14215L	PARTICIPANT	\N	PRESENT	0
22514	21525	92031P	PARTICIPANT	\N	PRESENT	0
22515	21525	14031R	PARTICIPANT	\N	PRESENT	0
22516	21525	14195A	PARTICIPANT	\N	PRESENT	0
22517	21525	14053L	PARTICIPANT	\N	PRESENT	0
22518	21525	10006L	PARTICIPANT	\N	PRESENT	0
22519	21525	14038Y	PARTICIPANT	\N	PRESENT	0
22524	21525	11112D	PARTICIPANT	\N	PRESENT	0
22526	21525	01028R	PARTICIPANT	\N	PRESENT	0
22525	21525	14197C	PARTICIPANT	\N	PRESENT	0
22527	21525	14107H	PARTICIPANT	\N	PRESENT	0
22528	21525	11095V	PARTICIPANT	\N	PRESENT	0
22529	21525	04053F	PARTICIPANT	\N	PRESENT	0
22530	21525	14087W	PARTICIPANT	\N	PRESENT	0
22531	21525	14253S	PARTICIPANT	\N	PRESENT	0
22532	21525	14213J	PARTICIPANT	\N	PRESENT	0
22533	21525	14026U	PARTICIPANT	\N	PRESENT	0
22534	21525	08015R	PARTICIPANT	\N	PRESENT	0
22535	21525	14235Q	PARTICIPANT	\N	PRESENT	0
22536	21525	14255U	PARTICIPANT	\N	PRESENT	0
22537	21525	14257W	PARTICIPANT	\N	PRESENT	0
22538	21525	04045F	PARTICIPANT	\N	PRESENT	0
22539	21525	14187A	PARTICIPANT	\N	PRESENT	0
22540	21525	95015C	PARTICIPANT	\N	PRESENT	0
22541	21525	14217N	PARTICIPANT	\N	PRESENT	0
22542	21525	14033T	PARTICIPANT	\N	PRESENT	0
22543	21525	14265W	PARTICIPANT	\N	PRESENT	0
22544	21525	14205J	PARTICIPANT	\N	PRESENT	0
22545	21525	08069G	PARTICIPANT	\N	PRESENT	0
22546	21525	95041E	PARTICIPANT	\N	PRESENT	0
22547	21525	14030Q	PARTICIPANT	\N	PRESENT	0
22548	21525	04092N	PARTICIPANT	\N	PRESENT	0
22549	21525	08017T	PARTICIPANT	\N	PRESENT	0
22550	21525	14014Q	PARTICIPANT	\N	PRESENT	0
22551	21525	01016M	PARTICIPANT	\N	PRESENT	0
22552	21525	07029T	PARTICIPANT	\N	PRESENT	0
22553	21525	11036J	PARTICIPANT	\N	PRESENT	0
22554	21525	11061K	PARTICIPANT	\N	PRESENT	0
22555	21525	14083S	PARTICIPANT	\N	PRESENT	0
22556	21525	08052W	PARTICIPANT	\N	PRESENT	0
22557	21525	14034U	PARTICIPANT	\N	PRESENT	0
22570	22569	05008E	PRESIDENT	0	PRESENT	0
22571	22569	14065Q	PARTICIPANT	\N	PRESENT	0
22572	22569	14069U	PARTICIPANT	\N	PRESENT	0
22573	22569	04047H	PARTICIPANT	\N	PRESENT	0
22574	22569	11035H	PARTICIPANT	\N	EXCUSE	0
22575	22569	01024M	PARTICIPANT	\N	PRESENT	0
22576	22569	14215L	PARTICIPANT	\N	PRESENT	0
22577	22569	08018U	PARTICIPANT	\N	PRESENT	0
22578	22569	11010L	PARTICIPANT	\N	PRESENT	0
22579	22569	08044W	PARTICIPANT	\N	PRESENT	0
22580	22569	11026G	PARTICIPANT	\N	PRESENT	0
22581	22569	14111D	PARTICIPANT	\N	PRESENT	0
22582	22569	14001X	PARTICIPANT	\N	PRESENT	0
22583	22569	14147R	PARTICIPANT	\N	PRESENT	0
22584	22569	95049N	PARTICIPANT	\N	PRESENT	0
22585	22569	08051V	PARTICIPANT	\N	PRESENT	0
22586	22569	04074L	PARTICIPANT	\N	PRESENT	0
22587	22569	10015M	PARTICIPANT	\N	PRESENT	0
22588	22569	98035U	PARTICIPANT	\N	PRESENT	0
22589	22569	04056J	PARTICIPANT	\N	PRESENT	0
22590	22569	04044E	PARTICIPANT	\N	PRESENT	0
22591	22569	92045V	PARTICIPANT	\N	EXCUSE	0
22592	22569	95067Q	PARTICIPANT	\N	PRESENT	0
22593	22569	04054G	PARTICIPANT	\N	PRESENT	0
22594	22569	08058D	PARTICIPANT	\N	PRESENT	0
22595	22569	04042C	PARTICIPANT	\N	PRESENT	0
22596	22569	98029W	PARTICIPANT	\N	PRESENT	0
22597	22569	98018T	PARTICIPANT	\N	PRESENT	0
22598	22569	92018S	PARTICIPANT	\N	PRESENT	0
22599	22569	92020L	PARTICIPANT	\N	PRESENT	0
22600	22569	95030B	PARTICIPANT	\N	PRESENT	0
22601	22569	95031C	PARTICIPANT	\N	PRESENT	0
22602	22569	97011G	PARTICIPANT	\N	PRESENT	0
22603	22569	08065C	PARTICIPANT	\N	PRESENT	0
22604	22569	04035D	PARTICIPANT	\N	PRESENT	0
22605	22569	07024N	PARTICIPANT	\N	PRESENT	0
22606	22569	14014Q	PARTICIPANT	\N	PRESENT	0
22607	22569	11015D	PARTICIPANT	\N	PRESENT	0
22608	22569	07004J	PARTICIPANT	\N	PRESENT	0
22609	22569	08056B	PARTICIPANT	\N	PRESENT	0
22610	22569	98022P	PARTICIPANT	\N	PRESENT	0
22611	22569	14097Y	PARTICIPANT	\N	PRESENT	0
22612	22569	04036E	PARTICIPANT	\N	PRESENT	0
22613	22569	14039A	PARTICIPANT	\N	PRESENT	0
22614	22569	92031P	PARTICIPANT	\N	PRESENT	0
22615	22569	83042R	PARTICIPANT	\N	PRESENT	0
22616	22569	08047A	PARTICIPANT	\N	PRESENT	0
22617	22569	14028W	PARTICIPANT	\N	PRESENT	0
22618	22569	14193X	PARTICIPANT	\N	PRESENT	0
22619	22569	98021N	PARTICIPANT	\N	PRESENT	0
22620	22569	95059Q	PARTICIPANT	\N	PRESENT	0
22621	22569	86044G	PARTICIPANT	\N	PRESENT	0
22622	22569	01014K	PARTICIPANT	\N	PRESENT	0
22623	22569	11054L	PARTICIPANT	\N	PRESENT	0
22624	22569	01056V	PARTICIPANT	\N	PRESENT	0
22625	22569	92044U	PARTICIPANT	\N	PRESENT	0
22626	22569	08049C	PARTICIPANT	\N	PRESENT	0
22627	22569	04033B	PARTICIPANT	\N	PRESENT	0
22628	22569	87003B	PARTICIPANT	\N	PRESENT	0
22629	22569	14187A	PARTICIPANT	\N	PRESENT	0
22630	22569	14247U	PARTICIPANT	\N	PRESENT	0
22631	22569	14031R	PARTICIPANT	\N	PRESENT	0
22632	22569	14179A	PARTICIPANT	\N	PRESENT	0
22633	22569	99004R	PARTICIPANT	\N	PRESENT	0
22634	22569	11066Q	PARTICIPANT	\N	PRESENT	0
22635	22569	14133K	PARTICIPANT	\N	PRESENT	0
22636	22569	11048N	PARTICIPANT	\N	PRESENT	0
22777	22755	11015D	PARTICIPANT	\N	PRESENT	0
22778	22755	07004J	PARTICIPANT	\N	PRESENT	0
22779	22755	95035G	PARTICIPANT	\N	PRESENT	0
22780	22755	08056B	PARTICIPANT	\N	PRESENT	0
22781	22755	14211G	PARTICIPANT	\N	PRESENT	0
22782	22755	98022P	PARTICIPANT	\N	PRESENT	0
22783	22755	11064N	PARTICIPANT	\N	PRESENT	0
22815	22813	04054G	PARTICIPANT	\N	PRESENT	0
22785	22755	04078Q	PARTICIPANT	\N	PRESENT	0
22786	22755	14097Y	PARTICIPANT	\N	PRESENT	0
22787	22755	95041E	PARTICIPANT	\N	PRESENT	0
22788	22755	04036E	PARTICIPANT	\N	PRESENT	0
22789	22755	14039A	PARTICIPANT	\N	PRESENT	0
22816	22813	04040A	PARTICIPANT	\N	EXCUSE	0
22791	22755	98005N	PARTICIPANT	\N	PRESENT	0
22792	22755	92031P	PARTICIPANT	\N	PRESENT	0
22793	22755	11106F	PARTICIPANT	\N	PRESENT	0
22794	22755	14251Q	PARTICIPANT	\N	PRESENT	0
22795	22755	83042R	PARTICIPANT	\N	PRESENT	0
22817	22813	08058D	PARTICIPANT	\N	PRESENT	0
22797	22755	11082Q	PARTICIPANT	\N	PRESENT	0
22798	22755	11105E	PARTICIPANT	\N	EXCUSE	0
22799	22755	14253S	PARTICIPANT	\N	PRESENT	0
22800	22755	08047A	PARTICIPANT	\N	PRESENT	0
22801	22755	14028W	PARTICIPANT	\N	PRESENT	0
22802	22755	14193X	PARTICIPANT	\N	PRESENT	0
22803	22755	98021N	PARTICIPANT	\N	PRESENT	0
22805	22755	04080J	PARTICIPANT	\N	PRESENT	0
22806	22755	95059Q	PARTICIPANT	\N	PRESENT	0
22807	22755	86044G	PARTICIPANT	\N	PRESENT	0
22808	22755	01014K	PARTICIPANT	\N	PRESENT	0
22809	22755	11054L	PARTICIPANT	\N	PRESENT	0
22810	22755	01056V	PARTICIPANT	\N	PRESENT	0
22811	22755	92044U	PARTICIPANT	\N	PRESENT	0
22812	22755	08049C	PARTICIPANT	\N	PRESENT	0
22818	22813	04042C	PARTICIPANT	\N	PRESENT	0
21681	21523	89029V	PARTICIPANT	\N	PRESENT	0
21682	21523	11054L	PARTICIPANT	\N	PRESENT	0
21683	21523	14197C	PARTICIPANT	\N	PRESENT	0
21684	21523	14159V	PARTICIPANT	\N	PRESENT	0
21685	21523	14103D	PARTICIPANT	\N	PRESENT	0
21686	21523	14261S	PARTICIPANT	\N	PRESENT	0
21687	21523	14061L	PARTICIPANT	\N	PRESENT	0
21688	21523	95067Q	PARTICIPANT	\N	PRESENT	0
21689	21523	14187A	PARTICIPANT	\N	PRESENT	0
21690	21523	14041T	PARTICIPANT	\N	PRESENT	0
21691	21523	96004D	PARTICIPANT	\N	PRESENT	0
21692	21523	98042T	PARTICIPANT	\N	PRESENT	0
21693	21523	08010L	PARTICIPANT	\N	PRESENT	0
21694	21523	08068F	PARTICIPANT	\N	PRESENT	0
21695	21523	14069U	PARTICIPANT	\N	PRESENT	0
21696	21523	14265W	PARTICIPANT	\N	PRESENT	0
21697	21523	14205J	PARTICIPANT	\N	PRESENT	0
21698	21523	04070G	PARTICIPANT	\N	PRESENT	0
21699	21523	04042C	PARTICIPANT	\N	PRESENT	0
21700	21523	14089Y	PARTICIPANT	\N	PRESENT	0
21701	21523	14179A	PARTICIPANT	\N	PRESENT	0
21702	21523	07026Q	PARTICIPANT	\N	PRESENT	0
21703	21523	11043H	PARTICIPANT	\N	PRESENT	0
21704	21523	08009T	PARTICIPANT	\N	PRESENT	0
21705	21523	11031D	PARTICIPANT	\N	PRESENT	0
21706	21523	11064N	PARTICIPANT	\N	PRESENT	0
21707	21523	11036J	PARTICIPANT	\N	PRESENT	0
21708	21523	10006L	PARTICIPANT	\N	PRESENT	0
21709	21523	95015C	PARTICIPANT	\N	PRESENT	0
21710	21523	14269B	PARTICIPANT	\N	PRESENT	0
21711	21523	08060W	PARTICIPANT	\N	PRESENT	0
21712	21523	11109J	PARTICIPANT	\N	PRESENT	0
21713	21523	14173T	PARTICIPANT	\N	PRESENT	0
21714	21523	14105F	PARTICIPANT	\N	PRESENT	0
21715	21523	80013X	PARTICIPANT	\N	PRESENT	0
21716	21523	14033T	PARTICIPANT	\N	PRESENT	0
21717	21523	14063N	PARTICIPANT	\N	PRESENT	0
21718	21523	14073Q	PARTICIPANT	\N	PRESENT	0
21719	21523	14014Q	PARTICIPANT	\N	PRESENT	0
21729	21612	14219Q	PARTICIPANT	\N	PRESENT	0
21730	21612	01061S	PARTICIPANT	\N	PRESENT	0
21731	21612	07034Q	PARTICIPANT	\N	PRESENT	0
21732	21612	11103C	PARTICIPANT	\N	PRESENT	0
21733	21612	11107G	PARTICIPANT	\N	PRESENT	0
21734	21612	08042U	PARTICIPANT	\N	PRESENT	0
21735	21612	13002U	PARTICIPANT	\N	PRESENT	0
21727	21612	14179A	PARTICIPANT	\N	PRESENT	0
21728	21612	14263U	PARTICIPANT	\N	PRESENT	0
21736	21612	04054G	PARTICIPANT	\N	PRESENT	0
21737	21612	04041B	PARTICIPANT	\N	PRESENT	0
21738	21612	11029K	PARTICIPANT	\N	PRESENT	0
21739	21612	01044R	PARTICIPANT	\N	PRESENT	0
21740	21612	11027H	PARTICIPANT	\N	PRESENT	0
21741	21612	98035U	PARTICIPANT	\N	PRESENT	0
21742	21612	99004R	PARTICIPANT	\N	PRESENT	0
21743	21612	14051J	PARTICIPANT	\N	PRESENT	0
21744	21612	95049N	PARTICIPANT	\N	PRESENT	0
21745	21612	01022K	PARTICIPANT	\N	PRESENT	0
21750	21612	14217N	PARTICIPANT	\N	PRESENT	0
21747	21612	14191V	PARTICIPANT	\N	PRESENT	0
21748	21612	14087W	PARTICIPANT	\N	PRESENT	0
21749	21612	08055A	PARTICIPANT	\N	PRESENT	0
21751	21612	14061L	PARTICIPANT	\N	PRESENT	0
21753	21612	08047A	PARTICIPANT	\N	PRESENT	0
21754	21612	95031C	PARTICIPANT	\N	PRESENT	0
21755	21612	11066Q	PARTICIPANT	\N	PRESENT	0
21756	21612	07032N	PARTICIPANT	\N	PRESENT	0
21757	21612	07029T	PARTICIPANT	\N	PRESENT	0
21758	21612	92018S	PARTICIPANT	\N	PRESENT	0
21759	21612	04085P	PARTICIPANT	\N	PRESENT	0
21760	21612	04044E	PARTICIPANT	\N	PRESENT	0
21761	21612	08022Q	PARTICIPANT	\N	PRESENT	0
21762	21612	14031R	PARTICIPANT	\N	PRESENT	0
21763	21612	90003B	PARTICIPANT	\N	PRESENT	0
21764	21612	01015L	PARTICIPANT	\N	PRESENT	0
21765	21612	14055N	PARTICIPANT	\N	PRESENT	0
21766	21612	07026Q	PARTICIPANT	\N	PRESENT	0
21767	21612	14053L	PARTICIPANT	\N	PRESENT	0
21768	21612	77002U	PARTICIPANT	\N	PRESENT	0
21769	21612	14079W	PARTICIPANT	\N	PRESENT	0
21770	21612	98042T	PARTICIPANT	\N	PRESENT	0
21771	21612	11074Q	PARTICIPANT	\N	PRESENT	0
21772	21612	08049C	PARTICIPANT	\N	PRESENT	0
21773	21612	00003C	PARTICIPANT	\N	PRESENT	0
21774	21612	88008L	PARTICIPANT	\N	PRESENT	0
21775	21612	11101A	PARTICIPANT	\N	PRESENT	0
21776	21612	14211G	PARTICIPANT	\N	PRESENT	0
21777	21612	95015C	PARTICIPANT	\N	PRESENT	0
21778	21612	10015M	PARTICIPANT	\N	PRESENT	0
21779	21612	14133K	PARTICIPANT	\N	PRESENT	0
21780	21612	14038Y	PARTICIPANT	\N	PRESENT	0
21781	21612	08018U	PARTICIPANT	\N	PRESENT	0
21782	21612	92031P	PARTICIPANT	\N	PRESENT	0
21783	21612	08014Q	PARTICIPANT	\N	PRESENT	0
21784	21612	11093T	PARTICIPANT	\N	PRESENT	0
21785	21612	14231L	PARTICIPANT	\N	PRESENT	0
21786	21612	14073Q	PARTICIPANT	\N	PRESENT	0
21787	21612	11110B	PARTICIPANT	\N	PRESENT	0
21788	21612	11042G	PARTICIPANT	\N	PRESENT	0
21789	21612	08065C	PARTICIPANT	\N	PRESENT	0
21790	21612	04056J	PARTICIPANT	\N	PRESENT	0
21791	21612	14175V	PARTICIPANT	\N	PRESENT	0
21792	21612	95063L	PARTICIPANT	\N	PRESENT	0
21793	21612	87003B	PARTICIPANT	\N	PRESENT	0
21794	21612	08016S	PARTICIPANT	\N	PRESENT	0
21795	21612	14173T	PARTICIPANT	\N	PRESENT	0
21796	21612	01013J	PARTICIPANT	\N	PRESENT	0
21797	21612	04086Q	PARTICIPANT	\N	PRESENT	0
21798	21612	11040E	PARTICIPANT	\N	PRESENT	0
21799	21612	95067Q	PARTICIPANT	\N	PRESENT	0
21800	21612	11056N	PARTICIPANT	\N	PRESENT	0
21801	21612	98023Q	PARTICIPANT	\N	PRESENT	0
21802	21612	12041X	PARTICIPANT	\N	PRESENT	0
21803	21612	11098Y	PARTICIPANT	\N	PRESENT	0
21804	21612	14037X	PARTICIPANT	\N	PRESENT	0
21805	21612	14013P	PARTICIPANT	\N	PRESENT	0
21806	21612	11055M	PARTICIPANT	\N	PRESENT	0
21807	21612	11083R	PARTICIPANT	\N	PRESENT	0
21808	21612	11099A	PARTICIPANT	\N	PRESENT	0
21809	21612	09001P	PARTICIPANT	\N	PRESENT	0
21810	21612	05004A	PARTICIPANT	\N	PRESENT	0
21811	21612	98021N	PARTICIPANT	\N	PRESENT	0
21812	21612	14069U	PARTICIPANT	\N	PRESENT	0
21813	21612	14261S	PARTICIPANT	\N	PRESENT	0
21814	21612	14239U	PARTICIPANT	\N	PRESENT	0
21815	21612	11030C	PARTICIPANT	\N	PRESENT	0
21816	21612	08069G	PARTICIPANT	\N	PRESENT	0
21817	21612	04067M	PARTICIPANT	\N	PRESENT	0
21818	21612	14147R	PARTICIPANT	\N	PRESENT	0
21819	21612	01019Q	PARTICIPANT	\N	PRESENT	0
21820	21612	11012A	PARTICIPANT	\N	PRESENT	0
21821	21612	14169X	PARTICIPANT	\N	PRESENT	0
21822	21612	14018U	PARTICIPANT	\N	PRESENT	0
21823	21612	01003G	PARTICIPANT	\N	PRESENT	0
21824	21612	04048J	PARTICIPANT	\N	PRESENT	0
21825	21612	14201E	PARTICIPANT	\N	PRESENT	0
21826	21612	95030B	PARTICIPANT	\N	PRESENT	0
21827	21612	11069T	PARTICIPANT	\N	PRESENT	0
21828	21612	86044G	PARTICIPANT	\N	PRESENT	0
21829	21612	98050T	PARTICIPANT	\N	PRESENT	0
21830	21612	01031L	PARTICIPANT	\N	PRESENT	0
21831	21612	14237S	PARTICIPANT	\N	PRESENT	0
21832	21612	14197C	PARTICIPANT	\N	PRESENT	0
21833	21612	01060R	PARTICIPANT	\N	PRESENT	0
21834	21612	14028W	PARTICIPANT	\N	PRESENT	0
21835	21612	98018T	PARTICIPANT	\N	PRESENT	0
21836	21612	11089X	PARTICIPANT	\N	PRESENT	0
21837	21612	14227Q	PARTICIPANT	\N	PRESENT	0
21838	21612	04092N	PARTICIPANT	\N	PRESENT	0
21839	21612	11026G	PARTICIPANT	\N	PRESENT	0
21840	21612	14223L	PARTICIPANT	\N	PRESENT	0
21841	21612	11059R	PARTICIPANT	\N	PRESENT	0
21842	21612	11084S	PARTICIPANT	\N	PRESENT	0
21843	21612	14193X	PARTICIPANT	\N	PRESENT	0
21844	21612	14135M	PARTICIPANT	\N	PRESENT	0
21845	21612	95041E	PARTICIPANT	\N	PRESENT	0
21846	21612	92020L	PARTICIPANT	\N	PRESENT	0
21847	21612	80013X	PARTICIPANT	\N	PRESENT	0
21849	21612	98029W	PARTICIPANT	\N	PRESENT	0
21850	21612	11036J	PARTICIPANT	\N	PRESENT	0
21852	21612	14001X	PARTICIPANT	\N	PRESENT	0
21855	21612	14225N	PARTICIPANT	\N	PRESENT	0
21856	21612	14207L	PARTICIPANT	\N	PRESENT	0
23738	23737	14263U	PARTICIPANT	\N	PRESENT	0
23739	23737	14133K	PARTICIPANT	\N	PRESENT	0
23740	23737	11109J	PARTICIPANT	\N	PRESENT	0
23741	23737	04059M	PARTICIPANT	\N	PRESENT	0
24341	23795	04044E	PARTICIPANT	\N	EXCUSE	0
23743	23737	01044R	PARTICIPANT	\N	PRESENT	0
24342	23795	14231L	PARTICIPANT	\N	EXCUSE	0
24442	24441	14263U	PARTICIPANT	\N	PRESENT	0
23746	23737	14105F	PARTICIPANT	\N	PRESENT	0
23747	23737	11029K	PARTICIPANT	\N	PRESENT	0
24514	24441	01058X	PARTICIPANT	\N	PRESENT	0
24825	23802	80013X	PARTICIPANT	\N	PRESENT	0
23750	23737	08024S	PARTICIPANT	\N	PRESENT	0
24445	24441	04059M	PARTICIPANT	\N	PRESENT	0
24446	24441	11039M	PARTICIPANT	\N	PRESENT	0
23753	23737	14209N	PARTICIPANT	\N	PRESENT	0
24447	24441	01044R	PARTICIPANT	\N	EXCUSE	0
23755	23737	11091R	PARTICIPANT	\N	EXCUSE	0
24448	24441	08043V	PARTICIPANT	\N	PRESENT	0
23757	23737	98042T	PARTICIPANT	\N	PRESENT	0
24449	24441	14089Y	PARTICIPANT	\N	PRESENT	0
23759	23737	01041N	PARTICIPANT	\N	EXCUSE	0
24826	23802	14223L	PARTICIPANT	\N	PRESENT	0
24451	24441	11029K	PARTICIPANT	\N	PRESENT	0
24452	24441	95015C	PARTICIPANT	\N	PRESENT	0
24827	23802	14013P	PARTICIPANT	\N	PRESENT	0
23764	23737	11089X	PARTICIPANT	\N	PRESENT	0
23765	23737	07026Q	PARTICIPANT	\N	EXCUSE	0
23766	23737	14123H	PARTICIPANT	\N	PRESENT	0
24454	24441	08024S	PARTICIPANT	\N	PRESENT	0
24828	23802	14197C	PARTICIPANT	\N	PRESENT	0
24456	24441	14209N	PARTICIPANT	\N	PRESENT	0
23770	23737	14061L	PARTICIPANT	\N	PRESENT	0
23771	23737	14073Q	PARTICIPANT	\N	PRESENT	0
24829	23802	11081P	PARTICIPANT	\N	PRESENT	0
24458	24441	11091R	PARTICIPANT	\N	PRESENT	0
23774	23737	08039A	PARTICIPANT	\N	PRESENT	0
24830	23802	07034Q	PARTICIPANT	\N	PRESENT	0
23776	23737	14059S	PARTICIPANT	\N	PRESENT	0
24460	24441	98042T	PARTICIPANT	\N	PRESENT	0
24831	23802	08065C	PARTICIPANT	\N	PRESENT	0
23779	23737	11104D	PARTICIPANT	\N	PRESENT	0
24462	24441	01041N	PARTICIPANT	\N	PRESENT	0
24463	24441	01025N	PARTICIPANT	\N	PRESENT	0
23782	23737	11014C	PARTICIPANT	\N	PRESENT	0
24832	23802	14209N	PARTICIPANT	\N	PRESENT	0
23784	23737	04070G	PRESIDENT	0	PRESENT	0
24833	23802	01025N	PARTICIPANT	\N	PRESENT	0
24466	24441	08035V	PARTICIPANT	\N	PRESENT	0
24467	24441	11089X	PARTICIPANT	\N	PRESENT	0
24468	24441	07026Q	PARTICIPANT	\N	PRESENT	0
24469	24441	14123H	PARTICIPANT	\N	PRESENT	0
24470	24441	14179A	PARTICIPANT	\N	PRESENT	0
23791	23737	14229S	PARTICIPANT	\N	PRESENT	0
24834	23802	14237S	PARTICIPANT	\N	PRESENT	0
23793	23737	11071M	PARTICIPANT	\N	PRESENT	0
24472	24441	14241N	PARTICIPANT	\N	PRESENT	0
24835	23802	97011G	PARTICIPANT	\N	PRESENT	0
24474	24441	14073Q	PARTICIPANT	\N	PRESENT	0
24475	24441	08031R	PARTICIPANT	\N	PRESENT	0
24836	23802	14157T	PARTICIPANT	\N	PRESENT	0
24477	24441	08039A	PARTICIPANT	\N	PRESENT	0
24478	24441	08017T	PARTICIPANT	\N	PRESENT	0
24479	24441	14059S	PARTICIPANT	\N	PRESENT	0
24480	24441	08012N	PARTICIPANT	\N	PRESENT	0
24481	24441	14103D	PARTICIPANT	\N	PRESENT	0
24482	24441	11104D	PARTICIPANT	\N	PRESENT	0
24483	24441	14063N	PARTICIPANT	\N	PRESENT	0
24484	24441	04057K	PARTICIPANT	\N	PRESENT	0
24485	24441	11014C	PARTICIPANT	\N	PRESENT	0
24486	24441	14109K	PARTICIPANT	\N	PRESENT	0
24487	24441	04070G	PRESIDENT	0	PRESENT	0
24488	24441	92040Q	PARTICIPANT	\N	PRESENT	0
24837	23802	05012A	PARTICIPANT	\N	PRESENT	0
24838	23802	14187A	PARTICIPANT	\N	PRESENT	0
24491	24441	14235Q	PARTICIPANT	\N	EXCUSE	0
24492	24441	14055N	PARTICIPANT	\N	PRESENT	0
24493	24441	04033B	PARTICIPANT	\N	PRESENT	0
24494	24441	14229S	PARTICIPANT	\N	PRESENT	0
24495	24441	11043H	PARTICIPANT	\N	PRESENT	0
24839	23802	11089X	PARTICIPANT	\N	PRESENT	0
24840	23802	11100Y	PARTICIPANT	\N	PRESENT	0
24841	23802	11091R	PARTICIPANT	\N	PRESENT	0
24842	23802	95030B	PARTICIPANT	\N	PRESENT	0
24843	23802	11090Q	PARTICIPANT	\N	PRESENT	0
24844	23802	14034U	PARTICIPANT	\N	PRESENT	0
24845	23802	14191V	PARTICIPANT	\N	PRESENT	0
24846	23802	14069U	PARTICIPANT	\N	PRESENT	0
24847	23802	11035H	PARTICIPANT	\N	PRESENT	0
24848	23802	08019V	PARTICIPANT	\N	PRESENT	0
24849	23802	14121F	PARTICIPANT	\N	PRESENT	0
24850	23802	14201E	PARTICIPANT	\N	PRESENT	0
24851	23802	11099A	PARTICIPANT	\N	PRESENT	0
24852	23802	14199E	PARTICIPANT	\N	PRESENT	0
24853	23802	14073Q	PARTICIPANT	\N	PRESENT	0
24854	23802	14277B	PARTICIPANT	\N	PRESENT	0
24855	23802	13002U	PARTICIPANT	\N	PRESENT	0
24856	23802	14221J	PARTICIPANT	\N	PRESENT	0
24857	23802	04080J	PARTICIPANT	\N	PRESENT	0
24858	23802	11059R	PARTICIPANT	\N	PRESENT	0
24859	23802	14173T	PARTICIPANT	\N	PRESENT	0
24860	23802	86044G	PARTICIPANT	\N	PRESENT	0
24861	23802	08022Q	PARTICIPANT	\N	PRESENT	0
24862	23802	04081K	PARTICIPANT	\N	PRESENT	0
24863	23802	04086Q	PARTICIPANT	\N	PRESENT	0
24864	23802	98023Q	PARTICIPANT	\N	PRESENT	0
24865	23802	87003B	PARTICIPANT	\N	PRESENT	0
24866	23802	99004R	PARTICIPANT	\N	PRESENT	0
24868	23802	04074L	PARTICIPANT	\N	PRESENT	0
24869	23802	14175V	PARTICIPANT	\N	PRESENT	0
24870	23802	11088W	PARTICIPANT	\N	PRESENT	0
24871	23802	14211G	PARTICIPANT	\N	PRESENT	0
24872	23802	04097T	PARTICIPANT	\N	PRESENT	0
24873	23802	14037X	PARTICIPANT	\N	PRESENT	0
24874	23802	11101A	PARTICIPANT	\N	PRESENT	0
24875	23802	14329V	PARTICIPANT	\N	PRESENT	0
24876	23802	04071H	PARTICIPANT	\N	PRESENT	0
24877	23802	01013J	PARTICIPANT	\N	PRESENT	0
24878	23802	11040E	PARTICIPANT	\N	PRESENT	0
24879	23802	11039M	PARTICIPANT	\N	PRESENT	0
24880	23802	04056J	PARTICIPANT	\N	PRESENT	0
24881	23802	01059Y	PARTICIPANT	\N	PRESENT	0
24882	23802	01016M	PARTICIPANT	\N	PRESENT	0
24883	23802	07029T	PARTICIPANT	\N	PRESENT	0
24884	23802	01048V	PARTICIPANT	\N	PRESENT	0
24885	23802	98021N	PARTICIPANT	\N	PRESENT	0
24886	23802	14038Y	PARTICIPANT	\N	PRESENT	0
24887	23802	02002K	PARTICIPANT	\N	PRESENT	0
24888	23802	96004D	PARTICIPANT	\N	PRESENT	0
24889	23802	14051J	PARTICIPANT	\N	PRESENT	0
24890	23802	08011M	PARTICIPANT	\N	PRESENT	0
24891	23802	92031P	PARTICIPANT	\N	PRESENT	0
24892	23802	08010L	PARTICIPANT	\N	PRESENT	0
24893	23802	95063L	PARTICIPANT	\N	PRESENT	0
24894	23802	01019Q	PARTICIPANT	\N	PRESENT	0
24895	23802	01058X	PARTICIPANT	\N	PRESENT	0
24896	23802	11080N	PARTICIPANT	\N	PRESENT	0
24897	23802	77002U	PARTICIPANT	\N	PRESENT	0
24898	23802	04059M	PARTICIPANT	\N	PRESENT	0
24899	23802	14063N	PARTICIPANT	\N	PRESENT	0
24900	23802	08052W	PARTICIPANT	\N	PRESENT	0
24901	23802	10006L	PARTICIPANT	\N	PRESENT	0
24902	23802	10015M	PARTICIPANT	\N	PRESENT	0
24903	23802	08055A	PARTICIPANT	\N	PRESENT	0
24904	23802	14107H	PARTICIPANT	\N	PRESENT	0
24905	23802	14119M	PARTICIPANT	\N	PRESENT	0
24906	23802	04066L	PARTICIPANT	\N	PRESENT	0
24907	23802	07024N	PARTICIPANT	\N	PRESENT	0
24908	23802	11027H	PARTICIPANT	\N	PRESENT	0
24909	23802	08034U	PARTICIPANT	\N	PRESENT	0
24910	23802	01011G	PARTICIPANT	\N	PRESENT	0
24911	23802	11030C	PARTICIPANT	\N	PRESENT	0
24912	23802	01008M	PARTICIPANT	\N	PRESENT	0
24913	23802	08060W	PARTICIPANT	\N	PRESENT	0
24914	23802	11060J	PARTICIPANT	\N	PRESENT	0
24915	23802	11056N	PARTICIPANT	\N	PRESENT	0
24916	23802	11098Y	PARTICIPANT	\N	PRESENT	0
24917	23802	11031D	PARTICIPANT	\N	PRESENT	0
24918	23802	11036J	PARTICIPANT	\N	PRESENT	0
24919	23802	14259Y	PARTICIPANT	\N	PRESENT	0
24920	23802	01015L	PARTICIPANT	\N	PRESENT	0
24921	23802	14079W	PARTICIPANT	\N	PRESENT	0
24922	23802	04033B	PARTICIPANT	\N	PRESENT	0
24923	23802	95041E	PARTICIPANT	\N	PRESENT	0
24924	23802	08016S	PARTICIPANT	\N	PRESENT	0
24925	23802	14135M	PARTICIPANT	\N	PRESENT	0
24926	23802	14151M	PARTICIPANT	\N	PRESENT	0
24927	23802	14071N	PARTICIPANT	\N	PRESENT	0
23291	22564	01019Q	PARTICIPANT	\N	PRESENT	0
23292	22564	09001P	PARTICIPANT	\N	PRESENT	0
23293	22564	14215L	PARTICIPANT	\N	PRESENT	0
23294	22564	11095V	PARTICIPANT	\N	PRESENT	0
23295	22564	11064N	PARTICIPANT	\N	PRESENT	0
23296	22564	88008L	PARTICIPANT	\N	PRESENT	0
23297	22564	08034U	PARTICIPANT	\N	PRESENT	0
23298	22564	11100Y	PARTICIPANT	\N	PRESENT	0
23300	23299	08025T	PARTICIPANT	\N	PRESENT	0
23301	23299	05008E	PRESIDENT	0	PRESENT	0
23302	23299	04085P	PARTICIPANT	\N	PRESENT	0
23303	23299	11030C	PARTICIPANT	\N	PRESENT	0
23304	23299	11033F	PARTICIPANT	\N	PRESENT	0
23305	23299	14065Q	PARTICIPANT	\N	PRESENT	0
23306	23299	14069U	PARTICIPANT	\N	PRESENT	0
23307	23299	04047H	PARTICIPANT	\N	PRESENT	0
23308	23299	11032E	PARTICIPANT	\N	PRESENT	0
23470	22565	08019V	PARTICIPANT	\N	PRESENT	0
23310	23299	99002P	PARTICIPANT	\N	PRESENT	0
23311	23299	11056N	PARTICIPANT	\N	PRESENT	0
23312	23299	14259Y	PARTICIPANT	\N	PRESENT	0
23471	22565	14191V	PARTICIPANT	\N	PRESENT	0
23314	23299	14041T	PARTICIPANT	\N	PRESENT	0
23315	23299	11113E	PARTICIPANT	\N	PRESENT	0
23316	23299	01024M	PARTICIPANT	\N	PRESENT	0
23317	23299	14215L	PARTICIPANT	\N	PRESENT	0
23318	23299	11034G	PARTICIPANT	\N	PRESENT	0
23319	23299	08018U	PARTICIPANT	\N	PRESENT	0
23472	22565	08062Y	PARTICIPANT	\N	PRESENT	0
23321	23299	01007L	PARTICIPANT	\N	PRESENT	0
23322	23299	11049P	PARTICIPANT	\N	PRESENT	0
23323	23299	08044W	PARTICIPANT	\N	PRESENT	0
23324	23299	11084S	PARTICIPANT	\N	PRESENT	0
23325	23299	11026G	PARTICIPANT	\N	PRESENT	0
23326	23299	04079R	PARTICIPANT	\N	PRESENT	0
23327	23299	14111D	PARTICIPANT	\N	PRESENT	0
23328	23299	14001X	PARTICIPANT	\N	PRESENT	0
23473	22565	08034U	PARTICIPANT	\N	PRESENT	0
23330	23299	01060R	PARTICIPANT	\N	PRESENT	0
23331	23299	14147R	PARTICIPANT	\N	PRESENT	0
23474	22565	05012A	PARTICIPANT	\N	PRESENT	0
23333	23299	08051V	PARTICIPANT	\N	PRESENT	0
23334	23299	11072N	PARTICIPANT	\N	PRESENT	0
23335	23299	07034Q	PARTICIPANT	\N	PRESENT	0
23336	23299	04074L	PARTICIPANT	\N	PRESENT	0
23337	23299	10015M	PARTICIPANT	\N	PRESENT	0
23338	23299	95063L	PARTICIPANT	\N	PRESENT	0
23339	23299	01019Q	PARTICIPANT	\N	PRESENT	0
23340	23299	01028R	PARTICIPANT	\N	PRESENT	0
23341	23299	98035U	PARTICIPANT	\N	PRESENT	0
23342	23299	04056J	PARTICIPANT	\N	PRESENT	0
23475	22565	11100Y	PARTICIPANT	\N	PRESENT	0
23344	23299	04044E	PRESIDENT	1	PRESENT	0
23345	23299	11037K	PARTICIPANT	\N	PRESENT	0
23346	23299	92045V	PARTICIPANT	\N	EXCUSE	0
23347	23299	95067Q	PARTICIPANT	\N	PRESENT	0
23348	23299	01047U	PARTICIPANT	\N	PRESENT	0
23476	22565	11043H	PARTICIPANT	\N	PRESENT	0
23477	22565	09001P	PARTICIPANT	\N	PRESENT	0
23478	22565	14215L	PARTICIPANT	\N	PRESENT	0
23479	22565	14237S	PARTICIPANT	\N	PRESENT	0
23480	22565	14083S	PARTICIPANT	\N	PRESENT	0
23481	22565	02002K	PARTICIPANT	\N	PRESENT	0
23482	22565	14079W	PARTICIPANT	\N	PRESENT	0
23483	22565	14241N	PARTICIPANT	\N	PRESENT	0
23484	22565	98022P	PARTICIPANT	\N	PRESENT	0
23485	22565	11033F	PARTICIPANT	\N	PRESENT	0
23486	22565	11065P	PARTICIPANT	\N	PRESENT	0
23487	22565	14159V	PARTICIPANT	\N	PRESENT	0
23488	22565	14197C	PARTICIPANT	\N	PRESENT	0
23489	22565	14269B	PARTICIPANT	\N	PRESENT	0
23490	22565	14109K	PARTICIPANT	\N	PRESENT	0
23491	22565	11036J	PARTICIPANT	\N	PRESENT	0
23492	22565	08014Q	PARTICIPANT	\N	PRESENT	0
23493	22565	14167V	PARTICIPANT	\N	PRESENT	0
23494	22565	14063N	PARTICIPANT	\N	PRESENT	0
23495	22565	08043V	PARTICIPANT	\N	PRESENT	0
23496	22565	08017T	PARTICIPANT	\N	PRESENT	0
23497	22565	11066Q	PARTICIPANT	\N	PRESENT	0
23498	22565	11032E	PARTICIPANT	\N	PRESENT	0
23499	22565	11031D	PARTICIPANT	\N	PRESENT	0
23500	22565	07026Q	PARTICIPANT	\N	PRESENT	0
23501	22565	80013X	PARTICIPANT	\N	PRESENT	0
23502	23349	08019V	PARTICIPANT	\N	PRESENT	0
23503	22565	14261S	PARTICIPANT	\N	PRESENT	0
23504	22565	04044E	PARTICIPANT	\N	PRESENT	0
23505	22565	11012A	PARTICIPANT	\N	PRESENT	0
23506	22565	95067Q	PARTICIPANT	\N	PRESENT	0
23507	22565	11067R	PARTICIPANT	\N	PRESENT	0
23508	22565	04057K	PARTICIPANT	\N	PRESENT	0
23509	22565	01031L	PARTICIPANT	\N	PRESENT	0
23510	22565	00003C	PARTICIPANT	\N	PRESENT	0
23513	22565	11014C	PARTICIPANT	\N	PRESENT	0
23514	22565	14265W	PARTICIPANT	\N	PRESENT	0
23515	22565	14187A	PARTICIPANT	\N	PRESENT	0
23516	22565	14201E	PARTICIPANT	\N	PRESENT	0
23517	22565	11025F	PARTICIPANT	\N	PRESENT	0
23567	22565	14051J	PARTICIPANT	\N	PRESENT	0
23569	22565	01003G	PARTICIPANT	\N	PRESENT	0
23570	22565	04088S	PARTICIPANT	\N	PRESENT	0
23571	22565	14014Q	PARTICIPANT	\N	PRESENT	0
23590	22565	11107G	PARTICIPANT	\N	PRESENT	0
23598	22565	01022K	PARTICIPANT	\N	PRESENT	0
23601	22565	08016S	PARTICIPANT	\N	PRESENT	0
23603	22565	14235Q	PARTICIPANT	\N	PRESENT	0
23604	22565	14018U	PARTICIPANT	\N	PRESENT	0
23605	22565	14073Q	PARTICIPANT	\N	PRESENT	0
23606	22565	14059S	PARTICIPANT	\N	PRESENT	0
23607	22565	11071M	PARTICIPANT	\N	PRESENT	0
23608	22565	07029T	PARTICIPANT	\N	PRESENT	0
23609	22565	14251Q	PARTICIPANT	\N	PRESENT	0
23610	22565	14097Y	PARTICIPANT	\N	PRESENT	0
23611	22565	14223L	PARTICIPANT	\N	PRESENT	0
23612	22565	14030Q	PARTICIPANT	\N	PRESENT	0
23613	22565	14271U	PARTICIPANT	\N	PRESENT	0
23614	22565	12042Y	PARTICIPANT	\N	PRESENT	0
23615	22565	14229S	PARTICIPANT	\N	PRESENT	0
23616	23511	14273W	PARTICIPANT	\N	EXCUSE	0
23617	22565	14038Y	PARTICIPANT	\N	PRESENT	0
23618	23299	14273W	PARTICIPANT	\N	EXCUSE	0
23619	23349	14273W	PARTICIPANT	\N	EXCUSE	0
23420	23349	08025T	PARTICIPANT	\N	PRESENT	0
23421	23349	04085P	PARTICIPANT	\N	PRESENT	0
23422	23349	05008E	PRESIDENT	0	PRESENT	0
23423	23349	11030C	PARTICIPANT	\N	PRESENT	0
23424	23349	11033F	PARTICIPANT	\N	PRESENT	0
23425	23349	14065Q	PARTICIPANT	\N	PRESENT	0
23620	22565	01046T	PARTICIPANT	\N	PRESENT	0
23427	23349	04047H	PARTICIPANT	\N	PRESENT	0
23621	22565	11112D	PARTICIPANT	\N	PRESENT	0
23622	22565	08052W	PARTICIPANT	\N	PRESENT	0
23430	23349	99002P	PARTICIPANT	\N	PRESENT	0
23431	23349	11056N	PARTICIPANT	\N	PRESENT	0
23432	23349	14259Y	PARTICIPANT	\N	PRESENT	0
23623	22565	14031R	PARTICIPANT	\N	PRESENT	0
23434	23349	14041T	PARTICIPANT	\N	PRESENT	0
23435	23349	11113E	PARTICIPANT	\N	PRESENT	0
23436	23349	01024M	PARTICIPANT	\N	PRESENT	0
23437	23349	14215L	PARTICIPANT	\N	PRESENT	0
23624	22565	14209N	PARTICIPANT	\N	PRESENT	0
23439	23349	08018U	PARTICIPANT	\N	PRESENT	0
23626	22565	01025N	PARTICIPANT	\N	PRESENT	0
23627	22565	11098Y	PARTICIPANT	\N	PRESENT	0
23442	23349	11049P	PARTICIPANT	\N	PRESENT	0
23443	23349	08044W	PARTICIPANT	\N	PRESENT	0
23444	23349	11084S	PARTICIPANT	\N	PRESENT	0
23445	23349	11026G	PARTICIPANT	\N	PRESENT	0
23446	23349	04079R	PARTICIPANT	\N	PRESENT	0
23628	22565	14087W	PARTICIPANT	\N	PRESENT	0
23448	23349	14001X	PARTICIPANT	\N	PRESENT	0
23639	22565	04066L	PARTICIPANT	\N	PRESENT	0
23662	22565	08010L	PARTICIPANT	\N	PRESENT	0
23451	23349	14147R	PARTICIPANT	\N	PRESENT	0
23673	22565	04067M	PARTICIPANT	\N	PRESENT	0
23674	22565	14026U	PARTICIPANT	\N	PRESENT	0
23675	22565	97011G	PARTICIPANT	\N	PRESENT	0
23455	23349	07034Q	PARTICIPANT	\N	PRESENT	0
23456	23349	04074L	PARTICIPANT	\N	PRESENT	0
23457	23349	10015M	PARTICIPANT	\N	PRESENT	0
23676	22565	10015M	PARTICIPANT	\N	PRESENT	0
23677	22565	01019Q	PARTICIPANT	\N	PRESENT	0
23460	23349	01028R	PARTICIPANT	\N	PRESENT	0
23461	23349	98035U	PARTICIPANT	\N	PRESENT	0
23678	22565	14065Q	PARTICIPANT	\N	PRESENT	0
23679	22565	14217N	PARTICIPANT	\N	PRESENT	0
23464	23349	04044E	PARTICIPANT	\N	PRESENT	0
23465	23349	11037K	PARTICIPANT	\N	PRESENT	0
23466	23349	92045V	PARTICIPANT	\N	EXCUSE	0
23467	23349	95067Q	PARTICIPANT	\N	PRESENT	0
23682	22565	92018S	PARTICIPANT	\N	PRESENT	0
23680	22565	01057W	PARTICIPANT	\N	PRESENT	0
23681	22565	04045F	PARTICIPANT	\N	PRESENT	0
23683	22565	08015R	PARTICIPANT	\N	PRESENT	0
23684	22565	14135M	PARTICIPANT	\N	PRESENT	0
23685	22565	01056V	PARTICIPANT	\N	PRESENT	0
23686	22565	14151M	PARTICIPANT	\N	PRESENT	0
23687	22565	11061K	PARTICIPANT	\N	PRESENT	0
23688	22565	14259Y	PARTICIPANT	\N	PRESENT	0
23689	22565	08069G	PARTICIPANT	\N	PRESENT	0
23690	22565	01024M	PARTICIPANT	\N	PRESENT	0
23803	22568	08021P	PARTICIPANT	\N	PRESENT	0
23804	22568	14063N	PARTICIPANT	\N	PRESENT	0
23805	22568	14081Q	PARTICIPANT	\N	PRESENT	0
23806	22568	14267Y	PARTICIPANT	\N	PRESENT	0
23811	22568	14079W	PARTICIPANT	\N	PRESENT	0
23812	22568	11080N	PARTICIPANT	\N	PRESENT	0
23818	22568	14219Q	PARTICIPANT	\N	PRESENT	0
23813	22568	04044E	PARTICIPANT	\N	PRESENT	0
23817	22568	86034E	PARTICIPANT	\N	PRESENT	0
23815	22568	07004J	PARTICIPANT	\N	PRESENT	0
23816	22568	14061L	PARTICIPANT	\N	PRESENT	0
23819	22568	08052W	PARTICIPANT	\N	PRESENT	0
23820	22568	11110B	PARTICIPANT	\N	PRESENT	0
23821	22568	04059M	PARTICIPANT	\N	PRESENT	0
23822	22568	08043V	PARTICIPANT	\N	PRESENT	0
23823	22568	11101A	PARTICIPANT	\N	PRESENT	0
23824	22568	11106F	PARTICIPANT	\N	PRESENT	0
23825	22568	04074L	PARTICIPANT	\N	PRESENT	0
23826	22568	14026U	PARTICIPANT	\N	PRESENT	0
23858	22568	14187A	PARTICIPANT	\N	PRESENT	0
23828	22568	14030Q	PARTICIPANT	\N	PRESENT	0
23829	22568	11088W	PARTICIPANT	\N	PRESENT	0
23830	22568	08016S	PARTICIPANT	\N	PRESENT	0
23831	22568	80013X	PARTICIPANT	\N	PRESENT	0
23891	22568	14109K	PARTICIPANT	\N	PRESENT	0
23833	22568	10006L	PARTICIPANT	\N	PRESENT	0
23834	22568	77002U	PARTICIPANT	\N	PRESENT	0
23835	22568	14051J	PARTICIPANT	\N	PRESENT	0
23836	22568	07034Q	PARTICIPANT	\N	PRESENT	0
23837	22568	88008L	PARTICIPANT	\N	PRESENT	0
23838	22568	08058D	PARTICIPANT	\N	PRESENT	0
23839	22568	08012N	PARTICIPANT	\N	PRESENT	0
23840	22568	14001X	PARTICIPANT	\N	PRESENT	0
23841	22568	08056B	PARTICIPANT	\N	PRESENT	0
23842	22568	11049P	PARTICIPANT	\N	PRESENT	0
23843	22568	14195A	PARTICIPANT	\N	PRESENT	0
23844	22568	14221J	PARTICIPANT	\N	PRESENT	0
23845	22568	14013P	PARTICIPANT	\N	PRESENT	0
23846	22568	08062Y	PARTICIPANT	\N	PRESENT	0
23860	22568	08022Q	PARTICIPANT	\N	PRESENT	0
23848	22568	14241N	PARTICIPANT	\N	PRESENT	0
23850	22568	11029K	PARTICIPANT	\N	PRESENT	0
23851	22568	14179A	PARTICIPANT	\N	PRESENT	0
23852	22568	01016M	PARTICIPANT	\N	PRESENT	0
23853	22568	11066Q	PARTICIPANT	\N	PRESENT	0
23854	22568	12042Y	PARTICIPANT	\N	PRESENT	0
23855	22568	04086Q	PARTICIPANT	\N	PRESENT	0
23856	22568	14193X	PARTICIPANT	\N	PRESENT	0
23859	22568	11044J	PARTICIPANT	\N	PRESENT	0
23861	22568	12041X	PARTICIPANT	\N	PRESENT	0
23862	22568	11103C	PARTICIPANT	\N	PRESENT	0
23863	22568	08015R	PARTICIPANT	\N	PRESENT	0
23864	22568	01027Q	PARTICIPANT	\N	PRESENT	0
23865	22568	08017T	PARTICIPANT	\N	PRESENT	0
23866	22568	99004R	PARTICIPANT	\N	PRESENT	0
23867	22568	95041E	PARTICIPANT	\N	PRESENT	0
23868	22568	14159V	PARTICIPANT	\N	PRESENT	0
23869	22568	14265W	PARTICIPANT	\N	PRESENT	0
23870	22568	14121F	PARTICIPANT	\N	PRESENT	0
23871	22568	14028W	PARTICIPANT	\N	PRESENT	0
23872	22568	04042C	PARTICIPANT	\N	PRESENT	0
23873	22568	08055A	PARTICIPANT	\N	PRESENT	0
23874	22568	11067R	PARTICIPANT	\N	PRESENT	0
23875	22568	04045F	PARTICIPANT	\N	PRESENT	0
23876	22568	14169X	PARTICIPANT	\N	PRESENT	0
23877	22568	02002K	PARTICIPANT	\N	PRESENT	0
23878	22568	14257W	PARTICIPANT	\N	PRESENT	0
23879	22568	08047A	PARTICIPANT	\N	PRESENT	0
23880	22568	11098Y	PARTICIPANT	\N	PRESENT	0
23881	22568	05012A	PARTICIPANT	\N	PRESENT	0
23882	22568	11107G	PARTICIPANT	\N	PRESENT	0
23883	22568	92040Q	PARTICIPANT	\N	PRESENT	0
23884	22568	11059R	PARTICIPANT	\N	PRESENT	0
23885	22568	11036J	PARTICIPANT	\N	PRESENT	0
23886	22568	14273W	PARTICIPANT	\N	PRESENT	0
23887	22568	11077T	PARTICIPANT	\N	PRESENT	0
23888	22568	92044U	PARTICIPANT	\N	PRESENT	0
23889	22568	04066L	PARTICIPANT	\N	PRESENT	0
23890	22568	00003C	PARTICIPANT	\N	PRESENT	0
23892	22568	08019V	PARTICIPANT	\N	PRESENT	0
23893	22568	11031D	PARTICIPANT	\N	PRESENT	0
23894	22568	14235Q	PARTICIPANT	\N	PRESENT	0
23895	22568	98042T	PARTICIPANT	\N	PRESENT	0
23896	22568	04081K	PARTICIPANT	\N	PRESENT	0
23897	22568	14225N	PARTICIPANT	\N	PRESENT	0
23898	22568	11046L	PARTICIPANT	\N	PRESENT	0
23899	22568	92018S	PARTICIPANT	\N	PRESENT	0
23900	22568	11056N	PARTICIPANT	\N	PRESENT	0
23901	22568	01015L	PARTICIPANT	\N	PRESENT	0
23902	22568	14031R	PARTICIPANT	\N	PRESENT	0
23903	22568	11043H	PARTICIPANT	\N	PRESENT	0
23904	22568	04085P	PARTICIPANT	\N	PRESENT	0
23905	22568	04054G	PARTICIPANT	\N	PRESENT	0
23906	22568	11040E	PARTICIPANT	\N	PRESENT	0
23907	22568	14038Y	PARTICIPANT	\N	PRESENT	0
23908	22568	98018T	PARTICIPANT	\N	PRESENT	0
23909	22568	11026G	PARTICIPANT	\N	PRESENT	0
23910	22568	01022K	PARTICIPANT	\N	PRESENT	0
23911	22568	09001P	PARTICIPANT	\N	PRESENT	0
23912	22568	11025F	PARTICIPANT	\N	PRESENT	0
23913	22568	92020L	PARTICIPANT	\N	PRESENT	0
23914	22568	14014Q	PARTICIPANT	\N	PRESENT	0
23915	22568	11076S	PARTICIPANT	\N	PRESENT	0
23916	22568	11069T	PARTICIPANT	\N	PRESENT	0
23917	22568	14042U	PARTICIPANT	\N	PRESENT	0
23918	22568	14071N	PARTICIPANT	\N	PRESENT	0
23919	22568	04048J	PARTICIPANT	\N	PRESENT	0
23920	22568	04035D	PARTICIPANT	\N	PRESENT	0
23921	22568	95059Q	PARTICIPANT	\N	PRESENT	0
23922	22568	97011G	PARTICIPANT	\N	PRESENT	0
23923	22568	11063M	PARTICIPANT	\N	PRESENT	0
23924	22568	04049K	PARTICIPANT	\N	PRESENT	0
23925	22568	98053W	PARTICIPANT	\N	PRESENT	0
23926	22568	92031P	PARTICIPANT	\N	PRESENT	0
23927	22568	98035U	PARTICIPANT	\N	PRESENT	0
23928	22568	01007L	PARTICIPANT	\N	PRESENT	0
23929	22568	98046X	PARTICIPANT	\N	PRESENT	0
23930	22568	14073Q	PARTICIPANT	\N	PRESENT	0
23931	22568	11100Y	PARTICIPANT	\N	PRESENT	0
23932	22568	11027H	PARTICIPANT	\N	PRESENT	0
23933	22568	96004D	PARTICIPANT	\N	PRESENT	0
23934	22568	11060J	PARTICIPANT	\N	PRESENT	0
23935	22568	04036E	PARTICIPANT	\N	PRESENT	0
23936	22568	04079R	PARTICIPANT	\N	PRESENT	0
23937	22568	95063L	PARTICIPANT	\N	PRESENT	0
23938	22568	95030B	PARTICIPANT	\N	PRESENT	0
23939	22568	04056J	PARTICIPANT	\N	PRESENT	0
23940	22568	11039M	PARTICIPANT	\N	PRESENT	0
23941	22568	14059S	PARTICIPANT	\N	PRESENT	0
23942	22568	14123H	PARTICIPANT	\N	PRESENT	0
23943	22568	11083R	PARTICIPANT	\N	PRESENT	0
23944	22568	11064N	PARTICIPANT	\N	PRESENT	0
23945	22568	13002U	PARTICIPANT	\N	PRESENT	0
23946	22568	14093U	PARTICIPANT	\N	PRESENT	0
23947	22568	11014C	PARTICIPANT	\N	PRESENT	0
23948	22568	08069G	PARTICIPANT	\N	PRESENT	0
23949	22568	98029W	PARTICIPANT	\N	PRESENT	0
23950	22568	14037X	PARTICIPANT	\N	PRESENT	0
23951	22568	95035G	PARTICIPANT	\N	PRESENT	0
23952	22568	11113E	PARTICIPANT	\N	PRESENT	0
23953	22568	11089X	PARTICIPANT	\N	PRESENT	0
23954	22568	14111D	PARTICIPANT	\N	PRESENT	0
23955	22568	14229S	PARTICIPANT	\N	PRESENT	0
23956	22568	08038Y	PARTICIPANT	\N	PRESENT	0
23957	22568	98023Q	PARTICIPANT	\N	PRESENT	0
23958	22568	01060R	PARTICIPANT	\N	PRESENT	0
23959	22568	04053F	PARTICIPANT	\N	PRESENT	0
23960	22568	04077P	PARTICIPANT	\N	PRESENT	0
23961	22568	08061X	PARTICIPANT	\N	PRESENT	0
23962	22568	14255U	PARTICIPANT	\N	PRESENT	0
23963	22568	14151M	PARTICIPANT	\N	PRESENT	0
23964	22568	11053K	PARTICIPANT	\N	PRESENT	0
23965	22568	14083S	PARTICIPANT	\N	PRESENT	0
23966	22568	14227Q	PARTICIPANT	\N	PRESENT	0
23967	22568	01024M	PARTICIPANT	\N	PRESENT	0
23968	22568	14205J	PARTICIPANT	\N	PRESENT	0
23969	22568	11112D	PARTICIPANT	\N	PRESENT	0
23970	22568	14039A	PARTICIPANT	\N	PRESENT	0
23971	22568	11032E	PARTICIPANT	\N	PRESENT	0
23972	22568	01057W	PARTICIPANT	\N	PRESENT	0
23973	22568	08018U	PARTICIPANT	\N	PRESENT	0
24016	22568	01025N	PARTICIPANT	\N	PRESENT	0
24033	22568	04067M	PARTICIPANT	\N	PRESENT	0
24034	22568	04080J	PARTICIPANT	\N	PRESENT	0
23977	22568	11033F	PARTICIPANT	\N	PRESENT	0
23978	22568	14135M	PARTICIPANT	\N	PRESENT	0
23979	22568	14213J	PARTICIPANT	\N	PRESENT	0
23980	22568	01014K	PARTICIPANT	\N	PRESENT	0
23981	22568	11071M	PARTICIPANT	\N	PRESENT	0
23982	22568	11054L	PARTICIPANT	\N	PRESENT	0
23983	22568	14269B	PARTICIPANT	\N	PRESENT	0
23984	22568	04057K	PARTICIPANT	\N	PRESENT	0
24032	22568	01044R	PARTICIPANT	\N	PRESENT	0
24030	22568	01003G	PARTICIPANT	\N	PRESENT	0
24023	22568	08051V	PARTICIPANT	\N	PRESENT	0
24031	22568	04078Q	PARTICIPANT	\N	PRESENT	0
23989	22568	08031R	PARTICIPANT	\N	PRESENT	0
23990	22568	14237S	PARTICIPANT	\N	PRESENT	0
24025	22568	05004A	PARTICIPANT	\N	PRESENT	0
23992	22568	98005N	PARTICIPANT	\N	PRESENT	0
24035	22568	11093T	PARTICIPANT	\N	PRESENT	0
24036	22568	04071H	PARTICIPANT	\N	PRESENT	0
23995	22568	11068S	PARTICIPANT	\N	PRESENT	0
23996	22568	07029T	PARTICIPANT	\N	PRESENT	0
23997	22568	04088S	PARTICIPANT	\N	PRESENT	0
23998	22568	11074Q	PARTICIPANT	\N	PRESENT	0
23999	22568	08068F	PARTICIPANT	\N	PRESENT	0
24000	22568	04043D	PARTICIPANT	\N	PRESENT	0
24001	22568	14069U	PARTICIPANT	\N	PRESENT	0
24038	22568	14251Q	PARTICIPANT	\N	PRESENT	0
24003	22568	14223L	PARTICIPANT	\N	PRESENT	0
24004	22568	14119M	PARTICIPANT	\N	PRESENT	0
24041	22568	11030C	PARTICIPANT	\N	PRESENT	0
24006	22568	14157T	PARTICIPANT	\N	PRESENT	0
24042	22568	10015M	PARTICIPANT	\N	PRESENT	0
24008	22568	14217N	PARTICIPANT	\N	PRESENT	0
24015	22568	11055M	PARTICIPANT	\N	PRESENT	0
24039	22568	14253S	PARTICIPANT	\N	PRESENT	0
24043	22568	01034P	PARTICIPANT	\N	PRESENT	0
24012	22568	07024N	PARTICIPANT	\N	PRESENT	0
24037	22568	01048V	PARTICIPANT	\N	PRESENT	0
24014	22568	11015D	PARTICIPANT	\N	PRESENT	0
24028	22568	11114F	PARTICIPANT	\N	PRESENT	0
24019	22568	04070G	PARTICIPANT	\N	PRESENT	0
24020	22568	14053L	PARTICIPANT	\N	PRESENT	0
24022	22568	11012A	PARTICIPANT	\N	PRESENT	0
24024	22568	04061F	PARTICIPANT	\N	PRESENT	0
24026	22568	01031L	PARTICIPANT	\N	PRESENT	0
24027	22568	86044G	PARTICIPANT	\N	PRESENT	0
24029	22568	01046T	PARTICIPANT	\N	PRESENT	0
24040	22568	11037K	PARTICIPANT	\N	PRESENT	0
24044	22568	01028R	PARTICIPANT	\N	PRESENT	0
24051	22568	11042G	PARTICIPANT	\N	PRESENT	0
24046	22568	11109J	PARTICIPANT	\N	PRESENT	0
24047	22568	95067Q	PARTICIPANT	\N	PRESENT	0
24049	22568	11072N	PARTICIPANT	\N	PRESENT	0
24050	22568	11085T	PARTICIPANT	\N	PRESENT	0
24052	22568	14201E	PARTICIPANT	\N	PRESENT	0
24271	22567	04066L	PARTICIPANT	\N	PRESENT	0
24272	22567	11068S	PARTICIPANT	\N	PRESENT	0
24273	22567	98018T	PARTICIPANT	\N	PRESENT	0
24274	22567	11109J	PARTICIPANT	\N	PRESENT	0
24275	22567	04054G	PARTICIPANT	\N	PRESENT	0
24276	22567	92020L	PARTICIPANT	\N	PRESENT	0
24277	22567	11015D	PARTICIPANT	\N	PRESENT	0
24278	22567	08019V	PARTICIPANT	\N	PRESENT	0
24279	22567	14267Y	PARTICIPANT	\N	PRESENT	0
24280	22567	04080J	PARTICIPANT	\N	PRESENT	0
24281	22567	14253S	PARTICIPANT	\N	PRESENT	0
24282	22567	04078Q	PARTICIPANT	\N	PRESENT	0
24283	22567	11027H	PARTICIPANT	\N	PRESENT	0
24284	22567	95059Q	PARTICIPANT	\N	PRESENT	0
24285	22567	07004J	PARTICIPANT	\N	PRESENT	0
24286	22567	04042C	PARTICIPANT	\N	PRESENT	0
24287	22567	07024N	PARTICIPANT	\N	PRESENT	0
24288	22567	07029T	PARTICIPANT	\N	PRESENT	0
24289	22567	04035D	PARTICIPANT	\N	PRESENT	0
24290	22567	14135M	PARTICIPANT	\N	PRESENT	0
24291	22567	14031R	PARTICIPANT	\N	PRESENT	0
24292	22567	98005N	PARTICIPANT	\N	PRESENT	0
24293	22567	04088S	PARTICIPANT	\N	PRESENT	0
24294	22567	14193X	PARTICIPANT	\N	PRESENT	0
24295	22567	95030B	PARTICIPANT	\N	PRESENT	0
24296	22567	86044G	PARTICIPANT	\N	PRESENT	0
24297	22567	08058D	PARTICIPANT	\N	PRESENT	0
24298	22567	98029W	PARTICIPANT	\N	PRESENT	0
24299	22567	14014Q	PARTICIPANT	\N	PRESENT	0
24300	22567	01014K	PARTICIPANT	\N	PRESENT	0
24301	22567	92018S	PARTICIPANT	\N	PRESENT	0
24302	22567	97011G	PARTICIPANT	\N	PRESENT	0
24303	22567	95035G	PARTICIPANT	\N	PRESENT	0
24304	22567	04077P	PARTICIPANT	\N	PRESENT	0
24305	22567	01048V	PARTICIPANT	\N	PRESENT	0
24306	22567	92031P	PARTICIPANT	\N	PRESENT	0
24307	22567	11054L	PARTICIPANT	\N	PRESENT	0
24308	22567	14225N	PARTICIPANT	\N	PRESENT	0
24330	22567	08051V	PARTICIPANT	\N	PRESENT	0
24331	22567	08047A	PARTICIPANT	\N	PRESENT	0
24334	22567	11076S	PARTICIPANT	\N	PRESENT	0
24335	22567	04074L	PARTICIPANT	\N	PRESENT	0
24336	22567	11042G	PARTICIPANT	\N	PRESENT	0
24337	22567	95041E	PARTICIPANT	\N	PRESENT	0
24338	22567	14069U	PARTICIPANT	\N	PRESENT	0
24339	22567	04036E	PARTICIPANT	\N	PRESENT	0
24340	22567	11012A	PARTICIPANT	\N	PRESENT	0
25400	25399	89017R	PARTICIPANT	\N	PRESENT	0
25318	25306	04089T	PARTICIPANT	\N	PRESENT	0
25319	25306	14197C	PARTICIPANT	\N	PRESENT	0
25320	25306	11110B	PARTICIPANT	\N	PRESENT	0
25307	25306	01008M	PARTICIPANT	\N	PRESENT	0
25321	25306	14187A	PARTICIPANT	\N	PRESENT	0
25322	25306	14033T	PARTICIPANT	\N	PRESENT	0
25323	25306	14081Q	PARTICIPANT	\N	PRESENT	0
25324	25306	04048J	PARTICIPANT	\N	EXCUSE	0
25401	25399	01031L	PRESIDENT	0	PRESENT	0
25326	25306	04049K	PARTICIPANT	\N	PRESENT	0
25328	25306	11111C	PARTICIPANT	\N	PRESENT	0
25329	25306	08015R	PARTICIPANT	\N	PRESENT	0
25330	25306	11100Y	PRESIDENT	0	PRESENT	0
25331	25306	01061S	PARTICIPANT	\N	PRESENT	0
25332	25306	11098Y	PARTICIPANT	\N	PRESENT	0
25333	25306	01043Q	PARTICIPANT	\N	PRESENT	0
25334	25306	11077T	PARTICIPANT	\N	PRESENT	0
25335	25306	14205J	PARTICIPANT	\N	PRESENT	0
25336	25306	08019V	PARTICIPANT	\N	PRESENT	0
25337	25306	14257W	PARTICIPANT	\N	PRESENT	0
25338	25306	08021P	PARTICIPANT	\N	EXCUSE	0
25339	25306	04088S	PARTICIPANT	\N	PRESENT	0
25340	25306	98050T	PARTICIPANT	\N	PRESENT	0
25308	25306	11036J	PARTICIPANT	\N	PRESENT	0
25403	25399	01013J	PARTICIPANT	\N	PRESENT	0
25341	25306	11090Q	PARTICIPANT	\N	PRESENT	0
25342	25306	11046L	PARTICIPANT	\N	PRESENT	0
25343	25306	01058X	PARTICIPANT	\N	PRESENT	0
25310	25306	14013P	PARTICIPANT	\N	PRESENT	0
25311	25306	08068F	PARTICIPANT	\N	PRESENT	0
25344	25306	11094U	PARTICIPANT	\N	PRESENT	0
25345	25306	11066Q	PARTICIPANT	\N	PRESENT	0
25404	25399	11068S	PARTICIPANT	\N	PRESENT	0
25406	25399	08014Q	PARTICIPANT	\N	PRESENT	0
25407	25399	14167V	PARTICIPANT	\N	PRESENT	0
25408	25399	14175V	PARTICIPANT	\N	PRESENT	0
25313	25306	11101A	PARTICIPANT	\N	PRESENT	0
25314	25306	90003B	PARTICIPANT	\N	PRESENT	0
25409	25399	14083S	PARTICIPANT	\N	PRESENT	0
25410	25399	11053K	PARTICIPANT	\N	PRESENT	0
25411	25399	14085U	PARTICIPANT	\N	PRESENT	0
25412	25399	11042G	PARTICIPANT	\N	PRESENT	0
25315	25306	08028W	PARTICIPANT	\N	PRESENT	0
25413	25399	88008L	PARTICIPANT	\N	PRESENT	0
25414	25399	04086Q	PARTICIPANT	\N	PRESENT	0
25416	25399	11070L	PARTICIPANT	\N	PRESENT	0
25417	25399	11088W	PARTICIPANT	\N	PRESENT	0
25316	25306	80013X	PARTICIPANT	\N	PRESENT	0
25419	25399	08022Q	PARTICIPANT	\N	PRESENT	0
25420	25399	01027Q	PARTICIPANT	\N	PRESENT	0
25422	25399	11074Q	PARTICIPANT	\N	PRESENT	0
23518	23511	08025T	PARTICIPANT	\N	PRESENT	0
23519	23511	04085P	PARTICIPANT	\N	PRESENT	0
23520	23511	05008E	PRESIDENT	0	PRESENT	0
23521	23511	11030C	PARTICIPANT	\N	PRESENT	0
23522	23511	11033F	PARTICIPANT	\N	PRESENT	0
23523	23511	14065Q	PARTICIPANT	\N	PRESENT	0
23568	23511	11049P	PARTICIPANT	\N	PRESENT	0
23525	23511	04047H	PARTICIPANT	\N	PRESENT	0
23574	23573	11036J	PARTICIPANT	\N	PRESENT	0
23575	23573	11033F	PARTICIPANT	\N	PRESENT	0
23528	23511	99002P	PARTICIPANT	\N	PRESENT	0
23529	23511	11056N	PARTICIPANT	\N	PRESENT	0
23530	23511	14259Y	PARTICIPANT	\N	PRESENT	0
23576	23573	14065Q	PARTICIPANT	\N	PRESENT	0
23532	23511	14041T	PARTICIPANT	\N	PRESENT	0
23533	23511	11113E	PARTICIPANT	\N	PRESENT	0
23534	23511	01024M	PARTICIPANT	\N	PRESENT	0
23535	23511	14215L	PARTICIPANT	\N	PRESENT	0
23577	23573	08043V	PRESIDENT	0	PRESENT	0
23537	23511	08018U	PARTICIPANT	\N	PRESENT	0
23578	23573	11031D	PARTICIPANT	\N	PRESENT	0
23579	23573	80013X	PARTICIPANT	\N	PRESENT	0
23580	23573	10006L	PARTICIPANT	\N	PRESENT	0
23541	23511	08044W	PARTICIPANT	\N	PRESENT	0
23542	23511	11084S	PARTICIPANT	\N	PRESENT	0
23543	23511	11026G	PARTICIPANT	\N	PRESENT	0
23544	23511	04079R	PARTICIPANT	\N	PRESENT	0
23581	23573	14041T	PARTICIPANT	\N	PRESENT	0
23546	23511	14001X	PARTICIPANT	\N	PRESENT	0
23582	23573	14087W	PARTICIPANT	\N	PRESENT	0
23583	23573	97011G	PARTICIPANT	\N	PRESENT	0
23549	23511	14147R	PARTICIPANT	\N	PRESENT	0
23584	23573	11061K	PARTICIPANT	\N	PRESENT	0
23585	23573	14014Q	PARTICIPANT	\N	PRESENT	0
23586	23573	08041T	PARTICIPANT	\N	PRESENT	0
23553	23511	07034Q	PARTICIPANT	\N	PRESENT	0
23554	23511	04074L	PARTICIPANT	\N	PRESENT	0
23555	23511	10015M	PARTICIPANT	\N	PRESENT	0
23587	23573	01011G	PARTICIPANT	\N	PRESENT	0
23588	23573	07026Q	PARTICIPANT	\N	PRESENT	0
23558	23511	01028R	PARTICIPANT	\N	PRESENT	0
23559	23511	98035U	PARTICIPANT	\N	PRESENT	0
23589	23573	95035G	PARTICIPANT	\N	PRESENT	0
23591	23573	14026U	PARTICIPANT	\N	PRESENT	0
23562	23511	04044E	PRESIDENT	1	PRESENT	0
23563	23511	11037K	PARTICIPANT	\N	PRESENT	0
23564	23511	92045V	PARTICIPANT	\N	EXCUSE	0
23565	23511	95067Q	PARTICIPANT	\N	PRESENT	0
23592	23573	04036E	PARTICIPANT	\N	PRESENT	0
23593	23573	08017T	PARTICIPANT	\N	PRESENT	0
23594	23573	04079R	PARTICIPANT	\N	PRESENT	0
23595	23573	11067R	PARTICIPANT	\N	PRESENT	0
23596	23573	14223L	PARTICIPANT	\N	PRESENT	0
23597	23573	11012A	PARTICIPANT	\N	PRESENT	0
23599	23573	98035U	PARTICIPANT	\N	PRESENT	0
23600	23573	04044E	PARTICIPANT	\N	PRESENT	0
23602	23573	95067Q	PRESIDENT	1	PRESENT	0
24346	24345	14093U	PARTICIPANT	\N	EXCUSE	0
24347	24345	14059S	PARTICIPANT	\N	EXCUSE	0
24348	24345	11010L	PARTICIPANT	\N	EXCUSE	0
24349	24344	11010L	PARTICIPANT	\N	EXCUSE	0
25305	24684	99004R	PARTICIPANT	\N	PRESENT	0
25347	25346	89017R	PARTICIPANT	\N	PRESENT	0
25348	25346	01031L	PRESIDENT	1	PRESENT	0
25067	23799	89029V	PARTICIPANT	0	PRESENT	0
25349	25346	05004A	PARTICIPANT	\N	PRESENT	0
25350	25346	01013J	PARTICIPANT	\N	PRESENT	0
25351	25346	11068S	PARTICIPANT	\N	PRESENT	0
25352	25346	11040E	PARTICIPANT	\N	PRESENT	0
25068	23799	01047U	PARTICIPANT	0	PRESENT	0
25353	25346	08014Q	PARTICIPANT	\N	PRESENT	0
25354	25346	14167V	PARTICIPANT	\N	PRESENT	0
25069	23799	11037K	PARTICIPANT	0	PRESENT	0
25070	23799	14265W	PARTICIPANT	0	PRESENT	0
25071	23799	14026U	PARTICIPANT	0	PRESENT	0
25072	23799	01028R	PARTICIPANT	0	PRESENT	0
25073	23799	14179A	PARTICIPANT	0	PRESENT	0
25074	23799	04088S	PARTICIPANT	0	PRESENT	0
25075	23799	14273W	PARTICIPANT	0	PRESENT	0
25076	23799	14089Y	PARTICIPANT	0	PRESENT	0
25077	23799	14215L	PARTICIPANT	0	PRESENT	0
25078	23799	04044E	PARTICIPANT	0	PRESENT	0
25079	23799	14105F	PARTICIPANT	0	PRESENT	0
25080	23799	11011M	PARTICIPANT	0	PRESENT	0
25081	23799	14147R	PARTICIPANT	0	PRESENT	0
25082	23799	14061L	PARTICIPANT	0	PRESENT	0
25083	23799	95049N	PARTICIPANT	0	PRESENT	0
25084	23799	04085P	PARTICIPANT	0	PRESENT	0
25085	23799	14065Q	PARTICIPANT	0	PRESENT	0
25086	23799	14205J	PARTICIPANT	0	PRESENT	0
25087	23799	14261S	PARTICIPANT	0	PRESENT	0
25088	23799	14239U	PARTICIPANT	0	PRESENT	0
25089	23799	08031R	PARTICIPANT	0	PRESENT	0
25090	23799	14247U	PARTICIPANT	0	PRESENT	0
25091	23799	01027Q	PARTICIPANT	0	PRESENT	0
25092	23799	14241N	PARTICIPANT	0	PRESENT	0
25093	23799	14103D	PARTICIPANT	0	PRESENT	0
25094	23799	14219Q	PARTICIPANT	0	PRESENT	0
25095	23799	14097Y	PARTICIPANT	0	PRESENT	0
25096	23799	95031C	PARTICIPANT	0	PRESENT	0
25097	23799	08015R	PARTICIPANT	0	PRESENT	0
25098	23799	14267Y	PARTICIPANT	0	PRESENT	0
25099	23799	14217N	PARTICIPANT	0	PRESENT	0
25100	23799	14033T	PARTICIPANT	0	PRESENT	0
25101	23799	08056B	PARTICIPANT	0	PRESENT	0
25102	23799	14042U	PARTICIPANT	0	PRESENT	0
25103	23799	08068F	PARTICIPANT	0	PRESENT	0
25104	23799	07026Q	PARTICIPANT	0	PRESENT	0
25105	23799	14263U	PARTICIPANT	0	PRESENT	0
25106	23799	11067R	PARTICIPANT	0	PRESENT	0
25107	23799	07032N	PARTICIPANT	0	PRESENT	0
25108	23799	08053X	PARTICIPANT	0	PRESENT	0
25109	23799	14213J	PARTICIPANT	0	PRESENT	0
25110	23799	14030Q	PARTICIPANT	0	PRESENT	0
25111	23799	14059S	PARTICIPANT	0	PRESENT	0
25112	23799	11032E	PARTICIPANT	0	PRESENT	0
25113	23799	05008E	PARTICIPANT	0	PRESENT	0
25114	23799	14087W	PARTICIPANT	0	PRESENT	0
25115	23799	14055N	PARTICIPANT	0	PRESENT	0
25116	23799	95035G	PARTICIPANT	0	PRESENT	0
25117	23799	98050T	PARTICIPANT	0	PRESENT	0
25118	23799	08062Y	PARTICIPANT	0	PRESENT	0
25119	23799	14053L	PARTICIPANT	0	PRESENT	0
25120	23799	11066Q	PARTICIPANT	0	PRESENT	0
25121	23799	11054L	PARTICIPANT	0	PRESENT	0
25122	23799	80013X	PARTICIPANT	0	PRESENT	0
25123	23799	14223L	PARTICIPANT	0	PRESENT	0
25124	23799	14013P	PARTICIPANT	0	PRESENT	0
25125	23799	14197C	PARTICIPANT	0	PRESENT	0
25126	23799	11081P	PARTICIPANT	0	PRESENT	0
25127	23799	11029K	PARTICIPANT	0	PRESENT	0
25128	23799	07034Q	PARTICIPANT	0	PRESENT	0
25129	23799	08065C	PARTICIPANT	0	PRESENT	0
25130	23799	14209N	PARTICIPANT	0	PRESENT	0
25131	23799	01025N	PARTICIPANT	0	PRESENT	0
25132	23799	14111D	PARTICIPANT	0	PRESENT	0
25133	23799	14237S	PARTICIPANT	0	PRESENT	0
25134	23799	97011G	PARTICIPANT	0	PRESENT	0
25135	23799	14157T	PARTICIPANT	0	PRESENT	0
25136	23799	05012A	PARTICIPANT	0	PRESENT	0
25137	23799	14187A	PARTICIPANT	0	PRESENT	0
25138	23799	11089X	PARTICIPANT	0	PRESENT	0
25139	23799	11100Y	PARTICIPANT	0	PRESENT	0
25140	23799	11091R	PARTICIPANT	0	PRESENT	0
25141	23799	95030B	PARTICIPANT	0	PRESENT	0
25142	23799	11090Q	PARTICIPANT	0	PRESENT	0
25143	23799	14034U	PARTICIPANT	0	PRESENT	0
25144	23799	14191V	PARTICIPANT	0	PRESENT	0
25145	23799	14069U	PARTICIPANT	0	PRESENT	0
25146	23799	11035H	PARTICIPANT	0	PRESENT	0
25147	23799	08019V	PARTICIPANT	0	PRESENT	0
25148	23799	14121F	PARTICIPANT	0	PRESENT	0
25149	23799	14201E	PARTICIPANT	0	PRESENT	0
25150	23799	11099A	PARTICIPANT	0	PRESENT	0
25151	23799	14199E	PARTICIPANT	0	PRESENT	0
25152	23799	14073Q	PARTICIPANT	0	PRESENT	0
25153	23799	14277B	PARTICIPANT	0	PRESENT	0
25154	23799	13002U	PARTICIPANT	0	PRESENT	0
25155	23799	14221J	PARTICIPANT	0	PRESENT	0
25156	23799	04080J	PARTICIPANT	0	PRESENT	0
25157	23799	11059R	PARTICIPANT	0	PRESENT	0
25158	23799	14173T	PARTICIPANT	0	PRESENT	0
23281	23244	14119M	PARTICIPANT	\N	PRESENT	0
23282	23244	14071N	PARTICIPANT	\N	PRESENT	0
23283	23244	07032N	PARTICIPANT	\N	PRESENT	0
23284	23244	14271U	PARTICIPANT	\N	PRESENT	0
23285	23244	11093T	PARTICIPANT	\N	PRESENT	0
23286	23244	11097X	PARTICIPANT	\N	EXCUSE	0
23287	23244	14227Q	PARTICIPANT	\N	PRESENT	0
23288	23244	01034P	PRESIDENT	1	PRESENT	0
23289	23244	11025F	PARTICIPANT	\N	PRESENT	0
23290	23244	11063M	PARTICIPANT	\N	PRESENT	0
23625	21501	14209N	PARTICIPANT	\N	EXCUSE	0
23630	23629	14239U	PARTICIPANT	\N	PRESENT	0
23631	23629	11055M	PARTICIPANT	\N	PRESENT	0
23632	23629	01046T	PARTICIPANT	\N	PRESENT	0
23633	23629	04053F	PARTICIPANT	\N	PRESENT	0
23634	23629	14255U	PARTICIPANT	\N	PRESENT	0
23635	23629	04066L	PARTICIPANT	\N	PRESENT	0
23636	23629	00003C	PARTICIPANT	\N	PRESENT	0
23637	23629	14053L	PARTICIPANT	\N	PRESENT	0
23638	23629	11103C	PARTICIPANT	\N	PRESENT	0
23640	23629	14195A	PARTICIPANT	\N	PRESENT	0
23641	23629	14267Y	PARTICIPANT	\N	PRESENT	0
23642	23629	08052W	PARTICIPANT	\N	PRESENT	0
23643	23629	01059Y	PARTICIPANT	\N	PRESENT	0
23644	23629	10006L	PARTICIPANT	\N	PRESENT	0
23645	23629	14217N	PARTICIPANT	\N	PRESENT	0
23646	23629	14042U	PARTICIPANT	\N	PRESENT	0
23647	23629	12042Y	PARTICIPANT	\N	PRESENT	0
23648	23629	14087W	PARTICIPANT	\N	PRESENT	0
23649	23629	14231L	PARTICIPANT	\N	PRESENT	0
23650	23629	11061K	PARTICIPANT	\N	PRESENT	0
23651	23629	08041T	PARTICIPANT	\N	PRESENT	0
23652	23629	14026U	PARTICIPANT	\N	PRESENT	0
23653	23629	14213J	PARTICIPANT	\N	PRESENT	0
23654	23629	14121F	PARTICIPANT	\N	PRESENT	0
23655	23629	11112D	PARTICIPANT	\N	PRESENT	0
23656	23629	14037X	PARTICIPANT	\N	PRESENT	0
23657	23629	11067R	PARTICIPANT	\N	EXCUSE	0
23658	23629	14223L	PARTICIPANT	\N	PRESENT	0
23659	23629	04092N	PRESIDENT	0	PRESENT	0
23660	23629	14265W	PARTICIPANT	\N	PRESENT	0
23661	23629	14119M	PARTICIPANT	\N	PRESENT	0
23663	23629	14071N	PARTICIPANT	\N	PRESENT	0
23664	23629	07032N	PARTICIPANT	\N	PRESENT	0
23665	23629	04043D	PARTICIPANT	\N	PRESENT	0
23666	23629	14271U	PARTICIPANT	\N	PRESENT	0
23667	23629	11093T	PARTICIPANT	\N	PRESENT	0
23668	23629	11097X	PARTICIPANT	\N	EXCUSE	0
23669	23629	14227Q	PARTICIPANT	\N	PRESENT	0
23670	23629	01034P	PARTICIPANT	\N	PRESENT	0
23671	23629	11025F	PARTICIPANT	\N	PRESENT	0
23672	23629	14269B	PARTICIPANT	\N	PRESENT	0
23702	23701	04040A	PARTICIPANT	\N	EXCUSE	0
23703	23701	08058D	PARTICIPANT	\N	PRESENT	0
23704	23701	04042C	PARTICIPANT	\N	PRESENT	0
23705	23701	98029W	PARTICIPANT	\N	PRESENT	0
23706	23701	11027H	PARTICIPANT	\N	PRESENT	0
23707	23701	98018T	PARTICIPANT	\N	EXCUSE	0
23708	23701	92018S	PARTICIPANT	\N	PRESENT	0
23709	23701	92020L	PARTICIPANT	\N	PRESENT	0
23710	23701	95030B	PARTICIPANT	\N	PRESENT	0
23711	23701	97011G	PARTICIPANT	\N	PRESENT	0
23712	23701	04035D	PARTICIPANT	\N	PRESENT	0
23713	23701	07024N	PARTICIPANT	\N	PRESENT	0
23714	23701	11015D	PARTICIPANT	\N	PRESENT	0
23715	23701	07004J	PARTICIPANT	\N	PRESENT	0
23716	23701	95035G	PARTICIPANT	\N	PRESENT	0
23717	23701	08056B	PARTICIPANT	\N	EXCUSE	0
23718	23701	14211G	PARTICIPANT	\N	PRESENT	0
23719	23701	04078Q	PARTICIPANT	\N	PRESENT	0
23720	23701	14097Y	PARTICIPANT	\N	PRESENT	0
23721	23701	95041E	PARTICIPANT	\N	EXCUSE	0
23722	23701	04036E	PARTICIPANT	\N	PRESENT	0
23723	23701	14039A	PARTICIPANT	\N	PRESENT	0
23724	23701	92031P	PARTICIPANT	\N	PRESENT	0
23725	23701	11106F	PARTICIPANT	\N	PRESENT	0
23726	23701	14251Q	PARTICIPANT	\N	PRESENT	0
23727	23701	11105E	PARTICIPANT	\N	EXCUSE	0
23728	23701	14253S	PARTICIPANT	\N	PRESENT	0
23729	23701	14028W	PARTICIPANT	\N	PRESENT	0
23730	23701	14193X	PARTICIPANT	\N	PRESENT	0
23731	23701	95059Q	PRESIDENT	0	PRESENT	0
23732	23701	86044G	PARTICIPANT	\N	PRESENT	0
23733	23701	01014K	PARTICIPANT	\N	PRESENT	0
23734	23701	11054L	PARTICIPANT	\N	PRESENT	0
23735	23701	01056V	PARTICIPANT	\N	PRESENT	0
23736	23701	92044U	PARTICIPANT	\N	PRESENT	0
24364	24361	14065Q	PARTICIPANT	\N	PRESENT	0
24365	24361	04038G	PARTICIPANT	\N	PRESENT	0
24362	24361	05008E	PRESIDENT	0	PRESENT	0
24363	24361	11033F	PARTICIPANT	\N	EXCUSE	0
24366	24361	11056N	PARTICIPANT	\N	EXCUSE	0
24367	24361	01024M	PARTICIPANT	\N	PRESENT	0
24368	24361	01007L	PARTICIPANT	\N	PRESENT	0
24369	24361	14111D	PARTICIPANT	\N	PRESENT	0
24370	24361	14273W	PARTICIPANT	\N	EXCUSE	0
24371	24361	14147R	PARTICIPANT	\N	PRESENT	0
24372	24361	07034Q	PARTICIPANT	\N	PRESENT	0
24373	24361	95063L	PARTICIPANT	\N	PRESENT	0
24374	24361	04044E	PARTICIPANT	\N	PRESENT	0
24375	24361	11037K	PARTICIPANT	\N	PRESENT	0
24376	24361	92045V	PARTICIPANT	\N	EXCUSE	0
24377	24361	01047U	PARTICIPANT	\N	PRESENT	0
24378	24361	11084S	PARTICIPANT	\N	EXCUSE	0
25355	25346	14175V	PARTICIPANT	\N	PRESENT	0
25356	25346	14083S	PARTICIPANT	\N	PRESENT	0
25357	25346	11053K	PARTICIPANT	\N	PRESENT	0
25358	25346	14085U	PARTICIPANT	\N	PRESENT	0
25359	25346	11042G	PARTICIPANT	\N	PRESENT	0
25360	25346	88008L	PARTICIPANT	\N	PRESENT	0
25361	25346	04086Q	PARTICIPANT	\N	PRESENT	0
25396	25346	86044G	RAPPORTEUR_AVIS	\N	PRESENT	0
25363	25346	11070L	PARTICIPANT	\N	PRESENT	0
25364	25346	11088W	PARTICIPANT	\N	PRESENT	0
25365	25346	14327T	PARTICIPANT	\N	PRESENT	0
25366	25346	08022Q	PARTICIPANT	\N	PRESENT	0
25367	25346	01027Q	PARTICIPANT	\N	PRESENT	0
25397	25346	11027H	RAPPORTEUR_AVIS	\N	PRESENT	0
25369	25346	11074Q	PARTICIPANT	\N	PRESENT	0
25398	25346	14037X	RAPPORTEUR_AVIS	\N	PRESENT	0
25371	25346	11083R	PARTICIPANT	\N	PRESENT	0
25372	25346	14199E	PARTICIPANT	\N	PRESENT	0
25373	25346	01057W	PARTICIPANT	\N	PRESENT	0
25374	25346	08016S	PARTICIPANT	\N	PRESENT	0
25375	25346	08069G	PARTICIPANT	\N	PRESENT	0
25376	25346	11048N	PARTICIPANT	\N	PRESENT	0
25377	25346	99004R	PARTICIPANT	\N	PRESENT	0
25378	25346	04061F	PARTICIPANT	\N	PRESENT	0
25379	25346	14159V	PARTICIPANT	\N	PRESENT	0
25380	25346	07029T	PARTICIPANT	\N	PRESENT	0
25381	25346	14277B	PARTICIPANT	\N	PRESENT	0
25382	25346	08010L	PARTICIPANT	\N	PRESENT	0
25383	25346	08034U	PARTICIPANT	\N	PRESENT	0
25384	25346	01048V	PARTICIPANT	\N	PRESENT	0
25385	25346	98046X	PARTICIPANT	\N	PRESENT	0
25424	25399	11083R	PARTICIPANT	\N	PRESENT	0
25387	25346	08011M	PARTICIPANT	\N	PRESENT	0
25388	25346	08073C	PARTICIPANT	\N	PRESENT	0
25389	25346	08061X	PARTICIPANT	\N	PRESENT	0
25390	25346	01016M	PARTICIPANT	\N	PRESENT	0
25391	25346	14225N	PARTICIPANT	\N	PRESENT	0
25392	25346	11012A	PARTICIPANT	\N	PRESENT	0
25393	25346	11057P	PARTICIPANT	\N	PRESENT	0
25394	25346	14173T	PARTICIPANT	\N	PRESENT	0
25395	25346	04034C	PRESIDENT	0	PRESENT	0
25546	25476	14239U	PARTICIPANT	\N	PRESENT	0
25426	25399	01057W	PARTICIPANT	\N	PRESENT	0
25547	25476	11055M	PARTICIPANT	\N	PRESENT	0
25428	25399	08069G	PARTICIPANT	\N	PRESENT	0
25429	25399	11048N	PARTICIPANT	\N	PRESENT	0
25430	25399	99004R	PARTICIPANT	\N	PRESENT	0
25431	25399	04061F	PARTICIPANT	\N	PRESENT	0
25432	25399	14159V	PARTICIPANT	\N	PRESENT	0
25433	25399	07029T	PARTICIPANT	\N	PRESENT	0
25434	25399	14277B	PARTICIPANT	\N	PRESENT	0
25435	25399	08010L	PARTICIPANT	\N	PRESENT	0
25436	25399	08034U	PARTICIPANT	\N	PRESENT	0
25437	25399	01048V	PARTICIPANT	\N	PRESENT	0
25438	25399	98046X	PARTICIPANT	\N	PRESENT	0
25439	25399	11085T	PARTICIPANT	\N	EXCUSE	0
25440	25399	08011M	PARTICIPANT	\N	PRESENT	0
25441	25399	08073C	PARTICIPANT	\N	PRESENT	0
25442	25399	08061X	PARTICIPANT	\N	PRESENT	0
25443	25399	01016M	PARTICIPANT	\N	PRESENT	0
25444	25399	14225N	PARTICIPANT	\N	PRESENT	0
25445	25399	11012A	PARTICIPANT	\N	PRESENT	0
25446	25399	11057P	PARTICIPANT	\N	PRESENT	0
25447	25399	14173T	PARTICIPANT	\N	PRESENT	0
25448	25399	04034C	PARTICIPANT	\N	PRESENT	0
23797	23795	11032E	PARTICIPANT	\N	EXCUSE	0
23798	23795	04040A	PRESIDENT	0	PRESENT	0
24309	23796	96004D	PRESIDENT	0	PRESENT	0
24313	23796	95030B	PARTICIPANT	\N	PRESENT	0
24311	23796	14089Y	PARTICIPANT	\N	PRESENT	0
24312	23796	14079W	PARTICIPANT	\N	PRESENT	0
24314	23796	08018U	PARTICIPANT	\N	PRESENT	0
24315	23796	11083R	PARTICIPANT	\N	PRESENT	0
24316	23796	14026U	PARTICIPANT	\N	PRESENT	0
24317	23796	14097Y	PARTICIPANT	\N	PRESENT	0
24318	23796	04061F	PARTICIPANT	\N	PRESENT	0
24319	23796	14073Q	PARTICIPANT	\N	PRESENT	0
24320	23796	11026G	PARTICIPANT	\N	PRESENT	0
24321	23796	98046X	PARTICIPANT	\N	PRESENT	0
24322	23796	14001X	PARTICIPANT	\N	PRESENT	0
24323	23796	04057K	PARTICIPANT	\N	PRESENT	0
24324	23796	04080J	PARTICIPANT	\N	PRESENT	0
24325	23796	01016M	PARTICIPANT	\N	PRESENT	0
24326	23796	10015M	PARTICIPANT	\N	PRESENT	0
24327	23796	11012A	PARTICIPANT	\N	PRESENT	0
24328	23796	95063L	PARTICIPANT	\N	PRESENT	0
24329	23796	98035U	PARTICIPANT	\N	PRESENT	0
24332	23796	08021P	PARTICIPANT	\N	EXCUSE	0
24333	23796	14135M	PARTICIPANT	\N	EXCUSE	0
25624	25623	11076S	PARTICIPANT	\N	PRESENT	0
25626	25623	04040A	PARTICIPANT	\N	PRESENT	0
25627	25623	08058D	PARTICIPANT	\N	PRESENT	0
25628	25623	04042C	PARTICIPANT	\N	PRESENT	0
25629	25623	77002U	PARTICIPANT	\N	PRESENT	0
25630	25623	98029W	PARTICIPANT	\N	PRESENT	0
25631	25623	11080N	PARTICIPANT	\N	PRESENT	0
25632	25623	11027H	PARTICIPANT	\N	PRESENT	0
25633	25623	98018T	PARTICIPANT	\N	EXCUSE	0
25634	25623	92018S	PARTICIPANT	\N	PRESENT	0
24698	24684	89017R	PARTICIPANT	\N	PRESENT	0
24699	24684	01031L	PARTICIPANT	\N	EXCUSE	0
24700	24684	05004A	PARTICIPANT	\N	PRESENT	0
24701	24684	01013J	PARTICIPANT	\N	PRESENT	0
24702	24684	11068S	PARTICIPANT	\N	PRESENT	0
24703	24684	11040E	PARTICIPANT	\N	PRESENT	0
24704	24684	08014Q	PARTICIPANT	\N	PRESENT	0
24705	24684	14167V	PARTICIPANT	\N	PRESENT	0
24706	24684	14175V	PARTICIPANT	\N	PRESENT	0
24707	24684	14083S	PARTICIPANT	\N	PRESENT	0
24708	24684	11053K	PARTICIPANT	\N	PRESENT	0
24709	24684	14085U	PARTICIPANT	\N	PRESENT	0
24710	24684	11042G	PARTICIPANT	\N	PRESENT	0
24711	24684	88008L	PARTICIPANT	\N	PRESENT	0
24712	24684	04086Q	PARTICIPANT	\N	PRESENT	0
24715	24684	11088W	PARTICIPANT	\N	PRESENT	0
24716	24684	14327T	PARTICIPANT	\N	PRESENT	0
24717	24684	08022Q	PARTICIPANT	\N	PRESENT	0
24719	24684	04071H	PARTICIPANT	\N	PRESENT	0
24720	24684	11074Q	PARTICIPANT	\N	PRESENT	0
24722	24684	11083R	PARTICIPANT	\N	PRESENT	0
24724	24684	01057W	PARTICIPANT	\N	PRESENT	0
24725	24684	08016S	PARTICIPANT	\N	PRESENT	0
24726	24684	08069G	PARTICIPANT	\N	PRESENT	0
25548	25476	01046T	PARTICIPANT	\N	PRESENT	0
24729	24684	04061F	PARTICIPANT	\N	PRESENT	0
24730	24684	14159V	PARTICIPANT	\N	PRESENT	0
24731	24684	07029T	PARTICIPANT	\N	PRESENT	0
24732	24684	14277B	PARTICIPANT	\N	PRESENT	0
24733	24684	08010L	PARTICIPANT	\N	PRESENT	0
24734	24684	08034U	PARTICIPANT	\N	PRESENT	0
24735	24684	01048V	PARTICIPANT	\N	PRESENT	0
24736	24684	98046X	PARTICIPANT	\N	PRESENT	0
24737	24684	11085T	PARTICIPANT	\N	PRESENT	0
24738	24684	08011M	PARTICIPANT	\N	PRESENT	0
24739	24684	08073C	PRESIDENT	0	PRESENT	0
24740	24684	08061X	PARTICIPANT	\N	PRESENT	0
24741	24684	01016M	PARTICIPANT	\N	PRESENT	0
24982	24684	14053L	RAPPORTEUR_AVIS	\N	PRESENT	0
24743	24684	11012A	PARTICIPANT	\N	PRESENT	0
24744	24684	11057P	PARTICIPANT	\N	PRESENT	0
24745	24684	14173T	PARTICIPANT	\N	PRESENT	0
24781	23802	01047U	PARTICIPANT	\N	PRESENT	0
24782	23802	11037K	PARTICIPANT	\N	PRESENT	0
24783	23802	14265W	PARTICIPANT	\N	PRESENT	0
24784	23802	01028R	PARTICIPANT	\N	PRESENT	0
24785	23802	14179A	PARTICIPANT	\N	PRESENT	0
24786	23802	04088S	PARTICIPANT	\N	PRESENT	0
24787	23802	14273W	PARTICIPANT	\N	PRESENT	0
24788	23802	14089Y	PARTICIPANT	\N	PRESENT	0
24789	23802	14215L	PARTICIPANT	\N	PRESENT	0
24790	23802	04044E	PARTICIPANT	\N	PRESENT	0
24791	23802	14105F	PARTICIPANT	\N	PRESENT	0
24792	23802	11011M	PARTICIPANT	\N	PRESENT	0
24793	23802	14147R	PARTICIPANT	\N	PRESENT	0
24794	23802	14061L	PARTICIPANT	\N	PRESENT	0
24795	23802	95049N	PARTICIPANT	\N	PRESENT	0
24796	23802	04085P	PARTICIPANT	\N	PRESENT	0
24797	23802	14065Q	PARTICIPANT	\N	PRESENT	0
24798	23802	14205J	PARTICIPANT	\N	PRESENT	0
24799	23802	14261S	PARTICIPANT	\N	PRESENT	0
24800	23802	14239U	PARTICIPANT	\N	PRESENT	0
24801	23802	08031R	PARTICIPANT	\N	PRESENT	0
24802	23802	14247U	PARTICIPANT	\N	PRESENT	0
24803	23802	01027Q	PARTICIPANT	\N	PRESENT	0
24804	23802	14219Q	PARTICIPANT	\N	PRESENT	0
24805	23802	14097Y	PARTICIPANT	\N	PRESENT	0
24806	23802	95031C	PARTICIPANT	\N	PRESENT	0
24807	23802	14217N	PARTICIPANT	\N	PRESENT	0
24808	23802	14033T	PARTICIPANT	\N	PRESENT	0
24809	23802	08056B	PARTICIPANT	\N	PRESENT	0
24810	23802	14042U	PARTICIPANT	\N	PRESENT	0
24811	23802	07026Q	PARTICIPANT	\N	PRESENT	0
24812	23802	14263U	PARTICIPANT	\N	PRESENT	0
24813	23802	08053X	PARTICIPANT	\N	PRESENT	0
24814	23802	14213J	PARTICIPANT	\N	PRESENT	0
24815	23802	14030Q	PARTICIPANT	\N	PRESENT	0
24816	23802	14059S	PARTICIPANT	\N	PRESENT	0
24817	23802	05008E	PARTICIPANT	\N	PRESENT	0
24818	23802	14087W	PARTICIPANT	\N	PRESENT	0
24819	23802	14055N	PARTICIPANT	\N	PRESENT	0
24820	23802	95035G	PARTICIPANT	\N	PRESENT	0
24821	23802	98050T	PARTICIPANT	\N	PRESENT	0
24822	23802	14053L	PARTICIPANT	\N	PRESENT	0
24823	23802	11066Q	PARTICIPANT	\N	PRESENT	0
24824	23802	11054L	PARTICIPANT	\N	PRESENT	0
25549	25476	04053F	PARTICIPANT	\N	PRESENT	0
25550	25476	14255U	PARTICIPANT	\N	PRESENT	0
25551	25476	04066L	PARTICIPANT	\N	PRESENT	0
25553	25476	14053L	PARTICIPANT	\N	PRESENT	0
25554	25476	11103C	PARTICIPANT	\N	PRESENT	0
25555	25476	11044J	PARTICIPANT	\N	PRESENT	0
25556	25476	14195A	PARTICIPANT	\N	PRESENT	0
25557	25476	14267Y	PARTICIPANT	\N	PRESENT	0
25559	25476	11031D	PARTICIPANT	\N	PRESENT	0
25560	25476	08052W	PARTICIPANT	\N	PRESENT	0
25561	25476	01059Y	PARTICIPANT	\N	PRESENT	0
25562	25476	04081K	PARTICIPANT	\N	PRESENT	0
25563	25476	98024R	PARTICIPANT	\N	PRESENT	0
25564	25476	10006L	PARTICIPANT	\N	PRESENT	0
25565	25476	04067M	PARTICIPANT	\N	PRESENT	0
25566	25476	14217N	PARTICIPANT	\N	PRESENT	0
25567	25476	14042U	PARTICIPANT	\N	PRESENT	0
25568	25476	14151M	PARTICIPANT	\N	PRESENT	0
25569	25476	12042Y	PARTICIPANT	\N	PRESENT	0
25570	25476	14281W	PARTICIPANT	\N	PRESENT	0
25571	25476	14087W	PARTICIPANT	\N	PRESENT	0
25574	25476	14231L	PARTICIPANT	\N	PRESENT	0
25575	25476	11061K	PARTICIPANT	\N	PRESENT	0
25577	25476	08041T	PARTICIPANT	\N	PRESENT	0
25578	25476	01011G	PARTICIPANT	\N	PRESENT	0
25579	25476	14026U	PARTICIPANT	\N	PRESENT	0
25580	25476	14213J	PARTICIPANT	\N	PRESENT	0
25582	25476	11112D	PARTICIPANT	\N	PRESENT	0
25583	25476	14037X	PARTICIPANT	\N	PRESENT	0
25584	25476	14018U	PARTICIPANT	\N	PRESENT	0
25585	25476	11067R	PARTICIPANT	\N	PRESENT	0
25586	25476	14223L	PARTICIPANT	\N	PRESENT	0
25587	25476	04092N	PRESIDENT	0	PRESENT	0
25588	25476	14265W	PARTICIPANT	\N	PRESENT	0
25589	25476	14119M	PARTICIPANT	\N	PRESENT	0
25590	25476	14071N	PARTICIPANT	\N	PRESENT	0
25591	25476	07032N	PARTICIPANT	\N	PRESENT	0
25592	25476	04043D	PARTICIPANT	\N	PRESENT	0
25593	25476	14271U	PARTICIPANT	\N	PRESENT	0
25595	25476	11093T	PARTICIPANT	\N	PRESENT	0
25596	25476	11097X	PARTICIPANT	\N	EXCUSE	0
25597	25476	04045F	PARTICIPANT	\N	PRESENT	0
25598	25476	14227Q	PARTICIPANT	\N	PRESENT	0
25599	25476	01034P	PARTICIPANT	\N	PRESENT	0
25601	25476	11063M	PARTICIPANT	\N	PRESENT	0
25449	24530	01007L	PARTICIPANT	\N	PRESENT	0
25450	24530	11035H	PARTICIPANT	\N	PRESENT	0
25451	24530	01044R	PARTICIPANT	\N	PRESENT	0
25452	24530	14033T	PARTICIPANT	\N	PRESENT	0
25453	24530	14059S	PARTICIPANT	\N	PRESENT	0
25454	24530	14081Q	PARTICIPANT	\N	PRESENT	0
25455	24530	14031R	PARTICIPANT	\N	PRESENT	0
25456	24530	14073Q	PARTICIPANT	\N	PRESENT	0
25457	24530	14237S	PARTICIPANT	\N	PRESENT	0
25458	24530	04057K	PARTICIPANT	\N	PRESENT	0
25459	24530	11066Q	PARTICIPANT	\N	PRESENT	0
25460	24530	11039M	PARTICIPANT	\N	PRESENT	0
25461	24530	14229S	PARTICIPANT	\N	PRESENT	0
25462	24530	07026Q	PARTICIPANT	\N	PRESENT	0
25463	24530	14235Q	PARTICIPANT	\N	PRESENT	0
25464	24530	14063N	PARTICIPANT	\N	PRESENT	0
25465	24530	14030Q	PARTICIPANT	\N	PRESENT	0
25466	24530	14219Q	PARTICIPANT	\N	PRESENT	0
25467	24530	11029K	PARTICIPANT	\N	PRESENT	0
25635	25623	92020L	PARTICIPANT	\N	PRESENT	0
25636	25623	95030B	PARTICIPANT	\N	PRESENT	0
26141	25239	04081K	PARTICIPANT	\N	PRESENT	0
26142	25239	08017T	PARTICIPANT	\N	PRESENT	0
26143	25239	11036J	PARTICIPANT	\N	PRESENT	0
25640	25623	08065C	PARTICIPANT	\N	PRESENT	0
25641	25623	04035D	PARTICIPANT	\N	PRESENT	0
25642	25623	07024N	PRESIDENT	0	PRESENT	0
26144	25239	11035H	PARTICIPANT	\N	PRESENT	0
25644	25623	14014Q	PARTICIPANT	\N	PRESENT	0
25645	25623	11015D	PARTICIPANT	\N	PRESENT	0
25646	25623	07004J	PARTICIPANT	\N	PRESENT	0
25647	25623	95035G	PARTICIPANT	\N	PRESENT	0
25648	25623	08056B	PARTICIPANT	\N	PRESENT	0
26145	25239	14269B	PARTICIPANT	\N	PRESENT	0
25650	25623	98022P	PARTICIPANT	\N	PRESENT	0
25651	25623	11064N	PARTICIPANT	\N	PRESENT	0
26146	25239	11040E	PARTICIPANT	\N	PRESENT	0
25653	25623	04078Q	PARTICIPANT	\N	PRESENT	0
25654	25623	14097Y	PARTICIPANT	\N	PRESENT	0
26147	25239	11037K	PARTICIPANT	\N	PRESENT	0
25656	25623	04036E	PARTICIPANT	\N	PRESENT	0
26148	25239	11033F	PARTICIPANT	\N	PRESENT	0
25658	25623	04077P	PARTICIPANT	\N	PRESENT	0
26149	25239	14219Q	PARTICIPANT	\N	PRESENT	0
25660	25623	92031P	PARTICIPANT	\N	PRESENT	0
25661	25623	11106F	PARTICIPANT	\N	PRESENT	0
25662	25623	14251Q	PARTICIPANT	\N	PRESENT	0
26150	25239	01024M	PARTICIPANT	\N	PRESENT	0
25664	25623	08053X	PARTICIPANT	\N	PRESENT	0
25665	25623	11082Q	PARTICIPANT	\N	PRESENT	0
25666	25623	11105E	PARTICIPANT	\N	EXCUSE	0
25667	25623	14253S	PARTICIPANT	\N	PRESENT	0
25668	25623	08047A	PARTICIPANT	\N	PRESENT	0
25669	25623	14028W	PARTICIPANT	\N	PRESENT	0
25670	25623	14193X	PARTICIPANT	\N	PRESENT	0
25671	25623	98021N	PARTICIPANT	\N	PRESENT	0
26158	25239	14197C	PARTICIPANT	\N	PRESENT	0
25673	25623	04080J	PARTICIPANT	\N	PRESENT	0
26151	25239	07034Q	PARTICIPANT	\N	PRESENT	0
26152	25239	08041T	PARTICIPANT	\N	PRESENT	0
25676	25623	01014K	PARTICIPANT	\N	PRESENT	0
25677	25623	11054L	PARTICIPANT	\N	PRESENT	0
25678	25623	01056V	PARTICIPANT	\N	PRESENT	0
25679	25623	92044U	PARTICIPANT	\N	PRESENT	0
26153	25239	08019V	PARTICIPANT	\N	PRESENT	0
26154	25239	11103C	PARTICIPANT	\N	PRESENT	0
26155	25239	14259Y	PARTICIPANT	\N	PRESENT	0
26156	25239	11064N	PARTICIPANT	\N	PRESENT	0
26157	25239	08031R	PARTICIPANT	\N	PRESENT	0
26159	25239	98050T	PARTICIPANT	\N	PRESENT	0
26160	25239	01019Q	PARTICIPANT	\N	PRESENT	0
26161	25239	14249W	PARTICIPANT	\N	PRESENT	0
26162	25239	14217N	PARTICIPANT	\N	PRESENT	0
26163	25239	14263U	PARTICIPANT	\N	PRESENT	0
26164	25239	11091R	PARTICIPANT	\N	PRESENT	0
26165	25239	04045F	PARTICIPANT	\N	PRESENT	0
26166	25239	11011M	PARTICIPANT	\N	PRESENT	0
26167	25239	11012A	PARTICIPANT	\N	PRESENT	0
26168	25239	11107G	PARTICIPANT	\N	PRESENT	0
26209	25239	14147R	PARTICIPANT	\N	PRESENT	0
26210	25239	14042U	PARTICIPANT	\N	PRESENT	0
26211	25239	14071N	PARTICIPANT	\N	PRESENT	0
26212	25239	14205J	PARTICIPANT	\N	PRESENT	0
26336	25240	80013X	PARTICIPANT	\N	PRESENT	0
26337	25240	11036J	PARTICIPANT	\N	PRESENT	0
26338	25240	11037K	PARTICIPANT	\N	PRESENT	0
26339	25240	11064N	PARTICIPANT	\N	PRESENT	0
26340	25240	11103C	PARTICIPANT	\N	PRESENT	0
26341	25240	98050T	PARTICIPANT	\N	PRESENT	0
26342	25240	08019V	PARTICIPANT	\N	PRESENT	0
26343	25240	11011M	PARTICIPANT	\N	PRESENT	0
26344	25240	11012A	PARTICIPANT	\N	PRESENT	0
26345	25240	14205J	PARTICIPANT	\N	PRESENT	0
26346	25240	14103D	PARTICIPANT	\N	PRESENT	0
26347	25240	14030Q	PARTICIPANT	\N	PRESENT	0
26348	25240	07034Q	PARTICIPANT	\N	PRESENT	0
26349	25240	14259Y	PARTICIPANT	\N	PRESENT	0
26368	25241	11012A	PARTICIPANT	\N	PRESENT	0
26369	25241	11100Y	PARTICIPANT	\N	PRESENT	0
26370	25241	09001P	PARTICIPANT	\N	PRESENT	0
26371	25241	04054G	PARTICIPANT	\N	PRESENT	0
26372	25241	11106F	PARTICIPANT	\N	PRESENT	0
26334	25240	04081K	PARTICIPANT	\N	PRESENT	0
26335	25240	04085P	PARTICIPANT	\N	PRESENT	0
26373	25241	11099A	PARTICIPANT	\N	PRESENT	0
26374	25241	14247U	PARTICIPANT	\N	PRESENT	0
26375	25241	04061F	PARTICIPANT	\N	PRESENT	0
26376	25241	14013P	PARTICIPANT	\N	PRESENT	0
26377	25241	08055A	PARTICIPANT	\N	PRESENT	0
26378	25241	14079W	PARTICIPANT	\N	PRESENT	0
26379	25241	14263U	PARTICIPANT	\N	PRESENT	0
26380	25241	11054L	PARTICIPANT	\N	PRESENT	0
26385	25241	14195A	PARTICIPANT	\N	PRESENT	0
26382	25241	14042U	PARTICIPANT	\N	PRESENT	0
26383	25241	14219Q	PARTICIPANT	\N	PRESENT	0
26366	25241	04066L	PARTICIPANT	\N	PRESENT	0
26367	25241	04040A	PARTICIPANT	\N	PRESENT	0
26384	25241	07024N	PARTICIPANT	\N	PRESENT	0
26386	25241	14103D	PARTICIPANT	\N	PRESENT	0
26387	25241	14327T	PARTICIPANT	\N	PRESENT	0
26388	25241	08069G	PARTICIPANT	\N	PRESENT	0
26389	25241	11091R	PARTICIPANT	\N	PRESENT	0
26390	25241	14255U	PARTICIPANT	\N	PRESENT	0
26395	25241	08017T	PARTICIPANT	\N	PRESENT	0
26399	25241	14030Q	PARTICIPANT	\N	PRESENT	0
26400	25241	14034U	PARTICIPANT	\N	PRESENT	0
26401	25241	95035G	PARTICIPANT	\N	PRESENT	0
26402	25241	11076S	PARTICIPANT	\N	PRESENT	0
26403	25241	14083S	PARTICIPANT	\N	PRESENT	0
26404	25241	14205J	PARTICIPANT	\N	PRESENT	0
26405	25241	14269B	PARTICIPANT	\N	PRESENT	0
26406	25241	07026Q	PARTICIPANT	\N	PRESENT	0
26407	25241	98018T	PARTICIPANT	\N	PRESENT	0
26408	25241	11011M	PARTICIPANT	\N	PRESENT	0
26409	25241	11036J	PARTICIPANT	\N	PRESENT	0
26411	25241	14093U	PARTICIPANT	\N	PRESENT	0
26412	25241	14265W	PARTICIPANT	\N	PRESENT	0
26413	25241	11083R	PARTICIPANT	\N	PRESENT	0
26414	25241	08009T	PARTICIPANT	\N	PRESENT	0
26415	25241	01015L	PARTICIPANT	\N	PRESENT	0
26416	25241	14157T	PARTICIPANT	\N	PRESENT	0
26417	25241	11059R	PARTICIPANT	\N	PRESENT	0
26420	25242	04066L	PARTICIPANT	\N	PRESENT	0
26422	25242	11012A	PARTICIPANT	\N	PRESENT	0
26426	25242	11106F	PARTICIPANT	\N	PRESENT	0
26427	25242	11099A	PARTICIPANT	\N	PRESENT	0
26428	25242	14247U	PARTICIPANT	\N	PRESENT	0
26431	25242	08055A	PARTICIPANT	\N	PRESENT	0
26435	25242	14042U	PARTICIPANT	\N	PRESENT	0
26436	25242	14219Q	PARTICIPANT	\N	PRESENT	0
26437	25242	07024N	PARTICIPANT	\N	PRESENT	0
26438	25242	14195A	PARTICIPANT	\N	PRESENT	0
26440	25242	14327T	PARTICIPANT	\N	PRESENT	0
26441	25242	08069G	PARTICIPANT	\N	PRESENT	0
26442	25242	11091R	PARTICIPANT	\N	PRESENT	0
25066	23795	05012A	PARTICIPANT	\N	EXCUSE	0
25162	25161	05008E	PRESIDENT	0	PRESENT	0
25163	25161	14065Q	PARTICIPANT	\N	PRESENT	0
25164	25161	04038G	PARTICIPANT	\N	PRESENT	0
25165	25161	01024M	PARTICIPANT	\N	PRESENT	0
25166	25161	14215L	PARTICIPANT	\N	PRESENT	0
25167	25161	08018U	PARTICIPANT	\N	PRESENT	0
25168	25161	01007L	PARTICIPANT	\N	PRESENT	0
25169	25161	11084S	PARTICIPANT	\N	EXCUSE	0
25173	25161	95049N	PARTICIPANT	\N	PRESENT	0
25171	25161	14273W	PARTICIPANT	\N	PRESENT	0
25172	25161	14147R	PARTICIPANT	\N	PRESENT	0
25174	25161	07034Q	PARTICIPANT	\N	PRESENT	0
25691	25346	11085T	PARTICIPANT	\N	EXCUSE	0
25176	25161	01028R	PARTICIPANT	\N	PRESENT	0
25177	25161	04044E	PARTICIPANT	\N	PRESENT	0
25178	25161	11037K	PARTICIPANT	\N	PRESENT	0
25179	25161	92045V	PARTICIPANT	\N	PRESENT	0
25180	25161	04074L	PARTICIPANT	\N	PRESENT	0
25486	25484	11076S	PARTICIPANT	\N	PRESENT	0
26501	23802	83047W	PARTICIPANT	\N	PRESENT	0
25488	25484	04040A	PARTICIPANT	\N	PRESENT	0
25489	25484	08058D	PARTICIPANT	\N	PRESENT	0
26559	26502	11072N	PARTICIPANT	\N	PRESENT	0
25491	25484	77002U	PARTICIPANT	\N	PRESENT	0
25492	25484	98029W	PARTICIPANT	\N	PRESENT	0
25493	25484	11080N	PARTICIPANT	\N	PRESENT	0
25494	25484	11027H	PARTICIPANT	\N	EXCUSE	0
25495	25484	98018T	PARTICIPANT	\N	EXCUSE	0
25496	25484	92018S	PARTICIPANT	\N	PRESENT	0
25497	25484	92020L	PARTICIPANT	\N	PRESENT	0
25498	25484	95030B	PARTICIPANT	\N	PRESENT	0
26560	26502	07026Q	PARTICIPANT	\N	PRESENT	0
26449	25242	14083S	PARTICIPANT	\N	PRESENT	0
25501	25484	97011G	PARTICIPANT	\N	PRESENT	0
25502	25484	08065C	PARTICIPANT	\N	PRESENT	0
25503	25484	04035D	PARTICIPANT	\N	PRESENT	0
25504	25484	07024N	PRESIDENT	0	PRESENT	0
26561	26502	04074L	PARTICIPANT	\N	PRESENT	0
25506	25484	14014Q	PARTICIPANT	\N	PRESENT	0
25507	25484	11015D	PARTICIPANT	\N	PRESENT	0
25508	25484	07004J	PARTICIPANT	\N	PRESENT	0
25509	25484	95035G	PARTICIPANT	\N	PRESENT	0
25510	25484	08056B	PARTICIPANT	\N	PRESENT	0
25511	25484	14211G	PARTICIPANT	\N	PRESENT	0
25512	25484	98022P	PARTICIPANT	\N	PRESENT	0
25513	25484	11064N	PARTICIPANT	\N	PRESENT	0
26562	26502	11098Y	PARTICIPANT	\N	PRESENT	0
25515	25484	04078Q	PARTICIPANT	\N	PRESENT	0
25516	25484	14097Y	PARTICIPANT	\N	PRESENT	0
26563	26502	01028R	PARTICIPANT	\N	PRESENT	0
25518	25484	04036E	PARTICIPANT	\N	PRESENT	0
26564	26502	11029K	PARTICIPANT	\N	PRESENT	0
26454	25242	11011M	PARTICIPANT	\N	PRESENT	0
26455	25242	11036J	PARTICIPANT	\N	PRESENT	0
25522	25484	92031P	PARTICIPANT	\N	PRESENT	0
25523	25484	11106F	PARTICIPANT	\N	PRESENT	0
25524	25484	14251Q	PARTICIPANT	\N	PRESENT	0
26565	26502	11011M	PARTICIPANT	\N	PRESENT	0
25526	25484	08053X	PARTICIPANT	\N	PRESENT	0
25527	25484	11082Q	PARTICIPANT	\N	PRESENT	0
25528	25484	11105E	PARTICIPANT	\N	EXCUSE	0
25529	25484	14253S	PARTICIPANT	\N	PRESENT	0
25530	25484	08047A	PARTICIPANT	\N	PRESENT	0
25531	25484	14028W	PARTICIPANT	\N	PRESENT	0
25532	25484	14193X	PARTICIPANT	\N	PRESENT	0
25533	25484	98021N	PARTICIPANT	\N	PRESENT	0
26566	26502	04085P	PARTICIPANT	\N	PRESENT	0
25535	25484	04080J	PARTICIPANT	\N	PRESENT	0
26457	25242	14265W	PARTICIPANT	\N	PRESENT	0
26567	26502	14069U	PARTICIPANT	\N	PRESENT	0
25538	25484	01014K	PARTICIPANT	\N	PRESENT	0
25539	25484	11054L	PARTICIPANT	\N	PRESENT	0
25540	25484	01056V	PARTICIPANT	\N	PRESENT	0
25541	25484	92044U	PARTICIPANT	\N	PRESENT	0
25542	25484	08049C	PARTICIPANT	\N	PRESENT	0
26568	26502	01022K	PARTICIPANT	\N	PRESENT	0
26460	25242	01015L	PARTICIPANT	\N	PRESENT	0
26461	25242	14157T	PARTICIPANT	\N	PRESENT	0
26462	25242	11059R	PARTICIPANT	\N	PRESENT	0
26569	26502	14051J	PARTICIPANT	\N	PRESENT	0
26570	26502	14135M	PARTICIPANT	\N	PRESENT	0
26571	26502	07024N	PARTICIPANT	\N	PRESENT	0
26573	26502	11091R	PARTICIPANT	\N	PRESENT	0
26574	26502	01003G	PARTICIPANT	\N	PRESENT	0
26575	26502	14107H	PARTICIPANT	\N	PRESENT	0
26576	26502	04070G	PARTICIPANT	\N	PRESENT	0
26577	26572	01024M	PARTICIPANT	\N	EXCUSE	0
26578	26572	08018U	PARTICIPANT	\N	PRESENT	0
26579	26572	11072N	PARTICIPANT	\N	PRESENT	0
26580	26572	04074L	PARTICIPANT	\N	PRESENT	0
26581	26572	01028R	PRESIDENT	0	PRESENT	0
26582	26502	11107G	PARTICIPANT	\N	PRESENT	0
26583	26502	11103C	PARTICIPANT	\N	PRESENT	0
26584	26502	11065P	PARTICIPANT	\N	PRESENT	0
26585	26502	05012A	PARTICIPANT	\N	PRESENT	0
26557	26502	98053W	PARTICIPANT	\N	PRESENT	0
26558	26502	14179A	PARTICIPANT	\N	PRESENT	0
26586	26502	99004R	PARTICIPANT	\N	PRESENT	0
26587	26502	14031R	PARTICIPANT	\N	PRESENT	0
26589	26588	11095V	PARTICIPANT	\N	EXCUSE	0
26590	26588	11065P	PARTICIPANT	\N	PRESENT	0
26591	26588	01015L	PARTICIPANT	\N	EXCUSE	0
26592	26588	11107G	PRESIDENT	0	PRESENT	0
26593	26588	01022K	PARTICIPANT	\N	PRESENT	0
26594	26588	08009T	PARTICIPANT	\N	EXCUSE	0
26595	26588	14221J	PARTICIPANT	\N	PRESENT	0
26596	26588	92039X	PARTICIPANT	\N	EXCUSE	0
26597	26588	14169X	PARTICIPANT	\N	EXCUSE	0
26598	26588	14135M	PARTICIPANT	\N	PRESENT	0
26599	26588	14107H	PARTICIPANT	\N	PRESENT	0
26600	26588	14051J	PARTICIPANT	\N	PRESENT	0
26601	26588	96003C	PARTICIPANT	\N	EXCUSE	0
26602	26502	95041E	PARTICIPANT	\N	PRESENT	0
26603	26588	05012A	PARTICIPANT	\N	EXCUSE	0
26604	26502	14221J	PARTICIPANT	\N	PRESENT	0
26633	26503	11098Y	PARTICIPANT	\N	PRESENT	0
26634	26503	01022K	PARTICIPANT	\N	PRESENT	0
26635	26503	11065P	PARTICIPANT	\N	PRESENT	0
26636	26503	01003G	PARTICIPANT	\N	PRESENT	0
26637	26503	14221J	PARTICIPANT	\N	PRESENT	0
26638	26503	14051J	PARTICIPANT	\N	PRESENT	0
26639	26503	14107H	PARTICIPANT	\N	PRESENT	0
26640	26503	05012A	PARTICIPANT	\N	PRESENT	0
26641	26503	14031R	PARTICIPANT	\N	PRESENT	0
26642	26503	14069U	PARTICIPANT	\N	PRESENT	0
26643	26503	95041E	PARTICIPANT	\N	PRESENT	0
26644	26503	11107G	PARTICIPANT	\N	PRESENT	0
26645	26503	80013X	PARTICIPANT	\N	PRESENT	0
26646	26503	11094U	PARTICIPANT	\N	PRESENT	0
26647	26503	14179A	PARTICIPANT	\N	PRESENT	0
26793	26522	04044E	PARTICIPANT	\N	PRESENT	0
26794	26522	11094U	PARTICIPANT	\N	PRESENT	0
26795	26522	14018U	PARTICIPANT	\N	PRESENT	0
26796	26522	01003G	PARTICIPANT	\N	PRESENT	0
26797	26522	14207L	PARTICIPANT	\N	PRESENT	0
26798	26522	14107H	PARTICIPANT	\N	PRESENT	0
26799	26522	14109K	PARTICIPANT	\N	PRESENT	0
26800	26522	14159V	PARTICIPANT	\N	PRESENT	0
26801	26522	01027Q	PARTICIPANT	\N	PRESENT	0
26802	26522	08056B	PARTICIPANT	\N	PRESENT	0
26803	26522	99004R	PARTICIPANT	\N	PRESENT	0
26631	26503	98053W	PARTICIPANT	\N	PRESENT	0
26632	26503	14135M	PARTICIPANT	\N	PRESENT	0
26804	26522	14089Y	PARTICIPANT	\N	PRESENT	0
26805	26522	14223L	PARTICIPANT	\N	PRESENT	0
26807	26522	14205J	PARTICIPANT	\N	PRESENT	0
26808	26522	98018T	PARTICIPANT	\N	PRESENT	0
26809	26522	14042U	PARTICIPANT	\N	PRESENT	0
26810	26522	14221J	PARTICIPANT	\N	PRESENT	0
26811	26522	11093T	PARTICIPANT	\N	PRESENT	0
26812	26522	92031P	PARTICIPANT	\N	PRESENT	0
26813	26522	04086Q	PARTICIPANT	\N	PRESENT	0
26814	26522	14083S	PARTICIPANT	\N	PRESENT	0
26815	26522	04033B	PARTICIPANT	\N	PRESENT	0
26816	26522	04040A	PARTICIPANT	\N	PRESENT	0
26817	26522	08044W	PARTICIPANT	\N	PRESENT	0
26818	26522	08039A	PARTICIPANT	\N	PRESENT	0
26819	26522	14073Q	PARTICIPANT	\N	PRESENT	0
26820	26522	08034U	PARTICIPANT	\N	PRESENT	0
26821	26522	08010L	PARTICIPANT	\N	PRESENT	0
26822	26522	04070G	PARTICIPANT	\N	PRESENT	0
26823	26522	80013X	PARTICIPANT	\N	PRESENT	0
26824	26522	08028W	PARTICIPANT	\N	PRESENT	0
26825	26522	14215L	PARTICIPANT	\N	PRESENT	0
26826	26522	01025N	PARTICIPANT	\N	PRESENT	0
26827	26522	10015M	PARTICIPANT	\N	PRESENT	0
26828	26522	11100Y	PARTICIPANT	\N	PRESENT	0
26829	26522	11048N	PARTICIPANT	\N	PRESENT	0
25603	24530	08068F	PARTICIPANT	\N	PRESENT	0
25604	24530	14147R	PARTICIPANT	\N	PRESENT	0
25605	24530	98050T	PARTICIPANT	\N	PRESENT	0
25606	24530	08043V	PARTICIPANT	\N	PRESENT	0
25607	24530	08017T	PARTICIPANT	\N	PRESENT	0
25608	24530	14111D	PARTICIPANT	\N	PRESENT	0
25609	24530	14061L	PARTICIPANT	\N	PRESENT	0
25610	24530	14079W	PARTICIPANT	\N	PRESENT	0
25611	24530	14026U	PARTICIPANT	\N	PRESENT	0
25612	24530	04059M	PARTICIPANT	\N	PRESENT	0
25613	24530	14187A	PARTICIPANT	\N	PRESENT	0
25614	24530	11036J	PARTICIPANT	\N	PRESENT	0
25615	24530	14205J	PARTICIPANT	\N	PRESENT	0
25616	24530	14267Y	PARTICIPANT	\N	PRESENT	0
25617	24530	04088S	PARTICIPANT	\N	PRESENT	0
25618	24530	14109K	PARTICIPANT	\N	PRESENT	0
25619	24530	14241N	PARTICIPANT	\N	PRESENT	0
25620	24530	14265W	PARTICIPANT	\N	PRESENT	0
25621	24530	04047H	PARTICIPANT	\N	PRESENT	0
25622	24530	14071N	PARTICIPANT	\N	PRESENT	0
26170	26169	14261S	PARTICIPANT	\N	PRESENT	0
26171	26169	08055A	PARTICIPANT	\N	PRESENT	0
26172	26169	14093U	PARTICIPANT	\N	PRESENT	0
26173	26169	14030Q	PARTICIPANT	\N	PRESENT	0
26174	26169	96004D	PARTICIPANT	\N	PRESENT	0
26175	26169	08060W	PARTICIPANT	\N	PRESENT	0
26214	26213	14261S	PARTICIPANT	\N	PRESENT	0
26177	26169	11095V	PARTICIPANT	\N	PRESENT	0
26178	26169	14038Y	PARTICIPANT	\N	PRESENT	0
26215	26213	08055A	PARTICIPANT	\N	PRESENT	0
26180	26169	98023Q	PARTICIPANT	\N	PRESENT	0
26181	26169	11065P	PARTICIPANT	\N	PRESENT	0
26182	26169	01015L	PARTICIPANT	\N	PRESENT	0
26183	26169	11107G	PARTICIPANT	\N	PRESENT	0
26698	26696	05008E	PARTICIPANT	\N	PRESENT	0
26185	26169	02002K	PARTICIPANT	\N	EXCUSE	0
26186	26169	01022K	PARTICIPANT	\N	PRESENT	0
26187	26169	04097T	PARTICIPANT	\N	PRESENT	0
26188	26169	09001P	PARTICIPANT	\N	PRESENT	0
26189	26169	11059R	PARTICIPANT	\N	PRESENT	0
26190	26169	14219Q	PARTICIPANT	\N	PRESENT	0
26191	26169	80027E	PARTICIPANT	\N	EXCUSE	0
26192	26169	14031R	PARTICIPANT	\N	PRESENT	0
26193	26169	08009T	PRESIDENT	0	PRESENT	0
26194	26169	08062Y	PARTICIPANT	\N	PRESENT	0
26195	26169	14221J	PARTICIPANT	\N	PRESENT	0
26196	26169	92039X	PARTICIPANT	\N	PRESENT	0
26197	26169	08042U	PARTICIPANT	\N	EXCUSE	0
26198	26169	14169X	PARTICIPANT	\N	PRESENT	0
26199	26169	14237S	PARTICIPANT	\N	PRESENT	0
26200	26169	13002U	PARTICIPANT	\N	PRESENT	0
26201	26169	05012A	PARTICIPANT	\N	PRESENT	0
26699	26696	11033F	PARTICIPANT	\N	PRESENT	0
26203	26169	14135M	PARTICIPANT	\N	PRESENT	0
26204	26169	95062K	PARTICIPANT	\N	EXCUSE	0
26205	26169	14107H	PARTICIPANT	\N	PRESENT	0
26206	26169	14051J	PARTICIPANT	\N	PRESENT	0
26207	26169	14157T	PARTICIPANT	\N	PRESENT	0
26208	26169	96003C	PARTICIPANT	\N	EXCUSE	0
26217	26213	14030Q	PARTICIPANT	\N	PRESENT	0
26255	26213	14179A	PARTICIPANT	\N	PRESENT	0
26697	26696	04085P	PARTICIPANT	\N	PRESENT	0
26700	26696	14069U	PARTICIPANT	\N	PRESENT	0
26221	26213	11095V	PARTICIPANT	\N	PRESENT	0
26222	26213	14038Y	PARTICIPANT	\N	PRESENT	0
26701	26696	04047H	PARTICIPANT	\N	PRESENT	0
26224	26213	98023Q	PARTICIPANT	\N	PRESENT	0
26225	26213	11065P	PARTICIPANT	\N	PRESENT	0
26226	26213	01015L	PARTICIPANT	\N	PRESENT	0
26227	26213	11107G	PARTICIPANT	\N	PRESENT	0
26702	26696	11035H	PARTICIPANT	\N	PRESENT	0
26229	26213	02002K	PARTICIPANT	\N	PRESENT	0
26703	26696	01024M	PARTICIPANT	\N	PRESENT	0
26231	26213	04097T	PARTICIPANT	\N	PRESENT	0
26704	26696	14215L	PARTICIPANT	\N	PRESENT	0
26705	26696	11034G	PARTICIPANT	\N	PRESENT	0
26234	26213	14219Q	PARTICIPANT	\N	PRESENT	0
26235	26213	80027E	PARTICIPANT	\N	EXCUSE	0
26236	26213	14031R	PARTICIPANT	\N	PRESENT	0
26237	26213	08009T	PRESIDENT	0	PRESENT	0
26706	26696	01007L	PARTICIPANT	\N	PRESENT	0
26707	26696	04079R	PARTICIPANT	\N	PRESENT	0
26240	26213	92039X	PARTICIPANT	\N	EXCUSE	0
26241	26213	08042U	PARTICIPANT	\N	EXCUSE	0
26242	26213	14169X	PARTICIPANT	\N	PRESENT	0
26708	26696	14111D	PARTICIPANT	\N	PRESENT	0
26244	26213	13002U	PARTICIPANT	\N	PRESENT	0
26245	26213	05012A	PARTICIPANT	\N	PRESENT	0
26247	26213	14135M	PARTICIPANT	\N	PRESENT	0
26248	26213	95062K	PARTICIPANT	\N	EXCUSE	0
26710	26696	11072N	PARTICIPANT	\N	PRESENT	0
26250	26213	14051J	PARTICIPANT	\N	PRESENT	0
26251	26213	14157T	PARTICIPANT	\N	PRESENT	0
26252	26213	96003C	PARTICIPANT	\N	EXCUSE	0
26711	26696	07034Q	PARTICIPANT	\N	PRESENT	0
26712	26696	04074L	PARTICIPANT	\N	PRESENT	0
26713	26696	95063L	PARTICIPANT	\N	PRESENT	0
26714	26696	01028R	PARTICIPANT	\N	PRESENT	0
26715	26696	04056J	PARTICIPANT	\N	PRESENT	0
26716	26696	04044E	PRESIDENT	0	PRESENT	0
26717	26696	11037K	PARTICIPANT	\N	PRESENT	0
26718	26696	92045V	PARTICIPANT	\N	PRESENT	0
26719	26696	14147R	PARTICIPANT	\N	PRESENT	0
26720	26696	08018U	PARTICIPANT	\N	PRESENT	0
26830	26522	11057P	PARTICIPANT	\N	PRESENT	0
27063	24345	96003C	PARTICIPANT	\N	EXCUSE	0
27064	24344	98005N	PARTICIPANT	\N	EXCUSE	0
27065	24345	98005N	PARTICIPANT	\N	EXCUSE	0
27084	27067	01007L	PARTICIPANT	\N	PRESENT	0
27089	27067	11039M	PARTICIPANT	\N	PRESENT	0
27090	27067	04088S	PARTICIPANT	\N	PRESENT	0
27092	27091	89017R	PARTICIPANT	\N	PRESENT	0
27093	27091	01031L	PRESIDENT	0	PRESENT	0
27094	27091	05004A	PARTICIPANT	\N	PRESENT	0
27095	27091	01013J	PARTICIPANT	\N	PRESENT	0
27096	27091	11068S	PARTICIPANT	\N	PRESENT	0
27097	27091	11040E	PARTICIPANT	\N	PRESENT	0
27141	27091	04038G	RAPPORTEUR_AVIS	\N	PRESENT	0
27099	27091	14167V	PARTICIPANT	\N	PRESENT	0
27100	27091	14175V	PARTICIPANT	\N	PRESENT	0
27101	27091	14083S	PARTICIPANT	\N	PRESENT	0
27103	27091	14085U	PARTICIPANT	\N	PRESENT	0
27104	27091	11042G	PARTICIPANT	\N	PRESENT	0
27106	27091	04086Q	PARTICIPANT	\N	PRESENT	0
27108	27091	11070L	PARTICIPANT	\N	PRESENT	0
27109	27091	11088W	PARTICIPANT	\N	PRESENT	0
27110	27091	14327T	PARTICIPANT	\N	PRESENT	0
27111	27091	08022Q	PARTICIPANT	\N	PRESENT	0
27112	27091	01027Q	PARTICIPANT	\N	PRESENT	0
27113	27091	04071H	PARTICIPANT	\N	PRESENT	0
27114	27091	11074Q	PARTICIPANT	\N	PRESENT	0
27115	27091	98053W	PARTICIPANT	\N	PRESENT	0
27116	27091	11083R	PARTICIPANT	\N	PRESENT	0
27061	24344	96003C	PARTICIPANT	\N	EXCUSE	0
27062	24344	14017T	PARTICIPANT	\N	EXCUSE	0
27118	27091	01057W	PARTICIPANT	\N	PRESENT	0
27119	27091	08016S	PARTICIPANT	\N	PRESENT	0
27148	27142	01044R	PARTICIPANT	\N	PRESENT	0
27122	27091	99004R	PARTICIPANT	\N	PRESENT	0
27123	27091	04061F	PARTICIPANT	\N	PRESENT	0
27124	27091	14159V	PARTICIPANT	\N	PRESENT	0
27125	27091	07029T	PARTICIPANT	\N	PRESENT	0
27149	27142	08043V	PARTICIPANT	\N	PRESENT	0
27127	27091	08010L	PARTICIPANT	\N	PRESENT	0
27128	27091	08034U	PARTICIPANT	\N	PRESENT	0
27129	27091	01048V	PARTICIPANT	\N	PRESENT	0
27130	27091	98046X	PARTICIPANT	\N	PRESENT	0
27131	27091	11085T	PARTICIPANT	\N	PRESENT	0
27132	27091	08011M	PARTICIPANT	\N	EXCUSE	0
27133	27091	08073C	PARTICIPANT	\N	PRESENT	0
27134	27091	08061X	PARTICIPANT	\N	PRESENT	0
27150	27142	14089Y	PARTICIPANT	\N	PRESENT	0
27136	27091	14225N	PARTICIPANT	\N	PRESENT	0
27137	27091	11012A	PARTICIPANT	\N	PRESENT	0
27138	27091	11057P	PARTICIPANT	\N	PRESENT	0
27139	27091	14173T	PARTICIPANT	\N	PRESENT	0
27140	27091	04034C	PARTICIPANT	\N	PRESENT	0
27151	27142	14105F	PARTICIPANT	\N	PRESENT	0
27152	27142	11029K	PARTICIPANT	\N	EXCUSE	0
27153	27142	95015C	PARTICIPANT	\N	PRESENT	0
25159	24344	14201E	PARTICIPANT	\N	EXCUSE	0
25160	24345	14201E	PARTICIPANT	\N	EXCUSE	0
25468	24530	08012N	PARTICIPANT	\N	PRESENT	0
25469	24530	08056B	PARTICIPANT	\N	PRESENT	0
25470	24530	88008L	PARTICIPANT	\N	PRESENT	0
25471	24530	14215L	PARTICIPANT	\N	PRESENT	0
25472	24530	14103D	PARTICIPANT	\N	PRESENT	0
25473	24530	14249W	PARTICIPANT	\N	PRESENT	0
25474	24530	11014C	PARTICIPANT	\N	PRESENT	0
25475	24530	14259Y	PARTICIPANT	\N	PRESENT	0
25477	24530	08051V	PARTICIPANT	\N	PRESENT	0
25478	24530	14089Y	PARTICIPANT	\N	PRESENT	0
25479	24530	14273W	PARTICIPANT	\N	PRESENT	0
25480	24530	11011M	PARTICIPANT	\N	PRESENT	0
25481	24530	11037K	PARTICIPANT	\N	PRESENT	0
25482	24530	11091R	PARTICIPANT	\N	PRESENT	0
25483	24530	11043H	PARTICIPANT	\N	PRESENT	0
25485	24530	04070G	PARTICIPANT	\N	PRESENT	0
25543	24530	11098Y	PARTICIPANT	\N	PRESENT	0
25544	24530	08031R	PARTICIPANT	\N	PRESENT	0
25545	24530	14087W	PARTICIPANT	\N	PRESENT	0
25681	24530	14105F	PARTICIPANT	\N	PRESENT	0
25682	24530	95030B	PARTICIPANT	\N	PRESENT	0
25683	24530	14269B	PARTICIPANT	\N	PRESENT	0
25684	24530	14263U	PARTICIPANT	\N	PRESENT	0
25685	24530	11040E	PARTICIPANT	\N	PRESENT	0
25686	24530	14018U	PARTICIPANT	\N	PRESENT	0
25687	24530	14209N	PARTICIPANT	\N	PRESENT	0
25690	24530	14069U	PARTICIPANT	\N	PRESENT	0
25692	24530	11012A	PARTICIPANT	\N	PRESENT	0
25693	24530	11089X	PARTICIPANT	\N	PRESENT	0
25694	24530	11104D	PARTICIPANT	\N	PRESENT	0
25695	24530	14133K	PARTICIPANT	\N	PRESENT	0
25696	24530	95035G	PARTICIPANT	\N	PRESENT	0
25697	24530	04085P	PARTICIPANT	\N	PRESENT	0
25698	24530	04049K	PARTICIPANT	\N	PRESENT	0
25699	24530	08053X	PARTICIPANT	\N	PRESENT	0
25700	24530	01015L	PARTICIPANT	\N	PRESENT	0
25701	24530	08016S	PARTICIPANT	\N	PRESENT	0
25702	24530	14173T	PARTICIPANT	\N	PRESENT	0
25703	24530	11042G	PARTICIPANT	\N	PRESENT	0
25727	24530	80013X	PARTICIPANT	\N	PRESENT	0
25739	24530	14157T	PARTICIPANT	\N	PRESENT	0
25749	24530	14261S	PARTICIPANT	\N	PRESENT	0
25751	24530	14051J	PARTICIPANT	\N	PRESENT	0
25752	24530	13002U	PARTICIPANT	\N	PRESENT	0
25753	24530	11095V	PARTICIPANT	\N	PRESENT	0
25754	24530	14159V	PARTICIPANT	\N	PRESENT	0
25755	24530	14257W	PARTICIPANT	\N	PRESENT	0
25756	24530	05012A	PARTICIPANT	\N	PRESENT	0
25757	24530	08024S	PARTICIPANT	\N	PRESENT	0
25758	24530	07029T	PARTICIPANT	\N	PRESENT	0
25759	24530	07032N	PARTICIPANT	\N	PRESENT	0
25760	24530	11081P	PARTICIPANT	\N	PRESENT	0
25761	24530	08058D	PARTICIPANT	\N	PRESENT	0
25762	24530	14225N	PARTICIPANT	\N	PRESENT	0
25763	24530	11111C	PARTICIPANT	\N	PRESENT	0
25764	24530	08014Q	PARTICIPANT	\N	PRESENT	0
25765	24530	11103C	PARTICIPANT	\N	PRESENT	0
25766	24530	98023Q	PARTICIPANT	\N	PRESENT	0
25767	24530	99004R	PARTICIPANT	\N	PRESENT	0
25768	24530	08018U	PARTICIPANT	\N	PRESENT	0
25769	25484	95059Q	PARTICIPANT	\N	EXCUSE	0
25770	25623	95059Q	PARTICIPANT	\N	EXCUSE	0
25771	24530	04044E	PARTICIPANT	\N	PRESENT	0
25772	24530	11064N	PARTICIPANT	\N	PRESENT	0
25773	24530	11059R	PARTICIPANT	\N	PRESENT	0
25774	24530	14038Y	PARTICIPANT	\N	PRESENT	0
25840	24531	01007L	PARTICIPANT	\N	PRESENT	0
25842	24531	08018U	PARTICIPANT	\N	PRESENT	0
25843	24531	14157T	PARTICIPANT	\N	PRESENT	0
25844	24531	14033T	PARTICIPANT	\N	PRESENT	0
25845	24531	04088S	PARTICIPANT	\N	PRESENT	0
25871	24531	14265W	PARTICIPANT	\N	PRESENT	0
25847	24531	04049K	PARTICIPANT	\N	PRESENT	0
25848	24531	11100Y	PARTICIPANT	\N	PRESENT	0
25849	24531	11103C	PARTICIPANT	\N	PRESENT	0
25850	24531	05012A	PARTICIPANT	\N	PRESENT	0
25851	24531	14273W	PARTICIPANT	\N	PRESENT	0
25852	24531	04047H	PARTICIPANT	\N	PRESENT	0
25853	24531	14205J	PARTICIPANT	\N	PRESENT	0
25854	24531	14079W	PARTICIPANT	\N	PRESENT	0
25855	24531	14261S	PARTICIPANT	\N	PRESENT	0
25856	24531	01044R	PARTICIPANT	\N	PRESENT	0
25857	24531	14159V	PARTICIPANT	\N	PRESENT	0
25858	24531	11099A	PARTICIPANT	\N	PRESENT	0
25859	24531	01031L	PARTICIPANT	\N	PRESENT	0
25860	24531	11104D	PARTICIPANT	\N	PRESENT	0
25861	24531	08068F	PARTICIPANT	\N	PRESENT	0
25862	24531	14001X	PARTICIPANT	\N	PRESENT	0
25863	24531	14151M	PARTICIPANT	\N	PRESENT	0
25864	24531	08014Q	PARTICIPANT	\N	PRESENT	0
25865	24531	11036J	PARTICIPANT	\N	PRESENT	0
25866	24531	01015L	PARTICIPANT	\N	PRESENT	0
25867	24531	14263U	PARTICIPANT	\N	PRESENT	0
25868	24531	11040E	PARTICIPANT	\N	PRESENT	0
25869	24531	80013X	PARTICIPANT	\N	PRESENT	0
25870	24531	86044G	PARTICIPANT	\N	PRESENT	0
25872	24531	08049C	PARTICIPANT	\N	PRESENT	0
25873	24531	14225N	PARTICIPANT	\N	PRESENT	0
25874	24531	11077T	PARTICIPANT	\N	PRESENT	0
25875	24531	11091R	PARTICIPANT	\N	PRESENT	0
25926	24531	04033B	PARTICIPANT	\N	PRESENT	0
25927	24531	11098Y	PARTICIPANT	\N	PRESENT	0
25928	24531	14237S	PARTICIPANT	\N	PRESENT	0
25929	24531	14197C	PARTICIPANT	\N	PRESENT	0
25931	24531	14247U	PARTICIPANT	\N	PRESENT	0
25932	24531	14219Q	PARTICIPANT	\N	PRESENT	0
25933	24531	08053X	PARTICIPANT	\N	PRESENT	0
25934	24531	08034U	PARTICIPANT	\N	PRESENT	0
25935	24531	08051V	PARTICIPANT	\N	PRESENT	0
25936	24531	01047U	PARTICIPANT	\N	PRESENT	0
25937	24531	08055A	PARTICIPANT	\N	PRESENT	0
25938	24531	11107G	PARTICIPANT	\N	PRESENT	0
25939	24531	11026G	PARTICIPANT	\N	PRESENT	0
25940	24531	14030Q	PARTICIPANT	\N	PRESENT	0
25992	24532	01015L	PARTICIPANT	\N	PRESENT	0
25993	24532	11098Y	PARTICIPANT	\N	PRESENT	0
25994	24532	11107G	PARTICIPANT	\N	PRESENT	0
25995	24532	11077T	PARTICIPANT	\N	PRESENT	0
25996	24532	11036J	PARTICIPANT	\N	PRESENT	0
25997	24532	08053X	PARTICIPANT	\N	PRESENT	0
25998	24532	08055A	PARTICIPANT	\N	PRESENT	0
25999	24532	11026G	PARTICIPANT	\N	PRESENT	0
26000	24532	11065P	PARTICIPANT	\N	PRESENT	0
26001	24532	01044R	PARTICIPANT	\N	PRESENT	0
26002	24532	11099A	PARTICIPANT	\N	PRESENT	0
26003	24532	11055M	PARTICIPANT	\N	PRESENT	0
26004	24532	11110B	PARTICIPANT	\N	PRESENT	0
26005	24532	14030Q	PARTICIPANT	\N	PRESENT	0
26006	24532	14219Q	PARTICIPANT	\N	PRESENT	0
26007	24532	14205J	PARTICIPANT	\N	PRESENT	0
26008	24532	08009T	PARTICIPANT	\N	PRESENT	0
25841	24531	04044E	PARTICIPANT	\N	PRESENT	0
26009	24532	14237S	PARTICIPANT	\N	PRESENT	0
26010	24532	04061F	PARTICIPANT	\N	PRESENT	0
26015	24532	04049K	PARTICIPANT	\N	PRESENT	0
26012	24532	05012A	PARTICIPANT	\N	PRESENT	0
26013	24532	08034U	PARTICIPANT	\N	PRESENT	0
26014	24532	14217N	PARTICIPANT	\N	PRESENT	0
26016	24532	14097Y	PARTICIPANT	\N	PRESENT	0
26017	24532	08051V	PARTICIPANT	\N	PRESENT	0
26018	24532	04088S	PARTICIPANT	\N	PRESENT	0
26019	24532	11029K	PARTICIPANT	\N	PRESENT	0
26020	24532	95030B	PARTICIPANT	\N	PRESENT	0
26021	24532	11048N	PARTICIPANT	\N	PRESENT	0
26022	24532	11033F	PARTICIPANT	\N	PRESENT	0
26023	24532	11083R	PARTICIPANT	\N	PRESENT	0
26032	24532	01034P	PARTICIPANT	\N	PRESENT	0
26043	24532	11012A	PARTICIPANT	\N	PRESENT	0
26044	24532	80013X	PARTICIPANT	\N	PRESENT	0
26045	24532	08031R	PARTICIPANT	\N	PRESENT	0
26046	24532	14034U	PARTICIPANT	\N	PRESENT	0
26047	24532	04067M	PARTICIPANT	\N	PRESENT	0
26048	24532	11069T	PARTICIPANT	\N	PRESENT	0
26049	24532	11112D	PARTICIPANT	\N	PRESENT	0
26050	24532	14073Q	PARTICIPANT	\N	PRESENT	0
26051	24532	11076S	PARTICIPANT	\N	PRESENT	0
26052	24532	14033T	PARTICIPANT	\N	PRESENT	0
25990	24532	01007L	PARTICIPANT	\N	PRESENT	0
25991	24532	14263U	PARTICIPANT	\N	PRESENT	0
26099	24546	14229S	PARTICIPANT	\N	PRESENT	0
26100	24546	11083R	PARTICIPANT	\N	PRESENT	0
26101	24546	01044R	PARTICIPANT	\N	PRESENT	0
26102	24546	04067M	PARTICIPANT	\N	PRESENT	0
26103	24546	14073Q	PARTICIPANT	\N	PRESENT	0
26104	24546	04070G	PARTICIPANT	\N	PRESENT	0
26105	24546	11029K	PARTICIPANT	\N	PRESENT	0
26106	24546	08019V	PARTICIPANT	\N	PRESENT	0
26107	24546	04057K	PARTICIPANT	\N	PRESENT	0
26108	24546	04059M	PARTICIPANT	\N	PRESENT	0
26109	24546	14263U	PARTICIPANT	\N	PRESENT	0
26110	24546	14235Q	PARTICIPANT	\N	PRESENT	0
26111	24546	08039A	PARTICIPANT	\N	PRESENT	0
26112	24546	14079W	PARTICIPANT	\N	PRESENT	0
26113	24546	11091R	PARTICIPANT	\N	PRESENT	0
26114	24546	08031R	PARTICIPANT	\N	PRESENT	0
26115	24546	11033F	PARTICIPANT	\N	PRESENT	0
26116	24546	14030Q	PARTICIPANT	\N	PRESENT	0
26117	24546	11055M	PARTICIPANT	\N	PRESENT	0
26118	24546	14061L	PARTICIPANT	\N	PRESENT	0
26119	24546	11065P	PARTICIPANT	\N	PRESENT	0
26120	24546	11069T	PARTICIPANT	\N	PRESENT	0
26121	24546	14179A	PARTICIPANT	\N	PRESENT	0
26122	24546	14249W	PARTICIPANT	\N	PRESENT	0
26123	24546	14033T	PARTICIPANT	\N	PRESENT	0
26124	24546	14265W	PARTICIPANT	\N	PRESENT	0
26125	24546	04049K	PARTICIPANT	\N	PRESENT	0
26126	24546	95030B	PARTICIPANT	\N	PRESENT	0
26127	24546	14034U	PARTICIPANT	\N	PRESENT	0
26128	24546	14157T	PARTICIPANT	\N	PRESENT	0
26129	24546	14133K	PARTICIPANT	\N	PRESENT	0
26130	24546	80013X	PARTICIPANT	\N	PRESENT	0
26832	26522	04074L	PARTICIPANT	\N	PRESENT	0
26419	25876	14081Q	PARTICIPANT	\N	PRESENT	0
26831	26522	08047A	PARTICIPANT	\N	PRESENT	0
26833	26522	14147R	PARTICIPANT	\N	PRESENT	0
26097	24546	08055A	PARTICIPANT	\N	PRESENT	0
26098	24546	12041X	PARTICIPANT	\N	PRESENT	0
26834	26522	04081K	PARTICIPANT	\N	PRESENT	0
26835	26522	14037X	PARTICIPANT	\N	PRESENT	0
26836	26522	14059S	PARTICIPANT	\N	PRESENT	0
26837	26522	01008M	PARTICIPANT	\N	PRESENT	0
26838	26522	14061L	PARTICIPANT	\N	PRESENT	0
26839	26522	14217N	PARTICIPANT	\N	PRESENT	0
26840	26522	14187A	PARTICIPANT	\N	PRESENT	0
26841	26522	11059R	PARTICIPANT	\N	PRESENT	0
26842	26522	14179A	PARTICIPANT	\N	PRESENT	0
26843	26522	14079W	PARTICIPANT	\N	PRESENT	0
26844	26522	14111D	PARTICIPANT	\N	PRESENT	0
26845	26522	11043H	PARTICIPANT	\N	PRESENT	0
26846	26522	01048V	PARTICIPANT	\N	PRESENT	0
26847	26522	14173T	PARTICIPANT	\N	PRESENT	0
26848	26522	07029T	PARTICIPANT	\N	PRESENT	0
26849	26522	11064N	PARTICIPANT	\N	PRESENT	0
26850	26522	11011M	PARTICIPANT	\N	PRESENT	0
26851	26522	98022P	PARTICIPANT	\N	PRESENT	0
26855	26522	11054L	PARTICIPANT	\N	PRESENT	0
26853	26522	14219Q	PARTICIPANT	\N	PRESENT	0
26854	26522	14267Y	PARTICIPANT	\N	PRESENT	0
26856	26522	14235Q	PARTICIPANT	\N	PRESENT	0
26857	26522	11056N	PARTICIPANT	\N	PRESENT	0
26858	26522	14239U	PARTICIPANT	\N	PRESENT	0
26859	26522	01047U	PARTICIPANT	\N	PRESENT	0
26860	26522	07032N	PARTICIPANT	\N	PRESENT	0
26861	26522	14031R	PARTICIPANT	\N	PRESENT	0
26862	26522	95015C	PARTICIPANT	\N	PRESENT	0
26863	26522	14213J	PARTICIPANT	\N	PRESENT	0
26864	26522	08015R	PARTICIPANT	\N	PRESENT	0
26865	26522	14069U	PARTICIPANT	\N	PRESENT	0
26866	26522	14169X	PARTICIPANT	\N	PRESENT	0
26867	26522	07024N	PARTICIPANT	\N	PRESENT	0
26868	26522	11085T	PARTICIPANT	\N	PRESENT	0
26869	26522	14151M	PARTICIPANT	\N	PRESENT	0
26870	26522	86044G	PARTICIPANT	\N	PRESENT	0
26871	26522	14227Q	PARTICIPANT	\N	PRESENT	0
26872	26522	02002K	PARTICIPANT	\N	PRESENT	0
26873	26522	14225N	PARTICIPANT	\N	PRESENT	0
26874	26522	11111C	PARTICIPANT	\N	PRESENT	0
26875	26522	83047W	PARTICIPANT	\N	PRESENT	0
26876	26522	92045V	PARTICIPANT	\N	PRESENT	0
26877	26522	01024M	PARTICIPANT	\N	PRESENT	0
26878	26522	83042R	PARTICIPANT	\N	PRESENT	0
26879	26522	08022Q	PARTICIPANT	\N	PRESENT	0
26880	26522	07004J	PARTICIPANT	\N	PRESENT	0
26881	26522	11091R	PARTICIPANT	\N	PRESENT	0
26884	26522	14103D	PARTICIPANT	\N	PRESENT	0
26885	26522	01037S	PARTICIPANT	\N	PRESENT	0
26886	26522	14013P	PARTICIPANT	\N	PRESENT	0
26887	26522	14030Q	PARTICIPANT	\N	PRESENT	0
26890	26522	01056V	PARTICIPANT	\N	PRESENT	0
26891	26522	12042Y	PARTICIPANT	\N	PRESENT	0
26892	26522	14135M	PARTICIPANT	\N	PRESENT	0
26893	26522	05012A	PARTICIPANT	\N	PRESENT	0
26894	26522	11063M	PARTICIPANT	\N	PRESENT	0
26895	26522	01058X	PARTICIPANT	\N	PRESENT	0
26896	26522	01034P	PARTICIPANT	\N	PRESENT	0
26897	26522	14249W	PARTICIPANT	\N	PRESENT	0
26898	26522	08049C	PARTICIPANT	\N	PRESENT	0
26899	26522	14251Q	PARTICIPANT	\N	PRESENT	0
26900	26522	14119M	PARTICIPANT	\N	PRESENT	0
26901	26522	14195A	PARTICIPANT	\N	PRESENT	0
26902	26522	90003B	PARTICIPANT	\N	PRESENT	0
27000	26523	11085T	PARTICIPANT	\N	PRESENT	0
27001	26523	11056N	PARTICIPANT	\N	PRESENT	0
27002	26523	05008E	PARTICIPANT	\N	PRESENT	0
27003	26523	01014K	PARTICIPANT	\N	PRESENT	0
27004	26523	08058D	PARTICIPANT	\N	PRESENT	0
27005	26523	08060W	PARTICIPANT	\N	PRESENT	0
27006	26523	14197C	PARTICIPANT	\N	PRESENT	0
27007	26523	11026G	PARTICIPANT	\N	PRESENT	0
27008	26523	01028R	PARTICIPANT	\N	PRESENT	0
27009	26523	95063L	PARTICIPANT	\N	PRESENT	0
27010	26523	11095V	PARTICIPANT	\N	PRESENT	0
27011	26523	14219Q	PARTICIPANT	\N	PRESENT	0
27012	26523	14231L	PARTICIPANT	\N	PRESENT	0
27013	26523	14059S	PARTICIPANT	\N	PRESENT	0
27014	26523	14105F	PARTICIPANT	\N	PRESENT	0
27015	26523	04044E	PARTICIPANT	\N	PRESENT	0
27016	26523	10015M	PARTICIPANT	\N	PRESENT	0
27017	26523	08047A	PARTICIPANT	\N	PRESENT	0
27018	26523	08056B	PARTICIPANT	\N	PRESENT	0
27019	26523	14083S	PARTICIPANT	\N	PRESENT	0
27020	26523	11033F	PARTICIPANT	\N	PRESENT	0
27021	26523	14215L	PARTICIPANT	\N	PRESENT	0
27022	26523	95030B	PARTICIPANT	\N	PRESENT	0
27023	26523	14217N	PARTICIPANT	\N	PRESENT	0
27024	26523	01024M	PARTICIPANT	\N	PRESENT	0
27041	26523	04033B	PARTICIPANT	\N	PRESENT	0
27042	26523	92018S	PARTICIPANT	\N	PRESENT	0
27043	26523	92031P	PARTICIPANT	\N	PRESENT	0
27044	26523	14089Y	PARTICIPANT	\N	PRESENT	0
27045	26523	01025N	PARTICIPANT	\N	PRESENT	0
27046	26523	08051V	PARTICIPANT	\N	PRESENT	0
27047	26523	14119M	PARTICIPANT	\N	PRESENT	0
27048	26523	14031R	PARTICIPANT	\N	PRESENT	0
27049	26523	14030Q	PARTICIPANT	\N	PRESENT	0
27050	26523	02002K	PARTICIPANT	\N	PRESENT	0
27051	26523	14033T	PARTICIPANT	\N	PRESENT	0
27052	26523	07029T	PARTICIPANT	\N	PRESENT	0
27053	26523	04088S	PARTICIPANT	\N	PRESENT	0
27054	26523	14265W	PARTICIPANT	\N	PRESENT	0
27055	26523	11036J	PARTICIPANT	\N	PRESENT	0
27056	26523	98053W	PARTICIPANT	\N	PRESENT	0
27069	27068	89017R	PARTICIPANT	\N	PRESENT	0
27070	27068	01031L	PRESIDENT	0	PRESENT	0
27071	27068	01013J	PARTICIPANT	\N	PRESENT	0
27072	27068	11068S	PARTICIPANT	\N	EXCUSE	0
27073	27068	14175V	PARTICIPANT	\N	PRESENT	0
27074	27068	14085U	PARTICIPANT	\N	PRESENT	0
27075	27068	11042G	PARTICIPANT	\N	PRESENT	0
27076	27068	04086Q	PARTICIPANT	\N	PRESENT	0
27077	27068	14327T	PARTICIPANT	\N	PRESENT	0
27078	27068	08022Q	PARTICIPANT	\N	PRESENT	0
27079	27068	01027Q	PARTICIPANT	\N	PRESENT	0
27080	27068	98053W	PARTICIPANT	\N	EXCUSE	0
27081	27068	11083R	PARTICIPANT	\N	PRESENT	0
27082	27068	14159V	PARTICIPANT	\N	PRESENT	0
27083	27068	07029T	PARTICIPANT	\N	PRESENT	0
27085	27068	08011M	PARTICIPANT	\N	PRESENT	0
27086	27068	08061X	PARTICIPANT	\N	PRESENT	0
27087	27068	11057P	PARTICIPANT	\N	PRESENT	0
27088	27068	14173T	PARTICIPANT	\N	PRESENT	0
27154	27142	92015P	PARTICIPANT	\N	EXCUSE	0
27155	27142	08024S	PARTICIPANT	\N	PRESENT	0
27160	27142	11091R	PARTICIPANT	\N	PRESENT	0
24928	23802	04061F	PARTICIPANT	\N	PRESENT	0
24929	23802	98046X	PARTICIPANT	\N	PRESENT	0
24930	23802	04038G	PARTICIPANT	\N	PRESENT	0
24931	23802	14028W	PARTICIPANT	\N	PRESENT	0
24932	23802	01022K	PARTICIPANT	\N	PRESENT	0
24933	23802	92045V	PARTICIPANT	\N	PRESENT	0
24934	23802	11044J	PARTICIPANT	\N	PRESENT	0
24935	23802	80027E	PARTICIPANT	\N	PRESENT	0
24936	23802	08012N	PARTICIPANT	\N	PRESENT	0
24937	23802	98024R	PARTICIPANT	\N	PRESENT	0
24938	23802	08068F	PARTICIPANT	\N	PRESENT	0
24939	23802	04035D	PARTICIPANT	\N	PRESENT	0
24940	23802	08043V	PARTICIPANT	\N	PRESENT	0
24941	23802	11015D	PARTICIPANT	\N	PRESENT	0
24942	23802	04057K	PARTICIPANT	\N	PRESENT	0
24943	23802	98029W	PARTICIPANT	\N	PRESENT	0
24944	23802	86034E	PARTICIPANT	\N	PRESENT	0
24945	23802	11046L	PARTICIPANT	\N	PRESENT	0
24946	23802	83042R	PARTICIPANT	\N	PRESENT	0
24947	23802	14253S	PARTICIPANT	\N	PRESENT	0
24948	23802	08042U	PARTICIPANT	\N	PRESENT	0
24949	23802	08017T	PARTICIPANT	\N	PRESENT	0
24950	23802	14229S	PARTICIPANT	\N	PRESENT	0
24951	23802	08058D	PARTICIPANT	\N	PRESENT	0
24952	23802	14167V	PARTICIPANT	\N	PRESENT	0
24953	23802	14227Q	PARTICIPANT	\N	PRESENT	0
24954	23802	08014Q	PARTICIPANT	\N	PRESENT	0
24955	23802	14001X	PARTICIPANT	\N	PRESENT	0
24956	23802	11095V	PARTICIPANT	\N	PRESENT	0
24957	23802	14111D	PARTICIPANT	\N	PRESENT	0
24958	23802	01057W	PARTICIPANT	\N	PRESENT	0
24959	23802	14133K	PARTICIPANT	\N	PRESENT	0
24960	23802	11042G	PARTICIPANT	\N	PRESENT	0
24961	23802	14014Q	PARTICIPANT	\N	PRESENT	0
24962	23802	05004A	PARTICIPANT	\N	PRESENT	0
24963	23802	11014C	PARTICIPANT	\N	PRESENT	0
24964	23802	14257W	PARTICIPANT	\N	PRESENT	0
24965	23802	11112D	PARTICIPANT	\N	PRESENT	0
24966	23802	04079R	PARTICIPANT	\N	PRESENT	0
24967	23802	11049P	PARTICIPANT	\N	PRESENT	0
24968	23802	11074Q	PARTICIPANT	\N	PRESENT	0
24969	23802	14271U	PARTICIPANT	\N	PRESENT	0
24970	23802	08069G	PARTICIPANT	\N	PRESENT	0
24971	23802	14281W	PARTICIPANT	\N	PRESENT	0
24972	23802	11057P	PARTICIPANT	\N	PRESENT	0
24973	23802	14093U	PARTICIPANT	\N	PRESENT	0
24974	23802	14235Q	PARTICIPANT	\N	PRESENT	0
24975	23802	04036E	PARTICIPANT	\N	PRESENT	0
24976	23802	11061K	PARTICIPANT	\N	PRESENT	0
24977	23802	08061X	PARTICIPANT	\N	PRESENT	0
24978	23802	04077P	PARTICIPANT	\N	PRESENT	0
24979	23802	04053F	PARTICIPANT	\N	PRESENT	0
24980	23802	08038Y	PARTICIPANT	\N	PRESENT	0
24981	23802	11110B	PARTICIPANT	\N	PRESENT	0
24983	23802	11104D	PARTICIPANT	\N	PRESENT	0
24984	23802	92039X	PARTICIPANT	\N	PRESENT	0
24985	23802	08025T	PARTICIPANT	\N	PRESENT	0
24986	23802	08024S	PARTICIPANT	\N	PRESENT	0
24987	23802	11106F	PARTICIPANT	\N	PRESENT	0
24988	23802	14169X	PARTICIPANT	\N	PRESENT	0
24989	23802	14085U	PARTICIPANT	\N	PRESENT	0
24990	23802	14081Q	PARTICIPANT	\N	PRESENT	0
24991	23802	11067R	PARTICIPANT	\N	PRESENT	0
24992	23802	14123H	PARTICIPANT	\N	PRESENT	0
24993	23802	04045F	PARTICIPANT	\N	PRESENT	0
24994	23802	11077T	PARTICIPANT	\N	PRESENT	0
24995	23802	11032E	PARTICIPANT	\N	PRESENT	0
24996	23802	08035V	PARTICIPANT	\N	PRESENT	0
24997	23802	14195A	PARTICIPANT	\N	PRESENT	0
24998	23802	14159V	PARTICIPANT	\N	PRESENT	0
24999	23802	11107G	PARTICIPANT	\N	PRESENT	0
25000	23802	12042Y	PARTICIPANT	\N	PRESENT	0
25001	23802	08041T	PARTICIPANT	\N	PRESENT	0
25002	23802	01014K	PARTICIPANT	\N	PRESENT	0
25003	23802	08073C	PARTICIPANT	\N	PRESENT	0
25004	23802	11094U	PARTICIPANT	\N	PRESENT	0
25005	23802	04054G	PARTICIPANT	\N	PRESENT	0
25006	23802	04049K	PARTICIPANT	\N	PRESENT	0
25007	23802	88008L	PARTICIPANT	\N	PRESENT	0
25008	23802	01046T	PARTICIPANT	\N	PRESENT	0
25009	23802	04040A	PARTICIPANT	\N	PRESENT	0
25010	23802	92044U	PARTICIPANT	\N	PRESENT	0
25011	23802	92040Q	PARTICIPANT	\N	PRESENT	0
25012	23802	01044R	PARTICIPANT	\N	PRESENT	0
25013	23802	11029K	PARTICIPANT	\N	PRESENT	0
25014	23802	11033F	PARTICIPANT	\N	PRESENT	0
25015	23802	89017R	PARTICIPANT	\N	PRESENT	0
25016	23802	11083R	PARTICIPANT	\N	PRESENT	0
25017	23802	04067M	PARTICIPANT	\N	PRESENT	0
25018	23802	11076S	PARTICIPANT	\N	PRESENT	0
25019	23802	11069T	PARTICIPANT	\N	PRESENT	0
25020	23802	11065P	PARTICIPANT	\N	PRESENT	0
25021	23802	08051V	PARTICIPANT	\N	PRESENT	0
25022	23802	11012A	PARTICIPANT	\N	PRESENT	0
25023	23802	08049C	PARTICIPANT	\N	PRESENT	0
25024	23802	04078Q	PARTICIPANT	\N	PRESENT	0
25025	23802	98022P	PARTICIPANT	\N	PRESENT	0
25026	23802	01043Q	PARTICIPANT	\N	PRESENT	0
25027	23802	04070G	PARTICIPANT	\N	PRESENT	0
25028	23802	08009T	PARTICIPANT	\N	PRESENT	0
25029	23802	14103D	PARTICIPANT	\N	PRESENT	0
25030	23802	11053K	PARTICIPANT	\N	PRESENT	0
25031	23802	01024M	PARTICIPANT	\N	PRESENT	0
25032	23802	11064N	PARTICIPANT	\N	PRESENT	0
25033	23802	14251Q	PARTICIPANT	\N	PRESENT	0
25034	23802	11082Q	PARTICIPANT	\N	PRESENT	0
25035	23802	11111C	PARTICIPANT	\N	PRESENT	0
25036	23802	11103C	PARTICIPANT	\N	PRESENT	0
25037	23802	14231L	PARTICIPANT	\N	PRESENT	0
25038	23802	11093T	PARTICIPANT	\N	PRESENT	0
25039	23802	14083S	PARTICIPANT	\N	PRESENT	0
25040	23802	07004J	PARTICIPANT	\N	PRESENT	0
25041	23802	98042T	PARTICIPANT	\N	PRESENT	0
25042	23802	04043D	PARTICIPANT	\N	PRESENT	0
25043	23802	14267Y	PARTICIPANT	\N	PRESENT	0
25044	23802	14255U	PARTICIPANT	\N	PRESENT	0
25045	23802	08018U	PARTICIPANT	\N	PRESENT	0
25046	23802	14327T	PARTICIPANT	\N	PRESENT	0
25047	23802	08015R	PARTICIPANT	\N	PRESENT	0
25048	23802	01060R	PARTICIPANT	\N	PRESENT	0
25049	23802	11063M	PARTICIPANT	\N	PRESENT	0
25050	23802	08062Y	PARTICIPANT	\N	PRESENT	0
25051	23802	14241N	PARTICIPANT	\N	PRESENT	0
25052	23802	14026U	PARTICIPANT	\N	PRESENT	0
25053	23802	07032N	PARTICIPANT	\N	PRESENT	0
25054	23802	14249W	PARTICIPANT	\N	PRESENT	0
25055	23802	14193X	PARTICIPANT	\N	PRESENT	0
25056	23802	08047A	PARTICIPANT	\N	PRESENT	0
25057	23802	11085T	PARTICIPANT	\N	PRESENT	0
25060	23802	11068S	PARTICIPANT	\N	PRESENT	0
25061	23802	01061S	PARTICIPANT	\N	PRESENT	0
25062	23802	89029V	PARTICIPANT	\N	PRESENT	0
25063	23802	01007L	PARTICIPANT	\N	PRESENT	0
25064	23802	08039A	PARTICIPANT	\N	PRESENT	0
25065	23802	90003B	PARTICIPANT	\N	PRESENT	0
25602	25476	14269B	PARTICIPANT	\N	PRESENT	0
25705	25704	08025T	PARTICIPANT	\N	PRESENT	0
25706	25704	04085P	PARTICIPANT	\N	PRESENT	0
25707	25704	05008E	PRESIDENT	0	PRESENT	0
25708	25704	11030C	PARTICIPANT	\N	PRESENT	0
25709	25704	11033F	PARTICIPANT	\N	PRESENT	0
25710	25704	14065Q	PARTICIPANT	\N	PRESENT	0
25711	25704	14069U	PARTICIPANT	\N	PRESENT	0
25712	25704	04047H	PARTICIPANT	\N	PRESENT	0
25713	25704	11032E	PARTICIPANT	\N	PRESENT	0
25714	25704	04038G	PARTICIPANT	\N	PRESENT	0
25715	25704	99002P	PARTICIPANT	\N	PRESENT	0
25716	25704	11056N	PARTICIPANT	\N	PRESENT	0
25717	25704	14259Y	PARTICIPANT	\N	PRESENT	0
25718	25704	11035H	PARTICIPANT	\N	PRESENT	0
25722	25704	11034G	PARTICIPANT	\N	PRESENT	0
25720	25704	01024M	PARTICIPANT	\N	PRESENT	0
25721	25704	14215L	PARTICIPANT	\N	PRESENT	0
25723	25704	08018U	PARTICIPANT	\N	PRESENT	0
25724	25704	01007L	PARTICIPANT	\N	PRESENT	0
25725	25704	11049P	PARTICIPANT	\N	PRESENT	0
25726	25704	11084S	PARTICIPANT	\N	EXCUSE	0
25728	25704	11026G	PARTICIPANT	\N	PRESENT	0
25729	25704	04079R	PARTICIPANT	\N	PRESENT	0
25730	25704	14111D	PARTICIPANT	\N	PRESENT	0
25731	25704	14001X	PARTICIPANT	\N	PRESENT	0
25732	25704	14273W	PARTICIPANT	\N	PRESENT	0
25733	25704	01060R	PARTICIPANT	\N	PRESENT	0
25734	25704	14147R	PARTICIPANT	\N	PRESENT	0
25735	25704	95049N	PARTICIPANT	\N	PRESENT	0
25736	25704	08051V	PARTICIPANT	\N	PRESENT	0
25737	25704	11072N	PARTICIPANT	\N	EXCUSE	0
25738	25704	07034Q	PARTICIPANT	\N	PRESENT	0
25740	25704	04074L	PARTICIPANT	\N	PRESENT	0
25741	25704	10015M	PARTICIPANT	\N	PRESENT	0
25742	25704	95063L	PARTICIPANT	\N	PRESENT	0
25743	25704	01019Q	PARTICIPANT	\N	PRESENT	0
25744	25704	01028R	PARTICIPANT	\N	PRESENT	0
25745	25704	04044E	PRESIDENT	1	PRESENT	0
25746	25704	11037K	PARTICIPANT	\N	PRESENT	0
25747	25704	92045V	PARTICIPANT	\N	PRESENT	0
25748	25704	01047U	PARTICIPANT	\N	PRESENT	0
25750	25704	14179A	RAPPORTEUR_AVIS	\N	PRESENT	0
26297	23795	11044J	PARTICIPANT	\N	PRESENT	0
26298	23795	11035H	PARTICIPANT	\N	PRESENT	0
26299	23795	01027Q	PARTICIPANT	\N	PRESENT	0
26300	23795	11034G	PARTICIPANT	\N	PRESENT	0
26301	23795	11049P	PARTICIPANT	\N	PRESENT	0
26302	23795	08010L	PARTICIPANT	\N	PRESENT	0
26303	23795	11098Y	PARTICIPANT	\N	PRESENT	0
26304	23795	08051V	PARTICIPANT	\N	PRESENT	0
26305	23795	14028W	PARTICIPANT	\N	PRESENT	0
26306	23795	95063L	PARTICIPANT	\N	PRESENT	0
26307	23795	14051J	PARTICIPANT	\N	PRESENT	0
26308	23795	11037K	PARTICIPANT	\N	PRESENT	0
26309	23795	14071N	PARTICIPANT	\N	PRESENT	0
26310	23795	11099A	PARTICIPANT	\N	PRESENT	0
26312	26311	04054G	PARTICIPANT	\N	PRESENT	0
26313	26311	14089Y	PARTICIPANT	\N	PRESENT	0
26314	26311	14079W	PARTICIPANT	\N	PRESENT	0
26315	26311	14249W	PARTICIPANT	\N	PRESENT	0
26316	26311	95030B	PARTICIPANT	\N	PRESENT	0
26317	26311	08018U	PARTICIPANT	\N	PRESENT	0
26318	26311	11083R	PARTICIPANT	\N	PRESENT	0
26319	26311	14097Y	PARTICIPANT	\N	PRESENT	0
26320	26311	04061F	PARTICIPANT	\N	PRESENT	0
26321	26311	14073Q	PARTICIPANT	\N	EXCUSE	0
26322	26311	11026G	PARTICIPANT	\N	PRESENT	0
26323	26311	98046X	PARTICIPANT	\N	PRESENT	0
26324	26311	04057K	PARTICIPANT	\N	PRESENT	0
26325	26311	08021P	PARTICIPANT	\N	EXCUSE	0
26326	26311	08042U	PARTICIPANT	\N	EXCUSE	0
26327	26311	08073C	PARTICIPANT	\N	PRESENT	0
26328	26311	01016M	PARTICIPANT	\N	PRESENT	0
26329	26311	04045F	PARTICIPANT	\N	PRESENT	0
26330	26311	92045V	PARTICIPANT	\N	PRESENT	0
26331	26311	96004D	PRESIDENT	0	PRESENT	0
26333	26311	14135M	PARTICIPANT	\N	EXCUSE	0
26391	23795	14014Q	PARTICIPANT	\N	EXCUSE	0
26392	23795	08038Y	PARTICIPANT	\N	EXCUSE	0
26393	23795	95067Q	PARTICIPANT	\N	EXCUSE	0
26394	23795	92040Q	PARTICIPANT	\N	EXCUSE	0
26396	23795	01057W	PARTICIPANT	\N	EXCUSE	0
26397	23795	04086Q	PARTICIPANT	\N	EXCUSE	0
26398	23795	07032N	PARTICIPANT	\N	EXCUSE	0
26463	25242	14103D	PARTICIPANT	\N	PRESENT	0
26464	25242	08009T	PARTICIPANT	\N	PRESENT	0
26465	25242	14030Q	PARTICIPANT	\N	PRESENT	0
26466	25242	80013X	PARTICIPANT	\N	PRESENT	0
26467	25242	11107G	PARTICIPANT	\N	PRESENT	0
26468	25242	07029T	PARTICIPANT	\N	PRESENT	0
26469	25242	05012A	PARTICIPANT	\N	PRESENT	0
26470	25242	14013P	PARTICIPANT	\N	PRESENT	0
26471	25242	98018T	PARTICIPANT	\N	PRESENT	0
26472	25242	11054L	PARTICIPANT	\N	PRESENT	0
26474	25242	08034U	PARTICIPANT	\N	PRESENT	0
26493	25242	04067M	PARTICIPANT	\N	PRESENT	0
26494	25242	14038Y	PARTICIPANT	\N	PRESENT	0
26495	25242	14263U	PARTICIPANT	\N	PRESENT	0
26496	25242	01024M	PARTICIPANT	\N	PRESENT	0
26497	25242	14034U	PARTICIPANT	\N	PRESENT	0
26661	26521	89029V	PARTICIPANT	\N	PRESENT	0
26662	26521	14269B	PARTICIPANT	\N	PRESENT	0
26663	26521	01025N	PARTICIPANT	\N	PRESENT	0
26664	26521	14253S	PARTICIPANT	\N	PRESENT	0
26665	26521	14063N	PARTICIPANT	\N	PRESENT	0
26666	26521	08068F	PARTICIPANT	\N	PRESENT	0
26667	26521	04038G	PARTICIPANT	\N	PRESENT	0
26668	26521	08051V	PARTICIPANT	\N	PRESENT	0
26669	26521	14103D	PARTICIPANT	\N	PRESENT	0
26670	26521	11063M	PARTICIPANT	\N	PRESENT	0
26671	26521	14031R	PARTICIPANT	\N	PRESENT	0
26672	26521	14217N	PARTICIPANT	\N	PRESENT	0
26673	26521	01058X	PARTICIPANT	\N	PRESENT	0
26674	26521	11059R	PARTICIPANT	\N	PRESENT	0
26675	26521	92045V	PARTICIPANT	\N	PRESENT	0
26676	26521	14265W	PARTICIPANT	\N	PRESENT	0
26677	26521	08041T	PARTICIPANT	\N	PRESENT	0
26678	26521	14263U	PARTICIPANT	\N	PRESENT	0
26679	26521	14179A	PARTICIPANT	\N	PRESENT	0
26680	26521	14028W	PARTICIPANT	\N	PRESENT	0
26681	26521	07034Q	PARTICIPANT	\N	PRESENT	0
26682	26521	08016S	PARTICIPANT	\N	PRESENT	0
26683	26521	14083S	PARTICIPANT	\N	PRESENT	0
26684	26521	11094U	PARTICIPANT	\N	PRESENT	0
26685	26521	08014Q	PARTICIPANT	\N	PRESENT	0
26686	26521	04049K	PARTICIPANT	\N	PRESENT	0
26687	26521	14219Q	PARTICIPANT	\N	PRESENT	0
26688	26521	14030Q	PARTICIPANT	\N	PRESENT	0
26689	26521	11085T	PARTICIPANT	\N	PRESENT	0
26690	26521	95015C	PARTICIPANT	\N	PRESENT	0
26691	26521	14105F	PARTICIPANT	\N	PRESENT	0
26692	26521	14018U	PARTICIPANT	\N	PRESENT	0
26693	26521	01043Q	PARTICIPANT	\N	PRESENT	0
26694	26521	11112D	PARTICIPANT	\N	PRESENT	0
26695	26521	14187A	PARTICIPANT	\N	PRESENT	0
26727	26522	08021P	PARTICIPANT	\N	PRESENT	0
26728	26522	04092N	PARTICIPANT	\N	PRESENT	0
26729	26522	14231L	PARTICIPANT	\N	PRESENT	0
26730	26522	11029K	PARTICIPANT	\N	PRESENT	0
26725	26522	98053W	PARTICIPANT	\N	PRESENT	0
26726	26522	04045F	PARTICIPANT	\N	PRESENT	0
26731	26522	14265W	PARTICIPANT	\N	PRESENT	0
26732	26522	04088S	PARTICIPANT	\N	PRESENT	0
26733	26522	14033T	PARTICIPANT	\N	PRESENT	0
26734	26522	14105F	PARTICIPANT	\N	PRESENT	0
26735	26522	14263U	PARTICIPANT	\N	PRESENT	0
26736	26522	11083R	PARTICIPANT	\N	PRESENT	0
26737	26522	08043V	PARTICIPANT	\N	PRESENT	0
26738	26522	11104D	PARTICIPANT	\N	PRESENT	0
26739	26522	04048J	PARTICIPANT	\N	PRESENT	0
26740	26522	11037K	PARTICIPANT	\N	PRESENT	0
26741	26522	11040E	PARTICIPANT	\N	PRESENT	0
26742	26522	01013J	PARTICIPANT	\N	PRESENT	0
26743	26522	07026Q	PARTICIPANT	\N	PRESENT	0
26744	26522	01022K	PARTICIPANT	\N	PRESENT	0
26745	26522	98046X	PARTICIPANT	\N	PRESENT	0
26746	26522	04057K	PARTICIPANT	\N	PRESENT	0
26747	26522	01007L	PARTICIPANT	\N	PRESENT	0
26748	26522	11067R	PARTICIPANT	\N	PRESENT	0
26749	26522	11110B	PARTICIPANT	\N	PRESENT	0
26750	26522	11103C	PARTICIPANT	\N	PRESENT	0
26754	26522	11034G	PARTICIPANT	\N	PRESENT	0
26752	26522	04085P	PARTICIPANT	\N	PRESENT	0
26753	26522	11098Y	PARTICIPANT	\N	PRESENT	0
26755	26522	08016S	PARTICIPANT	\N	PRESENT	0
26756	26522	08055A	PARTICIPANT	\N	PRESENT	0
26757	26522	92020L	PARTICIPANT	\N	PRESENT	0
26758	26522	14065Q	PARTICIPANT	\N	PRESENT	0
26759	26522	08025T	PARTICIPANT	\N	PRESENT	0
26760	26522	08053X	PARTICIPANT	\N	PRESENT	0
26761	26522	11027H	PARTICIPANT	\N	PRESENT	0
26762	26522	08068F	PARTICIPANT	\N	PRESENT	0
26763	26522	11036J	PARTICIPANT	\N	PRESENT	0
26764	26522	08014Q	PARTICIPANT	\N	PRESENT	0
26765	26522	14121F	PARTICIPANT	\N	PRESENT	0
26766	26522	14063N	PARTICIPANT	\N	PRESENT	0
26767	26522	11112D	PARTICIPANT	\N	PRESENT	0
26768	26522	11042G	PARTICIPANT	\N	PRESENT	0
26769	26522	14257W	PARTICIPANT	\N	PRESENT	0
26770	26522	01031L	PARTICIPANT	\N	PRESENT	0
26771	26522	11089X	PARTICIPANT	\N	PRESENT	0
26772	26522	14197C	PARTICIPANT	\N	PRESENT	0
26773	26522	14039A	PARTICIPANT	\N	PRESENT	0
26774	26522	08073C	PARTICIPANT	\N	PRESENT	0
26775	26522	04094Q	PARTICIPANT	\N	PRESENT	0
26776	26522	11107G	PARTICIPANT	\N	PRESENT	0
26777	26522	08038Y	PARTICIPANT	\N	PRESENT	0
26778	26522	01028R	PARTICIPANT	\N	PRESENT	0
26779	26522	08061X	PARTICIPANT	\N	PRESENT	0
26780	26522	04053F	PARTICIPANT	\N	PRESENT	0
26781	26522	14229S	PARTICIPANT	\N	PRESENT	0
26782	26522	01044R	PARTICIPANT	\N	PRESENT	0
26783	26522	11033F	PARTICIPANT	\N	PRESENT	0
26784	26522	95049N	PARTICIPANT	\N	PRESENT	0
26785	26522	08051V	PARTICIPANT	\N	PRESENT	0
26786	26522	11099A	PARTICIPANT	\N	PRESENT	0
26787	26522	11069T	PARTICIPANT	\N	PRESENT	0
26788	26522	11065P	PARTICIPANT	\N	PRESENT	0
26789	26522	14269B	PARTICIPANT	\N	PRESENT	0
26790	26522	11014C	PARTICIPANT	\N	PRESENT	0
26791	26522	04059M	PARTICIPANT	\N	PRESENT	0
26792	26522	05008E	PARTICIPANT	\N	PRESENT	0
25058	24684	14103D	RAPPORTEUR_AVIS	\N	PRESENT	0
25059	24684	04059M	RAPPORTEUR_AVIS	\N	PRESENT	0
25182	25181	14263U	PARTICIPANT	\N	EXCUSE	0
25248	25247	14263U	PARTICIPANT	\N	PRESENT	0
25249	25247	14133K	PARTICIPANT	\N	PRESENT	0
25185	25181	04059M	PARTICIPANT	\N	PRESENT	0
25688	25623	97011G	PARTICIPANT	\N	PRESENT	0
25187	25181	01044R	PARTICIPANT	\N	EXCUSE	0
25188	25181	08043V	PARTICIPANT	\N	PRESENT	0
25189	25181	14089Y	PARTICIPANT	\N	PRESENT	0
25190	25181	14105F	PARTICIPANT	\N	PRESENT	0
25191	25181	11029K	PARTICIPANT	\N	PRESENT	0
25251	25247	04059M	PARTICIPANT	\N	PRESENT	0
25193	25181	92015P	PARTICIPANT	\N	EXCUSE	0
25194	25181	08024S	PARTICIPANT	\N	EXCUSE	0
25689	25623	86044G	PARTICIPANT	\N	PRESENT	0
25252	25247	11039M	PARTICIPANT	\N	PRESENT	0
25197	25181	14209N	PARTICIPANT	\N	PRESENT	0
25253	25247	01044R	PARTICIPANT	\N	PRESENT	0
25199	25181	11091R	PARTICIPANT	\N	PRESENT	0
25200	25181	87003B	PARTICIPANT	\N	PRESENT	0
25254	25247	08043V	PARTICIPANT	\N	PRESENT	0
25255	25247	14089Y	PARTICIPANT	\N	PRESENT	0
25256	25247	14105F	PARTICIPANT	\N	PRESENT	0
25204	25181	01025N	PARTICIPANT	\N	PRESENT	0
25257	25247	11029K	PARTICIPANT	\N	PRESENT	0
26477	26473	01015L	PARTICIPANT	\N	PRESENT	0
25259	25247	92015P	PARTICIPANT	\N	EXCUSE	0
25208	25181	11089X	PARTICIPANT	\N	PRESENT	0
25209	25181	07026Q	PARTICIPANT	\N	PRESENT	0
25210	25181	14123H	PARTICIPANT	\N	PRESENT	0
25211	25181	14179A	PARTICIPANT	\N	PRESENT	0
25260	25247	08024S	PARTICIPANT	\N	PRESENT	0
25213	25181	14241N	PARTICIPANT	\N	PRESENT	0
25214	25181	14061L	PARTICIPANT	\N	PRESENT	0
25215	25181	14073Q	PARTICIPANT	\N	PRESENT	0
25216	25181	08031R	PARTICIPANT	\N	PRESENT	0
25261	25247	14201E	PARTICIPANT	\N	PRESENT	0
25218	25181	08039A	PARTICIPANT	\N	PRESENT	0
25219	25181	08017T	PARTICIPANT	\N	PRESENT	0
25220	25181	14059S	PARTICIPANT	\N	PRESENT	0
25878	25876	01031L	PRESIDENT	0	PRESENT	0
25222	25181	14103D	PARTICIPANT	\N	PRESENT	0
25223	25181	11104D	PARTICIPANT	\N	PRESENT	0
25263	25247	14209N	PARTICIPANT	\N	PRESENT	0
25225	25181	04057K	PARTICIPANT	\N	PRESENT	0
25226	25181	11014C	PARTICIPANT	\N	PRESENT	0
25264	25247	14079W	PARTICIPANT	\N	PRESENT	0
25228	25181	04070G	PRESIDENT	0	PRESENT	0
25265	25247	11091R	PARTICIPANT	\N	PRESENT	0
25266	25247	87003B	PARTICIPANT	\N	PRESENT	0
25231	25181	83047W	PARTICIPANT	\N	PRESENT	0
25267	25247	98042T	PARTICIPANT	\N	PRESENT	0
25233	25181	14055N	PARTICIPANT	\N	PRESENT	0
25268	25247	14249W	PARTICIPANT	\N	PRESENT	0
26025	26024	14133K	PARTICIPANT	\N	PRESENT	0
25270	25247	01025N	PARTICIPANT	\N	PRESENT	0
25880	25876	01013J	PARTICIPANT	\N	PRESENT	0
25238	25181	11011M	PARTICIPANT	\N	PRESENT	0
25272	25247	89029V	PARTICIPANT	\N	PRESENT	0
25273	25247	08035V	PARTICIPANT	\N	PRESENT	0
25274	25247	11089X	PARTICIPANT	\N	PRESENT	0
25275	25247	07026Q	PARTICIPANT	\N	PRESENT	0
25276	25247	14123H	PARTICIPANT	\N	PRESENT	0
25277	25247	14179A	PARTICIPANT	\N	PRESENT	0
25881	25876	11068S	PARTICIPANT	\N	PRESENT	0
25279	25247	14241N	PARTICIPANT	\N	PRESENT	0
25280	25247	14061L	PARTICIPANT	\N	PRESENT	0
25281	25247	14073Q	PARTICIPANT	\N	PRESENT	0
25282	25247	08031R	PARTICIPANT	\N	PRESENT	0
25283	25247	12041X	PARTICIPANT	\N	PRESENT	0
25284	25247	08039A	PARTICIPANT	\N	PRESENT	0
25285	25247	08017T	PARTICIPANT	\N	PRESENT	0
25286	25247	14059S	PARTICIPANT	\N	PRESENT	0
25287	25247	08012N	PARTICIPANT	\N	PRESENT	0
25288	25247	14103D	PARTICIPANT	\N	PRESENT	0
25289	25247	11104D	PARTICIPANT	\N	PRESENT	0
25290	25247	14063N	PARTICIPANT	\N	PRESENT	0
25291	25247	04057K	PARTICIPANT	\N	PRESENT	0
25292	25247	11014C	PARTICIPANT	\N	PRESENT	0
25293	25247	14109K	PARTICIPANT	\N	PRESENT	0
25294	25247	04070G	PRESIDENT	0	PRESENT	0
25295	25247	92040Q	PARTICIPANT	\N	PRESENT	0
25296	25247	14191V	PARTICIPANT	\N	PRESENT	0
25297	25247	83047W	PARTICIPANT	\N	PRESENT	0
25298	25247	14235Q	PARTICIPANT	\N	PRESENT	0
25299	25247	14055N	PARTICIPANT	\N	PRESENT	0
25300	25247	04033B	PARTICIPANT	\N	PRESENT	0
25301	25247	14229S	PARTICIPANT	\N	PRESENT	0
25302	25247	11043H	PARTICIPANT	\N	PRESENT	0
26026	26024	04054G	PARTICIPANT	\N	PRESENT	0
25304	25247	11011M	PARTICIPANT	\N	PRESENT	0
25883	25876	08014Q	PARTICIPANT	\N	PRESENT	0
25884	25876	14167V	PARTICIPANT	\N	PRESENT	0
25885	25876	14175V	PARTICIPANT	\N	PRESENT	0
25886	25876	14083S	PARTICIPANT	\N	PRESENT	0
25887	25876	11053K	PARTICIPANT	\N	PRESENT	0
26027	26024	96004D	PRESIDENT	0	PRESENT	0
25889	25876	11042G	PARTICIPANT	\N	PRESENT	0
26028	26024	14089Y	PARTICIPANT	\N	PRESENT	0
25891	25876	04086Q	PARTICIPANT	\N	PRESENT	0
25892	25876	04055H	PARTICIPANT	\N	PRESENT	0
25893	25876	11070L	PARTICIPANT	\N	PRESENT	0
25894	25876	11088W	PARTICIPANT	\N	PRESENT	0
25895	25876	14327T	PARTICIPANT	\N	PRESENT	0
25896	25876	08022Q	PARTICIPANT	\N	PRESENT	0
25897	25876	01027Q	PARTICIPANT	\N	PRESENT	0
25898	25876	04071H	PARTICIPANT	\N	PRESENT	0
25899	25876	11074Q	PARTICIPANT	\N	PRESENT	0
26029	26024	11035H	PARTICIPANT	\N	PRESENT	0
26030	26024	95030B	PARTICIPANT	\N	PRESENT	0
25902	25876	14199E	PARTICIPANT	\N	PRESENT	0
25903	25876	01057W	PARTICIPANT	\N	PRESENT	0
25904	25876	08016S	PARTICIPANT	\N	PRESENT	0
25905	25876	08069G	PARTICIPANT	\N	PRESENT	0
25906	25876	11048N	PARTICIPANT	\N	PRESENT	0
25907	25876	99004R	PARTICIPANT	\N	PRESENT	0
25908	25876	04061F	PARTICIPANT	\N	PRESENT	0
25909	25876	14159V	PARTICIPANT	\N	PRESENT	0
25910	25876	07029T	PARTICIPANT	\N	PRESENT	0
25911	25876	14277B	PARTICIPANT	\N	PRESENT	0
25912	25876	08010L	PARTICIPANT	\N	PRESENT	0
25913	25876	08034U	PARTICIPANT	\N	PRESENT	0
26031	26024	11083R	PARTICIPANT	\N	PRESENT	0
25915	25876	98046X	PARTICIPANT	\N	PRESENT	0
25916	25876	11085T	PARTICIPANT	\N	EXCUSE	0
25917	25876	08011M	PARTICIPANT	\N	PRESENT	0
25918	25876	08073C	PARTICIPANT	\N	PRESENT	0
25919	25876	08061X	PARTICIPANT	\N	PRESENT	0
25920	25876	01016M	PARTICIPANT	\N	PRESENT	0
25921	25876	14225N	PARTICIPANT	\N	PRESENT	0
25922	25876	11012A	PARTICIPANT	\N	PRESENT	0
25923	25876	11057P	PARTICIPANT	\N	PRESENT	0
25924	25876	14173T	PARTICIPANT	\N	PRESENT	0
25925	25876	04034C	PARTICIPANT	\N	PRESENT	0
26033	26024	14097Y	PARTICIPANT	\N	PRESENT	0
26034	26024	98046X	PARTICIPANT	\N	PRESENT	0
26035	26024	04057K	PARTICIPANT	\N	PRESENT	0
26036	26024	08021P	PARTICIPANT	\N	EXCUSE	0
26037	26024	08042U	PARTICIPANT	\N	EXCUSE	0
26038	26024	01016M	PARTICIPANT	\N	PRESENT	0
26039	26024	11012A	PARTICIPANT	\N	PRESENT	0
26040	26024	95063L	PARTICIPANT	\N	PRESENT	0
26041	26024	92045V	PARTICIPANT	\N	PRESENT	0
26042	26024	04034C	PARTICIPANT	\N	PRESENT	0
26475	26473	08055A	PARTICIPANT	\N	PRESENT	0
26476	26473	14038Y	PARTICIPANT	\N	PRESENT	0
26478	26473	11107G	PRESIDENT	0	PRESENT	0
26479	26473	11059R	PARTICIPANT	\N	PRESENT	0
26480	26473	14219Q	PARTICIPANT	\N	PRESENT	0
26481	26473	80027E	PARTICIPANT	\N	PRESENT	0
26482	26473	08009T	PARTICIPANT	\N	EXCUSE	0
26483	26473	05012A	PARTICIPANT	\N	PRESENT	0
26484	26473	14135M	PARTICIPANT	\N	PRESENT	0
26485	26473	14051J	PARTICIPANT	\N	PRESENT	0
26486	26473	14157T	PARTICIPANT	\N	PRESENT	0
26487	26473	95062K	PARTICIPANT	\N	EXCUSE	0
26488	26473	96003C	PARTICIPANT	\N	EXCUSE	0
26489	26473	14031R	PARTICIPANT	\N	EXCUSE	0
26490	26473	92039X	PARTICIPANT	\N	EXCUSE	0
26491	26473	01022K	PARTICIPANT	\N	EXCUSE	0
26492	26473	08062Y	PARTICIPANT	\N	EXCUSE	0
27827	27823	14030Q	PARTICIPANT	\N	PRESENT	0
27829	27823	14105F	PARTICIPANT	\N	PRESENT	0
27832	27823	14255U	PARTICIPANT	\N	PRESENT	0
27834	27823	14151M	PARTICIPANT	\N	PRESENT	0
27837	27823	14121F	PARTICIPANT	\N	PRESENT	0
27838	27823	14039A	PARTICIPANT	\N	PRESENT	0
27840	27823	14061L	PARTICIPANT	\N	PRESENT	0
27842	27823	04049K	PARTICIPANT	\N	PRESENT	0
27845	27823	14265W	PARTICIPANT	\N	PRESENT	0
27846	27823	14253S	PARTICIPANT	\N	PRESENT	0
27853	27823	89017R	PARTICIPANT	\N	EXCUSE	0
27855	27823	14261S	PARTICIPANT	\N	EXCUSE	0
27857	27823	08055A	PARTICIPANT	\N	EXCUSE	0
27860	27823	14065Q	PARTICIPANT	\N	EXCUSE	0
27861	27823	14013P	PARTICIPANT	\N	EXCUSE	0
27864	27823	08068F	PARTICIPANT	\N	EXCUSE	0
27865	27823	04053F	PARTICIPANT	\N	EXCUSE	0
27866	27823	14207L	PARTICIPANT	\N	EXCUSE	0
27868	27823	14083S	PARTICIPANT	\N	EXCUSE	0
27869	27823	14079W	PARTICIPANT	\N	EXCUSE	0
27872	27823	11088W	PARTICIPANT	\N	EXCUSE	0
27874	27823	14041T	PARTICIPANT	\N	EXCUSE	0
27875	27823	04071H	PARTICIPANT	\N	EXCUSE	0
27878	27823	11110B	PARTICIPANT	\N	EXCUSE	0
27879	27823	14087W	PARTICIPANT	\N	EXCUSE	0
27883	27823	14034U	PARTICIPANT	\N	EXCUSE	0
27884	27823	95041E	PARTICIPANT	\N	EXCUSE	0
27885	27823	04077P	PARTICIPANT	\N	EXCUSE	0
27888	27823	01043Q	PARTICIPANT	\N	EXCUSE	0
27891	27823	11077T	PARTICIPANT	\N	EXCUSE	0
27896	27823	11069T	PARTICIPANT	\N	EXCUSE	0
27897	27823	11090Q	PARTICIPANT	\N	EXCUSE	0
27898	27823	10015M	PARTICIPANT	\N	EXCUSE	0
27900	27823	14157T	PARTICIPANT	\N	EXCUSE	0
27901	27823	95067Q	PARTICIPANT	\N	EXCUSE	0
27902	27823	11063M	PARTICIPANT	\N	EXCUSE	0
28323	27204	11048N	PARTICIPANT	\N	PRESENT	0
28324	27204	04059M	PARTICIPANT	\N	PRESENT	0
28325	27204	14030Q	PARTICIPANT	\N	PRESENT	0
28326	27204	09001P	PARTICIPANT	\N	PRESENT	0
28327	27204	04045F	PARTICIPANT	\N	PRESENT	0
28328	27204	11077T	PARTICIPANT	\N	PRESENT	0
28329	27204	01024M	PARTICIPANT	\N	PRESENT	0
28330	27204	14039A	PARTICIPANT	\N	PRESENT	0
28331	27204	98042T	PARTICIPANT	\N	PRESENT	0
28332	27204	08035V	PARTICIPANT	\N	PRESENT	0
28333	27204	14159V	PARTICIPANT	\N	PRESENT	0
28334	27204	14269B	PARTICIPANT	\N	PRESENT	0
28335	27204	11107G	PARTICIPANT	\N	PRESENT	0
28336	27204	14071N	PARTICIPANT	\N	PRESENT	0
28337	27204	12042Y	PARTICIPANT	\N	PRESENT	0
28338	27204	14193X	PARTICIPANT	\N	PRESENT	0
28339	27204	04079R	PARTICIPANT	\N	PRESENT	0
28340	27204	04094Q	PARTICIPANT	\N	PRESENT	0
28341	27204	14123H	PARTICIPANT	\N	PRESENT	0
28342	27204	08073C	PARTICIPANT	\N	PRESENT	0
28343	27204	14259Y	PARTICIPANT	\N	PRESENT	0
28344	27204	11049P	PARTICIPANT	\N	PRESENT	0
28345	27204	14231L	PARTICIPANT	\N	PRESENT	0
28346	27204	07034Q	PARTICIPANT	\N	PRESENT	0
28347	27204	01034P	PARTICIPANT	\N	PRESENT	0
28348	27204	08018U	PARTICIPANT	\N	PRESENT	0
28349	27204	04080J	PARTICIPANT	\N	PRESENT	0
28350	27204	04070G	PARTICIPANT	\N	PRESENT	0
28351	27204	11043H	PARTICIPANT	\N	PRESENT	0
28352	27204	14267Y	PARTICIPANT	\N	PRESENT	0
28353	27204	14042U	PARTICIPANT	\N	PRESENT	0
28354	27204	14219Q	PARTICIPANT	\N	PRESENT	0
28355	27204	11093T	PARTICIPANT	\N	PRESENT	0
28356	27204	07004J	PARTICIPANT	\N	PRESENT	0
28357	27204	14083S	PARTICIPANT	\N	PRESENT	0
28358	27204	11064N	PARTICIPANT	\N	PRESENT	0
28359	27204	14217N	PARTICIPANT	\N	PRESENT	0
28360	27204	14273W	PARTICIPANT	\N	PRESENT	0
28361	27204	14089Y	PARTICIPANT	\N	PRESENT	0
28362	27204	01007L	PARTICIPANT	\N	PRESENT	0
28363	27204	10015M	PARTICIPANT	\N	PRESENT	0
28364	27204	04043D	PARTICIPANT	\N	PRESENT	0
28365	27204	11101A	PARTICIPANT	\N	PRESENT	0
28366	27204	14173T	PARTICIPANT	\N	PRESENT	0
28367	27204	11088W	PARTICIPANT	\N	PRESENT	0
28368	27204	04054G	PARTICIPANT	\N	PRESENT	0
28369	27204	14265W	PARTICIPANT	\N	PRESENT	0
28370	27204	14135M	PARTICIPANT	\N	PRESENT	0
28371	27204	08034U	PARTICIPANT	\N	PRESENT	0
28372	27204	11091R	PARTICIPANT	\N	PRESENT	0
28373	27204	04041B	PARTICIPANT	\N	PRESENT	0
28374	27204	14169X	PARTICIPANT	\N	PRESENT	0
28375	27204	14253S	PARTICIPANT	\N	PRESENT	0
28376	27204	04074L	PARTICIPANT	\N	PRESENT	0
28377	27204	14034U	PARTICIPANT	\N	PRESENT	0
28378	27204	14191V	PARTICIPANT	\N	PRESENT	0
28379	27204	11089X	PARTICIPANT	\N	PRESENT	0
28380	27204	11044J	PARTICIPANT	\N	PRESENT	0
28381	27204	98050T	PARTICIPANT	\N	PRESENT	0
28382	27204	14329V	PARTICIPANT	\N	PRESENT	0
28383	27204	04049K	PARTICIPANT	\N	PRESENT	0
28384	27204	98024R	PARTICIPANT	\N	PRESENT	0
28385	27204	14119M	PARTICIPANT	\N	PRESENT	0
28386	27204	14199E	PARTICIPANT	\N	PRESENT	0
28393	27204	14239U	PARTICIPANT	\N	PRESENT	0
28388	27204	08062Y	PARTICIPANT	\N	PRESENT	0
28392	27204	01031L	PARTICIPANT	\N	PRESENT	0
28390	27204	11085T	PARTICIPANT	\N	PRESENT	0
28391	27204	14249W	PARTICIPANT	\N	PRESENT	0
28397	27204	80027E	PARTICIPANT	\N	PRESENT	0
28395	27204	89017R	PARTICIPANT	\N	PRESENT	0
28396	27204	14085U	PARTICIPANT	\N	PRESENT	0
28398	27204	11072N	PARTICIPANT	\N	PRESENT	0
28404	27204	04097T	PARTICIPANT	\N	PRESENT	0
28405	27204	01041N	PARTICIPANT	\N	PRESENT	0
28623	28399	11085T	PARTICIPANT	\N	PRESENT	0
28624	28399	11029K	PARTICIPANT	\N	PRESENT	0
28625	28399	11042G	PARTICIPANT	\N	PRESENT	0
28626	28399	14013P	PARTICIPANT	\N	PRESENT	0
28627	28399	01059Y	PARTICIPANT	\N	PRESENT	0
28628	28399	14042U	PARTICIPANT	\N	PRESENT	0
28629	28399	11025F	PARTICIPANT	\N	PRESENT	0
28630	28399	04053F	PARTICIPANT	\N	PRESENT	0
28631	28399	11061K	PARTICIPANT	\N	PRESENT	0
28632	28399	04092N	PARTICIPANT	\N	PRESENT	0
28633	28399	98024R	PARTICIPANT	\N	PRESENT	0
28634	28399	14239U	PARTICIPANT	\N	PRESENT	0
28635	28399	14269B	PARTICIPANT	\N	PRESENT	0
28636	28399	11112D	PARTICIPANT	\N	PRESENT	0
28637	28399	12042Y	PARTICIPANT	\N	PRESENT	0
28638	28399	04043D	PARTICIPANT	\N	PRESENT	0
28639	28399	14195A	PARTICIPANT	\N	PRESENT	0
28640	28399	14265W	PARTICIPANT	\N	PRESENT	0
28641	28399	11091R	PARTICIPANT	\N	PRESENT	0
28642	28399	08034U	PARTICIPANT	\N	PRESENT	0
28643	28399	14231L	PARTICIPANT	\N	PRESENT	0
28644	28399	14255U	PARTICIPANT	\N	PRESENT	0
28645	28399	11093T	PARTICIPANT	\N	PRESENT	0
28646	28399	14034U	PARTICIPANT	\N	PRESENT	0
28647	28399	80013X	PARTICIPANT	\N	PRESENT	0
28648	28399	11063M	PARTICIPANT	\N	PRESENT	0
28649	28399	13002U	PARTICIPANT	\N	PRESENT	0
28650	28399	11067R	PARTICIPANT	\N	PRESENT	0
28651	28399	14271U	PARTICIPANT	\N	PRESENT	0
28652	28399	14215L	PARTICIPANT	\N	PRESENT	0
28653	28399	01048V	PARTICIPANT	\N	PRESENT	0
28654	28399	05008E	PARTICIPANT	\N	PRESENT	0
28655	28399	01041N	PARTICIPANT	\N	PRESENT	0
28656	28399	01046T	PARTICIPANT	\N	PRESENT	0
28657	28399	01008M	PARTICIPANT	\N	PRESENT	0
28659	28399	11089X	PARTICIPANT	\N	PRESENT	0
28660	28399	14030Q	PARTICIPANT	\N	PRESENT	0
28661	28658	04040A	PRESIDENT	0	PRESENT	0
28662	28399	11012A	PARTICIPANT	\N	PRESENT	0
28663	28399	99004R	PARTICIPANT	\N	PRESENT	0
28664	28399	14103D	PARTICIPANT	\N	PRESENT	0
28665	28399	04057K	PARTICIPANT	\N	PRESENT	0
28667	28399	14109K	PARTICIPANT	\N	PRESENT	0
28668	28399	14105F	PARTICIPANT	\N	PRESENT	0
28669	28399	01011G	PARTICIPANT	\N	PRESENT	0
28670	28399	04088S	PARTICIPANT	\N	PRESENT	0
28671	28399	04080J	PARTICIPANT	\N	PRESENT	0
28672	28399	14267Y	PARTICIPANT	\N	PRESENT	0
28673	28399	04081K	PARTICIPANT	\N	PRESENT	0
28674	28399	14083S	PARTICIPANT	\N	PRESENT	0
28675	28399	04067M	PARTICIPANT	\N	PRESENT	0
28676	28399	04066L	PARTICIPANT	\N	PRESENT	0
28677	28399	07034Q	PARTICIPANT	\N	PRESENT	0
28678	28399	14037X	PARTICIPANT	\N	PRESENT	0
28681	27204	01019Q	PARTICIPANT	\N	PRESENT	0
28682	28658	11035H	PARTICIPANT	\N	EXCUSE	0
28683	28658	14034U	PARTICIPANT	\N	EXCUSE	0
28686	28666	08039A	PARTICIPANT	\N	EXCUSE	0
27209	27208	04070G	PRESIDENT	0	PRESENT	0
27210	27208	14263U	PARTICIPANT	\N	PRESENT	0
27267	27208	11091R	PARTICIPANT	\N	PRESENT	0
27317	27208	08035V	PARTICIPANT	\N	PRESENT	0
27213	27208	04059M	PARTICIPANT	\N	PRESENT	0
27214	27208	11039M	PARTICIPANT	\N	PRESENT	0
27215	27208	01044R	PARTICIPANT	\N	PRESENT	0
27216	27208	08043V	PARTICIPANT	\N	PRESENT	0
27217	27208	14089Y	PARTICIPANT	\N	PRESENT	0
27218	27208	14105F	PARTICIPANT	\N	PRESENT	0
27219	27208	11029K	PARTICIPANT	\N	PRESENT	0
27220	27208	95015C	PARTICIPANT	\N	PRESENT	0
27221	27208	92015P	PARTICIPANT	\N	EXCUSE	0
27222	27208	08024S	PARTICIPANT	\N	EXCUSE	0
27376	26806	08055A	PARTICIPANT	\N	PRESENT	0
27377	26806	11093T	PARTICIPANT	\N	PRESENT	0
27378	26806	11103C	PARTICIPANT	\N	PRESENT	0
27379	26806	11043H	PARTICIPANT	\N	PRESENT	0
27380	26806	14223L	PARTICIPANT	\N	PRESENT	0
27228	27208	87003B	PARTICIPANT	\N	PRESENT	0
27229	27208	98042T	PARTICIPANT	\N	PRESENT	0
27230	27208	14249W	PARTICIPANT	\N	PRESENT	0
27381	26806	14053L	PARTICIPANT	\N	PRESENT	0
27232	27208	01025N	PARTICIPANT	\N	PRESENT	0
27382	26806	14263U	PARTICIPANT	\N	PRESENT	0
27383	26806	11112D	PARTICIPANT	\N	PRESENT	0
27384	26806	11063M	PARTICIPANT	\N	PRESENT	0
27236	27208	11089X	PARTICIPANT	\N	PRESENT	0
27237	27208	07026Q	PARTICIPANT	\N	PRESENT	0
27238	27208	14123H	PARTICIPANT	\N	PRESENT	0
27239	27208	14179A	PARTICIPANT	\N	PRESENT	0
27385	26806	14105F	PARTICIPANT	\N	PRESENT	0
27241	27208	14241N	PARTICIPANT	\N	PRESENT	0
27242	27208	14061L	PARTICIPANT	\N	PRESENT	0
27243	27208	14073Q	PARTICIPANT	\N	PRESENT	0
27244	27208	08031R	PARTICIPANT	\N	EXCUSE	0
27386	26806	14089Y	PARTICIPANT	\N	PRESENT	0
27246	27208	08039A	PARTICIPANT	\N	PRESENT	0
27387	26806	14121F	PARTICIPANT	\N	PRESENT	0
27248	27208	14059S	PARTICIPANT	\N	PRESENT	0
27249	27208	08012N	PARTICIPANT	\N	PRESENT	0
27250	27208	14103D	PARTICIPANT	\N	PRESENT	0
27251	27208	11104D	PARTICIPANT	\N	PRESENT	0
27252	27208	14063N	PARTICIPANT	\N	PRESENT	0
27253	27208	04057K	PARTICIPANT	\N	PRESENT	0
27254	27208	11014C	PARTICIPANT	\N	PRESENT	0
27255	27208	14109K	PARTICIPANT	\N	PRESENT	0
27256	27208	92040Q	PARTICIPANT	\N	PRESENT	0
27388	26806	08043V	PARTICIPANT	\N	PRESENT	0
27258	27208	83047W	PARTICIPANT	\N	PRESENT	0
27259	27208	14235Q	PARTICIPANT	\N	EXCUSE	0
27389	26806	08041T	PARTICIPANT	\N	PRESENT	0
27390	26806	14042U	PARTICIPANT	\N	PRESENT	0
27262	27208	14229S	PARTICIPANT	\N	PRESENT	0
27263	27208	11043H	PARTICIPANT	\N	PRESENT	0
27391	26806	14219Q	PARTICIPANT	\N	PRESENT	0
27392	26806	04067M	PARTICIPANT	\N	PRESENT	0
27396	26806	14271U	PARTICIPANT	\N	PRESENT	0
27394	26806	11067R	PARTICIPANT	\N	PRESENT	0
27395	26806	11066Q	PARTICIPANT	\N	PRESENT	0
27397	26806	04092N	PARTICIPANT	\N	PRESENT	0
27398	26806	01046T	PARTICIPANT	\N	PRESENT	0
27399	26806	04081K	PARTICIPANT	\N	PRESENT	0
27400	26806	14195A	PARTICIPANT	\N	PRESENT	0
27401	26806	14173T	PARTICIPANT	\N	PRESENT	0
27402	26806	14147R	PARTICIPANT	\N	PRESENT	0
27403	26806	14257W	PARTICIPANT	\N	PRESENT	0
27404	26806	14109K	PARTICIPANT	\N	PRESENT	0
27405	26806	14018U	PARTICIPANT	\N	PRESENT	0
27406	26806	04088S	PARTICIPANT	\N	PRESENT	0
27407	26806	14033T	PARTICIPANT	\N	PRESENT	0
27408	26806	13002U	PARTICIPANT	\N	PRESENT	0
27409	26806	01034P	PARTICIPANT	\N	PRESENT	0
27410	26806	14059S	PARTICIPANT	\N	PRESENT	0
27414	26806	14281W	PARTICIPANT	\N	PRESENT	0
27412	26806	14135M	PARTICIPANT	\N	PRESENT	0
27413	26806	14265W	PARTICIPANT	\N	PRESENT	0
27455	26806	11101A	PARTICIPANT	\N	PRESENT	0
27456	26806	12042Y	PARTICIPANT	\N	PRESENT	0
27457	26806	04045F	PARTICIPANT	\N	PRESENT	0
27458	26806	14217N	PARTICIPANT	\N	PRESENT	0
27459	26806	08056B	PARTICIPANT	\N	PRESENT	0
27460	26806	14267Y	PARTICIPANT	\N	PRESENT	0
27461	26806	11074Q	PARTICIPANT	\N	PRESENT	0
27462	26806	14103D	PARTICIPANT	\N	PRESENT	0
27463	26806	14269B	PARTICIPANT	\N	PRESENT	0
27464	26806	01015L	PARTICIPANT	\N	PRESENT	0
27465	26806	14239U	PARTICIPANT	\N	PRESENT	0
27466	26806	04043D	PARTICIPANT	\N	PRESENT	0
27467	26806	14205J	PARTICIPANT	\N	PRESENT	0
27468	26806	14273W	PARTICIPANT	\N	PRESENT	0
27470	26806	14187A	PARTICIPANT	\N	PRESENT	0
27528	26806	14237S	PARTICIPANT	\N	PRESENT	0
27529	26806	14111D	PARTICIPANT	\N	PRESENT	0
27530	26806	14207L	PARTICIPANT	\N	PRESENT	0
27531	26806	87003B	PARTICIPANT	\N	PRESENT	0
27532	26806	08062Y	PARTICIPANT	\N	PRESENT	0
27533	26806	11091R	PARTICIPANT	\N	PRESENT	0
27534	26806	08016S	PARTICIPANT	\N	PRESENT	0
27535	26806	01003G	PARTICIPANT	\N	PRESENT	0
27537	27536	08025T	PARTICIPANT	\N	PRESENT	0
27538	27536	04085P	PARTICIPANT	\N	PRESENT	0
27539	27536	05008E	PRESIDENT	0	PRESENT	0
27586	26806	14034U	PARTICIPANT	\N	PRESENT	0
27541	27536	11033F	PARTICIPANT	\N	PRESENT	0
27542	27536	14065Q	PARTICIPANT	\N	PRESENT	0
27543	27536	14069U	PARTICIPANT	\N	PRESENT	0
27544	27536	04047H	PARTICIPANT	\N	PRESENT	0
27587	26806	14063N	PARTICIPANT	\N	PRESENT	0
27546	27536	04038G	PARTICIPANT	\N	PRESENT	0
27597	26806	14231L	PARTICIPANT	\N	PRESENT	0
27548	27536	11056N	PARTICIPANT	\N	PRESENT	0
27549	27536	14259Y	PARTICIPANT	\N	PRESENT	0
27550	27536	11035H	PARTICIPANT	\N	PRESENT	0
27588	26806	14179A	PARTICIPANT	\N	PRESENT	0
27589	26806	86044G	PARTICIPANT	\N	PRESENT	0
27553	27536	01024M	PARTICIPANT	\N	PRESENT	0
27554	27536	14215L	PARTICIPANT	\N	PRESENT	0
27555	27536	11034G	PARTICIPANT	\N	PRESENT	0
27556	27536	08018U	PARTICIPANT	\N	PRESENT	0
27590	26806	11104D	PARTICIPANT	\N	PRESENT	0
27591	26806	08047A	PARTICIPANT	\N	PRESENT	0
27559	27536	11049P	PARTICIPANT	\N	PRESENT	0
27560	27536	08044W	PARTICIPANT	\N	PRESENT	0
27592	26806	98050T	PARTICIPANT	\N	PRESENT	0
27562	27536	11026G	PARTICIPANT	\N	PRESENT	0
27563	27536	04079R	PARTICIPANT	\N	PRESENT	0
27564	27536	14111D	PARTICIPANT	\N	PRESENT	0
27565	27536	14001X	PARTICIPANT	\N	PRESENT	0
27566	27536	14273W	PARTICIPANT	\N	PRESENT	0
27595	26806	14097Y	PARTICIPANT	\N	PRESENT	0
27568	27536	14147R	PARTICIPANT	\N	PRESENT	0
27569	27536	95049N	PARTICIPANT	\N	PRESENT	0
27570	27536	08051V	PARTICIPANT	\N	PRESENT	0
27571	27536	11072N	PARTICIPANT	\N	PRESENT	0
27572	27536	07034Q	PARTICIPANT	\N	PRESENT	0
27573	27536	04074L	PARTICIPANT	\N	PRESENT	0
27574	27536	10015M	PARTICIPANT	\N	PRESENT	0
27575	27536	95063L	PARTICIPANT	\N	PRESENT	0
27576	27536	01019Q	PARTICIPANT	\N	PRESENT	0
27577	27536	01028R	PARTICIPANT	\N	PRESENT	0
27578	27536	98035U	PARTICIPANT	\N	PRESENT	0
27579	27536	04056J	PARTICIPANT	\N	PRESENT	0
27596	26806	01022K	PARTICIPANT	\N	PRESENT	0
27581	27536	04044E	PARTICIPANT	\N	PRESENT	0
27582	27536	11037K	PARTICIPANT	\N	PRESENT	0
27583	27536	92045V	PARTICIPANT	\N	PRESENT	0
27598	26806	14197C	PARTICIPANT	\N	PRESENT	0
27585	27536	01047U	PARTICIPANT	\N	PRESENT	0
27599	26806	11111C	PARTICIPANT	\N	PRESENT	0
27600	26806	01058X	PARTICIPANT	\N	PRESENT	0
27601	26806	98024R	PARTICIPANT	\N	PRESENT	0
27602	26806	04048J	PARTICIPANT	\N	PRESENT	0
27603	26806	14069U	PARTICIPANT	\N	PRESENT	0
27604	26806	14071N	PARTICIPANT	\N	PRESENT	0
27605	26806	14119M	PARTICIPANT	\N	PRESENT	0
27606	26806	80013X	PARTICIPANT	\N	PRESENT	0
27607	26806	14081Q	PARTICIPANT	\N	PRESENT	0
27608	26806	11061K	PARTICIPANT	\N	PRESENT	0
27609	26806	11025F	PARTICIPANT	\N	PRESENT	0
27610	26806	01019Q	PARTICIPANT	\N	PRESENT	0
27611	26806	11012A	PARTICIPANT	\N	PRESENT	0
27612	26806	04053F	PARTICIPANT	\N	PRESENT	0
27613	26806	11100Y	PARTICIPANT	\N	PRESENT	0
27614	26806	01008M	PARTICIPANT	\N	PRESENT	0
27615	26806	08015R	PARTICIPANT	\N	PRESENT	0
27616	26806	11036J	PARTICIPANT	\N	PRESENT	0
27617	26806	14061L	PARTICIPANT	\N	PRESENT	0
27618	26806	07004J	PARTICIPANT	\N	PRESENT	0
27207	27142	01048V	PARTICIPANT	\N	PRESENT	0
27268	27266	89017R	PARTICIPANT	\N	PRESENT	0
27163	27142	14249W	PARTICIPANT	\N	PRESENT	0
27269	27266	01031L	PRESIDENT	0	PRESENT	0
27165	27142	01025N	PARTICIPANT	\N	PRESENT	0
27270	27266	05004A	PARTICIPANT	\N	PRESENT	0
27271	27266	01013J	PARTICIPANT	\N	PRESENT	0
27272	27266	11068S	PARTICIPANT	\N	PRESENT	0
27169	27142	11089X	PARTICIPANT	\N	PRESENT	0
27170	27142	07026Q	PARTICIPANT	\N	PRESENT	0
27171	27142	14123H	PARTICIPANT	\N	PRESENT	0
27273	27266	11040E	PARTICIPANT	\N	PRESENT	0
27619	26806	92045V	PARTICIPANT	\N	PRESENT	0
27174	27142	14241N	PARTICIPANT	\N	PRESENT	0
27175	27142	14061L	PARTICIPANT	\N	PRESENT	0
27176	27142	14073Q	PARTICIPANT	\N	EXCUSE	0
27177	27142	08031R	PARTICIPANT	\N	EXCUSE	0
27275	27266	14167V	PARTICIPANT	\N	PRESENT	0
27179	27142	08039A	PARTICIPANT	\N	PRESENT	0
27276	27266	14175V	PARTICIPANT	\N	PRESENT	0
27277	27266	14083S	PARTICIPANT	\N	PRESENT	0
27620	26806	11064N	PARTICIPANT	\N	PRESENT	0
27183	27142	14103D	PARTICIPANT	\N	PRESENT	0
27184	27142	11104D	PARTICIPANT	\N	PRESENT	0
27185	27142	14063N	PARTICIPANT	\N	PRESENT	0
27186	27142	04057K	PARTICIPANT	\N	EXCUSE	0
27187	27142	11014C	PARTICIPANT	\N	PRESENT	0
27188	27142	14109K	PARTICIPANT	\N	PRESENT	0
27189	27142	04070G	PRESIDENT	0	PRESENT	0
27279	27266	14085U	PARTICIPANT	\N	PRESENT	0
27280	27266	11042G	PARTICIPANT	\N	PRESENT	0
27192	27142	83047W	PARTICIPANT	\N	PRESENT	0
27193	27142	14235Q	PARTICIPANT	\N	EXCUSE	0
27621	26806	14013P	PARTICIPANT	\N	PRESENT	0
27282	27266	04086Q	PARTICIPANT	\N	PRESENT	0
27196	27142	14229S	PARTICIPANT	\N	PRESENT	0
27197	27142	11043H	PARTICIPANT	\N	PRESENT	0
27622	26806	14030Q	PARTICIPANT	\N	PRESENT	0
27623	26806	90003B	PARTICIPANT	\N	PRESENT	0
27284	27266	11070L	PARTICIPANT	\N	PRESENT	0
27285	27266	11088W	PARTICIPANT	\N	PRESENT	0
27286	27266	14327T	PARTICIPANT	\N	PRESENT	0
27287	27266	08022Q	PARTICIPANT	\N	PRESENT	0
27288	27266	01027Q	PARTICIPANT	\N	PRESENT	0
27289	27266	04071H	PARTICIPANT	\N	PRESENT	0
27290	27266	11074Q	PARTICIPANT	\N	PRESENT	0
27624	26806	04057K	PARTICIPANT	\N	PRESENT	0
27292	27266	11083R	PARTICIPANT	\N	PRESENT	0
27625	26806	01059Y	PARTICIPANT	\N	PRESENT	0
27294	27266	01057W	PARTICIPANT	\N	PRESENT	0
27295	27266	08016S	PARTICIPANT	\N	PRESENT	0
27626	26806	92039X	PARTICIPANT	\N	PRESENT	0
27627	26806	14151M	PARTICIPANT	\N	PRESENT	0
27298	27266	99004R	PARTICIPANT	\N	PRESENT	0
27299	27266	04061F	PARTICIPANT	\N	PRESENT	0
27300	27266	14159V	PARTICIPANT	\N	PRESENT	0
27301	27266	07029T	PARTICIPANT	\N	PRESENT	0
27628	26806	11110B	PARTICIPANT	\N	PRESENT	0
27303	27266	08010L	PARTICIPANT	\N	PRESENT	0
27304	27266	08034U	PARTICIPANT	\N	PRESENT	0
27305	27266	01048V	PARTICIPANT	\N	PRESENT	0
27306	27266	98046X	PARTICIPANT	\N	PRESENT	0
27307	27266	11085T	PARTICIPANT	\N	PRESENT	0
27308	27266	08011M	PARTICIPANT	\N	EXCUSE	0
27309	27266	08073C	PARTICIPANT	\N	PRESENT	0
27646	26806	11099A	PARTICIPANT	\N	PRESENT	0
27647	26806	89017R	PARTICIPANT	\N	PRESENT	0
27312	27266	14225N	PARTICIPANT	\N	PRESENT	0
27313	27266	11012A	PARTICIPANT	\N	PRESENT	0
27314	27266	11057P	PARTICIPANT	\N	PRESENT	0
27315	27266	14173T	PARTICIPANT	\N	PRESENT	0
27316	27266	04034C	PARTICIPANT	\N	PRESENT	0
27648	26806	07029T	PARTICIPANT	\N	PRESENT	0
27699	26806	14215L	PARTICIPANT	\N	PRESENT	0
27700	26806	05012A	PARTICIPANT	\N	PRESENT	0
27702	26806	01057W	PARTICIPANT	\N	PRESENT	0
27703	26806	08051V	PARTICIPANT	\N	PRESENT	0
27704	26806	08034U	PARTICIPANT	\N	PRESENT	0
27705	26806	11083R	PARTICIPANT	\N	PRESENT	0
27706	26806	01027Q	PARTICIPANT	\N	PRESENT	0
27707	26806	01056V	PARTICIPANT	\N	PRESENT	0
27764	27593	01059Y	PARTICIPANT	\N	PRESENT	0
27765	27593	14269B	PARTICIPANT	\N	PRESENT	0
27766	27593	11067R	PARTICIPANT	\N	PRESENT	0
27767	27593	14271U	PARTICIPANT	\N	PRESENT	0
27768	27593	04092N	PARTICIPANT	\N	PRESENT	0
27769	27593	11112D	PARTICIPANT	\N	PRESENT	0
27770	27593	01046T	PARTICIPANT	\N	PRESENT	0
27771	27593	11012A	PARTICIPANT	\N	PRESENT	0
27772	27593	14121F	PARTICIPANT	\N	PRESENT	0
27773	27593	14237S	PARTICIPANT	\N	PRESENT	0
27774	27593	01056V	PARTICIPANT	\N	PRESENT	0
27775	27593	14195A	PARTICIPANT	\N	PRESENT	0
27776	27593	14059S	PARTICIPANT	\N	PRESENT	0
27777	27593	11093T	PARTICIPANT	\N	PRESENT	0
27778	27593	14071N	PARTICIPANT	\N	PRESENT	0
27779	27593	04045F	PARTICIPANT	\N	PRESENT	0
27780	27593	11103C	PARTICIPANT	\N	PRESENT	0
27781	27593	14026U	PARTICIPANT	\N	PRESENT	0
27782	27593	14018U	PARTICIPANT	\N	PRESENT	0
27783	27593	08022Q	PARTICIPANT	\N	PRESENT	0
27784	27593	14215L	PARTICIPANT	\N	PRESENT	0
27785	27593	14031R	PARTICIPANT	\N	PRESENT	0
27786	27593	14169X	PARTICIPANT	\N	PRESENT	0
27787	27593	12042Y	PARTICIPANT	\N	PRESENT	0
27788	27593	14042U	PARTICIPANT	\N	PRESENT	0
27789	27593	14219Q	PARTICIPANT	\N	PRESENT	0
27790	27593	14231L	PARTICIPANT	\N	PRESENT	0
27801	27593	11095V	PARTICIPANT	\N	PRESENT	0
27802	27593	14197C	PARTICIPANT	\N	PRESENT	0
27803	27593	08052W	PARTICIPANT	\N	PRESENT	0
27804	27593	14103D	PARTICIPANT	\N	PRESENT	0
27805	27593	14033T	PARTICIPANT	\N	PRESENT	0
27806	27593	14119M	PARTICIPANT	\N	PRESENT	0
27807	27593	14265W	PARTICIPANT	\N	PRESENT	0
27808	27593	14217N	PARTICIPANT	\N	PRESENT	0
27809	27593	11039M	PARTICIPANT	\N	PRESENT	0
27810	27593	11104D	PARTICIPANT	\N	PRESENT	0
27811	27593	14267Y	PARTICIPANT	\N	PRESENT	0
27812	27593	14083S	PARTICIPANT	\N	PRESENT	0
27813	27593	14034U	PARTICIPANT	\N	PRESENT	0
28701	28658	14028W	PARTICIPANT	\N	EXCUSE	0
28703	28702	14030Q	PARTICIPANT	\N	PRESENT	0
28704	28702	11029K	PARTICIPANT	\N	PRESENT	0
28705	28702	80013X	PARTICIPANT	\N	PRESENT	0
28706	28702	14217N	PARTICIPANT	\N	PRESENT	0
28707	28702	14059S	PARTICIPANT	\N	PRESENT	0
28708	28702	11091R	PARTICIPANT	\N	PRESENT	0
28709	28702	07026Q	PARTICIPANT	\N	PRESENT	0
28710	28702	11067R	PARTICIPANT	\N	PRESENT	0
28711	28702	11027H	PARTICIPANT	\N	PRESENT	0
28712	28702	09001P	PRESIDENT	0	PRESENT	0
28713	28658	04044E	PARTICIPANT	\N	EXCUSE	0
28715	24344	08065C	PARTICIPANT	\N	EXCUSE	0
28716	24344	11023D	PARTICIPANT	\N	EXCUSE	0
27762	27593	08024S	PARTICIPANT	\N	PRESENT	0
27763	27593	11063M	PARTICIPANT	\N	PRESENT	0
27320	27318	04054G	PARTICIPANT	\N	PRESENT	0
27321	27318	04040A	PARTICIPANT	\N	EXCUSE	0
27322	27318	08058D	PARTICIPANT	\N	PRESENT	0
27323	27318	04042C	PRESIDENT	0	PRESENT	0
27324	27318	77002U	PARTICIPANT	\N	PRESENT	0
27325	27318	98029W	PARTICIPANT	\N	PRESENT	0
27327	27318	11027H	PARTICIPANT	\N	PRESENT	0
27328	27318	98018T	PARTICIPANT	\N	PRESENT	0
27329	27318	92018S	PARTICIPANT	\N	PRESENT	0
27330	27318	92020L	PARTICIPANT	\N	PRESENT	0
27331	27318	95030B	PARTICIPANT	\N	PRESENT	0
28741	28724	01024M	PARTICIPANT	\N	PRESENT	0
27335	27318	08065C	PARTICIPANT	\N	EXCUSE	0
27336	27318	04035D	PARTICIPANT	\N	EXCUSE	0
27337	27318	07024N	PARTICIPANT	\N	PRESENT	0
27339	27318	14014Q	PARTICIPANT	\N	PRESENT	0
27341	27318	07004J	PARTICIPANT	\N	PRESENT	0
27342	27318	95035G	PARTICIPANT	\N	EXCUSE	0
27343	27318	08056B	PARTICIPANT	\N	PRESENT	0
27344	27318	14211G	PARTICIPANT	\N	PRESENT	0
27346	27318	11064N	PARTICIPANT	\N	PRESENT	0
27347	27318	95037J	PARTICIPANT	\N	PRESENT	0
27348	27318	04078Q	PARTICIPANT	\N	PRESENT	0
27349	27318	14097Y	PARTICIPANT	\N	PRESENT	0
27350	27318	95041E	PARTICIPANT	\N	PRESENT	0
27351	27318	04036E	PARTICIPANT	\N	EXCUSE	0
27352	27318	14039A	PARTICIPANT	\N	PRESENT	0
27353	27318	04077P	PARTICIPANT	\N	EXCUSE	0
28747	28724	11049P	PARTICIPANT	\N	PRESENT	0
27355	27318	92031P	PARTICIPANT	\N	PRESENT	0
27357	27318	14251Q	PARTICIPANT	\N	PRESENT	0
27359	27318	08053X	PARTICIPANT	\N	PRESENT	0
27361	27318	11105E	PARTICIPANT	\N	EXCUSE	0
27362	27318	14253S	PARTICIPANT	\N	PRESENT	0
27363	27318	08047A	PARTICIPANT	\N	PRESENT	0
27364	27318	14028W	PARTICIPANT	\N	PRESENT	0
27365	27318	14193X	PARTICIPANT	\N	PRESENT	0
28752	28724	14111D	PARTICIPANT	\N	PRESENT	0
27368	27318	04080J	PARTICIPANT	\N	PRESENT	0
27369	27318	95059Q	PARTICIPANT	\N	EXCUSE	0
27370	27318	86044G	PARTICIPANT	\N	PRESENT	0
27371	27318	01014K	PARTICIPANT	\N	PRESENT	0
27372	27318	11054L	PARTICIPANT	\N	PRESENT	0
27373	27318	01056V	PARTICIPANT	\N	PRESENT	0
27375	27318	08049C	PARTICIPANT	\N	PRESENT	0
28754	28724	14273W	PARTICIPANT	\N	PRESENT	0
28757	28724	95049N	PARTICIPANT	\N	PRESENT	0
28759	28724	11072N	PARTICIPANT	\N	PRESENT	0
28760	28724	07034Q	PARTICIPANT	\N	PRESENT	0
28765	28724	01028R	PARTICIPANT	\N	PRESENT	0
28766	28724	98035U	PARTICIPANT	\N	PRESENT	0
28768	28724	14275Y	PARTICIPANT	\N	PRESENT	0
28771	28724	92045V	PARTICIPANT	\N	PRESENT	0
28772	28724	95067Q	PARTICIPANT	\N	PRESENT	0
28860	24344	11109J	PARTICIPANT	\N	PRESENT	0
28861	24344	14093U	PARTICIPANT	\N	PRESENT	0
28862	24344	11114F	PARTICIPANT	\N	PRESENT	0
28863	24344	14259Y	PARTICIPANT	\N	PRESENT	0
28865	24344	14039A	PARTICIPANT	\N	PRESENT	0
28866	24344	04094Q	PARTICIPANT	\N	PRESENT	0
28867	24344	14219Q	PARTICIPANT	\N	PRESENT	0
28868	24344	08019V	PRESIDENT	0	PRESENT	0
28869	24344	11072N	PARTICIPANT	\N	PRESENT	0
28870	24344	11106F	PARTICIPANT	\N	PRESENT	0
28871	24344	14059S	PARTICIPANT	\N	PRESENT	0
28872	24344	95062K	PARTICIPANT	\N	PRESENT	0
28874	24344	11054L	PARTICIPANT	\N	PRESENT	0
28875	24344	14275Y	PARTICIPANT	\N	PRESENT	0
28877	24344	11020A	PARTICIPANT	\N	PRESENT	0
28879	24344	01027Q	PARTICIPANT	\N	EXCUSE	0
28881	24344	01022K	PARTICIPANT	\N	PRESENT	0
28885	24344	14097Y	PARTICIPANT	\N	PRESENT	0
28908	24344	08055A	PARTICIPANT	\N	PRESENT	0
28909	24344	14030Q	PARTICIPANT	\N	PRESENT	0
28727	28724	05008E	PRESIDENT	0	PRESENT	0
28910	24344	14038Y	PARTICIPANT	\N	PRESENT	0
28729	28724	11033F	PARTICIPANT	\N	EXCUSE	0
28730	28724	14065Q	PARTICIPANT	\N	PRESENT	0
28911	24344	98023Q	PARTICIPANT	\N	PRESENT	0
28912	24344	11065P	PARTICIPANT	\N	PRESENT	0
28913	24344	01015L	PARTICIPANT	\N	PRESENT	0
28734	28724	04038G	PARTICIPANT	\N	PRESENT	0
28914	24344	11107G	PARTICIPANT	\N	PRESENT	0
28915	24344	02002K	PARTICIPANT	\N	PRESENT	0
28737	28724	14259Y	PARTICIPANT	\N	PRESENT	0
28916	24344	04097T	PARTICIPANT	\N	PRESENT	0
28917	24344	09001P	PARTICIPANT	\N	PRESENT	0
28918	24344	11059R	PARTICIPANT	\N	PRESENT	0
27416	27415	01008M	PARTICIPANT	\N	PRESENT	0
27417	27415	11036J	PARTICIPANT	\N	PRESENT	0
27630	27629	11068S	PARTICIPANT	\N	PRESENT	0
27419	27415	14013P	PARTICIPANT	\N	PRESENT	0
27420	27415	08068F	PARTICIPANT	\N	PRESENT	0
27421	27415	14207L	PARTICIPANT	\N	PRESENT	0
27422	27415	11101A	PARTICIPANT	\N	PRESENT	0
27423	27415	90003B	PARTICIPANT	\N	PRESENT	0
27424	27415	08028W	PARTICIPANT	\N	PRESENT	0
27425	27415	80013X	PARTICIPANT	\N	PRESENT	0
27426	27415	08038Y	PARTICIPANT	\N	PRESENT	0
27427	27415	04089T	PARTICIPANT	\N	PRESENT	0
27428	27415	14197C	PARTICIPANT	\N	EXCUSE	0
27429	27415	11110B	PARTICIPANT	\N	PRESENT	0
27430	27415	14187A	PARTICIPANT	\N	PRESENT	0
27431	27415	14033T	PARTICIPANT	\N	PRESENT	0
27432	27415	14081Q	PARTICIPANT	\N	PRESENT	0
27433	27415	04048J	PARTICIPANT	\N	PRESENT	0
27434	27415	11099A	PARTICIPANT	\N	PRESENT	0
27435	27415	04049K	PARTICIPANT	\N	PRESENT	0
27436	27415	04094Q	PARTICIPANT	\N	PRESENT	0
27437	27415	11111C	PARTICIPANT	\N	PRESENT	0
27438	27415	08015R	PARTICIPANT	\N	PRESENT	0
27439	27415	11100Y	PRESIDENT	0	PRESENT	0
27440	27415	01061S	PARTICIPANT	\N	PRESENT	0
27441	27415	11098Y	PARTICIPANT	\N	PRESENT	0
27442	27415	01043Q	PARTICIPANT	\N	PRESENT	0
27443	27415	11077T	PARTICIPANT	\N	PRESENT	0
27444	27415	14205J	PARTICIPANT	\N	PRESENT	0
27631	27629	14083S	PARTICIPANT	\N	PRESENT	0
27446	27415	14257W	PARTICIPANT	\N	PRESENT	0
27632	27629	04038G	PARTICIPANT	\N	PRESENT	0
27448	27415	04088S	PARTICIPANT	\N	PRESENT	0
27449	27415	98050T	PARTICIPANT	\N	PRESENT	0
27633	27629	98023Q	PARTICIPANT	\N	PRESENT	0
27451	27415	11046L	PARTICIPANT	\N	PRESENT	0
27452	27415	01058X	PARTICIPANT	\N	PRESENT	0
27453	27415	11094U	PARTICIPANT	\N	PRESENT	0
27454	27415	11066Q	PARTICIPANT	\N	PRESENT	0
27634	27629	11056N	PARTICIPANT	\N	EXCUSE	0
27635	27629	11035H	PARTICIPANT	\N	PRESENT	0
27636	27629	08022Q	PARTICIPANT	\N	PRESENT	0
27637	27629	98042T	PARTICIPANT	\N	PRESENT	0
27638	27629	11026G	PARTICIPANT	\N	PRESENT	0
27639	27629	01061S	PARTICIPANT	\N	PRESENT	0
27640	27629	08051V	PARTICIPANT	\N	PRESENT	0
27641	27629	14169X	PARTICIPANT	\N	PRESENT	0
27642	27629	04074L	PARTICIPANT	\N	PRESENT	0
27643	27629	95063L	PARTICIPANT	\N	PRESENT	0
27644	27629	14227Q	PARTICIPANT	\N	PRESENT	0
27645	27629	01056V	PARTICIPANT	\N	PRESENT	0
27650	27649	89017R	PARTICIPANT	0	PRESENT	0
27651	27649	01031L	PRESIDENT	0	PRESENT	0
27701	27649	95015C	RAPPORTEUR_AVIS	\N	PRESENT	0
27653	27649	01013J	PARTICIPANT	\N	PRESENT	0
27654	27649	11068S	PARTICIPANT	\N	PRESENT	0
27655	27649	11040E	PARTICIPANT	\N	PRESENT	0
27821	27201	08024S	PARTICIPANT	\N	PRESENT	0
27848	27201	01013J	PARTICIPANT	\N	PRESENT	0
27658	27649	14175V	PARTICIPANT	\N	PRESENT	0
27659	27649	14083S	PARTICIPANT	\N	PRESENT	0
27852	27201	01031L	PARTICIPANT	\N	PRESENT	0
27661	27649	14085U	PARTICIPANT	\N	PRESENT	0
27662	27649	11042G	PARTICIPANT	\N	PRESENT	0
27856	27201	14063N	PARTICIPANT	\N	PRESENT	0
27664	27649	04086Q	PARTICIPANT	\N	PRESENT	0
27665	27649	04055H	PARTICIPANT	\N	PRESENT	0
27666	27649	11070L	PARTICIPANT	\N	PRESENT	0
27667	27649	11088W	PARTICIPANT	\N	PRESENT	0
27668	27649	14327T	PARTICIPANT	\N	PRESENT	0
27669	27649	08022Q	PARTICIPANT	\N	PRESENT	0
27670	27649	01027Q	PARTICIPANT	\N	PRESENT	0
27671	27649	04071H	PARTICIPANT	\N	PRESENT	0
27672	27649	11074Q	PARTICIPANT	\N	PRESENT	0
27673	27649	98053W	PARTICIPANT	\N	PRESENT	0
27674	27649	11083R	PARTICIPANT	\N	PRESENT	0
27858	27201	14159V	PARTICIPANT	\N	PRESENT	0
27676	27649	01057W	PARTICIPANT	\N	PRESENT	0
27862	27201	11042G	PARTICIPANT	\N	PRESENT	0
27867	27201	11068S	PARTICIPANT	\N	PRESENT	0
27870	27201	14085U	PARTICIPANT	\N	PRESENT	0
27680	27649	99004R	PARTICIPANT	\N	PRESENT	0
27681	27649	04061F	PARTICIPANT	\N	PRESENT	0
27682	27649	14159V	PARTICIPANT	\N	PRESENT	0
27683	27649	07029T	PARTICIPANT	\N	PRESENT	0
27873	27201	11083R	PARTICIPANT	\N	PRESENT	0
27685	27649	08010L	PARTICIPANT	\N	PRESENT	0
27686	27649	08034U	PARTICIPANT	\N	PRESENT	0
27687	27649	01048V	PARTICIPANT	\N	PRESENT	0
27688	27649	98046X	PARTICIPANT	\N	PRESENT	0
27876	27201	11037K	PARTICIPANT	\N	PRESENT	0
27690	27649	08011M	PARTICIPANT	\N	PRESENT	0
27691	27649	08073C	PARTICIPANT	\N	PRESENT	0
27692	27649	08061X	PARTICIPANT	\N	PRESENT	0
27880	27201	11076S	PARTICIPANT	\N	PRESENT	0
27694	27649	14225N	PARTICIPANT	\N	PRESENT	0
27695	27649	11012A	PARTICIPANT	\N	PRESENT	0
27696	27649	11057P	PARTICIPANT	\N	PRESENT	0
27886	27201	11012A	PARTICIPANT	\N	PRESENT	0
27698	27649	04034C	PARTICIPANT	\N	PRESENT	0
27890	27201	14103D	PARTICIPANT	\N	PRESENT	0
27892	27201	14042U	PARTICIPANT	\N	PRESENT	0
27894	27201	14219Q	PARTICIPANT	\N	PRESENT	0
27899	27201	11070L	PARTICIPANT	\N	PRESENT	0
27907	27201	14097Y	PARTICIPANT	\N	PRESENT	0
27908	27201	14121F	PARTICIPANT	\N	PRESENT	0
27910	27201	01027Q	PARTICIPANT	\N	PRESENT	0
27913	27201	98046X	PARTICIPANT	\N	PRESENT	0
27915	27201	08061X	PARTICIPANT	\N	PRESENT	0
27917	27201	14239U	PARTICIPANT	\N	PRESENT	0
27919	27201	14173T	PARTICIPANT	\N	PRESENT	0
27921	27201	14191V	PARTICIPANT	\N	PRESENT	0
27923	27201	04041B	PARTICIPANT	\N	PRESENT	0
27924	27201	14223L	PARTICIPANT	\N	PRESENT	0
27925	27201	01057W	PARTICIPANT	\N	PRESENT	0
27926	27201	14033T	PARTICIPANT	\N	PRESENT	0
27928	27201	07029T	PARTICIPANT	\N	PRESENT	0
27930	27201	98018T	PARTICIPANT	\N	PRESENT	0
27931	27201	07024N	PARTICIPANT	\N	PRESENT	0
27932	27201	07034Q	PARTICIPANT	\N	PRESENT	0
27933	27201	11088W	PARTICIPANT	\N	PRESENT	0
27934	27201	11091R	PARTICIPANT	\N	PRESENT	0
27935	27201	11025F	PARTICIPANT	\N	PRESENT	0
27936	27201	01058X	PARTICIPANT	\N	PRESENT	0
27937	27201	08062Y	PARTICIPANT	\N	PRESENT	0
27938	27201	14061L	PARTICIPANT	\N	PRESENT	0
27939	27201	11048N	PARTICIPANT	\N	PRESENT	0
27940	27201	14269B	PARTICIPANT	\N	PRESENT	0
27941	27201	11067R	PARTICIPANT	\N	PRESENT	0
27942	27201	87003B	PARTICIPANT	\N	PRESENT	0
27943	27201	14231L	PARTICIPANT	\N	PRESENT	0
27944	27201	14249W	PARTICIPANT	\N	PRESENT	0
27945	27201	01046T	PARTICIPANT	\N	PRESENT	0
27946	27201	14265W	PARTICIPANT	\N	PRESENT	0
27947	27201	98050T	PARTICIPANT	\N	PRESENT	0
27948	27201	11103C	PARTICIPANT	\N	PRESENT	0
27949	27201	14195A	PARTICIPANT	\N	PRESENT	0
27950	27201	04092N	PARTICIPANT	\N	PRESENT	0
27951	27201	04045F	PARTICIPANT	\N	PRESENT	0
27952	27201	14031R	PARTICIPANT	\N	PRESENT	0
27953	27201	11036J	PARTICIPANT	\N	PRESENT	0
27954	27201	14267Y	PARTICIPANT	\N	PRESENT	0
27955	27201	11093T	PARTICIPANT	\N	PRESENT	0
27956	27201	14073Q	PARTICIPANT	\N	PRESENT	0
27957	27201	86044G	PARTICIPANT	\N	PRESENT	0
27958	27201	01008M	PARTICIPANT	\N	PRESENT	0
27959	27201	98024R	PARTICIPANT	\N	PRESENT	0
27960	27201	14105F	PARTICIPANT	\N	PRESENT	0
27961	27201	11029K	PARTICIPANT	\N	PRESENT	0
27962	27201	10015M	PARTICIPANT	\N	PRESENT	0
27963	27201	11112D	PARTICIPANT	\N	PRESENT	0
27964	27201	01059Y	PARTICIPANT	\N	PRESENT	0
27965	27201	14083S	PARTICIPANT	\N	PRESENT	0
27966	27201	08053X	PARTICIPANT	\N	PRESENT	0
27471	27469	14239U	PARTICIPANT	\N	PRESENT	0
27472	27469	11055M	PARTICIPANT	\N	PRESENT	0
27473	27469	01046T	PARTICIPANT	\N	PRESENT	0
27474	27469	04053F	PARTICIPANT	\N	PRESENT	0
27475	27469	14255U	PARTICIPANT	\N	PRESENT	0
27476	27469	04066L	PARTICIPANT	\N	PRESENT	0
27824	27822	04054G	PARTICIPANT	\N	PRESENT	0
27478	27469	14053L	PARTICIPANT	\N	PRESENT	0
27479	27469	11103C	PARTICIPANT	\N	PRESENT	0
27825	27822	96004D	PRESIDENT	0	PRESENT	0
27481	27469	14195A	PARTICIPANT	\N	PRESENT	0
27482	27469	14267Y	PARTICIPANT	\N	PRESENT	0
27828	27822	95030B	PARTICIPANT	\N	EXCUSE	0
27484	27469	11031D	PARTICIPANT	\N	EXCUSE	0
27485	27469	08052W	PARTICIPANT	\N	PRESENT	0
27486	27469	01059Y	PARTICIPANT	\N	PRESENT	0
27487	27469	04081K	PARTICIPANT	\N	PRESENT	0
27488	27469	98024R	PARTICIPANT	\N	PRESENT	0
27830	27822	08018U	PARTICIPANT	\N	PRESENT	0
27490	27469	04067M	PARTICIPANT	\N	PRESENT	0
27491	27469	14217N	PARTICIPANT	\N	PRESENT	0
27492	27469	14042U	PARTICIPANT	\N	PRESENT	0
27493	27469	14151M	PARTICIPANT	\N	PRESENT	0
27494	27469	12042Y	PARTICIPANT	\N	PRESENT	0
27495	27469	14281W	PARTICIPANT	\N	PRESENT	0
27831	27822	04035D	PARTICIPANT	\N	EXCUSE	0
27497	27469	01003G	PARTICIPANT	\N	PRESENT	0
27498	27469	14034U	PARTICIPANT	\N	PRESENT	0
27499	27469	14231L	PARTICIPANT	\N	PRESENT	0
27500	27469	11061K	PARTICIPANT	\N	PRESENT	0
27833	27822	11083R	PARTICIPANT	\N	PRESENT	0
27502	27469	08041T	PARTICIPANT	\N	PRESENT	0
27503	27469	01011G	PARTICIPANT	\N	PRESENT	0
27504	27469	14026U	PARTICIPANT	\N	EXCUSE	0
27835	27822	14026U	PARTICIPANT	\N	EXCUSE	0
27506	27469	14121F	PARTICIPANT	\N	PRESENT	0
27507	27469	11112D	PARTICIPANT	\N	PRESENT	0
27508	27469	14037X	PARTICIPANT	\N	PRESENT	0
27509	27469	14018U	PARTICIPANT	\N	PRESENT	0
27510	27469	11067R	PARTICIPANT	\N	PRESENT	0
27511	27469	14223L	PARTICIPANT	\N	PRESENT	0
27512	27469	04092N	PRESIDENT	0	PRESENT	0
27513	27469	14265W	PARTICIPANT	\N	PRESENT	0
27514	27469	14119M	PARTICIPANT	\N	PRESENT	0
27515	27469	14071N	PARTICIPANT	\N	PRESENT	0
27516	27469	07032N	PARTICIPANT	\N	PRESENT	0
27517	27469	04043D	PARTICIPANT	\N	PRESENT	0
27518	27469	14271U	PARTICIPANT	\N	PRESENT	0
27836	27822	14097Y	PARTICIPANT	\N	PRESENT	0
27520	27469	11093T	PARTICIPANT	\N	PRESENT	0
27521	27469	11097X	PARTICIPANT	\N	EXCUSE	0
27522	27469	04045F	PARTICIPANT	\N	PRESENT	0
27523	27469	14227Q	PARTICIPANT	\N	PRESENT	0
27524	27469	01034P	PARTICIPANT	\N	PRESENT	0
27525	27469	11025F	PARTICIPANT	\N	PRESENT	0
27526	27469	11063M	PARTICIPANT	\N	PRESENT	0
27527	27469	14269B	PARTICIPANT	\N	PRESENT	0
27839	27822	14073Q	PARTICIPANT	\N	PRESENT	0
27841	27822	11026G	PARTICIPANT	\N	EXCUSE	0
27843	27822	14001X	PARTICIPANT	\N	PRESENT	0
27844	27822	04057K	PARTICIPANT	\N	EXCUSE	0
27847	27822	14135M	PARTICIPANT	\N	EXCUSE	0
27849	27822	10015M	PARTICIPANT	\N	PRESENT	0
27850	27826	01031L	PRESIDENT	0	PRESENT	0
27851	27822	04045F	PARTICIPANT	\N	PRESENT	0
27854	27822	98035U	PARTICIPANT	\N	PRESENT	0
27859	27822	04034C	PARTICIPANT	\N	PRESENT	0
27863	27826	11068S	PARTICIPANT	\N	PRESENT	0
27871	27826	14175V	PARTICIPANT	\N	PRESENT	0
27877	27826	14083S	PARTICIPANT	\N	PRESENT	0
27881	27826	14085U	PARTICIPANT	\N	PRESENT	0
27882	27826	11042G	PARTICIPANT	\N	PRESENT	0
27887	27826	11070L	PARTICIPANT	\N	PRESENT	0
27889	27826	11088W	PARTICIPANT	\N	PRESENT	0
27893	27826	08022Q	PARTICIPANT	\N	PRESENT	0
27895	27826	01027Q	PARTICIPANT	\N	PRESENT	0
27903	27826	11074Q	PARTICIPANT	\N	PRESENT	0
27904	27826	11083R	PARTICIPANT	\N	PRESENT	0
27905	27826	14199E	PARTICIPANT	\N	PRESENT	0
27906	27826	01057W	PARTICIPANT	\N	PRESENT	0
27909	27826	11048N	PARTICIPANT	\N	PRESENT	0
27911	27826	14159V	PARTICIPANT	\N	PRESENT	0
27912	27826	07029T	PARTICIPANT	\N	PRESENT	0
27914	27826	08034U	PARTICIPANT	\N	PRESENT	0
27916	27826	98046X	PARTICIPANT	\N	PRESENT	0
27918	27826	08011M	PARTICIPANT	\N	EXCUSE	0
27920	27826	08073C	PARTICIPANT	\N	PRESENT	0
27922	27826	08061X	PARTICIPANT	\N	PRESENT	0
27927	27826	14173T	PARTICIPANT	\N	PRESENT	0
27929	27826	04034C	PARTICIPANT	\N	PRESENT	0
28032	27203	01059Y	PARTICIPANT	\N	PRESENT	0
28033	27203	08061X	PARTICIPANT	\N	PRESENT	0
28034	27203	08053X	PARTICIPANT	\N	PRESENT	0
28035	27203	11112D	PARTICIPANT	\N	PRESENT	0
28036	27203	14269B	PARTICIPANT	\N	PRESENT	0
28037	27203	14063N	PARTICIPANT	\N	PRESENT	0
28038	27203	14257W	PARTICIPANT	\N	PRESENT	0
28039	27203	11067R	PARTICIPANT	\N	PRESENT	0
28040	27203	14121F	PARTICIPANT	\N	PRESENT	0
28041	27203	14097Y	PARTICIPANT	\N	PRESENT	0
28042	27203	11036J	PARTICIPANT	\N	PRESENT	0
28043	27203	11025F	PARTICIPANT	\N	PRESENT	0
28044	27203	14085U	PARTICIPANT	\N	PRESENT	0
28045	27203	11068S	PARTICIPANT	\N	PRESENT	0
28046	27203	11029K	PARTICIPANT	\N	PRESENT	0
28047	27203	11083R	PARTICIPANT	\N	PRESENT	0
28048	27203	11037K	PARTICIPANT	\N	PRESENT	0
28049	27203	14103D	PARTICIPANT	\N	PRESENT	0
28050	27203	14219Q	PARTICIPANT	\N	PRESENT	0
28051	27203	14042U	PARTICIPANT	\N	PRESENT	0
28052	27203	12042Y	PARTICIPANT	\N	PRESENT	0
28053	27203	14267Y	PARTICIPANT	\N	PRESENT	0
28054	27203	01011G	PARTICIPANT	\N	PRESENT	0
28055	27203	11093T	PARTICIPANT	\N	PRESENT	0
28056	27203	14231L	PARTICIPANT	\N	PRESENT	0
28057	27203	14083S	PARTICIPANT	\N	PRESENT	0
28058	27203	04053F	PARTICIPANT	\N	PRESENT	0
28059	27203	01046T	PARTICIPANT	\N	PRESENT	0
28060	27203	14249W	PARTICIPANT	\N	PRESENT	0
28061	27203	14217N	PARTICIPANT	\N	PRESENT	0
28062	27203	01008M	PARTICIPANT	\N	PRESENT	0
28063	27203	14061L	PARTICIPANT	\N	PRESENT	0
28064	27203	11103C	PARTICIPANT	\N	PRESENT	0
28065	27203	14037X	PARTICIPANT	\N	PRESENT	0
28066	27203	86044G	PARTICIPANT	\N	PRESENT	0
28067	27203	11088W	PARTICIPANT	\N	PRESENT	0
28068	27203	14215L	PARTICIPANT	\N	PRESENT	0
28069	27203	98050T	PARTICIPANT	\N	PRESENT	0
28070	27203	14265W	PARTICIPANT	\N	PRESENT	0
28071	27203	14271U	PARTICIPANT	\N	PRESENT	0
28072	27203	11091R	PARTICIPANT	\N	PRESENT	0
28073	27203	08062Y	PARTICIPANT	\N	PRESENT	0
28074	27203	07029T	PARTICIPANT	\N	PRESENT	0
28075	27203	14195A	PARTICIPANT	\N	PRESENT	0
28076	27203	14105F	PARTICIPANT	\N	PRESENT	0
28077	27203	01057W	PARTICIPANT	\N	PRESENT	0
28078	27203	14223L	PARTICIPANT	\N	PRESENT	0
28079	27203	14191V	PARTICIPANT	\N	PRESENT	0
28080	27203	11061K	PARTICIPANT	\N	PRESENT	0
28030	27203	08024S	PARTICIPANT	\N	PRESENT	0
28031	27203	01013J	PARTICIPANT	\N	PRESENT	0
28081	27203	04092N	PARTICIPANT	\N	PRESENT	0
28082	27203	14239U	PARTICIPANT	\N	PRESENT	0
28083	27203	98024R	PARTICIPANT	\N	PRESENT	0
28084	27203	07034Q	PARTICIPANT	\N	PRESENT	0
28085	27203	01058X	PARTICIPANT	\N	PRESENT	0
28086	27203	14169X	PARTICIPANT	\N	PRESENT	0
28087	27203	08010L	PARTICIPANT	\N	PRESENT	0
28088	27203	95031C	PARTICIPANT	\N	PRESENT	0
28089	27203	01027Q	PARTICIPANT	\N	PRESENT	0
28090	27203	11101A	PARTICIPANT	\N	PRESENT	0
28091	27203	04088S	PARTICIPANT	\N	PRESENT	0
28092	27203	87003B	PARTICIPANT	\N	PRESENT	0
28093	27203	10015M	PARTICIPANT	\N	PRESENT	0
28094	27203	08016S	PARTICIPANT	\N	PRESENT	0
28095	27203	14207L	PARTICIPANT	\N	PRESENT	0
28096	27203	11063M	PARTICIPANT	\N	PRESENT	0
28097	27203	04048J	PARTICIPANT	\N	PRESENT	0
28098	27203	08034U	PARTICIPANT	\N	PRESENT	0
28099	27203	04043D	PARTICIPANT	\N	PRESENT	0
28100	27203	11066Q	PARTICIPANT	\N	PRESENT	0
28101	27203	14031R	PARTICIPANT	\N	PRESENT	0
28102	27203	14073Q	PARTICIPANT	\N	PRESENT	0
28103	27203	04049K	PARTICIPANT	\N	PRESENT	0
28104	27203	11043H	PARTICIPANT	\N	PRESENT	0
28105	27203	04038G	PARTICIPANT	\N	PRESENT	0
28106	27203	11012A	PARTICIPANT	\N	PRESENT	0
28107	27203	11110B	PARTICIPANT	\N	PRESENT	0
28156	28153	08024S	PARTICIPANT	\N	PRESENT	0
28157	28153	01007L	PARTICIPANT	\N	PRESENT	0
28158	28153	98053W	PARTICIPANT	\N	PRESENT	0
28159	28153	04081K	PARTICIPANT	\N	PRESENT	0
28160	28153	04066L	PARTICIPANT	\N	PRESENT	0
28161	28153	11085T	PARTICIPANT	\N	PRESENT	0
28162	28153	08055A	PARTICIPANT	\N	PRESENT	0
28163	28153	11039M	PARTICIPANT	\N	PRESENT	0
28164	28153	01019Q	PARTICIPANT	\N	PRESENT	0
28165	28153	98042T	PARTICIPANT	\N	PRESENT	0
28166	28153	89017R	PARTICIPANT	\N	PRESENT	0
28167	28153	04042C	PARTICIPANT	\N	PRESENT	0
28168	28153	04067M	PARTICIPANT	\N	PRESENT	0
28169	28153	11110B	PARTICIPANT	\N	PRESENT	0
28170	28153	01003G	PARTICIPANT	\N	PRESENT	0
28171	28153	95037J	PARTICIPANT	\N	PRESENT	0
28172	28153	04094Q	PARTICIPANT	\N	PRESENT	0
28173	28153	08039A	PARTICIPANT	\N	PRESENT	0
28174	28153	01043Q	PARTICIPANT	\N	PRESENT	0
28175	28153	04057K	PARTICIPANT	\N	PRESENT	0
28176	28153	04088S	PARTICIPANT	\N	PRESENT	0
28177	28153	04056J	PARTICIPANT	\N	PRESENT	0
28178	27204	86034E	PARTICIPANT	\N	PRESENT	0
28179	27204	11110B	PARTICIPANT	\N	PRESENT	0
28180	27204	04036E	PARTICIPANT	\N	PRESENT	0
28181	27204	11037K	PARTICIPANT	\N	PRESENT	0
28182	27204	01056V	PARTICIPANT	\N	PRESENT	0
28183	27204	14103D	PARTICIPANT	\N	PRESENT	0
28184	27204	01011G	PARTICIPANT	\N	PRESENT	0
28185	27204	14327T	PARTICIPANT	\N	PRESENT	0
28186	27204	14223L	PARTICIPANT	\N	PRESENT	0
28187	27204	95031C	PARTICIPANT	\N	PRESENT	0
28188	27204	90003B	PARTICIPANT	\N	PRESENT	0
28189	27204	92018S	PARTICIPANT	\N	PRESENT	0
28190	27204	05008E	PARTICIPANT	\N	PRESENT	0
28191	27204	11015D	PARTICIPANT	\N	PRESENT	0
28192	27204	14081Q	PARTICIPANT	\N	PRESENT	0
28193	27204	11103C	PARTICIPANT	\N	PRESENT	0
28194	27204	08015R	PARTICIPANT	\N	PRESENT	0
28195	27204	14195A	PARTICIPANT	\N	PRESENT	0
28196	27204	08053X	PARTICIPANT	\N	PRESENT	0
28197	27204	14073Q	PARTICIPANT	\N	PRESENT	0
28198	27204	11106F	PARTICIPANT	\N	PRESENT	0
28199	27204	14018U	PARTICIPANT	\N	PRESENT	0
28154	28153	86034E	PARTICIPANT	\N	PRESENT	0
28200	27204	11025F	PARTICIPANT	\N	PRESENT	0
28201	27204	04048J	PARTICIPANT	\N	PRESENT	0
28202	27204	04088S	PARTICIPANT	\N	PRESENT	0
28203	27204	87003B	PARTICIPANT	\N	PRESENT	0
28204	27204	14175V	PARTICIPANT	\N	PRESENT	0
28205	27204	07026Q	PARTICIPANT	\N	PRESENT	0
28206	27204	14051J	PARTICIPANT	\N	PRESENT	0
28207	27204	80013X	PARTICIPANT	\N	PRESENT	0
28208	27204	14059S	PARTICIPANT	\N	PRESENT	0
28209	27204	01015L	PARTICIPANT	\N	PRESENT	0
28210	27204	01013J	PARTICIPANT	\N	PRESENT	0
28211	27204	11039M	PARTICIPANT	\N	PRESENT	0
28212	27204	08055A	PARTICIPANT	\N	PRESENT	0
28213	27204	11032E	PARTICIPANT	\N	PRESENT	0
28214	27204	13002U	PARTICIPANT	\N	PRESENT	0
28215	27204	98029W	PARTICIPANT	\N	PRESENT	0
28216	27204	04066L	PARTICIPANT	\N	PRESENT	0
28217	27204	14109K	PARTICIPANT	\N	PRESENT	0
28218	27204	04034C	PARTICIPANT	\N	PRESENT	0
28219	27204	11029K	PARTICIPANT	\N	PRESENT	0
28220	27204	11055M	PARTICIPANT	\N	PRESENT	0
28221	27204	08024S	PARTICIPANT	\N	PRESENT	0
28222	27204	04053F	PARTICIPANT	\N	PRESENT	0
28223	27204	11056N	PARTICIPANT	\N	PRESENT	0
28224	27204	11034G	PARTICIPANT	\N	PRESENT	0
28225	27204	14013P	PARTICIPANT	\N	PRESENT	0
28226	27204	01059Y	PARTICIPANT	\N	PRESENT	0
28227	27649	14173T	PARTICIPANT	\N	PRESENT	0
28228	27204	01022K	PARTICIPANT	\N	PRESENT	0
28229	27204	98053W	PARTICIPANT	\N	PRESENT	0
28230	27204	07024N	PARTICIPANT	\N	PRESENT	0
28231	27204	11099A	PARTICIPANT	\N	PRESENT	0
28232	27204	11069T	PARTICIPANT	\N	PRESENT	0
28233	27204	11065P	PARTICIPANT	\N	PRESENT	0
28234	27204	96004D	PARTICIPANT	\N	PRESENT	0
28235	27204	01044R	PARTICIPANT	\N	PRESENT	0
28236	27204	01008M	PARTICIPANT	\N	PRESENT	0
28237	27204	04067M	PARTICIPANT	\N	PRESENT	0
28238	27204	11033F	PARTICIPANT	\N	PRESENT	0
28239	27204	04061F	PARTICIPANT	\N	PRESENT	0
28240	27204	11060J	PARTICIPANT	\N	PRESENT	0
28241	27204	11083R	PARTICIPANT	\N	PRESENT	0
28242	27204	01058X	PARTICIPANT	\N	PRESENT	0
28243	27204	98018T	PARTICIPANT	\N	PRESENT	0
28244	27204	14026U	PARTICIPANT	\N	PRESENT	0
28245	27204	01060R	PARTICIPANT	\N	PRESENT	0
28246	27204	14055N	PARTICIPANT	\N	PRESENT	0
28247	27204	14105F	PARTICIPANT	\N	PRESENT	0
28248	27204	08051V	PARTICIPANT	\N	PRESENT	0
28249	27204	07029T	PARTICIPANT	\N	PRESENT	0
28250	27204	01046T	PARTICIPANT	\N	PRESENT	0
28251	27204	08031R	PARTICIPANT	\N	PRESENT	0
28252	27204	04078Q	PARTICIPANT	\N	PRESENT	0
28253	27204	04042C	PARTICIPANT	\N	PRESENT	0
28254	27204	11076S	PARTICIPANT	\N	PRESENT	0
28255	27204	11012A	PARTICIPANT	\N	PRESENT	0
28256	27204	04038G	PARTICIPANT	\N	PRESENT	0
28257	27204	11081P	PARTICIPANT	\N	PRESENT	0
28258	27204	98022P	PARTICIPANT	\N	PRESENT	0
28259	27204	99004R	PARTICIPANT	\N	PRESENT	0
28260	27204	08016S	PARTICIPANT	\N	PRESENT	0
28261	27204	14061L	PARTICIPANT	\N	PRESENT	0
28262	27204	98035U	PARTICIPANT	\N	PRESENT	0
28263	27204	14037X	PARTICIPANT	\N	PRESENT	0
28264	27204	04071H	PARTICIPANT	\N	PRESENT	0
28265	27204	98046X	PARTICIPANT	\N	PRESENT	0
28266	27204	08052W	PARTICIPANT	\N	PRESENT	0
28267	27204	14187A	PARTICIPANT	\N	PRESENT	0
28268	27204	95063L	PARTICIPANT	\N	PRESENT	0
28269	27204	04081K	PARTICIPANT	\N	PRESENT	0
28270	27204	14151M	PARTICIPANT	\N	PRESENT	0
28271	27204	04057K	PARTICIPANT	\N	PRESENT	0
28272	27204	11061K	PARTICIPANT	\N	PRESENT	0
28273	27204	08022Q	PARTICIPANT	\N	PRESENT	0
28274	27204	11112D	PARTICIPANT	\N	PRESENT	0
28275	27204	11067R	PARTICIPANT	\N	PRESENT	0
28276	27204	04086Q	PARTICIPANT	\N	PRESENT	0
28277	27204	08012N	PARTICIPANT	\N	PRESENT	0
28279	27204	11100Y	PARTICIPANT	\N	PRESENT	0
28280	27204	11036J	PARTICIPANT	\N	PRESENT	0
28281	27204	86044G	PARTICIPANT	\N	PRESENT	0
28282	27204	11042G	PARTICIPANT	\N	PRESENT	0
28283	27204	01027Q	PARTICIPANT	\N	PRESENT	0
28284	27204	08058D	PARTICIPANT	\N	PRESENT	0
28285	27204	14215L	PARTICIPANT	\N	PRESENT	0
28286	27204	14097Y	PARTICIPANT	\N	PRESENT	0
28287	27204	77002U	PARTICIPANT	\N	PRESENT	0
28288	27204	14001X	PARTICIPANT	\N	PRESENT	0
28289	27204	92031P	PARTICIPANT	\N	PRESENT	0
28290	27204	11027H	PARTICIPANT	\N	PRESENT	0
28291	27204	08010L	PARTICIPANT	\N	PRESENT	0
28292	27204	11095V	PARTICIPANT	\N	PRESENT	0
28293	27204	11074Q	PARTICIPANT	\N	PRESENT	0
28294	27204	14207L	PARTICIPANT	\N	PRESENT	0
28295	27204	98023Q	PARTICIPANT	\N	PRESENT	0
28296	27204	11014C	PARTICIPANT	\N	PRESENT	0
28297	27204	14257W	PARTICIPANT	\N	PRESENT	0
28298	27204	01057W	PARTICIPANT	\N	PRESENT	0
28300	27204	14063N	PARTICIPANT	\N	PRESENT	0
28301	27204	14121F	PARTICIPANT	\N	PRESENT	0
28302	27204	14227Q	PARTICIPANT	\N	PRESENT	0
28303	27204	14225N	PARTICIPANT	\N	PRESENT	0
28304	27204	04056J	PARTICIPANT	\N	PRESENT	0
28305	27204	14031R	PARTICIPANT	\N	PRESENT	0
28306	27204	08061X	PARTICIPANT	\N	PRESENT	0
28307	27204	14255U	PARTICIPANT	\N	PRESENT	0
28308	27204	01028R	PARTICIPANT	\N	PRESENT	0
28309	27204	14251Q	PARTICIPANT	\N	PRESENT	0
28310	27204	11104D	PARTICIPANT	\N	PRESENT	0
28311	27204	14111D	PARTICIPANT	\N	PRESENT	0
28312	27204	08038Y	PARTICIPANT	\N	PRESENT	0
28313	27204	11080N	PARTICIPANT	\N	PRESENT	0
28314	27204	92039X	PARTICIPANT	\N	PRESENT	0
28315	27204	11066Q	PARTICIPANT	\N	PRESENT	0
28316	27204	04092N	PARTICIPANT	\N	PRESENT	0
28317	27204	11068S	PARTICIPANT	\N	PRESENT	0
28318	27204	14271U	PARTICIPANT	\N	PRESENT	0
28319	27204	01043Q	PARTICIPANT	\N	PRESENT	0
28320	27204	14281W	PARTICIPANT	\N	PRESENT	0
28321	27204	14263U	PARTICIPANT	\N	PRESENT	0
28322	27204	04085P	PARTICIPANT	\N	PRESENT	0
28942	28401	04066L	PARTICIPANT	\N	PRESENT	0
28943	28401	07034Q	PARTICIPANT	\N	PRESENT	0
28944	28401	11037K	PARTICIPANT	\N	PRESENT	0
28945	28401	11056N	PARTICIPANT	\N	PRESENT	0
28946	28401	01028R	PARTICIPANT	\N	PRESENT	0
28947	28401	11033F	PARTICIPANT	\N	PRESENT	0
28948	28401	14041T	PARTICIPANT	\N	PRESENT	0
28949	28401	04036E	PARTICIPANT	\N	PRESENT	0
28950	28401	14103D	PARTICIPANT	\N	PRESENT	0
28951	28401	07004J	PARTICIPANT	\N	PRESENT	0
28952	28401	08041T	PARTICIPANT	\N	PRESENT	0
28953	28401	14087W	PARTICIPANT	\N	PRESENT	0
28954	28401	95049N	PARTICIPANT	\N	PRESENT	0
28955	28401	14265W	PARTICIPANT	\N	PRESENT	0
28956	28401	95063L	PARTICIPANT	\N	PRESENT	0
28957	28401	10015M	PARTICIPANT	\N	PRESENT	0
28958	28401	14223L	PARTICIPANT	\N	PRESENT	0
28959	28401	14065Q	PARTICIPANT	\N	PRESENT	0
28960	28401	11034G	PARTICIPANT	\N	PRESENT	0
28961	28401	01013J	PARTICIPANT	\N	PRESENT	0
28962	28401	11072N	PARTICIPANT	\N	PRESENT	0
28963	28401	14215L	PARTICIPANT	\N	PRESENT	0
28964	28401	14073Q	PARTICIPANT	\N	PRESENT	0
28965	28401	14039A	PARTICIPANT	\N	PRESENT	0
28966	28401	04085P	PARTICIPANT	\N	PRESENT	0
28967	28401	05008E	PARTICIPANT	\N	PRESENT	0
28968	28401	14235Q	PARTICIPANT	\N	PRESENT	0
28969	28401	01003G	PARTICIPANT	\N	PRESENT	0
28970	28401	14105F	PARTICIPANT	\N	PRESENT	0
28971	28401	08015R	PARTICIPANT	\N	PRESENT	0
28972	28401	14213J	PARTICIPANT	\N	PRESENT	0
28973	28401	14147R	PARTICIPANT	\N	PRESENT	0
28974	28401	01048V	PARTICIPANT	\N	PRESENT	0
28975	28401	95031C	PARTICIPANT	\N	PRESENT	0
28976	28401	99004R	PARTICIPANT	\N	PRESENT	0
28977	28401	11100Y	PARTICIPANT	\N	PRESENT	0
28978	28401	11064N	PARTICIPANT	\N	PRESENT	0
28979	28401	14089Y	PARTICIPANT	\N	PRESENT	0
28980	28401	14083S	PARTICIPANT	\N	PRESENT	0
28981	28401	14263U	PARTICIPANT	\N	PRESENT	0
28982	28401	88008L	PARTICIPANT	\N	PRESENT	0
28983	28401	04038G	PARTICIPANT	\N	PRESENT	0
28984	28401	14205J	PARTICIPANT	\N	PRESENT	0
28985	28401	14247U	PARTICIPANT	\N	PRESENT	0
28986	28401	97011G	PARTICIPANT	\N	PRESENT	0
28987	28401	08048B	PARTICIPANT	\N	PRESENT	0
28988	28401	11048N	PARTICIPANT	\N	PRESENT	0
28989	28401	87003B	PARTICIPANT	\N	PRESENT	0
28990	28401	14187A	PARTICIPANT	\N	PRESENT	0
28991	28401	14267Y	PARTICIPANT	\N	PRESENT	0
28992	28401	11094U	PARTICIPANT	\N	PRESENT	0
28993	28401	11103C	PARTICIPANT	\N	PRESENT	0
28994	28401	08044W	PARTICIPANT	\N	PRESENT	0
28995	28401	04074L	PARTICIPANT	\N	PRESENT	0
28996	28401	11083R	PARTICIPANT	\N	PRESENT	0
28997	28401	08035V	PARTICIPANT	\N	PRESENT	0
28998	28401	01019Q	PARTICIPANT	\N	PRESENT	0
28999	28401	01058X	PARTICIPANT	\N	PRESENT	0
29000	28401	98053W	PARTICIPANT	\N	PRESENT	0
29001	28401	96004D	PARTICIPANT	\N	PRESENT	0
29002	28401	11035H	PARTICIPANT	\N	PRESENT	0
29003	28401	11030C	PARTICIPANT	\N	PRESENT	0
29004	28401	14033T	PARTICIPANT	\N	PRESENT	0
29005	28401	11043H	PARTICIPANT	\N	PRESENT	0
29006	28401	08031R	PARTICIPANT	\N	PRESENT	0
29007	28401	04056J	PARTICIPANT	\N	PRESENT	0
29008	28401	14159V	PARTICIPANT	\N	PRESENT	0
29009	28401	14237S	PARTICIPANT	\N	PRESENT	0
29010	28401	14079W	PARTICIPANT	\N	PRESENT	0
29011	28401	14063N	PARTICIPANT	\N	PRESENT	0
29012	28401	08018U	PARTICIPANT	\N	PRESENT	0
29013	28401	11106F	PARTICIPANT	\N	PRESENT	0
29014	28401	01041N	PARTICIPANT	\N	PRESENT	0
29015	28401	80027E	PARTICIPANT	\N	PRESENT	0
29016	28401	14034U	PARTICIPANT	\N	PRESENT	0
29017	28401	14219Q	PARTICIPANT	\N	PRESENT	0
29018	28401	04041B	PARTICIPANT	\N	PRESENT	0
29019	28401	95067Q	PARTICIPANT	\N	PRESENT	0
29020	28401	08028W	PARTICIPANT	\N	PRESENT	0
29021	28401	07032N	PARTICIPANT	\N	PRESENT	0
29022	28401	01025N	PARTICIPANT	\N	PRESENT	0
29023	28401	08051V	PARTICIPANT	\N	PRESENT	0
29024	28401	14026U	PARTICIPANT	\N	PRESENT	0
29025	28401	04088S	PARTICIPANT	\N	PRESENT	0
29026	28401	14135M	PARTICIPANT	\N	PRESENT	0
29027	28401	14031R	PARTICIPANT	\N	PRESENT	0
29028	28401	14038Y	PARTICIPANT	\N	PRESENT	0
29029	28401	95062K	PARTICIPANT	\N	PRESENT	0
29030	28401	14259Y	PARTICIPANT	\N	PRESENT	0
29031	28401	11036J	PARTICIPANT	\N	PRESENT	0
29032	28401	08053X	PARTICIPANT	\N	PRESENT	0
29033	28401	08062Y	PARTICIPANT	\N	PRESENT	0
29034	28401	14169X	PARTICIPANT	\N	PRESENT	0
29035	28401	14173T	PARTICIPANT	\N	PRESENT	0
29036	28401	14030Q	PARTICIPANT	\N	PRESENT	0
29037	28401	14179A	PARTICIPANT	\N	PRESENT	0
29038	28401	14211G	PARTICIPANT	\N	PRESENT	0
29039	28401	04059M	PARTICIPANT	\N	PRESENT	0
29040	28401	11088W	PARTICIPANT	\N	PRESENT	0
29041	28401	11049P	PARTICIPANT	\N	PRESENT	0
29042	28401	11066Q	PARTICIPANT	\N	PRESENT	0
29043	28401	11054L	PARTICIPANT	\N	PRESENT	0
29044	28401	14001X	PARTICIPANT	\N	PRESENT	0
29045	28401	10006L	PARTICIPANT	\N	PRESENT	0
29046	28401	04057K	PARTICIPANT	\N	PRESENT	0
29047	28401	80013X	PARTICIPANT	\N	PRESENT	0
29048	28401	01046T	PARTICIPANT	\N	PRESENT	0
29049	28401	14061L	PARTICIPANT	\N	PRESENT	0
29050	28401	14257W	PARTICIPANT	\N	PRESENT	0
29051	28401	08025T	PARTICIPANT	\N	PRESENT	0
29052	28401	01022K	PARTICIPANT	\N	PRESENT	0
29053	28401	14207L	PARTICIPANT	\N	PRESENT	0
29054	28401	14273W	PARTICIPANT	\N	PRESENT	0
29055	28401	14059S	PARTICIPANT	\N	PRESENT	0
29056	28401	08010L	PARTICIPANT	\N	PRESENT	0
29057	28401	14221J	PARTICIPANT	\N	PRESENT	0
29058	28401	14085U	PARTICIPANT	\N	PRESENT	0
29059	28401	08043V	PARTICIPANT	\N	PRESENT	0
29060	28401	11012A	PARTICIPANT	\N	PRESENT	0
29061	28401	11070L	PARTICIPANT	\N	PRESENT	0
29062	28401	08019V	PARTICIPANT	\N	PRESENT	0
29063	28401	14109K	PARTICIPANT	\N	PRESENT	0
29064	28401	14197C	PARTICIPANT	\N	PRESENT	0
29065	28401	11074Q	PARTICIPANT	\N	PRESENT	0
29066	28401	14081Q	PARTICIPANT	\N	PRESENT	0
29067	28401	07026Q	PARTICIPANT	\N	PRESENT	0
29068	28401	11067R	PARTICIPANT	\N	PRESENT	0
29069	28401	14209N	PARTICIPANT	\N	PRESENT	0
29070	28401	14013P	PARTICIPANT	\N	PRESENT	0
29071	28401	11031D	PARTICIPANT	\N	PRESENT	0
29072	28401	11098Y	PARTICIPANT	\N	PRESENT	0
29073	28401	01015L	PARTICIPANT	\N	PRESENT	0
29074	28401	11040E	PARTICIPANT	\N	PRESENT	0
29075	28401	11063M	PARTICIPANT	\N	PRESENT	0
29076	28401	08012N	PARTICIPANT	\N	PRESENT	0
29077	28401	14227Q	PARTICIPANT	\N	PRESENT	0
29078	28401	14271U	PARTICIPANT	\N	PRESENT	0
29079	28401	14229S	PARTICIPANT	\N	PRESENT	0
29080	28401	13002U	PARTICIPANT	\N	PRESENT	0
29081	28401	11014C	PARTICIPANT	\N	PRESENT	0
29082	28401	11015D	PARTICIPANT	\N	PRESENT	0
29083	28401	08060W	PARTICIPANT	\N	PRESENT	0
29084	28401	00003C	PARTICIPANT	\N	PRESENT	0
29085	28401	14107H	PARTICIPANT	\N	PRESENT	0
29086	28401	08055A	PARTICIPANT	\N	PRESENT	0
29087	28401	98046X	PARTICIPANT	\N	PRESENT	0
29088	28401	08052W	PARTICIPANT	\N	PRESENT	0
29089	28401	14151M	PARTICIPANT	\N	PRESENT	0
29090	28401	14051J	PARTICIPANT	\N	PRESENT	0
29091	28401	01031L	PARTICIPANT	\N	PRESENT	0
29092	28401	01011G	PARTICIPANT	\N	PRESENT	0
29093	28401	14028W	PARTICIPANT	\N	PRESENT	0
29095	28401	04045F	PARTICIPANT	\N	PRESENT	0
29096	28401	11085T	PARTICIPANT	\N	PRESENT	0
29097	28401	04077P	PARTICIPANT	\N	PRESENT	0
29098	28401	98021N	PARTICIPANT	\N	PRESENT	0
29099	28401	08061X	PARTICIPANT	\N	PRESENT	0
29100	28401	05004A	PARTICIPANT	\N	PRESENT	0
29942	29941	01031L	PRESIDENT	0	PRESENT	0
29943	29941	11040E	PARTICIPANT	\N	PRESENT	0
29944	29941	14085U	PARTICIPANT	\N	PRESENT	0
29945	29941	11042G	PARTICIPANT	\N	PRESENT	0
29946	29941	88008L	PARTICIPANT	\N	PRESENT	0
29947	29941	04086Q	PARTICIPANT	\N	PRESENT	0
29948	29941	04055H	PARTICIPANT	\N	PRESENT	0
29949	29941	11070L	PARTICIPANT	\N	PRESENT	0
29950	29941	01027Q	PARTICIPANT	\N	PRESENT	0
29951	29941	11074Q	PARTICIPANT	\N	PRESENT	0
29952	29941	11083R	PARTICIPANT	\N	PRESENT	0
29953	29941	01057W	PARTICIPANT	\N	PRESENT	0
29954	29941	14159V	PARTICIPANT	\N	PRESENT	0
29955	29941	07029T	PARTICIPANT	\N	PRESENT	0
29956	29941	08010L	PARTICIPANT	\N	PRESENT	0
29959	29941	98046X	PARTICIPANT	\N	PRESENT	0
29961	29941	08011M	PARTICIPANT	\N	PRESENT	0
29963	29941	14225N	PARTICIPANT	\N	PRESENT	0
29964	29941	11012A	PARTICIPANT	\N	PRESENT	0
29965	29941	14173T	PARTICIPANT	\N	PRESENT	0
29966	29941	04034C	PARTICIPANT	\N	PRESENT	0
29967	29941	11057P	PARTICIPANT	\N	PRESENT	0
29993	29881	98022P	PARTICIPANT	\N	PRESENT	0
30010	30006	11076S	PARTICIPANT	\N	PRESENT	0
30011	30006	04054G	PARTICIPANT	\N	PRESENT	0
30012	30006	04040A	PARTICIPANT	\N	PRESENT	0
30013	30006	08058D	PARTICIPANT	\N	PRESENT	0
30014	30006	04042C	PARTICIPANT	\N	PRESENT	0
30015	30006	77002U	PARTICIPANT	\N	PRESENT	0
30016	30006	98029W	PARTICIPANT	\N	PRESENT	0
30017	30006	11080N	PARTICIPANT	\N	EXCUSE	0
30018	30006	11027H	PARTICIPANT	\N	PRESENT	0
30019	30006	98018T	PARTICIPANT	\N	EXCUSE	0
30021	30006	92020L	PARTICIPANT	\N	PRESENT	0
30022	30006	95030B	PARTICIPANT	\N	PRESENT	0
30696	30653	05008E	PARTICIPANT	\N	PRESENT	0
30076	30006	95031C	PARTICIPANT	\N	PRESENT	0
30025	30006	97011G	PARTICIPANT	\N	PRESENT	0
30026	30006	08065C	PARTICIPANT	\N	EXCUSE	0
30027	30006	04035D	PARTICIPANT	\N	PRESENT	0
30028	30006	07024N	PARTICIPANT	\N	EXCUSE	0
30697	30653	11029K	PARTICIPANT	\N	PRESENT	0
30030	30006	14014Q	PARTICIPANT	\N	PRESENT	0
30031	30006	11015D	PARTICIPANT	\N	PRESENT	0
30032	30006	07004J	PARTICIPANT	\N	PRESENT	0
30698	30653	04088S	PARTICIPANT	\N	PRESENT	0
30699	30653	14041T	PARTICIPANT	\N	PRESENT	0
30035	30006	14211G	PARTICIPANT	\N	PRESENT	0
30036	30006	98022P	PARTICIPANT	\N	PRESENT	0
30037	30006	11064N	PARTICIPANT	\N	PRESENT	0
30038	30006	95037J	PARTICIPANT	\N	PRESENT	0
30039	30006	04078Q	PARTICIPANT	\N	EXCUSE	0
30040	30006	14097Y	PARTICIPANT	\N	PRESENT	0
30041	30006	95041E	PARTICIPANT	\N	PRESENT	0
30042	30006	04036E	PARTICIPANT	\N	PRESENT	0
30043	30006	14039A	PARTICIPANT	\N	PRESENT	0
30044	30006	04077P	PARTICIPANT	\N	PRESENT	0
30700	30653	14059S	PARTICIPANT	\N	PRESENT	0
30046	30006	92031P	PARTICIPANT	\N	PRESENT	0
30047	30006	11106F	PARTICIPANT	\N	PRESENT	0
30048	30006	14251Q	PARTICIPANT	\N	PRESENT	0
30701	30653	14026U	PARTICIPANT	\N	PRESENT	0
30050	30006	08053X	PARTICIPANT	\N	PRESENT	0
30702	30653	01028R	PARTICIPANT	\N	PRESENT	0
30703	30653	11056N	PARTICIPANT	\N	PRESENT	0
30704	30653	11098Y	PARTICIPANT	\N	PRESENT	0
30054	30006	08047A	PARTICIPANT	\N	PRESENT	0
30055	30006	14028W	PARTICIPANT	\N	PRESENT	0
30056	30006	14193X	PARTICIPANT	\N	PRESENT	0
30057	30006	98021N	PARTICIPANT	\N	PRESENT	0
30705	30653	11012A	PARTICIPANT	\N	PRESENT	0
30059	30006	04080J	PARTICIPANT	\N	PRESENT	0
30060	30006	95059Q	PRESIDENT	0	PRESENT	0
30706	30653	95049N	PARTICIPANT	\N	PRESENT	0
30062	30006	01014K	PARTICIPANT	\N	PRESENT	0
30063	30006	11054L	PARTICIPANT	\N	PRESENT	0
30064	30006	01056V	PARTICIPANT	\N	PRESENT	0
30065	30006	92044U	PARTICIPANT	\N	PRESENT	0
30066	30006	08049C	PARTICIPANT	\N	PRESENT	0
30079	30006	92018S	PARTICIPANT	\N	PRESENT	0
30707	30653	14215L	PARTICIPANT	\N	PRESENT	0
30708	30653	14079W	PARTICIPANT	\N	PRESENT	0
30709	30653	08051V	PARTICIPANT	\N	PRESENT	0
30710	30653	14065Q	PARTICIPANT	\N	PRESENT	0
30711	30653	11033F	PARTICIPANT	\N	PRESENT	0
30712	30653	14033T	PARTICIPANT	\N	PRESENT	0
30713	30653	80013X	PARTICIPANT	\N	PRESENT	0
30714	30653	04044E	PARTICIPANT	\N	PRESENT	0
30715	30653	95063L	PARTICIPANT	\N	PRESENT	0
30716	30653	14219Q	PARTICIPANT	\N	PRESENT	0
30717	30653	14217N	PARTICIPANT	\N	PRESENT	0
30718	30653	95030B	PARTICIPANT	\N	PRESENT	0
30719	30653	11049P	PARTICIPANT	\N	PRESENT	0
30720	30653	08060W	PARTICIPANT	\N	PRESENT	0
30721	30653	11036J	PARTICIPANT	\N	PRESENT	0
30722	30653	14097Y	PARTICIPANT	\N	PRESENT	0
30723	30653	01016M	PARTICIPANT	\N	PRESENT	0
30724	30653	14069U	PARTICIPANT	\N	PRESENT	0
30725	30653	14209N	PARTICIPANT	\N	PRESENT	0
30726	30653	95067Q	PARTICIPANT	\N	PRESENT	0
30727	30653	14265W	PARTICIPANT	\N	PRESENT	0
30728	30653	14237S	PARTICIPANT	\N	PRESENT	0
30729	30653	14259Y	PARTICIPANT	\N	PRESENT	0
30730	30653	14179A	PARTICIPANT	\N	PRESENT	0
30732	30731	08025T	PARTICIPANT	\N	PRESENT	0
30694	30653	08055A	PARTICIPANT	\N	PRESENT	0
30695	30653	01024M	PARTICIPANT	\N	PRESENT	0
30733	30731	04085P	PARTICIPANT	\N	PRESENT	0
30734	30731	05008E	PRESIDENT	0	PRESENT	0
30735	30653	14083S	PARTICIPANT	\N	PRESENT	0
30736	30731	11030C	PARTICIPANT	\N	PRESENT	0
30737	30731	11033F	PARTICIPANT	\N	PRESENT	0
30738	30731	14065Q	PARTICIPANT	\N	PRESENT	0
30739	30731	14069U	PARTICIPANT	\N	PRESENT	0
30740	30653	10006L	PARTICIPANT	\N	PRESENT	0
30741	30731	04038G	PARTICIPANT	\N	PRESENT	0
30742	30731	99002P	PARTICIPANT	\N	PRESENT	0
30743	30731	11056N	PARTICIPANT	\N	PRESENT	0
30744	30731	14259Y	PARTICIPANT	\N	PRESENT	0
30782	30653	11031D	PARTICIPANT	\N	PRESENT	0
30746	30731	14041T	PARTICIPANT	\N	PRESENT	0
30747	30731	11113E	PARTICIPANT	\N	PRESENT	0
30748	30731	01024M	PARTICIPANT	\N	PRESENT	0
30749	30731	14215L	PARTICIPANT	\N	PRESENT	0
30750	30653	14133K	PARTICIPANT	\N	PRESENT	0
30751	30731	11034G	PARTICIPANT	\N	PRESENT	0
30752	30731	08018U	PARTICIPANT	\N	PRESENT	0
30753	30731	01007L	PARTICIPANT	\N	PRESENT	0
30754	30731	11049P	PARTICIPANT	\N	PRESENT	0
30755	30731	08044W	PARTICIPANT	\N	PRESENT	0
30756	30731	11084S	PARTICIPANT	\N	PRESENT	0
30757	30731	11026G	PARTICIPANT	\N	PRESENT	0
30758	30731	04079R	PARTICIPANT	\N	PRESENT	0
30759	30731	14111D	PARTICIPANT	\N	PRESENT	0
30760	30731	14001X	PARTICIPANT	\N	PRESENT	0
30761	30731	14273W	PARTICIPANT	\N	EXCUSE	0
30762	30731	01060R	PARTICIPANT	\N	PRESENT	0
30763	30731	14147R	PARTICIPANT	\N	PRESENT	0
30764	30731	95049N	PARTICIPANT	\N	PRESENT	0
30765	30731	08051V	PARTICIPANT	\N	PRESENT	0
30766	30731	11072N	PARTICIPANT	\N	PRESENT	0
30767	30731	07034Q	PRESIDENT	1	PRESENT	0
30768	30731	04074L	PARTICIPANT	\N	PRESENT	0
30769	30731	10015M	PARTICIPANT	\N	PRESENT	0
30770	30731	95063L	PARTICIPANT	\N	PRESENT	0
30771	30731	01019Q	PARTICIPANT	\N	PRESENT	0
30772	30731	01028R	PARTICIPANT	\N	PRESENT	0
30773	30731	98035U	PARTICIPANT	\N	PRESENT	0
30774	30731	04056J	PARTICIPANT	\N	PRESENT	0
30775	30731	14275Y	PARTICIPANT	\N	PRESENT	0
30776	30731	04044E	PARTICIPANT	\N	PRESENT	0
30777	30731	11037K	PARTICIPANT	\N	PRESENT	0
30778	30731	92045V	PARTICIPANT	\N	PRESENT	0
30779	30731	95067Q	PARTICIPANT	\N	PRESENT	0
30780	30731	01047U	PARTICIPANT	\N	PRESENT	0
30781	30731	11035H	PARTICIPANT	\N	PRESENT	0
30783	30653	04085P	PARTICIPANT	\N	PRESENT	0
30784	30653	11112D	PARTICIPANT	\N	PRESENT	0
30807	30577	01027Q	PARTICIPANT	\N	PRESENT	0
30809	30808	01008M	PARTICIPANT	\N	PRESENT	0
30810	30808	11036J	PARTICIPANT	\N	PRESENT	0
30812	30808	14013P	PARTICIPANT	\N	PRESENT	0
30813	30808	08068F	PARTICIPANT	\N	PRESENT	0
30814	30808	14207L	PARTICIPANT	\N	PRESENT	0
30228	28721	04081K	PARTICIPANT	\N	PRESENT	0
30229	28721	07034Q	PARTICIPANT	\N	PRESENT	0
30230	28721	14033T	PARTICIPANT	\N	PRESENT	0
30231	28721	14041T	PARTICIPANT	\N	PRESENT	0
30233	28721	11072N	PARTICIPANT	\N	PRESENT	0
30244	28721	14097Y	PARTICIPANT	\N	PRESENT	0
30249	28721	01024M	PARTICIPANT	\N	PRESENT	0
30252	28721	04038G	PARTICIPANT	\N	PRESENT	0
30255	28721	95049N	PARTICIPANT	\N	PRESENT	0
30257	28721	14147R	PARTICIPANT	\N	PRESENT	0
30258	28721	08051V	PARTICIPANT	\N	PRESENT	0
30262	28721	14263U	PARTICIPANT	\N	PRESENT	0
30263	28721	11056N	PARTICIPANT	\N	PRESENT	0
30264	28721	05008E	PARTICIPANT	\N	PRESENT	0
30267	28721	14219Q	PARTICIPANT	\N	PRESENT	0
30268	28721	11103C	PARTICIPANT	\N	PRESENT	0
30269	28721	08062Y	PARTICIPANT	\N	PRESENT	0
30270	28721	14265W	PARTICIPANT	\N	PRESENT	0
30271	28721	95062K	PARTICIPANT	\N	PRESENT	0
30272	28721	01028R	PARTICIPANT	\N	PRESENT	0
30313	28721	87003B	PARTICIPANT	\N	PRESENT	0
30274	30106	08055A	PARTICIPANT	\N	PRESENT	0
30316	28721	11034G	PARTICIPANT	\N	PRESENT	0
30276	30106	14030Q	PARTICIPANT	\N	PRESENT	0
30277	30106	96004D	PARTICIPANT	\N	PRESENT	0
30278	30106	08060W	PARTICIPANT	\N	PRESENT	0
30314	28721	04056J	PARTICIPANT	\N	PRESENT	0
30280	30106	11095V	PARTICIPANT	\N	PRESENT	0
30315	28721	14169X	PARTICIPANT	\N	PRESENT	0
30282	30106	11114F	PARTICIPANT	\N	PRESENT	0
30283	30106	98023Q	PARTICIPANT	\N	PRESENT	0
30317	28721	11114F	PARTICIPANT	\N	PRESENT	0
30285	30106	01015L	PARTICIPANT	\N	PRESENT	0
30286	30106	11107G	PARTICIPANT	\N	PRESENT	0
30287	30106	11020A	PARTICIPANT	\N	PRESENT	0
30288	30106	02002K	PARTICIPANT	\N	PRESENT	0
30289	30106	01022K	PARTICIPANT	\N	PRESENT	0
30290	30106	04097T	PARTICIPANT	\N	PRESENT	0
30291	30106	09001P	PARTICIPANT	\N	PRESENT	0
30292	30106	11059R	PARTICIPANT	\N	PRESENT	0
30293	30106	14219Q	PARTICIPANT	\N	PRESENT	0
30294	30106	80027E	PARTICIPANT	\N	PRESENT	0
30295	30106	14031R	PARTICIPANT	\N	PRESENT	0
30296	30106	08009T	PRESIDENT	0	PRESENT	0
30297	30106	08062Y	PARTICIPANT	\N	PRESENT	0
30298	30106	14221J	PARTICIPANT	\N	PRESENT	0
30299	30106	92039X	PARTICIPANT	\N	PRESENT	0
30300	30106	08042U	PARTICIPANT	\N	PRESENT	0
30301	30106	14169X	PARTICIPANT	\N	PRESENT	0
30302	30106	14237S	PARTICIPANT	\N	PRESENT	0
30303	30106	13002U	PARTICIPANT	\N	PRESENT	0
30304	30106	05012A	PARTICIPANT	\N	EXCUSE	0
30305	30106	14247U	PARTICIPANT	\N	PRESENT	0
30306	30106	14135M	PARTICIPANT	\N	PRESENT	0
30307	30106	95062K	PARTICIPANT	\N	PRESENT	0
30308	30106	14107H	PARTICIPANT	\N	PRESENT	0
30309	30106	14051J	PARTICIPANT	\N	PRESENT	0
30310	30106	14157T	PARTICIPANT	\N	EXCUSE	0
30319	30318	01008M	PARTICIPANT	\N	PRESENT	0
30312	28721	14026U	PARTICIPANT	\N	PRESENT	0
30320	30318	11036J	PARTICIPANT	\N	PRESENT	0
30358	28721	14013P	PARTICIPANT	\N	PRESENT	0
30322	30318	14013P	PARTICIPANT	\N	PRESENT	0
30323	30318	08068F	PARTICIPANT	\N	PRESENT	0
30324	30318	14207L	PARTICIPANT	\N	PRESENT	0
30325	30318	11101A	PARTICIPANT	\N	PRESENT	0
30326	30318	90003B	PARTICIPANT	\N	PRESENT	0
30327	30318	08028W	PARTICIPANT	\N	PRESENT	0
30328	30318	80013X	PARTICIPANT	\N	PRESENT	0
30329	30318	08038Y	PARTICIPANT	\N	PRESENT	0
30330	30318	04089T	PARTICIPANT	\N	PRESENT	0
30331	30318	14197C	PARTICIPANT	\N	PRESENT	0
30359	28721	14069U	PARTICIPANT	\N	PRESENT	0
30360	28721	08035V	PARTICIPANT	\N	PRESENT	0
30334	30318	14033T	PARTICIPANT	\N	PRESENT	0
30335	30318	14081Q	PARTICIPANT	\N	PRESENT	0
30361	28721	14187A	PARTICIPANT	\N	PRESENT	0
30337	30318	11099A	PARTICIPANT	\N	PRESENT	0
30338	30318	04049K	PARTICIPANT	\N	PRESENT	0
30339	30318	04094Q	PARTICIPANT	\N	PRESENT	0
30340	30318	11111C	PARTICIPANT	\N	PRESENT	0
30341	30318	08015R	PARTICIPANT	\N	PRESENT	0
30342	30318	11100Y	PRESIDENT	0	PRESENT	0
30343	30318	01061S	PARTICIPANT	\N	PRESENT	0
30344	30318	11098Y	PARTICIPANT	\N	PRESENT	0
30345	30318	01043Q	PARTICIPANT	\N	PRESENT	0
30362	28721	04074L	PARTICIPANT	\N	PRESENT	0
30347	30318	14205J	PARTICIPANT	\N	PRESENT	0
30348	30318	08019V	PARTICIPANT	\N	PRESENT	0
30349	30318	14257W	PARTICIPANT	\N	PRESENT	0
30350	30318	08021P	PARTICIPANT	\N	PRESENT	0
30351	30318	04088S	PARTICIPANT	\N	PRESENT	0
30352	30318	98050T	PARTICIPANT	\N	PRESENT	0
30353	30318	11090Q	PARTICIPANT	\N	PRESENT	0
30354	30318	11046L	PARTICIPANT	\N	PRESENT	0
30363	28721	14135M	PARTICIPANT	\N	PRESENT	0
30364	28721	14065Q	PARTICIPANT	\N	PRESENT	0
30357	30318	11066Q	PARTICIPANT	\N	PRESENT	0
30365	28721	11049P	PARTICIPANT	\N	PRESENT	0
30366	28721	14121F	PARTICIPANT	\N	PRESENT	0
30367	28721	14257W	PARTICIPANT	\N	PRESENT	0
30368	28721	14030Q	PARTICIPANT	\N	PRESENT	0
30369	28721	11035H	PARTICIPANT	\N	PRESENT	0
30370	28721	08015R	PARTICIPANT	\N	PRESENT	0
30371	28721	10015M	PARTICIPANT	\N	PRESENT	0
30373	30372	04081K	PARTICIPANT	\N	PRESENT	0
30422	30372	14133K	PARTICIPANT	\N	PRESENT	0
30375	30372	14033T	PARTICIPANT	\N	PRESENT	0
30376	30372	14041T	PARTICIPANT	\N	PRESENT	0
30377	30372	11072N	PARTICIPANT	\N	PRESENT	0
30378	30372	14097Y	PARTICIPANT	\N	PRESENT	0
30379	30372	01024M	PARTICIPANT	\N	PRESENT	0
30420	30372	14215L	PARTICIPANT	\N	PRESENT	0
30381	30372	95049N	PARTICIPANT	\N	PRESENT	0
30382	30372	14147R	PARTICIPANT	\N	PRESENT	0
30383	30372	08051V	PARTICIPANT	\N	PRESENT	0
30384	30372	14263U	PARTICIPANT	\N	PRESENT	0
30385	30372	11056N	PARTICIPANT	\N	PRESENT	0
30386	30372	05008E	PARTICIPANT	\N	PRESENT	0
30387	30372	14219Q	PARTICIPANT	\N	PRESENT	0
30388	30372	11103C	PARTICIPANT	\N	PRESENT	0
30389	30372	14265W	PARTICIPANT	\N	PRESENT	0
30390	30372	95062K	PARTICIPANT	\N	PRESENT	0
30391	30372	01028R	PARTICIPANT	\N	PRESENT	0
30417	30372	14105F	PARTICIPANT	\N	PRESENT	0
30416	30372	98050T	PARTICIPANT	\N	PRESENT	0
30394	30372	04056J	PARTICIPANT	\N	PRESENT	0
30418	30372	11066Q	PARTICIPANT	\N	PRESENT	0
30396	30372	11034G	PARTICIPANT	\N	PRESENT	0
30397	30372	11114F	PARTICIPANT	\N	PRESENT	0
30398	30372	14013P	PARTICIPANT	\N	PRESENT	0
30419	30372	08068F	PARTICIPANT	\N	PRESENT	0
30580	30577	01031L	PRESIDENT	0	PRESENT	0
30401	30372	04074L	PARTICIPANT	\N	PRESENT	0
30402	30372	14135M	PARTICIPANT	\N	PRESENT	0
30403	30372	14065Q	PARTICIPANT	\N	PRESENT	0
30404	30372	11049P	PARTICIPANT	\N	PRESENT	0
30405	30372	14121F	PARTICIPANT	\N	PRESENT	0
30406	30372	14257W	PARTICIPANT	\N	PRESENT	0
30407	30372	14030Q	PARTICIPANT	\N	PRESENT	0
30408	30372	11035H	PARTICIPANT	\N	PRESENT	0
30421	30372	04085P	PARTICIPANT	\N	PRESENT	0
30410	30372	10015M	PARTICIPANT	\N	PRESENT	0
30411	30372	14205J	PARTICIPANT	\N	PRESENT	0
30412	30372	04088S	PARTICIPANT	\N	PRESENT	0
30583	30577	01013J	PARTICIPANT	\N	PRESENT	0
30414	30372	14259Y	PARTICIPANT	\N	PRESENT	0
30415	30372	11036J	PARTICIPANT	\N	PRESENT	0
30423	30372	14199E	PARTICIPANT	\N	PRESENT	0
30424	30372	14026U	PARTICIPANT	\N	PRESENT	0
30425	30372	08015R	PARTICIPANT	\N	PRESENT	0
30426	30372	14237S	PARTICIPANT	\N	PRESENT	0
30579	30577	89017R	PARTICIPANT	\N	EXCUSE	0
30428	30372	14267Y	PARTICIPANT	\N	PRESENT	0
30429	30372	08060W	PARTICIPANT	\N	PRESENT	0
30430	30372	01046T	PARTICIPANT	\N	PRESENT	0
30431	30372	14051J	PARTICIPANT	\N	PRESENT	0
30432	30372	11033F	PARTICIPANT	\N	PRESENT	0
30433	30372	80013X	PARTICIPANT	\N	PRESENT	0
30434	30372	01047U	PARTICIPANT	\N	PRESENT	0
30435	30372	11085T	PARTICIPANT	\N	PRESENT	0
30584	30577	11068S	PARTICIPANT	\N	PRESENT	0
30585	30577	11040E	PARTICIPANT	\N	PRESENT	0
30586	30577	08014Q	PARTICIPANT	\N	PRESENT	0
30587	30577	14175V	PARTICIPANT	\N	PRESENT	0
30588	30577	14083S	PARTICIPANT	\N	PRESENT	0
30589	30577	11053K	PARTICIPANT	\N	PRESENT	0
30590	30577	14085U	PARTICIPANT	\N	PRESENT	0
30591	30577	11042G	PARTICIPANT	\N	PRESENT	0
29180	29094	11109J	PARTICIPANT	\N	PRESENT	0
29110	29094	08055A	PARTICIPANT	\N	PRESENT	0
29111	29094	14093U	PARTICIPANT	\N	PRESENT	0
29112	29094	14030Q	PARTICIPANT	\N	PRESENT	0
29186	29094	14259Y	PARTICIPANT	\N	PRESENT	0
29192	29094	14097Y	PARTICIPANT	\N	PRESENT	0
29193	29094	14039A	PARTICIPANT	\N	PRESENT	0
29195	29094	04094Q	PARTICIPANT	\N	PRESENT	0
29117	29094	14038Y	PARTICIPANT	\N	PRESENT	0
29118	29094	11114F	PARTICIPANT	\N	PRESENT	0
29119	29094	98023Q	PARTICIPANT	\N	PRESENT	0
29120	29094	11065P	PARTICIPANT	\N	PRESENT	0
29121	29094	01015L	PARTICIPANT	\N	PRESENT	0
29122	29094	11107G	PARTICIPANT	\N	PRESENT	0
29123	29094	11020A	PARTICIPANT	\N	PRESENT	0
29124	29094	02002K	PARTICIPANT	\N	PRESENT	0
29125	29094	01022K	PARTICIPANT	\N	PRESENT	0
29126	29094	04097T	PARTICIPANT	\N	PRESENT	0
29127	29094	09001P	PARTICIPANT	\N	PRESENT	0
29128	29094	11059R	PARTICIPANT	\N	PRESENT	0
29129	29094	14219Q	PARTICIPANT	\N	PRESENT	0
29130	29094	80027E	PARTICIPANT	\N	PRESENT	0
29131	29094	14031R	PARTICIPANT	\N	PRESENT	0
29132	29094	08009T	PRESIDENT	0	PRESENT	0
29207	29094	14059S	PARTICIPANT	\N	PRESENT	0
29134	29094	14221J	PARTICIPANT	\N	PRESENT	0
29135	29094	92039X	PARTICIPANT	\N	PRESENT	0
29136	29094	08042U	PARTICIPANT	\N	EXCUSE	0
29137	29094	14169X	PARTICIPANT	\N	PRESENT	0
29138	29094	14237S	PARTICIPANT	\N	PRESENT	0
29139	29094	13002U	PARTICIPANT	\N	PRESENT	0
29140	29094	05012A	PARTICIPANT	\N	PRESENT	0
29210	29094	11106F	PARTICIPANT	\N	PRESENT	0
29211	29094	08019V	PARTICIPANT	\N	PRESENT	0
29143	29094	95062K	PARTICIPANT	\N	PRESENT	0
29144	29094	14107H	PARTICIPANT	\N	PRESENT	0
29214	29094	11072N	PARTICIPANT	\N	PRESENT	0
29146	29094	14157T	PARTICIPANT	\N	PRESENT	0
29217	29094	11054L	PARTICIPANT	\N	PRESENT	0
29219	29094	14275Y	PARTICIPANT	\N	PRESENT	0
29882	29881	11076S	PARTICIPANT	\N	PRESENT	0
30077	30075	14133K	PARTICIPANT	\N	PRESENT	0
29884	29881	04040A	PARTICIPANT	\N	PRESENT	0
29885	29881	08058D	PARTICIPANT	\N	PRESENT	0
30082	30075	96004D	PRESIDENT	0	PRESENT	0
30592	30577	88008L	PARTICIPANT	\N	PRESENT	0
29888	29881	98029W	PARTICIPANT	\N	PRESENT	0
30091	30075	14089Y	PARTICIPANT	\N	PRESENT	0
29890	29881	11027H	PARTICIPANT	\N	PRESENT	0
29891	29881	98018T	PARTICIPANT	\N	EXCUSE	0
29892	29881	92018S	PARTICIPANT	\N	PRESENT	0
29893	29881	92020L	PARTICIPANT	\N	PRESENT	0
29894	29881	95030B	PARTICIPANT	\N	PRESENT	0
30092	30075	90003B	PARTICIPANT	\N	EXCUSE	0
30093	30075	11035H	PARTICIPANT	\N	PRESENT	0
29897	29881	97011G	PARTICIPANT	\N	PRESENT	0
29898	29881	08065C	PARTICIPANT	\N	EXCUSE	0
29899	29881	04035D	PARTICIPANT	\N	EXCUSE	0
29900	29881	07024N	PARTICIPANT	\N	EXCUSE	0
30094	30075	04035D	PARTICIPANT	\N	EXCUSE	0
29902	29881	14014Q	PARTICIPANT	\N	PRESENT	0
30095	30075	11026G	PARTICIPANT	\N	PRESENT	0
30096	30075	14001X	PARTICIPANT	\N	PRESENT	0
29905	29881	95035G	PARTICIPANT	\N	EXCUSE	0
30097	30075	04057K	PARTICIPANT	\N	PRESENT	0
30098	30075	08021P	PARTICIPANT	\N	EXCUSE	0
30099	30075	04080J	PARTICIPANT	\N	PRESENT	0
29909	29881	11064N	PARTICIPANT	\N	PRESENT	0
29910	29881	95037J	PARTICIPANT	\N	PRESENT	0
29911	29881	04078Q	PARTICIPANT	\N	EXCUSE	0
29912	29881	14097Y	PARTICIPANT	\N	PRESENT	0
29913	29881	95041E	PARTICIPANT	\N	EXCUSE	0
29914	29881	04036E	PARTICIPANT	\N	PRESENT	0
30100	30075	01016M	PARTICIPANT	\N	PRESENT	0
29916	29881	04077P	PARTICIPANT	\N	PRESENT	0
30593	30577	04086Q	PARTICIPANT	\N	PRESENT	0
29918	29881	92031P	PARTICIPANT	\N	PRESENT	0
29919	29881	11106F	PARTICIPANT	\N	PRESENT	0
29920	29881	14251Q	PARTICIPANT	\N	PRESENT	0
30594	30577	11070L	PARTICIPANT	\N	PRESENT	0
29922	29881	08053X	PARTICIPANT	\N	PRESENT	0
30595	30577	11088W	PARTICIPANT	\N	PRESENT	0
30596	30577	08022Q	PARTICIPANT	\N	PRESENT	0
30632	30629	11031D	PARTICIPANT	\N	PRESENT	0
29926	29881	08047A	PARTICIPANT	\N	PRESENT	0
29927	29881	14028W	PARTICIPANT	\N	PRESENT	0
29928	29881	14193X	PARTICIPANT	\N	PRESENT	0
29929	29881	98021N	PARTICIPANT	\N	PRESENT	0
30598	30577	04071H	PARTICIPANT	\N	PRESENT	0
30101	30075	04045F	PARTICIPANT	\N	PRESENT	0
29932	29881	95059Q	PRESIDENT	0	PRESENT	0
30599	30577	11074Q	PARTICIPANT	\N	PRESENT	0
29934	29881	01014K	PARTICIPANT	\N	PRESENT	0
29935	29881	11054L	PARTICIPANT	\N	PRESENT	0
30102	30075	92045V	PARTICIPANT	\N	PRESENT	0
29937	29881	92044U	PARTICIPANT	\N	PRESENT	0
29938	29881	08049C	PARTICIPANT	\N	PRESENT	0
29939	29881	04071H	RAPPORTEUR_AVIS	\N	PRESENT	0
30103	30075	08073C	PARTICIPANT	\N	EXCUSE	0
30104	30075	11083R	PARTICIPANT	\N	PRESENT	0
30600	30577	11083R	PARTICIPANT	\N	PRESENT	0
30604	30577	08069G	PARTICIPANT	\N	PRESENT	0
30602	30577	01057W	PARTICIPANT	\N	PRESENT	0
30603	30577	08016S	PARTICIPANT	\N	PRESENT	0
30605	30577	11048N	PARTICIPANT	\N	PRESENT	0
30606	30577	99004R	PARTICIPANT	\N	PRESENT	0
30607	30577	04061F	PARTICIPANT	\N	PRESENT	0
30608	30577	14159V	PARTICIPANT	\N	PRESENT	0
30613	30577	01048V	PARTICIPANT	\N	PRESENT	0
30610	30577	07029T	PARTICIPANT	\N	PRESENT	0
30611	30577	08010L	PARTICIPANT	\N	PRESENT	0
30612	30577	08034U	PARTICIPANT	\N	PRESENT	0
30614	30577	98046X	PARTICIPANT	\N	PRESENT	0
30615	30577	08011M	PARTICIPANT	\N	PRESENT	0
30616	30577	08061X	PARTICIPANT	\N	PRESENT	0
30617	30577	01016M	PARTICIPANT	\N	PRESENT	0
30618	30577	14225N	PARTICIPANT	\N	PRESENT	0
30619	30577	11012A	PARTICIPANT	\N	PRESENT	0
30621	30577	11057P	PARTICIPANT	\N	PRESENT	0
30622	30577	14173T	PARTICIPANT	\N	PRESENT	0
30623	30577	04034C	PARTICIPANT	\N	PRESENT	0
30625	30577	11111C	RAPPORTEUR_AVIS	\N	PRESENT	0
30630	30629	04053F	PARTICIPANT	\N	PRESENT	0
30631	30629	14195A	PARTICIPANT	\N	PRESENT	0
30633	30629	08052W	PARTICIPANT	\N	PRESENT	0
30634	30629	98024R	PRESIDENT	0	PRESENT	0
30636	30629	10006L	PARTICIPANT	\N	PRESENT	0
30637	30629	12042Y	PARTICIPANT	\N	PRESENT	0
30638	30629	14281W	PARTICIPANT	\N	PRESENT	0
30639	30629	11061K	PARTICIPANT	\N	PRESENT	0
30640	30629	14213J	PARTICIPANT	\N	PRESENT	0
30641	30629	11112D	PARTICIPANT	\N	PRESENT	0
30642	30629	14037X	PARTICIPANT	\N	PRESENT	0
30643	30629	14119M	PARTICIPANT	\N	PRESENT	0
30644	30629	14271U	PARTICIPANT	\N	PRESENT	0
30645	30629	04045F	PARTICIPANT	\N	PRESENT	0
30646	30629	11063M	PARTICIPANT	\N	PRESENT	0
30647	30629	14269B	PARTICIPANT	\N	PRESENT	0
30648	30629	14231L	PARTICIPANT	\N	EXCUSE	0
30649	30629	11097X	PARTICIPANT	\N	EXCUSE	0
30650	30629	07029T	PARTICIPANT	\N	PRESENT	0
30816	30808	90003B	PARTICIPANT	\N	PRESENT	0
30818	30808	80013X	PARTICIPANT	\N	PRESENT	0
30820	30808	04089T	PARTICIPANT	\N	PRESENT	0
30821	30808	14197C	PARTICIPANT	\N	PRESENT	0
30823	30808	14187A	PARTICIPANT	\N	PRESENT	0
30824	30808	14033T	PARTICIPANT	\N	PRESENT	0
30828	30808	04049K	PARTICIPANT	\N	PRESENT	0
30829	30808	04094Q	PARTICIPANT	\N	PRESENT	0
30830	30808	11111C	PARTICIPANT	\N	PRESENT	0
30832	30808	11100Y	PRESIDENT	0	PRESENT	0
30834	30808	11098Y	PARTICIPANT	\N	PRESENT	0
30837	30808	14205J	PARTICIPANT	\N	PRESENT	0
30841	30808	04088S	PARTICIPANT	\N	PRESENT	0
30842	30808	98050T	PARTICIPANT	\N	PRESENT	0
30843	30808	11090Q	PARTICIPANT	\N	PRESENT	0
29101	28401	04053F	PARTICIPANT	\N	PRESENT	0
29102	28401	11104D	PARTICIPANT	\N	PRESENT	0
29103	28401	11110B	PARTICIPANT	\N	PRESENT	0
29104	28401	08024S	PARTICIPANT	\N	PRESENT	0
29105	28401	08038Y	PARTICIPANT	\N	PRESENT	0
29106	28401	92039X	PARTICIPANT	\N	PRESENT	0
29107	28401	92031P	PARTICIPANT	\N	PRESENT	0
29108	28401	08017T	PARTICIPANT	\N	PRESENT	0
29148	28401	01014K	PARTICIPANT	\N	PRESENT	0
29149	28401	14225N	PARTICIPANT	\N	PRESENT	0
29150	28401	11020A	PARTICIPANT	\N	PRESENT	0
29151	28401	14269B	PARTICIPANT	\N	PRESENT	0
29152	28401	02002K	PARTICIPANT	\N	PRESENT	0
29156	28401	12042Y	PARTICIPANT	\N	PRESENT	0
29154	28401	11107G	PARTICIPANT	\N	PRESENT	0
29155	28401	99002P	PARTICIPANT	\N	PRESENT	0
29157	28401	04094Q	PARTICIPANT	\N	PRESENT	0
29158	28401	11042G	PARTICIPANT	\N	PRESENT	0
29159	28401	11081P	PARTICIPANT	\N	PRESENT	0
29160	28401	14018U	PARTICIPANT	\N	PRESENT	0
29161	28401	08049C	PARTICIPANT	\N	PRESENT	0
29162	28401	98042T	PARTICIPANT	\N	PRESENT	0
29163	28401	11095V	PARTICIPANT	\N	PRESENT	0
29164	28401	92020L	PARTICIPANT	\N	PRESENT	0
29165	28401	08014Q	PARTICIPANT	\N	PRESENT	0
29166	28401	90003B	PARTICIPANT	\N	PRESENT	0
29167	28401	11065P	PARTICIPANT	\N	PRESENT	0
29168	28401	14121F	PARTICIPANT	\N	PRESENT	0
29169	28401	95015C	PARTICIPANT	\N	PRESENT	0
29170	28401	04071H	PARTICIPANT	\N	PRESENT	0
29171	28401	04067M	PARTICIPANT	\N	PRESENT	0
29172	28401	11076S	PARTICIPANT	\N	PRESENT	0
29173	28401	01044R	PARTICIPANT	\N	PRESENT	0
29174	28401	11029K	PARTICIPANT	\N	PRESENT	0
29175	28401	11099A	PARTICIPANT	\N	PRESENT	0
29176	28401	01027Q	PARTICIPANT	\N	PRESENT	0
29177	28401	04089T	PARTICIPANT	\N	PRESENT	0
29178	28401	01024M	PARTICIPANT	\N	PRESENT	0
29179	28401	92044U	PARTICIPANT	\N	PRESENT	0
29184	28401	14133K	PARTICIPANT	\N	PRESENT	0
29182	28401	89017R	PARTICIPANT	\N	PRESENT	0
29183	28401	14275Y	PARTICIPANT	\N	PRESENT	0
29185	28401	11093T	PARTICIPANT	\N	PRESENT	0
29187	28401	14255U	PARTICIPANT	\N	PRESENT	0
29188	28401	04040A	PARTICIPANT	\N	PRESENT	0
29189	28401	01047U	PARTICIPANT	\N	PRESENT	0
29190	28401	04070G	PARTICIPANT	\N	PRESENT	0
29191	28401	01007L	PARTICIPANT	\N	PRESENT	0
29194	28401	14042U	PARTICIPANT	\N	PRESENT	0
29196	28401	14327T	PARTICIPANT	\N	PRESENT	0
29197	28401	09001P	PARTICIPANT	\N	PRESENT	0
29198	28401	04079R	PARTICIPANT	\N	PRESENT	0
29199	28401	01059Y	PARTICIPANT	\N	PRESENT	0
29200	28401	04054G	PARTICIPANT	\N	PRESENT	0
29201	28401	92018S	PARTICIPANT	\N	PRESENT	0
29202	28401	01034P	PARTICIPANT	\N	PRESENT	0
29203	28401	12041X	PARTICIPANT	\N	PRESENT	0
29204	28401	11111C	PARTICIPANT	\N	PRESENT	0
29205	28401	11109J	PARTICIPANT	\N	PRESENT	0
29206	28401	11026G	PARTICIPANT	\N	PRESENT	0
29208	28401	95059Q	PARTICIPANT	\N	PRESENT	0
29209	28401	04043D	PARTICIPANT	\N	PRESENT	0
29212	28401	04034C	PARTICIPANT	\N	PRESENT	0
29213	28401	14097Y	PARTICIPANT	\N	PRESENT	0
29215	28401	95037J	PARTICIPANT	\N	PRESENT	0
29216	28401	11059R	PARTICIPANT	\N	PRESENT	0
29218	28401	01008M	PARTICIPANT	\N	PRESENT	0
29220	28401	11027H	PARTICIPANT	\N	PRESENT	0
29221	28401	08068F	PARTICIPANT	\N	PRESENT	0
29222	28401	11101A	PARTICIPANT	\N	PRESENT	0
29223	28401	08058D	PARTICIPANT	\N	PRESENT	0
29224	28401	04042C	PARTICIPANT	\N	PRESENT	0
29225	28401	14014Q	PARTICIPANT	\N	PRESENT	0
29226	28401	11113E	PARTICIPANT	\N	PRESENT	0
29227	28401	98022P	PARTICIPANT	\N	PRESENT	0
29228	28401	14239U	PARTICIPANT	\N	PRESENT	0
29229	28401	14053L	PARTICIPANT	\N	PRESENT	0
29230	28401	14329V	PARTICIPANT	\N	PRESENT	0
29231	28401	04080J	PARTICIPANT	\N	PRESENT	0
29232	28401	11053K	PARTICIPANT	\N	PRESENT	0
29233	28401	98023Q	PARTICIPANT	\N	PRESENT	0
29234	28401	04086Q	PARTICIPANT	\N	PRESENT	0
29235	28401	04081K	PARTICIPANT	\N	PRESENT	0
29236	28401	01016M	PARTICIPANT	\N	PRESENT	0
29237	28401	08022Q	PARTICIPANT	\N	PRESENT	0
29238	28401	11057P	PARTICIPANT	\N	PRESENT	0
29239	28401	11046L	PARTICIPANT	\N	PRESENT	0
29240	28401	04061F	PARTICIPANT	\N	PRESENT	0
29241	28401	14217N	PARTICIPANT	\N	PRESENT	0
29242	28401	14111D	PARTICIPANT	\N	PRESENT	0
29243	28401	11114F	PARTICIPANT	\N	PRESENT	0
29244	28401	14199E	PARTICIPANT	\N	PRESENT	0
29245	28401	14193X	PARTICIPANT	\N	PRESENT	0
29246	28401	14071N	PARTICIPANT	\N	PRESENT	0
29247	28401	01057W	PARTICIPANT	\N	PRESENT	0
29580	28402	04066L	PARTICIPANT	\N	PRESENT	0
29249	28401	08069G	PARTICIPANT	\N	PRESENT	0
29250	28401	04097T	PARTICIPANT	\N	PRESENT	0
29251	28401	07029T	PARTICIPANT	\N	PRESENT	0
29252	28401	04049K	PARTICIPANT	\N	PRESENT	0
29253	28401	86044G	PARTICIPANT	\N	PRESENT	0
29254	28401	04033B	PARTICIPANT	\N	PRESENT	0
29255	28401	14123H	PARTICIPANT	\N	PRESENT	0
29256	28401	86034E	PARTICIPANT	\N	PRESENT	0
29257	28401	08039A	PARTICIPANT	\N	PRESENT	0
29258	28401	14037X	PARTICIPANT	\N	PRESENT	0
29259	28401	11090Q	PARTICIPANT	\N	PRESENT	0
29260	28401	08042U	PARTICIPANT	\N	PRESENT	0
29261	28401	14251Q	PARTICIPANT	\N	PRESENT	0
29262	28401	08011M	PARTICIPANT	\N	PRESENT	0
29263	28401	92040Q	PARTICIPANT	\N	PRESENT	0
29264	28401	14119M	PARTICIPANT	\N	PRESENT	0
29265	28401	08047A	PARTICIPANT	\N	PRESENT	0
29266	28401	04047H	PARTICIPANT	\N	PRESENT	0
29267	28401	01060R	PARTICIPANT	\N	PRESENT	0
29268	28401	05012A	PARTICIPANT	\N	PRESENT	0
29269	28401	98050T	PARTICIPANT	\N	PRESENT	0
29270	28401	11089X	PARTICIPANT	\N	PRESENT	0
29271	28401	14093U	PARTICIPANT	\N	PRESENT	0
29272	28401	14157T	PARTICIPANT	\N	PRESENT	0
29273	28401	04044E	PARTICIPANT	\N	PRESENT	0
29274	28401	14195A	PARTICIPANT	\N	PRESENT	0
29275	28401	01043Q	PARTICIPANT	\N	PRESENT	0
29276	28401	08009T	PARTICIPANT	\N	PRESENT	0
29277	28401	01061S	PARTICIPANT	\N	PRESENT	0
29278	28401	11060J	PARTICIPANT	\N	PRESENT	0
29279	28401	11039M	PARTICIPANT	\N	PRESENT	0
29280	28401	11068S	PARTICIPANT	\N	PRESENT	0
29281	28401	98029W	PARTICIPANT	\N	PRESENT	0
29282	28401	95030B	PARTICIPANT	\N	PRESENT	0
29283	28401	08034U	PARTICIPANT	\N	PRESENT	0
29284	28401	11084S	PARTICIPANT	\N	PRESENT	0
29285	28401	11112D	PARTICIPANT	\N	PRESENT	0
29286	28401	83047W	PARTICIPANT	\N	PRESENT	0
29287	28401	11077T	PARTICIPANT	\N	PRESENT	0
29581	28402	01024M	PARTICIPANT	\N	PRESENT	0
29582	28402	05008E	PARTICIPANT	\N	PRESENT	0
29583	28402	07034Q	PARTICIPANT	\N	PRESENT	0
29584	28402	14031R	PARTICIPANT	\N	PRESENT	0
29585	28402	14041T	PARTICIPANT	\N	PRESENT	0
29586	28402	07029T	PARTICIPANT	\N	PRESENT	0
29587	28402	08062Y	PARTICIPANT	\N	PRESENT	0
29588	28402	10015M	PARTICIPANT	\N	PRESENT	0
29589	28402	11049P	PARTICIPANT	\N	PRESENT	0
29590	28402	01028R	PARTICIPANT	\N	PRESENT	0
29591	28402	11072N	PARTICIPANT	\N	PRESENT	0
29592	28402	11068S	PARTICIPANT	\N	PRESENT	0
29593	28402	11056N	PARTICIPANT	\N	PRESENT	0
29594	28402	14215L	PARTICIPANT	\N	PRESENT	0
29595	28402	07004J	PARTICIPANT	\N	PRESENT	0
29596	28402	11037K	PARTICIPANT	\N	PRESENT	0
29597	28402	01057W	PARTICIPANT	\N	PRESENT	0
29598	28402	11043H	PARTICIPANT	\N	PRESENT	0
29599	28402	14223L	PARTICIPANT	\N	PRESENT	0
29600	28402	01007L	PARTICIPANT	\N	PRESENT	0
29601	28402	11012A	PARTICIPANT	\N	PRESENT	0
29602	28402	88008L	PARTICIPANT	\N	PRESENT	0
29603	28402	01046T	PARTICIPANT	\N	PRESENT	0
29604	28402	08044W	PARTICIPANT	\N	PRESENT	0
29605	28402	14059S	PARTICIPANT	\N	PRESENT	0
29606	28402	08051V	PARTICIPANT	\N	PRESENT	0
29607	28402	14147R	PARTICIPANT	\N	PRESENT	0
29608	28402	14026U	PARTICIPANT	\N	PRESENT	0
29609	28402	04043D	PARTICIPANT	\N	PRESENT	0
29610	28402	14195A	PARTICIPANT	\N	PRESENT	0
29611	28402	08018U	PARTICIPANT	\N	PRESENT	0
29612	28402	14105F	PARTICIPANT	\N	PRESENT	0
29613	28402	95049N	PARTICIPANT	\N	PRESENT	0
29614	28402	04056J	PARTICIPANT	\N	PRESENT	0
29615	28402	08021P	PARTICIPANT	\N	PRESENT	0
29616	28402	01003G	PARTICIPANT	\N	PRESENT	0
29617	28402	14039A	PARTICIPANT	\N	PRESENT	0
29618	28402	14209N	PARTICIPANT	\N	PRESENT	0
29619	28402	08031R	PARTICIPANT	\N	PRESENT	0
29620	28402	14018U	PARTICIPANT	\N	PRESENT	0
29621	28402	04038G	PARTICIPANT	\N	PRESENT	0
29622	28402	14235Q	PARTICIPANT	\N	PRESENT	0
29623	28402	11095V	PARTICIPANT	\N	PRESENT	0
29624	28402	87003B	PARTICIPANT	\N	PRESENT	0
29625	28402	14103D	PARTICIPANT	\N	PRESENT	0
29626	28402	14038Y	PARTICIPANT	\N	PRESENT	0
29627	28402	14219Q	PARTICIPANT	\N	PRESENT	0
29628	28402	14065Q	PARTICIPANT	\N	PRESENT	0
29629	28402	08010L	PARTICIPANT	\N	PRESENT	0
29630	28402	95063L	PARTICIPANT	\N	PRESENT	0
29631	28402	11034G	PARTICIPANT	\N	PRESENT	0
29632	28402	14034U	PARTICIPANT	\N	PRESENT	0
29633	28402	95062K	PARTICIPANT	\N	PRESENT	0
29634	28402	11033F	PARTICIPANT	\N	PRESENT	0
29635	28402	14211G	PARTICIPANT	\N	PRESENT	0
29636	28402	14265W	PARTICIPANT	\N	PRESENT	0
29637	28402	11048N	PARTICIPANT	\N	PRESENT	0
29638	28402	14271U	PARTICIPANT	\N	PRESENT	0
29639	28402	80013X	PARTICIPANT	\N	PRESENT	0
29640	28402	14217N	PARTICIPANT	\N	PRESENT	0
29641	28402	14079W	PARTICIPANT	\N	PRESENT	0
29642	28402	08053X	PARTICIPANT	\N	PRESENT	0
29643	28402	14259Y	PARTICIPANT	\N	PRESENT	0
29701	28403	11056N	PARTICIPANT	\N	PRESENT	0
29702	28403	07034Q	PARTICIPANT	\N	PRESENT	0
29703	28403	08035V	PARTICIPANT	\N	PRESENT	0
29704	28403	11072N	PARTICIPANT	\N	PRESENT	0
29705	28403	14089Y	PARTICIPANT	\N	PRESENT	0
29706	28403	07029T	PARTICIPANT	\N	PRESENT	0
29707	28403	04047H	PARTICIPANT	\N	PRESENT	0
29708	28403	05008E	PARTICIPANT	\N	PRESENT	0
29709	28403	14026U	PARTICIPANT	\N	PRESENT	0
29710	28403	95049N	PARTICIPANT	\N	PRESENT	0
29711	28403	14187A	PARTICIPANT	\N	PRESENT	0
29712	28403	10015M	PARTICIPANT	\N	PRESENT	0
29713	28403	08015R	PARTICIPANT	\N	PRESENT	0
29714	28403	14213J	PARTICIPANT	\N	PRESENT	0
29715	28403	01024M	PARTICIPANT	\N	PRESENT	0
29716	28403	14087W	PARTICIPANT	\N	PRESENT	0
29717	28403	95041E	PARTICIPANT	\N	PRESENT	0
29718	28403	04038G	PARTICIPANT	\N	PRESENT	0
29719	28403	14205J	PARTICIPANT	\N	PRESENT	0
29720	28403	14211G	PARTICIPANT	\N	PRESENT	0
29721	28403	95030B	PARTICIPANT	\N	PRESENT	0
29722	28403	14169X	PARTICIPANT	\N	PRESENT	0
29723	28403	14179A	PARTICIPANT	\N	PRESENT	0
29724	28403	14215L	PARTICIPANT	\N	PRESENT	0
29725	28403	08010L	PARTICIPANT	\N	PRESENT	0
29726	28403	14209N	PARTICIPANT	\N	PRESENT	0
29727	28403	11090Q	PARTICIPANT	\N	PRESENT	0
29728	28403	14259Y	PARTICIPANT	\N	PRESENT	0
29729	28403	04067M	PARTICIPANT	\N	PRESENT	0
29730	28403	08051V	PARTICIPANT	\N	PRESENT	0
29731	28403	08031R	PARTICIPANT	\N	PRESENT	0
29732	28403	04085P	PARTICIPANT	\N	PRESENT	0
29733	28403	95063L	PARTICIPANT	\N	PRESENT	0
29734	28403	14079W	PARTICIPANT	\N	PRESENT	0
29735	28403	11012A	PARTICIPANT	\N	PRESENT	0
29736	28403	01008M	PARTICIPANT	\N	PRESENT	0
29737	28403	14195A	PARTICIPANT	\N	PRESENT	0
29738	28403	14111D	PARTICIPANT	\N	PRESENT	0
29739	28403	95067Q	PARTICIPANT	\N	PRESENT	0
29740	28403	11036J	PARTICIPANT	\N	PRESENT	0
29741	28403	14133K	PARTICIPANT	\N	PRESENT	0
29742	28403	14197C	PARTICIPANT	\N	PRESENT	0
29743	28403	14030Q	PARTICIPANT	\N	PRESENT	0
29744	28403	14265W	PARTICIPANT	\N	PRESENT	0
29745	28403	14065Q	PARTICIPANT	\N	PRESENT	0
29746	28403	98053W	PARTICIPANT	\N	PRESENT	0
29747	28403	14083S	PARTICIPANT	\N	PRESENT	0
29748	28403	14033T	PARTICIPANT	\N	PRESENT	0
29749	28403	14034U	PARTICIPANT	\N	PRESENT	0
29699	28403	08024S	PARTICIPANT	\N	PRESENT	0
29700	28403	14235Q	PARTICIPANT	\N	PRESENT	0
30234	29941	89017R	PARTICIPANT	\N	PRESENT	0
30235	29941	05004A	PARTICIPANT	\N	PRESENT	0
30236	29941	01013J	PARTICIPANT	\N	PRESENT	0
30237	29941	11068S	PARTICIPANT	\N	PRESENT	0
30238	29941	08014Q	PARTICIPANT	\N	PRESENT	0
30239	29941	14175V	PARTICIPANT	\N	PRESENT	0
30240	29941	14083S	PARTICIPANT	\N	PRESENT	0
30241	29941	11053K	PARTICIPANT	\N	PRESENT	0
30242	29941	11088W	PARTICIPANT	\N	PRESENT	0
30243	29941	14327T	PARTICIPANT	\N	PRESENT	0
30245	29941	08022Q	PARTICIPANT	\N	PRESENT	0
30246	29941	04071H	PARTICIPANT	\N	PRESENT	0
30247	29941	98053W	PARTICIPANT	\N	PRESENT	0
30248	29941	14199E	PARTICIPANT	\N	PRESENT	0
30250	29941	08016S	PARTICIPANT	\N	PRESENT	0
30251	29941	08069G	PARTICIPANT	\N	PRESENT	0
30253	29941	11048N	PARTICIPANT	\N	PRESENT	0
30254	29941	99004R	PARTICIPANT	\N	PRESENT	0
30256	29941	04061F	PARTICIPANT	\N	PRESENT	0
30259	29941	08034U	PARTICIPANT	\N	PRESENT	0
30477	30456	14263U	PARTICIPANT	\N	PRESENT	0
30261	29941	11085T	PARTICIPANT	\N	PRESENT	0
30265	29941	08061X	PARTICIPANT	\N	PRESENT	0
30266	29941	01016M	PARTICIPANT	\N	PRESENT	0
30479	30456	11109J	PARTICIPANT	\N	PRESENT	0
30480	30456	04059M	PARTICIPANT	\N	PRESENT	0
30481	30456	11039M	PARTICIPANT	\N	PRESENT	0
29843	29841	08055A	PARTICIPANT	\N	PRESENT	0
29845	29841	14030Q	PARTICIPANT	\N	PRESENT	0
29847	29841	08060W	PARTICIPANT	\N	PRESENT	0
29849	29841	11095V	PARTICIPANT	\N	PRESENT	0
29850	29841	14038Y	PARTICIPANT	\N	PRESENT	0
29851	29841	11114F	PARTICIPANT	\N	PRESENT	0
29854	29841	01015L	PARTICIPANT	\N	PRESENT	0
29855	29841	11107G	PARTICIPANT	\N	PRESENT	0
29994	29988	04040A	PARTICIPANT	\N	PRESENT	0
29857	29841	02002K	PARTICIPANT	\N	PRESENT	0
29859	29841	04097T	PARTICIPANT	\N	PRESENT	0
29861	29841	11059R	PARTICIPANT	\N	PRESENT	0
29862	29841	14219Q	PARTICIPANT	\N	PRESENT	0
29863	29841	80027E	PARTICIPANT	\N	PRESENT	0
29864	29841	14031R	PARTICIPANT	\N	PRESENT	0
29865	29841	08009T	PRESIDENT	0	PRESENT	0
29866	29841	08062Y	PARTICIPANT	\N	PRESENT	0
29868	29841	92039X	PARTICIPANT	\N	PRESENT	0
29995	29988	08058D	PARTICIPANT	\N	PRESENT	0
29871	29841	14237S	PARTICIPANT	\N	PRESENT	0
29873	29841	05012A	PARTICIPANT	\N	PRESENT	0
29875	29841	14135M	PARTICIPANT	\N	PRESENT	0
29876	29841	95062K	PARTICIPANT	\N	PRESENT	0
29877	29841	14107H	PARTICIPANT	\N	PRESENT	0
29878	29841	14051J	PARTICIPANT	\N	PRESENT	0
29879	29841	14157T	PARTICIPANT	\N	PRESENT	0
29996	29988	04042C	PARTICIPANT	\N	PRESENT	0
29997	29988	98029W	PARTICIPANT	\N	PRESENT	0
29998	29988	11080N	PARTICIPANT	\N	EXCUSE	0
29999	29988	11027H	PARTICIPANT	\N	PRESENT	0
30000	29988	92018S	PARTICIPANT	\N	PRESENT	0
30001	29988	95030B	PARTICIPANT	\N	PRESENT	0
30002	29988	97011G	PARTICIPANT	\N	PRESENT	0
30003	29988	08065C	PARTICIPANT	\N	EXCUSE	0
30004	29988	04035D	PARTICIPANT	\N	PRESENT	0
30005	29988	07024N	PARTICIPANT	\N	EXCUSE	0
30007	29988	14014Q	PARTICIPANT	\N	PRESENT	0
30008	29988	11015D	PARTICIPANT	\N	PRESENT	0
30009	29988	07004J	PARTICIPANT	\N	PRESENT	0
30067	29988	98022P	PARTICIPANT	\N	PRESENT	0
30068	29988	95037J	PARTICIPANT	\N	PRESENT	0
30069	29988	04078Q	PARTICIPANT	\N	EXCUSE	0
30070	29988	14097Y	PARTICIPANT	\N	PRESENT	0
30071	29988	04036E	PARTICIPANT	\N	PRESENT	0
30072	29988	14039A	PARTICIPANT	\N	PRESENT	0
30073	29988	92031P	PARTICIPANT	\N	PRESENT	0
30074	29988	11106F	PARTICIPANT	\N	PRESENT	0
30078	29988	08047A	PARTICIPANT	\N	PRESENT	0
30080	29988	14028W	PARTICIPANT	\N	PRESENT	0
30081	29988	14193X	PARTICIPANT	\N	PRESENT	0
30083	29988	98021N	PARTICIPANT	\N	PRESENT	0
30084	29988	04080J	PARTICIPANT	\N	PRESENT	0
30085	29988	95059Q	PRESIDENT	0	PRESENT	0
30086	29988	01014K	PARTICIPANT	\N	PRESENT	0
30087	29988	11054L	PARTICIPANT	\N	PRESENT	0
30088	29988	01056V	PARTICIPANT	\N	PRESENT	0
30089	29988	92044U	PARTICIPANT	\N	PRESENT	0
30090	29988	08049C	PARTICIPANT	\N	PRESENT	0
30105	29988	95035G	PARTICIPANT	\N	EXCUSE	0
30108	30107	14263U	PARTICIPANT	\N	PRESENT	0
30109	30107	14133K	PARTICIPANT	\N	PRESENT	0
30110	30107	11109J	PARTICIPANT	\N	PRESENT	0
30111	30107	04059M	PARTICIPANT	\N	PRESENT	0
30112	30107	11039M	PARTICIPANT	\N	PRESENT	0
30113	30107	01044R	PARTICIPANT	\N	PRESENT	0
30114	30107	08043V	PARTICIPANT	\N	PRESENT	0
30115	30107	14089Y	PARTICIPANT	\N	PRESENT	0
30116	30107	14105F	PARTICIPANT	\N	PRESENT	0
30117	30107	11029K	PARTICIPANT	\N	PRESENT	0
30118	30107	95015C	PARTICIPANT	\N	EXCUSE	0
29802	29801	01008M	PARTICIPANT	\N	PRESENT	0
29803	29801	11036J	PARTICIPANT	\N	PRESENT	0
29804	29801	11081P	PARTICIPANT	\N	PRESENT	0
29805	29801	14013P	PARTICIPANT	\N	PRESENT	0
29806	29801	08068F	PARTICIPANT	\N	PRESENT	0
29807	29801	14207L	PARTICIPANT	\N	PRESENT	0
29808	29801	11101A	PARTICIPANT	\N	PRESENT	0
29809	29801	90003B	PARTICIPANT	\N	PRESENT	0
29810	29801	08028W	PARTICIPANT	\N	PRESENT	0
29811	29801	80013X	PARTICIPANT	\N	PRESENT	0
29812	29801	08038Y	PARTICIPANT	\N	PRESENT	0
29813	29801	04089T	PARTICIPANT	\N	PRESENT	0
29814	29801	14197C	PARTICIPANT	\N	PRESENT	0
29815	29801	11110B	PARTICIPANT	\N	PRESENT	0
29816	29801	14187A	PARTICIPANT	\N	PRESENT	0
29817	29801	14033T	PARTICIPANT	\N	PRESENT	0
29818	29801	14081Q	PARTICIPANT	\N	PRESENT	0
30119	30107	92015P	PARTICIPANT	\N	EXCUSE	0
29820	29801	11099A	PARTICIPANT	\N	PRESENT	0
29821	29801	04049K	PARTICIPANT	\N	PRESENT	0
30120	30107	08024S	PARTICIPANT	\N	PRESENT	0
29823	29801	11111C	PARTICIPANT	\N	PRESENT	0
29824	29801	08015R	PARTICIPANT	\N	PRESENT	0
29825	29801	11100Y	PRESIDENT	0	PRESENT	0
29826	29801	01061S	PARTICIPANT	\N	PRESENT	0
29827	29801	11098Y	PARTICIPANT	\N	PRESENT	0
29828	29801	01043Q	PARTICIPANT	\N	PRESENT	0
29829	29801	11077T	PARTICIPANT	\N	PRESENT	0
29830	29801	14205J	PARTICIPANT	\N	PRESENT	0
30121	30107	14201E	PARTICIPANT	\N	EXCUSE	0
29832	29801	14257W	PARTICIPANT	\N	PRESENT	0
30122	30107	14329V	PARTICIPANT	\N	EXCUSE	0
29834	29801	04088S	PARTICIPANT	\N	PRESENT	0
29835	29801	98050T	PARTICIPANT	\N	PRESENT	0
29836	29801	11090Q	PARTICIPANT	\N	PRESENT	0
29837	29801	11046L	PARTICIPANT	\N	PRESENT	0
29838	29801	01058X	PARTICIPANT	\N	PRESENT	0
29839	29801	11094U	PARTICIPANT	\N	EXCUSE	0
29840	29801	11066Q	PARTICIPANT	\N	PRESENT	0
30123	30107	14209N	PARTICIPANT	\N	PRESENT	0
30124	30107	14079W	PARTICIPANT	\N	PRESENT	0
30125	30107	11091R	PARTICIPANT	\N	EXCUSE	0
30126	30107	87003B	PARTICIPANT	\N	PRESENT	0
30127	30107	98042T	PARTICIPANT	\N	PRESENT	0
30128	30107	14249W	PARTICIPANT	\N	PRESENT	0
30129	30107	01041N	PARTICIPANT	\N	PRESENT	0
30130	30107	01025N	PARTICIPANT	\N	PRESENT	0
30131	30107	01037S	PARTICIPANT	\N	PRESENT	0
30133	30107	08035V	PARTICIPANT	\N	PRESENT	0
30134	30107	11089X	PARTICIPANT	\N	PRESENT	0
30135	30107	07026Q	PARTICIPANT	\N	PRESENT	0
30136	30107	14123H	PARTICIPANT	\N	PRESENT	0
30139	30107	14241N	PARTICIPANT	\N	EXCUSE	0
30140	30107	14061L	PARTICIPANT	\N	PRESENT	0
30141	30107	14073Q	PARTICIPANT	\N	PRESENT	0
30142	30107	08031R	PARTICIPANT	\N	PRESENT	0
30144	30107	08039A	PARTICIPANT	\N	PRESENT	0
30145	30107	08017T	PARTICIPANT	\N	PRESENT	0
30146	30107	14059S	PARTICIPANT	\N	PRESENT	0
30147	30107	08012N	PARTICIPANT	\N	PRESENT	0
30148	30107	14103D	PARTICIPANT	\N	PRESENT	0
30149	30107	11104D	PARTICIPANT	\N	PRESENT	0
30150	30107	14063N	PARTICIPANT	\N	PRESENT	0
30151	30107	04057K	PARTICIPANT	\N	PRESENT	0
30152	30107	11014C	PARTICIPANT	\N	PRESENT	0
30154	30107	04070G	PRESIDENT	0	PRESENT	0
30158	30107	14235Q	PARTICIPANT	\N	PRESENT	0
30162	30107	11043H	PARTICIPANT	\N	PRESENT	0
28919	24344	80027E	PARTICIPANT	\N	PRESENT	0
28920	24344	14031R	PARTICIPANT	\N	PRESENT	0
28921	24344	08009T	PARTICIPANT	\N	PRESENT	0
28922	24344	14221J	PARTICIPANT	\N	PRESENT	0
28923	24344	92039X	PARTICIPANT	\N	PRESENT	0
28924	24344	14169X	PARTICIPANT	\N	PRESENT	0
28925	24344	14237S	PARTICIPANT	\N	PRESENT	0
28926	24344	13002U	PARTICIPANT	\N	PRESENT	0
28927	24344	05012A	PARTICIPANT	\N	PRESENT	0
28928	24344	14107H	PARTICIPANT	\N	PRESENT	0
28929	24344	14157T	PARTICIPANT	\N	PRESENT	0
30166	30107	11094U	PARTICIPANT	\N	PRESENT	0
30165	30107	14229S	PARTICIPANT	\N	PRESENT	0
30167	30107	11068S	PARTICIPANT	\N	PRESENT	0
30171	30170	14239U	PARTICIPANT	\N	PRESENT	0
30172	30170	11055M	PARTICIPANT	\N	PRESENT	0
30173	30170	01046T	PARTICIPANT	\N	PRESENT	0
30174	30170	04053F	PARTICIPANT	\N	PRESENT	0
30175	30170	14255U	PARTICIPANT	\N	PRESENT	0
30176	30170	04066L	PARTICIPANT	\N	PRESENT	0
30177	30170	00003C	PARTICIPANT	\N	PRESENT	0
30178	30170	14053L	PARTICIPANT	\N	PRESENT	0
30179	30170	11103C	PARTICIPANT	\N	PRESENT	0
30180	30170	11044J	PARTICIPANT	\N	PRESENT	0
30181	30170	14195A	PARTICIPANT	\N	PRESENT	0
30182	30170	14267Y	PARTICIPANT	\N	PRESENT	0
30436	30372	04038G	PARTICIPANT	\N	PRESENT	0
30184	30170	11031D	PARTICIPANT	\N	PRESENT	0
30185	30170	08052W	PARTICIPANT	\N	PRESENT	0
30186	30170	01059Y	PARTICIPANT	\N	PRESENT	0
30187	30170	04081K	PARTICIPANT	\N	PRESENT	0
30188	30170	98024R	PRESIDENT	0	PRESENT	0
30189	30170	10006L	PARTICIPANT	\N	PRESENT	0
30190	30170	04067M	PARTICIPANT	\N	PRESENT	0
30191	30170	14217N	PARTICIPANT	\N	PRESENT	0
30192	30170	14042U	PARTICIPANT	\N	PRESENT	0
30193	30170	14151M	PARTICIPANT	\N	PRESENT	0
30194	30170	12042Y	PARTICIPANT	\N	PRESENT	0
30195	30170	14281W	PARTICIPANT	\N	PRESENT	0
30437	30372	01025N	PARTICIPANT	\N	PRESENT	0
30197	30170	01003G	PARTICIPANT	\N	PRESENT	0
30438	30372	11090Q	PARTICIPANT	\N	PRESENT	0
30199	30170	14231L	PARTICIPANT	\N	EXCUSE	0
30200	30170	11061K	PARTICIPANT	\N	PRESENT	0
30439	30372	07004J	PARTICIPANT	\N	PRESENT	0
30202	30170	08041T	PARTICIPANT	\N	PRESENT	0
30203	30170	01011G	PARTICIPANT	\N	PRESENT	0
30204	30170	14026U	PARTICIPANT	\N	PRESENT	0
30205	30170	14213J	PARTICIPANT	\N	PRESENT	0
30206	30170	14121F	PARTICIPANT	\N	PRESENT	0
30207	30170	11112D	PARTICIPANT	\N	PRESENT	0
30208	30170	14037X	PARTICIPANT	\N	PRESENT	0
30209	30170	14018U	PARTICIPANT	\N	PRESENT	0
30210	30170	11067R	PARTICIPANT	\N	PRESENT	0
30211	30170	14223L	PARTICIPANT	\N	PRESENT	0
30212	30170	04092N	PARTICIPANT	\N	EXCUSE	0
30213	30170	14265W	PARTICIPANT	\N	PRESENT	0
30214	30170	14119M	PARTICIPANT	\N	PRESENT	0
30215	30170	14071N	PARTICIPANT	\N	PRESENT	0
30216	30170	07032N	PARTICIPANT	\N	PRESENT	0
30217	30170	04043D	PARTICIPANT	\N	PRESENT	0
30218	30170	14271U	PARTICIPANT	\N	PRESENT	0
30440	30372	14249W	PARTICIPANT	\N	PRESENT	0
30220	30170	11093T	PARTICIPANT	\N	PRESENT	0
30221	30170	11097X	PARTICIPANT	\N	EXCUSE	0
30222	30170	04045F	PARTICIPANT	\N	PRESENT	0
30223	30170	14227Q	PARTICIPANT	\N	PRESENT	0
30224	30170	01034P	PARTICIPANT	\N	PRESENT	0
30538	30456	14069U	PARTICIPANT	\N	PRESENT	0
30226	30170	11063M	PARTICIPANT	\N	PRESENT	0
30227	30170	14269B	PARTICIPANT	\N	PRESENT	0
30442	30372	14038Y	PARTICIPANT	\N	PRESENT	0
30443	30372	11099A	PARTICIPANT	\N	PRESENT	0
30444	30372	14197C	PARTICIPANT	\N	PRESENT	0
30539	30456	11083R	PARTICIPANT	\N	PRESENT	0
30446	30372	08055A	PARTICIPANT	\N	PRESENT	0
30447	30372	11067R	PARTICIPANT	\N	PRESENT	0
30451	30372	07034Q	PARTICIPANT	\N	PRESENT	0
30452	30372	14103D	PARTICIPANT	\N	PRESENT	0
30453	30372	01007L	PARTICIPANT	\N	PRESENT	0
30454	30372	14073Q	PARTICIPANT	\N	PRESENT	0
30455	30372	11012A	PARTICIPANT	\N	PRESENT	0
30482	30456	01044R	PARTICIPANT	\N	PRESENT	0
30483	30456	08043V	PARTICIPANT	\N	PRESENT	0
30535	30372	11104D	PARTICIPANT	\N	PRESENT	0
30485	30456	14105F	PARTICIPANT	\N	PRESENT	0
30486	30456	11029K	PARTICIPANT	\N	PRESENT	0
30487	30456	95015C	PARTICIPANT	\N	PRESENT	0
30536	30372	04057K	PARTICIPANT	\N	PRESENT	0
30489	30456	08024S	PARTICIPANT	\N	PRESENT	0
30490	30456	14201E	PARTICIPANT	\N	EXCUSE	0
30491	30456	14329V	PARTICIPANT	\N	EXCUSE	0
30492	30456	14209N	PARTICIPANT	\N	PRESENT	0
30493	30456	14079W	PARTICIPANT	\N	PRESENT	0
30494	30456	11091R	PARTICIPANT	\N	EXCUSE	0
30495	30456	87003B	PARTICIPANT	\N	PRESENT	0
30537	30372	11106F	PARTICIPANT	\N	PRESENT	0
30497	30456	14249W	PARTICIPANT	\N	PRESENT	0
30498	30456	01041N	PARTICIPANT	\N	PRESENT	0
30502	30456	08035V	PARTICIPANT	\N	PRESENT	0
30503	30456	11089X	PARTICIPANT	\N	PRESENT	0
30505	30456	14123H	PARTICIPANT	\N	PRESENT	0
30508	30456	14241N	PARTICIPANT	\N	EXCUSE	0
30509	30456	14061L	PARTICIPANT	\N	PRESENT	0
30510	30456	14073Q	PARTICIPANT	\N	PRESENT	0
30511	30456	08031R	PARTICIPANT	\N	PRESENT	0
30512	30456	12041X	PARTICIPANT	\N	PRESENT	0
30513	30456	08039A	PARTICIPANT	\N	PRESENT	0
30514	30456	08017T	PARTICIPANT	\N	PRESENT	0
30515	30456	14059S	PARTICIPANT	\N	PRESENT	0
30516	30456	08012N	PARTICIPANT	\N	PRESENT	0
30517	30456	14103D	PARTICIPANT	\N	PRESENT	0
30518	30456	11104D	PARTICIPANT	\N	PRESENT	0
30519	30456	14063N	PARTICIPANT	\N	PRESENT	0
30520	30456	04057K	PARTICIPANT	\N	PRESENT	0
30521	30456	11014C	PARTICIPANT	\N	PRESENT	0
30523	30456	04070G	PRESIDENT	0	PRESENT	0
30524	30456	92040Q	PARTICIPANT	\N	PRESENT	0
30527	30456	14235Q	PARTICIPANT	\N	PRESENT	0
30529	30456	04033B	PARTICIPANT	\N	PRESENT	0
30530	30456	14229S	PARTICIPANT	\N	PRESENT	0
30561	30372	14195A	PARTICIPANT	\N	PRESENT	0
30562	30372	01048V	PARTICIPANT	\N	PRESENT	0
30568	30372	14059S	PARTICIPANT	\N	PRESENT	0
30569	30372	14209N	PARTICIPANT	\N	PRESENT	0
30570	30372	11053K	PARTICIPANT	\N	PRESENT	0
30571	30372	01027Q	PARTICIPANT	\N	PRESENT	0
30572	30372	95067Q	PARTICIPANT	\N	PRESENT	0
30573	30372	95015C	PARTICIPANT	\N	PRESENT	0
30574	30372	11064N	PARTICIPANT	\N	PRESENT	0
30575	30372	14217N	PARTICIPANT	\N	PRESENT	0
30576	30372	88008L	PARTICIPANT	\N	PRESENT	0
30581	30372	11107G	PARTICIPANT	\N	PRESENT	0
30582	30372	14159V	PARTICIPANT	\N	PRESENT	0
30635	30372	01008M	PARTICIPANT	\N	PRESENT	0
30651	30372	14079W	PARTICIPANT	\N	PRESENT	0
30652	30372	11029K	PARTICIPANT	\N	PRESENT	0
31006	28658	14327T	PARTICIPANT	\N	EXCUSE	0
31007	28658	14014Q	PARTICIPANT	\N	EXCUSE	0
31018	24345	11023D	PARTICIPANT	\N	EXCUSE	0
31019	24345	11114F	PARTICIPANT	\N	PRESENT	0
31020	24345	14259Y	PARTICIPANT	\N	PRESENT	0
31021	24345	01027Q	PARTICIPANT	\N	PRESENT	0
31022	24345	14097Y	PARTICIPANT	\N	EXCUSE	0
31023	24345	01022K	PARTICIPANT	\N	PRESENT	0
31024	24345	11106F	PARTICIPANT	\N	PRESENT	0
31025	24345	08019V	PRESIDENT	0	PRESENT	0
31026	24345	11072N	PARTICIPANT	\N	EXCUSE	0
31027	24345	95062K	PARTICIPANT	\N	EXCUSE	0
31028	24345	14275Y	PARTICIPANT	\N	PRESENT	0
31029	24345	08065C	PARTICIPANT	\N	EXCUSE	0
31030	24345	14034U	PARTICIPANT	\N	EXCUSE	0
31031	24345	11025F	PARTICIPANT	\N	EXCUSE	0
32307	32306	14133K	PARTICIPANT	\N	PRESENT	0
38267	31452	14053L	PARTICIPANT	\N	EXCUSE	0
38898	38897	01031L	PRESIDENT	0	PRESENT	0
32310	32306	04059M	PARTICIPANT	\N	PRESENT	0
32311	32306	11039M	PARTICIPANT	\N	PRESENT	0
32312	32306	01044R	PARTICIPANT	\N	PRESENT	0
32313	32306	08043V	PARTICIPANT	\N	EXCUSE	0
32314	32306	14089Y	PARTICIPANT	\N	PRESENT	0
32315	32306	14105F	PARTICIPANT	\N	PRESENT	0
32316	32306	11029K	PARTICIPANT	\N	PRESENT	0
32317	32306	95015C	PARTICIPANT	\N	PRESENT	0
32318	32306	92015P	PARTICIPANT	\N	EXCUSE	0
32319	32306	08024S	PARTICIPANT	\N	PRESENT	0
32320	32306	14201E	PARTICIPANT	\N	PRESENT	0
38899	38897	01013J	PARTICIPANT	\N	PRESENT	0
38900	38897	11040E	PARTICIPANT	\N	PRESENT	0
38901	38897	14175V	PARTICIPANT	\N	PRESENT	0
32324	32306	11091R	PARTICIPANT	\N	PRESENT	0
32325	32306	87003B	PARTICIPANT	\N	PRESENT	0
38902	38897	11053K	PARTICIPANT	\N	PRESENT	0
38903	38897	14085U	PARTICIPANT	\N	PRESENT	0
38904	38897	11042G	PARTICIPANT	\N	PRESENT	0
32329	32306	01025N	PARTICIPANT	\N	PRESENT	0
38905	38897	04086Q	PARTICIPANT	\N	PRESENT	0
38906	38897	11070L	PARTICIPANT	\N	PRESENT	0
32332	32306	08035V	PARTICIPANT	\N	PRESENT	0
32333	32306	11089X	PARTICIPANT	\N	PRESENT	0
38907	38897	08022Q	PARTICIPANT	\N	PRESENT	0
32335	32306	14123H	PARTICIPANT	\N	PRESENT	0
38908	38897	01027Q	PARTICIPANT	\N	PRESENT	0
38909	38897	04071H	PARTICIPANT	\N	PRESENT	0
32338	32306	14241N	PARTICIPANT	\N	PRESENT	0
32339	32306	14061L	PARTICIPANT	\N	PRESENT	0
32340	32306	14073Q	PARTICIPANT	\N	PRESENT	0
32341	32306	08031R	PARTICIPANT	\N	PRESENT	0
38910	38897	11083R	PARTICIPANT	\N	PRESENT	0
32343	32306	08039A	PARTICIPANT	\N	EXCUSE	0
32344	32306	08017T	PARTICIPANT	\N	PRESENT	0
32345	32306	14059S	PARTICIPANT	\N	EXCUSE	0
38911	38897	14199E	PARTICIPANT	\N	PRESENT	0
38912	38897	01057W	PARTICIPANT	\N	PRESENT	0
32348	32306	11104D	PARTICIPANT	\N	PRESENT	0
32349	32306	14063N	PARTICIPANT	\N	PRESENT	0
32350	32306	04057K	PARTICIPANT	\N	PRESENT	0
38913	38897	11048N	PARTICIPANT	\N	PRESENT	0
32352	32306	14109K	PARTICIPANT	\N	PRESENT	0
32353	32306	04070G	PRESIDENT	0	PRESENT	0
32354	32306	92040Q	PARTICIPANT	0	PRESENT	0
38914	38897	07029T	PARTICIPANT	\N	PRESENT	0
38915	38897	08010L	PARTICIPANT	\N	PRESENT	0
38916	38897	08034U	PARTICIPANT	\N	PRESENT	0
38917	38897	98046X	PARTICIPANT	\N	PRESENT	0
38918	38897	08011M	PARTICIPANT	\N	PRESENT	0
32360	32306	14229S	PARTICIPANT	\N	PRESENT	0
32361	32306	11043H	PARTICIPANT	\N	PRESENT	0
38919	38897	08061X	PARTICIPANT	\N	PRESENT	0
38920	38897	01016M	PARTICIPANT	\N	PRESENT	0
38921	38897	11012A	PARTICIPANT	\N	PRESENT	0
38922	38897	11057P	PARTICIPANT	\N	PRESENT	0
38923	38897	04034C	PARTICIPANT	\N	PRESENT	0
41777	41776	89017R	PARTICIPANT	\N	PRESENT	0
41778	41776	01031L	PRESIDENT	0	PRESENT	0
42464	42463	92045V	PARTICIPANT	\N	PRESENT	0
41780	41776	01013J	PARTICIPANT	\N	PRESENT	0
42475	42474	11039M	PARTICIPANT	\N	PRESENT	0
41782	41776	11040E	PARTICIPANT	\N	PRESENT	0
41783	41776	08014Q	PARTICIPANT	\N	PRESENT	0
41784	41776	14167V	PARTICIPANT	\N	PRESENT	0
42476	42474	98042T	PARTICIPANT	\N	PRESENT	0
41786	41776	14083S	PARTICIPANT	\N	PRESENT	0
42477	42474	01019Q	PARTICIPANT	\N	PRESENT	0
52286	52285	01013J	PARTICIPANT	\N	PRESENT	0
52287	52285	11053K	PARTICIPANT	\N	PRESENT	0
52288	52285	11080N	PARTICIPANT	\N	EXCUSE	0
41791	41776	04086Q	PARTICIPANT	\N	PRESENT	0
52289	52285	01027Q	PRESIDENT	0	PRESENT	0
41793	41776	11070L	PARTICIPANT	\N	PRESENT	0
52290	52285	01057W	PARTICIPANT	\N	PRESENT	0
41795	41776	14327T	PARTICIPANT	\N	PRESENT	0
52291	52285	14159V	PARTICIPANT	\N	PRESENT	0
41797	41776	01027Q	PARTICIPANT	\N	EXCUSE	0
41798	41776	04071H	PARTICIPANT	\N	PRESENT	0
41799	41776	11074Q	PARTICIPANT	\N	PRESENT	0
52292	52285	92039X	PARTICIPANT	\N	PRESENT	0
41801	41776	11083R	PARTICIPANT	\N	PRESENT	0
52293	52285	11012A	PARTICIPANT	\N	PRESENT	0
52294	52285	14157T	PARTICIPANT	\N	EXCUSE	0
52317	51473	08024S	PARTICIPANT	\N	PRESENT	0
41805	41776	08069G	PARTICIPANT	\N	PRESENT	0
41806	41776	11048N	PARTICIPANT	\N	PRESENT	0
41807	41776	99004R	PARTICIPANT	\N	PRESENT	0
52318	51473	11040E	PARTICIPANT	\N	PRESENT	0
41809	41776	14159V	PARTICIPANT	\N	PRESENT	0
41810	41776	07029T	PARTICIPANT	\N	PRESENT	0
52319	51473	01022K	PARTICIPANT	\N	PRESENT	0
41812	41776	08010L	PARTICIPANT	\N	PRESENT	0
41813	41776	08034U	PARTICIPANT	\N	PRESENT	0
52320	51473	04041B	PARTICIPANT	\N	PRESENT	0
41815	41776	98046X	PARTICIPANT	\N	PRESENT	0
52321	51473	95031C	PARTICIPANT	\N	PRESENT	0
41817	41776	08011M	PARTICIPANT	\N	PRESENT	0
52322	51473	08069G	PARTICIPANT	\N	PRESENT	0
52323	51473	04088S	PARTICIPANT	\N	PRESENT	0
41820	41776	01016M	PARTICIPANT	\N	PRESENT	0
41821	41776	14225N	PARTICIPANT	\N	PRESENT	0
41822	41776	11012A	PARTICIPANT	\N	PRESENT	0
41823	41776	11057P	PARTICIPANT	\N	PRESENT	0
41824	41776	14173T	PARTICIPANT	\N	PRESENT	0
41825	41776	04034C	PARTICIPANT	\N	PRESENT	0
52324	51473	80027E	PARTICIPANT	\N	PRESENT	0
52325	51473	95063L	PARTICIPANT	\N	PRESENT	0
52326	51473	14147R	PARTICIPANT	\N	PRESENT	0
52327	51473	00003C	PARTICIPANT	\N	PRESENT	0
52328	51473	01015L	PARTICIPANT	\N	PRESENT	0
52329	51473	14265W	PARTICIPANT	\N	PRESENT	0
52330	51473	14197C	PARTICIPANT	\N	PRESENT	0
52331	51473	13002U	PARTICIPANT	\N	PRESENT	0
52332	51473	14061L	PARTICIPANT	\N	PRESENT	0
52333	51473	14051J	PARTICIPANT	\N	PRESENT	0
52334	51473	14237S	PARTICIPANT	\N	PRESENT	0
52335	51473	98046X	PARTICIPANT	\N	PRESENT	0
52336	51473	09001P	PARTICIPANT	\N	PRESENT	0
52337	51473	11103C	PARTICIPANT	\N	PRESENT	0
52338	51473	08055A	PARTICIPANT	\N	PRESENT	0
52339	51473	14107H	PARTICIPANT	\N	PRESENT	0
52340	51473	08060W	PARTICIPANT	\N	PRESENT	0
52341	51473	08016S	PARTICIPANT	\N	PRESENT	0
52342	51473	92039X	PARTICIPANT	\N	PRESENT	0
52343	51473	11107G	PARTICIPANT	\N	PRESENT	0
52344	51473	11066Q	PARTICIPANT	\N	PRESENT	0
52345	51473	01044R	PARTICIPANT	\N	PRESENT	0
52346	51473	11114F	PARTICIPANT	\N	PRESENT	0
52347	51473	11095V	PARTICIPANT	\N	PRESENT	0
52348	51473	08049C	PARTICIPANT	\N	PRESENT	0
52349	51473	14261S	PARTICIPANT	\N	PRESENT	0
52350	51473	14083S	PARTICIPANT	\N	PRESENT	0
52351	51473	14030Q	PARTICIPANT	\N	PRESENT	0
52352	51473	14219Q	PARTICIPANT	\N	PRESENT	0
52353	51473	14103D	PARTICIPANT	\N	PRESENT	0
52354	51473	08009T	PARTICIPANT	\N	PRESENT	0
52355	51473	14093U	PARTICIPANT	\N	PRESENT	0
52356	51473	11090Q	PARTICIPANT	\N	PRESENT	0
52357	51473	04089T	PARTICIPANT	\N	PRESENT	0
52358	51473	14213J	PARTICIPANT	\N	PRESENT	0
52359	51473	11099A	PARTICIPANT	\N	PRESENT	0
52360	51473	14331P	PARTICIPANT	\N	PRESENT	0
52361	51473	14223L	PARTICIPANT	\N	PRESENT	0
52362	51473	14157T	PARTICIPANT	\N	PRESENT	0
52363	51473	08062Y	PARTICIPANT	\N	PRESENT	0
52364	51473	14055N	PARTICIPANT	\N	PRESENT	0
52365	51473	11011M	PARTICIPANT	\N	PRESENT	0
52366	51473	14039A	PARTICIPANT	\N	PRESENT	0
52367	51473	11049P	PARTICIPANT	\N	PRESENT	0
51047	49955	01044R	PARTICIPANT	\N	PRESENT	0
51048	49955	95015C	PARTICIPANT	\N	PRESENT	0
51049	49955	08068F	PARTICIPANT	\N	PRESENT	0
51050	49955	14159V	PARTICIPANT	\N	PRESENT	0
51051	49955	08038Y	PARTICIPANT	\N	PRESENT	0
51052	49955	11097X	PARTICIPANT	\N	PRESENT	0
51053	49955	14205J	PARTICIPANT	\N	PRESENT	0
51054	49955	14187A	PARTICIPANT	\N	PRESENT	0
51055	49955	11090Q	PARTICIPANT	\N	PRESENT	0
51056	49955	11064N	PARTICIPANT	\N	PRESENT	0
51151	49956	14235Q	PARTICIPANT	\N	PRESENT	0
51152	49956	14263U	PARTICIPANT	\N	PRESENT	0
51153	49956	92015P	PARTICIPANT	\N	PRESENT	0
51154	49956	11036J	PARTICIPANT	\N	PRESENT	0
51155	49956	01022K	PARTICIPANT	\N	PRESENT	0
51156	49956	08068F	PARTICIPANT	\N	PRESENT	0
51157	49956	14121F	PARTICIPANT	\N	PRESENT	0
51158	49956	11104D	PARTICIPANT	\N	PRESENT	0
51159	49956	14014Q	PARTICIPANT	\N	PRESENT	0
51160	49956	14207L	PARTICIPANT	\N	PRESENT	0
51161	49956	14159V	PARTICIPANT	\N	PRESENT	0
51162	49956	11029K	PARTICIPANT	\N	PRESENT	0
51163	49956	01044R	PARTICIPANT	\N	PRESENT	0
51164	49956	14030Q	PARTICIPANT	\N	PRESENT	0
51165	49956	95062K	PARTICIPANT	\N	PRESENT	0
51166	49956	14241N	PARTICIPANT	\N	PRESENT	0
51167	49956	95015C	PARTICIPANT	\N	PRESENT	0
51168	49956	14205J	PARTICIPANT	\N	PRESENT	0
51169	49956	14327T	PARTICIPANT	\N	PRESENT	0
51170	49956	08056B	PARTICIPANT	\N	PRESENT	0
51171	49956	14215L	PARTICIPANT	\N	PRESENT	0
51172	49956	14087W	PARTICIPANT	\N	PRESENT	0
51173	49956	08010L	PARTICIPANT	\N	PRESENT	0
51174	49956	14267Y	PARTICIPANT	\N	PRESENT	0
51175	49956	87003B	PARTICIPANT	\N	PRESENT	0
51176	49956	08031R	PARTICIPANT	\N	PRESENT	0
51177	49956	14259Y	PARTICIPANT	\N	PRESENT	0
51178	49956	11012A	PARTICIPANT	\N	PRESENT	0
51179	49956	11090Q	PARTICIPANT	\N	PRESENT	0
51180	49956	88008L	PARTICIPANT	\N	PRESENT	0
51181	49956	14031R	PARTICIPANT	\N	PRESENT	0
51182	49956	04057K	PARTICIPANT	\N	PRESENT	0
51183	49956	01016M	PARTICIPANT	\N	PRESENT	0
51184	49956	14033T	PARTICIPANT	\N	PRESENT	0
51185	49956	14135M	PARTICIPANT	\N	PRESENT	0
51186	49956	14257W	PARTICIPANT	\N	PRESENT	0
51187	49956	07029T	PARTICIPANT	\N	PRESENT	0
51188	49956	04088S	PARTICIPANT	\N	PRESENT	0
51189	49956	14013P	PARTICIPANT	\N	PRESENT	0
51190	49956	14105F	PARTICIPANT	\N	PRESENT	0
51191	49956	14231L	PARTICIPANT	\N	PRESENT	0
51192	49956	14083S	PARTICIPANT	\N	PRESENT	0
51193	49956	14187A	PARTICIPANT	\N	PRESENT	0
51194	49956	14179A	PARTICIPANT	\N	PRESENT	0
51195	49956	14053L	PARTICIPANT	\N	PRESENT	0
51196	49956	14079W	PARTICIPANT	\N	PRESENT	0
51197	49956	14209N	PARTICIPANT	\N	PRESENT	0
51198	49956	14273W	PARTICIPANT	\N	PRESENT	0
51199	49956	14331P	PARTICIPANT	\N	PRESENT	0
51200	49956	14041T	PARTICIPANT	\N	PRESENT	0
51201	49956	89017R	PARTICIPANT	\N	PRESENT	0
51202	49956	11043H	PARTICIPANT	\N	PRESENT	0
51203	49956	08065C	PARTICIPANT	\N	PRESENT	0
51204	49956	14059S	PARTICIPANT	\N	PRESENT	0
51205	49956	14073Q	PARTICIPANT	\N	PRESENT	0
51206	49956	04070G	PARTICIPANT	\N	PRESENT	0
51208	49956	14265W	PARTICIPANT	\N	PRESENT	0
51209	49956	14237S	PARTICIPANT	\N	PRESENT	0
51210	49956	14157T	PARTICIPANT	\N	PRESENT	0
51211	49956	11014C	PARTICIPANT	\N	PRESENT	0
51212	49956	80013X	PARTICIPANT	\N	PRESENT	0
51213	49956	14133K	PARTICIPANT	\N	PRESENT	0
51214	49956	11107G	PARTICIPANT	\N	PRESENT	0
51215	49956	11070L	PARTICIPANT	\N	PRESENT	0
51216	49956	11085T	PARTICIPANT	\N	PRESENT	0
51221	49956	11105E	PARTICIPANT	\N	PRESENT	0
51222	49956	14103D	PARTICIPANT	\N	PRESENT	0
51223	49956	14197C	PARTICIPANT	\N	PRESENT	0
51224	49956	14175V	PARTICIPANT	\N	PRESENT	0
51225	49956	11093T	PARTICIPANT	\N	PRESENT	0
51226	49956	14195A	PARTICIPANT	\N	PRESENT	0
51227	49956	14061L	PARTICIPANT	\N	PRESENT	0
51309	49957	12042Y	PARTICIPANT	\N	PRESENT	0
51310	49957	11063M	PARTICIPANT	\N	PRESENT	0
51311	49957	14235Q	PARTICIPANT	\N	PRESENT	0
51312	49957	11098Y	PARTICIPANT	\N	PRESENT	0
51313	49957	14151M	PARTICIPANT	\N	PRESENT	0
51314	49957	80013X	PARTICIPANT	\N	PRESENT	0
51315	49957	14227Q	PARTICIPANT	\N	PRESENT	0
51316	49957	14121F	PARTICIPANT	\N	PRESENT	0
51317	49957	08052W	PARTICIPANT	\N	PRESENT	0
51318	49957	00003C	PARTICIPANT	\N	PRESENT	0
51319	49957	14207L	PARTICIPANT	\N	PRESENT	0
51320	49957	14257W	PARTICIPANT	\N	PRESENT	0
51321	49957	14281W	PARTICIPANT	\N	PRESENT	0
51322	49957	14271U	PARTICIPANT	\N	PRESENT	0
51323	49957	11025F	PARTICIPANT	\N	PRESENT	0
51324	49957	04053F	PARTICIPANT	\N	PRESENT	0
51325	49957	11031D	PARTICIPANT	\N	PRESENT	0
51326	49957	14105F	PARTICIPANT	\N	PRESENT	0
51149	49956	08055A	PARTICIPANT	\N	PRESENT	0
51150	49956	07026Q	PARTICIPANT	\N	PRESENT	0
51327	49957	14267Y	PARTICIPANT	\N	PRESENT	0
51328	49957	14253S	PARTICIPANT	\N	PRESENT	0
51329	49957	14205J	PARTICIPANT	\N	PRESENT	0
51330	49957	14071N	PARTICIPANT	\N	PRESENT	0
51331	49957	14034U	PARTICIPANT	\N	PRESENT	0
51332	49957	14327T	PARTICIPANT	\N	PRESENT	0
51333	49957	14273W	PARTICIPANT	\N	PRESENT	0
51334	49957	14018U	PARTICIPANT	\N	PRESENT	0
51335	49957	14195A	PARTICIPANT	\N	PRESENT	0
51336	49957	14255U	PARTICIPANT	\N	PRESENT	0
51337	49957	14097Y	PARTICIPANT	\N	PRESENT	0
51338	49957	14051J	PARTICIPANT	\N	PRESENT	0
51339	49957	14030Q	PARTICIPANT	\N	PRESENT	0
51340	49957	01059Y	PARTICIPANT	\N	PRESENT	0
51341	49957	14231L	PARTICIPANT	\N	PRESENT	0
51342	49957	14187A	PARTICIPANT	\N	PRESENT	0
51343	49957	14059S	PARTICIPANT	\N	PRESENT	0
51344	49957	11107G	PARTICIPANT	\N	PRESENT	0
51345	49957	14033T	PARTICIPANT	\N	PRESENT	0
51346	49957	14265W	PARTICIPANT	\N	PRESENT	0
51347	49957	14042U	PARTICIPANT	\N	PRESENT	0
51348	49957	11093T	PARTICIPANT	\N	PRESENT	0
51349	49957	01034P	PARTICIPANT	\N	PRESENT	0
51350	49957	11061K	PARTICIPANT	\N	PRESENT	0
51351	49957	08060W	PARTICIPANT	\N	PRESENT	0
51352	49957	01044R	PARTICIPANT	\N	PRESENT	0
51353	49957	04088S	PARTICIPANT	\N	PRESENT	0
51354	49957	14209N	PARTICIPANT	\N	PRESENT	0
51355	49957	10006L	PARTICIPANT	\N	PRESENT	0
51356	49957	14197C	PARTICIPANT	\N	PRESENT	0
51357	49957	14031R	PARTICIPANT	\N	PRESENT	0
51358	49957	04045F	PARTICIPANT	\N	PRESENT	0
51359	49957	08061X	PARTICIPANT	\N	PRESENT	0
51360	49957	01016M	PARTICIPANT	\N	PRESENT	0
51361	49957	14135M	PARTICIPANT	\N	PRESENT	0
51362	49957	14259Y	PARTICIPANT	\N	PRESENT	0
51363	49957	11048N	PARTICIPANT	\N	PRESENT	0
51364	49957	14109K	PARTICIPANT	\N	PRESENT	0
51365	49957	14083S	PARTICIPANT	\N	PRESENT	0
51366	49957	14133K	PARTICIPANT	\N	PRESENT	0
51367	49957	14053L	PARTICIPANT	\N	PRESENT	0
51368	49957	08010L	PARTICIPANT	\N	PRESENT	0
51369	49957	08015R	PARTICIPANT	\N	PRESENT	0
51370	49957	11036J	PARTICIPANT	\N	PRESENT	0
51371	49957	14241N	PARTICIPANT	\N	PRESENT	0
51372	49957	11099A	PARTICIPANT	\N	PRESENT	0
51373	49957	08051V	PARTICIPANT	\N	PRESENT	0
51374	49957	11064N	PARTICIPANT	\N	PRESENT	0
51375	49957	01015L	PARTICIPANT	\N	PRESENT	0
51307	49957	08024S	PARTICIPANT	\N	PRESENT	0
51308	49957	04092N	PARTICIPANT	\N	PRESENT	0
33365	33361	08024S	PARTICIPANT	\N	PRESENT	0
33363	33361	14133K	PARTICIPANT	\N	PRESENT	0
33364	33361	08043V	PARTICIPANT	\N	PRESENT	0
33366	33361	08031R	PARTICIPANT	\N	PRESENT	0
33367	33361	11014C	PARTICIPANT	\N	PRESENT	0
35635	35634	11076S	PARTICIPANT	\N	PRESENT	0
35636	35634	04054G	PARTICIPANT	\N	PRESENT	0
35637	35634	04040A	PARTICIPANT	\N	PRESENT	0
35638	35634	08058D	PARTICIPANT	\N	PRESENT	0
35639	35634	04042C	PRESIDENT	0	PRESENT	0
35692	35634	14083S	RAPPORTEUR_FOND	\N	PRESENT	0
35641	35634	98029W	PARTICIPANT	\N	PRESENT	0
37348	37347	07024N	PARTICIPANT	\N	PRESENT	0
35643	35634	11027H	PARTICIPANT	\N	PRESENT	0
35644	35634	98018T	PARTICIPANT	\N	PRESENT	0
35645	35634	92018S	PARTICIPANT	\N	PRESENT	0
35646	35634	92020L	PARTICIPANT	\N	PRESENT	0
35647	35634	95030B	PARTICIPANT	\N	PRESENT	0
37349	37347	98021N	PARTICIPANT	\N	PRESENT	0
35649	35634	95031C	PARTICIPANT	\N	PRESENT	0
35650	35634	97011G	PARTICIPANT	\N	PRESENT	0
37350	37347	01014K	PARTICIPANT	\N	PRESENT	0
35652	35634	04035D	PARTICIPANT	\N	PRESENT	0
35653	35634	07024N	PARTICIPANT	\N	PRESENT	0
35654	35634	04095R	PARTICIPANT	\N	PRESENT	0
35655	35634	14014Q	PARTICIPANT	\N	PRESENT	0
35656	35634	11015D	PARTICIPANT	\N	PRESENT	0
35657	35634	07004J	PARTICIPANT	\N	EXCUSE	0
35658	35634	95035G	PARTICIPANT	\N	PRESENT	0
35659	35634	08056B	PARTICIPANT	\N	PRESENT	0
35660	35634	14211G	PARTICIPANT	\N	PRESENT	0
37351	37347	01056V	PARTICIPANT	\N	PRESENT	0
37352	37347	11106F	PARTICIPANT	\N	PRESENT	0
35663	35634	95037J	PARTICIPANT	\N	PRESENT	0
35664	35634	04078Q	PARTICIPANT	\N	PRESENT	0
35665	35634	14097Y	PARTICIPANT	\N	PRESENT	0
37354	37353	07024N	PARTICIPANT	\N	PRESENT	0
35667	35634	04036E	PARTICIPANT	\N	PRESENT	0
35668	35634	14039A	PARTICIPANT	\N	PRESENT	0
35669	35634	04077P	PARTICIPANT	\N	PRESENT	0
35670	35634	98005N	PARTICIPANT	\N	PRESENT	0
35671	35634	92031P	PARTICIPANT	\N	PRESENT	0
35672	35634	11106F	PARTICIPANT	\N	PRESENT	0
35673	35634	14251Q	PARTICIPANT	\N	PRESENT	0
35674	35634	83042R	PARTICIPANT	\N	PRESENT	0
35675	35634	08053X	PARTICIPANT	\N	PRESENT	0
35676	35634	11082Q	PARTICIPANT	\N	PRESENT	0
37355	37353	98021N	PARTICIPANT	\N	PRESENT	0
37356	37353	01014K	PARTICIPANT	\N	PRESENT	0
35679	35634	08047A	PARTICIPANT	\N	PRESENT	0
35680	35634	14028W	PARTICIPANT	\N	PRESENT	0
35681	35634	14193X	PARTICIPANT	\N	PRESENT	0
35682	35634	98021N	PARTICIPANT	\N	PRESENT	0
35684	35634	04080J	PARTICIPANT	\N	PRESENT	0
35685	35634	95059Q	PRESIDENT	1	PRESENT	0
35686	35634	86044G	PARTICIPANT	\N	PRESENT	0
35687	35634	01014K	PARTICIPANT	\N	PRESENT	0
35688	35634	11054L	PARTICIPANT	\N	PRESENT	0
35689	35634	01056V	PARTICIPANT	\N	PRESENT	0
35690	35634	92044U	PARTICIPANT	\N	PRESENT	0
35691	35634	08049C	PARTICIPANT	\N	PRESENT	0
37367	37366	98018T	PARTICIPANT	\N	PRESENT	0
43347	43344	99004R	PARTICIPANT	\N	PRESENT	0
45685	42527	14133K	PARTICIPANT	\N	PRESENT	0
45686	42527	08043V	PARTICIPANT	\N	PRESENT	0
45687	42527	10006L	PARTICIPANT	\N	PRESENT	0
45688	42527	08024S	PARTICIPANT	\N	PRESENT	0
45689	42527	14265W	PARTICIPANT	\N	PRESENT	0
54894	54893	10006L	PARTICIPANT	\N	PRESENT	0
54895	54893	98042T	PARTICIPANT	\N	PRESENT	0
54896	54893	11048N	PARTICIPANT	\N	PRESENT	0
54897	54893	14061L	PARTICIPANT	\N	PRESENT	0
54898	54893	14059S	PARTICIPANT	\N	PRESENT	0
54899	54893	14063N	PARTICIPANT	\N	PRESENT	0
55961	54969	08058D	PARTICIPANT	\N	PRESENT	0
55963	54969	14229S	PARTICIPANT	\N	PRESENT	0
55967	54969	01024M	PARTICIPANT	\N	PRESENT	0
55968	54969	14073Q	PARTICIPANT	\N	PRESENT	0
55969	54969	14205J	PARTICIPANT	\N	PRESENT	0
55978	54969	01016M	PARTICIPANT	\N	PRESENT	0
57176	51893	14157T	PARTICIPANT	\N	PRESENT	0
57177	51893	11063M	PARTICIPANT	\N	PRESENT	0
57178	51893	14083S	PARTICIPANT	\N	PRESENT	0
57179	51893	14030Q	PARTICIPANT	\N	PRESENT	0
57180	52499	11063M	PARTICIPANT	\N	PRESENT	0
57181	52499	14083S	PARTICIPANT	\N	PRESENT	0
57182	52499	14030Q	PARTICIPANT	\N	PRESENT	0
57242	57241	08043V	PARTICIPANT	\N	EXCUSE	0
57243	57241	95035G	PARTICIPANT	\N	EXCUSE	0
57244	57241	07029T	PARTICIPANT	\N	EXCUSE	0
57245	57241	14237S	PARTICIPANT	\N	EXCUSE	0
57246	57241	11031D	PARTICIPANT	\N	PRESENT	0
57247	57241	14217N	PARTICIPANT	\N	PRESENT	0
57248	57241	14281W	PARTICIPANT	\N	PRESENT	0
57249	57241	07026Q	PARTICIPANT	\N	PRESENT	0
57250	57241	09001P	PRESIDENT	0	PRESENT	0
57251	57241	04036E	PARTICIPANT	\N	PRESENT	0
57252	57241	08031R	PARTICIPANT	\N	PRESENT	0
57253	57241	14031R	PARTICIPANT	\N	PRESENT	0
57254	57241	11067R	PARTICIPANT	\N	PRESENT	0
57256	57241	11014C	PARTICIPANT	\N	PRESENT	0
57849	57846	11040E	PARTICIPANT	\N	PRESENT	0
57850	57846	96004D	PRESIDENT	0	PRESENT	0
57851	57846	14133K	PARTICIPANT	\N	PRESENT	0
57852	57846	14089Y	PARTICIPANT	\N	PRESENT	0
57853	57846	14079W	PARTICIPANT	\N	PRESENT	0
57854	57846	11083R	PARTICIPANT	\N	PRESENT	0
57855	57846	14026U	PARTICIPANT	\N	PRESENT	0
57856	57846	14097Y	PARTICIPANT	\N	PRESENT	0
57857	57846	04061F	PARTICIPANT	\N	PRESENT	0
57858	57846	14073Q	PARTICIPANT	\N	PRESENT	0
57859	57846	11026G	PARTICIPANT	\N	PRESENT	0
57860	57846	14001X	PARTICIPANT	\N	PRESENT	0
57861	57846	04080J	PARTICIPANT	\N	PRESENT	0
57862	57846	01016M	PARTICIPANT	\N	PRESENT	0
57863	57846	11012A	PARTICIPANT	\N	PRESENT	0
57864	57846	95063L	PARTICIPANT	\N	PRESENT	0
57865	57846	04045F	PARTICIPANT	\N	PRESENT	0
57866	57846	98035U	PARTICIPANT	\N	PRESENT	0
57867	57846	92045V	PARTICIPANT	\N	PRESENT	0
57868	57846	04034C	PARTICIPANT	\N	PRESENT	0
57869	57846	90003B	PARTICIPANT	\N	EXCUSE	0
57870	57846	98046X	PARTICIPANT	\N	EXCUSE	0
57871	57846	04057K	PARTICIPANT	\N	EXCUSE	0
57872	57846	11035H	PARTICIPANT	\N	EXCUSE	0
57942	56793	14241N	PARTICIPANT	\N	PRESENT	0
57943	56793	14193X	PARTICIPANT	\N	PRESENT	0
60317	60257	08051V	PARTICIPANT	\N	PRESENT	0
60320	60319	04044E	PARTICIPANT	\N	PRESENT	0
60323	60322	04085P	PARTICIPANT	\N	PRESENT	0
60315	60257	95049N	PARTICIPANT	\N	PRESENT	0
60316	60257	04044E	PARTICIPANT	\N	PRESENT	0
60324	60322	11033F	PARTICIPANT	\N	PRESENT	0
60325	60322	95049N	PARTICIPANT	\N	PRESENT	0
60327	60326	11033F	PARTICIPANT	\N	PRESENT	0
60328	60326	95049N	PARTICIPANT	\N	PRESENT	0
60334	60332	11033F	PARTICIPANT	\N	PRESENT	0
60335	60332	08051V	PARTICIPANT	\N	PRESENT	0
60336	60332	95049N	PARTICIPANT	\N	PRESENT	0
60337	60332	95063L	PARTICIPANT	\N	PRESENT	0
60338	60332	04044E	PARTICIPANT	\N	PRESENT	0
60340	60339	95049N	PARTICIPANT	\N	PRESENT	0
60342	60341	05008E	PARTICIPANT	\N	PRESENT	0
60343	60341	04085P	PARTICIPANT	\N	PRESENT	0
60344	60341	11033F	PARTICIPANT	\N	PRESENT	0
60345	60341	95049N	PARTICIPANT	\N	PRESENT	0
60346	60341	95063L	PARTICIPANT	\N	PRESENT	0
60347	60341	04044E	PARTICIPANT	\N	PRESENT	0
60390	60389	11076S	PARTICIPANT	\N	PRESENT	0
60391	60389	04066L	PARTICIPANT	\N	PRESENT	0
60392	60389	08038Y	PARTICIPANT	\N	PRESENT	0
60393	60389	11091R	PARTICIPANT	\N	PRESENT	0
60394	60389	14018U	PARTICIPANT	\N	PRESENT	0
60395	60389	08053X	PARTICIPANT	\N	PRESENT	0
60396	60389	11105E	PARTICIPANT	\N	PRESENT	0
60397	60389	11046L	PARTICIPANT	\N	PRESENT	0
60398	60389	14235Q	PARTICIPANT	\N	PRESENT	0
60450	60449	04053F	PARTICIPANT	\N	PRESENT	0
60451	60449	04086Q	PARTICIPANT	\N	PRESENT	0
60452	60449	11035H	PARTICIPANT	\N	PRESENT	0
60453	60449	10006L	PARTICIPANT	\N	PRESENT	0
60454	60449	08018U	PARTICIPANT	\N	PRESENT	0
60455	60449	01037S	PARTICIPANT	\N	PRESENT	0
60456	60449	11083R	PARTICIPANT	\N	PRESENT	0
60457	60449	14159V	PARTICIPANT	\N	PRESENT	0
48679	48678	95067Q	PARTICIPANT	\N	PRESENT	0
48680	48678	05012A	PARTICIPANT	\N	PRESENT	0
49394	49393	14263U	PARTICIPANT	\N	EXCUSE	0
49395	49393	14133K	PARTICIPANT	\N	PRESENT	0
49396	49393	04059M	PARTICIPANT	\N	PRESENT	0
49397	49393	01044R	PARTICIPANT	\N	PRESENT	0
49398	49393	08043V	PARTICIPANT	\N	PRESENT	0
49399	49393	11029K	PARTICIPANT	\N	PRESENT	0
49400	49393	92015P	PARTICIPANT	\N	PRESENT	0
49401	49393	11091R	PARTICIPANT	\N	PRESENT	0
49402	49393	14249W	PARTICIPANT	\N	PRESENT	0
49403	49393	01025N	PARTICIPANT	\N	PRESENT	0
49404	49393	11089X	PARTICIPANT	\N	PRESENT	0
49405	49393	07026Q	PARTICIPANT	\N	PRESENT	0
49406	49393	14179A	PARTICIPANT	\N	PRESENT	0
49407	49393	08031R	PARTICIPANT	\N	PRESENT	0
49408	49393	12041X	PARTICIPANT	\N	PRESENT	0
49409	49393	08039A	PARTICIPANT	\N	PRESENT	0
49410	49393	14059S	PARTICIPANT	\N	PRESENT	0
49411	49393	04057K	PRESIDENT	1	PRESENT	0
49412	49393	14109K	PARTICIPANT	\N	PRESENT	0
49413	49393	04070G	PRESIDENT	0	PRESENT	0
49414	49393	14235Q	PARTICIPANT	\N	EXCUSE	0
49415	49393	14229S	PARTICIPANT	\N	PRESENT	0
49571	45694	14133K	PARTICIPANT	\N	PRESENT	0
49572	45694	08024S	PARTICIPANT	\N	PRESENT	0
49573	45694	11014C	PARTICIPANT	\N	PRESENT	0
49574	45694	14265W	PARTICIPANT	\N	PRESENT	0
49582	49581	14038Y	PARTICIPANT	\N	PRESENT	0
49583	49581	11072N	PARTICIPANT	\N	PRESENT	0
49584	49581	04034C	PARTICIPANT	\N	PRESENT	0
49586	49585	11074Q	PARTICIPANT	\N	PRESENT	0
49587	49585	04056J	PARTICIPANT	\N	PRESENT	0
49588	49585	11091R	PARTICIPANT	\N	PRESENT	0
49662	49661	14079W	PARTICIPANT	\N	PRESENT	0
49663	49661	14187A	PARTICIPANT	\N	PRESENT	0
49664	49661	14087W	PARTICIPANT	\N	PRESENT	0
49665	49661	01037S	PARTICIPANT	\N	PRESENT	0
49666	49661	04041B	PARTICIPANT	\N	PRESENT	0
49667	49661	11084S	PARTICIPANT	\N	PRESENT	0
49668	49661	11026G	PARTICIPANT	\N	PRESENT	0
49669	49661	11105E	PARTICIPANT	\N	PRESENT	0
49671	49670	01037S	PARTICIPANT	\N	PRESENT	0
49672	49670	07004J	PARTICIPANT	\N	PRESENT	0
49673	49670	11112D	PARTICIPANT	\N	PRESENT	0
49674	49670	10015M	PARTICIPANT	\N	PRESENT	0
49852	48554	92039X	PARTICIPANT	\N	PRESENT	0
49960	49557	11114F	PARTICIPANT	\N	PRESENT	0
49854	48554	04094Q	PARTICIPANT	\N	PRESENT	0
49912	49855	01027Q	PARTICIPANT	\N	EXCUSE	0
49954	49557	98053W	PARTICIPANT	\N	PRESENT	0
49961	49557	07026Q	PARTICIPANT	\N	PRESENT	0
49962	49557	11031D	PARTICIPANT	\N	PRESENT	0
49963	49557	11040E	PARTICIPANT	\N	PRESENT	0
49964	49557	01044R	PARTICIPANT	\N	PRESENT	0
49965	49557	11029K	PARTICIPANT	\N	PRESENT	0
49966	49557	08031R	PARTICIPANT	\N	PRESENT	0
49967	49557	14038Y	PARTICIPANT	\N	PRESENT	0
49968	49557	04088S	PARTICIPANT	\N	PRESENT	0
49969	49557	08069G	PARTICIPANT	\N	PRESENT	0
49970	49557	14157T	PARTICIPANT	\N	PRESENT	0
49971	49557	14103D	PARTICIPANT	\N	PRESENT	0
49972	49557	14083S	PARTICIPANT	\N	PRESENT	0
49973	49557	14013P	PARTICIPANT	\N	PRESENT	0
49974	49557	01022K	PARTICIPANT	\N	PRESENT	0
49975	49557	01059Y	PARTICIPANT	\N	PRESENT	0
49976	49557	01013J	PARTICIPANT	\N	PRESENT	0
49977	49557	01015L	PARTICIPANT	\N	PRESENT	0
49978	49557	11056N	PARTICIPANT	\N	PRESENT	0
49979	49557	11089X	PARTICIPANT	\N	PRESENT	0
49980	49557	14147R	PARTICIPANT	\N	PRESENT	0
49981	49557	04081K	PARTICIPANT	\N	PRESENT	0
49982	49557	07029T	PARTICIPANT	\N	PRESENT	0
49983	49557	01061S	PARTICIPANT	\N	PRESENT	0
49984	49557	14263U	PARTICIPANT	\N	PRESENT	0
49985	49557	04054G	PARTICIPANT	\N	PRESENT	0
49986	49557	11100Y	PARTICIPANT	\N	PRESENT	0
49987	49557	14265W	PARTICIPANT	\N	PRESENT	0
49988	49557	11034G	PARTICIPANT	\N	PRESENT	0
49989	49557	12041X	PARTICIPANT	\N	PRESENT	0
49990	49557	11012A	PARTICIPANT	\N	PRESENT	0
49991	49557	14089Y	PARTICIPANT	\N	PRESENT	0
49992	49557	14179A	PARTICIPANT	\N	PRESENT	0
49993	49557	14273W	PARTICIPANT	\N	PRESENT	0
49994	49557	11088W	PARTICIPANT	\N	PRESENT	0
49995	49557	04034C	PARTICIPANT	\N	PRESENT	0
49996	49557	11068S	PARTICIPANT	\N	PRESENT	0
49997	49557	04085P	PARTICIPANT	\N	PRESENT	0
49998	49557	11098Y	PARTICIPANT	\N	PRESENT	0
49999	49557	11063M	PARTICIPANT	\N	PRESENT	0
50000	49557	14026U	PARTICIPANT	\N	PRESENT	0
50001	49557	14219Q	PARTICIPANT	\N	PRESENT	0
50002	49557	11057P	PARTICIPANT	\N	PRESENT	0
50003	49557	14197C	PARTICIPANT	\N	PRESENT	0
50004	49557	08014Q	PARTICIPANT	\N	PRESENT	0
50005	49557	11066Q	PARTICIPANT	\N	PRESENT	0
50006	49557	14034U	PARTICIPANT	\N	PRESENT	0
50007	49557	14037X	PARTICIPANT	\N	PRESENT	0
50008	49557	14061L	PARTICIPANT	\N	PRESENT	0
50009	49557	04049K	PARTICIPANT	\N	PRESENT	0
50010	49557	11043H	PARTICIPANT	\N	PRESENT	0
50011	49557	14173T	PARTICIPANT	\N	PRESENT	0
50012	49557	01043Q	PARTICIPANT	\N	PRESENT	0
50013	49557	14235Q	PARTICIPANT	\N	PRESENT	0
50014	49557	08053X	PARTICIPANT	\N	PRESENT	0
50015	49557	04089T	PARTICIPANT	\N	PRESENT	0
50016	49557	11025F	PARTICIPANT	\N	PRESENT	0
50017	49557	08015R	PARTICIPANT	\N	PRESENT	0
50018	49557	08042U	PARTICIPANT	\N	PRESENT	0
50019	49557	01047U	PARTICIPANT	\N	PRESENT	0
50020	49557	14207L	PARTICIPANT	\N	PRESENT	0
50021	49557	11085T	PARTICIPANT	\N	PRESENT	0
50025	49557	83042R	PARTICIPANT	\N	PRESENT	0
50023	49557	14028W	PARTICIPANT	\N	PRESENT	0
50024	49557	11036J	PARTICIPANT	\N	PRESENT	0
50026	49557	14267Y	PARTICIPANT	\N	PRESENT	0
50027	49557	14241N	PARTICIPANT	\N	PRESENT	0
50028	49557	08038Y	PARTICIPANT	\N	PRESENT	0
50029	49557	14059S	PARTICIPANT	\N	PRESENT	0
50030	49557	98050T	PARTICIPANT	\N	PRESENT	0
50031	49557	14159V	PARTICIPANT	\N	PRESENT	0
50032	49557	92015P	PARTICIPANT	\N	PRESENT	0
50033	49557	14205J	PARTICIPANT	\N	PRESENT	0
50034	49557	11042G	PARTICIPANT	\N	PRESENT	0
50036	49557	14257W	PARTICIPANT	\N	PRESENT	0
50037	49557	11014C	PARTICIPANT	\N	PRESENT	0
50039	49557	14201E	PARTICIPANT	\N	PRESENT	0
50042	49557	14195A	PARTICIPANT	\N	PRESENT	0
50043	49557	08028W	PARTICIPANT	\N	PRESENT	0
50044	49557	11104D	PARTICIPANT	\N	PRESENT	0
50045	49557	01016M	PARTICIPANT	\N	PRESENT	0
50046	49557	11097X	PARTICIPANT	\N	PRESENT	0
50047	49557	11094U	PARTICIPANT	\N	PRESENT	0
50048	49557	14031R	PARTICIPANT	\N	PRESENT	0
50049	49557	14327T	PARTICIPANT	\N	PRESENT	0
50050	49557	13002U	PARTICIPANT	\N	PRESENT	0
50051	49557	11110B	PARTICIPANT	\N	PRESENT	0
50052	49557	14014Q	PARTICIPANT	\N	PRESENT	0
501598	500477	19647E	PARTICIPANT	\N	PRESENT	0
501599	500477	19711U	PARTICIPANT	\N	PRESENT	0
501600	500477	08034U	PARTICIPANT	\N	PRESENT	0
501601	500477	19531S	PARTICIPANT	\N	PRESENT	0
501602	500477	01057W	PARTICIPANT	\N	PRESENT	0
501603	500477	19687N	PARTICIPANT	\N	PRESENT	0
501604	500477	19689Q	PARTICIPANT	\N	PRESENT	0
501605	500477	20080C	PARTICIPANT	\N	PRESENT	0
501606	500477	20044X	PARTICIPANT	\N	PRESENT	0
501607	500477	20150Y	PARTICIPANT	\N	PRESENT	0
501608	500477	14225N	PRESIDENT	0	PRESENT	0
501609	500477	04086Q	PARTICIPANT	\N	PRESENT	0
501610	500477	14083S	PARTICIPANT	\N	PRESENT	0
501611	500477	20070A	PARTICIPANT	\N	PRESENT	0
501612	500477	08010L	PARTICIPANT	\N	PRESENT	0
501613	500477	99004R	PARTICIPANT	\N	PRESENT	0
501614	500477	11053K	PARTICIPANT	\N	PRESENT	0
501617	500477	08011M	PARTICIPANT	\N	PRESENT	0
501618	500477	07029T	PARTICIPANT	\N	PRESENT	0
501624	500477	11048N	PARTICIPANT	\N	PRESENT	0
501625	500477	20126Y	PARTICIPANT	\N	PRESENT	0
501658	500477	04071H	PARTICIPANT	\N	PRESENT	0
501659	500477	01048V	PARTICIPANT	\N	PRESENT	0
501660	500477	19671E	PARTICIPANT	\N	PRESENT	0
501661	500477	11070L	PARTICIPANT	\N	PRESENT	0
501675	500477	20036X	PARTICIPANT	\N	PRESENT	0
501676	500477	12016W	PARTICIPANT	\N	PRESENT	0
501677	500282	14026U	PARTICIPANT	\N	PRESENT	0
501678	498850	19515S	PRESIDENT	0	PRESENT	0
36657	36656	14069U	PARTICIPANT	\N	PRESENT	0
36759	35864	11068S	PARTICIPANT	\N	EXCUSE	0
41567	41566	05008E	PARTICIPANT	\N	PRESENT	0
41568	41566	08024S	PARTICIPANT	\N	PRESENT	0
41569	41566	14042U	PARTICIPANT	\N	PRESENT	0
41570	41566	14231L	PARTICIPANT	\N	PRESENT	0
41571	41566	11083R	PARTICIPANT	\N	PRESENT	0
41572	41566	14061L	PARTICIPANT	\N	PRESENT	0
41573	41566	14059S	PARTICIPANT	\N	PRESENT	0
41574	41566	98046X	PARTICIPANT	\N	PRESENT	0
41575	41566	14071N	PARTICIPANT	\N	PRESENT	0
41576	41566	11069T	PARTICIPANT	\N	PRESENT	0
41577	41566	04043D	PARTICIPANT	\N	PRESENT	0
41578	41566	11043H	PARTICIPANT	\N	PRESENT	0
42479	42478	89017R	PARTICIPANT	\N	PRESENT	0
42480	42478	01031L	PRESIDENT	0	PRESENT	0
42481	42478	05004A	PARTICIPANT	\N	PRESENT	0
42482	42478	11068S	PARTICIPANT	\N	EXCUSE	0
42483	42478	11040E	PARTICIPANT	\N	PRESENT	0
42484	42478	08014Q	PARTICIPANT	\N	PRESENT	0
42485	42478	14175V	PARTICIPANT	\N	PRESENT	0
42486	42478	14083S	PARTICIPANT	\N	PRESENT	0
42487	42478	14085U	PARTICIPANT	\N	PRESENT	0
42489	42478	11042G	PARTICIPANT	\N	PRESENT	0
42490	42478	04055H	PARTICIPANT	\N	PRESENT	0
42491	42478	14327T	PARTICIPANT	\N	PRESENT	0
42492	42478	08022Q	PARTICIPANT	\N	PRESENT	0
42493	42478	01027Q	PARTICIPANT	\N	PRESENT	0
42494	42478	11074Q	PARTICIPANT	\N	PRESENT	0
42495	42478	11083R	PARTICIPANT	\N	PRESENT	0
42496	42478	14199E	PARTICIPANT	\N	PRESENT	0
42497	42478	01057W	PARTICIPANT	\N	PRESENT	0
42500	42478	08016S	PARTICIPANT	\N	PRESENT	0
42501	42478	08069G	PARTICIPANT	\N	PRESENT	0
42502	42478	11048N	PARTICIPANT	\N	PRESENT	0
42503	42478	14159V	PARTICIPANT	\N	PRESENT	0
42504	42478	07029T	PARTICIPANT	\N	PRESENT	0
42505	42478	14277B	PARTICIPANT	\N	PRESENT	0
42506	42478	08010L	PARTICIPANT	\N	PRESENT	0
42507	42478	08034U	PARTICIPANT	\N	PRESENT	0
42508	42478	01048V	PARTICIPANT	\N	PRESENT	0
42509	42478	98046X	PARTICIPANT	\N	PRESENT	0
42510	42478	08011M	PARTICIPANT	\N	PRESENT	0
42511	42478	08061X	PARTICIPANT	\N	PRESENT	0
42512	42478	01016M	PARTICIPANT	\N	PRESENT	0
42513	42478	14225N	PARTICIPANT	\N	PRESENT	0
42514	42478	11012A	PARTICIPANT	\N	PRESENT	0
42516	42478	11057P	PARTICIPANT	\N	PRESENT	0
42517	42478	14173T	PARTICIPANT	\N	PRESENT	0
42519	42478	04034C	PARTICIPANT	\N	PRESENT	0
46480	41619	98005N	PARTICIPANT	\N	EXCUSE	0
46482	41619	14097Y	PARTICIPANT	\N	EXCUSE	0
49829	43531	11099A	PARTICIPANT	\N	PRESENT	0
49830	43531	08051V	PARTICIPANT	\N	PRESENT	0
49831	43531	11112D	PARTICIPANT	\N	PRESENT	0
49856	49855	04040A	PRESIDENT	0	PRESENT	0
49857	49855	95067Q	PARTICIPANT	\N	EXCUSE	0
52368	51473	14221J	PARTICIPANT	\N	PRESENT	0
52369	51473	14031R	PARTICIPANT	\N	PRESENT	0
52370	51473	08061X	PARTICIPANT	\N	PRESENT	0
52371	51473	11056N	PARTICIPANT	\N	PRESENT	0
52372	51473	01027Q	PARTICIPANT	\N	PRESENT	0
52373	51473	01025N	PARTICIPANT	\N	PRESENT	0
52374	51473	14135M	PARTICIPANT	\N	PRESENT	0
52375	51473	14191V	PARTICIPANT	\N	PRESENT	0
52376	51473	14169X	PARTICIPANT	\N	PRESENT	0
52377	51473	14069U	PARTICIPANT	\N	PRESENT	0
52378	51473	96003C	PARTICIPANT	\N	PRESENT	0
52379	51473	14327T	PARTICIPANT	\N	PRESENT	0
52380	51473	14159V	PARTICIPANT	\N	PRESENT	0
52381	51473	11032E	PARTICIPANT	\N	PRESENT	0
52382	51473	14205J	PARTICIPANT	\N	PRESENT	0
52383	51473	14018U	PARTICIPANT	\N	PRESENT	0
52384	51473	11065P	PARTICIPANT	\N	PRESENT	0
52385	51473	11100Y	PARTICIPANT	\N	PRESENT	0
52386	51473	14073Q	PARTICIPANT	\N	PRESENT	0
52387	51473	92015P	PARTICIPANT	\N	PRESENT	0
52388	51473	14097Y	PARTICIPANT	\N	PRESENT	0
52389	51473	14207L	PARTICIPANT	\N	PRESENT	0
52390	51473	86044G	PARTICIPANT	\N	PRESENT	0
52391	51473	14105F	PARTICIPANT	\N	PRESENT	0
52392	51473	01047U	PARTICIPANT	\N	PRESENT	0
52393	51473	14001X	PARTICIPANT	\N	PRESENT	0
52394	51473	11059R	PARTICIPANT	\N	PRESENT	0
52395	51473	11111C	PARTICIPANT	\N	PRESENT	0
52396	51473	11048N	PARTICIPANT	\N	PRESENT	0
52397	51473	87003B	PARTICIPANT	\N	PRESENT	0
52398	51473	14033T	PARTICIPANT	\N	PRESENT	0
52399	51473	14111D	PARTICIPANT	\N	PRESENT	0
52400	51473	14053L	PARTICIPANT	\N	PRESENT	0
52401	51473	14087W	PARTICIPANT	\N	PRESENT	0
52402	51473	14231L	PARTICIPANT	\N	PRESENT	0
52403	51473	11081P	PARTICIPANT	\N	PRESENT	0
52404	51473	08042U	PARTICIPANT	\N	PRESENT	0
52405	51473	14028W	PARTICIPANT	\N	PRESENT	0
52406	51473	04094Q	PARTICIPANT	\N	PRESENT	0
52407	51473	11109J	PARTICIPANT	\N	PRESENT	0
52408	51473	11023D	PARTICIPANT	\N	PRESENT	0
52409	51473	88008L	PARTICIPANT	\N	PRESENT	0
52410	51473	14013P	PARTICIPANT	\N	PRESENT	0
52411	51473	14038Y	PARTICIPANT	\N	PRESENT	0
52412	51473	08068F	PARTICIPANT	\N	PRESENT	0
52413	51473	14026U	PARTICIPANT	\N	PRESENT	0
52414	51473	14269B	PARTICIPANT	\N	PRESENT	0
52415	51473	05012A	PARTICIPANT	\N	PRESENT	0
52416	51473	11084S	PARTICIPANT	\N	PRESENT	0
52417	51473	11042G	PARTICIPANT	\N	PRESENT	0
52418	51473	95030B	PARTICIPANT	\N	PRESENT	0
52419	51473	14041T	PARTICIPANT	\N	PRESENT	0
52420	51473	01013J	PARTICIPANT	\N	PRESENT	0
52421	51473	80013X	PARTICIPANT	\N	PRESENT	0
52422	51473	14225N	PARTICIPANT	\N	PRESENT	0
52463	51473	14085U	PARTICIPANT	\N	PRESENT	0
52464	51473	01028R	PARTICIPANT	\N	PRESENT	0
52465	51473	14199E	PARTICIPANT	\N	PRESENT	0
52466	51473	11071M	PARTICIPANT	\N	PRESENT	0
52467	51473	11097X	PARTICIPANT	\N	PRESENT	0
52468	51473	14173T	PARTICIPANT	\N	PRESENT	0
52469	51473	11029K	PARTICIPANT	\N	PRESENT	0
52470	51473	11057P	PARTICIPANT	\N	PRESENT	0
52471	51473	14167V	PARTICIPANT	\N	PRESENT	0
52472	51473	11037K	PARTICIPANT	\N	PRESENT	0
52473	51473	01061S	PARTICIPANT	\N	PRESENT	0
52474	51473	14195A	PARTICIPANT	\N	PRESENT	0
52475	51473	08028W	PARTICIPANT	\N	PRESENT	0
52476	51473	14121F	PARTICIPANT	\N	PRESENT	0
52477	51473	14037X	PARTICIPANT	\N	PRESENT	0
52478	51473	07032N	PARTICIPANT	\N	PRESENT	0
52479	51473	98005N	PARTICIPANT	\N	PRESENT	0
52480	51473	14259Y	PARTICIPANT	\N	PRESENT	0
52481	51473	14215L	PARTICIPANT	\N	PRESENT	0
52482	51473	14241N	PARTICIPANT	\N	PRESENT	0
52483	51473	14267Y	PARTICIPANT	\N	PRESENT	0
52484	51473	11094U	PARTICIPANT	\N	PRESENT	0
52485	51473	11089X	PARTICIPANT	\N	PRESENT	0
52486	51473	01003G	PARTICIPANT	\N	PRESENT	0
52487	51473	14042U	PARTICIPANT	\N	PRESENT	0
52488	51473	04045F	PARTICIPANT	\N	PRESENT	0
52489	51473	14251Q	PARTICIPANT	\N	PRESENT	0
52490	51473	01046T	PARTICIPANT	\N	PRESENT	0
52491	51473	11036J	PARTICIPANT	\N	PRESENT	0
52492	51473	01060R	PARTICIPANT	\N	PRESENT	0
52501	51473	01048V	PARTICIPANT	\N	PRESENT	0
52502	51473	89029V	PARTICIPANT	\N	PRESENT	0
52503	51473	04092N	PARTICIPANT	\N	PRESENT	0
52504	51473	08053X	PARTICIPANT	\N	PRESENT	0
52507	51473	11098Y	PARTICIPANT	\N	PRESENT	0
52508	51473	95015C	PARTICIPANT	\N	PRESENT	0
52509	51473	14059S	PARTICIPANT	\N	PRESENT	0
52510	51473	14227Q	PARTICIPANT	\N	PRESENT	0
52511	51473	99004R	PARTICIPANT	\N	PRESENT	0
52512	51473	08025T	PARTICIPANT	\N	PRESENT	0
52513	51473	04049K	PARTICIPANT	\N	PRESENT	0
52514	51473	01016M	PARTICIPANT	\N	PRESENT	0
52515	51473	08038Y	PARTICIPANT	\N	PRESENT	0
52516	51473	01037S	PARTICIPANT	\N	PRESENT	0
52517	51473	11106F	PARTICIPANT	\N	PRESENT	0
52518	51474	08024S	PARTICIPANT	\N	PRESENT	0
52519	51474	11040E	PARTICIPANT	\N	PRESENT	0
52520	51474	01022K	PARTICIPANT	\N	PRESENT	0
52521	51474	04041B	PARTICIPANT	\N	PRESENT	0
52522	51474	95031C	PARTICIPANT	\N	PRESENT	0
52523	51474	08069G	PARTICIPANT	\N	PRESENT	0
52524	51474	04088S	PARTICIPANT	\N	PRESENT	0
52525	51474	80027E	PARTICIPANT	\N	PRESENT	0
52526	51474	95063L	PARTICIPANT	\N	PRESENT	0
51446	49958	09001P	PARTICIPANT	\N	PRESENT	0
51447	49958	11031D	PARTICIPANT	\N	PRESENT	0
51448	49958	01015L	PARTICIPANT	\N	PRESENT	0
51449	49958	11036J	PARTICIPANT	\N	PRESENT	0
51450	49958	14051J	PARTICIPANT	\N	PRESENT	0
51451	49958	11107G	PARTICIPANT	\N	PRESENT	0
51452	49958	80013X	PARTICIPANT	\N	PRESENT	0
51453	49958	08052W	PARTICIPANT	\N	PRESENT	0
51454	49958	11061K	PARTICIPANT	\N	PRESENT	0
51467	49958	14265W	PARTICIPANT	\N	PRESENT	0
51456	49958	08060W	PARTICIPANT	\N	PRESENT	0
51457	49958	14281W	PARTICIPANT	\N	PRESENT	0
51458	49958	14271U	PARTICIPANT	\N	PRESENT	0
51459	49958	11099A	PARTICIPANT	\N	PRESENT	0
51460	49958	14018U	PARTICIPANT	\N	PRESENT	0
51461	49958	14241N	PARTICIPANT	\N	PRESENT	0
51462	49958	14030Q	PARTICIPANT	\N	PRESENT	0
51463	49958	14042U	PARTICIPANT	\N	PRESENT	0
51464	49958	14231L	PARTICIPANT	\N	PRESENT	0
51465	49958	14033T	PARTICIPANT	\N	PRESENT	0
51466	49958	02002K	PARTICIPANT	\N	PRESENT	0
51468	49958	14273W	PARTICIPANT	\N	PRESENT	0
51472	51234	08055A	PARTICIPANT	\N	PRESENT	0
51475	51234	14263U	PARTICIPANT	\N	PRESENT	0
51476	51234	11036J	PARTICIPANT	\N	PRESENT	0
51478	51234	11046L	PARTICIPANT	\N	PRESENT	0
51479	51234	11042G	PARTICIPANT	\N	PRESENT	0
51480	51234	01044R	PARTICIPANT	\N	PRESENT	0
51481	51234	14201E	PARTICIPANT	\N	PRESENT	0
51482	51234	14221J	PARTICIPANT	\N	PRESENT	0
51483	51234	14073Q	PARTICIPANT	\N	PRESENT	0
51484	51234	14273W	PARTICIPANT	\N	PRESENT	0
51485	51234	11100Y	PARTICIPANT	\N	PRESENT	0
51486	51234	01058X	PARTICIPANT	\N	PRESENT	0
51487	51234	04088S	PARTICIPANT	\N	PRESENT	0
51488	51234	14103D	PARTICIPANT	\N	PRESENT	0
51489	51234	11043H	PARTICIPANT	\N	PRESENT	0
51490	51234	01003G	PARTICIPANT	\N	PRESENT	0
51491	51234	98005N	PARTICIPANT	\N	PRESENT	0
51492	51234	08019V	PARTICIPANT	\N	PRESENT	0
51493	51234	14069U	PARTICIPANT	\N	PRESENT	0
51494	51234	04043D	PARTICIPANT	\N	PRESENT	0
51495	51234	11089X	PARTICIPANT	\N	PRESENT	0
51496	51234	14219Q	PARTICIPANT	\N	PRESENT	0
51497	51234	14193X	PARTICIPANT	\N	PRESENT	0
51498	51234	14031R	PARTICIPANT	\N	PRESENT	0
51499	51234	89017R	PARTICIPANT	\N	PRESENT	0
51500	51234	08056B	PARTICIPANT	\N	PRESENT	0
51501	51234	04057K	PARTICIPANT	\N	PRESENT	0
51502	51234	14209N	PARTICIPANT	\N	PRESENT	0
51503	51234	14033T	PARTICIPANT	\N	PRESENT	0
51504	51234	83042R	PARTICIPANT	\N	PRESENT	0
51505	51234	14235Q	PARTICIPANT	\N	PRESENT	0
51506	51234	01048V	PARTICIPANT	\N	PRESENT	0
51507	51234	95015C	PARTICIPANT	\N	PRESENT	0
51444	49958	08024S	PARTICIPANT	\N	PRESENT	0
51445	49958	08009T	PARTICIPANT	\N	PRESENT	0
51508	51234	95031C	PARTICIPANT	\N	PRESENT	0
51509	51234	11113E	PARTICIPANT	\N	PRESENT	0
51526	51234	14079W	PARTICIPANT	\N	PRESENT	0
51527	51234	90003B	PARTICIPANT	\N	PRESENT	0
51528	51234	08015R	PARTICIPANT	\N	PRESENT	0
51531	51530	14133K	PARTICIPANT	\N	PRESENT	0
51532	51530	04054G	PARTICIPANT	\N	PRESENT	0
51533	51530	96004D	PRESIDENT	0	PRESENT	0
51534	51530	11040E	PARTICIPANT	\N	PRESENT	0
51535	51530	14089Y	PARTICIPANT	\N	PRESENT	0
51536	51530	90003B	PARTICIPANT	\N	PRESENT	0
51537	51530	14079W	PARTICIPANT	\N	PRESENT	0
51538	51530	11083R	PARTICIPANT	\N	PRESENT	0
51539	51530	95037J	PARTICIPANT	\N	PRESENT	0
51540	51530	14097Y	PARTICIPANT	\N	PRESENT	0
51541	51530	04061F	PARTICIPANT	\N	PRESENT	0
51542	51530	14073Q	PARTICIPANT	\N	PRESENT	0
51543	51530	11026G	PARTICIPANT	\N	PRESENT	0
51544	51530	14001X	PARTICIPANT	\N	EXCUSE	0
51545	51530	04057K	PARTICIPANT	\N	PRESENT	0
51546	51530	14135M	PARTICIPANT	\N	PRESENT	0
51547	51530	01016M	PARTICIPANT	\N	PRESENT	0
51548	51530	10015M	PARTICIPANT	\N	PRESENT	0
51549	51530	04045F	PARTICIPANT	\N	PRESENT	0
51550	51530	98035U	PARTICIPANT	\N	PRESENT	0
51551	51530	04034C	PARTICIPANT	\N	PRESENT	0
51552	51234	11104D	PARTICIPANT	\N	PRESENT	0
51553	51530	11035H	PARTICIPANT	\N	EXCUSE	0
51554	51530	14026U	PARTICIPANT	\N	EXCUSE	0
51555	51234	14187A	PARTICIPANT	\N	PRESENT	0
51556	51234	98050T	PARTICIPANT	\N	PRESENT	0
51557	51234	14038Y	PARTICIPANT	\N	PRESENT	0
51560	51234	14071N	PARTICIPANT	\N	PRESENT	0
51562	51561	14253S	PARTICIPANT	\N	PRESENT	0
51612	51235	14087W	PARTICIPANT	\N	PRESENT	0
51613	51235	14331P	PARTICIPANT	\N	PRESENT	0
51614	51235	08065C	PARTICIPANT	\N	PRESENT	0
51615	51235	08068F	PARTICIPANT	\N	PRESENT	0
51616	51235	11066Q	PARTICIPANT	\N	PRESENT	0
51617	51235	99004R	PARTICIPANT	\N	PRESENT	0
51618	51235	14231L	PARTICIPANT	\N	PRESENT	0
51619	51235	07004J	PARTICIPANT	\N	PRESENT	0
51620	51235	04056J	PARTICIPANT	\N	PRESENT	0
51621	51235	04077P	PARTICIPANT	\N	PRESENT	0
51622	51235	87003B	PARTICIPANT	\N	PRESENT	0
51623	51235	14105F	PARTICIPANT	\N	PRESENT	0
51624	51235	90003B	PARTICIPANT	\N	PRESENT	0
51625	51235	11069T	PARTICIPANT	\N	PRESENT	0
51626	51235	11020A	PARTICIPANT	\N	PRESENT	0
51627	51235	14195A	PARTICIPANT	\N	PRESENT	0
51628	51235	14215L	PARTICIPANT	\N	PRESENT	0
51629	51235	14179A	PARTICIPANT	\N	PRESENT	0
51630	51235	97011G	PARTICIPANT	\N	PRESENT	0
51631	51235	04074L	PARTICIPANT	\N	PRESENT	0
51632	51235	11043H	PARTICIPANT	\N	PRESENT	0
51633	51235	14265W	PARTICIPANT	\N	PRESENT	0
51634	51235	14031R	PARTICIPANT	\N	PRESENT	0
51635	51235	14253S	PARTICIPANT	\N	PRESENT	0
51636	51235	04097T	PARTICIPANT	\N	PRESENT	0
51637	51235	95063L	PARTICIPANT	\N	PRESENT	0
51638	51235	11044J	PARTICIPANT	\N	PRESENT	0
51639	51235	08055A	PARTICIPANT	\N	PRESENT	0
51640	51235	04088S	PARTICIPANT	\N	PRESENT	0
51641	51235	98035U	PARTICIPANT	\N	PRESENT	0
51642	51235	11049P	PARTICIPANT	\N	PRESENT	0
51643	51235	04059M	PARTICIPANT	\N	PRESENT	0
51644	51235	95035G	PARTICIPANT	\N	PRESENT	0
51645	51235	14259Y	PARTICIPANT	\N	PRESENT	0
51646	51235	04045F	PARTICIPANT	\N	PRESENT	0
51647	51235	98005N	PARTICIPANT	\N	PRESENT	0
51687	51235	98050T	PARTICIPANT	\N	PRESENT	0
51649	51235	14033T	PARTICIPANT	\N	PRESENT	0
51650	51235	04053F	PARTICIPANT	\N	PRESENT	0
51651	51235	14187A	PARTICIPANT	\N	PRESENT	0
51652	51235	08015R	PARTICIPANT	\N	PRESENT	0
51653	51235	14193X	PARTICIPANT	\N	PRESENT	0
51610	51235	86034E	PARTICIPANT	\N	PRESENT	0
51611	51235	95031C	PARTICIPANT	\N	PRESENT	0
51654	51235	14237S	PARTICIPANT	\N	PRESENT	0
51655	51235	04049K	PARTICIPANT	\N	PRESENT	0
51656	51235	11088W	PARTICIPANT	\N	PRESENT	0
51658	51235	01058X	PARTICIPANT	\N	PRESENT	0
51659	51235	04047H	PARTICIPANT	\N	PRESENT	0
51660	51235	14111D	PARTICIPANT	\N	PRESENT	0
51661	51235	08016S	PARTICIPANT	\N	PRESENT	0
51662	51235	04042C	PARTICIPANT	\N	PRESENT	0
51663	51235	14041T	PARTICIPANT	\N	PRESENT	0
51664	51235	08061X	PARTICIPANT	\N	PRESENT	0
51665	51235	86044G	PARTICIPANT	\N	PRESENT	0
51666	51235	04086Q	PARTICIPANT	\N	PRESENT	0
51667	51235	11100Y	PARTICIPANT	\N	PRESENT	0
51668	51235	95062K	PARTICIPANT	\N	PRESENT	0
51669	51235	95059Q	PARTICIPANT	\N	PRESENT	0
51670	51235	10015M	PARTICIPANT	\N	PRESENT	0
51671	51235	04092N	PARTICIPANT	\N	PRESENT	0
51672	51235	95015C	PARTICIPANT	\N	PRESENT	0
51673	51235	08018U	PARTICIPANT	\N	PRESENT	0
51674	51235	08034U	PARTICIPANT	\N	PRESENT	0
51675	51235	01013J	PARTICIPANT	\N	PRESENT	0
51676	51235	04085P	PARTICIPANT	\N	PRESENT	0
51677	51235	08010L	PARTICIPANT	\N	PRESENT	0
51678	51235	07026Q	PARTICIPANT	\N	PRESENT	0
51679	51235	14069U	PARTICIPANT	\N	PRESENT	0
51680	51235	14263U	PARTICIPANT	\N	PRESENT	0
51681	51235	11063M	PARTICIPANT	\N	PRESENT	0
51682	51235	07034Q	PARTICIPANT	\N	PRESENT	0
51683	51235	92018S	PARTICIPANT	\N	PRESENT	0
51684	51235	11031D	PARTICIPANT	\N	PRESENT	0
51685	51235	04043D	PARTICIPANT	\N	PRESENT	0
51686	51235	04033B	PARTICIPANT	\N	PRESENT	0
51688	51235	14235Q	PARTICIPANT	\N	PRESENT	0
44099	44098	04086Q	PARTICIPANT	\N	PRESENT	0
44103	44098	11106F	PARTICIPANT	\N	PRESENT	0
44101	44098	04036E	PARTICIPANT	\N	PRESENT	0
44102	44098	14159V	PARTICIPANT	\N	PRESENT	0
44104	44098	04079R	PARTICIPANT	\N	PRESENT	0
44105	44098	10015M	PARTICIPANT	\N	PRESENT	0
44106	44098	95067Q	PARTICIPANT	\N	PRESENT	0
44107	44098	04040A	PARTICIPANT	\N	PRESENT	0
46503	46502	11029K	PARTICIPANT	\N	PRESENT	0
46504	46502	11031D	PARTICIPANT	\N	PRESENT	0
46505	46502	80013X	PARTICIPANT	\N	PRESENT	0
46506	46502	04036E	PARTICIPANT	\N	PRESENT	0
46507	46502	04035D	PARTICIPANT	\N	PRESENT	0
46508	46502	09001P	PARTICIPANT	\N	PRESENT	0
46510	46509	08043V	PARTICIPANT	\N	PRESENT	0
46511	46509	11027H	PARTICIPANT	\N	PRESENT	0
46512	46509	04035D	PARTICIPANT	\N	PRESENT	0
60458	60449	99004R	PARTICIPANT	\N	PRESENT	0
60529	60038	08051V	PARTICIPANT	\N	PRESENT	0
60530	60038	08022Q	PARTICIPANT	\N	PRESENT	0
60531	60038	11088W	PARTICIPANT	\N	PRESENT	0
60532	60038	11070L	PARTICIPANT	\N	PRESENT	0
60533	60038	11012A	PARTICIPANT	\N	PRESENT	0
60534	60038	11029K	PARTICIPANT	\N	PRESENT	0
60535	60038	14081Q	PARTICIPANT	\N	PRESENT	0
60536	60038	07026Q	PARTICIPANT	\N	PRESENT	0
60537	60038	80013X	PARTICIPANT	\N	PRESENT	0
60538	60038	04085P	PARTICIPANT	\N	PRESENT	0
60539	60038	01028R	PARTICIPANT	\N	PRESENT	0
60540	60038	11091R	PARTICIPANT	\N	PRESENT	0
60541	60038	14013P	PARTICIPANT	\N	PRESENT	0
60542	60038	95063L	PARTICIPANT	\N	PRESENT	0
60543	60038	11107G	PARTICIPANT	\N	PRESENT	0
60544	60038	14089Y	PARTICIPANT	\N	PRESENT	0
60557	60038	04034C	PARTICIPANT	\N	PRESENT	0
60558	60038	11068S	PARTICIPANT	\N	PRESENT	0
60559	60038	98018T	PARTICIPANT	\N	PRESENT	0
60560	60038	11098Y	PARTICIPANT	\N	PRESENT	0
60564	60038	99004R	PARTICIPANT	\N	PRESENT	0
60562	60038	01048V	PARTICIPANT	\N	PRESENT	0
60563	60038	04080J	PARTICIPANT	\N	PRESENT	0
60566	60565	89017R	PARTICIPANT	\N	PRESENT	0
60527	60038	04066L	PARTICIPANT	\N	PRESENT	0
60528	60038	07034Q	PARTICIPANT	\N	PRESENT	0
60567	60565	14237S	PARTICIPANT	\N	PRESENT	0
60568	60565	11084S	PARTICIPANT	\N	PRESENT	0
60569	60565	01019Q	PARTICIPANT	\N	PRESENT	0
60570	60038	08019V	PARTICIPANT	\N	PRESENT	0
60571	60038	04078Q	PARTICIPANT	\N	PRESENT	0
60595	60594	11076S	PARTICIPANT	\N	PRESENT	0
60596	60594	01008M	PARTICIPANT	\N	PRESENT	0
60597	60594	14069U	PARTICIPANT	\N	PRESENT	0
60598	60594	14175V	PARTICIPANT	\N	PRESENT	0
60599	60594	04038G	PARTICIPANT	\N	PRESENT	0
60600	60594	14249W	PARTICIPANT	\N	PRESENT	0
60601	60594	04035D	PARTICIPANT	\N	PRESENT	0
60602	60594	11061K	PARTICIPANT	\N	PRESENT	0
60603	60594	14179A	PARTICIPANT	\N	PRESENT	0
60604	60594	04041B	PARTICIPANT	\N	PRESENT	0
60605	60594	14205J	PARTICIPANT	\N	PRESENT	0
60606	60594	14059S	PARTICIPANT	\N	PRESENT	0
60607	60594	14063N	PARTICIPANT	\N	PRESENT	0
60608	60594	08042U	PARTICIPANT	\N	PRESENT	0
60609	60594	14169X	PARTICIPANT	\N	PRESENT	0
60610	60594	11012A	PARTICIPANT	\N	PRESENT	0
60611	60594	04045F	PARTICIPANT	\N	PRESENT	0
60612	60594	14051J	PARTICIPANT	\N	PRESENT	0
60613	60594	14157T	PARTICIPANT	\N	PRESENT	0
60614	60594	01047U	PARTICIPANT	\N	PRESENT	0
60616	60615	11030C	PARTICIPANT	\N	PRESENT	0
60625	60624	01046T	PARTICIPANT	\N	PRESENT	0
60627	60624	08052W	PARTICIPANT	\N	PRESENT	0
60629	60628	01046T	PARTICIPANT	\N	PRESENT	0
60630	60628	08052W	PARTICIPANT	\N	PRESENT	0
60639	60638	07004J	PARTICIPANT	\N	PRESENT	0
60640	60638	01027Q	PARTICIPANT	\N	PRESENT	0
60641	60638	10015M	PARTICIPANT	\N	PRESENT	0
60643	60642	92020L	PARTICIPANT	\N	PRESENT	0
60648	60647	14251Q	PARTICIPANT	\N	PRESENT	0
60649	60647	95037J	PARTICIPANT	\N	PRESENT	0
60650	60647	95041E	PARTICIPANT	\N	PRESENT	0
60651	60647	11076S	PARTICIPANT	\N	PRESENT	0
60653	60652	11015D	PARTICIPANT	\N	PRESENT	0
60654	60652	92031P	PARTICIPANT	\N	PRESENT	0
60656	60655	11015D	PARTICIPANT	\N	PRESENT	0
60657	60655	04040A	PARTICIPANT	\N	PRESENT	0
60659	60658	11015D	PARTICIPANT	\N	PRESENT	0
60660	60658	92031P	PARTICIPANT	\N	PRESENT	0
60662	60661	01014K	PARTICIPANT	\N	PRESENT	0
60663	60661	07024N	PARTICIPANT	\N	PRESENT	0
60664	60661	11106F	PARTICIPANT	\N	PRESENT	0
60667	56934	01027Q	PARTICIPANT	\N	PRESENT	0
60668	56934	11074Q	PARTICIPANT	\N	PRESENT	0
60669	56934	04040A	PARTICIPANT	\N	PRESENT	0
60670	56934	14051J	PARTICIPANT	\N	PRESENT	0
60671	56934	92040Q	PARTICIPANT	\N	PRESENT	0
60672	56934	14063N	PARTICIPANT	\N	PRESENT	0
60673	56934	14071N	PARTICIPANT	\N	PRESENT	0
60674	56934	04045F	PARTICIPANT	\N	PRESENT	0
60675	56934	11099A	PARTICIPANT	\N	PRESENT	0
60676	56934	14013P	PARTICIPANT	\N	PRESENT	0
60678	60677	05012A	PARTICIPANT	\N	PRESENT	0
60679	60677	11101A	PARTICIPANT	\N	PRESENT	0
60680	60677	08038Y	PARTICIPANT	\N	PRESENT	0
61103	61102	14133K	PARTICIPANT	\N	PRESENT	0
61104	61102	11088W	PARTICIPANT	\N	PRESENT	0
61105	61102	11112D	PARTICIPANT	\N	PRESENT	0
61106	61102	14205J	PARTICIPANT	\N	PRESENT	0
61107	61102	08042U	PARTICIPANT	\N	PRESENT	0
61108	61102	11054L	PARTICIPANT	\N	PRESENT	0
61109	61102	92045V	PARTICIPANT	\N	PRESENT	0
61125	61122	11109J	PARTICIPANT	\N	EXCUSE	0
61126	61122	04059M	PARTICIPANT	\N	PRESENT	0
61128	61122	01044R	PARTICIPANT	\N	PRESENT	0
61129	61122	08043V	PARTICIPANT	\N	PRESENT	0
61131	61122	14105F	PARTICIPANT	\N	PRESENT	0
61132	61122	11029K	PARTICIPANT	\N	PRESENT	0
61134	61122	92015P	PARTICIPANT	\N	EXCUSE	0
61135	61122	08024S	PARTICIPANT	\N	EXCUSE	0
61138	61122	14209N	PARTICIPANT	\N	PRESENT	0
61140	61122	11091R	PARTICIPANT	\N	PRESENT	0
61143	61122	14249W	PARTICIPANT	\N	PRESENT	0
61144	61122	01041N	PARTICIPANT	\N	PRESENT	0
61145	61122	01025N	PARTICIPANT	\N	PRESENT	0
61149	61122	11089X	PARTICIPANT	\N	PRESENT	0
61150	61122	07026Q	PARTICIPANT	\N	PRESENT	0
61154	61122	14241N	PARTICIPANT	\N	PRESENT	0
61155	61122	14061L	PARTICIPANT	\N	PRESENT	0
61157	61122	08031R	PARTICIPANT	\N	PRESENT	0
61158	61122	12041X	PARTICIPANT	\N	PRESENT	0
61159	61122	08039A	PARTICIPANT	\N	PRESENT	0
61161	61122	14059S	PARTICIPANT	\N	PRESENT	0
61162	61122	08012N	PARTICIPANT	\N	PRESENT	0
61163	61122	14103D	PARTICIPANT	\N	PRESENT	0
61166	61122	04057K	PARTICIPANT	\N	PRESENT	0
61167	61122	11014C	PARTICIPANT	\N	PRESENT	0
61168	61122	14109K	PARTICIPANT	\N	PRESENT	0
61169	61122	04070G	PRESIDENT	0	PRESENT	0
61176	61122	14229S	PARTICIPANT	\N	PRESENT	0
50134	49558	14169X	PARTICIPANT	\N	PRESENT	0
50135	49558	87003B	PARTICIPANT	\N	PRESENT	0
50136	49558	11043H	PARTICIPANT	\N	PRESENT	0
50137	49558	14031R	PARTICIPANT	\N	PRESENT	0
50138	49558	14038Y	PARTICIPANT	\N	PRESENT	0
50139	49558	98050T	PARTICIPANT	\N	PRESENT	0
50140	49558	08041T	PARTICIPANT	\N	PRESENT	0
50141	49558	08042U	PARTICIPANT	\N	PRESENT	0
50142	49558	14061L	PARTICIPANT	\N	PRESENT	0
50143	49558	14059S	PARTICIPANT	\N	PRESENT	0
50144	49558	14249W	PARTICIPANT	\N	PRESENT	0
50145	49558	14026U	PARTICIPANT	\N	PRESENT	0
50146	49558	11103C	PARTICIPANT	\N	PRESENT	0
50147	49558	04081K	PARTICIPANT	\N	PRESENT	0
50148	49558	14223L	PARTICIPANT	\N	PRESENT	0
50149	49558	90003B	PARTICIPANT	\N	PRESENT	0
50150	49558	14273W	PARTICIPANT	\N	PRESENT	0
50151	49558	14221J	PARTICIPANT	\N	PRESENT	0
50152	49558	14205J	PARTICIPANT	\N	PRESENT	0
50153	49558	14030Q	PARTICIPANT	\N	PRESENT	0
50154	49558	14034U	PARTICIPANT	\N	PRESENT	0
50155	49558	14267Y	PARTICIPANT	\N	PRESENT	0
50156	49558	11094U	PARTICIPANT	\N	PRESENT	0
50157	49558	01046T	PARTICIPANT	\N	PRESENT	0
50158	49558	14159V	PARTICIPANT	\N	PRESENT	0
50159	49558	14014Q	PARTICIPANT	\N	PRESENT	0
50160	49558	01044R	PARTICIPANT	\N	PRESENT	0
50161	49558	92015P	PARTICIPANT	\N	PRESENT	0
50162	49558	08012N	PARTICIPANT	\N	PRESENT	0
50163	49558	14257W	PARTICIPANT	\N	PRESENT	0
50164	49558	08014Q	PARTICIPANT	\N	PRESENT	0
50165	49558	14097Y	PARTICIPANT	\N	PRESENT	0
50166	49558	11036J	PARTICIPANT	\N	PRESENT	0
50167	49558	14197C	PARTICIPANT	\N	PRESENT	0
50168	49558	14263U	PARTICIPANT	\N	PRESENT	0
50169	49558	14013P	PARTICIPANT	\N	PRESENT	0
50170	49558	11098Y	PARTICIPANT	\N	PRESENT	0
50171	49558	14042U	PARTICIPANT	\N	PRESENT	0
50172	49558	08010L	PARTICIPANT	\N	PRESENT	0
50173	49558	14253S	PARTICIPANT	\N	PRESENT	0
50174	49558	01061S	PARTICIPANT	\N	PRESENT	0
50175	49558	14121F	PARTICIPANT	\N	PRESENT	0
50176	49558	11099A	PARTICIPANT	\N	PRESENT	0
50177	49558	14028W	PARTICIPANT	\N	PRESENT	0
50178	49558	04089T	PARTICIPANT	\N	PRESENT	0
50179	49558	95030B	PARTICIPANT	\N	PRESENT	0
50180	49558	04088S	PARTICIPANT	\N	PRESENT	0
50181	49558	14327T	PARTICIPANT	\N	PRESENT	0
50133	49558	98053W	PARTICIPANT	\N	PRESENT	0
50182	49558	14219Q	PARTICIPANT	\N	PRESENT	0
50183	49558	14083S	PARTICIPANT	\N	PRESENT	0
50184	49558	07034Q	PARTICIPANT	\N	PRESENT	0
50185	49558	11105E	PARTICIPANT	\N	PRESENT	0
50186	49558	14033T	PARTICIPANT	\N	PRESENT	0
50187	49558	11067R	PARTICIPANT	\N	PRESENT	0
50188	49558	01008M	PARTICIPANT	\N	PRESENT	0
50189	49558	08069G	PARTICIPANT	\N	PRESENT	0
50190	49558	14109K	PARTICIPANT	\N	PRESENT	0
50191	49558	11035H	PARTICIPANT	\N	PRESENT	0
50192	49558	08055A	PARTICIPANT	\N	PRESENT	0
50193	49558	11066Q	PARTICIPANT	\N	PRESENT	0
50194	49558	11012A	PARTICIPANT	\N	PRESENT	0
50195	49558	00003C	PARTICIPANT	\N	PRESENT	0
50196	49558	11083R	PARTICIPANT	\N	PRESENT	0
50197	49558	14195A	PARTICIPANT	\N	PRESENT	0
50198	49558	14103D	PARTICIPANT	\N	PRESENT	0
50199	49558	05012A	PARTICIPANT	\N	PRESENT	0
50200	49558	04040A	PARTICIPANT	\N	PRESENT	0
50201	49558	14073Q	PARTICIPANT	\N	PRESENT	0
50202	49558	04045F	PARTICIPANT	\N	PRESENT	0
50203	49558	86044G	PARTICIPANT	\N	PRESENT	0
50204	49558	01003G	PARTICIPANT	\N	PRESENT	0
50205	49558	11037K	PARTICIPANT	\N	PRESENT	0
50206	49558	97011G	PARTICIPANT	\N	PRESENT	0
50207	49558	14179A	PARTICIPANT	\N	PRESENT	0
50208	49558	95067Q	PARTICIPANT	\N	PRESENT	0
50209	49558	14053L	PARTICIPANT	\N	PRESENT	0
50210	49558	14041T	PARTICIPANT	\N	PRESENT	0
50211	49558	14187A	PARTICIPANT	\N	PRESENT	0
50212	49558	04044E	PARTICIPANT	\N	PRESENT	0
50214	49558	14239U	PARTICIPANT	\N	PRESENT	0
50295	49559	11037K	PARTICIPANT	\N	PRESENT	0
50299	49559	14103D	PARTICIPANT	\N	PRESENT	0
50297	49559	04095R	PARTICIPANT	\N	PRESENT	0
50298	49559	14239U	PARTICIPANT	\N	PRESENT	0
50300	49559	01016M	PARTICIPANT	\N	PRESENT	0
50301	49559	14159V	PARTICIPANT	\N	PRESENT	0
50302	49559	14327T	PARTICIPANT	\N	PRESENT	0
50303	49559	14215L	PARTICIPANT	\N	PRESENT	0
50304	49559	14061L	PARTICIPANT	\N	PRESENT	0
50305	49559	14059S	PARTICIPANT	\N	PRESENT	0
50306	49559	14187A	PARTICIPANT	\N	PRESENT	0
50307	49559	14053L	PARTICIPANT	\N	PRESENT	0
50308	49559	05012A	PARTICIPANT	\N	PRESENT	0
50309	49559	98023Q	PARTICIPANT	\N	PRESENT	0
50310	49559	08034U	PARTICIPANT	\N	PRESENT	0
50311	49559	07029T	PARTICIPANT	\N	PRESENT	0
50312	49559	14195A	PARTICIPANT	\N	PRESENT	0
50313	49559	14157T	PARTICIPANT	\N	PRESENT	0
50314	49559	01061S	PARTICIPANT	\N	PRESENT	0
50315	49559	01057W	PARTICIPANT	\N	PRESENT	0
50316	49559	04088S	PARTICIPANT	\N	PRESENT	0
50317	49559	14273W	PARTICIPANT	\N	PRESENT	0
50318	49559	04044E	PARTICIPANT	\N	PRESENT	0
50319	49559	95067Q	PARTICIPANT	\N	PRESENT	0
50320	49559	11056N	PARTICIPANT	\N	PRESENT	0
50321	49559	97011G	PARTICIPANT	\N	PRESENT	0
50322	49559	11099A	PARTICIPANT	\N	PRESENT	0
50323	49559	14028W	PARTICIPANT	\N	PRESENT	0
50324	49559	14014Q	PARTICIPANT	\N	PRESENT	0
50325	49559	01028R	PARTICIPANT	\N	PRESENT	0
50326	49559	04040A	PARTICIPANT	\N	PRESENT	0
50327	49559	11065P	PARTICIPANT	\N	PRESENT	0
50328	49559	11096W	PARTICIPANT	\N	PRESENT	0
50329	49559	14241N	PARTICIPANT	\N	PRESENT	0
50330	49559	14147R	PARTICIPANT	\N	PRESENT	0
50331	49559	14265W	PARTICIPANT	\N	PRESENT	0
50332	49559	14038Y	PARTICIPANT	\N	PRESENT	0
50333	49559	11112D	PARTICIPANT	\N	PRESENT	0
50334	49559	95049N	PARTICIPANT	\N	PRESENT	0
50335	49559	08010L	PARTICIPANT	\N	PRESENT	0
50336	49559	14087W	PARTICIPANT	\N	PRESENT	0
50337	49559	13002U	PARTICIPANT	\N	PRESENT	0
50338	49559	14033T	PARTICIPANT	\N	PRESENT	0
50339	49559	92045V	PARTICIPANT	\N	PRESENT	0
50340	49559	01027Q	PARTICIPANT	\N	PRESENT	0
50341	49559	14133K	PARTICIPANT	\N	PRESENT	0
50342	49559	14199E	PARTICIPANT	\N	PRESENT	0
50343	49559	11097X	PARTICIPANT	\N	PRESENT	0
50344	49559	05008E	PARTICIPANT	\N	PRESENT	0
50345	49559	95062K	PARTICIPANT	\N	PRESENT	0
50346	49559	14071N	PARTICIPANT	\N	PRESENT	0
50347	49559	14217N	PARTICIPANT	\N	PRESENT	0
50348	49559	11098Y	PARTICIPANT	\N	PRESENT	0
50349	49559	14235Q	PARTICIPANT	\N	PRESENT	0
50350	49559	92018S	PARTICIPANT	\N	PRESENT	0
50351	49559	95041E	PARTICIPANT	\N	PRESENT	0
50352	49559	01008M	PARTICIPANT	\N	PRESENT	0
50353	49559	14205J	PARTICIPANT	\N	PRESENT	0
50354	49559	14079W	PARTICIPANT	\N	PRESENT	0
50355	49559	14001X	PARTICIPANT	\N	PRESENT	0
50356	49559	11012A	PARTICIPANT	\N	PRESENT	0
50357	49559	14069U	PARTICIPANT	\N	PRESENT	0
50734	50701	04088S	PARTICIPANT	\N	PRESENT	0
50735	50701	98050T	PARTICIPANT	\N	PRESENT	0
50736	50701	11090Q	PARTICIPANT	\N	PRESENT	0
50737	50701	11046L	PARTICIPANT	\N	PRESENT	0
50738	50701	01058X	PARTICIPANT	\N	EXCUSE	0
50739	50701	11094U	PARTICIPANT	\N	PRESENT	0
50740	50701	11066Q	PARTICIPANT	\N	PRESENT	0
50849	50847	08055A	PARTICIPANT	\N	PRESENT	0
50850	50847	14093U	PARTICIPANT	\N	PRESENT	0
50851	50847	14030Q	PARTICIPANT	\N	PRESENT	0
50853	50847	08060W	PARTICIPANT	\N	PRESENT	0
50855	50847	14038Y	PARTICIPANT	\N	PRESENT	0
50856	50847	11114F	PARTICIPANT	\N	PRESENT	0
50293	49559	98053W	PARTICIPANT	\N	PRESENT	0
50857	50847	98023Q	PARTICIPANT	\N	PRESENT	0
50859	50847	01015L	PARTICIPANT	\N	PRESENT	0
50860	50847	11107G	PARTICIPANT	\N	PRESENT	0
50862	50847	02002K	PARTICIPANT	\N	PRESENT	0
50863	50847	01022K	PARTICIPANT	\N	PRESENT	0
33369	33368	89017R	PARTICIPANT	\N	PRESENT	0
33370	33368	01031L	PRESIDENT	0	PRESENT	0
33371	33368	01013J	PARTICIPANT	\N	PRESENT	0
33372	33368	11040E	PARTICIPANT	\N	PRESENT	0
33373	33368	08014Q	PARTICIPANT	\N	PRESENT	0
33374	33368	14167V	PARTICIPANT	\N	PRESENT	0
33375	33368	14175V	PARTICIPANT	\N	PRESENT	0
33376	33368	14083S	PARTICIPANT	\N	PRESENT	0
33377	33368	11042G	PARTICIPANT	\N	PRESENT	0
33378	33368	88008L	PARTICIPANT	\N	PRESENT	0
33379	33368	04086Q	PARTICIPANT	\N	PRESENT	0
33380	33368	11088W	PARTICIPANT	\N	PRESENT	0
33381	33368	08022Q	PARTICIPANT	\N	PRESENT	0
33382	33368	01027Q	PARTICIPANT	\N	PRESENT	0
33383	33368	04071H	PARTICIPANT	\N	PRESENT	0
33384	33368	11074Q	PARTICIPANT	\N	PRESENT	0
33385	33368	11083R	PARTICIPANT	\N	PRESENT	0
33386	33368	14199E	PARTICIPANT	\N	PRESENT	0
33387	33368	08069G	PARTICIPANT	\N	PRESENT	0
33388	33368	11048N	PARTICIPANT	\N	PRESENT	0
33389	33368	99004R	PARTICIPANT	\N	PRESENT	0
33390	33368	14159V	PARTICIPANT	\N	PRESENT	0
33391	33368	07029T	PARTICIPANT	\N	PRESENT	0
33392	33368	14277B	PARTICIPANT	\N	PRESENT	0
33393	33368	08010L	PARTICIPANT	\N	PRESENT	0
33394	33368	08034U	PARTICIPANT	\N	PRESENT	0
33395	33368	11085T	PARTICIPANT	\N	EXCUSE	0
33396	33368	08011M	PARTICIPANT	\N	PRESENT	0
33397	33368	08073C	PARTICIPANT	\N	PRESENT	0
33398	33368	08061X	PARTICIPANT	\N	PRESENT	0
33399	33368	01016M	PARTICIPANT	\N	PRESENT	0
33400	33368	14225N	PARTICIPANT	\N	PRESENT	0
33401	33368	11057P	PARTICIPANT	\N	PRESENT	0
33402	33368	14173T	PARTICIPANT	\N	PRESENT	0
33403	33368	14213J	RAPPORTEUR_AVIS	\N	PRESENT	0
33410	33409	14215L	PARTICIPANT	\N	PRESENT	0
33405	33368	01057W	PARTICIPANT	\N	PRESENT	0
33408	33407	14215L	PARTICIPANT	\N	PRESENT	0
33467	33466	10015M	PARTICIPANT	\N	PRESENT	0
33469	33468	11072N	PARTICIPANT	\N	PRESENT	0
33471	33470	11072N	PARTICIPANT	\N	PRESENT	0
33473	33472	11072N	PARTICIPANT	\N	PRESENT	0
33475	33474	11072N	PARTICIPANT	\N	PRESENT	0
33490	33488	11072N	PARTICIPANT	\N	PRESENT	0
45602	45601	80013X	PARTICIPANT	\N	PRESENT	0
36455	36454	14263U	PARTICIPANT	\N	PRESENT	0
33463	33413	10015M	PARTICIPANT	\N	PRESENT	0
33465	33464	10015M	PARTICIPANT	\N	PRESENT	0
36456	36454	14133K	PARTICIPANT	\N	PRESENT	0
36457	36454	11109J	PARTICIPANT	\N	PRESENT	0
36458	36454	04059M	PARTICIPANT	\N	PRESENT	0
36459	36454	11039M	PARTICIPANT	\N	PRESENT	0
36460	36454	01044R	PARTICIPANT	\N	PRESENT	0
36461	36454	08043V	PARTICIPANT	\N	PRESENT	0
36462	36454	14089Y	PARTICIPANT	\N	PRESENT	0
36463	36454	14105F	PARTICIPANT	\N	PRESENT	0
36464	36454	11029K	PARTICIPANT	\N	PRESENT	0
36465	36454	95015C	PARTICIPANT	\N	PRESENT	0
36466	36454	92015P	PARTICIPANT	\N	PRESENT	0
36467	36454	08024S	PARTICIPANT	\N	PRESENT	0
36468	36454	14201E	PARTICIPANT	\N	PRESENT	0
36469	36454	14329V	PARTICIPANT	\N	PRESENT	0
36470	36454	14209N	PARTICIPANT	\N	PRESENT	0
45603	45601	09001P	PARTICIPANT	\N	PRESENT	0
36472	36454	11091R	PARTICIPANT	\N	PRESENT	0
36473	36454	87003B	PARTICIPANT	\N	PRESENT	0
36474	36454	98042T	PARTICIPANT	\N	PRESENT	0
36475	36454	14249W	PARTICIPANT	\N	PRESENT	0
36476	36454	01041N	PARTICIPANT	\N	PRESENT	0
36477	36454	01025N	PARTICIPANT	\N	PRESENT	0
45604	45601	11031D	PARTICIPANT	\N	PRESENT	0
36479	36454	89029V	PARTICIPANT	\N	PRESENT	0
36480	36454	08035V	PARTICIPANT	\N	PRESENT	0
36481	36454	11089X	PARTICIPANT	\N	PRESENT	0
36482	36454	07026Q	PARTICIPANT	\N	PRESENT	0
36483	36454	14123H	PARTICIPANT	\N	PRESENT	0
36484	36454	14179A	PARTICIPANT	\N	PRESENT	0
36485	36454	04041B	PARTICIPANT	\N	PRESENT	0
36486	36454	14241N	PARTICIPANT	\N	PRESENT	0
36487	36454	14061L	PARTICIPANT	\N	PRESENT	0
36488	36454	14073Q	PARTICIPANT	\N	PRESENT	0
36489	36454	08031R	PARTICIPANT	\N	PRESENT	0
45605	45601	11029K	PARTICIPANT	\N	PRESENT	0
36491	36454	08039A	PARTICIPANT	\N	PRESENT	0
36492	36454	08017T	PARTICIPANT	\N	PRESENT	0
36493	36454	14059S	PARTICIPANT	\N	PRESENT	0
36494	36454	08012N	PARTICIPANT	\N	PRESENT	0
36495	36454	14103D	PARTICIPANT	\N	PRESENT	0
36496	36454	11104D	PARTICIPANT	\N	PRESENT	0
36497	36454	14063N	PARTICIPANT	\N	PRESENT	0
36498	36454	04057K	PARTICIPANT	\N	PRESENT	0
45606	45601	14109K	PARTICIPANT	\N	PRESENT	0
36500	36454	14109K	PARTICIPANT	\N	PRESENT	0
36501	36454	04070G	PRESIDENT	0	PRESENT	0
36502	36454	92040Q	PARTICIPANT	\N	PRESENT	0
45608	45607	80013X	PARTICIPANT	\N	PRESENT	0
36504	36454	83047W	PARTICIPANT	\N	PRESENT	0
36505	36454	14235Q	PARTICIPANT	\N	PRESENT	0
36506	36454	14055N	PARTICIPANT	\N	PRESENT	0
45609	45607	08031R	PARTICIPANT	\N	PRESENT	0
36508	36454	14229S	PARTICIPANT	\N	PRESENT	0
36509	36454	11043H	PARTICIPANT	\N	PRESENT	0
36510	36454	11071M	PARTICIPANT	\N	PRESENT	0
45611	45610	08043V	PARTICIPANT	\N	PRESENT	0
45612	45610	11031D	PARTICIPANT	\N	PRESENT	0
45613	45610	11027H	PARTICIPANT	\N	PRESENT	0
45614	45610	14217N	PARTICIPANT	\N	PRESENT	0
45615	45610	11061K	PARTICIPANT	\N	PRESENT	0
45616	45610	08031R	PARTICIPANT	\N	PRESENT	0
45617	45610	11067R	PARTICIPANT	\N	PRESENT	0
45618	45610	80013X	PARTICIPANT	\N	PRESENT	0
45620	45619	08043V	PARTICIPANT	\N	PRESENT	0
45621	45619	11031D	PARTICIPANT	\N	PRESENT	0
45622	45619	11027H	PARTICIPANT	\N	PRESENT	0
45623	45619	14217N	PARTICIPANT	\N	PRESENT	0
45624	45619	80013X	PARTICIPANT	\N	PRESENT	0
45625	45619	11061K	PARTICIPANT	\N	PRESENT	0
45626	45619	08031R	PARTICIPANT	\N	PRESENT	0
45627	45619	11067R	PARTICIPANT	\N	PRESENT	0
51689	51235	14037X	PARTICIPANT	\N	PRESENT	0
51690	51235	14169X	PARTICIPANT	\N	PRESENT	0
51691	51235	05008E	PARTICIPANT	\N	PRESENT	0
51693	51235	77002U	PARTICIPANT	\N	PRESENT	0
51694	51235	14135M	PARTICIPANT	\N	PRESENT	0
51695	51692	08051V	PARTICIPANT	\N	PRESENT	0
51696	51235	11101A	PARTICIPANT	\N	PRESENT	0
51697	51235	14013P	PARTICIPANT	\N	PRESENT	0
51698	51235	08039A	PARTICIPANT	\N	PRESENT	0
51699	51235	11039M	PARTICIPANT	\N	PRESENT	0
51700	51235	98021N	PARTICIPANT	\N	PRESENT	0
51701	51235	14209N	PARTICIPANT	\N	PRESENT	0
51702	51235	04057K	PARTICIPANT	\N	PRESENT	0
51703	51235	01016M	PARTICIPANT	\N	PRESENT	0
51704	51235	92015P	PARTICIPANT	\N	PRESENT	0
51705	51235	08052W	PARTICIPANT	\N	PRESENT	0
51706	51235	08062Y	PARTICIPANT	\N	PRESENT	0
51707	51235	14273W	PARTICIPANT	\N	PRESENT	0
51708	51235	05012A	PARTICIPANT	\N	PRESENT	0
51709	51235	98046X	PARTICIPANT	\N	PRESENT	0
51710	51235	08019V	PARTICIPANT	\N	PRESENT	0
51711	51235	14059S	PARTICIPANT	\N	PRESENT	0
51712	51235	14151M	PARTICIPANT	\N	PRESENT	0
51713	51235	14061L	PARTICIPANT	\N	PRESENT	0
51714	51235	14051J	PARTICIPANT	\N	PRESENT	0
51715	51235	07029T	PARTICIPANT	\N	PRESENT	0
51716	51235	04054G	PARTICIPANT	\N	PRESENT	0
51717	51235	11040E	PARTICIPANT	\N	PRESENT	0
51718	51235	01015L	PARTICIPANT	\N	PRESENT	0
51719	51235	98053W	PARTICIPANT	\N	PRESENT	0
51720	51235	11030C	PARTICIPANT	\N	PRESENT	0
51721	51235	11074Q	PARTICIPANT	\N	PRESENT	0
51722	51235	11071M	PARTICIPANT	\N	PRESENT	0
51723	51235	04034C	PARTICIPANT	\N	PRESENT	0
51724	51235	04081K	PARTICIPANT	\N	PRESENT	0
51725	51235	11084S	PARTICIPANT	\N	PRESENT	0
51726	51235	11103C	PARTICIPANT	\N	PRESENT	0
51727	51235	01011G	PARTICIPANT	\N	PRESENT	0
51728	51235	01056V	PARTICIPANT	\N	PRESENT	0
51729	51235	92020L	PARTICIPANT	\N	PRESENT	0
51730	51235	08011M	PARTICIPANT	\N	PRESENT	0
51731	51235	11036J	PARTICIPANT	\N	PRESENT	0
51732	51235	80013X	PARTICIPANT	\N	PRESENT	0
51733	51235	11059R	PARTICIPANT	\N	PRESENT	0
51734	51235	01057W	PARTICIPANT	\N	PRESENT	0
51735	51235	11056N	PARTICIPANT	\N	PRESENT	0
51736	51235	04048J	PARTICIPANT	\N	PRESENT	0
51737	51235	11048N	PARTICIPANT	\N	PRESENT	0
51738	51235	14038Y	PARTICIPANT	\N	PRESENT	0
51739	51235	11080N	PARTICIPANT	\N	PRESENT	0
51740	51235	14267Y	PARTICIPANT	\N	PRESENT	0
51741	51235	01044R	PARTICIPANT	\N	PRESENT	0
51742	51235	11029K	PARTICIPANT	\N	PRESENT	0
51743	51235	11033F	PARTICIPANT	\N	PRESENT	0
51744	51235	04067M	PARTICIPANT	\N	PRESENT	0
51745	51235	11055M	PARTICIPANT	\N	PRESENT	0
51746	51235	11083R	PARTICIPANT	\N	PRESENT	0
51752	51235	14018U	PARTICIPANT	\N	PRESENT	0
51748	51235	08021P	PARTICIPANT	\N	PRESENT	0
51749	51235	01060R	PARTICIPANT	\N	PRESENT	0
51750	51235	92044U	PARTICIPANT	\N	PRESENT	0
51751	51235	92031P	PARTICIPANT	\N	PRESENT	0
51753	51235	14205J	PARTICIPANT	\N	PRESENT	0
51754	51235	04036E	PARTICIPANT	\N	PRESENT	0
51755	51235	88008L	PARTICIPANT	\N	PRESENT	0
51756	51235	11096W	PARTICIPANT	\N	PRESENT	0
51757	51235	04061F	PARTICIPANT	\N	PRESENT	0
51758	51235	08051V	PARTICIPANT	\N	PRESENT	0
51759	51235	01046T	PARTICIPANT	\N	PRESENT	0
51760	51235	08031R	PARTICIPANT	\N	PRESENT	0
51761	51235	14201E	PARTICIPANT	\N	PRESENT	0
51762	51235	11099A	PARTICIPANT	\N	PRESENT	0
51763	51235	01003G	PARTICIPANT	\N	PRESENT	0
51764	51235	14079W	PARTICIPANT	\N	PRESENT	0
51765	51235	98022P	PARTICIPANT	\N	PRESENT	0
51766	51235	14119M	PARTICIPANT	\N	PRESENT	0
51767	51235	14071N	PARTICIPANT	\N	PRESENT	0
51768	51235	00003C	PARTICIPANT	\N	PRESENT	0
51769	51235	11053K	PARTICIPANT	\N	PRESENT	0
51770	51235	04089T	PARTICIPANT	\N	PRESENT	0
51771	51235	14073Q	PARTICIPANT	\N	PRESENT	0
51772	51235	09001P	PARTICIPANT	\N	PRESENT	0
51773	51235	11027H	PARTICIPANT	\N	PRESENT	0
51774	51235	14103D	PARTICIPANT	\N	PRESENT	0
51775	51235	14197C	PARTICIPANT	\N	PRESENT	0
51776	51235	11015D	PARTICIPANT	\N	PRESENT	0
51777	51235	08043V	PARTICIPANT	\N	PRESENT	0
51778	51235	11105E	PARTICIPANT	\N	PRESENT	0
51779	51235	11032E	PARTICIPANT	\N	PRESENT	0
51780	51235	14093U	PARTICIPANT	\N	PRESENT	0
51781	51235	04035D	PARTICIPANT	\N	PRESENT	0
51782	51235	83047W	PARTICIPANT	\N	PRESENT	0
51783	51235	08056B	PARTICIPANT	\N	PRESENT	0
51784	51235	08058D	PARTICIPANT	\N	PRESENT	0
51785	51235	01007L	PARTICIPANT	\N	PRESENT	0
51786	51235	95037J	PARTICIPANT	\N	PRESENT	0
51787	51235	08017T	PARTICIPANT	\N	PRESENT	0
51788	51235	83042R	PARTICIPANT	\N	PRESENT	0
51789	51235	14030Q	PARTICIPANT	\N	PRESENT	0
51790	51235	11046L	PARTICIPANT	\N	PRESENT	0
51791	51235	98029W	PARTICIPANT	\N	PRESENT	0
51792	51235	01047U	PARTICIPANT	\N	PRESENT	0
51793	51235	14014Q	PARTICIPANT	\N	PRESENT	0
51794	51235	04080J	PARTICIPANT	\N	PRESENT	0
51795	51235	14109K	PARTICIPANT	\N	PRESENT	0
51796	51235	11070L	PARTICIPANT	\N	PRESENT	0
51797	51235	14207L	PARTICIPANT	\N	PRESENT	0
51798	51235	14001X	PARTICIPANT	\N	PRESENT	0
51799	51235	11085T	PARTICIPANT	\N	PRESENT	0
51800	51235	14227Q	PARTICIPANT	\N	PRESENT	0
51801	51235	08009T	PARTICIPANT	\N	PRESENT	0
51802	51235	14097Y	PARTICIPANT	\N	PRESENT	0
51803	51235	98042T	PARTICIPANT	\N	PRESENT	0
51804	51235	14229S	PARTICIPANT	\N	PRESENT	0
51805	51235	11065P	PARTICIPANT	\N	PRESENT	0
51806	51235	14042U	PARTICIPANT	\N	PRESENT	0
51807	51235	14225N	PARTICIPANT	\N	PRESENT	0
51808	51235	01031L	PARTICIPANT	\N	PRESENT	0
51809	51235	14121F	PARTICIPANT	\N	PRESENT	0
51810	51235	11093T	PARTICIPANT	\N	PRESENT	0
51811	51235	14271U	PARTICIPANT	\N	PRESENT	0
51812	51235	11061K	PARTICIPANT	\N	PRESENT	0
51813	51235	13002U	PARTICIPANT	\N	PRESENT	0
51814	51235	14257W	PARTICIPANT	\N	PRESENT	0
51815	51235	04040A	PARTICIPANT	\N	PRESENT	0
51816	51235	04055H	PARTICIPANT	\N	PRESENT	0
51817	51235	01028R	PARTICIPANT	\N	PRESENT	0
51818	51235	11104D	PARTICIPANT	\N	PRESENT	0
51819	51235	08038Y	PARTICIPANT	\N	PRESENT	0
51820	51235	08024S	PARTICIPANT	\N	PRESENT	0
51821	51235	11068S	PARTICIPANT	\N	PRESENT	0
51822	51235	11014C	PARTICIPANT	\N	PRESENT	0
51823	51235	14157T	PARTICIPANT	\N	PRESENT	0
51824	51235	08053X	PARTICIPANT	\N	PRESENT	0
51825	51235	11106F	PARTICIPANT	\N	PRESENT	0
51826	51235	11067R	PARTICIPANT	\N	PRESENT	0
51827	51235	14133K	PARTICIPANT	\N	PRESENT	0
51828	51235	11077T	PARTICIPANT	\N	PRESENT	0
51829	51235	11042G	PARTICIPANT	\N	PRESENT	0
51830	51235	04095R	PARTICIPANT	\N	PRESENT	0
51831	51235	14159V	PARTICIPANT	\N	PRESENT	0
51832	51235	11064N	PARTICIPANT	\N	PRESENT	0
51833	51235	11025F	PARTICIPANT	\N	PRESENT	0
51834	51235	14269B	PARTICIPANT	\N	PRESENT	0
51835	51235	12042Y	PARTICIPANT	\N	PRESENT	0
51836	51235	11107G	PARTICIPANT	\N	PRESENT	0
51837	51235	14199E	PARTICIPANT	\N	PRESENT	0
51838	51235	08069G	PARTICIPANT	\N	PRESENT	0
51839	51235	04079R	PARTICIPANT	\N	PRESENT	0
51840	51235	11113E	PARTICIPANT	\N	PRESENT	0
51841	51235	08035V	PARTICIPANT	\N	PRESENT	0
51842	51235	11037K	PARTICIPANT	\N	PRESENT	0
51843	51235	14255U	PARTICIPANT	\N	PRESENT	0
51844	51235	14219Q	PARTICIPANT	\N	PRESENT	0
51845	51235	14221J	PARTICIPANT	\N	PRESENT	0
51846	51235	14089Y	PARTICIPANT	\N	PRESENT	0
51847	51235	14217N	PARTICIPANT	\N	PRESENT	0
51848	51235	14083S	PARTICIPANT	\N	PRESENT	0
51849	49567	04049K	PRESIDENT	0	PRESENT	0
51850	51235	14327T	PARTICIPANT	\N	PRESENT	0
51851	51235	01043Q	PARTICIPANT	\N	PRESENT	0
51852	49567	89017R	PARTICIPANT	\N	PRESENT	0
51853	49567	14030Q	PARTICIPANT	\N	PRESENT	0
51854	49567	14105F	PARTICIPANT	\N	PRESENT	0
51855	49567	04053F	PARTICIPANT	\N	PRESENT	0
51856	51235	11026G	PARTICIPANT	\N	PRESENT	0
51857	49567	14207L	PARTICIPANT	\N	PRESENT	0
51858	49567	14255U	PARTICIPANT	\N	PRESENT	0
38079	31452	04043D	PARTICIPANT	\N	EXCUSE	0
38080	31452	11054L	PARTICIPANT	\N	EXCUSE	0
39322	39321	11076S	PARTICIPANT	\N	PRESENT	0
39323	39321	04054G	PARTICIPANT	\N	PRESENT	0
39324	39321	04040A	PARTICIPANT	\N	PRESENT	0
39325	39321	08058D	PARTICIPANT	\N	PRESENT	0
39326	39321	04042C	PARTICIPANT	\N	PRESENT	0
39327	39321	77002U	PARTICIPANT	\N	PRESENT	0
39328	39321	98029W	PARTICIPANT	\N	PRESENT	0
39329	39321	11080N	PARTICIPANT	\N	PRESENT	0
39330	39321	11027H	PARTICIPANT	\N	PRESENT	0
39331	39321	98018T	PARTICIPANT	\N	PRESENT	0
39332	39321	92018S	PARTICIPANT	\N	PRESENT	0
39333	39321	92020L	PARTICIPANT	\N	PRESENT	0
39334	39321	95030B	PARTICIPANT	\N	PRESENT	0
39632	39631	04042C	PARTICIPANT	\N	PRESENT	0
39336	39321	95031C	PARTICIPANT	\N	PRESENT	0
39633	39631	89017R	PARTICIPANT	\N	PRESENT	0
39338	39321	08065C	PARTICIPANT	\N	PRESENT	0
39339	39321	04035D	PARTICIPANT	\N	PRESENT	0
39340	39321	07024N	PARTICIPANT	\N	PRESENT	0
39634	39631	89029V	PARTICIPANT	\N	PRESENT	0
39342	39321	14014Q	PARTICIPANT	\N	EXCUSE	0
39343	39321	11015D	PARTICIPANT	\N	PRESENT	0
39344	39321	07004J	PARTICIPANT	\N	PRESENT	0
39345	39321	95035G	PARTICIPANT	\N	PRESENT	0
39346	39321	08056B	PARTICIPANT	\N	PRESENT	0
39347	39321	14211G	PARTICIPANT	\N	PRESENT	0
39635	39631	08039A	PARTICIPANT	\N	PRESENT	0
39349	39321	11064N	PARTICIPANT	\N	PRESENT	0
39350	39321	95037J	PARTICIPANT	\N	PRESENT	0
39351	39321	04078Q	PARTICIPANT	\N	PRESENT	0
39352	39321	14097Y	PARTICIPANT	\N	PRESENT	0
39354	39321	04036E	PARTICIPANT	\N	PRESENT	0
42591	42590	14261S	PARTICIPANT	\N	PRESENT	0
39356	39321	04077P	PARTICIPANT	\N	PRESENT	0
39357	39321	98005N	PARTICIPANT	\N	PRESENT	0
39358	39321	92031P	PARTICIPANT	\N	PRESENT	0
39359	39321	11106F	PARTICIPANT	\N	PRESENT	0
39360	39321	14251Q	PARTICIPANT	\N	PRESENT	0
39361	39321	83042R	PARTICIPANT	\N	EXCUSE	0
39362	39321	08053X	PARTICIPANT	\N	PRESENT	0
42592	42590	08055A	PARTICIPANT	\N	PRESENT	0
42593	42590	14093U	PARTICIPANT	\N	PRESENT	0
39365	39321	14253S	PARTICIPANT	\N	PRESENT	0
39366	39321	08047A	PARTICIPANT	\N	PRESENT	0
39367	39321	14028W	PARTICIPANT	\N	PRESENT	0
39368	39321	14193X	PARTICIPANT	\N	PRESENT	0
39369	39321	98021N	PARTICIPANT	\N	PRESENT	0
39370	39321	11069T	PARTICIPANT	\N	PRESENT	0
39371	39321	04080J	PARTICIPANT	\N	PRESENT	0
39372	39321	95059Q	PRESIDENT	0	PRESENT	0
39373	39321	86044G	PARTICIPANT	\N	PRESENT	0
39374	39321	01014K	PARTICIPANT	\N	PRESENT	0
39375	39321	11054L	PARTICIPANT	\N	PRESENT	0
39376	39321	01056V	PARTICIPANT	\N	PRESENT	0
42594	42590	14030Q	PARTICIPANT	\N	PRESENT	0
39378	39321	08049C	PARTICIPANT	\N	EXCUSE	0
50527	50526	14239U	PARTICIPANT	\N	PRESENT	0
42596	42590	08060W	PARTICIPANT	\N	PRESENT	0
42597	42590	11060J	PARTICIPANT	\N	PRESENT	0
42598	42590	11095V	PARTICIPANT	\N	PRESENT	0
42599	42590	14038Y	PARTICIPANT	\N	PRESENT	0
42600	42590	11114F	PARTICIPANT	\N	PRESENT	0
42601	42590	98023Q	PARTICIPANT	\N	PRESENT	0
50702	50701	01008M	PARTICIPANT	\N	PRESENT	0
42603	42590	01015L	PARTICIPANT	\N	PRESENT	0
42604	42590	11107G	PARTICIPANT	\N	PRESENT	0
50529	50526	01046T	PARTICIPANT	\N	PRESENT	0
42606	42590	02002K	PARTICIPANT	\N	PRESENT	0
42607	42590	01022K	PARTICIPANT	\N	PRESENT	0
42608	42590	04097T	PARTICIPANT	\N	PRESENT	0
42609	42590	09001P	PARTICIPANT	\N	PRESENT	0
42610	42590	11059R	PARTICIPANT	\N	PRESENT	0
42611	42590	14219Q	PARTICIPANT	\N	PRESENT	0
42612	42590	80027E	PARTICIPANT	\N	PRESENT	0
42613	42590	14031R	PARTICIPANT	\N	PRESENT	0
42614	42590	08009T	PRESIDENT	0	PRESENT	0
42615	42590	08062Y	PARTICIPANT	\N	PRESENT	0
42616	42590	14221J	PARTICIPANT	\N	PRESENT	0
50530	50526	04053F	PARTICIPANT	\N	PRESENT	0
42618	42590	08042U	PARTICIPANT	\N	PRESENT	0
42619	42590	14169X	PARTICIPANT	\N	PRESENT	0
42620	42590	14237S	PARTICIPANT	\N	PRESENT	0
42621	42590	13002U	PARTICIPANT	\N	EXCUSE	0
42622	42590	05012A	PARTICIPANT	\N	PRESENT	0
50531	50526	14255U	PARTICIPANT	\N	PRESENT	0
42624	42590	14135M	PARTICIPANT	\N	PRESENT	0
42625	42590	95062K	PARTICIPANT	\N	PRESENT	0
42626	42590	14107H	PARTICIPANT	\N	PRESENT	0
42627	42590	14051J	PARTICIPANT	\N	PRESENT	0
50532	50526	04066L	PARTICIPANT	\N	PRESENT	0
42629	42590	96003C	PARTICIPANT	\N	EXCUSE	0
50533	50526	00003C	PARTICIPANT	\N	PRESENT	0
50534	50526	14053L	PARTICIPANT	\N	PRESENT	0
50535	50526	11103C	PARTICIPANT	\N	PRESENT	0
50536	50526	11044J	PARTICIPANT	\N	PRESENT	0
50537	50526	14195A	PARTICIPANT	\N	PRESENT	0
50538	50526	14267Y	PARTICIPANT	\N	PRESENT	0
50733	50701	08021P	PARTICIPANT	\N	EXCUSE	0
50540	50526	11031D	PARTICIPANT	\N	PRESENT	0
50541	50526	08052W	PARTICIPANT	\N	PRESENT	0
50542	50526	01059Y	PARTICIPANT	\N	PRESENT	0
50543	50526	04081K	PARTICIPANT	\N	PRESENT	0
50544	50526	98024R	PRESIDENT	0	PRESENT	0
50545	50526	10006L	PARTICIPANT	\N	PRESENT	0
50703	50701	11036J	PARTICIPANT	\N	PRESENT	0
50547	50526	14217N	PARTICIPANT	\N	PRESENT	0
50548	50526	14042U	PARTICIPANT	\N	PRESENT	0
50549	50526	14151M	PARTICIPANT	\N	PRESENT	0
50550	50526	12042Y	PARTICIPANT	\N	PRESENT	0
50551	50526	14281W	PARTICIPANT	\N	PRESENT	0
50552	50526	14087W	PARTICIPANT	\N	PRESENT	0
50554	50526	14034U	PARTICIPANT	\N	PRESENT	0
50555	50526	14231L	PARTICIPANT	\N	PRESENT	0
50556	50526	11061K	PARTICIPANT	\N	PRESENT	0
50705	50701	14013P	PARTICIPANT	\N	EXCUSE	0
50558	50526	08041T	PARTICIPANT	\N	PRESENT	0
50559	50526	01011G	PARTICIPANT	\N	PRESENT	0
50560	50526	14026U	PARTICIPANT	\N	PRESENT	0
50562	50526	14121F	PARTICIPANT	\N	PRESENT	0
50706	50701	08068F	PARTICIPANT	\N	PRESENT	0
50564	50526	14037X	PARTICIPANT	\N	PRESENT	0
50565	50526	14018U	PARTICIPANT	\N	PRESENT	0
50566	50526	11067R	PARTICIPANT	\N	PRESENT	0
50567	50526	14223L	PARTICIPANT	\N	PRESENT	0
50568	50526	04092N	PRESIDENT	1	PRESENT	0
50569	50526	14265W	PARTICIPANT	\N	PRESENT	0
50570	50526	14119M	PARTICIPANT	\N	PRESENT	0
50571	50526	14071N	PARTICIPANT	\N	PRESENT	0
50572	50526	07032N	PARTICIPANT	\N	PRESENT	0
50573	50526	04043D	PARTICIPANT	\N	PRESENT	0
50574	50526	14271U	PARTICIPANT	\N	PRESENT	0
50707	50701	14207L	PARTICIPANT	\N	PRESENT	0
50576	50526	11093T	PARTICIPANT	\N	PRESENT	0
50577	50526	11097X	PARTICIPANT	\N	PRESENT	0
50578	50526	04045F	PARTICIPANT	\N	PRESENT	0
50579	50526	14227Q	PARTICIPANT	\N	PRESENT	0
50580	50526	01034P	PARTICIPANT	\N	PRESENT	0
50581	50526	11025F	PARTICIPANT	\N	PRESENT	0
50582	50526	11063M	PARTICIPANT	\N	PRESENT	0
50583	50526	14269B	PARTICIPANT	\N	PRESENT	0
50708	50701	11101A	PARTICIPANT	\N	PRESENT	0
50709	50701	90003B	PARTICIPANT	\N	PRESENT	0
50710	50701	08028W	PARTICIPANT	\N	EXCUSE	0
50711	50701	80013X	PARTICIPANT	\N	PRESENT	0
50712	50701	08038Y	PARTICIPANT	\N	PRESENT	0
50713	50701	04089T	PARTICIPANT	\N	PRESENT	0
50714	50701	14197C	PARTICIPANT	\N	PRESENT	0
50715	50701	11110B	PARTICIPANT	\N	PRESENT	0
50716	50701	14187A	PARTICIPANT	\N	PRESENT	0
50717	50701	14033T	PARTICIPANT	\N	PRESENT	0
50719	50701	04048J	PARTICIPANT	\N	PRESENT	0
50720	50701	11099A	PARTICIPANT	\N	PRESENT	0
50721	50701	04049K	PARTICIPANT	\N	PRESENT	0
50723	50701	11111C	PARTICIPANT	\N	PRESENT	0
50725	50701	11100Y	PRESIDENT	0	PRESENT	0
50726	50701	01061S	PARTICIPANT	\N	PRESENT	0
50727	50701	11098Y	PARTICIPANT	\N	PRESENT	0
50728	50701	01043Q	PARTICIPANT	\N	PRESENT	0
50729	50701	11077T	PARTICIPANT	\N	PRESENT	0
50730	50701	14205J	PARTICIPANT	\N	PRESENT	0
50731	50701	08019V	PARTICIPANT	\N	PRESENT	0
50732	50701	14257W	PARTICIPANT	\N	PRESENT	0
50865	50847	09001P	PARTICIPANT	\N	PRESENT	0
50866	50847	11059R	PARTICIPANT	\N	PRESENT	0
50867	50847	14219Q	PARTICIPANT	\N	PRESENT	0
50868	50847	80027E	PARTICIPANT	\N	PRESENT	0
50869	50847	14031R	PARTICIPANT	\N	PRESENT	0
50870	50847	08009T	PRESIDENT	0	PRESENT	0
50871	50847	08062Y	PARTICIPANT	\N	PRESENT	0
50872	50847	14221J	PARTICIPANT	\N	PRESENT	0
50873	50847	92039X	PARTICIPANT	\N	PRESENT	0
50874	50847	08042U	PARTICIPANT	\N	PRESENT	0
50875	50847	14169X	PARTICIPANT	\N	PRESENT	0
50876	50847	14237S	PARTICIPANT	\N	PRESENT	0
50877	50847	13002U	PARTICIPANT	\N	PRESENT	0
50878	50847	05012A	PARTICIPANT	\N	PRESENT	0
50898	50847	08025T	PARTICIPANT	\N	PRESENT	0
50899	50847	05008E	PARTICIPANT	\N	PRESENT	0
50900	50847	11033F	PARTICIPANT	\N	PRESENT	0
50882	50847	95062K	PARTICIPANT	\N	PRESENT	0
50901	50847	14065Q	PARTICIPANT	\N	PRESENT	0
50884	50847	14051J	PARTICIPANT	\N	PRESENT	0
50902	50847	14069U	PARTICIPANT	\N	PRESENT	0
50886	50847	96003C	PARTICIPANT	\N	EXCUSE	0
50903	50847	04047H	PARTICIPANT	\N	PRESENT	0
50904	50847	11032E	PARTICIPANT	\N	PRESENT	0
50905	50847	14259Y	PARTICIPANT	\N	PRESENT	0
50906	50847	11035H	PARTICIPANT	\N	PRESENT	0
50907	50847	14041T	PARTICIPANT	\N	PRESENT	0
50908	50847	14215L	PARTICIPANT	\N	PRESENT	0
50909	50847	08018U	PARTICIPANT	\N	PRESENT	0
50910	50847	14111D	PARTICIPANT	\N	PRESENT	0
50911	50847	14001X	PARTICIPANT	\N	PRESENT	0
50913	50847	14273W	PARTICIPANT	\N	PRESENT	0
50914	50847	14147R	PARTICIPANT	\N	PRESENT	0
50915	50847	07034Q	PARTICIPANT	\N	PRESENT	0
50916	50847	10015M	PARTICIPANT	\N	PRESENT	0
50917	50847	95063L	PARTICIPANT	\N	PRESENT	0
50918	50847	01028R	PARTICIPANT	\N	PRESENT	0
50919	50847	98035U	PARTICIPANT	\N	PRESENT	0
50921	50847	04044E	PARTICIPANT	\N	PRESENT	0
50922	50847	92045V	PARTICIPANT	\N	PRESENT	0
50923	50847	95067Q	PARTICIPANT	\N	PRESENT	0
50924	50847	04074L	PARTICIPANT	\N	PRESENT	0
50925	50847	08051V	PARTICIPANT	\N	PRESENT	0
50926	50847	95049N	PARTICIPANT	\N	PRESENT	0
51207	50929	02002K	PARTICIPANT	\N	PRESENT	0
50931	50929	08055A	PARTICIPANT	\N	PRESENT	0
50932	50929	14093U	PARTICIPANT	\N	PRESENT	0
50933	50929	14030Q	PARTICIPANT	\N	PRESENT	0
52209	52207	11015D	PARTICIPANT	\N	PRESENT	0
50935	50929	08060W	PARTICIPANT	\N	PRESENT	0
50936	50929	11095V	PARTICIPANT	\N	PRESENT	0
50937	50929	14038Y	PARTICIPANT	\N	PRESENT	0
50938	50929	11114F	PARTICIPANT	\N	PRESENT	0
50939	50929	98023Q	PARTICIPANT	\N	PRESENT	0
52217	52215	11015D	PARTICIPANT	\N	PRESENT	0
50941	50929	01015L	PARTICIPANT	\N	PRESENT	0
50942	50929	11107G	PARTICIPANT	\N	PRESENT	0
50943	50929	11020A	PARTICIPANT	\N	PRESENT	0
52220	52219	04054G	PARTICIPANT	\N	PRESENT	0
50945	50929	01022K	PARTICIPANT	\N	PRESENT	0
50946	50929	04097T	PARTICIPANT	\N	PRESENT	0
50947	50929	09001P	PARTICIPANT	\N	PRESENT	0
50948	50929	11059R	PARTICIPANT	\N	PRESENT	0
50949	50929	14219Q	PARTICIPANT	\N	PRESENT	0
50950	50929	80027E	PARTICIPANT	\N	PRESENT	0
50951	50929	14031R	PARTICIPANT	\N	PRESENT	0
50952	50929	08009T	PRESIDENT	0	PRESENT	0
50953	50929	08062Y	PARTICIPANT	\N	PRESENT	0
50954	50929	14221J	PARTICIPANT	\N	PRESENT	0
52312	49835	95062K	PARTICIPANT	\N	EXCUSE	0
50956	50929	08042U	PARTICIPANT	\N	PRESENT	0
50957	50929	14169X	PARTICIPANT	\N	PRESENT	0
50958	50929	14237S	PARTICIPANT	\N	PRESENT	0
50959	50929	13002U	PARTICIPANT	\N	PRESENT	0
50960	50929	05012A	PARTICIPANT	\N	PRESENT	0
53751	53750	07034Q	PARTICIPANT	\N	PRESENT	0
50962	50929	14135M	PARTICIPANT	\N	PRESENT	0
53753	52314	01015L	PARTICIPANT	\N	PRESENT	0
50964	50929	95062K	PARTICIPANT	\N	PRESENT	0
50965	50929	14107H	PARTICIPANT	\N	PRESENT	0
50966	50929	14051J	PARTICIPANT	\N	PRESENT	0
50967	50929	14157T	PARTICIPANT	\N	PRESENT	0
50968	50929	96003C	PARTICIPANT	\N	EXCUSE	0
53754	52314	11040E	PARTICIPANT	\N	PRESENT	0
53755	52314	92015P	PARTICIPANT	\N	PRESENT	0
53756	52314	80027E	PARTICIPANT	\N	PRESENT	0
53757	52314	00003C	PARTICIPANT	\N	PRESENT	0
53758	52314	04034C	PARTICIPANT	\N	PRESENT	0
53759	52314	08060W	PARTICIPANT	\N	PRESENT	0
53760	52314	08055A	PARTICIPANT	\N	PRESENT	0
53763	52314	11066Q	PARTICIPANT	\N	PRESENT	0
53764	52314	11107G	PARTICIPANT	\N	PRESENT	0
53765	52314	11099A	PARTICIPANT	\N	PRESENT	0
53766	52314	01044R	PARTICIPANT	\N	PRESENT	0
53767	53762	07034Q	PARTICIPANT	\N	PRESENT	0
53768	52314	08049C	PARTICIPANT	\N	PRESENT	0
53769	52314	14103D	PARTICIPANT	\N	PRESENT	0
53770	52314	14327T	PARTICIPANT	\N	PRESENT	0
53771	52314	14038Y	PARTICIPANT	\N	PRESENT	0
53772	52314	04089T	PARTICIPANT	\N	PRESENT	0
53774	52314	14105F	PARTICIPANT	\N	PRESENT	0
53775	52314	04088S	PARTICIPANT	\N	PRESENT	0
53776	52314	04041B	PARTICIPANT	\N	PRESENT	0
53834	52314	07029T	PARTICIPANT	\N	PRESENT	0
53835	53773	14239U	PARTICIPANT	\N	PRESENT	0
53836	53773	11055M	PARTICIPANT	\N	EXCUSE	0
53837	53773	01046T	PARTICIPANT	\N	PRESENT	0
53838	53773	04053F	PARTICIPANT	\N	PRESENT	0
53840	53773	04066L	PARTICIPANT	\N	PRESENT	0
53841	53773	00003C	PARTICIPANT	\N	PRESENT	0
53842	53773	14053L	PARTICIPANT	\N	PRESENT	0
53843	53773	11103C	PARTICIPANT	\N	PRESENT	0
53844	53773	11044J	PARTICIPANT	\N	EXCUSE	0
53845	53773	14195A	PARTICIPANT	\N	PRESENT	0
53846	53773	14267Y	PARTICIPANT	\N	PRESENT	0
53847	53773	11023D	PARTICIPANT	\N	PRESENT	0
53848	53773	11031D	PARTICIPANT	\N	PRESENT	0
53849	53773	08052W	PARTICIPANT	\N	PRESENT	0
53850	53773	01059Y	PARTICIPANT	\N	PRESENT	0
53851	53773	04081K	PARTICIPANT	\N	PRESENT	0
53852	53773	98024R	PARTICIPANT	\N	PRESENT	0
53641	52314	01007L	PARTICIPANT	\N	PRESENT	0
53643	53642	08025T	PARTICIPANT	\N	PRESENT	0
53644	53642	04085P	PARTICIPANT	\N	PRESENT	0
53645	53642	05008E	PRESIDENT	0	PRESENT	0
53646	53642	11030C	PARTICIPANT	\N	PRESENT	0
53647	53642	11033F	PARTICIPANT	\N	PRESENT	0
53648	53642	14065Q	PARTICIPANT	\N	PRESENT	0
53649	53642	14069U	PARTICIPANT	\N	PRESENT	0
53650	53642	04047H	PARTICIPANT	\N	PRESENT	0
53651	53642	11032E	PARTICIPANT	\N	PRESENT	0
53652	53642	04038G	PARTICIPANT	\N	PRESENT	0
53654	53642	11056N	PARTICIPANT	\N	PRESENT	0
53655	53642	14259Y	PARTICIPANT	\N	PRESENT	0
53656	53642	11035H	PARTICIPANT	\N	PRESENT	0
53657	53642	14041T	PARTICIPANT	\N	PRESENT	0
53658	53642	11113E	PARTICIPANT	\N	PRESENT	0
53659	53642	01024M	PARTICIPANT	\N	PRESENT	0
53660	53642	14215L	PARTICIPANT	\N	PRESENT	0
53661	53642	11034G	PARTICIPANT	\N	PRESENT	0
53662	53642	08018U	PARTICIPANT	\N	EXCUSE	0
53664	53642	01007L	PARTICIPANT	\N	PRESENT	0
53665	53642	11049P	PARTICIPANT	\N	PRESENT	0
53667	53642	11084S	PARTICIPANT	\N	PRESENT	0
53668	53642	11026G	PARTICIPANT	\N	PRESENT	0
53669	53642	04079R	PARTICIPANT	\N	PRESENT	0
53670	53642	14111D	PARTICIPANT	\N	PRESENT	0
53671	53642	14001X	PARTICIPANT	\N	PRESENT	0
53672	53642	14273W	PARTICIPANT	\N	PRESENT	0
53673	53642	01060R	PARTICIPANT	\N	PRESENT	0
53674	53642	14147R	PARTICIPANT	\N	PRESENT	0
53675	53642	95049N	PARTICIPANT	\N	PRESENT	0
53676	53642	08051V	PARTICIPANT	\N	PRESENT	0
53677	53642	11072N	PARTICIPANT	\N	PRESENT	0
53678	53642	07034Q	PARTICIPANT	\N	PRESENT	0
53679	53642	04074L	PARTICIPANT	\N	PRESENT	0
53681	53642	95063L	PARTICIPANT	\N	PRESENT	0
53682	53642	01019Q	PARTICIPANT	\N	PRESENT	0
53683	53642	01028R	PARTICIPANT	\N	PRESENT	0
53684	53642	98035U	PARTICIPANT	\N	PRESENT	0
53685	53642	04056J	PARTICIPANT	\N	PRESENT	0
53686	53642	14275Y	PARTICIPANT	\N	PRESENT	0
53687	53642	04044E	PARTICIPANT	\N	PRESENT	0
53688	53642	11037K	PARTICIPANT	\N	PRESENT	0
53689	53642	92045V	PARTICIPANT	\N	PRESENT	0
53690	53642	95067Q	PARTICIPANT	\N	PRESENT	0
53691	53642	01047U	PARTICIPANT	\N	PRESENT	0
31235	31234	01046T	PARTICIPANT	\N	PRESENT	0
31236	31234	04053F	PARTICIPANT	\N	PRESENT	0
31237	31234	14255U	PARTICIPANT	\N	PRESENT	0
31238	31234	11044J	PARTICIPANT	\N	PRESENT	0
31239	31234	14267Y	PARTICIPANT	\N	PRESENT	0
31240	31234	11031D	PARTICIPANT	\N	PRESENT	0
31241	31234	08052W	PARTICIPANT	\N	PRESENT	0
31242	31234	01059Y	PARTICIPANT	\N	PRESENT	0
31243	31234	14034U	PARTICIPANT	\N	PRESENT	0
31244	31234	14231L	PARTICIPANT	\N	PRESENT	0
31245	31234	01011G	PARTICIPANT	\N	PRESENT	0
31246	31234	14121F	PARTICIPANT	\N	PRESENT	0
31247	31234	14037X	PARTICIPANT	\N	PRESENT	0
31248	31234	14223L	PARTICIPANT	\N	PRESENT	0
31249	31234	04092N	PRESIDENT	0	PRESENT	0
31250	31234	14119M	PARTICIPANT	\N	PRESENT	0
31251	31234	14071N	PARTICIPANT	\N	PRESENT	0
31252	31234	14271U	PARTICIPANT	\N	PRESENT	0
31253	31234	11093T	PARTICIPANT	\N	PRESENT	0
31254	31234	11097X	PARTICIPANT	\N	EXCUSE	0
31255	31234	04045F	PARTICIPANT	\N	PRESENT	0
31256	31234	14227Q	PARTICIPANT	\N	PRESENT	0
31257	31234	01034P	PARTICIPANT	\N	PRESENT	0
31258	31234	11063M	PARTICIPANT	\N	PRESENT	0
31259	31234	14269B	PARTICIPANT	\N	PRESENT	0
33149	33148	14135M	PARTICIPANT	\N	PRESENT	0
33151	33150	14135M	PARTICIPANT	\N	PRESENT	0
33152	33150	11109J	PARTICIPANT	\N	PRESENT	0
33153	33150	14030Q	PARTICIPANT	\N	PRESENT	0
33154	33150	97011G	PARTICIPANT	\N	PRESENT	0
45629	45628	80013X	PARTICIPANT	\N	PRESENT	0
45630	45628	95035G	PARTICIPANT	\N	PRESENT	0
45631	45628	11067R	PARTICIPANT	\N	PRESENT	0
45634	45633	80013X	PARTICIPANT	\N	PRESENT	0
45635	45633	95035G	PARTICIPANT	\N	PRESENT	0
45636	45633	11067R	PARTICIPANT	\N	PRESENT	0
45638	45637	11031D	PARTICIPANT	\N	PRESENT	0
45639	45637	80013X	PARTICIPANT	\N	PRESENT	0
45640	45637	95035G	PARTICIPANT	\N	PRESENT	0
45641	45637	08031R	PARTICIPANT	\N	PRESENT	0
45642	45637	11067R	PARTICIPANT	\N	PRESENT	0
50593	50589	08025T	PARTICIPANT	\N	PRESENT	0
46894	44317	14083S	PARTICIPANT	\N	EXCUSE	0
46895	44317	08068F	PARTICIPANT	\N	EXCUSE	0
48555	48554	01016M	PARTICIPANT	\N	PRESENT	0
51004	51002	01016M	PARTICIPANT	\N	PRESENT	0
50594	50589	04085P	PARTICIPANT	\N	PRESENT	0
50595	50589	05008E	PRESIDENT	0	PRESENT	0
50596	50589	11030C	PARTICIPANT	\N	PRESENT	0
50597	50589	11033F	PARTICIPANT	\N	PRESENT	0
50598	50589	14065Q	PARTICIPANT	\N	PRESENT	0
50599	50589	14069U	PARTICIPANT	\N	PRESENT	0
50600	50589	04047H	PARTICIPANT	\N	PRESENT	0
50601	50589	11032E	PARTICIPANT	\N	PRESENT	0
50602	50589	04038G	PARTICIPANT	\N	PRESENT	0
50603	50589	99002P	PARTICIPANT	\N	EXCUSE	0
50604	50589	11056N	PARTICIPANT	\N	PRESENT	0
50605	50589	14259Y	PARTICIPANT	\N	PRESENT	0
50606	50589	11035H	PARTICIPANT	\N	PRESENT	0
50607	50589	14041T	PARTICIPANT	\N	PRESENT	0
50608	50589	11113E	PARTICIPANT	\N	PRESENT	0
50609	50589	01024M	PARTICIPANT	\N	PRESENT	0
50610	50589	14215L	PARTICIPANT	\N	PRESENT	0
50611	50589	11034G	PARTICIPANT	\N	PRESENT	0
50612	50589	08018U	PARTICIPANT	\N	PRESENT	0
50613	50589	11010L	PARTICIPANT	\N	EXCUSE	0
51229	51228	14001X	PARTICIPANT	\N	PRESENT	0
51230	49835	14053L	PARTICIPANT	\N	EXCUSE	0
50616	50589	08044W	PARTICIPANT	\N	PRESENT	0
50617	50589	11084S	PARTICIPANT	\N	PRESENT	0
50618	50589	11026G	PARTICIPANT	\N	PRESENT	0
50619	50589	04079R	PARTICIPANT	\N	PRESENT	0
50620	50589	14111D	PARTICIPANT	\N	PRESENT	0
50621	50589	14001X	PARTICIPANT	\N	PRESENT	0
50622	50589	14273W	PARTICIPANT	\N	PRESENT	0
50623	50589	01060R	PARTICIPANT	\N	PRESENT	0
50624	50589	14147R	PARTICIPANT	\N	PRESENT	0
50625	50589	95049N	PARTICIPANT	\N	PRESENT	0
50626	50589	08051V	PARTICIPANT	\N	PRESENT	0
51232	51231	14001X	PARTICIPANT	\N	PRESENT	0
50628	50589	07034Q	PARTICIPANT	\N	PRESENT	0
50629	50589	04074L	PARTICIPANT	\N	PRESENT	0
50630	50589	10015M	PARTICIPANT	\N	PRESENT	0
50631	50589	95063L	PARTICIPANT	\N	PRESENT	0
50632	50589	01019Q	PARTICIPANT	\N	PRESENT	0
50633	50589	01028R	PARTICIPANT	\N	PRESENT	0
50634	50589	98035U	PARTICIPANT	\N	PRESENT	0
51233	51231	14133K	PARTICIPANT	\N	PRESENT	0
52146	51235	89017R	PARTICIPANT	\N	PRESENT	0
50637	50589	04044E	PRESIDENT	1	PRESENT	0
50638	50589	11037K	PARTICIPANT	\N	PRESENT	0
50639	50589	92045V	PARTICIPANT	\N	PRESENT	0
50640	50589	95067Q	PARTICIPANT	\N	PRESENT	0
50641	50589	01047U	PARTICIPANT	\N	PRESENT	0
52527	51474	14147R	PARTICIPANT	\N	PRESENT	0
52528	51474	00003C	PARTICIPANT	\N	PRESENT	0
52529	51474	01015L	PARTICIPANT	\N	PRESENT	0
52530	51474	14265W	PARTICIPANT	\N	PRESENT	0
52531	51474	14197C	PARTICIPANT	\N	PRESENT	0
52532	51474	13002U	PARTICIPANT	\N	PRESENT	0
52533	51474	14061L	PARTICIPANT	\N	PRESENT	0
52534	51474	14051J	PARTICIPANT	\N	PRESENT	0
52535	51474	14237S	PARTICIPANT	\N	PRESENT	0
52536	51474	98046X	PARTICIPANT	\N	PRESENT	0
52537	51474	09001P	PARTICIPANT	\N	PRESENT	0
52538	51474	11103C	PARTICIPANT	\N	PRESENT	0
52539	51474	08055A	PARTICIPANT	\N	PRESENT	0
52540	51474	14107H	PARTICIPANT	\N	PRESENT	0
52541	51474	08060W	PARTICIPANT	\N	PRESENT	0
52542	51474	08016S	PARTICIPANT	\N	PRESENT	0
52543	51474	92039X	PARTICIPANT	\N	PRESENT	0
52544	51474	11107G	PARTICIPANT	\N	PRESENT	0
52545	51474	11066Q	PARTICIPANT	\N	PRESENT	0
52546	51474	01044R	PARTICIPANT	\N	PRESENT	0
52547	51474	11114F	PARTICIPANT	\N	PRESENT	0
52548	51474	11095V	PARTICIPANT	\N	PRESENT	0
52549	51474	08049C	PARTICIPANT	\N	PRESENT	0
52550	51474	14261S	PARTICIPANT	\N	PRESENT	0
52551	51474	14083S	PARTICIPANT	\N	PRESENT	0
52552	51474	14030Q	PARTICIPANT	\N	PRESENT	0
52553	51474	14219Q	PARTICIPANT	\N	PRESENT	0
52554	51474	14103D	PARTICIPANT	\N	PRESENT	0
52555	51474	08009T	PARTICIPANT	\N	PRESENT	0
52556	51474	14093U	PARTICIPANT	\N	PRESENT	0
52557	51474	11090Q	PARTICIPANT	\N	PRESENT	0
52558	51474	04089T	PARTICIPANT	\N	PRESENT	0
52559	51474	14213J	PARTICIPANT	\N	PRESENT	0
52560	51474	11099A	PARTICIPANT	\N	PRESENT	0
52561	51474	14331P	PARTICIPANT	\N	PRESENT	0
52562	51474	14223L	PARTICIPANT	\N	PRESENT	0
52563	51474	14157T	PARTICIPANT	\N	PRESENT	0
52564	51474	08062Y	PARTICIPANT	\N	PRESENT	0
52565	51474	14055N	PARTICIPANT	\N	PRESENT	0
52566	51474	11011M	PARTICIPANT	\N	PRESENT	0
52567	51474	14039A	PARTICIPANT	\N	PRESENT	0
52568	51474	11049P	PARTICIPANT	\N	PRESENT	0
52569	51474	14221J	PARTICIPANT	\N	PRESENT	0
52570	51474	14031R	PARTICIPANT	\N	PRESENT	0
52571	51474	08061X	PARTICIPANT	\N	PRESENT	0
52572	51474	11056N	PARTICIPANT	\N	PRESENT	0
52573	51474	01027Q	PARTICIPANT	\N	PRESENT	0
52574	51474	01025N	PARTICIPANT	\N	PRESENT	0
52575	51474	14135M	PARTICIPANT	\N	PRESENT	0
52576	51474	14191V	PARTICIPANT	\N	PRESENT	0
52577	51474	14169X	PARTICIPANT	\N	PRESENT	0
52578	51474	14069U	PARTICIPANT	\N	PRESENT	0
52579	51474	96003C	PARTICIPANT	\N	PRESENT	0
52580	51474	14327T	PARTICIPANT	\N	PRESENT	0
52581	51474	14159V	PARTICIPANT	\N	PRESENT	0
52582	51474	11032E	PARTICIPANT	\N	PRESENT	0
52583	51474	14205J	PARTICIPANT	\N	PRESENT	0
52584	51474	14018U	PARTICIPANT	\N	PRESENT	0
52585	51474	11065P	PARTICIPANT	\N	PRESENT	0
52586	51474	11100Y	PARTICIPANT	\N	PRESENT	0
52587	51474	14073Q	PARTICIPANT	\N	PRESENT	0
52588	51474	92015P	PARTICIPANT	\N	PRESENT	0
52589	51474	14097Y	PARTICIPANT	\N	PRESENT	0
52590	51474	14207L	PARTICIPANT	\N	PRESENT	0
52591	51474	86044G	PARTICIPANT	\N	PRESENT	0
52592	51474	14105F	PARTICIPANT	\N	PRESENT	0
52593	51474	14001X	PARTICIPANT	\N	PRESENT	0
52594	51474	11059R	PARTICIPANT	\N	PRESENT	0
52595	51474	11111C	PARTICIPANT	\N	PRESENT	0
52596	51474	11048N	PARTICIPANT	\N	PRESENT	0
52597	51474	87003B	PARTICIPANT	\N	PRESENT	0
52598	51474	14033T	PARTICIPANT	\N	PRESENT	0
52599	51474	14111D	PARTICIPANT	\N	PRESENT	0
52600	51474	14053L	PARTICIPANT	\N	PRESENT	0
51859	49567	14083S	PARTICIPANT	\N	PRESENT	0
51860	49567	14041T	PARTICIPANT	\N	PRESENT	0
52147	49569	04049K	PRESIDENT	0	PRESENT	0
51862	49567	14151M	PARTICIPANT	\N	PRESENT	0
51863	49567	14087W	PARTICIPANT	\N	PRESENT	0
51864	49567	14061L	PARTICIPANT	\N	PRESENT	0
51865	49567	14265W	PARTICIPANT	\N	PRESENT	0
51866	49567	14157T	PARTICIPANT	\N	PRESENT	0
51867	51235	01048V	PARTICIPANT	\N	PRESENT	0
51868	49567	11063M	PARTICIPANT	\N	PRESENT	0
51869	51235	14251Q	PARTICIPANT	\N	PRESENT	0
51870	51235	11114F	PARTICIPANT	\N	PRESENT	0
51871	51235	14034U	PARTICIPANT	\N	PRESENT	0
51872	49568	04049K	PARTICIPANT	\N	PRESENT	0
51873	49568	14030Q	PARTICIPANT	\N	PRESENT	0
51874	49568	14105F	PARTICIPANT	\N	PRESENT	0
51875	49568	04053F	PARTICIPANT	\N	PRESENT	0
51876	49568	14255U	PARTICIPANT	\N	PRESENT	0
51877	51235	95041E	PARTICIPANT	\N	PRESENT	0
51878	51235	10006L	PARTICIPANT	\N	PRESENT	0
51879	49568	14083S	PARTICIPANT	\N	PRESENT	0
52148	49569	14151M	PARTICIPANT	\N	PRESENT	0
51881	49568	14041T	PARTICIPANT	\N	PRESENT	0
52149	49569	14255U	PARTICIPANT	\N	PRESENT	0
51883	51235	11076S	PARTICIPANT	\N	PRESENT	0
51884	49568	14087W	PARTICIPANT	\N	PRESENT	0
51885	49568	14061L	PARTICIPANT	\N	PRESENT	0
51886	49568	14265W	PARTICIPANT	\N	PRESENT	0
51887	49568	14157T	PARTICIPANT	\N	PRESENT	0
51888	49568	11063M	PARTICIPANT	\N	PRESENT	0
51889	51235	04071H	PARTICIPANT	\N	PRESENT	0
51890	51235	14241N	PARTICIPANT	\N	PRESENT	0
51892	51891	14087W	PARTICIPANT	\N	PRESENT	0
51894	51893	14087W	PARTICIPANT	\N	PRESENT	0
51895	51235	05004A	PARTICIPANT	\N	PRESENT	0
52145	51236	04081K	PARTICIPANT	\N	PRESENT	0
52150	51236	14013P	PARTICIPANT	\N	PRESENT	0
52151	49569	14105F	PARTICIPANT	\N	PRESENT	0
52152	51236	11048N	PARTICIPANT	\N	PRESENT	0
52153	51236	14051J	PARTICIPANT	\N	PRESENT	0
52154	51236	13002U	PARTICIPANT	\N	PRESENT	0
52155	51236	11061K	PARTICIPANT	\N	PRESENT	0
52156	51236	01044R	PARTICIPANT	\N	PRESENT	0
52157	51236	11055M	PARTICIPANT	\N	PRESENT	0
52158	51236	11096W	PARTICIPANT	\N	PRESENT	0
52159	51236	14179A	PARTICIPANT	\N	PRESENT	0
52160	51236	11076S	PARTICIPANT	\N	PRESENT	0
52161	51236	01015L	PARTICIPANT	\N	PRESENT	0
52162	51236	04080J	PARTICIPANT	\N	PRESENT	0
52163	51236	14031R	PARTICIPANT	\N	PRESENT	0
52164	51236	14038Y	PARTICIPANT	\N	PRESENT	0
52165	51236	14083S	PARTICIPANT	\N	PRESENT	0
52166	51236	04061F	PARTICIPANT	\N	PRESENT	0
52167	51236	07029T	PARTICIPANT	\N	PRESENT	0
52168	51236	11113E	PARTICIPANT	\N	PRESENT	0
52169	51236	04095R	PARTICIPANT	\N	PRESENT	0
52170	51236	04036E	PARTICIPANT	\N	PRESENT	0
52171	51236	14267Y	PARTICIPANT	\N	PRESENT	0
52172	51236	08056B	PARTICIPANT	\N	PRESENT	0
52173	51236	98005N	PARTICIPANT	\N	PRESENT	0
52174	51236	95035G	PARTICIPANT	\N	PRESENT	0
52175	51236	14199E	PARTICIPANT	\N	PRESENT	0
52176	51236	08055A	PARTICIPANT	\N	PRESENT	0
52222	51236	04067M	PARTICIPANT	\N	PRESENT	0
52233	51236	08069G	PARTICIPANT	\N	PRESENT	0
52252	49835	14059S	PARTICIPANT	\N	EXCUSE	0
52253	49959	04094Q	PARTICIPANT	\N	EXCUSE	0
52256	52255	14093U	PARTICIPANT	\N	PRESENT	0
52258	52257	04048J	PARTICIPANT	\N	PRESENT	0
52260	52259	14237S	PARTICIPANT	\N	PRESENT	0
52273	52272	14097Y	PARTICIPANT	\N	PRESENT	0
52274	52272	14133K	PARTICIPANT	\N	PRESENT	0
52275	52272	04080J	PARTICIPANT	\N	PRESENT	0
52276	51235	07024N	PARTICIPANT	\N	PRESENT	0
52302	52301	04034C	PARTICIPANT	\N	PRESENT	0
52424	52423	14261S	PARTICIPANT	\N	PRESENT	0
52425	52423	08055A	PARTICIPANT	\N	PRESENT	0
52426	52423	14093U	PARTICIPANT	\N	PRESENT	0
52427	52423	14030Q	PARTICIPANT	\N	PRESENT	0
53194	52278	14147R	PARTICIPANT	\N	PRESENT	0
52429	52423	08060W	PARTICIPANT	\N	PRESENT	0
52430	52423	11095V	PARTICIPANT	\N	PRESENT	0
52431	52423	14038Y	PARTICIPANT	\N	PRESENT	0
52432	52423	11114F	PARTICIPANT	\N	PRESENT	0
53195	52278	80027E	PARTICIPANT	\N	PRESENT	0
52434	52423	11065P	PARTICIPANT	\N	PRESENT	0
52435	52423	01015L	PARTICIPANT	\N	PRESENT	0
52436	52423	11107G	PARTICIPANT	\N	PRESENT	0
53196	52278	00003C	PARTICIPANT	\N	PRESENT	0
53197	52278	11067R	PARTICIPANT	\N	PRESENT	0
52439	52423	01022K	PARTICIPANT	\N	PRESENT	0
53198	52278	14065Q	PARTICIPANT	\N	PRESENT	0
52441	52423	09001P	PARTICIPANT	\N	PRESENT	0
52442	52423	11059R	PARTICIPANT	\N	PRESENT	0
52443	52423	14219Q	PARTICIPANT	\N	PRESENT	0
52444	52423	80027E	PARTICIPANT	\N	PRESENT	0
52445	52423	14031R	PARTICIPANT	\N	PRESENT	0
52446	52423	08009T	PRESIDENT	0	PRESENT	0
52447	52423	08062Y	PARTICIPANT	\N	PRESENT	0
52448	52423	14221J	PARTICIPANT	\N	PRESENT	0
52449	52423	92039X	PARTICIPANT	\N	PRESENT	0
52450	52423	08042U	PARTICIPANT	\N	PRESENT	0
52451	52423	14169X	PARTICIPANT	\N	PRESENT	0
52452	52423	14237S	PARTICIPANT	\N	PRESENT	0
52453	52423	13002U	PARTICIPANT	\N	PRESENT	0
53199	52278	14030Q	PARTICIPANT	\N	PRESENT	0
53200	52278	04089T	PARTICIPANT	\N	PRESENT	0
52456	52423	14135M	PARTICIPANT	\N	PRESENT	0
53201	52278	11096W	PARTICIPANT	\N	PRESENT	0
52458	52423	95062K	PARTICIPANT	\N	EXCUSE	0
52459	52423	14107H	PARTICIPANT	\N	PRESENT	0
52460	52423	14051J	PARTICIPANT	\N	PRESENT	0
52461	52423	14157T	PARTICIPANT	\N	PRESENT	0
53202	52278	08049C	PARTICIPANT	\N	PRESENT	0
53203	52278	14231L	PARTICIPANT	\N	PRESENT	0
53204	52278	14257W	PARTICIPANT	\N	PRESENT	0
53205	52278	11048N	PARTICIPANT	\N	PRESENT	0
53207	52278	14331P	PARTICIPANT	\N	PRESENT	0
53209	52278	04045F	PARTICIPANT	\N	PRESENT	0
53211	52278	04067M	PARTICIPANT	\N	PRESENT	0
53214	52278	14237S	PARTICIPANT	\N	PRESENT	0
53216	52278	14042U	PARTICIPANT	\N	PRESENT	0
53218	52278	14205J	PARTICIPANT	\N	PRESENT	0
53219	52278	14261S	PARTICIPANT	\N	PRESENT	0
53220	52278	01027Q	PARTICIPANT	\N	PRESENT	0
53221	52278	14249W	PARTICIPANT	\N	PRESENT	0
53222	52278	14105F	PARTICIPANT	\N	PRESENT	0
53223	52278	08060W	PARTICIPANT	\N	PRESENT	0
53224	52278	08031R	PARTICIPANT	\N	PRESENT	0
53225	52278	14018U	PARTICIPANT	\N	PRESENT	0
53226	52278	11114F	PARTICIPANT	\N	PRESENT	0
53227	52278	14079W	PARTICIPANT	\N	PRESENT	0
53228	52278	14026U	PARTICIPANT	\N	PRESENT	0
53229	52278	04034C	PARTICIPANT	\N	PRESENT	0
53230	52278	11109J	PARTICIPANT	\N	PRESENT	0
53231	52278	11110B	PARTICIPANT	\N	PRESENT	0
53232	52278	95030B	PARTICIPANT	\N	PRESENT	0
53233	52278	14103D	PARTICIPANT	\N	PRESENT	0
53234	52278	01003G	PARTICIPANT	\N	PRESENT	0
53235	52278	14039A	PARTICIPANT	\N	PRESENT	0
53236	52278	11105E	PARTICIPANT	\N	PRESENT	0
53237	52278	11029K	PARTICIPANT	\N	PRESENT	0
53238	52278	04081K	PARTICIPANT	\N	PRESENT	0
53239	52278	11064N	PARTICIPANT	\N	PRESENT	0
53240	52278	14014Q	PARTICIPANT	\N	PRESENT	0
53241	52278	14051J	PARTICIPANT	\N	PRESENT	0
53242	52278	14059S	PARTICIPANT	\N	PRESENT	0
53243	52278	14135M	PARTICIPANT	\N	PRESENT	0
53244	52278	08010L	PARTICIPANT	\N	PRESENT	0
37277	31452	96003C	PARTICIPANT	\N	EXCUSE	0
37278	31452	11010L	PARTICIPANT	\N	EXCUSE	0
38468	38466	14175V	PARTICIPANT	\N	PRESENT	0
38469	38466	14255U	PARTICIPANT	\N	PRESENT	0
38470	38466	14038Y	PARTICIPANT	\N	PRESENT	0
38471	38466	14237S	PARTICIPANT	\N	PRESENT	0
38472	38466	14193X	PARTICIPANT	\N	PRESENT	0
38473	38466	04045F	PARTICIPANT	\N	PRESENT	0
38474	38466	04044E	PARTICIPANT	\N	PRESENT	0
38475	38466	95067Q	PARTICIPANT	\N	PRESENT	0
38477	38476	14038Y	PARTICIPANT	\N	PRESENT	0
38478	38476	11091R	PARTICIPANT	\N	PRESENT	0
38480	38476	14237S	PARTICIPANT	\N	PRESENT	0
38481	38476	14193X	PARTICIPANT	\N	PRESENT	0
38551	38550	01008M	PARTICIPANT	\N	PRESENT	0
38552	38550	11036J	PARTICIPANT	\N	PRESENT	0
38751	37248	01048V	PARTICIPANT	\N	EXCUSE	0
38554	38550	14013P	PARTICIPANT	\N	PRESENT	0
38555	38550	08068F	PARTICIPANT	\N	PRESENT	0
38556	38550	14207L	PARTICIPANT	\N	PRESENT	0
38557	38550	11101A	PARTICIPANT	\N	PRESENT	0
38558	38550	90003B	PARTICIPANT	\N	PRESENT	0
38559	38550	08028W	PARTICIPANT	\N	PRESENT	0
40279	40277	04054G	PARTICIPANT	\N	PRESENT	0
38561	38550	08038Y	PARTICIPANT	\N	PRESENT	0
38562	38550	04089T	PARTICIPANT	\N	PRESENT	0
38563	38550	14197C	PARTICIPANT	\N	PRESENT	0
38749	37248	01046T	PARTICIPANT	\N	EXCUSE	0
38565	38550	14187A	PARTICIPANT	\N	PRESENT	0
38566	38550	14033T	PARTICIPANT	\N	PRESENT	0
38567	38550	14081Q	PARTICIPANT	\N	PRESENT	0
38568	38550	04048J	PARTICIPANT	\N	PRESENT	0
38569	38550	11099A	PARTICIPANT	\N	PRESENT	0
38570	38550	04049K	PARTICIPANT	\N	PRESENT	0
38750	37248	04061F	PARTICIPANT	\N	EXCUSE	0
38572	38550	11111C	PARTICIPANT	\N	PRESENT	0
38573	38550	08015R	PARTICIPANT	\N	PRESENT	0
38574	38550	11100Y	PRESIDENT	0	PRESENT	0
38575	38550	01061S	PARTICIPANT	\N	PRESENT	0
38576	38550	11098Y	PARTICIPANT	\N	PRESENT	0
38577	38550	01043Q	PARTICIPANT	\N	PRESENT	0
38752	37248	14221J	PARTICIPANT	\N	EXCUSE	0
38579	38550	14205J	PARTICIPANT	\N	PRESENT	0
38580	38550	08019V	PARTICIPANT	\N	PRESENT	0
38581	38550	14257W	PARTICIPANT	\N	PRESENT	0
38582	38550	08021P	PARTICIPANT	\N	EXCUSE	0
38583	38550	04088S	PARTICIPANT	\N	PRESENT	0
38584	38550	98050T	PARTICIPANT	\N	PRESENT	0
38585	38550	11090Q	PARTICIPANT	\N	PRESENT	0
38586	38550	11046L	PARTICIPANT	\N	PRESENT	0
38587	38550	01058X	PARTICIPANT	\N	PRESENT	0
38588	38550	11094U	PARTICIPANT	\N	PRESENT	0
38589	38550	11066Q	PARTICIPANT	\N	PRESENT	0
38753	32377	01046T	PARTICIPANT	\N	EXCUSE	0
38757	32377	80013X	PARTICIPANT	\N	EXCUSE	0
38755	32377	11036J	PARTICIPANT	\N	EXCUSE	0
38756	32377	14209N	PARTICIPANT	\N	EXCUSE	0
38758	32377	04061F	PARTICIPANT	\N	EXCUSE	0
38759	32377	01048V	PARTICIPANT	\N	EXCUSE	0
38760	32377	04043D	PARTICIPANT	\N	EXCUSE	0
40278	40277	14133K	PARTICIPANT	\N	PRESENT	0
40280	40277	96004D	PARTICIPANT	\N	EXCUSE	0
40281	40277	11040E	PARTICIPANT	\N	PRESENT	0
40282	40277	14089Y	PARTICIPANT	\N	PRESENT	0
40283	40277	90003B	PARTICIPANT	\N	EXCUSE	0
40284	40277	14079W	PARTICIPANT	\N	PRESENT	0
40285	40277	11083R	PARTICIPANT	\N	PRESENT	0
40286	40277	14026U	PARTICIPANT	\N	EXCUSE	0
40287	40277	14097Y	PARTICIPANT	\N	PRESENT	0
40288	40277	14001X	PARTICIPANT	\N	PRESENT	0
40289	40277	04057K	PRESIDENT	0	PRESENT	0
40290	40277	08042U	PARTICIPANT	\N	PRESENT	0
40291	40277	04080J	PARTICIPANT	\N	PRESENT	0
40292	40277	14135M	PARTICIPANT	\N	PRESENT	0
40293	40277	01016M	PARTICIPANT	\N	PRESENT	0
40294	40277	11012A	PARTICIPANT	\N	EXCUSE	0
40295	40277	98035U	PARTICIPANT	\N	PRESENT	0
40296	40277	92045V	PARTICIPANT	\N	EXCUSE	0
40309	40306	01031L	PRESIDENT	0	PRESENT	0
40312	40306	11068S	PARTICIPANT	\N	EXCUSE	0
40313	40306	11040E	PARTICIPANT	\N	PRESENT	0
40315	40306	14083S	PARTICIPANT	\N	PRESENT	0
40317	40306	11042G	PARTICIPANT	\N	PRESENT	0
40320	40306	88008L	PARTICIPANT	\N	PRESENT	0
40324	40306	04086Q	PARTICIPANT	\N	PRESENT	0
40326	40306	11070L	PARTICIPANT	\N	PRESENT	0
40328	40306	11088W	PARTICIPANT	\N	PRESENT	0
40329	40306	01027Q	PARTICIPANT	\N	PRESENT	0
40330	40306	04071H	PARTICIPANT	\N	PRESENT	0
40331	40306	11074Q	PARTICIPANT	\N	PRESENT	0
40332	40306	99004R	PARTICIPANT	\N	PRESENT	0
40336	40306	14159V	PARTICIPANT	\N	PRESENT	0
40338	40306	07029T	PARTICIPANT	\N	PRESENT	0
40340	40306	08034U	PARTICIPANT	\N	PRESENT	0
40343	40306	98046X	PARTICIPANT	\N	PRESENT	0
40344	40306	08011M	PARTICIPANT	\N	PRESENT	0
40346	40306	01016M	PARTICIPANT	\N	PRESENT	0
40415	40306	08061X	PARTICIPANT	\N	PRESENT	0
45808	44620	14209N	PARTICIPANT	\N	EXCUSE	0
46880	46822	98022P	PARTICIPANT	\N	PRESENT	0
45880	44248	14209N	PARTICIPANT	\N	PRESENT	0
45881	44248	01048V	PARTICIPANT	\N	PRESENT	0
46824	46822	04054G	PARTICIPANT	\N	PRESENT	0
46825	46822	04040A	PARTICIPANT	\N	EXCUSE	0
46883	46822	14133K	PARTICIPANT	\N	PRESENT	0
46884	46822	14026U	PARTICIPANT	\N	PRESENT	0
46885	46822	14249W	PARTICIPANT	\N	PRESENT	0
46886	46822	04045F	PARTICIPANT	\N	PRESENT	0
46888	46822	90003B	PARTICIPANT	\N	PRESENT	0
46889	46822	95063L	PARTICIPANT	\N	PRESENT	0
46832	46822	98018T	PARTICIPANT	\N	PRESENT	0
46833	46822	92018S	PARTICIPANT	\N	PRESENT	0
46890	46822	14073Q	PARTICIPANT	\N	PRESENT	0
46835	46822	95030B	PARTICIPANT	\N	PRESENT	0
46891	46822	11012A	PARTICIPANT	\N	PRESENT	0
46892	46822	14089Y	PARTICIPANT	\N	PRESENT	0
46893	46822	96004D	PARTICIPANT	\N	PRESENT	0
47266	47059	96004D	PRESIDENT	0	PRESENT	0
47267	47059	14089Y	PARTICIPANT	\N	PRESENT	0
46841	46822	07024N	PRESIDENT	0	PRESENT	0
47269	47059	90003B	PARTICIPANT	\N	PRESENT	0
46843	46822	14014Q	PARTICIPANT	\N	EXCUSE	0
47270	47059	14133K	PARTICIPANT	\N	PRESENT	0
47274	47059	14249W	PARTICIPANT	\N	PRESENT	0
46846	46822	95035G	PARTICIPANT	\N	PRESENT	0
47322	47059	04054G	PARTICIPANT	\N	PRESENT	0
47323	47059	95030B	PARTICIPANT	\N	PRESENT	0
47324	47059	11012A	PARTICIPANT	\N	PRESENT	0
47325	47059	04045F	PARTICIPANT	\N	PRESENT	0
47326	47059	92045V	PARTICIPANT	\N	PRESENT	0
46852	46822	04078Q	PARTICIPANT	\N	PRESENT	0
47327	47059	04057K	PARTICIPANT	\N	EXCUSE	0
47328	47059	14097Y	PARTICIPANT	\N	EXCUSE	0
46855	46822	04036E	PARTICIPANT	\N	PRESENT	0
47329	47059	08018U	PARTICIPANT	\N	EXCUSE	0
47337	47336	14133K	PARTICIPANT	\N	PRESENT	0
47338	47336	04054G	PARTICIPANT	\N	PRESENT	0
46859	46822	92031P	PARTICIPANT	\N	EXCUSE	0
47340	47336	96004D	PRESIDENT	0	PRESENT	0
47344	47336	14089Y	PARTICIPANT	\N	PRESENT	0
46862	46822	83042R	PARTICIPANT	\N	EXCUSE	0
47345	47336	90003B	PARTICIPANT	\N	PRESENT	0
47346	47336	14249W	PARTICIPANT	\N	PRESENT	0
47348	47336	95030B	PARTICIPANT	\N	PRESENT	0
47349	47336	08018U	PARTICIPANT	\N	EXCUSE	0
47350	47336	14097Y	PARTICIPANT	\N	EXCUSE	0
46868	46822	14028W	PARTICIPANT	\N	PRESENT	0
46869	46822	14193X	PARTICIPANT	\N	PRESENT	0
47351	47336	14073Q	PARTICIPANT	\N	PRESENT	0
47352	47336	04057K	PARTICIPANT	\N	EXCUSE	0
46872	46822	04080J	PARTICIPANT	\N	PRESENT	0
46873	46822	95059Q	PARTICIPANT	\N	EXCUSE	0
46874	46822	86044G	PARTICIPANT	\N	PRESENT	0
47353	47336	04080J	PARTICIPANT	\N	PRESENT	0
46876	46822	11054L	PARTICIPANT	\N	PRESENT	0
46877	46822	01056V	PARTICIPANT	\N	PRESENT	0
47354	47336	11012A	PARTICIPANT	\N	PRESENT	0
47355	47336	95063L	PARTICIPANT	\N	PRESENT	0
47356	47336	04045F	PARTICIPANT	\N	PRESENT	0
47357	47336	92045V	PARTICIPANT	\N	PRESENT	0
47359	47336	98018T	PARTICIPANT	\N	PRESENT	0
47360	47336	92018S	PARTICIPANT	\N	PRESENT	0
47361	47336	07024N	PARTICIPANT	\N	PRESENT	0
47362	47336	95035G	PARTICIPANT	\N	PRESENT	0
47363	47336	98022P	PARTICIPANT	\N	PRESENT	0
47364	47336	04078Q	PARTICIPANT	\N	PRESENT	0
47365	47336	04036E	PARTICIPANT	\N	PRESENT	0
47366	47336	14028W	PARTICIPANT	\N	PRESENT	0
47367	47336	14193X	PARTICIPANT	\N	PRESENT	0
53853	53773	10006L	PARTICIPANT	\N	PRESENT	0
53907	52314	14093U	PARTICIPANT	\N	PRESENT	0
53855	53773	14217N	PARTICIPANT	\N	PRESENT	0
53856	53773	14042U	PARTICIPANT	\N	PRESENT	0
53857	53773	14151M	PARTICIPANT	\N	PRESENT	0
53858	53773	12042Y	PARTICIPANT	\N	PRESENT	0
53906	52314	08009T	PARTICIPANT	\N	PRESENT	0
53908	52314	11090Q	PARTICIPANT	\N	PRESENT	0
53861	53773	01003G	PARTICIPANT	\N	EXCUSE	0
53910	52314	14033T	PARTICIPANT	\N	PRESENT	0
53863	53773	14231L	PARTICIPANT	\N	PRESENT	0
53864	53773	11061K	PARTICIPANT	\N	PRESENT	0
53865	53773	08048B	PARTICIPANT	\N	PRESENT	0
53866	53773	08041T	PARTICIPANT	\N	PRESENT	0
53867	53773	01011G	PARTICIPANT	\N	PRESENT	0
53868	53773	14026U	PARTICIPANT	\N	PRESENT	0
53869	53773	14213J	PARTICIPANT	\N	PRESENT	0
53870	53773	14121F	PARTICIPANT	\N	PRESENT	0
53871	53773	11112D	PARTICIPANT	\N	PRESENT	0
53872	53773	14037X	PARTICIPANT	\N	PRESENT	0
53873	53773	14018U	PARTICIPANT	\N	PRESENT	0
53874	53773	11067R	PARTICIPANT	\N	PRESENT	0
53875	53773	14223L	PARTICIPANT	\N	PRESENT	0
53876	53773	04092N	PRESIDENT	0	PRESENT	0
53877	53773	14265W	PARTICIPANT	\N	PRESENT	0
53878	53773	14119M	PARTICIPANT	\N	PRESENT	0
53921	52314	01057W	PARTICIPANT	\N	PRESENT	0
53880	53773	07032N	PARTICIPANT	\N	PRESENT	0
53925	52314	14215L	PARTICIPANT	\N	PRESENT	0
53882	53773	14271U	PARTICIPANT	\N	PRESENT	0
53883	53773	14017T	PARTICIPANT	\N	EXCUSE	0
53884	53773	11093T	PARTICIPANT	\N	PRESENT	0
53885	53773	11097X	PARTICIPANT	\N	PRESENT	0
53886	53773	04045F	PARTICIPANT	\N	PRESENT	0
53887	53773	14227Q	PARTICIPANT	\N	PRESENT	0
53888	53773	01034P	PARTICIPANT	\N	PRESENT	0
53927	52314	14235Q	PARTICIPANT	\N	PRESENT	0
53890	53773	11063M	PARTICIPANT	\N	PRESENT	0
53928	52314	14263U	PARTICIPANT	\N	PRESENT	0
53892	52314	14265W	PARTICIPANT	\N	PRESENT	0
53893	52314	14071N	PARTICIPANT	\N	PRESENT	0
53894	52314	14209N	PARTICIPANT	\N	PRESENT	0
53895	52314	11103C	PARTICIPANT	\N	PRESENT	0
53896	52314	11065P	PARTICIPANT	\N	PRESENT	0
53897	52314	01027Q	PARTICIPANT	\N	PRESENT	0
53898	52314	08025T	PARTICIPANT	\N	PRESENT	0
53899	52314	14207L	PARTICIPANT	\N	PRESENT	0
53900	52314	11023D	PARTICIPANT	\N	PRESENT	0
53901	52314	14039A	PARTICIPANT	\N	PRESENT	0
53902	52314	11109J	PARTICIPANT	\N	PRESENT	0
53903	52314	14107H	PARTICIPANT	\N	PRESENT	0
53904	52314	14237S	PARTICIPANT	\N	PRESENT	0
53905	52314	13002U	PARTICIPANT	\N	PRESENT	0
53909	52314	14157T	PARTICIPANT	\N	PRESENT	0
53913	52314	96004D	PARTICIPANT	\N	PRESENT	0
53934	52314	14089Y	PARTICIPANT	\N	PRESENT	0
53938	52314	14205J	PARTICIPANT	\N	PRESENT	0
53939	52314	14030Q	PARTICIPANT	\N	PRESENT	0
53940	52314	14221J	PARTICIPANT	\N	PRESENT	0
53941	52314	01022K	PARTICIPANT	\N	PRESENT	0
53942	52314	11011M	PARTICIPANT	\N	PRESENT	0
53943	52314	14028W	PARTICIPANT	\N	PRESENT	0
53944	52314	11111C	PARTICIPANT	\N	PRESENT	0
53945	52314	14261S	PARTICIPANT	\N	PRESENT	0
53946	52314	14073Q	PARTICIPANT	\N	PRESENT	0
53947	52314	11049P	PARTICIPANT	\N	PRESENT	0
53948	52314	14041T	PARTICIPANT	\N	PRESENT	0
53949	52314	14042U	PARTICIPANT	\N	PRESENT	0
53990	52314	14231L	PARTICIPANT	\N	PRESENT	0
53991	52314	11114F	PARTICIPANT	\N	PRESENT	0
53992	52314	11081P	PARTICIPANT	\N	PRESENT	0
53993	52314	04067M	PARTICIPANT	\N	PRESENT	0
53994	52314	14063N	PARTICIPANT	\N	PRESENT	0
53995	52314	14031R	PARTICIPANT	\N	PRESENT	0
53996	52314	11104D	PARTICIPANT	\N	PRESENT	0
53998	52314	14079W	PARTICIPANT	\N	PRESENT	0
53999	52314	14179A	PARTICIPANT	\N	PRESENT	0
54000	52314	14269B	PARTICIPANT	\N	PRESENT	0
54001	52314	08017T	PARTICIPANT	\N	PRESENT	0
54043	52314	05012A	PARTICIPANT	\N	PRESENT	0
54044	52314	14267Y	PARTICIPANT	\N	PRESENT	0
54045	52314	11012A	PARTICIPANT	\N	PRESENT	0
54046	52314	08062Y	PARTICIPANT	\N	PRESENT	0
54047	52314	97011G	PARTICIPANT	\N	PRESENT	0
54048	52314	09001P	PARTICIPANT	\N	PRESENT	0
54049	52314	01043Q	PARTICIPANT	\N	PRESENT	0
54050	52314	14147R	PARTICIPANT	\N	PRESENT	0
54051	52314	08010L	PARTICIPANT	\N	PRESENT	0
54052	52314	08015R	PARTICIPANT	\N	PRESENT	0
54053	52314	07032N	PARTICIPANT	\N	PRESENT	0
54054	52314	04045F	PARTICIPANT	\N	PRESENT	0
54055	52314	14109K	PARTICIPANT	\N	PRESENT	0
54056	52314	04043D	PARTICIPANT	\N	PRESENT	0
54057	49569	11063M	PARTICIPANT	\N	PRESENT	0
54058	52314	14169X	PARTICIPANT	\N	PRESENT	0
54063	52314	90003B	PARTICIPANT	\N	PRESENT	0
54069	52314	14331P	PARTICIPANT	\N	PRESENT	0
54070	52314	14026U	PARTICIPANT	\N	PRESENT	0
54071	52314	14069U	PARTICIPANT	\N	PRESENT	0
54072	52314	01048V	PARTICIPANT	\N	PRESENT	0
54073	52314	11100Y	PARTICIPANT	\N	PRESENT	0
54074	52314	14133K	PARTICIPANT	\N	PRESENT	0
54075	52314	14051J	PARTICIPANT	\N	PRESENT	0
54076	52314	01016M	PARTICIPANT	\N	PRESENT	0
54078	52314	08034U	PARTICIPANT	\N	PRESENT	0
54079	52314	11098Y	PARTICIPANT	\N	PRESENT	0
54080	52314	14037X	PARTICIPANT	\N	PRESENT	0
54083	52314	98023Q	PARTICIPANT	\N	PRESENT	0
54084	52314	04094Q	PARTICIPANT	\N	PRESENT	0
54085	52314	14159V	PARTICIPANT	\N	PRESENT	0
54086	52314	80013X	PARTICIPANT	\N	PRESENT	0
54087	52314	14193X	PARTICIPANT	\N	PRESENT	0
54088	52314	14273W	PARTICIPANT	\N	PRESENT	0
54089	52314	14199E	PARTICIPANT	\N	PRESENT	0
54090	52314	14219Q	PARTICIPANT	\N	PRESENT	0
54091	52314	08016S	PARTICIPANT	\N	PRESENT	0
54092	52314	14241N	PARTICIPANT	\N	PRESENT	0
54093	52314	14065Q	PARTICIPANT	\N	PRESENT	0
54094	52314	11042G	PARTICIPANT	\N	PRESENT	0
54095	52314	14257W	PARTICIPANT	\N	PRESENT	0
54096	52314	11015D	PARTICIPANT	\N	PRESENT	0
54097	52314	11036J	PARTICIPANT	\N	PRESENT	0
54098	52314	14135M	PARTICIPANT	\N	PRESENT	0
54099	52314	11097X	PARTICIPANT	\N	PRESENT	0
54100	52314	14217N	PARTICIPANT	\N	PRESENT	0
54101	52314	01008M	PARTICIPANT	\N	PRESENT	0
54102	52314	14083S	PARTICIPANT	\N	PRESENT	0
54103	52314	11056N	PARTICIPANT	\N	PRESENT	0
54104	52314	11067R	PARTICIPANT	\N	PRESENT	0
54105	52314	14197C	PARTICIPANT	\N	PRESENT	0
54107	52314	11105E	PARTICIPANT	\N	PRESENT	0
54108	52314	01019Q	PARTICIPANT	\N	PRESENT	0
54109	52314	14061L	PARTICIPANT	\N	PRESENT	0
54110	52314	14053L	PARTICIPANT	\N	PRESENT	0
54111	52314	11093T	PARTICIPANT	\N	PRESENT	0
54154	52314	11095V	PARTICIPANT	\N	PRESENT	0
54155	52314	14225N	PARTICIPANT	\N	PRESENT	0
54156	52314	10006L	PARTICIPANT	\N	PRESENT	0
54165	52314	08042U	PARTICIPANT	\N	PRESENT	0
54158	52314	95035G	PARTICIPANT	\N	PRESENT	0
54159	52314	89017R	PARTICIPANT	\N	PRESENT	0
54163	52314	11048N	PARTICIPANT	\N	PRESENT	0
54164	52314	04047H	PARTICIPANT	\N	PRESENT	0
54166	52314	92039X	PARTICIPANT	\N	PRESENT	0
54167	52314	04033B	PARTICIPANT	\N	PRESENT	0
54168	52314	11083R	PARTICIPANT	\N	PRESENT	0
54169	52314	14259Y	PARTICIPANT	\N	PRESENT	0
54170	52314	04049K	PARTICIPANT	\N	PRESENT	0
54171	52314	11084S	PARTICIPANT	\N	PRESENT	0
45697	45696	12042Y	PARTICIPANT	\N	PRESENT	0
45703	45702	12042Y	PARTICIPANT	\N	PRESENT	0
45706	45705	12042Y	PARTICIPANT	\N	PRESENT	0
47636	47635	11036J	PARTICIPANT	\N	PRESENT	0
47637	47635	14038Y	PARTICIPANT	\N	PRESENT	0
47638	47635	14193X	PARTICIPANT	\N	PRESENT	0
47639	47635	04088S	PARTICIPANT	\N	PRESENT	0
47640	47635	08009T	PARTICIPANT	\N	PRESENT	0
47641	47635	11046L	PARTICIPANT	\N	PRESENT	0
47642	47635	01058X	PARTICIPANT	\N	PRESENT	0
47643	47635	01028R	PARTICIPANT	\N	PRESENT	0
48637	48636	01008M	PARTICIPANT	\N	PRESENT	0
48638	48636	11036J	PARTICIPANT	\N	PRESENT	0
48639	48636	11081P	PARTICIPANT	\N	PRESENT	0
48676	48636	04054G	PARTICIPANT	\N	PRESENT	0
48641	48636	08068F	PARTICIPANT	\N	PRESENT	0
48642	48636	14207L	PARTICIPANT	\N	PRESENT	0
48677	48636	14089Y	PARTICIPANT	\N	PRESENT	0
48644	48636	90003B	PARTICIPANT	\N	EXCUSE	0
48645	48636	08028W	PARTICIPANT	\N	PRESENT	0
48646	48636	80013X	PARTICIPANT	\N	EXCUSE	0
48647	48636	08038Y	PARTICIPANT	\N	PRESENT	0
48648	48636	04089T	PARTICIPANT	\N	PRESENT	0
48649	48636	14197C	PARTICIPANT	\N	PRESENT	0
48650	48636	11110B	PARTICIPANT	\N	PRESENT	0
48651	48636	14187A	PARTICIPANT	\N	PRESENT	0
48652	48636	14033T	PARTICIPANT	\N	PRESENT	0
52601	51474	14087W	PARTICIPANT	\N	PRESENT	0
48654	48636	04048J	PARTICIPANT	\N	PRESENT	0
48655	48636	11099A	PARTICIPANT	\N	PRESENT	0
48656	48636	04049K	PARTICIPANT	\N	PRESENT	0
48657	48636	04094Q	PARTICIPANT	\N	PRESENT	0
48658	48636	11111C	PARTICIPANT	\N	PRESENT	0
52602	51474	14231L	PARTICIPANT	\N	PRESENT	0
48660	48636	11100Y	PRESIDENT	0	PRESENT	0
48661	48636	01061S	PARTICIPANT	\N	PRESENT	0
48662	48636	11098Y	PARTICIPANT	\N	PRESENT	0
52603	51474	11081P	PARTICIPANT	\N	PRESENT	0
48664	48636	11077T	PARTICIPANT	\N	PRESENT	0
48665	48636	14205J	PARTICIPANT	\N	PRESENT	0
48666	48636	08019V	PARTICIPANT	\N	EXCUSE	0
48667	48636	14257W	PARTICIPANT	\N	PRESENT	0
48668	48636	08021P	PARTICIPANT	\N	EXCUSE	0
48669	48636	04088S	PARTICIPANT	\N	PRESENT	0
52604	51474	08042U	PARTICIPANT	\N	PRESENT	0
48671	48636	11090Q	PARTICIPANT	\N	PRESENT	0
48672	48636	11046L	PARTICIPANT	\N	PRESENT	0
48673	48636	01058X	PARTICIPANT	\N	PRESENT	0
48674	48636	11094U	PARTICIPANT	\N	PRESENT	0
48675	48636	11066Q	PARTICIPANT	\N	PRESENT	0
52605	51474	14028W	PARTICIPANT	\N	PRESENT	0
52606	51474	04094Q	PARTICIPANT	\N	PRESENT	0
52607	51474	11109J	PARTICIPANT	\N	PRESENT	0
52608	51474	11023D	PARTICIPANT	\N	PRESENT	0
52609	51474	88008L	PARTICIPANT	\N	PRESENT	0
52610	51474	14013P	PARTICIPANT	\N	PRESENT	0
52611	51474	14038Y	PARTICIPANT	\N	PRESENT	0
52612	51474	08068F	PARTICIPANT	\N	PRESENT	0
52613	51474	14026U	PARTICIPANT	\N	PRESENT	0
52614	51474	14269B	PARTICIPANT	\N	PRESENT	0
52615	51474	05012A	PARTICIPANT	\N	PRESENT	0
52616	51474	11084S	PARTICIPANT	\N	PRESENT	0
52617	51474	11042G	PARTICIPANT	\N	PRESENT	0
52618	51474	95030B	PARTICIPANT	\N	PRESENT	0
52619	51474	14041T	PARTICIPANT	\N	PRESENT	0
52620	51474	01013J	PARTICIPANT	\N	PRESENT	0
52621	51474	80013X	PARTICIPANT	\N	PRESENT	0
52622	51474	14225N	PARTICIPANT	\N	PRESENT	0
52623	51474	14085U	PARTICIPANT	\N	PRESENT	0
52624	51474	01028R	PARTICIPANT	\N	PRESENT	0
52625	51474	14199E	PARTICIPANT	\N	PRESENT	0
52626	51474	11071M	PARTICIPANT	\N	PRESENT	0
52627	51474	11097X	PARTICIPANT	\N	PRESENT	0
52628	51474	14173T	PARTICIPANT	\N	PRESENT	0
52629	51474	11029K	PARTICIPANT	\N	PRESENT	0
52630	51474	11057P	PARTICIPANT	\N	PRESENT	0
52631	51474	14167V	PARTICIPANT	\N	PRESENT	0
52632	51474	11037K	PARTICIPANT	\N	PRESENT	0
52633	51474	01061S	PARTICIPANT	\N	PRESENT	0
52634	51474	14195A	PARTICIPANT	\N	PRESENT	0
52635	51474	08028W	PARTICIPANT	\N	PRESENT	0
52636	51474	14121F	PARTICIPANT	\N	PRESENT	0
52637	51474	14037X	PARTICIPANT	\N	PRESENT	0
52638	51474	07032N	PARTICIPANT	\N	PRESENT	0
52639	51474	98005N	PARTICIPANT	\N	PRESENT	0
52640	51474	14259Y	PARTICIPANT	\N	PRESENT	0
52641	51474	14215L	PARTICIPANT	\N	PRESENT	0
52642	51474	14241N	PARTICIPANT	\N	PRESENT	0
52643	51474	14267Y	PARTICIPANT	\N	PRESENT	0
52644	51474	11094U	PARTICIPANT	\N	PRESENT	0
52645	51474	11089X	PARTICIPANT	\N	PRESENT	0
52646	51474	01003G	PARTICIPANT	\N	PRESENT	0
52647	51474	14042U	PARTICIPANT	\N	PRESENT	0
52648	51474	04045F	PARTICIPANT	\N	PRESENT	0
52649	51474	14251Q	PARTICIPANT	\N	PRESENT	0
52650	51474	01046T	PARTICIPANT	\N	PRESENT	0
52651	51474	11036J	PARTICIPANT	\N	PRESENT	0
52652	51474	01060R	PARTICIPANT	\N	PRESENT	0
52653	51474	01048V	PARTICIPANT	\N	PRESENT	0
52654	51474	89029V	PARTICIPANT	\N	PRESENT	0
52655	51474	04092N	PARTICIPANT	\N	PRESENT	0
52656	51474	08053X	PARTICIPANT	\N	PRESENT	0
52657	51474	11098Y	PARTICIPANT	\N	PRESENT	0
52658	51474	95015C	PARTICIPANT	\N	PRESENT	0
52659	51474	14059S	PARTICIPANT	\N	PRESENT	0
52660	51474	14227Q	PARTICIPANT	\N	PRESENT	0
52661	51474	99004R	PARTICIPANT	\N	PRESENT	0
52662	51474	08025T	PARTICIPANT	\N	PRESENT	0
52663	51474	04049K	PARTICIPANT	\N	PRESENT	0
52664	51474	01016M	PARTICIPANT	\N	PRESENT	0
52665	51474	08038Y	PARTICIPANT	\N	PRESENT	0
52666	51474	01037S	PARTICIPANT	\N	PRESENT	0
52667	51474	11106F	PARTICIPANT	\N	PRESENT	0
52668	51474	92018S	PARTICIPANT	\N	PRESENT	0
52669	51474	07026Q	PARTICIPANT	\N	PRESENT	0
52670	51474	12041X	PARTICIPANT	\N	PRESENT	0
52671	51474	98053W	PARTICIPANT	\N	PRESENT	0
52672	51474	83047W	PARTICIPANT	\N	PRESENT	0
52673	51474	14253S	PARTICIPANT	\N	PRESENT	0
52674	51474	01019Q	PARTICIPANT	\N	PRESENT	0
52675	51474	98035U	PARTICIPANT	\N	PRESENT	0
52676	51474	04097T	PARTICIPANT	\N	PRESENT	0
52677	51474	04056J	PARTICIPANT	\N	PRESENT	0
52678	51474	11039M	PARTICIPANT	\N	PRESENT	0
52679	51474	14187A	PARTICIPANT	\N	PRESENT	0
52680	51474	08012N	PARTICIPANT	\N	PRESENT	0
52681	51474	08052W	PARTICIPANT	\N	PRESENT	0
52682	51474	01008M	PARTICIPANT	\N	PRESENT	0
52683	51474	05004A	PARTICIPANT	\N	PRESENT	0
52684	51474	04081K	PARTICIPANT	\N	PRESENT	0
53318	52279	11090Q	PARTICIPANT	\N	PRESENT	0
53319	52279	08009T	PARTICIPANT	\N	PRESENT	0
53320	52279	80013X	PARTICIPANT	\N	PRESENT	0
53321	52279	01044R	PARTICIPANT	\N	PRESENT	0
53322	52279	11064N	PARTICIPANT	\N	PRESENT	0
53323	52279	11109J	PARTICIPANT	\N	PRESENT	0
53324	52279	11049P	PARTICIPANT	\N	PRESENT	0
53325	52279	01015L	PARTICIPANT	\N	PRESENT	0
53326	52279	14235Q	PARTICIPANT	\N	PRESENT	0
53327	52279	11098Y	PARTICIPANT	\N	PRESENT	0
53328	52279	08060W	PARTICIPANT	\N	PRESENT	0
53329	52279	08055A	PARTICIPANT	\N	PRESENT	0
53330	52279	92015P	PARTICIPANT	\N	PRESENT	0
53331	52279	14097Y	PARTICIPANT	\N	PRESENT	0
53332	52279	11107G	PARTICIPANT	\N	PRESENT	0
53333	52279	13002U	PARTICIPANT	\N	PRESENT	0
53334	52279	11029K	PARTICIPANT	\N	PRESENT	0
53335	52279	11099A	PARTICIPANT	\N	PRESENT	0
53336	52279	08049C	PARTICIPANT	\N	PRESENT	0
53337	52279	11065P	PARTICIPANT	\N	PRESENT	0
53338	52279	80027E	PARTICIPANT	\N	PRESENT	0
53339	52279	14051J	PARTICIPANT	\N	PRESENT	0
53340	52279	04089T	PARTICIPANT	\N	PRESENT	0
53341	52279	14079W	PARTICIPANT	\N	PRESENT	0
53342	52279	14237S	PARTICIPANT	\N	PRESENT	0
53343	52279	14215L	PARTICIPANT	\N	PRESENT	0
53344	52279	01008M	PARTICIPANT	\N	PRESENT	0
53345	52279	14217N	PARTICIPANT	\N	PRESENT	0
53346	52279	14199E	PARTICIPANT	\N	PRESENT	0
53347	52279	14331P	PARTICIPANT	\N	PRESENT	0
53348	52279	11103C	PARTICIPANT	\N	PRESENT	0
53349	52279	08042U	PARTICIPANT	\N	PRESENT	0
53350	52279	14026U	PARTICIPANT	\N	PRESENT	0
53351	52279	14265W	PARTICIPANT	\N	PRESENT	0
53352	52279	04049K	PARTICIPANT	\N	PRESENT	0
53353	52279	08015R	PARTICIPANT	\N	PRESENT	0
53354	52279	14213J	PARTICIPANT	\N	PRESENT	0
53355	52279	11097X	PARTICIPANT	\N	PRESENT	0
53356	52279	14033T	PARTICIPANT	\N	PRESENT	0
53357	52279	04088S	PARTICIPANT	\N	PRESENT	0
53358	52279	14157T	PARTICIPANT	\N	PRESENT	0
53359	52279	98023Q	PARTICIPANT	\N	PRESENT	0
53360	52279	01022K	PARTICIPANT	\N	PRESENT	0
53361	52279	14103D	PARTICIPANT	\N	PRESENT	0
53362	52279	11105E	PARTICIPANT	\N	PRESENT	0
53363	52279	14261S	PARTICIPANT	\N	PRESENT	0
53364	52279	11012A	PARTICIPANT	\N	PRESENT	0
53365	52279	14135M	PARTICIPANT	\N	PRESENT	0
53366	52279	11114F	PARTICIPANT	\N	PRESENT	0
53367	52279	14259Y	PARTICIPANT	\N	PRESENT	0
53368	52279	11023D	PARTICIPANT	\N	PRESENT	0
53369	52279	01031L	PARTICIPANT	\N	PRESENT	0
53370	52279	92045V	PARTICIPANT	\N	PRESENT	0
53316	52279	11085T	PARTICIPANT	\N	PRESENT	0
53317	52279	14093U	PARTICIPANT	\N	PRESENT	0
53371	52279	14107H	PARTICIPANT	\N	PRESENT	0
53372	52279	14205J	PARTICIPANT	\N	PRESENT	0
53373	52279	14119M	PARTICIPANT	\N	PRESENT	0
53374	52279	05012A	PARTICIPANT	\N	PRESENT	0
53375	52279	08062Y	PARTICIPANT	\N	PRESENT	0
53376	52279	04045F	PARTICIPANT	\N	PRESENT	0
53377	52279	14169X	PARTICIPANT	\N	PRESENT	0
53378	52279	95030B	PARTICIPANT	\N	PRESENT	0
53379	52279	08038Y	PARTICIPANT	\N	PRESENT	0
53380	52279	14030Q	PARTICIPANT	\N	PRESENT	0
53381	52279	14059S	PARTICIPANT	\N	PRESENT	0
53382	52279	14133K	PARTICIPANT	\N	PRESENT	0
53383	52279	14105F	PARTICIPANT	\N	PRESENT	0
53384	52279	14031R	PARTICIPANT	\N	PRESENT	0
53385	52279	14159V	PARTICIPANT	\N	PRESENT	0
53386	52279	14147R	PARTICIPANT	\N	PRESENT	0
53387	52279	11056N	PARTICIPANT	\N	PRESENT	0
53388	52279	14219Q	PARTICIPANT	\N	PRESENT	0
53389	52279	14061L	PARTICIPANT	\N	PRESENT	0
53390	52279	14089Y	PARTICIPANT	\N	PRESENT	0
53391	52279	92039X	PARTICIPANT	\N	PRESENT	0
53392	52279	14257W	PARTICIPANT	\N	PRESENT	0
53393	52279	14197C	PARTICIPANT	\N	PRESENT	0
53394	52279	01043Q	PARTICIPANT	\N	PRESENT	0
53395	52279	14207L	PARTICIPANT	\N	PRESENT	0
53396	52279	04033B	PARTICIPANT	\N	PRESENT	0
53397	52279	14255U	PARTICIPANT	\N	PRESENT	0
53398	52279	11036J	PARTICIPANT	\N	PRESENT	0
53399	52279	11059R	PARTICIPANT	\N	PRESENT	0
53400	52279	14034U	PARTICIPANT	\N	PRESENT	0
53401	52279	14038Y	PARTICIPANT	\N	PRESENT	0
53402	52279	14123H	PARTICIPANT	\N	PRESENT	0
53412	49835	01022K	PARTICIPANT	\N	EXCUSE	0
54113	49959	96004D	PARTICIPANT	\N	EXCUSE	0
54370	54369	11036J	PARTICIPANT	\N	PRESENT	0
54415	54414	14133K	PARTICIPANT	\N	PRESENT	0
54372	54369	04054G	PARTICIPANT	\N	PRESENT	0
54373	54369	14013P	PARTICIPANT	\N	PRESENT	0
54374	54369	14083S	PARTICIPANT	\N	PRESENT	0
54375	54369	90003B	PARTICIPANT	\N	PRESENT	0
54376	54369	14038Y	PARTICIPANT	\N	PRESENT	0
54377	54369	80013X	PARTICIPANT	\N	PRESENT	0
54378	54369	14079W	PARTICIPANT	\N	PRESENT	0
54416	54414	96004D	PRESIDENT	0	PRESENT	0
54417	54414	11040E	PARTICIPANT	\N	PRESENT	0
54418	54414	14089Y	PARTICIPANT	\N	PRESENT	0
54419	54414	14079W	PARTICIPANT	\N	PRESENT	0
54420	54414	11035H	PARTICIPANT	\N	PRESENT	0
54421	54414	14249W	PARTICIPANT	\N	PRESENT	0
54422	54414	04035D	PARTICIPANT	\N	EXCUSE	0
54423	54414	11083R	PARTICIPANT	\N	PRESENT	0
54424	54414	14097Y	PARTICIPANT	\N	PRESENT	0
54425	54414	14073Q	PARTICIPANT	\N	PRESENT	0
54426	54414	01016M	PARTICIPANT	\N	PRESENT	0
54390	54369	14033T	PARTICIPANT	\N	PRESENT	0
54391	54369	08016S	PARTICIPANT	\N	PRESENT	0
54427	54414	11012A	PARTICIPANT	\N	EXCUSE	0
54429	54414	04045F	PARTICIPANT	\N	PRESENT	0
54430	54414	98035U	PARTICIPANT	\N	PRESENT	0
54431	54414	04034C	PARTICIPANT	\N	EXCUSE	0
54434	54414	04057K	PARTICIPANT	\N	EXCUSE	0
54478	54477	14087W	PARTICIPANT	\N	PRESENT	0
54398	54369	11100Y	PARTICIPANT	\N	PRESENT	0
54399	54369	14257W	PARTICIPANT	\N	PRESENT	0
54482	49835	14261S	PARTICIPANT	\N	PRESENT	0
54484	49835	11023D	PARTICIPANT	\N	EXCUSE	0
54485	49835	14259Y	PARTICIPANT	\N	PRESENT	0
54403	54369	04088S	PARTICIPANT	\N	PRESENT	0
54486	49835	11113E	PARTICIPANT	\N	PRESENT	0
54487	49835	01027Q	PARTICIPANT	\N	PRESENT	0
54489	49835	14097Y	PARTICIPANT	\N	PRESENT	0
54407	54369	01016M	PARTICIPANT	\N	PRESENT	0
54490	49835	14039A	PARTICIPANT	\N	PRESENT	0
54409	54369	14271U	PARTICIPANT	\N	PRESENT	0
54410	54369	01058X	PARTICIPANT	\N	PRESENT	0
54491	49835	04094Q	PARTICIPANT	\N	PRESENT	0
54412	54369	92045V	PARTICIPANT	\N	PRESENT	0
54413	54369	95067Q	PARTICIPANT	\N	PRESENT	0
54492	49835	98005N	PARTICIPANT	\N	PRESENT	0
54493	49835	08019V	PARTICIPANT	\N	EXCUSE	0
54494	49835	11072N	PRESIDENT	0	PRESENT	0
54495	49835	04043D	PARTICIPANT	\N	PRESENT	0
54496	49835	11071M	PARTICIPANT	\N	PRESENT	0
54497	49835	14275Y	PARTICIPANT	\N	PRESENT	0
54498	49835	11011M	PARTICIPANT	\N	PRESENT	0
54499	54414	98046X	PARTICIPANT	\N	EXCUSE	0
54502	54501	01007L	PARTICIPANT	\N	PRESENT	0
54503	54501	11039M	PARTICIPANT	\N	PRESENT	0
54504	54501	04088S	PARTICIPANT	\N	PRESENT	0
54510	54509	04074L	PARTICIPANT	\N	PRESENT	0
54575	54572	14093U	PARTICIPANT	\N	PRESENT	0
54576	54572	14030Q	PARTICIPANT	\N	PRESENT	0
54577	54572	96004D	PARTICIPANT	\N	PRESENT	0
54579	54572	11095V	PARTICIPANT	\N	PRESENT	0
54583	54572	11065P	PARTICIPANT	\N	PRESENT	0
54585	54572	11107G	PARTICIPANT	\N	PRESENT	0
54588	54572	01022K	PARTICIPANT	\N	PRESENT	0
54590	54572	09001P	PARTICIPANT	\N	EXCUSE	0
54593	54572	80027E	PARTICIPANT	\N	PRESENT	0
54594	54572	14031R	PARTICIPANT	\N	EXCUSE	0
54595	54572	08009T	PRESIDENT	0	PRESENT	0
54596	54572	08062Y	PARTICIPANT	\N	EXCUSE	0
31679	28401	08021P	PARTICIPANT	\N	PRESENT	0
33042	33041	01061S	PARTICIPANT	\N	PRESENT	0
36523	36521	14263U	PARTICIPANT	\N	PRESENT	0
36524	36521	14133K	PARTICIPANT	\N	PRESENT	0
36525	36521	11109J	PARTICIPANT	\N	PRESENT	0
36526	36521	04059M	PARTICIPANT	\N	PRESENT	0
36527	36521	11039M	PARTICIPANT	\N	PRESENT	0
36528	36521	01044R	PARTICIPANT	\N	PRESENT	0
36529	36521	08043V	PARTICIPANT	\N	PRESENT	0
37059	37057	11031D	PARTICIPANT	\N	PRESENT	0
36531	36521	14105F	PARTICIPANT	\N	PRESENT	0
36532	36521	11029K	PARTICIPANT	\N	PRESENT	0
36533	36521	95015C	PARTICIPANT	\N	PRESENT	0
37060	37057	14039A	PARTICIPANT	\N	PRESENT	0
36535	36521	08024S	PARTICIPANT	\N	PRESENT	0
36536	36521	14201E	PARTICIPANT	\N	PRESENT	0
36537	36521	14329V	PARTICIPANT	\N	PRESENT	0
36538	36521	14209N	PARTICIPANT	\N	PRESENT	0
37061	37057	08073C	PARTICIPANT	\N	PRESENT	0
36540	36521	11091R	PARTICIPANT	\N	PRESENT	0
36541	36521	87003B	PARTICIPANT	\N	PRESENT	0
36542	36521	98042T	PARTICIPANT	\N	PRESENT	0
36543	36521	14249W	PARTICIPANT	\N	PRESENT	0
36544	36521	01041N	PARTICIPANT	\N	PRESENT	0
36545	36521	01025N	PARTICIPANT	\N	PRESENT	0
37062	37057	01019Q	PARTICIPANT	\N	PRESENT	0
36547	36521	89029V	PARTICIPANT	\N	PRESENT	0
36548	36521	08035V	PARTICIPANT	\N	PRESENT	0
36549	36521	11089X	PARTICIPANT	\N	PRESENT	0
36550	36521	07026Q	PARTICIPANT	\N	PRESENT	0
36551	36521	14123H	PARTICIPANT	\N	PRESENT	0
37063	37057	14061L	PARTICIPANT	\N	PRESENT	0
37064	37057	14169X	PARTICIPANT	\N	PRESENT	0
36554	36521	14241N	PARTICIPANT	\N	PRESENT	0
36555	36521	14061L	PARTICIPANT	\N	PRESENT	0
37065	37057	05012A	PARTICIPANT	\N	PRESENT	0
36557	36521	08031R	PARTICIPANT	\N	PRESENT	0
37597	37373	07024N	PARTICIPANT	\N	PRESENT	0
36559	36521	08039A	PARTICIPANT	\N	PRESENT	0
36560	36521	08017T	PARTICIPANT	\N	PRESENT	0
36561	36521	14059S	PARTICIPANT	\N	PRESENT	0
36562	36521	08012N	PARTICIPANT	\N	PRESENT	0
36563	36521	14103D	PARTICIPANT	\N	PRESENT	0
36564	36521	11104D	PARTICIPANT	\N	PRESENT	0
36565	36521	14063N	PARTICIPANT	\N	PRESENT	0
36566	36521	04057K	PARTICIPANT	\N	PRESENT	0
37598	37373	11074Q	PARTICIPANT	\N	PRESENT	0
36568	36521	14109K	PARTICIPANT	\N	PRESENT	0
36569	36521	04070G	PRESIDENT	0	PRESENT	0
36570	36521	92040Q	PARTICIPANT	\N	PRESENT	0
37599	37373	04042C	PARTICIPANT	\N	PRESENT	0
37600	37373	01013J	PARTICIPANT	\N	PRESENT	0
36573	36521	14235Q	PARTICIPANT	\N	PRESENT	0
36574	36521	14055N	PARTICIPANT	\N	PRESENT	0
37603	37373	11043H	PARTICIPANT	\N	PRESENT	0
36576	36521	14229S	PARTICIPANT	\N	PRESENT	0
36577	36521	11043H	PARTICIPANT	\N	PRESENT	0
36578	36521	11071M	PARTICIPANT	\N	PRESENT	0
37604	37373	98005N	PARTICIPANT	\N	PRESENT	0
37607	37373	08069G	PARTICIPANT	\N	PRESENT	0
37623	37373	11026G	PARTICIPANT	\N	PRESENT	0
37798	37375	11085T	PARTICIPANT	\N	PRESENT	0
37628	37373	11053K	PARTICIPANT	\N	PRESENT	0
37799	37375	08011M	PARTICIPANT	\N	PRESENT	0
37800	37375	01031L	PARTICIPANT	\N	PRESENT	0
37801	37375	04034C	PARTICIPANT	\N	PRESENT	0
37802	37375	98046X	PARTICIPANT	\N	PRESENT	0
37803	37375	08052W	PARTICIPANT	\N	PRESENT	0
37804	37375	14081Q	PARTICIPANT	\N	PRESENT	0
37805	37375	11023D	PARTICIPANT	\N	PRESENT	0
37806	37375	14159V	PARTICIPANT	\N	PRESENT	0
37807	37375	11083R	PARTICIPANT	\N	PRESENT	0
37808	37375	98053W	PARTICIPANT	\N	PRESENT	0
37809	37375	01013J	PARTICIPANT	\N	PRESENT	0
37810	37375	11070L	PARTICIPANT	\N	PRESENT	0
37811	37375	11012A	PARTICIPANT	\N	PRESENT	0
37812	37375	14041T	PARTICIPANT	\N	PRESENT	0
37813	37375	08069G	PARTICIPANT	\N	PRESENT	0
37814	37375	14175V	PARTICIPANT	\N	PRESENT	0
37815	37375	04086Q	PARTICIPANT	\N	PRESENT	0
37816	37375	14069U	PARTICIPANT	\N	PRESENT	0
37817	37375	11074Q	PARTICIPANT	\N	PRESENT	0
37818	37375	11036J	PARTICIPANT	\N	PRESENT	0
37819	37375	01027Q	PARTICIPANT	\N	PRESENT	0
37820	37375	99004R	PARTICIPANT	\N	PRESENT	0
37821	37375	14107H	PARTICIPANT	\N	PRESENT	0
37822	37375	11042G	PARTICIPANT	\N	PRESENT	0
37823	37375	14225N	PARTICIPANT	\N	PRESENT	0
37824	37375	01016M	PARTICIPANT	\N	PRESENT	0
37825	37375	11053K	PARTICIPANT	\N	PRESENT	0
37826	37375	14051J	PARTICIPANT	\N	PRESENT	0
37827	37375	01037S	PARTICIPANT	\N	PRESENT	0
37828	37375	14207L	PARTICIPANT	\N	PRESENT	0
37829	37375	08016S	PARTICIPANT	\N	PRESENT	0
37830	37375	11113E	PARTICIPANT	\N	PRESENT	0
37831	37375	11109J	PARTICIPANT	\N	PRESENT	0
37832	37375	14085U	PARTICIPANT	\N	PRESENT	0
37833	37375	14277B	PARTICIPANT	\N	PRESENT	0
37834	37375	14275Y	PARTICIPANT	\N	PRESENT	0
37835	37375	04071H	PARTICIPANT	\N	PRESENT	0
37836	37375	07004J	PARTICIPANT	\N	PRESENT	0
37837	37375	07029T	PARTICIPANT	\N	PRESENT	0
37838	37375	14119M	PARTICIPANT	\N	PRESENT	0
37839	37375	11077T	PARTICIPANT	\N	PRESENT	0
37840	37375	08019V	PARTICIPANT	\N	PRESENT	0
37841	37375	14083S	PARTICIPANT	\N	PRESENT	0
42635	41832	95035G	PARTICIPANT	\N	PRESENT	0
42636	41832	11048N	PARTICIPANT	\N	PRESENT	0
42637	41832	14213J	PARTICIPANT	\N	PRESENT	0
42638	41832	01022K	PARTICIPANT	\N	PRESENT	0
42639	41832	08055A	PARTICIPANT	\N	PRESENT	0
42640	41832	08025T	PARTICIPANT	\N	PRESENT	0
42641	41832	01003G	PARTICIPANT	\N	PRESENT	0
42642	41832	11088W	PARTICIPANT	\N	PRESENT	0
42643	41832	14030Q	PARTICIPANT	\N	PRESENT	0
42644	41832	80013X	PARTICIPANT	\N	PRESENT	0
42645	41832	11043H	PARTICIPANT	\N	PRESENT	0
42646	41832	11097X	PARTICIPANT	\N	PRESENT	0
42647	41832	87003B	PARTICIPANT	\N	PRESENT	0
42650	41832	98035U	PARTICIPANT	\N	PRESENT	0
42651	41832	11012A	PARTICIPANT	\N	PRESENT	0
42653	41832	04088S	PARTICIPANT	\N	PRESENT	0
42657	41832	11066Q	PARTICIPANT	\N	PRESENT	0
42658	41832	89017R	PARTICIPANT	\N	PRESENT	0
42659	41832	14187A	PARTICIPANT	\N	PRESENT	0
42660	41832	11099A	PARTICIPANT	\N	PRESENT	0
42661	41832	14199E	PARTICIPANT	\N	PRESENT	0
42662	41832	99004R	PARTICIPANT	\N	PRESENT	0
42663	41832	08069G	PARTICIPANT	\N	PRESENT	0
42664	41832	11101A	PARTICIPANT	\N	PRESENT	0
42665	41832	01008M	PARTICIPANT	\N	PRESENT	0
42706	41832	08062Y	PARTICIPANT	\N	PRESENT	0
42707	41832	01007L	PARTICIPANT	\N	PRESENT	0
42713	41832	08024S	PARTICIPANT	\N	PRESENT	0
42714	41832	14033T	PARTICIPANT	\N	PRESENT	0
42846	41833	01007L	PARTICIPANT	\N	PRESENT	0
42847	41833	01028R	PARTICIPANT	\N	PRESENT	0
42848	41833	01031L	PARTICIPANT	\N	PRESENT	0
42849	41833	01016M	PARTICIPANT	\N	PRESENT	0
42850	41833	11042G	PARTICIPANT	\N	PRESENT	0
42851	41833	11057P	PARTICIPANT	\N	PRESENT	0
42852	41833	11035H	PARTICIPANT	\N	PRESENT	0
42853	41833	08025T	PARTICIPANT	\N	PRESENT	0
42854	41833	11083R	PARTICIPANT	\N	PRESENT	0
42855	41833	01003G	PARTICIPANT	\N	PRESENT	0
42856	41833	01024M	PARTICIPANT	\N	PRESENT	0
42857	41833	95049N	PARTICIPANT	\N	PRESENT	0
42858	41833	14231L	PARTICIPANT	\N	PRESENT	0
42859	41833	14041T	PARTICIPANT	\N	PRESENT	0
42860	41833	08018U	PARTICIPANT	\N	PRESENT	0
42861	41833	14033T	PARTICIPANT	\N	PRESENT	0
42862	41833	08062Y	PARTICIPANT	\N	PRESENT	0
42863	41833	07029T	PARTICIPANT	\N	PRESENT	0
42864	41833	01057W	PARTICIPANT	\N	PRESENT	0
42865	41833	14187A	PARTICIPANT	\N	PRESENT	0
42866	41833	14265W	PARTICIPANT	\N	PRESENT	0
42868	41833	14135M	PARTICIPANT	\N	PRESENT	0
42869	41833	95062K	PARTICIPANT	\N	PRESENT	0
42870	41833	11012A	PARTICIPANT	\N	PRESENT	0
42928	41833	14083S	PARTICIPANT	\N	PRESENT	0
42929	41833	01043Q	PARTICIPANT	\N	PRESENT	0
42930	41833	14179A	PARTICIPANT	\N	PRESENT	0
42934	41834	11035H	PARTICIPANT	\N	PRESENT	0
42932	41834	08055A	PARTICIPANT	\N	PRESENT	0
42933	41834	92015P	PARTICIPANT	\N	PRESENT	0
42935	41834	11083R	PARTICIPANT	\N	PRESENT	0
42936	41834	11107G	PARTICIPANT	\N	PRESENT	0
42937	41834	14063N	PARTICIPANT	\N	PRESENT	0
54258	52315	08009T	PARTICIPANT	\N	PRESENT	0
54259	52315	11090Q	PARTICIPANT	\N	PRESENT	0
54260	52315	80027E	PARTICIPANT	\N	PRESENT	0
54261	52315	14197C	PARTICIPANT	\N	PRESENT	0
54262	52315	14107H	PARTICIPANT	\N	PRESENT	0
54263	52315	14051J	PARTICIPANT	\N	PRESENT	0
54264	52315	01022K	PARTICIPANT	\N	PRESENT	0
54265	52315	13002U	PARTICIPANT	\N	PRESENT	0
54266	52315	08060W	PARTICIPANT	\N	PRESENT	0
54267	52315	14207L	PARTICIPANT	\N	PRESENT	0
54268	52315	08061X	PARTICIPANT	\N	PRESENT	0
54269	52315	11107G	PARTICIPANT	\N	PRESENT	0
54270	52315	11099A	PARTICIPANT	\N	PRESENT	0
54271	52315	01044R	PARTICIPANT	\N	PRESENT	0
54272	52315	11065P	PARTICIPANT	\N	PRESENT	0
54273	52315	14030Q	PARTICIPANT	\N	PRESENT	0
54274	52315	14089Y	PARTICIPANT	\N	PRESENT	0
54275	52315	04089T	PARTICIPANT	\N	PRESENT	0
54276	52315	14079W	PARTICIPANT	\N	PRESENT	0
54277	52315	14053L	PARTICIPANT	\N	PRESENT	0
54278	52315	11048N	PARTICIPANT	\N	PRESENT	0
54279	52315	14038Y	PARTICIPANT	\N	PRESENT	0
54280	52315	14215L	PARTICIPANT	\N	PRESENT	0
54281	52315	04033B	PARTICIPANT	\N	PRESENT	0
54282	52315	14257W	PARTICIPANT	\N	PRESENT	0
54283	52315	14331P	PARTICIPANT	\N	PRESENT	0
54284	52315	14033T	PARTICIPANT	\N	PRESENT	0
54285	52315	11109J	PARTICIPANT	\N	PRESENT	0
54286	52315	14159V	PARTICIPANT	\N	PRESENT	0
54287	52315	11098Y	PARTICIPANT	\N	PRESENT	0
54288	52315	11056N	PARTICIPANT	\N	PRESENT	0
54289	52315	01015L	PARTICIPANT	\N	PRESENT	0
54290	52315	14097Y	PARTICIPANT	\N	PRESENT	0
54291	52315	14135M	PARTICIPANT	\N	PRESENT	0
54292	52315	14193X	PARTICIPANT	\N	PRESENT	0
54293	52315	95049N	PARTICIPANT	\N	PRESENT	0
54294	52315	14205J	PARTICIPANT	\N	PRESENT	0
54295	52315	04040A	PARTICIPANT	\N	PRESENT	0
54296	52315	04045F	PARTICIPANT	\N	PRESENT	0
54297	52315	11103C	PARTICIPANT	\N	PRESENT	0
54298	52315	11049P	PARTICIPANT	\N	PRESENT	0
54299	52315	14265W	PARTICIPANT	\N	PRESENT	0
54300	52315	10006L	PARTICIPANT	\N	PRESENT	0
54301	52315	04088S	PARTICIPANT	\N	PRESENT	0
54302	52315	14042U	PARTICIPANT	\N	PRESENT	0
54303	52315	92045V	PARTICIPANT	\N	PRESENT	0
54304	52315	92039X	PARTICIPANT	\N	PRESENT	0
54305	52315	14169X	PARTICIPANT	\N	PRESENT	0
54306	52315	14249W	PARTICIPANT	\N	PRESENT	0
54307	52315	14237S	PARTICIPANT	\N	PRESENT	0
54308	52315	14179A	PARTICIPANT	\N	PRESENT	0
54309	52315	14267Y	PARTICIPANT	\N	PRESENT	0
54310	52315	01057W	PARTICIPANT	\N	PRESENT	0
54311	52315	14083S	PARTICIPANT	\N	PRESENT	0
54312	52315	98023Q	PARTICIPANT	\N	PRESENT	0
54313	52315	14219Q	PARTICIPANT	\N	PRESENT	0
54314	52315	04038G	PARTICIPANT	\N	PRESENT	0
54315	52315	05012A	PARTICIPANT	\N	PRESENT	0
54316	52315	14073Q	PARTICIPANT	\N	PRESENT	0
54317	52315	14157T	PARTICIPANT	\N	PRESENT	0
54318	52315	80013X	PARTICIPANT	\N	PRESENT	0
54319	52315	14261S	PARTICIPANT	\N	PRESENT	0
54320	52315	08051V	PARTICIPANT	\N	PRESENT	0
54321	52315	11012A	PARTICIPANT	\N	PRESENT	0
54322	52315	11114F	PARTICIPANT	\N	PRESENT	0
54432	54160	07026Q	PARTICIPANT	\N	PRESENT	0
54433	54160	08009T	PARTICIPANT	\N	PRESENT	0
54435	54160	14093U	PARTICIPANT	\N	PRESENT	0
54256	52315	04066L	PARTICIPANT	\N	PRESENT	0
54257	52315	14093U	PARTICIPANT	\N	PRESENT	0
54436	54160	01022K	PARTICIPANT	\N	PRESENT	0
54437	54160	14051J	PARTICIPANT	\N	PRESENT	0
54438	54160	80027E	PARTICIPANT	\N	PRESENT	0
54439	54160	14063N	PARTICIPANT	\N	PRESENT	0
54440	54160	01031L	PARTICIPANT	\N	PRESENT	0
54441	54160	14207L	PARTICIPANT	\N	PRESENT	0
54442	54160	14107H	PARTICIPANT	\N	PRESENT	0
54443	54160	14159V	PARTICIPANT	\N	PRESENT	0
54444	54160	08060W	PARTICIPANT	\N	PRESENT	0
54445	54160	13002U	PARTICIPANT	\N	PRESENT	0
54446	54160	08055A	PARTICIPANT	\N	PRESENT	0
54447	54160	11114F	PARTICIPANT	\N	PRESENT	0
54448	54160	14039A	PARTICIPANT	\N	PRESENT	0
54449	54160	04045F	PARTICIPANT	\N	PRESENT	0
54450	54160	11107G	PARTICIPANT	\N	PRESENT	0
54451	54160	11099A	PARTICIPANT	\N	PRESENT	0
54452	54160	01044R	PARTICIPANT	\N	PRESENT	0
54453	54160	14030Q	PARTICIPANT	\N	PRESENT	0
54454	54160	04089T	PARTICIPANT	\N	PRESENT	0
54455	54160	14103D	PARTICIPANT	\N	PRESENT	0
54456	54160	11012A	PARTICIPANT	\N	PRESENT	0
54457	54160	14261S	PARTICIPANT	\N	PRESENT	0
54458	54160	14273W	PARTICIPANT	\N	PRESENT	0
54459	54160	11040E	PARTICIPANT	\N	PRESENT	0
54460	54160	14061L	PARTICIPANT	\N	PRESENT	0
54461	54160	11103C	PARTICIPANT	\N	PRESENT	0
54462	54160	98023Q	PARTICIPANT	\N	PRESENT	0
54463	54160	11100Y	PARTICIPANT	\N	PRESENT	0
54464	54160	14265W	PARTICIPANT	\N	PRESENT	0
54368	54160	01007L	PARTICIPANT	\N	PRESENT	0
54428	54160	01015L	PARTICIPANT	\N	PRESENT	0
54465	54160	11090Q	PARTICIPANT	\N	PRESENT	0
54466	54160	92045V	PARTICIPANT	\N	PRESENT	0
54467	54160	14033T	PARTICIPANT	\N	PRESENT	0
54468	54160	04088S	PARTICIPANT	\N	PRESENT	0
54469	54160	08069G	PARTICIPANT	\N	PRESENT	0
54470	54160	14157T	PARTICIPANT	\N	PRESENT	0
54471	54160	11065P	PARTICIPANT	\N	PRESENT	0
54472	54160	14038Y	PARTICIPANT	\N	PRESENT	0
54473	54160	01016M	PARTICIPANT	\N	PRESENT	0
54474	54160	14197C	PARTICIPANT	\N	PRESENT	0
54475	54160	08061X	PARTICIPANT	\N	PRESENT	0
54476	54160	05012A	PARTICIPANT	\N	PRESENT	0
54479	54160	01028R	PARTICIPANT	\N	PRESENT	0
54480	54160	14041T	PARTICIPANT	\N	PRESENT	0
54481	54160	14249W	PARTICIPANT	\N	PRESENT	0
54483	54160	14135M	PARTICIPANT	\N	PRESENT	0
54488	54160	14331P	PARTICIPANT	\N	PRESENT	0
54500	54160	98035U	PARTICIPANT	\N	PRESENT	0
54505	54160	14221J	PARTICIPANT	\N	PRESENT	0
54506	54160	11056N	PARTICIPANT	\N	PRESENT	0
54507	54160	04057K	PARTICIPANT	\N	PRESENT	0
54508	54160	92039X	PARTICIPANT	\N	PRESENT	0
54511	54160	11112D	PARTICIPANT	\N	PRESENT	0
54512	54160	11042G	PARTICIPANT	\N	PRESENT	0
54571	54161	08055A	PARTICIPANT	\N	PRESENT	0
54612	54161	08009T	PARTICIPANT	\N	PRESENT	0
54613	54161	14093U	PARTICIPANT	\N	PRESENT	0
54614	54161	07026Q	PARTICIPANT	\N	PRESENT	0
54615	54161	01022K	PARTICIPANT	\N	PRESENT	0
54616	54161	14051J	PARTICIPANT	\N	PRESENT	0
54617	54161	14107H	PARTICIPANT	\N	PRESENT	0
54618	54161	14063N	PARTICIPANT	\N	PRESENT	0
54619	54161	14039A	PARTICIPANT	\N	PRESENT	0
54620	54161	80027E	PARTICIPANT	\N	PRESENT	0
54621	54161	13002U	PARTICIPANT	\N	PRESENT	0
54622	54161	11107G	PARTICIPANT	\N	PRESENT	0
54623	54161	01044R	PARTICIPANT	\N	PRESENT	0
54624	54161	11065P	PARTICIPANT	\N	PRESENT	0
54625	54161	14030Q	PARTICIPANT	\N	PRESENT	0
54626	54161	14073Q	PARTICIPANT	\N	PRESENT	0
54627	54161	07024N	PARTICIPANT	\N	PRESENT	0
54628	54161	11103C	PARTICIPANT	\N	PRESENT	0
54629	54161	11011M	PARTICIPANT	\N	PRESENT	0
54630	54161	98005N	PARTICIPANT	\N	PRESENT	0
54631	54161	08039A	PARTICIPANT	\N	PRESENT	0
54632	54161	99004R	PARTICIPANT	\N	PRESENT	0
54633	54161	05012A	PARTICIPANT	\N	PRESENT	0
54634	54161	95063L	PARTICIPANT	\N	PRESENT	0
54635	54161	14261S	PARTICIPANT	\N	PRESENT	0
54636	54161	14041T	PARTICIPANT	\N	PRESENT	0
54637	54161	01015L	PARTICIPANT	\N	PRESENT	0
54638	54161	14257W	PARTICIPANT	\N	PRESENT	0
54639	54161	14159V	PARTICIPANT	\N	PRESENT	0
54640	54161	11114F	PARTICIPANT	\N	PRESENT	0
54641	54161	11099A	PARTICIPANT	\N	PRESENT	0
54642	54161	08061X	PARTICIPANT	\N	PRESENT	0
54643	54161	01027Q	PARTICIPANT	\N	PRESENT	0
54644	54161	11083R	PARTICIPANT	\N	PRESENT	0
54645	54161	14033T	PARTICIPANT	\N	PRESENT	0
54646	54161	11039M	PARTICIPANT	\N	PRESENT	0
54647	54161	08073C	PARTICIPANT	\N	PRESENT	0
54648	54161	08060W	PARTICIPANT	\N	PRESENT	0
54649	54161	14207L	PARTICIPANT	\N	PRESENT	0
54650	54161	14037X	PARTICIPANT	\N	PRESENT	0
54651	54161	14013P	PARTICIPANT	\N	PRESENT	0
54654	54161	10006L	PARTICIPANT	\N	PRESENT	0
54655	54161	14135M	PARTICIPANT	\N	PRESENT	0
35806	35805	14239U	PARTICIPANT	\N	PRESENT	0
40542	40541	92045V	PARTICIPANT	\N	PRESENT	0
35808	35805	01046T	PARTICIPANT	\N	PRESENT	0
35809	35805	04053F	PARTICIPANT	\N	PRESENT	0
35810	35805	14255U	PARTICIPANT	\N	PRESENT	0
35811	35805	04066L	PARTICIPANT	\N	PRESENT	0
35812	35805	00003C	PARTICIPANT	\N	PRESENT	0
35813	35805	14053L	PARTICIPANT	\N	PRESENT	0
40545	40543	92045V	PARTICIPANT	\N	PRESENT	0
35815	35805	11044J	PARTICIPANT	\N	PRESENT	0
35816	35805	14195A	PARTICIPANT	\N	PRESENT	0
35817	35805	14267Y	PARTICIPANT	\N	PRESENT	0
35818	35805	11023D	PARTICIPANT	\N	PRESENT	0
35819	35805	11031D	PARTICIPANT	\N	PRESENT	0
35820	35805	08052W	PARTICIPANT	\N	PRESENT	0
35821	35805	01059Y	PARTICIPANT	\N	PRESENT	0
35822	35805	04081K	PARTICIPANT	\N	PRESENT	0
35823	35805	98024R	PARTICIPANT	\N	PRESENT	0
35824	35805	10006L	PARTICIPANT	\N	PRESENT	0
43721	40901	11109J	PARTICIPANT	\N	PRESENT	0
35826	35805	14217N	PARTICIPANT	\N	PRESENT	0
35827	35805	14042U	PARTICIPANT	\N	PRESENT	0
35828	35805	14151M	PARTICIPANT	\N	PRESENT	0
35829	35805	12042Y	PARTICIPANT	\N	PRESENT	0
35830	35805	14281W	PARTICIPANT	\N	PRESENT	0
35831	35805	14087W	PARTICIPANT	\N	PRESENT	0
35832	35805	01003G	PARTICIPANT	\N	PRESENT	0
35833	35805	14034U	PARTICIPANT	\N	PRESENT	0
35834	35805	14231L	PARTICIPANT	\N	EXCUSE	0
35835	35805	11061K	PARTICIPANT	\N	PRESENT	0
35836	35805	08048B	PARTICIPANT	\N	PRESENT	0
35837	35805	08041T	PARTICIPANT	\N	PRESENT	0
35838	35805	01011G	PARTICIPANT	\N	PRESENT	0
35839	35805	14026U	PARTICIPANT	\N	PRESENT	0
35840	35805	14213J	PARTICIPANT	\N	PRESENT	0
35841	35805	14121F	PARTICIPANT	\N	PRESENT	0
35842	35805	11112D	PARTICIPANT	\N	PRESENT	0
35843	35805	14037X	PARTICIPANT	\N	PRESENT	0
35844	35805	14018U	PARTICIPANT	\N	PRESENT	0
35845	35805	11067R	PARTICIPANT	\N	PRESENT	0
35846	35805	14223L	PARTICIPANT	\N	PRESENT	0
35847	35805	04092N	PRESIDENT	0	PRESENT	0
35848	35805	14265W	PARTICIPANT	\N	PRESENT	0
35849	35805	14119M	PARTICIPANT	\N	PRESENT	0
35850	35805	14071N	PARTICIPANT	\N	PRESENT	0
35851	35805	07032N	PARTICIPANT	\N	PRESENT	0
35852	35805	04043D	PARTICIPANT	\N	PRESENT	0
35853	35805	14271U	PARTICIPANT	\N	PRESENT	0
35854	35805	14017T	PARTICIPANT	\N	PRESENT	0
35855	35805	11093T	PARTICIPANT	\N	PRESENT	0
35856	35805	11097X	PARTICIPANT	\N	PRESENT	0
35857	35805	04045F	PARTICIPANT	\N	PRESENT	0
35858	35805	14227Q	PARTICIPANT	\N	PRESENT	0
35859	35805	01034P	PARTICIPANT	\N	PRESENT	0
35860	35805	11025F	PARTICIPANT	\N	EXCUSE	0
35861	35805	11063M	PARTICIPANT	\N	PRESENT	0
35862	35805	14269B	PARTICIPANT	\N	PRESENT	0
43722	40901	14261S	PARTICIPANT	\N	PRESENT	0
43723	40901	14259Y	PARTICIPANT	\N	PRESENT	0
43724	40901	11113E	PARTICIPANT	\N	PRESENT	0
43725	40901	14097Y	PARTICIPANT	\N	PRESENT	0
43726	40901	14039A	PARTICIPANT	\N	PRESENT	0
43727	40901	98005N	PARTICIPANT	\N	PRESENT	0
43728	40901	14219Q	PARTICIPANT	\N	PRESENT	0
43729	40901	14059S	PARTICIPANT	\N	PRESENT	0
43730	40901	08019V	PRESIDENT	0	PRESENT	0
43731	40901	11072N	PARTICIPANT	\N	PRESENT	0
43732	40901	08073C	PARTICIPANT	\N	PRESENT	0
43733	40901	11054L	PARTICIPANT	\N	PRESENT	0
43734	40901	14275Y	PARTICIPANT	\N	PRESENT	0
43736	40901	04043D	PARTICIPANT	\N	PRESENT	0
43835	43834	01031L	PRESIDENT	0	PRESENT	0
43836	43834	11068S	PARTICIPANT	\N	PRESENT	0
43837	43834	14175V	PARTICIPANT	\N	PRESENT	0
43838	43834	14083S	PARTICIPANT	\N	PRESENT	0
43839	43834	11053K	PARTICIPANT	\N	PRESENT	0
43840	43834	11042G	PARTICIPANT	\N	PRESENT	0
43841	43834	04086Q	PARTICIPANT	\N	PRESENT	0
43842	43834	04071H	PARTICIPANT	\N	PRESENT	0
43843	43834	08069G	PARTICIPANT	\N	PRESENT	0
43844	43834	14159V	PARTICIPANT	\N	PRESENT	0
43845	43834	07029T	PARTICIPANT	\N	PRESENT	0
43846	43834	08011M	PARTICIPANT	\N	PRESENT	0
43847	43834	14225N	PARTICIPANT	\N	PRESENT	0
43848	43834	11012A	PARTICIPANT	\N	PRESENT	0
43849	43834	04034C	PARTICIPANT	\N	PRESENT	0
45659	44248	14221J	PARTICIPANT	\N	EXCUSE	0
47963	47962	14133K	PARTICIPANT	\N	PRESENT	0
47964	47962	90003B	PARTICIPANT	\N	PRESENT	0
47966	47965	14133K	PARTICIPANT	\N	PRESENT	0
48352	48351	04061F	PARTICIPANT	\N	PRESENT	0
48740	48739	89017R	PARTICIPANT	\N	PRESENT	0
48741	48739	01031L	PRESIDENT	0	PRESENT	0
48791	48636	01043Q	PARTICIPANT	\N	EXCUSE	0
48743	48739	01013J	PARTICIPANT	\N	PRESENT	0
48744	48739	11068S	PARTICIPANT	\N	PRESENT	0
52298	49835	14093U	PARTICIPANT	\N	EXCUSE	0
48746	48739	08014Q	PARTICIPANT	\N	PRESENT	0
48747	48739	14167V	PARTICIPANT	\N	PRESENT	0
48748	48739	14175V	PARTICIPANT	\N	PRESENT	0
48749	48739	14083S	PARTICIPANT	\N	PRESENT	0
48750	48739	11053K	PARTICIPANT	\N	PRESENT	0
48751	48739	14085U	PARTICIPANT	\N	PRESENT	0
48752	48739	11042G	PARTICIPANT	\N	PRESENT	0
48753	48739	88008L	PARTICIPANT	\N	PRESENT	0
48754	48739	04086Q	PARTICIPANT	\N	PRESENT	0
52685	51474	95041E	PARTICIPANT	\N	PRESENT	0
48756	48739	11070L	PARTICIPANT	\N	PRESENT	0
52686	51474	01058X	PARTICIPANT	\N	PRESENT	0
48758	48739	14327T	PARTICIPANT	\N	PRESENT	0
48759	48739	08022Q	PARTICIPANT	\N	PRESENT	0
48760	48739	01027Q	PARTICIPANT	\N	PRESENT	0
52687	51474	01059Y	PARTICIPANT	\N	PRESENT	0
48762	48739	11074Q	PARTICIPANT	\N	PRESENT	0
48763	48739	98053W	PARTICIPANT	\N	PRESENT	0
48764	48739	11083R	PARTICIPANT	\N	PRESENT	0
48765	48739	14199E	PARTICIPANT	\N	PRESENT	0
48766	48739	01057W	PARTICIPANT	\N	PRESENT	0
52688	51474	14071N	PARTICIPANT	\N	PRESENT	0
52689	51474	04054G	PARTICIPANT	\N	PRESENT	0
48769	48739	11048N	PARTICIPANT	\N	PRESENT	0
48770	48739	99004R	PARTICIPANT	\N	PRESENT	0
48771	48739	04061F	PARTICIPANT	\N	PRESENT	0
48772	48739	14159V	PARTICIPANT	\N	PRESENT	0
48773	48739	07029T	PARTICIPANT	\N	PRESENT	0
52690	51474	14235Q	PARTICIPANT	\N	PRESENT	0
48775	48739	08010L	PARTICIPANT	\N	PRESENT	0
48776	48739	08034U	PARTICIPANT	\N	PRESENT	0
48777	48739	01048V	PARTICIPANT	\N	PRESENT	0
48778	48739	98046X	PARTICIPANT	\N	PRESENT	0
48779	48739	11085T	PARTICIPANT	\N	PRESENT	0
48780	48739	08011M	PARTICIPANT	\N	PRESENT	0
48781	48739	08073C	PARTICIPANT	\N	PRESENT	0
48782	48739	08061X	PARTICIPANT	\N	PRESENT	0
48783	48739	01016M	PARTICIPANT	\N	PRESENT	0
48784	48739	14225N	PARTICIPANT	\N	PRESENT	0
48785	48739	11012A	PARTICIPANT	\N	PRESENT	0
48786	48739	11057P	PARTICIPANT	\N	PRESENT	0
48787	48739	14173T	PARTICIPANT	\N	PRESENT	0
48788	48739	04034C	PARTICIPANT	\N	PRESENT	0
52691	51474	04047H	PARTICIPANT	\N	PRESENT	0
52692	51474	11063M	PARTICIPANT	\N	PRESENT	0
52693	51474	11069T	PARTICIPANT	\N	PRESENT	0
52694	51474	08047A	PARTICIPANT	\N	PRESENT	0
52695	51474	11033F	PARTICIPANT	\N	PRESENT	0
52696	51474	11083R	PARTICIPANT	\N	PRESENT	0
52697	51474	11043H	PARTICIPANT	\N	PRESENT	0
52698	51474	11096W	PARTICIPANT	\N	PRESENT	0
52699	51474	04057K	PARTICIPANT	\N	PRESENT	0
52700	51474	98018T	PARTICIPANT	\N	PRESENT	0
52701	51474	11012A	PARTICIPANT	\N	PRESENT	0
52702	51474	04078Q	PARTICIPANT	\N	PRESENT	0
52703	51474	04042C	PARTICIPANT	\N	PRESENT	0
52704	51474	08031R	PARTICIPANT	\N	PRESENT	0
52705	51474	07029T	PARTICIPANT	\N	PRESENT	0
52706	51474	14239U	PARTICIPANT	\N	PRESENT	0
52707	51474	98022P	PARTICIPANT	\N	PRESENT	0
52708	51474	08015R	PARTICIPANT	\N	PRESENT	0
52709	51474	08010L	PARTICIPANT	\N	PRESENT	0
52710	51474	08051V	PARTICIPANT	\N	PRESENT	0
52711	51474	08039A	PARTICIPANT	\N	PRESENT	0
52712	51474	11076S	PARTICIPANT	\N	PRESENT	0
52713	51474	14123H	PARTICIPANT	\N	PRESENT	0
52714	51474	95067Q	PARTICIPANT	\N	PRESENT	0
52715	51474	04071H	PARTICIPANT	\N	PRESENT	0
52716	51474	14151M	PARTICIPANT	\N	PRESENT	0
52717	51474	01031L	PARTICIPANT	\N	PRESENT	0
52718	51474	11055M	PARTICIPANT	\N	PRESENT	0
52719	51474	92031P	PARTICIPANT	\N	PRESENT	0
54677	49876	14263U	PARTICIPANT	\N	EXCUSE	0
54678	49876	01046T	PARTICIPANT	\N	EXCUSE	0
54683	54682	08051V	PARTICIPANT	\N	PRESENT	0
54684	54477	14061L	PARTICIPANT	\N	PRESENT	0
54685	52505	14061L	PARTICIPANT	\N	PRESENT	0
54686	52493	14061L	PARTICIPANT	\N	PRESENT	0
54687	51891	14061L	PARTICIPANT	\N	PRESENT	0
54688	52494	14061L	PARTICIPANT	\N	PRESENT	0
54689	52497	14061L	PARTICIPANT	\N	PRESENT	0
54866	54865	92031P	PARTICIPANT	\N	PRESENT	0
54867	54865	08017T	PARTICIPANT	\N	PRESENT	0
54932	54872	07026Q	PARTICIPANT	\N	PRESENT	0
54933	54872	92044U	PARTICIPANT	\N	PRESENT	0
54934	54872	11100Y	PARTICIPANT	\N	PRESENT	0
54935	54872	14223L	PARTICIPANT	\N	PRESENT	0
54936	54872	14221J	PARTICIPANT	\N	PRESENT	0
54937	54872	14169X	PARTICIPANT	\N	PRESENT	0
54938	54872	80027E	PARTICIPANT	\N	PRESENT	0
54939	54872	08051V	PARTICIPANT	\N	PRESENT	0
54940	54872	14039A	PARTICIPANT	\N	PRESENT	0
54941	54872	14038Y	PARTICIPANT	\N	PRESENT	0
54942	54872	14267Y	PARTICIPANT	\N	PRESENT	0
54600	54572	14169X	PARTICIPANT	\N	EXCUSE	0
54943	54872	08068F	PARTICIPANT	\N	PRESENT	0
54602	54572	13002U	PARTICIPANT	\N	PRESENT	0
54603	54572	05012A	PARTICIPANT	\N	PRESENT	0
54951	54872	04043D	PARTICIPANT	\N	PRESENT	0
54952	54872	14331P	PARTICIPANT	\N	PRESENT	0
54606	54572	14331P	PARTICIPANT	\N	PRESENT	0
54607	54572	95062K	PARTICIPANT	\N	EXCUSE	0
54608	54572	14107H	PARTICIPANT	\N	PRESENT	0
54609	54572	14051J	PARTICIPANT	\N	PRESENT	0
54953	54872	08041T	PARTICIPANT	\N	PRESENT	0
54954	54872	14173T	PARTICIPANT	\N	PRESENT	0
54955	54872	14103D	PARTICIPANT	\N	PRESENT	0
54956	54872	01058X	PARTICIPANT	\N	PRESENT	0
54930	54872	89029V	PARTICIPANT	\N	PRESENT	0
54931	54872	11109J	PARTICIPANT	\N	PRESENT	0
54957	54872	80013X	PARTICIPANT	\N	PRESENT	0
54958	54872	14083S	PARTICIPANT	\N	PRESENT	0
54959	54872	14209N	PARTICIPANT	\N	PRESENT	0
54960	54872	92018S	PARTICIPANT	\N	PRESENT	0
54961	54872	14191V	PARTICIPANT	\N	PRESENT	0
54962	54872	01027Q	PARTICIPANT	\N	PRESENT	0
54963	54872	95031C	PARTICIPANT	\N	PRESENT	0
54964	54872	95015C	PARTICIPANT	\N	PRESENT	0
54965	54872	14053L	PARTICIPANT	\N	PRESENT	0
54966	54872	14033T	PARTICIPANT	\N	PRESENT	0
54967	54872	14097Y	PARTICIPANT	\N	PRESENT	0
54968	54872	13002U	PARTICIPANT	\N	PRESENT	0
54970	54872	14237S	PARTICIPANT	\N	PRESENT	0
54973	54872	14205J	PARTICIPANT	\N	PRESENT	0
54974	54872	11026G	PARTICIPANT	\N	PRESENT	0
54975	54872	11066Q	PARTICIPANT	\N	PRESENT	0
54997	54872	01060R	PARTICIPANT	\N	PRESENT	0
55004	54872	08009T	PARTICIPANT	\N	PRESENT	0
55017	54969	95030B	PARTICIPANT	\N	PRESENT	0
55018	54969	11101A	PARTICIPANT	\N	PRESENT	0
55019	54969	13002U	PARTICIPANT	\N	PRESENT	0
55015	54969	86034E	PARTICIPANT	\N	PRESENT	0
55016	54969	14277B	PARTICIPANT	\N	PRESENT	0
55020	54969	08060W	PARTICIPANT	\N	PRESENT	0
55021	54969	11074Q	PARTICIPANT	\N	PRESENT	0
55022	54969	89029V	PARTICIPANT	\N	PRESENT	0
55023	54969	04088S	PARTICIPANT	\N	PRESENT	0
55024	54969	14265W	PARTICIPANT	\N	PRESENT	0
55025	54969	11106F	PARTICIPANT	\N	PRESENT	0
55026	54969	04089T	PARTICIPANT	\N	PRESENT	0
55027	54969	87003B	PARTICIPANT	\N	PRESENT	0
55028	54969	95031C	PARTICIPANT	\N	PRESENT	0
55029	54969	07034Q	PARTICIPANT	\N	PRESENT	0
55030	54969	14051J	PARTICIPANT	\N	PRESENT	0
55031	54969	11103C	PARTICIPANT	\N	PRESENT	0
55032	54969	11088W	PARTICIPANT	\N	PRESENT	0
55033	54969	01056V	PARTICIPANT	\N	PRESENT	0
55034	54969	02002K	PARTICIPANT	\N	PRESENT	0
55035	54969	04054G	PARTICIPANT	\N	PRESENT	0
55036	54969	01015L	PARTICIPANT	\N	PRESENT	0
55037	54969	11040E	PARTICIPANT	\N	PRESENT	0
55038	54969	98035U	PARTICIPANT	\N	PRESENT	0
55039	54969	01031L	PARTICIPANT	\N	PRESENT	0
55040	54969	11066Q	PARTICIPANT	\N	PRESENT	0
55041	54969	04067M	PARTICIPANT	\N	PRESENT	0
55042	54969	11055M	PARTICIPANT	\N	PRESENT	0
55043	54969	04066L	PARTICIPANT	\N	PRESENT	0
55044	54969	11098Y	PARTICIPANT	\N	PRESENT	0
55045	54969	14227Q	PARTICIPANT	\N	PRESENT	0
55046	54969	14197C	PARTICIPANT	\N	PRESENT	0
55047	54969	01011G	PARTICIPANT	\N	PRESENT	0
55048	54969	14107H	PARTICIPANT	\N	PRESENT	0
55049	54969	08053X	PARTICIPANT	\N	PRESENT	0
55050	54969	11068S	PARTICIPANT	\N	PRESENT	0
55051	54969	01046T	PARTICIPANT	\N	PRESENT	0
55052	54969	11107G	PARTICIPANT	\N	PRESENT	0
55053	54969	11059R	PARTICIPANT	\N	PRESENT	0
55054	54969	01059Y	PARTICIPANT	\N	PRESENT	0
55055	54969	92018S	PARTICIPANT	\N	PRESENT	0
55056	54969	11114F	PARTICIPANT	\N	PRESENT	0
55057	54969	11025F	PARTICIPANT	\N	PRESENT	0
55058	54969	08055A	PARTICIPANT	\N	PRESENT	0
55059	54969	11081P	PARTICIPANT	\N	PRESENT	0
55062	54969	07026Q	PARTICIPANT	\N	PRESENT	0
55063	54969	14235Q	PARTICIPANT	\N	PRESENT	0
55064	54969	95062K	PARTICIPANT	\N	PRESENT	0
55065	54969	01058X	PARTICIPANT	\N	PRESENT	0
55066	54969	11034G	PARTICIPANT	\N	PRESENT	0
55067	54969	99004R	PARTICIPANT	\N	PRESENT	0
55068	54969	14211G	PARTICIPANT	\N	PRESENT	0
55069	54969	08025T	PARTICIPANT	\N	PRESENT	0
55070	54969	04041B	PARTICIPANT	\N	PRESENT	0
55071	54969	01019Q	PARTICIPANT	\N	PRESENT	0
55072	54969	95015C	PARTICIPANT	\N	PRESENT	0
55073	54969	14281W	PARTICIPANT	\N	PRESENT	0
55074	54969	14253S	PARTICIPANT	\N	PRESENT	0
55075	54969	14263U	PARTICIPANT	\N	PRESENT	0
55076	54969	04085P	PARTICIPANT	\N	PRESENT	0
55077	54969	04071H	PARTICIPANT	\N	PRESENT	0
55078	54969	14028W	PARTICIPANT	\N	PRESENT	0
55079	54969	14169X	PARTICIPANT	\N	PRESENT	0
55080	54969	80027E	PARTICIPANT	\N	PRESENT	0
55081	54969	11080N	PARTICIPANT	\N	PRESENT	0
55082	54969	95037J	PARTICIPANT	\N	PRESENT	0
55083	54969	14191V	PARTICIPANT	\N	PRESENT	0
55084	54969	14017T	PARTICIPANT	\N	PRESENT	0
55085	54969	14063N	PARTICIPANT	\N	PRESENT	0
55086	54969	14121F	PARTICIPANT	\N	PRESENT	0
55087	54969	14031R	PARTICIPANT	\N	PRESENT	0
55088	54969	14001X	PARTICIPANT	\N	PRESENT	0
55089	54969	11042G	PARTICIPANT	\N	PRESENT	0
55090	54969	11046L	PARTICIPANT	\N	PRESENT	0
55091	54969	14271U	PARTICIPANT	\N	PRESENT	0
55092	54969	92040Q	PARTICIPANT	\N	PRESENT	0
55093	54969	01061S	PARTICIPANT	\N	PRESENT	0
55094	54969	11061K	PARTICIPANT	\N	PRESENT	0
55095	54969	08016S	PARTICIPANT	\N	PRESENT	0
55096	54969	11039M	PARTICIPANT	\N	PRESENT	0
55097	54969	98005N	PARTICIPANT	\N	PRESENT	0
55098	54969	04056J	PARTICIPANT	\N	PRESENT	0
55099	54969	01022K	PARTICIPANT	\N	PRESENT	0
55100	54969	11011M	PARTICIPANT	\N	PRESENT	0
55101	54969	08012N	PARTICIPANT	\N	PRESENT	0
55102	54969	14039A	PARTICIPANT	\N	PRESENT	0
55103	54969	98018T	PARTICIPANT	\N	PRESENT	0
55104	54969	01007L	PARTICIPANT	\N	PRESENT	0
55105	54969	04048J	PARTICIPANT	\N	PRESENT	0
55106	54969	11109J	PARTICIPANT	\N	PRESENT	0
55107	54969	08022Q	PARTICIPANT	\N	PRESENT	0
55108	54969	11113E	PARTICIPANT	\N	PRESENT	0
55109	54969	08035V	PARTICIPANT	\N	PRESENT	0
55110	54969	77002U	PARTICIPANT	\N	PRESENT	0
55111	54969	04094Q	PARTICIPANT	\N	PRESENT	0
55112	54969	04045F	PARTICIPANT	\N	PRESENT	0
55113	54969	11077T	PARTICIPANT	\N	PRESENT	0
55114	54969	11033F	PARTICIPANT	\N	PRESENT	0
55115	54969	04047H	PARTICIPANT	\N	PRESENT	0
55116	54969	98024R	PARTICIPANT	\N	PRESENT	0
55117	54969	14081Q	PARTICIPANT	\N	PRESENT	0
55118	54969	01027Q	PARTICIPANT	\N	PRESENT	0
55119	54969	11067R	PARTICIPANT	\N	PRESENT	0
55120	54969	11029K	PARTICIPANT	\N	PRESENT	0
55121	54969	01044R	PARTICIPANT	\N	PRESENT	0
55122	54969	95041E	PARTICIPANT	\N	PRESENT	0
55123	54969	10006L	PARTICIPANT	\N	PRESENT	0
55124	54969	14085U	PARTICIPANT	\N	PRESENT	0
55125	54969	11084S	PARTICIPANT	\N	PRESENT	0
55126	54969	14223L	PARTICIPANT	\N	PRESENT	0
55127	54969	11010L	PARTICIPANT	\N	PRESENT	0
55128	54969	04043D	PARTICIPANT	\N	PRESENT	0
55129	54969	08024S	PARTICIPANT	\N	PRESENT	0
32368	32306	01037S	PARTICIPANT	\N	PRESENT	0
32376	32306	14249W	PARTICIPANT	\N	PRESENT	0
32605	32306	07026Q	PARTICIPANT	\N	PRESENT	0
42938	41834	14083S	PARTICIPANT	\N	PRESENT	0
35866	35863	01031L	PRESIDENT	0	PRESENT	0
42939	41834	14327T	PARTICIPANT	\N	PRESENT	0
35868	35863	01013J	PARTICIPANT	\N	PRESENT	0
42940	41834	14089Y	PARTICIPANT	\N	PRESENT	0
42941	41834	14051J	PARTICIPANT	\N	PRESENT	0
35871	35863	08014Q	PARTICIPANT	\N	PRESENT	0
35872	35863	14167V	PARTICIPANT	\N	PRESENT	0
35873	35863	14175V	PARTICIPANT	\N	PRESENT	0
35874	35863	14083S	PARTICIPANT	\N	PRESENT	0
35875	35863	11053K	PARTICIPANT	\N	PRESENT	0
35876	35863	14085U	PARTICIPANT	\N	PRESENT	0
42942	41834	98050T	PARTICIPANT	\N	PRESENT	0
42943	41834	07029T	PARTICIPANT	\N	PRESENT	0
35879	35863	04086Q	PARTICIPANT	\N	PRESENT	0
42944	41834	14263U	PARTICIPANT	\N	PRESENT	0
35881	35863	11070L	PARTICIPANT	\N	PRESENT	0
35882	35863	11088W	PARTICIPANT	\N	PRESENT	0
42945	41834	01022K	PARTICIPANT	\N	PRESENT	0
42946	41834	04034C	PARTICIPANT	\N	PRESENT	0
35885	35863	01027Q	PARTICIPANT	\N	PRESENT	0
35886	35863	04071H	PARTICIPANT	\N	PRESENT	0
35887	35863	11074Q	PARTICIPANT	\N	PRESENT	0
42947	41834	11057P	PARTICIPANT	\N	PRESENT	0
42948	41834	11036J	PARTICIPANT	\N	PRESENT	0
42949	41834	14085U	PARTICIPANT	\N	PRESENT	0
35891	35863	01057W	PARTICIPANT	\N	PRESENT	0
42950	41834	04067M	PARTICIPANT	\N	PRESENT	0
35893	35863	08069G	PARTICIPANT	\N	PRESENT	0
35894	35863	11048N	PARTICIPANT	\N	PRESENT	0
42952	41834	14219Q	PARTICIPANT	\N	PRESENT	0
42953	41834	01015L	PARTICIPANT	\N	PRESENT	0
35897	35863	14159V	PARTICIPANT	\N	PRESENT	0
35898	35863	07029T	PARTICIPANT	\N	PRESENT	0
42954	41834	14041T	PARTICIPANT	\N	PRESENT	0
35900	35863	08010L	PARTICIPANT	\N	PRESENT	0
35901	35863	08034U	PARTICIPANT	\N	PRESENT	0
35902	35863	01048V	PARTICIPANT	\N	PRESENT	0
35903	35863	98046X	PARTICIPANT	\N	PRESENT	0
35904	35863	11085T	PARTICIPANT	\N	PRESENT	0
35905	35863	08011M	PARTICIPANT	\N	PRESENT	0
42955	41834	95062K	PARTICIPANT	\N	PRESENT	0
35907	35863	08061X	PARTICIPANT	\N	PRESENT	0
35908	35863	01016M	PARTICIPANT	\N	PRESENT	0
35909	35863	14225N	PARTICIPANT	\N	PRESENT	0
35910	35863	11012A	PARTICIPANT	\N	PRESENT	0
35911	35863	11057P	PARTICIPANT	\N	PRESENT	0
35912	35863	14173T	PARTICIPANT	\N	PRESENT	0
35913	35863	04034C	PARTICIPANT	\N	PRESENT	0
42956	41834	86044G	PARTICIPANT	\N	PRESENT	0
42958	41834	11081P	PARTICIPANT	\N	PRESENT	0
42959	41834	87003B	PARTICIPANT	\N	PRESENT	0
42960	41834	14053L	PARTICIPANT	\N	PRESENT	0
42961	41834	08042U	PARTICIPANT	\N	PRESENT	0
42962	41834	05012A	PARTICIPANT	\N	PRESENT	0
42963	41834	95015C	PARTICIPANT	\N	PRESENT	0
42964	41834	01028R	PARTICIPANT	\N	PRESENT	0
42965	41834	08011M	PARTICIPANT	\N	PRESENT	0
42966	41834	01031L	PARTICIPANT	\N	PRESENT	0
42967	41834	04045F	PARTICIPANT	\N	PRESENT	0
42968	41834	14038Y	PARTICIPANT	\N	PRESENT	0
42969	41834	14225N	PARTICIPANT	\N	PRESENT	0
42970	41834	08062Y	PARTICIPANT	\N	PRESENT	0
42971	41834	14147R	PARTICIPANT	\N	PRESENT	0
42972	41834	95035G	PARTICIPANT	\N	PRESENT	0
42973	41834	14215L	PARTICIPANT	\N	PRESENT	0
42974	41834	14265W	PARTICIPANT	\N	PRESENT	0
42975	41834	14257W	PARTICIPANT	\N	PRESENT	0
42976	41834	01003G	PARTICIPANT	\N	PRESENT	0
42978	41834	14179A	PARTICIPANT	\N	PRESENT	0
43059	41881	08055A	PARTICIPANT	\N	PRESENT	0
42980	41834	04088S	PARTICIPANT	\N	PRESENT	0
42981	41834	14199E	PARTICIPANT	\N	PRESENT	0
42982	41834	14231L	PARTICIPANT	\N	PRESENT	0
42983	41834	14081Q	PARTICIPANT	\N	PRESENT	0
42984	41834	08069G	PARTICIPANT	\N	PRESENT	0
42985	41834	14097Y	PARTICIPANT	\N	PRESENT	0
42986	41834	14109K	PARTICIPANT	\N	PRESENT	0
42987	41834	01016M	PARTICIPANT	\N	PRESENT	0
42988	41834	00003C	PARTICIPANT	\N	PRESENT	0
42989	41834	11105E	PARTICIPANT	\N	PRESENT	0
42990	41834	08015R	PARTICIPANT	\N	PRESENT	0
42991	41834	11054L	PARTICIPANT	\N	PRESENT	0
42992	41834	14251Q	PARTICIPANT	\N	PRESENT	0
42993	41834	01057W	PARTICIPANT	\N	PRESENT	0
42994	41834	14267Y	PARTICIPANT	\N	PRESENT	0
43036	41834	14073Q	PARTICIPANT	\N	PRESENT	0
43053	41834	14159V	PARTICIPANT	\N	PRESENT	0
43054	41834	14107H	PARTICIPANT	\N	PRESENT	0
43055	41834	11074Q	PARTICIPANT	\N	PRESENT	0
43056	41834	11059R	PARTICIPANT	\N	PRESENT	0
43057	41834	08068F	PARTICIPANT	\N	PRESENT	0
43058	41834	08025T	PARTICIPANT	\N	PRESENT	0
43060	41881	92015P	PARTICIPANT	\N	PRESENT	0
43123	41881	14187A	PARTICIPANT	\N	PRESENT	0
43062	41881	11083R	PARTICIPANT	\N	PRESENT	0
43063	41881	11107G	PARTICIPANT	\N	PRESENT	0
43064	41881	14063N	PARTICIPANT	\N	PRESENT	0
43065	41881	14083S	PARTICIPANT	\N	PRESENT	0
43066	41881	14327T	PARTICIPANT	\N	PRESENT	0
43125	41881	04067M	PARTICIPANT	\N	PRESENT	0
43068	41881	14051J	PARTICIPANT	\N	PRESENT	0
43069	41881	98050T	PARTICIPANT	\N	PRESENT	0
43070	41881	07029T	PARTICIPANT	\N	PRESENT	0
43071	41881	14263U	PARTICIPANT	\N	PRESENT	0
43072	41881	01022K	PARTICIPANT	\N	PRESENT	0
43073	41881	04034C	PARTICIPANT	\N	PRESENT	0
43074	41881	11036J	PARTICIPANT	\N	PRESENT	0
43075	41881	14085U	PARTICIPANT	\N	PRESENT	0
43124	41881	95030B	PARTICIPANT	\N	PRESENT	0
43077	41881	14219Q	PARTICIPANT	\N	PRESENT	0
43078	41881	01015L	PARTICIPANT	\N	PRESENT	0
43079	41881	14041T	PARTICIPANT	\N	PRESENT	0
43080	41881	95062K	PARTICIPANT	\N	PRESENT	0
43081	41881	86044G	PARTICIPANT	\N	PRESENT	0
43082	41881	11081P	PARTICIPANT	\N	PRESENT	0
43083	41881	87003B	PARTICIPANT	\N	PRESENT	0
43084	41881	14053L	PARTICIPANT	\N	PRESENT	0
43085	41881	08042U	PARTICIPANT	\N	PRESENT	0
43086	41881	05012A	PARTICIPANT	\N	PRESENT	0
43127	41881	14033T	PARTICIPANT	\N	PRESENT	0
43122	41881	14059S	PARTICIPANT	\N	PRESENT	0
43089	41881	01031L	PARTICIPANT	\N	PRESENT	0
43126	41881	14213J	PARTICIPANT	\N	PRESENT	0
43091	41881	14038Y	PARTICIPANT	\N	PRESENT	0
43092	41881	14225N	PARTICIPANT	\N	PRESENT	0
43093	41881	08062Y	PARTICIPANT	\N	PRESENT	0
43132	41881	11099A	PARTICIPANT	\N	PRESENT	0
43095	41881	95035G	PARTICIPANT	\N	PRESENT	0
43096	41881	14215L	PARTICIPANT	\N	PRESENT	0
43097	41881	14265W	PARTICIPANT	\N	PRESENT	0
43098	41881	14257W	PARTICIPANT	\N	PRESENT	0
43099	41881	01003G	PARTICIPANT	\N	PRESENT	0
43100	41881	14179A	PARTICIPANT	\N	PRESENT	0
43101	41881	04088S	PARTICIPANT	\N	PRESENT	0
43102	41881	14199E	PARTICIPANT	\N	PRESENT	0
43103	41881	14231L	PARTICIPANT	\N	PRESENT	0
43128	41881	07032N	PARTICIPANT	\N	PRESENT	0
43105	41881	08069G	PARTICIPANT	\N	PRESENT	0
43106	41881	14109K	PARTICIPANT	\N	PRESENT	0
43107	41881	01016M	PARTICIPANT	\N	PRESENT	0
43137	41881	11012A	PARTICIPANT	\N	PRESENT	0
43109	41881	11105E	PARTICIPANT	\N	PRESENT	0
43131	41881	14121F	PARTICIPANT	\N	PRESENT	0
43111	41881	11054L	PARTICIPANT	\N	PRESENT	0
43112	41881	14251Q	PARTICIPANT	\N	PRESENT	0
43113	41881	01057W	PARTICIPANT	\N	PRESENT	0
43114	41881	14267Y	PARTICIPANT	\N	PRESENT	0
43115	41881	14073Q	PARTICIPANT	\N	PRESENT	0
43116	41881	14159V	PARTICIPANT	\N	PRESENT	0
43117	41881	14107H	PARTICIPANT	\N	PRESENT	0
43118	41881	11074Q	PARTICIPANT	\N	PRESENT	0
43119	41881	11059R	PARTICIPANT	\N	PRESENT	0
43120	41881	08068F	PARTICIPANT	\N	PRESENT	0
43129	41881	11043H	PARTICIPANT	\N	PRESENT	0
43130	41881	14030Q	PARTICIPANT	\N	PRESENT	0
43133	41881	08034U	PARTICIPANT	\N	PRESENT	0
43138	41881	08051V	PARTICIPANT	\N	PRESENT	0
43139	41881	11067R	PARTICIPANT	\N	PRESENT	0
43146	41881	08061X	PARTICIPANT	\N	PRESENT	0
43147	41881	83047W	PARTICIPANT	\N	PRESENT	0
43157	41881	04043D	PARTICIPANT	\N	PRESENT	0
43158	41881	14081Q	PARTICIPANT	\N	PRESENT	0
43159	41881	14237S	PARTICIPANT	\N	PRESENT	0
43160	41881	14173T	PARTICIPANT	\N	PRESENT	0
54665	54161	11036J	PARTICIPANT	\N	PRESENT	0
54666	54161	11048N	PARTICIPANT	\N	PRESENT	0
54667	54161	14169X	PARTICIPANT	\N	PRESENT	0
54672	54161	04094Q	PARTICIPANT	\N	PRESENT	0
54673	54161	11090Q	PARTICIPANT	\N	PRESENT	0
54674	54161	98023Q	PARTICIPANT	\N	PRESENT	0
54675	54161	11056N	PARTICIPANT	\N	PRESENT	0
54676	54161	80013X	PARTICIPANT	\N	PRESENT	0
54679	54161	08034U	PARTICIPANT	\N	PRESENT	0
54680	54161	01041N	PARTICIPANT	\N	PRESENT	0
54681	54161	14269B	PARTICIPANT	\N	PRESENT	0
54690	54161	11089X	PARTICIPANT	\N	PRESENT	0
54691	54161	08069G	PARTICIPANT	\N	PRESENT	0
54692	54161	11031D	PARTICIPANT	\N	PRESENT	0
54720	54162	14093U	PARTICIPANT	\N	PRESENT	0
54662	54161	11023D	PARTICIPANT	\N	PRESENT	0
54664	54161	14042U	PARTICIPANT	\N	PRESENT	0
54721	54162	11090Q	PARTICIPANT	\N	PRESENT	0
54722	54162	11065P	PARTICIPANT	\N	PRESENT	0
54723	54162	14039A	PARTICIPANT	\N	PRESENT	0
54724	54162	01015L	PARTICIPANT	\N	PRESENT	0
54725	54162	01044R	PARTICIPANT	\N	PRESENT	0
54726	54162	13002U	PARTICIPANT	\N	PRESENT	0
54727	54162	08060W	PARTICIPANT	\N	PRESENT	0
54728	54162	11107G	PARTICIPANT	\N	PRESENT	0
54729	54162	14107H	PARTICIPANT	\N	PRESENT	0
54730	54162	80013X	PARTICIPANT	\N	PRESENT	0
54731	54162	11099A	PARTICIPANT	\N	PRESENT	0
54732	54162	14030Q	PARTICIPANT	\N	PRESENT	0
54733	54162	11103C	PARTICIPANT	\N	PRESENT	0
54734	54162	14261S	PARTICIPANT	\N	PRESENT	0
54735	54162	01056V	PARTICIPANT	\N	PRESENT	0
54736	54162	14169X	PARTICIPANT	\N	PRESENT	0
54737	54162	98005N	PARTICIPANT	\N	PRESENT	0
54738	54162	10006L	PARTICIPANT	\N	PRESENT	0
54739	54162	11031D	PARTICIPANT	\N	PRESENT	0
54740	54162	98023Q	PARTICIPANT	\N	PRESENT	0
54741	54162	01022K	PARTICIPANT	\N	PRESENT	0
54742	54162	11023D	PARTICIPANT	\N	PRESENT	0
54743	54162	11114F	PARTICIPANT	\N	PRESENT	0
54744	54162	04054G	PARTICIPANT	\N	PRESENT	0
54718	54162	04081K	PARTICIPANT	\N	PRESENT	0
54719	54162	08009T	PARTICIPANT	\N	PRESENT	0
54782	54332	14107H	PARTICIPANT	\N	PRESENT	0
54783	54332	11114F	PARTICIPANT	\N	PRESENT	0
54784	54332	11011M	PARTICIPANT	\N	PRESENT	0
54785	54332	99004R	PARTICIPANT	\N	PRESENT	0
54786	54332	08016S	PARTICIPANT	\N	PRESENT	0
54787	54332	11031D	PARTICIPANT	\N	PRESENT	0
54788	54332	11023D	PARTICIPANT	\N	PRESENT	0
54789	54332	10006L	PARTICIPANT	\N	PRESENT	0
54790	54332	14039A	PARTICIPANT	\N	PRESENT	0
54791	54332	09001P	PARTICIPANT	\N	PRESENT	0
54792	54332	11029K	PARTICIPANT	\N	PRESENT	0
54793	54332	11083R	PARTICIPANT	\N	PRESENT	0
54824	54333	08009T	PARTICIPANT	\N	PRESENT	0
54825	54333	14093U	PARTICIPANT	\N	PRESENT	0
54826	54333	01056V	PARTICIPANT	\N	PRESENT	0
54827	54333	13002U	PARTICIPANT	\N	PRESENT	0
54828	54333	01044R	PARTICIPANT	\N	PRESENT	0
54829	54333	14041T	PARTICIPANT	\N	PRESENT	0
54830	54333	80013X	PARTICIPANT	\N	PRESENT	0
54831	54333	98023Q	PARTICIPANT	\N	PRESENT	0
54832	54333	08060W	PARTICIPANT	\N	PRESENT	0
54839	54333	14275Y	PARTICIPANT	\N	PRESENT	0
54834	54333	11103C	PARTICIPANT	\N	PRESENT	0
54835	54333	11099A	PARTICIPANT	\N	PRESENT	0
54836	54333	11031D	PARTICIPANT	\N	PRESENT	0
54837	54333	01015L	PARTICIPANT	\N	PRESENT	0
54838	54333	11023D	PARTICIPANT	\N	PRESENT	0
54840	54333	14107H	PARTICIPANT	\N	PRESENT	0
54841	54333	14039A	PARTICIPANT	\N	PRESENT	0
54842	54333	11107G	PARTICIPANT	\N	PRESENT	0
54844	54843	11090Q	PARTICIPANT	\N	PRESENT	0
54845	54333	04081K	PARTICIPANT	\N	PRESENT	0
54846	54333	09001P	PARTICIPANT	\N	PRESENT	0
54847	54333	11011M	PARTICIPANT	\N	PRESENT	0
54822	54333	11085T	PARTICIPANT	\N	PRESENT	0
54823	54333	11090Q	PARTICIPANT	\N	PRESENT	0
54849	54848	04040A	PARTICIPANT	\N	PRESENT	0
54859	54333	98005N	PARTICIPANT	\N	PRESENT	0
54851	54333	11065P	PARTICIPANT	\N	PRESENT	0
54855	54333	04043D	PARTICIPANT	\N	PRESENT	0
54856	54333	11114F	PARTICIPANT	\N	PRESENT	0
54861	54333	11080N	PARTICIPANT	\N	PRESENT	0
54860	54333	01028R	PARTICIPANT	\N	PRESENT	0
54862	54333	08051V	PARTICIPANT	\N	PRESENT	0
54863	54333	01022K	PARTICIPANT	\N	PRESENT	0
54864	54333	11083R	PARTICIPANT	\N	PRESENT	0
54868	54333	11069T	PARTICIPANT	\N	PRESENT	0
54945	54944	14151M	PARTICIPANT	\N	PRESENT	0
54946	54944	11084S	PARTICIPANT	\N	PRESENT	0
54947	54944	98005N	PARTICIPANT	\N	PRESENT	0
54948	54944	92039X	PARTICIPANT	\N	PRESENT	0
54949	54944	11100Y	PARTICIPANT	\N	PRESENT	0
54950	54944	11012A	PARTICIPANT	\N	PRESENT	0
55006	55005	04054G	PARTICIPANT	\N	PRESENT	0
55007	55005	96004D	PRESIDENT	0	PRESENT	0
55008	55005	08042U	PARTICIPANT	\N	PRESENT	0
55009	55005	11012A	PARTICIPANT	\N	PRESENT	0
55010	55005	04045F	PARTICIPANT	\N	PRESENT	0
55011	55005	98035U	PARTICIPANT	\N	PRESENT	0
55061	55060	14071N	PARTICIPANT	\N	PRESENT	0
55985	54477	04049K	PARTICIPANT	\N	PRESENT	0
55986	54477	14030Q	PARTICIPANT	\N	PRESENT	0
55987	54477	11063M	PARTICIPANT	\N	PRESENT	0
55988	52505	04049K	PARTICIPANT	\N	PRESENT	0
55989	52505	14030Q	PARTICIPANT	\N	PRESENT	0
55990	52505	11063M	PARTICIPANT	\N	PRESENT	0
55991	52493	04049K	PARTICIPANT	\N	PRESENT	0
55992	52493	14030Q	PARTICIPANT	\N	PRESENT	0
55993	52493	11063M	PARTICIPANT	\N	PRESENT	0
56255	56235	14195A	PARTICIPANT	\N	PRESENT	0
56237	56235	01046T	PARTICIPANT	\N	PRESENT	0
56256	56235	14269B	PARTICIPANT	\N	PRESENT	0
56239	56235	11103C	PRESIDENT	0	PRESENT	0
56257	56235	14119M	PARTICIPANT	\N	PRESENT	0
56242	56235	08052W	PARTICIPANT	\N	PRESENT	0
56243	56235	01059Y	PARTICIPANT	\N	PRESENT	0
56244	56235	98024R	PARTICIPANT	\N	PRESENT	0
56245	56235	10006L	PARTICIPANT	\N	PRESENT	0
56246	56235	14151M	PARTICIPANT	\N	PRESENT	0
56247	56235	12042Y	PARTICIPANT	\N	EXCUSE	0
56248	56235	11061K	PARTICIPANT	\N	PRESENT	0
56249	56235	01011G	PARTICIPANT	\N	PRESENT	0
56250	56235	04092N	PARTICIPANT	\N	PRESENT	0
56251	56235	14071N	PARTICIPANT	\N	PRESENT	0
56252	56235	11093T	PARTICIPANT	\N	PRESENT	0
56253	56235	11097X	PARTICIPANT	\N	PRESENT	0
56254	56235	01034P	PARTICIPANT	\N	PRESENT	0
56265	56261	01046T	PARTICIPANT	\N	PRESENT	0
56266	56261	04053F	PARTICIPANT	\N	PRESENT	0
56268	56261	04066L	PARTICIPANT	\N	PRESENT	0
56271	56261	11103C	PARTICIPANT	\N	PRESENT	0
56272	56261	11044J	PARTICIPANT	\N	PRESENT	0
56273	56261	14195A	PARTICIPANT	\N	PRESENT	0
56274	56261	14267Y	PARTICIPANT	\N	PRESENT	0
56277	56261	08052W	PARTICIPANT	\N	PRESENT	0
56278	56261	01059Y	PARTICIPANT	\N	PRESENT	0
56279	56261	04081K	PARTICIPANT	\N	PRESENT	0
56280	56261	98024R	PARTICIPANT	\N	PRESENT	0
56281	56261	10006L	PARTICIPANT	\N	PRESENT	0
56283	56261	14217N	PARTICIPANT	\N	EXCUSE	0
56284	56261	14042U	PARTICIPANT	\N	PRESENT	0
56285	56261	14151M	PARTICIPANT	\N	PRESENT	0
56286	56261	12042Y	PARTICIPANT	\N	EXCUSE	0
56287	56261	14281W	PARTICIPANT	\N	PRESENT	0
56288	56261	14087W	PARTICIPANT	\N	PRESENT	0
56291	56261	14231L	PARTICIPANT	\N	PRESENT	0
56292	56261	11061K	PARTICIPANT	\N	PRESENT	0
56294	56261	08041T	PARTICIPANT	\N	PRESENT	0
56295	56261	01011G	PARTICIPANT	\N	PRESENT	0
56297	56261	14213J	PARTICIPANT	\N	PRESENT	0
56298	56261	14121F	PARTICIPANT	\N	PRESENT	0
56300	56261	14037X	PARTICIPANT	\N	PRESENT	0
40572	40570	01019Q	PARTICIPANT	\N	PRESENT	0
40574	40573	11039M	PARTICIPANT	\N	PRESENT	0
40571	40570	11039M	PARTICIPANT	\N	PRESENT	0
31625	31621	04053F	PARTICIPANT	\N	PRESENT	0
40575	40573	98042T	PARTICIPANT	\N	PRESENT	0
40576	40573	01019Q	PARTICIPANT	\N	PRESENT	0
31628	31621	00003C	PARTICIPANT	\N	PRESENT	0
31629	31621	14053L	PARTICIPANT	\N	PRESENT	0
31630	31621	11103C	PARTICIPANT	\N	PRESENT	0
31631	31621	11044J	PARTICIPANT	\N	PRESENT	0
31632	31621	14195A	PARTICIPANT	\N	PRESENT	0
40578	40577	11039M	PARTICIPANT	\N	PRESENT	0
40579	40577	98042T	PARTICIPANT	\N	PRESENT	0
31635	31621	11031D	PARTICIPANT	\N	PRESENT	0
31636	31621	08052W	PARTICIPANT	\N	PRESENT	0
31637	31621	01059Y	PARTICIPANT	\N	PRESENT	0
40580	40577	01019Q	PARTICIPANT	\N	PRESENT	0
47334	47333	01014K	PARTICIPANT	\N	PRESENT	0
31640	31621	10006L	PARTICIPANT	\N	PRESENT	0
47335	47333	07024N	PARTICIPANT	\N	PRESENT	0
31642	31621	14217N	PARTICIPANT	\N	PRESENT	0
31643	31621	14042U	PARTICIPANT	\N	PRESENT	0
31644	31621	14151M	PARTICIPANT	\N	PRESENT	0
31645	31621	12042Y	PARTICIPANT	\N	PRESENT	0
31646	31621	14281W	PARTICIPANT	\N	PRESENT	0
31647	31621	14087W	PARTICIPANT	\N	PRESENT	0
31650	31621	14231L	PARTICIPANT	\N	PRESENT	0
52495	52494	14087W	PARTICIPANT	\N	PRESENT	0
31653	31621	08041T	PARTICIPANT	\N	PRESENT	0
52498	52497	14087W	PARTICIPANT	\N	PRESENT	0
31655	31621	14026U	PARTICIPANT	\N	PRESENT	0
31656	31621	14213J	PARTICIPANT	\N	PRESENT	0
31657	31621	14121F	PARTICIPANT	\N	PRESENT	0
52500	52499	14087W	PARTICIPANT	\N	PRESENT	0
31659	31621	14037X	PARTICIPANT	\N	PRESENT	0
52506	52505	14087W	PARTICIPANT	\N	PRESENT	0
31661	31621	11067R	PARTICIPANT	\N	PRESENT	0
31662	31621	14223L	PARTICIPANT	\N	PRESENT	0
31663	31621	04092N	PRESIDENT	0	PRESENT	0
31664	31621	14265W	PARTICIPANT	\N	PRESENT	0
31665	31621	14119M	PARTICIPANT	\N	PRESENT	0
31666	31621	14071N	PARTICIPANT	\N	PRESENT	0
31667	31621	07032N	PARTICIPANT	\N	PRESENT	0
52720	51474	08048B	PARTICIPANT	\N	PRESENT	0
52721	51474	14211G	PARTICIPANT	\N	PRESENT	0
52722	51474	08065C	PARTICIPANT	\N	PRESENT	0
31671	31621	11093T	PARTICIPANT	\N	PRESENT	0
31672	31621	11097X	PARTICIPANT	\N	EXCUSE	0
31673	31621	04045F	PARTICIPANT	\N	PRESENT	0
52723	51474	01047U	PARTICIPANT	\N	PRESENT	0
31675	31621	01034P	PARTICIPANT	\N	PRESENT	0
52724	51474	14329V	PARTICIPANT	\N	PRESENT	0
31677	31621	11063M	PARTICIPANT	\N	PRESENT	0
31678	31621	14269B	PARTICIPANT	\N	PRESENT	0
52725	51474	08056B	PARTICIPANT	\N	PRESENT	0
52726	51474	92045V	PARTICIPANT	\N	PRESENT	0
52727	51474	11030C	PARTICIPANT	\N	PRESENT	0
52728	51474	95035G	PARTICIPANT	\N	PRESENT	0
52729	51474	77002U	PARTICIPANT	\N	PRESENT	0
52730	51474	07024N	PARTICIPANT	\N	PRESENT	0
52731	51474	04033B	PARTICIPANT	\N	PRESENT	0
52732	51474	92020L	PARTICIPANT	\N	PRESENT	0
52733	51474	11015D	PARTICIPANT	\N	PRESENT	0
52734	51474	08043V	PARTICIPANT	\N	PRESENT	0
52735	51474	92040Q	PARTICIPANT	\N	PRESENT	0
52736	51474	95037J	PARTICIPANT	\N	PRESENT	0
52737	51474	11105E	PARTICIPANT	\N	PRESENT	0
52738	51474	05008E	PARTICIPANT	\N	PRESENT	0
52739	51474	90003B	PARTICIPANT	\N	PRESENT	0
52740	51474	83042R	PARTICIPANT	\N	PRESENT	0
52741	51474	08058D	PARTICIPANT	\N	PRESENT	0
52742	51474	04034C	PARTICIPANT	\N	PRESENT	0
52743	51474	04043D	PARTICIPANT	\N	PRESENT	0
52744	51474	04036E	PARTICIPANT	\N	PRESENT	0
52745	51474	11026G	PARTICIPANT	\N	PRESENT	0
52746	51474	95059Q	PARTICIPANT	\N	PRESENT	0
52747	51474	14263U	PARTICIPANT	\N	PRESENT	0
52748	51474	11101A	PARTICIPANT	\N	PRESENT	0
52749	51474	11082Q	PARTICIPANT	\N	PRESENT	0
52751	51474	04086Q	PARTICIPANT	\N	PRESENT	0
52752	51474	14079W	PARTICIPANT	\N	PRESENT	0
52753	51474	04070G	PARTICIPANT	\N	PRESENT	0
52754	51474	11031D	PARTICIPANT	\N	PRESENT	0
52755	51474	98024R	PARTICIPANT	\N	PRESENT	0
52756	51474	04077P	PARTICIPANT	\N	PRESENT	0
52757	51474	10006L	PARTICIPANT	\N	PRESENT	0
52758	51474	08017T	PARTICIPANT	\N	PRESENT	0
52796	51474	11093T	PARTICIPANT	\N	PRESENT	0
52760	51474	08035V	PARTICIPANT	\N	PRESENT	0
52761	51474	95049N	PARTICIPANT	\N	PRESENT	0
52762	51474	14065Q	PARTICIPANT	\N	PRESENT	0
52763	51474	04079R	PARTICIPANT	\N	PRESENT	0
52764	51474	11046L	PARTICIPANT	\N	PRESENT	0
52765	51474	08044W	PARTICIPANT	\N	PRESENT	0
52766	51474	14014Q	PARTICIPANT	\N	PRESENT	0
52793	51474	01034P	PARTICIPANT	\N	PRESENT	0
52768	51474	14109K	PARTICIPANT	\N	PRESENT	0
52769	51474	98042T	PARTICIPANT	\N	PRESENT	0
52770	51474	11080N	PARTICIPANT	\N	PRESENT	0
52771	51474	11027H	PARTICIPANT	\N	PRESENT	0
52772	51474	07034Q	PARTICIPANT	\N	PRESENT	0
52773	51474	97011G	PARTICIPANT	\N	PRESENT	0
52774	51474	14281W	PARTICIPANT	\N	PRESENT	0
52775	51474	14229S	PARTICIPANT	\N	PRESENT	0
52776	51474	98023Q	PARTICIPANT	\N	PRESENT	0
52777	51474	14063N	PARTICIPANT	\N	PRESENT	0
52778	51474	04066L	PARTICIPANT	\N	PRESENT	0
52779	51474	11044J	PARTICIPANT	\N	PRESENT	0
52780	51474	11112D	PARTICIPANT	\N	PRESENT	0
52781	51474	14257W	PARTICIPANT	\N	PRESENT	0
52782	51474	11014C	PARTICIPANT	\N	PRESENT	0
52783	51474	04048J	PARTICIPANT	\N	PRESENT	0
52784	51474	11035H	PARTICIPANT	\N	PRESENT	0
52785	51474	01057W	PARTICIPANT	\N	PRESENT	0
52786	51474	86034E	PARTICIPANT	\N	PRESENT	0
52787	51474	04053F	PARTICIPANT	\N	PRESENT	0
52788	51474	11104D	PARTICIPANT	\N	PRESENT	0
52789	51474	11110B	PARTICIPANT	\N	PRESENT	0
52790	51474	04044E	PARTICIPANT	\N	PRESENT	0
52791	51474	04059M	PARTICIPANT	\N	PRESENT	0
52792	51474	07004J	PARTICIPANT	\N	PRESENT	0
52794	51474	14275Y	PARTICIPANT	\N	PRESENT	0
52795	51474	04080J	PARTICIPANT	\N	PRESENT	0
52797	51474	04074L	PARTICIPANT	\N	PRESENT	0
52798	51474	01024M	PARTICIPANT	\N	PRESENT	0
52799	51474	11077T	PARTICIPANT	\N	PRESENT	0
52800	51474	11074Q	PARTICIPANT	\N	PRESENT	0
52801	51474	11085T	PARTICIPANT	\N	PRESENT	0
52802	51474	01014K	PARTICIPANT	\N	PRESENT	0
52803	51474	12042Y	PARTICIPANT	\N	PRESENT	0
52804	51474	04040A	PARTICIPANT	\N	PRESENT	0
52805	51474	11034G	PARTICIPANT	\N	PRESENT	0
52806	51474	04085P	PARTICIPANT	\N	PRESENT	0
52807	51474	14255U	PARTICIPANT	\N	PRESENT	0
52808	51474	11113E	PARTICIPANT	\N	PRESENT	0
52809	51474	11061K	PARTICIPANT	\N	PRESENT	0
52810	51474	11064N	PARTICIPANT	\N	PRESENT	0
52811	51474	14179A	PARTICIPANT	\N	PRESENT	0
52812	51474	01007L	PARTICIPANT	\N	PRESENT	0
52813	51474	95062K	PARTICIPANT	\N	PRESENT	0
52814	51474	08011M	PARTICIPANT	\N	PRESENT	0
52815	51474	92044U	PARTICIPANT	\N	PRESENT	0
52816	51474	04067M	PARTICIPANT	\N	PRESENT	0
52817	51474	14119M	PARTICIPANT	\N	PRESENT	0
52818	51474	08034U	PARTICIPANT	\N	PRESENT	0
52819	51474	11053K	PARTICIPANT	\N	PRESENT	0
52820	51474	14034U	PARTICIPANT	\N	PRESENT	0
52821	51474	98021N	PARTICIPANT	\N	PRESENT	0
52822	51474	14249W	PARTICIPANT	\N	PRESENT	0
52823	51474	14217N	PARTICIPANT	\N	PRESENT	0
52824	51474	08073C	PARTICIPANT	\N	PRESENT	0
52825	51474	01011G	PARTICIPANT	\N	PRESENT	0
52826	51474	04038G	PARTICIPANT	\N	PRESENT	0
52830	51474	14089Y	PARTICIPANT	\N	PRESENT	0
52828	51474	01043Q	PARTICIPANT	\N	PRESENT	0
52829	51474	11067R	PARTICIPANT	\N	PRESENT	0
52831	51474	11070L	PARTICIPANT	\N	PRESENT	0
55130	54969	11036J	PARTICIPANT	\N	PRESENT	0
55131	54969	14071N	PARTICIPANT	\N	PRESENT	0
55132	54969	14111D	PARTICIPANT	\N	PRESENT	0
55133	54969	14167V	PARTICIPANT	\N	PRESENT	0
55134	54969	98029W	PARTICIPANT	\N	PRESENT	0
55135	54969	08034U	PARTICIPANT	\N	PRESENT	0
55136	54969	92039X	PARTICIPANT	\N	PRESENT	0
55137	54969	14053L	PARTICIPANT	\N	PRESENT	0
55138	54969	08038Y	PARTICIPANT	\N	PRESENT	0
55139	54969	04044E	PARTICIPANT	\N	PRESENT	0
55140	54969	11035H	PARTICIPANT	\N	PRESENT	0
55141	54969	11097X	PARTICIPANT	\N	PRESENT	0
55142	54969	11104D	PARTICIPANT	\N	PRESENT	0
55143	54969	01028R	PARTICIPANT	\N	PRESENT	0
55144	54969	08047A	PARTICIPANT	\N	PRESENT	0
55145	54969	14173T	PARTICIPANT	\N	PRESENT	0
55146	54969	04077P	PARTICIPANT	\N	PRESENT	0
55147	54969	08061X	PARTICIPANT	\N	PRESENT	0
55148	54969	88008L	PARTICIPANT	\N	PRESENT	0
55149	54969	14038Y	PARTICIPANT	\N	PRESENT	0
55150	54969	04078Q	PARTICIPANT	\N	PRESENT	0
55151	54969	14199E	PARTICIPANT	\N	PRESENT	0
55152	54969	14225N	PARTICIPANT	\N	PRESENT	0
55153	54969	11069T	PARTICIPANT	\N	PRESENT	0
55154	54969	14159V	PARTICIPANT	\N	PRESENT	0
55155	54969	14329V	PARTICIPANT	\N	PRESENT	0
55156	54969	14014Q	PARTICIPANT	\N	PRESENT	0
55157	54969	08019V	PARTICIPANT	\N	PRESENT	0
55158	54969	83042R	PARTICIPANT	\N	PRESENT	0
55159	54969	14195A	PARTICIPANT	\N	PRESENT	0
55160	54969	11095V	PARTICIPANT	\N	PRESENT	0
55161	54969	07029T	PARTICIPANT	\N	PRESENT	0
55162	54969	08062Y	PARTICIPANT	\N	PRESENT	0
55163	54969	14013P	PARTICIPANT	\N	PRESENT	0
55164	54969	11063M	PARTICIPANT	\N	PRESENT	0
55165	54969	07032N	PARTICIPANT	\N	PRESENT	0
55166	54969	14093U	PARTICIPANT	\N	PRESENT	0
55167	54969	11031D	PARTICIPANT	\N	PRESENT	0
55168	54969	98023Q	PARTICIPANT	\N	PRESENT	0
55169	54969	08049C	PARTICIPANT	\N	PRESENT	0
55170	54969	14079W	PARTICIPANT	\N	PRESENT	0
55171	54969	11012A	PARTICIPANT	\N	PRESENT	0
55172	54969	14193X	PARTICIPANT	\N	PRESENT	0
55173	54969	08031R	PARTICIPANT	\N	PRESENT	0
55174	54969	08051V	PARTICIPANT	\N	PRESENT	0
55175	54969	04038G	PARTICIPANT	\N	PRESENT	0
55176	54969	14251Q	PARTICIPANT	\N	PRESENT	0
55177	54969	11048N	PARTICIPANT	\N	PRESENT	0
55178	54969	01034P	PARTICIPANT	\N	PRESENT	0
55179	54969	11053K	PARTICIPANT	\N	PRESENT	0
55180	54969	01060R	PARTICIPANT	\N	PRESENT	0
55181	54969	14034U	PARTICIPANT	\N	PRESENT	0
55182	54969	95035G	PARTICIPANT	\N	PRESENT	0
55183	54969	11070L	PARTICIPANT	\N	PRESENT	0
55184	54969	14267Y	PARTICIPANT	\N	PRESENT	0
55185	54969	14147R	PARTICIPANT	\N	PRESENT	0
55186	54969	11064N	PARTICIPANT	\N	PRESENT	0
55187	54969	14103D	PARTICIPANT	\N	PRESENT	0
55188	54969	11043H	PARTICIPANT	\N	PRESENT	0
55189	54969	14239U	PARTICIPANT	\N	PRESENT	0
55190	54969	98022P	PARTICIPANT	\N	PRESENT	0
55191	54969	14241N	PARTICIPANT	\N	PRESENT	0
55192	54969	04070G	PARTICIPANT	\N	PRESENT	0
55241	54969	08010L	PARTICIPANT	\N	PRESENT	0
55194	54969	98042T	PARTICIPANT	\N	PRESENT	0
55195	54969	11093T	PARTICIPANT	\N	PRESENT	0
55196	54969	14237S	PARTICIPANT	\N	PRESENT	0
55197	54969	14175V	PARTICIPANT	\N	PRESENT	0
55198	54969	04040A	PARTICIPANT	\N	PRESENT	0
55199	54969	14255U	PARTICIPANT	\N	PRESENT	0
55200	54969	92045V	PARTICIPANT	\N	PRESENT	0
55201	54969	14083S	PARTICIPANT	\N	PRESENT	0
55202	54969	14275Y	PARTICIPANT	\N	PRESENT	0
55203	54969	04057K	PARTICIPANT	\N	PRESENT	0
55204	54969	14273W	PARTICIPANT	\N	PRESENT	0
55205	54969	14187A	PARTICIPANT	\N	PRESENT	0
55206	54969	14059S	PARTICIPANT	\N	PRESENT	0
55207	54969	14089Y	PARTICIPANT	\N	PRESENT	0
55208	54969	01025N	PARTICIPANT	\N	PRESENT	0
55209	54969	14209N	PARTICIPANT	\N	PRESENT	0
55210	54969	08028W	PARTICIPANT	\N	PRESENT	0
55211	54969	11111C	PARTICIPANT	\N	PRESENT	0
55212	54969	11037K	PARTICIPANT	\N	PRESENT	0
55213	54969	04081K	PARTICIPANT	\N	PRESENT	0
55214	54969	08073C	PARTICIPANT	\N	PRESENT	0
55215	54969	14041T	PARTICIPANT	\N	PRESENT	0
55216	54969	92044U	PARTICIPANT	\N	PRESENT	0
55217	54969	14055N	PARTICIPANT	\N	PRESENT	0
55218	54969	08042U	PARTICIPANT	\N	PRESENT	0
55219	54969	11105E	PARTICIPANT	\N	PRESENT	0
55220	54969	11089X	PARTICIPANT	\N	PRESENT	0
55221	54969	14327T	PARTICIPANT	\N	PRESENT	0
55222	54969	14331P	PARTICIPANT	\N	PRESENT	0
55223	54969	04079R	PARTICIPANT	\N	PRESENT	0
55228	54969	14030Q	PARTICIPANT	\N	PRESENT	0
55225	54969	14105F	PARTICIPANT	\N	PRESENT	0
55226	54969	04053F	PARTICIPANT	\N	PRESENT	0
55227	54969	14042U	PARTICIPANT	\N	PRESENT	0
55242	54969	11056N	PARTICIPANT	\N	PRESENT	0
55230	54969	11049P	PARTICIPANT	\N	PRESENT	0
55231	54969	14033T	PARTICIPANT	\N	PRESENT	0
55232	54969	14026U	PARTICIPANT	\N	PRESENT	0
55233	54969	14065Q	PARTICIPANT	\N	PRESENT	0
55234	54969	14259Y	PARTICIPANT	\N	PRESENT	0
55235	54969	96003C	PARTICIPANT	\N	PRESENT	0
55236	54969	11026G	PARTICIPANT	\N	PRESENT	0
55237	54969	14221J	PARTICIPANT	\N	PRESENT	0
55238	54969	07024N	PARTICIPANT	\N	PRESENT	0
55239	54969	14219Q	PARTICIPANT	\N	PRESENT	0
55240	54969	14037X	PARTICIPANT	\N	PRESENT	0
55243	54969	98053W	PARTICIPANT	\N	PRESENT	0
55244	54969	14213J	PARTICIPANT	\N	PRESENT	0
55245	54969	08015R	PARTICIPANT	\N	PRESENT	0
55246	54969	11083R	PARTICIPANT	\N	PRESENT	0
55247	54969	14207L	PARTICIPANT	\N	PRESENT	0
55248	54969	11099A	PARTICIPANT	\N	PRESENT	0
55249	54969	08065C	PARTICIPANT	\N	PRESENT	0
55250	54969	08068F	PARTICIPANT	\N	PRESENT	0
55251	54969	14087W	PARTICIPANT	\N	PRESENT	0
55252	54969	08018U	PARTICIPANT	\N	PRESENT	0
55253	54969	14247U	PARTICIPANT	\N	PRESENT	0
55254	54969	14069U	PARTICIPANT	\N	PRESENT	0
55255	54969	96004D	PARTICIPANT	\N	PRESENT	0
55256	54969	11090Q	PARTICIPANT	\N	PRESENT	0
55257	54969	04059M	PARTICIPANT	\N	PRESENT	0
55258	54969	14135M	PARTICIPANT	\N	PRESENT	0
55259	54969	80013X	PARTICIPANT	\N	PRESENT	0
55260	54969	95059Q	PARTICIPANT	\N	PRESENT	0
55308	54969	04092N	PARTICIPANT	\N	PRESENT	0
55262	54969	04086Q	PARTICIPANT	\N	PRESENT	0
55263	54969	11044J	PARTICIPANT	\N	PRESENT	0
55265	54969	04033B	PARTICIPANT	\N	PRESENT	0
55266	54969	08052W	PARTICIPANT	\N	PRESENT	0
55267	54969	11014C	PARTICIPANT	\N	PRESENT	0
55268	54969	04055H	PARTICIPANT	\N	PRESENT	0
55269	54969	14157T	PARTICIPANT	\N	PRESENT	0
55270	54969	14119M	PARTICIPANT	\N	PRESENT	0
55271	54969	14097Y	PARTICIPANT	\N	PRESENT	0
55272	54969	14269B	PARTICIPANT	\N	PRESENT	0
55273	54969	11015D	PARTICIPANT	\N	PRESENT	0
55274	54969	04042C	PARTICIPANT	\N	PRESENT	0
55275	54969	01057W	PARTICIPANT	\N	PRESENT	0
55301	54969	90003B	PARTICIPANT	\N	PRESENT	0
55277	54969	01048V	PARTICIPANT	\N	PRESENT	0
55278	54969	14215L	PARTICIPANT	\N	PRESENT	0
55286	54969	95063L	PARTICIPANT	\N	PRESENT	0
55280	54969	08041T	PARTICIPANT	\N	PRESENT	0
55281	54969	14061L	PARTICIPANT	\N	PRESENT	0
55291	54969	14133K	PARTICIPANT	\N	PRESENT	0
55284	54969	01043Q	PARTICIPANT	\N	PRESENT	0
55285	54969	08009T	PARTICIPANT	\N	PRESENT	0
55287	54969	05008E	PARTICIPANT	\N	PRESENT	0
55305	54969	86044G	PARTICIPANT	\N	PRESENT	0
55289	54969	14151M	PARTICIPANT	\N	PRESENT	0
55290	54969	09001P	PARTICIPANT	\N	PRESENT	0
55306	54969	95067Q	PARTICIPANT	\N	PRESENT	0
55303	54969	11100Y	PARTICIPANT	\N	PRESENT	0
55302	54969	04049K	PARTICIPANT	\N	PRESENT	0
55304	54969	04074L	PARTICIPANT	\N	PRESENT	0
55296	54969	08039A	PARTICIPANT	\N	PRESENT	0
55297	54969	14109K	PARTICIPANT	\N	PRESENT	0
55298	54969	11057P	PARTICIPANT	\N	PRESENT	0
55299	54969	10015M	PARTICIPANT	\N	PRESENT	0
55300	54969	01047U	PARTICIPANT	\N	PRESENT	0
55310	54969	83047W	PARTICIPANT	\N	PRESENT	0
55309	54969	11023D	PARTICIPANT	\N	PRESENT	0
55312	54969	11085T	PARTICIPANT	\N	PRESENT	0
33048	33047	11027H	PARTICIPANT	\N	PRESENT	0
33049	33047	97011G	PARTICIPANT	\N	PRESENT	0
33050	33047	11061K	PARTICIPANT	\N	PRESENT	0
33051	33047	04036E	PARTICIPANT	\N	PRESENT	0
33052	33047	04077P	PARTICIPANT	\N	PRESENT	0
33053	33047	04049K	PARTICIPANT	\N	PRESENT	0
33054	33047	95067Q	PARTICIPANT	\N	PRESENT	0
33055	33047	01056V	PARTICIPANT	\N	PRESENT	0
33056	33047	11046L	PARTICIPANT	\N	PRESENT	0
33057	33047	04070G	PARTICIPANT	\N	PRESENT	0
33058	33047	98029W	PARTICIPANT	\N	PRESENT	0
33061	33060	11074Q	PARTICIPANT	\N	PRESENT	0
33062	33060	88008L	PARTICIPANT	\N	PRESENT	0
33063	33060	11012A	PARTICIPANT	\N	PRESENT	0
35964	35961	04044E	PARTICIPANT	\N	PRESENT	0
36970	36967	08043V	PARTICIPANT	\N	PRESENT	0
36972	36967	80013X	PARTICIPANT	\N	PRESENT	0
36973	36967	14030Q	PARTICIPANT	\N	PRESENT	0
36974	36967	11029K	PARTICIPANT	\N	PRESENT	0
36975	36967	11067R	PRESIDENT	1	PRESENT	0
36976	36967	07026Q	PRESIDENT	0	PRESENT	0
36977	36967	08060W	PARTICIPANT	\N	EXCUSE	0
36978	36967	95035G	PARTICIPANT	\N	EXCUSE	0
36979	36967	14059S	PARTICIPANT	\N	EXCUSE	0
43161	41881	11014C	PARTICIPANT	\N	PRESENT	0
43162	41881	01034P	PARTICIPANT	\N	PRESENT	0
43163	41881	01046T	PARTICIPANT	\N	PRESENT	0
43164	41881	01048V	PARTICIPANT	\N	PRESENT	0
43168	41881	01059Y	PARTICIPANT	\N	PRESENT	0
43169	41881	98053W	PARTICIPANT	\N	PRESENT	0
43170	41881	14197C	PARTICIPANT	\N	PRESENT	0
43171	41881	14034U	PARTICIPANT	\N	PRESENT	0
43172	41881	14205J	PARTICIPANT	\N	PRESENT	0
43173	41881	11093T	PARTICIPANT	\N	PRESENT	0
43174	41881	01025N	PARTICIPANT	\N	PRESENT	0
43175	41881	04070G	PARTICIPANT	\N	PRESENT	0
43176	41881	14217N	PARTICIPANT	\N	PRESENT	0
43177	41881	04092N	PARTICIPANT	\N	PRESENT	0
43178	41881	95015C	PARTICIPANT	\N	PRESENT	0
43179	41881	08073C	PARTICIPANT	\N	PRESENT	0
43180	41881	11069T	PARTICIPANT	\N	PRESENT	0
43181	41881	98046X	PARTICIPANT	\N	PRESENT	0
43182	41881	14097Y	PARTICIPANT	\N	PRESENT	0
43183	41881	08015R	PARTICIPANT	\N	PRESENT	0
43184	41881	11082Q	PARTICIPANT	\N	PRESENT	0
43211	41881	14135M	PARTICIPANT	\N	PRESENT	0
43214	41881	11104D	PARTICIPANT	\N	PRESENT	0
43218	41881	11097X	PARTICIPANT	\N	PRESENT	0
43219	41881	04053F	PARTICIPANT	\N	PRESENT	0
43220	41881	08010L	PARTICIPANT	\N	PRESENT	0
43221	41881	07026Q	PARTICIPANT	\N	PRESENT	0
43242	41881	01019Q	PARTICIPANT	\N	PRESENT	0
43243	41881	01024M	PARTICIPANT	\N	PRESENT	0
43323	43241	07026Q	PARTICIPANT	\N	PRESENT	0
43324	43241	01031L	PARTICIPANT	\N	PRESENT	0
43325	43241	95062K	PARTICIPANT	\N	PRESENT	0
43326	43241	14121F	PARTICIPANT	\N	PRESENT	0
43327	43241	01019Q	PARTICIPANT	\N	PRESENT	0
43328	43241	98046X	PARTICIPANT	\N	PRESENT	0
43329	43241	08010L	PARTICIPANT	\N	PRESENT	0
43330	43241	04092N	PARTICIPANT	\N	PRESENT	0
43331	43241	11067R	PARTICIPANT	\N	PRESENT	0
43332	43241	01057W	PARTICIPANT	\N	PRESENT	0
43333	43241	80013X	PARTICIPANT	\N	PRESENT	0
43334	43241	04088S	PARTICIPANT	\N	PRESENT	0
43335	43241	14197C	PARTICIPANT	\N	PRESENT	0
43336	43241	14041T	PARTICIPANT	\N	PRESENT	0
43337	43241	14097Y	PARTICIPANT	\N	PRESENT	0
43338	43241	14213J	PARTICIPANT	\N	PRESENT	0
43339	43241	04034C	PARTICIPANT	\N	PRESENT	0
43340	43241	11097X	PARTICIPANT	\N	PRESENT	0
43341	43241	14159V	PARTICIPANT	\N	PRESENT	0
43364	43241	14069U	PARTICIPANT	\N	PRESENT	0
43343	43241	14085U	PARTICIPANT	\N	PRESENT	0
43345	43241	14237S	PARTICIPANT	\N	PRESENT	0
43346	43241	11104D	PARTICIPANT	\N	PRESENT	0
43348	43241	11042G	PARTICIPANT	\N	PRESENT	0
43349	43241	04053F	PARTICIPANT	\N	PRESENT	0
43350	43241	08061X	PARTICIPANT	\N	PRESENT	0
43351	43241	01046T	PARTICIPANT	\N	PRESENT	0
43352	43241	11012A	PARTICIPANT	\N	PRESENT	0
43353	43241	14034U	PARTICIPANT	\N	PRESENT	0
43354	43241	11082Q	PARTICIPANT	\N	PRESENT	0
43355	43241	14231L	PARTICIPANT	\N	PRESENT	0
43356	43241	14083S	PARTICIPANT	\N	PRESENT	0
43357	43241	01024M	PARTICIPANT	\N	PRESENT	0
43358	43241	11043H	PARTICIPANT	\N	PRESENT	0
43359	43241	14217N	PARTICIPANT	\N	PRESENT	0
43360	43241	04067M	PARTICIPANT	\N	PRESENT	0
43361	43241	07029T	PARTICIPANT	\N	PRESENT	0
43362	43241	14081Q	PARTICIPANT	\N	PRESENT	0
43363	43241	11105E	PARTICIPANT	\N	PRESENT	0
43365	43241	14205J	PARTICIPANT	\N	PRESENT	0
43366	43241	11074Q	PARTICIPANT	\N	PRESENT	0
43369	43241	08034U	PARTICIPANT	\N	PRESENT	0
43370	43241	11031D	PARTICIPANT	\N	PRESENT	0
43377	43241	01025N	PARTICIPANT	\N	PRESENT	0
43378	43241	08015R	PARTICIPANT	\N	PRESENT	0
43379	43241	14169X	PARTICIPANT	\N	PRESENT	0
43380	43241	08017T	PARTICIPANT	\N	PRESENT	0
43381	43241	14269B	PARTICIPANT	\N	PRESENT	0
43382	43241	14241N	PARTICIPANT	\N	PRESENT	0
43383	43241	11036J	PARTICIPANT	\N	PRESENT	0
43384	43241	11112D	PARTICIPANT	\N	PRESENT	0
43385	43241	14199E	PARTICIPANT	\N	PRESENT	0
43386	43241	92045V	PARTICIPANT	\N	PRESENT	0
43387	43241	08011M	PARTICIPANT	\N	PRESENT	0
43388	43241	08031R	PARTICIPANT	\N	PRESENT	0
43389	43241	01037S	PARTICIPANT	\N	PRESENT	0
43390	43241	11014C	PARTICIPANT	\N	PRESENT	0
43449	43244	08024S	PARTICIPANT	\N	PRESENT	0
43450	43244	07026Q	PARTICIPANT	\N	PRESENT	0
43451	43244	14235Q	PARTICIPANT	\N	PRESENT	0
43452	43244	08043V	PARTICIPANT	\N	PRESENT	0
43453	43244	08017T	PARTICIPANT	\N	PRESENT	0
43454	43244	11104D	PARTICIPANT	\N	PRESENT	0
43455	43244	01048V	PARTICIPANT	\N	PRESENT	0
43456	43244	98053W	PARTICIPANT	\N	PRESENT	0
43457	43244	01031L	PARTICIPANT	\N	PRESENT	0
43458	43244	14207L	PARTICIPANT	\N	PRESENT	0
43459	43244	11042G	PARTICIPANT	\N	PRESENT	0
43460	43244	01044R	PARTICIPANT	\N	PRESENT	0
43461	43244	11029K	PARTICIPANT	\N	PRESENT	0
43462	43244	04070G	PARTICIPANT	\N	PRESENT	0
43463	43244	01025N	PARTICIPANT	\N	PRESENT	0
43464	43244	14059S	PARTICIPANT	\N	PRESENT	0
43465	43244	04057K	PARTICIPANT	\N	PRESENT	0
43466	43244	08015R	PARTICIPANT	\N	PRESENT	0
43467	43244	11043H	PARTICIPANT	\N	PRESENT	0
43321	43241	08055A	PARTICIPANT	\N	PRESENT	0
43322	43241	01059Y	PARTICIPANT	\N	PRESENT	0
43468	43244	95062K	PARTICIPANT	\N	PRESENT	0
43469	43244	14197C	PARTICIPANT	\N	PRESENT	0
43470	43244	14219Q	PARTICIPANT	\N	PRESENT	0
43471	43244	14237S	PARTICIPANT	\N	PRESENT	0
43472	43244	14241N	PARTICIPANT	\N	PRESENT	0
43473	43244	08031R	PARTICIPANT	\N	PRESENT	0
43474	43244	14261S	PARTICIPANT	\N	PRESENT	0
43475	43244	14231L	PARTICIPANT	\N	PRESENT	0
43476	43244	14123H	PARTICIPANT	\N	PRESENT	0
43477	43244	11074Q	PARTICIPANT	\N	PRESENT	0
43478	43244	95015C	PARTICIPANT	\N	PRESENT	0
43479	43244	14034U	PARTICIPANT	\N	PRESENT	0
43480	43244	14073Q	PARTICIPANT	\N	PRESENT	0
43481	43244	14083S	PARTICIPANT	\N	PRESENT	0
43482	43244	14061L	PARTICIPANT	\N	PRESENT	0
43483	43244	01059Y	PARTICIPANT	\N	PRESENT	0
43484	43244	08034U	PARTICIPANT	\N	PRESENT	0
43485	43244	14097Y	PARTICIPANT	\N	PRESENT	0
43486	43244	08039A	PARTICIPANT	\N	PRESENT	0
43487	43244	14030Q	PARTICIPANT	\N	PRESENT	0
43488	43244	80013X	PARTICIPANT	\N	PRESENT	0
43489	43244	14169X	PARTICIPANT	\N	PRESENT	0
43490	43244	14217N	PARTICIPANT	\N	PRESENT	0
43491	43244	08061X	PARTICIPANT	\N	PRESENT	0
43492	43244	14121F	PARTICIPANT	\N	PRESENT	0
43493	43244	04088S	PARTICIPANT	\N	PRESENT	0
43494	43244	11014C	PARTICIPANT	\N	PRESENT	0
43495	43244	14179A	PARTICIPANT	\N	PRESENT	0
43496	43244	01057W	PARTICIPANT	\N	PRESENT	0
43497	43244	14265W	PARTICIPANT	\N	PRESENT	0
43498	43244	92045V	PARTICIPANT	\N	PRESENT	0
43499	43244	11036J	PARTICIPANT	\N	PRESENT	0
43500	43244	11089X	PARTICIPANT	\N	PRESENT	0
43501	43244	14133K	PARTICIPANT	\N	PRESENT	0
43688	43585	11035H	PARTICIPANT	\N	EXCUSE	0
43689	43585	14001X	PARTICIPANT	\N	EXCUSE	0
43690	43585	08042U	PARTICIPANT	\N	EXCUSE	0
56302	56261	11067R	PARTICIPANT	\N	PRESENT	0
56303	56261	14223L	PARTICIPANT	\N	PRESENT	0
56304	56261	04092N	PRESIDENT	0	PRESENT	0
56305	56261	14265W	PARTICIPANT	\N	PRESENT	0
56306	56261	14119M	PARTICIPANT	\N	PRESENT	0
56307	56261	14071N	PARTICIPANT	\N	PRESENT	0
56416	56415	92015P	PARTICIPANT	\N	EXCUSE	0
56309	56261	04043D	PARTICIPANT	\N	PRESENT	0
56417	56415	14263U	PARTICIPANT	\N	PRESENT	0
56311	56261	14017T	PARTICIPANT	\N	PRESENT	0
56312	56261	11093T	PARTICIPANT	\N	PRESENT	0
56313	56261	11097X	PARTICIPANT	\N	PRESENT	0
56314	56261	04045F	PARTICIPANT	\N	PRESENT	0
56315	56261	14227Q	PARTICIPANT	\N	PRESENT	0
56316	56261	01034P	PARTICIPANT	\N	PRESENT	0
56318	56261	11025F	PARTICIPANT	\N	PRESENT	0
56319	56261	11063M	PARTICIPANT	\N	PRESENT	0
56320	56261	14269B	PARTICIPANT	\N	PRESENT	0
56418	56415	14133K	PARTICIPANT	\N	PRESENT	0
56419	56415	11109J	PARTICIPANT	\N	PRESENT	0
56420	56415	04059M	PARTICIPANT	\N	PRESENT	0
56421	56415	11039M	PARTICIPANT	\N	PRESENT	0
56422	56415	01044R	PARTICIPANT	\N	PRESENT	0
56423	56415	08043V	PARTICIPANT	\N	PRESENT	0
56424	56415	14089Y	PARTICIPANT	\N	PRESENT	0
56425	56415	14105F	PARTICIPANT	\N	PRESENT	0
56426	56415	11029K	PARTICIPANT	\N	PRESENT	0
56427	56415	95015C	PARTICIPANT	\N	PRESENT	0
56428	56415	08024S	PARTICIPANT	\N	PRESENT	0
56429	56415	14201E	PARTICIPANT	\N	EXCUSE	0
56430	56415	14329V	PARTICIPANT	\N	PRESENT	0
56431	56415	14209N	PARTICIPANT	\N	PRESENT	0
56432	56415	14079W	PARTICIPANT	\N	PRESENT	0
56433	56415	11091R	PARTICIPANT	\N	PRESENT	0
56434	56415	87003B	PARTICIPANT	\N	PRESENT	0
56435	56415	98042T	PARTICIPANT	\N	PRESENT	0
56436	56415	14249W	PARTICIPANT	\N	EXCUSE	0
56741	56740	08025T	PARTICIPANT	\N	PRESENT	0
56438	56415	01025N	PARTICIPANT	\N	PRESENT	0
56742	56740	04085P	PARTICIPANT	\N	PRESENT	0
56440	56415	89029V	PARTICIPANT	\N	PRESENT	0
56441	56415	08035V	PARTICIPANT	\N	PRESENT	0
56442	56415	11089X	PARTICIPANT	\N	PRESENT	0
56443	56415	07026Q	PARTICIPANT	\N	PRESENT	0
56444	56415	14123H	PARTICIPANT	\N	PRESENT	0
56445	56415	14179A	PARTICIPANT	\N	PRESENT	0
56446	56415	04041B	PARTICIPANT	\N	PRESENT	0
56447	56415	14241N	PARTICIPANT	\N	PRESENT	0
56448	56415	14061L	PARTICIPANT	\N	PRESENT	0
56449	56415	14073Q	PARTICIPANT	\N	PRESENT	0
56450	56415	08031R	PARTICIPANT	\N	PRESENT	0
56451	56415	12041X	PARTICIPANT	\N	PRESENT	0
56452	56415	08039A	PARTICIPANT	\N	PRESENT	0
56790	56740	14089Y	PARTICIPANT	\N	PRESENT	0
56454	56415	14059S	PARTICIPANT	\N	PRESENT	0
56455	56415	08012N	PARTICIPANT	\N	PRESENT	0
56456	56415	14103D	PARTICIPANT	\N	PRESENT	0
56457	56415	11104D	PARTICIPANT	\N	PRESENT	0
56458	56415	14063N	PARTICIPANT	\N	PRESENT	0
56459	56415	04057K	PARTICIPANT	\N	PRESENT	0
56460	56415	11014C	PARTICIPANT	\N	PRESENT	0
56461	56415	14109K	PARTICIPANT	\N	PRESENT	0
56462	56415	04070G	PRESIDENT	0	PRESENT	0
56463	56415	92040Q	PARTICIPANT	\N	PRESENT	0
56464	56415	14191V	PARTICIPANT	\N	PRESENT	0
56465	56415	83047W	PARTICIPANT	\N	PRESENT	0
56466	56415	14235Q	PARTICIPANT	\N	PRESENT	0
56467	56415	14055N	PARTICIPANT	\N	PRESENT	0
56468	56415	04033B	PARTICIPANT	\N	PRESENT	0
56469	56415	14229S	PARTICIPANT	\N	PRESENT	0
56470	56415	11043H	PARTICIPANT	\N	PRESENT	0
56949	54794	14030Q	PARTICIPANT	\N	PRESENT	0
56472	56415	11011M	PARTICIPANT	\N	PRESENT	0
56743	56740	05008E	PRESIDENT	0	PRESENT	0
56950	54794	14083S	PARTICIPANT	\N	PRESENT	0
56745	56740	11033F	PARTICIPANT	\N	PRESENT	0
56746	56740	14065Q	PARTICIPANT	\N	PRESENT	0
56747	56740	14069U	PARTICIPANT	\N	PRESENT	0
56748	56740	04047H	PARTICIPANT	\N	PRESENT	0
56749	56740	11032E	PARTICIPANT	\N	PRESENT	0
56750	56740	04038G	PARTICIPANT	\N	PRESENT	0
56951	54797	14030Q	PARTICIPANT	\N	PRESENT	0
56752	56740	11056N	PARTICIPANT	\N	PRESENT	0
56753	56740	14259Y	PARTICIPANT	\N	PRESENT	0
56754	56740	11035H	PARTICIPANT	\N	PRESENT	0
56755	56740	14041T	PARTICIPANT	\N	PRESENT	0
56756	56740	11113E	PARTICIPANT	\N	PRESENT	0
56757	56740	01024M	PARTICIPANT	\N	PRESENT	0
56758	56740	14215L	PARTICIPANT	\N	PRESENT	0
56759	56740	11034G	PARTICIPANT	\N	PRESENT	0
56760	56740	08018U	PARTICIPANT	\N	PRESENT	0
56761	56740	11010L	PARTICIPANT	\N	PRESENT	0
56762	56740	01007L	PARTICIPANT	\N	PRESENT	0
56763	56740	11049P	PARTICIPANT	\N	PRESENT	0
56952	54797	14083S	PARTICIPANT	\N	PRESENT	0
56765	56740	11084S	PARTICIPANT	\N	PRESENT	0
56766	56740	11026G	PARTICIPANT	\N	PRESENT	0
56767	56740	04079R	PARTICIPANT	\N	PRESENT	0
56768	56740	14111D	PARTICIPANT	\N	PRESENT	0
56769	56740	14001X	PARTICIPANT	\N	PRESENT	0
56770	56740	14273W	PARTICIPANT	\N	PRESENT	0
56771	56740	01060R	PARTICIPANT	\N	PRESENT	0
56772	56740	14147R	PARTICIPANT	\N	PRESENT	0
56773	56740	95049N	PARTICIPANT	\N	PRESENT	0
56774	56740	08051V	PARTICIPANT	\N	PRESENT	0
56775	56740	11072N	PARTICIPANT	\N	PRESENT	0
56776	56740	07034Q	PARTICIPANT	\N	PRESENT	0
56777	56740	04074L	PARTICIPANT	\N	PRESENT	0
56778	56740	10015M	PARTICIPANT	\N	PRESENT	0
56779	56740	95063L	PARTICIPANT	\N	PRESENT	0
56780	56740	01019Q	PARTICIPANT	\N	PRESENT	0
56781	56740	01028R	PARTICIPANT	\N	PRESENT	0
56782	56740	98035U	PARTICIPANT	\N	PRESENT	0
56783	56740	04056J	PARTICIPANT	\N	PRESENT	0
56784	56740	14275Y	PARTICIPANT	\N	PRESENT	0
56785	56740	04044E	PARTICIPANT	\N	PRESENT	0
56786	56740	11037K	PARTICIPANT	\N	PRESENT	0
56787	56740	92045V	PARTICIPANT	\N	PRESENT	0
56788	56740	95067Q	PARTICIPANT	\N	PRESENT	0
56789	56740	01047U	PARTICIPANT	\N	PRESENT	0
57278	52499	04049K	PARTICIPANT	\N	PRESENT	0
57279	52499	14105F	PARTICIPANT	\N	PRESENT	0
57816	57815	01008M	PARTICIPANT	\N	PRESENT	0
57817	57815	11029K	PARTICIPANT	\N	PRESENT	0
57818	57815	04038G	PARTICIPANT	\N	PRESENT	0
57820	57815	14257W	PARTICIPANT	\N	PRESENT	0
58092	54852	04040A	PRESIDENT	0	PRESENT	0
58093	54852	95067Q	PARTICIPANT	\N	EXCUSE	0
58640	54852	11098Y	PARTICIPANT	\N	EXCUSE	0
58967	58964	05012A	PRESIDENT	0	PRESENT	0
58969	58964	08038Y	PARTICIPANT	\N	PRESENT	0
58970	58964	11101A	PARTICIPANT	\N	PRESENT	0
59008	58964	14030Q	PARTICIPANT	\N	PRESENT	0
59010	58964	14013P	PARTICIPANT	\N	PRESENT	0
59251	59250	01031L	PARTICIPANT	\N	PRESENT	0
59252	59250	95015C	PARTICIPANT	\N	PRESENT	0
59253	59250	14038Y	PARTICIPANT	\N	PRESENT	0
59254	59250	08028W	PARTICIPANT	\N	PRESENT	0
59255	59250	04038G	PARTICIPANT	\N	PRESENT	0
59256	59250	11027H	PARTICIPANT	\N	PRESENT	0
59257	59250	01027Q	PARTICIPANT	\N	PRESENT	0
59258	59250	11091R	PARTICIPANT	\N	PRESENT	0
59259	59250	01041N	PARTICIPANT	\N	PRESENT	0
59260	59250	97011G	PARTICIPANT	\N	PRESENT	0
59261	59250	11089X	PARTICIPANT	\N	PRESENT	0
59262	59250	95035G	PARTICIPANT	\N	PRESENT	0
59263	59250	98005N	PARTICIPANT	\N	PRESENT	0
59264	59250	92031P	PARTICIPANT	\N	PRESENT	0
59265	59250	14037X	PARTICIPANT	\N	PRESENT	0
59267	59266	01031L	PARTICIPANT	\N	PRESENT	0
59268	59266	08043V	PARTICIPANT	\N	PRESENT	0
59269	59266	14175V	PARTICIPANT	\N	PRESENT	0
59270	59266	14207L	PARTICIPANT	\N	PRESENT	0
59271	59266	95015C	PARTICIPANT	\N	PRESENT	0
59272	59266	14038Y	PARTICIPANT	\N	PRESENT	0
59273	59266	08028W	PARTICIPANT	\N	PRESENT	0
59274	59266	11023D	PARTICIPANT	\N	PRESENT	0
59275	59266	04038G	PARTICIPANT	\N	PRESENT	0
59276	59266	11027H	PARTICIPANT	\N	PRESENT	0
59277	59266	14041T	PARTICIPANT	\N	PRESENT	0
59278	59266	01027Q	PARTICIPANT	\N	PRESENT	0
59279	59266	11091R	PARTICIPANT	\N	PRESENT	0
59280	59266	01041N	PARTICIPANT	\N	PRESENT	0
59281	59266	97011G	PARTICIPANT	\N	PRESENT	0
59282	59266	01037S	PARTICIPANT	\N	PRESENT	0
59283	59266	11083R	PARTICIPANT	\N	PRESENT	0
59284	59266	11089X	PARTICIPANT	\N	PRESENT	0
59285	59266	95035G	PARTICIPANT	\N	PRESENT	0
59286	59266	14179A	PARTICIPANT	\N	PRESENT	0
48937	48936	14263U	PARTICIPANT	\N	EXCUSE	0
37082	37080	14133K	PARTICIPANT	\N	PRESENT	0
37083	37080	11109J	PARTICIPANT	\N	PRESENT	0
48938	48936	14133K	PARTICIPANT	\N	PRESENT	0
49008	49004	14263U	PARTICIPANT	\N	EXCUSE	0
37086	37080	01044R	PARTICIPANT	\N	PRESENT	0
37087	37080	08043V	PARTICIPANT	\N	PRESENT	0
37088	37080	14089Y	PARTICIPANT	\N	PRESENT	0
37089	37080	14105F	PARTICIPANT	\N	PRESENT	0
37090	37080	11029K	PARTICIPANT	\N	PRESENT	0
37091	37080	95015C	PARTICIPANT	\N	PRESENT	0
37092	37080	92015P	PARTICIPANT	\N	EXCUSE	0
37093	37080	08024S	PARTICIPANT	\N	PRESENT	0
48940	48936	04059M	PARTICIPANT	\N	PRESENT	0
48941	48936	11039M	PARTICIPANT	\N	PRESENT	0
48942	48936	01044R	PARTICIPANT	\N	PRESENT	0
37097	37080	14079W	PARTICIPANT	\N	PRESENT	0
37098	37080	11091R	PARTICIPANT	\N	PRESENT	0
48943	48936	08043V	PARTICIPANT	\N	PRESENT	0
48944	48936	14089Y	PARTICIPANT	\N	PRESENT	0
37101	37080	14249W	PARTICIPANT	\N	PRESENT	0
48945	48936	14105F	PARTICIPANT	\N	PRESENT	0
48946	48936	11029K	PARTICIPANT	\N	PRESENT	0
48947	48936	95015C	PARTICIPANT	\N	PRESENT	0
48948	48936	92015P	PARTICIPANT	\N	PRESENT	0
48949	48936	08024S	PARTICIPANT	\N	PRESENT	0
37107	37080	11089X	PARTICIPANT	\N	PRESENT	0
37108	37080	07026Q	PARTICIPANT	\N	PRESENT	0
37109	37080	14123H	PARTICIPANT	\N	PRESENT	0
49009	49004	14133K	PARTICIPANT	\N	PRESENT	0
48951	48936	14329V	PARTICIPANT	\N	PRESENT	0
37112	37080	14241N	PARTICIPANT	\N	PRESENT	0
37113	37080	14061L	PARTICIPANT	\N	PRESENT	0
37114	37080	14073Q	PARTICIPANT	\N	PRESENT	0
37115	37080	08031R	PARTICIPANT	\N	PRESENT	0
48952	48936	14209N	PARTICIPANT	\N	PRESENT	0
37117	37080	08039A	PARTICIPANT	\N	PRESENT	0
37118	37080	08017T	PARTICIPANT	\N	PRESENT	0
37119	37080	14059S	PARTICIPANT	\N	PRESENT	0
37120	37080	08012N	PARTICIPANT	\N	PRESENT	0
48953	48936	14079W	PARTICIPANT	\N	PRESENT	0
48954	48936	11091R	PARTICIPANT	\N	PRESENT	0
37123	37080	14063N	PARTICIPANT	\N	PRESENT	0
37124	37080	04057K	PARTICIPANT	\N	PRESENT	0
49071	49004	04033B	PARTICIPANT	\N	PRESENT	0
37126	37080	14109K	PARTICIPANT	\N	EXCUSE	0
37127	37080	04070G	PRESIDENT	0	PRESENT	0
48956	48936	98042T	PARTICIPANT	\N	PRESENT	0
48957	48936	14249W	PARTICIPANT	\N	PRESENT	0
49011	49004	04059M	PARTICIPANT	\N	PRESENT	0
37131	37080	14235Q	PARTICIPANT	\N	PRESENT	0
48959	48936	01025N	PARTICIPANT	\N	PRESENT	0
49121	49004	07026Q	PARTICIPANT	\N	EXCUSE	0
49013	49004	01044R	PARTICIPANT	\N	PRESENT	0
37135	37080	11043H	PARTICIPANT	\N	PRESENT	0
37136	37080	11071M	PARTICIPANT	\N	PRESENT	0
49014	49004	08043V	PARTICIPANT	\N	PRESENT	0
49122	49004	14235Q	PARTICIPANT	\N	EXCUSE	0
48963	48936	11089X	PARTICIPANT	\N	PRESENT	0
48964	48936	07026Q	PARTICIPANT	\N	EXCUSE	0
49323	49322	01047U	PARTICIPANT	\N	PRESENT	0
48966	48936	14179A	PARTICIPANT	\N	PRESENT	0
48967	48936	04041B	PARTICIPANT	\N	PRESENT	0
48968	48936	14241N	PARTICIPANT	\N	PRESENT	0
48969	48936	14061L	PARTICIPANT	\N	PRESENT	0
48970	48936	14073Q	PARTICIPANT	\N	PRESENT	0
48971	48936	08031R	PARTICIPANT	\N	PRESENT	0
48972	48936	12041X	PARTICIPANT	\N	PRESENT	0
48973	48936	08039A	PARTICIPANT	\N	PRESENT	0
48974	48936	08017T	PARTICIPANT	\N	PRESENT	0
48975	48936	14059S	PARTICIPANT	\N	PRESENT	0
48976	48936	08012N	PARTICIPANT	\N	PRESENT	0
48977	48936	14103D	PARTICIPANT	\N	PRESENT	0
48978	48936	11104D	PARTICIPANT	\N	PRESENT	0
49017	49004	11029K	PARTICIPANT	\N	PRESENT	0
48980	48936	04057K	PARTICIPANT	\N	PRESENT	0
48981	48936	11014C	PARTICIPANT	\N	PRESENT	0
48982	48936	14109K	PARTICIPANT	\N	PRESENT	0
48983	48936	04070G	PRESIDENT	0	PRESENT	0
48984	48936	92040Q	PARTICIPANT	\N	PRESENT	0
48985	48936	14191V	PARTICIPANT	\N	PRESENT	0
48986	48936	83047W	PARTICIPANT	\N	PRESENT	0
48987	48936	14235Q	PARTICIPANT	\N	EXCUSE	0
49018	49004	95015C	PARTICIPANT	\N	PRESENT	0
48989	48936	04033B	PARTICIPANT	\N	PRESENT	0
48990	48936	14229S	PARTICIPANT	\N	PRESENT	0
48991	48936	11043H	PARTICIPANT	\N	PRESENT	0
48992	48936	11071M	PARTICIPANT	\N	PRESENT	0
49352	49351	11039M	PARTICIPANT	\N	PRESENT	0
49353	49351	98042T	PARTICIPANT	\N	PRESENT	0
49354	49351	01019Q	PARTICIPANT	\N	PRESENT	0
49873	49872	01058X	PARTICIPANT	\N	PRESENT	0
49875	49874	01058X	PARTICIPANT	\N	PRESENT	0
49023	49004	14209N	PARTICIPANT	\N	PRESENT	0
52316	49835	14201E	PARTICIPANT	\N	EXCUSE	0
49025	49004	11091R	PARTICIPANT	\N	PRESENT	0
49026	49004	87003B	PARTICIPANT	\N	PRESENT	0
53142	52278	08024S	PARTICIPANT	\N	PRESENT	0
49028	49004	14249W	PARTICIPANT	\N	PRESENT	0
53143	52278	08009T	PARTICIPANT	\N	PRESENT	0
49030	49004	01025N	PARTICIPANT	\N	PRESENT	0
53144	52278	11090Q	PARTICIPANT	\N	PRESENT	0
53145	52278	14191V	PARTICIPANT	\N	PRESENT	0
53146	52278	98005N	PARTICIPANT	\N	PRESENT	0
49034	49004	11089X	PARTICIPANT	\N	PRESENT	0
53147	52278	14041T	PARTICIPANT	\N	PRESENT	0
49036	49004	14123H	PARTICIPANT	\N	PRESENT	0
49037	49004	14179A	PARTICIPANT	\N	PRESENT	0
53148	52278	14195A	PARTICIPANT	\N	PRESENT	0
49039	49004	14241N	PARTICIPANT	\N	PRESENT	0
53149	52278	11049P	PARTICIPANT	\N	PRESENT	0
53150	52278	08062Y	PARTICIPANT	\N	PRESENT	0
49042	49004	08031R	PARTICIPANT	\N	PRESENT	0
53151	52278	07032N	PARTICIPANT	\N	PRESENT	0
49044	49004	08039A	PARTICIPANT	\N	PRESENT	0
53152	52278	05012A	PARTICIPANT	\N	PRESENT	0
49046	49004	14059S	PARTICIPANT	\N	PRESENT	0
49047	49004	08012N	PARTICIPANT	\N	PRESENT	0
49048	49004	14103D	PARTICIPANT	\N	PRESENT	0
53153	52278	04049K	PARTICIPANT	\N	PRESENT	0
53154	52278	11097X	PARTICIPANT	\N	PRESENT	0
49051	49004	04057K	PARTICIPANT	\N	PRESENT	0
49052	49004	11014C	PARTICIPANT	\N	PRESENT	0
49053	49004	14109K	PARTICIPANT	\N	PRESENT	0
49054	49004	04070G	PRESIDENT	0	PRESENT	0
49055	49004	92040Q	PARTICIPANT	\N	PRESENT	0
53155	52278	98023Q	PARTICIPANT	\N	PRESENT	0
49057	49004	83047W	PARTICIPANT	\N	PRESENT	0
53156	52278	14093U	PARTICIPANT	\N	PRESENT	0
53157	52278	01008M	PARTICIPANT	\N	PRESENT	0
53158	52278	01061S	PARTICIPANT	\N	PRESENT	0
49061	49004	14229S	PARTICIPANT	\N	PRESENT	0
49062	49004	11043H	PARTICIPANT	\N	PRESENT	0
49063	49004	11071M	PARTICIPANT	\N	PRESENT	0
53159	52278	14215L	PARTICIPANT	\N	PRESENT	0
53160	52278	08056B	PARTICIPANT	\N	PRESENT	0
53161	52278	11103C	PARTICIPANT	\N	PRESENT	0
53162	52278	08042U	PARTICIPANT	\N	PRESENT	0
53163	52278	14157T	PARTICIPANT	\N	PRESENT	0
53164	52278	14031R	PARTICIPANT	\N	PRESENT	0
53165	52278	04088S	PARTICIPANT	\N	PRESENT	0
53166	52278	01048V	PARTICIPANT	\N	PRESENT	0
53167	52278	14061L	PARTICIPANT	\N	PRESENT	0
53168	52278	11093T	PARTICIPANT	\N	PRESENT	0
53169	52278	14221J	PARTICIPANT	\N	PRESENT	0
53170	52278	14219Q	PARTICIPANT	\N	PRESENT	0
53171	52278	11065P	PARTICIPANT	\N	PRESENT	0
53172	52278	11099A	PARTICIPANT	\N	PRESENT	0
53173	52278	11023D	PARTICIPANT	\N	PRESENT	0
53174	52278	04079R	PARTICIPANT	\N	PRESENT	0
53175	52278	14121F	PARTICIPANT	\N	PRESENT	0
53176	52278	14097Y	PARTICIPANT	\N	PRESENT	0
53177	52278	11036J	PARTICIPANT	\N	PRESENT	0
53178	52278	08058D	PARTICIPANT	\N	PRESENT	0
53179	52278	80013X	PARTICIPANT	\N	PRESENT	0
53180	52278	11074Q	PARTICIPANT	\N	PRESENT	0
53181	52278	11107G	PARTICIPANT	\N	PRESENT	0
53182	52278	11066Q	PARTICIPANT	\N	PRESENT	0
53183	52278	14037X	PARTICIPANT	\N	PRESENT	0
53184	52278	14071N	PARTICIPANT	\N	PRESENT	0
53185	52278	14033T	PARTICIPANT	\N	PRESENT	0
53186	52278	01044R	PARTICIPANT	\N	PRESENT	0
53187	52278	92015P	PARTICIPANT	\N	PRESENT	0
53188	52278	08055A	PARTICIPANT	\N	PRESENT	0
53189	52278	14107H	PARTICIPANT	\N	PRESENT	0
53190	52278	13002U	PARTICIPANT	\N	PRESENT	0
53191	52278	14263U	PARTICIPANT	\N	PRESENT	0
53192	52278	01015L	PARTICIPANT	\N	PRESENT	0
53193	52278	01022K	PARTICIPANT	\N	PRESENT	0
55313	54969	95049N	PARTICIPANT	\N	PRESENT	0
55314	54969	14123H	PARTICIPANT	\N	PRESENT	0
55315	54969	01008M	PARTICIPANT	\N	PRESENT	0
55316	54969	14217N	PARTICIPANT	\N	PRESENT	0
55317	54969	89017R	PARTICIPANT	\N	PRESENT	0
55318	54969	08043V	PARTICIPANT	\N	PRESENT	0
55319	54969	11110B	PARTICIPANT	\N	PRESENT	0
55320	54969	04095R	PARTICIPANT	\N	PRESENT	0
55321	54969	11112D	PARTICIPANT	\N	PRESENT	0
55322	54969	12041X	PARTICIPANT	\N	PRESENT	0
55323	54969	08011M	PARTICIPANT	\N	PRESENT	0
55324	54969	05004A	PARTICIPANT	\N	PRESENT	0
55327	54972	86034E	PARTICIPANT	\N	PRESENT	0
55328	54972	14277B	PARTICIPANT	\N	PRESENT	0
55329	54972	95030B	PARTICIPANT	\N	PRESENT	0
55330	54972	11101A	PARTICIPANT	\N	PRESENT	0
55331	54972	13002U	PARTICIPANT	\N	PRESENT	0
55332	54972	08060W	PARTICIPANT	\N	PRESENT	0
55333	54972	11074Q	PARTICIPANT	\N	PRESENT	0
55334	54972	89029V	PARTICIPANT	\N	PRESENT	0
55335	54972	04088S	PARTICIPANT	\N	PRESENT	0
55336	54972	14265W	PARTICIPANT	\N	PRESENT	0
55337	54972	11106F	PARTICIPANT	\N	PRESENT	0
55338	54972	04089T	PARTICIPANT	\N	PRESENT	0
55339	54972	87003B	PARTICIPANT	\N	PRESENT	0
55340	54972	95031C	PARTICIPANT	\N	PRESENT	0
55341	54972	07034Q	PARTICIPANT	\N	PRESENT	0
55342	54972	14051J	PARTICIPANT	\N	PRESENT	0
55343	54972	11103C	PARTICIPANT	\N	PRESENT	0
55344	54972	11088W	PARTICIPANT	\N	PRESENT	0
55345	54972	01056V	PARTICIPANT	\N	PRESENT	0
55346	54972	02002K	PARTICIPANT	\N	PRESENT	0
55347	54972	04054G	PARTICIPANT	\N	PRESENT	0
55348	54972	01015L	PARTICIPANT	\N	PRESENT	0
55349	54972	11040E	PARTICIPANT	\N	PRESENT	0
55350	54972	98035U	PARTICIPANT	\N	PRESENT	0
55351	54972	01031L	PARTICIPANT	\N	PRESENT	0
55352	54972	11066Q	PARTICIPANT	\N	PRESENT	0
55353	54972	04067M	PARTICIPANT	\N	PRESENT	0
55354	54972	11055M	PARTICIPANT	\N	PRESENT	0
55355	54972	04066L	PARTICIPANT	\N	PRESENT	0
55356	54972	11098Y	PARTICIPANT	\N	PRESENT	0
55357	54972	14227Q	PARTICIPANT	\N	PRESENT	0
55358	54972	14197C	PARTICIPANT	\N	PRESENT	0
55359	54972	01011G	PARTICIPANT	\N	PRESENT	0
55360	54972	14107H	PARTICIPANT	\N	PRESENT	0
55361	54972	08053X	PARTICIPANT	\N	PRESENT	0
55362	54972	11068S	PARTICIPANT	\N	PRESENT	0
55363	54972	01046T	PARTICIPANT	\N	PRESENT	0
55364	54972	11107G	PARTICIPANT	\N	PRESENT	0
55365	54972	11059R	PARTICIPANT	\N	PRESENT	0
55366	54972	01059Y	PARTICIPANT	\N	PRESENT	0
55367	54972	92018S	PARTICIPANT	\N	PRESENT	0
55368	54972	11114F	PARTICIPANT	\N	PRESENT	0
55369	54972	11025F	PARTICIPANT	\N	PRESENT	0
55370	54972	08055A	PARTICIPANT	\N	PRESENT	0
55371	54972	11081P	PARTICIPANT	\N	PRESENT	0
55372	54972	07026Q	PARTICIPANT	\N	PRESENT	0
55373	54972	14235Q	PARTICIPANT	\N	PRESENT	0
55374	54972	95062K	PARTICIPANT	\N	PRESENT	0
55375	54972	01058X	PARTICIPANT	\N	PRESENT	0
55376	54972	11034G	PARTICIPANT	\N	PRESENT	0
55377	54972	99004R	PARTICIPANT	\N	PRESENT	0
55378	54972	14211G	PARTICIPANT	\N	PRESENT	0
55379	54972	08025T	PARTICIPANT	\N	PRESENT	0
55380	54972	04041B	PARTICIPANT	\N	PRESENT	0
55381	54972	01019Q	PARTICIPANT	\N	PRESENT	0
55382	54972	95015C	PARTICIPANT	\N	PRESENT	0
55383	54972	14281W	PARTICIPANT	\N	PRESENT	0
55384	54972	14253S	PARTICIPANT	\N	PRESENT	0
55385	54972	14263U	PARTICIPANT	\N	PRESENT	0
55386	54972	04085P	PARTICIPANT	\N	PRESENT	0
55387	54972	04071H	PARTICIPANT	\N	PRESENT	0
55388	54972	14028W	PARTICIPANT	\N	PRESENT	0
55389	54972	14169X	PARTICIPANT	\N	PRESENT	0
55390	54972	80027E	PARTICIPANT	\N	PRESENT	0
55391	54972	11080N	PARTICIPANT	\N	PRESENT	0
55392	54972	95037J	PARTICIPANT	\N	PRESENT	0
55393	54972	14191V	PARTICIPANT	\N	PRESENT	0
55394	54972	14017T	PARTICIPANT	\N	PRESENT	0
55395	54972	14063N	PARTICIPANT	\N	PRESENT	0
55396	54972	14121F	PARTICIPANT	\N	PRESENT	0
55397	54972	14031R	PARTICIPANT	\N	PRESENT	0
55398	54972	14001X	PARTICIPANT	\N	PRESENT	0
55399	54972	11042G	PARTICIPANT	\N	PRESENT	0
55400	54972	11046L	PARTICIPANT	\N	PRESENT	0
55401	54972	14271U	PARTICIPANT	\N	PRESENT	0
55402	54972	92040Q	PARTICIPANT	\N	PRESENT	0
55403	54972	01061S	PARTICIPANT	\N	PRESENT	0
55404	54972	11061K	PARTICIPANT	\N	PRESENT	0
55405	54972	08016S	PARTICIPANT	\N	PRESENT	0
55406	54972	11039M	PARTICIPANT	\N	PRESENT	0
55407	54972	98005N	PARTICIPANT	\N	PRESENT	0
55408	54972	04056J	PARTICIPANT	\N	PRESENT	0
55409	54972	01022K	PARTICIPANT	\N	PRESENT	0
55410	54972	11011M	PARTICIPANT	\N	PRESENT	0
55411	54972	08012N	PARTICIPANT	\N	PRESENT	0
55412	54972	14039A	PARTICIPANT	\N	PRESENT	0
55413	54972	98018T	PARTICIPANT	\N	PRESENT	0
55414	54972	01007L	PARTICIPANT	\N	PRESENT	0
55415	54972	04048J	PARTICIPANT	\N	PRESENT	0
55416	54972	11109J	PARTICIPANT	\N	PRESENT	0
55417	54972	08022Q	PARTICIPANT	\N	PRESENT	0
55418	54972	11113E	PARTICIPANT	\N	PRESENT	0
55419	54972	08035V	PARTICIPANT	\N	PRESENT	0
55420	54972	77002U	PARTICIPANT	\N	PRESENT	0
55421	54972	04094Q	PARTICIPANT	\N	PRESENT	0
55422	54972	04045F	PARTICIPANT	\N	PRESENT	0
55423	54972	11077T	PARTICIPANT	\N	PRESENT	0
55424	54972	11033F	PARTICIPANT	\N	PRESENT	0
55425	54972	04047H	PARTICIPANT	\N	PRESENT	0
55426	54972	98024R	PARTICIPANT	\N	PRESENT	0
55427	54972	14081Q	PARTICIPANT	\N	PRESENT	0
55428	54972	01027Q	PARTICIPANT	\N	PRESENT	0
55429	54972	11067R	PARTICIPANT	\N	PRESENT	0
55430	54972	11029K	PARTICIPANT	\N	PRESENT	0
55431	54972	01044R	PARTICIPANT	\N	PRESENT	0
55432	54972	95041E	PARTICIPANT	\N	PRESENT	0
55433	54972	10006L	PARTICIPANT	\N	PRESENT	0
55434	54972	14085U	PARTICIPANT	\N	PRESENT	0
55435	54972	11084S	PARTICIPANT	\N	PRESENT	0
55436	54972	14223L	PARTICIPANT	\N	PRESENT	0
55437	54972	11010L	PARTICIPANT	\N	PRESENT	0
55438	54972	04043D	PARTICIPANT	\N	PRESENT	0
55439	54972	08024S	PARTICIPANT	\N	PRESENT	0
55440	54972	11036J	PARTICIPANT	\N	PRESENT	0
55441	54972	14071N	PARTICIPANT	\N	PRESENT	0
55442	54972	14111D	PARTICIPANT	\N	PRESENT	0
55443	54972	14167V	PARTICIPANT	\N	PRESENT	0
55444	54972	98029W	PARTICIPANT	\N	PRESENT	0
55445	54972	08034U	PARTICIPANT	\N	PRESENT	0
55446	54972	92039X	PARTICIPANT	\N	PRESENT	0
55447	54972	14053L	PARTICIPANT	\N	PRESENT	0
55448	54972	08038Y	PARTICIPANT	\N	PRESENT	0
55449	54972	04044E	PARTICIPANT	\N	PRESENT	0
55450	54972	11035H	PARTICIPANT	\N	PRESENT	0
55451	54972	11097X	PARTICIPANT	\N	PRESENT	0
55452	54972	11104D	PARTICIPANT	\N	PRESENT	0
55453	54972	01028R	PARTICIPANT	\N	PRESENT	0
55454	54972	08047A	PARTICIPANT	\N	PRESENT	0
55455	54972	14173T	PARTICIPANT	\N	PRESENT	0
55456	54972	04077P	PARTICIPANT	\N	PRESENT	0
55457	54972	08061X	PARTICIPANT	\N	PRESENT	0
55458	54972	88008L	PARTICIPANT	\N	PRESENT	0
55459	54972	14038Y	PARTICIPANT	\N	PRESENT	0
55460	54972	04078Q	PARTICIPANT	\N	PRESENT	0
55461	54972	14199E	PARTICIPANT	\N	PRESENT	0
55462	54972	14225N	PARTICIPANT	\N	PRESENT	0
55463	54972	11069T	PARTICIPANT	\N	PRESENT	0
55464	54972	14159V	PARTICIPANT	\N	PRESENT	0
55465	54972	14329V	PARTICIPANT	\N	PRESENT	0
55466	54972	14014Q	PARTICIPANT	\N	PRESENT	0
55467	54972	08019V	PARTICIPANT	\N	PRESENT	0
55468	54972	83042R	PARTICIPANT	\N	PRESENT	0
55469	54972	14195A	PARTICIPANT	\N	PRESENT	0
55470	54972	11095V	PARTICIPANT	\N	PRESENT	0
55471	54972	07029T	PARTICIPANT	\N	PRESENT	0
55472	54972	08062Y	PARTICIPANT	\N	PRESENT	0
55473	54972	14013P	PARTICIPANT	\N	PRESENT	0
55474	54972	11063M	PARTICIPANT	\N	PRESENT	0
55475	54972	07032N	PARTICIPANT	\N	PRESENT	0
55476	54972	14093U	PARTICIPANT	\N	PRESENT	0
55477	54972	11031D	PARTICIPANT	\N	PRESENT	0
55478	54972	98023Q	PARTICIPANT	\N	PRESENT	0
55479	54972	08049C	PARTICIPANT	\N	PRESENT	0
55480	54972	14079W	PARTICIPANT	\N	PRESENT	0
55481	54972	11012A	PARTICIPANT	\N	PRESENT	0
55482	54972	14193X	PARTICIPANT	\N	PRESENT	0
32758	32757	14261S	PARTICIPANT	\N	PRESENT	0
32759	32757	08055A	PARTICIPANT	\N	PRESENT	0
32760	32757	14093U	PARTICIPANT	\N	PRESENT	0
32761	32757	14030Q	PARTICIPANT	\N	PRESENT	0
32799	32798	14261S	PARTICIPANT	\N	PRESENT	0
32800	32798	08055A	PARTICIPANT	\N	PRESENT	0
32801	32798	14093U	PARTICIPANT	\N	PRESENT	0
32802	32798	14030Q	PARTICIPANT	\N	PRESENT	0
32766	32757	14038Y	PARTICIPANT	\N	PRESENT	0
32803	32798	96004D	PARTICIPANT	\N	PRESENT	0
32768	32757	98023Q	PARTICIPANT	\N	PRESENT	0
32769	32757	11065P	PARTICIPANT	\N	PRESENT	0
32770	32757	01015L	PARTICIPANT	\N	PRESENT	0
32771	32757	11107G	PARTICIPANT	\N	PRESENT	0
32839	32798	96003C	PARTICIPANT	\N	EXCUSE	0
32773	32757	02002K	PARTICIPANT	\N	PRESENT	0
32774	32757	01022K	PARTICIPANT	\N	EXCUSE	0
32840	32798	92039X	PARTICIPANT	\N	EXCUSE	0
32841	32798	08062Y	PARTICIPANT	\N	EXCUSE	0
32777	32757	11059R	PARTICIPANT	\N	PRESENT	0
32778	32757	14219Q	PARTICIPANT	\N	PRESENT	0
32842	32798	01022K	PARTICIPANT	\N	EXCUSE	0
32780	32757	14031R	PARTICIPANT	\N	PRESENT	0
32781	32757	08009T	PRESIDENT	0	PRESENT	0
32782	32757	08062Y	PARTICIPANT	\N	EXCUSE	0
32783	32757	14221J	PARTICIPANT	\N	PRESENT	0
32784	32757	92039X	PARTICIPANT	\N	EXCUSE	0
32785	32757	08042U	PARTICIPANT	\N	PRESENT	0
32786	32757	14169X	PARTICIPANT	\N	PRESENT	0
32787	32757	14237S	PARTICIPANT	\N	PRESENT	0
32788	32757	13002U	PARTICIPANT	\N	PRESENT	0
32789	32757	05012A	PARTICIPANT	\N	PRESENT	0
32884	32843	11094U	PARTICIPANT	\N	EXCUSE	0
32791	32757	14135M	PARTICIPANT	\N	PRESENT	0
32792	32757	95062K	PARTICIPANT	\N	PRESENT	0
32793	32757	14107H	PARTICIPANT	\N	PRESENT	0
32794	32757	14051J	PARTICIPANT	\N	PRESENT	0
32795	32757	14157T	PARTICIPANT	\N	PRESENT	0
32796	32757	96003C	PARTICIPANT	\N	EXCUSE	0
32809	32798	98023Q	PARTICIPANT	\N	PRESENT	0
32810	32798	11065P	PARTICIPANT	\N	PRESENT	0
32811	32798	01015L	PARTICIPANT	\N	PRESENT	0
32812	32798	11107G	PARTICIPANT	\N	PRESENT	0
32845	32843	11036J	PARTICIPANT	\N	PRESENT	0
32814	32798	02002K	PARTICIPANT	\N	PRESENT	0
32885	32843	14275Y	PARTICIPANT	\N	PRESENT	0
32886	32843	08073C	PARTICIPANT	\N	PRESENT	0
32848	32843	08068F	PARTICIPANT	\N	PRESENT	0
32818	32798	11059R	PARTICIPANT	\N	PRESENT	0
32819	32798	14219Q	PARTICIPANT	\N	PRESENT	0
32849	32843	14207L	PARTICIPANT	\N	PRESENT	0
32821	32798	14031R	PARTICIPANT	\N	PRESENT	0
32822	32798	08009T	PRESIDENT	0	PRESENT	0
32887	32843	11054L	PARTICIPANT	\N	PRESENT	0
32824	32798	14221J	PARTICIPANT	\N	PRESENT	0
32851	32843	90003B	PARTICIPANT	\N	EXCUSE	0
32826	32798	08042U	PARTICIPANT	\N	PRESENT	0
32827	32798	14169X	PARTICIPANT	\N	PRESENT	0
32828	32798	14237S	PARTICIPANT	\N	PRESENT	0
32829	32798	13002U	PARTICIPANT	\N	PRESENT	0
32830	32798	05012A	PARTICIPANT	\N	PRESENT	0
32852	32843	08028W	PARTICIPANT	\N	PRESENT	0
32832	32798	14135M	PARTICIPANT	\N	PRESENT	0
32833	32798	95062K	PARTICIPANT	\N	PRESENT	0
32834	32798	14107H	PARTICIPANT	\N	PRESENT	0
32835	32798	14051J	PARTICIPANT	\N	PRESENT	0
32836	32798	14157T	PARTICIPANT	\N	PRESENT	0
32853	32843	80013X	PARTICIPANT	\N	PRESENT	0
41741	41740	04059M	PARTICIPANT	\N	PRESENT	0
41750	41005	90003B	PARTICIPANT	\N	PRESENT	0
32856	32843	14197C	PARTICIPANT	\N	PRESENT	0
41751	41005	01008M	PARTICIPANT	\N	PRESENT	0
32858	32843	14187A	PARTICIPANT	\N	PRESENT	0
32859	32843	14033T	PARTICIPANT	\N	PRESENT	0
41752	41005	88008L	PARTICIPANT	\N	PRESENT	0
41753	41005	14042U	PARTICIPANT	\N	PRESENT	0
32862	32843	11099A	PARTICIPANT	\N	PRESENT	0
32863	32843	04049K	PARTICIPANT	\N	PRESENT	0
32864	32843	04094Q	PARTICIPANT	\N	PRESENT	0
41754	41005	12042Y	PARTICIPANT	\N	PRESENT	0
32866	32843	08015R	PARTICIPANT	\N	PRESENT	0
32867	32843	11100Y	PRESIDENT	0	PRESENT	0
32868	32843	01061S	PARTICIPANT	\N	EXCUSE	0
41755	41005	14179A	PARTICIPANT	\N	PRESENT	0
32870	32843	01043Q	PARTICIPANT	\N	PRESENT	0
41756	41005	14097Y	PARTICIPANT	\N	PRESENT	0
32872	32843	14205J	PARTICIPANT	\N	PRESENT	0
32873	32843	08019V	PARTICIPANT	\N	PRESENT	0
32874	32843	14257W	PARTICIPANT	\N	PRESENT	0
41757	41005	14265W	PARTICIPANT	\N	PRESENT	0
32876	32843	04088S	PARTICIPANT	\N	PRESENT	0
32877	32843	98050T	PARTICIPANT	\N	PRESENT	0
41758	41005	14169X	PARTICIPANT	\N	PRESENT	0
32879	32843	11046L	PARTICIPANT	\N	PRESENT	0
32880	32843	01058X	PARTICIPANT	\N	PRESENT	0
41759	41005	04088S	PARTICIPANT	\N	PRESENT	0
32882	32843	11066Q	PARTICIPANT	\N	PRESENT	0
41760	41005	14227Q	PARTICIPANT	\N	PRESENT	0
41761	41005	95067Q	PARTICIPANT	\N	PRESENT	0
42520	33406	14133K	PARTICIPANT	\N	PRESENT	0
42521	33406	08024S	PARTICIPANT	\N	PRESENT	0
42523	33406	01037S	PARTICIPANT	\N	PRESENT	0
42524	33406	11014C	PARTICIPANT	\N	PRESENT	0
42649	42648	01019Q	PARTICIPANT	\N	PRESENT	0
42654	42652	11039M	PARTICIPANT	\N	PRESENT	0
42655	42652	98042T	PARTICIPANT	\N	PRESENT	0
42656	42652	01019Q	PARTICIPANT	\N	PRESENT	0
42709	42708	01007L	PARTICIPANT	\N	PRESENT	0
42710	42708	04088S	PARTICIPANT	\N	PRESENT	0
42711	42708	04067M	PARTICIPANT	\N	PRESENT	0
42712	42708	01003G	PARTICIPANT	\N	PRESENT	0
42872	42867	14133K	PARTICIPANT	\N	PRESENT	0
42874	42867	04059M	PARTICIPANT	\N	PRESENT	0
42875	42867	11039M	PARTICIPANT	\N	PRESENT	0
42876	42867	01044R	PARTICIPANT	\N	PRESENT	0
42877	42867	08043V	PARTICIPANT	\N	PRESENT	0
42879	42867	14105F	PARTICIPANT	\N	PRESENT	0
42880	42867	11029K	PARTICIPANT	\N	PRESENT	0
42881	42867	95015C	PARTICIPANT	\N	PRESENT	0
42882	42867	92015P	PARTICIPANT	\N	PRESENT	0
42883	42867	08024S	PARTICIPANT	\N	PRESENT	0
42884	42867	14201E	PARTICIPANT	\N	EXCUSE	0
42886	42867	14209N	PARTICIPANT	\N	PRESENT	0
42888	42867	11091R	PARTICIPANT	\N	PRESENT	0
42889	42867	87003B	PARTICIPANT	\N	PRESENT	0
42890	42867	98042T	PARTICIPANT	\N	PRESENT	0
42891	42867	14249W	PARTICIPANT	\N	EXCUSE	0
42892	42867	01041N	PARTICIPANT	\N	PRESENT	0
42893	42867	01025N	PARTICIPANT	\N	PRESENT	0
42894	42867	01037S	PARTICIPANT	\N	PRESENT	0
42895	42867	89029V	PARTICIPANT	\N	PRESENT	0
42896	42867	08035V	PARTICIPANT	\N	PRESENT	0
42897	42867	11089X	PARTICIPANT	\N	PRESENT	0
42898	42867	07026Q	PARTICIPANT	\N	PRESENT	0
42899	42867	14123H	PARTICIPANT	\N	PRESENT	0
42900	42867	14179A	PARTICIPANT	\N	PRESENT	0
42902	42867	14241N	PARTICIPANT	\N	PRESENT	0
42903	42867	14061L	PARTICIPANT	\N	PRESENT	0
42904	42867	14073Q	PARTICIPANT	\N	PRESENT	0
42905	42867	08031R	PARTICIPANT	\N	PRESENT	0
42907	42867	08039A	PARTICIPANT	\N	PRESENT	0
42908	42867	08017T	PARTICIPANT	\N	PRESENT	0
42909	42867	14059S	PARTICIPANT	\N	PRESENT	0
42912	42867	11104D	PARTICIPANT	\N	PRESENT	0
42913	42867	14063N	PARTICIPANT	\N	PRESENT	0
42914	42867	04057K	PARTICIPANT	\N	PRESENT	0
42915	42867	11014C	PARTICIPANT	\N	PRESENT	0
42916	42867	14109K	PARTICIPANT	\N	PRESENT	0
42917	42867	04070G	PRESIDENT	0	PRESENT	0
42918	42867	92040Q	PARTICIPANT	\N	PRESENT	0
42920	42867	83047W	PARTICIPANT	\N	PRESENT	0
42921	42867	14235Q	PARTICIPANT	\N	PRESENT	0
42924	42867	14229S	PARTICIPANT	\N	PRESENT	0
42925	42867	11043H	PARTICIPANT	\N	PRESENT	0
59287	59266	98005N	PARTICIPANT	\N	PRESENT	0
59288	59266	14037X	PARTICIPANT	\N	PRESENT	0
59289	59266	08019V	PARTICIPANT	\N	PRESENT	0
59290	59266	11067R	PARTICIPANT	\N	PRESENT	0
59351	59350	14239U	PARTICIPANT	\N	PRESENT	0
59408	59350	04067M	PARTICIPANT	\N	EXCUSE	0
59353	59350	01046T	PARTICIPANT	\N	PRESENT	0
59354	59350	04053F	PARTICIPANT	\N	PRESENT	0
59355	59350	14255U	PARTICIPANT	\N	PRESENT	0
59356	59350	04066L	PARTICIPANT	\N	PRESENT	0
59357	59350	00003C	PARTICIPANT	\N	PRESENT	0
59358	59350	14053L	PARTICIPANT	\N	PRESENT	0
59359	59350	11103C	PARTICIPANT	\N	PRESENT	0
59360	59350	11044J	PARTICIPANT	\N	PRESENT	0
59361	59350	14195A	PARTICIPANT	\N	PRESENT	0
59362	59350	14267Y	PARTICIPANT	\N	PRESENT	0
59363	59350	11023D	PARTICIPANT	\N	PRESENT	0
59364	59350	11031D	PARTICIPANT	\N	PRESENT	0
59365	59350	08052W	PARTICIPANT	\N	PRESENT	0
59366	59350	01059Y	PARTICIPANT	\N	PRESENT	0
59367	59350	04081K	PARTICIPANT	\N	PRESENT	0
59368	59350	98024R	PARTICIPANT	\N	PRESENT	0
59369	59350	10006L	PARTICIPANT	\N	PRESENT	0
59552	59550	01008M	PARTICIPANT	\N	PRESENT	0
59371	59350	14217N	PARTICIPANT	\N	PRESENT	0
59372	59350	14042U	PARTICIPANT	\N	PRESENT	0
59553	59550	11036J	PARTICIPANT	\N	PRESENT	0
59374	59350	12042Y	PARTICIPANT	\N	PRESENT	0
60232	60034	08055A	PARTICIPANT	\N	PRESENT	0
59376	59350	14087W	PARTICIPANT	\N	PRESENT	0
59555	59550	14013P	PARTICIPANT	\N	PRESENT	0
59556	59550	08068F	PARTICIPANT	\N	PRESENT	0
59379	59350	14231L	PARTICIPANT	\N	PRESENT	0
59380	59350	11061K	PARTICIPANT	\N	PRESENT	0
59381	59350	08048B	PARTICIPANT	\N	PRESENT	0
59382	59350	08041T	PARTICIPANT	\N	PRESENT	0
59383	59350	01011G	PARTICIPANT	\N	PRESENT	0
59557	59550	14207L	PARTICIPANT	\N	PRESENT	0
59385	59350	14213J	PARTICIPANT	\N	PRESENT	0
59386	59350	14121F	PARTICIPANT	\N	PRESENT	0
59387	59350	11112D	PARTICIPANT	\N	PRESENT	0
59388	59350	14037X	PARTICIPANT	\N	PRESENT	0
59389	59350	14018U	PARTICIPANT	\N	PRESENT	0
59390	59350	11067R	PARTICIPANT	\N	PRESENT	0
59391	59350	14223L	PARTICIPANT	\N	PRESENT	0
59392	59350	04092N	PRESIDENT	0	PRESENT	0
59393	59350	14265W	PARTICIPANT	\N	PRESENT	0
59394	59350	14119M	PARTICIPANT	\N	PRESENT	0
59395	59350	14071N	PARTICIPANT	\N	PRESENT	0
59396	59350	07032N	PARTICIPANT	\N	PRESENT	0
59397	59350	04043D	PARTICIPANT	\N	PRESENT	0
59398	59350	14271U	PARTICIPANT	\N	PRESENT	0
59558	59550	11101A	PARTICIPANT	\N	PRESENT	0
59400	59350	11093T	PARTICIPANT	\N	PRESENT	0
59401	59350	11097X	PARTICIPANT	\N	PRESENT	0
59402	59350	04045F	PARTICIPANT	\N	PRESENT	0
59403	59350	14227Q	PARTICIPANT	\N	PRESENT	0
59404	59350	01034P	PARTICIPANT	\N	PRESENT	0
60234	60233	05012A	PARTICIPANT	\N	PRESENT	0
59406	59350	11063M	PARTICIPANT	\N	PRESENT	0
59407	59350	14269B	PARTICIPANT	\N	PRESENT	0
59560	59550	08028W	PARTICIPANT	\N	PRESENT	0
59561	59550	80013X	PARTICIPANT	\N	PRESENT	0
59562	59550	08038Y	PARTICIPANT	\N	PRESENT	0
59563	59550	04089T	PARTICIPANT	\N	PRESENT	0
59564	59550	14197C	PARTICIPANT	\N	PRESENT	0
59565	59550	11110B	PARTICIPANT	\N	PRESENT	0
59566	59550	14187A	PARTICIPANT	\N	PRESENT	0
59567	59550	14033T	PARTICIPANT	\N	PRESENT	0
59568	59550	14081Q	PARTICIPANT	\N	PRESENT	0
59569	59550	04048J	PARTICIPANT	\N	PRESENT	0
59570	59550	11099A	PARTICIPANT	\N	PRESENT	0
60236	60235	05008E	PARTICIPANT	\N	PRESENT	0
60237	60235	95049N	PARTICIPANT	\N	PRESENT	0
59573	59550	11111C	PARTICIPANT	\N	PRESENT	0
59574	59550	08015R	PARTICIPANT	\N	PRESENT	0
59575	59550	11100Y	PRESIDENT	0	PRESENT	0
59576	59550	01061S	PARTICIPANT	\N	PRESENT	0
59577	59550	11098Y	PARTICIPANT	\N	PRESENT	0
59578	59550	01043Q	PARTICIPANT	\N	PRESENT	0
59579	59550	11077T	PARTICIPANT	\N	PRESENT	0
59580	59550	14205J	PARTICIPANT	\N	PRESENT	0
59581	59550	08019V	PARTICIPANT	\N	PRESENT	0
59582	59550	14257W	PARTICIPANT	\N	PRESENT	0
60238	60235	04044E	PARTICIPANT	\N	PRESENT	0
59584	59550	04088S	PARTICIPANT	\N	PRESENT	0
60239	60034	04054G	PARTICIPANT	\N	PRESENT	0
59586	59550	11090Q	PARTICIPANT	\N	PRESENT	0
59587	59550	11046L	PARTICIPANT	\N	PRESENT	0
59588	59550	01058X	PARTICIPANT	\N	PRESENT	0
59589	59550	11094U	PARTICIPANT	\N	PRESENT	0
59590	59550	11066Q	PARTICIPANT	\N	PRESENT	0
60240	60034	11098Y	PARTICIPANT	\N	PRESENT	0
60241	60034	14097Y	PARTICIPANT	\N	PRESENT	0
60242	60034	14063N	PARTICIPANT	\N	PRESENT	0
60243	60034	11090Q	PARTICIPANT	\N	PRESENT	0
60244	60034	11099A	PARTICIPANT	\N	PRESENT	0
60245	60034	14042U	PARTICIPANT	\N	PRESENT	0
60246	60034	14219Q	PARTICIPANT	\N	PRESENT	0
60247	60034	14030Q	PARTICIPANT	\N	PRESENT	0
60248	60034	14089Y	PARTICIPANT	\N	PRESENT	0
60249	60034	14247U	PARTICIPANT	\N	PRESENT	0
60250	60034	01041N	PARTICIPANT	\N	PRESENT	0
60251	60034	14073Q	PARTICIPANT	\N	PRESENT	0
60252	60034	11083R	PARTICIPANT	\N	PRESENT	0
60253	60034	14079W	PARTICIPANT	\N	PRESENT	0
60254	60034	98046X	PARTICIPANT	\N	PRESENT	0
60255	60034	04085P	PARTICIPANT	\N	PRESENT	0
60256	60034	14263U	PARTICIPANT	\N	PRESENT	0
60307	60034	11066Q	PARTICIPANT	\N	PRESENT	0
60308	60034	04080J	PARTICIPANT	\N	PRESENT	0
60309	60034	14265W	PARTICIPANT	\N	PRESENT	0
60310	60034	04035D	PARTICIPANT	\N	PRESENT	0
60311	60034	01016M	PARTICIPANT	\N	PRESENT	0
60312	60034	14249W	PARTICIPANT	\N	PRESENT	0
60313	60034	96004D	PARTICIPANT	\N	PRESENT	0
60314	60034	14135M	PARTICIPANT	\N	PRESENT	0
60318	60034	04057K	PARTICIPANT	\N	PRESENT	0
60321	60034	11035H	PARTICIPANT	\N	PRESENT	0
60329	60034	14257W	PARTICIPANT	\N	PRESENT	0
60330	60034	14159V	PARTICIPANT	\N	PRESENT	0
60331	60034	11110B	PARTICIPANT	\N	PRESENT	0
60333	60034	01003G	PARTICIPANT	\N	PRESENT	0
60348	60034	08019V	PARTICIPANT	\N	PRESENT	0
60349	60034	11091R	PARTICIPANT	\N	PRESENT	0
60350	60034	11048N	PARTICIPANT	\N	PRESENT	0
60351	60034	14037X	PARTICIPANT	\N	PRESENT	0
60352	60034	11012A	PARTICIPANT	\N	PRESENT	0
60353	60034	80013X	PARTICIPANT	\N	PRESENT	0
60366	60365	14133K	PARTICIPANT	\N	PRESENT	0
60367	60034	11112D	PARTICIPANT	\N	PRESENT	0
60368	60365	96004D	PRESIDENT	0	PRESENT	0
60369	60365	14089Y	PARTICIPANT	\N	PRESENT	0
60370	60365	90003B	PARTICIPANT	\N	EXCUSE	0
60371	60365	14079W	PARTICIPANT	\N	PRESENT	0
60372	60365	11035H	PARTICIPANT	\N	PRESENT	0
60373	60365	04035D	PARTICIPANT	\N	PRESENT	0
60374	60365	11083R	PARTICIPANT	\N	PRESENT	0
60375	60365	14097Y	PARTICIPANT	\N	PRESENT	0
60376	60365	14073Q	PARTICIPANT	\N	PRESENT	0
60377	60365	11026G	PARTICIPANT	\N	EXCUSE	0
60378	60365	98046X	PARTICIPANT	\N	PRESENT	0
60379	60365	14001X	PARTICIPANT	\N	PRESENT	0
60380	60365	04057K	PARTICIPANT	\N	PRESENT	0
60381	60365	04080J	PARTICIPANT	\N	PRESENT	0
60382	60365	01016M	PARTICIPANT	\N	PRESENT	0
60383	60365	95063L	PARTICIPANT	\N	PRESENT	0
60384	60365	92045V	PARTICIPANT	\N	PRESENT	0
60385	60365	04034C	PARTICIPANT	\N	PRESENT	0
60386	60034	97011G	PARTICIPANT	\N	PRESENT	0
60387	60034	92045V	PARTICIPANT	\N	PRESENT	0
60388	60034	99004R	PARTICIPANT	\N	PRESENT	0
60399	60034	07026Q	PARTICIPANT	\N	PRESENT	0
60400	60034	14217N	PARTICIPANT	\N	PRESENT	0
60401	60034	14034U	PARTICIPANT	\N	PRESENT	0
60402	60034	11040E	PARTICIPANT	\N	PRESENT	0
35626	35625	07034Q	PARTICIPANT	\N	PRESENT	0
35627	35625	10006L	PARTICIPANT	\N	PRESENT	0
35628	35625	14071N	PARTICIPANT	\N	PRESENT	0
35629	35625	14037X	PARTICIPANT	\N	PRESENT	0
35630	35625	14259Y	PARTICIPANT	\N	PRESENT	0
35632	35631	07034Q	PARTICIPANT	\N	PRESENT	0
35633	35631	11083R	PARTICIPANT	\N	PRESENT	0
37966	37377	04066L	PARTICIPANT	\N	PRESENT	0
37967	37377	11040E	PARTICIPANT	\N	PRESENT	0
37970	37377	11112D	PARTICIPANT	\N	PRESENT	0
37971	37377	11036J	PARTICIPANT	\N	PRESENT	0
37972	37377	11077T	PARTICIPANT	\N	PRESENT	0
37973	37377	14225N	PARTICIPANT	\N	PRESENT	0
37974	37377	11023D	PARTICIPANT	\N	PRESENT	0
37975	37377	14081Q	PARTICIPANT	\N	PRESENT	0
37976	37377	08016S	PARTICIPANT	\N	PRESENT	0
37977	37377	11109J	PARTICIPANT	\N	PRESENT	0
37978	37377	11083R	PARTICIPANT	\N	PRESENT	0
37979	37377	14159V	PARTICIPANT	\N	PRESENT	0
37980	37377	14085U	PARTICIPANT	\N	PRESENT	0
37981	37377	14219Q	PARTICIPANT	\N	PRESENT	0
37982	37377	07004J	PARTICIPANT	\N	PRESENT	0
37983	37377	11070L	PARTICIPANT	\N	PRESENT	0
37984	37377	14269B	PARTICIPANT	\N	PRESENT	0
37985	37377	04034C	PARTICIPANT	\N	PRESENT	0
37986	37377	11012A	PARTICIPANT	\N	PRESENT	0
37987	37377	14261S	PARTICIPANT	\N	PRESENT	0
37988	37377	14217N	PARTICIPANT	\N	PRESENT	0
37989	37377	09001P	PARTICIPANT	\N	PRESENT	0
37990	37377	04086Q	PARTICIPANT	\N	PRESENT	0
37991	37377	14069U	PARTICIPANT	\N	PRESENT	0
37992	37377	11090Q	PARTICIPANT	\N	PRESENT	0
37993	37377	14119M	PARTICIPANT	\N	PRESENT	0
37994	37377	11080N	PARTICIPANT	\N	PRESENT	0
37995	37377	04071H	PARTICIPANT	\N	PRESENT	0
37996	37377	04043D	PARTICIPANT	\N	PRESENT	0
37997	37377	01031L	PARTICIPANT	\N	PRESENT	0
37998	37377	08011M	PARTICIPANT	\N	PRESENT	0
37999	37377	08019V	PARTICIPANT	\N	PRESENT	0
38000	37377	14041T	PARTICIPANT	\N	PRESENT	0
38001	37377	07029T	PARTICIPANT	\N	PRESENT	0
38002	37377	98005N	PARTICIPANT	\N	PRESENT	0
38003	37377	14175V	PARTICIPANT	\N	PRESENT	0
38004	37377	01027Q	PARTICIPANT	\N	PRESENT	0
38005	37377	99004R	PARTICIPANT	\N	PRESENT	0
38006	37377	11088W	PARTICIPANT	\N	PRESENT	0
38007	37377	14207L	PARTICIPANT	\N	PRESENT	0
38008	37377	14275Y	PARTICIPANT	\N	PRESENT	0
38009	37377	11053K	PARTICIPANT	\N	PRESENT	0
38010	37377	14173T	PARTICIPANT	\N	PRESENT	0
38011	37377	04042C	PARTICIPANT	\N	PRESENT	0
38012	37377	08073C	PARTICIPANT	\N	PRESENT	0
38013	37377	14051J	PARTICIPANT	\N	PRESENT	0
38014	37377	14083S	PARTICIPANT	\N	PRESENT	0
38015	37377	11048N	PARTICIPANT	\N	PRESENT	0
38146	38145	11106F	PARTICIPANT	\N	PRESENT	0
38149	38148	07024N	PARTICIPANT	\N	PRESENT	0
38150	38148	01014K	PARTICIPANT	\N	PRESENT	0
40809	40808	01008M	PARTICIPANT	\N	PRESENT	0
40810	40808	14089Y	PARTICIPANT	\N	EXCUSE	0
40811	40808	08060W	PARTICIPANT	\N	EXCUSE	0
40812	40808	11029K	PARTICIPANT	\N	EXCUSE	0
40813	40808	11080N	PARTICIPANT	\N	EXCUSE	0
40814	40808	08028W	PARTICIPANT	\N	EXCUSE	0
40815	40808	88008L	PARTICIPANT	\N	EXCUSE	0
40816	40808	04038G	PARTICIPANT	\N	PRESENT	0
40817	40808	01059Y	PARTICIPANT	\N	EXCUSE	0
40818	40808	11088W	PARTICIPANT	\N	EXCUSE	0
40819	40808	98018T	PARTICIPANT	\N	EXCUSE	0
40820	40808	01015L	PARTICIPANT	\N	EXCUSE	0
40821	40808	01041N	PARTICIPANT	\N	EXCUSE	0
40822	40808	14187A	PARTICIPANT	\N	EXCUSE	0
40823	40808	02002K	PARTICIPANT	\N	EXCUSE	0
40831	40808	08048B	PARTICIPANT	\N	EXCUSE	0
40833	40808	11089X	PARTICIPANT	\N	EXCUSE	0
40835	40808	14026U	PARTICIPANT	\N	EXCUSE	0
40836	40808	14179A	PARTICIPANT	\N	EXCUSE	0
40837	40808	14121F	PARTICIPANT	\N	EXCUSE	0
40838	40808	11084S	PARTICIPANT	\N	EXCUSE	0
40839	40808	99004R	PRESIDENT	0	PRESENT	0
40840	40808	04061F	PARTICIPANT	\N	EXCUSE	0
40841	40808	01061S	PARTICIPANT	\N	EXCUSE	0
40843	40808	08012N	PARTICIPANT	\N	PRESENT	0
40844	40808	14103D	PARTICIPANT	\N	EXCUSE	0
40845	40808	08062Y	PARTICIPANT	\N	EXCUSE	0
40846	40808	14257W	PARTICIPANT	\N	EXCUSE	0
40848	40808	11046L	PARTICIPANT	\N	EXCUSE	0
40849	40808	01028R	PARTICIPANT	\N	EXCUSE	0
40850	40808	11094U	PARTICIPANT	\N	PRESENT	0
40851	40808	92045V	PARTICIPANT	\N	EXCUSE	0
40852	40808	11066Q	PARTICIPANT	\N	PRESENT	0
41022	41008	08019V	PARTICIPANT	\N	PRESENT	0
40855	40853	11094U	PARTICIPANT	\N	PRESENT	0
40856	40853	08012N	PARTICIPANT	\N	PRESENT	0
41023	41008	01022K	PARTICIPANT	\N	PRESENT	0
41025	41024	14157T	PARTICIPANT	\N	PRESENT	0
41027	41026	02002K	PARTICIPANT	\N	PRESENT	0
41028	41026	14069U	PARTICIPANT	\N	PRESENT	0
41029	38465	11107G	PARTICIPANT	\N	PRESENT	0
41030	38465	95062K	PARTICIPANT	\N	PRESENT	0
41031	38465	14030Q	PARTICIPANT	\N	PRESENT	0
41032	38465	14031R	PARTICIPANT	\N	PRESENT	0
41033	38502	14031R	PARTICIPANT	\N	PRESENT	0
41034	38502	11107G	PARTICIPANT	\N	PRESENT	0
41036	41035	02002K	PARTICIPANT	\N	PRESENT	0
41037	41035	14069U	PARTICIPANT	\N	PRESENT	0
41039	41038	02002K	PARTICIPANT	\N	PRESENT	0
41040	41038	01015L	PARTICIPANT	\N	PRESENT	0
41041	41038	14051J	PARTICIPANT	\N	PRESENT	0
41042	41038	11114F	PARTICIPANT	\N	PRESENT	0
41043	41038	01022K	PARTICIPANT	\N	PRESENT	0
41044	41038	14031R	PARTICIPANT	\N	PRESENT	0
41045	41038	08042U	PARTICIPANT	\N	PRESENT	0
41046	41038	14221J	PARTICIPANT	\N	PRESENT	0
41047	41038	11107G	PARTICIPANT	\N	PRESENT	0
41048	41038	14069U	PARTICIPANT	\N	PRESENT	0
42401	41832	89029V	PARTICIPANT	\N	PRESENT	0
42402	41832	01027Q	PARTICIPANT	\N	PRESENT	0
42403	41832	04034C	PARTICIPANT	\N	PRESENT	0
42404	41832	01031L	PARTICIPANT	\N	PRESENT	0
42405	41832	11057P	PARTICIPANT	\N	PRESENT	0
42406	41832	92020L	PARTICIPANT	\N	PRESENT	0
42407	41832	11027H	PARTICIPANT	\N	PRESENT	0
42408	41832	11015D	PARTICIPANT	\N	PRESENT	0
42409	41832	04054G	PARTICIPANT	\N	PRESENT	0
42410	41832	14267Y	PARTICIPANT	\N	PRESENT	0
42411	41832	14255U	PARTICIPANT	\N	PRESENT	0
42412	41832	04078Q	PARTICIPANT	\N	PRESENT	0
42413	41832	11026G	PARTICIPANT	\N	PRESENT	0
42414	41832	14121F	PARTICIPANT	\N	PRESENT	0
42415	41832	95037J	PARTICIPANT	\N	PRESENT	0
42416	41832	14028W	PARTICIPANT	\N	PRESENT	0
42417	41832	11035H	PARTICIPANT	\N	PRESENT	0
42418	41832	14085U	PARTICIPANT	\N	PRESENT	0
42419	41832	01014K	PARTICIPANT	\N	PRESENT	0
42420	41832	11076S	PARTICIPANT	\N	PRESENT	0
42421	41832	04042C	PARTICIPANT	\N	PRESENT	0
42422	41832	98018T	PARTICIPANT	\N	PRESENT	0
42423	41832	14173T	PARTICIPANT	\N	PRESENT	0
42424	41832	07029T	PARTICIPANT	\N	PRESENT	0
42425	41832	14175V	PARTICIPANT	\N	PRESENT	0
42426	41832	08011M	PARTICIPANT	\N	PRESENT	0
42427	41832	01056V	PARTICIPANT	\N	PRESENT	0
42428	41832	14211G	PARTICIPANT	\N	PRESENT	0
42429	41832	08065C	PARTICIPANT	\N	PRESENT	0
42430	41832	04055H	PARTICIPANT	\N	PRESENT	0
42431	41832	97011G	PARTICIPANT	\N	PRESENT	0
42432	41832	01041N	PARTICIPANT	\N	PRESENT	0
42433	41832	07024N	PARTICIPANT	\N	PRESENT	0
42434	41832	14277B	PARTICIPANT	\N	PRESENT	0
42435	41832	07004J	PARTICIPANT	\N	PRESENT	0
42436	41832	98005N	PARTICIPANT	\N	PRESENT	0
42437	41832	08022Q	PARTICIPANT	\N	PRESENT	0
42438	41832	86044G	PARTICIPANT	\N	PRESENT	0
42439	41832	95059Q	PARTICIPANT	\N	PRESENT	0
42440	41832	92031P	PARTICIPANT	\N	PRESENT	0
42441	41832	04036E	PARTICIPANT	\N	PRESENT	0
42442	41832	11106F	PARTICIPANT	\N	PRESENT	0
42443	41832	14083S	PARTICIPANT	\N	PRESENT	0
42444	41832	08017T	PARTICIPANT	\N	PRESENT	0
42445	41832	04077P	PARTICIPANT	\N	PRESENT	0
42446	41832	08061X	PARTICIPANT	\N	PRESENT	0
42447	41832	11054L	PARTICIPANT	\N	PRESENT	0
42448	41832	04035D	PARTICIPANT	\N	PRESENT	0
42449	41832	14265W	PARTICIPANT	\N	PRESENT	0
42450	41832	77002U	PARTICIPANT	\N	PRESENT	0
55483	54972	08031R	PARTICIPANT	\N	PRESENT	0
55484	54972	08051V	PARTICIPANT	\N	PRESENT	0
55485	54972	04038G	PARTICIPANT	\N	PRESENT	0
55486	54972	14251Q	PARTICIPANT	\N	PRESENT	0
55487	54972	11048N	PARTICIPANT	\N	PRESENT	0
55488	54972	01034P	PARTICIPANT	\N	PRESENT	0
55489	54972	11053K	PARTICIPANT	\N	PRESENT	0
55490	54972	01060R	PARTICIPANT	\N	PRESENT	0
55491	54972	14034U	PARTICIPANT	\N	PRESENT	0
55492	54972	95035G	PARTICIPANT	\N	PRESENT	0
55493	54972	11070L	PARTICIPANT	\N	PRESENT	0
55494	54972	14267Y	PARTICIPANT	\N	PRESENT	0
55495	54972	14147R	PARTICIPANT	\N	PRESENT	0
55496	54972	11064N	PARTICIPANT	\N	PRESENT	0
55497	54972	14103D	PARTICIPANT	\N	PRESENT	0
55498	54972	11043H	PARTICIPANT	\N	PRESENT	0
55499	54972	14239U	PARTICIPANT	\N	PRESENT	0
55500	54972	98022P	PARTICIPANT	\N	PRESENT	0
55501	54972	14241N	PARTICIPANT	\N	PRESENT	0
55502	54972	04070G	PARTICIPANT	\N	PRESENT	0
55503	54972	98042T	PARTICIPANT	\N	PRESENT	0
55504	54972	11093T	PARTICIPANT	\N	PRESENT	0
55505	54972	14237S	PARTICIPANT	\N	PRESENT	0
55506	54972	14175V	PARTICIPANT	\N	PRESENT	0
55507	54972	04040A	PARTICIPANT	\N	PRESENT	0
55508	54972	14255U	PARTICIPANT	\N	PRESENT	0
55509	54972	92045V	PARTICIPANT	\N	PRESENT	0
55510	54972	14083S	PARTICIPANT	\N	PRESENT	0
55511	54972	14275Y	PARTICIPANT	\N	PRESENT	0
55512	54972	04057K	PARTICIPANT	\N	PRESENT	0
55513	54972	14273W	PARTICIPANT	\N	PRESENT	0
55514	54972	14187A	PARTICIPANT	\N	PRESENT	0
55515	54972	14059S	PARTICIPANT	\N	PRESENT	0
55516	54972	14089Y	PARTICIPANT	\N	PRESENT	0
55517	54972	01025N	PARTICIPANT	\N	PRESENT	0
55518	54972	14209N	PARTICIPANT	\N	PRESENT	0
55519	54972	08028W	PARTICIPANT	\N	PRESENT	0
55520	54972	11111C	PARTICIPANT	\N	PRESENT	0
55521	54972	11037K	PARTICIPANT	\N	PRESENT	0
55522	54972	04081K	PARTICIPANT	\N	PRESENT	0
55523	54972	08073C	PARTICIPANT	\N	PRESENT	0
55524	54972	14041T	PARTICIPANT	\N	PRESENT	0
55525	54972	92044U	PARTICIPANT	\N	PRESENT	0
55526	54972	14055N	PARTICIPANT	\N	PRESENT	0
55527	54972	08042U	PARTICIPANT	\N	PRESENT	0
55528	54972	11105E	PARTICIPANT	\N	PRESENT	0
55529	54972	11089X	PARTICIPANT	\N	PRESENT	0
55530	54972	14327T	PARTICIPANT	\N	PRESENT	0
55531	54972	14331P	PARTICIPANT	\N	PRESENT	0
55532	54972	04079R	PARTICIPANT	\N	PRESENT	0
55533	54972	14105F	PARTICIPANT	\N	PRESENT	0
55534	54972	04053F	PARTICIPANT	\N	PRESENT	0
55535	54972	14042U	PARTICIPANT	\N	PRESENT	0
55536	54972	14030Q	PARTICIPANT	\N	PRESENT	0
55537	54972	11049P	PARTICIPANT	\N	PRESENT	0
55538	54972	14033T	PARTICIPANT	\N	PRESENT	0
55539	54972	14026U	PARTICIPANT	\N	PRESENT	0
55540	54972	14065Q	PARTICIPANT	\N	PRESENT	0
55541	54972	14259Y	PARTICIPANT	\N	PRESENT	0
55542	54972	96003C	PARTICIPANT	\N	PRESENT	0
55543	54972	11026G	PARTICIPANT	\N	PRESENT	0
55544	54972	14221J	PARTICIPANT	\N	PRESENT	0
55545	54972	07024N	PARTICIPANT	\N	PRESENT	0
55546	54972	14219Q	PARTICIPANT	\N	PRESENT	0
55547	54972	14037X	PARTICIPANT	\N	PRESENT	0
55548	54972	08010L	PARTICIPANT	\N	PRESENT	0
55549	54972	11056N	PARTICIPANT	\N	PRESENT	0
55550	54972	98053W	PARTICIPANT	\N	PRESENT	0
55551	54972	14213J	PARTICIPANT	\N	PRESENT	0
55552	54972	08015R	PARTICIPANT	\N	PRESENT	0
55553	54972	11083R	PARTICIPANT	\N	PRESENT	0
55554	54972	14207L	PARTICIPANT	\N	PRESENT	0
55555	54972	11099A	PARTICIPANT	\N	PRESENT	0
55556	54972	08065C	PARTICIPANT	\N	PRESENT	0
55557	54972	08068F	PARTICIPANT	\N	PRESENT	0
55558	54972	14087W	PARTICIPANT	\N	PRESENT	0
55559	54972	08018U	PARTICIPANT	\N	PRESENT	0
55560	54972	14247U	PARTICIPANT	\N	PRESENT	0
55561	54972	14069U	PARTICIPANT	\N	PRESENT	0
55562	54972	96004D	PARTICIPANT	\N	PRESENT	0
55563	54972	11090Q	PARTICIPANT	\N	PRESENT	0
55564	54972	04059M	PARTICIPANT	\N	PRESENT	0
55565	54972	14135M	PARTICIPANT	\N	PRESENT	0
55566	54972	80013X	PARTICIPANT	\N	PRESENT	0
55567	54972	95059Q	PARTICIPANT	\N	PRESENT	0
55568	54972	04086Q	PARTICIPANT	\N	PRESENT	0
55569	54972	11044J	PARTICIPANT	\N	PRESENT	0
55570	54972	04033B	PARTICIPANT	\N	PRESENT	0
55571	54972	08052W	PARTICIPANT	\N	PRESENT	0
55572	54972	11014C	PARTICIPANT	\N	PRESENT	0
55573	54972	04055H	PARTICIPANT	\N	PRESENT	0
55574	54972	14157T	PARTICIPANT	\N	PRESENT	0
55575	54972	14119M	PARTICIPANT	\N	PRESENT	0
55576	54972	14097Y	PARTICIPANT	\N	PRESENT	0
55577	54972	14269B	PARTICIPANT	\N	PRESENT	0
55578	54972	11015D	PARTICIPANT	\N	PRESENT	0
55579	54972	04042C	PARTICIPANT	\N	PRESENT	0
55580	54972	01057W	PARTICIPANT	\N	PRESENT	0
55581	54972	01048V	PARTICIPANT	\N	PRESENT	0
55582	54972	14215L	PARTICIPANT	\N	PRESENT	0
55583	54972	08041T	PARTICIPANT	\N	PRESENT	0
55584	54972	14061L	PARTICIPANT	\N	PRESENT	0
55585	54972	01043Q	PARTICIPANT	\N	PRESENT	0
55586	54972	08009T	PARTICIPANT	\N	PRESENT	0
55587	54972	95063L	PARTICIPANT	\N	PRESENT	0
55588	54972	05008E	PARTICIPANT	\N	PRESENT	0
55589	54972	14151M	PARTICIPANT	\N	PRESENT	0
55590	54972	09001P	PARTICIPANT	\N	PRESENT	0
55591	54972	14133K	PARTICIPANT	\N	PRESENT	0
55592	54972	08039A	PARTICIPANT	\N	PRESENT	0
55593	54972	14109K	PARTICIPANT	\N	PRESENT	0
55594	54972	11057P	PARTICIPANT	\N	PRESENT	0
55595	54972	10015M	PARTICIPANT	\N	PRESENT	0
55596	54972	01047U	PARTICIPANT	\N	PRESENT	0
55597	54972	90003B	PARTICIPANT	\N	PRESENT	0
55598	54972	04049K	PARTICIPANT	\N	PRESENT	0
55599	54972	11100Y	PARTICIPANT	\N	PRESENT	0
55600	54972	04074L	PARTICIPANT	\N	PRESENT	0
55601	54972	86044G	PARTICIPANT	\N	PRESENT	0
55602	54972	95067Q	PARTICIPANT	\N	PRESENT	0
55603	54972	04092N	PARTICIPANT	\N	PRESENT	0
55604	54972	11023D	PARTICIPANT	\N	PRESENT	0
55605	54972	83047W	PARTICIPANT	\N	PRESENT	0
55606	54972	11085T	PARTICIPANT	\N	PRESENT	0
55607	54972	95049N	PARTICIPANT	\N	PRESENT	0
55608	54972	14123H	PARTICIPANT	\N	PRESENT	0
55609	54972	01008M	PARTICIPANT	\N	PRESENT	0
55610	54972	14217N	PARTICIPANT	\N	PRESENT	0
55611	54972	89017R	PARTICIPANT	\N	PRESENT	0
55612	54972	08043V	PARTICIPANT	\N	PRESENT	0
55613	54972	11110B	PARTICIPANT	\N	PRESENT	0
55614	54972	04095R	PARTICIPANT	\N	PRESENT	0
55615	54972	11112D	PARTICIPANT	\N	PRESENT	0
55616	54972	12041X	PARTICIPANT	\N	PRESENT	0
55617	54972	08011M	PARTICIPANT	\N	PRESENT	0
55618	54972	05004A	PARTICIPANT	\N	PRESENT	0
55911	54873	98053W	PARTICIPANT	\N	PRESENT	0
55912	54873	01047U	PARTICIPANT	\N	PRESENT	0
55913	54873	11056N	PARTICIPANT	\N	PRESENT	0
55914	54873	14042U	PARTICIPANT	\N	PRESENT	0
55915	54873	01028R	PARTICIPANT	\N	PRESENT	0
55916	54873	08051V	PARTICIPANT	\N	PRESENT	0
55917	54873	11033F	PARTICIPANT	\N	PRESENT	0
55936	54873	01060R	PARTICIPANT	\N	PRESENT	0
55934	54873	14033T	PARTICIPANT	\N	PRESENT	0
55920	54873	14219Q	PARTICIPANT	\N	PRESENT	0
55921	54873	14205J	PARTICIPANT	\N	PRESENT	0
55922	54873	14063N	PARTICIPANT	\N	PRESENT	0
55923	54873	14097Y	PARTICIPANT	\N	PRESENT	0
55937	54873	11034G	PARTICIPANT	\N	PRESENT	0
55938	54873	11110B	PARTICIPANT	\N	PRESENT	0
55926	54873	80013X	PARTICIPANT	\N	PRESENT	0
55939	54873	14121F	PARTICIPANT	\N	PRESENT	0
55940	54873	14147R	PARTICIPANT	\N	PRESENT	0
55929	54873	14081Q	PARTICIPANT	\N	PRESENT	0
55930	54873	11081P	PARTICIPANT	\N	PRESENT	0
55941	54873	11036J	PARTICIPANT	\N	PRESENT	0
55932	54873	14273W	PARTICIPANT	\N	PRESENT	0
55933	54873	14213J	PARTICIPANT	\N	PRESENT	0
55935	54873	14041T	PARTICIPANT	\N	PRESENT	0
55942	54873	01057W	PARTICIPANT	\N	PRESENT	0
55943	54873	04044E	PARTICIPANT	\N	PRESENT	0
55944	54873	01027Q	PARTICIPANT	\N	PRESENT	0
55945	54873	11042G	PARTICIPANT	\N	PRESENT	0
55946	54873	05008E	PARTICIPANT	\N	PRESENT	0
55947	54873	14265W	PARTICIPANT	\N	PRESENT	0
55948	54873	14065Q	PARTICIPANT	\N	PRESENT	0
55949	54873	14191V	PARTICIPANT	\N	PRESENT	0
36761	36760	89017R	PARTICIPANT	\N	PRESENT	0
36762	36760	01031L	PRESIDENT	0	PRESENT	0
36816	36760	11089X	RAPPORTEUR_AVIS	\N	PRESENT	0
36764	36760	01013J	PARTICIPANT	\N	PRESENT	0
36765	36760	11068S	PARTICIPANT	\N	EXCUSE	0
36766	36760	11040E	PARTICIPANT	\N	PRESENT	0
36767	36760	08014Q	PARTICIPANT	\N	PRESENT	0
37255	37248	11082Q	PARTICIPANT	\N	EXCUSE	0
36769	36760	14175V	PARTICIPANT	\N	PRESENT	0
36770	36760	14083S	PARTICIPANT	\N	PRESENT	0
36771	36760	11053K	PARTICIPANT	\N	PRESENT	0
36772	36760	14085U	PARTICIPANT	\N	PRESENT	0
36773	36760	11042G	PARTICIPANT	\N	PRESENT	0
36774	36760	88008L	PARTICIPANT	\N	PRESENT	0
36775	36760	04086Q	PARTICIPANT	\N	PRESENT	0
37256	32377	11082Q	PARTICIPANT	\N	EXCUSE	0
36777	36760	11070L	PARTICIPANT	\N	PRESENT	0
36778	36760	11088W	PARTICIPANT	\N	PRESENT	0
36779	36760	14327T	PARTICIPANT	\N	EXCUSE	0
36780	36760	08022Q	PARTICIPANT	\N	PRESENT	0
36781	36760	01027Q	PARTICIPANT	\N	PRESENT	0
36782	36760	04071H	PARTICIPANT	\N	PRESENT	0
36814	36760	14071N	RAPPORTEUR_AVIS	\N	PRESENT	0
36815	36760	95035G	RAPPORTEUR_AVIS	\N	PRESENT	0
36785	36760	11083R	PARTICIPANT	\N	PRESENT	0
36786	36760	14199E	PARTICIPANT	\N	PRESENT	0
41261	40995	04081K	PARTICIPANT	\N	PRESENT	0
37381	37379	01031L	PRESIDENT	0	PRESENT	0
41262	40995	14013P	PARTICIPANT	\N	PRESENT	0
41263	40995	11098Y	PARTICIPANT	\N	PRESENT	0
36791	36760	99004R	PARTICIPANT	\N	PRESENT	0
36792	36760	04061F	PARTICIPANT	\N	PRESENT	0
36793	36760	14159V	PARTICIPANT	\N	PRESENT	0
36794	36760	07029T	PARTICIPANT	\N	PRESENT	0
37384	37379	11068S	PARTICIPANT	\N	EXCUSE	0
36796	36760	08010L	PARTICIPANT	\N	PRESENT	0
36797	36760	08034U	PARTICIPANT	\N	PRESENT	0
36798	36760	01048V	PARTICIPANT	\N	PRESENT	0
36799	36760	98046X	PARTICIPANT	\N	PRESENT	0
36800	36760	11085T	PARTICIPANT	\N	PRESENT	0
36801	36760	08011M	PARTICIPANT	\N	PRESENT	0
37385	37379	11040E	PARTICIPANT	\N	PRESENT	0
36803	36760	08061X	PARTICIPANT	\N	PRESENT	0
36804	36760	01016M	PARTICIPANT	\N	PRESENT	0
36805	36760	14225N	PARTICIPANT	\N	PRESENT	0
36806	36760	11012A	PARTICIPANT	\N	PRESENT	0
36807	36760	11057P	PARTICIPANT	\N	PRESENT	0
36808	36760	14173T	PARTICIPANT	\N	PRESENT	0
36809	36760	04034C	PARTICIPANT	\N	PRESENT	0
41264	40995	11057P	PARTICIPANT	\N	PRESENT	0
41265	40995	04034C	PARTICIPANT	\N	PRESENT	0
37388	37379	14175V	PARTICIPANT	\N	PRESENT	0
41266	40995	14257W	PARTICIPANT	\N	PRESENT	0
37390	37379	11053K	PARTICIPANT	\N	PRESENT	0
41267	40995	11074Q	PARTICIPANT	\N	PRESENT	0
37392	37379	11042G	PARTICIPANT	\N	PRESENT	0
41268	40995	08068F	PARTICIPANT	\N	PRESENT	0
37394	37379	04086Q	PARTICIPANT	\N	PRESENT	0
41269	40995	08016S	PARTICIPANT	\N	PRESENT	0
37396	37379	11070L	PARTICIPANT	\N	PRESENT	0
37397	37379	11088W	PARTICIPANT	\N	PRESENT	0
41270	40995	08052W	PARTICIPANT	\N	PRESENT	0
41271	40995	11083R	PARTICIPANT	\N	PRESENT	0
37400	37379	01027Q	PARTICIPANT	\N	EXCUSE	0
37401	37379	04071H	PARTICIPANT	\N	PRESENT	0
41272	40995	14083S	PARTICIPANT	\N	PRESENT	0
41273	40995	14103D	PARTICIPANT	\N	PRESENT	0
37404	37379	11083R	PARTICIPANT	\N	PRESENT	0
41274	40995	04086Q	PARTICIPANT	\N	PRESENT	0
37406	37379	01057W	PARTICIPANT	\N	PRESENT	0
37407	37379	08016S	PARTICIPANT	\N	PRESENT	0
41275	40995	10015M	PARTICIPANT	\N	PRESENT	0
37409	37379	11048N	PARTICIPANT	\N	PRESENT	0
37410	37379	99004R	PARTICIPANT	\N	PRESENT	0
41276	40995	04049K	PARTICIPANT	\N	PRESENT	0
37412	37379	14159V	PARTICIPANT	\N	PRESENT	0
37413	37379	07029T	PARTICIPANT	\N	PRESENT	0
37414	37379	14277B	PARTICIPANT	\N	PRESENT	0
41277	40995	14175V	PARTICIPANT	\N	PRESENT	0
37416	37379	08034U	PARTICIPANT	\N	PRESENT	0
37417	37379	01048V	PARTICIPANT	\N	PRESENT	0
37418	37379	98046X	PARTICIPANT	\N	PRESENT	0
41278	40995	08019V	PARTICIPANT	\N	PRESENT	0
37420	37379	08011M	PARTICIPANT	\N	PRESENT	0
37421	37379	08073C	PARTICIPANT	\N	PRESENT	0
41279	40995	01057W	PARTICIPANT	\N	PRESENT	0
37423	37379	01016M	PARTICIPANT	\N	PRESENT	0
37424	37379	14225N	PARTICIPANT	\N	PRESENT	0
37425	37379	11012A	PARTICIPANT	\N	PRESENT	0
37426	37379	11057P	PARTICIPANT	\N	PRESENT	0
41280	40995	01061S	PARTICIPANT	\N	PRESENT	0
37428	37379	04034C	PARTICIPANT	\N	PRESENT	0
41281	40995	88008L	PARTICIPANT	\N	PRESENT	0
41282	40995	14159V	PARTICIPANT	\N	PRESENT	0
41283	40995	01031L	PARTICIPANT	\N	PRESENT	0
41284	40995	01016M	PARTICIPANT	\N	PRESENT	0
41285	40995	11027H	PARTICIPANT	\N	PRESENT	0
41286	40995	14225N	PARTICIPANT	\N	PRESENT	0
41287	40995	01041N	PARTICIPANT	\N	PRESENT	0
41288	40995	14229S	PARTICIPANT	\N	PRESENT	0
41289	40995	99004R	PARTICIPANT	\N	PRESENT	0
41290	40995	14261S	PARTICIPANT	\N	PRESENT	0
41291	40995	14109K	PARTICIPANT	\N	PRESENT	0
41292	40995	11042G	PARTICIPANT	\N	PRESENT	0
41293	40995	14039A	PARTICIPANT	\N	PRESENT	0
41294	40995	07029T	PARTICIPANT	\N	PRESENT	0
41295	40995	08011M	PARTICIPANT	\N	PRESENT	0
41296	40995	08038Y	PARTICIPANT	\N	PRESENT	0
41338	40996	11083R	PARTICIPANT	\N	PRESENT	0
41339	40996	01031L	PARTICIPANT	\N	PRESENT	0
41340	40996	11098Y	PARTICIPANT	\N	PRESENT	0
41341	40996	12041X	PARTICIPANT	\N	PRESENT	0
41342	40996	14013P	PARTICIPANT	\N	PRESENT	0
41343	40996	08068F	PARTICIPANT	\N	PRESENT	0
41344	40996	08043V	PARTICIPANT	\N	PRESENT	0
41345	40996	08016S	PARTICIPANT	\N	PRESENT	0
41346	40996	14225N	PARTICIPANT	\N	PRESENT	0
41347	40996	04059M	PARTICIPANT	\N	PRESENT	0
41348	40996	14159V	PARTICIPANT	\N	PRESENT	0
41349	40996	14227Q	PARTICIPANT	\N	PRESENT	0
41350	40996	14109K	PARTICIPANT	\N	PRESENT	0
41351	40996	14229S	PARTICIPANT	\N	PRESENT	0
41352	40996	01044R	PARTICIPANT	\N	PRESENT	0
41353	40996	14261S	PARTICIPANT	\N	PRESENT	0
41354	40996	88008L	PARTICIPANT	\N	PRESENT	0
41355	40996	14103D	PARTICIPANT	\N	PRESENT	0
41356	40996	01025N	PARTICIPANT	\N	PRESENT	0
41357	40996	07029T	PARTICIPANT	\N	PRESENT	0
41358	40996	95035G	PARTICIPANT	\N	PRESENT	0
41359	40996	14041T	PARTICIPANT	\N	PRESENT	0
41360	40996	14083S	PARTICIPANT	\N	PRESENT	0
41361	40996	14175V	PARTICIPANT	\N	PRESENT	0
41362	40996	08019V	PARTICIPANT	\N	PRESENT	0
41363	40996	11057P	PARTICIPANT	\N	PRESENT	0
41364	40996	04034C	PARTICIPANT	\N	PRESENT	0
41365	40996	11027H	PARTICIPANT	\N	PRESENT	0
41366	40996	99004R	PARTICIPANT	\N	PRESENT	0
41367	40996	01041N	PARTICIPANT	\N	PRESENT	0
41368	40996	11074Q	PARTICIPANT	\N	PRESENT	0
41369	40996	08017T	PARTICIPANT	\N	PRESENT	0
41370	40996	08052W	PARTICIPANT	\N	PRESENT	0
41371	40996	01057W	PARTICIPANT	\N	PRESENT	0
41372	40996	11091R	PARTICIPANT	\N	PRESENT	0
41373	40996	08038Y	PARTICIPANT	\N	PRESENT	0
41336	40996	04066L	PARTICIPANT	\N	PRESENT	0
41337	40996	04070G	PARTICIPANT	\N	PRESENT	0
41374	40996	11114F	PARTICIPANT	\N	PRESENT	0
41375	40996	08011M	PARTICIPANT	\N	PRESENT	0
41385	41297	04081K	PARTICIPANT	\N	PRESENT	0
41386	41297	11040E	PARTICIPANT	\N	PRESENT	0
41387	41297	14071N	PARTICIPANT	\N	PRESENT	0
41388	41297	01031L	PARTICIPANT	\N	PRESENT	0
41389	41297	04034C	PARTICIPANT	\N	PRESENT	0
41390	41297	11031D	PARTICIPANT	\N	PRESENT	0
41391	41297	14231L	PARTICIPANT	\N	PRESENT	0
41392	41297	14173T	PARTICIPANT	\N	PRESENT	0
41393	41297	14041T	PARTICIPANT	\N	PRESENT	0
41394	41297	07029T	PARTICIPANT	\N	PRESENT	0
41404	41297	11074Q	PARTICIPANT	\N	PRESENT	0
41396	41297	04086Q	PARTICIPANT	\N	PRESENT	0
41397	41297	04044E	PARTICIPANT	\N	PRESENT	0
41398	41297	11055M	PARTICIPANT	\N	PRESENT	0
41399	41297	14227Q	PARTICIPANT	\N	PRESENT	0
41400	41297	11012A	PARTICIPANT	\N	PRESENT	0
41401	41297	14281W	PARTICIPANT	\N	PRESENT	0
41402	41297	14225N	PARTICIPANT	\N	PRESENT	0
41403	41297	98005N	PARTICIPANT	\N	PRESENT	0
41405	41297	11072N	PARTICIPANT	\N	PRESENT	0
60461	60449	11012A	PARTICIPANT	\N	PRESENT	0
60462	60037	04066L	PARTICIPANT	\N	PRESENT	0
60547	60545	04036E	PARTICIPANT	\N	PRESENT	0
60499	60497	08017T	PARTICIPANT	\N	PRESENT	0
60554	60553	14133K	PARTICIPANT	\N	PRESENT	0
60549	60548	04036E	PARTICIPANT	\N	PRESENT	0
60555	60553	08024S	PARTICIPANT	\N	PRESENT	0
60556	60553	08043V	PARTICIPANT	\N	PRESENT	0
60626	60592	14097Y	PARTICIPANT	\N	EXCUSE	0
60632	60631	11074Q	PARTICIPANT	\N	PRESENT	0
60633	60631	07034Q	PARTICIPANT	\N	PRESENT	0
60634	60631	04056J	PARTICIPANT	\N	PRESENT	0
60635	60631	11083R	PARTICIPANT	\N	PRESENT	0
60636	60631	11091R	PARTICIPANT	\N	PRESENT	0
60637	60631	01024M	PARTICIPANT	\N	PRESENT	0
60645	60644	14087W	PARTICIPANT	\N	PRESENT	0
60646	60592	14059S	PARTICIPANT	\N	EXCUSE	0
60665	54852	04044E	PARTICIPANT	\N	PRESENT	0
60666	58964	04044E	PARTICIPANT	\N	PRESENT	0
60693	60692	95015C	PARTICIPANT	\N	PRESENT	0
60694	60692	86034E	PARTICIPANT	\N	PRESENT	0
60696	60695	95015C	PARTICIPANT	\N	PRESENT	0
60697	54852	04045F	PARTICIPANT	\N	PRESENT	0
60698	58964	04045F	PARTICIPANT	\N	PRESENT	0
60699	60592	96003C	PARTICIPANT	\N	EXCUSE	0
60459	60449	14179A	PARTICIPANT	\N	PRESENT	0
60460	60449	10015M	PARTICIPANT	\N	PRESENT	0
31181	28666	83042R	PARTICIPANT	\N	EXCUSE	0
31516	31371	04081K	PARTICIPANT	\N	PRESENT	0
31519	31371	14105F	PARTICIPANT	\N	PRESENT	0
31525	31371	14013P	PARTICIPANT	\N	PRESENT	0
31526	31371	14223L	PARTICIPANT	\N	PRESENT	0
31527	31371	14121F	PARTICIPANT	\N	PRESENT	0
31528	31371	14269B	PARTICIPANT	\N	PRESENT	0
31529	31371	12042Y	PARTICIPANT	\N	PRESENT	0
31530	31371	08052W	PARTICIPANT	\N	PRESENT	0
31531	31371	11040E	PARTICIPANT	\N	PRESENT	0
31532	31371	14195A	PARTICIPANT	\N	PRESENT	0
31533	31371	04045F	PARTICIPANT	\N	PRESENT	0
31534	31371	11059R	PARTICIPANT	\N	PRESENT	0
31535	31371	11031D	PARTICIPANT	\N	PRESENT	0
31536	31371	14026U	PARTICIPANT	\N	PRESENT	0
31537	31371	14061L	PARTICIPANT	\N	PRESENT	0
31538	31371	01034P	PARTICIPANT	\N	PRESENT	0
31539	31371	11067R	PARTICIPANT	\N	PRESENT	0
31540	31371	00003C	PARTICIPANT	\N	PRESENT	0
31541	31371	11063M	PARTICIPANT	\N	PRESENT	0
31542	31371	01059Y	PARTICIPANT	\N	PRESENT	0
31543	31371	14263U	PARTICIPANT	\N	PRESENT	0
31544	31371	04053F	PARTICIPANT	\N	PRESENT	0
31545	31371	14281W	PARTICIPANT	\N	PRESENT	0
31546	31371	11055M	PARTICIPANT	\N	PRESENT	0
31547	31371	14239U	PARTICIPANT	\N	PRESENT	0
31548	31371	14042U	PARTICIPANT	\N	PRESENT	0
31549	31371	01046T	PARTICIPANT	\N	PRESENT	0
31550	31371	04092N	PARTICIPANT	\N	PRESENT	0
31551	31371	11103C	PARTICIPANT	\N	PRESENT	0
31552	31371	08019V	PARTICIPANT	\N	PRESENT	0
31553	31371	14159V	PARTICIPANT	\N	PRESENT	0
31554	31371	14111D	PARTICIPANT	\N	PRESENT	0
31555	31371	04097T	PARTICIPANT	\N	PRESENT	0
31556	31371	14213J	PARTICIPANT	\N	PRESENT	0
31557	31371	14053L	PARTICIPANT	\N	PRESENT	0
31558	31371	11088W	PARTICIPANT	\N	PRESENT	0
31559	31371	08062Y	PARTICIPANT	\N	PRESENT	0
31560	31371	14265W	PARTICIPANT	\N	PRESENT	0
31561	31371	14327T	PARTICIPANT	\N	PRESENT	0
31562	31371	14231L	PARTICIPANT	\N	PRESENT	0
31563	31371	11093T	PARTICIPANT	\N	PRESENT	0
31564	31371	07026Q	PARTICIPANT	\N	PRESENT	0
31565	31371	01028R	PARTICIPANT	\N	PRESENT	0
31566	31371	14071N	PARTICIPANT	\N	PRESENT	0
31567	31371	14217N	PARTICIPANT	\N	PRESENT	0
31568	31371	14103D	PARTICIPANT	\N	PRESENT	0
31569	31371	14151M	PARTICIPANT	\N	PRESENT	0
31570	31371	08028W	PARTICIPANT	\N	PRESENT	0
31571	31371	11091R	PARTICIPANT	\N	PRESENT	0
31572	31371	14273W	PARTICIPANT	\N	PRESENT	0
31573	31371	08056B	PARTICIPANT	\N	PRESENT	0
31574	31371	92045V	PARTICIPANT	\N	PRESENT	0
31575	31371	14267Y	PARTICIPANT	\N	PRESENT	0
31576	31371	14059S	PARTICIPANT	\N	PRESENT	0
31577	31371	14255U	PARTICIPANT	\N	PRESENT	0
31578	31371	14219Q	PARTICIPANT	\N	PRESENT	0
31579	31371	14147R	PARTICIPANT	\N	PRESENT	0
31580	31371	11036J	PARTICIPANT	\N	PRESENT	0
31581	31371	08015R	PARTICIPANT	\N	PRESENT	0
31582	31371	95035G	PARTICIPANT	\N	PRESENT	0
31583	31371	11061K	PARTICIPANT	\N	PRESENT	0
31584	31371	01041N	PARTICIPANT	\N	PRESENT	0
31585	31371	04066L	PARTICIPANT	\N	PRESENT	0
31586	31371	11066Q	PARTICIPANT	\N	PRESENT	0
31587	31371	08016S	PARTICIPANT	\N	PRESENT	0
31588	31371	04057K	PARTICIPANT	\N	PRESENT	0
31589	31371	08041T	PARTICIPANT	\N	PRESENT	0
31590	31371	14069U	PARTICIPANT	\N	PRESENT	0
31591	31371	04080J	PARTICIPANT	\N	PRESENT	0
31592	31371	08017T	PARTICIPANT	\N	PRESENT	0
31593	31371	10006L	PARTICIPANT	\N	PRESENT	0
31594	31371	14087W	PARTICIPANT	\N	PRESENT	0
31595	31371	01048V	PARTICIPANT	\N	PRESENT	0
31596	31371	11044J	PARTICIPANT	\N	PRESENT	0
31597	31371	14083S	PARTICIPANT	\N	PRESENT	0
31598	31371	14034U	PARTICIPANT	\N	PRESENT	0
31599	31371	99004R	PARTICIPANT	\N	PRESENT	0
31600	31371	08061X	PARTICIPANT	\N	PRESENT	0
31601	31371	14173T	PARTICIPANT	\N	PRESENT	0
31602	31371	14073Q	PARTICIPANT	\N	PRESENT	0
31603	31371	98050T	PARTICIPANT	\N	PRESENT	0
31604	31371	11085T	PARTICIPANT	\N	PRESENT	0
31605	31371	14197C	PARTICIPANT	\N	PRESENT	0
31606	31371	89017R	PARTICIPANT	\N	PRESENT	0
31607	31371	08034U	PARTICIPANT	\N	PRESENT	0
31608	31371	01027Q	PARTICIPANT	\N	PRESENT	0
31609	31371	11053K	PARTICIPANT	\N	PRESENT	0
31610	31371	01047U	PARTICIPANT	\N	PRESENT	0
31614	31371	01058X	PARTICIPANT	\N	PRESENT	0
31616	31371	98024R	PARTICIPANT	\N	PRESENT	0
31617	31371	14135M	PARTICIPANT	\N	PRESENT	0
31618	31371	11026G	PARTICIPANT	\N	PRESENT	0
31619	31371	14261S	PARTICIPANT	\N	PRESENT	0
31620	31371	08010L	PARTICIPANT	\N	PRESENT	0
37602	37601	98018T	PARTICIPANT	\N	PRESENT	0
37281	37279	04085P	PARTICIPANT	\N	PRESENT	0
37282	37279	05008E	PARTICIPANT	\N	PRESENT	0
42451	41832	11042G	PARTICIPANT	\N	PRESENT	0
37284	37279	11033F	PARTICIPANT	\N	PRESENT	0
37285	37279	14065Q	PARTICIPANT	\N	PRESENT	0
42452	41832	11083R	PARTICIPANT	\N	PRESENT	0
37287	37279	04047H	PARTICIPANT	\N	EXCUSE	0
42453	41832	08058D	PARTICIPANT	\N	PRESENT	0
42454	41832	08034U	PARTICIPANT	\N	PRESENT	0
42455	41832	14231L	PARTICIPANT	\N	PRESENT	0
42456	41832	01048V	PARTICIPANT	\N	PRESENT	0
37292	37279	14259Y	PARTICIPANT	\N	PRESENT	0
42457	41832	14225N	PARTICIPANT	\N	PRESENT	0
37294	37279	14041T	PARTICIPANT	\N	PRESENT	0
37295	37279	11113E	PARTICIPANT	\N	PRESENT	0
37296	37279	01024M	PARTICIPANT	\N	PRESENT	0
37297	37279	14215L	PARTICIPANT	\N	EXCUSE	0
37298	37279	11034G	PARTICIPANT	\N	PRESENT	0
37299	37279	08018U	PARTICIPANT	\N	PRESENT	0
37300	37279	11010L	PARTICIPANT	\N	PRESENT	0
37301	37279	01007L	PARTICIPANT	\N	PRESENT	0
42458	41832	11113E	PARTICIPANT	\N	PRESENT	0
42459	41832	08018U	PARTICIPANT	\N	PRESENT	0
37304	37279	11084S	PARTICIPANT	\N	PRESENT	0
37305	37279	11026G	PARTICIPANT	\N	PRESENT	0
37306	37279	04079R	PARTICIPANT	\N	PRESENT	0
42460	41832	14041T	PARTICIPANT	\N	PRESENT	0
37308	37279	14001X	PARTICIPANT	\N	PRESENT	0
42461	41832	08010L	PARTICIPANT	\N	PRESENT	0
42462	41832	01024M	PARTICIPANT	\N	PRESENT	0
42465	41832	01047U	PARTICIPANT	\N	PRESENT	0
37312	37279	95049N	PARTICIPANT	\N	PRESENT	0
42466	41832	11049P	PARTICIPANT	\N	PRESENT	0
42471	41832	04040A	PARTICIPANT	\N	PRESENT	0
37315	37279	07034Q	PARTICIPANT	\N	EXCUSE	0
42472	41832	10015M	PARTICIPANT	\N	PRESENT	0
42473	41832	08014Q	PARTICIPANT	\N	PRESENT	0
42488	41832	98046X	PARTICIPANT	\N	PRESENT	0
42498	41832	08041T	PARTICIPANT	\N	PRESENT	0
37320	37279	01028R	PARTICIPANT	\N	PRESENT	0
42499	41832	11105E	PARTICIPANT	\N	PRESENT	0
37322	37279	04056J	PARTICIPANT	\N	PRESENT	0
37323	37279	14275Y	PARTICIPANT	\N	PRESENT	0
37324	37279	04044E	PRESIDENT	0	PRESENT	0
37325	37279	11037K	PARTICIPANT	\N	PRESENT	0
37326	37279	92045V	PARTICIPANT	\N	EXCUSE	0
37327	37279	95067Q	PARTICIPANT	\N	PRESENT	0
42515	41832	92015P	PARTICIPANT	\N	PRESENT	0
42518	41832	14031R	PARTICIPANT	\N	PRESENT	0
42522	41832	98022P	PARTICIPANT	\N	PRESENT	0
42525	41832	14107H	PARTICIPANT	\N	PRESENT	0
42526	41832	95062K	PARTICIPANT	\N	PRESENT	0
42528	41832	14135M	PARTICIPANT	\N	PRESENT	0
42529	41832	11103C	PARTICIPANT	\N	PRESENT	0
42580	41832	14038Y	PARTICIPANT	\N	PRESENT	0
42585	41832	14133K	PARTICIPANT	\N	PRESENT	0
42586	41832	95015C	PARTICIPANT	\N	PRESENT	0
42587	41832	95030B	PARTICIPANT	\N	PRESENT	0
42588	41832	01057W	PARTICIPANT	\N	PRESENT	0
42589	41832	01016M	PARTICIPANT	\N	PRESENT	0
42630	41832	14221J	PARTICIPANT	\N	PRESENT	0
42631	41832	14219Q	PARTICIPANT	\N	PRESENT	0
42632	41832	14259Y	PARTICIPANT	\N	PRESENT	0
42633	41832	11084S	PARTICIPANT	\N	PRESENT	0
42634	41832	14159V	PARTICIPANT	\N	PRESENT	0
45681	44620	01048V	PARTICIPANT	\N	EXCUSE	0
45684	45683	14017T	PARTICIPANT	\N	PRESENT	0
45693	45691	14213J	PARTICIPANT	\N	PRESENT	0
45745	45744	14239U	PARTICIPANT	\N	PRESENT	0
45746	45744	11055M	PARTICIPANT	\N	PRESENT	0
45747	45744	01046T	PARTICIPANT	\N	PRESENT	0
45748	45744	04053F	PARTICIPANT	\N	PRESENT	0
55950	54873	14031R	PARTICIPANT	\N	PRESENT	0
55951	54873	04085P	PARTICIPANT	\N	PRESENT	0
55952	54873	00003C	PARTICIPANT	\N	PRESENT	0
55953	54873	04038G	PARTICIPANT	\N	PRESENT	0
55954	54873	14014Q	PARTICIPANT	\N	PRESENT	0
55955	54873	04088S	PARTICIPANT	\N	PRESENT	0
55956	54873	98035U	PARTICIPANT	\N	PRESENT	0
55957	54873	95049N	PARTICIPANT	\N	PRESENT	0
55958	54873	01024M	PARTICIPANT	\N	PRESENT	0
55959	54873	14107H	PARTICIPANT	\N	PRESENT	0
55960	54873	14215L	PARTICIPANT	\N	PRESENT	0
55962	54873	08041T	PARTICIPANT	\N	PRESENT	0
55964	54873	14079W	PARTICIPANT	\N	PRESENT	0
55965	54873	11053K	PARTICIPANT	\N	PRESENT	0
55966	54873	14013P	PARTICIPANT	\N	PRESENT	0
55970	54873	14083S	PARTICIPANT	\N	PRESENT	0
55971	54873	95062K	PARTICIPANT	\N	PRESENT	0
55972	54873	14223L	PARTICIPANT	\N	PRESENT	0
55973	54873	11067R	PARTICIPANT	\N	PRESENT	0
55974	54873	14026U	PARTICIPANT	\N	PRESENT	0
55975	54873	01008M	PARTICIPANT	\N	PRESENT	0
55976	54873	14038Y	PARTICIPANT	\N	PRESENT	0
55977	54873	14199E	PARTICIPANT	\N	PRESENT	0
55979	54873	14187A	PARTICIPANT	\N	PRESENT	0
55980	54873	11084S	PARTICIPANT	\N	PRESENT	0
55981	54873	95030B	PARTICIPANT	\N	PRESENT	0
55982	54873	14195A	PARTICIPANT	\N	PRESENT	0
55983	54873	14119M	PARTICIPANT	\N	PRESENT	0
55984	54873	14269B	PARTICIPANT	\N	PRESENT	0
55994	54873	95063L	PARTICIPANT	\N	PRESENT	0
55995	54873	14259Y	PARTICIPANT	\N	PRESENT	0
55996	54873	14231L	PARTICIPANT	\N	PRESENT	0
55998	55997	07034Q	PARTICIPANT	\N	PRESENT	0
55999	54873	11097X	PARTICIPANT	\N	PRESENT	0
56000	54873	92045V	PARTICIPANT	\N	PRESENT	0
56001	54873	14169X	PARTICIPANT	\N	PRESENT	0
56003	56002	07034Q	PARTICIPANT	\N	PRESENT	0
56004	54873	08019V	PARTICIPANT	\N	PRESENT	0
56005	54873	14051J	PARTICIPANT	\N	PRESENT	0
56006	54873	11029K	PARTICIPANT	\N	PRESENT	0
56007	54873	08028W	PARTICIPANT	\N	PRESENT	0
56008	54873	01007L	PARTICIPANT	\N	PRESENT	0
56009	54873	14217N	PARTICIPANT	\N	PRESENT	0
56010	54874	98053W	PARTICIPANT	\N	PRESENT	0
56132	54874	04044E	PARTICIPANT	\N	PRESENT	0
56133	54874	14193X	PARTICIPANT	\N	PRESENT	0
56124	54874	11112D	PARTICIPANT	\N	PRESENT	0
56134	54874	14105F	PARTICIPANT	\N	PRESENT	0
56135	54874	14014Q	PARTICIPANT	\N	PRESENT	0
56052	54874	11037K	PARTICIPANT	\N	PRESENT	0
56056	56055	14263U	PARTICIPANT	\N	PRESENT	0
56136	54874	11036J	PARTICIPANT	\N	PRESENT	0
56137	54874	11068S	PARTICIPANT	\N	PRESENT	0
56138	54874	01028R	PARTICIPANT	\N	PRESENT	0
56021	54874	11034G	PARTICIPANT	\N	PRESENT	0
56139	54874	14205J	PARTICIPANT	\N	PRESENT	0
56140	54874	14034U	PARTICIPANT	\N	PRESENT	0
56141	54874	14231L	PARTICIPANT	\N	PRESENT	0
56025	54874	05008E	PARTICIPANT	\N	PRESENT	0
56026	54874	14265W	PARTICIPANT	\N	PRESENT	0
56057	56055	14133K	PARTICIPANT	\N	PRESENT	0
56126	54874	01046T	PARTICIPANT	\N	PRESENT	0
56029	54874	04038G	PARTICIPANT	\N	PRESENT	0
56142	54874	14071N	PARTICIPANT	\N	PRESENT	0
56143	54874	01008M	PARTICIPANT	\N	PRESENT	0
56144	54874	14187A	PARTICIPANT	\N	PRESENT	0
56059	56055	04059M	PARTICIPANT	\N	PRESENT	0
56034	54874	14215L	PARTICIPANT	\N	PRESENT	0
56035	54874	14079W	PARTICIPANT	\N	PRESENT	0
56145	54874	14169X	PARTICIPANT	\N	PRESENT	0
56146	54874	11097X	PARTICIPANT	\N	PRESENT	0
56150	54874	14213J	PARTICIPANT	\N	PRESENT	0
56061	56055	01044R	PARTICIPANT	\N	PRESENT	0
56148	54874	14271U	PARTICIPANT	\N	PRESENT	0
56062	56055	08043V	PARTICIPANT	\N	EXCUSE	0
56149	54874	14087W	PARTICIPANT	\N	PRESENT	0
56151	54874	11012A	PARTICIPANT	\N	PRESENT	0
56152	54874	14026U	PARTICIPANT	\N	PRESENT	0
56153	54874	14073Q	PARTICIPANT	\N	PRESENT	0
56154	54874	08051V	PARTICIPANT	\N	PRESENT	0
56047	54874	92045V	PARTICIPANT	\N	PRESENT	0
56155	54874	80013X	PARTICIPANT	\N	PRESENT	0
56049	54874	11029K	PARTICIPANT	\N	PRESENT	0
56156	54874	14219Q	PARTICIPANT	\N	PRESENT	0
56157	54874	14083S	PARTICIPANT	\N	PRESENT	0
56063	56055	14089Y	PARTICIPANT	\N	PRESENT	0
56064	56055	14105F	PARTICIPANT	\N	PRESENT	0
56065	56055	11029K	PARTICIPANT	\N	PRESENT	0
56066	56055	95015C	PARTICIPANT	\N	PRESENT	0
56067	56055	92015P	PARTICIPANT	\N	EXCUSE	0
56068	56055	08024S	PARTICIPANT	\N	PRESENT	0
56069	56055	14201E	PARTICIPANT	\N	EXCUSE	0
56070	56055	14329V	PARTICIPANT	\N	PRESENT	0
56071	56055	14209N	PARTICIPANT	\N	PRESENT	0
56158	54874	11064N	PARTICIPANT	\N	PRESENT	0
56159	54874	11026G	PARTICIPANT	\N	PRESENT	0
56074	56055	87003B	PARTICIPANT	\N	PRESENT	0
56160	54874	14235Q	PARTICIPANT	\N	PRESENT	0
56161	54874	11056N	PARTICIPANT	\N	PRESENT	0
56077	56055	01041N	PARTICIPANT	\N	PRESENT	0
56078	56055	01025N	PARTICIPANT	\N	PRESENT	0
56125	54874	04057K	PARTICIPANT	\N	PRESENT	0
56127	54874	01059Y	PARTICIPANT	\N	PRESENT	0
56128	54874	14065Q	PARTICIPANT	\N	PRESENT	0
56082	56055	11089X	PARTICIPANT	\N	PRESENT	0
56083	56055	07026Q	PARTICIPANT	\N	PRESENT	0
56084	56055	14123H	PARTICIPANT	\N	PRESENT	0
56129	54874	14030Q	PARTICIPANT	\N	PRESENT	0
56086	56055	04041B	PARTICIPANT	\N	PRESENT	0
56087	56055	14241N	PARTICIPANT	\N	PRESENT	0
56088	56055	14061L	PARTICIPANT	\N	PRESENT	0
56089	56055	14073Q	PARTICIPANT	\N	PRESENT	0
56090	56055	08031R	PARTICIPANT	\N	PRESENT	0
56091	56055	12041X	PARTICIPANT	\N	PRESENT	0
56092	56055	08039A	PARTICIPANT	\N	PRESENT	0
56130	54874	14031R	PARTICIPANT	\N	PRESENT	0
56094	56055	14059S	PARTICIPANT	\N	PRESENT	0
56131	54874	14191V	PARTICIPANT	\N	PRESENT	0
56096	56055	14103D	PARTICIPANT	\N	PRESENT	0
56097	56055	11104D	PARTICIPANT	\N	PRESENT	0
56162	54874	01007L	PARTICIPANT	\N	PRESENT	0
56099	56055	04057K	PARTICIPANT	\N	PRESENT	0
56100	56055	11014C	PARTICIPANT	\N	PRESENT	0
56101	56055	14109K	PARTICIPANT	\N	PRESENT	0
56102	56055	04070G	PRESIDENT	0	PRESENT	0
56103	56055	92040Q	PARTICIPANT	\N	PRESENT	0
56104	56055	14191V	PARTICIPANT	\N	PRESENT	0
56105	56055	83047W	PARTICIPANT	\N	PRESENT	0
56106	56055	14235Q	PARTICIPANT	\N	PRESENT	0
56163	54874	14089Y	PARTICIPANT	\N	PRESENT	0
56108	56055	04033B	PARTICIPANT	\N	PRESENT	0
56109	56055	14229S	PARTICIPANT	\N	PRESENT	0
56110	56055	11043H	PARTICIPANT	\N	PRESENT	0
56164	54874	14038Y	PARTICIPANT	\N	PRESENT	0
56112	56055	11011M	PARTICIPANT	\N	PRESENT	0
56165	54874	14033T	PARTICIPANT	\N	PRESENT	0
56331	56330	11039M	PARTICIPANT	\N	PRESENT	0
56332	56330	98042T	PARTICIPANT	\N	PRESENT	0
56333	56330	01019Q	PARTICIPANT	\N	PRESENT	0
56336	56334	08055A	PARTICIPANT	\N	PRESENT	0
56337	56334	14093U	PARTICIPANT	\N	PRESENT	0
56338	56334	14030Q	PARTICIPANT	\N	PRESENT	0
56339	56334	96004D	PARTICIPANT	\N	EXCUSE	0
56340	56334	08060W	PARTICIPANT	\N	PRESENT	0
56341	56334	11095V	PARTICIPANT	\N	EXCUSE	0
56342	56334	14038Y	PARTICIPANT	\N	PRESENT	0
56343	56334	11114F	PARTICIPANT	\N	PRESENT	0
56344	56334	98023Q	PARTICIPANT	\N	PRESENT	0
56347	56334	11107G	PARTICIPANT	\N	PRESENT	0
56349	56334	02002K	PARTICIPANT	\N	PRESENT	0
56350	56334	01022K	PARTICIPANT	\N	PRESENT	0
56352	56334	09001P	PARTICIPANT	\N	PRESENT	0
56353	56334	11059R	PARTICIPANT	\N	PRESENT	0
56354	56334	14219Q	PARTICIPANT	\N	PRESENT	0
56355	56334	80027E	PARTICIPANT	\N	PRESENT	0
56356	56334	14031R	PARTICIPANT	\N	PRESENT	0
56357	56334	08009T	PRESIDENT	0	PRESENT	0
56358	56334	08062Y	PARTICIPANT	\N	PRESENT	0
56359	56334	14221J	PARTICIPANT	\N	PRESENT	0
56360	56334	92039X	PARTICIPANT	\N	PRESENT	0
56362	56334	14169X	PARTICIPANT	\N	PRESENT	0
56363	56334	14237S	PARTICIPANT	\N	PRESENT	0
56364	56334	13002U	PARTICIPANT	\N	PRESENT	0
31681	31680	04054G	PARTICIPANT	\N	PRESENT	0
31682	31680	04040A	PARTICIPANT	\N	EXCUSE	0
31684	31680	08058D	PARTICIPANT	\N	PRESENT	0
31685	31680	04042C	PARTICIPANT	\N	PRESENT	0
31686	31680	11027H	PARTICIPANT	\N	PRESENT	0
31688	31680	98018T	PARTICIPANT	\N	EXCUSE	0
31694	31680	14014Q	PARTICIPANT	\N	EXCUSE	0
31691	31680	92020L	PARTICIPANT	\N	EXCUSE	0
31692	31680	97011G	PARTICIPANT	\N	PRESENT	0
31693	31680	07024N	PARTICIPANT	\N	EXCUSE	0
31695	31680	07004J	PARTICIPANT	\N	EXCUSE	0
31696	31680	95035G	PARTICIPANT	\N	PRESENT	0
31698	31680	08056B	PARTICIPANT	\N	PRESENT	0
31699	31680	92031P	PARTICIPANT	\N	PRESENT	0
31700	31680	04078Q	PARTICIPANT	\N	PRESENT	0
31701	31680	04036E	PARTICIPANT	\N	EXCUSE	0
31702	31680	04077P	PARTICIPANT	\N	PRESENT	0
31703	31680	11106F	PARTICIPANT	\N	EXCUSE	0
31704	31680	14251Q	PARTICIPANT	\N	PRESENT	0
31705	31680	83042R	PARTICIPANT	\N	EXCUSE	0
31706	31680	11105E	PARTICIPANT	\N	EXCUSE	0
31707	31680	14028W	PARTICIPANT	\N	EXCUSE	0
31708	31680	98021N	PARTICIPANT	\N	EXCUSE	0
31709	31680	95059Q	PRESIDENT	0	PRESENT	0
31710	31680	86044G	PARTICIPANT	\N	PRESENT	0
31711	31680	11054L	PARTICIPANT	\N	PRESENT	0
35124	35123	11061K	PARTICIPANT	\N	PRESENT	0
35125	35123	04036E	PARTICIPANT	\N	PRESENT	0
35126	35123	95067Q	PARTICIPANT	\N	PRESENT	0
35128	35127	08018U	PARTICIPANT	\N	PRESENT	0
35129	35127	04036E	PARTICIPANT	\N	PRESENT	0
35130	35127	95067Q	PARTICIPANT	\N	PRESENT	0
41406	41297	14159V	PARTICIPANT	\N	PRESENT	0
41407	41297	08019V	PARTICIPANT	\N	PRESENT	0
41408	41297	07026Q	PARTICIPANT	\N	PRESENT	0
41409	41297	99004R	PARTICIPANT	\N	PRESENT	0
41410	41297	11083R	PARTICIPANT	\N	PRESENT	0
41411	41297	14261S	PARTICIPANT	\N	PRESENT	0
41412	41297	04053F	PARTICIPANT	\N	PRESENT	0
41413	41297	11098Y	PARTICIPANT	\N	PRESENT	0
41414	41297	14269B	PARTICIPANT	\N	PRESENT	0
41415	41297	08014Q	PARTICIPANT	\N	PRESENT	0
41416	41297	98018T	PARTICIPANT	\N	PRESENT	0
41417	41297	08010L	PARTICIPANT	\N	PRESENT	0
41418	41297	11071M	PARTICIPANT	\N	PRESENT	0
41419	41297	11082Q	PARTICIPANT	\N	PRESENT	0
41420	41297	07024N	PARTICIPANT	\N	PRESENT	0
41421	41297	11054L	PARTICIPANT	\N	PRESENT	0
41462	41461	14033T	PARTICIPANT	\N	PRESENT	0
41463	41461	01008M	PARTICIPANT	\N	PRESENT	0
41464	41461	04088S	PARTICIPANT	\N	PRESENT	0
41465	41461	11099A	PARTICIPANT	\N	PRESENT	0
41467	41466	14033T	PARTICIPANT	\N	PRESENT	0
41468	41466	14207L	PARTICIPANT	\N	PRESENT	0
41469	41466	01008M	PARTICIPANT	\N	PRESENT	0
41475	41474	14033T	PARTICIPANT	\N	PRESENT	0
41472	41471	14033T	PARTICIPANT	\N	PRESENT	0
41473	41471	08015R	PARTICIPANT	\N	PRESENT	0
41476	41474	14207L	PARTICIPANT	\N	PRESENT	0
41478	41477	14033T	PARTICIPANT	\N	PRESENT	0
41479	41477	14207L	PARTICIPANT	\N	PRESENT	0
41481	41480	14033T	PARTICIPANT	\N	PRESENT	0
41482	41480	11100Y	PARTICIPANT	\N	PRESENT	0
41483	41480	14207L	PARTICIPANT	\N	PRESENT	0
41484	41480	01008M	PARTICIPANT	\N	PRESENT	0
41486	41485	14033T	PARTICIPANT	\N	PRESENT	0
41488	41487	14033T	PARTICIPANT	\N	PRESENT	0
41489	41487	04089T	PARTICIPANT	\N	PRESENT	0
41490	41487	01008M	PARTICIPANT	\N	PRESENT	0
41492	41491	14033T	PARTICIPANT	\N	PRESENT	0
41493	41491	04089T	PARTICIPANT	\N	PRESENT	0
41494	41491	01008M	PARTICIPANT	\N	PRESENT	0
41496	41495	14033T	PARTICIPANT	\N	PRESENT	0
41497	41495	14207L	PARTICIPANT	\N	PRESENT	0
41499	41498	14033T	PARTICIPANT	\N	PRESENT	0
41500	41498	14207L	PARTICIPANT	\N	PRESENT	0
41502	41501	01031L	PRESIDENT	0	PRESENT	0
41503	41501	11040E	PARTICIPANT	\N	PRESENT	0
41504	41501	08014Q	PARTICIPANT	\N	PRESENT	0
41505	41501	04086Q	PARTICIPANT	\N	PRESENT	0
41506	41501	04071H	PARTICIPANT	\N	PRESENT	0
41507	41501	11074Q	PARTICIPANT	\N	PRESENT	0
41508	41501	11083R	PARTICIPANT	\N	PRESENT	0
41509	41501	08069G	PARTICIPANT	\N	PRESENT	0
41459	41458	14033T	PARTICIPANT	\N	PRESENT	0
41460	41458	08015R	PARTICIPANT	\N	PRESENT	0
41510	41501	99004R	PARTICIPANT	\N	PRESENT	0
41511	41501	14159V	PARTICIPANT	\N	PRESENT	0
41512	41501	07029T	PARTICIPANT	\N	PRESENT	0
41513	41501	08010L	PARTICIPANT	\N	PRESENT	0
41514	41501	14225N	PARTICIPANT	\N	PRESENT	0
41515	41501	11012A	PARTICIPANT	\N	PRESENT	0
41516	41501	14173T	PARTICIPANT	\N	PRESENT	0
41517	41501	04034C	PARTICIPANT	\N	PRESENT	0
41518	41501	08011M	PARTICIPANT	\N	EXCUSE	0
41581	41298	01031L	PARTICIPANT	\N	PRESENT	0
41582	41298	08014Q	PARTICIPANT	\N	PRESENT	0
41583	41298	11026G	PARTICIPANT	\N	PRESENT	0
41584	41298	11074Q	PARTICIPANT	\N	PRESENT	0
41585	41298	11098Y	PARTICIPANT	\N	PRESENT	0
41586	41298	07026Q	PARTICIPANT	\N	PRESENT	0
41587	41298	14225N	PARTICIPANT	\N	PRESENT	0
41588	41298	11042G	PARTICIPANT	\N	PRESENT	0
41589	41298	11023D	PARTICIPANT	\N	PRESENT	0
41590	41298	11033F	PARTICIPANT	\N	PRESENT	0
41591	41298	11083R	PARTICIPANT	\N	PRESENT	0
41592	41298	11084S	PARTICIPANT	\N	PRESENT	0
41593	41298	14261S	PARTICIPANT	\N	PRESENT	0
41594	41298	04038G	PARTICIPANT	\N	PRESENT	0
41595	41298	07004J	PARTICIPANT	\N	PRESENT	0
41596	41298	07029T	PARTICIPANT	\N	PRESENT	0
41597	41298	14041T	PARTICIPANT	\N	PRESENT	0
41598	41298	98005N	PARTICIPANT	\N	PRESENT	0
41599	41298	14031R	PARTICIPANT	\N	PRESENT	0
41600	41298	08069G	PARTICIPANT	\N	PRESENT	0
41601	41298	01041N	PARTICIPANT	\N	PRESENT	0
41602	41298	11060J	PARTICIPANT	\N	PRESENT	0
41603	41298	04047H	PARTICIPANT	\N	PRESENT	0
41604	41298	01056V	PARTICIPANT	\N	PRESENT	0
41605	41298	98046X	PARTICIPANT	\N	PRESENT	0
41606	41298	14159V	PARTICIPANT	\N	PRESENT	0
41607	41298	14207L	PARTICIPANT	\N	PRESENT	0
41608	41298	14257W	PARTICIPANT	\N	PRESENT	0
41609	41298	04034C	PARTICIPANT	\N	PRESENT	0
41610	41298	11090Q	PARTICIPANT	\N	PRESENT	0
41614	41298	90003B	PARTICIPANT	\N	PRESENT	0
41615	41298	05008E	PARTICIPANT	\N	PRESENT	0
41616	41298	98018T	PARTICIPANT	\N	PRESENT	0
41618	41298	01016M	PARTICIPANT	\N	PRESENT	0
41620	41298	11012A	PARTICIPANT	\N	PRESENT	0
41621	41298	11085T	PARTICIPANT	\N	PRESENT	0
41622	41298	11034G	PARTICIPANT	\N	PRESENT	0
41623	41298	14135M	PARTICIPANT	\N	PRESENT	0
41624	41298	08010L	PARTICIPANT	\N	PRESENT	0
41625	41298	08058D	PARTICIPANT	\N	PRESENT	0
41626	41298	04071H	PARTICIPANT	\N	PRESENT	0
41627	41298	04035D	PARTICIPANT	\N	PRESENT	0
41628	41298	11111C	PARTICIPANT	\N	PRESENT	0
41629	41298	14033T	PARTICIPANT	\N	PRESENT	0
41657	41299	08069G	PARTICIPANT	\N	PRESENT	0
41658	41299	08014Q	PARTICIPANT	\N	PRESENT	0
41659	41299	11098Y	PARTICIPANT	\N	PRESENT	0
41579	41298	04081K	PARTICIPANT	\N	PRESENT	0
41580	41298	99004R	PARTICIPANT	\N	PRESENT	0
41660	41299	14207L	PARTICIPANT	\N	PRESENT	0
41661	41299	14135M	PARTICIPANT	\N	PRESENT	0
41662	41299	14033T	PARTICIPANT	\N	PRESENT	0
41663	41299	14257W	PARTICIPANT	\N	PRESENT	0
41664	41299	08016S	PARTICIPANT	\N	PRESENT	0
41665	41299	11110B	PARTICIPANT	\N	PRESENT	0
41666	41299	01016M	PARTICIPANT	\N	PRESENT	0
41667	41299	14083S	PARTICIPANT	\N	PRESENT	0
41668	41299	90003B	PARTICIPANT	\N	PRESENT	0
41669	41299	11100Y	PARTICIPANT	\N	PRESENT	0
41655	41299	08055A	PARTICIPANT	\N	PRESENT	0
41656	41299	01031L	PARTICIPANT	\N	PRESENT	0
60551	60550	11048N	PARTICIPANT	\N	PRESENT	0
60552	60550	14063N	PARTICIPANT	\N	PRESENT	0
45749	45744	14255U	PARTICIPANT	\N	PRESENT	0
45750	45744	04066L	PARTICIPANT	\N	PRESENT	0
45751	45744	00003C	PARTICIPANT	\N	PRESENT	0
45752	45744	14053L	PARTICIPANT	\N	PRESENT	0
45753	45744	11103C	PARTICIPANT	\N	PRESENT	0
45883	45882	01008M	PARTICIPANT	\N	PRESENT	0
45755	45744	14195A	PARTICIPANT	\N	PRESENT	0
45756	45744	14267Y	PARTICIPANT	\N	PRESENT	0
45757	45744	11023D	PARTICIPANT	\N	PRESENT	0
45758	45744	11031D	PARTICIPANT	\N	PRESENT	0
45759	45744	08052W	PARTICIPANT	\N	PRESENT	0
45760	45744	01059Y	PARTICIPANT	\N	PRESENT	0
45761	45744	04081K	PARTICIPANT	\N	PRESENT	0
45762	45744	98024R	PARTICIPANT	\N	PRESENT	0
45763	45744	10006L	PARTICIPANT	\N	PRESENT	0
45764	45744	04067M	PARTICIPANT	\N	PRESENT	0
45765	45744	14217N	PARTICIPANT	\N	PRESENT	0
45766	45744	14042U	PARTICIPANT	\N	PRESENT	0
45884	45882	11036J	PARTICIPANT	\N	PRESENT	0
45768	45744	12042Y	PARTICIPANT	\N	PRESENT	0
45885	45882	11081P	PARTICIPANT	\N	PRESENT	0
45770	45744	14087W	PARTICIPANT	\N	PRESENT	0
45771	45744	01003G	PARTICIPANT	\N	PRESENT	0
45886	45882	14013P	PARTICIPANT	\N	PRESENT	0
45773	45744	14231L	PARTICIPANT	\N	PRESENT	0
45774	45744	11061K	PARTICIPANT	\N	PRESENT	0
45775	45744	08048B	PARTICIPANT	\N	PRESENT	0
45887	45882	08068F	PARTICIPANT	\N	PRESENT	0
45777	45744	01011G	PARTICIPANT	\N	PRESENT	0
45778	45744	14026U	PARTICIPANT	\N	PRESENT	0
45779	45744	14213J	PARTICIPANT	\N	PRESENT	0
45780	45744	14121F	PARTICIPANT	\N	PRESENT	0
45781	45744	11112D	PARTICIPANT	\N	PRESENT	0
45782	45744	14037X	PARTICIPANT	\N	PRESENT	0
45888	45882	14207L	PARTICIPANT	\N	PRESENT	0
45784	45744	11067R	PARTICIPANT	\N	PRESENT	0
45785	45744	14223L	PARTICIPANT	\N	PRESENT	0
45786	45744	04092N	PRESIDENT	0	PRESENT	0
45787	45744	14265W	PARTICIPANT	\N	PRESENT	0
45788	45744	14119M	PARTICIPANT	\N	PRESENT	0
45789	45744	14071N	PARTICIPANT	\N	PRESENT	0
45790	45744	07032N	PARTICIPANT	\N	PRESENT	0
45791	45744	04043D	PARTICIPANT	\N	PRESENT	0
45792	45744	14271U	PARTICIPANT	\N	PRESENT	0
45793	45744	14017T	PARTICIPANT	\N	EXCUSE	0
45794	45744	11093T	PARTICIPANT	\N	PRESENT	0
45795	45744	11097X	PARTICIPANT	\N	PRESENT	0
45796	45744	04045F	PARTICIPANT	\N	PRESENT	0
45797	45744	14227Q	PARTICIPANT	\N	PRESENT	0
45798	45744	01034P	PARTICIPANT	\N	PRESENT	0
45889	45882	11101A	PARTICIPANT	\N	PRESENT	0
45800	45744	11063M	PARTICIPANT	\N	PRESENT	0
45801	45744	14269B	PARTICIPANT	\N	PRESENT	0
45890	45882	90003B	PARTICIPANT	\N	PRESENT	0
45891	45882	08028W	PARTICIPANT	\N	PRESENT	0
45892	45882	80013X	PARTICIPANT	\N	PRESENT	0
45893	45882	08038Y	PARTICIPANT	\N	PRESENT	0
45894	45882	04089T	PARTICIPANT	\N	PRESENT	0
45895	45882	14197C	PARTICIPANT	\N	PRESENT	0
45896	45882	11110B	PARTICIPANT	\N	PRESENT	0
45897	45882	14187A	PARTICIPANT	\N	PRESENT	0
45898	45882	14033T	PARTICIPANT	\N	PRESENT	0
46080	46078	14263U	PARTICIPANT	\N	PRESENT	0
45900	45882	04048J	PARTICIPANT	\N	PRESENT	0
45901	45882	11099A	PARTICIPANT	\N	PRESENT	0
45902	45882	04049K	PARTICIPANT	\N	PRESENT	0
46081	46078	14133K	PARTICIPANT	\N	PRESENT	0
45904	45882	11111C	PARTICIPANT	\N	PRESENT	0
45905	45882	08015R	PARTICIPANT	\N	PRESENT	0
45906	45882	11100Y	PRESIDENT	0	PRESENT	0
45907	45882	01061S	PARTICIPANT	\N	PRESENT	0
45908	45882	11098Y	PARTICIPANT	\N	PRESENT	0
45909	45882	01043Q	PARTICIPANT	\N	EXCUSE	0
45910	45882	11077T	PARTICIPANT	\N	PRESENT	0
45911	45882	14205J	PARTICIPANT	\N	PRESENT	0
45912	45882	08019V	PARTICIPANT	\N	PRESENT	0
45913	45882	14257W	PARTICIPANT	\N	PRESENT	0
45914	45882	08021P	PARTICIPANT	\N	PRESENT	0
45915	45882	04088S	PARTICIPANT	\N	PRESENT	0
49166	47946	11042G	PARTICIPANT	\N	PRESENT	0
45917	45882	11090Q	PARTICIPANT	\N	PRESENT	0
45918	45882	11046L	PARTICIPANT	\N	PRESENT	0
45919	45882	01058X	PARTICIPANT	\N	PRESENT	0
45920	45882	11094U	PARTICIPANT	\N	PRESENT	0
45921	45882	11066Q	PARTICIPANT	\N	PRESENT	0
49167	47946	01016M	PARTICIPANT	\N	PRESENT	0
46083	46078	04059M	PARTICIPANT	\N	PRESENT	0
46084	46078	11039M	PARTICIPANT	\N	PRESENT	0
46085	46078	01044R	PARTICIPANT	\N	PRESENT	0
46086	46078	08043V	PARTICIPANT	\N	PRESENT	0
46087	46078	14089Y	PARTICIPANT	\N	PRESENT	0
46088	46078	14105F	PARTICIPANT	\N	PRESENT	0
46089	46078	11029K	PARTICIPANT	\N	PRESENT	0
46090	46078	95015C	PRESIDENT	0	PRESENT	0
46091	46078	92015P	PARTICIPANT	\N	PRESENT	0
46092	46078	08024S	PARTICIPANT	\N	PRESENT	0
46093	46078	14201E	PARTICIPANT	\N	PRESENT	0
49168	47946	98046X	PARTICIPANT	\N	PRESENT	0
46095	46078	14209N	PARTICIPANT	\N	PRESENT	0
46096	46078	14079W	PARTICIPANT	\N	PRESENT	0
46097	46078	11091R	PARTICIPANT	\N	EXCUSE	0
46098	46078	87003B	PARTICIPANT	\N	PRESENT	0
46099	46078	98042T	PARTICIPANT	\N	PRESENT	0
46100	46078	14249W	PARTICIPANT	\N	PRESENT	0
46101	46078	01041N	PARTICIPANT	\N	PRESENT	0
46102	46078	01025N	PARTICIPANT	\N	PRESENT	0
46103	46078	01037S	PARTICIPANT	\N	PRESENT	0
46104	46078	89029V	PARTICIPANT	\N	PRESENT	0
49169	47946	14269B	PARTICIPANT	\N	PRESENT	0
46106	46078	11089X	PARTICIPANT	\N	PRESENT	0
46107	46078	07026Q	PARTICIPANT	\N	PRESENT	0
46108	46078	14123H	PARTICIPANT	\N	PRESENT	0
46109	46078	14179A	PARTICIPANT	\N	PRESENT	0
46110	46078	04041B	PARTICIPANT	\N	PRESENT	0
46111	46078	14241N	PARTICIPANT	\N	PRESENT	0
46112	46078	14061L	PARTICIPANT	\N	PRESENT	0
46113	46078	14073Q	PARTICIPANT	\N	PRESENT	0
46114	46078	08031R	PARTICIPANT	\N	EXCUSE	0
49170	47946	08014Q	PARTICIPANT	\N	PRESENT	0
46116	46078	08039A	PARTICIPANT	\N	PRESENT	0
49171	47946	04045F	PARTICIPANT	\N	PRESENT	0
46118	46078	14059S	PARTICIPANT	\N	EXCUSE	0
49172	47946	14121F	PARTICIPANT	\N	PRESENT	0
46120	46078	14103D	PARTICIPANT	\N	PRESENT	0
46121	46078	11104D	PARTICIPANT	\N	PRESENT	0
46122	46078	14063N	PARTICIPANT	\N	PRESENT	0
46123	46078	04057K	PARTICIPANT	\N	PRESENT	0
46124	46078	11014C	PARTICIPANT	\N	PRESENT	0
46125	46078	14109K	PARTICIPANT	\N	PRESENT	0
46126	46078	04070G	PARTICIPANT	\N	EXCUSE	0
46127	46078	92040Q	PARTICIPANT	\N	PRESENT	0
46128	46078	14191V	PARTICIPANT	\N	PRESENT	0
46129	46078	83047W	PARTICIPANT	\N	PRESENT	0
46130	46078	14235Q	PARTICIPANT	\N	PRESENT	0
49173	47946	04034C	PARTICIPANT	\N	PRESENT	0
49174	47946	14225N	PARTICIPANT	\N	PRESENT	0
46133	46078	14229S	PARTICIPANT	\N	PRESENT	0
46134	46078	11043H	PARTICIPANT	\N	PRESENT	0
46135	46078	11071M	PARTICIPANT	\N	PRESENT	0
49175	47946	14085U	PARTICIPANT	\N	PRESENT	0
49176	47946	11083R	PARTICIPANT	\N	PRESENT	0
49177	47946	01031L	PARTICIPANT	\N	PRESENT	0
49178	47946	08011M	PARTICIPANT	\N	PRESENT	0
49179	47946	14030Q	PARTICIPANT	\N	PRESENT	0
49180	47946	11093T	PARTICIPANT	\N	PRESENT	0
49181	47946	14073Q	PARTICIPANT	\N	PRESENT	0
49182	47946	11053K	PARTICIPANT	\N	PRESENT	0
49183	47946	11070L	PARTICIPANT	\N	PRESENT	0
49184	47946	14083S	PARTICIPANT	\N	PRESENT	0
49185	47946	14273W	PARTICIPANT	\N	PRESENT	0
49186	47946	14193X	PARTICIPANT	\N	PRESENT	0
49187	47946	14069U	PARTICIPANT	\N	PRESENT	0
49188	47946	04086Q	PARTICIPANT	\N	PRESENT	0
49189	47946	99004R	PARTICIPANT	\N	PRESENT	0
49190	47946	04071H	PARTICIPANT	\N	PRESENT	0
49191	47946	95015C	PARTICIPANT	\N	PRESENT	0
49192	47946	11091R	PARTICIPANT	\N	PRESENT	0
49193	47946	11097X	PARTICIPANT	\N	PRESENT	0
49194	47946	07029T	PARTICIPANT	\N	PRESENT	0
49195	47946	04088S	PARTICIPANT	\N	PRESENT	0
49196	47946	14041T	PARTICIPANT	\N	PRESENT	0
49197	47946	11112D	PARTICIPANT	\N	PRESENT	0
49198	47946	14038Y	PARTICIPANT	\N	PRESENT	0
49199	47946	14173T	PARTICIPANT	\N	PRESENT	0
49200	47946	14191V	PARTICIPANT	\N	PRESENT	0
49201	47946	01057W	PARTICIPANT	\N	PRESENT	0
49202	47946	14157T	PARTICIPANT	\N	PRESENT	0
49203	47946	14195A	PARTICIPANT	\N	PRESENT	0
49204	47946	14205J	PARTICIPANT	\N	PRESENT	0
56374	56334	14207L	PARTICIPANT	\N	PRESENT	0
56376	56375	01008M	PARTICIPANT	\N	PRESENT	0
56377	56375	11036J	PARTICIPANT	\N	PRESENT	0
56378	56375	11081P	PARTICIPANT	\N	PRESENT	0
56379	56375	14013P	PARTICIPANT	\N	PRESENT	0
56380	56375	08068F	PARTICIPANT	\N	PRESENT	0
56381	56375	14207L	PARTICIPANT	\N	PRESENT	0
56382	56375	11101A	PARTICIPANT	\N	PRESENT	0
56383	56375	90003B	PARTICIPANT	\N	PRESENT	0
56384	56375	08028W	PARTICIPANT	\N	PRESENT	0
56385	56375	80013X	PARTICIPANT	\N	PRESENT	0
56386	56375	08038Y	PARTICIPANT	\N	PRESENT	0
56387	56375	04089T	PARTICIPANT	\N	PRESENT	0
56388	56375	14197C	PARTICIPANT	\N	PRESENT	0
56389	56375	11110B	PARTICIPANT	\N	PRESENT	0
56390	56375	14187A	PARTICIPANT	\N	PRESENT	0
56391	56375	14033T	PARTICIPANT	\N	PRESENT	0
56392	56375	14081Q	PARTICIPANT	\N	PRESENT	0
56393	56375	04048J	PARTICIPANT	\N	PRESENT	0
56394	56375	11099A	PARTICIPANT	\N	PRESENT	0
56395	56375	04049K	PARTICIPANT	\N	PRESENT	0
56396	56375	04094Q	PARTICIPANT	\N	PRESENT	0
56397	56375	11111C	PARTICIPANT	\N	PRESENT	0
56398	56375	08015R	PARTICIPANT	\N	PRESENT	0
56399	56375	11100Y	PRESIDENT	0	PRESENT	0
56400	56375	01061S	PARTICIPANT	\N	PRESENT	0
56401	56375	11098Y	PARTICIPANT	\N	PRESENT	0
56402	56375	01043Q	PARTICIPANT	\N	PRESENT	0
56403	56375	11077T	PARTICIPANT	\N	PRESENT	0
56404	56375	14205J	PARTICIPANT	\N	PRESENT	0
56405	56375	08019V	PARTICIPANT	\N	PRESENT	0
56406	56375	14257W	PARTICIPANT	\N	PRESENT	0
56616	56225	08055A	PARTICIPANT	\N	PRESENT	0
56408	56375	04088S	PARTICIPANT	\N	PRESENT	0
56617	56225	11025F	PARTICIPANT	\N	PRESENT	0
56410	56375	11090Q	PARTICIPANT	\N	PRESENT	0
56411	56375	11046L	PARTICIPANT	\N	PRESENT	0
56412	56375	01058X	PARTICIPANT	\N	PRESENT	0
56618	56225	14121F	PARTICIPANT	\N	PRESENT	0
56414	56375	11066Q	PARTICIPANT	\N	PRESENT	0
56619	56225	14247U	PARTICIPANT	\N	PRESENT	0
56620	56225	92045V	PARTICIPANT	\N	PRESENT	0
56634	56225	14175V	PARTICIPANT	\N	PRESENT	0
56622	56225	11066Q	PARTICIPANT	\N	PRESENT	0
56623	56225	11037K	PARTICIPANT	\N	PRESENT	0
56624	56225	11034G	PARTICIPANT	\N	PRESENT	0
56625	56225	01044R	PARTICIPANT	\N	PRESENT	0
56626	56225	11029K	PARTICIPANT	\N	PRESENT	0
56627	56225	13002U	PARTICIPANT	\N	PRESENT	0
56628	56225	11059R	PARTICIPANT	\N	PRESENT	0
56629	56225	11105E	PARTICIPANT	\N	PRESENT	0
56630	56225	14030Q	PARTICIPANT	\N	PRESENT	0
56631	56225	11077T	PARTICIPANT	\N	PRESENT	0
56632	56225	04044E	PARTICIPANT	\N	PRESENT	0
56633	56225	04089T	PARTICIPANT	\N	PRESENT	0
56635	51891	14030Q	PARTICIPANT	\N	PRESENT	0
56637	56225	04038G	PARTICIPANT	\N	PRESENT	0
56687	56225	14273W	PARTICIPANT	\N	PRESENT	0
56697	56225	11081P	PARTICIPANT	\N	PRESENT	0
56690	52494	14030Q	PARTICIPANT	\N	PRESENT	0
56692	56225	95049N	PARTICIPANT	\N	PRESENT	0
56693	56225	01007L	PARTICIPANT	\N	PRESENT	0
56694	52497	04049K	PARTICIPANT	\N	PRESENT	0
56695	56225	14223L	PARTICIPANT	\N	PRESENT	0
56696	56225	14207L	PARTICIPANT	\N	PRESENT	0
56698	56225	04088S	PARTICIPANT	\N	PRESENT	0
56699	56225	14038Y	PARTICIPANT	\N	PRESENT	0
56700	56225	14265W	PARTICIPANT	\N	PRESENT	0
56701	56225	99004R	PARTICIPANT	\N	PRESENT	0
56702	56225	95062K	PARTICIPANT	\N	PRESENT	0
56704	56225	11036J	PARTICIPANT	\N	PRESENT	0
56705	56225	14257W	PARTICIPANT	\N	PRESENT	0
56706	56225	14013P	PARTICIPANT	\N	PRESENT	0
56707	56225	11040E	PARTICIPANT	\N	PRESENT	0
56708	56225	14079W	PARTICIPANT	\N	PRESENT	0
56709	56225	14157T	PARTICIPANT	\N	PRESENT	0
56710	56225	14037X	PARTICIPANT	\N	PRESENT	0
56712	56375	08021P	PARTICIPANT	\N	EXCUSE	0
56713	56375	98050T	PARTICIPANT	\N	EXCUSE	0
56714	56375	11094U	PARTICIPANT	\N	EXCUSE	0
56715	56225	04094Q	PARTICIPANT	\N	PRESENT	0
56716	56225	14205J	PARTICIPANT	\N	PRESENT	0
56717	56225	14081Q	PARTICIPANT	\N	PRESENT	0
56718	56225	14135M	PARTICIPANT	\N	PRESENT	0
56719	56225	08062Y	PARTICIPANT	\N	PRESENT	0
56720	56222	11044J	PARTICIPANT	\N	PRESENT	0
56721	56222	11067R	PARTICIPANT	\N	PRESENT	0
56722	56225	14275Y	PARTICIPANT	\N	PRESENT	0
56723	56225	01043Q	PARTICIPANT	\N	PRESENT	0
56724	56225	08015R	PARTICIPANT	\N	PRESENT	0
56725	56225	11026G	PARTICIPANT	\N	PRESENT	0
56726	56225	14033T	PARTICIPANT	\N	PRESENT	0
56365	56334	05012A	PARTICIPANT	\N	PRESENT	0
56727	56225	14173T	PARTICIPANT	\N	PRESENT	0
56367	56334	14135M	PARTICIPANT	\N	PRESENT	0
56368	56334	14331P	PARTICIPANT	\N	PRESENT	0
56369	56334	95062K	PARTICIPANT	\N	PRESENT	0
56370	56334	14107H	PARTICIPANT	\N	PRESENT	0
56371	56334	14051J	PARTICIPANT	\N	PRESENT	0
56372	56334	14157T	PARTICIPANT	\N	PRESENT	0
56728	56225	14169X	PARTICIPANT	\N	PRESENT	0
56729	56225	11084S	PARTICIPANT	\N	PRESENT	0
56730	56225	14215L	PARTICIPANT	\N	PRESENT	0
56731	56225	08051V	PARTICIPANT	\N	PRESENT	0
56732	56225	14063N	PARTICIPANT	\N	PRESENT	0
56733	56225	14195A	PARTICIPANT	\N	PRESENT	0
56734	56225	14147R	PARTICIPANT	\N	PRESENT	0
56735	56225	11098Y	PARTICIPANT	\N	PRESENT	0
56736	56225	08068F	PARTICIPANT	\N	PRESENT	0
56737	56225	14107H	PARTICIPANT	\N	PRESENT	0
56738	56225	01048V	PARTICIPANT	\N	PRESENT	0
56739	56225	11101A	PARTICIPANT	\N	PRESENT	0
56797	56225	05008E	PARTICIPANT	\N	PRESENT	0
56798	56225	14267Y	PARTICIPANT	\N	PRESENT	0
56799	56225	14051J	PARTICIPANT	\N	PRESENT	0
56800	56225	14259Y	PARTICIPANT	\N	PRESENT	0
56801	56225	14069U	PARTICIPANT	\N	PRESENT	0
56802	56225	01008M	PARTICIPANT	\N	PRESENT	0
56803	56225	11103C	PARTICIPANT	\N	PRESENT	0
56804	56225	88008L	PARTICIPANT	\N	PRESENT	0
56805	56225	11067R	PARTICIPANT	\N	PRESENT	0
56806	56225	14197C	PARTICIPANT	\N	PRESENT	0
56807	56225	14159V	PARTICIPANT	\N	PRESENT	0
56808	56225	01027Q	PARTICIPANT	\N	PRESENT	0
56809	56225	14231L	PARTICIPANT	\N	PRESENT	0
56810	56225	11042G	PARTICIPANT	\N	PRESENT	0
56811	56225	08010L	PARTICIPANT	\N	PRESENT	0
56812	56225	86044G	PARTICIPANT	\N	PRESENT	0
56813	56225	14199E	PARTICIPANT	\N	PRESENT	0
56814	56225	11070L	PARTICIPANT	\N	PRESENT	0
56815	56225	08034U	PARTICIPANT	\N	PRESENT	0
56816	56225	80013X	PARTICIPANT	\N	PRESENT	0
56817	56225	14034U	PARTICIPANT	\N	PRESENT	0
56818	56225	01016M	PARTICIPANT	\N	PRESENT	0
56819	56225	95063L	PARTICIPANT	\N	PRESENT	0
56820	56225	11090Q	PARTICIPANT	\N	PRESENT	0
56821	56225	11112D	PARTICIPANT	\N	PRESENT	0
56822	56225	14087W	PARTICIPANT	\N	PRESENT	0
56823	56225	14251Q	PARTICIPANT	\N	PRESENT	0
56825	56824	14263U	PARTICIPANT	\N	PRESENT	0
56827	56824	11109J	PARTICIPANT	\N	PRESENT	0
56828	56824	04059M	PARTICIPANT	\N	PRESENT	0
56829	56824	11039M	PARTICIPANT	\N	PRESENT	0
56830	56824	01044R	PARTICIPANT	\N	PRESENT	0
56831	56824	08043V	PARTICIPANT	\N	EXCUSE	0
56832	56824	14089Y	PARTICIPANT	\N	PRESENT	0
56833	56824	14105F	PARTICIPANT	\N	PRESENT	0
56835	56824	95015C	PARTICIPANT	\N	PRESENT	0
56836	56824	92015P	PARTICIPANT	\N	EXCUSE	0
56837	56824	08024S	PARTICIPANT	\N	PRESENT	0
56838	56824	14201E	PARTICIPANT	\N	EXCUSE	0
56839	56824	14329V	PARTICIPANT	\N	PRESENT	0
56842	56824	11091R	PARTICIPANT	\N	PRESENT	0
56843	56824	87003B	PARTICIPANT	\N	PRESENT	0
56845	56824	14249W	PARTICIPANT	\N	EXCUSE	0
56846	56824	01041N	PARTICIPANT	\N	PRESENT	0
56847	56824	01025N	PARTICIPANT	\N	PRESENT	0
56851	56824	11089X	PARTICIPANT	\N	PRESENT	0
56852	56824	07026Q	PARTICIPANT	\N	PRESENT	0
56854	56824	14179A	PARTICIPANT	\N	PRESENT	0
33124	32370	14263U	PARTICIPANT	\N	EXCUSE	0
33125	32370	14209N	PARTICIPANT	\N	EXCUSE	0
41736	41611	11039M	PARTICIPANT	\N	PRESENT	0
41737	41611	14147R	PARTICIPANT	\N	PRESENT	0
41738	41611	14071N	PARTICIPANT	\N	PRESENT	0
41739	41611	14041T	PARTICIPANT	\N	PRESENT	0
41742	41611	11110B	PARTICIPANT	\N	PRESENT	0
41743	41611	05012A	PARTICIPANT	\N	PRESENT	0
41744	41611	11111C	PARTICIPANT	\N	PRESENT	0
41745	41611	08052W	PARTICIPANT	\N	PRESENT	0
41746	41611	14269B	PARTICIPANT	\N	PRESENT	0
41747	41611	14275Y	PARTICIPANT	\N	PRESENT	0
41748	41611	14059S	PARTICIPANT	\N	PRESENT	0
41749	41611	14237S	PARTICIPANT	\N	PRESENT	0
41762	41611	14105F	PARTICIPANT	\N	PRESENT	0
41763	41611	08065C	PARTICIPANT	\N	PRESENT	0
41764	41611	11113E	PARTICIPANT	\N	PRESENT	0
41765	41611	14063N	PARTICIPANT	\N	PRESENT	0
41766	41611	11104D	PARTICIPANT	\N	PRESENT	0
41767	41611	14111D	PARTICIPANT	\N	PRESENT	0
41768	41611	14173T	PARTICIPANT	\N	PRESENT	0
41769	41611	11094U	PARTICIPANT	\N	PRESENT	0
41734	41611	89029V	PARTICIPANT	\N	PRESENT	0
41735	41611	01028R	PARTICIPANT	\N	PRESENT	0
41770	41611	11061K	PARTICIPANT	\N	PRESENT	0
41771	41611	95015C	PARTICIPANT	\N	PRESENT	0
41772	41611	14031R	PARTICIPANT	\N	PRESENT	0
41773	41611	14179A	PARTICIPANT	\N	PRESENT	0
41774	41611	14033T	PARTICIPANT	\N	PRESENT	0
41775	41611	01027Q	PARTICIPANT	\N	PRESENT	0
41826	41611	04034C	PARTICIPANT	\N	PRESENT	0
41827	41611	98018T	PARTICIPANT	\N	PRESENT	0
41828	41611	14109K	PARTICIPANT	\N	PRESENT	0
41829	41611	04043D	PARTICIPANT	\N	PRESENT	0
41830	41611	02002K	PARTICIPANT	\N	PRESENT	0
41831	41611	04038G	PARTICIPANT	\N	PRESENT	0
41835	41611	11031D	PARTICIPANT	\N	PRESENT	0
41836	41611	04054G	PARTICIPANT	\N	PRESENT	0
41837	41611	11063M	PARTICIPANT	\N	PRESENT	0
41850	41612	08058D	PARTICIPANT	\N	PRESENT	0
41851	41612	01022K	PARTICIPANT	\N	PRESENT	0
41852	41612	80013X	PARTICIPANT	\N	PRESENT	0
41853	41612	08060W	PARTICIPANT	\N	PRESENT	0
41854	41612	14107H	PARTICIPANT	\N	PRESENT	0
41855	41612	11083R	PARTICIPANT	\N	PRESENT	0
41856	41612	09001P	PARTICIPANT	\N	PRESENT	0
41857	41612	08009T	PARTICIPANT	\N	PRESENT	0
41858	41612	92039X	PARTICIPANT	\N	PRESENT	0
41847	41612	08055A	PARTICIPANT	\N	PRESENT	0
41849	41612	14263U	PARTICIPANT	\N	PRESENT	0
41859	41612	08022Q	PARTICIPANT	\N	PRESENT	0
41860	41612	01031L	PARTICIPANT	\N	PRESENT	0
41861	41612	08042U	PARTICIPANT	\N	PRESENT	0
41862	41612	14213J	PARTICIPANT	\N	PRESENT	0
41863	41612	14265W	PARTICIPANT	\N	PRESENT	0
41864	41612	14093U	PARTICIPANT	\N	PRESENT	0
41865	41612	14175V	PARTICIPANT	\N	PRESENT	0
41866	41612	11107G	PARTICIPANT	\N	PRESENT	0
41867	41612	98046X	PARTICIPANT	\N	PRESENT	0
41868	41612	01058X	PARTICIPANT	\N	PRESENT	0
41869	41612	11053K	PARTICIPANT	\N	PRESENT	0
41871	41612	01015L	PARTICIPANT	\N	PRESENT	0
41872	41612	11098Y	PARTICIPANT	\N	PRESENT	0
41873	41612	14219Q	PARTICIPANT	\N	PRESENT	0
41874	41612	14038Y	PARTICIPANT	\N	PRESENT	0
41875	41612	95062K	PARTICIPANT	\N	PRESENT	0
41876	41612	11036J	PARTICIPANT	\N	PRESENT	0
41877	41612	14221J	PARTICIPANT	\N	PRESENT	0
41878	41612	14018U	PARTICIPANT	\N	PRESENT	0
41879	41612	14207L	PARTICIPANT	\N	PRESENT	0
41880	41612	14089Y	PARTICIPANT	\N	PRESENT	0
41882	41612	14147R	PARTICIPANT	\N	PRESENT	0
41883	41612	11048N	PARTICIPANT	\N	PRESENT	0
41884	41612	07029T	PARTICIPANT	\N	PRESENT	0
41885	41612	11095V	PARTICIPANT	\N	PRESENT	0
41886	41612	14159V	PARTICIPANT	\N	PRESENT	0
41887	41612	14135M	PARTICIPANT	\N	PRESENT	0
41888	41612	14041T	PARTICIPANT	\N	PRESENT	0
41889	41612	11040E	PARTICIPANT	\N	PRESENT	0
41890	41612	11057P	PARTICIPANT	\N	PRESENT	0
41891	41612	11034G	PARTICIPANT	\N	PRESENT	0
41892	41612	04034C	PARTICIPANT	\N	PRESENT	0
41893	41612	14121F	PARTICIPANT	\N	PRESENT	0
41894	41612	14013P	PARTICIPANT	\N	PRESENT	0
41895	41612	11042G	PARTICIPANT	\N	PRESENT	0
41896	41612	04088S	PARTICIPANT	\N	PRESENT	0
41897	41612	14033T	PARTICIPANT	\N	PRESENT	0
41898	41612	04033B	PARTICIPANT	\N	PRESENT	0
41899	41612	95031C	PARTICIPANT	\N	PRESENT	0
41900	41612	01008M	PARTICIPANT	\N	PRESENT	0
41901	41612	14237S	PARTICIPANT	\N	PRESENT	0
41902	41612	11049P	PARTICIPANT	\N	PRESENT	0
41903	41612	14026U	PARTICIPANT	\N	PRESENT	0
41904	41612	14169X	PARTICIPANT	\N	PRESENT	0
41905	41612	14217N	PARTICIPANT	\N	PRESENT	0
41906	41612	14028W	PARTICIPANT	\N	PRESENT	0
41907	41612	14083S	PARTICIPANT	\N	PRESENT	0
41908	41612	14030Q	PARTICIPANT	\N	PRESENT	0
41909	41612	14231L	PARTICIPANT	\N	PRESENT	0
41910	41612	14267Y	PARTICIPANT	\N	PRESENT	0
41911	41612	98050T	PARTICIPANT	\N	PRESENT	0
41912	41612	08034U	PARTICIPANT	\N	PRESENT	0
41913	41612	11088W	PARTICIPANT	\N	PRESENT	0
41914	41612	14031R	PARTICIPANT	\N	PRESENT	0
41915	41612	11066Q	PARTICIPANT	\N	PRESENT	0
41916	41612	14225N	PARTICIPANT	\N	PRESENT	0
41917	41612	95063L	PARTICIPANT	\N	PRESENT	0
41918	41612	95037J	PARTICIPANT	\N	PRESENT	0
41919	41612	14197C	PARTICIPANT	\N	PRESENT	0
41920	41612	11100Y	PARTICIPANT	\N	PRESENT	0
41921	41612	14071N	PARTICIPANT	\N	PRESENT	0
41922	41612	11101A	PARTICIPANT	\N	PRESENT	0
41923	41612	08065C	PARTICIPANT	\N	PRESENT	0
41924	41612	01003G	PARTICIPANT	\N	PRESENT	0
41925	41612	08068F	PARTICIPANT	\N	PRESENT	0
41926	41612	01043Q	PARTICIPANT	\N	PRESENT	0
41927	41612	01016M	PARTICIPANT	\N	PRESENT	0
41928	41612	95035G	PARTICIPANT	\N	PRESENT	0
41929	41612	08010L	PARTICIPANT	\N	PRESENT	0
41930	41612	98018T	PARTICIPANT	\N	PRESENT	0
41931	41612	86044G	PARTICIPANT	\N	PRESENT	0
41932	41612	89017R	PARTICIPANT	\N	PRESENT	0
41933	41612	98022P	PARTICIPANT	\N	PRESENT	0
41934	41612	04045F	PARTICIPANT	\N	PRESENT	0
41935	41612	14051J	PARTICIPANT	\N	PRESENT	0
41936	41612	04049K	PARTICIPANT	\N	PRESENT	0
41937	41612	08015R	PARTICIPANT	\N	PRESENT	0
41938	41612	97011G	PARTICIPANT	\N	PRESENT	0
41939	41612	14061L	PARTICIPANT	\N	PRESENT	0
41940	41612	14069U	PARTICIPANT	\N	PRESENT	0
41941	41612	14235Q	PARTICIPANT	\N	PRESENT	0
41942	41612	12042Y	PARTICIPANT	\N	PRESENT	0
41943	41612	04094Q	PARTICIPANT	\N	PRESENT	0
41944	41612	14179A	PARTICIPANT	\N	PRESENT	0
41945	41612	14209N	PARTICIPANT	\N	PRESENT	0
41946	41612	11105E	PARTICIPANT	\N	PRESENT	0
41947	41612	14073Q	PARTICIPANT	\N	PRESENT	0
41948	41612	14059S	PARTICIPANT	\N	PRESENT	0
41949	41612	08062Y	PARTICIPANT	\N	PRESENT	0
42008	41612	14215L	PARTICIPANT	\N	PRESENT	0
42009	41612	14239U	PARTICIPANT	\N	PRESENT	0
42010	41612	04092N	PARTICIPANT	\N	PRESENT	0
42011	41612	87003B	PARTICIPANT	\N	PRESENT	0
42012	41612	14123H	PARTICIPANT	\N	PRESENT	0
42013	41612	77002U	PARTICIPANT	\N	PRESENT	0
42014	41612	11061K	PARTICIPANT	\N	PRESENT	0
42015	41612	95030B	PARTICIPANT	\N	PRESENT	0
42016	41612	08041T	PARTICIPANT	\N	PRESENT	0
42017	41612	07032N	PARTICIPANT	\N	PRESENT	0
42018	41612	08052W	PARTICIPANT	\N	PRESENT	0
42019	41612	89029V	PARTICIPANT	\N	PRESENT	0
42020	41612	01056V	PARTICIPANT	\N	PRESENT	0
42021	41612	01027Q	PARTICIPANT	\N	PRESENT	0
42022	41612	11091R	PARTICIPANT	\N	PRESENT	0
42023	41848	08055A	PARTICIPANT	\N	PRESENT	0
42025	41848	80013X	PARTICIPANT	\N	PRESENT	0
42029	41848	09001P	PARTICIPANT	\N	PRESENT	0
42030	41848	08009T	PARTICIPANT	\N	PRESENT	0
42033	41848	01031L	PARTICIPANT	\N	PRESENT	0
42034	41848	08042U	PARTICIPANT	\N	PRESENT	0
60064	58247	07034Q	PARTICIPANT	\N	PRESENT	0
60065	58247	04045F	PARTICIPANT	\N	PRESENT	0
60066	58247	11093T	PARTICIPANT	\N	PRESENT	0
60067	58247	14231L	PARTICIPANT	\N	PRESENT	0
60068	58247	14259Y	PARTICIPANT	\N	PRESENT	0
60069	58247	14207L	PARTICIPANT	\N	PRESENT	0
60070	58247	11035H	PARTICIPANT	\N	PRESENT	0
60071	58247	14033T	PARTICIPANT	\N	PRESENT	0
60072	58247	86044G	PARTICIPANT	\N	PRESENT	0
60073	58247	14041T	PARTICIPANT	\N	PRESENT	0
60074	58248	08055A	PARTICIPANT	\N	PRESENT	0
60075	58248	80013X	PARTICIPANT	\N	PRESENT	0
60150	58248	11033F	PARTICIPANT	\N	PRESENT	0
60151	58248	08018U	PARTICIPANT	\N	PRESENT	0
60078	58248	95049N	PARTICIPANT	\N	PRESENT	0
60079	58248	14265W	PARTICIPANT	\N	PRESENT	0
60152	58248	11098Y	PARTICIPANT	\N	PRESENT	0
60081	58248	07026Q	PARTICIPANT	\N	PRESENT	0
60082	58248	14073Q	PARTICIPANT	\N	PRESENT	0
60153	58248	01028R	PARTICIPANT	\N	PRESENT	0
60084	58248	11036J	PARTICIPANT	\N	PRESENT	0
60085	58248	11091R	PARTICIPANT	\N	PRESENT	0
60154	58248	14053L	PARTICIPANT	\N	PRESENT	0
60155	58248	01003G	PARTICIPANT	\N	PRESENT	0
60088	58248	14103D	PARTICIPANT	\N	PRESENT	0
60089	58248	08010L	PARTICIPANT	\N	PRESENT	0
60090	58248	11061K	PARTICIPANT	\N	PRESENT	0
60091	58248	14121F	PARTICIPANT	\N	PRESENT	0
60156	58248	14097Y	PARTICIPANT	\N	PRESENT	0
60093	58248	14249W	PARTICIPANT	\N	PRESENT	0
60094	58248	14157T	PARTICIPANT	\N	PRESENT	0
60157	58248	14231L	PARTICIPANT	\N	PRESENT	0
60158	58248	14215L	PARTICIPANT	\N	PRESENT	0
60097	58248	11037K	PARTICIPANT	\N	PRESENT	0
60159	58248	14033T	PARTICIPANT	\N	PRESENT	0
60099	58248	04038G	PARTICIPANT	\N	PRESENT	0
60172	58248	04047H	PARTICIPANT	\N	PRESENT	0
60101	58248	14079W	PARTICIPANT	\N	PRESENT	0
60102	58248	05008E	PARTICIPANT	\N	PRESENT	0
60173	58248	14217N	PARTICIPANT	\N	PRESENT	0
60104	58248	14179A	PARTICIPANT	\N	PRESENT	0
60105	58248	01008M	PARTICIPANT	\N	PRESENT	0
60106	58248	08034U	PARTICIPANT	\N	PRESENT	0
60107	58248	11112D	PARTICIPANT	\N	PRESENT	0
60174	58248	07004J	PARTICIPANT	\N	PRESENT	0
60175	58248	05012A	PARTICIPANT	\N	PRESENT	0
60110	58248	08015R	PARTICIPANT	\N	PRESENT	0
60111	58248	14257W	PARTICIPANT	\N	PRESENT	0
60176	58248	04056J	PARTICIPANT	\N	PRESENT	0
60177	58248	14197C	PARTICIPANT	\N	PRESENT	0
60114	58248	01007L	PARTICIPANT	\N	PRESENT	0
60115	58248	14219Q	PARTICIPANT	\N	PRESENT	0
60178	58248	11063M	PARTICIPANT	\N	PRESENT	0
60179	58248	14135M	PARTICIPANT	\N	PRESENT	0
60118	58248	04085P	PARTICIPANT	\N	PRESENT	0
60119	58248	14267Y	PARTICIPANT	\N	PRESENT	0
60120	58248	14273W	PARTICIPANT	\N	PRESENT	0
60180	58248	95041E	PARTICIPANT	\N	PRESENT	0
60122	58248	08009T	PARTICIPANT	\N	PRESENT	0
60123	58248	14159V	PARTICIPANT	\N	PRESENT	0
60181	58248	04088S	PARTICIPANT	\N	PRESENT	0
60125	58248	14263U	PARTICIPANT	\N	PRESENT	0
60182	58248	14034U	PARTICIPANT	\N	PRESENT	0
60127	58248	01027Q	PARTICIPANT	\N	PRESENT	0
60128	58248	07034Q	PARTICIPANT	\N	PRESENT	0
60129	58248	04045F	PARTICIPANT	\N	PRESENT	0
60130	58248	11093T	PARTICIPANT	\N	PRESENT	0
60183	58248	11085T	PARTICIPANT	\N	PRESENT	0
60184	58254	11085T	PARTICIPANT	\N	PRESENT	0
60133	58248	14207L	PARTICIPANT	\N	PRESENT	0
60134	58248	11035H	PARTICIPANT	\N	PRESENT	0
60185	58254	08019V	PARTICIPANT	\N	PRESENT	0
60136	58248	86044G	PARTICIPANT	\N	PRESENT	0
60137	58248	14041T	PARTICIPANT	\N	PRESENT	0
60138	58248	08051V	PARTICIPANT	\N	PRESENT	0
60139	58248	14001X	PARTICIPANT	\N	PRESENT	0
60140	58248	04066L	PARTICIPANT	\N	PRESENT	0
60141	58248	11012A	PARTICIPANT	\N	PRESENT	0
60142	58248	08031R	PARTICIPANT	\N	PRESENT	0
60143	58248	14239U	PARTICIPANT	\N	PRESENT	0
60144	58248	11049P	PARTICIPANT	\N	PRESENT	0
60145	58248	14247U	PARTICIPANT	\N	PRESENT	0
60146	58248	97011G	PARTICIPANT	\N	PRESENT	0
60147	58248	99004R	PARTICIPANT	\N	PRESENT	0
60148	58248	10015M	PARTICIPANT	\N	PRESENT	0
60149	58248	01024M	PARTICIPANT	\N	PRESENT	0
60186	58254	14249W	PARTICIPANT	\N	PRESENT	0
60187	58254	11035H	PARTICIPANT	\N	PRESENT	0
60188	58254	04074L	PARTICIPANT	\N	PRESENT	0
60189	58254	01028R	PARTICIPANT	\N	PRESENT	0
60190	58254	14263U	PARTICIPANT	\N	PRESENT	0
60191	58254	01024M	PARTICIPANT	\N	PRESENT	0
60192	58254	04038G	PARTICIPANT	\N	PRESENT	0
60193	58254	11055M	PARTICIPANT	\N	PRESENT	0
60194	58254	14059S	PARTICIPANT	\N	PRESENT	0
60195	58254	95049N	PARTICIPANT	\N	PRESENT	0
60196	58254	08051V	PARTICIPANT	\N	PRESENT	0
60197	58254	14207L	PARTICIPANT	\N	PRESENT	0
60198	58254	04085P	PARTICIPANT	\N	PRESENT	0
60199	58254	14215L	PARTICIPANT	\N	PRESENT	0
60200	58254	11098Y	PARTICIPANT	\N	PRESENT	0
60201	58254	11049P	PARTICIPANT	\N	PRESENT	0
60202	58254	11012A	PARTICIPANT	\N	PRESENT	0
60203	58254	95041E	PARTICIPANT	\N	PRESENT	0
60204	58254	14079W	PARTICIPANT	\N	PRESENT	0
60205	58254	14265W	PARTICIPANT	\N	PRESENT	0
60206	58254	04088S	PARTICIPANT	\N	PRESENT	0
60207	58254	14209N	PARTICIPANT	\N	PRESENT	0
60216	58254	14219Q	PARTICIPANT	\N	PRESENT	0
60218	58254	14034U	PARTICIPANT	\N	PRESENT	0
60223	58254	92045V	PARTICIPANT	\N	PRESENT	0
60231	58254	14037X	PARTICIPANT	\N	PRESENT	0
60573	60572	96004D	PRESIDENT	0	PRESENT	0
60574	60572	04054G	PARTICIPANT	\N	PRESENT	0
60575	60572	11035H	PARTICIPANT	\N	PRESENT	0
60576	60572	95030B	PARTICIPANT	\N	PRESENT	0
60577	60572	11083R	PARTICIPANT	\N	PRESENT	0
60578	60572	10015M	PARTICIPANT	\N	PRESENT	0
60579	60572	98035U	PARTICIPANT	\N	PRESENT	0
60580	60572	04045F	PARTICIPANT	\N	PRESENT	0
60581	60572	04061F	PARTICIPANT	\N	PRESENT	0
60582	60572	04057K	PARTICIPANT	\N	PRESENT	0
60583	60572	04080J	PARTICIPANT	\N	PRESENT	0
60584	60572	04034C	PARTICIPANT	\N	PRESENT	0
60585	60572	11012A	PARTICIPANT	\N	PRESENT	0
61052	61051	96004D	PRESIDENT	0	PRESENT	0
61053	61051	11035H	PARTICIPANT	\N	PRESENT	0
61054	61051	11083R	PARTICIPANT	\N	PRESENT	0
61055	61051	04057K	PARTICIPANT	\N	PRESENT	0
61056	61051	08042U	PARTICIPANT	\N	PRESENT	0
61057	61051	04080J	PARTICIPANT	\N	PRESENT	0
61058	61051	95037J	PARTICIPANT	\N	PRESENT	0
61059	61051	14251Q	PARTICIPANT	\N	PRESENT	0
61060	61051	95041E	PARTICIPANT	\N	PRESENT	0
61061	61051	01014K	PARTICIPANT	\N	PRESENT	0
61081	61080	05008E	PRESIDENT	0	PRESENT	0
35694	35693	14263U	PARTICIPANT	\N	PRESENT	0
35695	35693	14133K	PARTICIPANT	\N	PRESENT	0
36828	36760	08058D	RAPPORTEUR_AVIS	\N	PRESENT	0
35697	35693	04059M	PARTICIPANT	\N	PRESENT	0
38143	38040	11077T	PARTICIPANT	\N	PRESENT	0
35699	35693	01044R	PARTICIPANT	\N	PRESENT	0
35700	35693	08043V	PARTICIPANT	\N	PRESENT	0
35701	35693	14089Y	PARTICIPANT	\N	PRESENT	0
35702	35693	14105F	PARTICIPANT	\N	PRESENT	0
35703	35693	11029K	PARTICIPANT	\N	PRESENT	0
35704	35693	95015C	PARTICIPANT	\N	PRESENT	0
35705	35693	92015P	PARTICIPANT	\N	PRESENT	0
35706	35693	08024S	PARTICIPANT	\N	PRESENT	0
38144	38040	08039A	PARTICIPANT	\N	PRESENT	0
38147	38040	04061F	PARTICIPANT	\N	PRESENT	0
35709	35693	14209N	PARTICIPANT	\N	PRESENT	0
35710	35693	14079W	PARTICIPANT	\N	PRESENT	0
35711	35693	11091R	PARTICIPANT	\N	PRESENT	0
35712	35693	87003B	PARTICIPANT	\N	PRESENT	0
38151	38040	14103D	PARTICIPANT	\N	PRESENT	0
35714	35693	14249W	PARTICIPANT	\N	EXCUSE	0
35715	35693	01041N	PARTICIPANT	\N	PRESENT	0
35716	35693	01025N	PARTICIPANT	\N	PRESENT	0
38152	38040	11042G	PARTICIPANT	\N	PRESENT	0
38157	38040	14038Y	PARTICIPANT	\N	PRESENT	0
35719	35693	08035V	PARTICIPANT	\N	PRESENT	0
35720	35693	11089X	PARTICIPANT	\N	PRESENT	0
38158	38041	11083R	PARTICIPANT	\N	PRESENT	0
35722	35693	14123H	PARTICIPANT	\N	PRESENT	0
38159	38041	04034C	PARTICIPANT	\N	PRESENT	0
38200	38041	11070L	PARTICIPANT	\N	PRESENT	0
35725	35693	14241N	PARTICIPANT	\N	PRESENT	0
35726	35693	14061L	PARTICIPANT	\N	PRESENT	0
35727	35693	14073Q	PARTICIPANT	\N	PRESENT	0
35728	35693	08031R	PARTICIPANT	\N	PRESENT	0
38161	38041	04086Q	PARTICIPANT	\N	PRESENT	0
35730	35693	08039A	PARTICIPANT	\N	PRESENT	0
35731	35693	08017T	PARTICIPANT	\N	PRESENT	0
35732	35693	14059S	PARTICIPANT	\N	PRESENT	0
35733	35693	08012N	PARTICIPANT	\N	PRESENT	0
35734	35693	14103D	PARTICIPANT	\N	PRESENT	0
35735	35693	11104D	PARTICIPANT	\N	PRESENT	0
38162	38041	01031L	PARTICIPANT	\N	PRESENT	0
35737	35693	04057K	PARTICIPANT	\N	PRESENT	0
38163	38041	08011M	PARTICIPANT	\N	PRESENT	0
35739	35693	14109K	PARTICIPANT	\N	PRESENT	0
35740	35693	04070G	PRESIDENT	0	PRESENT	0
35741	35693	92040Q	PARTICIPANT	\N	PRESENT	0
35742	35693	14191V	PARTICIPANT	\N	PRESENT	0
35743	35693	83047W	PARTICIPANT	\N	PRESENT	0
35744	35693	14235Q	PARTICIPANT	\N	PRESENT	0
38164	38041	98053W	PARTICIPANT	\N	PRESENT	0
38199	38041	08019V	PARTICIPANT	\N	PRESENT	0
35747	35693	14229S	PARTICIPANT	\N	PRESENT	0
35748	35693	11043H	PARTICIPANT	\N	PRESENT	0
38166	38041	11057P	PARTICIPANT	\N	PRESENT	0
38201	38041	11012A	PARTICIPANT	\N	PRESENT	0
38202	38041	11077T	PARTICIPANT	\N	PRESENT	0
38169	38041	11053K	PARTICIPANT	\N	PRESENT	0
38170	38041	07029T	PARTICIPANT	\N	PRESENT	0
38171	38041	14175V	PARTICIPANT	\N	PRESENT	0
38172	38041	14261S	PARTICIPANT	\N	PRESENT	0
38203	38041	99004R	PARTICIPANT	\N	PRESENT	0
38174	38041	01027Q	PARTICIPANT	\N	PRESENT	0
38175	38041	07026Q	PARTICIPANT	\N	PRESENT	0
38221	38041	92045V	PARTICIPANT	\N	PRESENT	0
38177	38041	11074Q	PARTICIPANT	\N	PRESENT	0
38229	38041	95041E	PARTICIPANT	\N	PRESENT	0
38179	38041	11088W	PARTICIPANT	\N	PRESENT	0
38222	38041	04071H	PARTICIPANT	\N	PRESENT	0
38181	38041	08034U	PARTICIPANT	\N	PRESENT	0
38182	38041	96004D	PARTICIPANT	\N	PRESENT	0
38223	38041	80013X	PARTICIPANT	\N	PRESENT	0
38224	38041	11048N	PARTICIPANT	\N	PRESENT	0
38225	38041	08039A	PARTICIPANT	\N	PRESENT	0
38226	38041	98046X	PARTICIPANT	\N	PRESENT	0
38227	38041	11098Y	PARTICIPANT	\N	PRESENT	0
38188	38041	14219Q	PARTICIPANT	\N	PRESENT	0
38228	38041	08069G	PARTICIPANT	\N	PRESENT	0
49206	49205	08025T	PARTICIPANT	\N	PRESENT	0
49207	49205	04085P	PARTICIPANT	\N	PRESENT	0
38192	38041	14103D	PARTICIPANT	\N	PRESENT	0
38193	38041	11042G	PARTICIPANT	\N	PRESENT	0
38194	38041	14038Y	PARTICIPANT	\N	PRESENT	0
38195	38041	14085U	PARTICIPANT	\N	PRESENT	0
38196	38041	14253S	PARTICIPANT	\N	PRESENT	0
38197	38041	08051V	PARTICIPANT	\N	PRESENT	0
38198	38041	11085T	PARTICIPANT	\N	PRESENT	0
49208	49205	05008E	PRESIDENT	0	PRESENT	0
49209	49205	11030C	PARTICIPANT	\N	PRESENT	0
49210	49205	11033F	PARTICIPANT	\N	PRESENT	0
49211	49205	14065Q	PARTICIPANT	\N	PRESENT	0
49212	49205	14069U	PARTICIPANT	\N	PRESENT	0
49213	49205	04047H	PARTICIPANT	\N	PRESENT	0
49214	49205	11032E	PARTICIPANT	\N	PRESENT	0
49215	49205	04038G	PARTICIPANT	\N	PRESENT	0
49216	49205	99002P	PARTICIPANT	\N	PRESENT	0
49217	49205	11056N	PARTICIPANT	\N	EXCUSE	0
49218	49205	14259Y	PARTICIPANT	\N	EXCUSE	0
49219	49205	11035H	PARTICIPANT	\N	PRESENT	0
49220	49205	14041T	PARTICIPANT	\N	PRESENT	0
49221	49205	11113E	PARTICIPANT	\N	PRESENT	0
49222	49205	01024M	PARTICIPANT	\N	PRESENT	0
49223	49205	14215L	PARTICIPANT	\N	EXCUSE	0
49224	49205	11034G	PARTICIPANT	\N	PRESENT	0
49225	49205	08018U	PARTICIPANT	\N	PRESENT	0
49226	49205	11010L	PARTICIPANT	\N	EXCUSE	0
49227	49205	01007L	PARTICIPANT	\N	EXCUSE	0
49228	49205	11049P	PARTICIPANT	\N	PRESENT	0
49229	49205	08044W	PARTICIPANT	\N	PRESENT	0
49230	49205	11084S	PARTICIPANT	\N	EXCUSE	0
49231	49205	11026G	PARTICIPANT	\N	PRESENT	0
49232	49205	04079R	PARTICIPANT	\N	PRESENT	0
49233	49205	14111D	PARTICIPANT	\N	EXCUSE	0
49234	49205	14001X	PARTICIPANT	\N	EXCUSE	0
49235	49205	14273W	PARTICIPANT	\N	PRESENT	0
49236	49205	01060R	PARTICIPANT	\N	EXCUSE	0
49237	49205	14147R	PARTICIPANT	\N	PRESENT	0
49238	49205	95049N	PARTICIPANT	\N	PRESENT	0
49239	49205	08051V	PARTICIPANT	\N	PRESENT	0
49240	49205	11072N	PARTICIPANT	\N	PRESENT	0
49241	49205	07034Q	PARTICIPANT	\N	PRESENT	0
49242	49205	04074L	PARTICIPANT	\N	PRESENT	0
49243	49205	10015M	PARTICIPANT	\N	PRESENT	0
49244	49205	95063L	PARTICIPANT	\N	PRESENT	0
49245	49205	01019Q	PARTICIPANT	\N	EXCUSE	0
49246	49205	01028R	PARTICIPANT	\N	PRESENT	0
49247	49205	98035U	PARTICIPANT	\N	PRESENT	0
49248	49205	04056J	PARTICIPANT	\N	PRESENT	0
49249	49205	14275Y	PARTICIPANT	\N	EXCUSE	0
49250	49205	04044E	PARTICIPANT	\N	PRESENT	0
49251	49205	11037K	PARTICIPANT	\N	PRESENT	0
49252	49205	92045V	PARTICIPANT	\N	PRESENT	0
49253	49205	95067Q	PARTICIPANT	\N	PRESENT	0
49254	49205	01047U	PARTICIPANT	\N	PRESENT	0
49255	47946	95035G	PARTICIPANT	\N	PRESENT	0
49256	47946	14255U	PARTICIPANT	\N	PRESENT	0
49257	47946	14267Y	PARTICIPANT	\N	PRESENT	0
49258	47946	14109K	PARTICIPANT	\N	PRESENT	0
49259	47946	08016S	PARTICIPANT	\N	PRESENT	0
49260	47946	14197C	PARTICIPANT	\N	PRESENT	0
49261	47946	11036J	PARTICIPANT	\N	PRESENT	0
49262	47946	08068F	PARTICIPANT	\N	PRESENT	0
49263	47946	11048N	PARTICIPANT	\N	PRESENT	0
49264	47946	14169X	PARTICIPANT	\N	PRESENT	0
49265	47946	01047U	PARTICIPANT	\N	PRESENT	0
49266	47946	07004J	PARTICIPANT	\N	PRESENT	0
49267	47946	14037X	PARTICIPANT	\N	PRESENT	0
49268	47946	86044G	PARTICIPANT	\N	PRESENT	0
49269	47946	11012A	PARTICIPANT	\N	PRESENT	0
49270	47946	11100Y	PARTICIPANT	\N	PRESENT	0
49271	47946	04061F	PARTICIPANT	\N	PRESENT	0
56855	56824	04041B	PARTICIPANT	\N	PRESENT	0
56856	56824	14241N	PARTICIPANT	\N	PRESENT	0
56857	56824	14061L	PARTICIPANT	\N	PRESENT	0
56858	56824	14073Q	PARTICIPANT	\N	PRESENT	0
56859	56824	08031R	PARTICIPANT	\N	PRESENT	0
56860	56824	12041X	PARTICIPANT	\N	PRESENT	0
56861	56824	08039A	PARTICIPANT	\N	PRESENT	0
56884	56225	04043D	PARTICIPANT	\N	PRESENT	0
56863	56824	14059S	PARTICIPANT	\N	PRESENT	0
56885	56225	04048J	PARTICIPANT	\N	PRESENT	0
56865	56824	14103D	PARTICIPANT	\N	PRESENT	0
56866	56824	11104D	PARTICIPANT	\N	PRESENT	0
56886	56225	11109J	PARTICIPANT	\N	PRESENT	0
56868	56824	04057K	PARTICIPANT	\N	PRESENT	0
56869	56824	11014C	PARTICIPANT	\N	PRESENT	0
56870	56824	14109K	PARTICIPANT	\N	PRESENT	0
56871	56824	04070G	PRESIDENT	0	PRESENT	0
56872	56824	92040Q	PARTICIPANT	\N	PRESENT	0
56887	56225	14225N	PARTICIPANT	\N	PRESENT	0
56888	56225	11095V	PARTICIPANT	\N	PRESENT	0
56875	56824	14235Q	PARTICIPANT	\N	PRESENT	0
56889	56225	07029T	PARTICIPANT	\N	PRESENT	0
56877	56824	04033B	PARTICIPANT	\N	PRESENT	0
56878	56824	14229S	PARTICIPANT	\N	PRESENT	0
56879	56824	11043H	PARTICIPANT	\N	PRESENT	0
56890	56225	14111D	PARTICIPANT	\N	PRESENT	0
56881	56824	11011M	PARTICIPANT	\N	PRESENT	0
56882	56225	14105F	PARTICIPANT	\N	PRESENT	0
56883	56225	14109K	PARTICIPANT	\N	PRESENT	0
56891	56225	14219Q	PARTICIPANT	\N	PRESENT	0
56892	56225	14179A	PARTICIPANT	\N	PRESENT	0
56893	56225	14083S	PARTICIPANT	\N	PRESENT	0
56894	56225	14211G	PARTICIPANT	\N	PRESENT	0
56895	56225	14089Y	PARTICIPANT	\N	PRESENT	0
56896	56225	11012A	PARTICIPANT	\N	PRESENT	0
56897	56225	11043H	PARTICIPANT	\N	PRESENT	0
56901	56225	14103D	PARTICIPANT	\N	PRESENT	0
56902	56225	14073Q	PARTICIPANT	\N	PRESENT	0
56903	56225	04066L	PARTICIPANT	\N	PRESENT	0
56904	56225	08022Q	PARTICIPANT	\N	PRESENT	0
56906	56225	11097X	PARTICIPANT	\N	PRESENT	0
56907	56905	14133K	PARTICIPANT	\N	PRESENT	0
56908	56905	14239U	PARTICIPANT	\N	PRESENT	0
56909	56905	14065Q	PARTICIPANT	\N	PRESENT	0
56910	56905	14089Y	PARTICIPANT	\N	PRESENT	0
56911	56905	14041T	PARTICIPANT	\N	PRESENT	0
56912	56905	14217N	PARTICIPANT	\N	EXCUSE	0
56913	56905	92020L	PARTICIPANT	\N	EXCUSE	0
56914	56905	14281W	PRESIDENT	0	PRESENT	0
56915	56905	08041T	PARTICIPANT	\N	PRESENT	0
56916	56905	07004J	PARTICIPANT	\N	EXCUSE	0
56917	56905	11049P	PARTICIPANT	\N	PRESENT	0
56918	56905	99004R	PARTICIPANT	\N	PRESENT	0
56922	56905	14193X	PARTICIPANT	\N	EXCUSE	0
56920	56905	04061F	PARTICIPANT	\N	PRESENT	0
56921	56905	11082Q	PARTICIPANT	\N	EXCUSE	0
56923	56905	11037K	PARTICIPANT	\N	EXCUSE	0
56924	56905	14269B	PARTICIPANT	\N	PRESENT	0
56925	56905	10015M	PARTICIPANT	\N	PRESENT	0
56926	56905	14247U	PARTICIPANT	\N	PRESENT	0
56927	56905	08053X	PARTICIPANT	\N	PRESENT	0
56928	56225	04095R	PARTICIPANT	\N	PRESENT	0
56929	56225	01022K	PARTICIPANT	\N	PRESENT	0
56930	56225	14026U	PARTICIPANT	\N	PRESENT	0
56931	56225	14221J	PARTICIPANT	\N	PRESENT	0
56932	56225	14213J	PARTICIPANT	\N	PRESENT	0
56933	56225	14133K	PARTICIPANT	\N	PRESENT	0
56935	56225	08019V	PARTICIPANT	\N	PRESENT	0
56940	56225	01058X	PARTICIPANT	\N	PRESENT	0
56937	56934	11101A	PARTICIPANT	\N	PRESENT	0
56938	56934	08038Y	PARTICIPANT	\N	PRESENT	0
56939	56934	05012A	PARTICIPANT	\N	PRESENT	0
56942	56225	07034Q	PARTICIPANT	\N	PRESENT	0
56944	56225	05012A	PARTICIPANT	\N	PRESENT	0
56946	56225	14065Q	PARTICIPANT	\N	PRESENT	0
56947	56225	01015L	PARTICIPANT	\N	PRESENT	0
56948	56225	14263U	PARTICIPANT	\N	PRESENT	0
56953	56225	01057W	PARTICIPANT	\N	PRESENT	0
56954	56225	14269B	PARTICIPANT	\N	PRESENT	0
56955	56225	11014C	PARTICIPANT	\N	PRESENT	0
56956	56225	01059Y	PARTICIPANT	\N	PRESENT	0
56957	56225	14187A	PARTICIPANT	\N	PRESENT	0
56958	56225	01028R	PARTICIPANT	\N	PRESENT	0
56959	56225	11093T	PARTICIPANT	\N	PRESENT	0
57011	56228	14239U	PARTICIPANT	\N	PRESENT	0
57012	56228	04092N	PARTICIPANT	\N	PRESENT	0
57013	56228	11031D	PARTICIPANT	\N	PRESENT	0
57014	56228	01011G	PARTICIPANT	\N	PRESENT	0
57015	56228	08052W	PARTICIPANT	\N	PRESENT	0
57016	56228	11089X	PARTICIPANT	\N	PRESENT	0
57017	56228	00003C	PARTICIPANT	\N	PRESENT	0
57018	56228	04053F	PARTICIPANT	\N	PRESENT	0
57019	56228	11067R	PARTICIPANT	\N	PRESENT	0
57020	56228	04045F	PARTICIPANT	\N	PRESENT	0
57021	56228	11029K	PARTICIPANT	\N	PRESENT	0
57022	56228	14221J	PARTICIPANT	\N	PRESENT	0
57023	56228	14241N	PARTICIPANT	\N	PRESENT	0
57024	56228	14073Q	PARTICIPANT	\N	PRESENT	0
57025	56228	11093T	PARTICIPANT	\N	PRESENT	0
57026	56228	14231L	PARTICIPANT	\N	PRESENT	0
57027	56228	14179A	PARTICIPANT	\N	PRESENT	0
57028	56228	11061K	PARTICIPANT	\N	PRESENT	0
57029	56228	14269B	PARTICIPANT	\N	PRESENT	0
57030	56228	14219Q	PARTICIPANT	\N	PRESENT	0
57031	56228	14105F	PARTICIPANT	\N	PRESENT	0
57032	56228	08019V	PARTICIPANT	\N	PRESENT	0
57033	56228	14119M	PARTICIPANT	\N	PRESENT	0
57034	56228	14079W	PARTICIPANT	\N	PRESENT	0
57035	56228	14193X	PARTICIPANT	\N	PRESENT	0
57036	56228	14217N	PARTICIPANT	\N	PRESENT	0
57037	56228	14031R	PARTICIPANT	\N	PRESENT	0
57038	56228	07034Q	PARTICIPANT	\N	PRESENT	0
57039	56228	14071N	PARTICIPANT	\N	PRESENT	0
57040	56228	10006L	PARTICIPANT	\N	PRESENT	0
57041	56228	04033B	PARTICIPANT	\N	PRESENT	0
57042	56228	10015M	PARTICIPANT	\N	PRESENT	0
57043	56228	01059Y	PARTICIPANT	\N	PRESENT	0
57044	56228	11036J	PARTICIPANT	\N	PRESENT	0
57045	56228	14235Q	PARTICIPANT	\N	PRESENT	0
57046	56228	14083S	PARTICIPANT	\N	PRESENT	0
57047	56228	14271U	PARTICIPANT	\N	PRESENT	0
57048	56228	14187A	PARTICIPANT	\N	PRESENT	0
57049	56228	14195A	PARTICIPANT	\N	PRESENT	0
57050	56228	01056V	PARTICIPANT	\N	PRESENT	0
57051	56228	11043H	PARTICIPANT	\N	PRESENT	0
57052	56228	95062K	PARTICIPANT	\N	PRESENT	0
57053	56228	14033T	PARTICIPANT	\N	PRESENT	0
57054	56228	08031R	PARTICIPANT	\N	PRESENT	0
57055	56228	02002K	PARTICIPANT	\N	PRESENT	0
57056	56228	14265W	PARTICIPANT	\N	PRESENT	0
57009	56228	04066L	PARTICIPANT	\N	PRESENT	0
57010	56228	98024R	PARTICIPANT	\N	PRESENT	0
57057	56228	14213J	PARTICIPANT	\N	PRESENT	0
57058	56228	08015R	PARTICIPANT	\N	PRESENT	0
57059	56228	92045V	PARTICIPANT	\N	PRESENT	0
57060	56228	11039M	PARTICIPANT	\N	PRESENT	0
57061	56228	14257W	PARTICIPANT	\N	PRESENT	0
57062	56228	14281W	PARTICIPANT	\N	PRESENT	0
57063	56228	08034U	PARTICIPANT	\N	PRESENT	0
57064	56228	14030Q	PARTICIPANT	\N	PRESENT	0
57066	56228	14215L	PARTICIPANT	\N	PRESENT	0
57067	56228	08010L	PARTICIPANT	\N	PRESENT	0
57068	56228	14207L	PARTICIPANT	\N	PRESENT	0
57069	56228	14038Y	PARTICIPANT	\N	PRESENT	0
57070	56228	14037X	PARTICIPANT	\N	PRESENT	0
57071	57065	05008E	PRESIDENT	0	PRESENT	0
57072	57065	14215L	PARTICIPANT	\N	PRESENT	0
57073	57065	14273W	PARTICIPANT	\N	EXCUSE	0
57074	57065	07034Q	PARTICIPANT	\N	PRESENT	0
57075	57065	10015M	PARTICIPANT	\N	PRESENT	0
57076	57065	95063L	PARTICIPANT	\N	PRESENT	0
57077	57065	01028R	PARTICIPANT	\N	PRESENT	0
57078	57065	04044E	PARTICIPANT	\N	PRESENT	0
57079	57065	11037K	PARTICIPANT	\N	PRESENT	0
57080	57065	92045V	PARTICIPANT	\N	PRESENT	0
57081	57065	95067Q	PARTICIPANT	\N	PRESENT	0
57082	57065	14065Q	PARTICIPANT	\N	PRESENT	0
57083	57065	14001X	PARTICIPANT	\N	PRESENT	0
57084	56228	11037K	PARTICIPANT	\N	PRESENT	0
57085	56228	11034G	PARTICIPANT	\N	PRESENT	0
57086	56228	04044E	PARTICIPANT	\N	PRESENT	0
57087	56228	01007L	PARTICIPANT	\N	PRESENT	0
57088	56960	04066L	PARTICIPANT	\N	PRESENT	0
57092	56960	11031D	PARTICIPANT	\N	PRESENT	0
37217	37215	08055A	PARTICIPANT	\N	PRESENT	0
37218	37215	14093U	PARTICIPANT	\N	PRESENT	0
37221	37215	01015L	PARTICIPANT	\N	PRESENT	0
37222	37215	11107G	PARTICIPANT	\N	PRESENT	0
37223	37215	01022K	PARTICIPANT	\N	EXCUSE	0
37224	37215	08009T	PRESIDENT	0	PRESENT	0
37228	37215	08062Y	PARTICIPANT	\N	EXCUSE	0
37229	37215	08042U	PARTICIPANT	\N	PRESENT	0
37230	37215	14237S	PARTICIPANT	\N	PRESENT	0
37231	37215	05012A	PARTICIPANT	\N	PRESENT	0
37232	37215	95062K	PARTICIPANT	\N	PRESENT	0
37233	37215	14051J	PARTICIPANT	\N	PRESENT	0
37234	37215	14157T	PARTICIPANT	\N	PRESENT	0
37235	37215	96003C	PARTICIPANT	\N	EXCUSE	0
37583	37582	96004D	PARTICIPANT	\N	PRESENT	0
37584	37582	11040E	PARTICIPANT	\N	PRESENT	0
37585	37582	14073Q	PARTICIPANT	\N	PRESENT	0
37586	37582	98035U	PARTICIPANT	\N	PRESENT	0
37595	33344	11066Q	PARTICIPANT	\N	PRESENT	0
37596	33344	95067Q	PARTICIPANT	\N	PRESENT	0
38153	37248	11068S	PARTICIPANT	\N	EXCUSE	0
38154	37248	08039A	PARTICIPANT	\N	EXCUSE	0
38155	32377	08039A	PARTICIPANT	\N	EXCUSE	0
38156	32377	11068S	PARTICIPANT	\N	EXCUSE	0
42135	41848	01034P	PARTICIPANT	\N	PRESENT	0
42123	41848	14209N	PARTICIPANT	\N	PRESENT	0
42039	41848	11107G	PARTICIPANT	\N	PRESENT	0
42119	41848	11055M	PARTICIPANT	\N	PRESENT	0
42122	41848	14071N	PARTICIPANT	\N	PRESENT	0
42125	41848	11090Q	PARTICIPANT	\N	PRESENT	0
42118	41848	11057P	PARTICIPANT	\N	PRESENT	0
42137	41848	11100Y	PARTICIPANT	\N	PRESENT	0
42121	41848	11074Q	PARTICIPANT	\N	PRESENT	0
42124	41848	01043Q	PARTICIPANT	\N	PRESENT	0
42047	41848	95062K	PARTICIPANT	\N	PRESENT	0
42120	41848	14042U	PARTICIPANT	\N	PRESENT	0
42126	41848	08041T	PARTICIPANT	\N	PRESENT	0
42050	41848	14018U	PARTICIPANT	\N	PRESENT	0
42051	41848	14207L	PARTICIPANT	\N	PRESENT	0
42127	41848	14213J	PARTICIPANT	\N	PRESENT	0
42128	41848	11044J	PARTICIPANT	\N	PRESENT	0
42054	41848	14159V	PARTICIPANT	\N	PRESENT	0
42129	41848	08034U	PARTICIPANT	\N	PRESENT	0
42187	41870	01031L	PARTICIPANT	\N	PRESENT	0
42131	41848	11067R	PARTICIPANT	\N	PRESENT	0
42132	41848	04053F	PARTICIPANT	\N	PRESENT	0
42133	41848	11063M	PARTICIPANT	\N	PRESENT	0
42060	41848	14013P	PARTICIPANT	\N	PRESENT	0
42061	41848	11042G	PARTICIPANT	\N	PRESENT	0
42134	41848	01059Y	PARTICIPANT	\N	PRESENT	0
42136	41848	14269B	PARTICIPANT	\N	PRESENT	0
42138	41848	01014K	PARTICIPANT	\N	PRESENT	0
42139	41848	14147R	PARTICIPANT	\N	PRESENT	0
42140	41848	14187A	PARTICIPANT	\N	PRESENT	0
42141	41848	14219Q	PARTICIPANT	\N	PRESENT	0
42142	41848	14083S	PARTICIPANT	\N	PRESENT	0
42143	41848	14031R	PARTICIPANT	\N	PRESENT	0
42070	41848	11088W	PARTICIPANT	\N	PRESENT	0
42144	41848	11031D	PARTICIPANT	\N	PRESENT	0
42072	41848	11066Q	PARTICIPANT	\N	PRESENT	0
42145	41848	14073Q	PARTICIPANT	\N	PRESENT	0
42146	41848	14105F	PARTICIPANT	\N	PRESENT	0
42147	41848	00003C	PARTICIPANT	\N	PRESENT	0
42076	41848	14197C	PARTICIPANT	\N	PRESENT	0
42148	41848	14237S	PARTICIPANT	\N	PRESENT	0
42149	41848	11093T	PARTICIPANT	\N	PRESENT	0
42079	41848	08065C	PARTICIPANT	\N	PRESENT	0
42150	41848	99004R	PARTICIPANT	\N	PRESENT	0
42151	41848	01007L	PARTICIPANT	\N	PRESENT	0
42082	41848	01016M	PARTICIPANT	\N	PRESENT	0
42083	41848	95035G	PARTICIPANT	\N	PRESENT	0
42152	41848	11036J	PARTICIPANT	\N	PRESENT	0
42188	41870	95062K	PARTICIPANT	\N	PRESENT	0
42154	41848	14259Y	PARTICIPANT	\N	PRESENT	0
42087	41848	98022P	PARTICIPANT	\N	PRESENT	0
42088	41848	04045F	PARTICIPANT	\N	PRESENT	0
42089	41848	14051J	PARTICIPANT	\N	PRESENT	0
42090	41848	04049K	PARTICIPANT	\N	PRESENT	0
42091	41848	08015R	PARTICIPANT	\N	PRESENT	0
42092	41848	97011G	PARTICIPANT	\N	PRESENT	0
42093	41848	14061L	PARTICIPANT	\N	PRESENT	0
42155	41848	11112D	PARTICIPANT	\N	PRESENT	0
42156	41848	01057W	PARTICIPANT	\N	PRESENT	0
42189	41870	11057P	PARTICIPANT	\N	PRESENT	0
42158	41848	01019Q	PARTICIPANT	\N	PRESENT	0
42159	41848	14173T	PARTICIPANT	\N	PRESENT	0
42160	41848	11077T	PARTICIPANT	\N	PRESENT	0
42161	41848	08010L	PARTICIPANT	\N	PRESENT	0
42101	41848	14059S	PARTICIPANT	\N	PRESENT	0
42102	41848	08062Y	PARTICIPANT	\N	PRESENT	0
42103	41848	14215L	PARTICIPANT	\N	PRESENT	0
42104	41848	14239U	PARTICIPANT	\N	PRESENT	0
42105	41848	04092N	PARTICIPANT	\N	PRESENT	0
42106	41848	87003B	PARTICIPANT	\N	PRESENT	0
42162	41848	11094U	PARTICIPANT	\N	PRESENT	0
42163	41848	11101A	PARTICIPANT	\N	PRESENT	0
42109	41848	11061K	PARTICIPANT	\N	PRESENT	0
42110	41848	95030B	PARTICIPANT	\N	PRESENT	0
42164	41848	04086Q	PARTICIPANT	\N	PRESENT	0
42112	41848	07032N	PARTICIPANT	\N	PRESENT	0
42113	41848	08052W	PARTICIPANT	\N	PRESENT	0
42166	41848	95067Q	PARTICIPANT	\N	PRESENT	0
42116	41848	01027Q	PARTICIPANT	\N	PRESENT	0
42167	41848	04071H	PARTICIPANT	\N	PRESENT	0
42168	41848	14231L	PARTICIPANT	\N	PRESENT	0
42169	41848	04043D	PARTICIPANT	\N	PRESENT	0
42170	41848	14033T	PARTICIPANT	\N	PRESENT	0
42171	41848	11097X	PARTICIPANT	\N	PRESENT	0
42172	41848	14211G	PARTICIPANT	\N	PRESENT	0
42173	41848	14217N	PARTICIPANT	\N	PRESENT	0
42175	41848	04035D	PARTICIPANT	\N	PRESENT	0
42176	41848	11080N	PARTICIPANT	\N	PRESENT	0
42177	41848	11104D	PARTICIPANT	\N	PRESENT	0
42178	41848	11012A	PARTICIPANT	\N	PRESENT	0
42179	41848	14069U	PARTICIPANT	\N	PRESENT	0
42180	41848	11082Q	PARTICIPANT	\N	PRESENT	0
42181	41848	14034U	PARTICIPANT	\N	PRESENT	0
42182	41848	90003B	PARTICIPANT	\N	PRESENT	0
42183	41848	08022Q	PARTICIPANT	\N	PRESENT	0
42184	41848	95015C	PARTICIPANT	\N	PRESENT	0
42185	41848	11098Y	PARTICIPANT	\N	PRESENT	0
42186	41848	14119M	PARTICIPANT	\N	PRESENT	0
42190	41870	14013P	PARTICIPANT	\N	PRESENT	0
42193	41870	11101A	PARTICIPANT	\N	PRESENT	0
42194	41870	01043Q	PARTICIPANT	\N	PRESENT	0
42196	41870	08015R	PARTICIPANT	\N	PRESENT	0
42197	41870	97011G	PARTICIPANT	\N	PRESENT	0
42199	41870	14215L	PARTICIPANT	\N	PRESENT	0
42202	41870	11061K	PARTICIPANT	\N	PRESENT	0
42203	41870	95030B	PARTICIPANT	\N	PRESENT	0
42208	41870	11090Q	PARTICIPANT	\N	PRESENT	0
42210	41870	11044J	PARTICIPANT	\N	PRESENT	0
42212	41870	11067R	PARTICIPANT	\N	PRESENT	0
42213	41870	04053F	PARTICIPANT	\N	PRESENT	0
42214	41870	11063M	PARTICIPANT	\N	PRESENT	0
42215	41870	01059Y	PARTICIPANT	\N	PRESENT	0
42216	41870	01034P	PARTICIPANT	\N	PRESENT	0
42217	41870	14269B	PARTICIPANT	\N	PRESENT	0
42219	41870	14147R	PARTICIPANT	\N	PRESENT	0
42220	41870	14187A	PARTICIPANT	\N	PRESENT	0
42221	41870	14105F	PARTICIPANT	\N	PRESENT	0
42222	41870	00003C	PARTICIPANT	\N	PRESENT	0
42224	41870	01007L	PARTICIPANT	\N	PRESENT	0
42225	41870	11036J	PARTICIPANT	\N	PRESENT	0
42226	41870	14259Y	PARTICIPANT	\N	PRESENT	0
42227	41870	11112D	PARTICIPANT	\N	PRESENT	0
42228	41870	01057W	PARTICIPANT	\N	PRESENT	0
42230	41870	11077T	PARTICIPANT	\N	PRESENT	0
42231	41870	08010L	PARTICIPANT	\N	PRESENT	0
42232	41870	11094U	PARTICIPANT	\N	PRESENT	0
42233	41870	04086Q	PARTICIPANT	\N	PRESENT	0
61072	60620	89029V	PARTICIPANT	\N	PRESENT	0
61073	60620	01025N	PARTICIPANT	\N	PRESENT	0
61074	60620	86044G	PARTICIPANT	\N	PRESENT	0
61075	60620	08065C	PARTICIPANT	\N	PRESENT	0
61076	60620	80013X	PARTICIPANT	\N	PRESENT	0
61077	60620	14079W	PARTICIPANT	\N	PRESENT	0
61078	60620	08051V	PARTICIPANT	\N	PRESENT	0
61079	60620	14217N	PARTICIPANT	\N	PRESENT	0
61082	61080	14069U	PARTICIPANT	\N	PRESENT	0
61083	61080	14041T	PARTICIPANT	\N	PRESENT	0
61084	61080	14215L	PARTICIPANT	\N	PRESENT	0
61085	61080	08018U	PARTICIPANT	\N	PRESENT	0
61086	61080	11049P	PARTICIPANT	\N	PRESENT	0
61087	61080	11026G	PARTICIPANT	\N	PRESENT	0
61088	61080	14273W	PARTICIPANT	\N	PRESENT	0
61089	61080	95049N	PARTICIPANT	\N	PRESENT	0
61090	61080	11072N	PARTICIPANT	\N	PRESENT	0
61091	61080	04074L	PARTICIPANT	\N	PRESENT	0
61092	60620	14213J	PARTICIPANT	\N	PRESENT	0
61093	60620	11049P	PARTICIPANT	\N	PRESENT	0
61094	61080	95063L	PARTICIPANT	\N	PRESENT	0
61095	61080	01028R	PARTICIPANT	\N	PRESENT	0
61096	61080	04056J	PARTICIPANT	\N	PRESENT	0
61097	60620	14219Q	PARTICIPANT	\N	PRESENT	0
61098	61080	04044E	PARTICIPANT	\N	EXCUSE	0
61099	60620	08043V	PARTICIPANT	\N	PRESENT	0
61100	60620	11034G	PARTICIPANT	\N	PRESENT	0
61101	60620	14109K	PARTICIPANT	\N	PRESENT	0
61110	60620	14053L	PARTICIPANT	\N	PRESENT	0
61111	60620	01041N	PARTICIPANT	\N	PRESENT	0
61112	60620	11107G	PARTICIPANT	\N	PRESENT	0
61113	60620	14273W	PARTICIPANT	\N	PRESENT	0
61114	60620	14229S	PARTICIPANT	\N	PRESENT	0
61115	60620	08014Q	PARTICIPANT	\N	PRESENT	0
61116	60620	98053W	PARTICIPANT	\N	PRESENT	0
61117	60620	14199E	PARTICIPANT	\N	PRESENT	0
61118	60620	98046X	PARTICIPANT	\N	PRESENT	0
61119	60620	14259Y	PARTICIPANT	\N	PRESENT	0
61120	60620	11100Y	PARTICIPANT	\N	PRESENT	0
61121	60620	14267Y	PARTICIPANT	\N	PRESENT	0
61352	60621	04044E	PARTICIPANT	\N	PRESENT	0
61353	60621	08047A	PARTICIPANT	\N	PRESENT	0
61351	60621	98023Q	PARTICIPANT	\N	PRESENT	0
61354	60621	01003G	PARTICIPANT	\N	PRESENT	0
61355	60621	08053X	PARTICIPANT	\N	PRESENT	0
61356	60621	14097Y	PARTICIPANT	\N	PRESENT	0
61357	60621	97011G	PARTICIPANT	\N	PRESENT	0
61358	60621	04054G	PARTICIPANT	\N	PRESENT	0
61359	60621	92018S	PARTICIPANT	\N	PRESENT	0
61360	60621	11040E	PARTICIPANT	\N	PRESENT	0
61361	60621	14001X	PARTICIPANT	\N	PRESENT	0
61362	60621	05008E	PARTICIPANT	\N	PRESENT	0
61363	60621	04059M	PARTICIPANT	\N	PRESENT	0
61364	60621	14079W	PARTICIPANT	\N	PRESENT	0
61365	60621	14157T	PARTICIPANT	\N	PRESENT	0
61366	60621	11090Q	PARTICIPANT	\N	PRESENT	0
61367	60621	08042U	PARTICIPANT	\N	PRESENT	0
61368	60621	14259Y	PARTICIPANT	\N	PRESENT	0
61369	60621	11056N	PARTICIPANT	\N	PRESENT	0
61370	60621	11093T	PARTICIPANT	\N	PRESENT	0
61371	60621	11111C	PARTICIPANT	\N	PRESENT	0
61372	60621	11082Q	PARTICIPANT	\N	PRESENT	0
61373	60621	14205J	PARTICIPANT	\N	PRESENT	0
61374	60621	11032E	PARTICIPANT	\N	PRESENT	0
61375	60621	08051V	PARTICIPANT	\N	PRESENT	0
61376	60621	14123H	PARTICIPANT	\N	PRESENT	0
61377	60621	04071H	PARTICIPANT	\N	PRESENT	0
61378	60621	08061X	PARTICIPANT	\N	PRESENT	0
61380	61379	14209N	PARTICIPANT	\N	PRESENT	0
61381	60621	11104D	PARTICIPANT	\N	PRESENT	0
61382	61379	14014Q	PARTICIPANT	\N	PRESENT	0
61383	61379	04036E	PARTICIPANT	\N	PRESENT	0
61384	61379	14001X	PARTICIPANT	\N	PRESENT	0
61385	61379	08053X	PARTICIPANT	\N	PRESENT	0
61386	61379	11014C	PARTICIPANT	\N	PRESENT	0
61387	60621	14034U	PARTICIPANT	\N	PRESENT	0
61388	60621	92039X	PARTICIPANT	\N	PRESENT	0
61389	60621	83047W	PARTICIPANT	\N	PRESENT	0
61390	60621	11064N	PARTICIPANT	\N	PRESENT	0
61391	60621	14257W	PARTICIPANT	\N	PRESENT	0
61392	60621	01013J	PARTICIPANT	\N	PRESENT	0
61393	60621	14219Q	PARTICIPANT	\N	PRESENT	0
61394	60621	14083S	PARTICIPANT	\N	PRESENT	0
61395	60621	14199E	PARTICIPANT	\N	PRESENT	0
61396	60621	14037X	PARTICIPANT	\N	PRESENT	0
61397	60621	04089T	PARTICIPANT	\N	PRESENT	0
61398	60621	11094U	PARTICIPANT	\N	PRESENT	0
61399	60621	01041N	PARTICIPANT	\N	PRESENT	0
61400	60621	04067M	PARTICIPANT	\N	PRESENT	0
61401	60621	08062Y	PARTICIPANT	\N	PRESENT	0
61402	60621	04070G	PARTICIPANT	\N	PRESENT	0
61403	60621	14251Q	PARTICIPANT	\N	PRESENT	0
61404	60621	14329V	PARTICIPANT	\N	PRESENT	0
61405	60621	04034C	PARTICIPANT	\N	PRESENT	0
61406	60621	11100Y	PARTICIPANT	\N	PRESENT	0
61407	60621	95041E	PARTICIPANT	\N	PRESENT	0
61408	60621	98046X	PARTICIPANT	\N	PRESENT	0
61409	60621	09001P	PARTICIPANT	\N	PRESENT	0
61410	60621	11012A	PARTICIPANT	\N	PRESENT	0
61411	60621	11099A	PARTICIPANT	\N	PRESENT	0
61412	60621	08018U	PARTICIPANT	\N	PRESENT	0
61413	60621	02002K	PARTICIPANT	\N	PRESENT	0
61414	60621	11059R	PARTICIPANT	\N	PRESENT	0
61415	60621	01061S	PARTICIPANT	\N	PRESENT	0
61416	60621	77002U	PARTICIPANT	\N	PRESENT	0
61417	60621	08014Q	PARTICIPANT	\N	PRESENT	0
61418	60621	14042U	PARTICIPANT	\N	PRESENT	0
61422	60621	01056V	PARTICIPANT	\N	PRESENT	0
61423	60621	07029T	PARTICIPANT	\N	PRESENT	0
61424	60621	11030C	PARTICIPANT	\N	PRESENT	0
61425	60621	11027H	PARTICIPANT	\N	PRESENT	0
61426	60621	01011G	PARTICIPANT	\N	PRESENT	0
61427	60621	14053L	PARTICIPANT	\N	PRESENT	0
61428	60621	14273W	PARTICIPANT	\N	PRESENT	0
61429	60621	04041B	PARTICIPANT	\N	PRESENT	0
61430	60621	14039A	PARTICIPANT	\N	PRESENT	0
61431	60621	04066L	PARTICIPANT	\N	PRESENT	0
61432	60621	80013X	PARTICIPANT	\N	PRESENT	0
61433	60621	01016M	PARTICIPANT	\N	PRESENT	0
61434	60621	08012N	PARTICIPANT	\N	PRESENT	0
61435	60621	08019V	PARTICIPANT	\N	PRESENT	0
61436	60621	11043H	PARTICIPANT	\N	PRESENT	0
61437	60621	14089Y	PARTICIPANT	\N	PRESENT	0
61438	60621	98024R	PARTICIPANT	\N	PRESENT	0
61439	60621	14093U	PARTICIPANT	\N	PRESENT	0
61440	60621	01024M	PARTICIPANT	\N	PRESENT	0
61441	60621	98021N	PARTICIPANT	\N	PRESENT	0
61442	60621	88008L	PARTICIPANT	\N	PRESENT	0
61443	60621	08025T	PARTICIPANT	\N	PRESENT	0
61685	61419	89029V	PARTICIPANT	\N	PRESENT	0
61686	61419	08039A	PARTICIPANT	\N	PRESENT	0
61687	61419	01025N	PARTICIPANT	\N	PRESENT	0
61688	61419	04070G	PARTICIPANT	\N	PRESENT	0
61689	61419	04059M	PARTICIPANT	\N	PRESENT	0
61690	61419	01044R	PARTICIPANT	\N	PRESENT	0
61691	61419	14247U	PARTICIPANT	\N	PRESENT	0
61692	61419	08031R	PARTICIPANT	\N	PRESENT	0
61693	61419	12041X	PARTICIPANT	\N	PRESENT	0
61694	61419	14235Q	PARTICIPANT	\N	PRESENT	0
61695	61419	07026Q	PARTICIPANT	\N	PRESENT	0
61696	61419	80013X	PARTICIPANT	\N	PRESENT	0
61697	61419	14121F	PARTICIPANT	\N	PRESENT	0
61698	61419	13002U	PARTICIPANT	\N	PRESENT	0
61699	61419	11014C	PARTICIPANT	\N	PRESENT	0
61700	61419	11061K	PARTICIPANT	\N	PRESENT	0
61701	61419	08043V	PARTICIPANT	\N	PRESENT	0
61702	61419	14271U	PARTICIPANT	\N	PRESENT	0
61703	61419	14159V	PARTICIPANT	\N	PRESENT	0
61704	61419	14081Q	PARTICIPANT	\N	PRESENT	0
61705	61419	11104D	PARTICIPANT	\N	PRESENT	0
61706	61419	08017T	PARTICIPANT	\N	PRESENT	0
61707	61419	04056J	PARTICIPANT	\N	PRESENT	0
61708	61419	14109K	PARTICIPANT	\N	PRESENT	0
61709	61419	14229S	PARTICIPANT	\N	PRESENT	0
61710	61419	14241N	PARTICIPANT	\N	PRESENT	0
61711	61419	11029K	PARTICIPANT	\N	PRESENT	0
61712	61419	14205J	PARTICIPANT	\N	PRESENT	0
61713	61419	14083S	PARTICIPANT	\N	PRESENT	0
61714	61419	14219Q	PARTICIPANT	\N	PRESENT	0
61715	61419	14221J	PARTICIPANT	\N	PRESENT	0
61716	61419	14089Y	PARTICIPANT	\N	PRESENT	0
61717	61419	07004J	PARTICIPANT	\N	PRESENT	0
61718	61419	08044W	PARTICIPANT	\N	PRESENT	0
61719	61419	01024M	PARTICIPANT	\N	PRESENT	0
61720	61419	04057K	PARTICIPANT	\N	PRESENT	0
61721	61419	14061L	PARTICIPANT	\N	PRESENT	0
61722	61419	14059S	PARTICIPANT	\N	PRESENT	0
61723	61419	14187A	PARTICIPANT	\N	PRESENT	0
61724	61419	14223L	PARTICIPANT	\N	PRESENT	0
36032	31452	96004D	PARTICIPANT	\N	EXCUSE	0
45821	45819	14263U	PARTICIPANT	\N	PRESENT	0
45822	45819	14133K	PARTICIPANT	\N	PRESENT	0
49324	47944	14225N	PARTICIPANT	\N	PRESENT	0
45824	45819	04059M	PARTICIPANT	\N	PRESENT	0
45825	45819	11039M	PARTICIPANT	\N	PRESENT	0
45826	45819	01044R	PARTICIPANT	\N	PRESENT	0
45827	45819	08043V	PARTICIPANT	\N	PRESENT	0
45828	45819	14089Y	PARTICIPANT	\N	PRESENT	0
45829	45819	14105F	PARTICIPANT	\N	PRESENT	0
45830	45819	11029K	PARTICIPANT	\N	PRESENT	0
45831	45819	95015C	PRESIDENT	0	PRESENT	0
45832	45819	92015P	PARTICIPANT	\N	PRESENT	0
45833	45819	08024S	PARTICIPANT	\N	PRESENT	0
45834	45819	14201E	PARTICIPANT	\N	PRESENT	0
49325	47944	04034C	PARTICIPANT	\N	PRESENT	0
45836	45819	14209N	PARTICIPANT	\N	PRESENT	0
45837	45819	14079W	PARTICIPANT	\N	PRESENT	0
45838	45819	11091R	PARTICIPANT	\N	EXCUSE	0
45839	45819	87003B	PARTICIPANT	\N	PRESENT	0
45840	45819	98042T	PARTICIPANT	\N	PRESENT	0
45841	45819	14249W	PARTICIPANT	\N	PRESENT	0
45842	45819	01041N	PARTICIPANT	\N	PRESENT	0
45843	45819	01025N	PARTICIPANT	\N	PRESENT	0
45844	45819	01037S	PARTICIPANT	\N	PRESENT	0
45845	45819	89029V	PARTICIPANT	\N	PRESENT	0
49326	47944	08017T	PARTICIPANT	\N	PRESENT	0
45847	45819	11089X	PARTICIPANT	\N	PRESENT	0
45848	45819	07026Q	PARTICIPANT	\N	PRESENT	0
45849	45819	14123H	PARTICIPANT	\N	PRESENT	0
45850	45819	14179A	PARTICIPANT	\N	PRESENT	0
45851	45819	04041B	PARTICIPANT	\N	PRESENT	0
45852	45819	14241N	PARTICIPANT	\N	PRESENT	0
45853	45819	14061L	PARTICIPANT	\N	PRESENT	0
45854	45819	14073Q	PARTICIPANT	\N	PRESENT	0
45855	45819	08031R	PARTICIPANT	\N	EXCUSE	0
49327	47944	08068F	PARTICIPANT	\N	PRESENT	0
45857	45819	08039A	PARTICIPANT	\N	PRESENT	0
49328	47944	07004J	PARTICIPANT	\N	PRESENT	0
45859	45819	14059S	PARTICIPANT	\N	EXCUSE	0
49329	47944	95035G	PARTICIPANT	\N	PRESENT	0
45861	45819	14103D	PARTICIPANT	\N	PRESENT	0
45862	45819	11104D	PARTICIPANT	\N	PRESENT	0
45863	45819	14063N	PARTICIPANT	\N	PRESENT	0
45864	45819	04057K	PARTICIPANT	\N	PRESENT	0
45865	45819	11014C	PARTICIPANT	\N	PRESENT	0
45866	45819	14109K	PARTICIPANT	\N	PRESENT	0
45867	45819	04070G	PARTICIPANT	\N	EXCUSE	0
45868	45819	92040Q	PARTICIPANT	\N	PRESENT	0
45869	45819	14191V	PARTICIPANT	\N	PRESENT	0
45870	45819	83047W	PARTICIPANT	\N	PRESENT	0
45871	45819	14235Q	PARTICIPANT	\N	PRESENT	0
49330	47944	11100Y	PARTICIPANT	\N	PRESENT	0
49320	47944	08055A	PARTICIPANT	\N	PRESENT	0
45874	45819	14229S	PARTICIPANT	\N	PRESENT	0
45875	45819	11043H	PARTICIPANT	\N	PRESENT	0
45876	45819	11071M	PARTICIPANT	\N	PRESENT	0
49321	47944	08011M	PARTICIPANT	\N	PRESENT	0
49331	47944	10015M	PARTICIPANT	\N	PRESENT	0
49332	47944	14169X	PARTICIPANT	\N	PRESENT	0
49333	47944	14157T	PARTICIPANT	\N	PRESENT	0
49334	47944	11012A	PARTICIPANT	\N	PRESENT	0
49335	47944	04088S	PARTICIPANT	\N	PRESENT	0
49336	47944	14041T	PARTICIPANT	\N	PRESENT	0
49337	47944	14073Q	PARTICIPANT	\N	PRESENT	0
49338	47944	11036J	PARTICIPANT	\N	PRESENT	0
49339	47944	11067R	PARTICIPANT	\N	PRESENT	0
49340	47944	01057W	PARTICIPANT	\N	PRESENT	0
49341	47944	14205J	PARTICIPANT	\N	PRESENT	0
49342	47944	14037X	PARTICIPANT	\N	PRESENT	0
49343	47944	07029T	PARTICIPANT	\N	PRESENT	0
49344	47944	11083R	PARTICIPANT	\N	PRESENT	0
49345	47944	11035H	PARTICIPANT	\N	PRESENT	0
49346	47944	01031L	PARTICIPANT	\N	PRESENT	0
49347	47944	14191V	PARTICIPANT	\N	PRESENT	0
49348	47944	14038Y	PARTICIPANT	\N	PRESENT	0
49349	47944	14179A	PARTICIPANT	\N	PRESENT	0
49350	47944	14219Q	PARTICIPANT	\N	PRESENT	0
49355	47944	11097X	PARTICIPANT	\N	PRESENT	0
49356	47945	08055A	PARTICIPANT	\N	PRESENT	0
49357	47945	08011M	PARTICIPANT	\N	PRESENT	0
49382	47945	14179A	PARTICIPANT	\N	PRESENT	0
49359	47945	04034C	PARTICIPANT	\N	PRESENT	0
49360	47945	08017T	PARTICIPANT	\N	PRESENT	0
49361	47945	07004J	PARTICIPANT	\N	PRESENT	0
49362	47945	95035G	PARTICIPANT	\N	PRESENT	0
49363	47945	10015M	PARTICIPANT	\N	PRESENT	0
49385	47945	14103D	PARTICIPANT	\N	PRESENT	0
49386	47945	14169X	PARTICIPANT	\N	PRESENT	0
49366	47945	11012A	PARTICIPANT	\N	PRESENT	0
49367	47945	04088S	PARTICIPANT	\N	PRESENT	0
49368	47945	14041T	PARTICIPANT	\N	PRESENT	0
49369	47945	14073Q	PARTICIPANT	\N	PRESENT	0
49370	47945	11036J	PARTICIPANT	\N	PRESENT	0
49383	47945	11097X	PARTICIPANT	\N	PRESENT	0
49372	47945	01057W	PARTICIPANT	\N	PRESENT	0
49373	47945	07029T	PARTICIPANT	\N	PRESENT	0
49374	47945	11083R	PARTICIPANT	\N	PRESENT	0
49375	47945	11035H	PARTICIPANT	\N	PRESENT	0
49376	47945	01031L	PARTICIPANT	\N	PRESENT	0
49384	47945	08028W	PARTICIPANT	\N	PRESENT	0
49387	47945	14249W	PARTICIPANT	\N	PRESENT	0
49388	47945	89017R	PARTICIPANT	\N	PRESENT	0
49380	47945	14219Q	PARTICIPANT	\N	PRESENT	0
49389	47945	11091R	PARTICIPANT	\N	PRESENT	0
49390	47945	11068S	PARTICIPANT	\N	PRESENT	0
49391	47945	08060W	PARTICIPANT	\N	PRESENT	0
49392	47945	04057K	PARTICIPANT	\N	PRESENT	0
49421	49416	04081K	PARTICIPANT	\N	PRESENT	0
49422	49416	11040E	PARTICIPANT	\N	PRESENT	0
49423	49416	04054G	PARTICIPANT	\N	PRESENT	0
49424	49416	11027H	PARTICIPANT	\N	PRESENT	0
49425	49416	11036J	PARTICIPANT	\N	PRESENT	0
49426	49416	07004J	PARTICIPANT	\N	PRESENT	0
49427	49416	14273W	PARTICIPANT	\N	PRESENT	0
49428	49416	14041T	PARTICIPANT	\N	PRESENT	0
49429	49416	14038Y	PARTICIPANT	\N	PRESENT	0
49430	49416	11106F	PARTICIPANT	\N	PRESENT	0
49431	49416	01056V	PARTICIPANT	\N	PRESENT	0
49432	49416	11103C	PARTICIPANT	\N	PRESENT	0
49433	49416	14033T	PARTICIPANT	\N	PRESENT	0
49436	49416	11091R	PARTICIPANT	\N	PRESENT	0
49437	49416	13002U	PARTICIPANT	\N	PRESENT	0
49438	49416	11076S	PARTICIPANT	\N	PRESENT	0
49439	49416	14089Y	PARTICIPANT	\N	PRESENT	0
49440	49416	99004R	PARTICIPANT	\N	PRESENT	0
49441	49416	14121F	PARTICIPANT	\N	PRESENT	0
49442	49416	14103D	PARTICIPANT	\N	PRESENT	0
49443	49416	07029T	PARTICIPANT	\N	PRESENT	0
49444	49416	14265W	PARTICIPANT	\N	PRESENT	0
49445	49416	04088S	PARTICIPANT	\N	PRESENT	0
49446	49416	04048J	PARTICIPANT	\N	PRESENT	0
49447	49416	14073Q	PARTICIPANT	\N	PRESENT	0
49448	49416	11012A	PARTICIPANT	\N	PRESENT	0
49449	49416	08016S	PARTICIPANT	\N	PRESENT	0
49450	49416	04074L	PARTICIPANT	\N	PRESENT	0
49451	49416	14133K	PARTICIPANT	\N	PRESENT	0
49452	49416	14219Q	PARTICIPANT	\N	PRESENT	0
49453	49416	14207L	PARTICIPANT	\N	PRESENT	0
49454	49416	10006L	PARTICIPANT	\N	PRESENT	0
49455	49417	04081K	PARTICIPANT	\N	PRESENT	0
49456	49417	11040E	PARTICIPANT	\N	PRESENT	0
49457	49417	04054G	PARTICIPANT	\N	PRESENT	0
49458	49417	11027H	PARTICIPANT	\N	PRESENT	0
49459	49417	11036J	PARTICIPANT	\N	PRESENT	0
49460	49417	07004J	PARTICIPANT	\N	PRESENT	0
49461	49417	14273W	PARTICIPANT	\N	PRESENT	0
49462	49417	14041T	PARTICIPANT	\N	PRESENT	0
49463	49417	14038Y	PARTICIPANT	\N	PRESENT	0
49464	49417	11106F	PARTICIPANT	\N	PRESENT	0
49465	49417	01056V	PARTICIPANT	\N	PRESENT	0
49466	49417	11103C	PARTICIPANT	\N	PRESENT	0
49467	49417	14033T	PARTICIPANT	\N	PRESENT	0
49468	49417	11091R	PARTICIPANT	\N	PRESENT	0
49469	49417	13002U	PARTICIPANT	\N	PRESENT	0
49470	49417	11076S	PARTICIPANT	\N	PRESENT	0
49471	49417	14089Y	PARTICIPANT	\N	PRESENT	0
49472	49417	99004R	PARTICIPANT	\N	PRESENT	0
49473	49417	14121F	PARTICIPANT	\N	PRESENT	0
49474	49417	14103D	PARTICIPANT	\N	PRESENT	0
49475	49417	07029T	PARTICIPANT	\N	PRESENT	0
49476	49417	14265W	PARTICIPANT	\N	PRESENT	0
49477	49417	04088S	PARTICIPANT	\N	PRESENT	0
49478	49417	04048J	PARTICIPANT	\N	PRESENT	0
49479	49417	14073Q	PARTICIPANT	\N	PRESENT	0
49480	49417	11012A	PARTICIPANT	\N	PRESENT	0
49481	49417	08016S	PARTICIPANT	\N	PRESENT	0
49482	49417	04074L	PARTICIPANT	\N	PRESENT	0
49483	49417	14133K	PARTICIPANT	\N	PRESENT	0
57158	56960	11036J	PARTICIPANT	\N	PRESENT	0
57159	56960	14026U	PARTICIPANT	\N	PRESENT	0
57172	56960	14069U	PARTICIPANT	\N	PRESENT	0
57173	49959	11106F	PARTICIPANT	\N	EXCUSE	0
57157	56960	01027Q	PARTICIPANT	\N	PRESENT	0
57100	56960	11029K	PARTICIPANT	\N	PRESENT	0
57821	57008	05008E	PARTICIPANT	\N	PRESENT	0
57822	57008	14069U	PARTICIPANT	\N	PRESENT	0
57103	56960	14073Q	PARTICIPANT	\N	PRESENT	0
57823	57008	02002K	PARTICIPANT	\N	PRESENT	0
57824	57008	14033T	PARTICIPANT	\N	PRESENT	0
57106	56960	14179A	PARTICIPANT	\N	PRESENT	0
57155	56960	05008E	PARTICIPANT	\N	PRESENT	0
57825	57008	98005N	PARTICIPANT	\N	PRESENT	0
57109	56960	14219Q	PARTICIPANT	\N	PRESENT	0
57110	56960	14105F	PARTICIPANT	\N	PRESENT	0
57826	57008	01041N	PARTICIPANT	\N	PRESENT	0
57827	57008	14073Q	PARTICIPANT	\N	PRESENT	0
57113	56960	14079W	PARTICIPANT	\N	PRESENT	0
57828	57008	14083S	PARTICIPANT	\N	PRESENT	0
57836	57008	11033F	PARTICIPANT	\N	PRESENT	0
57830	57008	11107G	PARTICIPANT	\N	PRESENT	0
57831	57008	14013P	PARTICIPANT	\N	PRESENT	0
57832	57008	01059Y	PARTICIPANT	\N	PRESENT	0
57833	57008	11031D	PARTICIPANT	\N	PRESENT	0
57834	57008	80013X	PARTICIPANT	\N	PRESENT	0
57835	57008	14065Q	PARTICIPANT	\N	PRESENT	0
57122	56960	01059Y	PARTICIPANT	\N	PRESENT	0
57837	57008	14103D	PARTICIPANT	\N	PRESENT	0
57124	56960	14235Q	PARTICIPANT	\N	PRESENT	0
57125	56960	14083S	PARTICIPANT	\N	PRESENT	0
57838	57008	14205J	PARTICIPANT	\N	PRESENT	0
57156	56960	11012A	PARTICIPANT	\N	PRESENT	0
57839	57008	11012A	PARTICIPANT	\N	PRESENT	0
57154	56960	88008L	PARTICIPANT	\N	PRESENT	0
57840	57008	11090Q	PARTICIPANT	\N	PRESENT	0
57841	57008	04048J	PARTICIPANT	\N	PRESENT	0
57132	56960	14033T	PARTICIPANT	\N	PRESENT	0
57842	57008	99004R	PARTICIPANT	\N	PRESENT	0
57843	57008	11036J	PARTICIPANT	\N	PRESENT	0
57135	56960	14265W	PARTICIPANT	\N	PRESENT	0
57844	57008	04043D	PARTICIPANT	\N	PRESENT	0
57845	57008	11066Q	PARTICIPANT	\N	PRESENT	0
57138	56960	92045V	PARTICIPANT	\N	PRESENT	0
57139	56960	11039M	PARTICIPANT	\N	PRESENT	0
57140	56960	14257W	PARTICIPANT	\N	PRESENT	0
57847	57008	08060W	PARTICIPANT	\N	PRESENT	0
57848	57008	11042G	PARTICIPANT	\N	PRESENT	0
57874	57873	11044J	PARTICIPANT	\N	PRESENT	0
57144	56960	14215L	PARTICIPANT	\N	PRESENT	0
57145	56960	08010L	PARTICIPANT	\N	PRESENT	0
57146	56960	14207L	PARTICIPANT	\N	PRESENT	0
57147	56960	14038Y	PARTICIPANT	\N	PRESENT	0
57875	57873	11067R	PARTICIPANT	\N	PRESENT	0
57149	56960	11037K	PARTICIPANT	\N	PRESENT	0
57150	56960	11034G	PARTICIPANT	\N	PRESENT	0
57151	56960	04044E	PARTICIPANT	\N	PRESENT	0
57876	57008	08069G	PARTICIPANT	\N	PRESENT	0
57153	56960	04085P	PARTICIPANT	\N	PRESENT	0
57877	57008	04088S	PARTICIPANT	\N	PRESENT	0
57878	57008	14041T	PARTICIPANT	\N	PRESENT	0
57879	57008	11081P	PARTICIPANT	\N	PRESENT	0
57880	57008	08019V	PARTICIPANT	\N	PRESENT	0
57881	57008	04036E	PARTICIPANT	\N	PRESENT	0
57882	57008	01058X	PARTICIPANT	\N	PRESENT	0
57883	57008	08055A	PARTICIPANT	\N	PRESENT	0
57884	57008	04057K	PARTICIPANT	\N	PRESENT	0
57889	57008	11048N	PARTICIPANT	\N	PRESENT	0
57927	56796	11031D	PARTICIPANT	\N	PRESENT	0
57928	56796	01059Y	PARTICIPANT	\N	PRESENT	0
57929	56796	14013P	PARTICIPANT	\N	PRESENT	0
57930	56796	11066Q	PARTICIPANT	\N	PRESENT	0
57931	56796	14205J	PARTICIPANT	\N	PRESENT	0
57932	56796	08019V	PARTICIPANT	\N	PRESENT	0
57933	56796	14041T	PARTICIPANT	\N	PRESENT	0
57934	56796	04043D	PARTICIPANT	\N	PRESENT	0
57935	56796	11081P	PARTICIPANT	\N	PRESENT	0
57936	56796	11036J	PARTICIPANT	\N	PRESENT	0
57937	56796	04053F	PARTICIPANT	\N	PRESENT	0
57938	56796	11099A	PARTICIPANT	\N	PRESENT	0
57939	56796	98005N	PARTICIPANT	\N	PRESENT	0
57940	56796	11090Q	PARTICIPANT	\N	PRESENT	0
57941	56796	11084S	PARTICIPANT	\N	PRESENT	0
57944	56796	08018U	PARTICIPANT	\N	PRESENT	0
57945	56796	10015M	PARTICIPANT	\N	PRESENT	0
57946	56796	04055H	PARTICIPANT	\N	PRESENT	0
57947	56796	89017R	PARTICIPANT	\N	PRESENT	0
57948	56796	04085P	PARTICIPANT	\N	PRESENT	0
57949	56796	11048N	PARTICIPANT	\N	PRESENT	0
57950	56796	11072N	PARTICIPANT	\N	PRESENT	0
57951	56796	14083S	PARTICIPANT	\N	PRESENT	0
57925	56796	04081K	PARTICIPANT	\N	PRESENT	0
57926	56796	04048J	PARTICIPANT	\N	PRESENT	0
57345	57174	01057W	PARTICIPANT	\N	PRESENT	0
57343	57174	11080N	PARTICIPANT	\N	EXCUSE	0
57344	57174	01027Q	PRESIDENT	0	PRESENT	0
57346	57174	14159V	PARTICIPANT	\N	PRESENT	0
57347	57174	01013J	PARTICIPANT	\N	EXCUSE	0
57348	57174	92039X	PARTICIPANT	\N	PRESENT	0
57349	57174	11012A	PARTICIPANT	\N	EXCUSE	0
57394	56793	08052W	PARTICIPANT	\N	PRESENT	0
57395	56793	11106F	PARTICIPANT	\N	PRESENT	0
57396	56793	08060W	PARTICIPANT	\N	PRESENT	0
57397	56793	11025F	PARTICIPANT	\N	PRESENT	0
57398	56793	14159V	PARTICIPANT	\N	PRESENT	0
57399	56793	14081Q	PARTICIPANT	\N	PRESENT	0
57400	56793	14030Q	PARTICIPANT	\N	PRESENT	0
57401	56793	14275Y	PARTICIPANT	\N	PRESENT	0
57402	56793	14231L	PARTICIPANT	\N	PRESENT	0
57403	56793	14205J	PARTICIPANT	\N	PRESENT	0
57404	56793	14267Y	PARTICIPANT	\N	PRESENT	0
57405	56793	14223L	PARTICIPANT	\N	PRESENT	0
57406	56793	14221J	PARTICIPANT	\N	PRESENT	0
57407	56793	11066Q	PARTICIPANT	\N	PRESENT	0
57408	56793	08068F	PARTICIPANT	\N	PRESENT	0
57409	56793	08025T	PARTICIPANT	\N	PRESENT	0
57410	56793	14227Q	PARTICIPANT	\N	PRESENT	0
57411	56793	11040E	PARTICIPANT	\N	PRESENT	0
57412	56793	07026Q	PARTICIPANT	\N	PRESENT	0
57413	56793	08055A	PARTICIPANT	\N	PRESENT	0
57414	56793	04077P	PARTICIPANT	\N	PRESENT	0
57415	56793	11042G	PARTICIPANT	\N	PRESENT	0
57416	56793	13002U	PARTICIPANT	\N	PRESENT	0
57417	56793	95037J	PARTICIPANT	\N	PRESENT	0
57418	56793	14107H	PARTICIPANT	\N	PRESENT	0
57419	56793	04056J	PARTICIPANT	\N	PRESENT	0
57420	56793	08014Q	PARTICIPANT	\N	PRESENT	0
57421	56793	11036J	PARTICIPANT	\N	PRESENT	0
57422	56793	11059R	PARTICIPANT	\N	PRESENT	0
57423	56793	98022P	PARTICIPANT	\N	PRESENT	0
57424	56793	11012A	PARTICIPANT	\N	PRESENT	0
57425	56793	11055M	PARTICIPANT	\N	PRESENT	0
57426	56793	98035U	PARTICIPANT	\N	PRESENT	0
57427	56793	14277B	PARTICIPANT	\N	PRESENT	0
57428	56793	11104D	PARTICIPANT	\N	PRESENT	0
57429	56793	14167V	PARTICIPANT	\N	PRESENT	0
57430	56793	07004J	PARTICIPANT	\N	PRESENT	0
57431	56793	04040A	PARTICIPANT	\N	PRESENT	0
57432	56793	04078Q	PARTICIPANT	\N	PRESENT	0
57433	56793	14042U	PARTICIPANT	\N	PRESENT	0
57435	56793	01016M	PARTICIPANT	\N	PRESENT	0
57436	56793	08031R	PARTICIPANT	\N	PRESENT	0
57392	57174	11069T	PARTICIPANT	\N	EXCUSE	0
57393	56793	86034E	PARTICIPANT	\N	PRESENT	0
57439	56793	14051J	PARTICIPANT	\N	PRESENT	0
57442	56793	14121F	PARTICIPANT	\N	PRESENT	0
57447	56793	83047W	PARTICIPANT	\N	PRESENT	0
57466	56793	98029W	PARTICIPANT	\N	PRESENT	0
57454	56793	14103D	PARTICIPANT	\N	PRESENT	0
57457	56793	04080J	PARTICIPANT	\N	PRESENT	0
57467	56793	04053F	PARTICIPANT	\N	PRESENT	0
57468	56793	11067R	PARTICIPANT	\N	PRESENT	0
57469	56793	01011G	PARTICIPANT	\N	PRESENT	0
57470	56793	11093T	PARTICIPANT	\N	PRESENT	0
57471	56793	01007L	PARTICIPANT	\N	PRESENT	0
57472	56793	11015D	PARTICIPANT	\N	PRESENT	0
57473	56793	11029K	PARTICIPANT	\N	PRESENT	0
57819	57008	04081K	PARTICIPANT	\N	PRESENT	0
42237	41870	04043D	PARTICIPANT	\N	PRESENT	0
38843	38841	04085P	PARTICIPANT	\N	PRESENT	0
38844	38841	05008E	PRESIDENT	0	PRESENT	0
42238	41870	14033T	PARTICIPANT	\N	PRESENT	0
38846	38841	11033F	PARTICIPANT	\N	PRESENT	0
42239	41870	11097X	PARTICIPANT	\N	PRESENT	0
42255	41870	14121F	PARTICIPANT	\N	PRESENT	0
38849	38841	04047H	PARTICIPANT	\N	PRESENT	0
42256	41870	14097Y	PARTICIPANT	\N	PRESENT	0
42242	41870	11080N	PARTICIPANT	\N	PRESENT	0
42243	41870	11104D	PARTICIPANT	\N	PRESENT	0
38853	38841	11056N	PARTICIPANT	\N	EXCUSE	0
42244	41870	11012A	PARTICIPANT	\N	PRESENT	0
38855	38841	11035H	PARTICIPANT	\N	PRESENT	0
38856	38841	14041T	PARTICIPANT	\N	PRESENT	0
42245	41870	14069U	PARTICIPANT	\N	PRESENT	0
38858	38841	01024M	PARTICIPANT	\N	PRESENT	0
38859	38841	14215L	PARTICIPANT	\N	PRESENT	0
42246	41870	11082Q	PARTICIPANT	\N	PRESENT	0
38861	38841	08018U	PARTICIPANT	\N	EXCUSE	0
42247	41870	14034U	PARTICIPANT	\N	PRESENT	0
42257	41870	01016M	PARTICIPANT	\N	PRESENT	0
42249	41870	08022Q	PARTICIPANT	\N	PRESENT	0
42250	41870	95015C	PARTICIPANT	\N	PRESENT	0
38866	38841	11084S	PARTICIPANT	\N	PRESENT	0
38867	38841	11026G	PARTICIPANT	\N	PRESENT	0
42251	41870	11098Y	PARTICIPANT	\N	PRESENT	0
42252	41870	14119M	PARTICIPANT	\N	PRESENT	0
42253	41870	01025N	PARTICIPANT	\N	PRESENT	0
42254	41870	08039A	PARTICIPANT	\N	PRESENT	0
42258	41870	11042G	PARTICIPANT	\N	PRESENT	0
42259	41870	14085U	PARTICIPANT	\N	PRESENT	0
42260	41870	92045V	PARTICIPANT	\N	PRESENT	0
38875	38841	08051V	PARTICIPANT	\N	PRESENT	0
38876	38841	11072N	PARTICIPANT	\N	PRESENT	0
38877	38841	07034Q	PARTICIPANT	\N	PRESENT	0
38878	38841	04074L	PARTICIPANT	\N	PRESENT	0
42261	41870	89017R	PARTICIPANT	\N	PRESENT	0
38880	38841	95063L	PARTICIPANT	\N	PRESENT	0
42262	41870	08068F	PARTICIPANT	\N	PRESENT	0
38882	38841	01028R	PARTICIPANT	\N	PRESENT	0
42263	41870	14265W	PARTICIPANT	\N	PRESENT	0
38884	38841	04056J	PARTICIPANT	\N	PRESENT	0
38885	38841	14275Y	PARTICIPANT	\N	PRESENT	0
38886	38841	04044E	PARTICIPANT	\N	EXCUSE	0
38887	38841	11037K	PARTICIPANT	\N	PRESENT	0
38888	38841	92045V	PARTICIPANT	\N	PRESENT	0
42264	41870	14235Q	PARTICIPANT	\N	PRESENT	0
42265	41870	14231L	PARTICIPANT	\N	PRESENT	0
42266	41870	14173T	PARTICIPANT	\N	PRESENT	0
42267	41870	08062Y	PARTICIPANT	\N	PRESENT	0
42268	41870	14217N	PARTICIPANT	\N	PRESENT	0
42269	41870	14175V	PARTICIPANT	\N	PRESENT	0
42270	41870	11105E	PARTICIPANT	\N	PRESENT	0
42271	41870	01008M	PARTICIPANT	\N	PRESENT	0
42272	41870	05012A	PARTICIPANT	\N	PRESENT	0
42273	41870	14159V	PARTICIPANT	\N	PRESENT	0
42274	41870	14213J	PARTICIPANT	\N	PRESENT	0
42275	41870	14109K	PARTICIPANT	\N	PRESENT	0
42276	41870	08055A	PARTICIPANT	\N	PRESENT	0
42277	41870	04088S	PARTICIPANT	\N	PRESENT	0
42278	41870	08051V	PARTICIPANT	\N	PRESENT	0
42279	41870	07029T	PARTICIPANT	\N	PRESENT	0
42280	41870	11048N	PARTICIPANT	\N	PRESENT	0
42332	41613	11077T	PARTICIPANT	\N	PRESENT	0
42333	41613	04086Q	PARTICIPANT	\N	PRESENT	0
42334	41613	11098Y	PARTICIPANT	\N	PRESENT	0
42335	41613	11105E	PARTICIPANT	\N	PRESENT	0
42336	41613	80013X	PARTICIPANT	\N	PRESENT	0
42337	41613	08014Q	PARTICIPANT	\N	PRESENT	0
42338	41613	11074Q	PARTICIPANT	\N	PRESENT	0
42339	41613	11057P	PARTICIPANT	\N	PRESENT	0
42340	41613	11112D	PARTICIPANT	\N	PRESENT	0
42341	41613	01025N	PARTICIPANT	\N	PRESENT	0
42342	41613	14105F	PARTICIPANT	\N	PRESENT	0
42343	41613	14059S	PARTICIPANT	\N	PRESENT	0
42344	41613	95062K	PARTICIPANT	\N	PRESENT	0
42345	41613	14187A	PARTICIPANT	\N	PRESENT	0
42346	41613	08034U	PARTICIPANT	\N	PRESENT	0
42347	41613	14207L	PARTICIPANT	\N	PRESENT	0
42348	41613	01027Q	PARTICIPANT	\N	PRESENT	0
42349	41613	14235Q	PARTICIPANT	\N	PRESENT	0
42350	41613	11036J	PARTICIPANT	\N	PRESENT	0
42351	41613	01016M	PARTICIPANT	\N	PRESENT	0
42352	41613	01057W	PARTICIPANT	\N	PRESENT	0
42353	41613	14053L	PARTICIPANT	\N	PRESENT	0
42354	41613	11061K	PARTICIPANT	\N	PRESENT	0
42355	41613	08051V	PARTICIPANT	\N	PRESENT	0
42356	41613	14197C	PARTICIPANT	\N	PRESENT	0
42357	41613	11012A	PARTICIPANT	\N	PRESENT	0
42358	41613	14018U	PARTICIPANT	\N	PRESENT	0
42359	41613	14069U	PARTICIPANT	\N	PRESENT	0
42360	41613	11067R	PARTICIPANT	\N	PRESENT	0
42361	41613	07029T	PARTICIPANT	\N	PRESENT	0
42362	41613	11043H	PARTICIPANT	\N	PRESENT	0
42363	41613	08031R	PARTICIPANT	\N	PRESENT	0
42364	41613	08062Y	PARTICIPANT	\N	PRESENT	0
42365	41613	14119M	PARTICIPANT	\N	PRESENT	0
42366	41613	11090Q	PARTICIPANT	\N	PRESENT	0
42367	41613	11048N	PARTICIPANT	\N	PRESENT	0
42368	41613	11044J	PARTICIPANT	\N	PRESENT	0
42369	41613	01043Q	PARTICIPANT	\N	PRESENT	0
42370	41613	08068F	PARTICIPANT	\N	PRESENT	0
42371	41613	11066Q	PARTICIPANT	\N	PRESENT	0
42372	41613	08011M	PARTICIPANT	\N	PRESENT	0
42373	41613	14083S	PARTICIPANT	\N	PRESENT	0
42374	41613	14265W	PARTICIPANT	\N	PRESENT	0
42375	41613	14033T	PARTICIPANT	\N	PRESENT	0
42376	41613	95015C	PARTICIPANT	\N	PRESENT	0
42377	41613	14217N	PARTICIPANT	\N	PRESENT	0
42378	41613	08015R	PARTICIPANT	\N	PRESENT	0
42379	41613	04088S	PARTICIPANT	\N	PRESENT	0
42380	41613	01008M	PARTICIPANT	\N	PRESENT	0
42330	41613	01007L	PARTICIPANT	\N	PRESENT	0
42331	41613	01031L	PARTICIPANT	\N	PRESENT	0
42381	41613	14213J	PARTICIPANT	\N	PRESENT	0
42382	41613	89017R	PARTICIPANT	\N	PRESENT	0
42383	41613	08010L	PARTICIPANT	\N	PRESENT	0
42384	41613	14026U	PARTICIPANT	\N	PRESENT	0
42385	41613	96004D	PARTICIPANT	\N	PRESENT	0
42386	41613	92045V	PARTICIPANT	\N	PRESENT	0
43187	43185	14151M	PARTICIPANT	\N	PRESENT	0
43188	43185	11084S	PARTICIPANT	\N	PRESENT	0
43186	43185	92039X	PARTICIPANT	\N	PRESENT	0
43189	43185	98005N	PARTICIPANT	\N	PRESENT	0
43190	43185	11100Y	PARTICIPANT	\N	PRESENT	0
43191	43185	11012A	PARTICIPANT	\N	PRESENT	0
43192	43185	98035U	PARTICIPANT	\N	PRESENT	0
43195	43193	04036E	PARTICIPANT	\N	PRESENT	0
43196	43193	04070G	PARTICIPANT	\N	PRESENT	0
43197	43193	14255U	PARTICIPANT	\N	PRESENT	0
43198	43193	95067Q	PARTICIPANT	\N	PRESENT	0
43199	43193	08031R	PARTICIPANT	\N	PRESENT	0
43200	43193	11026G	PARTICIPANT	\N	PRESENT	0
43202	43201	14255U	PARTICIPANT	\N	PRESENT	0
43203	43201	04070G	PARTICIPANT	\N	PRESENT	0
43204	43201	08015R	PARTICIPANT	\N	PRESENT	0
43210	43205	95067Q	PARTICIPANT	\N	PRESENT	0
43207	43205	11026G	PARTICIPANT	\N	PRESENT	0
43213	43212	11076S	PARTICIPANT	\N	PRESENT	0
43209	43205	04070G	PARTICIPANT	\N	PRESENT	0
43215	43212	04036E	PARTICIPANT	\N	PRESENT	0
43216	43212	11026G	PARTICIPANT	\N	PRESENT	0
44562	44560	86034E	PARTICIPANT	\N	PRESENT	0
44286	44283	04049K	PARTICIPANT	\N	PRESENT	0
44332	44330	14081Q	PARTICIPANT	\N	PRESENT	0
44563	44560	04049K	PARTICIPANT	\N	PRESENT	0
44565	44560	01043Q	PARTICIPANT	\N	PRESENT	0
44566	44560	14255U	PARTICIPANT	\N	PRESENT	0
44567	44560	14083S	PARTICIPANT	\N	PRESENT	0
44568	44560	14041T	PARTICIPANT	\N	PRESENT	0
44570	44560	92031P	PARTICIPANT	\N	PRESENT	0
44571	44560	14265W	PARTICIPANT	\N	PRESENT	0
44573	44560	14253S	PARTICIPANT	\N	PRESENT	0
44574	44560	11090Q	PARTICIPANT	\N	PRESENT	0
44575	44560	14157T	PARTICIPANT	\N	PRESENT	0
44578	44560	89017R	PARTICIPANT	\N	EXCUSE	0
44579	44560	14261S	PARTICIPANT	\N	EXCUSE	0
44580	44560	08055A	PARTICIPANT	\N	EXCUSE	0
44581	44560	14065Q	PARTICIPANT	\N	EXCUSE	0
44582	44560	14030Q	PARTICIPANT	\N	EXCUSE	0
44583	44560	14013P	PARTICIPANT	\N	EXCUSE	0
44584	44560	08014Q	PARTICIPANT	\N	EXCUSE	0
44585	44560	14105F	PARTICIPANT	\N	EXCUSE	0
44586	44560	08068F	PARTICIPANT	\N	EXCUSE	0
44587	44560	04053F	PARTICIPANT	\N	EXCUSE	0
44588	44560	14207L	PARTICIPANT	\N	EXCUSE	0
44589	44560	14079W	PARTICIPANT	\N	EXCUSE	0
44590	44560	04055H	PARTICIPANT	\N	EXCUSE	0
61726	61419	87003B	PARTICIPANT	\N	PRESENT	0
61727	61419	08062Y	PARTICIPANT	\N	PRESENT	0
61728	61419	11091R	PARTICIPANT	\N	PRESENT	0
61729	61419	11049P	PARTICIPANT	\N	PRESENT	0
61730	61419	14041T	PARTICIPANT	\N	PRESENT	0
61731	61419	04088S	PARTICIPANT	\N	PRESENT	0
61732	61419	08069G	PARTICIPANT	\N	PRESENT	0
61733	61419	07029T	PARTICIPANT	\N	PRESENT	0
61734	61419	14123H	PARTICIPANT	\N	PRESENT	0
61735	61419	04041B	PARTICIPANT	\N	PRESENT	0
61736	61419	95062K	PARTICIPANT	\N	PRESENT	0
61737	61419	14013P	PARTICIPANT	\N	PRESENT	0
61738	61419	11089X	PARTICIPANT	\N	PRESENT	0
61739	61419	11074Q	PARTICIPANT	\N	PRESENT	0
61740	61419	14273W	PARTICIPANT	\N	PRESENT	0
61741	61419	14249W	PARTICIPANT	\N	PRESENT	0
61742	61419	08019V	PARTICIPANT	\N	PRESENT	0
61743	61419	14329V	PARTICIPANT	\N	PRESENT	0
61744	61419	11093T	PARTICIPANT	\N	PRESENT	0
61745	61419	14133K	PARTICIPANT	\N	PRESENT	0
61746	61419	14103D	PARTICIPANT	\N	PRESENT	0
61747	61419	11094U	PARTICIPANT	\N	PRESENT	0
61748	61419	04044E	PARTICIPANT	\N	PRESENT	0
61749	61419	95030B	PARTICIPANT	\N	PRESENT	0
61750	61419	14267Y	PARTICIPANT	\N	PRESENT	0
61751	61419	14030Q	PARTICIPANT	\N	PRESENT	0
61752	61419	14042U	PARTICIPANT	\N	PRESENT	0
61753	61419	83047W	PARTICIPANT	\N	PRESENT	0
61754	61419	14231L	PARTICIPANT	\N	PRESENT	0
61755	61419	14269B	PARTICIPANT	\N	PRESENT	0
61756	61419	11103C	PARTICIPANT	\N	PRESENT	0
61757	61419	14213J	PARTICIPANT	\N	PRESENT	0
61758	61419	08015R	PARTICIPANT	\N	PRESENT	0
61759	61419	92039X	PARTICIPANT	\N	PRESENT	0
61760	61419	95049N	PARTICIPANT	\N	PRESENT	0
61761	61419	14034U	PARTICIPANT	\N	PRESENT	0
61762	61419	01027Q	PARTICIPANT	\N	PRESENT	0
61763	61419	98021N	PARTICIPANT	\N	PRESENT	0
61764	61419	14033T	PARTICIPANT	\N	PRESENT	0
61765	61419	14209N	PARTICIPANT	\N	PRESENT	0
61766	61419	11039M	PARTICIPANT	\N	PRESENT	0
61767	61419	14107H	PARTICIPANT	\N	PRESENT	0
61768	61419	14051J	PARTICIPANT	\N	PRESENT	0
61769	61419	97011G	PARTICIPANT	\N	PRESENT	0
61770	61419	04049K	PARTICIPANT	\N	PRESENT	0
61771	61419	14217N	PARTICIPANT	\N	PRESENT	0
61772	61419	14079W	PARTICIPANT	\N	PRESENT	0
61773	61419	14087W	PARTICIPANT	\N	PRESENT	0
61774	61419	11107G	PARTICIPANT	\N	PRESENT	0
61775	61419	01028R	PARTICIPANT	\N	PRESENT	0
61776	61419	01022K	PARTICIPANT	\N	PRESENT	0
61777	61419	08016S	PARTICIPANT	\N	PRESENT	0
61778	61419	14257W	PARTICIPANT	\N	PRESENT	0
61779	61419	11112D	PARTICIPANT	\N	PRESENT	0
61780	61419	11095V	PARTICIPANT	\N	PRESENT	0
61781	61419	11044J	PARTICIPANT	\N	PRESENT	0
61782	61419	11083R	PARTICIPANT	\N	PRESENT	0
61783	61419	92040Q	PARTICIPANT	\N	PRESENT	0
61784	61419	11097X	PARTICIPANT	\N	PRESENT	0
61785	61419	98046X	PARTICIPANT	\N	PRESENT	0
61786	61419	01034P	PARTICIPANT	\N	PRESENT	0
61787	61419	04048J	PARTICIPANT	\N	PRESENT	0
61788	61419	11042G	PARTICIPANT	\N	PRESENT	0
61790	61789	11039M	PARTICIPANT	\N	PRESENT	0
61791	61789	98042T	PARTICIPANT	\N	PRESENT	0
61792	61789	01019Q	PARTICIPANT	\N	PRESENT	0
61793	61419	04067M	PARTICIPANT	\N	PRESENT	0
61795	61794	11053K	PARTICIPANT	\N	EXCUSE	0
61796	61794	11080N	PARTICIPANT	\N	PRESENT	0
61797	61794	01027Q	PRESIDENT	0	PRESENT	0
61798	61794	01057W	PARTICIPANT	\N	PRESENT	0
61799	61794	14159V	PARTICIPANT	\N	PRESENT	0
61800	61794	92039X	PARTICIPANT	\N	PRESENT	0
61801	61794	11012A	PARTICIPANT	\N	PRESENT	0
61802	61794	14157T	PARTICIPANT	\N	PRESENT	0
61803	60622	98053W	PARTICIPANT	\N	PRESENT	0
61804	60622	08039A	PARTICIPANT	\N	PRESENT	0
61805	60622	01044R	PARTICIPANT	\N	PRESENT	0
61806	60622	07026Q	PARTICIPANT	\N	PRESENT	0
61807	60622	08043V	PARTICIPANT	\N	PRESENT	0
61808	60622	01028R	PARTICIPANT	\N	PRESENT	0
61809	60622	14109K	PARTICIPANT	\N	PRESENT	0
61810	60622	04059M	PARTICIPANT	\N	PRESENT	0
61811	60622	14241N	PARTICIPANT	\N	PRESENT	0
61812	60622	14089Y	PARTICIPANT	\N	PRESENT	0
61813	60622	90003B	PARTICIPANT	\N	PRESENT	0
61814	60622	01025N	PARTICIPANT	\N	PRESENT	0
61815	60622	11089X	PARTICIPANT	\N	PRESENT	0
61816	60622	11029K	PARTICIPANT	\N	PRESENT	0
61817	60622	14229S	PARTICIPANT	\N	PRESENT	0
61818	60622	04070G	PARTICIPANT	\N	PRESENT	0
61819	60622	14209N	PARTICIPANT	\N	PRESENT	0
61820	60622	04057K	PARTICIPANT	\N	PRESENT	0
61821	60622	11074Q	PARTICIPANT	\N	PRESENT	0
61822	60622	14329V	PARTICIPANT	\N	PRESENT	0
61823	60622	04041B	PARTICIPANT	\N	PRESENT	0
61824	60622	08017T	PARTICIPANT	\N	PRESENT	0
61825	60622	04056J	PARTICIPANT	\N	PRESENT	0
61826	60622	08062Y	PARTICIPANT	\N	PRESENT	0
61827	60622	11094U	PARTICIPANT	\N	PRESENT	0
61828	60622	14059S	PARTICIPANT	\N	PRESENT	0
61829	60622	14061L	PARTICIPANT	\N	PRESENT	0
61830	60622	14249W	PARTICIPANT	\N	PRESENT	0
61831	60622	12041X	PARTICIPANT	\N	PRESENT	0
61832	60622	14235Q	PARTICIPANT	\N	PRESENT	0
61833	60622	01034P	PARTICIPANT	\N	PRESENT	0
61834	60622	95049N	PARTICIPANT	\N	PRESENT	0
61835	60622	11043H	PARTICIPANT	\N	PRESENT	0
61836	60622	14257W	PARTICIPANT	\N	PRESENT	0
61837	60622	14237S	PARTICIPANT	\N	PRESENT	0
61838	60622	14259Y	PARTICIPANT	\N	PRESENT	0
61839	60622	14031R	PARTICIPANT	\N	PRESENT	0
61840	60622	14121F	PARTICIPANT	\N	PRESENT	0
61841	60622	07032N	PARTICIPANT	\N	PRESENT	0
61842	60622	14169X	PARTICIPANT	\N	PRESENT	0
61843	60622	14026U	PARTICIPANT	\N	PRESENT	0
61844	60622	08019V	PARTICIPANT	\N	PRESENT	0
61845	60622	14073Q	PARTICIPANT	\N	PRESENT	0
61846	60622	14219Q	PARTICIPANT	\N	PRESENT	0
61847	60622	14030Q	PARTICIPANT	\N	PRESENT	0
61848	60622	14231L	PARTICIPANT	\N	PRESENT	0
61850	60622	14097Y	PARTICIPANT	\N	PRESENT	0
61851	60622	14281W	PARTICIPANT	\N	PRESENT	0
61857	61849	01044R	PARTICIPANT	\N	PRESENT	0
61858	61849	08043V	PARTICIPANT	\N	PRESENT	0
61860	61849	14105F	PARTICIPANT	\N	EXCUSE	0
61861	61849	11029K	PARTICIPANT	\N	PRESENT	0
61863	61849	92015P	PARTICIPANT	\N	EXCUSE	0
61864	61849	08024S	PARTICIPANT	\N	EXCUSE	0
61866	61849	14329V	PARTICIPANT	\N	PRESENT	0
61867	61849	14209N	PARTICIPANT	\N	PRESENT	0
61868	61849	14079W	PARTICIPANT	\N	PRESENT	0
61869	61849	11091R	PARTICIPANT	\N	PRESENT	0
61872	61849	14249W	PARTICIPANT	\N	PRESENT	0
61873	61849	01041N	PARTICIPANT	\N	PRESENT	0
61874	61849	01025N	PARTICIPANT	\N	PRESENT	0
61878	61849	11089X	PARTICIPANT	\N	PRESENT	0
61882	61849	04041B	PARTICIPANT	\N	PRESENT	0
61883	61849	14241N	PARTICIPANT	\N	PRESENT	0
61884	61849	14061L	PARTICIPANT	\N	PRESENT	0
61886	61849	08031R	PARTICIPANT	\N	PRESENT	0
61887	61849	12041X	PARTICIPANT	\N	PRESENT	0
61888	61849	08039A	PARTICIPANT	\N	PRESENT	0
61889	61849	08017T	PARTICIPANT	\N	PRESENT	0
61890	61849	14059S	PARTICIPANT	\N	PRESENT	0
61893	61849	11104D	PARTICIPANT	\N	PRESENT	0
61895	61849	04057K	PARTICIPANT	\N	PRESENT	0
61725	61419	11043H	PARTICIPANT	\N	PRESENT	0
32141	32131	01008M	PARTICIPANT	\N	PRESENT	0
32146	32131	11091R	PARTICIPANT	\N	PRESENT	0
32149	32131	01037S	PARTICIPANT	\N	PRESENT	0
32150	32131	95062K	PARTICIPANT	\N	PRESENT	0
32153	32131	14133K	PARTICIPANT	\N	PRESENT	0
32168	32166	01008M	PARTICIPANT	\N	PRESENT	0
32219	32166	14133K	PARTICIPANT	\N	PRESENT	0
32221	32166	01041N	PARTICIPANT	\N	PRESENT	0
32223	32166	11091R	PARTICIPANT	\N	PRESENT	0
32224	32166	01037S	PARTICIPANT	\N	PRESENT	0
32228	32166	14037X	PARTICIPANT	\N	PRESENT	0
32229	32166	14219Q	PARTICIPANT	\N	PRESENT	0
32233	32166	04036E	PARTICIPANT	\N	PRESENT	0
32235	32166	14265W	PARTICIPANT	\N	PRESENT	0
32237	32166	95062K	PARTICIPANT	\N	PRESENT	0
48509	44368	04055H	PARTICIPANT	\N	EXCUSE	0
48510	44368	89017R	PARTICIPANT	\N	EXCUSE	0
44636	44248	80013X	PARTICIPANT	\N	PRESENT	0
48511	44368	14261S	PARTICIPANT	\N	EXCUSE	0
48512	44368	08055A	PARTICIPANT	\N	EXCUSE	0
48513	44368	14065Q	PARTICIPANT	\N	EXCUSE	0
48514	44368	14030Q	PARTICIPANT	\N	EXCUSE	0
48515	44368	14013P	PARTICIPANT	\N	EXCUSE	0
48516	44368	08014Q	PARTICIPANT	\N	EXCUSE	0
48517	44368	08068F	PARTICIPANT	\N	EXCUSE	0
48518	44368	14207L	PARTICIPANT	\N	EXCUSE	0
48519	44368	14083S	PARTICIPANT	\N	EXCUSE	0
48520	44368	14079W	PARTICIPANT	\N	EXCUSE	0
48521	44368	11088W	PARTICIPANT	\N	EXCUSE	0
48522	44368	14041T	PARTICIPANT	\N	EXCUSE	0
48523	44368	11110B	PARTICIPANT	\N	EXCUSE	0
48524	44368	14087W	PARTICIPANT	\N	EXCUSE	0
48525	44368	02002K	PARTICIPANT	\N	EXCUSE	0
48526	44368	14034U	PARTICIPANT	\N	EXCUSE	0
48527	44368	14121F	PARTICIPANT	\N	EXCUSE	0
48528	44368	95041E	PARTICIPANT	\N	EXCUSE	0
48529	44368	14039A	PARTICIPANT	\N	EXCUSE	0
48530	44368	14061L	PARTICIPANT	\N	EXCUSE	0
48531	44368	04077P	PARTICIPANT	\N	EXCUSE	0
48532	44368	01043Q	PARTICIPANT	\N	EXCUSE	0
48533	44368	11077T	PARTICIPANT	\N	EXCUSE	0
48534	44368	14018U	PARTICIPANT	\N	EXCUSE	0
48535	44368	14265W	PARTICIPANT	\N	EXCUSE	0
48536	44368	14253S	PARTICIPANT	\N	EXCUSE	0
48537	44368	11069T	PARTICIPANT	\N	EXCUSE	0
48538	44368	11090Q	PARTICIPANT	\N	EXCUSE	0
48539	44368	10015M	PARTICIPANT	\N	EXCUSE	0
48540	44368	14157T	PARTICIPANT	\N	EXCUSE	0
48541	44368	95067Q	PARTICIPANT	\N	EXCUSE	0
48542	44368	11063M	PARTICIPANT	\N	EXCUSE	0
49484	49417	14219Q	PARTICIPANT	\N	PRESENT	0
49485	49417	14207L	PARTICIPANT	\N	PRESENT	0
49486	49417	10006L	PARTICIPANT	\N	PRESENT	0
49488	49417	14259Y	PARTICIPANT	\N	PRESENT	0
49489	49417	11029K	PARTICIPANT	\N	PRESENT	0
49490	49487	04081K	PARTICIPANT	\N	PRESENT	0
49491	49487	11040E	PARTICIPANT	\N	PRESENT	0
49492	49487	04054G	PARTICIPANT	\N	PRESENT	0
49493	49487	11027H	PARTICIPANT	\N	PRESENT	0
49494	49487	11036J	PARTICIPANT	\N	PRESENT	0
49495	49487	07004J	PARTICIPANT	\N	PRESENT	0
49496	49487	14273W	PARTICIPANT	\N	PRESENT	0
49497	49487	14041T	PARTICIPANT	\N	PRESENT	0
49498	49487	14038Y	PARTICIPANT	\N	PRESENT	0
49555	49418	01028R	PARTICIPANT	\N	PRESENT	0
49500	49487	01056V	PARTICIPANT	\N	PRESENT	0
49501	49487	11103C	PARTICIPANT	\N	PRESENT	0
49502	49487	14033T	PARTICIPANT	\N	PRESENT	0
49503	49487	11091R	PARTICIPANT	\N	PRESENT	0
49504	49487	13002U	PARTICIPANT	\N	PRESENT	0
49505	49487	11076S	PARTICIPANT	\N	PRESENT	0
49506	49487	14089Y	PARTICIPANT	\N	PRESENT	0
49507	49487	99004R	PARTICIPANT	\N	PRESENT	0
49508	49487	14121F	PARTICIPANT	\N	PRESENT	0
49509	49487	14103D	PARTICIPANT	\N	PRESENT	0
49510	49487	07029T	PARTICIPANT	\N	PRESENT	0
49511	49487	14265W	PARTICIPANT	\N	PRESENT	0
49512	49487	04088S	PARTICIPANT	\N	PRESENT	0
49513	49487	04048J	PARTICIPANT	\N	PRESENT	0
49514	49487	14073Q	PARTICIPANT	\N	PRESENT	0
49515	49487	11012A	PARTICIPANT	\N	PRESENT	0
49516	49487	08016S	PARTICIPANT	\N	PRESENT	0
49517	49487	04074L	PARTICIPANT	\N	PRESENT	0
49518	49487	14133K	PARTICIPANT	\N	PRESENT	0
49519	49487	14219Q	PARTICIPANT	\N	PRESENT	0
49556	49418	14041T	PARTICIPANT	\N	PRESENT	0
49521	49487	10006L	PARTICIPANT	\N	PRESENT	0
49522	49487	14259Y	PARTICIPANT	\N	PRESENT	0
49523	49487	11029K	PARTICIPANT	\N	PRESENT	0
49524	49418	04081K	PARTICIPANT	\N	PRESENT	0
49525	49418	11040E	PARTICIPANT	\N	PRESENT	0
49526	49418	04054G	PARTICIPANT	\N	PRESENT	0
49560	49418	05008E	PARTICIPANT	\N	PRESENT	0
49528	49418	11036J	PARTICIPANT	\N	PRESENT	0
49561	49418	11085T	PARTICIPANT	\N	PRESENT	0
49682	49681	11042G	PARTICIPANT	\N	PRESENT	0
49683	49681	04056J	PARTICIPANT	\N	PRESENT	0
49532	49418	14038Y	PARTICIPANT	\N	PRESENT	0
49684	49681	04034C	PARTICIPANT	\N	PRESENT	0
49833	49832	07024N	PARTICIPANT	\N	PRESENT	0
49834	49832	01014K	PARTICIPANT	\N	PRESENT	0
49536	49418	11091R	PARTICIPANT	\N	PRESENT	0
49537	49418	13002U	PARTICIPANT	\N	PRESENT	0
49892	49855	14071N	PARTICIPANT	\N	PRESENT	0
49913	49855	04044E	PARTICIPANT	\N	EXCUSE	0
49914	49855	11034G	PARTICIPANT	\N	EXCUSE	0
49541	49418	14121F	PARTICIPANT	\N	PRESENT	0
49542	49418	14103D	PARTICIPANT	\N	PRESENT	0
49543	49418	07029T	PARTICIPANT	\N	PRESENT	0
49544	49418	14265W	PARTICIPANT	\N	PRESENT	0
49915	49855	14327T	PARTICIPANT	\N	PRESENT	0
49916	49855	11035H	PARTICIPANT	\N	EXCUSE	0
49547	49418	14073Q	PARTICIPANT	\N	PRESENT	0
49548	49418	11012A	PARTICIPANT	\N	PRESENT	0
49549	49418	04074L	PARTICIPANT	\N	PRESENT	0
49550	49418	14133K	PARTICIPANT	\N	PRESENT	0
49551	49418	14219Q	PARTICIPANT	\N	PRESENT	0
50447	50446	14133K	PARTICIPANT	\N	PRESENT	0
50448	50446	96004D	PRESIDENT	0	PRESENT	0
49554	49418	11029K	PARTICIPANT	\N	PRESENT	0
50450	50446	14089Y	PARTICIPANT	\N	PRESENT	0
50451	50446	90003B	PARTICIPANT	\N	PRESENT	0
50452	50446	14079W	PARTICIPANT	\N	PRESENT	0
50453	50446	11035H	PARTICIPANT	\N	PRESENT	0
50455	50446	95030B	PARTICIPANT	\N	PRESENT	0
50456	50446	11083R	PARTICIPANT	\N	PRESENT	0
50458	50446	95037J	PARTICIPANT	\N	PRESENT	0
50459	50446	04061F	PARTICIPANT	\N	PRESENT	0
50460	50446	98046X	PARTICIPANT	\N	PRESENT	0
50461	50446	14001X	PARTICIPANT	\N	PRESENT	0
50462	50446	04057K	PARTICIPANT	\N	PRESENT	0
50463	50446	14135M	PARTICIPANT	\N	PRESENT	0
50464	50446	11012A	PARTICIPANT	\N	PRESENT	0
50465	50446	04045F	PARTICIPANT	\N	PRESENT	0
50466	50446	92045V	PARTICIPANT	\N	PRESENT	0
50467	50446	04034C	PARTICIPANT	\N	EXCUSE	0
50469	50468	11039M	PARTICIPANT	\N	PRESENT	0
50470	50468	98042T	PARTICIPANT	\N	PRESENT	0
50471	50468	01019Q	PARTICIPANT	\N	PRESENT	0
50473	50472	11039M	PARTICIPANT	\N	PRESENT	0
50474	50472	98042T	PARTICIPANT	\N	PRESENT	0
50475	50472	01019Q	PARTICIPANT	\N	PRESENT	0
50591	49955	08055A	PARTICIPANT	\N	PRESENT	0
50741	49955	11025F	PARTICIPANT	\N	PRESENT	0
50742	49955	14079W	PARTICIPANT	\N	PRESENT	0
50743	49955	14193X	PARTICIPANT	\N	PRESENT	0
50744	49955	04088S	PARTICIPANT	\N	PRESENT	0
50745	49955	14041T	PARTICIPANT	\N	PRESENT	0
50746	49955	14259Y	PARTICIPANT	\N	PRESENT	0
50747	49955	14089Y	PARTICIPANT	\N	PRESENT	0
50748	49955	14263U	PARTICIPANT	\N	PRESENT	0
50749	49955	13002U	PARTICIPANT	\N	PRESENT	0
50750	49955	11036J	PARTICIPANT	\N	PRESENT	0
50751	49955	14231L	PARTICIPANT	\N	PRESENT	0
50752	49955	11037K	PARTICIPANT	\N	PRESENT	0
50753	49955	14038Y	PARTICIPANT	\N	PRESENT	0
50754	49955	04040A	PARTICIPANT	\N	PRESENT	0
50755	49955	11070L	PARTICIPANT	\N	PRESENT	0
50756	49955	14331P	PARTICIPANT	\N	PRESENT	0
50757	49955	14028W	PARTICIPANT	\N	PRESENT	0
50758	49955	04034C	PARTICIPANT	\N	PRESENT	0
50759	49955	14121F	PARTICIPANT	\N	PRESENT	0
50760	49955	14257W	PARTICIPANT	\N	PRESENT	0
50761	49955	14235Q	PARTICIPANT	\N	PRESENT	0
50762	49955	01015L	PARTICIPANT	\N	PRESENT	0
50763	49955	14013P	PARTICIPANT	\N	PRESENT	0
50764	49955	92015P	PARTICIPANT	\N	PRESENT	0
57474	56793	11033F	PARTICIPANT	\N	PRESENT	0
57475	56793	01044R	PARTICIPANT	\N	PRESENT	0
57476	56793	11107G	PARTICIPANT	\N	PRESENT	0
57477	56793	11063M	PARTICIPANT	\N	PRESENT	0
57478	56793	01015L	PARTICIPANT	\N	PRESENT	0
57479	56793	12041X	PARTICIPANT	\N	PRESENT	0
57480	56793	11031D	PARTICIPANT	\N	PRESENT	0
57481	56793	04059M	PARTICIPANT	\N	PRESENT	0
57482	56793	98046X	PARTICIPANT	\N	PRESENT	0
57483	56793	04066L	PARTICIPANT	\N	PRESENT	0
57484	56793	11027H	PARTICIPANT	\N	PRESENT	0
57485	56793	11084S	PARTICIPANT	\N	PRESENT	0
57486	56793	01022K	PARTICIPANT	\N	PRESENT	0
57487	56793	14271U	PARTICIPANT	\N	PRESENT	0
57488	56793	08058D	PARTICIPANT	\N	PRESENT	0
57489	56793	04034C	PARTICIPANT	\N	PRESENT	0
57490	56793	11034G	PARTICIPANT	\N	PRESENT	0
57491	56793	14151M	PARTICIPANT	\N	PRESENT	0
57492	56793	95062K	PARTICIPANT	\N	PRESENT	0
57493	56793	14281W	PARTICIPANT	\N	PRESENT	0
57494	56793	02002K	PARTICIPANT	\N	PRESENT	0
57495	56793	14229S	PARTICIPANT	\N	PRESENT	0
57496	56793	04071H	PARTICIPANT	\N	PRESENT	0
57497	56793	99004R	PARTICIPANT	\N	PRESENT	0
57498	56793	14097Y	PARTICIPANT	\N	PRESENT	0
57499	56793	01058X	PARTICIPANT	\N	PRESENT	0
57500	56793	14001X	PARTICIPANT	\N	PRESENT	0
57501	56793	14211G	PARTICIPANT	\N	PRESENT	0
57502	56793	14063N	PARTICIPANT	\N	PRESENT	0
57503	56793	14207L	PARTICIPANT	\N	PRESENT	0
57504	56793	04061F	PARTICIPANT	\N	PRESENT	0
57505	56793	14169X	PARTICIPANT	\N	PRESENT	0
57506	56793	04097T	PARTICIPANT	\N	PRESENT	0
57507	56793	14028W	PARTICIPANT	\N	PRESENT	0
57508	56793	80013X	PARTICIPANT	\N	PRESENT	0
57509	56793	14017T	PARTICIPANT	\N	PRESENT	0
57510	56793	11101A	PARTICIPANT	\N	PRESENT	0
57511	56793	14225N	PARTICIPANT	\N	PRESENT	0
57512	56793	01031L	PARTICIPANT	\N	PRESENT	0
57513	56793	14093U	PARTICIPANT	\N	PRESENT	0
57514	56793	08038Y	PARTICIPANT	\N	PRESENT	0
57515	56793	92040Q	PARTICIPANT	\N	PRESENT	0
57517	56793	98005N	PARTICIPANT	\N	PRESENT	0
57518	56793	95063L	PARTICIPANT	\N	PRESENT	0
57519	56793	14085U	PARTICIPANT	\N	PRESENT	0
57520	56793	04074L	PARTICIPANT	\N	PRESENT	0
57521	56793	04045F	PARTICIPANT	\N	PRESENT	0
57522	56793	14038Y	PARTICIPANT	\N	PRESENT	0
57523	56793	04094Q	PARTICIPANT	\N	PRESENT	0
57524	56793	01057W	PARTICIPANT	\N	PRESENT	0
57525	56793	11109J	PARTICIPANT	\N	PRESENT	0
57575	56793	14253S	PARTICIPANT	\N	PRESENT	0
57527	56793	11010L	PARTICIPANT	\N	PRESENT	0
57528	56793	11072N	PARTICIPANT	\N	PRESENT	0
57529	56793	96004D	PARTICIPANT	\N	PRESENT	0
57530	56793	11023D	PARTICIPANT	\N	PRESENT	0
57531	56793	14109K	PARTICIPANT	\N	PRESENT	0
57532	56793	14157T	PARTICIPANT	\N	PRESENT	0
57533	56793	14033T	PARTICIPANT	\N	PRESENT	0
57534	56793	14269B	PARTICIPANT	\N	PRESENT	0
57535	56793	08018U	PARTICIPANT	\N	PRESENT	0
57536	56793	11076S	PARTICIPANT	\N	PRESENT	0
57537	56793	11099A	PARTICIPANT	\N	PRESENT	0
57538	56793	01003G	PARTICIPANT	\N	PRESENT	0
57539	56793	95059Q	PARTICIPANT	\N	PRESENT	0
57540	56793	11081P	PARTICIPANT	\N	PRESENT	0
57541	56793	88008L	PARTICIPANT	\N	PRESENT	0
57542	56793	01028R	PARTICIPANT	\N	PRESENT	0
57543	56793	04033B	PARTICIPANT	\N	PRESENT	0
57544	56793	10006L	PARTICIPANT	\N	PRESENT	0
57545	56793	01034P	PARTICIPANT	\N	PRESENT	0
57546	56793	86044G	PARTICIPANT	\N	PRESENT	0
57547	56793	11053K	PARTICIPANT	\N	PRESENT	0
57548	56793	08022Q	PARTICIPANT	\N	PRESENT	0
57549	56793	04089T	PARTICIPANT	\N	PRESENT	0
57550	56793	11064N	PARTICIPANT	\N	PRESENT	0
57551	56793	04086Q	PARTICIPANT	\N	PRESENT	0
57552	56793	14083S	PARTICIPANT	\N	PRESENT	0
57553	56793	14079W	PARTICIPANT	\N	PRESENT	0
57554	56793	14219Q	PARTICIPANT	\N	PRESENT	0
57555	56793	95035G	PARTICIPANT	\N	PRESENT	0
57556	56793	14123H	PARTICIPANT	\N	PRESENT	0
57557	56793	14031R	PARTICIPANT	\N	PRESENT	0
57558	56793	08019V	PARTICIPANT	\N	PRESENT	0
57559	56793	11088W	PARTICIPANT	\N	PRESENT	0
57560	56793	14073Q	PARTICIPANT	\N	PRESENT	0
57561	56793	04088S	PARTICIPANT	\N	PRESENT	0
57562	56793	98042T	PARTICIPANT	\N	PRESENT	0
57563	56793	09001P	PARTICIPANT	\N	PRESENT	0
57564	56793	14041T	PARTICIPANT	\N	PRESENT	0
57565	56793	11085T	PARTICIPANT	\N	PRESENT	0
57566	56793	14255U	PARTICIPANT	\N	PRESENT	0
57567	56793	07029T	PARTICIPANT	\N	PRESENT	0
57568	56793	92044U	PARTICIPANT	\N	PRESENT	0
57569	56793	89017R	PARTICIPANT	\N	PRESENT	0
57570	56793	11069T	PARTICIPANT	\N	PRESENT	0
57571	56793	14247U	PARTICIPANT	\N	PRESENT	0
57572	56793	01027Q	PARTICIPANT	\N	PRESENT	0
57573	56793	11048N	PARTICIPANT	\N	PRESENT	0
57574	56793	11113E	PARTICIPANT	\N	PRESENT	0
57576	56793	11030C	PARTICIPANT	\N	PRESENT	0
57577	56793	04095R	PARTICIPANT	\N	PRESENT	0
57578	56793	11098Y	PARTICIPANT	\N	PRESENT	0
57579	56793	10015M	PARTICIPANT	\N	PRESENT	0
57580	56793	14013P	PARTICIPANT	\N	PRESENT	0
57581	56793	14235Q	PARTICIPANT	\N	PRESENT	0
57582	56793	08015R	PARTICIPANT	\N	PRESENT	0
57583	56793	01059Y	PARTICIPANT	\N	PRESENT	0
57584	56793	04085P	PARTICIPANT	\N	PRESENT	0
57585	56793	14037X	PARTICIPANT	\N	PRESENT	0
57586	56793	11039M	PARTICIPANT	\N	PRESENT	0
57587	56793	14061L	PARTICIPANT	\N	PRESENT	0
57591	56793	01008M	PARTICIPANT	\N	PRESENT	0
57589	56793	11089X	PARTICIPANT	\N	PRESENT	0
57590	56793	14187A	PARTICIPANT	\N	PRESENT	0
57600	56793	14265W	PARTICIPANT	\N	PRESENT	0
57593	56793	14209N	PARTICIPANT	\N	PRESENT	0
57594	56793	11044J	PARTICIPANT	\N	PRESENT	0
57595	56793	95067Q	PARTICIPANT	\N	PRESENT	0
57596	56793	14065Q	PARTICIPANT	\N	PRESENT	0
57597	56793	11090Q	PARTICIPANT	\N	PRESENT	0
57598	56793	08012N	PARTICIPANT	\N	PRESENT	0
57599	56793	11037K	PARTICIPANT	\N	PRESENT	0
57601	56793	08061X	PARTICIPANT	\N	PRESENT	0
57602	56793	05008E	PARTICIPANT	\N	PRESENT	0
57603	56793	11112D	PARTICIPANT	\N	PRESENT	0
57604	56793	14071N	PARTICIPANT	\N	PRESENT	0
57605	56793	04067M	PARTICIPANT	\N	PRESENT	0
57606	56793	11083R	PARTICIPANT	\N	PRESENT	0
57607	56793	01060R	PARTICIPANT	\N	PRESENT	0
57608	56793	04057K	PARTICIPANT	\N	PRESENT	0
57609	56793	05012A	PARTICIPANT	\N	PRESENT	0
57610	56793	04048J	PARTICIPANT	\N	PRESENT	0
57611	56793	07034Q	PARTICIPANT	\N	PRESENT	0
57612	56793	04043D	PARTICIPANT	\N	PRESENT	0
57613	56793	08010L	PARTICIPANT	\N	PRESENT	0
57614	56793	14069U	PARTICIPANT	\N	PRESENT	0
57615	56793	14026U	PARTICIPANT	\N	PRESENT	0
57616	56793	04035D	PARTICIPANT	\N	PRESENT	0
57617	56793	04079R	PARTICIPANT	\N	PRESENT	0
57618	56793	14105F	PARTICIPANT	\N	PRESENT	0
57619	56793	14111D	PARTICIPANT	\N	PRESENT	0
57620	56793	11032E	PARTICIPANT	\N	PRESENT	0
57635	56793	04049K	PARTICIPANT	\N	PRESENT	0
57622	56793	14249W	PARTICIPANT	\N	PRESENT	0
57627	56793	14257W	PARTICIPANT	\N	PRESENT	0
57628	56793	11074Q	PARTICIPANT	\N	PRESENT	0
57651	56793	05004A	PARTICIPANT	\N	PRESENT	0
57630	56793	14133K	PARTICIPANT	\N	PRESENT	0
57631	56793	14217N	PARTICIPANT	\N	PRESENT	0
57632	56793	14273W	PARTICIPANT	\N	PRESENT	0
57633	56793	14195A	PARTICIPANT	\N	PRESENT	0
57634	56793	04081K	PARTICIPANT	\N	PRESENT	0
57636	56793	04036E	PARTICIPANT	\N	PRESENT	0
57637	56793	01041N	PARTICIPANT	\N	PRESENT	0
57640	56793	14213J	PARTICIPANT	\N	PRESENT	0
57641	56793	08041T	PARTICIPANT	\N	PRESENT	0
57642	56793	11043H	PARTICIPANT	\N	PRESENT	0
57643	56793	14119M	PARTICIPANT	\N	PRESENT	0
57644	56793	14175V	PARTICIPANT	\N	PRESENT	0
57645	56793	07032N	PARTICIPANT	\N	PRESENT	0
57646	56793	08062Y	PARTICIPANT	\N	PRESENT	0
57647	56793	11011M	PARTICIPANT	\N	PRESENT	0
57648	56793	00003C	PARTICIPANT	\N	PRESENT	0
57649	56793	14059S	PARTICIPANT	\N	PRESENT	0
57650	56793	14087W	PARTICIPANT	\N	PRESENT	0
57653	57652	07024N	PARTICIPANT	\N	PRESENT	0
38372	38371	14069U	PARTICIPANT	\N	PRESENT	0
38375	38374	14069U	PARTICIPANT	\N	PRESENT	0
31513	31455	08048B	PARTICIPANT	\N	PRESENT	0
37632	37631	10015M	PARTICIPANT	\N	PRESENT	0
44591	44560	11088W	PARTICIPANT	\N	EXCUSE	0
31459	31455	04053F	PARTICIPANT	\N	PRESENT	0
44592	44560	04071H	PARTICIPANT	\N	EXCUSE	0
31461	31455	04066L	PARTICIPANT	\N	PRESENT	0
31462	31455	00003C	PARTICIPANT	\N	PRESENT	0
31463	31455	14053L	PARTICIPANT	\N	PRESENT	0
31464	31455	11103C	PARTICIPANT	\N	PRESENT	0
31465	31455	11044J	PARTICIPANT	\N	PRESENT	0
31466	31455	14195A	PARTICIPANT	\N	PRESENT	0
31467	31455	14267Y	PARTICIPANT	\N	PRESENT	0
44593	44560	14151M	PARTICIPANT	\N	EXCUSE	0
31469	31455	11031D	PARTICIPANT	\N	PRESENT	0
31470	31455	08052W	PARTICIPANT	\N	PRESENT	0
31471	31455	01059Y	PARTICIPANT	\N	PRESENT	0
31472	31455	04081K	PARTICIPANT	\N	PRESENT	0
31473	31455	98024R	PARTICIPANT	\N	PRESENT	0
31474	31455	10006L	PARTICIPANT	\N	PRESENT	0
44594	44560	11110B	PARTICIPANT	\N	EXCUSE	0
31476	31455	14217N	PARTICIPANT	\N	PRESENT	0
31477	31455	14042U	PARTICIPANT	\N	PRESENT	0
31478	31455	14151M	PARTICIPANT	\N	PRESENT	0
31479	31455	12042Y	PARTICIPANT	\N	PRESENT	0
31480	31455	14281W	PARTICIPANT	\N	PRESENT	0
31481	31455	14087W	PARTICIPANT	\N	PRESENT	0
44595	44560	14087W	PARTICIPANT	\N	EXCUSE	0
44596	44560	02002K	PARTICIPANT	\N	EXCUSE	0
31484	31455	14231L	PARTICIPANT	\N	PRESENT	0
31485	31455	11061K	PARTICIPANT	\N	PRESENT	0
44597	44560	14034U	PARTICIPANT	\N	EXCUSE	0
31487	31455	08041T	PARTICIPANT	\N	PRESENT	0
44598	44560	14121F	PARTICIPANT	\N	EXCUSE	0
44599	44560	95041E	PARTICIPANT	\N	EXCUSE	0
31490	31455	14213J	PARTICIPANT	\N	PRESENT	0
31491	31455	14121F	PARTICIPANT	\N	PRESENT	0
31492	31455	11112D	PARTICIPANT	\N	PRESENT	0
44600	44560	14039A	PARTICIPANT	\N	EXCUSE	0
44601	44560	14061L	PARTICIPANT	\N	EXCUSE	0
31495	31455	11067R	PARTICIPANT	\N	PRESENT	0
31496	31455	14223L	PARTICIPANT	\N	PRESENT	0
31497	31455	04092N	PRESIDENT	0	PRESENT	0
31498	31455	14265W	PARTICIPANT	\N	PRESENT	0
31499	31455	14119M	PARTICIPANT	\N	PRESENT	0
31500	31455	14071N	PARTICIPANT	\N	PRESENT	0
31501	31455	07032N	PARTICIPANT	\N	PRESENT	0
44602	44560	04077P	PARTICIPANT	\N	EXCUSE	0
31503	31455	14271U	PARTICIPANT	\N	PRESENT	0
44603	44560	11077T	PARTICIPANT	\N	EXCUSE	0
31505	31455	11093T	PARTICIPANT	\N	PRESENT	0
31506	31455	11097X	PARTICIPANT	\N	EXCUSE	0
31507	31455	04045F	PARTICIPANT	\N	PRESENT	0
31508	31455	14227Q	PARTICIPANT	\N	PRESENT	0
31509	31455	01034P	PARTICIPANT	\N	PRESENT	0
44604	44560	14018U	PARTICIPANT	\N	EXCUSE	0
31511	31455	11063M	PARTICIPANT	\N	PRESENT	0
44605	44560	11069T	PARTICIPANT	\N	EXCUSE	0
44606	44560	10015M	PARTICIPANT	\N	EXCUSE	0
44607	44560	95067Q	PARTICIPANT	\N	EXCUSE	0
44608	44560	11063M	PARTICIPANT	\N	EXCUSE	0
44972	44971	04049K	PARTICIPANT	\N	PRESENT	0
44974	44971	14061L	PARTICIPANT	\N	PRESENT	0
44975	44971	14065Q	PARTICIPANT	\N	PRESENT	0
44976	44971	14079W	PARTICIPANT	\N	PRESENT	0
44977	44971	04061F	PARTICIPANT	\N	PRESENT	0
44979	44971	14073Q	PARTICIPANT	\N	PRESENT	0
44981	44971	14265W	PARTICIPANT	\N	PRESENT	0
44983	44971	89017R	PARTICIPANT	\N	EXCUSE	0
44984	44971	14261S	PARTICIPANT	\N	EXCUSE	0
44985	44971	08055A	PARTICIPANT	\N	EXCUSE	0
44986	44971	14030Q	PARTICIPANT	\N	EXCUSE	0
44987	44971	14013P	PARTICIPANT	\N	EXCUSE	0
44988	44971	08014Q	PARTICIPANT	\N	EXCUSE	0
44989	44971	14105F	PARTICIPANT	\N	EXCUSE	0
44990	44971	08068F	PARTICIPANT	\N	EXCUSE	0
44991	44971	04053F	PARTICIPANT	\N	EXCUSE	0
44992	44971	14207L	PARTICIPANT	\N	EXCUSE	0
44993	44971	14255U	PARTICIPANT	\N	EXCUSE	0
44994	44971	14083S	PARTICIPANT	\N	EXCUSE	0
44995	44971	04055H	PARTICIPANT	\N	EXCUSE	0
44996	44971	11088W	PARTICIPANT	\N	EXCUSE	0
44997	44971	14041T	PARTICIPANT	\N	EXCUSE	0
44998	44971	04071H	PARTICIPANT	\N	EXCUSE	0
44999	44971	14151M	PARTICIPANT	\N	EXCUSE	0
45000	44971	11110B	PARTICIPANT	\N	EXCUSE	0
45001	44971	14087W	PARTICIPANT	\N	EXCUSE	0
45002	44971	02002K	PARTICIPANT	\N	EXCUSE	0
45003	44971	14034U	PARTICIPANT	\N	EXCUSE	0
45004	44971	14121F	PARTICIPANT	\N	EXCUSE	0
45005	44971	95041E	PARTICIPANT	\N	EXCUSE	0
45006	44971	14039A	PARTICIPANT	\N	EXCUSE	0
45007	44971	04077P	PARTICIPANT	\N	EXCUSE	0
45008	44971	01043Q	PARTICIPANT	\N	EXCUSE	0
45009	44971	11077T	PARTICIPANT	\N	EXCUSE	0
45010	44971	14018U	PARTICIPANT	\N	EXCUSE	0
45011	44971	14253S	PARTICIPANT	\N	EXCUSE	0
45012	44971	11069T	PARTICIPANT	\N	EXCUSE	0
45013	44971	11090Q	PARTICIPANT	\N	EXCUSE	0
45014	44971	10015M	PARTICIPANT	\N	EXCUSE	0
45015	44971	14157T	PARTICIPANT	\N	EXCUSE	0
45016	44971	95067Q	PARTICIPANT	\N	EXCUSE	0
45017	44971	11063M	PARTICIPANT	\N	EXCUSE	0
45117	41461	14081Q	PARTICIPANT	\N	PRESENT	0
46000	45976	11076S	PARTICIPANT	\N	PRESENT	0
46001	45976	04054G	PARTICIPANT	\N	PRESENT	0
46002	45976	04040A	PARTICIPANT	\N	PRESENT	0
46003	45976	08058D	PARTICIPANT	\N	PRESENT	0
46004	45976	04042C	PARTICIPANT	\N	PRESENT	0
46005	45976	77002U	PARTICIPANT	\N	PRESENT	0
46006	45976	98029W	PARTICIPANT	\N	PRESENT	0
46007	45976	11080N	PARTICIPANT	\N	PRESENT	0
46008	45976	11027H	PARTICIPANT	\N	PRESENT	0
46009	45976	98018T	PARTICIPANT	\N	PRESENT	0
46010	45976	92018S	PARTICIPANT	\N	PRESENT	0
46011	45976	92020L	PARTICIPANT	\N	PRESENT	0
46012	45976	95030B	PARTICIPANT	\N	PRESENT	0
46079	46077	04054G	PARTICIPANT	\N	PRESENT	0
46149	46077	04040A	PARTICIPANT	\N	PRESENT	0
46015	45976	97011G	PARTICIPANT	\N	PRESENT	0
46016	45976	08065C	PARTICIPANT	\N	PRESENT	0
46017	45976	04035D	PARTICIPANT	\N	PRESENT	0
46018	45976	07024N	PARTICIPANT	\N	PRESENT	0
46150	46077	08058D	PARTICIPANT	\N	PRESENT	0
46020	45976	14014Q	PARTICIPANT	\N	EXCUSE	0
46021	45976	11015D	PARTICIPANT	\N	PRESENT	0
46022	45976	07004J	PARTICIPANT	\N	PRESENT	0
46023	45976	95035G	PARTICIPANT	\N	PRESENT	0
46024	45976	08056B	PARTICIPANT	\N	PRESENT	0
46025	45976	14211G	PARTICIPANT	\N	PRESENT	0
46026	45976	98022P	PARTICIPANT	\N	PRESENT	0
46027	45976	11064N	PARTICIPANT	\N	PRESENT	0
46028	45976	95037J	PARTICIPANT	\N	PRESENT	0
46029	45976	04078Q	PARTICIPANT	\N	PRESENT	0
46151	46077	04042C	PARTICIPANT	\N	PRESENT	0
46031	45976	95041E	PARTICIPANT	\N	PRESENT	0
46032	45976	04036E	PARTICIPANT	\N	PRESENT	0
46152	46077	77002U	PARTICIPANT	\N	PRESENT	0
46034	45976	04077P	PARTICIPANT	\N	PRESENT	0
46035	45976	98005N	PARTICIPANT	\N	PRESENT	0
46036	45976	92031P	PARTICIPANT	\N	PRESENT	0
46037	45976	11106F	PARTICIPANT	\N	PRESENT	0
46038	45976	14251Q	PARTICIPANT	\N	PRESENT	0
46039	45976	83042R	PARTICIPANT	\N	EXCUSE	0
46153	46077	98029W	PARTICIPANT	\N	PRESENT	0
46041	45976	11082Q	PARTICIPANT	\N	PRESENT	0
46042	45976	11105E	PARTICIPANT	\N	PRESENT	0
46043	45976	14253S	PARTICIPANT	\N	PRESENT	0
46044	45976	08047A	PARTICIPANT	\N	PRESENT	0
46154	46077	11080N	PARTICIPANT	\N	PRESENT	0
46046	45976	14193X	PARTICIPANT	\N	PRESENT	0
46047	45976	98021N	PARTICIPANT	\N	PRESENT	0
46048	45976	11069T	PARTICIPANT	\N	PRESENT	0
46049	45976	04080J	PARTICIPANT	\N	PRESENT	0
46050	45976	95059Q	PRESIDENT	0	PRESENT	0
46051	45976	86044G	PARTICIPANT	\N	PRESENT	0
46052	45976	01014K	PARTICIPANT	\N	PRESENT	0
46053	45976	11054L	PARTICIPANT	\N	PRESENT	0
46054	45976	01056V	PARTICIPANT	\N	PRESENT	0
46055	45976	92044U	PARTICIPANT	\N	PRESENT	0
46056	45976	08049C	PARTICIPANT	\N	PRESENT	0
46155	46077	11027H	PARTICIPANT	\N	PRESENT	0
46156	46077	98018T	PARTICIPANT	\N	PRESENT	0
46157	46077	92018S	PARTICIPANT	\N	PRESENT	0
46159	46077	92020L	PARTICIPANT	\N	PRESENT	0
46160	46077	97011G	PARTICIPANT	\N	PRESENT	0
46161	46077	08065C	PARTICIPANT	\N	PRESENT	0
46163	46077	07024N	PARTICIPANT	\N	PRESENT	0
46164	46077	14014Q	PARTICIPANT	\N	EXCUSE	0
61910	60622	14223L	PARTICIPANT	\N	PRESENT	0
61911	60622	14187A	PARTICIPANT	\N	PRESENT	0
61912	60622	14033T	PARTICIPANT	\N	PRESENT	0
61913	60622	04088S	PARTICIPANT	\N	PRESENT	0
61914	60622	08015R	PARTICIPANT	\N	PRESENT	0
61915	60622	14193X	PARTICIPANT	\N	PRESENT	0
61916	60622	95041E	PARTICIPANT	\N	PRESENT	0
61917	60622	14087W	PARTICIPANT	\N	PRESENT	0
61918	61849	14089Y	PARTICIPANT	\N	PRESENT	0
61919	60622	04033B	PARTICIPANT	\N	PRESENT	0
61920	60622	08061X	PARTICIPANT	\N	PRESENT	0
61921	60622	92045V	PARTICIPANT	\N	PRESENT	0
61922	60622	14038Y	PARTICIPANT	\N	PRESENT	0
61923	60622	12042Y	PARTICIPANT	\N	PRESENT	0
61924	60622	11039M	PARTICIPANT	\N	PRESENT	0
61925	60622	80013X	PARTICIPANT	\N	PRESENT	0
61926	60622	14265W	PARTICIPANT	\N	PRESENT	0
61927	60622	14197C	PARTICIPANT	\N	PRESENT	0
61928	60622	11105E	PARTICIPANT	\N	PRESENT	0
61929	60622	14111D	PARTICIPANT	\N	PRESENT	0
61930	60622	14119M	PARTICIPANT	\N	PRESENT	0
61931	60622	14213J	PARTICIPANT	\N	PRESENT	0
61932	60622	01008M	PARTICIPANT	\N	PRESENT	0
61933	60622	11104D	PARTICIPANT	\N	PRESENT	0
61934	60622	92031P	PARTICIPANT	\N	PRESENT	0
61935	60622	11042G	PARTICIPANT	\N	PRESENT	0
61936	60622	08031R	PARTICIPANT	\N	PRESENT	0
61937	60622	14083S	PARTICIPANT	\N	PRESENT	0
61938	61849	14235Q	PARTICIPANT	\N	PRESENT	0
61939	60622	14123H	PARTICIPANT	\N	PRESENT	0
61940	60622	07029T	PARTICIPANT	\N	PRESENT	0
61941	60622	11026G	PARTICIPANT	\N	PRESENT	0
61896	61849	11014C	PARTICIPANT	\N	PRESENT	0
61897	61849	14109K	PARTICIPANT	\N	PRESENT	0
61898	61849	04070G	PRESIDENT	0	PRESENT	0
61899	61849	92040Q	PARTICIPANT	\N	PRESENT	0
61905	61849	14229S	PARTICIPANT	\N	PRESENT	0
61906	61849	11043H	PARTICIPANT	\N	PRESENT	0
61909	61849	11109J	PARTICIPANT	\N	EXCUSE	0
61988	61987	04054G	PARTICIPANT	\N	PRESENT	0
61989	61987	04040A	PARTICIPANT	\N	PRESENT	0
61990	61987	04042C	PARTICIPANT	\N	PRESENT	0
61991	61987	98029W	PARTICIPANT	\N	PRESENT	0
61992	61987	11027H	PARTICIPANT	\N	PRESENT	0
61993	61987	98018T	PARTICIPANT	\N	EXCUSE	0
61994	61987	95030B	PARTICIPANT	\N	PRESENT	0
62026	62023	05008E	PRESIDENT	0	PRESENT	0
61996	61987	97011G	PARTICIPANT	\N	PRESENT	0
61997	61987	04035D	PARTICIPANT	\N	PRESENT	0
61998	61987	07024N	PARTICIPANT	\N	EXCUSE	0
61999	61987	11015D	PARTICIPANT	\N	PRESENT	0
62000	61987	95035G	PARTICIPANT	\N	EXCUSE	0
62001	61987	08056B	PARTICIPANT	\N	EXCUSE	0
62002	61987	98022P	PARTICIPANT	\N	PRESENT	0
62003	61987	95037J	PARTICIPANT	\N	PRESENT	0
62004	61987	14097Y	PARTICIPANT	\N	PRESENT	0
62005	61987	95041E	PARTICIPANT	\N	PRESENT	0
62006	61987	04036E	PARTICIPANT	\N	PRESENT	0
62007	61987	14039A	PARTICIPANT	\N	PRESENT	0
62008	61987	04077P	PARTICIPANT	\N	PRESENT	0
62009	61987	92031P	PARTICIPANT	\N	PRESENT	0
62010	61987	11106F	PARTICIPANT	\N	PRESENT	0
62011	61987	14251Q	PARTICIPANT	\N	PRESENT	0
62012	61987	83042R	PARTICIPANT	\N	PRESENT	0
62013	61987	11082Q	PARTICIPANT	\N	EXCUSE	0
62014	61987	11105E	PARTICIPANT	\N	EXCUSE	0
62015	61987	14253S	PARTICIPANT	\N	PRESENT	0
62016	61987	08047A	PARTICIPANT	\N	PRESENT	0
62017	61987	14028W	PARTICIPANT	\N	PRESENT	0
62018	61987	98021N	PARTICIPANT	\N	PRESENT	0
62019	61987	04080J	PARTICIPANT	\N	PRESENT	0
62020	61987	95059Q	PRESIDENT	0	PRESENT	0
62021	61987	01014K	PARTICIPANT	\N	PRESENT	0
62022	61987	01056V	PARTICIPANT	\N	PRESENT	0
62024	62023	08025T	PARTICIPANT	\N	PRESENT	0
62025	62023	04085P	PARTICIPANT	\N	PRESENT	0
62027	62023	11030C	PARTICIPANT	\N	PRESENT	0
62028	62023	04047H	PARTICIPANT	\N	PRESENT	0
62029	62023	11032E	PARTICIPANT	\N	PRESENT	0
62030	62023	04038G	PARTICIPANT	\N	PRESENT	0
62031	62023	11035H	PARTICIPANT	\N	PRESENT	0
62032	62023	14041T	PARTICIPANT	\N	PRESENT	0
62033	62023	01024M	PARTICIPANT	\N	PRESENT	0
62034	62023	11034G	PARTICIPANT	\N	PRESENT	0
62035	62023	08018U	PARTICIPANT	\N	PRESENT	0
62036	62023	08044W	PARTICIPANT	\N	PRESENT	0
62037	62023	11084S	PARTICIPANT	\N	PRESENT	0
62038	62023	11026G	PARTICIPANT	\N	PRESENT	0
62039	62023	04079R	PARTICIPANT	\N	PRESENT	0
62040	62023	14111D	PARTICIPANT	\N	PRESENT	0
62041	62023	14001X	PARTICIPANT	\N	PRESENT	0
62042	62023	14273W	PARTICIPANT	\N	PRESENT	0
62043	62023	14147R	PARTICIPANT	\N	PRESENT	0
62044	62023	95049N	PARTICIPANT	\N	PRESENT	0
62045	62023	08051V	PARTICIPANT	\N	PRESENT	0
62046	62023	11072N	PARTICIPANT	\N	PRESENT	0
62047	62023	07034Q	PARTICIPANT	\N	PRESENT	0
62048	62023	04074L	PARTICIPANT	\N	PRESENT	0
62049	62023	10015M	PARTICIPANT	\N	PRESENT	0
62050	62023	01019Q	PARTICIPANT	\N	PRESENT	0
62051	62023	01028R	PARTICIPANT	\N	PRESENT	0
62052	62023	04056J	PARTICIPANT	\N	PRESENT	0
62053	62023	04044E	PARTICIPANT	\N	PRESENT	0
62054	62023	11037K	PARTICIPANT	\N	PRESENT	0
62055	62023	92045V	PARTICIPANT	\N	PRESENT	0
62056	62023	01047U	PARTICIPANT	\N	PRESENT	0
62057	62023	95063L	PARTICIPANT	\N	PRESENT	0
62058	60644	14061L	PARTICIPANT	\N	PRESENT	0
62059	60644	14030Q	PARTICIPANT	\N	PRESENT	0
62061	62060	01008M	PARTICIPANT	\N	PRESENT	0
62062	62060	11036J	PARTICIPANT	\N	EXCUSE	0
62063	62060	11081P	PARTICIPANT	\N	PRESENT	0
62065	62060	08068F	PARTICIPANT	\N	PRESENT	0
62066	62060	14207L	PARTICIPANT	\N	PRESENT	0
62067	62060	11101A	PARTICIPANT	\N	PRESENT	0
62068	62060	90003B	PARTICIPANT	\N	PRESENT	0
62069	62060	08028W	PARTICIPANT	\N	PRESENT	0
62070	62060	80013X	PARTICIPANT	\N	PRESENT	0
62071	62060	08038Y	PARTICIPANT	\N	PRESENT	0
62072	62060	04089T	PARTICIPANT	\N	PRESENT	0
62075	62060	14187A	PARTICIPANT	\N	PRESENT	0
62076	62060	14033T	PARTICIPANT	\N	PRESENT	0
62078	62060	04048J	PARTICIPANT	\N	PRESENT	0
62079	62060	11099A	PARTICIPANT	\N	PRESENT	0
62080	62060	04049K	PARTICIPANT	\N	PRESENT	0
62082	62060	11111C	PARTICIPANT	\N	PRESENT	0
62083	62060	08015R	PARTICIPANT	\N	PRESENT	0
62084	62060	11100Y	PRESIDENT	0	PRESENT	0
31010	30948	04080J	RAPPORTEUR_AVIS	\N	PRESENT	0
30950	30948	01031L	PRESIDENT	0	PRESENT	0
35182	35181	14069U	PARTICIPANT	\N	PRESENT	0
35184	35183	14069U	PARTICIPANT	\N	PRESENT	0
30953	30948	11068S	PARTICIPANT	\N	PRESENT	0
30954	30948	11040E	PARTICIPANT	\N	PRESENT	0
35186	35185	14069U	PARTICIPANT	\N	PRESENT	0
35188	35187	14069U	PARTICIPANT	\N	PRESENT	0
30957	30948	14175V	PARTICIPANT	\N	PRESENT	0
43527	43526	08051V	PARTICIPANT	\N	PRESENT	0
30959	30948	11053K	PARTICIPANT	\N	PRESENT	0
43528	43526	04086Q	PARTICIPANT	\N	PRESENT	0
30961	30948	11042G	PARTICIPANT	\N	PRESENT	0
30962	30948	88008L	PARTICIPANT	\N	PRESENT	0
30963	30948	04086Q	PARTICIPANT	\N	PRESENT	0
43529	43526	01057W	PARTICIPANT	\N	PRESENT	0
44209	41619	11109J	PARTICIPANT	\N	EXCUSE	0
44211	44210	01031L	PRESIDENT	0	PRESENT	0
30967	30948	14327T	PARTICIPANT	\N	PRESENT	0
44212	44210	11068S	PARTICIPANT	\N	PRESENT	0
30969	30948	01027Q	PARTICIPANT	\N	PRESENT	0
30970	30948	04071H	PARTICIPANT	\N	PRESENT	0
30971	30948	11074Q	PARTICIPANT	\N	PRESENT	0
44213	44210	14175V	PARTICIPANT	\N	PRESENT	0
30973	30948	11083R	PARTICIPANT	\N	PRESENT	0
44214	44210	11053K	PARTICIPANT	\N	PRESENT	0
30975	30948	01057W	PARTICIPANT	\N	PRESENT	0
44215	44210	04086Q	PARTICIPANT	\N	PRESENT	0
44216	44210	04071H	PARTICIPANT	\N	PRESENT	0
44217	44210	98053W	PARTICIPANT	\N	PRESENT	0
30979	30948	99004R	PARTICIPANT	\N	PRESENT	0
44218	44210	11083R	PARTICIPANT	\N	PRESENT	0
30981	30948	14159V	PARTICIPANT	\N	PRESENT	0
30982	30948	07029T	PARTICIPANT	\N	PRESENT	0
44219	44210	04061F	PARTICIPANT	\N	PRESENT	0
30984	30948	08010L	PARTICIPANT	\N	PRESENT	0
30985	30948	08034U	PARTICIPANT	\N	PRESENT	0
30986	30948	01048V	PARTICIPANT	\N	PRESENT	0
30987	30948	98046X	PARTICIPANT	\N	PRESENT	0
44220	44210	07029T	PARTICIPANT	\N	PRESENT	0
30989	30948	08011M	PARTICIPANT	\N	PRESENT	0
44221	44210	01048V	PARTICIPANT	\N	PRESENT	0
30991	30948	08061X	PARTICIPANT	\N	PRESENT	0
30992	30948	01016M	PARTICIPANT	\N	PRESENT	0
30993	30948	14225N	PARTICIPANT	\N	PRESENT	0
44222	44210	98046X	PARTICIPANT	\N	PRESENT	0
30995	30948	11057P	PARTICIPANT	\N	PRESENT	0
44223	44210	08011M	PARTICIPANT	\N	PRESENT	0
30997	30948	04034C	PARTICIPANT	\N	PRESENT	0
44224	44210	14225N	PARTICIPANT	\N	PRESENT	0
44225	44210	04034C	PARTICIPANT	\N	PRESENT	0
44257	44256	11026G	PARTICIPANT	\N	PRESENT	0
44259	44258	04054G	PARTICIPANT	\N	PRESENT	0
44260	44258	14175V	PARTICIPANT	\N	PRESENT	0
44261	44258	14079W	PARTICIPANT	\N	PRESENT	0
44262	44258	04055H	PARTICIPANT	\N	PRESENT	0
44263	44258	14179A	PARTICIPANT	\N	PRESENT	0
44267	44258	01048V	PARTICIPANT	\N	PRESENT	0
44265	44258	14121F	PARTICIPANT	\N	PRESENT	0
44266	44258	92031P	PARTICIPANT	\N	PRESENT	0
44268	44258	04044E	PARTICIPANT	\N	PRESENT	0
44269	44258	95062K	PARTICIPANT	\N	PRESENT	0
44270	44258	08051V	PARTICIPANT	\N	PRESENT	0
50765	49955	14327T	PARTICIPANT	\N	PRESENT	0
50766	49955	14083S	PARTICIPANT	\N	PRESENT	0
50767	49955	14195A	PARTICIPANT	\N	PRESENT	0
50768	49955	14253S	PARTICIPANT	\N	PRESENT	0
50770	49955	14273W	PARTICIPANT	\N	PRESENT	0
50772	49955	08043V	PARTICIPANT	\N	PRESENT	0
50773	49955	08065C	PARTICIPANT	\N	PRESENT	0
50776	49955	14030Q	PARTICIPANT	\N	PRESENT	0
50777	49955	08051V	PARTICIPANT	\N	PRESENT	0
50778	49955	05012A	PARTICIPANT	\N	PRESENT	0
50779	49955	14065Q	PARTICIPANT	\N	PRESENT	0
50780	49955	01022K	PARTICIPANT	\N	PRESENT	0
50781	49955	11066Q	PARTICIPANT	\N	PRESENT	0
50782	49955	10015M	PARTICIPANT	\N	PRESENT	0
50783	49955	14033T	PARTICIPANT	\N	PRESENT	0
50784	49955	80027E	PARTICIPANT	\N	PRESENT	0
50785	49955	11099A	PARTICIPANT	\N	PRESENT	0
50786	49955	08056B	PARTICIPANT	\N	PRESENT	0
50788	50787	14263U	PARTICIPANT	\N	PRESENT	0
50789	50787	14133K	PARTICIPANT	\N	PRESENT	0
50846	49955	01057W	PARTICIPANT	\N	PRESENT	0
50791	50787	04059M	PARTICIPANT	\N	PRESENT	0
50792	50787	11039M	PARTICIPANT	\N	PRESENT	0
50793	50787	01044R	PARTICIPANT	\N	PRESENT	0
50794	50787	08043V	PARTICIPANT	\N	PRESENT	0
50795	50787	14089Y	PARTICIPANT	\N	PRESENT	0
50796	50787	14105F	PARTICIPANT	\N	PRESENT	0
50797	50787	11029K	PARTICIPANT	\N	PRESENT	0
50798	50787	95015C	PARTICIPANT	\N	PRESENT	0
50799	50787	92015P	PARTICIPANT	\N	PRESENT	0
50800	50787	08024S	PARTICIPANT	\N	PRESENT	0
50801	50787	14201E	PARTICIPANT	\N	PRESENT	0
50802	50787	14329V	PARTICIPANT	\N	PRESENT	0
50803	50787	14209N	PARTICIPANT	\N	PRESENT	0
50887	49955	14215L	PARTICIPANT	\N	PRESENT	0
50805	50787	11091R	PARTICIPANT	\N	EXCUSE	0
50806	50787	87003B	PARTICIPANT	\N	PRESENT	0
50807	50787	98042T	PARTICIPANT	\N	PRESENT	0
50808	50787	14249W	PARTICIPANT	\N	PRESENT	0
50809	50787	01041N	PARTICIPANT	\N	EXCUSE	0
50971	49955	87003B	PARTICIPANT	\N	PRESENT	0
50888	49955	14105F	PARTICIPANT	\N	PRESENT	0
50812	50787	89029V	PARTICIPANT	\N	EXCUSE	0
50889	49955	14207L	PARTICIPANT	\N	PRESENT	0
50814	50787	11089X	PARTICIPANT	\N	PRESENT	0
50815	50787	07026Q	PARTICIPANT	\N	PRESENT	0
50816	50787	14123H	PARTICIPANT	\N	PRESENT	0
50817	50787	14179A	PARTICIPANT	\N	PRESENT	0
50890	49955	14087W	PARTICIPANT	\N	PRESENT	0
50819	50787	14241N	PARTICIPANT	\N	PRESENT	0
50820	50787	14061L	PARTICIPANT	\N	PRESENT	0
50821	50787	14073Q	PARTICIPANT	\N	PRESENT	0
50822	50787	08031R	PARTICIPANT	\N	PRESENT	0
50823	50787	12041X	PARTICIPANT	\N	PRESENT	0
50824	50787	08039A	PARTICIPANT	\N	PRESENT	0
50825	50787	08017T	PARTICIPANT	\N	PRESENT	0
50826	50787	14059S	PARTICIPANT	\N	PRESENT	0
50827	50787	08012N	PARTICIPANT	\N	PRESENT	0
50828	50787	14103D	PARTICIPANT	\N	PRESENT	0
50829	50787	11104D	PARTICIPANT	\N	PRESENT	0
50830	50787	14063N	PARTICIPANT	\N	EXCUSE	0
50831	50787	04057K	PARTICIPANT	\N	PRESENT	0
50832	50787	11014C	PARTICIPANT	\N	PRESENT	0
50833	50787	14109K	PARTICIPANT	\N	PRESENT	0
50834	50787	04070G	PRESIDENT	0	PRESENT	0
50835	50787	92040Q	PARTICIPANT	\N	PRESENT	0
50891	49955	14061L	PARTICIPANT	\N	PRESENT	0
50837	50787	83047W	PARTICIPANT	\N	PRESENT	0
50838	50787	14235Q	PARTICIPANT	\N	PRESENT	0
50892	49955	14026U	PARTICIPANT	\N	PRESENT	0
50840	50787	04033B	PARTICIPANT	\N	PRESENT	0
50841	50787	14229S	PARTICIPANT	\N	PRESENT	0
50842	50787	11043H	PARTICIPANT	\N	PRESENT	0
50893	49955	11012A	PARTICIPANT	\N	PRESENT	0
50894	49955	08044W	PARTICIPANT	\N	PRESENT	0
50845	49955	14051J	PARTICIPANT	\N	PRESENT	0
50895	49955	14059S	PARTICIPANT	\N	PRESENT	0
50896	49955	95035G	PARTICIPANT	\N	PRESENT	0
50897	49955	14241N	PARTICIPANT	\N	PRESENT	0
50920	50787	01037S	PARTICIPANT	\N	EXCUSE	0
50969	49955	08031R	PARTICIPANT	\N	PRESENT	0
50970	49955	07029T	PARTICIPANT	\N	PRESENT	0
50972	49955	07026Q	PARTICIPANT	\N	PRESENT	0
50973	49955	08017T	PARTICIPANT	\N	PRESENT	0
50974	49955	14265W	PARTICIPANT	\N	PRESENT	0
50975	49955	95062K	PARTICIPANT	\N	PRESENT	0
50976	49955	04078Q	PARTICIPANT	\N	PRESENT	0
50977	49955	14014Q	PARTICIPANT	\N	PRESENT	0
50978	49955	14267Y	PARTICIPANT	\N	PRESENT	0
50979	49955	14251Q	PARTICIPANT	\N	PRESENT	0
50980	49955	14157T	PARTICIPANT	\N	PRESENT	0
50981	49955	14135M	PARTICIPANT	\N	PRESENT	0
50982	49955	11043H	PARTICIPANT	\N	PRESENT	0
50984	49955	11104D	PARTICIPANT	\N	PRESENT	0
50993	49955	14173T	PARTICIPANT	\N	PRESENT	0
51014	49955	14169X	PARTICIPANT	\N	PRESENT	0
51015	49955	14111D	PARTICIPANT	\N	PRESENT	0
51016	49955	14199E	PARTICIPANT	\N	PRESENT	0
51018	49955	95067Q	PARTICIPANT	\N	PRESENT	0
51024	49955	14053L	PARTICIPANT	\N	PRESENT	0
51026	49955	04081K	PARTICIPANT	\N	PRESENT	0
51032	49955	14179A	PARTICIPANT	\N	PRESENT	0
51037	49955	01016M	PARTICIPANT	\N	PRESENT	0
51038	49955	14167V	PARTICIPANT	\N	PRESENT	0
57654	57652	11106F	PARTICIPANT	\N	PRESENT	0
57655	56793	11026G	PARTICIPANT	\N	PRESENT	0
57656	56793	14199E	PARTICIPANT	\N	PRESENT	0
57657	56793	01056V	PARTICIPANT	\N	PRESENT	0
57658	56793	07024N	PARTICIPANT	\N	PRESENT	0
57659	56793	77002U	PARTICIPANT	\N	PRESENT	0
57993	57992	14151M	PARTICIPANT	\N	PRESENT	0
57994	57992	92039X	PARTICIPANT	\N	PRESENT	0
58043	58042	05012A	PARTICIPANT	\N	PRESENT	0
58066	57516	04061F	PARTICIPANT	\N	EXCUSE	0
58094	57516	04043D	PARTICIPANT	\N	PRESENT	0
58095	57516	01058X	PARTICIPANT	\N	PRESENT	0
58146	57516	01046T	PARTICIPANT	\N	PRESENT	0
59213	59212	89017R	PARTICIPANT	\N	PRESENT	0
59214	59212	01031L	PRESIDENT	0	PRESENT	0
59215	59212	01013J	PARTICIPANT	\N	PRESENT	0
59216	59212	11068S	PARTICIPANT	\N	PRESENT	0
59217	59212	08014Q	PARTICIPANT	\N	PRESENT	0
59218	59212	14167V	PARTICIPANT	\N	PRESENT	0
59219	59212	14175V	PARTICIPANT	\N	PRESENT	0
59220	59212	11053K	PARTICIPANT	\N	PRESENT	0
59221	59212	14085U	PARTICIPANT	\N	PRESENT	0
59222	59212	11042G	PARTICIPANT	\N	PRESENT	0
59223	59212	04086Q	PARTICIPANT	\N	PRESENT	0
59224	59212	04055H	PARTICIPANT	\N	PRESENT	0
59225	59212	11070L	PARTICIPANT	\N	PRESENT	0
59226	59212	11088W	PARTICIPANT	\N	PRESENT	0
59227	59212	14327T	PARTICIPANT	\N	PRESENT	0
59228	59212	08022Q	PARTICIPANT	\N	PRESENT	0
59229	59212	01027Q	PARTICIPANT	\N	PRESENT	0
59230	59212	11083R	PARTICIPANT	\N	PRESENT	0
59231	59212	14199E	PARTICIPANT	\N	PRESENT	0
59232	59212	01057W	PARTICIPANT	\N	PRESENT	0
59233	59212	08069G	PARTICIPANT	\N	PRESENT	0
59234	59212	11048N	PARTICIPANT	\N	PRESENT	0
59235	59212	07029T	PARTICIPANT	\N	PRESENT	0
59236	59212	08010L	PARTICIPANT	\N	PRESENT	0
59237	59212	08034U	PARTICIPANT	\N	PRESENT	0
59238	59212	01048V	PARTICIPANT	\N	PRESENT	0
59239	59212	98046X	PARTICIPANT	\N	PRESENT	0
59240	59212	11085T	PARTICIPANT	\N	PRESENT	0
59241	59212	08011M	PARTICIPANT	\N	PRESENT	0
59242	59212	08073C	PARTICIPANT	\N	EXCUSE	0
59243	59212	08061X	PARTICIPANT	\N	PRESENT	0
59244	59212	01016M	PARTICIPANT	\N	PRESENT	0
59245	59212	14225N	PARTICIPANT	\N	PRESENT	0
59246	59212	11012A	PARTICIPANT	\N	PRESENT	0
59247	59212	11057P	PARTICIPANT	\N	PRESENT	0
59248	59212	14173T	PARTICIPANT	\N	PRESENT	0
59249	59212	04034C	PARTICIPANT	\N	PRESENT	0
59409	54852	14063N	PARTICIPANT	\N	EXCUSE	0
59649	59648	11076S	PARTICIPANT	\N	PRESENT	0
59650	59648	04054G	PARTICIPANT	\N	PRESENT	0
59651	59648	04040A	PARTICIPANT	\N	PRESENT	0
59652	59648	08058D	PARTICIPANT	\N	PRESENT	0
59653	59648	77002U	PARTICIPANT	\N	PRESENT	0
59654	59648	98029W	PARTICIPANT	\N	PRESENT	0
59655	59648	11027H	PARTICIPANT	\N	PRESENT	0
59682	59648	98018T	PARTICIPANT	\N	PRESENT	0
59684	59648	92020L	PARTICIPANT	\N	PRESENT	0
59685	59648	11096W	PARTICIPANT	\N	PRESENT	0
59686	59648	97011G	PARTICIPANT	\N	PRESENT	0
59696	59648	04035D	PARTICIPANT	\N	PRESENT	0
59698	59648	07024N	PARTICIPANT	\N	PRESENT	0
59699	59648	14014Q	PARTICIPANT	\N	EXCUSE	0
59700	59648	11015D	PARTICIPANT	\N	PRESENT	0
59701	59648	07004J	PARTICIPANT	\N	PRESENT	0
59703	59648	95035G	PARTICIPANT	\N	PRESENT	0
59704	59648	08056B	PARTICIPANT	\N	PRESENT	0
59705	59648	14211G	PARTICIPANT	\N	PRESENT	0
59706	59648	98022P	PARTICIPANT	\N	PRESENT	0
59708	59648	95037J	PARTICIPANT	\N	PRESENT	0
59709	59648	14097Y	PARTICIPANT	\N	PRESENT	0
59710	59648	95041E	PARTICIPANT	\N	PRESENT	0
59711	59648	04036E	PARTICIPANT	\N	PRESENT	0
59712	59648	04077P	PARTICIPANT	\N	PRESENT	0
59713	59648	92031P	PARTICIPANT	\N	PRESENT	0
59714	59648	11106F	PARTICIPANT	\N	PRESENT	0
59715	59648	14251Q	PARTICIPANT	\N	PRESENT	0
59716	59648	83042R	PARTICIPANT	\N	PRESENT	0
59717	59648	08053X	PARTICIPANT	\N	PRESENT	0
59718	59648	11082Q	PARTICIPANT	\N	PRESENT	0
59719	59648	11105E	PARTICIPANT	\N	PRESENT	0
59721	59648	14253S	PARTICIPANT	\N	PRESENT	0
59722	59648	08047A	PARTICIPANT	\N	PRESENT	0
59723	59648	14028W	PARTICIPANT	\N	PRESENT	0
59724	59648	14193X	PARTICIPANT	\N	PRESENT	0
59725	59648	98021N	PARTICIPANT	\N	PRESENT	0
59726	59648	11069T	PARTICIPANT	\N	PRESENT	0
59727	59648	04080J	PARTICIPANT	\N	PRESENT	0
59728	59648	95059Q	PRESIDENT	0	PRESENT	0
59729	59648	86044G	PARTICIPANT	\N	PRESENT	0
59730	59648	01014K	PARTICIPANT	\N	PRESENT	0
59731	59648	11054L	PARTICIPANT	\N	EXCUSE	0
59732	59648	01056V	PARTICIPANT	\N	PRESENT	0
59733	59648	92044U	PARTICIPANT	\N	PRESENT	0
59734	59648	08049C	PARTICIPANT	\N	PRESENT	0
59735	59648	14133K	PARTICIPANT	\N	PRESENT	0
59736	59648	04045F	PARTICIPANT	\N	PRESENT	0
59737	59648	08018U	PARTICIPANT	\N	PRESENT	0
59738	59648	04034C	PARTICIPANT	\N	PRESENT	0
59739	59648	04061F	PARTICIPANT	\N	PRESENT	0
59740	59648	14073Q	PARTICIPANT	\N	PRESENT	0
59742	59648	14089Y	PARTICIPANT	\N	PRESENT	0
59744	59648	04057K	PARTICIPANT	\N	PRESENT	0
59745	59648	92045V	PARTICIPANT	\N	PRESENT	0
59776	59775	01008M	PARTICIPANT	\N	PRESENT	0
59777	59775	11094U	PARTICIPANT	\N	PRESENT	0
59778	59775	08062Y	PARTICIPANT	\N	PRESENT	0
59781	59775	01015L	PARTICIPANT	\N	EXCUSE	0
59783	59775	08012N	PARTICIPANT	\N	EXCUSE	0
59784	59775	08028W	PARTICIPANT	\N	EXCUSE	0
59786	59775	14179A	PARTICIPANT	\N	EXCUSE	0
59788	59775	01061S	PARTICIPANT	\N	EXCUSE	0
46165	46077	11015D	PARTICIPANT	\N	PRESENT	0
46166	46077	07004J	PARTICIPANT	\N	EXCUSE	0
46167	46077	11064N	PARTICIPANT	\N	PRESENT	0
46168	46077	95037J	PARTICIPANT	\N	PRESENT	0
46169	46077	04078Q	PARTICIPANT	\N	PRESENT	0
46170	46077	04036E	PARTICIPANT	\N	PRESENT	0
46172	46077	98005N	PARTICIPANT	\N	PRESENT	0
46173	46077	92031P	PARTICIPANT	\N	PRESENT	0
46174	46077	11106F	PARTICIPANT	\N	PRESENT	0
46175	46077	14251Q	PARTICIPANT	\N	PRESENT	0
46176	46077	83042R	PARTICIPANT	\N	EXCUSE	0
46177	46077	14253S	PARTICIPANT	\N	PRESENT	0
46178	46077	08047A	PARTICIPANT	\N	PRESENT	0
46179	46077	14193X	PARTICIPANT	\N	PRESENT	0
46180	46077	98021N	PARTICIPANT	\N	PRESENT	0
46181	46077	11069T	PARTICIPANT	\N	PRESENT	0
46182	46077	04080J	PARTICIPANT	\N	PRESENT	0
46183	46077	95059Q	PRESIDENT	0	PRESENT	0
46184	46077	86044G	PARTICIPANT	\N	PRESENT	0
46185	46077	01014K	PARTICIPANT	\N	PRESENT	0
46186	46077	11054L	PARTICIPANT	\N	PRESENT	0
46187	46077	01056V	PARTICIPANT	\N	PRESENT	0
46188	46077	92044U	PARTICIPANT	\N	PRESENT	0
46201	46077	04077P	PARTICIPANT	\N	PRESENT	0
46236	46235	04040A	PRESIDENT	0	PRESENT	0
46237	46077	95035G	PARTICIPANT	\N	PRESENT	0
46238	46235	14028W	PARTICIPANT	\N	PRESENT	0
46239	46235	05012A	PARTICIPANT	\N	PRESENT	0
46240	46235	11034G	PARTICIPANT	\N	PRESENT	0
46241	46235	11101A	PARTICIPANT	\N	PRESENT	0
46242	46235	08034U	PARTICIPANT	\N	PRESENT	0
46243	46235	11035H	PARTICIPANT	\N	PRESENT	0
46244	46235	11074Q	PARTICIPANT	\N	PRESENT	0
46245	46235	14231L	PARTICIPANT	\N	PRESENT	0
46246	46235	14063N	PARTICIPANT	\N	PRESENT	0
46247	46235	14051J	PARTICIPANT	\N	PRESENT	0
46248	46235	95067Q	PARTICIPANT	\N	PRESENT	0
46249	46235	01057W	PARTICIPANT	\N	PRESENT	0
46250	46235	08010L	PARTICIPANT	\N	PRESENT	0
46251	46235	11037K	PARTICIPANT	\N	PRESENT	0
46252	46235	11112D	PARTICIPANT	\N	PRESENT	0
46253	46235	14327T	PARTICIPANT	\N	PRESENT	0
46254	46235	14034U	PARTICIPANT	\N	PRESENT	0
46255	46235	01027Q	PARTICIPANT	\N	PRESENT	0
46256	46235	92040Q	PARTICIPANT	\N	PRESENT	0
46257	46235	11098Y	PARTICIPANT	\N	PRESENT	0
46258	46235	04044E	PARTICIPANT	\N	PRESENT	0
46259	46235	04086Q	PARTICIPANT	\N	PRESENT	0
46260	46235	11099A	PARTICIPANT	\N	PRESENT	0
46424	46422	01031L	PRESIDENT	0	PRESENT	0
46425	46422	01013J	PARTICIPANT	\N	PRESENT	0
46426	46422	11068S	PARTICIPANT	\N	PRESENT	0
46428	46422	08014Q	PARTICIPANT	\N	PRESENT	0
46431	46422	14175V	PARTICIPANT	\N	PRESENT	0
46432	46422	14085U	PARTICIPANT	\N	PRESENT	0
46433	46422	11042G	PARTICIPANT	\N	PRESENT	0
46434	46422	88008L	PARTICIPANT	\N	PRESENT	0
46436	46422	04086Q	PARTICIPANT	\N	PRESENT	0
46439	46422	11070L	PARTICIPANT	\N	PRESENT	0
46441	46422	11088W	PARTICIPANT	\N	PRESENT	0
46443	46422	98053W	PARTICIPANT	\N	EXCUSE	0
46445	46422	11083R	PARTICIPANT	\N	PRESENT	0
46446	46422	01057W	PARTICIPANT	\N	PRESENT	0
46448	46422	11048N	PARTICIPANT	\N	PRESENT	0
46449	46422	99004R	PARTICIPANT	\N	PRESENT	0
46450	46422	14159V	PARTICIPANT	\N	PRESENT	0
46451	46422	07029T	PARTICIPANT	\N	PRESENT	0
46452	46422	08010L	PARTICIPANT	\N	PRESENT	0
46453	46422	08034U	PARTICIPANT	\N	PRESENT	0
46455	46422	98046X	PARTICIPANT	\N	PRESENT	0
46456	46422	08011M	PARTICIPANT	\N	PRESENT	0
46457	46422	08061X	PARTICIPANT	\N	PRESENT	0
46458	46422	01016M	PARTICIPANT	\N	PRESENT	0
46459	46422	14225N	PARTICIPANT	\N	PRESENT	0
47339	44248	01046T	PARTICIPANT	\N	EXCUSE	0
47341	44248	11036J	PARTICIPANT	\N	EXCUSE	0
47342	44248	08069G	PARTICIPANT	\N	EXCUSE	0
47581	47336	86044G	PARTICIPANT	\N	PRESENT	0
47584	47336	11054L	PARTICIPANT	\N	PRESENT	0
47277	47264	89017R	PARTICIPANT	\N	PRESENT	0
47278	47264	11039M	PARTICIPANT	\N	PRESENT	0
47279	47264	08055A	PARTICIPANT	\N	PRESENT	0
47280	47264	04066L	PARTICIPANT	\N	PRESENT	0
47281	47264	04042C	PARTICIPANT	\N	PRESENT	0
47585	47336	01056V	PARTICIPANT	\N	PRESENT	0
47283	47264	04081K	PARTICIPANT	\N	PRESENT	0
47284	47264	04067M	PARTICIPANT	\N	PRESENT	0
47285	47264	98042T	PARTICIPANT	\N	PRESENT	0
47593	47336	11026G	PARTICIPANT	\N	EXCUSE	0
47287	47264	01003G	PARTICIPANT	\N	PRESENT	0
47288	47264	98053W	PARTICIPANT	\N	PRESENT	0
47289	47264	89029V	PARTICIPANT	\N	PRESENT	0
47290	47264	08048B	PARTICIPANT	\N	PRESENT	0
47291	47264	01007L	PARTICIPANT	\N	PRESENT	0
47292	47264	95037J	PARTICIPANT	\N	PRESENT	0
47293	47264	86034E	PARTICIPANT	\N	PRESENT	0
47631	43531	08010L	PARTICIPANT	\N	EXCUSE	0
47297	47264	11085T	PARTICIPANT	\N	PRESENT	0
47298	47264	04057K	PARTICIPANT	\N	PRESENT	0
47300	47264	04088S	PARTICIPANT	\N	PRESENT	0
47301	47264	01019Q	PARTICIPANT	\N	PRESENT	0
47665	47664	01031L	PRESIDENT	0	PRESENT	0
47666	47664	01013J	PARTICIPANT	\N	PRESENT	0
47667	47664	14175V	PARTICIPANT	\N	PRESENT	0
47668	47664	11053K	PARTICIPANT	\N	PRESENT	0
47669	47664	11042G	PARTICIPANT	\N	PRESENT	0
47670	47664	04086Q	PARTICIPANT	\N	PRESENT	0
47671	47664	11088W	PARTICIPANT	\N	PRESENT	0
47672	47664	11083R	PARTICIPANT	\N	PRESENT	0
47673	47664	01057W	PARTICIPANT	\N	PRESENT	0
47674	47664	11048N	PARTICIPANT	\N	PRESENT	0
47675	47664	99004R	PARTICIPANT	\N	PRESENT	0
47676	47664	07029T	PARTICIPANT	\N	PRESENT	0
47677	47664	08034U	PARTICIPANT	\N	PRESENT	0
47678	47664	98046X	PARTICIPANT	\N	PRESENT	0
47679	47664	08011M	PARTICIPANT	\N	PRESENT	0
47680	47664	01016M	PARTICIPANT	\N	PRESENT	0
47681	47664	11012A	PARTICIPANT	\N	PRESENT	0
47682	47664	04034C	PARTICIPANT	\N	PRESENT	0
47863	47794	04066L	PARTICIPANT	\N	PRESENT	0
47864	47794	14269B	PARTICIPANT	\N	PRESENT	0
47865	47794	11112D	PARTICIPANT	\N	PRESENT	0
47866	47794	11093T	PARTICIPANT	\N	PRESENT	0
47867	47794	11061K	PARTICIPANT	\N	PRESENT	0
47868	47794	04053F	PARTICIPANT	\N	PRESENT	0
47869	47794	04092N	PARTICIPANT	\N	PRESENT	0
47870	47794	04067M	PARTICIPANT	\N	PRESENT	0
47871	47794	11031D	PARTICIPANT	\N	PRESENT	0
47872	47794	01046T	PARTICIPANT	\N	PRESENT	0
47873	47794	11063M	PARTICIPANT	\N	PRESENT	0
47874	47794	04043D	PARTICIPANT	\N	PRESENT	0
47875	47794	14173T	PARTICIPANT	\N	PRESENT	0
47876	47794	08052W	PARTICIPANT	\N	PRESENT	0
47877	47794	14271U	PARTICIPANT	\N	PRESENT	0
47878	47794	14042U	PARTICIPANT	\N	PRESENT	0
47879	47794	10006L	PARTICIPANT	\N	PRESENT	0
47880	47794	14213J	PARTICIPANT	\N	PRESENT	0
47881	47794	14037X	PARTICIPANT	\N	PRESENT	0
47882	47794	11012A	PARTICIPANT	\N	PRESENT	0
47883	47794	11055M	PARTICIPANT	\N	PRESENT	0
47907	47796	04092N	PARTICIPANT	\N	PRESENT	0
47908	47796	14213J	PARTICIPANT	\N	PRESENT	0
47909	47796	14037X	PARTICIPANT	\N	PRESENT	0
47910	47796	14042U	PARTICIPANT	\N	PRESENT	0
47911	47796	11093T	PARTICIPANT	\N	PRESENT	0
47912	47796	01046T	PARTICIPANT	\N	PRESENT	0
47913	47796	11061K	PARTICIPANT	\N	PRESENT	0
47914	47796	14271U	PARTICIPANT	\N	PRESENT	0
47915	47796	04053F	PARTICIPANT	\N	PRESENT	0
47916	47796	08052W	PARTICIPANT	\N	PRESENT	0
47917	47796	14269B	PARTICIPANT	\N	PRESENT	0
47918	47796	11112D	PARTICIPANT	\N	PRESENT	0
47919	47796	04043D	PARTICIPANT	\N	PRESENT	0
47920	47796	11031D	PARTICIPANT	\N	PRESENT	0
47921	47796	11063M	PARTICIPANT	\N	PRESENT	0
47922	47796	11055M	PARTICIPANT	\N	PRESENT	0
47925	47796	00003C	PARTICIPANT	\N	PRESENT	0
47926	47796	11012A	PARTICIPANT	\N	PRESENT	0
47948	47947	11039M	PARTICIPANT	\N	PRESENT	0
47949	47947	98042T	PARTICIPANT	\N	PRESENT	0
47950	47947	01019Q	PARTICIPANT	\N	PRESENT	0
47905	47796	04066L	PARTICIPANT	\N	PRESENT	0
47906	47796	10006L	PARTICIPANT	\N	PRESENT	0
47952	47951	14069U	PARTICIPANT	\N	PRESENT	0
60593	60592	98005N	PARTICIPANT	\N	EXCUSE	0
60618	60617	07024N	PARTICIPANT	\N	PRESENT	0
60619	60617	04043D	PARTICIPANT	\N	PRESENT	0
61180	60620	08034U	PARTICIPANT	\N	PRESENT	0
61181	60620	11084S	PARTICIPANT	\N	PRESENT	0
61182	60620	05012A	PARTICIPANT	\N	PRESENT	0
61183	61122	14079W	PARTICIPANT	\N	PRESENT	0
61184	61122	14329V	PARTICIPANT	\N	PRESENT	0
61185	60620	11095V	PARTICIPANT	\N	PRESENT	0
61192	60621	14041T	PARTICIPANT	\N	PRESENT	0
61193	60621	07034Q	PARTICIPANT	\N	PRESENT	0
61194	60621	08052W	PARTICIPANT	\N	PRESENT	0
61195	60621	11035H	PARTICIPANT	\N	PRESENT	0
61190	60621	86034E	PARTICIPANT	\N	PRESENT	0
61191	60621	95049N	PARTICIPANT	\N	PRESENT	0
61196	60621	07024N	PARTICIPANT	\N	PRESENT	0
61197	60621	14227Q	PARTICIPANT	\N	PRESENT	0
61198	60621	14235Q	PARTICIPANT	\N	PRESENT	0
61199	60621	07026Q	PARTICIPANT	\N	PRESENT	0
61200	60621	14051J	PARTICIPANT	\N	PRESENT	0
61201	60621	11010L	PARTICIPANT	\N	PRESENT	0
61202	60621	04092N	PARTICIPANT	\N	PRESENT	0
61203	60621	04048J	PARTICIPANT	\N	PRESENT	0
61204	60621	11061K	PARTICIPANT	\N	PRESENT	0
61205	60621	01022K	PARTICIPANT	\N	PRESENT	0
61206	60621	11107G	PARTICIPANT	\N	PRESENT	0
61207	60621	14269B	PARTICIPANT	\N	PRESENT	0
61208	60621	14107H	PARTICIPANT	\N	PRESENT	0
61209	60621	11088W	PARTICIPANT	\N	PRESENT	0
61210	60621	08069G	PARTICIPANT	\N	PRESENT	0
61211	60621	11037K	PARTICIPANT	\N	PRESENT	0
61212	60621	11063M	PARTICIPANT	\N	PRESENT	0
61213	60621	14013P	PARTICIPANT	\N	PRESENT	0
61214	60621	04077P	PARTICIPANT	\N	PRESENT	0
61215	60621	04053F	PARTICIPANT	\N	PRESENT	0
61216	60621	90003B	PARTICIPANT	\N	PRESENT	0
61217	60621	13002U	PARTICIPANT	\N	PRESENT	0
61218	60621	11103C	PARTICIPANT	\N	PRESENT	0
61219	60621	11044J	PARTICIPANT	\N	PRESENT	0
61220	60621	14061L	PARTICIPANT	\N	PRESENT	0
61222	60621	04088S	PARTICIPANT	\N	PRESENT	0
61223	61221	14239U	PARTICIPANT	\N	PRESENT	0
61225	61224	14135M	PARTICIPANT	\N	PRESENT	0
61226	60621	08016S	PARTICIPANT	\N	PRESENT	0
61227	60621	95063L	PARTICIPANT	\N	PRESENT	0
61228	60621	08055A	PARTICIPANT	\N	PRESENT	0
61229	60621	11067R	PARTICIPANT	\N	PRESENT	0
61230	60621	14014Q	PARTICIPANT	\N	PRESENT	0
61231	60621	11014C	PARTICIPANT	\N	PRESENT	0
61232	60621	14207L	PARTICIPANT	\N	PRESENT	0
61233	60621	14197C	PARTICIPANT	\N	PRESENT	0
61234	60621	11015D	PARTICIPANT	\N	PRESENT	0
61235	60621	95037J	PARTICIPANT	\N	PRESENT	0
61236	60621	11026G	PARTICIPANT	\N	PRESENT	0
61237	60621	14121F	PARTICIPANT	\N	PRESENT	0
61238	60621	04045F	PARTICIPANT	\N	PRESENT	0
61239	60621	11066Q	PARTICIPANT	\N	PRESENT	0
61240	60621	14085U	PARTICIPANT	\N	PRESENT	0
61241	60621	11033F	PARTICIPANT	\N	PRESENT	0
61242	60621	14159V	PARTICIPANT	\N	PRESENT	0
61243	60621	08073C	PARTICIPANT	\N	PRESENT	0
61244	60621	12042Y	PARTICIPANT	\N	PRESENT	0
61245	60621	11042G	PARTICIPANT	\N	PRESENT	0
61246	60621	11077T	PARTICIPANT	\N	PRESENT	0
61247	60621	14028W	PARTICIPANT	\N	PRESENT	0
61248	60621	14271U	PARTICIPANT	\N	PRESENT	0
61249	60621	11083R	PARTICIPANT	\N	PRESENT	0
61250	60621	11084S	PARTICIPANT	\N	PRESENT	0
61251	60621	14225N	PARTICIPANT	\N	PRESENT	0
61252	60621	01028R	PARTICIPANT	\N	PRESENT	0
61253	60621	04038G	PARTICIPANT	\N	PRESENT	0
61254	60621	08031R	PARTICIPANT	\N	PRESENT	0
61255	60621	08058D	PARTICIPANT	\N	PRESENT	0
61256	60621	14281W	PARTICIPANT	\N	PRESENT	0
61257	60621	11031D	PARTICIPANT	\N	PRESENT	0
61258	60621	04085P	PARTICIPANT	\N	PRESENT	0
61259	60621	98053W	PARTICIPANT	\N	PRESENT	0
61260	60621	12041X	PARTICIPANT	\N	PRESENT	0
61261	60621	04080J	PARTICIPANT	\N	PRESENT	0
61262	60621	14030Q	PARTICIPANT	\N	PRESENT	0
61263	60621	14221J	PARTICIPANT	\N	PRESENT	0
61264	60621	14231L	PARTICIPANT	\N	PRESENT	0
61265	60621	07004J	PARTICIPANT	\N	PRESENT	0
61266	60621	01047U	PARTICIPANT	\N	PRESENT	0
61267	60621	01025N	PARTICIPANT	\N	PRESENT	0
61268	60621	01043Q	PARTICIPANT	\N	PRESENT	0
61269	60621	11029K	PARTICIPANT	\N	PRESENT	0
61270	60621	98029W	PARTICIPANT	\N	PRESENT	0
61271	60621	14327T	PARTICIPANT	\N	PRESENT	0
61272	60621	04061F	PARTICIPANT	\N	PRESENT	0
61273	60621	14087W	PARTICIPANT	\N	PRESENT	0
61274	60621	14215L	PARTICIPANT	\N	PRESENT	0
61275	60621	11039M	PARTICIPANT	\N	PRESENT	0
61276	60621	11089X	PARTICIPANT	\N	PRESENT	0
61277	60621	11112D	PARTICIPANT	\N	PRESENT	0
61278	60621	11081P	PARTICIPANT	\N	PRESENT	0
61279	60621	14267Y	PARTICIPANT	\N	PRESENT	0
61280	60621	01034P	PARTICIPANT	\N	PRESENT	0
61281	60621	92031P	PARTICIPANT	\N	PRESENT	0
61282	60621	11065P	PARTICIPANT	\N	PRESENT	0
61283	60621	14069U	PARTICIPANT	\N	PRESENT	0
61284	60621	04033B	PARTICIPANT	\N	PRESENT	0
61285	60621	10006L	PARTICIPANT	\N	PRESENT	0
61286	60621	04086Q	PARTICIPANT	\N	PRESENT	0
61287	60621	92020L	PARTICIPANT	\N	PRESENT	0
61288	60621	04043D	PARTICIPANT	\N	PRESENT	0
61289	60621	14063N	PARTICIPANT	\N	PRESENT	0
61290	60621	11076S	PARTICIPANT	\N	PRESENT	0
61291	60621	08068F	PARTICIPANT	\N	PRESENT	0
61292	60621	11074Q	PARTICIPANT	\N	PRESENT	0
61293	60621	04081K	PARTICIPANT	\N	PRESENT	0
61294	60621	04057K	PARTICIPANT	\N	PRESENT	0
61295	60621	14026U	PARTICIPANT	\N	PRESENT	0
61296	60621	14209N	PARTICIPANT	\N	PRESENT	0
61297	60621	14247U	PARTICIPANT	\N	PRESENT	0
61298	60621	01008M	PARTICIPANT	\N	PRESENT	0
61299	60621	14109K	PARTICIPANT	\N	PRESENT	0
61300	60621	14151M	PARTICIPANT	\N	PRESENT	0
61301	60621	95059Q	PARTICIPANT	\N	PRESENT	0
61302	60621	08043V	PARTICIPANT	\N	PRESENT	0
61303	60621	08017T	PARTICIPANT	\N	PRESENT	0
61304	60621	04035D	PARTICIPANT	\N	PRESENT	0
61305	60621	08022Q	PARTICIPANT	\N	PRESENT	0
61306	60621	01027Q	PARTICIPANT	\N	PRESENT	0
61307	60621	01058X	PARTICIPANT	\N	PRESENT	0
61308	60621	14103D	PARTICIPANT	\N	PRESENT	0
61309	60621	14059S	PARTICIPANT	\N	PRESENT	0
61310	60621	14033T	PARTICIPANT	\N	PRESENT	0
61311	60621	86044G	PARTICIPANT	\N	PRESENT	0
61312	60621	04036E	PARTICIPANT	\N	PRESENT	0
61313	60621	99004R	PARTICIPANT	\N	PRESENT	0
61314	60621	08028W	PARTICIPANT	\N	PRESENT	0
61315	60621	01019Q	PARTICIPANT	\N	PRESENT	0
61316	60621	08039A	PARTICIPANT	\N	PRESENT	0
61317	60621	14211G	PARTICIPANT	\N	PRESENT	0
61318	60621	95062K	PARTICIPANT	\N	PRESENT	0
61319	60621	01057W	PARTICIPANT	\N	PRESENT	0
61320	60621	11080N	PARTICIPANT	\N	PRESENT	0
61321	60621	14195A	PARTICIPANT	\N	PRESENT	0
61322	60621	14175V	PARTICIPANT	\N	PRESENT	0
61323	60621	11049P	PARTICIPANT	\N	PRESENT	0
61324	60621	87003B	PARTICIPANT	\N	PRESENT	0
61325	60621	04042C	PARTICIPANT	\N	PRESENT	0
61326	60621	01048V	PARTICIPANT	\N	PRESENT	0
61327	60621	14223L	PARTICIPANT	\N	PRESENT	0
61328	60621	05012A	PARTICIPANT	\N	PRESENT	0
61329	60621	11048N	PARTICIPANT	\N	PRESENT	0
61330	60621	14241N	PARTICIPANT	\N	PRESENT	0
61331	60621	11097X	PARTICIPANT	\N	PRESENT	0
61332	60621	08034U	PARTICIPANT	\N	PRESENT	0
61333	60621	14147R	PARTICIPANT	\N	PRESENT	0
61334	60621	14265W	PARTICIPANT	\N	PRESENT	0
61335	60621	11091R	PARTICIPANT	\N	PRESENT	0
61336	60621	14135M	PARTICIPANT	\N	PRESENT	0
61337	60621	04049K	PARTICIPANT	\N	PRESENT	0
61338	60621	08015R	PARTICIPANT	\N	PRESENT	0
61339	60621	14213J	PARTICIPANT	\N	PRESENT	0
61340	60621	08065C	PARTICIPANT	\N	PRESENT	0
61341	60621	14187A	PARTICIPANT	\N	PRESENT	0
61342	60621	14031R	PARTICIPANT	\N	PRESENT	0
61343	60621	14173T	PARTICIPANT	\N	PRESENT	0
61344	60621	14038Y	PARTICIPANT	\N	PRESENT	0
61345	60621	14229S	PARTICIPANT	\N	PRESENT	0
61346	60621	04056J	PARTICIPANT	\N	PRESENT	0
61347	60621	11095V	PARTICIPANT	\N	PRESENT	0
61348	60621	14201E	PARTICIPANT	\N	PRESENT	0
61349	60621	08049C	PARTICIPANT	\N	PRESENT	0
61350	60621	08044W	PARTICIPANT	\N	PRESENT	0
30852	28658	05012A	PARTICIPANT	\N	PRESENT	0
30854	28658	14051J	PARTICIPANT	\N	PRESENT	0
30856	28658	11037K	PARTICIPANT	\N	PRESENT	0
30860	28658	11112D	PARTICIPANT	\N	PRESENT	0
30862	28658	11074Q	PARTICIPANT	\N	PRESENT	0
30864	28658	11099A	PARTICIPANT	\N	PRESENT	0
30865	28658	01027Q	PARTICIPANT	\N	PRESENT	0
30867	28658	95067Q	PARTICIPANT	\N	PRESENT	0
30871	28658	01057W	PARTICIPANT	\N	PRESENT	0
30873	28658	08010L	PARTICIPANT	\N	PRESENT	0
30894	30893	14133K	PARTICIPANT	\N	PRESENT	0
30895	30893	04054G	PARTICIPANT	\N	EXCUSE	0
30896	30893	96004D	PRESIDENT	0	PRESENT	0
30897	30893	11040E	PARTICIPANT	\N	PRESENT	0
30898	30893	14089Y	PARTICIPANT	\N	PRESENT	0
30899	30893	90003B	PARTICIPANT	\N	EXCUSE	0
30900	30893	11035H	PARTICIPANT	\N	PRESENT	0
30901	30893	95030B	PARTICIPANT	\N	PRESENT	0
30902	30893	08018U	PARTICIPANT	\N	PRESENT	0
30903	30893	14026U	PARTICIPANT	\N	EXCUSE	0
30904	30893	14097Y	PARTICIPANT	\N	EXCUSE	0
30905	30893	04061F	PARTICIPANT	\N	PRESENT	0
30906	30893	14073Q	PARTICIPANT	\N	PRESENT	0
30907	30893	11026G	PARTICIPANT	\N	EXCUSE	0
30908	30893	98046X	PARTICIPANT	\N	PRESENT	0
30909	30893	14001X	PARTICIPANT	\N	PRESENT	0
30910	30893	04057K	PARTICIPANT	\N	PRESENT	0
30911	30893	08021P	PARTICIPANT	\N	EXCUSE	0
30912	30893	08042U	PARTICIPANT	\N	PRESENT	0
30913	30893	08073C	PARTICIPANT	\N	EXCUSE	0
30914	30893	14135M	PARTICIPANT	\N	PRESENT	0
30915	30893	01016M	PARTICIPANT	\N	PRESENT	0
30916	30893	10015M	PARTICIPANT	\N	EXCUSE	0
30917	30893	95063L	PARTICIPANT	\N	PRESENT	0
30918	30893	04045F	PARTICIPANT	\N	EXCUSE	0
30919	30893	04034C	PARTICIPANT	\N	PRESENT	0
31106	28666	01058X	PARTICIPANT	\N	EXCUSE	0
31183	31182	11103C	PRESIDENT	0	PRESENT	0
31184	31182	08052W	PARTICIPANT	\N	PRESENT	0
31185	31182	01059Y	PARTICIPANT	\N	PRESENT	0
31186	31182	14151M	PARTICIPANT	\N	PRESENT	0
31187	31182	12042Y	PARTICIPANT	\N	PRESENT	0
31188	31182	14071N	PARTICIPANT	\N	PRESENT	0
31189	31182	11093T	PARTICIPANT	\N	PRESENT	0
31190	31182	01034P	PARTICIPANT	\N	PRESENT	0
31191	31182	14271U	PARTICIPANT	\N	PRESENT	0
31192	31182	14265W	PARTICIPANT	\N	PRESENT	0
31193	31182	04092N	PARTICIPANT	\N	EXCUSE	0
31194	31182	11097X	PARTICIPANT	\N	EXCUSE	0
40902	40901	96004D	PARTICIPANT	\N	EXCUSE	0
40903	40901	11064N	PARTICIPANT	\N	EXCUSE	0
40904	40901	14093U	PARTICIPANT	\N	EXCUSE	0
40906	40905	04059M	PARTICIPANT	\N	PRESENT	0
40908	40907	92040Q	PARTICIPANT	\N	PRESENT	0
40910	40909	95015C	PARTICIPANT	\N	PRESENT	0
40912	40911	11104D	PARTICIPANT	\N	PRESENT	0
40914	40913	95015C	PARTICIPANT	\N	PRESENT	0
40916	40915	95015C	PARTICIPANT	\N	PRESENT	0
40918	40917	95015C	PARTICIPANT	\N	PRESENT	0
40920	40919	14263U	PARTICIPANT	\N	PRESENT	0
40922	40921	04057K	PARTICIPANT	\N	PRESENT	0
40924	40923	14103D	PARTICIPANT	\N	PRESENT	0
40926	40925	08012N	PARTICIPANT	\N	PRESENT	0
40928	40927	08012N	PARTICIPANT	\N	PRESENT	0
40930	40929	11089X	PARTICIPANT	\N	PRESENT	0
40932	40931	04059M	PARTICIPANT	\N	PRESENT	0
40934	40933	04059M	PARTICIPANT	\N	PRESENT	0
40936	40935	08017T	PARTICIPANT	\N	PRESENT	0
40938	40937	08017T	PARTICIPANT	\N	PRESENT	0
40940	40939	04059M	PARTICIPANT	\N	PRESENT	0
40942	40941	08012N	PARTICIPANT	\N	PRESENT	0
40944	40943	08017T	PARTICIPANT	\N	PRESENT	0
40946	40945	95015C	PARTICIPANT	\N	PRESENT	0
40947	40945	08031R	PARTICIPANT	\N	PRESENT	0
40949	40948	08039A	PARTICIPANT	\N	PRESENT	0
40951	40950	95015C	PARTICIPANT	\N	PRESENT	0
40952	40950	08031R	PARTICIPANT	\N	PRESENT	0
40954	40953	08017T	PARTICIPANT	\N	PRESENT	0
40956	40955	95015C	PARTICIPANT	\N	PRESENT	0
40957	40955	08031R	PARTICIPANT	\N	PRESENT	0
40959	40958	95015C	PARTICIPANT	\N	PRESENT	0
40960	40958	08031R	PARTICIPANT	\N	PRESENT	0
40962	40961	95015C	PARTICIPANT	\N	PRESENT	0
40963	40961	08031R	PARTICIPANT	\N	PRESENT	0
43586	43585	14133K	PARTICIPANT	\N	PRESENT	0
43587	43585	11040E	PARTICIPANT	\N	PRESENT	0
43588	43585	96004D	PRESIDENT	0	PRESENT	0
43589	43585	14089Y	PARTICIPANT	\N	PRESENT	0
43590	43585	95030B	PARTICIPANT	\N	EXCUSE	0
43591	43585	11083R	PARTICIPANT	\N	PRESENT	0
43592	43585	14026U	PARTICIPANT	\N	EXCUSE	0
43593	43585	14097Y	PARTICIPANT	\N	PRESENT	0
43594	43585	04061F	PARTICIPANT	\N	PRESENT	0
43595	43585	14073Q	PARTICIPANT	\N	PRESENT	0
43596	43585	98046X	PARTICIPANT	\N	PRESENT	0
43597	43585	04057K	PARTICIPANT	\N	PRESENT	0
43598	43585	95049N	PARTICIPANT	\N	EXCUSE	0
43599	43585	08021P	PARTICIPANT	\N	EXCUSE	0
43600	43585	14135M	PARTICIPANT	\N	PRESENT	0
43601	43585	04045F	PARTICIPANT	\N	EXCUSE	0
43602	43585	98035U	PARTICIPANT	\N	PRESENT	0
43603	43585	92045V	PARTICIPANT	\N	PRESENT	0
43604	43585	04034C	PARTICIPANT	\N	PRESENT	0
43605	43585	08073C	PARTICIPANT	\N	EXCUSE	0
51039	49955	14073Q	PARTICIPANT	\N	PRESENT	0
51045	49955	14209N	PARTICIPANT	\N	PRESENT	0
51046	49955	11029K	PARTICIPANT	\N	PRESENT	0
59883	59882	01016M	PARTICIPANT	\N	PRESENT	0
59890	59889	11027H	PARTICIPANT	\N	PRESENT	0
59891	59889	92039X	PARTICIPANT	\N	PRESENT	0
59892	59889	01016M	PARTICIPANT	\N	PRESENT	0
59893	59889	14199E	PARTICIPANT	\N	PRESENT	0
59936	59935	11076S	PARTICIPANT	\N	PRESENT	0
59937	59935	04054G	PARTICIPANT	\N	PRESENT	0
59938	59935	04040A	PARTICIPANT	\N	PRESENT	0
59939	59935	08058D	PARTICIPANT	\N	PRESENT	0
59995	59993	11076S	PARTICIPANT	\N	PRESENT	0
59941	59935	77002U	PARTICIPANT	\N	PRESENT	0
59942	59935	98029W	PARTICIPANT	\N	PRESENT	0
59996	59993	04054G	PARTICIPANT	\N	PRESENT	0
59944	59935	11027H	PARTICIPANT	\N	PRESENT	0
59945	59935	98018T	PARTICIPANT	\N	PRESENT	0
59997	59993	04040A	PARTICIPANT	\N	PRESENT	0
59947	59935	92020L	PARTICIPANT	\N	PRESENT	0
59998	59993	08058D	PARTICIPANT	\N	PRESENT	0
59949	59935	11096W	PARTICIPANT	\N	PRESENT	0
59950	59935	95031C	PARTICIPANT	\N	PRESENT	0
59951	59935	97011G	PARTICIPANT	\N	PRESENT	0
59999	59993	98029W	PARTICIPANT	\N	PRESENT	0
59953	59935	04035D	PARTICIPANT	\N	PRESENT	0
59954	59935	07024N	PARTICIPANT	\N	PRESENT	0
60000	59993	11027H	PARTICIPANT	\N	PRESENT	0
59956	59935	14014Q	PARTICIPANT	\N	EXCUSE	0
59957	59935	11015D	PARTICIPANT	\N	PRESENT	0
59958	59935	07004J	PARTICIPANT	\N	PRESENT	0
59959	59935	95035G	PARTICIPANT	\N	PRESENT	0
59960	59935	08056B	PARTICIPANT	\N	PRESENT	0
59961	59935	14211G	PARTICIPANT	\N	PRESENT	0
59962	59935	98022P	PARTICIPANT	\N	PRESENT	0
59963	59935	11064N	PARTICIPANT	\N	PRESENT	0
59964	59935	95037J	PARTICIPANT	\N	PRESENT	0
59965	59935	04078Q	PARTICIPANT	\N	PRESENT	0
59966	59935	14097Y	PARTICIPANT	\N	PRESENT	0
59967	59935	95041E	PARTICIPANT	\N	PRESENT	0
59968	59935	04036E	PARTICIPANT	\N	PRESENT	0
60001	59993	98018T	PARTICIPANT	\N	PRESENT	0
59970	59935	04077P	PARTICIPANT	\N	PRESENT	0
60002	59993	92020L	PARTICIPANT	\N	PRESENT	0
59972	59935	92031P	PARTICIPANT	\N	PRESENT	0
59973	59935	11106F	PARTICIPANT	\N	PRESENT	0
59974	59935	14251Q	PARTICIPANT	\N	PRESENT	0
59975	59935	83042R	PARTICIPANT	\N	PRESENT	0
59976	59935	08053X	PARTICIPANT	\N	PRESENT	0
59977	59935	11082Q	PARTICIPANT	\N	PRESENT	0
59978	59935	11105E	PARTICIPANT	\N	PRESENT	0
59979	59935	14253S	PARTICIPANT	\N	PRESENT	0
59980	59935	08047A	PARTICIPANT	\N	PRESENT	0
59981	59935	14028W	PARTICIPANT	\N	PRESENT	0
59982	59935	14193X	PARTICIPANT	\N	PRESENT	0
59983	59935	98021N	PARTICIPANT	\N	PRESENT	0
59984	59935	11069T	PARTICIPANT	\N	PRESENT	0
59985	59935	04080J	PARTICIPANT	\N	PRESENT	0
59986	59935	95059Q	PRESIDENT	0	PRESENT	0
59987	59935	86044G	PARTICIPANT	\N	PRESENT	0
59988	59935	01014K	PARTICIPANT	\N	PRESENT	0
59989	59935	11054L	PARTICIPANT	\N	EXCUSE	0
59990	59935	01056V	PARTICIPANT	\N	PRESENT	0
59991	59935	92044U	PARTICIPANT	\N	PRESENT	0
59992	59935	08049C	PARTICIPANT	\N	PRESENT	0
60003	59993	97011G	PARTICIPANT	\N	PRESENT	0
60004	59993	04035D	PARTICIPANT	\N	PRESENT	0
60005	59993	07024N	PARTICIPANT	\N	PRESENT	0
60006	59993	14014Q	PARTICIPANT	\N	EXCUSE	0
60007	59993	11015D	PARTICIPANT	\N	PRESENT	0
60008	59993	95035G	PARTICIPANT	\N	PRESENT	0
60009	59993	08056B	PARTICIPANT	\N	PRESENT	0
60010	59993	95037J	PARTICIPANT	\N	PRESENT	0
60011	59993	04078Q	PARTICIPANT	\N	PRESENT	0
60012	59993	14097Y	PARTICIPANT	\N	PRESENT	0
60013	59993	04036E	PARTICIPANT	\N	PRESENT	0
60014	59993	04077P	PARTICIPANT	\N	PRESENT	0
60015	59993	92031P	PARTICIPANT	\N	PRESENT	0
60016	59993	11106F	PARTICIPANT	\N	PRESENT	0
60017	59993	14251Q	PARTICIPANT	\N	PRESENT	0
60018	59993	08053X	PARTICIPANT	\N	PRESENT	0
60019	59993	11082Q	PARTICIPANT	\N	PRESENT	0
60020	59993	11105E	PARTICIPANT	\N	PRESENT	0
60021	59993	14253S	PARTICIPANT	\N	PRESENT	0
60022	59993	08047A	PARTICIPANT	\N	PRESENT	0
60023	59993	14028W	PARTICIPANT	\N	EXCUSE	0
60024	59993	14193X	PARTICIPANT	\N	PRESENT	0
60025	59993	98021N	PARTICIPANT	\N	PRESENT	0
60026	59993	04080J	PARTICIPANT	\N	PRESENT	0
60027	59993	95059Q	PRESIDENT	0	PRESENT	0
60028	59993	86044G	PARTICIPANT	\N	PRESENT	0
60029	59993	01014K	PARTICIPANT	\N	PRESENT	0
60030	59993	11054L	PARTICIPANT	\N	EXCUSE	0
60031	59993	01056V	PARTICIPANT	\N	PRESENT	0
60032	59993	92044U	PARTICIPANT	\N	PRESENT	0
60160	57516	11036J	PARTICIPANT	\N	EXCUSE	0
60161	57516	01044R	PARTICIPANT	\N	EXCUSE	0
60162	57516	14209N	PARTICIPANT	\N	EXCUSE	0
60163	57516	80013X	PARTICIPANT	\N	EXCUSE	0
60164	57516	11089X	PARTICIPANT	\N	EXCUSE	0
60165	57516	08069G	PARTICIPANT	\N	EXCUSE	0
60167	57516	01048V	PARTICIPANT	\N	PRESENT	0
60168	57516	08039A	PARTICIPANT	\N	EXCUSE	0
60169	57516	14221J	PARTICIPANT	\N	PRESENT	0
60170	57516	11082Q	PARTICIPANT	\N	EXCUSE	0
60209	60208	04085P	PARTICIPANT	\N	PRESENT	0
60210	60208	05008E	PRESIDENT	0	PRESENT	0
60211	60208	11033F	PARTICIPANT	\N	PRESENT	0
60212	60208	14069U	PARTICIPANT	\N	PRESENT	0
60213	60208	04047H	PARTICIPANT	\N	PRESENT	0
60214	60208	11035H	PARTICIPANT	\N	PRESENT	0
60215	60208	14041T	PARTICIPANT	\N	PRESENT	0
60217	60208	01024M	PARTICIPANT	\N	PRESENT	0
60219	60208	14215L	PARTICIPANT	\N	PRESENT	0
60220	60208	08018U	PARTICIPANT	\N	PRESENT	0
60221	60208	11049P	PARTICIPANT	\N	PRESENT	0
60222	60208	14001X	PARTICIPANT	\N	PRESENT	0
60224	60208	14273W	PARTICIPANT	\N	PRESENT	0
60225	60208	95049N	PARTICIPANT	\N	PRESENT	0
60226	60208	07034Q	PARTICIPANT	\N	PRESENT	0
60227	60208	95063L	PARTICIPANT	\N	PRESENT	0
60228	60208	01028R	PARTICIPANT	\N	PRESENT	0
60229	60208	04056J	PARTICIPANT	\N	PRESENT	0
60230	60208	04044E	PARTICIPANT	\N	EXCUSE	0
60355	60354	11040E	PARTICIPANT	\N	PRESENT	0
60356	60354	14255U	PARTICIPANT	\N	PRESENT	0
60357	60354	14081Q	PARTICIPANT	\N	PRESENT	0
60358	60354	04041B	PARTICIPANT	\N	PRESENT	0
60359	60354	08031R	PARTICIPANT	\N	PRESENT	0
60360	60354	11111C	PARTICIPANT	\N	PRESENT	0
60361	60354	14135M	PARTICIPANT	\N	PRESENT	0
60362	60354	80027E	PARTICIPANT	\N	PRESENT	0
60363	60354	11059R	PARTICIPANT	\N	PRESENT	0
60364	60354	14059S	PARTICIPANT	\N	PRESENT	0
60463	60037	11098Y	PARTICIPANT	\N	PRESENT	0
60464	60037	04086Q	PARTICIPANT	\N	PRESENT	0
60465	60037	11090Q	PARTICIPANT	\N	PRESENT	0
60466	60037	14081Q	PARTICIPANT	\N	PRESENT	0
60467	60037	11083R	PARTICIPANT	\N	PRESENT	0
60468	60037	07026Q	PARTICIPANT	\N	PRESENT	0
60469	60037	07034Q	PARTICIPANT	\N	PRESENT	0
60470	60037	01013J	PARTICIPANT	\N	PRESENT	0
60471	60037	11012A	PARTICIPANT	\N	PRESENT	0
60472	60037	11070L	PARTICIPANT	\N	PRESENT	0
60473	60037	04036E	PARTICIPANT	\N	PRESENT	0
60474	60037	08017T	PARTICIPANT	\N	PRESENT	0
60475	60037	01031L	PARTICIPANT	\N	PRESENT	0
60476	60037	14013P	PARTICIPANT	\N	PRESENT	0
60481	60037	11091R	PARTICIPANT	\N	PRESENT	0
60478	60037	01016M	PARTICIPANT	\N	PRESENT	0
60479	60037	11099A	PARTICIPANT	\N	PRESENT	0
60480	60037	14269B	PARTICIPANT	\N	PRESENT	0
60482	60037	11039M	PARTICIPANT	\N	PRESENT	0
60483	60037	04081K	PARTICIPANT	\N	PRESENT	0
60484	60037	08055A	PARTICIPANT	\N	PRESENT	0
60485	60037	14231L	PARTICIPANT	\N	PRESENT	0
60486	60037	08022Q	PARTICIPANT	\N	PRESENT	0
60487	60037	11088W	PARTICIPANT	\N	PRESENT	0
60488	60037	77002U	PARTICIPANT	\N	PRESENT	0
60489	60037	01041N	PARTICIPANT	\N	PRESENT	0
60490	60037	80013X	PARTICIPANT	\N	PRESENT	0
60491	60037	95035G	PARTICIPANT	\N	PRESENT	0
60492	60037	14259Y	PARTICIPANT	\N	PRESENT	0
60493	60037	11084S	PARTICIPANT	\N	PRESENT	0
60494	60037	14159V	PARTICIPANT	\N	PRESENT	0
60495	60037	08051V	PARTICIPANT	\N	PRESENT	0
60496	60037	11074Q	PARTICIPANT	\N	PRESENT	0
40041	38927	11085T	PARTICIPANT	\N	PRESENT	0
40042	38927	01013J	PARTICIPANT	\N	PRESENT	0
39787	38926	11036J	PARTICIPANT	\N	PRESENT	0
39788	38926	08068F	PARTICIPANT	\N	PRESENT	0
39789	38926	14034U	PARTICIPANT	\N	PRESENT	0
39790	38926	14109K	PARTICIPANT	\N	PRESENT	0
39833	38926	14028W	PARTICIPANT	\N	PRESENT	0
39792	38926	11066Q	PARTICIPANT	\N	PRESENT	0
40043	38927	11040E	PARTICIPANT	\N	PRESENT	0
39844	38926	11029K	PARTICIPANT	\N	PRESENT	0
39795	38926	08031R	PARTICIPANT	\N	PRESENT	0
39851	38926	14030Q	PARTICIPANT	\N	PRESENT	0
39856	38926	92031P	PARTICIPANT	\N	PRESENT	0
39798	38926	04048J	PARTICIPANT	\N	PRESENT	0
39799	38926	08043V	PARTICIPANT	\N	PRESENT	0
39800	38926	14151M	PARTICIPANT	\N	PRESENT	0
39839	38926	08055A	PARTICIPANT	\N	PRESENT	0
39802	38926	11104D	PARTICIPANT	\N	PRESENT	0
39835	38926	80027E	PARTICIPANT	\N	PRESENT	0
40044	38927	14263U	PARTICIPANT	\N	PRESENT	0
40045	38927	80013X	PARTICIPANT	\N	PRESENT	0
39831	38926	01059Y	PARTICIPANT	\N	PRESENT	0
39807	38926	11010L	PARTICIPANT	\N	PRESENT	0
39858	38926	77002U	PARTICIPANT	\N	PRESENT	0
39809	38926	92018S	PARTICIPANT	\N	PRESENT	0
40046	38927	08014Q	PARTICIPANT	\N	PRESENT	0
39811	38926	08034U	PARTICIPANT	\N	PRESENT	0
39812	38926	14221J	PARTICIPANT	\N	PRESENT	0
39854	38926	13002U	PARTICIPANT	\N	PRESENT	0
39814	38926	14281W	PARTICIPANT	\N	PRESENT	0
39815	38926	11106F	PARTICIPANT	\N	PRESENT	0
39816	38926	01022K	PARTICIPANT	\N	PRESENT	0
40047	38927	01028R	PARTICIPANT	\N	PRESENT	0
39818	38926	01056V	PARTICIPANT	\N	PRESENT	0
39819	38926	04036E	PARTICIPANT	\N	PRESENT	0
39820	38926	08017T	PARTICIPANT	\N	PRESENT	0
39821	38926	11067R	PARTICIPANT	\N	PRESENT	0
39822	38926	05012A	PARTICIPANT	\N	PRESENT	0
39823	38926	08018U	PARTICIPANT	\N	PRESENT	0
39824	38926	01014K	PARTICIPANT	\N	PRESENT	0
39825	38926	04080J	PARTICIPANT	\N	PRESENT	0
39826	38926	07024N	PARTICIPANT	\N	PRESENT	0
39827	38926	04057K	PARTICIPANT	\N	PRESENT	0
40048	38927	01057W	PARTICIPANT	\N	PRESENT	0
39829	38926	95059Q	PARTICIPANT	\N	PRESENT	0
39830	38926	11031D	PARTICIPANT	\N	PRESENT	0
39832	38926	08016S	PARTICIPANT	\N	PRESENT	0
39834	38926	08058D	PARTICIPANT	\N	PRESENT	0
39836	38926	11014C	PARTICIPANT	\N	PRESENT	0
39837	38926	14051J	PARTICIPANT	\N	PRESENT	0
39838	38926	92020L	PARTICIPANT	\N	PRESENT	0
39840	38926	11046L	PARTICIPANT	\N	PRESENT	0
39842	38926	08061X	PARTICIPANT	\N	PRESENT	0
39843	38926	11072N	PARTICIPANT	\N	PRESENT	0
39845	38926	11033F	PARTICIPANT	\N	PRESENT	0
39846	38926	11069T	PARTICIPANT	\N	PRESENT	0
39847	38926	11083R	PARTICIPANT	\N	PRESENT	0
39848	38926	14255U	PARTICIPANT	\N	PRESENT	0
39849	38926	14089Y	PARTICIPANT	\N	PRESENT	0
39850	38926	04070G	PARTICIPANT	\N	PRESENT	0
39852	38926	11094U	PARTICIPANT	\N	PRESENT	0
39853	38926	11026G	PARTICIPANT	\N	PRESENT	0
39855	38926	14053L	PARTICIPANT	\N	PRESENT	0
39857	38926	98021N	PARTICIPANT	\N	PRESENT	0
39859	38926	01058X	PARTICIPANT	\N	PRESENT	0
40049	38927	14225N	PARTICIPANT	\N	PRESENT	0
40050	38927	01031L	PARTICIPANT	\N	PRESENT	0
40051	38927	98046X	PARTICIPANT	\N	PRESENT	0
40052	38927	11037K	PARTICIPANT	\N	PRESENT	0
40053	38927	11070L	PARTICIPANT	\N	PRESENT	0
40054	38927	01046T	PARTICIPANT	\N	PRESENT	0
40055	38927	88008L	PARTICIPANT	\N	PRESENT	0
40056	38927	14175V	PARTICIPANT	\N	PRESENT	0
40057	38927	14159V	PARTICIPANT	\N	PRESENT	0
40058	38927	14079W	PARTICIPANT	\N	PRESENT	0
40059	38927	14195A	PARTICIPANT	\N	PRESENT	0
40060	38927	14157T	PARTICIPANT	\N	PRESENT	0
40061	38927	08034U	PARTICIPANT	\N	PRESENT	0
40062	38927	14105F	PARTICIPANT	\N	PRESENT	0
40063	38927	14059S	PARTICIPANT	\N	PRESENT	0
40064	38927	95067Q	PARTICIPANT	\N	PRESENT	0
40065	38927	04086Q	PARTICIPANT	\N	PRESENT	0
40066	38927	99004R	PARTICIPANT	\N	PRESENT	0
40067	38927	01007L	PARTICIPANT	\N	PRESENT	0
40068	38927	07029T	PARTICIPANT	\N	PRESENT	0
40069	38927	14065Q	PARTICIPANT	\N	PRESENT	0
40070	38927	01016M	PARTICIPANT	\N	PRESENT	0
40071	38927	11053K	PARTICIPANT	\N	PRESENT	0
40072	38927	14179A	PARTICIPANT	\N	PRESENT	0
40073	38927	10006L	PARTICIPANT	\N	PRESENT	0
40074	38927	11043H	PARTICIPANT	\N	PRESENT	0
40075	38927	14187A	PARTICIPANT	\N	PRESENT	0
40076	38927	14265W	PARTICIPANT	\N	PRESENT	0
40077	38927	14215L	PARTICIPANT	\N	PRESENT	0
40078	38927	14083S	PARTICIPANT	\N	PRESENT	0
40079	38927	14034U	PARTICIPANT	\N	PRESENT	0
40080	38927	14231L	PARTICIPANT	\N	PRESENT	0
40081	38927	14073Q	PARTICIPANT	\N	PRESENT	0
40082	38927	14213J	PARTICIPANT	\N	PRESENT	0
40083	38927	04088S	PARTICIPANT	\N	PRESENT	0
40084	38927	08015R	PARTICIPANT	\N	PRESENT	0
40085	38927	01008M	PARTICIPANT	\N	PRESENT	0
40086	38927	14033T	PARTICIPANT	\N	PRESENT	0
40087	38927	08061X	PARTICIPANT	\N	PRESENT	0
40088	38927	08052W	PARTICIPANT	\N	PRESENT	0
40089	38927	11074Q	PARTICIPANT	\N	PRESENT	0
40101	40090	01007L	PARTICIPANT	\N	PRESENT	0
40124	40090	04092N	PARTICIPANT	\N	PRESENT	0
40125	40090	01034P	PARTICIPANT	\N	PRESENT	0
40126	40090	14227Q	PARTICIPANT	\N	PRESENT	0
40127	40090	14063N	PARTICIPANT	\N	PRESENT	0
40128	40090	11031D	PARTICIPANT	\N	PRESENT	0
40129	40090	12042Y	PARTICIPANT	\N	PRESENT	0
40130	40090	14281W	PARTICIPANT	\N	PRESENT	0
40131	40090	11067R	PARTICIPANT	\N	PRESENT	0
40132	40090	08052W	PARTICIPANT	\N	PRESENT	0
40133	40090	14083S	PARTICIPANT	\N	PRESENT	0
40134	40090	11093T	PARTICIPANT	\N	PRESENT	0
40135	40090	14231L	PARTICIPANT	\N	PRESENT	0
40136	40090	14179A	PARTICIPANT	\N	PRESENT	0
40137	40090	01046T	PARTICIPANT	\N	PRESENT	0
40138	40090	11063M	PARTICIPANT	\N	PRESENT	0
40139	40090	14041T	PARTICIPANT	\N	PRESENT	0
40140	40090	14105F	PARTICIPANT	\N	PRESENT	0
40141	40090	14187A	PARTICIPANT	\N	PRESENT	0
40142	40090	14195A	PARTICIPANT	\N	PRESENT	0
40143	40090	14031R	PARTICIPANT	\N	PRESENT	0
40144	40090	14265W	PARTICIPANT	\N	PRESENT	0
40145	40090	11091R	PARTICIPANT	\N	PRESENT	0
40146	40090	14213J	PARTICIPANT	\N	PRESENT	0
40147	40090	04067M	PARTICIPANT	\N	PRESENT	0
40148	40090	11097X	PARTICIPANT	\N	PRESENT	0
40149	40090	14217N	PARTICIPANT	\N	PRESENT	0
40150	40090	14255U	PARTICIPANT	\N	PRESENT	0
40151	40090	14089Y	PARTICIPANT	\N	PRESENT	0
40152	40090	14103D	PARTICIPANT	\N	PRESENT	0
40153	40090	14109K	PARTICIPANT	\N	PRESENT	0
40154	40090	00003C	PARTICIPANT	\N	PRESENT	0
40155	40090	14269B	PARTICIPANT	\N	PRESENT	0
40156	40090	14219Q	PARTICIPANT	\N	PRESENT	0
40157	40090	14267Y	PARTICIPANT	\N	PRESENT	0
40158	40090	04066L	PARTICIPANT	\N	PRESENT	0
40159	40090	04048J	PARTICIPANT	\N	PRESENT	0
40160	40090	14263U	PARTICIPANT	\N	PRESENT	0
40161	40090	10006L	PARTICIPANT	\N	PRESENT	0
40162	40090	14215L	PARTICIPANT	\N	PRESENT	0
37588	37587	14089Y	PARTICIPANT	\N	PRESENT	0
43609	32370	14299H	PARTICIPANT	\N	PRESENT	0
43958	43957	14133K	PARTICIPANT	\N	PRESENT	0
43959	43957	14097Y	PARTICIPANT	\N	PRESENT	0
43961	43960	14133K	PARTICIPANT	\N	PRESENT	0
43962	43960	14097Y	PARTICIPANT	\N	PRESENT	0
43963	43960	04080J	PARTICIPANT	\N	PRESENT	0
43965	43964	14133K	PARTICIPANT	\N	PRESENT	0
43966	43964	14097Y	PARTICIPANT	\N	PRESENT	0
43967	43964	11012A	PARTICIPANT	\N	PRESENT	0
43969	43968	14133K	PARTICIPANT	\N	PRESENT	0
43970	43968	14097Y	PARTICIPANT	\N	PRESENT	0
43975	43974	11031D	PARTICIPANT	\N	PRESENT	0
43976	43974	14039A	PARTICIPANT	\N	PRESENT	0
43977	43974	08073C	PARTICIPANT	\N	PRESENT	0
43978	43974	11039M	PARTICIPANT	\N	PRESENT	0
43979	43974	11100Y	PARTICIPANT	\N	PRESENT	0
43980	43974	14169X	PARTICIPANT	\N	PRESENT	0
50477	50476	89017R	PARTICIPANT	\N	PRESENT	0
50478	50476	01031L	PRESIDENT	0	PRESENT	0
50585	50584	10015M	PARTICIPANT	\N	PRESENT	0
50480	50476	01013J	PARTICIPANT	\N	PRESENT	0
50481	50476	11068S	PARTICIPANT	\N	PRESENT	0
50482	50476	11040E	PARTICIPANT	\N	PRESENT	0
50483	50476	08014Q	PARTICIPANT	\N	PRESENT	0
50484	50476	14167V	PARTICIPANT	\N	PRESENT	0
50587	50586	10006L	PARTICIPANT	\N	PRESENT	0
50486	50476	14083S	PARTICIPANT	\N	PRESENT	0
59349	59291	14201E	PARTICIPANT	\N	EXCUSE	0
50488	50476	14085U	PARTICIPANT	\N	PRESENT	0
50489	50476	11042G	PARTICIPANT	\N	PRESENT	0
59656	58246	08055A	PARTICIPANT	\N	PRESENT	0
50491	50476	04086Q	PARTICIPANT	\N	PRESENT	0
59657	58246	11101A	PARTICIPANT	\N	PRESENT	0
50493	50476	11070L	PARTICIPANT	\N	PRESENT	0
50494	50476	11088W	PARTICIPANT	\N	PRESENT	0
50495	50476	14327T	PARTICIPANT	\N	PRESENT	0
59658	58246	14105F	PARTICIPANT	\N	PRESENT	0
50497	50476	01027Q	PARTICIPANT	\N	PRESENT	0
50498	50476	04071H	PARTICIPANT	\N	PRESENT	0
59659	58246	80013X	PARTICIPANT	\N	PRESENT	0
50500	50476	98053W	PARTICIPANT	\N	EXCUSE	0
50501	50476	11083R	PARTICIPANT	\N	PRESENT	0
50502	50476	14199E	PARTICIPANT	\N	PRESENT	0
50503	50476	01057W	PARTICIPANT	\N	PRESENT	0
50504	50476	08016S	PARTICIPANT	\N	PRESENT	0
50505	50476	08069G	PARTICIPANT	\N	PRESENT	0
50506	50476	11048N	PARTICIPANT	\N	EXCUSE	0
50507	50476	99004R	PARTICIPANT	\N	PRESENT	0
59660	58246	08060W	PARTICIPANT	\N	PRESENT	0
50509	50476	14159V	PARTICIPANT	\N	PRESENT	0
50510	50476	07029T	PARTICIPANT	\N	PRESENT	0
59661	58246	01015L	PARTICIPANT	\N	PRESENT	0
50512	50476	08010L	PARTICIPANT	\N	PRESENT	0
50513	50476	08034U	PARTICIPANT	\N	PRESENT	0
50514	50476	01048V	PARTICIPANT	\N	PRESENT	0
50515	50476	98046X	PARTICIPANT	\N	PRESENT	0
59662	58246	14053L	PARTICIPANT	\N	PRESENT	0
50517	50476	08011M	PARTICIPANT	\N	PRESENT	0
50518	50476	08073C	PARTICIPANT	\N	EXCUSE	0
50519	50476	08061X	PARTICIPANT	\N	PRESENT	0
50520	50476	01016M	PARTICIPANT	\N	PRESENT	0
50521	50476	14225N	PARTICIPANT	\N	PRESENT	0
50522	50476	11012A	PARTICIPANT	\N	EXCUSE	0
50523	50476	11057P	PARTICIPANT	\N	PRESENT	0
50524	50476	14173T	PARTICIPANT	\N	PRESENT	0
50525	50476	04034C	PARTICIPANT	\N	PRESENT	0
59663	58246	14331P	PARTICIPANT	\N	PRESENT	0
59664	58246	13002U	PARTICIPANT	\N	PRESENT	0
59299	59291	14089Y	PARTICIPANT	\N	PRESENT	0
59300	59291	14105F	PARTICIPANT	\N	PRESENT	0
59301	59291	11029K	PARTICIPANT	\N	PRESENT	0
59302	59291	95015C	PRESIDENT	0	PRESENT	0
59303	59291	92015P	PARTICIPANT	\N	EXCUSE	0
59304	59291	08024S	PARTICIPANT	\N	PRESENT	0
59665	58246	07029T	PARTICIPANT	\N	PRESENT	0
59666	58246	04088S	PARTICIPANT	\N	PRESENT	0
59307	59291	14209N	PARTICIPANT	\N	PRESENT	0
59308	59291	14079W	PARTICIPANT	\N	PRESENT	0
59309	59291	11091R	PARTICIPANT	\N	PRESENT	0
59310	59291	87003B	PARTICIPANT	\N	PRESENT	0
59667	58246	14179A	PARTICIPANT	\N	PRESENT	0
59312	59291	14249W	PARTICIPANT	\N	PRESENT	0
59313	59291	01041N	PARTICIPANT	\N	PRESENT	0
59314	59291	01025N	PARTICIPANT	\N	PRESENT	0
59668	58246	14013P	PARTICIPANT	\N	PRESENT	0
59316	59291	89029V	PARTICIPANT	\N	PRESENT	0
59317	59291	08035V	PARTICIPANT	\N	PRESENT	0
59318	59291	11089X	PARTICIPANT	\N	PRESENT	0
59319	59291	07026Q	PARTICIPANT	\N	PRESENT	0
59320	59291	14123H	PARTICIPANT	\N	PRESENT	0
59321	59291	14179A	PARTICIPANT	\N	PRESENT	0
59322	59291	04041B	PARTICIPANT	\N	PRESENT	0
59323	59291	14241N	PARTICIPANT	\N	PRESENT	0
59324	59291	14061L	PARTICIPANT	\N	PRESENT	0
59325	59291	14073Q	PARTICIPANT	\N	PRESENT	0
59326	59291	08031R	PARTICIPANT	\N	PRESENT	0
59669	58246	14063N	PARTICIPANT	\N	PRESENT	0
59328	59291	08039A	PARTICIPANT	\N	PRESENT	0
59329	59291	08017T	PARTICIPANT	\N	PRESENT	0
59330	59291	14059S	PARTICIPANT	\N	PRESENT	0
59670	58246	11067R	PARTICIPANT	\N	PRESENT	0
59332	59291	14103D	PARTICIPANT	\N	PRESENT	0
59333	59291	11104D	PARTICIPANT	\N	PRESENT	0
59334	59291	14063N	PARTICIPANT	\N	PRESENT	0
59335	59291	04057K	PARTICIPANT	\N	PRESENT	0
59336	59291	11014C	PARTICIPANT	\N	PRESENT	0
59671	58246	14107H	PARTICIPANT	\N	PRESENT	0
59338	59291	04070G	PARTICIPANT	\N	PRESENT	0
59339	59291	92040Q	PARTICIPANT	\N	PRESENT	0
59340	59291	14191V	PARTICIPANT	\N	PRESENT	0
59341	59291	83047W	PARTICIPANT	\N	PRESENT	0
59342	59291	14235Q	PARTICIPANT	\N	PRESENT	0
59672	58246	14038Y	PARTICIPANT	\N	PRESENT	0
59344	59291	04033B	PARTICIPANT	\N	PRESENT	0
59345	59291	14229S	PARTICIPANT	\N	PRESENT	0
59346	59291	11043H	PARTICIPANT	\N	PRESENT	0
59683	58246	14147R	PARTICIPANT	\N	PRESENT	0
59348	59291	11011M	PARTICIPANT	\N	PRESENT	0
59673	58246	00003C	PARTICIPANT	\N	PRESENT	0
59674	58246	14051J	PARTICIPANT	\N	PRESENT	0
59675	58246	09001P	PARTICIPANT	\N	PRESENT	0
59676	58246	95049N	PARTICIPANT	\N	PRESENT	0
59677	58246	14030Q	PARTICIPANT	\N	PRESENT	0
59678	58246	14207L	PARTICIPANT	\N	PRESENT	0
59679	58246	11066Q	PARTICIPANT	\N	PRESENT	0
59680	58246	14195A	PARTICIPANT	\N	PRESENT	0
59681	58246	14265W	PARTICIPANT	\N	PRESENT	0
59687	58246	14259Y	PARTICIPANT	\N	PRESENT	0
59688	58246	14215L	PARTICIPANT	\N	PRESENT	0
59689	58246	14042U	PARTICIPANT	\N	PRESENT	0
59690	58246	14209N	PARTICIPANT	\N	PRESENT	0
59691	58246	14059S	PARTICIPANT	\N	PRESENT	0
59692	58246	14235Q	PARTICIPANT	\N	PRESENT	0
59693	58246	14033T	PARTICIPANT	\N	PRESENT	0
59694	58246	14191V	PARTICIPANT	\N	PRESENT	0
59695	58246	07026Q	PARTICIPANT	\N	PRESENT	0
59697	58246	01048V	PARTICIPANT	\N	PRESENT	0
59702	58246	11099A	PARTICIPANT	\N	PRESENT	0
59707	58246	14073Q	PARTICIPANT	\N	PRESENT	0
59720	58246	14041T	PARTICIPANT	\N	PRESENT	0
59741	58246	11064N	PARTICIPANT	\N	PRESENT	0
59743	58246	08042U	PARTICIPANT	\N	PRESENT	0
59746	58246	08015R	PARTICIPANT	\N	PRESENT	0
59747	58246	14197C	PARTICIPANT	\N	PRESENT	0
59748	58246	04081K	PARTICIPANT	\N	PRESENT	0
59749	58246	11090Q	PARTICIPANT	\N	PRESENT	0
59750	58246	01025N	PARTICIPANT	\N	PRESENT	0
59751	58246	11107G	PARTICIPANT	\N	PRESENT	0
59752	58246	02002K	PARTICIPANT	\N	PRESENT	0
59753	58246	14263U	PARTICIPANT	\N	PRESENT	0
59754	58246	11036J	PARTICIPANT	\N	PRESENT	0
59755	58246	11091R	PARTICIPANT	\N	PRESENT	0
59756	58246	08062Y	PARTICIPANT	\N	PRESENT	0
59757	58246	08048B	PARTICIPANT	\N	PRESENT	0
59758	58246	14267Y	PARTICIPANT	\N	PRESENT	0
59759	58246	14187A	PARTICIPANT	\N	PRESENT	0
59760	58246	99004R	PARTICIPANT	\N	PRESENT	0
59761	58246	11011M	PARTICIPANT	\N	PRESENT	0
59762	58246	11040E	PARTICIPANT	\N	PRESENT	0
59763	58246	08056B	PARTICIPANT	\N	PRESENT	0
59764	58246	14034U	PARTICIPANT	\N	PRESENT	0
59765	58246	14173T	PARTICIPANT	\N	PRESENT	0
59766	58246	08009T	PARTICIPANT	\N	PRESENT	0
59767	58246	14213J	PARTICIPANT	\N	PRESENT	0
59768	58246	14071N	PARTICIPANT	\N	PRESENT	0
36316	36276	01008M	PARTICIPANT	\N	PRESENT	0
36284	36276	11095V	PARTICIPANT	\N	PRESENT	0
36317	36276	11036J	PARTICIPANT	\N	PRESENT	0
36286	36276	11114F	PARTICIPANT	\N	PRESENT	0
36318	36276	14013P	PARTICIPANT	\N	PRESENT	0
36288	36276	11065P	PARTICIPANT	\N	PRESENT	0
36289	36276	01015L	PARTICIPANT	\N	PRESENT	0
36290	36276	11107G	PARTICIPANT	\N	PRESENT	0
36319	36276	08068F	PARTICIPANT	\N	PRESENT	0
36320	36276	14207L	PARTICIPANT	\N	PRESENT	0
36293	36276	01022K	PARTICIPANT	\N	PRESENT	0
36321	36276	90003B	PARTICIPANT	\N	PRESENT	0
36322	36276	08028W	PARTICIPANT	\N	PRESENT	0
36296	36276	11059R	PARTICIPANT	\N	PRESENT	0
36323	36276	80013X	PARTICIPANT	\N	PRESENT	0
36324	36276	08038Y	PARTICIPANT	\N	PRESENT	0
36325	36276	04089T	PARTICIPANT	\N	PRESENT	0
36300	36276	08009T	PRESIDENT	0	PRESENT	0
36326	36276	14197C	PARTICIPANT	\N	PRESENT	0
36302	36276	14221J	PARTICIPANT	\N	PRESENT	0
36303	36276	92039X	PARTICIPANT	\N	PRESENT	0
36304	36276	08042U	PARTICIPANT	\N	PRESENT	0
36305	36276	14169X	PARTICIPANT	\N	PRESENT	0
36330	36276	14033T	PARTICIPANT	\N	PRESENT	0
36328	36276	11110B	PARTICIPANT	\N	PRESENT	0
36308	36276	05012A	PARTICIPANT	\N	PRESENT	0
36329	36276	14187A	PARTICIPANT	\N	PRESENT	0
36310	36276	14135M	PARTICIPANT	\N	PRESENT	0
36311	36276	95062K	PARTICIPANT	\N	PRESENT	0
36331	36276	14081Q	PARTICIPANT	\N	PRESENT	0
36332	36276	11099A	PARTICIPANT	\N	PRESENT	0
36314	36276	14157T	PARTICIPANT	\N	PRESENT	0
36315	36276	96003C	PARTICIPANT	\N	EXCUSE	0
36333	36276	04049K	PARTICIPANT	\N	PRESENT	0
36336	36276	11098Y	PARTICIPANT	\N	PRESENT	0
36337	36276	11100Y	PARTICIPANT	\N	PRESENT	0
36338	36276	14205J	PARTICIPANT	\N	PRESENT	0
36342	36276	14257W	PARTICIPANT	\N	PRESENT	0
36344	36276	04088S	PARTICIPANT	\N	PRESENT	0
36345	36276	98050T	PARTICIPANT	\N	PRESENT	0
36347	36276	11046L	PARTICIPANT	\N	PRESENT	0
36348	36276	11066Q	PARTICIPANT	\N	PRESENT	0
36349	36276	92045V	PARTICIPANT	\N	PRESENT	0
36350	36276	04045F	PARTICIPANT	\N	PRESENT	0
36351	36276	14001X	PARTICIPANT	\N	PRESENT	0
36353	36276	11026G	PARTICIPANT	\N	PRESENT	0
36355	36276	11035H	PARTICIPANT	\N	PRESENT	0
36357	36276	14133K	PARTICIPANT	\N	PRESENT	0
36360	36359	01008M	PARTICIPANT	\N	PRESENT	0
36361	36359	11036J	PARTICIPANT	\N	PRESENT	0
36362	36359	11081P	PARTICIPANT	\N	PRESENT	0
36363	36359	14013P	PARTICIPANT	\N	PRESENT	0
36364	36359	08068F	PARTICIPANT	\N	PRESENT	0
36365	36359	14207L	PARTICIPANT	\N	PRESENT	0
36366	36359	11101A	PARTICIPANT	\N	PRESENT	0
36367	36359	90003B	PARTICIPANT	\N	PRESENT	0
36368	36359	08028W	PARTICIPANT	\N	PRESENT	0
36369	36359	80013X	PARTICIPANT	\N	PRESENT	0
36370	36359	08038Y	PARTICIPANT	\N	PRESENT	0
36371	36359	04089T	PARTICIPANT	\N	PRESENT	0
36372	36359	14197C	PARTICIPANT	\N	PRESENT	0
36373	36359	11110B	PARTICIPANT	\N	PRESENT	0
36374	36359	14187A	PARTICIPANT	\N	PRESENT	0
36375	36359	14033T	PARTICIPANT	\N	PRESENT	0
36376	36359	14081Q	PARTICIPANT	\N	PRESENT	0
36377	36359	04048J	PARTICIPANT	\N	PRESENT	0
36378	36359	11099A	PARTICIPANT	\N	PRESENT	0
36379	36359	04049K	PARTICIPANT	\N	PRESENT	0
36380	36359	04094Q	PARTICIPANT	\N	PRESENT	0
36381	36359	11111C	PARTICIPANT	\N	PRESENT	0
36382	36359	08015R	PARTICIPANT	\N	PRESENT	0
36383	36359	11100Y	PRESIDENT	0	PRESENT	0
36384	36359	01061S	PARTICIPANT	\N	PRESENT	0
36385	36359	11098Y	PARTICIPANT	\N	PRESENT	0
36386	36359	01043Q	PARTICIPANT	\N	PRESENT	0
36387	36359	11077T	PARTICIPANT	\N	PRESENT	0
36388	36359	14205J	PARTICIPANT	\N	PRESENT	0
36389	36359	08019V	PARTICIPANT	\N	PRESENT	0
36390	36359	14257W	PARTICIPANT	\N	PRESENT	0
36391	36359	08021P	PARTICIPANT	\N	PRESENT	0
36392	36359	04088S	PARTICIPANT	\N	PRESENT	0
36393	36359	98050T	PARTICIPANT	\N	PRESENT	0
36394	36359	11090Q	PARTICIPANT	\N	PRESENT	0
36395	36359	11046L	PARTICIPANT	\N	PRESENT	0
36396	36359	01058X	PARTICIPANT	\N	PRESENT	0
36397	36359	11094U	PARTICIPANT	\N	EXCUSE	0
36398	36359	11066Q	PARTICIPANT	\N	PRESENT	0
36453	36359	11042G	PARTICIPANT	\N	PRESENT	0
37269	32370	11068S	PARTICIPANT	\N	EXCUSE	0
37273	32377	14263U	PARTICIPANT	\N	EXCUSE	0
37345	37341	04043D	PARTICIPANT	\N	PRESENT	0
37343	37341	08038Y	PARTICIPANT	\N	PRESENT	0
37344	37341	98042T	PARTICIPANT	\N	PRESENT	0
37346	37341	14001X	PARTICIPANT	\N	PRESENT	0
37361	37357	04081K	PARTICIPANT	\N	PRESENT	0
37362	37357	04067M	PARTICIPANT	\N	PRESENT	0
37630	37629	92045V	PARTICIPANT	\N	PRESENT	0
37634	37633	92045V	PARTICIPANT	\N	PRESENT	0
38024	38023	08055A	PARTICIPANT	\N	PRESENT	0
38025	38023	14105F	PARTICIPANT	\N	PRESENT	0
38026	38023	92015P	PARTICIPANT	\N	PRESENT	0
38027	38023	11103C	PARTICIPANT	\N	PRESENT	0
38028	38023	04089T	PARTICIPANT	\N	PRESENT	0
38029	38023	14059S	PARTICIPANT	\N	PRESENT	0
38030	38023	07032N	PARTICIPANT	\N	PRESENT	0
38031	38023	05012A	PARTICIPANT	\N	PRESENT	0
38032	38023	14107H	PARTICIPANT	\N	PRESENT	0
38033	38023	92045V	PARTICIPANT	\N	PRESENT	0
38035	38034	14038Y	PARTICIPANT	\N	PRESENT	0
38036	38034	11095V	PARTICIPANT	\N	PRESENT	0
38037	38034	08009T	PARTICIPANT	\N	PRESENT	0
38038	38034	14169X	PARTICIPANT	\N	PRESENT	0
38245	38244	89017R	PARTICIPANT	\N	EXCUSE	0
38246	38244	01031L	PRESIDENT	0	PRESENT	0
38247	38244	14175V	PARTICIPANT	\N	PRESENT	0
38248	38244	11042G	PARTICIPANT	\N	PRESENT	0
38249	38244	04086Q	PARTICIPANT	\N	PRESENT	0
38250	38244	11088W	PARTICIPANT	\N	PRESENT	0
38251	38244	01027Q	PARTICIPANT	\N	PRESENT	0
38252	38244	04071H	PARTICIPANT	\N	PRESENT	0
38253	38244	11074Q	PARTICIPANT	\N	PRESENT	0
38254	38244	11083R	PARTICIPANT	\N	PRESENT	0
38255	38244	08069G	PARTICIPANT	\N	PRESENT	0
38256	38244	99004R	PARTICIPANT	\N	PRESENT	0
38257	38244	04061F	PARTICIPANT	\N	PRESENT	0
38258	38244	07029T	PARTICIPANT	\N	PRESENT	0
38259	38244	08034U	PARTICIPANT	\N	PRESENT	0
38260	38244	98046X	PARTICIPANT	\N	PRESENT	0
38261	38244	08011M	PARTICIPANT	\N	PRESENT	0
38262	38244	08073C	PARTICIPANT	\N	PRESENT	0
38263	38244	11012A	PARTICIPANT	\N	PRESENT	0
38264	38244	11057P	PARTICIPANT	\N	PRESENT	0
38265	38244	04034C	PARTICIPANT	\N	PRESENT	0
38266	31687	11049P	PARTICIPANT	\N	PRESENT	0
38485	38484	14239U	PARTICIPANT	\N	PRESENT	0
38486	38484	11055M	PARTICIPANT	\N	PRESENT	0
38487	38484	04053F	PARTICIPANT	\N	PRESENT	0
38489	38484	04066L	PARTICIPANT	\N	PRESENT	0
38491	38484	00003C	PARTICIPANT	\N	PRESENT	0
38494	38484	14053L	PARTICIPANT	\N	PRESENT	0
38496	38484	14195A	PARTICIPANT	\N	PRESENT	0
38497	38484	11023D	PARTICIPANT	\N	PRESENT	0
38499	38484	11031D	PARTICIPANT	\N	PRESENT	0
38500	38484	08052W	PARTICIPANT	\N	PRESENT	0
38501	38484	01059Y	PARTICIPANT	\N	PRESENT	0
38503	38484	98024R	PARTICIPANT	\N	PRESENT	0
38504	38484	10006L	PARTICIPANT	\N	PRESENT	0
38506	38484	14217N	PARTICIPANT	\N	PRESENT	0
38507	38484	14042U	PARTICIPANT	\N	PRESENT	0
38508	38484	14151M	PARTICIPANT	\N	PRESENT	0
38509	38484	12042Y	PARTICIPANT	\N	PRESENT	0
38510	38484	14281W	PARTICIPANT	\N	PRESENT	0
38511	38484	14087W	PARTICIPANT	\N	PRESENT	0
38512	38484	14231L	PARTICIPANT	\N	PRESENT	0
38513	38484	11061K	PARTICIPANT	\N	PRESENT	0
38514	38484	08048B	PARTICIPANT	\N	PRESENT	0
38517	38484	08041T	PARTICIPANT	\N	EXCUSE	0
38519	38484	01011G	PARTICIPANT	\N	PRESENT	0
38520	38484	14026U	PARTICIPANT	\N	PRESENT	0
38521	38484	14213J	PARTICIPANT	\N	PRESENT	0
38522	38484	14121F	PARTICIPANT	\N	PRESENT	0
38523	38484	11112D	PARTICIPANT	\N	PRESENT	0
38524	38484	14037X	PARTICIPANT	\N	PRESENT	0
38525	38484	11067R	PARTICIPANT	\N	PRESENT	0
38526	38484	14223L	PARTICIPANT	\N	PRESENT	0
38528	38484	04092N	PRESIDENT	0	PRESENT	0
38529	38484	14265W	PARTICIPANT	\N	PRESENT	0
38530	38484	14119M	PARTICIPANT	\N	PRESENT	0
38531	38484	14071N	PARTICIPANT	\N	PRESENT	0
50380	50372	04047H	PARTICIPANT	\N	PRESENT	0
50381	50372	11032E	PARTICIPANT	\N	PRESENT	0
50422	50372	08055A	PARTICIPANT	\N	PRESENT	0
50383	50372	99002P	PARTICIPANT	\N	EXCUSE	0
50423	50372	11059R	PARTICIPANT	\N	PRESENT	0
50385	50372	14259Y	PARTICIPANT	\N	PRESENT	0
50386	50372	11035H	PARTICIPANT	\N	PRESENT	0
50387	50372	14041T	PARTICIPANT	\N	PRESENT	0
50424	50372	14030Q	PARTICIPANT	\N	PRESENT	0
50425	50372	14038Y	PARTICIPANT	\N	PRESENT	0
50390	50372	14215L	PARTICIPANT	\N	PRESENT	0
50426	50372	01015L	PARTICIPANT	\N	PRESENT	0
50392	50372	08018U	PARTICIPANT	\N	PRESENT	0
50393	50372	11010L	PARTICIPANT	\N	EXCUSE	0
50427	50372	11107G	PARTICIPANT	\N	PRESENT	0
50428	50372	02002K	PARTICIPANT	\N	PRESENT	0
50429	50372	01022K	PARTICIPANT	\N	PRESENT	0
50430	50372	14219Q	PARTICIPANT	\N	PRESENT	0
50431	50372	14169X	PARTICIPANT	\N	PRESENT	0
50432	50372	14237S	PARTICIPANT	\N	PRESENT	0
50400	50372	14111D	PARTICIPANT	\N	PRESENT	0
50401	50372	14001X	PARTICIPANT	\N	PRESENT	0
50402	50372	14273W	PARTICIPANT	\N	PRESENT	0
50433	50372	05012A	PARTICIPANT	\N	PRESENT	0
50404	50372	14147R	PARTICIPANT	\N	PRESENT	0
50405	50372	95049N	PARTICIPANT	\N	PRESENT	0
50406	50372	08051V	PARTICIPANT	\N	PRESENT	0
50434	50372	95062K	PARTICIPANT	\N	PRESENT	0
50408	50372	07034Q	PARTICIPANT	\N	PRESENT	0
50409	50372	04074L	PARTICIPANT	\N	PRESENT	0
50410	50372	10015M	PARTICIPANT	\N	PRESENT	0
50411	50372	95063L	PARTICIPANT	\N	PRESENT	0
50435	50372	14051J	PARTICIPANT	\N	PRESENT	0
50413	50372	01028R	PARTICIPANT	\N	PRESENT	0
50414	50372	98035U	PARTICIPANT	\N	PRESENT	0
50436	50372	08060W	PARTICIPANT	\N	PRESENT	0
50437	50372	92039X	PARTICIPANT	\N	PRESENT	0
50417	50372	04044E	PARTICIPANT	\N	PRESENT	0
50438	50372	98023Q	PARTICIPANT	\N	PRESENT	0
50419	50372	92045V	PARTICIPANT	\N	PRESENT	0
50420	50372	95067Q	PARTICIPANT	\N	PRESENT	0
50439	50372	13002U	PARTICIPANT	\N	PRESENT	0
50440	50372	11114F	PARTICIPANT	\N	PRESENT	0
50441	50372	09001P	PARTICIPANT	\N	PRESENT	0
50442	50372	14093U	PARTICIPANT	\N	PRESENT	0
50443	50372	80027E	PARTICIPANT	\N	PRESENT	0
50444	50372	14031R	PARTICIPANT	\N	PRESENT	0
50445	50372	08009T	PARTICIPANT	\N	PRESENT	0
50449	50372	08062Y	PARTICIPANT	\N	PRESENT	0
50454	50372	14221J	PARTICIPANT	\N	PRESENT	0
50457	50372	08042U	PARTICIPANT	\N	PRESENT	0
51510	49855	11099A	PARTICIPANT	\N	PRESENT	0
51511	49855	08010L	PARTICIPANT	\N	PRESENT	0
51512	49855	04045F	PARTICIPANT	\N	PRESENT	0
51513	49855	11048N	PARTICIPANT	\N	PRESENT	0
51514	49855	11101A	PARTICIPANT	\N	PRESENT	0
51515	49855	95063L	PARTICIPANT	\N	PRESENT	0
51516	49855	14051J	PARTICIPANT	\N	PRESENT	0
51517	49855	08038Y	PARTICIPANT	\N	PRESENT	0
51518	49855	11037K	PARTICIPANT	\N	PRESENT	0
51519	49855	05012A	PARTICIPANT	\N	PRESENT	0
51520	49855	01057W	PARTICIPANT	\N	PRESENT	0
51521	49855	04086Q	PARTICIPANT	\N	PRESENT	0
51522	49855	08051V	PARTICIPANT	\N	PRESENT	0
51523	49855	14231L	PARTICIPANT	\N	PRESENT	0
51524	49855	11044J	PARTICIPANT	\N	PRESENT	0
51896	49835	11054L	PARTICIPANT	\N	EXCUSE	0
51529	49855	11074Q	PARTICIPANT	\N	PRESENT	0
51558	49855	11032E	PARTICIPANT	\N	PRESENT	0
51559	49855	08034U	PARTICIPANT	\N	PRESENT	0
51897	49835	04095R	PARTICIPANT	\N	EXCUSE	0
52178	52177	11029K	PARTICIPANT	\N	PRESENT	0
52179	52177	11031D	PARTICIPANT	\N	PRESENT	0
52180	52177	80013X	PARTICIPANT	\N	PRESENT	0
52181	52177	04035D	PARTICIPANT	\N	PRESENT	0
52182	52177	11061K	PARTICIPANT	\N	PRESENT	0
52183	52177	07026Q	PARTICIPANT	\N	PRESENT	0
52184	52177	09001P	PRESIDENT	0	PRESENT	0
52185	52177	04036E	PARTICIPANT	\N	PRESENT	0
52186	52177	07029T	PARTICIPANT	\N	PRESENT	0
52187	52177	11067R	PARTICIPANT	\N	PRESENT	0
52188	52177	14031R	PARTICIPANT	\N	EXCUSE	0
52189	52177	14237S	PARTICIPANT	\N	EXCUSE	0
52190	52177	08060W	PARTICIPANT	\N	EXCUSE	0
52191	52177	14030Q	PARTICIPANT	\N	EXCUSE	0
52192	52177	14041T	PARTICIPANT	\N	EXCUSE	0
52194	52193	11029K	PARTICIPANT	\N	PRESENT	0
52195	52193	11031D	PARTICIPANT	\N	PRESENT	0
52196	52193	11027H	PARTICIPANT	\N	PRESENT	0
52197	52193	80013X	PARTICIPANT	\N	PRESENT	0
52198	52193	14217N	PARTICIPANT	\N	PRESENT	0
52199	52193	98042T	PARTICIPANT	\N	PRESENT	0
52200	52193	12042Y	PARTICIPANT	\N	PRESENT	0
52201	52193	11061K	PARTICIPANT	\N	PRESENT	0
52202	52193	07026Q	PARTICIPANT	\N	PRESENT	0
52203	52193	95035G	PARTICIPANT	\N	PRESENT	0
52204	52193	09001P	PRESIDENT	0	PRESENT	0
52205	52193	08031R	PARTICIPANT	\N	PRESENT	0
52206	52193	07029T	PARTICIPANT	\N	PRESENT	0
52208	52193	08017T	PARTICIPANT	\N	PRESENT	0
52210	52193	11067R	PARTICIPANT	\N	PRESENT	0
52211	52193	11014C	PARTICIPANT	\N	PRESENT	0
52212	52193	14031R	PARTICIPANT	\N	PRESENT	0
52213	52193	08060W	PARTICIPANT	\N	PRESENT	0
52214	52193	14237S	PARTICIPANT	\N	EXCUSE	0
52216	52193	14030Q	PARTICIPANT	\N	EXCUSE	0
52218	52193	14041T	PARTICIPANT	\N	EXCUSE	0
52223	52221	09001P	PRESIDENT	0	PRESENT	0
52224	52221	11029K	PARTICIPANT	\N	PRESENT	0
52225	52221	11027H	PARTICIPANT	\N	PRESENT	0
52226	52221	04035D	PARTICIPANT	\N	PRESENT	0
52227	52221	07026Q	PARTICIPANT	\N	PRESENT	0
52229	52228	11027H	PARTICIPANT	\N	PRESENT	0
52230	52228	04035D	PARTICIPANT	\N	PRESENT	0
52231	52228	07026Q	PARTICIPANT	\N	PRESENT	0
52232	52193	04070G	PARTICIPANT	\N	PRESENT	0
52254	49835	11010L	PARTICIPANT	\N	EXCUSE	0
53414	53413	11039M	PARTICIPANT	\N	PRESENT	0
53415	53413	98042T	PARTICIPANT	\N	PRESENT	0
53416	53413	01019Q	PARTICIPANT	\N	PRESENT	0
53526	53475	01047U	PARTICIPANT	\N	PRESENT	0
53477	53475	04085P	PARTICIPANT	\N	PRESENT	0
53478	53475	05008E	PRESIDENT	0	PRESENT	0
53479	53475	11030C	PARTICIPANT	\N	PRESENT	0
53480	53475	11033F	PARTICIPANT	\N	PRESENT	0
53481	53475	14065Q	PARTICIPANT	\N	PRESENT	0
53482	53475	14069U	PARTICIPANT	\N	PRESENT	0
53483	53475	04047H	PARTICIPANT	\N	PRESENT	0
53484	53475	11032E	PARTICIPANT	\N	PRESENT	0
53485	53475	04038G	PARTICIPANT	\N	PRESENT	0
53584	53475	02002K	RAPPORTEUR_AVIS	\N	PRESENT	0
53487	53475	11056N	PARTICIPANT	\N	PRESENT	0
53585	53475	14147R	PARTICIPANT	\N	PRESENT	0
53489	53475	11035H	PARTICIPANT	\N	PRESENT	0
53951	53950	01008M	PARTICIPANT	\N	PRESENT	0
53491	53475	11113E	PARTICIPANT	\N	PRESENT	0
53492	53475	01024M	PARTICIPANT	\N	PRESENT	0
53493	53475	14215L	PARTICIPANT	\N	PRESENT	0
53494	53475	11034G	PARTICIPANT	\N	PRESENT	0
53495	53475	08018U	PARTICIPANT	\N	EXCUSE	0
53952	53950	11036J	PARTICIPANT	\N	PRESENT	0
53953	53950	11081P	PARTICIPANT	\N	PRESENT	0
53498	53475	11049P	PARTICIPANT	\N	PRESENT	0
53954	53950	14013P	PARTICIPANT	\N	PRESENT	0
53500	53475	11084S	PARTICIPANT	\N	PRESENT	0
53501	53475	11026G	PARTICIPANT	\N	PRESENT	0
53956	53950	14207L	PARTICIPANT	\N	PRESENT	0
53504	53475	14001X	PARTICIPANT	\N	PRESENT	0
53505	53475	14273W	PARTICIPANT	\N	PRESENT	0
53506	53475	01060R	PARTICIPANT	\N	PRESENT	0
53957	53950	11101A	PARTICIPANT	\N	PRESENT	0
53958	53950	90003B	PARTICIPANT	\N	PRESENT	0
53959	53950	08028W	PARTICIPANT	\N	PRESENT	0
53510	53475	11072N	PARTICIPANT	\N	PRESENT	0
53511	53475	07034Q	PARTICIPANT	\N	PRESENT	0
53512	53475	04074L	PARTICIPANT	\N	PRESENT	0
53960	53950	80013X	PARTICIPANT	\N	PRESENT	0
53514	53475	95063L	PARTICIPANT	\N	PRESENT	0
53961	53950	08038Y	PARTICIPANT	\N	PRESENT	0
53962	53950	04089T	PARTICIPANT	\N	PRESENT	0
53517	53475	98035U	PARTICIPANT	\N	PRESENT	0
53518	53475	04056J	PARTICIPANT	\N	PRESENT	0
53963	53950	14197C	PARTICIPANT	\N	PRESENT	0
53520	53475	04044E	PARTICIPANT	0	PRESENT	0
53521	53475	11037K	PARTICIPANT	\N	PRESENT	0
53522	53475	92045V	PARTICIPANT	\N	PRESENT	0
53965	53950	14187A	PARTICIPANT	\N	PRESENT	0
40826	32377	11089X	PARTICIPANT	\N	PRESENT	0
40829	32377	01058X	PARTICIPANT	\N	EXCUSE	0
40834	32377	14299H	PARTICIPANT	\N	EXCUSE	0
40163	40090	14151M	PARTICIPANT	\N	PRESENT	0
40842	32377	14221J	PARTICIPANT	\N	EXCUSE	0
40847	32377	83042R	PARTICIPANT	\N	EXCUSE	0
41114	41113	01031L	PRESIDENT	0	PRESENT	0
41115	41113	11068S	PARTICIPANT	\N	PRESENT	0
41116	41113	14167V	PARTICIPANT	\N	PRESENT	0
41118	41113	14175V	PARTICIPANT	\N	PRESENT	0
41119	41113	88008L	PARTICIPANT	\N	PRESENT	0
41120	41113	11083R	PARTICIPANT	\N	PRESENT	0
41121	41113	99004R	PARTICIPANT	\N	PRESENT	0
41122	41113	07029T	PARTICIPANT	\N	PRESENT	0
41123	41113	08034U	PARTICIPANT	\N	PRESENT	0
41124	41113	01016M	PARTICIPANT	\N	PRESENT	0
41125	41113	11057P	PARTICIPANT	\N	PRESENT	0
41126	41113	14173T	PARTICIPANT	\N	PRESENT	0
41150	41147	08012N	PARTICIPANT	\N	PRESENT	0
41151	41147	11094U	PARTICIPANT	\N	PRESENT	0
41152	41147	14179A	PARTICIPANT	\N	PRESENT	0
41156	41155	08012N	PARTICIPANT	\N	PRESENT	0
41157	41155	11094U	PARTICIPANT	\N	PRESENT	0
41158	41155	14179A	PARTICIPANT	\N	PRESENT	0
42951	41619	01027Q	PARTICIPANT	\N	EXCUSE	0
42977	41619	95062K	PARTICIPANT	\N	EXCUSE	0
42995	42957	14263U	PARTICIPANT	\N	PRESENT	0
42996	42957	14133K	PARTICIPANT	\N	PRESENT	0
43194	40901	11106F	PARTICIPANT	\N	EXCUSE	0
42998	42957	04059M	PARTICIPANT	\N	PRESENT	0
42999	42957	11039M	PARTICIPANT	\N	PRESENT	0
43000	42957	01044R	PARTICIPANT	\N	PRESENT	0
43001	42957	08043V	PARTICIPANT	\N	PRESENT	0
43002	42957	14089Y	PARTICIPANT	\N	PRESENT	0
43003	42957	14105F	PARTICIPANT	\N	PRESENT	0
43004	42957	11029K	PARTICIPANT	\N	PRESENT	0
43005	42957	95015C	PARTICIPANT	\N	PRESENT	0
43368	43367	95067Q	PARTICIPANT	\N	PRESENT	0
43372	43371	95067Q	PARTICIPANT	\N	PRESENT	0
43008	42957	14201E	PARTICIPANT	\N	EXCUSE	0
43374	43373	95067Q	PARTICIPANT	\N	PRESENT	0
43010	42957	14209N	PARTICIPANT	\N	PRESENT	0
43376	43375	95067Q	PARTICIPANT	\N	PRESENT	0
43012	42957	11091R	PARTICIPANT	\N	PRESENT	0
43013	42957	87003B	PARTICIPANT	\N	PRESENT	0
44617	44241	05004A	PARTICIPANT	\N	PRESENT	0
43015	42957	14249W	PARTICIPANT	\N	EXCUSE	0
44618	44241	01011G	PARTICIPANT	\N	PRESENT	0
43017	42957	01025N	PARTICIPANT	\N	PRESENT	0
44619	44241	11068S	PARTICIPANT	\N	PRESENT	0
44621	44620	01044R	PARTICIPANT	\N	EXCUSE	0
43020	42957	08035V	PARTICIPANT	\N	PRESENT	0
43021	42957	11089X	PARTICIPANT	\N	PRESENT	0
43022	42957	07026Q	PARTICIPANT	\N	PRESENT	0
43023	42957	14123H	PARTICIPANT	\N	PRESENT	0
43024	42957	14179A	PARTICIPANT	\N	PRESENT	0
44622	44620	01058X	PARTICIPANT	\N	EXCUSE	0
43026	42957	14241N	PARTICIPANT	\N	PRESENT	0
43027	42957	14061L	PARTICIPANT	\N	PRESENT	0
44623	44620	01016M	PARTICIPANT	\N	EXCUSE	0
43029	42957	08031R	PARTICIPANT	\N	PRESENT	0
44624	44620	04043D	PARTICIPANT	\N	EXCUSE	0
43031	42957	08039A	PARTICIPANT	\N	PRESENT	0
44625	44620	11082Q	PARTICIPANT	\N	EXCUSE	0
43033	42957	14059S	PARTICIPANT	\N	PRESENT	0
44626	44620	08039A	PARTICIPANT	\N	EXCUSE	0
44627	44620	08069G	PARTICIPANT	\N	EXCUSE	0
44628	44620	11089X	PARTICIPANT	\N	EXCUSE	0
43038	42957	14063N	PARTICIPANT	\N	PRESENT	0
43039	42957	04057K	PARTICIPANT	\N	PRESENT	0
43040	42957	11014C	PARTICIPANT	\N	PRESENT	0
43041	42957	14109K	PARTICIPANT	\N	PRESENT	0
43042	42957	04070G	PRESIDENT	0	PRESENT	0
44629	44620	80013X	PARTICIPANT	\N	EXCUSE	0
44630	44241	11032E	PARTICIPANT	\N	PRESENT	0
43045	42957	83047W	PARTICIPANT	\N	PRESENT	0
43046	42957	14235Q	PARTICIPANT	\N	PRESENT	0
44631	44241	14109K	PARTICIPANT	\N	PRESENT	0
44632	44241	11056N	PARTICIPANT	\N	PRESENT	0
43049	42957	14229S	PARTICIPANT	\N	PRESENT	0
43050	42957	11043H	PARTICIPANT	\N	PRESENT	0
44634	44241	01015L	PARTICIPANT	\N	PRESENT	0
44638	44248	01058X	PARTICIPANT	\N	PRESENT	0
44928	44242	86034E	PARTICIPANT	\N	PRESENT	0
44929	44242	95037J	PARTICIPANT	\N	PRESENT	0
44930	44242	95030B	PARTICIPANT	\N	PRESENT	0
44931	44242	01058X	PARTICIPANT	\N	PRESENT	0
44932	44242	08068F	PARTICIPANT	\N	PRESENT	0
44933	44242	11067R	PARTICIPANT	\N	PRESENT	0
44934	44242	01019Q	PARTICIPANT	\N	PRESENT	0
44935	44242	11110B	PARTICIPANT	\N	PRESENT	0
44936	44242	11012A	PARTICIPANT	\N	PRESENT	0
44937	44242	14187A	PARTICIPANT	\N	PRESENT	0
44938	44242	95031C	PARTICIPANT	\N	PRESENT	0
44939	44242	11034G	PARTICIPANT	\N	PRESENT	0
44940	44242	01025N	PARTICIPANT	\N	PRESENT	0
44941	44242	14281W	PARTICIPANT	\N	PRESENT	0
44942	44242	86044G	PARTICIPANT	\N	PRESENT	0
44943	44242	14087W	PARTICIPANT	\N	PRESENT	0
44944	44242	01003G	PARTICIPANT	\N	PRESENT	0
44945	44242	97011G	PARTICIPANT	\N	PRESENT	0
44946	44242	08065C	PARTICIPANT	\N	PRESENT	0
44947	44242	04044E	PARTICIPANT	\N	PRESENT	0
44948	44242	01037S	PARTICIPANT	\N	PRESENT	0
44949	44242	04043D	PARTICIPANT	\N	PRESENT	0
44950	44242	14034U	PARTICIPANT	\N	PRESENT	0
44951	44242	04035D	PARTICIPANT	\N	PRESENT	0
44952	44242	14231L	PARTICIPANT	\N	PRESENT	0
44953	44242	11083R	PARTICIPANT	\N	PRESENT	0
44954	44242	07024N	PARTICIPANT	\N	PRESENT	0
44955	44242	14199E	PARTICIPANT	\N	PRESENT	0
44956	44242	11061K	PARTICIPANT	\N	PRESENT	0
44957	44242	04045F	PARTICIPANT	\N	PRESENT	0
44958	44242	11025F	PARTICIPANT	\N	PRESENT	0
44959	44242	14107H	PARTICIPANT	\N	PRESENT	0
44960	44242	11089X	PARTICIPANT	\N	PRESENT	0
44961	44242	01011G	PARTICIPANT	\N	PRESENT	0
44962	44242	07026Q	PARTICIPANT	\N	PRESENT	0
44963	44242	11015D	PARTICIPANT	\N	PRESENT	0
44964	44242	07004J	PARTICIPANT	\N	PRESENT	0
44965	44242	01007L	PARTICIPANT	\N	PRESENT	0
44966	44242	04088S	PARTICIPANT	\N	PRESENT	0
44967	44242	08056B	PARTICIPANT	\N	PRESENT	0
44968	44242	14211G	PARTICIPANT	\N	PRESENT	0
44969	44242	14033T	PARTICIPANT	\N	PRESENT	0
44970	44242	11049P	PARTICIPANT	\N	PRESENT	0
44973	44242	10015M	PARTICIPANT	\N	PRESENT	0
44978	44242	95062K	PARTICIPANT	\N	PRESENT	0
44980	44242	01057W	PARTICIPANT	\N	PRESENT	0
44982	44242	98022P	PARTICIPANT	\N	PRESENT	0
45018	44242	11057P	PARTICIPANT	\N	PRESENT	0
45019	44242	14081Q	PARTICIPANT	\N	PRESENT	0
45020	44242	14179A	PARTICIPANT	\N	PRESENT	0
45021	44242	01022K	PARTICIPANT	\N	PRESENT	0
45022	44242	04048J	PARTICIPANT	\N	PRESENT	0
45023	44242	04078Q	PARTICIPANT	\N	PRESENT	0
45024	44242	04041B	PARTICIPANT	\N	PRESENT	0
45025	44242	08069G	PARTICIPANT	\N	PRESENT	0
45026	44242	04097T	PARTICIPANT	\N	PRESENT	0
45027	44242	11048N	PARTICIPANT	\N	PRESENT	0
45028	44242	14105F	PARTICIPANT	\N	PRESENT	0
45029	44242	14121F	PARTICIPANT	\N	PRESENT	0
45030	44242	14205J	PARTICIPANT	\N	PRESENT	0
45031	44242	14030Q	PARTICIPANT	\N	PRESENT	0
45032	44242	14097Y	PARTICIPANT	\N	PRESENT	0
45033	44242	14241N	PARTICIPANT	\N	PRESENT	0
45034	44242	95041E	PARTICIPANT	\N	PRESENT	0
45035	44242	11084S	PARTICIPANT	\N	PRESENT	0
45036	44242	04036E	PARTICIPANT	\N	PRESENT	0
45037	44242	11037K	PARTICIPANT	\N	PRESENT	0
45038	44242	99004R	PARTICIPANT	\N	PRESENT	0
45039	44242	04061F	PARTICIPANT	\N	PRESENT	0
45040	44242	14061L	PARTICIPANT	\N	PRESENT	0
45041	44242	14073Q	PARTICIPANT	\N	PRESENT	0
45042	44242	04077P	PARTICIPANT	\N	PRESENT	0
45043	44242	11099A	PARTICIPANT	\N	PRESENT	0
45044	44242	11112D	PARTICIPANT	\N	PRESENT	0
45045	44242	08031R	PARTICIPANT	\N	PRESENT	0
45048	44242	07029T	PARTICIPANT	\N	PRESENT	0
45049	44242	14159V	PARTICIPANT	\N	PRESENT	0
45050	44242	04049K	PARTICIPANT	\N	PRESENT	0
45053	44242	08060W	PARTICIPANT	\N	PRESENT	0
45054	44242	11111C	PARTICIPANT	\N	PRESENT	0
39046	39045	14263U	PARTICIPANT	\N	PRESENT	0
39047	39045	14133K	PARTICIPANT	\N	PRESENT	0
39380	39379	08025T	PARTICIPANT	\N	PRESENT	0
39049	39045	04059M	PARTICIPANT	\N	PRESENT	0
39050	39045	11039M	PARTICIPANT	\N	PRESENT	0
39051	39045	01044R	PARTICIPANT	\N	PRESENT	0
39052	39045	08043V	PARTICIPANT	\N	PRESENT	0
39053	39045	14089Y	PARTICIPANT	\N	PRESENT	0
39054	39045	14105F	PARTICIPANT	\N	PRESENT	0
39055	39045	11029K	PARTICIPANT	\N	PRESENT	0
39381	39379	04085P	PARTICIPANT	\N	PRESENT	0
39057	39045	92015P	PARTICIPANT	\N	PRESENT	0
39058	39045	08024S	PARTICIPANT	\N	PRESENT	0
39059	39045	14201E	PARTICIPANT	\N	EXCUSE	0
39382	39379	05008E	PRESIDENT	0	PRESENT	0
39061	39045	14209N	PARTICIPANT	\N	PRESENT	0
39062	39045	14079W	PARTICIPANT	\N	PRESENT	0
39063	39045	11091R	PARTICIPANT	\N	PRESENT	0
39064	39045	87003B	PARTICIPANT	\N	PRESENT	0
39065	39045	98042T	PARTICIPANT	\N	PRESENT	0
39066	39045	14249W	PARTICIPANT	\N	PRESENT	0
39067	39045	01041N	PARTICIPANT	\N	PRESENT	0
39068	39045	01025N	PARTICIPANT	\N	PRESENT	0
39069	39045	01037S	PARTICIPANT	\N	PRESENT	0
39070	39045	89029V	PARTICIPANT	\N	PRESENT	0
39071	39045	08035V	PARTICIPANT	\N	PRESENT	0
39383	39379	11030C	PARTICIPANT	\N	PRESENT	0
39073	39045	07026Q	PARTICIPANT	\N	PRESENT	0
39074	39045	14123H	PARTICIPANT	\N	PRESENT	0
39075	39045	14179A	PARTICIPANT	\N	PRESENT	0
39076	39045	04041B	PARTICIPANT	\N	PRESENT	0
39077	39045	14241N	PARTICIPANT	\N	PRESENT	0
39078	39045	14061L	PARTICIPANT	\N	PRESENT	0
39079	39045	14073Q	PARTICIPANT	\N	PRESENT	0
39080	39045	08031R	PARTICIPANT	\N	PRESENT	0
39081	39045	12041X	PARTICIPANT	\N	PRESENT	0
39082	39045	08039A	PARTICIPANT	\N	PRESENT	0
39083	39045	08017T	PARTICIPANT	\N	PRESENT	0
39084	39045	14059S	PARTICIPANT	\N	PRESENT	0
39085	39045	08012N	PARTICIPANT	\N	PRESENT	0
39086	39045	14103D	PARTICIPANT	\N	PRESENT	0
39087	39045	11104D	PARTICIPANT	\N	PRESENT	0
39614	39572	01016M	PARTICIPANT	\N	PRESENT	0
39089	39045	04057K	PARTICIPANT	\N	PRESENT	0
39090	39045	11014C	PARTICIPANT	\N	PRESENT	0
39091	39045	14109K	PARTICIPANT	\N	PRESENT	0
39092	39045	04070G	PRESIDENT	0	PRESENT	0
39093	39045	92040Q	PARTICIPANT	\N	PRESENT	0
39385	39379	14065Q	PARTICIPANT	\N	PRESENT	0
39095	39045	83047W	PARTICIPANT	\N	PRESENT	0
39096	39045	14235Q	PARTICIPANT	\N	PRESENT	0
39097	39045	14055N	PARTICIPANT	\N	PRESENT	0
39098	39045	04033B	PARTICIPANT	\N	PRESENT	0
39099	39045	14229S	PARTICIPANT	\N	PRESENT	0
39100	39045	11043H	PARTICIPANT	\N	PRESENT	0
39101	39045	11071M	PARTICIPANT	\N	PRESENT	0
39386	39379	14069U	PARTICIPANT	\N	PRESENT	0
39387	39379	04047H	PARTICIPANT	\N	PRESENT	0
39388	39379	11032E	PARTICIPANT	\N	PRESENT	0
39389	39379	04038G	PARTICIPANT	\N	PRESENT	0
39390	39379	99002P	PARTICIPANT	\N	PRESENT	0
39391	39379	11056N	PARTICIPANT	\N	PRESENT	0
39392	39379	14259Y	PARTICIPANT	\N	PRESENT	0
39393	39379	11035H	PARTICIPANT	\N	PRESENT	0
39394	39379	14041T	PARTICIPANT	\N	PRESENT	0
39519	31452	11109J	PARTICIPANT	\N	EXCUSE	0
39396	39379	01024M	PARTICIPANT	\N	PRESENT	0
39397	39379	14215L	PARTICIPANT	\N	PRESENT	0
39398	39379	11034G	PARTICIPANT	\N	PRESENT	0
39399	39379	08018U	PARTICIPANT	\N	PRESENT	0
39400	39379	11010L	PARTICIPANT	\N	PRESENT	0
39401	39379	01007L	PARTICIPANT	\N	PRESENT	0
39402	39379	11049P	PARTICIPANT	\N	PRESENT	0
39403	39379	08044W	PARTICIPANT	\N	PRESENT	0
39404	39379	11084S	PARTICIPANT	\N	PRESENT	0
39405	39379	11026G	PARTICIPANT	\N	PRESENT	0
39406	39379	04079R	PARTICIPANT	\N	PRESENT	0
39407	39379	14111D	PARTICIPANT	\N	PRESENT	0
39408	39379	14001X	PARTICIPANT	\N	PRESENT	0
39574	39572	01008M	PARTICIPANT	\N	PRESENT	0
39410	39379	01060R	PARTICIPANT	\N	PRESENT	0
39411	39379	14147R	PARTICIPANT	\N	PRESENT	0
39412	39379	95049N	PARTICIPANT	\N	PRESENT	0
39413	39379	08051V	PARTICIPANT	\N	PRESENT	0
39414	39379	11072N	PARTICIPANT	\N	PRESENT	0
39415	39379	07034Q	PARTICIPANT	\N	PRESENT	0
39416	39379	04074L	PARTICIPANT	\N	PRESENT	0
39417	39379	10015M	PARTICIPANT	\N	PRESENT	0
39418	39379	95063L	PARTICIPANT	\N	PRESENT	0
39419	39379	01019Q	PARTICIPANT	\N	PRESENT	0
39420	39379	01028R	PRESIDENT	1	PRESENT	0
39421	39379	98035U	PARTICIPANT	\N	PRESENT	0
39422	39379	04056J	PARTICIPANT	\N	PRESENT	0
39423	39379	14275Y	PARTICIPANT	\N	PRESENT	0
39424	39379	04044E	PARTICIPANT	\N	PRESENT	0
39425	39379	11037K	PARTICIPANT	\N	PRESENT	0
39426	39379	92045V	PARTICIPANT	\N	PRESENT	0
39427	39379	95067Q	PARTICIPANT	\N	PRESENT	0
39428	39379	01047U	PARTICIPANT	\N	PRESENT	0
39575	39572	11036J	PARTICIPANT	\N	PRESENT	0
42667	42666	01008M	PARTICIPANT	\N	PRESENT	0
39577	39572	14013P	PARTICIPANT	\N	PRESENT	0
39578	39572	08068F	PARTICIPANT	\N	PRESENT	0
39579	39572	14207L	PARTICIPANT	\N	PRESENT	0
39580	39572	11101A	PARTICIPANT	\N	PRESENT	0
39581	39572	90003B	PARTICIPANT	\N	PRESENT	0
39582	39572	08028W	PARTICIPANT	\N	PRESENT	0
39583	39572	80013X	PARTICIPANT	\N	PRESENT	0
39584	39572	08038Y	PARTICIPANT	\N	PRESENT	0
39585	39572	04089T	PARTICIPANT	\N	PRESENT	0
39586	39572	14197C	PARTICIPANT	\N	EXCUSE	0
42668	42666	11036J	PARTICIPANT	\N	PRESENT	0
39588	39572	14187A	PARTICIPANT	\N	PRESENT	0
39589	39572	14033T	PARTICIPANT	\N	PRESENT	0
39590	39572	14081Q	PARTICIPANT	\N	PRESENT	0
39591	39572	04048J	PARTICIPANT	\N	PRESENT	0
39592	39572	11099A	PARTICIPANT	\N	PRESENT	0
39593	39572	04049K	PARTICIPANT	\N	PRESENT	0
42669	42666	11081P	PARTICIPANT	\N	PRESENT	0
39595	39572	11111C	PARTICIPANT	\N	PRESENT	0
39596	39572	08015R	PARTICIPANT	\N	PRESENT	0
39597	39572	11100Y	PRESIDENT	0	PRESENT	0
39598	39572	01061S	PARTICIPANT	\N	PRESENT	0
39599	39572	11098Y	PARTICIPANT	\N	PRESENT	0
39600	39572	01043Q	PARTICIPANT	\N	PRESENT	0
39601	39572	11077T	PARTICIPANT	\N	PRESENT	0
39602	39572	14205J	PARTICIPANT	\N	PRESENT	0
39603	39572	08019V	PARTICIPANT	\N	PRESENT	0
39604	39572	14257W	PARTICIPANT	\N	PRESENT	0
39605	39572	08021P	PARTICIPANT	\N	EXCUSE	0
39606	39572	04088S	PARTICIPANT	\N	PRESENT	0
39607	39572	98050T	PARTICIPANT	\N	PRESENT	0
39608	39572	11090Q	PARTICIPANT	\N	PRESENT	0
39609	39572	11046L	PARTICIPANT	\N	PRESENT	0
39610	39572	01058X	PARTICIPANT	\N	PRESENT	0
39612	39572	11066Q	PARTICIPANT	\N	PRESENT	0
42670	42666	14013P	PARTICIPANT	\N	PRESENT	0
42671	42666	08068F	PARTICIPANT	\N	PRESENT	0
42672	42666	14207L	PARTICIPANT	\N	PRESENT	0
42673	42666	11101A	PARTICIPANT	\N	PRESENT	0
42674	42666	90003B	PARTICIPANT	\N	PRESENT	0
42675	42666	08028W	PARTICIPANT	\N	PRESENT	0
42676	42666	80013X	PARTICIPANT	\N	PRESENT	0
42677	42666	08038Y	PARTICIPANT	\N	PRESENT	0
42678	42666	04089T	PARTICIPANT	\N	PRESENT	0
42679	42666	14197C	PARTICIPANT	\N	PRESENT	0
42681	42666	14187A	PARTICIPANT	\N	PRESENT	0
42682	42666	14033T	PARTICIPANT	\N	PRESENT	0
42683	42666	14081Q	PARTICIPANT	\N	PRESENT	0
42684	42666	04048J	PARTICIPANT	\N	EXCUSE	0
42685	42666	11099A	PARTICIPANT	\N	PRESENT	0
42686	42666	04049K	PARTICIPANT	\N	PRESENT	0
42687	42666	04094Q	PARTICIPANT	\N	EXCUSE	0
42688	42666	11111C	PARTICIPANT	\N	PRESENT	0
42689	42666	08015R	PARTICIPANT	\N	PRESENT	0
42690	42666	11100Y	PRESIDENT	0	PRESENT	0
42691	42666	01061S	PARTICIPANT	\N	EXCUSE	0
42692	42666	11098Y	PARTICIPANT	\N	PRESENT	0
42693	42666	01043Q	PARTICIPANT	\N	PRESENT	0
42694	42666	11077T	PARTICIPANT	\N	PRESENT	0
42695	42666	14205J	PARTICIPANT	\N	PRESENT	0
42696	42666	08019V	PARTICIPANT	\N	PRESENT	0
42697	42666	14257W	PARTICIPANT	\N	PRESENT	0
42698	42666	08021P	PARTICIPANT	\N	PRESENT	0
42699	42666	04088S	PARTICIPANT	\N	PRESENT	0
42700	42666	98050T	PARTICIPANT	\N	PRESENT	0
42701	42666	11090Q	PARTICIPANT	\N	PRESENT	0
42702	42666	11046L	PARTICIPANT	\N	PRESENT	0
38533	38484	07032N	PARTICIPANT	\N	PRESENT	0
38534	38484	04043D	PARTICIPANT	\N	PRESENT	0
38535	38484	14271U	PARTICIPANT	\N	PRESENT	0
38536	38484	11093T	PARTICIPANT	\N	PRESENT	0
38537	38484	11097X	PARTICIPANT	\N	PRESENT	0
38538	38484	14227Q	PARTICIPANT	\N	PRESENT	0
38539	38484	01034P	PARTICIPANT	\N	PRESENT	0
38540	38484	14269B	PARTICIPANT	\N	PRESENT	0
38896	38895	92045V	PARTICIPANT	\N	PRESENT	0
38983	38982	89017R	PARTICIPANT	\N	PRESENT	0
38984	38982	01031L	PRESIDENT	0	PRESENT	0
39103	37248	14299H	PARTICIPANT	\N	PRESENT	0
38986	38982	01013J	PARTICIPANT	\N	PRESENT	0
38987	38982	11068S	PARTICIPANT	\N	EXCUSE	0
38988	38982	11040E	PARTICIPANT	\N	PRESENT	0
38989	38982	08014Q	PARTICIPANT	\N	PRESENT	0
38990	38982	14167V	PARTICIPANT	\N	PRESENT	0
38991	38982	14175V	PARTICIPANT	\N	PRESENT	0
38992	38982	14083S	PARTICIPANT	\N	PRESENT	0
38993	38982	11053K	PARTICIPANT	\N	PRESENT	0
38994	38982	14085U	PARTICIPANT	\N	PRESENT	0
38995	38982	11042G	PARTICIPANT	\N	PRESENT	0
38996	38982	88008L	PARTICIPANT	\N	PRESENT	0
38997	38982	04086Q	PARTICIPANT	\N	PRESENT	0
38998	38982	04055H	PARTICIPANT	\N	PRESENT	0
38999	38982	11070L	PARTICIPANT	\N	PRESENT	0
39000	38982	11088W	PARTICIPANT	\N	PRESENT	0
39001	38982	14327T	PARTICIPANT	\N	PRESENT	0
39002	38982	08022Q	PARTICIPANT	\N	PRESENT	0
39003	38982	01027Q	PARTICIPANT	\N	PRESENT	0
39005	38982	11074Q	PARTICIPANT	\N	PRESENT	0
39006	38982	98053W	PARTICIPANT	\N	EXCUSE	0
39007	38982	11083R	PARTICIPANT	\N	PRESENT	0
39008	38982	14199E	PARTICIPANT	\N	PRESENT	0
39009	38982	01057W	PARTICIPANT	\N	PRESENT	0
39010	38982	08016S	PARTICIPANT	\N	PRESENT	0
39011	38982	08069G	PARTICIPANT	\N	PRESENT	0
39012	38982	11048N	PARTICIPANT	\N	PRESENT	0
39013	38982	99004R	PARTICIPANT	\N	PRESENT	0
39014	38982	04061F	PARTICIPANT	\N	PRESENT	0
39016	38982	07029T	PARTICIPANT	\N	PRESENT	0
39017	38982	14277B	PARTICIPANT	\N	PRESENT	0
39018	38982	08010L	PARTICIPANT	\N	PRESENT	0
39019	38982	08034U	PARTICIPANT	\N	PRESENT	0
39020	38982	01048V	PARTICIPANT	\N	PRESENT	0
39021	38982	98046X	PARTICIPANT	\N	PRESENT	0
39023	38982	08011M	PARTICIPANT	\N	PRESENT	0
39024	38982	08073C	PARTICIPANT	\N	PRESENT	0
39025	38982	08061X	PARTICIPANT	\N	PRESENT	0
39026	38982	01016M	PARTICIPANT	\N	PRESENT	0
39027	38982	14225N	PARTICIPANT	\N	PRESENT	0
39028	38982	11012A	PARTICIPANT	\N	PRESENT	0
39029	38982	11057P	PARTICIPANT	\N	PRESENT	0
39030	38982	14173T	PARTICIPANT	\N	PRESENT	0
39031	38982	04034C	PARTICIPANT	\N	PRESENT	0
39107	37248	01058X	PARTICIPANT	\N	PRESENT	0
39108	37248	04043D	PARTICIPANT	\N	PRESENT	0
41672	41299	14119M	PARTICIPANT	\N	PRESENT	0
39116	37248	01016M	PARTICIPANT	\N	EXCUSE	0
39111	37248	14209N	PARTICIPANT	\N	PRESENT	0
39112	37248	80013X	PARTICIPANT	\N	PRESENT	0
39113	37248	11089X	PARTICIPANT	\N	PRESENT	0
39114	37248	11036J	PARTICIPANT	\N	PRESENT	0
39115	37248	14263U	PARTICIPANT	\N	EXCUSE	0
39117	37248	01044R	PARTICIPANT	\N	PRESENT	0
41670	41299	11111C	PARTICIPANT	\N	PRESENT	0
41671	41299	11090Q	PARTICIPANT	\N	PRESENT	0
41673	41299	07029T	PARTICIPANT	\N	PRESENT	0
41674	41299	11099A	PARTICIPANT	\N	PRESENT	0
41675	41299	11012A	PARTICIPANT	\N	PRESENT	0
41676	41299	14221J	PARTICIPANT	\N	PRESENT	0
41677	41299	14235Q	PARTICIPANT	\N	PRESENT	0
41678	41299	11074Q	PARTICIPANT	\N	PRESENT	0
41679	41299	08010L	PARTICIPANT	\N	PRESENT	0
41680	41299	11114F	PARTICIPANT	\N	PRESENT	0
41681	41299	14111D	PARTICIPANT	\N	PRESENT	0
41682	41299	11048N	PARTICIPANT	\N	PRESENT	0
41683	41299	05012A	PARTICIPANT	\N	PRESENT	0
41684	41299	80013X	PARTICIPANT	\N	PRESENT	0
41685	41299	11053K	PARTICIPANT	\N	PRESENT	0
41686	41299	14327T	PARTICIPANT	\N	PRESENT	0
41687	41299	01037S	PARTICIPANT	\N	PRESENT	0
41951	41950	14263U	PARTICIPANT	\N	PRESENT	0
42703	42666	01058X	PARTICIPANT	\N	PRESENT	0
42704	42666	11094U	PARTICIPANT	\N	PRESENT	0
41954	41950	04059M	PARTICIPANT	\N	PRESENT	0
42705	42666	11066Q	PARTICIPANT	\N	PRESENT	0
41956	41950	01044R	PARTICIPANT	\N	PRESENT	0
41957	41950	08043V	PARTICIPANT	\N	EXCUSE	0
41958	41950	14089Y	PARTICIPANT	\N	PRESENT	0
41959	41950	14105F	PARTICIPANT	\N	PRESENT	0
41960	41950	11029K	PARTICIPANT	\N	PRESENT	0
41961	41950	95015C	PARTICIPANT	\N	PRESENT	0
41962	41950	92015P	PARTICIPANT	\N	PRESENT	0
41963	41950	08024S	PARTICIPANT	\N	PRESENT	0
41964	41950	14201E	PARTICIPANT	\N	EXCUSE	0
41965	41950	14329V	PARTICIPANT	\N	PRESENT	0
41966	41950	14209N	PARTICIPANT	\N	PRESENT	0
42755	42715	11053K	PARTICIPANT	\N	PRESENT	0
41968	41950	11091R	PARTICIPANT	\N	PRESENT	0
41969	41950	87003B	PARTICIPANT	\N	PRESENT	0
42717	42715	08055A	PARTICIPANT	\N	PRESENT	0
41971	41950	14249W	PARTICIPANT	\N	EXCUSE	0
41972	41950	01041N	PARTICIPANT	\N	PRESENT	0
41973	41950	01025N	PARTICIPANT	\N	PRESENT	0
41974	41950	01037S	PARTICIPANT	\N	PRESENT	0
42718	42715	14093U	PARTICIPANT	\N	PRESENT	0
42719	42715	14030Q	PARTICIPANT	\N	PRESENT	0
42720	42715	96004D	PARTICIPANT	\N	PRESENT	0
41978	41950	07026Q	PARTICIPANT	\N	PRESENT	0
41979	41950	14123H	PARTICIPANT	\N	PRESENT	0
41980	41950	14179A	PARTICIPANT	\N	PRESENT	0
43165	40901	01027Q	PARTICIPANT	\N	EXCUSE	0
41982	41950	14241N	PARTICIPANT	\N	PRESENT	0
41983	41950	14061L	PARTICIPANT	\N	PRESENT	0
41984	41950	14073Q	PARTICIPANT	\N	PRESENT	0
41985	41950	08031R	PARTICIPANT	\N	PRESENT	0
43985	43984	14105F	PARTICIPANT	\N	PRESENT	0
41987	41950	08039A	PARTICIPANT	\N	PRESENT	0
41988	41950	08017T	PARTICIPANT	\N	PRESENT	0
41989	41950	14059S	PARTICIPANT	\N	PRESENT	0
41990	41950	08012N	PARTICIPANT	\N	PRESENT	0
42723	42715	11095V	PARTICIPANT	\N	PRESENT	0
41992	41950	11104D	PARTICIPANT	\N	PRESENT	0
41993	41950	14063N	PARTICIPANT	\N	PRESENT	0
41994	41950	04057K	PARTICIPANT	\N	PRESENT	0
41995	41950	11014C	PARTICIPANT	\N	PRESENT	0
41996	41950	14109K	PARTICIPANT	\N	PRESENT	0
41997	41950	04070G	PRESIDENT	0	PRESENT	0
41998	41950	92040Q	PARTICIPANT	\N	PRESENT	0
42724	42715	14038Y	PARTICIPANT	\N	PRESENT	0
43986	43984	11103C	PARTICIPANT	\N	PRESENT	0
42001	41950	14235Q	PARTICIPANT	\N	EXCUSE	0
43987	43984	11044J	PARTICIPANT	\N	PRESENT	0
43988	43984	90003B	PARTICIPANT	\N	PRESENT	0
42004	41950	14229S	PARTICIPANT	\N	PRESENT	0
42728	42715	01015L	PARTICIPANT	\N	PRESENT	0
42729	42715	11107G	PARTICIPANT	\N	PRESENT	0
43989	43984	04089T	PARTICIPANT	\N	PRESENT	0
43990	43984	14063N	PARTICIPANT	\N	PRESENT	0
42731	42715	02002K	PARTICIPANT	\N	PRESENT	0
42732	42715	01022K	PARTICIPANT	\N	PRESENT	0
43991	43984	08061X	PARTICIPANT	\N	PRESENT	0
42734	42715	09001P	PARTICIPANT	\N	EXCUSE	0
43992	43984	07032N	PARTICIPANT	\N	PRESENT	0
42736	42715	14219Q	PARTICIPANT	\N	PRESENT	0
43993	43984	98050T	PARTICIPANT	\N	PRESENT	0
42738	42715	14031R	PARTICIPANT	\N	PRESENT	0
42739	42715	08009T	PRESIDENT	0	PRESENT	0
42740	42715	08062Y	PARTICIPANT	\N	PRESENT	0
42741	42715	14221J	PARTICIPANT	\N	PRESENT	0
42742	42715	92039X	PARTICIPANT	\N	PRESENT	0
42743	42715	08042U	PARTICIPANT	\N	PRESENT	0
42744	42715	14169X	PARTICIPANT	\N	PRESENT	0
42745	42715	14237S	PARTICIPANT	\N	PRESENT	0
42746	42715	13002U	PARTICIPANT	\N	EXCUSE	0
42747	42715	05012A	PARTICIPANT	\N	PRESENT	0
43994	43984	11090Q	PARTICIPANT	\N	PRESENT	0
42749	42715	14135M	PARTICIPANT	\N	PRESENT	0
43995	43984	14271U	PARTICIPANT	\N	PRESENT	0
42751	42715	14107H	PARTICIPANT	\N	PRESENT	0
42752	42715	14051J	PARTICIPANT	\N	PRESENT	0
43996	43984	92045V	PARTICIPANT	\N	PRESENT	0
42754	42715	96003C	PARTICIPANT	\N	EXCUSE	0
43998	43997	95062K	PARTICIPANT	\N	PRESENT	0
44040	44039	95063L	PARTICIPANT	\N	PRESENT	0
38386	38385	01061S	PARTICIPANT	\N	PRESENT	0
38438	38437	01008M	PARTICIPANT	\N	PRESENT	0
38441	38437	14038Y	PARTICIPANT	\N	PRESENT	0
38442	38437	14195A	PARTICIPANT	\N	PRESENT	0
38443	38437	01059Y	PARTICIPANT	\N	PRESENT	0
38444	38437	01003G	PARTICIPANT	\N	PRESENT	0
38445	38437	14221J	PARTICIPANT	\N	PRESENT	0
38446	38437	14107H	PARTICIPANT	\N	PRESENT	0
38447	38437	14197C	PARTICIPANT	\N	PRESENT	0
38448	38437	14327T	PARTICIPANT	\N	PRESENT	0
38455	38454	05012A	PARTICIPANT	\N	PRESENT	0
38457	38456	05012A	PARTICIPANT	\N	PRESENT	0
38462	38459	04049K	PARTICIPANT	\N	PRESENT	0
38464	38463	08068F	PARTICIPANT	\N	PRESENT	0
38542	38541	04049K	PARTICIPANT	\N	PRESENT	0
38492	38465	08042U	PARTICIPANT	\N	PRESENT	0
38505	38502	08042U	PRESIDENT	0	PRESENT	0
38544	38543	04049K	PARTICIPANT	\N	PRESENT	0
39184	39183	14239U	PARTICIPANT	\N	PRESENT	0
39185	39183	11055M	PARTICIPANT	\N	PRESENT	0
39186	39183	01046T	PARTICIPANT	\N	PRESENT	0
39187	39183	04053F	PARTICIPANT	\N	PRESENT	0
39188	39183	14255U	PARTICIPANT	\N	PRESENT	0
39189	39183	04066L	PARTICIPANT	\N	PRESENT	0
39190	39183	00003C	PARTICIPANT	\N	PRESENT	0
39191	39183	14053L	PARTICIPANT	\N	PRESENT	0
39192	39183	11103C	PARTICIPANT	\N	PRESENT	0
39193	39183	11044J	PARTICIPANT	\N	PRESENT	0
39194	39183	14195A	PARTICIPANT	\N	PRESENT	0
39195	39183	14267Y	PARTICIPANT	\N	PRESENT	0
39196	39183	11023D	PARTICIPANT	\N	PRESENT	0
39197	39183	11031D	PARTICIPANT	\N	PRESENT	0
39198	39183	08052W	PARTICIPANT	\N	PRESENT	0
39199	39183	01059Y	PARTICIPANT	\N	PRESENT	0
39242	39241	14261S	PARTICIPANT	\N	PRESENT	0
39201	39183	98024R	PARTICIPANT	\N	PRESENT	0
39202	39183	10006L	PARTICIPANT	\N	PRESENT	0
39203	39183	04067M	PARTICIPANT	\N	PRESENT	0
39204	39183	14217N	PARTICIPANT	\N	PRESENT	0
39205	39183	14042U	PARTICIPANT	\N	PRESENT	0
39206	39183	14151M	PARTICIPANT	\N	PRESENT	0
39207	39183	12042Y	PARTICIPANT	\N	PRESENT	0
39208	39183	14281W	PARTICIPANT	\N	PRESENT	0
39209	39183	14087W	PARTICIPANT	\N	PRESENT	0
39243	39241	08055A	PARTICIPANT	\N	PRESENT	0
39211	39183	14034U	PARTICIPANT	\N	PRESENT	0
39212	39183	14231L	PARTICIPANT	\N	PRESENT	0
39282	39281	14261S	PARTICIPANT	\N	PRESENT	0
39214	39183	08048B	PARTICIPANT	\N	PRESENT	0
39215	39183	08041T	PARTICIPANT	\N	EXCUSE	0
39245	39241	14030Q	PARTICIPANT	\N	PRESENT	0
39217	39183	14026U	PARTICIPANT	\N	PRESENT	0
39218	39183	14213J	PARTICIPANT	\N	PRESENT	0
39219	39183	14121F	PARTICIPANT	\N	PRESENT	0
39220	39183	11112D	PARTICIPANT	\N	PRESENT	0
39221	39183	14037X	PARTICIPANT	\N	PRESENT	0
39222	39183	14018U	PARTICIPANT	\N	PRESENT	0
39223	39183	11067R	PARTICIPANT	\N	PRESENT	0
39224	39183	14223L	PARTICIPANT	\N	PRESENT	0
39225	39183	04092N	PRESIDENT	0	PRESENT	0
39226	39183	14265W	PARTICIPANT	\N	PRESENT	0
39227	39183	14119M	PARTICIPANT	\N	PRESENT	0
39228	39183	14071N	PARTICIPANT	\N	PRESENT	0
39229	39183	07032N	PARTICIPANT	\N	PRESENT	0
39230	39183	04043D	PARTICIPANT	\N	PRESENT	0
39231	39183	14271U	PARTICIPANT	\N	PRESENT	0
39246	39241	96004D	PARTICIPANT	\N	PRESENT	0
39247	39241	08060W	PARTICIPANT	\N	PRESENT	0
39234	39183	11097X	PARTICIPANT	\N	PRESENT	0
39248	39241	11060J	PARTICIPANT	\N	PRESENT	0
39236	39183	14227Q	PARTICIPANT	\N	PRESENT	0
39237	39183	01034P	PARTICIPANT	\N	PRESENT	0
39238	39183	11025F	PARTICIPANT	\N	PRESENT	0
39239	39183	11063M	PARTICIPANT	\N	PRESENT	0
39240	39183	14269B	PARTICIPANT	\N	PRESENT	0
39249	39241	11095V	PARTICIPANT	\N	PRESENT	0
39250	39241	14038Y	PARTICIPANT	\N	EXCUSE	0
39251	39241	11114F	PARTICIPANT	\N	PRESENT	0
39252	39241	98023Q	PARTICIPANT	\N	PRESENT	0
39253	39241	11065P	PARTICIPANT	\N	PRESENT	0
39254	39241	01015L	PARTICIPANT	\N	PRESENT	0
39255	39241	11107G	PARTICIPANT	\N	PRESENT	0
39257	39241	02002K	PARTICIPANT	\N	PRESENT	0
39258	39241	01022K	PARTICIPANT	\N	PRESENT	0
39259	39241	04097T	PARTICIPANT	\N	PRESENT	0
39260	39241	09001P	PARTICIPANT	\N	PRESENT	0
39261	39241	11059R	PARTICIPANT	\N	PRESENT	0
39262	39241	14219Q	PARTICIPANT	\N	PRESENT	0
39263	39241	80027E	PARTICIPANT	\N	PRESENT	0
39264	39241	14031R	PARTICIPANT	\N	PRESENT	0
39265	39241	08009T	PRESIDENT	0	PRESENT	0
39267	39241	14221J	PARTICIPANT	\N	PRESENT	0
39268	39241	92039X	PARTICIPANT	\N	PRESENT	0
39269	39241	08042U	PARTICIPANT	\N	PRESENT	0
39270	39241	14169X	PARTICIPANT	\N	PRESENT	0
39271	39241	14237S	PARTICIPANT	\N	PRESENT	0
39272	39241	13002U	PARTICIPANT	\N	PRESENT	0
39273	39241	05012A	PARTICIPANT	\N	PRESENT	0
39285	39281	14030Q	PARTICIPANT	\N	PRESENT	0
39275	39241	14135M	PARTICIPANT	\N	PRESENT	0
39276	39241	95062K	PARTICIPANT	\N	PRESENT	0
39277	39241	14107H	PARTICIPANT	\N	PRESENT	0
39278	39241	14051J	PARTICIPANT	\N	PRESENT	0
39279	39241	14157T	PARTICIPANT	\N	PRESENT	0
39280	39241	96003C	PARTICIPANT	\N	EXCUSE	0
39286	39281	96004D	PARTICIPANT	\N	PRESENT	0
39287	39281	08060W	PARTICIPANT	\N	PRESENT	0
39289	39281	11095V	PARTICIPANT	\N	PRESENT	0
39290	39281	14038Y	PARTICIPANT	\N	EXCUSE	0
39291	39281	11114F	PARTICIPANT	\N	PRESENT	0
39294	39281	01015L	PARTICIPANT	\N	PRESENT	0
39295	39281	11107G	PARTICIPANT	\N	PRESENT	0
39298	39281	01022K	PARTICIPANT	\N	PRESENT	0
39299	39281	04097T	PARTICIPANT	\N	PRESENT	0
39301	39281	11059R	PARTICIPANT	\N	PRESENT	0
39302	39281	14219Q	PARTICIPANT	\N	PRESENT	0
39303	39281	80027E	PARTICIPANT	\N	PRESENT	0
39304	39281	14031R	PARTICIPANT	\N	PRESENT	0
39305	39281	08009T	PRESIDENT	0	PRESENT	0
39307	39281	14221J	PARTICIPANT	\N	PRESENT	0
39308	39281	92039X	PARTICIPANT	\N	PRESENT	0
39310	39281	14169X	PARTICIPANT	\N	PRESENT	0
39311	39281	14237S	PARTICIPANT	\N	PRESENT	0
39312	39281	13002U	PARTICIPANT	\N	PRESENT	0
39313	39281	05012A	PARTICIPANT	\N	PRESENT	0
39315	39281	14135M	PARTICIPANT	\N	PRESENT	0
39316	39281	95062K	PARTICIPANT	\N	PRESENT	0
39317	39281	14107H	PARTICIPANT	\N	PRESENT	0
39319	39281	14157T	PARTICIPANT	\N	PRESENT	0
39320	39281	96003C	PARTICIPANT	\N	EXCUSE	0
45055	44242	98005N	PARTICIPANT	\N	PRESENT	0
45056	44242	12041X	PARTICIPANT	\N	PRESENT	0
45057	44242	05008E	PARTICIPANT	\N	PRESENT	0
45058	44242	14083S	PARTICIPANT	\N	PRESENT	0
45059	44242	92031P	PARTICIPANT	\N	PRESENT	0
45060	44242	08010L	PARTICIPANT	\N	PRESENT	0
45061	44242	08034U	PARTICIPANT	\N	PRESENT	0
45062	44242	14037X	PARTICIPANT	\N	PRESENT	0
45063	44242	08039A	PARTICIPANT	\N	PRESENT	0
45064	44242	11100Y	PARTICIPANT	\N	PRESENT	0
45065	44242	08017T	PARTICIPANT	\N	PRESENT	0
45066	44242	11059R	PARTICIPANT	\N	PRESENT	0
45067	44242	11098Y	PARTICIPANT	\N	PRESENT	0
45068	44242	01061S	PARTICIPANT	\N	PRESENT	0
45069	44242	11093T	PARTICIPANT	\N	PRESENT	0
45070	44242	11077T	PARTICIPANT	\N	PRESENT	0
45071	44242	14219Q	PARTICIPANT	\N	PRESENT	0
45072	44242	11106F	PARTICIPANT	\N	PRESENT	0
45073	44242	01048V	PARTICIPANT	\N	PRESENT	0
45074	44242	08012N	PARTICIPANT	\N	PRESENT	0
45075	44242	14103D	PARTICIPANT	\N	PRESENT	0
45076	44242	04079R	PARTICIPANT	\N	PRESENT	0
45077	44242	80027E	PARTICIPANT	\N	PRESENT	0
45078	44242	11104D	PARTICIPANT	\N	PRESENT	0
45079	44242	08019V	PARTICIPANT	\N	PRESENT	0
45080	44242	14018U	PARTICIPANT	\N	PRESENT	0
45081	44242	14251Q	PARTICIPANT	\N	PRESENT	0
45082	44242	14063N	PARTICIPANT	\N	PRESENT	0
45083	44242	14031R	PARTICIPANT	\N	PRESENT	0
45084	44242	14111D	PARTICIPANT	\N	PRESENT	0
45085	44242	98046X	PARTICIPANT	\N	PRESENT	0
45086	44242	14001X	PARTICIPANT	\N	PRESENT	0
45087	44242	11085T	PARTICIPANT	\N	PRESENT	0
45088	44242	04086Q	PARTICIPANT	\N	PRESENT	0
45089	44242	01031L	PARTICIPANT	\N	PRESENT	0
45090	44242	01060R	PARTICIPANT	\N	PRESENT	0
45091	44242	08062Y	PARTICIPANT	\N	PRESENT	0
45092	44242	08053X	PARTICIPANT	\N	PRESENT	0
45093	44242	14147R	PARTICIPANT	\N	PRESENT	0
45094	44242	11094U	PARTICIPANT	\N	PRESENT	0
45095	44242	08051V	PARTICIPANT	\N	PRESENT	0
45096	44242	11014C	PARTICIPANT	\N	PRESENT	0
45097	44242	14223L	PARTICIPANT	\N	PRESENT	0
45098	44242	04092N	PARTICIPANT	\N	PRESENT	0
45099	44242	92039X	PARTICIPANT	\N	PRESENT	0
45100	44242	14109K	PARTICIPANT	\N	PRESENT	0
45101	44242	08055A	PARTICIPANT	\N	PRESENT	0
45102	44242	08011M	PARTICIPANT	\N	PRESENT	0
45103	44242	14265W	PARTICIPANT	\N	PRESENT	0
45104	44242	04070G	PARTICIPANT	\N	PRESENT	0
45105	44242	14119M	PARTICIPANT	\N	PRESENT	0
45106	44242	14053L	PARTICIPANT	\N	PRESENT	0
45107	44242	92040Q	PARTICIPANT	\N	PRESENT	0
45108	44242	11082Q	PARTICIPANT	\N	PRESENT	0
45109	44242	08042U	PARTICIPANT	\N	PRESENT	0
45110	44242	08021P	PARTICIPANT	\N	PRESENT	0
45111	44242	11105E	PARTICIPANT	\N	PRESENT	0
45112	44242	14169X	PARTICIPANT	\N	PRESENT	0
45113	44242	14253S	PARTICIPANT	\N	PRESENT	0
45114	44242	01027Q	PARTICIPANT	\N	PRESENT	0
45115	44242	08061X	PARTICIPANT	\N	PRESENT	0
45116	44242	08073C	PARTICIPANT	\N	PRESENT	0
45118	44242	83047W	PARTICIPANT	\N	PRESENT	0
45119	44242	08052W	PARTICIPANT	\N	PRESENT	0
45120	44242	14215L	PARTICIPANT	\N	PRESENT	0
45121	44242	07034Q	PARTICIPANT	\N	PRESENT	0
45122	44242	98021N	PARTICIPANT	\N	PRESENT	0
45123	44242	07032N	PARTICIPANT	\N	PRESENT	0
45124	44242	11069T	PARTICIPANT	\N	PRESENT	0
45125	44242	05012A	PARTICIPANT	\N	PRESENT	0
45126	44242	98050T	PARTICIPANT	\N	PRESENT	0
45127	44242	04074L	PARTICIPANT	\N	PRESENT	0
45128	44242	04080J	PARTICIPANT	\N	PRESENT	0
45129	44242	11090Q	PARTICIPANT	\N	PRESENT	0
45130	44242	14235Q	PARTICIPANT	\N	PRESENT	0
45131	44242	14247U	PARTICIPANT	\N	PRESENT	0
45132	44242	14135M	PARTICIPANT	\N	PRESENT	0
45133	44242	01016M	PARTICIPANT	\N	PRESENT	0
45134	44242	14225N	PARTICIPANT	\N	PRESENT	0
45135	44242	01014K	PARTICIPANT	\N	PRESENT	0
45136	44242	14041T	PARTICIPANT	\N	PRESENT	0
45137	44242	14271U	PARTICIPANT	\N	PRESENT	0
45138	44242	14229S	PARTICIPANT	\N	PRESENT	0
45139	44242	11039M	PARTICIPANT	\N	PRESENT	0
45140	44242	11097X	PARTICIPANT	\N	PRESENT	0
45141	44242	11046L	PARTICIPANT	\N	PRESENT	0
45142	44242	11071M	PARTICIPANT	\N	PRESENT	0
45143	44242	95059Q	PARTICIPANT	\N	PRESENT	0
45144	44242	01028R	PARTICIPANT	\N	PRESENT	0
45145	44242	98035U	PARTICIPANT	\N	PRESENT	0
45146	44242	14051J	PARTICIPANT	\N	PRESENT	0
45147	44242	14227Q	PARTICIPANT	\N	PRESENT	0
45148	44242	01056V	PARTICIPANT	\N	PRESENT	0
45149	44242	92044U	PARTICIPANT	\N	PRESENT	0
45150	44242	89017R	PARTICIPANT	\N	PRESENT	0
45151	44242	11076S	PARTICIPANT	\N	PRESENT	0
45152	44242	08049C	PARTICIPANT	\N	PRESENT	0
45153	44242	01034P	PARTICIPANT	\N	PRESENT	0
45154	44242	14157T	PARTICIPANT	\N	PRESENT	0
45155	44242	11066Q	PARTICIPANT	\N	PRESENT	0
45156	44242	95067Q	PARTICIPANT	\N	PRESENT	0
45157	44242	04085P	PARTICIPANT	\N	PRESENT	0
45158	44242	14173T	PARTICIPANT	\N	PRESENT	0
45159	44242	11063M	PARTICIPANT	\N	PRESENT	0
45160	44242	14269B	PARTICIPANT	\N	PRESENT	0
45161	44242	04034C	PARTICIPANT	\N	PRESENT	0
45162	44242	01047U	PARTICIPANT	\N	PRESENT	0
45163	44242	14263U	PARTICIPANT	\N	PRESENT	0
45164	44242	14133K	PARTICIPANT	\N	PRESENT	0
45165	44242	08025T	PARTICIPANT	\N	PRESENT	0
45166	44242	11055M	PARTICIPANT	\N	PRESENT	0
45167	44242	14261S	PARTICIPANT	\N	PRESENT	0
45168	44242	04059M	PARTICIPANT	\N	PRESENT	0
45169	44242	01008M	PARTICIPANT	\N	PRESENT	0
45170	44242	11036J	PARTICIPANT	\N	PRESENT	0
45171	44242	01013J	PARTICIPANT	\N	PRESENT	0
45172	44242	04057K	PARTICIPANT	\N	PRESENT	0
45173	44242	11081P	PARTICIPANT	\N	PRESENT	0
45174	44242	11068S	PARTICIPANT	\N	PRESENT	0
45175	44242	14065Q	PARTICIPANT	\N	PRESENT	0
45176	44242	05004A	PARTICIPANT	\N	PRESENT	0
45177	44242	01044R	PARTICIPANT	\N	PRESENT	0
45178	44242	08043V	PARTICIPANT	\N	PRESENT	0
45179	44242	11030C	PARTICIPANT	\N	PRESENT	0
45180	44242	11040E	PARTICIPANT	\N	PRESENT	0
45181	44242	11033F	PARTICIPANT	\N	PRESENT	0
45182	44242	14013P	PARTICIPANT	\N	PRESENT	0
45183	44242	08014Q	PARTICIPANT	\N	PRESENT	0
45184	44242	11060J	PARTICIPANT	\N	PRESENT	0
45185	44242	04054G	PARTICIPANT	\N	PRESENT	0
45186	44242	11029K	PARTICIPANT	\N	PRESENT	0
45187	44242	08058D	PARTICIPANT	\N	PRESENT	0
45188	44242	96004D	PARTICIPANT	\N	PRESENT	0
45189	44242	14175V	PARTICIPANT	\N	PRESENT	0
45190	44242	04053F	PARTICIPANT	\N	PRESENT	0
45191	44242	14255U	PARTICIPANT	\N	PRESENT	0
45192	44242	14207L	PARTICIPANT	\N	PRESENT	0
45193	44242	11101A	PARTICIPANT	\N	PRESENT	0
45194	44242	11095V	PARTICIPANT	\N	PRESENT	0
45195	44242	04042C	PARTICIPANT	\N	PRESENT	0
45196	44242	00003C	PARTICIPANT	\N	PRESENT	0
45197	44242	77002U	PARTICIPANT	\N	PRESENT	0
45198	44242	11053K	PARTICIPANT	\N	PRESENT	0
45199	44242	14085U	PARTICIPANT	\N	PRESENT	0
45200	44242	10006L	PARTICIPANT	\N	PRESENT	0
45201	44242	92015P	PARTICIPANT	\N	PRESENT	0
45202	44242	95015C	PARTICIPANT	\N	PRESENT	0
45203	44242	08024S	PARTICIPANT	\N	PRESENT	0
45204	44242	01046T	PARTICIPANT	\N	PRESENT	0
45205	44242	14201E	PARTICIPANT	\N	PRESENT	0
45206	44242	98029W	PARTICIPANT	\N	PRESENT	0
45207	44242	90003B	PARTICIPANT	\N	PRESENT	0
45208	44242	14038Y	PARTICIPANT	\N	PRESENT	0
45209	44242	14069U	PARTICIPANT	\N	PRESENT	0
45210	44242	14195A	PARTICIPANT	\N	PRESENT	0
45211	44242	08028W	PARTICIPANT	\N	PRESENT	0
45212	44242	11042G	PARTICIPANT	\N	PRESENT	0
45213	44242	14267Y	PARTICIPANT	\N	PRESENT	0
45214	44242	11023D	PARTICIPANT	\N	PRESENT	0
45215	44242	11031D	PARTICIPANT	\N	PRESENT	0
45216	44242	88008L	PARTICIPANT	\N	PRESENT	0
45217	44242	04038G	PARTICIPANT	\N	PRESENT	0
45218	44242	14209N	PARTICIPANT	\N	PRESENT	0
45219	44242	98023Q	PARTICIPANT	\N	PRESENT	0
45220	44242	11027H	PARTICIPANT	\N	PRESENT	0
45221	44242	80013X	PARTICIPANT	\N	PRESENT	0
45222	44242	11056N	PARTICIPANT	\N	PRESENT	0
45223	44242	14079W	PARTICIPANT	\N	PRESENT	0
32292	32291	14030Q	PARTICIPANT	\N	PRESENT	0
32293	32291	01015L	PARTICIPANT	\N	PRESENT	0
32294	32291	14073Q	PARTICIPANT	\N	PRESENT	0
32295	32291	14031R	PARTICIPANT	\N	PRESENT	0
32296	32291	92045V	PARTICIPANT	\N	PRESENT	0
33033	33032	01056V	PARTICIPANT	\N	PRESENT	0
33034	33032	11106F	PARTICIPANT	\N	PRESENT	0
33036	33035	04080J	PARTICIPANT	\N	PRESENT	0
33038	33037	11076S	PARTICIPANT	\N	PRESENT	0
33040	33039	04042C	PARTICIPANT	\N	PRESENT	0
33654	33345	14209N	PARTICIPANT	\N	PRESENT	0
33655	33345	14195A	PARTICIPANT	\N	PRESENT	0
33656	33345	98053W	PARTICIPANT	\N	PRESENT	0
33657	33345	04043D	PARTICIPANT	\N	PRESENT	0
33658	33345	11036J	PARTICIPANT	\N	PRESENT	0
33659	33345	14197C	PARTICIPANT	\N	PRESENT	0
33660	33345	14207L	PARTICIPANT	\N	PRESENT	0
33661	33345	14037X	PARTICIPANT	\N	PRESENT	0
33662	33345	14039A	PARTICIPANT	\N	PRESENT	0
33663	33345	14269B	PARTICIPANT	\N	PRESENT	0
33664	33345	98021N	PARTICIPANT	\N	PRESENT	0
33665	33345	11107G	PARTICIPANT	\N	PRESENT	0
33666	33345	14193X	PARTICIPANT	\N	PRESENT	0
33667	33345	12042Y	PARTICIPANT	\N	PRESENT	0
33668	33345	14059S	PARTICIPANT	\N	PRESENT	0
33669	33345	14187A	PARTICIPANT	\N	PRESENT	0
33670	33345	11114F	PARTICIPANT	\N	PRESENT	0
33671	33345	11113E	PARTICIPANT	\N	PRESENT	0
33672	33345	08022Q	PARTICIPANT	\N	PRESENT	0
33673	33345	11109J	PARTICIPANT	\N	PRESENT	0
33674	33345	04071H	PARTICIPANT	\N	PRESENT	0
33675	33345	11023D	PARTICIPANT	\N	PRESENT	0
33676	33345	11037K	PARTICIPANT	\N	PRESENT	0
33677	33345	95035G	PARTICIPANT	\N	PRESENT	0
33678	33345	04049K	PARTICIPANT	\N	PRESENT	0
33679	33345	11033F	PARTICIPANT	\N	PRESENT	0
33680	33345	14038Y	PARTICIPANT	\N	PRESENT	0
33681	33345	11056N	PARTICIPANT	\N	PRESENT	0
33682	33345	11029K	PARTICIPANT	\N	PRESENT	0
33683	33345	01044R	PARTICIPANT	\N	PRESENT	0
33684	33345	11069T	PARTICIPANT	\N	PRESENT	0
33685	33345	11076S	PARTICIPANT	\N	PRESENT	0
33686	33345	11099A	PARTICIPANT	\N	PRESENT	0
33687	33345	14017T	PARTICIPANT	\N	PRESENT	0
33691	33345	01014K	PARTICIPANT	\N	PRESENT	0
33689	33345	04067M	PARTICIPANT	\N	PRESENT	0
33690	33345	11083R	PARTICIPANT	\N	PRESENT	0
33692	33345	14119M	PARTICIPANT	\N	PRESENT	0
33693	33345	01046T	PARTICIPANT	\N	PRESENT	0
33694	33345	88008L	PARTICIPANT	\N	PRESENT	0
33695	33345	04078Q	PARTICIPANT	\N	PRESENT	0
33696	33345	11012A	PARTICIPANT	\N	PRESENT	0
33697	33345	08049C	PARTICIPANT	\N	PRESENT	0
33698	33345	14018U	PARTICIPANT	\N	PRESENT	0
33699	33345	04038G	PARTICIPANT	\N	PRESENT	0
33700	33345	08062Y	PARTICIPANT	\N	PRESENT	0
33701	33345	11081P	PARTICIPANT	\N	PRESENT	0
33702	33345	11027H	PARTICIPANT	\N	PRESENT	0
33703	33345	08039A	PARTICIPANT	\N	PRESENT	0
33704	33345	14261S	PARTICIPANT	\N	PRESENT	0
33705	33345	14201E	PARTICIPANT	\N	PRESENT	0
33706	33345	98022P	PARTICIPANT	\N	PRESENT	0
33707	33345	14239U	PARTICIPANT	\N	PRESENT	0
33708	33345	14241N	PARTICIPANT	\N	PRESENT	0
33709	33345	08021P	PARTICIPANT	\N	PRESENT	0
33710	33345	14257W	PARTICIPANT	\N	PRESENT	0
33711	33345	14069U	PARTICIPANT	\N	PRESENT	0
33712	33345	14055N	PARTICIPANT	\N	PRESENT	0
33713	33345	14247U	PARTICIPANT	\N	PRESENT	0
33714	33345	04040A	PARTICIPANT	\N	PRESENT	0
33715	33345	01025N	PARTICIPANT	\N	PRESENT	0
33716	33345	08056B	PARTICIPANT	\N	PRESENT	0
33717	33345	01047U	PARTICIPANT	\N	PRESENT	0
33718	33345	14083S	PARTICIPANT	\N	PRESENT	0
33719	33345	08044W	PARTICIPANT	\N	PRESENT	0
33720	33345	07004J	PARTICIPANT	\N	PRESENT	0
33721	33345	11070L	PARTICIPANT	\N	PRESENT	0
33722	33345	92018S	PARTICIPANT	\N	PRESENT	0
33723	33345	02002K	PARTICIPANT	\N	PRESENT	0
33724	33345	04089T	PARTICIPANT	\N	PRESENT	0
33725	33345	14231L	PARTICIPANT	\N	PRESENT	0
33726	33345	11082Q	PARTICIPANT	\N	PRESENT	0
33727	33345	92031P	PARTICIPANT	\N	PRESENT	0
33728	33345	11111C	PARTICIPANT	\N	PRESENT	0
33729	33345	14277B	PARTICIPANT	\N	PRESENT	0
33730	33345	83047W	PARTICIPANT	\N	PRESENT	0
33731	33345	08017T	PARTICIPANT	\N	PRESENT	0
33732	33345	14089Y	PARTICIPANT	\N	PRESENT	0
33740	33345	01048V	PARTICIPANT	\N	PRESENT	0
33734	33345	11053K	PARTICIPANT	\N	PRESENT	0
33735	33345	04080J	PARTICIPANT	\N	PRESENT	0
33736	33345	14034U	PARTICIPANT	\N	PRESENT	0
33737	33345	14253S	PARTICIPANT	\N	PRESENT	0
33738	33345	11064N	PARTICIPANT	\N	PRESENT	0
33739	33345	08009T	PARTICIPANT	\N	PRESENT	0
33741	33345	14205J	PARTICIPANT	\N	PRESENT	0
33742	33345	14219Q	PARTICIPANT	\N	PRESENT	0
33743	33345	14103D	PARTICIPANT	\N	PRESENT	0
33744	33345	14030Q	PARTICIPANT	\N	PRESENT	0
33745	33345	14157T	PARTICIPANT	\N	PRESENT	0
33746	33345	14221J	PARTICIPANT	\N	PRESENT	0
33747	33345	00003C	PARTICIPANT	\N	PRESENT	0
33748	33345	14014Q	PARTICIPANT	\N	PRESENT	0
33749	33345	08073C	PARTICIPANT	\N	PRESENT	0
33750	33345	11035H	PARTICIPANT	\N	PRESENT	0
33751	33345	14169X	PARTICIPANT	\N	PRESENT	0
33752	33345	14263U	PARTICIPANT	\N	PRESENT	0
33753	33345	04054G	PARTICIPANT	\N	PRESENT	0
33754	33345	11080N	PARTICIPANT	\N	PRESENT	0
33755	33345	08035V	PARTICIPANT	\N	PRESENT	0
33756	33345	14013P	PARTICIPANT	\N	PRESENT	0
33757	33345	04061F	PARTICIPANT	\N	PRESENT	0
33763	33345	01008M	PARTICIPANT	\N	PRESENT	0
33759	33345	14249W	PARTICIPANT	\N	PRESENT	0
33760	33345	05012A	PARTICIPANT	\N	PRESENT	0
33764	33345	11039M	PARTICIPANT	\N	PRESENT	0
33762	33345	98042T	PARTICIPANT	\N	PRESENT	0
33765	33345	01028R	PARTICIPANT	\N	PRESENT	0
33771	33345	11085T	PARTICIPANT	\N	PRESENT	0
33767	33345	90003B	PARTICIPANT	\N	PRESENT	0
33768	33345	11110B	PARTICIPANT	\N	PRESENT	0
33772	33345	01041N	PARTICIPANT	\N	PRESENT	0
33773	33345	14041T	PARTICIPANT	\N	PRESENT	0
33774	33345	14175V	PARTICIPANT	\N	PRESENT	0
33775	33345	14087W	PARTICIPANT	\N	PRESENT	0
33782	33345	95063L	PARTICIPANT	\N	PRESENT	0
33777	33345	01027Q	PARTICIPANT	\N	PRESENT	0
33778	33345	11065P	PARTICIPANT	\N	PRESENT	0
33780	33345	98018T	PARTICIPANT	\N	PRESENT	0
33784	33345	05004A	PARTICIPANT	\N	PRESENT	0
33783	33345	95067Q	PARTICIPANT	\N	PRESENT	0
33785	33345	14097Y	PARTICIPANT	\N	PRESENT	0
33786	33345	08031R	PARTICIPANT	\N	PRESENT	0
33787	33345	14065Q	PARTICIPANT	\N	PRESENT	0
33788	33345	14327T	PARTICIPANT	\N	PRESENT	0
33789	33345	08038Y	PARTICIPANT	\N	PRESENT	0
33790	33345	14179A	PARTICIPANT	\N	PRESENT	0
33791	33345	11074Q	PARTICIPANT	\N	PRESENT	0
33792	33345	86034E	PARTICIPANT	\N	PRESENT	0
33793	33345	11106F	PARTICIPANT	\N	PRESENT	0
33797	33345	01011G	PARTICIPANT	\N	PRESENT	0
33795	33345	08051V	PARTICIPANT	\N	PRESENT	0
33796	33345	07034Q	PARTICIPANT	\N	PRESENT	0
33798	33345	11057P	PARTICIPANT	\N	PRESENT	0
33799	33345	11090Q	PARTICIPANT	\N	PRESENT	0
33800	33345	04035D	PARTICIPANT	\N	PRESENT	0
33801	33345	08010L	PARTICIPANT	\N	PRESENT	0
33802	33345	11066Q	PARTICIPANT	\N	PRESENT	0
33803	33345	01024M	PARTICIPANT	\N	PRESENT	0
33804	33345	14111D	PARTICIPANT	\N	PRESENT	0
33805	33345	14159V	PARTICIPANT	\N	PRESENT	0
33806	33345	89017R	PARTICIPANT	\N	PRESENT	0
33807	33345	14255U	PARTICIPANT	\N	PRESENT	0
33808	33345	92044U	PARTICIPANT	\N	PRESENT	0
33809	33345	92015P	PARTICIPANT	\N	PRESENT	0
33810	33345	01016M	PARTICIPANT	\N	PRESENT	0
33814	33345	01003G	PARTICIPANT	\N	PRESENT	0
33812	33345	05008E	PARTICIPANT	\N	PRESENT	0
33813	33345	92039X	PARTICIPANT	\N	PRESENT	0
33815	33346	04053F	PARTICIPANT	\N	PRESENT	0
33816	33346	99004R	PARTICIPANT	\N	PRESENT	0
33817	33346	98024R	PARTICIPANT	\N	PRESENT	0
33818	33346	95031C	PARTICIPANT	\N	PRESENT	0
33819	33346	08028W	PARTICIPANT	\N	PRESENT	0
33820	33346	08041T	PARTICIPANT	\N	PRESENT	0
33821	33346	14223L	PARTICIPANT	\N	PRESENT	0
33822	33346	14031R	PARTICIPANT	\N	PRESENT	0
33823	33346	14251Q	PARTICIPANT	\N	PRESENT	0
44042	44041	08009T	PARTICIPANT	\N	PRESENT	0
44043	44041	14093U	PARTICIPANT	\N	PRESENT	0
44066	44065	01047U	PARTICIPANT	\N	PRESENT	0
44078	44077	11089X	PARTICIPANT	\N	PRESENT	0
44079	44077	04080J	PARTICIPANT	\N	PRESENT	0
44552	44248	14263U	PARTICIPANT	\N	EXCUSE	0
44553	44248	01044R	PARTICIPANT	\N	EXCUSE	0
44554	44248	04061F	PARTICIPANT	\N	EXCUSE	0
44555	44248	83042R	PARTICIPANT	\N	EXCUSE	0
45052	45051	11100Y	PARTICIPANT	\N	PRESENT	0
46781	46779	05012A	PARTICIPANT	\N	PRESENT	0
46786	46785	05012A	PARTICIPANT	\N	PRESENT	0
46816	46814	04038G	PARTICIPANT	\N	PRESENT	0
46817	46814	11066Q	PARTICIPANT	\N	PRESENT	0
47647	47646	11100Y	PARTICIPANT	\N	PRESENT	0
48354	48287	97011G	PARTICIPANT	\N	PRESENT	0
48291	48287	04054G	PARTICIPANT	\N	PRESENT	0
48292	48287	04040A	PARTICIPANT	\N	PRESENT	0
48293	48287	08058D	PARTICIPANT	\N	PRESENT	0
48294	48287	04042C	PARTICIPANT	\N	PRESENT	0
48432	48431	05008E	PRESIDENT	0	PRESENT	0
48296	48287	98029W	PARTICIPANT	\N	PRESENT	0
48433	48431	11033F	PARTICIPANT	\N	PRESENT	0
48298	48287	11027H	PARTICIPANT	\N	PRESENT	0
48299	48287	98018T	PARTICIPANT	\N	PRESENT	0
48300	48287	92018S	PARTICIPANT	\N	PRESENT	0
48301	48287	92020L	PARTICIPANT	\N	PRESENT	0
48302	48287	95030B	PARTICIPANT	\N	PRESENT	0
48434	48431	14069U	PARTICIPANT	\N	PRESENT	0
48435	48431	04047H	PARTICIPANT	\N	PRESENT	0
48436	48431	04038G	PARTICIPANT	\N	PRESENT	0
48306	48287	08065C	PARTICIPANT	\N	PRESENT	0
48437	48431	11056N	PARTICIPANT	\N	PRESENT	0
48308	48287	07024N	PARTICIPANT	\N	PRESENT	0
48438	48431	11035H	PARTICIPANT	\N	PRESENT	0
48439	48431	14041T	PARTICIPANT	\N	PRESENT	0
48311	48287	11015D	PARTICIPANT	\N	PRESENT	0
48440	48431	01024M	PARTICIPANT	\N	PRESENT	0
48313	48287	95035G	PARTICIPANT	\N	PRESENT	0
48441	48431	11034G	PARTICIPANT	\N	PRESENT	0
48315	48287	14211G	PARTICIPANT	\N	PRESENT	0
48442	48431	08018U	PARTICIPANT	\N	PRESENT	0
48443	48431	11010L	PARTICIPANT	\N	EXCUSE	0
48318	48287	95037J	PARTICIPANT	\N	PRESENT	0
48319	48287	04078Q	PARTICIPANT	\N	PRESENT	0
48444	48431	01007L	PARTICIPANT	\N	EXCUSE	0
48321	48287	95041E	PARTICIPANT	\N	PRESENT	0
48322	48287	04036E	PARTICIPANT	\N	PRESENT	0
48445	48431	11049P	PARTICIPANT	\N	PRESENT	0
48324	48287	04077P	PARTICIPANT	\N	PRESENT	0
48446	48431	14111D	PARTICIPANT	\N	PRESENT	0
48326	48287	92031P	PARTICIPANT	\N	PRESENT	0
48327	48287	11106F	PARTICIPANT	\N	EXCUSE	0
48447	48431	14273W	PARTICIPANT	\N	PRESENT	0
48329	48287	83042R	PARTICIPANT	\N	PRESENT	0
48330	48287	08053X	PARTICIPANT	\N	PRESENT	0
48448	48431	14147R	PARTICIPANT	\N	PRESENT	0
48332	48287	11105E	PARTICIPANT	\N	PRESENT	0
48333	48287	14253S	PARTICIPANT	\N	PRESENT	0
48334	48287	08047A	PARTICIPANT	\N	PRESENT	0
48335	48287	14028W	PARTICIPANT	\N	PRESENT	0
48449	48431	11072N	PARTICIPANT	\N	PRESENT	0
48337	48287	98021N	PARTICIPANT	\N	EXCUSE	0
48450	48431	07034Q	PARTICIPANT	\N	PRESENT	0
48339	48287	04080J	PARTICIPANT	\N	PRESENT	0
48340	48287	95059Q	PRESIDENT	0	PRESENT	0
48341	48287	86044G	PARTICIPANT	\N	PRESENT	0
48342	48287	01014K	PARTICIPANT	\N	PRESENT	0
48343	48287	11054L	PARTICIPANT	\N	PRESENT	0
48344	48287	01056V	PARTICIPANT	\N	PRESENT	0
48345	48287	92044U	PARTICIPANT	\N	PRESENT	0
48346	48287	08049C	PARTICIPANT	\N	PRESENT	0
48451	48431	10015M	PARTICIPANT	\N	PRESENT	0
48452	48431	01019Q	PARTICIPANT	\N	PRESENT	0
48453	48431	01028R	PARTICIPANT	\N	PRESENT	0
48454	48431	98035U	PARTICIPANT	\N	PRESENT	0
48455	48431	04056J	PARTICIPANT	\N	PRESENT	0
48456	48431	04044E	PARTICIPANT	\N	PRESENT	0
48457	48431	11037K	PARTICIPANT	\N	PRESENT	0
48459	48458	14065Q	PARTICIPANT	\N	PRESENT	0
48460	48458	04038G	PARTICIPANT	\N	PRESENT	0
48461	48458	14259Y	PARTICIPANT	\N	PRESENT	0
48462	48458	14041T	PARTICIPANT	\N	PRESENT	0
48463	48458	01024M	PARTICIPANT	\N	PRESENT	0
48464	48458	14215L	PARTICIPANT	\N	PRESENT	0
48465	48458	11034G	PARTICIPANT	\N	PRESENT	0
48466	48458	11010L	PARTICIPANT	\N	EXCUSE	0
48467	48458	01007L	PARTICIPANT	\N	EXCUSE	0
48468	48458	14273W	PARTICIPANT	\N	PRESENT	0
48469	48458	14147R	PARTICIPANT	\N	PRESENT	0
48470	48458	11072N	PARTICIPANT	\N	PRESENT	0
48471	48458	07034Q	PARTICIPANT	\N	PRESENT	0
48472	48458	10015M	PARTICIPANT	\N	PRESENT	0
48473	48458	01028R	PARTICIPANT	\N	PRESENT	0
48474	48458	98035U	PARTICIPANT	\N	PRESENT	0
48475	48458	04044E	PARTICIPANT	\N	PRESENT	0
48476	48458	11037K	PARTICIPANT	\N	PRESENT	0
48477	48458	92045V	PARTICIPANT	\N	PRESENT	0
48478	48458	05008E	PRESIDENT	0	PRESENT	0
49139	49138	11039M	PARTICIPANT	\N	PRESENT	0
48801	48799	08055A	PARTICIPANT	\N	PRESENT	0
48802	48799	14093U	PARTICIPANT	\N	PRESENT	0
48803	48799	14030Q	PARTICIPANT	\N	PRESENT	0
49140	49138	98042T	PARTICIPANT	\N	PRESENT	0
48805	48799	08060W	PARTICIPANT	\N	PRESENT	0
48806	48799	11060J	PARTICIPANT	\N	PRESENT	0
48807	48799	11095V	PARTICIPANT	\N	PRESENT	0
48808	48799	14038Y	PARTICIPANT	\N	PRESENT	0
48809	48799	11114F	PARTICIPANT	\N	PRESENT	0
48810	48799	98023Q	PARTICIPANT	\N	PRESENT	0
48811	48799	11065P	PARTICIPANT	\N	PRESENT	0
48812	48799	01015L	PARTICIPANT	\N	PRESENT	0
48813	48799	11107G	PARTICIPANT	\N	PRESENT	0
49141	49138	01019Q	PARTICIPANT	\N	PRESENT	0
48815	48799	02002K	PARTICIPANT	\N	PRESENT	0
48816	48799	01022K	PARTICIPANT	\N	PRESENT	0
48817	48799	04097T	PARTICIPANT	\N	PRESENT	0
48818	48799	09001P	PARTICIPANT	\N	PRESENT	0
48819	48799	11059R	PARTICIPANT	\N	PRESENT	0
48820	48799	14219Q	PARTICIPANT	\N	PRESENT	0
49147	49145	11039M	PARTICIPANT	\N	PRESENT	0
49148	49145	98042T	PARTICIPANT	\N	PRESENT	0
48823	48799	08009T	PRESIDENT	0	PRESENT	0
48824	48799	08062Y	PARTICIPANT	\N	PRESENT	0
49149	49145	01019Q	PARTICIPANT	\N	PRESENT	0
49156	49155	01019Q	PARTICIPANT	\N	PRESENT	0
48827	48799	08042U	PARTICIPANT	\N	PRESENT	0
48828	48799	14169X	PARTICIPANT	\N	PRESENT	0
48829	48799	14237S	PARTICIPANT	\N	PRESENT	0
48830	48799	13002U	PARTICIPANT	\N	PRESENT	0
48831	48799	05012A	PARTICIPANT	\N	PRESENT	0
48832	48799	14247U	PARTICIPANT	\N	PRESENT	0
49563	49562	11084S	PARTICIPANT	\N	PRESENT	0
48834	48799	95062K	PARTICIPANT	\N	PRESENT	0
48835	48799	14107H	PARTICIPANT	\N	PRESENT	0
48836	48799	14051J	PARTICIPANT	\N	PRESENT	0
48837	48799	14157T	PARTICIPANT	\N	PRESENT	0
48838	48799	96003C	PARTICIPANT	\N	EXCUSE	0
49564	49562	04080J	PARTICIPANT	\N	PRESENT	0
49566	49565	04080J	PARTICIPANT	\N	PRESENT	0
49602	49601	04036E	PARTICIPANT	\N	PRESENT	0
49603	49601	11057P	PARTICIPANT	\N	PRESENT	0
49604	49601	98046X	PARTICIPANT	\N	PRESENT	0
49606	49605	14133K	PARTICIPANT	\N	PRESENT	0
49607	49605	14239U	PARTICIPANT	\N	PRESENT	0
49609	49605	14065Q	PARTICIPANT	\N	PRESENT	0
49610	49605	14089Y	PARTICIPANT	\N	PRESENT	0
49611	49605	98029W	PARTICIPANT	\N	PRESENT	0
49612	49605	14041T	PARTICIPANT	\N	PRESENT	0
49613	49605	14217N	PARTICIPANT	\N	PRESENT	0
49614	49605	92020L	PARTICIPANT	\N	PRESENT	0
49615	49605	14281W	PARTICIPANT	\N	PRESENT	0
49616	49605	08041T	PARTICIPANT	\N	PRESENT	0
49617	49605	07004J	PARTICIPANT	\N	PRESENT	0
49619	49605	14123H	PARTICIPANT	\N	PRESENT	0
49620	49605	99004R	PARTICIPANT	\N	PRESENT	0
49621	49605	04061F	PARTICIPANT	\N	EXCUSE	0
49622	49605	08053X	PARTICIPANT	\N	PRESENT	0
49624	49605	14193X	PARTICIPANT	\N	PRESENT	0
49626	49605	10015M	PARTICIPANT	\N	PRESENT	0
49628	49605	11037K	PARTICIPANT	\N	PRESENT	0
38452	38451	11098Y	PARTICIPANT	\N	PRESENT	0
38461	38460	11111C	PARTICIPANT	\N	PRESENT	0
38483	38479	90003B	PARTICIPANT	\N	PRESENT	0
38498	38493	01058X	PARTICIPANT	\N	PRESENT	0
38518	38516	01058X	PARTICIPANT	\N	PRESENT	0
38532	38527	01058X	PARTICIPANT	\N	PRESENT	0
38547	38546	01058X	PARTICIPANT	\N	PRESENT	0
38595	38594	14187A	PARTICIPANT	\N	PRESENT	0
38599	38598	14187A	PARTICIPANT	\N	PRESENT	0
38602	38601	14187A	PARTICIPANT	\N	PRESENT	0
38604	38603	14187A	PARTICIPANT	\N	PRESENT	0
41617	40901	96003C	PARTICIPANT	\N	EXCUSE	0
42531	42530	08025T	PARTICIPANT	\N	PRESENT	0
42532	42530	04085P	PARTICIPANT	\N	PRESENT	0
42533	42530	05008E	PARTICIPANT	\N	PRESENT	0
44249	44248	08039A	PARTICIPANT	\N	EXCUSE	0
42535	42530	11033F	PARTICIPANT	\N	PRESENT	0
45573	45571	14069U	PARTICIPANT	\N	PRESENT	0
42537	42530	14069U	PARTICIPANT	\N	PRESENT	0
45692	45690	12042Y	PARTICIPANT	\N	PRESENT	0
42539	42530	11032E	PARTICIPANT	\N	PRESENT	0
42540	42530	04038G	PARTICIPANT	\N	PRESENT	0
44252	44248	11082Q	PARTICIPANT	\N	PRESENT	0
46767	44317	89017R	PARTICIPANT	\N	EXCUSE	0
42543	42530	14259Y	PARTICIPANT	\N	PRESENT	0
42544	42530	11035H	PARTICIPANT	\N	EXCUSE	0
42545	42530	14041T	PARTICIPANT	\N	PRESENT	0
42546	42530	11113E	PARTICIPANT	\N	PRESENT	0
42547	42530	01024M	PARTICIPANT	\N	PRESENT	0
42548	42530	14215L	PARTICIPANT	\N	PRESENT	0
44254	44248	11089X	PARTICIPANT	\N	PRESENT	0
46768	44317	14261S	PARTICIPANT	\N	EXCUSE	0
46769	44317	14065Q	PARTICIPANT	\N	EXCUSE	0
42552	42530	01007L	PARTICIPANT	\N	PRESENT	0
42553	42530	11049P	PARTICIPANT	\N	PRESENT	0
46770	44317	14030Q	PARTICIPANT	\N	PRESENT	0
42555	42530	11084S	PARTICIPANT	\N	PRESENT	0
38439	38394	11098Y	PARTICIPANT	\N	PRESENT	0
38450	38449	11098Y	PARTICIPANT	\N	PRESENT	0
42556	42530	11026G	PARTICIPANT	\N	PRESENT	0
42557	42530	04079R	PARTICIPANT	\N	PRESENT	0
42558	42530	14111D	PARTICIPANT	\N	PRESENT	0
46771	44317	08014Q	PARTICIPANT	\N	EXCUSE	0
46772	44317	14105F	PARTICIPANT	\N	PRESENT	0
46773	44317	04053F	PARTICIPANT	\N	PRESENT	0
42562	42530	14147R	PARTICIPANT	\N	PRESENT	0
42563	42530	95049N	PARTICIPANT	\N	PRESENT	0
42564	42530	08051V	PARTICIPANT	\N	PRESENT	0
42565	42530	11072N	PARTICIPANT	\N	PRESENT	0
42566	42530	07034Q	PARTICIPANT	\N	PRESENT	0
42567	42530	04074L	PARTICIPANT	\N	PRESENT	0
42568	42530	10015M	PARTICIPANT	\N	PRESENT	0
42569	42530	95063L	PARTICIPANT	\N	PRESENT	0
42570	42530	01019Q	PARTICIPANT	\N	PRESENT	0
42571	42530	01028R	PARTICIPANT	\N	PRESENT	0
42572	42530	98035U	PARTICIPANT	\N	PRESENT	0
42573	42530	04056J	PARTICIPANT	\N	PRESENT	0
42574	42530	14275Y	PARTICIPANT	\N	PRESENT	0
42575	42530	04044E	PARTICIPANT	\N	PRESENT	0
46774	44317	14207L	PARTICIPANT	\N	PRESENT	0
42577	42530	92045V	PARTICIPANT	\N	PRESENT	0
42578	42530	95067Q	PARTICIPANT	\N	PRESENT	0
46775	44317	14255U	PARTICIPANT	\N	PRESENT	0
46776	44317	14079W	PARTICIPANT	\N	EXCUSE	0
46777	44317	04055H	PARTICIPANT	\N	EXCUSE	0
46778	44317	11088W	PARTICIPANT	\N	EXCUSE	0
46780	44317	14041T	PARTICIPANT	\N	PRESENT	0
46782	44317	04071H	PARTICIPANT	\N	EXCUSE	0
46783	44317	14151M	PARTICIPANT	\N	EXCUSE	0
46784	44317	14087W	PARTICIPANT	\N	PRESENT	0
46787	44317	02002K	PARTICIPANT	\N	EXCUSE	0
46788	44317	14034U	PARTICIPANT	\N	EXCUSE	0
46789	44317	14121F	PARTICIPANT	\N	EXCUSE	0
46790	44317	14039A	PARTICIPANT	\N	EXCUSE	0
46791	44317	14061L	PARTICIPANT	\N	PRESENT	0
46792	44317	04049K	PARTICIPANT	\N	PRESENT	0
46793	44317	01043Q	PARTICIPANT	\N	EXCUSE	0
46794	44317	04077P	PARTICIPANT	\N	EXCUSE	0
46796	44317	11077T	PARTICIPANT	\N	EXCUSE	0
46798	44317	14018U	PARTICIPANT	\N	EXCUSE	0
46799	44317	14265W	PARTICIPANT	\N	PRESENT	0
46800	44317	14253S	PARTICIPANT	\N	EXCUSE	0
46801	44317	11069T	PARTICIPANT	\N	EXCUSE	0
46802	44317	11090Q	PARTICIPANT	\N	EXCUSE	0
46804	44317	10015M	PARTICIPANT	\N	EXCUSE	0
46805	44317	14157T	PARTICIPANT	\N	PRESENT	0
46806	44317	95067Q	PARTICIPANT	\N	PRESENT	0
46807	44317	11063M	PARTICIPANT	\N	EXCUSE	0
46899	46897	92031P	PARTICIPANT	\N	PRESENT	0
46900	46897	04042C	PARTICIPANT	\N	PRESENT	0
46902	46901	92031P	PARTICIPANT	\N	PRESENT	0
46903	46901	14037X	PARTICIPANT	\N	PRESENT	0
46905	46904	92031P	PARTICIPANT	\N	PRESENT	0
50927	50642	95063L	PARTICIPANT	\N	PRESENT	0
50928	50642	01037S	PARTICIPANT	\N	PRESENT	0
50986	50985	92031P	PARTICIPANT	\N	PRESENT	0
50987	50985	11099A	PARTICIPANT	\N	PRESENT	0
50989	50988	11054L	PARTICIPANT	\N	PRESENT	0
50990	50988	14235Q	PARTICIPANT	\N	PRESENT	0
50991	50988	11031D	PARTICIPANT	\N	PRESENT	0
50997	50994	11069T	PARTICIPANT	\N	PRESENT	0
50995	50994	04077P	PARTICIPANT	\N	PRESENT	0
50996	50994	95035G	PARTICIPANT	\N	PRESENT	0
50998	50994	11084S	PARTICIPANT	\N	PRESENT	0
50999	50994	14179A	PARTICIPANT	\N	PRESENT	0
51000	50994	11100Y	PARTICIPANT	\N	PRESENT	0
51007	51006	04042C	PARTICIPANT	\N	PRESENT	0
51008	51006	11084S	PARTICIPANT	\N	PRESENT	0
51009	51006	14071N	PARTICIPANT	\N	PRESENT	0
51010	51006	14193X	PARTICIPANT	\N	PRESENT	0
51012	51011	04040A	PARTICIPANT	\N	PRESENT	0
51013	51011	14069U	PARTICIPANT	\N	PRESENT	0
51019	51017	04066L	PARTICIPANT	\N	PRESENT	0
51020	51017	14085U	PARTICIPANT	\N	PRESENT	0
51021	51017	11031D	PARTICIPANT	\N	PRESENT	0
51022	51017	01059Y	PARTICIPANT	\N	PRESENT	0
51023	51017	92018S	PARTICIPANT	\N	PRESENT	0
51025	51017	04036E	PARTICIPANT	\N	PRESENT	0
51027	51017	04056J	PARTICIPANT	\N	PRESENT	0
51028	51017	01028R	PARTICIPANT	\N	PRESENT	0
51029	51017	11066Q	PARTICIPANT	\N	PRESENT	0
51030	51017	11107G	PARTICIPANT	\N	PRESENT	0
51031	51017	14034U	PARTICIPANT	\N	PRESENT	0
51033	51017	14211G	PARTICIPANT	\N	PRESENT	0
51034	51017	01057W	PARTICIPANT	\N	PRESENT	0
51035	51017	14073Q	PARTICIPANT	\N	PRESENT	0
51036	51017	95062K	PARTICIPANT	\N	PRESENT	0
51041	51040	14227Q	PARTICIPANT	\N	PRESENT	0
51042	51040	07024N	PARTICIPANT	\N	PRESENT	0
51044	51043	04086Q	PARTICIPANT	\N	PRESENT	0
53966	53950	14033T	PARTICIPANT	\N	PRESENT	0
53967	53950	14081Q	PARTICIPANT	\N	PRESENT	0
53968	53950	04048J	PARTICIPANT	\N	PRESENT	0
53969	53950	11099A	PARTICIPANT	\N	PRESENT	0
53970	53950	04049K	PARTICIPANT	\N	PRESENT	0
53971	53950	04094Q	PARTICIPANT	\N	PRESENT	0
53972	53950	11111C	PARTICIPANT	\N	PRESENT	0
53973	53950	08015R	PARTICIPANT	\N	PRESENT	0
53974	53950	11100Y	PRESIDENT	0	PRESENT	0
53975	53950	01061S	PARTICIPANT	\N	PRESENT	0
53976	53950	11098Y	PARTICIPANT	\N	PRESENT	0
53977	53950	01043Q	PARTICIPANT	\N	PRESENT	0
53978	53950	11077T	PARTICIPANT	\N	PRESENT	0
53979	53950	14205J	PARTICIPANT	\N	PRESENT	0
53980	53950	08019V	PARTICIPANT	\N	PRESENT	0
53981	53950	14257W	PARTICIPANT	\N	PRESENT	0
53982	53950	08021P	PARTICIPANT	\N	PRESENT	0
53983	53950	04088S	PARTICIPANT	\N	PRESENT	0
53997	53950	14097Y	PARTICIPANT	\N	PRESENT	0
53985	53950	11090Q	PARTICIPANT	\N	PRESENT	0
53986	53950	11046L	PARTICIPANT	\N	PRESENT	0
53987	53950	01058X	PARTICIPANT	\N	PRESENT	0
53988	53950	11094U	PARTICIPANT	\N	EXCUSE	0
53989	53950	11066Q	PARTICIPANT	\N	PRESENT	0
54003	54002	01008M	PARTICIPANT	\N	PRESENT	0
54004	54002	11036J	PARTICIPANT	\N	PRESENT	0
54005	54002	11081P	PARTICIPANT	\N	PRESENT	0
54006	54002	14013P	PARTICIPANT	\N	PRESENT	0
54008	54002	14207L	PARTICIPANT	\N	PRESENT	0
54010	54002	90003B	PARTICIPANT	\N	PRESENT	0
54011	54002	08028W	PARTICIPANT	\N	PRESENT	0
54012	54002	80013X	PARTICIPANT	\N	PRESENT	0
54013	54002	08038Y	PARTICIPANT	\N	PRESENT	0
54014	54002	04089T	PARTICIPANT	\N	PRESENT	0
54015	54002	14197C	PARTICIPANT	\N	PRESENT	0
45226	44620	01046T	PARTICIPANT	\N	EXCUSE	0
45227	44242	08038Y	PARTICIPANT	\N	PRESENT	0
45228	44620	04061F	PARTICIPANT	\N	EXCUSE	0
45229	44242	01059Y	PARTICIPANT	\N	PRESENT	0
45230	44242	98018T	PARTICIPANT	\N	PRESENT	0
45231	44242	14327T	PARTICIPANT	\N	PRESENT	0
45232	44242	11088W	PARTICIPANT	\N	PRESENT	0
45233	44620	14221J	PARTICIPANT	\N	EXCUSE	0
45234	44242	11035H	PARTICIPANT	\N	PRESENT	0
45235	44242	92018S	PARTICIPANT	\N	PRESENT	0
45236	44242	98024R	PARTICIPANT	\N	PRESENT	0
45237	44242	08022Q	PARTICIPANT	\N	PRESENT	0
45238	44242	04067M	PARTICIPANT	\N	PRESENT	0
45239	44242	14217N	PARTICIPANT	\N	PRESENT	0
45240	44242	01015L	PARTICIPANT	\N	PRESENT	0
45241	44242	14042U	PARTICIPANT	\N	PRESENT	0
45242	44242	04071H	PARTICIPANT	\N	PRESENT	0
45243	44242	04089T	PARTICIPANT	\N	PRESENT	0
45244	44242	87003B	PARTICIPANT	\N	PRESENT	0
45245	44242	98042T	PARTICIPANT	\N	PRESENT	0
45246	44242	01041N	PARTICIPANT	\N	PRESENT	0
45247	44242	14151M	PARTICIPANT	\N	PRESENT	0
45248	44242	14197C	PARTICIPANT	\N	PRESENT	0
45249	44242	14249W	PARTICIPANT	\N	PRESENT	0
45250	44242	92020L	PARTICIPANT	\N	PRESENT	0
45251	44242	11070L	PARTICIPANT	\N	PRESENT	0
45252	44242	11080N	PARTICIPANT	\N	PRESENT	0
45253	44242	14237S	PARTICIPANT	\N	PRESENT	0
45254	44242	11026G	PARTICIPANT	\N	PRESENT	0
45255	44242	98053W	PARTICIPANT	\N	PRESENT	0
45256	44242	04081K	PARTICIPANT	\N	PRESENT	0
45257	44242	12042Y	PARTICIPANT	\N	PRESENT	0
45258	44242	95063L	PARTICIPANT	\N	PRESENT	0
45259	44242	11107G	PARTICIPANT	\N	PRESENT	0
45260	44242	14257W	PARTICIPANT	\N	PRESENT	0
45261	44242	14089Y	PARTICIPANT	\N	PRESENT	0
45262	44242	14221J	PARTICIPANT	\N	PRESENT	0
45547	44243	08024S	PARTICIPANT	\N	PRESENT	0
45548	44243	11034G	PARTICIPANT	\N	PRESENT	0
45549	44243	08025T	PARTICIPANT	\N	PRESENT	0
45550	44243	04044E	PARTICIPANT	\N	PRESENT	0
45224	44242	14259Y	PARTICIPANT	\N	PRESENT	0
45225	44242	04055H	PARTICIPANT	\N	PRESENT	0
45551	44243	92018S	PARTICIPANT	\N	PRESENT	0
45552	44243	11036J	PARTICIPANT	\N	PRESENT	0
45553	44243	08060W	PARTICIPANT	\N	PRESENT	0
45554	44243	95062K	PARTICIPANT	\N	PRESENT	0
45555	44243	08022Q	PARTICIPANT	\N	PRESENT	0
45556	44243	14041T	PARTICIPANT	\N	PRESENT	0
45557	44243	08058D	PARTICIPANT	\N	PRESENT	0
45558	44243	01016M	PARTICIPANT	\N	PRESENT	0
45559	44243	08052W	PARTICIPANT	\N	PRESENT	0
45560	44243	14121F	PARTICIPANT	\N	PRESENT	0
45561	44243	14063N	PARTICIPANT	\N	PRESENT	0
45562	44243	11042G	PARTICIPANT	\N	PRESENT	0
45563	44243	87003B	PARTICIPANT	\N	PRESENT	0
45564	44243	14159V	PARTICIPANT	\N	PRESENT	0
45565	44243	14187A	PARTICIPANT	\N	PRESENT	0
45566	44243	11099A	PARTICIPANT	\N	PRESENT	0
45567	44243	08062Y	PARTICIPANT	\N	PRESENT	0
45568	44243	07029T	PARTICIPANT	\N	PRESENT	0
45569	44243	11071M	PARTICIPANT	\N	PRESENT	0
45570	44243	14087W	PARTICIPANT	\N	PRESENT	0
45572	44243	14215L	PARTICIPANT	\N	PRESENT	0
45574	44243	14217N	PARTICIPANT	\N	PRESENT	0
45575	44243	14237S	PARTICIPANT	\N	PRESENT	0
45576	44243	11083R	PARTICIPANT	\N	PRESENT	0
45577	44243	14079W	PARTICIPANT	\N	PRESENT	0
45578	44243	14111D	PARTICIPANT	\N	PRESENT	0
45579	44243	14034U	PARTICIPANT	\N	PRESENT	0
45580	44243	14103D	PARTICIPANT	\N	PRESENT	0
45581	44243	14205J	PARTICIPANT	\N	PRESENT	0
45582	44243	14030Q	PARTICIPANT	\N	PRESENT	0
45583	44243	14042U	PARTICIPANT	\N	PRESENT	0
45584	44243	04038G	PARTICIPANT	\N	PRESENT	0
45585	44243	01028R	PARTICIPANT	\N	PRESENT	0
45586	44243	14105F	PARTICIPANT	\N	PRESENT	0
45587	44243	04036E	PARTICIPANT	\N	PRESENT	0
45588	44243	14223L	PARTICIPANT	\N	PRESENT	0
45589	44243	14263U	PARTICIPANT	\N	PRESENT	0
45590	44243	11012A	PARTICIPANT	\N	PRESENT	0
45591	44243	14265W	PARTICIPANT	\N	PRESENT	0
45592	44243	01060R	PARTICIPANT	\N	PRESENT	0
45593	44243	01057W	PARTICIPANT	\N	PRESENT	0
45594	44243	14083S	PARTICIPANT	\N	PRESENT	0
45595	44243	97011G	PARTICIPANT	\N	PRESENT	0
45596	44243	11081P	PARTICIPANT	\N	PRESENT	0
45597	44243	04097T	PARTICIPANT	\N	PRESENT	0
45598	44243	04067M	PARTICIPANT	\N	PRESENT	0
45599	44243	14195A	PARTICIPANT	\N	PRESENT	0
45600	44243	14065Q	PARTICIPANT	\N	PRESENT	0
45644	41619	08073C	PARTICIPANT	\N	EXCUSE	0
47605	47599	11061K	PARTICIPANT	\N	PRESENT	0
47603	47599	01034P	PARTICIPANT	\N	PRESENT	0
47604	47599	90003B	PARTICIPANT	\N	PRESENT	0
47606	47599	14121F	PARTICIPANT	\N	PRESENT	0
47607	47599	98005N	PARTICIPANT	\N	PRESENT	0
47608	47599	11100Y	PARTICIPANT	\N	PRESENT	0
47609	47599	08053X	PARTICIPANT	\N	PRESENT	0
47613	47612	14209N	PARTICIPANT	\N	PRESENT	0
47615	47612	98005N	PARTICIPANT	\N	PRESENT	0
47616	47612	14219Q	PARTICIPANT	\N	PRESENT	0
47617	47612	08053X	PARTICIPANT	\N	PRESENT	0
47618	47612	04043D	PARTICIPANT	\N	PRESENT	0
47619	47612	14227Q	PARTICIPANT	\N	PRESENT	0
47620	47612	07034Q	PARTICIPANT	\N	PRESENT	0
49124	49123	14069U	PARTICIPANT	\N	PRESENT	0
49126	49125	14069U	PARTICIPANT	\N	PRESENT	0
49128	49127	14069U	PARTICIPANT	\N	PRESENT	0
49131	49130	14069U	PARTICIPANT	\N	PRESENT	0
49133	49132	14069U	PARTICIPANT	\N	PRESENT	0
49135	49134	14069U	PARTICIPANT	\N	PRESENT	0
49137	49136	14069U	PARTICIPANT	\N	PRESENT	0
49143	49142	14069U	PARTICIPANT	\N	PRESENT	0
49146	49144	14069U	PARTICIPANT	\N	PRESENT	0
49151	49150	14069U	PARTICIPANT	\N	PRESENT	0
53418	53417	14263U	PARTICIPANT	\N	PRESENT	0
53419	53417	14133K	PARTICIPANT	\N	PRESENT	0
53420	53417	11109J	PARTICIPANT	\N	PRESENT	0
53421	53417	04059M	PARTICIPANT	\N	PRESENT	0
53422	53417	11039M	PARTICIPANT	\N	PRESENT	0
53423	53417	01044R	PARTICIPANT	\N	PRESENT	0
53424	53417	08043V	PARTICIPANT	\N	PRESENT	0
53425	53417	14089Y	PARTICIPANT	\N	PRESENT	0
53426	53417	14105F	PARTICIPANT	\N	PRESENT	0
53427	53417	11029K	PARTICIPANT	\N	PRESENT	0
53428	53417	95015C	PARTICIPANT	\N	PRESENT	0
53429	53417	92015P	PARTICIPANT	\N	PRESENT	0
53430	53417	08024S	PARTICIPANT	\N	PRESENT	0
53431	53417	14201E	PARTICIPANT	\N	EXCUSE	0
53433	53417	14209N	PARTICIPANT	\N	PRESENT	0
53434	53417	14079W	PARTICIPANT	\N	PRESENT	0
53435	53417	11091R	PARTICIPANT	\N	EXCUSE	0
53436	53417	87003B	PARTICIPANT	\N	PRESENT	0
53437	53417	98042T	PARTICIPANT	\N	PRESENT	0
53438	53417	14249W	PARTICIPANT	\N	PRESENT	0
53439	53417	01041N	PARTICIPANT	\N	PRESENT	0
53440	53417	01025N	PARTICIPANT	\N	EXCUSE	0
53442	53417	89029V	PARTICIPANT	\N	PRESENT	0
53443	53417	08035V	PARTICIPANT	\N	PRESENT	0
53444	53417	11089X	PARTICIPANT	\N	PRESENT	0
53445	53417	07026Q	PARTICIPANT	\N	PRESENT	0
53446	53417	14123H	PARTICIPANT	\N	PRESENT	0
53447	53417	14179A	PARTICIPANT	\N	PRESENT	0
53448	53417	04041B	PARTICIPANT	\N	PRESENT	0
53449	53417	14241N	PARTICIPANT	\N	PRESENT	0
53450	53417	14061L	PARTICIPANT	\N	PRESENT	0
53451	53417	14073Q	PARTICIPANT	\N	PRESENT	0
53452	53417	08031R	PARTICIPANT	\N	PRESENT	0
53453	53417	12041X	PARTICIPANT	\N	PRESENT	0
53454	53417	08039A	PARTICIPANT	\N	PRESENT	0
53455	53417	08017T	PARTICIPANT	\N	PRESENT	0
53456	53417	14059S	PARTICIPANT	\N	PRESENT	0
53457	53417	08012N	PARTICIPANT	\N	PRESENT	0
53458	53417	14103D	PARTICIPANT	\N	PRESENT	0
53459	53417	11104D	PARTICIPANT	\N	PRESENT	0
53460	53417	14063N	PARTICIPANT	\N	PRESENT	0
53461	53417	04057K	PARTICIPANT	\N	PRESENT	0
53462	53417	11014C	PARTICIPANT	\N	PRESENT	0
53463	53417	14109K	PARTICIPANT	\N	PRESENT	0
53464	53417	04070G	PRESIDENT	0	PRESENT	0
53465	53417	92040Q	PARTICIPANT	\N	PRESENT	0
53466	53417	14191V	PARTICIPANT	\N	PRESENT	0
53468	53417	14235Q	PARTICIPANT	\N	PRESENT	0
53469	53417	14055N	PARTICIPANT	\N	PRESENT	0
53470	53417	04033B	PARTICIPANT	\N	PRESENT	0
32369	28666	14221J	PARTICIPANT	\N	EXCUSE	0
32371	32370	08069G	PARTICIPANT	\N	EXCUSE	0
32372	32370	04061F	PARTICIPANT	\N	EXCUSE	0
32373	32370	83042R	PARTICIPANT	\N	EXCUSE	0
32374	32370	11082Q	PARTICIPANT	\N	EXCUSE	0
32375	32370	01016M	PARTICIPANT	\N	EXCUSE	0
33824	33346	11049P	PARTICIPANT	\N	PRESENT	0
33825	33346	07026Q	PARTICIPANT	\N	PRESENT	0
33826	33346	14191V	PARTICIPANT	\N	PRESENT	0
33827	33346	14173T	PARTICIPANT	\N	PRESENT	0
33828	33346	08019V	PARTICIPANT	\N	PRESENT	0
33829	33346	11088W	PARTICIPANT	\N	PRESENT	0
33830	33346	89029V	PARTICIPANT	\N	PRESENT	0
33831	33346	14227Q	PARTICIPANT	\N	PRESENT	0
33832	33346	04097T	PARTICIPANT	\N	PRESENT	0
33833	33346	11103C	PARTICIPANT	\N	PRESENT	0
33834	33346	98035U	PARTICIPANT	\N	PRESENT	0
33835	33346	14267Y	PARTICIPANT	\N	PRESENT	0
33836	33346	08052W	PARTICIPANT	\N	PRESENT	0
33837	33346	08048B	PARTICIPANT	\N	PRESENT	0
33838	33346	04088S	PARTICIPANT	\N	PRESENT	0
33839	33346	11060J	PARTICIPANT	\N	PRESENT	0
33840	33346	08025T	PARTICIPANT	\N	PRESENT	0
33841	33346	14215L	PARTICIPANT	\N	PRESENT	0
33842	33346	08016S	PARTICIPANT	\N	PRESENT	0
33843	33346	14217N	PARTICIPANT	\N	PRESENT	0
33844	33346	01015L	PARTICIPANT	\N	PRESENT	0
33845	33346	01019Q	PARTICIPANT	\N	PRESENT	0
33846	33346	11054L	PARTICIPANT	\N	PRESENT	0
33847	33346	04066L	PARTICIPANT	\N	PRESENT	0
33848	33346	11084S	PARTICIPANT	\N	PRESENT	0
33849	33346	01060R	PARTICIPANT	\N	PRESENT	0
33850	33346	11091R	PARTICIPANT	\N	PRESENT	0
33851	33346	80013X	PARTICIPANT	\N	PRESENT	0
33852	33346	04059M	PARTICIPANT	\N	PRESENT	0
33853	33346	98023Q	PARTICIPANT	\N	PRESENT	0
33854	33346	14085U	PARTICIPANT	\N	PRESENT	0
33855	33346	14273W	PARTICIPANT	\N	PRESENT	0
33856	33346	14081Q	PARTICIPANT	\N	PRESENT	0
33857	33346	08055A	PARTICIPANT	\N	PRESENT	0
33858	33346	92040Q	PARTICIPANT	\N	PRESENT	0
33859	33346	01013J	PARTICIPANT	\N	PRESENT	0
33860	33346	14133K	PARTICIPANT	\N	PRESENT	0
33861	33346	14121F	PARTICIPANT	\N	PRESENT	0
33862	33346	07029T	PARTICIPANT	\N	PRESENT	0
33863	33346	11055M	PARTICIPANT	\N	PRESENT	0
33864	33346	01034P	PARTICIPANT	\N	PRESENT	0
33865	33346	14275Y	PARTICIPANT	\N	PRESENT	0
33866	33346	01037S	PARTICIPANT	\N	PRESENT	0
33867	33346	11093T	PARTICIPANT	\N	PRESENT	0
33868	33346	14281W	PARTICIPANT	\N	PRESENT	0
33869	33346	14235Q	PARTICIPANT	\N	PRESENT	0
33870	33346	95041E	PARTICIPANT	\N	PRESENT	0
33871	33346	04095R	PARTICIPANT	\N	PRESENT	0
33872	33346	04036E	PARTICIPANT	\N	PRESENT	0
33873	33346	11067R	PARTICIPANT	\N	PRESENT	0
33874	33346	10006L	PARTICIPANT	\N	PRESENT	0
33875	33346	08012N	PARTICIPANT	\N	PRESENT	0
33876	33346	14063N	PARTICIPANT	\N	PRESENT	0
33877	33346	95030B	PARTICIPANT	\N	PRESENT	0
33878	33346	04034C	PARTICIPANT	\N	PRESENT	0
33879	33346	11101A	PARTICIPANT	\N	PRESENT	0
33880	33346	08043V	PARTICIPANT	\N	PRESENT	0
33881	33346	11077T	PARTICIPANT	\N	PRESENT	0
33882	33346	14147R	PARTICIPANT	\N	PRESENT	0
33883	33346	14265W	PARTICIPANT	\N	PRESENT	0
33884	33346	14211G	PARTICIPANT	\N	PRESENT	0
33885	33346	08018U	PARTICIPANT	\N	PRESENT	0
33886	33346	11097X	PARTICIPANT	\N	PRESENT	0
33887	33346	11048N	PARTICIPANT	\N	PRESENT	0
33888	33346	98050T	PARTICIPANT	\N	PRESENT	0
33889	33346	14079W	PARTICIPANT	\N	PRESENT	0
33890	33346	04057K	PARTICIPANT	\N	PRESENT	0
33891	33346	08065C	PARTICIPANT	\N	PRESENT	0
33892	33346	87003B	PARTICIPANT	\N	PRESENT	0
33893	33346	08011M	PARTICIPANT	\N	PRESENT	0
33894	33346	11031D	PARTICIPANT	\N	PRESENT	0
33895	33346	11063M	PARTICIPANT	\N	PRESENT	0
33896	33346	14237S	PARTICIPANT	\N	PRESENT	0
33897	33346	04081K	PARTICIPANT	\N	PRESENT	0
33898	33346	04086Q	PARTICIPANT	\N	PRESENT	0
33899	33346	08069G	PARTICIPANT	\N	PRESENT	0
33900	33346	11100Y	PARTICIPANT	\N	PRESENT	0
33901	33346	04092N	PARTICIPANT	\N	PRESENT	0
33902	33346	95059Q	PARTICIPANT	\N	PRESENT	0
33903	33346	07024N	PARTICIPANT	\N	PRESENT	0
33904	33346	98046X	PARTICIPANT	\N	PRESENT	0
33905	33346	97011G	PARTICIPANT	\N	PRESENT	0
33906	33346	98005N	PARTICIPANT	\N	PRESENT	0
33907	33346	08034U	PARTICIPANT	\N	PRESENT	0
33908	33346	11098Y	PARTICIPANT	\N	PRESENT	0
33909	33346	11040E	PARTICIPANT	\N	PRESENT	0
33910	33346	11034G	PARTICIPANT	\N	PRESENT	0
33911	33346	08042U	PARTICIPANT	\N	PRESENT	0
33912	33346	95062K	PARTICIPANT	\N	PRESENT	0
33913	33346	01059Y	PARTICIPANT	\N	PRESENT	0
33914	33346	08015R	PARTICIPANT	\N	PRESENT	0
33915	33346	12041X	PARTICIPANT	\N	PRESENT	0
33916	33346	04085P	PARTICIPANT	\N	PRESENT	0
33917	33346	11071M	PARTICIPANT	\N	PRESENT	0
33918	33346	11030C	PARTICIPANT	\N	PRESENT	0
33919	33346	04048J	PARTICIPANT	\N	PRESENT	0
33920	33346	86044G	PARTICIPANT	\N	PRESENT	0
33921	33346	14271U	PARTICIPANT	\N	PRESENT	0
33922	33346	95015C	PARTICIPANT	\N	PRESENT	0
33923	33346	04041B	PARTICIPANT	\N	PRESENT	0
33924	33346	01056V	PARTICIPANT	\N	PRESENT	0
33925	33346	01022K	PARTICIPANT	\N	PRESENT	0
33926	33346	14033T	PARTICIPANT	\N	PRESENT	0
33927	33346	92020L	PARTICIPANT	\N	PRESENT	0
33928	33346	11043H	PARTICIPANT	\N	PRESENT	0
33929	33346	01058X	PARTICIPANT	\N	PRESENT	0
33930	33346	14107H	PARTICIPANT	\N	PRESENT	0
33931	33346	08047A	PARTICIPANT	\N	PRESENT	0
33932	33346	14051J	PARTICIPANT	\N	PRESENT	0
33933	33346	96004D	PARTICIPANT	\N	PRESENT	0
33934	33346	14093U	PARTICIPANT	\N	PRESENT	0
33935	33346	04033B	PARTICIPANT	\N	PRESENT	0
33936	33346	11044J	PARTICIPANT	\N	PRESENT	0
33937	33346	80027E	PARTICIPANT	\N	PRESENT	0
33938	33346	04074L	PARTICIPANT	\N	PRESENT	0
33939	33346	98029W	PARTICIPANT	\N	PRESENT	0
33940	33346	14225N	PARTICIPANT	\N	PRESENT	0
33941	33346	01061S	PARTICIPANT	\N	PRESENT	0
33942	33346	83042R	PARTICIPANT	\N	PRESENT	0
33943	33346	14229S	PARTICIPANT	\N	PRESENT	0
33944	33346	01057W	PARTICIPANT	\N	PRESENT	0
33945	33346	95037J	PARTICIPANT	\N	PRESENT	0
33946	33346	08058D	PARTICIPANT	\N	PRESENT	0
33947	33346	14329V	PARTICIPANT	\N	PRESENT	0
33948	33346	14105F	PARTICIPANT	\N	PRESENT	0
33949	33346	14109K	PARTICIPANT	\N	PRESENT	0
33950	33346	14028W	PARTICIPANT	\N	PRESENT	0
33951	33346	11010L	PARTICIPANT	\N	PRESENT	0
33952	33346	08014Q	PARTICIPANT	\N	PRESENT	0
33953	33346	11095V	PARTICIPANT	\N	PRESENT	0
33954	33346	14042U	PARTICIPANT	\N	PRESENT	0
33955	33346	14001X	PARTICIPANT	\N	PRESENT	0
33956	33346	14213J	PARTICIPANT	\N	PRESENT	0
33957	33346	14167V	PARTICIPANT	\N	PRESENT	0
33958	33346	14135M	PARTICIPANT	\N	PRESENT	0
33959	33346	04056J	PARTICIPANT	\N	PRESENT	0
33960	33346	10015M	PARTICIPANT	\N	PRESENT	0
33961	33346	11042G	PARTICIPANT	\N	PRESENT	0
33962	33346	08060W	PARTICIPANT	\N	PRESENT	0
33963	33346	13002U	PARTICIPANT	\N	PRESENT	0
33964	33346	14053L	PARTICIPANT	\N	PRESENT	0
33965	33346	11112D	PARTICIPANT	\N	PRESENT	0
33966	33346	14199E	PARTICIPANT	\N	PRESENT	0
33967	33346	04042C	PARTICIPANT	\N	PRESENT	0
33968	33346	92045V	PARTICIPANT	\N	PRESENT	0
33969	33346	11026G	PARTICIPANT	\N	PRESENT	0
33970	33346	01031L	PARTICIPANT	\N	PRESENT	0
33971	33346	11015D	PARTICIPANT	\N	PRESENT	0
33972	33346	14061L	PARTICIPANT	\N	PRESENT	0
33973	33346	04077P	PARTICIPANT	\N	PRESENT	0
33974	33346	08061X	PARTICIPANT	\N	PRESENT	0
33975	33346	11089X	PARTICIPANT	\N	PRESENT	0
33976	33346	08024S	PARTICIPANT	\N	PRESENT	0
33977	33346	07032N	PARTICIPANT	\N	PRESENT	0
33978	33346	08053X	PARTICIPANT	\N	PRESENT	0
33979	33346	14259Y	PARTICIPANT	\N	PRESENT	0
33980	33346	11059R	PARTICIPANT	\N	PRESENT	0
33981	33346	04044E	PARTICIPANT	\N	PRESENT	0
33982	33346	14123H	PARTICIPANT	\N	PRESENT	0
33983	33346	14071N	PARTICIPANT	\N	PRESENT	0
33984	33346	99002P	PARTICIPANT	\N	PRESENT	0
33985	33346	08068F	PARTICIPANT	\N	PRESENT	0
33986	33346	14073Q	PARTICIPANT	\N	PRESENT	0
52283	49876	11082Q	PARTICIPANT	\N	EXCUSE	0
49634	49633	01008M	PARTICIPANT	\N	PRESENT	0
49635	49633	96004D	PARTICIPANT	\N	PRESENT	0
49636	49633	04038G	PARTICIPANT	\N	PRESENT	0
49637	49633	01057W	PARTICIPANT	\N	PRESENT	0
49638	49633	14179A	PARTICIPANT	\N	PRESENT	0
49639	49633	11026G	PARTICIPANT	\N	PRESENT	0
49640	49633	11084S	PARTICIPANT	\N	PRESENT	0
49641	49633	04097T	PARTICIPANT	\N	PRESENT	0
49643	49642	08039A	PARTICIPANT	\N	PRESENT	0
49644	49642	01008M	PARTICIPANT	\N	PRESENT	0
49645	49642	14119M	PARTICIPANT	\N	PRESENT	0
49646	49642	04088S	PARTICIPANT	\N	PRESENT	0
49647	49642	08043V	PARTICIPANT	\N	PRESENT	0
49648	49642	14079W	PARTICIPANT	\N	PRESENT	0
52281	49835	14017T	PARTICIPANT	\N	EXCUSE	0
50645	50643	04054G	PARTICIPANT	\N	PRESENT	0
50646	50643	04040A	PARTICIPANT	\N	PRESENT	0
50647	50643	08058D	PARTICIPANT	\N	EXCUSE	0
50648	50643	04042C	PARTICIPANT	\N	PRESENT	0
50649	50643	77002U	PARTICIPANT	\N	PRESENT	0
50650	50643	98029W	PARTICIPANT	\N	PRESENT	0
52282	49876	11068S	PARTICIPANT	\N	EXCUSE	0
50652	50643	11027H	PARTICIPANT	\N	PRESENT	0
50653	50643	98018T	PARTICIPANT	\N	EXCUSE	0
50654	50643	92018S	PARTICIPANT	\N	PRESENT	0
50655	50643	92020L	PARTICIPANT	\N	PRESENT	0
50656	50643	95030B	PARTICIPANT	\N	PRESENT	0
52284	49876	04043D	PARTICIPANT	\N	EXCUSE	0
52297	49835	14034U	PARTICIPANT	\N	EXCUSE	0
50659	50643	97011G	PARTICIPANT	\N	PRESENT	0
50660	50643	08065C	PARTICIPANT	\N	PRESENT	0
50661	50643	04035D	PARTICIPANT	\N	PRESENT	0
50662	50643	07024N	PARTICIPANT	\N	PRESENT	0
50663	50643	04095R	PARTICIPANT	\N	PRESENT	0
50664	50643	14014Q	PARTICIPANT	\N	PRESENT	0
50665	50643	11015D	PARTICIPANT	\N	PRESENT	0
50666	50643	07004J	PARTICIPANT	\N	PRESENT	0
50667	50643	95035G	PARTICIPANT	\N	PRESENT	0
50668	50643	08056B	PARTICIPANT	\N	PRESENT	0
50669	50643	14211G	PARTICIPANT	\N	PRESENT	0
50670	50643	98022P	PARTICIPANT	\N	EXCUSE	0
50671	50643	11064N	PARTICIPANT	\N	PRESENT	0
50672	50643	95037J	PARTICIPANT	\N	PRESENT	0
50673	50643	04078Q	PARTICIPANT	\N	PRESENT	0
50674	50643	14097Y	PARTICIPANT	\N	PRESENT	0
50675	50643	95041E	PARTICIPANT	\N	PRESENT	0
50676	50643	04036E	PARTICIPANT	\N	PRESENT	0
52299	49876	08069G	PARTICIPANT	\N	EXCUSE	0
50678	50643	04077P	PARTICIPANT	\N	PRESENT	0
50679	50643	98005N	PARTICIPANT	\N	PRESENT	0
50680	50643	92031P	PARTICIPANT	\N	PRESENT	0
50681	50643	11106F	PARTICIPANT	\N	PRESENT	0
50682	50643	14251Q	PARTICIPANT	\N	PRESENT	0
50683	50643	83042R	PARTICIPANT	\N	PRESENT	0
50684	50643	08053X	PARTICIPANT	\N	PRESENT	0
52300	49876	83042R	PARTICIPANT	\N	EXCUSE	0
50686	50643	11105E	PARTICIPANT	\N	PRESENT	0
50687	50643	14253S	PARTICIPANT	\N	PRESENT	0
50688	50643	08047A	PARTICIPANT	\N	PRESENT	0
50689	50643	14028W	PARTICIPANT	\N	PRESENT	0
50690	50643	14193X	PARTICIPANT	\N	PRESENT	0
50691	50643	98021N	PARTICIPANT	\N	PRESENT	0
52313	51235	04078Q	PARTICIPANT	\N	PRESENT	0
53206	49876	14209N	PARTICIPANT	\N	EXCUSE	0
50694	50643	95059Q	PRESIDENT	0	PRESENT	0
50695	50643	86044G	PARTICIPANT	\N	PRESENT	0
50696	50643	01014K	PARTICIPANT	\N	EXCUSE	0
50697	50643	11054L	PARTICIPANT	\N	EXCUSE	0
50698	50643	01056V	PARTICIPANT	\N	PRESENT	0
50699	50643	92044U	PARTICIPANT	\N	PRESENT	0
50700	50643	08049C	PARTICIPANT	\N	PRESENT	0
53208	49876	80013X	PARTICIPANT	\N	EXCUSE	0
53210	49876	04061F	PARTICIPANT	\N	EXCUSE	0
53212	49876	08039A	PARTICIPANT	\N	EXCUSE	0
53213	49876	01048V	PARTICIPANT	\N	EXCUSE	0
53215	49876	01016M	PARTICIPANT	\N	EXCUSE	0
53217	49876	01058X	PARTICIPANT	\N	EXCUSE	0
53693	53692	11076S	PARTICIPANT	\N	PRESENT	0
53694	53692	04054G	PARTICIPANT	\N	PRESENT	0
53695	53692	04040A	PARTICIPANT	\N	PRESENT	0
53696	53692	08058D	PARTICIPANT	\N	PRESENT	0
53697	53692	04042C	PARTICIPANT	\N	PRESENT	0
53698	53692	77002U	PARTICIPANT	\N	PRESENT	0
53699	53692	98029W	PARTICIPANT	\N	EXCUSE	0
53700	53692	11080N	PARTICIPANT	\N	PRESENT	0
53701	53692	11027H	PARTICIPANT	\N	PRESENT	0
53702	53692	98018T	PARTICIPANT	\N	PRESENT	0
53703	53692	92018S	PARTICIPANT	\N	PRESENT	0
53704	53692	92020L	PARTICIPANT	\N	PRESENT	0
53705	53692	95030B	PARTICIPANT	\N	PRESENT	0
53706	53692	11096W	PARTICIPANT	\N	PRESENT	0
53707	53692	95031C	PARTICIPANT	\N	PRESENT	0
53708	53692	97011G	PARTICIPANT	\N	PRESENT	0
53710	53692	04035D	PARTICIPANT	\N	EXCUSE	0
53711	53692	07024N	PARTICIPANT	\N	PRESENT	0
53777	53761	11076S	PARTICIPANT	\N	PRESENT	0
53713	53692	14014Q	PARTICIPANT	\N	PRESENT	0
53714	53692	11015D	PARTICIPANT	\N	PRESENT	0
53715	53692	07004J	PARTICIPANT	\N	PRESENT	0
53716	53692	95035G	PARTICIPANT	\N	PRESENT	0
53717	53692	08056B	PARTICIPANT	\N	PRESENT	0
53718	53692	14211G	PARTICIPANT	\N	PRESENT	0
53719	53692	98022P	PARTICIPANT	\N	EXCUSE	0
53720	53692	11064N	PARTICIPANT	\N	PRESENT	0
53721	53692	95037J	PARTICIPANT	\N	PRESENT	0
53778	53761	04054G	PARTICIPANT	\N	PRESENT	0
53723	53692	14097Y	PARTICIPANT	\N	PRESENT	0
53779	53761	04040A	PARTICIPANT	\N	PRESENT	0
53725	53692	04036E	PARTICIPANT	\N	PRESENT	0
53726	53692	14039A	PARTICIPANT	\N	PRESENT	0
53727	53692	04077P	PARTICIPANT	\N	PRESENT	0
53728	53692	98005N	PARTICIPANT	\N	PRESENT	0
53729	53692	92031P	PARTICIPANT	\N	PRESENT	0
53730	53692	11106F	PARTICIPANT	\N	PRESENT	0
53731	53692	14251Q	PARTICIPANT	\N	PRESENT	0
53732	53692	83042R	PARTICIPANT	\N	PRESENT	0
53733	53692	08053X	PARTICIPANT	\N	PRESENT	0
53734	53692	11082Q	PARTICIPANT	\N	PRESENT	0
53735	53692	11105E	PARTICIPANT	\N	PRESENT	0
53736	53692	14253S	PARTICIPANT	\N	PRESENT	0
53737	53692	08047A	PARTICIPANT	\N	PRESENT	0
53738	53692	14028W	PARTICIPANT	\N	PRESENT	0
53739	53692	14193X	PARTICIPANT	\N	PRESENT	0
53740	53692	98021N	PARTICIPANT	\N	PRESENT	0
53741	53692	11069T	PARTICIPANT	\N	PRESENT	0
53742	53692	04080J	PARTICIPANT	\N	PRESENT	0
53743	53692	95059Q	PRESIDENT	0	PRESENT	0
53744	53692	86044G	PARTICIPANT	\N	PRESENT	0
53745	53692	01014K	PARTICIPANT	\N	PRESENT	0
53746	53692	11054L	PARTICIPANT	\N	EXCUSE	0
53747	53692	01056V	PARTICIPANT	\N	PRESENT	0
53748	53692	92044U	PARTICIPANT	\N	PRESENT	0
53749	53692	08049C	PARTICIPANT	\N	PRESENT	0
53780	53761	08058D	PARTICIPANT	\N	PRESENT	0
53781	53761	04042C	PARTICIPANT	\N	PRESENT	0
53782	53761	77002U	PARTICIPANT	\N	PRESENT	0
53783	53761	98029W	PARTICIPANT	\N	EXCUSE	0
53784	53761	11080N	PARTICIPANT	\N	PRESENT	0
53785	53761	11027H	PARTICIPANT	\N	PRESENT	0
53786	53761	98018T	PARTICIPANT	\N	PRESENT	0
53787	53761	92018S	PARTICIPANT	\N	PRESENT	0
53788	53761	92020L	PARTICIPANT	\N	PRESENT	0
53789	53761	95030B	PARTICIPANT	\N	PRESENT	0
53790	53761	11096W	PARTICIPANT	\N	PRESENT	0
53791	53761	95031C	PARTICIPANT	\N	PRESENT	0
53792	53761	97011G	PARTICIPANT	\N	PRESENT	0
53794	53761	04035D	PARTICIPANT	\N	EXCUSE	0
53795	53761	07024N	PARTICIPANT	\N	PRESENT	0
53797	53761	14014Q	PARTICIPANT	\N	PRESENT	0
53798	53761	11015D	PARTICIPANT	\N	PRESENT	0
53799	53761	07004J	PARTICIPANT	\N	PRESENT	0
53800	53761	95035G	PARTICIPANT	\N	PRESENT	0
53801	53761	08056B	PARTICIPANT	\N	PRESENT	0
53802	53761	14211G	PARTICIPANT	\N	PRESENT	0
53803	53761	98022P	PARTICIPANT	\N	EXCUSE	0
53804	53761	11064N	PARTICIPANT	\N	PRESENT	0
53805	53761	95037J	PARTICIPANT	\N	PRESENT	0
53807	53761	14097Y	PARTICIPANT	\N	PRESENT	0
53808	53761	95041E	PARTICIPANT	\N	PRESENT	0
53809	53761	04036E	PARTICIPANT	\N	PRESENT	0
53810	53761	14039A	PARTICIPANT	\N	PRESENT	0
53811	53761	04077P	PARTICIPANT	\N	PRESENT	0
53812	53761	98005N	PARTICIPANT	\N	PRESENT	0
53813	53761	92031P	PARTICIPANT	\N	PRESENT	0
31278	31277	04066L	PARTICIPANT	\N	PRESENT	0
31279	31277	00003C	PARTICIPANT	\N	PRESENT	0
31280	31277	11044J	PARTICIPANT	\N	PRESENT	0
31281	31277	08052W	PARTICIPANT	\N	PRESENT	0
31282	31277	98024R	PARTICIPANT	\N	PRESENT	0
31283	31277	12042Y	PARTICIPANT	\N	PRESENT	0
31284	31277	14281W	PARTICIPANT	\N	PRESENT	0
31285	31277	08041T	PARTICIPANT	\N	PRESENT	0
31286	31277	01011G	PARTICIPANT	\N	PRESENT	0
31287	31277	14213J	PARTICIPANT	\N	PRESENT	0
31288	31277	11112D	PARTICIPANT	\N	PRESENT	0
31289	31277	14223L	PARTICIPANT	\N	PRESENT	0
31290	31277	04092N	PRESIDENT	0	PRESENT	0
31291	31277	14265W	PARTICIPANT	\N	PRESENT	0
31292	31277	14119M	PARTICIPANT	\N	PRESENT	0
31293	31277	14071N	PARTICIPANT	\N	PRESENT	0
31294	31277	14271U	PARTICIPANT	\N	PRESENT	0
31295	31277	11093T	PARTICIPANT	\N	PRESENT	0
31296	31277	11097X	PARTICIPANT	\N	EXCUSE	0
31297	31277	04045F	PARTICIPANT	\N	PRESENT	0
31298	31277	01034P	PARTICIPANT	\N	PRESENT	0
31299	31277	14269B	PARTICIPANT	\N	PRESENT	0
32637	32634	04053F	PARTICIPANT	\N	PRESENT	0
32638	32634	11103C	PARTICIPANT	\N	PRESENT	0
32639	32634	14195A	PARTICIPANT	\N	EXCUSE	0
32642	32634	11031D	PARTICIPANT	\N	PRESENT	0
32644	32634	08052W	PARTICIPANT	\N	PRESENT	0
32646	32634	04081K	PARTICIPANT	\N	PRESENT	0
32647	32634	10006L	PARTICIPANT	\N	PRESENT	0
32649	32634	04067M	PARTICIPANT	\N	PRESENT	0
32650	32634	14217N	PARTICIPANT	\N	PRESENT	0
32651	32634	14042U	PARTICIPANT	\N	PRESENT	0
32652	32634	12042Y	PARTICIPANT	\N	PRESENT	0
32653	32634	14281W	PARTICIPANT	\N	PRESENT	0
32655	32634	14034U	PARTICIPANT	\N	PRESENT	0
32656	32634	14231L	PARTICIPANT	\N	PRESENT	0
32658	32634	08041T	PARTICIPANT	\N	PRESENT	0
32661	32634	14213J	PARTICIPANT	\N	PRESENT	0
32664	32634	14037X	PARTICIPANT	\N	PRESENT	0
32665	32634	14018U	PARTICIPANT	\N	PRESENT	0
32666	32634	11067R	PARTICIPANT	\N	PRESENT	0
32667	32634	14265W	PARTICIPANT	\N	PRESENT	0
32669	32634	14119M	PARTICIPANT	\N	PRESENT	0
32671	32634	11097X	PARTICIPANT	\N	EXCUSE	0
32673	32634	14227Q	PARTICIPANT	\N	PRESENT	0
32674	32634	01034P	PARTICIPANT	\N	PRESENT	0
32675	32634	11063M	PARTICIPANT	\N	PRESENT	0
32686	32634	04092N	PRESIDENT	0	PRESENT	0
32695	32694	89017R	PARTICIPANT	\N	PRESENT	0
32698	32694	01013J	PARTICIPANT	\N	PRESENT	0
32697	32694	01031L	PRESIDENT	0	PRESENT	0
32699	32694	08014Q	PARTICIPANT	\N	PRESENT	0
32700	32694	14175V	PARTICIPANT	\N	PRESENT	0
32701	32694	14083S	PARTICIPANT	\N	PRESENT	0
32702	32694	11053K	PARTICIPANT	\N	PRESENT	0
32703	32694	14085U	PARTICIPANT	\N	EXCUSE	0
32704	32694	04086Q	PARTICIPANT	\N	PRESENT	0
32705	32694	11088W	PARTICIPANT	\N	PRESENT	0
32706	32694	14327T	PARTICIPANT	\N	PRESENT	0
32707	32694	01027Q	PARTICIPANT	\N	PRESENT	0
32708	32694	04071H	PARTICIPANT	\N	PRESENT	0
32709	32694	11074Q	PARTICIPANT	\N	PRESENT	0
32710	32694	11083R	PARTICIPANT	\N	PRESENT	0
32711	32694	01057W	PARTICIPANT	\N	PRESENT	0
32712	32694	11048N	PARTICIPANT	\N	PRESENT	0
32713	32694	99004R	PARTICIPANT	\N	PRESENT	0
32714	32694	04061F	PARTICIPANT	\N	EXCUSE	0
32715	32694	14159V	PARTICIPANT	\N	PRESENT	0
32716	32694	07029T	PARTICIPANT	\N	PRESENT	0
32717	32694	08010L	PARTICIPANT	\N	PRESENT	0
32718	32694	08034U	PARTICIPANT	\N	PRESENT	0
32719	32694	01048V	PARTICIPANT	\N	EXCUSE	0
32720	32694	98046X	PARTICIPANT	\N	EXCUSE	0
32721	32694	11085T	PARTICIPANT	\N	EXCUSE	0
32722	32694	08011M	PARTICIPANT	\N	PRESENT	0
32723	32694	08073C	PARTICIPANT	\N	PRESENT	0
32724	32694	01016M	PARTICIPANT	\N	PRESENT	0
32725	32694	14225N	PARTICIPANT	\N	PRESENT	0
32726	32694	11012A	PARTICIPANT	\N	PRESENT	0
32727	32694	11057P	PARTICIPANT	\N	PRESENT	0
32728	32694	14173T	PARTICIPANT	\N	EXCUSE	0
32744	32743	14087W	PARTICIPANT	\N	PRESENT	0
32746	32745	14087W	PARTICIPANT	\N	PRESENT	0
32748	32747	14017T	PARTICIPANT	\N	PRESENT	0
32750	32749	14017T	PARTICIPANT	\N	PRESENT	0
32752	32751	14213J	PARTICIPANT	\N	PRESENT	0
32754	32753	14087W	PARTICIPANT	\N	PRESENT	0
32756	32755	14213J	PARTICIPANT	\N	PRESENT	0
51564	51563	04038G	PARTICIPANT	\N	PRESENT	0
51565	51563	01015L	PARTICIPANT	\N	PRESENT	0
51566	51563	11066Q	PARTICIPANT	\N	PRESENT	0
51567	51563	14257W	PARTICIPANT	\N	PRESENT	0
54016	54002	11110B	PARTICIPANT	\N	PRESENT	0
54017	54002	14187A	PARTICIPANT	\N	PRESENT	0
54018	54002	14033T	PARTICIPANT	\N	PRESENT	0
54019	54002	14081Q	PARTICIPANT	\N	PRESENT	0
54020	54002	04048J	PARTICIPANT	\N	PRESENT	0
54021	54002	11099A	PARTICIPANT	\N	PRESENT	0
54022	54002	04049K	PARTICIPANT	\N	PRESENT	0
54023	54002	04094Q	PARTICIPANT	\N	PRESENT	0
54024	54002	11111C	PARTICIPANT	\N	PRESENT	0
54025	54002	08015R	PARTICIPANT	\N	PRESENT	0
54026	54002	11100Y	PRESIDENT	0	PRESENT	0
54027	54002	01061S	PARTICIPANT	\N	PRESENT	0
54028	54002	11098Y	PARTICIPANT	\N	PRESENT	0
54029	54002	01043Q	PARTICIPANT	\N	PRESENT	0
54030	54002	11077T	PARTICIPANT	\N	PRESENT	0
54031	54002	14205J	PARTICIPANT	\N	PRESENT	0
54032	54002	08019V	PARTICIPANT	\N	PRESENT	0
54033	54002	14257W	PARTICIPANT	\N	PRESENT	0
54034	54002	08021P	PARTICIPANT	\N	PRESENT	0
54035	54002	04088S	PARTICIPANT	\N	PRESENT	0
54795	54794	14087W	PARTICIPANT	\N	PRESENT	0
54037	54002	11090Q	PARTICIPANT	\N	PRESENT	0
54081	54002	11101A	PARTICIPANT	\N	PRESENT	0
54039	54002	01058X	PARTICIPANT	\N	PRESENT	0
54040	54002	11094U	PARTICIPANT	\N	EXCUSE	0
54041	54002	11066Q	PARTICIPANT	\N	PRESENT	0
54082	54002	11046L	PARTICIPANT	\N	PRESENT	0
54798	54797	14087W	PARTICIPANT	\N	PRESENT	0
54883	49959	95062K	PARTICIPANT	\N	EXCUSE	0
54885	54884	98046X	PARTICIPANT	\N	PRESENT	0
54886	54884	04036E	PARTICIPANT	\N	PRESENT	0
54887	54884	14255U	PARTICIPANT	\N	PRESENT	0
54888	54884	08015R	PARTICIPANT	\N	PRESENT	0
54889	54884	11026G	PARTICIPANT	\N	PRESENT	0
54890	54884	14028W	PARTICIPANT	\N	PRESENT	0
54891	54884	14051J	PARTICIPANT	\N	PRESENT	0
54892	54884	11057P	PARTICIPANT	\N	PRESENT	0
54977	54976	05008E	PRESIDENT	0	PRESENT	0
54978	54976	14069U	PARTICIPANT	\N	PRESENT	0
54979	54976	04047H	PARTICIPANT	\N	PRESENT	0
54980	54976	04038G	PARTICIPANT	\N	PRESENT	0
54981	54976	11035H	PARTICIPANT	\N	PRESENT	0
54982	54976	14041T	PARTICIPANT	\N	PRESENT	0
54983	54976	01024M	PARTICIPANT	\N	PRESENT	0
54653	54652	14215L	PARTICIPANT	\N	PRESENT	0
54656	49876	11036J	PARTICIPANT	\N	PRESENT	0
54657	49876	14221J	PARTICIPANT	\N	PRESENT	0
54658	49876	11089X	PARTICIPANT	\N	PRESENT	0
54669	54668	01056V	PARTICIPANT	\N	PRESENT	0
54670	54668	11106F	PARTICIPANT	\N	PRESENT	0
54671	54668	01014K	PARTICIPANT	\N	PRESENT	0
56197	56172	95049N	PARTICIPANT	\N	PRESENT	0
56198	56172	08051V	PARTICIPANT	\N	PRESENT	0
56199	56172	11072N	PARTICIPANT	\N	PRESENT	0
56200	56172	04074L	PARTICIPANT	\N	PRESENT	0
56201	56172	07034Q	PARTICIPANT	\N	PRESENT	0
56202	56172	10015M	PARTICIPANT	\N	PRESENT	0
56203	56172	95063L	PARTICIPANT	\N	PRESENT	0
56204	56172	01019Q	PARTICIPANT	\N	PRESENT	0
56205	56172	01028R	PARTICIPANT	\N	PRESENT	0
56206	56172	98035U	PARTICIPANT	\N	PRESENT	0
56207	56172	04056J	PARTICIPANT	\N	PRESENT	0
56208	56172	14275Y	PARTICIPANT	\N	PRESENT	0
56209	56172	04044E	PARTICIPANT	\N	PRESENT	0
56210	56172	11037K	PARTICIPANT	\N	PRESENT	0
56211	56172	92045V	PARTICIPANT	\N	PRESENT	0
56212	56172	95067Q	PARTICIPANT	\N	PRESENT	0
56214	56213	11027H	PARTICIPANT	\N	PRESENT	0
56215	56213	11061K	PARTICIPANT	\N	PRESENT	0
56216	56213	04067M	PARTICIPANT	\N	PRESENT	0
56217	56213	12042Y	PARTICIPANT	\N	PRESENT	0
56218	56213	14097Y	PARTICIPANT	\N	PRESENT	0
56219	56213	08017T	PARTICIPANT	\N	PRESENT	0
56220	56213	04057K	PARTICIPANT	\N	PRESENT	0
56221	56213	14109K	PARTICIPANT	\N	PRESENT	0
56230	56229	11044J	PARTICIPANT	\N	PRESENT	0
56231	56229	11067R	PARTICIPANT	\N	PRESENT	0
56262	56258	01027Q	PARTICIPANT	\N	EXCUSE	0
56260	56258	04040A	PRESIDENT	0	PRESENT	0
56317	56258	11049P	PARTICIPANT	\N	EXCUSE	0
56321	56258	08051V	PARTICIPANT	\N	EXCUSE	0
56322	56258	04086Q	PARTICIPANT	\N	PRESENT	0
56323	56258	14231L	PARTICIPANT	\N	PRESENT	0
56324	56258	01057W	PARTICIPANT	\N	PRESENT	0
56325	56258	14063N	PARTICIPANT	\N	PRESENT	0
56326	56258	14071N	PARTICIPANT	\N	PRESENT	0
56327	56258	14028W	PARTICIPANT	\N	PRESENT	0
56328	56258	14051J	PARTICIPANT	\N	PRESENT	0
56329	56258	11032E	PARTICIPANT	\N	PRESENT	0
56474	56473	89017R	PARTICIPANT	\N	PRESENT	0
56475	56473	01031L	PRESIDENT	0	PRESENT	0
56476	56473	05004A	PARTICIPANT	\N	PRESENT	0
56477	56473	01013J	PARTICIPANT	\N	EXCUSE	0
56478	56473	11068S	PARTICIPANT	\N	PRESENT	0
56479	56473	11040E	PARTICIPANT	\N	PRESENT	0
56524	56523	89017R	PARTICIPANT	\N	PRESENT	0
56481	56473	14167V	PARTICIPANT	\N	PRESENT	0
56482	56473	14175V	PARTICIPANT	\N	PRESENT	0
56483	56473	14083S	PARTICIPANT	\N	PRESENT	0
56484	56473	11053K	PARTICIPANT	\N	PRESENT	0
56485	56473	14085U	PARTICIPANT	\N	PRESENT	0
56486	56473	11042G	PARTICIPANT	\N	PRESENT	0
56487	56473	88008L	PARTICIPANT	\N	PRESENT	0
56488	56473	04086Q	PARTICIPANT	\N	PRESENT	0
56489	56473	04055H	PARTICIPANT	\N	PRESENT	0
56490	56473	11070L	PARTICIPANT	\N	PRESENT	0
56491	56473	11088W	PARTICIPANT	\N	PRESENT	0
56492	56473	14327T	PARTICIPANT	\N	PRESENT	0
56493	56473	08022Q	PARTICIPANT	\N	PRESENT	0
56494	56473	01027Q	PARTICIPANT	\N	PRESENT	0
56525	56523	01031L	PRESIDENT	0	PRESENT	0
56496	56473	11074Q	PARTICIPANT	\N	PRESENT	0
56497	56473	98053W	PARTICIPANT	\N	PRESENT	0
56498	56473	11083R	PARTICIPANT	\N	PRESENT	0
56499	56473	14199E	PARTICIPANT	\N	PRESENT	0
56500	56473	01057W	PARTICIPANT	\N	PRESENT	0
56502	56473	08069G	PARTICIPANT	\N	EXCUSE	0
56503	56473	11048N	PARTICIPANT	\N	PRESENT	0
56504	56473	99004R	PARTICIPANT	\N	PRESENT	0
56505	56473	04061F	PARTICIPANT	\N	PRESENT	0
56506	56473	14159V	PARTICIPANT	\N	PRESENT	0
56507	56473	07029T	PARTICIPANT	\N	PRESENT	0
56508	56473	14277B	PARTICIPANT	\N	PRESENT	0
56509	56473	08010L	PARTICIPANT	\N	PRESENT	0
56510	56473	08034U	PARTICIPANT	\N	PRESENT	0
56511	56473	01048V	PARTICIPANT	\N	PRESENT	0
56512	56473	98046X	PARTICIPANT	\N	PRESENT	0
56513	56473	11085T	PARTICIPANT	\N	PRESENT	0
56514	56473	08011M	PARTICIPANT	\N	PRESENT	0
56515	56473	08073C	PARTICIPANT	\N	PRESENT	0
56516	56473	08061X	PARTICIPANT	\N	PRESENT	0
56517	56473	01016M	PARTICIPANT	\N	PRESENT	0
56518	56473	14225N	PARTICIPANT	\N	PRESENT	0
56519	56473	11012A	PARTICIPANT	\N	PRESENT	0
56520	56473	11057P	PARTICIPANT	\N	PRESENT	0
56521	56473	14173T	PARTICIPANT	\N	PRESENT	0
56550	56523	01057W	PARTICIPANT	\N	PRESENT	0
56527	56523	01013J	PARTICIPANT	\N	EXCUSE	0
56528	56523	11068S	PARTICIPANT	\N	PRESENT	0
56529	56523	11040E	PARTICIPANT	\N	PRESENT	0
56531	56523	14167V	PARTICIPANT	\N	PRESENT	0
56532	56523	14175V	PARTICIPANT	\N	PRESENT	0
56533	56523	14083S	PARTICIPANT	\N	PRESENT	0
56534	56523	11053K	PARTICIPANT	\N	PRESENT	0
56536	56523	11042G	PARTICIPANT	\N	PRESENT	0
56537	56523	88008L	PARTICIPANT	\N	PRESENT	0
56538	56523	04086Q	PARTICIPANT	\N	PRESENT	0
56539	56523	04055H	PARTICIPANT	\N	PRESENT	0
56540	56523	11070L	PARTICIPANT	\N	PRESENT	0
56541	56523	11088W	PARTICIPANT	\N	PRESENT	0
56542	56523	14327T	PARTICIPANT	\N	PRESENT	0
56543	56523	08022Q	PARTICIPANT	\N	PRESENT	0
56544	56523	01027Q	PARTICIPANT	\N	PRESENT	0
56546	56523	11074Q	PARTICIPANT	\N	PRESENT	0
56547	56523	98053W	PARTICIPANT	\N	PRESENT	0
56548	56523	11083R	PARTICIPANT	\N	PRESENT	0
56549	56523	14199E	PARTICIPANT	\N	PRESENT	0
53471	53417	14229S	PARTICIPANT	\N	PRESENT	0
53472	53417	11043H	PARTICIPANT	\N	PRESENT	0
53473	53417	11071M	PARTICIPANT	\N	PRESENT	0
53474	53417	11011M	PARTICIPANT	\N	PRESENT	0
53527	53525	14263U	PARTICIPANT	\N	PRESENT	0
53529	53525	11109J	PARTICIPANT	\N	PRESENT	0
53530	53525	04059M	PARTICIPANT	\N	PRESENT	0
53532	53525	01044R	PARTICIPANT	\N	PRESENT	0
53533	53525	08043V	PARTICIPANT	\N	PRESENT	0
53534	53525	14089Y	PARTICIPANT	\N	PRESENT	0
53536	53525	11029K	PARTICIPANT	\N	PRESENT	0
53538	53525	92015P	PARTICIPANT	\N	PRESENT	0
53539	53525	08024S	PARTICIPANT	\N	PRESENT	0
53540	53525	14201E	PARTICIPANT	\N	EXCUSE	0
53542	53525	14209N	PARTICIPANT	\N	PRESENT	0
53544	53525	11091R	PARTICIPANT	\N	EXCUSE	0
53545	53525	87003B	PARTICIPANT	\N	PRESENT	0
53547	53525	14249W	PARTICIPANT	\N	PRESENT	0
53548	53525	01041N	PARTICIPANT	\N	PRESENT	0
53549	53525	01025N	PARTICIPANT	\N	EXCUSE	0
53553	53525	11089X	PARTICIPANT	\N	PRESENT	0
53554	53525	07026Q	PARTICIPANT	\N	PRESENT	0
53555	53525	14123H	PARTICIPANT	\N	PRESENT	0
53556	53525	14179A	PARTICIPANT	\N	PRESENT	0
53557	53525	04041B	PARTICIPANT	\N	PRESENT	0
53558	53525	14241N	PARTICIPANT	\N	PRESENT	0
53559	53525	14061L	PARTICIPANT	\N	PRESENT	0
53560	53525	14073Q	PARTICIPANT	\N	PRESENT	0
53562	53525	12041X	PARTICIPANT	\N	PRESENT	0
53563	53525	08039A	PARTICIPANT	\N	PRESENT	0
53564	53525	08017T	PARTICIPANT	\N	PRESENT	0
53567	53525	14103D	PARTICIPANT	\N	PRESENT	0
53568	53525	11104D	PARTICIPANT	\N	PRESENT	0
53569	53525	14063N	PARTICIPANT	\N	PRESENT	0
53570	53525	04057K	PARTICIPANT	\N	PRESENT	0
53571	53525	11014C	PARTICIPANT	\N	PRESENT	0
53572	53525	14109K	PARTICIPANT	\N	PRESENT	0
53573	53525	04070G	PRESIDENT	0	PRESENT	0
53576	53525	83047W	PARTICIPANT	\N	PRESENT	0
53577	53525	14235Q	PARTICIPANT	\N	PRESENT	0
53578	53525	14055N	PARTICIPANT	\N	PRESENT	0
53580	53525	14229S	PARTICIPANT	\N	PRESENT	0
53581	53525	11043H	PARTICIPANT	\N	PRESENT	0
33987	33346	11046L	PARTICIPANT	\N	PRESENT	0
33988	33346	04045F	PARTICIPANT	\N	PRESENT	0
33989	33346	04094Q	PARTICIPANT	\N	PRESENT	0
33990	33346	11061K	PARTICIPANT	\N	PRESENT	0
33991	33346	14209N	PARTICIPANT	\N	PRESENT	0
33992	33346	14195A	PARTICIPANT	\N	PRESENT	0
33993	33346	98053W	PARTICIPANT	\N	PRESENT	0
33994	33346	04043D	PARTICIPANT	\N	PRESENT	0
33995	33346	11036J	PARTICIPANT	\N	PRESENT	0
33996	33346	14197C	PARTICIPANT	\N	PRESENT	0
33997	33346	14207L	PARTICIPANT	\N	PRESENT	0
33998	33346	14037X	PARTICIPANT	\N	PRESENT	0
33999	33346	14039A	PARTICIPANT	\N	PRESENT	0
34000	33346	14269B	PARTICIPANT	\N	PRESENT	0
34001	33346	98021N	PARTICIPANT	\N	PRESENT	0
34002	33346	11107G	PARTICIPANT	\N	PRESENT	0
34003	33346	14193X	PARTICIPANT	\N	PRESENT	0
34004	33346	12042Y	PARTICIPANT	\N	PRESENT	0
34005	33346	14059S	PARTICIPANT	\N	PRESENT	0
34006	33346	14187A	PARTICIPANT	\N	PRESENT	0
34007	33346	11114F	PARTICIPANT	\N	PRESENT	0
34008	33346	11113E	PARTICIPANT	\N	PRESENT	0
34009	33346	08022Q	PARTICIPANT	\N	PRESENT	0
34010	33346	11109J	PARTICIPANT	\N	PRESENT	0
34011	33346	04071H	PARTICIPANT	\N	PRESENT	0
34012	33346	11023D	PARTICIPANT	\N	PRESENT	0
34013	33346	11037K	PARTICIPANT	\N	PRESENT	0
34014	33346	95035G	PARTICIPANT	\N	PRESENT	0
34015	33346	04049K	PARTICIPANT	\N	PRESENT	0
34016	33346	11033F	PARTICIPANT	\N	PRESENT	0
34017	33346	14038Y	PARTICIPANT	\N	PRESENT	0
34018	33346	11056N	PARTICIPANT	\N	PRESENT	0
34019	33346	11029K	PARTICIPANT	\N	PRESENT	0
34020	33346	01044R	PARTICIPANT	\N	PRESENT	0
34021	33346	11069T	PARTICIPANT	\N	PRESENT	0
34022	33346	11076S	PARTICIPANT	\N	PRESENT	0
34023	33346	11099A	PARTICIPANT	\N	PRESENT	0
34024	33346	14017T	PARTICIPANT	\N	PRESENT	0
34025	33346	04067M	PARTICIPANT	\N	PRESENT	0
34026	33346	11083R	PARTICIPANT	\N	PRESENT	0
34027	33346	01014K	PARTICIPANT	\N	PRESENT	0
34028	33346	14119M	PARTICIPANT	\N	PRESENT	0
34029	33346	01046T	PARTICIPANT	\N	PRESENT	0
34030	33346	88008L	PARTICIPANT	\N	PRESENT	0
34031	33346	04078Q	PARTICIPANT	\N	PRESENT	0
34032	33346	11012A	PARTICIPANT	\N	PRESENT	0
34033	33346	08049C	PARTICIPANT	\N	PRESENT	0
34034	33346	14018U	PARTICIPANT	\N	PRESENT	0
34035	33346	04038G	PARTICIPANT	\N	PRESENT	0
34036	33346	08062Y	PARTICIPANT	\N	PRESENT	0
34037	33346	11081P	PARTICIPANT	\N	PRESENT	0
34038	33346	11027H	PARTICIPANT	\N	PRESENT	0
34039	33346	08039A	PARTICIPANT	\N	PRESENT	0
34040	33346	14261S	PARTICIPANT	\N	PRESENT	0
34041	33346	14201E	PARTICIPANT	\N	PRESENT	0
34042	33346	98022P	PARTICIPANT	\N	PRESENT	0
34043	33346	14239U	PARTICIPANT	\N	PRESENT	0
34044	33346	14241N	PARTICIPANT	\N	PRESENT	0
34045	33346	08021P	PARTICIPANT	\N	PRESENT	0
34046	33346	14257W	PARTICIPANT	\N	PRESENT	0
34047	33346	14069U	PARTICIPANT	\N	PRESENT	0
34048	33346	14055N	PARTICIPANT	\N	PRESENT	0
34049	33346	14247U	PARTICIPANT	\N	PRESENT	0
34050	33346	04040A	PARTICIPANT	\N	PRESENT	0
34051	33346	01025N	PARTICIPANT	\N	PRESENT	0
34052	33346	08056B	PARTICIPANT	\N	PRESENT	0
34053	33346	01047U	PARTICIPANT	\N	PRESENT	0
34054	33346	14083S	PARTICIPANT	\N	PRESENT	0
34055	33346	08044W	PARTICIPANT	\N	PRESENT	0
34056	33346	07004J	PARTICIPANT	\N	PRESENT	0
34057	33346	11070L	PARTICIPANT	\N	PRESENT	0
34058	33346	92018S	PARTICIPANT	\N	PRESENT	0
34059	33346	02002K	PARTICIPANT	\N	PRESENT	0
34060	33346	04089T	PARTICIPANT	\N	PRESENT	0
34061	33346	14231L	PARTICIPANT	\N	PRESENT	0
34062	33346	11082Q	PARTICIPANT	\N	PRESENT	0
34063	33346	92031P	PARTICIPANT	\N	PRESENT	0
34064	33346	11111C	PARTICIPANT	\N	PRESENT	0
34065	33346	14277B	PARTICIPANT	\N	PRESENT	0
34066	33346	83047W	PARTICIPANT	\N	PRESENT	0
34067	33346	08017T	PARTICIPANT	\N	PRESENT	0
34068	33346	14089Y	PARTICIPANT	\N	PRESENT	0
34069	33346	11053K	PARTICIPANT	\N	PRESENT	0
34070	33346	04080J	PARTICIPANT	\N	PRESENT	0
34071	33346	14034U	PARTICIPANT	\N	PRESENT	0
34072	33346	14253S	PARTICIPANT	\N	PRESENT	0
34073	33346	11064N	PARTICIPANT	\N	PRESENT	0
34074	33346	08009T	PARTICIPANT	\N	PRESENT	0
34075	33346	01048V	PARTICIPANT	\N	PRESENT	0
34076	33346	14205J	PARTICIPANT	\N	PRESENT	0
34077	33346	14219Q	PARTICIPANT	\N	PRESENT	0
34078	33346	14103D	PARTICIPANT	\N	PRESENT	0
34079	33346	14030Q	PARTICIPANT	\N	PRESENT	0
34080	33346	14157T	PARTICIPANT	\N	PRESENT	0
34081	33346	14221J	PARTICIPANT	\N	PRESENT	0
34082	33346	00003C	PARTICIPANT	\N	PRESENT	0
34083	33346	14014Q	PARTICIPANT	\N	PRESENT	0
34084	33346	08073C	PARTICIPANT	\N	PRESENT	0
34085	33346	11035H	PARTICIPANT	\N	PRESENT	0
34086	33346	14169X	PARTICIPANT	\N	PRESENT	0
34087	33346	14263U	PARTICIPANT	\N	PRESENT	0
34088	33346	04054G	PARTICIPANT	\N	PRESENT	0
34089	33346	11080N	PARTICIPANT	\N	PRESENT	0
34090	33346	08035V	PARTICIPANT	\N	PRESENT	0
34091	33346	14013P	PARTICIPANT	\N	PRESENT	0
34092	33346	04061F	PARTICIPANT	\N	PRESENT	0
34093	33346	14249W	PARTICIPANT	\N	PRESENT	0
34094	33346	05012A	PARTICIPANT	\N	PRESENT	0
34095	33346	98042T	PARTICIPANT	\N	PRESENT	0
34096	33346	01008M	PARTICIPANT	\N	PRESENT	0
34097	33346	11039M	PARTICIPANT	\N	PRESENT	0
34098	33346	01028R	PARTICIPANT	\N	PRESENT	0
34099	33346	90003B	PARTICIPANT	\N	PRESENT	0
34100	33346	11110B	PARTICIPANT	\N	PRESENT	0
34101	33346	11085T	PARTICIPANT	\N	PRESENT	0
34102	33346	01041N	PARTICIPANT	\N	PRESENT	0
34103	33346	14041T	PARTICIPANT	\N	PRESENT	0
34104	33346	14175V	PARTICIPANT	\N	PRESENT	0
34105	33346	14087W	PARTICIPANT	\N	PRESENT	0
34106	33346	01027Q	PARTICIPANT	\N	PRESENT	0
34107	33346	11065P	PARTICIPANT	\N	PRESENT	0
34108	33346	98018T	PARTICIPANT	\N	PRESENT	0
34109	33346	95063L	PARTICIPANT	\N	PRESENT	0
34110	33346	95067Q	PARTICIPANT	\N	PRESENT	0
34111	33346	05004A	PARTICIPANT	\N	PRESENT	0
34112	33346	14097Y	PARTICIPANT	\N	PRESENT	0
34113	33346	08031R	PARTICIPANT	\N	PRESENT	0
34114	33346	14065Q	PARTICIPANT	\N	PRESENT	0
34115	33346	14327T	PARTICIPANT	\N	PRESENT	0
34116	33346	08038Y	PARTICIPANT	\N	PRESENT	0
34117	33346	14179A	PARTICIPANT	\N	PRESENT	0
34118	33346	11074Q	PARTICIPANT	\N	PRESENT	0
34119	33346	86034E	PARTICIPANT	\N	PRESENT	0
34120	33346	11106F	PARTICIPANT	\N	PRESENT	0
34121	33346	08051V	PARTICIPANT	\N	PRESENT	0
34122	33346	07034Q	PARTICIPANT	\N	PRESENT	0
34123	33346	01011G	PARTICIPANT	\N	PRESENT	0
34124	33346	11057P	PARTICIPANT	\N	PRESENT	0
34125	33346	11090Q	PARTICIPANT	\N	PRESENT	0
34126	33346	04035D	PARTICIPANT	\N	PRESENT	0
34127	33346	08010L	PARTICIPANT	\N	PRESENT	0
34128	33346	11066Q	PARTICIPANT	\N	PRESENT	0
34129	33346	01024M	PARTICIPANT	\N	PRESENT	0
34130	33346	14111D	PARTICIPANT	\N	PRESENT	0
34131	33346	14159V	PARTICIPANT	\N	PRESENT	0
34132	33346	89017R	PARTICIPANT	\N	PRESENT	0
34133	33346	14255U	PARTICIPANT	\N	PRESENT	0
34134	33346	92044U	PARTICIPANT	\N	PRESENT	0
34135	33346	92015P	PARTICIPANT	\N	PRESENT	0
34136	33346	01016M	PARTICIPANT	\N	PRESENT	0
34137	33346	05008E	PARTICIPANT	\N	PRESENT	0
34138	33346	92039X	PARTICIPANT	\N	PRESENT	0
34139	33346	01003G	PARTICIPANT	\N	PRESENT	0
34140	33347	04053F	PARTICIPANT	\N	PRESENT	0
34141	33347	99004R	PARTICIPANT	\N	PRESENT	0
34142	33347	98024R	PARTICIPANT	\N	PRESENT	0
34143	33347	95031C	PARTICIPANT	\N	PRESENT	0
34144	33347	08028W	PARTICIPANT	\N	PRESENT	0
34145	33347	08041T	PARTICIPANT	\N	PRESENT	0
34146	33347	14223L	PARTICIPANT	\N	PRESENT	0
34147	33347	14031R	PARTICIPANT	\N	PRESENT	0
34148	33347	14251Q	PARTICIPANT	\N	PRESENT	0
34149	33347	11049P	PARTICIPANT	\N	PRESENT	0
34150	33347	07026Q	PARTICIPANT	\N	PRESENT	0
34151	33347	14191V	PARTICIPANT	\N	PRESENT	0
34152	33347	14173T	PARTICIPANT	\N	PRESENT	0
34153	33347	08019V	PARTICIPANT	\N	PRESENT	0
34154	33347	11088W	PARTICIPANT	\N	PRESENT	0
53814	53761	11106F	PARTICIPANT	\N	PRESENT	0
53815	53761	14251Q	PARTICIPANT	\N	PRESENT	0
53816	53761	83042R	PARTICIPANT	\N	PRESENT	0
53817	53761	08053X	PARTICIPANT	\N	PRESENT	0
53818	53761	11082Q	PARTICIPANT	\N	PRESENT	0
53819	53761	11105E	PARTICIPANT	\N	PRESENT	0
53820	53761	14253S	PARTICIPANT	\N	PRESENT	0
53821	53761	08047A	PARTICIPANT	\N	PRESENT	0
53822	53761	14028W	PARTICIPANT	\N	PRESENT	0
53823	53761	14193X	PARTICIPANT	\N	PRESENT	0
53824	53761	98021N	PARTICIPANT	\N	PRESENT	0
53825	53761	11069T	PARTICIPANT	\N	PRESENT	0
53826	53761	04080J	PARTICIPANT	\N	PRESENT	0
53827	53761	95059Q	PRESIDENT	0	PRESENT	0
53828	53761	86044G	PARTICIPANT	\N	PRESENT	0
53829	53761	01014K	PARTICIPANT	\N	PRESENT	0
53830	53761	11054L	PARTICIPANT	\N	EXCUSE	0
53831	53761	01056V	PARTICIPANT	\N	PRESENT	0
53832	53761	92044U	PARTICIPANT	\N	PRESENT	0
53833	53761	08049C	PARTICIPANT	\N	PRESENT	0
53911	53761	01031L	PARTICIPANT	\N	PRESENT	0
53912	53761	11040E	PARTICIPANT	\N	PRESENT	0
53914	53761	14083S	PARTICIPANT	\N	PRESENT	0
53915	53761	11042G	PARTICIPANT	\N	PRESENT	0
53916	53761	88008L	PARTICIPANT	\N	PRESENT	0
53917	53761	14327T	PARTICIPANT	\N	PRESENT	0
53918	53761	01027Q	PARTICIPANT	\N	PRESENT	0
53919	53761	01057W	PARTICIPANT	\N	PRESENT	0
53920	53761	11048N	PARTICIPANT	\N	PRESENT	0
53922	53761	99004R	PARTICIPANT	\N	PRESENT	0
53923	53761	04061F	PARTICIPANT	\N	PRESENT	0
53924	53761	14159V	PARTICIPANT	\N	PRESENT	0
53926	53761	07029T	PARTICIPANT	\N	PRESENT	0
53929	53761	08010L	PARTICIPANT	\N	PRESENT	0
53930	53761	08034U	PARTICIPANT	\N	PRESENT	0
53931	53761	08073C	PARTICIPANT	\N	PRESENT	0
53932	53761	01016M	PARTICIPANT	\N	PRESENT	0
53933	53761	14225N	PARTICIPANT	\N	PRESENT	0
53935	53761	11012A	PARTICIPANT	\N	PRESENT	0
53936	53761	11057P	PARTICIPANT	\N	PRESENT	0
53937	53761	04034C	PARTICIPANT	\N	PRESENT	0
54059	53692	95041E	PARTICIPANT	\N	PRESENT	0
54077	53475	95049N	PARTICIPANT	\N	PRESENT	0
54106	49835	96003C	PARTICIPANT	\N	EXCUSE	0
54112	49835	11106F	PARTICIPANT	\N	EXCUSE	0
54115	54114	14261S	PARTICIPANT	\N	PRESENT	0
54116	54114	08055A	PARTICIPANT	\N	PRESENT	0
54117	54114	14093U	PARTICIPANT	\N	PRESENT	0
54118	54114	14030Q	PARTICIPANT	\N	PRESENT	0
54119	54114	96004D	PARTICIPANT	\N	PRESENT	0
54120	54114	08060W	PARTICIPANT	\N	PRESENT	0
54121	54114	11095V	PARTICIPANT	\N	PRESENT	0
54122	54114	14038Y	PARTICIPANT	\N	PRESENT	0
54123	54114	11114F	PARTICIPANT	\N	PRESENT	0
54124	54114	98023Q	PARTICIPANT	\N	PRESENT	0
54125	54114	11065P	PARTICIPANT	\N	PRESENT	0
54126	54114	01015L	PARTICIPANT	\N	PRESENT	0
54127	54114	11107G	PARTICIPANT	\N	PRESENT	0
54663	51235	01022K	PARTICIPANT	\N	PRESENT	0
54129	54114	02002K	PARTICIPANT	\N	PRESENT	0
54130	54114	01022K	PARTICIPANT	\N	PRESENT	0
54131	54114	04097T	PARTICIPANT	\N	PRESENT	0
54132	54114	09001P	PARTICIPANT	\N	PRESENT	0
54133	54114	11059R	PARTICIPANT	\N	PRESENT	0
54134	54114	14219Q	PARTICIPANT	\N	PRESENT	0
54135	54114	80027E	PARTICIPANT	\N	PRESENT	0
54136	54114	14031R	PARTICIPANT	\N	PRESENT	0
54137	54114	08009T	PRESIDENT	0	PRESENT	0
54138	54114	08062Y	PARTICIPANT	\N	PRESENT	0
54139	54114	14221J	PARTICIPANT	\N	PRESENT	0
54140	54114	92039X	PARTICIPANT	\N	PRESENT	0
54141	54114	08042U	PARTICIPANT	\N	PRESENT	0
54142	54114	14169X	PARTICIPANT	\N	PRESENT	0
54143	54114	14237S	PARTICIPANT	\N	PRESENT	0
54144	54114	13002U	PARTICIPANT	\N	PRESENT	0
54145	54114	05012A	PARTICIPANT	\N	PRESENT	0
54173	52493	14087W	PARTICIPANT	\N	PRESENT	0
54147	54114	14135M	PARTICIPANT	\N	PRESENT	0
54148	54114	14331P	PARTICIPANT	\N	PRESENT	0
54149	54114	95062K	PARTICIPANT	\N	EXCUSE	0
54150	54114	14107H	PARTICIPANT	\N	PRESENT	0
54151	54114	14051J	PARTICIPANT	\N	PRESENT	0
54152	54114	14157T	PARTICIPANT	\N	PRESENT	0
54174	49569	04053F	PARTICIPANT	\N	PRESENT	0
56120	56119	14133K	PARTICIPANT	\N	PRESENT	0
56121	56119	07024N	PARTICIPANT	\N	PRESENT	0
56122	56119	11105E	PARTICIPANT	\N	PRESENT	0
56123	56119	95059Q	PARTICIPANT	\N	PRESENT	0
56574	56573	04040A	PARTICIPANT	\N	PRESENT	0
56575	56573	08058D	PARTICIPANT	\N	PRESENT	0
56576	56573	04042C	PARTICIPANT	\N	PRESENT	0
56577	56573	77002U	PARTICIPANT	\N	PRESENT	0
56578	56573	98029W	PARTICIPANT	\N	PRESENT	0
56579	56573	11027H	PARTICIPANT	\N	PRESENT	0
56580	56573	98018T	PARTICIPANT	\N	PRESENT	0
56581	56573	92018S	PARTICIPANT	\N	PRESENT	0
56582	56573	92020L	PARTICIPANT	\N	EXCUSE	0
56583	56573	04035D	PARTICIPANT	\N	PRESENT	0
56584	56573	07024N	PARTICIPANT	\N	PRESENT	0
56585	56573	14014Q	PARTICIPANT	\N	EXCUSE	0
56586	56573	11015D	PARTICIPANT	\N	PRESENT	0
56587	56573	07004J	PARTICIPANT	\N	EXCUSE	0
56588	56573	95035G	PARTICIPANT	\N	PRESENT	0
56589	56573	08056B	PARTICIPANT	\N	EXCUSE	0
56590	56573	14211G	PARTICIPANT	\N	PRESENT	0
56591	56573	98022P	PARTICIPANT	\N	PRESENT	0
56592	56573	11064N	PARTICIPANT	\N	PRESENT	0
56593	56573	95037J	PARTICIPANT	\N	PRESENT	0
56594	56573	04078Q	PARTICIPANT	\N	PRESENT	0
56595	56573	14097Y	PARTICIPANT	\N	PRESENT	0
56596	56573	95041E	PARTICIPANT	\N	PRESENT	0
56597	56573	04036E	PARTICIPANT	\N	PRESENT	0
56598	56573	04077P	PARTICIPANT	\N	PRESENT	0
56599	56573	98005N	PARTICIPANT	\N	PRESENT	0
56600	56573	92031P	PARTICIPANT	\N	EXCUSE	0
56601	56573	11106F	PARTICIPANT	\N	PRESENT	0
56602	56573	14251Q	PARTICIPANT	\N	PRESENT	0
56603	56573	83042R	PARTICIPANT	\N	PRESENT	0
56604	56573	11082Q	PARTICIPANT	\N	EXCUSE	0
56605	56573	11105E	PARTICIPANT	\N	PRESENT	0
56606	56573	14253S	PARTICIPANT	\N	PRESENT	0
56607	56573	08047A	PARTICIPANT	\N	PRESENT	0
56608	56573	14028W	PARTICIPANT	\N	PRESENT	0
56609	56573	14193X	PARTICIPANT	\N	PRESENT	0
56610	56573	04080J	PARTICIPANT	\N	EXCUSE	0
56611	56573	95059Q	PRESIDENT	0	PRESENT	0
56612	56573	01014K	PARTICIPANT	\N	EXCUSE	0
56613	56573	11054L	PARTICIPANT	\N	EXCUSE	0
56614	56573	01056V	PARTICIPANT	\N	PRESENT	0
56615	56573	92044U	PARTICIPANT	\N	PRESENT	0
56691	56688	11093T	PARTICIPANT	\N	PRESENT	0
56711	56688	11061K	PARTICIPANT	\N	PRESENT	0
56898	52497	11063M	PARTICIPANT	\N	PRESENT	0
56899	52497	14083S	PARTICIPANT	\N	PRESENT	0
56900	54794	04049K	PARTICIPANT	\N	PRESENT	0
57263	57260	08043V	PARTICIPANT	\N	PRESENT	0
57264	57260	11032E	PARTICIPANT	\N	PRESENT	0
57265	57260	01059Y	PARTICIPANT	\N	PRESENT	0
57266	57260	11091R	PARTICIPANT	\N	PRESENT	0
57267	57260	14151M	PARTICIPANT	\N	PRESENT	0
57268	57260	14121F	PARTICIPANT	\N	PRESENT	0
57269	57260	12041X	PARTICIPANT	\N	PRESENT	0
57270	57260	11098Y	PARTICIPANT	\N	PRESENT	0
57271	57260	14001X	PARTICIPANT	\N	PRESENT	0
57272	57260	04057K	PARTICIPANT	\N	PRESENT	0
57273	57260	04088S	PARTICIPANT	\N	PRESENT	0
57274	57260	14235Q	PARTICIPANT	\N	PRESENT	0
57275	57260	98035U	PARTICIPANT	\N	PRESENT	0
57276	57260	95067Q	PARTICIPANT	\N	PRESENT	0
57277	57260	04035D	PARTICIPANT	\N	PRESENT	0
57318	49959	11109J	PARTICIPANT	\N	PRESENT	0
57319	49959	14093U	PARTICIPANT	\N	PRESENT	0
57320	49959	11023D	PARTICIPANT	\N	PRESENT	0
57321	49959	14053L	PARTICIPANT	\N	EXCUSE	0
57322	49959	11114F	PARTICIPANT	\N	EXCUSE	0
57323	49959	11113E	PARTICIPANT	\N	PRESENT	0
57324	49959	01027Q	PARTICIPANT	\N	PRESENT	0
57325	49959	11020A	PARTICIPANT	\N	EXCUSE	0
57326	49959	08065C	PARTICIPANT	\N	EXCUSE	0
57327	49959	04095R	PARTICIPANT	\N	PRESENT	0
57328	49959	14033T	PARTICIPANT	\N	PRESENT	0
57329	49959	01022K	PARTICIPANT	\N	PRESENT	0
57330	49959	14097Y	PARTICIPANT	\N	PRESENT	0
57331	49959	14039A	PARTICIPANT	\N	EXCUSE	0
57332	49959	98005N	PARTICIPANT	\N	PRESENT	0
57333	49959	14277B	PARTICIPANT	\N	PRESENT	0
57334	49959	14059S	PARTICIPANT	\N	PRESENT	0
57335	49959	08019V	PRESIDENT	0	PRESENT	0
57336	49959	11072N	PARTICIPANT	\N	PRESENT	0
31451	31401	08017T	RAPPORTEUR_AVIS	\N	PRESENT	0
31403	31401	01031L	PARTICIPANT	\N	EXCUSE	0
31404	31401	05004A	PARTICIPANT	\N	PRESENT	0
32681	32678	14119M	PARTICIPANT	\N	PRESENT	0
32682	32678	14269B	PARTICIPANT	\N	PRESENT	0
31407	31401	11040E	PARTICIPANT	\N	PRESENT	0
31409	31401	14167V	PARTICIPANT	\N	PRESENT	0
31411	31401	14083S	PARTICIPANT	\N	PRESENT	0
31412	31401	11053K	PARTICIPANT	\N	PRESENT	0
31416	31401	04086Q	PARTICIPANT	\N	PRESENT	0
31418	31401	11070L	PRESIDENT	0	PRESENT	0
36442	36441	92045V	PARTICIPANT	\N	PRESENT	0
36966	32370	04043D	PARTICIPANT	\N	EXCUSE	0
31422	31401	01027Q	PARTICIPANT	\N	PRESENT	0
31423	31401	04071H	PARTICIPANT	\N	PRESENT	0
31424	31401	11074Q	PARTICIPANT	\N	PRESENT	0
36968	32370	80013X	PARTICIPANT	\N	EXCUSE	0
36969	32370	11089X	PARTICIPANT	\N	EXCUSE	0
36971	32370	08039A	PARTICIPANT	\N	EXCUSE	0
37035	37002	14133K	PARTICIPANT	\N	PRESENT	0
37036	37002	04054G	PARTICIPANT	\N	PRESENT	0
31430	31401	08069G	PARTICIPANT	\N	PRESENT	0
31431	31401	11048N	PARTICIPANT	\N	PRESENT	0
31432	31401	99004R	PARTICIPANT	\N	PRESENT	0
37037	37002	96004D	PRESIDENT	0	PRESENT	0
31434	31401	14159V	PARTICIPANT	\N	PRESENT	0
31435	31401	07029T	PARTICIPANT	\N	PRESENT	0
37038	37002	11040E	PARTICIPANT	\N	PRESENT	0
31437	31401	08010L	PARTICIPANT	\N	PRESENT	0
37039	37002	14089Y	PARTICIPANT	\N	PRESENT	0
37040	37002	90003B	PARTICIPANT	\N	EXCUSE	0
31440	31401	98046X	PARTICIPANT	\N	EXCUSE	0
31441	31401	11085T	PARTICIPANT	\N	EXCUSE	0
31442	31401	08011M	PARTICIPANT	\N	PRESENT	0
37041	37002	14079W	PARTICIPANT	\N	PRESENT	0
31444	31401	08061X	PARTICIPANT	\N	PRESENT	0
37042	37002	95030B	PARTICIPANT	\N	PRESENT	0
37043	37002	95037J	PARTICIPANT	\N	PRESENT	0
31447	31401	11012A	PARTICIPANT	\N	PRESENT	0
37044	37002	14097Y	PARTICIPANT	\N	PRESENT	0
31449	31401	14173T	PARTICIPANT	\N	PRESENT	0
37045	37002	14073Q	PARTICIPANT	\N	PRESENT	0
37046	37002	14001X	PARTICIPANT	\N	PRESENT	0
37047	37002	04057K	PARTICIPANT	\N	EXCUSE	0
37048	37002	08021P	PARTICIPANT	\N	EXCUSE	0
37049	37002	04080J	PARTICIPANT	\N	PRESENT	0
37050	37002	14135M	PARTICIPANT	\N	PRESENT	0
37051	37002	98035U	PARTICIPANT	\N	PRESENT	0
40546	31452	11114F	PARTICIPANT	\N	PRESENT	0
40547	31452	01027Q	PRESIDENT	1	PRESENT	0
40548	31452	08065C	PARTICIPANT	\N	PRESENT	0
40549	31452	08019V	PRESIDENT	0	PRESENT	0
40550	31452	11072N	PARTICIPANT	\N	PRESENT	0
40551	31452	95062K	PARTICIPANT	\N	PRESENT	0
40552	31452	11071M	PARTICIPANT	\N	PRESENT	0
40553	31452	11025F	PARTICIPANT	\N	PRESENT	0
40555	31452	11106F	PARTICIPANT	\N	PRESENT	0
40566	40565	11039M	PARTICIPANT	\N	PRESENT	0
40558	31452	14097Y	PARTICIPANT	\N	PRESENT	0
40559	31452	01022K	PARTICIPANT	\N	PRESENT	0
40567	40565	98042T	PARTICIPANT	\N	PRESENT	0
40568	40565	01019Q	PARTICIPANT	\N	PRESENT	0
43691	43144	08024S	PARTICIPANT	\N	PRESENT	0
43692	43144	14179A	PARTICIPANT	\N	PRESENT	0
43693	43144	14175V	PARTICIPANT	\N	PRESENT	0
43694	43144	14085U	PARTICIPANT	\N	PRESENT	0
43695	43144	14215L	PARTICIPANT	\N	PRESENT	0
43696	43144	14041T	PARTICIPANT	\N	PRESENT	0
43697	43144	11072N	PARTICIPANT	\N	PRESENT	0
43698	43144	11057P	PARTICIPANT	\N	PRESENT	0
43699	43144	04043D	PARTICIPANT	\N	PRESENT	0
43700	43144	04036E	PARTICIPANT	\N	PRESENT	0
43701	43144	04086Q	PARTICIPANT	\N	PRESENT	0
43702	43144	04088S	PARTICIPANT	\N	PRESENT	0
43703	43144	14275Y	PARTICIPANT	\N	PRESENT	0
43704	43144	11040E	PARTICIPANT	\N	PRESENT	0
43705	43144	11054L	PARTICIPANT	\N	PRESENT	0
43706	43144	11083R	PARTICIPANT	\N	PRESENT	0
43707	43144	01031L	PARTICIPANT	\N	PRESENT	0
43708	43144	14159V	PARTICIPANT	\N	PRESENT	0
43709	43144	14219Q	PARTICIPANT	\N	PRESENT	0
43710	43144	14073Q	PARTICIPANT	\N	PRESENT	0
43711	43144	14083S	PARTICIPANT	\N	PRESENT	0
43712	43144	98005N	PARTICIPANT	\N	PRESENT	0
43713	43144	08011M	PARTICIPANT	\N	PRESENT	0
43714	43144	14225N	PARTICIPANT	\N	PRESENT	0
43715	43144	04059M	PARTICIPANT	\N	PRESENT	0
43716	43144	14063N	PARTICIPANT	\N	PRESENT	0
43717	43144	14207L	PARTICIPANT	\N	PRESENT	0
43718	43144	07026Q	PARTICIPANT	\N	PRESENT	0
43719	43144	14259Y	PARTICIPANT	\N	PRESENT	0
43720	43144	14277B	PARTICIPANT	\N	PRESENT	0
43735	43144	98018T	PARTICIPANT	\N	PRESENT	0
43737	43144	08014Q	PARTICIPANT	\N	PRESENT	0
43738	43144	01022K	PARTICIPANT	\N	PRESENT	0
43739	43144	01041N	PARTICIPANT	\N	PRESENT	0
43740	43144	11109J	PARTICIPANT	\N	PRESENT	0
43741	43144	98046X	PARTICIPANT	\N	PRESENT	0
43742	43144	99004R	PARTICIPANT	\N	PRESENT	0
43743	43144	01027Q	PARTICIPANT	\N	PRESENT	0
43744	43144	14261S	PARTICIPANT	\N	PRESENT	0
43745	43144	95035G	PARTICIPANT	\N	PRESENT	0
43746	43144	14037X	PARTICIPANT	\N	PRESENT	0
43747	43144	14013P	PARTICIPANT	\N	PRESENT	0
43748	43144	08019V	PARTICIPANT	\N	PRESENT	0
43749	43144	14199E	PARTICIPANT	\N	PRESENT	0
43750	43144	07029T	PARTICIPANT	\N	PRESENT	0
43751	43144	01046T	PARTICIPANT	\N	PRESENT	0
43752	43144	11100Y	PARTICIPANT	\N	PRESENT	0
43753	43144	04071H	PARTICIPANT	\N	PRESENT	0
43754	43144	14039A	PARTICIPANT	\N	PRESENT	0
43755	43144	11036J	PARTICIPANT	\N	PRESENT	0
43756	43144	11042G	PARTICIPANT	\N	PRESENT	0
43757	43144	14197C	PARTICIPANT	\N	PRESENT	0
43758	43144	04094Q	PARTICIPANT	\N	PRESENT	0
43759	43144	11063M	PARTICIPANT	\N	PRESENT	0
43760	43144	04034C	PARTICIPANT	\N	PRESENT	0
43761	43144	11105E	PARTICIPANT	\N	PRESENT	0
43762	43144	08069G	PARTICIPANT	\N	PRESENT	0
43763	43144	14059S	PARTICIPANT	\N	PRESENT	0
43764	43144	04053F	PARTICIPANT	\N	PRESENT	0
43765	43144	08016S	PARTICIPANT	\N	PRESENT	0
43766	43144	08073C	PARTICIPANT	\N	PRESENT	0
43767	43144	80013X	PARTICIPANT	\N	PRESENT	0
43768	43144	11055M	PARTICIPANT	\N	PRESENT	0
43769	43149	08024S	PARTICIPANT	\N	PRESENT	0
43771	43149	14041T	PARTICIPANT	\N	PRESENT	0
43772	43149	11072N	PARTICIPANT	\N	PRESENT	0
43776	43149	14275Y	PARTICIPANT	\N	PRESENT	0
43777	43149	11054L	PARTICIPANT	\N	PRESENT	0
43778	43149	11083R	PARTICIPANT	\N	PRESENT	0
43779	43149	01031L	PARTICIPANT	\N	PRESENT	0
43780	43149	14159V	PARTICIPANT	\N	PRESENT	0
43781	43149	14219Q	PARTICIPANT	\N	PRESENT	0
43783	43149	14083S	PARTICIPANT	\N	PRESENT	0
43784	43149	98005N	PARTICIPANT	\N	PRESENT	0
43785	43149	08011M	PARTICIPANT	\N	PRESENT	0
43786	43149	14225N	PARTICIPANT	\N	PRESENT	0
43788	43149	07026Q	PARTICIPANT	\N	PRESENT	0
43789	43149	14277B	PARTICIPANT	\N	PRESENT	0
43790	43149	98018T	PARTICIPANT	\N	PRESENT	0
43792	43149	01022K	PARTICIPANT	\N	PRESENT	0
43793	43149	01041N	PARTICIPANT	\N	PRESENT	0
43794	43149	11109J	PARTICIPANT	\N	PRESENT	0
43798	43149	14261S	PARTICIPANT	\N	PRESENT	0
43800	43149	14037X	PARTICIPANT	\N	PRESENT	0
43801	43149	08019V	PARTICIPANT	\N	PRESENT	0
43803	43149	07029T	PARTICIPANT	\N	PRESENT	0
43804	43149	01046T	PARTICIPANT	\N	PRESENT	0
41004	41003	11094U	PARTICIPANT	\N	PRESENT	0
41006	41005	01061S	PARTICIPANT	\N	PRESENT	0
41009	41008	14093U	PARTICIPANT	\N	PRESENT	0
41010	41008	11114F	PARTICIPANT	\N	PRESENT	0
41012	41011	14093U	PARTICIPANT	\N	PRESENT	0
41013	41011	09001P	PARTICIPANT	\N	PRESENT	0
41014	41011	01015L	PARTICIPANT	\N	PRESENT	0
41015	41011	01022K	PARTICIPANT	\N	PRESENT	0
41016	41011	13002U	PARTICIPANT	\N	PRESENT	0
41017	41011	04040A	PARTICIPANT	\N	PRESENT	0
41018	41011	11094U	PARTICIPANT	\N	PRESENT	0
41019	41011	01044R	PARTICIPANT	\N	PRESENT	0
41020	41011	04061F	PARTICIPANT	\N	PRESENT	0
41021	41011	08038Y	PARTICIPANT	\N	PRESENT	0
41382	41381	14251Q	PARTICIPANT	\N	PRESENT	0
41384	41383	11027H	PARTICIPANT	\N	PRESENT	0
56703	56636	08069G	PARTICIPANT	\N	EXCUSE	0
56552	56523	08069G	PARTICIPANT	\N	EXCUSE	0
56553	56523	11048N	PARTICIPANT	\N	PRESENT	0
56554	56523	99004R	PARTICIPANT	\N	PRESENT	0
56555	56523	04061F	PARTICIPANT	\N	PRESENT	0
56556	56523	14159V	PARTICIPANT	\N	PRESENT	0
56557	56523	07029T	PARTICIPANT	\N	PRESENT	0
56558	56523	14277B	PARTICIPANT	\N	PRESENT	0
56559	56523	08010L	PARTICIPANT	\N	PRESENT	0
56560	56523	08034U	PARTICIPANT	\N	PRESENT	0
56561	56523	01048V	PARTICIPANT	\N	PRESENT	0
56562	56523	98046X	PARTICIPANT	\N	PRESENT	0
56563	56523	11085T	PARTICIPANT	\N	PRESENT	0
56564	56523	08011M	PARTICIPANT	\N	PRESENT	0
56565	56523	08073C	PARTICIPANT	\N	PRESENT	0
56566	56523	08061X	PARTICIPANT	\N	PRESENT	0
56567	56523	01016M	PARTICIPANT	\N	PRESENT	0
56568	56523	14225N	PARTICIPANT	\N	PRESENT	0
56569	56523	11012A	PARTICIPANT	\N	PRESENT	0
56570	56523	11057P	PARTICIPANT	\N	PRESENT	0
56571	56523	14173T	PARTICIPANT	\N	PRESENT	0
56572	56523	04034C	PARTICIPANT	\N	PRESENT	0
56638	56636	89017R	PARTICIPANT	\N	PRESENT	0
56639	56636	01031L	PRESIDENT	0	PRESENT	0
57175	56636	11012A	PARTICIPANT	\N	PRESENT	0
56641	56636	01013J	PARTICIPANT	\N	EXCUSE	0
56642	56636	11068S	PARTICIPANT	\N	PRESENT	0
57282	57281	99004R	PRESIDENT	0	PRESENT	0
57283	57281	01008M	PARTICIPANT	\N	PRESENT	0
56645	56636	14167V	PARTICIPANT	\N	PRESENT	0
56646	56636	14175V	PARTICIPANT	\N	PRESENT	0
56647	56636	14083S	PARTICIPANT	\N	PRESENT	0
56648	56636	11053K	PARTICIPANT	\N	PRESENT	0
57284	57281	04038G	PARTICIPANT	\N	PRESENT	0
56650	56636	11042G	PARTICIPANT	\N	PRESENT	0
56651	56636	88008L	PARTICIPANT	\N	PRESENT	0
56652	56636	04086Q	PARTICIPANT	\N	PRESENT	0
56653	56636	04055H	PARTICIPANT	\N	PRESENT	0
57285	57281	01059Y	PARTICIPANT	\N	PRESENT	0
56655	56636	11088W	PARTICIPANT	\N	PRESENT	0
57286	57281	14187A	PARTICIPANT	\N	PRESENT	0
56657	56636	08022Q	PARTICIPANT	\N	PRESENT	0
56658	56636	01027Q	PARTICIPANT	\N	PRESENT	0
57287	57281	11089X	PARTICIPANT	\N	PRESENT	0
56660	56636	11074Q	PARTICIPANT	\N	PRESENT	0
57288	57281	14026U	PARTICIPANT	\N	EXCUSE	0
56662	56636	11083R	PARTICIPANT	\N	PRESENT	0
57289	57281	14179A	PARTICIPANT	\N	PRESENT	0
56664	56636	01057W	PARTICIPANT	\N	PRESENT	0
57290	57281	14121F	PARTICIPANT	\N	PRESENT	0
57291	57281	11084S	PARTICIPANT	\N	PRESENT	0
56667	56636	11048N	PARTICIPANT	\N	PRESENT	0
57292	57281	08012N	PARTICIPANT	\N	PRESENT	0
56669	56636	04061F	PARTICIPANT	\N	PRESENT	0
56670	56636	14159V	PARTICIPANT	\N	PRESENT	0
56671	56636	07029T	PARTICIPANT	\N	PRESENT	0
56672	56636	14277B	PARTICIPANT	\N	PRESENT	0
56673	56636	08010L	PARTICIPANT	\N	PRESENT	0
56674	56636	08034U	PARTICIPANT	\N	PRESENT	0
57293	57281	08062Y	PARTICIPANT	\N	PRESENT	0
57294	57281	14257W	PARTICIPANT	\N	PRESENT	0
57295	57281	14107H	PARTICIPANT	\N	PRESENT	0
56678	56636	08011M	PARTICIPANT	\N	PRESENT	0
56679	56636	08073C	PARTICIPANT	\N	PRESENT	0
56680	56636	08061X	PARTICIPANT	\N	PRESENT	0
56681	56636	01016M	PARTICIPANT	\N	PRESENT	0
56682	56636	14225N	PARTICIPANT	\N	PRESENT	0
57296	57281	11066Q	PARTICIPANT	\N	PRESENT	0
56684	56636	11057P	PARTICIPANT	\N	PRESENT	0
57299	57281	08028W	PARTICIPANT	\N	EXCUSE	0
56686	56636	04034C	PARTICIPANT	\N	PRESENT	0
57300	57281	11094U	PARTICIPANT	\N	EXCUSE	0
57301	57281	08048B	PARTICIPANT	\N	EXCUSE	0
58003	58002	11064N	PARTICIPANT	\N	PRESENT	0
57303	57281	11029K	PARTICIPANT	\N	EXCUSE	0
57308	57281	92045V	PARTICIPANT	\N	EXCUSE	0
57996	57995	14073Q	PARTICIPANT	\N	PRESENT	0
58004	58002	04040A	PARTICIPANT	\N	PRESENT	0
58005	58002	01003G	PARTICIPANT	\N	PRESENT	0
58006	58002	08018U	PARTICIPANT	\N	PRESENT	0
58007	58002	14034U	PARTICIPANT	\N	PRESENT	0
58008	58002	14097Y	PARTICIPANT	\N	PRESENT	0
58009	58002	04077P	PARTICIPANT	\N	PRESENT	0
58010	58002	11063M	PARTICIPANT	\N	PRESENT	0
58023	58022	14151M	PARTICIPANT	\N	PRESENT	0
58024	58022	92039X	PARTICIPANT	\N	PRESENT	0
58026	58025	11056N	PARTICIPANT	\N	PRESENT	0
58027	58025	08035V	PARTICIPANT	\N	PRESENT	0
58028	58025	11026G	PARTICIPANT	\N	PRESENT	0
58029	58025	11106F	PARTICIPANT	\N	PRESENT	0
58030	58025	11105E	PARTICIPANT	\N	PRESENT	0
58031	58025	14235Q	PARTICIPANT	\N	PRESENT	0
58032	58025	95067Q	PARTICIPANT	\N	PRESENT	0
58033	58025	11063M	PARTICIPANT	\N	PRESENT	0
58035	58034	86044G	PARTICIPANT	\N	PRESENT	0
58037	58036	08039A	PARTICIPANT	\N	PRESENT	0
58039	58038	08039A	PARTICIPANT	\N	PRESENT	0
58041	58040	08039A	PARTICIPANT	\N	PRESENT	0
58045	58044	11029K	PARTICIPANT	\N	PRESENT	0
58046	58044	08031R	PARTICIPANT	\N	PRESENT	0
58147	58060	86034E	PARTICIPANT	\N	PRESENT	0
58098	58096	04085P	PARTICIPANT	\N	PRESENT	0
58099	58096	05008E	PRESIDENT	0	PRESENT	0
58148	58060	14087W	PARTICIPANT	\N	PRESENT	0
58149	58060	14179A	PARTICIPANT	\N	PRESENT	0
58102	58096	14065Q	PARTICIPANT	\N	PRESENT	0
58103	58096	14069U	PARTICIPANT	\N	PRESENT	0
58104	58096	04047H	PARTICIPANT	\N	PRESENT	0
58150	58060	11035H	PARTICIPANT	\N	PRESENT	0
58106	58096	04038G	PARTICIPANT	\N	PRESENT	0
58151	58060	11037K	PARTICIPANT	\N	PRESENT	0
58152	58060	95049N	PARTICIPANT	\N	PRESENT	0
58153	58060	80027E	PARTICIPANT	\N	PRESENT	0
58110	58096	11035H	PARTICIPANT	\N	PRESENT	0
58111	58096	14041T	PARTICIPANT	\N	PRESENT	0
58154	58060	14030Q	PARTICIPANT	\N	PRESENT	0
58113	58096	01024M	PARTICIPANT	\N	PRESENT	0
58114	58096	14215L	PARTICIPANT	\N	PRESENT	0
58115	58096	11034G	PARTICIPANT	\N	PRESENT	0
58116	58096	08018U	PARTICIPANT	\N	PRESENT	0
58117	58096	11010L	PARTICIPANT	\N	PRESENT	0
58155	58060	14026U	PARTICIPANT	\N	PRESENT	0
58156	58060	14331P	PARTICIPANT	\N	PRESENT	0
58157	58060	14037X	PARTICIPANT	\N	PRESENT	0
58121	58096	11084S	PARTICIPANT	\N	PRESENT	0
58158	58060	95031C	PARTICIPANT	\N	PRESENT	0
58159	58060	99004R	PARTICIPANT	\N	PRESENT	0
58124	58096	14111D	PARTICIPANT	\N	PRESENT	0
58160	58060	04085P	PARTICIPANT	\N	PRESENT	0
58126	58096	14273W	PARTICIPANT	\N	PRESENT	0
58161	58060	95063L	PARTICIPANT	\N	PRESENT	0
58128	58096	14147R	PARTICIPANT	\N	PRESENT	0
58129	58096	95049N	PARTICIPANT	\N	PRESENT	0
58130	58096	08051V	PARTICIPANT	\N	PRESENT	0
58162	58060	08016S	PARTICIPANT	\N	PRESENT	0
58132	58096	07034Q	PRESIDENT	1	PRESENT	0
58163	58060	11039M	PARTICIPANT	\N	PRESENT	0
58164	58060	11089X	PARTICIPANT	\N	PRESENT	0
58135	58096	95063L	PARTICIPANT	\N	PRESENT	0
58136	58096	01019Q	PARTICIPANT	\N	PRESENT	0
58137	58096	01028R	PARTICIPANT	\N	PRESENT	0
58138	58096	98035U	PARTICIPANT	\N	PRESENT	0
58139	58096	04056J	PARTICIPANT	\N	PRESENT	0
58165	58060	11067R	PARTICIPANT	\N	PRESENT	0
58141	58096	04044E	PARTICIPANT	\N	EXCUSE	0
58142	58096	11037K	PARTICIPANT	\N	PRESENT	0
58166	58060	08043V	PARTICIPANT	\N	PRESENT	0
58167	58060	11036J	PARTICIPANT	\N	PRESENT	0
58168	58060	14109K	PARTICIPANT	\N	PRESENT	0
58169	58060	14013P	PARTICIPANT	\N	PRESENT	0
58170	58060	14159V	PARTICIPANT	\N	PRESENT	0
58171	58060	14063N	PARTICIPANT	\N	PRESENT	0
58172	58060	11056N	PARTICIPANT	\N	PRESENT	0
34155	33347	89029V	PARTICIPANT	\N	PRESENT	0
34156	33347	14227Q	PARTICIPANT	\N	PRESENT	0
34157	33347	04097T	PARTICIPANT	\N	PRESENT	0
34158	33347	11103C	PARTICIPANT	\N	PRESENT	0
34159	33347	98035U	PARTICIPANT	\N	PRESENT	0
34160	33347	14267Y	PARTICIPANT	\N	PRESENT	0
34161	33347	08052W	PARTICIPANT	\N	PRESENT	0
34162	33347	08048B	PARTICIPANT	\N	PRESENT	0
34163	33347	04088S	PARTICIPANT	\N	PRESENT	0
34164	33347	11060J	PARTICIPANT	\N	PRESENT	0
34165	33347	08025T	PARTICIPANT	\N	PRESENT	0
34166	33347	14215L	PARTICIPANT	\N	PRESENT	0
34167	33347	08016S	PARTICIPANT	\N	PRESENT	0
34168	33347	14217N	PARTICIPANT	\N	PRESENT	0
34169	33347	01015L	PARTICIPANT	\N	PRESENT	0
34170	33347	01019Q	PARTICIPANT	\N	PRESENT	0
34171	33347	11054L	PARTICIPANT	\N	PRESENT	0
34172	33347	04066L	PARTICIPANT	\N	PRESENT	0
34173	33347	11084S	PARTICIPANT	\N	PRESENT	0
34174	33347	01060R	PARTICIPANT	\N	PRESENT	0
34175	33347	11091R	PARTICIPANT	\N	PRESENT	0
34176	33347	80013X	PARTICIPANT	\N	PRESENT	0
34177	33347	04059M	PARTICIPANT	\N	PRESENT	0
34178	33347	98023Q	PARTICIPANT	\N	PRESENT	0
34179	33347	14085U	PARTICIPANT	\N	PRESENT	0
34180	33347	14273W	PARTICIPANT	\N	PRESENT	0
34181	33347	14081Q	PARTICIPANT	\N	PRESENT	0
34182	33347	08055A	PARTICIPANT	\N	PRESENT	0
34183	33347	92040Q	PARTICIPANT	\N	PRESENT	0
34184	33347	01013J	PARTICIPANT	\N	PRESENT	0
34185	33347	14133K	PARTICIPANT	\N	PRESENT	0
34186	33347	14121F	PARTICIPANT	\N	PRESENT	0
34187	33347	07029T	PARTICIPANT	\N	PRESENT	0
34188	33347	11055M	PARTICIPANT	\N	PRESENT	0
34189	33347	01034P	PARTICIPANT	\N	PRESENT	0
34190	33347	14275Y	PARTICIPANT	\N	PRESENT	0
34191	33347	01037S	PARTICIPANT	\N	PRESENT	0
34192	33347	11093T	PARTICIPANT	\N	PRESENT	0
34193	33347	14281W	PARTICIPANT	\N	PRESENT	0
34194	33347	14235Q	PARTICIPANT	\N	PRESENT	0
34195	33347	95041E	PARTICIPANT	\N	PRESENT	0
34196	33347	04095R	PARTICIPANT	\N	PRESENT	0
34197	33347	04036E	PARTICIPANT	\N	PRESENT	0
34198	33347	11067R	PARTICIPANT	\N	PRESENT	0
34199	33347	10006L	PARTICIPANT	\N	PRESENT	0
34200	33347	08012N	PARTICIPANT	\N	PRESENT	0
34201	33347	14063N	PARTICIPANT	\N	PRESENT	0
34202	33347	95030B	PARTICIPANT	\N	PRESENT	0
34203	33347	04034C	PARTICIPANT	\N	PRESENT	0
34204	33347	11101A	PARTICIPANT	\N	PRESENT	0
34205	33347	08043V	PARTICIPANT	\N	PRESENT	0
34206	33347	11077T	PARTICIPANT	\N	PRESENT	0
34207	33347	14147R	PARTICIPANT	\N	PRESENT	0
34208	33347	14265W	PARTICIPANT	\N	PRESENT	0
34209	33347	14211G	PARTICIPANT	\N	PRESENT	0
34210	33347	08018U	PARTICIPANT	\N	PRESENT	0
34211	33347	11097X	PARTICIPANT	\N	PRESENT	0
34212	33347	11048N	PARTICIPANT	\N	PRESENT	0
34213	33347	98050T	PARTICIPANT	\N	PRESENT	0
34214	33347	14079W	PARTICIPANT	\N	PRESENT	0
34215	33347	04057K	PARTICIPANT	\N	PRESENT	0
34216	33347	08065C	PARTICIPANT	\N	PRESENT	0
34217	33347	87003B	PARTICIPANT	\N	PRESENT	0
34218	33347	08011M	PARTICIPANT	\N	PRESENT	0
34219	33347	11031D	PARTICIPANT	\N	PRESENT	0
34220	33347	11063M	PARTICIPANT	\N	PRESENT	0
34221	33347	14237S	PARTICIPANT	\N	PRESENT	0
34222	33347	04081K	PARTICIPANT	\N	PRESENT	0
34223	33347	04086Q	PARTICIPANT	\N	PRESENT	0
34224	33347	08069G	PARTICIPANT	\N	PRESENT	0
34225	33347	11100Y	PARTICIPANT	\N	PRESENT	0
34226	33347	04092N	PARTICIPANT	\N	PRESENT	0
34227	33347	95059Q	PARTICIPANT	\N	PRESENT	0
34228	33347	07024N	PARTICIPANT	\N	PRESENT	0
34229	33347	98046X	PARTICIPANT	\N	PRESENT	0
34230	33347	97011G	PARTICIPANT	\N	PRESENT	0
34231	33347	98005N	PARTICIPANT	\N	PRESENT	0
34232	33347	08034U	PARTICIPANT	\N	PRESENT	0
34233	33347	11098Y	PARTICIPANT	\N	PRESENT	0
34234	33347	11040E	PARTICIPANT	\N	PRESENT	0
34235	33347	11034G	PARTICIPANT	\N	PRESENT	0
34236	33347	08042U	PARTICIPANT	\N	PRESENT	0
34237	33347	95062K	PARTICIPANT	\N	PRESENT	0
34238	33347	01059Y	PARTICIPANT	\N	PRESENT	0
34239	33347	08015R	PARTICIPANT	\N	PRESENT	0
34240	33347	12041X	PARTICIPANT	\N	PRESENT	0
34241	33347	04085P	PARTICIPANT	\N	PRESENT	0
34242	33347	11071M	PARTICIPANT	\N	PRESENT	0
34243	33347	11030C	PARTICIPANT	\N	PRESENT	0
34244	33347	04048J	PARTICIPANT	\N	PRESENT	0
34245	33347	86044G	PARTICIPANT	\N	PRESENT	0
34246	33347	14271U	PARTICIPANT	\N	PRESENT	0
34247	33347	95015C	PARTICIPANT	\N	PRESENT	0
34248	33347	04041B	PARTICIPANT	\N	PRESENT	0
34249	33347	01056V	PARTICIPANT	\N	PRESENT	0
34250	33347	01022K	PARTICIPANT	\N	PRESENT	0
34251	33347	14033T	PARTICIPANT	\N	PRESENT	0
34252	33347	92020L	PARTICIPANT	\N	PRESENT	0
34253	33347	11043H	PARTICIPANT	\N	PRESENT	0
34254	33347	01058X	PARTICIPANT	\N	PRESENT	0
34255	33347	14107H	PARTICIPANT	\N	PRESENT	0
34256	33347	08047A	PARTICIPANT	\N	PRESENT	0
34257	33347	14051J	PARTICIPANT	\N	PRESENT	0
34258	33347	96004D	PARTICIPANT	\N	PRESENT	0
34259	33347	14093U	PARTICIPANT	\N	PRESENT	0
34260	33347	04033B	PARTICIPANT	\N	PRESENT	0
34261	33347	11044J	PARTICIPANT	\N	PRESENT	0
34262	33347	80027E	PARTICIPANT	\N	PRESENT	0
34263	33347	04074L	PARTICIPANT	\N	PRESENT	0
34264	33347	98029W	PARTICIPANT	\N	PRESENT	0
34265	33347	14225N	PARTICIPANT	\N	PRESENT	0
34266	33347	01061S	PARTICIPANT	\N	PRESENT	0
34267	33347	83042R	PARTICIPANT	\N	PRESENT	0
34268	33347	14229S	PARTICIPANT	\N	PRESENT	0
34269	33347	01057W	PARTICIPANT	\N	PRESENT	0
34270	33347	95037J	PARTICIPANT	\N	PRESENT	0
34271	33347	08058D	PARTICIPANT	\N	PRESENT	0
34272	33347	14329V	PARTICIPANT	\N	PRESENT	0
34273	33347	14105F	PARTICIPANT	\N	PRESENT	0
34274	33347	14109K	PARTICIPANT	\N	PRESENT	0
34275	33347	14028W	PARTICIPANT	\N	PRESENT	0
34276	33347	11010L	PARTICIPANT	\N	PRESENT	0
34277	33347	08014Q	PARTICIPANT	\N	PRESENT	0
34278	33347	11095V	PARTICIPANT	\N	PRESENT	0
34279	33347	14042U	PARTICIPANT	\N	PRESENT	0
34280	33347	14001X	PARTICIPANT	\N	PRESENT	0
34281	33347	14213J	PARTICIPANT	\N	PRESENT	0
34282	33347	14167V	PARTICIPANT	\N	PRESENT	0
34283	33347	14135M	PARTICIPANT	\N	PRESENT	0
34284	33347	04056J	PARTICIPANT	\N	PRESENT	0
34285	33347	10015M	PARTICIPANT	\N	PRESENT	0
34286	33347	11042G	PARTICIPANT	\N	PRESENT	0
34287	33347	08060W	PARTICIPANT	\N	PRESENT	0
34288	33347	13002U	PARTICIPANT	\N	PRESENT	0
34289	33347	14053L	PARTICIPANT	\N	PRESENT	0
34290	33347	11112D	PARTICIPANT	\N	PRESENT	0
34291	33347	14199E	PARTICIPANT	\N	PRESENT	0
34292	33347	04042C	PARTICIPANT	\N	PRESENT	0
34293	33347	92045V	PARTICIPANT	\N	PRESENT	0
34294	33347	11026G	PARTICIPANT	\N	PRESENT	0
34295	33347	01031L	PARTICIPANT	\N	PRESENT	0
34296	33347	11015D	PARTICIPANT	\N	PRESENT	0
34297	33347	14061L	PARTICIPANT	\N	PRESENT	0
34298	33347	04077P	PARTICIPANT	\N	PRESENT	0
34299	33347	08061X	PARTICIPANT	\N	PRESENT	0
34300	33347	11089X	PARTICIPANT	\N	PRESENT	0
34301	33347	08024S	PARTICIPANT	\N	PRESENT	0
34302	33347	07032N	PARTICIPANT	\N	PRESENT	0
34303	33347	08053X	PARTICIPANT	\N	PRESENT	0
34304	33347	14259Y	PARTICIPANT	\N	PRESENT	0
34305	33347	11059R	PARTICIPANT	\N	PRESENT	0
34306	33347	04044E	PARTICIPANT	\N	PRESENT	0
34307	33347	14123H	PARTICIPANT	\N	PRESENT	0
34308	33347	14071N	PARTICIPANT	\N	PRESENT	0
34309	33347	99002P	PARTICIPANT	\N	PRESENT	0
34310	33347	08068F	PARTICIPANT	\N	PRESENT	0
34311	33347	14073Q	PARTICIPANT	\N	PRESENT	0
34312	33347	11046L	PARTICIPANT	\N	PRESENT	0
34313	33347	04045F	PARTICIPANT	\N	PRESENT	0
34314	33347	04094Q	PARTICIPANT	\N	PRESENT	0
34315	33347	11061K	PARTICIPANT	\N	PRESENT	0
34316	33347	14209N	PARTICIPANT	\N	PRESENT	0
34317	33347	14195A	PARTICIPANT	\N	PRESENT	0
34318	33347	98053W	PARTICIPANT	\N	PRESENT	0
34319	33347	04043D	PARTICIPANT	\N	PRESENT	0
34320	33347	11036J	PARTICIPANT	\N	PRESENT	0
34321	33347	14197C	PARTICIPANT	\N	PRESENT	0
34322	33347	14207L	PARTICIPANT	\N	PRESENT	0
57337	49959	08073C	PARTICIPANT	\N	EXCUSE	0
57338	49959	04043D	PARTICIPANT	\N	PRESENT	0
57339	49959	11071M	PARTICIPANT	\N	EXCUSE	0
57340	49959	14275Y	PARTICIPANT	\N	PRESENT	0
57341	49959	11025F	PARTICIPANT	\N	PRESENT	0
57342	49959	14017T	PARTICIPANT	\N	EXCUSE	0
57437	57434	89017R	PARTICIPANT	\N	PRESENT	0
57438	57434	11039M	PARTICIPANT	\N	PRESENT	0
57440	57434	08055A	PARTICIPANT	\N	PRESENT	0
57441	57434	04066L	PARTICIPANT	\N	PRESENT	0
57443	57434	04042C	PARTICIPANT	\N	PRESENT	0
57444	57434	08024S	PARTICIPANT	\N	PRESENT	0
57445	57434	04081K	PARTICIPANT	\N	PRESENT	0
57446	57434	04067M	PARTICIPANT	\N	PRESENT	0
57448	57434	98042T	PARTICIPANT	\N	PRESENT	0
57449	57434	01003G	PARTICIPANT	\N	PRESENT	0
57450	57434	98053W	PARTICIPANT	\N	PRESENT	0
57451	57434	08048B	PARTICIPANT	\N	PRESENT	0
57453	57434	01007L	PARTICIPANT	\N	PRESENT	0
57455	57434	95037J	PARTICIPANT	\N	PRESENT	0
57456	57434	86034E	PARTICIPANT	\N	PRESENT	0
57458	57434	04094Q	PARTICIPANT	\N	PRESENT	0
57459	57434	08039A	PARTICIPANT	\N	PRESENT	0
57460	57434	11085T	PARTICIPANT	\N	PRESENT	0
57461	57434	04057K	PARTICIPANT	\N	PRESENT	0
57462	57434	92040Q	PARTICIPANT	\N	PRESENT	0
57463	57434	04088S	PARTICIPANT	\N	PRESENT	0
57464	57434	01019Q	PARTICIPANT	\N	PRESENT	0
57465	57434	04056J	PARTICIPANT	\N	PRESENT	0
57624	57623	11039M	PARTICIPANT	\N	PRESENT	0
57625	57623	98042T	PARTICIPANT	\N	PRESENT	0
57626	57623	01019Q	PARTICIPANT	\N	PRESENT	0
58551	57516	11068S	PARTICIPANT	\N	PRESENT	0
59131	59130	11030C	PARTICIPANT	\N	PRESENT	0
59411	59410	01008M	PARTICIPANT	\N	PRESENT	0
59412	59410	11036J	PARTICIPANT	\N	PRESENT	0
59451	59450	08025T	PARTICIPANT	\N	PRESENT	0
59414	59410	14013P	PARTICIPANT	\N	PRESENT	0
59415	59410	08068F	PARTICIPANT	\N	PRESENT	0
59416	59410	14207L	PARTICIPANT	\N	PRESENT	0
58949	58948	11039M	PARTICIPANT	\N	PRESENT	0
58950	58948	01019Q	PARTICIPANT	\N	PRESENT	0
59417	59410	11101A	PARTICIPANT	\N	PRESENT	0
59452	59450	04085P	PARTICIPANT	\N	PRESENT	0
59419	59410	08028W	PARTICIPANT	\N	PRESENT	0
59420	59410	80013X	PARTICIPANT	\N	PRESENT	0
59421	59410	08038Y	PARTICIPANT	\N	PRESENT	0
59422	59410	04089T	PARTICIPANT	\N	PRESENT	0
59423	59410	14197C	PARTICIPANT	\N	PRESENT	0
59424	59410	11110B	PARTICIPANT	\N	PRESENT	0
59425	59410	14187A	PARTICIPANT	\N	PRESENT	0
59426	59410	14033T	PARTICIPANT	\N	PRESENT	0
59427	59410	14081Q	PARTICIPANT	\N	PRESENT	0
59428	59410	04048J	PARTICIPANT	\N	PRESENT	0
59429	59410	11099A	PARTICIPANT	\N	PRESENT	0
59453	59450	05008E	PRESIDENT	0	PRESENT	0
59454	59450	11030C	PARTICIPANT	\N	PRESENT	0
59432	59410	11111C	PARTICIPANT	\N	PRESENT	0
59433	59410	08015R	PARTICIPANT	\N	PRESENT	0
59434	59410	11100Y	PRESIDENT	0	PRESENT	0
59435	59410	01061S	PARTICIPANT	\N	PRESENT	0
59436	59410	11098Y	PARTICIPANT	\N	PRESENT	0
59437	59410	01043Q	PARTICIPANT	\N	PRESENT	0
59438	59410	11077T	PARTICIPANT	\N	PRESENT	0
59439	59410	14205J	PARTICIPANT	\N	PRESENT	0
59440	59410	08019V	PARTICIPANT	\N	PRESENT	0
59441	59410	14257W	PARTICIPANT	\N	PRESENT	0
59455	59450	11033F	PARTICIPANT	\N	PRESENT	0
59443	59410	04088S	PARTICIPANT	\N	PRESENT	0
59501	59500	89017R	PARTICIPANT	\N	PRESENT	0
59445	59410	11090Q	PARTICIPANT	\N	PRESENT	0
59446	59410	11046L	PARTICIPANT	\N	PRESENT	0
59447	59410	01058X	PARTICIPANT	\N	PRESENT	0
59448	59410	11094U	PARTICIPANT	\N	PRESENT	0
59449	59410	11066Q	PARTICIPANT	\N	PRESENT	0
59456	59450	14065Q	PARTICIPANT	\N	PRESENT	0
59457	59450	14069U	PARTICIPANT	\N	PRESENT	0
59458	59450	04047H	PARTICIPANT	\N	PRESENT	0
59459	59450	11032E	PARTICIPANT	\N	PRESENT	0
59460	59450	04038G	PARTICIPANT	\N	PRESENT	0
59502	59500	01031L	PRESIDENT	0	PRESENT	0
59462	59450	11056N	PARTICIPANT	\N	PRESENT	0
59463	59450	14259Y	PARTICIPANT	\N	PRESENT	0
59464	59450	11035H	PARTICIPANT	\N	PRESENT	0
59465	59450	14041T	PARTICIPANT	\N	PRESENT	0
59466	59450	11113E	PARTICIPANT	\N	PRESENT	0
59467	59450	01024M	PARTICIPANT	\N	PRESENT	0
59468	59450	14215L	PARTICIPANT	\N	PRESENT	0
59469	59450	11034G	PARTICIPANT	\N	PRESENT	0
59470	59450	08018U	PARTICIPANT	\N	PRESENT	0
59769	58246	14083S	PARTICIPANT	\N	PRESENT	0
59472	59450	01007L	PARTICIPANT	\N	PRESENT	0
59473	59450	11049P	PARTICIPANT	\N	PRESENT	0
59474	59450	08044W	PARTICIPANT	\N	PRESENT	0
59475	59450	11084S	PARTICIPANT	\N	PRESENT	0
59504	59500	01013J	PARTICIPANT	\N	PRESENT	0
59477	59450	04079R	PARTICIPANT	\N	PRESENT	0
59478	59450	14111D	PARTICIPANT	\N	PRESENT	0
59479	59450	14001X	PARTICIPANT	\N	PRESENT	0
59480	59450	14273W	PARTICIPANT	\N	PRESENT	0
59481	59450	01060R	PARTICIPANT	\N	PRESENT	0
59482	59450	14147R	PARTICIPANT	\N	PRESENT	0
59483	59450	95049N	PARTICIPANT	\N	PRESENT	0
59484	59450	08051V	PARTICIPANT	\N	PRESENT	0
59505	59500	11068S	PARTICIPANT	\N	PRESENT	0
59486	59450	07034Q	PRESIDENT	2	PRESENT	0
59487	59450	04074L	PARTICIPANT	\N	PRESENT	0
59488	59450	10015M	PARTICIPANT	\N	PRESENT	0
59489	59450	95063L	PARTICIPANT	\N	PRESENT	0
59490	59450	01019Q	PARTICIPANT	\N	PRESENT	0
59491	59450	01028R	PRESIDENT	1	PRESENT	0
59492	59450	98035U	PARTICIPANT	\N	PRESENT	0
59493	59450	04056J	PARTICIPANT	\N	PRESENT	0
59506	59500	11040E	PARTICIPANT	\N	PRESENT	0
59495	59450	04044E	PARTICIPANT	\N	EXCUSE	0
59496	59450	11037K	PARTICIPANT	\N	PRESENT	0
59497	59450	92045V	PARTICIPANT	\N	PRESENT	0
59507	59500	08014Q	PARTICIPANT	\N	PRESENT	0
59499	59450	01047U	PARTICIPANT	\N	PRESENT	0
59508	59500	14167V	PARTICIPANT	\N	PRESENT	0
59509	59500	14175V	PARTICIPANT	\N	PRESENT	0
59510	59500	14083S	PARTICIPANT	\N	PRESENT	0
59511	59500	11053K	PARTICIPANT	\N	PRESENT	0
59512	59500	14085U	PARTICIPANT	\N	PRESENT	0
59513	59500	11042G	PARTICIPANT	\N	PRESENT	0
59514	59500	88008L	PARTICIPANT	\N	PRESENT	0
59515	59500	04086Q	PARTICIPANT	\N	PRESENT	0
59770	58246	11039M	PARTICIPANT	\N	PRESENT	0
59517	59500	11070L	PARTICIPANT	\N	PRESENT	0
59518	59500	11088W	PARTICIPANT	\N	PRESENT	0
59519	59500	14327T	PARTICIPANT	\N	PRESENT	0
59520	59500	08022Q	PARTICIPANT	\N	PRESENT	0
59521	59500	01027Q	PARTICIPANT	\N	PRESENT	0
59522	59500	04071H	PARTICIPANT	\N	PRESENT	0
59523	59500	11074Q	PARTICIPANT	\N	PRESENT	0
59771	58246	11110B	PARTICIPANT	\N	PRESENT	0
59525	59500	11083R	PARTICIPANT	\N	PRESENT	0
59526	59500	14199E	PARTICIPANT	\N	PRESENT	0
59527	59500	01057W	PARTICIPANT	\N	PRESENT	0
59528	59500	08016S	PARTICIPANT	\N	PRESENT	0
59529	59500	08069G	PARTICIPANT	\N	PRESENT	0
59530	59500	11048N	PARTICIPANT	\N	PRESENT	0
59531	59500	99004R	PARTICIPANT	\N	PRESENT	0
59532	59500	04061F	PARTICIPANT	\N	PRESENT	0
59533	59500	14159V	PARTICIPANT	\N	PRESENT	0
59534	59500	07029T	PARTICIPANT	\N	PRESENT	0
59535	59500	14277B	PARTICIPANT	\N	PRESENT	0
59536	59500	08010L	PARTICIPANT	\N	PRESENT	0
59537	59500	08034U	PARTICIPANT	\N	PRESENT	0
59538	59500	01048V	PARTICIPANT	\N	PRESENT	0
59539	59500	98046X	PARTICIPANT	\N	PRESENT	0
59772	58246	14103D	PARTICIPANT	\N	PRESENT	0
59541	59500	08011M	PARTICIPANT	\N	PRESENT	0
59542	59500	08073C	PARTICIPANT	\N	EXCUSE	0
59543	59500	08061X	PARTICIPANT	\N	PRESENT	0
59544	59500	01016M	PARTICIPANT	\N	PRESENT	0
59545	59500	14225N	PARTICIPANT	\N	PRESENT	0
59546	59500	11012A	PARTICIPANT	\N	PRESENT	0
59547	59500	11057P	PARTICIPANT	\N	PRESENT	0
59548	59500	14173T	PARTICIPANT	\N	PRESENT	0
59549	59500	04034C	PARTICIPANT	\N	PRESENT	0
59773	58246	14065Q	PARTICIPANT	\N	PRESENT	0
59774	58246	08010L	PARTICIPANT	\N	PRESENT	0
59779	58246	14241N	PARTICIPANT	\N	PRESENT	0
59780	58246	14231L	PARTICIPANT	\N	PRESENT	0
59782	58246	14237S	PARTICIPANT	\N	PRESENT	0
59785	58246	01047U	PARTICIPANT	\N	PRESENT	0
59787	58246	11093T	PARTICIPANT	\N	PRESENT	0
59789	58246	11061K	PARTICIPANT	\N	PRESENT	0
59790	58246	14089Y	PARTICIPANT	\N	PRESENT	0
36667	36665	04074L	PARTICIPANT	\N	PRESENT	0
36669	36668	04074L	PARTICIPANT	\N	PRESENT	0
43806	43149	04071H	PARTICIPANT	\N	PRESENT	0
36600	36595	04053F	PARTICIPANT	\N	PRESENT	0
36601	36595	14255U	PARTICIPANT	\N	PRESENT	0
36602	36595	04066L	PARTICIPANT	\N	PRESENT	0
36603	36595	00003C	PARTICIPANT	\N	PRESENT	0
36604	36595	14053L	PARTICIPANT	\N	PRESENT	0
36605	36595	11103C	PARTICIPANT	\N	PRESENT	0
43807	43149	14039A	PARTICIPANT	\N	PRESENT	0
36607	36595	14195A	PARTICIPANT	\N	PRESENT	0
43824	43149	11113E	PARTICIPANT	\N	PRESENT	0
43809	43149	11042G	PARTICIPANT	\N	PRESENT	0
43825	43149	11063M	PARTICIPANT	\N	PRESENT	0
36611	36595	08052W	PARTICIPANT	\N	PRESENT	0
36612	36595	01059Y	PARTICIPANT	\N	PRESENT	0
36613	36595	04081K	PARTICIPANT	\N	EXCUSE	0
43811	43149	04094Q	PARTICIPANT	\N	PRESENT	0
43812	43149	04034C	PARTICIPANT	\N	PRESENT	0
36616	36595	04067M	PARTICIPANT	\N	PRESENT	0
36617	36595	14217N	PARTICIPANT	\N	PRESENT	0
43826	43149	11012A	PARTICIPANT	\N	PRESENT	0
36619	36595	14151M	PARTICIPANT	\N	PRESENT	0
36620	36595	12042Y	PARTICIPANT	\N	PRESENT	0
36621	36595	14281W	PARTICIPANT	\N	PRESENT	0
36622	36595	14087W	PARTICIPANT	\N	PRESENT	0
43827	43149	11105E	PARTICIPANT	\N	PRESENT	0
36624	36595	14034U	PARTICIPANT	\N	PRESENT	0
36625	36595	14231L	PARTICIPANT	\N	PRESENT	0
36626	36595	11061K	PARTICIPANT	\N	PRESENT	0
43828	43149	08016S	PARTICIPANT	\N	PRESENT	0
36628	36595	08041T	PARTICIPANT	\N	EXCUSE	0
36629	36595	01011G	PARTICIPANT	\N	PRESENT	0
36630	36595	14026U	PARTICIPANT	\N	PRESENT	0
43829	43149	08031R	PARTICIPANT	\N	PRESENT	0
36632	36595	14121F	PARTICIPANT	\N	PRESENT	0
36633	36595	11112D	PARTICIPANT	\N	PRESENT	0
36634	36595	14037X	PARTICIPANT	\N	PRESENT	0
43830	43149	11053K	PARTICIPANT	\N	PRESENT	0
36636	36595	11067R	PARTICIPANT	\N	PRESENT	0
36637	36595	14223L	PARTICIPANT	\N	EXCUSE	0
36638	36595	04092N	PRESIDENT	0	PRESENT	0
36639	36595	14265W	PARTICIPANT	\N	PRESENT	0
36640	36595	14119M	PARTICIPANT	\N	PRESENT	0
36641	36595	14071N	PARTICIPANT	\N	PRESENT	0
36642	36595	07032N	PARTICIPANT	\N	PRESENT	0
36643	36595	04043D	PARTICIPANT	\N	PRESENT	0
36644	36595	14271U	PARTICIPANT	\N	PRESENT	0
43818	43149	08073C	PARTICIPANT	\N	PRESENT	0
36646	36595	11093T	PARTICIPANT	\N	PRESENT	0
36647	36595	11097X	PARTICIPANT	\N	PRESENT	0
36648	36595	04045F	PARTICIPANT	\N	PRESENT	0
43819	43149	80013X	PARTICIPANT	\N	PRESENT	0
36650	36595	01034P	PARTICIPANT	\N	PRESENT	0
43831	43149	14175V	PARTICIPANT	\N	PRESENT	0
43821	43149	04085P	PARTICIPANT	\N	PRESENT	0
36653	36595	14269B	PARTICIPANT	\N	PRESENT	0
43822	43149	14235Q	PARTICIPANT	\N	PRESENT	0
43823	43149	11082Q	PARTICIPANT	\N	PRESENT	0
43832	43149	14133K	PARTICIPANT	\N	PRESENT	0
43833	43153	04066L	PARTICIPANT	\N	PRESENT	0
43850	43153	14235Q	PARTICIPANT	\N	PRESENT	0
43851	43153	11031D	PARTICIPANT	\N	PRESENT	0
43852	43153	11063M	PARTICIPANT	\N	PRESENT	0
43853	43153	80013X	PARTICIPANT	\N	PRESENT	0
43854	43153	07029T	PARTICIPANT	\N	PRESENT	0
43855	43153	01031L	PARTICIPANT	\N	PRESENT	0
43856	43153	11042G	PARTICIPANT	\N	PRESENT	0
43857	43153	14159V	PARTICIPANT	\N	PRESENT	0
43858	43153	11105E	PARTICIPANT	\N	PRESENT	0
43859	43153	14225N	PARTICIPANT	\N	PRESENT	0
43860	43153	04034C	PARTICIPANT	\N	PRESENT	0
43861	43153	11054L	PARTICIPANT	\N	PRESENT	0
43862	43153	14037X	PARTICIPANT	\N	PRESENT	0
43863	43153	11012A	PARTICIPANT	\N	PRESENT	0
43864	43153	07004J	PARTICIPANT	\N	PRESENT	0
43865	43153	14219Q	PARTICIPANT	\N	PRESENT	0
43866	43153	11082Q	PARTICIPANT	\N	PRESENT	0
43867	43153	01041N	PARTICIPANT	\N	PRESENT	0
43868	43153	07024N	PARTICIPANT	\N	PRESENT	0
43869	43153	14119M	PARTICIPANT	\N	PRESENT	0
43870	43153	01028R	PARTICIPANT	\N	PRESENT	0
43871	43153	11083R	PARTICIPANT	\N	PRESENT	0
43872	43153	01046T	PARTICIPANT	\N	PRESENT	0
43873	43153	14133K	PARTICIPANT	\N	PRESENT	0
43874	43153	14111D	PARTICIPANT	\N	PRESENT	0
43875	43153	14261S	PARTICIPANT	\N	PRESENT	0
43876	43153	11026G	PARTICIPANT	\N	PRESENT	0
43877	43153	08031R	PARTICIPANT	\N	PRESENT	0
43878	43153	14179A	PARTICIPANT	\N	PRESENT	0
43879	43153	04042C	PARTICIPANT	\N	PRESENT	0
43880	43153	08069G	PARTICIPANT	\N	PRESENT	0
43881	43153	08025T	PARTICIPANT	\N	PRESENT	0
43882	43156	04066L	PARTICIPANT	\N	PRESENT	0
43883	43156	14235Q	PARTICIPANT	\N	PRESENT	0
43884	43156	11063M	PARTICIPANT	\N	PRESENT	0
45657	44620	11068S	PARTICIPANT	\N	EXCUSE	0
43886	43156	07029T	PARTICIPANT	\N	PRESENT	0
43887	43156	01031L	PARTICIPANT	\N	PRESENT	0
45658	44248	11068S	PARTICIPANT	\N	EXCUSE	0
43889	43156	14159V	PARTICIPANT	\N	PRESENT	0
47304	47303	11090Q	PARTICIPANT	\N	PRESENT	0
43891	43156	14225N	PARTICIPANT	\N	PRESENT	0
43892	43156	04034C	PARTICIPANT	\N	PRESENT	0
43893	43156	11054L	PARTICIPANT	\N	PRESENT	0
47306	47305	11090Q	PARTICIPANT	\N	PRESENT	0
47309	47308	11100Y	PARTICIPANT	\N	PRESENT	0
43896	43156	07004J	PARTICIPANT	\N	PRESENT	0
47311	47310	11100Y	PARTICIPANT	\N	PRESENT	0
47314	47313	09001P	PARTICIPANT	\N	PRESENT	0
47316	47315	09001P	PARTICIPANT	\N	PRESENT	0
43900	43156	07024N	PARTICIPANT	\N	PRESENT	0
43901	43156	14119M	PARTICIPANT	\N	PRESENT	0
43902	43156	01028R	PARTICIPANT	\N	PRESENT	0
43903	43156	11083R	PARTICIPANT	\N	PRESENT	0
43904	43156	01046T	PARTICIPANT	\N	PRESENT	0
47319	47318	09001P	PARTICIPANT	\N	PRESENT	0
43907	43156	14261S	PARTICIPANT	\N	PRESENT	0
43908	43156	11026G	PARTICIPANT	\N	PRESENT	0
43909	43156	08031R	PARTICIPANT	\N	PRESENT	0
47358	43531	04040A	PRESIDENT	0	PRESENT	0
43911	43156	04042C	PARTICIPANT	\N	PRESENT	0
54984	54976	14215L	PARTICIPANT	\N	PRESENT	0
43913	43156	08025T	PARTICIPANT	\N	PRESENT	0
43914	43156	11031D	PARTICIPANT	\N	PRESENT	0
43915	43156	14083S	PARTICIPANT	\N	PRESENT	0
54985	54976	11034G	PARTICIPANT	\N	PRESENT	0
54986	54976	08018U	PARTICIPANT	\N	PRESENT	0
54987	54976	01007L	PARTICIPANT	\N	PRESENT	0
54988	54976	11026G	PARTICIPANT	\N	PRESENT	0
54989	54976	14111D	PARTICIPANT	\N	PRESENT	0
54990	54976	14273W	PARTICIPANT	\N	PRESENT	0
54991	54976	07034Q	PARTICIPANT	\N	PRESENT	0
54992	54976	04074L	PARTICIPANT	\N	PRESENT	0
54993	54976	95063L	PARTICIPANT	\N	PRESENT	0
54994	54976	01028R	PARTICIPANT	\N	PRESENT	0
54995	54976	98035U	PARTICIPANT	\N	PRESENT	0
54996	54976	04056J	PARTICIPANT	\N	PRESENT	0
54998	54976	14275Y	PARTICIPANT	\N	PRESENT	0
54999	54976	04044E	PRESIDENT	1	PRESENT	0
55000	54976	11037K	PARTICIPANT	\N	PRESENT	0
55001	54976	92045V	PARTICIPANT	\N	PRESENT	0
55002	54976	01047U	PARTICIPANT	\N	PRESENT	0
55003	54976	95067Q	PARTICIPANT	\N	PRESENT	0
56173	56172	08025T	PARTICIPANT	\N	PRESENT	0
56174	56172	04085P	PARTICIPANT	\N	PRESENT	0
56175	56172	05008E	PRESIDENT	0	PRESENT	0
56176	56172	11033F	PARTICIPANT	\N	PRESENT	0
56177	56172	14065Q	PARTICIPANT	\N	PRESENT	0
56178	56172	14069U	PARTICIPANT	\N	PRESENT	0
56179	56172	04047H	PARTICIPANT	\N	PRESENT	0
56180	56172	04038G	PARTICIPANT	\N	PRESENT	0
56181	56172	11056N	PARTICIPANT	\N	PRESENT	0
56182	56172	11035H	PARTICIPANT	\N	PRESENT	0
56183	56172	14041T	PARTICIPANT	\N	PRESENT	0
56184	56172	01024M	PARTICIPANT	\N	PRESENT	0
56185	56172	14215L	PARTICIPANT	\N	PRESENT	0
56186	56172	11034G	PARTICIPANT	\N	PRESENT	0
56187	56172	08018U	PARTICIPANT	\N	PRESENT	0
56188	56172	11010L	PARTICIPANT	\N	PRESENT	0
56189	56172	01007L	PARTICIPANT	\N	PRESENT	0
56190	56172	11049P	PARTICIPANT	\N	PRESENT	0
56191	56172	11084S	PARTICIPANT	\N	PRESENT	0
56192	56172	11026G	PARTICIPANT	\N	PRESENT	0
56193	56172	14111D	PARTICIPANT	\N	PRESENT	0
56194	56172	14001X	PARTICIPANT	\N	PRESENT	0
56195	56172	14273W	PARTICIPANT	\N	PRESENT	0
56196	56172	14147R	PARTICIPANT	\N	PRESENT	0
58173	58060	08058D	PARTICIPANT	\N	PRESENT	0
58174	58060	11066Q	PARTICIPANT	\N	PRESENT	0
58175	58060	14065Q	PARTICIPANT	\N	PRESENT	0
58176	58060	14219Q	PARTICIPANT	\N	PRESENT	0
58177	58060	14205J	PARTICIPANT	\N	PRESENT	0
58178	58060	14231L	PARTICIPANT	\N	PRESENT	0
58179	58060	08044W	PARTICIPANT	\N	PRESENT	0
58180	58060	01047U	PARTICIPANT	\N	PRESENT	0
58181	58060	88008L	PARTICIPANT	\N	PRESENT	0
58182	58060	04038G	PARTICIPANT	\N	PRESENT	0
58183	58060	11012A	PARTICIPANT	\N	PRESENT	0
58184	58060	14018U	PARTICIPANT	\N	PRESENT	0
58185	58060	11040E	PARTICIPANT	\N	PRESENT	0
58186	58060	01025N	PARTICIPANT	\N	PRESENT	0
58187	58060	95030B	PARTICIPANT	\N	PRESENT	0
58188	58060	04081K	PARTICIPANT	\N	PRESENT	0
58189	58060	04047H	PARTICIPANT	\N	PRESENT	0
58190	58060	86044G	PARTICIPANT	\N	PRESENT	0
58191	58060	01058X	PARTICIPANT	\N	PRESENT	0
58192	58060	01019Q	PARTICIPANT	\N	PRESENT	0
58193	58060	14211G	PARTICIPANT	\N	PRESENT	0
58194	58060	08028W	PARTICIPANT	\N	PRESENT	0
58195	58060	11043H	PARTICIPANT	\N	PRESENT	0
58196	58060	11048N	PARTICIPANT	\N	PRESENT	0
58197	58060	87003B	PARTICIPANT	\N	PRESENT	0
58198	58060	10015M	PARTICIPANT	\N	PRESENT	0
58199	58060	04041B	PARTICIPANT	\N	PRESENT	0
58200	58060	14147R	PARTICIPANT	\N	PRESENT	0
58201	58060	11091R	PARTICIPANT	\N	PRESENT	0
58202	58060	04043D	PARTICIPANT	\N	PRESENT	0
58203	58060	14191V	PARTICIPANT	\N	PRESENT	0
58204	58060	11044J	PARTICIPANT	\N	PRESENT	0
58205	58060	11103C	PARTICIPANT	\N	PRESENT	0
58206	58060	14187A	PARTICIPANT	\N	PRESENT	0
58207	58060	14061L	PARTICIPANT	\N	PRESENT	0
58208	58060	14059S	PARTICIPANT	\N	PRESENT	0
58209	58060	11090Q	PARTICIPANT	\N	PRESENT	0
58210	58060	08041T	PARTICIPANT	\N	PRESENT	0
58211	58060	07029T	PARTICIPANT	\N	PRESENT	0
58212	58060	11011M	PARTICIPANT	\N	PRESENT	0
58213	58060	14105F	PARTICIPANT	\N	PRESENT	0
58214	58060	01024M	PARTICIPANT	\N	PRESENT	0
58215	58060	11049P	PARTICIPANT	\N	PRESENT	0
58216	58060	14111D	PARTICIPANT	\N	PRESENT	0
58217	58060	14041T	PARTICIPANT	\N	PRESENT	0
58218	58060	04088S	PARTICIPANT	\N	PRESENT	0
58219	58060	14033T	PARTICIPANT	\N	PRESENT	0
58220	58060	14157T	PARTICIPANT	\N	PRESENT	0
58221	58060	14173T	PARTICIPANT	\N	PRESENT	0
58222	58060	14223L	PARTICIPANT	\N	PRESENT	0
58223	58060	14038Y	PARTICIPANT	\N	PRESENT	0
58224	58060	14273W	PARTICIPANT	\N	PRESENT	0
58225	58060	08053X	PARTICIPANT	\N	PRESENT	0
58226	58060	14028W	PARTICIPANT	\N	PRESENT	0
58227	58060	14169X	PARTICIPANT	\N	PRESENT	0
58228	58060	08051V	PARTICIPANT	\N	PRESENT	0
58229	58060	04035D	PARTICIPANT	\N	PRESENT	0
58230	58060	14265W	PARTICIPANT	\N	PRESENT	0
58231	58060	05008E	PARTICIPANT	\N	PRESENT	0
58232	58060	14207L	PARTICIPANT	\N	PRESENT	0
58233	58060	14103D	PARTICIPANT	\N	PRESENT	0
58234	58060	08024S	PARTICIPANT	\N	PRESENT	0
58235	58060	07004J	PARTICIPANT	\N	PRESENT	0
58236	58060	14209N	PARTICIPANT	\N	PRESENT	0
58237	58060	14213J	PARTICIPANT	\N	PRESENT	0
58238	58060	11111C	PARTICIPANT	\N	PRESENT	0
58239	58060	95035G	PARTICIPANT	\N	PRESENT	0
58240	58060	96004D	PARTICIPANT	\N	PRESENT	0
58241	58060	04071H	PARTICIPANT	\N	PRESENT	0
58242	58060	11042G	PARTICIPANT	\N	PRESENT	0
58243	58060	14053L	PARTICIPANT	\N	PRESENT	0
58244	58060	11097X	PARTICIPANT	\N	PRESENT	0
58245	58060	01028R	PARTICIPANT	\N	PRESENT	0
58249	58060	11033F	PARTICIPANT	\N	PRESENT	0
58251	58060	04033B	PARTICIPANT	\N	PRESENT	0
58252	58060	14271U	PARTICIPANT	\N	PRESENT	0
58255	58060	95062K	PARTICIPANT	\N	PRESENT	0
58256	58060	14073Q	PARTICIPANT	\N	PRESENT	0
58257	58060	11064N	PARTICIPANT	\N	PRESENT	0
58258	58060	08038Y	PARTICIPANT	\N	PRESENT	0
58259	58060	14259Y	PARTICIPANT	\N	PRESENT	0
58260	58060	14031R	PARTICIPANT	\N	PRESENT	0
58261	58060	01048V	PARTICIPANT	\N	PRESENT	0
58262	58060	11057P	PARTICIPANT	\N	PRESENT	0
58263	58060	11034G	PARTICIPANT	\N	PRESENT	0
58264	58060	04053F	PARTICIPANT	\N	PRESENT	0
58265	58060	14215L	PARTICIPANT	\N	PRESENT	0
58266	58060	11110B	PARTICIPANT	\N	PRESENT	0
58267	58060	11112D	PARTICIPANT	\N	PRESENT	0
58268	58060	14267Y	PARTICIPANT	\N	PRESENT	0
58269	58060	08014Q	PARTICIPANT	\N	PRESENT	0
58270	58060	12042Y	PARTICIPANT	\N	PRESENT	0
58271	58060	97011G	PARTICIPANT	\N	PRESENT	0
58272	58060	04057K	PARTICIPANT	\N	PRESENT	0
58273	58060	11094U	PARTICIPANT	\N	PRESENT	0
58274	58060	01060R	PARTICIPANT	\N	PRESENT	0
58275	58060	14239U	PARTICIPANT	\N	PRESENT	0
58276	58060	07032N	PARTICIPANT	\N	PRESENT	0
58277	58060	08015R	PARTICIPANT	\N	PRESENT	0
58278	58060	14121F	PARTICIPANT	\N	PRESENT	0
58279	58060	14195A	PARTICIPANT	\N	PRESENT	0
58280	58060	11084S	PARTICIPANT	\N	PRESENT	0
58281	58060	08055A	PARTICIPANT	\N	PRESENT	0
58282	58060	14089Y	PARTICIPANT	\N	PRESENT	0
58283	58060	01022K	PARTICIPANT	\N	PRESENT	0
58284	58060	13002U	PARTICIPANT	\N	PRESENT	0
58285	58060	11093T	PARTICIPANT	\N	PRESENT	0
58286	58060	11082Q	PARTICIPANT	\N	PRESENT	0
58287	58060	14051J	PARTICIPANT	\N	PRESENT	0
58288	58060	14217N	PARTICIPANT	\N	PRESENT	0
58289	58060	14175V	PARTICIPANT	\N	PRESENT	0
58290	58060	98021N	PARTICIPANT	\N	PRESENT	0
58291	58060	90003B	PARTICIPANT	\N	PRESENT	0
58292	58060	11055M	PARTICIPANT	\N	PRESENT	0
58293	58060	14197C	PARTICIPANT	\N	PRESENT	0
58294	58060	08062Y	PARTICIPANT	\N	PRESENT	0
58295	58060	14329V	PARTICIPANT	\N	PRESENT	0
58296	58060	14199E	PARTICIPANT	\N	PRESENT	0
58297	58060	80013X	PARTICIPANT	\N	PRESENT	0
58298	58060	01015L	PARTICIPANT	\N	PRESENT	0
58299	58060	11088W	PARTICIPANT	\N	PRESENT	0
58300	58060	98022P	PARTICIPANT	\N	PRESENT	0
58301	58060	14237S	PARTICIPANT	\N	PRESENT	0
58302	58060	00003C	PARTICIPANT	\N	PRESENT	0
58303	58060	04049K	PARTICIPANT	\N	PRESENT	0
58304	58060	11098Y	PARTICIPANT	\N	PRESENT	0
58305	58060	11104D	PARTICIPANT	\N	PRESENT	0
58306	58060	11105E	PARTICIPANT	\N	PRESENT	0
58307	58060	08068F	PARTICIPANT	\N	PRESENT	0
58308	58060	14269B	PARTICIPANT	\N	PRESENT	0
58309	58060	08021P	PARTICIPANT	\N	PRESENT	0
58310	58060	95041E	PARTICIPANT	\N	PRESENT	0
58311	58060	01007L	PARTICIPANT	\N	PRESENT	0
58312	58060	14069U	PARTICIPANT	\N	PRESENT	0
58313	58060	04048J	PARTICIPANT	\N	PRESENT	0
58314	58060	01008M	PARTICIPANT	\N	PRESENT	0
58315	58060	10006L	PARTICIPANT	\N	PRESENT	0
58316	58060	14081Q	PARTICIPANT	\N	PRESENT	0
58317	58060	95015C	PARTICIPANT	\N	PRESENT	0
58318	58060	07026Q	PARTICIPANT	\N	PRESENT	0
58319	58060	14097Y	PARTICIPANT	\N	PRESENT	0
58320	58060	14085U	PARTICIPANT	\N	PRESENT	0
58321	58060	11053K	PARTICIPANT	\N	PRESENT	0
58322	58060	98035U	PARTICIPANT	\N	PRESENT	0
58323	58060	14001X	PARTICIPANT	\N	PRESENT	0
58324	58060	01037S	PARTICIPANT	\N	PRESENT	0
58325	58060	14123H	PARTICIPANT	\N	PRESENT	0
58326	58060	14257W	PARTICIPANT	\N	PRESENT	0
58327	58060	11106F	PARTICIPANT	\N	PRESENT	0
58328	58060	07024N	PARTICIPANT	\N	PRESENT	0
58329	58060	95059Q	PARTICIPANT	\N	PRESENT	0
58330	58060	89029V	PARTICIPANT	\N	PRESENT	0
58331	57886	86034E	PARTICIPANT	\N	PRESENT	0
58332	57886	14087W	PARTICIPANT	\N	PRESENT	0
58333	57886	14179A	PARTICIPANT	\N	PRESENT	0
58334	57886	11035H	PARTICIPANT	\N	PRESENT	0
58335	57886	11037K	PARTICIPANT	\N	PRESENT	0
58336	57886	95049N	PARTICIPANT	\N	PRESENT	0
58337	57886	80027E	PARTICIPANT	\N	PRESENT	0
58338	57886	14030Q	PARTICIPANT	\N	PRESENT	0
58339	57886	14026U	PARTICIPANT	\N	PRESENT	0
58340	57886	14331P	PARTICIPANT	\N	PRESENT	0
58341	57886	14037X	PARTICIPANT	\N	PRESENT	0
58342	57886	95031C	PARTICIPANT	\N	PRESENT	0
58344	57886	04085P	PARTICIPANT	\N	PRESENT	0
58345	57886	95063L	PARTICIPANT	\N	PRESENT	0
58346	57886	11089X	PARTICIPANT	\N	PRESENT	0
31350	31197	14135M	PARTICIPANT	\N	PRESENT	0
31351	31197	08019V	PARTICIPANT	\N	PRESENT	0
31352	31197	14261S	PARTICIPANT	\N	PRESENT	0
31353	31197	11012A	PARTICIPANT	\N	PRESENT	0
31354	31197	04045F	PARTICIPANT	\N	PRESENT	0
31355	31197	95041E	PARTICIPANT	\N	PRESENT	0
31356	31197	14267Y	PARTICIPANT	\N	PRESENT	0
31357	31197	14042U	PARTICIPANT	\N	PRESENT	0
31358	31197	14231L	PARTICIPANT	\N	PRESENT	0
31359	31197	11067R	PARTICIPANT	\N	PRESENT	0
31360	31197	14271U	PARTICIPANT	\N	PRESENT	0
31361	31197	14053L	PARTICIPANT	\N	PRESENT	0
31362	31197	11061K	PARTICIPANT	\N	PRESENT	0
31363	31197	92045V	PARTICIPANT	\N	PRESENT	0
31364	31197	14034U	PARTICIPANT	\N	PRESENT	0
31365	31197	11044J	PARTICIPANT	\N	PRESENT	0
31366	31197	04067M	PARTICIPANT	\N	PRESENT	0
31367	31197	14121F	PARTICIPANT	\N	PRESENT	0
31368	31197	11112D	PARTICIPANT	\N	PRESENT	0
31369	31197	14275Y	PARTICIPANT	\N	PRESENT	0
31370	31197	14119M	PARTICIPANT	\N	PRESENT	0
31372	31197	14069U	PARTICIPANT	\N	PRESENT	0
31373	31197	14281W	PARTICIPANT	\N	PRESENT	0
31374	31197	11100Y	PARTICIPANT	\N	PRESENT	0
34323	33347	14037X	PARTICIPANT	\N	PRESENT	0
34324	33347	14039A	PARTICIPANT	\N	PRESENT	0
34325	33347	14269B	PARTICIPANT	\N	PRESENT	0
34326	33347	98021N	PARTICIPANT	\N	PRESENT	0
34327	33347	11107G	PARTICIPANT	\N	PRESENT	0
34328	33347	14193X	PARTICIPANT	\N	PRESENT	0
34329	33347	12042Y	PARTICIPANT	\N	PRESENT	0
34330	33347	14059S	PARTICIPANT	\N	PRESENT	0
34331	33347	14187A	PARTICIPANT	\N	PRESENT	0
34332	33347	11114F	PARTICIPANT	\N	PRESENT	0
34333	33347	11113E	PARTICIPANT	\N	PRESENT	0
34334	33347	08022Q	PARTICIPANT	\N	PRESENT	0
34335	33347	11109J	PARTICIPANT	\N	PRESENT	0
34336	33347	04071H	PARTICIPANT	\N	PRESENT	0
34337	33347	11023D	PARTICIPANT	\N	PRESENT	0
34338	33347	11037K	PARTICIPANT	\N	PRESENT	0
34339	33347	95035G	PARTICIPANT	\N	PRESENT	0
34340	33347	04049K	PARTICIPANT	\N	PRESENT	0
34341	33347	11033F	PARTICIPANT	\N	PRESENT	0
34342	33347	14038Y	PARTICIPANT	\N	PRESENT	0
34343	33347	11056N	PARTICIPANT	\N	PRESENT	0
34344	33347	11029K	PARTICIPANT	\N	PRESENT	0
34345	33347	01044R	PARTICIPANT	\N	PRESENT	0
34346	33347	11069T	PARTICIPANT	\N	PRESENT	0
34347	33347	11076S	PARTICIPANT	\N	PRESENT	0
34348	33347	11099A	PARTICIPANT	\N	PRESENT	0
34349	33347	14017T	PARTICIPANT	\N	PRESENT	0
34350	33347	04067M	PARTICIPANT	\N	PRESENT	0
34351	33347	11083R	PARTICIPANT	\N	PRESENT	0
34352	33347	01014K	PARTICIPANT	\N	PRESENT	0
34353	33347	14119M	PARTICIPANT	\N	PRESENT	0
34354	33347	01046T	PARTICIPANT	\N	PRESENT	0
34355	33347	88008L	PARTICIPANT	\N	PRESENT	0
34356	33347	04078Q	PARTICIPANT	\N	PRESENT	0
34357	33347	11012A	PARTICIPANT	\N	PRESENT	0
34358	33347	08049C	PARTICIPANT	\N	PRESENT	0
34359	33347	14018U	PARTICIPANT	\N	PRESENT	0
34360	33347	04038G	PARTICIPANT	\N	PRESENT	0
34361	33347	08062Y	PARTICIPANT	\N	PRESENT	0
34362	33347	11081P	PARTICIPANT	\N	PRESENT	0
34363	33347	11027H	PARTICIPANT	\N	PRESENT	0
34364	33347	08039A	PARTICIPANT	\N	PRESENT	0
34365	33347	14261S	PARTICIPANT	\N	PRESENT	0
34366	33347	14201E	PARTICIPANT	\N	PRESENT	0
34367	33347	98022P	PARTICIPANT	\N	PRESENT	0
34368	33347	14239U	PARTICIPANT	\N	PRESENT	0
34369	33347	14241N	PARTICIPANT	\N	PRESENT	0
34370	33347	08021P	PARTICIPANT	\N	PRESENT	0
34371	33347	14257W	PARTICIPANT	\N	PRESENT	0
34372	33347	14069U	PARTICIPANT	\N	PRESENT	0
34373	33347	14055N	PARTICIPANT	\N	PRESENT	0
34374	33347	14247U	PARTICIPANT	\N	PRESENT	0
34375	33347	04040A	PARTICIPANT	\N	PRESENT	0
34376	33347	01025N	PARTICIPANT	\N	PRESENT	0
34377	33347	08056B	PARTICIPANT	\N	PRESENT	0
34378	33347	01047U	PARTICIPANT	\N	PRESENT	0
34379	33347	14083S	PARTICIPANT	\N	PRESENT	0
34380	33347	08044W	PARTICIPANT	\N	PRESENT	0
34381	33347	07004J	PARTICIPANT	\N	PRESENT	0
34382	33347	11070L	PARTICIPANT	\N	PRESENT	0
34383	33347	92018S	PARTICIPANT	\N	PRESENT	0
34384	33347	02002K	PARTICIPANT	\N	PRESENT	0
34385	33347	04089T	PARTICIPANT	\N	PRESENT	0
34386	33347	14231L	PARTICIPANT	\N	PRESENT	0
34387	33347	11082Q	PARTICIPANT	\N	PRESENT	0
34388	33347	92031P	PARTICIPANT	\N	PRESENT	0
34389	33347	11111C	PARTICIPANT	\N	PRESENT	0
34390	33347	14277B	PARTICIPANT	\N	PRESENT	0
34391	33347	83047W	PARTICIPANT	\N	PRESENT	0
34392	33347	08017T	PARTICIPANT	\N	PRESENT	0
34393	33347	14089Y	PARTICIPANT	\N	PRESENT	0
34394	33347	11053K	PARTICIPANT	\N	PRESENT	0
34395	33347	04080J	PARTICIPANT	\N	PRESENT	0
34396	33347	14034U	PARTICIPANT	\N	PRESENT	0
34397	33347	14253S	PARTICIPANT	\N	PRESENT	0
34398	33347	11064N	PARTICIPANT	\N	PRESENT	0
34399	33347	08009T	PARTICIPANT	\N	PRESENT	0
34400	33347	01048V	PARTICIPANT	\N	PRESENT	0
34401	33347	14205J	PARTICIPANT	\N	PRESENT	0
34402	33347	14219Q	PARTICIPANT	\N	PRESENT	0
34403	33347	14103D	PARTICIPANT	\N	PRESENT	0
34404	33347	14030Q	PARTICIPANT	\N	PRESENT	0
34405	33347	14157T	PARTICIPANT	\N	PRESENT	0
34406	33347	14221J	PARTICIPANT	\N	PRESENT	0
34407	33347	00003C	PARTICIPANT	\N	PRESENT	0
34408	33347	14014Q	PARTICIPANT	\N	PRESENT	0
34409	33347	08073C	PARTICIPANT	\N	PRESENT	0
34410	33347	11035H	PARTICIPANT	\N	PRESENT	0
34411	33347	14169X	PARTICIPANT	\N	PRESENT	0
34412	33347	14263U	PARTICIPANT	\N	PRESENT	0
34413	33347	04054G	PARTICIPANT	\N	PRESENT	0
34414	33347	11080N	PARTICIPANT	\N	PRESENT	0
34415	33347	08035V	PARTICIPANT	\N	PRESENT	0
34416	33347	14013P	PARTICIPANT	\N	PRESENT	0
34417	33347	04061F	PARTICIPANT	\N	PRESENT	0
34418	33347	14249W	PARTICIPANT	\N	PRESENT	0
34419	33347	05012A	PARTICIPANT	\N	PRESENT	0
34420	33347	98042T	PARTICIPANT	\N	PRESENT	0
34421	33347	01008M	PARTICIPANT	\N	PRESENT	0
34422	33347	11039M	PARTICIPANT	\N	PRESENT	0
34423	33347	01028R	PARTICIPANT	\N	PRESENT	0
34424	33347	90003B	PARTICIPANT	\N	PRESENT	0
34425	33347	11110B	PARTICIPANT	\N	PRESENT	0
34426	33347	11085T	PARTICIPANT	\N	PRESENT	0
34427	33347	01041N	PARTICIPANT	\N	PRESENT	0
34428	33347	14041T	PARTICIPANT	\N	PRESENT	0
34429	33347	14175V	PARTICIPANT	\N	PRESENT	0
34430	33347	14087W	PARTICIPANT	\N	PRESENT	0
34431	33347	01027Q	PARTICIPANT	\N	PRESENT	0
34432	33347	11065P	PARTICIPANT	\N	PRESENT	0
34433	33347	98018T	PARTICIPANT	\N	PRESENT	0
34434	33347	95063L	PARTICIPANT	\N	PRESENT	0
34435	33347	95067Q	PARTICIPANT	\N	PRESENT	0
34436	33347	05004A	PARTICIPANT	\N	PRESENT	0
34437	33347	14097Y	PARTICIPANT	\N	PRESENT	0
34438	33347	08031R	PARTICIPANT	\N	PRESENT	0
34439	33347	14065Q	PARTICIPANT	\N	PRESENT	0
34440	33347	14327T	PARTICIPANT	\N	PRESENT	0
34441	33347	08038Y	PARTICIPANT	\N	PRESENT	0
34442	33347	14179A	PARTICIPANT	\N	PRESENT	0
34443	33347	11074Q	PARTICIPANT	\N	PRESENT	0
34444	33347	86034E	PARTICIPANT	\N	PRESENT	0
34445	33347	11106F	PARTICIPANT	\N	PRESENT	0
34446	33347	08051V	PARTICIPANT	\N	PRESENT	0
34447	33347	07034Q	PARTICIPANT	\N	PRESENT	0
34448	33347	01011G	PARTICIPANT	\N	PRESENT	0
34449	33347	11057P	PARTICIPANT	\N	PRESENT	0
34450	33347	11090Q	PARTICIPANT	\N	PRESENT	0
34451	33347	04035D	PARTICIPANT	\N	PRESENT	0
34452	33347	08010L	PARTICIPANT	\N	PRESENT	0
34453	33347	11066Q	PARTICIPANT	\N	PRESENT	0
34454	33347	01024M	PARTICIPANT	\N	PRESENT	0
34455	33347	14111D	PARTICIPANT	\N	PRESENT	0
34456	33347	14159V	PARTICIPANT	\N	PRESENT	0
34457	33347	89017R	PARTICIPANT	\N	PRESENT	0
34458	33347	14255U	PARTICIPANT	\N	PRESENT	0
34459	33347	92044U	PARTICIPANT	\N	PRESENT	0
34460	33347	92015P	PARTICIPANT	\N	PRESENT	0
34461	33347	01016M	PARTICIPANT	\N	PRESENT	0
34462	33347	05008E	PARTICIPANT	\N	PRESENT	0
34463	33347	92039X	PARTICIPANT	\N	PRESENT	0
34464	33347	01003G	PARTICIPANT	\N	PRESENT	0
47684	47661	04066L	PARTICIPANT	\N	PRESENT	0
47685	47661	01013J	PARTICIPANT	\N	PRESENT	0
47686	47661	01031L	PARTICIPANT	\N	PRESENT	0
47687	47661	08011M	PARTICIPANT	\N	PRESENT	0
47688	47661	80013X	PARTICIPANT	\N	PRESENT	0
47689	47661	14063N	PARTICIPANT	\N	PRESENT	0
47690	47661	08043V	PARTICIPANT	\N	PRESENT	0
47691	47661	11042G	PARTICIPANT	\N	PRESENT	0
47692	47661	04034C	PARTICIPANT	\N	PRESENT	0
47693	47661	98046X	PARTICIPANT	\N	PRESENT	0
47694	47661	08012N	PARTICIPANT	\N	PRESENT	0
47695	47661	11083R	PARTICIPANT	\N	PRESENT	0
47696	47661	11012A	PARTICIPANT	\N	PRESENT	0
47697	47661	11053K	PARTICIPANT	\N	PRESENT	0
47698	47661	11099A	PARTICIPANT	\N	PRESENT	0
47699	47661	09001P	PARTICIPANT	\N	PRESENT	0
47700	47661	07029T	PARTICIPANT	\N	PRESENT	0
47701	47661	14175V	PARTICIPANT	\N	PRESENT	0
47702	47661	01057W	PARTICIPANT	\N	PRESENT	0
47703	47661	98053W	PARTICIPANT	\N	PRESENT	0
47704	47661	01048V	PARTICIPANT	\N	PRESENT	0
47705	47661	04086Q	PARTICIPANT	\N	PRESENT	0
47706	47661	11088W	PARTICIPANT	\N	PRESENT	0
47707	47661	11048N	PARTICIPANT	\N	PRESENT	0
47708	47661	14237S	PARTICIPANT	\N	PRESENT	0
47709	47661	11070L	PARTICIPANT	\N	PRESENT	0
47710	47661	08034U	PARTICIPANT	\N	PRESENT	0
47711	47661	01016M	PARTICIPANT	\N	PRESENT	0
47712	47661	01041N	PARTICIPANT	\N	PRESENT	0
47713	47661	14269B	PARTICIPANT	\N	PRESENT	0
47714	47661	08016S	PARTICIPANT	\N	PRESENT	0
47715	47661	14271U	PARTICIPANT	\N	PRESENT	0
47716	47661	99004R	PARTICIPANT	\N	PRESENT	0
47717	47661	04053F	PARTICIPANT	\N	PRESENT	0
47718	47661	11100Y	PARTICIPANT	\N	PRESENT	0
47719	47661	11107G	PARTICIPANT	\N	PRESENT	0
47720	47661	14191V	PARTICIPANT	\N	PRESENT	0
47721	47661	14109K	PARTICIPANT	\N	PRESENT	0
47722	47661	11065P	PARTICIPANT	\N	PRESENT	0
47723	47661	04071H	PARTICIPANT	\N	PRESENT	0
47724	47661	11089X	PARTICIPANT	\N	PRESENT	0
47725	47661	14119M	PARTICIPANT	\N	PRESENT	0
47746	47662	04066L	PARTICIPANT	\N	PRESENT	0
47747	47662	14063N	PARTICIPANT	\N	PRESENT	0
47748	47662	01013J	PARTICIPANT	\N	PRESENT	0
47749	47662	08011M	PARTICIPANT	\N	PRESENT	0
47750	47662	01031L	PARTICIPANT	\N	PRESENT	0
47751	47662	04034C	PARTICIPANT	\N	PRESENT	0
47752	47662	11083R	PARTICIPANT	\N	PRESENT	0
47753	47662	11053K	PARTICIPANT	\N	PRESENT	0
47754	47662	08043V	PARTICIPANT	\N	PRESENT	0
47755	47662	07029T	PARTICIPANT	\N	PRESENT	0
47756	47662	14175V	PARTICIPANT	\N	PRESENT	0
47757	47662	04086Q	PARTICIPANT	\N	PRESENT	0
59791	58246	14121F	PARTICIPANT	\N	PRESENT	0
59792	58246	01028R	PARTICIPANT	\N	PRESENT	0
59793	58246	08019V	PARTICIPANT	\N	PRESENT	0
59794	58246	14249W	PARTICIPANT	\N	PRESENT	0
59795	58246	08017T	PARTICIPANT	\N	PRESENT	0
59796	58246	07032N	PARTICIPANT	\N	PRESENT	0
59798	59797	14239U	PARTICIPANT	\N	PRESENT	0
59799	59797	14217N	PARTICIPANT	\N	PRESENT	0
59800	59797	07004J	PARTICIPANT	\N	PRESENT	0
59801	59797	14281W	PRESIDENT	0	PRESENT	0
59802	59797	11049P	PARTICIPANT	\N	PRESENT	0
59803	59797	14123H	PARTICIPANT	\N	PRESENT	0
59804	59797	11082Q	PARTICIPANT	\N	PRESENT	0
59805	59797	14247U	PARTICIPANT	\N	PRESENT	0
59806	59797	14269B	PARTICIPANT	\N	PRESENT	0
59807	58246	14273W	PARTICIPANT	\N	PRESENT	0
59808	58246	14157T	PARTICIPANT	\N	PRESENT	0
59809	58247	08055A	PARTICIPANT	\N	PRESENT	0
59810	58247	11101A	PARTICIPANT	\N	PRESENT	0
59811	58247	14105F	PARTICIPANT	\N	PRESENT	0
59812	58247	80013X	PARTICIPANT	\N	PRESENT	0
59899	58247	11037K	PARTICIPANT	\N	PRESENT	0
59814	58247	01015L	PARTICIPANT	\N	PRESENT	0
59915	58247	01008M	PARTICIPANT	\N	PRESENT	0
59916	58247	14059S	PARTICIPANT	\N	PRESENT	0
59897	58247	08068F	PARTICIPANT	\N	PRESENT	0
59917	58247	08034U	PARTICIPANT	\N	PRESENT	0
59919	58247	14085U	PARTICIPANT	\N	PRESENT	0
59902	58247	95049N	PARTICIPANT	\N	PRESENT	0
59896	58247	11034G	PARTICIPANT	\N	PRESENT	0
59918	58247	08060W	PARTICIPANT	\N	PRESENT	0
59900	58247	01003G	PARTICIPANT	\N	PRESENT	0
59901	58247	04038G	PARTICIPANT	\N	PRESENT	0
59825	58247	14038Y	PARTICIPANT	\N	PRESENT	0
59920	58247	11046L	PARTICIPANT	\N	PRESENT	0
59913	58247	14179A	PARTICIPANT	\N	PRESENT	0
59903	58247	08044W	PARTICIPANT	\N	PRESENT	0
59898	58247	11065P	PARTICIPANT	\N	PRESENT	0
59904	58247	14237S	PARTICIPANT	\N	PRESENT	0
59921	58247	11112D	PARTICIPANT	\N	PRESENT	0
59832	58247	14265W	PARTICIPANT	\N	PRESENT	0
59833	58247	14215L	PARTICIPANT	\N	PRESENT	0
59905	58247	14079W	PARTICIPANT	\N	PRESENT	0
59922	58247	14030Q	PARTICIPANT	\N	PRESENT	0
59910	59797	98029W	PARTICIPANT	\N	PRESENT	0
59837	58247	07026Q	PARTICIPANT	\N	PRESENT	0
59923	58247	04088S	PARTICIPANT	\N	PRESENT	0
59839	58247	14073Q	PARTICIPANT	\N	PRESENT	0
59924	59797	14133K	PARTICIPANT	\N	PRESENT	0
59906	59797	14089Y	PARTICIPANT	\N	PRESENT	0
59926	58247	08015R	PARTICIPANT	\N	PRESENT	0
59925	58247	01031L	PARTICIPANT	\N	PRESENT	0
59911	58247	05008E	PARTICIPANT	\N	PRESENT	0
59907	59797	92020L	PARTICIPANT	\N	PRESENT	0
59846	58247	11107G	PARTICIPANT	\N	PRESENT	0
59912	58247	08014Q	PARTICIPANT	\N	PRESENT	0
59895	58247	11098Y	PARTICIPANT	\N	PRESENT	0
59849	58247	11036J	PARTICIPANT	\N	PRESENT	0
59850	58247	11091R	PARTICIPANT	\N	PRESENT	0
59927	58247	14257W	PARTICIPANT	\N	PRESENT	0
59928	58247	11039M	PARTICIPANT	\N	PRESENT	0
59914	58247	14069U	PARTICIPANT	\N	PRESENT	0
59854	58247	11011M	PARTICIPANT	\N	PRESENT	0
59908	59797	08053X	PARTICIPANT	\N	PRESENT	0
59909	58247	01057W	PARTICIPANT	\N	PRESENT	0
59929	58247	14053L	PARTICIPANT	\N	PRESENT	0
59930	58247	01007L	PARTICIPANT	\N	PRESENT	0
59859	58247	14213J	PARTICIPANT	\N	PRESENT	0
59931	58247	12042Y	PARTICIPANT	\N	PRESENT	0
59932	58247	14193X	PARTICIPANT	\N	PRESENT	0
59933	58247	14219Q	PARTICIPANT	\N	PRESENT	0
59863	58247	11110B	PARTICIPANT	\N	PRESENT	0
59864	58247	14103D	PARTICIPANT	\N	PRESENT	0
59934	58247	11105E	PARTICIPANT	\N	PRESENT	0
59866	58247	08010L	PARTICIPANT	\N	PRESENT	0
59867	58247	14241N	PARTICIPANT	\N	PRESENT	0
59994	58247	14205J	PARTICIPANT	\N	PRESENT	0
60033	58247	01043Q	PARTICIPANT	\N	PRESENT	0
60035	58247	14042U	PARTICIPANT	\N	PRESENT	0
60041	58247	04085P	PARTICIPANT	\N	PRESENT	0
59872	58247	11061K	PARTICIPANT	\N	PRESENT	0
60042	58247	14267Y	PARTICIPANT	\N	PRESENT	0
59874	58247	14121F	PARTICIPANT	\N	PRESENT	0
59875	58247	01028R	PARTICIPANT	\N	PRESENT	0
59876	58247	08019V	PARTICIPANT	\N	PRESENT	0
59877	58247	14249W	PARTICIPANT	\N	PRESENT	0
60043	58247	14083S	PARTICIPANT	\N	PRESENT	0
60044	58247	14273W	PARTICIPANT	\N	PRESENT	0
60045	58247	08016S	PARTICIPANT	\N	PRESENT	0
59881	58247	14157T	PARTICIPANT	\N	PRESENT	0
59884	59797	99004R	PARTICIPANT	\N	PRESENT	0
59885	59797	14041T	PARTICIPANT	\N	PRESENT	0
59886	59797	04061F	PARTICIPANT	\N	PRESENT	0
59887	59797	10015M	PARTICIPANT	\N	PRESENT	0
59888	59797	11054L	PARTICIPANT	\N	EXCUSE	0
59894	58247	14147R	PARTICIPANT	\N	PRESENT	0
60046	58247	08009T	PARTICIPANT	\N	PRESENT	0
60047	58247	08048B	PARTICIPANT	\N	PRESENT	0
60048	58247	14159V	PARTICIPANT	\N	PRESENT	0
60049	58247	14253S	PARTICIPANT	\N	PRESENT	0
60050	59550	90003B	PARTICIPANT	\N	EXCUSE	0
60051	58247	14263U	PARTICIPANT	\N	PRESENT	0
60052	59410	90003B	PARTICIPANT	\N	EXCUSE	0
60053	58247	92045V	PARTICIPANT	\N	PRESENT	0
60054	58247	01027Q	PARTICIPANT	\N	PRESENT	0
60056	60055	14030Q	PARTICIPANT	\N	PRESENT	0
60057	60055	14053L	PARTICIPANT	\N	PRESENT	0
60058	60055	11023D	PARTICIPANT	\N	PRESENT	0
60059	60055	11035H	PARTICIPANT	\N	PRESENT	0
60060	60055	01022K	PARTICIPANT	\N	PRESENT	0
60061	60055	11098Y	PARTICIPANT	\N	PRESENT	0
60062	60055	14331P	PARTICIPANT	\N	PRESENT	0
60063	60055	14157T	PARTICIPANT	\N	PRESENT	0
37429	37373	86034E	PARTICIPANT	\N	PRESENT	0
37432	37373	14051J	PARTICIPANT	\N	PRESENT	0
37433	37373	14109K	PARTICIPANT	\N	PRESENT	0
37434	37373	14275Y	PARTICIPANT	\N	PRESENT	0
37435	37373	11069T	PARTICIPANT	\N	PRESENT	0
37436	37373	04067M	PARTICIPANT	\N	PRESENT	0
37437	37373	14273W	PARTICIPANT	\N	PRESENT	0
37438	37373	11109J	PARTICIPANT	\N	PRESENT	0
37439	37373	11037K	PARTICIPANT	\N	PRESENT	0
37440	37373	14018U	PARTICIPANT	\N	PRESENT	0
37441	37373	11113E	PARTICIPANT	\N	PRESENT	0
37442	37373	14225N	PARTICIPANT	\N	PRESENT	0
37443	37373	14159V	PARTICIPANT	\N	PRESENT	0
37444	37373	14215L	PARTICIPANT	\N	PRESENT	0
37445	37373	01056V	PARTICIPANT	\N	PRESENT	0
37446	37373	08052W	PARTICIPANT	\N	PRESENT	0
37447	37373	11107G	PARTICIPANT	\N	PRESENT	0
37448	37373	11110B	PARTICIPANT	\N	PRESENT	0
37449	37373	11089X	PARTICIPANT	\N	PRESENT	0
37450	37373	04034C	PARTICIPANT	\N	PRESENT	0
37451	37373	14107H	PARTICIPANT	\N	PRESENT	0
37452	37373	01037S	PARTICIPANT	\N	PRESENT	0
37453	37373	95035G	PARTICIPANT	\N	PRESENT	0
37454	37373	14073Q	PARTICIPANT	\N	PRESENT	0
37455	37373	11031D	PARTICIPANT	\N	PRESENT	0
37456	37373	07026Q	PARTICIPANT	\N	PRESENT	0
37457	37373	11046L	PARTICIPANT	\N	PRESENT	0
37458	37373	08053X	PARTICIPANT	\N	PRESENT	0
37459	37373	11036J	PARTICIPANT	\N	PRESENT	0
37460	37373	14271U	PARTICIPANT	\N	PRESENT	0
37461	37373	12042Y	PARTICIPANT	\N	PRESENT	0
37462	37373	08068F	PARTICIPANT	\N	PRESENT	0
37463	37373	11040E	PARTICIPANT	\N	PRESENT	0
37464	37373	04085P	PARTICIPANT	\N	PRESENT	0
37465	37373	11034G	PARTICIPANT	\N	PRESENT	0
37466	37373	11063M	PARTICIPANT	\N	PRESENT	0
37467	37373	11076S	PARTICIPANT	\N	PRESENT	0
37468	37373	11055M	PARTICIPANT	\N	PRESENT	0
37469	37373	11029K	PARTICIPANT	\N	PRESENT	0
37470	37373	14247U	PARTICIPANT	\N	PRESENT	0
37471	37373	14055N	PARTICIPANT	\N	PRESENT	0
37472	37373	11083R	PARTICIPANT	\N	PRESENT	0
37473	37373	01016M	PARTICIPANT	\N	PRESENT	0
37474	37373	08016S	PARTICIPANT	\N	PRESENT	0
37475	37373	04056J	PARTICIPANT	\N	PRESENT	0
37476	37373	98046X	PARTICIPANT	\N	PRESENT	0
37477	37373	11059R	PARTICIPANT	\N	PRESENT	0
37478	37373	04066L	PARTICIPANT	\N	PRESENT	0
37479	37373	08060W	PARTICIPANT	\N	PRESENT	0
37480	37373	00003C	PARTICIPANT	\N	PRESENT	0
37481	37373	14281W	PARTICIPANT	\N	PRESENT	0
37482	37373	92018S	PARTICIPANT	\N	PRESENT	0
37483	37373	01031L	PARTICIPANT	\N	PRESENT	0
37484	37373	14207L	PARTICIPANT	\N	PRESENT	0
37485	37373	14257W	PARTICIPANT	\N	PRESENT	0
37486	37373	11061K	PARTICIPANT	\N	PRESENT	0
37487	37373	04077P	PARTICIPANT	\N	PRESENT	0
37488	37373	04059M	PARTICIPANT	\N	PRESENT	0
37489	37373	04053F	PARTICIPANT	\N	PRESENT	0
37490	37373	01028R	PARTICIPANT	\N	PRESENT	0
37491	37373	11035H	PARTICIPANT	\N	PRESENT	0
37492	37373	11042G	PARTICIPANT	\N	PRESENT	0
37493	37373	14081Q	PARTICIPANT	\N	PRESENT	0
37494	37373	08073C	PARTICIPANT	\N	PRESENT	0
37495	37373	14269B	PARTICIPANT	\N	PRESENT	0
37496	37373	08011M	PARTICIPANT	\N	PRESENT	0
37497	37373	11023D	PARTICIPANT	\N	PRESENT	0
37498	37373	11033F	PARTICIPANT	\N	PRESENT	0
37499	37373	12041X	PARTICIPANT	\N	PRESENT	0
37500	37373	11060J	PARTICIPANT	\N	PRESENT	0
37501	37373	11012A	PARTICIPANT	\N	PRESENT	0
37502	37373	04078Q	PARTICIPANT	\N	PRESENT	0
37503	37373	14261S	PARTICIPANT	\N	PRESENT	0
37504	37373	08049C	PARTICIPANT	\N	PRESENT	0
37505	37373	96004D	PARTICIPANT	\N	PRESENT	0
37506	37373	95049N	PARTICIPANT	\N	PRESENT	0
37507	37373	07004J	PARTICIPANT	\N	PRESENT	0
37508	37373	14205J	PARTICIPANT	\N	PRESENT	0
37509	37373	11070L	PARTICIPANT	\N	PRESENT	0
37510	37373	09001P	PARTICIPANT	\N	PRESENT	0
37511	37373	08044W	PARTICIPANT	\N	PRESENT	0
37512	37373	14133K	PARTICIPANT	\N	PRESENT	0
37513	37373	14267Y	PARTICIPANT	\N	PRESENT	0
37514	37373	11064N	PARTICIPANT	\N	PRESENT	0
37515	37373	01007L	PARTICIPANT	\N	PRESENT	0
37516	37373	14327T	PARTICIPANT	\N	PRESENT	0
37517	37373	11065P	PARTICIPANT	\N	PRESENT	0
37518	37373	01043Q	PARTICIPANT	\N	PRESENT	0
37519	37373	05004A	PARTICIPANT	\N	PRESENT	0
37520	37373	05008E	PARTICIPANT	\N	PRESENT	0
37521	37373	11077T	PARTICIPANT	\N	PRESENT	0
37522	37373	14119M	PARTICIPANT	\N	PRESENT	0
37523	37373	04055H	PARTICIPANT	\N	PRESENT	0
37524	37373	95030B	PARTICIPANT	\N	PRESENT	0
37525	37373	77002U	PARTICIPANT	\N	PRESENT	0
37526	37373	04047H	PARTICIPANT	\N	PRESENT	0
37527	37373	99004R	PARTICIPANT	\N	PRESENT	0
37528	37373	95059Q	PARTICIPANT	\N	PRESENT	0
37529	37373	08039A	PARTICIPANT	\N	PRESENT	0
37530	37373	14175V	PARTICIPANT	\N	PRESENT	0
37531	37373	95041E	PARTICIPANT	\N	PRESENT	0
37532	37373	86044G	PARTICIPANT	\N	PRESENT	0
37533	37373	92031P	PARTICIPANT	\N	PRESENT	0
37534	37373	14211G	PARTICIPANT	\N	PRESENT	0
37535	37373	11088W	PARTICIPANT	\N	PRESENT	0
37536	37373	01048V	PARTICIPANT	\N	PRESENT	0
37537	37373	11100Y	PARTICIPANT	\N	PRESENT	0
37538	37373	11048N	PARTICIPANT	\N	PRESENT	0
37539	37373	14041T	PARTICIPANT	\N	PRESENT	0
37540	37373	95067Q	PARTICIPANT	\N	PRESENT	0
37541	37373	01057W	PARTICIPANT	\N	PRESENT	0
37542	37373	08019V	PARTICIPANT	\N	PRESENT	0
37543	37373	11010L	PARTICIPANT	\N	PRESENT	0
37544	37373	14031R	PARTICIPANT	\N	PRESENT	0
37545	37373	04097T	PARTICIPANT	\N	PRESENT	0
37546	37373	08062Y	PARTICIPANT	\N	PRESENT	0
37547	37373	07032N	PARTICIPANT	\N	PRESENT	0
37548	37373	08034U	PARTICIPANT	\N	PRESENT	0
37549	37373	08017T	PARTICIPANT	\N	PRESENT	0
37550	37373	98023Q	PARTICIPANT	\N	PRESENT	0
37551	37373	14147R	PARTICIPANT	\N	PRESENT	0
37552	37373	04088S	PARTICIPANT	\N	PRESENT	0
37553	37373	95063L	PARTICIPANT	\N	PRESENT	0
37554	37373	14033T	PARTICIPANT	\N	PRESENT	0
37555	37373	07029T	PARTICIPANT	\N	PRESENT	0
37556	37373	14265W	PARTICIPANT	\N	PRESENT	0
37557	37373	14249W	PARTICIPANT	\N	PRESENT	0
37558	37373	04033B	PARTICIPANT	\N	PRESENT	0
37559	37373	04086Q	PARTICIPANT	\N	PRESENT	0
37560	37373	14071N	PARTICIPANT	\N	PRESENT	0
37561	37373	04043D	PARTICIPANT	\N	PRESENT	0
37562	37373	14193X	PARTICIPANT	\N	PRESENT	0
37563	37373	14069U	PARTICIPANT	\N	PRESENT	0
37564	37373	04081K	PARTICIPANT	\N	PRESENT	0
37565	37373	04057K	PARTICIPANT	\N	PRESENT	0
37566	37373	14053L	PARTICIPANT	\N	PRESENT	0
37567	37373	14079W	PARTICIPANT	\N	PRESENT	0
37568	37373	14217N	PARTICIPANT	\N	PRESENT	0
37569	37373	11091R	PARTICIPANT	\N	PRESENT	0
37570	37373	11090Q	PARTICIPANT	\N	PRESENT	0
37571	37373	14259Y	PARTICIPANT	\N	PRESENT	0
37572	37373	14037X	PARTICIPANT	\N	PRESENT	0
37573	37373	04044E	PARTICIPANT	\N	PRESENT	0
37574	37373	98053W	PARTICIPANT	\N	PRESENT	0
37575	37373	01027Q	PARTICIPANT	\N	PRESENT	0
37576	37373	11085T	PARTICIPANT	\N	PRESENT	0
37577	37373	04080J	PARTICIPANT	\N	PRESENT	0
37578	37373	14157T	PARTICIPANT	\N	PRESENT	0
37579	37373	04035D	PARTICIPANT	\N	PRESENT	0
37580	37373	14014Q	PARTICIPANT	\N	PRESENT	0
37581	37373	08058D	PARTICIPANT	\N	PRESENT	0
37589	37373	11084S	PARTICIPANT	\N	PRESENT	0
37590	37373	11080N	PARTICIPANT	\N	PRESENT	0
37591	37373	92045V	PARTICIPANT	\N	PRESENT	0
38268	38042	08024S	PARTICIPANT	\N	PRESENT	0
38269	38042	14041T	PARTICIPANT	\N	PRESENT	0
38270	38042	08069G	PARTICIPANT	\N	PRESENT	0
38271	38042	01013J	PARTICIPANT	\N	PRESENT	0
38272	38042	11040E	PARTICIPANT	\N	PRESENT	0
38273	38042	11103C	PARTICIPANT	\N	PRESENT	0
38274	38042	04034C	PARTICIPANT	\N	PRESENT	0
38275	38042	14223L	PARTICIPANT	\N	PRESENT	0
38276	38042	08062Y	PARTICIPANT	\N	PRESENT	0
38277	38042	11099A	PARTICIPANT	\N	PRESENT	0
38278	38042	11106F	PARTICIPANT	\N	PRESENT	0
38279	38042	14073Q	PARTICIPANT	\N	PRESENT	0
38280	38042	11012A	PARTICIPANT	\N	PRESENT	0
38281	38042	14103D	PARTICIPANT	\N	PRESENT	0
40164	40090	11066Q	PARTICIPANT	\N	PRESENT	0
40165	40090	11098Y	PARTICIPANT	\N	PRESENT	0
40166	40090	11036J	PARTICIPANT	\N	PRESENT	0
40167	40090	14121F	PARTICIPANT	\N	PRESENT	0
40168	40090	11023D	PARTICIPANT	\N	PRESENT	0
40169	40090	11014C	PARTICIPANT	\N	PRESENT	0
40170	40090	92015P	PARTICIPANT	\N	PRESENT	0
40171	40090	88008L	PARTICIPANT	\N	PRESENT	0
40172	40090	14237S	PARTICIPANT	\N	PRESENT	0
40173	40090	04057K	PARTICIPANT	\N	PRESENT	0
40174	40090	11103C	PARTICIPANT	\N	PRESENT	0
40175	40090	11044J	PARTICIPANT	\N	PRESENT	0
40176	40090	04081K	PARTICIPANT	\N	PRESENT	0
40177	40090	11088W	PARTICIPANT	\N	PRESENT	0
40178	40090	08028W	PARTICIPANT	\N	PRESENT	0
40179	40090	14157T	PARTICIPANT	\N	PRESENT	0
40180	40090	01048V	PARTICIPANT	\N	PRESENT	0
40181	40090	04088S	PARTICIPANT	\N	PRESENT	0
40182	40090	08016S	PARTICIPANT	\N	PRESENT	0
40183	40090	14030Q	PARTICIPANT	\N	PRESENT	0
40184	40090	11043H	PARTICIPANT	\N	PRESENT	0
40185	40090	14159V	PARTICIPANT	\N	PRESENT	0
40186	40090	11054L	PARTICIPANT	\N	PRESENT	0
40187	40090	14119M	PARTICIPANT	\N	PRESENT	0
40188	40090	14207L	PARTICIPANT	\N	PRESENT	0
40189	40090	14033T	PARTICIPANT	\N	PRESENT	0
40190	40090	08053X	PARTICIPANT	\N	PRESENT	0
40299	40091	08065C	PARTICIPANT	\N	PRESENT	0
40300	40091	14041T	PARTICIPANT	\N	PRESENT	0
40301	40091	14275Y	PARTICIPANT	\N	PRESENT	0
40302	40091	14277B	PARTICIPANT	\N	PRESENT	0
40310	40091	14059S	PARTICIPANT	\N	PRESENT	0
40304	40091	14221J	PARTICIPANT	\N	PRESENT	0
40305	40091	14219Q	PARTICIPANT	\N	PRESENT	0
40307	40091	07004J	PARTICIPANT	\N	PRESENT	0
40308	40091	14121F	PARTICIPANT	\N	PRESENT	0
40319	40091	14030Q	PARTICIPANT	\N	PRESENT	0
40314	40091	08042U	PARTICIPANT	\N	PRESENT	0
40316	40091	14195A	PARTICIPANT	\N	PRESENT	0
40318	40091	14267Y	PARTICIPANT	\N	PRESENT	0
40321	40091	01046T	PARTICIPANT	\N	PRESENT	0
40322	40091	14073Q	PARTICIPANT	\N	PRESENT	0
40323	40091	04059M	PARTICIPANT	\N	PRESENT	0
40325	40091	80013X	PARTICIPANT	\N	PRESENT	0
40327	40091	04077P	PARTICIPANT	\N	PRESENT	0
40333	40091	08031R	PARTICIPANT	\N	PRESENT	0
40334	40091	14063N	PARTICIPANT	\N	PRESENT	0
40335	40091	11103C	PARTICIPANT	\N	PRESENT	0
40337	40091	08021P	PARTICIPANT	\N	PRESENT	0
40339	40091	04080J	PARTICIPANT	\N	PRESENT	0
40341	40091	07024N	PARTICIPANT	\N	PRESENT	0
40342	40091	11091R	PARTICIPANT	\N	PRESENT	0
40372	40091	11100Y	PARTICIPANT	\N	PRESENT	0
40347	40091	14209N	PARTICIPANT	\N	PRESENT	0
40348	40091	99004R	PARTICIPANT	\N	PRESENT	0
40349	40091	95049N	PARTICIPANT	\N	PRESENT	0
40350	40091	92015P	PARTICIPANT	\N	PRESENT	0
40351	40091	00003C	PARTICIPANT	\N	PRESENT	0
40352	40091	04074L	PARTICIPANT	\N	PRESENT	0
40353	40091	11014C	PARTICIPANT	\N	PRESENT	0
40354	40091	80027E	PARTICIPANT	\N	PRESENT	0
40355	40091	11044J	PARTICIPANT	\N	PRESENT	0
40356	40091	08052W	PARTICIPANT	\N	PRESENT	0
40357	40091	95015C	PARTICIPANT	\N	PRESENT	0
40358	40091	11097X	PARTICIPANT	\N	PRESENT	0
40359	40091	04047H	PARTICIPANT	\N	PRESENT	0
40360	40091	14207L	PARTICIPANT	\N	PRESENT	0
40361	40091	11037K	PARTICIPANT	\N	PRESENT	0
40362	40091	95062K	PARTICIPANT	\N	PRESENT	0
40363	40091	11107G	PARTICIPANT	\N	PRESENT	0
40364	40091	14033T	PARTICIPANT	\N	PRESENT	0
40365	40091	11059R	PARTICIPANT	\N	PRESENT	0
40366	40091	04088S	PARTICIPANT	\N	PRESENT	0
40367	40091	11040E	PARTICIPANT	\N	PRESENT	0
40368	40091	14133K	PARTICIPANT	\N	PRESENT	0
40369	40091	04081K	PARTICIPANT	\N	PRESENT	0
40370	40091	08028W	PARTICIPANT	\N	PRESENT	0
40371	40091	14327T	PARTICIPANT	\N	PRESENT	0
40373	40091	01013J	PARTICIPANT	\N	PRESENT	0
40374	40091	04066L	PARTICIPANT	\N	PRESENT	0
40375	40091	11080N	PARTICIPANT	\N	PRESENT	0
40376	40091	14281W	PARTICIPANT	\N	PRESENT	0
40377	40091	11015D	PARTICIPANT	\N	PRESENT	0
40378	40091	07034Q	PARTICIPANT	\N	PRESENT	0
40379	40091	11066Q	PARTICIPANT	\N	PRESENT	0
40380	40091	92044U	PARTICIPANT	\N	PRESENT	0
40381	40091	14259Y	PARTICIPANT	\N	PRESENT	0
40382	40091	01031L	PARTICIPANT	\N	PRESENT	0
40383	40091	14105F	PARTICIPANT	\N	PRESENT	0
40384	40091	11025F	PARTICIPANT	\N	PRESENT	0
40385	40091	14111D	PARTICIPANT	\N	PRESENT	0
40386	40091	01022K	PARTICIPANT	\N	PRESENT	0
40297	40091	86034E	PARTICIPANT	\N	PRESENT	0
40298	40091	04048J	PARTICIPANT	\N	PRESENT	0
40387	40091	92040Q	PARTICIPANT	\N	PRESENT	0
40388	40091	11054L	PARTICIPANT	\N	PRESENT	0
40389	40091	14187A	PARTICIPANT	\N	PRESENT	0
40390	40091	83047W	PARTICIPANT	\N	PRESENT	0
40391	40091	14215L	PARTICIPANT	\N	PRESENT	0
40392	40091	08043V	PARTICIPANT	\N	PRESENT	0
40393	40091	04097T	PARTICIPANT	\N	PRESENT	0
40394	40091	04045F	PARTICIPANT	\N	PRESENT	0
40395	40091	98024R	PARTICIPANT	\N	PRESENT	0
40396	40091	95037J	PARTICIPANT	\N	PRESENT	0
40397	40091	14193X	PARTICIPANT	\N	PRESENT	0
40398	40091	14037X	PARTICIPANT	\N	PRESENT	0
40399	40091	08012N	PARTICIPANT	\N	PRESENT	0
40400	40091	02002K	PARTICIPANT	\N	PRESENT	0
40401	40091	14253S	PARTICIPANT	\N	PRESENT	0
40402	40091	14031R	PARTICIPANT	\N	PRESENT	0
40403	40091	14199E	PARTICIPANT	\N	PRESENT	0
40404	40091	04057K	PARTICIPANT	\N	PRESENT	0
40405	40091	14079W	PARTICIPANT	\N	PRESENT	0
40406	40091	14217N	PARTICIPANT	\N	PRESENT	0
40407	40091	08034U	PARTICIPANT	\N	PRESENT	0
40408	40091	01027Q	PARTICIPANT	\N	PRESENT	0
40409	40091	04054G	PARTICIPANT	\N	PRESENT	0
40410	40091	08011M	PARTICIPANT	\N	PRESENT	0
40411	40091	14211G	PARTICIPANT	\N	PRESENT	0
40412	40091	11098Y	PARTICIPANT	\N	PRESENT	0
40413	40091	11034G	PARTICIPANT	\N	PRESENT	0
40414	40091	14147R	PARTICIPANT	\N	PRESENT	0
40416	40091	01015L	PARTICIPANT	\N	PRESENT	0
40417	40091	01058X	PARTICIPANT	\N	PRESENT	0
40418	40091	14157T	PARTICIPANT	\N	PRESENT	0
40419	40091	11029K	PARTICIPANT	\N	PRESENT	0
40420	40091	11069T	PARTICIPANT	\N	PRESENT	0
40421	40091	11055M	PARTICIPANT	\N	PRESENT	0
40422	40091	14069U	PARTICIPANT	\N	PRESENT	0
40423	40091	04078Q	PARTICIPANT	\N	PRESENT	0
40424	40091	01057W	PARTICIPANT	\N	PRESENT	0
40425	40091	88008L	PARTICIPANT	\N	PRESENT	0
40426	40091	04038G	PARTICIPANT	\N	PRESENT	0
40427	40091	86044G	PARTICIPANT	\N	PRESENT	0
40428	40091	07026Q	PARTICIPANT	\N	PRESENT	0
40429	40091	07029T	PARTICIPANT	\N	PRESENT	0
40430	40091	04085P	PARTICIPANT	\N	PRESENT	0
40431	40091	08019V	PARTICIPANT	\N	PRESENT	0
40432	40091	14034U	PARTICIPANT	\N	PRESENT	0
40433	40091	04070G	PARTICIPANT	\N	PRESENT	0
40434	40091	09001P	PARTICIPANT	\N	PRESENT	0
40435	40091	04040A	PARTICIPANT	\N	PRESENT	0
40436	40091	14329V	PARTICIPANT	\N	PRESENT	0
40437	40091	14103D	PARTICIPANT	\N	PRESENT	0
40438	40091	14083S	PARTICIPANT	\N	PRESENT	0
40439	40091	14231L	PARTICIPANT	\N	PRESENT	0
40440	40091	89017R	PARTICIPANT	\N	PRESENT	0
40441	40091	11093T	PARTICIPANT	\N	PRESENT	0
40442	40091	11082Q	PARTICIPANT	\N	PRESENT	0
40443	40091	08015R	PARTICIPANT	\N	PRESENT	0
40444	40091	11088W	PARTICIPANT	\N	PRESENT	0
40445	40091	08062Y	PARTICIPANT	\N	PRESENT	0
40446	40091	04086Q	PARTICIPANT	\N	PRESENT	0
40447	40091	11070L	PARTICIPANT	\N	PRESENT	0
40448	40091	11053K	PARTICIPANT	\N	PRESENT	0
40449	40091	14261S	PARTICIPANT	\N	PRESENT	0
40450	40091	14255U	PARTICIPANT	\N	PRESENT	0
40451	40091	11094U	PARTICIPANT	\N	PRESENT	0
40452	40091	77002U	PARTICIPANT	\N	PRESENT	0
40453	40091	98053W	PARTICIPANT	\N	PRESENT	0
40454	40091	14251Q	PARTICIPANT	\N	PRESENT	0
40455	40091	01060R	PARTICIPANT	\N	PRESENT	0
40456	40091	04043D	PARTICIPANT	\N	PRESENT	0
40457	40091	95059Q	PARTICIPANT	\N	PRESENT	0
40458	40091	11033F	PARTICIPANT	\N	PRESENT	0
40459	40091	11030C	PARTICIPANT	\N	PRESENT	0
40460	40091	04042C	PARTICIPANT	\N	PRESENT	0
40461	40091	08016S	PARTICIPANT	\N	PRESENT	0
31725	31683	01007L	PARTICIPANT	\N	PRESENT	0
31786	31683	14213J	PARTICIPANT	\N	PRESENT	0
31787	31683	98018T	PARTICIPANT	\N	PRESENT	0
31788	31683	14273W	PARTICIPANT	\N	PRESENT	0
31789	31683	08019V	PARTICIPANT	\N	PRESENT	0
31790	31683	14041T	PARTICIPANT	\N	PRESENT	0
31791	31683	14037X	PARTICIPANT	\N	PRESENT	0
31792	31683	08041T	PARTICIPANT	\N	PRESENT	0
31793	31683	14033T	PARTICIPANT	\N	PRESENT	0
31794	31683	01041N	PARTICIPANT	\N	PRESENT	0
31795	31683	11093T	PARTICIPANT	\N	PRESENT	0
31796	31683	14231L	PARTICIPANT	\N	PRESENT	0
31797	31683	11063M	PARTICIPANT	\N	PRESENT	0
31798	31683	11031D	PARTICIPANT	\N	PRESENT	0
31799	31683	14265W	PARTICIPANT	\N	PRESENT	0
31800	31683	14227Q	PARTICIPANT	\N	PRESENT	0
31801	31683	14207L	PARTICIPANT	\N	PRESENT	0
31802	31683	11067R	PARTICIPANT	\N	PRESENT	0
31803	31683	08052W	PARTICIPANT	\N	PRESENT	0
31804	31683	01034P	PARTICIPANT	\N	PRESENT	0
31805	31683	04092N	PARTICIPANT	\N	PRESENT	0
31806	31683	04053F	PARTICIPANT	\N	PRESENT	0
31807	31683	14281W	PARTICIPANT	\N	PRESENT	0
31808	31683	14018U	PARTICIPANT	\N	PRESENT	0
31809	31683	14239U	PARTICIPANT	\N	PRESENT	0
31810	31683	12042Y	PARTICIPANT	\N	PRESENT	0
31811	31683	14042U	PARTICIPANT	\N	PRESENT	0
31812	31683	14034U	PARTICIPANT	\N	PRESENT	0
31813	31683	14217N	PARTICIPANT	\N	PRESENT	0
31814	31683	00003C	PARTICIPANT	\N	PRESENT	0
31815	31683	04067M	PARTICIPANT	\N	PRESENT	0
31816	31683	04088S	PARTICIPANT	\N	PRESENT	0
31817	31683	14069U	PARTICIPANT	\N	PRESENT	0
31818	31683	11103C	PARTICIPANT	\N	PRESENT	0
31819	31683	14255U	PARTICIPANT	\N	PRESENT	0
31820	31683	11044J	PARTICIPANT	\N	PRESENT	0
31821	31683	11026G	PARTICIPANT	\N	PRESENT	0
31822	31683	11055M	PARTICIPANT	\N	PRESENT	0
31823	31683	04034C	PARTICIPANT	\N	PRESENT	0
31824	31683	14205J	PARTICIPANT	\N	PRESENT	0
31825	31683	11061K	PARTICIPANT	\N	PRESENT	0
31826	31683	01059Y	PARTICIPANT	\N	PRESENT	0
31827	31683	92045V	PARTICIPANT	\N	PRESENT	0
31828	31683	14147R	PARTICIPANT	\N	PRESENT	0
31829	31683	01046T	PARTICIPANT	\N	PRESENT	0
31830	31683	14187A	PARTICIPANT	\N	PRESENT	0
31831	31683	14201E	PARTICIPANT	\N	PRESENT	0
31832	31683	08017T	PARTICIPANT	\N	PRESENT	0
31833	31683	14257W	PARTICIPANT	\N	PRESENT	0
31834	31683	86044G	PARTICIPANT	\N	PRESENT	0
31835	31683	11012A	PARTICIPANT	\N	PRESENT	0
31836	31683	08051V	PARTICIPANT	\N	PRESENT	0
31837	31683	10006L	PARTICIPANT	\N	PRESENT	0
31838	31683	08056B	PARTICIPANT	\N	PRESENT	0
31839	31683	11112D	PARTICIPANT	\N	PRESENT	0
31840	31683	04085P	PARTICIPANT	\N	PRESENT	0
31841	31683	95035G	PARTICIPANT	\N	PRESENT	0
31842	31683	05008E	PARTICIPANT	\N	PRESENT	0
31843	31683	07034Q	PARTICIPANT	\N	PRESENT	0
31844	31683	11066Q	PARTICIPANT	\N	PRESENT	0
31845	31683	97011G	PARTICIPANT	\N	PRESENT	0
31846	31683	04066L	PARTICIPANT	\N	PRESENT	0
31847	31683	14073Q	PARTICIPANT	\N	PRESENT	0
31848	31683	04081K	PARTICIPANT	\N	PRESENT	0
31877	31683	14223L	PARTICIPANT	\N	PRESENT	0
31878	31849	14205J	PARTICIPANT	\N	PRESENT	0
31879	31849	14265W	PARTICIPANT	\N	PRESENT	0
31880	31849	04088S	PARTICIPANT	\N	PRESENT	0
31886	31849	09001P	PARTICIPANT	\N	PRESENT	0
31882	31683	08053X	PARTICIPANT	\N	PRESENT	0
31883	31849	92045V	PARTICIPANT	\N	PRESENT	0
31884	31849	08042U	PARTICIPANT	\N	PRESENT	0
31885	31849	01007L	PARTICIPANT	\N	PRESENT	0
31887	31683	04057K	PARTICIPANT	\N	PRESENT	0
31889	31888	08043V	PARTICIPANT	\N	EXCUSE	0
31890	31888	08060W	PARTICIPANT	\N	EXCUSE	0
31891	31888	11029K	PARTICIPANT	\N	EXCUSE	0
31892	31888	11027H	PRESIDENT	1	PRESENT	0
31893	31888	80013X	PARTICIPANT	\N	PRESENT	0
31894	31888	14014Q	PARTICIPANT	\N	EXCUSE	0
31895	31888	07026Q	PARTICIPANT	\N	EXCUSE	0
31896	31888	95035G	PARTICIPANT	\N	EXCUSE	0
31897	31888	04036E	PRESIDENT	0	PRESENT	0
31898	31888	08031R	PARTICIPANT	\N	EXCUSE	0
31899	31888	14059S	PARTICIPANT	\N	EXCUSE	0
31900	31683	80013X	PARTICIPANT	\N	PRESENT	0
31902	31901	89017R	PARTICIPANT	\N	PRESENT	0
31903	31901	01031L	PRESIDENT	0	PRESENT	0
31904	31901	01013J	PARTICIPANT	\N	PRESENT	0
31875	31849	14249W	PARTICIPANT	\N	PRESENT	0
31876	31849	11112D	PARTICIPANT	\N	PRESENT	0
31905	31901	11040E	PARTICIPANT	\N	PRESENT	0
31906	31901	08014Q	PARTICIPANT	\N	PRESENT	0
31907	31901	14167V	PARTICIPANT	\N	PRESENT	0
31908	31901	14175V	PARTICIPANT	\N	PRESENT	0
31909	31901	14083S	PARTICIPANT	\N	PRESENT	0
31910	31901	11053K	PARTICIPANT	\N	PRESENT	0
31911	31901	14085U	PARTICIPANT	\N	EXCUSE	0
31912	31901	11042G	PARTICIPANT	\N	PRESENT	0
31913	31901	88008L	PARTICIPANT	\N	PRESENT	0
31914	31901	04086Q	PARTICIPANT	\N	PRESENT	0
31915	31901	11070L	PARTICIPANT	\N	PRESENT	0
31916	31901	11088W	PARTICIPANT	\N	PRESENT	0
31917	31901	14327T	PARTICIPANT	\N	PRESENT	0
31918	31901	08022Q	PARTICIPANT	\N	PRESENT	0
31919	31901	01027Q	PARTICIPANT	\N	PRESENT	0
31920	31901	04071H	PARTICIPANT	\N	PRESENT	0
31921	31901	11074Q	PARTICIPANT	\N	PRESENT	0
31922	31901	11083R	PARTICIPANT	\N	PRESENT	0
31923	31901	14199E	PARTICIPANT	\N	PRESENT	0
31924	31901	01057W	PARTICIPANT	\N	PRESENT	0
31925	31901	08016S	PARTICIPANT	\N	PRESENT	0
31926	31901	08069G	PARTICIPANT	\N	PRESENT	0
31927	31901	11048N	PARTICIPANT	\N	PRESENT	0
31928	31901	99004R	PARTICIPANT	\N	PRESENT	0
31929	31901	04061F	PARTICIPANT	\N	PRESENT	0
31930	31901	14159V	PARTICIPANT	\N	PRESENT	0
31934	31901	08034U	PARTICIPANT	\N	PRESENT	0
31932	31901	07029T	PARTICIPANT	\N	PRESENT	0
31933	31901	08010L	PARTICIPANT	\N	PRESENT	0
31935	31901	01048V	PARTICIPANT	\N	PRESENT	0
31936	31901	98046X	PARTICIPANT	\N	EXCUSE	0
31937	31901	11085T	PARTICIPANT	\N	PRESENT	0
31938	31901	08011M	PARTICIPANT	\N	PRESENT	0
31939	31901	08073C	PARTICIPANT	\N	PRESENT	0
31940	31901	08061X	PARTICIPANT	\N	PRESENT	0
31941	31901	01016M	PARTICIPANT	\N	PRESENT	0
31942	31901	14225N	PARTICIPANT	\N	PRESENT	0
31943	31901	11012A	PARTICIPANT	\N	PRESENT	0
31944	31901	11057P	PARTICIPANT	\N	PRESENT	0
31945	31901	14173T	PARTICIPANT	\N	EXCUSE	0
31946	31901	04034C	PARTICIPANT	\N	PRESENT	0
31947	31683	14071N	PARTICIPANT	\N	PRESENT	0
31948	31683	14235Q	PARTICIPANT	\N	PRESENT	0
32000	31687	86034E	PARTICIPANT	\N	PRESENT	0
32001	31687	08052W	PARTICIPANT	\N	PRESENT	0
32002	31687	14081Q	PARTICIPANT	\N	PRESENT	0
32003	31687	14259Y	PARTICIPANT	\N	PRESENT	0
32004	31687	11015D	PARTICIPANT	\N	PRESENT	0
32005	31687	11027H	PARTICIPANT	\N	PRESENT	0
32006	31687	95030B	PARTICIPANT	\N	PRESENT	0
32007	31687	14038Y	PARTICIPANT	\N	PRESENT	0
32008	31687	14197C	PARTICIPANT	\N	PRESENT	0
32009	31687	14041T	PARTICIPANT	\N	PRESENT	0
32010	31687	14227Q	PARTICIPANT	\N	PRESENT	0
32011	31687	08021P	PARTICIPANT	\N	PRESENT	0
32012	31687	80027E	PARTICIPANT	\N	PRESENT	0
32013	31687	00003C	PARTICIPANT	\N	PRESENT	0
32014	31687	11066Q	PARTICIPANT	\N	PRESENT	0
32015	31687	04036E	PARTICIPANT	\N	PRESENT	0
32016	31687	95031C	PARTICIPANT	\N	PRESENT	0
32017	31687	10015M	PARTICIPANT	\N	PRESENT	0
32018	31687	92040Q	PARTICIPANT	\N	PRESENT	0
32019	31687	14223L	PARTICIPANT	\N	PRESENT	0
32020	31687	08053X	PARTICIPANT	\N	PRESENT	0
32021	31687	80013X	PARTICIPANT	\N	PRESENT	0
32022	31687	11104D	PARTICIPANT	\N	PRESENT	0
32023	31687	86044G	PARTICIPANT	\N	PRESENT	0
32024	31687	11039M	PARTICIPANT	\N	PRESENT	0
32025	31687	14051J	PARTICIPANT	\N	PRESENT	0
32026	31687	08058D	PARTICIPANT	\N	PRESENT	0
32027	31687	14107H	PARTICIPANT	\N	PRESENT	0
32028	31687	14207L	PARTICIPANT	\N	PRESENT	0
32029	31687	98035U	PARTICIPANT	\N	PRESENT	0
32030	31687	92045V	PARTICIPANT	\N	PRESENT	0
32031	31687	11012A	PARTICIPANT	\N	PRESENT	0
32032	31687	04038G	PARTICIPANT	\N	PRESENT	0
32033	31687	08024S	PARTICIPANT	\N	PRESENT	0
32034	31687	04074L	PARTICIPANT	\N	PRESENT	0
40257	40256	14030Q	PARTICIPANT	\N	PRESENT	0
40258	40256	08043V	PARTICIPANT	\N	PRESENT	0
40259	40256	08060W	PARTICIPANT	\N	EXCUSE	0
40260	40256	11029K	PARTICIPANT	\N	PRESENT	0
40261	40256	11031D	PARTICIPANT	\N	PRESENT	0
40262	40256	11027H	PARTICIPANT	\N	PRESENT	0
40263	40256	80013X	PARTICIPANT	\N	PRESENT	0
40264	40256	14014Q	PARTICIPANT	\N	EXCUSE	0
40265	40256	07026Q	PARTICIPANT	\N	PRESENT	0
40266	40256	95035G	PARTICIPANT	\N	PRESENT	0
40267	40256	08069G	PARTICIPANT	\N	EXCUSE	0
40268	40256	09001P	PRESIDENT	0	PRESENT	0
40269	40256	14241N	PARTICIPANT	\N	PRESENT	0
40270	40256	04036E	PARTICIPANT	\N	PRESENT	0
40271	40256	08031R	PARTICIPANT	\N	PRESENT	0
40272	40256	08017T	PARTICIPANT	\N	PRESENT	0
40273	40256	11067R	PARTICIPANT	\N	PRESENT	0
40274	40256	11014C	PARTICIPANT	\N	PRESENT	0
40275	40256	14109K	PARTICIPANT	\N	PRESENT	0
40276	40256	14237S	PARTICIPANT	\N	EXCUSE	0
43521	43134	11085T	PARTICIPANT	\N	PRESENT	0
43525	43134	14237S	PARTICIPANT	\N	PRESENT	0
43532	43134	07026Q	PARTICIPANT	\N	PRESENT	0
43614	43140	11085T	PARTICIPANT	\N	PRESENT	0
43534	43134	14063N	PARTICIPANT	\N	PRESENT	0
43535	43134	08017T	PARTICIPANT	\N	PRESENT	0
43536	43134	08043V	PARTICIPANT	\N	PRESENT	0
43537	43134	04070G	PARTICIPANT	\N	PRESENT	0
43538	43134	08039A	PARTICIPANT	\N	PRESENT	0
43539	43134	01031L	PARTICIPANT	\N	PRESENT	0
43540	43134	11074Q	PARTICIPANT	\N	PRESENT	0
43541	43134	11104D	PARTICIPANT	\N	PRESENT	0
43542	43134	04059M	PARTICIPANT	\N	PRESENT	0
43543	43134	01044R	PARTICIPANT	\N	PRESENT	0
43544	43134	11029K	PARTICIPANT	\N	PRESENT	0
43545	43134	14083S	PARTICIPANT	\N	PRESENT	0
43546	43134	14179A	PARTICIPANT	\N	PRESENT	0
43547	43134	04035D	PARTICIPANT	\N	PRESENT	0
43548	43134	01048V	PARTICIPANT	\N	PRESENT	0
43549	43134	86044G	PARTICIPANT	\N	PRESENT	0
43550	43134	14235Q	PARTICIPANT	\N	PRESENT	0
43551	43134	95062K	PARTICIPANT	\N	PRESENT	0
43552	43134	14229S	PARTICIPANT	\N	PRESENT	0
43553	43134	14265W	PARTICIPANT	\N	PRESENT	0
43554	43134	08061X	PARTICIPANT	\N	PRESENT	0
43555	43134	14241N	PARTICIPANT	\N	PRESENT	0
43556	43134	04057K	PARTICIPANT	\N	PRESENT	0
43557	43134	14061L	PARTICIPANT	\N	PRESENT	0
43558	43134	05004A	PARTICIPANT	\N	PRESENT	0
43559	43134	11043H	PARTICIPANT	\N	PRESENT	0
43560	43134	11083R	PARTICIPANT	\N	PRESENT	0
43561	43134	11042G	PARTICIPANT	\N	PRESENT	0
43562	43134	11014C	PARTICIPANT	\N	PRESENT	0
43563	43134	14207L	PARTICIPANT	\N	PRESENT	0
43564	43134	01003G	PARTICIPANT	\N	PRESENT	0
43565	43134	04088S	PARTICIPANT	\N	PRESENT	0
43566	43134	11057P	PARTICIPANT	\N	PRESENT	0
43567	43134	01057W	PARTICIPANT	\N	PRESENT	0
43568	43134	04042C	PARTICIPANT	\N	PRESENT	0
43569	43134	11036J	PARTICIPANT	\N	PRESENT	0
43570	43134	08014Q	PARTICIPANT	\N	PRESENT	0
43571	43134	14231L	PARTICIPANT	\N	PRESENT	0
43572	43134	11039M	PARTICIPANT	\N	PRESENT	0
43573	43134	14197C	PARTICIPANT	\N	PRESENT	0
43574	43134	14030Q	PARTICIPANT	\N	PRESENT	0
43575	43134	14217N	PARTICIPANT	\N	PRESENT	0
43576	43134	14159V	PARTICIPANT	\N	PRESENT	0
43577	43134	08012N	PARTICIPANT	\N	PRESENT	0
43578	43134	98050T	PARTICIPANT	\N	PRESENT	0
43579	43134	11105E	PARTICIPANT	\N	PRESENT	0
43580	43134	08016S	PARTICIPANT	\N	PRESENT	0
43581	43134	99004R	PARTICIPANT	\N	PRESENT	0
43582	43134	14042U	PARTICIPANT	\N	PRESENT	0
43583	43134	14085U	PARTICIPANT	\N	PRESENT	0
43584	43134	14073Q	PARTICIPANT	\N	PRESENT	0
43606	43134	14199E	PARTICIPANT	\N	PRESENT	0
43607	43134	14219Q	PARTICIPANT	\N	PRESENT	0
43608	43134	14041T	PARTICIPANT	\N	PRESENT	0
43613	43134	14263U	PARTICIPANT	\N	PRESENT	0
43615	43140	14237S	PARTICIPANT	\N	PRESENT	0
43669	43140	08043V	PARTICIPANT	\N	PRESENT	0
43617	43140	14063N	PARTICIPANT	\N	PRESENT	0
43618	43140	08017T	PARTICIPANT	\N	PRESENT	0
43619	43140	04070G	PARTICIPANT	\N	PRESENT	0
43678	43140	04059M	PARTICIPANT	\N	PRESENT	0
43621	43140	01031L	PARTICIPANT	\N	PRESENT	0
43622	43140	11104D	PARTICIPANT	\N	PRESENT	0
43671	43140	14277B	PARTICIPANT	\N	PRESENT	0
43624	43140	01044R	PARTICIPANT	\N	PRESENT	0
43625	43140	11029K	PARTICIPANT	\N	PRESENT	0
43626	43140	14083S	PARTICIPANT	\N	PRESENT	0
43680	43140	14179A	PARTICIPANT	\N	PRESENT	0
43679	43140	14259Y	PARTICIPANT	\N	PRESENT	0
43681	43140	14059S	PARTICIPANT	\N	PRESENT	0
43630	43140	14235Q	PARTICIPANT	\N	PRESENT	0
43682	43140	95062K	PARTICIPANT	\N	PRESENT	0
43632	43140	14265W	PARTICIPANT	\N	PRESENT	0
43672	43140	14215L	PARTICIPANT	\N	PRESENT	0
43634	43140	14241N	PARTICIPANT	\N	PRESENT	0
43635	43140	04057K	PARTICIPANT	\N	PRESENT	0
43636	43140	14061L	PARTICIPANT	\N	PRESENT	0
43683	43140	04034C	PARTICIPANT	\N	PRESENT	0
43638	43140	11043H	PARTICIPANT	\N	PRESENT	0
43684	43140	11027H	PARTICIPANT	\N	PRESENT	0
43640	43140	11042G	PARTICIPANT	\N	PRESENT	0
43641	43140	11014C	PARTICIPANT	\N	PRESENT	0
43685	43140	14042U	PARTICIPANT	\N	PRESENT	0
43643	43140	01003G	PARTICIPANT	\N	PRESENT	0
43644	43140	04088S	PARTICIPANT	\N	PRESENT	0
43645	43140	11057P	PARTICIPANT	\N	PRESENT	0
43646	43140	01057W	PARTICIPANT	\N	PRESENT	0
43686	43140	95035G	PARTICIPANT	\N	PRESENT	0
43648	43140	11036J	PARTICIPANT	\N	PRESENT	0
43649	43140	08014Q	PARTICIPANT	\N	PRESENT	0
43687	43140	98018T	PARTICIPANT	\N	PRESENT	0
43651	43140	11039M	PARTICIPANT	\N	PRESENT	0
44272	44241	86034E	PARTICIPANT	\N	PRESENT	0
43653	43140	14030Q	PARTICIPANT	\N	PRESENT	0
43654	43140	14217N	PARTICIPANT	\N	PRESENT	0
43655	43140	14159V	PARTICIPANT	\N	PRESENT	0
43656	43140	08012N	PARTICIPANT	\N	PRESENT	0
44273	44241	11095V	PARTICIPANT	\N	PRESENT	0
43658	43140	11105E	PARTICIPANT	\N	PRESENT	0
43659	43140	08016S	PARTICIPANT	\N	PRESENT	0
43660	43140	99004R	PARTICIPANT	\N	PRESENT	0
44274	44241	80013X	PARTICIPANT	\N	PRESENT	0
43662	43140	14085U	PARTICIPANT	\N	PRESENT	0
43663	43140	14073Q	PARTICIPANT	\N	PRESENT	0
43664	43140	14199E	PARTICIPANT	\N	PRESENT	0
43665	43140	14219Q	PARTICIPANT	\N	PRESENT	0
43666	43140	14041T	PARTICIPANT	\N	PRESENT	0
43670	43140	07004J	PARTICIPANT	\N	PRESENT	0
43668	43140	11089X	PARTICIPANT	\N	PRESENT	0
43673	43140	01027Q	PARTICIPANT	\N	PRESENT	0
43674	43140	14263U	PARTICIPANT	\N	PRESENT	0
43675	43140	07026Q	PARTICIPANT	\N	PRESENT	0
43676	43140	08024S	PARTICIPANT	\N	PRESENT	0
43677	43140	98035U	PARTICIPANT	\N	PRESENT	0
44275	44241	08016S	PARTICIPANT	\N	PRESENT	0
44276	44241	01022K	PARTICIPANT	\N	PRESENT	0
44277	44241	98035U	PARTICIPANT	\N	PRESENT	0
44278	44241	08014Q	PARTICIPANT	\N	PRESENT	0
44279	44241	11035H	PARTICIPANT	\N	PRESENT	0
44280	44241	11025F	PARTICIPANT	\N	PRESENT	0
44281	44241	14201E	PARTICIPANT	\N	PRESENT	0
44282	44241	14103D	PARTICIPANT	\N	PRESENT	0
44284	44241	98046X	PARTICIPANT	\N	PRESENT	0
44285	44241	11055M	PARTICIPANT	\N	PRESENT	0
44287	44241	08025T	PARTICIPANT	\N	PRESENT	0
44288	44241	92018S	PARTICIPANT	\N	PRESENT	0
44289	44241	07026Q	PARTICIPANT	\N	PRESENT	0
44290	44241	11107G	PARTICIPANT	\N	PRESENT	0
44291	44241	01031L	PARTICIPANT	\N	PRESENT	0
44292	44241	01013J	PARTICIPANT	\N	PRESENT	0
44293	44241	11098Y	PARTICIPANT	\N	PRESENT	0
44294	44241	14211G	PARTICIPANT	\N	PRESENT	0
44295	44241	04097T	PARTICIPANT	\N	PRESENT	0
44296	44241	14051J	PARTICIPANT	\N	PRESENT	0
44297	44241	95062K	PARTICIPANT	\N	PRESENT	0
44298	44241	14063N	PARTICIPANT	\N	PRESENT	0
44299	44241	95031C	PARTICIPANT	\N	PRESENT	0
44300	44241	01027Q	PARTICIPANT	\N	PRESENT	0
44301	44241	99004R	PARTICIPANT	\N	PRESENT	0
44302	44241	08058D	PARTICIPANT	\N	PRESENT	0
44303	44241	11083R	PARTICIPANT	\N	PRESENT	0
44304	44241	08010L	PARTICIPANT	\N	PRESENT	0
44305	44241	11029K	PARTICIPANT	\N	PRESENT	0
44306	44241	14169X	PARTICIPANT	\N	PRESENT	0
44307	44241	11080N	PARTICIPANT	\N	PRESENT	0
33164	33146	86034E	PARTICIPANT	\N	PRESENT	0
33165	33146	01015L	PARTICIPANT	\N	PRESENT	0
33166	33146	01059Y	PARTICIPANT	\N	PRESENT	0
33167	33146	07026Q	PARTICIPANT	\N	PRESENT	0
33168	33146	04085P	PARTICIPANT	\N	PRESENT	0
33169	33146	01016M	PARTICIPANT	\N	PRESENT	0
33170	33146	11039M	PARTICIPANT	\N	PRESENT	0
33171	33146	14151M	PARTICIPANT	\N	PRESENT	0
33172	33146	08055A	PARTICIPANT	\N	PRESENT	0
33173	33146	14121F	PARTICIPANT	\N	PRESENT	0
33174	33146	14031R	PARTICIPANT	\N	PRESENT	0
33175	33146	11057P	PARTICIPANT	\N	PRESENT	0
33176	33146	95067Q	PARTICIPANT	\N	PRESENT	0
33177	33146	01022K	PARTICIPANT	\N	PRESENT	0
33178	33146	01027Q	PARTICIPANT	\N	PRESENT	0
33179	33146	04033B	PARTICIPANT	\N	PRESENT	0
33180	33146	80013X	PARTICIPANT	\N	PRESENT	0
33181	33146	92045V	PARTICIPANT	\N	PRESENT	0
33182	33146	08052W	PARTICIPANT	\N	PRESENT	0
33183	33146	86044G	PARTICIPANT	\N	PRESENT	0
33184	33146	11061K	PARTICIPANT	\N	PRESENT	0
33185	33146	14281W	PARTICIPANT	\N	PRESENT	0
33186	33146	14038Y	PARTICIPANT	\N	PRESENT	0
33187	33146	14271U	PARTICIPANT	\N	PRESENT	0
33188	33146	14195A	PARTICIPANT	\N	PRESENT	0
33189	33146	13002U	PARTICIPANT	\N	PRESENT	0
33190	33146	14157T	PARTICIPANT	\N	PRESENT	0
33191	33146	14107H	PARTICIPANT	\N	PRESENT	0
33192	33146	14135M	PARTICIPANT	\N	PRESENT	0
33193	33146	14133K	PARTICIPANT	\N	PRESENT	0
33194	33146	11036J	PARTICIPANT	\N	PRESENT	0
33195	33146	98018T	PARTICIPANT	\N	PRESENT	0
33196	33146	11074Q	PARTICIPANT	\N	PRESENT	0
33202	33146	14109K	PARTICIPANT	\N	PRESENT	0
33198	33146	01031L	PARTICIPANT	\N	PRESENT	0
33199	33146	14197C	PARTICIPANT	\N	PRESENT	0
33200	33146	14097Y	PARTICIPANT	\N	PRESENT	0
33201	33146	11112D	PARTICIPANT	\N	PRESENT	0
33203	33146	14014Q	PARTICIPANT	\N	PRESENT	0
33204	33146	14207L	PARTICIPANT	\N	PRESENT	0
33205	33146	11077T	PARTICIPANT	\N	PRESENT	0
33206	33146	11023D	PARTICIPANT	\N	PRESENT	0
33207	33146	11026G	PARTICIPANT	\N	PRESENT	0
33208	33146	08068F	PARTICIPANT	\N	PRESENT	0
33209	33146	12042Y	PARTICIPANT	\N	PRESENT	0
33210	33146	14081Q	PARTICIPANT	\N	PRESENT	0
33211	33146	11066Q	PARTICIPANT	\N	PRESENT	0
33212	33146	11042G	PARTICIPANT	\N	PRESENT	0
33213	33146	14235Q	PARTICIPANT	\N	PRESENT	0
33214	33146	14033T	PARTICIPANT	\N	PRESENT	0
33215	33146	11114F	PARTICIPANT	\N	PRESENT	0
33216	33146	04081K	PARTICIPANT	\N	PRESENT	0
33217	33146	14159V	PARTICIPANT	\N	PRESENT	0
33218	33146	14079W	PARTICIPANT	\N	PRESENT	0
33219	33146	11065P	PARTICIPANT	\N	PRESENT	0
33220	33146	11099A	PARTICIPANT	\N	PRESENT	0
33221	33146	01044R	PARTICIPANT	\N	PRESENT	0
33222	33147	01015L	PARTICIPANT	\N	PRESENT	0
33223	33147	01059Y	PARTICIPANT	\N	PRESENT	0
33224	33147	07026Q	PARTICIPANT	\N	PRESENT	0
33225	33147	04085P	PARTICIPANT	\N	PRESENT	0
33226	33147	01016M	PARTICIPANT	\N	PRESENT	0
33227	33147	11039M	PARTICIPANT	\N	PRESENT	0
33228	33147	14151M	PARTICIPANT	\N	PRESENT	0
33229	33147	08055A	PARTICIPANT	\N	PRESENT	0
33230	33147	14121F	PARTICIPANT	\N	PRESENT	0
33231	33147	14031R	PARTICIPANT	\N	PRESENT	0
33232	33147	11057P	PARTICIPANT	\N	PRESENT	0
33233	33147	95067Q	PARTICIPANT	\N	PRESENT	0
33234	33147	01022K	PARTICIPANT	\N	PRESENT	0
33235	33147	01027Q	PARTICIPANT	\N	PRESENT	0
33236	33147	04033B	PARTICIPANT	\N	PRESENT	0
33237	33147	80013X	PARTICIPANT	\N	PRESENT	0
33238	33147	92045V	PARTICIPANT	\N	PRESENT	0
33239	33147	08052W	PARTICIPANT	\N	PRESENT	0
33240	33147	86044G	PARTICIPANT	\N	PRESENT	0
33241	33147	11061K	PARTICIPANT	\N	PRESENT	0
33242	33147	14281W	PARTICIPANT	\N	PRESENT	0
33243	33147	14038Y	PARTICIPANT	\N	PRESENT	0
33244	33147	14271U	PARTICIPANT	\N	PRESENT	0
33245	33147	14195A	PARTICIPANT	\N	PRESENT	0
33246	33147	13002U	PARTICIPANT	\N	PRESENT	0
33247	33147	14157T	PARTICIPANT	\N	PRESENT	0
33248	33147	14107H	PARTICIPANT	\N	PRESENT	0
33249	33147	14135M	PARTICIPANT	\N	PRESENT	0
33250	33147	14133K	PARTICIPANT	\N	PRESENT	0
33251	33147	11036J	PARTICIPANT	\N	PRESENT	0
33252	33147	98018T	PARTICIPANT	\N	PRESENT	0
33253	33147	11074Q	PARTICIPANT	\N	PRESENT	0
33254	33147	01031L	PARTICIPANT	\N	PRESENT	0
33255	33147	14197C	PARTICIPANT	\N	PRESENT	0
33256	33147	14097Y	PARTICIPANT	\N	PRESENT	0
33257	33147	11112D	PARTICIPANT	\N	PRESENT	0
33258	33147	14109K	PARTICIPANT	\N	PRESENT	0
33259	33147	14014Q	PARTICIPANT	\N	PRESENT	0
33260	33147	14207L	PARTICIPANT	\N	PRESENT	0
33261	33147	11077T	PARTICIPANT	\N	PRESENT	0
33262	33147	11023D	PARTICIPANT	\N	PRESENT	0
33263	33147	11026G	PARTICIPANT	\N	PRESENT	0
33264	33147	08068F	PARTICIPANT	\N	PRESENT	0
33265	33147	12042Y	PARTICIPANT	\N	PRESENT	0
33266	33147	14081Q	PARTICIPANT	\N	PRESENT	0
33267	33147	11066Q	PARTICIPANT	\N	PRESENT	0
33268	33147	11042G	PARTICIPANT	\N	PRESENT	0
33269	33147	14235Q	PARTICIPANT	\N	PRESENT	0
33270	33147	14033T	PARTICIPANT	\N	PRESENT	0
33271	33147	11114F	PARTICIPANT	\N	PRESENT	0
33272	33147	04081K	PARTICIPANT	\N	PRESENT	0
33273	33147	14159V	PARTICIPANT	\N	PRESENT	0
33274	33147	14079W	PARTICIPANT	\N	PRESENT	0
33275	33147	11065P	PARTICIPANT	\N	PRESENT	0
33276	33147	11099A	PARTICIPANT	\N	PRESENT	0
33277	33147	01044R	PARTICIPANT	\N	PRESENT	0
33278	33147	14037X	PARTICIPANT	\N	PRESENT	0
33279	33147	11107G	PARTICIPANT	\N	PRESENT	0
33280	33147	11076S	PARTICIPANT	\N	PRESENT	0
33281	33147	11100Y	PARTICIPANT	\N	PRESENT	0
33282	33147	11029K	PARTICIPANT	\N	PRESENT	0
33283	33147	96004D	PARTICIPANT	\N	PRESENT	0
33284	33147	11048N	PARTICIPANT	\N	PRESENT	0
33285	33147	95049N	PARTICIPANT	\N	PRESENT	0
33286	33147	01008M	PARTICIPANT	\N	PRESENT	0
33287	33147	08051V	PARTICIPANT	\N	PRESENT	0
33288	33147	88008L	PARTICIPANT	\N	PRESENT	0
33289	33147	14055N	PARTICIPANT	\N	PRESENT	0
33290	33147	08049C	PARTICIPANT	\N	PRESENT	0
33291	33147	14209N	PARTICIPANT	\N	PRESENT	0
33292	33147	14018U	PARTICIPANT	\N	PRESENT	0
33293	33147	04049K	PARTICIPANT	\N	PRESENT	0
33294	33147	08031R	PARTICIPANT	\N	PRESENT	0
33295	33147	01034P	PARTICIPANT	\N	PRESENT	0
33296	33147	14265W	PARTICIPANT	\N	PRESENT	0
33297	33147	14147R	PARTICIPANT	\N	PRESENT	0
33298	33147	04040A	PARTICIPANT	\N	PRESENT	0
33299	33147	08015R	PARTICIPANT	\N	PRESENT	0
33300	33147	14213J	PARTICIPANT	\N	PRESENT	0
33301	33147	08009T	PARTICIPANT	\N	PRESENT	0
33302	33147	14059S	PARTICIPANT	\N	PRESENT	0
33303	33147	14261S	PARTICIPANT	\N	PRESENT	0
33304	33147	14042U	PARTICIPANT	\N	PRESENT	0
33326	33147	14093U	PARTICIPANT	\N	PRESENT	0
33306	33147	14030Q	PARTICIPANT	\N	PRESENT	0
33307	33147	11071M	PARTICIPANT	\N	PRESENT	0
33308	33147	14103D	PARTICIPANT	\N	PRESENT	0
33309	33147	14255U	PARTICIPANT	\N	PRESENT	0
33310	33147	14205J	PARTICIPANT	\N	PRESENT	0
33311	33147	14231L	PARTICIPANT	\N	PRESENT	0
33312	33147	14083S	PARTICIPANT	\N	PRESENT	0
33313	33147	09001P	PARTICIPANT	\N	PRESENT	0
33314	33147	08044W	PARTICIPANT	\N	PRESENT	0
33321	33147	07029T	PARTICIPANT	\N	PRESENT	0
33316	33147	04070G	PARTICIPANT	\N	PRESENT	0
33317	33147	01025N	PARTICIPANT	\N	PRESENT	0
33318	33147	08011M	PARTICIPANT	\N	PRESENT	0
33319	33147	11049P	PARTICIPANT	\N	PRESENT	0
33320	33147	14069U	PARTICIPANT	\N	PRESENT	0
33322	33147	86034E	PARTICIPANT	\N	PRESENT	0
33324	33147	14249W	PARTICIPANT	\N	PRESENT	0
33325	33147	04088S	PARTICIPANT	\N	PRESENT	0
33327	33147	08019V	PARTICIPANT	\N	PRESENT	0
33328	33147	14105F	PARTICIPANT	\N	PRESENT	0
33329	33147	04097T	PARTICIPANT	\N	PRESENT	0
33330	33147	08069G	PARTICIPANT	\N	PRESENT	0
33331	33147	14215L	PARTICIPANT	\N	PRESENT	0
33332	33147	11103C	PARTICIPANT	\N	PRESENT	0
33333	33147	14193X	PARTICIPANT	\N	PRESENT	0
40462	40091	98035U	PARTICIPANT	\N	PRESENT	0
40463	40091	05012A	PARTICIPANT	\N	PRESENT	0
40464	40091	01016M	PARTICIPANT	\N	PRESENT	0
40465	40091	11039M	PARTICIPANT	\N	PRESENT	0
40466	40091	04056J	PARTICIPANT	\N	PRESENT	0
40467	40091	14237S	PARTICIPANT	\N	PRESENT	0
40468	40091	98046X	PARTICIPANT	\N	PRESENT	0
40469	40091	95063L	PARTICIPANT	\N	PRESENT	0
40470	40091	11027H	PARTICIPANT	\N	PRESENT	0
40471	40091	11084S	PARTICIPANT	\N	PRESENT	0
40472	40091	14225N	PARTICIPANT	\N	PRESENT	0
40473	40091	11067R	PARTICIPANT	\N	PRESENT	0
40474	40091	14213J	PARTICIPANT	\N	PRESENT	0
40475	40091	14028W	PARTICIPANT	\N	PRESENT	0
40476	40091	98050T	PARTICIPANT	\N	PRESENT	0
40477	40091	11036J	PARTICIPANT	\N	PRESENT	0
40478	40091	01008M	PARTICIPANT	\N	PRESENT	0
40479	40091	11089X	PARTICIPANT	\N	PRESENT	0
40480	40091	98029W	PARTICIPANT	\N	PRESENT	0
40481	40091	08069G	PARTICIPANT	\N	PRESENT	0
40482	40091	11046L	PARTICIPANT	\N	PRESENT	0
40483	40091	95035G	PARTICIPANT	\N	PRESENT	0
40484	40091	08053X	PARTICIPANT	\N	PRESENT	0
40485	40091	08058D	PARTICIPANT	\N	PRESENT	0
40486	40091	11042G	PARTICIPANT	\N	PRESENT	0
40487	40091	14109K	PARTICIPANT	\N	PRESENT	0
40488	40091	14119M	PARTICIPANT	\N	PRESENT	0
40489	40091	08014Q	PARTICIPANT	\N	PRESENT	0
40490	40091	08017T	PARTICIPANT	\N	PRESENT	0
40491	40091	14227Q	PARTICIPANT	\N	PRESENT	0
40492	40091	14013P	PARTICIPANT	\N	PRESENT	0
40493	40091	98021N	PARTICIPANT	\N	PRESENT	0
40494	40091	11031D	PARTICIPANT	\N	PRESENT	0
40495	40091	11112D	PARTICIPANT	\N	PRESENT	0
40496	40091	92031P	PARTICIPANT	\N	PRESENT	0
40497	40091	14257W	PARTICIPANT	\N	PRESENT	0
40498	40091	13002U	PARTICIPANT	\N	PRESENT	0
40499	40091	11074Q	PARTICIPANT	\N	PRESENT	0
40500	40091	11061K	PARTICIPANT	\N	PRESENT	0
40501	40091	14229S	PARTICIPANT	\N	PRESENT	0
40502	40091	04079R	PARTICIPANT	\N	PRESENT	0
40503	40091	14151M	PARTICIPANT	\N	PRESENT	0
40504	40091	11063M	PARTICIPANT	\N	PRESENT	0
40505	40091	98042T	PARTICIPANT	\N	PRESENT	0
40506	40091	14205J	PARTICIPANT	\N	PRESENT	0
40507	40091	14249W	PARTICIPANT	\N	PRESENT	0
40508	40091	04036E	PARTICIPANT	\N	PRESENT	0
40509	40091	08061X	PARTICIPANT	\N	PRESENT	0
40510	40091	11071M	PARTICIPANT	\N	PRESENT	0
40511	40091	01028R	PARTICIPANT	\N	PRESENT	0
40512	40091	08038Y	PARTICIPANT	\N	PRESENT	0
40513	40091	11104D	PARTICIPANT	\N	PRESENT	0
40514	40091	14265W	PARTICIPANT	\N	PRESENT	0
40515	40091	08024S	PARTICIPANT	\N	PRESENT	0
40516	40091	01041N	PARTICIPANT	\N	PRESENT	0
40517	40091	08068F	PARTICIPANT	\N	PRESENT	0
40518	40091	11106F	PARTICIPANT	\N	PRESENT	0
40519	40091	14081Q	PARTICIPANT	\N	PRESENT	0
40520	40091	14135M	PARTICIPANT	\N	PRESENT	0
40521	40091	11023D	PARTICIPANT	\N	PRESENT	0
40522	40091	14159V	PARTICIPANT	\N	PRESENT	0
40523	40091	12042Y	PARTICIPANT	\N	PRESENT	0
40524	40091	11077T	PARTICIPANT	\N	PRESENT	0
40525	40091	11114F	PARTICIPANT	\N	PRESENT	0
40526	40091	14269B	PARTICIPANT	\N	PRESENT	0
40527	40091	01014K	PARTICIPANT	\N	PRESENT	0
40528	40091	11072N	PARTICIPANT	\N	PRESENT	0
40529	40091	14241N	PARTICIPANT	\N	PRESENT	0
40530	40091	11065P	PARTICIPANT	\N	PRESENT	0
40531	40091	14247U	PARTICIPANT	\N	PRESENT	0
40532	40091	01024M	PARTICIPANT	\N	PRESENT	0
40533	40091	14093U	PARTICIPANT	\N	PRESENT	0
40534	40091	04067M	PARTICIPANT	\N	PRESENT	0
40535	40091	04071H	PARTICIPANT	\N	PRESENT	0
40536	40091	11064N	PARTICIPANT	\N	PRESENT	0
40537	40091	11032E	PARTICIPANT	\N	PRESENT	0
40554	40091	01056V	PARTICIPANT	\N	PRESENT	0
40539	40091	14169X	PARTICIPANT	\N	PRESENT	0
40540	40091	95067Q	PARTICIPANT	\N	PRESENT	0
40544	40091	14065Q	PARTICIPANT	\N	PRESENT	0
40557	40091	05004A	PARTICIPANT	\N	PRESENT	0
40560	40091	11026G	PARTICIPANT	\N	PRESENT	0
40564	40091	11085T	PARTICIPANT	\N	PRESENT	0
40562	40091	08010L	PARTICIPANT	\N	PRESENT	0
40563	40091	11110B	PARTICIPANT	\N	PRESENT	0
40569	40091	11083R	PARTICIPANT	\N	PRESENT	0
40861	40093	04066L	PARTICIPANT	\N	PRESENT	0
40862	40093	08010L	PARTICIPANT	\N	PRESENT	0
40863	40093	01024M	PARTICIPANT	\N	PRESENT	0
40864	40093	01031L	PARTICIPANT	\N	PRESENT	0
40865	40093	11098Y	PARTICIPANT	\N	PRESENT	0
40866	40093	11074Q	PARTICIPANT	\N	PRESENT	0
40867	40093	01016M	PARTICIPANT	\N	PRESENT	0
40868	40093	14225N	PARTICIPANT	\N	PRESENT	0
40869	40093	14159V	PARTICIPANT	\N	PRESENT	0
40870	40093	11114F	PARTICIPANT	\N	PRESENT	0
40871	40093	11037K	PARTICIPANT	\N	PRESENT	0
40872	40093	11094U	PARTICIPANT	\N	PRESENT	0
40873	40093	14261S	PARTICIPANT	\N	PRESENT	0
40874	40093	14083S	PARTICIPANT	\N	PRESENT	0
40875	40093	01028R	PARTICIPANT	\N	PRESENT	0
40876	40093	14041T	PARTICIPANT	\N	PRESENT	0
40877	40093	04085P	PARTICIPANT	\N	PRESENT	0
40878	40093	08034U	PARTICIPANT	\N	PRESENT	0
40879	40093	08011M	PARTICIPANT	\N	PRESENT	0
40880	40093	08019V	PARTICIPANT	\N	PRESENT	0
40881	40093	08052W	PARTICIPANT	\N	PRESENT	0
40882	40093	04074L	PARTICIPANT	\N	PRESENT	0
40883	40093	11057P	PARTICIPANT	\N	PRESENT	0
40884	40093	08031R	PARTICIPANT	\N	PRESENT	0
40896	40093	14037X	PARTICIPANT	\N	PRESENT	0
48016	47942	86034E	PARTICIPANT	\N	PRESENT	0
48017	47942	08041T	PARTICIPANT	\N	PRESENT	0
48018	47942	11030C	PARTICIPANT	\N	PRESENT	0
48019	47942	14042U	PARTICIPANT	\N	PRESENT	0
48020	47942	90003B	PARTICIPANT	\N	PRESENT	0
48021	47942	14121F	PARTICIPANT	\N	PRESENT	0
48022	47942	14219Q	PARTICIPANT	\N	PRESENT	0
48023	47942	98022P	PARTICIPANT	\N	PRESENT	0
48024	47942	14157T	PARTICIPANT	\N	PRESENT	0
48025	47942	07034Q	PARTICIPANT	\N	PRESENT	0
48026	47942	14087W	PARTICIPANT	\N	PRESENT	0
48027	47942	14159V	PARTICIPANT	\N	PRESENT	0
48028	47942	08056B	PARTICIPANT	\N	PRESENT	0
48029	47942	08068F	PARTICIPANT	\N	PRESENT	0
48030	47942	14039A	PARTICIPANT	\N	PRESENT	0
48031	47942	01027Q	PARTICIPANT	\N	PRESENT	0
48032	47942	11101A	PARTICIPANT	\N	PRESENT	0
48033	47942	14175V	PARTICIPANT	\N	PRESENT	0
48034	47942	04088S	PARTICIPANT	\N	PRESENT	0
48035	47942	14281W	PARTICIPANT	\N	PRESENT	0
48036	47942	08060W	PARTICIPANT	\N	PRESENT	0
48037	47942	11059R	PARTICIPANT	\N	PRESENT	0
48038	47942	04034C	PARTICIPANT	\N	PRESENT	0
48039	47942	11025F	PARTICIPANT	\N	PRESENT	0
48040	47942	11066Q	PARTICIPANT	\N	PRESENT	0
48041	47942	14107H	PARTICIPANT	\N	PRESENT	0
48042	47942	11037K	PARTICIPANT	\N	PRESENT	0
48043	47942	14055N	PARTICIPANT	\N	PRESENT	0
48044	47942	04081K	PARTICIPANT	\N	PRESENT	0
48045	47942	07026Q	PARTICIPANT	\N	PRESENT	0
48046	47942	08052W	PARTICIPANT	\N	PRESENT	0
48047	47942	14085U	PARTICIPANT	\N	PRESENT	0
48048	47942	14221J	PARTICIPANT	\N	PRESENT	0
48049	47942	14133K	PARTICIPANT	\N	PRESENT	0
48050	47942	08016S	PARTICIPANT	\N	PRESENT	0
48051	47942	86044G	PARTICIPANT	\N	PRESENT	0
48052	47942	08065C	PARTICIPANT	\N	PRESENT	0
48053	47942	04048J	PARTICIPANT	\N	PRESENT	0
48054	47942	14033T	PARTICIPANT	\N	PRESENT	0
48055	47942	01061S	PARTICIPANT	\N	PRESENT	0
48056	47942	08017T	PARTICIPANT	\N	PRESENT	0
48057	47942	14063N	PARTICIPANT	\N	PRESENT	0
48058	47942	14013P	PARTICIPANT	\N	PRESENT	0
48059	47942	12041X	PARTICIPANT	\N	PRESENT	0
48060	47942	00003C	PARTICIPANT	\N	PRESENT	0
48061	47942	04079R	PARTICIPANT	\N	PRESENT	0
48062	47942	80027E	PARTICIPANT	\N	PRESENT	0
48063	47942	14167V	PARTICIPANT	\N	PRESENT	0
48064	47942	83047W	PARTICIPANT	\N	PRESENT	0
48065	47942	11063M	PARTICIPANT	\N	PRESENT	0
48066	47942	92040Q	PARTICIPANT	\N	PRESENT	0
48067	47942	01015L	PARTICIPANT	\N	PRESENT	0
48068	47942	08039A	PARTICIPANT	\N	PRESENT	0
48069	47942	04097T	PARTICIPANT	\N	PRESENT	0
48070	47942	08055A	PARTICIPANT	\N	PRESENT	0
48071	47942	02002K	PARTICIPANT	\N	PRESENT	0
48072	47942	14211G	PARTICIPANT	\N	PRESENT	0
30851	30801	98053W	PARTICIPANT	\N	PRESENT	0
30853	30801	01028R	PARTICIPANT	\N	PRESENT	0
30855	30801	11035H	PARTICIPANT	\N	PRESENT	0
30857	30801	11033F	PARTICIPANT	\N	PRESENT	0
30858	30801	11037K	PARTICIPANT	\N	PRESENT	0
30859	30801	04085P	PARTICIPANT	\N	PRESENT	0
30861	30801	07004J	PARTICIPANT	\N	PRESENT	0
30863	30801	14041T	PARTICIPANT	\N	PRESENT	0
30866	30801	07034Q	PARTICIPANT	\N	PRESENT	0
30868	30801	14103D	PARTICIPANT	\N	PRESENT	0
30869	30801	01024M	PARTICIPANT	\N	PRESENT	0
30870	30801	05008E	PARTICIPANT	\N	PRESENT	0
30872	30801	04057K	PARTICIPANT	\N	PRESENT	0
30874	30801	11012A	PARTICIPANT	\N	PRESENT	0
30875	30802	98053W	PARTICIPANT	\N	PRESENT	0
30876	30802	01028R	PARTICIPANT	\N	PRESENT	0
30877	30802	11035H	PARTICIPANT	\N	PRESENT	0
30878	30802	11033F	PARTICIPANT	\N	PRESENT	0
30879	30802	11037K	PARTICIPANT	\N	PRESENT	0
30880	30802	04085P	PARTICIPANT	\N	PRESENT	0
30881	30802	07004J	PARTICIPANT	\N	PRESENT	0
30882	30802	14041T	PARTICIPANT	\N	PRESENT	0
30883	30802	07034Q	PARTICIPANT	\N	PRESENT	0
30884	30802	14103D	PARTICIPANT	\N	PRESENT	0
30885	30802	01024M	PARTICIPANT	\N	PRESENT	0
30886	30802	05008E	PARTICIPANT	\N	PRESENT	0
30887	30802	04057K	PARTICIPANT	\N	PRESENT	0
30888	30802	11012A	PARTICIPANT	\N	PRESENT	0
30889	30802	98050T	PARTICIPANT	\N	PRESENT	0
30890	30802	11040E	PARTICIPANT	\N	PRESENT	0
30891	30802	04088S	PARTICIPANT	\N	PRESENT	0
30892	30802	11036J	PARTICIPANT	\N	PRESENT	0
30920	30802	07026Q	PARTICIPANT	\N	PRESENT	0
30921	30802	08058D	PARTICIPANT	\N	PRESENT	0
30922	30802	14265W	PARTICIPANT	\N	PRESENT	0
30923	30802	95063L	PARTICIPANT	\N	PRESENT	0
30924	30802	01041N	PARTICIPANT	\N	PRESENT	0
30925	30803	98053W	PARTICIPANT	\N	PRESENT	0
30926	30803	01028R	PARTICIPANT	\N	PRESENT	0
30927	30803	11035H	PARTICIPANT	\N	PRESENT	0
30928	30803	11033F	PARTICIPANT	\N	PRESENT	0
30998	30803	14249W	PARTICIPANT	\N	PRESENT	0
30930	30803	04085P	PARTICIPANT	\N	PRESENT	0
30999	30803	14225N	PARTICIPANT	\N	PRESENT	0
30932	30803	14041T	PARTICIPANT	\N	PRESENT	0
31000	30803	11056N	PARTICIPANT	\N	PRESENT	0
31001	30803	11053K	PARTICIPANT	\N	PRESENT	0
31002	30803	11039M	PARTICIPANT	\N	PRESENT	0
31003	30803	07004J	PARTICIPANT	\N	PRESENT	0
31004	30803	14069U	PARTICIPANT	\N	PRESENT	0
30938	30803	11012A	PARTICIPANT	\N	PRESENT	0
31005	30803	04056J	PARTICIPANT	\N	PRESENT	0
31008	30803	04080J	PARTICIPANT	\N	PRESENT	0
31016	30803	98050T	PARTICIPANT	\N	PRESENT	0
30942	30803	11036J	PARTICIPANT	\N	PRESENT	0
31009	30803	88008L	PARTICIPANT	\N	PRESENT	0
31011	30803	11040E	PARTICIPANT	\N	PRESENT	0
31012	30803	95063L	PARTICIPANT	\N	PRESENT	0
31013	30803	11037K	PARTICIPANT	\N	PRESENT	0
30947	30803	01041N	PARTICIPANT	\N	PRESENT	0
31014	30803	05008E	PARTICIPANT	\N	PRESENT	0
31015	30803	07029T	PARTICIPANT	\N	PRESENT	0
31017	30803	14265W	PARTICIPANT	\N	PRESENT	0
31032	30803	14001X	PARTICIPANT	\N	PRESENT	0
31033	30803	14103D	PARTICIPANT	\N	PRESENT	0
31034	30803	14219Q	PARTICIPANT	\N	PRESENT	0
31035	30803	04057K	PARTICIPANT	\N	PRESENT	0
31103	30805	95063L	PARTICIPANT	\N	PRESENT	0
31093	30805	07026Q	PARTICIPANT	\N	PRESENT	0
31098	30805	07034Q	PARTICIPANT	\N	PRESENT	0
31066	30805	11033F	PARTICIPANT	\N	PRESENT	0
31095	30805	08018U	PARTICIPANT	\N	PRESENT	0
31096	30805	01028R	PARTICIPANT	\N	PRESENT	0
31153	30805	99004R	PARTICIPANT	\N	PRESENT	0
31090	30805	14079W	PARTICIPANT	\N	PRESENT	0
31091	30805	14065Q	PARTICIPANT	\N	PRESENT	0
31092	30805	08060W	PARTICIPANT	\N	PRESENT	0
31094	30805	11072N	PARTICIPANT	\N	PRESENT	0
31074	30805	11056N	PARTICIPANT	\N	PRESENT	0
31154	30805	04036E	PARTICIPANT	\N	PRESENT	0
31097	30805	01024M	PARTICIPANT	\N	PRESENT	0
31099	30805	11113E	PARTICIPANT	\N	PRESENT	0
31100	30805	01048V	PARTICIPANT	\N	PRESENT	0
31101	30805	04081K	PARTICIPANT	\N	PRESENT	0
31102	30805	14038Y	PARTICIPANT	\N	PRESENT	0
31104	30805	14041T	PARTICIPANT	\N	PRESENT	0
31082	30805	11037K	PARTICIPANT	\N	PRESENT	0
31083	30805	05008E	PARTICIPANT	\N	PRESENT	0
31084	30805	07029T	PARTICIPANT	\N	PRESENT	0
31105	30805	04043D	PARTICIPANT	\N	PRESENT	0
31086	30805	14265W	PARTICIPANT	\N	PRESENT	0
31107	30805	08051V	PARTICIPANT	\N	PRESENT	0
31152	30805	98050T	PARTICIPANT	\N	PRESENT	0
31148	30805	04057K	PARTICIPANT	\N	PRESENT	0
31149	30805	14259Y	PARTICIPANT	\N	PRESENT	0
31150	30805	07004J	PARTICIPANT	\N	PRESENT	0
31156	30805	01041N	PARTICIPANT	\N	PRESENT	0
31155	30805	08019V	PARTICIPANT	\N	PRESENT	0
31157	30805	14013P	PARTICIPANT	\N	PRESENT	0
31158	30805	04056J	PARTICIPANT	\N	PRESENT	0
31159	30805	08034U	PARTICIPANT	\N	PRESENT	0
31160	30805	01031L	PARTICIPANT	\N	PRESENT	0
31161	30805	04077P	PARTICIPANT	\N	PRESENT	0
31162	30805	04035D	PARTICIPANT	\N	PRESENT	0
31163	30805	04038G	PARTICIPANT	\N	PRESENT	0
31164	30805	92045V	PARTICIPANT	\N	PRESENT	0
31165	30805	11082Q	PARTICIPANT	\N	PRESENT	0
31166	30805	95035G	PARTICIPANT	\N	PRESENT	0
31167	30805	04042C	PARTICIPANT	\N	PRESENT	0
31169	30805	04085P	PARTICIPANT	\N	PRESENT	0
31203	31196	08024S	PARTICIPANT	\N	PRESENT	0
31204	31196	14271U	PARTICIPANT	\N	PRESENT	0
31205	31196	11093T	PARTICIPANT	\N	PRESENT	0
31206	31196	08052W	PARTICIPANT	\N	PRESENT	0
31207	31196	01034P	PARTICIPANT	\N	PRESENT	0
31208	31196	08041T	PARTICIPANT	\N	PRESENT	0
31209	31196	11044J	PARTICIPANT	\N	PRESENT	0
31210	31196	04092N	PARTICIPANT	\N	PRESENT	0
31211	31196	11055M	PARTICIPANT	\N	PRESENT	0
31212	31196	04066L	PARTICIPANT	\N	PRESENT	0
31213	31196	14223L	PARTICIPANT	\N	PRESENT	0
31214	31196	14213J	PARTICIPANT	\N	PRESENT	0
31215	31196	14037X	PARTICIPANT	\N	PRESENT	0
31216	31196	14231L	PARTICIPANT	\N	PRESENT	0
31217	31196	12042Y	PARTICIPANT	\N	PRESENT	0
31218	31196	14327T	PARTICIPANT	\N	PRESENT	0
31219	31196	98024R	PARTICIPANT	\N	PRESENT	0
31220	31196	01059Y	PARTICIPANT	\N	PRESENT	0
31221	31196	11063M	PARTICIPANT	\N	PRESENT	0
31222	31196	00003C	PARTICIPANT	\N	PRESENT	0
31223	31196	01046T	PARTICIPANT	\N	PRESENT	0
31224	31196	04053F	PARTICIPANT	\N	PRESENT	0
31225	31196	01011G	PARTICIPANT	\N	PRESENT	0
31226	31196	14051J	PARTICIPANT	\N	PRESENT	0
31227	31196	14281W	PARTICIPANT	\N	PRESENT	0
31228	31196	11031D	PARTICIPANT	\N	PRESENT	0
31229	31196	04045F	PARTICIPANT	\N	PRESENT	0
31230	31196	14267Y	PARTICIPANT	\N	PRESENT	0
31231	31196	14261S	PARTICIPANT	\N	PRESENT	0
31232	31196	11088W	PARTICIPANT	\N	PRESENT	0
31233	31196	14227Q	PARTICIPANT	\N	PRESENT	0
44308	44241	14247U	PARTICIPANT	\N	PRESENT	0
44309	44241	04047H	PARTICIPANT	\N	PRESENT	0
44310	44241	88008L	PARTICIPANT	\N	PRESENT	0
44311	44241	08031R	PARTICIPANT	\N	PRESENT	0
44312	44241	11012A	PARTICIPANT	\N	PRESENT	0
44313	44241	01025N	PARTICIPANT	\N	PRESENT	0
44314	44241	14018U	PARTICIPANT	\N	PRESENT	0
44315	44241	11081P	PARTICIPANT	\N	PRESENT	0
44316	44241	98018T	PARTICIPANT	\N	PRESENT	0
44318	44241	04044E	PARTICIPANT	\N	PRESENT	0
44319	44241	10006L	PARTICIPANT	\N	PRESENT	0
44320	44241	04086Q	PARTICIPANT	\N	PRESENT	0
44321	44241	11040E	PARTICIPANT	\N	PRESENT	0
44322	44241	08011M	PARTICIPANT	\N	PRESENT	0
44323	44241	04036E	PARTICIPANT	\N	PRESENT	0
44324	44241	14069U	PARTICIPANT	\N	PRESENT	0
44325	44241	86044G	PARTICIPANT	\N	PRESENT	0
44326	44241	14223L	PARTICIPANT	\N	PRESENT	0
44327	44241	11101A	PARTICIPANT	\N	PRESENT	0
44328	44241	98024R	PARTICIPANT	\N	PRESENT	0
44329	44241	95030B	PARTICIPANT	\N	PRESENT	0
44331	44241	14215L	PARTICIPANT	\N	PRESENT	0
44333	44241	14087W	PARTICIPANT	\N	PRESENT	0
44334	44241	04048J	PARTICIPANT	\N	PRESENT	0
44335	44241	04057K	PARTICIPANT	\N	PRESENT	0
44336	44241	11057P	PARTICIPANT	\N	PRESENT	0
44337	44241	95015C	PARTICIPANT	\N	PRESENT	0
44338	44241	01016M	PARTICIPANT	\N	PRESENT	0
44339	44241	11103C	PARTICIPANT	\N	PRESENT	0
44340	44241	04081K	PARTICIPANT	\N	PRESENT	0
44341	44241	08055A	PARTICIPANT	\N	PRESENT	0
44342	44241	14271U	PARTICIPANT	\N	PRESENT	0
44343	44241	98023Q	PARTICIPANT	\N	PRESENT	0
44344	44241	08028W	PARTICIPANT	\N	PRESENT	0
44345	44241	14157T	PARTICIPANT	\N	PRESENT	0
44346	44241	08012N	PARTICIPANT	\N	PRESENT	0
44347	44241	11105E	PARTICIPANT	\N	PRESENT	0
44348	44241	14173T	PARTICIPANT	\N	PRESENT	0
44349	44241	08068F	PARTICIPANT	\N	PRESENT	0
44350	44241	04041B	PARTICIPANT	\N	PRESENT	0
44351	44241	11015D	PARTICIPANT	\N	PRESENT	0
44352	44241	08053X	PARTICIPANT	\N	PRESENT	0
44353	44241	87003B	PARTICIPANT	\N	PRESENT	0
44354	44241	95037J	PARTICIPANT	\N	PRESENT	0
44355	44241	04034C	PARTICIPANT	\N	PRESENT	0
44356	44241	04042C	PARTICIPANT	\N	PRESENT	0
44357	44241	83047W	PARTICIPANT	\N	PRESENT	0
44358	44241	14097Y	PARTICIPANT	\N	PRESENT	0
44359	44241	01057W	PARTICIPANT	\N	PRESENT	0
44360	44241	14001X	PARTICIPANT	\N	PRESENT	0
44361	44241	98029W	PARTICIPANT	\N	PRESENT	0
44362	44241	14147R	PARTICIPANT	\N	PRESENT	0
44363	44241	08061X	PARTICIPANT	\N	PRESENT	0
44364	44241	11097X	PARTICIPANT	\N	PRESENT	0
44365	44241	08047A	PARTICIPANT	\N	PRESENT	0
44366	44241	92039X	PARTICIPANT	\N	PRESENT	0
44367	44241	14085U	PARTICIPANT	\N	PRESENT	0
44369	44241	11106F	PARTICIPANT	\N	PRESENT	0
44370	44241	14265W	PARTICIPANT	\N	PRESENT	0
44371	44241	14081Q	PARTICIPANT	\N	PRESENT	0
44384	44241	11037K	PARTICIPANT	\N	PRESENT	0
44373	44241	04045F	PARTICIPANT	\N	PRESENT	0
44374	44241	11066Q	PARTICIPANT	\N	PRESENT	0
44375	44241	11026G	PARTICIPANT	\N	PRESENT	0
44376	44241	04092N	PARTICIPANT	\N	PRESENT	0
44377	44241	00003C	PARTICIPANT	\N	PRESENT	0
44378	44241	07034Q	PARTICIPANT	\N	PRESENT	0
44379	44241	08024S	PARTICIPANT	\N	PRESENT	0
44380	44241	14225N	PARTICIPANT	\N	PRESENT	0
44381	44241	08073C	PARTICIPANT	\N	PRESENT	0
44382	44241	92031P	PARTICIPANT	\N	PRESENT	0
44383	44241	14037X	PARTICIPANT	\N	PRESENT	0
44385	44241	14013P	PARTICIPANT	\N	PRESENT	0
44386	44241	11034G	PARTICIPANT	\N	PRESENT	0
44387	44241	04054G	PARTICIPANT	\N	PRESENT	0
44388	44241	07029T	PARTICIPANT	\N	PRESENT	0
44389	44241	08043V	PARTICIPANT	\N	PRESENT	0
44390	44241	11049P	PARTICIPANT	\N	PRESENT	0
44391	44241	08051V	PARTICIPANT	\N	PRESENT	0
44392	44241	08049C	PARTICIPANT	\N	PRESENT	0
44393	44241	08022Q	PARTICIPANT	\N	PRESENT	0
44394	44241	01003G	PARTICIPANT	\N	PRESENT	0
44395	44241	14041T	PARTICIPANT	\N	PRESENT	0
44396	44241	14261S	PARTICIPANT	\N	PRESENT	0
44397	44241	08034U	PARTICIPANT	\N	PRESENT	0
44398	44241	98005N	PARTICIPANT	\N	PRESENT	0
44399	44241	11046L	PARTICIPANT	\N	PRESENT	0
44400	44241	01058X	PARTICIPANT	\N	PRESENT	0
44401	44241	01037S	PARTICIPANT	\N	PRESENT	0
44402	44241	14105F	PARTICIPANT	\N	PRESENT	0
44403	44241	11053K	PARTICIPANT	\N	PRESENT	0
44404	44241	04080J	PARTICIPANT	\N	PRESENT	0
44405	44241	14205J	PARTICIPANT	\N	PRESENT	0
44406	44241	08019V	PARTICIPANT	\N	PRESENT	0
44407	44241	11093T	PARTICIPANT	\N	PRESENT	0
44408	44241	14267Y	PARTICIPANT	\N	PRESENT	0
44409	44241	98021N	PARTICIPANT	\N	PRESENT	0
44410	44241	07024N	PARTICIPANT	\N	PRESENT	0
44411	44241	14227Q	PARTICIPANT	\N	PRESENT	0
44412	44241	90003B	PARTICIPANT	\N	PRESENT	0
44413	44241	14121F	PARTICIPANT	\N	PRESENT	0
44414	44241	96004D	PARTICIPANT	\N	PRESENT	0
44415	44241	08017T	PARTICIPANT	\N	PRESENT	0
44416	44241	14107H	PARTICIPANT	\N	PRESENT	0
44417	44241	04035D	PARTICIPANT	\N	PRESENT	0
44418	44241	14079W	PARTICIPANT	\N	PRESENT	0
44419	44241	98022P	PARTICIPANT	\N	PRESENT	0
44420	44241	14241N	PARTICIPANT	\N	PRESENT	0
44421	44241	97011G	PARTICIPANT	\N	PRESENT	0
44422	44241	08065C	PARTICIPANT	\N	PRESENT	0
44423	44241	11027H	PARTICIPANT	\N	PRESENT	0
44424	44241	14135M	PARTICIPANT	\N	PRESENT	0
44425	44241	11033F	PARTICIPANT	\N	PRESENT	0
44426	44241	14175V	PARTICIPANT	\N	PRESENT	0
44427	44241	14151M	PARTICIPANT	\N	PRESENT	0
44428	44241	14209N	PARTICIPANT	\N	PRESENT	0
44429	44241	92015P	PARTICIPANT	\N	PRESENT	0
44430	44241	11088W	PARTICIPANT	\N	PRESENT	0
44431	44241	11014C	PARTICIPANT	\N	PRESENT	0
44432	44241	04078Q	PARTICIPANT	\N	PRESENT	0
44433	44241	01028R	PARTICIPANT	\N	PRESENT	0
44434	44241	89029V	PARTICIPANT	\N	PRESENT	0
44435	44241	11036J	PARTICIPANT	\N	PRESENT	0
44436	44241	01048V	PARTICIPANT	\N	PRESENT	0
44437	44241	11031D	PARTICIPANT	\N	PRESENT	0
44438	44241	98053W	PARTICIPANT	\N	PRESENT	0
44439	44241	98050T	PARTICIPANT	\N	PRESENT	0
44440	44241	04085P	PARTICIPANT	\N	PRESENT	0
44441	44241	08042U	PARTICIPANT	\N	PRESENT	0
44442	44241	04053F	PARTICIPANT	\N	PRESENT	0
44443	44241	04038G	PARTICIPANT	\N	PRESENT	0
44444	44241	14031R	PARTICIPANT	\N	PRESENT	0
44445	44241	14159V	PARTICIPANT	\N	PRESENT	0
44446	44241	14259Y	PARTICIPANT	\N	PRESENT	0
44447	44241	14034U	PARTICIPANT	\N	PRESENT	0
44448	44241	14038Y	PARTICIPANT	\N	PRESENT	0
44449	44241	14133K	PARTICIPANT	\N	PRESENT	0
44450	44241	11082Q	PARTICIPANT	\N	PRESENT	0
44451	44241	14231L	PARTICIPANT	\N	PRESENT	0
44452	44241	01008M	PARTICIPANT	\N	PRESENT	0
44453	44241	14073Q	PARTICIPANT	\N	PRESENT	0
44454	44241	77002U	PARTICIPANT	\N	PRESENT	0
44455	44241	01014K	PARTICIPANT	\N	PRESENT	0
44456	44241	04071H	PARTICIPANT	\N	PRESENT	0
44457	44241	11111C	PARTICIPANT	\N	PRESENT	0
44458	44241	98042T	PARTICIPANT	\N	PRESENT	0
44459	44241	04070G	PARTICIPANT	\N	PRESENT	0
44460	44241	04074L	PARTICIPANT	\N	PRESENT	0
44461	44241	11090Q	PARTICIPANT	\N	PRESENT	0
44462	44241	14083S	PARTICIPANT	\N	PRESENT	0
44463	44241	07004J	PARTICIPANT	\N	PRESENT	0
44464	44241	01034P	PARTICIPANT	\N	PRESENT	0
44465	44241	04089T	PARTICIPANT	\N	PRESENT	0
44466	44241	14179A	PARTICIPANT	\N	PRESENT	0
44467	44241	92040Q	PARTICIPANT	\N	PRESENT	0
44468	44241	14255U	PARTICIPANT	\N	PRESENT	0
44469	44241	11070L	PARTICIPANT	\N	PRESENT	0
44470	44241	01047U	PARTICIPANT	\N	PRESENT	0
44471	44241	04088S	PARTICIPANT	\N	PRESENT	0
44472	44241	01024M	PARTICIPANT	\N	PRESENT	0
44473	44241	08056B	PARTICIPANT	\N	PRESENT	0
44474	44241	11030C	PARTICIPANT	\N	PRESENT	0
44475	44241	01007L	PARTICIPANT	\N	PRESENT	0
44476	44241	14327T	PARTICIPANT	\N	PRESENT	0
44477	44241	95059Q	PARTICIPANT	\N	PRESENT	0
44478	44241	11084S	PARTICIPANT	\N	PRESENT	0
44479	44241	14217N	PARTICIPANT	\N	PRESENT	0
44480	44241	80027E	PARTICIPANT	\N	PRESENT	0
33334	33147	14187A	PARTICIPANT	\N	PRESENT	0
33335	33147	11104D	PARTICIPANT	\N	PRESENT	0
33336	33147	14087W	PARTICIPANT	\N	PRESENT	0
33337	33147	04045F	PARTICIPANT	\N	PRESENT	0
33338	33147	11012A	PARTICIPANT	\N	PRESENT	0
33339	33147	14275Y	PARTICIPANT	\N	PRESENT	0
33340	33147	14034U	PARTICIPANT	\N	PRESENT	0
33341	33147	14247U	PARTICIPANT	\N	PRESENT	0
33342	33147	11064N	PARTICIPANT	\N	PRESENT	0
33343	33147	11110B	PARTICIPANT	\N	PRESENT	0
33412	33345	04053F	PARTICIPANT	\N	PRESENT	0
33476	33345	99004R	PARTICIPANT	\N	PRESENT	0
33477	33345	98024R	PARTICIPANT	\N	PRESENT	0
33478	33345	95031C	PARTICIPANT	\N	PRESENT	0
33479	33345	08028W	PARTICIPANT	\N	PRESENT	0
33480	33345	08041T	PARTICIPANT	\N	PRESENT	0
33481	33345	14223L	PARTICIPANT	\N	PRESENT	0
33482	33345	14031R	PARTICIPANT	\N	PRESENT	0
33483	33345	14251Q	PARTICIPANT	\N	PRESENT	0
33484	33345	11049P	PARTICIPANT	\N	PRESENT	0
33485	33345	07026Q	PARTICIPANT	\N	PRESENT	0
33486	33345	14191V	PARTICIPANT	\N	PRESENT	0
33487	33345	14173T	PARTICIPANT	\N	PRESENT	0
33489	33345	08019V	PARTICIPANT	\N	PRESENT	0
33491	33345	11088W	PARTICIPANT	\N	PRESENT	0
33492	33345	89029V	PARTICIPANT	\N	PRESENT	0
33493	33345	14227Q	PARTICIPANT	\N	PRESENT	0
33494	33345	04097T	PARTICIPANT	\N	PRESENT	0
33495	33345	11103C	PARTICIPANT	\N	PRESENT	0
33496	33345	98035U	PARTICIPANT	\N	PRESENT	0
33497	33345	14267Y	PARTICIPANT	\N	PRESENT	0
33498	33345	08052W	PARTICIPANT	\N	PRESENT	0
33499	33345	08048B	PARTICIPANT	\N	PRESENT	0
33500	33345	04088S	PARTICIPANT	\N	PRESENT	0
33501	33345	11060J	PARTICIPANT	\N	PRESENT	0
33502	33345	08025T	PARTICIPANT	\N	PRESENT	0
33503	33345	14215L	PARTICIPANT	\N	PRESENT	0
33504	33345	08016S	PARTICIPANT	\N	PRESENT	0
33505	33345	14217N	PARTICIPANT	\N	PRESENT	0
33506	33345	01015L	PARTICIPANT	\N	PRESENT	0
33507	33345	01019Q	PARTICIPANT	\N	PRESENT	0
33508	33345	11054L	PARTICIPANT	\N	PRESENT	0
33509	33345	04066L	PARTICIPANT	\N	PRESENT	0
33510	33345	11084S	PARTICIPANT	\N	PRESENT	0
33511	33345	01060R	PARTICIPANT	\N	PRESENT	0
33512	33345	11091R	PARTICIPANT	\N	PRESENT	0
33513	33345	80013X	PARTICIPANT	\N	PRESENT	0
33514	33345	04059M	PARTICIPANT	\N	PRESENT	0
33515	33345	98023Q	PARTICIPANT	\N	PRESENT	0
33516	33345	14085U	PARTICIPANT	\N	PRESENT	0
33517	33345	14273W	PARTICIPANT	\N	PRESENT	0
33518	33345	14081Q	PARTICIPANT	\N	PRESENT	0
33519	33345	08055A	PARTICIPANT	\N	PRESENT	0
33520	33345	92040Q	PARTICIPANT	\N	PRESENT	0
33521	33345	01013J	PARTICIPANT	\N	PRESENT	0
33522	33345	14133K	PARTICIPANT	\N	PRESENT	0
33523	33345	14121F	PARTICIPANT	\N	PRESENT	0
33524	33345	07029T	PARTICIPANT	\N	PRESENT	0
33525	33345	11055M	PARTICIPANT	\N	PRESENT	0
33526	33345	01034P	PARTICIPANT	\N	PRESENT	0
33527	33345	14275Y	PARTICIPANT	\N	PRESENT	0
33528	33345	01037S	PARTICIPANT	\N	PRESENT	0
33529	33345	11093T	PARTICIPANT	\N	PRESENT	0
33530	33345	14281W	PARTICIPANT	\N	PRESENT	0
33531	33345	14235Q	PARTICIPANT	\N	PRESENT	0
33532	33345	95041E	PARTICIPANT	\N	PRESENT	0
33533	33345	04095R	PARTICIPANT	\N	PRESENT	0
33534	33345	04036E	PARTICIPANT	\N	PRESENT	0
33535	33345	11067R	PARTICIPANT	\N	PRESENT	0
33536	33345	10006L	PARTICIPANT	\N	PRESENT	0
33537	33345	08012N	PARTICIPANT	\N	PRESENT	0
33538	33345	14063N	PARTICIPANT	\N	PRESENT	0
33539	33345	95030B	PARTICIPANT	\N	PRESENT	0
33540	33345	04034C	PARTICIPANT	\N	PRESENT	0
33541	33345	11101A	PARTICIPANT	\N	PRESENT	0
33542	33345	08043V	PARTICIPANT	\N	PRESENT	0
33543	33345	11077T	PARTICIPANT	\N	PRESENT	0
33544	33345	14147R	PARTICIPANT	\N	PRESENT	0
33545	33345	14265W	PARTICIPANT	\N	PRESENT	0
33546	33345	14211G	PARTICIPANT	\N	PRESENT	0
33547	33345	08018U	PARTICIPANT	\N	PRESENT	0
33548	33345	11097X	PARTICIPANT	\N	PRESENT	0
33549	33345	11048N	PARTICIPANT	\N	PRESENT	0
33550	33345	98050T	PARTICIPANT	\N	PRESENT	0
33551	33345	14079W	PARTICIPANT	\N	PRESENT	0
33552	33345	04057K	PARTICIPANT	\N	PRESENT	0
33553	33345	08065C	PARTICIPANT	\N	PRESENT	0
33554	33345	87003B	PARTICIPANT	\N	PRESENT	0
33555	33345	08011M	PARTICIPANT	\N	PRESENT	0
33556	33345	11031D	PARTICIPANT	\N	PRESENT	0
33557	33345	11063M	PARTICIPANT	\N	PRESENT	0
33558	33345	14237S	PARTICIPANT	\N	PRESENT	0
33559	33345	04081K	PARTICIPANT	\N	PRESENT	0
33560	33345	04086Q	PARTICIPANT	\N	PRESENT	0
33561	33345	08069G	PARTICIPANT	\N	PRESENT	0
33562	33345	11100Y	PARTICIPANT	\N	PRESENT	0
33563	33345	04092N	PARTICIPANT	\N	PRESENT	0
33564	33345	95059Q	PARTICIPANT	\N	PRESENT	0
33565	33345	07024N	PARTICIPANT	\N	PRESENT	0
33566	33345	98046X	PARTICIPANT	\N	PRESENT	0
33567	33345	97011G	PARTICIPANT	\N	PRESENT	0
33568	33345	98005N	PARTICIPANT	\N	PRESENT	0
33569	33345	08034U	PARTICIPANT	\N	PRESENT	0
33570	33345	11098Y	PARTICIPANT	\N	PRESENT	0
33571	33345	11040E	PARTICIPANT	\N	PRESENT	0
33572	33345	11034G	PARTICIPANT	\N	PRESENT	0
33573	33345	08042U	PARTICIPANT	\N	PRESENT	0
33574	33345	95062K	PARTICIPANT	\N	PRESENT	0
33575	33345	01059Y	PARTICIPANT	\N	PRESENT	0
33576	33345	08015R	PARTICIPANT	\N	PRESENT	0
33577	33345	12041X	PARTICIPANT	\N	PRESENT	0
33578	33345	04085P	PARTICIPANT	\N	PRESENT	0
33579	33345	11071M	PARTICIPANT	\N	PRESENT	0
33580	33345	11030C	PARTICIPANT	\N	PRESENT	0
33581	33345	04048J	PARTICIPANT	\N	PRESENT	0
33582	33345	86044G	PARTICIPANT	\N	PRESENT	0
33583	33345	14271U	PARTICIPANT	\N	PRESENT	0
33584	33345	95015C	PARTICIPANT	\N	PRESENT	0
33585	33345	04041B	PARTICIPANT	\N	PRESENT	0
33586	33345	01056V	PARTICIPANT	\N	PRESENT	0
33587	33345	01022K	PARTICIPANT	\N	PRESENT	0
33588	33345	14033T	PARTICIPANT	\N	PRESENT	0
33589	33345	92020L	PARTICIPANT	\N	PRESENT	0
33590	33345	11043H	PARTICIPANT	\N	PRESENT	0
33591	33345	01058X	PARTICIPANT	\N	PRESENT	0
33592	33345	14107H	PARTICIPANT	\N	PRESENT	0
33593	33345	08047A	PARTICIPANT	\N	PRESENT	0
33594	33345	14051J	PARTICIPANT	\N	PRESENT	0
33595	33345	96004D	PARTICIPANT	\N	PRESENT	0
33596	33345	14093U	PARTICIPANT	\N	PRESENT	0
33597	33345	04033B	PARTICIPANT	\N	PRESENT	0
33598	33345	11044J	PARTICIPANT	\N	PRESENT	0
33599	33345	80027E	PARTICIPANT	\N	PRESENT	0
33600	33345	04074L	PARTICIPANT	\N	PRESENT	0
33601	33345	98029W	PARTICIPANT	\N	PRESENT	0
33602	33345	14225N	PARTICIPANT	\N	PRESENT	0
33603	33345	01061S	PARTICIPANT	\N	PRESENT	0
33604	33345	83042R	PARTICIPANT	\N	PRESENT	0
33605	33345	14229S	PARTICIPANT	\N	PRESENT	0
33606	33345	01057W	PARTICIPANT	\N	PRESENT	0
33607	33345	95037J	PARTICIPANT	\N	PRESENT	0
33608	33345	08058D	PARTICIPANT	\N	PRESENT	0
33609	33345	14329V	PARTICIPANT	\N	PRESENT	0
33610	33345	14105F	PARTICIPANT	\N	PRESENT	0
33611	33345	14109K	PARTICIPANT	\N	PRESENT	0
33612	33345	14028W	PARTICIPANT	\N	PRESENT	0
33613	33345	11010L	PARTICIPANT	\N	PRESENT	0
33614	33345	08014Q	PARTICIPANT	\N	PRESENT	0
33615	33345	11095V	PARTICIPANT	\N	PRESENT	0
33616	33345	14042U	PARTICIPANT	\N	PRESENT	0
33617	33345	14001X	PARTICIPANT	\N	PRESENT	0
33618	33345	14213J	PARTICIPANT	\N	PRESENT	0
33619	33345	14167V	PARTICIPANT	\N	PRESENT	0
33620	33345	14135M	PARTICIPANT	\N	PRESENT	0
33621	33345	04056J	PARTICIPANT	\N	PRESENT	0
33622	33345	10015M	PARTICIPANT	\N	PRESENT	0
33623	33345	11042G	PARTICIPANT	\N	PRESENT	0
33624	33345	08060W	PARTICIPANT	\N	PRESENT	0
33625	33345	13002U	PARTICIPANT	\N	PRESENT	0
33626	33345	14053L	PARTICIPANT	\N	PRESENT	0
33627	33345	11112D	PARTICIPANT	\N	PRESENT	0
33628	33345	14199E	PARTICIPANT	\N	PRESENT	0
33629	33345	04042C	PARTICIPANT	\N	PRESENT	0
33630	33345	92045V	PARTICIPANT	\N	PRESENT	0
33631	33345	11026G	PARTICIPANT	\N	PRESENT	0
33632	33345	01031L	PARTICIPANT	\N	PRESENT	0
33633	33345	11015D	PARTICIPANT	\N	PRESENT	0
48075	47942	14201E	PARTICIPANT	\N	PRESENT	0
48076	47942	08010L	PARTICIPANT	\N	PRESENT	0
48077	47942	96004D	PARTICIPANT	\N	PRESENT	0
48078	47942	98018T	PARTICIPANT	\N	PRESENT	0
48079	47942	01019Q	PARTICIPANT	\N	PRESENT	0
48080	47942	11080N	PARTICIPANT	\N	PRESENT	0
48081	47942	04086Q	PARTICIPANT	\N	PRESENT	0
48082	47942	14105F	PARTICIPANT	\N	PRESENT	0
48083	47942	11100Y	PARTICIPANT	\N	PRESENT	0
48084	47942	11048N	PARTICIPANT	\N	PRESENT	0
48085	47942	10006L	PARTICIPANT	\N	PRESENT	0
48086	47942	98023Q	PARTICIPANT	\N	PRESENT	0
48087	47942	14069U	PARTICIPANT	\N	PRESENT	0
48088	47942	04047H	PARTICIPANT	\N	PRESENT	0
48089	47942	04043D	PARTICIPANT	\N	PRESENT	0
48090	47942	11044J	PARTICIPANT	\N	PRESENT	0
48091	47942	92018S	PARTICIPANT	\N	PRESENT	0
48092	47942	95035G	PARTICIPANT	\N	PRESENT	0
48093	47942	11031D	PARTICIPANT	\N	PRESENT	0
48094	47942	14227Q	PARTICIPANT	\N	PRESENT	0
48095	47942	92031P	PARTICIPANT	\N	PRESENT	0
48096	47942	14071N	PARTICIPANT	\N	PRESENT	0
48097	47942	11040E	PARTICIPANT	\N	PRESENT	0
48098	47942	04033B	PARTICIPANT	\N	PRESENT	0
48099	47942	04054G	PARTICIPANT	\N	PRESENT	0
48100	47942	01059Y	PARTICIPANT	\N	PRESENT	0
48101	47942	04041B	PARTICIPANT	\N	PRESENT	0
48102	47942	04085P	PARTICIPANT	\N	PRESENT	0
48103	47942	11039M	PARTICIPANT	\N	PRESENT	0
48104	47942	14259Y	PARTICIPANT	\N	PRESENT	0
48105	47942	01016M	PARTICIPANT	\N	PRESENT	0
48106	47942	98035U	PARTICIPANT	\N	PRESENT	0
48107	47942	92015P	PARTICIPANT	\N	PRESENT	0
48108	47942	14329V	PARTICIPANT	\N	PRESENT	0
48109	47942	98046X	PARTICIPANT	\N	PRESENT	0
48110	47942	01011G	PARTICIPANT	\N	PRESENT	0
48111	47942	11103C	PARTICIPANT	\N	PRESENT	0
48112	47942	11027H	PARTICIPANT	\N	PRESENT	0
48113	47942	95067Q	PARTICIPANT	\N	PRESENT	0
48114	47942	04066L	PARTICIPANT	\N	PRESENT	0
48115	47942	04042C	PARTICIPANT	\N	PRESENT	0
48116	47942	08043V	PARTICIPANT	\N	PRESENT	0
48117	47942	01056V	PARTICIPANT	\N	PRESENT	0
48118	47942	11105E	PARTICIPANT	\N	PRESENT	0
48119	47942	14028W	PARTICIPANT	\N	PRESENT	0
48120	47942	08053X	PARTICIPANT	\N	PRESENT	0
48121	47942	95030B	PARTICIPANT	\N	PRESENT	0
48122	47942	99004R	PARTICIPANT	\N	PRESENT	0
48123	47942	08058D	PARTICIPANT	\N	PRESENT	0
48124	47942	01028R	PARTICIPANT	\N	PRESENT	0
48125	47942	11046L	PARTICIPANT	\N	PRESENT	0
48126	47942	98029W	PARTICIPANT	\N	PRESENT	0
48127	47942	14031R	PARTICIPANT	\N	PRESENT	0
48128	47942	14014Q	PARTICIPANT	\N	PRESENT	0
48129	47942	11042G	PARTICIPANT	\N	PRESENT	0
48130	47942	14135M	PARTICIPANT	\N	PRESENT	0
48131	47942	14207L	PARTICIPANT	\N	PRESENT	0
48132	47942	11074Q	PARTICIPANT	\N	PRESENT	0
48133	47942	14229S	PARTICIPANT	\N	PRESENT	0
48134	47942	11077T	PARTICIPANT	\N	PRESENT	0
48135	47942	11014C	PARTICIPANT	\N	PRESENT	0
48136	47942	04092N	PARTICIPANT	\N	PRESENT	0
48137	47942	12042Y	PARTICIPANT	\N	PRESENT	0
48138	47942	14225N	PARTICIPANT	\N	PRESENT	0
48139	47942	04044E	PARTICIPANT	\N	PRESENT	0
48140	47942	11015D	PARTICIPANT	\N	PRESENT	0
48141	47942	99002P	PARTICIPANT	\N	PRESENT	0
48142	47942	11049P	PARTICIPANT	\N	PRESENT	0
48143	47942	11067R	PARTICIPANT	\N	PRESENT	0
48144	47942	04094Q	PARTICIPANT	\N	PRESENT	0
48145	47942	14147R	PARTICIPANT	\N	PRESENT	0
48146	47942	14123H	PARTICIPANT	\N	PRESENT	0
48147	47942	08024S	PARTICIPANT	\N	PRESENT	0
48148	47942	08038Y	PARTICIPANT	\N	PRESENT	0
48149	47942	14119M	PARTICIPANT	\N	PRESENT	0
48150	47942	04053F	PARTICIPANT	\N	PRESENT	0
48151	47942	04059M	PARTICIPANT	\N	PRESENT	0
48152	47942	14038Y	PARTICIPANT	\N	PRESENT	0
48153	47942	04049K	PARTICIPANT	\N	PRESENT	0
48154	47942	13002U	PARTICIPANT	\N	PRESENT	0
48155	47942	14269B	PARTICIPANT	\N	PRESENT	0
48156	47942	14253S	PARTICIPANT	\N	PRESENT	0
48157	47942	11107G	PARTICIPANT	\N	PRESENT	0
48158	47942	11060J	PARTICIPANT	\N	PRESENT	0
48159	47942	11055M	PARTICIPANT	\N	PRESENT	0
48160	47942	95062K	PARTICIPANT	\N	PRESENT	0
48161	47942	01044R	PARTICIPANT	\N	PRESENT	0
48162	47942	01058X	PARTICIPANT	\N	PRESENT	0
48163	47942	11083R	PARTICIPANT	\N	PRESENT	0
48164	47942	14251Q	PARTICIPANT	\N	PRESENT	0
48165	47942	11081P	PARTICIPANT	\N	PRESENT	0
48166	47942	11097X	PARTICIPANT	\N	PRESENT	0
48167	47942	01003G	PARTICIPANT	\N	PRESENT	0
48168	47942	11091R	PARTICIPANT	\N	PRESENT	0
48169	47942	01014K	PARTICIPANT	\N	PRESENT	0
48170	47942	95059Q	PARTICIPANT	\N	PRESENT	0
48171	47942	11012A	PARTICIPANT	\N	PRESENT	0
48172	47942	04038G	PARTICIPANT	\N	PRESENT	0
48173	47942	08051V	PARTICIPANT	\N	PRESENT	0
48174	47942	05008E	PARTICIPANT	\N	PRESENT	0
48175	47942	14257W	PARTICIPANT	\N	PRESENT	0
48176	47942	95063L	PARTICIPANT	\N	PRESENT	0
48177	47942	08022Q	PARTICIPANT	\N	PRESENT	0
48178	47942	04078Q	PARTICIPANT	\N	PRESENT	0
48179	47942	08049C	PARTICIPANT	\N	PRESENT	0
48180	47942	88008L	PARTICIPANT	\N	PRESENT	0
48181	47942	08042U	PARTICIPANT	\N	PRESENT	0
48182	47942	08031R	PARTICIPANT	\N	PRESENT	0
48183	47942	11110B	PARTICIPANT	\N	PRESENT	0
48184	47942	05012A	PARTICIPANT	\N	PRESENT	0
48185	47942	95049N	PARTICIPANT	\N	PRESENT	0
48186	47942	08015R	PARTICIPANT	\N	PRESENT	0
48187	47942	08061X	PARTICIPANT	\N	PRESENT	0
48188	47942	01057W	PARTICIPANT	\N	PRESENT	0
48189	47942	04077P	PARTICIPANT	\N	PRESENT	0
48190	47942	01034P	PARTICIPANT	\N	PRESENT	0
48191	47942	01031L	PARTICIPANT	\N	PRESENT	0
48192	47942	14061L	PARTICIPANT	\N	PRESENT	0
48193	47942	11099A	PARTICIPANT	\N	PRESENT	0
48194	47942	07029T	PARTICIPANT	\N	PRESENT	0
48195	47942	04080J	PARTICIPANT	\N	PRESENT	0
48196	47942	08047A	PARTICIPANT	\N	PRESENT	0
48197	47942	14255U	PARTICIPANT	\N	PRESENT	0
48198	47942	11053K	PARTICIPANT	\N	PRESENT	0
48199	47942	11064N	PARTICIPANT	\N	PRESENT	0
48200	47942	07024N	PARTICIPANT	\N	PRESENT	0
48201	47942	11029K	PARTICIPANT	\N	PRESENT	0
48202	47942	14103D	PARTICIPANT	\N	PRESENT	0
48203	47942	14267Y	PARTICIPANT	\N	PRESENT	0
48204	47942	09001P	PARTICIPANT	\N	PRESENT	0
48205	47942	11093T	PARTICIPANT	\N	PRESENT	0
48206	47942	14073Q	PARTICIPANT	\N	PRESENT	0
48207	47942	04057K	PARTICIPANT	\N	PRESENT	0
48208	47942	14179A	PARTICIPANT	\N	PRESENT	0
48209	47942	14231L	PARTICIPANT	\N	PRESENT	0
48210	47942	14083S	PARTICIPANT	\N	PRESENT	0
48211	47942	04089T	PARTICIPANT	\N	PRESENT	0
48212	47942	97011G	PARTICIPANT	\N	PRESENT	0
48213	47942	08044W	PARTICIPANT	\N	PRESENT	0
48214	47942	07004J	PARTICIPANT	\N	PRESENT	0
48215	47942	14037X	PARTICIPANT	\N	PRESENT	0
48216	47942	01047U	PARTICIPANT	\N	PRESENT	0
48217	47942	04070G	PARTICIPANT	\N	PRESENT	0
48218	47942	01024M	PARTICIPANT	\N	PRESENT	0
48219	47942	14213J	PARTICIPANT	\N	PRESENT	0
48073	47942	11069T	PARTICIPANT	\N	PRESENT	0
48074	47942	08028W	PARTICIPANT	\N	PRESENT	0
48220	47942	04040A	PARTICIPANT	\N	PRESENT	0
48221	47942	01025N	PARTICIPANT	\N	PRESENT	0
48222	47942	14026U	PARTICIPANT	\N	PRESENT	0
48223	47942	14327T	PARTICIPANT	\N	PRESENT	0
48224	47942	01043Q	PARTICIPANT	\N	PRESENT	0
48225	47942	11071M	PARTICIPANT	\N	PRESENT	0
48226	47942	11089X	PARTICIPANT	\N	PRESENT	0
48227	47942	14093U	PARTICIPANT	\N	PRESENT	0
48228	47942	11072N	PARTICIPANT	\N	PRESENT	0
48229	47942	14265W	PARTICIPANT	\N	PRESENT	0
48231	47942	14041T	PARTICIPANT	\N	PRESENT	0
48232	47942	11090Q	PARTICIPANT	\N	PRESENT	0
48233	47942	14081Q	PARTICIPANT	\N	PRESENT	0
48234	47942	01008M	PARTICIPANT	\N	PRESENT	0
48235	47942	11033F	PARTICIPANT	\N	PRESENT	0
48236	47942	95041E	PARTICIPANT	\N	PRESENT	0
48237	47942	08025T	PARTICIPANT	\N	PRESENT	0
48238	47942	77002U	PARTICIPANT	\N	PRESENT	0
48239	47942	14151M	PARTICIPANT	\N	PRESENT	0
48240	47942	14263U	PARTICIPANT	\N	PRESENT	0
31260	31196	14041T	PARTICIPANT	\N	PRESENT	0
31261	31196	14269B	PARTICIPANT	\N	PRESENT	0
31262	31196	14053L	PARTICIPANT	\N	PRESENT	0
31263	31196	04067M	PARTICIPANT	\N	PRESENT	0
31264	31196	14034U	PARTICIPANT	\N	PRESENT	0
31265	31196	14071N	PARTICIPANT	\N	PRESENT	0
31266	31196	08062Y	PARTICIPANT	\N	PRESENT	0
31300	31197	08024S	PARTICIPANT	\N	PRESENT	0
31268	31196	11053K	PARTICIPANT	\N	PRESENT	0
31269	31196	01003G	PARTICIPANT	\N	PRESENT	0
31270	31196	11103C	PARTICIPANT	\N	PRESENT	0
31271	31196	95041E	PARTICIPANT	\N	PRESENT	0
31272	31196	92045V	PARTICIPANT	\N	PRESENT	0
31273	31196	01041N	PARTICIPANT	\N	PRESENT	0
31274	31196	14265W	PARTICIPANT	\N	PRESENT	0
31275	31196	11112D	PARTICIPANT	\N	PRESENT	0
31346	31197	11063M	PARTICIPANT	\N	PRESENT	0
31347	31197	14269B	PARTICIPANT	\N	PRESENT	0
31302	31197	11093T	PARTICIPANT	\N	PRESENT	0
31303	31197	08052W	PARTICIPANT	\N	PRESENT	0
31304	31197	01034P	PARTICIPANT	\N	PRESENT	0
32037	31687	14231L	PARTICIPANT	\N	PRESENT	0
31349	31197	08041T	PARTICIPANT	\N	PRESENT	0
31307	31197	04092N	PARTICIPANT	\N	PRESENT	0
31308	31197	11055M	PARTICIPANT	\N	PRESENT	0
31348	31197	14227Q	PARTICIPANT	\N	PRESENT	0
31310	31197	14223L	PARTICIPANT	\N	PRESENT	0
31311	31197	14213J	PARTICIPANT	\N	PRESENT	0
31312	31197	14037X	PARTICIPANT	\N	PRESENT	0
32038	31687	14030Q	PARTICIPANT	\N	PRESENT	0
31314	31197	12042Y	PARTICIPANT	\N	PRESENT	0
32039	31687	14201E	PARTICIPANT	\N	PRESENT	0
31316	31197	98024R	PARTICIPANT	\N	PRESENT	0
31317	31197	01059Y	PARTICIPANT	\N	PRESENT	0
32040	31687	11043H	PARTICIPANT	\N	PRESENT	0
31319	31197	00003C	PARTICIPANT	\N	PRESENT	0
31320	31197	01046T	PARTICIPANT	\N	PRESENT	0
31321	31197	04053F	PARTICIPANT	\N	PRESENT	0
32041	31687	04059M	PARTICIPANT	\N	PRESENT	0
32042	31687	14221J	PARTICIPANT	\N	PRESENT	0
32043	31687	95015C	PARTICIPANT	\N	PRESENT	0
31325	31197	11031D	PARTICIPANT	\N	PRESENT	0
32044	31687	92020L	PARTICIPANT	\N	PRESENT	0
32045	31687	08015R	PARTICIPANT	\N	PRESENT	0
32046	31687	01044R	PARTICIPANT	\N	PRESENT	0
31329	31197	11088W	PARTICIPANT	\N	PRESENT	0
32047	31687	90003B	PARTICIPANT	\N	PRESENT	0
32048	31687	14063N	PARTICIPANT	\N	PRESENT	0
32049	31687	04088S	PARTICIPANT	\N	PRESENT	0
32160	31687	04077P	PARTICIPANT	\N	PRESENT	0
32035	31687	08043V	PARTICIPANT	\N	PRESENT	0
32051	31687	11107G	PARTICIPANT	\N	PRESENT	0
31336	31197	14071N	PARTICIPANT	\N	PRESENT	0
32052	31687	14169X	PARTICIPANT	\N	PRESENT	0
32036	31687	12042Y	PARTICIPANT	\N	PRESENT	0
32053	31687	14229S	PARTICIPANT	\N	PRESENT	0
31340	31197	11103C	PARTICIPANT	\N	PRESENT	0
32054	31687	04056J	PARTICIPANT	\N	PRESENT	0
32055	31687	87003B	PARTICIPANT	\N	PRESENT	0
31343	31197	01041N	PARTICIPANT	\N	PRESENT	0
31344	31197	14265W	PARTICIPANT	\N	PRESENT	0
32056	31687	07029T	PARTICIPANT	\N	PRESENT	0
32057	31687	01027Q	PARTICIPANT	\N	PRESENT	0
32058	31687	98029W	PARTICIPANT	\N	PRESENT	0
32059	31687	11100Y	PARTICIPANT	\N	PRESENT	0
32060	31687	99004R	PARTICIPANT	\N	PRESENT	0
32061	31687	02002K	PARTICIPANT	\N	PRESENT	0
32062	31687	08028W	PARTICIPANT	\N	PRESENT	0
32063	31687	11048N	PARTICIPANT	\N	PRESENT	0
32064	31687	14265W	PARTICIPANT	\N	PRESENT	0
32065	31687	10006L	PARTICIPANT	\N	PRESENT	0
32066	31687	95062K	PARTICIPANT	\N	PRESENT	0
32067	31687	14193X	PARTICIPANT	\N	PRESENT	0
32068	31687	14083S	PARTICIPANT	\N	PRESENT	0
32069	31687	04044E	PARTICIPANT	\N	PRESENT	0
32070	31687	01059Y	PARTICIPANT	\N	PRESENT	0
32071	31687	14071N	PARTICIPANT	\N	PRESENT	0
32072	31687	98053W	PARTICIPANT	\N	PRESENT	0
32073	31687	07026Q	PARTICIPANT	\N	PRESENT	0
32074	31687	04042C	PARTICIPANT	\N	PRESENT	0
32075	31687	01015L	PARTICIPANT	\N	PRESENT	0
32076	31687	11063M	PARTICIPANT	\N	PRESENT	0
32077	31687	11040E	PARTICIPANT	\N	PRESENT	0
32078	31687	01058X	PARTICIPANT	\N	PRESENT	0
32079	31687	77002U	PARTICIPANT	\N	PRESENT	0
32080	31687	11029K	PARTICIPANT	\N	PRESENT	0
32081	31687	11083R	PARTICIPANT	\N	PRESENT	0
32082	31687	92031P	PARTICIPANT	\N	PRESENT	0
32083	31687	04085P	PARTICIPANT	\N	PRESENT	0
32084	31687	01013J	PARTICIPANT	\N	PRESENT	0
32085	31687	14026U	PARTICIPANT	\N	PRESENT	0
32086	31687	14105F	PARTICIPANT	\N	PRESENT	0
32087	31687	08051V	PARTICIPANT	\N	PRESENT	0
32088	31687	01046T	PARTICIPANT	\N	PRESENT	0
32089	31687	14241N	PARTICIPANT	\N	PRESENT	0
32090	31687	08011M	PARTICIPANT	\N	PRESENT	0
32091	31687	01057W	PARTICIPANT	\N	PRESENT	0
32092	31687	08049C	PARTICIPANT	\N	PRESENT	0
32093	31687	14239U	PARTICIPANT	\N	PRESENT	0
32094	31687	11044J	PARTICIPANT	\N	PRESENT	0
32095	31687	88008L	PARTICIPANT	\N	PRESENT	0
32096	31687	08031R	PARTICIPANT	\N	PRESENT	0
32097	31687	14261S	PARTICIPANT	\N	PRESENT	0
32098	31687	98023Q	PARTICIPANT	\N	PRESENT	0
32099	31687	97011G	PARTICIPANT	\N	PRESENT	0
32100	31687	08022Q	PARTICIPANT	\N	PRESENT	0
32101	31687	01016M	PARTICIPANT	\N	PRESENT	0
32102	31687	08010L	PARTICIPANT	\N	PRESENT	0
32103	31687	04086Q	PARTICIPANT	\N	PRESENT	0
32104	31687	11057P	PARTICIPANT	\N	PRESENT	0
32105	31687	98018T	PARTICIPANT	\N	PRESENT	0
32106	31687	14069U	PARTICIPANT	\N	PRESENT	0
32107	31687	14235Q	PARTICIPANT	\N	PRESENT	0
32108	31687	11034G	PARTICIPANT	\N	PRESENT	0
32109	31687	11103C	PARTICIPANT	\N	PRESENT	0
32110	31687	08016S	PARTICIPANT	\N	PRESENT	0
32111	31687	14031R	PARTICIPANT	\N	PRESENT	0
32112	31687	04061F	PARTICIPANT	\N	PRESENT	0
32113	31687	12041X	PARTICIPANT	\N	PRESENT	0
32114	31687	01007L	PARTICIPANT	\N	PRESENT	0
32115	31687	08056B	PARTICIPANT	\N	PRESENT	0
32116	31687	11067R	PARTICIPANT	\N	PRESENT	0
32117	31687	11059R	PARTICIPANT	\N	PRESENT	0
32118	31687	05012A	PARTICIPANT	\N	PRESENT	0
32119	31687	11036J	PARTICIPANT	\N	PRESENT	0
32120	31687	14037X	PARTICIPANT	\N	PRESENT	0
32121	31687	11032E	PARTICIPANT	\N	PRESENT	0
32122	31687	14175V	PARTICIPANT	\N	PRESENT	0
32123	31687	11046L	PARTICIPANT	\N	PRESENT	0
32124	31687	08017T	PARTICIPANT	\N	PRESENT	0
32125	31687	04081K	PARTICIPANT	\N	PRESENT	0
32126	31687	04034C	PARTICIPANT	\N	PRESENT	0
32127	31687	14033T	PARTICIPANT	\N	PRESENT	0
32128	31687	95037J	PARTICIPANT	\N	PRESENT	0
32129	31687	14225N	PARTICIPANT	\N	PRESENT	0
32130	31687	08034U	PARTICIPANT	\N	PRESENT	0
32132	31687	14109K	PARTICIPANT	\N	PRESENT	0
32133	31687	08014Q	PARTICIPANT	\N	PRESENT	0
32134	31687	04049K	PARTICIPANT	\N	PRESENT	0
32135	31687	08068F	PARTICIPANT	\N	PRESENT	0
32136	31687	14061L	PARTICIPANT	\N	PRESENT	0
32137	31687	14257W	PARTICIPANT	\N	PRESENT	0
32138	31687	08055A	PARTICIPANT	\N	PRESENT	0
32139	31687	04092N	PARTICIPANT	\N	PRESENT	0
32140	31687	13002U	PARTICIPANT	\N	PRESENT	0
32142	31687	11112D	PARTICIPANT	\N	PRESENT	0
32143	31687	04057K	PARTICIPANT	\N	PRESENT	0
32144	31687	11074Q	PARTICIPANT	\N	PRESENT	0
32145	31687	14147R	PARTICIPANT	\N	PRESENT	0
32147	31687	01031L	PARTICIPANT	\N	PRESENT	0
32148	31687	11091R	PARTICIPANT	\N	PRESENT	0
32151	31687	01041N	PARTICIPANT	\N	PRESENT	0
32152	31687	01056V	PARTICIPANT	\N	PRESENT	0
32154	31687	11054L	PARTICIPANT	\N	PRESENT	0
32155	31687	08041T	PARTICIPANT	\N	PRESENT	0
32156	31687	11026G	PARTICIPANT	\N	PRESENT	0
32157	31687	11060J	PARTICIPANT	\N	PRESENT	0
32158	31687	95063L	PARTICIPANT	\N	PRESENT	0
32159	31687	14073Q	PARTICIPANT	\N	PRESENT	0
32161	31687	08061X	PARTICIPANT	\N	PRESENT	0
32162	31687	04053F	PARTICIPANT	\N	PRESENT	0
32164	31687	01028R	PARTICIPANT	\N	PRESENT	0
32165	31687	14157T	PARTICIPANT	\N	PRESENT	0
32167	31687	14275Y	PARTICIPANT	\N	PRESENT	0
32218	31687	01037S	PARTICIPANT	\N	PRESENT	0
32220	31687	14217N	PARTICIPANT	\N	PRESENT	0
32222	31687	11042G	PARTICIPANT	\N	PRESENT	0
32225	31687	14273W	PARTICIPANT	\N	PRESENT	0
41109	40901	11010L	PARTICIPANT	\N	EXCUSE	0
41143	41142	14211G	PARTICIPANT	\N	PRESENT	0
41144	41142	14028W	PARTICIPANT	\N	PRESENT	0
41160	41159	07024N	PARTICIPANT	\N	PRESENT	0
41161	41159	01014K	PARTICIPANT	\N	PRESENT	0
41163	41162	07024N	PARTICIPANT	\N	PRESENT	0
41164	41162	01014K	PARTICIPANT	\N	PRESENT	0
41165	41162	04040A	PARTICIPANT	\N	PRESENT	0
41167	41166	11015D	PARTICIPANT	\N	PRESENT	0
41168	41166	92031P	PARTICIPANT	\N	PRESENT	0
41173	41172	11035H	PARTICIPANT	\N	PRESENT	0
41175	41174	11035H	PARTICIPANT	\N	PRESENT	0
41179	41178	11035H	PARTICIPANT	\N	PRESENT	0
41181	41180	11035H	PARTICIPANT	\N	PRESENT	0
41183	41182	04047H	PARTICIPANT	\N	PRESENT	0
41185	41184	04047H	PARTICIPANT	\N	PRESENT	0
43921	43916	04081K	PARTICIPANT	\N	PRESENT	0
43922	43916	01013J	PARTICIPANT	\N	PRESENT	0
43923	43916	98046X	PARTICIPANT	\N	PRESENT	0
43924	43916	04034C	PARTICIPANT	\N	PRESENT	0
43925	43916	11026G	PARTICIPANT	\N	PRESENT	0
43926	43916	11042G	PARTICIPANT	\N	PRESENT	0
43927	43916	08011M	PARTICIPANT	\N	PRESENT	0
43928	43916	01031L	PARTICIPANT	\N	PRESENT	0
43929	43916	11070L	PARTICIPANT	\N	PRESENT	0
43930	43916	14219Q	PARTICIPANT	\N	PRESENT	0
43931	43916	14041T	PARTICIPANT	\N	PRESENT	0
44000	43916	04053F	PARTICIPANT	\N	PRESENT	0
43933	43916	11048N	PARTICIPANT	\N	PRESENT	0
43934	43916	14001X	PARTICIPANT	\N	PRESENT	0
43935	43916	01022K	PARTICIPANT	\N	PRESENT	0
43936	43916	95037J	PARTICIPANT	\N	PRESENT	0
43937	43916	11083R	PARTICIPANT	\N	PRESENT	0
43938	43916	98005N	PARTICIPANT	\N	PRESENT	0
43939	43916	08031R	PARTICIPANT	\N	PRESENT	0
43940	43916	08016S	PARTICIPANT	\N	PRESENT	0
43941	43916	98035U	PARTICIPANT	\N	PRESENT	0
43942	43916	14281W	PARTICIPANT	\N	PRESENT	0
43943	43916	14083S	PARTICIPANT	\N	PRESENT	0
43944	43916	01041N	PARTICIPANT	\N	PRESENT	0
43945	43916	01016M	PARTICIPANT	\N	PRESENT	0
43946	43916	14225N	PARTICIPANT	\N	PRESENT	0
43947	43916	14159V	PARTICIPANT	\N	PRESENT	0
43948	43916	04059M	PARTICIPANT	\N	PRESENT	0
43949	43916	11084S	PARTICIPANT	\N	PRESENT	0
43950	43916	11088W	PARTICIPANT	\N	PRESENT	0
43951	43916	08034U	PARTICIPANT	\N	PRESENT	0
43952	43916	14261S	PARTICIPANT	\N	PRESENT	0
43954	43916	07004J	PARTICIPANT	\N	PRESENT	0
43955	43916	99002P	PARTICIPANT	\N	PRESENT	0
43956	43916	04043D	PARTICIPANT	\N	PRESENT	0
43971	43916	08035V	PARTICIPANT	\N	PRESENT	0
43972	43916	14275Y	PARTICIPANT	\N	PRESENT	0
43973	43916	04071H	PARTICIPANT	\N	PRESENT	0
43981	43916	11031D	PARTICIPANT	\N	PRESENT	0
43982	43916	80013X	PARTICIPANT	\N	PRESENT	0
43983	43916	99004R	PARTICIPANT	\N	PRESENT	0
43999	43916	11053K	PARTICIPANT	\N	PRESENT	0
44048	43524	04034C	PARTICIPANT	\N	PRESENT	0
44049	43524	14175V	PARTICIPANT	\N	PRESENT	0
44050	43524	14041T	PARTICIPANT	\N	PRESENT	0
44051	43524	14001X	PARTICIPANT	\N	PRESENT	0
44052	43524	14225N	PARTICIPANT	\N	PRESENT	0
44053	43524	08011M	PARTICIPANT	\N	PRESENT	0
44054	43524	08031R	PARTICIPANT	\N	PRESENT	0
44055	43524	11053K	PARTICIPANT	\N	PRESENT	0
44056	43524	01013J	PARTICIPANT	\N	PRESENT	0
44057	43524	95037J	PARTICIPANT	\N	PRESENT	0
44058	43524	08016S	PARTICIPANT	\N	PRESENT	0
44059	43524	11083R	PARTICIPANT	\N	PRESENT	0
44060	43524	14219Q	PARTICIPANT	\N	PRESENT	0
44063	43524	01048V	PARTICIPANT	\N	PRESENT	0
44067	43524	11070L	PARTICIPANT	\N	PRESENT	0
44068	43524	98046X	PARTICIPANT	\N	PRESENT	0
44069	43524	11031D	PARTICIPANT	\N	PRESENT	0
44070	43524	11042G	PARTICIPANT	\N	PRESENT	0
44071	43524	14159V	PARTICIPANT	\N	PRESENT	0
44072	43524	04071H	PARTICIPANT	\N	PRESENT	0
44073	43524	98005N	PARTICIPANT	\N	PRESENT	0
44074	43524	11088W	PARTICIPANT	\N	PRESENT	0
44075	43524	04036E	PARTICIPANT	\N	PRESENT	0
44076	43524	01016M	PARTICIPANT	\N	PRESENT	0
44080	43524	08034U	PARTICIPANT	\N	PRESENT	0
44081	43524	14281W	PARTICIPANT	\N	PRESENT	0
44082	43524	08035V	PARTICIPANT	\N	PRESENT	0
44083	43524	04053F	PARTICIPANT	\N	PRESENT	0
44084	43524	01022K	PARTICIPANT	\N	PRESENT	0
44085	43524	14261S	PARTICIPANT	\N	PRESENT	0
44086	43524	07029T	PARTICIPANT	\N	PRESENT	0
44087	43524	99004R	PARTICIPANT	\N	PRESENT	0
44088	43524	98053W	PARTICIPANT	\N	PRESENT	0
44089	43524	01041N	PARTICIPANT	\N	PRESENT	0
44090	43524	04086Q	PARTICIPANT	\N	PRESENT	0
44091	43524	11068S	PARTICIPANT	\N	PRESENT	0
44092	43524	11034G	PARTICIPANT	\N	PRESENT	0
44093	43524	04043D	PARTICIPANT	\N	PRESENT	0
44046	43524	04066L	PARTICIPANT	\N	PRESENT	0
44047	43524	01031L	PARTICIPANT	\N	PRESENT	0
44094	43524	08019V	PARTICIPANT	\N	PRESENT	0
44095	43524	11026G	PARTICIPANT	\N	PRESENT	0
44096	43524	98035U	PARTICIPANT	\N	PRESENT	0
44097	43524	11113E	PARTICIPANT	\N	PRESENT	0
44481	44241	04055H	PARTICIPANT	\N	PRESENT	0
44482	44241	11067R	PARTICIPANT	\N	PRESENT	0
44483	44241	10015M	PARTICIPANT	\N	PRESENT	0
44484	44241	01060R	PARTICIPANT	\N	PRESENT	0
44485	44241	08021P	PARTICIPANT	\N	PRESENT	0
44486	44241	07032N	PARTICIPANT	\N	PRESENT	0
44487	44241	14199E	PARTICIPANT	\N	PRESENT	0
44488	44241	11063M	PARTICIPANT	\N	PRESENT	0
44489	44241	14119M	PARTICIPANT	\N	PRESENT	0
44490	44241	08052W	PARTICIPANT	\N	PRESENT	0
44491	44241	08039A	PARTICIPANT	\N	PRESENT	0
44492	44241	14219Q	PARTICIPANT	\N	PRESENT	0
44493	44241	11077T	PARTICIPANT	\N	PRESENT	0
44494	44241	14207L	PARTICIPANT	\N	PRESENT	0
44495	44241	11048N	PARTICIPANT	\N	PRESENT	0
44496	44241	14281W	PARTICIPANT	\N	PRESENT	0
44500	44241	14033T	PARTICIPANT	\N	PRESENT	0
44498	44241	95067Q	PARTICIPANT	\N	PRESENT	0
44499	44241	14061L	PARTICIPANT	\N	PRESENT	0
44501	44241	14187A	PARTICIPANT	\N	PRESENT	0
44502	44241	14253S	PARTICIPANT	\N	PRESENT	0
44503	44241	01041N	PARTICIPANT	\N	PRESENT	0
44504	44241	11071M	PARTICIPANT	\N	PRESENT	0
44505	44241	14257W	PARTICIPANT	\N	PRESENT	0
44509	44241	92020L	PARTICIPANT	\N	PRESENT	0
44507	44241	14053L	PARTICIPANT	\N	PRESENT	0
44508	44241	14251Q	PARTICIPANT	\N	PRESENT	0
44510	44241	14197C	PARTICIPANT	\N	PRESENT	0
44511	44241	14167V	PARTICIPANT	\N	PRESENT	0
44513	44241	01061S	PARTICIPANT	\N	PRESENT	0
44514	44241	14195A	PARTICIPANT	\N	PRESENT	0
44515	44241	04079R	PARTICIPANT	\N	PRESENT	0
44516	44241	04043D	PARTICIPANT	\N	PRESENT	0
44517	44241	01019Q	PARTICIPANT	\N	PRESENT	0
44518	44241	08069G	PARTICIPANT	\N	PRESENT	0
44519	44241	95041E	PARTICIPANT	\N	PRESENT	0
44520	44241	11100Y	PARTICIPANT	\N	PRESENT	0
44521	44241	08062Y	PARTICIPANT	\N	PRESENT	0
44522	44241	05008E	PARTICIPANT	\N	PRESENT	0
44524	44241	11061K	PARTICIPANT	\N	PRESENT	0
44525	44241	12042Y	PARTICIPANT	\N	PRESENT	0
44526	44241	01059Y	PARTICIPANT	\N	PRESENT	0
44527	44241	08060W	PARTICIPANT	\N	PRESENT	0
44528	44241	89017R	PARTICIPANT	\N	PRESENT	0
44529	44241	14249W	PARTICIPANT	\N	PRESENT	0
44530	44241	14042U	PARTICIPANT	\N	PRESENT	0
44531	44241	14065Q	PARTICIPANT	\N	PRESENT	0
44532	44241	04059M	PARTICIPANT	\N	PRESENT	0
44533	44241	92044U	PARTICIPANT	\N	PRESENT	0
44534	44241	11085T	PARTICIPANT	\N	PRESENT	0
44535	44241	01056V	PARTICIPANT	\N	PRESENT	0
44536	44241	14089Y	PARTICIPANT	\N	PRESENT	0
44537	44241	01044R	PARTICIPANT	\N	PRESENT	0
44538	44241	04061F	PARTICIPANT	\N	PRESENT	0
44539	44241	14221J	PARTICIPANT	\N	PRESENT	0
44540	44241	12041X	PARTICIPANT	\N	PRESENT	0
44541	44241	14235Q	PARTICIPANT	\N	PRESENT	0
44542	44241	01046T	PARTICIPANT	\N	PRESENT	0
44543	44241	11110B	PARTICIPANT	\N	PRESENT	0
44544	44241	11104D	PARTICIPANT	\N	PRESENT	0
44545	44241	08038Y	PARTICIPANT	\N	PRESENT	0
44546	44241	04077P	PARTICIPANT	\N	PRESENT	0
44547	44241	14269B	PARTICIPANT	\N	PRESENT	0
44548	44241	11094U	PARTICIPANT	\N	PRESENT	0
44549	44241	05012A	PARTICIPANT	\N	PRESENT	0
33634	33345	14061L	PARTICIPANT	\N	PRESENT	0
33635	33345	04077P	PARTICIPANT	\N	PRESENT	0
33636	33345	08061X	PARTICIPANT	\N	PRESENT	0
33637	33345	11089X	PARTICIPANT	\N	PRESENT	0
33638	33345	08024S	PARTICIPANT	\N	PRESENT	0
33639	33345	07032N	PARTICIPANT	\N	PRESENT	0
33640	33345	08053X	PARTICIPANT	\N	PRESENT	0
33641	33345	14259Y	PARTICIPANT	\N	PRESENT	0
33642	33345	11059R	PARTICIPANT	\N	PRESENT	0
33643	33345	04044E	PARTICIPANT	\N	PRESENT	0
33644	33345	14123H	PARTICIPANT	\N	PRESENT	0
33645	33345	14071N	PARTICIPANT	\N	PRESENT	0
33646	33345	99002P	PARTICIPANT	\N	PRESENT	0
33647	33345	08068F	PARTICIPANT	\N	PRESENT	0
33648	33345	14073Q	PARTICIPANT	\N	PRESENT	0
33649	33345	11046L	PARTICIPANT	\N	PRESENT	0
33650	33345	04045F	PARTICIPANT	\N	PRESENT	0
36024	35621	14241N	PARTICIPANT	\N	PRESENT	0
33652	33345	04094Q	PARTICIPANT	\N	PRESENT	0
33653	33345	11061K	PARTICIPANT	\N	PRESENT	0
35180	28401	01056V	PARTICIPANT	\N	PRESENT	0
35965	35621	04081K	PARTICIPANT	\N	PRESENT	0
36025	35621	14105F	PARTICIPANT	\N	PRESENT	0
36026	35621	14041T	PARTICIPANT	\N	PRESENT	0
36027	35621	14247U	PARTICIPANT	\N	PRESENT	0
36028	35621	04038G	PARTICIPANT	\N	PRESENT	0
36029	35621	14018U	PARTICIPANT	\N	PRESENT	0
36030	35621	04044E	PARTICIPANT	\N	PRESENT	0
36031	35621	14237S	PARTICIPANT	\N	PRESENT	0
36033	35621	14063N	PARTICIPANT	\N	PRESENT	0
36092	35621	11034G	PARTICIPANT	\N	PRESENT	0
36093	35621	98035U	PARTICIPANT	\N	PRESENT	0
36094	35621	14205J	PARTICIPANT	\N	PRESENT	0
36095	35621	14199E	PARTICIPANT	\N	PRESENT	0
36096	35621	05008E	PARTICIPANT	\N	PRESENT	0
36097	35621	80013X	PARTICIPANT	\N	PRESENT	0
36098	35621	08051V	PARTICIPANT	\N	PRESENT	0
36099	35621	95037J	PARTICIPANT	\N	PRESENT	0
36100	35621	13002U	PARTICIPANT	\N	PRESENT	0
36101	35621	90003B	PARTICIPANT	\N	PRESENT	0
36102	35621	01046T	PARTICIPANT	\N	PRESENT	0
36103	35621	11099A	PARTICIPANT	\N	PRESENT	0
36105	35621	14327T	PARTICIPANT	\N	PRESENT	0
36145	35621	14103D	PARTICIPANT	\N	PRESENT	0
36146	35621	14261S	PARTICIPANT	\N	PRESENT	0
36147	35621	14207L	PARTICIPANT	\N	PRESENT	0
36148	35621	14069U	PARTICIPANT	\N	PRESENT	0
36149	35621	14259Y	PARTICIPANT	\N	PRESENT	0
36151	35621	14179A	PARTICIPANT	\N	PRESENT	0
36152	35621	14109K	PARTICIPANT	\N	PRESENT	0
36154	35621	11036J	PARTICIPANT	\N	PRESENT	0
36158	35621	14073Q	PARTICIPANT	\N	PRESENT	0
36159	35621	08056B	PARTICIPANT	\N	PRESENT	0
36160	35621	14133K	PARTICIPANT	\N	PRESENT	0
36180	35621	14097Y	PARTICIPANT	\N	PRESENT	0
36199	35621	11043H	PARTICIPANT	\N	PRESENT	0
36202	35621	14033T	PARTICIPANT	\N	PRESENT	0
36226	35621	95035G	PARTICIPANT	\N	PRESENT	0
36235	35621	14147R	PARTICIPANT	\N	PRESENT	0
36334	35621	14061L	PARTICIPANT	\N	PRESENT	0
36335	35621	11091R	PARTICIPANT	\N	PRESENT	0
36339	35621	14038Y	PARTICIPANT	\N	PRESENT	0
36340	35621	14201E	PARTICIPANT	\N	PRESENT	0
36341	35621	08031R	PARTICIPANT	\N	PRESENT	0
36343	35621	01024M	PARTICIPANT	\N	PRESENT	0
36346	35621	14219Q	PARTICIPANT	\N	PRESENT	0
36352	35621	11066Q	PARTICIPANT	\N	PRESENT	0
36354	35621	14263U	PARTICIPANT	\N	PRESENT	0
36356	35621	11098Y	PARTICIPANT	\N	PRESENT	0
36358	35621	97011G	PARTICIPANT	\N	PRESENT	0
36399	35622	04081K	PARTICIPANT	\N	PRESENT	0
36587	35622	14327T	PARTICIPANT	\N	PRESENT	0
36401	35622	14105F	PARTICIPANT	\N	PRESENT	0
36402	35622	14041T	PARTICIPANT	\N	PRESENT	0
36451	35622	14257W	PARTICIPANT	\N	PRESENT	0
36404	35622	04038G	PARTICIPANT	\N	PRESENT	0
36452	35622	14205J	PARTICIPANT	\N	PRESENT	0
36512	35622	88008L	PARTICIPANT	\N	PRESENT	0
36513	35622	14261S	PARTICIPANT	\N	PRESENT	0
36514	35622	11012A	PARTICIPANT	\N	PRESENT	0
36515	35622	14018U	PARTICIPANT	\N	PRESENT	0
36516	35622	08031R	PARTICIPANT	\N	PRESENT	0
36590	35622	95015C	PARTICIPANT	\N	PRESENT	0
36517	35622	01046T	PARTICIPANT	\N	PRESENT	0
36518	35622	14201E	PARTICIPANT	\N	PRESENT	0
36414	35622	08051V	PARTICIPANT	\N	PRESENT	0
36519	35622	14179A	PARTICIPANT	\N	PRESENT	0
36520	35622	14219Q	PARTICIPANT	\N	PRESENT	0
36417	35622	11099A	PARTICIPANT	\N	PRESENT	0
36580	35622	14063N	PARTICIPANT	\N	PRESENT	0
36522	35622	14273W	PARTICIPANT	\N	PRESENT	0
36581	35622	11036J	PARTICIPANT	\N	PRESENT	0
36591	35622	08039A	PARTICIPANT	\N	PRESENT	0
36594	35622	86044G	PARTICIPANT	\N	PRESENT	0
36584	35622	14267Y	PARTICIPANT	\N	PRESENT	0
36585	35622	14103D	PARTICIPANT	\N	PRESENT	0
36586	35622	14237S	PARTICIPANT	\N	PRESENT	0
36588	35622	14133K	PARTICIPANT	\N	PRESENT	0
36589	35622	14207L	PARTICIPANT	\N	PRESENT	0
36428	35622	14033T	PARTICIPANT	\N	PRESENT	0
36592	35622	14241N	PARTICIPANT	\N	PRESENT	0
36593	35622	05008E	PARTICIPANT	\N	PRESENT	0
36596	35622	04045F	PARTICIPANT	\N	PRESENT	0
36654	35622	14121F	PARTICIPANT	\N	PRESENT	0
36655	35622	80013X	PARTICIPANT	\N	PRESENT	0
36658	35622	14215L	PARTICIPANT	\N	PRESENT	0
36435	35622	01024M	PARTICIPANT	\N	PRESENT	0
36659	35622	08056B	PARTICIPANT	\N	PRESENT	0
36660	35622	01058X	PARTICIPANT	\N	PRESENT	0
36661	35622	14053L	PARTICIPANT	\N	PRESENT	0
36662	35622	11098Y	PARTICIPANT	\N	PRESENT	0
36440	35622	97011G	PARTICIPANT	\N	PRESENT	0
36443	35622	14259Y	PARTICIPANT	\N	PRESENT	0
36444	35622	01047U	PARTICIPANT	\N	PRESENT	0
36445	35622	04085P	PARTICIPANT	\N	PRESENT	0
36446	35622	01028R	PARTICIPANT	\N	PRESENT	0
36447	35622	08062Y	PARTICIPANT	\N	PRESENT	0
36448	35622	14013P	PARTICIPANT	\N	PRESENT	0
36663	35622	14147R	PARTICIPANT	\N	PRESENT	0
36664	35622	14197C	PARTICIPANT	\N	PRESENT	0
36666	35622	04088S	PARTICIPANT	\N	PRESENT	0
36670	35622	14135M	PARTICIPANT	\N	PRESENT	0
36671	35622	14173T	PARTICIPANT	\N	PRESENT	0
36672	35622	11103C	PARTICIPANT	\N	PRESENT	0
36673	35622	92031P	PARTICIPANT	\N	PRESENT	0
36674	35622	14026U	PARTICIPANT	\N	PRESENT	0
36675	35622	01048V	PARTICIPANT	\N	PRESENT	0
36676	35622	14042U	PARTICIPANT	\N	PRESENT	0
36677	35622	14209N	PARTICIPANT	\N	PRESENT	0
36678	35622	11064N	PARTICIPANT	\N	PRESENT	0
36679	35622	14265W	PARTICIPANT	\N	PRESENT	0
36680	35622	14249W	PARTICIPANT	\N	PRESENT	0
36681	35622	04056J	PARTICIPANT	\N	PRESENT	0
36682	35622	11039M	PARTICIPANT	\N	PRESENT	0
36683	35622	04067M	PARTICIPANT	\N	PRESENT	0
36684	35622	14038Y	PARTICIPANT	\N	PRESENT	0
36685	35622	07004J	PARTICIPANT	\N	PRESENT	0
36686	35622	14097Y	PARTICIPANT	\N	PRESENT	0
36687	35622	04057K	PARTICIPANT	\N	PRESENT	0
500938	500280	12041X	PARTICIPANT	\N	PRESENT	0
40967	40964	04081K	PARTICIPANT	\N	PRESENT	0
40968	40964	11098Y	PARTICIPANT	\N	PRESENT	0
40969	40964	07026Q	PARTICIPANT	\N	PRESENT	0
40970	40964	11057P	PARTICIPANT	\N	PRESENT	0
40971	40964	89017R	PARTICIPANT	\N	PRESENT	0
40972	40964	01031L	PARTICIPANT	\N	PRESENT	0
40973	40964	01022K	PARTICIPANT	\N	PRESENT	0
40974	40964	11074Q	PARTICIPANT	\N	PRESENT	0
40975	40964	08043V	PARTICIPANT	\N	PRESENT	0
40976	40964	08052W	PARTICIPANT	\N	PRESENT	0
40977	40964	11029K	PARTICIPANT	\N	PRESENT	0
40978	40964	14041T	PARTICIPANT	\N	PRESENT	0
40979	40964	11091R	PARTICIPANT	\N	PRESENT	0
40980	40964	08031R	PARTICIPANT	\N	PRESENT	0
40981	40964	04070G	PARTICIPANT	\N	PRESENT	0
40982	40964	14123H	PARTICIPANT	\N	PRESENT	0
40983	40964	11089X	PARTICIPANT	\N	PRESENT	0
40984	40964	11068S	PARTICIPANT	\N	PRESENT	0
40985	40964	14229S	PARTICIPANT	\N	PRESENT	0
40998	40964	11071M	PARTICIPANT	\N	PRESENT	0
40987	40964	14159V	PARTICIPANT	\N	PRESENT	0
40988	40964	14227Q	PARTICIPANT	\N	PRESENT	0
40989	40964	08010L	PARTICIPANT	\N	PRESENT	0
40990	40964	14173T	PARTICIPANT	\N	PRESENT	0
40991	40964	14225N	PARTICIPANT	\N	PRESENT	0
40992	40964	14133K	PARTICIPANT	\N	PRESENT	0
40993	40964	11064N	PARTICIPANT	\N	PRESENT	0
40994	40964	99004R	PARTICIPANT	\N	PRESENT	0
40999	40964	88008L	PARTICIPANT	\N	PRESENT	0
41000	40964	01056V	PARTICIPANT	\N	PRESENT	0
41001	40964	11094U	PARTICIPANT	\N	PRESENT	0
41002	40964	11110B	PARTICIPANT	\N	PRESENT	0
41007	40964	14175V	PARTICIPANT	\N	PRESENT	0
41186	40965	01028R	PARTICIPANT	\N	PRESENT	0
41084	40965	07024N	PARTICIPANT	\N	PRESENT	0
41085	40965	01014K	PARTICIPANT	\N	PRESENT	0
41086	40965	11054L	PARTICIPANT	\N	PRESENT	0
41087	40965	08052W	PARTICIPANT	\N	PRESENT	0
41088	40965	07004J	PARTICIPANT	\N	PRESENT	0
41089	40965	14193X	PARTICIPANT	\N	PRESENT	0
41090	40965	04080J	PARTICIPANT	\N	PRESENT	0
41091	40965	01056V	PARTICIPANT	\N	PRESENT	0
41092	40965	08058D	PARTICIPANT	\N	PRESENT	0
41093	40965	08034U	PARTICIPANT	\N	PRESENT	0
41094	40965	01016M	PARTICIPANT	\N	PRESENT	0
41095	40965	01031L	PARTICIPANT	\N	PRESENT	0
41096	40965	08043V	PARTICIPANT	\N	PRESENT	0
41097	40965	14159V	PARTICIPANT	\N	PRESENT	0
41098	40965	07029T	PARTICIPANT	\N	PRESENT	0
41099	40965	99004R	PARTICIPANT	\N	PRESENT	0
41100	40965	14173T	PARTICIPANT	\N	PRESENT	0
41101	40965	14225N	PARTICIPANT	\N	PRESENT	0
41102	40965	95059Q	PARTICIPANT	\N	PRESENT	0
41103	40965	11057P	PARTICIPANT	\N	PRESENT	0
41104	40965	01041N	PARTICIPANT	\N	PRESENT	0
41105	40965	14133K	PARTICIPANT	\N	PRESENT	0
41188	40965	08019V	PARTICIPANT	\N	PRESENT	0
41107	40965	14167V	PARTICIPANT	\N	PRESENT	0
41108	40965	11074Q	PARTICIPANT	\N	PRESENT	0
41110	40965	14175V	PARTICIPANT	\N	PRESENT	0
41111	40965	14041T	PARTICIPANT	\N	PRESENT	0
41112	40965	08016S	PARTICIPANT	\N	PRESENT	0
41117	40965	92031P	PARTICIPANT	\N	PRESENT	0
41127	40965	04035D	PARTICIPANT	\N	PRESENT	0
41128	40965	04056J	PARTICIPANT	\N	PRESENT	0
41081	40965	08024S	PARTICIPANT	\N	PRESENT	0
41082	40965	11106F	PARTICIPANT	\N	PRESENT	0
41129	40965	11027H	PARTICIPANT	\N	PRESENT	0
41130	40965	14229S	PARTICIPANT	\N	PRESENT	0
41131	40965	11076S	PARTICIPANT	\N	PRESENT	0
41132	40965	01061S	PARTICIPANT	\N	PRESENT	0
41133	40965	04043D	PARTICIPANT	\N	PRESENT	0
41134	40965	11064N	PARTICIPANT	\N	PRESENT	0
41135	40965	11083R	PARTICIPANT	\N	PRESENT	0
41136	40965	88008L	PARTICIPANT	\N	PRESENT	0
41137	40965	04036E	PARTICIPANT	\N	PRESENT	0
41138	40965	04071H	PARTICIPANT	\N	PRESENT	0
41139	40965	11088W	PARTICIPANT	\N	PRESENT	0
41140	40965	04042C	PARTICIPANT	\N	PRESENT	0
41141	40965	14053L	PARTICIPANT	\N	PRESENT	0
41153	40965	14261S	PARTICIPANT	\N	PRESENT	0
41154	40965	08017T	PARTICIPANT	\N	PRESENT	0
41169	40965	04055H	PARTICIPANT	\N	PRESENT	0
41170	40965	08011M	PARTICIPANT	\N	PRESENT	0
41171	40965	08068F	PARTICIPANT	\N	PRESENT	0
41176	40965	01013J	PARTICIPANT	\N	PRESENT	0
41177	40965	11031D	PARTICIPANT	\N	PRESENT	0
41187	40965	14227Q	PARTICIPANT	\N	PRESENT	0
41189	40965	14255U	PARTICIPANT	\N	PRESENT	0
41190	40965	86044G	PARTICIPANT	\N	PRESENT	0
41191	40965	04054G	PARTICIPANT	\N	PRESENT	0
41219	40966	04066L	PARTICIPANT	\N	PRESENT	0
41221	40966	11098Y	PARTICIPANT	\N	PRESENT	0
41222	40966	11074Q	PARTICIPANT	\N	PRESENT	0
41223	40966	11042G	PARTICIPANT	\N	PRESENT	0
41224	40966	08016S	PARTICIPANT	\N	PRESENT	0
41225	40966	01016M	PARTICIPANT	\N	PRESENT	0
41226	40966	11027H	PARTICIPANT	\N	PRESENT	0
41227	40966	08017T	PARTICIPANT	\N	PRESENT	0
41228	40966	14159V	PARTICIPANT	\N	PRESENT	0
41229	40966	14225N	PARTICIPANT	\N	PRESENT	0
41230	40966	88008L	PARTICIPANT	\N	PRESENT	0
41231	40966	01031L	PARTICIPANT	\N	PRESENT	0
41232	40966	04078Q	PARTICIPANT	\N	PRESENT	0
41233	40966	14261S	PARTICIPANT	\N	PRESENT	0
41234	40966	04080J	PARTICIPANT	\N	PRESENT	0
41235	40966	01041N	PARTICIPANT	\N	PRESENT	0
41236	40966	04036E	PARTICIPANT	\N	PRESENT	0
41237	40966	07024N	PARTICIPANT	\N	PRESENT	0
41238	40966	08052W	PARTICIPANT	\N	PRESENT	0
41239	40966	04035D	PARTICIPANT	\N	PRESENT	0
41240	40966	11114F	PARTICIPANT	\N	PRESENT	0
41241	40966	08019V	PARTICIPANT	\N	PRESENT	0
41242	40966	04061F	PARTICIPANT	\N	PRESENT	0
41243	40966	11076S	PARTICIPANT	\N	PRESENT	0
41244	40966	01057W	PARTICIPANT	\N	PRESENT	0
41245	40966	08068F	PARTICIPANT	\N	PRESENT	0
41246	40966	86044G	PARTICIPANT	\N	PRESENT	0
41220	40966	04054G	PARTICIPANT	\N	PRESENT	0
41247	40966	04049K	PARTICIPANT	\N	PRESENT	0
48241	47942	11043H	PARTICIPANT	\N	PRESENT	0
48242	47942	11056N	PARTICIPANT	\N	PRESENT	0
48243	47942	11034G	PARTICIPANT	\N	PRESENT	0
48244	47942	98021N	PARTICIPANT	\N	PRESENT	0
48245	47942	11098Y	PARTICIPANT	\N	PRESENT	0
48246	47942	08018U	PARTICIPANT	\N	PRESENT	0
48247	47942	11054L	PARTICIPANT	\N	PRESENT	0
48248	47942	08014Q	PARTICIPANT	\N	PRESENT	0
48249	47942	11095V	PARTICIPANT	\N	PRESENT	0
48250	47942	14249W	PARTICIPANT	\N	PRESENT	0
48251	47942	11068S	PARTICIPANT	\N	PRESENT	0
48252	47942	11036J	PARTICIPANT	\N	PRESENT	0
48253	47942	11035H	PARTICIPANT	\N	PRESENT	0
48254	47942	04061F	PARTICIPANT	\N	PRESENT	0
48255	47942	14247U	PARTICIPANT	\N	PRESENT	0
48256	47942	08034U	PARTICIPANT	\N	PRESENT	0
48257	47942	11057P	PARTICIPANT	\N	PRESENT	0
48258	47942	11104D	PARTICIPANT	\N	PRESENT	0
48259	47942	14111D	PARTICIPANT	\N	PRESENT	0
48260	47942	08009T	PARTICIPANT	\N	PRESENT	0
48261	47942	14209N	PARTICIPANT	\N	PRESENT	0
48262	47942	14079W	PARTICIPANT	\N	PRESENT	0
48263	47942	04056J	PARTICIPANT	\N	PRESENT	0
48264	47942	14239U	PARTICIPANT	\N	PRESENT	0
48265	47942	14273W	PARTICIPANT	\N	PRESENT	0
48266	47942	07032N	PARTICIPANT	\N	PRESENT	0
48267	47942	14034U	PARTICIPANT	\N	PRESENT	0
48268	47942	14195A	PARTICIPANT	\N	PRESENT	0
48269	47942	11114F	PARTICIPANT	\N	PRESENT	0
48270	47942	98042T	PARTICIPANT	\N	PRESENT	0
48271	47942	14215L	PARTICIPANT	\N	PRESENT	0
48272	47942	11111C	PARTICIPANT	\N	PRESENT	0
48273	47942	14059S	PARTICIPANT	\N	PRESENT	0
48274	47942	92044U	PARTICIPANT	\N	PRESENT	0
48275	47942	89017R	PARTICIPANT	\N	PRESENT	0
48276	47942	08062Y	PARTICIPANT	\N	PRESENT	0
48277	47942	95037J	PARTICIPANT	\N	PRESENT	0
48278	47942	14271U	PARTICIPANT	\N	PRESENT	0
48279	47942	83042R	PARTICIPANT	\N	PRESENT	0
48280	47942	14187A	PARTICIPANT	\N	PRESENT	0
48281	47942	14065Q	PARTICIPANT	\N	PRESENT	0
48282	47942	14053L	PARTICIPANT	\N	PRESENT	0
48283	47942	11094U	PARTICIPANT	\N	PRESENT	0
48284	47942	95015C	PARTICIPANT	\N	PRESENT	0
48285	47942	14217N	PARTICIPANT	\N	PRESENT	0
48347	47942	11084S	PARTICIPANT	\N	PRESENT	0
48288	47942	08011M	PARTICIPANT	\N	PRESENT	0
48348	47942	14223L	PARTICIPANT	\N	PRESENT	0
32226	31687	14281W	PARTICIPANT	\N	PRESENT	0
32227	31687	08035V	PARTICIPANT	\N	PRESENT	0
32230	31687	04094Q	PARTICIPANT	\N	PRESENT	0
32231	31687	08073C	PARTICIPANT	\N	PRESENT	0
32232	31687	14159V	PARTICIPANT	\N	PRESENT	0
32234	31687	14135M	PARTICIPANT	\N	PRESENT	0
32236	31687	14269B	PARTICIPANT	\N	PRESENT	0
32238	31687	11077T	PARTICIPANT	\N	PRESENT	0
32239	31687	14018U	PARTICIPANT	\N	PRESENT	0
32240	31687	14237S	PARTICIPANT	\N	PRESENT	0
32241	31687	14327T	PARTICIPANT	\N	PRESENT	0
32242	31687	07034Q	PARTICIPANT	\N	PRESENT	0
32243	31687	01024M	PARTICIPANT	\N	PRESENT	0
32244	31687	14111D	PARTICIPANT	\N	PRESENT	0
32245	31687	04070G	PARTICIPANT	\N	PRESENT	0
32246	31687	14255U	PARTICIPANT	\N	PRESENT	0
32247	31687	14179A	PARTICIPANT	\N	PRESENT	0
32248	31687	14253S	PARTICIPANT	\N	PRESENT	0
32249	31687	01025N	PARTICIPANT	\N	PRESENT	0
32250	31687	11093T	PARTICIPANT	\N	PRESENT	0
32251	31687	14042U	PARTICIPANT	\N	PRESENT	0
32252	31687	14219Q	PARTICIPANT	\N	PRESENT	0
32253	31687	08069G	PARTICIPANT	\N	PRESENT	0
32254	31687	11070L	PARTICIPANT	\N	PRESENT	0
32255	31687	11064N	PARTICIPANT	\N	PRESENT	0
32256	31687	14205J	PARTICIPANT	\N	PRESENT	0
32257	31687	14251Q	PARTICIPANT	\N	PRESENT	0
32258	31687	11080N	PARTICIPANT	\N	PRESENT	0
32259	31687	08009T	PARTICIPANT	\N	PRESENT	0
32260	31687	01034P	PARTICIPANT	\N	PRESENT	0
32261	31687	11053K	PARTICIPANT	\N	PRESENT	0
32262	31687	14213J	PARTICIPANT	\N	PRESENT	0
32263	31687	14187A	PARTICIPANT	\N	PRESENT	0
32264	31687	11033F	PARTICIPANT	\N	PRESENT	0
32265	31687	11055M	PARTICIPANT	\N	PRESENT	0
32266	31687	11071M	PARTICIPANT	\N	PRESENT	0
32267	31687	08042U	PARTICIPANT	\N	PRESENT	0
32268	31687	11023D	PARTICIPANT	\N	PRESENT	0
32269	31687	14123H	PARTICIPANT	\N	PRESENT	0
32270	31687	05008E	PARTICIPANT	\N	PRESENT	0
32271	31687	05004A	PARTICIPANT	\N	PRESENT	0
32272	31687	01008M	PARTICIPANT	\N	PRESENT	0
32274	31687	01048V	PARTICIPANT	\N	PRESENT	0
32275	31687	14093U	PARTICIPANT	\N	PRESENT	0
32276	31687	11088W	PARTICIPANT	\N	PRESENT	0
32277	31687	11084S	PARTICIPANT	\N	PRESENT	0
32278	31687	04078Q	PARTICIPANT	\N	PRESENT	0
32281	31687	08019V	PARTICIPANT	\N	PRESENT	0
32282	31687	11061K	PARTICIPANT	\N	PRESENT	0
32289	31687	04071H	PARTICIPANT	\N	PRESENT	0
32285	31687	04067M	PARTICIPANT	\N	PRESENT	0
32286	31687	14133K	PARTICIPANT	\N	PRESENT	0
32287	31687	14199E	PARTICIPANT	\N	PRESENT	0
32288	31687	95067Q	PARTICIPANT	\N	PRESENT	0
32290	31687	14249W	PARTICIPANT	\N	PRESENT	0
32297	31687	14119M	PARTICIPANT	\N	PRESENT	0
32298	31687	95035G	PARTICIPANT	\N	PRESENT	0
32299	31687	14034U	PARTICIPANT	\N	PRESENT	0
32300	31687	96004D	PARTICIPANT	\N	PRESENT	0
32304	31687	11076S	PARTICIPANT	\N	PRESENT	0
32302	31687	11031D	PARTICIPANT	\N	PRESENT	0
32303	31687	11085T	PARTICIPANT	\N	PRESENT	0
32305	31687	11069T	PARTICIPANT	\N	PRESENT	0
32367	31687	14151M	PARTICIPANT	\N	PRESENT	0
32606	31690	08055A	PARTICIPANT	\N	PRESENT	0
32607	31690	01034P	PARTICIPANT	\N	PRESENT	0
32608	31690	04092N	PARTICIPANT	\N	PRESENT	0
32609	31690	11061K	PARTICIPANT	\N	PRESENT	0
32610	31690	08052W	PARTICIPANT	\N	PRESENT	0
32611	31690	14041T	PARTICIPANT	\N	PRESENT	0
32612	31690	07026Q	PARTICIPANT	\N	PRESENT	0
32613	31690	01059Y	PARTICIPANT	\N	PRESENT	0
32614	31690	11063M	PARTICIPANT	\N	PRESENT	0
32615	31690	11054L	PARTICIPANT	\N	PRESENT	0
32616	31690	14227Q	PARTICIPANT	\N	PRESENT	0
32617	31690	11026G	PARTICIPANT	\N	PRESENT	0
32618	31690	11036J	PARTICIPANT	\N	PRESENT	0
32619	31690	80013X	PARTICIPANT	\N	PRESENT	0
32620	31690	00003C	PARTICIPANT	\N	PRESENT	0
32621	31690	04053F	PARTICIPANT	\N	PRESENT	0
32622	31690	11031D	PARTICIPANT	\N	PRESENT	0
32623	31690	14261S	PARTICIPANT	\N	PRESENT	0
32624	31690	14217N	PARTICIPANT	\N	PRESENT	0
32625	31690	95030B	PARTICIPANT	\N	PRESENT	0
32626	31690	11091R	PARTICIPANT	\N	PRESENT	0
32627	31690	14223L	PARTICIPANT	\N	PRESENT	0
32628	31690	08041T	PARTICIPANT	\N	PRESENT	0
32629	31690	14273W	PARTICIPANT	\N	PRESENT	0
32630	31690	11060J	PARTICIPANT	\N	PRESENT	0
32631	31690	97011G	PARTICIPANT	\N	PRESENT	0
32632	31690	14201E	PARTICIPANT	\N	PRESENT	0
32633	31690	14219Q	PARTICIPANT	\N	PRESENT	0
32635	31690	12042Y	PARTICIPANT	\N	PRESENT	0
32636	31690	11103C	PARTICIPANT	\N	PRESENT	0
32640	31690	14037X	PARTICIPANT	\N	PRESENT	0
32641	31690	11093T	PARTICIPANT	\N	PRESENT	0
32643	31690	14231L	PARTICIPANT	\N	PRESENT	0
32645	31690	08019V	PARTICIPANT	\N	PRESENT	0
32648	31690	14269B	PARTICIPANT	\N	PRESENT	0
32654	31690	11055M	PARTICIPANT	\N	PRESENT	0
32659	31690	10006L	PARTICIPANT	\N	PRESENT	0
32660	31690	14213J	PARTICIPANT	\N	PRESENT	0
32662	32657	14119M	PARTICIPANT	\N	PRESENT	0
32663	31690	04067M	PARTICIPANT	\N	PRESENT	0
32668	31690	14169X	PARTICIPANT	\N	PRESENT	0
32670	31690	86044G	PARTICIPANT	\N	PRESENT	0
32672	31690	11023D	PARTICIPANT	\N	PRESENT	0
32676	31690	14033T	PARTICIPANT	\N	PRESENT	0
32677	32657	14269B	PARTICIPANT	\N	PRESENT	0
32679	31690	11067R	PARTICIPANT	\N	PRESENT	0
32680	31690	08043V	PARTICIPANT	\N	PRESENT	0
32683	31690	14235Q	PARTICIPANT	\N	PRESENT	0
32684	31690	14071N	PARTICIPANT	\N	PRESENT	0
32685	31690	14026U	PARTICIPANT	\N	PRESENT	0
32687	31690	14135M	PARTICIPANT	\N	PRESENT	0
32688	31690	04036E	PARTICIPANT	\N	PRESENT	0
32689	31690	04088S	PARTICIPANT	\N	PRESENT	0
32690	31690	14111D	PARTICIPANT	\N	PRESENT	0
32691	31690	08056B	PARTICIPANT	\N	PRESENT	0
32692	31690	14018U	PARTICIPANT	\N	PRESENT	0
32693	31690	14147R	PARTICIPANT	\N	PRESENT	0
32729	31690	14034U	PARTICIPANT	\N	PRESENT	0
32730	31690	95015C	PARTICIPANT	\N	PRESENT	0
32731	31690	92045V	PARTICIPANT	\N	PRESENT	0
32732	31690	11088W	PARTICIPANT	\N	PRESENT	0
32733	31690	14265W	PARTICIPANT	\N	PRESENT	0
32734	31690	01046T	PARTICIPANT	\N	PRESENT	0
32735	31690	14221J	PARTICIPANT	\N	PRESENT	0
32736	31690	11012A	PARTICIPANT	\N	PRESENT	0
32737	31690	95035G	PARTICIPANT	\N	PRESENT	0
32738	31690	05008E	PARTICIPANT	\N	PRESENT	0
32739	31690	11048N	PARTICIPANT	\N	PRESENT	0
32740	31690	11107G	PARTICIPANT	\N	PRESENT	0
32741	31690	14151M	PARTICIPANT	\N	PRESENT	0
32742	31690	11042G	PARTICIPANT	\N	PRESENT	0
32797	31690	04066L	PARTICIPANT	\N	PRESENT	0
32838	31690	07029T	PARTICIPANT	\N	PRESENT	0
32883	31690	14239U	PARTICIPANT	\N	PRESENT	0
32888	31690	14073Q	PARTICIPANT	\N	PRESENT	0
32889	31690	14157T	PARTICIPANT	\N	PRESENT	0
32893	31690	04049K	PARTICIPANT	\N	PRESENT	0
32894	31690	08016S	PARTICIPANT	\N	PRESENT	0
32895	31690	98018T	PARTICIPANT	\N	PRESENT	0
44550	44241	14229S	PARTICIPANT	\N	PRESENT	0
44551	44241	11099A	PARTICIPANT	\N	PRESENT	0
44556	44241	11064N	PARTICIPANT	\N	PRESENT	0
44557	44241	11076S	PARTICIPANT	\N	PRESENT	0
44558	44241	04067M	PARTICIPANT	\N	PRESENT	0
44569	44241	11042G	PARTICIPANT	\N	PRESENT	0
44561	44241	04049K	PARTICIPANT	\N	PRESENT	0
44564	44241	11039M	PARTICIPANT	\N	PRESENT	0
44572	44241	11089X	PARTICIPANT	\N	PRESENT	0
44613	44241	11112D	PARTICIPANT	\N	PRESENT	0
44577	44241	11059R	PARTICIPANT	\N	PRESENT	0
44609	44241	11023D	PARTICIPANT	\N	PRESENT	0
44616	44241	11060J	PARTICIPANT	\N	PRESENT	0
44614	44241	11069T	PARTICIPANT	\N	PRESENT	0
44615	44241	14030Q	PARTICIPANT	\N	PRESENT	0
45972	44244	89029V	PARTICIPANT	\N	PRESENT	0
45974	44244	14063N	PARTICIPANT	\N	PRESENT	0
45979	44244	14061L	PARTICIPANT	\N	PRESENT	0
45981	44244	14239U	PARTICIPANT	\N	PRESENT	0
45983	44244	14231L	PARTICIPANT	\N	PRESENT	0
45984	44244	07026Q	PARTICIPANT	\N	PRESENT	0
45985	44244	14197C	PARTICIPANT	\N	PRESENT	0
45986	44244	14217N	PARTICIPANT	\N	PRESENT	0
45989	44244	14089Y	PARTICIPANT	\N	PRESENT	0
45990	44244	01044R	PARTICIPANT	\N	PRESENT	0
45991	44244	04070G	PARTICIPANT	\N	PRESENT	0
45992	44244	14235Q	PARTICIPANT	\N	PRESENT	0
45995	44244	14195A	PARTICIPANT	\N	PRESENT	0
45996	44244	92015P	PARTICIPANT	\N	PRESENT	0
45997	44244	11104D	PARTICIPANT	\N	PRESENT	0
45998	44244	11066Q	PARTICIPANT	\N	PRESENT	0
45999	44244	11067R	PARTICIPANT	\N	PRESENT	0
46057	44244	14265W	PARTICIPANT	\N	PRESENT	0
46058	44244	14207L	PARTICIPANT	\N	PRESENT	0
46059	44244	04088S	PARTICIPANT	\N	PRESENT	0
46060	44244	14105F	PARTICIPANT	\N	PRESENT	0
46061	44244	14038Y	PARTICIPANT	\N	PRESENT	0
46062	44244	11014C	PARTICIPANT	\N	PRESENT	0
46065	44244	14030Q	PARTICIPANT	\N	PRESENT	0
46066	44244	14147R	PARTICIPANT	\N	PRESENT	0
46067	44244	95062K	PARTICIPANT	\N	PRESENT	0
46068	44244	04057K	PARTICIPANT	\N	PRESENT	0
46069	44244	08039A	PARTICIPANT	\N	PRESENT	0
46070	44244	14041T	PARTICIPANT	\N	PRESENT	0
46073	44244	14263U	PARTICIPANT	\N	PRESENT	0
46074	44244	98021N	PARTICIPANT	\N	PRESENT	0
46075	44244	04077P	PARTICIPANT	\N	PRESENT	0
46076	44244	11029K	PARTICIPANT	\N	PRESENT	0
46137	44244	95015C	PARTICIPANT	\N	PRESENT	0
46140	44244	14042U	PARTICIPANT	\N	PRESENT	0
46141	44244	08015R	PARTICIPANT	\N	PRESENT	0
46142	44244	14073Q	PARTICIPANT	\N	PRESENT	0
46143	44244	08028W	PARTICIPANT	\N	PRESENT	0
46144	44244	14031R	PARTICIPANT	\N	PRESENT	0
46145	44244	11089X	PARTICIPANT	\N	PRESENT	0
46146	44244	14179A	PARTICIPANT	\N	PRESENT	0
46147	44244	14267Y	PARTICIPANT	\N	PRESENT	0
46148	44244	08043V	PARTICIPANT	\N	PRESENT	0
46158	44244	14237S	PARTICIPANT	\N	PRESENT	0
46162	44244	08051V	PARTICIPANT	\N	PRESENT	0
46171	44244	01022K	PARTICIPANT	\N	PRESENT	0
46189	44244	14028W	PARTICIPANT	\N	PRESENT	0
46194	44244	08062Y	PARTICIPANT	\N	PRESENT	0
46195	44244	08048B	PARTICIPANT	\N	PRESENT	0
46196	44244	98022P	PARTICIPANT	\N	PRESENT	0
46197	44244	11043H	PARTICIPANT	\N	PRESENT	0
46198	44244	90003B	PARTICIPANT	\N	PRESENT	0
46199	44244	14229S	PARTICIPANT	\N	PRESENT	0
46200	44244	88008L	PARTICIPANT	\N	PRESENT	0
46202	44244	08014Q	PARTICIPANT	\N	PRESENT	0
46203	44244	11112D	PARTICIPANT	\N	PRESENT	0
46205	44244	14205J	PARTICIPANT	\N	PRESENT	0
46209	44244	14209N	PARTICIPANT	\N	PRESENT	0
46211	44244	14026U	PARTICIPANT	\N	PRESENT	0
46217	44244	04045F	PARTICIPANT	\N	PRESENT	0
46218	44244	11084S	PARTICIPANT	\N	PRESENT	0
46219	44244	01003G	PARTICIPANT	\N	PRESENT	0
46220	44244	14251Q	PARTICIPANT	\N	PRESENT	0
46222	44244	14219Q	PARTICIPANT	\N	PRESENT	0
46223	44244	14103D	PARTICIPANT	\N	PRESENT	0
46224	44244	08055A	PARTICIPANT	\N	PRESENT	0
46226	44244	98050T	PARTICIPANT	\N	PRESENT	0
46227	44244	14033T	PARTICIPANT	\N	PRESENT	0
46228	44244	11098Y	PARTICIPANT	\N	PRESENT	0
46232	44244	14135M	PARTICIPANT	\N	PRESENT	0
46233	44244	07032N	PARTICIPANT	\N	PRESENT	0
46234	44244	14123H	PARTICIPANT	\N	PRESENT	0
46261	44244	14191V	PARTICIPANT	\N	PRESENT	0
46262	44244	95035G	PARTICIPANT	\N	PRESENT	0
46263	44244	14193X	PARTICIPANT	\N	PRESENT	0
46265	44244	01019Q	PARTICIPANT	\N	PRESENT	0
46266	44244	11100Y	PARTICIPANT	\N	PRESENT	0
46267	44244	14213J	PARTICIPANT	\N	PRESENT	0
46268	44244	08060W	PARTICIPANT	\N	PRESENT	0
46269	44244	14199E	PARTICIPANT	\N	PRESENT	0
46270	44244	14013P	PARTICIPANT	\N	PRESENT	0
46271	44244	08068F	PARTICIPANT	\N	PRESENT	0
46272	44244	14257W	PARTICIPANT	\N	PRESENT	0
46273	44244	14187A	PARTICIPANT	\N	PRESENT	0
46274	44244	01008M	PARTICIPANT	\N	PRESENT	0
46275	44244	14034U	PARTICIPANT	\N	PRESENT	0
46276	44244	80013X	PARTICIPANT	\N	PRESENT	0
46289	44244	14121F	PARTICIPANT	\N	PRESENT	0
46278	44244	14157T	PARTICIPANT	\N	PRESENT	0
46284	44244	14071N	PARTICIPANT	\N	PRESENT	0
46287	44244	96004D	PARTICIPANT	\N	PRESENT	0
46288	44244	87003B	PARTICIPANT	\N	PRESENT	0
46290	44244	04089T	PARTICIPANT	\N	PRESENT	0
46382	44246	08055A	PARTICIPANT	\N	PRESENT	0
46383	44246	07032N	PARTICIPANT	\N	PRESENT	0
46384	44246	14213J	PARTICIPANT	\N	PRESENT	0
46385	44246	14041T	PARTICIPANT	\N	PRESENT	0
46386	44246	14033T	PARTICIPANT	\N	PRESENT	0
46388	44246	14195A	PARTICIPANT	\N	PRESENT	0
46389	44246	01008M	PARTICIPANT	\N	PRESENT	0
46390	44246	11112D	PARTICIPANT	\N	PRESENT	0
46391	44246	11098Y	PARTICIPANT	\N	PRESENT	0
46392	44246	07026Q	PARTICIPANT	\N	PRESENT	0
46393	44246	11036J	PARTICIPANT	\N	PRESENT	0
46394	44246	14263U	PARTICIPANT	\N	PRESENT	0
46395	44246	11043H	PARTICIPANT	\N	PRESENT	0
46396	44246	87003B	PARTICIPANT	\N	PRESENT	0
46397	44246	11100Y	PARTICIPANT	\N	PRESENT	0
46398	44246	95062K	PARTICIPANT	\N	PRESENT	0
46399	44246	80013X	PARTICIPANT	\N	PRESENT	0
46400	44246	08048B	PARTICIPANT	\N	PRESENT	0
46401	44246	14265W	PARTICIPANT	\N	PRESENT	0
46402	44246	95030B	PARTICIPANT	\N	PRESENT	0
46403	44246	92015P	PARTICIPANT	\N	PRESENT	0
46404	44246	14038Y	PARTICIPANT	\N	PRESENT	0
46406	44246	14085U	PARTICIPANT	\N	PRESENT	0
46409	44246	14159V	PARTICIPANT	\N	PRESENT	0
46410	44246	14157T	PARTICIPANT	\N	PRESENT	0
46411	44246	07029T	PARTICIPANT	\N	PRESENT	0
46412	44246	14207L	PARTICIPANT	\N	PRESENT	0
46413	44246	04089T	PARTICIPANT	\N	PRESENT	0
46414	44246	98050T	PARTICIPANT	\N	PRESENT	0
46415	44246	14031R	PARTICIPANT	\N	PRESENT	0
46418	44246	04088S	PARTICIPANT	\N	PRESENT	0
46419	44246	11111C	PARTICIPANT	\N	PRESENT	0
46420	44246	14205J	PARTICIPANT	\N	PRESENT	0
46421	44246	14063N	PARTICIPANT	\N	PRESENT	0
46423	44246	08015R	PARTICIPANT	\N	PRESENT	0
46427	44246	14061L	PARTICIPANT	\N	PRESENT	0
46429	44246	14193X	PARTICIPANT	\N	PRESENT	0
46430	44246	14237S	PARTICIPANT	\N	PRESENT	0
46435	44246	14257W	PARTICIPANT	\N	PRESENT	0
46437	44246	01022K	PARTICIPANT	\N	PRESENT	0
46438	44246	86044G	PARTICIPANT	\N	PRESENT	0
46440	44246	96004D	PARTICIPANT	\N	PRESENT	0
46442	44246	14135M	PARTICIPANT	\N	PRESENT	0
46444	44246	11099A	PARTICIPANT	\N	PRESENT	0
46447	44246	14133K	PARTICIPANT	\N	PRESENT	0
46454	44246	90003B	PARTICIPANT	\N	PRESENT	0
46460	44246	11064N	PARTICIPANT	\N	PRESENT	0
46461	44246	11090Q	PARTICIPANT	\N	PRESENT	0
46462	44246	01019Q	PARTICIPANT	\N	PRESENT	0
46463	44246	14042U	PARTICIPANT	\N	PRESENT	0
46464	44246	14191V	PARTICIPANT	\N	PRESENT	0
46465	44246	11066Q	PARTICIPANT	\N	PRESENT	0
46466	44246	14107H	PARTICIPANT	\N	PRESENT	0
46467	44246	08028W	PARTICIPANT	\N	PRESENT	0
46470	44246	08051V	PARTICIPANT	\N	PRESENT	0
46471	44246	14119M	PARTICIPANT	\N	PRESENT	0
46472	44246	14187A	PARTICIPANT	\N	PRESENT	0
46474	44246	14071N	PARTICIPANT	\N	PRESENT	0
46475	44246	07034Q	PARTICIPANT	\N	PRESENT	0
46479	44246	11048N	PARTICIPANT	\N	PRESENT	0
36752	35623	14259Y	PARTICIPANT	\N	PRESENT	0
36753	35623	14261S	PARTICIPANT	\N	PRESENT	0
36754	35623	11064N	PARTICIPANT	\N	PRESENT	0
36755	35623	04085P	PARTICIPANT	\N	PRESENT	0
36756	35623	11113E	PARTICIPANT	\N	PRESENT	0
36757	35623	11055M	PARTICIPANT	\N	PRESENT	0
36758	35623	14041T	PARTICIPANT	\N	PRESENT	0
36812	35623	01028R	PARTICIPANT	\N	PRESENT	0
36817	35623	14051J	PARTICIPANT	\N	PRESENT	0
36818	35623	11012A	PARTICIPANT	\N	PRESENT	0
36834	35623	14103D	PARTICIPANT	\N	PRESENT	0
36820	35623	04088S	PARTICIPANT	\N	PRESENT	0
36821	35623	88008L	PARTICIPANT	\N	PRESENT	0
36822	35623	11043H	PARTICIPANT	\N	PRESENT	0
36823	35623	08055A	PARTICIPANT	\N	PRESENT	0
36824	35623	14241N	PARTICIPANT	\N	PRESENT	0
36825	35623	04044E	PARTICIPANT	\N	PRESENT	0
36826	35623	11103C	PARTICIPANT	\N	PRESENT	0
36827	35623	14199E	PARTICIPANT	\N	PRESENT	0
36829	35623	14001X	PARTICIPANT	\N	PRESENT	0
36832	35623	08031R	PARTICIPANT	\N	PRESENT	0
36831	35623	14235Q	PARTICIPANT	\N	PRESENT	0
36833	35623	14265W	PARTICIPANT	\N	PRESENT	0
36835	35623	97011G	PARTICIPANT	\N	PRESENT	0
36836	35623	01024M	PARTICIPANT	\N	PRESENT	0
36837	35623	80013X	PARTICIPANT	\N	PRESENT	0
36838	35623	08056B	PARTICIPANT	\N	PRESENT	0
36839	35623	08019V	PARTICIPANT	\N	PRESENT	0
36872	35624	88008L	PARTICIPANT	\N	PRESENT	0
36873	35624	04086Q	PARTICIPANT	\N	PRESENT	0
36874	35624	14151M	PARTICIPANT	\N	PRESENT	0
36875	35624	14157T	PARTICIPANT	\N	PRESENT	0
36876	35624	11098Y	PARTICIPANT	\N	PRESENT	0
36750	35623	04081K	PARTICIPANT	\N	PRESENT	0
36751	35623	04056J	PARTICIPANT	\N	PRESENT	0
36877	35624	05008E	PARTICIPANT	\N	PRESENT	0
36878	35624	08018U	PARTICIPANT	\N	PRESENT	0
36879	35624	14207L	PARTICIPANT	\N	PRESENT	0
36880	35624	14030Q	PARTICIPANT	\N	PRESENT	0
36881	35624	14041T	PARTICIPANT	\N	PRESENT	0
36882	35624	14219Q	PARTICIPANT	\N	PRESENT	0
36883	35624	14235Q	PARTICIPANT	\N	PRESENT	0
36884	35624	01024M	PARTICIPANT	\N	PRESENT	0
36885	35624	14133K	PARTICIPANT	\N	PRESENT	0
36886	35624	01015L	PARTICIPANT	\N	PRESENT	0
36887	35624	14001X	PARTICIPANT	\N	PRESENT	0
36888	35624	04053F	PARTICIPANT	\N	PRESENT	0
36889	35624	01028R	PARTICIPANT	\N	PRESENT	0
36890	35624	01016M	PARTICIPANT	\N	PRESENT	0
36891	35624	04080J	PARTICIPANT	\N	PRESENT	0
36892	35624	08051V	PARTICIPANT	\N	PRESENT	0
36895	35624	14033T	PARTICIPANT	\N	PRESENT	0
36896	35624	14265W	PARTICIPANT	\N	PRESENT	0
36981	36893	01031L	PARTICIPANT	\N	PRESENT	0
36982	36893	01016M	PARTICIPANT	\N	PRESENT	0
36983	36893	08016S	PARTICIPANT	\N	PRESENT	0
36984	36893	11040E	PARTICIPANT	\N	PRESENT	0
36985	36893	01013J	PARTICIPANT	\N	PRESENT	0
36986	36893	14197C	PARTICIPANT	\N	PRESENT	0
36987	36893	95037J	PARTICIPANT	\N	PRESENT	0
36870	35624	04066L	PARTICIPANT	\N	PRESENT	0
36871	35624	11099A	PARTICIPANT	\N	PRESENT	0
36988	36893	95063L	PARTICIPANT	\N	PRESENT	0
36989	36893	11057P	PARTICIPANT	\N	PRESENT	0
36990	36893	14225N	PARTICIPANT	\N	PRESENT	0
36991	36893	04034C	PARTICIPANT	\N	PRESENT	0
36992	36893	98046X	PARTICIPANT	\N	PRESENT	0
36993	36893	14085U	PARTICIPANT	\N	PRESENT	0
36994	36893	14159V	PARTICIPANT	\N	PRESENT	0
36995	36893	11037K	PARTICIPANT	\N	PRESENT	0
36996	36893	88008L	PARTICIPANT	\N	PRESENT	0
36997	36893	11012A	PARTICIPANT	\N	PRESENT	0
36998	36893	11053K	PARTICIPANT	\N	PRESENT	0
36999	36893	07004J	PARTICIPANT	\N	PRESENT	0
37000	36893	11070L	PARTICIPANT	\N	PRESENT	0
37001	36893	14083S	PARTICIPANT	\N	PRESENT	0
37003	36893	14275Y	PARTICIPANT	\N	PRESENT	0
37004	36893	14277B	PARTICIPANT	\N	PRESENT	0
37005	36893	89017R	PARTICIPANT	\N	PRESENT	0
37006	36893	14079W	PARTICIPANT	\N	PRESENT	0
36965	36893	04081K	PARTICIPANT	\N	PRESENT	0
36980	36893	08011M	PARTICIPANT	\N	PRESENT	0
37007	36893	99004R	PARTICIPANT	\N	PRESENT	0
37008	36893	95015C	PARTICIPANT	\N	PRESENT	0
37009	36893	04086Q	PARTICIPANT	\N	PRESENT	0
37010	36893	98050T	PARTICIPANT	\N	PRESENT	0
37011	36893	11100Y	PARTICIPANT	\N	PRESENT	0
37012	36893	04057K	PARTICIPANT	\N	PRESENT	0
37013	36893	14327T	PARTICIPANT	\N	PRESENT	0
37014	36893	08034U	PARTICIPANT	\N	PRESENT	0
37015	36893	80027E	PARTICIPANT	\N	PRESENT	0
37016	36893	04043D	PARTICIPANT	\N	PRESENT	0
37017	36893	01057W	PARTICIPANT	\N	PRESENT	0
37076	36893	01027Q	PARTICIPANT	\N	PRESENT	0
37019	36893	07029T	PARTICIPANT	\N	PRESENT	0
37020	36893	11071M	PARTICIPANT	\N	PRESENT	0
37021	36893	14041T	PARTICIPANT	\N	PRESENT	0
37022	36893	14063N	PARTICIPANT	\N	PRESENT	0
37023	36893	98005N	PARTICIPANT	\N	PRESENT	0
37024	36893	04071H	PARTICIPANT	\N	PRESENT	0
37025	36893	95030B	PARTICIPANT	\N	PRESENT	0
37026	36893	11103C	PARTICIPANT	\N	PRESENT	0
37027	36893	14039A	PARTICIPANT	\N	PRESENT	0
37028	36893	11048N	PARTICIPANT	\N	PRESENT	0
37029	36893	11083R	PARTICIPANT	\N	PRESENT	0
37030	36893	14269B	PARTICIPANT	\N	PRESENT	0
37031	36893	08017T	PARTICIPANT	\N	PRESENT	0
37032	36893	08043V	PARTICIPANT	\N	PRESENT	0
37033	36893	14073Q	PARTICIPANT	\N	PRESENT	0
37034	36893	08069G	PARTICIPANT	\N	PRESENT	0
37052	36893	14217N	PARTICIPANT	\N	PRESENT	0
37053	36893	07024N	PARTICIPANT	\N	PRESENT	0
37054	36893	04088S	PARTICIPANT	\N	PRESENT	0
37055	36893	14105F	PARTICIPANT	\N	PRESENT	0
37056	36893	08073C	PARTICIPANT	\N	PRESENT	0
37058	36893	98053W	PARTICIPANT	\N	PRESENT	0
37066	36893	14147R	PARTICIPANT	\N	PRESENT	0
37067	36893	14261S	PARTICIPANT	\N	PRESENT	0
37068	36893	14201E	PARTICIPANT	\N	PRESENT	0
37069	36893	14001X	PARTICIPANT	\N	PRESENT	0
37070	36893	14030Q	PARTICIPANT	\N	PRESENT	0
37071	36893	14265W	PARTICIPANT	\N	PRESENT	0
37072	36893	97011G	PARTICIPANT	\N	PRESENT	0
37073	36893	08039A	PARTICIPANT	\N	PRESENT	0
37074	36893	14175V	PARTICIPANT	\N	PRESENT	0
37075	36893	14259Y	PARTICIPANT	\N	PRESENT	0
37077	36893	14199E	PARTICIPANT	\N	PRESENT	0
37078	36893	14249W	PARTICIPANT	\N	PRESENT	0
37079	36893	11088W	PARTICIPANT	\N	PRESENT	0
37193	36894	08055A	PARTICIPANT	\N	PRESENT	0
37194	36894	01013J	PARTICIPANT	\N	PRESENT	0
37195	36894	14063N	PARTICIPANT	\N	PRESENT	0
37196	36894	14159V	PARTICIPANT	\N	PRESENT	0
37197	36894	11012A	PARTICIPANT	\N	PRESENT	0
37198	36894	95049N	PARTICIPANT	\N	PRESENT	0
37199	36894	14073Q	PARTICIPANT	\N	PRESENT	0
37200	36894	14083S	PARTICIPANT	\N	PRESENT	0
37201	36894	14041T	PARTICIPANT	\N	PRESENT	0
37202	36894	01031L	PARTICIPANT	\N	PRESENT	0
37203	36894	98053W	PARTICIPANT	\N	PRESENT	0
37204	36894	11040E	PARTICIPANT	\N	PRESENT	0
37205	36894	04071H	PARTICIPANT	\N	PRESENT	0
37206	36894	14175V	PARTICIPANT	\N	PRESENT	0
37207	36894	01027Q	PARTICIPANT	\N	PRESENT	0
37208	36894	01057W	PARTICIPANT	\N	PRESENT	0
37209	36894	98050T	PARTICIPANT	\N	PRESENT	0
37210	36894	08016S	PARTICIPANT	\N	PRESENT	0
37211	36894	14033T	PARTICIPANT	\N	PRESENT	0
37212	36894	11053K	PARTICIPANT	\N	PRESENT	0
37213	36894	04034C	PARTICIPANT	\N	PRESENT	0
37214	36894	11088W	PARTICIPANT	\N	PRESENT	0
37216	36894	14001X	PARTICIPANT	\N	PRESENT	0
37219	36894	11042G	PARTICIPANT	\N	PRESENT	0
37220	36894	11057P	PARTICIPANT	\N	PRESENT	0
37225	36894	14061L	PARTICIPANT	\N	PRESENT	0
37226	36894	14085U	PARTICIPANT	\N	PRESENT	0
37227	36894	98046X	PARTICIPANT	\N	PRESENT	0
37236	36894	95015C	PARTICIPANT	\N	PRESENT	0
37237	36894	08011M	PARTICIPANT	\N	PRESENT	0
37238	36894	08034U	PARTICIPANT	\N	PRESENT	0
37239	36894	14051J	PARTICIPANT	\N	PRESENT	0
37240	36894	11048N	PARTICIPANT	\N	PRESENT	0
37241	36894	14217N	PARTICIPANT	\N	PRESENT	0
37242	36894	14225N	PARTICIPANT	\N	PRESENT	0
37243	36894	14199E	PARTICIPANT	\N	PRESENT	0
37244	36894	14265W	PARTICIPANT	\N	PRESENT	0
37245	36894	98005N	PARTICIPANT	\N	PRESENT	0
37246	36894	11023D	PARTICIPANT	\N	PRESENT	0
43166	40901	01022K	PARTICIPANT	\N	EXCUSE	0
43167	40901	14053L	PARTICIPANT	\N	EXCUSE	0
43217	40901	04094Q	PARTICIPANT	\N	EXCUSE	0
43222	41619	04094Q	PARTICIPANT	\N	EXCUSE	0
43223	40901	14034U	PARTICIPANT	\N	EXCUSE	0
46686	41619	01022K	PARTICIPANT	\N	PRESENT	0
46687	41619	11071M	PARTICIPANT	\N	PRESENT	0
46688	41619	08019V	PRESIDENT	0	PRESENT	0
46689	41619	11106F	PARTICIPANT	\N	PRESENT	0
46690	41619	14053L	PARTICIPANT	\N	PRESENT	0
46691	41619	11064N	PARTICIPANT	\N	PRESENT	0
46692	41619	11113E	PARTICIPANT	\N	EXCUSE	0
46695	41619	11023D	PARTICIPANT	\N	PRESENT	0
46752	46751	01041N	PARTICIPANT	\N	PRESENT	0
48349	47942	14018U	PARTICIPANT	\N	PRESENT	0
48350	47942	08069G	PARTICIPANT	\N	PRESENT	0
48353	47942	11026G	PARTICIPANT	\N	PRESENT	0
48355	47942	92045V	PARTICIPANT	\N	PRESENT	0
48356	47942	04071H	PARTICIPANT	\N	PRESENT	0
48357	47942	11061K	PARTICIPANT	\N	PRESENT	0
48358	47942	92020L	PARTICIPANT	\N	PRESENT	0
48359	47942	11112D	PARTICIPANT	\N	PRESENT	0
48360	47942	92039X	PARTICIPANT	\N	PRESENT	0
48361	47942	14109K	PARTICIPANT	\N	PRESENT	0
48362	47942	14237S	PARTICIPANT	\N	PRESENT	0
48363	47942	04036E	PARTICIPANT	\N	PRESENT	0
48364	47942	14199E	PARTICIPANT	\N	PRESENT	0
48365	47942	10015M	PARTICIPANT	\N	PRESENT	0
48366	47942	04045F	PARTICIPANT	\N	PRESENT	0
48397	47941	08011M	PARTICIPANT	\N	PRESENT	0
48368	47941	08062Y	PARTICIPANT	\N	PRESENT	0
48369	47941	04088S	PARTICIPANT	\N	PRESENT	0
48370	47941	07032N	PARTICIPANT	\N	PRESENT	0
48371	47941	14014Q	PARTICIPANT	\N	PRESENT	0
48372	47941	14215L	PARTICIPANT	\N	PRESENT	0
48373	47941	11099A	PARTICIPANT	\N	PRESENT	0
48374	47941	14247U	PARTICIPANT	\N	PRESENT	0
48375	47941	14201E	PARTICIPANT	\N	PRESENT	0
48376	47941	14018U	PARTICIPANT	\N	PRESENT	0
48377	47941	11040E	PARTICIPANT	\N	PRESENT	0
48378	47941	14087W	PARTICIPANT	\N	PRESENT	0
48379	47941	04034C	PARTICIPANT	\N	PRESENT	0
48380	47941	14028W	PARTICIPANT	\N	PRESENT	0
48381	47941	01022K	PARTICIPANT	\N	PRESENT	0
48382	47941	11035H	PARTICIPANT	\N	PRESENT	0
48383	47941	04057K	PARTICIPANT	\N	PRESENT	0
48384	47941	01008M	PARTICIPANT	\N	PRESENT	0
48385	47941	07029T	PARTICIPANT	\N	PRESENT	0
48386	47941	14105F	PARTICIPANT	\N	PRESENT	0
48387	47941	14265W	PARTICIPANT	\N	PRESENT	0
48388	47941	04054G	PARTICIPANT	\N	PRESENT	0
48389	47941	11083R	PARTICIPANT	\N	PRESENT	0
48390	47941	01003G	PARTICIPANT	\N	PRESENT	0
48391	47941	11091R	PARTICIPANT	\N	PRESENT	0
48392	47941	11101A	PARTICIPANT	\N	PRESENT	0
48393	47941	04097T	PARTICIPANT	\N	PRESENT	0
48394	47941	98018T	PARTICIPANT	\N	PRESENT	0
48395	47941	14263U	PARTICIPANT	\N	PRESENT	0
48396	47941	96004D	PARTICIPANT	\N	PRESENT	0
48398	47941	04081K	PARTICIPANT	\N	PRESENT	0
48399	47941	95062K	PARTICIPANT	\N	PRESENT	0
48400	47941	04080J	PARTICIPANT	\N	PRESENT	0
48401	47941	08068F	PARTICIPANT	\N	PRESENT	0
48402	47941	04045F	PARTICIPANT	\N	PRESENT	0
48403	47941	04061F	PARTICIPANT	\N	PRESENT	0
48404	47941	14223L	PARTICIPANT	\N	PRESENT	0
48405	47941	98046X	PARTICIPANT	\N	PRESENT	0
48406	47941	14133K	PARTICIPANT	\N	PRESENT	0
48407	47941	11103C	PARTICIPANT	\N	PRESENT	0
48408	47941	11026G	PARTICIPANT	\N	PRESENT	0
48409	47941	95030B	PARTICIPANT	\N	PRESENT	0
48410	47941	11063M	PARTICIPANT	\N	PRESENT	0
48411	47941	95035G	PARTICIPANT	\N	PRESENT	0
48412	47941	11059R	PARTICIPANT	\N	PRESENT	0
48413	47941	14033T	PARTICIPANT	\N	PRESENT	0
48414	47941	11036J	PARTICIPANT	\N	PRESENT	0
48415	47941	11097X	PARTICIPANT	\N	PRESENT	0
48416	47941	14103D	PARTICIPANT	\N	PRESENT	0
48417	47941	14257W	PARTICIPANT	\N	PRESENT	0
48418	47941	08052W	PARTICIPANT	\N	PRESENT	0
48419	47941	11114F	PARTICIPANT	\N	PRESENT	0
48420	47941	98035U	PARTICIPANT	\N	PRESENT	0
48421	47941	08047A	PARTICIPANT	\N	PRESENT	0
48422	47941	01016M	PARTICIPANT	\N	PRESENT	0
48423	47941	08017T	PARTICIPANT	\N	PRESENT	0
48424	47941	07004J	PARTICIPANT	\N	PRESENT	0
48425	47941	14079W	PARTICIPANT	\N	PRESENT	0
48426	47941	14135M	PARTICIPANT	\N	PRESENT	0
48427	47941	14107H	PARTICIPANT	\N	PRESENT	0
48428	47941	14217N	PARTICIPANT	\N	PRESENT	0
48429	47941	87003B	PARTICIPANT	\N	PRESENT	0
48430	47941	97011G	PARTICIPANT	\N	PRESENT	0
48479	47941	01024M	PARTICIPANT	\N	PRESENT	0
48480	47941	10015M	PARTICIPANT	\N	PRESENT	0
48481	47941	11098Y	PARTICIPANT	\N	PRESENT	0
52280	49876	01044R	PARTICIPANT	\N	EXCUSE	0
54779	54332	80013X	PARTICIPANT	\N	PRESENT	0
54753	54332	08009T	PARTICIPANT	\N	PRESENT	0
54754	54332	14093U	PARTICIPANT	\N	PRESENT	0
54755	54332	11090Q	PARTICIPANT	\N	PRESENT	0
54756	54332	11065P	PARTICIPANT	\N	PRESENT	0
54880	54879	95049N	PARTICIPANT	\N	PRESENT	0
54758	54332	01015L	PARTICIPANT	\N	PRESENT	0
54759	54332	01044R	PARTICIPANT	\N	PRESENT	0
54760	54332	13002U	PARTICIPANT	\N	PRESENT	0
54761	54332	08060W	PARTICIPANT	\N	PRESENT	0
54762	54332	11107G	PARTICIPANT	\N	PRESENT	0
54780	54332	11070L	PARTICIPANT	\N	PRESENT	0
54781	54332	14041T	PARTICIPANT	\N	PRESENT	0
54765	54332	11099A	PARTICIPANT	\N	PRESENT	0
54766	54332	14030Q	PARTICIPANT	\N	PRESENT	0
54767	54332	11103C	PARTICIPANT	\N	PRESENT	0
54768	54332	14261S	PARTICIPANT	\N	PRESENT	0
54769	54332	01056V	PARTICIPANT	\N	PRESENT	0
54778	54332	04066L	PARTICIPANT	\N	PRESENT	0
54771	54332	98005N	PARTICIPANT	\N	PRESENT	0
54876	54875	95049N	PARTICIPANT	\N	PRESENT	0
54878	54877	95049N	PARTICIPANT	\N	PRESENT	0
54774	54332	98023Q	PARTICIPANT	\N	PRESENT	0
54775	54332	01022K	PARTICIPANT	\N	PRESENT	0
54882	54881	95049N	PARTICIPANT	\N	PRESENT	0
55326	55325	14042U	PARTICIPANT	\N	PRESENT	0
57998	57997	11076S	PARTICIPANT	\N	PRESENT	0
57999	57997	08069G	PARTICIPANT	\N	PRESENT	0
58000	57997	07004J	PARTICIPANT	\N	PRESENT	0
58001	57997	11082Q	PARTICIPANT	\N	PRESENT	0
58012	58011	04040A	PARTICIPANT	\N	PRESENT	0
58013	58011	14042U	PARTICIPANT	\N	PRESENT	0
58014	58011	11083R	PARTICIPANT	\N	PRESENT	0
58015	58011	14033T	PARTICIPANT	\N	PRESENT	0
58016	58011	14097Y	PARTICIPANT	\N	PRESENT	0
58017	58011	14059S	PARTICIPANT	\N	PRESENT	0
58018	58011	04057K	PARTICIPANT	\N	PRESENT	0
58019	58011	14071N	PARTICIPANT	\N	PRESENT	0
58020	58011	04043D	PARTICIPANT	\N	PRESENT	0
58021	58011	11043H	PARTICIPANT	\N	PRESENT	0
58048	58047	08051V	PARTICIPANT	\N	PRESENT	0
58049	58047	04038G	PARTICIPANT	\N	PRESENT	0
58050	58047	01048V	PARTICIPANT	\N	PRESENT	0
58051	58047	14097Y	PARTICIPANT	\N	PRESENT	0
58052	58047	04042C	PARTICIPANT	\N	PRESENT	0
58053	58047	14079W	PARTICIPANT	\N	PRESENT	0
58054	58047	08011M	PARTICIPANT	\N	PRESENT	0
58055	58047	07024N	PARTICIPANT	\N	PRESENT	0
58056	58047	14175V	PARTICIPANT	\N	PRESENT	0
58057	58047	11026G	PARTICIPANT	\N	PRESENT	0
58058	58047	04080J	PARTICIPANT	\N	PRESENT	0
58059	58047	01057W	PARTICIPANT	\N	PRESENT	0
58064	57516	83042R	PARTICIPANT	\N	EXCUSE	0
58366	57886	01025N	PARTICIPANT	\N	PRESENT	0
58347	57886	11067R	PARTICIPANT	\N	PRESENT	0
58348	57886	11036J	PARTICIPANT	\N	PRESENT	0
58349	57886	14013P	PARTICIPANT	\N	PRESENT	0
58350	57886	14159V	PARTICIPANT	\N	PRESENT	0
58351	57886	14063N	PARTICIPANT	\N	PRESENT	0
58352	57886	11056N	PARTICIPANT	\N	PRESENT	0
58353	57886	08058D	PARTICIPANT	\N	PRESENT	0
58354	57886	11066Q	PARTICIPANT	\N	PRESENT	0
58355	57886	14065Q	PARTICIPANT	\N	PRESENT	0
58356	57886	14219Q	PARTICIPANT	\N	PRESENT	0
58357	57886	14205J	PARTICIPANT	\N	PRESENT	0
58358	57886	14231L	PARTICIPANT	\N	PRESENT	0
58359	57886	08044W	PARTICIPANT	\N	PRESENT	0
58360	57886	01047U	PARTICIPANT	\N	PRESENT	0
58361	57886	88008L	PARTICIPANT	\N	PRESENT	0
58362	57886	04038G	PARTICIPANT	\N	PRESENT	0
58363	57886	11012A	PARTICIPANT	\N	PRESENT	0
58364	57886	14018U	PARTICIPANT	\N	PRESENT	0
58365	57886	11040E	PARTICIPANT	\N	PRESENT	0
32941	31697	04066L	PARTICIPANT	\N	PRESENT	0
32942	31697	14037X	PARTICIPANT	\N	PRESENT	0
32943	31697	14265W	PARTICIPANT	\N	PRESENT	0
32944	31697	11088W	PARTICIPANT	\N	PRESENT	0
32945	31697	08041T	PARTICIPANT	\N	PRESENT	0
32946	31697	14169X	PARTICIPANT	\N	PRESENT	0
32947	31697	14227Q	PARTICIPANT	\N	PRESENT	0
32948	31697	14235Q	PARTICIPANT	\N	PRESENT	0
32949	31697	01059Y	PARTICIPANT	\N	PRESENT	0
32950	31697	11031D	PARTICIPANT	\N	PRESENT	0
32951	31697	07026Q	PARTICIPANT	\N	PRESENT	0
32952	31697	11063M	PARTICIPANT	\N	PRESENT	0
32953	31697	14151M	PARTICIPANT	\N	PRESENT	0
32954	31697	08052W	PARTICIPANT	\N	PRESENT	0
32955	31697	11067R	PARTICIPANT	\N	PRESENT	0
32956	31697	00003C	PARTICIPANT	\N	PRESENT	0
32957	31697	12042Y	PARTICIPANT	\N	PRESENT	0
32958	31697	01034P	PARTICIPANT	\N	PRESENT	0
32959	31697	04092N	PARTICIPANT	\N	PRESENT	0
32960	31697	01046T	PARTICIPANT	\N	PRESENT	0
32961	31697	14217N	PARTICIPANT	\N	PRESENT	0
32962	31697	14213J	PARTICIPANT	\N	PRESENT	0
32963	31697	11091R	PARTICIPANT	\N	PRESENT	0
32964	31697	14135M	PARTICIPANT	\N	PRESENT	0
32965	31697	08019V	PARTICIPANT	\N	PRESENT	0
32966	31697	14221J	PARTICIPANT	\N	PRESENT	0
32967	31697	14219Q	PARTICIPANT	\N	PRESENT	0
32968	31697	14261S	PARTICIPANT	\N	PRESENT	0
32969	31697	14231L	PARTICIPANT	\N	PRESENT	0
32970	31697	14147R	PARTICIPANT	\N	PRESENT	0
32971	31697	11090Q	PARTICIPANT	\N	PRESENT	0
32972	31697	11026G	PARTICIPANT	\N	PRESENT	0
32973	31697	11061K	PARTICIPANT	\N	PRESENT	0
32981	31697	04053F	PARTICIPANT	\N	PRESENT	0
32982	31697	08016S	PARTICIPANT	\N	PRESENT	0
32983	31697	11044J	PARTICIPANT	\N	PRESENT	0
32984	31697	11093T	PARTICIPANT	\N	PRESENT	0
32985	31697	14083S	PARTICIPANT	\N	PRESENT	0
32986	31697	04067M	PARTICIPANT	\N	PRESENT	0
32987	31697	10006L	PARTICIPANT	\N	PRESENT	0
33001	32890	04081K	PARTICIPANT	\N	PRESENT	0
33002	32890	04092N	PARTICIPANT	\N	PRESENT	0
33003	32890	01034P	PARTICIPANT	\N	PRESENT	0
33004	32890	01059Y	PARTICIPANT	\N	PRESENT	0
33005	32890	11031D	PARTICIPANT	\N	PRESENT	0
33006	32890	00003C	PARTICIPANT	\N	PRESENT	0
33007	32890	08052W	PARTICIPANT	\N	PRESENT	0
33008	32890	12042Y	PARTICIPANT	\N	PRESENT	0
33009	32890	11023D	PARTICIPANT	\N	PRESENT	0
33010	32890	11063M	PARTICIPANT	\N	PRESENT	0
33011	32890	11067R	PARTICIPANT	\N	PRESENT	0
33012	32890	11093T	PARTICIPANT	\N	PRESENT	0
33013	32890	11103C	PARTICIPANT	\N	PRESENT	0
33014	32890	14147R	PARTICIPANT	\N	PRESENT	0
33015	32890	08041T	PARTICIPANT	\N	PRESENT	0
33016	32890	14261S	PARTICIPANT	\N	PRESENT	0
33017	32890	04053F	PARTICIPANT	\N	PRESENT	0
33018	32890	11061K	PARTICIPANT	\N	PRESENT	0
33019	32890	14227Q	PARTICIPANT	\N	PRESENT	0
33020	32890	14073Q	PARTICIPANT	\N	PRESENT	0
33021	32890	04067M	PARTICIPANT	\N	PRESENT	0
33022	32890	04085P	PARTICIPANT	\N	PRESENT	0
33023	32890	98018T	PARTICIPANT	\N	PRESENT	0
33024	32890	10006L	PARTICIPANT	\N	PRESENT	0
33025	32890	08016S	PARTICIPANT	\N	PRESENT	0
33028	32890	11044J	PARTICIPANT	\N	PRESENT	0
33029	32890	11107G	PARTICIPANT	\N	PRESENT	0
33030	32890	95015C	PARTICIPANT	\N	PRESENT	0
33031	32890	14269B	PARTICIPANT	\N	PRESENT	0
33043	32890	11088W	PARTICIPANT	\N	PRESENT	0
33044	32890	14271U	PARTICIPANT	\N	PRESENT	0
33045	32890	01003G	PARTICIPANT	\N	PRESENT	0
33059	32890	08018U	PARTICIPANT	\N	PRESENT	0
33090	32891	01059Y	PARTICIPANT	\N	PRESENT	0
33091	32891	11031D	PARTICIPANT	\N	PRESENT	0
33092	32891	11063M	PARTICIPANT	\N	PRESENT	0
33093	32891	14227Q	PARTICIPANT	\N	PRESENT	0
33094	32891	14271U	PARTICIPANT	\N	PRESENT	0
33095	32891	00003C	PARTICIPANT	\N	PRESENT	0
33096	32891	08052W	PARTICIPANT	\N	PRESENT	0
33097	32891	04067M	PARTICIPANT	\N	PRESENT	0
33098	32891	11093T	PARTICIPANT	\N	PRESENT	0
33099	32891	11103C	PARTICIPANT	\N	PRESENT	0
33100	32891	11044J	PARTICIPANT	\N	PRESENT	0
33101	32891	04092N	PARTICIPANT	\N	PRESENT	0
33102	32891	01034P	PARTICIPANT	\N	PRESENT	0
33103	32891	08041T	PARTICIPANT	\N	PRESENT	0
33104	32891	98018T	PARTICIPANT	\N	PRESENT	0
33105	32891	11061K	PARTICIPANT	\N	PRESENT	0
33106	32891	10006L	PARTICIPANT	\N	PRESENT	0
33107	32891	11067R	PARTICIPANT	\N	PRESENT	0
33108	32891	04053F	PARTICIPANT	\N	PRESENT	0
33109	32891	11071M	PARTICIPANT	\N	PRESENT	0
33110	32891	14261S	PARTICIPANT	\N	PRESENT	0
33111	32891	08019V	PARTICIPANT	\N	PRESENT	0
33112	32891	11023D	PARTICIPANT	\N	PRESENT	0
33113	32891	04094Q	PARTICIPANT	\N	PRESENT	0
33088	32891	08024S	PARTICIPANT	\N	PRESENT	0
33089	32891	01015L	PARTICIPANT	\N	PRESENT	0
33114	32891	11088W	PARTICIPANT	\N	PRESENT	0
33115	32891	11107G	PARTICIPANT	\N	PRESENT	0
33116	32891	14269B	PARTICIPANT	\N	PRESENT	0
33117	32891	14073Q	PARTICIPANT	\N	PRESENT	0
33118	32891	01003G	PARTICIPANT	\N	PRESENT	0
33119	32891	11091R	PARTICIPANT	\N	PRESENT	0
33120	32891	04066L	PARTICIPANT	\N	PRESENT	0
33121	32891	99004R	PARTICIPANT	\N	PRESENT	0
33122	32891	14053L	PARTICIPANT	\N	PRESENT	0
33123	32891	07029T	PARTICIPANT	\N	PRESENT	0
33126	32891	14221J	PARTICIPANT	\N	PRESENT	0
33127	32891	95015C	PARTICIPANT	\N	PRESENT	0
33128	32891	01019Q	PARTICIPANT	\N	PRESENT	0
33129	28666	01044R	PARTICIPANT	\N	EXCUSE	0
33132	28666	04061F	PARTICIPANT	\N	PRESENT	0
33141	31687	01060R	PARTICIPANT	\N	PRESENT	0
33145	33144	14135M	PARTICIPANT	\N	PRESENT	0
34790	33348	14263U	PARTICIPANT	\N	PRESENT	0
34791	33348	01059Y	PARTICIPANT	\N	PRESENT	0
34792	33348	14211G	PARTICIPANT	\N	PRESENT	0
34793	33348	01056V	PARTICIPANT	\N	PRESENT	0
34794	33348	95062K	PARTICIPANT	\N	PRESENT	0
34795	33348	11060J	PARTICIPANT	\N	PRESENT	0
34796	33348	04036E	PARTICIPANT	\N	PRESENT	0
34797	33348	01027Q	PARTICIPANT	\N	PRESENT	0
34798	33348	96004D	PARTICIPANT	\N	PRESENT	0
34799	33348	95031C	PARTICIPANT	\N	PRESENT	0
34800	33348	86034E	PARTICIPANT	\N	PRESENT	0
34801	33348	95030B	PARTICIPANT	\N	PRESENT	0
34802	33348	04041B	PARTICIPANT	\N	PRESENT	0
34803	33348	14223L	PARTICIPANT	\N	PRESENT	0
34804	33348	08010L	PARTICIPANT	\N	PRESENT	0
34805	33348	08022Q	PARTICIPANT	\N	PRESENT	0
34806	33348	08039A	PARTICIPANT	\N	PRESENT	0
34807	33348	95059Q	PARTICIPANT	\N	PRESENT	0
34808	33348	89029V	PARTICIPANT	\N	PRESENT	0
34809	33348	01019Q	PARTICIPANT	\N	PRESENT	0
34810	33348	08028W	PARTICIPANT	\N	PRESENT	0
34811	33348	11080N	PARTICIPANT	\N	PRESENT	0
34812	33348	14191V	PARTICIPANT	\N	PRESENT	0
34813	33348	08041T	PARTICIPANT	\N	PRESENT	0
34814	33348	87003B	PARTICIPANT	\N	PRESENT	0
34815	33348	99004R	PARTICIPANT	\N	PRESENT	0
34816	33348	14071N	PARTICIPANT	\N	PRESENT	0
34817	33348	01057W	PARTICIPANT	\N	PRESENT	0
34818	33348	95041E	PARTICIPANT	\N	PRESENT	0
34819	33348	11030C	PARTICIPANT	\N	PRESENT	0
34820	33348	90003B	PARTICIPANT	\N	PRESENT	0
34821	33348	04057K	PARTICIPANT	\N	PRESENT	0
34822	33348	11010L	PARTICIPANT	\N	PRESENT	0
34823	33348	10006L	PARTICIPANT	\N	PRESENT	0
34824	33348	14041T	PARTICIPANT	\N	PRESENT	0
34825	33348	04088S	PARTICIPANT	\N	PRESENT	0
34826	33348	07024N	PARTICIPANT	\N	PRESENT	0
34827	33348	04085P	PARTICIPANT	\N	PRESENT	0
34828	33348	04092N	PARTICIPANT	\N	PRESENT	0
34829	33348	02002K	PARTICIPANT	\N	PRESENT	0
34830	33348	01013J	PARTICIPANT	\N	PRESENT	0
34831	33348	98018T	PARTICIPANT	\N	PRESENT	0
34832	33348	14169X	PARTICIPANT	\N	PRESENT	0
34833	33348	11063M	PARTICIPANT	\N	PRESENT	0
34834	33348	95015C	PARTICIPANT	\N	PRESENT	0
34835	33348	04097T	PARTICIPANT	\N	PRESENT	0
34836	33348	14135M	PARTICIPANT	\N	PRESENT	0
34837	33348	11031D	PARTICIPANT	\N	PRESENT	0
34838	33348	07026Q	PARTICIPANT	\N	PRESENT	0
34839	33348	14235Q	PARTICIPANT	\N	PRESENT	0
44125	44122	98053W	PARTICIPANT	\N	PRESENT	0
44126	44122	11040E	PARTICIPANT	\N	PRESENT	0
44127	44122	08011M	PARTICIPANT	\N	PRESENT	0
44128	44122	01031L	PARTICIPANT	\N	PRESENT	0
44129	44122	11057P	PARTICIPANT	\N	PRESENT	0
44130	44122	98046X	PARTICIPANT	\N	PRESENT	0
44131	44122	14261S	PARTICIPANT	\N	PRESENT	0
44132	44122	11083R	PARTICIPANT	\N	PRESENT	0
44133	44122	11070L	PARTICIPANT	\N	PRESENT	0
44134	44122	04086Q	PARTICIPANT	\N	PRESENT	0
44135	44122	14175V	PARTICIPANT	\N	PRESENT	0
44136	44122	14041T	PARTICIPANT	\N	PRESENT	0
44137	44122	08019V	PARTICIPANT	\N	PRESENT	0
44138	44122	01048V	PARTICIPANT	\N	PRESENT	0
44139	44122	14225N	PARTICIPANT	\N	PRESENT	0
44140	44122	80013X	PARTICIPANT	\N	PRESENT	0
44141	44122	04048J	PARTICIPANT	\N	PRESENT	0
44142	44122	04043D	PARTICIPANT	\N	PRESENT	0
44143	44122	11053K	PARTICIPANT	\N	PRESENT	0
44144	44122	11088W	PARTICIPANT	\N	PRESENT	0
44145	44122	11023D	PARTICIPANT	\N	PRESENT	0
44146	44122	98018T	PARTICIPANT	\N	PRESENT	0
44147	44122	11068S	PARTICIPANT	\N	PRESENT	0
44148	44122	07004J	PARTICIPANT	\N	PRESENT	0
44149	44122	04059M	PARTICIPANT	\N	PRESENT	0
44150	44122	04034C	PARTICIPANT	\N	PRESENT	0
44151	44122	01041N	PARTICIPANT	\N	PRESENT	0
44183	44123	11083R	PARTICIPANT	\N	PRESENT	0
44184	44123	08019V	PARTICIPANT	\N	PRESENT	0
44185	44123	98018T	PARTICIPANT	\N	PRESENT	0
44186	44123	14041T	PARTICIPANT	\N	PRESENT	0
44187	44123	07029T	PARTICIPANT	\N	PRESENT	0
44188	44123	04059M	PARTICIPANT	\N	PRESENT	0
44189	44123	11103C	PARTICIPANT	\N	PRESENT	0
44190	44123	07024N	PARTICIPANT	\N	PRESENT	0
44191	44123	04086Q	PARTICIPANT	\N	PRESENT	0
44192	44123	08011M	PARTICIPANT	\N	PRESENT	0
44193	44123	14261S	PARTICIPANT	\N	PRESENT	0
44194	44123	07004J	PARTICIPANT	\N	PRESENT	0
44195	44123	14225N	PARTICIPANT	\N	PRESENT	0
44196	44123	11053K	PARTICIPANT	\N	PRESENT	0
44197	44123	95030B	PARTICIPANT	\N	PRESENT	0
44198	44123	98053W	PARTICIPANT	\N	PRESENT	0
44199	44123	01031L	PARTICIPANT	\N	PRESENT	0
44200	44123	14175V	PARTICIPANT	\N	PRESENT	0
44201	44123	01041N	PARTICIPANT	\N	PRESENT	0
44202	44123	04061F	PARTICIPANT	\N	PRESENT	0
44203	44123	99004R	PARTICIPANT	\N	PRESENT	0
44204	44123	98046X	PARTICIPANT	\N	PRESENT	0
44205	44123	01048V	PARTICIPANT	\N	PRESENT	0
44206	44123	04048J	PARTICIPANT	\N	PRESENT	0
44207	44123	11023D	PARTICIPANT	\N	PRESENT	0
44208	44123	04071H	PARTICIPANT	\N	PRESENT	0
46484	44246	04057K	PARTICIPANT	\N	PRESENT	0
44181	44123	04081K	PARTICIPANT	\N	PRESENT	0
44182	44123	04034C	PARTICIPANT	\N	PRESENT	0
46485	44246	01024M	PARTICIPANT	\N	PRESENT	0
46486	44246	14103D	PARTICIPANT	\N	PRESENT	0
46487	44246	08068F	PARTICIPANT	\N	PRESENT	0
46488	44246	14026U	PARTICIPANT	\N	PRESENT	0
46489	44246	14217N	PARTICIPANT	\N	PRESENT	0
46490	44246	10006L	PARTICIPANT	\N	PRESENT	0
46491	44246	11012A	PARTICIPANT	\N	PRESENT	0
46492	44246	08010L	PARTICIPANT	\N	PRESENT	0
46494	44246	11097X	PARTICIPANT	\N	PRESENT	0
46495	44246	01048V	PARTICIPANT	\N	PRESENT	0
46496	44246	14053L	PARTICIPANT	\N	PRESENT	0
46497	44246	14197C	PARTICIPANT	\N	PRESENT	0
46498	44246	14069U	PARTICIPANT	\N	PRESENT	0
46499	44246	14089Y	PARTICIPANT	\N	PRESENT	0
46500	44246	08019V	PARTICIPANT	\N	PRESENT	0
46501	44246	08039A	PARTICIPANT	\N	PRESENT	0
46513	44246	01031L	PARTICIPANT	\N	PRESENT	0
46590	44247	14257W	PARTICIPANT	\N	PRESENT	0
46591	44247	14207L	PARTICIPANT	\N	PRESENT	0
46592	44247	11099A	PARTICIPANT	\N	PRESENT	0
46593	44247	14033T	PARTICIPANT	\N	PRESENT	0
46594	44247	04089T	PARTICIPANT	\N	PRESENT	0
46595	44247	14237S	PARTICIPANT	\N	PRESENT	0
46596	44247	01008M	PARTICIPANT	\N	PRESENT	0
46597	44247	08019V	PARTICIPANT	\N	PRESENT	0
46598	44247	07029T	PARTICIPANT	\N	PRESENT	0
46599	44247	14195A	PARTICIPANT	\N	PRESENT	0
46600	44247	14157T	PARTICIPANT	\N	PRESENT	0
46601	44247	14031R	PARTICIPANT	\N	PRESENT	0
46602	44247	14069U	PARTICIPANT	\N	PRESENT	0
46481	44246	98018T	PARTICIPANT	\N	PRESENT	0
46483	44246	14225N	PARTICIPANT	\N	PRESENT	0
46603	44247	90003B	PARTICIPANT	\N	PRESENT	0
46604	44247	14265W	PARTICIPANT	\N	PRESENT	0
46605	44247	96004D	PARTICIPANT	\N	PRESENT	0
46606	44247	01058X	PARTICIPANT	\N	PRESENT	0
46607	44247	14026U	PARTICIPANT	\N	PRESENT	0
46608	44247	14030Q	PARTICIPANT	\N	PRESENT	0
46609	44247	11111C	PARTICIPANT	\N	PRESENT	0
46610	44247	95030B	PARTICIPANT	\N	PRESENT	0
46611	44247	14107H	PARTICIPANT	\N	PRESENT	0
46612	44247	11090Q	PARTICIPANT	\N	PRESENT	0
46613	44247	95062K	PARTICIPANT	\N	PRESENT	0
46614	44247	14235Q	PARTICIPANT	\N	PRESENT	0
46615	44247	14219Q	PARTICIPANT	\N	PRESENT	0
46616	44247	11048N	PARTICIPANT	\N	PRESENT	0
46617	44247	11097X	PARTICIPANT	\N	PRESENT	0
46618	44247	08015R	PARTICIPANT	\N	PRESENT	0
46619	44247	14217N	PARTICIPANT	\N	PRESENT	0
46620	44247	14135M	PARTICIPANT	\N	PRESENT	0
46621	44247	14231L	PARTICIPANT	\N	PRESENT	0
46622	44247	04045F	PARTICIPANT	\N	PRESENT	0
46623	44247	08068F	PARTICIPANT	\N	PRESENT	0
46624	44247	14159V	PARTICIPANT	\N	PRESENT	0
46625	44247	05012A	PARTICIPANT	\N	PRESENT	0
46626	44247	14037X	PARTICIPANT	\N	PRESENT	0
46627	44247	80013X	PARTICIPANT	\N	PRESENT	0
46628	44247	11036J	PARTICIPANT	\N	PRESENT	0
46629	44247	11012A	PARTICIPANT	\N	PRESENT	0
46630	44247	14038Y	PARTICIPANT	\N	PRESENT	0
46631	44247	11066Q	PARTICIPANT	\N	PRESENT	0
46632	44247	14119M	PARTICIPANT	\N	PRESENT	0
46633	44247	01056V	PARTICIPANT	\N	PRESENT	0
46634	44247	01025N	PARTICIPANT	\N	PRESENT	0
46635	44247	11100Y	PARTICIPANT	\N	PRESENT	0
46636	44247	11026G	PARTICIPANT	\N	PRESENT	0
46637	44247	04049K	PARTICIPANT	\N	PRESENT	0
46638	44247	10006L	PARTICIPANT	\N	PRESENT	0
46639	44247	88008L	PARTICIPANT	\N	PRESENT	0
46640	44247	14073Q	PARTICIPANT	\N	PRESENT	0
46641	44247	08016S	PARTICIPANT	\N	PRESENT	0
46642	44247	04088S	PARTICIPANT	\N	PRESENT	0
46643	44247	92045V	PARTICIPANT	\N	PRESENT	0
46644	44247	01024M	PARTICIPANT	\N	PRESENT	0
46645	44247	89017R	PARTICIPANT	\N	PRESENT	0
46646	44247	08034U	PARTICIPANT	\N	PRESENT	0
46647	44247	98053W	PARTICIPANT	\N	PRESENT	0
46648	44247	14089Y	PARTICIPANT	\N	PRESENT	0
46696	46661	08055A	PARTICIPANT	\N	PRESENT	0
46697	46661	98046X	PARTICIPANT	\N	PRESENT	0
46698	46661	11040E	PARTICIPANT	\N	PRESENT	0
46699	46661	01031L	PARTICIPANT	\N	PRESENT	0
46700	46661	08011M	PARTICIPANT	\N	PRESENT	0
46701	46661	04034C	PARTICIPANT	\N	PRESENT	0
46702	46661	11057P	PARTICIPANT	\N	PRESENT	0
46703	46661	14085U	PARTICIPANT	\N	PRESENT	0
46704	46661	01044R	PARTICIPANT	\N	PRESENT	0
46705	46661	11083R	PARTICIPANT	\N	PRESENT	0
46706	46661	11053K	PARTICIPANT	\N	PRESENT	0
46707	46661	11100Y	PARTICIPANT	\N	PRESENT	0
46708	46661	87003B	PARTICIPANT	\N	PRESENT	0
46709	46661	14041T	PARTICIPANT	\N	PRESENT	0
46710	46661	07029T	PARTICIPANT	\N	PRESENT	0
46588	44247	08055A	PARTICIPANT	\N	PRESENT	0
46589	44247	11098Y	PARTICIPANT	\N	PRESENT	0
46711	46661	14327T	PARTICIPANT	\N	PRESENT	0
46712	46661	14175V	PARTICIPANT	\N	PRESENT	0
46713	46661	14191V	PARTICIPANT	\N	PRESENT	0
46714	46661	14033T	PARTICIPANT	\N	PRESENT	0
46715	46661	04092N	PARTICIPANT	\N	PRESENT	0
46716	46661	11043H	PARTICIPANT	\N	PRESENT	0
46717	46661	14257W	PARTICIPANT	\N	PRESENT	0
46718	46661	08043V	PARTICIPANT	\N	PRESENT	0
46719	46661	01057W	PARTICIPANT	\N	PRESENT	0
46720	46661	11012A	PARTICIPANT	\N	PRESENT	0
46721	46661	92015P	PARTICIPANT	\N	PRESENT	0
46722	46661	14271U	PARTICIPANT	\N	PRESENT	0
46723	46661	08034U	PARTICIPANT	\N	PRESENT	0
46724	46661	14159V	PARTICIPANT	\N	PRESENT	0
46725	46661	14267Y	PARTICIPANT	\N	PRESENT	0
46726	46661	95015C	PARTICIPANT	\N	PRESENT	0
46727	46661	11042G	PARTICIPANT	\N	PRESENT	0
46728	46661	14225N	PARTICIPANT	\N	PRESENT	0
36106	36104	01008M	PARTICIPANT	\N	PRESENT	0
36107	36104	11036J	PARTICIPANT	\N	PRESENT	0
36150	36104	01058X	PARTICIPANT	\N	EXCUSE	0
36109	36104	14013P	PARTICIPANT	\N	PRESENT	0
36110	36104	08068F	PARTICIPANT	\N	PRESENT	0
36111	36104	14207L	PARTICIPANT	\N	PRESENT	0
36168	36104	14093U	PARTICIPANT	\N	PRESENT	0
36113	36104	90003B	PARTICIPANT	\N	PRESENT	0
36114	36104	08028W	PARTICIPANT	\N	PRESENT	0
36115	36104	80013X	PARTICIPANT	\N	PRESENT	0
36116	36104	08038Y	PARTICIPANT	\N	PRESENT	0
36117	36104	04089T	PARTICIPANT	\N	PRESENT	0
36118	36104	14197C	PARTICIPANT	\N	PRESENT	0
36119	36104	11110B	PARTICIPANT	\N	PRESENT	0
36120	36104	14187A	PARTICIPANT	\N	PRESENT	0
36121	36104	14033T	PARTICIPANT	\N	PRESENT	0
36122	36104	14081Q	PARTICIPANT	\N	PRESENT	0
36172	36104	96004D	PARTICIPANT	\N	PRESENT	0
36124	36104	11099A	PARTICIPANT	\N	PRESENT	0
36125	36104	04049K	PARTICIPANT	\N	PRESENT	0
36170	36104	14030Q	PARTICIPANT	\N	PRESENT	0
36178	36104	11095V	PARTICIPANT	\N	PRESENT	0
36128	36104	08015R	PARTICIPANT	\N	PRESENT	0
36129	36104	11100Y	PRESIDENT	0	PRESENT	0
36182	36104	11114F	PARTICIPANT	\N	PRESENT	0
36131	36104	11098Y	PARTICIPANT	\N	PRESENT	0
36132	36104	01043Q	PARTICIPANT	\N	EXCUSE	0
36185	36104	11065P	PARTICIPANT	\N	PRESENT	0
36134	36104	14205J	PARTICIPANT	\N	PRESENT	0
36190	36104	01015L	PARTICIPANT	\N	PRESENT	0
36136	36104	14257W	PARTICIPANT	\N	PRESENT	0
36191	36104	11107G	PARTICIPANT	\N	PRESENT	0
36138	36104	04088S	PARTICIPANT	\N	PRESENT	0
36139	36104	98050T	PARTICIPANT	\N	PRESENT	0
36193	36104	01022K	PARTICIPANT	\N	PRESENT	0
36141	36104	11046L	PARTICIPANT	\N	PRESENT	0
36194	36104	11059R	PARTICIPANT	\N	PRESENT	0
36195	36104	08009T	PARTICIPANT	\N	PRESENT	0
36144	36104	11066Q	PARTICIPANT	\N	PRESENT	0
36196	36104	14221J	PARTICIPANT	\N	PRESENT	0
36197	36104	92039X	PARTICIPANT	\N	PRESENT	0
36198	36104	08042U	PARTICIPANT	\N	PRESENT	0
36200	36104	14169X	PARTICIPANT	\N	PRESENT	0
36201	36104	05012A	PARTICIPANT	\N	PRESENT	0
36203	36104	14135M	PARTICIPANT	\N	PRESENT	0
36205	36104	95062K	PARTICIPANT	\N	PRESENT	0
36209	36104	14157T	PARTICIPANT	\N	PRESENT	0
36220	36104	04045F	PARTICIPANT	\N	PRESENT	0
36223	36104	11026G	PARTICIPANT	\N	PRESENT	0
36227	36104	11035H	PARTICIPANT	\N	PRESENT	0
36232	36104	14001X	PARTICIPANT	\N	PRESENT	0
36233	36104	14133K	PARTICIPANT	\N	PRESENT	0
36234	36104	92045V	PARTICIPANT	\N	PRESENT	0
36902	36901	89017R	PARTICIPANT	\N	PRESENT	0
36903	36901	01031L	PRESIDENT	0	PRESENT	0
36904	36901	01013J	PARTICIPANT	\N	PRESENT	0
36905	36901	11068S	PARTICIPANT	\N	EXCUSE	0
36906	36901	14175V	PARTICIPANT	\N	PRESENT	0
36907	36901	14083S	PARTICIPANT	\N	PRESENT	0
36908	36901	14085U	PARTICIPANT	\N	PRESENT	0
36909	36901	11042G	PARTICIPANT	\N	PRESENT	0
36910	36901	88008L	PARTICIPANT	\N	PRESENT	0
36911	36901	04086Q	PARTICIPANT	\N	PRESENT	0
36912	36901	11070L	PARTICIPANT	\N	PRESENT	0
36913	36901	11088W	PARTICIPANT	\N	PRESENT	0
36914	36901	01027Q	PARTICIPANT	\N	PRESENT	0
36921	36901	01057W	PARTICIPANT	\N	PRESENT	0
36916	36901	08016S	PARTICIPANT	\N	PRESENT	0
36917	36901	11083R	PARTICIPANT	\N	PRESENT	0
36918	36901	04071H	PARTICIPANT	\N	PRESENT	0
36922	36901	04061F	PARTICIPANT	\N	PRESENT	0
36920	36901	14199E	PARTICIPANT	\N	PRESENT	0
36923	36901	07029T	PARTICIPANT	\N	PRESENT	0
36924	36901	14159V	PARTICIPANT	\N	PRESENT	0
36925	36901	14277B	PARTICIPANT	\N	PRESENT	0
36926	36901	08010L	PARTICIPANT	\N	PRESENT	0
36927	36901	08034U	PARTICIPANT	\N	PRESENT	0
36928	36901	98046X	PARTICIPANT	\N	PRESENT	0
36929	36901	11085T	PARTICIPANT	\N	PRESENT	0
36934	36901	11012A	PARTICIPANT	\N	PRESENT	0
36931	36901	08073C	PARTICIPANT	\N	PRESENT	0
36932	36901	01016M	PARTICIPANT	\N	PRESENT	0
36933	36901	14225N	PARTICIPANT	\N	PRESENT	0
36935	36901	11057P	PARTICIPANT	\N	PRESENT	0
36936	36901	04034C	PARTICIPANT	\N	PRESENT	0
36937	36901	11048N	PARTICIPANT	\N	PRESENT	0
36938	36901	99004R	PARTICIPANT	\N	PRESENT	0
36939	36901	08011M	PARTICIPANT	\N	PRESENT	0
37250	36894	08073C	PARTICIPANT	\N	PRESENT	0
37251	36894	14207L	PARTICIPANT	\N	PRESENT	0
37252	36894	04086Q	PARTICIPANT	\N	PRESENT	0
37253	36894	97011G	PARTICIPANT	\N	PRESENT	0
37254	36894	01016M	PARTICIPANT	\N	PRESENT	0
37258	32377	01044R	PARTICIPANT	\N	EXCUSE	0
37259	32370	01044R	PARTICIPANT	\N	EXCUSE	0
37260	36894	80013X	PARTICIPANT	\N	PRESENT	0
37261	36894	96004D	PARTICIPANT	\N	PRESENT	0
37262	36894	99004R	PARTICIPANT	\N	PRESENT	0
37263	36894	01037S	PARTICIPANT	\N	PRESENT	0
37264	36894	07029T	PARTICIPANT	\N	PRESENT	0
37265	36894	07024N	PARTICIPANT	\N	PRESENT	0
37266	36894	14013P	PARTICIPANT	\N	PRESENT	0
37267	36894	11083R	PARTICIPANT	\N	PRESENT	0
37268	36894	07026Q	PARTICIPANT	\N	PRESENT	0
37247	36894	95035G	PARTICIPANT	\N	PRESENT	0
37249	36894	14039A	PARTICIPANT	\N	PRESENT	0
37270	36894	04067M	PARTICIPANT	\N	PRESENT	0
37271	36894	08043V	PARTICIPANT	\N	PRESENT	0
37272	36894	08017T	PARTICIPANT	\N	PRESENT	0
37274	36894	11107G	PARTICIPANT	\N	PRESENT	0
37275	36894	04080J	PARTICIPANT	\N	PRESENT	0
37276	36894	98035U	PARTICIPANT	\N	PRESENT	0
37368	32370	01046T	PARTICIPANT	\N	EXCUSE	0
37369	32370	01048V	PARTICIPANT	\N	EXCUSE	0
37370	32370	14221J	PARTICIPANT	\N	PRESENT	0
37371	32370	01058X	PARTICIPANT	\N	PRESENT	0
37372	37248	83042R	PARTICIPANT	\N	EXCUSE	0
37378	32370	11036J	PARTICIPANT	\N	EXCUSE	0
38132	31452	14059S	PARTICIPANT	\N	PRESENT	0
38133	31452	14201E	PARTICIPANT	\N	EXCUSE	0
38134	31452	14093U	PARTICIPANT	\N	EXCUSE	0
38242	38241	92045V	PARTICIPANT	\N	PRESENT	0
38243	27204	08065C	PARTICIPANT	\N	PRESENT	0
38282	38042	11042G	PARTICIPANT	\N	PRESENT	0
38283	38042	11029K	PARTICIPANT	\N	PRESENT	0
38284	38042	01031L	PARTICIPANT	\N	PRESENT	0
38285	38042	08011M	PARTICIPANT	\N	PRESENT	0
38286	38042	98046X	PARTICIPANT	\N	PRESENT	0
38287	38042	11070L	PARTICIPANT	\N	PRESENT	0
38288	38042	14215L	PARTICIPANT	\N	PRESENT	0
38289	38042	04086Q	PARTICIPANT	\N	PRESENT	0
38290	38042	14059S	PARTICIPANT	\N	PRESENT	0
38291	38042	08055A	PARTICIPANT	\N	PRESENT	0
38292	38042	14175V	PARTICIPANT	\N	PRESENT	0
38293	38042	07029T	PARTICIPANT	\N	PRESENT	0
38294	38042	14105F	PARTICIPANT	\N	PRESENT	0
38295	38042	14173T	PARTICIPANT	\N	PRESENT	0
38296	38042	08014Q	PARTICIPANT	\N	PRESENT	0
38297	38042	14030Q	PARTICIPANT	\N	PRESENT	0
38298	38042	95049N	PARTICIPANT	\N	PRESENT	0
38299	38042	11057P	PARTICIPANT	\N	PRESENT	0
38300	38042	07004J	PARTICIPANT	\N	PRESENT	0
38301	38042	99004R	PARTICIPANT	\N	PRESENT	0
38302	38042	01057W	PARTICIPANT	\N	PRESENT	0
38303	38042	14053L	PARTICIPANT	\N	PRESENT	0
38304	38042	95062K	PARTICIPANT	\N	PRESENT	0
38305	38042	14147R	PARTICIPANT	\N	PRESENT	0
38306	38042	08065C	PARTICIPANT	\N	PRESENT	0
38307	38042	98023Q	PARTICIPANT	\N	PRESENT	0
38308	38042	14265W	PARTICIPANT	\N	PRESENT	0
38309	38042	11053K	PARTICIPANT	\N	PRESENT	0
38310	38042	14225N	PARTICIPANT	\N	PRESENT	0
38311	38042	14085U	PARTICIPANT	\N	PRESENT	0
38312	38042	14042U	PARTICIPANT	\N	PRESENT	0
38313	38042	14097Y	PARTICIPANT	\N	PRESENT	0
38314	38042	11107G	PARTICIPANT	\N	PRESENT	0
38315	38042	11114F	PARTICIPANT	\N	PRESENT	0
38316	38042	04077P	PARTICIPANT	\N	PRESENT	0
38317	38042	08058D	PARTICIPANT	\N	PRESENT	0
38318	38042	11074Q	PARTICIPANT	\N	PRESENT	0
38319	38042	11037K	PARTICIPANT	\N	PRESENT	0
38320	38042	14083S	PARTICIPANT	\N	PRESENT	0
38321	38042	01027Q	PARTICIPANT	\N	PRESENT	0
38322	38042	14069U	PARTICIPANT	\N	PRESENT	0
38323	38042	14135M	PARTICIPANT	\N	PRESENT	0
38324	38042	14231L	PARTICIPANT	\N	PRESENT	0
38325	38042	11077T	PARTICIPANT	\N	PRESENT	0
38326	38042	11091R	PARTICIPANT	\N	PRESENT	0
38327	38042	08010L	PARTICIPANT	\N	PRESENT	0
45645	45643	14071N	PARTICIPANT	\N	PRESENT	0
45647	45646	14071N	PARTICIPANT	\N	PRESENT	0
45649	45648	14071N	PARTICIPANT	\N	PRESENT	0
45651	45650	14071N	PARTICIPANT	\N	PRESENT	0
45654	45653	14071N	PARTICIPANT	\N	PRESENT	0
45656	45655	14071N	PARTICIPANT	\N	PRESENT	0
45712	45711	89017R	PARTICIPANT	\N	PRESENT	0
45713	45711	01031L	PRESIDENT	0	PRESENT	0
45714	45711	05004A	PARTICIPANT	\N	PRESENT	0
45715	45711	01013J	PARTICIPANT	\N	PRESENT	0
45716	45711	11068S	PARTICIPANT	\N	PRESENT	0
45717	45711	11040E	PARTICIPANT	\N	PRESENT	0
45718	45711	08014Q	PARTICIPANT	\N	PRESENT	0
45719	45711	14167V	PARTICIPANT	\N	PRESENT	0
45720	45711	14175V	PARTICIPANT	\N	PRESENT	0
45721	45711	14083S	PARTICIPANT	\N	PRESENT	0
45722	45711	11053K	PARTICIPANT	\N	PRESENT	0
45723	45711	14085U	PARTICIPANT	\N	PRESENT	0
45724	45711	11042G	PARTICIPANT	\N	PRESENT	0
45725	45711	88008L	PARTICIPANT	\N	PRESENT	0
45726	45711	04086Q	PARTICIPANT	\N	PRESENT	0
45727	45711	11070L	PARTICIPANT	\N	PRESENT	0
45728	45711	11088W	PARTICIPANT	\N	PRESENT	0
45729	45711	14327T	PARTICIPANT	\N	PRESENT	0
45730	45711	08022Q	PARTICIPANT	\N	PRESENT	0
45731	45711	01027Q	PARTICIPANT	\N	PRESENT	0
45732	45711	04071H	PARTICIPANT	\N	PRESENT	0
45733	45711	98053W	PARTICIPANT	\N	EXCUSE	0
45734	45711	11083R	PARTICIPANT	\N	PRESENT	0
45735	45711	14199E	PARTICIPANT	\N	PRESENT	0
45736	45711	01057W	PARTICIPANT	\N	PRESENT	0
45737	45711	08069G	PARTICIPANT	\N	PRESENT	0
45738	45711	11048N	PARTICIPANT	\N	PRESENT	0
45739	45711	99004R	PARTICIPANT	\N	PRESENT	0
45740	45711	04061F	PARTICIPANT	\N	PRESENT	0
45741	45711	07029T	PARTICIPANT	\N	PRESENT	0
45742	45711	14159V	PARTICIPANT	\N	PRESENT	0
45743	45711	08010L	PARTICIPANT	\N	PRESENT	0
45809	45711	08034U	PARTICIPANT	\N	PRESENT	0
45810	45711	01048V	PARTICIPANT	\N	PRESENT	0
45811	45711	98046X	PARTICIPANT	\N	PRESENT	0
45812	45711	11085T	PARTICIPANT	\N	PRESENT	0
45813	45711	08011M	PARTICIPANT	\N	PRESENT	0
45814	45711	08061X	PARTICIPANT	\N	PRESENT	0
45815	45711	01016M	PARTICIPANT	\N	PRESENT	0
45816	45711	14225N	PARTICIPANT	\N	PRESENT	0
45817	45711	11012A	PARTICIPANT	\N	PRESENT	0
45818	45711	11057P	PARTICIPANT	\N	PRESENT	0
45820	45711	04034C	PARTICIPANT	\N	PRESENT	0
46282	46279	98018T	PARTICIPANT	\N	PRESENT	0
46280	46279	01031L	PARTICIPANT	\N	PRESENT	0
46281	46279	14093U	PARTICIPANT	\N	PRESENT	0
46283	46279	08009T	PARTICIPANT	\N	PRESENT	0
46407	46405	11039M	PARTICIPANT	\N	PRESENT	0
46408	46405	01019Q	PARTICIPANT	\N	PRESENT	0
46417	46416	11039M	PARTICIPANT	\N	PRESENT	0
47758	47662	11012A	PARTICIPANT	\N	PRESENT	0
47759	47662	80013X	PARTICIPANT	\N	PRESENT	0
47760	47662	98046X	PARTICIPANT	\N	PRESENT	0
47761	47662	01057W	PARTICIPANT	\N	PRESENT	0
47762	47662	11088W	PARTICIPANT	\N	PRESENT	0
47763	47662	09001P	PARTICIPANT	\N	PRESENT	0
47764	47662	14271U	PARTICIPANT	\N	PRESENT	0
47765	47662	14269B	PARTICIPANT	\N	PRESENT	0
47766	47662	01016M	PARTICIPANT	\N	PRESENT	0
47767	47662	99004R	PARTICIPANT	\N	PRESENT	0
47768	47662	14109K	PARTICIPANT	\N	PRESENT	0
47769	47662	08017T	PARTICIPANT	\N	PRESENT	0
47770	47662	08012N	PARTICIPANT	\N	PRESENT	0
47771	47662	98053W	PARTICIPANT	\N	PRESENT	0
47772	47662	14167V	PARTICIPANT	\N	PRESENT	0
47773	47662	11099A	PARTICIPANT	\N	PRESENT	0
47774	47662	11070L	PARTICIPANT	\N	PRESENT	0
47775	47662	04043D	PARTICIPANT	\N	PRESENT	0
47776	47662	04053F	PARTICIPANT	\N	PRESENT	0
47777	47662	01048V	PARTICIPANT	\N	PRESENT	0
47778	47662	11107G	PARTICIPANT	\N	PRESENT	0
47779	47662	04059M	PARTICIPANT	\N	PRESENT	0
47780	47662	04071H	PARTICIPANT	\N	PRESENT	0
47781	47662	14191V	PARTICIPANT	\N	PRESENT	0
47782	47662	11077T	PARTICIPANT	\N	PRESENT	0
47786	47662	01041N	PARTICIPANT	\N	PRESENT	0
47787	47662	11048N	PARTICIPANT	\N	PRESENT	0
47788	47662	11023D	PARTICIPANT	\N	PRESENT	0
47789	47662	14041T	PARTICIPANT	\N	PRESENT	0
47790	47662	01028R	PARTICIPANT	\N	PRESENT	0
47791	47662	14225N	PARTICIPANT	\N	PRESENT	0
47792	47662	11068S	PARTICIPANT	\N	PRESENT	0
47793	47662	11085T	PARTICIPANT	\N	PRESENT	0
47798	47663	11085T	PARTICIPANT	\N	PRESENT	0
47799	47663	01031L	PARTICIPANT	\N	PRESENT	0
47800	47663	08011M	PARTICIPANT	\N	PRESENT	0
47801	47663	08043V	PARTICIPANT	\N	PRESENT	0
47802	47663	11023D	PARTICIPANT	\N	PRESENT	0
47803	47663	14225N	PARTICIPANT	\N	PRESENT	0
47804	47663	11083R	PARTICIPANT	\N	PRESENT	0
47805	47663	11012A	PARTICIPANT	\N	PRESENT	0
47806	47663	01041N	PARTICIPANT	\N	PRESENT	0
47807	47663	14175V	PARTICIPANT	\N	PRESENT	0
47808	47663	04086Q	PARTICIPANT	\N	PRESENT	0
47809	47663	11070L	PARTICIPANT	\N	PRESENT	0
47810	47663	14167V	PARTICIPANT	\N	PRESENT	0
47811	47663	98053W	PARTICIPANT	\N	PRESENT	0
47812	47663	14271U	PARTICIPANT	\N	PRESENT	0
47813	47663	11048N	PARTICIPANT	\N	PRESENT	0
47814	47663	11077T	PARTICIPANT	\N	PRESENT	0
47815	47663	01056V	PARTICIPANT	\N	PRESENT	0
47816	47663	11107G	PARTICIPANT	\N	PRESENT	0
47817	47663	96004D	PARTICIPANT	\N	PRESENT	0
47818	47663	14121F	PARTICIPANT	\N	PRESENT	0
47819	47663	11057P	PARTICIPANT	\N	PRESENT	0
47820	47663	07029T	PARTICIPANT	\N	PRESENT	0
47821	47663	04071H	PARTICIPANT	\N	PRESENT	0
47822	47663	04059M	PARTICIPANT	\N	PRESENT	0
47823	47663	11053K	PARTICIPANT	\N	PRESENT	0
47824	47663	11068S	PARTICIPANT	\N	PRESENT	0
47825	47663	14193X	PARTICIPANT	\N	PRESENT	0
47841	47663	01028R	PARTICIPANT	\N	PRESENT	0
49877	49835	96004D	PARTICIPANT	\N	EXCUSE	0
58367	57886	95030B	PARTICIPANT	\N	PRESENT	0
58368	57886	04081K	PARTICIPANT	\N	PRESENT	0
58369	57886	04047H	PARTICIPANT	\N	PRESENT	0
58370	57886	86044G	PARTICIPANT	\N	PRESENT	0
58371	57886	01058X	PARTICIPANT	\N	PRESENT	0
58372	57886	01019Q	PARTICIPANT	\N	PRESENT	0
58373	57886	14211G	PARTICIPANT	\N	PRESENT	0
58374	57886	08028W	PARTICIPANT	\N	PRESENT	0
58375	57886	11043H	PARTICIPANT	\N	PRESENT	0
58376	57886	11048N	PARTICIPANT	\N	PRESENT	0
58377	57886	87003B	PARTICIPANT	\N	PRESENT	0
58378	57886	10015M	PARTICIPANT	\N	PRESENT	0
58379	57886	04041B	PARTICIPANT	\N	PRESENT	0
58380	57886	14147R	PARTICIPANT	\N	PRESENT	0
58381	57886	11091R	PARTICIPANT	\N	PRESENT	0
58382	57886	04043D	PARTICIPANT	\N	PRESENT	0
58383	57886	14191V	PARTICIPANT	\N	PRESENT	0
58384	57886	11044J	PARTICIPANT	\N	PRESENT	0
58385	57886	11103C	PARTICIPANT	\N	PRESENT	0
58386	57886	14187A	PARTICIPANT	\N	PRESENT	0
58387	57886	14061L	PARTICIPANT	\N	PRESENT	0
58388	57886	14059S	PARTICIPANT	\N	PRESENT	0
58389	57886	11090Q	PARTICIPANT	\N	PRESENT	0
58390	57886	08041T	PARTICIPANT	\N	PRESENT	0
58391	57886	07029T	PARTICIPANT	\N	PRESENT	0
58392	57886	11011M	PARTICIPANT	\N	PRESENT	0
58393	57886	14105F	PARTICIPANT	\N	PRESENT	0
58394	57886	01024M	PARTICIPANT	\N	PRESENT	0
58395	57886	11049P	PARTICIPANT	\N	PRESENT	0
58396	57886	14111D	PARTICIPANT	\N	PRESENT	0
58397	57886	14041T	PARTICIPANT	\N	PRESENT	0
58398	57886	04088S	PARTICIPANT	\N	PRESENT	0
58399	57886	14033T	PARTICIPANT	\N	PRESENT	0
58400	57886	14157T	PARTICIPANT	\N	PRESENT	0
58401	57886	14173T	PARTICIPANT	\N	PRESENT	0
58402	57886	14223L	PARTICIPANT	\N	PRESENT	0
58403	57886	14038Y	PARTICIPANT	\N	PRESENT	0
58404	57886	14273W	PARTICIPANT	\N	PRESENT	0
58405	57886	08053X	PARTICIPANT	\N	PRESENT	0
58406	57886	14028W	PARTICIPANT	\N	PRESENT	0
58407	57886	08051V	PARTICIPANT	\N	PRESENT	0
58408	57886	04035D	PARTICIPANT	\N	PRESENT	0
58409	57886	14265W	PARTICIPANT	\N	PRESENT	0
58410	57886	05008E	PARTICIPANT	\N	PRESENT	0
58411	57886	14207L	PARTICIPANT	\N	PRESENT	0
58412	57886	14103D	PARTICIPANT	\N	PRESENT	0
58413	57886	08024S	PARTICIPANT	\N	PRESENT	0
58414	57886	07004J	PARTICIPANT	\N	PRESENT	0
58415	57886	14209N	PARTICIPANT	\N	PRESENT	0
58416	57886	14213J	PARTICIPANT	\N	PRESENT	0
31201	28666	01016M	PARTICIPANT	\N	EXCUSE	0
34840	33348	12041X	PARTICIPANT	\N	PRESENT	0
34841	33348	08011M	PARTICIPANT	\N	PRESENT	0
34842	33348	11034G	PARTICIPANT	\N	PRESENT	0
34843	33348	04086Q	PARTICIPANT	\N	PRESENT	0
34844	33348	04054G	PARTICIPANT	\N	PRESENT	0
34845	33348	11040E	PARTICIPANT	\N	PRESENT	0
34846	33348	14013P	PARTICIPANT	\N	PRESENT	0
34847	33348	11056N	PARTICIPANT	\N	PRESENT	0
34848	33348	14061L	PARTICIPANT	\N	PRESENT	0
34849	33348	14037X	PARTICIPANT	\N	PRESENT	0
34850	33348	04042C	PARTICIPANT	\N	PRESENT	0
34851	33348	11069T	PARTICIPANT	\N	PRESENT	0
34852	33348	01044R	PARTICIPANT	\N	PRESENT	0
34853	33348	11029K	PARTICIPANT	\N	PRESENT	0
34854	33348	11099A	PARTICIPANT	\N	PRESENT	0
34855	33348	98024R	PARTICIPANT	\N	PRESENT	0
34856	33348	11033F	PARTICIPANT	\N	PRESENT	0
34857	33348	11065P	PARTICIPANT	\N	PRESENT	0
34858	33348	10015M	PARTICIPANT	\N	PRESENT	0
34859	33348	14175V	PARTICIPANT	\N	PRESENT	0
34860	33348	14093U	PARTICIPANT	\N	PRESENT	0
34861	33348	08051V	PARTICIPANT	\N	PRESENT	0
34862	33348	01046T	PARTICIPANT	\N	PRESENT	0
34863	33348	88008L	PARTICIPANT	\N	PRESENT	0
34864	33348	01008M	PARTICIPANT	\N	PRESENT	0
34865	33348	04078Q	PARTICIPANT	\N	PRESENT	0
34866	33348	08049C	PARTICIPANT	\N	PRESENT	0
34867	33348	05012A	PARTICIPANT	\N	PRESENT	0
34868	33348	11012A	PARTICIPANT	\N	PRESENT	0
34869	33348	11081P	PARTICIPANT	\N	PRESENT	0
34870	33348	11103C	PARTICIPANT	\N	PRESENT	0
34871	33348	04038G	PARTICIPANT	\N	PRESENT	0
34872	33348	14018U	PARTICIPANT	\N	PRESENT	0
34873	33348	08031R	PARTICIPANT	\N	PRESENT	0
34874	33348	14261S	PARTICIPANT	\N	PRESENT	0
34875	33348	04044E	PARTICIPANT	\N	PRESENT	0
34876	33348	14201E	PARTICIPANT	\N	PRESENT	0
34877	33348	11100Y	PARTICIPANT	\N	PRESENT	0
34878	33348	98022P	PARTICIPANT	\N	PRESENT	0
34879	33348	01048V	PARTICIPANT	\N	PRESENT	0
34880	33348	14239U	PARTICIPANT	\N	PRESENT	0
34881	33348	14241N	PARTICIPANT	\N	PRESENT	0
34882	33348	04081K	PARTICIPANT	\N	PRESENT	0
34883	33348	92018S	PARTICIPANT	\N	PRESENT	0
34884	33348	98053W	PARTICIPANT	\N	PRESENT	0
34885	33348	01058X	PARTICIPANT	\N	PRESENT	0
34886	33348	92031P	PARTICIPANT	\N	PRESENT	0
34887	33348	14059S	PARTICIPANT	\N	PRESENT	0
34888	33348	08016S	PARTICIPANT	\N	PRESENT	0
34889	33348	11101A	PARTICIPANT	\N	PRESENT	0
34890	33348	98035U	PARTICIPANT	\N	PRESENT	0
34891	33348	01016M	PARTICIPANT	\N	PRESENT	0
34892	33348	04056J	PARTICIPANT	\N	PRESENT	0
34893	33348	14069U	PARTICIPANT	\N	PRESENT	0
34894	33348	11039M	PARTICIPANT	\N	PRESENT	0
34895	33348	05004A	PARTICIPANT	\N	PRESENT	0
34896	33348	92015P	PARTICIPANT	\N	PRESENT	0
34897	33348	04033B	PARTICIPANT	\N	PRESENT	0
34898	33348	98046X	PARTICIPANT	\N	PRESENT	0
34899	33348	01015L	PARTICIPANT	\N	PRESENT	0
34900	33348	11083R	PARTICIPANT	\N	PRESENT	0
34901	33348	11049P	PARTICIPANT	\N	PRESENT	0
34902	33348	14123H	PARTICIPANT	\N	PRESENT	0
34903	33348	08052W	PARTICIPANT	\N	PRESENT	0
34904	33348	08025T	PARTICIPANT	\N	PRESENT	0
34905	33348	04035D	PARTICIPANT	\N	PRESENT	0
34906	33348	14051J	PARTICIPANT	\N	PRESENT	0
34907	33348	14017T	PARTICIPANT	\N	PRESENT	0
34908	33348	11071M	PARTICIPANT	\N	PRESENT	0
34909	33348	08055A	PARTICIPANT	\N	PRESENT	0
34910	33348	07034Q	PARTICIPANT	\N	PRESENT	0
34911	33348	14107H	PARTICIPANT	\N	PRESENT	0
34912	33348	04066L	PARTICIPANT	\N	PRESENT	0
34913	33348	04061F	PARTICIPANT	\N	PRESENT	0
34914	33348	08053X	PARTICIPANT	\N	PRESENT	0
34915	33348	01011G	PARTICIPANT	\N	PRESENT	0
34916	33348	14195A	PARTICIPANT	\N	PRESENT	0
34917	33348	11057P	PARTICIPANT	\N	PRESENT	0
34918	33348	11084S	PARTICIPANT	\N	PRESENT	0
34919	33348	92040Q	PARTICIPANT	\N	PRESENT	0
34920	33348	00003C	PARTICIPANT	\N	PRESENT	0
34921	33348	92020L	PARTICIPANT	\N	PRESENT	0
34922	33348	08060W	PARTICIPANT	\N	PRESENT	0
34923	33348	80013X	PARTICIPANT	\N	PRESENT	0
34924	33348	98021N	PARTICIPANT	\N	PRESENT	0
34925	33348	14028W	PARTICIPANT	\N	PRESENT	0
34926	33348	01022K	PARTICIPANT	\N	PRESENT	0
34927	33348	11015D	PARTICIPANT	\N	PRESENT	0
34928	33348	14215L	PARTICIPANT	\N	PRESENT	0
34929	33348	14065Q	PARTICIPANT	\N	PRESENT	0
34930	33348	11042G	PARTICIPANT	\N	PRESENT	0
34931	33348	08043V	PARTICIPANT	\N	PRESENT	0
34932	33348	08068F	PARTICIPANT	\N	PRESENT	0
34933	33348	11089X	PARTICIPANT	\N	PRESENT	0
34934	33348	11043H	PARTICIPANT	\N	PRESENT	0
34935	33348	08012N	PARTICIPANT	\N	PRESENT	0
34936	33348	80027E	PARTICIPANT	\N	PRESENT	0
34937	33348	11036J	PARTICIPANT	\N	PRESENT	0
34938	33348	11048N	PARTICIPANT	\N	PRESENT	0
34939	33348	98029W	PARTICIPANT	\N	PRESENT	0
34940	33348	04074L	PARTICIPANT	\N	PRESENT	0
34941	33348	11046L	PARTICIPANT	\N	PRESENT	0
34942	33348	11044J	PARTICIPANT	\N	PRESENT	0
34943	33348	14063N	PARTICIPANT	\N	PRESENT	0
34944	33348	83042R	PARTICIPANT	\N	PRESENT	0
34945	33348	11027H	PARTICIPANT	\N	PRESENT	0
34946	33348	08017T	PARTICIPANT	\N	PRESENT	0
34947	33348	04047H	PARTICIPANT	\N	PRESENT	0
34948	33348	04034C	PARTICIPANT	\N	PRESENT	0
34949	33348	95037J	PARTICIPANT	\N	PRESENT	0
34950	33348	08058D	PARTICIPANT	\N	PRESENT	0
34951	33348	14213J	PARTICIPANT	\N	PRESENT	0
34952	33348	14271U	PARTICIPANT	\N	PRESENT	0
34953	33348	83047W	PARTICIPANT	\N	PRESENT	0
34954	33348	14273W	PARTICIPANT	\N	PRESENT	0
34955	33348	14014Q	PARTICIPANT	\N	PRESENT	0
34956	33348	14109K	PARTICIPANT	\N	PRESENT	0
34957	33348	14033T	PARTICIPANT	\N	PRESENT	0
34958	33348	14207L	PARTICIPANT	\N	PRESENT	0
34959	33348	14197C	PARTICIPANT	\N	PRESENT	0
34960	33348	97011G	PARTICIPANT	\N	PRESENT	0
34961	33348	08014Q	PARTICIPANT	\N	PRESENT	0
34962	33348	08015R	PARTICIPANT	\N	PRESENT	0
34963	33348	11095V	PARTICIPANT	\N	PRESENT	0
34964	33348	92045V	PARTICIPANT	\N	PRESENT	0
34965	33348	14001X	PARTICIPANT	\N	PRESENT	0
34966	33348	14227Q	PARTICIPANT	\N	PRESENT	0
34967	33348	11097X	PARTICIPANT	\N	PRESENT	0
34968	33348	14097Y	PARTICIPANT	\N	PRESENT	0
34969	33348	11054L	PARTICIPANT	\N	PRESENT	0
34970	33348	08018U	PARTICIPANT	\N	PRESENT	0
34971	33348	08035V	PARTICIPANT	\N	PRESENT	0
34972	33348	13002U	PARTICIPANT	\N	PRESENT	0
34973	33348	04071H	PARTICIPANT	\N	PRESENT	0
34974	33348	11032E	PARTICIPANT	\N	PRESENT	0
34975	33348	14187A	PARTICIPANT	\N	PRESENT	0
34976	33348	14121F	PARTICIPANT	\N	PRESENT	0
34977	33348	14259Y	PARTICIPANT	\N	PRESENT	0
34978	33348	11088W	PARTICIPANT	\N	PRESENT	0
34979	33348	01031L	PARTICIPANT	\N	PRESENT	0
34980	33348	04079R	PARTICIPANT	\N	PRESENT	0
34981	33348	14281W	PARTICIPANT	\N	PRESENT	0
34982	33348	14329V	PARTICIPANT	\N	PRESENT	0
34983	33348	11059R	PARTICIPANT	\N	PRESENT	0
34984	33348	08069G	PARTICIPANT	\N	PRESENT	0
34985	33348	11061K	PARTICIPANT	\N	PRESENT	0
34986	33348	14038Y	PARTICIPANT	\N	PRESENT	0
34987	33348	11026G	PARTICIPANT	\N	PRESENT	0
34988	33348	14111D	PARTICIPANT	\N	PRESENT	0
34989	33348	04077P	PARTICIPANT	\N	PRESENT	0
34990	33348	14031R	PARTICIPANT	\N	PRESENT	0
34991	33348	08061X	PARTICIPANT	\N	PRESENT	0
34992	33348	01028R	PARTICIPANT	\N	PRESENT	0
34993	33348	04053F	PARTICIPANT	\N	PRESENT	0
34994	33348	11104D	PARTICIPANT	\N	PRESENT	0
34995	33348	11110B	PARTICIPANT	\N	PRESENT	0
34996	33348	14133K	PARTICIPANT	\N	PRESENT	0
34997	33348	14173T	PARTICIPANT	\N	PRESENT	0
34998	33348	08038Y	PARTICIPANT	\N	PRESENT	0
34999	33348	92039X	PARTICIPANT	\N	PRESENT	0
35000	33348	11035H	PARTICIPANT	\N	PRESENT	0
35001	33348	08024S	PARTICIPANT	\N	PRESENT	0
35002	33348	14157T	PARTICIPANT	\N	PRESENT	0
35003	33348	04059M	PARTICIPANT	\N	PRESENT	0
35004	33348	11091R	PARTICIPANT	\N	PRESENT	0
35005	33348	14229S	PARTICIPANT	\N	PRESENT	0
35006	33348	14085U	PARTICIPANT	\N	PRESENT	0
44121	41619	11010L	PARTICIPANT	\N	EXCUSE	0
46729	46661	14031R	PARTICIPANT	\N	PRESENT	0
46730	46661	14187A	PARTICIPANT	\N	PRESENT	0
46731	46661	11097X	PARTICIPANT	\N	PRESENT	0
46732	46661	14195A	PARTICIPANT	\N	PRESENT	0
46733	46661	14219Q	PARTICIPANT	\N	PRESENT	0
46734	46661	04061F	PARTICIPANT	\N	PRESENT	0
46735	46661	11048N	PARTICIPANT	\N	PRESENT	0
46736	46661	14157T	PARTICIPANT	\N	PRESENT	0
46737	46661	89017R	PARTICIPANT	\N	PRESENT	0
46738	46661	11067R	PARTICIPANT	\N	PRESENT	0
46739	46661	88008L	PARTICIPANT	\N	PRESENT	0
46740	46661	11064N	PARTICIPANT	\N	PRESENT	0
46741	46661	14231L	PARTICIPANT	\N	PRESENT	0
46742	46661	11036J	PARTICIPANT	\N	PRESENT	0
46743	46661	01024M	PARTICIPANT	\N	PRESENT	0
46744	46661	86044G	PARTICIPANT	\N	PRESENT	0
46745	46661	01016M	PARTICIPANT	\N	PRESENT	0
46746	46661	11066Q	PARTICIPANT	\N	PRESENT	0
46747	46661	90003B	PARTICIPANT	\N	PRESENT	0
46748	46661	01048V	PARTICIPANT	\N	PRESENT	0
46749	46661	04071H	PARTICIPANT	\N	PRESENT	0
46750	46661	14121F	PARTICIPANT	\N	PRESENT	0
46753	46661	11104D	PARTICIPANT	\N	PRESENT	0
46754	46661	14269B	PARTICIPANT	\N	PRESENT	0
46755	46661	98053W	PARTICIPANT	\N	PRESENT	0
46756	46661	14265W	PARTICIPANT	\N	PRESENT	0
46760	46661	04086Q	PARTICIPANT	\N	PRESENT	0
46758	46661	14053L	PARTICIPANT	\N	PRESENT	0
46759	46661	95062K	PARTICIPANT	\N	PRESENT	0
46763	46661	01022K	PARTICIPANT	\N	PRESENT	0
46764	46661	08010L	PARTICIPANT	\N	PRESENT	0
46765	46661	14249W	PARTICIPANT	\N	PRESENT	0
46766	46661	14105F	PARTICIPANT	\N	PRESENT	0
46795	46661	07004J	PARTICIPANT	\N	PRESENT	0
46797	46661	95063L	PARTICIPANT	\N	PRESENT	0
46803	46661	14030Q	PARTICIPANT	\N	PRESENT	0
46808	46661	95030B	PARTICIPANT	\N	PRESENT	0
46809	46661	95035G	PARTICIPANT	\N	PRESENT	0
46810	46661	14089Y	PARTICIPANT	\N	PRESENT	0
46811	46661	04048J	PARTICIPANT	\N	PRESENT	0
46812	46661	11014C	PARTICIPANT	\N	PRESENT	0
46813	46661	14103D	PARTICIPANT	\N	PRESENT	0
46815	46661	14259Y	PARTICIPANT	\N	PRESENT	0
46818	46661	14073Q	PARTICIPANT	\N	PRESENT	0
46819	46661	14034U	PARTICIPANT	\N	PRESENT	0
46820	46661	14063N	PARTICIPANT	\N	PRESENT	0
46821	46661	98018T	PARTICIPANT	\N	PRESENT	0
46881	46661	11027H	PARTICIPANT	\N	PRESENT	0
46882	46661	14037X	PARTICIPANT	\N	PRESENT	0
46887	46661	04088S	PARTICIPANT	\N	PRESENT	0
46896	46661	01027Q	PARTICIPANT	\N	PRESENT	0
46898	46661	01008M	PARTICIPANT	\N	PRESENT	0
46906	46661	04059M	PARTICIPANT	\N	PRESENT	0
46907	46661	11068S	PARTICIPANT	\N	PRESENT	0
46908	45707	08055A	PARTICIPANT	\N	PRESENT	0
46909	45707	98046X	PARTICIPANT	\N	PRESENT	0
46910	45707	11040E	PARTICIPANT	\N	PRESENT	0
46911	45707	01031L	PARTICIPANT	\N	PRESENT	0
46912	45707	08011M	PARTICIPANT	\N	PRESENT	0
46913	45707	04034C	PARTICIPANT	\N	PRESENT	0
46914	45707	11057P	PARTICIPANT	\N	PRESENT	0
46915	45707	01044R	PARTICIPANT	\N	PRESENT	0
46916	45707	11083R	PARTICIPANT	\N	PRESENT	0
46917	45707	11053K	PARTICIPANT	\N	PRESENT	0
46918	45707	11100Y	PARTICIPANT	\N	PRESENT	0
46919	45707	87003B	PARTICIPANT	\N	PRESENT	0
46920	45707	14041T	PARTICIPANT	\N	PRESENT	0
46921	45707	07029T	PARTICIPANT	\N	PRESENT	0
46922	45707	14327T	PARTICIPANT	\N	PRESENT	0
46923	45707	14175V	PARTICIPANT	\N	PRESENT	0
46924	45707	14191V	PARTICIPANT	\N	PRESENT	0
46925	45707	14033T	PARTICIPANT	\N	PRESENT	0
46926	45707	11043H	PARTICIPANT	\N	PRESENT	0
46927	45707	08043V	PARTICIPANT	\N	PRESENT	0
46928	45707	01057W	PARTICIPANT	\N	PRESENT	0
46929	45707	11012A	PARTICIPANT	\N	PRESENT	0
46930	45707	92015P	PARTICIPANT	\N	PRESENT	0
46931	45707	14271U	PARTICIPANT	\N	PRESENT	0
46932	45707	14159V	PARTICIPANT	\N	PRESENT	0
46933	45707	95015C	PARTICIPANT	\N	PRESENT	0
46934	45707	11042G	PARTICIPANT	\N	PRESENT	0
46935	45707	14225N	PARTICIPANT	\N	PRESENT	0
46936	45707	14187A	PARTICIPANT	\N	PRESENT	0
46937	45707	11097X	PARTICIPANT	\N	PRESENT	0
46938	45707	14195A	PARTICIPANT	\N	PRESENT	0
46939	45707	14219Q	PARTICIPANT	\N	PRESENT	0
46940	45707	04061F	PARTICIPANT	\N	PRESENT	0
46941	45707	11048N	PARTICIPANT	\N	PRESENT	0
46942	45707	14157T	PARTICIPANT	\N	PRESENT	0
46943	45707	89017R	PARTICIPANT	\N	PRESENT	0
46944	45707	11067R	PARTICIPANT	\N	PRESENT	0
46945	45707	88008L	PARTICIPANT	\N	PRESENT	0
46946	45707	14231L	PARTICIPANT	\N	PRESENT	0
46947	45707	11036J	PARTICIPANT	\N	PRESENT	0
46948	45707	01024M	PARTICIPANT	\N	PRESENT	0
46949	45707	86044G	PARTICIPANT	\N	PRESENT	0
46950	45707	01016M	PARTICIPANT	\N	PRESENT	0
46951	45707	90003B	PARTICIPANT	\N	PRESENT	0
46952	45707	04071H	PARTICIPANT	\N	PRESENT	0
46953	45707	14269B	PARTICIPANT	\N	PRESENT	0
46954	45707	98053W	PARTICIPANT	\N	PRESENT	0
46955	45707	14265W	PARTICIPANT	\N	PRESENT	0
46956	45707	95062K	PARTICIPANT	\N	PRESENT	0
46957	45707	04086Q	PARTICIPANT	\N	PRESENT	0
46958	45707	01022K	PARTICIPANT	\N	PRESENT	0
46959	45707	08010L	PARTICIPANT	\N	PRESENT	0
46960	45707	14105F	PARTICIPANT	\N	PRESENT	0
46961	45707	07004J	PARTICIPANT	\N	PRESENT	0
46962	45707	95063L	PARTICIPANT	\N	PRESENT	0
46963	45707	14030Q	PARTICIPANT	\N	PRESENT	0
46964	45707	95030B	PARTICIPANT	\N	PRESENT	0
46965	45707	95035G	PARTICIPANT	\N	PRESENT	0
46966	45707	14089Y	PARTICIPANT	\N	PRESENT	0
46967	45707	04048J	PARTICIPANT	\N	PRESENT	0
46968	45707	11014C	PARTICIPANT	\N	PRESENT	0
46969	45707	14103D	PARTICIPANT	\N	PRESENT	0
46970	45707	14259Y	PARTICIPANT	\N	PRESENT	0
46971	45707	14073Q	PARTICIPANT	\N	PRESENT	0
46972	45707	14034U	PARTICIPANT	\N	PRESENT	0
46973	45707	14063N	PARTICIPANT	\N	PRESENT	0
46974	45707	98018T	PARTICIPANT	\N	PRESENT	0
46975	45707	14037X	PARTICIPANT	\N	PRESENT	0
46976	45707	04088S	PARTICIPANT	\N	PRESENT	0
46977	45707	01027Q	PARTICIPANT	\N	PRESENT	0
46978	45707	01008M	PARTICIPANT	\N	PRESENT	0
46979	45707	04059M	PARTICIPANT	\N	PRESENT	0
46980	45707	11068S	PARTICIPANT	\N	PRESENT	0
47056	45708	86034E	PARTICIPANT	\N	PRESENT	0
47057	45708	14030Q	PARTICIPANT	\N	PRESENT	0
47058	45708	08052W	PARTICIPANT	\N	PRESENT	0
47060	45708	11059R	PARTICIPANT	\N	PRESENT	0
47061	45708	11043H	PARTICIPANT	\N	PRESENT	0
47062	45708	08019V	PARTICIPANT	\N	PRESENT	0
47063	45708	14191V	PARTICIPANT	\N	PRESENT	0
47064	45708	95062K	PARTICIPANT	\N	PRESENT	0
47065	45708	14063N	PARTICIPANT	\N	PRESENT	0
47066	45708	11012A	PARTICIPANT	\N	PRESENT	0
47067	45708	14026U	PARTICIPANT	\N	PRESENT	0
47068	45708	14227Q	PARTICIPANT	\N	PRESENT	0
47069	45708	01044R	PARTICIPANT	\N	PRESENT	0
47070	45708	14013P	PARTICIPANT	\N	PRESENT	0
47071	45708	98029W	PARTICIPANT	\N	PRESENT	0
47072	45708	01047U	PARTICIPANT	\N	PRESENT	0
47073	45708	11107G	PARTICIPANT	\N	PRESENT	0
47074	45708	11090Q	PARTICIPANT	\N	PRESENT	0
47075	45708	14085U	PARTICIPANT	\N	PRESENT	0
47076	45708	08009T	PARTICIPANT	\N	PRESENT	0
47077	45708	14087W	PARTICIPANT	\N	PRESENT	0
47078	45708	01022K	PARTICIPANT	\N	PRESENT	0
47079	45708	98005N	PARTICIPANT	\N	PRESENT	0
47080	45708	11037K	PARTICIPANT	\N	PRESENT	0
47081	45708	14073Q	PARTICIPANT	\N	PRESENT	0
47082	45708	04047H	PARTICIPANT	\N	PRESENT	0
47083	45708	92020L	PARTICIPANT	\N	PRESENT	0
47084	45708	11063M	PARTICIPANT	\N	PRESENT	0
47085	45708	14209N	PARTICIPANT	\N	PRESENT	0
47086	45708	14259Y	PARTICIPANT	\N	PRESENT	0
47087	45708	14231L	PARTICIPANT	\N	PRESENT	0
47088	45708	14051J	PARTICIPANT	\N	PRESENT	0
47089	45708	08043V	PARTICIPANT	\N	PRESENT	0
47090	45708	11067R	PARTICIPANT	\N	PRESENT	0
47091	45708	07026Q	PARTICIPANT	\N	PRESENT	0
47092	45708	14235Q	PARTICIPANT	\N	PRESENT	0
47093	45708	14107H	PARTICIPANT	\N	PRESENT	0
47094	45708	14197C	PARTICIPANT	\N	PRESENT	0
47095	45708	08065C	PARTICIPANT	\N	PRESENT	0
47096	45708	11069T	PARTICIPANT	\N	PRESENT	0
37606	37605	05008E	PARTICIPANT	\N	PRESENT	0
32170	32163	01031L	PRESIDENT	0	PRESENT	0
37608	37605	04047H	PARTICIPANT	\N	PRESENT	0
32172	32163	01013J	PARTICIPANT	\N	PRESENT	0
37609	37605	14259Y	PARTICIPANT	\N	PRESENT	0
32174	32163	11040E	PARTICIPANT	\N	PRESENT	0
32175	32163	08014Q	PARTICIPANT	\N	PRESENT	0
37610	37605	14041T	PARTICIPANT	\N	PRESENT	0
32177	32163	14175V	PARTICIPANT	\N	PRESENT	0
32178	32163	14083S	PARTICIPANT	\N	PRESENT	0
32179	32163	11053K	PARTICIPANT	\N	PRESENT	0
32180	32163	14085U	PARTICIPANT	\N	EXCUSE	0
32181	32163	11042G	PARTICIPANT	\N	PRESENT	0
32182	32163	88008L	PARTICIPANT	\N	PRESENT	0
32183	32163	04086Q	PARTICIPANT	\N	PRESENT	0
37611	37605	11113E	PARTICIPANT	\N	PRESENT	0
32185	32163	11070L	PARTICIPANT	\N	PRESENT	0
32186	32163	11088W	PARTICIPANT	\N	PRESENT	0
37612	37605	01024M	PARTICIPANT	\N	EXCUSE	0
32188	32163	08022Q	PARTICIPANT	\N	PRESENT	0
32189	32163	01027Q	PARTICIPANT	\N	PRESENT	0
37613	37605	14215L	PARTICIPANT	\N	PRESENT	0
32191	32163	11074Q	PARTICIPANT	\N	PRESENT	0
37614	37605	08018U	PARTICIPANT	\N	EXCUSE	0
32193	32163	11083R	PARTICIPANT	\N	PRESENT	0
32194	32163	14199E	PARTICIPANT	\N	PRESENT	0
32195	32163	01057W	PARTICIPANT	\N	PRESENT	0
32196	32163	08016S	PARTICIPANT	\N	PRESENT	0
32197	32163	08069G	PARTICIPANT	\N	PRESENT	0
32198	32163	11048N	PARTICIPANT	\N	PRESENT	0
32199	32163	99004R	PARTICIPANT	\N	PRESENT	0
32200	32163	04061F	PARTICIPANT	\N	PRESENT	0
32201	32163	14159V	PARTICIPANT	\N	PRESENT	0
32202	32163	07029T	PARTICIPANT	\N	PRESENT	0
37615	37605	01007L	PARTICIPANT	\N	PRESENT	0
32204	32163	08010L	PARTICIPANT	\N	PRESENT	0
32205	32163	08034U	PARTICIPANT	\N	PRESENT	0
32206	32163	01048V	PARTICIPANT	\N	EXCUSE	0
32207	32163	98046X	PARTICIPANT	\N	EXCUSE	0
32208	32163	11085T	PARTICIPANT	\N	PRESENT	0
32209	32163	08011M	PARTICIPANT	\N	PRESENT	0
32210	32163	08073C	PARTICIPANT	\N	PRESENT	0
32211	32163	08061X	PARTICIPANT	\N	PRESENT	0
32212	32163	01016M	PARTICIPANT	\N	PRESENT	0
32213	32163	14225N	PARTICIPANT	\N	PRESENT	0
32214	32163	11012A	PARTICIPANT	\N	PRESENT	0
32215	32163	11057P	PARTICIPANT	\N	PRESENT	0
32216	32163	14173T	PARTICIPANT	\N	EXCUSE	0
32217	32163	04034C	PARTICIPANT	\N	PRESENT	0
37616	37605	14273W	PARTICIPANT	\N	PRESENT	0
37617	37605	14147R	PARTICIPANT	\N	PRESENT	0
37618	37605	95049N	PARTICIPANT	\N	PRESENT	0
37619	37605	01028R	PARTICIPANT	\N	PRESENT	0
37620	37605	04056J	PARTICIPANT	\N	PRESENT	0
37621	37605	14275Y	PARTICIPANT	\N	PRESENT	0
37622	37605	04044E	PRESIDENT	0	PRESENT	0
37624	37605	11037K	PARTICIPANT	\N	PRESENT	0
37625	37605	92045V	PARTICIPANT	\N	EXCUSE	0
37626	37605	95067Q	PARTICIPANT	\N	PRESENT	0
38021	31452	04094Q	PARTICIPANT	\N	EXCUSE	0
38022	31452	14017T	PARTICIPANT	\N	EXCUSE	0
38044	38039	04066L	PARTICIPANT	\N	PRESENT	0
38045	38039	11040E	PARTICIPANT	\N	PRESENT	0
38046	38039	11077T	PARTICIPANT	\N	PRESENT	0
38047	38039	11023D	PARTICIPANT	\N	PRESENT	0
38048	38039	11083R	PARTICIPANT	\N	PRESENT	0
38049	38039	11070L	PARTICIPANT	\N	PRESENT	0
38050	38039	04034C	PARTICIPANT	\N	PRESENT	0
38051	38039	11012A	PARTICIPANT	\N	PRESENT	0
38052	38039	04086Q	PARTICIPANT	\N	PRESENT	0
38053	38039	04043D	PARTICIPANT	\N	PRESENT	0
38054	38039	01031L	PARTICIPANT	\N	PRESENT	0
38055	38039	08011M	PARTICIPANT	\N	PRESENT	0
38056	38039	14041T	PARTICIPANT	\N	PRESENT	0
38057	38039	98053W	PARTICIPANT	\N	PRESENT	0
38058	38039	01024M	PARTICIPANT	\N	PRESENT	0
38059	38039	98046X	PARTICIPANT	\N	PRESENT	0
38060	38039	11057P	PARTICIPANT	\N	PRESENT	0
38061	38039	14159V	PARTICIPANT	\N	PRESENT	0
38062	38039	08019V	PARTICIPANT	\N	PRESENT	0
38063	38039	08073C	PARTICIPANT	\N	PRESENT	0
38064	38039	11074Q	PARTICIPANT	\N	PRESENT	0
38065	38039	14119M	PARTICIPANT	\N	PRESENT	0
38066	38039	11053K	PARTICIPANT	\N	PRESENT	0
38067	38039	11054L	PARTICIPANT	\N	PRESENT	0
38068	38039	98005N	PARTICIPANT	\N	PRESENT	0
38069	38039	14269B	PARTICIPANT	\N	PRESENT	0
38070	38039	04071H	PARTICIPANT	\N	PRESENT	0
38071	38039	07004J	PARTICIPANT	\N	PRESENT	0
38072	38039	14175V	PARTICIPANT	\N	PRESENT	0
38073	38039	07029T	PARTICIPANT	\N	PRESENT	0
38074	38039	14277B	PARTICIPANT	\N	PRESENT	0
38075	38039	08039A	PARTICIPANT	\N	PRESENT	0
38076	38039	04036E	PARTICIPANT	\N	PRESENT	0
38077	38039	11103C	PARTICIPANT	\N	PRESENT	0
38078	38039	14261S	PARTICIPANT	\N	PRESENT	0
38081	38039	14275Y	PARTICIPANT	\N	PRESENT	0
38113	38040	01027Q	PARTICIPANT	\N	PRESENT	0
38083	38040	11040E	PARTICIPANT	\N	PRESENT	0
38084	38040	11083R	PARTICIPANT	\N	PRESENT	0
38123	38040	04071H	PARTICIPANT	\N	PRESENT	0
38086	38040	04034C	PARTICIPANT	\N	PRESENT	0
38087	38040	11012A	PARTICIPANT	\N	PRESENT	0
38088	38040	04086Q	PARTICIPANT	\N	PRESENT	0
38124	38040	04053F	PARTICIPANT	\N	PRESENT	0
38090	38040	01031L	PARTICIPANT	\N	PRESENT	0
38091	38040	08011M	PARTICIPANT	\N	PRESENT	0
38115	38040	95035G	PARTICIPANT	\N	PRESENT	0
38093	38040	98053W	PARTICIPANT	\N	PRESENT	0
38094	38040	11057P	PARTICIPANT	\N	PRESENT	0
38095	38040	14159V	PARTICIPANT	\N	PRESENT	0
38096	38040	08019V	PARTICIPANT	\N	PRESENT	0
38097	38040	08073C	PARTICIPANT	\N	PRESENT	0
38114	38040	07026Q	PARTICIPANT	\N	PRESENT	0
38116	38040	11054L	PARTICIPANT	\N	PRESENT	0
38100	38040	98005N	PARTICIPANT	\N	PRESENT	0
38101	38040	07029T	PARTICIPANT	\N	PRESENT	0
38125	38040	04059M	PARTICIPANT	\N	PRESENT	0
38126	38040	11023D	PARTICIPANT	\N	PRESENT	0
38104	38040	07004J	PARTICIPANT	\N	PRESENT	0
38127	38040	08034U	PARTICIPANT	\N	PRESENT	0
38128	38040	96004D	PARTICIPANT	\N	PRESENT	0
38107	38040	11103C	PARTICIPANT	\N	PRESENT	0
38108	38040	14261S	PARTICIPANT	\N	PRESENT	0
38109	38040	14275Y	PARTICIPANT	\N	PRESENT	0
38110	38040	01007L	PARTICIPANT	\N	PRESENT	0
38111	38040	11053K	PARTICIPANT	\N	PRESENT	0
38112	38040	14175V	PARTICIPANT	\N	PRESENT	0
38117	38040	98046X	PARTICIPANT	\N	PRESENT	0
38118	38040	11074Q	PARTICIPANT	\N	PRESENT	0
38119	38040	14119M	PARTICIPANT	\N	PRESENT	0
38120	38040	14277B	PARTICIPANT	\N	PRESENT	0
38121	38040	14041T	PARTICIPANT	\N	PRESENT	0
38122	38040	11088W	PARTICIPANT	\N	PRESENT	0
38129	38040	08016S	PARTICIPANT	\N	PRESENT	0
38130	38040	11091R	PARTICIPANT	\N	PRESENT	0
38131	38040	01048V	PARTICIPANT	\N	PRESENT	0
38135	38040	11010L	PARTICIPANT	\N	PRESENT	0
38136	38040	04057K	PARTICIPANT	\N	PRESENT	0
38137	38040	99004R	PARTICIPANT	\N	PRESENT	0
38138	38040	14219Q	PARTICIPANT	\N	PRESENT	0
38139	38040	95041E	PARTICIPANT	\N	PRESENT	0
38328	38042	14063N	PARTICIPANT	\N	PRESENT	0
38329	38042	08022Q	PARTICIPANT	\N	PRESENT	0
38330	38042	08012N	PARTICIPANT	\N	PRESENT	0
38331	38042	14061L	PARTICIPANT	\N	PRESENT	0
38332	38042	14179A	PARTICIPANT	\N	PRESENT	0
38333	38042	80027E	PARTICIPANT	\N	PRESENT	0
38334	38042	92015P	PARTICIPANT	\N	PRESENT	0
38335	38042	01016M	PARTICIPANT	\N	PRESENT	0
38336	38042	01043Q	PARTICIPANT	\N	PRESENT	0
38337	38042	14111D	PARTICIPANT	\N	PRESENT	0
38338	38042	08073C	PARTICIPANT	\N	PRESENT	0
38339	38042	14031R	PARTICIPANT	\N	PRESENT	0
38340	38042	08034U	PARTICIPANT	\N	PRESENT	0
38341	38042	04097T	PARTICIPANT	\N	PRESENT	0
38342	38042	04057K	PARTICIPANT	\N	PRESENT	0
38343	38042	04081K	PARTICIPANT	\N	PRESENT	0
38344	38042	11104D	PARTICIPANT	\N	PRESENT	0
38345	38042	08061X	PARTICIPANT	\N	PRESENT	0
38346	38042	04070G	PARTICIPANT	\N	PRESENT	0
38347	38042	11054L	PARTICIPANT	\N	PRESENT	0
38348	38042	11071M	PARTICIPANT	\N	PRESENT	0
38349	38042	08039A	PARTICIPANT	\N	PRESENT	0
38350	38042	11044J	PARTICIPANT	\N	PRESENT	0
38351	38042	14263U	PARTICIPANT	\N	PRESENT	0
38352	38042	08043V	PARTICIPANT	\N	PRESENT	0
38353	38042	14219Q	PARTICIPANT	\N	PRESENT	0
38354	38042	04071H	PARTICIPANT	\N	PRESENT	0
40886	40885	01031L	PRESIDENT	0	PRESENT	0
40887	40885	11068S	PARTICIPANT	\N	EXCUSE	0
40888	40885	11074Q	PARTICIPANT	\N	PRESENT	0
40889	40885	14159V	PARTICIPANT	\N	PRESENT	0
40890	40885	07029T	PARTICIPANT	\N	EXCUSE	0
40891	40885	08010L	PARTICIPANT	\N	PRESENT	0
40892	40885	08034U	PARTICIPANT	\N	PRESENT	0
40893	40885	08011M	PARTICIPANT	\N	PRESENT	0
40894	40885	01016M	PARTICIPANT	\N	PRESENT	0
40895	40885	14225N	PARTICIPANT	\N	PRESENT	0
54335	54334	14089Y	PARTICIPANT	\N	PRESENT	0
58417	57886	11111C	PARTICIPANT	\N	PRESENT	0
58418	57886	95035G	PARTICIPANT	\N	PRESENT	0
58419	57886	96004D	PARTICIPANT	\N	PRESENT	0
58420	57886	04071H	PARTICIPANT	\N	PRESENT	0
58421	57886	11042G	PARTICIPANT	\N	PRESENT	0
58422	57886	14053L	PARTICIPANT	\N	PRESENT	0
58423	57886	11097X	PARTICIPANT	\N	PRESENT	0
58424	57886	01028R	PARTICIPANT	\N	PRESENT	0
58425	57886	11033F	PARTICIPANT	\N	PRESENT	0
58426	57886	04033B	PARTICIPANT	\N	PRESENT	0
58427	57886	14271U	PARTICIPANT	\N	PRESENT	0
58428	57886	95062K	PARTICIPANT	\N	PRESENT	0
58429	57886	14073Q	PARTICIPANT	\N	PRESENT	0
58430	57886	11064N	PARTICIPANT	\N	PRESENT	0
58431	57886	08038Y	PARTICIPANT	\N	PRESENT	0
58432	57886	14259Y	PARTICIPANT	\N	PRESENT	0
58433	57886	14031R	PARTICIPANT	\N	PRESENT	0
58434	57886	01048V	PARTICIPANT	\N	PRESENT	0
58435	57886	11057P	PARTICIPANT	\N	PRESENT	0
58436	57886	11034G	PARTICIPANT	\N	PRESENT	0
58437	57886	04053F	PARTICIPANT	\N	PRESENT	0
58438	57886	14215L	PARTICIPANT	\N	PRESENT	0
58439	57886	11110B	PARTICIPANT	\N	PRESENT	0
58440	57886	11112D	PARTICIPANT	\N	PRESENT	0
58441	57886	14267Y	PARTICIPANT	\N	PRESENT	0
58442	57886	08014Q	PARTICIPANT	\N	PRESENT	0
58443	57886	12042Y	PARTICIPANT	\N	PRESENT	0
58444	57886	97011G	PARTICIPANT	\N	PRESENT	0
58445	57886	04057K	PARTICIPANT	\N	PRESENT	0
58446	57886	11094U	PARTICIPANT	\N	PRESENT	0
58447	57886	01060R	PARTICIPANT	\N	PRESENT	0
58448	57886	14239U	PARTICIPANT	\N	PRESENT	0
58449	57886	07032N	PARTICIPANT	\N	PRESENT	0
58450	57886	08015R	PARTICIPANT	\N	PRESENT	0
58451	57886	14121F	PARTICIPANT	\N	PRESENT	0
58452	57886	14195A	PARTICIPANT	\N	PRESENT	0
58453	57886	11084S	PARTICIPANT	\N	PRESENT	0
58454	57886	08055A	PARTICIPANT	\N	PRESENT	0
58455	57886	14089Y	PARTICIPANT	\N	PRESENT	0
58456	57886	01022K	PARTICIPANT	\N	PRESENT	0
58457	57886	13002U	PARTICIPANT	\N	PRESENT	0
58458	57886	11093T	PARTICIPANT	\N	PRESENT	0
58459	57886	11082Q	PARTICIPANT	\N	PRESENT	0
58460	57886	14051J	PARTICIPANT	\N	PRESENT	0
58461	57886	14217N	PARTICIPANT	\N	PRESENT	0
58462	57886	14175V	PARTICIPANT	\N	PRESENT	0
58463	57886	98021N	PARTICIPANT	\N	PRESENT	0
58464	57886	90003B	PARTICIPANT	\N	PRESENT	0
58465	57886	11055M	PARTICIPANT	\N	PRESENT	0
58466	57886	14197C	PARTICIPANT	\N	PRESENT	0
58467	57886	08062Y	PARTICIPANT	\N	PRESENT	0
58468	57886	14329V	PARTICIPANT	\N	PRESENT	0
58469	57886	14199E	PARTICIPANT	\N	PRESENT	0
58470	57886	80013X	PARTICIPANT	\N	PRESENT	0
58471	57886	01015L	PARTICIPANT	\N	PRESENT	0
58472	57886	11088W	PARTICIPANT	\N	PRESENT	0
58473	57886	98022P	PARTICIPANT	\N	PRESENT	0
58474	57886	14237S	PARTICIPANT	\N	PRESENT	0
58475	57886	00003C	PARTICIPANT	\N	PRESENT	0
58476	57886	04049K	PARTICIPANT	\N	PRESENT	0
58477	57886	11098Y	PARTICIPANT	\N	PRESENT	0
58478	57886	11104D	PARTICIPANT	\N	PRESENT	0
58479	57886	11105E	PARTICIPANT	\N	PRESENT	0
58480	57886	08068F	PARTICIPANT	\N	PRESENT	0
58481	57886	14269B	PARTICIPANT	\N	PRESENT	0
58482	57886	08021P	PARTICIPANT	\N	PRESENT	0
58483	57886	95041E	PARTICIPANT	\N	PRESENT	0
58484	57886	01007L	PARTICIPANT	\N	PRESENT	0
58485	57886	14069U	PARTICIPANT	\N	PRESENT	0
58486	57886	04048J	PARTICIPANT	\N	PRESENT	0
58487	57886	01008M	PARTICIPANT	\N	PRESENT	0
58488	57886	10006L	PARTICIPANT	\N	PRESENT	0
58489	57886	14081Q	PARTICIPANT	\N	PRESENT	0
58490	57886	95015C	PARTICIPANT	\N	PRESENT	0
58491	57886	07026Q	PARTICIPANT	\N	PRESENT	0
58492	57886	14097Y	PARTICIPANT	\N	PRESENT	0
58493	57886	14085U	PARTICIPANT	\N	PRESENT	0
58494	57886	11053K	PARTICIPANT	\N	PRESENT	0
58495	57886	98035U	PARTICIPANT	\N	PRESENT	0
58496	57886	14001X	PARTICIPANT	\N	PRESENT	0
58497	57886	01037S	PARTICIPANT	\N	PRESENT	0
58498	57886	14123H	PARTICIPANT	\N	PRESENT	0
58499	57886	14257W	PARTICIPANT	\N	PRESENT	0
58500	57886	11106F	PARTICIPANT	\N	PRESENT	0
58501	57886	07024N	PARTICIPANT	\N	PRESENT	0
58502	57886	95059Q	PARTICIPANT	\N	PRESENT	0
58503	57886	89029V	PARTICIPANT	\N	PRESENT	0
58504	57886	92031P	PARTICIPANT	\N	PRESENT	0
58505	57886	01027Q	PARTICIPANT	\N	PRESENT	0
58506	57886	08016S	PARTICIPANT	\N	PRESENT	0
58507	57886	98023Q	PARTICIPANT	\N	PRESENT	0
58508	57886	92044U	PARTICIPANT	\N	PRESENT	0
58509	57886	14135M	PARTICIPANT	\N	PRESENT	0
58510	57886	14263U	PARTICIPANT	\N	PRESENT	0
58511	57886	01013J	PARTICIPANT	\N	PRESENT	0
58512	57886	04054G	PARTICIPANT	\N	PRESENT	0
58513	57886	98053W	PARTICIPANT	\N	PRESENT	0
58514	57886	11080N	PARTICIPANT	\N	PRESENT	0
58515	57886	77002U	PARTICIPANT	\N	PRESENT	0
58516	57886	14235Q	PARTICIPANT	\N	PRESENT	0
58517	57886	11076S	PARTICIPANT	\N	PRESENT	0
58518	57886	01044R	PARTICIPANT	\N	PRESENT	0
58519	57886	11029K	PARTICIPANT	\N	PRESENT	0
58520	57886	14169X	PARTICIPANT	\N	PRESENT	0
58521	57886	08042U	PARTICIPANT	\N	PRESENT	0
58522	57886	11083R	PARTICIPANT	\N	PRESENT	0
58523	57886	11099A	PARTICIPANT	\N	PRESENT	0
58524	57886	04092N	PARTICIPANT	\N	PRESENT	0
58525	57886	11069T	PARTICIPANT	\N	PRESENT	0
58526	57886	04086Q	PARTICIPANT	\N	PRESENT	0
58527	57886	01046T	PARTICIPANT	\N	PRESENT	0
58528	57886	08011M	PARTICIPANT	\N	PRESENT	0
58529	57886	04078Q	PARTICIPANT	\N	PRESENT	0
58530	57886	09001P	PARTICIPANT	\N	PRESENT	0
58531	57886	08031R	PARTICIPANT	\N	PRESENT	0
58532	57886	01043Q	PARTICIPANT	\N	PRESENT	0
58533	57886	11039M	PARTICIPANT	\N	PRESENT	0
58534	57886	11100Y	PARTICIPANT	\N	PRESENT	0
58536	57886	04056J	PARTICIPANT	\N	PRESENT	0
58537	57886	01016M	PARTICIPANT	\N	PRESENT	0
58538	57886	92045V	PARTICIPANT	\N	PRESENT	0
58539	57886	14225N	PARTICIPANT	\N	PRESENT	0
58540	57886	98046X	PARTICIPANT	\N	PRESENT	0
58541	57886	08052W	PARTICIPANT	\N	PRESENT	0
58542	57886	08025T	PARTICIPANT	\N	PRESENT	0
58543	57886	14151M	PARTICIPANT	\N	PRESENT	0
58544	57886	08022Q	PARTICIPANT	\N	PRESENT	0
58545	57886	12041X	PARTICIPANT	\N	PRESENT	0
58546	57886	04066L	PARTICIPANT	\N	PRESENT	0
58547	57886	11027H	PARTICIPANT	\N	PRESENT	0
58548	57886	01011G	PARTICIPANT	\N	PRESENT	0
58549	57886	08010L	PARTICIPANT	\N	PRESENT	0
58550	57886	92020L	PARTICIPANT	\N	PRESENT	0
58552	57886	11015D	PARTICIPANT	\N	PRESENT	0
58553	57886	98029W	PARTICIPANT	\N	PRESENT	0
58554	57886	11046L	PARTICIPANT	\N	PRESENT	0
58555	57886	14109K	PARTICIPANT	\N	PRESENT	0
58556	57886	14249W	PARTICIPANT	\N	PRESENT	0
58557	57886	08017T	PARTICIPANT	\N	PRESENT	0
58558	57886	04034C	PARTICIPANT	\N	PRESENT	0
58559	57886	01041N	PARTICIPANT	\N	PRESENT	0
58560	57886	11059R	PARTICIPANT	\N	PRESENT	0
58561	57886	11030C	PARTICIPANT	\N	PRESENT	0
58562	57886	08049C	PARTICIPANT	\N	PRESENT	0
58563	57886	14133K	PARTICIPANT	\N	PRESENT	0
58564	57886	14167V	PARTICIPANT	\N	PRESENT	0
58565	57886	08018U	PARTICIPANT	\N	PRESENT	0
58566	57886	83047W	PARTICIPANT	\N	PRESENT	0
58567	57886	11061K	PARTICIPANT	\N	PRESENT	0
58568	57886	04036E	PARTICIPANT	\N	PRESENT	0
58569	57886	11014C	PARTICIPANT	\N	PRESENT	0
58570	57886	14079W	PARTICIPANT	\N	PRESENT	0
58571	57886	11074Q	PARTICIPANT	\N	PRESENT	0
58572	57886	02002K	PARTICIPANT	\N	PRESENT	0
58573	57886	14227Q	PARTICIPANT	\N	PRESENT	0
58574	57886	95037J	PARTICIPANT	\N	PRESENT	0
58575	57886	08061X	PARTICIPANT	\N	PRESENT	0
35009	33348	14081Q	PARTICIPANT	\N	PRESENT	0
35010	33348	14249W	PARTICIPANT	\N	PRESENT	0
35011	33348	99002P	PARTICIPANT	\N	PRESENT	0
31112	31108	14030Q	PARTICIPANT	\N	EXCUSE	0
31113	31108	96004D	PARTICIPANT	\N	PRESENT	0
31114	31108	08060W	PARTICIPANT	\N	PRESENT	0
35012	33348	04045F	PARTICIPANT	\N	PRESENT	0
35013	33348	98023Q	PARTICIPANT	\N	PRESENT	0
31117	31108	14038Y	PARTICIPANT	\N	PRESENT	0
31118	31108	11114F	PARTICIPANT	\N	PRESENT	0
35014	33348	11077T	PARTICIPANT	\N	PRESENT	0
31120	31108	11065P	PARTICIPANT	\N	PRESENT	0
31121	31108	01015L	PARTICIPANT	\N	PRESENT	0
31122	31108	11107G	PARTICIPANT	\N	PRESENT	0
35015	33348	11066Q	PARTICIPANT	\N	PRESENT	0
35016	33348	04094Q	PARTICIPANT	\N	PRESENT	0
31125	31108	01022K	PARTICIPANT	\N	PRESENT	0
35017	33348	04095R	PARTICIPANT	\N	PRESENT	0
35018	33348	14053L	PARTICIPANT	\N	PRESENT	0
35019	33348	08073C	PARTICIPANT	\N	PRESENT	0
31129	31108	14219Q	PARTICIPANT	\N	PRESENT	0
35020	33348	14039A	PARTICIPANT	\N	PRESENT	0
31131	31108	14031R	PARTICIPANT	\N	EXCUSE	0
31132	31108	08009T	PRESIDENT	0	PRESENT	0
35021	33348	14159V	PARTICIPANT	\N	PRESENT	0
35022	33348	14269B	PARTICIPANT	\N	PRESENT	0
31135	31108	92039X	PARTICIPANT	\N	EXCUSE	0
31136	31108	08042U	PARTICIPANT	\N	PRESENT	0
31137	31108	14169X	PARTICIPANT	\N	PRESENT	0
35023	33348	14105F	PARTICIPANT	\N	PRESENT	0
35024	33348	11107G	PARTICIPANT	\N	PRESENT	0
31140	31108	05012A	PARTICIPANT	\N	PRESENT	0
35025	33348	12042Y	PARTICIPANT	\N	PRESENT	0
35026	33348	05008E	PARTICIPANT	\N	PRESENT	0
31143	31108	95062K	PARTICIPANT	\N	PRESENT	0
35027	33348	14257W	PARTICIPANT	\N	PRESENT	0
31145	31108	14051J	PARTICIPANT	\N	PRESENT	0
35028	33348	11113E	PARTICIPANT	\N	PRESENT	0
35029	33348	11109J	PARTICIPANT	\N	PRESENT	0
35030	33348	11023D	PARTICIPANT	\N	PRESENT	0
35031	33348	11067R	PARTICIPANT	\N	PRESENT	0
35032	33348	11037K	PARTICIPANT	\N	PRESENT	0
35033	33348	14209N	PARTICIPANT	\N	PRESENT	0
35034	33348	08021P	PARTICIPANT	\N	PRESENT	0
35035	33348	14079W	PARTICIPANT	\N	PRESENT	0
35036	33348	11114F	PARTICIPANT	\N	PRESENT	0
35037	33348	01060R	PARTICIPANT	\N	PRESENT	0
35038	33348	14247U	PARTICIPANT	\N	PRESENT	0
35039	33348	14055N	PARTICIPANT	\N	PRESENT	0
35040	33348	89017R	PARTICIPANT	\N	PRESENT	0
35041	33348	08065C	PARTICIPANT	\N	PRESENT	0
35042	33348	04043D	PARTICIPANT	\N	PRESENT	0
35094	33348	04048J	PARTICIPANT	\N	PRESENT	0
35044	33348	14147R	PARTICIPANT	\N	PRESENT	0
35045	33348	01007L	PARTICIPANT	\N	PRESENT	0
35046	33348	04049K	PARTICIPANT	\N	PRESENT	0
35047	33348	14327T	PARTICIPANT	\N	PRESENT	0
35048	33348	07029T	PARTICIPANT	\N	PRESENT	0
35049	33348	01025N	PARTICIPANT	\N	PRESENT	0
35050	33348	01024M	PARTICIPANT	\N	PRESENT	0
35051	33348	08056B	PARTICIPANT	\N	PRESENT	0
35052	33348	14237S	PARTICIPANT	\N	PRESENT	0
35053	33348	01047U	PARTICIPANT	\N	PRESENT	0
35054	33348	08044W	PARTICIPANT	\N	PRESENT	0
35055	33348	14193X	PARTICIPANT	\N	PRESENT	0
35056	33348	14255U	PARTICIPANT	\N	PRESENT	0
35057	33348	07004J	PARTICIPANT	\N	PRESENT	0
35058	33348	98042T	PARTICIPANT	\N	PRESENT	0
35059	33348	95063L	PARTICIPANT	\N	PRESENT	0
35060	33348	14167V	PARTICIPANT	\N	PRESENT	0
35061	33348	04089T	PARTICIPANT	\N	PRESENT	0
35062	33348	14179A	PARTICIPANT	\N	PRESENT	0
35063	33348	11093T	PARTICIPANT	\N	PRESENT	0
35064	33348	14231L	PARTICIPANT	\N	PRESENT	0
35065	33348	14083S	PARTICIPANT	\N	PRESENT	0
35066	33348	14089Y	PARTICIPANT	\N	PRESENT	0
35067	33348	11082Q	PARTICIPANT	\N	PRESENT	0
35068	33348	11090Q	PARTICIPANT	\N	PRESENT	0
35069	33348	11111C	PARTICIPANT	\N	PRESENT	0
35070	33348	14073Q	PARTICIPANT	\N	PRESENT	0
35071	33348	95035G	PARTICIPANT	\N	PRESENT	0
35072	33348	14275Y	PARTICIPANT	\N	PRESENT	0
35073	33348	14277B	PARTICIPANT	\N	PRESENT	0
35074	33348	98050T	PARTICIPANT	\N	PRESENT	0
35075	33348	14030Q	PARTICIPANT	\N	PRESENT	0
35076	33348	14221J	PARTICIPANT	\N	PRESENT	0
35077	33348	14042U	PARTICIPANT	\N	PRESENT	0
35078	33348	14219Q	PARTICIPANT	\N	PRESENT	0
35079	33348	14103D	PARTICIPANT	\N	PRESENT	0
35080	33348	14267Y	PARTICIPANT	\N	PRESENT	0
35081	33348	11070L	PARTICIPANT	\N	PRESENT	0
35082	33348	11064N	PARTICIPANT	\N	PRESENT	0
35083	33348	14205J	PARTICIPANT	\N	PRESENT	0
35084	33348	04080J	PARTICIPANT	\N	PRESENT	0
35085	33348	14034U	PARTICIPANT	\N	PRESENT	0
35086	33348	98005N	PARTICIPANT	\N	PRESENT	0
35087	33348	08009T	PARTICIPANT	\N	PRESENT	0
35088	33348	11053K	PARTICIPANT	\N	PRESENT	0
35089	33348	11112D	PARTICIPANT	\N	PRESENT	0
35090	33348	01034P	PARTICIPANT	\N	PRESENT	0
35091	33348	04040A	PARTICIPANT	\N	PRESENT	0
35092	33348	92044U	PARTICIPANT	\N	PRESENT	0
35093	33348	14087W	PARTICIPANT	\N	PRESENT	0
35095	33348	14119M	PARTICIPANT	\N	PRESENT	0
35099	33348	07032N	PARTICIPANT	\N	PRESENT	0
35097	33348	95067Q	PARTICIPANT	\N	PRESENT	0
35098	33348	86044G	PARTICIPANT	\N	PRESENT	0
35100	33348	08019V	PARTICIPANT	\N	PRESENT	0
35101	33348	08047A	PARTICIPANT	\N	PRESENT	0
35102	33348	08042U	PARTICIPANT	\N	PRESENT	0
35103	33348	01061S	PARTICIPANT	\N	PRESENT	0
35104	33348	14253S	PARTICIPANT	\N	PRESENT	0
35105	33348	08062Y	PARTICIPANT	\N	PRESENT	0
35106	33348	14265W	PARTICIPANT	\N	PRESENT	0
35107	33348	14199E	PARTICIPANT	\N	PRESENT	0
35114	33348	04067M	PARTICIPANT	\N	PRESENT	0
35109	33348	01014K	PARTICIPANT	\N	PRESENT	0
35110	33348	01003G	PARTICIPANT	\N	PRESENT	0
35111	33348	11076S	PARTICIPANT	\N	PRESENT	0
35112	33348	08048B	PARTICIPANT	\N	PRESENT	0
35113	33348	14151M	PARTICIPANT	\N	PRESENT	0
35115	33348	08034U	PARTICIPANT	\N	PRESENT	0
35116	33348	04070G	PARTICIPANT	\N	PRESENT	0
35117	33348	14225N	PARTICIPANT	\N	PRESENT	0
35007	33348	14217N	PARTICIPANT	\N	PRESENT	0
35008	33348	11106F	PARTICIPANT	\N	PRESENT	0
35118	33348	11074Q	PARTICIPANT	\N	PRESENT	0
35119	33348	14251Q	PARTICIPANT	\N	PRESENT	0
35122	33348	11085T	PARTICIPANT	\N	PRESENT	0
35517	33349	86034E	PARTICIPANT	\N	PRESENT	0
35518	33349	01013J	PARTICIPANT	\N	PRESENT	0
35519	33349	11098Y	PARTICIPANT	\N	PRESENT	0
35520	33349	08014Q	PARTICIPANT	\N	PRESENT	0
35521	33349	14225N	PARTICIPANT	\N	PRESENT	0
35522	33349	14107H	PARTICIPANT	\N	PRESENT	0
35523	33349	01031L	PARTICIPANT	\N	PRESENT	0
35524	33349	08073C	PARTICIPANT	\N	PRESENT	0
35525	33349	11110B	PARTICIPANT	\N	PRESENT	0
35526	33349	11065P	PARTICIPANT	\N	PRESENT	0
35527	33349	11037K	PARTICIPANT	\N	PRESENT	0
35528	33349	14042U	PARTICIPANT	\N	PRESENT	0
35529	33349	11053K	PARTICIPANT	\N	PRESENT	0
35530	33349	14167V	PARTICIPANT	\N	PRESENT	0
35531	33349	14271U	PARTICIPANT	\N	PRESENT	0
35532	33349	14281W	PARTICIPANT	\N	PRESENT	0
35557	33349	14081Q	PARTICIPANT	\N	PRESENT	0
35534	33349	01046T	PARTICIPANT	\N	PRESENT	0
35535	33349	04038G	PARTICIPANT	\N	PRESENT	0
35536	33349	14089Y	PARTICIPANT	\N	PRESENT	0
35537	33349	14215L	PARTICIPANT	\N	PRESENT	0
35538	33349	04086Q	PARTICIPANT	\N	PRESENT	0
35539	33349	11090Q	PARTICIPANT	\N	PRESENT	0
35540	33349	14037X	PARTICIPANT	\N	PRESENT	0
35541	33349	14147R	PARTICIPANT	\N	PRESENT	0
35542	33349	08028W	PARTICIPANT	\N	PRESENT	0
35543	33349	11100Y	PARTICIPANT	\N	PRESENT	0
35544	33349	14169X	PARTICIPANT	\N	PRESENT	0
35545	33349	11044J	PARTICIPANT	\N	PRESENT	0
35546	33349	01057W	PARTICIPANT	\N	PRESENT	0
35547	33349	04097T	PARTICIPANT	\N	PRESENT	0
35548	33349	07029T	PARTICIPANT	\N	PRESENT	0
35549	33349	14199E	PARTICIPANT	\N	PRESENT	0
35550	33349	14031R	PARTICIPANT	\N	PRESENT	0
35551	33349	14133K	PARTICIPANT	\N	PRESENT	0
35552	33349	08062Y	PARTICIPANT	\N	PRESENT	0
35553	33349	14173T	PARTICIPANT	\N	PRESENT	0
35554	33349	14261S	PARTICIPANT	\N	PRESENT	0
35555	33349	08068F	PARTICIPANT	\N	PRESENT	0
35556	33349	92020L	PARTICIPANT	\N	PRESENT	0
41146	41145	05012A	PARTICIPANT	\N	PRESENT	0
41149	41148	14221J	PARTICIPANT	\N	PRESENT	0
45975	45973	01046T	PARTICIPANT	\N	PRESENT	0
45978	45977	01046T	PARTICIPANT	\N	PRESENT	0
46064	46063	01046T	PARTICIPANT	\N	PRESENT	0
45994	45993	14037X	PARTICIPANT	\N	PRESENT	0
46072	46071	01046T	PARTICIPANT	\N	PRESENT	0
46139	46138	14037X	PARTICIPANT	\N	PRESENT	0
46191	46190	11039M	PARTICIPANT	\N	PRESENT	0
46192	46190	98042T	PARTICIPANT	\N	PRESENT	0
46193	46190	01019Q	PARTICIPANT	\N	PRESENT	0
46285	44248	04043D	PARTICIPANT	\N	PRESENT	0
46286	44620	11036J	PARTICIPANT	\N	EXCUSE	0
46682	46681	01044R	PARTICIPANT	\N	PRESENT	0
46683	46681	14038Y	PARTICIPANT	\N	PRESENT	0
46684	46681	01037S	PARTICIPANT	\N	PRESENT	0
46685	46681	11091R	PARTICIPANT	\N	PRESENT	0
46694	46693	01044R	PARTICIPANT	\N	PRESENT	0
47099	45708	14265W	PARTICIPANT	\N	PRESENT	0
47100	45708	14133K	PARTICIPANT	\N	PRESENT	0
47101	45708	11097X	PARTICIPANT	\N	PRESENT	0
47102	45708	14031R	PARTICIPANT	\N	PRESENT	0
47103	45708	14253S	PARTICIPANT	\N	PRESENT	0
47104	45708	14103D	PARTICIPANT	\N	PRESENT	0
47105	45708	04088S	PARTICIPANT	\N	PRESENT	0
47106	45708	87003B	PARTICIPANT	\N	PRESENT	0
47122	45708	11104D	PARTICIPANT	\N	PRESENT	0
47108	45708	11098Y	PARTICIPANT	\N	PRESENT	0
47109	45708	11042G	PARTICIPANT	\N	PRESENT	0
47110	45708	98022P	PARTICIPANT	\N	PRESENT	0
47111	45708	14018U	PARTICIPANT	\N	PRESENT	0
47112	45708	98046X	PARTICIPANT	\N	PRESENT	0
47113	45708	11070L	PARTICIPANT	\N	PRESENT	0
47114	45708	04097T	PARTICIPANT	\N	PRESENT	0
47115	45708	77002U	PARTICIPANT	\N	PRESENT	0
47116	45708	14187A	PARTICIPANT	\N	PRESENT	0
47117	45708	04074L	PARTICIPANT	\N	PRESENT	0
47118	45708	14053L	PARTICIPANT	\N	PRESENT	0
47119	45708	14219Q	PARTICIPANT	\N	PRESENT	0
47120	45708	14239U	PARTICIPANT	\N	PRESENT	0
47121	45708	14201E	PARTICIPANT	\N	PRESENT	0
47123	45708	14225N	PARTICIPANT	\N	PRESENT	0
47124	45708	04059M	PARTICIPANT	\N	PRESENT	0
47125	45708	11077T	PARTICIPANT	\N	PRESENT	0
47126	45708	04085P	PARTICIPANT	\N	PRESENT	0
47127	45708	01013J	PARTICIPANT	\N	PRESENT	0
47128	45708	01056V	PARTICIPANT	\N	PRESENT	0
47129	45708	04066L	PARTICIPANT	\N	PRESENT	0
47130	45708	12041X	PARTICIPANT	\N	PRESENT	0
47131	45708	92018S	PARTICIPANT	\N	PRESENT	0
47132	45708	98053W	PARTICIPANT	\N	PRESENT	0
47097	45708	08015R	PARTICIPANT	\N	PRESENT	0
47098	45708	92044U	PARTICIPANT	\N	PRESENT	0
47133	45708	14169X	PARTICIPANT	\N	PRESENT	0
47134	45708	11040E	PARTICIPANT	\N	PRESENT	0
47135	45708	01015L	PARTICIPANT	\N	PRESENT	0
47136	45708	11083R	PARTICIPANT	\N	PRESENT	0
47137	45708	04067M	PARTICIPANT	\N	PRESENT	0
47138	45708	04035D	PARTICIPANT	\N	PRESENT	0
47139	45708	04038G	PARTICIPANT	\N	PRESENT	0
47140	45708	01003G	PARTICIPANT	\N	PRESENT	0
47141	45708	86044G	PARTICIPANT	\N	PRESENT	0
47142	45708	04086Q	PARTICIPANT	\N	PRESENT	0
47143	45708	04089T	PARTICIPANT	\N	PRESENT	0
47144	45708	07029T	PARTICIPANT	\N	PRESENT	0
47145	45708	95049N	PARTICIPANT	\N	PRESENT	0
47146	45708	01007L	PARTICIPANT	\N	PRESENT	0
47147	45708	11053K	PARTICIPANT	\N	PRESENT	0
47148	45708	04036E	PARTICIPANT	\N	PRESENT	0
47149	45708	95030B	PARTICIPANT	\N	PRESENT	0
47150	45708	14249W	PARTICIPANT	\N	PRESENT	0
47151	45708	14327T	PARTICIPANT	\N	PRESENT	0
47152	45708	98024R	PARTICIPANT	\N	PRESENT	0
47153	45708	14083S	PARTICIPANT	\N	PRESENT	0
47154	45708	14089Y	PARTICIPANT	\N	PRESENT	0
47155	45708	04049K	PARTICIPANT	\N	PRESENT	0
47156	45708	14267Y	PARTICIPANT	\N	PRESENT	0
47157	45708	04042C	PARTICIPANT	\N	PRESENT	0
47158	45708	01024M	PARTICIPANT	\N	PRESENT	0
47159	45708	01025N	PARTICIPANT	\N	PRESENT	0
47160	45708	01058X	PARTICIPANT	\N	PRESENT	0
47161	45708	11039M	PARTICIPANT	\N	PRESENT	0
47162	45708	01016M	PARTICIPANT	\N	PRESENT	0
47163	45708	92015P	PARTICIPANT	\N	PRESENT	0
47164	45708	95063L	PARTICIPANT	\N	PRESENT	0
47165	45708	11048N	PARTICIPANT	\N	PRESENT	0
47166	45708	08055A	PARTICIPANT	\N	PRESENT	0
47167	45708	80013X	PARTICIPANT	\N	PRESENT	0
47168	45708	01008M	PARTICIPANT	\N	PRESENT	0
47169	45708	14028W	PARTICIPANT	\N	PRESENT	0
47170	45708	08012N	PARTICIPANT	\N	PRESENT	0
47171	45708	11089X	PARTICIPANT	\N	PRESENT	0
47172	45708	14071N	PARTICIPANT	\N	PRESENT	0
47173	45708	11036J	PARTICIPANT	\N	PRESENT	0
47174	45708	11046L	PARTICIPANT	\N	PRESENT	0
47175	45708	11088W	PARTICIPANT	\N	PRESENT	0
47176	45708	01031L	PARTICIPANT	\N	PRESENT	0
47177	45708	08017T	PARTICIPANT	\N	PRESENT	0
47178	45708	04034C	PARTICIPANT	\N	PRESENT	0
47179	45708	95037J	PARTICIPANT	\N	PRESENT	0
47180	45708	11054L	PARTICIPANT	\N	PRESENT	0
47181	45708	14193X	PARTICIPANT	\N	PRESENT	0
47182	45708	14167V	PARTICIPANT	\N	PRESENT	0
47183	45708	11057P	PARTICIPANT	\N	PRESENT	0
47184	45708	95067Q	PARTICIPANT	\N	PRESENT	0
47185	45708	14001X	PARTICIPANT	\N	PRESENT	0
47186	45708	04079R	PARTICIPANT	\N	PRESENT	0
47187	45708	14207L	PARTICIPANT	\N	PRESENT	0
47188	45708	14251Q	PARTICIPANT	\N	PRESENT	0
47189	45708	14033T	PARTICIPANT	\N	PRESENT	0
47190	45708	14269B	PARTICIPANT	\N	PRESENT	0
47191	45708	04057K	PARTICIPANT	\N	PRESENT	0
47192	45708	04077P	PARTICIPANT	\N	PRESENT	0
47193	45708	11032E	PARTICIPANT	\N	PRESENT	0
47194	45708	04053F	PARTICIPANT	\N	PRESENT	0
47195	45708	01028R	PARTICIPANT	\N	PRESENT	0
47196	45708	01057W	PARTICIPANT	\N	PRESENT	0
47197	45708	11066Q	PARTICIPANT	\N	PRESENT	0
47198	45708	01060R	PARTICIPANT	\N	PRESENT	0
47199	45708	14247U	PARTICIPANT	\N	PRESENT	0
47200	45708	08035V	PARTICIPANT	\N	PRESENT	0
47201	45708	89017R	PARTICIPANT	\N	PRESENT	0
47202	45708	14271U	PARTICIPANT	\N	PRESENT	0
47203	45708	11014C	PARTICIPANT	\N	PRESENT	0
47204	45708	12042Y	PARTICIPANT	\N	PRESENT	0
47205	45708	08042U	PARTICIPANT	\N	PRESENT	0
47206	45708	11029K	PARTICIPANT	\N	PRESENT	0
47207	45708	98023Q	PARTICIPANT	\N	PRESENT	0
47208	45708	11023D	PARTICIPANT	\N	PRESENT	0
47209	45708	11033F	PARTICIPANT	\N	PRESENT	0
47210	45708	08034U	PARTICIPANT	\N	PRESENT	0
47211	45708	04080J	PARTICIPANT	\N	PRESENT	0
47212	45708	88008L	PARTICIPANT	\N	PRESENT	0
47213	45708	98050T	PARTICIPANT	\N	PRESENT	0
47214	45708	07004J	PARTICIPANT	\N	PRESENT	0
47219	45708	11071M	PARTICIPANT	\N	PRESENT	0
47216	45708	08056B	PARTICIPANT	\N	PRESENT	0
47217	45708	11082Q	PARTICIPANT	\N	PRESENT	0
47218	45708	01027Q	PARTICIPANT	\N	PRESENT	0
47220	45708	14123H	PARTICIPANT	\N	PRESENT	0
47221	45708	99004R	PARTICIPANT	\N	PRESENT	0
47222	45708	14069U	PARTICIPANT	\N	PRESENT	0
47223	45708	11111C	PARTICIPANT	\N	PRESENT	0
47230	45708	11100Y	PARTICIPANT	\N	PRESENT	0
47225	45708	02002K	PARTICIPANT	\N	PRESENT	0
47226	45708	08010L	PARTICIPANT	\N	PRESENT	0
47233	45708	14255U	PARTICIPANT	\N	PRESENT	0
47228	45708	04071H	PARTICIPANT	\N	PRESENT	0
47229	45708	08011M	PARTICIPANT	\N	PRESENT	0
47231	45708	95035G	PARTICIPANT	\N	PRESENT	0
47232	45708	11068S	PARTICIPANT	\N	PRESENT	0
47234	45708	98042T	PARTICIPANT	\N	PRESENT	0
47235	45708	14237S	PARTICIPANT	\N	PRESENT	0
47236	45708	14105F	PARTICIPANT	\N	PRESENT	0
47237	45708	14037X	PARTICIPANT	\N	PRESENT	0
47238	45708	14157T	PARTICIPANT	\N	PRESENT	0
47239	45708	11049P	PARTICIPANT	\N	PRESENT	0
47240	45708	14195A	PARTICIPANT	\N	PRESENT	0
47241	45708	96004D	PARTICIPANT	\N	PRESENT	0
47242	45708	14093U	PARTICIPANT	\N	PRESENT	0
47243	45708	01041N	PARTICIPANT	\N	PRESENT	0
47244	45708	14119M	PARTICIPANT	\N	PRESENT	0
47245	45708	14038Y	PARTICIPANT	\N	PRESENT	0
30844	30808	11046L	PARTICIPANT	\N	PRESENT	0
30845	30808	01058X	PARTICIPANT	\N	PRESENT	0
30846	30808	11094U	PARTICIPANT	\N	PRESENT	0
30847	30808	11066Q	PARTICIPANT	\N	PRESENT	0
31195	28666	04043D	PARTICIPANT	\N	EXCUSE	0
38355	38042	14038Y	PARTICIPANT	\N	PRESENT	0
38356	38042	97011G	PARTICIPANT	\N	PRESENT	0
38357	38042	14327T	PARTICIPANT	\N	PRESENT	0
38358	38042	86044G	PARTICIPANT	\N	PRESENT	0
38359	38042	14167V	PARTICIPANT	\N	PRESENT	0
38360	38042	08031R	PARTICIPANT	\N	PRESENT	0
38361	38042	80013X	PARTICIPANT	\N	PRESENT	0
38362	38042	11032E	PARTICIPANT	\N	PRESENT	0
38363	38042	11095V	PARTICIPANT	\N	PRESENT	0
38364	38042	14267Y	PARTICIPANT	\N	PRESENT	0
38365	38042	11010L	PARTICIPANT	\N	PRESENT	0
38366	38042	14199E	PARTICIPANT	\N	PRESENT	0
38367	38042	01025N	PARTICIPANT	\N	PRESENT	0
38368	38042	14001X	PARTICIPANT	\N	PRESENT	0
38369	38042	99002P	PARTICIPANT	\N	PRESENT	0
38370	38042	11100Y	PARTICIPANT	\N	PRESENT	0
38373	38042	08016S	PARTICIPANT	\N	PRESENT	0
38376	38042	11027H	PARTICIPANT	\N	PRESENT	0
38377	38042	95035G	PARTICIPANT	\N	PRESENT	0
38378	38042	14205J	PARTICIPANT	\N	PRESENT	0
38379	38042	01003G	PARTICIPANT	\N	PRESENT	0
38380	38042	95037J	PARTICIPANT	\N	PRESENT	0
38381	38042	14051J	PARTICIPANT	\N	PRESENT	0
38382	38042	07032N	PARTICIPANT	\N	PRESENT	0
38387	38042	87003B	PARTICIPANT	\N	PRESENT	0
38388	38042	98029W	PARTICIPANT	\N	PRESENT	0
38389	38042	14169X	PARTICIPANT	\N	PRESENT	0
38390	38042	11023D	PARTICIPANT	\N	PRESENT	0
38391	38042	11083R	PARTICIPANT	\N	PRESENT	0
38392	38042	00003C	PARTICIPANT	\N	PRESENT	0
38393	38042	14121F	PARTICIPANT	\N	PRESENT	0
38396	38042	11067R	PARTICIPANT	\N	PRESENT	0
38435	38042	14281W	PARTICIPANT	\N	PRESENT	0
38436	38042	14271U	PARTICIPANT	\N	PRESENT	0
38440	38042	14195A	PARTICIPANT	\N	PRESENT	0
38453	38042	11097X	PARTICIPANT	\N	PRESENT	0
38458	38042	04080J	PARTICIPANT	\N	PRESENT	0
38482	38042	95030B	PARTICIPANT	\N	PRESENT	0
38488	38042	04092N	PARTICIPANT	\N	PRESENT	0
38490	38042	08009T	PARTICIPANT	\N	PRESENT	0
38495	38042	14217N	PARTICIPANT	\N	PRESENT	0
38515	38042	14026U	PARTICIPANT	\N	PRESENT	0
38545	38042	98018T	PARTICIPANT	\N	PRESENT	0
38548	38042	14197C	PARTICIPANT	\N	PRESENT	0
38549	38042	04088S	PARTICIPANT	\N	PRESENT	0
38590	38042	01034P	PARTICIPANT	\N	PRESENT	0
38591	38042	14207L	PARTICIPANT	\N	PRESENT	0
38592	38042	08028W	PARTICIPANT	\N	PRESENT	0
38593	38042	14033T	PARTICIPANT	\N	PRESENT	0
38596	38042	08015R	PARTICIPANT	\N	PRESENT	0
38597	38042	08038Y	PARTICIPANT	\N	PRESENT	0
38600	38042	08017T	PARTICIPANT	\N	PRESENT	0
38605	38042	08068F	PARTICIPANT	\N	PRESENT	0
38606	38042	11048N	PARTICIPANT	\N	PRESENT	0
38607	38042	01048V	PARTICIPANT	\N	PRESENT	0
38608	38042	14257W	PARTICIPANT	\N	PRESENT	0
38609	38042	14241N	PARTICIPANT	\N	PRESENT	0
38610	38042	11101A	PARTICIPANT	\N	PRESENT	0
38611	38042	04048J	PARTICIPANT	\N	PRESENT	0
38612	38042	14229S	PARTICIPANT	\N	PRESENT	0
38613	38042	14187A	PARTICIPANT	\N	PRESENT	0
38614	38042	01022K	PARTICIPANT	\N	PRESENT	0
38615	38042	11066Q	PARTICIPANT	\N	PRESENT	0
38616	38042	11084S	PARTICIPANT	\N	PRESENT	0
38617	38042	96004D	PARTICIPANT	\N	PRESENT	0
38618	38042	04049K	PARTICIPANT	\N	PRESENT	0
38620	38042	14028W	PARTICIPANT	\N	PRESENT	0
38621	38042	11026G	PARTICIPANT	\N	PRESENT	0
38623	38042	11014C	PARTICIPANT	\N	PRESENT	0
38624	38042	08060W	PARTICIPANT	\N	PRESENT	0
38625	38042	08056B	PARTICIPANT	\N	PRESENT	0
38626	38042	95031C	PARTICIPANT	\N	PRESENT	0
38627	38042	10006L	PARTICIPANT	\N	PRESENT	0
38628	38042	11093T	PARTICIPANT	\N	PRESENT	0
38629	38042	14081Q	PARTICIPANT	\N	PRESENT	0
38630	38042	14213J	PARTICIPANT	\N	PRESENT	0
38631	38042	11111C	PARTICIPANT	\N	PRESENT	0
38632	38042	12042Y	PARTICIPANT	\N	PRESENT	0
38633	38042	11098Y	PARTICIPANT	\N	PRESENT	0
38634	38042	08051V	PARTICIPANT	\N	PRESENT	0
38635	38042	05012A	PARTICIPANT	\N	PRESENT	0
38636	38042	92039X	PARTICIPANT	\N	PRESENT	0
38637	38042	14261S	PARTICIPANT	\N	PRESENT	0
38638	38042	04053F	PARTICIPANT	\N	PRESENT	0
38639	38042	92031P	PARTICIPANT	\N	PRESENT	0
38640	38042	11059R	PARTICIPANT	\N	PRESENT	0
38641	38042	01037S	PARTICIPANT	\N	PRESENT	0
38642	38042	04033B	PARTICIPANT	\N	PRESENT	0
38643	38042	11036J	PARTICIPANT	\N	PRESENT	0
38644	38042	14157T	PARTICIPANT	\N	PRESENT	0
38761	38619	08055A	PARTICIPANT	\N	PRESENT	0
38762	38619	80013X	PARTICIPANT	\N	PRESENT	0
38763	38619	01022K	PARTICIPANT	\N	PRESENT	0
38764	38619	14051J	PARTICIPANT	\N	PRESENT	0
38765	38619	01016M	PARTICIPANT	\N	PRESENT	0
38766	38619	14083S	PARTICIPANT	\N	PRESENT	0
38767	38619	14031R	PARTICIPANT	\N	PRESENT	0
38768	38619	07029T	PARTICIPANT	\N	PRESENT	0
38769	38619	14157T	PARTICIPANT	\N	PRESENT	0
38770	38619	08009T	PARTICIPANT	\N	PRESENT	0
38771	38619	14069U	PARTICIPANT	\N	PRESENT	0
38772	38619	14265W	PARTICIPANT	\N	PRESENT	0
38773	38619	11065P	PARTICIPANT	\N	PRESENT	0
38774	38619	01015L	PARTICIPANT	\N	PRESENT	0
38775	38619	98018T	PARTICIPANT	\N	PRESENT	0
38776	38619	95030B	PARTICIPANT	\N	PRESENT	0
38777	38619	14033T	PARTICIPANT	\N	PRESENT	0
38778	38619	04097T	PARTICIPANT	\N	PRESENT	0
38779	38619	14217N	PARTICIPANT	\N	PRESENT	0
38780	38619	14231L	PARTICIPANT	\N	PRESENT	0
38781	38619	14241N	PARTICIPANT	\N	PRESENT	0
38782	38619	14219Q	PARTICIPANT	\N	PRESENT	0
38783	38619	11107G	PARTICIPANT	\N	PRESENT	0
38784	38619	14135M	PARTICIPANT	\N	PRESENT	0
38785	38619	14026U	PARTICIPANT	\N	PRESENT	0
38786	38619	11098Y	PARTICIPANT	\N	PRESENT	0
38787	38619	11114F	PARTICIPANT	\N	PRESENT	0
38791	38619	08068F	PARTICIPANT	\N	PRESENT	0
38789	38619	14213J	PARTICIPANT	\N	PRESENT	0
38790	38619	14123H	PARTICIPANT	\N	PRESENT	0
38792	38619	08051V	PARTICIPANT	\N	PRESENT	0
38793	38619	14034U	PARTICIPANT	\N	PRESENT	0
38794	38619	08052W	PARTICIPANT	\N	PRESENT	0
38795	38622	08055A	PARTICIPANT	\N	PRESENT	0
38796	38622	80013X	PARTICIPANT	\N	PRESENT	0
38797	38622	01022K	PARTICIPANT	\N	PRESENT	0
38798	38622	14051J	PARTICIPANT	\N	PRESENT	0
38799	38622	01016M	PARTICIPANT	\N	PRESENT	0
38800	38622	14083S	PARTICIPANT	\N	PRESENT	0
38801	38622	14031R	PARTICIPANT	\N	PRESENT	0
38802	38622	07029T	PARTICIPANT	\N	PRESENT	0
38829	38622	11036J	PARTICIPANT	\N	PRESENT	0
38804	38622	08009T	PARTICIPANT	\N	PRESENT	0
38892	38891	04061F	PARTICIPANT	\N	PRESENT	0
38806	38622	14265W	PARTICIPANT	\N	PRESENT	0
38807	38622	11065P	PARTICIPANT	\N	PRESENT	0
38808	38622	01015L	PARTICIPANT	\N	PRESENT	0
38809	38622	98018T	PARTICIPANT	\N	PRESENT	0
38810	38622	95030B	PARTICIPANT	\N	PRESENT	0
38811	38622	14033T	PARTICIPANT	\N	PRESENT	0
38812	38622	04097T	PARTICIPANT	\N	PRESENT	0
38813	38622	14217N	PARTICIPANT	\N	PRESENT	0
38814	38622	14231L	PARTICIPANT	\N	PRESENT	0
38815	38622	14241N	PARTICIPANT	\N	PRESENT	0
38816	38622	14219Q	PARTICIPANT	\N	PRESENT	0
38817	38622	11107G	PARTICIPANT	\N	PRESENT	0
38818	38622	14135M	PARTICIPANT	\N	PRESENT	0
38894	38893	04061F	PARTICIPANT	\N	PRESENT	0
38928	38924	89029V	PARTICIPANT	\N	PRESENT	0
38821	38622	11114F	PARTICIPANT	\N	PRESENT	0
38822	38622	14213J	PARTICIPANT	\N	PRESENT	0
38823	38622	14123H	PARTICIPANT	\N	PRESENT	0
38824	38622	08068F	PARTICIPANT	\N	PRESENT	0
38929	38924	11040E	PARTICIPANT	\N	PRESENT	0
38826	38622	14034U	PARTICIPANT	\N	PRESENT	0
38827	38622	08052W	PARTICIPANT	\N	PRESENT	0
38828	38622	14157T	PARTICIPANT	\N	PRESENT	0
38930	38924	01057W	PARTICIPANT	\N	PRESENT	0
38931	38924	01031L	PARTICIPANT	\N	PRESENT	0
38932	38924	14225N	PARTICIPANT	\N	PRESENT	0
38933	38924	11042G	PARTICIPANT	\N	PRESENT	0
38934	38924	98046X	PARTICIPANT	\N	PRESENT	0
38935	38924	11057P	PARTICIPANT	\N	PRESENT	0
45701	45700	14037X	PARTICIPANT	\N	PRESENT	0
45704	44620	14263U	PARTICIPANT	\N	EXCUSE	0
45803	45802	14209N	PARTICIPANT	\N	PRESENT	0
45804	45802	14225N	PARTICIPANT	\N	PRESENT	0
45805	45802	14237S	PARTICIPANT	\N	PRESENT	0
45806	45802	01037S	PARTICIPANT	\N	PRESENT	0
45807	45802	11026G	PARTICIPANT	\N	PRESENT	0
45923	45922	08025T	PARTICIPANT	\N	PRESENT	0
45924	45922	04085P	PARTICIPANT	\N	PRESENT	0
45925	45922	05008E	PRESIDENT	0	PRESENT	0
45926	45922	11030C	PARTICIPANT	\N	PRESENT	0
45927	45922	11033F	PARTICIPANT	\N	PRESENT	0
45928	45922	14065Q	PARTICIPANT	\N	PRESENT	0
45929	45922	14069U	PARTICIPANT	\N	PRESENT	0
45930	45922	04047H	PARTICIPANT	\N	PRESENT	0
45931	45922	11032E	PARTICIPANT	\N	PRESENT	0
45932	45922	04038G	PARTICIPANT	\N	PRESENT	0
46212	46210	08043V	PARTICIPANT	\N	PRESENT	0
46213	46210	95015C	PARTICIPANT	\N	PRESENT	0
45935	45922	14259Y	PARTICIPANT	\N	PRESENT	0
45936	45922	11035H	PARTICIPANT	\N	PRESENT	0
45937	45922	14041T	PARTICIPANT	\N	PRESENT	0
46214	46210	08028W	PARTICIPANT	\N	PRESENT	0
45939	45922	01024M	PARTICIPANT	\N	EXCUSE	0
45940	45922	14215L	PARTICIPANT	\N	PRESENT	0
45941	45922	11034G	PARTICIPANT	\N	PRESENT	0
45942	45922	08018U	PARTICIPANT	\N	EXCUSE	0
46215	46210	11083R	PARTICIPANT	\N	PRESENT	0
45944	45922	01007L	PARTICIPANT	\N	PRESENT	0
45945	45922	11049P	PARTICIPANT	\N	PRESENT	0
46216	46210	01027Q	PARTICIPANT	\N	PRESENT	0
45947	45922	11084S	PARTICIPANT	\N	PRESENT	0
45948	45922	11026G	PARTICIPANT	\N	PRESENT	0
45949	45922	04079R	PARTICIPANT	\N	PRESENT	0
45950	45922	14111D	PARTICIPANT	\N	PRESENT	0
46225	46221	95015C	PARTICIPANT	\N	PRESENT	0
46229	43212	95059Q	PARTICIPANT	\N	PRESENT	0
46231	43212	89029V	PARTICIPANT	\N	PRESENT	0
45954	45922	14147R	PARTICIPANT	\N	PRESENT	0
45955	45922	95049N	PARTICIPANT	\N	PRESENT	0
45956	45922	08051V	PARTICIPANT	\N	PRESENT	0
47726	43531	05012A	PARTICIPANT	\N	EXCUSE	0
45958	45922	07034Q	PARTICIPANT	\N	PRESENT	0
45959	45922	04074L	PARTICIPANT	\N	PRESENT	0
45960	45922	10015M	PARTICIPANT	\N	PRESENT	0
45961	45922	95063L	PARTICIPANT	\N	PRESENT	0
45962	45922	01019Q	PARTICIPANT	\N	PRESENT	0
45963	45922	01028R	PARTICIPANT	\N	PRESENT	0
45964	45922	98035U	PARTICIPANT	\N	PRESENT	0
47728	47727	01031L	PRESIDENT	0	PRESENT	0
47729	47727	01013J	PARTICIPANT	\N	PRESENT	0
45967	45922	04044E	PARTICIPANT	\N	PRESENT	0
45968	45922	11037K	PARTICIPANT	\N	PRESENT	0
45969	45922	92045V	PARTICIPANT	\N	PRESENT	0
45970	45922	95067Q	PARTICIPANT	\N	PRESENT	0
45971	45922	01047U	PARTICIPANT	\N	PRESENT	0
47730	47727	14175V	PARTICIPANT	\N	PRESENT	0
47731	47727	11053K	PARTICIPANT	\N	PRESENT	0
47732	47727	11042G	PARTICIPANT	\N	PRESENT	0
47733	47727	04086Q	PARTICIPANT	\N	PRESENT	0
47734	47727	11088W	PARTICIPANT	\N	PRESENT	0
47735	47727	11070L	PARTICIPANT	\N	PRESENT	0
47736	47727	04071H	PARTICIPANT	\N	PRESENT	0
47737	47727	11083R	PARTICIPANT	\N	PRESENT	0
47738	47727	01057W	PARTICIPANT	\N	PRESENT	0
47739	47727	99004R	PARTICIPANT	\N	PRESENT	0
47740	47727	07029T	PARTICIPANT	\N	PRESENT	0
47741	47727	01048V	PARTICIPANT	\N	PRESENT	0
47742	47727	98046X	PARTICIPANT	\N	PRESENT	0
47743	47727	08011M	PARTICIPANT	\N	PRESENT	0
47744	47727	01016M	PARTICIPANT	\N	PRESENT	0
47745	47727	11012A	PARTICIPANT	\N	PRESENT	0
48546	48545	88008L	PARTICIPANT	\N	PRESENT	0
48547	48545	10006L	PARTICIPANT	\N	PRESENT	0
48548	48545	11091R	PARTICIPANT	\N	PRESENT	0
48549	48545	14249W	PARTICIPANT	\N	PRESENT	0
48550	48545	80027E	PARTICIPANT	\N	PRESENT	0
48551	48545	11063M	PARTICIPANT	\N	PRESENT	0
58072	57516	01016M	PARTICIPANT	\N	EXCUSE	0
58576	57886	11101A	PARTICIPANT	\N	PRESENT	0
58577	57886	04077P	PARTICIPANT	\N	PRESENT	0
58578	57886	92040Q	PARTICIPANT	\N	PRESENT	0
58579	57886	92039X	PARTICIPANT	\N	PRESENT	0
58580	57886	11096W	PARTICIPANT	\N	PRESENT	0
58581	57886	01003G	PARTICIPANT	\N	PRESENT	0
58582	57886	05012A	PARTICIPANT	\N	PRESENT	0
58583	57886	01031L	PARTICIPANT	\N	PRESENT	0
58584	57886	04074L	PARTICIPANT	\N	PRESENT	0
58585	57886	14093U	PARTICIPANT	\N	PRESENT	0
58586	57886	04045F	PARTICIPANT	\N	PRESENT	0
58587	57886	11077T	PARTICIPANT	\N	PRESENT	0
58588	57886	01014K	PARTICIPANT	\N	PRESENT	0
58589	57886	11107G	PARTICIPANT	\N	PRESENT	0
58590	57886	08035V	PARTICIPANT	\N	PRESENT	0
58591	57886	98024R	PARTICIPANT	\N	PRESENT	0
58592	57886	11113E	PARTICIPANT	\N	PRESENT	0
58593	57886	11023D	PARTICIPANT	\N	PRESENT	0
58594	57886	01034P	PARTICIPANT	\N	PRESENT	0
58595	57886	04040A	PARTICIPANT	\N	PRESENT	0
58596	57886	11085T	PARTICIPANT	\N	PRESENT	0
58597	57886	04080J	PARTICIPANT	\N	PRESENT	0
58598	57886	11070L	PARTICIPANT	\N	PRESENT	0
58599	57886	98005N	PARTICIPANT	\N	PRESENT	0
58600	57886	14042U	PARTICIPANT	\N	PRESENT	0
58601	57886	14253S	PARTICIPANT	\N	PRESENT	0
58602	57886	14277B	PARTICIPANT	\N	PRESENT	0
58603	57886	89017R	PARTICIPANT	\N	PRESENT	0
58604	57886	04089T	PARTICIPANT	\N	PRESENT	0
58605	57886	14255U	PARTICIPANT	\N	PRESENT	0
58606	57886	01056V	PARTICIPANT	\N	PRESENT	0
58607	57886	08056B	PARTICIPANT	\N	PRESENT	0
58608	57886	04070G	PARTICIPANT	\N	PRESENT	0
58609	57886	01061S	PARTICIPANT	\N	PRESENT	0
58610	57886	14327T	PARTICIPANT	\N	PRESENT	0
58611	57886	83042R	PARTICIPANT	\N	PRESENT	0
58612	57886	05004A	PARTICIPANT	\N	PRESENT	0
58613	57886	11031D	PARTICIPANT	\N	PRESENT	0
58614	57886	11032E	PARTICIPANT	\N	PRESENT	0
58615	57886	14229S	PARTICIPANT	\N	PRESENT	0
58616	57886	04097T	PARTICIPANT	\N	PRESENT	0
58617	57886	01057W	PARTICIPANT	\N	PRESENT	0
58618	57886	11010L	PARTICIPANT	\N	PRESENT	0
58619	57886	08048B	PARTICIPANT	\N	PRESENT	0
58620	57886	08069G	PARTICIPANT	\N	PRESENT	0
58621	57886	08019V	PARTICIPANT	\N	PRESENT	0
58622	57886	14071N	PARTICIPANT	\N	PRESENT	0
58623	57886	08034U	PARTICIPANT	\N	PRESENT	0
58624	57886	07034Q	PARTICIPANT	\N	PRESENT	0
58625	57886	08047A	PARTICIPANT	\N	PRESENT	0
58626	57886	14107H	PARTICIPANT	\N	PRESENT	0
58627	57886	04059M	PARTICIPANT	\N	PRESENT	0
58628	57886	11068S	PARTICIPANT	\N	PRESENT	0
58631	57886	04061F	PARTICIPANT	\N	PRESENT	0
58633	57886	14193X	PARTICIPANT	\N	PRESENT	0
58635	57886	01059Y	PARTICIPANT	\N	PRESENT	0
58638	57886	14251Q	PARTICIPANT	\N	PRESENT	0
58636	57886	11063M	PARTICIPANT	\N	PRESENT	0
58637	57886	14241N	PARTICIPANT	\N	PRESENT	0
58639	57886	08039A	PARTICIPANT	\N	PRESENT	0
58641	57886	14034U	PARTICIPANT	\N	PRESENT	0
58642	57886	98018T	PARTICIPANT	\N	PRESENT	0
35558	33349	08060W	PARTICIPANT	\N	PRESENT	0
35559	33349	11036J	PARTICIPANT	\N	PRESENT	0
35560	33349	14197C	PARTICIPANT	\N	PRESENT	0
35561	33349	11056N	PARTICIPANT	\N	PRESENT	0
35562	33349	01059Y	PARTICIPANT	\N	PRESENT	0
35563	33349	98053W	PARTICIPANT	\N	PRESENT	0
35564	33349	01015L	PARTICIPANT	\N	PRESENT	0
35565	33349	14263U	PARTICIPANT	\N	PRESENT	0
35566	33349	04054G	PARTICIPANT	\N	PRESENT	0
35567	33349	08049C	PARTICIPANT	\N	PRESENT	0
35568	33349	08051V	PARTICIPANT	\N	PRESENT	0
35569	33349	92045V	PARTICIPANT	\N	PRESENT	0
35570	33349	07032N	PARTICIPANT	\N	PRESENT	0
35571	33349	04033B	PARTICIPANT	\N	PRESENT	0
35572	33349	10006L	PARTICIPANT	\N	PRESENT	0
35573	33349	14059S	PARTICIPANT	\N	PRESENT	0
35574	33349	14083S	PARTICIPANT	\N	PRESENT	0
35575	33349	08011M	PARTICIPANT	\N	PRESENT	0
35576	33349	14231L	PARTICIPANT	\N	PRESENT	0
35577	33349	98046X	PARTICIPANT	\N	PRESENT	0
35578	33349	14030Q	PARTICIPANT	\N	PRESENT	0
35579	33349	05004A	PARTICIPANT	\N	PRESENT	0
35580	33349	08039A	PARTICIPANT	\N	PRESENT	0
35581	33349	14053L	PARTICIPANT	\N	PRESENT	0
35582	33349	14205J	PARTICIPANT	\N	PRESENT	0
35583	33349	14327T	PARTICIPANT	\N	PRESENT	0
35584	33349	11112D	PARTICIPANT	\N	PRESENT	0
35585	33349	14073Q	PARTICIPANT	\N	PRESENT	0
35586	33349	14069U	PARTICIPANT	\N	PRESENT	0
35587	33349	14265W	PARTICIPANT	\N	PRESENT	0
35588	33349	14033T	PARTICIPANT	\N	PRESENT	0
35589	33349	01007L	PARTICIPANT	\N	PRESENT	0
35590	33349	04088S	PARTICIPANT	\N	PRESENT	0
35591	33349	14038Y	PARTICIPANT	\N	PRESENT	0
35592	33349	80013X	PARTICIPANT	\N	PRESENT	0
35593	33349	14267Y	PARTICIPANT	\N	PRESENT	0
35594	33349	14034U	PARTICIPANT	\N	PRESENT	0
35595	33349	14219Q	PARTICIPANT	\N	PRESENT	0
35596	33349	14257W	PARTICIPANT	\N	PRESENT	0
35597	33349	14026U	PARTICIPANT	\N	PRESENT	0
35598	33349	01034P	PARTICIPANT	\N	PRESENT	0
35599	33349	14195A	PARTICIPANT	\N	PRESENT	0
35600	33349	14259Y	PARTICIPANT	\N	PRESENT	0
35601	33349	14207L	PARTICIPANT	\N	PRESENT	0
35752	35751	14133K	PARTICIPANT	\N	PRESENT	0
35753	35751	96004D	PRESIDENT	0	PRESENT	0
35754	35751	90003B	PARTICIPANT	\N	PRESENT	0
35755	35751	11035H	PARTICIPANT	\N	PRESENT	0
35756	35751	11026G	PARTICIPANT	\N	PRESENT	0
35757	35751	14001X	PARTICIPANT	\N	PRESENT	0
35758	35751	04057K	PARTICIPANT	\N	EXCUSE	0
35759	35751	08042U	PARTICIPANT	\N	PRESENT	0
35760	35751	14135M	PARTICIPANT	\N	PRESENT	0
35761	35751	04045F	PARTICIPANT	\N	PRESENT	0
35762	35751	92045V	PARTICIPANT	\N	PRESENT	0
35763	35751	08021P	PARTICIPANT	\N	EXCUSE	0
35764	35751	01008M	PARTICIPANT	\N	PRESENT	0
35765	35751	11036J	PARTICIPANT	\N	PRESENT	0
35766	35751	14013P	PARTICIPANT	\N	PRESENT	0
35767	35751	08068F	PARTICIPANT	\N	PRESENT	0
35768	35751	14207L	PARTICIPANT	\N	PRESENT	0
35769	35751	08028W	PARTICIPANT	\N	PRESENT	0
35770	35751	80013X	PARTICIPANT	\N	PRESENT	0
35771	35751	08038Y	PARTICIPANT	\N	PRESENT	0
35772	35751	04089T	PARTICIPANT	\N	PRESENT	0
35773	35751	14197C	PARTICIPANT	\N	PRESENT	0
35774	35751	11110B	PARTICIPANT	\N	PRESENT	0
35775	35751	14187A	PARTICIPANT	\N	PRESENT	0
35776	35751	14033T	PARTICIPANT	\N	PRESENT	0
35777	35751	14081Q	PARTICIPANT	\N	PRESENT	0
35778	35751	11099A	PARTICIPANT	\N	PRESENT	0
35779	35751	04049K	PARTICIPANT	\N	PRESENT	0
35780	35751	08015R	PARTICIPANT	\N	PRESENT	0
35781	35751	11098Y	PARTICIPANT	\N	PRESENT	0
35782	35751	11100Y	PARTICIPANT	\N	PRESENT	0
35783	35751	14205J	PARTICIPANT	\N	PRESENT	0
35784	35751	14257W	PARTICIPANT	\N	PRESENT	0
35785	35751	04088S	PARTICIPANT	\N	PRESENT	0
35786	35751	98050T	PARTICIPANT	\N	PRESENT	0
35787	35751	11046L	PARTICIPANT	\N	PRESENT	0
35788	35751	11066Q	PARTICIPANT	\N	PRESENT	0
35789	35751	14093U	PARTICIPANT	\N	PRESENT	0
35790	35751	14030Q	PARTICIPANT	\N	PRESENT	0
35791	35751	11095V	PARTICIPANT	\N	PRESENT	0
35792	35751	11114F	PARTICIPANT	\N	PRESENT	0
35793	35751	11065P	PARTICIPANT	\N	PRESENT	0
35794	35751	01015L	PARTICIPANT	\N	PRESENT	0
35795	35751	11107G	PARTICIPANT	\N	PRESENT	0
35796	35751	01022K	PARTICIPANT	\N	PRESENT	0
35797	35751	11059R	PARTICIPANT	\N	PRESENT	0
35798	35751	08009T	PARTICIPANT	\N	PRESENT	0
35799	35751	14221J	PARTICIPANT	\N	PRESENT	0
35800	35751	92039X	PARTICIPANT	\N	PRESENT	0
35801	35751	14169X	PARTICIPANT	\N	PRESENT	0
35802	35751	05012A	PARTICIPANT	\N	PRESENT	0
35803	35751	95062K	PARTICIPANT	\N	PRESENT	0
35804	35751	14157T	PARTICIPANT	\N	PRESENT	0
35914	35864	89017R	PARTICIPANT	\N	PRESENT	0
35915	35864	01031L	PRESIDENT	0	PRESENT	0
35916	35864	05004A	PARTICIPANT	\N	PRESENT	0
35917	35864	01013J	PARTICIPANT	\N	PRESENT	0
35918	35864	08014Q	PARTICIPANT	\N	PRESENT	0
35919	35864	14167V	PARTICIPANT	\N	PRESENT	0
35920	35864	14175V	PARTICIPANT	\N	PRESENT	0
35957	35864	11085T	PARTICIPANT	\N	EXCUSE	0
35922	35864	14085U	PARTICIPANT	\N	PRESENT	0
35923	35864	11042G	PARTICIPANT	\N	PRESENT	0
35924	35864	88008L	PARTICIPANT	\N	PRESENT	0
35925	35864	04086Q	PARTICIPANT	\N	PRESENT	0
35926	35864	11070L	PARTICIPANT	\N	PRESENT	0
35927	35864	11088W	PARTICIPANT	\N	PRESENT	0
35928	35864	14327T	PARTICIPANT	\N	PRESENT	0
35929	35864	08022Q	PARTICIPANT	\N	PRESENT	0
35930	35864	01027Q	PARTICIPANT	\N	PRESENT	0
35931	35864	04071H	PARTICIPANT	\N	PRESENT	0
35932	35864	11074Q	PARTICIPANT	\N	PRESENT	0
35933	35864	11083R	PARTICIPANT	\N	PRESENT	0
35934	35864	14199E	PARTICIPANT	\N	PRESENT	0
35935	35864	01057W	PARTICIPANT	\N	PRESENT	0
35936	35864	08016S	PARTICIPANT	\N	PRESENT	0
35937	35864	08069G	PARTICIPANT	\N	PRESENT	0
35938	35864	99004R	PARTICIPANT	\N	PRESENT	0
35939	35864	14159V	PARTICIPANT	\N	PRESENT	0
35940	35864	07029T	PARTICIPANT	\N	PRESENT	0
35941	35864	14277B	PARTICIPANT	\N	PRESENT	0
35942	35864	08010L	PARTICIPANT	\N	PRESENT	0
35943	35864	08034U	PARTICIPANT	\N	PRESENT	0
35944	35864	01048V	PARTICIPANT	\N	PRESENT	0
35945	35864	98046X	PARTICIPANT	\N	PRESENT	0
35946	35864	08011M	PARTICIPANT	\N	PRESENT	0
35947	35864	08073C	PARTICIPANT	\N	PRESENT	0
35948	35864	08061X	PARTICIPANT	\N	PRESENT	0
35949	35864	01016M	PARTICIPANT	\N	PRESENT	0
35950	35864	14225N	PARTICIPANT	\N	PRESENT	0
35951	35864	11012A	PARTICIPANT	\N	PRESENT	0
35952	35864	11057P	PARTICIPANT	\N	PRESENT	0
35953	35864	14173T	PARTICIPANT	\N	PRESENT	0
35954	35864	04034C	PARTICIPANT	\N	PRESENT	0
35955	35864	14083S	PARTICIPANT	\N	PRESENT	0
35956	35864	04061F	PARTICIPANT	\N	PRESENT	0
35958	35864	01024M	RAPPORTEUR_AVIS	\N	PRESENT	0
35959	35864	08012N	RAPPORTEUR_AVIS	\N	PRESENT	0
35960	35864	11104D	RAPPORTEUR_AVIS	\N	PRESENT	0
35962	35864	14119M	RAPPORTEUR_AVIS	\N	PRESENT	0
35963	35864	14187A	RAPPORTEUR_AVIS	\N	PRESENT	0
35967	35966	11076S	PARTICIPANT	\N	PRESENT	0
35968	35966	04054G	PARTICIPANT	\N	PRESENT	0
35969	35966	04040A	PARTICIPANT	\N	PRESENT	0
35970	35966	08058D	PARTICIPANT	\N	PRESENT	0
35971	35966	04042C	PARTICIPANT	\N	PRESENT	0
35973	35966	98029W	PARTICIPANT	\N	PRESENT	0
35975	35966	11027H	PARTICIPANT	\N	PRESENT	0
35976	35966	98018T	PARTICIPANT	\N	PRESENT	0
35977	35966	92018S	PARTICIPANT	\N	PRESENT	0
35978	35966	92020L	PARTICIPANT	\N	PRESENT	0
35979	35966	95030B	PARTICIPANT	\N	PRESENT	0
35982	35966	97011G	PARTICIPANT	\N	PRESENT	0
35984	35966	04035D	PARTICIPANT	\N	PRESENT	0
35985	35966	07024N	PARTICIPANT	\N	PRESENT	0
35986	35966	04095R	PARTICIPANT	\N	PRESENT	0
35987	35966	14014Q	PARTICIPANT	\N	PRESENT	0
35988	35966	11015D	PARTICIPANT	\N	PRESENT	0
35989	35966	07004J	PARTICIPANT	\N	PRESENT	0
43953	41619	96003C	PARTICIPANT	\N	EXCUSE	0
47248	45708	08062Y	PARTICIPANT	\N	PRESENT	0
47246	45708	95015C	PARTICIPANT	\N	PRESENT	0
47247	45708	07032N	PARTICIPANT	\N	PRESENT	0
47249	45708	14041T	PARTICIPANT	\N	PRESENT	0
47250	45708	07024N	PARTICIPANT	\N	PRESENT	0
47251	45708	04048J	PARTICIPANT	\N	PRESENT	0
47252	45708	05012A	PARTICIPANT	\N	PRESENT	0
47253	45708	14061L	PARTICIPANT	\N	PRESENT	0
47254	45708	11055M	PARTICIPANT	\N	PRESENT	0
47255	45708	01048V	PARTICIPANT	\N	PRESENT	0
47256	45708	14175V	PARTICIPANT	\N	PRESENT	0
47257	45708	04081K	PARTICIPANT	\N	PRESENT	0
47258	45708	98018T	PARTICIPANT	\N	PRESENT	0
47259	45708	11031D	PARTICIPANT	\N	PRESENT	0
47260	45708	11112D	PARTICIPANT	\N	PRESENT	0
47261	45708	09001P	PARTICIPANT	\N	PRESENT	0
47262	45708	11076S	PARTICIPANT	\N	PRESENT	0
47263	45708	05004A	PARTICIPANT	\N	PRESENT	0
47265	45708	04061F	PARTICIPANT	\N	PRESENT	0
47307	45708	14205J	PARTICIPANT	\N	PRESENT	0
47312	45708	11084S	PARTICIPANT	\N	PRESENT	0
47317	45708	11099A	PARTICIPANT	\N	PRESENT	0
47320	45708	11085T	PARTICIPANT	\N	PRESENT	0
47321	45708	08069G	PARTICIPANT	\N	PRESENT	0
47330	45708	92045V	PARTICIPANT	\N	PRESENT	0
47331	45708	14034U	PARTICIPANT	\N	PRESENT	0
47579	45709	01013J	PARTICIPANT	\N	PRESENT	0
47580	45709	04081K	PARTICIPANT	\N	PRESENT	0
47582	45709	01015L	PARTICIPANT	\N	PRESENT	0
47583	45709	08009T	PARTICIPANT	\N	PRESENT	0
47586	45709	11107G	PARTICIPANT	\N	PRESENT	0
47587	45709	11099A	PARTICIPANT	\N	PRESENT	0
47588	45709	11012A	PARTICIPANT	\N	PRESENT	0
47591	45709	11068S	PARTICIPANT	\N	PRESENT	0
47592	45709	14038Y	PARTICIPANT	\N	PRESENT	0
47594	45709	08042U	PARTICIPANT	\N	PRESENT	0
47595	45709	80013X	PARTICIPANT	\N	PRESENT	0
47596	45709	11031D	PARTICIPANT	\N	PRESENT	0
47597	45709	98005N	PARTICIPANT	\N	PRESENT	0
47598	45709	04085P	PARTICIPANT	\N	PRESENT	0
47600	45709	07029T	PARTICIPANT	\N	PRESENT	0
47602	45709	04036E	PARTICIPANT	\N	PRESENT	0
47610	45709	07026Q	PARTICIPANT	\N	PRESENT	0
47611	45709	14013P	PARTICIPANT	\N	PRESENT	0
47614	45709	95035G	PARTICIPANT	\N	PRESENT	0
47621	45709	14051J	PARTICIPANT	\N	PRESENT	0
47622	45709	14063N	PARTICIPANT	\N	PRESENT	0
47623	45709	01008M	PARTICIPANT	\N	PRESENT	0
47624	45709	11084S	PARTICIPANT	\N	PRESENT	0
47625	45709	08055A	PARTICIPANT	\N	PRESENT	0
47626	45709	11036J	PARTICIPANT	\N	PRESENT	0
47627	45709	14265W	PARTICIPANT	\N	PRESENT	0
47628	45709	11034G	PARTICIPANT	\N	PRESENT	0
47629	45709	14083S	PARTICIPANT	\N	PRESENT	0
47634	45709	99004R	PARTICIPANT	\N	PRESENT	0
47644	45709	08043V	PARTICIPANT	\N	PRESENT	0
47645	45709	14197C	PARTICIPANT	\N	PRESENT	0
47648	45709	01016M	PARTICIPANT	\N	PRESENT	0
47649	45709	04042C	PARTICIPANT	\N	PRESENT	0
47650	45709	04066L	PARTICIPANT	\N	PRESENT	0
48501	44368	04049K	PARTICIPANT	\N	PRESENT	0
48502	44368	04053F	PARTICIPANT	\N	PRESENT	0
48503	44368	14105F	PARTICIPANT	\N	PRESENT	0
48504	44368	04071H	PARTICIPANT	\N	PRESENT	0
48505	44368	14151M	PARTICIPANT	\N	PRESENT	0
48506	44368	14255U	PARTICIPANT	\N	EXCUSE	0
48553	48552	05012A	PARTICIPANT	\N	PRESENT	0
48789	48681	01046T	PARTICIPANT	\N	PRESENT	0
48685	48681	04053F	PARTICIPANT	\N	PRESENT	0
48686	48681	14255U	PARTICIPANT	\N	PRESENT	0
48688	48681	00003C	PARTICIPANT	\N	PRESENT	0
48689	48681	14053L	PARTICIPANT	\N	PRESENT	0
48690	48681	11103C	PARTICIPANT	\N	PRESENT	0
48691	48681	11044J	PARTICIPANT	\N	PRESENT	0
48692	48681	14195A	PARTICIPANT	\N	PRESENT	0
48693	48681	14267Y	PARTICIPANT	\N	PRESENT	0
48695	48681	11031D	PARTICIPANT	\N	PRESENT	0
48696	48681	08052W	PARTICIPANT	\N	PRESENT	0
48697	48681	01059Y	PARTICIPANT	\N	PRESENT	0
48698	48681	04081K	PARTICIPANT	\N	PRESENT	0
48699	48681	98024R	PARTICIPANT	\N	PRESENT	0
48700	48681	10006L	PARTICIPANT	\N	PRESENT	0
48701	48681	04067M	PARTICIPANT	\N	PRESENT	0
48702	48681	14217N	PARTICIPANT	\N	PRESENT	0
48703	48681	14042U	PARTICIPANT	\N	PRESENT	0
48704	48681	14151M	PARTICIPANT	\N	PRESENT	0
48705	48681	12042Y	PARTICIPANT	\N	PRESENT	0
48706	48681	14281W	PARTICIPANT	\N	PRESENT	0
48707	48681	14087W	PARTICIPANT	\N	PRESENT	0
48709	48681	14034U	PARTICIPANT	\N	PRESENT	0
48710	48681	14231L	PARTICIPANT	\N	PRESENT	0
48711	48681	11061K	PARTICIPANT	\N	PRESENT	0
48713	48681	08041T	PARTICIPANT	\N	PRESENT	0
48714	48681	01011G	PARTICIPANT	\N	PRESENT	0
48715	48681	14026U	PARTICIPANT	\N	PRESENT	0
48716	48681	14213J	PARTICIPANT	\N	EXCUSE	0
48717	48681	14121F	PARTICIPANT	\N	PRESENT	0
48718	48681	11112D	PARTICIPANT	\N	PRESENT	0
48719	48681	14037X	PARTICIPANT	\N	PRESENT	0
48720	48681	14018U	PARTICIPANT	\N	PRESENT	0
48721	48681	11067R	PARTICIPANT	\N	PRESENT	0
48722	48681	14223L	PARTICIPANT	\N	PRESENT	0
48723	48681	04092N	PRESIDENT	0	PRESENT	0
48724	48681	14265W	PARTICIPANT	\N	PRESENT	0
48725	48681	14119M	PARTICIPANT	\N	PRESENT	0
48726	48681	14071N	PARTICIPANT	\N	PRESENT	0
48727	48681	07032N	PARTICIPANT	\N	PRESENT	0
48728	48681	04043D	PARTICIPANT	\N	PRESENT	0
48729	48681	14271U	PARTICIPANT	\N	PRESENT	0
48731	48681	11093T	PARTICIPANT	\N	PRESENT	0
48732	48681	11097X	PARTICIPANT	\N	PRESENT	0
48733	48681	04045F	PARTICIPANT	\N	PRESENT	0
48734	48681	14227Q	PARTICIPANT	\N	PRESENT	0
48735	48681	01034P	PARTICIPANT	\N	PRESENT	0
48736	48681	11025F	PARTICIPANT	\N	PRESENT	0
48737	48681	11063M	PARTICIPANT	\N	PRESENT	0
48738	48681	14269B	PARTICIPANT	\N	PRESENT	0
48840	48839	11076S	PARTICIPANT	\N	PRESENT	0
48842	48839	04040A	PARTICIPANT	\N	PRESENT	0
48843	48839	08058D	PARTICIPANT	\N	PRESENT	0
48844	48839	04042C	PARTICIPANT	\N	PRESENT	0
48846	48839	98029W	PARTICIPANT	\N	PRESENT	0
48848	48839	11027H	PARTICIPANT	\N	PRESENT	0
48849	48839	98018T	PARTICIPANT	\N	PRESENT	0
48850	48839	92018S	PARTICIPANT	\N	PRESENT	0
48851	48839	92020L	PARTICIPANT	\N	PRESENT	0
48852	48839	95030B	PARTICIPANT	\N	PRESENT	0
48856	48839	08065C	PARTICIPANT	\N	PRESENT	0
48858	48839	07024N	PARTICIPANT	\N	PRESENT	0
48861	48839	11015D	PARTICIPANT	\N	PRESENT	0
48862	48839	07004J	PARTICIPANT	\N	PRESENT	0
48863	48839	95035G	PARTICIPANT	\N	PRESENT	0
48864	48839	08056B	PARTICIPANT	\N	EXCUSE	0
48865	48839	14211G	PARTICIPANT	\N	PRESENT	0
48866	48839	98022P	PARTICIPANT	\N	PRESENT	0
48867	48839	11064N	PARTICIPANT	\N	PRESENT	0
48868	48839	95037J	PARTICIPANT	\N	PRESENT	0
48869	48839	04078Q	PARTICIPANT	\N	PRESENT	0
48872	48839	04036E	PARTICIPANT	\N	PRESENT	0
48874	48839	04077P	PARTICIPANT	\N	PRESENT	0
48876	48839	92031P	PARTICIPANT	\N	PRESENT	0
48877	48839	11106F	PARTICIPANT	\N	EXCUSE	0
48878	48839	14251Q	PARTICIPANT	\N	PRESENT	0
48879	48839	83042R	PARTICIPANT	\N	PRESENT	0
48880	48839	08053X	PARTICIPANT	\N	PRESENT	0
38976	38924	08073C	PARTICIPANT	\N	PRESENT	0
38977	38924	08061X	PARTICIPANT	\N	PRESENT	0
38978	38924	14231L	PARTICIPANT	\N	PRESENT	0
38979	38924	14034U	PARTICIPANT	\N	PRESENT	0
38980	38924	01016M	PARTICIPANT	\N	PRESENT	0
38981	38924	14018U	PARTICIPANT	\N	PRESENT	0
39032	38924	14103D	PARTICIPANT	\N	PRESENT	0
39033	38924	08022Q	PARTICIPANT	\N	PRESENT	0
39034	38924	11049P	PARTICIPANT	\N	PRESENT	0
39035	38924	11084S	PARTICIPANT	\N	PRESENT	0
39036	38924	14205J	PARTICIPANT	\N	PRESENT	0
39037	38924	14259Y	PARTICIPANT	\N	PRESENT	0
39038	38924	01047U	PARTICIPANT	\N	PRESENT	0
39039	38924	11085T	PARTICIPANT	\N	PRESENT	0
39040	38924	08044W	PARTICIPANT	\N	PRESENT	0
39041	38924	04089T	PARTICIPANT	\N	PRESENT	0
39042	38924	08010L	PARTICIPANT	\N	PRESENT	0
39043	38924	14209N	PARTICIPANT	\N	PRESENT	0
39044	38924	99004R	PARTICIPANT	\N	PRESENT	0
39118	38924	14041T	PARTICIPANT	\N	PRESENT	0
39119	38924	11112D	PARTICIPANT	\N	PRESENT	0
39120	38924	11026G	PARTICIPANT	\N	PRESENT	0
39121	38924	04088S	PARTICIPANT	\N	PRESENT	0
39122	38924	14195A	PARTICIPANT	\N	PRESENT	0
39123	38924	11043H	PARTICIPANT	\N	PRESENT	0
39124	38924	01019Q	PARTICIPANT	\N	PRESENT	0
39125	38924	14257W	PARTICIPANT	\N	PRESENT	0
39126	38924	14001X	PARTICIPANT	\N	PRESENT	0
39127	38924	01046T	PARTICIPANT	\N	PRESENT	0
38936	38924	01013J	PARTICIPANT	\N	PRESENT	0
38937	38924	08014Q	PARTICIPANT	\N	PRESENT	0
38938	38924	11025F	PARTICIPANT	\N	PRESENT	0
38939	38924	08016S	PARTICIPANT	\N	PRESENT	0
38940	38924	14085U	PARTICIPANT	\N	PRESENT	0
38941	38924	88008L	PARTICIPANT	\N	PRESENT	0
38942	38924	11053K	PARTICIPANT	\N	PRESENT	0
38943	38924	14327T	PARTICIPANT	\N	PRESENT	0
38944	38924	14083S	PARTICIPANT	\N	PRESENT	0
38945	38924	01007L	PARTICIPANT	\N	PRESENT	0
38946	38924	99002P	PARTICIPANT	\N	PRESENT	0
38947	38924	14167V	PARTICIPANT	\N	PRESENT	0
38948	38924	04034C	PARTICIPANT	\N	PRESENT	0
38949	38924	11037K	PARTICIPANT	\N	PRESENT	0
38950	38924	01003G	PARTICIPANT	\N	PRESENT	0
38951	38924	04086Q	PARTICIPANT	\N	PRESENT	0
38952	38924	14069U	PARTICIPANT	\N	PRESENT	0
38953	38924	14175V	PARTICIPANT	\N	PRESENT	0
38954	38924	07029T	PARTICIPANT	\N	PRESENT	0
38955	38924	08069G	PARTICIPANT	\N	PRESENT	0
38956	38924	08047A	PARTICIPANT	\N	PRESENT	0
38957	38924	14173T	PARTICIPANT	\N	PRESENT	0
38958	38924	95031C	PARTICIPANT	\N	PRESENT	0
38959	38924	04041B	PARTICIPANT	\N	PRESENT	0
38960	38924	11074Q	PARTICIPANT	\N	PRESENT	0
38961	38924	89017R	PARTICIPANT	\N	PRESENT	0
38962	38924	14105F	PARTICIPANT	\N	PRESENT	0
38963	38924	08015R	PARTICIPANT	\N	PRESENT	0
38964	38924	11012A	PARTICIPANT	\N	PRESENT	0
38965	38924	14065Q	PARTICIPANT	\N	PRESENT	0
38966	38924	11091R	PARTICIPANT	\N	PRESENT	0
38967	38924	87003B	PARTICIPANT	\N	PRESENT	0
38968	38924	14079W	PARTICIPANT	\N	PRESENT	0
38969	38924	08051V	PARTICIPANT	\N	PRESENT	0
38970	38924	08034U	PARTICIPANT	\N	PRESENT	0
38971	38924	11088W	PARTICIPANT	\N	PRESENT	0
38972	38924	11034G	PARTICIPANT	\N	PRESENT	0
38973	38924	11065P	PARTICIPANT	\N	PRESENT	0
38974	38924	01027Q	PARTICIPANT	\N	PRESENT	0
38975	38924	14199E	PARTICIPANT	\N	PRESENT	0
39472	38925	14263U	PARTICIPANT	\N	PRESENT	0
39473	38925	14227Q	PARTICIPANT	\N	PRESENT	0
39474	38925	08014Q	PARTICIPANT	\N	PRESENT	0
39475	38925	14257W	PARTICIPANT	\N	PRESENT	0
39476	38925	14107H	PARTICIPANT	\N	PRESENT	0
39477	38925	11042G	PARTICIPANT	\N	PRESENT	0
39478	38925	14225N	PARTICIPANT	\N	PRESENT	0
39479	38925	01031L	PARTICIPANT	\N	PRESENT	0
39480	38925	01057W	PARTICIPANT	\N	PRESENT	0
39481	38925	11035H	PARTICIPANT	\N	PRESENT	0
39482	38925	98046X	PARTICIPANT	\N	PRESENT	0
39483	38925	14085U	PARTICIPANT	\N	PRESENT	0
39484	38925	11065P	PARTICIPANT	\N	PRESENT	0
39485	38925	08073C	PARTICIPANT	\N	PRESENT	0
39486	38925	14159V	PARTICIPANT	\N	PRESENT	0
39487	38925	11037K	PARTICIPANT	\N	PRESENT	0
39488	38925	14231L	PARTICIPANT	\N	PRESENT	0
39489	38925	11053K	PARTICIPANT	\N	PRESENT	0
39490	38925	07004J	PARTICIPANT	\N	PRESENT	0
39492	38925	11057P	PARTICIPANT	\N	PRESENT	0
39493	38925	04088S	PARTICIPANT	\N	PRESENT	0
39494	38925	07029T	PARTICIPANT	\N	PRESENT	0
39495	38925	88008L	PARTICIPANT	\N	PRESENT	0
39496	38925	14327T	PARTICIPANT	\N	PRESENT	0
39497	38925	04086Q	PARTICIPANT	\N	PRESENT	0
39498	38925	01027Q	PARTICIPANT	\N	PRESENT	0
39499	38925	99004R	PARTICIPANT	\N	PRESENT	0
39500	38925	14173T	PARTICIPANT	\N	PRESENT	0
39501	38925	99002P	PARTICIPANT	\N	PRESENT	0
39502	38925	12042Y	PARTICIPANT	\N	PRESENT	0
39503	38925	04041B	PARTICIPANT	\N	PRESENT	0
39504	38925	14111D	PARTICIPANT	\N	PRESENT	0
39505	38925	11103C	PARTICIPANT	\N	PRESENT	0
39506	38925	14175V	PARTICIPANT	\N	PRESENT	0
39507	38925	08047A	PARTICIPANT	\N	PRESENT	0
39508	38925	11064N	PARTICIPANT	\N	PRESENT	0
39509	38925	08048B	PARTICIPANT	\N	PRESENT	0
39510	38925	14083S	PARTICIPANT	\N	PRESENT	0
39511	38925	08011M	PARTICIPANT	\N	PRESENT	0
39512	38925	11097X	PARTICIPANT	\N	PRESENT	0
39513	38925	95062K	PARTICIPANT	\N	PRESENT	0
39514	38925	01025N	PARTICIPANT	\N	PRESENT	0
39515	38925	04038G	PARTICIPANT	\N	PRESENT	0
39516	38925	14041T	PARTICIPANT	\N	PRESENT	0
39517	38925	11088W	PARTICIPANT	\N	PRESENT	0
39518	38925	08051V	PARTICIPANT	\N	PRESENT	0
39520	38925	08044W	PARTICIPANT	\N	PRESENT	0
39521	38925	08056B	PARTICIPANT	\N	PRESENT	0
39522	38925	14209N	PARTICIPANT	\N	PRESENT	0
39523	38925	14215L	PARTICIPANT	\N	PRESENT	0
39524	38925	08065C	PARTICIPANT	\N	PRESENT	0
39525	38925	04034C	PARTICIPANT	\N	PRESENT	0
39526	38925	11091R	PARTICIPANT	\N	PRESENT	0
39527	38925	08022Q	PARTICIPANT	\N	PRESENT	0
39528	38925	14247U	PARTICIPANT	\N	PRESENT	0
39470	38925	01007L	PARTICIPANT	\N	PRESENT	0
39471	38925	01013J	PARTICIPANT	\N	PRESENT	0
39529	38925	11054L	PARTICIPANT	\N	PRESENT	0
39530	38925	14079W	PARTICIPANT	\N	PRESENT	0
39531	38925	11040E	PARTICIPANT	\N	PRESENT	0
39532	38925	14103D	PARTICIPANT	\N	PRESENT	0
39533	38925	14267Y	PARTICIPANT	\N	PRESENT	0
39534	38925	92015P	PARTICIPANT	\N	PRESENT	0
39535	38925	14042U	PARTICIPANT	\N	PRESENT	0
39536	38925	11023D	PARTICIPANT	\N	PRESENT	0
39537	38925	14259Y	PARTICIPANT	\N	PRESENT	0
39538	38925	14193X	PARTICIPANT	\N	PRESENT	0
39539	38925	98050T	PARTICIPANT	\N	PRESENT	0
39540	38925	11070L	PARTICIPANT	\N	PRESENT	0
39541	38925	01046T	PARTICIPANT	\N	PRESENT	0
39542	38925	14157T	PARTICIPANT	\N	PRESENT	0
39543	38925	11074Q	PARTICIPANT	\N	PRESENT	0
39544	38925	14269B	PARTICIPANT	\N	PRESENT	0
39545	38925	11043H	PARTICIPANT	\N	PRESENT	0
39546	38925	14051J	PARTICIPANT	\N	PRESENT	0
39547	38925	89017R	PARTICIPANT	\N	PRESENT	0
39548	38925	95030B	PARTICIPANT	\N	PRESENT	0
39549	38925	14105F	PARTICIPANT	\N	PRESENT	0
39550	38925	01016M	PARTICIPANT	\N	PRESENT	0
39551	38925	14265W	PARTICIPANT	\N	PRESENT	0
39552	38925	14031R	PARTICIPANT	\N	PRESENT	0
39553	38925	14195A	PARTICIPANT	\N	PRESENT	0
39554	38925	08015R	PARTICIPANT	\N	PRESENT	0
39555	38925	05008E	PARTICIPANT	\N	PRESENT	0
39556	38925	14081Q	PARTICIPANT	\N	PRESENT	0
39557	38925	14097Y	PARTICIPANT	\N	PRESENT	0
39558	38925	11034G	PARTICIPANT	\N	PRESENT	0
39559	38925	96004D	PARTICIPANT	\N	PRESENT	0
39560	38925	08053X	PARTICIPANT	\N	PRESENT	0
39561	38925	14199E	PARTICIPANT	\N	PRESENT	0
39562	38925	14187A	PARTICIPANT	\N	PRESENT	0
39563	38925	11107G	PARTICIPANT	\N	PRESENT	0
39564	38925	14121F	PARTICIPANT	\N	PRESENT	0
39565	38925	14219Q	PARTICIPANT	\N	PRESENT	0
39566	38925	08052W	PARTICIPANT	\N	PRESENT	0
39567	38925	14133K	PARTICIPANT	\N	PRESENT	0
39568	38925	14026U	PARTICIPANT	\N	PRESENT	0
39569	38925	04081K	PARTICIPANT	\N	PRESENT	0
39570	38925	07032N	PARTICIPANT	\N	PRESENT	0
44152	41619	11054L	PARTICIPANT	\N	EXCUSE	0
44153	41619	14017T	PARTICIPANT	\N	EXCUSE	0
47924	47923	95067Q	PARTICIPANT	\N	PRESENT	0
49007	49005	04048J	PARTICIPANT	\N	PRESENT	0
49066	49065	04048J	PARTICIPANT	\N	PRESENT	0
49070	49069	04048J	PARTICIPANT	\N	PRESENT	0
49878	48554	11114F	PARTICIPANT	\N	PRESENT	0
58947	57887	08024S	PARTICIPANT	\N	PRESENT	0
58958	57887	04085P	PARTICIPANT	\N	PRESENT	0
58952	57887	08058D	PARTICIPANT	\N	PRESENT	0
58953	57887	14097Y	PARTICIPANT	\N	PRESENT	0
58954	57887	95049N	PARTICIPANT	\N	PRESENT	0
58955	57887	05008E	PARTICIPANT	\N	PRESENT	0
58959	57887	01028R	PARTICIPANT	\N	PRESENT	0
58957	57887	14013P	PARTICIPANT	\N	PRESENT	0
58960	57887	14269B	PARTICIPANT	\N	PRESENT	0
58961	57887	14159V	PARTICIPANT	\N	PRESENT	0
58962	57887	14271U	PARTICIPANT	\N	PRESENT	0
58963	57887	14081Q	PARTICIPANT	\N	PRESENT	0
58965	57887	14205J	PARTICIPANT	\N	PRESENT	0
58966	57887	01060R	PARTICIPANT	\N	PRESENT	0
58968	57887	14065Q	PARTICIPANT	\N	PRESENT	0
58971	57887	14103D	PARTICIPANT	\N	PRESENT	0
58972	57887	11096W	PARTICIPANT	\N	PRESENT	0
58973	57887	04038G	PARTICIPANT	\N	PRESENT	0
58974	57887	01007L	PARTICIPANT	\N	PRESENT	0
58975	57887	14215L	PARTICIPANT	\N	PRESENT	0
58976	57887	95062K	PARTICIPANT	\N	PRESENT	0
58977	57887	14211G	PARTICIPANT	\N	PRESENT	0
58978	57887	04041B	PARTICIPANT	\N	PRESENT	0
58979	57887	98005N	PARTICIPANT	\N	PRESENT	0
58980	57887	14041T	PARTICIPANT	\N	PRESENT	0
58981	57887	14037X	PARTICIPANT	\N	PRESENT	0
58982	57887	14265W	PARTICIPANT	\N	PRESENT	0
58983	57887	14147R	PARTICIPANT	\N	PRESENT	0
58984	57887	10015M	PARTICIPANT	\N	PRESENT	0
58985	57887	14195A	PARTICIPANT	\N	PRESENT	0
58986	57887	14273W	PARTICIPANT	\N	PRESENT	0
58987	57887	14217N	PARTICIPANT	\N	PRESENT	0
58988	57887	01024M	PARTICIPANT	\N	PRESENT	0
58989	57887	04088S	PARTICIPANT	\N	PRESENT	0
58990	57887	07024N	PARTICIPANT	\N	PRESENT	0
58991	57887	14187A	PARTICIPANT	\N	PRESENT	0
58992	57887	08015R	PARTICIPANT	\N	PRESENT	0
58993	57887	14207L	PARTICIPANT	\N	PRESENT	0
58994	57887	95037J	PARTICIPANT	\N	PRESENT	0
58995	57887	11056N	PARTICIPANT	\N	PRESENT	0
58996	57887	11033F	PARTICIPANT	\N	PRESENT	0
58997	57887	11103C	PARTICIPANT	\N	PRESENT	0
58998	57887	14231L	PARTICIPANT	\N	PRESENT	0
58999	57887	14073Q	PARTICIPANT	\N	PRESENT	0
59000	57887	11012A	PARTICIPANT	\N	PRESENT	0
59001	57887	14223L	PARTICIPANT	\N	PRESENT	0
59002	57887	07034Q	PARTICIPANT	\N	PRESENT	0
59003	57887	14249W	PARTICIPANT	\N	PRESENT	0
59004	57887	04057K	PARTICIPANT	\N	PRESENT	0
59005	57887	04045F	PARTICIPANT	\N	PRESENT	0
59006	57887	08028W	PARTICIPANT	\N	PRESENT	0
59007	57887	96004D	PARTICIPANT	\N	PRESENT	0
59009	57887	04047H	PARTICIPANT	\N	PRESENT	0
59011	57887	14209N	PARTICIPANT	\N	PRESENT	0
59012	57887	14105F	PARTICIPANT	\N	PRESENT	0
59013	57887	11082Q	PARTICIPANT	\N	PRESENT	0
59014	57887	14179A	PARTICIPANT	\N	PRESENT	0
59015	57887	01058X	PARTICIPANT	\N	PRESENT	0
59016	57887	14038Y	PARTICIPANT	\N	PRESENT	0
59017	57887	80013X	PARTICIPANT	\N	PRESENT	0
59018	57887	14257W	PARTICIPANT	\N	PRESENT	0
59019	57887	07004J	PARTICIPANT	\N	PRESENT	0
59020	57887	11110B	PARTICIPANT	\N	PRESENT	0
59021	57887	98022P	PARTICIPANT	\N	PRESENT	0
59022	57887	08055A	PARTICIPANT	\N	PRESENT	0
59023	57887	95063L	PARTICIPANT	\N	PRESENT	0
59024	57887	14191V	PARTICIPANT	\N	PRESENT	0
59025	57887	14031R	PARTICIPANT	\N	PRESENT	0
59026	57887	14033T	PARTICIPANT	\N	PRESENT	0
59027	57887	87003B	PARTICIPANT	\N	PRESENT	0
59028	57887	14253S	PARTICIPANT	\N	PRESENT	0
59029	57887	11043H	PARTICIPANT	\N	PRESENT	0
59030	57887	04048J	PARTICIPANT	\N	PRESENT	0
59031	57887	14061L	PARTICIPANT	\N	PRESENT	0
59032	57887	14237S	PARTICIPANT	\N	PRESENT	0
59033	57887	11030C	PARTICIPANT	\N	PRESENT	0
59034	57887	14133K	PARTICIPANT	\N	PRESENT	0
59035	57887	14219Q	PARTICIPANT	\N	PRESENT	0
59036	57887	10006L	PARTICIPANT	\N	PRESENT	0
59037	57887	01048V	PARTICIPANT	\N	PRESENT	0
59038	57887	11048N	PARTICIPANT	\N	PRESENT	0
59039	57887	01025N	PARTICIPANT	\N	PRESENT	0
59040	57887	92045V	PARTICIPANT	\N	PRESENT	0
59041	57887	08010L	PARTICIPANT	\N	PRESENT	0
59042	57887	14079W	PARTICIPANT	\N	PRESENT	0
59043	57887	14107H	PARTICIPANT	\N	PRESENT	0
59044	57887	11036J	PARTICIPANT	\N	PRESENT	0
59045	57887	11098Y	PARTICIPANT	\N	PRESENT	0
59132	58063	01007L	PARTICIPANT	\N	PRESENT	0
59133	58063	95049N	PARTICIPANT	\N	PRESENT	0
59134	58063	05008E	PARTICIPANT	\N	PRESENT	0
59135	58063	11056N	PARTICIPANT	\N	PRESENT	0
59136	58063	95063L	PARTICIPANT	\N	PRESENT	0
59137	58063	01028R	PARTICIPANT	\N	PRESENT	0
59138	58063	14065Q	PARTICIPANT	\N	PRESENT	0
59139	58063	14257W	PARTICIPANT	\N	PRESENT	0
59140	58063	12042Y	PARTICIPANT	\N	PRESENT	0
59141	58063	04085P	PARTICIPANT	\N	PRESENT	0
59142	58063	11033F	PARTICIPANT	\N	PRESENT	0
59143	58063	14105F	PARTICIPANT	\N	PRESENT	0
59144	58063	14195A	PARTICIPANT	\N	PRESENT	0
59145	58063	07029T	PARTICIPANT	\N	PRESENT	0
59146	58063	95030B	PARTICIPANT	\N	PRESENT	0
59147	58063	96004D	PARTICIPANT	\N	PRESENT	0
59148	58063	14147R	PARTICIPANT	\N	PRESENT	0
59149	58063	95041E	PARTICIPANT	\N	PRESENT	0
59150	58063	10015M	PARTICIPANT	\N	PRESENT	0
59151	58063	07034Q	PARTICIPANT	\N	PRESENT	0
59152	58063	14031R	PARTICIPANT	\N	PRESENT	0
59153	58063	14037X	PARTICIPANT	\N	PRESENT	0
59154	58063	14187A	PARTICIPANT	\N	PRESENT	0
59155	58063	14053L	PARTICIPANT	\N	PRESENT	0
59156	58063	14073Q	PARTICIPANT	\N	PRESENT	0
59157	58063	14030Q	PARTICIPANT	\N	PRESENT	0
59158	58063	14042U	PARTICIPANT	\N	PRESENT	0
59159	58063	14219Q	PARTICIPANT	\N	PRESENT	0
59160	58063	14267Y	PARTICIPANT	\N	PRESENT	0
59161	58063	14089Y	PARTICIPANT	\N	PRESENT	0
59162	58063	11094U	PARTICIPANT	\N	PRESENT	0
59163	58063	01025N	PARTICIPANT	\N	PRESENT	0
59164	58063	11012A	PARTICIPANT	\N	PRESENT	0
59165	58063	07004J	PARTICIPANT	\N	PRESENT	0
59166	58063	14215L	PARTICIPANT	\N	PRESENT	0
59167	58063	01024M	PARTICIPANT	\N	PRESENT	0
59168	58063	14273W	PARTICIPANT	\N	PRESENT	0
59169	58063	04047H	PARTICIPANT	\N	PRESENT	0
59170	58063	04033B	PARTICIPANT	\N	PRESENT	0
59171	58063	11097X	PARTICIPANT	\N	PRESENT	0
59172	58063	14213J	PARTICIPANT	\N	PRESENT	0
59173	58063	14199E	PARTICIPANT	\N	PRESENT	0
59174	58063	04088S	PARTICIPANT	\N	PRESENT	0
59175	58063	01034P	PARTICIPANT	\N	PRESENT	0
59176	58063	14231L	PARTICIPANT	\N	PRESENT	0
59177	58063	14265W	PARTICIPANT	\N	PRESENT	0
59178	58063	08061X	PARTICIPANT	\N	PRESENT	0
59179	58063	08053X	PARTICIPANT	\N	PRESENT	0
59180	58063	14083S	PARTICIPANT	\N	PRESENT	0
59181	58063	11043H	PARTICIPANT	\N	PRESENT	0
59182	58063	92031P	PARTICIPANT	\N	PRESENT	0
59183	58063	11110B	PARTICIPANT	\N	PRESENT	0
59184	58063	14123H	PARTICIPANT	\N	PRESENT	0
59185	58063	08010L	PARTICIPANT	\N	PRESENT	0
59186	58063	14034U	PARTICIPANT	\N	PRESENT	0
59187	58063	14061L	PARTICIPANT	\N	PRESENT	0
59188	58063	14079W	PARTICIPANT	\N	PRESENT	0
59189	58063	14038Y	PARTICIPANT	\N	PRESENT	0
59190	58063	14059S	PARTICIPANT	\N	PRESENT	0
59191	58063	10006L	PARTICIPANT	\N	PRESENT	0
59192	58063	14033T	PARTICIPANT	\N	PRESENT	0
59193	58063	08015R	PARTICIPANT	\N	PRESENT	0
59194	58063	14133K	PARTICIPANT	\N	PRESENT	0
59195	58063	11036J	PARTICIPANT	\N	PRESENT	0
59196	58063	01027Q	PARTICIPANT	\N	PRESENT	0
59197	58063	92045V	PARTICIPANT	\N	PRESENT	0
59293	59291	14133K	PARTICIPANT	\N	PRESENT	0
59295	59291	04059M	PARTICIPANT	\N	PRESENT	0
59296	59291	11039M	PARTICIPANT	\N	PRESENT	0
59297	59291	01044R	PARTICIPANT	\N	PRESENT	0
59298	59291	08043V	PARTICIPANT	\N	PRESENT	0
31517	31514	04043D	PARTICIPANT	\N	PRESENT	0
31522	31514	11082Q	PARTICIPANT	\N	PRESENT	0
31523	31514	80013X	PARTICIPANT	\N	PRESENT	0
31524	31514	01058X	PARTICIPANT	\N	PRESENT	0
36035	36034	11076S	PARTICIPANT	\N	PRESENT	0
36161	35961	08025T	PARTICIPANT	\N	PRESENT	0
36037	36034	04040A	PARTICIPANT	\N	PRESENT	0
36038	36034	08058D	PARTICIPANT	\N	PRESENT	0
36039	36034	04042C	PARTICIPANT	\N	PRESENT	0
36162	35961	04085P	PARTICIPANT	\N	PRESENT	0
36041	36034	98029W	PARTICIPANT	\N	PRESENT	0
36163	35961	05008E	PRESIDENT	0	PRESENT	0
36043	36034	11027H	PARTICIPANT	\N	PRESENT	0
36044	36034	98018T	PARTICIPANT	\N	PRESENT	0
36045	36034	92018S	PARTICIPANT	\N	PRESENT	0
36046	36034	92020L	PARTICIPANT	\N	PRESENT	0
36047	36034	95030B	PARTICIPANT	\N	PRESENT	0
36164	35961	11030C	PARTICIPANT	\N	PRESENT	0
36165	35961	11033F	PARTICIPANT	\N	PRESENT	0
36050	36034	97011G	PARTICIPANT	\N	PRESENT	0
36166	35961	14065Q	PARTICIPANT	\N	PRESENT	0
36052	36034	04035D	PARTICIPANT	\N	PRESENT	0
36053	36034	07024N	PARTICIPANT	\N	PRESENT	0
36054	36034	04095R	PARTICIPANT	\N	PRESENT	0
36055	36034	14014Q	PARTICIPANT	\N	PRESENT	0
36056	36034	11015D	PARTICIPANT	\N	PRESENT	0
36057	36034	07004J	PARTICIPANT	\N	EXCUSE	0
36058	36034	95035G	PARTICIPANT	\N	PRESENT	0
36167	35961	14069U	PARTICIPANT	\N	PRESENT	0
36060	36034	14211G	PARTICIPANT	\N	PRESENT	0
36061	36034	98022P	PARTICIPANT	\N	PRESENT	0
36062	36034	11064N	PARTICIPANT	\N	PRESENT	0
36169	35961	04047H	PARTICIPANT	\N	PRESENT	0
36171	35961	04038G	PARTICIPANT	\N	PRESENT	0
36065	36034	14097Y	PARTICIPANT	\N	PRESENT	0
36066	36034	95041E	PARTICIPANT	\N	PRESENT	0
36067	36034	04036E	PARTICIPANT	\N	PRESENT	0
36068	36034	14039A	PARTICIPANT	\N	PRESENT	0
36069	36034	04077P	PARTICIPANT	\N	PRESENT	0
36070	36034	98005N	PARTICIPANT	\N	PRESENT	0
36071	36034	92031P	PARTICIPANT	\N	PRESENT	0
36072	36034	11106F	PARTICIPANT	\N	PRESENT	0
36073	36034	14251Q	PARTICIPANT	\N	PRESENT	0
36173	35961	99002P	PARTICIPANT	\N	PRESENT	0
36174	35961	11056N	PARTICIPANT	\N	PRESENT	0
36175	35961	14259Y	PARTICIPANT	\N	PRESENT	0
36176	35961	11035H	PARTICIPANT	\N	PRESENT	0
36078	36034	14253S	PARTICIPANT	\N	PRESENT	0
36079	36034	08047A	PARTICIPANT	\N	PRESENT	0
36080	36034	14028W	PARTICIPANT	\N	PRESENT	0
36081	36034	14193X	PARTICIPANT	\N	EXCUSE	0
36082	36034	98021N	PARTICIPANT	\N	PRESENT	0
36177	35961	14041T	PARTICIPANT	\N	PRESENT	0
36084	36034	04080J	PARTICIPANT	\N	PRESENT	0
36085	36034	95059Q	PRESIDENT	0	PRESENT	0
36086	36034	86044G	PARTICIPANT	\N	PRESENT	0
36087	36034	01014K	PARTICIPANT	\N	PRESENT	0
36088	36034	11054L	PARTICIPANT	\N	PRESENT	0
36089	36034	01056V	PARTICIPANT	\N	PRESENT	0
36090	36034	92044U	PARTICIPANT	\N	PRESENT	0
36091	36034	08049C	PARTICIPANT	\N	PRESENT	0
36179	35961	11113E	PARTICIPANT	\N	PRESENT	0
36181	35961	01024M	PARTICIPANT	\N	PRESENT	0
36183	35961	14215L	PARTICIPANT	\N	PRESENT	0
36184	35961	11034G	PARTICIPANT	\N	PRESENT	0
36186	35961	08018U	PARTICIPANT	\N	PRESENT	0
36187	35961	11010L	PARTICIPANT	\N	PRESENT	0
36188	35961	01007L	PARTICIPANT	\N	PRESENT	0
36189	35961	11049P	PARTICIPANT	\N	PRESENT	0
36192	35961	08044W	PARTICIPANT	\N	PRESENT	0
36204	35961	11084S	PARTICIPANT	\N	PRESENT	0
36206	35961	11026G	PARTICIPANT	\N	PRESENT	0
36207	35961	04079R	PARTICIPANT	\N	PRESENT	0
36208	35961	14111D	PARTICIPANT	\N	PRESENT	0
36210	35961	14001X	PARTICIPANT	\N	PRESENT	0
36211	35961	14273W	PARTICIPANT	\N	PRESENT	0
36212	35961	01060R	PARTICIPANT	\N	PRESENT	0
36213	35961	14147R	PARTICIPANT	\N	PRESENT	0
36214	35961	08051V	PARTICIPANT	\N	PRESENT	0
36215	35961	07034Q	PARTICIPANT	\N	PRESENT	0
36216	35961	04074L	PARTICIPANT	\N	PRESENT	0
36217	35961	10015M	PARTICIPANT	\N	PRESENT	0
36218	35961	95063L	PARTICIPANT	\N	PRESENT	0
36219	35961	01019Q	PARTICIPANT	\N	PRESENT	0
36221	35961	01028R	PARTICIPANT	\N	PRESENT	0
36222	35961	98035U	PARTICIPANT	\N	PRESENT	0
36224	35961	04056J	PARTICIPANT	\N	PRESENT	0
36225	35961	14275Y	PARTICIPANT	\N	PRESENT	0
36228	35961	11037K	PARTICIPANT	\N	PRESENT	0
36229	35961	92045V	PARTICIPANT	\N	PRESENT	0
36230	35961	95067Q	PARTICIPANT	\N	PRESENT	0
36231	35961	01047U	PARTICIPANT	\N	PRESENT	0
36237	36236	14261S	PARTICIPANT	\N	PRESENT	0
36238	36236	08055A	PARTICIPANT	\N	PRESENT	0
36239	36236	14093U	PARTICIPANT	\N	PRESENT	0
36240	36236	14030Q	PARTICIPANT	\N	PRESENT	0
36241	36236	96004D	PARTICIPANT	\N	PRESENT	0
36242	36236	08060W	PARTICIPANT	\N	PRESENT	0
36243	36236	11060J	PARTICIPANT	\N	PRESENT	0
36244	36236	11095V	PARTICIPANT	\N	PRESENT	0
36245	36236	14038Y	PARTICIPANT	\N	PRESENT	0
36246	36236	11114F	PARTICIPANT	\N	PRESENT	0
36247	36236	98023Q	PARTICIPANT	\N	PRESENT	0
36249	36236	01015L	PARTICIPANT	\N	PRESENT	0
36250	36236	11107G	PARTICIPANT	\N	PRESENT	0
36252	36236	02002K	PARTICIPANT	\N	PRESENT	0
36253	36236	01022K	PARTICIPANT	\N	PRESENT	0
36254	36236	04097T	PARTICIPANT	\N	PRESENT	0
36255	36236	09001P	PARTICIPANT	\N	PRESENT	0
36256	36236	11059R	PARTICIPANT	\N	PRESENT	0
36257	36236	14219Q	PARTICIPANT	\N	PRESENT	0
36258	36236	80027E	PARTICIPANT	\N	PRESENT	0
36259	36236	14031R	PARTICIPANT	\N	PRESENT	0
36260	36236	08009T	PRESIDENT	0	PRESENT	0
36261	36236	08062Y	PARTICIPANT	\N	PRESENT	0
36262	36236	14221J	PARTICIPANT	\N	EXCUSE	0
36263	36236	92039X	PARTICIPANT	\N	PRESENT	0
36279	36276	14093U	PARTICIPANT	\N	PRESENT	0
36265	36236	14169X	PARTICIPANT	\N	PRESENT	0
36266	36236	14237S	PARTICIPANT	\N	PRESENT	0
36267	36236	13002U	PARTICIPANT	\N	PRESENT	0
36268	36236	05012A	PARTICIPANT	\N	PRESENT	0
35990	35966	95035G	PARTICIPANT	\N	PRESENT	0
35991	35966	08056B	PARTICIPANT	\N	PRESENT	0
35992	35966	14211G	PARTICIPANT	\N	PRESENT	0
35993	35966	98022P	PARTICIPANT	\N	PRESENT	0
35994	35966	11064N	PARTICIPANT	\N	PRESENT	0
35995	35966	95037J	PARTICIPANT	\N	PRESENT	0
35996	35966	04078Q	PARTICIPANT	\N	PRESENT	0
35997	35966	14097Y	PARTICIPANT	\N	PRESENT	0
35998	35966	95041E	PARTICIPANT	\N	PRESENT	0
35999	35966	04036E	PARTICIPANT	\N	PRESENT	0
36000	35966	14039A	PARTICIPANT	\N	PRESENT	0
36001	35966	04077P	PARTICIPANT	\N	PRESENT	0
36002	35966	98005N	PARTICIPANT	\N	PRESENT	0
36003	35966	92031P	PARTICIPANT	\N	PRESENT	0
36004	35966	11106F	PARTICIPANT	\N	PRESENT	0
36005	35966	14251Q	PARTICIPANT	\N	PRESENT	0
36006	35966	83042R	PARTICIPANT	\N	PRESENT	0
36007	35966	08053X	PARTICIPANT	\N	PRESENT	0
36008	35966	11082Q	PARTICIPANT	\N	PRESENT	0
36010	35966	14253S	PARTICIPANT	\N	PRESENT	0
36011	35966	08047A	PARTICIPANT	\N	PRESENT	0
36012	35966	14028W	PARTICIPANT	\N	PRESENT	0
36013	35966	14193X	PARTICIPANT	\N	EXCUSE	0
36014	35966	98021N	PARTICIPANT	\N	PRESENT	0
36270	36236	14135M	PARTICIPANT	\N	PRESENT	0
36016	35966	04080J	PARTICIPANT	\N	PRESENT	0
36017	35966	95059Q	PRESIDENT	0	PRESENT	0
36018	35966	86044G	PARTICIPANT	\N	PRESENT	0
36019	35966	01014K	PARTICIPANT	\N	PRESENT	0
36020	35966	11054L	PARTICIPANT	\N	PRESENT	0
36021	35966	01056V	PARTICIPANT	\N	PRESENT	0
36022	35966	92044U	PARTICIPANT	\N	PRESENT	0
36023	35966	08049C	PARTICIPANT	\N	PRESENT	0
36271	36236	95062K	PARTICIPANT	\N	PRESENT	0
36272	36236	14107H	PARTICIPANT	\N	PRESENT	0
36273	36236	14051J	PARTICIPANT	\N	PRESENT	0
36274	36236	14157T	PARTICIPANT	\N	PRESENT	0
36275	36236	96003C	PARTICIPANT	\N	EXCUSE	0
36280	36276	14030Q	PARTICIPANT	\N	PRESENT	0
36281	36276	96004D	PARTICIPANT	\N	PRESENT	0
48883	48839	14253S	PARTICIPANT	\N	PRESENT	0
48884	48839	08047A	PARTICIPANT	\N	PRESENT	0
48885	48839	14028W	PARTICIPANT	\N	PRESENT	0
48886	48839	14193X	PARTICIPANT	\N	PRESENT	0
48887	48839	98021N	PARTICIPANT	\N	EXCUSE	0
49164	47946	13002U	PARTICIPANT	\N	PRESENT	0
48889	48839	04080J	PARTICIPANT	\N	PRESENT	0
48890	48839	95059Q	PRESIDENT	0	PRESENT	0
48891	48839	86044G	PARTICIPANT	\N	PRESENT	0
48892	48839	01014K	PARTICIPANT	\N	PRESENT	0
48893	48839	11054L	PARTICIPANT	\N	PRESENT	0
48894	48839	01056V	PARTICIPANT	\N	PRESENT	0
48895	48839	92044U	PARTICIPANT	\N	PRESENT	0
48896	48839	08049C	PARTICIPANT	\N	PRESENT	0
49165	47946	11040E	PARTICIPANT	\N	PRESENT	0
49702	49701	01016M	PARTICIPANT	\N	PRESENT	0
49934	49933	05008E	PRESIDENT	0	PRESENT	0
49935	49933	11035H	PARTICIPANT	\N	PRESENT	0
49722	49721	14135M	PARTICIPANT	\N	PRESENT	0
49723	49721	01044R	PARTICIPANT	\N	PRESENT	0
49724	49721	14239U	PARTICIPANT	\N	PRESENT	0
49725	49721	88008L	PARTICIPANT	\N	PRESENT	0
49726	49721	11083R	PARTICIPANT	\N	PRESENT	0
49727	49721	08025T	PARTICIPANT	\N	PRESENT	0
49728	49721	04049K	PARTICIPANT	\N	PRESENT	0
49729	49721	04036E	PARTICIPANT	\N	PRESENT	0
49730	49721	08061X	PARTICIPANT	\N	PRESENT	0
48911	48839	97011G	PARTICIPANT	\N	PRESENT	0
49732	49731	90003B	PARTICIPANT	\N	PRESENT	0
49733	49731	08022Q	PARTICIPANT	\N	PRESENT	0
49734	49731	11091R	PARTICIPANT	\N	PRESENT	0
49735	49731	08010L	PARTICIPANT	\N	PRESENT	0
49736	49731	14059S	PARTICIPANT	\N	PRESENT	0
49737	49731	04057K	PARTICIPANT	\N	PRESENT	0
49738	49731	04088S	PARTICIPANT	\N	PRESENT	0
49739	49731	04044E	PARTICIPANT	\N	PRESENT	0
49742	49741	01025N	PARTICIPANT	\N	PRESENT	0
49743	49741	08039A	PARTICIPANT	\N	PRESENT	0
49744	49741	14109K	PARTICIPANT	\N	PRESENT	0
49745	49741	14229S	PARTICIPANT	\N	PRESENT	0
49747	49746	01025N	PARTICIPANT	\N	PRESENT	0
49748	49746	08039A	PARTICIPANT	\N	PRESENT	0
49750	49749	08039A	PARTICIPANT	\N	PRESENT	0
49751	49749	14263U	PARTICIPANT	\N	PRESENT	0
49752	49749	11029K	PARTICIPANT	\N	PRESENT	0
49753	49749	08043V	PARTICIPANT	\N	PRESENT	0
49754	49749	08031R	PARTICIPANT	\N	PRESENT	0
49755	49749	14235Q	PARTICIPANT	\N	PRESENT	0
49756	49749	14229S	PARTICIPANT	\N	PRESENT	0
49758	49757	01025N	PARTICIPANT	\N	PRESENT	0
49759	49757	08039A	PARTICIPANT	\N	PRESENT	0
49760	49757	14229S	PARTICIPANT	\N	PRESENT	0
49761	49757	14109K	PARTICIPANT	\N	PRESENT	0
49763	49762	08039A	PARTICIPANT	\N	PRESENT	0
49764	49762	01025N	PARTICIPANT	\N	PRESENT	0
49766	49765	01025N	PARTICIPANT	\N	PRESENT	0
49767	49765	08043V	PARTICIPANT	\N	PRESENT	0
49769	49768	01025N	PARTICIPANT	\N	PRESENT	0
49770	49768	08039A	PARTICIPANT	\N	PRESENT	0
49771	49768	07026Q	PARTICIPANT	\N	PRESENT	0
49772	49768	14179A	PARTICIPANT	\N	PRESENT	0
49774	49773	01025N	PARTICIPANT	\N	PRESENT	0
49775	49773	08039A	PARTICIPANT	\N	PRESENT	0
49776	49773	07026Q	PARTICIPANT	\N	PRESENT	0
49777	49773	08043V	PARTICIPANT	\N	PRESENT	0
49778	49773	14109K	PARTICIPANT	\N	PRESENT	0
49779	49773	14229S	PARTICIPANT	\N	PRESENT	0
49781	49780	08039A	PARTICIPANT	\N	PRESENT	0
49782	49780	14229S	PARTICIPANT	\N	PRESENT	0
49784	49783	11083R	PARTICIPANT	\N	PRESENT	0
49078	49077	08025T	PARTICIPANT	\N	PRESENT	0
49079	49077	04085P	PARTICIPANT	\N	PRESENT	0
47969	47961	05008E	PRESIDENT	0	PRESENT	0
49080	49077	05008E	PRESIDENT	0	PRESENT	0
47971	47961	11033F	PARTICIPANT	\N	PRESENT	0
47972	47961	14065Q	PARTICIPANT	\N	PRESENT	0
47973	47961	14069U	PARTICIPANT	\N	PRESENT	0
47974	47961	04047H	PARTICIPANT	\N	PRESENT	0
49081	49077	11030C	PARTICIPANT	\N	PRESENT	0
47976	47961	04038G	PARTICIPANT	\N	PRESENT	0
49082	49077	11033F	PARTICIPANT	\N	PRESENT	0
47978	47961	11056N	PARTICIPANT	\N	EXCUSE	0
49083	49077	14065Q	PARTICIPANT	\N	PRESENT	0
47980	47961	11035H	PARTICIPANT	\N	PRESENT	0
47981	47961	14041T	PARTICIPANT	\N	PRESENT	0
49084	49077	14069U	PARTICIPANT	\N	PRESENT	0
47983	47961	01024M	PARTICIPANT	\N	PRESENT	0
49085	49077	04047H	PARTICIPANT	\N	PRESENT	0
49086	49077	11032E	PARTICIPANT	\N	PRESENT	0
49087	49077	04038G	PARTICIPANT	\N	PRESENT	0
47987	47961	11010L	PARTICIPANT	\N	EXCUSE	0
47988	47961	01007L	PARTICIPANT	\N	EXCUSE	0
49088	49077	99002P	PARTICIPANT	\N	PRESENT	0
49089	49077	11035H	PARTICIPANT	\N	PRESENT	0
49090	49077	14041T	PARTICIPANT	\N	PRESENT	0
47992	47961	11026G	PARTICIPANT	\N	PRESENT	0
49091	49077	11113E	PARTICIPANT	\N	PRESENT	0
47994	47961	14111D	PARTICIPANT	\N	PRESENT	0
49092	49077	01024M	PARTICIPANT	\N	PRESENT	0
47996	47961	14273W	PARTICIPANT	\N	PRESENT	0
49093	49077	11034G	PARTICIPANT	\N	PRESENT	0
47998	47961	14147R	PARTICIPANT	\N	PRESENT	0
49094	49077	08018U	PARTICIPANT	\N	PRESENT	0
49095	49077	11049P	PARTICIPANT	\N	PRESENT	0
48001	47961	11072N	PARTICIPANT	\N	PRESENT	0
48002	47961	07034Q	PARTICIPANT	\N	PRESENT	0
49096	49077	08044W	PARTICIPANT	\N	PRESENT	0
49097	49077	11026G	PARTICIPANT	\N	PRESENT	0
49098	49077	14273W	PARTICIPANT	\N	PRESENT	0
49099	49077	14147R	PARTICIPANT	\N	PRESENT	0
48007	47961	01028R	PARTICIPANT	\N	PRESENT	0
48008	47961	98035U	PARTICIPANT	\N	PRESENT	0
48009	47961	04056J	PARTICIPANT	\N	PRESENT	0
49100	49077	95049N	PARTICIPANT	\N	PRESENT	0
48011	47961	04044E	PARTICIPANT	\N	PRESENT	0
48012	47961	11037K	PARTICIPANT	\N	PRESENT	0
48013	47961	92045V	PARTICIPANT	\N	PRESENT	0
48014	47961	95067Q	PARTICIPANT	\N	PRESENT	0
49101	49077	08051V	PARTICIPANT	\N	PRESENT	0
49102	49077	11072N	PARTICIPANT	\N	PRESENT	0
49103	49077	07034Q	PARTICIPANT	\N	PRESENT	0
49104	49077	04074L	PARTICIPANT	\N	PRESENT	0
49105	49077	10015M	PARTICIPANT	\N	PRESENT	0
49106	49077	95063L	PARTICIPANT	\N	PRESENT	0
49107	49077	01028R	PARTICIPANT	\N	PRESENT	0
49108	49077	98035U	PARTICIPANT	\N	PRESENT	0
49109	49077	04056J	PARTICIPANT	\N	PRESENT	0
49110	49077	04044E	PARTICIPANT	\N	PRESENT	0
49111	49077	11037K	PARTICIPANT	\N	PRESENT	0
49112	49077	92045V	PARTICIPANT	\N	PRESENT	0
49785	49783	14179A	PARTICIPANT	\N	PRESENT	0
49114	49077	95067Q	PARTICIPANT	\N	PRESENT	0
49115	49077	01047U	PARTICIPANT	\N	PRESENT	0
49786	49783	14159V	PARTICIPANT	\N	PRESENT	0
49787	49783	08017T	PARTICIPANT	\N	PRESENT	0
49788	49783	04057K	PARTICIPANT	\N	PRESENT	0
49789	49783	04070G	PARTICIPANT	\N	PRESENT	0
49936	49933	14041T	PARTICIPANT	\N	PRESENT	0
49937	49933	01024M	PARTICIPANT	\N	PRESENT	0
49938	49933	14215L	PARTICIPANT	\N	PRESENT	0
49939	49933	11034G	PARTICIPANT	\N	PRESENT	0
49157	49077	04079R	PARTICIPANT	\N	PRESENT	0
49940	49933	11010L	PARTICIPANT	\N	EXCUSE	0
49941	49933	01007L	PARTICIPANT	\N	PRESENT	0
49942	49933	11084S	PARTICIPANT	\N	PRESENT	0
49943	49933	14273W	PARTICIPANT	\N	PRESENT	0
49162	47946	08055A	PARTICIPANT	\N	PRESENT	0
49163	47946	14063N	PARTICIPANT	\N	PRESENT	0
49944	49933	07034Q	PARTICIPANT	\N	PRESENT	0
49945	49933	04074L	PARTICIPANT	\N	PRESENT	0
49946	49933	01028R	PARTICIPANT	\N	PRESENT	0
49947	49933	98035U	PARTICIPANT	\N	PRESENT	0
49948	49933	04056J	PARTICIPANT	\N	PRESENT	0
49949	49933	04044E	PARTICIPANT	\N	EXCUSE	0
49950	49933	11037K	PARTICIPANT	\N	PRESENT	0
49951	49933	92045V	PARTICIPANT	\N	PRESENT	0
49952	49933	95067Q	PARTICIPANT	\N	PRESENT	0
49953	49933	01019Q	PARTICIPANT	\N	EXCUSE	0
50213	49855	11098Y	PARTICIPANT	\N	EXCUSE	0
50373	50372	08025T	PARTICIPANT	\N	PRESENT	0
50375	50372	05008E	PRESIDENT	0	PRESENT	0
50377	50372	11033F	PARTICIPANT	\N	PRESENT	0
50378	50372	14065Q	PARTICIPANT	\N	PRESENT	0
50379	50372	14069U	PARTICIPANT	\N	PRESENT	0
33027	33026	11054L	PARTICIPANT	\N	PRESENT	0
39571	38925	08010L	PARTICIPANT	\N	PRESENT	0
39573	38925	04092N	PARTICIPANT	\N	PRESENT	0
39613	38925	10006L	PARTICIPANT	\N	PRESENT	0
39615	38925	14213J	PARTICIPANT	\N	PRESENT	0
39616	38925	95063L	PARTICIPANT	\N	PRESENT	0
39617	38925	01048V	PARTICIPANT	\N	PRESENT	0
39618	38925	11100Y	PARTICIPANT	\N	PRESENT	0
39619	38925	14071N	PARTICIPANT	\N	PRESENT	0
39620	38925	01034P	PARTICIPANT	\N	PRESENT	0
39621	38925	14249W	PARTICIPANT	\N	PRESENT	0
39622	38925	11015D	PARTICIPANT	\N	PRESENT	0
39623	38925	14001X	PARTICIPANT	\N	PRESENT	0
39624	38925	14065Q	PARTICIPANT	\N	PRESENT	0
39625	38925	14229S	PARTICIPANT	\N	PRESENT	0
39626	38925	14059S	PARTICIPANT	\N	PRESENT	0
39627	38925	11071M	PARTICIPANT	\N	PRESENT	0
39628	38925	11036J	PARTICIPANT	\N	PRESENT	0
39629	38925	08068F	PARTICIPANT	\N	PRESENT	0
39630	38925	14034U	PARTICIPANT	\N	PRESENT	0
39636	38925	14109K	PARTICIPANT	\N	PRESENT	0
39637	38925	08055A	PARTICIPANT	\N	PRESENT	0
39638	38925	11066Q	PARTICIPANT	\N	PRESENT	0
39639	38925	11048N	PARTICIPANT	\N	PRESENT	0
39640	38925	04059M	PARTICIPANT	\N	PRESENT	0
39641	38925	08031R	PARTICIPANT	\N	PRESENT	0
39642	38925	11085T	PARTICIPANT	\N	PRESENT	0
39643	38925	95035G	PARTICIPANT	\N	PRESENT	0
39644	38925	04048J	PARTICIPANT	\N	PRESENT	0
39645	38925	08012N	PARTICIPANT	\N	PRESENT	0
39646	38925	08043V	PARTICIPANT	\N	PRESENT	0
39648	38925	14151M	PARTICIPANT	\N	PRESENT	0
39649	38925	08061X	PARTICIPANT	\N	PRESENT	0
39650	38925	11104D	PARTICIPANT	\N	PRESENT	0
39651	38925	80013X	PARTICIPANT	\N	PRESENT	0
39652	38925	08069G	PARTICIPANT	\N	PRESENT	0
39653	38925	14073Q	PARTICIPANT	\N	PRESENT	0
39654	38925	11098Y	PARTICIPANT	\N	PRESENT	0
39655	38925	11010L	PARTICIPANT	\N	PRESENT	0
39656	38925	14179A	PARTICIPANT	\N	PRESENT	0
39657	38925	92018S	PARTICIPANT	\N	PRESENT	0
39658	38925	01019Q	PARTICIPANT	\N	PRESENT	0
39659	38925	08034U	PARTICIPANT	\N	PRESENT	0
39660	38925	14221J	PARTICIPANT	\N	PRESENT	0
39661	38925	08009T	PARTICIPANT	\N	PRESENT	0
39662	38925	14281W	PARTICIPANT	\N	PRESENT	0
39663	38925	11106F	PARTICIPANT	\N	PRESENT	0
39664	38925	01022K	PARTICIPANT	\N	PRESENT	0
39665	38925	08028W	PARTICIPANT	\N	PRESENT	0
39666	38925	01056V	PARTICIPANT	\N	PRESENT	0
39667	38925	04036E	PARTICIPANT	\N	PRESENT	0
39668	38925	08017T	PARTICIPANT	\N	PRESENT	0
39669	38925	11067R	PARTICIPANT	\N	PRESENT	0
39670	38925	05012A	PARTICIPANT	\N	PRESENT	0
39671	38925	08018U	PARTICIPANT	\N	PRESENT	0
39672	38925	01014K	PARTICIPANT	\N	PRESENT	0
39673	38925	04080J	PARTICIPANT	\N	PRESENT	0
39674	38925	07024N	PARTICIPANT	\N	PRESENT	0
39675	38925	04057K	PARTICIPANT	\N	PRESENT	0
39676	38926	01007L	PARTICIPANT	\N	PRESENT	0
39860	38926	95067Q	PARTICIPANT	\N	PRESENT	0
39861	38926	11076S	PARTICIPANT	\N	PRESENT	0
39862	38926	14253S	PARTICIPANT	\N	PRESENT	0
39680	38926	08014Q	PARTICIPANT	\N	PRESENT	0
39681	38926	14257W	PARTICIPANT	\N	PRESENT	0
39876	38926	11039M	PARTICIPANT	\N	PRESENT	0
39683	38926	11042G	PARTICIPANT	\N	PRESENT	0
39863	38926	14211G	PARTICIPANT	\N	PRESENT	0
39864	38926	04071H	PARTICIPANT	\N	PRESENT	0
39686	38926	01057W	PARTICIPANT	\N	PRESENT	0
39687	38926	11035H	PARTICIPANT	\N	PRESENT	0
39865	38926	11040E	PARTICIPANT	\N	PRESENT	0
39866	38926	14069U	PARTICIPANT	\N	PRESENT	0
39690	38926	11065P	PARTICIPANT	\N	PRESENT	0
39867	38926	01013J	PARTICIPANT	\N	PRESENT	0
39692	38926	14159V	PARTICIPANT	\N	PRESENT	0
39868	38926	14263U	PARTICIPANT	\N	PRESENT	0
39874	38926	14251Q	PARTICIPANT	\N	PRESENT	0
39869	38926	04054G	PARTICIPANT	\N	PRESENT	0
39870	38926	04040A	PARTICIPANT	\N	PRESENT	0
39871	38926	04085P	PARTICIPANT	\N	PRESENT	0
39698	38926	04088S	PARTICIPANT	\N	PRESENT	0
39699	38926	07029T	PARTICIPANT	\N	PRESENT	0
39700	38926	88008L	PARTICIPANT	\N	PRESENT	0
39701	38926	14327T	PARTICIPANT	\N	PRESENT	0
39872	38926	14213J	PARTICIPANT	\N	PRESENT	0
39703	38926	01027Q	PARTICIPANT	\N	PRESENT	0
39704	38926	99004R	PARTICIPANT	\N	PRESENT	0
39875	38926	14261S	PARTICIPANT	\N	PRESENT	0
39706	38926	12042Y	PARTICIPANT	\N	PRESENT	0
39877	38926	08069G	PARTICIPANT	\N	PRESENT	0
39878	38926	08019V	PARTICIPANT	\N	PRESENT	0
39873	38926	11080N	PARTICIPANT	\N	PRESENT	0
39879	38926	98018T	PARTICIPANT	\N	PRESENT	0
39880	38926	89017R	PARTICIPANT	\N	PRESENT	0
39881	38926	14207L	PARTICIPANT	\N	PRESENT	0
39882	38926	01008M	PARTICIPANT	\N	PRESENT	0
39883	38926	14033T	PARTICIPANT	\N	PRESENT	0
39715	38926	08011M	PARTICIPANT	\N	PRESENT	0
39884	38926	95037J	PARTICIPANT	\N	PRESENT	0
39717	38926	95062K	PARTICIPANT	\N	PRESENT	0
39885	38926	14269B	PARTICIPANT	\N	PRESENT	0
39886	38926	14179A	PARTICIPANT	\N	PRESENT	0
39887	38926	11071M	PARTICIPANT	\N	PRESENT	0
39888	38926	14073Q	PARTICIPANT	\N	PRESENT	0
39722	38926	08051V	PARTICIPANT	\N	PRESENT	0
39728	38926	11091R	PARTICIPANT	\N	PRESENT	0
39729	38926	08022Q	PARTICIPANT	\N	PRESENT	0
39730	38926	14247U	PARTICIPANT	\N	PRESENT	0
39731	38926	11054L	PARTICIPANT	\N	PRESENT	0
39732	38926	14079W	PARTICIPANT	\N	PRESENT	0
39734	38926	14103D	PARTICIPANT	\N	PRESENT	0
39735	38926	14267Y	PARTICIPANT	\N	PRESENT	0
39736	38926	92015P	PARTICIPANT	\N	PRESENT	0
39738	38926	11023D	PARTICIPANT	\N	PRESENT	0
39740	38926	14193X	PARTICIPANT	\N	PRESENT	0
39744	38926	14157T	PARTICIPANT	\N	PRESENT	0
39745	38926	11074Q	PARTICIPANT	\N	PRESENT	0
39749	38926	95030B	PARTICIPANT	\N	PRESENT	0
39750	38926	14105F	PARTICIPANT	\N	PRESENT	0
39751	38926	01016M	PARTICIPANT	\N	PRESENT	0
39753	38926	14031R	PARTICIPANT	\N	PRESENT	0
39754	38926	14195A	PARTICIPANT	\N	PRESENT	0
39755	38926	08015R	PARTICIPANT	\N	PRESENT	0
39756	38926	05008E	PARTICIPANT	\N	PRESENT	0
39757	38926	14081Q	PARTICIPANT	\N	PRESENT	0
39758	38926	14097Y	PARTICIPANT	\N	PRESENT	0
39760	38926	96004D	PARTICIPANT	\N	PRESENT	0
39762	38926	14187A	PARTICIPANT	\N	PRESENT	0
39764	38926	14121F	PARTICIPANT	\N	PRESENT	0
39765	38926	14219Q	PARTICIPANT	\N	PRESENT	0
39766	38926	08052W	PARTICIPANT	\N	PRESENT	0
39767	38926	14133K	PARTICIPANT	\N	PRESENT	0
39769	38926	04081K	PARTICIPANT	\N	PRESENT	0
39771	38926	08010L	PARTICIPANT	\N	PRESENT	0
39772	38926	04092N	PARTICIPANT	\N	PRESENT	0
39773	38926	10006L	PARTICIPANT	\N	PRESENT	0
39776	38926	01048V	PARTICIPANT	\N	PRESENT	0
39777	38926	11100Y	PARTICIPANT	\N	PRESENT	0
39778	38926	14071N	PARTICIPANT	\N	PRESENT	0
39780	38926	14249W	PARTICIPANT	\N	PRESENT	0
39781	38926	11015D	PARTICIPANT	\N	PRESENT	0
39783	38926	14065Q	PARTICIPANT	\N	PRESENT	0
39784	38926	14229S	PARTICIPANT	\N	PRESENT	0
66854	66803	11089X	PARTICIPANT	\N	EXCUSE	0
66855	66803	11036J	PRESIDENT	1	PRESENT	0
66856	66808	14263U	PARTICIPANT	\N	EXCUSE	0
66857	66808	01044R	PARTICIPANT	\N	EXCUSE	0
66858	66808	14209N	PARTICIPANT	\N	EXCUSE	0
66859	66808	08069G	PARTICIPANT	\N	EXCUSE	0
66860	66808	04061F	PARTICIPANT	\N	EXCUSE	0
66861	66808	08039A	PARTICIPANT	\N	EXCUSE	0
66862	66808	01048V	PARTICIPANT	\N	EXCUSE	0
66863	66808	01016M	PARTICIPANT	\N	EXCUSE	0
66864	66808	11082Q	PARTICIPANT	\N	EXCUSE	0
66867	66808	11089X	PARTICIPANT	\N	PRESENT	0
66868	66808	01058X	PARTICIPANT	\N	PRESENT	0
68418	68417	04049K	PARTICIPANT	\N	PRESENT	0
68334	68332	11036J	PARTICIPANT	\N	PRESENT	0
68419	68417	14151M	PARTICIPANT	\N	PRESENT	0
68336	68332	14013P	PARTICIPANT	\N	PRESENT	0
68337	68332	08068F	PARTICIPANT	\N	PRESENT	0
68460	68417	14261S	PARTICIPANT	\N	PRESENT	0
68339	68332	11101A	PARTICIPANT	\N	PRESENT	0
68340	68332	90003B	PARTICIPANT	\N	PRESENT	0
68341	68332	08028W	PARTICIPANT	\N	PRESENT	0
68342	68332	80013X	PARTICIPANT	\N	PRESENT	0
68343	68332	08038Y	PARTICIPANT	\N	PRESENT	0
68344	68332	04089T	PARTICIPANT	\N	PRESENT	0
68461	68417	14207L	PARTICIPANT	\N	PRESENT	0
68346	68332	11110B	PARTICIPANT	\N	PRESENT	0
68347	68332	14187A	PARTICIPANT	\N	PRESENT	0
68462	68417	14083S	PARTICIPANT	\N	PRESENT	0
68349	68332	14081Q	PARTICIPANT	\N	PRESENT	0
68463	68417	14121F	PARTICIPANT	\N	PRESENT	0
68351	68332	11099A	PARTICIPANT	\N	PRESENT	0
68352	68332	04049K	PARTICIPANT	\N	PRESENT	0
70673	70670	11031D	PARTICIPANT	\N	PRESENT	0
68354	68332	11111C	PARTICIPANT	\N	PRESENT	0
68355	68332	08015R	PARTICIPANT	\N	PRESENT	0
68356	68332	11100Y	PRESIDENT	0	PRESENT	0
68465	68417	14265W	PARTICIPANT	\N	PRESENT	0
68358	68332	11098Y	PARTICIPANT	\N	PRESENT	0
68466	68417	14253S	PARTICIPANT	\N	PRESENT	0
68360	68332	11077T	PARTICIPANT	\N	PRESENT	0
68361	68332	14205J	PARTICIPANT	\N	PRESENT	0
68362	68332	08019V	PARTICIPANT	\N	EXCUSE	0
68363	68332	14257W	PARTICIPANT	\N	PRESENT	0
68467	68417	95030B	PARTICIPANT	\N	PRESENT	0
68365	68332	04088S	PARTICIPANT	\N	PRESENT	0
70671	70670	14030Q	PARTICIPANT	\N	PRESENT	0
68367	68332	11090Q	PARTICIPANT	\N	PRESENT	0
68368	68332	11046L	PARTICIPANT	\N	PRESENT	0
68369	68332	01058X	PARTICIPANT	\N	PRESENT	0
68370	68332	11094U	PARTICIPANT	\N	PRESENT	0
68371	68332	11066Q	PARTICIPANT	\N	PRESENT	0
70672	70670	08043V	PARTICIPANT	\N	PRESENT	0
70674	70670	11027H	PARTICIPANT	\N	PRESENT	0
70675	70670	80013X	PARTICIPANT	\N	PRESENT	0
70676	70670	14041T	PARTICIPANT	\N	PRESENT	0
70677	70670	12042Y	PARTICIPANT	\N	PRESENT	0
70678	70670	14187A	PARTICIPANT	\N	PRESENT	0
70679	70670	14281W	PARTICIPANT	\N	PRESENT	0
70680	70670	04035D	PARTICIPANT	\N	PRESENT	0
70681	70670	11061K	PARTICIPANT	\N	PRESENT	0
70682	70670	07026Q	PARTICIPANT	\N	PRESENT	0
70683	70670	95035G	PARTICIPANT	\N	PRESENT	0
70684	70670	04041B	PARTICIPANT	\N	PRESENT	0
70685	70670	09001P	PRESIDENT	0	PRESENT	0
70687	70670	08031R	PARTICIPANT	\N	PRESENT	0
70688	70670	07029T	PARTICIPANT	\N	PRESENT	0
70689	70670	11067R	PARTICIPANT	\N	PRESENT	0
70691	70670	08060W	PARTICIPANT	\N	EXCUSE	0
70692	70670	14038Y	PARTICIPANT	\N	EXCUSE	0
70693	70670	14031R	PARTICIPANT	\N	EXCUSE	0
70694	70670	04053F	PARTICIPANT	\N	PRESENT	0
70695	70670	04049K	PARTICIPANT	\N	PRESENT	0
70696	70670	14265W	PARTICIPANT	\N	PRESENT	0
70697	70670	04070G	PARTICIPANT	\N	PRESENT	0
70783	70670	14061L	PARTICIPANT	\N	EXCUSE	0
70781	70670	14255U	PARTICIPANT	\N	EXCUSE	0
70782	70670	14034U	PARTICIPANT	\N	EXCUSE	0
70784	70670	01043Q	PARTICIPANT	\N	EXCUSE	0
70785	70670	14253S	PARTICIPANT	\N	EXCUSE	0
71291	71290	96004D	PRESIDENT	0	PRESENT	0
71294	71290	14133K	PARTICIPANT	\N	PRESENT	0
71297	71290	04054G	PARTICIPANT	\N	PRESENT	0
71299	71290	90003B	PARTICIPANT	\N	PRESENT	0
71300	71290	14089Y	PARTICIPANT	\N	PRESENT	0
71301	71290	95030B	PARTICIPANT	\N	PRESENT	0
71302	71290	14026U	PARTICIPANT	\N	PRESENT	0
71303	71290	11026G	PARTICIPANT	\N	PRESENT	0
71304	71290	98046X	PARTICIPANT	\N	PRESENT	0
71305	71290	04045F	PARTICIPANT	\N	PRESENT	0
71306	71290	11012A	PARTICIPANT	\N	PRESENT	0
71307	71290	14097Y	PARTICIPANT	\N	PRESENT	0
71308	71290	14001X	PARTICIPANT	\N	PRESENT	0
71309	71290	01016M	PARTICIPANT	\N	PRESENT	0
71311	71290	11076S	PARTICIPANT	\N	PRESENT	0
71312	71290	04040A	PARTICIPANT	\N	PRESENT	0
71313	71290	08058D	PARTICIPANT	\N	PRESENT	0
71314	71290	11027H	PARTICIPANT	\N	PRESENT	0
71315	71290	98018T	PARTICIPANT	\N	PRESENT	0
71316	71290	92018S	PARTICIPANT	\N	PRESENT	0
71317	71290	92020L	PARTICIPANT	\N	PRESENT	0
71318	71290	11096W	PARTICIPANT	\N	PRESENT	0
71319	71290	97011G	PARTICIPANT	\N	PRESENT	0
71320	71290	08065C	PARTICIPANT	\N	PRESENT	0
71321	71290	07024N	PARTICIPANT	\N	PRESENT	0
71322	71290	04095R	PARTICIPANT	\N	PRESENT	0
71323	71290	14014Q	PARTICIPANT	\N	PRESENT	0
71324	71290	11064N	PARTICIPANT	\N	PRESENT	0
71325	71290	04078Q	PARTICIPANT	\N	PRESENT	0
71326	71290	11106F	PARTICIPANT	\N	PRESENT	0
71327	71290	08049C	PARTICIPANT	\N	PRESENT	0
71328	71290	11054L	PARTICIPANT	\N	PRESENT	0
71329	71290	01014K	PARTICIPANT	\N	PRESENT	0
71330	71290	86044G	PARTICIPANT	\N	PRESENT	0
71332	71290	01008M	PARTICIPANT	\N	PRESENT	0
71334	71290	11036J	PARTICIPANT	\N	PRESENT	0
71335	71290	14013P	PARTICIPANT	\N	PRESENT	0
71336	71290	08068F	PARTICIPANT	\N	PRESENT	0
71337	71290	14207L	PARTICIPANT	\N	PRESENT	0
71338	71290	08028W	PARTICIPANT	\N	PRESENT	0
71339	71290	80013X	PARTICIPANT	\N	PRESENT	0
71340	71290	08038Y	PARTICIPANT	\N	PRESENT	0
71341	71290	14197C	PARTICIPANT	\N	PRESENT	0
71342	71290	14187A	PARTICIPANT	\N	PRESENT	0
71344	71290	14033T	PARTICIPANT	\N	PRESENT	0
71345	71290	04048J	PARTICIPANT	\N	PRESENT	0
71346	71290	11099A	PARTICIPANT	\N	PRESENT	0
71347	71290	04049K	PARTICIPANT	\N	PRESENT	0
71348	71290	04094Q	PARTICIPANT	\N	PRESENT	0
71349	71290	11111C	PARTICIPANT	\N	PRESENT	0
71351	71290	08015R	PARTICIPANT	\N	PRESENT	0
71353	71290	11100Y	PARTICIPANT	\N	PRESENT	0
71355	71290	11098Y	PARTICIPANT	\N	PRESENT	0
71357	71290	01061S	PARTICIPANT	\N	PRESENT	0
71359	71290	11077T	PARTICIPANT	\N	PRESENT	0
71362	71290	14205J	PARTICIPANT	\N	PRESENT	0
71363	71290	14257W	PARTICIPANT	\N	PRESENT	0
71365	71290	11090Q	PARTICIPANT	\N	PRESENT	0
71367	71290	11046L	PARTICIPANT	\N	PRESENT	0
71368	71290	11094U	PARTICIPANT	\N	PRESENT	0
71369	71290	11066Q	PARTICIPANT	\N	PRESENT	0
72050	72049	95059Q	PRESIDENT	0	PRESENT	0
72051	72049	98018T	PARTICIPANT	\N	PRESENT	0
72052	72049	92020L	PARTICIPANT	\N	PRESENT	0
72053	72049	92018S	PARTICIPANT	\N	PRESENT	0
72054	72049	01014K	PARTICIPANT	\N	PRESENT	0
72055	72049	11015D	PARTICIPANT	\N	PRESENT	0
72056	72049	04080J	PARTICIPANT	\N	PRESENT	0
72057	72049	98021N	PARTICIPANT	\N	PRESENT	0
72059	72058	95059Q	PARTICIPANT	\N	PRESENT	0
72060	72058	98018T	PARTICIPANT	\N	PRESENT	0
72061	72058	92020L	PARTICIPANT	\N	PRESENT	0
72062	72058	92018S	PARTICIPANT	\N	PRESENT	0
72063	72058	01014K	PARTICIPANT	\N	PRESENT	0
72064	72058	11015D	PARTICIPANT	\N	PRESENT	0
72065	72058	04080J	PARTICIPANT	\N	PRESENT	0
72066	72058	98021N	PARTICIPANT	\N	PRESENT	0
72067	72058	11076S	PARTICIPANT	\N	PRESENT	0
72068	72058	04042C	PARTICIPANT	\N	PRESENT	0
75488	75487	89017R	PARTICIPANT	\N	PRESENT	0
72070	72058	01048V	PARTICIPANT	\N	PRESENT	0
72072	72071	07024N	PARTICIPANT	\N	PRESENT	0
75491	75490	89017R	PARTICIPANT	\N	PRESENT	0
75515	75511	04086Q	PARTICIPANT	\N	PRESENT	0
75533	75528	89017R	PARTICIPANT	\N	PRESENT	0
75582	75579	89017R	PARTICIPANT	\N	PRESENT	0
75616	75597	04086Q	PARTICIPANT	\N	PRESENT	0
75653	75647	01016M	PARTICIPANT	\N	PRESENT	0
75677	75670	89017R	PARTICIPANT	\N	PRESENT	0
82806	82770	80027E	PARTICIPANT	\N	PRESENT	0
82807	82770	14031R	PARTICIPANT	\N	PRESENT	0
82808	82770	08009T	PRESIDENT	0	PRESENT	0
82809	82770	08062Y	PARTICIPANT	\N	PRESENT	0
82810	82770	14221J	PARTICIPANT	\N	PRESENT	0
82811	82770	92039X	PARTICIPANT	\N	EXCUSE	0
82812	82770	08042U	PARTICIPANT	\N	PRESENT	0
82813	82770	14169X	PARTICIPANT	\N	PRESENT	0
82814	82770	14237S	PARTICIPANT	\N	PRESENT	0
82815	82770	13002U	PARTICIPANT	\N	PRESENT	0
82816	82770	05012A	PARTICIPANT	\N	PRESENT	0
82935	82932	08043V	PARTICIPANT	\N	PRESENT	0
82818	82770	14135M	PARTICIPANT	\N	PRESENT	0
82819	82770	14331P	PARTICIPANT	\N	PRESENT	0
82820	82770	95062K	PARTICIPANT	\N	PRESENT	0
82821	82770	14107H	PARTICIPANT	\N	PRESENT	0
82822	82770	14051J	PARTICIPANT	\N	PRESENT	0
82823	82770	14157T	PARTICIPANT	\N	PRESENT	0
82824	82770	96003C	PARTICIPANT	\N	EXCUSE	0
82934	82932	11109J	PARTICIPANT	\N	PRESENT	0
82936	82932	08038Y	PARTICIPANT	\N	PRESENT	0
82937	82932	14281W	PARTICIPANT	\N	PRESENT	0
82938	82932	11072N	PARTICIPANT	\N	PRESENT	0
82939	82932	14071N	PARTICIPANT	\N	PRESENT	0
82940	82932	11094U	PARTICIPANT	\N	PRESENT	0
82941	82932	14227Q	PARTICIPANT	\N	PRESENT	0
82949	82948	14331P	PARTICIPANT	\N	PRESENT	0
83288	83287	04077P	PARTICIPANT	\N	PRESENT	0
83289	83287	95067Q	PARTICIPANT	\N	PRESENT	0
83290	83287	11061K	PARTICIPANT	\N	PRESENT	0
83292	83291	07004J	PARTICIPANT	\N	PRESENT	0
83293	83291	10015M	PARTICIPANT	\N	PRESENT	0
83295	83294	04038G	PARTICIPANT	\N	PRESENT	0
83296	83294	11066Q	PARTICIPANT	\N	PRESENT	0
83298	83297	07004J	PARTICIPANT	\N	PRESENT	0
83300	77780	14030Q	PARTICIPANT	\N	PRESENT	0
83301	77781	14030Q	PARTICIPANT	\N	PRESENT	0
83302	83299	04038G	PARTICIPANT	\N	PRESENT	0
83304	83303	14030Q	PARTICIPANT	\N	PRESENT	0
83305	83299	99004R	PRESIDENT	0	PRESENT	0
83306	83299	01059Y	PARTICIPANT	\N	PRESENT	0
83307	83299	14121F	PARTICIPANT	\N	PRESENT	0
83308	83299	14257W	PARTICIPANT	\N	PRESENT	0
83309	83299	11046L	PARTICIPANT	\N	PRESENT	0
83310	83299	01028R	PARTICIPANT	\N	PRESENT	0
83311	83299	11066Q	PARTICIPANT	\N	PRESENT	0
83312	83299	01008M	PARTICIPANT	\N	EXCUSE	0
83313	83299	14089Y	PARTICIPANT	\N	EXCUSE	0
83314	83299	08060W	PARTICIPANT	\N	EXCUSE	0
83315	83299	11029K	PARTICIPANT	\N	EXCUSE	0
83316	83299	11080N	PARTICIPANT	\N	EXCUSE	0
83317	83299	08028W	PARTICIPANT	\N	EXCUSE	0
83318	83299	88008L	PARTICIPANT	\N	EXCUSE	0
83319	83299	11088W	PARTICIPANT	\N	EXCUSE	0
83320	83299	98018T	PARTICIPANT	\N	EXCUSE	0
83321	83299	01015L	PARTICIPANT	\N	EXCUSE	0
83322	83299	01041N	PARTICIPANT	\N	EXCUSE	0
83323	83299	14187A	PARTICIPANT	\N	EXCUSE	0
83324	83299	02002K	PARTICIPANT	\N	EXCUSE	0
83325	83299	08048B	PARTICIPANT	\N	EXCUSE	0
83326	83299	11089X	PARTICIPANT	\N	EXCUSE	0
83327	83299	14026U	PARTICIPANT	\N	EXCUSE	0
83328	83299	11084S	PARTICIPANT	\N	EXCUSE	0
83329	83299	04061F	PARTICIPANT	\N	EXCUSE	0
83330	83299	01061S	PARTICIPANT	\N	EXCUSE	0
83331	83299	08012N	PARTICIPANT	\N	EXCUSE	0
83332	83299	14103D	PARTICIPANT	\N	EXCUSE	0
83333	83299	08062Y	PARTICIPANT	\N	EXCUSE	0
83334	83299	08021P	PARTICIPANT	\N	EXCUSE	0
83335	83299	14229S	PARTICIPANT	\N	EXCUSE	0
83336	83299	14107H	PARTICIPANT	\N	EXCUSE	0
83337	83299	11094U	PARTICIPANT	\N	EXCUSE	0
83338	83299	92045V	PARTICIPANT	\N	EXCUSE	0
83352	83351	14133K	PARTICIPANT	\N	EXCUSE	0
83353	83351	11035H	PARTICIPANT	\N	EXCUSE	0
83354	83351	96004D	PRESIDENT	0	PRESENT	0
83355	83351	11040E	PARTICIPANT	\N	PRESENT	0
83356	83351	11083R	PARTICIPANT	\N	PRESENT	0
83357	83351	14097Y	PARTICIPANT	\N	PRESENT	0
83358	83351	04061F	PARTICIPANT	\N	PRESENT	0
83359	83351	98046X	PARTICIPANT	\N	PRESENT	0
83360	83351	14001X	PARTICIPANT	\N	PRESENT	0
83361	83351	04057K	PARTICIPANT	\N	PRESENT	0
83362	83351	04080J	PARTICIPANT	\N	PRESENT	0
83363	83351	14135M	PARTICIPANT	\N	PRESENT	0
83364	83351	01016M	PARTICIPANT	\N	PRESENT	0
83365	83351	10015M	PARTICIPANT	\N	PRESENT	0
83366	83351	04045F	PARTICIPANT	\N	PRESENT	0
83367	83351	01031L	PARTICIPANT	\N	PRESENT	0
83368	83351	07029T	PARTICIPANT	\N	PRESENT	0
83369	83351	04086Q	PARTICIPANT	\N	PRESENT	0
83370	83351	08034U	PARTICIPANT	\N	PRESENT	0
83371	83351	01048V	PARTICIPANT	\N	PRESENT	0
83372	83351	11042G	PARTICIPANT	\N	PRESENT	0
83373	83351	14083S	PARTICIPANT	\N	PRESENT	0
83453	83374	08011M	PARTICIPANT	\N	EXCUSE	0
83523	83521	08015R	PARTICIPANT	\N	PRESENT	0
83524	83521	01008M	PARTICIPANT	\N	PRESENT	0
83525	83521	11094U	PARTICIPANT	\N	PRESENT	0
83526	83521	04089T	PARTICIPANT	\N	PRESENT	0
83527	83521	14207L	PARTICIPANT	\N	PRESENT	0
83528	83521	14257W	PARTICIPANT	\N	PRESENT	0
83543	83542	98046X	PARTICIPANT	\N	PRESENT	0
83545	83544	98046X	PARTICIPANT	\N	PRESENT	0
83547	83546	14327T	PARTICIPANT	\N	PRESENT	0
83549	83548	98046X	PARTICIPANT	\N	PRESENT	0
83551	83550	01013J	PARTICIPANT	\N	PRESENT	0
83553	83552	01013J	PARTICIPANT	\N	PRESENT	0
83554	83297	10015M	PARTICIPANT	\N	PRESENT	0
83555	83291	14269B	PARTICIPANT	\N	PRESENT	0
83620	83618	11083R	PARTICIPANT	\N	PRESENT	0
83621	83618	11074Q	PARTICIPANT	\N	PRESENT	0
83628	83626	11083R	PARTICIPANT	\N	PRESENT	0
83630	83626	11074Q	PARTICIPANT	\N	PRESENT	0
83633	83632	11074Q	PARTICIPANT	\N	PRESENT	0
83634	83632	11083R	PARTICIPANT	\N	PRESENT	0
83640	83639	04086Q	PARTICIPANT	\N	PRESENT	0
83642	83641	08011M	PARTICIPANT	\N	PRESENT	0
83766	83765	01031L	PARTICIPANT	\N	PRESENT	0
83780	83779	14175V	PARTICIPANT	\N	PRESENT	0
83781	83779	14085U	PARTICIPANT	\N	PRESENT	0
83782	83779	11042G	PARTICIPANT	\N	PRESENT	0
83783	83779	04086Q	PARTICIPANT	\N	PRESENT	0
83785	83779	14159V	PARTICIPANT	\N	PRESENT	0
83789	83779	08011M	PARTICIPANT	\N	PRESENT	0
83794	83793	01031L	PARTICIPANT	\N	PRESENT	0
83795	83793	14159V	PARTICIPANT	\N	PRESENT	0
83799	83798	04086Q	PARTICIPANT	\N	PRESENT	0
83800	83798	11083R	PARTICIPANT	\N	PRESENT	0
83801	83798	11042G	PARTICIPANT	\N	PRESENT	0
83802	83798	14159V	PARTICIPANT	\N	PRESENT	0
83855	83854	14087W	PARTICIPANT	\N	PRESENT	0
83877	83874	14037X	PARTICIPANT	\N	PRESENT	0
83880	83874	14034U	PARTICIPANT	\N	PRESENT	0
83881	83874	14087W	PARTICIPANT	\N	PRESENT	0
84210	84209	05008E	PRESIDENT	0	PRESENT	0
84122	84092	14179A	PARTICIPANT	\N	PRESENT	0
84211	84209	14259Y	PARTICIPANT	\N	PRESENT	0
84212	84209	11035H	PARTICIPANT	\N	PRESENT	0
84125	84092	14061L	PARTICIPANT	\N	PRESENT	0
84126	84092	14073Q	PARTICIPANT	\N	PRESENT	0
84213	84209	14041T	PARTICIPANT	\N	PRESENT	0
84214	84209	14215L	PARTICIPANT	\N	PRESENT	0
84129	84092	08039A	PARTICIPANT	\N	PRESENT	0
84130	84092	08017T	PARTICIPANT	\N	PRESENT	0
84215	84209	08018U	PARTICIPANT	\N	PRESENT	0
84132	84092	08012N	PARTICIPANT	\N	EXCUSE	0
84216	84209	11026G	PARTICIPANT	\N	PRESENT	0
84217	84209	14111D	PARTICIPANT	\N	PRESENT	0
84218	84209	11072N	PARTICIPANT	\N	PRESENT	0
84136	84092	04057K	PARTICIPANT	\N	PRESENT	0
84137	84092	11014C	PARTICIPANT	\N	PRESENT	0
84219	84209	07034Q	PARTICIPANT	\N	PRESENT	0
84139	84092	04070G	PRESIDENT	0	PRESENT	0
84220	84209	95063L	PARTICIPANT	\N	PRESENT	0
84221	84209	01028R	PARTICIPANT	\N	PRESENT	0
84142	84092	83047W	PARTICIPANT	\N	PRESENT	0
84143	84092	14235Q	PARTICIPANT	\N	PRESENT	0
84222	84209	98035U	PARTICIPANT	\N	PRESENT	0
84223	84209	14275Y	PARTICIPANT	\N	PRESENT	0
84146	84092	14229S	PARTICIPANT	\N	PRESENT	0
84147	84092	11043H	PARTICIPANT	\N	PRESENT	0
84224	84209	04044E	PRESIDENT	1	PRESENT	0
84225	84209	11037K	PARTICIPANT	\N	PRESENT	0
84150	84092	14263U	PARTICIPANT	\N	PRESENT	0
84226	84209	92045V	PARTICIPANT	\N	EXCUSE	0
84227	84209	95067Q	PARTICIPANT	\N	PRESENT	0
84230	84229	01008M	PARTICIPANT	\N	PRESENT	0
84231	84229	11036J	PARTICIPANT	\N	PRESENT	0
69232	69231	89017R	PARTICIPANT	\N	PRESENT	0
69233	69231	01031L	PRESIDENT	0	PRESENT	0
69234	69231	01013J	PARTICIPANT	\N	PRESENT	0
69235	69231	11040E	PARTICIPANT	\N	PRESENT	0
69236	69231	08014Q	PARTICIPANT	\N	PRESENT	0
69237	69231	14167V	PARTICIPANT	\N	PRESENT	0
69238	69231	14175V	PARTICIPANT	\N	EXCUSE	0
69239	69231	14083S	PARTICIPANT	\N	PRESENT	0
69240	69231	14085U	PARTICIPANT	\N	PRESENT	0
69241	69231	11042G	PARTICIPANT	\N	PRESENT	0
69242	69231	88008L	PARTICIPANT	\N	PRESENT	0
69243	69231	04086Q	PARTICIPANT	\N	PRESENT	0
69244	69231	11070L	PARTICIPANT	\N	PRESENT	0
69245	69231	11088W	PARTICIPANT	\N	PRESENT	0
69246	69231	14327T	PARTICIPANT	\N	PRESENT	0
69247	69231	01027Q	PARTICIPANT	\N	PRESENT	0
69248	69231	04071H	PARTICIPANT	\N	PRESENT	0
69249	69231	11074Q	PARTICIPANT	\N	PRESENT	0
69250	69231	11083R	PARTICIPANT	\N	PRESENT	0
69251	69231	14199E	PARTICIPANT	\N	PRESENT	0
69252	69231	01057W	PARTICIPANT	\N	PRESENT	0
69253	69231	08069G	PARTICIPANT	\N	PRESENT	0
69254	69231	11048N	PARTICIPANT	\N	PRESENT	0
69255	69231	99004R	PARTICIPANT	\N	PRESENT	0
69256	69231	14159V	PARTICIPANT	\N	PRESENT	0
69257	69231	07029T	PARTICIPANT	\N	PRESENT	0
69258	69231	08010L	PARTICIPANT	\N	PRESENT	0
69259	69231	08034U	PARTICIPANT	\N	PRESENT	0
69260	69231	98046X	PARTICIPANT	\N	PRESENT	0
69261	69231	01048V	PARTICIPANT	\N	PRESENT	0
69262	69231	08011M	PARTICIPANT	\N	EXCUSE	0
69263	69231	08073C	PARTICIPANT	\N	PRESENT	0
69264	69231	01016M	PARTICIPANT	\N	PRESENT	0
69265	69231	08061X	PARTICIPANT	\N	PRESENT	0
69266	69231	14225N	PARTICIPANT	\N	PRESENT	0
69267	69231	11057P	PARTICIPANT	\N	PRESENT	0
69268	69231	14173T	PARTICIPANT	\N	PRESENT	0
69313	69312	14133K	PARTICIPANT	\N	PRESENT	0
69314	69312	04054G	PARTICIPANT	\N	PRESENT	0
69315	69312	96004D	PRESIDENT	0	PRESENT	0
69316	69312	11040E	PARTICIPANT	\N	PRESENT	0
69317	69312	14089Y	PARTICIPANT	\N	PRESENT	0
69318	69312	14249W	PARTICIPANT	\N	PRESENT	0
69319	69312	04035D	PARTICIPANT	\N	PRESENT	0
69320	69312	11083R	PARTICIPANT	\N	PRESENT	0
69321	69312	14097Y	PARTICIPANT	\N	PRESENT	0
69322	69312	14073Q	PARTICIPANT	\N	PRESENT	0
69323	69312	11026G	PARTICIPANT	\N	PRESENT	0
69324	69312	98046X	PARTICIPANT	\N	PRESENT	0
69325	69312	04057K	PARTICIPANT	\N	PRESENT	0
69326	69312	08042U	PARTICIPANT	\N	EXCUSE	0
69327	69312	04080J	PARTICIPANT	\N	PRESENT	0
69328	69312	01016M	PARTICIPANT	\N	PRESENT	0
69329	69312	10015M	PARTICIPANT	\N	PRESENT	0
69330	69312	95063L	PARTICIPANT	\N	PRESENT	0
69331	69312	04045F	PARTICIPANT	\N	PRESENT	0
69332	69312	98035U	PARTICIPANT	\N	PRESENT	0
69333	69312	11035H	PARTICIPANT	\N	PRESENT	0
69334	69312	14135M	PARTICIPANT	\N	PRESENT	0
69335	69312	11012A	PARTICIPANT	\N	PRESENT	0
69336	69312	14026U	PARTICIPANT	\N	EXCUSE	0
69337	69312	90003B	PARTICIPANT	\N	EXCUSE	0
69361	69231	11068S	PARTICIPANT	\N	PRESENT	0
69362	69231	11053K	PARTICIPANT	\N	PRESENT	0
69363	69231	08022Q	PARTICIPANT	\N	PRESENT	0
69364	69231	04061F	PARTICIPANT	\N	PRESENT	0
69365	69231	11012A	PARTICIPANT	\N	PRESENT	0
72096	56945	04045F	PARTICIPANT	\N	EXCUSE	0
72099	56945	04040A	PRESIDENT	0	PRESENT	0
75701	75697	89017R	PARTICIPANT	\N	PRESENT	0
75713	75710	89017R	PARTICIPANT	\N	PRESENT	0
75726	75724	89017R	PARTICIPANT	\N	PRESENT	0
75737	75733	89017R	PARTICIPANT	\N	PRESENT	0
75764	75763	04044E	PARTICIPANT	\N	PRESENT	0
76428	76427	04086Q	PARTICIPANT	\N	PRESENT	0
76430	76429	04086Q	PARTICIPANT	\N	PRESENT	0
76709	76706	01046T	PARTICIPANT	\N	PRESENT	0
76710	76706	04053F	PARTICIPANT	\N	PRESENT	0
76711	76706	14255U	PARTICIPANT	\N	PRESENT	0
76713	76706	00003C	PARTICIPANT	\N	PRESENT	0
76714	76706	14053L	PARTICIPANT	\N	PRESENT	0
76715	76706	11103C	PARTICIPANT	\N	PRESENT	0
76717	76706	14195A	PARTICIPANT	\N	PRESENT	0
76718	76706	14267Y	PARTICIPANT	\N	PRESENT	0
76721	76706	08052W	PARTICIPANT	\N	PRESENT	0
76723	76706	04081K	PARTICIPANT	\N	EXCUSE	0
76724	76706	98024R	PARTICIPANT	\N	PRESENT	0
76725	76706	10006L	PARTICIPANT	\N	PRESENT	0
76726	76706	04067M	PARTICIPANT	\N	PRESENT	0
76727	76706	14217N	PARTICIPANT	\N	PRESENT	0
76728	76706	14042U	PARTICIPANT	\N	PRESENT	0
76729	76706	14151M	PARTICIPANT	\N	PRESENT	0
76730	76706	12042Y	PARTICIPANT	\N	PRESENT	0
76731	76706	14281W	PARTICIPANT	\N	PRESENT	0
76732	76706	14087W	PARTICIPANT	\N	PRESENT	0
76734	76706	14034U	PARTICIPANT	\N	PRESENT	0
76735	76706	14231L	PARTICIPANT	\N	PRESENT	0
76736	76706	11061K	PARTICIPANT	\N	EXCUSE	0
76738	76706	08041T	PARTICIPANT	\N	PRESENT	0
76739	76706	01011G	PARTICIPANT	\N	PRESENT	0
76740	76706	14026U	PARTICIPANT	\N	PRESENT	0
76741	76706	14213J	PARTICIPANT	\N	PRESENT	0
76743	76706	11112D	PARTICIPANT	\N	PRESENT	0
76744	76706	14037X	PARTICIPANT	\N	PRESENT	0
76746	76706	11067R	PARTICIPANT	\N	PRESENT	0
76747	76706	14223L	PARTICIPANT	\N	PRESENT	0
76748	76706	04092N	PRESIDENT	0	PRESENT	0
76749	76706	14265W	PARTICIPANT	\N	PRESENT	0
76750	76706	14119M	PARTICIPANT	\N	PRESENT	0
76751	76706	14071N	PARTICIPANT	\N	PRESENT	0
76752	76706	07032N	PARTICIPANT	\N	PRESENT	0
76754	76706	14271U	PARTICIPANT	\N	PRESENT	0
76755	76706	14017T	PARTICIPANT	\N	PRESENT	0
76756	76706	11093T	PARTICIPANT	\N	PRESENT	0
76757	76706	11097X	PARTICIPANT	\N	PRESENT	0
76758	76706	04045F	PARTICIPANT	\N	PRESENT	0
76759	76706	14227Q	PARTICIPANT	\N	PRESENT	0
76760	76706	01034P	PARTICIPANT	\N	PRESENT	0
87582	87187	14030Q	PARTICIPANT	\N	PRESENT	0
87583	87187	09001P	PARTICIPANT	\N	PRESENT	0
87584	87187	01019Q	PARTICIPANT	\N	PRESENT	0
87585	87187	11043H	PARTICIPANT	\N	PRESENT	0
87586	87187	95031C	PARTICIPANT	\N	PRESENT	0
87587	87187	14133K	PARTICIPANT	\N	PRESENT	0
87588	87187	95041E	PARTICIPANT	\N	PRESENT	0
87589	87187	14213J	PARTICIPANT	\N	PRESENT	0
87590	87187	11107G	PARTICIPANT	\N	PRESENT	0
87591	87187	08025T	PARTICIPANT	\N	PRESENT	0
87592	87187	14107H	PARTICIPANT	\N	PRESENT	0
87593	87187	00003C	PARTICIPANT	\N	PRESENT	0
87594	87187	98050T	PARTICIPANT	\N	PRESENT	0
87595	87187	08052W	PARTICIPANT	\N	PRESENT	0
87596	87187	08048B	PARTICIPANT	\N	PRESENT	0
87597	87187	11029K	PARTICIPANT	\N	PRESENT	0
87598	87187	11080N	PARTICIPANT	\N	PRESENT	0
87599	87187	14039A	PARTICIPANT	\N	PRESENT	0
87600	87187	14261S	PARTICIPANT	\N	PRESENT	0
87601	87187	14111D	PARTICIPANT	\N	PRESENT	0
87602	87187	11093T	PARTICIPANT	\N	PRESENT	0
87603	87187	14217N	PARTICIPANT	\N	PRESENT	0
87604	87187	14033T	PARTICIPANT	\N	PRESENT	0
87605	87187	14231L	PARTICIPANT	\N	PRESENT	0
87606	87187	11082Q	PARTICIPANT	\N	PRESENT	0
87607	87187	04089T	PARTICIPANT	\N	PRESENT	0
87608	87187	11103C	PARTICIPANT	\N	PRESENT	0
87609	87187	95030B	PARTICIPANT	\N	PRESENT	0
87610	87187	01022K	PARTICIPANT	\N	PRESENT	0
87611	87187	07026Q	PARTICIPANT	\N	PRESENT	0
87612	87187	14263U	PARTICIPANT	\N	PRESENT	0
87613	87187	92031P	PARTICIPANT	\N	PRESENT	0
87614	87187	14051J	PARTICIPANT	\N	PRESENT	0
87615	87187	89029V	PARTICIPANT	\N	PRESENT	0
87616	87187	11039M	PARTICIPANT	\N	PRESENT	0
87617	87187	98046X	PARTICIPANT	\N	PRESENT	0
87618	87187	14055N	PARTICIPANT	\N	PRESENT	0
87619	87187	14071N	PARTICIPANT	\N	PRESENT	0
87620	87187	11072N	PARTICIPANT	\N	PRESENT	0
87621	87187	11109J	PARTICIPANT	\N	PRESENT	0
87622	87187	14059S	PARTICIPANT	\N	PRESENT	0
87623	87187	11081P	PARTICIPANT	\N	PRESENT	0
87624	87187	08068F	PARTICIPANT	\N	PRESENT	0
87625	87187	14169X	PARTICIPANT	\N	PRESENT	0
87626	87187	08015R	PARTICIPANT	\N	PRESENT	0
87627	87187	04038G	PARTICIPANT	\N	PRESENT	0
87628	87187	88008L	PARTICIPANT	\N	PRESENT	0
87629	87187	08061X	PARTICIPANT	\N	PRESENT	0
87630	87187	04043D	PARTICIPANT	\N	PRESENT	0
87631	87187	11046L	PARTICIPANT	\N	PRESENT	0
87632	87187	04097T	PARTICIPANT	\N	PRESENT	0
87633	87187	98022P	PARTICIPANT	\N	PRESENT	0
87634	87187	01060R	PARTICIPANT	\N	PRESENT	0
87635	87187	14273W	PARTICIPANT	\N	PRESENT	0
87636	87187	11061K	PARTICIPANT	\N	PRESENT	0
87637	87187	95063L	PARTICIPANT	\N	PRESENT	0
87638	87187	11011M	PARTICIPANT	\N	PRESENT	0
87639	87187	96004D	PARTICIPANT	\N	PRESENT	0
87640	87187	14221J	PARTICIPANT	\N	PRESENT	0
87641	87187	11094U	PARTICIPANT	\N	PRESENT	0
87642	87187	04070G	PARTICIPANT	\N	PRESENT	0
87643	87187	14063N	PARTICIPANT	\N	PRESENT	0
87644	87187	10006L	PARTICIPANT	\N	PRESENT	0
87645	87187	95067Q	PARTICIPANT	\N	PRESENT	0
87646	87187	14265W	PARTICIPANT	\N	PRESENT	0
87647	87187	11100Y	PARTICIPANT	\N	PRESENT	0
87648	87187	92044U	PARTICIPANT	\N	PRESENT	0
87649	87187	95015C	PARTICIPANT	\N	PRESENT	0
87650	87187	07024N	PARTICIPANT	\N	PRESENT	0
87651	87187	98018T	PARTICIPANT	\N	PRESENT	0
87652	87187	01048V	PARTICIPANT	\N	PRESENT	0
87653	87187	04085P	PARTICIPANT	\N	PRESENT	0
87654	87187	01061S	PARTICIPANT	\N	PRESENT	0
87655	87187	92018S	PARTICIPANT	\N	PRESENT	0
87656	87187	92040Q	PARTICIPANT	\N	PRESENT	0
87657	87187	14013P	PARTICIPANT	\N	PRESENT	0
87658	87187	11056N	PARTICIPANT	\N	PRESENT	0
87659	87187	11098Y	PARTICIPANT	\N	PRESENT	0
87660	87187	11040E	PARTICIPANT	\N	PRESENT	0
87661	87187	14038Y	PARTICIPANT	\N	PRESENT	0
87662	87187	01059Y	PARTICIPANT	\N	PRESENT	0
87663	87187	11031D	PARTICIPANT	\N	PRESENT	0
87664	87187	04081K	PARTICIPANT	\N	PRESENT	0
87665	87187	01015L	PARTICIPANT	\N	PRESENT	0
87666	87187	11063M	PARTICIPANT	\N	PRESENT	0
87667	87187	98024R	PARTICIPANT	\N	PRESENT	0
87668	87187	07032N	PARTICIPANT	\N	PRESENT	0
87669	87187	08016S	PARTICIPANT	\N	PRESENT	0
87670	87187	92045V	PARTICIPANT	\N	PRESENT	0
87671	87187	98035U	PARTICIPANT	\N	PRESENT	0
87672	87187	92015P	PARTICIPANT	\N	PRESENT	0
87673	87187	95062K	PARTICIPANT	\N	PRESENT	0
87674	87187	04033B	PARTICIPANT	\N	PRESENT	0
87675	87187	14211G	PARTICIPANT	\N	PRESENT	0
87676	87187	08055A	PARTICIPANT	\N	PRESENT	0
87677	87187	01031L	PARTICIPANT	\N	PRESENT	0
87678	87187	08062Y	PARTICIPANT	\N	PRESENT	0
87679	87187	11027H	PARTICIPANT	\N	PRESENT	0
87680	87187	04041B	PARTICIPANT	\N	PRESENT	0
87681	87187	14028W	PARTICIPANT	\N	PRESENT	0
87682	87187	01011G	PARTICIPANT	\N	PRESENT	0
87683	87187	14253S	PARTICIPANT	\N	PRESENT	0
87684	87187	11089X	PARTICIPANT	\N	PRESENT	0
87685	87187	11036J	PARTICIPANT	\N	PRESENT	0
87686	87187	86044G	PARTICIPANT	\N	PRESENT	0
87687	87187	83047W	PARTICIPANT	\N	PRESENT	0
87688	87187	11059R	PARTICIPANT	\N	PRESENT	0
87689	87187	08053X	PARTICIPANT	\N	PRESENT	0
87690	87187	08012N	PARTICIPANT	\N	PRESENT	0
87691	87187	14187A	PARTICIPANT	\N	PRESENT	0
87692	87187	83042R	PARTICIPANT	\N	PRESENT	0
87693	87187	08041T	PARTICIPANT	\N	PRESENT	0
87694	87187	14175V	PARTICIPANT	\N	PRESENT	0
87695	87187	01058X	PARTICIPANT	\N	PRESENT	0
87696	87187	14109K	PARTICIPANT	\N	PRESENT	0
87697	87187	11014C	PARTICIPANT	\N	PRESENT	0
87698	87187	11095V	PARTICIPANT	\N	PRESENT	0
87699	87187	11030C	PARTICIPANT	\N	PRESENT	0
87700	87187	08014Q	PARTICIPANT	\N	PRESENT	0
87701	87187	11054L	PARTICIPANT	\N	PRESENT	0
87702	87187	08018U	PARTICIPANT	\N	PRESENT	0
87703	87187	14281W	PARTICIPANT	\N	PRESENT	0
87704	87187	04044E	PARTICIPANT	\N	PRESENT	0
87705	87187	14167V	PARTICIPANT	\N	PRESENT	0
87706	87187	14229S	PARTICIPANT	\N	PRESENT	0
87707	87187	14017T	PARTICIPANT	\N	PRESENT	0
87708	87187	14121F	PARTICIPANT	\N	PRESENT	0
87709	87187	14097Y	PARTICIPANT	\N	PRESENT	0
87710	87187	11077T	PARTICIPANT	\N	PRESENT	0
87711	87187	04056J	PARTICIPANT	\N	PRESENT	0
87712	87187	14037X	PARTICIPANT	\N	PRESENT	0
87713	87187	11057P	PARTICIPANT	\N	PRESENT	0
87714	87187	14147R	PARTICIPANT	\N	PRESENT	0
87715	87187	08024S	PARTICIPANT	\N	PRESENT	0
87716	87187	92020L	PARTICIPANT	\N	PRESENT	0
87717	87187	14151M	PARTICIPANT	\N	PRESENT	0
87718	87187	14193X	PARTICIPANT	\N	PRESENT	0
87719	87187	11084S	PARTICIPANT	\N	PRESENT	0
87720	87187	80027E	PARTICIPANT	\N	PRESENT	0
87721	87187	14329V	PARTICIPANT	\N	PRESENT	0
87722	87187	01028R	PARTICIPANT	\N	PRESENT	0
87723	87187	11110B	PARTICIPANT	\N	PRESENT	0
87724	87187	04057K	PARTICIPANT	\N	PRESENT	0
87725	87187	11042G	PARTICIPANT	\N	PRESENT	0
87726	87187	14031R	PARTICIPANT	\N	PRESENT	0
87727	87187	01037S	PARTICIPANT	\N	PRESENT	0
87728	87187	04092N	PARTICIPANT	\N	PRESENT	0
87729	87187	87003B	PARTICIPANT	\N	PRESENT	0
87730	87187	04035D	PARTICIPANT	\N	PRESENT	0
87731	87187	04079R	PARTICIPANT	\N	PRESENT	0
87732	87187	08042U	PARTICIPANT	\N	PRESENT	0
87733	87187	01008M	PARTICIPANT	\N	PRESENT	0
87734	87187	04094Q	PARTICIPANT	\N	PRESENT	0
87735	87187	04048J	PARTICIPANT	\N	PRESENT	0
87736	87187	11114F	PARTICIPANT	\N	PRESENT	0
87737	87187	92039X	PARTICIPANT	\N	PRESENT	0
87738	87187	98021N	PARTICIPANT	\N	PRESENT	0
87739	87187	11113E	PARTICIPANT	\N	PRESENT	0
87740	87187	11033F	PARTICIPANT	\N	PRESENT	0
87741	87187	11049P	PARTICIPANT	\N	PRESENT	0
87742	87187	11099A	PARTICIPANT	\N	PRESENT	0
87743	87187	14119M	PARTICIPANT	\N	PRESENT	0
87744	87187	04067M	PARTICIPANT	\N	PRESENT	0
87745	87187	11065P	PARTICIPANT	\N	PRESENT	0
87746	87187	08019V	PARTICIPANT	\N	PRESENT	0
87747	87187	99002P	PARTICIPANT	\N	PRESENT	0
87748	87187	01046T	PARTICIPANT	\N	PRESENT	0
87749	87187	14079W	PARTICIPANT	\N	PRESENT	0
64544	63999	14030Q	PARTICIPANT	\N	PRESENT	0
64545	63999	14221J	PARTICIPANT	\N	PRESENT	0
64546	63999	01034P	PARTICIPANT	\N	PRESENT	0
64547	63999	90003B	PARTICIPANT	\N	PRESENT	0
64548	63999	11044J	PARTICIPANT	\N	PRESENT	0
64550	63999	08009T	PARTICIPANT	\N	PRESENT	0
64551	63999	11053K	PARTICIPANT	\N	PRESENT	0
64552	63999	14017T	PARTICIPANT	\N	PRESENT	0
64553	63999	04080J	PARTICIPANT	\N	PRESENT	0
64554	63999	14034U	PARTICIPANT	\N	PRESENT	0
64555	63999	11085T	PARTICIPANT	\N	PRESENT	0
64557	63999	11101A	PARTICIPANT	\N	PRESENT	0
64558	63999	11070L	PARTICIPANT	\N	PRESENT	0
64559	63999	01061S	PARTICIPANT	\N	PRESENT	0
64561	63999	14042U	PARTICIPANT	\N	PRESENT	0
64562	63999	14251Q	PARTICIPANT	\N	PRESENT	0
64564	63999	14219Q	PARTICIPANT	\N	PRESENT	0
64566	63999	11048N	PARTICIPANT	\N	PRESENT	0
64567	63999	14267Y	PARTICIPANT	\N	PRESENT	0
64569	63999	14103D	PARTICIPANT	\N	PRESENT	0
64570	63999	08069G	PARTICIPANT	\N	PRESENT	0
64571	63999	11043H	PARTICIPANT	\N	PRESENT	0
64573	63999	11082Q	PARTICIPANT	\N	PRESENT	0
64574	63999	04074L	PARTICIPANT	\N	PRESENT	0
64576	63999	11093T	PARTICIPANT	\N	PRESENT	0
64577	63999	11020A	PARTICIPANT	\N	PRESENT	0
64578	63999	14089Y	PARTICIPANT	\N	PRESENT	0
64580	63999	89017R	PARTICIPANT	\N	PRESENT	0
64581	63999	14231L	PARTICIPANT	\N	PRESENT	0
64582	63999	08044W	PARTICIPANT	\N	PRESENT	0
64583	63999	04043D	PARTICIPANT	\N	PRESENT	0
64585	63999	14083S	PARTICIPANT	\N	PRESENT	0
64586	63999	07004J	PARTICIPANT	\N	PRESENT	0
64588	63999	02002K	PARTICIPANT	\N	PRESENT	0
64589	63999	98042T	PARTICIPANT	\N	PRESENT	0
64590	63999	04089T	PARTICIPANT	\N	PRESENT	0
64592	63999	11049P	PARTICIPANT	\N	PRESENT	0
64594	63999	14205J	PARTICIPANT	\N	PRESENT	0
64595	63999	14073Q	PARTICIPANT	\N	PRESENT	0
64597	63999	04049K	PARTICIPANT	\N	PRESENT	0
64598	63999	11111C	PARTICIPANT	\N	PRESENT	0
64600	63999	97011G	PARTICIPANT	\N	PRESENT	0
64601	63999	01047U	PARTICIPANT	\N	PRESENT	0
64602	63999	04070G	PARTICIPANT	\N	PRESENT	0
64604	63999	11103C	PARTICIPANT	\N	PRESENT	0
64605	63999	01024M	PARTICIPANT	\N	PRESENT	0
64606	63999	95035G	PARTICIPANT	\N	PRESENT	0
64607	63999	08056B	PARTICIPANT	\N	PRESENT	0
64608	63999	04040A	PARTICIPANT	\N	PRESENT	0
64609	63999	14157T	PARTICIPANT	\N	PRESENT	0
64610	63999	09001P	PARTICIPANT	\N	PRESENT	0
64611	63999	92039X	PARTICIPANT	\N	PRESENT	0
64612	63999	08034U	PARTICIPANT	\N	PRESENT	0
64613	63999	01025N	PARTICIPANT	\N	PRESENT	0
64614	63999	14175V	PARTICIPANT	\N	PRESENT	0
64615	63999	01007L	PARTICIPANT	\N	PRESENT	0
64616	63999	14327T	PARTICIPANT	\N	PRESENT	0
64617	63999	01043Q	PARTICIPANT	\N	PRESENT	0
64618	63999	10015M	PARTICIPANT	\N	PRESENT	0
64619	63999	11091R	PARTICIPANT	\N	PRESENT	0
64620	63999	14093U	PARTICIPANT	\N	PRESENT	0
64621	63999	11094U	PARTICIPANT	\N	PRESENT	0
64622	63999	14187A	PARTICIPANT	\N	PRESENT	0
64667	63999	08022Q	PARTICIPANT	\N	PRESENT	0
64625	63999	14199E	PARTICIPANT	\N	PRESENT	0
64627	63999	11088W	PARTICIPANT	\N	PRESENT	0
64665	63999	14329V	PARTICIPANT	\N	PRESENT	0
64632	63999	14041T	PARTICIPANT	\N	PRESENT	0
64635	63999	07029T	PARTICIPANT	\N	PRESENT	0
64636	63999	04088S	PARTICIPANT	\N	PRESENT	0
64638	63999	11071M	PARTICIPANT	\N	PRESENT	0
64639	63999	92045V	PARTICIPANT	\N	PRESENT	0
64641	63999	08015R	PARTICIPANT	\N	PRESENT	0
64643	63999	14213J	PARTICIPANT	\N	PRESENT	0
64644	63999	14135M	PARTICIPANT	\N	PRESENT	0
64646	63999	08065C	PARTICIPANT	\N	PRESENT	0
64647	63999	14033T	PARTICIPANT	\N	PRESENT	0
64649	63999	14037X	PARTICIPANT	\N	PRESENT	0
64650	63999	14059S	PARTICIPANT	\N	PRESENT	0
64653	63999	14119M	PARTICIPANT	\N	PRESENT	0
64655	63999	14173T	PARTICIPANT	\N	PRESENT	0
64657	63999	01041N	PARTICIPANT	\N	PRESENT	0
64658	63999	07024N	PARTICIPANT	\N	PRESENT	0
64659	63999	05012A	PARTICIPANT	\N	PRESENT	0
64660	63999	04044E	PARTICIPANT	\N	PRESENT	0
64661	63999	07034Q	PARTICIPANT	\N	PRESENT	0
64662	63999	04081K	PARTICIPANT	\N	PRESENT	0
64663	63999	05004A	PARTICIPANT	\N	PRESENT	0
64664	63999	08019V	PARTICIPANT	\N	PRESENT	0
64666	63999	04033B	PARTICIPANT	\N	PRESENT	0
64668	63999	98018T	PARTICIPANT	\N	PRESENT	0
64669	63999	14111D	PARTICIPANT	\N	PRESENT	0
64670	63999	08048B	PARTICIPANT	\N	PRESENT	0
64671	63999	77002U	PARTICIPANT	\N	PRESENT	0
64672	63999	14265W	PARTICIPANT	\N	PRESENT	0
64673	63999	14026U	PARTICIPANT	\N	PRESENT	0
64674	63999	01057W	PARTICIPANT	\N	PRESENT	0
64675	63999	01058X	PARTICIPANT	\N	PRESENT	0
64676	63999	11030C	PARTICIPANT	\N	PRESENT	0
64677	63999	98024R	PARTICIPANT	\N	PRESENT	0
64678	63999	14147R	PARTICIPANT	\N	PRESENT	0
64679	63999	04057K	PARTICIPANT	\N	PRESENT	0
64680	63999	01027Q	PARTICIPANT	\N	PRESENT	0
64681	63999	04055H	PARTICIPANT	\N	PRESENT	0
64682	63999	86034E	PARTICIPANT	\N	PRESENT	0
64683	63999	14195A	PARTICIPANT	\N	PRESENT	0
64684	63999	95015C	PARTICIPANT	\N	PRESENT	0
64707	63999	11026G	PARTICIPANT	\N	PRESENT	0
64686	63999	08047A	PARTICIPANT	\N	PRESENT	0
64687	63999	95030B	PARTICIPANT	\N	PRESENT	0
64688	63999	11097X	PARTICIPANT	\N	PRESENT	0
64689	63999	11027H	PARTICIPANT	\N	PRESENT	0
64690	63999	04071H	PARTICIPANT	\N	PRESENT	0
64691	63999	07032N	PARTICIPANT	\N	PRESENT	0
64692	63999	14061L	PARTICIPANT	\N	PRESENT	0
64694	63999	14053L	PARTICIPANT	\N	PRESENT	0
64695	63999	98021N	PARTICIPANT	\N	PRESENT	0
64696	63999	14249W	PARTICIPANT	\N	PRESENT	0
64697	63999	04047H	PARTICIPANT	\N	PRESENT	0
64698	63999	14217N	PARTICIPANT	\N	PRESENT	0
64699	63999	04086Q	PARTICIPANT	\N	PRESENT	0
64700	63999	14273W	PARTICIPANT	\N	PRESENT	0
64701	63999	14179A	PARTICIPANT	\N	PRESENT	0
65019	64000	08055A	PARTICIPANT	\N	PRESENT	0
64703	63999	87003B	PARTICIPANT	\N	PRESENT	0
64704	63999	95031C	PARTICIPANT	\N	PRESENT	0
64705	63999	04035D	PARTICIPANT	\N	PRESENT	0
64706	63999	92031P	PARTICIPANT	\N	PRESENT	0
64708	63999	14237S	PARTICIPANT	\N	PRESENT	0
65020	64000	14013P	PARTICIPANT	\N	PRESENT	0
65021	64000	14197C	PARTICIPANT	\N	PRESENT	0
65022	64000	08058D	PARTICIPANT	\N	PRESENT	0
65023	64000	08060W	PARTICIPANT	\N	PRESENT	0
65024	64000	14028W	PARTICIPANT	\N	PRESENT	0
65025	64000	12042Y	PARTICIPANT	\N	PRESENT	0
65026	64000	04095R	PARTICIPANT	\N	PRESENT	0
65027	64000	14269B	PARTICIPANT	\N	PRESENT	0
65028	64000	14105F	PARTICIPANT	\N	PRESENT	0
65029	64000	08018U	PARTICIPANT	\N	PRESENT	0
65030	64000	07029T	PARTICIPANT	\N	PRESENT	0
65031	64000	11071M	PARTICIPANT	\N	PRESENT	0
65032	64000	14059S	PARTICIPANT	\N	PRESENT	0
65033	64000	08065C	PARTICIPANT	\N	PRESENT	0
65037	64000	10015M	PARTICIPANT	\N	PRESENT	0
65035	64000	14251Q	PARTICIPANT	\N	PRESENT	0
65036	64000	11100Y	PARTICIPANT	\N	PRESENT	0
65038	64000	01041N	PARTICIPANT	\N	PRESENT	0
65039	64000	99004R	PARTICIPANT	\N	PRESENT	0
65040	64000	04048J	PARTICIPANT	\N	PRESENT	0
65041	64000	08044W	PARTICIPANT	\N	PRESENT	0
65042	64000	07004J	PARTICIPANT	\N	PRESENT	0
65043	64000	14205J	PARTICIPANT	\N	PRESENT	0
65044	64000	01028R	PARTICIPANT	\N	PRESENT	0
65045	64000	11026G	PARTICIPANT	\N	PRESENT	0
65046	64000	11034G	PARTICIPANT	\N	PRESENT	0
65047	64000	11098Y	PARTICIPANT	\N	PRESENT	0
65048	64000	04038G	PARTICIPANT	\N	PRESENT	0
65049	64000	14018U	PARTICIPANT	\N	PRESENT	0
65050	64000	14201E	PARTICIPANT	\N	PRESENT	0
65052	64000	98022P	PARTICIPANT	\N	PRESENT	0
65053	64000	95062K	PARTICIPANT	\N	PRESENT	0
65055	64000	98018T	PARTICIPANT	\N	PRESENT	0
65057	64000	14061L	PARTICIPANT	\N	PRESENT	0
65060	64000	04088S	PARTICIPANT	\N	PRESENT	0
65061	64000	11082Q	PARTICIPANT	\N	PRESENT	0
65062	64000	01007L	PARTICIPANT	\N	PRESENT	0
65064	64000	14179A	PARTICIPANT	\N	PRESENT	0
65065	64000	14237S	PARTICIPANT	\N	PRESENT	0
65068	64000	04047H	PARTICIPANT	\N	PRESENT	0
85626	85513	14105F	PARTICIPANT	\N	PRESENT	0
85627	85513	04086Q	PARTICIPANT	\N	PRESENT	0
84234	84229	08068F	PARTICIPANT	\N	PRESENT	0
84235	84229	14207L	PARTICIPANT	\N	PRESENT	0
85628	85513	14267Y	PARTICIPANT	\N	PRESENT	0
84237	84229	90003B	PARTICIPANT	\N	PRESENT	0
84238	84229	08028W	PARTICIPANT	\N	PRESENT	0
84239	84229	80013X	PARTICIPANT	\N	PRESENT	0
85629	85513	11012A	PARTICIPANT	\N	PRESENT	0
85630	85513	11091R	PARTICIPANT	\N	PRESENT	0
84242	84229	14197C	PARTICIPANT	\N	PRESENT	0
85072	85066	01044R	PARTICIPANT	\N	PRESENT	0
84244	84229	14187A	PARTICIPANT	\N	PRESENT	0
84245	84229	14033T	PARTICIPANT	\N	PRESENT	0
85073	85066	08043V	PARTICIPANT	\N	PRESENT	0
84247	84229	04048J	PARTICIPANT	\N	PRESENT	0
85074	85066	14089Y	PARTICIPANT	\N	PRESENT	0
85075	85066	14105F	PARTICIPANT	\N	PRESENT	0
85076	85066	11029K	PARTICIPANT	\N	PRESENT	0
85077	85066	95015C	PARTICIPANT	\N	PRESENT	0
84252	84229	08015R	PARTICIPANT	\N	PRESENT	0
84253	84229	11100Y	PRESIDENT	0	PRESENT	0
84254	84229	01061S	PARTICIPANT	\N	PRESENT	0
84255	84229	11098Y	PARTICIPANT	\N	PRESENT	0
85078	85066	92015P	PARTICIPANT	\N	PRESENT	0
84257	84229	11077T	PARTICIPANT	\N	PRESENT	0
85079	85066	08024S	PARTICIPANT	\N	EXCUSE	0
84259	84229	08019V	PARTICIPANT	\N	PRESENT	0
84260	84229	14257W	PARTICIPANT	\N	PRESENT	0
85631	85513	10015M	PARTICIPANT	\N	PRESENT	0
84262	84229	04088S	PARTICIPANT	\N	PRESENT	0
85632	85513	14159V	PARTICIPANT	\N	PRESENT	0
84264	84229	11090Q	PARTICIPANT	\N	PRESENT	0
84265	84229	11046L	PARTICIPANT	\N	PRESENT	0
84266	84229	01058X	PARTICIPANT	\N	PRESENT	0
84267	84229	11094U	PARTICIPANT	\N	PRESENT	0
84268	84229	11066Q	PARTICIPANT	\N	PRESENT	0
85633	85513	14263U	PARTICIPANT	\N	PRESENT	0
85634	85513	01015L	PARTICIPANT	\N	PRESENT	0
85082	85066	14209N	PARTICIPANT	\N	PRESENT	0
85083	85066	14079W	PARTICIPANT	\N	PRESENT	0
85084	85066	11091R	PARTICIPANT	\N	PRESENT	0
85085	85066	87003B	PARTICIPANT	\N	PRESENT	0
85635	85513	14109K	PARTICIPANT	\N	PRESENT	0
85087	85066	14249W	PARTICIPANT	\N	PRESENT	0
85637	85513	14041T	PARTICIPANT	\N	PRESENT	0
85089	85066	01025N	PARTICIPANT	\N	PRESENT	0
85090	85066	01037S	PARTICIPANT	\N	PRESENT	0
85638	85513	11095V	PARTICIPANT	\N	PRESENT	0
85092	85066	08035V	PARTICIPANT	\N	PRESENT	0
85093	85066	11089X	PARTICIPANT	\N	PRESENT	0
85094	85066	07026Q	PARTICIPANT	\N	PRESENT	0
85095	85066	14123H	PARTICIPANT	\N	PRESENT	0
85639	85513	14085U	PARTICIPANT	\N	PRESENT	0
85640	85513	98018T	PARTICIPANT	\N	PRESENT	0
85098	85066	14241N	PARTICIPANT	\N	PRESENT	0
85099	85066	14061L	PARTICIPANT	\N	PRESENT	0
85100	85066	14073Q	PARTICIPANT	\N	PRESENT	0
85101	85066	08031R	PARTICIPANT	\N	PRESENT	0
85641	85513	11056N	PARTICIPANT	\N	PRESENT	0
85103	85066	08039A	PARTICIPANT	\N	PRESENT	0
85104	85066	08017T	PARTICIPANT	\N	PRESENT	0
85105	85066	14059S	PARTICIPANT	\N	PRESENT	0
85657	85513	11098Y	PARTICIPANT	\N	PRESENT	0
85660	85513	14219Q	PARTICIPANT	\N	PRESENT	0
85108	85066	11104D	PARTICIPANT	\N	PRESENT	0
85109	85066	14063N	PARTICIPANT	\N	PRESENT	0
85110	85066	04057K	PARTICIPANT	\N	PRESENT	0
85111	85066	11014C	PARTICIPANT	\N	PRESENT	0
85112	85066	14109K	PARTICIPANT	\N	PRESENT	0
85113	85066	04070G	PRESIDENT	0	PRESENT	0
85114	85066	92040Q	PARTICIPANT	\N	PRESENT	0
85663	85513	14205J	PARTICIPANT	\N	PRESENT	0
85116	85066	83047W	PARTICIPANT	\N	PRESENT	0
85117	85066	14235Q	PARTICIPANT	\N	PRESENT	0
85667	85513	11072N	PARTICIPANT	\N	PRESENT	0
85670	85513	14273W	PARTICIPANT	\N	PRESENT	0
85120	85066	14229S	PARTICIPANT	\N	PRESENT	0
85121	85066	11043H	PARTICIPANT	\N	PRESENT	0
85624	85513	01007L	PARTICIPANT	\N	PRESENT	0
85123	85066	11011M	PARTICIPANT	\N	PRESENT	0
85672	85513	14213J	PARTICIPANT	\N	PRESENT	0
85673	85513	95063L	PARTICIPANT	\N	PRESENT	0
85674	85513	14031R	PARTICIPANT	\N	PRESENT	0
85675	85513	14331P	PARTICIPANT	\N	PRESENT	0
85687	85513	11103C	PARTICIPANT	\N	PRESENT	0
85691	85513	92015P	PARTICIPANT	\N	PRESENT	0
85696	85513	11042G	PARTICIPANT	\N	PRESENT	0
85697	85513	14231L	PARTICIPANT	\N	PRESENT	0
85698	85513	11093T	PARTICIPANT	\N	PRESENT	0
85699	85513	14193X	PARTICIPANT	\N	PRESENT	0
85700	85513	01013J	PARTICIPANT	\N	PRESENT	0
85701	85513	87003B	PARTICIPANT	\N	PRESENT	0
85702	85513	05008E	PARTICIPANT	\N	PRESENT	0
85703	85513	14225N	PARTICIPANT	\N	PRESENT	0
85704	85513	14223L	PARTICIPANT	\N	PRESENT	0
85705	85513	14209N	PARTICIPANT	\N	PRESENT	0
85706	85513	14038Y	PARTICIPANT	\N	PRESENT	0
85748	85515	14235Q	PARTICIPANT	\N	PRESENT	0
85749	85515	01013J	PARTICIPANT	\N	PRESENT	0
85750	85515	11098Y	PARTICIPANT	\N	PRESENT	0
85751	85515	14107H	PARTICIPANT	\N	PRESENT	0
85752	85515	14249W	PARTICIPANT	\N	PRESENT	0
85753	85515	14109K	PARTICIPANT	\N	PRESENT	0
85754	85515	14265W	PARTICIPANT	\N	PRESENT	0
85755	85515	14225N	PARTICIPANT	\N	PRESENT	0
85625	85513	11011M	PARTICIPANT	\N	PRESENT	0
85756	85515	11095V	PARTICIPANT	\N	PRESENT	0
85757	85515	87003B	PARTICIPANT	\N	PRESENT	0
85758	85515	11046L	PARTICIPANT	\N	PRESENT	0
85759	85515	11011M	PARTICIPANT	\N	PRESENT	0
85760	85515	92015P	PARTICIPANT	\N	PRESENT	0
85762	85515	14038Y	PARTICIPANT	\N	PRESENT	0
85763	85515	11042G	PARTICIPANT	\N	PRESENT	0
85768	85515	14159V	PARTICIPANT	\N	PRESENT	0
85765	85515	14105F	PARTICIPANT	\N	PRESENT	0
85766	85515	14041T	PARTICIPANT	\N	PRESENT	0
85767	85515	14223L	PARTICIPANT	\N	PRESENT	0
85769	85515	04059M	PARTICIPANT	\N	PRESENT	0
85770	85515	11012A	PARTICIPANT	\N	PRESENT	0
85771	85515	11091R	PARTICIPANT	\N	PRESENT	0
85772	85515	14205J	PARTICIPANT	\N	PRESENT	0
85773	85515	14219Q	PARTICIPANT	\N	PRESENT	0
85774	85515	14073Q	PARTICIPANT	\N	PRESENT	0
85775	85515	04086Q	PARTICIPANT	\N	PRESENT	0
85776	85515	11093T	PARTICIPANT	\N	PRESENT	0
85777	85515	14267Y	PARTICIPANT	\N	PRESENT	0
85835	85515	14231L	PARTICIPANT	\N	PRESENT	0
85836	85515	14061L	PARTICIPANT	\N	PRESENT	0
85837	85515	14209N	PARTICIPANT	\N	PRESENT	0
85838	85515	08018U	PARTICIPANT	\N	PRESENT	0
85839	85515	11103C	PARTICIPANT	\N	PRESENT	0
85840	85515	04057K	PARTICIPANT	\N	PRESENT	0
85841	85515	04042C	PARTICIPANT	\N	PRESENT	0
85842	85515	14229S	PARTICIPANT	\N	PRESENT	0
85843	85515	11026G	PARTICIPANT	\N	PRESENT	0
85844	85515	11072N	PARTICIPANT	\N	PRESENT	0
85845	85515	14193X	PARTICIPANT	\N	PRESENT	0
85746	85515	01007L	PARTICIPANT	\N	PRESENT	0
85747	85515	05008E	PARTICIPANT	\N	PRESENT	0
85846	85515	14213J	PARTICIPANT	\N	PRESENT	0
85876	85515	11040E	PARTICIPANT	\N	PRESENT	0
85848	85515	14263U	PARTICIPANT	\N	PRESENT	0
85850	85515	14273W	PARTICIPANT	\N	PRESENT	0
85870	85515	95063L	PARTICIPANT	\N	PRESENT	0
85875	85515	14331P	PARTICIPANT	\N	PRESENT	0
85880	85515	01028R	PARTICIPANT	\N	PRESENT	0
85878	85515	04041B	PARTICIPANT	\N	PRESENT	0
85879	85515	01058X	PARTICIPANT	\N	PRESENT	0
85881	85515	80013X	PARTICIPANT	\N	PRESENT	0
85884	85515	04070G	PARTICIPANT	\N	PRESENT	0
85907	85515	98022P	PARTICIPANT	\N	PRESENT	0
85908	85515	11029K	PARTICIPANT	\N	PRESENT	0
85909	85515	11104D	PARTICIPANT	\N	PRESENT	0
85910	85515	14201E	PARTICIPANT	\N	PRESENT	0
85911	85515	14195A	PARTICIPANT	\N	PRESENT	0
85912	85515	13002U	PARTICIPANT	\N	PRESENT	0
85913	85515	08056B	PARTICIPANT	\N	PRESENT	0
85914	85515	11056N	PARTICIPANT	\N	PRESENT	0
85915	85515	11094U	PARTICIPANT	\N	PRESENT	0
85917	85916	04047H	PRESIDENT	0	PRESENT	0
85918	85515	10006L	PARTICIPANT	\N	PRESENT	0
85919	85515	11036J	PARTICIPANT	\N	PRESENT	0
85920	85916	14065Q	PARTICIPANT	\N	PRESENT	0
85921	85916	04038G	PARTICIPANT	\N	PRESENT	0
85922	85916	14041T	PARTICIPANT	\N	PRESENT	0
85923	85916	01024M	PARTICIPANT	\N	PRESENT	0
85924	85916	08044W	PARTICIPANT	\N	PRESENT	0
85925	85916	11026G	PARTICIPANT	\N	PRESENT	0
76761	76706	11025F	PARTICIPANT	\N	PRESENT	0
76862	76860	05008E	PRESIDENT	0	PRESENT	0
76863	76860	11030C	PARTICIPANT	\N	PRESENT	0
76861	76860	08025T	PARTICIPANT	\N	PRESENT	0
76864	76860	11033F	PARTICIPANT	\N	PRESENT	0
76865	76860	14065Q	PARTICIPANT	\N	PRESENT	0
76866	76860	04038G	PARTICIPANT	\N	PRESENT	0
76867	76860	99002P	PARTICIPANT	\N	PRESENT	0
76868	76860	11056N	PARTICIPANT	\N	PRESENT	0
76869	76860	14259Y	PARTICIPANT	\N	PRESENT	0
76870	76860	11035H	PARTICIPANT	\N	PRESENT	0
76871	76860	14041T	PARTICIPANT	\N	PRESENT	0
76872	76860	01024M	PARTICIPANT	\N	PRESENT	0
76873	76860	14215L	PARTICIPANT	\N	PRESENT	0
76874	76860	11034G	PARTICIPANT	\N	PRESENT	0
76875	76860	01007L	PARTICIPANT	\N	PRESENT	0
76876	76860	11049P	PARTICIPANT	\N	PRESENT	0
76878	76860	11084S	PARTICIPANT	\N	PRESENT	0
76880	76860	11026G	PARTICIPANT	\N	PRESENT	0
76881	76860	04079R	PARTICIPANT	\N	PRESENT	0
76882	76860	14111D	PARTICIPANT	\N	PRESENT	0
76884	76860	14001X	PARTICIPANT	\N	PRESENT	0
76885	76860	14273W	PARTICIPANT	\N	PRESENT	0
76886	76860	01060R	PARTICIPANT	\N	PRESENT	0
76887	76860	14147R	PARTICIPANT	\N	PRESENT	0
76888	76860	95049N	PARTICIPANT	\N	PRESENT	0
76889	76860	08051V	PARTICIPANT	\N	PRESENT	0
76890	76860	11072N	PARTICIPANT	\N	PRESENT	0
76891	76860	07034Q	PARTICIPANT	\N	PRESENT	0
76892	76860	04074L	PARTICIPANT	\N	PRESENT	0
76893	76860	10015M	PARTICIPANT	\N	PRESENT	0
76894	76860	95063L	PARTICIPANT	\N	PRESENT	0
76895	76860	01019Q	PARTICIPANT	\N	PRESENT	0
76896	76860	01028R	PARTICIPANT	\N	PRESENT	0
76897	76860	04056J	PARTICIPANT	\N	PRESENT	0
76898	76860	14275Y	PARTICIPANT	\N	PRESENT	0
76899	76860	04044E	PARTICIPANT	\N	PRESENT	0
76900	76860	11037K	PARTICIPANT	\N	PRESENT	0
76901	76860	95067Q	PARTICIPANT	\N	PRESENT	0
76902	76860	01047U	PARTICIPANT	\N	PRESENT	0
76904	76903	08025T	PARTICIPANT	\N	PRESENT	0
76905	76903	04085P	PARTICIPANT	\N	PRESENT	0
76906	76903	05008E	PRESIDENT	0	PRESENT	0
76907	76903	11030C	PARTICIPANT	\N	PRESENT	0
76908	76903	11033F	PARTICIPANT	\N	PRESENT	0
76909	76903	14065Q	PARTICIPANT	\N	PRESENT	0
76911	76903	14069U	PARTICIPANT	\N	PRESENT	0
76912	76903	04047H	PARTICIPANT	\N	PRESENT	0
76913	76903	04038G	PARTICIPANT	\N	PRESENT	0
76915	76903	99002P	PARTICIPANT	\N	PRESENT	0
76916	76903	11056N	PARTICIPANT	\N	PRESENT	0
76918	76903	14259Y	PARTICIPANT	\N	PRESENT	0
76919	76903	11035H	PARTICIPANT	\N	PRESENT	0
76920	76903	14041T	PARTICIPANT	\N	PRESENT	0
76922	76903	01024M	PARTICIPANT	\N	PRESENT	0
76924	76903	14215L	PARTICIPANT	\N	PRESENT	0
76928	76903	11034G	PARTICIPANT	\N	PRESENT	0
76929	76903	01007L	PARTICIPANT	\N	PRESENT	0
76931	76903	11049P	PARTICIPANT	\N	PRESENT	0
76932	76903	11084S	PARTICIPANT	\N	PRESENT	0
76933	76903	11026G	PARTICIPANT	\N	PRESENT	0
76937	76903	04079R	PARTICIPANT	\N	PRESENT	0
76938	76903	14111D	PARTICIPANT	\N	PRESENT	0
76939	76903	14001X	PARTICIPANT	\N	PRESENT	0
76940	76903	14273W	PARTICIPANT	\N	PRESENT	0
76941	76903	01060R	PARTICIPANT	\N	PRESENT	0
76942	76903	95049N	PARTICIPANT	\N	PRESENT	0
76943	76903	14147R	PARTICIPANT	\N	PRESENT	0
76944	76903	08051V	PARTICIPANT	\N	PRESENT	0
76945	76903	11072N	PARTICIPANT	\N	PRESENT	0
76946	76903	07034Q	PARTICIPANT	\N	PRESENT	0
76947	76903	04074L	PARTICIPANT	\N	PRESENT	0
76948	76903	10015M	PARTICIPANT	\N	PRESENT	0
76949	76903	95063L	PARTICIPANT	\N	PRESENT	0
76950	76903	01019Q	PARTICIPANT	\N	PRESENT	0
76951	76903	01028R	PARTICIPANT	\N	PRESENT	0
76952	76903	04056J	PARTICIPANT	\N	PRESENT	0
76953	76903	14275Y	PARTICIPANT	\N	PRESENT	0
76954	76903	04044E	PARTICIPANT	\N	PRESENT	0
76955	76903	11037K	PARTICIPANT	\N	PRESENT	0
76956	76903	92045V	PARTICIPANT	\N	PRESENT	0
76958	76903	95067Q	PARTICIPANT	\N	PRESENT	0
76959	76903	01047U	PARTICIPANT	\N	PRESENT	0
76963	76962	14263U	PARTICIPANT	\N	PRESENT	0
76964	76962	14133K	PARTICIPANT	\N	PRESENT	0
77029	76903	08047A	PARTICIPANT	\N	PRESENT	0
76966	76962	04059M	PARTICIPANT	\N	PRESENT	0
76967	76962	11039M	PARTICIPANT	\N	PRESENT	0
76968	76962	01044R	PARTICIPANT	\N	PRESENT	0
76969	76962	08043V	PARTICIPANT	\N	PRESENT	0
76970	76962	14089Y	PARTICIPANT	\N	PRESENT	0
76971	76962	14105F	PARTICIPANT	\N	PRESENT	0
76972	76962	11029K	PARTICIPANT	\N	EXCUSE	0
76973	76962	95015C	PARTICIPANT	\N	PRESENT	0
76974	76962	92015P	PARTICIPANT	\N	PRESENT	0
76975	76962	08024S	PARTICIPANT	\N	PRESENT	0
77030	76903	08011M	PARTICIPANT	\N	PRESENT	0
77073	76962	14249W	PARTICIPANT	\N	EXCUSE	0
77096	77095	14026U	PARTICIPANT	\N	PRESENT	0
77097	77095	04045F	PARTICIPANT	\N	PRESENT	0
76980	76962	11091R	PARTICIPANT	\N	PRESENT	0
76981	76962	87003B	PARTICIPANT	\N	PRESENT	0
76982	76962	98042T	PARTICIPANT	\N	PRESENT	0
77416	77415	88008L	PARTICIPANT	\N	PRESENT	0
76984	76962	01041N	PARTICIPANT	\N	PRESENT	0
76985	76962	01025N	PARTICIPANT	\N	PRESENT	0
77417	77415	04061F	PARTICIPANT	\N	PRESENT	0
77419	77418	88008L	PARTICIPANT	\N	PRESENT	0
77420	77418	04061F	PARTICIPANT	\N	PRESENT	0
76989	76962	11089X	PARTICIPANT	\N	PRESENT	0
76990	76962	07026Q	PARTICIPANT	\N	PRESENT	0
76991	76962	14123H	PARTICIPANT	\N	PRESENT	0
77422	77421	88008L	PARTICIPANT	\N	PRESENT	0
76993	76962	04041B	PARTICIPANT	\N	EXCUSE	0
76994	76962	14241N	PARTICIPANT	\N	PRESENT	0
76995	76962	14061L	PARTICIPANT	\N	PRESENT	0
76996	76962	14073Q	PARTICIPANT	\N	PRESENT	0
76997	76962	08031R	PARTICIPANT	\N	PRESENT	0
76998	76962	12041X	PARTICIPANT	\N	PRESENT	0
77423	77421	04061F	PARTICIPANT	\N	PRESENT	0
77000	76962	08017T	PARTICIPANT	\N	PRESENT	0
77001	76962	14059S	PARTICIPANT	\N	PRESENT	0
77002	76962	08012N	PARTICIPANT	\N	PRESENT	0
77003	76962	14103D	PARTICIPANT	\N	PRESENT	0
77004	76962	11104D	PARTICIPANT	\N	PRESENT	0
77005	76962	14063N	PARTICIPANT	\N	PRESENT	0
77006	76962	04057K	PARTICIPANT	\N	PRESENT	0
77007	76962	11014C	PARTICIPANT	\N	PRESENT	0
77425	77424	88008L	PARTICIPANT	\N	PRESENT	0
77009	76962	04070G	PRESIDENT	0	PRESENT	0
77426	77424	04061F	PARTICIPANT	\N	PRESENT	0
77428	77427	14175V	PARTICIPANT	\N	PRESENT	0
77012	76962	83047W	PARTICIPANT	\N	PRESENT	0
77013	76962	14235Q	PARTICIPANT	\N	PRESENT	0
77429	77427	14085U	PARTICIPANT	\N	PRESENT	0
77434	77433	08010L	PARTICIPANT	\N	PRESENT	0
77456	71343	01027Q	PRESIDENT	0	PRESENT	0
77017	76962	11043H	PARTICIPANT	\N	PRESENT	0
77457	71343	01022K	PARTICIPANT	\N	PRESENT	0
77458	71343	14097Y	PARTICIPANT	\N	PRESENT	0
77459	71343	04094Q	PARTICIPANT	\N	PRESENT	0
77460	71343	14059S	PARTICIPANT	\N	PRESENT	0
77461	71343	11025F	PARTICIPANT	\N	PRESENT	0
77462	71343	95062K	PARTICIPANT	\N	PRESENT	0
77463	71343	04043D	PARTICIPANT	\N	PRESENT	0
77464	71343	11106F	PARTICIPANT	\N	PRESENT	0
77465	75073	11025F	PARTICIPANT	\N	EXCUSE	0
77559	75073	04043D	PARTICIPANT	\N	PRESENT	0
77560	75073	01027Q	PRESIDENT	0	PRESENT	0
77561	75073	04095R	PARTICIPANT	\N	EXCUSE	0
77620	77619	98023Q	PARTICIPANT	\N	PRESENT	0
77622	77621	98023Q	PARTICIPANT	\N	PRESENT	0
77623	77621	08015R	PARTICIPANT	\N	PRESENT	0
77624	77621	08056B	PARTICIPANT	\N	PRESENT	0
77626	77625	98023Q	PARTICIPANT	\N	PRESENT	0
77627	77625	08015R	PARTICIPANT	\N	PRESENT	0
77628	77625	08056B	PARTICIPANT	\N	PRESENT	0
77629	77625	92039X	PARTICIPANT	\N	PRESENT	0
77631	77630	08051V	PARTICIPANT	\N	PRESENT	0
77632	77630	08034U	PARTICIPANT	\N	PRESENT	0
77633	77630	11106F	PARTICIPANT	\N	PRESENT	0
77634	77630	11026G	PARTICIPANT	\N	PRESENT	0
77635	77630	04056J	PARTICIPANT	\N	PRESENT	0
77642	77641	01013J	PARTICIPANT	\N	PRESENT	0
77644	77643	01013J	PARTICIPANT	\N	PRESENT	0
77649	77645	14030Q	PARTICIPANT	\N	PRESENT	0
87750	87187	08031R	PARTICIPANT	\N	PRESENT	0
87751	87187	11096W	PARTICIPANT	\N	PRESENT	0
87752	87187	04088S	PARTICIPANT	\N	PRESENT	0
87753	87187	14065Q	PARTICIPANT	\N	PRESENT	0
87754	87187	14331P	PARTICIPANT	\N	PRESENT	0
87755	87187	04034C	PARTICIPANT	\N	PRESENT	0
87756	87187	14069U	PARTICIPANT	\N	PRESENT	0
87757	87187	12042Y	PARTICIPANT	\N	PRESENT	0
87758	87187	04086Q	PARTICIPANT	\N	PRESENT	0
87759	87187	14159V	PARTICIPANT	\N	PRESENT	0
87760	87187	14239U	PARTICIPANT	\N	PRESENT	0
87761	87187	01057W	PARTICIPANT	\N	PRESENT	0
87762	87187	08021P	PARTICIPANT	\N	PRESENT	0
87763	87187	01041N	PARTICIPANT	\N	PRESENT	0
87764	87187	04059M	PARTICIPANT	\N	PRESENT	0
87765	87187	12041X	PARTICIPANT	\N	PRESENT	0
87766	87187	14249W	PARTICIPANT	\N	PRESENT	0
87767	87187	08058D	PARTICIPANT	\N	PRESENT	0
87768	87187	11066Q	PARTICIPANT	\N	PRESENT	0
87769	87187	11097X	PARTICIPANT	\N	PRESENT	0
87770	87187	08035V	PARTICIPANT	\N	PRESENT	0
87771	87187	07034Q	PARTICIPANT	\N	PRESENT	0
87772	87187	14061L	PARTICIPANT	\N	PRESENT	0
87773	87187	14241N	PARTICIPANT	\N	PRESENT	0
87774	87187	04061F	PARTICIPANT	\N	PRESENT	0
87775	87187	04053F	PARTICIPANT	\N	PRESENT	0
87776	87187	14014Q	PARTICIPANT	\N	PRESENT	0
87777	87187	01034P	PARTICIPANT	\N	PRESENT	0
87778	87187	01043Q	PARTICIPANT	\N	PRESENT	0
87779	87187	14327T	PARTICIPANT	\N	PRESENT	0
87780	87187	04040A	PARTICIPANT	\N	PRESENT	0
87781	87187	08056B	PARTICIPANT	\N	PRESENT	0
87782	87187	01047U	PARTICIPANT	\N	PRESENT	0
87783	87187	08009T	PARTICIPANT	\N	PRESENT	0
87784	87187	95035G	PARTICIPANT	\N	PRESENT	0
87785	87187	14255U	PARTICIPANT	\N	PRESENT	0
87786	87187	11070L	PARTICIPANT	\N	PRESENT	0
87787	87187	04080J	PARTICIPANT	\N	PRESENT	0
87788	87187	98042T	PARTICIPANT	\N	PRESENT	0
87789	87187	01024M	PARTICIPANT	\N	PRESENT	0
87790	87187	14205J	PARTICIPANT	\N	PRESENT	0
87791	87187	14267Y	PARTICIPANT	\N	PRESENT	0
87792	87187	14103D	PARTICIPANT	\N	PRESENT	0
87793	87187	11111C	PARTICIPANT	\N	PRESENT	0
87794	87187	14275Y	PARTICIPANT	\N	PRESENT	0
87795	87187	97011G	PARTICIPANT	\N	PRESENT	0
87796	87187	77002U	PARTICIPANT	\N	PRESENT	0
87797	87187	14083S	PARTICIPANT	\N	PRESENT	0
87798	87187	11026G	PARTICIPANT	\N	PRESENT	0
87799	87187	14093U	PARTICIPANT	\N	PRESENT	0
87800	87187	04050C	PARTICIPANT	\N	PRESENT	0
87801	87187	04042C	PARTICIPANT	\N	PRESENT	0
87802	87187	01013J	PARTICIPANT	\N	PRESENT	0
87803	87187	14235Q	PARTICIPANT	\N	PRESENT	0
87804	87187	04054G	PARTICIPANT	\N	PRESENT	0
87805	87187	07029T	PARTICIPANT	\N	PRESENT	0
87806	87187	11034G	PARTICIPANT	\N	PRESENT	0
87807	87187	08011M	PARTICIPANT	\N	PRESENT	0
87808	87187	98023Q	PARTICIPANT	\N	PRESENT	0
87809	87187	11101A	PARTICIPANT	\N	PRESENT	0
87810	87187	01027Q	PARTICIPANT	\N	PRESENT	0
87811	87187	14197C	PARTICIPANT	\N	PRESENT	0
87812	87187	11076S	PARTICIPANT	\N	PRESENT	0
87813	87187	14173T	PARTICIPANT	\N	PRESENT	0
87814	87187	14123H	PARTICIPANT	\N	PRESENT	0
87815	87187	14179A	PARTICIPANT	\N	PRESENT	0
87816	87187	14089Y	PARTICIPANT	\N	PRESENT	0
87817	87187	95059Q	PARTICIPANT	\N	PRESENT	0
87818	87187	14209N	PARTICIPANT	\N	PRESENT	0
87819	87187	08065C	PARTICIPANT	\N	PRESENT	0
87820	87187	11020A	PARTICIPANT	\N	PRESENT	0
87821	87187	04071H	PARTICIPANT	\N	PRESENT	0
87822	87187	01016M	PARTICIPANT	\N	PRESENT	0
87823	87187	08047A	PARTICIPANT	\N	PRESENT	0
87824	87187	98029W	PARTICIPANT	\N	PRESENT	0
87825	87187	08010L	PARTICIPANT	\N	PRESENT	0
87826	87187	14041T	PARTICIPANT	\N	PRESENT	0
87827	87187	11088W	PARTICIPANT	\N	PRESENT	0
87828	87187	14215L	PARTICIPANT	\N	PRESENT	0
87829	87187	14199E	PARTICIPANT	\N	PRESENT	0
87830	87187	11048N	PARTICIPANT	\N	PRESENT	0
87831	87187	08039A	PARTICIPANT	\N	PRESENT	0
87832	87187	05012A	PARTICIPANT	\N	PRESENT	0
87833	87187	14053L	PARTICIPANT	\N	PRESENT	0
87834	87187	11053K	PARTICIPANT	\N	PRESENT	0
87835	87187	14251Q	PARTICIPANT	\N	PRESENT	0
87836	87187	14034U	PARTICIPANT	\N	PRESENT	0
87837	87187	07004J	PARTICIPANT	\N	PRESENT	0
87838	87187	04078Q	PARTICIPANT	\N	PRESENT	0
87839	87187	08044W	PARTICIPANT	\N	PRESENT	0
87840	87187	14157T	PARTICIPANT	\N	PRESENT	0
87841	87187	05004A	PARTICIPANT	\N	PRESENT	0
87842	87187	01014K	PARTICIPANT	\N	PRESENT	0
87843	87187	14018U	PARTICIPANT	\N	PRESENT	0
87844	87187	08060W	PARTICIPANT	\N	PRESENT	0
87845	87187	04047H	PARTICIPANT	\N	PRESENT	0
87846	87187	14225N	PARTICIPANT	\N	PRESENT	0
87847	87187	11090Q	PARTICIPANT	\N	PRESENT	0
87848	87187	14135M	PARTICIPANT	\N	PRESENT	0
87849	87187	10015M	PARTICIPANT	\N	PRESENT	0
87850	87187	11044J	PARTICIPANT	\N	PRESENT	0
87851	87187	90003B	PARTICIPANT	\N	PRESENT	0
87852	87187	14195A	PARTICIPANT	\N	PRESENT	0
87853	87187	98053W	PARTICIPANT	\N	PRESENT	0
87854	87187	11037K	PARTICIPANT	\N	PRESENT	0
87855	87187	11112D	PARTICIPANT	\N	PRESENT	0
87856	87187	14237S	PARTICIPANT	\N	PRESENT	0
87857	87187	01007L	PARTICIPANT	\N	PRESENT	0
87858	87187	14271U	PARTICIPANT	\N	PRESENT	0
87859	87187	04045F	PARTICIPANT	\N	PRESENT	0
87860	87187	95037J	PARTICIPANT	\N	PRESENT	0
87861	87187	01003G	PARTICIPANT	\N	PRESENT	0
87862	87187	01056V	PARTICIPANT	\N	PRESENT	0
87863	87187	11015D	PARTICIPANT	\N	PRESENT	0
87864	87187	08028W	PARTICIPANT	\N	PRESENT	0
87865	87187	08038Y	PARTICIPANT	\N	PRESENT	0
87866	87187	14269B	PARTICIPANT	\N	PRESENT	0
87867	87187	13002U	PARTICIPANT	\N	PRESENT	0
87868	87187	08043V	PARTICIPANT	\N	PRESENT	0
87869	87187	11032E	PARTICIPANT	\N	PRESENT	0
87870	87187	11083R	PARTICIPANT	\N	PRESENT	0
87871	87187	11074Q	PARTICIPANT	\N	PRESENT	0
87872	87187	89017R	PARTICIPANT	\N	PRESENT	0
87873	87187	11064N	PARTICIPANT	\N	PRESENT	0
87874	87187	11068S	PARTICIPANT	\N	PRESENT	0
87875	87187	04055H	PARTICIPANT	\N	PRESENT	0
87882	87187	14257W	PARTICIPANT	\N	PRESENT	0
87883	87187	14219Q	PARTICIPANT	\N	PRESENT	0
87884	87187	11055M	PARTICIPANT	\N	PRESENT	0
87885	87188	86034E	PARTICIPANT	\N	PRESENT	0
87886	87188	14223L	PARTICIPANT	\N	PRESENT	0
87887	87188	14026U	PARTICIPANT	\N	PRESENT	0
87888	87188	04077P	PARTICIPANT	\N	PRESENT	0
87889	87188	04074L	PARTICIPANT	\N	PRESENT	0
87890	87188	11025F	PARTICIPANT	\N	PRESENT	0
87891	87188	14105F	PARTICIPANT	\N	PRESENT	0
87892	87188	14247U	PARTICIPANT	\N	PRESENT	0
87893	87188	14201E	PARTICIPANT	\N	PRESENT	0
87894	87188	08017T	PARTICIPANT	\N	PRESENT	0
87895	87188	11091R	PARTICIPANT	\N	PRESENT	0
87896	87188	99004R	PARTICIPANT	\N	PRESENT	0
87897	87188	04036E	PARTICIPANT	\N	PRESENT	0
87898	87188	11012A	PARTICIPANT	\N	PRESENT	0
87899	87188	14259Y	PARTICIPANT	\N	PRESENT	0
87900	87188	11106F	PARTICIPANT	\N	PRESENT	0
87901	87188	14227Q	PARTICIPANT	\N	PRESENT	0
87902	87188	11035H	PARTICIPANT	\N	PRESENT	0
87903	87188	14277B	PARTICIPANT	\N	PRESENT	0
87904	87188	80013X	PARTICIPANT	\N	PRESENT	0
87905	87188	14042U	PARTICIPANT	\N	PRESENT	0
87906	87188	14030Q	PARTICIPANT	\N	PRESENT	0
87907	87188	09001P	PARTICIPANT	\N	PRESENT	0
87908	87188	01019Q	PARTICIPANT	\N	PRESENT	0
87909	87188	11043H	PARTICIPANT	\N	PRESENT	0
87910	87188	95031C	PARTICIPANT	\N	PRESENT	0
87911	87188	14133K	PARTICIPANT	\N	PRESENT	0
87912	87188	95041E	PARTICIPANT	\N	PRESENT	0
87913	87188	14213J	PARTICIPANT	\N	PRESENT	0
87914	87188	11107G	PARTICIPANT	\N	PRESENT	0
87915	87188	08025T	PARTICIPANT	\N	PRESENT	0
87916	87188	14107H	PARTICIPANT	\N	PRESENT	0
87917	87188	00003C	PARTICIPANT	\N	PRESENT	0
87918	87188	98050T	PARTICIPANT	\N	PRESENT	0
87919	87188	08052W	PARTICIPANT	\N	PRESENT	0
87920	87188	08048B	PARTICIPANT	\N	PRESENT	0
87921	87188	11029K	PARTICIPANT	\N	PRESENT	0
87922	87188	11080N	PARTICIPANT	\N	PRESENT	0
87923	87188	14039A	PARTICIPANT	\N	PRESENT	0
64400	64397	08018U	PARTICIPANT	\N	PRESENT	0
64402	64397	04035D	PARTICIPANT	\N	PRESENT	0
64404	64397	04036E	PARTICIPANT	\N	PRESENT	0
64405	64397	08015R	PARTICIPANT	\N	PRESENT	0
64407	64397	11026G	PARTICIPANT	\N	PRESENT	0
64409	64397	04070G	PARTICIPANT	\N	PRESENT	0
64426	64424	77002U	PARTICIPANT	\N	PRESENT	0
64427	64424	88008L	PARTICIPANT	\N	PRESENT	0
64429	64424	14041T	PARTICIPANT	\N	PRESENT	0
64430	64424	14217N	PARTICIPANT	\N	PRESENT	0
64431	64424	98042T	PARTICIPANT	\N	PRESENT	0
64432	64424	92020L	PARTICIPANT	\N	PRESENT	0
64433	64424	08065C	PARTICIPANT	\N	PRESENT	0
64556	64543	04059M	PARTICIPANT	\N	PRESENT	0
64437	64424	11061K	PARTICIPANT	\N	PRESENT	0
64439	64424	04036E	PARTICIPANT	\N	PRESENT	0
64441	64424	04077P	PARTICIPANT	\N	PRESENT	0
64442	64424	08031R	PARTICIPANT	\N	PRESENT	0
64444	64424	01043Q	PARTICIPANT	\N	PRESENT	0
64445	64424	11106F	PARTICIPANT	\N	PRESENT	0
64446	64424	04057K	PARTICIPANT	\N	PRESENT	0
64447	64424	04070G	PARTICIPANT	\N	PRESENT	0
64449	64424	04044E	PARTICIPANT	\N	PRESENT	0
64549	64543	14263U	PARTICIPANT	\N	PRESENT	0
64560	64543	01044R	PARTICIPANT	\N	PRESENT	0
64563	64543	08043V	PARTICIPANT	\N	PRESENT	0
64565	64543	11029K	PARTICIPANT	\N	PRESENT	0
64568	64543	92015P	PARTICIPANT	\N	EXCUSE	0
64572	64543	14209N	PARTICIPANT	\N	EXCUSE	0
64575	64543	11091R	PARTICIPANT	\N	PRESENT	0
64579	64543	87003B	PARTICIPANT	\N	EXCUSE	0
64584	64543	01041N	PARTICIPANT	\N	PRESENT	0
64587	64543	01025N	PARTICIPANT	\N	PRESENT	0
64591	64543	11089X	PARTICIPANT	\N	PRESENT	0
64593	64543	07026Q	PARTICIPANT	\N	PRESENT	0
64596	64543	14241N	PARTICIPANT	\N	PRESENT	0
64599	64543	14061L	PARTICIPANT	\N	EXCUSE	0
64603	64543	14073Q	PARTICIPANT	\N	PRESENT	0
64623	64543	08039A	PARTICIPANT	\N	PRESENT	0
64626	64543	14059S	PARTICIPANT	\N	PRESENT	0
64629	64543	08012N	PARTICIPANT	\N	PRESENT	0
64630	64543	14103D	PARTICIPANT	\N	PRESENT	0
64631	64543	11104D	PARTICIPANT	\N	EXCUSE	0
64633	64543	14063N	PARTICIPANT	\N	PRESENT	0
64634	64543	04057K	PARTICIPANT	\N	PRESENT	0
64637	64543	11014C	PARTICIPANT	\N	PRESENT	0
64640	64543	14109K	PARTICIPANT	\N	PRESENT	0
64642	64543	04070G	PRESIDENT	0	PRESENT	0
64645	64543	92040Q	PARTICIPANT	\N	PRESENT	0
64648	64543	14235Q	PARTICIPANT	\N	PRESENT	0
64651	64543	04033B	PARTICIPANT	\N	PRESENT	0
64652	64543	14229S	PARTICIPANT	\N	PRESENT	0
64654	64543	11043H	PARTICIPANT	\N	PRESENT	0
64656	64543	08017T	PARTICIPANT	\N	PRESENT	0
64693	64543	08031R	PARTICIPANT	\N	PRESENT	0
65017	65016	11100Y	PARTICIPANT	\N	PRESENT	0
65018	65016	04048J	PARTICIPANT	\N	PRESENT	0
65069	64000	04085P	PARTICIPANT	\N	PRESENT	0
65072	64000	95049N	PARTICIPANT	\N	PRESENT	0
65075	64000	11056N	PARTICIPANT	\N	PRESENT	0
65078	64000	14329V	PARTICIPANT	\N	PRESENT	0
65085	64000	08069G	PARTICIPANT	\N	PRESENT	0
65106	64000	11093T	PARTICIPANT	\N	PRESENT	0
65087	64000	14073Q	PARTICIPANT	\N	PRESENT	0
65088	64000	01034P	PARTICIPANT	\N	PRESENT	0
65089	64000	14331P	PARTICIPANT	\N	PRESENT	0
65090	64000	86044G	PARTICIPANT	\N	PRESENT	0
65091	64000	95015C	PARTICIPANT	\N	PRESENT	0
65092	64000	14033T	PARTICIPANT	\N	PRESENT	0
65093	64000	11091R	PARTICIPANT	\N	PRESENT	0
65095	64000	01057W	PARTICIPANT	\N	PRESENT	0
65099	64000	11043H	PARTICIPANT	\N	PRESENT	0
65105	64000	14187A	PARTICIPANT	\N	PRESENT	0
65107	64000	11027H	PARTICIPANT	\N	PRESENT	0
65121	64000	11105E	PARTICIPANT	\N	PRESENT	0
65122	64000	08062Y	PARTICIPANT	\N	PRESENT	0
65123	64000	97011G	PARTICIPANT	\N	PRESENT	0
65124	64000	14223L	PARTICIPANT	\N	PRESENT	0
65125	64000	11095V	PARTICIPANT	\N	PRESENT	0
65126	64000	11033F	PARTICIPANT	\N	PRESENT	0
65127	64000	14195A	PARTICIPANT	\N	PRESENT	0
65128	64000	01047U	PARTICIPANT	\N	PRESENT	0
65129	64000	08017T	PARTICIPANT	\N	PRESENT	0
65130	64000	08010L	PARTICIPANT	\N	PRESENT	0
65131	64000	14069U	PARTICIPANT	\N	PRESENT	0
65132	64000	01025N	PARTICIPANT	\N	PRESENT	0
65133	64000	11084S	PARTICIPANT	\N	PRESENT	0
65134	64000	14217N	PARTICIPANT	\N	PRESENT	0
65135	64000	11067R	PARTICIPANT	\N	PRESENT	0
65136	64000	04044E	PARTICIPANT	\N	PRESENT	0
65137	64000	05008E	PARTICIPANT	\N	PRESENT	0
65138	64000	04056J	PARTICIPANT	\N	PRESENT	0
65139	64000	11096W	PARTICIPANT	\N	PRESENT	0
65140	64000	04081K	PARTICIPANT	\N	PRESENT	0
65141	64000	14249W	PARTICIPANT	\N	PRESENT	0
65142	64000	14031R	PARTICIPANT	\N	PRESENT	0
65143	64000	11097X	PARTICIPANT	\N	PRESENT	0
65144	64000	14265W	PARTICIPANT	\N	PRESENT	0
65145	64000	14135M	PARTICIPANT	\N	PRESENT	0
65146	64000	14199E	PARTICIPANT	\N	PRESENT	0
65147	64000	14225N	PARTICIPANT	\N	PRESENT	0
65148	64000	14209N	PARTICIPANT	\N	PRESENT	0
65149	64000	14087W	PARTICIPANT	\N	PRESENT	0
65177	64000	95030B	PARTICIPANT	\N	PRESENT	0
65179	64000	04059M	PARTICIPANT	\N	PRESENT	0
65180	64000	14109K	PARTICIPANT	\N	PRESENT	0
65181	64000	14267Y	PARTICIPANT	\N	PRESENT	0
65182	64000	14273W	PARTICIPANT	\N	PRESENT	0
65183	64000	01016M	PARTICIPANT	\N	PRESENT	0
65245	64003	11085T	PARTICIPANT	\N	PRESENT	0
65246	64003	08039A	PARTICIPANT	\N	PRESENT	0
65247	64003	01025N	PARTICIPANT	\N	PRESENT	0
65248	64003	14109K	PARTICIPANT	\N	PRESENT	0
65249	64003	08043V	PARTICIPANT	\N	PRESENT	0
65250	64003	04059M	PARTICIPANT	\N	PRESENT	0
65251	64003	11074Q	PARTICIPANT	\N	PRESENT	0
65252	64003	92039X	PARTICIPANT	\N	PRESENT	0
65253	64003	01037S	PARTICIPANT	\N	PRESENT	0
65254	64003	14051J	PARTICIPANT	\N	PRESENT	0
65255	64003	14263U	PARTICIPANT	\N	PRESENT	0
65256	64003	11093T	PARTICIPANT	\N	PRESENT	0
65257	64003	14267Y	PARTICIPANT	\N	PRESENT	0
65258	64003	14205J	PARTICIPANT	\N	PRESENT	0
65259	64003	08056B	PARTICIPANT	\N	PRESENT	0
65260	64003	14231L	PARTICIPANT	\N	PRESENT	0
65261	64003	14089Y	PARTICIPANT	\N	PRESENT	0
65262	64003	14030Q	PARTICIPANT	\N	PRESENT	0
65263	64003	12041X	PARTICIPANT	\N	PRESENT	0
65264	64003	14327T	PARTICIPANT	\N	PRESENT	0
65265	64003	11098Y	PARTICIPANT	\N	PRESENT	0
65266	64003	14175V	PARTICIPANT	\N	PRESENT	0
65278	64003	02002K	PARTICIPANT	\N	PRESENT	0
65268	64003	14331P	PARTICIPANT	\N	PRESENT	0
65269	64003	04033B	PARTICIPANT	\N	PRESENT	0
65270	64003	04057K	PARTICIPANT	\N	PRESENT	0
65271	64003	11091R	PARTICIPANT	\N	PRESENT	0
65272	64003	11044J	PARTICIPANT	\N	PRESENT	0
65273	64003	14169X	PARTICIPANT	\N	PRESENT	0
65274	64003	14105F	PARTICIPANT	\N	PRESENT	0
65275	64003	08047A	PARTICIPANT	\N	PRESENT	0
65276	64003	14038Y	PARTICIPANT	\N	PRESENT	0
65280	64003	80013X	PARTICIPANT	\N	PRESENT	0
65279	64003	14197C	PARTICIPANT	\N	PRESENT	0
65281	64003	08017T	PARTICIPANT	\N	PRESENT	0
65282	64003	14018U	PARTICIPANT	\N	PRESENT	0
65283	64003	08031R	PARTICIPANT	\N	PRESENT	0
65284	64003	11101A	PARTICIPANT	\N	PRESENT	0
65285	64003	92040Q	PARTICIPANT	\N	PRESENT	0
65286	64003	07029T	PARTICIPANT	\N	PRESENT	0
65287	64003	95030B	PARTICIPANT	\N	PRESENT	0
65288	64003	11029K	PARTICIPANT	\N	PRESENT	0
65289	64003	04070G	PARTICIPANT	\N	PRESENT	0
65290	64003	14061L	PARTICIPANT	\N	PRESENT	0
65291	64003	14229S	PARTICIPANT	\N	PRESENT	0
65292	64003	14042U	PARTICIPANT	\N	PRESENT	0
65293	64003	01044R	PARTICIPANT	\N	PRESENT	0
65294	64003	14031R	PARTICIPANT	\N	PRESENT	0
65295	64003	14187A	PARTICIPANT	\N	PRESENT	0
65296	64003	01008M	PARTICIPANT	\N	PRESENT	0
65297	64003	14223L	PARTICIPANT	\N	PRESENT	0
65298	64003	01034P	PARTICIPANT	\N	PRESENT	0
65299	64003	14217N	PARTICIPANT	\N	PRESENT	0
65300	64003	08015R	PARTICIPANT	\N	PRESENT	0
65301	64003	14219Q	PARTICIPANT	\N	PRESENT	0
65302	64003	14249W	PARTICIPANT	\N	PRESENT	0
65303	64003	14265W	PARTICIPANT	\N	PRESENT	0
65304	64003	14271U	PARTICIPANT	\N	PRESENT	0
65305	64003	04045F	PARTICIPANT	\N	PRESENT	0
65306	64003	12042Y	PARTICIPANT	\N	PRESENT	0
65307	64003	11097X	PARTICIPANT	\N	PRESENT	0
85926	85916	14273W	PARTICIPANT	\N	PRESENT	0
85928	85916	10015M	PARTICIPANT	\N	PRESENT	0
85929	85916	95063L	PARTICIPANT	\N	PRESENT	0
85930	85916	01028R	PARTICIPANT	\N	PRESENT	0
85932	85916	98035U	PARTICIPANT	\N	PRESENT	0
85934	85916	92045V	PARTICIPANT	\N	PRESENT	0
85936	85916	95067Q	PARTICIPANT	\N	PRESENT	0
85945	85515	14169X	PARTICIPANT	\N	PRESENT	0
85946	85515	04048J	PARTICIPANT	\N	PRESENT	0
85947	85916	11076S	PARTICIPANT	\N	PRESENT	0
85949	85916	98018T	PARTICIPANT	\N	PRESENT	0
85951	85916	95030B	PARTICIPANT	\N	PRESENT	0
85953	85916	07024N	PARTICIPANT	\N	PRESENT	0
85954	85916	98022P	PARTICIPANT	\N	PRESENT	0
85955	85916	14097Y	PARTICIPANT	\N	PRESENT	0
85956	85916	92031P	PARTICIPANT	\N	PRESENT	0
85957	85916	11106F	PARTICIPANT	\N	PRESENT	0
85958	85916	95059Q	PARTICIPANT	\N	PRESENT	0
85959	85916	11054L	PARTICIPANT	\N	PRESENT	0
85960	85916	04080J	PARTICIPANT	\N	PRESENT	0
85961	85916	14079W	PARTICIPANT	\N	PRESENT	0
85962	85916	04034C	PARTICIPANT	\N	PRESENT	0
85963	85515	09001P	PARTICIPANT	\N	PRESENT	0
85964	85916	04054G	PARTICIPANT	\N	PRESENT	0
85965	85515	14133K	PARTICIPANT	\N	PRESENT	0
85966	85916	01016M	PARTICIPANT	\N	PRESENT	0
85967	85916	11105E	PARTICIPANT	\N	PRESENT	0
85968	85916	14133K	PARTICIPANT	\N	PRESENT	0
85969	85916	14073Q	PARTICIPANT	\N	PRESENT	0
85970	85515	04085P	PARTICIPANT	\N	PRESENT	0
85971	85916	14089Y	PARTICIPANT	\N	PRESENT	0
85972	85916	14249W	PARTICIPANT	\N	PRESENT	0
85973	85916	96004D	PARTICIPANT	\N	PRESENT	0
85974	85916	95035G	PARTICIPANT	\N	PRESENT	0
85975	85916	08042U	PARTICIPANT	\N	PRESENT	0
85976	85515	14121F	PARTICIPANT	\N	PRESENT	0
85977	85916	04035D	PARTICIPANT	\N	PRESENT	0
85978	85515	11097X	PARTICIPANT	\N	PRESENT	0
85979	85515	05012A	PARTICIPANT	\N	PRESENT	0
85980	85515	04033B	PARTICIPANT	\N	PRESENT	0
85985	85515	01031L	PARTICIPANT	\N	PRESENT	0
85986	85515	07024N	PARTICIPANT	\N	PRESENT	0
85987	85515	14251Q	PARTICIPANT	\N	PRESENT	0
86002	85515	14179A	PARTICIPANT	\N	PRESENT	0
86003	85515	89017R	PARTICIPANT	\N	PRESENT	0
86004	85515	14031R	PARTICIPANT	\N	PRESENT	0
86005	85515	08031R	PARTICIPANT	\N	PRESENT	0
86007	86006	08014Q	PARTICIPANT	\N	PRESENT	0
86008	86006	08069G	PARTICIPANT	\N	PRESENT	0
86009	85515	11089X	PARTICIPANT	\N	PRESENT	0
86011	86010	08014Q	PARTICIPANT	\N	PRESENT	0
86012	86010	08069G	PARTICIPANT	\N	PRESENT	0
86014	86013	14133K	PARTICIPANT	\N	PRESENT	0
86015	86013	14097Y	PARTICIPANT	\N	PRESENT	0
86016	86013	10015M	PARTICIPANT	\N	PRESENT	0
86017	85515	07026Q	PARTICIPANT	\N	PRESENT	0
86018	83892	11109J	PARTICIPANT	\N	PRESENT	0
86019	83892	14259Y	PARTICIPANT	\N	PRESENT	0
86020	83892	01027Q	PARTICIPANT	\N	PRESENT	0
86021	83892	04095R	PARTICIPANT	\N	PRESENT	0
86022	83892	14097Y	PARTICIPANT	\N	PRESENT	0
86023	83892	14039A	PARTICIPANT	\N	PRESENT	0
86024	83892	11106F	PARTICIPANT	\N	PRESENT	0
86025	83892	08019V	PRESIDENT	0	PRESENT	0
86026	83892	04043D	PARTICIPANT	\N	EXCUSE	0
86027	83892	11072N	PARTICIPANT	\N	PRESENT	0
86028	83892	95062K	PARTICIPANT	\N	EXCUSE	0
86029	83892	14275Y	PARTICIPANT	\N	PRESENT	0
86030	83892	11025F	PARTICIPANT	\N	PRESENT	0
86031	83892	96004D	PARTICIPANT	\N	EXCUSE	0
86032	85515	04067M	PARTICIPANT	\N	PRESENT	0
86033	83892	11054L	PARTICIPANT	\N	EXCUSE	0
86096	85516	14179A	PARTICIPANT	\N	PRESENT	0
86119	85516	87003B	PARTICIPANT	\N	PRESENT	0
86125	85516	14187A	PARTICIPANT	\N	PRESENT	0
86099	85516	01056V	PARTICIPANT	\N	PRESENT	0
86127	85516	14175V	PARTICIPANT	\N	PRESENT	0
86101	85516	14033T	PARTICIPANT	\N	PRESENT	0
86102	85516	11015D	PARTICIPANT	\N	PRESENT	0
86103	85516	14063N	PARTICIPANT	\N	PRESENT	0
86104	85516	14107H	PARTICIPANT	\N	PRESENT	0
86105	85516	01014K	PARTICIPANT	\N	PRESENT	0
86106	85516	11037K	PARTICIPANT	\N	PRESENT	0
86107	85516	11025F	PARTICIPANT	\N	PRESENT	0
86108	85516	12042Y	PARTICIPANT	\N	PRESENT	0
86109	85516	08055A	PARTICIPANT	\N	PRESENT	0
86110	85516	98022P	PARTICIPANT	\N	PRESENT	0
86111	85516	92015P	PARTICIPANT	\N	PRESENT	0
86112	85516	11114F	PARTICIPANT	\N	PRESENT	0
86113	85516	11012A	PARTICIPANT	\N	PRESENT	0
86114	85516	11066Q	PARTICIPANT	\N	PRESENT	0
86115	85516	14111D	PARTICIPANT	\N	PRESENT	0
86116	85516	14257W	PARTICIPANT	\N	PRESENT	0
86117	85516	11112D	PARTICIPANT	\N	PRESENT	0
86118	85516	14105F	PARTICIPANT	\N	PRESENT	0
86120	85516	11107G	PARTICIPANT	\N	PRESENT	0
86121	85516	98018T	PARTICIPANT	\N	PRESENT	0
86122	85516	04036E	PARTICIPANT	\N	PRESENT	0
86123	85516	01003G	PARTICIPANT	\N	PRESENT	0
86124	85516	14119M	PARTICIPANT	\N	PRESENT	0
86126	85516	11080N	PARTICIPANT	\N	PRESENT	0
86128	85516	04088S	PARTICIPANT	\N	PRESENT	0
86129	85516	14225N	PARTICIPANT	\N	PRESENT	0
86130	85516	04048J	PARTICIPANT	\N	PRESENT	0
86131	85516	86044G	PARTICIPANT	\N	PRESENT	0
86132	85516	14195A	PARTICIPANT	\N	PRESENT	0
86133	85516	80013X	PARTICIPANT	\N	PRESENT	0
86134	85516	04089T	PARTICIPANT	\N	PRESENT	0
86094	85516	86034E	PARTICIPANT	\N	PRESENT	0
86095	85516	14223L	PARTICIPANT	\N	PRESENT	0
86135	85516	14267Y	PARTICIPANT	\N	PRESENT	0
86136	85516	14159V	PARTICIPANT	\N	PRESENT	0
86137	85516	14042U	PARTICIPANT	\N	PRESENT	0
86138	85516	11014C	PARTICIPANT	\N	PRESENT	0
86139	85516	14253S	PARTICIPANT	\N	PRESENT	0
86140	85516	11104D	PARTICIPANT	\N	PRESENT	0
86141	85516	92020L	PARTICIPANT	\N	PRESENT	0
86142	85516	11082Q	PARTICIPANT	\N	PRESENT	0
86143	85516	11040E	PARTICIPANT	\N	PRESENT	0
86144	85516	14085U	PARTICIPANT	\N	PRESENT	0
86145	85516	04081K	PARTICIPANT	\N	PRESENT	0
86146	85516	14028W	PARTICIPANT	\N	PRESENT	0
86147	85516	07024N	PARTICIPANT	\N	PRESENT	0
86148	85516	14249W	PARTICIPANT	\N	PRESENT	0
86150	85516	80027E	PARTICIPANT	\N	PRESENT	0
86151	85516	11097X	PARTICIPANT	\N	PRESENT	0
86152	85516	11081P	PARTICIPANT	\N	PRESENT	0
86153	85516	08015R	PARTICIPANT	\N	PRESENT	0
86154	85516	14271U	PARTICIPANT	\N	PRESENT	0
86155	85516	14041T	PARTICIPANT	\N	PRESENT	0
86156	85516	01015L	PARTICIPANT	\N	PRESENT	0
86157	85516	08061X	PARTICIPANT	\N	PRESENT	0
86158	85516	14273W	PARTICIPANT	\N	PRESENT	0
86159	85516	04059M	PARTICIPANT	\N	PRESENT	0
86160	85516	01008M	PARTICIPANT	\N	PRESENT	0
86161	85516	11100Y	PARTICIPANT	\N	PRESENT	0
86162	85516	14065Q	PARTICIPANT	\N	PRESENT	0
86163	85516	11032E	PARTICIPANT	\N	PRESENT	0
86164	85516	11105E	PARTICIPANT	\N	PRESENT	0
86165	85516	04070G	PARTICIPANT	\N	PRESENT	0
86166	85516	14227Q	PARTICIPANT	\N	PRESENT	0
86167	85516	83047W	PARTICIPANT	\N	PRESENT	0
86168	85516	14073Q	PARTICIPANT	\N	PRESENT	0
86169	85516	07026Q	PARTICIPANT	\N	PRESENT	0
86170	85516	04050C	PARTICIPANT	\N	PRESENT	0
86171	85516	08056B	PARTICIPANT	\N	PRESENT	0
86172	85516	01013J	PARTICIPANT	\N	PRESENT	0
86173	85516	14013P	PARTICIPANT	\N	PRESENT	0
86175	85516	11034G	PARTICIPANT	\N	PRESENT	0
86176	85516	14103D	PARTICIPANT	\N	PRESENT	0
86177	85516	01059Y	PARTICIPANT	\N	PRESENT	0
86178	85516	14235Q	PARTICIPANT	\N	PRESENT	0
86179	85516	11063M	PARTICIPANT	\N	PRESENT	0
86180	85516	04086Q	PARTICIPANT	\N	PRESENT	0
86181	85516	92031P	PARTICIPANT	\N	PRESENT	0
86182	85516	14051J	PARTICIPANT	\N	PRESENT	0
86183	85516	14079W	PARTICIPANT	\N	PRESENT	0
86184	85516	08053X	PARTICIPANT	\N	PRESENT	0
86185	85516	14193X	PARTICIPANT	\N	PRESENT	0
86186	85516	11059R	PARTICIPANT	\N	PRESENT	0
86187	85516	02002K	PARTICIPANT	\N	PRESENT	0
86188	85516	01011G	PARTICIPANT	\N	PRESENT	0
86189	85516	14133K	PARTICIPANT	\N	PRESENT	0
86190	85516	04066L	PARTICIPANT	\N	PRESENT	0
86191	85516	92040Q	PARTICIPANT	\N	PRESENT	0
86192	85516	98046X	PARTICIPANT	\N	PRESENT	0
86193	85516	01041N	PARTICIPANT	\N	PRESENT	0
62528	62527	11095V	PARTICIPANT	\N	PRESENT	0
62529	62527	08028W	PARTICIPANT	\N	PRESENT	0
62530	62527	01003G	PARTICIPANT	\N	PRESENT	0
62531	62527	14221J	PARTICIPANT	\N	PRESENT	0
62532	62527	14223L	PARTICIPANT	\N	PRESENT	0
62534	62533	89017R	PARTICIPANT	\N	PRESENT	0
62535	62533	01044R	PARTICIPANT	\N	PRESENT	0
62536	62533	88008L	PARTICIPANT	\N	PRESENT	0
62537	62533	10006L	PARTICIPANT	\N	PRESENT	0
62538	62533	11091R	PARTICIPANT	\N	PRESENT	0
62539	62533	14249W	PARTICIPANT	\N	PRESENT	0
62540	62533	11074Q	PARTICIPANT	\N	PRESENT	0
62541	62533	14018U	PARTICIPANT	\N	PRESENT	0
62542	62533	04056J	PARTICIPANT	\N	PRESENT	0
62544	62543	89017R	PARTICIPANT	\N	PRESENT	0
62545	62543	10006L	PARTICIPANT	\N	PRESENT	0
62546	62543	04036E	PARTICIPANT	\N	PRESENT	0
62547	62543	07026Q	PARTICIPANT	\N	PRESENT	0
62555	62554	14133K	PARTICIPANT	\N	EXCUSE	0
63905	63904	14031R	PARTICIPANT	\N	PRESENT	0
63906	63904	14093U	PARTICIPANT	\N	PRESENT	0
62558	62554	14089Y	PARTICIPANT	\N	PRESENT	0
63908	63907	14031R	PARTICIPANT	\N	PRESENT	0
62560	62554	14041T	PARTICIPANT	\N	PRESENT	0
62561	62554	14217N	PARTICIPANT	\N	PRESENT	0
62562	62554	92020L	PARTICIPANT	\N	PRESENT	0
62563	62554	14281W	PRESIDENT	0	PRESENT	0
62564	62554	08041T	PARTICIPANT	\N	PRESENT	0
62565	62554	07004J	PARTICIPANT	\N	PRESENT	0
62566	62554	11049P	PARTICIPANT	\N	PRESENT	0
62567	62554	14123H	PARTICIPANT	\N	PRESENT	0
62568	62554	99004R	PARTICIPANT	\N	PRESENT	0
62569	62554	04061F	PARTICIPANT	\N	PRESENT	0
62570	62554	08053X	PARTICIPANT	\N	PRESENT	0
62571	62554	11082Q	PARTICIPANT	\N	PRESENT	0
62572	62554	14193X	PARTICIPANT	\N	EXCUSE	0
62573	62554	14247U	PARTICIPANT	\N	PRESENT	0
62574	62554	10015M	PARTICIPANT	\N	EXCUSE	0
62575	62554	11054L	PARTICIPANT	\N	EXCUSE	0
63909	63907	14030Q	PARTICIPANT	\N	PRESENT	0
62577	62554	14269B	PARTICIPANT	\N	PRESENT	0
63910	63907	01022K	PARTICIPANT	\N	PRESENT	0
63911	63907	95062K	PARTICIPANT	\N	PRESENT	0
63912	63907	14157T	PARTICIPANT	\N	PRESENT	0
63915	63914	14031R	PARTICIPANT	\N	PRESENT	0
63916	63914	14030Q	PARTICIPANT	\N	PRESENT	0
63917	63914	01022K	PARTICIPANT	\N	PRESENT	0
63918	63914	95062K	PARTICIPANT	\N	PRESENT	0
63919	63914	14157T	PARTICIPANT	\N	PRESENT	0
63921	63920	14031R	PARTICIPANT	\N	PRESENT	0
63924	63923	14031R	PARTICIPANT	\N	PRESENT	0
63925	63923	01022K	PARTICIPANT	\N	PRESENT	0
63927	63926	14031R	PARTICIPANT	\N	PRESENT	0
63928	63926	01022K	PARTICIPANT	\N	PRESENT	0
63930	63929	14031R	PARTICIPANT	\N	PRESENT	0
63931	63929	01022K	PARTICIPANT	\N	PRESENT	0
63932	63929	14157T	PARTICIPANT	\N	PRESENT	0
63933	63929	14083S	PARTICIPANT	\N	PRESENT	0
63935	63934	14031R	PARTICIPANT	\N	PRESENT	0
63936	63934	14157T	PARTICIPANT	\N	PRESENT	0
63937	63934	14083S	PARTICIPANT	\N	PRESENT	0
63939	63938	14031R	PARTICIPANT	\N	PRESENT	0
63940	63938	98046X	PARTICIPANT	\N	PRESENT	0
63942	63941	14031R	PARTICIPANT	\N	PRESENT	0
63943	63941	14093U	PARTICIPANT	\N	PRESENT	0
63944	63941	14157T	PARTICIPANT	\N	PRESENT	0
63946	63945	14031R	PARTICIPANT	\N	PRESENT	0
63947	63945	14093U	PARTICIPANT	\N	PRESENT	0
63948	63945	14157T	PARTICIPANT	\N	PRESENT	0
70826	70825	08058D	PARTICIPANT	\N	PRESENT	0
70827	70825	04042C	PARTICIPANT	\N	PRESENT	0
70828	70825	77002U	PARTICIPANT	\N	PRESENT	0
70829	70825	98029W	PARTICIPANT	\N	PRESENT	0
70830	70825	98018T	PARTICIPANT	\N	PRESENT	0
70831	70825	92018S	PARTICIPANT	\N	PRESENT	0
70832	70825	92020L	PARTICIPANT	\N	PRESENT	0
70833	70825	95030B	PARTICIPANT	\N	PRESENT	0
70834	70825	11096W	PARTICIPANT	\N	PRESENT	0
70835	70825	97011G	PARTICIPANT	\N	PRESENT	0
70836	70825	08065C	PARTICIPANT	\N	PRESENT	0
70837	70825	04035D	PARTICIPANT	\N	PRESENT	0
70838	70825	07024N	PARTICIPANT	\N	PRESENT	0
70839	70825	04095R	PARTICIPANT	\N	PRESENT	0
70840	70825	14014Q	PARTICIPANT	\N	PRESENT	0
70841	70825	11015D	PARTICIPANT	\N	PRESENT	0
70842	70825	07004J	PARTICIPANT	\N	PRESENT	0
70843	70825	95035G	PARTICIPANT	\N	PRESENT	0
70844	70825	08056B	PARTICIPANT	\N	EXCUSE	0
70845	70825	11064N	PARTICIPANT	\N	PRESENT	0
70846	70825	04078Q	PARTICIPANT	\N	PRESENT	0
70847	70825	14097Y	PARTICIPANT	\N	PRESENT	0
70848	70825	04036E	PARTICIPANT	\N	EXCUSE	0
70849	70825	92031P	PARTICIPANT	\N	PRESENT	0
70850	70825	08053X	PARTICIPANT	\N	PRESENT	0
70851	70825	11082Q	PARTICIPANT	\N	PRESENT	0
70852	70825	11105E	PARTICIPANT	\N	PRESENT	0
70853	70825	14253S	PARTICIPANT	\N	EXCUSE	0
70854	70825	14028W	PARTICIPANT	\N	EXCUSE	0
70855	70825	14193X	PARTICIPANT	\N	PRESENT	0
70856	70825	98021N	PARTICIPANT	\N	PRESENT	0
70857	70825	04080J	PARTICIPANT	\N	PRESENT	0
70858	70825	95059Q	PRESIDENT	0	PRESENT	0
70859	70825	86044G	PARTICIPANT	\N	PRESENT	0
70860	70825	01014K	PARTICIPANT	\N	PRESENT	0
70861	70825	11054L	PARTICIPANT	\N	PRESENT	0
70862	70825	01056V	PARTICIPANT	\N	PRESENT	0
70863	70825	08049C	PARTICIPANT	\N	PRESENT	0
70943	70942	89017R	PARTICIPANT	\N	PRESENT	0
70944	70942	01031L	PRESIDENT	0	PRESENT	0
71795	71794	11040E	PARTICIPANT	\N	PRESENT	0
70946	70942	01013J	PARTICIPANT	\N	PRESENT	0
70947	70942	11068S	PARTICIPANT	\N	PRESENT	0
70948	70942	11040E	PARTICIPANT	\N	PRESENT	0
70949	70942	08014Q	PARTICIPANT	\N	PRESENT	0
71796	71794	95030B	PARTICIPANT	\N	PRESENT	0
70951	70942	14175V	PARTICIPANT	\N	PRESENT	0
70952	70942	14083S	PARTICIPANT	\N	PRESENT	0
70953	70942	11053K	PARTICIPANT	\N	PRESENT	0
70954	70942	14085U	PARTICIPANT	\N	PRESENT	0
70955	70942	11042G	PARTICIPANT	\N	PRESENT	0
70956	70942	88008L	PARTICIPANT	\N	PRESENT	0
70957	70942	04086Q	PARTICIPANT	\N	PRESENT	0
70958	70942	04055H	PARTICIPANT	\N	PRESENT	0
73227	73226	08025T	PARTICIPANT	\N	PRESENT	0
70960	70942	11088W	PARTICIPANT	\N	PRESENT	0
73228	73226	04085P	PARTICIPANT	\N	PRESENT	0
70962	70942	08022Q	PARTICIPANT	\N	PRESENT	0
70963	70942	01027Q	PARTICIPANT	\N	PRESENT	0
73229	73226	05008E	PRESIDENT	0	PRESENT	0
73230	73226	11030C	PARTICIPANT	\N	PRESENT	0
70966	70942	98053W	PARTICIPANT	\N	EXCUSE	0
70967	70942	11083R	PARTICIPANT	\N	PRESENT	0
73231	73226	11033F	PARTICIPANT	\N	PRESENT	0
70969	70942	01057W	PARTICIPANT	\N	PRESENT	0
70970	70942	08016S	PARTICIPANT	\N	PRESENT	0
70971	70942	08069G	PARTICIPANT	\N	PRESENT	0
70972	70942	11048N	PARTICIPANT	\N	PRESENT	0
70973	70942	99004R	PARTICIPANT	\N	PRESENT	0
70974	70942	04061F	PARTICIPANT	\N	PRESENT	0
70975	70942	14159V	PARTICIPANT	\N	PRESENT	0
70976	70942	07029T	PARTICIPANT	\N	PRESENT	0
73232	73226	14065Q	PARTICIPANT	\N	PRESENT	0
70978	70942	08010L	PARTICIPANT	\N	PRESENT	0
70979	70942	08034U	PARTICIPANT	\N	PRESENT	0
70980	70942	01048V	PARTICIPANT	\N	PRESENT	0
70981	70942	98046X	PARTICIPANT	\N	PRESENT	0
73233	73226	14069U	PARTICIPANT	\N	PRESENT	0
70983	70942	08011M	PARTICIPANT	\N	PRESENT	0
70984	70942	08073C	PARTICIPANT	\N	PRESENT	0
70985	70942	08061X	PARTICIPANT	\N	PRESENT	0
70986	70942	01016M	PARTICIPANT	\N	PRESENT	0
70987	70942	14225N	PARTICIPANT	\N	PRESENT	0
70988	70942	11012A	PARTICIPANT	\N	PRESENT	0
70989	70942	11057P	PARTICIPANT	\N	EXCUSE	0
73234	73226	04047H	PARTICIPANT	\N	PRESENT	0
73236	73226	04038G	PARTICIPANT	\N	PRESENT	0
73237	73226	99002P	PARTICIPANT	\N	PRESENT	0
73238	73226	11056N	PARTICIPANT	\N	PRESENT	0
73239	73226	14259Y	PARTICIPANT	\N	PRESENT	0
73240	73226	11035H	PARTICIPANT	\N	PRESENT	0
73241	73226	14041T	PARTICIPANT	\N	PRESENT	0
73243	73226	01024M	PARTICIPANT	\N	PRESENT	0
73244	73226	14215L	PARTICIPANT	\N	PRESENT	0
73245	73226	11034G	PARTICIPANT	\N	PRESENT	0
73246	73226	08018U	PARTICIPANT	\N	PRESENT	0
73248	73226	01007L	PARTICIPANT	\N	PRESENT	0
87924	87188	14261S	PARTICIPANT	\N	PRESENT	0
87926	87188	11093T	PARTICIPANT	\N	PRESENT	0
87927	87188	14217N	PARTICIPANT	\N	PRESENT	0
87928	87188	14033T	PARTICIPANT	\N	PRESENT	0
87929	87188	14231L	PARTICIPANT	\N	PRESENT	0
87930	87188	11082Q	PARTICIPANT	\N	PRESENT	0
87931	87188	04089T	PARTICIPANT	\N	PRESENT	0
87932	87188	11103C	PARTICIPANT	\N	PRESENT	0
87933	87188	95030B	PARTICIPANT	\N	PRESENT	0
87934	87188	01022K	PARTICIPANT	\N	PRESENT	0
87935	87188	07026Q	PARTICIPANT	\N	PRESENT	0
87936	87188	14263U	PARTICIPANT	\N	PRESENT	0
87937	87188	92031P	PARTICIPANT	\N	PRESENT	0
87938	87188	14051J	PARTICIPANT	\N	PRESENT	0
87939	87188	89029V	PARTICIPANT	\N	PRESENT	0
87940	87188	11039M	PARTICIPANT	\N	PRESENT	0
87941	87188	98046X	PARTICIPANT	\N	PRESENT	0
87942	87188	14055N	PARTICIPANT	\N	PRESENT	0
87943	87188	14071N	PARTICIPANT	\N	PRESENT	0
87944	87188	11072N	PARTICIPANT	\N	PRESENT	0
87945	87188	11109J	PARTICIPANT	\N	PRESENT	0
87946	87188	14059S	PARTICIPANT	\N	PRESENT	0
87947	87188	11081P	PARTICIPANT	\N	PRESENT	0
87948	87188	08068F	PARTICIPANT	\N	PRESENT	0
87949	87188	14169X	PARTICIPANT	\N	PRESENT	0
87950	87188	08015R	PARTICIPANT	\N	PRESENT	0
87951	87188	04038G	PARTICIPANT	\N	PRESENT	0
87952	87188	88008L	PARTICIPANT	\N	PRESENT	0
87953	87188	08061X	PARTICIPANT	\N	PRESENT	0
87954	87188	04043D	PARTICIPANT	\N	PRESENT	0
87955	87188	11046L	PARTICIPANT	\N	PRESENT	0
87956	87188	04097T	PARTICIPANT	\N	PRESENT	0
87957	87188	98022P	PARTICIPANT	\N	PRESENT	0
87958	87188	01060R	PARTICIPANT	\N	PRESENT	0
87959	87188	14273W	PARTICIPANT	\N	PRESENT	0
87960	87188	11061K	PARTICIPANT	\N	PRESENT	0
87961	87188	95063L	PARTICIPANT	\N	PRESENT	0
87962	87188	11011M	PARTICIPANT	\N	PRESENT	0
87963	87188	96004D	PARTICIPANT	\N	PRESENT	0
87964	87188	14221J	PARTICIPANT	\N	PRESENT	0
87965	87188	11094U	PARTICIPANT	\N	PRESENT	0
87966	87188	04070G	PARTICIPANT	\N	PRESENT	0
87967	87188	14063N	PARTICIPANT	\N	PRESENT	0
87968	87188	10006L	PARTICIPANT	\N	PRESENT	0
87969	87188	95067Q	PARTICIPANT	\N	PRESENT	0
87970	87188	14265W	PARTICIPANT	\N	PRESENT	0
87971	87188	11100Y	PARTICIPANT	\N	PRESENT	0
87972	87188	92044U	PARTICIPANT	\N	PRESENT	0
87973	87188	95015C	PARTICIPANT	\N	PRESENT	0
87974	87188	07024N	PARTICIPANT	\N	PRESENT	0
87975	87188	98018T	PARTICIPANT	\N	PRESENT	0
87976	87188	01048V	PARTICIPANT	\N	PRESENT	0
87977	87188	04085P	PARTICIPANT	\N	PRESENT	0
87978	87188	01061S	PARTICIPANT	\N	PRESENT	0
87979	87188	92018S	PARTICIPANT	\N	PRESENT	0
87980	87188	92040Q	PARTICIPANT	\N	PRESENT	0
87981	87188	14013P	PARTICIPANT	\N	PRESENT	0
87982	87188	11056N	PARTICIPANT	\N	PRESENT	0
87983	87188	11098Y	PARTICIPANT	\N	PRESENT	0
87984	87188	11040E	PARTICIPANT	\N	PRESENT	0
87985	87188	14038Y	PARTICIPANT	\N	PRESENT	0
87986	87188	01059Y	PARTICIPANT	\N	PRESENT	0
87987	87188	11031D	PARTICIPANT	\N	PRESENT	0
87988	87188	04081K	PARTICIPANT	\N	PRESENT	0
87989	87188	01015L	PARTICIPANT	\N	PRESENT	0
87990	87188	11063M	PARTICIPANT	\N	PRESENT	0
87991	87188	98024R	PARTICIPANT	\N	PRESENT	0
87992	87188	07032N	PARTICIPANT	\N	PRESENT	0
87993	87188	08016S	PARTICIPANT	\N	PRESENT	0
87994	87188	92045V	PARTICIPANT	\N	PRESENT	0
87995	87188	98035U	PARTICIPANT	\N	PRESENT	0
87996	87188	92015P	PARTICIPANT	\N	PRESENT	0
87997	87188	95062K	PARTICIPANT	\N	PRESENT	0
87999	87188	14211G	PARTICIPANT	\N	PRESENT	0
88000	87188	08055A	PARTICIPANT	\N	PRESENT	0
88001	87188	01031L	PARTICIPANT	\N	PRESENT	0
88002	87188	08062Y	PARTICIPANT	\N	PRESENT	0
88003	87188	11027H	PARTICIPANT	\N	PRESENT	0
88004	87188	04041B	PARTICIPANT	\N	PRESENT	0
88005	87188	14028W	PARTICIPANT	\N	PRESENT	0
88006	87188	01011G	PARTICIPANT	\N	PRESENT	0
88007	87188	14253S	PARTICIPANT	\N	PRESENT	0
88008	87188	11089X	PARTICIPANT	\N	PRESENT	0
88009	87188	11036J	PARTICIPANT	\N	PRESENT	0
88010	87188	86044G	PARTICIPANT	\N	PRESENT	0
88011	87188	83047W	PARTICIPANT	\N	PRESENT	0
88012	87188	11059R	PARTICIPANT	\N	PRESENT	0
88013	87188	08053X	PARTICIPANT	\N	PRESENT	0
88014	87188	08012N	PARTICIPANT	\N	PRESENT	0
88015	87188	14187A	PARTICIPANT	\N	PRESENT	0
88016	87188	83042R	PARTICIPANT	\N	PRESENT	0
88017	87188	08041T	PARTICIPANT	\N	PRESENT	0
88018	87188	14175V	PARTICIPANT	\N	PRESENT	0
88019	87188	01058X	PARTICIPANT	\N	PRESENT	0
88020	87188	14109K	PARTICIPANT	\N	PRESENT	0
88021	87188	11014C	PARTICIPANT	\N	PRESENT	0
88022	87188	11095V	PARTICIPANT	\N	PRESENT	0
88023	87188	11030C	PARTICIPANT	\N	PRESENT	0
88024	87188	08014Q	PARTICIPANT	\N	PRESENT	0
88025	87188	11054L	PARTICIPANT	\N	PRESENT	0
88026	87188	08018U	PARTICIPANT	\N	PRESENT	0
88027	87188	14281W	PARTICIPANT	\N	PRESENT	0
88028	87188	04044E	PARTICIPANT	\N	PRESENT	0
88029	87188	14167V	PARTICIPANT	\N	PRESENT	0
88030	87188	14229S	PARTICIPANT	\N	PRESENT	0
88031	87188	14017T	PARTICIPANT	\N	PRESENT	0
88032	87188	14121F	PARTICIPANT	\N	PRESENT	0
88033	87188	14097Y	PARTICIPANT	\N	PRESENT	0
88034	87188	11077T	PARTICIPANT	\N	PRESENT	0
88035	87188	04056J	PARTICIPANT	\N	PRESENT	0
88036	87188	14037X	PARTICIPANT	\N	PRESENT	0
88037	87188	11057P	PARTICIPANT	\N	PRESENT	0
88038	87188	14147R	PARTICIPANT	\N	PRESENT	0
88039	87188	08024S	PARTICIPANT	\N	PRESENT	0
88040	87188	92020L	PARTICIPANT	\N	PRESENT	0
88041	87188	14151M	PARTICIPANT	\N	PRESENT	0
88042	87188	14193X	PARTICIPANT	\N	PRESENT	0
88044	87188	80027E	PARTICIPANT	\N	PRESENT	0
88045	87188	14329V	PARTICIPANT	\N	PRESENT	0
88046	87188	01028R	PARTICIPANT	\N	PRESENT	0
88047	87188	11110B	PARTICIPANT	\N	PRESENT	0
88048	87188	04057K	PARTICIPANT	\N	PRESENT	0
88049	87188	11042G	PARTICIPANT	\N	PRESENT	0
88051	87188	01037S	PARTICIPANT	\N	PRESENT	0
88052	87188	04092N	PARTICIPANT	\N	PRESENT	0
88053	87188	87003B	PARTICIPANT	\N	PRESENT	0
88054	87188	04035D	PARTICIPANT	\N	PRESENT	0
88055	87188	04079R	PARTICIPANT	\N	PRESENT	0
88056	87188	08042U	PARTICIPANT	\N	PRESENT	0
88057	87188	01008M	PARTICIPANT	\N	PRESENT	0
88058	87188	04094Q	PARTICIPANT	\N	PRESENT	0
88059	87188	04048J	PARTICIPANT	\N	PRESENT	0
88060	87188	11114F	PARTICIPANT	\N	PRESENT	0
88061	87188	92039X	PARTICIPANT	\N	PRESENT	0
88062	87188	98021N	PARTICIPANT	\N	PRESENT	0
88063	87188	11113E	PARTICIPANT	\N	PRESENT	0
88064	87188	11033F	PARTICIPANT	\N	PRESENT	0
88065	87188	11049P	PARTICIPANT	\N	PRESENT	0
88066	87188	11099A	PARTICIPANT	\N	PRESENT	0
88067	87188	14119M	PARTICIPANT	\N	PRESENT	0
88068	87188	04067M	PARTICIPANT	\N	PRESENT	0
88069	87188	11065P	PARTICIPANT	\N	PRESENT	0
88070	87188	08019V	PARTICIPANT	\N	PRESENT	0
88071	87188	99002P	PARTICIPANT	\N	PRESENT	0
88072	87188	01046T	PARTICIPANT	\N	PRESENT	0
88073	87188	14079W	PARTICIPANT	\N	PRESENT	0
88074	87188	08031R	PARTICIPANT	\N	PRESENT	0
88075	87188	11096W	PARTICIPANT	\N	PRESENT	0
88076	87188	04088S	PARTICIPANT	\N	PRESENT	0
88077	87188	14065Q	PARTICIPANT	\N	PRESENT	0
88078	87188	14331P	PARTICIPANT	\N	PRESENT	0
88079	87188	04034C	PARTICIPANT	\N	PRESENT	0
88080	87188	14069U	PARTICIPANT	\N	PRESENT	0
88081	87188	12042Y	PARTICIPANT	\N	PRESENT	0
88082	87188	04086Q	PARTICIPANT	\N	PRESENT	0
88083	87188	14159V	PARTICIPANT	\N	PRESENT	0
88084	87188	14239U	PARTICIPANT	\N	PRESENT	0
88085	87188	01057W	PARTICIPANT	\N	PRESENT	0
88086	87188	08021P	PARTICIPANT	\N	PRESENT	0
88087	87188	01041N	PARTICIPANT	\N	PRESENT	0
88088	87188	04059M	PARTICIPANT	\N	PRESENT	0
88089	87188	12041X	PARTICIPANT	\N	PRESENT	0
88090	87188	14249W	PARTICIPANT	\N	PRESENT	0
88091	87188	08058D	PARTICIPANT	\N	PRESENT	0
65310	64003	11043H	PARTICIPANT	\N	PRESENT	0
65311	64003	92031P	PARTICIPANT	\N	PRESENT	0
65312	64003	14059S	PARTICIPANT	\N	PRESENT	0
65313	64003	14213J	PARTICIPANT	\N	PRESENT	0
65314	64003	08034U	PARTICIPANT	\N	PRESENT	0
65315	64003	11061K	PARTICIPANT	\N	PRESENT	0
65316	64003	14281W	PARTICIPANT	\N	PRESENT	0
65317	64003	11026G	PARTICIPANT	\N	PRESENT	0
65318	64003	08069G	PARTICIPANT	\N	PRESENT	0
65319	64003	14071N	PARTICIPANT	\N	PRESENT	0
65320	64003	14053L	PARTICIPANT	\N	PRESENT	0
65321	64003	14073Q	PARTICIPANT	\N	PRESENT	0
65322	64003	08051V	PARTICIPANT	\N	PRESENT	0
65323	64003	01046T	PARTICIPANT	\N	PRESENT	0
65324	64003	95049N	PARTICIPANT	\N	PRESENT	0
65325	64003	14123H	PARTICIPANT	\N	PRESENT	0
65326	64003	14034U	PARTICIPANT	\N	PRESENT	0
65327	64003	14209N	PARTICIPANT	\N	PRESENT	0
65328	64003	14033T	PARTICIPANT	\N	PRESENT	0
65329	64003	14241N	PARTICIPANT	\N	PRESENT	0
65330	64003	14257W	PARTICIPANT	\N	PRESENT	0
65331	64003	01028R	PARTICIPANT	\N	PRESENT	0
65332	64003	92045V	PARTICIPANT	\N	PRESENT	0
65333	64003	14083S	PARTICIPANT	\N	PRESENT	0
65524	65523	11061K	PARTICIPANT	\N	PRESENT	0
65525	65523	11093T	PARTICIPANT	\N	PRESENT	0
65881	65880	14263U	PARTICIPANT	\N	PRESENT	0
65949	65880	14061L	PARTICIPANT	\N	PRESENT	0
69357	69356	07024N	PARTICIPANT	\N	PRESENT	0
65884	65880	04059M	PARTICIPANT	\N	PRESENT	0
69359	69358	11027H	PARTICIPANT	\N	PRESENT	0
65886	65880	01044R	PARTICIPANT	\N	PRESENT	0
65887	65880	08043V	PARTICIPANT	\N	PRESENT	0
65888	65880	14089Y	PARTICIPANT	\N	PRESENT	0
69360	69358	86044G	PARTICIPANT	\N	PRESENT	0
69366	66808	11036J	PARTICIPANT	\N	PRESENT	0
69367	66808	04043D	PARTICIPANT	\N	PRESENT	0
65892	65880	92015P	PARTICIPANT	\N	EXCUSE	0
65893	65880	08024S	PARTICIPANT	\N	EXCUSE	0
65901	65880	14249W	PARTICIPANT	\N	PRESENT	0
69375	66808	83042R	PARTICIPANT	\N	EXCUSE	0
65903	65880	01025N	PARTICIPANT	\N	PRESENT	0
65904	65880	01037S	PARTICIPANT	\N	PRESENT	0
69376	66808	80013X	PARTICIPANT	\N	EXCUSE	0
70711	70710	08024S	PARTICIPANT	\N	PRESENT	0
70712	70710	14237S	PARTICIPANT	\N	PRESENT	0
65908	65880	07026Q	PARTICIPANT	\N	PRESENT	0
70713	70710	14133K	PARTICIPANT	\N	PRESENT	0
65910	65880	14179A	PARTICIPANT	\N	PRESENT	0
70714	70710	01037S	PARTICIPANT	\N	PRESENT	0
70715	70710	14265W	PARTICIPANT	\N	PRESENT	0
70787	70786	98046X	PARTICIPANT	\N	PRESENT	0
70789	70788	14263U	PARTICIPANT	\N	PRESENT	0
70790	70788	14133K	PARTICIPANT	\N	PRESENT	0
70791	70788	04059M	PARTICIPANT	\N	PRESENT	0
65917	65880	08039A	PARTICIPANT	\N	PRESENT	0
70792	70788	11039M	PARTICIPANT	\N	PRESENT	0
65919	65880	14059S	PARTICIPANT	\N	PRESENT	0
70793	70788	01044R	PARTICIPANT	\N	PRESENT	0
70794	70788	14089Y	PARTICIPANT	\N	PRESENT	0
70795	70788	14105F	PARTICIPANT	\N	PRESENT	0
70796	70788	95015C	PARTICIPANT	\N	PRESENT	0
65924	65880	04057K	PARTICIPANT	\N	PRESENT	0
70797	70788	92015P	PARTICIPANT	\N	PRESENT	0
70798	70788	08024S	PARTICIPANT	\N	PRESENT	0
65927	65880	04070G	PRESIDENT	0	PRESENT	0
70799	70788	14209N	PARTICIPANT	\N	PRESENT	0
70800	70788	11091R	PARTICIPANT	\N	PRESENT	0
70801	70788	87003B	PARTICIPANT	\N	PRESENT	0
70802	70788	14249W	PARTICIPANT	\N	EXCUSE	0
70803	70788	01041N	PARTICIPANT	\N	PRESENT	0
70804	70788	01025N	PARTICIPANT	\N	EXCUSE	0
65934	65880	14229S	PARTICIPANT	\N	PRESENT	0
70805	70788	01037S	PARTICIPANT	\N	PRESENT	0
65936	65880	11071M	PARTICIPANT	\N	PRESENT	0
70806	70788	89029V	PARTICIPANT	\N	EXCUSE	0
70807	70788	08035V	PARTICIPANT	\N	PRESENT	0
70808	70788	07026Q	PARTICIPANT	\N	PRESENT	0
70809	70788	14123H	PARTICIPANT	\N	PRESENT	0
70810	70788	04041B	PARTICIPANT	\N	EXCUSE	0
70811	70788	14241N	PARTICIPANT	\N	PRESENT	0
70812	70788	14073Q	PARTICIPANT	\N	PRESENT	0
70813	70788	08031R	PARTICIPANT	\N	PRESENT	0
70814	70788	08039A	PARTICIPANT	\N	PRESENT	0
70815	70788	08017T	PARTICIPANT	\N	PRESENT	0
70816	70788	14059S	PARTICIPANT	\N	PRESENT	0
70817	70788	11104D	PARTICIPANT	\N	PRESENT	0
70818	70788	14063N	PARTICIPANT	\N	PRESENT	0
70819	70788	04057K	PARTICIPANT	\N	PRESENT	0
70820	70788	04070G	PRESIDENT	0	PRESENT	0
70821	70788	92040Q	PARTICIPANT	\N	PRESENT	0
70822	70788	14235Q	PARTICIPANT	\N	EXCUSE	0
70823	70788	14229S	PARTICIPANT	\N	PRESENT	0
70824	70788	11043H	PARTICIPANT	\N	EXCUSE	0
70865	70864	08025T	PARTICIPANT	\N	PRESENT	0
70866	70864	04085P	PARTICIPANT	\N	PRESENT	0
70867	70864	05008E	PRESIDENT	0	PRESENT	0
70868	70864	11030C	PARTICIPANT	\N	PRESENT	0
70869	70864	11033F	PARTICIPANT	\N	PRESENT	0
70870	70864	14065Q	PARTICIPANT	\N	PRESENT	0
70871	70864	14069U	PARTICIPANT	\N	PRESENT	0
70872	70864	11032E	PARTICIPANT	\N	PRESENT	0
70873	70864	04038G	PARTICIPANT	\N	PRESENT	0
70874	70864	11056N	PARTICIPANT	\N	PRESENT	0
70875	70864	11035H	PARTICIPANT	\N	PRESENT	0
70876	70864	14041T	PARTICIPANT	\N	PRESENT	0
70877	70864	11113E	PARTICIPANT	\N	PRESENT	0
70878	70864	01024M	PARTICIPANT	\N	PRESENT	0
70879	70864	14215L	PARTICIPANT	\N	PRESENT	0
70880	70864	11034G	PARTICIPANT	\N	PRESENT	0
70881	70864	08018U	PARTICIPANT	\N	PRESENT	0
70882	70864	01007L	PARTICIPANT	\N	PRESENT	0
70883	70864	11049P	PARTICIPANT	\N	PRESENT	0
70884	70864	08044W	PARTICIPANT	\N	PRESENT	0
70885	70864	11026G	PARTICIPANT	\N	PRESENT	0
70886	70864	04079R	PARTICIPANT	\N	PRESENT	0
70887	70864	14111D	PARTICIPANT	\N	PRESENT	0
70888	70864	14001X	PARTICIPANT	\N	PRESENT	0
70889	70864	14273W	PARTICIPANT	\N	PRESENT	0
70890	70864	14147R	PARTICIPANT	\N	PRESENT	0
70891	70864	95049N	PARTICIPANT	\N	PRESENT	0
70892	70864	08051V	PARTICIPANT	\N	PRESENT	0
70893	70864	07034Q	PARTICIPANT	\N	PRESENT	0
70894	70864	04074L	PARTICIPANT	\N	PRESENT	0
70895	70864	10015M	PARTICIPANT	\N	PRESENT	0
70896	70864	95063L	PARTICIPANT	\N	PRESENT	0
70897	70864	01028R	PARTICIPANT	\N	PRESENT	0
70898	70864	98035U	PARTICIPANT	\N	PRESENT	0
70899	70864	04056J	PARTICIPANT	\N	PRESENT	0
70900	70864	04044E	PRESIDENT	1	PRESENT	0
70901	70864	11037K	PARTICIPANT	\N	PRESENT	0
71158	70864	01047U	PARTICIPANT	\N	PRESENT	0
71159	70864	92045V	PARTICIPANT	\N	PRESENT	0
71673	71672	11044J	PARTICIPANT	\N	PRESENT	0
71674	71672	11067R	PARTICIPANT	\N	PRESENT	0
71716	71715	89017R	PARTICIPANT	\N	PRESENT	0
71717	71715	04067M	PARTICIPANT	\N	PRESENT	0
71718	71715	01007L	PARTICIPANT	\N	PRESENT	0
71719	71715	04088S	PARTICIPANT	\N	PRESENT	0
71878	71877	14038Y	PARTICIPANT	\N	PRESENT	0
71880	71879	14038Y	PARTICIPANT	\N	PRESENT	0
71881	71879	14169X	PARTICIPANT	\N	PRESENT	0
71883	71882	14038Y	PARTICIPANT	\N	PRESENT	0
65308	64003	11048N	PARTICIPANT	\N	PRESENT	0
65309	64003	04088S	PARTICIPANT	\N	PRESENT	0
71886	71885	05012A	PARTICIPANT	\N	PRESENT	0
72206	72205	95049N	PARTICIPANT	\N	PRESENT	0
72208	72207	95049N	PARTICIPANT	\N	PRESENT	0
74167	71331	14039A	PARTICIPANT	\N	PRESENT	0
74168	71331	14097Y	PARTICIPANT	\N	PRESENT	0
74169	71331	01027Q	PARTICIPANT	\N	PRESENT	0
74170	71331	14259Y	PARTICIPANT	\N	PRESENT	0
74171	71331	11114F	PARTICIPANT	\N	PRESENT	0
74172	71331	01022K	PARTICIPANT	\N	PRESENT	0
74173	71331	11055M	PARTICIPANT	\N	PRESENT	0
74175	71331	11106F	PARTICIPANT	\N	EXCUSE	0
74176	71331	08019V	PRESIDENT	0	PRESENT	0
74178	71331	04043D	PARTICIPANT	\N	PRESENT	0
74182	71331	11071M	PARTICIPANT	\N	PRESENT	0
74184	71331	14275Y	PARTICIPANT	\N	PRESENT	0
74191	71331	04095R	PARTICIPANT	\N	PRESENT	0
74209	71331	11023D	PARTICIPANT	\N	EXCUSE	0
86194	85516	04085P	PARTICIPANT	\N	PRESENT	0
86195	85516	11056N	PARTICIPANT	\N	PRESENT	0
86196	85516	08058D	PARTICIPANT	\N	PRESENT	0
86197	85516	08012N	PARTICIPANT	\N	PRESENT	0
86198	85516	00003C	PARTICIPANT	\N	PRESENT	0
86199	85516	08068F	PARTICIPANT	\N	PRESENT	0
86200	85516	83042R	PARTICIPANT	\N	PRESENT	0
86201	85516	11036J	PARTICIPANT	\N	PRESENT	0
86202	85516	14229S	PARTICIPANT	\N	PRESENT	0
86203	85516	95062K	PARTICIPANT	\N	PRESENT	0
86204	85516	99004R	PARTICIPANT	\N	PRESENT	0
86205	85516	14263U	PARTICIPANT	\N	PRESENT	0
86206	85516	11043H	PARTICIPANT	\N	PRESENT	0
86207	85516	11098Y	PARTICIPANT	\N	PRESENT	0
86208	85516	98053W	PARTICIPANT	\N	PRESENT	0
86209	85516	11027H	PARTICIPANT	\N	PRESENT	0
86210	85516	04044E	PARTICIPANT	\N	PRESENT	0
86211	85516	14151M	PARTICIPANT	\N	PRESENT	0
86212	85516	95041E	PARTICIPANT	\N	PRESENT	0
86213	85516	14121F	PARTICIPANT	\N	PRESENT	0
86214	85516	14237S	PARTICIPANT	\N	PRESENT	0
86215	85516	14001X	PARTICIPANT	\N	PRESENT	0
86216	85516	01057W	PARTICIPANT	\N	PRESENT	0
86217	85516	14123H	PARTICIPANT	\N	PRESENT	0
86218	85516	08069G	PARTICIPANT	\N	PRESENT	0
86219	85516	04074L	PARTICIPANT	\N	PRESENT	0
86220	85516	13002U	PARTICIPANT	\N	PRESENT	0
86221	85516	11055M	PARTICIPANT	\N	PRESENT	0
86222	85516	11033F	PARTICIPANT	\N	PRESENT	0
86223	85516	08019V	PARTICIPANT	\N	PRESENT	0
86224	85516	11076S	PARTICIPANT	\N	PRESENT	0
86225	85516	98050T	PARTICIPANT	\N	PRESENT	0
86226	85516	14247U	PARTICIPANT	\N	PRESENT	0
86227	85516	14037X	PARTICIPANT	\N	PRESENT	0
86228	85516	92044U	PARTICIPANT	\N	PRESENT	0
86229	85516	11090Q	PARTICIPANT	\N	PRESENT	0
86230	85516	04078Q	PARTICIPANT	\N	PRESENT	0
86231	85516	11029K	PARTICIPANT	\N	PRESENT	0
86232	85516	08010L	PARTICIPANT	\N	PRESENT	0
86233	85516	08031R	PARTICIPANT	\N	PRESENT	0
86234	85516	14201E	PARTICIPANT	\N	PRESENT	0
86235	85516	95035G	PARTICIPANT	\N	PRESENT	0
86236	85516	11049P	PARTICIPANT	\N	PRESENT	0
86237	85516	98035U	PARTICIPANT	\N	PRESENT	0
86238	85516	01016M	PARTICIPANT	\N	PRESENT	0
86239	85516	07029T	PARTICIPANT	\N	PRESENT	0
86240	85516	11039M	PARTICIPANT	\N	PRESENT	0
86241	85516	05004A	PARTICIPANT	\N	PRESENT	0
86242	85516	08052W	PARTICIPANT	\N	PRESENT	0
86243	85516	14061L	PARTICIPANT	\N	PRESENT	0
86244	85516	95063L	PARTICIPANT	\N	PRESENT	0
86245	85516	04057K	PARTICIPANT	\N	PRESENT	0
86246	85516	04067M	PARTICIPANT	\N	PRESENT	0
86247	85516	14157T	PARTICIPANT	\N	PRESENT	0
86248	85516	11065P	PARTICIPANT	\N	PRESENT	0
86249	85516	96004D	PARTICIPANT	\N	PRESENT	0
86250	85516	08043V	PARTICIPANT	\N	PRESENT	0
86251	85516	05012A	PARTICIPANT	\N	PRESENT	0
86252	85516	98029W	PARTICIPANT	\N	PRESENT	0
86253	85516	14169X	PARTICIPANT	\N	PRESENT	0
86254	85516	11067R	PARTICIPANT	\N	PRESENT	0
86255	85516	04034C	PARTICIPANT	\N	PRESENT	0
86256	85516	07032N	PARTICIPANT	\N	PRESENT	0
86257	85516	95037J	PARTICIPANT	\N	PRESENT	0
86258	85516	11088W	PARTICIPANT	\N	PRESENT	0
86259	85516	11054L	PARTICIPANT	\N	PRESENT	0
86260	85516	10015M	PARTICIPANT	\N	PRESENT	0
86261	85516	04033B	PARTICIPANT	\N	PRESENT	0
86262	85516	08014Q	PARTICIPANT	\N	PRESENT	0
86263	85516	14135M	PARTICIPANT	\N	PRESENT	0
86264	85516	14331P	PARTICIPANT	\N	PRESENT	0
86265	85516	14207L	PARTICIPANT	\N	PRESENT	0
86266	85516	11042G	PARTICIPANT	\N	PRESENT	0
86267	85516	14097Y	PARTICIPANT	\N	PRESENT	0
86268	85516	08016S	PARTICIPANT	\N	PRESENT	0
86269	85516	14251Q	PARTICIPANT	\N	PRESENT	0
86270	85516	14281W	PARTICIPANT	\N	PRESENT	0
86271	85516	14031R	PARTICIPANT	\N	PRESENT	0
86272	85516	11074Q	PARTICIPANT	\N	PRESENT	0
86273	85516	08062Y	PARTICIPANT	\N	PRESENT	0
86274	85516	01031L	PARTICIPANT	\N	PRESENT	0
86275	85516	11026G	PARTICIPANT	\N	PRESENT	0
86276	85516	14038Y	PARTICIPANT	\N	PRESENT	0
86277	85516	04077P	PARTICIPANT	\N	PRESENT	0
86278	85516	92045V	PARTICIPANT	\N	PRESENT	0
86279	85516	04053F	PARTICIPANT	\N	PRESENT	0
86280	85516	04061F	PARTICIPANT	\N	PRESENT	0
86281	85516	01028R	PARTICIPANT	\N	PRESENT	0
86282	85516	11110B	PARTICIPANT	\N	PRESENT	0
86283	85516	08038Y	PARTICIPANT	\N	PRESENT	0
86284	85516	05008E	PARTICIPANT	\N	PRESENT	0
86285	85516	11061K	PARTICIPANT	\N	PRESENT	0
86286	85516	01037S	PARTICIPANT	\N	PRESENT	0
86287	85516	11046L	PARTICIPANT	\N	PRESENT	0
86288	85516	97011G	PARTICIPANT	\N	PRESENT	0
86289	85516	11068S	PARTICIPANT	\N	PRESENT	0
86290	85516	08018U	PARTICIPANT	\N	PRESENT	0
86291	85516	04045F	PARTICIPANT	\N	PRESENT	0
86292	85516	04041B	PARTICIPANT	\N	PRESENT	0
86293	85516	04095R	PARTICIPANT	\N	PRESENT	0
86294	85516	14213J	PARTICIPANT	\N	PRESENT	0
86295	85516	14269B	PARTICIPANT	\N	PRESENT	0
86296	85516	14265W	PARTICIPANT	\N	PRESENT	0
86297	85516	04094Q	PARTICIPANT	\N	PRESENT	0
86298	85516	98023Q	PARTICIPANT	\N	PRESENT	0
86299	85516	11113E	PARTICIPANT	\N	PRESENT	0
86300	85516	14039A	PARTICIPANT	\N	PRESENT	0
86301	85516	11072N	PARTICIPANT	\N	PRESENT	0
86302	85516	11109J	PARTICIPANT	\N	PRESENT	0
86327	85516	08044W	PARTICIPANT	\N	PRESENT	0
86304	85516	04038G	PARTICIPANT	\N	PRESENT	0
86305	85516	14089Y	PARTICIPANT	\N	PRESENT	0
86306	85516	95049N	PARTICIPANT	\N	PRESENT	0
86307	85516	11093T	PARTICIPANT	\N	PRESENT	0
86308	85516	11094U	PARTICIPANT	\N	PRESENT	0
86309	85516	08009T	PARTICIPANT	\N	PRESENT	0
86310	85516	11053K	PARTICIPANT	\N	PRESENT	0
86311	85516	98042T	PARTICIPANT	\N	PRESENT	0
86312	85516	04080J	PARTICIPANT	\N	PRESENT	0
86313	85516	11064N	PARTICIPANT	\N	PRESENT	0
86314	85516	14205J	PARTICIPANT	\N	PRESENT	0
86315	85516	14219Q	PARTICIPANT	\N	PRESENT	0
86316	85516	14231L	PARTICIPANT	\N	PRESENT	0
86317	85516	07004J	PARTICIPANT	\N	PRESENT	0
86318	85516	01007L	PARTICIPANT	\N	PRESENT	0
86319	85516	14030Q	PARTICIPANT	\N	PRESENT	0
86329	85516	01027Q	PARTICIPANT	\N	PRESENT	0
86321	85516	14034U	PARTICIPANT	\N	PRESENT	0
86322	85516	14221J	PARTICIPANT	\N	PRESENT	0
86323	85516	95059Q	PARTICIPANT	\N	PRESENT	0
86324	85516	14255U	PARTICIPANT	\N	PRESENT	0
86325	85516	01043Q	PARTICIPANT	\N	PRESENT	0
86326	85516	14275Y	PARTICIPANT	\N	PRESENT	0
86339	85516	09001P	PARTICIPANT	\N	PRESENT	0
86352	85516	95030B	PARTICIPANT	\N	PRESENT	0
86331	85516	04042C	PARTICIPANT	\N	PRESENT	0
86361	85516	11095V	PARTICIPANT	\N	PRESENT	0
86333	85516	14109K	PARTICIPANT	\N	PRESENT	0
86357	85516	10006L	PARTICIPANT	\N	PRESENT	0
86335	85516	95067Q	PARTICIPANT	\N	PRESENT	0
86336	85516	11044J	PARTICIPANT	\N	PRESENT	0
86348	85516	98021N	PARTICIPANT	\N	PRESENT	0
86338	85516	01058X	PARTICIPANT	\N	PRESENT	0
86340	85516	11091R	PARTICIPANT	\N	PRESENT	0
86350	85516	14093U	PARTICIPANT	\N	PRESENT	0
86343	85516	11089X	PARTICIPANT	\N	PRESENT	0
86344	85516	14199E	PARTICIPANT	\N	PRESENT	0
86356	85516	14259Y	PARTICIPANT	\N	PRESENT	0
86346	85516	11011M	PARTICIPANT	\N	PRESENT	0
86347	85516	08034U	PARTICIPANT	\N	PRESENT	0
86349	85516	14217N	PARTICIPANT	\N	PRESENT	0
86351	85516	11103C	PARTICIPANT	\N	PRESENT	0
86353	85516	04035D	PARTICIPANT	\N	PRESENT	0
86354	85516	11085T	PARTICIPANT	\N	PRESENT	0
86355	85516	77002U	PARTICIPANT	\N	PRESENT	0
86358	85516	14059S	PARTICIPANT	\N	PRESENT	0
86362	85516	89017R	PARTICIPANT	\N	PRESENT	0
86363	85516	08017T	PARTICIPANT	\N	PRESENT	0
86369	86368	07024N	PARTICIPANT	\N	PRESENT	0
86365	85516	11048N	PARTICIPANT	\N	PRESENT	0
86367	86366	95059Q	PARTICIPANT	\N	PRESENT	0
86370	86368	01014K	PARTICIPANT	\N	PRESENT	0
86371	86368	11106F	PARTICIPANT	\N	PRESENT	0
86372	86368	14193X	PARTICIPANT	\N	PRESENT	0
86374	86373	07024N	PARTICIPANT	\N	PRESENT	0
86375	86373	01014K	PARTICIPANT	\N	PRESENT	0
86376	86373	04040A	PARTICIPANT	\N	PRESENT	0
86377	86373	11106F	PARTICIPANT	\N	PRESENT	0
73249	73226	11049P	PARTICIPANT	\N	PRESENT	0
73250	73226	08044W	PARTICIPANT	\N	PRESENT	0
73251	73226	11084S	PARTICIPANT	\N	PRESENT	0
73252	73226	11026G	PARTICIPANT	\N	PRESENT	0
73253	73226	04079R	PARTICIPANT	\N	PRESENT	0
73254	73226	14111D	PARTICIPANT	\N	PRESENT	0
73255	73226	14001X	PARTICIPANT	\N	PRESENT	0
73256	73226	14273W	PARTICIPANT	\N	PRESENT	0
73257	73226	01060R	PARTICIPANT	\N	PRESENT	0
73258	73226	14147R	PARTICIPANT	\N	PRESENT	0
73259	73226	95049N	PARTICIPANT	\N	PRESENT	0
73260	73226	08051V	PARTICIPANT	\N	PRESENT	0
73523	73516	05008E	PARTICIPANT	\N	PRESENT	0
73262	73226	07034Q	PARTICIPANT	\N	PRESENT	0
73263	73226	04074L	PARTICIPANT	\N	PRESENT	0
73264	73226	10015M	PARTICIPANT	\N	PRESENT	0
73265	73226	95063L	PARTICIPANT	\N	PRESENT	0
73266	73226	01019Q	PARTICIPANT	\N	PRESENT	0
73267	73226	01028R	PARTICIPANT	\N	PRESENT	0
73268	73226	98035U	PARTICIPANT	\N	PRESENT	0
73269	73226	04056J	PARTICIPANT	\N	PRESENT	0
73270	73226	14275Y	PARTICIPANT	\N	PRESENT	0
73271	73226	04044E	PRESIDENT	1	PRESENT	0
73272	73226	11037K	PARTICIPANT	\N	PRESENT	0
73273	73226	92045V	PARTICIPANT	\N	PRESENT	0
73274	73226	95067Q	PARTICIPANT	\N	PRESENT	0
73275	73226	01047U	PARTICIPANT	\N	PRESENT	0
73480	73078	14179A	PARTICIPANT	\N	PRESENT	0
73524	73516	04038G	PARTICIPANT	\N	PRESENT	0
73525	73516	11056N	PARTICIPANT	\N	PRESENT	0
73526	73516	14259Y	PARTICIPANT	\N	PRESENT	0
73527	73516	11035H	PARTICIPANT	\N	PRESENT	0
73528	73516	14041T	PARTICIPANT	\N	PRESENT	0
73529	73516	14215L	PARTICIPANT	\N	PRESENT	0
73530	73516	08018U	PARTICIPANT	\N	PRESENT	0
73531	73516	11049P	PARTICIPANT	\N	PRESENT	0
73532	73516	14001X	PARTICIPANT	\N	PRESENT	0
73533	73516	14273W	PARTICIPANT	\N	PRESENT	0
73540	73516	01028R	PARTICIPANT	\N	PRESENT	0
73535	73516	14147R	PARTICIPANT	\N	PRESENT	0
73536	73516	95049N	PARTICIPANT	\N	PRESENT	0
73537	73516	10015M	PARTICIPANT	\N	PRESENT	0
73541	73516	92045V	PARTICIPANT	\N	PRESENT	0
76767	76766	89017R	PARTICIPANT	\N	PRESENT	0
76768	76766	01031L	PARTICIPANT	\N	EXCUSE	0
76769	76766	11040E	PARTICIPANT	\N	PRESENT	0
76770	76766	08014Q	PARTICIPANT	\N	PRESENT	0
76771	76766	14167V	PARTICIPANT	\N	PRESENT	0
76772	76766	14175V	PARTICIPANT	\N	PRESENT	0
76773	76766	14083S	PARTICIPANT	\N	PRESENT	0
76774	76766	14085U	PARTICIPANT	\N	PRESENT	0
76775	76766	11042G	PARTICIPANT	\N	PRESENT	0
76776	76766	88008L	PARTICIPANT	\N	PRESENT	0
76777	76766	04086Q	PARTICIPANT	\N	PRESENT	0
76778	76766	11070L	PARTICIPANT	\N	PRESENT	0
76779	76766	11088W	PRESIDENT	0	PRESENT	0
76780	76766	14327T	PARTICIPANT	\N	PRESENT	0
76781	76766	08022Q	PARTICIPANT	\N	PRESENT	0
76782	76766	01027Q	PARTICIPANT	\N	PRESENT	0
76783	76766	04071H	PARTICIPANT	\N	PRESENT	0
76784	76766	98053W	PARTICIPANT	\N	EXCUSE	0
76785	76766	11083R	PARTICIPANT	\N	PRESENT	0
76786	76766	01057W	PARTICIPANT	\N	PRESENT	0
76787	76766	08016S	PARTICIPANT	\N	PRESENT	0
76788	76766	08069G	PARTICIPANT	\N	PRESENT	0
76789	76766	99004R	PARTICIPANT	\N	PRESENT	0
76790	76766	04061F	PARTICIPANT	\N	PRESENT	0
76791	76766	14159V	PARTICIPANT	\N	PRESENT	0
76792	76766	07029T	PARTICIPANT	\N	PRESENT	0
76793	76766	08010L	PARTICIPANT	\N	PRESENT	0
76794	76766	08034U	PARTICIPANT	\N	PRESENT	0
76795	76766	01048V	PARTICIPANT	\N	PRESENT	0
76796	76766	98046X	PARTICIPANT	\N	PRESENT	0
76797	76766	08011M	PARTICIPANT	\N	PRESENT	0
76798	76766	08073C	PARTICIPANT	\N	EXCUSE	0
76799	76766	08061X	PARTICIPANT	\N	PRESENT	0
76800	76766	01016M	PARTICIPANT	\N	PRESENT	0
76801	76766	14225N	PARTICIPANT	\N	PRESENT	0
76802	76766	11012A	PARTICIPANT	\N	PRESENT	0
76803	76766	11057P	PARTICIPANT	\N	PRESENT	0
76804	76766	14173T	PARTICIPANT	\N	PRESENT	0
76805	76766	04034C	PARTICIPANT	\N	PRESENT	0
76879	76877	14071N	PARTICIPANT	\N	PRESENT	0
77569	77566	04044E	PARTICIPANT	\N	PRESENT	0
77563	77562	08034U	PARTICIPANT	\N	PRESENT	0
77565	77564	04044E	PARTICIPANT	\N	PRESENT	0
77637	77636	04042C	PARTICIPANT	\N	PRESENT	0
77638	77636	98005N	PARTICIPANT	\N	PRESENT	0
77640	77639	04042C	PARTICIPANT	\N	PRESENT	0
77762	77761	01057W	PARTICIPANT	\N	PRESENT	0
77763	77761	14225N	PARTICIPANT	\N	PRESENT	0
77765	77764	11088W	PARTICIPANT	\N	PRESENT	0
77766	77764	08011M	PARTICIPANT	\N	PRESENT	0
77767	77764	14225N	PARTICIPANT	\N	PRESENT	0
77768	77764	01057W	PARTICIPANT	\N	PRESENT	0
77656	77645	11065P	PARTICIPANT	\N	PRESENT	0
77657	77645	01015L	PARTICIPANT	\N	PRESENT	0
77658	77645	11107G	PARTICIPANT	\N	PRESENT	0
77769	77764	98046X	PARTICIPANT	\N	PRESENT	0
77770	77764	04086Q	PARTICIPANT	\N	PRESENT	0
77661	77645	01022K	PARTICIPANT	\N	PRESENT	0
77772	77764	08051V	PARTICIPANT	\N	PRESENT	0
77773	77764	01007L	PARTICIPANT	\N	PRESENT	0
77774	77764	14167V	PARTICIPANT	\N	PRESENT	0
77776	77764	01013J	PARTICIPANT	\N	PRESENT	0
77777	77764	14199E	PARTICIPANT	\N	PRESENT	0
77667	77645	14031R	PARTICIPANT	\N	PRESENT	0
77668	77645	08009T	PRESIDENT	0	PRESENT	0
77778	77764	11012A	PARTICIPANT	\N	PRESENT	0
77779	77764	11070L	PARTICIPANT	\N	PRESENT	0
77783	77782	11088W	PARTICIPANT	\N	PRESENT	0
77784	77782	08011M	PARTICIPANT	\N	PRESENT	0
77785	77782	14225N	PARTICIPANT	\N	PRESENT	0
77786	77782	01057W	PARTICIPANT	\N	PRESENT	0
77787	77782	98046X	PARTICIPANT	\N	PRESENT	0
77788	77782	04086Q	PARTICIPANT	\N	PRESENT	0
77789	77782	01013J	PARTICIPANT	\N	PRESENT	0
77790	77782	08051V	PARTICIPANT	\N	PRESENT	0
77679	77645	14331P	PARTICIPANT	\N	PRESENT	0
77680	77645	95062K	PARTICIPANT	\N	PRESENT	0
77791	77782	01007L	PARTICIPANT	\N	PRESENT	0
77792	77782	14167V	PARTICIPANT	\N	PRESENT	0
77683	77645	14157T	PARTICIPANT	\N	PRESENT	0
77793	77782	14199E	PARTICIPANT	\N	PRESENT	0
77794	77782	11012A	PARTICIPANT	\N	PRESENT	0
77802	77801	08018U	PARTICIPANT	\N	PRESENT	0
77804	77803	08018U	PARTICIPANT	\N	PRESENT	0
77806	77805	08018U	PARTICIPANT	\N	PRESENT	0
78306	78305	14083S	PARTICIPANT	\N	PRESENT	0
78496	78390	11065P	PARTICIPANT	\N	EXCUSE	0
78623	78620	04054G	PARTICIPANT	\N	EXCUSE	0
78624	78620	04040A	PARTICIPANT	\N	PRESENT	0
78625	78620	08058D	PARTICIPANT	\N	PRESENT	0
78626	78620	04042C	PARTICIPANT	\N	PRESENT	0
78627	78620	77002U	PARTICIPANT	\N	EXCUSE	0
78628	78620	98029W	PARTICIPANT	\N	PRESENT	0
78630	78620	11027H	PARTICIPANT	\N	PRESENT	0
78631	78620	98018T	PARTICIPANT	\N	PRESENT	0
78632	78620	92018S	PARTICIPANT	\N	PRESENT	0
78633	78620	92020L	PARTICIPANT	\N	PRESENT	0
78634	78620	95030B	PARTICIPANT	\N	PRESENT	0
78637	78620	97011G	PARTICIPANT	\N	PRESENT	0
78638	78620	08065C	PARTICIPANT	\N	EXCUSE	0
78642	78620	14014Q	PARTICIPANT	\N	PRESENT	0
78643	78620	11015D	PARTICIPANT	\N	PRESENT	0
78644	78620	07004J	PARTICIPANT	\N	PRESENT	0
78645	78620	95035G	PARTICIPANT	\N	PRESENT	0
78646	78620	08056B	PARTICIPANT	\N	PRESENT	0
78647	78620	14211G	PARTICIPANT	\N	PRESENT	0
78649	78620	11064N	PARTICIPANT	\N	PRESENT	0
78650	78620	95037J	PARTICIPANT	\N	PRESENT	0
78652	78620	14097Y	PARTICIPANT	\N	PRESENT	0
78653	78620	95041E	PARTICIPANT	\N	PRESENT	0
78654	78620	04036E	PARTICIPANT	\N	PRESENT	0
78656	78620	04077P	PARTICIPANT	\N	PRESENT	0
78657	78620	98005N	PARTICIPANT	\N	PRESENT	0
78658	78620	92031P	PARTICIPANT	\N	PRESENT	0
78659	78620	11106F	PARTICIPANT	\N	PRESENT	0
78660	78620	14251Q	PARTICIPANT	\N	PRESENT	0
88092	87188	11066Q	PARTICIPANT	\N	PRESENT	0
88093	87188	11097X	PARTICIPANT	\N	PRESENT	0
88094	87188	08035V	PARTICIPANT	\N	PRESENT	0
88095	87188	07034Q	PARTICIPANT	\N	PRESENT	0
88096	87188	14061L	PARTICIPANT	\N	PRESENT	0
88097	87188	14241N	PARTICIPANT	\N	PRESENT	0
88098	87188	04061F	PARTICIPANT	\N	PRESENT	0
88099	87188	04053F	PARTICIPANT	\N	PRESENT	0
88100	87188	14014Q	PARTICIPANT	\N	PRESENT	0
88101	87188	01034P	PARTICIPANT	\N	PRESENT	0
88102	87188	01043Q	PARTICIPANT	\N	PRESENT	0
88103	87188	14327T	PARTICIPANT	\N	PRESENT	0
88104	87188	04040A	PARTICIPANT	\N	PRESENT	0
88105	87188	08056B	PARTICIPANT	\N	PRESENT	0
88106	87188	01047U	PARTICIPANT	\N	PRESENT	0
88107	87188	08009T	PARTICIPANT	\N	PRESENT	0
88108	87188	95035G	PARTICIPANT	\N	PRESENT	0
88109	87188	14255U	PARTICIPANT	\N	PRESENT	0
88110	87188	11070L	PARTICIPANT	\N	PRESENT	0
88111	87188	04080J	PARTICIPANT	\N	PRESENT	0
88112	87188	98042T	PARTICIPANT	\N	PRESENT	0
88113	87188	01024M	PARTICIPANT	\N	PRESENT	0
88114	87188	14205J	PARTICIPANT	\N	PRESENT	0
88115	87188	14267Y	PARTICIPANT	\N	PRESENT	0
88116	87188	14103D	PARTICIPANT	\N	PRESENT	0
88117	87188	11111C	PARTICIPANT	\N	PRESENT	0
88118	87188	14275Y	PARTICIPANT	\N	PRESENT	0
88119	87188	97011G	PARTICIPANT	\N	PRESENT	0
88120	87188	77002U	PARTICIPANT	\N	PRESENT	0
88121	87188	14083S	PARTICIPANT	\N	PRESENT	0
90806	89310	08060W	PARTICIPANT	\N	PRESENT	0
88123	87188	14093U	PARTICIPANT	\N	PRESENT	0
90804	89310	14133K	PARTICIPANT	\N	PRESENT	0
88125	87188	04042C	PARTICIPANT	\N	PRESENT	0
88126	87188	01013J	PARTICIPANT	\N	PRESENT	0
88127	87188	14235Q	PARTICIPANT	\N	PRESENT	0
88128	87188	04054G	PARTICIPANT	\N	PRESENT	0
88129	87188	07029T	PARTICIPANT	\N	PRESENT	0
88130	87188	11034G	PARTICIPANT	\N	PRESENT	0
88131	87188	08011M	PARTICIPANT	\N	PRESENT	0
88132	87188	98023Q	PARTICIPANT	\N	PRESENT	0
88133	87188	11101A	PARTICIPANT	\N	PRESENT	0
88134	87188	01027Q	PARTICIPANT	\N	PRESENT	0
88135	87188	14197C	PARTICIPANT	\N	PRESENT	0
88136	87188	11076S	PARTICIPANT	\N	PRESENT	0
88137	87188	14173T	PARTICIPANT	\N	PRESENT	0
88138	87188	14123H	PARTICIPANT	\N	PRESENT	0
88139	87188	14179A	PARTICIPANT	\N	PRESENT	0
88140	87188	14089Y	PARTICIPANT	\N	PRESENT	0
88141	87188	95059Q	PARTICIPANT	\N	PRESENT	0
88142	87188	14209N	PARTICIPANT	\N	PRESENT	0
88143	87188	08065C	PARTICIPANT	\N	PRESENT	0
88144	87188	11020A	PARTICIPANT	\N	PRESENT	0
88145	87188	04071H	PARTICIPANT	\N	PRESENT	0
88146	87188	01016M	PARTICIPANT	\N	PRESENT	0
88147	87188	08047A	PARTICIPANT	\N	PRESENT	0
88148	87188	98029W	PARTICIPANT	\N	PRESENT	0
88149	87188	08010L	PARTICIPANT	\N	PRESENT	0
88150	87188	14041T	PARTICIPANT	\N	PRESENT	0
88151	87188	11088W	PARTICIPANT	\N	PRESENT	0
88152	87188	14215L	PARTICIPANT	\N	PRESENT	0
88153	87188	14199E	PARTICIPANT	\N	PRESENT	0
88154	87188	11048N	PARTICIPANT	\N	PRESENT	0
88155	87188	08039A	PARTICIPANT	\N	PRESENT	0
88156	87188	05012A	PARTICIPANT	\N	PRESENT	0
88157	87188	14053L	PARTICIPANT	\N	PRESENT	0
88158	87188	11053K	PARTICIPANT	\N	PRESENT	0
90805	89310	11090Q	PARTICIPANT	\N	PRESENT	0
88160	87188	14034U	PARTICIPANT	\N	PRESENT	0
88161	87188	07004J	PARTICIPANT	\N	PRESENT	0
88162	87188	04078Q	PARTICIPANT	\N	PRESENT	0
88163	87188	08044W	PARTICIPANT	\N	PRESENT	0
88164	87188	14157T	PARTICIPANT	\N	PRESENT	0
88165	87188	05004A	PARTICIPANT	\N	PRESENT	0
88166	87188	01014K	PARTICIPANT	\N	PRESENT	0
88167	87188	14018U	PARTICIPANT	\N	PRESENT	0
88168	87188	08060W	PARTICIPANT	\N	PRESENT	0
88169	87188	04047H	PARTICIPANT	\N	PRESENT	0
88170	87188	14225N	PARTICIPANT	\N	PRESENT	0
88171	87188	11090Q	PARTICIPANT	\N	PRESENT	0
88172	87188	14135M	PARTICIPANT	\N	PRESENT	0
88173	87188	10015M	PARTICIPANT	\N	PRESENT	0
88174	87188	11044J	PARTICIPANT	\N	PRESENT	0
88175	87188	90003B	PARTICIPANT	\N	PRESENT	0
88176	87188	14195A	PARTICIPANT	\N	PRESENT	0
88177	87188	98053W	PARTICIPANT	\N	PRESENT	0
88178	87188	11037K	PARTICIPANT	\N	PRESENT	0
88179	87188	11112D	PARTICIPANT	\N	PRESENT	0
88180	87188	14237S	PARTICIPANT	\N	PRESENT	0
88181	87188	01007L	PARTICIPANT	\N	PRESENT	0
88182	87188	14271U	PARTICIPANT	\N	PRESENT	0
88183	87188	04045F	PARTICIPANT	\N	PRESENT	0
88184	87188	95037J	PARTICIPANT	\N	PRESENT	0
88185	87188	01003G	PARTICIPANT	\N	PRESENT	0
88186	87188	01056V	PARTICIPANT	\N	PRESENT	0
88187	87188	11015D	PARTICIPANT	\N	PRESENT	0
88188	87188	08028W	PARTICIPANT	\N	PRESENT	0
88189	87188	08038Y	PARTICIPANT	\N	PRESENT	0
88190	87188	14269B	PARTICIPANT	\N	PRESENT	0
88191	87188	13002U	PARTICIPANT	\N	PRESENT	0
88192	87188	08043V	PARTICIPANT	\N	PRESENT	0
88193	87188	11032E	PARTICIPANT	\N	PRESENT	0
88194	87188	11083R	PARTICIPANT	\N	PRESENT	0
88195	87188	11074Q	PARTICIPANT	\N	PRESENT	0
88196	87188	89017R	PARTICIPANT	\N	PRESENT	0
88197	87188	11064N	PARTICIPANT	\N	PRESENT	0
88198	87188	11068S	PARTICIPANT	\N	PRESENT	0
88199	87188	04055H	PARTICIPANT	\N	PRESENT	0
88200	87188	14257W	PARTICIPANT	\N	PRESENT	0
88201	87188	14219Q	PARTICIPANT	\N	PRESENT	0
88202	87188	11055M	PARTICIPANT	\N	PRESENT	0
90807	89310	92015P	PARTICIPANT	\N	PRESENT	0
90808	89310	01022K	PARTICIPANT	\N	PRESENT	0
90809	89310	14051J	PARTICIPANT	\N	PRESENT	0
90810	89310	11023D	PARTICIPANT	\N	PRESENT	0
90811	89310	11114F	PARTICIPANT	\N	PRESENT	0
90812	89310	14271U	PARTICIPANT	\N	PRESENT	0
90813	89310	14331P	PARTICIPANT	\N	PRESENT	0
90814	89310	14265W	PARTICIPANT	\N	PRESENT	0
90815	89310	08055A	PARTICIPANT	\N	PRESENT	0
90816	89310	08069G	PARTICIPANT	\N	PRESENT	0
90817	89310	14191V	PARTICIPANT	\N	PRESENT	0
90818	89310	95062K	PARTICIPANT	\N	PRESENT	0
90819	89310	11103C	PARTICIPANT	\N	PRESENT	0
90820	89310	11111C	PARTICIPANT	\N	PRESENT	0
90821	89310	14273W	PARTICIPANT	\N	PRESENT	0
90822	89310	08048B	PARTICIPANT	\N	PRESENT	0
90823	89310	14157T	PARTICIPANT	\N	PRESENT	0
90824	89310	04080J	PARTICIPANT	\N	PRESENT	0
90825	89310	95049N	PARTICIPANT	\N	PRESENT	0
90826	89310	08068F	PARTICIPANT	\N	PRESENT	0
90827	89310	01008M	PARTICIPANT	\N	PRESENT	0
90828	89310	09001P	PARTICIPANT	\N	PRESENT	0
90829	89310	14083S	PARTICIPANT	\N	PRESENT	0
90830	89310	14069U	PARTICIPANT	\N	PRESENT	0
90831	89310	14259Y	PARTICIPANT	\N	PRESENT	0
90832	89310	04053F	PARTICIPANT	\N	PRESENT	0
90833	89310	14237S	PARTICIPANT	\N	PRESENT	0
90834	89310	04038G	PARTICIPANT	\N	PRESENT	0
90835	89310	11012A	PARTICIPANT	\N	PRESENT	0
90836	89310	04034C	PARTICIPANT	\N	PRESENT	0
90837	89310	14327T	PARTICIPANT	\N	PRESENT	0
90838	89310	14030Q	PARTICIPANT	\N	PRESENT	0
90839	89310	11084S	PARTICIPANT	\N	PRESENT	0
90840	89310	14147R	PARTICIPANT	\N	PRESENT	0
90841	89310	14215L	PARTICIPANT	\N	PRESENT	0
90847	89310	04097T	PARTICIPANT	\N	PRESENT	0
90849	89310	14031R	PARTICIPANT	\N	PRESENT	0
90878	89310	08016S	PARTICIPANT	\N	PRESENT	0
90879	89310	11036J	PARTICIPANT	\N	PRESENT	0
90887	89310	14063N	PARTICIPANT	\N	PRESENT	0
90890	89310	11104D	PARTICIPANT	\N	PRESENT	0
90891	89310	04088S	PARTICIPANT	\N	PRESENT	0
90892	89310	14059S	PARTICIPANT	\N	PRESENT	0
90893	89310	80013X	PARTICIPANT	\N	PRESENT	0
90894	89310	05012A	PARTICIPANT	\N	PRESENT	0
90895	89310	14223L	PARTICIPANT	\N	PRESENT	0
90896	89310	14187A	PARTICIPANT	\N	PRESENT	0
90897	89310	11098Y	PARTICIPANT	\N	PRESENT	0
90898	89310	14241N	PARTICIPANT	\N	PRESENT	0
90899	89310	95030B	PARTICIPANT	\N	PRESENT	0
90900	89310	11029K	PARTICIPANT	\N	PRESENT	0
90901	89310	14257W	PARTICIPANT	\N	PRESENT	0
90902	89310	92039X	PARTICIPANT	\N	PRESENT	0
90903	89310	11093T	PARTICIPANT	\N	PRESENT	0
90904	89310	14179A	PARTICIPANT	\N	PRESENT	0
90908	89310	14018U	PARTICIPANT	\N	PRESENT	0
90919	89310	01043Q	PARTICIPANT	\N	PRESENT	0
62715	62714	05008E	PRESIDENT	0	PRESENT	0
62600	62598	08055A	PARTICIPANT	\N	EXCUSE	0
62601	62598	14093U	PARTICIPANT	\N	PRESENT	0
62602	62598	14030Q	PARTICIPANT	\N	PRESENT	0
62603	62598	96004D	PARTICIPANT	\N	EXCUSE	0
62716	62714	04047H	PARTICIPANT	\N	PRESENT	0
62605	62598	11095V	PARTICIPANT	\N	PRESENT	0
62606	62598	14038Y	PARTICIPANT	\N	PRESENT	0
62607	62598	11114F	PARTICIPANT	\N	PRESENT	0
62717	62714	01024M	PARTICIPANT	\N	PRESENT	0
62609	62598	11065P	PARTICIPANT	\N	PRESENT	0
62610	62598	01015L	PARTICIPANT	\N	EXCUSE	0
62611	62598	11107G	PARTICIPANT	\N	PRESENT	0
62718	62714	14001X	PARTICIPANT	\N	PRESENT	0
62613	62598	02002K	PARTICIPANT	\N	PRESENT	0
62614	62598	01022K	PARTICIPANT	\N	PRESENT	0
62615	62598	04097T	PARTICIPANT	\N	EXCUSE	0
62616	62598	09001P	PARTICIPANT	\N	PRESENT	0
62617	62598	11059R	PARTICIPANT	\N	PRESENT	0
62618	62598	14219Q	PARTICIPANT	\N	PRESENT	0
62619	62598	80027E	PARTICIPANT	\N	PRESENT	0
62620	62598	14031R	PARTICIPANT	\N	PRESENT	0
62621	62598	08009T	PRESIDENT	0	PRESENT	0
62622	62598	08062Y	PARTICIPANT	\N	PRESENT	0
62623	62598	14221J	PARTICIPANT	\N	PRESENT	0
62624	62598	92039X	PARTICIPANT	\N	PRESENT	0
62719	62714	14273W	PARTICIPANT	\N	PRESENT	0
62626	62598	14169X	PARTICIPANT	\N	PRESENT	0
62627	62598	14237S	PARTICIPANT	\N	PRESENT	0
62628	62598	13002U	PARTICIPANT	\N	PRESENT	0
62629	62598	05012A	PARTICIPANT	\N	PRESENT	0
62720	62714	14147R	PARTICIPANT	\N	PRESENT	0
62631	62598	14135M	PARTICIPANT	\N	EXCUSE	0
62632	62598	14331P	PARTICIPANT	\N	PRESENT	0
62633	62598	95062K	PARTICIPANT	\N	PRESENT	0
62634	62598	14107H	PARTICIPANT	\N	PRESENT	0
62635	62598	14051J	PARTICIPANT	\N	PRESENT	0
62636	62598	14157T	PARTICIPANT	\N	PRESENT	0
62721	62714	95049N	PARTICIPANT	\N	PRESENT	0
62722	62714	07034Q	PARTICIPANT	\N	PRESENT	0
62723	62714	92045V	PARTICIPANT	\N	PRESENT	0
62724	62714	04034C	PARTICIPANT	\N	PRESENT	0
62725	62714	14026U	PARTICIPANT	\N	PRESENT	0
62726	62714	97011G	PARTICIPANT	\N	PRESENT	0
62727	62714	11083R	PARTICIPANT	\N	PRESENT	0
62728	62714	95030B	PARTICIPANT	\N	PRESENT	0
62729	62714	14089Y	PARTICIPANT	\N	PRESENT	0
62730	62714	04045F	PARTICIPANT	\N	PRESENT	0
62731	62714	01016M	PARTICIPANT	\N	PRESENT	0
62732	62714	04035D	PARTICIPANT	\N	PRESENT	0
62733	62714	04061F	PARTICIPANT	\N	PRESENT	0
66248	63994	14071N	PARTICIPANT	\N	PRESENT	0
66249	63994	14231L	PARTICIPANT	\N	PRESENT	0
66250	63994	14051J	PARTICIPANT	\N	PRESENT	0
66251	63994	11037K	PARTICIPANT	\N	PRESENT	0
66252	63994	08038Y	PARTICIPANT	\N	PRESENT	0
66253	63994	11101A	PARTICIPANT	\N	PRESENT	0
66254	63995	05012A	PARTICIPANT	\N	PRESENT	0
66255	63995	11101A	PARTICIPANT	\N	PRESENT	0
66256	63995	08038Y	PARTICIPANT	\N	PRESENT	0
66257	63995	92040Q	PARTICIPANT	\N	PRESENT	0
66258	63995	04044E	PARTICIPANT	\N	PRESENT	0
66259	63996	05012A	PARTICIPANT	\N	PRESENT	0
66260	63996	11101A	PARTICIPANT	\N	PRESENT	0
66261	63996	08038Y	PARTICIPANT	\N	PRESENT	0
66262	63996	11099A	PARTICIPANT	\N	PRESENT	0
66263	63996	14051J	PARTICIPANT	\N	PRESENT	0
66264	63996	04045F	PARTICIPANT	\N	PRESENT	0
66430	66429	92039X	PARTICIPANT	\N	PRESENT	0
74221	71331	14033T	PARTICIPANT	\N	EXCUSE	0
74997	74996	14065Q	PARTICIPANT	\N	PRESENT	0
74998	74996	04040A	PARTICIPANT	\N	PRESENT	0
74999	74996	08018U	PARTICIPANT	\N	PRESENT	0
75000	74996	14063N	PARTICIPANT	\N	PRESENT	0
75001	74996	89017R	PARTICIPANT	\N	PRESENT	0
75050	75049	98046X	PARTICIPANT	\N	PRESENT	0
75693	75690	89017R	PARTICIPANT	\N	PRESENT	0
75754	75753	08022Q	PARTICIPANT	\N	PRESENT	0
75755	75753	08061X	PARTICIPANT	\N	PRESENT	0
75756	75753	98053W	PARTICIPANT	\N	PRESENT	0
75757	75753	04061F	PARTICIPANT	\N	PRESENT	0
75766	75765	14273W	PARTICIPANT	\N	PRESENT	0
76540	76539	01008M	PARTICIPANT	\N	PRESENT	0
76541	76539	11036J	PARTICIPANT	\N	PRESENT	0
76542	76539	11081P	PARTICIPANT	\N	PRESENT	0
76543	76539	14013P	PARTICIPANT	\N	PRESENT	0
76544	76539	08068F	PARTICIPANT	\N	PRESENT	0
76545	76539	14207L	PARTICIPANT	\N	PRESENT	0
76622	76621	11076S	PARTICIPANT	\N	PRESENT	0
76547	76539	90003B	PARTICIPANT	\N	PRESENT	0
76548	76539	08028W	PARTICIPANT	\N	PRESENT	0
76549	76539	80013X	PARTICIPANT	\N	PRESENT	0
76550	76539	08038Y	PARTICIPANT	\N	PRESENT	0
76551	76539	04089T	PARTICIPANT	\N	PRESENT	0
76552	76539	14197C	PARTICIPANT	\N	PRESENT	0
76553	76539	11110B	PARTICIPANT	\N	PRESENT	0
76554	76539	14187A	PARTICIPANT	\N	PRESENT	0
76555	76539	14033T	PARTICIPANT	\N	PRESENT	0
76623	76621	04054G	PARTICIPANT	\N	PRESENT	0
76624	76621	04040A	PARTICIPANT	\N	PRESENT	0
76625	76621	08058D	PARTICIPANT	\N	PRESENT	0
76559	76539	04049K	PARTICIPANT	\N	PRESENT	0
76560	76539	04094Q	PARTICIPANT	\N	PRESENT	0
76561	76539	11111C	PARTICIPANT	\N	PRESENT	0
76562	76539	08015R	PARTICIPANT	\N	PRESENT	0
76563	76539	11100Y	PRESIDENT	0	PRESENT	0
76564	76539	01061S	PARTICIPANT	\N	PRESENT	0
76565	76539	11098Y	PARTICIPANT	\N	PRESENT	0
76566	76539	01043Q	PARTICIPANT	\N	PRESENT	0
76567	76539	11077T	PARTICIPANT	\N	PRESENT	0
76568	76539	14205J	PARTICIPANT	\N	PRESENT	0
76626	76621	04042C	PRESIDENT	0	PRESENT	0
76627	76621	77002U	PARTICIPANT	\N	PRESENT	0
76571	76539	08021P	PARTICIPANT	\N	EXCUSE	0
76572	76539	04088S	PARTICIPANT	\N	PRESENT	0
76628	76621	98029W	PARTICIPANT	\N	PRESENT	0
76629	76621	11027H	PARTICIPANT	\N	PRESENT	0
76630	76621	98018T	PARTICIPANT	\N	EXCUSE	0
76576	76539	01058X	PARTICIPANT	\N	PRESENT	0
76577	76539	11094U	PARTICIPANT	\N	PRESENT	0
76578	76539	11066Q	PARTICIPANT	\N	PRESENT	0
76579	76539	11101A	PARTICIPANT	\N	EXCUSE	0
76631	76621	92018S	PARTICIPANT	\N	EXCUSE	0
76632	76621	92020L	PARTICIPANT	\N	EXCUSE	0
76633	76621	95030B	PARTICIPANT	\N	PRESENT	0
76634	76621	97011G	PARTICIPANT	\N	PRESENT	0
76635	76621	04035D	PARTICIPANT	\N	EXCUSE	0
76636	76621	07024N	PARTICIPANT	\N	EXCUSE	0
76637	76621	14014Q	PARTICIPANT	\N	PRESENT	0
76638	76621	95035G	PARTICIPANT	\N	PRESENT	0
76639	76621	08056B	PARTICIPANT	\N	PRESENT	0
76640	76621	98022P	PARTICIPANT	\N	PRESENT	0
76641	76621	11064N	PARTICIPANT	\N	PRESENT	0
76642	76621	95037J	PARTICIPANT	\N	PRESENT	0
76643	76621	04078Q	PARTICIPANT	\N	PRESENT	0
76644	76621	14097Y	PARTICIPANT	\N	PRESENT	0
76645	76621	04036E	PARTICIPANT	\N	PRESENT	0
76646	76621	04077P	PARTICIPANT	\N	PRESENT	0
76647	76621	98005N	PARTICIPANT	\N	PRESENT	0
76648	76621	92031P	PARTICIPANT	\N	PRESENT	0
76649	76621	11106F	PARTICIPANT	\N	PRESENT	0
76650	76621	14251Q	PARTICIPANT	\N	PRESENT	0
76651	76621	83042R	PARTICIPANT	\N	PRESENT	0
76652	76621	08053X	PARTICIPANT	\N	PRESENT	0
76653	76621	11082Q	PARTICIPANT	\N	PRESENT	0
76654	76621	11105E	PARTICIPANT	\N	PRESENT	0
76655	76621	14253S	PARTICIPANT	\N	PRESENT	0
76656	76621	08047A	PARTICIPANT	\N	PRESENT	0
76657	76621	14028W	PARTICIPANT	\N	PRESENT	0
76658	76621	98021N	PARTICIPANT	\N	PRESENT	0
76659	76621	95059Q	PARTICIPANT	\N	EXCUSE	0
76660	76621	86044G	PARTICIPANT	\N	PRESENT	0
76661	76621	01014K	PARTICIPANT	\N	PRESENT	0
76662	76621	11054L	PARTICIPANT	\N	PRESENT	0
76663	76621	01056V	PARTICIPANT	\N	EXCUSE	0
76664	76621	08049C	PARTICIPANT	\N	EXCUSE	0
77435	77432	14133K	PARTICIPANT	\N	PRESENT	0
77436	77432	96004D	PRESIDENT	0	PRESENT	0
77437	77432	11040E	PARTICIPANT	\N	PRESENT	0
77438	77432	11035H	PARTICIPANT	\N	PRESENT	0
77439	77432	14249W	PARTICIPANT	\N	PRESENT	0
77440	77432	11083R	PARTICIPANT	\N	PRESENT	0
77441	77432	14097Y	PARTICIPANT	\N	PRESENT	0
77442	77432	11026G	PARTICIPANT	\N	PRESENT	0
77443	77432	98046X	PARTICIPANT	\N	EXCUSE	0
77444	77432	04057K	PARTICIPANT	\N	PRESENT	0
77445	77432	14135M	PARTICIPANT	\N	PRESENT	0
77446	77432	01016M	PARTICIPANT	\N	PRESENT	0
77447	77432	10015M	PARTICIPANT	\N	PRESENT	0
86378	86373	14193X	PARTICIPANT	\N	PRESENT	0
86379	86373	11054L	PARTICIPANT	\N	PRESENT	0
86382	85516	11084S	PARTICIPANT	\N	PRESENT	0
86397	86394	07024N	PARTICIPANT	\N	PRESENT	0
86399	86394	01014K	PARTICIPANT	\N	PRESENT	0
86400	86394	04040A	PARTICIPANT	\N	PRESENT	0
86401	86394	11106F	PARTICIPANT	\N	PRESENT	0
86402	86394	14193X	PARTICIPANT	\N	PRESENT	0
86659	85517	04081K	PARTICIPANT	\N	PRESENT	0
86660	85517	05008E	PARTICIPANT	\N	PRESENT	0
86661	85517	08018U	PARTICIPANT	\N	PRESENT	0
86662	85517	04036E	PARTICIPANT	\N	PRESENT	0
86663	85517	04041B	PARTICIPANT	\N	PRESENT	0
86664	85517	07029T	PARTICIPANT	\N	PRESENT	0
86665	85517	14273W	PARTICIPANT	\N	PRESENT	0
86666	85517	01059Y	PARTICIPANT	\N	PRESENT	0
86667	85517	14013P	PARTICIPANT	\N	PRESENT	0
86668	85517	01015L	PARTICIPANT	\N	PRESENT	0
86669	85517	11098Y	PARTICIPANT	\N	PRESENT	0
86670	85517	11107G	PARTICIPANT	\N	PRESENT	0
86671	85517	14219Q	PARTICIPANT	\N	PRESENT	0
86672	85517	01043Q	PARTICIPANT	\N	PRESENT	0
86673	85517	14159V	PARTICIPANT	\N	PRESENT	0
86674	85517	11012A	PARTICIPANT	\N	PRESENT	0
86675	85517	08009T	PARTICIPANT	\N	PRESENT	0
86676	85517	11089X	PARTICIPANT	\N	PRESENT	0
86677	85517	04086Q	PARTICIPANT	\N	PRESENT	0
86678	85517	09001P	PARTICIPANT	\N	PRESENT	0
86679	85517	07024N	PARTICIPANT	\N	PRESENT	0
86680	85517	10006L	PARTICIPANT	\N	PRESENT	0
86681	85517	14033T	PARTICIPANT	\N	PRESENT	0
86682	85517	80013X	PARTICIPANT	\N	PRESENT	0
86683	85517	11095V	PARTICIPANT	\N	PRESENT	0
86684	85517	08010L	PARTICIPANT	\N	PRESENT	0
86685	85517	14179A	PARTICIPANT	\N	PRESENT	0
86686	85517	01037S	PARTICIPANT	\N	PRESENT	0
86687	85517	11046L	PARTICIPANT	\N	PRESENT	0
86688	85517	04059M	PARTICIPANT	\N	PRESENT	0
86689	85517	14257W	PARTICIPANT	\N	PRESENT	0
86690	85517	14073Q	PARTICIPANT	\N	PRESENT	0
86691	85517	14089Y	PARTICIPANT	\N	PRESENT	0
86692	85517	07026Q	PARTICIPANT	\N	PRESENT	0
86693	85517	14038Y	PARTICIPANT	\N	PRESENT	0
86694	85517	01016M	PARTICIPANT	\N	PRESENT	0
86695	85517	11103C	PARTICIPANT	\N	PRESENT	0
86696	85517	08031R	PARTICIPANT	\N	PRESENT	0
86697	85517	14235Q	PARTICIPANT	\N	PRESENT	0
86698	85517	04070G	PARTICIPANT	\N	PRESENT	0
86699	85517	14269B	PARTICIPANT	\N	PRESENT	0
86700	85517	11034G	PARTICIPANT	\N	PRESENT	0
86701	85517	14331P	PARTICIPANT	\N	PRESENT	0
86702	85517	04057K	PARTICIPANT	\N	PRESENT	0
86703	85517	11090Q	PARTICIPANT	\N	PRESENT	0
86704	85517	92015P	PARTICIPANT	\N	PRESENT	0
86705	85517	14169X	PARTICIPANT	\N	PRESENT	0
86706	85517	11036J	PARTICIPANT	\N	PRESENT	0
86707	85517	01058X	PARTICIPANT	\N	PRESENT	0
86708	85517	14034U	PARTICIPANT	\N	PRESENT	0
86709	85517	04088S	PARTICIPANT	\N	PRESENT	0
86710	85517	11029K	PARTICIPANT	\N	PRESENT	0
86711	85517	08043V	PARTICIPANT	\N	PRESENT	0
86712	85517	14151M	PARTICIPANT	\N	PRESENT	0
86713	85517	01013J	PARTICIPANT	\N	PRESENT	0
86714	85517	14135M	PARTICIPANT	\N	PRESENT	0
86715	85517	99004R	PARTICIPANT	\N	PRESENT	0
86716	85517	14039A	PARTICIPANT	\N	PRESENT	0
86717	85517	01031L	PARTICIPANT	\N	PRESENT	0
86718	85517	04095R	PARTICIPANT	\N	PRESENT	0
86720	85517	08019V	PARTICIPANT	\N	PRESENT	0
86725	85517	11027H	PARTICIPANT	\N	PRESENT	0
86726	85517	11011M	PARTICIPANT	\N	PRESENT	0
86727	85517	08034U	PARTICIPANT	\N	PRESENT	0
86728	85517	04035D	PARTICIPANT	\N	PRESENT	0
86729	85517	11048N	PARTICIPANT	\N	PRESENT	0
86730	85517	11026G	PARTICIPANT	\N	PRESENT	0
86745	85517	04085P	PARTICIPANT	\N	PRESENT	0
86762	85517	08055A	PARTICIPANT	\N	PRESENT	0
86780	85517	01028R	PARTICIPANT	\N	PRESENT	0
86781	85517	98018T	PARTICIPANT	\N	PRESENT	0
86782	85517	11082Q	PARTICIPANT	\N	PRESENT	0
86816	85518	11046L	PARTICIPANT	\N	PRESENT	0
86817	85518	11089X	PARTICIPANT	\N	PRESENT	0
86818	85518	11095V	PARTICIPANT	\N	PRESENT	0
86819	85518	08018U	PARTICIPANT	\N	PRESENT	0
86820	85518	14179A	PARTICIPANT	\N	PRESENT	0
86821	85518	14038Y	PARTICIPANT	\N	PRESENT	0
86822	85518	11012A	PARTICIPANT	\N	PRESENT	0
86823	85518	04085P	PARTICIPANT	\N	PRESENT	0
86824	85518	04086Q	PARTICIPANT	\N	PRESENT	0
86825	85518	11026G	PARTICIPANT	\N	PRESENT	0
86826	85518	11027H	PARTICIPANT	\N	PRESENT	0
86827	85518	95063L	PARTICIPANT	\N	PRESENT	0
86828	85518	04070G	PARTICIPANT	\N	PRESENT	0
86829	85518	01028R	PARTICIPANT	\N	PRESENT	0
86830	85518	04034C	PARTICIPANT	\N	PRESENT	0
86831	85518	01031L	PARTICIPANT	\N	PRESENT	0
86832	85518	80013X	PARTICIPANT	\N	PRESENT	0
86833	85518	11029K	PARTICIPANT	\N	PRESENT	0
86834	85518	05008E	PARTICIPANT	\N	PRESENT	0
86835	85518	14169X	PARTICIPANT	\N	PRESENT	0
86836	85518	04059M	PARTICIPANT	\N	PRESENT	0
86837	85518	08019V	PARTICIPANT	\N	PRESENT	0
86852	85519	11085T	PARTICIPANT	\N	PRESENT	0
86853	85519	07026Q	PARTICIPANT	\N	PRESENT	0
86854	85519	80013X	PARTICIPANT	\N	PRESENT	0
86855	85519	98046X	PARTICIPANT	\N	PRESENT	0
86856	85519	11046L	PARTICIPANT	\N	PRESENT	0
86857	85519	04059M	PARTICIPANT	\N	PRESENT	0
86858	85519	11026G	PARTICIPANT	\N	PRESENT	0
86859	85519	08009T	PARTICIPANT	\N	PRESENT	0
86860	85519	08018U	PARTICIPANT	\N	PRESENT	0
86814	85518	11085T	PARTICIPANT	\N	PRESENT	0
86815	85518	14013P	PARTICIPANT	\N	PRESENT	0
86861	85519	08019V	PARTICIPANT	\N	PRESENT	0
86862	85519	14169X	PARTICIPANT	\N	PRESENT	0
86863	85519	04086Q	PARTICIPANT	\N	PRESENT	0
86864	85519	11029K	PARTICIPANT	\N	PRESENT	0
86865	85519	14038Y	PARTICIPANT	\N	PRESENT	0
86866	85519	11012A	PARTICIPANT	\N	PRESENT	0
86867	85519	05008E	PARTICIPANT	\N	PRESENT	0
86868	85519	01058X	PARTICIPANT	\N	PRESENT	0
86869	85519	11011M	PARTICIPANT	\N	PRESENT	0
86871	86870	11100Y	PARTICIPANT	\N	PRESENT	0
86872	86870	14013P	PARTICIPANT	\N	PRESENT	0
86873	86870	08068F	PARTICIPANT	\N	PRESENT	0
86874	86870	14207L	PARTICIPANT	\N	PRESENT	0
86875	86870	80013X	PARTICIPANT	\N	PRESENT	0
86876	86870	14197C	PARTICIPANT	\N	PRESENT	0
86877	86870	14033T	PARTICIPANT	\N	PRESENT	0
86878	86870	11098Y	PARTICIPANT	\N	PRESENT	0
86879	86870	11077T	PARTICIPANT	\N	PRESENT	0
86880	86870	08019V	PARTICIPANT	\N	PRESENT	0
86881	86870	14257W	PARTICIPANT	\N	PRESENT	0
86882	86870	11094U	PARTICIPANT	\N	PRESENT	0
86883	85519	04085P	PARTICIPANT	\N	PRESENT	0
86885	86884	08028W	PARTICIPANT	\N	PRESENT	0
86886	86884	08068F	PARTICIPANT	\N	PRESENT	0
86887	86884	14033T	PARTICIPANT	\N	PRESENT	0
86888	86884	14205J	PARTICIPANT	\N	PRESENT	0
86890	86889	14187A	PARTICIPANT	\N	PRESENT	0
86891	86889	01043Q	PARTICIPANT	\N	PRESENT	0
86894	86893	01043Q	PARTICIPANT	\N	PRESENT	0
86901	85519	04071H	PARTICIPANT	\N	PRESENT	0
86902	85519	11095V	PARTICIPANT	\N	PRESENT	0
86944	85520	80013X	PARTICIPANT	\N	PRESENT	0
86945	85520	04086Q	PARTICIPANT	\N	PRESENT	0
86946	85520	11072N	PARTICIPANT	\N	PRESENT	0
86947	85520	11029K	PARTICIPANT	\N	PRESENT	0
86948	85520	08018U	PARTICIPANT	\N	PRESENT	0
86949	85520	14038Y	PARTICIPANT	\N	PRESENT	0
86950	85520	04085P	PARTICIPANT	\N	PRESENT	0
86951	85520	11091R	PARTICIPANT	\N	PRESENT	0
86952	85520	14169X	PARTICIPANT	\N	PRESENT	0
86953	85520	11046L	PARTICIPANT	\N	PRESENT	0
86954	85520	11095V	PARTICIPANT	\N	PRESENT	0
86955	85520	04057K	PARTICIPANT	\N	PRESENT	0
86956	85520	14269B	PARTICIPANT	\N	PRESENT	0
86957	85520	08019V	PARTICIPANT	\N	PRESENT	0
86958	85520	05008E	PARTICIPANT	\N	PRESENT	0
86969	85520	11027H	PARTICIPANT	\N	PRESENT	0
86970	85520	11114F	PARTICIPANT	\N	PRESENT	0
86971	85520	99004R	PARTICIPANT	\N	PRESENT	0
86942	85520	11085T	PARTICIPANT	\N	PRESENT	0
86943	85520	07026Q	PARTICIPANT	\N	PRESENT	0
86972	85520	08009T	PARTICIPANT	\N	PRESENT	0
86977	85520	04035D	PARTICIPANT	\N	PRESENT	0
86980	85520	14042U	PARTICIPANT	\N	PRESENT	0
86981	85520	14261S	PARTICIPANT	\N	PRESENT	0
62735	62734	01031L	PARTICIPANT	\N	PRESENT	0
62736	62734	08009T	PARTICIPANT	\N	PRESENT	0
62737	62734	98018T	PARTICIPANT	\N	PRESENT	0
66290	66289	14251Q	PARTICIPANT	\N	PRESENT	0
66291	66289	95037J	PARTICIPANT	\N	PRESENT	0
66294	66293	14251Q	PARTICIPANT	\N	PRESENT	0
68563	68562	14239U	PARTICIPANT	\N	PRESENT	0
69420	69419	11061K	PARTICIPANT	\N	PRESENT	0
68565	68562	01046T	PARTICIPANT	\N	PRESENT	0
69421	69419	11093T	PARTICIPANT	\N	PRESENT	0
68567	68562	14255U	PARTICIPANT	\N	PRESENT	0
69424	69423	14087W	PARTICIPANT	\N	PRESENT	0
68569	68562	00003C	PARTICIPANT	\N	PRESENT	0
68570	68562	14053L	PARTICIPANT	\N	PRESENT	0
68571	68562	11103C	PARTICIPANT	\N	PRESENT	0
68572	68562	11044J	PARTICIPANT	\N	PRESENT	0
68573	68562	14195A	PARTICIPANT	\N	PRESENT	0
68574	68562	14267Y	PARTICIPANT	\N	PRESENT	0
72047	56945	11032E	PARTICIPANT	\N	EXCUSE	0
68576	68562	11031D	PARTICIPANT	\N	PRESENT	0
68577	68562	08052W	PARTICIPANT	\N	PRESENT	0
72048	56945	04044E	PARTICIPANT	\N	EXCUSE	0
68579	68562	04081K	PARTICIPANT	\N	EXCUSE	0
68580	68562	98024R	PARTICIPANT	\N	PRESENT	0
68581	68562	10006L	PARTICIPANT	\N	PRESENT	0
78661	78620	83042R	PARTICIPANT	\N	PRESENT	0
68583	68562	14217N	PARTICIPANT	\N	PRESENT	0
68584	68562	14042U	PARTICIPANT	\N	PRESENT	0
68585	68562	14151M	PARTICIPANT	\N	EXCUSE	0
68586	68562	12042Y	PARTICIPANT	\N	PRESENT	0
68587	68562	14281W	PARTICIPANT	\N	PRESENT	0
78750	78749	98046X	PARTICIPANT	\N	PRESENT	0
78759	78620	11082Q	PARTICIPANT	\N	PRESENT	0
68590	68562	14034U	PARTICIPANT	\N	PRESENT	0
68591	68562	14231L	PARTICIPANT	\N	PRESENT	0
68592	68562	11061K	PARTICIPANT	\N	PRESENT	0
68593	68562	08048B	PARTICIPANT	\N	PRESENT	0
68594	68562	08041T	PARTICIPANT	\N	PRESENT	0
68595	68562	01011G	PARTICIPANT	\N	PRESENT	0
68596	68562	14026U	PARTICIPANT	\N	PRESENT	0
68597	68562	14213J	PARTICIPANT	\N	PRESENT	0
68598	68562	14121F	PARTICIPANT	\N	PRESENT	0
68599	68562	11112D	PARTICIPANT	\N	PRESENT	0
68600	68562	14037X	PARTICIPANT	\N	PRESENT	0
68601	68562	14018U	PARTICIPANT	\N	PRESENT	0
68602	68562	11067R	PARTICIPANT	\N	PRESENT	0
68603	68562	14223L	PARTICIPANT	\N	PRESENT	0
68604	68562	04092N	PRESIDENT	0	PRESENT	0
68605	68562	14265W	PARTICIPANT	\N	PRESENT	0
68606	68562	14119M	PARTICIPANT	\N	PRESENT	0
68607	68562	14071N	PARTICIPANT	\N	PRESENT	0
68608	68562	07032N	PARTICIPANT	\N	PRESENT	0
68609	68562	04043D	PARTICIPANT	\N	PRESENT	0
68610	68562	14271U	PARTICIPANT	\N	PRESENT	0
78664	78620	11105E	PARTICIPANT	\N	PRESENT	0
68612	68562	11093T	PARTICIPANT	\N	PRESENT	0
68613	68562	11097X	PARTICIPANT	\N	PRESENT	0
68614	68562	04045F	PARTICIPANT	\N	PRESENT	0
68615	68562	14227Q	PARTICIPANT	\N	PRESENT	0
68616	68562	01034P	PARTICIPANT	\N	PRESENT	0
78665	78620	14253S	PARTICIPANT	\N	PRESENT	0
68618	68562	11063M	PARTICIPANT	\N	PRESENT	0
78666	78620	08047A	PARTICIPANT	\N	PRESENT	0
78667	78620	14028W	PARTICIPANT	\N	PRESENT	0
78668	78620	14193X	PARTICIPANT	\N	PRESENT	0
78669	78620	98021N	PARTICIPANT	\N	PRESENT	0
78763	78762	14239U	PARTICIPANT	\N	PRESENT	0
78671	78620	95059Q	PRESIDENT	0	PRESENT	0
78672	78620	86044G	PARTICIPANT	\N	PRESENT	0
78765	78762	92020L	PARTICIPANT	\N	PRESENT	0
78674	78620	11054L	PARTICIPANT	\N	PRESENT	0
78675	78620	01056V	PARTICIPANT	\N	PRESENT	0
78676	78620	92044U	PARTICIPANT	\N	PRESENT	0
78766	78762	14281W	PRESIDENT	0	PRESENT	0
78767	78762	08041T	PARTICIPANT	\N	PRESENT	0
78768	78762	07004J	PARTICIPANT	\N	PRESENT	0
78770	78762	10015M	PARTICIPANT	\N	PRESENT	0
78771	78762	14269B	PARTICIPANT	\N	PRESENT	0
78772	78762	11054L	PARTICIPANT	\N	EXCUSE	0
78799	78762	04061F	PARTICIPANT	\N	PRESENT	0
78856	78762	14123H	PARTICIPANT	\N	PRESENT	0
78873	78762	14089Y	PARTICIPANT	\N	PRESENT	0
78893	78892	14133K	PARTICIPANT	\N	PRESENT	0
78894	78892	08043V	PARTICIPANT	\N	PRESENT	0
78895	78892	08024S	PARTICIPANT	\N	PRESENT	0
78896	78892	10006L	PARTICIPANT	\N	PRESENT	0
78897	78892	01037S	PARTICIPANT	\N	PRESENT	0
78898	78892	14265W	PARTICIPANT	\N	PRESENT	0
78899	78892	14237S	PARTICIPANT	\N	PRESENT	0
78900	78892	11014C	PARTICIPANT	\N	PRESENT	0
78902	78901	14133K	PARTICIPANT	\N	PRESENT	0
78903	78901	08024S	PARTICIPANT	\N	PRESENT	0
78904	78901	14265W	PARTICIPANT	\N	PRESENT	0
78917	78916	96004D	PARTICIPANT	\N	PRESENT	0
78919	78918	04036E	PARTICIPANT	\N	PRESENT	0
78920	78918	11027H	PARTICIPANT	\N	PRESENT	0
78921	78918	92020L	PARTICIPANT	\N	PRESENT	0
78922	78918	04077P	PARTICIPANT	\N	PRESENT	0
78923	78918	11106F	PARTICIPANT	\N	PRESENT	0
78924	78918	95062K	PARTICIPANT	\N	PRESENT	0
78925	78918	95067Q	PARTICIPANT	\N	PRESENT	0
78926	78918	14217N	PARTICIPANT	\N	PRESENT	0
78927	78918	11091R	PARTICIPANT	\N	PRESENT	0
78928	78918	01037S	PARTICIPANT	\N	PRESENT	0
78929	78918	14097Y	PARTICIPANT	\N	PRESENT	0
79391	79390	04040A	PRESIDENT	0	PRESENT	0
79392	79390	04086Q	PARTICIPANT	\N	PRESENT	0
79393	79390	14327T	PARTICIPANT	\N	PRESENT	0
79394	79390	14231L	PARTICIPANT	\N	PRESENT	0
79395	79390	08010L	PARTICIPANT	\N	PRESENT	0
79396	79390	11098Y	PARTICIPANT	\N	PRESENT	0
79397	79390	14063N	PARTICIPANT	\N	PRESENT	0
79398	79390	14071N	PARTICIPANT	\N	PRESENT	0
79399	79390	14028W	PARTICIPANT	\N	PRESENT	0
79400	79390	11037K	PARTICIPANT	\N	PRESENT	0
79401	79390	95067Q	PARTICIPANT	\N	PRESENT	0
79402	79390	11074Q	PARTICIPANT	\N	PRESENT	0
79403	79390	01057W	PARTICIPANT	\N	PRESENT	0
79405	79404	04036E	PARTICIPANT	\N	PRESENT	0
79406	79404	04070G	PARTICIPANT	\N	PRESENT	0
79407	79404	08015R	PARTICIPANT	\N	PRESENT	0
79408	79404	11026G	PARTICIPANT	\N	PRESENT	0
79409	79404	04077P	PARTICIPANT	\N	PRESENT	0
79412	79411	92020L	PARTICIPANT	\N	PRESENT	0
79413	79411	08043V	PARTICIPANT	\N	PRESENT	0
79414	79411	14097Y	PARTICIPANT	\N	PRESENT	0
79415	79411	01037S	PARTICIPANT	\N	PRESENT	0
79500	79497	98042T	PARTICIPANT	\N	PRESENT	0
79501	79497	01019Q	PARTICIPANT	\N	PRESENT	0
80079	80078	01013J	PARTICIPANT	\N	PRESENT	0
80080	80078	11053K	PARTICIPANT	\N	EXCUSE	0
80081	80078	11080N	PARTICIPANT	\N	PRESENT	0
80082	80078	04067M	PARTICIPANT	\N	PRESENT	0
80083	80078	01027Q	PRESIDENT	0	PRESENT	0
80084	80078	01057W	PARTICIPANT	\N	PRESENT	0
80085	80078	14159V	PARTICIPANT	\N	PRESENT	0
80086	80078	92039X	PARTICIPANT	\N	EXCUSE	0
80087	80078	14225N	PARTICIPANT	\N	EXCUSE	0
80088	80078	11012A	PARTICIPANT	\N	PRESENT	0
80089	80078	14157T	PARTICIPANT	\N	PRESENT	0
80417	77795	11106F	PARTICIPANT	\N	EXCUSE	0
81729	81724	11103C	PRESIDENT	0	PRESENT	0
81736	81724	11093T	PARTICIPANT	\N	EXCUSE	0
81740	81724	01034P	PARTICIPANT	\N	PRESENT	0
81855	81854	04080J	PARTICIPANT	\N	PRESENT	0
81856	81854	95063L	PARTICIPANT	\N	PRESENT	0
81857	81854	11015D	PARTICIPANT	\N	PRESENT	0
81858	81854	11083R	PARTICIPANT	\N	PRESENT	0
82192	80433	96004D	PARTICIPANT	\N	PRESENT	0
82193	80433	01048V	PARTICIPANT	\N	PRESENT	0
82982	82980	14239U	PARTICIPANT	\N	PRESENT	0
82983	82980	14281W	PRESIDENT	0	PRESENT	0
82984	82980	08041T	PARTICIPANT	\N	PRESENT	0
82985	82980	07004J	PARTICIPANT	\N	PRESENT	0
82986	82980	11082Q	PARTICIPANT	\N	PRESENT	0
82988	82980	14247U	PARTICIPANT	\N	PRESENT	0
82990	82980	14269B	PARTICIPANT	\N	PRESENT	0
82991	82980	14133K	PARTICIPANT	\N	EXCUSE	0
82992	82980	92020L	PARTICIPANT	\N	EXCUSE	0
82993	82980	11054L	PARTICIPANT	\N	EXCUSE	0
82994	82980	14217N	PARTICIPANT	\N	EXCUSE	0
82995	82980	99004R	PARTICIPANT	\N	EXCUSE	0
83144	82980	10015M	PARTICIPANT	\N	PRESENT	0
83146	83145	14281W	PARTICIPANT	\N	PRESENT	0
83147	83145	07004J	PARTICIPANT	\N	PRESENT	0
88728	88703	14221J	PARTICIPANT	\N	PRESENT	0
88729	88703	92039X	PARTICIPANT	\N	EXCUSE	0
88861	88803	01037S	PARTICIPANT	\N	PRESENT	0
88731	88703	14169X	PARTICIPANT	\N	PRESENT	0
88732	88703	14237S	PARTICIPANT	\N	PRESENT	0
88733	88703	13002U	PARTICIPANT	\N	PRESENT	0
88734	88703	05012A	PARTICIPANT	\N	PRESENT	0
88735	88703	14247U	PARTICIPANT	\N	PRESENT	0
88736	88703	14135M	PARTICIPANT	\N	PRESENT	0
88737	88703	14331P	PARTICIPANT	\N	PRESENT	0
88738	88703	95062K	PARTICIPANT	\N	PRESENT	0
88739	88703	14107H	PARTICIPANT	\N	PRESENT	0
88740	88703	14051J	PARTICIPANT	\N	PRESENT	0
88741	88703	14157T	PARTICIPANT	\N	PRESENT	0
88742	88703	96003C	PARTICIPANT	\N	EXCUSE	0
88805	88803	04054G	PARTICIPANT	\N	PRESENT	0
88806	88803	04040A	PARTICIPANT	\N	PRESENT	0
88807	88803	08058D	PARTICIPANT	\N	PRESENT	0
88808	88803	04042C	PARTICIPANT	\N	PRESENT	0
88809	88803	77002U	PARTICIPANT	\N	PRESENT	0
88810	88803	98029W	PARTICIPANT	\N	PRESENT	0
88862	88803	04056J	PARTICIPANT	\N	PRESENT	0
88863	88803	95067Q	PARTICIPANT	\N	PRESENT	0
88813	88803	98018T	PARTICIPANT	\N	PRESENT	0
88814	88803	92018S	PARTICIPANT	\N	PRESENT	0
88815	88803	92020L	PARTICIPANT	\N	PRESENT	0
88816	88803	95030B	PARTICIPANT	\N	PRESENT	0
88817	88803	11096W	PARTICIPANT	\N	PRESENT	0
88864	88803	14179A	PARTICIPANT	\N	PRESENT	0
88819	88803	97011G	PARTICIPANT	\N	PRESENT	0
88865	88803	14239U	PARTICIPANT	\N	PRESENT	0
88821	88803	04035D	PARTICIPANT	\N	PRESENT	0
88822	88803	07024N	PARTICIPANT	\N	PRESENT	0
88866	88803	14235Q	PARTICIPANT	\N	PRESENT	0
88824	88803	14014Q	PARTICIPANT	\N	PRESENT	0
88825	88803	11015D	PARTICIPANT	\N	PRESENT	0
88826	88803	07004J	PARTICIPANT	\N	PRESENT	0
88827	88803	95035G	PARTICIPANT	\N	PRESENT	0
88828	88803	08056B	PARTICIPANT	\N	PRESENT	0
89193	89192	14135M	PARTICIPANT	\N	PRESENT	0
89195	89194	14135M	PARTICIPANT	\N	PRESENT	0
88831	88803	11064N	PARTICIPANT	\N	PRESENT	0
89197	89196	14135M	PARTICIPANT	\N	PRESENT	0
89199	89198	14135M	PARTICIPANT	\N	PRESENT	0
88834	88803	14097Y	PARTICIPANT	\N	PRESENT	0
89201	89200	14237S	PARTICIPANT	\N	PRESENT	0
88836	88803	04036E	PARTICIPANT	\N	PRESENT	0
88837	88803	14039A	PARTICIPANT	\N	PRESENT	0
88838	88803	04077P	PARTICIPANT	\N	PRESENT	0
89203	89202	14135M	PARTICIPANT	\N	PRESENT	0
88840	88803	92031P	PARTICIPANT	\N	PRESENT	0
88841	88803	11106F	PARTICIPANT	\N	PRESENT	0
88842	88803	14251Q	PARTICIPANT	\N	PRESENT	0
88843	88803	83042R	PARTICIPANT	\N	PRESENT	0
88844	88803	08053X	PARTICIPANT	\N	PRESENT	0
88845	88803	11082Q	PARTICIPANT	\N	PRESENT	0
88846	88803	11105E	PARTICIPANT	\N	EXCUSE	0
88847	88803	14253S	PARTICIPANT	\N	PRESENT	0
89205	89204	14237S	PARTICIPANT	\N	PRESENT	0
88849	88803	14028W	PARTICIPANT	\N	PRESENT	0
88850	88803	14193X	PARTICIPANT	\N	EXCUSE	0
88851	88803	98021N	PARTICIPANT	\N	EXCUSE	0
88852	88803	04080J	PARTICIPANT	\N	PRESENT	0
88853	88803	95059Q	PRESIDENT	0	PRESENT	0
88854	88803	86044G	PARTICIPANT	\N	PRESENT	0
88855	88803	01014K	PARTICIPANT	\N	PRESENT	0
88856	88803	11054L	PARTICIPANT	\N	PRESENT	0
88857	88803	01056V	PARTICIPANT	\N	PRESENT	0
89207	89206	14237S	PARTICIPANT	\N	PRESENT	0
88859	88803	08049C	PARTICIPANT	\N	EXCUSE	0
88860	88803	04050C	PARTICIPANT	\N	PRESENT	0
89209	89208	14237S	PARTICIPANT	\N	PRESENT	0
89211	89210	14097Y	PARTICIPANT	\N	PRESENT	0
89212	89210	04080J	PARTICIPANT	\N	PRESENT	0
89214	89213	08014Q	PARTICIPANT	\N	PRESENT	0
89215	89213	08069G	PARTICIPANT	\N	PRESENT	0
89217	89216	14327T	PARTICIPANT	\N	PRESENT	0
89219	89218	98046X	PARTICIPANT	\N	PRESENT	0
89221	89220	98046X	PARTICIPANT	\N	PRESENT	0
89223	89222	11083R	PARTICIPANT	\N	PRESENT	0
89224	89222	11074Q	PARTICIPANT	\N	PRESENT	0
89226	89225	11088W	PARTICIPANT	\N	PRESENT	0
89230	89229	04071H	PARTICIPANT	\N	PRESENT	0
89232	89231	07029T	PARTICIPANT	\N	PRESENT	0
89234	89233	92031P	PARTICIPANT	\N	PRESENT	0
89235	89233	11015D	PARTICIPANT	\N	PRESENT	0
89237	89236	01014K	PARTICIPANT	\N	PRESENT	0
89239	89238	07024N	PARTICIPANT	\N	PRESENT	0
89240	89238	01014K	PARTICIPANT	\N	PRESENT	0
89242	89241	04040A	PARTICIPANT	\N	PRESENT	0
89243	89241	14097Y	PARTICIPANT	\N	PRESENT	0
89244	89241	95035G	PARTICIPANT	\N	PRESENT	0
89245	89241	95030B	PARTICIPANT	\N	PRESENT	0
89246	89241	08058D	PARTICIPANT	\N	PRESENT	0
90940	89310	08062Y	PARTICIPANT	\N	PRESENT	0
90941	89310	11066Q	PARTICIPANT	\N	PRESENT	0
90942	89310	96004D	PARTICIPANT	\N	PRESENT	0
90943	89310	14111D	PARTICIPANT	\N	PRESENT	0
90944	89310	08034U	PARTICIPANT	\N	PRESENT	0
90945	89310	01048V	PARTICIPANT	\N	PRESENT	0
90946	89310	14263U	PARTICIPANT	\N	PRESENT	0
90947	89310	97011G	PARTICIPANT	\N	PRESENT	0
90948	89310	98050T	PARTICIPANT	\N	PRESENT	0
90950	89310	14039A	PARTICIPANT	\N	PRESENT	0
90951	89310	14105F	PARTICIPANT	\N	PRESENT	0
90952	89310	07029T	PARTICIPANT	\N	PRESENT	0
90953	89310	05008E	PARTICIPANT	\N	PRESENT	0
90954	89310	04043D	PARTICIPANT	\N	PRESENT	0
90955	89310	98053W	PARTICIPANT	\N	PRESENT	0
90956	89310	14267Y	PARTICIPANT	\N	PRESENT	0
90957	89310	14209N	PARTICIPANT	\N	PRESENT	0
90958	89310	80027E	PARTICIPANT	\N	PRESENT	0
90959	89310	14225N	PARTICIPANT	\N	PRESENT	0
90960	89310	01056V	PARTICIPANT	\N	PRESENT	0
90961	89310	04067M	PARTICIPANT	\N	PRESENT	0
90962	89310	01003G	PARTICIPANT	\N	PRESENT	0
90963	89310	14107H	PARTICIPANT	\N	PRESENT	0
90964	89310	01025N	PARTICIPANT	\N	PRESENT	0
90965	89310	10006L	PARTICIPANT	\N	PRESENT	0
90966	89310	04044E	PARTICIPANT	\N	PRESENT	0
90967	89310	86044G	PARTICIPANT	\N	PRESENT	0
90968	89310	14253S	PARTICIPANT	\N	PRESENT	0
90969	89310	14038Y	PARTICIPANT	\N	PRESENT	0
90970	89310	99004R	PARTICIPANT	\N	PRESENT	0
90971	89310	00003C	PARTICIPANT	\N	PRESENT	0
90972	89310	08014Q	PARTICIPANT	\N	PRESENT	0
90973	89310	14197C	PARTICIPANT	\N	PRESENT	0
90974	89310	14151M	PARTICIPANT	\N	PRESENT	0
90975	87176	14033T	PARTICIPANT	\N	EXCUSE	0
90976	87176	14097Y	PARTICIPANT	\N	EXCUSE	0
90977	89310	11046L	PARTICIPANT	\N	PRESENT	0
90978	89310	14135M	PARTICIPANT	\N	PRESENT	0
90979	89310	14061L	PARTICIPANT	\N	PRESENT	0
90980	89310	07032N	PARTICIPANT	\N	PRESENT	0
90981	89310	11097X	PARTICIPANT	\N	PRESENT	0
90982	89310	14121F	PARTICIPANT	\N	PRESENT	0
90983	89310	14073Q	PARTICIPANT	\N	PRESENT	0
90984	89310	11067R	PARTICIPANT	\N	PRESENT	0
90986	90985	14255U	PARTICIPANT	\N	PRESENT	0
90987	90985	04086Q	PARTICIPANT	\N	PRESENT	0
90988	90985	04067M	PARTICIPANT	\N	PRESENT	0
90989	90985	01027Q	PARTICIPANT	\N	PRESENT	0
90990	90985	12042Y	PRESIDENT	0	PRESENT	0
90991	90985	11061K	PARTICIPANT	\N	PRESENT	0
90992	90985	14014Q	PARTICIPANT	\N	PRESENT	0
90993	90985	14026U	PARTICIPANT	\N	PRESENT	0
90994	90985	11112D	PARTICIPANT	\N	PRESENT	0
90995	90985	04049K	PARTICIPANT	\N	PRESENT	0
90996	90985	14037X	PARTICIPANT	\N	PRESENT	0
90997	90985	11100Y	PARTICIPANT	\N	PRESENT	0
90998	89310	14217N	PARTICIPANT	\N	PRESENT	0
90999	90985	04092N	PARTICIPANT	\N	PRESENT	0
91000	90985	14135M	PARTICIPANT	\N	PRESENT	0
91001	90985	11097X	PARTICIPANT	\N	PRESENT	0
91002	89310	08017T	PARTICIPANT	\N	PRESENT	0
91003	90985	04045F	PARTICIPANT	\N	PRESENT	0
91004	90985	14227Q	PARTICIPANT	\N	PRESENT	0
91005	90985	14205J	PARTICIPANT	\N	EXCUSE	0
91006	89310	14239U	PARTICIPANT	\N	PRESENT	0
91007	89310	88008L	PARTICIPANT	\N	PRESENT	0
91008	89310	11113E	PARTICIPANT	\N	PRESENT	0
91009	89310	08031R	PARTICIPANT	\N	PRESENT	0
91013	91012	04085P	PARTICIPANT	\N	PRESENT	0
91014	91012	05008E	PRESIDENT	0	PRESENT	0
91015	91012	11030C	PARTICIPANT	\N	PRESENT	0
91016	91012	11033F	PARTICIPANT	\N	PRESENT	0
91017	91012	14065Q	PARTICIPANT	\N	PRESENT	0
91018	91012	14069U	PARTICIPANT	\N	PRESENT	0
63446	63441	11015D	PARTICIPANT	\N	PRESENT	0
63447	63441	92031P	PARTICIPANT	\N	PRESENT	0
63448	63441	14039A	PARTICIPANT	\N	PRESENT	0
69426	69425	04092N	PARTICIPANT	\N	PRESENT	0
77448	77432	11012A	PARTICIPANT	\N	PRESENT	0
77449	77432	92045V	PARTICIPANT	\N	PRESENT	0
77450	77432	04034C	PARTICIPANT	\N	PRESENT	0
77451	77432	14026U	PARTICIPANT	\N	EXCUSE	0
77452	77432	08018U	PARTICIPANT	\N	EXCUSE	0
77453	77432	90003B	PARTICIPANT	\N	EXCUSE	0
77454	77432	08042U	PARTICIPANT	\N	EXCUSE	0
77455	77432	04045F	PARTICIPANT	\N	EXCUSE	0
77686	77685	04086Q	PARTICIPANT	\N	PRESENT	0
77687	77685	11033F	PARTICIPANT	\N	PRESENT	0
77688	77685	04040A	PARTICIPANT	\N	PRESENT	0
77689	77685	04053F	PARTICIPANT	\N	PRESENT	0
77690	77685	08069G	PARTICIPANT	\N	PRESENT	0
77691	77685	04036E	PARTICIPANT	\N	PRESENT	0
77692	77685	99004R	PARTICIPANT	\N	PRESENT	0
77693	77685	11026G	PARTICIPANT	\N	PRESENT	0
77694	77685	11106F	PARTICIPANT	\N	PRESENT	0
77695	77685	14225N	PARTICIPANT	\N	PRESENT	0
77696	77685	04070G	PARTICIPANT	\N	PRESENT	0
77697	77685	10015M	PARTICIPANT	\N	PRESENT	0
77698	77685	95067Q	PARTICIPANT	\N	PRESENT	0
77699	77685	04092N	PARTICIPANT	\N	PRESENT	0
77701	77700	04086Q	PARTICIPANT	\N	PRESENT	0
77702	77700	10015M	PARTICIPANT	\N	PRESENT	0
77703	77700	08069G	PARTICIPANT	\N	PRESENT	0
77705	77704	04086Q	PARTICIPANT	\N	PRESENT	0
77706	77704	08069G	PARTICIPANT	\N	PRESENT	0
77707	77704	04053F	PARTICIPANT	\N	PRESENT	0
77708	77704	10006L	PARTICIPANT	\N	PRESENT	0
77709	77704	01034P	PARTICIPANT	\N	PRESENT	0
77710	77704	14255U	PARTICIPANT	\N	PRESENT	0
77711	77704	11112D	PARTICIPANT	\N	PRESENT	0
77712	77704	08052W	PARTICIPANT	\N	PRESENT	0
77714	77713	96004D	PARTICIPANT	\N	PRESENT	0
77715	77713	14097Y	PARTICIPANT	\N	PRESENT	0
77717	77716	01058X	PARTICIPANT	\N	PRESENT	0
77719	77718	01043Q	PARTICIPANT	\N	PRESENT	0
77721	77720	05012A	PARTICIPANT	\N	PRESENT	0
77723	77722	14093U	PARTICIPANT	\N	PRESENT	0
77724	77722	08025T	PARTICIPANT	\N	PRESENT	0
77730	77722	14031R	PARTICIPANT	\N	PRESENT	0
77731	77722	14030Q	PARTICIPANT	\N	PRESENT	0
77732	77722	92039X	PARTICIPANT	\N	PRESENT	0
77733	77722	01015L	PARTICIPANT	\N	PRESENT	0
77734	77722	11085T	PARTICIPANT	\N	PRESENT	0
77735	77722	01024M	PARTICIPANT	\N	PRESENT	0
77736	77722	95063L	PARTICIPANT	\N	PRESENT	0
77737	77722	14089Y	PARTICIPANT	\N	PRESENT	0
77738	77722	14271U	PARTICIPANT	\N	PRESENT	0
77740	77739	11112D	PARTICIPANT	\N	PRESENT	0
77741	77739	14205J	PARTICIPANT	\N	PRESENT	0
77742	77739	04088S	PARTICIPANT	\N	PRESENT	0
77743	77739	92045V	PARTICIPANT	\N	PRESENT	0
77744	77739	14173T	PARTICIPANT	\N	PRESENT	0
77756	77755	04086Q	PARTICIPANT	\N	PRESENT	0
77758	77757	04086Q	PARTICIPANT	\N	PRESENT	0
77760	77759	04086Q	PARTICIPANT	\N	PRESENT	0
77796	77795	96004D	PARTICIPANT	\N	EXCUSE	0
77798	77797	11068S	PARTICIPANT	\N	PRESENT	0
77800	77799	11068S	PARTICIPANT	\N	PRESENT	0
78300	78299	04086Q	PARTICIPANT	\N	PRESENT	0
78302	78301	04086Q	PARTICIPANT	\N	PRESENT	0
78303	78301	08018U	PARTICIPANT	\N	PRESENT	0
78304	78301	01058X	PARTICIPANT	\N	PRESENT	0
78752	78223	14135M	PARTICIPANT	\N	PRESENT	0
78753	78223	11084S	PARTICIPANT	\N	PRESENT	0
78754	78223	04085P	PARTICIPANT	\N	PRESENT	0
78755	78223	08015R	PARTICIPANT	\N	PRESENT	0
78756	78223	14259Y	PARTICIPANT	\N	PRESENT	0
78757	78223	11066Q	PARTICIPANT	\N	PRESENT	0
78758	78223	14079W	PARTICIPANT	\N	PRESENT	0
78760	78223	11014C	PARTICIPANT	\N	PRESENT	0
78761	78223	01028R	PARTICIPANT	\N	PRESENT	0
78764	78223	01003G	PARTICIPANT	\N	PRESENT	0
78769	78223	86044G	PARTICIPANT	\N	PRESENT	0
78773	78223	04044E	PARTICIPANT	\N	PRESENT	0
78774	78223	04047H	PARTICIPANT	\N	PRESENT	0
78775	78223	14107H	PARTICIPANT	\N	PRESENT	0
78776	78223	14169X	PARTICIPANT	\N	PRESENT	0
78777	78223	14041T	PARTICIPANT	\N	PRESENT	0
78778	78223	14273W	PARTICIPANT	\N	PRESENT	0
78779	78223	14061L	PARTICIPANT	\N	PRESENT	0
78780	78223	01015L	PARTICIPANT	\N	PRESENT	0
78781	78223	08010L	PARTICIPANT	\N	PRESENT	0
78782	78223	04057K	PARTICIPANT	\N	PRESENT	0
78783	78223	14205J	PARTICIPANT	\N	PRESENT	0
78784	78223	14087W	PARTICIPANT	\N	PRESENT	0
78796	78223	11093T	PARTICIPANT	\N	PRESENT	0
78797	78223	14121F	PARTICIPANT	\N	PRESENT	0
78798	78223	14123H	PARTICIPANT	\N	PRESENT	0
78801	78223	14253S	PARTICIPANT	\N	PRESENT	0
78812	78223	97011G	PARTICIPANT	\N	PRESENT	0
78813	78223	11100Y	PARTICIPANT	\N	PRESENT	0
78820	78223	11043H	PARTICIPANT	\N	PRESENT	0
78821	78223	08055A	PARTICIPANT	\N	PRESENT	0
78827	78223	04088S	PARTICIPANT	\N	PRESENT	0
78828	78223	14197C	PARTICIPANT	\N	PRESENT	0
78831	78223	14201E	PARTICIPANT	\N	PRESENT	0
78843	78223	14069U	PARTICIPANT	\N	PRESENT	0
78844	78223	08034U	PARTICIPANT	\N	PRESENT	0
78857	78223	02002K	PARTICIPANT	\N	PRESENT	0
78858	78223	14037X	PARTICIPANT	\N	PRESENT	0
78859	78223	04056J	PARTICIPANT	\N	PRESENT	0
78860	78223	14235Q	PARTICIPANT	\N	PRESENT	0
78861	78223	95030B	PARTICIPANT	\N	PRESENT	0
78862	78223	80013X	PARTICIPANT	\N	PRESENT	0
78863	78223	14071N	PARTICIPANT	\N	PRESENT	0
78864	78223	11112D	PARTICIPANT	\N	PRESENT	0
78865	78223	14159V	PARTICIPANT	\N	PRESENT	0
78866	78223	00003C	PARTICIPANT	\N	PRESENT	0
78867	78223	14237S	PARTICIPANT	\N	PRESENT	0
78868	78223	95067Q	PARTICIPANT	\N	PRESENT	0
78869	78223	14251Q	PARTICIPANT	\N	PRESENT	0
78870	78223	98046X	PARTICIPANT	\N	PRESENT	0
78871	78223	98018T	PARTICIPANT	\N	PRESENT	0
78872	78223	04043D	PARTICIPANT	\N	PRESENT	0
78874	78223	01007L	PARTICIPANT	\N	PRESENT	0
78875	78223	11090Q	PARTICIPANT	\N	PRESENT	0
78876	78223	11083R	PARTICIPANT	\N	PRESENT	0
78877	78223	11104D	PARTICIPANT	\N	PRESENT	0
78879	78223	11105E	PARTICIPANT	\N	PRESENT	0
78880	78223	04081K	PARTICIPANT	\N	PRESENT	0
78881	78223	14109K	PARTICIPANT	\N	PRESENT	0
78882	78223	14209N	PARTICIPANT	\N	PRESENT	0
78883	78223	14028W	PARTICIPANT	\N	PRESENT	0
78884	78223	14031R	PARTICIPANT	\N	PRESENT	0
78885	78223	14038Y	PARTICIPANT	\N	PRESENT	0
78886	78223	14133K	PARTICIPANT	\N	PRESENT	0
78887	78223	11067R	PARTICIPANT	\N	PRESENT	0
78888	78223	01008M	PARTICIPANT	\N	PRESENT	0
78889	78223	11089X	PARTICIPANT	\N	PRESENT	0
78890	78223	14225N	PARTICIPANT	\N	PRESENT	0
78891	78223	01056V	PARTICIPANT	\N	PRESENT	0
78905	78223	11107G	PARTICIPANT	\N	PRESENT	0
78906	78223	14083S	PARTICIPANT	\N	PRESENT	0
78907	78223	14018U	PARTICIPANT	\N	PRESENT	0
78908	78223	14073Q	PARTICIPANT	\N	PRESENT	0
78909	78223	14193X	PARTICIPANT	\N	PRESENT	0
78910	78223	11026G	PARTICIPANT	\N	PRESENT	0
78911	78223	14199E	PARTICIPANT	\N	PRESENT	0
78912	78223	14042U	PARTICIPANT	\N	PRESENT	0
78913	78223	01037S	PARTICIPANT	\N	PRESENT	0
78914	78223	04053F	PARTICIPANT	\N	PRESENT	0
78915	78223	04049K	PARTICIPANT	\N	PRESENT	0
78930	78223	95015C	PARTICIPANT	\N	PRESENT	0
78931	78223	14147R	PARTICIPANT	\N	PRESENT	0
78932	78223	04045F	PARTICIPANT	\N	PRESENT	0
78933	78223	08069G	PARTICIPANT	\N	PRESENT	0
78934	78223	08017T	PARTICIPANT	\N	PRESENT	0
78935	78223	08043V	PARTICIPANT	\N	PRESENT	0
78936	78223	14119M	PARTICIPANT	\N	PRESENT	0
78938	78223	01031L	PARTICIPANT	\N	PRESENT	0
78939	78223	92045V	PARTICIPANT	\N	PRESENT	0
78940	78223	01016M	PARTICIPANT	\N	PRESENT	0
78941	78223	14001X	PARTICIPANT	\N	PRESENT	0
78942	78223	11098Y	PARTICIPANT	\N	PRESENT	0
78943	78223	14275Y	PARTICIPANT	\N	PRESENT	0
78944	78223	14030Q	PARTICIPANT	\N	PRESENT	0
78945	78223	04042C	PARTICIPANT	\N	PRESENT	0
78946	78223	14281W	PARTICIPANT	\N	PRESENT	0
78947	78223	11059R	PARTICIPANT	\N	PRESENT	0
78948	78223	08053X	PARTICIPANT	\N	PRESENT	0
78949	78223	08052W	PARTICIPANT	\N	PRESENT	0
78950	78223	14014Q	PARTICIPANT	\N	PRESENT	0
86986	86985	01025N	PARTICIPANT	\N	PRESENT	0
86988	86987	11104D	PARTICIPANT	\N	PRESENT	0
86989	86987	14061L	PARTICIPANT	\N	PRESENT	0
87005	87004	95035G	PARTICIPANT	\N	PRESENT	0
87006	87004	01037S	PARTICIPANT	\N	PRESENT	0
87007	87004	97011G	PARTICIPANT	\N	PRESENT	0
87008	87004	14237S	PARTICIPANT	\N	PRESENT	0
87009	87004	11084S	PARTICIPANT	\N	PRESENT	0
87010	87004	14179A	PARTICIPANT	\N	PRESENT	0
87151	87150	08034U	PARTICIPANT	\N	PRESENT	0
87153	87152	08011M	PARTICIPANT	\N	PRESENT	0
87163	87162	99004R	PARTICIPANT	\N	PRESENT	0
87177	87175	11054L	PARTICIPANT	\N	EXCUSE	0
87178	87175	11072N	PARTICIPANT	\N	EXCUSE	0
87179	87176	11072N	PARTICIPANT	\N	EXCUSE	0
87180	87176	96003C	PARTICIPANT	\N	EXCUSE	0
87181	87175	96003C	PARTICIPANT	\N	EXCUSE	0
87182	87175	04094Q	PARTICIPANT	\N	EXCUSE	0
87183	87176	04094Q	PARTICIPANT	\N	EXCUSE	0
87184	87175	98005N	PARTICIPANT	\N	EXCUSE	0
87185	87176	98005N	PARTICIPANT	\N	EXCUSE	0
87200	87197	07034Q	PARTICIPANT	\N	PRESENT	0
87333	87326	07034Q	PARTICIPANT	\N	PRESENT	0
87879	87878	08021P	PARTICIPANT	\N	PRESENT	0
87880	87878	04035D	PARTICIPANT	\N	PRESENT	0
87881	87878	04088S	PARTICIPANT	\N	PRESENT	0
88555	88554	89017R	PARTICIPANT	\N	PRESENT	0
88556	88554	01031L	PRESIDENT	0	PRESENT	0
88557	88554	05004A	PARTICIPANT	\N	PRESENT	0
88558	88554	01013J	PARTICIPANT	\N	PRESENT	0
88559	88554	11068S	PARTICIPANT	\N	PRESENT	0
88560	88554	11040E	PARTICIPANT	\N	PRESENT	0
88604	88554	08014Q	PARTICIPANT	\N	PRESENT	0
88606	88554	14167V	PARTICIPANT	\N	PRESENT	0
88607	88554	14175V	PARTICIPANT	\N	PRESENT	0
88608	88554	11042G	PARTICIPANT	\N	PRESENT	0
88609	88554	88008L	PARTICIPANT	\N	PRESENT	0
88610	88554	04086Q	PARTICIPANT	\N	PRESENT	0
88611	88554	04055H	PARTICIPANT	\N	EXCUSE	0
88612	88554	11070L	PARTICIPANT	\N	PRESENT	0
88613	88554	11088W	PARTICIPANT	\N	PRESENT	0
88614	88554	14327T	PARTICIPANT	\N	PRESENT	0
88615	88554	01027Q	PARTICIPANT	\N	PRESENT	0
88616	88554	04071H	PARTICIPANT	\N	PRESENT	0
88617	88554	11074Q	PARTICIPANT	\N	PRESENT	0
88618	88554	98053W	PARTICIPANT	\N	PRESENT	0
88619	88554	11083R	PARTICIPANT	\N	PRESENT	0
88620	88554	14199E	PARTICIPANT	\N	PRESENT	0
88621	88554	01057W	PARTICIPANT	\N	PRESENT	0
88622	88554	08069G	PARTICIPANT	\N	PRESENT	0
88623	88554	11048N	PARTICIPANT	\N	PRESENT	0
88624	88554	99004R	PARTICIPANT	\N	PRESENT	0
88625	88554	04061F	PARTICIPANT	\N	PRESENT	0
88626	88554	14159V	PARTICIPANT	\N	PRESENT	0
88627	88554	07029T	PARTICIPANT	\N	PRESENT	0
88628	88554	14277B	PARTICIPANT	\N	PRESENT	0
88629	88554	08010L	PARTICIPANT	\N	PRESENT	0
88630	88554	08034U	PARTICIPANT	\N	PRESENT	0
88631	88554	01048V	PARTICIPANT	\N	PRESENT	0
88632	88554	98046X	PARTICIPANT	\N	PRESENT	0
88633	88554	11085T	PARTICIPANT	\N	EXCUSE	0
88634	88554	08011M	PARTICIPANT	\N	PRESENT	0
88635	88554	08073C	PARTICIPANT	\N	PRESENT	0
88636	88554	08061X	PARTICIPANT	\N	PRESENT	0
88637	88554	01016M	PARTICIPANT	\N	PRESENT	0
88638	88554	14225N	PARTICIPANT	\N	PRESENT	0
88639	88554	11012A	PARTICIPANT	\N	PRESENT	0
88640	88554	11057P	PARTICIPANT	\N	PRESENT	0
88641	88554	14173T	PARTICIPANT	\N	PRESENT	0
88642	88554	04034C	PARTICIPANT	\N	PRESENT	0
88643	88554	07034Q	RAPPORTEUR_AVIS	\N	PRESENT	0
89254	87175	11025F	PARTICIPANT	\N	EXCUSE	0
89255	87176	11025F	PARTICIPANT	\N	EXCUSE	0
89256	87176	04043D	PARTICIPANT	\N	EXCUSE	0
89259	87175	96004D	PARTICIPANT	\N	EXCUSE	0
89260	87176	96004D	PARTICIPANT	\N	EXCUSE	0
90252	87176	04095R	PARTICIPANT	\N	EXCUSE	0
90253	87175	04095R	PARTICIPANT	\N	EXCUSE	0
90921	89310	14231L	PARTICIPANT	\N	PRESENT	0
91068	89310	08058D	PARTICIPANT	\N	PRESENT	0
91069	89310	14079W	PARTICIPANT	\N	PRESENT	0
91070	89310	14119M	PARTICIPANT	\N	PRESENT	0
91071	89310	08010L	PARTICIPANT	\N	PRESENT	0
91072	89310	01058X	PARTICIPANT	\N	PRESENT	0
91073	89310	04081K	PARTICIPANT	\N	PRESENT	0
91074	89310	89017R	PARTICIPANT	\N	PRESENT	0
91075	89310	01046T	PARTICIPANT	\N	PRESENT	0
91076	89310	14097Y	PARTICIPANT	\N	PRESENT	0
91077	89310	14281W	PARTICIPANT	\N	PRESENT	0
91078	89310	14235Q	PARTICIPANT	\N	PRESENT	0
91079	89310	01027Q	PARTICIPANT	\N	PRESENT	0
91080	89310	14219Q	PARTICIPANT	\N	PRESENT	0
91170	89311	11023D	PARTICIPANT	\N	PRESENT	0
91171	89311	04089T	PARTICIPANT	\N	PRESENT	0
91172	89311	14093U	PARTICIPANT	\N	PRESENT	0
91173	89311	14231L	PARTICIPANT	\N	PRESENT	0
86982	85520	01058X	PARTICIPANT	\N	PRESENT	0
86984	86983	01025N	PARTICIPANT	\N	PRESENT	0
91174	89311	01027Q	PARTICIPANT	\N	PRESENT	0
91175	89311	13002U	PARTICIPANT	\N	PRESENT	0
91176	89311	11103C	PARTICIPANT	\N	PRESENT	0
91177	89311	01015L	PARTICIPANT	\N	PRESENT	0
91178	89311	01044R	PARTICIPANT	\N	PRESENT	0
91179	89311	01046T	PARTICIPANT	\N	PRESENT	0
91180	89311	08060W	PARTICIPANT	\N	PRESENT	0
91181	89311	14273W	PARTICIPANT	\N	PRESENT	0
91182	89311	14187A	PARTICIPANT	\N	PRESENT	0
91183	89311	14265W	PARTICIPANT	\N	PRESENT	0
91184	89311	11097X	PARTICIPANT	\N	PRESENT	0
91185	89311	14157T	PARTICIPANT	\N	PRESENT	0
91186	89311	14331P	PARTICIPANT	\N	PRESENT	0
91187	89311	11107G	PARTICIPANT	\N	PRESENT	0
91188	89311	11036J	PARTICIPANT	\N	PRESENT	0
91189	89311	08019V	PARTICIPANT	\N	PRESENT	0
91190	89311	14105F	PARTICIPANT	\N	PRESENT	0
91191	89311	11112D	PARTICIPANT	\N	PRESENT	0
91192	89311	11109J	PARTICIPANT	\N	PRESENT	0
91193	89311	14039A	PARTICIPANT	\N	PRESENT	0
91194	89311	14033T	PARTICIPANT	\N	PRESENT	0
91195	89311	14327T	PARTICIPANT	\N	PRESENT	0
91196	89311	14159V	PARTICIPANT	\N	PRESENT	0
91197	89311	11098Y	PARTICIPANT	\N	PRESENT	0
91198	89311	14061L	PARTICIPANT	\N	PRESENT	0
91199	89311	01008M	PARTICIPANT	\N	PRESENT	0
91200	89311	11114F	PARTICIPANT	\N	PRESENT	0
91201	89311	14223L	PARTICIPANT	\N	PRESENT	0
91202	89311	04088S	PARTICIPANT	\N	PRESENT	0
91203	89311	14241N	PARTICIPANT	\N	PRESENT	0
91204	89311	14018U	PARTICIPANT	\N	PRESENT	0
91205	89311	14235Q	PARTICIPANT	\N	PRESENT	0
91206	89311	11056N	PARTICIPANT	\N	PRESENT	0
91207	89311	11090Q	PARTICIPANT	\N	PRESENT	0
91208	89311	14213J	PARTICIPANT	\N	PRESENT	0
91209	89311	95062K	PARTICIPANT	\N	PRESENT	0
91210	89311	10006L	PARTICIPANT	\N	PRESENT	0
91211	89311	14167V	PARTICIPANT	\N	PRESENT	0
91212	89311	14207L	PARTICIPANT	\N	PRESENT	0
91213	89311	08009T	PARTICIPANT	\N	PRESENT	0
91214	89311	11065P	PARTICIPANT	\N	PRESENT	0
91215	89311	14107H	PARTICIPANT	\N	PRESENT	0
91216	89311	08015R	PARTICIPANT	\N	PRESENT	0
91217	89311	01024M	PARTICIPANT	\N	PRESENT	0
91218	89311	04049K	PARTICIPANT	\N	PRESENT	0
91219	89311	95067Q	PARTICIPANT	\N	PRESENT	0
91220	89311	11093T	PARTICIPANT	\N	PRESENT	0
91221	89311	11026G	PARTICIPANT	\N	PRESENT	0
91222	89311	08031R	PARTICIPANT	\N	PRESENT	0
91232	89311	14030Q	PARTICIPANT	\N	PRESENT	0
91233	89311	04033B	PARTICIPANT	\N	PRESENT	0
91234	89311	14135M	PARTICIPANT	\N	PRESENT	0
91235	89311	14195A	PARTICIPANT	\N	PRESENT	0
91236	89311	96004D	PARTICIPANT	\N	PRESENT	0
91237	89311	14079W	PARTICIPANT	\N	PRESENT	0
91238	89311	05012A	PARTICIPANT	\N	PRESENT	0
91239	89311	14217N	PARTICIPANT	\N	PRESENT	0
91240	89311	14119M	PARTICIPANT	\N	PRESENT	0
91241	89311	92045V	PARTICIPANT	\N	PRESENT	0
91242	89311	11044J	PARTICIPANT	\N	PRESENT	0
91243	89311	14259Y	PARTICIPANT	\N	PRESENT	0
91244	89311	95063L	PARTICIPANT	\N	PRESENT	0
91245	89311	14037X	PARTICIPANT	\N	PRESENT	0
91246	89311	14083S	PARTICIPANT	\N	PRESENT	0
91247	89311	80013X	PARTICIPANT	\N	PRESENT	0
91248	89311	01022K	PARTICIPANT	\N	PRESENT	0
91249	89311	11048N	PARTICIPANT	\N	PRESENT	0
91250	89311	14073Q	PARTICIPANT	\N	PRESENT	0
91251	89311	14219Q	PARTICIPANT	\N	PRESENT	0
91252	89311	14038Y	PARTICIPANT	\N	PRESENT	0
91253	89311	11099A	PARTICIPANT	\N	PRESENT	0
63481	63480	14038Y	PARTICIPANT	\N	PRESENT	0
63482	63480	01037S	PARTICIPANT	\N	PRESENT	0
63483	63480	14097Y	PARTICIPANT	\N	PRESENT	0
63484	63480	04088S	PARTICIPANT	\N	PRESENT	0
63485	63480	11046L	PARTICIPANT	\N	PRESENT	0
63773	58964	14051J	PARTICIPANT	\N	PRESENT	0
63774	58964	14063N	PARTICIPANT	\N	PRESENT	0
63775	58964	14071N	PARTICIPANT	\N	PRESENT	0
63776	58964	11099A	PARTICIPANT	\N	PRESENT	0
66724	66723	11100Y	PARTICIPANT	\N	PRESENT	0
66725	66723	90003B	PARTICIPANT	\N	PRESENT	0
79759	79758	04085P	PARTICIPANT	\N	PRESENT	0
79760	79758	05008E	PRESIDENT	0	PRESENT	0
79761	79758	11030C	PARTICIPANT	\N	PRESENT	0
79762	79758	14065Q	PARTICIPANT	\N	PRESENT	0
79763	79758	04047H	PARTICIPANT	\N	PRESENT	0
79764	79758	11056N	PARTICIPANT	\N	PRESENT	0
79765	79758	01007L	PARTICIPANT	\N	PRESENT	0
79766	79758	14111D	PARTICIPANT	\N	PRESENT	0
79767	79758	14273W	PARTICIPANT	\N	PRESENT	0
79768	79758	95049N	PARTICIPANT	\N	PRESENT	0
79769	79758	14147R	PARTICIPANT	\N	PRESENT	0
79770	79758	07034Q	PARTICIPANT	\N	PRESENT	0
79771	79758	04074L	PARTICIPANT	\N	PRESENT	0
79772	79758	10015M	PARTICIPANT	\N	PRESENT	0
79773	79758	95063L	PARTICIPANT	\N	PRESENT	0
79774	79758	01028R	PARTICIPANT	\N	PRESENT	0
79775	79758	92045V	PARTICIPANT	\N	PRESENT	0
80064	80063	14255U	PARTICIPANT	\N	PRESENT	0
80065	80063	98042T	PARTICIPANT	\N	PRESENT	0
80066	80063	14179A	PARTICIPANT	\N	PRESENT	0
80067	80063	11026G	PARTICIPANT	\N	PRESENT	0
83148	83145	04061F	PARTICIPANT	\N	PRESENT	0
83149	83145	14041T	PARTICIPANT	\N	PRESENT	0
83150	83145	14217N	PARTICIPANT	\N	PRESENT	0
83673	83672	01057W	PARTICIPANT	\N	PRESENT	0
83717	83716	08034U	PARTICIPANT	\N	PRESENT	0
83743	80091	01046T	PARTICIPANT	\N	EXCUSE	0
83744	80091	11068S	PARTICIPANT	\N	EXCUSE	0
83745	80092	14263U	PARTICIPANT	\N	EXCUSE	0
83746	80092	01046T	PARTICIPANT	\N	PRESENT	0
83747	80092	11036J	PARTICIPANT	\N	EXCUSE	0
83807	83806	92031P	PARTICIPANT	\N	PRESENT	0
83749	80092	01044R	PARTICIPANT	\N	PRESENT	0
83750	80092	80013X	PARTICIPANT	\N	PRESENT	0
83751	80092	11061K	PARTICIPANT	\N	EXCUSE	0
83752	80092	14209N	PARTICIPANT	\N	PRESENT	0
83753	80092	11089X	PARTICIPANT	\N	EXCUSE	0
83754	80092	08069G	PARTICIPANT	\N	EXCUSE	0
83755	80092	04061F	PARTICIPANT	\N	EXCUSE	0
83757	80092	08039A	PARTICIPANT	\N	EXCUSE	0
83758	80092	14221J	PARTICIPANT	\N	EXCUSE	0
83759	80092	14257W	PARTICIPANT	\N	EXCUSE	0
83760	80092	11082Q	PARTICIPANT	\N	EXCUSE	0
83761	80092	04043D	PARTICIPANT	\N	PRESENT	0
83762	80092	01058X	PARTICIPANT	\N	EXCUSE	0
83763	80092	11068S	PARTICIPANT	\N	EXCUSE	0
83804	83803	92031P	PARTICIPANT	\N	PRESENT	0
83805	83803	11015D	PARTICIPANT	\N	PRESENT	0
83808	83806	11015D	PARTICIPANT	\N	PRESENT	0
83810	83809	05012A	PARTICIPANT	\N	PRESENT	0
86079	86078	08009T	PARTICIPANT	\N	PRESENT	0
86081	86080	08009T	PARTICIPANT	\N	PRESENT	0
86082	86080	11026G	PARTICIPANT	\N	PRESENT	0
86084	86083	01027Q	PRESIDENT	0	PRESENT	0
86085	86083	14159V	PARTICIPANT	\N	PRESENT	0
86086	86083	01013J	PARTICIPANT	\N	PRESENT	0
86087	86083	01057W	PARTICIPANT	\N	PRESENT	0
86088	86083	14157T	PARTICIPANT	\N	PRESENT	0
86089	86083	14225N	PARTICIPANT	\N	PRESENT	0
86090	86083	11029K	PARTICIPANT	\N	EXCUSE	0
86091	86083	11053K	PARTICIPANT	\N	EXCUSE	0
86092	86083	11080N	PARTICIPANT	\N	EXCUSE	0
86093	86083	11012A	PARTICIPANT	\N	EXCUSE	0
86732	86731	04071H	PARTICIPANT	\N	PRESENT	0
86734	86733	04071H	PARTICIPANT	\N	PRESENT	0
86736	86735	04071H	PARTICIPANT	\N	PRESENT	0
86738	86737	11088W	PARTICIPANT	\N	PRESENT	0
86742	86740	11088W	PARTICIPANT	\N	PRESENT	0
86769	86768	14239U	PARTICIPANT	\N	PRESENT	0
86770	86768	11032E	PARTICIPANT	\N	PRESENT	0
86771	86768	14087W	PARTICIPANT	\N	PRESENT	0
86772	86768	97011G	PARTICIPANT	\N	PRESENT	0
86773	86768	14014Q	PARTICIPANT	\N	PRESENT	0
86774	86768	08016S	PARTICIPANT	\N	PRESENT	0
86775	86768	11084S	PARTICIPANT	\N	PRESENT	0
86776	86768	04036E	PARTICIPANT	\N	PRESENT	0
86777	86768	11026G	PARTICIPANT	\N	PRESENT	0
86778	86768	08053X	PARTICIPANT	\N	PRESENT	0
86779	86768	11105E	PARTICIPANT	\N	PRESENT	0
86974	86973	14034U	PARTICIPANT	\N	PRESENT	0
86976	86975	14034U	PARTICIPANT	\N	PRESENT	0
87196	83922	14257W	PARTICIPANT	\N	PRESENT	0
87198	83922	14221J	PARTICIPANT	\N	PRESENT	0
87199	83922	08069G	PARTICIPANT	\N	PRESENT	0
87201	83922	11068S	PARTICIPANT	\N	PRESENT	0
87203	87202	11033F	PARTICIPANT	\N	PRESENT	0
87204	87202	04044E	PARTICIPANT	\N	PRESENT	0
87282	87186	11082Q	PARTICIPANT	\N	PRESENT	0
87283	87186	04089T	PARTICIPANT	\N	PRESENT	0
87284	87186	11103C	PARTICIPANT	\N	PRESENT	0
87285	87186	95030B	PARTICIPANT	\N	PRESENT	0
87286	87186	01022K	PARTICIPANT	\N	PRESENT	0
87287	87186	07026Q	PARTICIPANT	\N	PRESENT	0
87288	87186	14263U	PARTICIPANT	\N	PRESENT	0
87289	87186	92031P	PARTICIPANT	\N	PRESENT	0
87290	87186	14051J	PARTICIPANT	\N	PRESENT	0
87291	87186	89029V	PARTICIPANT	\N	PRESENT	0
87292	87186	11039M	PARTICIPANT	\N	PRESENT	0
87293	87186	98046X	PARTICIPANT	\N	PRESENT	0
87294	87186	14055N	PARTICIPANT	\N	PRESENT	0
87295	87186	14071N	PARTICIPANT	\N	PRESENT	0
87296	87186	11072N	PARTICIPANT	\N	PRESENT	0
87297	87186	11109J	PARTICIPANT	\N	PRESENT	0
87298	87186	14059S	PARTICIPANT	\N	PRESENT	0
87299	87186	11081P	PARTICIPANT	\N	PRESENT	0
87300	87186	08068F	PARTICIPANT	\N	PRESENT	0
87301	87186	14169X	PARTICIPANT	\N	PRESENT	0
87302	87186	08015R	PARTICIPANT	\N	PRESENT	0
87303	87186	04038G	PARTICIPANT	\N	PRESENT	0
87304	87186	88008L	PARTICIPANT	\N	PRESENT	0
87305	87186	08061X	PARTICIPANT	\N	PRESENT	0
87306	87186	04043D	PARTICIPANT	\N	PRESENT	0
87307	87186	11046L	PARTICIPANT	\N	PRESENT	0
87308	87186	04097T	PARTICIPANT	\N	PRESENT	0
87309	87186	98022P	PARTICIPANT	\N	PRESENT	0
87310	87186	01060R	PARTICIPANT	\N	PRESENT	0
87311	87186	14273W	PARTICIPANT	\N	PRESENT	0
87312	87186	11061K	PARTICIPANT	\N	PRESENT	0
87313	87186	95063L	PARTICIPANT	\N	PRESENT	0
87314	87186	11011M	PARTICIPANT	\N	PRESENT	0
87315	87186	96004D	PARTICIPANT	\N	PRESENT	0
87316	87186	14221J	PARTICIPANT	\N	PRESENT	0
87317	87186	11094U	PARTICIPANT	\N	PRESENT	0
87318	87186	04070G	PARTICIPANT	\N	PRESENT	0
87319	87186	14063N	PARTICIPANT	\N	PRESENT	0
87320	87186	10006L	PARTICIPANT	\N	PRESENT	0
87321	87186	95067Q	PARTICIPANT	\N	PRESENT	0
87322	87186	14265W	PARTICIPANT	\N	PRESENT	0
87323	87186	11100Y	PARTICIPANT	\N	PRESENT	0
87324	87186	92044U	PARTICIPANT	\N	PRESENT	0
87325	87186	95015C	PARTICIPANT	\N	PRESENT	0
87327	87186	07024N	PARTICIPANT	\N	PRESENT	0
87328	87186	98018T	PARTICIPANT	\N	PRESENT	0
87329	87186	01048V	PARTICIPANT	\N	PRESENT	0
87330	87186	04085P	PARTICIPANT	\N	PRESENT	0
87331	87186	01061S	PARTICIPANT	\N	PRESENT	0
87332	87186	92018S	PARTICIPANT	\N	PRESENT	0
87334	87186	92040Q	PARTICIPANT	\N	PRESENT	0
87335	87186	14013P	PARTICIPANT	\N	PRESENT	0
87336	87186	11056N	PARTICIPANT	\N	PRESENT	0
87337	87186	11098Y	PARTICIPANT	\N	PRESENT	0
87338	87186	11040E	PARTICIPANT	\N	PRESENT	0
87339	87186	14038Y	PARTICIPANT	\N	PRESENT	0
87340	87186	01059Y	PARTICIPANT	\N	PRESENT	0
87341	87186	11031D	PARTICIPANT	\N	PRESENT	0
87342	87186	04081K	PARTICIPANT	\N	PRESENT	0
87343	87186	01015L	PARTICIPANT	\N	PRESENT	0
87344	87186	11063M	PARTICIPANT	\N	PRESENT	0
87345	87186	98024R	PARTICIPANT	\N	PRESENT	0
87346	87186	07032N	PARTICIPANT	\N	PRESENT	0
91011	91010	04049K	PARTICIPANT	\N	PRESENT	0
91032	91012	11049P	PARTICIPANT	\N	PRESENT	0
91033	91012	11084S	PARTICIPANT	\N	PRESENT	0
91034	91012	04079R	PARTICIPANT	\N	PRESENT	0
91035	91012	14111D	PARTICIPANT	\N	PRESENT	0
91036	91012	14001X	PARTICIPANT	\N	PRESENT	0
91037	91012	14273W	PARTICIPANT	\N	PRESENT	0
91038	91012	01060R	PARTICIPANT	\N	PRESENT	0
91039	91012	14147R	PARTICIPANT	\N	PRESENT	0
91040	91012	95049N	PARTICIPANT	\N	PRESENT	0
91041	91012	08051V	PARTICIPANT	\N	PRESENT	0
91042	91012	07034Q	PARTICIPANT	\N	PRESENT	0
91043	91012	04074L	PARTICIPANT	\N	PRESENT	0
91044	91012	10015M	PARTICIPANT	\N	PRESENT	0
91045	91012	95063L	PARTICIPANT	\N	PRESENT	0
91046	91012	01019Q	PARTICIPANT	\N	PRESENT	0
91047	91012	01028R	PARTICIPANT	\N	PRESENT	0
91048	91012	98035U	PARTICIPANT	\N	PRESENT	0
91049	91012	04056J	PARTICIPANT	\N	PRESENT	0
91050	91012	04044E	PARTICIPANT	\N	PRESENT	0
91051	91012	11037K	PARTICIPANT	\N	PRESENT	0
91052	91012	92045V	PARTICIPANT	\N	PRESENT	0
91053	91012	01047U	PARTICIPANT	\N	PRESENT	0
91054	91012	11026G	PARTICIPANT	\N	PRESENT	0
91056	91055	14239U	PARTICIPANT	\N	PRESENT	0
91057	91055	14065Q	PARTICIPANT	\N	PRESENT	0
91058	91055	14217N	PARTICIPANT	\N	PRESENT	0
91059	91055	14281W	PRESIDENT	0	PRESENT	0
91060	91055	07004J	PARTICIPANT	\N	PRESENT	0
91061	91055	14123H	PARTICIPANT	\N	PRESENT	0
91062	91055	10015M	PARTICIPANT	\N	PRESENT	0
91063	91055	14269B	PARTICIPANT	\N	PRESENT	0
91064	91055	14089Y	PARTICIPANT	\N	EXCUSE	0
91065	91055	14041T	PARTICIPANT	\N	EXCUSE	0
91066	91055	92020L	PARTICIPANT	\N	EXCUSE	0
91067	91055	14193X	PARTICIPANT	\N	EXCUSE	0
91760	83931	04049K	PRESIDENT	0	PRESENT	0
91761	83931	14105F	PARTICIPANT	\N	PRESENT	0
91762	83931	14030Q	PARTICIPANT	\N	PRESENT	0
91763	83931	14061L	PARTICIPANT	\N	PRESENT	0
91764	83931	14255U	PARTICIPANT	\N	PRESENT	0
91765	83931	10015M	PARTICIPANT	\N	PRESENT	0
91766	83931	14083S	PARTICIPANT	\N	PRESENT	0
91767	83931	14265W	PARTICIPANT	\N	PRESENT	0
91768	83931	14157T	PARTICIPANT	\N	PRESENT	0
91769	83931	14207L	PARTICIPANT	\N	PRESENT	0
91770	83931	14121F	PARTICIPANT	\N	PRESENT	0
91771	83931	05012A	PARTICIPANT	\N	PRESENT	0
91772	83931	89017R	PARTICIPANT	\N	EXCUSE	0
91773	83931	14261S	PARTICIPANT	\N	EXCUSE	0
91774	83931	08068F	PARTICIPANT	\N	EXCUSE	0
91775	83931	14065Q	PARTICIPANT	\N	EXCUSE	0
91776	83931	14013P	PARTICIPANT	\N	EXCUSE	0
91777	83931	14079W	PARTICIPANT	\N	EXCUSE	0
91778	83931	04055H	PARTICIPANT	\N	EXCUSE	0
91779	83931	04071H	PARTICIPANT	\N	EXCUSE	0
91780	83931	95041E	PARTICIPANT	\N	EXCUSE	0
91781	83931	01043Q	PARTICIPANT	\N	EXCUSE	0
91782	83931	11077T	PARTICIPANT	\N	EXCUSE	0
91783	83931	14253S	PARTICIPANT	\N	EXCUSE	0
92013	90325	04066L	PARTICIPANT	\N	PRESENT	0
92014	83931	14087W	PARTICIPANT	\N	EXCUSE	0
92015	90325	14093U	PARTICIPANT	\N	PRESENT	0
92016	90325	08009T	PARTICIPANT	\N	PRESENT	0
92051	92048	11106F	PARTICIPANT	\N	PRESENT	0
92018	90325	01015L	PARTICIPANT	\N	PRESENT	0
92019	83931	14039A	PARTICIPANT	\N	EXCUSE	0
92020	83931	11090Q	PARTICIPANT	\N	EXCUSE	0
92021	83931	04053F	PARTICIPANT	\N	EXCUSE	0
92022	90325	80013X	PARTICIPANT	\N	PRESENT	0
92023	90325	11065P	PARTICIPANT	\N	PRESENT	0
92024	90325	01044R	PARTICIPANT	\N	PRESENT	0
92049	92048	07024N	PARTICIPANT	\N	PRESENT	0
92050	92048	01014K	PARTICIPANT	\N	PRESENT	0
92052	92048	04040A	PARTICIPANT	\N	PRESENT	0
92053	92048	11054L	PARTICIPANT	\N	PRESENT	0
92054	90325	09001P	PARTICIPANT	\N	PRESENT	0
92055	90325	14179A	PARTICIPANT	\N	PRESENT	0
92057	90325	11098Y	PARTICIPANT	\N	PRESENT	0
92058	92056	07024N	PARTICIPANT	\N	PRESENT	0
92059	92056	01014K	PARTICIPANT	\N	PRESENT	0
92060	92056	11106F	PARTICIPANT	\N	PRESENT	0
92061	92056	11054L	PARTICIPANT	\N	PRESENT	0
92062	90325	14219Q	PARTICIPANT	\N	PRESENT	0
92064	92063	07024N	PARTICIPANT	\N	PRESENT	0
92065	92063	01014K	PARTICIPANT	\N	PRESENT	0
92066	92063	04040A	PARTICIPANT	\N	PRESENT	0
92067	92063	11106F	PARTICIPANT	\N	PRESENT	0
92069	92068	07024N	PARTICIPANT	\N	PRESENT	0
92070	92068	01014K	PARTICIPANT	\N	PRESENT	0
92071	92068	11106F	PARTICIPANT	\N	PRESENT	0
92072	92068	04040A	PARTICIPANT	\N	PRESENT	0
92073	90325	92015P	PARTICIPANT	\N	PRESENT	0
92075	92074	07024N	PARTICIPANT	\N	PRESENT	0
92076	92074	01014K	PARTICIPANT	\N	PRESENT	0
92077	90325	11099A	PARTICIPANT	\N	PRESENT	0
92078	90325	11012A	PARTICIPANT	\N	PRESENT	0
92079	90325	07024N	PARTICIPANT	\N	PRESENT	0
92080	90325	95062K	PARTICIPANT	\N	PRESENT	0
92082	92081	04040A	PARTICIPANT	\N	PRESENT	0
92083	92081	14097Y	PARTICIPANT	\N	PRESENT	0
92084	92081	08058D	PARTICIPANT	\N	PRESENT	0
92085	92081	95035G	PARTICIPANT	\N	PRESENT	0
92086	90325	04033B	PARTICIPANT	\N	PRESENT	0
92087	90325	14041T	PARTICIPANT	\N	PRESENT	0
92089	90325	13002U	PARTICIPANT	\N	PRESENT	0
92090	92088	04040A	PARTICIPANT	\N	PRESENT	0
92091	92088	14097Y	PARTICIPANT	\N	PRESENT	0
92092	92088	08058D	PARTICIPANT	\N	PRESENT	0
92093	92088	95035G	PARTICIPANT	\N	PRESENT	0
92094	90325	11109J	PARTICIPANT	\N	PRESENT	0
92095	92088	04035D	PARTICIPANT	\N	PRESENT	0
92096	90325	04036E	PARTICIPANT	\N	PRESENT	0
92097	90325	04088S	PARTICIPANT	\N	PRESENT	0
92098	90325	01008M	PARTICIPANT	\N	PRESENT	0
92099	90325	11023D	PARTICIPANT	\N	PRESENT	0
92100	90325	14207L	PARTICIPANT	\N	PRESENT	0
92101	90325	08060W	PARTICIPANT	\N	PRESENT	0
92103	92102	86044G	PARTICIPANT	\N	PRESENT	0
92104	90325	11114F	PARTICIPANT	\N	PRESENT	0
92105	90325	14038Y	PARTICIPANT	\N	PRESENT	0
92106	90325	11091R	PARTICIPANT	\N	PRESENT	0
92107	90325	14209N	PARTICIPANT	\N	PRESENT	0
92108	90325	11097X	PARTICIPANT	\N	PRESENT	0
92109	90325	14030Q	PARTICIPANT	\N	PRESENT	0
92110	90325	01028R	PARTICIPANT	\N	PRESENT	0
92111	90325	14121F	PARTICIPANT	\N	PRESENT	0
92112	90325	11107G	PARTICIPANT	\N	PRESENT	0
92113	90325	14033T	PARTICIPANT	\N	PRESENT	0
92114	90325	11101A	PARTICIPANT	\N	PRESENT	0
92115	90325	95015C	PARTICIPANT	\N	PRESENT	0
92116	90325	11090Q	PARTICIPANT	\N	PRESENT	0
92117	90325	14135M	PARTICIPANT	\N	PRESENT	0
92118	90325	05012A	PARTICIPANT	\N	PRESENT	0
92119	90325	08016S	PARTICIPANT	\N	PRESENT	0
92120	90325	14169X	PARTICIPANT	\N	PRESENT	0
92121	90325	96004D	PARTICIPANT	\N	PRESENT	0
92122	90325	08043V	PARTICIPANT	\N	PRESENT	0
92123	90325	92045V	PARTICIPANT	\N	PRESENT	0
92124	90325	01041N	PARTICIPANT	\N	PRESENT	0
92125	90325	08034U	PARTICIPANT	\N	PRESENT	0
92133	90325	14327T	PARTICIPANT	\N	PRESENT	0
92144	90325	08019V	PARTICIPANT	\N	PRESENT	0
92145	90325	04067M	PARTICIPANT	\N	PRESENT	0
63783	63782	11082Q	PARTICIPANT	\N	PRESENT	0
63785	63784	80013X	PARTICIPANT	\N	PRESENT	0
63787	63784	11082Q	PARTICIPANT	\N	PRESENT	0
63788	63784	04043D	PARTICIPANT	\N	PRESENT	0
63789	63784	01058X	PARTICIPANT	\N	PRESENT	0
78951	78223	14231L	PARTICIPANT	\N	PRESENT	0
78952	78223	11085T	PARTICIPANT	\N	PRESENT	0
78953	78223	89017R	PARTICIPANT	\N	PRESENT	0
78954	78223	92018S	PARTICIPANT	\N	PRESENT	0
78955	78223	88008L	PARTICIPANT	\N	PRESENT	0
78956	78223	14033T	PARTICIPANT	\N	PRESENT	0
78957	78223	14053L	PARTICIPANT	\N	PRESENT	0
78958	78223	08011M	PARTICIPANT	\N	PRESENT	0
79055	78224	14103D	PARTICIPANT	\N	PRESENT	0
79056	78224	11093T	PARTICIPANT	\N	PRESENT	0
79057	78224	14026U	PARTICIPANT	\N	PRESENT	0
79058	78224	07034Q	PARTICIPANT	\N	PRESENT	0
79059	78224	04044E	PARTICIPANT	\N	PRESENT	0
79060	78224	92018S	PARTICIPANT	\N	PRESENT	0
79061	78224	14235Q	PARTICIPANT	\N	PRESENT	0
79062	78224	11033F	PARTICIPANT	\N	PRESENT	0
79063	78224	99004R	PARTICIPANT	\N	PRESENT	0
79064	78224	14079W	PARTICIPANT	\N	PRESENT	0
79065	78224	04056J	PARTICIPANT	\N	PRESENT	0
79066	78224	14065Q	PARTICIPANT	\N	PRESENT	0
79067	78224	11105E	PARTICIPANT	\N	PRESENT	0
79068	78224	01034P	PARTICIPANT	\N	PRESENT	0
79069	78224	01056V	PARTICIPANT	\N	PRESENT	0
79070	78224	14215L	PARTICIPANT	\N	PRESENT	0
79071	78224	11094U	PARTICIPANT	\N	PRESENT	0
79072	78224	04085P	PARTICIPANT	\N	PRESENT	0
79073	78224	95062K	PARTICIPANT	\N	PRESENT	0
79074	78224	14257W	PARTICIPANT	\N	PRESENT	0
79075	78224	14157T	PARTICIPANT	\N	PRESENT	0
79076	78224	14038Y	PARTICIPANT	\N	PRESENT	0
79077	78224	11026G	PARTICIPANT	\N	PRESENT	0
79078	78224	14207L	PARTICIPANT	\N	PRESENT	0
79079	78224	08052W	PARTICIPANT	\N	PRESENT	0
79080	78224	14059S	PARTICIPANT	\N	PRESENT	0
79081	78224	14281W	PARTICIPANT	\N	PRESENT	0
79082	78224	12042Y	PARTICIPANT	\N	PRESENT	0
79083	78224	92045V	PARTICIPANT	\N	PRESENT	0
79084	78224	14071N	PARTICIPANT	\N	PRESENT	0
79085	78224	11057P	PARTICIPANT	\N	PRESENT	0
79086	78224	01031L	PARTICIPANT	\N	PRESENT	0
79087	78224	08053X	PARTICIPANT	\N	PRESENT	0
79088	78224	11036J	PARTICIPANT	\N	PRESENT	0
79089	78224	14031R	PARTICIPANT	\N	PRESENT	0
79090	78224	04042C	PARTICIPANT	\N	PRESENT	0
79091	78224	10015M	PARTICIPANT	\N	PRESENT	0
79092	78224	04045F	PARTICIPANT	\N	PRESENT	0
79093	78224	01028R	PARTICIPANT	\N	PRESENT	0
79094	78224	07004J	PARTICIPANT	\N	PRESENT	0
79095	78224	14265W	PARTICIPANT	\N	PRESENT	0
79096	78224	14053L	PARTICIPANT	\N	PRESENT	0
79097	78224	08015R	PARTICIPANT	\N	PRESENT	0
79098	78224	10006L	PARTICIPANT	\N	PRESENT	0
79099	78224	01016M	PARTICIPANT	\N	PRESENT	0
79100	78224	08051V	PARTICIPANT	\N	PRESENT	0
79101	78224	04038G	PARTICIPANT	\N	PRESENT	0
79102	78224	08049C	PARTICIPANT	\N	PRESENT	0
79103	78224	11012A	PARTICIPANT	\N	PRESENT	0
79104	78224	14217N	PARTICIPANT	\N	PRESENT	0
79105	78224	04088S	PARTICIPANT	\N	PRESENT	0
79106	78224	14033T	PARTICIPANT	\N	PRESENT	0
79107	78224	14267Y	PARTICIPANT	\N	PRESENT	0
79108	78224	11097X	PARTICIPANT	\N	PRESENT	0
79109	78224	14087W	PARTICIPANT	\N	PRESENT	0
79110	78224	14030Q	PARTICIPANT	\N	PRESENT	0
79111	78224	14042U	PARTICIPANT	\N	PRESENT	0
79112	78224	14073Q	PARTICIPANT	\N	PRESENT	0
79113	78224	14119M	PARTICIPANT	\N	PRESENT	0
79114	78224	11061K	PARTICIPANT	\N	PRESENT	0
79115	78224	01008M	PARTICIPANT	\N	PRESENT	0
79116	78224	14133K	PARTICIPANT	\N	PRESENT	0
79117	78224	08011M	PARTICIPANT	\N	PRESENT	0
79118	78224	14205J	PARTICIPANT	\N	PRESENT	0
79119	78224	14219Q	PARTICIPANT	\N	PRESENT	0
79120	78224	04040A	PARTICIPANT	\N	PRESENT	0
79121	78224	01024M	PARTICIPANT	\N	PRESENT	0
79122	78224	14083S	PARTICIPANT	\N	PRESENT	0
79123	78224	04047H	PARTICIPANT	\N	PRESENT	0
79124	78224	01027Q	PARTICIPANT	\N	PRESENT	0
79125	78224	05008E	PARTICIPANT	\N	PRESENT	0
79126	78224	95049N	PARTICIPANT	\N	PRESENT	0
79127	78224	80013X	PARTICIPANT	\N	PRESENT	0
79128	78224	95063L	PARTICIPANT	\N	PRESENT	0
79621	78238	09001P	PARTICIPANT	\N	PRESENT	0
79622	78238	04057K	PARTICIPANT	\N	PRESENT	0
79623	78238	14269B	PARTICIPANT	\N	PRESENT	0
79624	78238	08018U	PARTICIPANT	\N	PRESENT	0
79625	78238	11055M	PARTICIPANT	\N	PRESENT	0
79626	78238	92031P	PARTICIPANT	\N	PRESENT	0
79627	78238	08024S	PARTICIPANT	\N	PRESENT	0
79628	78238	08069G	PARTICIPANT	\N	PRESENT	0
79629	78238	04053F	PARTICIPANT	\N	PRESENT	0
79630	78238	04077P	PARTICIPANT	\N	PRESENT	0
79631	78238	08061X	PARTICIPANT	\N	PRESENT	0
79632	78238	08038Y	PARTICIPANT	\N	PRESENT	0
79633	78238	11076S	PARTICIPANT	\N	PRESENT	0
79634	78238	11029K	PARTICIPANT	\N	PRESENT	0
79635	78238	04043D	PARTICIPANT	\N	PRESENT	0
79636	78238	11083R	PARTICIPANT	\N	PRESENT	0
79637	78238	98005N	PARTICIPANT	\N	PRESENT	0
79638	78238	11065P	PARTICIPANT	\N	PRESENT	0
79639	78238	04036E	PARTICIPANT	\N	PRESENT	0
79640	78238	14109K	PARTICIPANT	\N	PRESENT	0
79053	78224	01007L	PARTICIPANT	\N	PRESENT	0
79054	78224	11031D	PARTICIPANT	\N	PRESENT	0
79641	78238	14014Q	PARTICIPANT	\N	PRESENT	0
79642	78238	07029T	PARTICIPANT	\N	PRESENT	0
79643	78238	98029W	PARTICIPANT	\N	PRESENT	0
79644	78238	14018U	PARTICIPANT	\N	PRESENT	0
79645	78238	04078Q	PARTICIPANT	\N	PRESENT	0
79646	78238	08049C	PARTICIPANT	\N	PRESENT	0
79647	78238	10015M	PARTICIPANT	\N	PRESENT	0
79648	78238	08051V	PARTICIPANT	\N	PRESENT	0
79649	78238	14105F	PARTICIPANT	\N	PRESENT	0
79650	78238	14271U	PARTICIPANT	\N	PRESENT	0
79651	78238	01024M	PARTICIPANT	\N	PRESENT	0
79652	78238	01034P	PARTICIPANT	\N	PRESENT	0
79653	78238	14042U	PARTICIPANT	\N	PRESENT	0
79655	78238	14209N	PARTICIPANT	\N	PRESENT	0
79656	78238	98042T	PARTICIPANT	\N	PRESENT	0
79657	78238	05004A	PARTICIPANT	\N	PRESENT	0
79658	78238	01008M	PARTICIPANT	\N	PRESENT	0
79659	78238	04067M	PARTICIPANT	\N	PRESENT	0
79660	78238	14251Q	PARTICIPANT	\N	PRESENT	0
79661	78238	11044J	PARTICIPANT	\N	PRESENT	0
79662	78238	11064N	PARTICIPANT	\N	PRESENT	0
79663	78238	04071H	PARTICIPANT	\N	PRESENT	0
79664	78238	11037K	PARTICIPANT	\N	PRESENT	0
79665	78238	14217N	PARTICIPANT	\N	PRESENT	0
79666	78238	04038G	PARTICIPANT	\N	PRESENT	0
79667	78238	14231L	PARTICIPANT	\N	PRESENT	0
79668	78238	14237S	PARTICIPANT	\N	PRESENT	0
79669	78238	04080J	PARTICIPANT	\N	PRESENT	0
79670	78238	11094U	PARTICIPANT	\N	PRESENT	0
79671	78238	04040A	PARTICIPANT	\N	PRESENT	0
79684	78238	14041T	PARTICIPANT	\N	PRESENT	0
79673	78238	08009T	PARTICIPANT	\N	PRESENT	0
79674	78238	11082Q	PARTICIPANT	\N	PRESENT	0
79675	78238	11093T	PARTICIPANT	\N	PRESENT	0
79676	78238	07004J	PARTICIPANT	\N	PRESENT	0
79677	78238	01007L	PARTICIPANT	\N	PRESENT	0
79678	78238	14327T	PARTICIPANT	\N	PRESENT	0
79679	78238	08011M	PARTICIPANT	\N	PRESENT	0
79680	78238	04061F	PARTICIPANT	\N	PRESENT	0
79681	78238	14038Y	PARTICIPANT	\N	PRESENT	0
79682	78238	04089T	PARTICIPANT	\N	PRESENT	0
79683	78238	14055N	PARTICIPANT	\N	PRESENT	0
79685	78238	05012A	PARTICIPANT	\N	PRESENT	0
79686	78238	11103C	PARTICIPANT	\N	PRESENT	0
79695	78238	95062K	PARTICIPANT	\N	PRESENT	0
79700	78238	11084S	PARTICIPANT	\N	PRESENT	0
79706	78238	11054L	PARTICIPANT	\N	PRESENT	0
79704	78238	11057P	PARTICIPANT	\N	PRESENT	0
79705	78238	04034C	PARTICIPANT	\N	PRESENT	0
79709	78238	05008E	PARTICIPANT	\N	PRESENT	0
79710	78238	89017R	PARTICIPANT	\N	PRESENT	0
79711	78238	01028R	PARTICIPANT	\N	PRESENT	0
91019	91012	04047H	PARTICIPANT	\N	PRESENT	0
91255	89311	14111D	PARTICIPANT	\N	PRESENT	0
91256	89311	04043D	PARTICIPANT	\N	PRESENT	0
91257	89311	14257W	PARTICIPANT	\N	PRESENT	0
91258	89311	14034U	PARTICIPANT	\N	PRESENT	0
91259	89311	14197C	PARTICIPANT	\N	PRESENT	0
91273	91272	14133K	PARTICIPANT	\N	PRESENT	0
91274	91272	04085P	PARTICIPANT	\N	PRESENT	0
91275	91272	04054G	PARTICIPANT	\N	PRESENT	0
91276	91272	04047H	PARTICIPANT	\N	PRESENT	0
91277	91272	14079W	PARTICIPANT	\N	PRESENT	0
91278	91272	11015D	PARTICIPANT	\N	PRESENT	0
91279	91272	95037J	PARTICIPANT	\N	PRESENT	0
91280	91272	14097Y	PARTICIPANT	\N	PRESENT	0
91281	91272	11084S	PARTICIPANT	\N	PRESENT	0
91282	91272	14073Q	PARTICIPANT	\N	PRESENT	0
91283	91272	11026G	PARTICIPANT	\N	PRESENT	0
91284	91272	92031P	PRESIDENT	0	PRESENT	0
91285	91272	14251Q	PARTICIPANT	\N	PRESENT	0
91286	91272	14001X	PARTICIPANT	\N	PRESENT	0
91287	91272	08053X	PARTICIPANT	\N	PRESENT	0
91288	91272	14237S	PARTICIPANT	\N	PRESENT	0
91289	91272	04080J	PARTICIPANT	\N	PRESENT	0
91290	91272	14331P	PARTICIPANT	\N	PRESENT	0
91291	91272	95067Q	PARTICIPANT	\N	PRESENT	0
91292	91272	14089Y	PARTICIPANT	\N	EXCUSE	0
91293	91272	11027H	PARTICIPANT	\N	EXCUSE	0
91295	90263	08055A	PARTICIPANT	\N	PRESENT	0
91296	90263	14089Y	PARTICIPANT	\N	PRESENT	0
91297	90263	95059Q	PARTICIPANT	\N	PRESENT	0
91351	90263	14223L	PARTICIPANT	\N	PRESENT	0
91299	90263	01044R	PARTICIPANT	\N	PRESENT	0
91300	90263	11096W	PARTICIPANT	\N	PRESENT	0
91301	90263	07004J	PARTICIPANT	\N	PRESENT	0
91302	90263	14031R	PARTICIPANT	\N	PRESENT	0
91303	90263	14191V	PARTICIPANT	\N	PRESENT	0
91304	90263	14253S	PARTICIPANT	\N	PRESENT	0
91305	90263	95015C	PARTICIPANT	\N	PRESENT	0
91306	90263	86044G	PARTICIPANT	\N	PRESENT	0
91307	90263	14209N	PARTICIPANT	\N	PRESENT	0
91308	90263	01041N	PARTICIPANT	\N	PRESENT	0
91312	90263	77002U	PARTICIPANT	\N	PRESENT	0
91310	90263	08058D	PARTICIPANT	\N	PRESENT	0
91311	90263	92015P	PARTICIPANT	\N	PRESENT	0
91319	90263	04042C	PARTICIPANT	\N	PRESENT	0
91314	90263	14219Q	PARTICIPANT	\N	PRESENT	0
91315	90263	14103D	PARTICIPANT	\N	PRESENT	0
91316	90263	11012A	PARTICIPANT	\N	PRESENT	0
91317	90263	11101A	PARTICIPANT	\N	PRESENT	0
91324	90263	08060W	PARTICIPANT	\N	PRESENT	0
91320	90263	14327T	PARTICIPANT	\N	PRESENT	0
91321	90263	95035G	PARTICIPANT	\N	PRESENT	0
91322	90263	04054G	PARTICIPANT	\N	PRESENT	0
91323	90263	04050C	PARTICIPANT	\N	PRESENT	0
91325	90263	14107H	PARTICIPANT	\N	PRESENT	0
91326	90263	01003G	PARTICIPANT	\N	PRESENT	0
91327	90263	98022P	PARTICIPANT	\N	PRESENT	0
91328	90263	04077P	PARTICIPANT	\N	PRESENT	0
91329	90263	14197C	PARTICIPANT	\N	PRESENT	0
91330	90263	14033T	PARTICIPANT	\N	PRESENT	0
91331	90263	04088S	PARTICIPANT	\N	PRESENT	0
91332	90263	12042Y	PARTICIPANT	\N	PRESENT	0
91333	90263	01056V	PARTICIPANT	\N	PRESENT	0
91334	90263	95062K	PARTICIPANT	\N	PRESENT	0
91335	90263	14167V	PARTICIPANT	\N	PRESENT	0
91336	90263	14079W	PARTICIPANT	\N	PRESENT	0
91337	90263	13002U	PARTICIPANT	\N	PRESENT	0
91338	90263	11054L	PARTICIPANT	\N	PRESENT	0
91339	90263	01022K	PARTICIPANT	\N	PRESENT	0
91340	90263	14073Q	PARTICIPANT	\N	PRESENT	0
91341	90263	14265W	PARTICIPANT	\N	PRESENT	0
91342	90263	01008M	PARTICIPANT	\N	PRESENT	0
91343	90263	11036J	PARTICIPANT	\N	PRESENT	0
91344	90263	14041T	PARTICIPANT	\N	PRESENT	0
91345	90263	14133K	PARTICIPANT	\N	PRESENT	0
91346	90263	14237S	PARTICIPANT	\N	PRESENT	0
91347	90263	14187A	PARTICIPANT	\N	PRESENT	0
91348	90263	11098Y	PARTICIPANT	\N	PRESENT	0
91349	90263	11109J	PARTICIPANT	\N	PRESENT	0
91350	90263	08010L	PARTICIPANT	\N	PRESENT	0
91352	90264	08055A	PARTICIPANT	\N	PRESENT	0
91411	90264	95037J	PARTICIPANT	\N	PRESENT	0
91406	90264	11107G	PARTICIPANT	\N	PRESENT	0
91355	90264	01044R	PARTICIPANT	\N	PRESENT	0
91407	90264	08015R	PARTICIPANT	\N	PRESENT	0
91357	90264	07004J	PARTICIPANT	\N	PRESENT	0
91412	90264	08009T	PARTICIPANT	\N	PRESENT	0
91359	90264	14191V	PARTICIPANT	\N	PRESENT	0
91360	90264	14253S	PARTICIPANT	\N	PRESENT	0
91413	90264	14093U	PARTICIPANT	\N	PRESENT	0
91414	90264	14331P	PARTICIPANT	\N	PRESENT	0
91363	90264	14209N	PARTICIPANT	\N	PRESENT	0
91364	90264	01041N	PARTICIPANT	\N	PRESENT	0
91365	90264	08058D	PARTICIPANT	\N	PRESENT	0
91366	90264	92015P	PARTICIPANT	\N	PRESENT	0
91367	90264	77002U	PARTICIPANT	\N	PRESENT	0
91415	90264	92045V	PARTICIPANT	\N	PRESENT	0
91369	90264	14103D	PARTICIPANT	\N	PRESENT	0
91370	90264	11012A	PARTICIPANT	\N	PRESENT	0
91416	90264	11104D	PARTICIPANT	\N	PRESENT	0
91372	90264	04042C	PARTICIPANT	\N	PRESENT	0
91408	90264	11065P	PARTICIPANT	\N	PRESENT	0
91417	90264	14039A	PARTICIPANT	\N	PRESENT	0
91409	90264	80013X	PARTICIPANT	\N	PRESENT	0
91418	90264	11099A	PARTICIPANT	\N	PRESENT	0
91377	90264	08060W	PARTICIPANT	\N	PRESENT	0
91378	90264	14107H	PARTICIPANT	\N	PRESENT	0
91419	90264	97011G	PARTICIPANT	\N	PRESENT	0
91380	90264	98022P	PARTICIPANT	\N	PRESENT	0
91410	90264	04089T	PARTICIPANT	\N	PRESENT	0
91382	90264	14197C	PARTICIPANT	\N	PRESENT	0
91383	90264	14033T	PARTICIPANT	\N	PRESENT	0
91384	90264	04088S	PARTICIPANT	\N	PRESENT	0
91385	90264	12042Y	PARTICIPANT	\N	PRESENT	0
91386	90264	01056V	PARTICIPANT	\N	PRESENT	0
91387	90264	95062K	PARTICIPANT	\N	PRESENT	0
91388	90264	14167V	PARTICIPANT	\N	PRESENT	0
91389	90264	14079W	PARTICIPANT	\N	PRESENT	0
91390	90264	13002U	PARTICIPANT	\N	PRESENT	0
91391	90264	11054L	PARTICIPANT	\N	PRESENT	0
91392	90264	01022K	PARTICIPANT	\N	PRESENT	0
91393	90264	14073Q	PARTICIPANT	\N	PRESENT	0
91394	90264	14265W	PARTICIPANT	\N	PRESENT	0
91395	90264	01008M	PARTICIPANT	\N	PRESENT	0
91396	90264	11036J	PARTICIPANT	\N	PRESENT	0
91397	90264	14041T	PARTICIPANT	\N	PRESENT	0
91422	90264	11103C	PARTICIPANT	\N	PRESENT	0
91399	90264	14237S	PARTICIPANT	\N	PRESENT	0
91400	90264	14187A	PARTICIPANT	\N	PRESENT	0
91401	90264	11098Y	PARTICIPANT	\N	PRESENT	0
91402	90264	11109J	PARTICIPANT	\N	PRESENT	0
91403	90264	08010L	PARTICIPANT	\N	PRESENT	0
91404	90264	14223L	PARTICIPANT	\N	PRESENT	0
91405	90264	01015L	PARTICIPANT	\N	PRESENT	0
91423	90264	14207L	PARTICIPANT	\N	PRESENT	0
91424	90264	14119M	PARTICIPANT	\N	PRESENT	0
91425	90264	01027Q	PARTICIPANT	\N	PRESENT	0
91426	90264	09001P	PARTICIPANT	\N	PRESENT	0
91427	90264	98050T	PARTICIPANT	\N	PRESENT	0
91428	90264	14105F	PARTICIPANT	\N	PRESENT	0
91429	90264	11084S	PARTICIPANT	\N	PRESENT	0
91430	90264	14195A	PARTICIPANT	\N	PRESENT	0
91431	90264	14157T	PARTICIPANT	\N	PRESENT	0
91432	90264	99004R	PARTICIPANT	\N	PRESENT	0
91433	90264	11056N	PARTICIPANT	\N	PRESENT	0
91434	90264	14069U	PARTICIPANT	\N	PRESENT	0
91435	90264	11105E	PARTICIPANT	\N	PRESENT	0
91436	87175	14097Y	PARTICIPANT	\N	PRESENT	0
91437	87175	01022K	PARTICIPANT	\N	PRESENT	0
91438	87175	11114F	PARTICIPANT	\N	PRESENT	0
91439	87175	11023D	PARTICIPANT	\N	PRESENT	0
91440	87175	01027Q	PARTICIPANT	\N	PRESENT	0
91441	87175	08019V	PRESIDENT	0	PRESENT	0
91442	87175	11106F	PARTICIPANT	\N	PRESENT	0
91443	87175	14219Q	PARTICIPANT	\N	PRESENT	0
91444	87175	14059S	PARTICIPANT	\N	PRESENT	0
91445	87175	04043D	PARTICIPANT	\N	PRESENT	0
91446	87175	95062K	PARTICIPANT	\N	PRESENT	0
91447	87175	11113E	PARTICIPANT	\N	PRESENT	0
91449	91448	96003C	PARTICIPANT	\N	EXCUSE	0
91450	90264	14257W	PARTICIPANT	\N	PRESENT	0
91451	90264	14014Q	PARTICIPANT	\N	PRESENT	0
91453	91452	89017R	PARTICIPANT	\N	PRESENT	0
91458	91457	89017R	PARTICIPANT	\N	PRESENT	0
91460	91459	89017R	PARTICIPANT	\N	PRESENT	0
91462	91461	89017R	PARTICIPANT	\N	PRESENT	0
91468	90264	11114F	PARTICIPANT	\N	PRESENT	0
91469	90264	88008L	PARTICIPANT	\N	PRESENT	0
91470	90264	08016S	PARTICIPANT	\N	PRESENT	0
62827	62826	01008M	PARTICIPANT	\N	PRESENT	0
62828	62826	14053L	PARTICIPANT	\N	PRESENT	0
62829	62826	01041N	PARTICIPANT	\N	PRESENT	0
62830	62826	12042Y	PARTICIPANT	\N	PRESENT	0
62831	62826	01037S	PARTICIPANT	\N	PRESENT	0
62832	62826	14026U	PARTICIPANT	\N	PRESENT	0
62833	62826	14179A	PARTICIPANT	\N	PRESENT	0
62834	62826	07029T	PARTICIPANT	\N	PRESENT	0
62835	62826	14219Q	PARTICIPANT	\N	PRESENT	0
62836	62826	14265W	PARTICIPANT	\N	PRESENT	0
62837	62826	14119M	PARTICIPANT	\N	PRESENT	0
62838	62826	11105E	PARTICIPANT	\N	PRESENT	0
62839	62826	95062K	PARTICIPANT	\N	PRESENT	0
63740	49570	14079W	PARTICIPANT	\N	PRESENT	0
63741	49570	14039A	PARTICIPANT	\N	PRESENT	0
63742	49570	04055H	PARTICIPANT	\N	PRESENT	0
63743	49570	14105F	PARTICIPANT	\N	PRESENT	0
63744	49570	14207L	PARTICIPANT	\N	PRESENT	0
63745	49570	14013P	PARTICIPANT	\N	PRESENT	0
63746	49570	14030Q	PARTICIPANT	\N	PRESENT	0
63747	49570	14265W	PARTICIPANT	\N	PRESENT	0
63748	49570	14087W	PARTICIPANT	\N	PRESENT	0
63749	49570	01043Q	PARTICIPANT	\N	PRESENT	0
63751	49570	04049K	PRESIDENT	0	PRESENT	0
63752	49570	14083S	PARTICIPANT	\N	PRESENT	0
63753	49570	14253S	PARTICIPANT	\N	PRESENT	0
63754	49570	11088W	PARTICIPANT	\N	PRESENT	0
63755	49570	14255U	PARTICIPANT	\N	PRESENT	0
63756	49570	04053F	PARTICIPANT	\N	PRESENT	0
63757	49570	14121F	PARTICIPANT	\N	PRESENT	0
63758	49570	14034U	PARTICIPANT	\N	PRESENT	0
63759	49570	11090Q	PARTICIPANT	\N	PRESENT	0
63760	49570	14061L	PARTICIPANT	\N	PRESENT	0
63761	49570	14018U	PARTICIPANT	\N	PRESENT	0
63762	49570	89017R	PARTICIPANT	\N	EXCUSE	0
63763	49570	14065Q	PARTICIPANT	\N	EXCUSE	0
63764	49570	14041T	PARTICIPANT	\N	EXCUSE	0
63765	49570	04071H	PARTICIPANT	\N	EXCUSE	0
63766	49570	14151M	PARTICIPANT	\N	EXCUSE	0
63767	49570	95041E	PARTICIPANT	\N	EXCUSE	0
63768	49570	11077T	PARTICIPANT	\N	EXCUSE	0
63769	49570	95067Q	PARTICIPANT	\N	EXCUSE	0
63770	49570	11063M	PARTICIPANT	\N	EXCUSE	0
63771	49570	11069T	PARTICIPANT	\N	EXCUSE	0
63772	49570	14157T	PARTICIPANT	\N	EXCUSE	0
63778	63777	04043D	PARTICIPANT	\N	PRESENT	0
63779	63777	07024N	PARTICIPANT	\N	PRESENT	0
63780	63777	08056B	PARTICIPANT	\N	PRESENT	0
63781	63777	10006L	PARTICIPANT	\N	PRESENT	0
87347	87186	08016S	PARTICIPANT	\N	PRESENT	0
87348	87186	92045V	PARTICIPANT	\N	PRESENT	0
87349	87186	98035U	PARTICIPANT	\N	PRESENT	0
87350	87186	92015P	PARTICIPANT	\N	PRESENT	0
87351	87186	95062K	PARTICIPANT	\N	PRESENT	0
87352	87186	04033B	PARTICIPANT	\N	PRESENT	0
87353	87186	14211G	PARTICIPANT	\N	PRESENT	0
87354	87186	08055A	PARTICIPANT	\N	PRESENT	0
87355	87186	01031L	PARTICIPANT	\N	PRESENT	0
87356	87186	08062Y	PARTICIPANT	\N	PRESENT	0
87357	87186	11027H	PARTICIPANT	\N	PRESENT	0
87358	87186	04041B	PARTICIPANT	\N	PRESENT	0
87359	87186	14028W	PARTICIPANT	\N	PRESENT	0
87360	87186	01011G	PARTICIPANT	\N	PRESENT	0
87361	87186	14253S	PARTICIPANT	\N	PRESENT	0
87362	87186	11089X	PARTICIPANT	\N	PRESENT	0
87363	87186	11036J	PARTICIPANT	\N	PRESENT	0
87364	87186	86044G	PARTICIPANT	\N	PRESENT	0
87365	87186	83047W	PARTICIPANT	\N	PRESENT	0
87366	87186	11059R	PARTICIPANT	\N	PRESENT	0
87367	87186	08053X	PARTICIPANT	\N	PRESENT	0
87368	87186	08012N	PARTICIPANT	\N	PRESENT	0
87369	87186	14187A	PARTICIPANT	\N	PRESENT	0
87370	87186	83042R	PARTICIPANT	\N	PRESENT	0
87371	87186	08041T	PARTICIPANT	\N	PRESENT	0
87372	87186	14175V	PARTICIPANT	\N	PRESENT	0
87373	87186	01058X	PARTICIPANT	\N	PRESENT	0
87374	87186	14109K	PARTICIPANT	\N	PRESENT	0
87375	87186	11014C	PARTICIPANT	\N	PRESENT	0
87376	87186	11095V	PARTICIPANT	\N	PRESENT	0
87377	87186	11030C	PARTICIPANT	\N	PRESENT	0
87378	87186	08014Q	PARTICIPANT	\N	PRESENT	0
87379	87186	11054L	PARTICIPANT	\N	PRESENT	0
87380	87186	08018U	PARTICIPANT	\N	PRESENT	0
87381	87186	14281W	PARTICIPANT	\N	PRESENT	0
87382	87186	04044E	PARTICIPANT	\N	PRESENT	0
87383	87186	14167V	PARTICIPANT	\N	PRESENT	0
87384	87186	14229S	PARTICIPANT	\N	PRESENT	0
87385	87186	14017T	PARTICIPANT	\N	PRESENT	0
87386	87186	14121F	PARTICIPANT	\N	PRESENT	0
87387	87186	14097Y	PARTICIPANT	\N	PRESENT	0
87388	87186	11077T	PARTICIPANT	\N	PRESENT	0
87389	87186	04056J	PARTICIPANT	\N	PRESENT	0
87390	87186	14037X	PARTICIPANT	\N	PRESENT	0
87391	87186	11057P	PARTICIPANT	\N	PRESENT	0
87392	87186	14147R	PARTICIPANT	\N	PRESENT	0
87393	87186	08024S	PARTICIPANT	\N	PRESENT	0
87394	87186	92020L	PARTICIPANT	\N	PRESENT	0
87395	87186	14151M	PARTICIPANT	\N	PRESENT	0
87396	87186	14193X	PARTICIPANT	\N	PRESENT	0
87397	87186	11084S	PARTICIPANT	\N	PRESENT	0
87398	87186	80027E	PARTICIPANT	\N	PRESENT	0
87399	87186	14329V	PARTICIPANT	\N	PRESENT	0
87400	87186	01028R	PARTICIPANT	\N	PRESENT	0
87401	87186	11110B	PARTICIPANT	\N	PRESENT	0
87402	87186	04057K	PARTICIPANT	\N	PRESENT	0
87403	87186	11042G	PARTICIPANT	\N	PRESENT	0
87404	87186	14031R	PARTICIPANT	\N	PRESENT	0
87405	87186	01037S	PARTICIPANT	\N	PRESENT	0
87406	87186	04092N	PARTICIPANT	\N	PRESENT	0
87407	87186	87003B	PARTICIPANT	\N	PRESENT	0
87408	87186	04035D	PARTICIPANT	\N	PRESENT	0
87409	87186	04079R	PARTICIPANT	\N	PRESENT	0
87410	87186	08042U	PARTICIPANT	\N	PRESENT	0
87411	87186	01008M	PARTICIPANT	\N	PRESENT	0
87412	87186	04094Q	PARTICIPANT	\N	PRESENT	0
87413	87186	04048J	PARTICIPANT	\N	PRESENT	0
87414	87186	11114F	PARTICIPANT	\N	PRESENT	0
87415	87186	92039X	PARTICIPANT	\N	PRESENT	0
87416	87186	98021N	PARTICIPANT	\N	PRESENT	0
87417	87186	11113E	PARTICIPANT	\N	PRESENT	0
87418	87186	11033F	PARTICIPANT	\N	PRESENT	0
87419	87186	11049P	PARTICIPANT	\N	PRESENT	0
87420	87186	11099A	PARTICIPANT	\N	PRESENT	0
87421	87186	14119M	PARTICIPANT	\N	PRESENT	0
87422	87186	04067M	PARTICIPANT	\N	PRESENT	0
87423	87186	11065P	PARTICIPANT	\N	PRESENT	0
87424	87186	08019V	PARTICIPANT	\N	PRESENT	0
87425	87186	99002P	PARTICIPANT	\N	PRESENT	0
87426	87186	01046T	PARTICIPANT	\N	PRESENT	0
87427	87186	14079W	PARTICIPANT	\N	PRESENT	0
87428	87186	08031R	PARTICIPANT	\N	PRESENT	0
87429	87186	11096W	PARTICIPANT	\N	PRESENT	0
87430	87186	04088S	PARTICIPANT	\N	PRESENT	0
87431	87186	14065Q	PARTICIPANT	\N	PRESENT	0
87432	87186	14331P	PARTICIPANT	\N	PRESENT	0
87433	87186	04034C	PARTICIPANT	\N	PRESENT	0
87434	87186	14069U	PARTICIPANT	\N	PRESENT	0
87435	87186	12042Y	PARTICIPANT	\N	PRESENT	0
87436	87186	04086Q	PARTICIPANT	\N	PRESENT	0
87437	87186	14159V	PARTICIPANT	\N	PRESENT	0
87438	87186	14239U	PARTICIPANT	\N	PRESENT	0
87439	87186	01057W	PARTICIPANT	\N	PRESENT	0
87440	87186	08021P	PARTICIPANT	\N	PRESENT	0
87441	87186	01041N	PARTICIPANT	\N	PRESENT	0
87442	87186	04059M	PARTICIPANT	\N	PRESENT	0
87443	87186	12041X	PARTICIPANT	\N	PRESENT	0
87444	87186	14249W	PARTICIPANT	\N	PRESENT	0
87445	87186	08058D	PARTICIPANT	\N	PRESENT	0
87446	87186	11066Q	PARTICIPANT	\N	PRESENT	0
87447	87186	11097X	PARTICIPANT	\N	PRESENT	0
87448	87186	08035V	PARTICIPANT	\N	PRESENT	0
87449	87186	07034Q	PARTICIPANT	\N	PRESENT	0
87450	87186	14061L	PARTICIPANT	\N	PRESENT	0
87451	87186	14241N	PARTICIPANT	\N	PRESENT	0
87452	87186	04061F	PARTICIPANT	\N	PRESENT	0
87453	87186	04053F	PARTICIPANT	\N	PRESENT	0
87454	87186	14014Q	PARTICIPANT	\N	PRESENT	0
87455	87186	01034P	PARTICIPANT	\N	PRESENT	0
87456	87186	01043Q	PARTICIPANT	\N	PRESENT	0
87457	87186	14327T	PARTICIPANT	\N	PRESENT	0
87458	87186	04040A	PARTICIPANT	\N	PRESENT	0
87459	87186	08056B	PARTICIPANT	\N	PRESENT	0
87460	87186	01047U	PARTICIPANT	\N	PRESENT	0
87461	87186	08009T	PARTICIPANT	\N	PRESENT	0
87462	87186	95035G	PARTICIPANT	\N	PRESENT	0
87463	87186	14255U	PARTICIPANT	\N	PRESENT	0
87464	87186	11070L	PARTICIPANT	\N	PRESENT	0
87465	87186	04080J	PARTICIPANT	\N	PRESENT	0
87466	87186	98042T	PARTICIPANT	\N	PRESENT	0
91741	91739	11029K	PARTICIPANT	\N	PRESENT	0
91742	91739	14038Y	PARTICIPANT	\N	EXCUSE	0
91743	91739	11031D	PARTICIPANT	\N	EXCUSE	0
91744	91739	11027H	PARTICIPANT	\N	EXCUSE	0
91745	91739	80013X	PARTICIPANT	\N	PRESENT	0
91746	91739	14041T	PARTICIPANT	\N	EXCUSE	0
91747	91739	14281W	PARTICIPANT	\N	PRESENT	0
91748	91739	14014Q	PARTICIPANT	\N	EXCUSE	0
91749	91739	07026Q	PARTICIPANT	\N	PRESENT	0
91750	91739	08056B	PARTICIPANT	\N	EXCUSE	0
91751	91739	09001P	PRESIDENT	0	PRESENT	0
91752	91739	04036E	PARTICIPANT	\N	PRESENT	0
91753	91739	08031R	PARTICIPANT	\N	PRESENT	0
91754	91739	14031R	PARTICIPANT	\N	PRESENT	0
91254	89311	08051V	PARTICIPANT	\N	PRESENT	0
92026	92025	14133K	PARTICIPANT	\N	PRESENT	0
91755	91739	11067R	PARTICIPANT	\N	PRESENT	0
91756	91739	11014C	PARTICIPANT	\N	EXCUSE	0
91757	91739	14237S	PARTICIPANT	\N	PRESENT	0
91758	91739	08043V	PARTICIPANT	\N	PRESENT	0
92027	92025	96004D	PRESIDENT	0	PRESENT	0
92028	92025	14089Y	PARTICIPANT	\N	PRESENT	0
92029	92025	90003B	PARTICIPANT	\N	EXCUSE	0
92030	92025	14079W	PARTICIPANT	\N	PRESENT	0
92031	92025	11035H	PARTICIPANT	\N	PRESENT	0
92032	92025	11083R	PARTICIPANT	\N	EXCUSE	0
92033	92025	14026U	PARTICIPANT	\N	EXCUSE	0
92034	92025	95037J	PARTICIPANT	\N	PRESENT	0
92035	92025	14097Y	PARTICIPANT	\N	PRESENT	0
92036	92025	14073Q	PARTICIPANT	\N	PRESENT	0
92037	92025	11026G	PARTICIPANT	\N	PRESENT	0
92038	92025	98046X	PARTICIPANT	\N	PRESENT	0
92039	92025	14001X	PARTICIPANT	\N	PRESENT	0
92040	92025	04057K	PARTICIPANT	\N	PRESENT	0
92041	92025	08042U	PARTICIPANT	\N	PRESENT	0
92042	92025	04080J	PARTICIPANT	\N	PRESENT	0
92043	92025	95063L	PARTICIPANT	\N	PRESENT	0
92044	92025	98035U	PARTICIPANT	\N	PRESENT	0
92045	92025	92045V	PARTICIPANT	\N	PRESENT	0
92046	92025	11040E	PARTICIPANT	\N	PRESENT	0
92047	92025	04045F	PARTICIPANT	\N	EXCUSE	0
92248	92247	08010L	PARTICIPANT	\N	PRESENT	0
92251	92250	08010L	PARTICIPANT	\N	PRESENT	0
92254	92253	01057W	PARTICIPANT	\N	PRESENT	0
92255	92253	14225N	PARTICIPANT	\N	PRESENT	0
92258	92257	01057W	PARTICIPANT	\N	PRESENT	0
92259	92257	14225N	PARTICIPANT	\N	PRESENT	0
92261	92260	14327T	PARTICIPANT	\N	PRESENT	0
92263	92262	08022Q	PARTICIPANT	\N	PRESENT	0
92264	92262	99004R	PARTICIPANT	\N	PRESENT	0
92265	92262	88008L	PARTICIPANT	\N	PRESENT	0
92266	92262	08061X	PARTICIPANT	\N	PRESENT	0
92267	92262	11053K	PARTICIPANT	\N	PRESENT	0
92268	92262	04061F	PARTICIPANT	\N	PRESENT	0
92270	92269	08022Q	PARTICIPANT	\N	PRESENT	0
92271	92269	99004R	PARTICIPANT	\N	PRESENT	0
92272	92269	88008L	PARTICIPANT	\N	PRESENT	0
92273	92269	08061X	PARTICIPANT	\N	PRESENT	0
92274	92269	11053K	PARTICIPANT	\N	PRESENT	0
92275	92269	04061F	PARTICIPANT	\N	PRESENT	0
92277	92276	11088W	PARTICIPANT	\N	PRESENT	0
92279	92278	11088W	PARTICIPANT	\N	PRESENT	0
92281	92280	11088W	PARTICIPANT	\N	PRESENT	0
92284	92283	14175V	PARTICIPANT	\N	PRESENT	0
92285	92283	14085U	PARTICIPANT	\N	PRESENT	0
92287	92286	11053K	PARTICIPANT	\N	PRESENT	0
92558	92217	95062K	PARTICIPANT	\N	PRESENT	0
92559	92217	04036E	PARTICIPANT	\N	PRESENT	0
92560	92217	95031C	PARTICIPANT	\N	PRESENT	0
92561	92217	95015C	PARTICIPANT	\N	PRESENT	0
92562	92217	89029V	PARTICIPANT	\N	PRESENT	0
92563	92217	01048V	PARTICIPANT	\N	PRESENT	0
92564	92217	04033B	PARTICIPANT	\N	PRESENT	0
92565	92217	11080N	PARTICIPANT	\N	PRESENT	0
92566	92217	14259Y	PARTICIPANT	\N	PRESENT	0
92567	92217	14031R	PARTICIPANT	\N	PRESENT	0
92568	92217	04071H	PARTICIPANT	\N	PRESENT	0
92569	92217	01061S	PARTICIPANT	\N	PRESENT	0
92570	92217	11049P	PARTICIPANT	\N	PRESENT	0
92571	92217	04081K	PARTICIPANT	\N	PRESENT	0
92572	92217	99004R	PARTICIPANT	\N	PRESENT	0
92573	92217	08028W	PARTICIPANT	\N	PRESENT	0
92574	92217	14211G	PARTICIPANT	\N	PRESENT	0
92575	92217	14169X	PARTICIPANT	\N	PRESENT	0
92576	92217	14223L	PARTICIPANT	\N	PRESENT	0
92577	92217	92040Q	PARTICIPANT	\N	PRESENT	0
92578	92217	08010L	PARTICIPANT	\N	PRESENT	0
92579	92217	02002K	PARTICIPANT	\N	PRESENT	0
92580	92217	14173T	PARTICIPANT	\N	PRESENT	0
92581	92217	04074L	PARTICIPANT	\N	PRESENT	0
92582	92217	04049K	PARTICIPANT	\N	PRESENT	0
92583	92217	08041T	PARTICIPANT	\N	PRESENT	0
92584	92217	08022Q	PARTICIPANT	\N	PRESENT	0
92585	92217	08011M	PARTICIPANT	\N	PRESENT	0
92586	92217	14051J	PARTICIPANT	\N	PRESENT	0
92587	92217	04085P	PARTICIPANT	\N	PRESENT	0
92588	92217	98053W	PARTICIPANT	\N	PRESENT	0
92589	92217	01059Y	PARTICIPANT	\N	PRESENT	0
92590	92217	92018S	PARTICIPANT	\N	PRESENT	0
92591	92217	07026Q	PARTICIPANT	\N	PRESENT	0
92592	92217	01013J	PARTICIPANT	\N	PRESENT	0
92499	92217	86034E	PARTICIPANT	\N	PRESENT	0
92593	92217	14013P	PARTICIPANT	\N	PRESENT	0
92502	92500	14133K	PARTICIPANT	\N	EXCUSE	0
92594	92217	11034G	PARTICIPANT	\N	PRESENT	0
92504	92500	04059M	PARTICIPANT	\N	PRESENT	0
92595	92217	10006L	PARTICIPANT	\N	PRESENT	0
92506	92500	01044R	PARTICIPANT	\N	PRESENT	0
92596	92217	11031D	PARTICIPANT	\N	PRESENT	0
92597	92217	14235Q	PARTICIPANT	\N	PRESENT	0
92509	92500	14105F	PARTICIPANT	\N	PRESENT	0
92510	92500	11029K	PARTICIPANT	\N	PRESENT	0
92511	92500	95015C	PARTICIPANT	\N	PRESENT	0
92512	92500	92015P	PARTICIPANT	\N	PRESENT	0
92598	92217	14263U	PARTICIPANT	\N	PRESENT	0
92514	92500	14201E	PARTICIPANT	\N	EXCUSE	0
92599	92217	11098Y	PARTICIPANT	\N	PRESENT	0
92516	92500	14209N	PARTICIPANT	\N	PRESENT	0
92600	92217	14253S	PARTICIPANT	\N	PRESENT	0
92518	92500	11091R	PARTICIPANT	\N	PRESENT	0
92519	92500	87003B	PARTICIPANT	\N	PRESENT	0
92605	92217	77002U	PARTICIPANT	\N	PRESENT	0
92602	92217	04054G	PARTICIPANT	\N	PRESENT	0
92522	92500	01041N	PARTICIPANT	\N	PRESENT	0
92523	92500	01025N	PARTICIPANT	\N	PRESENT	0
92524	92500	01037S	PARTICIPANT	\N	EXCUSE	0
92603	92217	95059Q	PARTICIPANT	\N	PRESENT	0
92604	92217	01015L	PARTICIPANT	\N	PRESENT	0
92606	92217	04047H	PARTICIPANT	\N	PRESENT	0
92528	92500	07026Q	PARTICIPANT	\N	PRESENT	0
92607	92217	14026U	PARTICIPANT	\N	PRESENT	0
92608	92217	87003B	PARTICIPANT	\N	PRESENT	0
92609	92217	11029K	PARTICIPANT	\N	PRESENT	0
92532	92500	14241N	PARTICIPANT	\N	PRESENT	0
92610	92217	01044R	PARTICIPANT	\N	PRESENT	0
92534	92500	14073Q	PARTICIPANT	\N	PRESENT	0
92535	92500	08031R	PARTICIPANT	\N	PRESENT	0
92611	92217	96004D	PARTICIPANT	\N	PRESENT	0
92537	92500	08039A	PARTICIPANT	\N	PRESENT	0
92538	92500	08017T	PARTICIPANT	\N	EXCUSE	0
92539	92500	14059S	PARTICIPANT	\N	PRESENT	0
92612	92217	11055M	PARTICIPANT	\N	PRESENT	0
92613	92217	11083R	PARTICIPANT	\N	PRESENT	0
92614	92217	04097T	PARTICIPANT	\N	PRESENT	0
92543	92500	14063N	PARTICIPANT	\N	PRESENT	0
92544	92500	04057K	PARTICIPANT	\N	PRESENT	0
92615	92217	14055N	PARTICIPANT	\N	PRESENT	0
92546	92500	14109K	PARTICIPANT	\N	PRESENT	0
92547	92500	04070G	PRESIDENT	0	PRESENT	0
92616	92217	92044U	PARTICIPANT	\N	PRESENT	0
92617	92217	95067Q	PARTICIPANT	\N	PRESENT	0
92618	92217	08021P	PARTICIPANT	\N	PRESENT	0
92551	92500	14235Q	PARTICIPANT	\N	PRESENT	0
92619	92217	01019Q	PARTICIPANT	\N	PRESENT	0
92620	92217	01046T	PARTICIPANT	\N	PRESENT	0
92554	92500	14229S	PARTICIPANT	\N	PRESENT	0
92621	92217	90003B	PARTICIPANT	\N	PRESENT	0
92622	92217	88008L	PARTICIPANT	\N	PRESENT	0
92623	92217	11096W	PARTICIPANT	\N	PRESENT	0
92624	92217	14069U	PARTICIPANT	\N	PRESENT	0
92625	92217	11012A	PARTICIPANT	\N	PRESENT	0
92626	92217	92031P	PARTICIPANT	\N	PRESENT	0
92627	92217	14018U	PARTICIPANT	\N	PRESENT	0
92628	92217	14071N	PARTICIPANT	\N	PRESENT	0
92629	92217	11081P	PARTICIPANT	\N	PRESENT	0
92630	92217	08031R	PARTICIPANT	\N	PRESENT	0
92631	92217	14215L	PARTICIPANT	\N	PRESENT	0
92632	92217	14261S	PARTICIPANT	\N	PRESENT	0
92633	92217	98022P	PARTICIPANT	\N	PRESENT	0
63150	63149	10015M	PARTICIPANT	\N	PRESENT	0
63152	63151	10015M	PARTICIPANT	\N	PRESENT	0
66330	60592	11109J	PARTICIPANT	\N	PRESENT	0
66331	60592	11114F	PARTICIPANT	\N	PRESENT	0
66332	60592	14259Y	PARTICIPANT	\N	PRESENT	0
66333	60592	01027Q	PARTICIPANT	\N	PRESENT	0
66334	60592	04095R	PARTICIPANT	\N	PRESENT	0
66336	60592	01022K	PARTICIPANT	\N	PRESENT	0
66338	60592	04094Q	PARTICIPANT	\N	PRESENT	0
66340	60592	08019V	PRESIDENT	0	PRESENT	0
66341	60592	04043D	PARTICIPANT	\N	PRESENT	0
66342	60592	11025F	PARTICIPANT	\N	PRESENT	0
66344	60592	11071M	PARTICIPANT	\N	PRESENT	0
66347	60592	95062K	PARTICIPANT	\N	PRESENT	0
66348	60592	11054L	PARTICIPANT	\N	PRESENT	0
66432	66431	14089Y	PARTICIPANT	\N	PRESENT	0
66433	66431	11029K	PARTICIPANT	\N	PRESENT	0
66434	66431	08028W	PARTICIPANT	\N	EXCUSE	0
66435	66431	88008L	PARTICIPANT	\N	EXCUSE	0
66436	66431	04038G	PARTICIPANT	\N	PRESENT	0
66437	66431	01059Y	PARTICIPANT	\N	EXCUSE	0
66438	66431	01015L	PARTICIPANT	\N	EXCUSE	0
66439	66431	01041N	PARTICIPANT	\N	EXCUSE	0
66440	66431	14187A	PARTICIPANT	\N	EXCUSE	0
66441	66431	14179A	PARTICIPANT	\N	EXCUSE	0
66442	66431	14121F	PARTICIPANT	\N	PRESENT	0
66443	66431	11084S	PARTICIPANT	\N	PRESENT	0
66444	66431	08012N	PARTICIPANT	\N	EXCUSE	0
66445	66431	08062Y	PARTICIPANT	\N	EXCUSE	0
66446	66431	14229S	PARTICIPANT	\N	EXCUSE	0
66447	66431	11094U	PARTICIPANT	\N	EXCUSE	0
66448	66431	11066Q	PARTICIPANT	\N	PRESENT	0
66449	66431	92045V	PARTICIPANT	\N	EXCUSE	0
69444	69443	11044J	PARTICIPANT	\N	PRESENT	0
69445	69443	11067R	PARTICIPANT	\N	PRESENT	0
69447	69446	14087W	PARTICIPANT	\N	PRESENT	0
69449	69448	01027Q	PRESIDENT	0	PRESENT	0
69450	69448	14159V	PARTICIPANT	\N	PRESENT	0
69451	69448	01013J	PARTICIPANT	\N	PRESENT	0
69452	69448	11012A	PARTICIPANT	\N	PRESENT	0
69453	69448	14225N	PARTICIPANT	\N	PRESENT	0
69454	69448	01057W	PARTICIPANT	\N	PRESENT	0
73136	56945	11048N	PARTICIPANT	\N	PRESENT	0
78937	75076	11023D	PARTICIPANT	\N	EXCUSE	0
79712	78238	99002P	PARTICIPANT	\N	PRESENT	0
79713	78238	08017T	PARTICIPANT	\N	PRESENT	0
79714	78238	11085T	PARTICIPANT	\N	PRESENT	0
79715	78238	95067Q	PARTICIPANT	\N	PRESENT	0
79716	78238	14034U	PARTICIPANT	\N	PRESENT	0
79717	78238	11027H	PARTICIPANT	\N	PRESENT	0
79718	78238	04056J	PARTICIPANT	\N	PRESENT	0
79719	78238	11039M	PARTICIPANT	\N	PRESENT	0
79721	78238	11099A	PARTICIPANT	\N	PRESENT	0
79723	78238	01015L	PARTICIPANT	\N	PRESENT	0
79745	78238	04070G	PARTICIPANT	\N	PRESENT	0
79746	78238	04059M	PARTICIPANT	\N	PRESENT	0
79751	78238	11026G	PARTICIPANT	\N	PRESENT	0
80000	78236	98053W	PARTICIPANT	\N	PRESENT	0
80001	78236	05008E	PARTICIPANT	\N	PRESENT	0
80002	78236	95049N	PARTICIPANT	\N	PRESENT	0
80003	78236	14041T	PARTICIPANT	\N	PRESENT	0
80004	78236	98005N	PARTICIPANT	\N	PRESENT	0
80018	78236	14042U	PARTICIPANT	\N	PRESENT	0
80006	78236	07004J	PARTICIPANT	\N	PRESENT	0
80007	78236	11071M	PARTICIPANT	\N	PRESENT	0
80008	78236	11033F	PARTICIPANT	\N	PRESENT	0
80009	78236	14033T	PARTICIPANT	\N	PRESENT	0
80010	78236	97011G	PARTICIPANT	\N	PRESENT	0
80013	78236	08065C	PARTICIPANT	\N	PRESENT	0
80014	78236	14205J	PARTICIPANT	\N	PRESENT	0
80015	78236	11067R	PARTICIPANT	\N	PRESENT	0
80016	78236	04067M	PARTICIPANT	\N	PRESENT	0
80017	78236	11091R	PARTICIPANT	\N	PRESENT	0
80019	78236	14065Q	PARTICIPANT	\N	PRESENT	0
80021	78236	11056N	PARTICIPANT	\N	PRESENT	0
80023	78236	11076S	PARTICIPANT	\N	PRESENT	0
80024	78236	11026G	PARTICIPANT	\N	PRESENT	0
80025	78236	04036E	PARTICIPANT	\N	PRESENT	0
80026	78236	14073Q	PARTICIPANT	\N	PRESENT	0
80027	78236	11036J	PARTICIPANT	\N	PRESENT	0
80028	78236	11049P	PARTICIPANT	\N	PRESENT	0
80029	78236	14135M	PARTICIPANT	\N	PRESENT	0
80030	78236	04088S	PARTICIPANT	\N	PRESENT	0
80031	78236	08051V	PARTICIPANT	\N	PRESENT	0
80032	78236	01028R	PARTICIPANT	\N	PRESENT	0
80033	78236	04077P	PARTICIPANT	\N	PRESENT	0
80034	78236	08034U	PARTICIPANT	\N	PRESENT	0
80035	78236	95063L	PARTICIPANT	\N	PRESENT	0
80036	78236	11061K	PARTICIPANT	\N	PRESENT	0
80037	78236	11097X	PARTICIPANT	\N	PRESENT	0
80058	78236	99004R	PARTICIPANT	\N	PRESENT	0
80059	78236	95030B	PARTICIPANT	\N	PRESENT	0
80040	78236	86044G	PARTICIPANT	\N	PRESENT	0
80060	78236	04038G	PARTICIPANT	\N	PRESENT	0
80061	78236	08053X	PARTICIPANT	\N	PRESENT	0
80062	78236	14191V	PARTICIPANT	\N	PRESENT	0
80068	78236	14034U	PARTICIPANT	\N	PRESENT	0
80069	78236	08019V	PARTICIPANT	\N	PRESENT	0
80070	78236	11031D	PARTICIPANT	\N	PRESENT	0
80072	78236	04085P	PARTICIPANT	\N	PRESENT	0
80074	78236	04043D	PARTICIPANT	\N	PRESENT	0
80090	78236	04086Q	PARTICIPANT	\N	PRESENT	0
80093	78236	01048V	PARTICIPANT	\N	PRESENT	0
80094	78236	11064N	PARTICIPANT	\N	PRESENT	0
80095	78236	04056J	PARTICIPANT	\N	PRESENT	0
80096	78236	04071H	PARTICIPANT	\N	PRESENT	0
80139	80113	14263U	PARTICIPANT	\N	PRESENT	0
80140	80113	14195A	PARTICIPANT	\N	PRESENT	0
80141	80113	14249W	PARTICIPANT	\N	PRESENT	0
80142	80113	97011G	PARTICIPANT	\N	PRESENT	0
80143	80113	08056B	PARTICIPANT	\N	PRESENT	0
80144	80113	01057W	PARTICIPANT	\N	PRESENT	0
80145	80113	01022K	PARTICIPANT	\N	PRESENT	0
80146	80113	11026G	PARTICIPANT	\N	PRESENT	0
80147	80113	92031P	PARTICIPANT	\N	PRESENT	0
80148	80113	95067Q	PARTICIPANT	\N	PRESENT	0
80156	77795	96003C	PARTICIPANT	\N	EXCUSE	0
80160	80159	07024N	PARTICIPANT	\N	PRESENT	0
80161	80158	01008M	PARTICIPANT	\N	PRESENT	0
80162	80158	08055A	PARTICIPANT	\N	PRESENT	0
80163	80158	88008L	PARTICIPANT	\N	PRESENT	0
80164	80158	14042U	PARTICIPANT	\N	PRESENT	0
80165	80158	12042Y	PARTICIPANT	\N	PRESENT	0
80166	80158	97011G	PARTICIPANT	\N	PRESENT	0
80167	80158	01037S	PARTICIPANT	\N	PRESENT	0
80168	80158	14033T	PARTICIPANT	\N	PRESENT	0
80169	80158	01061S	PARTICIPANT	\N	PRESENT	0
80170	80158	14205J	PARTICIPANT	\N	PRESENT	0
80171	80158	11014C	PARTICIPANT	\N	PRESENT	0
80172	80158	14265W	PARTICIPANT	\N	PRESENT	0
80173	80158	14169X	PARTICIPANT	\N	PRESENT	0
80174	80158	04088S	PARTICIPANT	\N	PRESENT	0
80175	80158	11043H	PARTICIPANT	\N	PRESENT	0
80176	80158	92045V	PARTICIPANT	\N	PRESENT	0
80177	80158	95067Q	PARTICIPANT	\N	PRESENT	0
80283	80280	14133K	PARTICIPANT	\N	PRESENT	0
80203	77795	04094Q	PARTICIPANT	\N	EXCUSE	0
80227	80226	04055H	PARTICIPANT	\N	PRESENT	0
80375	57183	01028R	PARTICIPANT	\N	PRESENT	0
80407	80406	08052W	PARTICIPANT	\N	PRESENT	0
80408	80406	01034P	PARTICIPANT	\N	PRESENT	0
80437	80436	05008E	PRESIDENT	0	PRESENT	0
80438	80436	11033F	PARTICIPANT	\N	PRESENT	0
80439	80436	14069U	PARTICIPANT	\N	PRESENT	0
80440	80436	04047H	PARTICIPANT	\N	PRESENT	0
80441	80436	14041T	PARTICIPANT	\N	PRESENT	0
80442	80436	08018U	PARTICIPANT	\N	PRESENT	0
80443	80436	14111D	PARTICIPANT	\N	PRESENT	0
80444	80436	14001X	PARTICIPANT	\N	PRESENT	0
80445	80436	14273W	PARTICIPANT	\N	PRESENT	0
80446	80436	95049N	PARTICIPANT	\N	EXCUSE	0
80447	80436	11072N	PARTICIPANT	\N	PRESENT	0
80448	80436	07034Q	PARTICIPANT	\N	PRESENT	0
80449	80436	01028R	PARTICIPANT	\N	PRESENT	0
80450	80436	98035U	PARTICIPANT	\N	PRESENT	0
77518	77517	04074L	PARTICIPANT	\N	PRESENT	0
77524	77523	08022Q	PARTICIPANT	\N	PRESENT	0
77526	77525	08022Q	PARTICIPANT	\N	PRESENT	0
77528	77527	08022Q	PARTICIPANT	\N	PRESENT	0
77530	77529	08022Q	PARTICIPANT	\N	PRESENT	0
77532	77531	08022Q	PARTICIPANT	\N	PRESENT	0
77534	77533	08022Q	PARTICIPANT	\N	PRESENT	0
77536	77535	04055H	PARTICIPANT	\N	PRESENT	0
77538	77537	08011M	PARTICIPANT	\N	PRESENT	0
77540	77539	04086Q	PARTICIPANT	\N	PRESENT	0
77542	77541	04086Q	PARTICIPANT	\N	PRESENT	0
77544	77543	04086Q	PARTICIPANT	\N	PRESENT	0
77546	77545	04086Q	PARTICIPANT	\N	PRESENT	0
77548	77547	04086Q	PARTICIPANT	\N	PRESENT	0
77550	77549	04086Q	PARTICIPANT	\N	PRESENT	0
77552	77551	04086Q	PARTICIPANT	\N	PRESENT	0
77554	77553	04086Q	PARTICIPANT	\N	PRESENT	0
77556	77555	11053K	PARTICIPANT	\N	PRESENT	0
77558	77557	11068S	PARTICIPANT	\N	PRESENT	0
77610	77608	92039X	PARTICIPANT	\N	PRESENT	0
77597	77592	08011M	PARTICIPANT	\N	PRESENT	0
77609	77608	04077P	PARTICIPANT	\N	PRESENT	0
77726	77725	11031D	PARTICIPANT	\N	PRESENT	0
77727	77725	14039A	PARTICIPANT	\N	PRESENT	0
77728	77725	11098Y	PARTICIPANT	\N	PRESENT	0
77729	77725	05012A	PARTICIPANT	\N	PRESENT	0
77746	77745	98023Q	PARTICIPANT	\N	PRESENT	0
77747	77745	92039X	PARTICIPANT	\N	PRESENT	0
77748	77745	08015R	PARTICIPANT	\N	PRESENT	0
77749	77745	08056B	PARTICIPANT	\N	PRESENT	0
77751	77750	98018T	PARTICIPANT	\N	PRESENT	0
77753	77752	01031L	PARTICIPANT	\N	PRESENT	0
77754	77752	92020L	PARTICIPANT	\N	PRESENT	0
88744	88743	14239U	PARTICIPANT	\N	PRESENT	0
88745	88743	11055M	PARTICIPANT	\N	PRESENT	0
88746	88743	01046T	PARTICIPANT	\N	PRESENT	0
88747	88743	04053F	PARTICIPANT	\N	PRESENT	0
88748	88743	14255U	PARTICIPANT	\N	EXCUSE	0
88886	88884	04085P	PARTICIPANT	\N	PRESENT	0
88750	88743	00003C	PARTICIPANT	\N	PRESENT	0
88751	88743	14053L	PARTICIPANT	\N	PRESENT	0
88752	88743	11103C	PARTICIPANT	\N	PRESENT	0
88887	88884	05008E	PRESIDENT	0	PRESENT	0
88754	88743	14195A	PARTICIPANT	\N	PRESENT	0
88755	88743	14267Y	PARTICIPANT	\N	PRESENT	0
88756	88743	11023D	PARTICIPANT	\N	EXCUSE	0
88757	88743	11031D	PARTICIPANT	\N	PRESENT	0
88758	88743	08052W	PARTICIPANT	\N	PRESENT	0
88759	88743	01059Y	PARTICIPANT	\N	EXCUSE	0
88760	88743	04081K	PARTICIPANT	\N	PRESENT	0
88761	88743	98024R	PARTICIPANT	\N	PRESENT	0
88996	88995	01027Q	PRESIDENT	0	PRESENT	0
88763	88743	04067M	PARTICIPANT	\N	PRESENT	0
88764	88743	14217N	PARTICIPANT	\N	PRESENT	0
88765	88743	14042U	PARTICIPANT	\N	PRESENT	0
88766	88743	14151M	PARTICIPANT	\N	PRESENT	0
88767	88743	12042Y	PARTICIPANT	\N	PRESENT	0
88889	88884	11030C	PARTICIPANT	\N	PRESENT	0
88890	88884	11033F	PARTICIPANT	\N	PRESENT	0
88770	88743	01003G	PARTICIPANT	\N	PRESENT	0
88771	88743	14034U	PARTICIPANT	\N	PRESENT	0
88891	88884	14065Q	PARTICIPANT	\N	PRESENT	0
88773	88743	11061K	PARTICIPANT	\N	PRESENT	0
88774	88743	08048B	PARTICIPANT	\N	PRESENT	0
88775	88743	08041T	PARTICIPANT	\N	PRESENT	0
88892	88884	14069U	PARTICIPANT	\N	PRESENT	0
88777	88743	14026U	PARTICIPANT	\N	PRESENT	0
88778	88743	14213J	PARTICIPANT	\N	PRESENT	0
88779	88743	14121F	PARTICIPANT	\N	PRESENT	0
88780	88743	11112D	PARTICIPANT	\N	PRESENT	0
88781	88743	14037X	PARTICIPANT	\N	PRESENT	0
88782	88743	14018U	PARTICIPANT	\N	PRESENT	0
88893	88884	04047H	PARTICIPANT	\N	PRESENT	0
88784	88743	14223L	PARTICIPANT	\N	PRESENT	0
88785	88743	04092N	PRESIDENT	0	PRESENT	0
88786	88743	14265W	PARTICIPANT	\N	PRESENT	0
88787	88743	14119M	PARTICIPANT	\N	PRESENT	0
88788	88743	14071N	PARTICIPANT	\N	PRESENT	0
88789	88743	07032N	PARTICIPANT	\N	PRESENT	0
88894	88884	11032E	PARTICIPANT	\N	PRESENT	0
88895	88884	04038G	PARTICIPANT	\N	PRESENT	0
88896	88884	99002P	PARTICIPANT	\N	PRESENT	0
88793	88743	11093T	PARTICIPANT	\N	PRESENT	0
88794	88743	11097X	PARTICIPANT	\N	PRESENT	0
88795	88743	04045F	PARTICIPANT	\N	PRESENT	0
88796	88743	14227Q	PARTICIPANT	\N	PRESENT	0
88797	88743	01034P	PARTICIPANT	\N	PRESENT	0
88798	88743	11025F	PARTICIPANT	\N	PRESENT	0
88897	88884	11056N	PARTICIPANT	\N	PRESENT	0
88898	88884	14259Y	PARTICIPANT	\N	PRESENT	0
88899	88884	11035H	PARTICIPANT	\N	PRESENT	0
88900	88884	14041T	PARTICIPANT	\N	PRESENT	0
88901	88884	11113E	PARTICIPANT	\N	PRESENT	0
88902	88884	01024M	PARTICIPANT	\N	PRESENT	0
88903	88884	14215L	PARTICIPANT	\N	PRESENT	0
88904	88884	11034G	PARTICIPANT	\N	PRESENT	0
88997	88995	14159V	PARTICIPANT	\N	PRESENT	0
88998	88995	01057W	PARTICIPANT	\N	PRESENT	0
88907	88884	01007L	PARTICIPANT	\N	PRESENT	0
88999	88995	14157T	PARTICIPANT	\N	PRESENT	0
88909	88884	08044W	PARTICIPANT	\N	PRESENT	0
88910	88884	11084S	PARTICIPANT	\N	PRESENT	0
88911	88884	11026G	PARTICIPANT	\N	PRESENT	0
88912	88884	04079R	PARTICIPANT	\N	PRESENT	0
89000	88995	01013J	PARTICIPANT	\N	EXCUSE	0
89001	88995	11012A	PARTICIPANT	\N	EXCUSE	0
88915	88884	14273W	PARTICIPANT	\N	PRESENT	0
88916	88884	01060R	PARTICIPANT	\N	PRESENT	0
88917	88884	14147R	PARTICIPANT	\N	PRESENT	0
88918	88884	95049N	PARTICIPANT	\N	PRESENT	0
89003	89002	01027Q	PRESIDENT	0	PRESENT	0
88920	88884	11072N	PARTICIPANT	\N	PRESENT	0
88921	88884	07034Q	PARTICIPANT	\N	PRESENT	0
88922	88884	04074L	PARTICIPANT	\N	PRESENT	0
88923	88884	10015M	PARTICIPANT	\N	PRESENT	0
88924	88884	95063L	PARTICIPANT	\N	PRESENT	0
88925	88884	01019Q	PARTICIPANT	\N	PRESENT	0
88926	88884	01028R	PARTICIPANT	\N	PRESENT	0
88927	88884	98035U	PARTICIPANT	\N	PRESENT	0
88928	88884	04056J	PARTICIPANT	\N	PRESENT	0
88929	88884	14275Y	PARTICIPANT	\N	PRESENT	0
88930	88884	04044E	PARTICIPANT	\N	PRESENT	0
88931	88884	11037K	PARTICIPANT	\N	PRESENT	0
88932	88884	92045V	PARTICIPANT	\N	PRESENT	0
88933	88884	95067Q	PARTICIPANT	\N	PRESENT	0
89004	89002	14159V	PARTICIPANT	\N	PRESENT	0
89006	89002	01057W	PARTICIPANT	\N	PRESENT	0
89007	89002	01013J	PARTICIPANT	\N	PRESENT	0
89008	89002	11012A	PARTICIPANT	\N	PRESENT	0
89392	89391	14213J	PARTICIPANT	\N	PRESENT	0
89394	89393	14213J	PARTICIPANT	\N	PRESENT	0
89396	89395	14213J	PARTICIPANT	\N	PRESENT	0
89398	89397	14213J	PARTICIPANT	\N	PRESENT	0
89560	89554	11039M	PARTICIPANT	\N	PRESENT	0
89588	89554	08012N	PARTICIPANT	\N	PRESENT	0
89589	89554	14235Q	PARTICIPANT	\N	PRESENT	0
90502	90499	08058D	PARTICIPANT	\N	PRESENT	0
90500	90499	04054G	PARTICIPANT	\N	PRESENT	0
90501	90499	04040A	PARTICIPANT	\N	PRESENT	0
90503	90499	04042C	PARTICIPANT	\N	PRESENT	0
90504	90499	77002U	PARTICIPANT	\N	PRESENT	0
90505	90499	98029W	PARTICIPANT	\N	PRESENT	0
90506	90499	11027H	PARTICIPANT	\N	EXCUSE	0
90507	90499	98018T	PARTICIPANT	\N	PRESENT	0
90508	90499	92018S	PARTICIPANT	\N	PRESENT	0
90509	90499	92020L	PARTICIPANT	\N	PRESENT	0
90510	90499	95030B	PARTICIPANT	\N	PRESENT	0
90511	90499	95031C	PARTICIPANT	\N	PRESENT	0
90512	90499	97011G	PARTICIPANT	\N	PRESENT	0
90513	90499	08065C	PARTICIPANT	\N	PRESENT	0
90514	90499	04035D	PARTICIPANT	\N	EXCUSE	0
90515	90499	07024N	PRESIDENT	1	PRESENT	0
90516	90499	14014Q	PARTICIPANT	\N	PRESENT	0
90517	90499	11015D	PARTICIPANT	\N	PRESENT	0
90518	90499	95035G	PARTICIPANT	\N	PRESENT	0
90519	90499	08056B	PARTICIPANT	\N	EXCUSE	0
90520	90499	14211G	PARTICIPANT	\N	PRESENT	0
90521	90499	98022P	PARTICIPANT	\N	PRESENT	0
90522	90499	95037J	PARTICIPANT	\N	PRESENT	0
90523	90499	04078Q	PARTICIPANT	\N	PRESENT	0
90524	90499	14097Y	PARTICIPANT	\N	PRESENT	0
90525	90499	04036E	PARTICIPANT	\N	PRESENT	0
90526	90499	14039A	PARTICIPANT	\N	PRESENT	0
90527	90499	92031P	PARTICIPANT	\N	PRESENT	0
90528	90499	11106F	PARTICIPANT	\N	PRESENT	0
90529	90499	14251Q	PARTICIPANT	\N	PRESENT	0
90530	90499	08053X	PARTICIPANT	\N	PRESENT	0
90531	90499	11082Q	PARTICIPANT	\N	PRESENT	0
90532	90499	11105E	PARTICIPANT	\N	EXCUSE	0
62841	62840	11040E	PARTICIPANT	\N	PRESENT	0
62842	62840	14089Y	PARTICIPANT	\N	PRESENT	0
62843	62840	14079W	PARTICIPANT	\N	PRESENT	0
62844	62840	95030B	PRESIDENT	0	PRESENT	0
62845	62840	04035D	PARTICIPANT	\N	PRESENT	0
62846	62840	14097Y	PARTICIPANT	\N	PRESENT	0
62847	62840	04061F	PARTICIPANT	\N	PRESENT	0
62848	62840	98046X	PARTICIPANT	\N	PRESENT	0
62849	62840	14001X	PARTICIPANT	\N	PRESENT	0
62850	62840	08073C	PARTICIPANT	\N	PRESENT	0
62851	62840	01016M	PARTICIPANT	\N	PRESENT	0
62852	62840	10015M	PARTICIPANT	\N	PRESENT	0
62853	62840	14135M	PARTICIPANT	\N	PRESENT	0
62854	62840	11012A	PARTICIPANT	\N	PRESENT	0
62855	62840	92045V	PARTICIPANT	\N	PRESENT	0
62856	62840	11083R	PARTICIPANT	\N	PRESENT	0
62857	62840	90003B	PARTICIPANT	\N	EXCUSE	0
62858	62840	14133K	PARTICIPANT	\N	EXCUSE	0
62859	62840	11035H	PARTICIPANT	\N	EXCUSE	0
62860	62840	04057K	PARTICIPANT	\N	EXCUSE	0
64012	57873	14119M	PARTICIPANT	\N	PRESENT	0
64013	57873	14042U	PARTICIPANT	\N	PRESENT	0
64014	56229	14195A	PARTICIPANT	\N	PRESENT	0
66354	66353	08025T	PARTICIPANT	\N	PRESENT	0
66355	66353	04085P	PARTICIPANT	\N	PRESENT	0
66356	66353	05008E	PRESIDENT	0	PRESENT	0
66357	66353	14065Q	PARTICIPANT	\N	PRESENT	0
66358	66353	04047H	PARTICIPANT	\N	PRESENT	0
66359	66353	01024M	PARTICIPANT	\N	EXCUSE	0
66360	66353	11034G	PARTICIPANT	\N	PRESENT	0
66361	66353	11084S	PARTICIPANT	\N	PRESENT	0
66362	66353	11026G	PARTICIPANT	\N	PRESENT	0
66363	66353	04079R	PARTICIPANT	\N	PRESENT	0
66364	66353	14001X	PARTICIPANT	\N	PRESENT	0
66365	66353	14273W	PARTICIPANT	\N	PRESENT	0
66366	66353	08051V	PARTICIPANT	\N	PRESENT	0
66367	66353	07034Q	PARTICIPANT	\N	PRESENT	0
66368	66353	04074L	PARTICIPANT	\N	PRESENT	0
66370	66353	10015M	PARTICIPANT	\N	PRESENT	0
66371	66353	95063L	PARTICIPANT	\N	PRESENT	0
66372	66353	01028R	PARTICIPANT	\N	PRESENT	0
66373	66353	04056J	PARTICIPANT	\N	PRESENT	0
66376	66353	04044E	PARTICIPANT	\N	PRESENT	0
66377	66353	11037K	PARTICIPANT	\N	PRESENT	0
66378	66353	92045V	PARTICIPANT	\N	PRESENT	0
75312	75219	86034E	PARTICIPANT	\N	PRESENT	0
75315	75219	14033T	PARTICIPANT	\N	PRESENT	0
75319	75219	95031C	PARTICIPANT	\N	PRESENT	0
75320	75219	14087W	PARTICIPANT	\N	PRESENT	0
75321	75219	14041T	PARTICIPANT	\N	PRESENT	0
75333	75219	00003C	PARTICIPANT	\N	PRESENT	0
75326	75219	14097Y	PARTICIPANT	\N	PRESENT	0
75331	75219	14267Y	PARTICIPANT	\N	PRESENT	0
75342	75219	14213J	PARTICIPANT	\N	PRESENT	0
75345	75219	11025F	PARTICIPANT	\N	PRESENT	0
75348	75219	14059S	PARTICIPANT	\N	PRESENT	0
75350	75219	14249W	PARTICIPANT	\N	PRESENT	0
75351	75219	14271U	PARTICIPANT	\N	PRESENT	0
75352	75219	14277B	PARTICIPANT	\N	PRESENT	0
75353	75219	14275Y	PARTICIPANT	\N	PRESENT	0
75354	75219	14030Q	PARTICIPANT	\N	PRESENT	0
75356	75219	01024M	PARTICIPANT	\N	PRESENT	0
75358	75219	11055M	PARTICIPANT	\N	PRESENT	0
75360	75219	09001P	PARTICIPANT	\N	PRESENT	0
75361	75219	08060W	PARTICIPANT	\N	PRESENT	0
75362	75219	11105E	PARTICIPANT	\N	PRESENT	0
75364	75219	14085U	PARTICIPANT	\N	PRESENT	0
75365	75219	14247U	PARTICIPANT	\N	PRESENT	0
75366	75219	08069G	PARTICIPANT	\N	PRESENT	0
75367	75219	04097T	PARTICIPANT	\N	PRESENT	0
75368	75219	08021P	PARTICIPANT	\N	PRESENT	0
75369	75219	04094Q	PARTICIPANT	\N	PRESENT	0
75370	75219	14039A	PARTICIPANT	\N	PRESENT	0
75371	75219	92018S	PARTICIPANT	\N	PRESENT	0
75372	75219	08053X	PARTICIPANT	\N	PRESENT	0
75373	75219	01022K	PARTICIPANT	\N	PRESENT	0
75374	75219	01043Q	PARTICIPANT	\N	PRESENT	0
75495	75219	07026Q	PARTICIPANT	\N	PRESENT	0
75376	75219	04078Q	PARTICIPANT	\N	PRESENT	0
75378	75219	04036E	PARTICIPANT	\N	PRESENT	0
75380	75219	92039X	PARTICIPANT	\N	PRESENT	0
75381	75219	14073Q	PARTICIPANT	\N	PRESENT	0
75382	75219	14038Y	PARTICIPANT	\N	PRESENT	0
75388	75219	14159V	PARTICIPANT	\N	PRESENT	0
75384	75219	11035H	PARTICIPANT	\N	PRESENT	0
75385	75219	11097X	PARTICIPANT	\N	PRESENT	0
75386	75219	99004R	PARTICIPANT	\N	PRESENT	0
75391	75219	11093T	PARTICIPANT	\N	PRESENT	0
75393	75219	11081P	PARTICIPANT	\N	PRESENT	0
75394	75219	14263U	PARTICIPANT	\N	PRESENT	0
75395	75219	04050C	PARTICIPANT	\N	PRESENT	0
75396	75219	08041T	PARTICIPANT	\N	PRESENT	0
75397	75219	95049N	PARTICIPANT	\N	PRESENT	0
75399	75219	11049P	PARTICIPANT	\N	PRESENT	0
75401	75219	08047A	PARTICIPANT	\N	PRESENT	0
75403	75219	07029T	PARTICIPANT	\N	PRESENT	0
75404	75219	04085P	PARTICIPANT	\N	PRESENT	0
75405	75219	14209N	PARTICIPANT	\N	PRESENT	0
75406	75219	01046T	PARTICIPANT	\N	PRESENT	0
75408	75219	98029W	PARTICIPANT	\N	PRESENT	0
75409	75219	01019Q	PARTICIPANT	\N	PRESENT	0
75411	75219	08028W	PARTICIPANT	\N	PRESENT	0
75412	75219	04088S	PARTICIPANT	\N	PRESENT	0
75413	75219	08051V	PARTICIPANT	\N	PRESENT	0
75414	75219	14079W	PARTICIPANT	\N	PRESENT	0
75415	75219	11103C	PARTICIPANT	\N	PRESENT	0
75416	75219	01048V	PARTICIPANT	\N	PRESENT	0
75417	75219	14201E	PARTICIPANT	\N	PRESENT	0
75418	75219	95062K	PARTICIPANT	\N	PRESENT	0
75419	75219	02002K	PARTICIPANT	\N	PRESENT	0
75420	75219	11053K	PARTICIPANT	\N	PRESENT	0
75421	75219	11090Q	PARTICIPANT	\N	PRESENT	0
75422	75219	11111C	PARTICIPANT	\N	PRESENT	0
75423	75219	01061S	PARTICIPANT	\N	PRESENT	0
75425	75219	11044J	PARTICIPANT	\N	PRESENT	0
75427	75219	95063L	PARTICIPANT	\N	PRESENT	0
75428	75219	14061L	PARTICIPANT	\N	PRESENT	0
75429	75219	07034Q	PARTICIPANT	\N	PRESENT	0
75430	75219	08052W	PARTICIPANT	\N	PRESENT	0
75431	75219	14169X	PARTICIPANT	\N	PRESENT	0
75434	75219	14167V	PARTICIPANT	\N	PRESENT	0
75435	75219	11033F	PARTICIPANT	\N	PRESENT	0
75436	75219	04086Q	PARTICIPANT	\N	PRESENT	0
75437	75219	01044R	PARTICIPANT	\N	PRESENT	0
75438	75219	96004D	PARTICIPANT	\N	PRESENT	0
75439	75219	14211G	PARTICIPANT	\N	PRESENT	0
75440	75219	98046X	PARTICIPANT	\N	PRESENT	0
75441	75219	89029V	PARTICIPANT	\N	PRESENT	0
75443	75219	14051J	PARTICIPANT	\N	PRESENT	0
75444	75219	04034C	PARTICIPANT	\N	PRESENT	0
75445	75219	01027Q	PARTICIPANT	\N	PRESENT	0
75446	75219	08044W	PARTICIPANT	\N	PRESENT	0
75447	75219	04042C	PARTICIPANT	\N	PRESENT	0
75448	75219	14197C	PARTICIPANT	\N	PRESENT	0
75449	75219	04033B	PARTICIPANT	\N	PRESENT	0
75451	75219	12041X	PARTICIPANT	\N	PRESENT	0
75452	75219	14111D	PARTICIPANT	\N	PRESENT	0
75453	75219	14223L	PARTICIPANT	\N	PRESENT	0
75454	75219	11034G	PARTICIPANT	\N	PRESENT	0
75455	75219	07032N	PARTICIPANT	\N	PRESENT	0
75456	75219	11056N	PARTICIPANT	\N	PRESENT	0
75457	75219	14093U	PARTICIPANT	\N	PRESENT	0
75458	75219	08015R	PARTICIPANT	\N	PRESENT	0
75459	75219	11057P	PARTICIPANT	\N	PRESENT	0
75460	75219	11040E	PARTICIPANT	\N	PRESENT	0
75461	75219	95015C	PARTICIPANT	\N	PRESENT	0
75462	75219	14175V	PARTICIPANT	\N	PRESENT	0
75463	75219	14259Y	PARTICIPANT	\N	PRESENT	0
75464	75219	04081K	PARTICIPANT	\N	PRESENT	0
75465	75219	95041E	PARTICIPANT	\N	PRESENT	0
75466	75219	04048J	PARTICIPANT	\N	PRESENT	0
75467	75219	08034U	PARTICIPANT	\N	PRESENT	0
75468	75219	97011G	PARTICIPANT	\N	PRESENT	0
75469	75219	08065C	PARTICIPANT	\N	PRESENT	0
75470	75219	14017T	PARTICIPANT	\N	PRESENT	0
75471	75219	11080N	PARTICIPANT	\N	PRESENT	0
75472	75219	11098Y	PARTICIPANT	\N	PRESENT	0
75474	75219	92031P	PARTICIPANT	\N	PRESENT	0
75475	75219	11059R	PARTICIPANT	\N	PRESENT	0
75476	75219	14028W	PARTICIPANT	\N	PRESENT	0
75477	75219	11088W	PARTICIPANT	\N	PRESENT	0
75478	75219	08014Q	PARTICIPANT	\N	PRESENT	0
75481	75219	95030B	PARTICIPANT	\N	PRESENT	0
75482	75219	14187A	PARTICIPANT	\N	PRESENT	0
75483	75219	05008E	PARTICIPANT	\N	PRESENT	0
75486	75219	04092N	PARTICIPANT	\N	PRESENT	0
75493	75219	08011M	PARTICIPANT	\N	PRESENT	0
75494	75219	90003B	PARTICIPANT	\N	PRESENT	0
75694	75219	04044E	PARTICIPANT	\N	PRESENT	0
75699	75219	14251Q	PARTICIPANT	\N	PRESENT	0
75707	75219	01015L	PARTICIPANT	\N	PRESENT	0
75705	75219	04043D	PARTICIPANT	\N	PRESENT	0
75706	75219	11099A	PARTICIPANT	\N	PRESENT	0
75708	75219	11031D	PARTICIPANT	\N	PRESENT	0
75714	75219	01060R	PARTICIPANT	\N	PRESENT	0
75715	75219	14055N	PARTICIPANT	\N	PRESENT	0
75718	75219	92044U	PARTICIPANT	\N	PRESENT	0
75719	75219	08039A	PARTICIPANT	\N	PRESENT	0
75741	75219	08017T	PARTICIPANT	\N	PRESENT	0
75727	75219	14089Y	PARTICIPANT	\N	PRESENT	0
75728	75219	11064N	PARTICIPANT	\N	PRESENT	0
75729	75219	08038Y	PARTICIPANT	\N	PRESENT	0
75731	75219	11094U	PARTICIPANT	\N	PRESENT	0
75732	75219	14255U	PARTICIPANT	\N	PRESENT	0
75734	75219	98053W	PARTICIPANT	\N	PRESENT	0
75735	75219	04070G	PARTICIPANT	\N	PRESENT	0
75736	75219	08048B	PARTICIPANT	\N	PRESENT	0
75745	75219	04055H	PARTICIPANT	\N	PRESENT	0
75749	75219	11065P	PARTICIPANT	\N	PRESENT	0
75758	75219	01034P	PARTICIPANT	\N	PRESENT	0
75759	75219	11054L	PARTICIPANT	\N	PRESENT	0
75760	75219	11068S	PARTICIPANT	\N	PRESENT	0
75761	75219	89017R	PARTICIPANT	\N	PRESENT	0
75762	75219	14065Q	PARTICIPANT	\N	PRESENT	0
75767	75220	86034E	PARTICIPANT	\N	PRESENT	0
75768	75220	14033T	PARTICIPANT	\N	PRESENT	0
75769	75220	95031C	PARTICIPANT	\N	PRESENT	0
75770	75220	14087W	PARTICIPANT	\N	PRESENT	0
75771	75220	14041T	PARTICIPANT	\N	PRESENT	0
75772	75220	14097Y	PARTICIPANT	\N	PRESENT	0
75773	75220	14267Y	PARTICIPANT	\N	PRESENT	0
75774	75220	00003C	PARTICIPANT	\N	PRESENT	0
75775	75220	14213J	PARTICIPANT	\N	PRESENT	0
75776	75220	11025F	PARTICIPANT	\N	PRESENT	0
75777	75220	14059S	PARTICIPANT	\N	PRESENT	0
75778	75220	14249W	PARTICIPANT	\N	PRESENT	0
75779	75220	14271U	PARTICIPANT	\N	PRESENT	0
75780	75220	14277B	PARTICIPANT	\N	PRESENT	0
75781	75220	14275Y	PARTICIPANT	\N	PRESENT	0
75782	75220	14030Q	PARTICIPANT	\N	PRESENT	0
75783	75220	01024M	PARTICIPANT	\N	PRESENT	0
75784	75220	11055M	PARTICIPANT	\N	PRESENT	0
75785	75220	09001P	PARTICIPANT	\N	PRESENT	0
75786	75220	08060W	PARTICIPANT	\N	PRESENT	0
75787	75220	11105E	PARTICIPANT	\N	PRESENT	0
75788	75220	14085U	PARTICIPANT	\N	PRESENT	0
75789	75220	14247U	PARTICIPANT	\N	PRESENT	0
75790	75220	08069G	PARTICIPANT	\N	PRESENT	0
75791	75220	04097T	PARTICIPANT	\N	PRESENT	0
75792	75220	08021P	PARTICIPANT	\N	PRESENT	0
75793	75220	04094Q	PARTICIPANT	\N	PRESENT	0
75794	75220	14039A	PARTICIPANT	\N	PRESENT	0
75795	75220	92018S	PARTICIPANT	\N	PRESENT	0
75796	75220	08053X	PARTICIPANT	\N	PRESENT	0
75797	75220	01022K	PARTICIPANT	\N	PRESENT	0
75798	75220	01043Q	PARTICIPANT	\N	PRESENT	0
75799	75220	04078Q	PARTICIPANT	\N	PRESENT	0
75800	75220	04036E	PARTICIPANT	\N	PRESENT	0
75801	75220	92039X	PARTICIPANT	\N	PRESENT	0
75802	75220	14073Q	PARTICIPANT	\N	PRESENT	0
75803	75220	14038Y	PARTICIPANT	\N	PRESENT	0
75804	75220	11035H	PARTICIPANT	\N	PRESENT	0
75805	75220	11097X	PARTICIPANT	\N	PRESENT	0
75806	75220	99004R	PARTICIPANT	\N	PRESENT	0
75807	75220	14159V	PARTICIPANT	\N	PRESENT	0
75808	75220	11093T	PARTICIPANT	\N	PRESENT	0
75809	75220	11081P	PARTICIPANT	\N	PRESENT	0
75810	75220	14263U	PARTICIPANT	\N	PRESENT	0
75811	75220	04050C	PARTICIPANT	\N	PRESENT	0
75812	75220	08041T	PARTICIPANT	\N	PRESENT	0
75813	75220	95049N	PARTICIPANT	\N	PRESENT	0
75814	75220	11049P	PARTICIPANT	\N	PRESENT	0
75815	75220	08047A	PARTICIPANT	\N	PRESENT	0
75816	75220	07029T	PARTICIPANT	\N	PRESENT	0
75817	75220	04085P	PARTICIPANT	\N	PRESENT	0
75818	75220	14209N	PARTICIPANT	\N	PRESENT	0
75819	75220	01046T	PARTICIPANT	\N	PRESENT	0
75820	75220	98029W	PARTICIPANT	\N	PRESENT	0
75821	75220	01019Q	PARTICIPANT	\N	PRESENT	0
75822	75220	08028W	PARTICIPANT	\N	PRESENT	0
75823	75220	04088S	PARTICIPANT	\N	PRESENT	0
75824	75220	08051V	PARTICIPANT	\N	PRESENT	0
75825	75220	14079W	PARTICIPANT	\N	PRESENT	0
75826	75220	11103C	PARTICIPANT	\N	PRESENT	0
75827	75220	01048V	PARTICIPANT	\N	PRESENT	0
75828	75220	14201E	PARTICIPANT	\N	PRESENT	0
75829	75220	95062K	PARTICIPANT	\N	PRESENT	0
75830	75220	02002K	PARTICIPANT	\N	PRESENT	0
75831	75220	11053K	PARTICIPANT	\N	PRESENT	0
75832	75220	11090Q	PARTICIPANT	\N	PRESENT	0
75833	75220	11111C	PARTICIPANT	\N	PRESENT	0
75834	75220	01061S	PARTICIPANT	\N	PRESENT	0
75835	75220	11044J	PARTICIPANT	\N	PRESENT	0
75836	75220	95063L	PARTICIPANT	\N	PRESENT	0
75837	75220	14061L	PARTICIPANT	\N	PRESENT	0
75838	75220	07034Q	PARTICIPANT	\N	PRESENT	0
75839	75220	08052W	PARTICIPANT	\N	PRESENT	0
75840	75220	14169X	PARTICIPANT	\N	PRESENT	0
75841	75220	14167V	PARTICIPANT	\N	PRESENT	0
75842	75220	11033F	PARTICIPANT	\N	PRESENT	0
75843	75220	04086Q	PARTICIPANT	\N	PRESENT	0
75844	75220	01044R	PARTICIPANT	\N	PRESENT	0
75845	75220	96004D	PARTICIPANT	\N	PRESENT	0
75846	75220	14211G	PARTICIPANT	\N	PRESENT	0
75847	75220	98046X	PARTICIPANT	\N	PRESENT	0
75848	75220	89029V	PARTICIPANT	\N	PRESENT	0
75849	75220	14051J	PARTICIPANT	\N	PRESENT	0
75850	75220	04034C	PARTICIPANT	\N	PRESENT	0
75851	75220	01027Q	PARTICIPANT	\N	PRESENT	0
75852	75220	08044W	PARTICIPANT	\N	PRESENT	0
75853	75220	04042C	PARTICIPANT	\N	PRESENT	0
75854	75220	14197C	PARTICIPANT	\N	PRESENT	0
75855	75220	04033B	PARTICIPANT	\N	PRESENT	0
75856	75220	12041X	PARTICIPANT	\N	PRESENT	0
75857	75220	14111D	PARTICIPANT	\N	PRESENT	0
75858	75220	14223L	PARTICIPANT	\N	PRESENT	0
75859	75220	11034G	PARTICIPANT	\N	PRESENT	0
75860	75220	07032N	PARTICIPANT	\N	PRESENT	0
75861	75220	11056N	PARTICIPANT	\N	PRESENT	0
75862	75220	14093U	PARTICIPANT	\N	PRESENT	0
75863	75220	08015R	PARTICIPANT	\N	PRESENT	0
75864	75220	11057P	PARTICIPANT	\N	PRESENT	0
75865	75220	11040E	PARTICIPANT	\N	PRESENT	0
75866	75220	95015C	PARTICIPANT	\N	PRESENT	0
75867	75220	14175V	PARTICIPANT	\N	PRESENT	0
75868	75220	14259Y	PARTICIPANT	\N	PRESENT	0
75869	75220	04081K	PARTICIPANT	\N	PRESENT	0
75870	75220	95041E	PARTICIPANT	\N	PRESENT	0
75871	75220	04048J	PARTICIPANT	\N	PRESENT	0
75872	75220	08034U	PARTICIPANT	\N	PRESENT	0
75873	75220	97011G	PARTICIPANT	\N	PRESENT	0
75874	75220	08065C	PARTICIPANT	\N	PRESENT	0
75875	75220	14017T	PARTICIPANT	\N	PRESENT	0
75876	75220	11080N	PARTICIPANT	\N	PRESENT	0
75877	75220	11098Y	PARTICIPANT	\N	PRESENT	0
75878	75220	92031P	PARTICIPANT	\N	PRESENT	0
75879	75220	11059R	PARTICIPANT	\N	PRESENT	0
75880	75220	14028W	PARTICIPANT	\N	PRESENT	0
75881	75220	11088W	PARTICIPANT	\N	PRESENT	0
75882	75220	08014Q	PARTICIPANT	\N	PRESENT	0
75883	75220	95030B	PARTICIPANT	\N	PRESENT	0
75884	75220	14187A	PARTICIPANT	\N	PRESENT	0
75885	75220	05008E	PARTICIPANT	\N	PRESENT	0
75886	75220	04092N	PARTICIPANT	\N	PRESENT	0
75887	75220	08011M	PARTICIPANT	\N	PRESENT	0
75888	75220	90003B	PARTICIPANT	\N	PRESENT	0
75889	75220	07026Q	PARTICIPANT	\N	PRESENT	0
75890	75220	87003B	PARTICIPANT	\N	PRESENT	0
75891	75220	11043H	PARTICIPANT	\N	PRESENT	0
75892	75220	08010L	PARTICIPANT	\N	PRESENT	0
75893	75220	11030C	PARTICIPANT	\N	PRESENT	0
75894	75220	14013P	PARTICIPANT	\N	PRESENT	0
75895	75220	01059Y	PARTICIPANT	\N	PRESENT	0
75896	75220	01041N	PARTICIPANT	\N	PRESENT	0
75897	75220	11063M	PARTICIPANT	\N	PRESENT	0
75898	75220	14123H	PARTICIPANT	\N	PRESENT	0
75899	75220	92045V	PARTICIPANT	\N	PRESENT	0
75900	75220	14151M	PARTICIPANT	\N	PRESENT	0
75901	75220	08025T	PARTICIPANT	\N	PRESENT	0
75902	75220	01058X	PARTICIPANT	\N	PRESENT	0
75903	75220	01016M	PARTICIPANT	\N	PRESENT	0
75904	75220	11039M	PARTICIPANT	\N	PRESENT	0
75905	75220	04056J	PARTICIPANT	\N	PRESENT	0
75906	75220	08016S	PARTICIPANT	\N	PRESENT	0
75907	75220	14215L	PARTICIPANT	\N	PRESENT	0
75908	75220	07024N	PARTICIPANT	\N	PRESENT	0
63815	63404	01025N	PARTICIPANT	\N	PRESENT	0
63813	63404	04066L	PARTICIPANT	\N	PRESENT	0
63814	63404	04070G	PARTICIPANT	\N	PRESENT	0
63816	63404	08039A	PARTICIPANT	\N	PRESENT	0
63817	63404	07026Q	PARTICIPANT	\N	PRESENT	0
63818	63404	14257W	PARTICIPANT	\N	PRESENT	0
63819	63404	11089X	PARTICIPANT	\N	PRESENT	0
63820	63404	14207L	PARTICIPANT	\N	PRESENT	0
63821	63404	01028R	PARTICIPANT	\N	PRESENT	0
63822	63404	12041X	PARTICIPANT	\N	PRESENT	0
63823	63404	01044R	PARTICIPANT	\N	PRESENT	0
63824	63404	11012A	PARTICIPANT	\N	PRESENT	0
63825	63404	04057K	PARTICIPANT	\N	PRESENT	0
63829	63404	04059M	PARTICIPANT	\N	PRESENT	0
63830	63404	14229S	PARTICIPANT	\N	PRESENT	0
63835	63404	14109K	PARTICIPANT	\N	PRESENT	0
63836	63404	01024M	PARTICIPANT	\N	PRESENT	0
63837	63404	04056J	PARTICIPANT	\N	PRESENT	0
63838	63404	01041N	PARTICIPANT	\N	PRESENT	0
63839	63404	08019V	PARTICIPANT	\N	PRESENT	0
63840	63404	14083S	PARTICIPANT	\N	PRESENT	0
63845	63404	14201E	PARTICIPANT	\N	PRESENT	0
63846	63404	14269B	PARTICIPANT	\N	PRESENT	0
63847	63404	04036E	PARTICIPANT	\N	PRESENT	0
63848	63404	14039A	PARTICIPANT	\N	PRESENT	0
63852	63404	08017T	PARTICIPANT	\N	PRESENT	0
63853	60592	14093U	PARTICIPANT	\N	EXCUSE	0
63854	63404	04053F	PARTICIPANT	\N	PRESENT	0
63855	60565	04049K	PARTICIPANT	\N	PRESENT	0
63882	63412	14109K	PARTICIPANT	\N	PRESENT	0
63883	63412	14257W	PARTICIPANT	\N	PRESENT	0
63884	63412	01041N	PARTICIPANT	\N	PRESENT	0
63885	63412	99004R	PARTICIPANT	\N	PRESENT	0
63886	63412	12041X	PARTICIPANT	\N	PRESENT	0
63887	63412	01044R	PARTICIPANT	\N	PRESENT	0
63888	63412	14207L	PARTICIPANT	\N	PRESENT	0
63889	63412	08039A	PARTICIPANT	\N	PRESENT	0
63890	63412	01025N	PARTICIPANT	\N	PRESENT	0
63891	63412	04070G	PARTICIPANT	\N	PRESENT	0
63892	63412	14271U	PARTICIPANT	\N	PRESENT	0
63893	63412	04059M	PARTICIPANT	\N	PRESENT	0
63894	63412	14229S	PARTICIPANT	\N	PRESENT	0
63895	63412	01024M	PARTICIPANT	\N	PRESENT	0
63896	63412	04057K	PARTICIPANT	\N	PRESENT	0
63897	63412	14089Y	PARTICIPANT	\N	PRESENT	0
63898	63412	11091R	PARTICIPANT	\N	PRESENT	0
63899	63412	08017T	PARTICIPANT	\N	PRESENT	0
63900	63412	11012A	PARTICIPANT	\N	PRESENT	0
63901	63412	14039A	PARTICIPANT	\N	PRESENT	0
63902	63412	11074Q	PARTICIPANT	\N	PRESENT	0
63903	63412	02002K	PARTICIPANT	\N	PRESENT	0
63913	63412	04043D	PARTICIPANT	\N	PRESENT	0
63922	63412	04035D	PARTICIPANT	\N	PRESENT	0
63880	63412	04081K	PARTICIPANT	\N	PRESENT	0
63881	63412	07026Q	PARTICIPANT	\N	PRESENT	0
63949	63412	08019V	PARTICIPANT	\N	PRESENT	0
63951	63950	11076S	PARTICIPANT	\N	PRESENT	0
63952	63950	04054G	PARTICIPANT	\N	PRESENT	0
63953	63950	08058D	PARTICIPANT	\N	PRESENT	0
63954	63950	04040A	PARTICIPANT	\N	PRESENT	0
63955	63950	98029W	PARTICIPANT	\N	PRESENT	0
63956	63950	04042C	PARTICIPANT	\N	PRESENT	0
63957	63950	92018S	PARTICIPANT	\N	PRESENT	0
63958	63950	07024N	PARTICIPANT	\N	PRESENT	0
63959	63950	95035G	PARTICIPANT	\N	PRESENT	0
63960	63950	14211G	PARTICIPANT	\N	PRESENT	0
63961	63950	98022P	PARTICIPANT	\N	PRESENT	0
63962	63950	95037J	PARTICIPANT	\N	PRESENT	0
63963	63950	14097Y	PARTICIPANT	\N	PRESENT	0
63964	63950	04036E	PARTICIPANT	\N	PRESENT	0
63965	63950	92031P	PARTICIPANT	\N	PRESENT	0
63966	63950	08047A	PARTICIPANT	\N	PRESENT	0
63967	63950	14028W	PARTICIPANT	\N	PRESENT	0
63968	63950	14193X	PARTICIPANT	\N	PRESENT	0
63969	63950	98021N	PARTICIPANT	\N	PRESENT	0
63970	63950	04080J	PARTICIPANT	\N	PRESENT	0
63971	63950	95059Q	PARTICIPANT	\N	PRESENT	0
63972	63950	01014K	PARTICIPANT	\N	PRESENT	0
63973	63950	01056V	PARTICIPANT	\N	PRESENT	0
63974	63412	11044J	PARTICIPANT	\N	PRESENT	0
63975	63412	04036E	PARTICIPANT	\N	PRESENT	0
63976	63412	11029K	PARTICIPANT	\N	PRESENT	0
63977	63412	14269B	PARTICIPANT	\N	PRESENT	0
63978	63412	11080N	PARTICIPANT	\N	PRESENT	0
63979	63412	11042G	PARTICIPANT	\N	PRESENT	0
63980	63412	14249W	PARTICIPANT	\N	PRESENT	0
63981	63412	92031P	PARTICIPANT	\N	PRESENT	0
63982	63412	11083R	PARTICIPANT	\N	PRESENT	0
63983	63412	04085P	PARTICIPANT	\N	PRESENT	0
63984	63412	04071H	PARTICIPANT	\N	PRESENT	0
63985	63412	08069G	PARTICIPANT	\N	PRESENT	0
63986	63412	14169X	PARTICIPANT	\N	PRESENT	0
69309	69307	11039M	PARTICIPANT	\N	PRESENT	0
69310	69307	98042T	PARTICIPANT	\N	PRESENT	0
69311	69307	01019Q	PARTICIPANT	\N	PRESENT	0
69393	69392	95049N	PARTICIPANT	\N	PRESENT	0
69395	69394	95049N	PARTICIPANT	\N	PRESENT	0
69397	69396	95049N	PARTICIPANT	\N	PRESENT	0
71734	71733	14133K	PARTICIPANT	\N	PRESENT	0
71735	71733	11040E	PARTICIPANT	\N	PRESENT	0
71736	71733	96004D	PRESIDENT	0	PRESENT	0
71737	71733	11035H	PARTICIPANT	\N	PRESENT	0
71738	71733	14249W	PARTICIPANT	\N	PRESENT	0
71739	71733	11083R	PARTICIPANT	\N	PRESENT	0
71741	71733	14097Y	PARTICIPANT	\N	PRESENT	0
71742	71733	04061F	PARTICIPANT	\N	PRESENT	0
71743	71733	11026G	PARTICIPANT	\N	PRESENT	0
71745	71733	98046X	PARTICIPANT	\N	PRESENT	0
71746	71733	14135M	PARTICIPANT	\N	PRESENT	0
71786	71733	01016M	PARTICIPANT	\N	PRESENT	0
71787	71733	10015M	PARTICIPANT	\N	PRESENT	0
71788	71733	95063L	PARTICIPANT	\N	PRESENT	0
71789	71733	92045V	PARTICIPANT	\N	PRESENT	0
71790	71733	04045F	PARTICIPANT	\N	EXCUSE	0
71791	71733	11012A	PARTICIPANT	\N	EXCUSE	0
72853	72852	11027H	PARTICIPANT	\N	PRESENT	0
72857	72852	08017T	PARTICIPANT	\N	PRESENT	0
72855	72852	14097Y	PARTICIPANT	\N	PRESENT	0
72856	72852	11061K	PARTICIPANT	\N	PRESENT	0
73079	73078	14263U	PARTICIPANT	\N	PRESENT	0
73082	73078	04059M	PARTICIPANT	\N	PRESENT	0
73084	73078	01044R	PARTICIPANT	\N	PRESENT	0
73085	73078	08043V	PARTICIPANT	\N	PRESENT	0
73086	73078	14089Y	PARTICIPANT	\N	PRESENT	0
73087	73078	14105F	PARTICIPANT	\N	PRESENT	0
73088	73078	11029K	PARTICIPANT	\N	EXCUSE	0
73089	73078	95015C	PARTICIPANT	\N	PRESENT	0
73090	73078	92015P	PARTICIPANT	\N	EXCUSE	0
73091	73078	08024S	PARTICIPANT	\N	PRESENT	0
73094	73078	14209N	PARTICIPANT	\N	PRESENT	0
73096	73078	11091R	PARTICIPANT	\N	PRESENT	0
73097	73078	87003B	PARTICIPANT	\N	PRESENT	0
73098	73078	98042T	PARTICIPANT	\N	PRESENT	0
73099	73078	14249W	PARTICIPANT	\N	PRESENT	0
73100	73078	01041N	PARTICIPANT	\N	PRESENT	0
73101	73078	01025N	PARTICIPANT	\N	PRESENT	0
73102	73078	01037S	PARTICIPANT	\N	PRESENT	0
73105	73078	11089X	PARTICIPANT	\N	PRESENT	0
73106	73078	07026Q	PARTICIPANT	\N	PRESENT	0
73107	73078	14123H	PARTICIPANT	\N	PRESENT	0
73109	73078	04041B	PARTICIPANT	\N	EXCUSE	0
73110	73078	14241N	PARTICIPANT	\N	PRESENT	0
73111	73078	14061L	PARTICIPANT	\N	PRESENT	0
73112	73078	14073Q	PARTICIPANT	\N	PRESENT	0
73113	73078	08031R	PARTICIPANT	\N	PRESENT	0
73114	73078	12041X	PARTICIPANT	\N	PRESENT	0
73115	73078	08039A	PARTICIPANT	\N	PRESENT	0
73116	73078	08017T	PARTICIPANT	\N	PRESENT	0
73117	73078	14059S	PARTICIPANT	\N	PRESENT	0
73118	73078	08012N	PARTICIPANT	\N	PRESENT	0
73119	73078	14103D	PARTICIPANT	\N	PRESENT	0
73120	73078	11104D	PARTICIPANT	\N	PRESENT	0
73121	73078	14063N	PARTICIPANT	\N	PRESENT	0
73122	73078	04057K	PARTICIPANT	\N	PRESENT	0
73124	73078	14109K	PARTICIPANT	\N	PRESENT	0
73125	73078	04070G	PRESIDENT	0	PRESENT	0
73126	73078	92040Q	PARTICIPANT	\N	PRESENT	0
73128	73078	83047W	PARTICIPANT	\N	PRESENT	0
83449	83002	14273W	PARTICIPANT	\N	PRESENT	0
83450	83002	14219Q	PARTICIPANT	\N	PRESENT	0
83451	83002	08031R	PARTICIPANT	\N	PRESENT	0
83452	83002	11034G	PARTICIPANT	\N	PRESENT	0
83454	83002	14223L	PARTICIPANT	\N	PRESENT	0
83455	83002	04038G	PARTICIPANT	\N	PRESENT	0
83456	83002	11011M	PARTICIPANT	\N	PRESENT	0
83457	83002	11100Y	PARTICIPANT	\N	PRESENT	0
83458	83002	14231L	PARTICIPANT	\N	PRESENT	0
83459	83002	11043H	PARTICIPANT	\N	PRESENT	0
83460	83002	13002U	PARTICIPANT	\N	PRESENT	0
83461	83002	14327T	PARTICIPANT	\N	PRESENT	0
83462	83002	11036J	PARTICIPANT	\N	PRESENT	0
83463	83002	07029T	PARTICIPANT	\N	PRESENT	0
83447	83002	04066L	PARTICIPANT	\N	PRESENT	0
83448	83002	08051V	PARTICIPANT	\N	PRESENT	0
83464	83002	14038Y	PARTICIPANT	\N	PRESENT	0
83465	83002	14237S	PARTICIPANT	\N	PRESENT	0
83466	83002	14259Y	PARTICIPANT	\N	PRESENT	0
83467	83002	08049C	PARTICIPANT	\N	PRESENT	0
83468	83002	14083S	PARTICIPANT	\N	PRESENT	0
83469	83002	14195A	PARTICIPANT	\N	PRESENT	0
83470	83002	98005N	PARTICIPANT	\N	PRESENT	0
83471	83002	01046T	PARTICIPANT	\N	PRESENT	0
83472	83002	14157T	PARTICIPANT	\N	PRESENT	0
83473	83002	11091R	PARTICIPANT	\N	PRESENT	0
83474	83002	14215L	PARTICIPANT	\N	PRESENT	0
83475	83002	04048J	PARTICIPANT	\N	PRESENT	0
83476	83002	14042U	PARTICIPANT	\N	PRESENT	0
83477	83002	05008E	PARTICIPANT	\N	PRESENT	0
83478	83002	14261S	PARTICIPANT	\N	PRESENT	0
83479	83002	14030Q	PARTICIPANT	\N	PRESENT	0
83480	83002	11048N	PARTICIPANT	\N	PRESENT	0
83481	83002	14037X	PARTICIPANT	\N	PRESENT	0
83482	83002	14159V	PARTICIPANT	\N	PRESENT	0
83483	83002	11063M	PARTICIPANT	\N	PRESENT	0
83484	83002	14031R	PARTICIPANT	\N	PRESENT	0
83495	83002	04085P	PARTICIPANT	\N	PRESENT	0
83497	83002	11040E	PARTICIPANT	\N	PRESENT	0
83529	83002	08052W	PARTICIPANT	\N	PRESENT	0
83530	83002	14331P	PARTICIPANT	\N	PRESENT	0
83531	83002	04036E	PARTICIPANT	\N	PRESENT	0
83532	83002	04092N	PARTICIPANT	\N	PRESENT	0
83533	83002	07024N	PARTICIPANT	\N	PRESENT	0
83534	83002	08019V	PARTICIPANT	\N	PRESENT	0
83535	83002	14107H	PARTICIPANT	\N	PRESENT	0
83536	83002	01014K	PARTICIPANT	\N	PRESENT	0
83537	83002	92045V	PARTICIPANT	\N	PRESENT	0
83538	83002	11031D	PARTICIPANT	\N	PRESENT	0
83539	83002	01024M	PARTICIPANT	\N	PRESENT	0
83540	83002	04053F	PARTICIPANT	\N	PRESENT	0
83541	83002	14013P	PARTICIPANT	\N	PRESENT	0
83609	82999	08031R	PARTICIPANT	\N	PRESENT	0
83610	82999	04053F	PARTICIPANT	\N	PRESENT	0
83611	82999	08052W	PARTICIPANT	\N	PRESENT	0
83612	82999	13002U	PARTICIPANT	\N	PRESENT	0
83613	82999	14219Q	PARTICIPANT	\N	PRESENT	0
83614	82999	01024M	PARTICIPANT	\N	PRESENT	0
83615	82999	04092N	PARTICIPANT	\N	PRESENT	0
83616	82999	11031D	PARTICIPANT	\N	PRESENT	0
83617	82999	11034G	PARTICIPANT	\N	PRESENT	0
83619	82999	98005N	PARTICIPANT	\N	PRESENT	0
83622	82999	01046T	PARTICIPANT	\N	PRESENT	0
83623	82999	11043H	PARTICIPANT	\N	PRESENT	0
83624	82999	14231L	PARTICIPANT	\N	PRESENT	0
83625	82999	14107H	PARTICIPANT	\N	PRESENT	0
83627	82999	14215L	PARTICIPANT	\N	PRESENT	0
83629	82999	11063M	PARTICIPANT	\N	PRESENT	0
83631	82999	14237S	PARTICIPANT	\N	PRESENT	0
83635	82999	04038G	PARTICIPANT	\N	PRESENT	0
83636	82999	07029T	PARTICIPANT	\N	PRESENT	0
83637	82999	08051V	PARTICIPANT	\N	PRESENT	0
83638	82999	95035G	PARTICIPANT	\N	PRESENT	0
83643	82999	14327T	PARTICIPANT	\N	PRESENT	0
83644	82999	11072N	PARTICIPANT	\N	PRESENT	0
83645	78335	04066L	PARTICIPANT	\N	PRESENT	0
83646	78335	92045V	PARTICIPANT	\N	PRESENT	0
83647	78335	01024M	PARTICIPANT	\N	PRESENT	0
83648	78335	14215L	PARTICIPANT	\N	PRESENT	0
83649	78335	11034G	PARTICIPANT	\N	PRESENT	0
83650	78335	11031D	PARTICIPANT	\N	PRESENT	0
83651	78335	98005N	PARTICIPANT	\N	PRESENT	0
83652	78335	11072N	PARTICIPANT	\N	PRESENT	0
83653	78335	08031R	PARTICIPANT	\N	PRESENT	0
83654	78335	13002U	PARTICIPANT	\N	PRESENT	0
83655	78335	11036J	PARTICIPANT	\N	PRESENT	0
86383	86380	04086Q	PARTICIPANT	\N	PRESENT	0
83657	78335	04085P	PARTICIPANT	\N	PRESENT	0
86381	86380	14255U	PARTICIPANT	\N	PRESENT	0
86384	86380	04067M	PARTICIPANT	\N	PRESENT	0
86385	86380	01027Q	PRESIDENT	0	PRESENT	0
86386	86380	12042Y	PRESIDENT	1	PRESENT	0
86387	86380	11061K	PARTICIPANT	\N	PRESENT	0
86388	86380	11112D	PARTICIPANT	\N	PRESENT	0
86389	86380	14037X	PARTICIPANT	\N	PRESENT	0
86390	86380	14205J	PARTICIPANT	\N	PRESENT	0
86391	86380	11097X	PARTICIPANT	\N	PRESENT	0
86392	86380	04045F	PARTICIPANT	\N	PRESENT	0
86393	86380	14227Q	PARTICIPANT	\N	PRESENT	0
86395	86380	04050C	PARTICIPANT	\N	PRESENT	0
86396	86380	11107G	PARTICIPANT	\N	EXCUSE	0
86398	86380	04092N	PARTICIPANT	\N	EXCUSE	0
87049	86909	08018U	PARTICIPANT	\N	PRESENT	0
83607	82999	04066L	PARTICIPANT	\N	PRESENT	0
83608	82999	08049C	PARTICIPANT	\N	PRESENT	0
87054	86909	07026Q	PARTICIPANT	\N	PRESENT	0
87055	86909	14263U	PARTICIPANT	\N	PRESENT	0
87056	86909	14013P	PARTICIPANT	\N	PRESENT	0
87057	86909	11095V	PARTICIPANT	\N	PRESENT	0
87058	86909	11027H	PARTICIPANT	\N	PRESENT	0
87060	86909	01028R	PARTICIPANT	\N	PRESENT	0
87062	86909	11046L	PARTICIPANT	\N	PRESENT	0
87067	86909	11029K	PARTICIPANT	\N	PRESENT	0
87070	86909	08019V	PARTICIPANT	\N	PRESENT	0
87072	86909	14169X	PARTICIPANT	\N	PRESENT	0
87073	86909	04086Q	PARTICIPANT	\N	PRESENT	0
87074	86909	01058X	PARTICIPANT	\N	PRESENT	0
87075	86909	14038Y	PARTICIPANT	\N	PRESENT	0
87077	86909	14261S	PARTICIPANT	\N	PRESENT	0
87047	86909	04081K	PARTICIPANT	\N	PRESENT	0
87080	86909	11011M	PARTICIPANT	\N	PRESENT	0
87088	86909	04035D	PARTICIPANT	\N	PRESENT	0
87089	86909	04071H	PARTICIPANT	\N	PRESENT	0
87090	86909	14217N	PARTICIPANT	\N	PRESENT	0
87091	86909	01041N	PARTICIPANT	\N	PRESENT	0
87092	86909	04094Q	PARTICIPANT	\N	PRESENT	0
87095	86909	11026G	PARTICIPANT	\N	PRESENT	0
87121	86910	07024N	PARTICIPANT	\N	PRESENT	0
87122	86910	11103C	PARTICIPANT	\N	PRESENT	0
87123	86910	14261S	PARTICIPANT	\N	PRESENT	0
87124	86910	08031R	PARTICIPANT	\N	PRESENT	0
87125	86910	14151M	PARTICIPANT	\N	PRESENT	0
87126	86910	14263U	PARTICIPANT	\N	PRESENT	0
87127	86910	08019V	PARTICIPANT	\N	PRESENT	0
87128	86910	14038Y	PARTICIPANT	\N	PRESENT	0
87129	86910	01058X	PARTICIPANT	\N	PRESENT	0
87130	86910	04057K	PARTICIPANT	\N	PRESENT	0
87131	86910	14197C	PARTICIPANT	\N	PRESENT	0
87132	86910	11113E	PARTICIPANT	\N	PRESENT	0
87133	86910	11027H	PARTICIPANT	\N	PRESENT	0
87134	86910	11083R	PARTICIPANT	\N	PRESENT	0
87135	86910	04085P	PARTICIPANT	\N	PRESENT	0
87136	86910	04035D	PARTICIPANT	\N	PRESENT	0
87137	86910	04034C	PARTICIPANT	\N	PRESENT	0
87138	86910	11029K	PARTICIPANT	\N	PRESENT	0
87139	86910	11046L	PARTICIPANT	\N	PRESENT	0
87140	86910	11026G	PARTICIPANT	\N	PRESENT	0
87119	86910	04081K	PARTICIPANT	\N	PRESENT	0
87120	86910	08018U	PARTICIPANT	\N	PRESENT	0
87141	86910	01031L	PARTICIPANT	\N	PRESENT	0
87142	86910	11072N	PARTICIPANT	\N	PRESENT	0
87143	86910	11109J	PARTICIPANT	\N	PRESENT	0
87144	86910	14331P	PARTICIPANT	\N	PRESENT	0
87145	86910	04086Q	PARTICIPANT	\N	PRESENT	0
87146	86910	11095V	PARTICIPANT	\N	PRESENT	0
87147	86910	04094Q	PARTICIPANT	\N	PRESENT	0
87148	86910	02002K	PARTICIPANT	\N	PRESENT	0
87149	86910	98046X	PARTICIPANT	\N	PRESENT	0
87158	86910	01041N	PARTICIPANT	\N	PRESENT	0
87164	86910	14259Y	PARTICIPANT	\N	PRESENT	0
87160	86910	14251Q	PARTICIPANT	\N	PRESENT	0
87161	86910	08039A	PARTICIPANT	\N	PRESENT	0
87165	86910	14275Y	PARTICIPANT	\N	PRESENT	0
87166	86910	08024S	PARTICIPANT	\N	PRESENT	0
87167	86910	11104D	PARTICIPANT	\N	PRESENT	0
87168	86910	11107G	PARTICIPANT	\N	PRESENT	0
71226	69644	04081K	PARTICIPANT	\N	PRESENT	0
71236	69644	11099A	PARTICIPANT	\N	PRESENT	0
71237	69644	11098Y	PARTICIPANT	\N	PRESENT	0
71238	69644	14331P	PARTICIPANT	\N	PRESENT	0
71239	69644	11094U	PARTICIPANT	\N	PRESENT	0
71240	69644	01044R	PARTICIPANT	\N	PRESENT	0
71241	69644	11066Q	PARTICIPANT	\N	PRESENT	0
71242	69644	14063N	PARTICIPANT	\N	PRESENT	0
71243	69644	11083R	PARTICIPANT	\N	PRESENT	0
71244	69644	14273W	PARTICIPANT	\N	PRESENT	0
71245	69644	01022K	PARTICIPANT	\N	PRESENT	0
71246	69644	04048J	PARTICIPANT	\N	PRESENT	0
71247	69644	14257W	PARTICIPANT	\N	PRESENT	0
71248	69644	11100Y	PARTICIPANT	\N	PRESENT	0
71249	69644	08055A	PARTICIPANT	\N	PRESENT	0
71250	69644	14031R	PARTICIPANT	\N	PRESENT	0
71251	69644	14215L	PARTICIPANT	\N	PRESENT	0
71252	69644	14121F	PARTICIPANT	\N	PRESENT	0
71253	69644	11110B	PARTICIPANT	\N	PRESENT	0
71254	69644	04059M	PARTICIPANT	\N	PRESENT	0
71255	69644	04067M	PARTICIPANT	\N	PRESENT	0
71256	69644	01027Q	PARTICIPANT	\N	PRESENT	0
71257	69644	14201E	PARTICIPANT	\N	PRESENT	0
71258	69644	13002U	PARTICIPANT	\N	PRESENT	0
71259	69644	14033T	PARTICIPANT	\N	PRESENT	0
71260	69644	08015R	PARTICIPANT	\N	PRESENT	0
71281	69644	08061X	PARTICIPANT	\N	PRESENT	0
71262	69644	08028W	PARTICIPANT	\N	PRESENT	0
71263	69644	14197C	PARTICIPANT	\N	PRESENT	0
71264	69644	14241N	PARTICIPANT	\N	PRESENT	0
71265	69644	14135M	PARTICIPANT	\N	PRESENT	0
71266	69644	14105F	PARTICIPANT	\N	PRESENT	0
71267	69644	14327T	PARTICIPANT	\N	PRESENT	0
71268	69644	14207L	PARTICIPANT	\N	PRESENT	0
71269	69644	04095R	PARTICIPANT	\N	PRESENT	0
71270	69644	01015L	PARTICIPANT	\N	PRESENT	0
71271	69644	01013J	PARTICIPANT	\N	PRESENT	0
71272	69644	14265W	PARTICIPANT	\N	PRESENT	0
71273	69644	11103C	PARTICIPANT	\N	PRESENT	0
71274	69644	11014C	PARTICIPANT	\N	PRESENT	0
71275	69644	92015P	PARTICIPANT	\N	PRESENT	0
71276	69644	14247U	PARTICIPANT	\N	PRESENT	0
71277	69644	14169X	PARTICIPANT	\N	PRESENT	0
71278	69644	98029W	PARTICIPANT	\N	PRESENT	0
71279	69644	04094Q	PARTICIPANT	\N	PRESENT	0
71280	69644	11055M	PARTICIPANT	\N	PRESENT	0
71282	69644	08014Q	PARTICIPANT	\N	PRESENT	0
71283	69644	95049N	PARTICIPANT	\N	PRESENT	0
71284	69644	14219Q	PARTICIPANT	\N	PRESENT	0
71285	69644	14041T	PARTICIPANT	\N	PRESENT	0
71292	69644	14073Q	PARTICIPANT	\N	PRESENT	0
71287	69644	11111C	PARTICIPANT	\N	PRESENT	0
71288	69644	11048N	PARTICIPANT	\N	PRESENT	0
71289	69644	14249W	PARTICIPANT	\N	PRESENT	0
71293	69644	11033F	PARTICIPANT	\N	PRESENT	0
71295	69644	08016S	PARTICIPANT	\N	PRESENT	0
71296	69644	11036J	PARTICIPANT	\N	PRESENT	0
71298	69644	80013X	PARTICIPANT	\N	PRESENT	0
71361	69644	01056V	PARTICIPANT	\N	PRESENT	0
71366	69644	11113E	PARTICIPANT	\N	PRESENT	0
71371	69644	11061K	PARTICIPANT	\N	PRESENT	0
71373	69644	14030Q	PARTICIPANT	\N	PRESENT	0
71374	69644	14103D	PARTICIPANT	\N	PRESENT	0
71378	69644	14069U	PARTICIPANT	\N	PRESENT	0
71382	69644	14111D	PARTICIPANT	\N	PRESENT	0
71386	69644	95063L	PARTICIPANT	\N	PRESENT	0
71390	69644	11035H	PARTICIPANT	\N	PRESENT	0
71462	69644	04049K	PARTICIPANT	\N	PRESENT	0
71464	69644	14199E	PARTICIPANT	\N	PRESENT	0
71466	69644	14059S	PARTICIPANT	\N	PRESENT	0
71468	69644	95035G	PARTICIPANT	\N	PRESENT	0
71471	69644	01003G	PARTICIPANT	\N	PRESENT	0
71473	69644	14225N	PARTICIPANT	\N	PRESENT	0
71476	69644	14014Q	PARTICIPANT	\N	PRESENT	0
71500	69644	11105E	PARTICIPANT	\N	PRESENT	0
71501	69644	11039M	PARTICIPANT	\N	PRESENT	0
71502	69644	04044E	PARTICIPANT	\N	PRESENT	0
71503	69644	11042G	PARTICIPANT	\N	PRESENT	0
71504	69644	14159V	PARTICIPANT	\N	PRESENT	0
71505	69644	11104D	PARTICIPANT	\N	PRESENT	0
71506	69644	14237S	PARTICIPANT	\N	PRESENT	0
71507	69644	14065Q	PARTICIPANT	\N	PRESENT	0
71509	69644	14179A	PARTICIPANT	\N	PRESENT	0
71511	69644	14147R	PARTICIPANT	\N	PRESENT	0
71512	69644	14267Y	PARTICIPANT	\N	PRESENT	0
71516	69644	11114F	PARTICIPANT	\N	PRESENT	0
71528	69644	04088S	PARTICIPANT	\N	PRESENT	0
71529	69644	11107G	PARTICIPANT	\N	PRESENT	0
71531	69644	01008M	PARTICIPANT	\N	PRESENT	0
71535	69644	11090Q	PARTICIPANT	\N	PRESENT	0
71546	69644	08039A	PARTICIPANT	\N	PRESENT	0
71560	69644	14037X	PARTICIPANT	\N	PRESENT	0
71562	69644	11059R	PARTICIPANT	\N	PRESENT	0
71563	69644	11063M	PARTICIPANT	\N	PRESENT	0
71564	69644	11095V	PARTICIPANT	\N	PRESENT	0
71565	69644	11067R	PARTICIPANT	\N	PRESENT	0
71568	69644	01024M	PARTICIPANT	\N	PRESENT	0
71570	69644	14213J	PARTICIPANT	\N	PRESENT	0
71571	69644	95062K	PARTICIPANT	\N	PRESENT	0
71572	69644	01016M	PARTICIPANT	\N	PRESENT	0
71573	69644	14205J	PARTICIPANT	\N	PRESENT	0
71574	69644	11056N	PARTICIPANT	\N	PRESENT	0
71575	69644	01059Y	PARTICIPANT	\N	PRESENT	0
71576	69644	08043V	PARTICIPANT	\N	PRESENT	0
71577	69644	92045V	PARTICIPANT	\N	PRESENT	0
71578	69644	11077T	PARTICIPANT	\N	PRESENT	0
71579	69644	99004R	PARTICIPANT	\N	PRESENT	0
71580	69644	08051V	PARTICIPANT	\N	PRESENT	0
71581	69644	14217N	PARTICIPANT	\N	PRESENT	0
71582	69644	14231L	PARTICIPANT	\N	PRESENT	0
71583	69644	14271U	PARTICIPANT	\N	PRESENT	0
71584	69644	14097Y	PARTICIPANT	\N	PRESENT	0
71585	69644	14157T	PARTICIPANT	\N	PRESENT	0
71586	69644	14089Y	PARTICIPANT	\N	PRESENT	0
71614	69644	14239U	PARTICIPANT	\N	PRESENT	0
71615	69644	04053F	PARTICIPANT	\N	PRESENT	0
71616	69644	04043D	PARTICIPANT	\N	PRESENT	0
71617	69644	86044G	PARTICIPANT	\N	PRESENT	0
71618	69644	07029T	PARTICIPANT	\N	PRESENT	0
71619	69644	11064N	PARTICIPANT	\N	PRESENT	0
71620	69644	11112D	PARTICIPANT	\N	PRESENT	0
71621	69644	00003C	PARTICIPANT	\N	PRESENT	0
71622	69644	08034U	PARTICIPANT	\N	PRESENT	0
71623	69644	14209N	PARTICIPANT	\N	PRESENT	0
71624	69644	08060W	PARTICIPANT	\N	PRESENT	0
71625	69644	04066L	PARTICIPANT	\N	PRESENT	0
71626	69644	14013P	PARTICIPANT	\N	PRESENT	0
71627	69644	11097X	PARTICIPANT	\N	PRESENT	0
71628	69644	14281W	PARTICIPANT	\N	PRESENT	0
71629	69644	11012A	PARTICIPANT	\N	PRESENT	0
71630	69644	98046X	PARTICIPANT	\N	PRESENT	0
71631	69644	05012A	PARTICIPANT	\N	PRESENT	0
75072	71343	14053L	PARTICIPANT	\N	EXCUSE	0
75074	75073	14053L	PARTICIPANT	\N	EXCUSE	0
75075	75073	96004D	PARTICIPANT	\N	EXCUSE	0
75078	75077	14038Y	PARTICIPANT	\N	PRESENT	0
75080	75079	14093U	PARTICIPANT	\N	PRESENT	0
75081	75079	08025T	PARTICIPANT	\N	PRESENT	0
75083	75082	14093U	PARTICIPANT	\N	PRESENT	0
75084	75082	08025T	PARTICIPANT	\N	PRESENT	0
75086	75085	11026G	PARTICIPANT	\N	PRESENT	0
75087	75085	10015M	PARTICIPANT	\N	PRESENT	0
75089	75088	07004J	PARTICIPANT	\N	PRESENT	0
75090	72441	04035D	PARTICIPANT	\N	EXCUSE	0
75496	75219	87003B	PARTICIPANT	\N	PRESENT	0
75497	75219	11043H	PARTICIPANT	\N	PRESENT	0
75498	75219	08010L	PARTICIPANT	\N	PRESENT	0
75499	75219	11030C	PARTICIPANT	\N	PRESENT	0
75500	75219	14013P	PARTICIPANT	\N	PRESENT	0
75501	75219	01059Y	PARTICIPANT	\N	PRESENT	0
75502	75219	01041N	PARTICIPANT	\N	PRESENT	0
75503	75219	11063M	PARTICIPANT	\N	PRESENT	0
75504	75219	14123H	PARTICIPANT	\N	PRESENT	0
75505	75219	92045V	PARTICIPANT	\N	PRESENT	0
75506	75219	14151M	PARTICIPANT	\N	PRESENT	0
75507	75219	08025T	PARTICIPANT	\N	PRESENT	0
75508	75219	01058X	PARTICIPANT	\N	PRESENT	0
75509	75219	01016M	PARTICIPANT	\N	PRESENT	0
75510	75219	11039M	PARTICIPANT	\N	PRESENT	0
75512	75219	04056J	PARTICIPANT	\N	PRESENT	0
75513	75219	08016S	PARTICIPANT	\N	PRESENT	0
75514	75219	14215L	PARTICIPANT	\N	PRESENT	0
75516	75219	07024N	PARTICIPANT	\N	PRESENT	0
75517	75219	92015P	PARTICIPANT	\N	PRESENT	0
75518	75219	14331P	PARTICIPANT	\N	PRESENT	0
75519	75219	08055A	PARTICIPANT	\N	PRESENT	0
75520	75219	95067Q	PARTICIPANT	\N	PRESENT	0
75521	75219	11100Y	PARTICIPANT	\N	PRESENT	0
75522	75219	14107H	PARTICIPANT	\N	PRESENT	0
75909	75220	92015P	PARTICIPANT	\N	PRESENT	0
75910	75220	14331P	PARTICIPANT	\N	PRESENT	0
75911	75220	08055A	PARTICIPANT	\N	PRESENT	0
75912	75220	95067Q	PARTICIPANT	\N	PRESENT	0
75913	75220	11100Y	PARTICIPANT	\N	PRESENT	0
75914	75220	14107H	PARTICIPANT	\N	PRESENT	0
75915	75220	04066L	PARTICIPANT	\N	PRESENT	0
75916	75220	92040Q	PARTICIPANT	\N	PRESENT	0
75917	75220	01011G	PARTICIPANT	\N	PRESENT	0
75918	75220	14119M	PARTICIPANT	\N	PRESENT	0
75919	75220	11084S	PARTICIPANT	\N	PRESENT	0
75920	75220	14135M	PARTICIPANT	\N	PRESENT	0
75921	75220	95035G	PARTICIPANT	\N	PRESENT	0
75922	75220	11089X	PARTICIPANT	\N	PRESENT	0
75923	75220	14037X	PARTICIPANT	\N	PRESENT	0
75924	75220	04047H	PARTICIPANT	\N	PRESENT	0
75925	75220	10015M	PARTICIPANT	\N	PRESENT	0
75926	75220	08012N	PARTICIPANT	\N	PRESENT	0
75927	75220	80027E	PARTICIPANT	\N	PRESENT	0
75928	75220	04079R	PARTICIPANT	\N	PRESENT	0
75929	75220	14053L	PARTICIPANT	\N	PRESENT	0
75930	75220	95037J	PARTICIPANT	\N	PRESENT	0
75931	75220	77002U	PARTICIPANT	\N	PRESENT	0
75932	75220	08058D	PARTICIPANT	\N	PRESENT	0
75933	75220	83047W	PARTICIPANT	\N	PRESENT	0
75934	75220	14227Q	PARTICIPANT	\N	PRESENT	0
75935	75220	14253S	PARTICIPANT	\N	PRESENT	0
75936	75220	14229S	PARTICIPANT	\N	PRESENT	0
75937	75220	14281W	PARTICIPANT	\N	PRESENT	0
75938	75220	11046L	PARTICIPANT	\N	PRESENT	0
75939	75220	11026G	PARTICIPANT	\N	PRESENT	0
75940	75220	14121F	PARTICIPANT	\N	PRESENT	0
75941	75220	08022Q	PARTICIPANT	\N	PRESENT	0
75942	75220	11074Q	PARTICIPANT	\N	PRESENT	0
75943	75220	11027H	PARTICIPANT	\N	PRESENT	0
75944	75220	14217N	PARTICIPANT	\N	PRESENT	0
75945	75220	14147R	PARTICIPANT	\N	PRESENT	0
75946	75220	14257W	PARTICIPANT	\N	PRESENT	0
75947	75220	11014C	PARTICIPANT	\N	PRESENT	0
75948	75220	99002P	PARTICIPANT	\N	PRESENT	0
75949	75220	14109K	PARTICIPANT	\N	PRESENT	0
75950	75220	14207L	PARTICIPANT	\N	PRESENT	0
75951	75220	14329V	PARTICIPANT	\N	PRESENT	0
75952	75220	14105F	PARTICIPANT	\N	PRESENT	0
75953	75220	11095V	PARTICIPANT	\N	PRESENT	0
75954	75220	14001X	PARTICIPANT	\N	PRESENT	0
75955	75220	05004A	PARTICIPANT	\N	PRESENT	0
75956	75220	05012A	PARTICIPANT	\N	PRESENT	0
75957	75220	04074L	PARTICIPANT	\N	PRESENT	0
75958	75220	14133K	PARTICIPANT	\N	PRESENT	0
75959	75220	14063N	PARTICIPANT	\N	PRESENT	0
75960	75220	01008M	PARTICIPANT	\N	PRESENT	0
75961	75220	83042R	PARTICIPANT	\N	PRESENT	0
75962	75220	14199E	PARTICIPANT	\N	PRESENT	0
75963	75220	11015D	PARTICIPANT	\N	PRESENT	0
75964	75220	08043V	PARTICIPANT	\N	PRESENT	0
75965	75220	11036J	PARTICIPANT	\N	PRESENT	0
75966	75220	11101A	PARTICIPANT	\N	PRESENT	0
75967	75220	80013X	PARTICIPANT	\N	PRESENT	0
75968	75220	14195A	PARTICIPANT	\N	PRESENT	0
75969	75220	11066Q	PARTICIPANT	\N	PRESENT	0
75970	75220	04077P	PARTICIPANT	\N	PRESENT	0
75971	75220	08061X	PARTICIPANT	\N	PRESENT	0
75972	75220	10006L	PARTICIPANT	\N	PRESENT	0
75973	75220	86044G	PARTICIPANT	\N	PRESENT	0
75974	75220	04053F	PARTICIPANT	\N	PRESENT	0
75975	75220	08073C	PARTICIPANT	\N	PRESENT	0
75976	75220	11020A	PARTICIPANT	\N	PRESENT	0
75977	75220	01028R	PARTICIPANT	\N	PRESENT	0
75978	75220	11104D	PARTICIPANT	\N	PRESENT	0
75979	75220	04057K	PARTICIPANT	\N	PRESENT	0
75980	75220	11110B	PARTICIPANT	\N	PRESENT	0
75981	75220	01057W	PARTICIPANT	\N	PRESENT	0
75982	75220	11032E	PARTICIPANT	\N	PRESENT	0
75983	75220	08024S	PARTICIPANT	\N	PRESENT	0
75984	75220	11071M	PARTICIPANT	\N	PRESENT	0
75985	75220	04059M	PARTICIPANT	\N	PRESENT	0
75986	75220	11048N	PARTICIPANT	\N	PRESENT	0
75987	75220	11061K	PARTICIPANT	\N	PRESENT	0
75988	75220	04061F	PARTICIPANT	\N	PRESENT	0
75989	75220	11106F	PARTICIPANT	\N	PRESENT	0
75990	75220	04035D	PARTICIPANT	\N	PRESENT	0
75991	75220	11067R	PARTICIPANT	\N	PRESENT	0
75992	75220	04049K	PARTICIPANT	\N	PRESENT	0
75993	75220	14014Q	PARTICIPANT	\N	PRESENT	0
75994	75220	11077T	PARTICIPANT	\N	PRESENT	0
75995	75220	04095R	PARTICIPANT	\N	PRESENT	0
75996	75220	11109J	PARTICIPANT	\N	PRESENT	0
75997	75220	98005N	PARTICIPANT	\N	PRESENT	0
75998	75220	11012A	PARTICIPANT	\N	PRESENT	0
75999	75220	13002U	PARTICIPANT	\N	PRESENT	0
76000	75220	11114F	PARTICIPANT	\N	PRESENT	0
76001	75220	08035V	PARTICIPANT	\N	PRESENT	0
76002	75220	11072N	PARTICIPANT	\N	PRESENT	0
76003	75220	14173T	PARTICIPANT	\N	PRESENT	0
76004	75220	01014K	PARTICIPANT	\N	PRESENT	0
76005	75220	14269B	PARTICIPANT	\N	PRESENT	0
76006	75220	98021N	PARTICIPANT	\N	PRESENT	0
76007	75220	11076S	PARTICIPANT	\N	PRESENT	0
76008	75220	14069U	PARTICIPANT	\N	PRESENT	0
76009	75220	11083R	PARTICIPANT	\N	PRESENT	0
76010	75220	14237S	PARTICIPANT	\N	PRESENT	0
76011	75220	11096W	PARTICIPANT	\N	PRESENT	0
76012	75220	08049C	PARTICIPANT	\N	PRESENT	0
76013	75220	88008L	PARTICIPANT	\N	PRESENT	0
76014	75220	04038G	PARTICIPANT	\N	PRESENT	0
76015	75220	04067M	PARTICIPANT	\N	PRESENT	0
76016	75220	04045F	PARTICIPANT	\N	PRESENT	0
76017	75220	98023Q	PARTICIPANT	\N	PRESENT	0
76018	75220	14026U	PARTICIPANT	\N	PRESENT	0
76019	75220	98024R	PARTICIPANT	\N	PRESENT	0
76020	75220	11091R	PARTICIPANT	\N	PRESENT	0
76021	75220	01003G	PARTICIPANT	\N	PRESENT	0
76022	75220	14157T	PARTICIPANT	\N	PRESENT	0
76023	75220	14239U	PARTICIPANT	\N	PRESENT	0
76024	75220	98022P	PARTICIPANT	\N	PRESENT	0
76025	75220	14241N	PARTICIPANT	\N	PRESENT	0
76026	75220	14031R	PARTICIPANT	\N	PRESENT	0
76027	75220	11037K	PARTICIPANT	\N	PRESENT	0
76028	75220	12042Y	PARTICIPANT	\N	PRESENT	0
76029	75220	08018U	PARTICIPANT	\N	PRESENT	0
76030	75220	11107G	PARTICIPANT	\N	PRESENT	0
76031	75220	08009T	PARTICIPANT	\N	PRESENT	0
76032	75220	08031R	PARTICIPANT	\N	PRESENT	0
76033	75220	14034U	PARTICIPANT	\N	PRESENT	0
76034	75220	14273W	PARTICIPANT	\N	PRESENT	0
76035	75220	04040A	PARTICIPANT	\N	PRESENT	0
76036	75220	14205J	PARTICIPANT	\N	PRESENT	0
76037	75220	14219Q	PARTICIPANT	\N	PRESENT	0
76038	75220	14042U	PARTICIPANT	\N	PRESENT	0
76039	75220	14103D	PARTICIPANT	\N	PRESENT	0
76040	75220	14221J	PARTICIPANT	\N	PRESENT	0
76041	75220	11082Q	PARTICIPANT	\N	PRESENT	0
76042	75220	01047U	PARTICIPANT	\N	PRESENT	0
76043	75220	14231L	PARTICIPANT	\N	PRESENT	0
76044	75220	14083S	PARTICIPANT	\N	PRESENT	0
76045	75220	04089T	PARTICIPANT	\N	PRESENT	0
76046	75220	14265W	PARTICIPANT	\N	PRESENT	0
76047	75220	14179A	PARTICIPANT	\N	PRESENT	0
76048	75220	98042T	PARTICIPANT	\N	PRESENT	0
76049	75220	07004J	PARTICIPANT	\N	PRESENT	0
76050	75220	11085T	PARTICIPANT	\N	PRESENT	0
76051	75220	11070L	PARTICIPANT	\N	PRESENT	0
76052	75220	08056B	PARTICIPANT	\N	PRESENT	0
76053	75220	01025N	PARTICIPANT	\N	PRESENT	0
76054	75220	01007L	PARTICIPANT	\N	PRESENT	0
76055	75220	14327T	PARTICIPANT	\N	PRESENT	0
76056	75220	11042G	PARTICIPANT	\N	PRESENT	0
76057	75220	04071H	PARTICIPANT	\N	PRESENT	0
76058	75220	11112D	PARTICIPANT	\N	PRESENT	0
76059	75220	14235Q	PARTICIPANT	\N	PRESENT	0
76060	75220	04054G	PARTICIPANT	\N	PRESENT	0
76061	75220	04044E	PARTICIPANT	\N	PRESENT	0
76062	75220	14251Q	PARTICIPANT	\N	PRESENT	0
76063	75220	04043D	PARTICIPANT	\N	PRESENT	0
76064	75220	11099A	PARTICIPANT	\N	PRESENT	0
76065	75220	01015L	PARTICIPANT	\N	PRESENT	0
76066	75220	11031D	PARTICIPANT	\N	PRESENT	0
76067	75220	01060R	PARTICIPANT	\N	PRESENT	0
76068	75220	14055N	PARTICIPANT	\N	PRESENT	0
76069	75220	92044U	PARTICIPANT	\N	PRESENT	0
76070	75220	08039A	PARTICIPANT	\N	PRESENT	0
76071	75220	14089Y	PARTICIPANT	\N	PRESENT	0
76072	75220	11064N	PARTICIPANT	\N	PRESENT	0
76073	75220	08038Y	PARTICIPANT	\N	PRESENT	0
76074	75220	11094U	PARTICIPANT	\N	PRESENT	0
76075	75220	14255U	PARTICIPANT	\N	PRESENT	0
76076	75220	98053W	PARTICIPANT	\N	PRESENT	0
62868	62861	86034E	PARTICIPANT	\N	PRESENT	0
62869	62861	11040E	PARTICIPANT	\N	PRESENT	0
62870	62861	04092N	PARTICIPANT	\N	PRESENT	0
62871	62861	01031L	PARTICIPANT	\N	PRESENT	0
62872	62861	01016M	PARTICIPANT	\N	PRESENT	0
62873	62861	11057P	PARTICIPANT	\N	PRESENT	0
62874	62861	95063L	PARTICIPANT	\N	PRESENT	0
62875	62861	14271U	PARTICIPANT	\N	PRESENT	0
62876	62861	08052W	PARTICIPANT	\N	PRESENT	0
62877	62861	14269B	PARTICIPANT	\N	PRESENT	0
62878	62861	08053X	PARTICIPANT	\N	PRESENT	0
62879	62861	13002U	PARTICIPANT	\N	PRESENT	0
62880	62861	11059R	PARTICIPANT	\N	PRESENT	0
62881	62861	04054G	PARTICIPANT	\N	PRESENT	0
62882	62861	14097Y	PARTICIPANT	\N	PRESENT	0
62883	62861	08014Q	PARTICIPANT	\N	PRESENT	0
62884	62861	11074Q	PARTICIPANT	\N	PRESENT	0
62885	62861	12042Y	PARTICIPANT	\N	PRESENT	0
62886	62861	04077P	PARTICIPANT	\N	PRESENT	0
62887	62861	11106F	PARTICIPANT	\N	PRESENT	0
62888	62861	04078Q	PARTICIPANT	\N	PRESENT	0
62889	62861	14257W	PARTICIPANT	\N	PRESENT	0
62890	62861	14235Q	PARTICIPANT	\N	PRESENT	0
62891	62861	11067R	PARTICIPANT	\N	PRESENT	0
62892	62861	01037S	PARTICIPANT	\N	PRESENT	0
62893	62861	01034P	PARTICIPANT	\N	PRESENT	0
62894	62861	08009T	PARTICIPANT	\N	PRESENT	0
62895	62861	14219Q	PARTICIPANT	\N	PRESENT	0
62896	62861	14103D	PARTICIPANT	\N	PRESENT	0
62897	62861	11093T	PARTICIPANT	\N	PRESENT	0
62898	62861	14073Q	PARTICIPANT	\N	PRESENT	0
62899	62861	14267Y	PARTICIPANT	\N	PRESENT	0
62900	62861	14107H	PARTICIPANT	\N	PRESENT	0
62901	62861	04089T	PARTICIPANT	\N	PRESENT	0
62902	62861	14273W	PARTICIPANT	\N	PRESENT	0
62903	62861	14079W	PARTICIPANT	\N	PRESENT	0
62904	62861	11083R	PARTICIPANT	\N	PRESENT	0
62905	62861	14255U	PARTICIPANT	\N	PRESENT	0
62906	62861	01024M	PARTICIPANT	\N	PRESENT	0
62907	62861	95030B	PARTICIPANT	\N	PRESENT	0
62908	62861	04035D	PARTICIPANT	\N	PRESENT	0
62909	62861	10015M	PARTICIPANT	\N	PRESENT	0
62910	62861	01027Q	PARTICIPANT	\N	PRESENT	0
62911	62861	04086Q	PARTICIPANT	\N	PRESENT	0
62912	62861	08039A	PARTICIPANT	\N	PRESENT	0
62913	62861	14223L	PARTICIPANT	\N	PRESENT	0
62914	62861	14253S	PARTICIPANT	\N	PRESENT	0
62915	62861	87003B	PARTICIPANT	\N	PRESENT	0
62916	62861	01057W	PARTICIPANT	\N	PRESENT	0
62917	62861	11048N	PARTICIPANT	\N	PRESENT	0
62918	62861	11091R	PARTICIPANT	\N	PRESENT	0
62919	62861	11103C	PARTICIPANT	\N	PRESENT	0
62920	62861	04057K	PARTICIPANT	\N	PRESENT	0
62921	62861	14201E	PARTICIPANT	\N	PRESENT	0
62922	62861	11042G	PARTICIPANT	\N	PRESENT	0
62923	62861	92031P	PARTICIPANT	\N	PRESENT	0
62924	62861	04048J	PARTICIPANT	\N	PRESENT	0
62925	62861	14331P	PARTICIPANT	\N	PRESENT	0
62926	62861	04055H	PARTICIPANT	\N	PRESENT	0
62927	62861	14061L	PARTICIPANT	\N	PRESENT	0
62928	62861	08073C	PARTICIPANT	\N	PRESENT	0
62929	62861	14018U	PARTICIPANT	\N	PRESENT	0
62930	62861	97011G	PARTICIPANT	\N	PRESENT	0
62931	62861	14175V	PARTICIPANT	\N	PRESENT	0
62932	62861	14135M	PARTICIPANT	\N	PRESENT	0
62933	62861	14033T	PARTICIPANT	\N	PRESENT	0
62934	62861	08019V	PARTICIPANT	\N	PRESENT	0
62935	62861	04088S	PARTICIPANT	\N	PRESENT	0
62936	62861	11101A	PARTICIPANT	\N	PRESENT	0
62937	62861	14028W	PARTICIPANT	\N	PRESENT	0
62938	62861	01007L	PARTICIPANT	\N	PRESENT	0
62939	62861	88008L	PARTICIPANT	\N	PRESENT	0
62940	62861	08051V	PARTICIPANT	\N	PRESENT	0
62941	62861	14038Y	PARTICIPANT	\N	PRESENT	0
62942	62861	14231L	PARTICIPANT	\N	PRESENT	0
62943	62861	14034U	PARTICIPANT	\N	PRESENT	0
62944	62861	11053K	PARTICIPANT	\N	PRESENT	0
62945	62861	04041B	PARTICIPANT	\N	PRESENT	0
62946	62861	14039A	PARTICIPANT	\N	PRESENT	0
62947	62861	95062K	PARTICIPANT	\N	PRESENT	0
62948	62861	14249W	PARTICIPANT	\N	PRESENT	0
62949	62861	14191V	PARTICIPANT	\N	PRESENT	0
62950	62861	14209N	PARTICIPANT	\N	PRESENT	0
62951	62861	14159V	PARTICIPANT	\N	PRESENT	0
62952	62861	08068F	PARTICIPANT	\N	PRESENT	0
62953	62861	14327T	PARTICIPANT	\N	PRESENT	0
62954	62861	14119M	PARTICIPANT	\N	PRESENT	0
62955	62861	01041N	PARTICIPANT	\N	PRESENT	0
62956	62861	01014K	PARTICIPANT	\N	PRESENT	0
62957	62861	98022P	PARTICIPANT	\N	PRESENT	0
62958	62861	14197C	PARTICIPANT	\N	PRESENT	0
62959	62861	11066Q	PARTICIPANT	\N	PRESENT	0
62960	62861	08069G	PARTICIPANT	\N	PRESENT	0
62961	62861	07029T	PARTICIPANT	\N	PRESENT	0
62962	62861	14083S	PARTICIPANT	\N	PRESENT	0
62963	62861	11012A	PARTICIPANT	\N	PRESENT	0
62964	62861	12041X	PARTICIPANT	\N	PRESENT	0
62965	62861	08011M	PARTICIPANT	\N	PRESENT	0
62966	62861	11027H	PARTICIPANT	\N	PRESENT	0
62967	62861	08061X	PARTICIPANT	\N	PRESENT	0
62968	62861	01025N	PARTICIPANT	\N	PRESENT	0
62969	62861	14259Y	PARTICIPANT	\N	PRESENT	0
62970	62861	80013X	PARTICIPANT	\N	PRESENT	0
62971	62861	14087W	PARTICIPANT	\N	PRESENT	0
62972	62861	95037J	PARTICIPANT	\N	PRESENT	0
62973	62861	04040A	PARTICIPANT	\N	PRESENT	0
62974	62861	11114F	PARTICIPANT	\N	PRESENT	0
62975	62861	14157T	PARTICIPANT	\N	PRESENT	0
62976	62861	07026Q	PARTICIPANT	\N	PRESENT	0
62977	62861	07024N	PARTICIPANT	\N	PRESENT	0
62978	62861	95035G	PARTICIPANT	\N	PRESENT	0
62979	62862	01007L	PARTICIPANT	\N	PRESENT	0
62983	62862	04054G	PARTICIPANT	\N	PRESENT	0
62985	62862	14235Q	PARTICIPANT	\N	PRESENT	0
62986	62862	80013X	PARTICIPANT	\N	PRESENT	0
62987	62862	14271U	PARTICIPANT	\N	PRESENT	0
62988	62862	11042G	PARTICIPANT	\N	PRESENT	0
62989	62862	13002U	PARTICIPANT	\N	PRESENT	0
62990	62862	08068F	PARTICIPANT	\N	PRESENT	0
62991	62862	14197C	PARTICIPANT	\N	PRESENT	0
62992	62862	95037J	PARTICIPANT	\N	PRESENT	0
62993	62862	14107H	PARTICIPANT	\N	PRESENT	0
62995	62862	11074Q	PARTICIPANT	\N	PRESENT	0
62996	62862	11106F	PARTICIPANT	\N	PRESENT	0
63007	62862	01025N	PARTICIPANT	\N	PRESENT	0
63009	62862	01024M	PARTICIPANT	\N	PRESENT	0
63010	62862	92031P	PARTICIPANT	\N	PRESENT	0
63012	62862	14159V	PARTICIPANT	\N	PRESENT	0
63013	62862	07024N	PARTICIPANT	\N	PRESENT	0
63014	62862	14209N	PARTICIPANT	\N	PRESENT	0
63016	62862	97011G	PARTICIPANT	\N	PRESENT	0
63017	62862	04088S	PARTICIPANT	\N	PRESENT	0
63019	62862	08069G	PARTICIPANT	\N	PRESENT	0
63021	62862	14031R	PARTICIPANT	\N	PRESENT	0
63023	62862	14038Y	PARTICIPANT	\N	PRESENT	0
63025	62862	14259Y	PARTICIPANT	\N	PRESENT	0
63026	62862	04041B	PARTICIPANT	\N	PRESENT	0
63029	62862	95030B	PARTICIPANT	\N	PRESENT	0
63037	62862	95062K	PARTICIPANT	\N	PRESENT	0
63039	62862	11104D	PARTICIPANT	\N	PRESENT	0
63040	62862	08053X	PARTICIPANT	\N	PRESENT	0
63041	62862	95035G	PARTICIPANT	\N	PRESENT	0
63042	62862	14097Y	PARTICIPANT	\N	PRESENT	0
63043	62862	14073Q	PARTICIPANT	\N	PRESENT	0
63044	62862	11091R	PARTICIPANT	\N	PRESENT	0
63045	62862	88008L	PARTICIPANT	\N	PRESENT	0
63046	62862	11012A	PARTICIPANT	\N	PRESENT	0
63048	62862	04035D	PARTICIPANT	\N	PRESENT	0
63050	62862	01041N	PARTICIPANT	\N	PRESENT	0
63051	62862	14061L	PARTICIPANT	\N	PRESENT	0
63052	62862	14229S	PARTICIPANT	\N	PRESENT	0
63053	62862	95031C	PARTICIPANT	\N	PRESENT	0
63054	62862	14269B	PARTICIPANT	\N	PRESENT	0
63055	62862	77002U	PARTICIPANT	\N	PRESENT	0
63056	62862	11027H	PARTICIPANT	\N	PRESENT	0
63057	62862	08043V	PARTICIPANT	\N	PRESENT	0
83929	83892	96003C	PARTICIPANT	\N	EXCUSE	0
89261	87175	14017T	PARTICIPANT	\N	EXCUSE	0
89262	87176	14017T	PARTICIPANT	\N	EXCUSE	0
89266	89265	98046X	PARTICIPANT	\N	PRESENT	0
89268	89267	98046X	PARTICIPANT	\N	PRESENT	0
89270	89269	98046X	PARTICIPANT	\N	PRESENT	0
89272	89271	14111D	PARTICIPANT	\N	PRESENT	0
91454	87175	14093U	PARTICIPANT	\N	EXCUSE	0
91455	87175	14039A	PARTICIPANT	\N	EXCUSE	0
91456	87175	08073C	PARTICIPANT	\N	EXCUSE	0
91463	87176	14093U	PARTICIPANT	\N	EXCUSE	0
91464	87176	14259Y	PARTICIPANT	\N	EXCUSE	0
91465	87176	14039A	PARTICIPANT	\N	EXCUSE	0
91466	87176	08073C	PARTICIPANT	\N	EXCUSE	0
91467	87175	14259Y	PARTICIPANT	\N	EXCUSE	0
91471	90264	11090Q	PARTICIPANT	\N	PRESENT	0
91511	90265	14223L	PARTICIPANT	\N	PRESENT	0
91512	90265	14231L	PARTICIPANT	\N	PRESENT	0
91514	90265	11067R	PARTICIPANT	\N	PRESENT	0
91515	90265	14219Q	PARTICIPANT	\N	PRESENT	0
91516	90265	14097Y	PARTICIPANT	\N	PRESENT	0
91517	90265	14227Q	PARTICIPANT	\N	PRESENT	0
91518	90265	92044U	PARTICIPANT	\N	PRESENT	0
91519	90265	11014C	PARTICIPANT	\N	PRESENT	0
91520	90265	14225N	PARTICIPANT	\N	PRESENT	0
91521	90265	13002U	PARTICIPANT	\N	PRESENT	0
91522	90265	14267Y	PARTICIPANT	\N	PRESENT	0
91523	90265	11055M	PARTICIPANT	\N	PRESENT	0
91524	90265	11066Q	PARTICIPANT	\N	PRESENT	0
91525	90265	14063N	PARTICIPANT	\N	PRESENT	0
91526	90265	14221J	PARTICIPANT	\N	PRESENT	0
91527	90265	11101A	PARTICIPANT	\N	PRESENT	0
91528	90265	14041T	PARTICIPANT	\N	PRESENT	0
91529	90265	01003G	PARTICIPANT	\N	PRESENT	0
91530	90265	80013X	PARTICIPANT	\N	PRESENT	0
91531	90265	14237S	PARTICIPANT	\N	PRESENT	0
91532	90265	88008L	PARTICIPANT	\N	PRESENT	0
91533	90265	01046T	PARTICIPANT	\N	PRESENT	0
91534	90265	14013P	PARTICIPANT	\N	PRESENT	0
91535	90265	04049K	PARTICIPANT	\N	PRESENT	0
91536	90265	07026Q	PARTICIPANT	\N	PRESENT	0
91537	90265	08014Q	PARTICIPANT	\N	PRESENT	0
91538	90265	11035H	PARTICIPANT	\N	PRESENT	0
91539	90265	98022P	PARTICIPANT	\N	PRESENT	0
91540	90265	14059S	PARTICIPANT	\N	PRESENT	0
91541	90265	98024R	PARTICIPANT	\N	PRESENT	0
91542	90265	99004R	PARTICIPANT	\N	PRESENT	0
91543	90265	11091R	PARTICIPANT	\N	PRESENT	0
91544	90265	11103C	PARTICIPANT	\N	PRESENT	0
91545	90265	14111D	PARTICIPANT	\N	PRESENT	0
91546	90265	11012A	PARTICIPANT	\N	PRESENT	0
91547	90265	11082Q	PARTICIPANT	\N	PRESENT	0
91509	90265	86034E	PARTICIPANT	\N	PRESENT	0
91510	90265	14179A	PARTICIPANT	\N	PRESENT	0
91548	90265	11097X	PARTICIPANT	\N	PRESENT	0
91549	90265	10006L	PARTICIPANT	\N	PRESENT	0
91550	90265	08058D	PARTICIPANT	\N	PRESENT	0
91551	90265	14251Q	PARTICIPANT	\N	PRESENT	0
91552	90265	12041X	PARTICIPANT	\N	PRESENT	0
91553	90265	04086Q	PARTICIPANT	\N	PRESENT	0
91554	90265	14191V	PARTICIPANT	\N	PRESENT	0
91555	90265	14265W	PARTICIPANT	\N	PRESENT	0
91556	90265	04050C	PARTICIPANT	\N	PRESENT	0
91557	90265	04085P	PARTICIPANT	\N	PRESENT	0
91558	90265	11040E	PARTICIPANT	\N	PRESENT	0
91559	90265	08022Q	PARTICIPANT	\N	PRESENT	0
91560	90265	11034G	PARTICIPANT	\N	PRESENT	0
91561	90265	14107H	PARTICIPANT	\N	PRESENT	0
91562	90265	95059Q	PARTICIPANT	\N	PRESENT	0
91563	90265	01013J	PARTICIPANT	\N	PRESENT	0
91564	90265	08062Y	PARTICIPANT	\N	PRESENT	0
91565	90265	14151M	PARTICIPANT	\N	PRESENT	0
91566	90265	14331P	PARTICIPANT	\N	PRESENT	0
91567	90265	08043V	PARTICIPANT	\N	PRESENT	0
91568	90265	08034U	PARTICIPANT	\N	PRESENT	0
91569	90265	08055A	PARTICIPANT	\N	PRESENT	0
91570	90265	11104D	PARTICIPANT	\N	PRESENT	0
91571	90265	14031R	PARTICIPANT	\N	PRESENT	0
91572	90265	92015P	PARTICIPANT	\N	PRESENT	0
91573	90265	04092N	PARTICIPANT	\N	PRESENT	0
91574	90265	11110B	PARTICIPANT	\N	PRESENT	0
91575	90265	11054L	PARTICIPANT	\N	PRESENT	0
91576	90265	14157T	PARTICIPANT	\N	PRESENT	0
91577	90265	07032N	PARTICIPANT	\N	PRESENT	0
91578	90265	08018U	PARTICIPANT	\N	PRESENT	0
91579	90265	14255U	PARTICIPANT	\N	PRESENT	0
91580	90265	08024S	PARTICIPANT	\N	PRESENT	0
91581	90265	14253S	PARTICIPANT	\N	PRESENT	0
91582	90265	04034C	PARTICIPANT	\N	PRESENT	0
91583	90265	08017T	PARTICIPANT	\N	PRESENT	0
91584	90265	14133K	PARTICIPANT	\N	PRESENT	0
91585	90265	95037J	PARTICIPANT	\N	PRESENT	0
91586	90265	98018T	PARTICIPANT	\N	PRESENT	0
91587	90265	01022K	PARTICIPANT	\N	PRESENT	0
91588	90265	04071H	PARTICIPANT	\N	PRESENT	0
91589	90265	14197C	PARTICIPANT	\N	PRESENT	0
91590	90265	95067Q	PARTICIPANT	\N	PRESENT	0
91591	90265	08012N	PARTICIPANT	\N	PRESENT	0
91592	90265	02002K	PARTICIPANT	\N	PRESENT	0
91593	90265	11046L	PARTICIPANT	\N	PRESENT	0
91594	90265	14071N	PARTICIPANT	\N	PRESENT	0
91595	90265	01056V	PARTICIPANT	\N	PRESENT	0
91596	90265	04033B	PARTICIPANT	\N	PRESENT	0
91597	90265	04057K	PARTICIPANT	\N	PRESENT	0
91598	90265	14105F	PARTICIPANT	\N	PRESENT	0
91599	90265	08015R	PARTICIPANT	\N	PRESENT	0
91600	90265	04036E	PARTICIPANT	\N	PRESENT	0
91601	90265	04043D	PARTICIPANT	\N	PRESENT	0
91602	90265	05004A	PARTICIPANT	\N	PRESENT	0
91603	90265	05012A	PARTICIPANT	\N	PRESENT	0
91604	90265	95015C	PARTICIPANT	\N	PRESENT	0
91605	90265	96004D	PARTICIPANT	\N	PRESENT	0
91606	90265	01027Q	PARTICIPANT	\N	PRESENT	0
91607	90265	01015L	PARTICIPANT	\N	PRESENT	0
91608	90265	04054G	PARTICIPANT	\N	PRESENT	0
91609	90265	92045V	PARTICIPANT	\N	PRESENT	0
91610	90265	01059Y	PARTICIPANT	\N	PRESENT	0
91611	90265	01008M	PARTICIPANT	\N	PRESENT	0
91612	90265	11056N	PARTICIPANT	\N	PRESENT	0
91613	90265	14135M	PARTICIPANT	\N	PRESENT	0
91614	90265	11029K	PARTICIPANT	\N	PRESENT	0
91615	90265	01044R	PARTICIPANT	\N	PRESENT	0
91616	90265	11049P	PARTICIPANT	\N	PRESENT	0
91617	90265	04088S	PARTICIPANT	\N	PRESENT	0
91618	90265	04078Q	PARTICIPANT	\N	PRESENT	0
91619	90265	08042U	PARTICIPANT	\N	PRESENT	0
91620	90265	97011G	PARTICIPANT	\N	PRESENT	0
91621	90265	14201E	PARTICIPANT	\N	PRESENT	0
91622	90265	01058X	PARTICIPANT	\N	PRESENT	0
91623	90265	14038Y	PARTICIPANT	\N	PRESENT	0
91624	90265	04074L	PARTICIPANT	\N	PRESENT	0
91625	90265	04067M	PARTICIPANT	\N	PRESENT	0
91626	90265	14329V	PARTICIPANT	\N	PRESENT	0
91627	90265	08019V	PARTICIPANT	\N	PRESENT	0
91628	90265	08016S	PARTICIPANT	\N	PRESENT	0
91629	90265	98035U	PARTICIPANT	\N	PRESENT	0
91630	90265	04056J	PARTICIPANT	\N	PRESENT	0
91631	90265	11088W	PARTICIPANT	\N	PRESENT	0
91632	90265	98046X	PARTICIPANT	\N	PRESENT	0
91633	90265	08052W	PARTICIPANT	\N	PRESENT	0
91634	90265	95063L	PARTICIPANT	\N	PRESENT	0
91635	90265	11100Y	PARTICIPANT	\N	PRESENT	0
91636	90265	14051J	PARTICIPANT	\N	PRESENT	0
91637	90265	14187A	PARTICIPANT	\N	PRESENT	0
91638	90265	04066L	PARTICIPANT	\N	PRESENT	0
91639	90265	98050T	PARTICIPANT	\N	PRESENT	0
91640	90265	01011G	PARTICIPANT	\N	PRESENT	0
91641	90265	08060W	PARTICIPANT	\N	PRESENT	0
91642	90265	07029T	PARTICIPANT	\N	PRESENT	0
91643	90265	11015D	PARTICIPANT	\N	PRESENT	0
91644	90265	77002U	PARTICIPANT	\N	PRESENT	0
91645	90265	11105E	PARTICIPANT	\N	PRESENT	0
91646	90265	14069U	PARTICIPANT	\N	PRESENT	0
91647	90265	11036J	PARTICIPANT	\N	PRESENT	0
91648	90265	92031P	PARTICIPANT	\N	PRESENT	0
91649	90265	98029W	PARTICIPANT	\N	PRESENT	0
91650	90265	14079W	PARTICIPANT	\N	PRESENT	0
91651	90265	83042R	PARTICIPANT	\N	PRESENT	0
91652	90265	14119M	PARTICIPANT	\N	PRESENT	0
91653	90265	01057W	PARTICIPANT	\N	PRESENT	0
91654	90265	14014Q	PARTICIPANT	\N	PRESENT	0
91655	90265	14207L	PARTICIPANT	\N	PRESENT	0
91656	90265	10015M	PARTICIPANT	\N	PRESENT	0
91657	90265	95062K	PARTICIPANT	\N	PRESENT	0
91658	90265	14001X	PARTICIPANT	\N	PRESENT	0
91659	90265	14217N	PARTICIPANT	\N	PRESENT	0
91660	90265	11031D	PARTICIPANT	\N	PRESENT	0
91661	90265	11098Y	PARTICIPANT	\N	PRESENT	0
62998	62994	14030Q	PARTICIPANT	\N	EXCUSE	0
62999	62994	08043V	PARTICIPANT	\N	PRESENT	0
63001	62994	11029K	PARTICIPANT	\N	PRESENT	0
63003	62994	11031D	PARTICIPANT	\N	PRESENT	0
63005	62994	11027H	PARTICIPANT	\N	PRESENT	0
63006	62994	80013X	PARTICIPANT	\N	PRESENT	0
63008	62994	14041T	PARTICIPANT	\N	EXCUSE	0
63011	62994	98042T	PARTICIPANT	\N	PRESENT	0
63015	62994	12042Y	PARTICIPANT	\N	PRESENT	0
63018	62994	14187A	PARTICIPANT	\N	EXCUSE	0
63020	62994	14281W	PARTICIPANT	\N	PRESENT	0
63022	62994	04035D	PARTICIPANT	\N	EXCUSE	0
63024	62994	11061K	PARTICIPANT	\N	PRESENT	0
63027	62994	14014Q	PARTICIPANT	\N	EXCUSE	0
63028	62994	07026Q	PARTICIPANT	\N	EXCUSE	0
63030	62994	95035G	PARTICIPANT	\N	PRESENT	0
63031	62994	04041B	PARTICIPANT	\N	PRESENT	0
63032	62994	09001P	PRESIDENT	0	PRESENT	0
63033	62994	08031R	PARTICIPANT	\N	PRESENT	0
63034	62994	07029T	PARTICIPANT	\N	PRESENT	0
63035	62994	14031R	PARTICIPANT	\N	EXCUSE	0
63036	62994	11067R	PARTICIPANT	\N	PRESENT	0
63038	62994	14265W	PARTICIPANT	\N	EXCUSE	0
64024	63998	08055A	PARTICIPANT	\N	PRESENT	0
64025	63998	14231L	PARTICIPANT	\N	PRESENT	0
64026	63998	07026Q	PARTICIPANT	\N	PRESENT	0
64027	63998	14259Y	PARTICIPANT	\N	PRESENT	0
64028	63998	11043H	PARTICIPANT	\N	PRESENT	0
64029	63998	14331P	PARTICIPANT	\N	PRESENT	0
64030	63998	14169X	PARTICIPANT	\N	PRESENT	0
64031	63998	14041T	PARTICIPANT	\N	PRESENT	0
64032	63998	14175V	PARTICIPANT	\N	PRESENT	0
64033	63998	14087W	PARTICIPANT	\N	PRESENT	0
64034	63998	11049P	PARTICIPANT	\N	PRESENT	0
64035	63998	14235Q	PARTICIPANT	\N	PRESENT	0
64036	63998	14273W	PARTICIPANT	\N	PRESENT	0
64037	63998	01044R	PARTICIPANT	\N	PRESENT	0
64038	63998	14209N	PARTICIPANT	\N	PRESENT	0
64039	63998	08039A	PARTICIPANT	\N	PRESENT	0
64040	63998	04070G	PARTICIPANT	\N	PRESENT	0
64041	63998	14241N	PARTICIPANT	\N	PRESENT	0
64042	63998	14121F	PARTICIPANT	\N	PRESENT	0
64043	63998	08043V	PARTICIPANT	\N	PRESENT	0
64044	63998	14229S	PARTICIPANT	\N	PRESENT	0
64045	63998	04059M	PARTICIPANT	\N	PRESENT	0
64046	63998	14109K	PARTICIPANT	\N	PRESENT	0
64047	63998	11089X	PARTICIPANT	\N	PRESENT	0
64048	63998	14265W	PARTICIPANT	\N	PRESENT	0
64049	63998	14187A	PARTICIPANT	\N	PRESENT	0
64050	63998	11014C	PARTICIPANT	\N	PRESENT	0
64051	63998	08012N	PARTICIPANT	\N	PRESENT	0
64052	63998	14221J	PARTICIPANT	\N	PRESENT	0
64053	63998	14219Q	PARTICIPANT	\N	PRESENT	0
64054	63998	14267Y	PARTICIPANT	\N	PRESENT	0
64055	63998	11104D	PARTICIPANT	\N	PRESENT	0
64056	63998	14073Q	PARTICIPANT	\N	PRESENT	0
64057	63998	14059S	PARTICIPANT	\N	PRESENT	0
64058	63998	11103C	PARTICIPANT	\N	PRESENT	0
64059	63998	14038Y	PARTICIPANT	\N	PRESENT	0
64060	63998	14173T	PARTICIPANT	\N	PRESENT	0
64061	63998	14147R	PARTICIPANT	\N	PRESENT	0
64062	63998	04033B	PARTICIPANT	\N	PRESENT	0
64063	63998	95037J	PARTICIPANT	\N	PRESENT	0
64064	63998	04088S	PARTICIPANT	\N	PRESENT	0
64065	63998	14237S	PARTICIPANT	\N	PRESENT	0
64066	63998	11012A	PARTICIPANT	\N	PRESENT	0
64067	63998	86044G	PARTICIPANT	\N	PRESENT	0
64068	63998	11029K	PARTICIPANT	\N	PRESENT	0
64069	63998	14207L	PARTICIPANT	\N	PRESENT	0
64070	63998	11044J	PARTICIPANT	\N	PRESENT	0
64071	63998	11091R	PARTICIPANT	\N	PRESENT	0
64072	63998	14071N	PARTICIPANT	\N	PRESENT	0
64073	63998	14026U	PARTICIPANT	\N	PRESENT	0
64074	63998	08065C	PARTICIPANT	\N	PRESENT	0
64075	63998	11074Q	PARTICIPANT	\N	PRESENT	0
64076	63998	08061X	PARTICIPANT	\N	PRESENT	0
64077	63998	13002U	PARTICIPANT	\N	PRESENT	0
64078	63998	14033T	PARTICIPANT	\N	PRESENT	0
64079	63998	14327T	PARTICIPANT	\N	PRESENT	0
64080	63998	92045V	PARTICIPANT	\N	PRESENT	0
64081	63998	14205J	PARTICIPANT	\N	PRESENT	0
64082	63998	11094U	PARTICIPANT	\N	PRESENT	0
64083	63998	14063N	PARTICIPANT	\N	PRESENT	0
64084	63998	01041N	PARTICIPANT	\N	PRESENT	0
64085	63998	14105F	PARTICIPANT	\N	PRESENT	0
64086	63998	01060R	PARTICIPANT	\N	PRESENT	0
64087	63998	01025N	PARTICIPANT	\N	PRESENT	0
64088	63998	08056B	PARTICIPANT	\N	PRESENT	0
64089	63998	14042U	PARTICIPANT	\N	PRESENT	0
64090	63998	14081Q	PARTICIPANT	\N	PRESENT	0
64091	63998	14263U	PARTICIPANT	\N	PRESENT	0
64092	63998	11066Q	PARTICIPANT	\N	PRESENT	0
64093	63998	04057K	PARTICIPANT	\N	PRESENT	0
64094	63998	97011G	PARTICIPANT	\N	PRESENT	0
64095	63998	08047A	PARTICIPANT	\N	PRESENT	0
64096	63998	04035D	PARTICIPANT	\N	PRESENT	0
64097	63998	11037K	PARTICIPANT	\N	PRESENT	0
64098	63998	14217N	PARTICIPANT	\N	PRESENT	0
64099	63998	88008L	PARTICIPANT	\N	PRESENT	0
64100	63998	14135M	PARTICIPANT	\N	PRESENT	0
64101	63998	08048B	PARTICIPANT	\N	PRESENT	0
64102	63998	11040E	PARTICIPANT	\N	PRESENT	0
64103	63998	14034U	PARTICIPANT	\N	PRESENT	0
64104	63998	08031R	PARTICIPANT	\N	PRESENT	0
64105	63998	08017T	PARTICIPANT	\N	PRESENT	0
64106	63998	11042G	PARTICIPANT	\N	PRESENT	0
64107	63998	08069G	PARTICIPANT	\N	PRESENT	0
64108	63998	01008M	PARTICIPANT	\N	PRESENT	0
64109	63998	08015R	PARTICIPANT	\N	PRESENT	0
64110	63998	14257W	PARTICIPANT	\N	PRESENT	0
64111	63998	04089T	PARTICIPANT	\N	PRESENT	0
64112	63998	14111D	PARTICIPANT	\N	PRESENT	0
64113	63998	14093U	PARTICIPANT	\N	PRESENT	0
64114	63998	08016S	PARTICIPANT	\N	PRESENT	0
64115	63998	08024S	PARTICIPANT	\N	PRESENT	0
64116	63998	14013P	PARTICIPANT	\N	PRESENT	0
64117	63998	95031C	PARTICIPANT	\N	PRESENT	0
64118	63998	14103D	PARTICIPANT	\N	PRESENT	0
64119	63998	14213J	PARTICIPANT	\N	PRESENT	0
64120	63998	11053K	PARTICIPANT	\N	PRESENT	0
64121	63998	08034U	PARTICIPANT	\N	PRESENT	0
64122	63998	08041T	PARTICIPANT	\N	PRESENT	0
64123	63998	11036J	PARTICIPANT	\N	PRESENT	0
64124	63998	01028R	PARTICIPANT	\N	PRESENT	0
64125	63998	14039A	PARTICIPANT	\N	PRESENT	0
64126	63998	14030Q	PARTICIPANT	\N	PRESENT	0
64127	63998	92018S	PARTICIPANT	\N	PRESENT	0
64128	63998	14159V	PARTICIPANT	\N	PRESENT	0
64129	63998	11071M	PARTICIPANT	\N	PRESENT	0
64130	63998	14053L	PARTICIPANT	\N	PRESENT	0
64131	63998	14061L	PARTICIPANT	\N	PRESENT	0
64132	63998	95015C	PARTICIPANT	\N	PRESENT	0
64133	63998	10015M	PARTICIPANT	\N	PRESENT	0
64134	63998	14199E	PARTICIPANT	\N	PRESENT	0
64135	63998	04048J	PARTICIPANT	\N	PRESENT	0
64136	63998	11114F	PARTICIPANT	\N	PRESENT	0
64137	63998	02002K	PARTICIPANT	\N	PRESENT	0
64138	63998	07004J	PARTICIPANT	\N	PRESENT	0
64139	63998	01007L	PARTICIPANT	\N	PRESENT	0
64140	63998	04056J	PARTICIPANT	\N	PRESENT	0
64141	63998	14223L	PARTICIPANT	\N	PRESENT	0
64142	63998	01027Q	PARTICIPANT	\N	PRESENT	0
64143	63998	01022K	PARTICIPANT	\N	PRESENT	0
64144	63998	14051J	PARTICIPANT	\N	PRESENT	0
64145	63998	01015L	PARTICIPANT	\N	PRESENT	0
64146	63998	11107G	PARTICIPANT	\N	PRESENT	0
64147	63998	14107H	PARTICIPANT	\N	PRESENT	0
64148	63998	11054L	PARTICIPANT	\N	PRESENT	0
64149	63998	08010L	PARTICIPANT	\N	PRESENT	0
64150	63998	08028W	PARTICIPANT	\N	PRESENT	0
64151	63998	14085U	PARTICIPANT	\N	PRESENT	0
64152	63998	14329V	PARTICIPANT	\N	PRESENT	0
64153	63998	95035G	PARTICIPANT	\N	PRESENT	0
64154	63998	14157T	PARTICIPANT	\N	PRESENT	0
64155	63998	14083S	PARTICIPANT	\N	PRESENT	0
64156	63998	08019V	PARTICIPANT	\N	PRESENT	0
64157	63998	14119M	PARTICIPANT	\N	PRESENT	0
64158	63998	11101A	PARTICIPANT	\N	PRESENT	0
64159	63998	87003B	PARTICIPANT	\N	PRESENT	0
64160	63998	90003B	PARTICIPANT	\N	PRESENT	0
64161	63998	14031R	PARTICIPANT	\N	PRESENT	0
64162	63998	11105E	PARTICIPANT	\N	PRESENT	0
64163	63998	07024N	PARTICIPANT	\N	PRESENT	0
64164	63998	95030B	PARTICIPANT	\N	PRESENT	0
64165	63998	95062K	PARTICIPANT	\N	PRESENT	0
64166	63998	95049N	PARTICIPANT	\N	PRESENT	0
64167	63998	11100Y	PARTICIPANT	\N	PRESENT	0
64168	63998	14195A	PARTICIPANT	\N	PRESENT	0
64169	63998	08021P	PARTICIPANT	\N	PRESENT	0
76077	75220	04070G	PARTICIPANT	\N	PRESENT	0
76078	75220	08048B	PARTICIPANT	\N	PRESENT	0
76079	75220	08017T	PARTICIPANT	\N	PRESENT	0
76080	75220	04055H	PARTICIPANT	\N	PRESENT	0
76081	75220	11065P	PARTICIPANT	\N	PRESENT	0
76082	75220	01034P	PARTICIPANT	\N	PRESENT	0
76083	75220	11054L	PARTICIPANT	\N	PRESENT	0
76084	75220	11068S	PARTICIPANT	\N	PRESENT	0
76085	75220	89017R	PARTICIPANT	\N	PRESENT	0
76086	75220	14065Q	PARTICIPANT	\N	PRESENT	0
76087	75210	86034E	PARTICIPANT	\N	PRESENT	0
76088	75210	14033T	PARTICIPANT	\N	PRESENT	0
76089	75210	95031C	PARTICIPANT	\N	PRESENT	0
76090	75210	14087W	PARTICIPANT	\N	PRESENT	0
76091	75210	14041T	PARTICIPANT	\N	PRESENT	0
76092	75210	14097Y	PARTICIPANT	\N	PRESENT	0
76093	75210	14267Y	PARTICIPANT	\N	PRESENT	0
76094	75210	00003C	PARTICIPANT	\N	PRESENT	0
76095	75210	14213J	PARTICIPANT	\N	PRESENT	0
76096	75210	11025F	PARTICIPANT	\N	PRESENT	0
76097	75210	14059S	PARTICIPANT	\N	PRESENT	0
76098	75210	14249W	PARTICIPANT	\N	PRESENT	0
76099	75210	14271U	PARTICIPANT	\N	PRESENT	0
76100	75210	14277B	PARTICIPANT	\N	PRESENT	0
76101	75210	14275Y	PARTICIPANT	\N	PRESENT	0
76102	75210	14030Q	PARTICIPANT	\N	PRESENT	0
76103	75210	01024M	PARTICIPANT	\N	PRESENT	0
76104	75210	11055M	PARTICIPANT	\N	PRESENT	0
76105	75210	09001P	PARTICIPANT	\N	PRESENT	0
76106	75210	08060W	PARTICIPANT	\N	PRESENT	0
76107	75210	11105E	PARTICIPANT	\N	PRESENT	0
76108	75210	14085U	PARTICIPANT	\N	PRESENT	0
76109	75210	14247U	PARTICIPANT	\N	PRESENT	0
76110	75210	08069G	PARTICIPANT	\N	PRESENT	0
76111	75210	04097T	PARTICIPANT	\N	PRESENT	0
76112	75210	08021P	PARTICIPANT	\N	PRESENT	0
76113	75210	04094Q	PARTICIPANT	\N	PRESENT	0
76114	75210	14039A	PARTICIPANT	\N	PRESENT	0
76115	75210	92018S	PARTICIPANT	\N	PRESENT	0
76117	75210	01022K	PARTICIPANT	\N	PRESENT	0
76118	75210	01043Q	PARTICIPANT	\N	PRESENT	0
76119	75210	04078Q	PARTICIPANT	\N	PRESENT	0
76120	75210	04036E	PARTICIPANT	\N	PRESENT	0
76121	75210	92039X	PARTICIPANT	\N	PRESENT	0
76122	75210	14073Q	PARTICIPANT	\N	PRESENT	0
76123	75210	14038Y	PARTICIPANT	\N	PRESENT	0
76124	75210	11035H	PARTICIPANT	\N	PRESENT	0
76125	75210	11097X	PARTICIPANT	\N	PRESENT	0
76126	75210	99004R	PARTICIPANT	\N	PRESENT	0
76127	75210	14159V	PARTICIPANT	\N	PRESENT	0
76128	75210	11093T	PARTICIPANT	\N	PRESENT	0
76129	75210	11081P	PARTICIPANT	\N	PRESENT	0
76130	75210	14263U	PARTICIPANT	\N	PRESENT	0
76131	75210	04050C	PARTICIPANT	\N	PRESENT	0
76132	75210	08041T	PARTICIPANT	\N	PRESENT	0
76133	75210	95049N	PARTICIPANT	\N	PRESENT	0
76134	75210	11049P	PARTICIPANT	\N	PRESENT	0
76135	75210	08047A	PARTICIPANT	\N	PRESENT	0
76136	75210	07029T	PARTICIPANT	\N	PRESENT	0
76137	75210	04085P	PARTICIPANT	\N	PRESENT	0
76138	75210	14209N	PARTICIPANT	\N	PRESENT	0
76139	75210	01046T	PARTICIPANT	\N	PRESENT	0
76140	75210	98029W	PARTICIPANT	\N	PRESENT	0
76141	75210	01019Q	PARTICIPANT	\N	PRESENT	0
76142	75210	08028W	PARTICIPANT	\N	PRESENT	0
76143	75210	04088S	PARTICIPANT	\N	PRESENT	0
76144	75210	08051V	PARTICIPANT	\N	PRESENT	0
76145	75210	14079W	PARTICIPANT	\N	PRESENT	0
76146	75210	11103C	PARTICIPANT	\N	PRESENT	0
76147	75210	01048V	PARTICIPANT	\N	PRESENT	0
76148	75210	14201E	PARTICIPANT	\N	PRESENT	0
76149	75210	95062K	PARTICIPANT	\N	PRESENT	0
76150	75210	02002K	PARTICIPANT	\N	PRESENT	0
76151	75210	11053K	PARTICIPANT	\N	PRESENT	0
76152	75210	11090Q	PARTICIPANT	\N	PRESENT	0
76153	75210	11111C	PARTICIPANT	\N	PRESENT	0
76154	75210	01061S	PARTICIPANT	\N	PRESENT	0
76157	75210	14061L	PARTICIPANT	\N	PRESENT	0
76158	75210	07034Q	PARTICIPANT	\N	PRESENT	0
76159	75210	08052W	PARTICIPANT	\N	PRESENT	0
76160	75210	14169X	PARTICIPANT	\N	PRESENT	0
76161	75210	14167V	PARTICIPANT	\N	PRESENT	0
76162	75210	11033F	PARTICIPANT	\N	PRESENT	0
76163	75210	04086Q	PARTICIPANT	\N	PRESENT	0
76164	75210	01044R	PARTICIPANT	\N	PRESENT	0
76165	75210	96004D	PARTICIPANT	\N	PRESENT	0
76166	75210	14211G	PARTICIPANT	\N	PRESENT	0
76167	75210	98046X	PARTICIPANT	\N	PRESENT	0
76169	75210	14051J	PARTICIPANT	\N	PRESENT	0
76170	75210	04034C	PARTICIPANT	\N	PRESENT	0
76171	75210	01027Q	PARTICIPANT	\N	PRESENT	0
76172	75210	08044W	PARTICIPANT	\N	PRESENT	0
76173	75210	04042C	PARTICIPANT	\N	PRESENT	0
76174	75210	14197C	PARTICIPANT	\N	PRESENT	0
76175	75210	04033B	PARTICIPANT	\N	PRESENT	0
76176	75210	12041X	PARTICIPANT	\N	PRESENT	0
76177	75210	14111D	PARTICIPANT	\N	PRESENT	0
76178	75210	14223L	PARTICIPANT	\N	PRESENT	0
76179	75210	11034G	PARTICIPANT	\N	PRESENT	0
76180	75210	07032N	PARTICIPANT	\N	PRESENT	0
76181	75210	11056N	PARTICIPANT	\N	PRESENT	0
76183	75210	08015R	PARTICIPANT	\N	PRESENT	0
76185	75210	11040E	PARTICIPANT	\N	PRESENT	0
76186	75210	95015C	PARTICIPANT	\N	PRESENT	0
76187	75210	14175V	PARTICIPANT	\N	PRESENT	0
76188	75210	14259Y	PARTICIPANT	\N	PRESENT	0
76189	75210	04081K	PARTICIPANT	\N	PRESENT	0
76190	75210	95041E	PARTICIPANT	\N	PRESENT	0
76191	75210	04048J	PARTICIPANT	\N	PRESENT	0
76192	75210	08034U	PARTICIPANT	\N	PRESENT	0
76193	75210	97011G	PARTICIPANT	\N	PRESENT	0
76194	75210	08065C	PARTICIPANT	\N	PRESENT	0
76195	75210	14017T	PARTICIPANT	\N	PRESENT	0
76196	75210	11080N	PARTICIPANT	\N	PRESENT	0
76197	75210	11098Y	PARTICIPANT	\N	PRESENT	0
76198	75210	92031P	PARTICIPANT	\N	PRESENT	0
76199	75210	11059R	PARTICIPANT	\N	PRESENT	0
76200	75210	14028W	PARTICIPANT	\N	PRESENT	0
76201	75210	11088W	PARTICIPANT	\N	PRESENT	0
76202	75210	08014Q	PARTICIPANT	\N	PRESENT	0
76203	75210	95030B	PARTICIPANT	\N	PRESENT	0
76204	75210	14187A	PARTICIPANT	\N	PRESENT	0
76205	75210	05008E	PARTICIPANT	\N	PRESENT	0
76206	75210	04092N	PARTICIPANT	\N	PRESENT	0
76207	75210	08011M	PARTICIPANT	\N	PRESENT	0
76208	75210	90003B	PARTICIPANT	\N	PRESENT	0
76209	75210	07026Q	PARTICIPANT	\N	PRESENT	0
76210	75210	87003B	PARTICIPANT	\N	PRESENT	0
76211	75210	11043H	PARTICIPANT	\N	PRESENT	0
76212	75210	08010L	PARTICIPANT	\N	PRESENT	0
76213	75210	11030C	PARTICIPANT	\N	PRESENT	0
76214	75210	14013P	PARTICIPANT	\N	PRESENT	0
76215	75210	01059Y	PARTICIPANT	\N	PRESENT	0
76216	75210	01041N	PARTICIPANT	\N	PRESENT	0
76218	75210	14123H	PARTICIPANT	\N	PRESENT	0
76219	75210	92045V	PARTICIPANT	\N	PRESENT	0
76220	75210	14151M	PARTICIPANT	\N	PRESENT	0
76221	75210	08025T	PARTICIPANT	\N	PRESENT	0
76222	75210	01058X	PARTICIPANT	\N	PRESENT	0
76223	75210	01016M	PARTICIPANT	\N	PRESENT	0
76224	75210	11039M	PARTICIPANT	\N	PRESENT	0
76225	75210	04056J	PARTICIPANT	\N	PRESENT	0
76226	75210	08016S	PARTICIPANT	\N	PRESENT	0
76227	75210	14215L	PARTICIPANT	\N	PRESENT	0
76228	75210	07024N	PARTICIPANT	\N	PRESENT	0
76229	75210	92015P	PARTICIPANT	\N	PRESENT	0
76230	75210	14331P	PARTICIPANT	\N	PRESENT	0
76231	75210	08055A	PARTICIPANT	\N	PRESENT	0
76233	75210	11100Y	PARTICIPANT	\N	PRESENT	0
76234	75210	14107H	PARTICIPANT	\N	PRESENT	0
76235	75210	04066L	PARTICIPANT	\N	PRESENT	0
76236	75210	92040Q	PARTICIPANT	\N	PRESENT	0
76237	75210	01011G	PARTICIPANT	\N	PRESENT	0
76238	75210	14119M	PARTICIPANT	\N	PRESENT	0
76239	75210	11084S	PARTICIPANT	\N	PRESENT	0
76240	75210	14135M	PARTICIPANT	\N	PRESENT	0
76241	75210	95035G	PARTICIPANT	\N	PRESENT	0
76242	75210	11089X	PARTICIPANT	\N	PRESENT	0
76243	75210	14037X	PARTICIPANT	\N	PRESENT	0
76244	75210	04047H	PARTICIPANT	\N	PRESENT	0
63060	62862	04048J	PARTICIPANT	\N	PRESENT	0
63061	62862	14191V	PARTICIPANT	\N	PRESENT	0
63062	62862	07029T	PARTICIPANT	\N	PRESENT	0
63063	62862	08014Q	PARTICIPANT	\N	PRESENT	0
63064	62862	14257W	PARTICIPANT	\N	PRESENT	0
63065	62862	14121F	PARTICIPANT	\N	PRESENT	0
63066	62862	87003B	PARTICIPANT	\N	PRESENT	0
63067	62862	14105F	PARTICIPANT	\N	PRESENT	0
63068	62862	01044R	PARTICIPANT	\N	PRESENT	0
63069	62862	95015C	PARTICIPANT	\N	PRESENT	0
63070	62862	04059M	PARTICIPANT	\N	PRESENT	0
63071	62862	11083R	PARTICIPANT	\N	PRESENT	0
63072	62862	14265W	PARTICIPANT	\N	PRESENT	0
63073	62862	08039A	PARTICIPANT	\N	PRESENT	0
63074	62862	04057K	PARTICIPANT	\N	PRESENT	0
63075	62862	04070G	PARTICIPANT	\N	PRESENT	0
63076	62862	11029K	PARTICIPANT	\N	PRESENT	0
63077	62862	08031R	PARTICIPANT	\N	PRESENT	0
63078	62862	14249W	PARTICIPANT	\N	PRESENT	0
63079	62862	07026Q	PARTICIPANT	\N	PRESENT	0
63080	62864	01007L	PARTICIPANT	\N	PRESENT	0
63081	62864	04054G	PARTICIPANT	\N	PRESENT	0
63082	62864	14235Q	PARTICIPANT	\N	PRESENT	0
63083	62864	80013X	PARTICIPANT	\N	PRESENT	0
63084	62864	11042G	PARTICIPANT	\N	PRESENT	0
63085	62864	11074Q	PARTICIPANT	\N	PRESENT	0
63086	62864	01025N	PARTICIPANT	\N	PRESENT	0
63087	62864	01024M	PARTICIPANT	\N	PRESENT	0
63088	62864	92031P	PARTICIPANT	\N	PRESENT	0
63089	62864	14159V	PARTICIPANT	\N	PRESENT	0
63090	62864	97011G	PARTICIPANT	\N	PRESENT	0
63091	62864	04088S	PARTICIPANT	\N	PRESENT	0
63092	62864	14259Y	PARTICIPANT	\N	PRESENT	0
63093	62864	04041B	PARTICIPANT	\N	PRESENT	0
63125	62864	14241N	PARTICIPANT	\N	PRESENT	0
63095	62864	95062K	PARTICIPANT	\N	PRESENT	0
63133	62864	14267Y	PARTICIPANT	\N	PRESENT	0
63097	62864	95035G	PARTICIPANT	\N	PRESENT	0
63098	62864	14097Y	PARTICIPANT	\N	PRESENT	0
63099	62864	14073Q	PARTICIPANT	\N	PRESENT	0
63100	62864	11091R	PARTICIPANT	\N	PRESENT	0
63101	62864	11012A	PARTICIPANT	\N	PRESENT	0
63102	62864	14061L	PARTICIPANT	\N	PRESENT	0
63128	62864	14037X	PARTICIPANT	\N	PRESENT	0
63126	62864	08061X	PARTICIPANT	\N	PRESENT	0
63127	62864	14229S	PARTICIPANT	\N	PRESENT	0
63106	62864	11027H	PARTICIPANT	\N	PRESENT	0
63107	62864	08043V	PARTICIPANT	\N	PRESENT	0
63108	62864	14191V	PARTICIPANT	\N	PRESENT	0
63109	62864	07029T	PARTICIPANT	\N	PRESENT	0
63110	62864	14257W	PARTICIPANT	\N	PRESENT	0
63111	62864	14121F	PARTICIPANT	\N	PRESENT	0
63129	62864	14105F	PARTICIPANT	\N	PRESENT	0
63113	62864	01044R	PARTICIPANT	\N	PRESENT	0
63130	62864	01028R	PARTICIPANT	\N	PRESENT	0
63115	62864	04059M	PARTICIPANT	\N	PRESENT	0
63116	62864	11083R	PARTICIPANT	\N	PRESENT	0
63117	62864	08039A	PARTICIPANT	\N	PRESENT	0
63118	62864	04057K	PARTICIPANT	\N	PRESENT	0
63119	62864	04070G	PARTICIPANT	\N	PRESENT	0
63120	62864	11029K	PARTICIPANT	\N	PRESENT	0
63121	62864	08031R	PARTICIPANT	\N	PRESENT	0
63122	62864	14249W	PARTICIPANT	\N	PRESENT	0
63123	62864	07026Q	PARTICIPANT	\N	PRESENT	0
63124	62864	01027Q	PARTICIPANT	\N	PRESENT	0
63131	62864	11104D	PARTICIPANT	\N	PRESENT	0
63132	62864	11039M	PARTICIPANT	\N	PRESENT	0
63134	62864	98042T	PARTICIPANT	\N	PRESENT	0
63135	62864	07004J	PARTICIPANT	\N	PRESENT	0
63136	62864	14231L	PARTICIPANT	\N	PRESENT	0
63137	62864	14219Q	PARTICIPANT	\N	PRESENT	0
63138	62864	08053X	PARTICIPANT	\N	PRESENT	0
63139	62864	92045V	PARTICIPANT	\N	PRESENT	0
63140	62864	14237S	PARTICIPANT	\N	PRESENT	0
63141	62864	07024N	PARTICIPANT	\N	PRESENT	0
63142	62864	14331P	PARTICIPANT	\N	PRESENT	0
63143	62864	14111D	PARTICIPANT	\N	PRESENT	0
63144	62864	14053L	PARTICIPANT	\N	PRESENT	0
63145	62864	11043H	PARTICIPANT	\N	PRESENT	0
63146	62864	95031C	PARTICIPANT	\N	PRESENT	0
63147	62864	14033T	PARTICIPANT	\N	PRESENT	0
63148	62864	14179A	PARTICIPANT	\N	PRESENT	0
63215	62865	01027Q	PARTICIPANT	\N	PRESENT	0
63216	62865	95031C	PARTICIPANT	\N	PRESENT	0
63217	62865	99004R	PARTICIPANT	\N	PRESENT	0
63218	62865	01013J	PARTICIPANT	\N	PRESENT	0
63219	62865	07026Q	PARTICIPANT	\N	PRESENT	0
63220	62865	95059Q	PARTICIPANT	\N	PRESENT	0
63221	62865	95015C	PARTICIPANT	\N	PRESENT	0
63222	62865	04041B	PARTICIPANT	\N	PRESENT	0
63223	62865	04085P	PARTICIPANT	\N	PRESENT	0
63224	62865	01059Y	PARTICIPANT	\N	PRESENT	0
63225	62865	14105F	PARTICIPANT	\N	PRESENT	0
63226	62865	12041X	PARTICIPANT	\N	PRESENT	0
63227	62865	11040E	PARTICIPANT	\N	PRESENT	0
63228	62865	01048V	PARTICIPANT	\N	PRESENT	0
63229	62865	14235Q	PARTICIPANT	\N	PRESENT	0
63230	62865	11034G	PARTICIPANT	\N	PRESENT	0
63231	62865	14013P	PARTICIPANT	\N	PRESENT	0
63232	62865	11043H	PARTICIPANT	\N	PRESENT	0
63233	62865	01056V	PARTICIPANT	\N	PRESENT	0
63234	62865	11076S	PARTICIPANT	\N	PRESENT	0
63235	62865	01044R	PARTICIPANT	\N	PRESENT	0
63236	62865	11029K	PARTICIPANT	\N	PRESENT	0
63237	62865	11065P	PARTICIPANT	\N	PRESENT	0
63238	62865	01058X	PARTICIPANT	\N	PRESENT	0
63239	62865	01060R	PARTICIPANT	\N	PRESENT	0
63240	62865	04035D	PARTICIPANT	\N	PRESENT	0
63241	62865	14247U	PARTICIPANT	\N	PRESENT	0
63242	62865	92044U	PARTICIPANT	\N	PRESENT	0
63243	62865	14169X	PARTICIPANT	\N	PRESENT	0
63244	62865	14071N	PARTICIPANT	\N	PRESENT	0
63245	62865	08051V	PARTICIPANT	\N	PRESENT	0
63246	62865	01003G	PARTICIPANT	\N	PRESENT	0
63247	62865	88008L	PARTICIPANT	\N	PRESENT	0
63248	62865	04078Q	PARTICIPANT	\N	PRESENT	0
63249	62865	05004A	PARTICIPANT	\N	PRESENT	0
63250	62865	01046T	PARTICIPANT	\N	PRESENT	0
63251	62865	11012A	PARTICIPANT	\N	PRESENT	0
63252	62865	14018U	PARTICIPANT	\N	PRESENT	0
63253	62865	08031R	PARTICIPANT	\N	PRESENT	0
63254	62865	11081P	PARTICIPANT	\N	PRESENT	0
63255	62865	14259Y	PARTICIPANT	\N	PRESENT	0
63256	62865	14201E	PARTICIPANT	\N	PRESENT	0
63257	62865	08021P	PARTICIPANT	\N	PRESENT	0
63258	62865	87003B	PARTICIPANT	\N	PRESENT	0
63259	62865	98022P	PARTICIPANT	\N	PRESENT	0
63260	62865	14241N	PARTICIPANT	\N	PRESENT	0
63261	62865	11101A	PARTICIPANT	\N	PRESENT	0
63262	62865	01043Q	PARTICIPANT	\N	PRESENT	0
63263	62865	04042C	PARTICIPANT	\N	PRESENT	0
63264	62865	95030B	PARTICIPANT	\N	PRESENT	0
63265	62865	14327T	PARTICIPANT	\N	PRESENT	0
63266	62865	07004J	PARTICIPANT	\N	PRESENT	0
63267	62865	14205J	PARTICIPANT	\N	PRESENT	0
63268	62865	14087W	PARTICIPANT	\N	PRESENT	0
63269	62865	08044W	PARTICIPANT	\N	PRESENT	0
63270	62865	92031P	PARTICIPANT	\N	PRESENT	0
63271	62865	98042T	PARTICIPANT	\N	PRESENT	0
63272	62865	14231L	PARTICIPANT	\N	PRESENT	0
63273	62865	14083S	PARTICIPANT	\N	PRESENT	0
63274	62865	11082Q	PARTICIPANT	\N	PRESENT	0
63213	62865	86034E	PARTICIPANT	\N	PRESENT	0
63214	62865	11100Y	PARTICIPANT	\N	PRESENT	0
63275	62865	14073Q	PARTICIPANT	\N	PRESENT	0
63276	62865	04089T	PARTICIPANT	\N	PRESENT	0
63277	62865	95035G	PARTICIPANT	\N	PRESENT	0
63278	62865	01024M	PARTICIPANT	\N	PRESENT	0
63279	62865	04036E	PARTICIPANT	\N	PRESENT	0
63280	62865	14255U	PARTICIPANT	\N	PRESENT	0
63281	62865	08011M	PARTICIPANT	\N	PRESENT	0
63282	62865	11096W	PARTICIPANT	\N	PRESENT	0
63283	62865	14031R	PARTICIPANT	\N	PRESENT	0
63284	62865	08056B	PARTICIPANT	\N	PRESENT	0
63285	62865	09001P	PARTICIPANT	\N	PRESENT	0
63286	62865	04049K	PARTICIPANT	\N	PRESENT	0
63287	62865	04040A	PARTICIPANT	\N	PRESENT	0
63288	62865	04033B	PARTICIPANT	\N	PRESENT	0
63289	62865	08009T	PARTICIPANT	\N	PRESENT	0
63290	62865	14079W	PARTICIPANT	\N	PRESENT	0
63291	62865	01034P	PARTICIPANT	\N	PRESENT	0
63292	62865	04048J	PARTICIPANT	\N	PRESENT	0
63293	62865	04080J	PARTICIPANT	\N	PRESENT	0
63294	62865	11093T	PARTICIPANT	\N	PRESENT	0
63295	62865	14042U	PARTICIPANT	\N	PRESENT	0
63296	62865	14219Q	PARTICIPANT	\N	PRESENT	0
63297	62865	14267Y	PARTICIPANT	\N	PRESENT	0
63298	62865	14331P	PARTICIPANT	\N	PRESENT	0
76532	71343	11072N	PARTICIPANT	\N	EXCUSE	0
76533	75073	11072N	PARTICIPANT	\N	EXCUSE	0
76534	75076	11072N	PARTICIPANT	\N	EXCUSE	0
76580	66879	11035H	PARTICIPANT	\N	EXCUSE	0
76665	66879	07032N	PARTICIPANT	\N	EXCUSE	0
88204	87188	95049N	PARTICIPANT	\N	PRESENT	0
85522	85521	11076S	PARTICIPANT	\N	PRESENT	0
88208	87188	01025N	PARTICIPANT	\N	PRESENT	0
85524	85521	04040A	PARTICIPANT	\N	PRESENT	0
85525	85521	08058D	PARTICIPANT	\N	PRESENT	0
85526	85521	04042C	PARTICIPANT	\N	PRESENT	0
88209	87188	14207L	PARTICIPANT	\N	PRESENT	0
85528	85521	98029W	PARTICIPANT	\N	PRESENT	0
88210	87188	11085T	PARTICIPANT	\N	PRESENT	0
85530	85521	11027H	PARTICIPANT	\N	PRESENT	0
85531	85521	98018T	PARTICIPANT	\N	PRESENT	0
85532	85521	92018S	PARTICIPANT	\N	PRESENT	0
85533	85521	92020L	PARTICIPANT	\N	PRESENT	0
85534	85521	95030B	PARTICIPANT	\N	PRESENT	0
85535	85521	11096W	PARTICIPANT	\N	PRESENT	0
88211	87188	04050C	PARTICIPANT	\N	PRESENT	0
85537	85521	97011G	PARTICIPANT	\N	PRESENT	0
88212	87188	08069G	PARTICIPANT	\N	PRESENT	0
88213	87188	14251Q	PARTICIPANT	\N	PRESENT	0
85540	85521	07024N	PARTICIPANT	\N	PRESENT	0
88214	87188	11026G	PARTICIPANT	\N	PRESENT	0
85542	85521	14014Q	PARTICIPANT	\N	PRESENT	0
85543	85521	11015D	PARTICIPANT	\N	PRESENT	0
88215	87188	11084S	PARTICIPANT	\N	PRESENT	0
85545	85521	95035G	PARTICIPANT	\N	PRESENT	0
85546	85521	08056B	PARTICIPANT	\N	EXCUSE	0
88216	87096	98053W	PARTICIPANT	\N	PRESENT	0
85548	85521	98022P	PARTICIPANT	\N	PRESENT	0
88217	87096	05004A	PARTICIPANT	\N	PRESENT	0
85550	85521	95037J	PARTICIPANT	\N	PRESENT	0
85551	85521	04078Q	PARTICIPANT	\N	PRESENT	0
85552	85521	14097Y	PARTICIPANT	\N	PRESENT	0
88223	87096	07029T	PARTICIPANT	\N	PRESENT	0
85554	85521	04036E	PARTICIPANT	\N	PRESENT	0
88224	87096	14119M	PARTICIPANT	\N	PRESENT	0
85556	85521	04077P	PARTICIPANT	\N	PRESENT	0
88225	87096	11088W	PARTICIPANT	\N	PRESENT	0
85558	85521	92031P	PARTICIPANT	\N	PRESENT	0
85559	85521	11106F	PARTICIPANT	\N	PRESENT	0
85560	85521	14251Q	PARTICIPANT	\N	PRESENT	0
88226	87096	14195A	PARTICIPANT	\N	PRESENT	0
85562	85521	08053X	PARTICIPANT	\N	PRESENT	0
88227	87096	05012A	PARTICIPANT	\N	PRESENT	0
88228	87096	14247U	PARTICIPANT	\N	PRESENT	0
88229	87096	01060R	PARTICIPANT	\N	PRESENT	0
88230	87096	14193X	PARTICIPANT	\N	PRESENT	0
85567	85521	14028W	PARTICIPANT	\N	PRESENT	0
85568	85521	14193X	PARTICIPANT	\N	PRESENT	0
85569	85521	98021N	PARTICIPANT	\N	PRESENT	0
85570	85521	04080J	PARTICIPANT	\N	PRESENT	0
85571	85521	95059Q	PRESIDENT	0	PRESENT	0
88231	87096	01013J	PARTICIPANT	\N	PRESENT	0
85573	85521	01014K	PARTICIPANT	\N	PRESENT	0
85574	85521	11054L	PARTICIPANT	\N	PRESENT	0
85575	85521	01056V	PARTICIPANT	\N	PRESENT	0
88236	87096	14167V	PARTICIPANT	\N	PRESENT	0
85577	85521	08049C	PARTICIPANT	\N	EXCUSE	0
88237	87096	01031L	PARTICIPANT	\N	PRESENT	0
88238	87096	04045F	PARTICIPANT	\N	PRESENT	0
88239	87096	11068S	PARTICIPANT	\N	PRESENT	0
88240	87096	11025F	PARTICIPANT	\N	PRESENT	0
88241	87096	04067M	PARTICIPANT	\N	PRESENT	0
88243	87096	01003G	PARTICIPANT	\N	PRESENT	0
88247	87096	11070L	PARTICIPANT	\N	PRESENT	0
88248	87096	14089Y	PARTICIPANT	\N	PRESENT	0
88249	87096	11012A	PARTICIPANT	\N	PRESENT	0
88250	87096	11056N	PARTICIPANT	\N	PRESENT	0
88251	87096	11083R	PARTICIPANT	\N	PRESENT	0
88252	87096	08062Y	PARTICIPANT	\N	PRESENT	0
88253	87096	11049P	PARTICIPANT	\N	PRESENT	0
88254	87096	97011G	PARTICIPANT	\N	PRESENT	0
88255	87096	14223L	PARTICIPANT	\N	PRESENT	0
88259	87096	14235Q	PARTICIPANT	\N	PRESENT	0
88273	87096	04050C	PARTICIPANT	\N	PRESENT	0
88274	87096	14231L	PARTICIPANT	\N	PRESENT	0
88275	87096	11082Q	PARTICIPANT	\N	PRESENT	0
88276	87096	08031R	PARTICIPANT	\N	PRESENT	0
88277	87096	11057P	PARTICIPANT	\N	PRESENT	0
88278	87096	14225N	PARTICIPANT	\N	PRESENT	0
88279	87096	14069U	PARTICIPANT	\N	PRESENT	0
88280	87096	11093T	PARTICIPANT	\N	PRESENT	0
88281	87096	14267Y	PARTICIPANT	\N	PRESENT	0
88282	87096	14014Q	PARTICIPANT	\N	PRESENT	0
88283	87096	14327T	PARTICIPANT	\N	PRESENT	0
88284	87096	98024R	PARTICIPANT	\N	PRESENT	0
88285	87096	95030B	PARTICIPANT	\N	PRESENT	0
88286	87096	04092N	PARTICIPANT	\N	PRESENT	0
88287	87096	14061L	PARTICIPANT	\N	PRESENT	0
88288	87096	11061K	PARTICIPANT	\N	PRESENT	0
88289	87096	04034C	PARTICIPANT	\N	PRESENT	0
88291	87096	14042U	PARTICIPANT	\N	PRESENT	0
88299	87096	11109J	PARTICIPANT	\N	PRESENT	0
88300	87096	08053X	PARTICIPANT	\N	PRESENT	0
88301	87096	11048N	PARTICIPANT	\N	PRESENT	0
88302	87096	01057W	PARTICIPANT	\N	PRESENT	0
88303	87096	14159V	PARTICIPANT	\N	PRESENT	0
88304	87096	11081P	PARTICIPANT	\N	PRESENT	0
88308	87096	14199E	PARTICIPANT	\N	PRESENT	0
88309	87096	14026U	PARTICIPANT	\N	PRESENT	0
88310	87096	11097X	PARTICIPANT	\N	PRESENT	0
88311	87096	11031D	PARTICIPANT	\N	PRESENT	0
88312	87096	01046T	PARTICIPANT	\N	PRESENT	0
88313	87096	08052W	PARTICIPANT	\N	PRESENT	0
88314	87096	01016M	PARTICIPANT	\N	PRESENT	0
88315	87096	14018U	PARTICIPANT	\N	PRESENT	0
88316	87096	14239U	PARTICIPANT	\N	PRESENT	0
88317	87096	08019V	PARTICIPANT	\N	PRESENT	0
88318	87096	14053L	PARTICIPANT	\N	PRESENT	0
88319	87096	14071N	PARTICIPANT	\N	PRESENT	0
88320	87096	14265W	PARTICIPANT	\N	PRESENT	0
88321	87097	98053W	PARTICIPANT	\N	PRESENT	0
88322	87097	11031D	PARTICIPANT	\N	PRESENT	0
88323	87097	08052W	PARTICIPANT	\N	PRESENT	0
88324	87097	00003C	PARTICIPANT	\N	PRESENT	0
88325	87097	04045F	PARTICIPANT	\N	PRESENT	0
88326	87097	12042Y	PARTICIPANT	\N	PRESENT	0
88327	87097	11068S	PARTICIPANT	\N	PRESENT	0
88328	87097	01016M	PARTICIPANT	\N	PRESENT	0
88329	87097	14159V	PARTICIPANT	\N	PRESENT	0
88330	87097	04067M	PARTICIPANT	\N	PRESENT	0
88331	87097	11081P	PARTICIPANT	\N	PRESENT	0
88332	87097	01046T	PARTICIPANT	\N	PRESENT	0
88333	87097	11012A	PARTICIPANT	\N	PRESENT	0
88334	87097	14239U	PARTICIPANT	\N	PRESENT	0
88335	87097	14018U	PARTICIPANT	\N	PRESENT	0
88336	87097	14327T	PARTICIPANT	\N	PRESENT	0
88337	87097	14267Y	PARTICIPANT	\N	PRESENT	0
88338	87097	14231L	PARTICIPANT	\N	PRESENT	0
88339	87097	92031P	PARTICIPANT	\N	PRESENT	0
88340	87097	14331P	PARTICIPANT	\N	PRESENT	0
88341	87097	14053L	PARTICIPANT	\N	PRESENT	0
88342	87097	14071N	PARTICIPANT	\N	PRESENT	0
88343	87097	11097X	PARTICIPANT	\N	PRESENT	0
88344	87097	14265W	PARTICIPANT	\N	PRESENT	0
88345	87097	14249W	PARTICIPANT	\N	PRESENT	0
88346	87097	07029T	PARTICIPANT	\N	PRESENT	0
88347	87097	08019V	PARTICIPANT	\N	PRESENT	0
88348	87097	14195A	PARTICIPANT	\N	PRESENT	0
88349	87097	01034P	PARTICIPANT	\N	PRESENT	0
88350	87097	14213J	PARTICIPANT	\N	PRESENT	0
88351	87097	01008M	PARTICIPANT	\N	PRESENT	0
88352	87097	11036J	PARTICIPANT	\N	PRESENT	0
88353	87097	14187A	PARTICIPANT	\N	PRESENT	0
88354	87097	95015C	PARTICIPANT	\N	PRESENT	0
88355	87097	14033T	PARTICIPANT	\N	PRESENT	0
88356	87097	14205J	PARTICIPANT	\N	PRESENT	0
88357	87097	11061K	PARTICIPANT	\N	PRESENT	0
88385	87097	11098Y	PARTICIPANT	\N	PRESENT	0
88386	87097	14235Q	PARTICIPANT	\N	PRESENT	0
88387	87097	14103D	PARTICIPANT	\N	PRESENT	0
88388	87097	04092N	PARTICIPANT	\N	PRESENT	0
88389	87097	14199E	PARTICIPANT	\N	PRESENT	0
88390	87097	14119M	PARTICIPANT	\N	PRESENT	0
88391	87097	14135M	PARTICIPANT	\N	PRESENT	0
64170	63998	98022P	PARTICIPANT	\N	PRESENT	0
64171	63998	11098Y	PARTICIPANT	\N	PRESENT	0
64172	63998	08022Q	PARTICIPANT	\N	PRESENT	0
64173	63998	07034Q	PARTICIPANT	\N	PRESENT	0
64174	63998	89029V	PARTICIPANT	\N	PRESENT	0
64175	63998	01057W	PARTICIPANT	\N	PRESENT	0
64176	63998	07032N	PARTICIPANT	\N	PRESENT	0
64177	63998	14251Q	PARTICIPANT	\N	PRESENT	0
64178	63998	04047H	PARTICIPANT	\N	PRESENT	0
64179	63998	14001X	PARTICIPANT	\N	PRESENT	0
64180	63998	11097X	PARTICIPANT	\N	PRESENT	0
64181	63998	08049C	PARTICIPANT	\N	PRESENT	0
64182	63998	80013X	PARTICIPANT	\N	PRESENT	0
64183	63998	83047W	PARTICIPANT	\N	PRESENT	0
64184	63998	80027E	PARTICIPANT	\N	PRESENT	0
64185	63998	04094Q	PARTICIPANT	\N	PRESENT	0
64186	63998	08060W	PARTICIPANT	\N	PRESENT	0
64187	63998	11082Q	PARTICIPANT	\N	PRESENT	0
64188	63998	11106F	PARTICIPANT	\N	PRESENT	0
64338	63999	01013J	PARTICIPANT	\N	PRESENT	0
64339	63999	14013P	PARTICIPANT	\N	PRESENT	0
64340	63999	92018S	PARTICIPANT	\N	PRESENT	0
64341	63999	01015L	PARTICIPANT	\N	PRESENT	0
64342	63999	07026Q	PARTICIPANT	\N	PRESENT	0
64343	63999	11098Y	PARTICIPANT	\N	PRESENT	0
64344	63999	11083R	PARTICIPANT	\N	PRESENT	0
64345	63999	08017T	PARTICIPANT	\N	PRESENT	0
64346	63999	80027E	PARTICIPANT	\N	PRESENT	0
64347	63999	11054L	PARTICIPANT	\N	PRESENT	0
64348	63999	14121F	PARTICIPANT	\N	PRESENT	0
64349	63999	08014Q	PARTICIPANT	\N	PRESENT	0
64350	63999	83042R	PARTICIPANT	\N	PRESENT	0
64351	63999	13002U	PARTICIPANT	\N	PRESENT	0
64352	63999	14257W	PARTICIPANT	\N	PRESENT	0
64353	63999	14207L	PARTICIPANT	\N	PRESENT	0
64354	63999	11040E	PARTICIPANT	\N	PRESENT	0
64355	63999	04085P	PARTICIPANT	\N	PRESENT	0
64356	63999	04054G	PARTICIPANT	\N	PRESENT	0
64357	63999	11089X	PARTICIPANT	\N	PRESENT	0
64358	63999	08012N	PARTICIPANT	\N	PRESENT	0
64359	63999	11034G	PARTICIPANT	\N	PRESENT	0
64360	63999	14235Q	PARTICIPANT	\N	PRESENT	0
64361	63999	01059Y	PARTICIPANT	\N	PRESENT	0
64362	63999	11031D	PARTICIPANT	\N	PRESENT	0
64363	63999	01044R	PARTICIPANT	\N	PRESENT	0
64364	63999	11029K	PARTICIPANT	\N	PRESENT	0
64365	63999	11055M	PARTICIPANT	\N	PRESENT	0
64366	63999	11076S	PARTICIPANT	\N	PRESENT	0
64367	63999	11099A	PARTICIPANT	\N	PRESENT	0
64368	63999	11033F	PARTICIPANT	\N	PRESENT	0
64369	63999	01060R	PARTICIPANT	\N	PRESENT	0
64370	63999	14055N	PARTICIPANT	\N	PRESENT	0
64371	63999	14247U	PARTICIPANT	\N	PRESENT	0
64372	63999	11063M	PARTICIPANT	\N	PRESENT	0
64373	63999	11056N	PARTICIPANT	\N	PRESENT	0
64374	63999	14263U	PARTICIPANT	\N	PRESENT	0
64375	63999	08025T	PARTICIPANT	\N	PRESENT	0
64376	63999	08051V	PARTICIPANT	\N	PRESENT	0
64377	63999	01046T	PARTICIPANT	\N	PRESENT	0
64378	63999	88008L	PARTICIPANT	\N	PRESENT	0
64379	63999	04078Q	PARTICIPANT	\N	PRESENT	0
64380	63999	11096W	PARTICIPANT	\N	PRESENT	0
64381	63999	08049C	PARTICIPANT	\N	PRESENT	0
64382	63999	14201E	PARTICIPANT	\N	PRESENT	0
64383	63999	14261S	PARTICIPANT	\N	PRESENT	0
64384	63999	08021P	PARTICIPANT	\N	PRESENT	0
64385	63999	98022P	PARTICIPANT	\N	PRESENT	0
64386	63999	14241N	PARTICIPANT	\N	PRESENT	0
64387	63999	04038G	PARTICIPANT	\N	PRESENT	0
64388	63999	08031R	PARTICIPANT	\N	PRESENT	0
64389	63999	01003G	PARTICIPANT	\N	PRESENT	0
64390	63999	14151M	PARTICIPANT	\N	PRESENT	0
64391	63999	08016S	PARTICIPANT	\N	PRESENT	0
64392	63999	98035U	PARTICIPANT	\N	PRESENT	0
64393	63999	01016M	PARTICIPANT	\N	PRESENT	0
64394	63999	04056J	PARTICIPANT	\N	PRESENT	0
64395	63999	11039M	PARTICIPANT	\N	PRESENT	0
64396	63999	04059M	PARTICIPANT	\N	PRESENT	0
64398	63999	08052W	PARTICIPANT	\N	PRESENT	0
64399	63999	95063L	PARTICIPANT	\N	PRESENT	0
64401	63999	14051J	PARTICIPANT	\N	PRESENT	0
64403	63999	12041X	PARTICIPANT	\N	PRESENT	0
64406	63999	08055A	PARTICIPANT	\N	PRESENT	0
64408	63999	14107H	PARTICIPANT	\N	PRESENT	0
64410	63999	04066L	PARTICIPANT	\N	PRESENT	0
64411	63999	01011G	PARTICIPANT	\N	PRESENT	0
64412	63999	11057P	PARTICIPANT	\N	PRESENT	0
64413	63999	11084S	PARTICIPANT	\N	PRESENT	0
64414	63999	00003C	PARTICIPANT	\N	PRESENT	0
64415	63999	92020L	PARTICIPANT	\N	PRESENT	0
64416	63999	08060W	PARTICIPANT	\N	PRESENT	0
64417	63999	80013X	PARTICIPANT	\N	PRESENT	0
64418	63999	14028W	PARTICIPANT	\N	PRESENT	0
64419	63999	01022K	PARTICIPANT	\N	PRESENT	0
64420	63999	14197C	PARTICIPANT	\N	PRESENT	0
64421	63999	14065Q	PARTICIPANT	\N	PRESENT	0
64422	63999	11015D	PARTICIPANT	\N	PRESENT	0
64423	63999	08043V	PARTICIPANT	\N	PRESENT	0
64425	63999	11105E	PARTICIPANT	\N	PRESENT	0
64428	63999	04095R	PARTICIPANT	\N	PRESENT	0
64435	63999	14167V	PARTICIPANT	\N	PRESENT	0
64436	63999	98029W	PARTICIPANT	\N	PRESENT	0
64438	63999	11046L	PARTICIPANT	\N	PRESENT	0
64440	63999	11036J	PARTICIPANT	\N	PRESENT	0
64443	63999	11112D	PARTICIPANT	\N	PRESENT	0
64448	63999	95037J	PARTICIPANT	\N	PRESENT	0
64450	63999	14229S	PARTICIPANT	\N	PRESENT	0
64451	63999	08058D	PARTICIPANT	\N	PRESENT	0
64452	63999	14271U	PARTICIPANT	\N	PRESENT	0
64453	63999	14109K	PARTICIPANT	\N	PRESENT	0
64454	63999	01008M	PARTICIPANT	\N	PRESENT	0
64455	63999	14069U	PARTICIPANT	\N	PRESENT	0
64456	63999	14105F	PARTICIPANT	\N	PRESENT	0
64457	63999	14331P	PARTICIPANT	\N	PRESENT	0
64458	63999	95059Q	PARTICIPANT	\N	PRESENT	0
64459	63999	86044G	PARTICIPANT	\N	PRESENT	0
64460	63999	14071N	PARTICIPANT	\N	PRESENT	0
64461	63999	14031R	PARTICIPANT	\N	PRESENT	0
64462	63999	92040Q	PARTICIPANT	\N	PRESENT	0
64463	63999	89029V	PARTICIPANT	\N	PRESENT	0
64464	63999	14087W	PARTICIPANT	\N	PRESENT	0
64466	63999	11114F	PARTICIPANT	\N	PRESENT	0
64467	63999	14038Y	PARTICIPANT	\N	PRESENT	0
64468	63999	08035V	PARTICIPANT	\N	PRESENT	0
64469	63999	11080N	PARTICIPANT	\N	PRESENT	0
64470	63999	14063N	PARTICIPANT	\N	PRESENT	0
64471	63999	11074Q	PARTICIPANT	\N	PRESENT	0
64472	63999	98023Q	PARTICIPANT	\N	PRESENT	0
64473	63999	14039A	PARTICIPANT	\N	PRESENT	0
64474	63999	04094Q	PARTICIPANT	\N	PRESENT	0
64475	63999	08041T	PARTICIPANT	\N	PRESENT	0
64476	63999	11109J	PARTICIPANT	\N	PRESENT	0
64477	63999	11042G	PARTICIPANT	\N	PRESENT	0
64478	63999	08073C	PARTICIPANT	\N	PRESENT	0
64479	63999	08042U	PARTICIPANT	\N	PRESENT	0
64480	63999	14169X	PARTICIPANT	\N	PRESENT	0
64481	63999	14159V	PARTICIPANT	\N	PRESENT	0
64482	63999	14269B	PARTICIPANT	\N	PRESENT	0
64483	63999	12042Y	PARTICIPANT	\N	PRESENT	0
64484	63999	11066Q	PARTICIPANT	\N	PRESENT	0
64485	63999	08053X	PARTICIPANT	\N	PRESENT	0
64486	63999	08018U	PARTICIPANT	\N	PRESENT	0
64487	63999	11032E	PARTICIPANT	\N	PRESENT	0
64488	63999	11077T	PARTICIPANT	\N	PRESENT	0
64489	63999	14209N	PARTICIPANT	\N	PRESENT	0
64490	63999	11095V	PARTICIPANT	\N	PRESENT	0
64491	63999	14001X	PARTICIPANT	\N	PRESENT	0
64492	63999	14281W	PARTICIPANT	\N	PRESENT	0
64493	63999	04061F	PARTICIPANT	\N	PRESENT	0
64494	63999	99004R	PARTICIPANT	\N	PRESENT	0
64495	63999	11061K	PARTICIPANT	\N	PRESENT	0
64496	63999	14227Q	PARTICIPANT	\N	PRESENT	0
64497	63999	04079R	PARTICIPANT	\N	PRESENT	0
64498	63999	83047W	PARTICIPANT	\N	PRESENT	0
64499	63999	95062K	PARTICIPANT	\N	PRESENT	0
64500	63999	14225N	PARTICIPANT	\N	PRESENT	0
64501	63999	08011M	PARTICIPANT	\N	PRESENT	0
64502	63999	95049N	PARTICIPANT	\N	PRESENT	0
64503	63999	04036E	PARTICIPANT	\N	PRESENT	0
64504	63999	04077P	PARTICIPANT	\N	PRESENT	0
64505	63999	08061X	PARTICIPANT	\N	PRESENT	0
64506	63999	96004D	PARTICIPANT	\N	PRESENT	0
64507	63999	04053F	PARTICIPANT	\N	PRESENT	0
64508	63999	01028R	PARTICIPANT	\N	PRESENT	0
64509	63999	14211G	PARTICIPANT	\N	PRESENT	0
64510	63999	11110B	PARTICIPANT	\N	PRESENT	0
64511	63999	11104D	PARTICIPANT	\N	PRESENT	0
76245	75210	10015M	PARTICIPANT	\N	PRESENT	0
76246	75210	08012N	PARTICIPANT	\N	PRESENT	0
76247	75210	80027E	PARTICIPANT	\N	PRESENT	0
76248	75210	04079R	PARTICIPANT	\N	PRESENT	0
76249	75210	14053L	PARTICIPANT	\N	PRESENT	0
76250	75210	95037J	PARTICIPANT	\N	PRESENT	0
76251	75210	77002U	PARTICIPANT	\N	PRESENT	0
76252	75210	08058D	PARTICIPANT	\N	PRESENT	0
76253	75210	83047W	PARTICIPANT	\N	PRESENT	0
76254	75210	14227Q	PARTICIPANT	\N	PRESENT	0
76255	75210	14253S	PARTICIPANT	\N	PRESENT	0
76256	75210	14229S	PARTICIPANT	\N	PRESENT	0
76257	75210	14281W	PARTICIPANT	\N	PRESENT	0
76258	75210	11046L	PARTICIPANT	\N	PRESENT	0
76259	75210	11026G	PARTICIPANT	\N	PRESENT	0
76260	75210	14121F	PARTICIPANT	\N	PRESENT	0
76261	75210	08022Q	PARTICIPANT	\N	PRESENT	0
76262	75210	11074Q	PARTICIPANT	\N	PRESENT	0
76263	75210	11027H	PARTICIPANT	\N	PRESENT	0
76264	75210	14217N	PARTICIPANT	\N	PRESENT	0
76265	75210	14147R	PARTICIPANT	\N	PRESENT	0
76266	75210	14257W	PARTICIPANT	\N	PRESENT	0
76267	75210	11014C	PARTICIPANT	\N	PRESENT	0
76268	75210	99002P	PARTICIPANT	\N	PRESENT	0
76269	75210	14109K	PARTICIPANT	\N	PRESENT	0
76270	75210	14207L	PARTICIPANT	\N	PRESENT	0
76271	75210	14329V	PARTICIPANT	\N	PRESENT	0
76272	75210	14105F	PARTICIPANT	\N	PRESENT	0
76273	75210	11095V	PARTICIPANT	\N	PRESENT	0
76274	75210	14001X	PARTICIPANT	\N	PRESENT	0
76275	75210	05004A	PARTICIPANT	\N	PRESENT	0
76276	75210	05012A	PARTICIPANT	\N	PRESENT	0
76277	75210	04074L	PARTICIPANT	\N	PRESENT	0
76414	75210	14093U	PARTICIPANT	\N	PRESENT	0
76279	75210	14063N	PARTICIPANT	\N	PRESENT	0
76280	75210	01008M	PARTICIPANT	\N	PRESENT	0
76281	75210	83042R	PARTICIPANT	\N	PRESENT	0
76282	75210	14199E	PARTICIPANT	\N	PRESENT	0
76410	75210	11077T	PARTICIPANT	\N	PRESENT	0
76284	75210	08043V	PARTICIPANT	\N	PRESENT	0
76285	75210	11036J	PARTICIPANT	\N	PRESENT	0
76286	75210	11101A	PARTICIPANT	\N	PRESENT	0
76287	75210	80013X	PARTICIPANT	\N	PRESENT	0
76288	75210	14195A	PARTICIPANT	\N	PRESENT	0
76413	75210	11044J	PARTICIPANT	\N	PRESENT	0
76290	75210	04077P	PARTICIPANT	\N	PRESENT	0
76291	75210	08061X	PARTICIPANT	\N	PRESENT	0
76415	75210	95063L	PARTICIPANT	\N	PRESENT	0
76293	75210	86044G	PARTICIPANT	\N	PRESENT	0
76294	75210	04053F	PARTICIPANT	\N	PRESENT	0
76295	75210	08073C	PARTICIPANT	\N	PRESENT	0
76296	75210	11020A	PARTICIPANT	\N	PRESENT	0
76297	75210	01028R	PARTICIPANT	\N	PRESENT	0
76298	75210	11104D	PARTICIPANT	\N	PRESENT	0
76299	75210	04057K	PARTICIPANT	\N	PRESENT	0
76300	75210	11110B	PARTICIPANT	\N	PRESENT	0
76301	75210	01057W	PARTICIPANT	\N	PRESENT	0
76302	75210	11032E	PARTICIPANT	\N	PRESENT	0
76303	75210	08024S	PARTICIPANT	\N	PRESENT	0
76304	75210	11071M	PARTICIPANT	\N	PRESENT	0
76305	75210	04059M	PARTICIPANT	\N	PRESENT	0
76306	75210	11048N	PARTICIPANT	\N	PRESENT	0
76307	75210	11061K	PARTICIPANT	\N	PRESENT	0
76308	75210	04061F	PARTICIPANT	\N	PRESENT	0
76309	75210	11106F	PARTICIPANT	\N	PRESENT	0
76310	75210	04035D	PARTICIPANT	\N	PRESENT	0
76311	75210	11067R	PARTICIPANT	\N	PRESENT	0
76312	75210	04049K	PARTICIPANT	\N	PRESENT	0
76313	75210	14014Q	PARTICIPANT	\N	PRESENT	0
76412	75210	04038G	PARTICIPANT	\N	PRESENT	0
76315	75210	04095R	PARTICIPANT	\N	PRESENT	0
76316	75210	11109J	PARTICIPANT	\N	PRESENT	0
76317	75210	98005N	PARTICIPANT	\N	PRESENT	0
76318	75210	11012A	PARTICIPANT	\N	PRESENT	0
76319	75210	13002U	PARTICIPANT	\N	PRESENT	0
76320	75210	11114F	PARTICIPANT	\N	PRESENT	0
76321	75210	08035V	PARTICIPANT	\N	PRESENT	0
76322	75210	11072N	PARTICIPANT	\N	PRESENT	0
76323	75210	14173T	PARTICIPANT	\N	PRESENT	0
76324	75210	01014K	PARTICIPANT	\N	PRESENT	0
76325	75210	14269B	PARTICIPANT	\N	PRESENT	0
76326	75210	98021N	PARTICIPANT	\N	PRESENT	0
76327	75210	11076S	PARTICIPANT	\N	PRESENT	0
76328	75210	14069U	PARTICIPANT	\N	PRESENT	0
76329	75210	11083R	PARTICIPANT	\N	PRESENT	0
76330	75210	14237S	PARTICIPANT	\N	PRESENT	0
76331	75210	11096W	PARTICIPANT	\N	PRESENT	0
76332	75210	08049C	PARTICIPANT	\N	PRESENT	0
76333	75210	88008L	PARTICIPANT	\N	PRESENT	0
76408	75210	11068S	PARTICIPANT	\N	PRESENT	0
76409	75210	11042G	PARTICIPANT	\N	PRESENT	0
76336	75210	04045F	PARTICIPANT	\N	PRESENT	0
76337	75210	98023Q	PARTICIPANT	\N	PRESENT	0
76338	75210	14026U	PARTICIPANT	\N	PRESENT	0
76339	75210	98024R	PARTICIPANT	\N	PRESENT	0
76340	75210	11091R	PARTICIPANT	\N	PRESENT	0
76341	75210	01003G	PARTICIPANT	\N	PRESENT	0
76342	75210	14157T	PARTICIPANT	\N	PRESENT	0
76343	75210	14239U	PARTICIPANT	\N	PRESENT	0
76344	75210	98022P	PARTICIPANT	\N	PRESENT	0
76345	75210	14241N	PARTICIPANT	\N	PRESENT	0
76346	75210	14031R	PARTICIPANT	\N	PRESENT	0
76347	75210	11037K	PARTICIPANT	\N	PRESENT	0
76348	75210	12042Y	PARTICIPANT	\N	PRESENT	0
76349	75210	08018U	PARTICIPANT	\N	PRESENT	0
76350	75210	11107G	PARTICIPANT	\N	PRESENT	0
76351	75210	08009T	PARTICIPANT	\N	PRESENT	0
76352	75210	08031R	PARTICIPANT	\N	PRESENT	0
76353	75210	14034U	PARTICIPANT	\N	PRESENT	0
76354	75210	14273W	PARTICIPANT	\N	PRESENT	0
76355	75210	04040A	PARTICIPANT	\N	PRESENT	0
76356	75210	14205J	PARTICIPANT	\N	PRESENT	0
76357	75210	14219Q	PARTICIPANT	\N	PRESENT	0
76358	75210	14042U	PARTICIPANT	\N	PRESENT	0
76359	75210	14103D	PARTICIPANT	\N	PRESENT	0
76360	75210	14221J	PARTICIPANT	\N	PRESENT	0
76361	75210	11082Q	PARTICIPANT	\N	PRESENT	0
76362	75210	01047U	PARTICIPANT	\N	PRESENT	0
76363	75210	14231L	PARTICIPANT	\N	PRESENT	0
76364	75210	14083S	PARTICIPANT	\N	PRESENT	0
76365	75210	04089T	PARTICIPANT	\N	PRESENT	0
76366	75210	14265W	PARTICIPANT	\N	PRESENT	0
76416	75210	14191V	PARTICIPANT	\N	PRESENT	0
76368	75210	98042T	PARTICIPANT	\N	PRESENT	0
76369	75210	07004J	PARTICIPANT	\N	PRESENT	0
76370	75210	11085T	PARTICIPANT	\N	PRESENT	0
76371	75210	11070L	PARTICIPANT	\N	PRESENT	0
76372	75210	08056B	PARTICIPANT	\N	PRESENT	0
76373	75210	01025N	PARTICIPANT	\N	PRESENT	0
76374	75210	01007L	PARTICIPANT	\N	PRESENT	0
76375	75210	14327T	PARTICIPANT	\N	PRESENT	0
76411	75210	11015D	PARTICIPANT	\N	PRESENT	0
76377	75210	04071H	PARTICIPANT	\N	PRESENT	0
76378	75210	11112D	PARTICIPANT	\N	PRESENT	0
76379	75210	14235Q	PARTICIPANT	\N	PRESENT	0
76380	75210	04054G	PARTICIPANT	\N	PRESENT	0
76381	75210	04044E	PARTICIPANT	\N	PRESENT	0
76382	75210	14251Q	PARTICIPANT	\N	PRESENT	0
76383	75210	04043D	PARTICIPANT	\N	PRESENT	0
76384	75210	11099A	PARTICIPANT	\N	PRESENT	0
76385	75210	01015L	PARTICIPANT	\N	PRESENT	0
76386	75210	11031D	PARTICIPANT	\N	PRESENT	0
76387	75210	01060R	PARTICIPANT	\N	PRESENT	0
76388	75210	14055N	PARTICIPANT	\N	PRESENT	0
76389	75210	92044U	PARTICIPANT	\N	PRESENT	0
76390	75210	08039A	PARTICIPANT	\N	PRESENT	0
76391	75210	14089Y	PARTICIPANT	\N	PRESENT	0
76392	75210	11064N	PARTICIPANT	\N	PRESENT	0
76393	75210	08038Y	PARTICIPANT	\N	PRESENT	0
76394	75210	11094U	PARTICIPANT	\N	PRESENT	0
76395	75210	14255U	PARTICIPANT	\N	PRESENT	0
76396	75210	98053W	PARTICIPANT	\N	PRESENT	0
76397	75210	04070G	PARTICIPANT	\N	PRESENT	0
76398	75210	08048B	PARTICIPANT	\N	PRESENT	0
76399	75210	08017T	PARTICIPANT	\N	PRESENT	0
76401	75210	11065P	PARTICIPANT	\N	PRESENT	0
76402	75210	01034P	PARTICIPANT	\N	PRESENT	0
76403	75210	11054L	PARTICIPANT	\N	PRESENT	0
76417	75210	95067Q	PARTICIPANT	\N	PRESENT	0
76405	75210	89017R	PARTICIPANT	\N	PRESENT	0
76406	75210	14065Q	PARTICIPANT	\N	PRESENT	0
76407	75210	04067M	PARTICIPANT	\N	PRESENT	0
76418	75210	10006L	PARTICIPANT	\N	PRESENT	0
76419	75210	08053X	PARTICIPANT	\N	PRESENT	0
76420	75210	11063M	PARTICIPANT	\N	PRESENT	0
76421	75210	11066Q	PARTICIPANT	\N	PRESENT	0
76422	75210	08068F	PARTICIPANT	\N	PRESENT	0
63299	62865	14030Q	PARTICIPANT	\N	PRESENT	0
63300	62865	14221J	PARTICIPANT	\N	PRESENT	0
63301	62865	10006L	PARTICIPANT	\N	PRESENT	0
63302	62865	14103D	PARTICIPANT	\N	PRESENT	0
63303	62865	14069U	PARTICIPANT	\N	PRESENT	0
63304	62865	05012A	PARTICIPANT	\N	PRESENT	0
63305	62865	08016S	PARTICIPANT	\N	PRESENT	0
63306	62865	11099A	PARTICIPANT	\N	PRESENT	0
63307	62865	01057W	PARTICIPANT	\N	PRESENT	0
63308	62865	04057K	PARTICIPANT	\N	PRESENT	0
63309	62865	11057P	PARTICIPANT	\N	PRESENT	0
63310	62865	11074Q	PARTICIPANT	\N	PRESENT	0
63311	62865	98018T	PARTICIPANT	\N	PRESENT	0
63312	62865	04056J	PARTICIPANT	\N	PRESENT	0
63313	62865	04043D	PARTICIPANT	\N	PRESENT	0
63314	62865	11039M	PARTICIPANT	\N	PRESENT	0
63315	62865	14051J	PARTICIPANT	\N	PRESENT	0
63316	62865	14251Q	PARTICIPANT	\N	PRESENT	0
63317	62865	14151M	PARTICIPANT	\N	PRESENT	0
63318	62865	08053X	PARTICIPANT	\N	PRESENT	0
63319	62865	01008M	PARTICIPANT	\N	PRESENT	0
63320	62865	98046X	PARTICIPANT	\N	PRESENT	0
63321	62865	08052W	PARTICIPANT	\N	PRESENT	0
63322	62865	98021N	PARTICIPANT	\N	PRESENT	0
63323	62865	14055N	PARTICIPANT	\N	PRESENT	0
63324	62865	04081K	PARTICIPANT	\N	PRESENT	0
63325	62865	08055A	PARTICIPANT	\N	PRESENT	0
63326	62865	01041N	PARTICIPANT	\N	PRESENT	0
63327	62865	14107H	PARTICIPANT	\N	PRESENT	0
63328	62865	98023Q	PARTICIPANT	\N	PRESENT	0
63329	62865	04066L	PARTICIPANT	\N	PRESENT	0
63330	62865	11027H	PARTICIPANT	\N	PRESENT	0
63331	62865	01011G	PARTICIPANT	\N	PRESENT	0
63332	62865	04086Q	PARTICIPANT	\N	PRESENT	0
63333	62865	95063L	PARTICIPANT	\N	PRESENT	0
63334	62865	14197C	PARTICIPANT	\N	PRESENT	0
63335	62865	14053L	PARTICIPANT	\N	PRESENT	0
63336	62865	97011G	PARTICIPANT	\N	PRESENT	0
63337	62865	01022K	PARTICIPANT	\N	PRESENT	0
63338	62865	04055H	PARTICIPANT	\N	PRESENT	0
63339	62865	14028W	PARTICIPANT	\N	PRESENT	0
63340	62865	14213J	PARTICIPANT	\N	PRESENT	0
63341	62865	80013X	PARTICIPANT	\N	PRESENT	0
63342	62865	92020L	PARTICIPANT	\N	PRESENT	0
63343	62865	08015R	PARTICIPANT	\N	PRESENT	0
63344	62865	11015D	PARTICIPANT	\N	PRESENT	0
63345	62865	11083R	PARTICIPANT	\N	PRESENT	0
63346	62865	11091R	PARTICIPANT	\N	PRESENT	0
63347	62865	08043V	PARTICIPANT	\N	PRESENT	0
63348	62865	11031D	PARTICIPANT	\N	PRESENT	0
63349	62865	11048N	PARTICIPANT	\N	PRESENT	0
63350	62865	08068F	PARTICIPANT	\N	PRESENT	0
63351	62865	14093U	PARTICIPANT	\N	PRESENT	0
63352	62865	07032N	PARTICIPANT	\N	PRESENT	0
63353	62865	11089X	PARTICIPANT	\N	PRESENT	0
63354	62865	14175V	PARTICIPANT	\N	PRESENT	0
63355	62865	08012N	PARTICIPANT	\N	PRESENT	0
63356	62865	11059R	PARTICIPANT	\N	PRESENT	0
63357	62865	07029T	PARTICIPANT	\N	PRESENT	0
63358	62865	14237S	PARTICIPANT	\N	PRESENT	0
63359	62865	01025N	PARTICIPANT	\N	PRESENT	0
63360	62865	14034U	PARTICIPANT	\N	PRESENT	0
63361	62865	07024N	PARTICIPANT	\N	PRESENT	0
63362	62865	01007L	PARTICIPANT	\N	PRESENT	0
63363	62865	04071H	PARTICIPANT	\N	PRESENT	0
63364	62865	83047W	PARTICIPANT	\N	PRESENT	0
63365	62865	14135M	PARTICIPANT	\N	PRESENT	0
63366	62865	14271U	PARTICIPANT	\N	PRESENT	0
63367	62865	11010L	PARTICIPANT	\N	PRESENT	0
63368	62865	95037J	PARTICIPANT	\N	PRESENT	0
63369	62865	04074L	PARTICIPANT	\N	PRESENT	0
63370	62865	11088W	PARTICIPANT	\N	PRESENT	0
63371	62865	04079R	PARTICIPANT	\N	PRESENT	0
63372	62865	08017T	PARTICIPANT	\N	PRESENT	0
63373	62865	04034C	PARTICIPANT	\N	PRESENT	0
63374	62865	08069G	PARTICIPANT	\N	PRESENT	0
63375	62865	83042R	PARTICIPANT	\N	PRESENT	0
63376	62865	11046L	PARTICIPANT	\N	PRESENT	0
63377	62865	11049P	PARTICIPANT	\N	PRESENT	0
63378	62865	98029W	PARTICIPANT	\N	PRESENT	0
63379	62865	14225N	PARTICIPANT	\N	PRESENT	0
63380	62865	14207L	PARTICIPANT	\N	PRESENT	0
63381	62865	08014Q	PARTICIPANT	\N	PRESENT	0
63382	62865	04092N	PARTICIPANT	\N	PRESENT	0
63383	62865	14195A	PARTICIPANT	\N	PRESENT	0
63384	62865	11095V	PARTICIPANT	\N	PRESENT	0
63385	62865	14033T	PARTICIPANT	\N	PRESENT	0
63386	62865	14001X	PARTICIPANT	\N	PRESENT	0
63387	62865	14227Q	PARTICIPANT	\N	PRESENT	0
63388	62865	14097Y	PARTICIPANT	\N	PRESENT	0
63389	62865	77002U	PARTICIPANT	\N	PRESENT	0
63390	62865	14281W	PARTICIPANT	\N	PRESENT	0
63391	62865	01031L	PARTICIPANT	\N	PRESENT	0
63392	62865	14119M	PARTICIPANT	\N	PRESENT	0
63393	62865	14229S	PARTICIPANT	\N	PRESENT	0
63394	62865	14121F	PARTICIPANT	\N	PRESENT	0
63395	62865	01014K	PARTICIPANT	\N	PRESENT	0
63396	62865	14329V	PARTICIPANT	\N	PRESENT	0
63397	62865	14063N	PARTICIPANT	\N	PRESENT	0
63398	62865	01016M	PARTICIPANT	\N	PRESENT	0
63399	62865	13002U	PARTICIPANT	\N	PRESENT	0
63400	62865	14209N	PARTICIPANT	\N	PRESENT	0
63401	62865	14059S	PARTICIPANT	\N	PRESENT	0
63402	62865	14257W	PARTICIPANT	\N	PRESENT	0
63403	62865	11094U	PARTICIPANT	\N	PRESENT	0
63405	62865	14037X	PARTICIPANT	\N	PRESENT	0
63406	62865	02002K	PARTICIPANT	\N	PRESENT	0
63407	62865	14039A	PARTICIPANT	\N	PRESENT	0
63408	62865	11114F	PARTICIPANT	\N	PRESENT	0
63409	62865	07034Q	PARTICIPANT	\N	PRESENT	0
63410	62865	14265W	PARTICIPANT	\N	PRESENT	0
63411	62865	08035V	PARTICIPANT	\N	PRESENT	0
63413	62865	11072N	PARTICIPANT	\N	PRESENT	0
63414	62865	11097X	PARTICIPANT	\N	PRESENT	0
63415	62865	08073C	PARTICIPANT	\N	PRESENT	0
63416	62865	11042G	PARTICIPANT	\N	PRESENT	0
63417	62865	14147R	PARTICIPANT	\N	PRESENT	0
63418	62865	14159V	PARTICIPANT	\N	PRESENT	0
63420	62865	14269B	PARTICIPANT	\N	PRESENT	0
63421	62865	11107G	PARTICIPANT	\N	PRESENT	0
63422	62865	12042Y	PARTICIPANT	\N	PRESENT	0
63423	62865	04045F	PARTICIPANT	\N	PRESENT	0
63424	62865	11077T	PARTICIPANT	\N	PRESENT	0
63425	62865	11103C	PARTICIPANT	\N	PRESENT	0
63426	62865	04088S	PARTICIPANT	\N	PRESENT	0
63427	62865	08039A	PARTICIPANT	\N	PRESENT	0
63428	62865	11067R	PARTICIPANT	\N	PRESENT	0
63429	62865	80027E	PARTICIPANT	\N	PRESENT	0
63430	62865	08024S	PARTICIPANT	\N	PRESENT	0
63431	62865	11066Q	PARTICIPANT	\N	PRESENT	0
63432	62865	11106F	PARTICIPANT	\N	PRESENT	0
63433	62865	04059M	PARTICIPANT	\N	PRESENT	0
63434	62865	95062K	PARTICIPANT	\N	PRESENT	0
63435	62865	01037S	PARTICIPANT	\N	PRESENT	0
63436	62865	11104D	PARTICIPANT	\N	PRESENT	0
63437	62865	11110B	PARTICIPANT	\N	PRESENT	0
63438	62865	14038Y	PARTICIPANT	\N	PRESENT	0
63439	62865	04053F	PARTICIPANT	\N	PRESENT	0
63440	62865	01028R	PARTICIPANT	\N	PRESENT	0
63442	62865	04077P	PARTICIPANT	\N	PRESENT	0
63443	62865	08061X	PARTICIPANT	\N	PRESENT	0
63444	62865	14217N	PARTICIPANT	\N	PRESENT	0
63445	62865	14199E	PARTICIPANT	\N	PRESENT	0
63449	62865	11032E	PARTICIPANT	\N	PRESENT	0
63450	62865	14157T	PARTICIPANT	\N	PRESENT	0
63451	62865	14109K	PARTICIPANT	\N	PRESENT	0
63452	62865	11044J	PARTICIPANT	\N	PRESENT	0
63453	62865	92045V	PARTICIPANT	\N	PRESENT	0
63454	62865	04070G	PARTICIPANT	\N	PRESENT	0
63455	62865	14061L	PARTICIPANT	\N	PRESENT	0
63456	62865	10015M	PARTICIPANT	\N	PRESENT	0
63457	62865	14273W	PARTICIPANT	\N	PRESENT	0
63458	62865	14123H	PARTICIPANT	\N	PRESENT	0
63459	62865	14187A	PARTICIPANT	\N	PRESENT	0
63460	62865	14249W	PARTICIPANT	\N	PRESENT	0
63461	62865	11068S	PARTICIPANT	\N	PRESENT	0
63462	62865	11090Q	PARTICIPANT	\N	PRESENT	0
63469	62865	11085T	PARTICIPANT	\N	PRESENT	0
63464	62865	11080N	PARTICIPANT	\N	PRESENT	0
63465	62865	14253S	PARTICIPANT	\N	PRESENT	0
63470	62865	04061F	PARTICIPANT	\N	PRESENT	0
63468	62865	08019V	PARTICIPANT	\N	PRESENT	0
63471	62865	14263U	PARTICIPANT	\N	PRESENT	0
63472	62865	04054G	PARTICIPANT	\N	PRESENT	0
63473	62865	89017R	PARTICIPANT	\N	PRESENT	0
63474	62865	14111D	PARTICIPANT	\N	PRESENT	0
63475	62865	14223L	PARTICIPANT	\N	PRESENT	0
63476	62865	04067M	PARTICIPANT	\N	PRESENT	0
87051	87050	07004J	PARTICIPANT	\N	PRESENT	0
87052	87050	14281W	PARTICIPANT	\N	PRESENT	0
87053	87050	10015M	PARTICIPANT	\N	PRESENT	0
87061	87059	14089Y	PARTICIPANT	\N	PRESENT	0
87063	87059	14281W	PARTICIPANT	\N	PRESENT	0
87064	87059	07004J	PARTICIPANT	\N	PRESENT	0
87065	87059	10015M	PARTICIPANT	\N	PRESENT	0
87066	87059	14269B	PARTICIPANT	\N	PRESENT	0
87068	87059	14065Q	PARTICIPANT	\N	PRESENT	0
87069	87059	04061F	PARTICIPANT	\N	PRESENT	0
87071	87059	14041T	PARTICIPANT	\N	PRESENT	0
87078	87076	14239U	PARTICIPANT	\N	PRESENT	0
87079	87076	14281W	PARTICIPANT	\N	PRESENT	0
87081	87076	07004J	PARTICIPANT	\N	PRESENT	0
87082	87076	10015M	PARTICIPANT	\N	PRESENT	0
87084	87083	14281W	PARTICIPANT	\N	PRESENT	0
87085	87083	07004J	PARTICIPANT	\N	PRESENT	0
87086	87083	10015M	PARTICIPANT	\N	PRESENT	0
89252	87175	11010L	PARTICIPANT	\N	EXCUSE	0
89253	87176	11010L	PARTICIPANT	\N	EXCUSE	0
92128	87176	01022K	PARTICIPANT	\N	EXCUSE	0
92129	87176	08019V	PRESIDENT	0	PRESENT	0
92130	87176	14059S	PARTICIPANT	\N	PRESENT	0
92132	92131	01027Q	PRESIDENT	0	PRESENT	0
92134	92131	14159V	PARTICIPANT	\N	PRESENT	0
92135	92131	01057W	PARTICIPANT	\N	PRESENT	0
92136	92131	14157T	PARTICIPANT	\N	PRESENT	0
92137	92131	11080N	PARTICIPANT	\N	PRESENT	0
92138	92131	11053K	PARTICIPANT	\N	PRESENT	0
92139	92131	11029K	PARTICIPANT	\N	EXCUSE	0
92140	92131	92039X	PARTICIPANT	\N	EXCUSE	0
92141	92131	14225N	PARTICIPANT	\N	EXCUSE	0
92142	92131	01013J	PARTICIPANT	\N	EXCUSE	0
92143	92131	11012A	PARTICIPANT	\N	EXCUSE	0
92179	90326	04066L	PARTICIPANT	\N	PRESENT	0
92180	90326	14033T	PARTICIPANT	\N	PRESENT	0
92181	90326	01015L	PARTICIPANT	\N	PRESENT	0
92182	90326	08060W	PARTICIPANT	\N	PRESENT	0
92183	90326	11107G	PARTICIPANT	\N	PRESENT	0
92184	90326	14093U	PARTICIPANT	\N	PRESENT	0
92185	90326	11012A	PARTICIPANT	\N	PRESENT	0
92186	90326	09001P	PARTICIPANT	\N	PRESENT	0
92187	90326	14219Q	PARTICIPANT	\N	PRESENT	0
92188	90326	14135M	PARTICIPANT	\N	PRESENT	0
92189	90326	05012A	PARTICIPANT	\N	PRESENT	0
92190	90326	07024N	PARTICIPANT	\N	PRESENT	0
92191	90326	08009T	PARTICIPANT	\N	PRESENT	0
92192	90326	11090Q	PARTICIPANT	\N	PRESENT	0
92193	90326	01044R	PARTICIPANT	\N	PRESENT	0
92194	90326	11109J	PARTICIPANT	\N	PRESENT	0
92195	90326	92045V	PARTICIPANT	\N	PRESENT	0
92196	90326	96004D	PARTICIPANT	\N	PRESENT	0
92197	90326	11114F	PARTICIPANT	\N	PRESENT	0
92198	90326	11099A	PARTICIPANT	\N	PRESENT	0
92199	90326	11065P	PARTICIPANT	\N	PRESENT	0
92200	90326	13002U	PARTICIPANT	\N	PRESENT	0
92204	90326	11023D	PARTICIPANT	\N	PRESENT	0
92213	90326	08019V	PARTICIPANT	\N	PRESENT	0
92214	90326	14041T	PARTICIPANT	\N	PRESENT	0
92215	90326	01003G	PARTICIPANT	\N	PRESENT	0
92237	92236	04040A	PARTICIPANT	\N	PRESENT	0
92238	92236	11084S	PARTICIPANT	\N	PRESENT	0
92239	92236	04036E	PARTICIPANT	\N	PRESENT	0
92240	92236	08069G	PARTICIPANT	\N	PRESENT	0
92241	92236	14219Q	PARTICIPANT	\N	PRESENT	0
92242	92236	10015M	PARTICIPANT	\N	PRESENT	0
92243	92236	01003G	PARTICIPANT	\N	PRESENT	0
92244	92236	07004J	PARTICIPANT	\N	PRESENT	0
92289	92288	08014Q	PARTICIPANT	\N	PRESENT	0
92290	92288	08069G	PARTICIPANT	\N	PRESENT	0
92126	87176	11113E	PARTICIPANT	\N	PRESENT	0
92127	87176	01027Q	PARTICIPANT	\N	PRESENT	0
92292	92291	07029T	PARTICIPANT	\N	PRESENT	0
92336	92216	89029V	PARTICIPANT	\N	PRESENT	0
92337	92216	14038Y	PARTICIPANT	\N	PRESENT	0
92338	92216	14033T	PARTICIPANT	\N	PRESENT	0
92339	92216	14265W	PARTICIPANT	\N	PRESENT	0
92340	92216	98021N	PARTICIPANT	\N	PRESENT	0
92341	92216	14219Q	PARTICIPANT	\N	PRESENT	0
92342	92216	11107G	PARTICIPANT	\N	PRESENT	0
92343	92216	08055A	PARTICIPANT	\N	PRESENT	0
92344	92216	14051J	PARTICIPANT	\N	PRESENT	0
92345	92216	14107H	PARTICIPANT	\N	PRESENT	0
92346	92216	14179A	PARTICIPANT	\N	PRESENT	0
92347	92216	14237S	PARTICIPANT	\N	PRESENT	0
92348	92216	08060W	PARTICIPANT	\N	PRESENT	0
92349	92216	08009T	PARTICIPANT	\N	PRESENT	0
92350	92216	92039X	PARTICIPANT	\N	PRESENT	0
92351	92216	01015L	PARTICIPANT	\N	PRESENT	0
92352	92216	14263U	PARTICIPANT	\N	PRESENT	0
92353	92216	14061L	PARTICIPANT	\N	PRESENT	0
92354	92216	11066Q	PARTICIPANT	\N	PRESENT	0
92355	92216	14261S	PARTICIPANT	\N	PRESENT	0
92359	92216	07024N	PARTICIPANT	\N	PRESENT	0
92357	92216	11113E	PARTICIPANT	\N	PRESENT	0
92358	92216	14031R	PARTICIPANT	\N	PRESENT	0
92360	92216	95030B	PARTICIPANT	\N	PRESENT	0
92361	92216	05012A	PARTICIPANT	\N	PRESENT	0
92362	92216	11054L	PARTICIPANT	\N	PRESENT	0
92363	92216	14257W	PARTICIPANT	\N	PRESENT	0
92364	92216	14037X	PARTICIPANT	\N	PRESENT	0
92365	92216	86044G	PARTICIPANT	\N	PRESENT	0
92366	92216	14157T	PARTICIPANT	\N	PRESENT	0
92367	92216	14259Y	PARTICIPANT	\N	PRESENT	0
92368	92216	08041T	PARTICIPANT	\N	PRESENT	0
92369	92216	88008L	PARTICIPANT	\N	PRESENT	0
92370	92216	01058X	PARTICIPANT	\N	PRESENT	0
92371	92216	02002K	PARTICIPANT	\N	PRESENT	0
92372	92216	11081P	PARTICIPANT	\N	PRESENT	0
92373	92216	11056N	PARTICIPANT	\N	PRESENT	0
92374	92216	14331P	PARTICIPANT	\N	PRESENT	0
92375	92216	11076S	PARTICIPANT	\N	PRESENT	0
92376	92216	14223L	PARTICIPANT	\N	PRESENT	0
92377	92216	14121F	PARTICIPANT	\N	PRESENT	0
92378	92216	98018T	PARTICIPANT	\N	PRESENT	0
92379	92216	97011G	PARTICIPANT	\N	PRESENT	0
92380	92216	11095V	PARTICIPANT	\N	PRESENT	0
92381	92216	14273W	PARTICIPANT	\N	PRESENT	0
92394	92216	08062Y	PARTICIPANT	\N	PRESENT	0
92395	92216	98050T	PARTICIPANT	\N	PRESENT	0
92396	92216	04088S	PARTICIPANT	\N	PRESENT	0
92397	92216	07032N	PARTICIPANT	\N	PRESENT	0
92398	92216	01056V	PARTICIPANT	\N	PRESENT	0
92401	92216	01014K	PARTICIPANT	\N	PRESENT	0
92402	92216	08019V	PARTICIPANT	\N	PRESENT	0
92403	92216	08056B	PARTICIPANT	\N	PRESENT	0
92404	92216	08069G	PARTICIPANT	\N	PRESENT	0
92405	92216	14193X	PARTICIPANT	\N	PRESENT	0
92406	92216	08053X	PARTICIPANT	\N	PRESENT	0
92407	92216	80027E	PARTICIPANT	\N	PRESENT	0
92408	92216	95037J	PARTICIPANT	\N	PRESENT	0
92410	92216	14235Q	PARTICIPANT	\N	PRESENT	0
92412	92216	11053K	PARTICIPANT	\N	PRESENT	0
92416	92216	11084S	PARTICIPANT	\N	PRESENT	0
92418	92216	11042G	PARTICIPANT	\N	PRESENT	0
92421	92216	08042U	PARTICIPANT	\N	PRESENT	0
92423	92216	07029T	PARTICIPANT	\N	PRESENT	0
92427	92216	08065C	PARTICIPANT	\N	PRESENT	0
92428	92216	11090Q	PARTICIPANT	\N	PRESENT	0
92429	92216	14069U	PARTICIPANT	\N	PRESENT	0
92430	92216	95031C	PARTICIPANT	\N	PRESENT	0
92431	92216	08021P	PARTICIPANT	\N	PRESENT	0
63997	60592	11072N	PARTICIPANT	\N	EXCUSE	0
64512	63999	04042C	PARTICIPANT	\N	PRESENT	0
64513	63999	08038Y	PARTICIPANT	\N	PRESENT	0
64514	63999	08039A	PARTICIPANT	\N	PRESENT	0
64515	63999	08024S	PARTICIPANT	\N	PRESENT	0
64516	63999	08028W	PARTICIPANT	\N	PRESENT	0
64517	63999	01037S	PARTICIPANT	\N	PRESENT	0
64518	63999	11081P	PARTICIPANT	\N	PRESENT	0
64519	63999	01019Q	PARTICIPANT	\N	PRESENT	0
64520	63999	11012A	PARTICIPANT	\N	PRESENT	0
64521	63999	14018U	PARTICIPANT	\N	PRESENT	0
64522	63999	14239U	PARTICIPANT	\N	PRESENT	0
64523	63999	14253S	PARTICIPANT	\N	PRESENT	0
64524	63999	14085U	PARTICIPANT	\N	PRESENT	0
64525	63999	11106F	PARTICIPANT	\N	PRESENT	0
64526	63999	14223L	PARTICIPANT	\N	PRESENT	0
64527	63999	14081Q	PARTICIPANT	\N	PRESENT	0
64528	63999	01048V	PARTICIPANT	\N	PRESENT	0
64529	63999	08010L	PARTICIPANT	\N	PRESENT	0
64530	63999	11067R	PARTICIPANT	\N	PRESENT	0
64531	63999	14123H	PARTICIPANT	\N	PRESENT	0
64532	63999	14191V	PARTICIPANT	\N	PRESENT	0
64533	63999	04045F	PARTICIPANT	\N	PRESENT	0
64534	63999	11025F	PARTICIPANT	\N	PRESENT	0
64535	63999	01014K	PARTICIPANT	\N	PRESENT	0
64536	63999	11107G	PARTICIPANT	\N	PRESENT	0
64537	63999	11100Y	PARTICIPANT	\N	PRESENT	0
64538	63999	11014C	PARTICIPANT	\N	PRESENT	0
64539	63999	01056V	PARTICIPANT	\N	PRESENT	0
64540	63999	11113E	PARTICIPANT	\N	PRESENT	0
64541	63999	11037K	PARTICIPANT	\N	PRESENT	0
64542	63999	04048J	PARTICIPANT	\N	PRESENT	0
66878	66803	11082Q	PARTICIPANT	\N	EXCUSE	0
69408	69407	98046X	PARTICIPANT	\N	PRESENT	0
69418	66592	98046X	PARTICIPANT	\N	PRESENT	0
70573	70572	11076S	PARTICIPANT	\N	PRESENT	0
70574	70572	04054G	PARTICIPANT	\N	PRESENT	0
70575	70572	04040A	PARTICIPANT	\N	PRESENT	0
70576	70572	08058D	PARTICIPANT	\N	PRESENT	0
71675	70686	08055A	PARTICIPANT	\N	PRESENT	0
71702	70686	14014Q	PARTICIPANT	\N	PRESENT	0
71677	70686	07026Q	PARTICIPANT	\N	PRESENT	0
71678	70686	01011G	PARTICIPANT	\N	PRESENT	0
70581	70572	11027H	PARTICIPANT	\N	PRESENT	0
70582	70572	98018T	PARTICIPANT	\N	PRESENT	0
71679	70686	14167V	PARTICIPANT	\N	PRESENT	0
70584	70572	92020L	PARTICIPANT	\N	PRESENT	0
70585	70572	95030B	PARTICIPANT	\N	PRESENT	0
70586	70572	11096W	PARTICIPANT	\N	PRESENT	0
71680	70686	14063N	PARTICIPANT	\N	PRESENT	0
70588	70572	97011G	PARTICIPANT	\N	PRESENT	0
70589	70572	08065C	PARTICIPANT	\N	PRESENT	0
71681	70686	11067R	PARTICIPANT	\N	PRESENT	0
70591	70572	07024N	PRESIDENT	0	PRESENT	0
70592	70572	04095R	PARTICIPANT	\N	PRESENT	0
70593	70572	14014Q	PARTICIPANT	\N	PRESENT	0
71682	70686	11012A	PARTICIPANT	\N	PRESENT	0
71683	70686	14219Q	PARTICIPANT	\N	PRESENT	0
71684	70686	07004J	PARTICIPANT	\N	PRESENT	0
70597	70572	08056B	PARTICIPANT	\N	EXCUSE	0
71685	70686	01024M	PARTICIPANT	\N	PRESENT	0
71686	70686	14041T	PARTICIPANT	\N	PRESENT	0
70600	70572	11064N	PARTICIPANT	\N	PRESENT	0
71687	70686	11103C	PARTICIPANT	\N	PRESENT	0
70602	70572	04078Q	PARTICIPANT	\N	PRESENT	0
71688	70686	11093T	PARTICIPANT	\N	PRESENT	0
71689	70686	04044E	PARTICIPANT	\N	PRESENT	0
70605	70572	04036E	PARTICIPANT	\N	EXCUSE	0
71690	70686	08043V	PARTICIPANT	\N	PRESENT	0
71691	70686	11112D	PARTICIPANT	\N	PRESENT	0
71692	70686	14037X	PARTICIPANT	\N	PRESENT	0
71693	70686	14109K	PARTICIPANT	\N	PRESENT	0
70610	70572	11106F	PARTICIPANT	\N	PRESENT	0
71694	70686	14207L	PARTICIPANT	\N	PRESENT	0
71695	70686	14059S	PARTICIPANT	\N	PRESENT	0
71696	70686	11033F	PARTICIPANT	\N	PRESENT	0
71697	70686	11036J	PARTICIPANT	\N	PRESENT	0
71698	70686	14267Y	PARTICIPANT	\N	PRESENT	0
71699	70686	14281W	PARTICIPANT	\N	PRESENT	0
71700	70686	12042Y	PARTICIPANT	\N	PRESENT	0
71701	70686	11031D	PARTICIPANT	\N	PRESENT	0
71703	70686	14231L	PARTICIPANT	\N	PRESENT	0
70620	70572	98021N	PARTICIPANT	\N	EXCUSE	0
71710	70686	11066Q	PARTICIPANT	\N	PRESENT	0
71711	70686	11061K	PARTICIPANT	\N	PRESENT	0
71712	70686	14033T	PARTICIPANT	\N	PRESENT	0
70624	70572	86044G	PARTICIPANT	\N	PRESENT	0
70625	70572	01014K	PARTICIPANT	\N	PRESENT	0
70626	70572	11054L	PARTICIPANT	\N	PRESENT	0
71713	70686	08010L	PARTICIPANT	\N	PRESENT	0
71714	70686	11064N	PARTICIPANT	\N	PRESENT	0
70629	70572	08049C	PARTICIPANT	\N	PRESENT	0
71720	70686	11037K	PARTICIPANT	\N	PRESENT	0
71721	70686	14159V	PARTICIPANT	\N	PRESENT	0
71722	70686	00003C	PARTICIPANT	\N	PRESENT	0
71723	70686	80013X	PARTICIPANT	\N	PRESENT	0
71724	70686	14271U	PARTICIPANT	\N	PRESENT	0
71725	70686	14237S	PARTICIPANT	\N	PRESENT	0
71726	70686	14030Q	PARTICIPANT	\N	PRESENT	0
71727	70686	14097Y	PARTICIPANT	\N	PRESENT	0
71728	70686	92045V	PARTICIPANT	\N	PRESENT	0
71729	70686	97011G	PARTICIPANT	\N	PRESENT	0
71730	70686	08052W	PARTICIPANT	\N	PRESENT	0
71731	70686	14065Q	PARTICIPANT	\N	PRESENT	0
71732	70686	11091R	PARTICIPANT	\N	PRESENT	0
71740	70686	14034U	PARTICIPANT	\N	PRESENT	0
71792	70686	01028R	PARTICIPANT	\N	PRESENT	0
71842	70701	01015L	PARTICIPANT	\N	PRESENT	0
71843	70701	11098Y	PARTICIPANT	\N	PRESENT	0
71844	70701	14038Y	PARTICIPANT	\N	PRESENT	0
71845	70701	14030Q	PARTICIPANT	\N	PRESENT	0
71846	70701	14031R	PARTICIPANT	\N	PRESENT	0
71847	70701	14331P	PARTICIPANT	\N	PRESENT	0
71848	70701	14063N	PARTICIPANT	\N	PRESENT	0
71849	70701	01022K	PARTICIPANT	\N	PRESENT	0
71850	70701	08009T	PARTICIPANT	\N	PRESENT	0
71851	70701	14053L	PARTICIPANT	\N	PRESENT	0
71852	70701	14093U	PARTICIPANT	\N	PRESENT	0
71853	70701	11033F	PARTICIPANT	\N	PRESENT	0
71854	70701	08055A	PARTICIPANT	\N	PRESENT	0
71855	70701	14169X	PARTICIPANT	\N	PRESENT	0
71856	70701	04067M	PARTICIPANT	\N	PRESENT	0
71857	70701	14261S	PARTICIPANT	\N	PRESENT	0
71858	70701	11100Y	PARTICIPANT	\N	PRESENT	0
71859	70701	14207L	PARTICIPANT	\N	PRESENT	0
71860	70701	04094Q	PARTICIPANT	\N	PRESENT	0
71861	70701	14157T	PARTICIPANT	\N	PRESENT	0
71862	70701	14105F	PARTICIPANT	\N	PRESENT	0
71863	70701	95062K	PARTICIPANT	\N	PRESENT	0
71864	70701	11042G	PARTICIPANT	\N	PRESENT	0
71865	70701	11023D	PARTICIPANT	\N	PRESENT	0
71872	70701	09001P	PARTICIPANT	\N	PRESENT	0
71873	70701	14237S	PARTICIPANT	\N	PRESENT	0
71874	70701	01041N	PARTICIPANT	\N	PRESENT	0
71875	70701	14059S	PARTICIPANT	\N	PRESENT	0
71876	70701	04095R	PARTICIPANT	\N	PRESENT	0
71884	70701	11091R	PARTICIPANT	\N	PRESENT	0
71887	70701	01048V	PARTICIPANT	\N	PRESENT	0
71894	70701	08073C	PARTICIPANT	\N	PRESENT	0
71889	70701	11036J	PARTICIPANT	\N	PRESENT	0
71890	70701	11107G	PARTICIPANT	\N	PRESENT	0
71891	70701	95030B	PARTICIPANT	\N	PRESENT	0
71892	70701	14159V	PARTICIPANT	\N	PRESENT	0
71893	70701	14041T	PARTICIPANT	\N	PRESENT	0
71895	70701	04085P	PARTICIPANT	\N	PRESENT	0
71904	70701	11114F	PARTICIPANT	\N	PRESENT	0
71919	70701	04043D	PARTICIPANT	\N	PRESENT	0
71974	70701	14199E	PARTICIPANT	\N	PRESENT	0
71975	70701	11099A	PARTICIPANT	\N	PRESENT	0
71979	70701	95035G	PARTICIPANT	\N	PRESENT	0
71840	70701	04066L	PARTICIPANT	\N	PRESENT	0
71841	70701	11037K	PARTICIPANT	\N	PRESENT	0
71980	70701	08051V	PARTICIPANT	\N	PRESENT	0
71982	70701	14109K	PARTICIPANT	\N	PRESENT	0
71983	70701	14249W	PARTICIPANT	\N	PRESENT	0
71984	70701	80013X	PARTICIPANT	\N	PRESENT	0
71985	70701	08069G	PARTICIPANT	\N	PRESENT	0
71987	70701	98046X	PARTICIPANT	\N	PRESENT	0
71989	70701	14083S	PARTICIPANT	\N	PRESENT	0
71993	70701	05012A	PARTICIPANT	\N	PRESENT	0
71994	70701	99004R	PARTICIPANT	\N	PRESENT	0
72012	71331	11010L	PARTICIPANT	\N	EXCUSE	0
72034	71331	96003C	PARTICIPANT	\N	EXCUSE	0
76423	75210	11057P	PARTICIPANT	\N	PRESENT	0
76424	75210	14179A	PARTICIPANT	\N	PRESENT	0
76432	75211	07026Q	PARTICIPANT	\N	PRESENT	0
76426	75210	14133K	PARTICIPANT	\N	PRESENT	0
76431	75211	08024S	PARTICIPANT	\N	PRESENT	0
76433	75211	11031D	PARTICIPANT	\N	PRESENT	0
76434	75211	14013P	PARTICIPANT	\N	PRESENT	0
76435	75211	01015L	PARTICIPANT	\N	PRESENT	0
76436	75211	14227Q	PARTICIPANT	\N	PRESENT	0
76437	75211	80013X	PARTICIPANT	\N	PRESENT	0
76438	75211	00003C	PARTICIPANT	\N	PRESENT	0
76439	75211	08060W	PARTICIPANT	\N	PRESENT	0
76440	75211	11110B	PARTICIPANT	\N	PRESENT	0
76441	75211	08052W	PARTICIPANT	\N	PRESENT	0
76442	75211	14014Q	PARTICIPANT	\N	PRESENT	0
76443	75211	11055M	PARTICIPANT	\N	PRESENT	0
76444	75211	14159V	PARTICIPANT	\N	PRESENT	0
76445	75211	11061K	PARTICIPANT	\N	PRESENT	0
76446	75211	04053F	PARTICIPANT	\N	PRESENT	0
76447	75211	98022P	PARTICIPANT	\N	PRESENT	0
76448	75211	14231L	PARTICIPANT	\N	PRESENT	0
76449	75211	14089Y	PARTICIPANT	\N	PRESENT	0
76450	75211	01059Y	PARTICIPANT	\N	PRESENT	0
76451	75211	14265W	PARTICIPANT	\N	PRESENT	0
76452	75211	11091R	PARTICIPANT	\N	PRESENT	0
76453	75211	14033T	PARTICIPANT	\N	PRESENT	0
76454	75211	98005N	PARTICIPANT	\N	PRESENT	0
76455	75211	14037X	PARTICIPANT	\N	PRESENT	0
76456	75211	10006L	PARTICIPANT	\N	PRESENT	0
76457	75211	95062K	PARTICIPANT	\N	PRESENT	0
76458	75211	01025N	PARTICIPANT	\N	PRESENT	0
76459	75211	14205J	PARTICIPANT	\N	PRESENT	0
76460	75211	04085P	PARTICIPANT	\N	PRESENT	0
76461	75211	11063M	PARTICIPANT	\N	PRESENT	0
76462	75211	14187A	PARTICIPANT	\N	PRESENT	0
76463	75211	14026U	PARTICIPANT	\N	PRESENT	0
76464	75211	11093T	PARTICIPANT	\N	PRESENT	0
76465	75211	14105F	PARTICIPANT	\N	PRESENT	0
76466	75211	11067R	PARTICIPANT	\N	PRESENT	0
76467	75211	01011G	PARTICIPANT	\N	PRESENT	0
76468	75211	11036J	PARTICIPANT	\N	PRESENT	0
76469	75211	14042U	PARTICIPANT	\N	PRESENT	0
76470	75211	14235Q	PARTICIPANT	\N	PRESENT	0
76471	75211	14263U	PARTICIPANT	\N	PRESENT	0
76472	75211	01022K	PARTICIPANT	\N	PRESENT	0
76473	75211	14179A	PARTICIPANT	\N	PRESENT	0
76474	75211	14239U	PARTICIPANT	\N	PRESENT	0
76475	75211	14281W	PARTICIPANT	\N	PRESENT	0
76476	75211	12042Y	PARTICIPANT	\N	PRESENT	0
76477	75211	04088S	PARTICIPANT	\N	PRESENT	0
76478	75211	14135M	PARTICIPANT	\N	PRESENT	0
76479	75211	01060R	PARTICIPANT	\N	PRESENT	0
76480	75211	97011G	PARTICIPANT	\N	PRESENT	0
76481	75211	01041N	PARTICIPANT	\N	PRESENT	0
76482	75211	11097X	PARTICIPANT	\N	PRESENT	0
76483	75211	07029T	PARTICIPANT	\N	PRESENT	0
76484	75211	14087W	PARTICIPANT	\N	PRESENT	0
76485	75211	11112D	PARTICIPANT	\N	PRESENT	0
76486	75211	14199E	PARTICIPANT	\N	PRESENT	0
76487	75211	04045F	PARTICIPANT	\N	PRESENT	0
76488	75211	14119M	PARTICIPANT	\N	PRESENT	0
76489	75211	95015C	PARTICIPANT	\N	PRESENT	0
76490	75211	87003B	PARTICIPANT	\N	PRESENT	0
77466	76536	04081K	PARTICIPANT	\N	PRESENT	0
77468	76536	14331P	PARTICIPANT	\N	PRESENT	0
77469	76536	04036E	PARTICIPANT	\N	PRESENT	0
77470	76536	14030Q	PARTICIPANT	\N	PRESENT	0
77471	76536	11099A	PARTICIPANT	\N	PRESENT	0
77472	76536	11109J	PARTICIPANT	\N	PRESENT	0
77473	76536	11098Y	PARTICIPANT	\N	PRESENT	0
77474	76536	14013P	PARTICIPANT	\N	PRESENT	0
77475	76536	01015L	PARTICIPANT	\N	PRESENT	0
77476	76536	14031R	PARTICIPANT	\N	PRESENT	0
77477	76536	01022K	PARTICIPANT	\N	PRESENT	0
77478	76536	01048V	PARTICIPANT	\N	PRESENT	0
77479	76536	11107G	PARTICIPANT	\N	PRESENT	0
77480	76536	04094Q	PARTICIPANT	\N	PRESENT	0
77481	76536	11054L	PARTICIPANT	\N	PRESENT	0
77482	76536	95062K	PARTICIPANT	\N	PRESENT	0
77483	76536	08009T	PARTICIPANT	\N	PRESENT	0
77484	76536	14121F	PARTICIPANT	\N	PRESENT	0
77485	76536	14261S	PARTICIPANT	\N	PRESENT	0
77486	76536	08022Q	PARTICIPANT	\N	PRESENT	0
77487	76536	14157T	PARTICIPANT	\N	PRESENT	0
77488	76536	04095R	PARTICIPANT	\N	PRESENT	0
77489	76536	95067Q	PARTICIPANT	\N	PRESENT	0
77490	76536	11025F	PARTICIPANT	\N	PRESENT	0
77491	76536	11091R	PARTICIPANT	\N	PRESENT	0
77492	76536	14135M	PARTICIPANT	\N	PRESENT	0
77514	76536	11042G	PARTICIPANT	\N	PRESENT	0
77515	76536	01041N	PARTICIPANT	\N	PRESENT	0
77516	76536	99004R	PARTICIPANT	\N	PRESENT	0
77519	76536	08034U	PARTICIPANT	\N	PRESENT	0
77520	76536	07024N	PARTICIPANT	\N	PRESENT	0
77521	76536	14039A	PARTICIPANT	\N	PRESENT	0
77522	76536	80013X	PARTICIPANT	\N	PRESENT	0
77567	76536	95035G	PARTICIPANT	\N	PRESENT	0
77568	76536	02002K	PARTICIPANT	\N	PRESENT	0
77570	76536	05012A	PARTICIPANT	\N	PRESENT	0
77571	76536	01027Q	PARTICIPANT	\N	PRESENT	0
77572	76536	04067M	PARTICIPANT	\N	PRESENT	0
77578	76536	04066L	PARTICIPANT	\N	PRESENT	0
77579	76536	01013J	PARTICIPANT	\N	PRESENT	0
77860	77580	08047A	PARTICIPANT	\N	PRESENT	0
77861	77580	08011M	PARTICIPANT	\N	PRESENT	0
77862	77580	04048J	PARTICIPANT	\N	PRESENT	0
77863	77580	11066Q	PARTICIPANT	\N	PRESENT	0
77864	77580	99004R	PARTICIPANT	\N	PRESENT	0
77865	77580	14147R	PARTICIPANT	\N	PRESENT	0
77866	77580	14193X	PARTICIPANT	\N	PRESENT	0
77867	77580	00003C	PARTICIPANT	\N	PRESENT	0
77868	77580	05008E	PARTICIPANT	\N	PRESENT	0
77869	77580	04086Q	PARTICIPANT	\N	PRESENT	0
77870	77580	07026Q	PARTICIPANT	\N	PRESENT	0
77871	77580	11040E	PARTICIPANT	\N	PRESENT	0
77872	77580	86044G	PARTICIPANT	\N	PRESENT	0
77873	77580	07004J	PARTICIPANT	\N	PRESENT	0
77858	77580	11085T	PARTICIPANT	\N	PRESENT	0
77859	77580	95049N	PARTICIPANT	\N	PRESENT	0
77874	77580	11103C	PARTICIPANT	\N	PRESENT	0
77875	77580	14187A	PARTICIPANT	\N	PRESENT	0
77876	77580	95063L	PARTICIPANT	\N	PRESENT	0
77877	77580	14197C	PARTICIPANT	\N	PRESENT	0
77878	77580	14030Q	PARTICIPANT	\N	PRESENT	0
77879	77580	08051V	PARTICIPANT	\N	PRESENT	0
77880	77580	01047U	PARTICIPANT	\N	PRESENT	0
77881	77580	14001X	PARTICIPANT	\N	PRESENT	0
77882	77580	12042Y	PARTICIPANT	\N	PRESENT	0
77883	77580	04038G	PARTICIPANT	\N	PRESENT	0
77884	77580	11094U	PARTICIPANT	\N	PRESENT	0
77885	77580	10006L	PARTICIPANT	\N	PRESENT	0
77886	77580	14061L	PARTICIPANT	\N	PRESENT	0
77887	77580	14225N	PARTICIPANT	\N	PRESENT	0
77888	77580	14133K	PARTICIPANT	\N	PRESENT	0
77889	77580	11056N	PARTICIPANT	\N	PRESENT	0
77890	77580	14253S	PARTICIPANT	\N	PRESENT	0
77891	77580	14085U	PARTICIPANT	\N	PRESENT	0
77892	77580	14207L	PARTICIPANT	\N	PRESENT	0
77893	77580	04056J	PARTICIPANT	\N	PRESENT	0
77894	77580	14263U	PARTICIPANT	\N	PRESENT	0
77895	77580	92018S	PARTICIPANT	\N	PRESENT	0
77896	77580	14014Q	PARTICIPANT	\N	PRESENT	0
77897	77580	01013J	PARTICIPANT	\N	PRESENT	0
77898	77580	14065Q	PARTICIPANT	\N	PRESENT	0
77899	77580	11049P	PARTICIPANT	\N	PRESENT	0
77900	77580	11053K	PARTICIPANT	\N	PRESENT	0
77901	77580	04033B	PARTICIPANT	\N	PRESENT	0
77902	77580	08058D	PARTICIPANT	\N	PRESENT	0
77903	77580	14239U	PARTICIPANT	\N	PRESENT	0
77904	77580	14041T	PARTICIPANT	\N	PRESENT	0
77905	77580	14257W	PARTICIPANT	\N	PRESENT	0
77906	77580	08041T	PARTICIPANT	\N	PRESENT	0
77907	77580	14087W	PARTICIPANT	\N	PRESENT	0
77908	77580	04085P	PARTICIPANT	\N	PRESENT	0
77909	77580	11106F	PARTICIPANT	\N	PRESENT	0
77910	77580	01024M	PARTICIPANT	\N	PRESENT	0
77911	77580	14205J	PARTICIPANT	\N	PRESENT	0
77912	77580	11081P	PARTICIPANT	\N	PRESENT	0
77913	77580	01028R	PARTICIPANT	\N	PRESENT	0
77914	77580	01015L	PARTICIPANT	\N	PRESENT	0
77915	77580	14013P	PARTICIPANT	\N	PRESENT	0
77916	77580	08028W	PARTICIPANT	\N	PRESENT	0
77917	77580	11033F	PARTICIPANT	\N	PRESENT	0
77918	77580	14083S	PARTICIPANT	\N	PRESENT	0
77919	77580	97011G	PARTICIPANT	\N	PRESENT	0
77920	77580	04081K	PARTICIPANT	\N	PRESENT	0
77921	77580	14269B	PARTICIPANT	\N	PRESENT	0
77922	77580	11084S	PARTICIPANT	\N	PRESENT	0
62158	61987	11054L	PARTICIPANT	\N	EXCUSE	0
62163	62162	08025T	PARTICIPANT	\N	PRESENT	0
62164	62162	04085P	PARTICIPANT	\N	PRESENT	0
62165	62162	05008E	PRESIDENT	0	PRESENT	0
62166	62162	11030C	PARTICIPANT	\N	PRESENT	0
62167	62162	11033F	PARTICIPANT	\N	PRESENT	0
62212	62162	04070G	PARTICIPANT	\N	PRESENT	0
62169	62162	14069U	PARTICIPANT	\N	PRESENT	0
62170	62162	04047H	PARTICIPANT	\N	PRESENT	0
62171	62162	11032E	PARTICIPANT	\N	PRESENT	0
62172	62162	04038G	PARTICIPANT	\N	PRESENT	0
62346	62288	10015M	PARTICIPANT	\N	PRESENT	0
62175	62162	14259Y	PARTICIPANT	\N	PRESENT	0
62176	62162	11035H	PARTICIPANT	\N	PRESENT	0
62177	62162	14041T	PARTICIPANT	\N	PRESENT	0
62291	62288	01046T	PARTICIPANT	\N	PRESENT	0
62179	62162	01024M	PARTICIPANT	\N	PRESENT	0
62292	62288	04053F	PARTICIPANT	\N	PRESENT	0
62181	62162	11034G	PARTICIPANT	\N	PRESENT	0
62182	62162	08018U	PARTICIPANT	\N	PRESENT	0
62183	62162	11010L	PARTICIPANT	\N	PRESENT	0
62293	62288	14255U	PARTICIPANT	\N	PRESENT	0
62185	62162	11049P	PARTICIPANT	\N	PRESENT	0
62186	62162	08044W	PARTICIPANT	\N	PRESENT	0
62187	62162	11084S	PARTICIPANT	\N	PRESENT	0
62188	62162	11026G	PARTICIPANT	\N	PRESENT	0
62189	62162	04079R	PARTICIPANT	\N	PRESENT	0
62190	62162	14111D	PARTICIPANT	\N	PRESENT	0
62191	62162	14001X	PARTICIPANT	\N	PRESENT	0
62192	62162	14273W	PARTICIPANT	\N	PRESENT	0
62193	62162	01060R	PARTICIPANT	\N	PRESENT	0
62194	62162	14147R	PARTICIPANT	\N	PRESENT	0
62195	62162	95049N	PARTICIPANT	\N	PRESENT	0
62196	62162	08051V	PARTICIPANT	\N	PRESENT	0
62197	62162	11072N	PARTICIPANT	\N	PRESENT	0
62198	62162	07034Q	PRESIDENT	1	PRESENT	0
62199	62162	04074L	PARTICIPANT	\N	PRESENT	0
62200	62162	10015M	PARTICIPANT	\N	PRESENT	0
62201	62162	95063L	PARTICIPANT	\N	PRESENT	0
62294	62288	04066L	PARTICIPANT	\N	PRESENT	0
62203	62162	01028R	PARTICIPANT	\N	PRESENT	0
70426	70418	08022Q	PARTICIPANT	\N	PRESENT	0
62205	62162	04056J	PARTICIPANT	\N	PRESENT	0
62296	62288	14053L	PARTICIPANT	\N	PRESENT	0
62207	62162	04044E	PARTICIPANT	\N	PRESENT	0
62208	62162	11037K	PARTICIPANT	\N	PRESENT	0
62209	62162	92045V	PARTICIPANT	\N	PRESENT	0
62297	62288	11103C	PARTICIPANT	\N	PRESENT	0
62211	62162	01047U	PARTICIPANT	\N	PRESENT	0
70427	70418	11053K	PARTICIPANT	\N	PRESENT	0
62299	62288	14195A	PARTICIPANT	\N	PRESENT	0
62300	62288	14267Y	PARTICIPANT	\N	PRESENT	0
62301	62288	11023D	PARTICIPANT	\N	PRESENT	0
62302	62288	11031D	PARTICIPANT	\N	PRESENT	0
62303	62288	08052W	PARTICIPANT	\N	PRESENT	0
62304	62288	01059Y	PARTICIPANT	\N	PRESENT	0
62305	62288	04081K	PARTICIPANT	\N	PRESENT	0
62306	62288	98024R	PARTICIPANT	\N	PRESENT	0
62307	62288	10006L	PARTICIPANT	\N	PRESENT	0
83893	83892	98005N	PARTICIPANT	\N	EXCUSE	0
62309	62288	14217N	PARTICIPANT	\N	PRESENT	0
73129	73078	14235Q	PARTICIPANT	\N	PRESENT	0
70430	70418	99004R	PARTICIPANT	\N	PRESENT	0
62312	62288	12042Y	PARTICIPANT	\N	PRESENT	0
62313	62288	14281W	PARTICIPANT	\N	PRESENT	0
70431	70418	04061F	PARTICIPANT	\N	PRESENT	0
70432	70418	08061X	PARTICIPANT	\N	PRESENT	0
62316	62288	14034U	PARTICIPANT	\N	PRESENT	0
62317	62288	14231L	PARTICIPANT	\N	PRESENT	0
62318	62288	11061K	PARTICIPANT	\N	PRESENT	0
70433	70418	01016M	PARTICIPANT	\N	PRESENT	0
62320	62288	08041T	PARTICIPANT	\N	PRESENT	0
62321	62288	01011G	PARTICIPANT	\N	PRESENT	0
62322	62288	14026U	PARTICIPANT	\N	PRESENT	0
62323	62288	14213J	PARTICIPANT	\N	PRESENT	0
62324	62288	14121F	PARTICIPANT	\N	PRESENT	0
62325	62288	11112D	PARTICIPANT	\N	PRESENT	0
62326	62288	14037X	PARTICIPANT	\N	PRESENT	0
62327	62288	14018U	PARTICIPANT	\N	PRESENT	0
62328	62288	11067R	PARTICIPANT	\N	PRESENT	0
62329	62288	14223L	PARTICIPANT	\N	PRESENT	0
62330	62288	04092N	PRESIDENT	0	PRESENT	0
62331	62288	14265W	PARTICIPANT	\N	PRESENT	0
62332	62288	14119M	PARTICIPANT	\N	PRESENT	0
62333	62288	14071N	PARTICIPANT	\N	PRESENT	0
62334	62288	07032N	PARTICIPANT	\N	PRESENT	0
62335	62288	04043D	PARTICIPANT	\N	PRESENT	0
62336	62288	14271U	PARTICIPANT	\N	PRESENT	0
62337	62288	14017T	PARTICIPANT	\N	EXCUSE	0
62338	62288	11093T	PARTICIPANT	\N	PRESENT	0
62339	62288	11097X	PARTICIPANT	\N	PRESENT	0
62340	62288	04045F	PARTICIPANT	\N	PRESENT	0
62341	62288	14227Q	PARTICIPANT	\N	PRESENT	0
62342	62288	01034P	PARTICIPANT	\N	PRESENT	0
83925	83924	11053K	PARTICIPANT	\N	PRESENT	0
83927	83926	11053K	PARTICIPANT	\N	PRESENT	0
62345	62288	14269B	PARTICIPANT	\N	PRESENT	0
83928	83892	11010L	PARTICIPANT	\N	EXCUSE	0
83935	83934	11053K	PARTICIPANT	\N	PRESENT	0
83937	83936	01057W	PARTICIPANT	\N	PRESENT	0
83938	83936	14225N	PARTICIPANT	\N	PRESENT	0
83939	83892	04094Q	PARTICIPANT	\N	PRESENT	0
83944	83892	14219Q	PARTICIPANT	\N	EXCUSE	0
83973	83972	92031P	PARTICIPANT	\N	PRESENT	0
84014	84013	98023Q	PARTICIPANT	\N	PRESENT	0
84015	84013	92039X	PARTICIPANT	\N	PRESENT	0
84016	84013	08015R	PARTICIPANT	\N	PRESENT	0
84017	84013	08056B	PARTICIPANT	\N	PRESENT	0
84018	84013	04035D	PARTICIPANT	\N	PRESENT	0
84096	84092	04059M	PARTICIPANT	\N	PRESENT	0
84098	84092	01044R	PARTICIPANT	\N	PRESENT	0
84099	84092	08043V	PARTICIPANT	\N	PRESENT	0
84100	84092	14089Y	PARTICIPANT	\N	PRESENT	0
84101	84092	14105F	PARTICIPANT	\N	PRESENT	0
84102	84092	11029K	PARTICIPANT	\N	PRESENT	0
84103	84092	95015C	PARTICIPANT	\N	PRESENT	0
84104	84092	92015P	PARTICIPANT	\N	PRESENT	0
84105	84092	08024S	PARTICIPANT	\N	EXCUSE	0
84106	84092	14201E	PARTICIPANT	\N	PRESENT	0
84108	84092	14209N	PARTICIPANT	\N	PRESENT	0
84110	84092	11091R	PARTICIPANT	\N	PRESENT	0
84111	84092	87003B	PARTICIPANT	\N	EXCUSE	0
84113	84092	14249W	PARTICIPANT	\N	EXCUSE	0
84114	84092	01041N	PARTICIPANT	\N	EXCUSE	0
84115	84092	01025N	PARTICIPANT	\N	PRESENT	0
84116	84092	01037S	PARTICIPANT	\N	PRESENT	0
84117	84092	89029V	PARTICIPANT	\N	PRESENT	0
73812	56945	11044J	PARTICIPANT	\N	PRESENT	0
73813	56945	04086Q	PARTICIPANT	\N	PRESENT	0
73132	73078	14229S	PARTICIPANT	\N	PRESENT	0
73133	73078	11043H	PARTICIPANT	\N	PRESENT	0
73134	73078	11071M	PARTICIPANT	\N	PRESENT	0
73814	56945	14327T	PARTICIPANT	\N	PRESENT	0
73815	56945	14034U	PARTICIPANT	\N	PRESENT	0
73816	56945	14231L	PARTICIPANT	\N	PRESENT	0
73817	56945	11049P	PARTICIPANT	\N	PRESENT	0
73818	56945	11112D	PARTICIPANT	\N	PRESENT	0
73819	56945	08010L	PARTICIPANT	\N	PRESENT	0
73820	56945	01057W	PARTICIPANT	\N	PRESENT	0
73821	56945	08051V	PRESIDENT	1	PRESENT	0
73822	56945	14028W	PARTICIPANT	\N	PRESENT	0
73823	56945	07032N	PARTICIPANT	\N	PRESENT	0
73824	56945	05012A	PARTICIPANT	\N	PRESENT	0
73825	56945	14051J	PARTICIPANT	\N	PRESENT	0
73826	56945	08034U	PARTICIPANT	\N	PRESENT	0
73827	56945	14071N	PARTICIPANT	\N	PRESENT	0
73828	56945	01027Q	PARTICIPANT	\N	EXCUSE	0
73829	56945	11101A	PARTICIPANT	\N	EXCUSE	0
73830	56945	92040Q	PARTICIPANT	\N	EXCUSE	0
75115	75114	98021N	PARTICIPANT	\N	PRESENT	0
75116	75114	07024N	PARTICIPANT	\N	PRESENT	0
75118	75117	98021N	PARTICIPANT	\N	PRESENT	0
75119	75117	07024N	PARTICIPANT	\N	PRESENT	0
75121	75120	98021N	PARTICIPANT	\N	PRESENT	0
75122	75120	07024N	PARTICIPANT	\N	PRESENT	0
84119	84092	11089X	PARTICIPANT	\N	PRESENT	0
84033	84032	14053L	PARTICIPANT	\N	PRESENT	0
84034	84032	12042Y	PARTICIPANT	\N	PRESENT	0
84036	84035	14053L	PARTICIPANT	\N	PRESENT	0
84037	84035	12042Y	PARTICIPANT	\N	PRESENT	0
84039	84038	11044J	PARTICIPANT	\N	PRESENT	0
84040	84038	11067R	PARTICIPANT	\N	PRESENT	0
84042	84041	98035U	PARTICIPANT	\N	PRESENT	0
84043	84041	04054G	PARTICIPANT	\N	PRESENT	0
84044	84041	11100Y	PARTICIPANT	\N	PRESENT	0
84045	84041	11012A	PARTICIPANT	\N	PRESENT	0
84047	84046	11083R	PARTICIPANT	\N	PRESENT	0
84048	84046	14042U	PARTICIPANT	\N	PRESENT	0
84049	84046	98046X	PARTICIPANT	\N	PRESENT	0
84050	84046	14059S	PARTICIPANT	\N	PRESENT	0
84052	84051	01013J	PARTICIPANT	\N	PRESENT	0
84054	84053	01013J	PARTICIPANT	\N	PRESENT	0
84056	84055	01013J	PARTICIPANT	\N	PRESENT	0
84058	84057	01013J	PARTICIPANT	\N	PRESENT	0
84060	84059	01013J	PARTICIPANT	\N	PRESENT	0
84062	84061	01013J	PARTICIPANT	\N	PRESENT	0
84063	83952	14327T	PARTICIPANT	\N	EXCUSE	0
84064	83952	04044E	PARTICIPANT	\N	EXCUSE	0
84084	83922	01058X	PARTICIPANT	\N	EXCUSE	0
84152	84151	00003C	PARTICIPANT	\N	PRESENT	0
84153	84151	14071N	PARTICIPANT	\N	PRESENT	0
84160	84159	89017R	PARTICIPANT	\N	PRESENT	0
84161	84159	01031L	PRESIDENT	0	PRESENT	0
84228	84159	01013J	PARTICIPANT	\N	EXCUSE	0
84444	84443	14001X	PARTICIPANT	\N	PRESENT	0
84164	84159	11068S	PARTICIPANT	\N	PRESENT	0
84165	84159	11040E	PARTICIPANT	\N	PRESENT	0
84166	84159	08014Q	PARTICIPANT	\N	PRESENT	0
84167	84159	14167V	PARTICIPANT	\N	PRESENT	0
84168	84159	14175V	PARTICIPANT	\N	PRESENT	0
84169	84159	14083S	PARTICIPANT	\N	PRESENT	0
84170	84159	11053K	PARTICIPANT	\N	PRESENT	0
84457	84456	01008M	PARTICIPANT	\N	PRESENT	0
84172	84159	11042G	PARTICIPANT	\N	PRESENT	0
84458	84456	14026U	PARTICIPANT	\N	PRESENT	0
84174	84159	04086Q	PARTICIPANT	\N	PRESENT	0
84459	84456	01037S	PARTICIPANT	\N	PRESENT	0
84176	84159	11070L	PARTICIPANT	\N	PRESENT	0
84177	84159	11088W	PARTICIPANT	\N	PRESENT	0
84460	84456	14179A	PARTICIPANT	\N	PRESENT	0
84461	84456	07029T	PARTICIPANT	\N	PRESENT	0
84180	84159	01027Q	PARTICIPANT	\N	PRESENT	0
84181	84159	04071H	PARTICIPANT	\N	PRESENT	0
84182	84159	11074Q	PARTICIPANT	\N	PRESENT	0
84462	84456	14219Q	PARTICIPANT	\N	PRESENT	0
84463	84456	04061F	PARTICIPANT	\N	PRESENT	0
84464	84456	95062K	PARTICIPANT	\N	PRESENT	0
84632	83952	11048N	PARTICIPANT	\N	EXCUSE	0
84636	83952	04045F	PARTICIPANT	\N	PRESENT	0
84188	84159	08069G	PARTICIPANT	\N	PRESENT	0
84189	84159	11048N	PARTICIPANT	\N	PRESENT	0
84190	84159	99004R	PARTICIPANT	\N	PRESENT	0
84818	83952	14028W	PARTICIPANT	\N	PRESENT	0
84192	84159	14159V	PARTICIPANT	\N	PRESENT	0
84193	84159	07029T	PARTICIPANT	\N	PRESENT	0
85405	83952	14014Q	PARTICIPANT	\N	EXCUSE	0
84195	84159	08010L	PARTICIPANT	\N	PRESENT	0
89555	89552	14030Q	PARTICIPANT	\N	PRESENT	0
90796	90764	08021P	PARTICIPANT	\N	PRESENT	0
84198	84159	98046X	PARTICIPANT	\N	PRESENT	0
84199	84159	11085T	PARTICIPANT	\N	PRESENT	0
84200	84159	08011M	PARTICIPANT	\N	PRESENT	0
84201	84159	08073C	PARTICIPANT	\N	PRESENT	0
84202	84159	08061X	PARTICIPANT	\N	PRESENT	0
90797	90764	04088S	PARTICIPANT	\N	PRESENT	0
84204	84159	14225N	PARTICIPANT	\N	PRESENT	0
84205	84159	11012A	PARTICIPANT	\N	PRESENT	0
90798	90764	98050T	PARTICIPANT	\N	PRESENT	0
84207	84159	14173T	PARTICIPANT	\N	PRESENT	0
84208	84159	04034C	PARTICIPANT	\N	PRESENT	0
90799	90764	11090Q	PARTICIPANT	\N	PRESENT	0
90800	90764	11046L	PARTICIPANT	\N	PRESENT	0
90801	90764	01058X	PARTICIPANT	\N	PRESENT	0
90802	90764	11094U	PARTICIPANT	\N	EXCUSE	0
90803	90764	11066Q	PARTICIPANT	\N	PRESENT	0
91294	90985	11107G	PARTICIPANT	\N	EXCUSE	0
91662	90265	04048J	PARTICIPANT	\N	PRESENT	0
91663	90265	11089X	PARTICIPANT	\N	PRESENT	0
91664	90265	14257W	PARTICIPANT	\N	PRESENT	0
91665	90265	11061K	PARTICIPANT	\N	PRESENT	0
91666	90265	08010L	PARTICIPANT	\N	PRESENT	0
91667	90265	11080N	PARTICIPANT	\N	PRESENT	0
91668	90265	14121F	PARTICIPANT	\N	PRESENT	0
91669	90265	04035D	PARTICIPANT	\N	PRESENT	0
91670	90265	01031L	PARTICIPANT	\N	PRESENT	0
91671	90265	14061L	PARTICIPANT	\N	PRESENT	0
91672	90265	14281W	PARTICIPANT	\N	PRESENT	0
91673	90265	04077P	PARTICIPANT	\N	PRESENT	0
91674	90265	07024N	PARTICIPANT	\N	PRESENT	0
91675	90265	08061X	PARTICIPANT	\N	PRESENT	0
91676	90265	11090Q	PARTICIPANT	\N	PRESENT	0
91677	90265	04053F	PARTICIPANT	\N	PRESENT	0
91678	90265	01028R	PARTICIPANT	\N	PRESENT	0
91679	90265	95035G	PARTICIPANT	\N	PRESENT	0
91680	90265	08038Y	PARTICIPANT	\N	PRESENT	0
91681	90265	99002P	PARTICIPANT	\N	PRESENT	0
91682	90265	14085U	PARTICIPANT	\N	PRESENT	0
91683	90265	04097T	PARTICIPANT	\N	PRESENT	0
91684	90265	11042G	PARTICIPANT	\N	PRESENT	0
91685	90265	14159V	PARTICIPANT	\N	PRESENT	0
91686	90265	04042C	PARTICIPANT	\N	PRESENT	0
91687	90265	14269B	PARTICIPANT	\N	PRESENT	0
91688	90265	11107G	PARTICIPANT	\N	PRESENT	0
91689	90265	12042Y	PARTICIPANT	\N	PRESENT	0
91690	90265	11037K	PARTICIPANT	\N	PRESENT	0
91691	90265	14037X	PARTICIPANT	\N	PRESENT	0
91692	90265	08073C	PARTICIPANT	\N	PRESENT	0
91693	90265	14195A	PARTICIPANT	\N	PRESENT	0
91694	90265	11113E	PARTICIPANT	\N	PRESENT	0
91695	90265	14039A	PARTICIPANT	\N	PRESENT	0
91696	90265	11109J	PARTICIPANT	\N	PRESENT	0
91697	90265	14271U	PARTICIPANT	\N	PRESENT	0
91698	90265	11096W	PARTICIPANT	\N	PRESENT	0
91699	90265	08031R	PARTICIPANT	\N	PRESENT	0
91700	90265	11074Q	PARTICIPANT	\N	PRESENT	0
91701	90265	11099A	PARTICIPANT	\N	PRESENT	0
91702	90265	14030Q	PARTICIPANT	\N	PRESENT	0
91703	90265	01034P	PARTICIPANT	\N	PRESENT	0
91704	90265	08009T	PARTICIPANT	\N	PRESENT	0
91705	90265	04080J	PARTICIPANT	\N	PRESENT	0
91706	90265	07004J	PARTICIPANT	\N	PRESENT	0
91707	90265	14042U	PARTICIPANT	\N	PRESENT	0
91708	90265	14103D	PARTICIPANT	\N	PRESENT	0
91709	90265	14213J	PARTICIPANT	\N	PRESENT	0
91710	90265	11026G	PARTICIPANT	\N	PRESENT	0
91711	90265	14089Y	PARTICIPANT	\N	PRESENT	0
91712	90265	11111C	PARTICIPANT	\N	PRESENT	0
91713	90265	04089T	PARTICIPANT	\N	PRESENT	0
91714	90265	11093T	PARTICIPANT	\N	PRESENT	0
91715	90265	04040A	PARTICIPANT	\N	PRESENT	0
91716	90265	11053K	PARTICIPANT	\N	PRESENT	0
91717	90265	14073Q	PARTICIPANT	\N	PRESENT	0
91718	90265	01024M	PARTICIPANT	\N	PRESENT	0
91719	90265	09001P	PARTICIPANT	\N	PRESENT	0
91720	90265	14055N	PARTICIPANT	\N	PRESENT	0
91721	90265	14034U	PARTICIPANT	\N	PRESENT	0
91722	90265	14209N	PARTICIPANT	\N	PRESENT	0
91726	90265	11077T	PARTICIPANT	\N	PRESENT	0
91724	90265	11085T	PARTICIPANT	\N	PRESENT	0
91725	90265	04061F	PARTICIPANT	\N	PRESENT	0
91727	90265	14093U	PARTICIPANT	\N	PRESENT	0
91728	90265	04044E	PARTICIPANT	\N	PRESENT	0
91729	90265	98023Q	PARTICIPANT	\N	PRESENT	0
91730	90265	11023D	PARTICIPANT	\N	PRESENT	0
91731	90265	01037S	PARTICIPANT	\N	PRESENT	0
91732	90265	92018S	PARTICIPANT	\N	PRESENT	0
91733	90265	01041N	PARTICIPANT	\N	PRESENT	0
91734	90265	11044J	PARTICIPANT	\N	PRESENT	0
91735	90265	08069G	PARTICIPANT	\N	PRESENT	0
91736	90265	14169X	PARTICIPANT	\N	PRESENT	0
91737	90265	11033F	PARTICIPANT	\N	PRESENT	0
91738	90265	11084S	PARTICIPANT	\N	PRESENT	0
91759	90265	11065P	PARTICIPANT	\N	PRESENT	0
64006	60592	14017T	PARTICIPANT	\N	EXCUSE	0
66163	66162	14261S	PARTICIPANT	\N	PRESENT	0
66164	66162	08055A	PARTICIPANT	\N	PRESENT	0
66165	66162	14093U	PARTICIPANT	\N	PRESENT	0
66166	66162	14030Q	PARTICIPANT	\N	PRESENT	0
66167	66162	08060W	PARTICIPANT	\N	PRESENT	0
66168	66162	11095V	PARTICIPANT	\N	PRESENT	0
66169	66162	14038Y	PARTICIPANT	\N	PRESENT	0
66170	66162	11114F	PARTICIPANT	\N	PRESENT	0
66171	66162	01015L	PARTICIPANT	\N	EXCUSE	0
66172	66162	11107G	PARTICIPANT	\N	PRESENT	0
66173	66162	02002K	PARTICIPANT	\N	PRESENT	0
66174	66162	09001P	PARTICIPANT	\N	PRESENT	0
66175	66162	14219Q	PARTICIPANT	\N	PRESENT	0
66176	66162	80027E	PARTICIPANT	\N	PRESENT	0
66177	66162	14031R	PARTICIPANT	\N	PRESENT	0
66178	66162	08009T	PARTICIPANT	\N	PRESENT	0
66179	66162	08062Y	PARTICIPANT	\N	PRESENT	0
66180	66162	14221J	PARTICIPANT	\N	PRESENT	0
66181	66162	08042U	PARTICIPANT	\N	PRESENT	0
66182	66162	14169X	PARTICIPANT	\N	PRESENT	0
66183	66162	14237S	PARTICIPANT	\N	PRESENT	0
66184	66162	13002U	PARTICIPANT	\N	PRESENT	0
66185	66162	05012A	PARTICIPANT	\N	PRESENT	0
66186	66162	14135M	PARTICIPANT	\N	PRESENT	0
66187	66162	14331P	PARTICIPANT	\N	PRESENT	0
66188	66162	95062K	PARTICIPANT	\N	PRESENT	0
66189	66162	14107H	PARTICIPANT	\N	PRESENT	0
66190	66162	14051J	PARTICIPANT	\N	PRESENT	0
66191	66162	14157T	PARTICIPANT	\N	PRESENT	0
66192	66162	96003C	PARTICIPANT	\N	EXCUSE	0
66193	66162	08049C	PARTICIPANT	\N	PRESENT	0
66194	66162	14173T	PARTICIPANT	\N	PRESENT	0
66195	66162	14033T	PARTICIPANT	\N	PRESENT	0
66196	66162	11097X	PARTICIPANT	\N	PRESENT	0
66870	66869	00003C	PARTICIPANT	\N	PRESENT	0
66871	66869	14071N	PARTICIPANT	\N	PRESENT	0
68252	68251	04085P	PARTICIPANT	\N	PRESENT	0
68253	68251	05008E	PRESIDENT	0	PRESENT	0
68254	68251	11033F	PARTICIPANT	\N	PRESENT	0
68255	68251	14065Q	PARTICIPANT	\N	PRESENT	0
68256	68251	04038G	PARTICIPANT	\N	PRESENT	0
68257	68251	11035H	PARTICIPANT	\N	PRESENT	0
68259	68251	01024M	PARTICIPANT	\N	PRESENT	0
68260	68251	14215L	PARTICIPANT	\N	PRESENT	0
68261	68251	01007L	PARTICIPANT	\N	PRESENT	0
68262	68251	08044W	PARTICIPANT	\N	PRESENT	0
68263	68251	11026G	PARTICIPANT	\N	PRESENT	0
68264	68251	14273W	PARTICIPANT	\N	PRESENT	0
68265	68251	95049N	PARTICIPANT	\N	PRESENT	0
68266	68251	08051V	PARTICIPANT	\N	PRESENT	0
68267	68251	07034Q	PARTICIPANT	\N	PRESENT	0
68268	68251	04074L	PARTICIPANT	\N	PRESENT	0
68269	68251	10015M	PARTICIPANT	\N	PRESENT	0
68270	68251	95063L	PARTICIPANT	\N	PRESENT	0
68271	68251	01028R	PARTICIPANT	\N	PRESENT	0
68272	68251	11037K	PARTICIPANT	\N	PRESENT	0
68273	68251	92045V	PARTICIPANT	\N	PRESENT	0
68274	68251	01047U	PARTICIPANT	\N	PRESENT	0
68275	68251	04056J	PARTICIPANT	\N	PRESENT	0
72040	72035	14167V	PARTICIPANT	\N	PRESENT	0
72037	72035	01057W	PARTICIPANT	\N	PRESENT	0
72038	72035	14225N	PARTICIPANT	\N	PRESENT	0
72039	72035	01013J	PARTICIPANT	\N	PRESENT	0
72041	72035	11070L	PARTICIPANT	\N	PRESENT	0
72042	72035	11088W	PARTICIPANT	\N	PRESENT	0
72043	72035	14327T	PARTICIPANT	\N	PRESENT	0
72044	72035	14199E	PARTICIPANT	\N	PRESENT	0
72045	72035	98046X	PARTICIPANT	\N	PRESENT	0
72046	72035	08073C	PARTICIPANT	\N	PRESENT	0
72263	71331	14053L	PARTICIPANT	\N	EXCUSE	0
75523	75219	04066L	PARTICIPANT	\N	PRESENT	0
75524	75219	92040Q	PARTICIPANT	\N	PRESENT	0
75525	75219	01011G	PARTICIPANT	\N	PRESENT	0
75526	75219	14119M	PARTICIPANT	\N	PRESENT	0
75527	75219	11084S	PARTICIPANT	\N	PRESENT	0
75529	75219	14135M	PARTICIPANT	\N	PRESENT	0
75530	75219	95035G	PARTICIPANT	\N	PRESENT	0
75531	75219	11089X	PARTICIPANT	\N	PRESENT	0
75532	75219	14037X	PARTICIPANT	\N	PRESENT	0
75534	75219	04047H	PARTICIPANT	\N	PRESENT	0
75535	75219	10015M	PARTICIPANT	\N	PRESENT	0
75536	75219	08012N	PARTICIPANT	\N	PRESENT	0
75537	75219	80027E	PARTICIPANT	\N	PRESENT	0
75538	75219	04079R	PARTICIPANT	\N	PRESENT	0
75539	75219	14053L	PARTICIPANT	\N	PRESENT	0
75540	75219	95037J	PARTICIPANT	\N	PRESENT	0
75541	75219	77002U	PARTICIPANT	\N	PRESENT	0
75543	75219	08058D	PARTICIPANT	\N	PRESENT	0
75544	75219	83047W	PARTICIPANT	\N	PRESENT	0
75547	75219	14227Q	PARTICIPANT	\N	PRESENT	0
75548	75219	14253S	PARTICIPANT	\N	PRESENT	0
75549	75219	14229S	PARTICIPANT	\N	PRESENT	0
75550	75219	14281W	PARTICIPANT	\N	PRESENT	0
75551	75219	11046L	PARTICIPANT	\N	PRESENT	0
75552	75219	11026G	PARTICIPANT	\N	PRESENT	0
75553	75219	14121F	PARTICIPANT	\N	PRESENT	0
75554	75219	08022Q	PARTICIPANT	\N	PRESENT	0
75555	75219	11074Q	PARTICIPANT	\N	PRESENT	0
75556	75219	11027H	PARTICIPANT	\N	PRESENT	0
75557	75219	14217N	PARTICIPANT	\N	PRESENT	0
75558	75219	14147R	PARTICIPANT	\N	PRESENT	0
75559	75219	14257W	PARTICIPANT	\N	PRESENT	0
75560	75219	11014C	PARTICIPANT	\N	PRESENT	0
75561	75219	99002P	PARTICIPANT	\N	PRESENT	0
75562	75219	14109K	PARTICIPANT	\N	PRESENT	0
75563	75219	14207L	PARTICIPANT	\N	PRESENT	0
75564	75219	14329V	PARTICIPANT	\N	PRESENT	0
75565	75219	14105F	PARTICIPANT	\N	PRESENT	0
75566	75219	11095V	PARTICIPANT	\N	PRESENT	0
75567	75219	14001X	PARTICIPANT	\N	PRESENT	0
75568	75219	05004A	PARTICIPANT	\N	PRESENT	0
75569	75219	05012A	PARTICIPANT	\N	PRESENT	0
75570	75219	04074L	PARTICIPANT	\N	PRESENT	0
75571	75219	14133K	PARTICIPANT	\N	PRESENT	0
75572	75219	14063N	PARTICIPANT	\N	PRESENT	0
75573	75219	01008M	PARTICIPANT	\N	PRESENT	0
75574	75219	83042R	PARTICIPANT	\N	PRESENT	0
75575	75219	14199E	PARTICIPANT	\N	PRESENT	0
75576	75219	11015D	PARTICIPANT	\N	PRESENT	0
75577	75219	08043V	PARTICIPANT	\N	PRESENT	0
75578	75219	11036J	PARTICIPANT	\N	PRESENT	0
75580	75219	11101A	PARTICIPANT	\N	PRESENT	0
75581	75219	80013X	PARTICIPANT	\N	PRESENT	0
75583	75219	14195A	PARTICIPANT	\N	PRESENT	0
75584	75219	11066Q	PARTICIPANT	\N	PRESENT	0
75585	75219	04077P	PARTICIPANT	\N	PRESENT	0
75586	75219	08061X	PARTICIPANT	\N	PRESENT	0
75587	75219	10006L	PARTICIPANT	\N	PRESENT	0
75588	75219	86044G	PARTICIPANT	\N	PRESENT	0
75589	75219	04053F	PARTICIPANT	\N	PRESENT	0
75590	75219	08073C	PARTICIPANT	\N	PRESENT	0
75591	75219	11020A	PARTICIPANT	\N	PRESENT	0
75592	75219	01028R	PARTICIPANT	\N	PRESENT	0
75593	75219	11104D	PARTICIPANT	\N	PRESENT	0
75594	75219	04057K	PARTICIPANT	\N	PRESENT	0
75595	75219	11110B	PARTICIPANT	\N	PRESENT	0
75596	75219	01057W	PARTICIPANT	\N	PRESENT	0
75598	75219	11032E	PARTICIPANT	\N	PRESENT	0
75599	75219	08024S	PARTICIPANT	\N	PRESENT	0
75600	75219	11071M	PARTICIPANT	\N	PRESENT	0
75601	75219	04059M	PARTICIPANT	\N	PRESENT	0
75602	75219	11048N	PARTICIPANT	\N	PRESENT	0
75603	75219	11061K	PARTICIPANT	\N	PRESENT	0
75604	75219	04061F	PARTICIPANT	\N	PRESENT	0
75605	75219	11106F	PARTICIPANT	\N	PRESENT	0
75606	75219	04035D	PARTICIPANT	\N	PRESENT	0
75607	75219	11067R	PARTICIPANT	\N	PRESENT	0
75608	75219	04049K	PARTICIPANT	\N	PRESENT	0
75609	75219	14014Q	PARTICIPANT	\N	PRESENT	0
75610	75219	11077T	PARTICIPANT	\N	PRESENT	0
75619	75219	13002U	PARTICIPANT	\N	PRESENT	0
75612	75219	04095R	PARTICIPANT	\N	PRESENT	0
75613	75219	11109J	PARTICIPANT	\N	PRESENT	0
75615	75219	98005N	PARTICIPANT	\N	PRESENT	0
75618	75219	11012A	PARTICIPANT	\N	PRESENT	0
75620	75219	11114F	PARTICIPANT	\N	PRESENT	0
75621	75219	08035V	PARTICIPANT	\N	PRESENT	0
75622	75219	11072N	PARTICIPANT	\N	PRESENT	0
75623	75219	14173T	PARTICIPANT	\N	PRESENT	0
75624	75219	01014K	PARTICIPANT	\N	PRESENT	0
75625	75219	14269B	PARTICIPANT	\N	PRESENT	0
75626	75219	98021N	PARTICIPANT	\N	PRESENT	0
75627	75219	11076S	PARTICIPANT	\N	PRESENT	0
75629	75219	14069U	PARTICIPANT	\N	PRESENT	0
75630	75219	11083R	PARTICIPANT	\N	PRESENT	0
75631	75219	14237S	PARTICIPANT	\N	PRESENT	0
75635	75219	11096W	PARTICIPANT	\N	PRESENT	0
77815	75076	14201E	PARTICIPANT	\N	EXCUSE	0
77817	77816	05008E	PRESIDENT	0	PRESENT	0
77818	77816	11033F	PARTICIPANT	\N	PRESENT	0
77819	77816	14065Q	PARTICIPANT	\N	PRESENT	0
77820	77816	14069U	PARTICIPANT	\N	PRESENT	0
77821	77816	04047H	PARTICIPANT	\N	PRESENT	0
77822	77816	04038G	PARTICIPANT	\N	PRESENT	0
77823	77816	11056N	PARTICIPANT	\N	PRESENT	0
77824	77816	14041T	PARTICIPANT	\N	PRESENT	0
77825	77816	01024M	PARTICIPANT	\N	PRESENT	0
77826	77816	14215L	PARTICIPANT	\N	PRESENT	0
77827	77816	11049P	PARTICIPANT	\N	PRESENT	0
77828	77816	11026G	PARTICIPANT	\N	PRESENT	0
77829	77816	14111D	PARTICIPANT	\N	PRESENT	0
77833	77816	07034Q	PARTICIPANT	\N	PRESENT	0
77831	77816	14273W	PARTICIPANT	\N	PRESENT	0
77832	77816	95049N	PARTICIPANT	\N	PRESENT	0
77834	77816	04074L	PARTICIPANT	\N	PRESENT	0
77835	77816	95063L	PARTICIPANT	\N	PRESENT	0
77836	77816	01028R	PARTICIPANT	\N	PRESENT	0
77837	77816	98035U	PARTICIPANT	\N	PRESENT	0
77838	77816	04044E	PRESIDENT	1	PRESENT	0
77839	77816	01047U	PARTICIPANT	\N	PRESENT	0
77923	77580	11026G	PARTICIPANT	\N	PRESENT	0
77924	77580	14219Q	PARTICIPANT	\N	PRESENT	0
77925	77580	92020L	PARTICIPANT	\N	PRESENT	0
77926	77580	14281W	PARTICIPANT	\N	PRESENT	0
77927	77580	14097Y	PARTICIPANT	\N	PRESENT	0
77928	75076	11106F	PARTICIPANT	\N	EXCUSE	0
77929	77580	14042U	PARTICIPANT	\N	PRESENT	0
77930	77580	95062K	PARTICIPANT	\N	PRESENT	0
77931	77580	14038Y	PARTICIPANT	\N	PRESENT	0
77932	77580	11031D	PARTICIPANT	\N	PRESENT	0
77933	77580	04088S	PARTICIPANT	\N	PRESENT	0
77934	77580	14199E	PARTICIPANT	\N	PRESENT	0
77935	77580	08069G	PARTICIPANT	\N	PRESENT	0
77938	77580	08053X	PARTICIPANT	\N	PRESENT	0
77940	77580	11091R	PARTICIPANT	\N	PRESENT	0
77948	77580	14073Q	PARTICIPANT	\N	PRESENT	0
77953	77580	95015C	PARTICIPANT	\N	PRESENT	0
77959	77580	14063N	PARTICIPANT	\N	PRESENT	0
77964	77580	14331P	PARTICIPANT	\N	PRESENT	0
77965	77580	11104D	PARTICIPANT	\N	PRESENT	0
77966	77580	11036J	PARTICIPANT	\N	PRESENT	0
77967	77580	14229S	PARTICIPANT	\N	PRESENT	0
77968	77580	08017T	PARTICIPANT	\N	PRESENT	0
77972	77580	14241N	PARTICIPANT	\N	PRESENT	0
77978	77580	04057K	PARTICIPANT	\N	PRESENT	0
77979	77580	04041B	PARTICIPANT	\N	PRESENT	0
77980	77580	13002U	PARTICIPANT	\N	PRESENT	0
77981	77580	14034U	PARTICIPANT	\N	PRESENT	0
77982	77580	08016S	PARTICIPANT	\N	PRESENT	0
77983	77580	14107H	PARTICIPANT	\N	PRESENT	0
77985	77580	14059S	PARTICIPANT	\N	PRESENT	0
77986	77580	08015R	PARTICIPANT	\N	PRESENT	0
77987	77580	14123H	PARTICIPANT	\N	PRESENT	0
77988	77580	14105F	PARTICIPANT	\N	PRESENT	0
77989	77580	11093T	PARTICIPANT	\N	PRESENT	0
77990	77580	14273W	PARTICIPANT	\N	PRESENT	0
77991	77580	14267Y	PARTICIPANT	\N	PRESENT	0
77992	77580	14179A	PARTICIPANT	\N	PRESENT	0
77993	77580	95059Q	PARTICIPANT	\N	PRESENT	0
77994	77580	08062Y	PARTICIPANT	\N	PRESENT	0
77995	77580	14251Q	PARTICIPANT	\N	PRESENT	0
77996	77580	14231L	PARTICIPANT	\N	PRESENT	0
77997	77580	14089Y	PARTICIPANT	\N	PRESENT	0
77998	77580	01025N	PARTICIPANT	\N	PRESENT	0
77999	77580	14221J	PARTICIPANT	\N	PRESENT	0
78000	77580	14111D	PARTICIPANT	\N	PRESENT	0
78001	77580	14119M	PARTICIPANT	\N	PRESENT	0
78002	77580	01027Q	PARTICIPANT	\N	PRESENT	0
78003	77580	14037X	PARTICIPANT	\N	PRESENT	0
78004	77580	14071N	PARTICIPANT	\N	PRESENT	0
78005	77580	08009T	PARTICIPANT	\N	PRESENT	0
78006	77580	01034P	PARTICIPANT	\N	PRESENT	0
78007	77580	14069U	PARTICIPANT	\N	PRESENT	0
78008	77580	95067Q	PARTICIPANT	\N	PRESENT	0
78009	77580	11077T	PARTICIPANT	\N	PRESENT	0
78010	77580	11037K	PARTICIPANT	\N	PRESENT	0
78022	77580	14195A	PARTICIPANT	\N	PRESENT	0
78023	77580	11097X	PARTICIPANT	\N	PRESENT	0
78024	77580	11098Y	PARTICIPANT	\N	PRESENT	0
78025	77580	11042G	PARTICIPANT	\N	PRESENT	0
78026	77580	08010L	PARTICIPANT	\N	PRESENT	0
78027	77580	04049K	PARTICIPANT	\N	PRESENT	0
78028	77580	14173T	PARTICIPANT	\N	PRESENT	0
78032	77580	01008M	PARTICIPANT	\N	PRESENT	0
78033	77580	90003B	PARTICIPANT	\N	PRESENT	0
78034	77580	14215L	PARTICIPANT	\N	PRESENT	0
78035	77580	01007L	PARTICIPANT	\N	PRESENT	0
78036	77580	14265W	PARTICIPANT	\N	PRESENT	0
78037	77580	07034Q	PARTICIPANT	\N	PRESENT	0
78038	77580	01057W	PARTICIPANT	\N	PRESENT	0
78039	77580	08034U	PARTICIPANT	\N	PRESENT	0
78040	77580	80013X	PARTICIPANT	\N	PRESENT	0
78041	77580	14211G	PARTICIPANT	\N	PRESENT	0
78042	77580	14121F	PARTICIPANT	\N	PRESENT	0
78043	77580	01022K	PARTICIPANT	\N	PRESENT	0
78044	77580	14033T	PARTICIPANT	\N	PRESENT	0
78045	77580	01031L	PARTICIPANT	\N	PRESENT	0
78046	77580	04059M	PARTICIPANT	\N	PRESENT	0
78047	77580	14159V	PARTICIPANT	\N	PRESENT	0
78048	77580	14157T	PARTICIPANT	\N	PRESENT	0
78066	77580	10015M	PARTICIPANT	\N	PRESENT	0
78067	77580	89017R	PARTICIPANT	\N	PRESENT	0
78070	77580	14191V	PARTICIPANT	\N	PRESENT	0
78073	77580	88008L	PARTICIPANT	\N	PRESENT	0
78074	77580	11105E	PARTICIPANT	\N	PRESENT	0
78075	77580	01016M	PARTICIPANT	\N	PRESENT	0
78076	77580	08056B	PARTICIPANT	\N	PRESENT	0
78077	77580	04047H	PARTICIPANT	\N	PRESENT	0
78078	77580	14031R	PARTICIPANT	\N	PRESENT	0
78079	77580	11100Y	PARTICIPANT	\N	PRESENT	0
78080	77580	87003B	PARTICIPANT	\N	PRESENT	0
78081	77580	04045F	PARTICIPANT	\N	PRESENT	0
78082	77580	14223L	PARTICIPANT	\N	PRESENT	0
78155	77581	04066L	PARTICIPANT	\N	PRESENT	0
78156	77581	05008E	PARTICIPANT	\N	PRESENT	0
78157	77581	95049N	PARTICIPANT	\N	PRESENT	0
78158	77581	14065Q	PARTICIPANT	\N	PRESENT	0
78159	77581	14257W	PARTICIPANT	\N	PRESENT	0
78160	77581	11056N	PARTICIPANT	\N	PRESENT	0
78161	77581	11098Y	PARTICIPANT	\N	PRESENT	0
78162	77581	14157T	PARTICIPANT	\N	PRESENT	0
78163	77581	14031R	PARTICIPANT	\N	PRESENT	0
78164	77581	14265W	PARTICIPANT	\N	PRESENT	0
78165	77581	04033B	PARTICIPANT	\N	PRESENT	0
78166	77581	04047H	PARTICIPANT	\N	PRESENT	0
78167	77581	01025N	PARTICIPANT	\N	PRESENT	0
78168	77581	08043V	PARTICIPANT	\N	PRESENT	0
78169	77581	14097Y	PARTICIPANT	\N	PRESENT	0
78170	77581	08047A	PARTICIPANT	\N	PRESENT	0
78171	77581	95063L	PARTICIPANT	\N	PRESENT	0
78172	77581	11033F	PARTICIPANT	\N	PRESENT	0
78173	77581	14089Y	PARTICIPANT	\N	PRESENT	0
78174	77581	14273W	PARTICIPANT	\N	PRESENT	0
78175	77581	14079W	PARTICIPANT	\N	PRESENT	0
78176	77581	11048N	PARTICIPANT	\N	PRESENT	0
78177	77581	14038Y	PARTICIPANT	\N	PRESENT	0
78178	77581	14211G	PARTICIPANT	\N	PRESENT	0
78179	77581	04056J	PARTICIPANT	\N	PRESENT	0
78180	77581	08051V	PARTICIPANT	\N	PRESENT	0
78181	77581	01046T	PARTICIPANT	\N	PRESENT	0
78182	77581	14053L	PARTICIPANT	\N	PRESENT	0
78183	77581	14059S	PARTICIPANT	\N	PRESENT	0
78184	77581	14215L	PARTICIPANT	\N	PRESENT	0
78185	77581	08022Q	PARTICIPANT	\N	PRESENT	0
78186	77581	04071H	PARTICIPANT	\N	PRESENT	0
78187	77581	11049P	PARTICIPANT	\N	PRESENT	0
78188	77581	08048B	PARTICIPANT	\N	PRESENT	0
78189	77581	14133K	PARTICIPANT	\N	PRESENT	0
78190	77581	01057W	PARTICIPANT	\N	PRESENT	0
78191	77581	14169X	PARTICIPANT	\N	PRESENT	0
78192	77581	11026G	PARTICIPANT	\N	PRESENT	0
78193	77581	14187A	PARTICIPANT	\N	PRESENT	0
78194	77581	14223L	PARTICIPANT	\N	PRESENT	0
78195	77581	97011G	PARTICIPANT	\N	PRESENT	0
78196	77581	14195A	PARTICIPANT	\N	PRESENT	0
78197	77581	14033T	PARTICIPANT	\N	PRESENT	0
78198	77581	04088S	PARTICIPANT	\N	PRESENT	0
78199	77581	14217N	PARTICIPANT	\N	PRESENT	0
78200	77581	92031P	PARTICIPANT	\N	PRESENT	0
78201	77581	14263U	PARTICIPANT	\N	PRESENT	0
78202	77581	01016M	PARTICIPANT	\N	PRESENT	0
78203	77581	14259Y	PARTICIPANT	\N	PRESENT	0
78204	77581	11097X	PARTICIPANT	\N	PRESENT	0
78205	77581	01047U	PARTICIPANT	\N	PRESENT	0
78206	77581	01027Q	PARTICIPANT	\N	PRESENT	0
78207	77581	10015M	PARTICIPANT	\N	PRESENT	0
62214	62213	89017R	PARTICIPANT	\N	PRESENT	0
62215	62213	01031L	PARTICIPANT	\N	EXCUSE	0
62216	62213	05004A	PARTICIPANT	\N	PRESENT	0
62217	62213	01013J	PARTICIPANT	\N	PRESENT	0
62218	62213	11068S	PARTICIPANT	\N	PRESENT	0
62219	62213	11040E	PARTICIPANT	\N	PRESENT	0
62220	62213	08014Q	PARTICIPANT	\N	PRESENT	0
62221	62213	14083S	PARTICIPANT	\N	PRESENT	0
62222	62213	11053K	PARTICIPANT	\N	PRESENT	0
62223	62213	14085U	PARTICIPANT	\N	PRESENT	0
62224	62213	11042G	PARTICIPANT	\N	PRESENT	0
62225	62213	88008L	PARTICIPANT	\N	PRESENT	0
62226	62213	04086Q	PARTICIPANT	\N	PRESENT	0
62227	62213	11070L	PRESIDENT	0	PRESENT	0
62228	62213	11088W	PARTICIPANT	\N	PRESENT	0
62229	62213	14327T	PARTICIPANT	\N	PRESENT	0
62230	62213	08022Q	PARTICIPANT	\N	PRESENT	0
62231	62213	01027Q	PARTICIPANT	\N	PRESENT	0
62232	62213	11074Q	PARTICIPANT	\N	PRESENT	0
62233	62213	98053W	PARTICIPANT	\N	PRESENT	0
62234	62213	11083R	PARTICIPANT	\N	PRESENT	0
62235	62213	14199E	PARTICIPANT	\N	PRESENT	0
62236	62213	01057W	PARTICIPANT	\N	PRESENT	0
62237	62213	08016S	PARTICIPANT	\N	PRESENT	0
62238	62213	08069G	PARTICIPANT	\N	PRESENT	0
62239	62213	11048N	PARTICIPANT	\N	PRESENT	0
62240	62213	99004R	PARTICIPANT	\N	PRESENT	0
62241	62213	04061F	PARTICIPANT	\N	PRESENT	0
62242	62213	14159V	PARTICIPANT	\N	PRESENT	0
62243	62213	07029T	PARTICIPANT	\N	PRESENT	0
62244	62213	98046X	PARTICIPANT	\N	PRESENT	0
62245	62213	11085T	PARTICIPANT	\N	PRESENT	0
62246	62213	08011M	PARTICIPANT	\N	PRESENT	0
62247	62213	08073C	PARTICIPANT	\N	PRESENT	0
62248	62213	08061X	PARTICIPANT	\N	PRESENT	0
62249	62213	01016M	PARTICIPANT	\N	PRESENT	0
62250	62213	14225N	PARTICIPANT	\N	PRESENT	0
62251	62213	11012A	PARTICIPANT	\N	PRESENT	0
62252	62213	11057P	PARTICIPANT	\N	PRESENT	0
62253	62213	14173T	PARTICIPANT	\N	PRESENT	0
62254	62213	04034C	PARTICIPANT	\N	PRESENT	0
62255	62213	08034U	PARTICIPANT	\N	PRESENT	0
62257	62256	01031L	PARTICIPANT	\N	EXCUSE	0
62258	62256	01013J	PARTICIPANT	\N	PRESENT	0
62259	62256	11068S	PARTICIPANT	\N	PRESENT	0
62260	62256	08014Q	PARTICIPANT	\N	PRESENT	0
62261	62256	14083S	PARTICIPANT	\N	PRESENT	0
62262	62256	11053K	PARTICIPANT	\N	PRESENT	0
62263	62256	14085U	PARTICIPANT	\N	PRESENT	0
62264	62256	11042G	PARTICIPANT	\N	PRESENT	0
62265	62256	04086Q	PARTICIPANT	\N	PRESENT	0
62266	62256	11070L	PRESIDENT	0	PRESENT	0
62267	62256	11088W	PARTICIPANT	\N	PRESENT	0
62268	62256	14327T	PARTICIPANT	\N	PRESENT	0
62269	62256	08022Q	PARTICIPANT	\N	PRESENT	0
62270	62256	01027Q	PARTICIPANT	\N	PRESENT	0
62271	62256	04071H	PARTICIPANT	\N	PRESENT	0
62272	62256	11074Q	PARTICIPANT	\N	PRESENT	0
62273	62256	11083R	PARTICIPANT	\N	PRESENT	0
62274	62256	01057W	PARTICIPANT	\N	PRESENT	0
62275	62256	08069G	PARTICIPANT	\N	PRESENT	0
62276	62256	99004R	PARTICIPANT	\N	PRESENT	0
62277	62256	04061F	PARTICIPANT	\N	PRESENT	0
62278	62256	14159V	PARTICIPANT	\N	PRESENT	0
62279	62256	07029T	PARTICIPANT	\N	PRESENT	0
62280	62256	01048V	PARTICIPANT	\N	PRESENT	0
62281	62256	11085T	PARTICIPANT	\N	PRESENT	0
62282	62256	08011M	PARTICIPANT	\N	PRESENT	0
62283	62256	08061X	PARTICIPANT	\N	PRESENT	0
62284	62256	01016M	PARTICIPANT	\N	PRESENT	0
62285	62256	14225N	PARTICIPANT	\N	PRESENT	0
62286	62256	11012A	PARTICIPANT	\N	PRESENT	0
62287	62256	11057P	PARTICIPANT	\N	PRESENT	0
69173	69172	11076S	PARTICIPANT	\N	PRESENT	0
69174	69172	04054G	PARTICIPANT	\N	PRESENT	0
69175	69172	04040A	PARTICIPANT	\N	PRESENT	0
69176	69172	08058D	PARTICIPANT	\N	PRESENT	0
69177	69172	04042C	PARTICIPANT	\N	PRESENT	0
69230	69172	98018T	PARTICIPANT	\N	PRESENT	0
69179	69172	98029W	PARTICIPANT	\N	PRESENT	0
69355	69354	04040A	PARTICIPANT	\N	PRESENT	0
69399	69398	05012A	PARTICIPANT	\N	PRESENT	0
69401	69400	05012A	PARTICIPANT	\N	PRESENT	0
69183	69172	92018S	PARTICIPANT	\N	PRESENT	0
69184	69172	92020L	PARTICIPANT	\N	PRESENT	0
69403	69402	14038Y	PARTICIPANT	\N	PRESENT	0
69405	69404	14038Y	PARTICIPANT	\N	PRESENT	0
69491	66808	14221J	PARTICIPANT	\N	EXCUSE	0
69188	69172	97011G	PARTICIPANT	\N	PRESENT	0
69189	69172	08065C	PARTICIPANT	\N	EXCUSE	0
69190	69172	04035D	PARTICIPANT	\N	PRESENT	0
69191	69172	07024N	PARTICIPANT	\N	PRESENT	0
71431	71343	04095R	PARTICIPANT	\N	PRESENT	0
69193	69172	14014Q	PARTICIPANT	\N	PRESENT	0
69194	69172	11015D	PARTICIPANT	\N	PRESENT	0
71705	71704	11044J	PARTICIPANT	\N	PRESENT	0
69196	69172	95035G	PARTICIPANT	\N	PRESENT	0
69197	69172	08056B	PARTICIPANT	\N	PRESENT	0
69198	69172	14211G	PARTICIPANT	\N	PRESENT	0
71706	71704	11067R	PARTICIPANT	\N	PRESENT	0
69200	69172	11064N	PARTICIPANT	\N	PRESENT	0
69201	69172	95037J	PARTICIPANT	\N	PRESENT	0
69202	69172	04078Q	PARTICIPANT	\N	PRESENT	0
69203	69172	14097Y	PARTICIPANT	\N	PRESENT	0
71708	71707	11044J	PARTICIPANT	\N	PRESENT	0
69205	69172	04036E	PARTICIPANT	\N	PRESENT	0
69206	69172	14039A	PARTICIPANT	\N	PRESENT	0
71709	71707	11067R	PARTICIPANT	\N	PRESENT	0
80451	80436	04056J	PARTICIPANT	\N	PRESENT	0
69209	69172	92031P	PARTICIPANT	\N	PRESENT	0
69210	69172	11106F	PARTICIPANT	\N	PRESENT	0
69211	69172	14251Q	PARTICIPANT	\N	PRESENT	0
69212	69172	83042R	PARTICIPANT	\N	PRESENT	0
69213	69172	08053X	PARTICIPANT	\N	PRESENT	0
69214	69172	11082Q	PARTICIPANT	\N	PRESENT	0
69215	69172	11105E	PARTICIPANT	\N	PRESENT	0
69216	69172	14253S	PARTICIPANT	\N	PRESENT	0
80452	80436	04044E	PARTICIPANT	\N	PRESENT	0
69218	69172	14028W	PARTICIPANT	\N	PRESENT	0
80453	80436	11037K	PARTICIPANT	\N	PRESENT	0
69220	69172	98021N	PARTICIPANT	\N	EXCUSE	0
80454	80436	95067Q	PARTICIPANT	\N	PRESENT	0
69222	69172	04080J	PARTICIPANT	\N	PRESENT	0
69223	69172	95059Q	PRESIDENT	0	PRESENT	0
69224	69172	86044G	PARTICIPANT	\N	PRESENT	0
69225	69172	01014K	PARTICIPANT	\N	PRESENT	0
69226	69172	11054L	PARTICIPANT	\N	PRESENT	0
69227	69172	01056V	PARTICIPANT	\N	PRESENT	0
80455	80436	04057K	PARTICIPANT	\N	PRESENT	0
80472	80471	04057K	PARTICIPANT	\N	PRESENT	0
80474	80473	11104D	PARTICIPANT	\N	PRESENT	0
80476	80475	04057K	PARTICIPANT	\N	PRESENT	0
80478	80477	04057K	PARTICIPANT	\N	PRESENT	0
80480	80479	04057K	PARTICIPANT	\N	PRESENT	0
80482	80481	04057K	PARTICIPANT	\N	PRESENT	0
80484	80483	04057K	PARTICIPANT	\N	PRESENT	0
80486	80485	11104D	PARTICIPANT	\N	PRESENT	0
80487	80485	14061L	PARTICIPANT	\N	PRESENT	0
80489	80488	04057K	PARTICIPANT	\N	PRESENT	0
80491	80490	04057K	PARTICIPANT	\N	PRESENT	0
80493	80492	04070G	PARTICIPANT	\N	PRESENT	0
80495	80494	04057K	PARTICIPANT	\N	PRESENT	0
80497	80496	04057K	PARTICIPANT	\N	PRESENT	0
80499	80498	04057K	PARTICIPANT	\N	PRESENT	0
80501	80500	04070G	PARTICIPANT	\N	PRESENT	0
80503	80502	04070G	PARTICIPANT	\N	PRESENT	0
80505	80504	04070G	PARTICIPANT	\N	PRESENT	0
80628	80626	11039M	PARTICIPANT	\N	PRESENT	0
80629	80626	14073Q	PARTICIPANT	\N	PRESENT	0
80630	80626	08012N	PARTICIPANT	\N	PRESENT	0
80632	80626	14235Q	PARTICIPANT	\N	PRESENT	0
80633	80626	87003B	PARTICIPANT	\N	PRESENT	0
80635	80626	14191V	PARTICIPANT	\N	PRESENT	0
80636	80626	11043H	PARTICIPANT	\N	PRESENT	0
80637	80626	14241N	PARTICIPANT	\N	PRESENT	0
80658	80626	14329V	PARTICIPANT	\N	EXCUSE	0
80645	80626	14263U	PARTICIPANT	\N	EXCUSE	0
80646	80626	14133K	PARTICIPANT	\N	EXCUSE	0
80647	80626	11109J	PARTICIPANT	\N	EXCUSE	0
80648	80626	04059M	PARTICIPANT	\N	EXCUSE	0
80649	80626	01044R	PARTICIPANT	\N	EXCUSE	0
80650	80626	08043V	PARTICIPANT	\N	EXCUSE	0
80651	80626	14089Y	PARTICIPANT	\N	EXCUSE	0
80652	80626	14105F	PARTICIPANT	\N	EXCUSE	0
80653	80626	11029K	PARTICIPANT	\N	EXCUSE	0
80654	80626	95015C	PARTICIPANT	\N	EXCUSE	0
80655	80626	92015P	PARTICIPANT	\N	EXCUSE	0
80656	80626	08024S	PARTICIPANT	\N	EXCUSE	0
80657	80626	14201E	PARTICIPANT	\N	EXCUSE	0
83857	83856	14037X	PARTICIPANT	\N	PRESENT	0
83858	83856	14034U	PARTICIPANT	\N	PRESENT	0
83859	83856	14087W	PARTICIPANT	\N	PRESENT	0
83863	83862	14037X	PARTICIPANT	\N	PRESENT	0
83864	83862	14034U	PARTICIPANT	\N	PRESENT	0
83865	83862	14087W	PARTICIPANT	\N	PRESENT	0
87094	87093	04080J	PARTICIPANT	\N	PRESENT	0
89175	89174	14259Y	PARTICIPANT	\N	PRESENT	0
89176	89174	14273W	PARTICIPANT	\N	PRESENT	0
90533	90499	14253S	PARTICIPANT	\N	PRESENT	0
90368	90365	08055A	PARTICIPANT	\N	PRESENT	0
90369	90365	14093U	PARTICIPANT	\N	PRESENT	0
90370	90365	14030Q	PARTICIPANT	\N	PRESENT	0
90371	90365	96004D	PARTICIPANT	\N	PRESENT	0
90372	90365	08060W	PARTICIPANT	\N	PRESENT	0
90534	90499	08047A	PARTICIPANT	\N	PRESENT	0
90374	90365	14038Y	PARTICIPANT	\N	PRESENT	0
90375	90365	11114F	PARTICIPANT	\N	PRESENT	0
90535	90499	14028W	PARTICIPANT	\N	PRESENT	0
90536	90499	14193X	PARTICIPANT	\N	EXCUSE	0
90377	90365	11065P	PARTICIPANT	\N	PRESENT	0
90378	90365	01015L	PARTICIPANT	\N	PRESENT	0
90379	90365	11107G	PARTICIPANT	\N	PRESENT	0
90380	90365	11020A	PARTICIPANT	\N	PRESENT	0
90381	90365	02002K	PARTICIPANT	\N	PRESENT	0
90382	90365	01022K	PARTICIPANT	\N	PRESENT	0
90383	90365	04097T	PARTICIPANT	\N	PRESENT	0
90384	90365	09001P	PARTICIPANT	\N	PRESENT	0
90385	90365	11059R	PARTICIPANT	\N	PRESENT	0
90386	90365	14219Q	PARTICIPANT	\N	PRESENT	0
90387	90365	80027E	PARTICIPANT	\N	PRESENT	0
90388	90365	14031R	PARTICIPANT	\N	PRESENT	0
90389	90365	08009T	PRESIDENT	0	PRESENT	0
90537	90499	98021N	PARTICIPANT	\N	EXCUSE	0
90391	90365	14221J	PARTICIPANT	\N	PRESENT	0
90392	90365	92039X	PARTICIPANT	\N	PRESENT	0
90393	90365	08042U	PARTICIPANT	\N	PRESENT	0
90394	90365	14169X	PARTICIPANT	\N	PRESENT	0
90395	90365	14237S	PARTICIPANT	\N	PRESENT	0
90396	90365	13002U	PARTICIPANT	\N	PRESENT	0
90397	90365	05012A	PARTICIPANT	\N	PRESENT	0
90538	90499	04080J	PARTICIPANT	\N	PRESENT	0
90399	90365	14135M	PARTICIPANT	\N	PRESENT	0
90400	90365	14331P	PARTICIPANT	\N	PRESENT	0
90539	90499	95059Q	PRESIDENT	0	PRESENT	0
90402	90365	14107H	PARTICIPANT	\N	PRESENT	0
90403	90365	14051J	PARTICIPANT	\N	PRESENT	0
90404	90365	14157T	PARTICIPANT	\N	PRESENT	0
90405	90365	96003C	PARTICIPANT	\N	EXCUSE	0
90540	90499	86044G	PARTICIPANT	\N	PRESENT	0
90541	90499	01014K	PARTICIPANT	\N	PRESENT	0
90542	90499	11054L	PARTICIPANT	\N	PRESENT	0
90543	90499	01056V	PARTICIPANT	\N	PRESENT	0
90544	90499	92044U	PARTICIPANT	\N	PRESENT	0
90545	90499	08049C	PARTICIPANT	\N	EXCUSE	0
90546	90499	95067Q	PARTICIPANT	\N	PRESENT	0
90843	90842	04085P	PARTICIPANT	\N	PRESENT	0
90844	90842	05008E	PRESIDENT	0	PRESENT	0
90845	90842	11030C	PARTICIPANT	\N	PRESENT	0
90846	90842	11033F	PARTICIPANT	\N	PRESENT	0
90848	90842	14065Q	PARTICIPANT	\N	PRESENT	0
90850	90842	14069U	PARTICIPANT	\N	PRESENT	0
90851	90842	04047H	PARTICIPANT	\N	PRESENT	0
90852	90842	04038G	PARTICIPANT	\N	PRESENT	0
90853	90842	99002P	PARTICIPANT	\N	PRESENT	0
90854	90842	11056N	PARTICIPANT	\N	PRESENT	0
90855	90842	14259Y	PARTICIPANT	\N	PRESENT	0
90856	90842	11035H	PARTICIPANT	\N	PRESENT	0
90857	90842	14041T	PARTICIPANT	\N	PRESENT	0
90858	90842	11113E	PARTICIPANT	\N	PRESENT	0
90859	90842	01024M	PARTICIPANT	\N	PRESENT	0
90860	90842	14215L	PARTICIPANT	\N	PRESENT	0
90861	90842	11034G	PARTICIPANT	\N	PRESENT	0
90862	90842	08018U	PARTICIPANT	\N	PRESENT	0
90863	90842	01007L	PARTICIPANT	\N	PRESENT	0
90864	90842	11049P	PARTICIPANT	\N	PRESENT	0
90865	90842	11084S	PARTICIPANT	\N	PRESENT	0
90866	90842	11026G	PARTICIPANT	\N	PRESENT	0
90867	90842	04079R	PARTICIPANT	\N	PRESENT	0
90868	90842	14111D	PARTICIPANT	\N	PRESENT	0
90869	90842	14001X	PARTICIPANT	\N	PRESENT	0
90870	90842	14273W	PARTICIPANT	\N	PRESENT	0
90871	90842	01060R	PARTICIPANT	\N	PRESENT	0
90872	90842	14147R	PARTICIPANT	\N	PRESENT	0
90873	90842	95049N	PARTICIPANT	\N	PRESENT	0
90874	90842	08051V	PARTICIPANT	\N	PRESENT	0
90875	90842	07034Q	PARTICIPANT	\N	PRESENT	0
90876	90842	04074L	PARTICIPANT	\N	PRESENT	0
90877	90842	10015M	PARTICIPANT	\N	PRESENT	0
90880	90842	95063L	PARTICIPANT	\N	PRESENT	0
90881	90842	01019Q	PARTICIPANT	\N	PRESENT	0
90882	90842	01028R	PARTICIPANT	\N	PRESENT	0
90883	90842	98035U	PARTICIPANT	\N	PRESENT	0
90884	90842	04056J	PARTICIPANT	\N	PRESENT	0
90885	90842	04044E	PARTICIPANT	\N	PRESENT	0
90886	90842	11037K	PARTICIPANT	\N	PRESENT	0
90888	90842	92045V	PARTICIPANT	\N	PRESENT	0
90889	90842	01047U	PARTICIPANT	\N	PRESENT	0
90905	83930	89017R	PARTICIPANT	\N	PRESENT	0
90906	83930	14030Q	PARTICIPANT	\N	PRESENT	0
90907	83930	14105F	PARTICIPANT	\N	PRESENT	0
90909	83930	04053F	PARTICIPANT	\N	PRESENT	0
90910	83930	14207L	PARTICIPANT	\N	PRESENT	0
90911	83930	14255U	PARTICIPANT	\N	PRESENT	0
90912	83930	14083S	PARTICIPANT	\N	PRESENT	0
90913	83930	14041T	PARTICIPANT	\N	PRESENT	0
90914	83930	14151M	PARTICIPANT	\N	PRESENT	0
90915	83930	14087W	PARTICIPANT	\N	PRESENT	0
90916	83930	14121F	PARTICIPANT	\N	PRESENT	0
90917	83930	14061L	PARTICIPANT	\N	PRESENT	0
90918	83930	04049K	PRESIDENT	0	PRESENT	0
90920	83930	01043Q	PARTICIPANT	\N	PRESENT	0
91421	91420	10015M	PARTICIPANT	\N	PRESENT	0
92234	92232	95067Q	PARTICIPANT	\N	PRESENT	0
92235	92232	04036E	PARTICIPANT	\N	PRESENT	0
92246	92245	14071N	PARTICIPANT	\N	PRESENT	0
92252	92249	14227Q	PARTICIPANT	\N	PRESENT	0
92256	92249	14133K	PARTICIPANT	\N	PRESENT	0
92306	92282	11088W	PARTICIPANT	\N	PRESENT	0
92313	92312	08034U	PARTICIPANT	\N	PRESENT	0
92315	92314	01048V	PARTICIPANT	\N	PRESENT	0
92212	90265	11114F	PARTICIPANT	\N	PRESENT	0
92233	92232	08042U	PARTICIPANT	\N	PRESENT	0
92327	92326	01048V	PARTICIPANT	\N	PRESENT	0
92323	92316	11053K	PARTICIPANT	\N	PRESENT	0
92325	92324	11053K	PARTICIPANT	\N	PRESENT	0
92329	92328	99004R	PARTICIPANT	\N	PRESENT	0
92331	92330	11031D	PARTICIPANT	\N	PRESENT	0
92332	92330	14039A	PARTICIPANT	\N	PRESENT	0
92333	92330	08073C	PARTICIPANT	\N	PRESENT	0
92335	92334	08015R	PARTICIPANT	\N	PRESENT	0
92383	92382	11031D	PARTICIPANT	\N	PRESENT	0
92384	92382	14039A	PARTICIPANT	\N	PRESENT	0
92385	92382	08073C	PARTICIPANT	\N	PRESENT	0
92386	92382	04070G	PARTICIPANT	\N	PRESENT	0
92387	92382	04035D	PARTICIPANT	\N	PRESENT	0
92388	92382	04054G	PARTICIPANT	\N	PRESENT	0
92389	92382	95067Q	PARTICIPANT	\N	PRESENT	0
92390	92382	11057P	PARTICIPANT	\N	PRESENT	0
92391	92382	04071H	PARTICIPANT	\N	PRESENT	0
92392	92382	08069G	PARTICIPANT	\N	PRESENT	0
92393	92382	14065Q	PARTICIPANT	\N	PRESENT	0
92400	92399	11083R	PARTICIPANT	\N	PRESENT	0
92411	92409	14041T	PARTICIPANT	\N	EXCUSE	0
92413	92409	14217N	PARTICIPANT	\N	PRESENT	0
92414	92409	92020L	PARTICIPANT	\N	PRESENT	0
92415	92409	14281W	PARTICIPANT	\N	EXCUSE	0
92417	92409	08041T	PRESIDENT	1	PRESENT	0
92419	92409	07004J	PARTICIPANT	\N	PRESENT	0
92420	92409	11049P	PARTICIPANT	\N	PRESENT	0
92422	92409	04061F	PARTICIPANT	\N	PRESENT	0
92424	92409	08053X	PARTICIPANT	\N	PRESENT	0
92425	92409	10015M	PARTICIPANT	\N	PRESENT	0
92426	92409	14269B	PRESIDENT	0	PRESENT	0
66117	66116	11049P	PARTICIPANT	\N	PRESENT	0
66119	66118	11049P	PARTICIPANT	\N	PRESENT	0
66380	66379	08025T	PARTICIPANT	\N	PRESENT	0
66381	66379	04085P	PARTICIPANT	\N	PRESENT	0
66382	66379	05008E	PRESIDENT	0	PRESENT	0
66451	66431	99004R	PRESIDENT	0	PRESENT	0
66618	66617	11099A	PARTICIPANT	\N	PRESENT	0
66385	66379	14065Q	PARTICIPANT	\N	PRESENT	0
66619	66617	14033T	PARTICIPANT	\N	PRESENT	0
66387	66379	04047H	PARTICIPANT	\N	PRESENT	0
66620	66617	11110B	PARTICIPANT	\N	PRESENT	0
66625	66624	11099A	PARTICIPANT	\N	PRESENT	0
66626	66624	14033T	PARTICIPANT	\N	PRESENT	0
66627	66624	11110B	PARTICIPANT	\N	PRESENT	0
66392	66379	14259Y	PARTICIPANT	\N	PRESENT	0
66629	66628	11099A	PARTICIPANT	\N	PRESENT	0
66630	66628	14033T	PARTICIPANT	\N	PRESENT	0
66631	66628	01008M	PARTICIPANT	\N	PRESENT	0
66396	66379	01024M	PARTICIPANT	\N	EXCUSE	0
66633	66632	11099A	PARTICIPANT	\N	PRESENT	0
66398	66379	11034G	PARTICIPANT	\N	PRESENT	0
66634	66632	14033T	PARTICIPANT	\N	PRESENT	0
66635	66632	01008M	PARTICIPANT	\N	PRESENT	0
66640	66639	11099A	PARTICIPANT	\N	PRESENT	0
66642	66641	11099A	PARTICIPANT	\N	PRESENT	0
66644	66643	11099A	PARTICIPANT	\N	PRESENT	0
66404	66379	11084S	PARTICIPANT	\N	PRESENT	0
66405	66379	11026G	PARTICIPANT	\N	PRESENT	0
66406	66379	04079R	PARTICIPANT	\N	PRESENT	0
66651	66650	05012A	PARTICIPANT	\N	PRESENT	0
66408	66379	14001X	PARTICIPANT	\N	PRESENT	0
66409	66379	14273W	PARTICIPANT	\N	PRESENT	0
70993	70992	14239U	PARTICIPANT	\N	PRESENT	0
75132	75131	14087W	PARTICIPANT	\N	PRESENT	0
70995	70992	01046T	PARTICIPANT	\N	PRESENT	0
66413	66379	08051V	PARTICIPANT	\N	PRESENT	0
70996	70992	04053F	PARTICIPANT	\N	PRESENT	0
66415	66379	07034Q	PARTICIPANT	\N	PRESENT	0
75207	75206	08011M	PARTICIPANT	\N	PRESENT	0
70998	70992	04066L	PARTICIPANT	\N	PRESENT	0
66418	66379	95063L	PARTICIPANT	\N	PRESENT	0
70999	70992	00003C	PARTICIPANT	\N	PRESENT	0
66420	66379	01028R	PARTICIPANT	\N	PRESENT	0
71000	70992	14053L	PARTICIPANT	\N	PRESENT	0
66422	66379	04056J	PARTICIPANT	\N	PRESENT	0
71001	70992	11103C	PARTICIPANT	\N	PRESENT	0
66424	66379	04044E	PARTICIPANT	\N	PRESENT	0
66425	66379	11037K	PARTICIPANT	\N	PRESENT	0
66426	66379	92045V	PARTICIPANT	\N	PRESENT	0
71003	70992	14195A	PARTICIPANT	\N	EXCUSE	0
71004	70992	14267Y	PARTICIPANT	\N	PRESENT	0
71005	70992	11023D	PARTICIPANT	\N	PRESENT	0
71007	70992	08052W	PARTICIPANT	\N	PRESENT	0
71009	70992	04081K	PARTICIPANT	\N	PRESENT	0
71010	70992	98024R	PARTICIPANT	\N	PRESENT	0
71011	70992	10006L	PARTICIPANT	\N	PRESENT	0
71013	70992	14217N	PARTICIPANT	\N	PRESENT	0
71015	70992	14151M	PARTICIPANT	\N	PRESENT	0
71016	70992	12042Y	PARTICIPANT	\N	PRESENT	0
71017	70992	14281W	PARTICIPANT	\N	PRESENT	0
71018	70992	14087W	PARTICIPANT	\N	PRESENT	0
71021	70992	14231L	PARTICIPANT	\N	PRESENT	0
71022	70992	11061K	PARTICIPANT	\N	PRESENT	0
71024	70992	08041T	PARTICIPANT	\N	PRESENT	0
71025	70992	01011G	PARTICIPANT	\N	PRESENT	0
71026	70992	14026U	PARTICIPANT	\N	PRESENT	0
71027	70992	14213J	PARTICIPANT	\N	PRESENT	0
71028	70992	14121F	PARTICIPANT	\N	PRESENT	0
71029	70992	11112D	PARTICIPANT	\N	PRESENT	0
71030	70992	14037X	PARTICIPANT	\N	PRESENT	0
71031	70992	14018U	PARTICIPANT	\N	PRESENT	0
71032	70992	11067R	PARTICIPANT	\N	PRESENT	0
71033	70992	14223L	PARTICIPANT	\N	PRESENT	0
71034	70992	04092N	PRESIDENT	0	PRESENT	0
71035	70992	14265W	PARTICIPANT	\N	PRESENT	0
71036	70992	14119M	PARTICIPANT	\N	PRESENT	0
71037	70992	14071N	PARTICIPANT	\N	PRESENT	0
71039	70992	04043D	PARTICIPANT	\N	PRESENT	0
71040	70992	14271U	PARTICIPANT	\N	PRESENT	0
71041	70992	14017T	PARTICIPANT	\N	EXCUSE	0
71042	70992	11093T	PARTICIPANT	\N	PRESENT	0
71043	70992	11097X	PARTICIPANT	\N	PRESENT	0
71044	70992	04045F	PARTICIPANT	\N	PRESENT	0
71045	70992	14227Q	PARTICIPANT	\N	PRESENT	0
71046	70992	01034P	PARTICIPANT	\N	PRESENT	0
71048	70992	11063M	PARTICIPANT	\N	PRESENT	0
75237	75236	14083S	PARTICIPANT	\N	PRESENT	0
75239	75238	14083S	PARTICIPANT	\N	PRESENT	0
75241	75240	01057W	PARTICIPANT	\N	PRESENT	0
75242	75240	14225N	PARTICIPANT	\N	PRESENT	0
75255	75254	14083S	PARTICIPANT	\N	PRESENT	0
75257	75256	08018U	PARTICIPANT	\N	PRESENT	0
75259	75258	14175V	PARTICIPANT	\N	PRESENT	0
75260	75258	14085U	PARTICIPANT	\N	PRESENT	0
75261	75258	11042G	PARTICIPANT	\N	PRESENT	0
75262	75258	04086Q	PARTICIPANT	\N	PRESENT	0
75263	75258	14159V	PARTICIPANT	\N	PRESENT	0
75264	75258	08011M	PARTICIPANT	\N	PRESENT	0
75269	75268	01031L	PARTICIPANT	\N	PRESENT	0
75275	75274	01031L	PARTICIPANT	\N	PRESENT	0
75276	75274	08011M	PARTICIPANT	\N	PRESENT	0
75278	75277	01031L	PARTICIPANT	\N	PRESENT	0
75280	75279	01031L	PARTICIPANT	\N	PRESENT	0
75282	75281	01031L	PARTICIPANT	\N	PRESENT	0
75284	75283	04086Q	PARTICIPANT	\N	PRESENT	0
75289	75288	04086Q	PARTICIPANT	\N	PRESENT	0
75293	75290	04086Q	PARTICIPANT	\N	PRESENT	0
75310	75303	04086Q	PARTICIPANT	\N	PRESENT	0
75340	75339	08034U	PARTICIPANT	\N	PRESENT	0
75363	75357	11053K	PARTICIPANT	\N	PRESENT	0
75390	75387	11053K	PARTICIPANT	\N	PRESENT	0
75410	75407	11053K	PARTICIPANT	\N	PRESENT	0
75450	75442	11053K	PARTICIPANT	\N	PRESENT	0
75485	75484	11053K	PARTICIPANT	\N	PRESENT	0
75492	75489	11053K	PARTICIPANT	\N	PRESENT	0
75633	75628	11053K	PARTICIPANT	\N	PRESENT	0
75636	75219	08049C	PARTICIPANT	\N	PRESENT	0
75637	75219	88008L	PARTICIPANT	\N	PRESENT	0
75638	75219	04038G	PARTICIPANT	\N	PRESENT	0
75639	75219	04067M	PARTICIPANT	\N	PRESENT	0
75640	75219	04045F	PARTICIPANT	\N	PRESENT	0
75641	75219	98023Q	PARTICIPANT	\N	PRESENT	0
75642	75219	14026U	PARTICIPANT	\N	PRESENT	0
75643	75219	98024R	PARTICIPANT	\N	PRESENT	0
75644	75219	11091R	PARTICIPANT	\N	PRESENT	0
75645	75219	01003G	PARTICIPANT	\N	PRESENT	0
75646	75219	14157T	PARTICIPANT	\N	PRESENT	0
75648	75219	14239U	PARTICIPANT	\N	PRESENT	0
75649	75219	98022P	PARTICIPANT	\N	PRESENT	0
75650	75219	14241N	PARTICIPANT	\N	PRESENT	0
75651	75219	14031R	PARTICIPANT	\N	PRESENT	0
75652	75219	11037K	PARTICIPANT	\N	PRESENT	0
75654	75219	12042Y	PARTICIPANT	\N	PRESENT	0
75655	75219	08018U	PARTICIPANT	\N	PRESENT	0
75656	75219	11107G	PARTICIPANT	\N	PRESENT	0
75657	75219	08009T	PARTICIPANT	\N	PRESENT	0
75658	75219	08031R	PARTICIPANT	\N	PRESENT	0
75659	75219	14034U	PARTICIPANT	\N	PRESENT	0
75660	75219	14273W	PARTICIPANT	\N	PRESENT	0
75661	75219	04040A	PARTICIPANT	\N	PRESENT	0
75662	75219	14205J	PARTICIPANT	\N	PRESENT	0
75663	75219	14219Q	PARTICIPANT	\N	PRESENT	0
75664	75219	14042U	PARTICIPANT	\N	PRESENT	0
75665	75219	14103D	PARTICIPANT	\N	PRESENT	0
75666	75219	14221J	PARTICIPANT	\N	PRESENT	0
75667	75219	11082Q	PARTICIPANT	\N	PRESENT	0
75668	75219	01047U	PARTICIPANT	\N	PRESENT	0
75751	75750	11074Q	PARTICIPANT	\N	PRESENT	0
75752	75750	11083R	PARTICIPANT	\N	PRESENT	0
77510	66879	04040A	PRESIDENT	0	PRESENT	0
77512	66879	04044E	PARTICIPANT	\N	EXCUSE	0
78210	77581	11044J	PARTICIPANT	\N	PRESENT	0
78211	77581	14197C	PARTICIPANT	\N	PRESENT	0
78212	77581	14034U	PARTICIPANT	\N	PRESENT	0
78213	77581	95062K	PARTICIPANT	\N	PRESENT	0
78214	77581	14135M	PARTICIPANT	\N	PRESENT	0
78215	77581	14331P	PARTICIPANT	\N	PRESENT	0
78216	77581	92018S	PARTICIPANT	\N	PRESENT	0
78217	77581	14205J	PARTICIPANT	\N	PRESENT	0
78218	77581	14083S	PARTICIPANT	\N	PRESENT	0
78219	77581	14105F	PARTICIPANT	\N	PRESENT	0
78220	77581	11043H	PARTICIPANT	\N	PRESENT	0
78221	77581	11070L	PARTICIPANT	\N	PRESENT	0
78222	77581	89017R	PARTICIPANT	\N	PRESENT	0
78233	78232	08018U	PARTICIPANT	\N	PRESENT	0
78313	78312	11039M	PARTICIPANT	\N	PRESENT	0
78314	78312	98042T	PARTICIPANT	\N	PRESENT	0
78315	78312	01019Q	PARTICIPANT	\N	PRESENT	0
78208	77581	01008M	PARTICIPANT	\N	PRESENT	0
78209	77581	11014C	PARTICIPANT	\N	PRESENT	0
79142	78234	11048N	PARTICIPANT	\N	PRESENT	0
79143	78234	01028R	PARTICIPANT	\N	PRESENT	0
78321	78319	04043D	PARTICIPANT	\N	PRESENT	0
78327	78316	04043D	PARTICIPANT	\N	PRESENT	0
78325	66879	14028W	PARTICIPANT	\N	EXCUSE	0
78332	78328	04043D	PARTICIPANT	\N	PRESENT	0
78382	78380	04043D	PARTICIPANT	\N	PRESENT	0
78385	78383	04043D	PARTICIPANT	\N	PRESENT	0
78431	78334	04043D	PARTICIPANT	\N	PRESENT	0
79132	78234	08055A	PARTICIPANT	\N	PRESENT	0
79133	78234	01003G	PARTICIPANT	\N	PRESENT	0
79134	78234	04085P	PARTICIPANT	\N	PRESENT	0
79135	78234	11059R	PARTICIPANT	\N	PRESENT	0
79136	78234	11026G	PARTICIPANT	\N	PRESENT	0
79137	78234	08025T	PARTICIPANT	\N	PRESENT	0
79138	78234	07004J	PARTICIPANT	\N	PRESENT	0
79139	78234	14089Y	PARTICIPANT	\N	PRESENT	0
79140	78234	14273W	PARTICIPANT	\N	PRESENT	0
79141	78234	89017R	PARTICIPANT	\N	PRESENT	0
79144	78234	05008E	PARTICIPANT	\N	PRESENT	0
79145	78234	11030C	PARTICIPANT	\N	PRESENT	0
79146	78234	14001X	PARTICIPANT	\N	PRESENT	0
79147	78234	14111D	PARTICIPANT	\N	PRESENT	0
79148	78234	04038G	PARTICIPANT	\N	PRESENT	0
79149	78234	95063L	PARTICIPANT	\N	PRESENT	0
79150	78234	98018T	PARTICIPANT	\N	PRESENT	0
79151	78234	11109J	PARTICIPANT	\N	PRESENT	0
79152	78234	04074L	PARTICIPANT	\N	PRESENT	0
79153	78234	95049N	PARTICIPANT	\N	PRESENT	0
79154	78234	01013J	PARTICIPANT	\N	PRESENT	0
79155	78234	14269B	PARTICIPANT	\N	PRESENT	0
79156	78234	11083R	PARTICIPANT	\N	PRESENT	0
79157	78234	14209N	PARTICIPANT	\N	PRESENT	0
79158	78234	95015C	PARTICIPANT	\N	PRESENT	0
79159	78234	14065Q	PARTICIPANT	\N	PRESENT	0
79160	78234	04080J	PARTICIPANT	\N	PRESENT	0
79161	78234	01007L	PARTICIPANT	\N	PRESENT	0
79162	78234	11103C	PARTICIPANT	\N	PRESENT	0
79163	78234	11091R	PARTICIPANT	\N	PRESENT	0
79164	78234	80013X	PARTICIPANT	\N	PRESENT	0
79165	78234	97011G	PARTICIPANT	\N	PRESENT	0
79166	78234	08034U	PARTICIPANT	\N	PRESENT	0
79167	78234	14041T	PARTICIPANT	\N	PRESENT	0
79168	78234	14147R	PARTICIPANT	\N	PRESENT	0
79169	78234	14159V	PARTICIPANT	\N	PRESENT	0
79170	78234	11036J	PARTICIPANT	\N	PRESENT	0
79171	78234	04089T	PARTICIPANT	\N	PRESENT	0
79172	78234	11040E	PARTICIPANT	\N	PRESENT	0
79173	78234	14267Y	PARTICIPANT	\N	PRESENT	0
79174	78234	14249W	PARTICIPANT	\N	PRESENT	0
79175	78234	08014Q	PARTICIPANT	\N	PRESENT	0
79176	78234	14219Q	PARTICIPANT	\N	PRESENT	0
79177	78234	07024N	PARTICIPANT	\N	PRESENT	0
79178	78234	98005N	PARTICIPANT	\N	PRESENT	0
79179	78234	11012A	PARTICIPANT	\N	PRESENT	0
79180	78234	11071M	PARTICIPANT	\N	PRESENT	0
79181	78234	07034Q	PARTICIPANT	\N	PRESENT	0
79182	78234	11056N	PARTICIPANT	\N	PRESENT	0
79183	78234	14275Y	PARTICIPANT	\N	PRESENT	0
79184	78234	14217N	PARTICIPANT	\N	PRESENT	0
79185	78234	14257W	PARTICIPANT	\N	PRESENT	0
79186	78234	04067M	PARTICIPANT	\N	PRESENT	0
79187	78234	14097Y	PARTICIPANT	\N	PRESENT	0
79188	78234	04047H	PARTICIPANT	\N	PRESENT	0
79189	78234	95062K	PARTICIPANT	\N	PRESENT	0
79190	78234	14173T	PARTICIPANT	\N	PRESENT	0
79191	78234	11093T	PARTICIPANT	\N	PRESENT	0
79192	78234	14237S	PARTICIPANT	\N	PRESENT	0
79193	78234	01015L	PARTICIPANT	\N	PRESENT	0
79194	78234	11104D	PARTICIPANT	\N	PRESENT	0
79195	78234	08051V	PARTICIPANT	\N	PRESENT	0
79196	78234	04043D	PARTICIPANT	\N	PRESENT	0
79197	78234	11105E	PARTICIPANT	\N	PRESENT	0
79198	78234	11066Q	PARTICIPANT	\N	PRESENT	0
79199	78234	11097X	PARTICIPANT	\N	PRESENT	0
79200	78234	14119M	PARTICIPANT	\N	PRESENT	0
79201	78234	04034C	PARTICIPANT	\N	PRESENT	0
79202	78234	01019Q	PARTICIPANT	\N	PRESENT	0
79214	78234	14121F	PARTICIPANT	\N	PRESENT	0
79215	78234	11043H	PARTICIPANT	\N	PRESENT	0
79216	78234	92045V	PARTICIPANT	\N	PRESENT	0
79218	78234	11082Q	PARTICIPANT	\N	PRESENT	0
79313	78235	08055A	PARTICIPANT	\N	PRESENT	0
79314	78235	05008E	PARTICIPANT	\N	PRESENT	0
79315	78235	95049N	PARTICIPANT	\N	PRESENT	0
79316	78235	11081P	PARTICIPANT	\N	PRESENT	0
79317	78235	08014Q	PARTICIPANT	\N	PRESENT	0
79318	78235	11066Q	PARTICIPANT	\N	PRESENT	0
79319	78235	14097Y	PARTICIPANT	\N	PRESENT	0
79320	78235	14237S	PARTICIPANT	\N	PRESENT	0
79321	78235	11071M	PARTICIPANT	\N	PRESENT	0
79322	78235	14191V	PARTICIPANT	\N	PRESENT	0
79323	78235	98005N	PARTICIPANT	\N	PRESENT	0
79324	78235	95062K	PARTICIPANT	\N	PRESENT	0
79325	78235	04034C	PARTICIPANT	\N	PRESENT	0
79326	78235	14121F	PARTICIPANT	\N	PRESENT	0
79327	78235	11026G	PARTICIPANT	\N	PRESENT	0
79330	78235	97011G	PARTICIPANT	\N	PRESENT	0
79331	78235	04043D	PARTICIPANT	\N	PRESENT	0
79332	78235	12042Y	PARTICIPANT	\N	PRESENT	0
79333	78235	07004J	PARTICIPANT	\N	PRESENT	0
79334	78235	11082Q	PARTICIPANT	\N	PRESENT	0
79335	78235	14059S	PARTICIPANT	\N	PRESENT	0
79336	78235	01031L	PARTICIPANT	\N	PRESENT	0
79337	78235	14235Q	PARTICIPANT	\N	PRESENT	0
79338	78235	11040E	PARTICIPANT	\N	PRESENT	0
79339	78235	10006L	PARTICIPANT	\N	PRESENT	0
79340	78235	11093T	PARTICIPANT	\N	PRESENT	0
79341	78235	11056N	PARTICIPANT	\N	PRESENT	0
79342	78235	92045V	PARTICIPANT	\N	PRESENT	0
79343	78235	11036J	PARTICIPANT	\N	PRESENT	0
79344	78235	14065Q	PARTICIPANT	\N	PRESENT	0
79345	78235	01028R	PARTICIPANT	\N	PRESENT	0
79346	78235	14147R	PARTICIPANT	\N	PRESENT	0
79347	78235	11091R	PARTICIPANT	\N	PRESENT	0
79348	78235	14111D	PARTICIPANT	\N	PRESENT	0
79349	78235	14273W	PARTICIPANT	\N	PRESENT	0
79350	78235	04047H	PARTICIPANT	\N	PRESENT	0
79351	78235	04044E	PARTICIPANT	\N	PRESENT	0
79352	78235	01058X	PARTICIPANT	\N	PRESENT	0
79353	78235	04085P	PARTICIPANT	\N	PRESENT	0
79354	78235	14069U	PARTICIPANT	\N	PRESENT	0
79363	78235	14033T	PARTICIPANT	\N	PRESENT	0
79365	78235	11048N	PARTICIPANT	\N	PRESENT	0
79367	78235	10015M	PARTICIPANT	\N	PRESENT	0
79370	78235	86044G	PARTICIPANT	\N	PRESENT	0
79371	78235	08068F	PARTICIPANT	\N	PRESENT	0
80659	80626	14209N	PARTICIPANT	\N	EXCUSE	0
80660	80626	14079W	PARTICIPANT	\N	EXCUSE	0
80661	80626	11091R	PARTICIPANT	\N	EXCUSE	0
80662	80626	98042T	PARTICIPANT	\N	EXCUSE	0
80663	80626	14249W	PARTICIPANT	\N	EXCUSE	0
80664	80626	01041N	PARTICIPANT	\N	EXCUSE	0
80665	80626	01025N	PARTICIPANT	\N	EXCUSE	0
80666	80626	01037S	PARTICIPANT	\N	EXCUSE	0
80667	80626	89029V	PARTICIPANT	\N	EXCUSE	0
80668	80626	08035V	PARTICIPANT	\N	EXCUSE	0
80669	80626	11089X	PARTICIPANT	\N	EXCUSE	0
80670	80626	07026Q	PARTICIPANT	\N	EXCUSE	0
80671	80626	14123H	PARTICIPANT	\N	EXCUSE	0
80672	80626	14179A	PARTICIPANT	\N	EXCUSE	0
80673	80626	04041B	PARTICIPANT	\N	EXCUSE	0
80674	80626	14061L	PARTICIPANT	\N	EXCUSE	0
80675	80626	08031R	PARTICIPANT	\N	EXCUSE	0
80676	80626	12041X	PARTICIPANT	\N	EXCUSE	0
80677	80626	08039A	PARTICIPANT	\N	EXCUSE	0
80678	80626	08017T	PARTICIPANT	\N	EXCUSE	0
80679	80626	14059S	PARTICIPANT	\N	EXCUSE	0
80680	80626	14103D	PARTICIPANT	\N	EXCUSE	0
80681	80626	11104D	PARTICIPANT	\N	EXCUSE	0
80682	80626	14063N	PARTICIPANT	\N	EXCUSE	0
80683	80626	04057K	PARTICIPANT	\N	EXCUSE	0
80684	80626	11014C	PARTICIPANT	\N	EXCUSE	0
80685	80626	14109K	PARTICIPANT	\N	EXCUSE	0
80686	80626	04070G	PARTICIPANT	\N	EXCUSE	0
80687	80626	92040Q	PARTICIPANT	\N	EXCUSE	0
80688	80626	83047W	PARTICIPANT	\N	EXCUSE	0
80689	80626	14055N	PARTICIPANT	\N	EXCUSE	0
80690	80626	04033B	PARTICIPANT	\N	EXCUSE	0
80691	80626	14229S	PARTICIPANT	\N	EXCUSE	0
80692	80626	11071M	PARTICIPANT	\N	EXCUSE	0
80693	80626	11011M	PARTICIPANT	\N	EXCUSE	0
82234	81724	14053L	PARTICIPANT	\N	PRESENT	0
82235	81724	08052W	PARTICIPANT	\N	PRESENT	0
82236	81724	10006L	PARTICIPANT	\N	PRESENT	0
82237	81724	12042Y	PARTICIPANT	\N	PRESENT	0
82238	81724	01011G	PARTICIPANT	\N	PRESENT	0
82240	81724	04092N	PARTICIPANT	\N	PRESENT	0
82241	81724	14071N	PARTICIPANT	\N	PRESENT	0
82242	81724	11097X	PARTICIPANT	\N	PRESENT	0
82243	81724	14271U	PARTICIPANT	\N	PRESENT	0
82244	81724	14281W	PARTICIPANT	\N	PRESENT	0
82245	81724	11023D	PARTICIPANT	\N	PRESENT	0
82246	81724	14195A	PARTICIPANT	\N	PRESENT	0
82247	81724	14087W	PARTICIPANT	\N	PRESENT	0
82248	81724	04045F	PARTICIPANT	\N	PRESENT	0
82249	81724	11067R	PARTICIPANT	\N	PRESENT	0
82251	81724	14231L	PARTICIPANT	\N	PRESENT	0
82252	81724	14026U	PARTICIPANT	\N	PRESENT	0
82355	82354	14263U	PARTICIPANT	\N	PRESENT	0
82412	82354	11104D	PARTICIPANT	\N	PRESENT	0
82357	82354	11109J	PARTICIPANT	\N	PRESENT	0
82358	82354	04059M	PARTICIPANT	\N	PRESENT	0
82413	77795	95062K	PARTICIPANT	\N	EXCUSE	0
82360	82354	01044R	PARTICIPANT	\N	PRESENT	0
82361	82354	08043V	PARTICIPANT	\N	PRESENT	0
82362	82354	14089Y	PARTICIPANT	\N	PRESENT	0
82363	82354	14105F	PARTICIPANT	\N	PRESENT	0
82364	82354	11029K	PARTICIPANT	\N	PRESENT	0
82365	82354	95015C	PARTICIPANT	\N	PRESENT	0
82366	82354	92015P	PARTICIPANT	\N	PRESENT	0
82416	82414	14133K	PARTICIPANT	\N	EXCUSE	0
82368	82354	14201E	PARTICIPANT	\N	EXCUSE	0
82417	82414	96004D	PARTICIPANT	\N	EXCUSE	0
82370	82354	14209N	PARTICIPANT	\N	PRESENT	0
82371	82354	14079W	PARTICIPANT	\N	PRESENT	0
82372	82354	11091R	PARTICIPANT	\N	PRESENT	0
82418	82414	14089Y	PARTICIPANT	\N	PRESENT	0
82419	82414	95030B	PARTICIPANT	\N	PRESENT	0
82375	82354	14249W	PARTICIPANT	\N	EXCUSE	0
82376	82354	01041N	PARTICIPANT	\N	PRESENT	0
82377	82354	01025N	PARTICIPANT	\N	PRESENT	0
82378	82354	01037S	PARTICIPANT	\N	EXCUSE	0
82420	82414	11083R	PARTICIPANT	\N	PRESENT	0
82421	82414	14097Y	PARTICIPANT	\N	PRESENT	0
82381	82354	11089X	PARTICIPANT	\N	PRESENT	0
82422	82414	11026G	PARTICIPANT	\N	PRESENT	0
82423	82414	08042U	PARTICIPANT	\N	PRESENT	0
82424	82414	14135M	PARTICIPANT	\N	EXCUSE	0
82425	82414	01016M	PARTICIPANT	\N	PRESENT	0
82426	82414	10015M	PRESIDENT	0	PRESENT	0
82387	82354	14061L	PARTICIPANT	\N	PRESENT	0
82427	82414	92045V	PARTICIPANT	\N	EXCUSE	0
82389	82354	08031R	PARTICIPANT	\N	PRESENT	0
82428	82414	04034C	PARTICIPANT	\N	PRESENT	0
82391	82354	08039A	PARTICIPANT	\N	PRESENT	0
82392	82354	08017T	PARTICIPANT	\N	PRESENT	0
82393	82354	14059S	PARTICIPANT	\N	PRESENT	0
82429	82414	11035H	PARTICIPANT	\N	EXCUSE	0
82430	82414	04057K	PARTICIPANT	\N	EXCUSE	0
82398	82354	04057K	PARTICIPANT	\N	PRESENT	0
82399	82354	11014C	PARTICIPANT	\N	PRESENT	0
82400	82354	14109K	PARTICIPANT	\N	PRESENT	0
82401	82354	04070G	PRESIDENT	0	PRESENT	0
82445	82440	01046T	PARTICIPANT	\N	PRESENT	0
82403	82354	14191V	PARTICIPANT	\N	PRESENT	0
82404	82354	83047W	PARTICIPANT	\N	PRESENT	0
82446	82440	04053F	PARTICIPANT	\N	PRESENT	0
82448	82440	04066L	PARTICIPANT	\N	PRESENT	0
82408	82354	14229S	PARTICIPANT	\N	PRESENT	0
82409	82354	11043H	PARTICIPANT	\N	PRESENT	0
82410	82354	11071M	PARTICIPANT	\N	PRESENT	0
82411	82354	11011M	PARTICIPANT	\N	PRESENT	0
82449	82440	00003C	PARTICIPANT	\N	PRESENT	0
82450	82440	14053L	PARTICIPANT	\N	PRESENT	0
82451	82440	11103C	PARTICIPANT	\N	PRESENT	0
82453	82440	14195A	PARTICIPANT	\N	PRESENT	0
82455	82440	11023D	PARTICIPANT	\N	PRESENT	0
82456	82440	11031D	PARTICIPANT	\N	PRESENT	0
82457	82440	08052W	PARTICIPANT	\N	PRESENT	0
82459	82440	04081K	PARTICIPANT	\N	PRESENT	0
82460	82440	98024R	PARTICIPANT	\N	PRESENT	0
82461	82440	10006L	PARTICIPANT	\N	PRESENT	0
82464	82440	14042U	PARTICIPANT	\N	PRESENT	0
82465	82440	14151M	PARTICIPANT	\N	PRESENT	0
82466	82440	12042Y	PARTICIPANT	\N	PRESENT	0
82467	82440	14281W	PARTICIPANT	\N	PRESENT	0
82468	82440	14087W	PARTICIPANT	\N	PRESENT	0
82470	82440	14034U	PARTICIPANT	\N	PRESENT	0
82471	82440	14231L	PARTICIPANT	\N	PRESENT	0
82472	82440	11061K	PARTICIPANT	\N	PRESENT	0
82474	82440	08041T	PARTICIPANT	\N	PRESENT	0
82475	82440	01011G	PARTICIPANT	\N	PRESENT	0
82476	82440	14026U	PARTICIPANT	\N	PRESENT	0
82477	82440	14213J	PARTICIPANT	\N	PRESENT	0
82478	82440	14121F	PARTICIPANT	\N	PRESENT	0
82480	82440	14037X	PARTICIPANT	\N	PRESENT	0
82482	82440	11067R	PARTICIPANT	\N	PRESENT	0
82483	82440	14223L	PARTICIPANT	\N	PRESENT	0
82484	82440	04092N	PRESIDENT	0	PRESENT	0
82485	82440	14265W	PARTICIPANT	\N	PRESENT	0
82486	82440	14119M	PARTICIPANT	\N	PRESENT	0
82487	82440	14071N	PARTICIPANT	\N	PRESENT	0
82488	82440	07032N	PARTICIPANT	\N	PRESENT	0
82489	82440	04043D	PARTICIPANT	\N	PRESENT	0
82490	82440	14271U	PARTICIPANT	\N	PRESENT	0
82492	82440	11093T	PARTICIPANT	\N	EXCUSE	0
82493	82440	11097X	PARTICIPANT	\N	PRESENT	0
82494	82440	04045F	PARTICIPANT	\N	EXCUSE	0
82495	82440	14227Q	PARTICIPANT	\N	PRESENT	0
82496	82440	01034P	PARTICIPANT	\N	PRESENT	0
82498	82440	11063M	PARTICIPANT	\N	PRESENT	0
82499	82440	14269B	PARTICIPANT	\N	PRESENT	0
82539	82537	01008M	PARTICIPANT	\N	PRESENT	0
82540	82537	11036J	PARTICIPANT	\N	PRESENT	0
82542	82537	14013P	PARTICIPANT	\N	PRESENT	0
82543	82537	08068F	PARTICIPANT	\N	PRESENT	0
82546	82537	90003B	PARTICIPANT	\N	PRESENT	0
82547	82537	08028W	PARTICIPANT	\N	PRESENT	0
82548	82537	80013X	PARTICIPANT	\N	PRESENT	0
88451	88450	01008M	PARTICIPANT	\N	PRESENT	0
88452	88450	11036J	PARTICIPANT	\N	PRESENT	0
88395	88392	04040A	PARTICIPANT	\N	PRESENT	0
88396	88392	08058D	PARTICIPANT	\N	PRESENT	0
88491	88490	98046X	PARTICIPANT	\N	PRESENT	0
88454	88450	14013P	PARTICIPANT	\N	PRESENT	0
88399	88392	98029W	PARTICIPANT	\N	PRESENT	0
88455	88450	08068F	PARTICIPANT	\N	PRESENT	0
88456	88450	14207L	PARTICIPANT	\N	PRESENT	0
88402	88392	98018T	PARTICIPANT	\N	PRESENT	0
88403	88392	92018S	PARTICIPANT	\N	PRESENT	0
88404	88392	92020L	PARTICIPANT	\N	EXCUSE	0
88405	88392	95030B	PARTICIPANT	\N	PRESENT	0
88457	88450	11101A	PARTICIPANT	\N	PRESENT	0
88458	88450	90003B	PARTICIPANT	\N	PRESENT	0
88408	88392	97011G	PARTICIPANT	\N	PRESENT	0
88409	88392	08065C	PARTICIPANT	\N	PRESENT	0
88410	88392	04035D	PARTICIPANT	\N	EXCUSE	0
88411	88392	07024N	PRESIDENT	0	PRESENT	0
88459	88450	08028W	PARTICIPANT	\N	PRESENT	0
88413	88392	14014Q	PARTICIPANT	\N	PRESENT	0
88460	88450	80013X	PARTICIPANT	\N	PRESENT	0
88461	88450	08038Y	PARTICIPANT	\N	PRESENT	0
88416	88392	95035G	PARTICIPANT	\N	EXCUSE	0
88462	88450	04089T	PARTICIPANT	\N	PRESENT	0
88463	88450	14197C	PARTICIPANT	\N	PRESENT	0
88419	88392	98022P	PARTICIPANT	\N	EXCUSE	0
88497	88496	11076S	PARTICIPANT	\N	PRESENT	0
88465	88450	14187A	PARTICIPANT	\N	PRESENT	0
88466	88450	14033T	PARTICIPANT	\N	PRESENT	0
88423	88392	14097Y	PARTICIPANT	\N	PRESENT	0
88498	88496	04054G	PARTICIPANT	\N	PRESENT	0
88468	88450	04048J	PARTICIPANT	\N	PRESENT	0
88469	88450	11099A	PARTICIPANT	\N	PRESENT	0
88499	88496	04040A	PARTICIPANT	\N	PRESENT	0
88500	88496	08058D	PARTICIPANT	\N	PRESENT	0
88429	88392	92031P	PARTICIPANT	\N	PRESENT	0
88430	88392	11106F	PARTICIPANT	\N	PRESENT	0
88472	88450	11111C	PARTICIPANT	\N	PRESENT	0
88473	88450	08015R	PARTICIPANT	\N	PRESENT	0
88474	88450	11100Y	PRESIDENT	0	PRESENT	0
88475	88450	01061S	PARTICIPANT	\N	PRESENT	0
88435	88392	11105E	PARTICIPANT	\N	EXCUSE	0
88436	88392	14253S	PARTICIPANT	\N	PRESENT	0
88476	88450	11098Y	PARTICIPANT	\N	PRESENT	0
88438	88392	14028W	PARTICIPANT	\N	EXCUSE	0
88477	88450	01043Q	PARTICIPANT	\N	PRESENT	0
88440	88392	98021N	PARTICIPANT	\N	EXCUSE	0
88441	88392	04080J	PARTICIPANT	\N	PRESENT	0
88442	88392	95059Q	PARTICIPANT	\N	EXCUSE	0
88478	88450	11077T	PARTICIPANT	\N	PRESENT	0
88444	88392	01014K	PARTICIPANT	\N	PRESENT	0
88445	88392	11054L	PARTICIPANT	\N	PRESENT	0
88446	88392	01056V	PARTICIPANT	\N	PRESENT	0
88479	88450	14205J	PARTICIPANT	\N	PRESENT	0
88448	88392	08049C	PARTICIPANT	\N	EXCUSE	0
88501	88496	04042C	PRESIDENT	0	PRESENT	0
88480	88450	08019V	PARTICIPANT	\N	PRESENT	0
88481	88450	14257W	PARTICIPANT	\N	PRESENT	0
88502	88496	77002U	PARTICIPANT	\N	PRESENT	0
88503	88496	98029W	PARTICIPANT	\N	PRESENT	0
88484	88450	98050T	PARTICIPANT	\N	PRESENT	0
88562	88561	14261S	PARTICIPANT	\N	PRESENT	0
88486	88450	11046L	PARTICIPANT	\N	PRESENT	0
88487	88450	01058X	PARTICIPANT	\N	PRESENT	0
88488	88450	11094U	PARTICIPANT	\N	PRESENT	0
88489	88450	11066Q	PARTICIPANT	\N	PRESENT	0
88563	88561	08055A	PARTICIPANT	\N	PRESENT	0
88505	88496	11027H	PARTICIPANT	\N	PRESENT	0
88506	88496	98018T	PARTICIPANT	\N	PRESENT	0
88507	88496	92018S	PARTICIPANT	\N	PRESENT	0
88508	88496	92020L	PARTICIPANT	\N	PRESENT	0
88509	88496	95030B	PARTICIPANT	\N	PRESENT	0
88510	88496	11096W	PARTICIPANT	\N	PRESENT	0
88564	88561	14093U	PARTICIPANT	\N	PRESENT	0
88512	88496	97011G	PARTICIPANT	\N	PRESENT	0
88565	88561	14030Q	PARTICIPANT	\N	PRESENT	0
88514	88496	04035D	PARTICIPANT	\N	PRESENT	0
88515	88496	07024N	PARTICIPANT	\N	PRESENT	0
88566	88561	96004D	PARTICIPANT	\N	PRESENT	0
88517	88496	14014Q	PARTICIPANT	\N	PRESENT	0
88518	88496	11015D	PARTICIPANT	\N	PRESENT	0
88519	88496	07004J	PARTICIPANT	\N	PRESENT	0
88520	88496	95035G	PARTICIPANT	\N	PRESENT	0
88521	88496	08056B	PARTICIPANT	\N	PRESENT	0
88522	88496	14211G	PARTICIPANT	\N	PRESENT	0
88523	88496	98022P	PARTICIPANT	\N	PRESENT	0
88524	88496	11064N	PARTICIPANT	\N	PRESENT	0
88525	88496	95037J	PARTICIPANT	\N	PRESENT	0
88526	88496	04078Q	PARTICIPANT	\N	PRESENT	0
88527	88496	14097Y	PARTICIPANT	\N	PRESENT	0
88528	88496	95041E	PARTICIPANT	\N	PRESENT	0
88529	88496	04036E	PARTICIPANT	\N	PRESENT	0
88530	88496	14039A	PARTICIPANT	\N	PRESENT	0
88531	88496	04077P	PARTICIPANT	\N	PRESENT	0
88567	88561	08060W	PARTICIPANT	\N	PRESENT	0
88533	88496	92031P	PARTICIPANT	\N	PRESENT	0
88534	88496	11106F	PARTICIPANT	\N	PRESENT	0
88535	88496	14251Q	PARTICIPANT	\N	PRESENT	0
88536	88496	83042R	PARTICIPANT	\N	PRESENT	0
88537	88496	08053X	PARTICIPANT	\N	PRESENT	0
88538	88496	11082Q	PARTICIPANT	\N	PRESENT	0
88539	88496	11105E	PARTICIPANT	\N	EXCUSE	0
88540	88496	14253S	PARTICIPANT	\N	PRESENT	0
88541	88496	08047A	PARTICIPANT	\N	PRESENT	0
88542	88496	14028W	PARTICIPANT	\N	PRESENT	0
88543	88496	14193X	PARTICIPANT	\N	EXCUSE	0
88544	88496	98021N	PARTICIPANT	\N	EXCUSE	0
88545	88496	04080J	PARTICIPANT	\N	PRESENT	0
88546	88496	95059Q	PARTICIPANT	\N	PRESENT	0
88547	88496	86044G	PARTICIPANT	\N	PRESENT	0
88548	88496	01014K	PARTICIPANT	\N	PRESENT	0
88549	88496	11054L	PARTICIPANT	\N	PRESENT	0
88550	88496	01056V	PARTICIPANT	\N	PRESENT	0
88551	88496	92044U	PARTICIPANT	\N	PRESENT	0
88552	88496	08049C	PARTICIPANT	\N	EXCUSE	0
88553	88496	04050C	PARTICIPANT	\N	PRESENT	0
88568	88561	11095V	PARTICIPANT	\N	PRESENT	0
88569	88561	14038Y	PARTICIPANT	\N	PRESENT	0
88570	88561	11114F	PARTICIPANT	\N	PRESENT	0
88571	88561	98023Q	PARTICIPANT	\N	PRESENT	0
88572	88561	11065P	PARTICIPANT	\N	PRESENT	0
88573	88561	01015L	PARTICIPANT	\N	PRESENT	0
88574	88561	11107G	PARTICIPANT	\N	PRESENT	0
88704	88703	14261S	PARTICIPANT	\N	PRESENT	0
88576	88561	02002K	PARTICIPANT	\N	EXCUSE	0
88577	88561	01022K	PARTICIPANT	\N	PRESENT	0
88578	88561	04097T	PARTICIPANT	\N	PRESENT	0
88579	88561	09001P	PARTICIPANT	\N	PRESENT	0
88580	88561	11059R	PARTICIPANT	\N	PRESENT	0
88581	88561	14219Q	PARTICIPANT	\N	PRESENT	0
88582	88561	80027E	PARTICIPANT	\N	PRESENT	0
88705	88703	08055A	PARTICIPANT	\N	PRESENT	0
88584	88561	08009T	PRESIDENT	0	PRESENT	0
88585	88561	08062Y	PARTICIPANT	\N	PRESENT	0
88586	88561	14221J	PARTICIPANT	\N	PRESENT	0
88587	88561	92039X	PARTICIPANT	\N	EXCUSE	0
88706	88703	14093U	PARTICIPANT	\N	PRESENT	0
88707	88703	14030Q	PARTICIPANT	\N	PRESENT	0
88590	88561	14237S	PARTICIPANT	\N	PRESENT	0
88591	88561	13002U	PARTICIPANT	\N	PRESENT	0
88592	88561	05012A	PARTICIPANT	\N	PRESENT	0
88708	88703	96004D	PARTICIPANT	\N	PRESENT	0
88594	88561	14135M	PARTICIPANT	\N	PRESENT	0
88595	88561	14331P	PARTICIPANT	\N	PRESENT	0
88596	88561	95062K	PARTICIPANT	\N	PRESENT	0
88597	88561	14107H	PARTICIPANT	\N	PRESENT	0
88598	88561	14051J	PARTICIPANT	\N	PRESENT	0
88599	88561	14157T	PARTICIPANT	\N	PRESENT	0
88600	88561	96003C	PARTICIPANT	\N	EXCUSE	0
88709	88703	08060W	PARTICIPANT	\N	PRESENT	0
88711	88703	14038Y	PARTICIPANT	\N	PRESENT	0
88712	88703	11114F	PARTICIPANT	\N	PRESENT	0
88713	88703	98023Q	PARTICIPANT	\N	PRESENT	0
88714	88703	11065P	PARTICIPANT	\N	PRESENT	0
88715	88703	01015L	PARTICIPANT	\N	PRESENT	0
88716	88703	11107G	PARTICIPANT	\N	PRESENT	0
88717	88703	11020A	PARTICIPANT	\N	PRESENT	0
88718	88703	02002K	PARTICIPANT	\N	EXCUSE	0
88719	88703	01022K	PARTICIPANT	\N	PRESENT	0
88720	88703	04097T	PARTICIPANT	\N	PRESENT	0
88721	88703	09001P	PARTICIPANT	\N	PRESENT	0
88722	88703	11059R	PARTICIPANT	\N	PRESENT	0
88724	88703	80027E	PARTICIPANT	\N	PRESENT	0
88726	88703	08009T	PRESIDENT	0	PRESENT	0
88727	88703	08062Y	PARTICIPANT	\N	PRESENT	0
62822	62821	01016M	PARTICIPANT	\N	PRESENT	0
62823	62821	04035D	PARTICIPANT	\N	PRESENT	0
62825	62824	01019Q	PARTICIPANT	\N	PRESENT	0
73831	69102	14030Q	PARTICIPANT	\N	PRESENT	0
73832	69102	14105F	PARTICIPANT	\N	PRESENT	0
73833	69102	14083S	PARTICIPANT	\N	PRESENT	0
73834	69102	14151M	PARTICIPANT	\N	PRESENT	0
73835	69102	14087W	PARTICIPANT	\N	PRESENT	0
73836	69102	14121F	PARTICIPANT	\N	PRESENT	0
73837	69102	14039A	PARTICIPANT	\N	PRESENT	0
73838	69102	04049K	PRESIDENT	0	PRESENT	0
73839	69102	14265W	PARTICIPANT	\N	PRESENT	0
73840	69102	14253S	PARTICIPANT	\N	PRESENT	0
73841	69102	14157T	PARTICIPANT	\N	PRESENT	0
73842	69102	95067Q	PARTICIPANT	\N	PRESENT	0
73843	69102	89017R	PARTICIPANT	\N	EXCUSE	0
73844	69102	14261S	PARTICIPANT	\N	EXCUSE	0
73845	69102	14065Q	PARTICIPANT	\N	EXCUSE	0
73846	69102	14013P	PARTICIPANT	\N	EXCUSE	0
73847	69102	08068F	PARTICIPANT	\N	EXCUSE	0
73848	69102	04053F	PARTICIPANT	\N	EXCUSE	0
73849	69102	14207L	PARTICIPANT	\N	EXCUSE	0
73850	69102	14255U	PARTICIPANT	\N	EXCUSE	0
73851	69102	14079W	PARTICIPANT	\N	EXCUSE	0
73852	69102	04055H	PARTICIPANT	\N	EXCUSE	0
73853	69102	11088W	PARTICIPANT	\N	EXCUSE	0
73854	69102	14041T	PARTICIPANT	\N	EXCUSE	0
73855	69102	04071H	PARTICIPANT	\N	EXCUSE	0
73972	69102	14034U	PARTICIPANT	\N	EXCUSE	0
73973	69102	95041E	PARTICIPANT	\N	EXCUSE	0
73974	69102	14061L	PARTICIPANT	\N	EXCUSE	0
73975	69102	01043Q	PARTICIPANT	\N	EXCUSE	0
73976	69102	11077T	PARTICIPANT	\N	EXCUSE	0
73977	69102	11090Q	PARTICIPANT	\N	EXCUSE	0
73978	69102	10015M	PARTICIPANT	\N	EXCUSE	0
74149	69102	11063M	PARTICIPANT	\N	EXCUSE	0
74385	74383	08047A	PARTICIPANT	\N	PRESENT	0
75223	75222	14227Q	PARTICIPANT	\N	PRESENT	0
75669	75219	14231L	PARTICIPANT	\N	PRESENT	0
75671	75219	14083S	PARTICIPANT	\N	PRESENT	0
75672	75219	04089T	PARTICIPANT	\N	PRESENT	0
75673	75219	14265W	PARTICIPANT	\N	PRESENT	0
75674	75219	14179A	PARTICIPANT	\N	PRESENT	0
75675	75219	98042T	PARTICIPANT	\N	PRESENT	0
75676	75219	07004J	PARTICIPANT	\N	PRESENT	0
75678	75219	11085T	PARTICIPANT	\N	PRESENT	0
75680	75219	11070L	PARTICIPANT	\N	PRESENT	0
75681	75219	08056B	PARTICIPANT	\N	PRESENT	0
75684	75219	01025N	PARTICIPANT	\N	PRESENT	0
75685	75219	01007L	PARTICIPANT	\N	PRESENT	0
75686	75219	14327T	PARTICIPANT	\N	PRESENT	0
75687	75219	11042G	PARTICIPANT	\N	PRESENT	0
75688	75219	04071H	PARTICIPANT	\N	PRESENT	0
75689	75219	11112D	PARTICIPANT	\N	PRESENT	0
75691	75219	14235Q	PARTICIPANT	\N	PRESENT	0
75692	75219	04054G	PARTICIPANT	\N	PRESENT	0
87467	87186	01024M	PARTICIPANT	\N	PRESENT	0
87468	87186	14205J	PARTICIPANT	\N	PRESENT	0
87469	87186	14267Y	PARTICIPANT	\N	PRESENT	0
87470	87186	14103D	PARTICIPANT	\N	PRESENT	0
87471	87186	11111C	PARTICIPANT	\N	PRESENT	0
87472	87186	14275Y	PARTICIPANT	\N	PRESENT	0
87473	87186	97011G	PARTICIPANT	\N	PRESENT	0
87474	87186	77002U	PARTICIPANT	\N	PRESENT	0
87475	87186	14083S	PARTICIPANT	\N	PRESENT	0
87476	87186	11026G	PARTICIPANT	\N	PRESENT	0
87477	87186	14093U	PARTICIPANT	\N	PRESENT	0
87478	87186	04050C	PARTICIPANT	\N	PRESENT	0
87479	87186	04042C	PARTICIPANT	\N	PRESENT	0
87480	87186	01013J	PARTICIPANT	\N	PRESENT	0
87481	87186	14235Q	PARTICIPANT	\N	PRESENT	0
87482	87186	04054G	PARTICIPANT	\N	PRESENT	0
87483	87186	07029T	PARTICIPANT	\N	PRESENT	0
87484	87186	11034G	PARTICIPANT	\N	PRESENT	0
87485	87186	08011M	PARTICIPANT	\N	PRESENT	0
87486	87186	98023Q	PARTICIPANT	\N	PRESENT	0
87487	87186	11101A	PARTICIPANT	\N	PRESENT	0
87488	87186	01027Q	PARTICIPANT	\N	PRESENT	0
87489	87186	14197C	PARTICIPANT	\N	PRESENT	0
87490	87186	11076S	PARTICIPANT	\N	PRESENT	0
87491	87186	14173T	PARTICIPANT	\N	PRESENT	0
87492	87186	14123H	PARTICIPANT	\N	PRESENT	0
87493	87186	14179A	PARTICIPANT	\N	PRESENT	0
87494	87186	14089Y	PARTICIPANT	\N	PRESENT	0
87495	87186	95059Q	PARTICIPANT	\N	PRESENT	0
87496	87186	14209N	PARTICIPANT	\N	PRESENT	0
87497	87186	08065C	PARTICIPANT	\N	PRESENT	0
87498	87186	11020A	PARTICIPANT	\N	PRESENT	0
87499	87186	04071H	PARTICIPANT	\N	PRESENT	0
87500	87186	01016M	PARTICIPANT	\N	PRESENT	0
87501	87186	08047A	PARTICIPANT	\N	PRESENT	0
87502	87186	98029W	PARTICIPANT	\N	PRESENT	0
87503	87186	08010L	PARTICIPANT	\N	PRESENT	0
87504	87186	14041T	PARTICIPANT	\N	PRESENT	0
87505	87186	11088W	PARTICIPANT	\N	PRESENT	0
87506	87186	14215L	PARTICIPANT	\N	PRESENT	0
87507	87186	14199E	PARTICIPANT	\N	PRESENT	0
87508	87186	11048N	PARTICIPANT	\N	PRESENT	0
87509	87186	08039A	PARTICIPANT	\N	PRESENT	0
87510	87186	05012A	PARTICIPANT	\N	PRESENT	0
87511	87186	14053L	PARTICIPANT	\N	PRESENT	0
87512	87186	11053K	PARTICIPANT	\N	PRESENT	0
87513	87186	14251Q	PARTICIPANT	\N	PRESENT	0
87514	87186	14034U	PARTICIPANT	\N	PRESENT	0
87515	87186	07004J	PARTICIPANT	\N	PRESENT	0
87516	87186	04078Q	PARTICIPANT	\N	PRESENT	0
87517	87186	08044W	PARTICIPANT	\N	PRESENT	0
87518	87186	14157T	PARTICIPANT	\N	PRESENT	0
87519	87186	05004A	PARTICIPANT	\N	PRESENT	0
87520	87186	01014K	PARTICIPANT	\N	PRESENT	0
87529	87186	10015M	PARTICIPANT	\N	PRESENT	0
87522	87186	14018U	PARTICIPANT	\N	PRESENT	0
87523	87186	08060W	PARTICIPANT	\N	PRESENT	0
87524	87186	04047H	PARTICIPANT	\N	PRESENT	0
87525	87186	14225N	PARTICIPANT	\N	PRESENT	0
87526	87186	11090Q	PARTICIPANT	\N	PRESENT	0
87527	87186	14135M	PARTICIPANT	\N	PRESENT	0
87531	87186	90003B	PARTICIPANT	\N	PRESENT	0
87530	87186	11044J	PARTICIPANT	\N	PRESENT	0
87538	87186	14237S	PARTICIPANT	\N	PRESENT	0
87533	87186	14195A	PARTICIPANT	\N	PRESENT	0
87534	87186	98053W	PARTICIPANT	\N	PRESENT	0
87535	87186	11037K	PARTICIPANT	\N	PRESENT	0
87536	87186	11112D	PARTICIPANT	\N	PRESENT	0
87540	87186	14271U	PARTICIPANT	\N	PRESENT	0
87539	87186	01007L	PARTICIPANT	\N	PRESENT	0
87541	87186	04045F	PARTICIPANT	\N	PRESENT	0
87543	87186	95037J	PARTICIPANT	\N	PRESENT	0
87544	87542	01043Q	PARTICIPANT	\N	PRESENT	0
87545	87186	01003G	PARTICIPANT	\N	PRESENT	0
87546	87186	01056V	PARTICIPANT	\N	PRESENT	0
87547	87186	11015D	PARTICIPANT	\N	PRESENT	0
87548	87186	08028W	PARTICIPANT	\N	PRESENT	0
87549	87186	08038Y	PARTICIPANT	\N	PRESENT	0
87550	87186	14269B	PARTICIPANT	\N	PRESENT	0
87551	87186	13002U	PARTICIPANT	\N	PRESENT	0
87552	87186	08043V	PARTICIPANT	\N	PRESENT	0
87553	87186	11032E	PARTICIPANT	\N	PRESENT	0
87554	87186	11083R	PARTICIPANT	\N	PRESENT	0
87555	87186	11074Q	PARTICIPANT	\N	PRESENT	0
87556	87186	89017R	PARTICIPANT	\N	PRESENT	0
87560	87186	04055H	PARTICIPANT	\N	PRESENT	0
87558	87186	11064N	PARTICIPANT	\N	PRESENT	0
87559	87186	11068S	PARTICIPANT	\N	PRESENT	0
87561	87187	86034E	PARTICIPANT	\N	PRESENT	0
87562	87187	14223L	PARTICIPANT	\N	PRESENT	0
87563	87187	14026U	PARTICIPANT	\N	PRESENT	0
87564	87187	04077P	PARTICIPANT	\N	PRESENT	0
87565	87187	04074L	PARTICIPANT	\N	PRESENT	0
87566	87187	11025F	PARTICIPANT	\N	PRESENT	0
87567	87187	14105F	PARTICIPANT	\N	PRESENT	0
87568	87187	14247U	PARTICIPANT	\N	PRESENT	0
87569	87187	14201E	PARTICIPANT	\N	PRESENT	0
87570	87187	08017T	PARTICIPANT	\N	PRESENT	0
87571	87187	11091R	PARTICIPANT	\N	PRESENT	0
87572	87187	99004R	PARTICIPANT	\N	PRESENT	0
87573	87187	04036E	PARTICIPANT	\N	PRESENT	0
87574	87187	11012A	PARTICIPANT	\N	PRESENT	0
87575	87187	14259Y	PARTICIPANT	\N	PRESENT	0
87576	87187	11106F	PARTICIPANT	\N	PRESENT	0
87577	87187	14227Q	PARTICIPANT	\N	PRESENT	0
87578	87187	11035H	PARTICIPANT	\N	PRESENT	0
87579	87187	14277B	PARTICIPANT	\N	PRESENT	0
87580	87187	80013X	PARTICIPANT	\N	PRESENT	0
87581	87187	14042U	PARTICIPANT	\N	PRESENT	0
77984	75076	01022K	PARTICIPANT	\N	EXCUSE	0
78012	78011	04055H	PARTICIPANT	\N	PRESENT	0
78014	78013	11083R	PARTICIPANT	\N	PRESENT	0
78016	78015	11083R	PARTICIPANT	\N	PRESENT	0
78018	78017	11074Q	PARTICIPANT	\N	PRESENT	0
78019	78017	11083R	PARTICIPANT	\N	PRESENT	0
78021	78020	04086Q	PARTICIPANT	\N	PRESENT	0
78050	78049	08042U	PARTICIPANT	\N	PRESENT	0
78051	78049	98035U	PARTICIPANT	\N	PRESENT	0
78053	78052	08042U	PARTICIPANT	\N	PRESENT	0
78054	78052	98035U	PARTICIPANT	\N	PRESENT	0
78056	78055	08042U	PARTICIPANT	\N	PRESENT	0
78057	78055	98035U	PARTICIPANT	\N	PRESENT	0
78059	78058	08042U	PARTICIPANT	\N	PRESENT	0
78060	78058	98035U	PARTICIPANT	\N	PRESENT	0
78062	78061	08042U	PARTICIPANT	\N	PRESENT	0
78063	78061	98035U	PARTICIPANT	\N	PRESENT	0
78065	78064	14273W	PARTICIPANT	\N	PRESENT	0
78069	78068	14273W	PARTICIPANT	\N	PRESENT	0
78072	78071	14273W	PARTICIPANT	\N	PRESENT	0
79381	78235	95041E	PARTICIPANT	\N	PRESENT	0
79382	78235	04088S	PARTICIPANT	\N	PRESENT	0
79383	78235	14089Y	PARTICIPANT	\N	PRESENT	0
79389	78235	11053K	PARTICIPANT	\N	PRESENT	0
79410	78235	95035G	PARTICIPANT	\N	PRESENT	0
79416	78235	08025T	PARTICIPANT	\N	PRESENT	0
79471	78238	14033T	PARTICIPANT	\N	PRESENT	0
79472	78238	14121F	PARTICIPANT	\N	PRESENT	0
79473	78238	14331P	PARTICIPANT	\N	PRESENT	0
79474	78238	04088S	PARTICIPANT	\N	PRESENT	0
79475	78238	01037S	PARTICIPANT	\N	PRESENT	0
79476	78238	11020A	PARTICIPANT	\N	PRESENT	0
79477	78238	14191V	PARTICIPANT	\N	PRESENT	0
79478	78238	14173T	PARTICIPANT	\N	PRESENT	0
79479	78238	14159V	PARTICIPANT	\N	PRESENT	0
79480	78238	14193X	PARTICIPANT	\N	PRESENT	0
79481	78238	08068F	PARTICIPANT	\N	PRESENT	0
79482	78238	14053L	PARTICIPANT	\N	PRESENT	0
79483	78238	14227Q	PARTICIPANT	\N	PRESENT	0
79485	78238	14157T	PARTICIPANT	\N	PRESENT	0
79486	78238	11066Q	PARTICIPANT	\N	PRESENT	0
79487	78238	95030B	PARTICIPANT	\N	PRESENT	0
79512	78238	92020L	PARTICIPANT	\N	PRESENT	0
79489	78238	11015D	PARTICIPANT	\N	PRESENT	0
79377	78235	14133K	PARTICIPANT	\N	PRESENT	0
79380	78235	14041T	PARTICIPANT	\N	PRESENT	0
79511	78238	11023D	PARTICIPANT	\N	PRESENT	0
79491	78238	14133K	PARTICIPANT	\N	PRESENT	0
79492	78238	11012A	PARTICIPANT	\N	PRESENT	0
79493	78238	04049K	PARTICIPANT	\N	PRESENT	0
79494	78238	14073Q	PARTICIPANT	\N	PRESENT	0
79495	78238	14241N	PARTICIPANT	\N	PRESENT	0
79496	78238	10006L	PARTICIPANT	\N	PRESENT	0
79498	78238	14061L	PARTICIPANT	\N	PRESENT	0
79502	78238	99004R	PARTICIPANT	\N	PRESENT	0
79503	78238	14267Y	PARTICIPANT	\N	PRESENT	0
79506	78238	14219Q	PARTICIPANT	\N	PRESENT	0
79508	78238	14147R	PARTICIPANT	\N	PRESENT	0
79509	78238	11080N	PARTICIPANT	\N	PRESENT	0
79510	78238	01025N	PARTICIPANT	\N	PRESENT	0
79513	78238	86044G	PARTICIPANT	\N	PRESENT	0
79514	78238	87003B	PARTICIPANT	\N	PRESENT	0
79515	78238	11081P	PARTICIPANT	\N	PRESENT	0
79516	78238	08065C	PARTICIPANT	\N	PRESENT	0
79517	78238	07026Q	PARTICIPANT	\N	PRESENT	0
79519	78238	92044U	PARTICIPANT	\N	PRESENT	0
79520	78238	14249W	PARTICIPANT	\N	PRESENT	0
79521	78238	11061K	PARTICIPANT	\N	PRESENT	0
79522	78238	14030Q	PARTICIPANT	\N	PRESENT	0
79523	78238	80013X	PARTICIPANT	\N	PRESENT	0
79525	78238	08015R	PARTICIPANT	\N	PRESENT	0
79526	78238	97011G	PARTICIPANT	\N	PRESENT	0
79527	78238	01027Q	PARTICIPANT	\N	PRESENT	0
79528	78238	04066L	PARTICIPANT	\N	PRESENT	0
79529	78238	11056N	PARTICIPANT	\N	PRESENT	0
79530	78238	14201E	PARTICIPANT	\N	PRESENT	0
79531	78238	11040E	PARTICIPANT	\N	PRESENT	0
79532	78238	14281W	PARTICIPANT	\N	PRESENT	0
79469	78238	86034E	PARTICIPANT	\N	PRESENT	0
79533	78238	98018T	PARTICIPANT	\N	PRESENT	0
79534	78238	01016M	PARTICIPANT	\N	PRESENT	0
79535	78238	14037X	PARTICIPANT	\N	PRESENT	0
79536	78238	08052W	PARTICIPANT	\N	PRESENT	0
79537	78238	11046L	PARTICIPANT	\N	PRESENT	0
79538	78238	04074L	PARTICIPANT	\N	PRESENT	0
79539	78238	11107G	PARTICIPANT	\N	PRESENT	0
79540	78238	11105E	PARTICIPANT	\N	PRESENT	0
79541	78238	04086Q	PARTICIPANT	\N	PRESENT	0
79542	78238	11042G	PARTICIPANT	\N	PRESENT	0
79543	78238	95041E	PARTICIPANT	\N	PRESENT	0
79544	78238	11067R	PARTICIPANT	\N	PRESENT	0
79545	78238	12041X	PARTICIPANT	\N	PRESENT	0
79546	78238	14013P	PARTICIPANT	\N	PRESENT	0
79547	78238	11097X	PARTICIPANT	\N	PRESENT	0
79548	78238	08055A	PARTICIPANT	\N	PRESENT	0
79549	78238	14107H	PARTICIPANT	\N	PRESENT	0
79550	78238	04054G	PARTICIPANT	\N	PRESENT	0
79551	78238	08053X	PARTICIPANT	\N	PRESENT	0
79552	78238	08014Q	PARTICIPANT	\N	PRESENT	0
79553	78238	95015C	PARTICIPANT	\N	PRESENT	0
79554	78238	14063N	PARTICIPANT	\N	PRESENT	0
79555	78238	11032E	PARTICIPANT	\N	PRESENT	0
79556	78238	14031R	PARTICIPANT	\N	PRESENT	0
79557	78238	01056V	PARTICIPANT	\N	PRESENT	0
79558	78238	01013J	PARTICIPANT	\N	PRESENT	0
79559	78238	02002K	PARTICIPANT	\N	PRESENT	0
79560	78238	96004D	PARTICIPANT	\N	PRESENT	0
79561	78238	07034Q	PARTICIPANT	\N	PRESENT	0
79562	78238	11104D	PARTICIPANT	\N	PRESENT	0
79563	78238	12042Y	PARTICIPANT	\N	PRESENT	0
79564	78238	14026U	PARTICIPANT	\N	PRESENT	0
79565	78238	01011G	PARTICIPANT	\N	PRESENT	0
79566	78238	95035G	PARTICIPANT	\N	PRESENT	0
79567	78238	92045V	PARTICIPANT	\N	PRESENT	0
79571	78238	14265W	PARTICIPANT	\N	PRESENT	0
79569	78238	14205J	PARTICIPANT	\N	PRESENT	0
79570	78238	14255U	PARTICIPANT	\N	PRESENT	0
79572	78238	95049N	PARTICIPANT	\N	PRESENT	0
79573	78238	98023Q	PARTICIPANT	\N	PRESENT	0
79574	78238	11033F	PARTICIPANT	\N	PRESENT	0
79575	78238	14079W	PARTICIPANT	\N	PRESENT	0
79576	78238	14275Y	PARTICIPANT	\N	PRESENT	0
79577	78238	14273W	PARTICIPANT	\N	PRESENT	0
79578	78238	01058X	PARTICIPANT	\N	PRESENT	0
79579	78238	07024N	PARTICIPANT	\N	PRESENT	0
79580	78238	14059S	PARTICIPANT	\N	PRESENT	0
79581	78238	11071M	PARTICIPANT	\N	PRESENT	0
79582	78238	08019V	PARTICIPANT	\N	PRESENT	0
79583	78238	08034U	PARTICIPANT	\N	PRESENT	0
79584	78238	98053W	PARTICIPANT	\N	PRESENT	0
79585	78238	04085P	PARTICIPANT	\N	PRESENT	0
79586	78238	14169X	PARTICIPANT	\N	PRESENT	0
79587	78238	92018S	PARTICIPANT	\N	PRESENT	0
79588	78238	04035D	PARTICIPANT	\N	PRESENT	0
79589	78238	11031D	PARTICIPANT	\N	PRESENT	0
79590	78238	11098Y	PARTICIPANT	\N	PRESENT	0
79591	78238	11048N	PARTICIPANT	\N	PRESENT	0
79592	78238	11036J	PARTICIPANT	\N	PRESENT	0
79593	78238	95059Q	PARTICIPANT	\N	PRESENT	0
79594	78238	80027E	PARTICIPANT	\N	PRESENT	0
79595	78238	01057W	PARTICIPANT	\N	PRESENT	0
79596	78238	95037J	PARTICIPANT	\N	PRESENT	0
79597	78238	08010L	PARTICIPANT	\N	PRESENT	0
79598	78238	14151M	PARTICIPANT	\N	PRESENT	0
79599	78238	08012N	PARTICIPANT	\N	PRESENT	0
79600	78238	11053K	PARTICIPANT	\N	PRESENT	0
79601	78238	14001X	PARTICIPANT	\N	PRESENT	0
79602	78238	14259Y	PARTICIPANT	\N	PRESENT	0
79603	78238	11059R	PARTICIPANT	\N	PRESENT	0
79604	78238	11049P	PARTICIPANT	\N	PRESENT	0
79605	78238	14135M	PARTICIPANT	\N	PRESENT	0
79606	78238	98046X	PARTICIPANT	\N	PRESENT	0
79607	78238	08060W	PARTICIPANT	\N	PRESENT	0
79608	78238	14069U	PARTICIPANT	\N	PRESENT	0
79609	78238	01031L	PARTICIPANT	\N	PRESENT	0
79610	78238	11089X	PARTICIPANT	\N	PRESENT	0
79611	78238	11090Q	PARTICIPANT	\N	PRESENT	0
79612	78238	11074Q	PARTICIPANT	\N	PRESENT	0
79613	78238	14097Y	PARTICIPANT	\N	PRESENT	0
79614	78238	14257W	PARTICIPANT	\N	PRESENT	0
79615	78238	11091R	PARTICIPANT	\N	PRESENT	0
79616	78238	14207L	PARTICIPANT	\N	PRESENT	0
79617	78238	14065Q	PARTICIPANT	\N	PRESENT	0
79618	78238	01043Q	PARTICIPANT	\N	PRESENT	0
79619	78238	11109J	PARTICIPANT	\N	PRESENT	0
79620	78238	04079R	PARTICIPANT	\N	PRESENT	0
64018	63994	05012A	PARTICIPANT	\N	PRESENT	0
64020	64019	05012A	PARTICIPANT	\N	PRESENT	0
64021	64019	11101A	PARTICIPANT	\N	PRESENT	0
64022	64019	08038Y	PARTICIPANT	\N	PRESENT	0
64023	60592	11113E	PARTICIPANT	\N	EXCUSE	0
66013	66012	04054G	PARTICIPANT	\N	EXCUSE	0
66014	66012	96004D	PRESIDENT	0	PRESENT	0
66015	66012	14089Y	PARTICIPANT	\N	EXCUSE	0
66016	66012	90003B	PARTICIPANT	\N	PRESENT	0
66017	66012	11035H	PARTICIPANT	\N	EXCUSE	0
66018	66012	14249W	PARTICIPANT	\N	PRESENT	0
66019	66012	08018U	PARTICIPANT	\N	EXCUSE	0
66020	66012	11083R	PARTICIPANT	\N	PRESENT	0
66021	66012	14026U	PARTICIPANT	\N	EXCUSE	0
66022	66012	14073Q	PARTICIPANT	\N	PRESENT	0
66023	66012	11026G	PARTICIPANT	\N	PRESENT	0
66024	66012	98046X	PARTICIPANT	\N	PRESENT	0
66025	66012	14001X	PARTICIPANT	\N	PRESENT	0
66026	66012	04057K	PARTICIPANT	\N	PRESENT	0
66068	66012	04080J	PARTICIPANT	\N	EXCUSE	0
66070	66012	14135M	PARTICIPANT	\N	PRESENT	0
66071	66012	01016M	PARTICIPANT	\N	PRESENT	0
66072	66012	10015M	PARTICIPANT	\N	PRESENT	0
66073	66012	04045F	PARTICIPANT	\N	PRESENT	0
66074	66012	98035U	PARTICIPANT	\N	EXCUSE	0
66075	66012	92045V	PARTICIPANT	\N	PRESENT	0
66082	66012	14133K	PARTICIPANT	\N	EXCUSE	0
66083	66012	14097Y	PARTICIPANT	\N	EXCUSE	0
66622	66621	07024N	PARTICIPANT	\N	PRESENT	0
66623	66621	01014K	PARTICIPANT	\N	PRESENT	0
66637	66636	11015D	PARTICIPANT	\N	PRESENT	0
66638	66636	92031P	PARTICIPANT	\N	PRESENT	0
66647	66646	11015D	PARTICIPANT	\N	PRESENT	0
66648	66646	92031P	PARTICIPANT	\N	PRESENT	0
66649	66646	11105E	PARTICIPANT	\N	PRESENT	0
66654	66653	11015D	PARTICIPANT	\N	PRESENT	0
66655	66653	92031P	PARTICIPANT	\N	PRESENT	0
66656	66653	11105E	PARTICIPANT	\N	PRESENT	0
75214	75213	08011M	PARTICIPANT	\N	PRESENT	0
75216	75215	08011M	PARTICIPANT	\N	PRESENT	0
75217	75215	04086Q	PARTICIPANT	\N	PRESENT	0
75328	75327	08016S	PARTICIPANT	\N	PRESENT	0
75338	75334	01027Q	PARTICIPANT	\N	PRESENT	0
75359	75355	01048V	PARTICIPANT	\N	PRESENT	0
75379	75377	01031L	PARTICIPANT	\N	PRESENT	0
75392	75389	01048V	PARTICIPANT	\N	PRESENT	0
82549	82537	08038Y	PARTICIPANT	\N	PRESENT	0
82550	82537	04089T	PARTICIPANT	\N	PRESENT	0
82551	82537	14197C	PARTICIPANT	\N	PRESENT	0
82552	82537	11110B	PARTICIPANT	\N	PRESENT	0
82553	82537	14187A	PARTICIPANT	\N	PRESENT	0
82554	82537	14033T	PARTICIPANT	\N	PRESENT	0
82585	82584	01008M	PARTICIPANT	\N	PRESENT	0
82556	82537	04048J	PARTICIPANT	\N	PRESENT	0
82557	82537	11099A	PARTICIPANT	\N	PRESENT	0
82558	82537	04049K	PARTICIPANT	\N	PRESENT	0
82586	82584	11036J	PARTICIPANT	\N	PRESENT	0
82560	82537	11111C	PARTICIPANT	\N	PRESENT	0
82561	82537	08015R	PARTICIPANT	\N	PRESENT	0
82562	82537	11100Y	PRESIDENT	0	PRESENT	0
82563	82537	01061S	PARTICIPANT	\N	PRESENT	0
82564	82537	11098Y	PARTICIPANT	\N	PRESENT	0
82565	82537	01043Q	PARTICIPANT	\N	EXCUSE	0
82566	82537	11077T	PARTICIPANT	\N	PRESENT	0
82567	82537	14205J	PARTICIPANT	\N	PRESENT	0
82568	82537	08019V	PARTICIPANT	\N	PRESENT	0
82569	82537	14257W	PARTICIPANT	\N	PRESENT	0
82627	82625	14133K	PARTICIPANT	\N	PRESENT	0
82571	82537	04088S	PARTICIPANT	\N	PRESENT	0
82670	82669	11039M	PARTICIPANT	\N	PRESENT	0
82573	82537	11090Q	PARTICIPANT	\N	PRESENT	0
82574	82537	11046L	PARTICIPANT	\N	PRESENT	0
82575	82537	01058X	PARTICIPANT	\N	PRESENT	0
82576	82537	11094U	PARTICIPANT	\N	PRESENT	0
82577	82537	11066Q	PARTICIPANT	\N	PRESENT	0
82588	82584	14013P	PARTICIPANT	\N	PRESENT	0
82671	82669	98042T	PARTICIPANT	\N	PRESENT	0
82590	82584	14207L	PARTICIPANT	\N	PRESENT	0
82591	82584	11101A	PARTICIPANT	\N	PRESENT	0
82592	82584	90003B	PARTICIPANT	\N	PRESENT	0
82593	82584	08028W	PARTICIPANT	\N	PRESENT	0
82594	82584	80013X	PARTICIPANT	\N	PRESENT	0
82595	82584	08038Y	PARTICIPANT	\N	PRESENT	0
82596	82584	04089T	PARTICIPANT	\N	PRESENT	0
82597	82584	14197C	PARTICIPANT	\N	PRESENT	0
82598	82584	11110B	PARTICIPANT	\N	PRESENT	0
82599	82584	14187A	PARTICIPANT	\N	PRESENT	0
82600	82584	14033T	PARTICIPANT	\N	PRESENT	0
82672	82669	01019Q	PARTICIPANT	\N	PRESENT	0
82602	82584	04048J	PARTICIPANT	\N	PRESENT	0
82631	82626	14030Q	PARTICIPANT	\N	PRESENT	0
82604	82584	04049K	PARTICIPANT	\N	PRESENT	0
82673	77795	08065C	PARTICIPANT	\N	EXCUSE	0
82606	82584	11111C	PARTICIPANT	\N	PRESENT	0
82607	82584	08015R	PARTICIPANT	\N	PRESENT	0
82608	82584	11100Y	PRESIDENT	0	PRESENT	0
82609	82584	01061S	PARTICIPANT	\N	PRESENT	0
82610	82584	11098Y	PARTICIPANT	\N	PRESENT	0
82611	82584	01043Q	PARTICIPANT	\N	PRESENT	0
82612	82584	11077T	PARTICIPANT	\N	PRESENT	0
82613	82584	14205J	PARTICIPANT	\N	PRESENT	0
82675	82674	14073Q	PARTICIPANT	\N	PRESENT	0
82615	82584	14257W	PARTICIPANT	\N	PRESENT	0
82616	82584	08021P	PARTICIPANT	\N	PRESENT	0
82617	82584	04088S	PARTICIPANT	\N	PRESENT	0
82634	82626	11095V	PARTICIPANT	\N	PRESENT	0
82619	82584	11090Q	PARTICIPANT	\N	PRESENT	0
82620	82584	11046L	PARTICIPANT	\N	PRESENT	0
82667	82625	14097Y	PARTICIPANT	\N	PRESENT	0
82622	82584	11094U	PARTICIPANT	\N	PRESENT	0
82623	82584	11066Q	PARTICIPANT	\N	PRESENT	0
82635	82626	14038Y	PARTICIPANT	\N	PRESENT	0
82676	82674	04054G	PARTICIPANT	\N	PRESENT	0
82736	82735	08022Q	PARTICIPANT	\N	PRESENT	0
82638	82626	11065P	PARTICIPANT	\N	PRESENT	0
82639	82626	01015L	PARTICIPANT	\N	PRESENT	0
82640	82626	11107G	PARTICIPANT	\N	PRESENT	0
82737	82735	99004R	PARTICIPANT	\N	PRESENT	0
82738	82735	04061F	PARTICIPANT	\N	PRESENT	0
82643	82626	01022K	PARTICIPANT	\N	PRESENT	0
82644	82626	04097T	PARTICIPANT	\N	PRESENT	0
82645	82626	09001P	PARTICIPANT	\N	EXCUSE	0
82739	82735	08061X	PARTICIPANT	\N	PRESENT	0
82647	82626	14219Q	PARTICIPANT	\N	PRESENT	0
82648	82626	80027E	PARTICIPANT	\N	PRESENT	0
82649	82626	14031R	PARTICIPANT	\N	PRESENT	0
82650	82626	08009T	PRESIDENT	0	PRESENT	0
82651	82626	08062Y	PARTICIPANT	\N	PRESENT	0
82740	82735	01016M	PARTICIPANT	\N	PRESENT	0
82653	82626	92039X	PARTICIPANT	\N	EXCUSE	0
82654	82626	08042U	PARTICIPANT	\N	PRESENT	0
82655	82626	14169X	PARTICIPANT	\N	PRESENT	0
82656	82626	14237S	PARTICIPANT	\N	PRESENT	0
82741	82354	08012N	PARTICIPANT	\N	EXCUSE	0
82658	82626	05012A	PARTICIPANT	\N	PRESENT	0
82660	82626	14135M	PARTICIPANT	\N	PRESENT	0
82661	82626	14331P	PARTICIPANT	\N	PRESENT	0
82662	82626	95062K	PARTICIPANT	\N	PRESENT	0
82663	82626	14107H	PARTICIPANT	\N	PRESENT	0
82664	82626	14051J	PARTICIPANT	\N	PRESENT	0
82665	82626	14157T	PARTICIPANT	\N	PRESENT	0
82666	82626	96003C	PARTICIPANT	\N	EXCUSE	0
82668	82625	04080J	PARTICIPANT	\N	PRESENT	0
82787	82770	08055A	PARTICIPANT	\N	PRESENT	0
82789	82770	14030Q	PARTICIPANT	\N	PRESENT	0
82791	82770	08060W	PARTICIPANT	\N	PRESENT	0
82792	82770	11095V	PARTICIPANT	\N	PRESENT	0
82795	82770	98023Q	PARTICIPANT	\N	PRESENT	0
82797	82770	01015L	PARTICIPANT	\N	PRESENT	0
82798	82770	11107G	PARTICIPANT	\N	PRESENT	0
82800	82770	02002K	PARTICIPANT	\N	PRESENT	0
82801	82770	01022K	PARTICIPANT	\N	PRESENT	0
82802	82770	04097T	PARTICIPANT	\N	PRESENT	0
82803	82770	09001P	PARTICIPANT	\N	EXCUSE	0
82805	82770	14219Q	PARTICIPANT	\N	PRESENT	0
76538	75073	01022K	PARTICIPANT	\N	EXCUSE	0
77605	77601	01034P	PARTICIPANT	\N	PRESENT	0
77606	77601	08052W	PARTICIPANT	\N	PRESENT	0
77617	77616	11015D	PARTICIPANT	\N	PRESENT	0
77618	77616	92031P	PARTICIPANT	\N	PRESENT	0
77941	77939	04059M	PARTICIPANT	\N	PRESENT	0
77942	77939	01044R	PARTICIPANT	\N	PRESENT	0
77943	77939	14089Y	PARTICIPANT	\N	PRESENT	0
77944	77939	14105F	PARTICIPANT	\N	PRESENT	0
77945	77939	11029K	PARTICIPANT	\N	PRESENT	0
77946	77939	95015C	PARTICIPANT	\N	PRESENT	0
77947	77939	92015P	PARTICIPANT	\N	EXCUSE	0
77949	77939	14201E	PARTICIPANT	\N	EXCUSE	0
77950	77939	11091R	PARTICIPANT	\N	PRESENT	0
77951	77939	14249W	PARTICIPANT	\N	PRESENT	0
77952	77939	01025N	PARTICIPANT	\N	PRESENT	0
77954	77939	01037S	PARTICIPANT	\N	PRESENT	0
77955	77939	11089X	PARTICIPANT	\N	PRESENT	0
77956	77939	14123H	PARTICIPANT	\N	PRESENT	0
77957	77939	14179A	PARTICIPANT	\N	PRESENT	0
77958	77939	14241N	PARTICIPANT	\N	PRESENT	0
77960	77939	14073Q	PARTICIPANT	\N	PRESENT	0
77961	77939	08031R	PARTICIPANT	\N	EXCUSE	0
77962	77939	08017T	PARTICIPANT	\N	PRESENT	0
77963	77939	08012N	PARTICIPANT	\N	PRESENT	0
77969	77939	11104D	PARTICIPANT	\N	PRESENT	0
77970	77939	14063N	PARTICIPANT	\N	PRESENT	0
77971	77939	04057K	PARTICIPANT	\N	PRESENT	0
77973	77939	11014C	PARTICIPANT	\N	EXCUSE	0
77974	77939	04070G	PRESIDENT	0	PRESENT	0
77975	77939	83047W	PARTICIPANT	\N	PRESENT	0
77976	77939	14229S	PARTICIPANT	\N	PRESENT	0
77977	77939	11043H	PARTICIPANT	\N	PRESENT	0
84399	83952	11035H	PARTICIPANT	\N	EXCUSE	0
87155	87154	11039M	PARTICIPANT	\N	PRESENT	0
87156	87154	98042T	PARTICIPANT	\N	PRESENT	0
87157	87154	01019Q	PARTICIPANT	\N	PRESENT	0
88801	87172	11085T	PARTICIPANT	\N	PRESENT	0
88802	87172	09001P	PARTICIPANT	\N	PRESENT	0
88867	87172	07026Q	PARTICIPANT	\N	PRESENT	0
88868	87172	11029K	PARTICIPANT	\N	PRESENT	0
88869	87172	04035D	PARTICIPANT	\N	PRESENT	0
88870	87172	08043V	PARTICIPANT	\N	PRESENT	0
88871	87172	08069G	PARTICIPANT	\N	PRESENT	0
88872	87172	95035G	PARTICIPANT	\N	PRESENT	0
88873	87172	07029T	PARTICIPANT	\N	PRESENT	0
88874	87172	14042U	PARTICIPANT	\N	PRESENT	0
88875	87172	14267Y	PARTICIPANT	\N	PRESENT	0
88876	87172	14121F	PARTICIPANT	\N	PRESENT	0
88877	87172	01015L	PARTICIPANT	\N	PRESENT	0
88878	87172	14105F	PARTICIPANT	\N	PRESENT	0
88879	87172	11098Y	PARTICIPANT	\N	PRESENT	0
88880	87172	14261S	PARTICIPANT	\N	PRESENT	0
88881	87172	08017T	PARTICIPANT	\N	PRESENT	0
88882	87172	14241N	PARTICIPANT	\N	PRESENT	0
88883	87172	11031D	PARTICIPANT	\N	PRESENT	0
88885	87172	14187A	PARTICIPANT	\N	PRESENT	0
88941	87172	08031R	PARTICIPANT	\N	PRESENT	0
88945	87172	14063N	PARTICIPANT	\N	PRESENT	0
88947	87172	14079W	PARTICIPANT	\N	PRESENT	0
88948	87172	14033T	PARTICIPANT	\N	PRESENT	0
88949	87172	11100Y	PARTICIPANT	\N	PRESENT	0
88950	87172	01008M	PARTICIPANT	\N	PRESENT	0
88951	87172	97011G	PARTICIPANT	\N	PRESENT	0
88952	87172	14259Y	PARTICIPANT	\N	PRESENT	0
88969	87172	11066Q	PARTICIPANT	\N	PRESENT	0
88971	87172	14014Q	PARTICIPANT	\N	PRESENT	0
88978	87172	11093T	PARTICIPANT	\N	PRESENT	0
88979	87172	14213J	PARTICIPANT	\N	PRESENT	0
88980	87172	11081P	PARTICIPANT	\N	PRESENT	0
88981	87172	01060R	PARTICIPANT	\N	PRESENT	0
88982	87172	80013X	PARTICIPANT	\N	PRESENT	0
88983	87172	11042G	PARTICIPANT	\N	PRESENT	0
88984	87172	14083S	PARTICIPANT	\N	PRESENT	0
88985	87172	14235Q	PARTICIPANT	\N	PRESENT	0
88986	87172	11034G	PARTICIPANT	\N	PRESENT	0
88987	87172	11012A	PARTICIPANT	\N	PRESENT	0
88988	87172	14037X	PARTICIPANT	\N	PRESENT	0
88989	87172	04059M	PARTICIPANT	\N	PRESENT	0
88990	87172	08055A	PARTICIPANT	\N	PRESENT	0
88991	87172	14159V	PARTICIPANT	\N	PRESENT	0
88992	87172	14199E	PARTICIPANT	\N	PRESENT	0
88993	87172	04081K	PARTICIPANT	\N	PRESENT	0
88994	87172	11049P	PARTICIPANT	\N	PRESENT	0
89005	87172	13002U	PARTICIPANT	\N	PRESENT	0
89009	87172	14018U	PARTICIPANT	\N	PRESENT	0
89010	87172	11048N	PARTICIPANT	\N	PRESENT	0
89011	87172	14251Q	PARTICIPANT	\N	PRESENT	0
89012	87172	01024M	PARTICIPANT	\N	PRESENT	0
89013	87172	11111C	PARTICIPANT	\N	PRESENT	0
89014	87173	11085T	PARTICIPANT	\N	PRESENT	0
89070	87173	07026Q	PARTICIPANT	\N	PRESENT	0
89071	87173	14241N	PARTICIPANT	\N	PRESENT	0
89072	87173	83047W	PARTICIPANT	\N	PRESENT	0
89073	87173	14179A	PARTICIPANT	\N	PRESENT	0
89074	87173	04035D	PARTICIPANT	\N	PRESENT	0
89077	87173	14038Y	PARTICIPANT	\N	PRESENT	0
89021	87173	07029T	PARTICIPANT	\N	PRESENT	0
89078	87173	14249W	PARTICIPANT	\N	PRESENT	0
89126	87174	07026Q	PARTICIPANT	\N	PRESENT	0
89024	87173	14261S	PARTICIPANT	\N	PRESENT	0
89127	87174	83047W	PARTICIPANT	\N	PRESENT	0
89128	87174	01044R	PARTICIPANT	\N	PRESENT	0
89129	87174	14061L	PARTICIPANT	\N	PRESENT	0
89130	87174	14249W	PARTICIPANT	\N	PRESENT	0
89029	87173	08031R	PARTICIPANT	\N	PRESENT	0
89131	87174	08031R	PARTICIPANT	\N	PRESENT	0
89132	87174	14033T	PARTICIPANT	\N	PRESENT	0
89032	87173	11100Y	PARTICIPANT	\N	PRESENT	0
89133	87174	14038Y	PARTICIPANT	\N	PRESENT	0
89134	87174	14123H	PARTICIPANT	\N	PRESENT	0
89135	87174	11012A	PARTICIPANT	\N	PRESENT	0
89036	87173	14014Q	PARTICIPANT	\N	PRESENT	0
89136	87174	14261S	PARTICIPANT	\N	PRESENT	0
89038	87173	11081P	PARTICIPANT	\N	PRESENT	0
89137	87174	14157T	PARTICIPANT	\N	PRESENT	0
89138	87174	01046T	PARTICIPANT	\N	PRESENT	0
89041	87173	11042G	PARTICIPANT	\N	PRESENT	0
89139	87174	98042T	PARTICIPANT	\N	PRESENT	0
89043	87173	11034G	PARTICIPANT	\N	PRESENT	0
89044	87173	11012A	PARTICIPANT	\N	PRESENT	0
89160	87174	08019V	PARTICIPANT	\N	PRESENT	0
89163	87174	04070G	PARTICIPANT	\N	PRESENT	0
89177	87174	07029T	PARTICIPANT	\N	PRESENT	0
89048	87173	14159V	PARTICIPANT	\N	PRESENT	0
90922	83930	11090Q	PARTICIPANT	\N	PRESENT	0
90923	83930	14265W	PARTICIPANT	\N	PRESENT	0
89051	87173	13002U	PARTICIPANT	\N	PRESENT	0
89052	87173	14018U	PARTICIPANT	\N	PRESENT	0
89053	87173	11048N	PARTICIPANT	\N	PRESENT	0
90924	83930	14261S	PARTICIPANT	\N	EXCUSE	0
89055	87173	01024M	PARTICIPANT	\N	PRESENT	0
89056	87173	11111C	PARTICIPANT	\N	PRESENT	0
89057	87173	14089Y	PARTICIPANT	\N	PRESENT	0
89058	87173	14175V	PARTICIPANT	\N	PRESENT	0
89059	87173	14265W	PARTICIPANT	\N	PRESENT	0
89060	87173	97011G	PARTICIPANT	\N	PRESENT	0
89064	87173	11036J	PARTICIPANT	\N	PRESENT	0
89065	87173	14157T	PARTICIPANT	\N	PRESENT	0
89067	87173	01046T	PARTICIPANT	\N	PRESENT	0
90925	83930	14065Q	PARTICIPANT	\N	EXCUSE	0
90926	83930	14079W	PARTICIPANT	\N	EXCUSE	0
90927	83930	04071H	PARTICIPANT	\N	EXCUSE	0
90928	83930	95041E	PARTICIPANT	\N	EXCUSE	0
90929	83930	14039A	PARTICIPANT	\N	EXCUSE	0
90930	83930	14013P	PARTICIPANT	\N	EXCUSE	0
90931	83930	08068F	PARTICIPANT	\N	EXCUSE	0
90932	83930	04055H	PARTICIPANT	\N	EXCUSE	0
90933	83930	11088W	PARTICIPANT	\N	EXCUSE	0
90934	83930	11077T	PARTICIPANT	\N	EXCUSE	0
89119	87174	11085T	PARTICIPANT	\N	PRESENT	0
89125	87174	11089X	PARTICIPANT	\N	PRESENT	0
90935	83930	14253S	PARTICIPANT	\N	EXCUSE	0
90936	83930	10015M	PARTICIPANT	\N	EXCUSE	0
90937	83930	95067Q	PARTICIPANT	\N	EXCUSE	0
90938	83930	14157T	PARTICIPANT	\N	EXCUSE	0
90939	83930	14034U	PARTICIPANT	\N	EXCUSE	0
91020	91012	04038G	PARTICIPANT	\N	PRESENT	0
91021	91012	99002P	PARTICIPANT	\N	PRESENT	0
91022	91012	11056N	PARTICIPANT	\N	PRESENT	0
91023	91012	14259Y	PARTICIPANT	\N	PRESENT	0
91024	91012	11035H	PARTICIPANT	\N	PRESENT	0
91025	91012	14041T	PARTICIPANT	\N	PRESENT	0
91026	91012	11113E	PARTICIPANT	\N	PRESENT	0
91027	91012	01024M	PARTICIPANT	\N	PRESENT	0
91028	91012	14215L	PARTICIPANT	\N	PRESENT	0
91029	91012	11034G	PARTICIPANT	\N	PRESENT	0
91030	91012	08018U	PARTICIPANT	\N	PRESENT	0
91031	91012	01007L	PARTICIPANT	\N	PRESENT	0
70025	68966	04080J	PARTICIPANT	\N	PRESENT	0
70026	68966	14034U	PARTICIPANT	\N	PRESENT	0
70027	68966	04070G	PARTICIPANT	\N	PRESENT	0
70028	68966	08044W	PARTICIPANT	\N	PRESENT	0
70030	68966	11070L	PARTICIPANT	\N	PRESENT	0
70031	68966	11064N	PARTICIPANT	\N	PRESENT	0
70032	68966	14205J	PARTICIPANT	\N	PRESENT	0
70033	68966	11093T	PARTICIPANT	\N	PRESENT	0
70034	68966	14231L	PARTICIPANT	\N	PRESENT	0
70036	68966	14083S	PARTICIPANT	\N	PRESENT	0
70037	68966	14267Y	PARTICIPANT	\N	PRESENT	0
70038	68966	14219Q	PARTICIPANT	\N	PRESENT	0
70039	68966	14103D	PARTICIPANT	\N	PRESENT	0
70040	68966	04044E	PARTICIPANT	\N	PRESENT	0
70041	68966	14221J	PARTICIPANT	\N	PRESENT	0
70042	68966	14030Q	PARTICIPANT	\N	PRESENT	0
70043	68966	11082Q	PARTICIPANT	\N	PRESENT	0
70044	68966	14073Q	PARTICIPANT	\N	PRESENT	0
70045	68966	14157T	PARTICIPANT	\N	PRESENT	0
70046	68966	14089Y	PARTICIPANT	\N	PRESENT	0
70049	68966	95041E	PARTICIPANT	\N	PRESENT	0
70050	68966	07004J	PARTICIPANT	\N	PRESENT	0
70052	68966	04035D	PARTICIPANT	\N	PRESENT	0
70053	68966	14237S	PARTICIPANT	\N	PRESENT	0
70057	68966	14265W	PARTICIPANT	\N	PRESENT	0
70058	68966	92031P	PARTICIPANT	\N	PRESENT	0
70059	68966	14038Y	PARTICIPANT	\N	PRESENT	0
70060	68966	14215L	PARTICIPANT	\N	PRESENT	0
70065	68966	08009T	PARTICIPANT	\N	PRESENT	0
70067	68966	14217N	PARTICIPANT	\N	PRESENT	0
70068	68966	14273W	PARTICIPANT	\N	PRESENT	0
70069	68966	01060R	PARTICIPANT	\N	PRESENT	0
70070	68966	04061F	PARTICIPANT	\N	PRESENT	0
70071	68966	11068S	PARTICIPANT	\N	PRESENT	0
70072	68966	14199E	PARTICIPANT	\N	PRESENT	0
70073	68966	11033F	PARTICIPANT	\N	PRESENT	0
70074	68966	08053X	PARTICIPANT	\N	PRESENT	0
70075	68966	11056N	PARTICIPANT	\N	PRESENT	0
70076	68966	11113E	PARTICIPANT	\N	PRESENT	0
70080	68966	11085T	PARTICIPANT	\N	PRESENT	0
70078	68966	11111C	PARTICIPANT	\N	PRESENT	0
70079	68966	04056J	PARTICIPANT	\N	PRESENT	0
70081	68966	11026G	PARTICIPANT	\N	PRESENT	0
70370	68967	98053W	PARTICIPANT	\N	PRESENT	0
70371	68967	11034G	PARTICIPANT	\N	PRESENT	0
70372	68967	11059R	PARTICIPANT	\N	PRESENT	0
70373	68967	11061K	PARTICIPANT	\N	PRESENT	0
70374	68967	11068S	PARTICIPANT	\N	PRESENT	0
70375	68967	11037K	PARTICIPANT	\N	PRESENT	0
70376	68967	04094Q	PARTICIPANT	\N	PRESENT	0
70377	68967	04095R	PARTICIPANT	\N	PRESENT	0
70378	68967	11083R	PARTICIPANT	\N	PRESENT	0
70379	68967	14205J	PARTICIPANT	\N	PRESENT	0
70380	68967	14219Q	PARTICIPANT	\N	PRESENT	0
70381	68967	07004J	PARTICIPANT	\N	PRESENT	0
70382	68967	14273W	PARTICIPANT	\N	PRESENT	0
70383	68967	88008L	PARTICIPANT	\N	PRESENT	0
70384	68967	04038G	PARTICIPANT	\N	PRESENT	0
70385	68967	11012A	PARTICIPANT	\N	PRESENT	0
70386	68967	14215L	PARTICIPANT	\N	PRESENT	0
70387	68967	04088S	PARTICIPANT	\N	PRESENT	0
70388	68967	14033T	PARTICIPANT	\N	PRESENT	0
70389	68967	01057W	PARTICIPANT	\N	PRESENT	0
70390	68967	13002U	PARTICIPANT	\N	PRESENT	0
70391	68967	14069U	PARTICIPANT	\N	PRESENT	0
70392	68967	14071N	PARTICIPANT	\N	PRESENT	0
70393	68967	14213J	PARTICIPANT	\N	PRESENT	0
70394	68967	14265W	PARTICIPANT	\N	PRESENT	0
70395	68967	11091R	PARTICIPANT	\N	PRESENT	0
70396	68967	14147R	PARTICIPANT	\N	PRESENT	0
70397	68967	01008M	PARTICIPANT	\N	PRESENT	0
70398	68967	11103C	PARTICIPANT	\N	PRESENT	0
70399	68967	92045V	PARTICIPANT	\N	PRESENT	0
70400	68967	04043D	PARTICIPANT	\N	PRESENT	0
70401	68967	11100Y	PARTICIPANT	\N	PRESENT	0
70402	68967	11043H	PARTICIPANT	\N	PRESENT	0
70403	68967	14123H	PARTICIPANT	\N	PRESENT	0
70404	68967	08022Q	PARTICIPANT	\N	PRESENT	0
70405	68967	01027Q	PARTICIPANT	\N	PRESENT	0
70406	68967	14261S	PARTICIPANT	\N	PRESENT	0
70407	68967	01060R	PARTICIPANT	\N	PRESENT	0
70408	68967	10015M	PARTICIPANT	\N	PRESENT	0
70409	68967	14223L	PARTICIPANT	\N	PRESENT	0
70410	68967	14331P	PARTICIPANT	\N	PRESENT	0
70411	68967	11042G	PARTICIPANT	\N	PRESENT	0
70412	68967	11104D	PARTICIPANT	\N	PRESENT	0
70413	68967	14121F	PARTICIPANT	\N	PRESENT	0
70414	68967	14031R	PARTICIPANT	\N	PRESENT	0
70415	68967	14225N	PARTICIPANT	\N	PRESENT	0
70416	68967	04085P	PARTICIPANT	\N	PRESENT	0
70417	68967	14327T	PARTICIPANT	\N	PRESENT	0
70420	68967	14281W	PARTICIPANT	\N	PRESENT	0
70421	68967	11105E	PARTICIPANT	\N	PRESENT	0
70422	68967	14037X	PARTICIPANT	\N	PRESENT	0
70423	68967	07029T	PARTICIPANT	\N	PRESENT	0
70424	68967	08053X	PARTICIPANT	\N	PRESENT	0
70425	68967	01007L	PARTICIPANT	\N	PRESENT	0
70479	68967	98046X	PARTICIPANT	\N	PRESENT	0
70480	68967	80013X	PARTICIPANT	\N	PRESENT	0
70481	68967	14119M	PARTICIPANT	\N	PRESENT	0
70482	68967	14105F	PARTICIPANT	\N	PRESENT	0
70483	68967	14157T	PARTICIPANT	\N	PRESENT	0
70484	68967	14199E	PARTICIPANT	\N	PRESENT	0
70485	68967	08051V	PARTICIPANT	\N	PRESENT	0
70486	68967	08034U	PARTICIPANT	\N	PRESENT	0
70487	68967	08010L	PARTICIPANT	\N	PRESENT	0
70488	68968	98053W	PARTICIPANT	\N	PRESENT	0
70489	68968	11034G	PARTICIPANT	\N	PRESENT	0
70547	68968	14231L	PARTICIPANT	\N	PRESENT	0
70548	68968	08009T	PARTICIPANT	\N	PRESENT	0
70549	68968	11105E	PARTICIPANT	\N	PRESENT	0
70493	68968	11037K	PARTICIPANT	\N	PRESENT	0
70550	68968	95062K	PARTICIPANT	\N	PRESENT	0
70551	68968	14265W	PARTICIPANT	\N	PRESENT	0
70552	68968	11012A	PARTICIPANT	\N	PRESENT	0
70553	68968	83042R	PARTICIPANT	\N	PRESENT	0
70554	68968	04038G	PARTICIPANT	\N	PRESENT	0
70555	68968	14215L	PARTICIPANT	\N	PRESENT	0
70556	68968	01027Q	PARTICIPANT	\N	PRESENT	0
70557	68968	14273W	PARTICIPANT	\N	PRESENT	0
70502	68968	01057W	PARTICIPANT	\N	PRESENT	0
70558	68968	01007L	PARTICIPANT	\N	PRESENT	0
70559	68968	11059R	PARTICIPANT	\N	PRESENT	0
70560	68968	14211G	PARTICIPANT	\N	PRESENT	0
70506	68968	14213J	PARTICIPANT	\N	PRESENT	0
70561	68968	05008E	PARTICIPANT	\N	PRESENT	0
70508	68968	11091R	PARTICIPANT	\N	PRESENT	0
70562	68968	08010L	PARTICIPANT	\N	PRESENT	0
70563	68968	11049P	PARTICIPANT	\N	PRESENT	0
70511	68968	11103C	PARTICIPANT	\N	PRESENT	0
70564	68968	14053L	PARTICIPANT	\N	PRESENT	0
70565	68968	11048N	PARTICIPANT	\N	PRESENT	0
71051	71050	11039M	PARTICIPANT	\N	PRESENT	0
71052	71050	98042T	PARTICIPANT	\N	PRESENT	0
71063	71061	01008M	PARTICIPANT	\N	PRESENT	0
71064	71061	11036J	PARTICIPANT	\N	PRESENT	0
70519	68968	14261S	PARTICIPANT	\N	PRESENT	0
70521	68968	10015M	PARTICIPANT	\N	PRESENT	0
71067	71061	08068F	PARTICIPANT	\N	PRESENT	0
70523	68968	14331P	PARTICIPANT	\N	PRESENT	0
71068	71061	14207L	PARTICIPANT	\N	PRESENT	0
71070	71061	90003B	PARTICIPANT	\N	PRESENT	0
71071	71061	08028W	PARTICIPANT	\N	PRESENT	0
70528	68968	14225N	PARTICIPANT	\N	PRESENT	0
70529	68968	04085P	PARTICIPANT	\N	PRESENT	0
71072	71061	80013X	PARTICIPANT	\N	PRESENT	0
71073	71061	08038Y	PARTICIPANT	\N	PRESENT	0
70533	68968	14037X	PARTICIPANT	\N	PRESENT	0
70534	68968	07029T	PARTICIPANT	\N	PRESENT	0
71075	71061	14197C	PARTICIPANT	\N	PRESENT	0
71076	71061	11110B	PARTICIPANT	\N	PRESENT	0
71077	71061	14187A	PARTICIPANT	\N	PRESENT	0
70538	68968	80013X	PARTICIPANT	\N	PRESENT	0
71078	71061	14033T	PARTICIPANT	\N	PRESENT	0
70541	68968	14157T	PARTICIPANT	\N	PRESENT	0
70542	68968	14199E	PARTICIPANT	\N	PRESENT	0
70543	68968	08051V	PARTICIPANT	\N	PRESENT	0
70544	68968	08034U	PARTICIPANT	\N	PRESENT	0
71080	71061	04048J	PARTICIPANT	\N	PRESENT	0
70546	68968	11056N	PARTICIPANT	\N	PRESENT	0
71081	71061	11099A	PARTICIPANT	\N	PRESENT	0
71082	71061	04049K	PARTICIPANT	\N	PRESENT	0
71083	71061	04094Q	PARTICIPANT	\N	PRESENT	0
62495	54852	08010L	PARTICIPANT	\N	EXCUSE	0
62581	54852	14014Q	PARTICIPANT	\N	EXCUSE	0
62584	62583	14073Q	PARTICIPANT	\N	PRESENT	0
62585	62583	01019Q	PARTICIPANT	\N	PRESENT	0
62586	62583	14255U	PARTICIPANT	\N	PRESENT	0
62587	62583	01037S	PARTICIPANT	\N	PRESENT	0
62588	62583	14085U	PARTICIPANT	\N	PRESENT	0
62589	62583	14053L	PARTICIPANT	\N	PRESENT	0
62590	62583	11083R	PARTICIPANT	\N	PRESENT	0
62591	62583	11114F	PARTICIPANT	\N	PRESENT	0
62592	62583	08017T	PARTICIPANT	\N	PRESENT	0
62739	62738	96004D	PARTICIPANT	\N	EXCUSE	0
62740	62738	14089Y	PARTICIPANT	\N	PRESENT	0
62741	62738	95030B	PRESIDENT	0	PRESENT	0
62742	62738	04035D	PARTICIPANT	\N	PRESENT	0
62743	62738	11083R	PARTICIPANT	\N	PRESENT	0
62744	62738	14026U	PARTICIPANT	\N	PRESENT	0
62745	62738	04061F	PARTICIPANT	\N	PRESENT	0
62746	62738	14001X	PARTICIPANT	\N	PRESENT	0
62747	62738	04057K	PARTICIPANT	\N	EXCUSE	0
62748	62738	95049N	PARTICIPANT	\N	PRESENT	0
62749	62738	04045F	PARTICIPANT	\N	PRESENT	0
62750	62738	92045V	PARTICIPANT	\N	PRESENT	0
62751	62738	04034C	PARTICIPANT	\N	PRESENT	0
62752	62738	14133K	PARTICIPANT	\N	EXCUSE	0
62753	62738	90003B	PARTICIPANT	\N	EXCUSE	0
62754	62738	11035H	PARTICIPANT	\N	EXCUSE	0
62755	62738	14135M	PARTICIPANT	\N	EXCUSE	0
62756	62738	01016M	PARTICIPANT	\N	PRESENT	0
62757	62738	05008E	PARTICIPANT	\N	PRESENT	0
62758	62738	01024M	PARTICIPANT	\N	PRESENT	0
62759	62738	07034Q	PARTICIPANT	\N	PRESENT	0
62760	62738	04047H	PARTICIPANT	\N	PRESENT	0
62761	62738	14273W	PARTICIPANT	\N	PRESENT	0
62762	62738	14147R	PARTICIPANT	\N	PRESENT	0
63478	63477	07004J	PARTICIPANT	\N	PRESENT	0
63479	63477	10015M	PARTICIPANT	\N	PRESENT	0
68895	68892	08025T	PARTICIPANT	\N	PRESENT	0
68896	68892	04085P	PARTICIPANT	\N	PRESENT	0
68897	68892	05008E	PARTICIPANT	\N	PRESENT	0
68898	68892	11030C	PARTICIPANT	\N	PRESENT	0
68899	68892	11033F	PARTICIPANT	\N	PRESENT	0
68900	68892	14065Q	PARTICIPANT	\N	PRESENT	0
68901	68892	14069U	PARTICIPANT	\N	PRESENT	0
68902	68892	04047H	PARTICIPANT	\N	PRESENT	0
68903	68892	11032E	PARTICIPANT	\N	PRESENT	0
68904	68892	04038G	PARTICIPANT	\N	PRESENT	0
68905	68892	99002P	PARTICIPANT	\N	PRESENT	0
69063	68468	04049K	PARTICIPANT	\N	PRESENT	0
69064	68468	14151M	PARTICIPANT	\N	PRESENT	0
68908	68892	11035H	PARTICIPANT	\N	PRESENT	0
68909	68892	14041T	PARTICIPANT	\N	PRESENT	0
68910	68892	11113E	PARTICIPANT	\N	PRESENT	0
68911	68892	01024M	PARTICIPANT	\N	PRESENT	0
68912	68892	14215L	PARTICIPANT	\N	PRESENT	0
68913	68892	11034G	PARTICIPANT	\N	PRESENT	0
69065	68468	14261S	PARTICIPANT	\N	PRESENT	0
69066	68468	14207L	PARTICIPANT	\N	PRESENT	0
68916	68892	01007L	PARTICIPANT	\N	PRESENT	0
68917	68892	11049P	PARTICIPANT	\N	PRESENT	0
68918	68892	08044W	PARTICIPANT	\N	PRESENT	0
69067	68468	14083S	PARTICIPANT	\N	PRESENT	0
68920	68892	11026G	PARTICIPANT	\N	PRESENT	0
68921	68892	04079R	PARTICIPANT	\N	PRESENT	0
68922	68892	14111D	PARTICIPANT	\N	PRESENT	0
69068	68468	14121F	PARTICIPANT	\N	PRESENT	0
68924	68892	14273W	PARTICIPANT	\N	PRESENT	0
70903	70902	14261S	PARTICIPANT	\N	PRESENT	0
69070	68468	14265W	PARTICIPANT	\N	PRESENT	0
68927	68892	95049N	PARTICIPANT	\N	PRESENT	0
68928	68892	08051V	PARTICIPANT	\N	PRESENT	0
69071	68468	14147R	PARTICIPANT	\N	PRESENT	0
68930	68892	07034Q	PARTICIPANT	\N	PRESENT	0
68931	68892	04074L	PARTICIPANT	\N	PRESENT	0
68932	68892	10015M	PARTICIPANT	\N	PRESENT	0
68933	68892	95063L	PARTICIPANT	\N	PRESENT	0
69072	68468	14253S	PARTICIPANT	\N	PRESENT	0
68935	68892	01028R	PARTICIPANT	\N	PRESENT	0
68936	68892	98035U	PARTICIPANT	\N	PRESENT	0
68937	68892	04056J	PARTICIPANT	\N	PRESENT	0
69073	68468	95030B	PARTICIPANT	\N	PRESENT	0
68939	68892	04044E	PARTICIPANT	\N	PRESENT	0
68940	68892	11037K	PARTICIPANT	\N	PRESENT	0
68941	68892	92045V	PARTICIPANT	\N	PRESENT	0
69078	69077	04049K	PARTICIPANT	\N	PRESENT	0
68943	68892	01047U	PARTICIPANT	\N	PRESENT	0
69079	69077	14151M	PARTICIPANT	\N	PRESENT	0
69080	69077	14261S	PARTICIPANT	\N	PRESENT	0
69081	69077	14207L	PARTICIPANT	\N	PRESENT	0
69082	69077	14083S	PARTICIPANT	\N	PRESENT	0
69083	69077	14121F	PARTICIPANT	\N	PRESENT	0
70904	70902	08055A	PARTICIPANT	\N	PRESENT	0
69085	69077	14265W	PARTICIPANT	\N	PRESENT	0
69086	69077	14253S	PARTICIPANT	\N	PRESENT	0
69087	69077	14147R	PARTICIPANT	\N	PRESENT	0
69088	69077	95030B	PARTICIPANT	\N	PRESENT	0
69090	69089	04049K	PARTICIPANT	\N	PRESENT	0
69091	69089	14151M	PARTICIPANT	\N	PRESENT	0
69092	69089	14261S	PARTICIPANT	\N	PRESENT	0
69093	69089	14207L	PARTICIPANT	\N	PRESENT	0
69094	69089	14083S	PARTICIPANT	\N	PRESENT	0
69095	69089	14121F	PARTICIPANT	\N	PRESENT	0
72101	72100	14251Q	PARTICIPANT	\N	PRESENT	0
69097	69089	14265W	PARTICIPANT	\N	PRESENT	0
69098	69089	14253S	PARTICIPANT	\N	PRESENT	0
69099	69089	95030B	PARTICIPANT	\N	PRESENT	0
70905	70902	14093U	PARTICIPANT	\N	PRESENT	0
70906	70902	14030Q	PARTICIPANT	\N	PRESENT	0
70907	70902	96004D	PARTICIPANT	\N	PRESENT	0
70908	70902	08060W	PARTICIPANT	\N	PRESENT	0
70909	70902	11095V	PARTICIPANT	\N	PRESENT	0
70910	70902	14038Y	PARTICIPANT	\N	PRESENT	0
70911	70902	11114F	PARTICIPANT	\N	PRESENT	0
70912	70902	98023Q	PARTICIPANT	\N	PRESENT	0
72103	72102	14251Q	PARTICIPANT	\N	PRESENT	0
70914	70902	01015L	PARTICIPANT	\N	PRESENT	0
70915	70902	11107G	PARTICIPANT	\N	PRESENT	0
70916	70902	11020A	PARTICIPANT	\N	PRESENT	0
70917	70902	02002K	PARTICIPANT	\N	PRESENT	0
70918	70902	01022K	PARTICIPANT	\N	PRESENT	0
72106	72104	86044G	PARTICIPANT	\N	PRESENT	0
70920	70902	09001P	PARTICIPANT	\N	PRESENT	0
70921	70902	11059R	PARTICIPANT	\N	PRESENT	0
70922	70902	14219Q	PARTICIPANT	\N	PRESENT	0
70923	70902	80027E	PARTICIPANT	\N	PRESENT	0
70924	70902	14031R	PARTICIPANT	\N	PRESENT	0
70925	70902	08009T	PRESIDENT	0	PRESENT	0
70926	70902	08062Y	PARTICIPANT	\N	EXCUSE	0
70927	70902	14221J	PARTICIPANT	\N	PRESENT	0
72107	72104	11027H	PARTICIPANT	\N	PRESENT	0
70929	70902	08042U	PARTICIPANT	\N	PRESENT	0
70930	70902	14169X	PARTICIPANT	\N	PRESENT	0
70931	70902	14237S	PARTICIPANT	\N	PRESENT	0
70932	70902	13002U	PARTICIPANT	\N	PRESENT	0
70933	70902	05012A	PARTICIPANT	\N	PRESENT	0
70934	70902	14247U	PARTICIPANT	\N	PRESENT	0
70935	70902	14135M	PARTICIPANT	\N	PRESENT	0
70936	70902	14331P	PARTICIPANT	\N	PRESENT	0
70937	70902	95062K	PARTICIPANT	\N	PRESENT	0
72120	72119	08047A	PARTICIPANT	\N	PRESENT	0
72122	72121	14028W	PARTICIPANT	\N	PRESENT	0
70940	70902	14157T	PARTICIPANT	\N	PRESENT	0
70941	70902	96003C	PARTICIPANT	\N	EXCUSE	0
72118	72110	08047A	PARTICIPANT	\N	PRESENT	0
72123	72121	04042C	PARTICIPANT	\N	PRESENT	0
72124	72121	01056V	PARTICIPANT	\N	PRESENT	0
72125	72121	11082Q	PARTICIPANT	\N	PRESENT	0
72127	72126	04042C	PARTICIPANT	\N	PRESENT	0
72129	72128	11106F	PARTICIPANT	\N	PRESENT	0
72131	72130	14041T	PARTICIPANT	\N	PRESENT	0
72132	72130	11026G	PARTICIPANT	\N	PRESENT	0
72133	72130	04043D	PARTICIPANT	\N	PRESENT	0
72135	72134	14151M	PARTICIPANT	\N	PRESENT	0
72137	72136	11044J	PARTICIPANT	\N	PRESENT	0
72138	72136	14069U	PARTICIPANT	\N	PRESENT	0
72139	72136	14255U	PARTICIPANT	\N	PRESENT	0
72140	72136	14073Q	PARTICIPANT	\N	PRESENT	0
72141	72136	14159V	PARTICIPANT	\N	PRESENT	0
72142	72136	14251Q	PARTICIPANT	\N	PRESENT	0
72143	72136	98046X	PARTICIPANT	\N	PRESENT	0
72144	72136	08062Y	PARTICIPANT	\N	PRESENT	0
72145	72136	14071N	PARTICIPANT	\N	PRESENT	0
72146	72136	14169X	PARTICIPANT	\N	PRESENT	0
72147	72136	05012A	PARTICIPANT	\N	PRESENT	0
72148	72136	14225N	PARTICIPANT	\N	PRESENT	0
72149	72136	95062K	PARTICIPANT	\N	PRESENT	0
68313	66607	01016M	PARTICIPANT	\N	PRESENT	0
68314	66607	95049N	PARTICIPANT	\N	PRESENT	0
68315	66607	92031P	PARTICIPANT	\N	PRESENT	0
68316	66607	14271U	PARTICIPANT	\N	PRESENT	0
68317	66607	14229S	PARTICIPANT	\N	PRESENT	0
68318	66607	14213J	PARTICIPANT	\N	PRESENT	0
68319	66607	08015R	PARTICIPANT	\N	PRESENT	0
68320	66607	14265W	PARTICIPANT	\N	PRESENT	0
68321	66607	05008E	PARTICIPANT	\N	PRESENT	0
68322	66607	14119M	PARTICIPANT	\N	PRESENT	0
68323	66607	14083S	PARTICIPANT	\N	PRESENT	0
68324	66607	14033T	PARTICIPANT	\N	PRESENT	0
68325	66607	14193X	PARTICIPANT	\N	PRESENT	0
68326	66607	08010L	PARTICIPANT	\N	PRESENT	0
69472	68417	14041T	PARTICIPANT	\N	PRESENT	0
69473	68468	14041T	PARTICIPANT	\N	PRESENT	0
69474	69077	14041T	PARTICIPANT	\N	PRESENT	0
69475	69089	14041T	PARTICIPANT	\N	PRESENT	0
68311	66607	14026U	PARTICIPANT	\N	PRESENT	0
68312	66607	14014Q	PARTICIPANT	\N	PRESENT	0
69477	69476	11015D	PARTICIPANT	\N	PRESENT	0
69478	69476	92031P	PARTICIPANT	\N	PRESENT	0
69480	69479	11015D	PARTICIPANT	\N	PRESENT	0
69481	69479	92031P	PARTICIPANT	\N	PRESENT	0
69483	69482	14028W	PARTICIPANT	\N	PRESENT	0
69484	69482	04042C	PARTICIPANT	\N	PRESENT	0
69485	69482	11082Q	PARTICIPANT	\N	PRESENT	0
69486	69482	01056V	PARTICIPANT	\N	PRESENT	0
69488	69487	92020L	PARTICIPANT	\N	PRESENT	0
69489	69487	98018T	PARTICIPANT	\N	PRESENT	0
69490	69487	11015D	PARTICIPANT	\N	PRESENT	0
69980	69975	11076S	PARTICIPANT	\N	PRESENT	0
69984	69975	08058D	PARTICIPANT	\N	PRESENT	0
69987	69975	98018T	PARTICIPANT	\N	PRESENT	0
69989	69975	92018S	PARTICIPANT	\N	PRESENT	0
69992	69975	92020L	PARTICIPANT	\N	PRESENT	0
69994	69975	95030B	PARTICIPANT	\N	PRESENT	0
69999	69975	97011G	PARTICIPANT	\N	PRESENT	0
70001	69975	04035D	PARTICIPANT	\N	PRESENT	0
70002	69975	07024N	PARTICIPANT	\N	PRESENT	0
70004	69975	95035G	PARTICIPANT	\N	PRESENT	0
70005	69975	08056B	PARTICIPANT	\N	EXCUSE	0
70029	69975	14097Y	PARTICIPANT	\N	PRESENT	0
70035	69975	04036E	PARTICIPANT	\N	EXCUSE	0
70047	69975	92031P	PARTICIPANT	\N	PRESENT	0
70048	69975	11106F	PARTICIPANT	\N	PRESENT	0
70051	69975	14251Q	PARTICIPANT	\N	PRESENT	0
70054	69975	08053X	PARTICIPANT	\N	PRESENT	0
70055	69975	14253S	PARTICIPANT	\N	PRESENT	0
70056	69975	08047A	PARTICIPANT	\N	PRESENT	0
70061	69975	98021N	PARTICIPANT	\N	PRESENT	0
70062	69975	95059Q	PRESIDENT	0	PRESENT	0
70063	69975	01014K	PARTICIPANT	\N	PRESENT	0
70064	69975	11054L	PARTICIPANT	\N	PRESENT	0
70066	69975	01056V	PARTICIPANT	\N	PRESENT	0
70630	70572	95059Q	PARTICIPANT	\N	EXCUSE	0
70631	70572	98046X	PARTICIPANT	\N	PRESENT	0
70632	70572	04094Q	PARTICIPANT	\N	PRESENT	0
73464	72250	04036E	PARTICIPANT	\N	PRESENT	0
73465	72250	08039A	PARTICIPANT	\N	PRESENT	0
73466	72250	14211G	PARTICIPANT	\N	PRESENT	0
73467	72250	14253S	PARTICIPANT	\N	PRESENT	0
73468	72250	04071H	PARTICIPANT	\N	PRESENT	0
73469	72250	01057W	PARTICIPANT	\N	PRESENT	0
73470	72250	08034U	PARTICIPANT	\N	PRESENT	0
73471	72250	14031R	PARTICIPANT	\N	PRESENT	0
73472	72250	14173T	PARTICIPANT	\N	PRESENT	0
73473	72250	11105E	PARTICIPANT	\N	PRESENT	0
73474	72250	14199E	PARTICIPANT	\N	PRESENT	0
73475	72250	14329V	PARTICIPANT	\N	PRESENT	0
73476	72250	08019V	PARTICIPANT	\N	PRESENT	0
73477	72250	04088S	PARTICIPANT	\N	PRESENT	0
73478	72250	11088W	PARTICIPANT	\N	PRESENT	0
73479	72250	14041T	PARTICIPANT	\N	PRESENT	0
73481	72250	08018U	PARTICIPANT	\N	PRESENT	0
73482	72250	14135M	PARTICIPANT	\N	PRESENT	0
73483	72250	14033T	PARTICIPANT	\N	PRESENT	0
73484	72250	07032N	PARTICIPANT	\N	PRESENT	0
73485	72250	11048N	PARTICIPANT	\N	PRESENT	0
73486	72250	14157T	PARTICIPANT	\N	PRESENT	0
73487	72250	11090Q	PARTICIPANT	\N	PRESENT	0
73488	72250	08042U	PARTICIPANT	\N	PRESENT	0
73489	72250	97011G	PARTICIPANT	\N	PRESENT	0
73490	72250	14247U	PARTICIPANT	\N	PRESENT	0
73491	72250	08056B	PARTICIPANT	\N	PRESENT	0
73492	72250	90003B	PARTICIPANT	\N	PRESENT	0
73493	72250	11056N	PARTICIPANT	\N	PRESENT	0
73494	72250	98029W	PARTICIPANT	\N	PRESENT	0
73495	72250	11027H	PARTICIPANT	\N	PRESENT	0
73496	72250	01059Y	PARTICIPANT	\N	PRESENT	0
73497	72250	01058X	PARTICIPANT	\N	PRESENT	0
73498	72250	08069G	PARTICIPANT	\N	PRESENT	0
73499	72250	14123H	PARTICIPANT	\N	PRESENT	0
73500	72250	89017R	PARTICIPANT	\N	PRESENT	0
73501	72250	07029T	PARTICIPANT	\N	PRESENT	0
73502	72250	04048J	PARTICIPANT	\N	PRESENT	0
73506	72250	14105F	PARTICIPANT	\N	PRESENT	0
73504	72250	05008E	PARTICIPANT	\N	PRESENT	0
73505	72250	04044E	PARTICIPANT	\N	PRESENT	0
73507	72250	08053X	PARTICIPANT	\N	PRESENT	0
73508	72250	11096W	PARTICIPANT	\N	PRESENT	0
73509	72250	95067Q	PARTICIPANT	\N	PRESENT	0
73510	72250	11091R	PARTICIPANT	\N	PRESENT	0
73511	72250	01031L	PARTICIPANT	\N	PRESENT	0
73512	72250	11042G	PARTICIPANT	\N	PRESENT	0
73513	72250	92018S	PARTICIPANT	\N	PRESENT	0
73514	72250	08061X	PARTICIPANT	\N	PRESENT	0
73515	72250	86044G	PARTICIPANT	\N	PRESENT	0
73518	72250	04049K	PARTICIPANT	\N	PRESENT	0
73521	72250	14195A	PARTICIPANT	\N	PRESENT	0
73522	72250	14119M	PARTICIPANT	\N	PRESENT	0
73538	72250	11080N	PARTICIPANT	\N	PRESENT	0
73539	72250	14059S	PARTICIPANT	\N	PRESENT	0
73545	72250	80013X	PARTICIPANT	\N	PRESENT	0
73546	72250	04038G	PARTICIPANT	\N	PRESENT	0
73547	72250	04042C	PARTICIPANT	\N	PRESENT	0
73548	72250	11094U	PARTICIPANT	\N	PRESENT	0
73549	72250	14255U	PARTICIPANT	\N	PRESENT	0
73550	72250	14249W	PARTICIPANT	\N	PRESENT	0
73551	72250	01041N	PARTICIPANT	\N	PRESENT	0
73552	72250	14121F	PARTICIPANT	\N	PRESENT	0
73553	72250	12041X	PARTICIPANT	\N	PRESENT	0
73554	72250	10006L	PARTICIPANT	\N	PRESENT	0
73555	72250	77002U	PARTICIPANT	\N	PRESENT	0
73556	72250	04040A	PARTICIPANT	\N	PRESENT	0
73557	72250	04070G	PARTICIPANT	\N	PRESENT	0
73558	72250	14014Q	PARTICIPANT	\N	PRESENT	0
73559	72250	14259Y	PARTICIPANT	\N	PRESENT	0
73560	72250	09001P	PARTICIPANT	\N	PRESENT	0
73561	72250	01037S	PARTICIPANT	\N	PRESENT	0
73562	72250	04074L	PARTICIPANT	\N	PRESENT	0
73563	72250	14013P	PARTICIPANT	\N	PRESENT	0
73564	72250	08009T	PARTICIPANT	\N	PRESENT	0
73565	72250	95037J	PARTICIPANT	\N	PRESENT	0
73566	72250	14069U	PARTICIPANT	\N	PRESENT	0
73567	72250	01015L	PARTICIPANT	\N	PRESENT	0
73627	72250	11030C	PARTICIPANT	\N	PRESENT	0
73652	72250	11077T	PARTICIPANT	\N	PRESENT	0
73653	72250	04054G	PARTICIPANT	\N	PRESENT	0
73654	72250	04034C	PARTICIPANT	\N	PRESENT	0
73655	72250	04053F	PARTICIPANT	\N	PRESENT	0
73656	72250	11039M	PARTICIPANT	\N	PRESENT	0
73657	72250	04045F	PARTICIPANT	\N	PRESENT	0
73658	72250	01028R	PARTICIPANT	\N	PRESENT	0
73659	72250	14223L	PARTICIPANT	\N	PRESENT	0
73660	72250	08022Q	PARTICIPANT	\N	PRESENT	0
73661	72250	01060R	PARTICIPANT	\N	PRESENT	0
73662	72250	11082Q	PARTICIPANT	\N	PRESENT	0
73663	72250	14193X	PARTICIPANT	\N	PRESENT	0
73664	72250	14053L	PARTICIPANT	\N	PRESENT	0
73665	72250	12042Y	PARTICIPANT	\N	PRESENT	0
73666	72251	08055A	PARTICIPANT	\N	PRESENT	0
73667	72251	11056N	PARTICIPANT	\N	PRESENT	0
73668	72251	14013P	PARTICIPANT	\N	PRESENT	0
73669	72251	01015L	PARTICIPANT	\N	PRESENT	0
73670	72251	04085P	PARTICIPANT	\N	PRESENT	0
73671	72251	14235Q	PARTICIPANT	\N	PRESENT	0
73672	72251	11031D	PARTICIPANT	\N	PRESENT	0
73673	72251	11057P	PARTICIPANT	\N	PRESENT	0
73674	72251	08052W	PARTICIPANT	\N	PRESENT	0
73675	72251	11084S	PARTICIPANT	\N	PRESENT	0
73676	72251	08068F	PARTICIPANT	\N	PRESENT	0
73677	72251	04034C	PARTICIPANT	\N	PRESENT	0
73678	72251	14097Y	PARTICIPANT	\N	PRESENT	0
73679	72251	11026G	PARTICIPANT	\N	PRESENT	0
73680	72251	11027H	PARTICIPANT	\N	PRESENT	0
73681	72251	04056J	PARTICIPANT	\N	PRESENT	0
73682	72251	14051J	PARTICIPANT	\N	PRESENT	0
73683	72251	14001X	PARTICIPANT	\N	PRESENT	0
71119	71118	01008M	PARTICIPANT	\N	PRESENT	0
71120	71118	11036J	PARTICIPANT	\N	PRESENT	0
62103	62100	01046T	PARTICIPANT	\N	PRESENT	0
62104	62100	04053F	PARTICIPANT	\N	PRESENT	0
62105	62100	14255U	PARTICIPANT	\N	PRESENT	0
62106	62100	04066L	PARTICIPANT	\N	PRESENT	0
72153	72150	77002U	PARTICIPANT	\N	PRESENT	0
62108	62100	14053L	PARTICIPANT	\N	PRESENT	0
62109	62100	11103C	PARTICIPANT	\N	PRESENT	0
62110	62100	11044J	PARTICIPANT	\N	PRESENT	0
62111	62100	14195A	PARTICIPANT	\N	PRESENT	0
62112	62100	14267Y	PARTICIPANT	\N	PRESENT	0
62113	62100	11023D	PARTICIPANT	\N	PRESENT	0
62114	62100	11031D	PARTICIPANT	\N	PRESENT	0
62115	62100	08052W	PARTICIPANT	\N	PRESENT	0
62116	62100	01059Y	PARTICIPANT	\N	PRESENT	0
62117	62100	04081K	PARTICIPANT	\N	PRESENT	0
62118	62100	98024R	PARTICIPANT	\N	PRESENT	0
62119	62100	10006L	PARTICIPANT	\N	PRESENT	0
62120	62100	04067M	PARTICIPANT	\N	PRESENT	0
62121	62100	14217N	PARTICIPANT	\N	PRESENT	0
62122	62100	14042U	PARTICIPANT	\N	PRESENT	0
62123	62100	14151M	PARTICIPANT	\N	PRESENT	0
62124	62100	12042Y	PARTICIPANT	\N	PRESENT	0
62125	62100	14281W	PARTICIPANT	\N	PRESENT	0
62126	62100	14087W	PARTICIPANT	\N	PRESENT	0
62361	62357	04059M	PARTICIPANT	\N	PRESENT	0
62128	62100	14034U	PARTICIPANT	\N	PRESENT	0
62129	62100	14231L	PARTICIPANT	\N	PRESENT	0
62130	62100	11061K	PARTICIPANT	\N	PRESENT	0
62362	62357	11039M	PARTICIPANT	\N	PRESENT	0
62132	62100	08041T	PARTICIPANT	\N	PRESENT	0
62133	62100	01011G	PARTICIPANT	\N	PRESENT	0
62134	62100	14026U	PARTICIPANT	\N	PRESENT	0
62135	62100	14213J	PARTICIPANT	\N	PRESENT	0
62136	62100	14121F	PARTICIPANT	\N	PRESENT	0
62137	62100	11112D	PARTICIPANT	\N	PRESENT	0
62138	62100	14037X	PARTICIPANT	\N	PRESENT	0
62139	62100	14018U	PARTICIPANT	\N	PRESENT	0
62140	62100	11067R	PARTICIPANT	\N	PRESENT	0
62141	62100	14223L	PARTICIPANT	\N	PRESENT	0
62142	62100	04092N	PRESIDENT	0	PRESENT	0
62143	62100	14265W	PARTICIPANT	\N	PRESENT	0
62144	62100	14119M	PARTICIPANT	\N	PRESENT	0
62145	62100	14071N	PARTICIPANT	\N	PRESENT	0
62146	62100	07032N	PARTICIPANT	\N	PRESENT	0
62147	62100	04043D	PARTICIPANT	\N	PRESENT	0
62148	62100	14271U	PARTICIPANT	\N	PRESENT	0
62363	62357	01044R	PARTICIPANT	\N	PRESENT	0
62150	62100	11093T	PARTICIPANT	\N	PRESENT	0
62151	62100	11097X	PARTICIPANT	\N	PRESENT	0
62152	62100	04045F	PARTICIPANT	\N	PRESENT	0
62153	62100	14227Q	PARTICIPANT	\N	PRESENT	0
62154	62100	01034P	PARTICIPANT	\N	PRESENT	0
62364	62357	08043V	PARTICIPANT	\N	PRESENT	0
62365	62357	14089Y	PARTICIPANT	\N	PRESENT	0
62157	62100	14269B	PARTICIPANT	\N	PRESENT	0
62366	62357	14105F	PARTICIPANT	\N	PRESENT	0
62367	62357	11029K	PARTICIPANT	\N	PRESENT	0
62368	62357	95015C	PRESIDENT	1	PRESENT	0
62369	62357	92015P	PARTICIPANT	\N	EXCUSE	0
62370	62357	08024S	PARTICIPANT	\N	EXCUSE	0
62371	62357	14201E	PARTICIPANT	\N	PRESENT	0
71122	71118	14013P	PARTICIPANT	\N	PRESENT	0
62373	62357	14209N	PARTICIPANT	\N	PRESENT	0
62374	62357	14079W	PARTICIPANT	\N	PRESENT	0
62375	62357	11091R	PARTICIPANT	\N	PRESENT	0
62376	62357	87003B	PARTICIPANT	\N	PRESENT	0
62377	62357	98042T	PARTICIPANT	\N	PRESENT	0
62378	62357	14249W	PARTICIPANT	\N	PRESENT	0
62379	62357	01041N	PARTICIPANT	\N	PRESENT	0
62380	62357	01025N	PARTICIPANT	\N	PRESENT	0
62381	62357	01037S	PARTICIPANT	\N	PRESENT	0
62382	62357	89029V	PARTICIPANT	\N	PRESENT	0
62383	62357	08035V	PARTICIPANT	\N	PRESENT	0
62384	62357	11089X	PARTICIPANT	\N	PRESENT	0
62385	62357	07026Q	PARTICIPANT	\N	PRESENT	0
62386	62357	14123H	PARTICIPANT	\N	PRESENT	0
62387	62357	14179A	PARTICIPANT	\N	PRESENT	0
62388	62357	04041B	PARTICIPANT	\N	PRESENT	0
62389	62357	14241N	PARTICIPANT	\N	PRESENT	0
62390	62357	14061L	PARTICIPANT	\N	PRESENT	0
62391	62357	14073Q	PARTICIPANT	\N	PRESENT	0
62392	62357	08031R	PARTICIPANT	\N	PRESENT	0
62393	62357	12041X	PARTICIPANT	\N	PRESENT	0
62394	62357	08039A	PARTICIPANT	\N	PRESENT	0
62395	62357	08017T	PARTICIPANT	\N	PRESENT	0
62396	62357	14059S	PARTICIPANT	\N	PRESENT	0
71123	71118	08068F	PARTICIPANT	\N	PRESENT	0
62398	62357	14103D	PARTICIPANT	\N	PRESENT	0
62399	62357	11104D	PARTICIPANT	\N	PRESENT	0
62400	62357	14063N	PARTICIPANT	\N	PRESENT	0
62401	62357	04057K	PARTICIPANT	\N	PRESENT	0
62402	62357	11014C	PARTICIPANT	\N	PRESENT	0
62403	62357	14109K	PARTICIPANT	\N	PRESENT	0
62404	62357	04070G	PRESIDENT	0	PRESENT	0
62405	62357	92040Q	PARTICIPANT	\N	PRESENT	0
62406	62357	14191V	PARTICIPANT	\N	PRESENT	0
62407	62357	83047W	PARTICIPANT	\N	PRESENT	0
62408	62357	14235Q	PARTICIPANT	\N	PRESENT	0
62409	62357	14055N	PARTICIPANT	\N	PRESENT	0
62410	62357	04033B	PARTICIPANT	\N	PRESENT	0
62411	62357	14229S	PARTICIPANT	\N	PRESENT	0
62412	62357	11043H	PARTICIPANT	\N	PRESENT	0
71124	71118	14207L	PARTICIPANT	\N	PRESENT	0
72182	72181	04040A	PARTICIPANT	\N	PRESENT	0
71126	71118	90003B	PARTICIPANT	\N	PRESENT	0
71127	71118	08028W	PARTICIPANT	\N	PRESENT	0
71128	71118	80013X	PARTICIPANT	\N	PRESENT	0
71129	71118	08038Y	PARTICIPANT	\N	PRESENT	0
72155	72150	14041T	PARTICIPANT	\N	PRESENT	0
71131	71118	14197C	PARTICIPANT	\N	PRESENT	0
72183	72181	86034E	PARTICIPANT	\N	PRESENT	0
71133	71118	14187A	PARTICIPANT	\N	PRESENT	0
71134	71118	14033T	PARTICIPANT	\N	PRESENT	0
72157	72150	08018U	PARTICIPANT	\N	PRESENT	0
71136	71118	04048J	PARTICIPANT	\N	PRESENT	0
71137	71118	11099A	PARTICIPANT	\N	PRESENT	0
71138	71118	04049K	PARTICIPANT	\N	PRESENT	0
71139	71118	04094Q	PARTICIPANT	\N	PRESENT	0
71140	71118	11111C	PARTICIPANT	\N	PRESENT	0
71141	71118	08015R	PARTICIPANT	\N	PRESENT	0
71142	71118	11100Y	PRESIDENT	0	PRESENT	0
71143	71118	01061S	PARTICIPANT	\N	PRESENT	0
71144	71118	11098Y	PARTICIPANT	\N	PRESENT	0
72158	72150	01037S	PARTICIPANT	\N	PRESENT	0
71146	71118	11077T	PARTICIPANT	\N	PRESENT	0
71147	71118	14205J	PARTICIPANT	\N	PRESENT	0
72159	72150	08041T	PARTICIPANT	\N	PRESENT	0
71149	71118	14257W	PARTICIPANT	\N	PRESENT	0
72184	72181	08018U	PARTICIPANT	\N	PRESENT	0
72161	72150	08010L	PARTICIPANT	\N	PRESENT	0
72185	72181	14041T	PARTICIPANT	\N	PRESENT	0
71153	71118	11090Q	PARTICIPANT	\N	PRESENT	0
71154	71118	11046L	PARTICIPANT	\N	PRESENT	0
72186	72181	01037S	PARTICIPANT	\N	PRESENT	0
71156	71118	11094U	PARTICIPANT	\N	PRESENT	0
71157	71118	11066Q	PARTICIPANT	\N	PRESENT	0
72164	72150	11012A	PARTICIPANT	\N	PRESENT	0
72166	72165	04040A	PARTICIPANT	\N	PRESENT	0
72187	72181	11012A	PARTICIPANT	\N	PRESENT	0
72168	72165	77002U	PARTICIPANT	\N	PRESENT	0
72189	72188	08018U	PARTICIPANT	\N	PRESENT	0
72170	72165	14041T	PARTICIPANT	\N	PRESENT	0
72190	72188	04057K	PARTICIPANT	\N	PRESENT	0
72172	72165	08018U	PARTICIPANT	\N	PRESENT	0
72173	72165	01037S	PARTICIPANT	\N	PRESENT	0
72191	72188	96004D	PARTICIPANT	\N	PRESENT	0
72192	72188	92045V	PARTICIPANT	\N	PRESENT	0
72176	72165	08010L	PARTICIPANT	\N	PRESENT	0
72193	72188	11083R	PARTICIPANT	\N	PRESENT	0
72194	72188	04080J	PARTICIPANT	\N	PRESENT	0
72179	72165	11012A	PARTICIPANT	\N	PRESENT	0
72180	72105	11026G	PARTICIPANT	\N	PRESENT	0
72195	72188	10015M	PARTICIPANT	\N	PRESENT	0
72197	72196	14281W	PRESIDENT	0	PRESENT	0
72198	72196	07004J	PARTICIPANT	\N	PRESENT	0
72199	72196	14089Y	PARTICIPANT	\N	EXCUSE	0
72200	72196	14217N	PARTICIPANT	\N	EXCUSE	0
72201	72196	92020L	PARTICIPANT	\N	EXCUSE	0
72202	72196	08041T	PARTICIPANT	\N	EXCUSE	0
72203	72196	11082Q	PARTICIPANT	\N	EXCUSE	0
72204	72196	14193X	PARTICIPANT	\N	EXCUSE	0
72450	56945	95067Q	PARTICIPANT	\N	EXCUSE	0
72614	56945	14063N	PARTICIPANT	\N	EXCUSE	0
72858	71331	95062K	PARTICIPANT	\N	EXCUSE	0
72859	71331	14059S	PARTICIPANT	\N	EXCUSE	0
77267	77266	11039M	PARTICIPANT	\N	PRESENT	0
77268	77266	98042T	PARTICIPANT	\N	PRESENT	0
77269	77266	01019Q	PARTICIPANT	\N	PRESENT	0
72448	71331	08073C	PARTICIPANT	\N	EXCUSE	0
72530	72439	14187A	PARTICIPANT	\N	PRESENT	0
72531	72439	97011G	PARTICIPANT	\N	PRESENT	0
72532	72439	04081K	PARTICIPANT	\N	PRESENT	0
72533	72439	14193X	PARTICIPANT	\N	PRESENT	0
72534	72439	08022Q	PARTICIPANT	\N	PRESENT	0
72535	72439	07024N	PARTICIPANT	\N	PRESENT	0
72536	72439	99004R	PARTICIPANT	\N	PRESENT	0
72537	72439	11043H	PARTICIPANT	\N	PRESENT	0
72538	72439	14223L	PARTICIPANT	\N	PRESENT	0
72539	72439	08010L	PARTICIPANT	\N	PRESENT	0
72540	72439	87003B	PARTICIPANT	\N	PRESENT	0
72541	72439	01057W	PARTICIPANT	\N	PRESENT	0
72542	72439	08047A	PARTICIPANT	\N	PRESENT	0
72543	72439	14147R	PARTICIPANT	\N	PRESENT	0
72544	72439	08015R	PARTICIPANT	\N	PRESENT	0
72545	72439	14265W	PARTICIPANT	\N	PRESENT	0
72546	72439	14111D	PARTICIPANT	\N	PRESENT	0
72547	72439	08018U	PARTICIPANT	\N	PRESENT	0
72548	72439	14041T	PARTICIPANT	\N	PRESENT	0
72549	72439	04088S	PARTICIPANT	\N	PRESENT	0
72550	72439	14033T	PARTICIPANT	\N	PRESENT	0
72551	72439	14157T	PARTICIPANT	\N	PRESENT	0
72552	72439	08069G	PARTICIPANT	\N	PRESENT	0
72553	72439	14105F	PARTICIPANT	\N	PRESENT	0
72554	72439	14173T	PARTICIPANT	\N	PRESENT	0
72555	72439	14031R	PARTICIPANT	\N	PRESENT	0
72556	72439	14061L	PARTICIPANT	\N	PRESENT	0
72557	72439	98029W	PARTICIPANT	\N	PRESENT	0
72558	72439	14241N	PARTICIPANT	\N	PRESENT	0
72559	72439	04080J	PARTICIPANT	\N	PRESENT	0
72560	72439	11040E	PARTICIPANT	\N	PRESENT	0
72561	72439	08028W	PARTICIPANT	\N	PRESENT	0
72562	72439	14231L	PARTICIPANT	\N	PRESENT	0
72563	72439	14063N	PARTICIPANT	\N	PRESENT	0
72564	72439	11012A	PARTICIPANT	\N	PRESENT	0
72565	72439	14039A	PARTICIPANT	\N	PRESENT	0
72566	72439	04095R	PARTICIPANT	\N	PRESENT	0
72567	72439	14001X	PARTICIPANT	\N	PRESENT	0
72568	72439	04043D	PARTICIPANT	\N	PRESENT	0
72569	72439	04042C	PARTICIPANT	\N	PRESENT	0
72570	72439	08056B	PARTICIPANT	\N	PRESENT	0
72571	72439	08034U	PARTICIPANT	\N	PRESENT	0
72572	72439	08031R	PARTICIPANT	\N	PRESENT	0
72573	72439	14135M	PARTICIPANT	\N	PRESENT	0
72574	72439	10006L	PARTICIPANT	\N	PRESENT	0
72575	72439	14205J	PARTICIPANT	\N	PRESENT	0
72576	72439	14034U	PARTICIPANT	\N	PRESENT	0
72577	72439	04077P	PARTICIPANT	\N	PRESENT	0
72578	70707	01015L	PARTICIPANT	\N	PRESENT	0
72579	70707	14028W	PARTICIPANT	\N	PRESENT	0
72580	70707	11036J	PARTICIPANT	\N	PRESENT	0
72581	70707	95063L	PARTICIPANT	\N	PRESENT	0
72582	70707	14073Q	PARTICIPANT	\N	PRESENT	0
72583	70707	14083S	PARTICIPANT	\N	PRESENT	0
72584	70707	01025N	PARTICIPANT	\N	PRESENT	0
72585	70707	01048V	PARTICIPANT	\N	PRESENT	0
72586	70707	14251Q	PARTICIPANT	\N	PRESENT	0
72587	70707	11066Q	PARTICIPANT	\N	PRESENT	0
72703	70707	14263U	PARTICIPANT	\N	PRESENT	0
72704	70707	04034C	PARTICIPANT	\N	PRESENT	0
72705	70707	08014Q	PARTICIPANT	\N	PRESENT	0
72706	70707	01031L	PARTICIPANT	\N	PRESENT	0
72707	70707	08068F	PARTICIPANT	\N	PRESENT	0
72708	70707	98046X	PARTICIPANT	\N	PRESENT	0
72709	70707	01037S	PARTICIPANT	\N	PRESENT	0
72710	70707	11083R	PARTICIPANT	\N	PRESENT	0
72711	70709	89029V	PARTICIPANT	\N	PRESENT	0
72721	70709	14327T	PARTICIPANT	\N	PRESENT	0
72723	70709	04040A	PARTICIPANT	\N	PRESENT	0
72724	70709	14087W	PARTICIPANT	\N	PRESENT	0
72726	70709	11042G	PARTICIPANT	\N	PRESENT	0
72727	70709	01016M	PARTICIPANT	\N	PRESENT	0
72739	70709	04080J	PARTICIPANT	\N	PRESENT	0
72740	70709	11040E	PARTICIPANT	\N	PRESENT	0
72741	70709	11012A	PARTICIPANT	\N	PRESENT	0
72743	70709	08031R	PARTICIPANT	\N	PRESENT	0
72744	70709	14034U	PARTICIPANT	\N	PRESENT	0
71084	71061	11111C	PARTICIPANT	\N	PRESENT	0
71085	71061	08015R	PARTICIPANT	\N	PRESENT	0
71086	71061	11100Y	PRESIDENT	0	PRESENT	0
71087	71061	01061S	PARTICIPANT	\N	PRESENT	0
71088	71061	11098Y	PARTICIPANT	\N	PRESENT	0
71089	71061	01043Q	PARTICIPANT	\N	PRESENT	0
71090	71061	11077T	PARTICIPANT	\N	PRESENT	0
71091	71061	14205J	PARTICIPANT	\N	PRESENT	0
65420	60592	11106F	PARTICIPANT	\N	EXCUSE	0
72098	72097	08018U	PARTICIPANT	\N	PRESENT	0
73520	73517	08042U	PARTICIPANT	\N	PRESENT	0
73341	73309	04045F	PARTICIPANT	\N	PRESENT	0
73519	73517	98035U	PARTICIPANT	\N	PRESENT	0
74654	74653	11039M	PARTICIPANT	\N	PRESENT	0
74655	74653	98042T	PARTICIPANT	\N	PRESENT	0
74656	74653	01019Q	PARTICIPANT	\N	PRESENT	0
77494	77493	14030Q	PARTICIPANT	\N	PRESENT	0
77495	77493	80013X	PARTICIPANT	\N	PRESENT	0
77496	77493	14041T	PARTICIPANT	\N	PRESENT	0
77497	77493	14217N	PARTICIPANT	\N	PRESENT	0
77498	77493	14281W	PARTICIPANT	\N	PRESENT	0
77499	77493	09001P	PRESIDENT	0	PRESENT	0
77500	77493	14031R	PARTICIPANT	\N	PRESENT	0
77501	77493	04036E	PARTICIPANT	\N	PRESENT	0
77502	77493	08043V	PARTICIPANT	\N	EXCUSE	0
77503	77493	14038Y	PARTICIPANT	\N	EXCUSE	0
77504	77493	12042Y	PARTICIPANT	\N	EXCUSE	0
77505	77493	14014Q	PARTICIPANT	\N	EXCUSE	0
77506	77493	08031R	PARTICIPANT	\N	EXCUSE	0
77507	77493	14265W	PARTICIPANT	\N	EXCUSE	0
77508	77493	14237S	PARTICIPANT	\N	EXCUSE	0
77513	77511	14327T	PARTICIPANT	\N	PRESENT	0
77594	77592	11032E	PARTICIPANT	\N	PRESENT	0
77602	77598	14071N	PARTICIPANT	\N	PRESENT	0
77599	77598	04059M	PARTICIPANT	\N	PRESENT	0
77600	77598	98029W	PARTICIPANT	\N	PRESENT	0
77603	77598	14193X	PARTICIPANT	\N	PRESENT	0
77604	77598	04049K	PARTICIPANT	\N	PRESENT	0
77607	77598	14089Y	PARTICIPANT	\N	PRESENT	0
80891	80433	08061X	PARTICIPANT	\N	PRESENT	0
80895	80433	11032E	PARTICIPANT	\N	PRESENT	0
80893	80433	01059Y	PARTICIPANT	\N	PRESENT	0
80894	80433	92018S	PARTICIPANT	\N	PRESENT	0
80896	80433	11063M	PARTICIPANT	\N	PRESENT	0
80897	80433	14013P	PARTICIPANT	\N	PRESENT	0
80909	80433	11031D	PARTICIPANT	\N	PRESENT	0
80899	80433	99002P	PARTICIPANT	\N	PRESENT	0
80900	80433	08062Y	PARTICIPANT	\N	PRESENT	0
80907	80433	11085T	PARTICIPANT	\N	PRESENT	0
80902	80433	14151M	PARTICIPANT	\N	PRESENT	0
80903	80433	14263U	PARTICIPANT	\N	PRESENT	0
80904	80433	14269B	PARTICIPANT	\N	PRESENT	0
80905	80433	14063N	PARTICIPANT	\N	PRESENT	0
80906	80433	14135M	PARTICIPANT	\N	PRESENT	0
80912	80433	11039M	PARTICIPANT	\N	PRESENT	0
80910	80433	13002U	PARTICIPANT	\N	PRESENT	0
80911	80433	01016M	PARTICIPANT	\N	PRESENT	0
80913	80433	04038G	PARTICIPANT	\N	PRESENT	0
80914	80433	11090Q	PARTICIPANT	\N	PRESENT	0
80915	80433	08073C	PARTICIPANT	\N	PRESENT	0
80916	80433	08038Y	PARTICIPANT	\N	PRESENT	0
80920	80433	04070G	PARTICIPANT	\N	PRESENT	0
80918	80433	04071H	PARTICIPANT	\N	PRESENT	0
80922	80433	11061K	PARTICIPANT	\N	PRESENT	0
80921	80433	08043V	PARTICIPANT	\N	PRESENT	0
80923	80433	07032N	PARTICIPANT	\N	PRESENT	0
80924	80433	11015D	PARTICIPANT	\N	PRESENT	0
80925	80433	08056B	PARTICIPANT	\N	PRESENT	0
80934	80433	89017R	PARTICIPANT	\N	PRESENT	0
80927	80433	11042G	PARTICIPANT	\N	PRESENT	0
80933	80433	14327T	PARTICIPANT	\N	PRESENT	0
80935	80433	98021N	PARTICIPANT	\N	PRESENT	0
80936	80434	89029V	PARTICIPANT	\N	PRESENT	0
80937	80434	05008E	PARTICIPANT	\N	PRESENT	0
80938	80434	14097Y	PARTICIPANT	\N	PRESENT	0
80939	80434	01047U	PARTICIPANT	\N	PRESENT	0
80940	80434	87003B	PARTICIPANT	\N	PRESENT	0
80941	80434	14331P	PARTICIPANT	\N	PRESENT	0
80942	80434	04077P	PARTICIPANT	\N	PRESENT	0
80943	80434	11037K	PARTICIPANT	\N	PRESENT	0
80944	80434	11105E	PARTICIPANT	\N	PRESENT	0
80945	80434	14001X	PARTICIPANT	\N	PRESENT	0
80946	80434	14133K	PARTICIPANT	\N	PRESENT	0
80947	80434	04048J	PARTICIPANT	\N	PRESENT	0
80948	80434	08052W	PARTICIPANT	\N	PRESENT	0
80949	80434	98024R	PARTICIPANT	\N	PRESENT	0
80950	80434	95031C	PARTICIPANT	\N	PRESENT	0
80951	80434	95049N	PARTICIPANT	\N	PRESENT	0
80952	80434	14073Q	PARTICIPANT	\N	PRESENT	0
80953	80434	04092N	PARTICIPANT	\N	PRESENT	0
80954	80434	14103D	PARTICIPANT	\N	PRESENT	0
80955	80434	97011G	PARTICIPANT	\N	PRESENT	0
80956	80434	08041T	PARTICIPANT	\N	PRESENT	0
80957	80434	98018T	PARTICIPANT	\N	PRESENT	0
80958	80434	14223L	PARTICIPANT	\N	PRESENT	0
80959	80434	14215L	PARTICIPANT	\N	PRESENT	0
80960	80434	04053F	PARTICIPANT	\N	PRESENT	0
80961	80434	80027E	PARTICIPANT	\N	PRESENT	0
80962	80434	14221J	PARTICIPANT	\N	PRESENT	0
80963	80434	14065Q	PARTICIPANT	\N	PRESENT	0
80964	80434	11027H	PARTICIPANT	\N	PRESENT	0
80965	80434	11103C	PARTICIPANT	\N	PRESENT	0
80966	80434	07034Q	PARTICIPANT	\N	PRESENT	0
80967	80434	14231L	PARTICIPANT	\N	PRESENT	0
80968	80434	14071N	PARTICIPANT	\N	PRESENT	0
80969	80434	04044E	PARTICIPANT	\N	PRESENT	0
80970	80434	00003C	PARTICIPANT	\N	PRESENT	0
80971	80434	98035U	PARTICIPANT	\N	PRESENT	0
80972	80434	14018U	PARTICIPANT	\N	PRESENT	0
80973	80434	14085U	PARTICIPANT	\N	PRESENT	0
80974	80434	11036J	PARTICIPANT	\N	PRESENT	0
80975	80434	11011M	PARTICIPANT	\N	PRESENT	0
80976	80434	98023Q	PARTICIPANT	\N	PRESENT	0
80977	80434	11066Q	PARTICIPANT	\N	PRESENT	0
80978	80434	80013X	PARTICIPANT	\N	PRESENT	0
80979	80434	14017T	PARTICIPANT	\N	PRESENT	0
80980	80434	14059S	PARTICIPANT	\N	PRESENT	0
80981	80434	07026Q	PARTICIPANT	\N	PRESENT	0
80982	80434	11109J	PARTICIPANT	\N	PRESENT	0
80983	80434	10015M	PARTICIPANT	\N	PRESENT	0
80984	80434	04088S	PARTICIPANT	\N	PRESENT	0
80985	80434	92040Q	PARTICIPANT	\N	PRESENT	0
80986	80434	04074L	PARTICIPANT	\N	PRESENT	0
80987	80434	11101A	PARTICIPANT	\N	PRESENT	0
80988	80434	14105F	PARTICIPANT	\N	PRESENT	0
80989	80434	11081P	PARTICIPANT	\N	PRESENT	0
80990	80434	11111C	PARTICIPANT	\N	PRESENT	0
80991	80434	12042Y	PARTICIPANT	\N	PRESENT	0
80992	80434	08025T	PARTICIPANT	\N	PRESENT	0
80993	80434	01015L	PARTICIPANT	\N	PRESENT	0
80994	80434	08021P	PARTICIPANT	\N	PRESENT	0
80995	80434	08058D	PARTICIPANT	\N	PRESENT	0
80996	80434	11112D	PARTICIPANT	\N	PRESENT	0
80997	80434	11067R	PARTICIPANT	\N	PRESENT	0
80998	80434	01011G	PARTICIPANT	\N	PRESENT	0
80999	80434	01022K	PARTICIPANT	\N	PRESENT	0
81000	80434	14247U	PARTICIPANT	\N	PRESENT	0
81001	80434	11097X	PARTICIPANT	\N	PRESENT	0
81002	80434	14213J	PARTICIPANT	\N	PRESENT	0
81003	80434	04057K	PARTICIPANT	\N	PRESENT	0
81004	80434	11049P	PARTICIPANT	\N	PRESENT	0
81005	80434	14273W	PARTICIPANT	\N	PRESENT	0
81006	80434	11098Y	PARTICIPANT	\N	PRESENT	0
81007	80434	14235Q	PARTICIPANT	\N	PRESENT	0
81008	80434	12041X	PARTICIPANT	\N	PRESENT	0
81009	80434	11034G	PARTICIPANT	\N	PRESENT	0
81010	80434	11029K	PARTICIPANT	\N	PRESENT	0
81011	80434	11113E	PARTICIPANT	\N	PRESENT	0
81012	80434	08028W	PARTICIPANT	\N	PRESENT	0
81013	80434	08065C	PARTICIPANT	\N	PRESENT	0
81014	80434	14079W	PARTICIPANT	\N	PRESENT	0
81015	80434	14026U	PARTICIPANT	\N	PRESENT	0
81016	80434	05012A	PARTICIPANT	\N	PRESENT	0
81017	80434	98029W	PARTICIPANT	\N	PRESENT	0
81018	80434	14271U	PARTICIPANT	\N	PRESENT	0
81019	80434	14199E	PARTICIPANT	\N	PRESENT	0
81020	80434	14259Y	PARTICIPANT	\N	PRESENT	0
81021	80434	08051V	PARTICIPANT	\N	PRESENT	0
81022	80434	92020L	PARTICIPANT	\N	PRESENT	0
81023	80434	95030B	PARTICIPANT	\N	PRESENT	0
81024	80434	11040E	PARTICIPANT	\N	PRESENT	0
81025	80434	11096W	PARTICIPANT	\N	PRESENT	0
81026	80434	04085P	PARTICIPANT	\N	PRESENT	0
81027	80434	04054G	PARTICIPANT	\N	PRESENT	0
81028	80434	11056N	PARTICIPANT	\N	PRESENT	0
81029	80434	95063L	PARTICIPANT	\N	PRESENT	0
81030	80434	08053X	PARTICIPANT	\N	PRESENT	0
81031	80434	08012N	PARTICIPANT	\N	PRESENT	0
81136	80434	14037X	PARTICIPANT	\N	PRESENT	0
81137	80434	14061L	PARTICIPANT	\N	PRESENT	0
81138	80434	11088W	PARTICIPANT	\N	PRESENT	0
81139	80434	14041T	PARTICIPANT	\N	PRESENT	0
81140	80434	01014K	PARTICIPANT	\N	PRESENT	0
81141	80434	01056V	PARTICIPANT	\N	PRESENT	0
81142	80434	01013J	PARTICIPANT	\N	PRESENT	0
81143	80434	99004R	PARTICIPANT	\N	PRESENT	0
81144	80434	11053K	PARTICIPANT	\N	PRESENT	0
81145	80434	95035G	PARTICIPANT	\N	PRESENT	0
81146	80434	95059Q	PARTICIPANT	\N	PRESENT	0
81147	80434	14033T	PARTICIPANT	\N	PRESENT	0
81148	80434	14193X	PARTICIPANT	\N	PRESENT	0
81149	80434	01008M	PARTICIPANT	\N	PRESENT	0
81150	80434	07029T	PARTICIPANT	\N	PRESENT	0
81151	80434	98005N	PARTICIPANT	\N	PRESENT	0
81152	80434	08015R	PARTICIPANT	\N	PRESENT	0
81153	80434	08034U	PARTICIPANT	\N	PRESENT	0
81154	80434	14195A	PARTICIPANT	\N	PRESENT	0
81155	80434	90003B	PARTICIPANT	\N	PRESENT	0
81156	80434	01061S	PARTICIPANT	\N	PRESENT	0
81157	80434	08019V	PARTICIPANT	\N	PRESENT	0
81158	80434	02002K	PARTICIPANT	\N	PRESENT	0
81159	80434	04042C	PARTICIPANT	\N	PRESENT	0
81160	80434	14175V	PARTICIPANT	\N	PRESENT	0
81161	80434	05004A	PARTICIPANT	\N	PRESENT	0
81162	80434	01027Q	PARTICIPANT	\N	PRESENT	0
81163	80434	04036E	PARTICIPANT	\N	PRESENT	0
81164	80434	04097T	PARTICIPANT	\N	PRESENT	0
81165	80434	14169X	PARTICIPANT	\N	PRESENT	0
81166	80434	14119M	PARTICIPANT	\N	PRESENT	0
81167	80434	14253S	PARTICIPANT	\N	PRESENT	0
81168	80434	04043D	PARTICIPANT	\N	PRESENT	0
81169	80434	14265W	PARTICIPANT	\N	PRESENT	0
81170	80434	95062K	PARTICIPANT	\N	PRESENT	0
73684	72251	01028R	PARTICIPANT	\N	PRESENT	0
81058	80434	11091R	PARTICIPANT	\N	PRESENT	0
81059	80434	11099A	PARTICIPANT	\N	PRESENT	0
81060	80434	11014C	PARTICIPANT	\N	PRESENT	0
81061	80434	14034U	PARTICIPANT	\N	PRESENT	0
81062	80434	04080J	PARTICIPANT	\N	PRESENT	0
81063	80434	83047W	PARTICIPANT	\N	PRESENT	0
81064	80434	14159V	PARTICIPANT	\N	PRESENT	0
81065	80434	11070L	PARTICIPANT	\N	PRESENT	0
81066	80434	04089T	PARTICIPANT	\N	PRESENT	0
81067	80434	14030Q	PARTICIPANT	\N	PRESENT	0
81068	80434	14042U	PARTICIPANT	\N	PRESENT	0
81069	80434	04040A	PARTICIPANT	\N	PRESENT	0
81070	80434	11065P	PARTICIPANT	\N	PRESENT	0
81071	80434	14227Q	PARTICIPANT	\N	PRESENT	0
81072	80434	04049K	PARTICIPANT	\N	PRESENT	0
81073	80434	08017T	PARTICIPANT	\N	PRESENT	0
81074	80434	14229S	PARTICIPANT	\N	PRESENT	0
81075	80434	14191V	PARTICIPANT	\N	PRESENT	0
81076	80434	11077T	PARTICIPANT	\N	PRESENT	0
81077	80434	08055A	PARTICIPANT	\N	PRESENT	0
81078	80434	14123H	PARTICIPANT	\N	PRESENT	0
81079	80434	11054L	PARTICIPANT	\N	PRESENT	0
81080	80434	08069G	PARTICIPANT	\N	PRESENT	0
81081	80434	08024S	PARTICIPANT	\N	PRESENT	0
81082	80434	11068S	PARTICIPANT	\N	PRESENT	0
81083	80434	01043Q	PARTICIPANT	\N	PRESENT	0
81084	80434	01007L	PARTICIPANT	\N	PRESENT	0
81085	80434	01025N	PARTICIPANT	\N	PRESENT	0
81086	80434	09001P	PARTICIPANT	\N	PRESENT	0
81087	80434	08009T	PARTICIPANT	\N	PRESENT	0
81088	80434	07004J	PARTICIPANT	\N	PRESENT	0
81089	80434	98042T	PARTICIPANT	\N	PRESENT	0
81090	80434	04034C	PARTICIPANT	\N	PRESENT	0
81091	80434	01031L	PARTICIPANT	\N	PRESENT	0
81092	80434	14083S	PARTICIPANT	\N	PRESENT	0
81093	80434	14147R	PARTICIPANT	\N	PRESENT	0
81094	80434	92044U	PARTICIPANT	\N	PRESENT	0
81095	80434	11082Q	PARTICIPANT	\N	PRESENT	0
81096	80434	11046L	PARTICIPANT	\N	PRESENT	0
81097	80434	11080N	PARTICIPANT	\N	PRESENT	0
81098	80434	14205J	PARTICIPANT	\N	PRESENT	0
81099	80434	14089Y	PARTICIPANT	\N	PRESENT	0
81100	80434	08014Q	PARTICIPANT	\N	PRESENT	0
81101	80434	11107G	PARTICIPANT	\N	PRESENT	0
81102	80434	04059M	PARTICIPANT	\N	PRESENT	0
81103	80434	14107H	PARTICIPANT	\N	PRESENT	0
81104	80434	11048N	PARTICIPANT	\N	PRESENT	0
81105	80434	14051J	PARTICIPANT	\N	PRESENT	0
81106	80434	11033F	PARTICIPANT	\N	PRESENT	0
81107	80434	11030C	PARTICIPANT	\N	PRESENT	0
81108	80434	11057P	PARTICIPANT	\N	PRESENT	0
81109	80434	14209N	PARTICIPANT	\N	PRESENT	0
81110	80434	11044J	PARTICIPANT	\N	PRESENT	0
81111	80434	14069U	PARTICIPANT	\N	PRESENT	0
81112	80434	14031R	PARTICIPANT	\N	PRESENT	0
81113	80434	11026G	PARTICIPANT	\N	PRESENT	0
81114	80434	04035D	PARTICIPANT	\N	PRESENT	0
81115	80434	08022Q	PARTICIPANT	\N	PRESENT	0
81116	80434	92031P	PARTICIPANT	\N	PRESENT	0
81117	80434	04086Q	PARTICIPANT	\N	PRESENT	0
81118	80434	10006L	PARTICIPANT	\N	PRESENT	0
81119	80434	04033B	PARTICIPANT	\N	PRESENT	0
81120	80434	08044W	PARTICIPANT	\N	PRESENT	0
81121	80434	14257W	PARTICIPANT	\N	PRESENT	0
81122	80434	14087W	PARTICIPANT	\N	PRESENT	0
81123	80434	14207L	PARTICIPANT	\N	PRESENT	0
81124	80434	11110B	PARTICIPANT	\N	PRESENT	0
81125	80434	11064N	PARTICIPANT	\N	PRESENT	0
81126	80434	11094U	PARTICIPANT	\N	PRESENT	0
81127	80434	14093U	PARTICIPANT	\N	PRESENT	0
81128	80434	14217N	PARTICIPANT	\N	PRESENT	0
81129	80434	14249W	PARTICIPANT	\N	PRESENT	0
81130	80434	01041N	PARTICIPANT	\N	PRESENT	0
81131	80434	14329V	PARTICIPANT	\N	PRESENT	0
81132	80434	14187A	PARTICIPANT	\N	PRESENT	0
81133	80434	08042U	PARTICIPANT	\N	PRESENT	0
81134	80434	14038Y	PARTICIPANT	\N	PRESENT	0
81135	80434	11095V	PARTICIPANT	\N	PRESENT	0
81171	80434	01019Q	PARTICIPANT	\N	PRESENT	0
81172	80434	01058X	PARTICIPANT	\N	PRESENT	0
81173	80434	08047A	PARTICIPANT	\N	PRESENT	0
81174	80434	14111D	PARTICIPANT	\N	PRESENT	0
81175	80434	08039A	PARTICIPANT	\N	PRESENT	0
81176	80434	08011M	PARTICIPANT	\N	PRESENT	0
81177	80434	08010L	PARTICIPANT	\N	PRESENT	0
81178	80434	08018U	PARTICIPANT	\N	PRESENT	0
81179	80434	14211G	PARTICIPANT	\N	PRESENT	0
81180	80434	04081K	PARTICIPANT	\N	PRESENT	0
81181	80434	11043H	PARTICIPANT	\N	PRESENT	0
81182	80434	11071M	PARTICIPANT	\N	PRESENT	0
81183	80434	07024N	PARTICIPANT	\N	PRESENT	0
81184	80434	14157T	PARTICIPANT	\N	PRESENT	0
81185	80434	08060W	PARTICIPANT	\N	PRESENT	0
81186	80434	95067Q	PARTICIPANT	\N	PRESENT	0
81187	80434	14173T	PARTICIPANT	\N	PRESENT	0
81188	80434	01057W	PARTICIPANT	\N	PRESENT	0
81189	80434	14053L	PARTICIPANT	\N	PRESENT	0
81190	80434	01060R	PARTICIPANT	\N	PRESENT	0
81191	80434	95041E	PARTICIPANT	\N	PRESENT	0
81192	80434	86034E	PARTICIPANT	\N	PRESENT	0
81193	80434	04056J	PARTICIPANT	\N	PRESENT	0
81194	80434	04045F	PARTICIPANT	\N	PRESENT	0
81195	80434	04061F	PARTICIPANT	\N	PRESENT	0
81196	80434	98046X	PARTICIPANT	\N	PRESENT	0
81197	80434	11074Q	PARTICIPANT	\N	PRESENT	0
81198	80434	04079R	PARTICIPANT	\N	PRESENT	0
81199	80434	04055H	PARTICIPANT	\N	PRESENT	0
81200	80434	04078Q	PARTICIPANT	\N	PRESENT	0
81201	80434	98022P	PARTICIPANT	\N	PRESENT	0
81202	80434	08061X	PARTICIPANT	\N	PRESENT	0
81203	80434	01059Y	PARTICIPANT	\N	PRESENT	0
81204	80434	92018S	PARTICIPANT	\N	PRESENT	0
81205	80434	11032E	PARTICIPANT	\N	PRESENT	0
81206	80434	11063M	PARTICIPANT	\N	PRESENT	0
81207	80434	14013P	PARTICIPANT	\N	PRESENT	0
81208	80434	99002P	PARTICIPANT	\N	PRESENT	0
81209	80434	08062Y	PARTICIPANT	\N	PRESENT	0
81210	80434	14151M	PARTICIPANT	\N	PRESENT	0
81211	80434	14263U	PARTICIPANT	\N	PRESENT	0
81212	80434	14269B	PARTICIPANT	\N	PRESENT	0
81213	80434	14063N	PARTICIPANT	\N	PRESENT	0
81214	80434	14135M	PARTICIPANT	\N	PRESENT	0
81215	80434	11085T	PARTICIPANT	\N	PRESENT	0
81216	80434	11031D	PARTICIPANT	\N	PRESENT	0
81217	80434	13002U	PARTICIPANT	\N	PRESENT	0
81218	80434	01016M	PARTICIPANT	\N	PRESENT	0
81219	80434	11039M	PARTICIPANT	\N	PRESENT	0
81220	80434	04038G	PARTICIPANT	\N	PRESENT	0
81221	80434	11090Q	PARTICIPANT	\N	PRESENT	0
81222	80434	08073C	PARTICIPANT	\N	PRESENT	0
81223	80434	08038Y	PARTICIPANT	\N	PRESENT	0
81224	80434	04071H	PARTICIPANT	\N	PRESENT	0
68373	68372	11039M	PARTICIPANT	\N	PRESENT	0
68374	68372	98042T	PARTICIPANT	\N	PRESENT	0
68375	68372	01019Q	PARTICIPANT	\N	PRESENT	0
68522	68521	14261S	PARTICIPANT	\N	PRESENT	0
68523	68521	08055A	PARTICIPANT	\N	PRESENT	0
68524	68521	14093U	PARTICIPANT	\N	PRESENT	0
68525	68521	14030Q	PARTICIPANT	\N	PRESENT	0
68561	68521	11098Y	PARTICIPANT	\N	PRESENT	0
68527	68521	08060W	PARTICIPANT	\N	PRESENT	0
68528	68521	11095V	PARTICIPANT	\N	PRESENT	0
68529	68521	14038Y	PARTICIPANT	\N	PRESENT	0
68660	68659	11076S	PARTICIPANT	\N	PRESENT	0
68531	68521	98023Q	PARTICIPANT	\N	PRESENT	0
68532	68521	11065P	PARTICIPANT	\N	PRESENT	0
68533	68521	01015L	PARTICIPANT	\N	PRESENT	0
68534	68521	11107G	PARTICIPANT	\N	PRESENT	0
68661	68659	04054G	PARTICIPANT	\N	PRESENT	0
68536	68521	02002K	PARTICIPANT	\N	PRESENT	0
68537	68521	01022K	PARTICIPANT	\N	PRESENT	0
68662	68659	04040A	PARTICIPANT	\N	PRESENT	0
68539	68521	09001P	PARTICIPANT	\N	PRESENT	0
68540	68521	11059R	PARTICIPANT	\N	PRESENT	0
68541	68521	14219Q	PARTICIPANT	\N	PRESENT	0
68542	68521	80027E	PARTICIPANT	\N	PRESENT	0
68543	68521	14031R	PARTICIPANT	\N	PRESENT	0
68544	68521	08009T	PRESIDENT	0	PRESENT	0
68545	68521	08062Y	PARTICIPANT	\N	PRESENT	0
68546	68521	14221J	PARTICIPANT	\N	PRESENT	0
68547	68521	92039X	PARTICIPANT	\N	PRESENT	0
68548	68521	08042U	PARTICIPANT	\N	PRESENT	0
68549	68521	14169X	PARTICIPANT	\N	PRESENT	0
68550	68521	14237S	PARTICIPANT	\N	PRESENT	0
68551	68521	13002U	PARTICIPANT	\N	PRESENT	0
68552	68521	05012A	PARTICIPANT	\N	PRESENT	0
68553	68521	14247U	PARTICIPANT	\N	PRESENT	0
68554	68521	14135M	PARTICIPANT	\N	PRESENT	0
68555	68521	14331P	PARTICIPANT	\N	PRESENT	0
68556	68521	95062K	PARTICIPANT	\N	PRESENT	0
68557	68521	14107H	PARTICIPANT	\N	EXCUSE	0
68558	68521	14051J	PARTICIPANT	\N	PRESENT	0
68559	68521	14157T	PARTICIPANT	\N	PRESENT	0
68560	68521	96003C	PARTICIPANT	\N	EXCUSE	0
68663	68659	08058D	PARTICIPANT	\N	PRESENT	0
68664	68659	04042C	PRESIDENT	0	PRESENT	0
68665	68659	77002U	PARTICIPANT	\N	PRESENT	0
68666	68659	98029W	PARTICIPANT	\N	PRESENT	0
68667	68659	98018T	PARTICIPANT	\N	PRESENT	0
68668	68659	92018S	PARTICIPANT	\N	PRESENT	0
68669	68659	92020L	PARTICIPANT	\N	PRESENT	0
68670	68659	97011G	PARTICIPANT	\N	PRESENT	0
68671	68659	08065C	PARTICIPANT	\N	PRESENT	0
68672	68659	04035D	PARTICIPANT	\N	PRESENT	0
68673	68659	07024N	PARTICIPANT	\N	PRESENT	0
68674	68659	14014Q	PARTICIPANT	\N	PRESENT	0
68675	68659	11015D	PARTICIPANT	\N	PRESENT	0
68676	68659	07004J	PARTICIPANT	\N	PRESENT	0
68677	68659	95035G	PARTICIPANT	\N	PRESENT	0
68678	68659	08056B	PARTICIPANT	\N	PRESENT	0
68679	68659	14211G	PARTICIPANT	\N	PRESENT	0
68680	68659	11064N	PARTICIPANT	\N	PRESENT	0
68681	68659	95037J	PARTICIPANT	\N	PRESENT	0
68682	68659	04078Q	PARTICIPANT	\N	PRESENT	0
68683	68659	14097Y	PARTICIPANT	\N	PRESENT	0
68684	68659	04036E	PARTICIPANT	\N	PRESENT	0
68685	68659	14039A	PARTICIPANT	\N	PRESENT	0
68686	68659	92031P	PARTICIPANT	\N	PRESENT	0
68687	68659	11106F	PARTICIPANT	\N	PRESENT	0
68688	68659	14251Q	PARTICIPANT	\N	PRESENT	0
68689	68659	08053X	PARTICIPANT	\N	PRESENT	0
68690	68659	11082Q	PARTICIPANT	\N	PRESENT	0
68691	68659	11105E	PARTICIPANT	\N	PRESENT	0
68692	68659	14253S	PARTICIPANT	\N	PRESENT	0
68693	68659	08047A	PARTICIPANT	\N	PRESENT	0
68694	68659	14028W	PARTICIPANT	\N	PRESENT	0
68695	68659	14193X	PARTICIPANT	\N	PRESENT	0
68696	68659	98021N	PARTICIPANT	\N	PRESENT	0
68697	68659	04080J	PARTICIPANT	\N	PRESENT	0
68698	68659	95059Q	PARTICIPANT	\N	EXCUSE	0
68699	68659	86044G	PARTICIPANT	\N	PRESENT	0
68700	68659	01014K	PARTICIPANT	\N	PRESENT	0
68701	68659	11054L	PARTICIPANT	\N	PRESENT	0
68702	68659	01056V	PARTICIPANT	\N	PRESENT	0
68703	68659	08049C	PARTICIPANT	\N	PRESENT	0
69026	66812	11101A	PARTICIPANT	\N	PRESENT	0
69028	66812	08038Y	PARTICIPANT	\N	PRESENT	0
69030	66812	05012A	PARTICIPANT	\N	PRESENT	0
69032	66812	04045F	PARTICIPANT	\N	PRESENT	0
69036	66812	14030Q	PARTICIPANT	\N	PRESENT	0
69049	66813	05012A	PARTICIPANT	\N	PRESENT	0
69050	66813	11101A	PARTICIPANT	\N	PRESENT	0
69051	66813	08038Y	PARTICIPANT	\N	PRESENT	0
69052	66813	04045F	PARTICIPANT	\N	PRESENT	0
69053	66813	14071N	PARTICIPANT	\N	PRESENT	0
71392	71388	01008M	PARTICIPANT	\N	PRESENT	0
71393	71388	11036J	PARTICIPANT	\N	PRESENT	0
71432	71388	89017R	PARTICIPANT	\N	PRESENT	0
71433	71388	01031L	PARTICIPANT	\N	PRESENT	0
71396	71388	08068F	PARTICIPANT	\N	PRESENT	0
71397	71388	14207L	PARTICIPANT	\N	PRESENT	0
71435	71388	01013J	PARTICIPANT	\N	PRESENT	0
71436	71388	11068S	PARTICIPANT	\N	PRESENT	0
71400	71388	08028W	PARTICIPANT	\N	PRESENT	0
71401	71388	80013X	PARTICIPANT	\N	PRESENT	0
71402	71388	08038Y	PARTICIPANT	\N	PRESENT	0
71437	71388	11040E	PARTICIPANT	\N	PRESENT	0
71404	71388	14197C	PARTICIPANT	\N	PRESENT	0
71405	71388	11110B	PARTICIPANT	\N	PRESENT	0
71406	71388	14187A	PARTICIPANT	\N	PRESENT	0
71407	71388	14033T	PARTICIPANT	\N	PRESENT	0
71438	71388	08014Q	PARTICIPANT	\N	PRESENT	0
71409	71388	04048J	PARTICIPANT	\N	PRESENT	0
71439	71388	14175V	PARTICIPANT	\N	PRESENT	0
71411	71388	04049K	PARTICIPANT	\N	PRESENT	0
71440	71388	14083S	PARTICIPANT	\N	PRESENT	0
71413	71388	11111C	PARTICIPANT	\N	PRESENT	0
71414	71388	08015R	PARTICIPANT	\N	PRESENT	0
71415	71388	11100Y	PRESIDENT	0	PRESENT	0
71416	71388	01061S	PARTICIPANT	\N	PRESENT	0
71417	71388	11098Y	PARTICIPANT	\N	PRESENT	0
71441	71388	11053K	PARTICIPANT	\N	PRESENT	0
71442	71388	14085U	PARTICIPANT	\N	PRESENT	0
71420	71388	14205J	PARTICIPANT	\N	PRESENT	0
71421	71388	08019V	PARTICIPANT	\N	EXCUSE	0
71422	71388	14257W	PARTICIPANT	\N	PRESENT	0
71443	71388	11042G	PARTICIPANT	\N	PRESENT	0
71444	71388	88008L	PARTICIPANT	\N	PRESENT	0
71445	71388	04086Q	PARTICIPANT	\N	PRESENT	0
71426	71388	11090Q	PARTICIPANT	\N	PRESENT	0
71427	71388	11046L	PARTICIPANT	\N	PRESENT	0
71447	71388	04055H	PARTICIPANT	\N	PRESENT	0
71448	71388	11088W	PARTICIPANT	\N	PRESENT	0
71430	71388	11066Q	PARTICIPANT	\N	PRESENT	0
71449	71388	08022Q	PARTICIPANT	\N	PRESENT	0
72747	70709	11036J	PARTICIPANT	\N	PRESENT	0
72797	70709	14103D	PARTICIPANT	\N	PRESENT	0
72749	70709	01025N	PARTICIPANT	\N	PRESENT	0
72794	70709	04057K	PARTICIPANT	\N	PRESENT	0
72795	70709	14273W	PARTICIPANT	\N	PRESENT	0
72798	70709	14179A	PARTICIPANT	\N	PRESENT	0
72799	70709	14197C	PARTICIPANT	\N	PRESENT	0
72804	70709	14026U	PARTICIPANT	\N	PRESENT	0
72796	70709	14209N	PARTICIPANT	\N	PRESENT	0
72756	70709	14159V	PARTICIPANT	\N	PRESENT	0
72757	70709	14013P	PARTICIPANT	\N	PRESENT	0
72758	70709	14231L	PARTICIPANT	\N	PRESENT	0
72800	70709	14033T	PARTICIPANT	\N	PRESENT	0
72793	70709	95059Q	PARTICIPANT	\N	PRESENT	0
72761	70709	14030Q	PARTICIPANT	\N	PRESENT	0
72801	70709	04088S	PARTICIPANT	\N	PRESENT	0
72802	70709	14265W	PARTICIPANT	\N	PRESENT	0
72764	70709	11035H	PARTICIPANT	\N	PRESENT	0
72765	70709	14133K	PARTICIPANT	\N	PRESENT	0
72803	70709	14069U	PARTICIPANT	\N	PRESENT	0
72811	70709	14083S	PARTICIPANT	\N	PRESENT	0
72768	70709	01008M	PARTICIPANT	\N	PRESENT	0
72812	70709	14217N	PARTICIPANT	\N	PRESENT	0
72813	70709	14135M	PARTICIPANT	\N	PRESENT	0
72814	70709	08011M	PARTICIPANT	\N	PRESENT	0
72815	70709	11094U	PARTICIPANT	\N	PRESENT	0
72792	70709	98035U	PARTICIPANT	\N	PRESENT	0
72774	70709	04061F	PARTICIPANT	\N	PRESENT	0
72775	70709	08056B	PARTICIPANT	\N	PRESENT	0
72776	70709	14205J	PARTICIPANT	\N	PRESENT	0
72777	70709	14089Y	PARTICIPANT	\N	PRESENT	0
72778	70709	96004D	PARTICIPANT	\N	PRESENT	0
72779	70709	08028W	PARTICIPANT	\N	PRESENT	0
72780	70709	14263U	PARTICIPANT	\N	PRESENT	0
72781	70709	04034C	PARTICIPANT	\N	PRESENT	0
72791	70709	11066Q	PARTICIPANT	\N	PRESENT	0
72816	70709	14111D	PARTICIPANT	\N	PRESENT	0
72817	70709	14187A	PARTICIPANT	\N	PRESENT	0
72785	70709	98046X	PARTICIPANT	\N	PRESENT	0
72786	70709	01037S	PARTICIPANT	\N	PRESENT	0
72787	70709	11083R	PARTICIPANT	\N	PRESENT	0
72788	70709	88008L	PARTICIPANT	\N	PRESENT	0
72789	70709	14207L	PARTICIPANT	\N	PRESENT	0
72790	70709	14001X	PARTICIPANT	\N	PRESENT	0
72818	70709	11097X	PARTICIPANT	\N	PRESENT	0
72819	70709	04066L	PARTICIPANT	\N	PRESENT	0
72820	70709	01031L	PARTICIPANT	\N	PRESENT	0
72821	70709	08051V	PARTICIPANT	\N	PRESENT	0
72822	70709	11048N	PARTICIPANT	\N	PRESENT	0
72823	70709	11112D	PARTICIPANT	\N	PRESENT	0
72824	70709	14257W	PARTICIPANT	\N	PRESENT	0
72829	70709	11056N	PARTICIPANT	\N	PRESENT	0
72830	70709	11098Y	PARTICIPANT	\N	PRESENT	0
72831	70709	11026G	PARTICIPANT	\N	PRESENT	0
72864	72863	11046L	PARTICIPANT	\N	PRESENT	0
72865	72863	14038Y	PARTICIPANT	\N	PRESENT	0
72866	72863	01037S	PARTICIPANT	\N	PRESENT	0
72868	72867	01008M	PARTICIPANT	\N	PRESENT	0
72869	72867	11036J	PARTICIPANT	\N	PRESENT	0
72870	72867	11081P	PARTICIPANT	\N	EXCUSE	0
72871	72867	14013P	PARTICIPANT	\N	PRESENT	0
72872	72867	08068F	PARTICIPANT	\N	PRESENT	0
72873	72867	14207L	PARTICIPANT	\N	PRESENT	0
72874	72867	11101A	PARTICIPANT	\N	EXCUSE	0
72875	72867	90003B	PARTICIPANT	\N	PRESENT	0
72876	72867	08028W	PARTICIPANT	\N	PRESENT	0
72877	72867	80013X	PARTICIPANT	\N	PRESENT	0
72950	72949	89017R	PARTICIPANT	\N	PRESENT	0
72879	72867	04089T	PARTICIPANT	\N	PRESENT	0
72880	72867	14197C	PARTICIPANT	\N	PRESENT	0
72881	72867	11110B	PARTICIPANT	\N	PRESENT	0
72882	72867	14187A	PARTICIPANT	\N	PRESENT	0
72883	72867	14033T	PARTICIPANT	\N	PRESENT	0
72884	72867	14081Q	PARTICIPANT	\N	EXCUSE	0
72885	72867	04048J	PARTICIPANT	\N	PRESENT	0
72886	72867	11099A	PARTICIPANT	\N	PRESENT	0
72887	72867	04049K	PARTICIPANT	\N	PRESENT	0
72888	72867	04094Q	PARTICIPANT	\N	PRESENT	0
72909	72907	08055A	PARTICIPANT	\N	PRESENT	0
72890	72867	08015R	PARTICIPANT	\N	PRESENT	0
72891	72867	11100Y	PRESIDENT	0	PRESENT	0
72892	72867	01061S	PARTICIPANT	\N	PRESENT	0
72893	72867	11098Y	PARTICIPANT	\N	PRESENT	0
72894	72867	01043Q	PARTICIPANT	\N	PRESENT	0
72895	72867	11077T	PARTICIPANT	\N	PRESENT	0
72896	72867	14205J	PARTICIPANT	\N	PRESENT	0
72897	72867	08019V	PARTICIPANT	\N	PRESENT	0
72898	72867	14257W	PARTICIPANT	\N	PRESENT	0
72899	72867	08021P	PARTICIPANT	\N	PRESENT	0
72900	72867	04088S	PARTICIPANT	\N	PRESENT	0
72951	72949	01031L	PRESIDENT	0	PRESENT	0
72902	72867	11090Q	PARTICIPANT	\N	PRESENT	0
72903	72867	11046L	PARTICIPANT	\N	PRESENT	0
72904	72867	01058X	PARTICIPANT	\N	PRESENT	0
72905	72867	11094U	PARTICIPANT	\N	PRESENT	0
72906	72867	11066Q	PARTICIPANT	\N	PRESENT	0
72952	72949	05004A	PARTICIPANT	\N	PRESENT	0
72911	72907	14030Q	PARTICIPANT	\N	PRESENT	0
72953	72949	01013J	PARTICIPANT	\N	PRESENT	0
72913	72907	08060W	PARTICIPANT	\N	PRESENT	0
72954	72949	11068S	PARTICIPANT	\N	PRESENT	0
72915	72907	14038Y	PARTICIPANT	\N	PRESENT	0
72916	72907	11114F	PARTICIPANT	\N	PRESENT	0
72917	72907	98023Q	PARTICIPANT	\N	PRESENT	0
72918	72907	11065P	PARTICIPANT	\N	PRESENT	0
72955	72949	11040E	PARTICIPANT	\N	PRESENT	0
72920	72907	11107G	PARTICIPANT	\N	PRESENT	0
72956	72949	08014Q	PARTICIPANT	\N	PRESENT	0
72922	72907	02002K	PARTICIPANT	\N	PRESENT	0
72923	72907	01022K	PARTICIPANT	\N	PRESENT	0
72957	72949	14167V	PARTICIPANT	\N	PRESENT	0
72925	72907	09001P	PARTICIPANT	\N	EXCUSE	0
72926	72907	11059R	PARTICIPANT	\N	PRESENT	0
72927	72907	14219Q	PARTICIPANT	\N	PRESENT	0
72928	72907	80027E	PARTICIPANT	\N	PRESENT	0
72929	72907	14031R	PARTICIPANT	\N	PRESENT	0
72930	72907	08009T	PRESIDENT	0	PRESENT	0
72931	72907	08062Y	PARTICIPANT	\N	PRESENT	0
72932	72907	14221J	PARTICIPANT	\N	PRESENT	0
72934	72907	08042U	PARTICIPANT	\N	PRESENT	0
72935	72907	14169X	PARTICIPANT	\N	PRESENT	0
72936	72907	14237S	PARTICIPANT	\N	PRESENT	0
72937	72907	13002U	PARTICIPANT	\N	PRESENT	0
72938	72907	05012A	PARTICIPANT	\N	PRESENT	0
72940	72907	14135M	PARTICIPANT	\N	PRESENT	0
72941	72907	14331P	PARTICIPANT	\N	PRESENT	0
72942	72907	95062K	PARTICIPANT	\N	PRESENT	0
72943	72907	14107H	PARTICIPANT	\N	PRESENT	0
72944	72907	14051J	PARTICIPANT	\N	PRESENT	0
72945	72907	14157T	PARTICIPANT	\N	PRESENT	0
72946	72907	96003C	PARTICIPANT	\N	EXCUSE	0
72959	72949	14083S	PARTICIPANT	\N	PRESENT	0
72961	72949	14085U	PARTICIPANT	\N	PRESENT	0
72962	72949	11042G	PARTICIPANT	\N	PRESENT	0
72963	72949	88008L	PARTICIPANT	\N	PRESENT	0
72964	72949	04086Q	PARTICIPANT	\N	PRESENT	0
72966	72949	11070L	PARTICIPANT	\N	PRESENT	0
72967	72949	11088W	PARTICIPANT	\N	PRESENT	0
72968	72949	14327T	PARTICIPANT	\N	PRESENT	0
72969	72949	08022Q	PARTICIPANT	\N	PRESENT	0
72970	72949	01027Q	PARTICIPANT	\N	PRESENT	0
72971	72949	04071H	PARTICIPANT	\N	PRESENT	0
72972	72949	11074Q	PARTICIPANT	\N	PRESENT	0
72973	72949	98053W	PARTICIPANT	\N	PRESENT	0
72974	72949	11083R	PARTICIPANT	\N	PRESENT	0
72975	72949	14199E	PARTICIPANT	\N	PRESENT	0
72976	72949	01057W	PARTICIPANT	\N	PRESENT	0
72977	72949	08016S	PARTICIPANT	\N	PRESENT	0
72978	72949	08069G	PARTICIPANT	\N	PRESENT	0
72979	72949	11048N	PARTICIPANT	\N	PRESENT	0
72980	72949	99004R	PARTICIPANT	\N	PRESENT	0
72981	72949	04061F	PARTICIPANT	\N	PRESENT	0
72982	72949	14159V	PARTICIPANT	\N	PRESENT	0
72983	72949	07029T	PARTICIPANT	\N	PRESENT	0
72984	72949	14277B	PARTICIPANT	\N	PRESENT	0
72985	72949	08010L	PARTICIPANT	\N	PRESENT	0
72987	72949	01048V	PARTICIPANT	\N	PRESENT	0
72988	72949	98046X	PARTICIPANT	\N	PRESENT	0
72990	72949	08011M	PARTICIPANT	\N	PRESENT	0
72992	72949	08061X	PARTICIPANT	\N	PRESENT	0
72993	72949	01016M	PARTICIPANT	\N	PRESENT	0
72994	72949	14225N	PARTICIPANT	\N	PRESENT	0
72995	72949	11012A	PARTICIPANT	\N	PRESENT	0
65554	65551	11061K	PARTICIPANT	\N	PRESENT	0
65555	65551	11093T	PARTICIPANT	\N	PRESENT	0
65566	65565	11061K	PARTICIPANT	\N	PRESENT	0
65567	65565	11093T	PARTICIPANT	\N	PRESENT	0
65608	65607	08025T	PARTICIPANT	\N	PRESENT	0
65609	65607	04085P	PARTICIPANT	\N	PRESENT	0
65610	65607	05008E	PRESIDENT	0	PRESENT	0
65611	65607	11030C	PARTICIPANT	\N	PRESENT	0
65612	65607	11033F	PARTICIPANT	\N	PRESENT	0
65613	65607	14065Q	PARTICIPANT	\N	PRESENT	0
65614	65607	14069U	PARTICIPANT	\N	PRESENT	0
65615	65607	04047H	PARTICIPANT	\N	PRESENT	0
65616	65607	11032E	PARTICIPANT	\N	PRESENT	0
65617	65607	04038G	PARTICIPANT	\N	PRESENT	0
65618	65607	11056N	PARTICIPANT	\N	PRESENT	0
65619	65607	14259Y	PARTICIPANT	\N	PRESENT	0
65620	65607	01024M	PARTICIPANT	\N	PRESENT	0
65622	65607	11034G	PARTICIPANT	\N	PRESENT	0
65623	65607	08018U	PARTICIPANT	\N	PRESENT	0
65624	65607	01007L	PARTICIPANT	\N	PRESENT	0
65625	65607	11049P	PARTICIPANT	\N	PRESENT	0
65626	65607	08044W	PARTICIPANT	\N	PRESENT	0
65627	65607	11084S	PARTICIPANT	\N	PRESENT	0
65628	65607	11026G	PARTICIPANT	\N	PRESENT	0
65631	65607	04079R	PARTICIPANT	\N	PRESENT	0
65632	65607	14001X	PARTICIPANT	\N	PRESENT	0
65633	65607	07034Q	PARTICIPANT	\N	PRESENT	0
65634	65607	04074L	PARTICIPANT	\N	PRESENT	0
65635	65607	10015M	PARTICIPANT	\N	PRESENT	0
65636	65607	95063L	PARTICIPANT	\N	PRESENT	0
65637	65607	01028R	PARTICIPANT	\N	PRESENT	0
65638	65607	98035U	PARTICIPANT	\N	PRESENT	0
65639	65607	04044E	PARTICIPANT	\N	PRESENT	0
65641	65607	11037K	PARTICIPANT	\N	PRESENT	0
65642	65607	01047U	PARTICIPANT	\N	PRESENT	0
65644	65607	14111D	PARTICIPANT	\N	PRESENT	0
65645	65607	14273W	PARTICIPANT	\N	PRESENT	0
65646	65607	01060R	PARTICIPANT	\N	PRESENT	0
65647	65607	14147R	PARTICIPANT	\N	PRESENT	0
65648	65607	01019Q	PARTICIPANT	\N	PRESENT	0
65649	65607	04056J	PARTICIPANT	\N	PRESENT	0
65650	65607	92045V	PARTICIPANT	\N	PRESENT	0
65653	65652	08025T	PARTICIPANT	\N	PRESENT	0
65654	65652	04085P	PARTICIPANT	\N	PRESENT	0
65655	65652	05008E	PRESIDENT	0	PRESENT	0
65656	65652	11030C	PARTICIPANT	\N	PRESENT	0
65657	65652	11033F	PARTICIPANT	\N	PRESENT	0
65658	65652	14069U	PARTICIPANT	\N	PRESENT	0
65659	65652	04047H	PARTICIPANT	\N	PRESENT	0
65660	65652	04038G	PARTICIPANT	\N	PRESENT	0
65661	65652	11056N	PARTICIPANT	\N	PRESENT	0
65662	65652	14259Y	PARTICIPANT	\N	PRESENT	0
65663	65652	01024M	PARTICIPANT	\N	PRESENT	0
65664	65652	11034G	PARTICIPANT	\N	PRESENT	0
65665	65652	08018U	PARTICIPANT	\N	PRESENT	0
65666	65652	01007L	PARTICIPANT	\N	PRESENT	0
65667	65652	11049P	PARTICIPANT	\N	PRESENT	0
65668	65652	08044W	PARTICIPANT	\N	PRESENT	0
65669	65652	11084S	PARTICIPANT	\N	PRESENT	0
65670	65652	11026G	PARTICIPANT	\N	PRESENT	0
65671	65652	14001X	PARTICIPANT	\N	PRESENT	0
65672	65652	14273W	PARTICIPANT	\N	PRESENT	0
65673	65652	14147R	PARTICIPANT	\N	PRESENT	0
65674	65652	95049N	PARTICIPANT	\N	PRESENT	0
65675	65652	08051V	PARTICIPANT	\N	PRESENT	0
65677	65652	04074L	PARTICIPANT	\N	PRESENT	0
65678	65652	10015M	PARTICIPANT	\N	PRESENT	0
65680	65652	95063L	PARTICIPANT	\N	PRESENT	0
65681	65652	01028R	PARTICIPANT	\N	PRESENT	0
65682	65652	98035U	PARTICIPANT	\N	PRESENT	0
65683	65652	04056J	PARTICIPANT	\N	PRESENT	0
65685	65652	04044E	PRESIDENT	1	PRESENT	0
65686	65652	11037K	PARTICIPANT	\N	PRESENT	0
65687	65652	92045V	PARTICIPANT	\N	PRESENT	0
65699	65607	08051V	PARTICIPANT	\N	PRESENT	0
65700	65607	95049N	PARTICIPANT	\N	PRESENT	0
72806	72805	11076S	PARTICIPANT	\N	PRESENT	0
72807	72805	04066L	PARTICIPANT	\N	PRESENT	0
72808	72805	08035V	PARTICIPANT	\N	PRESENT	0
72809	72805	11105E	PARTICIPANT	\N	PRESENT	0
72810	72805	11106F	PARTICIPANT	\N	PRESENT	0
72826	72825	11039M	PARTICIPANT	\N	PRESENT	0
72827	72825	98042T	PARTICIPANT	\N	PRESENT	0
72828	72825	01019Q	PARTICIPANT	\N	PRESENT	0
72833	72832	14133K	PARTICIPANT	\N	PRESENT	0
72834	72832	11040E	PARTICIPANT	\N	PRESENT	0
72835	72832	04038G	PARTICIPANT	\N	PRESENT	0
72836	72832	95030B	PARTICIPANT	\N	PRESENT	0
72837	72832	01057W	PARTICIPANT	\N	PRESENT	0
72838	72832	14179A	PARTICIPANT	\N	PRESENT	0
72839	72832	14097Y	PARTICIPANT	\N	PRESENT	0
72840	72832	11026G	PARTICIPANT	\N	PRESENT	0
72841	72832	08034U	PARTICIPANT	\N	PRESENT	0
72842	72832	01048V	PARTICIPANT	\N	PRESENT	0
72843	72832	98021N	PARTICIPANT	\N	PRESENT	0
72844	72832	04080J	PARTICIPANT	\N	PRESENT	0
72845	72832	04044E	PARTICIPANT	\N	PRESENT	0
72846	72832	95062K	PARTICIPANT	\N	PRESENT	0
72948	72947	08018U	PARTICIPANT	\N	PRESENT	0
73569	73568	14033T	PARTICIPANT	\N	PRESENT	0
73571	73570	14033T	PARTICIPANT	\N	PRESENT	0
73573	73572	14237S	PARTICIPANT	\N	PRESENT	0
73575	73574	01058X	PARTICIPANT	\N	PRESENT	0
73577	73576	01058X	PARTICIPANT	\N	PRESENT	0
73580	73579	01058X	PARTICIPANT	\N	PRESENT	0
73582	73581	11036J	PARTICIPANT	\N	PRESENT	0
73629	73628	08042U	PARTICIPANT	\N	PRESENT	0
73630	73628	11107G	PARTICIPANT	\N	PRESENT	0
73585	73581	14013P	PARTICIPANT	\N	PRESENT	0
73586	73581	14083S	PARTICIPANT	\N	PRESENT	0
73631	73628	14030Q	PARTICIPANT	\N	PRESENT	0
73633	73632	08055A	PARTICIPANT	\N	PRESENT	0
73647	73632	14031R	PARTICIPANT	\N	PRESENT	0
73590	73581	14079W	PARTICIPANT	\N	PRESENT	0
73635	73632	08060W	PARTICIPANT	\N	PRESENT	0
73636	73632	11065P	PARTICIPANT	\N	PRESENT	0
73637	73632	11107G	PARTICIPANT	\N	PRESENT	0
73594	73581	01024M	PARTICIPANT	\N	PRESENT	0
73638	73632	14219Q	PARTICIPANT	\N	PRESENT	0
73596	73581	01003G	PARTICIPANT	\N	PRESENT	0
73639	73632	08009T	PARTICIPANT	\N	PRESENT	0
73640	73632	08062Y	PARTICIPANT	\N	PRESENT	0
73641	73632	14169X	PARTICIPANT	\N	PRESENT	0
73642	73632	05012A	PARTICIPANT	\N	PRESENT	0
73643	73632	14107H	PARTICIPANT	\N	PRESENT	0
73644	73632	14051J	PARTICIPANT	\N	PRESENT	0
73645	73632	14093U	PARTICIPANT	\N	PRESENT	0
73604	73581	08069G	PARTICIPANT	\N	PRESENT	0
73605	73581	04097T	PARTICIPANT	\N	PRESENT	0
73646	73632	14135M	PARTICIPANT	\N	PRESENT	0
73648	73632	14157T	PARTICIPANT	\N	PRESENT	0
77612	77611	01014K	PARTICIPANT	\N	PRESENT	0
77614	77613	01014K	PARTICIPANT	\N	PRESENT	0
73610	73581	11100Y	PARTICIPANT	\N	PRESENT	0
77615	77613	07024N	PARTICIPANT	\N	PRESENT	0
81032	80434	83042R	PARTICIPANT	\N	PRESENT	0
81033	80434	14121F	PARTICIPANT	\N	PRESENT	0
73614	73581	14237S	PARTICIPANT	\N	PRESENT	0
73615	73581	04088S	PARTICIPANT	\N	PRESENT	0
81034	80434	01028R	PARTICIPANT	\N	PRESENT	0
81035	80434	11104D	PARTICIPANT	\N	PRESENT	0
81036	80434	14014Q	PARTICIPANT	\N	PRESENT	0
81037	80434	11012A	PARTICIPANT	\N	PRESENT	0
73620	73581	11012A	PARTICIPANT	\N	PRESENT	0
81038	80434	88008L	PARTICIPANT	\N	PRESENT	0
81039	80434	11089X	PARTICIPANT	\N	PRESENT	0
81040	80434	14241N	PARTICIPANT	\N	PRESENT	0
81041	80434	08031R	PARTICIPANT	\N	PRESENT	0
73625	73581	11066Q	PARTICIPANT	\N	PRESENT	0
73626	73581	95067Q	PARTICIPANT	\N	PRESENT	0
81042	80434	14028W	PARTICIPANT	\N	PRESENT	0
81043	80434	08049C	PARTICIPANT	\N	PRESENT	0
81044	80434	14197C	PARTICIPANT	\N	PRESENT	0
81045	80434	01044R	PARTICIPANT	\N	PRESENT	0
81046	80434	14281W	PARTICIPANT	\N	PRESENT	0
81047	80434	08068F	PARTICIPANT	\N	PRESENT	0
81048	80434	11106F	PARTICIPANT	\N	PRESENT	0
81049	80434	01003G	PARTICIPANT	\N	PRESENT	0
81050	80434	92015P	PARTICIPANT	\N	PRESENT	0
81051	80434	11023D	PARTICIPANT	\N	PRESENT	0
81052	80434	01034P	PARTICIPANT	\N	PRESENT	0
81053	80434	11083R	PARTICIPANT	\N	PRESENT	0
81054	80434	11072N	PARTICIPANT	\N	PRESENT	0
81055	80434	14109K	PARTICIPANT	\N	PRESENT	0
81056	80434	11100Y	PARTICIPANT	\N	PRESENT	0
81057	80434	14239U	PARTICIPANT	\N	PRESENT	0
81225	80434	04070G	PARTICIPANT	\N	PRESENT	0
81226	80434	08043V	PARTICIPANT	\N	PRESENT	0
81227	80434	11061K	PARTICIPANT	\N	PRESENT	0
81228	80434	07032N	PARTICIPANT	\N	PRESENT	0
81229	80434	11015D	PARTICIPANT	\N	PRESENT	0
81230	80434	08056B	PARTICIPANT	\N	PRESENT	0
81231	80434	11042G	PARTICIPANT	\N	PRESENT	0
81232	80434	14327T	PARTICIPANT	\N	PRESENT	0
81233	80434	89017R	PARTICIPANT	\N	PRESENT	0
81234	80434	98021N	PARTICIPANT	\N	PRESENT	0
81535	78329	92018S	PARTICIPANT	\N	PRESENT	0
81536	78329	14263U	PARTICIPANT	\N	PRESENT	0
81537	78329	01015L	PARTICIPANT	\N	PRESENT	0
81538	78329	01013J	PARTICIPANT	\N	PRESENT	0
81539	78329	07026Q	PARTICIPANT	\N	PRESENT	0
81540	78329	04054G	PARTICIPANT	\N	PRESENT	0
81541	78329	14235Q	PARTICIPANT	\N	PRESENT	0
81542	78329	11098Y	PARTICIPANT	\N	PRESENT	0
81543	78329	14013P	PARTICIPANT	\N	PRESENT	0
81544	78329	11031D	PARTICIPANT	\N	PRESENT	0
81545	78329	11056N	PARTICIPANT	\N	PRESENT	0
81546	78329	11039M	PARTICIPANT	\N	PRESENT	0
81547	78329	98035U	PARTICIPANT	\N	PRESENT	0
81548	78329	14065Q	PARTICIPANT	\N	PRESENT	0
81549	78329	92015P	PARTICIPANT	\N	PRESENT	0
81550	78329	08052W	PARTICIPANT	\N	PRESENT	0
81551	78329	08025T	PARTICIPANT	\N	PRESENT	0
81552	78329	14051J	PARTICIPANT	\N	PRESENT	0
81553	78329	08055A	PARTICIPANT	\N	PRESENT	0
81554	78329	14107H	PARTICIPANT	\N	PRESENT	0
81555	78329	11027H	PARTICIPANT	\N	PRESENT	0
81556	78329	01011G	PARTICIPANT	\N	PRESENT	0
81557	78329	14197C	PARTICIPANT	\N	PRESENT	0
81558	78329	01022K	PARTICIPANT	\N	PRESENT	0
81559	78329	14028W	PARTICIPANT	\N	PRESENT	0
81560	78329	00003C	PARTICIPANT	\N	PRESENT	0
81561	78329	80013X	PARTICIPANT	\N	PRESENT	0
81562	78329	11036J	PARTICIPANT	\N	PRESENT	0
81563	78329	08043V	PARTICIPANT	\N	PRESENT	0
81564	78329	08068F	PARTICIPANT	\N	PRESENT	0
81565	78329	11034G	PARTICIPANT	\N	PRESENT	0
81566	78329	11105E	PARTICIPANT	\N	PRESENT	0
81567	78329	08012N	PARTICIPANT	\N	PRESENT	0
81568	78329	80027E	PARTICIPANT	\N	PRESENT	0
81569	78329	14271U	PARTICIPANT	\N	PRESENT	0
81570	78329	08058D	PARTICIPANT	\N	PRESENT	0
81571	78329	04034C	PARTICIPANT	\N	PRESENT	0
81572	78329	08017T	PARTICIPANT	\N	PRESENT	0
81573	78329	08053X	PARTICIPANT	\N	PRESENT	0
81574	78329	83042R	PARTICIPANT	\N	PRESENT	0
81575	78329	99002P	PARTICIPANT	\N	PRESENT	0
81576	78329	98029W	PARTICIPANT	\N	PRESENT	0
81577	78329	14207L	PARTICIPANT	\N	PRESENT	0
81578	78329	11095V	PARTICIPANT	\N	PRESENT	0
81579	78329	08014Q	PARTICIPANT	\N	PRESENT	0
81580	78329	11057P	PARTICIPANT	\N	PRESENT	0
81581	78329	14001X	PARTICIPANT	\N	PRESENT	0
81582	78329	14227Q	PARTICIPANT	\N	PRESENT	0
81583	78329	11054L	PARTICIPANT	\N	PRESENT	0
81584	78329	04079R	PARTICIPANT	\N	PRESENT	0
81585	78329	14281W	PARTICIPANT	\N	PRESENT	0
81586	78329	14229S	PARTICIPANT	\N	PRESENT	0
81587	78329	14121F	PARTICIPANT	\N	PRESENT	0
81588	78329	01031L	PARTICIPANT	\N	PRESENT	0
81589	78329	14133K	PARTICIPANT	\N	PRESENT	0
81590	78329	11112D	PARTICIPANT	\N	PRESENT	0
81591	78329	04036E	PARTICIPANT	\N	PRESENT	0
81592	78329	14257W	PARTICIPANT	\N	PRESENT	0
81593	78329	01027Q	PARTICIPANT	\N	PRESENT	0
81594	78329	11026G	PARTICIPANT	\N	PRESENT	0
81595	78329	04035D	PARTICIPANT	\N	PRESENT	0
81596	78329	83047W	PARTICIPANT	\N	PRESENT	0
81597	78329	98046X	PARTICIPANT	\N	PRESENT	0
81598	78329	95031C	PARTICIPANT	\N	PRESENT	0
81599	78329	04077P	PARTICIPANT	\N	PRESENT	0
81600	78329	08061X	PARTICIPANT	\N	PRESENT	0
81601	78329	95062K	PARTICIPANT	\N	PRESENT	0
81602	78329	04045F	PARTICIPANT	\N	PRESENT	0
81603	78329	01028R	PARTICIPANT	\N	PRESENT	0
81604	78329	99004R	PARTICIPANT	\N	PRESENT	0
81605	78329	02002K	PARTICIPANT	\N	PRESENT	0
81606	78329	04097T	PARTICIPANT	\N	PRESENT	0
81607	78329	08039A	PARTICIPANT	\N	PRESENT	0
81608	78329	04053F	PARTICIPANT	\N	PRESENT	0
81609	78329	14211G	PARTICIPANT	\N	PRESENT	0
81610	78329	11104D	PARTICIPANT	\N	PRESENT	0
81611	78329	08024S	PARTICIPANT	\N	PRESENT	0
81612	78329	95041E	PARTICIPANT	\N	PRESENT	0
81613	78329	11106F	PARTICIPANT	\N	PRESENT	0
81614	78329	14085U	PARTICIPANT	\N	PRESENT	0
81615	78329	04059M	PARTICIPANT	\N	PRESENT	0
81616	78329	11066Q	PARTICIPANT	\N	PRESENT	0
81617	78329	08022Q	PARTICIPANT	\N	PRESENT	0
81618	78329	92020L	PARTICIPANT	\N	PRESENT	0
81619	78329	11067R	PARTICIPANT	\N	PRESENT	0
81620	78329	12041X	PARTICIPANT	\N	PRESENT	0
81621	78329	08028W	PARTICIPANT	\N	PRESENT	0
81622	78329	11042G	PARTICIPANT	\N	PRESENT	0
81623	78329	08015R	PARTICIPANT	\N	PRESENT	0
81624	78329	11077T	PARTICIPANT	\N	PRESENT	0
81625	78329	01019Q	PARTICIPANT	\N	PRESENT	0
81626	78329	14097Y	PARTICIPANT	\N	PRESENT	0
81627	78329	11074Q	PARTICIPANT	\N	PRESENT	0
81628	78329	04081K	PARTICIPANT	\N	PRESENT	0
81629	78329	14159V	PARTICIPANT	\N	PRESENT	0
81630	78329	14269B	PARTICIPANT	\N	PRESENT	0
81631	78329	11023D	PARTICIPANT	\N	PRESENT	0
81632	78329	11113E	PARTICIPANT	\N	PRESENT	0
81633	78329	11109J	PARTICIPANT	\N	PRESENT	0
81634	78329	04033B	PARTICIPANT	\N	PRESENT	0
81635	78329	08073C	PARTICIPANT	\N	PRESENT	0
81636	78329	01014K	PARTICIPANT	\N	PRESENT	0
81637	78329	11107G	PARTICIPANT	\N	PRESENT	0
81638	78329	14253S	PARTICIPANT	\N	PRESENT	0
81639	78329	12042Y	PARTICIPANT	\N	PRESENT	0
81640	78329	14169X	PARTICIPANT	\N	PRESENT	0
81641	78329	11037K	PARTICIPANT	\N	PRESENT	0
81642	78329	95067Q	PARTICIPANT	\N	PRESENT	0
81643	78329	11029K	PARTICIPANT	\N	PRESENT	0
81644	78329	11033F	PARTICIPANT	\N	PRESENT	0
81645	78329	01044R	PARTICIPANT	\N	PRESENT	0
81646	78329	87003B	PARTICIPANT	\N	PRESENT	0
81647	78329	11099A	PARTICIPANT	\N	PRESENT	0
81648	78329	11055M	PARTICIPANT	\N	PRESENT	0
81649	78329	08041T	PARTICIPANT	\N	PRESENT	0
81650	78329	05012A	PARTICIPANT	\N	PRESENT	0
81651	78329	13002U	PARTICIPANT	\N	PRESENT	0
81652	78329	04044E	PARTICIPANT	\N	PRESENT	0
81653	78329	11103C	PARTICIPANT	\N	PRESENT	0
81654	78329	14191V	PARTICIPANT	\N	PRESENT	0
81655	78329	08051V	PARTICIPANT	\N	PRESENT	0
81656	78329	11012A	PARTICIPANT	\N	PRESENT	0
81657	78329	14123H	PARTICIPANT	\N	PRESENT	0
81658	78329	88008L	PARTICIPANT	\N	PRESENT	0
81659	78329	08049C	PARTICIPANT	\N	PRESENT	0
81660	78329	01057W	PARTICIPANT	\N	PRESENT	0
81661	78329	04038G	PARTICIPANT	\N	PRESENT	0
81662	78329	11096W	PARTICIPANT	\N	PRESENT	0
81663	78329	11081P	PARTICIPANT	\N	PRESENT	0
81664	78329	01003G	PARTICIPANT	\N	PRESENT	0
81665	78329	08010L	PARTICIPANT	\N	PRESENT	0
81666	78329	08031R	PARTICIPANT	\N	PRESENT	0
81667	78329	14239U	PARTICIPANT	\N	PRESENT	0
81668	78329	14241N	PARTICIPANT	\N	PRESENT	0
81669	78329	14111D	PARTICIPANT	\N	PRESENT	0
81670	78329	98022P	PARTICIPANT	\N	PRESENT	0
81671	78329	08021P	PARTICIPANT	\N	PRESENT	0
81672	78329	11011M	PARTICIPANT	\N	PRESENT	0
81673	78329	95049N	PARTICIPANT	\N	PRESENT	0
81674	78329	04040A	PARTICIPANT	\N	PRESENT	0
81675	78329	11094U	PARTICIPANT	\N	PRESENT	0
81676	78329	01034P	PARTICIPANT	\N	PRESENT	0
81677	78329	11053K	PARTICIPANT	\N	PRESENT	0
81678	78329	14034U	PARTICIPANT	\N	PRESENT	0
81679	78329	04080J	PARTICIPANT	\N	PRESENT	0
81680	78329	04047H	PARTICIPANT	\N	PRESENT	0
81681	78329	01043Q	PARTICIPANT	\N	PRESENT	0
81682	78329	11083R	PARTICIPANT	\N	PRESENT	0
81683	78329	14026U	PARTICIPANT	\N	PRESENT	0
81684	78329	95063L	PARTICIPANT	\N	PRESENT	0
81685	78329	14205J	PARTICIPANT	\N	PRESENT	0
81686	78329	14071N	PARTICIPANT	\N	PRESENT	0
81687	78329	98042T	PARTICIPANT	\N	PRESENT	0
81688	78329	95059Q	PARTICIPANT	\N	PRESENT	0
81689	78329	14103D	PARTICIPANT	\N	PRESENT	0
81690	78329	14219Q	PARTICIPANT	\N	PRESENT	0
81691	78329	14223L	PARTICIPANT	\N	PRESENT	0
69339	69338	07024N	PARTICIPANT	\N	PRESENT	0
69340	69338	98021N	PARTICIPANT	\N	PRESENT	0
69342	69341	07024N	PARTICIPANT	\N	PRESENT	0
69343	69341	98021N	PARTICIPANT	\N	PRESENT	0
69345	69344	14097Y	PARTICIPANT	\N	PRESENT	0
69347	69346	14251Q	PARTICIPANT	\N	PRESENT	0
69348	69346	95037J	PARTICIPANT	\N	PRESENT	0
69349	69346	11076S	PARTICIPANT	\N	PRESENT	0
69351	69350	14251Q	PARTICIPANT	\N	PRESENT	0
69352	69350	95037J	PARTICIPANT	\N	PRESENT	0
69353	69350	11076S	PARTICIPANT	\N	PRESENT	0
71450	71388	01027Q	PARTICIPANT	\N	PRESENT	0
71451	71388	11083R	PARTICIPANT	\N	PRESENT	0
71452	71388	01057W	PARTICIPANT	\N	PRESENT	0
71453	71388	08016S	PARTICIPANT	\N	PRESENT	0
71454	71388	08069G	PARTICIPANT	\N	PRESENT	0
71455	71388	11048N	PARTICIPANT	\N	PRESENT	0
71456	71388	99004R	PARTICIPANT	\N	PRESENT	0
71457	71388	04061F	PARTICIPANT	\N	PRESENT	0
71458	71388	14159V	PARTICIPANT	\N	PRESENT	0
71459	71388	07029T	PARTICIPANT	\N	PRESENT	0
71460	71388	08010L	PARTICIPANT	\N	PRESENT	0
71461	71388	08034U	PARTICIPANT	\N	PRESENT	0
71463	71388	01048V	PARTICIPANT	\N	PRESENT	0
71465	71388	98046X	PARTICIPANT	\N	PRESENT	0
71467	71388	08011M	PARTICIPANT	\N	PRESENT	0
71469	71388	08073C	PARTICIPANT	\N	PRESENT	0
71470	71388	08061X	PARTICIPANT	\N	PRESENT	0
71472	71388	01016M	PARTICIPANT	\N	PRESENT	0
71474	71388	14225N	PARTICIPANT	\N	PRESENT	0
71475	71388	11012A	PARTICIPANT	\N	PRESENT	0
71508	71388	14013P	PARTICIPANT	\N	EXCUSE	0
71867	71866	14133K	PARTICIPANT	\N	PRESENT	0
71868	71866	11112D	PARTICIPANT	\N	PRESENT	0
71869	71866	14205J	PARTICIPANT	\N	PRESENT	0
71870	71866	14265W	PARTICIPANT	\N	PRESENT	0
71871	71866	92045V	PARTICIPANT	\N	PRESENT	0
72459	72458	11103C	PRESIDENT	0	PRESENT	0
72460	72458	14053L	PARTICIPANT	\N	PRESENT	0
72461	72458	14223L	PARTICIPANT	\N	PRESENT	0
72462	72458	14071N	PARTICIPANT	\N	PRESENT	0
72463	72458	08052W	PARTICIPANT	\N	PRESENT	0
72464	72458	14119M	PARTICIPANT	\N	PRESENT	0
72473	72458	14231L	PARTICIPANT	\N	PRESENT	0
72471	72458	14042U	PARTICIPANT	\N	PRESENT	0
72472	72458	04092N	PARTICIPANT	\N	PRESENT	0
72592	72458	11112D	PARTICIPANT	\N	PRESENT	0
74120	74116	89017R	PARTICIPANT	\N	PRESENT	0
74122	74116	11039M	PARTICIPANT	\N	PRESENT	0
74123	74116	08055A	PARTICIPANT	\N	PRESENT	0
72601	72458	01059Y	PARTICIPANT	\N	EXCUSE	0
74124	74116	04042C	PARTICIPANT	\N	PRESENT	0
74125	74116	08024S	PARTICIPANT	\N	PRESENT	0
72604	72458	14151M	PARTICIPANT	\N	EXCUSE	0
74126	74116	04081K	PARTICIPANT	\N	PRESENT	0
74127	74116	04067M	PARTICIPANT	\N	PRESENT	0
74128	74116	98042T	PARTICIPANT	\N	PRESENT	0
72608	72458	11093T	PARTICIPANT	\N	EXCUSE	0
74129	74116	11110B	PARTICIPANT	\N	PRESENT	0
72610	72458	01034P	PARTICIPANT	\N	EXCUSE	0
74130	74116	01003G	PARTICIPANT	\N	PRESENT	0
74131	74116	98053W	PARTICIPANT	\N	PRESENT	0
74132	74116	01007L	PARTICIPANT	\N	PRESENT	0
74133	74116	95037J	PARTICIPANT	\N	PRESENT	0
74134	74116	86034E	PARTICIPANT	\N	PRESENT	0
74136	74116	04094Q	PARTICIPANT	\N	PRESENT	0
74137	74116	08039A	PARTICIPANT	\N	PRESENT	0
74138	74116	01043Q	PARTICIPANT	\N	PRESENT	0
74139	74116	04057K	PARTICIPANT	\N	PRESENT	0
74140	74116	92040Q	PARTICIPANT	\N	PRESENT	0
74141	74116	04088S	PARTICIPANT	\N	PRESENT	0
74142	74116	01019Q	PARTICIPANT	\N	PRESENT	0
74156	74155	08022Q	PARTICIPANT	\N	PRESENT	0
74157	74155	99004R	PARTICIPANT	\N	PRESENT	0
74158	74155	08061X	PARTICIPANT	\N	PRESENT	0
74159	74155	01016M	PARTICIPANT	\N	PRESENT	0
74165	74164	11083R	PARTICIPANT	\N	PRESENT	0
74166	74164	04057K	PARTICIPANT	\N	PRESENT	0
74177	74174	04054G	PARTICIPANT	\N	PRESENT	0
74179	74174	96004D	PRESIDENT	0	PRESENT	0
74180	74174	11040E	PARTICIPANT	\N	PRESENT	0
74181	74174	90003B	PARTICIPANT	\N	PRESENT	0
74183	74174	14079W	PARTICIPANT	\N	PRESENT	0
74185	74174	11035H	PARTICIPANT	\N	PRESENT	0
74186	74174	95030B	PARTICIPANT	\N	EXCUSE	0
74187	74174	08018U	PARTICIPANT	\N	PRESENT	0
74188	74174	11083R	PARTICIPANT	\N	EXCUSE	0
74189	74174	95037J	PARTICIPANT	\N	PRESENT	0
74190	74174	14026U	PARTICIPANT	\N	EXCUSE	0
74192	74174	04061F	PARTICIPANT	\N	EXCUSE	0
74193	74174	14073Q	PARTICIPANT	\N	PRESENT	0
74194	74174	98046X	PARTICIPANT	\N	PRESENT	0
74195	74174	14001X	PARTICIPANT	\N	PRESENT	0
74196	74174	04057K	PARTICIPANT	\N	EXCUSE	0
74197	74174	08073C	PARTICIPANT	\N	EXCUSE	0
74198	74174	04080J	PARTICIPANT	\N	PRESENT	0
74199	74174	01016M	PARTICIPANT	\N	PRESENT	0
74200	74174	04045F	PARTICIPANT	\N	PRESENT	0
74201	74174	98035U	PARTICIPANT	\N	PRESENT	0
74202	74174	92045V	PARTICIPANT	\N	PRESENT	0
74203	74174	10015M	PARTICIPANT	\N	EXCUSE	0
74204	74174	14097Y	PARTICIPANT	\N	PRESENT	0
74211	74210	14217N	PARTICIPANT	\N	PRESENT	0
74212	74210	92020L	PARTICIPANT	\N	PRESENT	0
74213	74210	14281W	PRESIDENT	0	PRESENT	0
74214	74210	07004J	PARTICIPANT	\N	PRESENT	0
74215	74210	11049P	PARTICIPANT	\N	PRESENT	0
74216	74210	99004R	PARTICIPANT	\N	PRESENT	0
74217	74210	11082Q	PARTICIPANT	\N	PRESENT	0
74218	74210	14041T	PARTICIPANT	\N	EXCUSE	0
74219	74210	08041T	PARTICIPANT	\N	EXCUSE	0
74220	74210	10015M	PARTICIPANT	\N	EXCUSE	0
74387	74210	14123H	PARTICIPANT	\N	PRESENT	0
75011	75009	14037X	PARTICIPANT	\N	PRESENT	0
77200	71343	08073C	PARTICIPANT	\N	EXCUSE	0
76583	76581	08055A	PARTICIPANT	\N	PRESENT	0
76584	76581	14093U	PARTICIPANT	\N	PRESENT	0
76585	76581	14030Q	PARTICIPANT	\N	PRESENT	0
76586	76581	96004D	PARTICIPANT	\N	PRESENT	0
76587	76581	08060W	PARTICIPANT	\N	PRESENT	0
76588	76581	11095V	PARTICIPANT	\N	PRESENT	0
77202	75073	08073C	PARTICIPANT	\N	EXCUSE	0
76590	76581	11114F	PARTICIPANT	\N	PRESENT	0
76591	76581	98023Q	PARTICIPANT	\N	PRESENT	0
76592	76581	11065P	PARTICIPANT	\N	PRESENT	0
76593	76581	01015L	PARTICIPANT	\N	EXCUSE	0
76594	76581	11107G	PARTICIPANT	\N	PRESENT	0
76595	76581	11020A	PARTICIPANT	\N	PRESENT	0
76596	76581	02002K	PARTICIPANT	\N	PRESENT	0
76597	76581	01022K	PARTICIPANT	\N	PRESENT	0
77212	77211	11068S	PARTICIPANT	\N	PRESENT	0
76599	76581	09001P	PARTICIPANT	\N	PRESENT	0
76600	76581	11059R	PARTICIPANT	\N	PRESENT	0
76601	76581	14219Q	PARTICIPANT	\N	PRESENT	0
76602	76581	80027E	PARTICIPANT	\N	PRESENT	0
76603	76581	14031R	PARTICIPANT	\N	PRESENT	0
76604	76581	08009T	PRESIDENT	0	PRESENT	0
76605	76581	08062Y	PARTICIPANT	\N	EXCUSE	0
76606	76581	14221J	PARTICIPANT	\N	PRESENT	0
76607	76581	92039X	PARTICIPANT	\N	PRESENT	0
76608	76581	08042U	PARTICIPANT	\N	EXCUSE	0
76609	76581	14169X	PARTICIPANT	\N	PRESENT	0
76610	76581	14237S	PARTICIPANT	\N	PRESENT	0
76611	76581	13002U	PARTICIPANT	\N	PRESENT	0
76612	76581	05012A	PARTICIPANT	\N	PRESENT	0
77213	77211	89017R	PARTICIPANT	\N	PRESENT	0
76614	76581	14135M	PARTICIPANT	\N	PRESENT	0
76615	76581	14331P	PARTICIPANT	\N	PRESENT	0
76616	76581	95062K	PARTICIPANT	\N	PRESENT	0
76617	76581	14107H	PARTICIPANT	\N	PRESENT	0
76618	76581	14051J	PARTICIPANT	\N	PRESENT	0
76619	76581	14157T	PARTICIPANT	\N	PRESENT	0
76620	76581	96003C	PARTICIPANT	\N	EXCUSE	0
77215	77214	11068S	PARTICIPANT	\N	PRESENT	0
77224	77223	14133K	PARTICIPANT	\N	PRESENT	0
77227	77223	14089Y	PARTICIPANT	\N	PRESENT	0
77228	77223	98029W	PARTICIPANT	\N	PRESENT	0
77229	77223	14041T	PARTICIPANT	\N	PRESENT	0
77230	77223	14217N	PARTICIPANT	\N	PRESENT	0
77231	77223	92020L	PARTICIPANT	\N	EXCUSE	0
77232	77223	14281W	PRESIDENT	0	PRESENT	0
77233	77223	08041T	PARTICIPANT	\N	PRESENT	0
77234	77223	07004J	PARTICIPANT	\N	PRESENT	0
77235	77223	11049P	PARTICIPANT	\N	PRESENT	0
77236	77223	14123H	PARTICIPANT	\N	PRESENT	0
77237	77223	99004R	PARTICIPANT	\N	PRESENT	0
72996	72949	11057P	PARTICIPANT	\N	PRESENT	0
72997	72949	14173T	PARTICIPANT	\N	PRESENT	0
72998	72949	04034C	PARTICIPANT	\N	PRESENT	0
73152	73151	11076S	PARTICIPANT	\N	PRESENT	0
73313	73310	11076S	PARTICIPANT	\N	PRESENT	0
73154	73151	04040A	PARTICIPANT	\N	PRESENT	0
73155	73151	08058D	PARTICIPANT	\N	PRESENT	0
73156	73151	04042C	PARTICIPANT	\N	PRESENT	0
73157	73151	77002U	PARTICIPANT	\N	PRESENT	0
73158	73151	98029W	PARTICIPANT	\N	PRESENT	0
73159	73151	11080N	PARTICIPANT	\N	PRESENT	0
73160	73151	11027H	PARTICIPANT	\N	PRESENT	0
73161	73151	98018T	PARTICIPANT	\N	EXCUSE	0
73162	73151	92018S	PARTICIPANT	\N	PRESENT	0
73163	73151	92020L	PARTICIPANT	\N	PRESENT	0
73164	73151	95030B	PARTICIPANT	\N	PRESENT	0
73165	73151	11096W	PARTICIPANT	\N	PRESENT	0
73166	73151	95031C	PARTICIPANT	\N	PRESENT	0
73167	73151	97011G	PARTICIPANT	\N	PRESENT	0
73316	73310	04040A	PARTICIPANT	\N	PRESENT	0
73169	73151	04035D	PARTICIPANT	\N	EXCUSE	0
73170	73151	07024N	PARTICIPANT	\N	PRESENT	0
73171	73151	04095R	PARTICIPANT	\N	PRESENT	0
73172	73151	14014Q	PARTICIPANT	\N	PRESENT	0
73173	73151	11015D	PARTICIPANT	\N	PRESENT	0
73174	73151	07004J	PARTICIPANT	\N	PRESENT	0
73175	73151	95035G	PARTICIPANT	\N	EXCUSE	0
73176	73151	08056B	PARTICIPANT	\N	PRESENT	0
73177	73151	14211G	PARTICIPANT	\N	PRESENT	0
73178	73151	98022P	PARTICIPANT	\N	PRESENT	0
73179	73151	11064N	PARTICIPANT	\N	PRESENT	0
73180	73151	95037J	PARTICIPANT	\N	PRESENT	0
73181	73151	04078Q	PARTICIPANT	\N	PRESENT	0
73182	73151	14097Y	PARTICIPANT	\N	PRESENT	0
73183	73151	95041E	PARTICIPANT	\N	PRESENT	0
73184	73151	04036E	PARTICIPANT	\N	PRESENT	0
73185	73151	14039A	PARTICIPANT	\N	PRESENT	0
73186	73151	04077P	PARTICIPANT	\N	PRESENT	0
73317	73310	08058D	PARTICIPANT	\N	PRESENT	0
73188	73151	92031P	PARTICIPANT	\N	PRESENT	0
73189	73151	11106F	PARTICIPANT	\N	PRESENT	0
73190	73151	14251Q	PARTICIPANT	\N	PRESENT	0
73191	73151	83042R	PARTICIPANT	\N	PRESENT	0
73192	73151	08053X	PARTICIPANT	\N	PRESENT	0
73193	73151	11082Q	PARTICIPANT	\N	PRESENT	0
73194	73151	11105E	PARTICIPANT	\N	PRESENT	0
73195	73151	14253S	PARTICIPANT	\N	PRESENT	0
73196	73151	08047A	PARTICIPANT	\N	PRESENT	0
73197	73151	14028W	PARTICIPANT	\N	PRESENT	0
73198	73151	14193X	PARTICIPANT	\N	PRESENT	0
73199	73151	98021N	PARTICIPANT	\N	PRESENT	0
73200	73151	04080J	PARTICIPANT	\N	PRESENT	0
73201	73151	95059Q	PRESIDENT	0	PRESENT	0
73202	73151	86044G	PARTICIPANT	\N	PRESENT	0
73203	73151	01014K	PARTICIPANT	\N	PRESENT	0
73204	73151	11054L	PARTICIPANT	\N	PRESENT	0
73321	73310	04042C	PARTICIPANT	\N	PRESENT	0
73206	73151	92044U	PARTICIPANT	\N	PRESENT	0
73207	73151	08049C	PARTICIPANT	\N	EXCUSE	0
73208	73151	04050C	PARTICIPANT	\N	PRESENT	0
73322	73310	77002U	PARTICIPANT	\N	PRESENT	0
73323	73310	98029W	PARTICIPANT	\N	PRESENT	0
73326	73310	11080N	PARTICIPANT	\N	PRESENT	0
73327	73310	11027H	PARTICIPANT	\N	PRESENT	0
73329	73310	98018T	PARTICIPANT	\N	EXCUSE	0
73330	73310	92018S	PARTICIPANT	\N	PRESENT	0
73332	73310	92020L	PARTICIPANT	\N	PRESENT	0
73334	73310	95030B	PARTICIPANT	\N	PRESENT	0
73336	73310	11096W	PARTICIPANT	\N	PRESENT	0
73338	73310	95031C	PARTICIPANT	\N	PRESENT	0
73340	73310	97011G	PARTICIPANT	\N	PRESENT	0
73343	73310	04035D	PARTICIPANT	\N	EXCUSE	0
73344	73310	07024N	PARTICIPANT	\N	PRESENT	0
73345	73310	04095R	PARTICIPANT	\N	PRESENT	0
73358	73310	14014Q	PARTICIPANT	\N	PRESENT	0
73359	73310	11015D	PARTICIPANT	\N	PRESENT	0
73363	73310	07004J	PARTICIPANT	\N	PRESENT	0
73365	73310	95035G	PARTICIPANT	\N	EXCUSE	0
73367	73310	08056B	PARTICIPANT	\N	PRESENT	0
73370	73310	98022P	PARTICIPANT	\N	PRESENT	0
73374	73310	11064N	PARTICIPANT	\N	PRESENT	0
73376	73310	95037J	PARTICIPANT	\N	PRESENT	0
73378	73310	04078Q	PARTICIPANT	\N	PRESENT	0
73379	73310	14097Y	PARTICIPANT	\N	PRESENT	0
73382	73310	04036E	PARTICIPANT	\N	PRESENT	0
73385	73310	04077P	PARTICIPANT	\N	PRESENT	0
73391	73310	11106F	PARTICIPANT	\N	PRESENT	0
73394	73310	14251Q	PARTICIPANT	\N	PRESENT	0
73398	73310	08053X	PARTICIPANT	\N	PRESENT	0
73400	73310	11082Q	PARTICIPANT	\N	PRESENT	0
73401	73310	11105E	PARTICIPANT	\N	PRESENT	0
73403	73310	14253S	PARTICIPANT	\N	PRESENT	0
73404	73310	08047A	PARTICIPANT	\N	PRESENT	0
73406	73310	14028W	PARTICIPANT	\N	PRESENT	0
73409	73310	98021N	PARTICIPANT	\N	PRESENT	0
73410	73310	04080J	PARTICIPANT	\N	PRESENT	0
73411	73310	95059Q	PRESIDENT	0	PRESENT	0
73413	73310	86044G	PARTICIPANT	\N	PRESENT	0
73415	73310	01014K	PARTICIPANT	\N	PRESENT	0
73417	73310	11054L	PARTICIPANT	\N	PRESENT	0
73419	73310	92044U	PARTICIPANT	\N	PRESENT	0
73421	73310	04050C	PARTICIPANT	\N	PRESENT	0
73448	73310	08049C	PARTICIPANT	\N	EXCUSE	0
81693	78329	14030Q	PARTICIPANT	\N	PRESENT	0
81694	78329	14221J	PARTICIPANT	\N	PRESENT	0
81695	78329	14119M	PARTICIPANT	\N	PRESENT	0
81696	78329	04056J	PARTICIPANT	\N	PRESENT	0
81697	78329	04086Q	PARTICIPANT	\N	PRESENT	0
81698	78329	11082Q	PARTICIPANT	\N	PRESENT	0
81699	78329	10006L	PARTICIPANT	\N	PRESENT	0
81700	78329	11111C	PARTICIPANT	\N	PRESENT	0
81701	78329	07034Q	PARTICIPANT	\N	PRESENT	0
81702	78329	14042U	PARTICIPANT	\N	PRESENT	0
81703	78329	14231L	PARTICIPANT	\N	PRESENT	0
81704	78329	07004J	PARTICIPANT	\N	PRESENT	0
81705	78329	04092N	PARTICIPANT	\N	PRESENT	0
81706	78329	04089T	PARTICIPANT	\N	PRESENT	0
81707	78329	11085T	PARTICIPANT	\N	PRESENT	0
81708	78329	08044W	PARTICIPANT	\N	PRESENT	0
81709	78329	09001P	PARTICIPANT	\N	PRESENT	0
81710	78329	08011M	PARTICIPANT	\N	PRESENT	0
81711	78329	01047U	PARTICIPANT	\N	PRESENT	0
81712	78329	01025N	PARTICIPANT	\N	PRESENT	0
81713	78329	08056B	PARTICIPANT	\N	PRESENT	0
81714	78329	01007L	PARTICIPANT	\N	PRESENT	0
81715	78329	14018U	PARTICIPANT	\N	PRESENT	0
81716	78329	14327T	PARTICIPANT	\N	PRESENT	0
81717	78329	14215L	PARTICIPANT	\N	PRESENT	0
81718	78329	14331P	PARTICIPANT	\N	PRESENT	0
81719	78329	14014Q	PARTICIPANT	\N	PRESENT	0
81720	78329	11048N	PARTICIPANT	\N	PRESENT	0
81721	78329	11064N	PARTICIPANT	\N	PRESENT	0
81722	78329	14031R	PARTICIPANT	\N	PRESENT	0
81723	78329	14089Y	PARTICIPANT	\N	PRESENT	0
81725	78329	11101A	PARTICIPANT	\N	PRESENT	0
81726	78329	11072N	PARTICIPANT	\N	PRESENT	0
81727	78329	92044U	PARTICIPANT	\N	PRESENT	0
81728	78329	89017R	PARTICIPANT	\N	PRESENT	0
81730	78329	92031P	PARTICIPANT	\N	PRESENT	0
81731	78329	14247U	PARTICIPANT	\N	PRESENT	0
81732	78329	08034U	PARTICIPANT	\N	PRESENT	0
81733	78329	98005N	PARTICIPANT	\N	PRESENT	0
81734	78329	14135M	PARTICIPANT	\N	PRESENT	0
81735	78329	14109K	PARTICIPANT	\N	PRESENT	0
81737	78329	11063M	PARTICIPANT	\N	PRESENT	0
81738	78329	01059Y	PARTICIPANT	\N	PRESENT	0
81739	78329	14187A	PARTICIPANT	\N	PRESENT	0
81741	78329	92040Q	PARTICIPANT	\N	PRESENT	0
81742	78329	98024R	PARTICIPANT	\N	PRESENT	0
81743	78329	08069G	PARTICIPANT	\N	PRESENT	0
81744	78329	11015D	PARTICIPANT	\N	PRESENT	0
81745	78329	98021N	PARTICIPANT	\N	PRESENT	0
81746	78329	14209N	PARTICIPANT	\N	PRESENT	0
81747	78329	14147R	PARTICIPANT	\N	PRESENT	0
81748	78329	04043D	PARTICIPANT	\N	PRESENT	0
81749	78329	11061K	PARTICIPANT	\N	PRESENT	0
81750	78329	11089X	PARTICIPANT	\N	PRESENT	0
81751	78329	14059S	PARTICIPANT	\N	PRESENT	0
81752	78329	04085P	PARTICIPANT	\N	PRESENT	0
81753	78329	14329V	PARTICIPANT	\N	PRESENT	0
81754	78329	14017T	PARTICIPANT	\N	PRESENT	0
81755	78329	11014C	PARTICIPANT	\N	PRESENT	0
81756	78329	04074L	PARTICIPANT	\N	PRESENT	0
81757	78329	08019V	PARTICIPANT	\N	PRESENT	0
81758	78329	07029T	PARTICIPANT	\N	PRESENT	0
81759	78329	14173T	PARTICIPANT	\N	PRESENT	0
81760	78329	14093U	PARTICIPANT	\N	PRESENT	0
81761	78329	14175V	PARTICIPANT	\N	PRESENT	0
81762	78329	14033T	PARTICIPANT	\N	PRESENT	0
69434	69433	14042U	PARTICIPANT	\N	PRESENT	0
69435	69433	11083R	PARTICIPANT	\N	PRESENT	0
69436	69433	98046X	PARTICIPANT	\N	PRESENT	0
69438	69437	14042U	PARTICIPANT	\N	PRESENT	0
69439	69437	11083R	PARTICIPANT	\N	PRESENT	0
69440	69437	98046X	PARTICIPANT	\N	PRESENT	0
69442	69441	04057K	PARTICIPANT	\N	PRESENT	0
71477	70419	14133K	PARTICIPANT	\N	PRESENT	0
73000	72999	89017R	PARTICIPANT	\N	PRESENT	0
73001	72999	01031L	PRESIDENT	0	PRESENT	0
71480	70419	14089Y	PARTICIPANT	\N	PRESENT	0
73049	72999	01046T	PARTICIPANT	\N	PRESENT	0
73003	72999	01013J	PARTICIPANT	\N	PRESENT	0
71483	70419	14217N	PARTICIPANT	\N	PRESENT	0
71484	70419	92020L	PARTICIPANT	\N	EXCUSE	0
71485	70419	14281W	PRESIDENT	0	PRESENT	0
71486	70419	08041T	PARTICIPANT	\N	PRESENT	0
71487	70419	07004J	PARTICIPANT	\N	PRESENT	0
71488	70419	11049P	PARTICIPANT	\N	PRESENT	0
71489	70419	14123H	PARTICIPANT	\N	PRESENT	0
71490	70419	99004R	PARTICIPANT	\N	PRESENT	0
73004	72999	11068S	PARTICIPANT	\N	PRESENT	0
73005	72999	11040E	PARTICIPANT	\N	PRESENT	0
71493	70419	11082Q	PARTICIPANT	\N	PRESENT	0
73006	72999	08014Q	PARTICIPANT	\N	PRESENT	0
73007	72999	14167V	PARTICIPANT	\N	PRESENT	0
71496	70419	10015M	PARTICIPANT	\N	PRESENT	0
71497	70419	11054L	PARTICIPANT	\N	EXCUSE	0
73050	72999	04053F	PARTICIPANT	\N	PRESENT	0
73009	72999	14083S	PARTICIPANT	\N	PRESENT	0
73010	72999	11053K	PARTICIPANT	\N	PRESENT	0
73011	72999	14085U	PARTICIPANT	\N	PRESENT	0
73012	72999	11042G	PARTICIPANT	\N	PRESENT	0
73013	72999	88008L	PARTICIPANT	\N	PRESENT	0
73014	72999	04086Q	PARTICIPANT	\N	PRESENT	0
73051	72999	14053L	PARTICIPANT	\N	PRESENT	0
73016	72999	11070L	PARTICIPANT	\N	PRESENT	0
73017	72999	11088W	PARTICIPANT	\N	PRESENT	0
73052	72999	11103C	PARTICIPANT	\N	PRESENT	0
73019	72999	08022Q	PARTICIPANT	\N	PRESENT	0
73020	72999	01027Q	PARTICIPANT	\N	PRESENT	0
73053	72999	14195A	PARTICIPANT	\N	PRESENT	0
73022	72999	11074Q	PARTICIPANT	\N	PRESENT	0
73054	72999	14267Y	PARTICIPANT	\N	PRESENT	0
73055	72999	08052W	PARTICIPANT	\N	PRESENT	0
73056	72999	04081K	PARTICIPANT	\N	PRESENT	0
73057	72999	98024R	PARTICIPANT	\N	PRESENT	0
73058	72999	10006L	PARTICIPANT	\N	PRESENT	0
73059	72999	14217N	PARTICIPANT	\N	PRESENT	0
73060	72999	14087W	PARTICIPANT	\N	PRESENT	0
73030	72999	99004R	PARTICIPANT	\N	PRESENT	0
73031	72999	04061F	PARTICIPANT	\N	PRESENT	0
73032	72999	14159V	PARTICIPANT	\N	PRESENT	0
73033	72999	07029T	PARTICIPANT	\N	PRESENT	0
73061	72999	11061K	PARTICIPANT	\N	PRESENT	0
73035	72999	08010L	PARTICIPANT	\N	PRESENT	0
73036	72999	08034U	PARTICIPANT	\N	PRESENT	0
73037	72999	01048V	PARTICIPANT	\N	PRESENT	0
73062	72999	14026U	PARTICIPANT	\N	PRESENT	0
73063	72999	14213J	PARTICIPANT	\N	PRESENT	0
73040	72999	08011M	PARTICIPANT	\N	PRESENT	0
73064	72999	14121F	PARTICIPANT	\N	PRESENT	0
73042	72999	08061X	PARTICIPANT	\N	PRESENT	0
73043	72999	01016M	PARTICIPANT	\N	PRESENT	0
73044	72999	14225N	PARTICIPANT	\N	PRESENT	0
73045	72999	11012A	PARTICIPANT	\N	PRESENT	0
73065	72999	11112D	PARTICIPANT	\N	PRESENT	0
73047	72999	14173T	PARTICIPANT	\N	PRESENT	0
73048	72999	04034C	PARTICIPANT	\N	PRESENT	0
73066	72999	14037X	PARTICIPANT	\N	PRESENT	0
73067	72999	11067R	PARTICIPANT	\N	PRESENT	0
73068	72999	14223L	PARTICIPANT	\N	PRESENT	0
73069	72999	04092N	PARTICIPANT	\N	PRESENT	0
73070	72999	14265W	PARTICIPANT	\N	PRESENT	0
73071	72999	14119M	PARTICIPANT	\N	PRESENT	0
73072	72999	14271U	PARTICIPANT	\N	PRESENT	0
73073	72999	11093T	PARTICIPANT	\N	PRESENT	0
73074	72999	11097X	PARTICIPANT	\N	PRESENT	0
73075	72999	04045F	PARTICIPANT	\N	PRESENT	0
73076	72999	14227Q	PARTICIPANT	\N	PRESENT	0
73077	72999	11063M	PARTICIPANT	\N	PRESENT	0
73650	73649	11015D	PARTICIPANT	\N	PRESENT	0
73651	73649	92031P	PARTICIPANT	\N	PRESENT	0
76764	76581	14038Y	PARTICIPANT	\N	EXCUSE	0
76668	76666	08055A	PARTICIPANT	\N	PRESENT	0
76765	76666	14038Y	PARTICIPANT	\N	EXCUSE	0
76670	76666	14030Q	PARTICIPANT	\N	PRESENT	0
76671	76666	96004D	PARTICIPANT	\N	PRESENT	0
76672	76666	08060W	PARTICIPANT	\N	PRESENT	0
76673	76666	11095V	PARTICIPANT	\N	PRESENT	0
78341	78340	01008M	PARTICIPANT	\N	PRESENT	0
76675	76666	11114F	PARTICIPANT	\N	PRESENT	0
76676	76666	98023Q	PARTICIPANT	\N	PRESENT	0
76677	76666	11065P	PARTICIPANT	\N	PRESENT	0
76678	76666	01015L	PARTICIPANT	\N	EXCUSE	0
76679	76666	11107G	PARTICIPANT	\N	PRESENT	0
78342	78340	11036J	PARTICIPANT	\N	PRESENT	0
76681	76666	02002K	PARTICIPANT	\N	PRESENT	0
76682	76666	01022K	PARTICIPANT	\N	PRESENT	0
78684	78681	14263U	PARTICIPANT	\N	PRESENT	0
76684	76666	09001P	PARTICIPANT	\N	PRESENT	0
76685	76666	11059R	PARTICIPANT	\N	PRESENT	0
76686	76666	14219Q	PARTICIPANT	\N	PRESENT	0
76687	76666	80027E	PARTICIPANT	\N	PRESENT	0
76688	76666	14031R	PARTICIPANT	\N	PRESENT	0
76689	76666	08009T	PRESIDENT	0	PRESENT	0
76690	76666	08062Y	PARTICIPANT	\N	EXCUSE	0
76691	76666	14221J	PARTICIPANT	\N	PRESENT	0
76692	76666	92039X	PARTICIPANT	\N	PRESENT	0
76693	76666	08042U	PARTICIPANT	\N	EXCUSE	0
76694	76666	14169X	PARTICIPANT	\N	PRESENT	0
76695	76666	14237S	PARTICIPANT	\N	PRESENT	0
76696	76666	13002U	PARTICIPANT	\N	PRESENT	0
76697	76666	05012A	PARTICIPANT	\N	PRESENT	0
76698	76666	14247U	PARTICIPANT	\N	PRESENT	0
76699	76666	14135M	PARTICIPANT	\N	PRESENT	0
76700	76666	14331P	PARTICIPANT	\N	PRESENT	0
76701	76666	95062K	PARTICIPANT	\N	PRESENT	0
76702	76666	14107H	PARTICIPANT	\N	PRESENT	0
76703	76666	14051J	PARTICIPANT	\N	PRESENT	0
76704	76666	14157T	PARTICIPANT	\N	PRESENT	0
76705	76666	96003C	PARTICIPANT	\N	EXCUSE	0
78344	78340	14013P	PARTICIPANT	\N	PRESENT	0
78345	78340	08068F	PARTICIPANT	\N	PRESENT	0
78346	78340	14207L	PARTICIPANT	\N	PRESENT	0
78347	78340	11101A	PARTICIPANT	\N	PRESENT	0
78348	78340	90003B	PARTICIPANT	\N	PRESENT	0
78349	78340	08028W	PARTICIPANT	\N	PRESENT	0
78350	78340	80013X	PARTICIPANT	\N	PRESENT	0
78351	78340	08038Y	PARTICIPANT	\N	PRESENT	0
78352	78340	04089T	PARTICIPANT	\N	PRESENT	0
78353	78340	14197C	PARTICIPANT	\N	PRESENT	0
78354	78340	11110B	PARTICIPANT	\N	PRESENT	0
78355	78340	14187A	PARTICIPANT	\N	PRESENT	0
78356	78340	14033T	PARTICIPANT	\N	PRESENT	0
78685	78681	14133K	PARTICIPANT	\N	PRESENT	0
78358	78340	04048J	PARTICIPANT	\N	PRESENT	0
78359	78340	11099A	PARTICIPANT	\N	PRESENT	0
78360	78340	04049K	PARTICIPANT	\N	PRESENT	0
78362	78340	11111C	PARTICIPANT	\N	PRESENT	0
78363	78340	08015R	PARTICIPANT	\N	PRESENT	0
78364	78340	11100Y	PRESIDENT	0	PRESENT	0
78365	78340	01061S	PARTICIPANT	\N	PRESENT	0
78366	78340	11098Y	PARTICIPANT	\N	PRESENT	0
78686	78681	11109J	PARTICIPANT	\N	PRESENT	0
78687	78681	04059M	PARTICIPANT	\N	PRESENT	0
78369	78340	14205J	PARTICIPANT	\N	PRESENT	0
78370	78340	08019V	PARTICIPANT	\N	PRESENT	0
78371	78340	14257W	PARTICIPANT	\N	PRESENT	0
78372	78340	08021P	PARTICIPANT	\N	EXCUSE	0
78373	78340	04088S	PARTICIPANT	\N	PRESENT	0
78375	78340	11090Q	PARTICIPANT	\N	PRESENT	0
78376	78340	11046L	PARTICIPANT	\N	PRESENT	0
78377	78340	01058X	PARTICIPANT	\N	PRESENT	0
78378	78340	11094U	PARTICIPANT	\N	PRESENT	0
78379	78340	11066Q	PARTICIPANT	\N	PRESENT	0
78688	78681	11039M	PARTICIPANT	\N	PRESENT	0
78689	78681	01044R	PARTICIPANT	\N	PRESENT	0
78690	78681	08043V	PARTICIPANT	\N	PRESENT	0
78691	78681	14089Y	PARTICIPANT	\N	PRESENT	0
78692	78681	14105F	PARTICIPANT	\N	PRESENT	0
78693	78681	11029K	PARTICIPANT	\N	PRESENT	0
78694	78681	95015C	PRESIDENT	0	PRESENT	0
78695	78681	92015P	PARTICIPANT	\N	PRESENT	0
78696	78681	08024S	PARTICIPANT	\N	PRESENT	0
78697	78681	14201E	PARTICIPANT	\N	PRESENT	0
78698	78681	14329V	PARTICIPANT	\N	PRESENT	0
78699	78681	14209N	PARTICIPANT	\N	PRESENT	0
78700	78681	14079W	PARTICIPANT	\N	PRESENT	0
81765	78329	11043H	PARTICIPANT	\N	PRESENT	0
81766	78329	11070L	PARTICIPANT	\N	PRESENT	0
81767	78329	14037X	PARTICIPANT	\N	PRESENT	0
81768	78329	14061L	PARTICIPANT	\N	PRESENT	0
81769	78329	01041N	PARTICIPANT	\N	PRESENT	0
81770	78329	11032E	PARTICIPANT	\N	PRESENT	0
81771	78329	11110B	PARTICIPANT	\N	PRESENT	0
81772	78329	11068S	PARTICIPANT	\N	PRESENT	0
81773	78329	10015M	PARTICIPANT	\N	PRESENT	0
81774	78329	04088S	PARTICIPANT	\N	PRESENT	0
81775	78329	89029V	PARTICIPANT	\N	PRESENT	0
81776	78329	08065C	PARTICIPANT	\N	PRESENT	0
81777	78329	95015C	PARTICIPANT	\N	PRESENT	0
81778	78329	97011G	PARTICIPANT	\N	PRESENT	0
81779	78329	14273W	PARTICIPANT	\N	PRESENT	0
81780	78329	08062Y	PARTICIPANT	\N	PRESENT	0
81824	78329	14195A	PARTICIPANT	\N	PRESENT	0
81782	78329	04057K	PARTICIPANT	\N	PRESENT	0
81783	78329	98023Q	PARTICIPANT	\N	PRESENT	0
81818	78329	14237S	PARTICIPANT	\N	PRESENT	0
81785	78329	04078Q	PARTICIPANT	\N	PRESENT	0
81786	78329	14079W	PARTICIPANT	\N	PRESENT	0
81805	78329	11071M	PARTICIPANT	\N	PRESENT	0
81819	78329	14041T	PARTICIPANT	\N	PRESENT	0
81822	78329	98018T	PARTICIPANT	\N	PRESENT	0
81790	78329	14193X	PARTICIPANT	\N	PRESENT	0
81820	78329	14213J	PARTICIPANT	\N	PRESENT	0
81792	78329	14265W	PARTICIPANT	\N	PRESENT	0
81815	78329	95035G	PARTICIPANT	\N	PRESENT	0
81794	78329	90003B	PARTICIPANT	\N	PRESENT	0
81808	78329	86034E	PARTICIPANT	\N	PRESENT	0
81796	78329	11044J	PARTICIPANT	\N	PRESENT	0
81797	78329	14157T	PARTICIPANT	\N	PRESENT	0
81798	78329	14073Q	PARTICIPANT	\N	PRESENT	0
81799	78329	07032N	PARTICIPANT	\N	PRESENT	0
81814	78329	04061F	PARTICIPANT	\N	PRESENT	0
81801	78329	11046L	PARTICIPANT	\N	PRESENT	0
81807	78329	01056V	PARTICIPANT	\N	PRESENT	0
81835	78329	04042C	PARTICIPANT	\N	PRESENT	0
81804	78329	04048J	PARTICIPANT	\N	PRESENT	0
81806	78329	11090Q	PARTICIPANT	\N	PRESENT	0
81812	78329	11097X	PARTICIPANT	\N	PRESENT	0
81810	78329	14087W	PARTICIPANT	\N	PRESENT	0
81811	78329	04049K	PARTICIPANT	\N	PRESENT	0
81813	78329	14199E	PARTICIPANT	\N	PRESENT	0
81816	78329	08047A	PARTICIPANT	\N	PRESENT	0
81817	78329	08009T	PARTICIPANT	\N	PRESENT	0
81821	78329	01008M	PARTICIPANT	\N	PRESENT	0
81823	78329	05004A	PARTICIPANT	\N	PRESENT	0
81825	78329	11091R	PARTICIPANT	\N	PRESENT	0
81826	78329	14053L	PARTICIPANT	\N	PRESENT	0
81827	78329	11030C	PARTICIPANT	\N	PRESENT	0
81828	78329	14249W	PARTICIPANT	\N	PRESENT	0
81829	78329	95030B	PARTICIPANT	\N	PRESENT	0
81830	78329	11080N	PARTICIPANT	\N	PRESENT	0
81831	78329	14217N	PARTICIPANT	\N	PRESENT	0
81832	78329	14069U	PARTICIPANT	\N	PRESENT	0
81833	78329	14105F	PARTICIPANT	\N	PRESENT	0
81834	78329	11049P	PARTICIPANT	\N	PRESENT	0
81842	78329	11065P	PARTICIPANT	\N	PRESENT	0
81844	78329	01061S	PARTICIPANT	\N	PRESENT	0
81838	78329	05008E	PARTICIPANT	\N	PRESENT	0
81847	78329	04070G	PARTICIPANT	\N	PRESENT	0
81840	78329	08018U	PARTICIPANT	\N	PRESENT	0
81845	78329	14038Y	PARTICIPANT	\N	PRESENT	0
81843	78329	01058X	PARTICIPANT	\N	PRESENT	0
81846	78329	11100Y	PARTICIPANT	\N	PRESENT	0
81848	78329	01016M	PARTICIPANT	\N	PRESENT	0
81849	78329	01060R	PARTICIPANT	\N	PRESENT	0
81850	78329	14151M	PARTICIPANT	\N	PRESENT	0
81851	78329	01048V	PARTICIPANT	\N	PRESENT	0
81852	78329	96004D	PARTICIPANT	\N	PRESENT	0
81853	78329	14063N	PARTICIPANT	\N	PRESENT	0
82158	78330	89029V	PARTICIPANT	\N	PRESENT	0
82160	78330	04044E	PARTICIPANT	\N	PRESENT	0
82161	78330	08012N	PARTICIPANT	\N	PRESENT	0
82162	78330	87003B	PARTICIPANT	\N	PRESENT	0
82163	78330	14223L	PARTICIPANT	\N	PRESENT	0
82164	78330	11043H	PARTICIPANT	\N	PRESENT	0
82165	78330	10015M	PARTICIPANT	\N	PRESENT	0
82166	78330	14014Q	PARTICIPANT	\N	PRESENT	0
82167	78330	11033F	PARTICIPANT	\N	PRESENT	0
82168	78330	11068S	PARTICIPANT	\N	PRESENT	0
82169	78330	14073Q	PARTICIPANT	\N	PRESENT	0
82170	78330	14237S	PARTICIPANT	\N	PRESENT	0
82171	78330	14273W	PARTICIPANT	\N	PRESENT	0
82172	78330	97011G	PARTICIPANT	\N	PRESENT	0
82173	78330	11039M	PARTICIPANT	\N	PRESENT	0
82174	78330	14105F	PARTICIPANT	\N	PRESENT	0
82175	78330	14235Q	PARTICIPANT	\N	PRESENT	0
82176	78330	11056N	PARTICIPANT	\N	PRESENT	0
82177	78330	11080N	PARTICIPANT	\N	PRESENT	0
82178	78330	14001X	PARTICIPANT	\N	PRESENT	0
82179	78330	14041T	PARTICIPANT	\N	PRESENT	0
82180	78330	14031R	PARTICIPANT	\N	PRESENT	0
82181	78330	14119M	PARTICIPANT	\N	PRESENT	0
82182	78330	14215L	PARTICIPANT	\N	PRESENT	0
82183	78330	14241N	PARTICIPANT	\N	PRESENT	0
82184	78330	05008E	PARTICIPANT	\N	PRESENT	0
82185	78330	95030B	PARTICIPANT	\N	PRESENT	0
82186	78330	95035G	PARTICIPANT	\N	PRESENT	0
82187	78330	14103D	PARTICIPANT	\N	PRESENT	0
82188	78330	07029T	PARTICIPANT	\N	PRESENT	0
82189	78330	11057P	PARTICIPANT	\N	PRESENT	0
82190	78330	83047W	PARTICIPANT	\N	PRESENT	0
82191	78330	04085P	PARTICIPANT	\N	PRESENT	0
82206	78330	11104D	PARTICIPANT	\N	PRESENT	0
82214	78330	14217N	PARTICIPANT	\N	PRESENT	0
82239	78330	95049N	PARTICIPANT	\N	PRESENT	0
82250	78330	14195A	PARTICIPANT	\N	PRESENT	0
82253	78330	08010L	PARTICIPANT	\N	PRESENT	0
82254	78330	11065P	PARTICIPANT	\N	PRESENT	0
82287	78333	11056N	PARTICIPANT	\N	PRESENT	0
82288	78333	92018S	PARTICIPANT	\N	PRESENT	0
82289	78333	14235Q	PARTICIPANT	\N	PRESENT	0
82290	78333	01059Y	PARTICIPANT	\N	PRESENT	0
82291	78333	08012N	PARTICIPANT	\N	PRESENT	0
82292	78333	14001X	PARTICIPANT	\N	PRESENT	0
82293	78333	11065P	PARTICIPANT	\N	PRESENT	0
82294	78333	14241N	PARTICIPANT	\N	PRESENT	0
82295	78333	14073Q	PARTICIPANT	\N	PRESENT	0
82296	78333	14031R	PARTICIPANT	\N	PRESENT	0
82297	78333	14215L	PARTICIPANT	\N	PRESENT	0
82298	78333	11103C	PARTICIPANT	\N	PRESENT	0
82299	78333	08062Y	PARTICIPANT	\N	PRESENT	0
82300	78333	11039M	PARTICIPANT	\N	PRESENT	0
82301	78333	11098Y	PARTICIPANT	\N	PRESENT	0
82302	78333	14038Y	PARTICIPANT	\N	PRESENT	0
82303	78333	05008E	PARTICIPANT	\N	PRESENT	0
82304	78333	88008L	PARTICIPANT	\N	PRESENT	0
82305	78333	14229S	PARTICIPANT	\N	PRESENT	0
81692	78329	14083S	PARTICIPANT	\N	PRESENT	0
81764	78329	08038Y	PARTICIPANT	\N	PRESENT	0
82306	78333	14147R	PARTICIPANT	\N	PRESENT	0
82307	78333	11012A	PARTICIPANT	\N	PRESENT	0
82308	78333	05012A	PARTICIPANT	\N	PRESENT	0
82309	78333	14103D	PARTICIPANT	\N	PRESENT	0
82310	78333	14263U	PARTICIPANT	\N	PRESENT	0
82311	78333	14033T	PARTICIPANT	\N	PRESENT	0
82312	78333	14197C	PARTICIPANT	\N	PRESENT	0
82313	78333	14119M	PARTICIPANT	\N	PRESENT	0
82314	78333	14231L	PARTICIPANT	\N	PRESENT	0
82315	78333	14331P	PARTICIPANT	\N	PRESENT	0
82316	78333	14105F	PARTICIPANT	\N	PRESENT	0
82285	78333	04081K	PARTICIPANT	\N	PRESENT	0
82286	78333	04044E	PARTICIPANT	\N	PRESENT	0
82317	78333	14069U	PARTICIPANT	\N	PRESENT	0
82318	78333	14034U	PARTICIPANT	\N	PRESENT	0
82319	78333	95030B	PARTICIPANT	\N	PRESENT	0
82320	78333	14026U	PARTICIPANT	\N	PRESENT	0
82321	78333	14030Q	PARTICIPANT	\N	PRESENT	0
82322	78333	14083S	PARTICIPANT	\N	PRESENT	0
82323	78333	95067Q	PARTICIPANT	\N	PRESENT	0
82324	78333	14219Q	PARTICIPANT	\N	PRESENT	0
82325	78333	08010L	PARTICIPANT	\N	PRESENT	0
82326	78333	11048N	PARTICIPANT	\N	PRESENT	0
82327	78333	11036J	PARTICIPANT	\N	PRESENT	0
82328	78333	04049K	PARTICIPANT	\N	PRESENT	0
82329	78333	14265W	PARTICIPANT	\N	PRESENT	0
82330	78333	07032N	PARTICIPANT	\N	PRESENT	0
82331	78333	14249W	PARTICIPANT	\N	PRESENT	0
82332	78333	14213J	PARTICIPANT	\N	PRESENT	0
82333	78333	01016M	PARTICIPANT	\N	PRESENT	0
82334	78333	08051V	PARTICIPANT	\N	PRESENT	0
82335	78333	11043H	PARTICIPANT	\N	PRESENT	0
82336	78333	08018U	PARTICIPANT	\N	PRESENT	0
82337	78333	89017R	PARTICIPANT	\N	PRESENT	0
82338	78333	08015R	PARTICIPANT	\N	PRESENT	0
65054	65051	05008E	PARTICIPANT	\N	EXCUSE	0
65056	65051	11033F	PARTICIPANT	\N	PRESENT	0
65058	65051	14069U	PARTICIPANT	\N	PRESENT	0
65059	65051	04047H	PARTICIPANT	\N	PRESENT	0
65063	65051	04038G	PARTICIPANT	\N	PRESENT	0
65066	65051	14041T	PARTICIPANT	\N	PRESENT	0
65067	65051	01024M	PARTICIPANT	\N	PRESENT	0
65070	65051	11084S	PARTICIPANT	\N	PRESENT	0
65071	65051	11026G	PARTICIPANT	\N	PRESENT	0
65073	65051	14111D	PARTICIPANT	\N	PRESENT	0
65074	65051	14273W	PARTICIPANT	\N	PRESENT	0
65076	65051	07034Q	PARTICIPANT	\N	PRESENT	0
65077	65051	01028R	PARTICIPANT	\N	PRESENT	0
65079	65051	04044E	PRESIDENT	0	PRESENT	0
65080	65051	11037K	PARTICIPANT	\N	PRESENT	0
65081	65051	92045V	PARTICIPANT	\N	PRESENT	0
65082	65051	01047U	PARTICIPANT	\N	PRESENT	0
65083	65051	98035U	PARTICIPANT	\N	PRESENT	0
65084	65051	04056J	PARTICIPANT	\N	PRESENT	0
69409	69406	11103C	PARTICIPANT	\N	PRESENT	0
69410	69406	11044J	PARTICIPANT	\N	PRESENT	0
69411	69406	08069G	PARTICIPANT	\N	PRESENT	0
69412	69406	14059S	PARTICIPANT	\N	PRESENT	0
69413	69406	14103D	PARTICIPANT	\N	PRESENT	0
69414	69406	14273W	PARTICIPANT	\N	PRESENT	0
69415	69406	04088S	PARTICIPANT	\N	PRESENT	0
69416	69406	11090Q	PARTICIPANT	\N	PRESENT	0
69417	69406	92045V	PARTICIPANT	\N	PRESENT	0
69430	69429	14053L	PARTICIPANT	\N	PRESENT	0
69431	69429	12042Y	PARTICIPANT	\N	PRESENT	0
69432	69429	14026U	PARTICIPANT	\N	PRESENT	0
71897	71896	11076S	PARTICIPANT	\N	PRESENT	0
71898	71896	01031L	PARTICIPANT	\N	PRESENT	0
71899	71896	14093U	PARTICIPANT	\N	PRESENT	0
71900	71896	14065Q	PARTICIPANT	\N	PRESENT	0
71901	71896	96004D	PARTICIPANT	\N	PRESENT	0
71902	71896	10006L	PARTICIPANT	\N	PRESENT	0
71903	71896	92020L	PARTICIPANT	\N	PRESENT	0
71905	71896	14281W	PARTICIPANT	\N	PRESENT	0
71906	71896	07024N	PARTICIPANT	\N	PRESENT	0
71907	71896	11061K	PARTICIPANT	\N	PRESENT	0
71908	71896	11089X	PARTICIPANT	\N	PRESENT	0
71909	71896	14097Y	PARTICIPANT	\N	PRESENT	0
71910	71896	14251Q	PARTICIPANT	\N	PRESENT	0
71911	71896	08009T	PARTICIPANT	\N	PRESENT	0
71912	71896	98018T	PARTICIPANT	\N	PRESENT	0
71913	71896	14225N	PARTICIPANT	\N	PRESENT	0
71914	71896	04045F	PARTICIPANT	\N	PRESENT	0
71958	71957	04080J	PARTICIPANT	\N	PRESENT	0
71959	71957	08042U	PARTICIPANT	\N	PRESENT	0
71961	71957	14026U	PARTICIPANT	\N	PRESENT	0
71962	71957	11026G	PARTICIPANT	\N	PRESENT	0
71963	71957	11035H	PARTICIPANT	\N	PRESENT	0
71966	71957	04045F	PARTICIPANT	\N	PRESENT	0
71969	71957	10015M	PARTICIPANT	\N	PRESENT	0
71972	71971	11026G	PARTICIPANT	\N	PRESENT	0
72468	72466	04034C	PARTICIPANT	\N	PRESENT	0
71977	71976	10015M	PARTICIPANT	\N	PRESENT	0
75092	75091	08018U	PARTICIPANT	\N	PRESENT	0
72470	72469	04034C	PARTICIPANT	\N	PRESENT	0
77239	77223	08053X	PARTICIPANT	\N	PRESENT	0
77240	77223	11082Q	PARTICIPANT	\N	EXCUSE	0
77241	77223	14193X	PARTICIPANT	\N	EXCUSE	0
77281	77280	08038Y	PARTICIPANT	\N	PRESENT	0
77243	77223	10015M	PARTICIPANT	\N	PRESENT	0
77244	77223	11054L	PARTICIPANT	\N	EXCUSE	0
77283	77280	14051J	PARTICIPANT	\N	PRESENT	0
77246	77223	14269B	PARTICIPANT	\N	PRESENT	0
77282	77280	05012A	PARTICIPANT	\N	PRESENT	0
77284	77280	14063N	PARTICIPANT	\N	PRESENT	0
77285	77280	14030Q	PARTICIPANT	\N	PRESENT	0
77287	77286	05012A	PARTICIPANT	\N	PRESENT	0
77288	77286	14051J	PARTICIPANT	\N	PRESENT	0
77289	77286	14063N	PARTICIPANT	\N	PRESENT	0
77290	77286	08038Y	PARTICIPANT	\N	PRESENT	0
77291	77286	14030Q	PARTICIPANT	\N	PRESENT	0
77293	77292	08038Y	PARTICIPANT	\N	PRESENT	0
77294	77292	05012A	PARTICIPANT	\N	PRESENT	0
77295	77292	14051J	PARTICIPANT	\N	PRESENT	0
77296	77292	14063N	PARTICIPANT	\N	PRESENT	0
78389	78340	01043Q	PARTICIPANT	\N	EXCUSE	0
78435	78434	08042U	PARTICIPANT	\N	PRESENT	0
78436	78434	95062K	PARTICIPANT	\N	PRESENT	0
78437	78434	11107G	PARTICIPANT	\N	PRESENT	0
78439	78438	14239U	PARTICIPANT	\N	PRESENT	0
78440	78438	11055M	PARTICIPANT	\N	PRESENT	0
78441	78438	01046T	PARTICIPANT	\N	PRESENT	0
78442	78438	04053F	PARTICIPANT	\N	PRESENT	0
78443	78438	14255U	PARTICIPANT	\N	PRESENT	0
78786	78785	08025T	PARTICIPANT	\N	PRESENT	0
78445	78438	00003C	PARTICIPANT	\N	PRESENT	0
78446	78438	14053L	PARTICIPANT	\N	PRESENT	0
78447	78438	11103C	PARTICIPANT	\N	PRESENT	0
78787	78785	04085P	PARTICIPANT	\N	PRESENT	0
78449	78438	14195A	PARTICIPANT	\N	PRESENT	0
78450	78438	14267Y	PARTICIPANT	\N	PRESENT	0
78451	78438	11023D	PARTICIPANT	\N	PRESENT	0
78788	78785	05008E	PRESIDENT	0	PRESENT	0
78453	78438	08052W	PARTICIPANT	\N	PRESENT	0
78789	78785	11030C	PARTICIPANT	\N	PRESENT	0
78455	78438	04081K	PARTICIPANT	\N	PRESENT	0
78456	78438	98024R	PARTICIPANT	\N	PRESENT	0
78457	78438	10006L	PARTICIPANT	\N	PRESENT	0
78790	78785	11033F	PARTICIPANT	\N	PRESENT	0
78459	78438	14217N	PARTICIPANT	\N	PRESENT	0
78460	78438	14042U	PARTICIPANT	\N	PRESENT	0
78461	78438	14151M	PARTICIPANT	\N	PRESENT	0
78791	78785	14065Q	PARTICIPANT	\N	PRESENT	0
78463	78438	14281W	PARTICIPANT	\N	PRESENT	0
78464	78438	14087W	PARTICIPANT	\N	PRESENT	0
78792	78785	14069U	PARTICIPANT	\N	PRESENT	0
78466	78438	14034U	PARTICIPANT	\N	PRESENT	0
78467	78438	14231L	PARTICIPANT	\N	PRESENT	0
78468	78438	11061K	PARTICIPANT	\N	PRESENT	0
78469	78438	08048B	PARTICIPANT	\N	PRESENT	0
78470	78438	08041T	PARTICIPANT	\N	PRESENT	0
78793	78785	04047H	PARTICIPANT	\N	PRESENT	0
78472	78438	14026U	PARTICIPANT	\N	PRESENT	0
78473	78438	14213J	PARTICIPANT	\N	EXCUSE	0
78474	78438	14121F	PARTICIPANT	\N	PRESENT	0
78475	78438	11112D	PARTICIPANT	\N	EXCUSE	0
78476	78438	14037X	PARTICIPANT	\N	PRESENT	0
78477	78438	14018U	PARTICIPANT	\N	PRESENT	0
78478	78438	11067R	PARTICIPANT	\N	PRESENT	0
78479	78438	14223L	PARTICIPANT	\N	PRESENT	0
78480	78438	04092N	PRESIDENT	0	PRESENT	0
78481	78438	14265W	PARTICIPANT	\N	PRESENT	0
78482	78438	14119M	PARTICIPANT	\N	PRESENT	0
78483	78438	14071N	PARTICIPANT	\N	PRESENT	0
78484	78438	07032N	PARTICIPANT	\N	PRESENT	0
78794	78785	04038G	PARTICIPANT	\N	PRESENT	0
78795	78785	99002P	PARTICIPANT	\N	PRESENT	0
78800	78785	11056N	PARTICIPANT	\N	PRESENT	0
78488	78438	11093T	PARTICIPANT	\N	PRESENT	0
78489	78438	11097X	PARTICIPANT	\N	PRESENT	0
78490	78438	04045F	PARTICIPANT	\N	PRESENT	0
78491	78438	14227Q	PARTICIPANT	\N	PRESENT	0
78492	78438	01034P	PARTICIPANT	\N	PRESENT	0
78802	78785	14259Y	PARTICIPANT	\N	PRESENT	0
78494	78438	11063M	PARTICIPANT	\N	PRESENT	0
78803	78785	11035H	PARTICIPANT	\N	PRESENT	0
78804	78785	01024M	PARTICIPANT	\N	PRESENT	0
78805	78785	14215L	PARTICIPANT	\N	PRESENT	0
78806	78785	08018U	PARTICIPANT	\N	PRESENT	0
78807	78785	01007L	PARTICIPANT	\N	PRESENT	0
78808	78785	11049P	PARTICIPANT	\N	PRESENT	0
78809	78785	11084S	PARTICIPANT	\N	PRESENT	0
78810	78785	11026G	PARTICIPANT	\N	PRESENT	0
78811	78785	04079R	PARTICIPANT	\N	PRESENT	0
78832	78785	14111D	PARTICIPANT	\N	PRESENT	0
78833	78785	14001X	PARTICIPANT	\N	PRESENT	0
78834	78785	14273W	PARTICIPANT	\N	PRESENT	0
78835	78785	01060R	PARTICIPANT	\N	PRESENT	0
78836	78785	14147R	PARTICIPANT	\N	PRESENT	0
78837	78785	95049N	PARTICIPANT	\N	PRESENT	0
78838	78785	08051V	PARTICIPANT	\N	PRESENT	0
78839	78785	07034Q	PRESIDENT	2	PRESENT	0
78840	78785	04074L	PARTICIPANT	\N	PRESENT	0
78841	78785	10015M	PARTICIPANT	\N	PRESENT	0
78842	78785	95063L	PARTICIPANT	\N	PRESENT	0
78845	78785	01019Q	PARTICIPANT	\N	PRESENT	0
78846	78785	01028R	PARTICIPANT	\N	PRESENT	0
78847	78785	98035U	PARTICIPANT	\N	PRESENT	0
78848	78785	04056J	PARTICIPANT	\N	PRESENT	0
78849	78785	14275Y	PARTICIPANT	\N	PRESENT	0
78850	78785	04044E	PRESIDENT	1	PRESENT	0
78851	78785	11037K	PARTICIPANT	\N	PRESENT	0
78852	78785	92045V	PARTICIPANT	\N	PRESENT	0
78853	78785	95067Q	PARTICIPANT	\N	PRESENT	0
81763	78329	11088W	PARTICIPANT	\N	PRESENT	0
82159	80071	11035H	PARTICIPANT	\N	EXCUSE	0
82195	82194	89017R	PARTICIPANT	\N	PRESENT	0
82196	82194	01031L	PRESIDENT	0	PRESENT	0
82197	82194	01013J	PARTICIPANT	\N	EXCUSE	0
82198	82194	11068S	PARTICIPANT	\N	PRESENT	0
82199	82194	11040E	PARTICIPANT	\N	EXCUSE	0
82200	82194	08014Q	PARTICIPANT	\N	PRESENT	0
82201	82194	14083S	PARTICIPANT	\N	PRESENT	0
82202	82194	11053K	PARTICIPANT	\N	PRESENT	0
82203	82194	14085U	PARTICIPANT	\N	PRESENT	0
82204	82194	11042G	PARTICIPANT	\N	PRESENT	0
82205	82194	88008L	PARTICIPANT	\N	PRESENT	0
82207	82194	04086Q	PARTICIPANT	\N	PRESENT	0
82208	82194	11070L	PARTICIPANT	\N	PRESENT	0
82209	82194	11088W	PARTICIPANT	\N	PRESENT	0
82210	82194	14327T	PARTICIPANT	\N	PRESENT	0
82211	82194	08022Q	PARTICIPANT	\N	PRESENT	0
82212	82194	01027Q	PARTICIPANT	\N	PRESENT	0
82213	82194	11074Q	PARTICIPANT	\N	PRESENT	0
82215	82194	98053W	PARTICIPANT	\N	EXCUSE	0
82216	82194	11083R	PARTICIPANT	\N	PRESENT	0
82217	82194	14199E	PARTICIPANT	\N	PRESENT	0
82218	82194	01057W	PARTICIPANT	\N	PRESENT	0
82219	82194	08069G	PARTICIPANT	\N	PRESENT	0
82220	82194	11048N	PARTICIPANT	\N	PRESENT	0
82221	82194	14159V	PARTICIPANT	\N	PRESENT	0
82222	82194	07029T	PARTICIPANT	\N	PRESENT	0
82223	82194	08010L	PARTICIPANT	\N	PRESENT	0
82224	82194	08034U	PARTICIPANT	\N	PRESENT	0
82225	82194	01048V	PARTICIPANT	\N	EXCUSE	0
82226	82194	98046X	PARTICIPANT	\N	PRESENT	0
82227	82194	08011M	PARTICIPANT	\N	PRESENT	0
82228	82194	08061X	PARTICIPANT	\N	PRESENT	0
82229	82194	01016M	PARTICIPANT	\N	PRESENT	0
82230	82194	11012A	PARTICIPANT	\N	PRESENT	0
82231	82194	11057P	PARTICIPANT	\N	PRESENT	0
82232	82194	14173T	PARTICIPANT	\N	PRESENT	0
82233	82194	04034C	PARTICIPANT	\N	PRESENT	0
82352	77795	01027Q	PARTICIPANT	\N	EXCUSE	0
83003	80435	14169X	PARTICIPANT	\N	PRESENT	0
83005	80435	14089Y	PARTICIPANT	\N	PRESENT	0
83006	80435	04045F	PARTICIPANT	\N	PRESENT	0
83093	83004	04070G	PARTICIPANT	\N	PRESENT	0
83094	83004	04074L	PARTICIPANT	\N	PRESENT	0
83095	83004	14263U	PARTICIPANT	\N	PRESENT	0
83096	83004	07026Q	PARTICIPANT	\N	PRESENT	0
83097	83004	14235Q	PARTICIPANT	\N	PRESENT	0
83098	83004	01022K	PARTICIPANT	\N	PRESENT	0
83099	83004	14197C	PARTICIPANT	\N	PRESENT	0
83100	83004	14121F	PARTICIPANT	\N	PRESENT	0
83101	83004	11112D	PARTICIPANT	\N	PRESENT	0
83102	83004	11036J	PARTICIPANT	\N	PRESENT	0
83103	83004	04045F	PARTICIPANT	\N	PRESENT	0
83104	83004	14014Q	PARTICIPANT	\N	PRESENT	0
83105	83004	14159V	PARTICIPANT	\N	PRESENT	0
83106	83004	01044R	PARTICIPANT	\N	PRESENT	0
83107	83004	92015P	PARTICIPANT	\N	PRESENT	0
83108	83004	14229S	PARTICIPANT	\N	PRESENT	0
83109	83004	11029K	PARTICIPANT	\N	PRESENT	0
83110	83004	14089Y	PARTICIPANT	\N	PRESENT	0
83111	83004	14273W	PARTICIPANT	\N	PRESENT	0
83112	83004	95015C	PARTICIPANT	\N	PRESENT	0
83113	83004	11088W	PARTICIPANT	\N	PRESENT	0
83114	83004	07029T	PARTICIPANT	\N	PRESENT	0
83115	83004	11091R	PARTICIPANT	\N	PRESENT	0
83116	83004	11103C	PARTICIPANT	\N	PRESENT	0
83117	83004	97011G	PARTICIPANT	\N	PRESENT	0
83118	83004	14249W	PARTICIPANT	\N	PRESENT	0
83119	83004	90003B	PARTICIPANT	\N	PRESENT	0
83120	83004	08039A	PARTICIPANT	\N	PRESENT	0
83121	83004	14083S	PARTICIPANT	\N	PRESENT	0
83122	83004	11040E	PARTICIPANT	\N	PRESENT	0
83123	83004	04057K	PARTICIPANT	\N	PRESENT	0
83124	83004	01008M	PARTICIPANT	\N	PRESENT	0
83125	83004	08069G	PARTICIPANT	\N	PRESENT	0
83126	83004	14147R	PARTICIPANT	\N	PRESENT	0
83127	83004	14265W	PARTICIPANT	\N	PRESENT	0
83128	83004	14223L	PARTICIPANT	\N	PRESENT	0
83129	83004	11107G	PARTICIPANT	\N	PRESENT	0
83130	83004	14059S	PARTICIPANT	\N	PRESENT	0
83131	83004	14241N	PARTICIPANT	\N	PRESENT	0
83132	83004	04056J	PARTICIPANT	\N	PRESENT	0
83133	83004	04048J	PARTICIPANT	\N	PRESENT	0
83134	83004	04081K	PARTICIPANT	\N	PRESENT	0
83135	83004	14073Q	PARTICIPANT	\N	PRESENT	0
83136	83004	14042U	PARTICIPANT	\N	PRESENT	0
83137	83004	14209N	PARTICIPANT	\N	PRESENT	0
83151	83004	11012A	PARTICIPANT	\N	PRESENT	0
83152	83004	14231L	PARTICIPANT	\N	PRESENT	0
83153	83004	04080J	PARTICIPANT	\N	PRESENT	0
83154	83004	13002U	PARTICIPANT	\N	PRESENT	0
83155	83004	01028R	PARTICIPANT	\N	PRESENT	0
83156	83004	11043H	PARTICIPANT	\N	PRESENT	0
83157	83004	04088S	PARTICIPANT	\N	PRESENT	0
83158	83004	95035G	PARTICIPANT	\N	PRESENT	0
83159	83004	14193X	PARTICIPANT	\N	PRESENT	0
83160	83004	08031R	PARTICIPANT	\N	PRESENT	0
83161	83004	14061L	PARTICIPANT	\N	PRESENT	0
83162	83004	14069U	PARTICIPANT	\N	PRESENT	0
83163	83004	14033T	PARTICIPANT	\N	PRESENT	0
83164	83004	11109J	PARTICIPANT	\N	PRESENT	0
83166	83004	07004J	PARTICIPANT	\N	PRESENT	0
83167	83004	11039M	PARTICIPANT	\N	PRESENT	0
83168	83004	08024S	PARTICIPANT	\N	PRESENT	0
83169	83004	08019V	PARTICIPANT	\N	PRESENT	0
83170	83004	14219Q	PARTICIPANT	\N	PRESENT	0
83171	83004	14179A	PARTICIPANT	\N	PRESENT	0
83172	83004	08055A	PARTICIPANT	\N	PRESENT	0
83173	83004	11053K	PARTICIPANT	\N	PRESENT	0
83241	78336	04044E	PARTICIPANT	\N	PRESENT	0
83242	78336	14257W	PARTICIPANT	\N	PRESENT	0
83243	78336	04056J	PARTICIPANT	\N	PRESENT	0
83244	78336	04085P	PARTICIPANT	\N	PRESENT	0
83245	78336	08031R	PARTICIPANT	\N	PRESENT	0
83246	78336	14033T	PARTICIPANT	\N	PRESENT	0
83247	78336	14265W	PARTICIPANT	\N	PRESENT	0
83248	78336	14135M	PARTICIPANT	\N	PRESENT	0
83249	78336	11112D	PARTICIPANT	\N	PRESENT	0
83250	78336	14219Q	PARTICIPANT	\N	PRESENT	0
83251	78336	01059Y	PARTICIPANT	\N	PRESENT	0
83252	78336	14083S	PARTICIPANT	\N	PRESENT	0
83485	80071	04045F	PARTICIPANT	\N	PRESENT	0
83486	80071	11101A	PARTICIPANT	\N	PRESENT	0
83488	83487	05012A	PARTICIPANT	\N	PRESENT	0
83489	83487	14071N	PARTICIPANT	\N	PRESENT	0
83490	83487	14051J	PARTICIPANT	\N	PRESENT	0
83091	83004	01007L	PARTICIPANT	\N	PRESENT	0
83092	83004	04059M	PARTICIPANT	\N	PRESENT	0
83491	83487	08038Y	PARTICIPANT	\N	PRESENT	0
83492	83487	11101A	PARTICIPANT	\N	PRESENT	0
83493	83487	11099A	PARTICIPANT	\N	PRESENT	0
83494	83487	14231L	PARTICIPANT	\N	PRESENT	0
83496	83487	11074Q	PARTICIPANT	\N	PRESENT	0
83499	83498	05012A	PARTICIPANT	\N	PRESENT	0
83500	83498	11101A	PARTICIPANT	\N	PRESENT	0
83502	83498	08038Y	PARTICIPANT	\N	PRESENT	0
83506	83498	14051J	PARTICIPANT	\N	PRESENT	0
83512	83511	05012A	PARTICIPANT	\N	PRESENT	0
83513	83511	11101A	PARTICIPANT	\N	PRESENT	0
83514	83511	08038Y	PARTICIPANT	\N	PRESENT	0
83515	83511	14071N	PARTICIPANT	\N	PRESENT	0
83516	83511	14231L	PARTICIPANT	\N	PRESENT	0
83518	83517	11099A	PARTICIPANT	\N	PRESENT	0
83519	83517	11101A	PARTICIPANT	\N	PRESENT	0
83520	83517	08038Y	PARTICIPANT	\N	PRESENT	0
83522	83517	05012A	PARTICIPANT	\N	PRESENT	0
83813	83812	14251Q	PARTICIPANT	\N	PRESENT	0
83814	83812	11076S	PARTICIPANT	\N	PRESENT	0
83816	83815	14251Q	PARTICIPANT	\N	PRESENT	0
83817	83815	95037J	PARTICIPANT	\N	PRESENT	0
83818	83815	11076S	PARTICIPANT	\N	PRESENT	0
83820	83819	14251Q	PARTICIPANT	\N	PRESENT	0
83821	83819	95037J	PARTICIPANT	\N	PRESENT	0
83853	83852	14087W	PARTICIPANT	\N	PRESENT	0
83861	83860	04071H	PARTICIPANT	\N	PRESENT	0
83867	83866	04071H	PARTICIPANT	\N	PRESENT	0
83239	78336	08024S	PARTICIPANT	\N	PRESENT	0
83240	78336	14231L	PARTICIPANT	\N	PRESENT	0
83869	83868	04071H	PARTICIPANT	\N	PRESENT	0
83871	83870	04071H	PARTICIPANT	\N	PRESENT	0
83873	83872	04071H	PARTICIPANT	\N	PRESENT	0
83876	83875	04071H	PARTICIPANT	\N	PRESENT	0
83879	83878	04071H	PARTICIPANT	\N	PRESENT	0
83883	83882	04071H	PARTICIPANT	\N	PRESENT	0
83885	83884	04071H	PARTICIPANT	\N	PRESENT	0
83913	83912	11068S	PARTICIPANT	\N	PRESENT	0
83915	83914	11068S	PARTICIPANT	\N	PRESENT	0
66305	66304	04080J	PARTICIPANT	\N	PRESENT	0
66308	66307	07024N	PARTICIPANT	\N	PRESENT	0
66309	66307	01014K	PARTICIPANT	\N	PRESENT	0
66310	66307	04040A	PARTICIPANT	\N	PRESENT	0
66311	66307	11106F	PARTICIPANT	\N	PRESENT	0
66312	66307	11054L	PARTICIPANT	\N	PRESENT	0
68421	68420	01008M	PARTICIPANT	\N	PRESENT	0
68422	68420	11036J	PARTICIPANT	\N	PRESENT	0
68621	68620	14263U	PARTICIPANT	\N	PRESENT	0
68424	68420	14013P	PARTICIPANT	\N	PRESENT	0
68425	68420	08068F	PARTICIPANT	\N	PRESENT	0
68426	68420	14207L	PARTICIPANT	\N	PRESENT	0
68427	68420	11101A	PARTICIPANT	\N	PRESENT	0
68428	68420	90003B	PARTICIPANT	\N	PRESENT	0
68429	68420	08028W	PARTICIPANT	\N	PRESENT	0
68430	68420	80013X	PARTICIPANT	\N	PRESENT	0
68431	68420	08038Y	PARTICIPANT	\N	PRESENT	0
68432	68420	04089T	PARTICIPANT	\N	PRESENT	0
68433	68420	14197C	PARTICIPANT	\N	PRESENT	0
68434	68420	11110B	PARTICIPANT	\N	PRESENT	0
68435	68420	14187A	PARTICIPANT	\N	PRESENT	0
68436	68420	14033T	PARTICIPANT	\N	PRESENT	0
68437	68420	14081Q	PARTICIPANT	\N	PRESENT	0
68622	68620	11109J	PARTICIPANT	\N	PRESENT	0
68439	68420	11099A	PARTICIPANT	\N	PRESENT	0
68440	68420	04049K	PARTICIPANT	\N	PRESENT	0
68623	68620	11039M	PARTICIPANT	\N	PRESENT	0
68442	68420	11111C	PARTICIPANT	\N	PRESENT	0
68443	68420	08015R	PARTICIPANT	\N	PRESENT	0
68444	68420	11100Y	PRESIDENT	0	PRESENT	0
68445	68420	01061S	PARTICIPANT	\N	PRESENT	0
68446	68420	11098Y	PARTICIPANT	\N	PRESENT	0
68447	68420	01043Q	PARTICIPANT	\N	PRESENT	0
68448	68420	11077T	PARTICIPANT	\N	PRESENT	0
68449	68420	14205J	PARTICIPANT	\N	PRESENT	0
68450	68420	08019V	PARTICIPANT	\N	EXCUSE	0
68451	68420	14257W	PARTICIPANT	\N	PRESENT	0
68452	68420	08021P	PARTICIPANT	\N	PRESENT	0
68453	68420	04088S	PARTICIPANT	\N	PRESENT	0
68624	68620	01044R	PARTICIPANT	\N	PRESENT	0
68455	68420	11090Q	PARTICIPANT	\N	PRESENT	0
68456	68420	11046L	PARTICIPANT	\N	PRESENT	0
68457	68420	01058X	PARTICIPANT	\N	PRESENT	0
68458	68420	11094U	PARTICIPANT	\N	PRESENT	0
68459	68420	11066Q	PARTICIPANT	\N	PRESENT	0
68625	68620	08043V	PARTICIPANT	\N	PRESENT	0
68626	68620	14089Y	PARTICIPANT	\N	PRESENT	0
68627	68620	11029K	PARTICIPANT	\N	PRESENT	0
68628	68620	95015C	PARTICIPANT	\N	PRESENT	0
68629	68620	92015P	PARTICIPANT	\N	PRESENT	0
68630	68620	14201E	PARTICIPANT	\N	PRESENT	0
68631	68620	11091R	PARTICIPANT	\N	PRESENT	0
68632	68620	87003B	PARTICIPANT	\N	EXCUSE	0
68633	68620	98042T	PARTICIPANT	\N	PRESENT	0
68634	68620	14249W	PARTICIPANT	\N	PRESENT	0
68635	68620	01041N	PARTICIPANT	\N	PRESENT	0
68636	68620	01025N	PARTICIPANT	\N	PRESENT	0
68637	68620	01037S	PARTICIPANT	\N	PRESENT	0
68638	68620	08035V	PARTICIPANT	\N	PRESENT	0
68639	68620	11089X	PARTICIPANT	\N	PRESENT	0
68640	68620	14123H	PARTICIPANT	\N	PRESENT	0
68641	68620	04041B	PARTICIPANT	\N	EXCUSE	0
68642	68620	14241N	PARTICIPANT	\N	PRESENT	0
68643	68620	14061L	PARTICIPANT	\N	PRESENT	0
68644	68620	14073Q	PARTICIPANT	\N	PRESENT	0
68645	68620	08031R	PARTICIPANT	\N	PRESENT	0
68646	68620	08039A	PARTICIPANT	\N	EXCUSE	0
68647	68620	08017T	PARTICIPANT	\N	PRESENT	0
68648	68620	14059S	PARTICIPANT	\N	PRESENT	0
68649	68620	11104D	PARTICIPANT	\N	PRESENT	0
68650	68620	14063N	PARTICIPANT	\N	PRESENT	0
68651	68620	04057K	PARTICIPANT	\N	PRESENT	0
68652	68620	14109K	PARTICIPANT	\N	PRESENT	0
68653	68620	04070G	PRESIDENT	0	PRESENT	0
68654	68620	92040Q	PARTICIPANT	\N	PRESENT	0
68655	68620	14235Q	PARTICIPANT	\N	PRESENT	0
68656	68620	14229S	PARTICIPANT	\N	PRESENT	0
68657	68620	11043H	PARTICIPANT	\N	PRESENT	0
73543	73542	14053L	PARTICIPANT	\N	PRESENT	0
73544	73542	12042Y	PARTICIPANT	\N	PRESENT	0
75023	75022	14273W	PARTICIPANT	\N	PRESENT	0
75025	75024	95049N	PARTICIPANT	\N	PRESENT	0
75027	75026	95049N	PARTICIPANT	\N	PRESENT	0
78744	78681	04074L	RAPPORTEUR_AVIS	\N	PRESENT	0
75030	75028	10015M	PARTICIPANT	\N	PRESENT	0
78701	78681	11091R	PARTICIPANT	\N	PRESENT	0
78702	78681	87003B	PARTICIPANT	\N	PRESENT	0
78703	78681	98042T	PARTICIPANT	\N	PRESENT	0
78704	78681	14249W	PARTICIPANT	\N	PRESENT	0
80415	80280	14097Y	PARTICIPANT	\N	PRESENT	0
78706	78681	01025N	PARTICIPANT	\N	PRESENT	0
78707	78681	01037S	PARTICIPANT	\N	PRESENT	0
80416	80280	04080J	PARTICIPANT	\N	PRESENT	0
78709	78681	08035V	PARTICIPANT	\N	PRESENT	0
78710	78681	11089X	PARTICIPANT	\N	PRESENT	0
78711	78681	07026Q	PARTICIPANT	\N	PRESENT	0
78712	78681	14123H	PARTICIPANT	\N	PRESENT	0
78713	78681	14179A	PARTICIPANT	\N	PRESENT	0
78714	78681	04041B	PARTICIPANT	\N	PRESENT	0
78715	78681	14241N	PARTICIPANT	\N	PRESENT	0
78716	78681	14061L	PARTICIPANT	\N	PRESENT	0
78717	78681	14073Q	PARTICIPANT	\N	PRESENT	0
78718	78681	08031R	PARTICIPANT	\N	EXCUSE	0
78719	78681	12041X	PARTICIPANT	\N	PRESENT	0
78720	78681	08039A	PARTICIPANT	\N	PRESENT	0
78721	78681	08017T	PARTICIPANT	\N	PRESENT	0
78722	78681	14059S	PARTICIPANT	\N	PRESENT	0
78723	78681	08012N	PARTICIPANT	\N	PRESENT	0
78724	78681	14103D	PARTICIPANT	\N	PRESENT	0
78725	78681	11104D	PARTICIPANT	\N	PRESENT	0
78726	78681	14063N	PARTICIPANT	\N	PRESENT	0
78727	78681	04057K	PARTICIPANT	\N	PRESENT	0
78728	78681	11014C	PARTICIPANT	\N	PRESENT	0
78729	78681	14109K	PARTICIPANT	\N	PRESENT	0
78730	78681	04070G	PARTICIPANT	\N	PRESENT	0
78731	78681	92040Q	PARTICIPANT	\N	PRESENT	0
78732	78681	14191V	PARTICIPANT	\N	PRESENT	0
78733	78681	83047W	PARTICIPANT	\N	PRESENT	0
78734	78681	14235Q	PARTICIPANT	\N	PRESENT	0
82353	80071	01027Q	PARTICIPANT	\N	EXCUSE	0
78736	78681	04033B	PARTICIPANT	\N	PRESENT	0
78737	78681	14229S	PARTICIPANT	\N	PRESENT	0
78738	78681	11043H	PARTICIPANT	\N	PRESENT	0
78739	78681	11071M	PARTICIPANT	\N	PRESENT	0
80457	80456	05008E	PRESIDENT	0	PRESENT	0
82415	80071	04040A	PRESIDENT	0	PRESENT	0
80459	80456	04038G	PARTICIPANT	\N	PRESENT	0
83719	83718	08011M	PARTICIPANT	\N	PRESENT	0
88377	88358	04074L	PARTICIPANT	\N	PRESENT	0
80462	80456	14215L	PARTICIPANT	\N	PRESENT	0
80463	80456	11034G	PARTICIPANT	\N	PRESENT	0
88378	88358	95063L	PARTICIPANT	\N	PRESENT	0
80465	80456	01007L	PARTICIPANT	\N	PRESENT	0
88379	88358	01028R	PARTICIPANT	\N	PRESENT	0
80467	80456	95063L	PARTICIPANT	\N	PRESENT	0
80468	80456	98035U	PARTICIPANT	\N	PRESENT	0
80469	80456	11037K	PARTICIPANT	\N	PRESENT	0
80470	80456	92045V	PARTICIPANT	\N	PRESENT	0
88380	88358	98035U	PARTICIPANT	\N	PRESENT	0
88381	88358	04056J	PARTICIPANT	\N	PRESENT	0
88382	88358	04044E	PRESIDENT	0	PRESENT	0
88383	88358	11037K	PARTICIPANT	\N	PRESENT	0
82339	78333	01008M	PARTICIPANT	\N	PRESENT	0
87237	87186	14026U	PARTICIPANT	\N	PRESENT	0
87238	87186	04077P	PARTICIPANT	\N	PRESENT	0
87239	87186	04074L	PARTICIPANT	\N	PRESENT	0
87240	87186	11025F	PARTICIPANT	\N	PRESENT	0
87241	87186	14105F	PARTICIPANT	\N	PRESENT	0
87242	87186	14247U	PARTICIPANT	\N	PRESENT	0
87243	87186	14201E	PARTICIPANT	\N	PRESENT	0
87244	87186	08017T	PARTICIPANT	\N	PRESENT	0
87235	87186	86034E	PARTICIPANT	\N	PRESENT	0
87236	87186	14223L	PARTICIPANT	\N	PRESENT	0
87245	87186	11091R	PARTICIPANT	\N	PRESENT	0
87246	87186	99004R	PARTICIPANT	\N	PRESENT	0
87247	87186	04036E	PARTICIPANT	\N	PRESENT	0
87248	87186	11012A	PARTICIPANT	\N	PRESENT	0
87249	87186	14259Y	PARTICIPANT	\N	PRESENT	0
87250	87186	11106F	PARTICIPANT	\N	PRESENT	0
87251	87186	14227Q	PARTICIPANT	\N	PRESENT	0
87255	87186	80013X	PARTICIPANT	\N	PRESENT	0
87253	87186	11035H	PARTICIPANT	\N	PRESENT	0
87254	87186	14277B	PARTICIPANT	\N	PRESENT	0
87256	87186	14042U	PARTICIPANT	\N	PRESENT	0
87257	87186	14030Q	PARTICIPANT	\N	PRESENT	0
87258	87186	09001P	PARTICIPANT	\N	PRESENT	0
87259	87186	01019Q	PARTICIPANT	\N	PRESENT	0
87260	87186	11043H	PARTICIPANT	\N	PRESENT	0
87261	87186	95031C	PARTICIPANT	\N	PRESENT	0
87262	87186	14133K	PARTICIPANT	\N	PRESENT	0
87263	87186	95041E	PARTICIPANT	\N	PRESENT	0
87264	87186	14213J	PARTICIPANT	\N	PRESENT	0
87265	87186	11107G	PARTICIPANT	\N	PRESENT	0
89257	87175	14053L	PARTICIPANT	\N	EXCUSE	0
87267	87186	08025T	PARTICIPANT	\N	PRESENT	0
87268	87186	14107H	PARTICIPANT	\N	PRESENT	0
87269	87186	00003C	PARTICIPANT	\N	PRESENT	0
87270	87186	98050T	PARTICIPANT	\N	PRESENT	0
87271	87186	08052W	PARTICIPANT	\N	PRESENT	0
87272	87186	08048B	PARTICIPANT	\N	PRESENT	0
87273	87186	11029K	PARTICIPANT	\N	PRESENT	0
87274	87186	11080N	PARTICIPANT	\N	PRESENT	0
87275	87186	14039A	PARTICIPANT	\N	PRESENT	0
87276	87186	14261S	PARTICIPANT	\N	PRESENT	0
87277	87186	14111D	PARTICIPANT	\N	PRESENT	0
87278	87186	11093T	PARTICIPANT	\N	PRESENT	0
87279	87186	14217N	PARTICIPANT	\N	PRESENT	0
87280	87186	14033T	PARTICIPANT	\N	PRESENT	0
87281	87186	14231L	PARTICIPANT	\N	PRESENT	0
89258	87176	14053L	PARTICIPANT	\N	EXCUSE	0
89264	89263	14111D	PARTICIPANT	\N	PRESENT	0
90412	87176	11023D	PARTICIPANT	\N	EXCUSE	0
89314	89312	01031L	PRESIDENT	0	PRESENT	0
90440	87176	95062K	PARTICIPANT	\N	EXCUSE	0
90681	90648	14159V	PARTICIPANT	\N	PRESENT	0
90698	89310	01007L	PARTICIPANT	\N	PRESENT	0
89318	89312	11040E	PARTICIPANT	\N	PRESENT	0
90700	90699	01008M	PARTICIPANT	\N	PRESENT	0
90684	90648	08010L	PARTICIPANT	\N	PRESENT	0
89321	89312	14175V	PARTICIPANT	\N	EXCUSE	0
89322	89312	14083S	PARTICIPANT	\N	PRESENT	0
90701	90699	11036J	PARTICIPANT	\N	PRESENT	0
90686	90648	01048V	PARTICIPANT	\N	PRESENT	0
90687	90648	98046X	PARTICIPANT	\N	PRESENT	0
90702	90699	11081P	PARTICIPANT	\N	PRESENT	0
89327	89312	04086Q	PARTICIPANT	\N	PRESENT	0
89328	89312	04055H	PARTICIPANT	\N	EXCUSE	0
90689	90648	08011M	PARTICIPANT	\N	EXCUSE	0
90739	89310	01044R	PARTICIPANT	\N	PRESENT	0
90691	90648	08061X	PARTICIPANT	\N	PRESENT	0
90704	90699	08068F	PARTICIPANT	\N	PRESENT	0
89333	89312	01027Q	PARTICIPANT	\N	PRESENT	0
89334	89312	04071H	PARTICIPANT	\N	PRESENT	0
90693	90648	14225N	PARTICIPANT	\N	PRESENT	0
90705	90699	14207L	PARTICIPANT	\N	PRESENT	0
89337	89312	11083R	PARTICIPANT	\N	PRESENT	0
90695	90648	11057P	PARTICIPANT	\N	PRESENT	0
90706	90699	11101A	PARTICIPANT	\N	PRESENT	0
90697	90648	04034C	PARTICIPANT	\N	PRESENT	0
90707	90699	90003B	PARTICIPANT	\N	PRESENT	0
89342	89312	11048N	PARTICIPANT	\N	PRESENT	0
89343	89312	99004R	PARTICIPANT	\N	PRESENT	0
90708	90699	08028W	PARTICIPANT	\N	PRESENT	0
89345	89312	14159V	PARTICIPANT	\N	PRESENT	0
89346	89312	07029T	PARTICIPANT	\N	PRESENT	0
90709	90699	80013X	PARTICIPANT	\N	PRESENT	0
89348	89312	08010L	PARTICIPANT	\N	PRESENT	0
90710	90699	08038Y	PARTICIPANT	\N	PRESENT	0
89350	89312	01048V	PARTICIPANT	\N	PRESENT	0
89351	89312	98046X	PARTICIPANT	\N	PRESENT	0
90711	90699	04089T	PARTICIPANT	\N	PRESENT	0
89353	89312	08011M	PARTICIPANT	\N	PRESENT	0
90712	90699	14197C	PARTICIPANT	\N	PRESENT	0
90740	89310	13002U	PARTICIPANT	\N	PRESENT	0
89356	89312	01016M	PARTICIPANT	\N	EXCUSE	0
89357	89312	14225N	PARTICIPANT	\N	PRESENT	0
90714	90699	14187A	PARTICIPANT	\N	PRESENT	0
90715	90699	14033T	PARTICIPANT	\N	PRESENT	0
89360	89312	14173T	PARTICIPANT	\N	PRESENT	0
89361	89312	04034C	PARTICIPANT	\N	PRESENT	0
90741	89310	11109J	PARTICIPANT	\N	PRESENT	0
90742	89310	11043H	PARTICIPANT	\N	PRESENT	0
90718	90699	11099A	PARTICIPANT	\N	PRESENT	0
90719	90699	04049K	PARTICIPANT	\N	PRESENT	0
90743	89310	01015L	PARTICIPANT	\N	PRESENT	0
90721	90699	11111C	PARTICIPANT	\N	PRESENT	0
90722	90699	08015R	PARTICIPANT	\N	PRESENT	0
90723	90699	11100Y	PRESIDENT	0	PRESENT	0
90744	89310	14167V	PARTICIPANT	\N	PRESENT	0
90725	90699	11098Y	PARTICIPANT	\N	PRESENT	0
90726	90699	01043Q	PARTICIPANT	\N	PRESENT	0
90727	90699	11077T	PARTICIPANT	\N	PRESENT	0
90749	90699	14013P	PARTICIPANT	\N	EXCUSE	0
90729	90699	08019V	PARTICIPANT	\N	PRESENT	0
90730	90699	14257W	PARTICIPANT	\N	PRESENT	0
90731	90699	08021P	PARTICIPANT	\N	PRESENT	0
90732	90699	04088S	PARTICIPANT	\N	PRESENT	0
90733	90699	98050T	PARTICIPANT	\N	PRESENT	0
90734	90699	11090Q	PARTICIPANT	\N	PRESENT	0
90735	90699	11046L	PARTICIPANT	\N	PRESENT	0
90736	90699	01058X	PARTICIPANT	\N	PRESENT	0
90751	90699	11094U	PARTICIPANT	\N	EXCUSE	0
90738	90699	11066Q	PARTICIPANT	\N	PRESENT	0
90745	89310	04089T	PARTICIPANT	\N	PRESENT	0
90746	89310	14207L	PARTICIPANT	\N	PRESENT	0
90747	89310	14093U	PARTICIPANT	\N	PRESENT	0
90748	89310	08009T	PARTICIPANT	\N	PRESENT	0
90750	90699	01061S	PARTICIPANT	\N	EXCUSE	0
90752	89310	11099A	PARTICIPANT	\N	PRESENT	0
90753	89310	11107G	PARTICIPANT	\N	PRESENT	0
90754	89310	08061X	PARTICIPANT	\N	PRESENT	0
90755	89310	01060R	PARTICIPANT	\N	PRESENT	0
90756	89310	08019V	PARTICIPANT	\N	PRESENT	0
90757	89310	11049P	PARTICIPANT	\N	PRESENT	0
90758	89310	04041B	PARTICIPANT	\N	PRESENT	0
90759	90648	07029T	PARTICIPANT	\N	PRESENT	0
90760	89310	14033T	PARTICIPANT	\N	PRESENT	0
90761	89310	11065P	PARTICIPANT	\N	PRESENT	0
90762	89310	08042U	PARTICIPANT	\N	PRESENT	0
90763	89310	14103D	PARTICIPANT	\N	PRESENT	0
90765	90764	01008M	PARTICIPANT	\N	PRESENT	0
90766	90764	11036J	PARTICIPANT	\N	PRESENT	0
90767	90764	11081P	PARTICIPANT	\N	PRESENT	0
90768	90764	14013P	PARTICIPANT	\N	EXCUSE	0
90769	90764	08068F	PARTICIPANT	\N	PRESENT	0
90770	90764	14207L	PARTICIPANT	\N	PRESENT	0
90771	90764	11101A	PARTICIPANT	\N	PRESENT	0
90772	90764	90003B	PARTICIPANT	\N	PRESENT	0
90773	90764	08028W	PARTICIPANT	\N	PRESENT	0
90774	90764	80013X	PARTICIPANT	\N	PRESENT	0
90775	90764	08038Y	PARTICIPANT	\N	PRESENT	0
90776	90764	04089T	PARTICIPANT	\N	PRESENT	0
90777	90764	14197C	PARTICIPANT	\N	PRESENT	0
90779	90764	14187A	PARTICIPANT	\N	PRESENT	0
90780	90764	14033T	PARTICIPANT	\N	PRESENT	0
90783	90764	11099A	PARTICIPANT	\N	PRESENT	0
90784	90764	04049K	PARTICIPANT	\N	PRESENT	0
90786	90764	11111C	PARTICIPANT	\N	PRESENT	0
90787	90764	08015R	PARTICIPANT	\N	PRESENT	0
90788	90764	11100Y	PRESIDENT	0	PRESENT	0
90789	90764	01061S	PARTICIPANT	\N	EXCUSE	0
90790	90764	11098Y	PARTICIPANT	\N	PRESENT	0
90791	90764	01043Q	PARTICIPANT	\N	PRESENT	0
90792	90764	11077T	PARTICIPANT	\N	PRESENT	0
90794	90764	08019V	PARTICIPANT	\N	PRESENT	0
90795	90764	14257W	PARTICIPANT	\N	PRESENT	0
63842	63841	08009T	PARTICIPANT	\N	PRESENT	0
63843	63841	92031P	PARTICIPANT	\N	PRESENT	0
63844	63841	11049P	PARTICIPANT	\N	PRESENT	0
63849	60592	11023D	PARTICIPANT	\N	EXCUSE	0
63850	60592	14034U	PARTICIPANT	\N	EXCUSE	0
63851	60592	11010L	PARTICIPANT	\N	EXCUSE	0
65096	65094	04043D	PARTICIPANT	\N	PRESENT	0
65097	65094	11036J	PARTICIPANT	\N	PRESENT	0
65102	65094	11046L	PARTICIPANT	\N	PRESENT	0
65100	65094	01037S	PARTICIPANT	\N	PRESENT	0
65101	65094	07024N	PARTICIPANT	\N	PRESENT	0
65103	65094	08053X	PARTICIPANT	\N	PRESENT	0
65104	65094	14209N	PARTICIPANT	\N	PRESENT	0
65151	65150	11036J	PARTICIPANT	\N	PRESENT	0
65152	65150	11033F	PARTICIPANT	\N	PRESENT	0
65153	65150	14030Q	PARTICIPANT	\N	PRESENT	0
65154	65150	08043V	PARTICIPANT	\N	PRESENT	0
65155	65150	14053L	PARTICIPANT	\N	PRESENT	0
65156	65150	11031D	PARTICIPANT	\N	PRESENT	0
65157	65150	80013X	PARTICIPANT	\N	PRESENT	0
65158	65150	10006L	PARTICIPANT	\N	PRESENT	0
65159	65150	14041T	PARTICIPANT	\N	PRESENT	0
65160	65150	14042U	PARTICIPANT	\N	PRESENT	0
65161	65150	14087W	PARTICIPANT	\N	PRESENT	0
65162	65150	97011G	PARTICIPANT	\N	PRESENT	0
65163	65150	11061K	PARTICIPANT	\N	PRESENT	0
65164	65150	08041T	PARTICIPANT	\N	PRESENT	0
65165	65150	01011G	PARTICIPANT	\N	PRESENT	0
65166	65150	07026Q	PARTICIPANT	\N	PRESENT	0
65167	65150	95035G	PRESIDENT	0	PRESENT	0
65168	65150	14026U	PARTICIPANT	\N	PRESENT	0
65169	65150	09001P	PARTICIPANT	\N	PRESENT	0
65170	65150	08017T	PARTICIPANT	\N	PRESENT	0
65171	65150	04079R	PARTICIPANT	\N	PRESENT	0
65172	65150	11067R	PARTICIPANT	\N	PRESENT	0
65173	65150	14223L	PARTICIPANT	\N	PRESENT	0
65174	65150	11012A	PARTICIPANT	\N	PRESENT	0
65175	65150	04044E	PARTICIPANT	\N	PRESENT	0
65176	65150	95067Q	PARTICIPANT	\N	EXCUSE	0
70083	70082	07004J	PARTICIPANT	\N	PRESENT	0
70084	70082	10015M	PARTICIPANT	\N	PRESENT	0
70085	70082	14041T	PARTICIPANT	\N	PRESENT	0
71587	71510	11036J	PARTICIPANT	\N	PRESENT	0
71588	71510	11033F	PARTICIPANT	\N	PRESENT	0
71589	71510	14065Q	PARTICIPANT	\N	PRESENT	0
71590	71510	14030Q	PARTICIPANT	\N	PRESENT	0
71591	71510	08043V	PARTICIPANT	\N	PRESENT	0
71592	71510	11031D	PARTICIPANT	\N	PRESENT	0
71593	71510	80013X	PARTICIPANT	\N	PRESENT	0
71594	71510	10006L	PARTICIPANT	\N	PRESENT	0
71595	71510	14041T	PARTICIPANT	\N	PRESENT	0
71596	71510	97011G	PARTICIPANT	\N	PRESENT	0
71597	71510	11061K	PARTICIPANT	\N	PRESENT	0
71598	71510	14014Q	PARTICIPANT	\N	PRESENT	0
71599	71510	08041T	PARTICIPANT	\N	PRESENT	0
71600	71510	01011G	PARTICIPANT	\N	PRESENT	0
71601	71510	07026Q	PARTICIPANT	\N	PRESENT	0
71602	71510	95035G	PRESIDENT	0	PRESENT	0
71603	71510	14026U	PARTICIPANT	\N	PRESENT	0
71604	71510	09001P	PARTICIPANT	\N	PRESENT	0
71605	71510	11067R	PARTICIPANT	\N	PRESENT	0
71606	71510	04092N	PARTICIPANT	\N	PRESENT	0
71607	71510	11012A	PARTICIPANT	\N	PRESENT	0
71608	71510	11093T	PARTICIPANT	\N	PRESENT	0
71609	71510	04044E	PARTICIPANT	\N	PRESENT	0
71610	71510	14053L	PARTICIPANT	\N	EXCUSE	0
71611	71510	08044W	PARTICIPANT	\N	EXCUSE	0
71612	71510	11043H	PARTICIPANT	\N	EXCUSE	0
71613	71510	95067Q	PARTICIPANT	\N	EXCUSE	0
71633	71632	04086Q	PARTICIPANT	\N	PRESENT	0
71634	71632	08009T	PARTICIPANT	\N	PRESENT	0
71638	71632	01014K	PARTICIPANT	\N	PRESENT	0
71636	71632	08039A	PARTICIPANT	\N	PRESENT	0
71637	71632	08069G	PARTICIPANT	\N	PRESENT	0
71639	71632	01037S	PARTICIPANT	\N	PRESENT	0
71640	71632	04035D	PARTICIPANT	\N	PRESENT	0
71641	71632	11106F	PARTICIPANT	\N	PRESENT	0
71642	71632	11026G	PARTICIPANT	\N	PRESENT	0
71965	69422	08038Y	PARTICIPANT	\N	PRESENT	0
71644	71632	04040A	PARTICIPANT	\N	PRESENT	0
71645	71632	14223L	PARTICIPANT	\N	PRESENT	0
71646	71632	10015M	PARTICIPANT	\N	PRESENT	0
71647	71632	99004R	PARTICIPANT	\N	PRESENT	0
71648	71632	11049P	PARTICIPANT	\N	PRESENT	0
71649	71632	04079R	PARTICIPANT	\N	PRESENT	0
71650	71632	14225N	PARTICIPANT	\N	PRESENT	0
71651	71632	98035U	PARTICIPANT	\N	PRESENT	0
71652	71632	10006L	PARTICIPANT	\N	PRESENT	0
71653	71632	11012A	PARTICIPANT	\N	PRESENT	0
71964	69422	05012A	PARTICIPANT	\N	PRESENT	0
71967	69422	11101A	PARTICIPANT	\N	PRESENT	0
71968	69422	14231L	PARTICIPANT	\N	PRESENT	0
77574	77573	07004J	PARTICIPANT	\N	PRESENT	0
77575	77573	10015M	PARTICIPANT	\N	PRESENT	0
77577	77576	07004J	PARTICIPANT	\N	PRESENT	0
78854	78785	01047U	PARTICIPANT	\N	PRESENT	0
78855	78785	08012N	RAPPORTEUR_AVIS	\N	PRESENT	0
80115	80114	08055A	PARTICIPANT	\N	PRESENT	0
80116	80114	14093U	PARTICIPANT	\N	PRESENT	0
80117	80114	14105F	PARTICIPANT	\N	PRESENT	0
80118	80114	14207L	PARTICIPANT	\N	PRESENT	0
80119	80114	90003B	PARTICIPANT	\N	PRESENT	0
80120	80114	88008L	PARTICIPANT	\N	PRESENT	0
80121	80114	01024M	PARTICIPANT	\N	PRESENT	0
80122	80114	87003B	PARTICIPANT	\N	PRESENT	0
80123	80114	01025N	PARTICIPANT	\N	PRESENT	0
80124	80114	04041B	PARTICIPANT	\N	PRESENT	0
80125	80114	14097Y	PARTICIPANT	\N	PRESENT	0
80126	80114	14061L	PARTICIPANT	\N	PRESENT	0
80127	80114	04049K	PARTICIPANT	\N	PRESENT	0
80128	80114	08015R	PARTICIPANT	\N	PRESENT	0
80129	80114	01061S	PARTICIPANT	\N	PRESENT	0
80130	80114	11098Y	PARTICIPANT	\N	PRESENT	0
80131	80114	80027E	PARTICIPANT	\N	PRESENT	0
80132	80114	04092N	PARTICIPANT	\N	PRESENT	0
80133	80114	14109K	PARTICIPANT	\N	PRESENT	0
80134	80114	14257W	PARTICIPANT	\N	PRESENT	0
80135	80114	08061X	PARTICIPANT	\N	PRESENT	0
80136	80114	11097X	PARTICIPANT	\N	PRESENT	0
80137	80114	11094U	PARTICIPANT	\N	PRESENT	0
80138	80114	95037J	PARTICIPANT	\N	PRESENT	0
80150	80149	08009T	PARTICIPANT	\N	PRESENT	0
80151	80149	14169X	PARTICIPANT	\N	PRESENT	0
80152	80149	14219Q	PARTICIPANT	\N	PRESENT	0
80153	80149	11059R	PARTICIPANT	\N	PRESENT	0
80154	80149	11107G	PARTICIPANT	\N	PRESENT	0
80155	80149	08060W	PARTICIPANT	\N	PRESENT	0
80210	80209	04086Q	PARTICIPANT	\N	PRESENT	0
80212	80211	04086Q	PARTICIPANT	\N	PRESENT	0
80214	80213	04086Q	PARTICIPANT	\N	PRESENT	0
80216	80215	08011M	PARTICIPANT	\N	PRESENT	0
80410	80409	04034C	PARTICIPANT	\N	PRESENT	0
80412	80411	04034C	PARTICIPANT	\N	PRESENT	0
83917	83916	11068S	PARTICIPANT	\N	PRESENT	0
83992	83892	11023D	PARTICIPANT	\N	EXCUSE	0
84086	84085	14030Q	PARTICIPANT	\N	PRESENT	0
84088	84087	14030Q	PARTICIPANT	\N	PRESENT	0
84278	84154	86034E	PARTICIPANT	\N	PRESENT	0
84280	84154	14013P	PARTICIPANT	\N	PRESENT	0
84281	84154	07026Q	PARTICIPANT	\N	PRESENT	0
84282	84154	14235Q	PARTICIPANT	\N	PRESENT	0
84283	84154	14197C	PARTICIPANT	\N	PRESENT	0
84284	84154	80013X	PARTICIPANT	\N	PRESENT	0
84285	84154	11066Q	PARTICIPANT	\N	PRESENT	0
84286	84154	11037K	PARTICIPANT	\N	PRESENT	0
84287	84154	14179A	PARTICIPANT	\N	PRESENT	0
84288	84154	14217N	PARTICIPANT	\N	PRESENT	0
84279	84154	11040E	PARTICIPANT	\N	PRESENT	0
84289	84154	04048J	PARTICIPANT	\N	PRESENT	0
84290	84154	04033B	PARTICIPANT	\N	PRESENT	0
84291	84154	04086Q	PARTICIPANT	\N	PRESENT	0
84292	84154	04053F	PARTICIPANT	\N	PRESENT	0
84293	84154	87003B	PARTICIPANT	\N	PRESENT	0
84294	84154	11101A	PARTICIPANT	\N	PRESENT	0
84295	84154	14267Y	PARTICIPANT	\N	PRESENT	0
84296	84154	08009T	PARTICIPANT	\N	PRESENT	0
84297	84154	11063M	PARTICIPANT	\N	PRESENT	0
84298	84154	08018U	PARTICIPANT	\N	PRESENT	0
84299	84154	02002K	PARTICIPANT	\N	PRESENT	0
84300	84154	11026G	PARTICIPANT	\N	PRESENT	0
84301	84154	04088S	PARTICIPANT	\N	PRESENT	0
84302	84154	14105F	PARTICIPANT	\N	PRESENT	0
84303	84154	01058X	PARTICIPANT	\N	PRESENT	0
84304	84154	08031R	PARTICIPANT	\N	PRESENT	0
84305	84154	04057K	PARTICIPANT	\N	PRESENT	0
84306	84154	14147R	PARTICIPANT	\N	PRESENT	0
84307	84154	05008E	PARTICIPANT	\N	PRESENT	0
84308	84154	11029K	PARTICIPANT	\N	PRESENT	0
88384	88358	92045V	PARTICIPANT	\N	PRESENT	0
88493	88492	10015M	PARTICIPANT	\N	PRESENT	0
88495	88494	10015M	PARTICIPANT	\N	PRESENT	0
88602	88601	07034Q	PARTICIPANT	\N	PRESENT	0
88702	88644	08039A	PARTICIPANT	\N	PRESENT	0
88646	88644	14133K	PARTICIPANT	\N	PRESENT	0
88647	88644	11109J	PARTICIPANT	\N	PRESENT	0
88936	88935	89017R	PARTICIPANT	\N	PRESENT	0
88937	88935	01031L	PRESIDENT	0	PRESENT	0
88938	88935	11068S	PARTICIPANT	\N	PRESENT	0
88939	88935	11040E	PARTICIPANT	\N	PRESENT	0
88652	88644	14089Y	PARTICIPANT	\N	PRESENT	0
88653	88644	14105F	PARTICIPANT	\N	PRESENT	0
88654	88644	11029K	PARTICIPANT	\N	PRESENT	0
88655	88644	95015C	PARTICIPANT	\N	PRESENT	0
88656	88644	92015P	PARTICIPANT	\N	EXCUSE	0
88657	88644	08024S	PARTICIPANT	\N	PRESENT	0
88658	88644	14201E	PARTICIPANT	\N	EXCUSE	0
88940	88935	08014Q	PARTICIPANT	\N	PRESENT	0
88942	88935	14167V	PARTICIPANT	\N	PRESENT	0
88661	88644	14079W	PARTICIPANT	\N	PRESENT	0
88662	88644	11091R	PARTICIPANT	\N	PRESENT	0
88663	88644	87003B	PARTICIPANT	\N	PRESENT	0
88943	88935	14175V	PARTICIPANT	\N	PRESENT	0
88944	88935	11042G	PARTICIPANT	\N	PRESENT	0
88666	88644	01041N	PARTICIPANT	\N	PRESENT	0
88946	88935	88008L	PARTICIPANT	\N	PRESENT	0
88668	88644	01037S	PARTICIPANT	\N	PRESENT	0
88953	88935	04086Q	PARTICIPANT	\N	PRESENT	0
88670	88644	08035V	PARTICIPANT	\N	PRESENT	0
88954	88935	04055H	PARTICIPANT	\N	EXCUSE	0
88672	88644	07026Q	PARTICIPANT	\N	PRESENT	0
88673	88644	14123H	PARTICIPANT	\N	PRESENT	0
88674	88644	14179A	PARTICIPANT	\N	PRESENT	0
88955	88935	11070L	PARTICIPANT	\N	PRESENT	0
88676	88644	14241N	PARTICIPANT	\N	PRESENT	0
88677	88644	14061L	PARTICIPANT	\N	PRESENT	0
88956	88935	11088W	PARTICIPANT	\N	PRESENT	0
88679	88644	08031R	PARTICIPANT	\N	PRESENT	0
88957	88935	01027Q	PARTICIPANT	\N	PRESENT	0
88958	88935	04071H	PARTICIPANT	\N	PRESENT	0
88682	88644	08017T	PARTICIPANT	\N	PRESENT	0
88683	88644	14059S	PARTICIPANT	\N	PRESENT	0
88684	88644	08012N	PARTICIPANT	\N	PRESENT	0
88685	88644	14103D	PARTICIPANT	\N	PRESENT	0
88686	88644	11104D	PARTICIPANT	\N	PRESENT	0
88687	88644	14063N	PARTICIPANT	\N	PRESENT	0
88688	88644	04057K	PARTICIPANT	\N	PRESENT	0
88959	88935	11074Q	PARTICIPANT	\N	PRESENT	0
88690	88644	14109K	PARTICIPANT	\N	PRESENT	0
88691	88644	04070G	PRESIDENT	0	PRESENT	0
88960	88935	11083R	PARTICIPANT	\N	PRESENT	0
88961	88935	11048N	PARTICIPANT	\N	PRESENT	0
88694	88644	83047W	PARTICIPANT	\N	PRESENT	0
88695	88644	14235Q	PARTICIPANT	\N	PRESENT	0
88962	88935	04061F	PARTICIPANT	\N	PRESENT	0
88963	88935	14159V	PARTICIPANT	\N	PRESENT	0
88964	88935	07029T	PARTICIPANT	\N	PRESENT	0
88699	88644	11043H	PARTICIPANT	\N	PRESENT	0
88965	88935	14277B	PARTICIPANT	\N	PRESENT	0
88966	88935	98046X	PARTICIPANT	\N	PRESENT	0
88967	88935	11085T	PARTICIPANT	\N	EXCUSE	0
88968	88935	08011M	PARTICIPANT	\N	PRESENT	0
88970	88935	08061X	PARTICIPANT	\N	PRESENT	0
88972	88935	04034C	PARTICIPANT	\N	PRESENT	0
88973	88935	14173T	PARTICIPANT	\N	PRESENT	0
88974	88935	01016M	PARTICIPANT	\N	PRESENT	0
88975	88935	11057P	PARTICIPANT	\N	PRESENT	0
88976	88935	11012A	PARTICIPANT	\N	PRESENT	0
88977	88935	14225N	PARTICIPANT	\N	PRESENT	0
89062	89061	89017R	PARTICIPANT	\N	PRESENT	0
89076	89075	14083S	PARTICIPANT	\N	PRESENT	0
89081	89080	14239U	PARTICIPANT	\N	PRESENT	0
89082	89080	14065Q	PARTICIPANT	\N	PRESENT	0
89083	89080	14089Y	PARTICIPANT	\N	PRESENT	0
89097	89080	14217N	PARTICIPANT	\N	PRESENT	0
89115	89080	92020L	PARTICIPANT	\N	PRESENT	0
89116	89080	14281W	PRESIDENT	0	PRESENT	0
89117	89080	08041T	PARTICIPANT	\N	PRESENT	0
89118	89080	07004J	PARTICIPANT	\N	PRESENT	0
89120	89080	04061F	PARTICIPANT	\N	PRESENT	0
89121	89080	08053X	PARTICIPANT	\N	PRESENT	0
89122	89080	10015M	PARTICIPANT	\N	PRESENT	0
89123	89080	11037K	PARTICIPANT	\N	PRESENT	0
89124	89080	14269B	PARTICIPANT	\N	PRESENT	0
89141	89140	92039X	PARTICIPANT	\N	PRESENT	0
89142	89140	11100Y	PARTICIPANT	\N	PRESENT	0
89143	89140	04036E	PARTICIPANT	\N	PRESENT	0
89144	89140	04035D	PARTICIPANT	\N	PRESENT	0
89145	89140	14041T	PARTICIPANT	\N	PRESENT	0
89146	89140	08018U	PARTICIPANT	\N	PRESENT	0
89147	89140	08056B	PARTICIPANT	\N	PRESENT	0
89148	89140	14028W	PARTICIPANT	\N	PRESENT	0
89149	89140	98035U	PARTICIPANT	\N	PRESENT	0
89150	89140	11012A	PARTICIPANT	\N	PRESENT	0
89151	89140	88008L	PARTICIPANT	\N	PRESENT	0
89152	89140	14199E	PARTICIPANT	\N	PRESENT	0
89154	89153	95015C	PARTICIPANT	\N	PRESENT	0
89155	89153	14179A	PARTICIPANT	\N	PRESENT	0
89156	89153	14237S	PARTICIPANT	\N	PRESENT	0
89159	89158	95015C	PARTICIPANT	\N	PRESENT	0
89161	89158	14179A	PARTICIPANT	\N	PRESENT	0
89165	89164	04077P	PARTICIPANT	\N	PRESENT	0
89167	89166	11039M	PARTICIPANT	\N	PRESENT	0
89168	89166	98042T	PARTICIPANT	\N	PRESENT	0
89169	89166	01019Q	PARTICIPANT	\N	PRESENT	0
89171	89170	11039M	PARTICIPANT	\N	PRESENT	0
89172	89170	98042T	PARTICIPANT	\N	PRESENT	0
89173	89170	01019Q	PARTICIPANT	\N	PRESENT	0
89303	89302	14195A	PARTICIPANT	\N	PRESENT	0
89368	89362	11105E	PARTICIPANT	\N	PRESENT	0
89369	89362	08035V	PARTICIPANT	\N	PRESENT	0
89370	89362	08038Y	PARTICIPANT	\N	PRESENT	0
89383	87176	11106F	PARTICIPANT	\N	EXCUSE	0
90059	90027	14241N	PARTICIPANT	\N	PRESENT	0
90060	90027	14061L	PARTICIPANT	\N	PRESENT	0
89507	89504	14093U	PARTICIPANT	\N	PRESENT	0
89508	89504	14030Q	PARTICIPANT	\N	PRESENT	0
89509	89504	96004D	PARTICIPANT	\N	PRESENT	0
89510	89504	08060W	PARTICIPANT	\N	PRESENT	0
90061	90027	14073Q	PARTICIPANT	\N	PRESENT	0
89512	89504	14038Y	PARTICIPANT	\N	PRESENT	0
89513	89504	11114F	PARTICIPANT	\N	PRESENT	0
90062	90027	08031R	PARTICIPANT	\N	PRESENT	0
89515	89504	11065P	PARTICIPANT	\N	PRESENT	0
89516	89504	01015L	PARTICIPANT	\N	PRESENT	0
89517	89504	11107G	PARTICIPANT	\N	PRESENT	0
90064	90027	08039A	PARTICIPANT	\N	PRESENT	0
89520	89504	01022K	PARTICIPANT	\N	PRESENT	0
90065	90027	08017T	PARTICIPANT	\N	PRESENT	0
89522	89504	09001P	PARTICIPANT	\N	PRESENT	0
89523	89504	11059R	PARTICIPANT	\N	PRESENT	0
89524	89504	14219Q	PARTICIPANT	\N	PRESENT	0
89525	89504	80027E	PARTICIPANT	\N	PRESENT	0
89526	89504	14031R	PARTICIPANT	\N	PRESENT	0
89527	89504	08009T	PRESIDENT	0	PRESENT	0
90066	90027	14059S	PARTICIPANT	\N	PRESENT	0
89529	89504	14221J	PARTICIPANT	\N	PRESENT	0
89530	89504	92039X	PARTICIPANT	\N	PRESENT	0
89532	89504	14169X	PARTICIPANT	\N	PRESENT	0
89533	89504	14237S	PARTICIPANT	\N	PRESENT	0
89534	89504	13002U	PARTICIPANT	\N	PRESENT	0
89535	89504	05012A	PARTICIPANT	\N	PRESENT	0
90068	90027	14103D	PARTICIPANT	\N	PRESENT	0
89537	89504	14135M	PARTICIPANT	\N	PRESENT	0
89538	89504	14331P	PARTICIPANT	\N	PRESENT	0
89539	89504	95062K	PARTICIPANT	\N	PRESENT	0
89540	89504	14107H	PARTICIPANT	\N	PRESENT	0
89541	89504	14051J	PARTICIPANT	\N	PRESENT	0
89542	89504	14157T	PARTICIPANT	\N	PRESENT	0
89543	89504	96003C	PARTICIPANT	\N	EXCUSE	0
90070	90027	14063N	PARTICIPANT	\N	PRESENT	0
90071	90027	04057K	PARTICIPANT	\N	PRESENT	0
90072	90027	11014C	PARTICIPANT	\N	PRESENT	0
90073	90027	14109K	PARTICIPANT	\N	PRESENT	0
90074	90027	04070G	PRESIDENT	0	PRESENT	0
90075	90027	92040Q	PARTICIPANT	\N	PRESENT	0
90078	90027	14235Q	PARTICIPANT	\N	PRESENT	0
90080	90027	04033B	PARTICIPANT	\N	PRESENT	0
90081	90027	14229S	PARTICIPANT	\N	PRESENT	0
65108	63782	01046T	PARTICIPANT	\N	EXCUSE	0
65109	63782	11036J	PARTICIPANT	\N	PRESENT	0
65110	63782	11068S	PARTICIPANT	\N	EXCUSE	0
65111	63782	01044R	PARTICIPANT	\N	EXCUSE	0
65112	63782	14209N	PARTICIPANT	\N	EXCUSE	0
65113	63782	11089X	PARTICIPANT	\N	PRESENT	0
65114	63782	80013X	PARTICIPANT	\N	EXCUSE	0
65115	63782	04061F	PARTICIPANT	\N	EXCUSE	0
65116	63782	08039A	PARTICIPANT	\N	EXCUSE	0
65117	63782	83042R	PARTICIPANT	\N	EXCUSE	0
65118	63782	14221J	PARTICIPANT	\N	EXCUSE	0
65119	63782	01058X	PARTICIPANT	\N	EXCUSE	0
65120	63782	04043D	PARTICIPANT	\N	EXCUSE	0
65178	63999	14259Y	PARTICIPANT	\N	PRESENT	0
71991	71990	07004J	PARTICIPANT	\N	PRESENT	0
71992	71990	10015M	PARTICIPANT	\N	PRESENT	0
78498	78497	89017R	PARTICIPANT	\N	PRESENT	0
78499	78497	01031L	PRESIDENT	0	PRESENT	0
78500	78497	01013J	PARTICIPANT	\N	PRESENT	0
78501	78497	14175V	PARTICIPANT	\N	PRESENT	0
78502	78497	14083S	PARTICIPANT	\N	PRESENT	0
78503	78497	11053K	PARTICIPANT	\N	PRESENT	0
78504	78497	11042G	PARTICIPANT	\N	PRESENT	0
78505	78497	88008L	PARTICIPANT	\N	PRESENT	0
78506	78497	04086Q	PARTICIPANT	\N	PRESENT	0
78507	78497	04055H	PARTICIPANT	\N	PRESENT	0
78508	78497	11088W	PARTICIPANT	\N	PRESENT	0
78509	78497	01027Q	PARTICIPANT	\N	PRESENT	0
78510	78497	11074Q	PARTICIPANT	\N	PRESENT	0
78511	78497	11083R	PARTICIPANT	\N	PRESENT	0
78512	78497	14199E	PARTICIPANT	\N	PRESENT	0
78513	78497	01057W	PARTICIPANT	\N	PRESENT	0
78514	78497	08069G	PARTICIPANT	\N	PRESENT	0
78515	78497	99004R	PARTICIPANT	\N	PRESENT	0
78516	78497	04061F	PARTICIPANT	\N	PRESENT	0
78517	78497	14159V	PARTICIPANT	\N	PRESENT	0
78518	78497	07029T	PARTICIPANT	\N	PRESENT	0
78519	78497	08010L	PARTICIPANT	\N	PRESENT	0
78520	78497	08034U	PARTICIPANT	\N	PRESENT	0
78521	78497	98046X	PARTICIPANT	\N	PRESENT	0
78522	78497	08011M	PARTICIPANT	\N	PRESENT	0
78523	78497	08061X	PARTICIPANT	\N	PRESENT	0
78524	78497	01016M	PARTICIPANT	\N	PRESENT	0
78525	78497	14225N	PARTICIPANT	\N	PRESENT	0
78526	78497	11012A	PARTICIPANT	\N	EXCUSE	0
78527	78497	11057P	PARTICIPANT	\N	PRESENT	0
78528	78497	04034C	PARTICIPANT	\N	PRESENT	0
79203	75076	11109J	PARTICIPANT	\N	PRESENT	0
79204	75076	14259Y	PARTICIPANT	\N	PRESENT	0
79205	75076	01027Q	PARTICIPANT	\N	PRESENT	0
79206	75076	04095R	PARTICIPANT	\N	EXCUSE	0
79207	75076	14097Y	PARTICIPANT	\N	PRESENT	0
79208	75076	98005N	PARTICIPANT	\N	PRESENT	0
79209	75076	14059S	PARTICIPANT	\N	PRESENT	0
79210	75076	08019V	PRESIDENT	0	PRESENT	0
79211	75076	04043D	PARTICIPANT	\N	PRESENT	0
79212	75076	95062K	PARTICIPANT	\N	PRESENT	0
79213	75076	11054L	PARTICIPANT	\N	PRESENT	0
79221	75076	11071M	PARTICIPANT	\N	PRESENT	0
79499	79390	11048N	PARTICIPANT	\N	EXCUSE	0
79504	79390	11112D	PARTICIPANT	\N	EXCUSE	0
79505	79390	11099A	PARTICIPANT	\N	EXCUSE	0
79507	79390	04044E	PARTICIPANT	\N	EXCUSE	0
79736	79735	14037X	PARTICIPANT	\N	PRESENT	0
79738	79737	14037X	PARTICIPANT	\N	PRESENT	0
79748	79747	11039M	PARTICIPANT	\N	PRESENT	0
79749	79747	98042T	PARTICIPANT	\N	PRESENT	0
79750	79747	01019Q	PARTICIPANT	\N	PRESENT	0
80042	80041	01058X	PARTICIPANT	\N	PRESENT	0
80044	80043	01058X	PARTICIPANT	\N	PRESENT	0
80046	80045	01058X	PARTICIPANT	\N	PRESENT	0
80048	80047	01043Q	PARTICIPANT	\N	PRESENT	0
80050	80049	01043Q	PARTICIPANT	\N	PRESENT	0
80051	66832	11046L	PARTICIPANT	\N	PRESENT	0
80052	66834	11046L	PARTICIPANT	\N	PRESENT	0
80053	66836	11046L	PARTICIPANT	\N	PRESENT	0
80054	66838	11046L	PARTICIPANT	\N	PRESENT	0
80055	73574	11046L	PARTICIPANT	\N	PRESENT	0
80056	73579	11046L	PARTICIPANT	\N	PRESENT	0
80057	77716	11046L	PARTICIPANT	\N	PRESENT	0
80184	80183	04042C	PARTICIPANT	\N	PRESENT	0
80185	80183	11082Q	PARTICIPANT	\N	PRESENT	0
80186	80183	98005N	PARTICIPANT	\N	PRESENT	0
80187	80183	14028W	PARTICIPANT	\N	PRESENT	0
80189	80188	04042C	PARTICIPANT	\N	PRESENT	0
80190	80188	11082Q	PARTICIPANT	\N	PRESENT	0
80191	80188	98005N	PARTICIPANT	\N	PRESENT	0
80192	80188	01056V	PARTICIPANT	\N	PRESENT	0
80193	80188	14028W	PARTICIPANT	\N	PRESENT	0
80197	80196	04080J	PARTICIPANT	\N	PRESENT	0
80200	80199	11015D	PARTICIPANT	\N	PRESENT	0
80201	80199	92031P	PARTICIPANT	\N	PRESENT	0
80204	80202	88008L	PARTICIPANT	\N	PRESENT	0
80205	80202	04061F	PARTICIPANT	\N	PRESENT	0
80207	80206	88008L	PARTICIPANT	\N	PRESENT	0
80208	80206	04061F	PARTICIPANT	\N	PRESENT	0
80218	80217	08022Q	PARTICIPANT	\N	PRESENT	0
80219	80217	99004R	PARTICIPANT	\N	PRESENT	0
80220	80217	04061F	PARTICIPANT	\N	PRESENT	0
80221	80217	11053K	PARTICIPANT	\N	PRESENT	0
80222	80217	08061X	PARTICIPANT	\N	PRESENT	0
80223	80217	01016M	PARTICIPANT	\N	PRESENT	0
80224	80217	98053W	PARTICIPANT	\N	PRESENT	0
80225	80217	88008L	PARTICIPANT	\N	PRESENT	0
89292	89063	89029V	PARTICIPANT	\N	PRESENT	0
89293	89063	04043D	PARTICIPANT	\N	PRESENT	0
89294	89063	14111D	PARTICIPANT	\N	PRESENT	0
89295	89063	14195A	PARTICIPANT	\N	PRESENT	0
89296	89063	14263U	PARTICIPANT	\N	PRESENT	0
89297	89063	14038Y	PARTICIPANT	\N	PRESENT	0
89298	89063	08068F	PARTICIPANT	\N	PRESENT	0
89299	89063	11066Q	PARTICIPANT	\N	PRESENT	0
89300	89063	14179A	PARTICIPANT	\N	PRESENT	0
89301	89063	14083S	PARTICIPANT	\N	PRESENT	0
89304	89063	08042U	PARTICIPANT	\N	PRESENT	0
89305	89063	14026U	PARTICIPANT	\N	PRESENT	0
89306	89063	14173T	PARTICIPANT	\N	PRESENT	0
89307	89063	14042U	PARTICIPANT	\N	PRESENT	0
89308	89063	14037X	PARTICIPANT	\N	PRESENT	0
89309	89063	01027Q	PARTICIPANT	\N	PRESENT	0
89363	89063	14053L	PARTICIPANT	\N	PRESENT	0
89364	89063	04049K	PARTICIPANT	\N	PRESENT	0
89365	89063	14105F	PARTICIPANT	\N	PRESENT	0
89366	89063	12041X	PARTICIPANT	\N	PRESENT	0
89367	89063	11105E	PARTICIPANT	\N	PRESENT	0
89371	89063	01060R	PARTICIPANT	\N	PRESENT	0
89372	89063	11031D	PARTICIPANT	\N	PRESENT	0
89373	89063	11063M	PARTICIPANT	\N	PRESENT	0
89374	89063	07029T	PARTICIPANT	\N	PRESENT	0
89375	89063	08052W	PARTICIPANT	\N	PRESENT	0
89376	89063	98029W	PARTICIPANT	\N	PRESENT	0
89377	89063	04079R	PARTICIPANT	\N	PRESENT	0
89378	89063	04045F	PARTICIPANT	\N	PRESENT	0
89379	89063	14187A	PARTICIPANT	\N	PRESENT	0
89380	89063	11084S	PARTICIPANT	\N	PRESENT	0
89381	89063	14063N	PARTICIPANT	\N	PRESENT	0
89401	89066	08065C	PARTICIPANT	\N	PRESENT	0
89402	89066	14041T	PARTICIPANT	\N	PRESENT	0
89403	89066	11061K	PARTICIPANT	\N	PRESENT	0
89404	89066	14227Q	PARTICIPANT	\N	PRESENT	0
89405	89066	95063L	PARTICIPANT	\N	PRESENT	0
89406	89066	11035H	PARTICIPANT	\N	PRESENT	0
89407	89066	05008E	PARTICIPANT	\N	PRESENT	0
89399	89066	86034E	PARTICIPANT	\N	PRESENT	0
89400	89066	95049N	PARTICIPANT	\N	PRESENT	0
89408	89066	08016S	PARTICIPANT	\N	PRESENT	0
89409	89066	14225N	PARTICIPANT	\N	PRESENT	0
89410	89066	92020L	PARTICIPANT	\N	PRESENT	0
89411	89066	14030Q	PARTICIPANT	\N	PRESENT	0
89412	89066	11034G	PARTICIPANT	\N	PRESENT	0
89413	89066	01011G	PARTICIPANT	\N	PRESENT	0
89414	89066	11055M	PARTICIPANT	\N	PRESENT	0
89415	89066	11029K	PARTICIPANT	\N	PRESENT	0
89416	89066	14219Q	PARTICIPANT	\N	PRESENT	0
89417	89066	14241N	PARTICIPANT	\N	PRESENT	0
89418	89066	14097Y	PARTICIPANT	\N	PRESENT	0
89419	89066	01031L	PARTICIPANT	\N	PRESENT	0
89420	89066	08009T	PARTICIPANT	\N	PRESENT	0
89421	89066	01013J	PARTICIPANT	\N	PRESENT	0
89422	89066	11063M	PARTICIPANT	\N	PRESENT	0
89423	89066	14001X	PARTICIPANT	\N	PRESENT	0
89424	89066	08055A	PARTICIPANT	\N	PRESENT	0
89425	89066	14271U	PARTICIPANT	\N	PRESENT	0
89426	89066	04070G	PARTICIPANT	\N	PRESENT	0
89427	89066	09001P	PARTICIPANT	\N	PRESENT	0
89428	89066	14109K	PARTICIPANT	\N	PRESENT	0
89429	89066	14157T	PARTICIPANT	\N	PRESENT	0
89430	89066	14031R	PARTICIPANT	\N	PRESENT	0
89431	89066	14103D	PARTICIPANT	\N	PRESENT	0
74648	74647	01014K	PARTICIPANT	\N	PRESENT	0
74649	74647	07024N	PARTICIPANT	\N	PRESENT	0
74650	74647	11106F	PARTICIPANT	\N	PRESENT	0
74651	74647	04040A	PARTICIPANT	\N	PRESENT	0
74652	74647	14193X	PARTICIPANT	\N	PRESENT	0
74658	74657	01014K	PARTICIPANT	\N	PRESENT	0
74659	74657	07024N	PARTICIPANT	\N	PRESENT	0
74660	74657	11106F	PARTICIPANT	\N	PRESENT	0
74661	74657	04040A	PARTICIPANT	\N	PRESENT	0
74662	74657	14193X	PARTICIPANT	\N	PRESENT	0
74664	74663	01014K	PARTICIPANT	\N	PRESENT	0
74665	74663	07024N	PARTICIPANT	\N	PRESENT	0
74666	74663	11106F	PARTICIPANT	\N	PRESENT	0
74667	74663	04040A	PARTICIPANT	\N	PRESENT	0
74668	74663	14193X	PARTICIPANT	\N	PRESENT	0
74670	74669	07024N	PARTICIPANT	\N	PRESENT	0
74671	74669	01014K	PARTICIPANT	\N	PRESENT	0
75039	66880	89017R	PARTICIPANT	\N	PRESENT	0
75040	66880	11097X	PARTICIPANT	\N	PRESENT	0
84309	84154	04097T	PARTICIPANT	\N	PRESENT	0
84310	84154	01019Q	PARTICIPANT	\N	PRESENT	0
84311	84154	14209N	PARTICIPANT	\N	PRESENT	0
84312	84154	95035G	PARTICIPANT	\N	PRESENT	0
84313	84154	07029T	PARTICIPANT	\N	PRESENT	0
84314	84154	98053W	PARTICIPANT	\N	PRESENT	0
84315	84154	98042T	PARTICIPANT	\N	PRESENT	0
84316	84154	10006L	PARTICIPANT	\N	PRESENT	0
84317	84154	04043D	PARTICIPANT	\N	PRESENT	0
84318	84154	01028R	PARTICIPANT	\N	PRESENT	0
84319	84154	00003C	PARTICIPANT	\N	PRESENT	0
84324	84154	11094U	PARTICIPANT	\N	PRESENT	0
84321	84154	14089Y	PARTICIPANT	\N	PRESENT	0
84322	84154	11095V	PARTICIPANT	\N	PRESENT	0
84323	84154	11046L	PARTICIPANT	\N	PRESENT	0
84325	84154	01061S	PARTICIPANT	\N	PRESENT	0
84326	84154	11036J	PARTICIPANT	\N	PRESENT	0
84327	84154	11014C	PARTICIPANT	\N	PRESENT	0
84328	84154	99004R	PARTICIPANT	\N	PRESENT	0
84329	84154	14038Y	PARTICIPANT	\N	PRESENT	0
84330	84154	95059Q	PARTICIPANT	\N	PRESENT	0
84331	84154	13002U	PARTICIPANT	\N	PRESENT	0
84332	84154	14241N	PARTICIPANT	\N	PRESENT	0
84333	84154	14028W	PARTICIPANT	\N	PRESENT	0
84334	84154	08043V	PARTICIPANT	\N	PRESENT	0
84335	84154	11089X	PARTICIPANT	\N	PRESENT	0
84336	84154	92015P	PARTICIPANT	\N	PRESENT	0
84337	84154	14229S	PARTICIPANT	\N	PRESENT	0
84338	84154	14073Q	PARTICIPANT	\N	PRESENT	0
84339	84154	04089T	PARTICIPANT	\N	PRESENT	0
84340	84154	08044W	PARTICIPANT	\N	PRESENT	0
84341	84154	11011M	PARTICIPANT	\N	PRESENT	0
84342	84154	14219Q	PARTICIPANT	\N	PRESENT	0
84343	84154	04070G	PARTICIPANT	\N	PRESENT	0
84344	84154	11082Q	PARTICIPANT	\N	PRESENT	0
84345	84154	08052W	PARTICIPANT	\N	PRESENT	0
84346	84154	12042Y	PARTICIPANT	\N	PRESENT	0
84347	84154	14107H	PARTICIPANT	\N	PRESENT	0
84348	84154	11012A	PARTICIPANT	\N	PRESENT	0
84349	84154	14227Q	PARTICIPANT	\N	PRESENT	0
84350	84154	08012N	PARTICIPANT	\N	PRESENT	0
84351	84154	11110B	PARTICIPANT	\N	PRESENT	0
84352	84154	14014Q	PARTICIPANT	\N	PRESENT	0
84353	84154	08016S	PARTICIPANT	\N	PRESENT	0
84354	84154	14257W	PARTICIPANT	\N	PRESENT	0
84355	84154	11059R	PARTICIPANT	\N	PRESENT	0
84356	84154	01022K	PARTICIPANT	\N	PRESENT	0
84357	84154	14263U	PARTICIPANT	\N	PRESENT	0
84358	84154	98046X	PARTICIPANT	\N	PRESENT	0
84359	84154	14331P	PARTICIPANT	\N	PRESENT	0
84360	84154	14173T	PARTICIPANT	\N	PRESENT	0
84361	84154	11100Y	PARTICIPANT	\N	PRESENT	0
84362	84154	14223L	PARTICIPANT	\N	PRESENT	0
84363	84154	14261S	PARTICIPANT	\N	PRESENT	0
84364	84154	01003G	PARTICIPANT	\N	PRESENT	0
84365	84154	01044R	PARTICIPANT	\N	PRESENT	0
84366	84154	14207L	PARTICIPANT	\N	PRESENT	0
84367	84154	08053X	PARTICIPANT	\N	PRESENT	0
84368	84154	11015D	PARTICIPANT	\N	PRESENT	0
84369	84154	14269B	PARTICIPANT	\N	PRESENT	0
84370	84154	04059M	PARTICIPANT	\N	PRESENT	0
84371	84154	11104D	PARTICIPANT	\N	PRESENT	0
84372	84154	14041T	PARTICIPANT	\N	PRESENT	0
84373	84154	98018T	PARTICIPANT	\N	PRESENT	0
84374	84154	08061X	PARTICIPANT	\N	PRESENT	0
84375	84154	14327T	PARTICIPANT	\N	PRESENT	0
84376	84154	11107G	PARTICIPANT	\N	PRESENT	0
84377	84154	95063L	PARTICIPANT	\N	PRESENT	0
84378	84154	01015L	PARTICIPANT	\N	PRESENT	0
84379	84154	98021N	PARTICIPANT	\N	PRESENT	0
84380	84154	14169X	PARTICIPANT	\N	PRESENT	0
84381	84154	08047A	PARTICIPANT	\N	PRESENT	0
84382	84154	11035H	PARTICIPANT	\N	PRESENT	0
84383	84154	08019V	PARTICIPANT	\N	PRESENT	0
84384	84154	11103C	PARTICIPANT	\N	PRESENT	0
84385	84154	05012A	PARTICIPANT	\N	PRESENT	0
84386	84154	04085P	PARTICIPANT	\N	PRESENT	0
84387	84154	08015R	PARTICIPANT	\N	PRESENT	0
84388	84154	14037X	PARTICIPANT	\N	PRESENT	0
84389	84154	11114F	PARTICIPANT	\N	PRESENT	0
84390	84154	14042U	PARTICIPANT	\N	PRESENT	0
84391	84154	01057W	PARTICIPANT	\N	PRESENT	0
84392	84154	01025N	PARTICIPANT	\N	PRESENT	0
84393	84154	01016M	PARTICIPANT	\N	PRESENT	0
84394	84154	11057P	PARTICIPANT	\N	PRESENT	0
84395	84154	01031L	PARTICIPANT	\N	PRESENT	0
84396	84154	11027H	PARTICIPANT	\N	PRESENT	0
84397	84154	14225N	PARTICIPANT	\N	PRESENT	0
84398	84154	14121F	PARTICIPANT	\N	PRESENT	0
84400	84154	14061L	PARTICIPANT	\N	PRESENT	0
84401	84154	97011G	PARTICIPANT	\N	PRESENT	0
84402	84154	14201E	PARTICIPANT	\N	PRESENT	0
84403	84154	95015C	PARTICIPANT	\N	PRESENT	0
84406	84154	14215L	PARTICIPANT	\N	PRESENT	0
84407	84154	11093T	PARTICIPANT	\N	PRESENT	0
84408	84154	08017T	PARTICIPANT	\N	PRESENT	0
84409	84154	14053L	PARTICIPANT	\N	PRESENT	0
84410	84154	14205J	PARTICIPANT	\N	PRESENT	0
84411	84154	11077T	PARTICIPANT	\N	PRESENT	0
84412	84154	08014Q	PARTICIPANT	\N	PRESENT	0
84413	84154	11048N	PARTICIPANT	\N	PRESENT	0
84414	84154	08062Y	PARTICIPANT	\N	PRESENT	0
84415	84154	09001P	PARTICIPANT	\N	PRESENT	0
84416	84154	01024M	PARTICIPANT	\N	PRESENT	0
84417	84154	01047U	PARTICIPANT	\N	PRESENT	0
84418	84154	14187A	PARTICIPANT	\N	PRESENT	0
84419	84154	01056V	PARTICIPANT	\N	PRESENT	0
84420	84154	83047W	PARTICIPANT	\N	PRESENT	0
84421	84154	08051V	PARTICIPANT	\N	PRESENT	0
84422	84154	08065C	PARTICIPANT	\N	PRESENT	0
84423	84154	11097X	PARTICIPANT	\N	PRESENT	0
84424	84154	14071N	PARTICIPANT	\N	PRESENT	0
84425	84154	04044E	PARTICIPANT	\N	PRESENT	0
84426	84154	14018U	PARTICIPANT	\N	PRESENT	0
84427	84154	92039X	PARTICIPANT	\N	PRESENT	0
84428	84154	11098Y	PARTICIPANT	\N	PRESENT	0
84429	84154	14159V	PARTICIPANT	\N	PRESENT	0
84430	84154	14079W	PARTICIPANT	\N	PRESENT	0
84431	84154	01027Q	PARTICIPANT	\N	PRESENT	0
84432	84154	14259Y	PARTICIPANT	\N	PRESENT	0
84433	84154	08010L	PARTICIPANT	\N	PRESENT	0
84434	84154	14083S	PARTICIPANT	\N	PRESENT	0
84435	84154	14111D	PARTICIPANT	\N	PRESENT	0
84436	84154	04081K	PARTICIPANT	\N	PRESENT	0
84437	84154	11091R	PARTICIPANT	\N	PRESENT	0
84438	84154	14051J	PARTICIPANT	\N	PRESENT	0
84439	84154	14030Q	PARTICIPANT	\N	PRESENT	0
84440	84154	14157T	PARTICIPANT	\N	PRESENT	0
84441	84154	14237S	PARTICIPANT	\N	PRESENT	0
84445	84154	14193X	PARTICIPANT	\N	PRESENT	0
84446	84154	14135M	PARTICIPANT	\N	PRESENT	0
84447	84154	14031R	PARTICIPANT	\N	PRESENT	0
84448	84154	11064N	PARTICIPANT	\N	PRESENT	0
84449	84154	14249W	PARTICIPANT	\N	PRESENT	0
84450	84154	86044G	PARTICIPANT	\N	PRESENT	0
84451	84154	08034U	PARTICIPANT	\N	PRESENT	0
84452	84154	04034C	PARTICIPANT	\N	PRESENT	0
84453	84154	14213J	PARTICIPANT	\N	PRESENT	0
84454	84154	14251Q	PARTICIPANT	\N	PRESENT	0
84455	84154	01046T	PARTICIPANT	\N	PRESENT	0
84465	84154	14265W	PARTICIPANT	\N	PRESENT	0
84466	84154	14065Q	PARTICIPANT	\N	PRESENT	0
84467	84154	14151M	PARTICIPANT	\N	PRESENT	0
84468	84154	11067R	PARTICIPANT	\N	PRESENT	0
84469	84154	92045V	PARTICIPANT	\N	PRESENT	0
84470	84154	11084S	PARTICIPANT	\N	PRESENT	0
84471	84154	11105E	PARTICIPANT	\N	PRESENT	0
84472	84154	95062K	PARTICIPANT	\N	PRESENT	0
84473	84154	89017R	PARTICIPANT	\N	PRESENT	0
68470	68469	08025T	PARTICIPANT	\N	PRESENT	0
68471	68469	04085P	PARTICIPANT	\N	PRESENT	0
68472	68469	05008E	PRESIDENT	0	PRESENT	0
68519	68469	01007L	PARTICIPANT	\N	PRESENT	0
68474	68469	11033F	PARTICIPANT	\N	PRESENT	0
68475	68469	14065Q	PARTICIPANT	\N	PRESENT	0
68476	68469	14069U	PARTICIPANT	\N	PRESENT	0
68477	68469	04047H	PARTICIPANT	\N	PRESENT	0
68478	68469	11032E	PARTICIPANT	\N	PRESENT	0
68479	68469	04038G	PARTICIPANT	\N	PRESENT	0
68480	68469	99002P	PARTICIPANT	\N	PRESENT	0
68520	68469	04044E	PARTICIPANT	\N	EXCUSE	0
79219	79217	04054G	PARTICIPANT	\N	PRESENT	0
68483	68469	11035H	PARTICIPANT	\N	PRESENT	0
68484	68469	14041T	PARTICIPANT	\N	PRESENT	0
68485	68469	11113E	PARTICIPANT	\N	PRESENT	0
68486	68469	01024M	PARTICIPANT	\N	PRESENT	0
68487	68469	14215L	PARTICIPANT	\N	PRESENT	0
68488	68469	11034G	PARTICIPANT	\N	PRESENT	0
79220	79217	96004D	PRESIDENT	0	PRESENT	0
79222	79217	11040E	PARTICIPANT	\N	PRESENT	0
79223	79217	14089Y	PARTICIPANT	\N	PRESENT	0
68492	68469	11049P	PARTICIPANT	\N	PRESENT	0
68493	68469	08044W	PARTICIPANT	\N	PRESENT	0
79224	79217	14079W	PARTICIPANT	\N	PRESENT	0
68495	68469	11026G	PARTICIPANT	\N	PRESENT	0
68496	68469	04079R	PARTICIPANT	\N	PRESENT	0
68497	68469	14111D	PARTICIPANT	\N	PRESENT	0
79225	79217	95030B	PARTICIPANT	\N	PRESENT	0
68499	68469	14273W	PARTICIPANT	\N	PRESENT	0
79226	79217	11083R	PARTICIPANT	\N	PRESENT	0
68501	68469	14147R	PARTICIPANT	\N	PRESENT	0
68502	68469	95049N	PARTICIPANT	\N	PRESENT	0
68503	68469	08051V	PARTICIPANT	\N	PRESENT	0
79227	79217	14026U	PARTICIPANT	\N	PRESENT	0
68505	68469	07034Q	PARTICIPANT	\N	PRESENT	0
68506	68469	04074L	PARTICIPANT	\N	PRESENT	0
68507	68469	10015M	PARTICIPANT	\N	PRESENT	0
68508	68469	95063L	PARTICIPANT	\N	PRESENT	0
68509	68469	01019Q	PARTICIPANT	\N	PRESENT	0
68510	68469	01028R	PARTICIPANT	\N	PRESENT	0
68511	68469	98035U	PARTICIPANT	\N	PRESENT	0
68512	68469	04056J	PARTICIPANT	\N	PRESENT	0
79228	79217	14097Y	PARTICIPANT	\N	PRESENT	0
79229	79217	04061F	PARTICIPANT	\N	PRESENT	0
68515	68469	11037K	PARTICIPANT	\N	PRESENT	0
68516	68469	92045V	PARTICIPANT	\N	PRESENT	0
79230	79217	11026G	PARTICIPANT	\N	PRESENT	0
68518	68469	01047U	PARTICIPANT	\N	PRESENT	0
79231	79217	14073Q	PARTICIPANT	\N	PRESENT	0
79232	79217	14001X	PARTICIPANT	\N	PRESENT	0
79233	79217	04057K	PARTICIPANT	\N	PRESENT	0
79234	79217	04080J	PARTICIPANT	\N	PRESENT	0
79235	79217	14135M	PARTICIPANT	\N	PRESENT	0
79236	79217	01016M	PARTICIPANT	\N	PRESENT	0
79237	79217	10015M	PARTICIPANT	\N	PRESENT	0
79238	79217	11012A	PARTICIPANT	\N	PRESENT	0
79239	79217	04045F	PARTICIPANT	\N	PRESENT	0
79240	79217	92045V	PARTICIPANT	\N	PRESENT	0
79241	79217	04034C	PARTICIPANT	\N	PRESENT	0
79242	79217	90003B	PARTICIPANT	\N	EXCUSE	0
79329	79328	10015M	PARTICIPANT	\N	PRESENT	0
79356	79355	05012A	PARTICIPANT	\N	PRESENT	0
79357	79355	08038Y	PARTICIPANT	\N	PRESENT	0
79358	79355	11101A	PARTICIPANT	\N	PRESENT	0
79359	79355	11044J	PARTICIPANT	\N	PRESENT	0
79360	79355	11074Q	PARTICIPANT	\N	PRESENT	0
79362	79361	05012A	PARTICIPANT	\N	PRESENT	0
79364	79361	11101A	PARTICIPANT	\N	PRESENT	0
79366	79361	08038Y	PARTICIPANT	\N	PRESENT	0
79368	79361	14231L	PARTICIPANT	\N	PRESENT	0
79369	79361	11099A	PARTICIPANT	\N	PRESENT	0
79373	79372	11101A	PARTICIPANT	\N	PRESENT	0
79374	79372	08038Y	PARTICIPANT	\N	PRESENT	0
79375	79372	05012A	PARTICIPANT	\N	PRESENT	0
79376	79372	04045F	PARTICIPANT	\N	PRESENT	0
79378	79372	11099A	PARTICIPANT	\N	PRESENT	0
79379	79372	01027Q	PARTICIPANT	\N	PRESENT	0
79753	79752	14217N	PARTICIPANT	\N	PRESENT	0
79754	79752	92020L	PARTICIPANT	\N	PRESENT	0
79755	79752	14281W	PRESIDENT	0	PRESENT	0
79756	79752	07004J	PARTICIPANT	\N	PRESENT	0
79757	79752	10015M	PARTICIPANT	\N	PRESENT	0
79776	79752	11054L	PARTICIPANT	\N	EXCUSE	0
80012	80011	11068S	PARTICIPANT	\N	PRESENT	0
80022	80020	11068S	PARTICIPANT	\N	PRESENT	0
80157	77795	11064N	PARTICIPANT	\N	EXCUSE	0
80180	80179	11053K	PARTICIPANT	\N	PRESENT	0
80182	80181	11053K	PARTICIPANT	\N	PRESENT	0
80195	80194	11053K	PARTICIPANT	\N	PRESENT	0
83993	83892	01022K	PARTICIPANT	\N	EXCUSE	0
83994	83952	14071N	PARTICIPANT	\N	EXCUSE	0
83995	83952	04040A	PRESIDENT	0	PRESENT	0
83998	83997	11040E	PARTICIPANT	\N	PRESENT	0
90353	90351	14034U	PARTICIPANT	\N	PRESENT	0
90267	90266	14263U	PARTICIPANT	\N	PRESENT	0
90268	90266	14133K	PARTICIPANT	\N	PRESENT	0
90269	90266	11109J	PARTICIPANT	\N	PRESENT	0
90270	90266	04059M	PARTICIPANT	\N	PRESENT	0
90354	90351	14037X	PARTICIPANT	\N	PRESENT	0
90272	90266	01044R	PARTICIPANT	\N	PRESENT	0
90273	90266	08043V	PARTICIPANT	\N	PRESENT	0
90356	90355	14087W	PARTICIPANT	\N	PRESENT	0
90275	90266	14105F	PARTICIPANT	\N	PRESENT	0
90276	90266	11029K	PARTICIPANT	\N	PRESENT	0
90357	90355	14034U	PARTICIPANT	\N	PRESENT	0
90278	90266	92015P	PARTICIPANT	\N	PRESENT	0
90279	90266	08024S	PARTICIPANT	\N	PRESENT	0
90280	90266	14201E	PARTICIPANT	\N	PRESENT	0
90281	90266	14329V	PARTICIPANT	\N	PRESENT	0
90282	90266	14209N	PARTICIPANT	\N	PRESENT	0
90283	90266	14079W	PARTICIPANT	\N	PRESENT	0
90284	90266	11091R	PARTICIPANT	\N	PRESENT	0
90285	90266	87003B	PARTICIPANT	\N	PRESENT	0
90286	90266	98042T	PARTICIPANT	\N	PRESENT	0
90358	90355	14037X	PARTICIPANT	\N	PRESENT	0
90288	90266	01041N	PARTICIPANT	\N	PRESENT	0
90289	90266	01025N	PARTICIPANT	\N	PRESENT	0
90290	90266	01037S	PARTICIPANT	\N	PRESENT	0
90291	90266	89029V	PARTICIPANT	\N	PRESENT	0
90292	90266	08035V	PARTICIPANT	\N	PRESENT	0
90361	90360	14087W	PARTICIPANT	\N	PRESENT	0
90294	90266	07026Q	PARTICIPANT	\N	PRESENT	0
90295	90266	14123H	PARTICIPANT	\N	PRESENT	0
90296	90266	14179A	PARTICIPANT	\N	PRESENT	0
90297	90266	04041B	PARTICIPANT	\N	PRESENT	0
90298	90266	14241N	PARTICIPANT	\N	PRESENT	0
90299	90266	14061L	PARTICIPANT	\N	PRESENT	0
90300	90266	14073Q	PARTICIPANT	\N	PRESENT	0
90301	90266	08031R	PARTICIPANT	\N	PRESENT	0
90302	90266	12041X	PARTICIPANT	\N	PRESENT	0
90303	90266	08039A	PARTICIPANT	\N	PRESENT	0
90304	90266	08017T	PARTICIPANT	\N	PRESENT	0
90305	90266	14059S	PARTICIPANT	\N	PRESENT	0
90306	90266	08012N	PARTICIPANT	\N	PRESENT	0
90307	90266	14103D	PARTICIPANT	\N	PRESENT	0
90362	90360	14034U	PARTICIPANT	\N	PRESENT	0
90309	90266	14063N	PARTICIPANT	\N	PRESENT	0
90310	90266	04057K	PARTICIPANT	\N	PRESENT	0
90311	90266	11014C	PARTICIPANT	\N	PRESENT	0
90363	90360	14037X	PARTICIPANT	\N	PRESENT	0
90313	90266	04070G	PRESIDENT	0	PRESENT	0
90314	90266	92040Q	PARTICIPANT	\N	PRESENT	0
90315	90266	14191V	PARTICIPANT	\N	PRESENT	0
90316	90266	83047W	PARTICIPANT	\N	PRESENT	0
90317	90266	14235Q	PARTICIPANT	\N	PRESENT	0
90318	90266	14055N	PARTICIPANT	\N	PRESENT	0
90366	90364	14087W	PARTICIPANT	\N	PRESENT	0
90320	90266	14229S	PARTICIPANT	\N	PRESENT	0
90321	90266	11043H	PARTICIPANT	\N	PRESENT	0
90406	90364	14034U	PARTICIPANT	\N	PRESENT	0
90407	90364	14037X	PARTICIPANT	\N	PRESENT	0
90409	90408	14087W	PARTICIPANT	\N	PRESENT	0
90410	90408	14034U	PARTICIPANT	\N	PRESENT	0
90411	90408	14037X	PARTICIPANT	\N	PRESENT	0
90414	90413	14087W	PARTICIPANT	\N	PRESENT	0
90415	90413	14034U	PARTICIPANT	\N	PRESENT	0
90416	90413	14037X	PARTICIPANT	\N	PRESENT	0
90418	90417	14087W	PARTICIPANT	\N	PRESENT	0
90419	90417	14034U	PARTICIPANT	\N	PRESENT	0
90420	90417	14037X	PARTICIPANT	\N	PRESENT	0
90422	90421	14087W	PARTICIPANT	\N	PRESENT	0
90423	90421	14034U	PARTICIPANT	\N	PRESENT	0
90424	90421	14037X	PARTICIPANT	\N	PRESENT	0
90426	90425	14087W	PARTICIPANT	\N	PRESENT	0
90427	90425	14034U	PARTICIPANT	\N	PRESENT	0
90428	90425	14037X	PARTICIPANT	\N	PRESENT	0
90430	90429	14087W	PARTICIPANT	\N	PRESENT	0
90431	90429	14037X	PARTICIPANT	\N	PRESENT	0
89432	89066	14073Q	PARTICIPANT	\N	PRESENT	0
89433	89066	14083S	PARTICIPANT	\N	PRESENT	0
89434	89066	08012N	PARTICIPANT	\N	PRESENT	0
89435	89066	14121F	PARTICIPANT	\N	PRESENT	0
89436	89066	14221J	PARTICIPANT	\N	PRESENT	0
89437	89066	92015P	PARTICIPANT	\N	PRESENT	0
89438	89066	04045F	PARTICIPANT	\N	PRESENT	0
89439	89066	11040E	PARTICIPANT	\N	PRESENT	0
89440	89066	14179A	PARTICIPANT	\N	PRESENT	0
89441	89066	14028W	PARTICIPANT	\N	PRESENT	0
89442	89066	95037J	PARTICIPANT	\N	PRESENT	0
89443	89066	07026Q	PARTICIPANT	\N	PRESENT	0
89444	89066	14263U	PARTICIPANT	\N	PRESENT	0
89445	89066	11033F	PARTICIPANT	\N	PRESENT	0
89446	89066	08051V	PARTICIPANT	\N	PRESENT	0
89447	89066	88008L	PARTICIPANT	\N	PRESENT	0
89448	89066	11012A	PARTICIPANT	\N	PRESENT	0
89449	89066	14269B	PARTICIPANT	\N	PRESENT	0
89450	89066	11031D	PARTICIPANT	\N	PRESENT	0
89451	89066	14231L	PARTICIPANT	\N	PRESENT	0
89452	89066	01047U	PARTICIPANT	\N	PRESENT	0
89453	89066	11054L	PARTICIPANT	\N	PRESENT	0
89454	89066	08043V	PARTICIPANT	\N	PRESENT	0
89455	89066	11026G	PARTICIPANT	\N	PRESENT	0
89456	89066	98046X	PARTICIPANT	\N	PRESENT	0
89457	89066	14235Q	PARTICIPANT	\N	PRESENT	0
89458	89066	95035G	PARTICIPANT	\N	PRESENT	0
89459	89066	14079W	PARTICIPANT	\N	PRESENT	0
89460	89066	14281W	PARTICIPANT	\N	PRESENT	0
89461	89066	14061L	PARTICIPANT	\N	PRESENT	0
89462	89066	14265W	PARTICIPANT	\N	PRESENT	0
89463	89066	11091R	PARTICIPANT	\N	PRESENT	0
89464	89066	11066Q	PARTICIPANT	\N	PRESENT	0
89465	89066	11097X	PARTICIPANT	\N	PRESENT	0
89466	89066	11089X	PARTICIPANT	\N	PRESENT	0
89467	89066	01028R	PARTICIPANT	\N	PRESENT	0
89468	89066	04085P	PARTICIPANT	\N	PRESENT	0
89469	89066	14197C	PARTICIPANT	\N	PRESENT	0
89470	89066	08031R	PARTICIPANT	\N	PRESENT	0
89471	89066	14237S	PARTICIPANT	\N	PRESENT	0
89472	89066	14207L	PARTICIPANT	\N	PRESENT	0
89473	89066	08017T	PARTICIPANT	\N	PRESENT	0
89474	89066	11112D	PARTICIPANT	\N	PRESENT	0
89475	89066	04088S	PARTICIPANT	\N	PRESENT	0
89476	89066	14033T	PARTICIPANT	\N	PRESENT	0
89477	89066	11049P	PARTICIPANT	\N	PRESENT	0
89478	89066	14111D	PARTICIPANT	\N	PRESENT	0
89479	89066	01057W	PARTICIPANT	\N	PRESENT	0
89480	89066	08041T	PARTICIPANT	\N	PRESENT	0
89481	89066	11043H	PARTICIPANT	\N	PRESENT	0
89482	89066	14253S	PARTICIPANT	\N	PRESENT	0
89483	89066	14211G	PARTICIPANT	\N	PRESENT	0
89484	89066	95062K	PARTICIPANT	\N	PRESENT	0
89485	89066	01027Q	PARTICIPANT	\N	PRESENT	0
89486	89066	08053X	PARTICIPANT	\N	PRESENT	0
89487	89066	99004R	PARTICIPANT	\N	PRESENT	0
89488	89066	97011G	PARTICIPANT	\N	PRESENT	0
89489	89066	04081K	PARTICIPANT	\N	PRESENT	0
89490	89066	11103C	PARTICIPANT	\N	PRESENT	0
89491	89066	14187A	PARTICIPANT	\N	PRESENT	0
89492	89066	14257W	PARTICIPANT	\N	PRESENT	0
89493	89066	11014C	PARTICIPANT	\N	PRESENT	0
89494	89066	05012A	PARTICIPANT	\N	PRESENT	0
89495	89066	07034Q	PARTICIPANT	\N	PRESENT	0
89496	89066	14259Y	PARTICIPANT	\N	PRESENT	0
89497	89066	11037K	PARTICIPANT	\N	PRESENT	0
89498	89066	04033B	PARTICIPANT	\N	PRESENT	0
89499	89066	04086Q	PARTICIPANT	\N	PRESENT	0
89500	89066	04044E	PARTICIPANT	\N	PRESENT	0
89501	89066	86044G	PARTICIPANT	\N	PRESENT	0
89502	89066	14038Y	PARTICIPANT	\N	PRESENT	0
89503	89066	14059S	PARTICIPANT	\N	PRESENT	0
89544	89066	14013P	PARTICIPANT	\N	PRESENT	0
89545	89066	04053F	PARTICIPANT	\N	PRESENT	0
89546	89066	87003B	PARTICIPANT	\N	PRESENT	0
89547	89066	14026U	PARTICIPANT	\N	PRESENT	0
89548	89066	14063N	PARTICIPANT	\N	PRESENT	0
89549	89066	04047H	PARTICIPANT	\N	PRESENT	0
89550	89066	14087W	PARTICIPANT	\N	PRESENT	0
89551	89066	14065Q	PARTICIPANT	\N	PRESENT	0
89553	89066	98024R	PARTICIPANT	\N	PRESENT	0
89557	89066	14229S	PARTICIPANT	\N	PRESENT	0
89561	89066	14105F	PARTICIPANT	\N	PRESENT	0
89562	89066	14107H	PARTICIPANT	\N	PRESENT	0
89563	89066	14051J	PARTICIPANT	\N	PRESENT	0
89564	89066	13002U	PARTICIPANT	\N	PRESENT	0
89565	89066	08069G	PARTICIPANT	\N	PRESENT	0
89566	89066	04043D	PARTICIPANT	\N	PRESENT	0
89567	89066	11023D	PARTICIPANT	\N	PRESENT	0
89568	89066	04092N	PARTICIPANT	\N	PRESENT	0
89569	89066	14042U	PARTICIPANT	\N	PRESENT	0
89570	89066	14135M	PARTICIPANT	\N	PRESENT	0
89571	89066	14327T	PARTICIPANT	\N	PRESENT	0
89572	89066	01048V	PARTICIPANT	\N	PRESENT	0
89573	89066	11093T	PARTICIPANT	\N	PRESENT	0
89574	89066	14147R	PARTICIPANT	\N	PRESENT	0
89575	89066	04089T	PARTICIPANT	\N	PRESENT	0
89576	89066	01022K	PARTICIPANT	\N	PRESENT	0
89577	89066	11059R	PARTICIPANT	\N	PRESENT	0
89578	89066	14201E	PARTICIPANT	\N	PRESENT	0
89579	89066	14251Q	PARTICIPANT	\N	PRESENT	0
89580	89066	08022Q	PARTICIPANT	\N	PRESENT	0
89581	89066	07029T	PARTICIPANT	\N	PRESENT	0
89582	89066	01025N	PARTICIPANT	\N	PRESENT	0
89583	89066	11030C	PARTICIPANT	\N	PRESENT	0
89584	89066	11053K	PARTICIPANT	\N	PRESENT	0
89585	89066	04038G	PARTICIPANT	\N	PRESENT	0
89586	89066	98018T	PARTICIPANT	\N	PRESENT	0
89587	89066	14223L	PARTICIPANT	\N	PRESENT	0
89590	89066	04057K	PARTICIPANT	\N	PRESENT	0
89592	89066	83042R	PARTICIPANT	\N	PRESENT	0
89647	89066	08011M	PARTICIPANT	\N	PRESENT	0
89649	89066	01024M	PARTICIPANT	\N	PRESENT	0
89651	89066	14217N	PARTICIPANT	\N	PRESENT	0
89797	89068	89029V	PARTICIPANT	\N	PRESENT	0
89798	89068	07034Q	PARTICIPANT	\N	PRESENT	0
89799	89068	08011M	PARTICIPANT	\N	PRESENT	0
89800	89068	01022K	PARTICIPANT	\N	PRESENT	0
89801	89068	11061K	PARTICIPANT	\N	PRESENT	0
89802	89068	11059R	PARTICIPANT	\N	PRESENT	0
89803	89068	11054L	PARTICIPANT	\N	PRESENT	0
89804	89068	14159V	PARTICIPANT	\N	PRESENT	0
89805	89068	08058D	PARTICIPANT	\N	PRESENT	0
89806	89068	01028R	PARTICIPANT	\N	PRESENT	0
89807	89068	11023D	PARTICIPANT	\N	PRESENT	0
89808	89068	11083R	PARTICIPANT	\N	PRESENT	0
89809	89068	14103D	PARTICIPANT	\N	PRESENT	0
89810	89068	14121F	PARTICIPANT	\N	PRESENT	0
89811	89068	13002U	PARTICIPANT	\N	PRESENT	0
89812	89068	01031L	PARTICIPANT	\N	PRESENT	0
89813	89068	14219Q	PARTICIPANT	\N	PRESENT	0
89814	89068	01013J	PARTICIPANT	\N	PRESENT	0
89815	89068	11040E	PARTICIPANT	\N	PRESENT	0
89816	89068	11053K	PARTICIPANT	\N	PRESENT	0
89817	89068	04038G	PARTICIPANT	\N	PRESENT	0
89818	89068	88008L	PARTICIPANT	\N	PRESENT	0
89819	89068	11112D	PARTICIPANT	\N	PRESENT	0
89820	89068	14063N	PARTICIPANT	\N	PRESENT	0
89821	89068	14179A	PARTICIPANT	\N	PRESENT	0
89822	89068	14073Q	PARTICIPANT	\N	PRESENT	0
89823	89068	14083S	PARTICIPANT	\N	PRESENT	0
89824	89068	14079W	PARTICIPANT	\N	PRESENT	0
89825	89068	95035G	PARTICIPANT	\N	PRESENT	0
89826	89068	14237S	PARTICIPANT	\N	PRESENT	0
89827	89068	14215L	PARTICIPANT	\N	PRESENT	0
89828	89068	01027Q	PARTICIPANT	\N	PRESENT	0
89829	89068	08022Q	PARTICIPANT	\N	PRESENT	0
89830	89068	14201E	PARTICIPANT	\N	PRESENT	0
89831	89068	14331P	PARTICIPANT	\N	PRESENT	0
89832	89068	01048V	PARTICIPANT	\N	PRESENT	0
89833	89068	14059S	PARTICIPANT	\N	PRESENT	0
89834	89068	97011G	PARTICIPANT	\N	PRESENT	0
89835	89068	14105F	PARTICIPANT	\N	PRESENT	0
89836	89068	98046X	PARTICIPANT	\N	PRESENT	0
89837	89068	14033T	PARTICIPANT	\N	PRESENT	0
89838	89068	14135M	PARTICIPANT	\N	PRESENT	0
89846	89068	14329V	PARTICIPANT	\N	PRESENT	0
89840	89068	11049P	PARTICIPANT	\N	PRESENT	0
89841	89068	11030C	PARTICIPANT	\N	PRESENT	0
89842	89068	14041T	PARTICIPANT	\N	PRESENT	0
89851	89068	87003B	PARTICIPANT	\N	PRESENT	0
89845	89068	08028W	PARTICIPANT	\N	PRESENT	0
89847	89068	08019V	PARTICIPANT	\N	PRESENT	0
89848	89068	14038Y	PARTICIPANT	\N	PRESENT	0
89849	89068	14111D	PARTICIPANT	\N	PRESENT	0
89850	89068	04088S	PARTICIPANT	\N	PRESENT	0
89852	89068	14265W	PARTICIPANT	\N	PRESENT	0
89853	89068	11091R	PARTICIPANT	\N	PRESENT	0
78815	78814	14133K	PARTICIPANT	\N	PRESENT	0
78816	78814	96004D	PRESIDENT	0	PRESENT	0
78817	78814	14089Y	PARTICIPANT	\N	PRESENT	0
78818	78814	11035H	PARTICIPANT	\N	PRESENT	0
78819	78814	11083R	PARTICIPANT	\N	PRESENT	0
78822	78814	14135M	PARTICIPANT	\N	PRESENT	0
78823	78814	04080J	PARTICIPANT	\N	PRESENT	0
78824	78814	04045F	PARTICIPANT	\N	PRESENT	0
78825	78814	92045V	PARTICIPANT	\N	PRESENT	0
78826	78814	04034C	PARTICIPANT	\N	PRESENT	0
78829	78814	11012A	PARTICIPANT	\N	EXCUSE	0
78830	78814	90003B	PARTICIPANT	\N	EXCUSE	0
80229	80228	11083R	PARTICIPANT	\N	PRESENT	0
80231	80230	11083R	PARTICIPANT	\N	PRESENT	0
80361	80359	08034U	PARTICIPANT	\N	PRESENT	0
83823	83822	14239U	PARTICIPANT	\N	PRESENT	0
83824	83822	97011G	PARTICIPANT	\N	PRESENT	0
83825	83822	11083R	PARTICIPANT	\N	PRESENT	0
83826	83822	08069G	PARTICIPANT	\N	PRESENT	0
83827	83822	14135M	PARTICIPANT	\N	PRESENT	0
83828	83822	01008M	PARTICIPANT	\N	PRESENT	0
83830	83829	10006L	PARTICIPANT	\N	PRESENT	0
83832	83831	10006L	PARTICIPANT	\N	PRESENT	0
84474	84154	14026U	PARTICIPANT	\N	PRESENT	0
84475	84154	08055A	PARTICIPANT	\N	PRESENT	0
84476	84154	95067Q	PARTICIPANT	\N	PRESENT	0
84550	84155	08018U	PARTICIPANT	\N	PRESENT	0
84551	84155	07026Q	PARTICIPANT	\N	PRESENT	0
84552	84155	14013P	PARTICIPANT	\N	PRESENT	0
84553	84155	14235Q	PARTICIPANT	\N	PRESENT	0
84554	84155	11046L	PARTICIPANT	\N	PRESENT	0
84555	84155	11110B	PARTICIPANT	\N	PRESENT	0
84556	84155	01044R	PARTICIPANT	\N	PRESENT	0
84557	84155	11029K	PARTICIPANT	\N	PRESENT	0
84558	84155	11012A	PARTICIPANT	\N	PRESENT	0
84559	84155	14105F	PARTICIPANT	\N	PRESENT	0
84560	84155	14038Y	PARTICIPANT	\N	PRESENT	0
84561	84155	11098Y	PARTICIPANT	\N	PRESENT	0
84562	84155	08034U	PARTICIPANT	\N	PRESENT	0
84563	84155	04057K	PARTICIPANT	\N	PRESENT	0
84564	84155	14014Q	PARTICIPANT	\N	PRESENT	0
84565	84155	11095V	PARTICIPANT	\N	PRESENT	0
84566	84155	14271U	PARTICIPANT	\N	PRESENT	0
84567	84155	04070G	PARTICIPANT	\N	PRESENT	0
84568	84155	11043H	PARTICIPANT	\N	PRESENT	0
84569	84155	11090Q	PARTICIPANT	\N	PRESENT	0
84570	84155	14209N	PARTICIPANT	\N	PRESENT	0
84571	84155	11089X	PARTICIPANT	\N	PRESENT	0
84572	84155	14257W	PARTICIPANT	\N	PRESENT	0
84573	84155	11027H	PARTICIPANT	\N	PRESENT	0
84574	84155	01027Q	PARTICIPANT	\N	PRESENT	0
84575	84155	11026G	PARTICIPANT	\N	PRESENT	0
84576	84155	01025N	PARTICIPANT	\N	PRESENT	0
84577	84155	14107H	PARTICIPANT	\N	PRESENT	0
84578	84155	14073Q	PARTICIPANT	\N	PRESENT	0
84579	84155	14033T	PARTICIPANT	\N	PRESENT	0
84580	84155	95067Q	PARTICIPANT	\N	PRESENT	0
84581	84155	11036J	PARTICIPANT	\N	PRESENT	0
84582	84155	01028R	PARTICIPANT	\N	PRESENT	0
84583	84155	14083S	PARTICIPANT	\N	PRESENT	0
84584	84155	08068F	PARTICIPANT	\N	PRESENT	0
84585	84155	01016M	PARTICIPANT	\N	PRESENT	0
84586	84155	14215L	PARTICIPANT	\N	PRESENT	0
84599	84155	14026U	PARTICIPANT	\N	PRESENT	0
84588	84155	12042Y	PARTICIPANT	\N	PRESENT	0
84589	84155	14331P	PARTICIPANT	\N	PRESENT	0
84590	84155	14259Y	PARTICIPANT	\N	PRESENT	0
84591	84155	11048N	PARTICIPANT	\N	PRESENT	0
84592	84155	14187A	PARTICIPANT	\N	PRESENT	0
84593	84155	14213J	PARTICIPANT	\N	PRESENT	0
84594	84155	14053L	PARTICIPANT	\N	PRESENT	0
84595	84155	14265W	PARTICIPANT	\N	PRESENT	0
84596	84155	14217N	PARTICIPANT	\N	PRESENT	0
84597	84155	11096W	PARTICIPANT	\N	PRESENT	0
84598	84155	14241N	PARTICIPANT	\N	PRESENT	0
84600	84155	11097X	PARTICIPANT	\N	PRESENT	0
84601	84155	92045V	PARTICIPANT	\N	PRESENT	0
84602	84155	04088S	PARTICIPANT	\N	PRESENT	0
84603	84155	08039A	PARTICIPANT	\N	PRESENT	0
84604	84155	14255U	PARTICIPANT	\N	PRESENT	0
84605	84155	04033B	PARTICIPANT	\N	PRESENT	0
84606	84155	14061L	PARTICIPANT	\N	PRESENT	0
84607	84155	14219Q	PARTICIPANT	\N	PRESENT	0
84608	84155	14179A	PARTICIPANT	\N	PRESENT	0
84609	84155	04040A	PARTICIPANT	\N	PRESENT	0
84610	84155	08051V	PARTICIPANT	\N	PRESENT	0
84611	84155	92039X	PARTICIPANT	\N	PRESENT	0
84612	84155	14018U	PARTICIPANT	\N	PRESENT	0
84613	84155	10006L	PARTICIPANT	\N	PRESENT	0
84614	84155	14031R	PARTICIPANT	\N	PRESENT	0
84615	84155	14211G	PARTICIPANT	\N	PRESENT	0
84616	84155	01058X	PARTICIPANT	\N	PRESENT	0
84617	84155	14034U	PARTICIPANT	\N	PRESENT	0
84618	84155	07029T	PARTICIPANT	\N	PRESENT	0
84634	84633	14135M	PARTICIPANT	\N	PRESENT	0
84635	83922	11061K	PARTICIPANT	\N	EXCUSE	0
84819	84156	86034E	PARTICIPANT	\N	PRESENT	0
84548	84155	08055A	PARTICIPANT	\N	PRESENT	0
84549	84155	04044E	PARTICIPANT	\N	PRESENT	0
84878	84156	04067M	PARTICIPANT	\N	PRESENT	0
84879	84156	11091R	PARTICIPANT	\N	PRESENT	0
84880	84156	95031C	PARTICIPANT	\N	PRESENT	0
84881	84156	04086Q	PARTICIPANT	\N	PRESENT	0
84882	84156	08011M	PARTICIPANT	\N	PRESENT	0
84883	84156	01031L	PARTICIPANT	\N	PRESENT	0
84884	84156	01034P	PARTICIPANT	\N	PRESENT	0
84885	84156	14227Q	PARTICIPANT	\N	PRESENT	0
84886	84156	11012A	PARTICIPANT	\N	PRESENT	0
84887	84156	14179A	PARTICIPANT	\N	PRESENT	0
84888	84156	04034C	PARTICIPANT	\N	PRESENT	0
84890	84156	08052W	PARTICIPANT	\N	PRESENT	0
84891	84156	08016S	PARTICIPANT	\N	PRESENT	0
84894	84156	11110B	PARTICIPANT	\N	PRESENT	0
84898	84156	07029T	PARTICIPANT	\N	PRESENT	0
84903	84156	14193X	PARTICIPANT	\N	PRESENT	0
84905	84156	01022K	PARTICIPANT	\N	PRESENT	0
84908	84156	04054G	PARTICIPANT	\N	PRESENT	0
84912	84156	11042G	PARTICIPANT	\N	PRESENT	0
84922	84156	14175V	PARTICIPANT	\N	PRESENT	0
84925	84156	01013J	PARTICIPANT	\N	PRESENT	0
84927	84156	11040E	PARTICIPANT	\N	PRESENT	0
84930	84156	08061X	PARTICIPANT	\N	PRESENT	0
84933	84156	14327T	PARTICIPANT	\N	PRESENT	0
84935	84156	14331P	PARTICIPANT	\N	PRESENT	0
84938	84156	14105F	PARTICIPANT	\N	PRESENT	0
84942	84156	01016M	PARTICIPANT	\N	PRESENT	0
84944	84156	14205J	PARTICIPANT	\N	PRESENT	0
84946	84156	14103D	PARTICIPANT	\N	PRESENT	0
84947	84156	14041T	PARTICIPANT	\N	PRESENT	0
84948	84156	08047A	PARTICIPANT	\N	PRESENT	0
84949	84156	04061F	PARTICIPANT	\N	PRESENT	0
84950	84156	99004R	PARTICIPANT	\N	PRESENT	0
84951	84156	08034U	PARTICIPANT	\N	PRESENT	0
84952	84156	11053K	PARTICIPANT	\N	PRESENT	0
84953	84156	11057P	PARTICIPANT	\N	PRESENT	0
84954	84156	04095R	PARTICIPANT	\N	PRESENT	0
84955	84156	14030Q	PARTICIPANT	\N	PRESENT	0
84956	84156	14085U	PARTICIPANT	\N	PRESENT	0
84957	84156	08055A	PARTICIPANT	\N	PRESENT	0
84958	84156	11070L	PARTICIPANT	\N	PRESENT	0
84959	84156	14223L	PARTICIPANT	\N	PRESENT	0
84963	84156	14001X	PARTICIPANT	\N	PRESENT	0
84961	84156	13002U	PARTICIPANT	\N	PRESENT	0
84962	84156	14121F	PARTICIPANT	\N	PRESENT	0
84964	84156	01008M	PARTICIPANT	\N	PRESENT	0
84965	84156	95035G	PARTICIPANT	\N	PRESENT	0
84966	84156	04045F	PARTICIPANT	\N	PRESENT	0
84967	84156	90003B	PARTICIPANT	\N	PRESENT	0
84968	84156	14107H	PARTICIPANT	\N	PRESENT	0
84969	84156	11011M	PARTICIPANT	\N	PRESENT	0
84970	84156	14281W	PARTICIPANT	\N	PRESENT	0
84971	84156	87003B	PARTICIPANT	\N	PRESENT	0
84972	84156	14197C	PARTICIPANT	\N	PRESENT	0
84973	84156	14267Y	PARTICIPANT	\N	PRESENT	0
84974	84156	11043H	PARTICIPANT	\N	PRESENT	0
84975	84156	14033T	PARTICIPANT	\N	PRESENT	0
84976	84156	14215L	PARTICIPANT	\N	PRESENT	0
84977	84156	14087W	PARTICIPANT	\N	PRESENT	0
84978	84156	98046X	PARTICIPANT	\N	PRESENT	0
84979	84156	95063L	PARTICIPANT	\N	PRESENT	0
84980	84156	14261S	PARTICIPANT	\N	PRESENT	0
84981	84156	14073Q	PARTICIPANT	\N	PRESENT	0
84982	84156	08043V	PARTICIPANT	\N	PRESENT	0
84983	84156	08041T	PARTICIPANT	\N	PRESENT	0
84984	84156	14026U	PARTICIPANT	\N	PRESENT	0
84985	84156	14195A	PARTICIPANT	\N	PRESENT	0
84986	84156	04088S	PARTICIPANT	\N	PRESENT	0
84987	84156	14169X	PARTICIPANT	\N	PRESENT	0
84989	84156	92015P	PARTICIPANT	\N	PRESENT	0
90433	90432	14087W	PARTICIPANT	\N	PRESENT	0
90434	90432	14034U	PARTICIPANT	\N	PRESENT	0
90435	90432	14037X	PARTICIPANT	\N	PRESENT	0
90437	90436	14087W	PARTICIPANT	\N	PRESENT	0
90438	90436	14034U	PARTICIPANT	\N	PRESENT	0
90439	90436	14037X	PARTICIPANT	\N	PRESENT	0
90442	90441	14239U	PARTICIPANT	\N	PRESENT	0
90548	90547	89017R	PARTICIPANT	\N	PRESENT	0
90444	90441	01046T	PARTICIPANT	\N	PRESENT	0
90445	90441	04053F	PARTICIPANT	\N	PRESENT	0
90446	90441	14255U	PARTICIPANT	\N	PRESENT	0
90447	90441	04066L	PARTICIPANT	\N	PRESENT	0
90448	90441	00003C	PARTICIPANT	\N	PRESENT	0
90449	90441	14053L	PARTICIPANT	\N	EXCUSE	0
90450	90441	11103C	PARTICIPANT	\N	PRESENT	0
90549	90547	01031L	PRESIDENT	0	PRESENT	0
90452	90441	14195A	PARTICIPANT	\N	PRESENT	0
90453	90441	14267Y	PARTICIPANT	\N	PRESENT	0
90454	90441	11023D	PARTICIPANT	\N	PRESENT	0
90455	90441	11031D	PARTICIPANT	\N	PRESENT	0
90456	90441	08052W	PARTICIPANT	\N	PRESENT	0
90550	90547	05004A	PARTICIPANT	\N	PRESENT	0
90458	90441	04081K	PARTICIPANT	\N	PRESENT	0
90459	90441	98024R	PARTICIPANT	\N	PRESENT	0
90460	90441	10006L	PARTICIPANT	\N	PRESENT	0
90551	90547	01013J	PARTICIPANT	\N	PRESENT	0
90462	90441	14217N	PARTICIPANT	\N	PRESENT	0
90463	90441	14042U	PARTICIPANT	\N	PRESENT	0
90598	90597	89017R	PARTICIPANT	\N	PRESENT	0
90465	90441	12042Y	PARTICIPANT	\N	PRESENT	0
90466	90441	14281W	PARTICIPANT	\N	PRESENT	0
90467	90441	14087W	PARTICIPANT	\N	PRESENT	0
90468	90441	01003G	PARTICIPANT	\N	PRESENT	0
90469	90441	14034U	PARTICIPANT	\N	PRESENT	0
90470	90441	14231L	PARTICIPANT	\N	PRESENT	0
90471	90441	11061K	PARTICIPANT	\N	PRESENT	0
90472	90441	08048B	PARTICIPANT	\N	PRESENT	0
90473	90441	08041T	PARTICIPANT	\N	PRESENT	0
90553	90547	11040E	PARTICIPANT	\N	PRESENT	0
90475	90441	14026U	PARTICIPANT	\N	PRESENT	0
90476	90441	14213J	PARTICIPANT	\N	PRESENT	0
90477	90441	14121F	PARTICIPANT	\N	PRESENT	0
90478	90441	11112D	PARTICIPANT	\N	PRESENT	0
90479	90441	14037X	PARTICIPANT	\N	PRESENT	0
90554	90547	08014Q	PARTICIPANT	\N	PRESENT	0
90481	90441	11067R	PARTICIPANT	\N	PRESENT	0
90482	90441	14223L	PARTICIPANT	\N	PRESENT	0
90483	90441	04092N	PRESIDENT	0	PRESENT	0
90484	90441	14265W	PARTICIPANT	\N	PRESENT	0
90485	90441	14119M	PARTICIPANT	\N	PRESENT	0
90486	90441	14071N	PARTICIPANT	\N	PRESENT	0
90487	90441	07032N	PARTICIPANT	\N	PRESENT	0
90488	90441	04043D	PARTICIPANT	\N	PRESENT	0
90489	90441	14271U	PARTICIPANT	\N	PRESENT	0
90555	90547	14167V	PARTICIPANT	\N	PRESENT	0
90491	90441	11093T	PARTICIPANT	\N	PRESENT	0
90492	90441	11097X	PARTICIPANT	\N	PRESENT	0
90493	90441	04045F	PARTICIPANT	\N	PRESENT	0
90494	90441	14227Q	PARTICIPANT	\N	PRESENT	0
90495	90441	01034P	PARTICIPANT	\N	PRESENT	0
90599	90597	01031L	PRESIDENT	0	PRESENT	0
90497	90441	11063M	PARTICIPANT	\N	PRESENT	0
90498	90441	14269B	PARTICIPANT	\N	PRESENT	0
90556	90547	14175V	PARTICIPANT	\N	PRESENT	0
90557	90547	14083S	PARTICIPANT	\N	PRESENT	0
90558	90547	11053K	PARTICIPANT	\N	PRESENT	0
90559	90547	14085U	PARTICIPANT	\N	PRESENT	0
90600	90597	05004A	PARTICIPANT	\N	PRESENT	0
90561	90547	88008L	PARTICIPANT	\N	PRESENT	0
90562	90547	04086Q	PARTICIPANT	\N	PRESENT	0
90563	90547	04055H	PARTICIPANT	\N	EXCUSE	0
90564	90547	11070L	PARTICIPANT	\N	PRESENT	0
90601	90597	01013J	PARTICIPANT	\N	PRESENT	0
90566	90547	14327T	PARTICIPANT	\N	PRESENT	0
90567	90547	08022Q	PARTICIPANT	\N	PRESENT	0
90568	90547	01027Q	PARTICIPANT	\N	PRESENT	0
90569	90547	04071H	PARTICIPANT	\N	PRESENT	0
90570	90547	11074Q	PARTICIPANT	\N	PRESENT	0
90571	90547	98053W	PARTICIPANT	\N	PRESENT	0
90572	90547	11083R	PARTICIPANT	\N	PRESENT	0
90602	90597	11068S	PARTICIPANT	\N	PRESENT	0
90574	90547	01057W	PARTICIPANT	\N	PRESENT	0
90603	90597	11040E	PARTICIPANT	\N	PRESENT	0
90576	90547	08069G	PARTICIPANT	\N	PRESENT	0
90577	90547	11048N	PARTICIPANT	\N	PRESENT	0
90578	90547	99004R	PARTICIPANT	\N	PRESENT	0
90579	90547	04061F	PARTICIPANT	\N	PRESENT	0
90580	90547	14159V	PARTICIPANT	\N	PRESENT	0
90581	90547	07029T	PARTICIPANT	\N	PRESENT	0
90604	90597	08014Q	PARTICIPANT	\N	PRESENT	0
90583	90547	08010L	PARTICIPANT	\N	PRESENT	0
90584	90547	08034U	PARTICIPANT	\N	PRESENT	0
90585	90547	01048V	PARTICIPANT	\N	PRESENT	0
90605	90597	14167V	PARTICIPANT	\N	PRESENT	0
90587	90547	11085T	PARTICIPANT	\N	PRESENT	0
90588	90547	08011M	PARTICIPANT	\N	EXCUSE	0
90589	90547	08073C	PARTICIPANT	\N	PRESENT	0
90590	90547	08061X	PARTICIPANT	\N	PRESENT	0
90606	90597	14175V	PARTICIPANT	\N	PRESENT	0
90592	90547	14225N	PARTICIPANT	\N	PRESENT	0
90593	90547	11012A	PARTICIPANT	\N	PRESENT	0
90594	90547	11057P	PARTICIPANT	\N	PRESENT	0
90647	89157	11082Q	PARTICIPANT	\N	EXCUSE	0
90596	90547	04034C	PARTICIPANT	\N	PRESENT	0
90607	90597	14083S	PARTICIPANT	\N	PRESENT	0
90608	90597	11053K	PARTICIPANT	\N	PRESENT	0
90609	90597	14085U	PARTICIPANT	\N	PRESENT	0
90649	90648	89017R	PARTICIPANT	\N	PRESENT	0
90611	90597	88008L	PARTICIPANT	\N	PRESENT	0
90612	90597	04086Q	PARTICIPANT	\N	PRESENT	0
90613	90597	04055H	PARTICIPANT	\N	EXCUSE	0
90614	90597	11070L	PARTICIPANT	\N	PRESENT	0
90650	90648	01031L	PRESIDENT	0	PRESENT	0
90616	90597	14327T	PARTICIPANT	\N	PRESENT	0
90617	90597	08022Q	PARTICIPANT	\N	PRESENT	0
90618	90597	01027Q	PARTICIPANT	\N	PRESENT	0
90619	90597	04071H	PARTICIPANT	\N	PRESENT	0
90620	90597	11074Q	PARTICIPANT	\N	PRESENT	0
90621	90597	98053W	PARTICIPANT	\N	PRESENT	0
90622	90597	11083R	PARTICIPANT	\N	PRESENT	0
90624	90597	01057W	PARTICIPANT	\N	PRESENT	0
90652	90648	01013J	PARTICIPANT	\N	PRESENT	0
90626	90597	08069G	PARTICIPANT	\N	PRESENT	0
90627	90597	11048N	PARTICIPANT	\N	PRESENT	0
90628	90597	99004R	PARTICIPANT	\N	PRESENT	0
90629	90597	04061F	PARTICIPANT	\N	PRESENT	0
90630	90597	14159V	PARTICIPANT	\N	PRESENT	0
90631	90597	07029T	PARTICIPANT	\N	PRESENT	0
90653	90648	11068S	PARTICIPANT	\N	PRESENT	0
90633	90597	08010L	PARTICIPANT	\N	PRESENT	0
90634	90597	08034U	PARTICIPANT	\N	PRESENT	0
90635	90597	01048V	PARTICIPANT	\N	PRESENT	0
90636	90597	98046X	PARTICIPANT	\N	PRESENT	0
90637	90597	11085T	PARTICIPANT	\N	PRESENT	0
90638	90597	08011M	PARTICIPANT	\N	EXCUSE	0
90639	90597	08073C	PARTICIPANT	\N	PRESENT	0
90640	90597	08061X	PARTICIPANT	\N	PRESENT	0
90654	90648	11040E	PARTICIPANT	\N	PRESENT	0
90642	90597	14225N	PARTICIPANT	\N	PRESENT	0
90643	90597	11012A	PARTICIPANT	\N	PRESENT	0
90644	90597	11057P	PARTICIPANT	\N	PRESENT	0
90655	90648	08014Q	PARTICIPANT	\N	PRESENT	0
90646	90597	04034C	PARTICIPANT	\N	PRESENT	0
90656	90648	14167V	PARTICIPANT	\N	PRESENT	0
90657	90648	14175V	PARTICIPANT	\N	PRESENT	0
90658	90648	14083S	PARTICIPANT	\N	PRESENT	0
90659	90648	11053K	PARTICIPANT	\N	PRESENT	0
90660	90648	14085U	PARTICIPANT	\N	PRESENT	0
90661	90648	11042G	PARTICIPANT	\N	PRESENT	0
90663	90648	04086Q	PARTICIPANT	\N	PRESENT	0
90664	90648	04055H	PARTICIPANT	\N	EXCUSE	0
90668	90648	08022Q	PARTICIPANT	\N	PRESENT	0
90669	90648	01027Q	PARTICIPANT	\N	PRESENT	0
90670	90648	04071H	PARTICIPANT	\N	PRESENT	0
90671	90648	11074Q	PARTICIPANT	\N	PRESENT	0
90672	90648	98053W	PARTICIPANT	\N	PRESENT	0
90673	90648	11083R	PARTICIPANT	\N	PRESENT	0
90675	90648	01057W	PARTICIPANT	\N	PRESENT	0
90676	90648	08016S	PARTICIPANT	\N	PRESENT	0
90677	90648	08069G	PARTICIPANT	\N	PRESENT	0
90679	90648	99004R	PARTICIPANT	\N	PRESENT	0
78878	75076	14053L	PARTICIPANT	\N	EXCUSE	0
84638	84637	14261S	PARTICIPANT	\N	PRESENT	0
84639	84637	08055A	PARTICIPANT	\N	PRESENT	0
84640	84637	14093U	PARTICIPANT	\N	PRESENT	0
84641	84637	14030Q	PARTICIPANT	\N	PRESENT	0
84642	84637	96004D	PARTICIPANT	\N	PRESENT	0
84718	84717	89017R	PARTICIPANT	\N	PRESENT	0
84644	84637	11095V	PARTICIPANT	\N	PRESENT	0
84645	84637	14038Y	PARTICIPANT	\N	PRESENT	0
84646	84637	11114F	PARTICIPANT	\N	PRESENT	0
84719	84717	01031L	PRESIDENT	0	PRESENT	0
84767	84717	08028W	PARTICIPANT	\N	PRESENT	0
84649	84637	01015L	PARTICIPANT	\N	PRESENT	0
84650	84637	11107G	PARTICIPANT	\N	PRESENT	0
84721	84717	01013J	PARTICIPANT	\N	PRESENT	0
84652	84637	02002K	PARTICIPANT	\N	PRESENT	0
84653	84637	01022K	PARTICIPANT	\N	PRESENT	0
84722	84717	11068S	PARTICIPANT	\N	PRESENT	0
84655	84637	09001P	PARTICIPANT	\N	PRESENT	0
84656	84637	11059R	PARTICIPANT	\N	PRESENT	0
84657	84637	14219Q	PARTICIPANT	\N	PRESENT	0
84658	84637	80027E	PARTICIPANT	\N	PRESENT	0
84659	84637	14031R	PARTICIPANT	\N	PRESENT	0
84660	84637	08009T	PRESIDENT	0	PRESENT	0
84661	84637	08062Y	PARTICIPANT	\N	PRESENT	0
84662	84637	14221J	PARTICIPANT	\N	PRESENT	0
84663	84637	92039X	PARTICIPANT	\N	PRESENT	0
84664	84637	08042U	PARTICIPANT	\N	PRESENT	0
84665	84637	14169X	PARTICIPANT	\N	PRESENT	0
84666	84637	14237S	PARTICIPANT	\N	PRESENT	0
84667	84637	13002U	PARTICIPANT	\N	PRESENT	0
84668	84637	05012A	PARTICIPANT	\N	PRESENT	0
84669	84637	14247U	PARTICIPANT	\N	PRESENT	0
84670	84637	14135M	PARTICIPANT	\N	PRESENT	0
84671	84637	14331P	PARTICIPANT	\N	PRESENT	0
84672	84637	95062K	PARTICIPANT	\N	PRESENT	0
84673	84637	14107H	PARTICIPANT	\N	PRESENT	0
84674	84637	14051J	PARTICIPANT	\N	PRESENT	0
84675	84637	14157T	PARTICIPANT	\N	PRESENT	0
84676	84637	96003C	PARTICIPANT	\N	EXCUSE	0
84723	84717	11040E	PARTICIPANT	\N	PRESENT	0
84724	84717	08014Q	PARTICIPANT	\N	PRESENT	0
84725	84717	14167V	PARTICIPANT	\N	PRESENT	0
84726	84717	14175V	PARTICIPANT	\N	PRESENT	0
84727	84717	14083S	PARTICIPANT	\N	PRESENT	0
85778	85761	11076S	PARTICIPANT	\N	PRESENT	0
84729	84717	14085U	PARTICIPANT	\N	PRESENT	0
84730	84717	11042G	PARTICIPANT	\N	PRESENT	0
85779	85761	04054G	PARTICIPANT	\N	PRESENT	0
84732	84717	04086Q	PARTICIPANT	\N	PRESENT	0
85780	85761	04040A	PARTICIPANT	\N	EXCUSE	0
84734	84717	11070L	PARTICIPANT	\N	PRESENT	0
84735	84717	11088W	PARTICIPANT	\N	PRESENT	0
84736	84717	14327T	PARTICIPANT	\N	PRESENT	0
85885	85761	04047H	PARTICIPANT	\N	PRESENT	0
85886	85761	04038G	PARTICIPANT	\N	PRESENT	0
84739	84717	04071H	PARTICIPANT	\N	PRESENT	0
85887	85761	14041T	PARTICIPANT	\N	PRESENT	0
84741	84717	98053W	PARTICIPANT	\N	EXCUSE	0
85888	85761	11026G	PARTICIPANT	\N	PRESENT	0
85889	85761	10015M	PARTICIPANT	\N	PRESENT	0
84744	84717	01057W	PARTICIPANT	\N	PRESENT	0
84745	84717	08016S	PARTICIPANT	\N	PRESENT	0
84746	84717	08069G	PARTICIPANT	\N	PRESENT	0
84747	84717	11048N	PARTICIPANT	\N	PRESENT	0
84748	84717	99004R	PARTICIPANT	\N	PRESENT	0
85890	85761	95063L	PARTICIPANT	\N	PRESENT	0
84750	84717	14159V	PARTICIPANT	\N	PRESENT	0
84751	84717	07029T	PARTICIPANT	\N	PRESENT	0
85787	85761	98018T	PARTICIPANT	\N	PRESENT	0
84753	84717	08010L	PARTICIPANT	\N	PRESENT	0
84754	84717	08034U	PARTICIPANT	\N	PRESENT	0
85891	85761	01028R	PARTICIPANT	\N	PRESENT	0
84756	84717	98046X	PARTICIPANT	\N	PRESENT	0
85892	85761	98035U	PARTICIPANT	\N	PRESENT	0
84758	84717	08011M	PARTICIPANT	\N	PRESENT	0
85790	85761	95030B	PARTICIPANT	\N	PRESENT	0
84760	84717	08061X	PARTICIPANT	\N	PRESENT	0
84761	84717	01016M	PARTICIPANT	\N	PRESENT	0
84762	84717	14225N	PARTICIPANT	\N	PRESENT	0
85893	85761	95067Q	PARTICIPANT	\N	PRESENT	0
84764	84717	11057P	PARTICIPANT	\N	PRESENT	0
84765	84717	14173T	PARTICIPANT	\N	PRESENT	0
84766	84717	04034C	PARTICIPANT	\N	PRESENT	0
85894	85761	01024M	PARTICIPANT	\N	PRESENT	0
85895	85761	96004D	PARTICIPANT	\N	PRESENT	0
85896	85761	04034C	PARTICIPANT	\N	PRESENT	0
85897	85761	14079W	PARTICIPANT	\N	PRESENT	0
85795	85761	04035D	PARTICIPANT	\N	PRESENT	0
85796	85761	07024N	PARTICIPANT	\N	PRESENT	0
85898	85761	01016M	PARTICIPANT	\N	PRESENT	0
85899	85761	14073Q	PARTICIPANT	\N	PRESENT	0
85900	85761	14089Y	PARTICIPANT	\N	PRESENT	0
85901	85761	14133K	PARTICIPANT	\N	PRESENT	0
85801	85761	95035G	PARTICIPANT	\N	PRESENT	0
85802	85761	08056B	PARTICIPANT	\N	EXCUSE	0
89854	89068	14225N	PARTICIPANT	\N	PRESENT	0
85804	85761	98022P	PARTICIPANT	\N	PRESENT	0
85902	85761	08044W	PARTICIPANT	\N	PRESENT	0
89855	89068	14197C	PARTICIPANT	\N	PRESENT	0
85903	85761	92045V	PARTICIPANT	\N	PRESENT	0
85808	85761	14097Y	PARTICIPANT	\N	PRESENT	0
85904	85761	14249W	PARTICIPANT	\N	PRESENT	0
85810	85761	04036E	PARTICIPANT	\N	EXCUSE	0
85905	85761	14065Q	PARTICIPANT	\N	PRESENT	0
85906	85761	08042U	PARTICIPANT	\N	PRESENT	0
85941	85761	14273W	PARTICIPANT	\N	PRESENT	0
85814	85761	92031P	PARTICIPANT	\N	PRESENT	0
85815	85761	11106F	PARTICIPANT	\N	PRESENT	0
89856	89068	11036J	PARTICIPANT	\N	PRESENT	0
89857	89068	14221J	PARTICIPANT	\N	PRESENT	0
89858	89068	14207L	PARTICIPANT	\N	PRESENT	0
89859	89068	04034C	PARTICIPANT	\N	PRESENT	0
85820	85761	11105E	PARTICIPANT	\N	PRESENT	0
89860	89068	11012A	PARTICIPANT	\N	PRESENT	0
89861	89068	11056N	PARTICIPANT	\N	PRESENT	0
85823	85761	14028W	PARTICIPANT	\N	EXCUSE	0
89862	89068	14187A	PARTICIPANT	\N	PRESENT	0
89863	89068	14223L	PARTICIPANT	\N	PRESENT	0
85826	85761	04080J	PARTICIPANT	\N	PRESENT	0
85827	85761	95059Q	PRESIDENT	0	PRESENT	0
89864	89068	01025N	PARTICIPANT	\N	PRESENT	0
89865	89068	14231L	PARTICIPANT	\N	PRESENT	0
85830	85761	11054L	PARTICIPANT	\N	PRESENT	0
89866	89068	95037J	PARTICIPANT	\N	PRESENT	0
89867	89068	08065C	PARTICIPANT	\N	PRESENT	0
85833	85761	08049C	PARTICIPANT	\N	EXCUSE	0
89868	89068	14213J	PARTICIPANT	\N	PRESENT	0
89869	89068	92015P	PARTICIPANT	\N	PRESENT	0
89870	89068	98050T	PARTICIPANT	\N	PRESENT	0
89871	89068	01024M	PARTICIPANT	\N	PRESENT	0
89872	89068	95049N	PARTICIPANT	\N	PRESENT	0
89873	89068	08042U	PARTICIPANT	\N	PRESENT	0
89874	89068	14061L	PARTICIPANT	\N	PRESENT	0
89875	89068	04066L	PARTICIPANT	\N	PRESENT	0
89876	89068	11105E	PARTICIPANT	\N	PRESENT	0
89877	89068	14065Q	PARTICIPANT	\N	PRESENT	0
89878	89068	14119M	PARTICIPANT	\N	PRESENT	0
89879	89068	14259Y	PARTICIPANT	\N	PRESENT	0
89880	89068	08041T	PARTICIPANT	\N	PRESENT	0
89881	89068	14195A	PARTICIPANT	\N	PRESENT	0
89882	89068	08039A	PARTICIPANT	\N	PRESENT	0
89883	89068	14097Y	PARTICIPANT	\N	PRESENT	0
89884	89068	14107H	PARTICIPANT	\N	PRESENT	0
89885	89068	01057W	PARTICIPANT	\N	PRESENT	0
89886	89068	11090Q	PARTICIPANT	\N	PRESENT	0
89887	89068	90003B	PARTICIPANT	\N	PRESENT	0
89888	89068	04049K	PARTICIPANT	\N	PRESENT	0
89889	89068	95030B	PARTICIPANT	\N	PRESENT	0
89890	89068	11034G	PARTICIPANT	\N	PRESENT	0
89891	89068	11098Y	PARTICIPANT	\N	PRESENT	0
89892	89068	14030Q	PARTICIPANT	\N	PRESENT	0
89893	89068	08060W	PARTICIPANT	\N	PRESENT	0
89894	89068	11066Q	PARTICIPANT	\N	PRESENT	0
89895	89068	01008M	PARTICIPANT	\N	PRESENT	0
89896	89068	14026U	PARTICIPANT	\N	PRESENT	0
89897	89068	14169X	PARTICIPANT	\N	PRESENT	0
89898	89068	01061S	PARTICIPANT	\N	PRESENT	0
89899	89068	95062K	PARTICIPANT	\N	PRESENT	0
89900	89068	11048N	PARTICIPANT	\N	PRESENT	0
89901	89068	07029T	PARTICIPANT	\N	PRESENT	0
89902	89068	01015L	PARTICIPANT	\N	PRESENT	0
89903	89068	14013P	PARTICIPANT	\N	PRESENT	0
89904	89068	14069U	PARTICIPANT	\N	PRESENT	0
84990	84156	04059M	PARTICIPANT	\N	PRESENT	0
84991	84156	11104D	PARTICIPANT	\N	PRESENT	0
85031	84156	11088W	PARTICIPANT	\N	PRESENT	0
85032	84156	14157T	PARTICIPANT	\N	PRESENT	0
85033	84156	14219Q	PARTICIPANT	\N	PRESENT	0
85035	84156	11048N	PARTICIPANT	\N	PRESENT	0
85036	84156	14235Q	PARTICIPANT	\N	PRESENT	0
85037	84156	14237S	PARTICIPANT	\N	PRESENT	0
85038	84156	04053F	PARTICIPANT	\N	PRESENT	0
85039	84156	14089Y	PARTICIPANT	\N	PRESENT	0
85040	84156	14083S	PARTICIPANT	\N	PRESENT	0
85041	84156	11098Y	PARTICIPANT	\N	PRESENT	0
85042	84156	95015C	PARTICIPANT	\N	PRESENT	0
85043	84156	95030B	PARTICIPANT	\N	PRESENT	0
85044	84156	11049P	PARTICIPANT	\N	PRESENT	0
85045	84156	14269B	PARTICIPANT	\N	PRESENT	0
85046	84156	14249W	PARTICIPANT	\N	PRESENT	0
85047	84156	14217N	PARTICIPANT	\N	PRESENT	0
85048	84156	14273W	PARTICIPANT	\N	PRESENT	0
85049	84156	08062Y	PARTICIPANT	\N	PRESENT	0
85050	84156	05012A	PARTICIPANT	\N	PRESENT	0
85051	84156	01027Q	PARTICIPANT	\N	PRESENT	0
85052	84156	14028W	PARTICIPANT	\N	PRESENT	0
85053	84156	11081P	PARTICIPANT	\N	PRESENT	0
85054	84156	08068F	PARTICIPANT	\N	PRESENT	0
85055	84156	97011G	PARTICIPANT	\N	PRESENT	0
85056	84156	14053L	PARTICIPANT	\N	PRESENT	0
85057	84156	14037X	PARTICIPANT	\N	PRESENT	0
85058	84156	14265W	PARTICIPANT	\N	PRESENT	0
85059	84156	00003C	PARTICIPANT	\N	PRESENT	0
85061	84156	14014Q	PARTICIPANT	\N	PRESENT	0
85062	84156	08015R	PARTICIPANT	\N	PRESENT	0
85063	84156	11054L	PARTICIPANT	\N	PRESENT	0
85064	84156	14221J	PARTICIPANT	\N	PRESENT	0
85065	84156	14209N	PARTICIPANT	\N	PRESENT	0
85124	84156	14031R	PARTICIPANT	\N	PRESENT	0
85125	84156	01003G	PARTICIPANT	\N	PRESENT	0
85126	84156	11046L	PARTICIPANT	\N	PRESENT	0
85127	84156	04035D	PARTICIPANT	\N	PRESENT	0
85236	84157	14263U	PARTICIPANT	\N	PRESENT	0
85237	84157	14013P	PARTICIPANT	\N	PRESENT	0
85238	84157	14235Q	PARTICIPANT	\N	PRESENT	0
85239	84157	01015L	PARTICIPANT	\N	PRESENT	0
85240	84157	14107H	PARTICIPANT	\N	PRESENT	0
85241	84157	11036J	PARTICIPANT	\N	PRESENT	0
85242	84157	80013X	PARTICIPANT	\N	PRESENT	0
85243	84157	08068F	PARTICIPANT	\N	PRESENT	0
85244	84157	11107G	PARTICIPANT	\N	PRESENT	0
85245	84157	14121F	PARTICIPANT	\N	PRESENT	0
85246	84157	11066Q	PARTICIPANT	\N	PRESENT	0
85247	84157	14109K	PARTICIPANT	\N	PRESENT	0
85248	84157	12042Y	PARTICIPANT	\N	PRESENT	0
85249	84157	11026G	PARTICIPANT	\N	PRESENT	0
85254	84157	04095R	PARTICIPANT	\N	PRESENT	0
85255	84157	11029K	PARTICIPANT	\N	PRESENT	0
85256	84157	14261S	PARTICIPANT	\N	PRESENT	0
85257	84157	01003G	PARTICIPANT	\N	PRESENT	0
85258	84157	11012A	PARTICIPANT	\N	PRESENT	0
85259	84157	14087W	PARTICIPANT	\N	PRESENT	0
85260	84157	04070G	PARTICIPANT	\N	PRESENT	0
85261	84157	14237S	PARTICIPANT	\N	PRESENT	0
85262	84157	08009T	PARTICIPANT	\N	PRESENT	0
85263	84157	11011M	PARTICIPANT	\N	PRESENT	0
85264	84157	14157T	PARTICIPANT	\N	PRESENT	0
85265	84157	14033T	PARTICIPANT	\N	PRESENT	0
85266	84157	14038Y	PARTICIPANT	\N	PRESENT	0
85267	84157	11103C	PARTICIPANT	\N	PRESENT	0
85268	84157	97011G	PARTICIPANT	\N	PRESENT	0
85269	84157	04035D	PARTICIPANT	\N	PRESENT	0
85270	84157	87003B	PARTICIPANT	\N	PRESENT	0
85271	84157	14265W	PARTICIPANT	\N	PRESENT	0
85272	84157	14105F	PARTICIPANT	\N	PRESENT	0
85273	84157	04057K	PARTICIPANT	\N	PRESENT	0
85274	84157	11098Y	PARTICIPANT	\N	PRESENT	0
85275	84157	14197C	PARTICIPANT	\N	PRESENT	0
85276	84157	11046L	PARTICIPANT	\N	PRESENT	0
85277	84157	14229S	PARTICIPANT	\N	PRESENT	0
85278	84157	01028R	PARTICIPANT	\N	PRESENT	0
85279	84157	14103D	PARTICIPANT	\N	PRESENT	0
85280	84157	14267Y	PARTICIPANT	\N	PRESENT	0
85281	84157	14179A	PARTICIPANT	\N	PRESENT	0
85282	84157	10006L	PARTICIPANT	\N	PRESENT	0
85283	84157	05008E	PARTICIPANT	\N	PRESENT	0
85284	84157	11030C	PARTICIPANT	\N	PRESENT	0
85285	84157	96004D	PARTICIPANT	\N	PRESENT	0
85286	84157	14147R	PARTICIPANT	\N	PRESENT	0
85287	84157	14221J	PARTICIPANT	\N	PRESENT	0
85288	84157	14187A	PARTICIPANT	\N	PRESENT	0
85289	84157	13002U	PARTICIPANT	\N	PRESENT	0
85290	84157	14031R	PARTICIPANT	\N	PRESENT	0
85291	84157	04081K	PARTICIPANT	\N	PRESENT	0
85292	84157	14257W	PARTICIPANT	\N	PRESENT	0
85293	84157	11089X	PARTICIPANT	\N	PRESENT	0
85294	84157	08043V	PARTICIPANT	\N	PRESENT	0
85295	84157	86044G	PARTICIPANT	\N	PRESENT	0
85296	84157	01058X	PARTICIPANT	\N	PRESENT	0
85297	84157	14231L	PARTICIPANT	\N	PRESENT	0
85298	84157	08038Y	PARTICIPANT	\N	PRESENT	0
85299	84157	14209N	PARTICIPANT	\N	PRESENT	0
85300	84157	14151M	PARTICIPANT	\N	PRESENT	0
85301	84157	11105E	PARTICIPANT	\N	PRESENT	0
85302	84157	08017T	PARTICIPANT	\N	PRESENT	0
85303	84157	14251Q	PARTICIPANT	\N	PRESENT	0
85307	84157	04059M	PARTICIPANT	\N	PRESENT	0
85308	84157	92015P	PARTICIPANT	\N	PRESENT	0
85309	84157	11111C	PARTICIPANT	\N	PRESENT	0
85310	84157	11048N	PARTICIPANT	\N	PRESENT	0
85311	84157	04085P	PARTICIPANT	\N	PRESENT	0
85312	84157	04041B	PARTICIPANT	\N	PRESENT	0
85313	84157	14169X	PARTICIPANT	\N	PRESENT	0
85314	84157	14195A	PARTICIPANT	\N	PRESENT	0
85315	84157	14041T	PARTICIPANT	\N	PRESENT	0
85316	84157	04088S	PARTICIPANT	\N	PRESENT	0
85317	84157	08069G	PARTICIPANT	\N	PRESENT	0
85318	84157	11044J	PARTICIPANT	\N	PRESENT	0
85319	84157	14217N	PARTICIPANT	\N	PRESENT	0
85320	84157	14273W	PARTICIPANT	\N	PRESENT	0
85321	84157	11097X	PARTICIPANT	\N	PRESENT	0
85322	84157	11031D	PARTICIPANT	\N	PRESENT	0
85323	84157	11095V	PARTICIPANT	\N	PRESENT	0
85324	84157	95063L	PARTICIPANT	\N	PRESENT	0
85325	84157	11067R	PARTICIPANT	\N	PRESENT	0
85326	84157	04045F	PARTICIPANT	\N	PRESENT	0
85327	84157	14042U	PARTICIPANT	\N	PRESENT	0
85328	84157	08010L	PARTICIPANT	\N	PRESENT	0
85329	84157	14331P	PARTICIPANT	\N	PRESENT	0
85330	84157	14111D	PARTICIPANT	\N	PRESENT	0
85331	84157	01043Q	PARTICIPANT	\N	PRESENT	0
85332	84157	14219Q	PARTICIPANT	\N	PRESENT	0
85333	84157	14030Q	PARTICIPANT	\N	PRESENT	0
85334	84157	14053L	PARTICIPANT	\N	PRESENT	0
85335	84157	04044E	PARTICIPANT	\N	PRESENT	0
85336	84157	02002K	PARTICIPANT	\N	PRESENT	0
85337	84157	14223L	PARTICIPANT	\N	PRESENT	0
85338	84157	14213J	PARTICIPANT	\N	PRESENT	0
85389	84157	11093T	PARTICIPANT	\N	PRESENT	0
85390	84157	14205J	PARTICIPANT	\N	PRESENT	0
85391	84157	14097Y	PARTICIPANT	\N	PRESENT	0
85392	84157	89017R	PARTICIPANT	\N	PRESENT	0
85393	84157	04086Q	PARTICIPANT	\N	PRESENT	0
85394	84157	95062K	PARTICIPANT	\N	PRESENT	0
85395	84157	14089Y	PARTICIPANT	\N	PRESENT	0
85396	84157	14014Q	PARTICIPANT	\N	PRESENT	0
85397	84157	14063N	PARTICIPANT	\N	PRESENT	0
85398	84157	11027H	PARTICIPANT	\N	PRESENT	0
85234	84157	08055A	PARTICIPANT	\N	PRESENT	0
85235	84157	08018U	PARTICIPANT	\N	PRESENT	0
85399	84157	14159V	PARTICIPANT	\N	PRESENT	0
85400	84157	14073Q	PARTICIPANT	\N	PRESENT	0
85401	84157	08031R	PARTICIPANT	\N	PRESENT	0
85402	84157	14037X	PARTICIPANT	\N	PRESENT	0
85403	84157	04048J	PARTICIPANT	\N	PRESENT	0
85404	84157	05012A	PARTICIPANT	\N	PRESENT	0
85406	84157	14085U	PARTICIPANT	\N	PRESENT	0
85407	84157	11104D	PARTICIPANT	\N	PRESENT	0
85408	84157	01031L	PARTICIPANT	\N	PRESENT	0
85409	84157	95041E	PARTICIPANT	\N	PRESENT	0
85410	84157	01027Q	PARTICIPANT	\N	PRESENT	0
85411	84157	01024M	PARTICIPANT	\N	PRESENT	0
85412	84157	11091R	PARTICIPANT	\N	PRESENT	0
85413	84157	11043H	PARTICIPANT	\N	PRESENT	0
85414	84157	01016M	PARTICIPANT	\N	PRESENT	0
85415	84157	11056N	PARTICIPANT	\N	PRESENT	0
85416	84157	01008M	PARTICIPANT	\N	PRESENT	0
85417	84157	08019V	PARTICIPANT	\N	PRESENT	0
85418	84157	08034U	PARTICIPANT	\N	PRESENT	0
85419	84157	11094U	PARTICIPANT	\N	PRESENT	0
85420	84158	01007L	PARTICIPANT	\N	PRESENT	0
66453	66452	96004D	PARTICIPANT	\N	PRESENT	0
66454	66452	95030B	PARTICIPANT	\N	PRESENT	0
66455	66452	11083R	PARTICIPANT	\N	PRESENT	0
66456	66452	04045F	PARTICIPANT	\N	PRESENT	0
66833	66832	01058X	PARTICIPANT	\N	PRESENT	0
66835	66834	01058X	PARTICIPANT	\N	PRESENT	0
66837	66836	01058X	PARTICIPANT	\N	PRESENT	0
66839	66838	01058X	PARTICIPANT	\N	PRESENT	0
66841	66803	14263U	PARTICIPANT	\N	EXCUSE	0
66842	66803	01044R	PARTICIPANT	\N	EXCUSE	0
66843	66803	14209N	PARTICIPANT	\N	EXCUSE	0
66844	66803	80013X	PARTICIPANT	\N	EXCUSE	0
66845	66803	08069G	PARTICIPANT	\N	EXCUSE	0
66846	66803	04061F	PARTICIPANT	\N	EXCUSE	0
66847	66803	01048V	PARTICIPANT	\N	EXCUSE	0
66848	66803	83042R	PARTICIPANT	\N	EXCUSE	0
66849	66803	14221J	PARTICIPANT	\N	EXCUSE	0
66850	66803	01016M	PARTICIPANT	\N	EXCUSE	0
84404	84085	14157T	PARTICIPANT	\N	PRESENT	0
80076	80073	00003C	PARTICIPANT	\N	PRESENT	0
80077	80073	14071N	PARTICIPANT	\N	PRESENT	0
84405	83303	14157T	PARTICIPANT	\N	PRESENT	0
84678	84677	14261S	PARTICIPANT	\N	PRESENT	0
84679	84677	08055A	PARTICIPANT	\N	PRESENT	0
84680	84677	14093U	PARTICIPANT	\N	PRESENT	0
84681	84677	14030Q	PARTICIPANT	\N	PRESENT	0
84682	84677	96004D	PARTICIPANT	\N	PRESENT	0
84769	84768	08025T	PARTICIPANT	\N	PRESENT	0
84684	84677	11095V	PARTICIPANT	\N	PRESENT	0
84685	84677	14038Y	PARTICIPANT	\N	PRESENT	0
84686	84677	11114F	PARTICIPANT	\N	PRESENT	0
84770	84768	04085P	PARTICIPANT	\N	PRESENT	0
84771	84768	05008E	PRESIDENT	0	PRESENT	0
84689	84677	01015L	PARTICIPANT	\N	PRESENT	0
84690	84677	11107G	PARTICIPANT	\N	PRESENT	0
84772	84768	11030C	PARTICIPANT	\N	PRESENT	0
84692	84677	02002K	PARTICIPANT	\N	PRESENT	0
84693	84677	01022K	PARTICIPANT	\N	PRESENT	0
84773	84768	11033F	PARTICIPANT	\N	PRESENT	0
84695	84677	09001P	PARTICIPANT	\N	PRESENT	0
84696	84677	11059R	PARTICIPANT	\N	PRESENT	0
84697	84677	14219Q	PARTICIPANT	\N	PRESENT	0
84698	84677	80027E	PARTICIPANT	\N	PRESENT	0
84699	84677	14031R	PARTICIPANT	\N	PRESENT	0
84700	84677	08009T	PRESIDENT	0	PRESENT	0
84701	84677	08062Y	PARTICIPANT	\N	PRESENT	0
84702	84677	14221J	PARTICIPANT	\N	PRESENT	0
84703	84677	92039X	PARTICIPANT	\N	PRESENT	0
84704	84677	08042U	PARTICIPANT	\N	PRESENT	0
84705	84677	14169X	PARTICIPANT	\N	PRESENT	0
84706	84677	14237S	PARTICIPANT	\N	PRESENT	0
84707	84677	13002U	PARTICIPANT	\N	PRESENT	0
84708	84677	05012A	PARTICIPANT	\N	PRESENT	0
84709	84677	14247U	PARTICIPANT	\N	PRESENT	0
84710	84677	14135M	PARTICIPANT	\N	PRESENT	0
84711	84677	14331P	PARTICIPANT	\N	PRESENT	0
84712	84677	95062K	PARTICIPANT	\N	PRESENT	0
84713	84677	14107H	PARTICIPANT	\N	PRESENT	0
84714	84677	14051J	PARTICIPANT	\N	PRESENT	0
84715	84677	14157T	PARTICIPANT	\N	PRESENT	0
84716	84677	96003C	PARTICIPANT	\N	EXCUSE	0
84774	84768	14065Q	PARTICIPANT	\N	PRESENT	0
84992	84988	01008M	PARTICIPANT	\N	PRESENT	0
84776	84768	04047H	PARTICIPANT	\N	PRESENT	0
84777	84768	11032E	PARTICIPANT	\N	PRESENT	0
84778	84768	04038G	PARTICIPANT	\N	PRESENT	0
84779	84768	99002P	PARTICIPANT	\N	PRESENT	0
84780	84768	11056N	PARTICIPANT	\N	PRESENT	0
84781	84768	14259Y	PARTICIPANT	\N	PRESENT	0
84782	84768	11035H	PARTICIPANT	\N	PRESENT	0
84783	84768	14041T	PARTICIPANT	\N	PRESENT	0
84784	84768	11113E	PARTICIPANT	\N	PRESENT	0
84785	84768	01024M	PARTICIPANT	\N	PRESENT	0
84786	84768	14215L	PARTICIPANT	\N	PRESENT	0
84993	84988	11036J	PARTICIPANT	\N	PRESENT	0
84788	84768	08018U	PARTICIPANT	\N	PRESENT	0
84994	84988	11081P	PARTICIPANT	\N	PRESENT	0
84790	84768	01007L	PARTICIPANT	\N	PRESENT	0
84791	84768	11049P	PARTICIPANT	\N	PRESENT	0
84995	84988	14013P	PARTICIPANT	\N	PRESENT	0
84793	84768	11084S	PARTICIPANT	\N	PRESENT	0
84794	84768	11026G	PARTICIPANT	\N	PRESENT	0
84795	84768	04079R	PARTICIPANT	\N	PRESENT	0
84796	84768	14111D	PARTICIPANT	\N	PRESENT	0
84797	84768	14001X	PARTICIPANT	\N	PRESENT	0
84798	84768	14273W	PARTICIPANT	\N	PRESENT	0
84996	84988	08068F	PARTICIPANT	\N	PRESENT	0
84800	84768	14147R	PARTICIPANT	\N	PRESENT	0
84997	84988	14207L	PARTICIPANT	\N	PRESENT	0
84998	84988	11101A	PARTICIPANT	\N	PRESENT	0
84803	84768	11072N	PARTICIPANT	\N	PRESENT	0
84804	84768	07034Q	PARTICIPANT	\N	PRESENT	0
84805	84768	04074L	PARTICIPANT	\N	PRESENT	0
84806	84768	10015M	PARTICIPANT	\N	PRESENT	0
84807	84768	95063L	PARTICIPANT	\N	PRESENT	0
84808	84768	01019Q	PARTICIPANT	\N	PRESENT	0
84809	84768	01028R	PARTICIPANT	\N	PRESENT	0
84810	84768	98035U	PARTICIPANT	\N	PRESENT	0
84999	84988	90003B	PARTICIPANT	\N	PRESENT	0
84812	84768	14275Y	PARTICIPANT	\N	PRESENT	0
84813	84768	04044E	PARTICIPANT	\N	PRESENT	0
84814	84768	11037K	PARTICIPANT	\N	PRESENT	0
84815	84768	92045V	PARTICIPANT	\N	PRESENT	0
84816	84768	95067Q	PARTICIPANT	\N	PRESENT	0
84817	84768	01047U	PARTICIPANT	\N	PRESENT	0
85000	84988	08028W	PARTICIPANT	\N	PRESENT	0
85001	84988	80013X	PARTICIPANT	\N	PRESENT	0
85002	84988	08038Y	PARTICIPANT	\N	PRESENT	0
85003	84988	04089T	PARTICIPANT	\N	PRESENT	0
85004	84988	14197C	PARTICIPANT	\N	PRESENT	0
85005	84988	11110B	PARTICIPANT	\N	PRESENT	0
85006	84988	14187A	PARTICIPANT	\N	PRESENT	0
85007	84988	14033T	PARTICIPANT	\N	PRESENT	0
85034	84988	11057P	PARTICIPANT	\N	PRESENT	0
85009	84988	04048J	PARTICIPANT	\N	PRESENT	0
85010	84988	11099A	PARTICIPANT	\N	PRESENT	0
85011	84988	04049K	PARTICIPANT	\N	PRESENT	0
85012	84988	04094Q	PARTICIPANT	\N	PRESENT	0
85013	84988	11111C	PARTICIPANT	\N	PRESENT	0
85014	84988	08015R	PARTICIPANT	\N	PRESENT	0
85015	84988	11100Y	PRESIDENT	0	PRESENT	0
85016	84988	01061S	PARTICIPANT	\N	PRESENT	0
85017	84988	11098Y	PARTICIPANT	\N	PRESENT	0
85642	85636	14133K	PARTICIPANT	\N	PRESENT	0
85019	84988	11077T	PARTICIPANT	\N	PRESENT	0
85020	84988	14205J	PARTICIPANT	\N	PRESENT	0
85021	84988	08019V	PARTICIPANT	\N	PRESENT	0
85022	84988	14257W	PARTICIPANT	\N	PRESENT	0
85643	85636	04054G	PARTICIPANT	\N	PRESENT	0
85024	84988	04088S	PARTICIPANT	\N	PRESENT	0
85025	84988	98050T	PARTICIPANT	\N	PRESENT	0
85026	84988	11090Q	PARTICIPANT	\N	PRESENT	0
85027	84988	11046L	PARTICIPANT	\N	PRESENT	0
85028	84988	01058X	PARTICIPANT	\N	PRESENT	0
85029	84988	11094U	PARTICIPANT	\N	PRESENT	0
85030	84988	11066Q	PARTICIPANT	\N	PRESENT	0
85644	85636	96004D	PRESIDENT	0	PRESENT	0
85645	85636	14089Y	PARTICIPANT	\N	PRESENT	0
85646	85636	90003B	PARTICIPANT	\N	EXCUSE	0
85647	85636	14079W	PARTICIPANT	\N	PRESENT	0
85648	85636	11035H	PARTICIPANT	\N	EXCUSE	0
85649	85636	14249W	PARTICIPANT	\N	PRESENT	0
85650	85636	95030B	PARTICIPANT	\N	PRESENT	0
85651	85636	11083R	PARTICIPANT	\N	EXCUSE	0
85652	85636	08044W	PARTICIPANT	\N	PRESENT	0
85653	85636	14097Y	PARTICIPANT	\N	PRESENT	0
85654	85636	14073Q	PARTICIPANT	\N	PRESENT	0
85655	85636	11026G	PARTICIPANT	\N	PRESENT	0
85656	85636	04057K	PARTICIPANT	\N	EXCUSE	0
85658	85636	08042U	PARTICIPANT	\N	PRESENT	0
85659	85636	04080J	PARTICIPANT	\N	PRESENT	0
85661	85636	01016M	PARTICIPANT	\N	PRESENT	0
85662	85636	10015M	PARTICIPANT	\N	PRESENT	0
85664	85636	95063L	PARTICIPANT	\N	PRESENT	0
85665	85636	04045F	PARTICIPANT	\N	EXCUSE	0
85666	85636	98035U	PARTICIPANT	\N	PRESENT	0
85668	85636	92045V	PARTICIPANT	\N	PRESENT	0
85669	85636	04034C	PARTICIPANT	\N	PRESENT	0
85671	85636	04035D	PARTICIPANT	\N	PRESENT	0
85676	85636	11106F	PARTICIPANT	\N	PRESENT	0
85677	85636	11076S	PARTICIPANT	\N	PRESENT	0
85678	85636	11054L	PARTICIPANT	\N	PRESENT	0
85679	85636	11105E	PARTICIPANT	\N	PRESENT	0
85680	85636	01024M	PARTICIPANT	\N	PRESENT	0
85681	85636	95059Q	PARTICIPANT	\N	PRESENT	0
85682	85636	04047H	PARTICIPANT	\N	PRESENT	0
85683	85636	95035G	PARTICIPANT	\N	PRESENT	0
89963	89079	89029V	PARTICIPANT	\N	PRESENT	0
89964	89079	08009T	PARTICIPANT	\N	PRESENT	0
89965	89079	01015L	PARTICIPANT	\N	PRESENT	0
89966	89079	11098Y	PARTICIPANT	\N	PRESENT	0
89967	89079	01022K	PARTICIPANT	\N	PRESENT	0
89968	89079	14051J	PARTICIPANT	\N	PRESENT	0
89969	89079	14197C	PARTICIPANT	\N	PRESENT	0
89970	89079	08060W	PARTICIPANT	\N	PRESENT	0
89971	89079	11066Q	PARTICIPANT	\N	PRESENT	0
89972	89079	11067R	PARTICIPANT	\N	PRESENT	0
89973	89079	14097Y	PARTICIPANT	\N	PRESENT	0
89974	89079	11023D	PARTICIPANT	\N	PRESENT	0
89975	89079	11107G	PARTICIPANT	\N	PRESENT	0
89976	89079	14159V	PARTICIPANT	\N	PRESENT	0
89977	89079	95049N	PARTICIPANT	\N	PRESENT	0
90020	89079	05012A	PARTICIPANT	\N	PRESENT	0
89979	89079	14069U	PARTICIPANT	\N	PRESENT	0
89980	89079	95062K	PARTICIPANT	\N	PRESENT	0
89981	89079	11048N	PARTICIPANT	\N	PRESENT	0
89982	89079	11090Q	PARTICIPANT	\N	PRESENT	0
89983	89079	08022Q	PARTICIPANT	\N	PRESENT	0
89984	89079	86044G	PARTICIPANT	\N	PRESENT	0
89985	89079	14217N	PARTICIPANT	\N	PRESENT	0
89986	89079	01057W	PARTICIPANT	\N	PRESENT	0
89987	89079	14265W	PARTICIPANT	\N	PRESENT	0
89988	89079	14026U	PARTICIPANT	\N	PRESENT	0
89989	89079	11103C	PARTICIPANT	\N	PRESENT	0
89990	89079	14038Y	PARTICIPANT	\N	PRESENT	0
89991	89079	97011G	PARTICIPANT	\N	PRESENT	0
89992	89079	01013J	PARTICIPANT	\N	PRESENT	0
89993	89079	14169X	PARTICIPANT	\N	PRESENT	0
89994	89079	14207L	PARTICIPANT	\N	PRESENT	0
89995	89079	14031R	PARTICIPANT	\N	PRESENT	0
89996	89079	11059R	PARTICIPANT	\N	PRESENT	0
89997	89079	14033T	PARTICIPANT	\N	PRESENT	0
89998	89079	14135M	PARTICIPANT	\N	PRESENT	0
89999	89079	08019V	PARTICIPANT	\N	PRESENT	0
90000	89079	01008M	PARTICIPANT	\N	PRESENT	0
90001	89079	14041T	PARTICIPANT	\N	PRESENT	0
90002	89079	07029T	PARTICIPANT	\N	PRESENT	0
90003	89079	04088S	PARTICIPANT	\N	PRESENT	0
90004	89079	08053X	PARTICIPANT	\N	PRESENT	0
90005	89079	11114F	PARTICIPANT	\N	PRESENT	0
90006	89079	11012A	PARTICIPANT	\N	PRESENT	0
90007	89079	14107H	PARTICIPANT	\N	PRESENT	0
90008	89079	04045F	PARTICIPANT	\N	PRESENT	0
90009	89079	09001P	PARTICIPANT	\N	PRESENT	0
90010	89079	14215L	PARTICIPANT	\N	PRESENT	0
90011	89079	14219Q	PARTICIPANT	\N	PRESENT	0
90012	89079	01061S	PARTICIPANT	\N	PRESENT	0
90013	89079	11056N	PARTICIPANT	\N	PRESENT	0
90014	89079	04089T	PARTICIPANT	\N	PRESENT	0
90015	89079	11099A	PARTICIPANT	\N	PRESENT	0
90016	89079	11065P	PARTICIPANT	\N	PRESENT	0
90017	89079	92039X	PARTICIPANT	\N	PRESENT	0
90018	89079	14327T	PARTICIPANT	\N	PRESENT	0
90019	89079	01043Q	PARTICIPANT	\N	PRESENT	0
90021	89079	14039A	PARTICIPANT	\N	PRESENT	0
90022	89079	08055A	PARTICIPANT	\N	PRESENT	0
90023	89079	14331P	PARTICIPANT	\N	PRESENT	0
90024	89079	14237S	PARTICIPANT	\N	PRESENT	0
90025	89079	08014Q	PARTICIPANT	\N	PRESENT	0
90026	89079	04097T	PARTICIPANT	\N	PRESENT	0
90085	89079	11029K	PARTICIPANT	\N	PRESENT	0
90086	89079	01044R	PARTICIPANT	\N	PRESENT	0
90087	89079	08051V	PARTICIPANT	\N	PRESENT	0
90088	89079	08031R	PARTICIPANT	\N	PRESENT	0
90089	89079	01028R	PARTICIPANT	\N	PRESENT	0
90090	89079	92015P	PARTICIPANT	\N	PRESENT	0
90091	89079	14271U	PARTICIPANT	\N	PRESENT	0
90092	89079	08052W	PARTICIPANT	\N	PRESENT	0
90093	89079	14109K	PARTICIPANT	\N	PRESENT	0
90094	89079	11061K	PARTICIPANT	\N	PRESENT	0
90095	89079	11043H	PARTICIPANT	\N	PRESENT	0
90096	89079	14157T	PARTICIPANT	\N	PRESENT	0
90174	89069	07034Q	PARTICIPANT	\N	PRESENT	0
90175	89069	14093U	PARTICIPANT	\N	PRESENT	0
90176	89069	11098Y	PARTICIPANT	\N	PRESENT	0
90177	89069	09001P	PARTICIPANT	\N	PRESENT	0
90178	89069	14215L	PARTICIPANT	\N	PRESENT	0
90179	89069	04089T	PARTICIPANT	\N	PRESENT	0
90180	89069	11090Q	PARTICIPANT	\N	PRESENT	0
90181	89069	14157T	PARTICIPANT	\N	PRESENT	0
90182	89069	14038Y	PARTICIPANT	\N	PRESENT	0
90207	89069	14159V	PARTICIPANT	\N	PRESENT	0
90184	89069	95062K	PARTICIPANT	\N	PRESENT	0
90185	89069	11012A	PARTICIPANT	\N	PRESENT	0
90186	89069	14237S	PARTICIPANT	\N	PRESENT	0
90187	89069	14069U	PARTICIPANT	\N	PRESENT	0
90188	89069	14187A	PARTICIPANT	\N	PRESENT	0
90189	89069	11103C	PARTICIPANT	\N	PRESENT	0
90190	89069	95030B	PARTICIPANT	\N	PRESENT	0
90191	89069	01008M	PARTICIPANT	\N	PRESENT	0
90192	89069	01015L	PARTICIPANT	\N	PRESENT	0
90193	89069	01044R	PARTICIPANT	\N	PRESENT	0
90194	89069	92015P	PARTICIPANT	\N	PRESENT	0
90195	89069	14033T	PARTICIPANT	\N	PRESENT	0
90196	89069	11099A	PARTICIPANT	\N	PRESENT	0
90197	89069	04088S	PARTICIPANT	\N	PRESENT	0
90198	89069	04049K	PARTICIPANT	\N	PRESENT	0
90199	89069	05012A	PARTICIPANT	\N	PRESENT	0
90200	89069	11107G	PARTICIPANT	\N	PRESENT	0
90201	89069	11065P	PARTICIPANT	\N	PRESENT	0
90202	89069	08060W	PARTICIPANT	\N	PRESENT	0
90203	89069	14213J	PARTICIPANT	\N	PRESENT	0
90204	89069	14331P	PARTICIPANT	\N	PRESENT	0
90205	89069	80027E	PARTICIPANT	\N	PRESENT	0
90206	89069	13002U	PARTICIPANT	\N	PRESENT	0
90208	89069	14257W	PARTICIPANT	\N	PRESENT	0
90209	89069	14265W	PARTICIPANT	\N	PRESENT	0
90210	89069	01025N	PARTICIPANT	\N	PRESENT	0
90211	89069	11114F	PARTICIPANT	\N	PRESENT	0
90212	89069	11023D	PARTICIPANT	\N	PRESENT	0
90213	89069	14207L	PARTICIPANT	\N	PRESENT	0
90214	89069	14097Y	PARTICIPANT	\N	PRESENT	0
90215	89069	04097T	PARTICIPANT	\N	PRESENT	0
90216	89069	14167V	PARTICIPANT	\N	PRESENT	0
90217	89069	14051J	PARTICIPANT	\N	PRESENT	0
90218	89069	14059S	PARTICIPANT	\N	PRESENT	0
90219	89069	11036J	PARTICIPANT	\N	PRESENT	0
90220	89069	11097X	PARTICIPANT	\N	PRESENT	0
90221	89069	14217N	PARTICIPANT	\N	PRESENT	0
90222	89069	11056N	PARTICIPANT	\N	PRESENT	0
90223	89069	08039A	PARTICIPANT	\N	PRESENT	0
90224	89069	04033B	PARTICIPANT	\N	PRESENT	0
90225	89069	14073Q	PARTICIPANT	\N	PRESENT	0
90226	89069	08019V	PARTICIPANT	\N	PRESENT	0
90227	89069	14107H	PARTICIPANT	\N	PRESENT	0
90228	89069	90003B	PARTICIPANT	\N	PRESENT	0
90229	89069	14135M	PARTICIPANT	\N	PRESENT	0
90230	89069	08015R	PARTICIPANT	\N	PRESENT	0
90231	89069	14119M	PARTICIPANT	\N	PRESENT	0
90232	89069	14253S	PARTICIPANT	\N	PRESENT	0
90233	89069	11049P	PARTICIPANT	\N	PRESENT	0
90234	89069	11112D	PARTICIPANT	\N	PRESENT	0
90235	89069	14030Q	PARTICIPANT	\N	PRESENT	0
90236	89069	04040A	PARTICIPANT	\N	PRESENT	0
90237	89069	14026U	PARTICIPANT	\N	PRESENT	0
90238	89069	11048N	PARTICIPANT	\N	PRESENT	0
90239	89069	14083S	PARTICIPANT	\N	PRESENT	0
90240	89069	92045V	PARTICIPANT	\N	PRESENT	0
90241	89069	07029T	PARTICIPANT	\N	PRESENT	0
90242	89069	14031R	PARTICIPANT	\N	PRESENT	0
90243	89069	01037S	PARTICIPANT	\N	PRESENT	0
90255	90254	05012A	PARTICIPANT	\N	PRESENT	0
90256	90254	11101A	PARTICIPANT	\N	PRESENT	0
90257	90254	08038Y	PARTICIPANT	\N	PRESENT	0
90328	90327	14037X	PARTICIPANT	\N	PRESENT	0
90329	90327	14034U	PARTICIPANT	\N	PRESENT	0
90330	90327	14087W	PARTICIPANT	\N	PRESENT	0
90172	89069	08055A	PARTICIPANT	\N	PRESENT	0
90173	89069	08009T	PARTICIPANT	\N	PRESENT	0
90332	90331	14087W	PARTICIPANT	\N	PRESENT	0
90333	90331	14034U	PARTICIPANT	\N	PRESENT	0
90334	90331	14037X	PARTICIPANT	\N	PRESENT	0
90336	90335	14087W	PARTICIPANT	\N	PRESENT	0
90337	90335	14034U	PARTICIPANT	\N	PRESENT	0
90338	90335	14037X	PARTICIPANT	\N	PRESENT	0
90340	90339	14087W	PARTICIPANT	\N	PRESENT	0
90341	90339	14034U	PARTICIPANT	\N	PRESENT	0
90342	90339	14037X	PARTICIPANT	\N	PRESENT	0
90344	90343	14087W	PARTICIPANT	\N	PRESENT	0
90345	90343	14034U	PARTICIPANT	\N	PRESENT	0
90346	90343	14037X	PARTICIPANT	\N	PRESENT	0
90348	90347	14087W	PARTICIPANT	\N	PRESENT	0
90349	90347	14034U	PARTICIPANT	\N	PRESENT	0
90350	90347	14037X	PARTICIPANT	\N	PRESENT	0
90352	90351	14087W	PARTICIPANT	\N	PRESENT	0
70635	70572	14001X	PARTICIPANT	\N	PRESENT	0
70633	70572	01016M	PARTICIPANT	\N	PRESENT	0
70634	70572	96004D	PARTICIPANT	\N	PRESENT	0
70636	70572	14133K	PARTICIPANT	\N	PRESENT	0
70637	70572	11012A	PARTICIPANT	\N	PRESENT	0
70638	70572	14026U	PARTICIPANT	\N	PRESENT	0
70639	70572	04045F	PARTICIPANT	\N	PRESENT	0
70640	70572	14089Y	PARTICIPANT	\N	PRESENT	0
70641	70572	14135M	PARTICIPANT	\N	PRESENT	0
70642	70572	90003B	PARTICIPANT	\N	PRESENT	0
70643	70572	11026G	PARTICIPANT	\N	PRESENT	0
70644	70572	01008M	PARTICIPANT	\N	PRESENT	0
70645	70572	11036J	PARTICIPANT	\N	PRESENT	0
70646	70572	14013P	PARTICIPANT	\N	PRESENT	0
70647	70572	08068F	PARTICIPANT	\N	PRESENT	0
70648	70572	14207L	PARTICIPANT	\N	PRESENT	0
70649	70572	08028W	PARTICIPANT	\N	PRESENT	0
70650	70572	80013X	PARTICIPANT	\N	PRESENT	0
70651	70572	08038Y	PARTICIPANT	\N	PRESENT	0
70652	70572	14197C	PARTICIPANT	\N	PRESENT	0
70653	70572	14187A	PARTICIPANT	\N	PRESENT	0
70654	70572	14033T	PARTICIPANT	\N	PRESENT	0
70655	70572	04048J	PARTICIPANT	\N	PRESENT	0
70656	70572	11099A	PARTICIPANT	\N	PRESENT	0
70657	70572	04049K	PARTICIPANT	\N	PRESENT	0
70658	70572	11111C	PARTICIPANT	\N	PRESENT	0
70659	70572	08015R	PARTICIPANT	\N	PRESENT	0
70660	70572	11100Y	PARTICIPANT	\N	PRESENT	0
70661	70572	01061S	PARTICIPANT	\N	PRESENT	0
70662	70572	11098Y	PARTICIPANT	\N	PRESENT	0
70663	70572	11077T	PARTICIPANT	\N	PRESENT	0
70664	70572	14205J	PARTICIPANT	\N	PRESENT	0
70665	70572	14257W	PARTICIPANT	\N	PRESENT	0
70666	70572	11090Q	PARTICIPANT	\N	PRESENT	0
70667	70572	11046L	PARTICIPANT	\N	PRESENT	0
70668	70572	11094U	PARTICIPANT	\N	PRESENT	0
70669	70572	11066Q	PARTICIPANT	\N	PRESENT	0
70717	70716	11076S	PARTICIPANT	\N	PRESENT	0
70718	70716	04054G	PARTICIPANT	\N	PRESENT	0
70719	70716	04040A	PARTICIPANT	\N	PRESENT	0
70720	70716	08058D	PARTICIPANT	\N	PRESENT	0
70721	70716	04042C	PARTICIPANT	\N	PRESENT	0
70722	70716	77002U	PARTICIPANT	\N	PRESENT	0
70723	70716	98029W	PARTICIPANT	\N	PRESENT	0
70724	70716	11080N	PARTICIPANT	\N	PRESENT	0
70725	70716	11027H	PARTICIPANT	\N	PRESENT	0
70726	70716	98018T	PARTICIPANT	\N	PRESENT	0
70727	70716	92018S	PARTICIPANT	\N	PRESENT	0
70728	70716	92020L	PARTICIPANT	\N	PRESENT	0
70729	70716	95030B	PARTICIPANT	\N	PRESENT	0
70730	70716	11096W	PARTICIPANT	\N	PRESENT	0
70731	70716	95031C	PARTICIPANT	\N	PRESENT	0
70732	70716	97011G	PARTICIPANT	\N	PRESENT	0
70733	70716	08065C	PARTICIPANT	\N	PRESENT	0
70734	70716	04035D	PARTICIPANT	\N	PRESENT	0
70735	70716	07024N	PARTICIPANT	\N	PRESENT	0
70736	70716	04095R	PARTICIPANT	\N	PRESENT	0
70737	70716	14014Q	PARTICIPANT	\N	PRESENT	0
70738	70716	11015D	PARTICIPANT	\N	PRESENT	0
70739	70716	07004J	PARTICIPANT	\N	PRESENT	0
70740	70716	95035G	PARTICIPANT	\N	PRESENT	0
70741	70716	08056B	PARTICIPANT	\N	EXCUSE	0
70742	70716	14211G	PARTICIPANT	\N	PRESENT	0
70743	70716	98022P	PARTICIPANT	\N	PRESENT	0
70744	70716	11064N	PARTICIPANT	\N	PRESENT	0
72253	70704	01048V	PARTICIPANT	\N	PRESENT	0
70746	70716	04078Q	PARTICIPANT	\N	PRESENT	0
70747	70716	14097Y	PARTICIPANT	\N	PRESENT	0
70748	70716	95041E	PARTICIPANT	\N	PRESENT	0
70749	70716	04036E	PARTICIPANT	\N	EXCUSE	0
72254	70704	14213J	PARTICIPANT	\N	PRESENT	0
72244	70704	89029V	PARTICIPANT	\N	PRESENT	0
72245	70704	08022Q	PARTICIPANT	\N	PRESENT	0
70753	70716	92031P	PARTICIPANT	\N	PRESENT	0
70754	70716	11106F	PARTICIPANT	\N	PRESENT	0
70755	70716	14251Q	PARTICIPANT	\N	PRESENT	0
70756	70716	83042R	PARTICIPANT	\N	PRESENT	0
70757	70716	08053X	PARTICIPANT	\N	PRESENT	0
70758	70716	11082Q	PARTICIPANT	\N	PRESENT	0
70759	70716	11105E	PARTICIPANT	\N	PRESENT	0
70760	70716	14253S	PARTICIPANT	\N	EXCUSE	0
70761	70716	08047A	PARTICIPANT	\N	PRESENT	0
70762	70716	14028W	PARTICIPANT	\N	EXCUSE	0
70763	70716	14193X	PARTICIPANT	\N	PRESENT	0
70764	70716	98021N	PARTICIPANT	\N	PRESENT	0
72255	70704	14179A	PARTICIPANT	\N	PRESENT	0
70766	70716	04080J	PARTICIPANT	\N	PRESENT	0
70767	70716	95059Q	PRESIDENT	0	PRESENT	0
70768	70716	86044G	PARTICIPANT	\N	PRESENT	0
70769	70716	01014K	PARTICIPANT	\N	PRESENT	0
70770	70716	11054L	PARTICIPANT	\N	PRESENT	0
70771	70716	01056V	PARTICIPANT	\N	PRESENT	0
70772	70716	92044U	PARTICIPANT	\N	PRESENT	0
70773	70716	08049C	PARTICIPANT	\N	PRESENT	0
72256	70704	14033T	PARTICIPANT	\N	PRESENT	0
72257	70704	08017T	PARTICIPANT	\N	PRESENT	0
72258	70704	14273W	PARTICIPANT	\N	PRESENT	0
72259	70704	01060R	PARTICIPANT	\N	PRESENT	0
72260	70704	08051V	PARTICIPANT	\N	PRESENT	0
72261	70704	14173T	PARTICIPANT	\N	PRESENT	0
72262	70704	00003C	PARTICIPANT	\N	PRESENT	0
72264	70704	14026U	PARTICIPANT	\N	PRESENT	0
72265	70704	08028W	PARTICIPANT	\N	PRESENT	0
72266	70704	08073C	PARTICIPANT	\N	PRESENT	0
72267	70704	11048N	PARTICIPANT	\N	PRESENT	0
72268	70704	92018S	PARTICIPANT	\N	PRESENT	0
72269	70704	08010L	PARTICIPANT	\N	PRESENT	0
72270	70704	14187A	PARTICIPANT	\N	PRESENT	0
72271	70704	08055A	PARTICIPANT	\N	PRESENT	0
72272	70704	11098Y	PARTICIPANT	\N	PRESENT	0
72273	70704	11094U	PARTICIPANT	\N	PRESENT	0
72274	70704	11107G	PARTICIPANT	\N	PRESENT	0
72294	70708	89029V	PARTICIPANT	\N	PRESENT	0
72295	70708	07026Q	PARTICIPANT	\N	PRESENT	0
72296	70708	92018S	PARTICIPANT	\N	PRESENT	0
72297	70708	11054L	PARTICIPANT	\N	PRESENT	0
72298	70708	11089X	PARTICIPANT	\N	PRESENT	0
72299	70708	14197C	PARTICIPANT	\N	PRESENT	0
72300	70708	00003C	PARTICIPANT	\N	PRESENT	0
72301	70708	14107H	PARTICIPANT	\N	PRESENT	0
72302	70708	92020L	PARTICIPANT	\N	PRESENT	0
72303	70708	11112D	PARTICIPANT	\N	PRESENT	0
72304	70708	08014Q	PARTICIPANT	\N	PRESENT	0
72246	70704	11026G	PARTICIPANT	\N	PRESENT	0
72247	70704	14193X	PARTICIPANT	\N	PRESENT	0
72248	70704	11066Q	PARTICIPANT	\N	PRESENT	0
72249	70704	11055M	PARTICIPANT	\N	PRESENT	0
72252	70704	14271U	PARTICIPANT	\N	PRESENT	0
72305	70708	14097Y	PARTICIPANT	\N	PRESENT	0
72306	70708	01031L	PARTICIPANT	\N	PRESENT	0
72307	70708	14225N	PARTICIPANT	\N	PRESENT	0
72308	70708	13002U	PARTICIPANT	\N	PRESENT	0
72309	70708	01022K	PARTICIPANT	\N	PRESENT	0
72310	70708	01014K	PARTICIPANT	\N	PRESENT	0
72311	70708	11037K	PARTICIPANT	\N	PRESENT	0
72312	70708	95059Q	PARTICIPANT	\N	PRESENT	0
72313	70708	14103D	PARTICIPANT	\N	PRESENT	0
72314	70708	14219Q	PARTICIPANT	\N	PRESENT	0
72315	70708	14042U	PARTICIPANT	\N	PRESENT	0
72316	70708	14221J	PARTICIPANT	\N	PRESENT	0
72317	70708	07004J	PARTICIPANT	\N	PRESENT	0
72318	70708	14179A	PARTICIPANT	\N	PRESENT	0
72319	70708	14327T	PARTICIPANT	\N	PRESENT	0
72320	70708	11106F	PARTICIPANT	\N	PRESENT	0
72321	70708	04040A	PARTICIPANT	\N	PRESENT	0
72322	70708	14087W	PARTICIPANT	\N	PRESENT	0
72323	70708	08058D	PARTICIPANT	\N	PRESENT	0
72324	70708	11076S	PARTICIPANT	\N	PRESENT	0
72325	70708	08053X	PARTICIPANT	\N	PRESENT	0
72326	70708	11042G	PARTICIPANT	\N	PRESENT	0
72327	70708	98022P	PARTICIPANT	\N	PRESENT	0
72328	70708	01016M	PARTICIPANT	\N	PRESENT	0
72329	70708	04078Q	PARTICIPANT	\N	PRESENT	0
72330	70708	14071N	PARTICIPANT	\N	PRESENT	0
72331	70708	98021N	PARTICIPANT	\N	PRESENT	0
72332	70708	14053L	PARTICIPANT	\N	PRESENT	0
72333	70708	14059S	PARTICIPANT	\N	PRESENT	0
72334	70708	14187A	PARTICIPANT	\N	PRESENT	0
72335	70708	97011G	PARTICIPANT	\N	PRESENT	0
72336	70708	04081K	PARTICIPANT	\N	PRESENT	0
72337	70708	14193X	PARTICIPANT	\N	PRESENT	0
72338	70708	08022Q	PARTICIPANT	\N	PRESENT	0
72339	70708	07024N	PARTICIPANT	\N	PRESENT	0
72340	70708	99004R	PARTICIPANT	\N	PRESENT	0
72341	70708	11043H	PARTICIPANT	\N	PRESENT	0
72342	70708	14223L	PARTICIPANT	\N	PRESENT	0
72343	70708	08010L	PARTICIPANT	\N	PRESENT	0
72344	70708	87003B	PARTICIPANT	\N	PRESENT	0
72345	70708	01057W	PARTICIPANT	\N	PRESENT	0
73981	72860	11080N	PARTICIPANT	\N	PRESENT	0
73982	72860	14219Q	PARTICIPANT	\N	PRESENT	0
73983	72860	05008E	PARTICIPANT	\N	PRESENT	0
73984	72860	11054L	PARTICIPANT	\N	PRESENT	0
73985	72860	04057K	PARTICIPANT	\N	PRESENT	0
73986	72860	11103C	PARTICIPANT	\N	PRESENT	0
73987	72860	98053W	PARTICIPANT	\N	PRESENT	0
73988	72860	04047H	PARTICIPANT	\N	PRESENT	0
73989	72860	04054G	PARTICIPANT	\N	PRESENT	0
73990	72860	01011G	PARTICIPANT	\N	PRESENT	0
73991	72860	11059R	PARTICIPANT	\N	PRESENT	0
73992	72860	14197C	PARTICIPANT	\N	PRESENT	0
73993	72860	14207L	PARTICIPANT	\N	PRESENT	0
73994	72860	11015D	PARTICIPANT	\N	PRESENT	0
73995	72860	11067R	PARTICIPANT	\N	PRESENT	0
73996	72860	11077T	PARTICIPANT	\N	PRESENT	0
73997	72860	11033F	PARTICIPANT	\N	PRESENT	0
73998	72860	13002U	PARTICIPANT	\N	PRESENT	0
73999	72860	14107H	PARTICIPANT	\N	PRESENT	0
74000	72860	11026G	PARTICIPANT	\N	PRESENT	0
74001	72860	11036J	PARTICIPANT	\N	PRESENT	0
74002	72860	95063L	PARTICIPANT	\N	PRESENT	0
74003	72860	08052W	PARTICIPANT	\N	PRESENT	0
74004	72860	11035H	PARTICIPANT	\N	PRESENT	0
74005	72860	11084S	PARTICIPANT	\N	PRESENT	0
74006	72860	14263U	PARTICIPANT	\N	PRESENT	0
74007	72860	04085P	PARTICIPANT	\N	PRESENT	0
74008	72860	11063M	PARTICIPANT	\N	PRESENT	0
74009	72860	11034G	PARTICIPANT	\N	PRESENT	0
74010	72860	14227Q	PARTICIPANT	\N	PRESENT	0
74011	72860	14159V	PARTICIPANT	\N	PRESENT	0
74012	72860	11037K	PARTICIPANT	\N	PRESENT	0
74013	72860	14103D	PARTICIPANT	\N	PRESENT	0
74014	72860	14201E	PARTICIPANT	\N	PRESENT	0
74015	72860	14089Y	PARTICIPANT	\N	PRESENT	0
74016	72860	14267Y	PARTICIPANT	\N	PRESENT	0
74017	72860	14221J	PARTICIPANT	\N	PRESENT	0
74018	72860	14073Q	PARTICIPANT	\N	PRESENT	0
74019	72860	14327T	PARTICIPANT	\N	PRESENT	0
74020	72860	01047U	PARTICIPANT	\N	PRESENT	0
74021	72860	14215L	PARTICIPANT	\N	PRESENT	0
74022	72860	14087W	PARTICIPANT	\N	PRESENT	0
74023	72860	14273W	PARTICIPANT	\N	PRESENT	0
74024	72860	14217N	PARTICIPANT	\N	PRESENT	0
74025	72860	01028R	PARTICIPANT	\N	PRESENT	0
74026	72860	14037X	PARTICIPANT	\N	PRESENT	0
74027	72860	08028W	PARTICIPANT	\N	PRESENT	0
74028	72860	04086Q	PARTICIPANT	\N	PRESENT	0
74029	72860	10006L	PARTICIPANT	\N	PRESENT	0
74030	72860	95059Q	PARTICIPANT	\N	PRESENT	0
74031	72860	14223L	PARTICIPANT	\N	PRESENT	0
74032	72860	11044J	PARTICIPANT	\N	PRESENT	0
74033	72860	01048V	PARTICIPANT	\N	PRESENT	0
74034	72860	08034U	PARTICIPANT	\N	PRESENT	0
74035	72860	14213J	PARTICIPANT	\N	PRESENT	0
74036	72860	14265W	PARTICIPANT	\N	PRESENT	0
74037	72860	11091R	PARTICIPANT	\N	PRESENT	0
74038	72860	08047A	PARTICIPANT	\N	PRESENT	0
74039	72860	04049K	PARTICIPANT	\N	PRESENT	0
74040	72860	08010L	PARTICIPANT	\N	PRESENT	0
74041	72860	14031R	PARTICIPANT	\N	PRESENT	0
74042	72860	14157T	PARTICIPANT	\N	PRESENT	0
74043	72860	14195A	PARTICIPANT	\N	PRESENT	0
74044	72860	14173T	PARTICIPANT	\N	PRESENT	0
74045	72860	14169X	PARTICIPANT	\N	PRESENT	0
74046	72860	14105F	PARTICIPANT	\N	PRESENT	0
74047	72860	14038Y	PARTICIPANT	\N	PRESENT	0
74048	72860	08018U	PARTICIPANT	\N	PRESENT	0
74049	72860	11071M	PARTICIPANT	\N	PRESENT	0
74050	72860	11100Y	PARTICIPANT	\N	PRESENT	0
74051	72860	14041T	PARTICIPANT	\N	PRESENT	0
74052	72860	11040E	PARTICIPANT	\N	PRESENT	0
74053	72860	07026Q	PARTICIPANT	\N	PRESENT	0
74054	72860	01022K	PARTICIPANT	\N	PRESENT	0
74055	72860	04034C	PARTICIPANT	\N	PRESENT	0
74056	72860	14121F	PARTICIPANT	\N	PRESENT	0
74057	72860	14097Y	PARTICIPANT	\N	PRESENT	0
74058	72860	11107G	PARTICIPANT	\N	PRESENT	0
74059	72860	08043V	PARTICIPANT	\N	PRESENT	0
74060	72860	08055A	PARTICIPANT	\N	PRESENT	0
74061	72860	14235Q	PARTICIPANT	\N	PRESENT	0
74062	72860	14281W	PARTICIPANT	\N	PRESENT	0
74063	72860	14030Q	PARTICIPANT	\N	PRESENT	0
74064	72860	08031R	PARTICIPANT	\N	PRESENT	0
74065	72860	08051V	PARTICIPANT	\N	PRESENT	0
74066	72860	04038G	PARTICIPANT	\N	PRESENT	0
74067	72860	14071N	PARTICIPANT	\N	PRESENT	0
74068	72860	01058X	PARTICIPANT	\N	PRESENT	0
74069	72860	77002U	PARTICIPANT	\N	PRESENT	0
74070	72860	95015C	PARTICIPANT	\N	PRESENT	0
74071	72860	04043D	PARTICIPANT	\N	PRESENT	0
74072	72860	04081K	PARTICIPANT	\N	PRESENT	0
74073	72860	04092N	PARTICIPANT	\N	PRESENT	0
74074	72860	14187A	PARTICIPANT	\N	PRESENT	0
74075	72860	11090Q	PARTICIPANT	\N	PRESENT	0
74076	72860	08062Y	PARTICIPANT	\N	PRESENT	0
74077	72860	14251Q	PARTICIPANT	\N	PRESENT	0
74078	72860	11097X	PARTICIPANT	\N	PRESENT	0
74079	72860	01057W	PARTICIPANT	\N	PRESENT	0
74080	72860	86034E	PARTICIPANT	\N	PRESENT	0
74081	72860	01027Q	PARTICIPANT	\N	PRESENT	0
74082	72860	96004D	PARTICIPANT	\N	PRESENT	0
74083	72860	01025N	PARTICIPANT	\N	PRESENT	0
74084	72860	99004R	PARTICIPANT	\N	PRESENT	0
74085	72860	98023Q	PARTICIPANT	\N	PRESENT	0
74086	72860	07032N	PARTICIPANT	\N	PRESENT	0
74087	72860	01060R	PARTICIPANT	\N	PRESENT	0
74088	72860	14247U	PARTICIPANT	\N	PRESENT	0
74089	72860	14331P	PARTICIPANT	\N	PRESENT	0
74090	72860	01041N	PARTICIPANT	\N	PRESENT	0
74091	72860	07034Q	PARTICIPANT	\N	PRESENT	0
74092	72860	11104D	PARTICIPANT	\N	PRESENT	0
74093	72860	14109K	PARTICIPANT	\N	PRESENT	0
74094	72860	11023D	PARTICIPANT	\N	PRESENT	0
74095	72860	01046T	PARTICIPANT	\N	PRESENT	0
74096	72860	08022Q	PARTICIPANT	\N	PRESENT	0
74097	72860	11093T	PARTICIPANT	\N	PRESENT	0
73980	72860	04048J	PARTICIPANT	\N	PRESENT	0
74098	72860	14231L	PARTICIPANT	\N	PRESENT	0
74099	72860	14079W	PARTICIPANT	\N	PRESENT	0
74100	72860	04095R	PARTICIPANT	\N	PRESENT	0
74101	72860	14033T	PARTICIPANT	\N	PRESENT	0
74102	72860	14061L	PARTICIPANT	\N	PRESENT	0
74103	72860	08017T	PARTICIPANT	\N	PRESENT	0
74104	72860	11105E	PARTICIPANT	\N	PRESENT	0
74105	72860	80013X	PARTICIPANT	\N	PRESENT	0
74106	72860	98022P	PARTICIPANT	\N	PRESENT	0
74107	72860	08009T	PARTICIPANT	\N	PRESENT	0
74108	72860	92015P	PARTICIPANT	\N	PRESENT	0
74109	72860	14271U	PARTICIPANT	\N	PRESENT	0
74110	72860	11042G	PARTICIPANT	\N	PRESENT	0
74111	72860	95049N	PARTICIPANT	\N	PRESENT	0
74112	72860	98042T	PARTICIPANT	\N	PRESENT	0
74113	72860	14119M	PARTICIPANT	\N	PRESENT	0
74114	72860	14135M	PARTICIPANT	\N	PRESENT	0
74115	72860	14151M	PARTICIPANT	\N	PRESENT	0
74117	72860	04077P	PARTICIPANT	\N	PRESENT	0
74118	72860	14014Q	PARTICIPANT	\N	PRESENT	0
74119	72860	01043Q	PARTICIPANT	\N	PRESENT	0
74121	72860	08044W	PARTICIPANT	\N	PRESENT	0
74135	72860	04033B	PARTICIPANT	\N	PRESENT	0
74143	72860	14225N	PARTICIPANT	\N	PRESENT	0
74144	72860	01007L	PARTICIPANT	\N	PRESENT	0
74145	72860	08053X	PARTICIPANT	\N	PRESENT	0
74146	72860	98035U	PARTICIPANT	\N	PRESENT	0
74147	72860	04094Q	PARTICIPANT	\N	PRESENT	0
74148	72860	89017R	PARTICIPANT	\N	PRESENT	0
74150	72860	04088S	PARTICIPANT	\N	PRESENT	0
74151	72860	14259Y	PARTICIPANT	\N	PRESENT	0
74152	72860	11112D	PARTICIPANT	\N	PRESENT	0
74153	72860	11088W	PARTICIPANT	\N	PRESENT	0
74154	72860	14053L	PARTICIPANT	\N	PRESENT	0
74160	72860	11061K	PARTICIPANT	\N	PRESENT	0
74161	72860	14193X	PARTICIPANT	\N	PRESENT	0
74162	72860	12042Y	PARTICIPANT	\N	PRESENT	0
74163	72860	92045V	PARTICIPANT	\N	PRESENT	0
74205	72860	11053K	PARTICIPANT	\N	PRESENT	0
74206	72860	86044G	PARTICIPANT	\N	PRESENT	0
74207	72860	07004J	PARTICIPANT	\N	PRESENT	0
74208	72860	04059M	PARTICIPANT	\N	PRESENT	0
73137	72250	86034E	PARTICIPANT	\N	PRESENT	0
73138	72250	11036J	PARTICIPANT	\N	PRESENT	0
73139	72250	11037K	PARTICIPANT	\N	PRESENT	0
73140	72250	80027E	PARTICIPANT	\N	PRESENT	0
73141	72250	14038Y	PARTICIPANT	\N	PRESENT	0
73142	72250	95031C	PARTICIPANT	\N	PRESENT	0
73143	72250	14087W	PARTICIPANT	\N	PRESENT	0
73144	72250	00003C	PARTICIPANT	\N	PRESENT	0
73145	72250	01003G	PARTICIPANT	\N	PRESENT	0
73146	72250	07034Q	PARTICIPANT	\N	PRESENT	0
73147	72250	11103C	PARTICIPANT	\N	PRESENT	0
73148	72250	14263U	PARTICIPANT	\N	PRESENT	0
73149	72250	07026Q	PARTICIPANT	\N	PRESENT	0
73150	72250	14267Y	PARTICIPANT	\N	PRESENT	0
73209	72250	11035H	PARTICIPANT	\N	PRESENT	0
73210	72250	13002U	PARTICIPANT	\N	PRESENT	0
73211	72250	14271U	PARTICIPANT	\N	PRESENT	0
73212	72250	11034G	PARTICIPANT	\N	PRESENT	0
73213	72250	87003B	PARTICIPANT	\N	PRESENT	0
73214	72250	08014Q	PARTICIPANT	\N	PRESENT	0
73215	72250	04059M	PARTICIPANT	\N	PRESENT	0
73216	72250	11067R	PARTICIPANT	\N	PRESENT	0
73217	72250	11031D	PARTICIPANT	\N	PRESENT	0
73218	72250	83047W	PARTICIPANT	\N	PRESENT	0
73219	72250	11059R	PARTICIPANT	\N	PRESENT	0
73220	72250	08025T	PARTICIPANT	\N	PRESENT	0
73221	72250	08052W	PARTICIPANT	\N	PRESENT	0
73222	72250	92020L	PARTICIPANT	\N	PRESENT	0
73223	72250	14065Q	PARTICIPANT	\N	PRESENT	0
73224	72250	14039A	PARTICIPANT	\N	PRESENT	0
73225	72250	11107G	PARTICIPANT	\N	PRESENT	0
73276	72250	08016S	PARTICIPANT	\N	PRESENT	0
73277	72250	01016M	PARTICIPANT	\N	PRESENT	0
73278	72250	95062K	PARTICIPANT	\N	PRESENT	0
73279	72250	98046X	PARTICIPANT	\N	PRESENT	0
73280	72250	04050C	PARTICIPANT	\N	PRESENT	0
73281	72250	04085P	PARTICIPANT	\N	PRESENT	0
73282	72250	14235Q	PARTICIPANT	\N	PRESENT	0
73283	72250	11063M	PARTICIPANT	\N	PRESENT	0
73284	72250	01013J	PARTICIPANT	\N	PRESENT	0
73285	72250	11026G	PARTICIPANT	\N	PRESENT	0
73286	72250	14281W	PARTICIPANT	\N	PRESENT	0
73287	72250	14227Q	PARTICIPANT	\N	PRESENT	0
73288	72250	01022K	PARTICIPANT	\N	PRESENT	0
73289	72250	14197C	PARTICIPANT	\N	PRESENT	0
73290	72250	14028W	PARTICIPANT	\N	PRESENT	0
73291	72250	01011G	PARTICIPANT	\N	PRESENT	0
73292	72250	08058D	PARTICIPANT	\N	PRESENT	0
73293	72250	11057P	PARTICIPANT	\N	PRESENT	0
73294	72250	11089X	PARTICIPANT	\N	PRESENT	0
73295	72250	14051J	PARTICIPANT	\N	PRESENT	0
73296	72250	14001X	PARTICIPANT	\N	PRESENT	0
73297	72250	14063N	PARTICIPANT	\N	PRESENT	0
73298	72250	08068F	PARTICIPANT	\N	PRESENT	0
73299	72250	08043V	PARTICIPANT	\N	PRESENT	0
73300	72250	11040E	PARTICIPANT	\N	PRESENT	0
73301	72250	08060W	PARTICIPANT	\N	PRESENT	0
73302	72250	14229S	PARTICIPANT	\N	PRESENT	0
73303	72250	04056J	PARTICIPANT	\N	PRESENT	0
73304	72250	14107H	PARTICIPANT	\N	PRESENT	0
73305	72250	04066L	PARTICIPANT	\N	PRESENT	0
73306	72250	14151M	PARTICIPANT	\N	PRESENT	0
73307	72250	95063L	PARTICIPANT	\N	PRESENT	0
73308	72250	04077P	PARTICIPANT	\N	PRESENT	0
73311	72250	11104D	PARTICIPANT	\N	PRESENT	0
73312	72250	08012N	PARTICIPANT	\N	PRESENT	0
73314	72250	08055A	PARTICIPANT	\N	PRESENT	0
73315	72250	11084S	PARTICIPANT	\N	PRESENT	0
73318	72250	14085U	PARTICIPANT	\N	PRESENT	0
73319	72250	08024S	PARTICIPANT	\N	PRESENT	0
73320	72250	11066Q	PARTICIPANT	\N	PRESENT	0
73324	72250	11061K	PARTICIPANT	\N	PRESENT	0
73325	72250	11074Q	PARTICIPANT	\N	PRESENT	0
73328	72250	04095R	PARTICIPANT	\N	PRESENT	0
73331	72250	11015D	PARTICIPANT	\N	PRESENT	0
73333	72250	14109K	PARTICIPANT	\N	PRESENT	0
73335	72250	14207L	PARTICIPANT	\N	PRESENT	0
73337	72250	14097Y	PARTICIPANT	\N	PRESENT	0
73339	72250	11112D	PARTICIPANT	\N	PRESENT	0
73342	72250	11095V	PARTICIPANT	\N	PRESENT	0
73346	72250	04078Q	PARTICIPANT	\N	PRESENT	0
73347	72250	08051V	PARTICIPANT	\N	PRESENT	0
73348	72250	01046T	PARTICIPANT	\N	PRESENT	0
73349	72250	11012A	PARTICIPANT	\N	PRESENT	0
73350	72250	08031R	PARTICIPANT	\N	PRESENT	0
73351	72250	08049C	PARTICIPANT	\N	PRESENT	0
73352	72250	14201E	PARTICIPANT	\N	PRESENT	0
73353	72250	11033F	PARTICIPANT	\N	PRESENT	0
73354	72250	11076S	PARTICIPANT	\N	PRESENT	0
73355	72250	14257W	PARTICIPANT	\N	PRESENT	0
73357	72250	11068S	PARTICIPANT	\N	PRESENT	0
73360	72250	95049N	PARTICIPANT	\N	PRESENT	0
73361	72250	01034P	PARTICIPANT	\N	PRESENT	0
73362	72250	11053K	PARTICIPANT	\N	PRESENT	0
73364	72250	04080J	PARTICIPANT	\N	PRESENT	0
73366	72250	14205J	PARTICIPANT	\N	PRESENT	0
73368	72250	14034U	PARTICIPANT	\N	PRESENT	0
73369	72250	11064N	PARTICIPANT	\N	PRESENT	0
73371	72250	14042U	PARTICIPANT	\N	PRESENT	0
73372	72250	14219Q	PARTICIPANT	\N	PRESENT	0
73373	72250	14103D	PARTICIPANT	\N	PRESENT	0
73375	72250	14221J	PARTICIPANT	\N	PRESENT	0
73377	72250	14030Q	PARTICIPANT	\N	PRESENT	0
73380	72250	14241N	PARTICIPANT	\N	PRESENT	0
73381	72250	14239U	PARTICIPANT	\N	PRESENT	0
73383	72250	98022P	PARTICIPANT	\N	PRESENT	0
73384	72250	14073Q	PARTICIPANT	\N	PRESENT	0
73386	72250	11093T	PARTICIPANT	\N	PRESENT	0
73387	72250	14231L	PARTICIPANT	\N	PRESENT	0
73388	72250	14083S	PARTICIPANT	\N	PRESENT	0
73389	72250	98042T	PARTICIPANT	\N	PRESENT	0
73390	72250	04089T	PARTICIPANT	\N	PRESENT	0
73392	72250	08044W	PARTICIPANT	\N	PRESENT	0
73393	72250	01047U	PARTICIPANT	\N	PRESENT	0
73395	72250	01024M	PARTICIPANT	\N	PRESENT	0
73396	72250	01025N	PARTICIPANT	\N	PRESENT	0
73397	72250	01007L	PARTICIPANT	\N	PRESENT	0
73399	72250	14327T	PARTICIPANT	\N	PRESENT	0
73402	72250	01043Q	PARTICIPANT	\N	PRESENT	0
73405	72250	04094Q	PARTICIPANT	\N	PRESENT	0
73407	72250	08017T	PARTICIPANT	\N	PRESENT	0
73408	72250	14089Y	PARTICIPANT	\N	PRESENT	0
73412	72250	14273W	PARTICIPANT	\N	PRESENT	0
73414	72250	14217N	PARTICIPANT	\N	PRESENT	0
73416	72250	14079W	PARTICIPANT	\N	PRESENT	0
73418	72250	14237S	PARTICIPANT	\N	PRESENT	0
73420	72250	14179A	PARTICIPANT	\N	PRESENT	0
73422	72250	14071N	PARTICIPANT	\N	PRESENT	0
73423	72250	14215L	PARTICIPANT	\N	PRESENT	0
73424	72250	04086Q	PARTICIPANT	\N	PRESENT	0
73425	72250	14331P	PARTICIPANT	\N	PRESENT	0
73426	72250	01008M	PARTICIPANT	\N	PRESENT	0
73427	72250	04047H	PARTICIPANT	\N	PRESENT	0
73428	72250	95030B	PARTICIPANT	\N	PRESENT	0
73429	72250	01019Q	PARTICIPANT	\N	PRESENT	0
73430	72250	04033B	PARTICIPANT	\N	PRESENT	0
73431	72250	98024R	PARTICIPANT	\N	PRESENT	0
73432	72250	04043D	PARTICIPANT	\N	PRESENT	0
73433	72250	04057K	PARTICIPANT	\N	PRESENT	0
73434	72250	05012A	PARTICIPANT	\N	PRESENT	0
73435	72250	04092N	PARTICIPANT	\N	PRESENT	0
73436	72250	01048V	PARTICIPANT	\N	PRESENT	0
73437	72250	14187A	PARTICIPANT	\N	PRESENT	0
73438	72250	04055H	PARTICIPANT	\N	PRESENT	0
73439	72250	14061L	PARTICIPANT	\N	PRESENT	0
73440	72250	14037X	PARTICIPANT	\N	PRESENT	0
73441	72250	08015R	PARTICIPANT	\N	PRESENT	0
73442	72250	14213J	PARTICIPANT	\N	PRESENT	0
73443	72250	08062Y	PARTICIPANT	\N	PRESENT	0
73444	72250	14265W	PARTICIPANT	\N	PRESENT	0
73445	72250	14147R	PARTICIPANT	\N	PRESENT	0
73446	72250	04081K	PARTICIPANT	\N	PRESENT	0
73447	72250	11044J	PARTICIPANT	\N	PRESENT	0
73449	72250	11100Y	PARTICIPANT	\N	PRESENT	0
73450	72250	14169X	PARTICIPANT	\N	PRESENT	0
73451	72250	14251Q	PARTICIPANT	\N	PRESENT	0
73452	72250	08047A	PARTICIPANT	\N	PRESENT	0
73453	72250	11097X	PARTICIPANT	\N	PRESENT	0
73454	72250	10015M	PARTICIPANT	\N	PRESENT	0
73455	72250	11071M	PARTICIPANT	\N	PRESENT	0
73456	72250	11043H	PARTICIPANT	\N	PRESENT	0
73457	72250	08010L	PARTICIPANT	\N	PRESENT	0
73458	72250	08028W	PARTICIPANT	\N	PRESENT	0
73459	72250	95015C	PARTICIPANT	\N	PRESENT	0
73460	72250	95059Q	PARTICIPANT	\N	PRESENT	0
73461	72250	96004D	PARTICIPANT	\N	PRESENT	0
73462	72250	99004R	PARTICIPANT	\N	PRESENT	0
73463	72250	01027Q	PARTICIPANT	\N	PRESENT	0
73685	72251	11067R	PARTICIPANT	\N	PRESENT	0
73686	72251	11033F	PARTICIPANT	\N	PRESENT	0
73687	72251	11107G	PARTICIPANT	\N	PRESENT	0
73688	72251	11015D	PARTICIPANT	\N	PRESENT	0
73689	72251	14271U	PARTICIPANT	\N	PRESENT	0
73690	72251	08017T	PARTICIPANT	\N	PRESENT	0
73691	72251	05008E	PARTICIPANT	\N	PRESENT	0
73692	72251	11037K	PARTICIPANT	\N	PRESENT	0
73693	72251	14103D	PARTICIPANT	\N	PRESENT	0
73694	72251	95049N	PARTICIPANT	\N	PRESENT	0
73695	72251	11053K	PARTICIPANT	\N	PRESENT	0
73696	72251	14089Y	PARTICIPANT	\N	PRESENT	0
73697	72251	01025N	PARTICIPANT	\N	PRESENT	0
73698	72251	14215L	PARTICIPANT	\N	PRESENT	0
73699	72251	14327T	PARTICIPANT	\N	PRESENT	0
73700	72251	14193X	PARTICIPANT	\N	PRESENT	0
73701	72251	07034Q	PARTICIPANT	\N	PRESENT	0
73702	72251	04081K	PARTICIPANT	\N	PRESENT	0
73703	72251	11103C	PARTICIPANT	\N	PRESENT	0
73704	72251	04092N	PARTICIPANT	\N	PRESENT	0
73705	72251	11090Q	PARTICIPANT	\N	PRESENT	0
73706	72251	95063L	PARTICIPANT	\N	PRESENT	0
73707	72251	11043H	PARTICIPANT	\N	PRESENT	0
73708	72251	14197C	PARTICIPANT	\N	PRESENT	0
73709	72251	14207L	PARTICIPANT	\N	PRESENT	0
73710	72251	11097X	PARTICIPANT	\N	PRESENT	0
73711	72251	04043D	PARTICIPANT	\N	PRESENT	0
73712	72251	14257W	PARTICIPANT	\N	PRESENT	0
73713	72251	14251Q	PARTICIPANT	\N	PRESENT	0
73714	72251	14031R	PARTICIPANT	\N	PRESENT	0
73715	72251	08018U	PARTICIPANT	\N	PRESENT	0
73716	72251	01016M	PARTICIPANT	\N	PRESENT	0
73717	72251	14038Y	PARTICIPANT	\N	PRESENT	0
73718	72251	04086Q	PARTICIPANT	\N	PRESENT	0
73719	72251	08015R	PARTICIPANT	\N	PRESENT	0
73720	72251	14213J	PARTICIPANT	\N	PRESENT	0
73721	72251	01007L	PARTICIPANT	\N	PRESENT	0
73722	72251	11077T	PARTICIPANT	\N	PRESENT	0
73723	72251	04038G	PARTICIPANT	\N	PRESENT	0
73724	72251	08051V	PARTICIPANT	\N	PRESENT	0
73725	72251	14033T	PARTICIPANT	\N	PRESENT	0
73726	72251	01060R	PARTICIPANT	\N	PRESENT	0
73727	72251	11064N	PARTICIPANT	\N	PRESENT	0
73728	72251	14281W	PARTICIPANT	\N	PRESENT	0
73729	72251	14157T	PARTICIPANT	\N	PRESENT	0
73730	72251	11066Q	PARTICIPANT	\N	PRESENT	0
73731	72251	12042Y	PARTICIPANT	\N	PRESENT	0
73732	72251	08062Y	PARTICIPANT	\N	PRESENT	0
73733	72251	14151M	PARTICIPANT	\N	PRESENT	0
73734	72251	14187A	PARTICIPANT	\N	PRESENT	0
73735	72251	14061L	PARTICIPANT	\N	PRESENT	0
73736	72251	05012A	PARTICIPANT	\N	PRESENT	0
73737	72251	14265W	PARTICIPANT	\N	PRESENT	0
73738	72251	04071H	PARTICIPANT	\N	PRESENT	0
73739	72251	14195A	PARTICIPANT	\N	PRESENT	0
73745	72251	14249W	PARTICIPANT	\N	PRESENT	0
73741	72251	14223L	PARTICIPANT	\N	PRESENT	0
73742	72251	95067Q	PARTICIPANT	\N	PRESENT	0
73743	72251	95015C	PARTICIPANT	\N	PRESENT	0
73744	72251	14217N	PARTICIPANT	\N	PRESENT	0
73746	72251	01043Q	PARTICIPANT	\N	PRESENT	0
73747	72251	14034U	PARTICIPANT	\N	PRESENT	0
73748	72251	11012A	PARTICIPANT	\N	PRESENT	0
73749	72251	14018U	PARTICIPANT	\N	PRESENT	0
73750	72251	08031R	PARTICIPANT	\N	PRESENT	0
73751	72251	04088S	PARTICIPANT	\N	PRESENT	0
73752	72251	01024M	PARTICIPANT	\N	PRESENT	0
73753	72251	04066L	PARTICIPANT	\N	PRESENT	0
73754	72251	01011G	PARTICIPANT	\N	PRESENT	0
73755	72251	14169X	PARTICIPANT	\N	PRESENT	0
73756	72251	04045F	PARTICIPANT	\N	PRESENT	0
73757	72251	08053X	PARTICIPANT	\N	PRESENT	0
73758	72251	08058D	PARTICIPANT	\N	PRESENT	0
73759	72251	14071N	PARTICIPANT	\N	PRESENT	0
73760	72251	11080N	PARTICIPANT	\N	PRESENT	0
73761	72251	14209N	PARTICIPANT	\N	PRESENT	0
73762	72251	07032N	PARTICIPANT	\N	PRESENT	0
73763	72251	14053L	PARTICIPANT	\N	PRESENT	0
73764	72251	11093T	PARTICIPANT	\N	PRESENT	0
73765	72251	04049K	PARTICIPANT	\N	PRESENT	0
73766	72251	04033B	PARTICIPANT	\N	PRESENT	0
73767	72251	14225N	PARTICIPANT	\N	PRESENT	0
73768	72251	14119M	PARTICIPANT	\N	PRESENT	0
73769	72251	14135M	PARTICIPANT	\N	PRESENT	0
73770	72251	01057W	PARTICIPANT	\N	PRESENT	0
73771	72251	14030Q	PARTICIPANT	\N	PRESENT	0
73772	72251	14042U	PARTICIPANT	\N	PRESENT	0
73773	72251	01008M	PARTICIPANT	\N	PRESENT	0
73774	72251	14105F	PARTICIPANT	\N	PRESENT	0
73775	72251	86034E	PARTICIPANT	\N	PRESENT	0
73776	72251	14237S	PARTICIPANT	\N	PRESENT	0
73777	72251	14211G	PARTICIPANT	\N	PRESENT	0
73778	72251	11048N	PARTICIPANT	\N	PRESENT	0
73779	72251	14253S	PARTICIPANT	\N	PRESENT	0
73780	72251	04044E	PARTICIPANT	\N	PRESENT	0
73781	72251	12041X	PARTICIPANT	\N	PRESENT	0
73782	72251	98053W	PARTICIPANT	\N	PRESENT	0
73783	72251	01047U	PARTICIPANT	\N	PRESENT	0
73784	72251	14073Q	PARTICIPANT	\N	PRESENT	0
73785	72251	14267Y	PARTICIPANT	\N	PRESENT	0
73786	72251	04070G	PARTICIPANT	\N	PRESENT	0
73787	72251	04059M	PARTICIPANT	\N	PRESENT	0
73788	72251	10006L	PARTICIPANT	\N	PRESENT	0
73789	72251	11105E	PARTICIPANT	\N	PRESENT	0
73790	72251	14231L	PARTICIPANT	\N	PRESENT	0
73791	72251	14069U	PARTICIPANT	\N	PRESENT	0
73792	72251	14219Q	PARTICIPANT	\N	PRESENT	0
73793	72251	08044W	PARTICIPANT	\N	PRESENT	0
73794	72251	11061K	PARTICIPANT	\N	PRESENT	0
73795	72251	92045V	PARTICIPANT	\N	PRESENT	0
73796	72251	11112D	PARTICIPANT	\N	PRESENT	0
73797	72251	95059Q	PARTICIPANT	\N	PRESENT	0
73798	72251	01027Q	PARTICIPANT	\N	PRESENT	0
73799	72251	14083S	PARTICIPANT	\N	PRESENT	0
73800	72251	11036J	PARTICIPANT	\N	PRESENT	0
73801	72251	14331P	PARTICIPANT	\N	PRESENT	0
75113	75112	08018U	PARTICIPANT	\N	PRESENT	0
75135	75134	01057W	PARTICIPANT	\N	PRESENT	0
75136	75134	14225N	PARTICIPANT	\N	PRESENT	0
75138	75137	01057W	PARTICIPANT	\N	PRESENT	0
75139	75137	14225N	PARTICIPANT	\N	PRESENT	0
75141	75140	88008L	PARTICIPANT	\N	PRESENT	0
75142	75140	04061F	PARTICIPANT	\N	PRESENT	0
75144	75143	88008L	PARTICIPANT	\N	PRESENT	0
75145	75143	04061F	PARTICIPANT	\N	PRESENT	0
75147	75146	01057W	PARTICIPANT	\N	PRESENT	0
75148	75146	14225N	PARTICIPANT	\N	PRESENT	0
75150	75149	01057W	PARTICIPANT	\N	PRESENT	0
75151	75149	14225N	PARTICIPANT	\N	PRESENT	0
75153	75152	01057W	PARTICIPANT	\N	PRESENT	0
75154	75152	14225N	PARTICIPANT	\N	PRESENT	0
75156	75155	88008L	PARTICIPANT	\N	PRESENT	0
75157	75155	04061F	PARTICIPANT	\N	PRESENT	0
75159	75158	88008L	PARTICIPANT	\N	PRESENT	0
75160	75158	04061F	PARTICIPANT	\N	PRESENT	0
75162	75161	88008L	PARTICIPANT	\N	PRESENT	0
75163	75161	04061F	PARTICIPANT	\N	PRESENT	0
75165	75164	88008L	PARTICIPANT	\N	PRESENT	0
75166	75164	04061F	PARTICIPANT	\N	PRESENT	0
75168	75167	88008L	PARTICIPANT	\N	PRESENT	0
75169	75167	04061F	PARTICIPANT	\N	PRESENT	0
75171	75170	88008L	PARTICIPANT	\N	PRESENT	0
75172	75170	04061F	PARTICIPANT	\N	PRESENT	0
75174	75173	88008L	PARTICIPANT	\N	PRESENT	0
75175	75173	04061F	PARTICIPANT	\N	PRESENT	0
75177	75176	88008L	PARTICIPANT	\N	PRESENT	0
75178	75176	04061F	PARTICIPANT	\N	PRESENT	0
75180	75179	88008L	PARTICIPANT	\N	PRESENT	0
75181	75179	04061F	PARTICIPANT	\N	PRESENT	0
75183	75182	88008L	PARTICIPANT	\N	PRESENT	0
75184	75182	04061F	PARTICIPANT	\N	PRESENT	0
75186	75185	88008L	PARTICIPANT	\N	PRESENT	0
75187	75185	04061F	PARTICIPANT	\N	PRESENT	0
63827	63826	86044G	PARTICIPANT	\N	PRESENT	0
63828	63826	11027H	PARTICIPANT	\N	PRESENT	0
63832	63831	07024N	PARTICIPANT	\N	PRESENT	0
63834	63833	04035D	PARTICIPANT	\N	PRESENT	0
72346	70708	08047A	PARTICIPANT	\N	PRESENT	0
72347	70708	14147R	PARTICIPANT	\N	PRESENT	0
72348	70708	08015R	PARTICIPANT	\N	PRESENT	0
72349	70708	14265W	PARTICIPANT	\N	PRESENT	0
72350	70708	14111D	PARTICIPANT	\N	PRESENT	0
72351	70708	08018U	PARTICIPANT	\N	PRESENT	0
72352	70708	14041T	PARTICIPANT	\N	PRESENT	0
72353	70708	04088S	PARTICIPANT	\N	PRESENT	0
72354	70708	14033T	PARTICIPANT	\N	PRESENT	0
72355	70708	14157T	PARTICIPANT	\N	PRESENT	0
72356	70708	08069G	PARTICIPANT	\N	PRESENT	0
72357	70708	14105F	PARTICIPANT	\N	PRESENT	0
72358	70708	14173T	PARTICIPANT	\N	PRESENT	0
72359	70708	14031R	PARTICIPANT	\N	PRESENT	0
72360	70708	14061L	PARTICIPANT	\N	PRESENT	0
72361	70708	98029W	PARTICIPANT	\N	PRESENT	0
72362	70708	14241N	PARTICIPANT	\N	PRESENT	0
72363	70708	04080J	PARTICIPANT	\N	PRESENT	0
72364	70707	89029V	PARTICIPANT	\N	PRESENT	0
72588	70707	14135M	PARTICIPANT	\N	PRESENT	0
72366	70707	92018S	PARTICIPANT	\N	PRESENT	0
72367	70707	11054L	PARTICIPANT	\N	PRESENT	0
72589	70707	14031R	PARTICIPANT	\N	PRESENT	0
72590	70707	95030B	PARTICIPANT	\N	PRESENT	0
72591	70707	14331P	PARTICIPANT	\N	PRESENT	0
72371	70707	14107H	PARTICIPANT	\N	PRESENT	0
72372	70707	92020L	PARTICIPANT	\N	PRESENT	0
72373	70707	11112D	PARTICIPANT	\N	PRESENT	0
72593	70707	14123H	PARTICIPANT	\N	PRESENT	0
72375	70707	14097Y	PARTICIPANT	\N	PRESENT	0
72594	70707	05012A	PARTICIPANT	\N	PRESENT	0
72595	70707	11048N	PARTICIPANT	\N	PRESENT	0
72596	70707	14213J	PARTICIPANT	\N	PRESENT	0
72379	70707	01022K	PARTICIPANT	\N	PRESENT	0
72380	70707	01014K	PARTICIPANT	\N	PRESENT	0
72597	70707	14217N	PARTICIPANT	\N	PRESENT	0
72382	70707	95059Q	PARTICIPANT	\N	PRESENT	0
72383	70707	14103D	PARTICIPANT	\N	PRESENT	0
72384	70707	14219Q	PARTICIPANT	\N	PRESENT	0
72611	70707	80013X	PARTICIPANT	\N	PRESENT	0
72612	70707	88008L	PARTICIPANT	\N	PRESENT	0
72387	70707	07004J	PARTICIPANT	\N	PRESENT	0
72388	70707	14179A	PARTICIPANT	\N	PRESENT	0
72389	70707	14327T	PARTICIPANT	\N	PRESENT	0
72390	70707	11106F	PARTICIPANT	\N	PRESENT	0
72391	70707	04040A	PARTICIPANT	\N	PRESENT	0
72392	70707	14087W	PARTICIPANT	\N	PRESENT	0
72393	70707	08058D	PARTICIPANT	\N	PRESENT	0
72613	70707	14159V	PARTICIPANT	\N	PRESENT	0
72616	70707	11107G	PARTICIPANT	\N	PRESENT	0
72396	70707	11042G	PARTICIPANT	\N	PRESENT	0
72397	70707	98022P	PARTICIPANT	\N	PRESENT	0
72398	70707	01016M	PARTICIPANT	\N	PRESENT	0
72399	70707	04078Q	PARTICIPANT	\N	PRESENT	0
72675	70707	14013P	PARTICIPANT	\N	PRESENT	0
72401	70707	98021N	PARTICIPANT	\N	PRESENT	0
72677	70707	14231L	PARTICIPANT	\N	PRESENT	0
72678	70707	04059M	PARTICIPANT	\N	PRESENT	0
72404	70707	14187A	PARTICIPANT	\N	PRESENT	0
72405	70707	97011G	PARTICIPANT	\N	PRESENT	0
72679	70707	95015C	PARTICIPANT	\N	PRESENT	0
72407	70707	14193X	PARTICIPANT	\N	PRESENT	0
72680	70707	14042U	PARTICIPANT	\N	PRESENT	0
72409	70707	07024N	PARTICIPANT	\N	PRESENT	0
72681	70707	14119M	PARTICIPANT	\N	PRESENT	0
72411	70707	11043H	PARTICIPANT	\N	PRESENT	0
72682	70707	14030Q	PARTICIPANT	\N	PRESENT	0
72683	70707	08018U	PARTICIPANT	\N	PRESENT	0
72414	70707	87003B	PARTICIPANT	\N	PRESENT	0
72684	70707	01003G	PARTICIPANT	\N	PRESENT	0
72416	70707	08047A	PARTICIPANT	\N	PRESENT	0
72417	70707	14147R	PARTICIPANT	\N	PRESENT	0
72418	70707	08015R	PARTICIPANT	\N	PRESENT	0
72419	70707	14265W	PARTICIPANT	\N	PRESENT	0
72685	70707	11105E	PARTICIPANT	\N	PRESENT	0
72686	70707	11035H	PARTICIPANT	\N	PRESENT	0
72422	70707	14041T	PARTICIPANT	\N	PRESENT	0
72423	70707	04088S	PARTICIPANT	\N	PRESENT	0
72687	70707	14133K	PARTICIPANT	\N	PRESENT	0
72425	70707	14157T	PARTICIPANT	\N	PRESENT	0
72688	70707	14209N	PARTICIPANT	\N	PRESENT	0
72689	70707	08062Y	PARTICIPANT	\N	PRESENT	0
72690	70707	01008M	PARTICIPANT	\N	PRESENT	0
72691	70707	14235Q	PARTICIPANT	\N	PRESENT	0
72430	70707	14061L	PARTICIPANT	\N	PRESENT	0
72431	70707	98029W	PARTICIPANT	\N	PRESENT	0
72692	70707	14169X	PARTICIPANT	\N	PRESENT	0
72433	70707	04080J	PARTICIPANT	\N	PRESENT	0
72434	70707	11040E	PARTICIPANT	\N	PRESENT	0
72693	70707	11026G	PARTICIPANT	\N	PRESENT	0
72436	70708	11040E	PARTICIPANT	\N	PRESENT	0
72437	70708	08028W	PARTICIPANT	\N	PRESENT	0
72438	70708	14231L	PARTICIPANT	\N	PRESENT	0
72440	70708	14063N	PARTICIPANT	\N	PRESENT	0
72442	70708	11012A	PARTICIPANT	\N	PRESENT	0
72443	70708	14039A	PARTICIPANT	\N	PRESENT	0
72444	70708	04095R	PARTICIPANT	\N	PRESENT	0
72445	70708	14001X	PARTICIPANT	\N	PRESENT	0
72446	70708	04043D	PARTICIPANT	\N	PRESENT	0
72447	70708	04042C	PARTICIPANT	\N	PRESENT	0
72449	70708	08056B	PARTICIPANT	\N	PRESENT	0
72451	70708	08034U	PARTICIPANT	\N	PRESENT	0
72452	70708	08031R	PARTICIPANT	\N	PRESENT	0
72453	70708	14135M	PARTICIPANT	\N	PRESENT	0
72454	70708	10006L	PARTICIPANT	\N	PRESENT	0
72455	70708	14205J	PARTICIPANT	\N	PRESENT	0
72456	70708	14034U	PARTICIPANT	\N	PRESENT	0
72457	70708	04077P	PARTICIPANT	\N	PRESENT	0
72694	70707	14069U	PARTICIPANT	\N	PRESENT	0
72475	70707	14063N	PARTICIPANT	\N	PRESENT	0
72476	70707	11012A	PARTICIPANT	\N	PRESENT	0
72695	70707	14071N	PARTICIPANT	\N	PRESENT	0
72696	70707	04061F	PARTICIPANT	\N	PRESENT	0
72697	70707	08056B	PARTICIPANT	\N	PRESENT	0
72698	70707	14205J	PARTICIPANT	\N	PRESENT	0
72699	70707	14089Y	PARTICIPANT	\N	PRESENT	0
72700	70707	01047U	PARTICIPANT	\N	PRESENT	0
72483	70707	08034U	PARTICIPANT	\N	PRESENT	0
72484	70707	08031R	PARTICIPANT	\N	PRESENT	0
72701	70707	96004D	PARTICIPANT	\N	PRESENT	0
72486	70707	10006L	PARTICIPANT	\N	PRESENT	0
72702	70707	08028W	PARTICIPANT	\N	PRESENT	0
72488	70707	14034U	PARTICIPANT	\N	PRESENT	0
72489	70707	04077P	PARTICIPANT	\N	PRESENT	0
72490	72439	89029V	PARTICIPANT	\N	PRESENT	0
72491	72439	07026Q	PARTICIPANT	\N	PRESENT	0
72492	72439	92018S	PARTICIPANT	\N	PRESENT	0
72493	72439	11054L	PARTICIPANT	\N	PRESENT	0
72494	72439	11089X	PARTICIPANT	\N	PRESENT	0
72495	72439	14197C	PARTICIPANT	\N	PRESENT	0
72496	72439	00003C	PARTICIPANT	\N	PRESENT	0
72497	72439	14107H	PARTICIPANT	\N	PRESENT	0
72498	72439	92020L	PARTICIPANT	\N	PRESENT	0
72499	72439	11112D	PARTICIPANT	\N	PRESENT	0
72500	72439	08014Q	PARTICIPANT	\N	PRESENT	0
72501	72439	14097Y	PARTICIPANT	\N	PRESENT	0
72502	72439	01031L	PARTICIPANT	\N	PRESENT	0
72503	72439	14225N	PARTICIPANT	\N	PRESENT	0
72504	72439	13002U	PARTICIPANT	\N	PRESENT	0
72505	72439	01022K	PARTICIPANT	\N	PRESENT	0
72506	72439	01014K	PARTICIPANT	\N	PRESENT	0
72507	72439	11037K	PARTICIPANT	\N	PRESENT	0
72508	72439	95059Q	PARTICIPANT	\N	PRESENT	0
72509	72439	14103D	PARTICIPANT	\N	PRESENT	0
72510	72439	14219Q	PARTICIPANT	\N	PRESENT	0
72511	72439	14042U	PARTICIPANT	\N	PRESENT	0
72512	72439	14221J	PARTICIPANT	\N	PRESENT	0
72513	72439	07004J	PARTICIPANT	\N	PRESENT	0
72514	72439	14179A	PARTICIPANT	\N	PRESENT	0
72515	72439	14327T	PARTICIPANT	\N	PRESENT	0
72516	72439	11106F	PARTICIPANT	\N	PRESENT	0
72517	72439	04040A	PARTICIPANT	\N	PRESENT	0
72518	72439	14087W	PARTICIPANT	\N	PRESENT	0
72519	72439	08058D	PARTICIPANT	\N	PRESENT	0
72520	72439	11076S	PARTICIPANT	\N	PRESENT	0
72521	72439	08053X	PARTICIPANT	\N	PRESENT	0
72522	72439	11042G	PARTICIPANT	\N	PRESENT	0
72523	72439	98022P	PARTICIPANT	\N	PRESENT	0
72524	72439	01016M	PARTICIPANT	\N	PRESENT	0
72525	72439	04078Q	PARTICIPANT	\N	PRESENT	0
72526	72439	14071N	PARTICIPANT	\N	PRESENT	0
72527	72439	98021N	PARTICIPANT	\N	PRESENT	0
72528	72439	14053L	PARTICIPANT	\N	PRESENT	0
72529	72439	14059S	PARTICIPANT	\N	PRESENT	0
74386	72441	11037K	PARTICIPANT	\N	PRESENT	0
74388	72441	92044U	PARTICIPANT	\N	PRESENT	0
74389	72441	14247U	PARTICIPANT	\N	PRESENT	0
74390	72441	14331P	PARTICIPANT	\N	PRESENT	0
74391	72441	08052W	PARTICIPANT	\N	PRESENT	0
74392	72441	11035H	PARTICIPANT	\N	PRESENT	0
74393	72441	92015P	PARTICIPANT	\N	PRESENT	0
74394	72441	14277B	PARTICIPANT	\N	PRESENT	0
74395	72441	11074Q	PARTICIPANT	\N	PRESENT	0
74396	72441	04095R	PARTICIPANT	\N	PRESENT	0
74397	72441	14249W	PARTICIPANT	\N	PRESENT	0
74398	72441	14109K	PARTICIPANT	\N	PRESENT	0
74399	72441	07034Q	PARTICIPANT	\N	PRESENT	0
74412	72441	07004J	PARTICIPANT	\N	PRESENT	0
74401	72441	80013X	PARTICIPANT	\N	PRESENT	0
74402	72441	04049K	PARTICIPANT	\N	PRESENT	0
74403	72441	14135M	PARTICIPANT	\N	PRESENT	0
74415	72441	11042G	PARTICIPANT	\N	PRESENT	0
74405	72441	11103C	PARTICIPANT	\N	PRESENT	0
74447	72441	14215L	PARTICIPANT	\N	PRESENT	0
74407	72441	11059R	PARTICIPANT	\N	PRESENT	0
74408	72441	14273W	PARTICIPANT	\N	PRESENT	0
74452	72441	01058X	PARTICIPANT	\N	PRESENT	0
74410	72441	04092N	PARTICIPANT	\N	PRESENT	0
74411	72441	14053L	PARTICIPANT	\N	PRESENT	0
74413	72441	11049P	PARTICIPANT	\N	PRESENT	0
74414	72441	04036E	PARTICIPANT	\N	PRESENT	0
74416	72441	07029T	PARTICIPANT	\N	PRESENT	0
74418	72441	04067M	PARTICIPANT	\N	PRESENT	0
74419	72441	98022P	PARTICIPANT	\N	PRESENT	0
74420	72441	14265W	PARTICIPANT	\N	PRESENT	0
74421	72441	08042U	PARTICIPANT	\N	PRESENT	0
74422	72441	14275Y	PARTICIPANT	\N	PRESENT	0
74423	72441	11097X	PARTICIPANT	\N	PRESENT	0
74424	72441	14221J	PARTICIPANT	\N	PRESENT	0
74425	72441	08024S	PARTICIPANT	\N	PRESENT	0
74426	72441	00003C	PARTICIPANT	\N	PRESENT	0
74427	72441	11066Q	PARTICIPANT	\N	PRESENT	0
74428	72441	01019Q	PARTICIPANT	\N	PRESENT	0
74429	72441	92040Q	PARTICIPANT	\N	PRESENT	0
74430	72441	04078Q	PARTICIPANT	\N	PRESENT	0
74431	72441	14083S	PARTICIPANT	\N	PRESENT	0
74432	72441	08028W	PARTICIPANT	\N	PRESENT	0
74433	72441	14187A	PARTICIPANT	\N	PRESENT	0
74434	72441	98023Q	PARTICIPANT	\N	PRESENT	0
74436	72441	04042C	PARTICIPANT	\N	PRESENT	0
74441	72441	11048N	PARTICIPANT	\N	PRESENT	0
74442	72441	90003B	PARTICIPANT	\N	PRESENT	0
74443	72441	11100Y	PARTICIPANT	\N	PRESENT	0
74444	72441	14169X	PARTICIPANT	\N	PRESENT	0
74445	72441	05012A	PARTICIPANT	\N	PRESENT	0
74446	72441	14105F	PARTICIPANT	\N	PRESENT	0
74448	72441	95059Q	PARTICIPANT	\N	PRESENT	0
74449	72441	04033B	PARTICIPANT	\N	PRESENT	0
74450	72441	14111D	PARTICIPANT	\N	PRESENT	0
74451	72441	14223L	PARTICIPANT	\N	PRESENT	0
74453	72441	04088S	PARTICIPANT	\N	PRESENT	0
74454	72441	08034U	PARTICIPANT	\N	PRESENT	0
74455	72441	14033T	PARTICIPANT	\N	PRESENT	0
74456	72441	08010L	PARTICIPANT	\N	PRESENT	0
74457	72441	14259Y	PARTICIPANT	\N	PRESENT	0
74458	72441	04043D	PARTICIPANT	\N	PRESENT	0
74459	72441	04044E	PARTICIPANT	\N	PRESENT	0
74460	72441	96004D	PARTICIPANT	\N	PRESENT	0
74461	72441	14079W	PARTICIPANT	\N	PRESENT	0
74462	72441	07024N	PARTICIPANT	\N	PRESENT	0
74463	72441	14209N	PARTICIPANT	\N	PRESENT	0
74464	72441	14195A	PARTICIPANT	\N	PRESENT	0
74465	72441	10006L	PARTICIPANT	\N	PRESENT	0
74466	72441	14071N	PARTICIPANT	\N	PRESENT	0
74467	72441	11088W	PARTICIPANT	\N	PRESENT	0
74468	72441	07026Q	PARTICIPANT	\N	PRESENT	0
74469	72441	04054G	PARTICIPANT	\N	PRESENT	0
74470	72441	08022Q	PARTICIPANT	\N	PRESENT	0
74471	72441	12041X	PARTICIPANT	\N	PRESENT	0
74472	72441	04085P	PARTICIPANT	\N	PRESENT	0
74473	72441	14327T	PARTICIPANT	\N	PRESENT	0
74474	72441	01013J	PARTICIPANT	\N	PRESENT	0
74475	72441	01047U	PARTICIPANT	\N	PRESENT	0
74476	72441	14235Q	PARTICIPANT	\N	PRESENT	0
74477	72441	14263U	PARTICIPANT	\N	PRESENT	0
74478	72441	95015C	PARTICIPANT	\N	PRESENT	0
74479	72441	01015L	PARTICIPANT	\N	PRESENT	0
74480	72441	86044G	PARTICIPANT	\N	PRESENT	0
74481	72441	11063M	PARTICIPANT	\N	PRESENT	0
74482	72441	14123H	PARTICIPANT	\N	PRESENT	0
74483	72441	04056J	PARTICIPANT	\N	PRESENT	0
74484	72441	01016M	PARTICIPANT	\N	PRESENT	0
74485	72441	98035U	PARTICIPANT	\N	PRESENT	0
74486	72441	14031R	PARTICIPANT	\N	PRESENT	0
74487	72441	08016S	PARTICIPANT	\N	PRESENT	0
74488	72441	98046X	PARTICIPANT	\N	PRESENT	0
74489	72441	95063L	PARTICIPANT	\N	PRESENT	0
74490	72441	07032N	PARTICIPANT	\N	PRESENT	0
74491	72441	14051J	PARTICIPANT	\N	PRESENT	0
74492	72441	08025T	PARTICIPANT	\N	PRESENT	0
74493	72441	14087W	PARTICIPANT	\N	PRESENT	0
74494	72441	14107H	PARTICIPANT	\N	PRESENT	0
74495	72441	04074L	PARTICIPANT	\N	PRESENT	0
74496	72441	08055A	PARTICIPANT	\N	PRESENT	0
74497	72441	11090Q	PARTICIPANT	\N	PRESENT	0
74498	72441	01011G	PARTICIPANT	\N	PRESENT	0
74499	72441	14197C	PARTICIPANT	\N	PRESENT	0
74505	72441	11036J	PARTICIPANT	\N	PRESENT	0
74501	72441	01022K	PARTICIPANT	\N	PRESENT	0
74502	72441	14028W	PARTICIPANT	\N	PRESENT	0
74503	72441	97011G	PARTICIPANT	\N	PRESENT	0
74504	72441	08053X	PARTICIPANT	\N	PRESENT	0
74506	72441	08015R	PARTICIPANT	\N	PRESENT	0
74507	72441	11105E	PARTICIPANT	\N	PRESENT	0
74508	72441	04081K	PARTICIPANT	\N	PRESENT	0
74509	72441	95037J	PARTICIPANT	\N	PRESENT	0
74510	72441	08058D	PARTICIPANT	\N	PRESENT	0
74511	72441	04034C	PARTICIPANT	\N	PRESENT	0
74512	72441	04055H	PARTICIPANT	\N	PRESENT	0
74513	72441	83042R	PARTICIPANT	\N	PRESENT	0
74514	72441	11046L	PARTICIPANT	\N	PRESENT	0
74515	72441	99004R	PARTICIPANT	\N	PRESENT	0
74516	72441	98029W	PARTICIPANT	\N	PRESENT	0
74517	72441	14329V	PARTICIPANT	\N	PRESENT	0
74518	72441	14041T	PARTICIPANT	\N	PRESENT	0
74519	72441	08018U	PARTICIPANT	\N	PRESENT	0
74520	72441	08014Q	PARTICIPANT	\N	PRESENT	0
74521	72441	11095V	PARTICIPANT	\N	PRESENT	0
74522	72441	14001X	PARTICIPANT	\N	PRESENT	0
74523	72441	11054L	PARTICIPANT	\N	PRESENT	0
74524	72441	14030Q	PARTICIPANT	\N	PRESENT	0
74525	72441	14229S	PARTICIPANT	\N	PRESENT	0
74526	72441	14281W	PARTICIPANT	\N	PRESENT	0
74527	72441	04047H	PARTICIPANT	\N	PRESENT	0
74528	72441	14151M	PARTICIPANT	\N	PRESENT	0
74529	72441	14207L	PARTICIPANT	\N	PRESENT	0
74530	72441	11089X	PARTICIPANT	\N	PRESENT	0
74531	72441	14038Y	PARTICIPANT	\N	PRESENT	0
74532	72441	14121F	PARTICIPANT	\N	PRESENT	0
74533	72441	11044J	PARTICIPANT	\N	PRESENT	0
74534	72441	01031L	PARTICIPANT	\N	PRESENT	0
74535	72441	08017T	PARTICIPANT	\N	PRESENT	0
74536	72441	11112D	PARTICIPANT	\N	PRESENT	0
74537	72441	04079R	PARTICIPANT	\N	PRESENT	0
74538	72441	14225N	PARTICIPANT	\N	PRESENT	0
74539	72441	14039A	PARTICIPANT	\N	PRESENT	0
74540	72441	11023D	PARTICIPANT	\N	PRESENT	0
74541	72441	04094Q	PARTICIPANT	\N	PRESENT	0
74542	72441	11077T	PARTICIPANT	\N	PRESENT	0
74543	72441	14159V	PARTICIPANT	\N	PRESENT	0
74544	72441	14253S	PARTICIPANT	\N	PRESENT	0
74545	72441	14271U	PARTICIPANT	\N	PRESENT	0
74546	72441	14014Q	PARTICIPANT	\N	PRESENT	0
74547	72441	11061K	PARTICIPANT	\N	PRESENT	0
74548	72441	04059M	PARTICIPANT	\N	PRESENT	0
74382	72441	86034E	PARTICIPANT	\N	PRESENT	0
74384	72441	04048J	PARTICIPANT	\N	PRESENT	0
74549	72441	14061L	PARTICIPANT	\N	PRESENT	0
74550	72441	14085U	PARTICIPANT	\N	PRESENT	0
74551	72441	04057K	PARTICIPANT	\N	PRESENT	0
74552	72441	01037S	PARTICIPANT	\N	PRESENT	0
74553	72441	11110B	PARTICIPANT	\N	PRESENT	0
74554	72441	11104D	PARTICIPANT	\N	PRESENT	0
74555	72441	04053F	PARTICIPANT	\N	PRESENT	0
74556	72441	01028R	PARTICIPANT	\N	PRESENT	0
74557	72441	04077P	PARTICIPANT	\N	PRESENT	0
74558	72441	77002U	PARTICIPANT	\N	PRESENT	0
74559	72441	08061X	PARTICIPANT	\N	PRESENT	0
74560	72441	11039M	PARTICIPANT	\N	PRESENT	0
74561	72441	95067Q	PARTICIPANT	\N	PRESENT	0
74562	72441	98053W	PARTICIPANT	\N	PRESENT	0
66733	66732	07024N	PARTICIPANT	\N	PRESENT	0
66735	66734	77002U	PARTICIPANT	\N	PRESENT	0
66736	66734	11106F	PARTICIPANT	\N	PRESENT	0
66737	66734	01041N	PARTICIPANT	\N	PRESENT	0
66738	66734	11042G	PARTICIPANT	\N	PRESENT	0
66886	66880	86034E	PARTICIPANT	\N	PRESENT	0
66890	66880	01044R	PARTICIPANT	\N	PRESENT	0
66888	66880	11037K	PARTICIPANT	\N	PRESENT	0
66889	66880	08021P	PARTICIPANT	\N	PRESENT	0
66891	66880	14097Y	PARTICIPANT	\N	PRESENT	0
66892	66880	08014Q	PARTICIPANT	\N	PRESENT	0
66893	66880	08043V	PARTICIPANT	\N	PRESENT	0
66894	66880	11113E	PARTICIPANT	\N	PRESENT	0
66895	66880	11029K	PARTICIPANT	\N	PRESENT	0
66896	66880	14231L	PARTICIPANT	\N	PRESENT	0
66897	66880	04089T	PARTICIPANT	\N	PRESENT	0
66898	66880	14241N	PARTICIPANT	\N	PRESENT	0
66899	66880	04042C	PARTICIPANT	\N	PRESENT	0
66900	66880	11091R	PARTICIPANT	\N	PRESENT	0
66901	66880	14038Y	PARTICIPANT	\N	PRESENT	0
66902	66880	04036E	PARTICIPANT	\N	PRESENT	0
66903	66880	14059S	PARTICIPANT	\N	PRESENT	0
66904	66880	08062Y	PARTICIPANT	\N	PRESENT	0
66905	66880	04088S	PARTICIPANT	\N	PRESENT	0
66906	66880	14191V	PARTICIPANT	\N	PRESENT	0
66907	66880	08065C	PARTICIPANT	\N	PRESENT	0
66908	66880	01056V	PARTICIPANT	\N	PRESENT	0
66909	66880	14063N	PARTICIPANT	\N	PRESENT	0
66910	66880	14105F	PARTICIPANT	\N	PRESENT	0
66911	66880	08035V	PARTICIPANT	\N	PRESENT	0
66912	66880	11106F	PARTICIPANT	\N	PRESENT	0
66913	66880	04066L	PARTICIPANT	\N	PRESENT	0
66914	66880	14039A	PARTICIPANT	\N	PRESENT	0
66915	66880	14201E	PARTICIPANT	\N	PRESENT	0
66916	66880	11035H	PARTICIPANT	\N	PRESENT	0
66917	66880	14085U	PARTICIPANT	\N	PRESENT	0
66918	66880	11033F	PARTICIPANT	\N	PRESENT	0
66919	66880	11104D	PARTICIPANT	\N	PRESENT	0
66920	66880	14227Q	PARTICIPANT	\N	PRESENT	0
66921	66880	04034C	PARTICIPANT	\N	PRESENT	0
66922	66880	04059M	PARTICIPANT	\N	PRESENT	0
66923	66880	14331P	PARTICIPANT	\N	PRESENT	0
66924	66880	89029V	PARTICIPANT	\N	PRESENT	0
66925	66880	14073Q	PARTICIPANT	\N	PRESENT	0
66926	66880	14042U	PARTICIPANT	\N	PRESENT	0
66927	66880	04040A	PARTICIPANT	\N	PRESENT	0
66928	66880	12041X	PARTICIPANT	\N	PRESENT	0
66929	66880	11031D	PARTICIPANT	\N	PRESENT	0
66930	66880	92018S	PARTICIPANT	\N	PRESENT	0
66931	66880	01015L	PARTICIPANT	\N	PRESENT	0
66932	66880	11040E	PARTICIPANT	\N	PRESENT	0
66933	66880	01060R	PARTICIPANT	\N	PRESENT	0
66934	66880	04070G	PARTICIPANT	\N	PRESENT	0
66935	66880	01025N	PARTICIPANT	\N	PRESENT	0
66936	66880	14263U	PARTICIPANT	\N	PRESENT	0
66937	66880	14235Q	PARTICIPANT	\N	PRESENT	0
66938	66880	11098Y	PARTICIPANT	\N	PRESENT	0
66939	66880	14253S	PARTICIPANT	\N	PRESENT	0
66940	66880	04038G	PARTICIPANT	\N	PRESENT	0
66941	66880	08031R	PARTICIPANT	\N	PRESENT	0
66942	66880	95062K	PARTICIPANT	\N	PRESENT	0
66943	66880	11096W	PARTICIPANT	\N	PRESENT	0
66944	66880	02002K	PARTICIPANT	\N	PRESENT	0
66945	66880	01003G	PARTICIPANT	\N	PRESENT	0
66946	66880	99004R	PARTICIPANT	\N	PRESENT	0
66947	66880	95049N	PARTICIPANT	\N	PRESENT	0
66948	66880	01034P	PARTICIPANT	\N	PRESENT	0
66949	66880	11080N	PARTICIPANT	\N	PRESENT	0
66950	66880	04080J	PARTICIPANT	\N	PRESENT	0
66951	66880	14034U	PARTICIPANT	\N	PRESENT	0
66952	66880	14221J	PARTICIPANT	\N	PRESENT	0
66953	66880	95031C	PARTICIPANT	\N	PRESENT	0
66954	66880	77002U	PARTICIPANT	\N	PRESENT	0
66955	66880	11082Q	PARTICIPANT	\N	PRESENT	0
66956	66880	01027Q	PARTICIPANT	\N	PRESENT	0
66957	66880	04078Q	PARTICIPANT	\N	PRESENT	0
66958	66880	95015C	PARTICIPANT	\N	PRESENT	0
66959	66880	11093T	PARTICIPANT	\N	PRESENT	0
66960	66880	01007L	PARTICIPANT	\N	PRESENT	0
66961	66880	07004J	PARTICIPANT	\N	PRESENT	0
66962	66880	95030B	PARTICIPANT	\N	PRESENT	0
66963	66880	14083S	PARTICIPANT	\N	PRESENT	0
66964	66880	01047U	PARTICIPANT	\N	PRESENT	0
66965	66880	01019Q	PARTICIPANT	\N	PRESENT	0
66967	66880	08056B	PARTICIPANT	\N	PRESENT	0
66968	66880	09001P	PARTICIPANT	\N	PRESENT	0
66969	66880	04033B	PARTICIPANT	\N	PRESENT	0
66970	66880	01043Q	PARTICIPANT	\N	PRESENT	0
66971	66880	14031R	PARTICIPANT	\N	PRESENT	0
66972	66880	98042T	PARTICIPANT	\N	PRESENT	0
66973	66880	11030C	PARTICIPANT	\N	PRESENT	0
66974	66880	11070L	PARTICIPANT	\N	PRESENT	0
66975	66880	08009T	PARTICIPANT	\N	PRESENT	0
66976	66880	01058X	PARTICIPANT	\N	PRESENT	0
66977	66880	14013P	PARTICIPANT	\N	PRESENT	0
66978	66880	11063M	PARTICIPANT	\N	PRESENT	0
66979	66880	04054G	PARTICIPANT	\N	PRESENT	0
66980	66880	08069G	PARTICIPANT	\N	PRESENT	0
66981	66880	14123H	PARTICIPANT	\N	PRESENT	0
66982	66880	10006L	PARTICIPANT	\N	PRESENT	0
66983	66880	11083R	PARTICIPANT	\N	PRESENT	0
66984	66880	11076S	PARTICIPANT	\N	PRESENT	0
66985	66880	98035U	PARTICIPANT	\N	PRESENT	0
66986	66880	01016M	PARTICIPANT	\N	PRESENT	0
66987	66880	04056J	PARTICIPANT	\N	PRESENT	0
66988	66880	11039M	PARTICIPANT	\N	PRESENT	0
66989	66880	08025T	PARTICIPANT	\N	PRESENT	0
66990	66880	08010L	PARTICIPANT	\N	PRESENT	0
66991	66880	04085P	PARTICIPANT	\N	PRESENT	0
66992	66880	14271U	PARTICIPANT	\N	PRESENT	0
66993	66880	11099A	PARTICIPANT	\N	PRESENT	0
66994	66880	14211G	PARTICIPANT	\N	PRESENT	0
66995	66880	08052W	PARTICIPANT	\N	PRESENT	0
66996	66880	08041T	PARTICIPANT	\N	PRESENT	0
66997	66880	98046X	PARTICIPANT	\N	PRESENT	0
66998	66880	92015P	PARTICIPANT	\N	PRESENT	0
66999	66880	08055A	PARTICIPANT	\N	PRESENT	0
67000	66880	08028W	PARTICIPANT	\N	PRESENT	0
67001	66880	04049K	PARTICIPANT	\N	PRESENT	0
67002	66880	11012A	PARTICIPANT	\N	PRESENT	0
67003	66880	08044W	PARTICIPANT	\N	PRESENT	0
67004	66880	14327T	PARTICIPANT	\N	PRESENT	0
67005	66880	01024M	PARTICIPANT	\N	PRESENT	0
67006	66880	14030Q	PARTICIPANT	\N	PRESENT	0
67007	66880	11061K	PARTICIPANT	\N	PRESENT	0
67008	66880	95037J	PARTICIPANT	\N	PRESENT	0
67009	66880	14223L	PARTICIPANT	\N	PRESENT	0
67010	66880	11043H	PARTICIPANT	\N	PRESENT	0
67011	66880	01011G	PARTICIPANT	\N	PRESENT	0
67012	66880	95063L	PARTICIPANT	\N	PRESENT	0
67013	66880	14197C	PARTICIPANT	\N	PRESENT	0
67014	66880	01022K	PARTICIPANT	\N	PRESENT	0
67015	66880	14028W	PARTICIPANT	\N	PRESENT	0
67016	66880	95035G	PARTICIPANT	\N	PRESENT	0
67017	66880	11077T	PARTICIPANT	\N	PRESENT	0
67018	66880	80013X	PARTICIPANT	\N	PRESENT	0
67019	66880	00003C	PARTICIPANT	\N	PRESENT	0
67020	66880	08053X	PARTICIPANT	\N	PRESENT	0
67021	66880	95041E	PARTICIPANT	\N	PRESENT	0
67022	66880	14213J	PARTICIPANT	\N	PRESENT	0
67023	66880	14065Q	PARTICIPANT	\N	PRESENT	0
67024	66880	11015D	PARTICIPANT	\N	PRESENT	0
67025	66880	07029T	PARTICIPANT	\N	PRESENT	0
67026	66880	11067R	PARTICIPANT	\N	PRESENT	0
67027	66880	11105E	PARTICIPANT	\N	PRESENT	0
67028	66880	11089X	PARTICIPANT	\N	PRESENT	0
67029	66880	08012N	PARTICIPANT	\N	PRESENT	0
67030	66880	11036J	PARTICIPANT	\N	PRESENT	0
67031	66880	14261S	PARTICIPANT	\N	PRESENT	0
67032	66880	14037X	PARTICIPANT	\N	PRESENT	0
67033	66880	08058D	PARTICIPANT	\N	PRESENT	0
67034	66880	11094U	PARTICIPANT	\N	PRESENT	0
67035	66880	11053K	PARTICIPANT	\N	PRESENT	0
67036	66880	14018U	PARTICIPANT	\N	PRESENT	0
67037	66880	14159V	PARTICIPANT	\N	PRESENT	0
67038	66880	98022P	PARTICIPANT	\N	PRESENT	0
67039	66880	14239U	PARTICIPANT	\N	PRESENT	0
67040	66880	01061S	PARTICIPANT	\N	PRESENT	0
67041	66880	11048N	PARTICIPANT	\N	PRESENT	0
67042	66880	11044J	PARTICIPANT	\N	PRESENT	0
67043	66880	90003B	PARTICIPANT	\N	PRESENT	0
67044	66880	14107H	PARTICIPANT	\N	PRESENT	0
67045	66880	01031L	PARTICIPANT	\N	PRESENT	0
67046	66880	83042R	PARTICIPANT	\N	PRESENT	0
67047	66880	98029W	PARTICIPANT	\N	PRESENT	0
67048	66880	92040Q	PARTICIPANT	\N	PRESENT	0
67049	66880	14175V	PARTICIPANT	\N	PRESENT	0
77360	75212	14031R	PARTICIPANT	\N	PRESENT	0
77361	75212	01015L	PARTICIPANT	\N	PRESENT	0
77362	75212	11098Y	PARTICIPANT	\N	PRESENT	0
77363	75212	01022K	PARTICIPANT	\N	PRESENT	0
77364	75212	14051J	PARTICIPANT	\N	PRESENT	0
77365	75212	11107G	PARTICIPANT	\N	PRESENT	0
77366	75212	11114F	PARTICIPANT	\N	PRESENT	0
77367	75212	14073Q	PARTICIPANT	\N	PRESENT	0
77368	75212	14030Q	PARTICIPANT	\N	PRESENT	0
77369	75212	14103D	PARTICIPANT	\N	PRESENT	0
77370	75212	11065P	PARTICIPANT	\N	PRESENT	0
77371	75212	08022Q	PARTICIPANT	\N	PRESENT	0
77372	75212	95062K	PARTICIPANT	\N	PRESENT	0
77373	75212	14159V	PARTICIPANT	\N	PRESENT	0
77374	75212	11042G	PARTICIPANT	\N	PRESENT	0
77375	75212	14197C	PARTICIPANT	\N	PRESENT	0
77376	75212	11012A	PARTICIPANT	\N	PRESENT	0
77377	75212	01016M	PARTICIPANT	\N	PRESENT	0
77378	75212	04094Q	PARTICIPANT	\N	PRESENT	0
77379	75212	14331P	PARTICIPANT	\N	PRESENT	0
77380	75212	80013X	PARTICIPANT	\N	PRESENT	0
77381	75212	92045V	PARTICIPANT	\N	PRESENT	0
77382	75212	14157T	PARTICIPANT	\N	PRESENT	0
77391	75212	11112D	PARTICIPANT	\N	PRESENT	0
77384	75212	11109J	PARTICIPANT	\N	PRESENT	0
77385	75212	14083S	PARTICIPANT	\N	PRESENT	0
77386	75212	14033T	PARTICIPANT	\N	PRESENT	0
77387	75212	14265W	PARTICIPANT	\N	PRESENT	0
77388	75212	96004D	PARTICIPANT	\N	PRESENT	0
77389	75212	05012A	PARTICIPANT	\N	PRESENT	0
77390	75212	04088S	PARTICIPANT	\N	PRESENT	0
77392	75212	14207L	PARTICIPANT	\N	PRESENT	0
77393	75212	14059S	PARTICIPANT	\N	PRESENT	0
77394	75212	14249W	PARTICIPANT	\N	PRESENT	0
77395	75212	14053L	PARTICIPANT	\N	PRESENT	0
77396	75212	14071N	PARTICIPANT	\N	PRESENT	0
77397	75212	14231L	PARTICIPANT	\N	PRESENT	0
78580	78223	14065Q	PARTICIPANT	\N	PRESENT	0
78581	78223	14103D	PARTICIPANT	\N	PRESENT	0
78582	78223	07004J	PARTICIPANT	\N	PRESENT	0
78583	78223	14223L	PARTICIPANT	\N	PRESENT	0
78584	78223	14215L	PARTICIPANT	\N	PRESENT	0
78585	78223	14331P	PARTICIPANT	\N	PRESENT	0
78586	78223	04038G	PARTICIPANT	\N	PRESENT	0
78587	78223	11056N	PARTICIPANT	\N	PRESENT	0
78588	78223	01060R	PARTICIPANT	\N	PRESENT	0
77358	75212	08024S	PARTICIPANT	\N	PRESENT	0
77359	75212	08009T	PARTICIPANT	\N	PRESENT	0
78589	78223	14211G	PARTICIPANT	\N	PRESENT	0
78590	78223	14207L	PARTICIPANT	\N	PRESENT	0
78591	78223	07029T	PARTICIPANT	\N	PRESENT	0
78592	78223	14105F	PARTICIPANT	\N	PRESENT	0
78593	78223	04041B	PARTICIPANT	\N	PRESENT	0
78594	78223	11091R	PARTICIPANT	\N	PRESENT	0
78595	78223	07034Q	PARTICIPANT	\N	PRESENT	0
78596	78223	08056B	PARTICIPANT	\N	PRESENT	0
78597	78223	04033B	PARTICIPANT	\N	PRESENT	0
78598	78223	13002U	PARTICIPANT	\N	PRESENT	0
78599	78223	99004R	PARTICIPANT	\N	PRESENT	0
78600	78223	08019V	PARTICIPANT	\N	PRESENT	0
78601	78223	92015P	PARTICIPANT	\N	PRESENT	0
78602	78223	14191V	PARTICIPANT	\N	PRESENT	0
78603	78223	07032N	PARTICIPANT	\N	PRESENT	0
78604	78223	11081P	PARTICIPANT	\N	PRESENT	0
78605	78223	14265W	PARTICIPANT	\N	PRESENT	0
78606	78223	95063L	PARTICIPANT	\N	PRESENT	0
78607	78223	14089Y	PARTICIPANT	\N	PRESENT	0
78608	78223	11094U	PARTICIPANT	\N	PRESENT	0
78609	78223	11057P	PARTICIPANT	\N	PRESENT	0
78610	78223	11103C	PARTICIPANT	\N	PRESENT	0
78611	78223	11076S	PARTICIPANT	\N	PRESENT	0
78612	78223	14257W	PARTICIPANT	\N	PRESENT	0
78613	78223	04089T	PARTICIPANT	\N	PRESENT	0
78614	78223	14059S	PARTICIPANT	\N	PRESENT	0
78615	78223	01034P	PARTICIPANT	\N	PRESENT	0
78616	78223	11033F	PARTICIPANT	\N	PRESENT	0
78617	78223	95062K	PARTICIPANT	\N	PRESENT	0
78618	78223	08051V	PARTICIPANT	\N	PRESENT	0
78619	78223	14187A	PARTICIPANT	\N	PRESENT	0
78621	78223	14157T	PARTICIPANT	\N	PRESENT	0
78679	78223	01047U	PARTICIPANT	\N	PRESENT	0
78680	78223	14241N	PARTICIPANT	\N	PRESENT	0
78682	78223	14034U	PARTICIPANT	\N	PRESENT	0
78683	78223	14219Q	PARTICIPANT	\N	PRESENT	0
78741	78223	08062Y	PARTICIPANT	\N	PRESENT	0
78742	78223	14239U	PARTICIPANT	\N	PRESENT	0
78743	78223	11042G	PARTICIPANT	\N	PRESENT	0
78745	78223	87003B	PARTICIPANT	\N	PRESENT	0
78578	78223	08024S	PARTICIPANT	\N	PRESENT	0
78579	78223	04048J	PARTICIPANT	\N	PRESENT	0
78746	78223	01027Q	PARTICIPANT	\N	PRESENT	0
78747	78223	11036J	PARTICIPANT	\N	PRESENT	0
78748	78223	07026Q	PARTICIPANT	\N	PRESENT	0
78751	78223	14179A	PARTICIPANT	\N	PRESENT	0
80751	80749	14179A	PARTICIPANT	\N	PRESENT	0
83139	83138	11039M	PARTICIPANT	\N	PRESENT	0
83140	83138	98042T	PARTICIPANT	\N	PRESENT	0
83141	83138	01019Q	PARTICIPANT	\N	PRESENT	0
83143	83142	01019Q	PARTICIPANT	\N	PRESENT	0
83675	83674	04040A	PARTICIPANT	\N	PRESENT	0
83676	83674	14097Y	PARTICIPANT	\N	PRESENT	0
83678	83677	07024N	PARTICIPANT	\N	PRESENT	0
83679	83677	01014K	PARTICIPANT	\N	PRESENT	0
83681	83680	07024N	PARTICIPANT	\N	PRESENT	0
83682	83680	01014K	PARTICIPANT	\N	PRESENT	0
83684	83683	07024N	PARTICIPANT	\N	PRESENT	0
83685	83683	01014K	PARTICIPANT	\N	PRESENT	0
83686	83683	11106F	PARTICIPANT	\N	PRESENT	0
83687	83683	04040A	PARTICIPANT	\N	PRESENT	0
83688	83683	11054L	PARTICIPANT	\N	PRESENT	0
83689	83683	14193X	PARTICIPANT	\N	PRESENT	0
83691	83690	07024N	PARTICIPANT	\N	PRESENT	0
83692	83690	01014K	PARTICIPANT	\N	PRESENT	0
83693	83690	11106F	PARTICIPANT	\N	PRESENT	0
83694	83690	04040A	PARTICIPANT	\N	PRESENT	0
83695	83690	11054L	PARTICIPANT	\N	PRESENT	0
83696	83690	14193X	PARTICIPANT	\N	PRESENT	0
83698	83697	07024N	PARTICIPANT	\N	PRESENT	0
83699	83697	01014K	PARTICIPANT	\N	PRESENT	0
83700	83697	04040A	PARTICIPANT	\N	PRESENT	0
83701	83697	11054L	PARTICIPANT	\N	PRESENT	0
83702	83697	14193X	PARTICIPANT	\N	PRESENT	0
83704	83703	07024N	PARTICIPANT	\N	PRESENT	0
83705	83703	01014K	PARTICIPANT	\N	PRESENT	0
83707	83706	07024N	PARTICIPANT	\N	PRESENT	0
83708	83706	01014K	PARTICIPANT	\N	PRESENT	0
83709	83706	04040A	PARTICIPANT	\N	PRESENT	0
83710	83706	11054L	PARTICIPANT	\N	PRESENT	0
83711	83706	14193X	PARTICIPANT	\N	PRESENT	0
83713	83712	07024N	PARTICIPANT	\N	PRESENT	0
83714	83712	01014K	PARTICIPANT	\N	PRESENT	0
83715	83712	14193X	PARTICIPANT	\N	PRESENT	0
84821	84820	11076S	PARTICIPANT	\N	PRESENT	0
84822	84820	04054G	PARTICIPANT	\N	PRESENT	0
84823	84820	04040A	PARTICIPANT	\N	PRESENT	0
84824	84820	08058D	PARTICIPANT	\N	PRESENT	0
84825	84820	04042C	PARTICIPANT	\N	PRESENT	0
84826	84820	77002U	PARTICIPANT	\N	PRESENT	0
84827	84820	98029W	PARTICIPANT	\N	PRESENT	0
84828	84820	11080N	PARTICIPANT	\N	PRESENT	0
84829	84820	11027H	PARTICIPANT	\N	PRESENT	0
84830	84820	98018T	PARTICIPANT	\N	PRESENT	0
84831	84820	92018S	PARTICIPANT	\N	PRESENT	0
84832	84820	92020L	PARTICIPANT	\N	PRESENT	0
84833	84820	95030B	PARTICIPANT	\N	PRESENT	0
84834	84820	11096W	PARTICIPANT	\N	PRESENT	0
84835	84820	95031C	PARTICIPANT	\N	PRESENT	0
84836	84820	97011G	PARTICIPANT	\N	PRESENT	0
84837	84820	08065C	PARTICIPANT	\N	PRESENT	0
84838	84820	04035D	PARTICIPANT	\N	PRESENT	0
84839	84820	07024N	PARTICIPANT	\N	PRESENT	0
84840	84820	04095R	PARTICIPANT	\N	PRESENT	0
84841	84820	14014Q	PARTICIPANT	\N	PRESENT	0
84842	84820	11015D	PARTICIPANT	\N	PRESENT	0
84843	84820	07004J	PARTICIPANT	\N	PRESENT	0
84844	84820	95035G	PARTICIPANT	\N	PRESENT	0
84845	84820	08056B	PARTICIPANT	\N	EXCUSE	0
84846	84820	14211G	PARTICIPANT	\N	PRESENT	0
84847	84820	98022P	PARTICIPANT	\N	PRESENT	0
84848	84820	11064N	PARTICIPANT	\N	PRESENT	0
84849	84820	95037J	PARTICIPANT	\N	PRESENT	0
84850	84820	04078Q	PARTICIPANT	\N	PRESENT	0
84851	84820	14097Y	PARTICIPANT	\N	PRESENT	0
84852	84820	95041E	PARTICIPANT	\N	PRESENT	0
84853	84820	04036E	PARTICIPANT	\N	PRESENT	0
84854	84820	14039A	PARTICIPANT	\N	PRESENT	0
84855	84820	04077P	PARTICIPANT	\N	PRESENT	0
65520	65359	08024S	PARTICIPANT	\N	PRESENT	0
65521	65359	07026Q	PARTICIPANT	\N	PRESENT	0
65522	65359	01044R	PARTICIPANT	\N	PRESENT	0
65526	65359	14263U	PARTICIPANT	\N	PRESENT	0
65527	65359	00003C	PARTICIPANT	\N	PRESENT	0
65528	65359	11104D	PARTICIPANT	\N	PRESENT	0
65529	65359	04059M	PARTICIPANT	\N	PRESENT	0
65530	65359	08043V	PARTICIPANT	\N	PRESENT	0
65532	65359	01025N	PARTICIPANT	\N	PRESENT	0
65535	65359	11025F	PARTICIPANT	\N	PRESENT	0
65536	65359	14030Q	PARTICIPANT	\N	PRESENT	0
65537	65359	07004J	PARTICIPANT	\N	PRESENT	0
65538	65359	14073Q	PARTICIPANT	\N	PRESENT	0
65539	65359	14179A	PARTICIPANT	\N	PRESENT	0
65540	65359	07029T	PARTICIPANT	\N	PRESENT	0
65541	65359	04088S	PARTICIPANT	\N	PRESENT	0
65542	65359	14229S	PARTICIPANT	\N	PRESENT	0
65543	65359	14241N	PARTICIPANT	\N	PRESENT	0
65544	65359	14059S	PARTICIPANT	\N	PRESENT	0
65545	65359	14026U	PARTICIPANT	\N	PRESENT	0
65546	65359	14331P	PARTICIPANT	\N	PRESENT	0
65547	65359	14051J	PARTICIPANT	\N	PRESENT	0
65548	65359	14271U	PARTICIPANT	\N	PRESENT	0
65549	65359	11066Q	PARTICIPANT	\N	PRESENT	0
65550	65359	08039A	PARTICIPANT	\N	PRESENT	0
65552	65359	04070G	PARTICIPANT	\N	PRESENT	0
65553	65359	14042U	PARTICIPANT	\N	PRESENT	0
65556	65359	95062K	PARTICIPANT	\N	PRESENT	0
65557	65359	14273W	PARTICIPANT	\N	PRESENT	0
65558	65359	99004R	PARTICIPANT	\N	PRESENT	0
65559	65359	08010L	PARTICIPANT	\N	PRESENT	0
65560	65359	14033T	PARTICIPANT	\N	PRESENT	0
65561	65359	08069G	PARTICIPANT	\N	PRESENT	0
65562	65359	11103C	PARTICIPANT	\N	PRESENT	0
65563	65359	08048B	PARTICIPANT	\N	PRESENT	0
65564	65359	11029K	PARTICIPANT	\N	PRESENT	0
65568	65359	95030B	PARTICIPANT	\N	PRESENT	0
65569	65359	01028R	PARTICIPANT	\N	PRESENT	0
65570	65359	04057K	PARTICIPANT	\N	PRESENT	0
65571	65359	14267Y	PARTICIPANT	\N	PRESENT	0
65572	65359	08017T	PARTICIPANT	\N	PRESENT	0
65573	65359	11091R	PARTICIPANT	\N	PRESENT	0
65574	65359	11014C	PARTICIPANT	\N	PRESENT	0
65575	65359	14089Y	PARTICIPANT	\N	PRESENT	0
65576	65359	14039A	PARTICIPANT	\N	PRESENT	0
65577	65359	14159V	PARTICIPANT	\N	PRESENT	0
65578	65359	04081K	PARTICIPANT	\N	PRESENT	0
65579	65359	14219Q	PARTICIPANT	\N	PRESENT	0
65580	65359	14187A	PARTICIPANT	\N	PRESENT	0
65581	65359	14107H	PARTICIPANT	\N	PRESENT	0
65582	65359	08034U	PARTICIPANT	\N	PRESENT	0
65583	65359	11098Y	PARTICIPANT	\N	PRESENT	0
65584	65359	14041T	PARTICIPANT	\N	PRESENT	0
65585	65359	11100Y	PARTICIPANT	\N	PRESENT	0
65586	65359	01027Q	PARTICIPANT	\N	PRESENT	0
65587	65359	12042Y	PARTICIPANT	\N	PRESENT	0
65588	65359	01022K	PARTICIPANT	\N	PRESENT	0
65589	65359	14105F	PARTICIPANT	\N	PRESENT	0
65590	65359	14327T	PARTICIPANT	\N	PRESENT	0
65591	65359	95035G	PARTICIPANT	\N	PRESENT	0
65592	65359	14249W	PARTICIPANT	\N	PRESENT	0
65593	65359	92045V	PARTICIPANT	\N	PRESENT	0
65596	65359	04045F	PARTICIPANT	\N	PRESENT	0
65598	65359	11036J	PARTICIPANT	\N	PRESENT	0
65599	65359	14197C	PARTICIPANT	\N	PRESENT	0
65600	65359	14205J	PARTICIPANT	\N	PRESENT	0
65601	65359	11040E	PARTICIPANT	\N	PRESENT	0
65602	65359	11026G	PARTICIPANT	\N	PRESENT	0
65603	65359	08068F	PARTICIPANT	\N	PRESENT	0
65604	65359	95049N	PARTICIPANT	\N	PRESENT	0
65605	65359	11039M	PARTICIPANT	\N	PRESENT	0
65606	65359	14013P	PARTICIPANT	\N	PRESENT	0
65621	65359	14093U	PARTICIPANT	\N	PRESENT	0
65629	65359	07032N	PARTICIPANT	\N	PRESENT	0
65630	65359	14103D	PARTICIPANT	\N	PRESENT	0
65640	65359	95015C	PARTICIPANT	\N	PRESENT	0
65643	65359	08031R	PARTICIPANT	\N	PRESENT	0
65651	65359	11090Q	PARTICIPANT	\N	PRESENT	0
65676	65359	11048N	PARTICIPANT	\N	PRESENT	0
65679	65359	14265W	PARTICIPANT	\N	PRESENT	0
65684	65359	14147R	PARTICIPANT	\N	PRESENT	0
65688	65359	01048V	PARTICIPANT	\N	PRESENT	0
65689	65359	01047U	PARTICIPANT	\N	PRESENT	0
65690	65359	10015M	PARTICIPANT	\N	PRESENT	0
65691	65359	01007L	PARTICIPANT	\N	PRESENT	0
65692	65359	14195A	PARTICIPANT	\N	PRESENT	0
65693	65359	08047A	PARTICIPANT	\N	PRESENT	0
65694	65359	11067R	PARTICIPANT	\N	PRESENT	0
65695	65359	08056B	PARTICIPANT	\N	PRESENT	0
65696	65359	08061X	PARTICIPANT	\N	PRESENT	0
65697	65359	14175V	PARTICIPANT	\N	PRESENT	0
65698	65359	14173T	PARTICIPANT	\N	PRESENT	0
65701	65359	11112D	PARTICIPANT	\N	PRESENT	0
65702	65359	08016S	PARTICIPANT	\N	PRESENT	0
65703	65359	04056J	PARTICIPANT	\N	PRESENT	0
65704	65359	14213J	PARTICIPANT	\N	PRESENT	0
65705	65359	97011G	PARTICIPANT	\N	PRESENT	0
65706	65359	11012A	PARTICIPANT	\N	PRESENT	0
65707	65359	11042G	PARTICIPANT	\N	PRESENT	0
65708	65359	11093T	PARTICIPANT	\N	PRESENT	0
65709	65359	01046T	PARTICIPANT	\N	PRESENT	0
65710	65359	01003G	PARTICIPANT	\N	PRESENT	0
65711	65359	11071M	PARTICIPANT	\N	PRESENT	0
65712	65359	04043D	PARTICIPANT	\N	PRESENT	0
65713	65359	14237S	PARTICIPANT	\N	PRESENT	0
65714	65359	11084S	PARTICIPANT	\N	PRESENT	0
65715	65359	14109K	PARTICIPANT	\N	PRESENT	0
65716	65359	14061L	PARTICIPANT	\N	PRESENT	0
65717	65359	04067M	PARTICIPANT	\N	PRESENT	0
65718	65359	80013X	PARTICIPANT	\N	PRESENT	0
65719	65359	14083S	PARTICIPANT	\N	PRESENT	0
65720	65359	08052W	PARTICIPANT	\N	PRESENT	0
65721	65359	14169X	PARTICIPANT	\N	PRESENT	0
65722	65359	14201E	PARTICIPANT	\N	PRESENT	0
65723	65359	14135M	PARTICIPANT	\N	PRESENT	0
65724	65359	14034U	PARTICIPANT	\N	PRESENT	0
65725	65359	04095R	PARTICIPANT	\N	PRESENT	0
65726	65359	04094Q	PARTICIPANT	\N	PRESENT	0
65727	65359	04044E	PARTICIPANT	\N	PRESENT	0
65728	65359	01024M	PARTICIPANT	\N	PRESENT	0
65729	65359	90003B	PARTICIPANT	\N	PRESENT	0
65730	65359	13002U	PARTICIPANT	\N	PRESENT	0
65731	65359	14199E	PARTICIPANT	\N	PRESENT	0
65732	65359	04047H	PARTICIPANT	\N	PRESENT	0
65733	65359	86044G	PARTICIPANT	\N	PRESENT	0
65734	65359	01060R	PARTICIPANT	\N	PRESENT	0
65735	65359	11101A	PARTICIPANT	\N	PRESENT	0
65736	65359	14069U	PARTICIPANT	\N	PRESENT	0
65737	65359	04035D	PARTICIPANT	\N	PRESENT	0
65738	65359	11105E	PARTICIPANT	\N	PRESENT	0
65739	65359	08060W	PARTICIPANT	\N	PRESENT	0
65740	65359	14037X	PARTICIPANT	\N	PRESENT	0
65741	65359	08055A	PARTICIPANT	\N	PRESENT	0
65742	65359	14217N	PARTICIPANT	\N	PRESENT	0
65821	65360	08024S	PARTICIPANT	\N	PRESENT	0
65822	65360	04077P	PARTICIPANT	\N	PRESENT	0
65823	65360	01022K	PARTICIPANT	\N	PRESENT	0
65824	65360	14001X	PARTICIPANT	\N	PRESENT	0
65825	65360	83042R	PARTICIPANT	\N	PRESENT	0
65826	65360	14065Q	PARTICIPANT	\N	PRESENT	0
65827	65360	04034C	PARTICIPANT	\N	PRESENT	0
65828	65360	04042C	PARTICIPANT	\N	PRESENT	0
65829	65360	96004D	PARTICIPANT	\N	PRESENT	0
65830	65360	08016S	PARTICIPANT	\N	PRESENT	0
65831	65360	04045F	PARTICIPANT	\N	PRESENT	0
65832	65360	14159V	PARTICIPANT	\N	PRESENT	0
65833	65360	11083R	PARTICIPANT	\N	PRESENT	0
65834	65360	11026G	PARTICIPANT	\N	PRESENT	0
65835	65360	04095R	PARTICIPANT	\N	PRESENT	0
65836	65360	14073Q	PARTICIPANT	\N	PRESENT	0
65837	65360	08056B	PARTICIPANT	\N	PRESENT	0
65838	65360	11012A	PARTICIPANT	\N	PRESENT	0
65839	65360	01024M	PARTICIPANT	\N	PRESENT	0
65840	65360	14135M	PARTICIPANT	\N	PRESENT	0
65841	65360	04088S	PARTICIPANT	\N	PRESENT	0
65842	65360	11101A	PARTICIPANT	\N	PRESENT	0
65843	65360	14033T	PARTICIPANT	\N	PRESENT	0
65844	65360	01060R	PARTICIPANT	\N	PRESENT	0
65845	65360	14331P	PARTICIPANT	\N	PRESENT	0
65846	65360	04044E	PARTICIPANT	\N	PRESENT	0
65847	65360	80013X	PARTICIPANT	\N	PRESENT	0
65848	65360	11063M	PARTICIPANT	\N	PRESENT	0
65849	65360	11015D	PARTICIPANT	\N	PRESENT	0
65850	65360	04094Q	PARTICIPANT	\N	PRESENT	0
65851	65360	14237S	PARTICIPANT	\N	PRESENT	0
65852	65360	98018T	PARTICIPANT	\N	PRESENT	0
74563	72441	14013P	PARTICIPANT	\N	PRESENT	0
74564	72441	11085T	PARTICIPANT	\N	PRESENT	0
74565	72441	11084S	PARTICIPANT	\N	PRESENT	0
74566	72441	95049N	PARTICIPANT	\N	PRESENT	0
74567	72441	11068S	PARTICIPANT	\N	PRESENT	0
74568	72441	01007L	PARTICIPANT	\N	PRESENT	0
74569	72441	11099A	PARTICIPANT	\N	PRESENT	0
74570	72441	11033F	PARTICIPANT	\N	PRESENT	0
74571	72441	01044R	PARTICIPANT	\N	PRESENT	0
74572	72441	01043Q	PARTICIPANT	\N	PRESENT	0
74573	72441	11055M	PARTICIPANT	\N	PRESENT	0
74574	72441	11065P	PARTICIPANT	\N	PRESENT	0
74575	72441	14093U	PARTICIPANT	\N	PRESENT	0
74576	72441	01057W	PARTICIPANT	\N	PRESENT	0
74577	72441	11067R	PARTICIPANT	\N	PRESENT	0
74578	72441	14257W	PARTICIPANT	\N	PRESENT	0
74579	72441	14251Q	PARTICIPANT	\N	PRESENT	0
74580	72441	12042Y	PARTICIPANT	\N	PRESENT	0
74581	72441	11107G	PARTICIPANT	\N	PRESENT	0
74582	72441	14037X	PARTICIPANT	\N	PRESENT	0
74583	72441	01014K	PARTICIPANT	\N	PRESENT	0
74584	72441	14201E	PARTICIPANT	\N	PRESENT	0
74585	72441	08062Y	PARTICIPANT	\N	PRESENT	0
74586	72441	11091R	PARTICIPANT	\N	PRESENT	0
74587	72441	08051V	PARTICIPANT	\N	PRESENT	0
74588	72441	08047A	PARTICIPANT	\N	PRESENT	0
74589	72441	01046T	PARTICIPANT	\N	PRESENT	0
74590	72441	08031R	PARTICIPANT	\N	PRESENT	0
74591	72441	11012A	PARTICIPANT	\N	PRESENT	0
74592	72441	14069U	PARTICIPANT	\N	PRESENT	0
74593	72441	11081P	PARTICIPANT	\N	PRESENT	0
74594	72441	14119M	PARTICIPANT	\N	PRESENT	0
74595	72441	14173T	PARTICIPANT	\N	PRESENT	0
74596	72441	14267Y	PARTICIPANT	\N	PRESENT	0
74597	72441	14219Q	PARTICIPANT	\N	PRESENT	0
74598	72441	14103D	PARTICIPANT	\N	PRESENT	0
74599	72441	11114F	PARTICIPANT	\N	PRESENT	0
74600	72441	14157T	PARTICIPANT	\N	PRESENT	0
74601	72441	14205J	PARTICIPANT	\N	PRESENT	0
74602	72441	01008M	PARTICIPANT	\N	PRESENT	0
74603	72441	04080J	PARTICIPANT	\N	PRESENT	0
74604	72441	11080N	PARTICIPANT	\N	PRESENT	0
74605	72441	08009T	PARTICIPANT	\N	PRESENT	0
74606	72441	11053K	PARTICIPANT	\N	PRESENT	0
74607	72441	01034P	PARTICIPANT	\N	PRESENT	0
74608	72441	14217N	PARTICIPANT	\N	PRESENT	0
74609	72441	11015D	PARTICIPANT	\N	PRESENT	0
74610	72441	05008E	PARTICIPANT	\N	PRESENT	0
74611	72441	08019V	PARTICIPANT	\N	PRESENT	0
74612	72441	01024M	PARTICIPANT	\N	PRESENT	0
74613	72441	14034U	PARTICIPANT	\N	PRESENT	0
74631	72441	11071M	PARTICIPANT	\N	PRESENT	0
74615	72441	98042T	PARTICIPANT	\N	PRESENT	0
74616	72441	11093T	PARTICIPANT	\N	PRESENT	0
74617	72441	14042U	PARTICIPANT	\N	PRESENT	0
74618	72441	14231L	PARTICIPANT	\N	PRESENT	0
74619	72441	04089T	PARTICIPANT	\N	PRESENT	0
74620	72441	11082Q	PARTICIPANT	\N	PRESENT	0
74621	72441	14227Q	PARTICIPANT	\N	PRESENT	0
74622	72441	14018U	PARTICIPANT	\N	PRESENT	0
74623	72441	89017R	PARTICIPANT	\N	PRESENT	0
74624	72441	14213J	PARTICIPANT	\N	PRESENT	0
74625	72441	04038G	PARTICIPANT	\N	PRESENT	0
74626	72441	01027Q	PARTICIPANT	\N	PRESENT	0
74627	72441	14193X	PARTICIPANT	\N	PRESENT	0
74628	72441	01048V	PARTICIPANT	\N	PRESENT	0
74629	72441	04061F	PARTICIPANT	\N	PRESENT	0
74630	72441	14255U	PARTICIPANT	\N	PRESENT	0
74632	72441	13002U	PARTICIPANT	\N	PRESENT	0
74633	72441	14199E	PARTICIPANT	\N	PRESENT	0
74640	72441	14089Y	PARTICIPANT	\N	PRESENT	0
74635	72441	08044W	PARTICIPANT	\N	PRESENT	0
74636	72441	09001P	PARTICIPANT	\N	PRESENT	0
74637	72441	04070G	PARTICIPANT	\N	PRESENT	0
74638	72441	92045V	PARTICIPANT	\N	PRESENT	0
74639	72441	92020L	PARTICIPANT	\N	PRESENT	0
74641	72441	04071H	PARTICIPANT	\N	PRESENT	0
74642	72441	01041N	PARTICIPANT	\N	PRESENT	0
74643	72441	11026G	PARTICIPANT	\N	PRESENT	0
74644	72441	11031D	PARTICIPANT	\N	PRESENT	0
74645	72441	14175V	PARTICIPANT	\N	PRESENT	0
74646	72441	04086Q	PARTICIPANT	\N	PRESENT	0
74921	72861	98053W	PARTICIPANT	\N	PRESENT	0
74922	72861	05008E	PARTICIPANT	\N	PRESENT	0
74923	72861	11054L	PARTICIPANT	\N	PRESENT	0
74924	72861	04034C	PARTICIPANT	\N	PRESENT	0
74925	72861	08017T	PARTICIPANT	\N	PRESENT	0
74926	72861	11036J	PARTICIPANT	\N	PRESENT	0
74927	72861	80013X	PARTICIPANT	\N	PRESENT	0
74928	72861	14014Q	PARTICIPANT	\N	PRESENT	0
74929	72861	11077T	PARTICIPANT	\N	PRESENT	0
74930	72861	04067M	PARTICIPANT	\N	PRESENT	0
74931	72861	14205J	PARTICIPANT	\N	PRESENT	0
74932	72861	01007L	PARTICIPANT	\N	PRESENT	0
74933	72861	14215L	PARTICIPANT	\N	PRESENT	0
74934	72861	14071N	PARTICIPANT	\N	PRESENT	0
74935	72861	01041N	PARTICIPANT	\N	PRESENT	0
74936	72861	14265W	PARTICIPANT	\N	PRESENT	0
74937	72861	07032N	PARTICIPANT	\N	PRESENT	0
74938	72861	11071M	PARTICIPANT	\N	PRESENT	0
74939	72861	11088W	PARTICIPANT	\N	PRESENT	0
74940	72861	07029T	PARTICIPANT	\N	PRESENT	0
74941	72861	08019V	PARTICIPANT	\N	PRESENT	0
74942	72861	14053L	PARTICIPANT	\N	PRESENT	0
74943	72861	04038G	PARTICIPANT	\N	PRESENT	0
74944	72861	08031R	PARTICIPANT	\N	PRESENT	0
74945	72861	14103D	PARTICIPANT	\N	PRESENT	0
74946	72861	01027Q	PARTICIPANT	\N	PRESENT	0
74947	72861	04085P	PARTICIPANT	\N	PRESENT	0
74948	72861	01043Q	PARTICIPANT	\N	PRESENT	0
74949	72861	11067R	PARTICIPANT	\N	PRESENT	0
74950	72861	00003C	PARTICIPANT	\N	PRESENT	0
74951	72861	14281W	PARTICIPANT	\N	PRESENT	0
74952	72861	11065P	PARTICIPANT	\N	PRESENT	0
74953	72861	11015D	PARTICIPANT	\N	PRESENT	0
74954	72861	07026Q	PARTICIPANT	\N	PRESENT	0
74955	72861	11031D	PARTICIPANT	\N	PRESENT	0
74956	72861	12041X	PARTICIPANT	\N	PRESENT	0
74957	72861	11033F	PARTICIPANT	\N	PRESENT	0
74958	72861	11026G	PARTICIPANT	\N	PRESENT	0
74959	72861	14201E	PARTICIPANT	\N	PRESENT	0
74960	72861	14273W	PARTICIPANT	\N	PRESENT	0
74961	72861	11105E	PARTICIPANT	\N	PRESENT	0
74962	72861	14251Q	PARTICIPANT	\N	PRESENT	0
74963	72861	11080N	PARTICIPANT	\N	PRESENT	0
74964	72861	04071H	PARTICIPANT	\N	PRESENT	0
74965	72861	14247U	PARTICIPANT	\N	PRESENT	0
74966	72861	08053X	PARTICIPANT	\N	PRESENT	0
74967	72861	01013J	PARTICIPANT	\N	PRESENT	0
74968	72861	14329V	PARTICIPANT	\N	PRESENT	0
74969	72861	14259Y	PARTICIPANT	\N	PRESENT	0
74970	72861	04033B	PARTICIPANT	\N	PRESENT	0
74971	72861	11090Q	PARTICIPANT	\N	PRESENT	0
74972	72861	14034U	PARTICIPANT	\N	PRESENT	0
74973	72861	14042U	PARTICIPANT	\N	PRESENT	0
74974	72861	14219Q	PARTICIPANT	\N	PRESENT	0
74975	72861	14030Q	PARTICIPANT	\N	PRESENT	0
74976	72861	11037K	PARTICIPANT	\N	PRESENT	0
74977	72861	14159V	PARTICIPANT	\N	PRESENT	0
74978	72861	08052W	PARTICIPANT	\N	PRESENT	0
74979	72861	01011G	PARTICIPANT	\N	PRESENT	0
74980	72861	14089Y	PARTICIPANT	\N	PRESENT	0
74981	72861	14083S	PARTICIPANT	\N	PRESENT	0
74982	72861	04077P	PARTICIPANT	\N	PRESENT	0
74983	72861	04044E	PARTICIPANT	\N	PRESENT	0
74984	72861	98029W	PARTICIPANT	\N	PRESENT	0
74985	72861	92020L	PARTICIPANT	\N	PRESENT	0
74986	72861	01028R	PARTICIPANT	\N	PRESENT	0
74987	72861	04059M	PARTICIPANT	\N	PRESENT	0
74988	72861	14041T	PARTICIPANT	\N	PRESENT	0
74989	72861	14157T	PARTICIPANT	\N	PRESENT	0
74990	72861	01034P	PARTICIPANT	\N	PRESENT	0
74991	72861	14135M	PARTICIPANT	\N	PRESENT	0
74992	72861	08047A	PARTICIPANT	\N	PRESENT	0
74993	72861	14249W	PARTICIPANT	\N	PRESENT	0
74994	72861	08010L	PARTICIPANT	\N	PRESENT	0
74995	72861	08018U	PARTICIPANT	\N	PRESENT	0
75002	72861	95063L	PARTICIPANT	\N	PRESENT	0
75003	72861	11091R	PARTICIPANT	\N	PRESENT	0
75004	72861	04081K	PARTICIPANT	\N	PRESENT	0
75005	72861	04086Q	PARTICIPANT	\N	PRESENT	0
75006	72861	10006L	PARTICIPANT	\N	PRESENT	0
75007	72861	14209N	PARTICIPANT	\N	PRESENT	0
75008	72861	14221J	PARTICIPANT	\N	PRESENT	0
75010	72861	14197C	PARTICIPANT	\N	PRESENT	0
75012	72861	05012A	PARTICIPANT	\N	PRESENT	0
75013	72861	04047H	PARTICIPANT	\N	PRESENT	0
75014	72861	11100Y	PARTICIPANT	\N	PRESENT	0
62347	61420	08024S	PARTICIPANT	\N	PRESENT	0
62348	61420	08039A	PARTICIPANT	\N	PRESENT	0
62349	61420	14038Y	PARTICIPANT	\N	PRESENT	0
62350	61420	01044R	PARTICIPANT	\N	PRESENT	0
62351	61420	14235Q	PARTICIPANT	\N	PRESENT	0
62352	61420	07026Q	PARTICIPANT	\N	PRESENT	0
62353	61420	14173T	PARTICIPANT	\N	PRESENT	0
62354	61420	04088S	PARTICIPANT	\N	PRESENT	0
62355	61420	14063N	PARTICIPANT	\N	PRESENT	0
62356	61420	14229S	PARTICIPANT	\N	PRESENT	0
62416	61420	04056J	PARTICIPANT	\N	PRESENT	0
62417	61420	14061L	PARTICIPANT	\N	PRESENT	0
62418	61420	11091R	PARTICIPANT	\N	PRESENT	0
62419	61420	04057K	PARTICIPANT	\N	PRESENT	0
62420	61420	08031R	PARTICIPANT	\N	PRESENT	0
62421	61420	13002U	PARTICIPANT	\N	PRESENT	0
62422	61420	11090Q	PARTICIPANT	\N	PRESENT	0
62423	61420	14018U	PARTICIPANT	\N	PRESENT	0
62424	61420	11029K	PARTICIPANT	\N	PRESENT	0
62425	61420	11043H	PARTICIPANT	\N	PRESENT	0
62426	61420	08055A	PARTICIPANT	\N	PRESENT	0
62427	61420	11040E	PARTICIPANT	\N	PRESENT	0
62428	61420	04070G	PARTICIPANT	\N	PRESENT	0
62429	61420	04059M	PARTICIPANT	\N	PRESENT	0
62430	61420	92040Q	PARTICIPANT	\N	PRESENT	0
62431	61420	95015C	PARTICIPANT	\N	PRESENT	0
62432	61420	14241N	PARTICIPANT	\N	PRESENT	0
62433	61420	04041B	PARTICIPANT	\N	PRESENT	0
62434	61420	14087W	PARTICIPANT	\N	PRESENT	0
62435	61420	01025N	PARTICIPANT	\N	PRESENT	0
62436	61420	14191V	PARTICIPANT	\N	PRESENT	0
62437	61420	14207L	PARTICIPANT	\N	PRESENT	0
62438	61420	11074Q	PARTICIPANT	\N	PRESENT	0
62439	61420	11089X	PARTICIPANT	\N	PRESENT	0
62440	61420	14103D	PARTICIPANT	\N	PRESENT	0
62441	61420	11103C	PARTICIPANT	\N	PRESENT	0
62443	61420	11105E	PARTICIPANT	\N	PRESENT	0
62444	61420	14107H	PARTICIPANT	\N	PRESENT	0
62445	61420	14249W	PARTICIPANT	\N	PRESENT	0
62446	61420	14265W	PARTICIPANT	\N	PRESENT	0
62447	61420	14273W	PARTICIPANT	\N	PRESENT	0
62448	61420	11104D	PARTICIPANT	\N	PRESENT	0
62449	61420	04089T	PARTICIPANT	\N	PRESENT	0
62450	61420	08019V	PARTICIPANT	\N	PRESENT	0
62451	61420	11066Q	PARTICIPANT	\N	PRESENT	0
62452	61420	86044G	PARTICIPANT	\N	PRESENT	0
62453	61420	87003B	PARTICIPANT	\N	PRESENT	0
62454	61420	11042G	PARTICIPANT	\N	PRESENT	0
62455	61420	14109K	PARTICIPANT	\N	PRESENT	0
62456	61420	07029T	PARTICIPANT	\N	PRESENT	0
62457	61420	12041X	PARTICIPANT	\N	PRESENT	0
62458	61420	01046T	PARTICIPANT	\N	PRESENT	0
62459	61420	08062Y	PARTICIPANT	\N	PRESENT	0
62460	61420	08043V	PARTICIPANT	\N	PRESENT	0
62461	61420	11093T	PARTICIPANT	\N	PRESENT	0
62462	61420	11053K	PARTICIPANT	\N	PRESENT	0
62463	61420	14201E	PARTICIPANT	\N	PRESENT	0
62464	61420	08017T	PARTICIPANT	\N	PRESENT	0
62465	61420	08065C	PARTICIPANT	\N	PRESENT	0
62466	61420	08034U	PARTICIPANT	\N	PRESENT	0
62467	61420	14259Y	PARTICIPANT	\N	PRESENT	0
62468	61420	14026U	PARTICIPANT	\N	PRESENT	0
62469	61420	11039M	PARTICIPANT	\N	PRESENT	0
62470	61420	14001X	PARTICIPANT	\N	PRESENT	0
62471	61420	14231L	PARTICIPANT	\N	PRESENT	0
62472	61420	14267Y	PARTICIPANT	\N	PRESENT	0
62473	61420	14225N	PARTICIPANT	\N	PRESENT	0
62474	61420	14331P	PARTICIPANT	\N	PRESENT	0
62475	61420	14059S	PARTICIPANT	\N	PRESENT	0
62476	61420	14033T	PARTICIPANT	\N	PRESENT	0
62477	61420	14195A	PARTICIPANT	\N	PRESENT	0
62478	61420	14089Y	PARTICIPANT	\N	PRESENT	0
62479	61420	08015R	PARTICIPANT	\N	PRESENT	0
62480	61420	11097X	PARTICIPANT	\N	PRESENT	0
62481	61420	14069U	PARTICIPANT	\N	PRESENT	0
62482	61420	97011G	PARTICIPANT	\N	PRESENT	0
62483	61420	01027Q	PARTICIPANT	\N	PRESENT	0
62484	61420	14051J	PARTICIPANT	\N	PRESENT	0
62485	61420	14257W	PARTICIPANT	\N	PRESENT	0
62486	61420	14083S	PARTICIPANT	\N	PRESENT	0
62487	61420	14121F	PARTICIPANT	\N	PRESENT	0
62488	61420	01048V	PARTICIPANT	\N	PRESENT	0
62489	61420	08068F	PARTICIPANT	\N	PRESENT	0
62490	61420	14071N	PARTICIPANT	\N	PRESENT	0
62491	61420	04049K	PARTICIPANT	\N	PRESENT	0
62492	61420	14209N	PARTICIPANT	\N	PRESENT	0
62493	61420	14123H	PARTICIPANT	\N	PRESENT	0
62494	61420	14111D	PARTICIPANT	\N	PRESENT	0
62496	61420	14237S	PARTICIPANT	\N	PRESENT	0
62497	61420	14219Q	PARTICIPANT	\N	PRESENT	0
62498	61420	14223L	PARTICIPANT	\N	PRESENT	0
62499	61420	01028R	PARTICIPANT	\N	PRESENT	0
62500	61420	90003B	PARTICIPANT	\N	PRESENT	0
62501	61420	11084S	PARTICIPANT	\N	PRESENT	0
62502	61420	14205J	PARTICIPANT	\N	PRESENT	0
62503	61420	95030B	PARTICIPANT	\N	PRESENT	0
62504	61420	11065P	PARTICIPANT	\N	PRESENT	0
62505	61420	01008M	PARTICIPANT	\N	PRESENT	0
62506	61420	14053L	PARTICIPANT	\N	PRESENT	0
62507	61420	04092N	PARTICIPANT	\N	PRESENT	0
62508	61420	07032N	PARTICIPANT	\N	PRESENT	0
62509	61420	14147R	PARTICIPANT	\N	PRESENT	0
62510	61420	14187A	PARTICIPANT	\N	PRESENT	0
62511	61420	98046X	PARTICIPANT	\N	PRESENT	0
62512	61420	01022K	PARTICIPANT	\N	PRESENT	0
62513	61420	11112D	PARTICIPANT	\N	PRESENT	0
62514	61420	14031R	PARTICIPANT	\N	PRESENT	0
62515	61420	14157T	PARTICIPANT	\N	PRESENT	0
62516	61420	08022Q	PARTICIPANT	\N	PRESENT	0
62517	61420	14213J	PARTICIPANT	\N	PRESENT	0
62518	61420	14030Q	PARTICIPANT	\N	PRESENT	0
62519	61420	11100Y	PARTICIPANT	\N	PRESENT	0
62520	61420	11070L	PARTICIPANT	\N	PRESENT	0
62521	61420	11057P	PARTICIPANT	\N	PRESENT	0
62522	61420	14013P	PARTICIPANT	\N	PRESENT	0
62523	61420	14037X	PARTICIPANT	\N	PRESENT	0
62524	61420	01047U	PARTICIPANT	\N	PRESENT	0
62525	61420	01034P	PARTICIPANT	\N	PRESENT	0
62526	61420	11085T	PARTICIPANT	\N	PRESENT	0
62548	61420	14199E	PARTICIPANT	\N	PRESENT	0
62549	61420	14073Q	PARTICIPANT	\N	PRESENT	0
62550	61420	14105F	PARTICIPANT	\N	PRESENT	0
62551	61420	11110B	PARTICIPANT	\N	PRESENT	0
62552	61420	80013X	PARTICIPANT	\N	PRESENT	0
62553	61420	08061X	PARTICIPANT	\N	PRESENT	0
62578	61420	11083R	PARTICIPANT	\N	PRESENT	0
62579	61420	01031L	PARTICIPANT	\N	PRESENT	0
62580	61420	01003G	PARTICIPANT	\N	PRESENT	0
62582	61420	88008L	PARTICIPANT	\N	PRESENT	0
62593	61420	11046L	PARTICIPANT	\N	PRESENT	0
62594	61420	08051V	PARTICIPANT	\N	PRESENT	0
62595	61420	11012A	PARTICIPANT	\N	PRESENT	0
62596	61420	14119M	PARTICIPANT	\N	PRESENT	0
62597	61420	04081K	PARTICIPANT	\N	PRESENT	0
62638	61420	08053X	PARTICIPANT	\N	PRESENT	0
62639	61420	11095V	PARTICIPANT	\N	PRESENT	0
62640	61420	05012A	PARTICIPANT	\N	PRESENT	0
62641	61420	09001P	PARTICIPANT	\N	PRESENT	0
62642	61420	07004J	PARTICIPANT	\N	PRESENT	0
62643	61420	12042Y	PARTICIPANT	\N	PRESENT	0
501679	498850	19575F	PRESIDENT	1	PRESENT	0
502054	500409	14133K	PARTICIPANT	\N	PRESENT	0
502055	500409	96004D	PARTICIPANT	\N	EXCUSE	0
502056	500409	14089Y	PARTICIPANT	\N	EXCUSE	0
502058	500409	19531S	PARTICIPANT	\N	PRESENT	0
502059	500409	20128B	PARTICIPANT	\N	PRESENT	0
502060	500409	14097Y	PARTICIPANT	\N	PRESENT	0
502061	500409	11026G	PARTICIPANT	\N	PRESENT	0
502062	500409	19441R	PARTICIPANT	\N	PRESENT	0
502063	500409	14001X	PARTICIPANT	\N	PRESENT	0
502064	500409	14026U	PARTICIPANT	\N	PRESENT	0
502065	500409	11083R	PARTICIPANT	\N	PRESENT	0
502066	500409	04035D	PARTICIPANT	\N	PRESENT	0
502067	500409	14169X	PARTICIPANT	\N	PRESENT	0
502068	500409	04070G	PARTICIPANT	\N	PRESENT	0
502069	500409	14237S	PARTICIPANT	\N	PRESENT	0
502070	500409	14331P	PRESIDENT	0	PRESENT	0
502071	500409	20098N	PARTICIPANT	\N	PRESENT	0
502072	500409	10015M	PARTICIPANT	\N	PRESENT	0
502073	500409	04034C	PARTICIPANT	\N	PRESENT	0
502074	500409	19701S	PARTICIPANT	\N	PRESENT	0
502075	500409	11101A	PARTICIPANT	\N	PRESENT	0
502076	500409	19251M	PARTICIPANT	\N	PRESENT	0
502077	500409	14207L	PARTICIPANT	\N	PRESENT	0
502078	500409	12016W	PARTICIPANT	\N	PRESENT	0
502079	500409	20100N	PARTICIPANT	\N	PRESENT	0
502093	500409	14357A	PARTICIPANT	\N	PRESENT	0
502094	500409	14073Q	PARTICIPANT	\N	PRESENT	0
502414	500285	04085P	PARTICIPANT	\N	PRESENT	0
82678	82677	14263U	PARTICIPANT	\N	PRESENT	0
82771	82769	11076S	PARTICIPANT	\N	EXCUSE	0
82680	82677	11109J	PARTICIPANT	\N	PRESENT	0
82681	82677	04059M	PARTICIPANT	\N	PRESENT	0
82682	82677	11039M	PARTICIPANT	\N	PRESENT	0
82683	82677	01044R	PARTICIPANT	\N	PRESENT	0
82684	82677	08043V	PARTICIPANT	\N	PRESENT	0
82685	82677	14089Y	PARTICIPANT	\N	PRESENT	0
82686	82677	14105F	PARTICIPANT	\N	PRESENT	0
82687	82677	11029K	PARTICIPANT	\N	PRESENT	0
82688	82677	95015C	PRESIDENT	0	PRESENT	0
82689	82677	92015P	PARTICIPANT	\N	PRESENT	0
82690	82677	08024S	PARTICIPANT	\N	PRESENT	0
82691	82677	14201E	PARTICIPANT	\N	EXCUSE	0
82692	82677	14329V	PARTICIPANT	\N	PRESENT	0
82693	82677	14209N	PARTICIPANT	\N	PRESENT	0
82694	82677	14079W	PARTICIPANT	\N	PRESENT	0
82695	82677	11091R	PARTICIPANT	\N	PRESENT	0
82696	82677	87003B	PARTICIPANT	\N	PRESENT	0
82697	82677	98042T	PARTICIPANT	\N	PRESENT	0
82698	82677	14249W	PARTICIPANT	\N	PRESENT	0
82699	82677	01041N	PARTICIPANT	\N	PRESENT	0
82700	82677	01025N	PARTICIPANT	\N	PRESENT	0
82701	82677	01037S	PARTICIPANT	\N	EXCUSE	0
82772	82769	04040A	PARTICIPANT	\N	EXCUSE	0
82773	82769	08058D	PARTICIPANT	\N	PRESENT	0
82704	82677	11089X	PARTICIPANT	\N	PRESENT	0
82705	82677	07026Q	PARTICIPANT	\N	PRESENT	0
82706	82677	14123H	PARTICIPANT	\N	PRESENT	0
82707	82677	14179A	PARTICIPANT	\N	PRESENT	0
82774	82769	04042C	PARTICIPANT	\N	PRESENT	0
82709	82677	14241N	PARTICIPANT	\N	PRESENT	0
82710	82677	14061L	PARTICIPANT	\N	PRESENT	0
82711	82677	14073Q	PARTICIPANT	\N	PRESENT	0
82712	82677	08031R	PARTICIPANT	\N	PRESENT	0
82713	82677	12041X	PARTICIPANT	\N	PRESENT	0
82714	82677	08039A	PARTICIPANT	\N	PRESENT	0
82715	82677	08017T	PARTICIPANT	\N	PRESENT	0
82716	82677	14059S	PARTICIPANT	\N	PRESENT	0
82717	82677	08012N	PARTICIPANT	\N	PRESENT	0
82718	82677	14103D	PARTICIPANT	\N	PRESENT	0
82719	82677	11104D	PARTICIPANT	\N	PRESENT	0
82720	82677	14063N	PARTICIPANT	\N	PRESENT	0
82721	82677	04057K	PARTICIPANT	\N	EXCUSE	0
82722	82677	11014C	PARTICIPANT	\N	PRESENT	0
82723	82677	14109K	PARTICIPANT	\N	PRESENT	0
82724	82677	04070G	PARTICIPANT	\N	PRESENT	0
82725	82677	92040Q	PARTICIPANT	\N	PRESENT	0
82726	82677	14191V	PARTICIPANT	\N	PRESENT	0
82727	82677	83047W	PARTICIPANT	\N	PRESENT	0
82728	82677	14235Q	PARTICIPANT	\N	PRESENT	0
82775	82769	77002U	PARTICIPANT	\N	EXCUSE	0
82730	82677	04033B	PARTICIPANT	\N	PRESENT	0
82731	82677	14229S	PARTICIPANT	\N	PRESENT	0
82732	82677	11043H	PARTICIPANT	\N	PRESENT	0
82733	82677	11071M	PARTICIPANT	\N	PRESENT	0
82734	82677	11011M	PARTICIPANT	\N	PRESENT	0
82776	82769	98029W	PARTICIPANT	\N	PRESENT	0
82777	82769	98018T	PARTICIPANT	\N	PRESENT	0
82778	82769	92018S	PARTICIPANT	\N	PRESENT	0
82779	82769	92020L	PARTICIPANT	\N	EXCUSE	0
82780	82769	95030B	PARTICIPANT	\N	PRESENT	0
82781	82769	97011G	PARTICIPANT	\N	PRESENT	0
82782	82769	08065C	PARTICIPANT	\N	PRESENT	0
82783	82769	07024N	PARTICIPANT	\N	PRESENT	0
82784	82769	14014Q	PARTICIPANT	\N	PRESENT	0
82785	82769	95035G	PARTICIPANT	\N	PRESENT	0
82825	82769	08056B	PARTICIPANT	\N	EXCUSE	0
82826	82769	98022P	PARTICIPANT	\N	PRESENT	0
82827	82769	11064N	PARTICIPANT	\N	EXCUSE	0
82828	82769	95037J	PARTICIPANT	\N	EXCUSE	0
82829	82769	04078Q	PARTICIPANT	\N	PRESENT	0
82831	82769	14097Y	PARTICIPANT	\N	PRESENT	0
82832	82769	95041E	PARTICIPANT	\N	EXCUSE	0
82833	82769	04036E	PARTICIPANT	\N	PRESENT	0
82835	82769	98005N	PARTICIPANT	\N	PRESENT	0
82837	82769	92031P	PARTICIPANT	\N	PRESENT	0
82840	82769	11106F	PARTICIPANT	\N	PRESENT	0
82842	82769	14251Q	PARTICIPANT	\N	EXCUSE	0
82846	82769	83042R	PARTICIPANT	\N	PRESENT	0
82848	82769	11105E	PARTICIPANT	\N	PRESENT	0
82849	82769	14253S	PARTICIPANT	\N	PRESENT	0
82850	82769	08047A	PARTICIPANT	\N	PRESENT	0
82851	82769	14028W	PARTICIPANT	\N	PRESENT	0
82852	82769	14193X	PARTICIPANT	\N	PRESENT	0
82853	82769	98021N	PARTICIPANT	\N	EXCUSE	0
82854	82769	04080J	PARTICIPANT	\N	PRESENT	0
82855	82769	86044G	PARTICIPANT	\N	EXCUSE	0
82856	82769	01014K	PARTICIPANT	\N	PRESENT	0
82857	82769	11054L	PARTICIPANT	\N	PRESENT	0
82858	82769	01056V	PARTICIPANT	\N	EXCUSE	0
82865	82769	95059Q	PRESIDENT	0	PRESENT	0
83273	83272	11109J	PARTICIPANT	\N	PRESENT	0
83777	83776	08042U	PARTICIPANT	\N	PRESENT	0
83275	83272	14030Q	PARTICIPANT	\N	PRESENT	0
83778	83776	11107G	PARTICIPANT	\N	PRESENT	0
83786	83784	01008M	PARTICIPANT	\N	PRESENT	0
83278	83272	01022K	PARTICIPANT	\N	PRESENT	0
83279	83272	11098Y	PARTICIPANT	\N	PRESENT	0
83280	83272	14031R	PARTICIPANT	\N	PRESENT	0
83281	83272	08009T	PRESIDENT	0	PRESENT	0
83787	83784	14157T	PARTICIPANT	\N	PRESENT	0
83283	83272	14331P	PARTICIPANT	\N	PRESENT	0
83284	83272	95062K	PARTICIPANT	\N	PRESENT	0
83285	83272	14051J	PARTICIPANT	\N	PRESENT	0
83286	83272	14157T	PARTICIPANT	\N	PRESENT	0
83788	83784	11112D	PARTICIPANT	\N	PRESENT	0
83790	83784	14033T	PARTICIPANT	\N	PRESENT	0
83791	83784	14265W	PARTICIPANT	\N	PRESENT	0
83792	83784	14097Y	PARTICIPANT	\N	PRESENT	0
85931	85927	14030Q	PARTICIPANT	\N	PRESENT	0
85933	85927	14217N	PARTICIPANT	\N	PRESENT	0
85935	85927	12042Y	PARTICIPANT	\N	PRESENT	0
85937	85927	95035G	PARTICIPANT	\N	EXCUSE	0
85938	85927	04041B	PARTICIPANT	\N	PRESENT	0
85939	85927	09001P	PRESIDENT	0	PRESENT	0
85940	85927	08031R	PARTICIPANT	\N	PRESENT	0
85942	85927	14031R	PARTICIPANT	\N	PRESENT	0
85943	85927	11067R	PARTICIPANT	\N	PRESENT	0
85944	85927	14265W	PARTICIPANT	\N	PRESENT	0
85948	85927	11029K	PARTICIPANT	\N	EXCUSE	0
85950	85927	14038Y	PARTICIPANT	\N	EXCUSE	0
85952	85927	07029T	PARTICIPANT	\N	EXCUSE	0
85982	85981	11048N	PARTICIPANT	\N	PRESENT	0
85984	85983	11048N	PARTICIPANT	\N	PRESENT	0
85989	85988	01057W	PARTICIPANT	\N	PRESENT	0
85990	85988	14225N	PARTICIPANT	\N	PRESENT	0
85991	85988	01013J	PARTICIPANT	\N	PRESENT	0
85992	85988	14167V	PARTICIPANT	\N	PRESENT	0
85993	85988	14175V	PARTICIPANT	\N	PRESENT	0
85994	85988	04086Q	PARTICIPANT	\N	PRESENT	0
85995	85988	11070L	PARTICIPANT	\N	PRESENT	0
85996	85988	11088W	PARTICIPANT	\N	PRESENT	0
85997	85988	14327T	PARTICIPANT	\N	PRESENT	0
85998	85988	14199E	PARTICIPANT	\N	PRESENT	0
85999	85988	98046X	PARTICIPANT	\N	PRESENT	0
86000	85988	08073C	PARTICIPANT	\N	PRESENT	0
86001	85988	11012A	PARTICIPANT	\N	PRESENT	0
90028	90027	14263U	PARTICIPANT	\N	PRESENT	0
90029	90027	14133K	PARTICIPANT	\N	PRESENT	0
90031	90027	04059M	PARTICIPANT	\N	PRESENT	0
90033	90027	01044R	PARTICIPANT	\N	PRESENT	0
90034	90027	08043V	PARTICIPANT	\N	PRESENT	0
90037	90027	11029K	PARTICIPANT	\N	PRESENT	0
90039	90027	92015P	PARTICIPANT	\N	PRESENT	0
90040	90027	08024S	PARTICIPANT	\N	PRESENT	0
90041	90027	14201E	PARTICIPANT	\N	PRESENT	0
90042	90027	14329V	PARTICIPANT	\N	PRESENT	0
90044	90027	14079W	PARTICIPANT	\N	PRESENT	0
90045	90027	11091R	PARTICIPANT	\N	PRESENT	0
90046	90027	87003B	PARTICIPANT	\N	PRESENT	0
90049	90027	01041N	PARTICIPANT	\N	PRESENT	0
90050	90027	01025N	PARTICIPANT	\N	PRESENT	0
90051	90027	01037S	PARTICIPANT	\N	EXCUSE	0
90054	90027	11089X	PARTICIPANT	\N	PRESENT	0
90057	90027	14179A	PARTICIPANT	\N	PRESENT	0
65855	65360	14219Q	PARTICIPANT	\N	PRESENT	0
65856	65360	95062K	PARTICIPANT	\N	PRESENT	0
65857	65360	01027Q	PARTICIPANT	\N	PRESENT	0
65858	65360	14037X	PARTICIPANT	\N	PRESENT	0
65859	65360	86044G	PARTICIPANT	\N	PRESENT	0
65860	65360	97011G	PARTICIPANT	\N	PRESENT	0
65861	65360	14026U	PARTICIPANT	\N	PRESENT	0
65862	65360	14265W	PARTICIPANT	\N	PRESENT	0
65863	65360	04047H	PARTICIPANT	\N	PRESENT	0
65864	65360	04035D	PARTICIPANT	\N	PRESENT	0
65865	65360	04061F	PARTICIPANT	\N	PRESENT	0
65866	65360	11091R	PARTICIPANT	\N	PRESENT	0
65867	65360	01037S	PARTICIPANT	\N	PRESENT	0
65868	65360	14061L	PARTICIPANT	\N	PRESENT	0
65869	65360	04057K	PARTICIPANT	\N	PRESENT	0
65870	65360	08039A	PARTICIPANT	\N	PRESENT	0
65871	65360	14013P	PARTICIPANT	\N	PRESENT	0
65872	65360	11040E	PARTICIPANT	\N	PRESENT	0
65873	65360	14263U	PARTICIPANT	\N	PRESENT	0
65874	65360	01014K	PARTICIPANT	\N	PRESENT	0
65875	65360	14031R	PARTICIPANT	\N	PRESENT	0
65876	65360	07024N	PARTICIPANT	\N	PRESENT	0
65877	65360	14271U	PARTICIPANT	\N	PRESENT	0
65878	65360	07004J	PARTICIPANT	\N	PRESENT	0
65879	65360	10015M	PARTICIPANT	\N	PRESENT	0
65938	65360	14217N	PARTICIPANT	\N	PRESENT	0
65939	65360	14213J	PARTICIPANT	\N	PRESENT	0
65940	65360	01008M	PARTICIPANT	\N	PRESENT	0
65941	65360	92031P	PARTICIPANT	\N	PRESENT	0
65942	65360	04059M	PARTICIPANT	\N	PRESENT	0
65943	65360	14018U	PARTICIPANT	\N	PRESENT	0
65944	65360	14247U	PARTICIPANT	\N	PRESENT	0
65945	65360	08034U	PARTICIPANT	\N	PRESENT	0
65946	65360	11061K	PARTICIPANT	\N	PRESENT	0
65947	65360	05012A	PARTICIPANT	\N	PRESENT	0
65948	65360	14030Q	PARTICIPANT	\N	PRESENT	0
65950	65360	14103D	PARTICIPANT	\N	PRESENT	0
65951	65360	11085T	PARTICIPANT	\N	PRESENT	0
65952	65360	14179A	PARTICIPANT	\N	PRESENT	0
65953	65360	11048N	PARTICIPANT	\N	PRESENT	0
65954	65360	08022Q	PARTICIPANT	\N	PRESENT	0
65955	65360	01058X	PARTICIPANT	\N	PRESENT	0
65956	65360	11036J	PARTICIPANT	\N	PRESENT	0
65957	65360	14069U	PARTICIPANT	\N	PRESENT	0
65958	65360	14249W	PARTICIPANT	\N	PRESENT	0
65959	65360	11098Y	PARTICIPANT	\N	PRESENT	0
65853	65360	90003B	PARTICIPANT	\N	PRESENT	0
65854	65360	14195A	PARTICIPANT	\N	PRESENT	0
65960	65360	07026Q	PARTICIPANT	\N	PRESENT	0
65961	65360	08051V	PARTICIPANT	\N	PRESENT	0
65962	65360	01016M	PARTICIPANT	\N	PRESENT	0
65963	65361	04066L	PARTICIPANT	\N	PRESENT	0
65964	65361	07026Q	PARTICIPANT	\N	PRESENT	0
65965	65361	14263U	PARTICIPANT	\N	PRESENT	0
65966	65361	80013X	PARTICIPANT	\N	PRESENT	0
65967	65361	14197C	PARTICIPANT	\N	PRESENT	0
65968	65361	14159V	PARTICIPANT	\N	PRESENT	0
65969	65361	04059M	PARTICIPANT	\N	PRESENT	0
65970	65361	08043V	PARTICIPANT	\N	PRESENT	0
65971	65361	14229S	PARTICIPANT	\N	PRESENT	0
65972	65361	14271U	PARTICIPANT	\N	PRESENT	0
65973	65361	01028R	PARTICIPANT	\N	PRESENT	0
65974	65361	11029K	PARTICIPANT	\N	PRESENT	0
65975	65361	01044R	PARTICIPANT	\N	PRESENT	0
65976	65361	11012A	PARTICIPANT	\N	PRESENT	0
65977	65361	14030Q	PARTICIPANT	\N	PRESENT	0
65978	65361	14073Q	PARTICIPANT	\N	PRESENT	0
65979	65361	14179A	PARTICIPANT	\N	PRESENT	0
65980	65361	14089Y	PARTICIPANT	\N	PRESENT	0
65981	65361	14059S	PARTICIPANT	\N	PRESENT	0
65982	65361	14061L	PARTICIPANT	\N	PRESENT	0
65983	65361	08034U	PARTICIPANT	\N	PRESENT	0
65984	65361	92045V	PARTICIPANT	\N	PRESENT	0
65985	65361	14031R	PARTICIPANT	\N	PRESENT	0
65986	65361	04057K	PARTICIPANT	\N	PRESENT	0
65987	65361	11091R	PARTICIPANT	\N	PRESENT	0
65988	65361	11048N	PARTICIPANT	\N	PRESENT	0
65989	65361	08039A	PARTICIPANT	\N	PRESENT	0
65990	65361	01025N	PARTICIPANT	\N	PRESENT	0
65991	65361	04070G	PARTICIPANT	\N	PRESENT	0
65992	65361	14103D	PARTICIPANT	\N	PRESENT	0
65993	65361	14033T	PARTICIPANT	\N	PRESENT	0
65994	65361	14331P	PARTICIPANT	\N	PRESENT	0
65995	65361	11036J	PARTICIPANT	\N	PRESENT	0
65996	65361	04088S	PARTICIPANT	\N	PRESENT	0
65997	65361	14217N	PARTICIPANT	\N	PRESENT	0
65998	65361	11061K	PARTICIPANT	\N	PRESENT	0
65999	65361	08031R	PARTICIPANT	\N	PRESENT	0
66000	65361	14261S	PARTICIPANT	\N	PRESENT	0
66001	65361	14265W	PARTICIPANT	\N	PRESENT	0
66002	65361	11112D	PARTICIPANT	\N	PRESENT	0
66003	65361	01008M	PARTICIPANT	\N	PRESENT	0
66004	65361	14219Q	PARTICIPANT	\N	PRESENT	0
66005	65361	14121F	PARTICIPANT	\N	PRESENT	0
66006	65361	11042G	PARTICIPANT	\N	PRESENT	0
66007	65361	08024S	PARTICIPANT	\N	PRESENT	0
66008	65361	04033B	PARTICIPANT	\N	PRESENT	0
66009	65361	14083S	PARTICIPANT	\N	PRESENT	0
66337	66335	11027H	PARTICIPANT	\N	PRESENT	0
66339	66335	86044G	PARTICIPANT	\N	PRESENT	0
66595	66594	98046X	PARTICIPANT	\N	PRESENT	0
66608	66604	04034C	PARTICIPANT	\N	PRESENT	0
68658	66882	08055A	PARTICIPANT	\N	PRESENT	0
68704	66882	14030Q	PARTICIPANT	\N	PRESENT	0
68705	66882	14173T	PARTICIPANT	\N	PRESENT	0
68706	66882	14026U	PARTICIPANT	\N	PRESENT	0
68707	66882	14063N	PARTICIPANT	\N	PRESENT	0
68708	66882	11034G	PARTICIPANT	\N	PRESENT	0
68709	66882	14085U	PARTICIPANT	\N	PRESENT	0
68710	66882	14018U	PARTICIPANT	\N	PRESENT	0
68711	66882	11095V	PARTICIPANT	\N	PRESENT	0
68712	66882	04092N	PARTICIPANT	\N	PRESENT	0
68713	66882	08028W	PARTICIPANT	\N	PRESENT	0
68714	66882	98042T	PARTICIPANT	\N	PRESENT	0
68715	66882	14089Y	PARTICIPANT	\N	PRESENT	0
68716	66882	04097T	PARTICIPANT	\N	PRESENT	0
68717	66882	01022K	PARTICIPANT	\N	PRESENT	0
68718	66882	14028W	PARTICIPANT	\N	PRESENT	0
68719	66882	14103D	PARTICIPANT	\N	PRESENT	0
68720	66882	08012N	PARTICIPANT	\N	PRESENT	0
68721	66882	14109K	PARTICIPANT	\N	PRESENT	0
68722	66882	11097X	PARTICIPANT	\N	PRESENT	0
68723	66882	01025N	PARTICIPANT	\N	PRESENT	0
68724	66882	14038Y	PARTICIPANT	\N	PRESENT	0
68725	66882	08051V	PARTICIPANT	\N	PRESENT	0
68726	66882	80013X	PARTICIPANT	\N	PRESENT	0
68727	66882	14263U	PARTICIPANT	\N	PRESENT	0
68728	66882	14273W	PARTICIPANT	\N	PRESENT	0
68729	66882	14271U	PARTICIPANT	\N	PRESENT	0
68730	66882	11111C	PARTICIPANT	\N	PRESENT	0
68731	66882	14331P	PARTICIPANT	\N	PRESENT	0
68732	66882	14327T	PARTICIPANT	\N	PRESENT	0
68733	66882	08041T	PARTICIPANT	\N	PRESENT	0
68734	66882	14231L	PARTICIPANT	\N	PRESENT	0
68735	66882	01015L	PARTICIPANT	\N	PRESENT	0
68736	66882	01013J	PARTICIPANT	\N	PRESENT	0
68737	66882	11067R	PARTICIPANT	\N	PRESENT	0
68738	66882	14069U	PARTICIPANT	\N	PRESENT	0
68739	66882	11082Q	PARTICIPANT	\N	PRESENT	0
68740	66882	11074Q	PARTICIPANT	\N	PRESENT	0
68741	66882	14247U	PARTICIPANT	\N	PRESENT	0
68742	66882	11014C	PARTICIPANT	\N	PRESENT	0
68743	66882	01031L	PARTICIPANT	\N	PRESENT	0
68744	66882	92015P	PARTICIPANT	\N	PRESENT	0
68745	66882	08048B	PARTICIPANT	\N	PRESENT	0
68746	66882	11091R	PARTICIPANT	\N	PRESENT	0
68747	66882	14227Q	PARTICIPANT	\N	PRESENT	0
68748	66882	11042G	PARTICIPANT	\N	PRESENT	0
68749	66882	08022Q	PARTICIPANT	\N	PRESENT	0
68750	66882	89017R	PARTICIPANT	\N	PRESENT	0
68751	66882	14037X	PARTICIPANT	\N	PRESENT	0
68752	66882	14121F	PARTICIPANT	\N	PRESENT	0
68753	66882	11099A	PARTICIPANT	\N	PRESENT	0
68754	66882	08031R	PARTICIPANT	\N	PRESENT	0
68755	66882	11040E	PARTICIPANT	\N	PRESENT	0
68756	66882	13002U	PARTICIPANT	\N	PRESENT	0
68757	66882	14031R	PARTICIPANT	\N	PRESENT	0
68758	66882	08015R	PARTICIPANT	\N	PRESENT	0
68759	66882	11112D	PARTICIPANT	\N	PRESENT	0
68760	66882	07032N	PARTICIPANT	\N	PRESENT	0
68761	66882	14235Q	PARTICIPANT	\N	PRESENT	0
68762	66882	14041T	PARTICIPANT	\N	PRESENT	0
68763	66882	05008E	PARTICIPANT	\N	PRESENT	0
68764	66882	08010L	PARTICIPANT	\N	PRESENT	0
68765	66882	97011G	PARTICIPANT	\N	PRESENT	0
68766	66882	99004R	PARTICIPANT	\N	PRESENT	0
72093	72092	08018U	PARTICIPANT	\N	PRESENT	0
72095	72094	08018U	PARTICIPANT	\N	PRESENT	0
75017	72861	14271U	PARTICIPANT	\N	PRESENT	0
75018	72861	14199E	PARTICIPANT	\N	PRESENT	0
75019	72861	95049N	PARTICIPANT	\N	PRESENT	0
75020	72861	11044J	PARTICIPANT	\N	PRESENT	0
75021	72861	08034U	PARTICIPANT	\N	PRESENT	0
75031	72861	04043D	PARTICIPANT	\N	PRESENT	0
75032	72861	08016S	PARTICIPANT	\N	PRESENT	0
75033	72861	11093T	PARTICIPANT	\N	PRESENT	0
75034	72861	86044G	PARTICIPANT	\N	PRESENT	0
75035	72861	86034E	PARTICIPANT	\N	PRESENT	0
75036	72861	14039A	PARTICIPANT	\N	PRESENT	0
75037	72861	08051V	PARTICIPANT	\N	PRESENT	0
75038	72861	11012A	PARTICIPANT	\N	PRESENT	0
75041	72861	04036E	PARTICIPANT	\N	PRESENT	0
75042	72861	01047U	PARTICIPANT	\N	PRESENT	0
75043	72861	04053F	PARTICIPANT	\N	PRESENT	0
75044	72861	14037X	PARTICIPANT	\N	PRESENT	0
75045	72861	08055A	PARTICIPANT	\N	PRESENT	0
75046	72861	95059Q	PARTICIPANT	\N	PRESENT	0
75047	72861	14018U	PARTICIPANT	\N	PRESENT	0
75048	72861	01046T	PARTICIPANT	\N	PRESENT	0
75051	72861	14255U	PARTICIPANT	\N	PRESENT	0
75052	72861	11089X	PARTICIPANT	\N	PRESENT	0
75053	72861	11082Q	PARTICIPANT	\N	PRESENT	0
75054	72861	11076S	PARTICIPANT	\N	PRESENT	0
75055	72861	14073Q	PARTICIPANT	\N	PRESENT	0
75056	72861	11107G	PARTICIPANT	\N	PRESENT	0
75057	72861	11084S	PARTICIPANT	\N	PRESENT	0
75058	72861	04056J	PARTICIPANT	\N	PRESENT	0
75059	72861	11053K	PARTICIPANT	\N	PRESENT	0
75060	72861	99004R	PARTICIPANT	\N	PRESENT	0
75061	72861	14093U	PARTICIPANT	\N	PRESENT	0
77158	75209	04081K	PARTICIPANT	\N	PRESENT	0
77160	75209	11099A	PARTICIPANT	\N	PRESENT	0
77161	75209	14030Q	PARTICIPANT	\N	PRESENT	0
77159	75209	14033T	PARTICIPANT	\N	PRESENT	0
77162	75209	98022P	PARTICIPANT	\N	PRESENT	0
77163	75209	11036J	PARTICIPANT	\N	PRESENT	0
77164	75209	11066Q	PARTICIPANT	\N	PRESENT	0
77165	75209	14042U	PARTICIPANT	\N	PRESENT	0
77166	75209	04089T	PARTICIPANT	\N	PRESENT	0
77167	75209	14237S	PARTICIPANT	\N	PRESENT	0
77168	75209	14249W	PARTICIPANT	\N	PRESENT	0
77169	75209	01008M	PARTICIPANT	\N	PRESENT	0
77170	75209	11098Y	PARTICIPANT	\N	PRESENT	0
77171	75209	14235Q	PARTICIPANT	\N	PRESENT	0
77172	75209	04067M	PARTICIPANT	\N	PRESENT	0
77173	75209	14205J	PARTICIPANT	\N	PRESENT	0
77174	75209	14157T	PARTICIPANT	\N	PRESENT	0
77175	75209	11061K	PARTICIPANT	\N	PRESENT	0
77176	75209	14073Q	PARTICIPANT	\N	PRESENT	0
77177	75209	11100Y	PARTICIPANT	\N	PRESENT	0
77178	75209	14265W	PARTICIPANT	\N	PRESENT	0
77179	75209	14041T	PARTICIPANT	\N	PRESENT	0
77180	75209	08047A	PARTICIPANT	\N	PRESENT	0
77181	75209	08034U	PARTICIPANT	\N	PRESENT	0
77182	75209	14031R	PARTICIPANT	\N	PRESENT	0
77183	75209	14169X	PARTICIPANT	\N	PRESENT	0
77184	75209	11103C	PARTICIPANT	\N	PRESENT	0
77034	76858	04081K	PARTICIPANT	\N	PRESENT	0
77035	76858	08060W	PARTICIPANT	\N	PRESENT	0
77036	76858	11106F	PARTICIPANT	\N	PRESENT	0
77037	76858	98022P	PARTICIPANT	\N	PRESENT	0
77038	76858	14247U	PARTICIPANT	\N	PRESENT	0
77039	76858	11088W	PARTICIPANT	\N	PRESENT	0
77040	76858	04071H	PARTICIPANT	\N	PRESENT	0
77041	76858	08069G	PARTICIPANT	\N	PRESENT	0
77042	76858	14265W	PARTICIPANT	\N	PRESENT	0
77043	76858	04053F	PARTICIPANT	\N	PRESENT	0
77044	76858	92015P	PARTICIPANT	\N	PRESENT	0
77045	76858	01027Q	PARTICIPANT	\N	PRESENT	0
77046	76858	14083S	PARTICIPANT	\N	PRESENT	0
77047	76858	13002U	PARTICIPANT	\N	PRESENT	0
77048	76858	11025F	PARTICIPANT	\N	PRESENT	0
77049	76858	11103C	PARTICIPANT	\N	PRESENT	0
77050	76858	14249W	PARTICIPANT	\N	PRESENT	0
77051	76858	08068F	PARTICIPANT	\N	PRESENT	0
77052	76858	11076S	PARTICIPANT	\N	PRESENT	0
77053	76858	08058D	PARTICIPANT	\N	PRESENT	0
77054	76858	11080N	PARTICIPANT	\N	PRESENT	0
77055	76858	01028R	PARTICIPANT	\N	PRESENT	0
77056	76858	99004R	PARTICIPANT	\N	PRESENT	0
77185	75209	97011G	PARTICIPANT	\N	PRESENT	0
77186	75209	14059S	PARTICIPANT	\N	PRESENT	0
77057	76858	95030B	PARTICIPANT	\N	PRESENT	0
77058	76858	08047A	PARTICIPANT	\N	PRESENT	0
77059	76858	04086Q	PARTICIPANT	\N	PRESENT	0
77060	76858	04047H	PARTICIPANT	\N	PRESENT	0
77061	76858	08056B	PARTICIPANT	\N	PRESENT	0
77062	76858	05008E	PARTICIPANT	\N	PRESENT	0
77063	76858	14097Y	PARTICIPANT	\N	PRESENT	0
77064	76858	11056N	PARTICIPANT	\N	PRESENT	0
77065	76858	14042U	PARTICIPANT	\N	PRESENT	0
77066	76858	14267Y	PARTICIPANT	\N	PRESENT	0
77067	76858	01043Q	PARTICIPANT	\N	PRESENT	0
77068	76858	14038Y	PARTICIPANT	\N	PRESENT	0
77069	76858	14069U	PARTICIPANT	\N	PRESENT	0
77070	76858	97011G	PARTICIPANT	\N	PRESENT	0
77071	76858	14103D	PARTICIPANT	\N	PRESENT	0
77072	76858	14033T	PARTICIPANT	\N	PRESENT	0
77074	76858	11059R	PARTICIPANT	\N	PRESENT	0
77075	76858	11091R	PARTICIPANT	\N	PRESENT	0
77076	76858	04088S	PARTICIPANT	\N	PRESENT	0
77077	76858	11042G	PARTICIPANT	\N	PRESENT	0
77078	76858	14207L	PARTICIPANT	\N	PRESENT	0
77079	76858	08061X	PARTICIPANT	\N	PRESENT	0
77080	76858	14111D	PARTICIPANT	\N	PRESENT	0
77081	76858	14273W	PARTICIPANT	\N	PRESENT	0
77082	76858	11110B	PARTICIPANT	\N	PRESENT	0
77083	76858	14135M	PARTICIPANT	\N	PRESENT	0
77084	76858	14187A	PARTICIPANT	\N	PRESENT	0
77085	76858	04067M	PARTICIPANT	\N	PRESENT	0
77086	76858	01003G	PARTICIPANT	\N	PRESENT	0
77087	76858	08015R	PARTICIPANT	\N	PRESENT	0
77089	76858	80027E	PARTICIPANT	\N	PRESENT	0
77090	76858	11036J	PARTICIPANT	\N	PRESENT	0
77091	76858	14197C	PARTICIPANT	\N	PRESENT	0
77092	76858	14071N	PARTICIPANT	\N	PRESENT	0
77093	76858	01025N	PARTICIPANT	\N	PRESENT	0
77094	76858	14219Q	PARTICIPANT	\N	PRESENT	0
77098	76858	11061K	PARTICIPANT	\N	PRESENT	0
77099	76858	14235Q	PARTICIPANT	\N	PRESENT	0
77100	76858	14105F	PARTICIPANT	\N	PRESENT	0
77101	76858	01014K	PARTICIPANT	\N	PRESENT	0
77102	76858	14031R	PARTICIPANT	\N	PRESENT	0
77103	76858	14205J	PARTICIPANT	\N	PRESENT	0
77104	76858	01008M	PARTICIPANT	\N	PRESENT	0
77105	76858	14199E	PARTICIPANT	\N	PRESENT	0
77106	76858	14123H	PARTICIPANT	\N	PRESENT	0
77107	76858	92039X	PARTICIPANT	\N	PRESENT	0
77108	76858	11098Y	PARTICIPANT	\N	PRESENT	0
77109	76858	04089T	PARTICIPANT	\N	PRESENT	0
77110	76858	11093T	PARTICIPANT	\N	PRESENT	0
77111	76858	14121F	PARTICIPANT	\N	PRESENT	0
77112	76858	08014Q	PARTICIPANT	\N	PRESENT	0
77113	76858	95035G	PARTICIPANT	\N	PRESENT	0
77114	76858	07029T	PARTICIPANT	\N	PRESENT	0
77115	76858	11111C	PARTICIPANT	\N	PRESENT	0
77116	76858	14147R	PARTICIPANT	\N	PRESENT	0
77117	76858	14157T	PARTICIPANT	\N	PRESENT	0
77118	76858	01048V	PARTICIPANT	\N	PRESENT	0
77119	76858	01019Q	PARTICIPANT	\N	PRESENT	0
77120	76858	14169X	PARTICIPANT	\N	PRESENT	0
77187	75209	14327T	PARTICIPANT	\N	PRESENT	0
77188	75209	04088S	PARTICIPANT	\N	PRESENT	0
77189	75209	95030B	PARTICIPANT	\N	PRESENT	0
77190	75209	14195A	PARTICIPANT	\N	PRESENT	0
77191	75209	11091R	PARTICIPANT	\N	PRESENT	0
77192	75209	14089Y	PARTICIPANT	\N	PRESENT	0
77193	75209	11111C	PARTICIPANT	\N	PRESENT	0
77194	75209	92039X	PARTICIPANT	\N	PRESENT	0
77195	75209	11067R	PARTICIPANT	\N	PRESENT	0
77196	75209	08016S	PARTICIPANT	\N	PRESENT	0
77197	75209	08014Q	PARTICIPANT	\N	PRESENT	0
77198	75209	80013X	PARTICIPANT	\N	PRESENT	0
77199	75209	01022K	PARTICIPANT	\N	PRESENT	0
77201	75209	08051V	PARTICIPANT	\N	PRESENT	0
77203	75209	14331P	PARTICIPANT	\N	PRESENT	0
77204	75209	14135M	PARTICIPANT	\N	PRESENT	0
77205	75209	14121F	PARTICIPANT	\N	PRESENT	0
77206	75209	92045V	PARTICIPANT	\N	PRESENT	0
77207	75209	11048N	PARTICIPANT	\N	PRESENT	0
77208	75209	08010L	PARTICIPANT	\N	PRESENT	0
75015	72861	08025T	PARTICIPANT	\N	PRESENT	0
75016	72861	14331P	PARTICIPANT	\N	PRESENT	0
77209	75209	11097X	PARTICIPANT	\N	PRESENT	0
62765	61421	01025N	PARTICIPANT	\N	PRESENT	0
62766	61421	08043V	PARTICIPANT	\N	PRESENT	0
62767	61421	04056J	PARTICIPANT	\N	PRESENT	0
62768	61421	14235Q	PARTICIPANT	\N	PRESENT	0
62769	61421	07026Q	PARTICIPANT	\N	PRESENT	0
62770	61421	11029K	PARTICIPANT	\N	PRESENT	0
62771	61421	14030Q	PARTICIPANT	\N	PRESENT	0
62772	61421	04057K	PARTICIPANT	\N	PRESENT	0
62773	61421	08031R	PARTICIPANT	\N	PRESENT	0
62774	61421	01044R	PARTICIPANT	\N	PRESENT	0
62775	61421	11043H	PARTICIPANT	\N	PRESENT	0
62776	61421	14169X	PARTICIPANT	\N	PRESENT	0
62777	61421	14038Y	PARTICIPANT	\N	PRESENT	0
62778	61421	04059M	PARTICIPANT	\N	PRESENT	0
62779	61421	14105F	PARTICIPANT	\N	PRESENT	0
62780	61421	12041X	PARTICIPANT	\N	PRESENT	0
62781	61421	14229S	PARTICIPANT	\N	PRESENT	0
62782	61421	14089Y	PARTICIPANT	\N	PRESENT	0
62783	61421	04033B	PARTICIPANT	\N	PRESENT	0
62784	61421	14187A	PARTICIPANT	\N	PRESENT	0
62785	61421	14073Q	PARTICIPANT	\N	PRESENT	0
62786	61421	14241N	PARTICIPANT	\N	PRESENT	0
62787	61421	08069G	PARTICIPANT	\N	PRESENT	0
62788	61421	14059S	PARTICIPANT	\N	PRESENT	0
62789	61421	01046T	PARTICIPANT	\N	PRESENT	0
62790	61421	04088S	PARTICIPANT	\N	PRESENT	0
62791	61421	11104D	PARTICIPANT	\N	PRESENT	0
62792	61421	08039A	PARTICIPANT	\N	PRESENT	0
62793	61421	14265W	PARTICIPANT	\N	PRESENT	0
62794	61421	14109K	PARTICIPANT	\N	PRESENT	0
62795	61421	92045V	PARTICIPANT	\N	PRESENT	0
62796	61421	14111D	PARTICIPANT	\N	PRESENT	0
62797	61421	11089X	PARTICIPANT	\N	PRESENT	0
62798	61421	14213J	PARTICIPANT	\N	PRESENT	0
62799	61421	14135M	PARTICIPANT	\N	PRESENT	0
62800	61421	01034P	PARTICIPANT	\N	PRESENT	0
62801	61421	08051V	PARTICIPANT	\N	PRESENT	0
62802	61421	11066Q	PARTICIPANT	\N	PRESENT	0
62803	61421	10006L	PARTICIPANT	\N	PRESENT	0
62804	61421	14249W	PARTICIPANT	\N	PRESENT	0
62805	61421	14042U	PARTICIPANT	\N	PRESENT	0
62806	61421	14231L	PARTICIPANT	\N	PRESENT	0
62763	61421	08024S	PARTICIPANT	\N	PRESENT	0
62764	61421	04070G	PARTICIPANT	\N	PRESENT	0
62807	61421	14083S	PARTICIPANT	\N	PRESENT	0
62808	61421	92031P	PARTICIPANT	\N	PRESENT	0
62809	61421	10015M	PARTICIPANT	\N	PRESENT	0
62810	61421	04049K	PARTICIPANT	\N	PRESENT	0
62811	61421	01027Q	PARTICIPANT	\N	PRESENT	0
62812	61421	14093U	PARTICIPANT	\N	PRESENT	0
62813	61421	01008M	PARTICIPANT	\N	PRESENT	0
62814	61421	08061X	PARTICIPANT	\N	PRESENT	0
62815	61421	14119M	PARTICIPANT	\N	PRESENT	0
62816	61421	14033T	PARTICIPANT	\N	PRESENT	0
62817	61421	01028R	PARTICIPANT	\N	PRESENT	0
62818	61421	14034U	PARTICIPANT	\N	PRESENT	0
62819	61421	14179A	PARTICIPANT	\N	PRESENT	0
62820	61421	14123H	PARTICIPANT	\N	PRESENT	0
66087	65354	11036J	PARTICIPANT	\N	PRESENT	0
66088	65354	04034C	PARTICIPANT	\N	PRESENT	0
66089	65354	11083R	PARTICIPANT	\N	PRESENT	0
66090	65354	14103D	PARTICIPANT	\N	PRESENT	0
66091	65354	14073Q	PARTICIPANT	\N	PRESENT	0
66092	65354	01027Q	PARTICIPANT	\N	PRESENT	0
66093	65354	01031L	PARTICIPANT	\N	PRESENT	0
66094	65354	08069G	PARTICIPANT	\N	PRESENT	0
66095	65354	11012A	PARTICIPANT	\N	PRESENT	0
66096	65354	01003G	PARTICIPANT	\N	PRESENT	0
66097	65354	14261S	PARTICIPANT	\N	PRESENT	0
66098	65354	14041T	PARTICIPANT	\N	PRESENT	0
66099	65354	07029T	PARTICIPANT	\N	PRESENT	0
66100	65354	14033T	PARTICIPANT	\N	PRESENT	0
66101	65354	14263U	PARTICIPANT	\N	PRESENT	0
66102	65354	14175V	PARTICIPANT	\N	PRESENT	0
66103	65354	11103C	PARTICIPANT	\N	PRESENT	0
66104	65354	98046X	PARTICIPANT	\N	PRESENT	0
66105	65354	11066Q	PARTICIPANT	\N	PRESENT	0
66106	65354	08016S	PARTICIPANT	\N	PRESENT	0
66107	65354	11025F	PARTICIPANT	\N	PRESENT	0
66108	65354	07004J	PARTICIPANT	\N	PRESENT	0
66109	65354	01008M	PARTICIPANT	\N	PRESENT	0
66110	65354	14219Q	PARTICIPANT	\N	PRESENT	0
66111	65354	14207L	PARTICIPANT	\N	PRESENT	0
66112	65354	14331P	PARTICIPANT	\N	PRESENT	0
66113	65354	14197C	PARTICIPANT	\N	PRESENT	0
66114	65354	11091R	PARTICIPANT	\N	PRESENT	0
66115	65354	04088S	PARTICIPANT	\N	PRESENT	0
66120	65354	08073C	PARTICIPANT	\N	PRESENT	0
66121	65354	11054L	PARTICIPANT	\N	PRESENT	0
66122	65355	08024S	PARTICIPANT	\N	PRESENT	0
66123	65355	11040E	PARTICIPANT	\N	PRESENT	0
66124	65355	11036J	PARTICIPANT	\N	PRESENT	0
66125	65355	04034C	PARTICIPANT	\N	PRESENT	0
66126	65355	11083R	PARTICIPANT	\N	PRESENT	0
66127	65355	14103D	PARTICIPANT	\N	PRESENT	0
66128	65355	14073Q	PARTICIPANT	\N	PRESENT	0
66129	65355	01027Q	PARTICIPANT	\N	PRESENT	0
66130	65355	01031L	PARTICIPANT	\N	PRESENT	0
66131	65355	08069G	PARTICIPANT	\N	PRESENT	0
66069	65354	08024S	PARTICIPANT	\N	PRESENT	0
66086	65354	11040E	PARTICIPANT	\N	PRESENT	0
66159	65355	01022K	PARTICIPANT	\N	PRESENT	0
66133	65355	01003G	PARTICIPANT	\N	PRESENT	0
66134	65355	14261S	PARTICIPANT	\N	PRESENT	0
66135	65355	14041T	PARTICIPANT	\N	PRESENT	0
66136	65355	07029T	PARTICIPANT	\N	PRESENT	0
66158	65355	97011G	PARTICIPANT	\N	PRESENT	0
66138	65355	14263U	PARTICIPANT	\N	PRESENT	0
66139	65355	14175V	PARTICIPANT	\N	PRESENT	0
66140	65355	11103C	PARTICIPANT	\N	PRESENT	0
66141	65355	98046X	PARTICIPANT	\N	PRESENT	0
66142	65355	11066Q	PARTICIPANT	\N	PRESENT	0
66161	65355	95062K	PARTICIPANT	\N	PRESENT	0
66144	65355	11025F	PARTICIPANT	\N	PRESENT	0
66145	65355	07004J	PARTICIPANT	\N	PRESENT	0
66146	65355	01008M	PARTICIPANT	\N	PRESENT	0
66147	65355	14219Q	PARTICIPANT	\N	PRESENT	0
66148	65355	14207L	PARTICIPANT	\N	PRESENT	0
66149	65355	14331P	PARTICIPANT	\N	PRESENT	0
66160	65355	01048V	PARTICIPANT	\N	PRESENT	0
66157	65355	14157T	PARTICIPANT	\N	PRESENT	0
66197	65355	14247U	PARTICIPANT	\N	PRESENT	0
66153	65355	08073C	PARTICIPANT	\N	PRESENT	0
66154	65355	11054L	PARTICIPANT	\N	PRESENT	0
66155	65355	14030Q	PARTICIPANT	\N	PRESENT	0
66156	65355	14083S	PARTICIPANT	\N	PRESENT	0
66208	65355	80013X	PARTICIPANT	\N	PRESENT	0
66209	65355	14119M	PARTICIPANT	\N	PRESENT	0
66266	65356	01028R	PARTICIPANT	\N	PRESENT	0
66267	65356	14269B	PARTICIPANT	\N	PRESENT	0
66268	65356	05008E	PARTICIPANT	\N	PRESENT	0
66269	65356	11030C	PARTICIPANT	\N	PRESENT	0
66270	65356	07026Q	PARTICIPANT	\N	PRESENT	0
66271	65356	08025T	PARTICIPANT	\N	PRESENT	0
66272	65356	11029K	PARTICIPANT	\N	PRESENT	0
66273	65356	04038G	PARTICIPANT	\N	PRESENT	0
66274	65356	14041T	PARTICIPANT	\N	PRESENT	0
66275	65356	07029T	PARTICIPANT	\N	PRESENT	0
66276	65356	11103C	PARTICIPANT	\N	PRESENT	0
66277	65356	14263U	PARTICIPANT	\N	PRESENT	0
66278	65356	04085P	PARTICIPANT	\N	PRESENT	0
66279	65356	14038Y	PARTICIPANT	\N	PRESENT	0
66280	65356	14331P	PARTICIPANT	\N	PRESENT	0
66281	65356	01041N	PARTICIPANT	\N	PRESENT	0
66282	65356	04070G	PARTICIPANT	\N	PRESENT	0
66283	65356	14083S	PARTICIPANT	\N	PRESENT	0
66284	65356	98018T	PARTICIPANT	\N	PRESENT	0
66285	65356	04045F	PARTICIPANT	\N	PRESENT	0
66286	65356	14159V	PARTICIPANT	\N	PRESENT	0
66287	65356	11036J	PARTICIPANT	\N	PRESENT	0
66288	65356	14247U	PARTICIPANT	\N	PRESENT	0
66292	65356	14219Q	PARTICIPANT	\N	PRESENT	0
66295	65356	04053F	PARTICIPANT	\N	PRESENT	0
66296	65356	04074L	PARTICIPANT	\N	PRESENT	0
66297	65356	11027H	PARTICIPANT	\N	PRESENT	0
66298	65356	04035D	PARTICIPANT	\N	PRESENT	0
66299	65356	07004J	PARTICIPANT	\N	PRESENT	0
66300	65356	08051V	PARTICIPANT	\N	PRESENT	0
66301	65356	11091R	PARTICIPANT	\N	PRESENT	0
66302	65356	01031L	PARTICIPANT	\N	PRESENT	0
66303	65356	99004R	PARTICIPANT	\N	PRESENT	0
66306	65356	11063M	PARTICIPANT	\N	PRESENT	0
66313	65356	14121F	PARTICIPANT	\N	PRESENT	0
66314	65356	01024M	PARTICIPANT	\N	PRESENT	0
66315	65356	04036E	PARTICIPANT	\N	PRESENT	0
66247	65356	04081K	PARTICIPANT	\N	PRESENT	0
66265	65356	11039M	PARTICIPANT	\N	PRESENT	0
66316	65356	14018U	PARTICIPANT	\N	PRESENT	0
75193	75192	14173T	PARTICIPANT	\N	PRESENT	0
75195	75194	04071H	PARTICIPANT	\N	PRESENT	0
75197	75196	14173T	PARTICIPANT	\N	PRESENT	0
75199	75198	04071H	PARTICIPANT	\N	PRESENT	0
75201	75200	08011M	PARTICIPANT	\N	PRESENT	0
75203	75202	08011M	PARTICIPANT	\N	PRESENT	0
75205	75204	04071H	PARTICIPANT	\N	PRESENT	0
80389	77795	11023D	PARTICIPANT	\N	EXCUSE	0
82743	82742	08025T	PARTICIPANT	\N	PRESENT	0
82744	82742	05008E	PRESIDENT	0	PRESENT	0
82745	82742	11056N	PARTICIPANT	\N	PRESENT	0
82746	82742	14041T	PARTICIPANT	\N	PRESENT	0
82747	82742	01024M	PARTICIPANT	\N	EXCUSE	0
82748	82742	14215L	PARTICIPANT	\N	PRESENT	0
82749	82742	08018U	PARTICIPANT	\N	PRESENT	0
82750	82742	04079R	PARTICIPANT	\N	PRESENT	0
82751	82742	14001X	PARTICIPANT	\N	PRESENT	0
82752	82742	14273W	PARTICIPANT	\N	PRESENT	0
82753	82742	01060R	PARTICIPANT	\N	PRESENT	0
82754	82742	14147R	PARTICIPANT	\N	PRESENT	0
82755	82742	11072N	PARTICIPANT	\N	PRESENT	0
82756	82742	10015M	PARTICIPANT	\N	PRESENT	0
82757	82742	95063L	PARTICIPANT	\N	PRESENT	0
82764	82742	04057K	PARTICIPANT	\N	PRESENT	0
82759	82742	01028R	PARTICIPANT	\N	PRESENT	0
82760	82742	98035U	PARTICIPANT	\N	PRESENT	0
82761	82742	04056J	PARTICIPANT	\N	PRESENT	0
82762	82742	04044E	PARTICIPANT	\N	PRESENT	0
82763	82742	11037K	PARTICIPANT	\N	PRESENT	0
82765	82742	14038Y	PARTICIPANT	\N	PRESENT	0
82766	82742	04086Q	PARTICIPANT	\N	PRESENT	0
82767	82742	01058X	PARTICIPANT	\N	PRESENT	0
82834	82830	08025T	PARTICIPANT	\N	PRESENT	0
82836	82830	04085P	PARTICIPANT	\N	PRESENT	0
82838	82830	05008E	PRESIDENT	0	PRESENT	0
82839	82830	14069U	PARTICIPANT	\N	PRESENT	0
82841	82830	11032E	PARTICIPANT	\N	PRESENT	0
82843	82830	99002P	PARTICIPANT	\N	PRESENT	0
82844	82830	11056N	PARTICIPANT	\N	PRESENT	0
82845	82830	14259Y	PARTICIPANT	\N	PRESENT	0
82847	82830	14041T	PARTICIPANT	\N	PRESENT	0
82859	82830	14215L	PARTICIPANT	\N	PRESENT	0
82860	82830	11034G	PARTICIPANT	\N	PRESENT	0
82861	82830	08018U	PARTICIPANT	\N	PRESENT	0
82862	82830	01007L	PARTICIPANT	\N	PRESENT	0
82863	82830	11026G	PARTICIPANT	\N	PRESENT	0
82864	82830	04079R	PARTICIPANT	\N	PRESENT	0
82866	82830	14111D	PARTICIPANT	\N	PRESENT	0
82867	82830	14001X	PARTICIPANT	\N	PRESENT	0
82868	82830	14273W	PARTICIPANT	\N	PRESENT	0
82869	82830	01060R	PARTICIPANT	\N	PRESENT	0
82870	82830	95049N	PARTICIPANT	\N	PRESENT	0
82871	82830	14147R	PARTICIPANT	\N	PRESENT	0
82872	82830	08051V	PARTICIPANT	\N	PRESENT	0
82873	82830	11072N	PARTICIPANT	\N	PRESENT	0
82874	82830	07034Q	PARTICIPANT	\N	PRESENT	0
82875	82830	04074L	PARTICIPANT	\N	PRESENT	0
82876	82830	10015M	PARTICIPANT	\N	PRESENT	0
82877	82830	95063L	PARTICIPANT	\N	PRESENT	0
82878	82830	01019Q	PARTICIPANT	\N	PRESENT	0
82879	82830	01028R	PARTICIPANT	\N	PRESENT	0
82880	82830	98035U	PARTICIPANT	\N	PRESENT	0
82881	82830	04056J	PARTICIPANT	\N	PRESENT	0
82882	82830	04044E	PRESIDENT	1	PRESENT	0
82883	82830	11037K	PARTICIPANT	\N	PRESENT	0
82884	82830	95067Q	PARTICIPANT	\N	PRESENT	0
82885	82830	01047U	PARTICIPANT	\N	PRESENT	0
82886	82830	01024M	PARTICIPANT	\N	EXCUSE	0
82887	82830	04057K	PARTICIPANT	\N	PRESENT	0
82888	82830	14038Y	PARTICIPANT	\N	PRESENT	0
82889	82830	04086Q	PARTICIPANT	\N	PRESENT	0
82890	82830	01058X	PARTICIPANT	\N	PRESENT	0
82913	82830	08044W	PARTICIPANT	\N	PRESENT	0
82929	82830	11049P	PARTICIPANT	\N	PRESENT	0
83165	77795	14053L	PARTICIPANT	\N	EXCUSE	0
83175	83174	14133K	PARTICIPANT	\N	EXCUSE	0
83176	83174	04054G	PARTICIPANT	\N	PRESENT	0
83177	83174	96004D	PRESIDENT	0	PRESENT	0
83178	83174	90003B	PARTICIPANT	\N	PRESENT	0
83179	83174	11035H	PARTICIPANT	\N	EXCUSE	0
83180	83174	14097Y	PARTICIPANT	\N	PRESENT	0
83181	83174	14073Q	PARTICIPANT	\N	PRESENT	0
83182	83174	11026G	PARTICIPANT	\N	PRESENT	0
83183	83174	14001X	PARTICIPANT	\N	PRESENT	0
83184	83174	04057K	PARTICIPANT	\N	PRESENT	0
83185	83174	04080J	PARTICIPANT	\N	PRESENT	0
83186	83174	01016M	PARTICIPANT	\N	PRESENT	0
83187	83174	95063L	PARTICIPANT	\N	PRESENT	0
83188	83174	98035U	PARTICIPANT	\N	PRESENT	0
83189	83174	92045V	PARTICIPANT	\N	EXCUSE	0
83190	83174	04034C	PARTICIPANT	\N	PRESENT	0
83191	83174	04045F	PARTICIPANT	\N	PRESENT	0
83192	83174	04061F	PARTICIPANT	\N	EXCUSE	0
83424	83374	04080J	PARTICIPANT	\N	PRESENT	0
83376	83374	01031L	PRESIDENT	0	PRESENT	0
83425	83374	14135M	PARTICIPANT	\N	PRESENT	0
83426	83374	04045F	PARTICIPANT	\N	PRESENT	0
83427	83374	14001X	PARTICIPANT	\N	PRESENT	0
83380	83374	11040E	PARTICIPANT	\N	PRESENT	0
83428	83374	04057K	PARTICIPANT	\N	PRESENT	0
83429	83374	10015M	PARTICIPANT	\N	PRESENT	0
83430	83374	96004D	PARTICIPANT	\N	PRESENT	0
83384	83374	14083S	PARTICIPANT	\N	PRESENT	0
83431	83374	14097Y	PARTICIPANT	\N	PRESENT	0
83432	80071	14014Q	PARTICIPANT	\N	EXCUSE	0
83387	83374	11042G	PARTICIPANT	\N	PRESENT	0
83389	83374	04086Q	PARTICIPANT	\N	PRESENT	0
83721	80091	01044R	PARTICIPANT	\N	PRESENT	0
83724	80091	04043D	PARTICIPANT	\N	PRESENT	0
83727	80091	14257W	PARTICIPANT	\N	EXCUSE	0
83728	80091	11082Q	PARTICIPANT	\N	EXCUSE	0
83729	80091	14221J	PARTICIPANT	\N	EXCUSE	0
83730	80091	08039A	PARTICIPANT	\N	EXCUSE	0
83731	80091	04061F	PARTICIPANT	\N	EXCUSE	0
83399	83374	11083R	PARTICIPANT	\N	PRESENT	0
83732	80091	08069G	PARTICIPANT	\N	EXCUSE	0
83733	80091	11089X	PARTICIPANT	\N	EXCUSE	0
83734	80091	14263U	PARTICIPANT	\N	EXCUSE	0
83767	77795	11109J	PARTICIPANT	\N	PRESENT	0
83736	80091	11036J	PARTICIPANT	\N	EXCUSE	0
83737	80091	14209N	PARTICIPANT	\N	EXCUSE	0
83406	83374	04061F	PARTICIPANT	\N	PRESENT	0
83738	80091	80013X	PARTICIPANT	\N	EXCUSE	0
83408	83374	07029T	PARTICIPANT	\N	PRESENT	0
83739	80091	11061K	PARTICIPANT	\N	EXCUSE	0
83410	83374	08010L	PARTICIPANT	\N	EXCUSE	0
83411	83374	08034U	PARTICIPANT	\N	PRESENT	0
83412	83374	01048V	PARTICIPANT	\N	PRESENT	0
83413	83374	98046X	PARTICIPANT	\N	PRESENT	0
83740	80091	01058X	PARTICIPANT	\N	EXCUSE	0
83768	77795	14259Y	PARTICIPANT	\N	PRESENT	0
83769	77795	14097Y	PARTICIPANT	\N	PRESENT	0
83418	83374	01016M	PARTICIPANT	\N	PRESENT	0
83770	77795	14059S	PARTICIPANT	\N	PRESENT	0
83771	77795	08019V	PRESIDENT	0	PRESENT	0
83772	77795	11011M	PARTICIPANT	\N	PRESENT	0
83773	77795	11072N	PARTICIPANT	\N	PRESENT	0
83774	77795	98005N	PARTICIPANT	\N	PRESENT	0
83775	77795	08073C	PARTICIPANT	\N	PRESENT	0
84012	83922	11082Q	PARTICIPANT	\N	EXCUSE	0
85421	84158	08018U	PARTICIPANT	\N	PRESENT	0
85422	84158	14263U	PARTICIPANT	\N	PRESENT	0
85423	84158	80013X	PARTICIPANT	\N	PRESENT	0
85424	84158	11046L	PARTICIPANT	\N	PRESENT	0
85425	84158	11089X	PARTICIPANT	\N	PRESENT	0
85426	84158	11029K	PARTICIPANT	\N	PRESENT	0
85427	84158	97011G	PARTICIPANT	\N	PRESENT	0
85428	84158	05008E	PARTICIPANT	\N	PRESENT	0
85429	84158	01058X	PARTICIPANT	\N	PRESENT	0
85430	84158	11026G	PARTICIPANT	\N	PRESENT	0
85431	84158	96004D	PARTICIPANT	\N	PRESENT	0
85432	84158	04086Q	PARTICIPANT	\N	PRESENT	0
85433	84158	01024M	PARTICIPANT	\N	PRESENT	0
85434	84158	14105F	PARTICIPANT	\N	PRESENT	0
85435	84158	11105E	PARTICIPANT	\N	PRESENT	0
85436	84158	14038Y	PARTICIPANT	\N	PRESENT	0
85437	84158	14151M	PARTICIPANT	\N	PRESENT	0
85438	84158	11093T	PARTICIPANT	\N	PRESENT	0
85439	84158	04059M	PARTICIPANT	\N	PRESENT	0
85440	84158	08031R	PARTICIPANT	\N	PRESENT	0
85441	84158	11095V	PARTICIPANT	\N	PRESENT	0
85442	84158	14187A	PARTICIPANT	\N	PRESENT	0
85443	84158	04044E	PARTICIPANT	\N	PRESENT	0
85444	84158	14331P	PARTICIPANT	\N	PRESENT	0
85445	84158	14033T	PARTICIPANT	\N	PRESENT	0
66599	66598	14133K	PARTICIPANT	\N	PRESENT	0
66600	66598	14097Y	PARTICIPANT	\N	PRESENT	0
66602	66601	14133K	PARTICIPANT	\N	PRESENT	0
66603	66601	14097Y	PARTICIPANT	\N	PRESENT	0
68767	66882	01058X	PARTICIPANT	\N	PRESENT	0
68768	66882	11054L	PARTICIPANT	\N	PRESENT	0
68769	66882	11049P	PARTICIPANT	\N	PRESENT	0
68770	66882	11036J	PARTICIPANT	\N	PRESENT	0
68771	66882	14195A	PARTICIPANT	\N	PRESENT	0
68772	66882	95059Q	PARTICIPANT	\N	PRESENT	0
68773	66882	11104D	PARTICIPANT	\N	PRESENT	0
68774	66882	14105F	PARTICIPANT	\N	PRESENT	0
68775	66882	08060W	PARTICIPANT	\N	PRESENT	0
68776	66882	14281W	PARTICIPANT	\N	PRESENT	0
68777	66882	95015C	PARTICIPANT	\N	PRESENT	0
68778	66882	01044R	PARTICIPANT	\N	PRESENT	0
68779	66882	14042U	PARTICIPANT	\N	PRESENT	0
68780	66882	14219Q	PARTICIPANT	\N	PRESENT	0
68781	66882	14215L	PARTICIPANT	\N	PRESENT	0
68782	66882	14253S	PARTICIPANT	\N	PRESENT	0
68783	66882	07029T	PARTICIPANT	\N	PRESENT	0
68784	66882	01019Q	PARTICIPANT	\N	PRESENT	0
68785	66882	14083S	PARTICIPANT	\N	PRESENT	0
68786	66882	08043V	PARTICIPANT	\N	PRESENT	0
68787	66882	08053X	PARTICIPANT	\N	PRESENT	0
68788	66882	01037S	PARTICIPANT	\N	PRESENT	0
68789	66882	95030B	PARTICIPANT	\N	PRESENT	0
68790	66882	11039M	PARTICIPANT	\N	PRESENT	0
68791	66882	14197C	PARTICIPANT	\N	PRESENT	0
68792	66882	14225N	PARTICIPANT	\N	PRESENT	0
68793	66882	14147R	PARTICIPANT	\N	PRESENT	0
68794	66882	01057W	PARTICIPANT	\N	PRESENT	0
68795	66882	92031P	PARTICIPANT	\N	PRESENT	0
68796	66882	04085P	PARTICIPANT	\N	PRESENT	0
68797	66883	08055A	PARTICIPANT	\N	PRESENT	0
68883	66883	14219Q	PARTICIPANT	\N	PRESENT	0
68884	66883	11076S	PARTICIPANT	\N	PRESENT	0
68879	66883	11104D	PARTICIPANT	\N	PRESENT	0
68801	66883	11034G	PARTICIPANT	\N	PRESENT	0
68880	66883	11012A	PARTICIPANT	\N	PRESENT	0
68881	66883	14147R	PARTICIPANT	\N	PRESENT	0
68804	66883	11095V	PARTICIPANT	\N	PRESENT	0
68885	66883	95030B	PARTICIPANT	\N	PRESENT	0
68886	66883	95035G	PARTICIPANT	\N	PRESENT	0
68887	66883	01008M	PARTICIPANT	\N	PRESENT	0
68888	66883	11064N	PARTICIPANT	\N	PRESENT	0
68889	66883	14195A	PARTICIPANT	\N	PRESENT	0
68890	66883	08056B	PARTICIPANT	\N	PRESENT	0
68891	66883	11059R	PARTICIPANT	\N	PRESENT	0
68893	66883	14123H	PARTICIPANT	\N	PRESENT	0
68894	66883	11091R	PARTICIPANT	\N	PRESENT	0
68944	66883	14205J	PARTICIPANT	\N	PRESENT	0
68815	66883	14273W	PARTICIPANT	\N	PRESENT	0
68816	66883	14271U	PARTICIPANT	\N	PRESENT	0
68945	66883	14257W	PARTICIPANT	\N	PRESENT	0
68946	66883	01022K	PARTICIPANT	\N	PRESENT	0
68947	66883	14051J	PARTICIPANT	\N	PRESENT	0
68820	66883	01015L	PARTICIPANT	\N	PRESENT	0
68821	66883	01013J	PARTICIPANT	\N	PRESENT	0
68948	66883	11089X	PARTICIPANT	\N	PRESENT	0
68949	66883	14207L	PARTICIPANT	\N	PRESENT	0
68950	66883	01016M	PARTICIPANT	\N	PRESENT	0
68951	66883	14265W	PARTICIPANT	\N	PRESENT	0
68952	66883	01047U	PARTICIPANT	\N	PRESENT	0
68953	66883	04066L	PARTICIPANT	\N	PRESENT	0
68954	66883	92015P	PARTICIPANT	\N	PRESENT	0
68955	66883	01048V	PARTICIPANT	\N	PRESENT	0
68956	66883	11107G	PARTICIPANT	\N	PRESENT	0
68831	66883	11042G	PARTICIPANT	\N	PRESENT	0
68957	66883	04044E	PARTICIPANT	\N	PRESENT	0
68958	66883	08022Q	PARTICIPANT	\N	PRESENT	0
68959	66883	14071N	PARTICIPANT	\N	PRESENT	0
68835	66883	14121F	PARTICIPANT	\N	PRESENT	0
68960	66883	01003G	PARTICIPANT	\N	PRESENT	0
68837	66883	08031R	PARTICIPANT	\N	PRESENT	0
68838	66883	11040E	PARTICIPANT	\N	PRESENT	0
68961	66883	14042U	PARTICIPANT	\N	PRESENT	0
68962	66883	11014C	PARTICIPANT	\N	PRESENT	0
68963	66883	00003C	PARTICIPANT	\N	PRESENT	0
68842	66883	07032N	PARTICIPANT	\N	PRESENT	0
68843	66883	14235Q	PARTICIPANT	\N	PRESENT	0
69019	66884	04044E	PARTICIPANT	\N	PRESENT	0
69020	66884	11098Y	PARTICIPANT	\N	PRESENT	0
68846	66883	97011G	PARTICIPANT	\N	PRESENT	0
69021	66884	92015P	PARTICIPANT	\N	PRESENT	0
69022	66884	14051J	PARTICIPANT	\N	PRESENT	0
68878	66883	11066Q	PARTICIPANT	\N	PRESENT	0
69023	66884	14197C	PARTICIPANT	\N	PRESENT	0
68851	66883	11036J	PARTICIPANT	\N	PRESENT	0
69024	66884	11036J	PARTICIPANT	\N	PRESENT	0
69025	66884	11066Q	PARTICIPANT	\N	PRESENT	0
69027	66884	11042G	PARTICIPANT	\N	PRESENT	0
69029	66884	11059R	PARTICIPANT	\N	PRESENT	0
69031	66884	11104D	PARTICIPANT	\N	PRESENT	0
68857	66883	14281W	PARTICIPANT	\N	PRESENT	0
68858	66883	95015C	PARTICIPANT	\N	PRESENT	0
69033	66884	14257W	PARTICIPANT	\N	PRESENT	0
69034	66884	11107G	PARTICIPANT	\N	PRESENT	0
69035	66884	14271U	PARTICIPANT	\N	PRESENT	0
69037	66884	11033F	PARTICIPANT	\N	PRESENT	0
68863	66883	14253S	PARTICIPANT	\N	PRESENT	0
69038	66884	14219Q	PARTICIPANT	\N	PRESENT	0
69039	66884	14042U	PARTICIPANT	\N	PRESENT	0
68866	66883	14083S	PARTICIPANT	\N	PRESENT	0
68867	66883	08043V	PARTICIPANT	\N	PRESENT	0
69040	66884	14205J	PARTICIPANT	\N	PRESENT	0
68869	66883	01037S	PARTICIPANT	\N	PRESENT	0
69041	66884	11012A	PARTICIPANT	\N	PRESENT	0
68871	66883	11039M	PARTICIPANT	\N	PRESENT	0
68872	66883	14197C	PARTICIPANT	\N	PRESENT	0
69042	66884	08031R	PARTICIPANT	\N	PRESENT	0
69043	66884	95063L	PARTICIPANT	\N	PRESENT	0
69044	66884	08042U	PARTICIPANT	\N	PRESENT	0
68876	66883	92031P	PARTICIPANT	\N	PRESENT	0
68877	66883	04085P	PARTICIPANT	\N	PRESENT	0
69045	66884	14071N	PARTICIPANT	\N	PRESENT	0
69046	66884	14265W	PARTICIPANT	\N	PRESENT	0
69047	66884	08022Q	PARTICIPANT	\N	PRESENT	0
69048	66884	14273W	PARTICIPANT	\N	PRESENT	0
69054	66884	90003B	PARTICIPANT	\N	PRESENT	0
69055	66884	05012A	PARTICIPANT	\N	PRESENT	0
69056	66884	14195A	PARTICIPANT	\N	PRESENT	0
69057	66884	01022K	PARTICIPANT	\N	PRESENT	0
69058	66884	14065Q	PARTICIPANT	\N	PRESENT	0
69059	66884	08015R	PARTICIPANT	\N	PRESENT	0
69060	66884	04088S	PARTICIPANT	\N	PRESENT	0
69061	66884	14030Q	PARTICIPANT	\N	PRESENT	0
69062	66884	14038Y	PARTICIPANT	\N	PRESENT	0
69074	66884	14059S	PARTICIPANT	\N	PRESENT	0
69075	66884	11100Y	PARTICIPANT	\N	PRESENT	0
69076	66884	04085P	PARTICIPANT	\N	PRESENT	0
69100	66884	01027Q	PARTICIPANT	\N	PRESENT	0
69101	66884	14217N	PARTICIPANT	\N	PRESENT	0
69103	66884	11064N	PARTICIPANT	\N	PRESENT	0
69104	66884	14014Q	PARTICIPANT	\N	PRESENT	0
69105	66884	08056B	PARTICIPANT	\N	PRESENT	0
69106	66884	01024M	PARTICIPANT	\N	PRESENT	0
69107	66884	01013J	PARTICIPANT	\N	PRESENT	0
69108	66884	11099A	PARTICIPANT	\N	PRESENT	0
69109	66884	11090Q	PARTICIPANT	\N	PRESENT	0
69017	66884	04066L	PARTICIPANT	\N	PRESENT	0
69018	66884	14069U	PARTICIPANT	\N	PRESENT	0
69110	66884	14159V	PARTICIPANT	\N	PRESENT	0
69111	66884	14083S	PARTICIPANT	\N	PRESENT	0
69112	66884	14103D	PARTICIPANT	\N	PRESENT	0
69113	66884	11097X	PARTICIPANT	\N	PRESENT	0
69114	66884	01007L	PARTICIPANT	\N	PRESENT	0
69115	66885	11098Y	PARTICIPANT	\N	PRESENT	0
69117	66885	11036J	PARTICIPANT	\N	PRESENT	0
69118	66885	11066Q	PARTICIPANT	\N	PRESENT	0
69119	66885	11042G	PARTICIPANT	\N	PRESENT	0
69120	66885	11059R	PARTICIPANT	\N	PRESENT	0
69121	66885	11104D	PARTICIPANT	\N	PRESENT	0
69125	66885	14205J	PARTICIPANT	\N	PRESENT	0
69126	66885	11012A	PARTICIPANT	\N	PRESENT	0
69130	66885	14265W	PARTICIPANT	\N	PRESENT	0
69132	66885	14273W	PARTICIPANT	\N	PRESENT	0
69135	66885	14195A	PARTICIPANT	\N	PRESENT	0
71333	71331	96004D	PARTICIPANT	\N	EXCUSE	0
71350	71343	96004D	PARTICIPANT	\N	EXCUSE	0
71793	71744	08062Y	PARTICIPANT	\N	EXCUSE	0
71916	71915	04038G	PARTICIPANT	\N	PRESENT	0
71917	71915	11066Q	PARTICIPANT	\N	PRESENT	0
71750	71744	14030Q	PARTICIPANT	\N	PRESENT	0
77217	75209	14207L	PARTICIPANT	\N	PRESENT	0
71922	71915	01008M	PARTICIPANT	\N	EXCUSE	0
71923	71915	14089Y	PARTICIPANT	\N	EXCUSE	0
71924	71915	08060W	PARTICIPANT	\N	EXCUSE	0
71755	71744	11114F	PARTICIPANT	\N	PRESENT	0
71925	71915	11029K	PARTICIPANT	\N	EXCUSE	0
71926	71915	11080N	PARTICIPANT	\N	EXCUSE	0
71758	71744	01015L	PARTICIPANT	\N	EXCUSE	0
71759	71744	11107G	PARTICIPANT	\N	PRESENT	0
71927	71915	08028W	PARTICIPANT	\N	EXCUSE	0
71928	71915	88008L	PARTICIPANT	\N	EXCUSE	0
71762	71744	01022K	PARTICIPANT	\N	PRESENT	0
71929	71915	01059Y	PARTICIPANT	\N	EXCUSE	0
71930	71915	11088W	PARTICIPANT	\N	EXCUSE	0
71931	71915	98018T	PARTICIPANT	\N	EXCUSE	0
71766	71744	14219Q	PARTICIPANT	\N	PRESENT	0
71932	71915	01015L	PARTICIPANT	\N	EXCUSE	0
71933	71915	01041N	PARTICIPANT	\N	EXCUSE	0
71769	71744	08009T	PRESIDENT	0	PRESENT	0
71934	71915	14187A	PARTICIPANT	\N	EXCUSE	0
71935	71915	02002K	PARTICIPANT	\N	EXCUSE	0
71936	71915	08048B	PARTICIPANT	\N	EXCUSE	0
71937	71915	11089X	PARTICIPANT	\N	EXCUSE	0
71774	71744	14169X	PARTICIPANT	\N	PRESENT	0
71775	71744	14237S	PARTICIPANT	\N	PRESENT	0
71938	71915	14026U	PARTICIPANT	\N	EXCUSE	0
71939	71915	14179A	PARTICIPANT	\N	EXCUSE	0
71940	71915	14121F	PARTICIPANT	\N	EXCUSE	0
71941	71915	11084S	PARTICIPANT	\N	EXCUSE	0
71780	71744	14331P	PARTICIPANT	\N	PRESENT	0
71781	71744	95062K	PARTICIPANT	\N	PRESENT	0
71942	71915	99004R	PARTICIPANT	\N	EXCUSE	0
71943	71915	04061F	PARTICIPANT	\N	EXCUSE	0
71784	71744	14157T	PARTICIPANT	\N	PRESENT	0
71785	71744	96003C	PARTICIPANT	\N	EXCUSE	0
71944	71915	01061S	PARTICIPANT	\N	EXCUSE	0
71945	71915	08012N	PARTICIPANT	\N	EXCUSE	0
71946	71915	14103D	PARTICIPANT	\N	EXCUSE	0
71947	71915	08062Y	PARTICIPANT	\N	EXCUSE	0
71948	71915	14257W	PARTICIPANT	\N	EXCUSE	0
71949	71915	08021P	PARTICIPANT	\N	EXCUSE	0
71950	71915	14229S	PARTICIPANT	\N	EXCUSE	0
71951	71915	11046L	PARTICIPANT	\N	EXCUSE	0
71952	71915	14107H	PARTICIPANT	\N	EXCUSE	0
71953	71915	01028R	PARTICIPANT	\N	EXCUSE	0
71954	71915	11094U	PARTICIPANT	\N	EXCUSE	0
71955	71915	92045V	PARTICIPANT	\N	EXCUSE	0
77218	75209	14051J	PARTICIPANT	\N	PRESENT	0
77219	75209	14111D	PARTICIPANT	\N	PRESENT	0
77220	75209	14069U	PARTICIPANT	\N	PRESENT	0
77221	75209	14083S	PARTICIPANT	\N	PRESENT	0
77222	75209	14179A	PARTICIPANT	\N	PRESENT	0
77247	75209	14199E	PARTICIPANT	\N	PRESENT	0
77248	75209	04043D	PARTICIPANT	\N	PRESENT	0
77249	75209	14037X	PARTICIPANT	\N	PRESENT	0
77250	75209	04034C	PARTICIPANT	\N	PRESENT	0
77251	75209	14197C	PARTICIPANT	\N	PRESENT	0
77252	75209	01016M	PARTICIPANT	\N	PRESENT	0
77253	75209	14217N	PARTICIPANT	\N	PRESENT	0
77254	75209	11090Q	PARTICIPANT	\N	PRESENT	0
77255	75209	04049K	PARTICIPANT	\N	PRESENT	0
77256	75209	11114F	PARTICIPANT	\N	PRESENT	0
77210	75209	11095V	PARTICIPANT	\N	PRESENT	0
77216	75209	98046X	PARTICIPANT	\N	PRESENT	0
77257	75209	14159V	PARTICIPANT	\N	PRESENT	0
77258	75209	14281W	PARTICIPANT	\N	PRESENT	0
77259	75209	95062K	PARTICIPANT	\N	PRESENT	0
77260	75209	01027Q	PARTICIPANT	\N	PRESENT	0
77261	75209	11112D	PARTICIPANT	\N	PRESENT	0
77262	75209	11107G	PARTICIPANT	\N	PRESENT	0
77263	75209	96004D	PARTICIPANT	\N	PRESENT	0
77264	75209	14273W	PARTICIPANT	\N	PRESENT	0
77265	75209	14053L	PARTICIPANT	\N	PRESENT	0
77270	75209	01015L	PARTICIPANT	\N	PRESENT	0
77271	75209	14231L	PARTICIPANT	\N	PRESENT	0
77272	75209	14247U	PARTICIPANT	\N	PRESENT	0
77273	75209	04094Q	PARTICIPANT	\N	PRESENT	0
77274	75209	14103D	PARTICIPANT	\N	PRESENT	0
77275	75209	14038Y	PARTICIPANT	\N	PRESENT	0
77276	75209	14259Y	PARTICIPANT	\N	PRESENT	0
77277	75209	01024M	PARTICIPANT	\N	PRESENT	0
77278	75209	01058X	PARTICIPANT	\N	PRESENT	0
77279	75209	11012A	PARTICIPANT	\N	PRESENT	0
77812	77795	11054L	PARTICIPANT	\N	EXCUSE	0
77814	77813	08018U	PARTICIPANT	\N	PRESENT	0
78239	75076	14039A	PARTICIPANT	\N	EXCUSE	0
80112	80071	08010L	PARTICIPANT	\N	EXCUSE	0
78392	78390	08055A	PARTICIPANT	\N	PRESENT	0
78393	78390	14093U	PARTICIPANT	\N	PRESENT	0
78244	78240	08058D	PARTICIPANT	\N	PRESENT	0
78394	78390	14030Q	PARTICIPANT	\N	PRESENT	0
78395	78390	96004D	PARTICIPANT	\N	PRESENT	0
78247	78240	98029W	PARTICIPANT	\N	PRESENT	0
78396	78390	08060W	PARTICIPANT	\N	PRESENT	0
78249	78240	11027H	PARTICIPANT	\N	PRESENT	0
78250	78240	98018T	PARTICIPANT	\N	PRESENT	0
78251	78240	92018S	PARTICIPANT	\N	PRESENT	0
78252	78240	92020L	PARTICIPANT	\N	PRESENT	0
78397	78390	11095V	PARTICIPANT	\N	EXCUSE	0
78398	78390	14038Y	PARTICIPANT	\N	PRESENT	0
80232	77771	89017R	PARTICIPANT	\N	PRESENT	0
78256	78240	97011G	PARTICIPANT	\N	PRESENT	0
78257	78240	08065C	PARTICIPANT	\N	EXCUSE	0
78258	78240	04035D	PARTICIPANT	\N	PRESENT	0
78400	78390	98023Q	PARTICIPANT	\N	PRESENT	0
80233	77771	14030Q	PARTICIPANT	\N	PRESENT	0
78261	78240	14014Q	PARTICIPANT	\N	PRESENT	0
78402	78390	01015L	PARTICIPANT	\N	PRESENT	0
78403	78390	11107G	PARTICIPANT	\N	EXCUSE	0
78264	78240	95035G	PARTICIPANT	\N	EXCUSE	0
78265	78240	08056B	PARTICIPANT	\N	EXCUSE	0
80234	77771	14105F	PARTICIPANT	\N	PRESENT	0
78405	78390	02002K	PARTICIPANT	\N	PRESENT	0
78406	78390	01022K	PARTICIPANT	\N	PRESENT	0
78269	78240	95037J	PARTICIPANT	\N	PRESENT	0
78270	78240	04078Q	PARTICIPANT	\N	PRESENT	0
78271	78240	14097Y	PARTICIPANT	\N	PRESENT	0
78407	78390	04097T	PARTICIPANT	\N	PRESENT	0
78273	78240	04036E	PARTICIPANT	\N	PRESENT	0
78408	78390	09001P	PARTICIPANT	\N	PRESENT	0
78275	78240	04077P	PARTICIPANT	\N	PRESENT	0
78276	78240	98005N	PARTICIPANT	\N	PRESENT	0
78277	78240	92031P	PARTICIPANT	\N	PRESENT	0
78278	78240	11106F	PARTICIPANT	\N	PRESENT	0
78279	78240	14251Q	PARTICIPANT	\N	PRESENT	0
78409	78390	11059R	PARTICIPANT	\N	PRESENT	0
78410	78390	14219Q	PARTICIPANT	\N	PRESENT	0
78282	78240	11082Q	PARTICIPANT	\N	PRESENT	0
78283	78240	11105E	PARTICIPANT	\N	PRESENT	0
78284	78240	14253S	PARTICIPANT	\N	PRESENT	0
78411	78390	80027E	PARTICIPANT	\N	PRESENT	0
78286	78240	14028W	PARTICIPANT	\N	PRESENT	0
78287	78240	14193X	PARTICIPANT	\N	PRESENT	0
78288	78240	98021N	PARTICIPANT	\N	EXCUSE	0
78412	78390	14031R	PARTICIPANT	\N	PRESENT	0
78290	78240	95059Q	PRESIDENT	0	PRESENT	0
78291	78240	86044G	PARTICIPANT	\N	PRESENT	0
78413	78390	08009T	PRESIDENT	0	PRESENT	0
78293	78240	11054L	PARTICIPANT	\N	PRESENT	0
78294	78240	01056V	PARTICIPANT	\N	EXCUSE	0
78414	78390	08062Y	PARTICIPANT	\N	PRESENT	0
80235	77771	08068F	PARTICIPANT	\N	PRESENT	0
80236	77771	04053F	PARTICIPANT	\N	PRESENT	0
78298	78240	04040A	PARTICIPANT	\N	PRESENT	0
78415	78390	14221J	PARTICIPANT	\N	PRESENT	0
78416	78390	92039X	PARTICIPANT	\N	PRESENT	0
78417	78390	08042U	PARTICIPANT	\N	PRESENT	0
78418	78390	14169X	PARTICIPANT	\N	PRESENT	0
78419	78390	14237S	PARTICIPANT	\N	PRESENT	0
78420	78390	13002U	PARTICIPANT	\N	PRESENT	0
78421	78390	05012A	PARTICIPANT	\N	PRESENT	0
80237	77771	14207L	PARTICIPANT	\N	PRESENT	0
78423	78390	14135M	PARTICIPANT	\N	PRESENT	0
78424	78390	14331P	PARTICIPANT	\N	PRESENT	0
78425	78390	95062K	PARTICIPANT	\N	PRESENT	0
80238	77771	14255U	PARTICIPANT	\N	PRESENT	0
78427	78390	14051J	PARTICIPANT	\N	PRESENT	0
78428	78390	14157T	PARTICIPANT	\N	PRESENT	0
78429	78390	96003C	PARTICIPANT	\N	EXCUSE	0
80239	77771	14083S	PARTICIPANT	\N	PRESENT	0
80240	77771	04055H	PARTICIPANT	\N	PRESENT	0
80241	77771	14041T	PARTICIPANT	\N	PRESENT	0
80242	77771	04071H	PARTICIPANT	\N	PRESENT	0
80243	77771	14151M	PARTICIPANT	\N	PRESENT	0
64016	64015	11061K	PARTICIPANT	\N	PRESENT	0
64017	64015	11093T	PARTICIPANT	\N	PRESENT	0
66317	65356	92045V	PARTICIPANT	\N	PRESENT	0
66318	65356	14037X	PARTICIPANT	\N	PRESENT	0
66319	65356	11042G	PARTICIPANT	\N	PRESENT	0
66320	65356	11084S	PARTICIPANT	\N	PRESENT	0
66321	65356	14195A	PARTICIPANT	\N	PRESENT	0
66322	65356	14259Y	PARTICIPANT	\N	PRESENT	0
66323	65356	14013P	PARTICIPANT	\N	PRESENT	0
66324	65356	14042U	PARTICIPANT	\N	PRESENT	0
66325	65356	11026G	PARTICIPANT	\N	PRESENT	0
66326	65356	04034C	PARTICIPANT	\N	PRESENT	0
66327	65356	14271U	PARTICIPANT	\N	PRESENT	0
66328	65356	08069G	PARTICIPANT	\N	PRESENT	0
66329	65356	14119M	PARTICIPANT	\N	PRESENT	0
66343	65356	08018U	PARTICIPANT	\N	PRESENT	0
66345	65356	04044E	PARTICIPANT	\N	PRESENT	0
66346	65356	01027Q	PARTICIPANT	\N	PRESENT	0
66349	65356	12042Y	PARTICIPANT	\N	PRESENT	0
66350	65356	95035G	PARTICIPANT	\N	PRESENT	0
66351	65356	92031P	PARTICIPANT	\N	PRESENT	0
66352	65356	11067R	PARTICIPANT	\N	PRESENT	0
66369	65356	00003C	PARTICIPANT	\N	PRESENT	0
66374	65356	14071N	PARTICIPANT	\N	PRESENT	0
66375	65356	01037S	PARTICIPANT	\N	PRESENT	0
66450	65356	14157T	PARTICIPANT	\N	PRESENT	0
66457	65356	11098Y	PARTICIPANT	\N	PRESENT	0
66458	65356	11031D	PARTICIPANT	\N	PRESENT	0
66502	65357	11063M	PARTICIPANT	\N	PRESENT	0
66503	65357	11098Y	PARTICIPANT	\N	PRESENT	0
66504	65357	00003C	PARTICIPANT	\N	PRESENT	0
66505	65357	04053F	PARTICIPANT	\N	PRESENT	0
66506	65357	01028R	PARTICIPANT	\N	PRESENT	0
66507	65357	12042Y	PARTICIPANT	\N	PRESENT	0
66508	65357	11055M	PARTICIPANT	\N	PRESENT	0
66509	65357	14042U	PARTICIPANT	\N	PRESENT	0
66510	65357	14157T	PARTICIPANT	\N	PRESENT	0
66511	65357	14071N	PARTICIPANT	\N	PRESENT	0
66512	65357	11061K	PARTICIPANT	\N	PRESENT	0
66513	65357	14261S	PARTICIPANT	\N	PRESENT	0
66514	65357	14269B	PARTICIPANT	\N	PRESENT	0
66515	65357	14195A	PARTICIPANT	\N	PRESENT	0
66516	65357	11031D	PARTICIPANT	\N	PRESENT	0
66517	65357	11026G	PARTICIPANT	\N	PRESENT	0
66518	65357	14121F	PARTICIPANT	\N	PRESENT	0
66539	66519	14119M	PARTICIPANT	\N	PRESENT	0
66540	66519	14071N	PARTICIPANT	\N	PRESENT	0
66541	66519	12042Y	PARTICIPANT	\N	PRESENT	0
66542	66519	00003C	PARTICIPANT	\N	PRESENT	0
66543	66519	14269B	PARTICIPANT	\N	PRESENT	0
66544	66519	11063M	PARTICIPANT	\N	PRESENT	0
66545	66519	11031D	PARTICIPANT	\N	PRESENT	0
66546	66519	14042U	PARTICIPANT	\N	PRESENT	0
66547	66519	11055M	PARTICIPANT	\N	PRESENT	0
66548	66519	14121F	PARTICIPANT	\N	PRESENT	0
66549	66519	11026G	PARTICIPANT	\N	PRESENT	0
66550	66519	11061K	PARTICIPANT	\N	PRESENT	0
66551	66519	11067R	PARTICIPANT	\N	PRESENT	0
66552	66519	14261S	PARTICIPANT	\N	PRESENT	0
66553	66519	04067M	PARTICIPANT	\N	PRESENT	0
66573	65358	14195A	PARTICIPANT	\N	PRESENT	0
66574	65358	00003C	PARTICIPANT	\N	PRESENT	0
66537	66519	04066L	PARTICIPANT	\N	PRESENT	0
66538	66519	14195A	PARTICIPANT	\N	PRESENT	0
66575	65358	14121F	PARTICIPANT	\N	PRESENT	0
66576	65358	14261S	PARTICIPANT	\N	PRESENT	0
66577	65358	14071N	PARTICIPANT	\N	PRESENT	0
66578	65358	14042U	PARTICIPANT	\N	PRESENT	0
66579	65358	11031D	PARTICIPANT	\N	PRESENT	0
66500	65357	04081K	PARTICIPANT	\N	PRESENT	0
66501	65357	11067R	PARTICIPANT	\N	PRESENT	0
66580	65358	11061K	PARTICIPANT	\N	PRESENT	0
66581	65358	14269B	PARTICIPANT	\N	PRESENT	0
66582	65358	11067R	PARTICIPANT	\N	PRESENT	0
66583	65358	11063M	PARTICIPANT	\N	PRESENT	0
66584	65358	04067M	PARTICIPANT	\N	PRESENT	0
67050	66880	14014Q	PARTICIPANT	\N	PRESENT	0
67051	66880	14109K	PARTICIPANT	\N	PRESENT	0
67052	66880	08022Q	PARTICIPANT	\N	PRESENT	0
67053	66880	14207L	PARTICIPANT	\N	PRESENT	0
67054	66880	14329V	PARTICIPANT	\N	PRESENT	0
66571	65358	04066L	PARTICIPANT	\N	PRESENT	0
66572	65358	12042Y	PARTICIPANT	\N	PRESENT	0
67055	66880	88008L	PARTICIPANT	\N	PRESENT	0
67057	66880	14051J	PARTICIPANT	\N	PRESENT	0
67058	66880	14167V	PARTICIPANT	\N	PRESENT	0
67059	66880	11054L	PARTICIPANT	\N	PRESENT	0
67060	66880	83047W	PARTICIPANT	\N	PRESENT	0
67061	66880	14133K	PARTICIPANT	\N	PRESENT	0
67062	66880	11059R	PARTICIPANT	\N	PRESENT	0
67063	66880	80027E	PARTICIPANT	\N	PRESENT	0
67064	66880	14281W	PARTICIPANT	\N	PRESENT	0
67065	66880	14135M	PARTICIPANT	\N	PRESENT	0
67066	66880	14121F	PARTICIPANT	\N	PRESENT	0
67067	66880	08015R	PARTICIPANT	\N	PRESENT	0
67068	66880	11074Q	PARTICIPANT	\N	PRESENT	0
67069	66880	14257W	PARTICIPANT	\N	PRESENT	0
67070	66880	11014C	PARTICIPANT	\N	PRESENT	0
67071	66880	08042U	PARTICIPANT	\N	PRESENT	0
67072	66880	96004D	PARTICIPANT	\N	PRESENT	0
67073	66880	11049P	PARTICIPANT	\N	PRESENT	0
67074	66880	08018U	PARTICIPANT	\N	PRESENT	0
67075	66880	08073C	PARTICIPANT	\N	PRESENT	0
67076	66880	98018T	PARTICIPANT	\N	PRESENT	0
67077	66880	08061X	PARTICIPANT	\N	PRESENT	0
67078	66880	11032E	PARTICIPANT	\N	PRESENT	0
67079	66880	10015M	PARTICIPANT	\N	PRESENT	0
67080	66880	11042G	PARTICIPANT	\N	PRESENT	0
67081	66880	11109J	PARTICIPANT	\N	PRESENT	0
67082	66880	14247U	PARTICIPANT	\N	PRESENT	0
67083	66880	14055N	PARTICIPANT	\N	PRESENT	0
67084	66880	11090Q	PARTICIPANT	\N	PRESENT	0
67085	66880	11107G	PARTICIPANT	\N	PRESENT	0
67087	66880	01041N	PARTICIPANT	\N	PRESENT	0
67088	66880	08016S	PARTICIPANT	\N	PRESENT	0
67089	66880	99002P	PARTICIPANT	\N	PRESENT	0
67090	66880	12042Y	PARTICIPANT	\N	PRESENT	0
67092	66880	14225N	PARTICIPANT	\N	PRESENT	0
67093	66880	08017T	PARTICIPANT	\N	PRESENT	0
67095	66880	14147R	PARTICIPANT	\N	PRESENT	0
67096	66880	14081Q	PARTICIPANT	\N	PRESENT	0
67097	66880	04047H	PARTICIPANT	\N	PRESENT	0
67098	66880	11066Q	PARTICIPANT	\N	PRESENT	0
67099	66880	86044G	PARTICIPANT	\N	PRESENT	0
67100	66880	92039X	PARTICIPANT	\N	PRESENT	0
67101	66880	14229S	PARTICIPANT	\N	PRESENT	0
67102	66880	01037S	PARTICIPANT	\N	PRESENT	0
67103	66880	14026U	PARTICIPANT	\N	PRESENT	0
67104	66880	11110B	PARTICIPANT	\N	PRESENT	0
67105	66880	08024S	PARTICIPANT	\N	PRESENT	0
67106	66880	01028R	PARTICIPANT	\N	PRESENT	0
67107	66880	01046T	PARTICIPANT	\N	PRESENT	0
67108	66880	04053F	PARTICIPANT	\N	PRESENT	0
67109	66880	11056N	PARTICIPANT	\N	PRESENT	0
67110	66880	14215L	PARTICIPANT	\N	PRESENT	0
67111	66880	14173T	PARTICIPANT	\N	PRESENT	0
67112	66880	14087W	PARTICIPANT	\N	PRESENT	0
67113	66880	04044E	PARTICIPANT	\N	PRESENT	0
67114	66880	11057P	PARTICIPANT	\N	PRESENT	0
67115	66880	11112D	PARTICIPANT	\N	PRESENT	0
67117	66880	01008M	PARTICIPANT	\N	PRESENT	0
67120	66880	07034Q	PARTICIPANT	\N	PRESENT	0
67122	66880	14251Q	PARTICIPANT	\N	PRESENT	0
67124	66880	05012A	PARTICIPANT	\N	PRESENT	0
67125	66880	04086Q	PARTICIPANT	\N	PRESENT	0
67126	66880	11046L	PARTICIPANT	\N	PRESENT	0
67127	66880	14237S	PARTICIPANT	\N	PRESENT	0
67128	66880	98023Q	PARTICIPANT	\N	PRESENT	0
67129	66880	01014K	PARTICIPANT	\N	PRESENT	0
67130	66880	01059Y	PARTICIPANT	\N	PRESENT	0
67131	66880	98053W	PARTICIPANT	\N	PRESENT	0
67132	66880	04074L	PARTICIPANT	\N	PRESENT	0
67133	66880	04041B	PARTICIPANT	\N	PRESENT	0
67134	66880	14053L	PARTICIPANT	\N	PRESENT	0
67135	66880	92045V	PARTICIPANT	\N	PRESENT	0
67136	66880	08038Y	PARTICIPANT	\N	PRESENT	0
67137	66880	14119M	PARTICIPANT	\N	PRESENT	0
67139	66880	14071N	PARTICIPANT	\N	PRESENT	0
78030	78029	86044G	PARTICIPANT	\N	PRESENT	0
78031	78029	11027H	PARTICIPANT	\N	PRESENT	0
79687	66879	05012A	PARTICIPANT	\N	PRESENT	0
79688	66879	11098Y	PARTICIPANT	\N	PRESENT	0
79689	66879	14063N	PARTICIPANT	\N	PRESENT	0
79690	66879	95063L	PARTICIPANT	\N	PRESENT	0
79691	66879	11037K	PARTICIPANT	\N	PRESENT	0
79692	66879	08051V	PARTICIPANT	\N	PRESENT	0
79693	66879	14231L	PARTICIPANT	\N	PRESENT	0
79694	66879	14327T	PARTICIPANT	\N	PRESENT	0
79696	66879	08010L	PARTICIPANT	\N	PRESENT	0
79697	66879	11049P	PARTICIPANT	\N	PRESENT	0
79698	66879	01057W	PARTICIPANT	\N	PRESENT	0
79722	79720	04040A	PARTICIPANT	\N	PRESENT	0
79724	79720	11106F	PARTICIPANT	\N	PRESENT	0
79725	79720	14193X	PARTICIPANT	\N	PRESENT	0
79726	79720	98021N	PARTICIPANT	\N	PRESENT	0
79727	79720	11054L	PARTICIPANT	\N	PRESENT	0
79729	79728	14251Q	PARTICIPANT	\N	PRESENT	0
79730	79728	95037J	PARTICIPANT	\N	PRESENT	0
79731	79728	11076S	PARTICIPANT	\N	PRESENT	0
79733	79732	14251Q	PARTICIPANT	\N	PRESENT	0
79734	79732	95037J	PARTICIPANT	\N	PRESENT	0
79740	79739	86044G	PARTICIPANT	\N	PRESENT	0
79741	79739	11027H	PARTICIPANT	\N	PRESENT	0
79743	79742	86044G	PARTICIPANT	\N	PRESENT	0
79744	79742	11027H	PARTICIPANT	\N	PRESENT	0
80377	80376	08010L	PARTICIPANT	\N	PRESENT	0
80379	80378	98046X	PARTICIPANT	\N	PRESENT	0
80380	80378	01013J	PARTICIPANT	\N	PRESENT	0
80381	80378	14327T	PARTICIPANT	\N	PRESENT	0
80382	80378	04086Q	PARTICIPANT	\N	PRESENT	0
80383	80378	11070L	PARTICIPANT	\N	PRESENT	0
80384	80378	14225N	PARTICIPANT	\N	PRESENT	0
80385	80378	14199E	PARTICIPANT	\N	PRESENT	0
80386	80378	01057W	PARTICIPANT	\N	PRESENT	0
80387	80378	11088W	PARTICIPANT	\N	PRESENT	0
80388	80378	14175V	PARTICIPANT	\N	PRESENT	0
80432	80071	14063N	PARTICIPANT	\N	EXCUSE	0
82342	78333	07029T	PARTICIPANT	\N	PRESENT	0
83340	83339	11085T	PARTICIPANT	\N	PRESENT	0
83341	83339	14030Q	PARTICIPANT	\N	PRESENT	0
83342	83339	14237S	PARTICIPANT	\N	PRESENT	0
83343	83339	11023D	PARTICIPANT	\N	PRESENT	0
83344	83339	92039X	PARTICIPANT	\N	PRESENT	0
83345	83339	14031R	PARTICIPANT	\N	PRESENT	0
83346	83339	14073Q	PARTICIPANT	\N	PRESENT	0
83348	83347	11103C	PARTICIPANT	\N	PRESENT	0
83349	83347	14107H	PARTICIPANT	\N	PRESENT	0
83350	83347	08061X	PARTICIPANT	\N	PRESENT	0
83503	83501	11091R	PARTICIPANT	\N	PRESENT	0
83504	83501	08034U	PARTICIPANT	\N	PRESENT	0
83505	83501	11026G	PARTICIPANT	\N	PRESENT	0
83508	83507	98042T	PARTICIPANT	\N	PRESENT	0
83509	83507	11048N	PARTICIPANT	\N	PRESENT	0
83510	83507	14063N	PARTICIPANT	\N	PRESENT	0
83726	83725	14327T	PARTICIPANT	\N	PRESENT	0
84857	84820	92031P	PARTICIPANT	\N	PRESENT	0
84858	84820	11106F	PARTICIPANT	\N	PRESENT	0
84859	84820	14251Q	PARTICIPANT	\N	PRESENT	0
84860	84820	83042R	PARTICIPANT	\N	PRESENT	0
84861	84820	08053X	PARTICIPANT	\N	PRESENT	0
84862	84820	11082Q	PARTICIPANT	\N	PRESENT	0
84863	84820	11105E	PARTICIPANT	\N	PRESENT	0
84864	84820	14253S	PARTICIPANT	\N	PRESENT	0
84865	84820	08047A	PARTICIPANT	\N	PRESENT	0
84866	84820	14028W	PARTICIPANT	\N	PRESENT	0
84867	84820	14193X	PARTICIPANT	\N	PRESENT	0
84868	84820	98021N	PARTICIPANT	\N	PRESENT	0
84869	84820	04080J	PARTICIPANT	\N	PRESENT	0
84870	84820	95059Q	PRESIDENT	0	PRESENT	0
84871	84820	86044G	PARTICIPANT	\N	PRESENT	0
84872	84820	01014K	PARTICIPANT	\N	PRESENT	0
84873	84820	11054L	PARTICIPANT	\N	PRESENT	0
84874	84820	01056V	PARTICIPANT	\N	PRESENT	0
82340	78333	11104D	PARTICIPANT	\N	PRESENT	0
82341	78333	11057P	PARTICIPANT	\N	PRESENT	0
84875	84820	92044U	PARTICIPANT	\N	PRESENT	0
84876	84820	08049C	PARTICIPANT	\N	EXCUSE	0
84877	84820	04050C	PARTICIPANT	\N	PRESENT	0
84892	84889	04040A	PARTICIPANT	\N	PRESENT	0
84893	84889	08058D	PARTICIPANT	\N	PRESENT	0
84895	84889	04042C	PARTICIPANT	\N	PRESENT	0
84896	84889	77002U	PARTICIPANT	\N	PRESENT	0
84897	84889	98029W	PARTICIPANT	\N	PRESENT	0
84899	84889	98018T	PARTICIPANT	\N	PRESENT	0
84900	84889	92018S	PARTICIPANT	\N	PRESENT	0
84901	84889	92020L	PARTICIPANT	\N	PRESENT	0
84902	84889	95030B	PARTICIPANT	\N	PRESENT	0
84904	84889	11096W	PARTICIPANT	\N	PRESENT	0
84906	84889	97011G	PARTICIPANT	\N	PRESENT	0
84907	84889	08065C	PARTICIPANT	\N	PRESENT	0
84909	84889	04035D	PARTICIPANT	\N	PRESENT	0
84910	84889	07024N	PARTICIPANT	\N	PRESENT	0
84911	84889	04095R	PARTICIPANT	\N	PRESENT	0
84913	84889	11015D	PARTICIPANT	\N	PRESENT	0
84914	84889	95035G	PARTICIPANT	\N	PRESENT	0
84915	84889	08056B	PARTICIPANT	\N	EXCUSE	0
84916	84889	14211G	PARTICIPANT	\N	PRESENT	0
84917	84889	98022P	PARTICIPANT	\N	PRESENT	0
84918	84889	11064N	PARTICIPANT	\N	PRESENT	0
84919	84889	14097Y	PARTICIPANT	\N	PRESENT	0
84920	84889	04036E	PARTICIPANT	\N	PRESENT	0
84921	84889	04077P	PARTICIPANT	\N	PRESENT	0
84923	84889	92031P	PARTICIPANT	\N	PRESENT	0
84924	84889	11106F	PARTICIPANT	\N	PRESENT	0
84926	84889	14251Q	PARTICIPANT	\N	PRESENT	0
84928	84889	11082Q	PARTICIPANT	\N	PRESENT	0
84929	84889	14253S	PARTICIPANT	\N	PRESENT	0
84931	84889	14028W	PARTICIPANT	\N	PRESENT	0
84932	84889	14193X	PARTICIPANT	\N	PRESENT	0
84934	84889	98021N	PARTICIPANT	\N	PRESENT	0
84936	84889	04080J	PARTICIPANT	\N	PRESENT	0
84937	84889	95059Q	PRESIDENT	0	PRESENT	0
84939	84889	86044G	PARTICIPANT	\N	PRESENT	0
84940	84889	01014K	PARTICIPANT	\N	PRESENT	0
84941	84889	11054L	PARTICIPANT	\N	PRESENT	0
84943	84889	01056V	PARTICIPANT	\N	PRESENT	0
84945	84889	08049C	PARTICIPANT	\N	EXCUSE	0
85060	83303	14083S	PARTICIPANT	\N	PRESENT	0
85251	85250	11039M	PARTICIPANT	\N	PRESENT	0
85252	85250	98042T	PARTICIPANT	\N	PRESENT	0
85253	85250	01019Q	PARTICIPANT	\N	PRESENT	0
85305	85304	01007L	PARTICIPANT	\N	PRESENT	0
85306	85304	04088S	PARTICIPANT	\N	PRESENT	0
85340	85339	89017R	PARTICIPANT	\N	PRESENT	0
85341	85339	01031L	PRESIDENT	0	PRESENT	0
85343	85339	01013J	PARTICIPANT	\N	PRESENT	0
85344	85339	11068S	PARTICIPANT	\N	PRESENT	0
85348	85339	14175V	PARTICIPANT	\N	PRESENT	0
85349	85339	14083S	PARTICIPANT	\N	PRESENT	0
85350	85339	11053K	PARTICIPANT	\N	PRESENT	0
85351	85339	14085U	PARTICIPANT	\N	PRESENT	0
85352	85339	11042G	PARTICIPANT	\N	PRESENT	0
85354	85339	04086Q	PARTICIPANT	\N	PRESENT	0
85357	85339	11088W	PARTICIPANT	\N	PRESENT	0
85358	85339	14327T	PARTICIPANT	\N	PRESENT	0
85359	85339	08022Q	PARTICIPANT	\N	PRESENT	0
85360	85339	01027Q	PARTICIPANT	\N	PRESENT	0
85361	85339	04071H	PARTICIPANT	\N	PRESENT	0
85362	85339	11074Q	PARTICIPANT	\N	PRESENT	0
85363	85339	98053W	PARTICIPANT	\N	EXCUSE	0
85365	85339	14199E	PARTICIPANT	\N	PRESENT	0
85366	85339	01057W	PARTICIPANT	\N	PRESENT	0
85367	85339	08016S	PARTICIPANT	\N	PRESENT	0
85370	85339	99004R	PARTICIPANT	\N	PRESENT	0
85371	85339	04061F	PARTICIPANT	\N	PRESENT	0
85372	85339	14159V	PARTICIPANT	\N	PRESENT	0
85373	85339	07029T	PARTICIPANT	\N	PRESENT	0
85375	85339	08010L	PARTICIPANT	\N	PRESENT	0
85376	85339	08034U	PARTICIPANT	\N	PRESENT	0
85378	85339	98046X	PARTICIPANT	\N	PRESENT	0
85380	85339	08011M	PARTICIPANT	\N	PRESENT	0
63791	54852	11101A	PARTICIPANT	\N	PRESENT	0
63792	54852	04086Q	PARTICIPANT	\N	PRESENT	0
63793	54852	14327T	PARTICIPANT	\N	PRESENT	0
63794	54852	14034U	PARTICIPANT	\N	PRESENT	0
63795	54852	14231L	PARTICIPANT	\N	PRESENT	0
63796	54852	11049P	PARTICIPANT	\N	PRESENT	0
63797	54852	01057W	PARTICIPANT	\N	PRESENT	0
63798	54852	11048N	PARTICIPANT	\N	PRESENT	0
63799	54852	11112D	PARTICIPANT	\N	PRESENT	0
63800	54852	08051V	PARTICIPANT	\N	PRESENT	0
63801	54852	14028W	PARTICIPANT	\N	PRESENT	0
63802	54852	07032N	PARTICIPANT	\N	PRESENT	0
63803	54852	05012A	PARTICIPANT	\N	PRESENT	0
63804	54852	95063L	PARTICIPANT	\N	PRESENT	0
63805	54852	14051J	PARTICIPANT	\N	PRESENT	0
65353	63782	08069G	PARTICIPANT	\N	EXCUSE	0
63807	58964	01027Q	PARTICIPANT	\N	PRESENT	0
65352	63782	14263U	PARTICIPANT	\N	EXCUSE	0
65363	65362	14239U	PARTICIPANT	\N	PRESENT	0
65364	65362	11055M	PARTICIPANT	\N	PRESENT	0
65365	65362	01046T	PARTICIPANT	\N	PRESENT	0
65366	65362	04053F	PARTICIPANT	\N	PRESENT	0
65439	65438	14133K	PARTICIPANT	\N	EXCUSE	0
65368	65362	04066L	PARTICIPANT	\N	PRESENT	0
65369	65362	00003C	PARTICIPANT	\N	PRESENT	0
65370	65362	14053L	PARTICIPANT	\N	PRESENT	0
65371	65362	11103C	PARTICIPANT	\N	PRESENT	0
65440	65438	14239U	PARTICIPANT	\N	PRESENT	0
65373	65362	14195A	PARTICIPANT	\N	PRESENT	0
65374	65362	14267Y	PARTICIPANT	\N	PRESENT	0
65441	65438	14065Q	PARTICIPANT	\N	PRESENT	0
65376	65362	11031D	PARTICIPANT	\N	PRESENT	0
65377	65362	08052W	PARTICIPANT	\N	PRESENT	0
65378	65362	01059Y	PARTICIPANT	\N	PRESENT	0
65379	65362	04081K	PARTICIPANT	\N	PRESENT	0
65380	65362	98024R	PRESIDENT	0	PRESENT	0
65442	65438	14089Y	PARTICIPANT	\N	PRESENT	0
65382	65362	04067M	PARTICIPANT	\N	PRESENT	0
65383	65362	14217N	PARTICIPANT	\N	PRESENT	0
65384	65362	14042U	PARTICIPANT	\N	PRESENT	0
65385	65362	14151M	PARTICIPANT	\N	PRESENT	0
65386	65362	12042Y	PARTICIPANT	\N	PRESENT	0
65387	65362	14281W	PARTICIPANT	\N	PRESENT	0
65388	65362	14087W	PARTICIPANT	\N	PRESENT	0
66699	66698	98046X	PARTICIPANT	\N	PRESENT	0
65444	65438	14041T	PARTICIPANT	\N	PRESENT	0
65391	65362	14231L	PARTICIPANT	\N	PRESENT	0
65392	65362	11061K	PARTICIPANT	\N	PRESENT	0
65393	65362	08048B	PARTICIPANT	\N	PRESENT	0
65394	65362	08041T	PARTICIPANT	\N	PRESENT	0
65395	65362	01011G	PARTICIPANT	\N	PRESENT	0
65396	65362	14026U	PARTICIPANT	\N	PRESENT	0
65397	65362	14213J	PARTICIPANT	\N	PRESENT	0
65445	65438	14217N	PARTICIPANT	\N	PRESENT	0
65399	65362	11112D	PARTICIPANT	\N	PRESENT	0
65400	65362	14037X	PARTICIPANT	\N	PRESENT	0
65401	65362	14018U	PARTICIPANT	\N	PRESENT	0
65402	65362	11067R	PARTICIPANT	\N	PRESENT	0
65403	65362	14223L	PARTICIPANT	\N	PRESENT	0
65404	65362	04092N	PARTICIPANT	\N	EXCUSE	0
65405	65362	14265W	PARTICIPANT	\N	PRESENT	0
65406	65362	14119M	PARTICIPANT	\N	PRESENT	0
65407	65362	14071N	PARTICIPANT	\N	PRESENT	0
65408	65362	07032N	PARTICIPANT	\N	PRESENT	0
65409	65362	04043D	PARTICIPANT	\N	PRESENT	0
65410	65362	14271U	PARTICIPANT	\N	PRESENT	0
65463	65462	11076S	PARTICIPANT	\N	PRESENT	0
65412	65362	11093T	PARTICIPANT	\N	PRESENT	0
65413	65362	11097X	PARTICIPANT	\N	PRESENT	0
65414	65362	04045F	PARTICIPANT	\N	PRESENT	0
65415	65362	14227Q	PARTICIPANT	\N	PRESENT	0
65416	65362	01034P	PARTICIPANT	\N	PRESENT	0
65417	65362	11025F	PARTICIPANT	\N	PRESENT	0
65418	65362	11063M	PARTICIPANT	\N	PRESENT	0
65419	65362	14269B	PARTICIPANT	\N	PRESENT	0
65446	65438	92020L	PARTICIPANT	\N	PRESENT	0
65447	65438	14281W	PRESIDENT	0	PRESENT	0
65448	65438	08041T	PARTICIPANT	\N	PRESENT	0
65449	65438	07004J	PARTICIPANT	\N	PRESENT	0
65450	65438	11049P	PARTICIPANT	\N	PRESENT	0
65451	65438	14123H	PARTICIPANT	\N	PRESENT	0
65452	65438	99004R	PARTICIPANT	\N	PRESENT	0
65453	65438	04061F	PARTICIPANT	\N	PRESENT	0
66702	66701	01013J	PARTICIPANT	\N	PRESENT	0
65455	65438	11082Q	PARTICIPANT	\N	PRESENT	0
66703	66701	14167V	PARTICIPANT	\N	PRESENT	0
65457	65438	14247U	PARTICIPANT	\N	PRESENT	0
65458	65438	10015M	PARTICIPANT	\N	PRESENT	0
65459	65438	11054L	PARTICIPANT	\N	EXCUSE	0
66704	66701	14175V	PARTICIPANT	\N	PRESENT	0
65461	65438	14269B	PARTICIPANT	\N	PRESENT	0
65464	65462	04054G	PARTICIPANT	\N	PRESENT	0
65465	65462	04040A	PARTICIPANT	\N	PRESENT	0
65466	65462	08058D	PARTICIPANT	\N	PRESENT	0
65467	65462	04042C	PRESIDENT	1	PRESENT	0
65468	65462	77002U	PARTICIPANT	\N	PRESENT	0
65469	65462	98029W	PARTICIPANT	\N	PRESENT	0
65470	65462	11080N	PARTICIPANT	\N	PRESENT	0
65471	65462	11027H	PARTICIPANT	\N	PRESENT	0
65472	65462	98018T	PARTICIPANT	\N	PRESENT	0
65595	65594	11061K	PARTICIPANT	\N	PRESENT	0
65474	65462	92020L	PARTICIPANT	\N	PRESENT	0
65475	65462	95030B	PARTICIPANT	\N	PRESENT	0
65476	65462	11096W	PARTICIPANT	\N	PRESENT	0
65597	65594	11093T	PARTICIPANT	\N	PRESENT	0
65478	65462	97011G	PARTICIPANT	\N	PRESENT	0
65479	65462	08065C	PARTICIPANT	\N	PRESENT	0
65480	65462	04035D	PARTICIPANT	\N	PRESENT	0
65481	65462	07024N	PARTICIPANT	\N	PRESENT	0
65482	65462	04095R	PARTICIPANT	\N	PRESENT	0
65483	65462	14014Q	PARTICIPANT	\N	EXCUSE	0
65484	65462	11015D	PARTICIPANT	\N	PRESENT	0
65485	65462	07004J	PARTICIPANT	\N	PRESENT	0
65486	65462	95035G	PARTICIPANT	\N	PRESENT	0
65487	65462	08056B	PARTICIPANT	\N	PRESENT	0
65488	65462	14211G	PARTICIPANT	\N	PRESENT	0
65489	65462	98022P	PARTICIPANT	\N	PRESENT	0
66705	66701	04086Q	PARTICIPANT	\N	PRESENT	0
65491	65462	95037J	PARTICIPANT	\N	PRESENT	0
65492	65462	04078Q	PARTICIPANT	\N	PRESENT	0
66706	66701	11070L	PARTICIPANT	\N	PRESENT	0
66707	66701	11088W	PARTICIPANT	\N	PRESENT	0
65495	65462	04036E	PARTICIPANT	\N	PRESENT	0
65496	65462	14039A	PARTICIPANT	\N	PRESENT	0
65497	65462	04077P	PARTICIPANT	\N	PRESENT	0
66708	66701	14327T	PARTICIPANT	\N	PRESENT	0
65499	65462	92031P	PARTICIPANT	\N	PRESENT	0
65500	65462	11106F	PARTICIPANT	\N	PRESENT	0
65501	65462	14251Q	PARTICIPANT	\N	PRESENT	0
65502	65462	83042R	PARTICIPANT	\N	PRESENT	0
65503	65462	08053X	PARTICIPANT	\N	PRESENT	0
65504	65462	11082Q	PARTICIPANT	\N	PRESENT	0
65505	65462	11105E	PARTICIPANT	\N	PRESENT	0
65506	65462	14253S	PARTICIPANT	\N	PRESENT	0
65507	65462	08047A	PARTICIPANT	\N	PRESENT	0
65508	65462	14028W	PARTICIPANT	\N	PRESENT	0
65509	65462	14193X	PARTICIPANT	\N	EXCUSE	0
65510	65462	98021N	PARTICIPANT	\N	PRESENT	0
66709	66701	14199E	PARTICIPANT	\N	PRESENT	0
65512	65462	04080J	PARTICIPANT	\N	PRESENT	0
65513	65462	95059Q	PRESIDENT	0	PRESENT	0
65514	65462	86044G	PARTICIPANT	\N	PRESENT	0
65515	65462	01014K	PARTICIPANT	\N	PRESENT	0
65516	65462	11054L	PARTICIPANT	\N	PRESENT	0
65517	65462	01056V	PARTICIPANT	\N	PRESENT	0
66710	66701	08073C	PARTICIPANT	\N	PRESENT	0
65519	65462	08049C	PARTICIPANT	\N	PRESENT	0
66711	66701	11012A	PARTICIPANT	\N	PRESENT	0
66712	66701	14225N	PARTICIPANT	\N	PRESENT	0
66713	66701	01057W	PARTICIPANT	\N	PRESENT	0
66718	66717	11029K	PARTICIPANT	\N	PRESENT	0
66719	66717	95035G	PARTICIPANT	\N	PRESENT	0
66720	66717	04044E	PARTICIPANT	\N	PRESENT	0
66721	66717	96004D	PARTICIPANT	\N	PRESENT	0
66722	66717	86034E	PARTICIPANT	\N	PRESENT	0
69136	66885	01022K	PARTICIPANT	\N	PRESENT	0
69138	66885	04088S	PARTICIPANT	\N	PRESENT	0
69141	66885	14059S	PARTICIPANT	\N	PRESENT	0
69142	66885	11100Y	PARTICIPANT	\N	PRESENT	0
69144	66885	01027Q	PARTICIPANT	\N	PRESENT	0
69145	66885	14217N	PARTICIPANT	\N	PRESENT	0
69146	66885	14014Q	PARTICIPANT	\N	PRESENT	0
69147	66885	08056B	PARTICIPANT	\N	PRESENT	0
69148	66885	01024M	PARTICIPANT	\N	PRESENT	0
80244	77771	14087W	PARTICIPANT	\N	EXCUSE	0
80245	77771	14034U	PARTICIPANT	\N	PRESENT	0
80246	77771	14121F	PARTICIPANT	\N	PRESENT	0
80247	77771	95041E	PARTICIPANT	\N	PRESENT	0
80248	77771	14061L	PARTICIPANT	\N	PRESENT	0
80249	77771	04049K	PRESIDENT	0	PRESENT	0
80250	77771	01043Q	PARTICIPANT	\N	PRESENT	0
80251	77771	14265W	PARTICIPANT	\N	PRESENT	0
80252	77771	14253S	PARTICIPANT	\N	PRESENT	0
80253	77771	11090Q	PARTICIPANT	\N	PRESENT	0
80254	77771	14157T	PARTICIPANT	\N	PRESENT	0
80255	77771	11063M	PARTICIPANT	\N	PRESENT	0
80256	77771	01008M	PARTICIPANT	\N	PRESENT	0
80257	77771	10006L	PARTICIPANT	\N	PRESENT	0
80258	77771	14042U	PARTICIPANT	\N	PRESENT	0
80259	77771	08065C	PARTICIPANT	\N	PRESENT	0
80260	77771	14231L	PARTICIPANT	\N	PRESENT	0
80261	77771	08015R	PARTICIPANT	\N	PRESENT	0
80262	77771	08010L	PARTICIPANT	\N	PRESENT	0
80263	77771	14037X	PARTICIPANT	\N	PRESENT	0
80264	77771	11100Y	PARTICIPANT	\N	PRESENT	0
80265	77771	14059S	PARTICIPANT	\N	PRESENT	0
80266	77771	08053X	PARTICIPANT	\N	PRESENT	0
80267	77771	04057K	PARTICIPANT	\N	PRESENT	0
80268	77771	14147R	PARTICIPANT	\N	PRESENT	0
80269	77771	14071N	PARTICIPANT	\N	PRESENT	0
80270	57183	89017R	PARTICIPANT	\N	PRESENT	0
80271	57183	14030Q	PARTICIPANT	\N	PRESENT	0
80272	57183	14105F	PARTICIPANT	\N	PRESENT	0
80273	57183	08068F	PARTICIPANT	\N	PRESENT	0
80274	57183	04053F	PARTICIPANT	\N	PRESENT	0
80275	57183	14207L	PARTICIPANT	\N	PRESENT	0
80276	57183	14255U	PARTICIPANT	\N	PRESENT	0
80277	57183	14083S	PARTICIPANT	\N	PRESENT	0
80278	57183	04055H	PARTICIPANT	\N	PRESENT	0
80279	57183	14041T	PARTICIPANT	\N	PRESENT	0
80281	57183	04071H	PARTICIPANT	\N	PRESENT	0
80282	57183	14151M	PARTICIPANT	\N	PRESENT	0
80284	57183	14034U	PARTICIPANT	\N	PRESENT	0
80285	57183	14121F	PARTICIPANT	\N	PRESENT	0
80286	57183	95041E	PARTICIPANT	\N	PRESENT	0
80287	57183	14061L	PARTICIPANT	\N	PRESENT	0
80288	57183	04049K	PRESIDENT	0	PRESENT	0
80289	57183	01043Q	PARTICIPANT	\N	PRESENT	0
80290	57183	14265W	PARTICIPANT	\N	PRESENT	0
80291	57183	14253S	PARTICIPANT	\N	PRESENT	0
80292	57183	11090Q	PARTICIPANT	\N	PRESENT	0
80293	57183	14157T	PARTICIPANT	\N	PRESENT	0
80294	57183	11063M	PARTICIPANT	\N	PRESENT	0
80295	57183	01008M	PARTICIPANT	\N	PRESENT	0
80296	57183	10006L	PARTICIPANT	\N	PRESENT	0
80297	57183	14042U	PARTICIPANT	\N	PRESENT	0
80298	57183	08065C	PARTICIPANT	\N	PRESENT	0
80299	57183	14231L	PARTICIPANT	\N	PRESENT	0
80300	57183	08015R	PARTICIPANT	\N	PRESENT	0
80301	57183	08010L	PARTICIPANT	\N	PRESENT	0
80302	57183	14037X	PARTICIPANT	\N	PRESENT	0
80303	57183	11100Y	PARTICIPANT	\N	PRESENT	0
80304	57183	14059S	PARTICIPANT	\N	PRESENT	0
80305	57183	08053X	PARTICIPANT	\N	PRESENT	0
80306	57183	04057K	PARTICIPANT	\N	PRESENT	0
80307	57183	14147R	PARTICIPANT	\N	PRESENT	0
80308	57183	14071N	PARTICIPANT	\N	PRESENT	0
80309	57183	11094U	PARTICIPANT	\N	PRESENT	0
80310	57183	14085U	PARTICIPANT	\N	PRESENT	0
80311	57183	11032E	PARTICIPANT	\N	PRESENT	0
80312	77775	89017R	PARTICIPANT	\N	PRESENT	0
80313	77775	14030Q	PARTICIPANT	\N	PRESENT	0
80314	77775	14105F	PARTICIPANT	\N	PRESENT	0
80315	77775	08068F	PARTICIPANT	\N	PRESENT	0
80316	77775	04053F	PARTICIPANT	\N	PRESENT	0
80317	77775	14207L	PARTICIPANT	\N	PRESENT	0
80318	77775	14255U	PARTICIPANT	\N	PRESENT	0
80319	77775	14083S	PARTICIPANT	\N	PRESENT	0
80320	77775	04055H	PARTICIPANT	\N	PRESENT	0
80321	77775	14041T	PARTICIPANT	\N	PRESENT	0
80322	77775	04071H	PARTICIPANT	\N	PRESENT	0
80323	77775	14151M	PARTICIPANT	\N	PRESENT	0
80324	77775	14087W	PARTICIPANT	\N	PRESENT	0
80325	77775	14034U	PARTICIPANT	\N	PRESENT	0
80326	77775	14121F	PARTICIPANT	\N	PRESENT	0
80327	77775	95041E	PARTICIPANT	\N	PRESENT	0
80328	77775	14061L	PARTICIPANT	\N	PRESENT	0
80329	77775	04049K	PARTICIPANT	\N	PRESENT	0
80330	77775	01043Q	PARTICIPANT	\N	PRESENT	0
80331	77775	14265W	PARTICIPANT	\N	PRESENT	0
80332	77775	14253S	PARTICIPANT	\N	PRESENT	0
80333	77775	11090Q	PARTICIPANT	\N	PRESENT	0
80334	77775	14157T	PARTICIPANT	\N	PRESENT	0
80335	77775	11063M	PARTICIPANT	\N	PRESENT	0
80336	77775	01008M	PARTICIPANT	\N	PRESENT	0
80337	77775	10006L	PARTICIPANT	\N	PRESENT	0
80338	77775	14042U	PARTICIPANT	\N	PRESENT	0
80339	77775	08065C	PARTICIPANT	\N	PRESENT	0
80340	77775	14231L	PARTICIPANT	\N	PRESENT	0
80341	77775	08015R	PARTICIPANT	\N	PRESENT	0
80342	77775	08010L	PARTICIPANT	\N	PRESENT	0
80343	77775	14037X	PARTICIPANT	\N	PRESENT	0
80344	77775	14059S	PARTICIPANT	\N	PRESENT	0
80345	77775	04057K	PARTICIPANT	\N	PRESENT	0
80346	77775	14147R	PARTICIPANT	\N	PRESENT	0
80347	77775	14071N	PARTICIPANT	\N	PRESENT	0
80348	57184	14105F	PARTICIPANT	\N	PRESENT	0
80349	57184	14013P	PARTICIPANT	\N	PRESENT	0
80350	57184	14255U	PARTICIPANT	\N	PRESENT	0
80351	57184	04049K	PARTICIPANT	\N	PRESENT	0
80352	57184	14265W	PARTICIPANT	\N	PRESENT	0
80353	57184	14157T	PARTICIPANT	\N	PRESENT	0
80354	57184	11094U	PARTICIPANT	\N	PRESENT	0
80355	57184	14059S	PARTICIPANT	\N	PRESENT	0
80356	57184	01008M	PARTICIPANT	\N	PRESENT	0
80357	77771	14103D	PARTICIPANT	\N	PRESENT	0
80358	57183	14103D	PARTICIPANT	\N	PRESENT	0
80360	57183	14205J	PARTICIPANT	\N	PRESENT	0
80362	77771	14205J	PARTICIPANT	\N	PRESENT	0
80363	77775	95030B	PARTICIPANT	\N	PRESENT	0
80364	57184	14121F	PARTICIPANT	\N	PRESENT	0
80365	80198	11053K	PARTICIPANT	\N	PRESENT	0
80367	80366	11068S	PARTICIPANT	\N	PRESENT	0
80369	80368	08011M	PARTICIPANT	\N	PRESENT	0
80372	80071	11037K	PARTICIPANT	\N	EXCUSE	0
80373	80071	11112D	PARTICIPANT	\N	EXCUSE	0
80374	80071	14028W	PARTICIPANT	\N	EXCUSE	0
80390	80071	14051J	PARTICIPANT	\N	PRESENT	0
80541	80433	14097Y	PARTICIPANT	\N	PRESENT	0
80542	80433	01047U	PARTICIPANT	\N	PRESENT	0
80543	80433	87003B	PARTICIPANT	\N	PRESENT	0
80544	80433	14331P	PARTICIPANT	\N	PRESENT	0
80545	80433	04077P	PARTICIPANT	\N	PRESENT	0
80546	80433	11037K	PARTICIPANT	\N	PRESENT	0
80547	80433	11105E	PARTICIPANT	\N	PRESENT	0
80548	80433	14001X	PARTICIPANT	\N	PRESENT	0
80549	80433	14133K	PARTICIPANT	\N	PRESENT	0
80550	80433	04048J	PARTICIPANT	\N	PRESENT	0
80552	80433	08052W	PARTICIPANT	\N	PRESENT	0
80553	80433	98024R	PARTICIPANT	\N	PRESENT	0
80554	80433	95031C	PARTICIPANT	\N	PRESENT	0
80555	80433	95049N	PARTICIPANT	\N	PRESENT	0
80556	80433	14073Q	PARTICIPANT	\N	PRESENT	0
80557	80433	04092N	PARTICIPANT	\N	PRESENT	0
80558	80433	14103D	PARTICIPANT	\N	PRESENT	0
80559	80433	97011G	PARTICIPANT	\N	PRESENT	0
80560	80433	08041T	PARTICIPANT	\N	PRESENT	0
80561	80433	98018T	PARTICIPANT	\N	PRESENT	0
80562	80433	14223L	PARTICIPANT	\N	PRESENT	0
80563	80433	14215L	PARTICIPANT	\N	PRESENT	0
80564	80433	04053F	PARTICIPANT	\N	PRESENT	0
80565	80433	80027E	PARTICIPANT	\N	PRESENT	0
80566	80433	14221J	PARTICIPANT	\N	PRESENT	0
80567	80433	14065Q	PARTICIPANT	\N	PRESENT	0
80568	80433	11027H	PARTICIPANT	\N	PRESENT	0
80569	80433	11103C	PARTICIPANT	\N	PRESENT	0
80570	80433	07034Q	PARTICIPANT	\N	PRESENT	0
80571	80433	14231L	PARTICIPANT	\N	PRESENT	0
80572	80433	14071N	PARTICIPANT	\N	PRESENT	0
80573	80433	04044E	PARTICIPANT	\N	PRESENT	0
80574	80433	00003C	PARTICIPANT	\N	PRESENT	0
80539	80433	89029V	PARTICIPANT	\N	PRESENT	0
80540	80433	05008E	PARTICIPANT	\N	PRESENT	0
80575	80433	98035U	PARTICIPANT	\N	PRESENT	0
80576	80433	14018U	PARTICIPANT	\N	PRESENT	0
80577	80433	14085U	PARTICIPANT	\N	PRESENT	0
80578	80433	11036J	PARTICIPANT	\N	PRESENT	0
80579	80433	11011M	PARTICIPANT	\N	PRESENT	0
80580	80433	98023Q	PARTICIPANT	\N	PRESENT	0
80581	80433	11066Q	PARTICIPANT	\N	PRESENT	0
80582	80433	80013X	PARTICIPANT	\N	PRESENT	0
80583	80433	14017T	PARTICIPANT	\N	PRESENT	0
80584	80433	14059S	PARTICIPANT	\N	PRESENT	0
65431	65430	11039M	PARTICIPANT	\N	PRESENT	0
65432	65430	98042T	PARTICIPANT	\N	PRESENT	0
65433	65430	01019Q	PARTICIPANT	\N	PRESENT	0
65435	65434	11039M	PARTICIPANT	\N	PRESENT	0
65436	65434	98042T	PARTICIPANT	\N	PRESENT	0
65437	65434	01019Q	PARTICIPANT	\N	PRESENT	0
66753	66752	14209N	PARTICIPANT	\N	PRESENT	0
66755	66754	14133K	PARTICIPANT	\N	PRESENT	0
66756	66754	14097Y	PARTICIPANT	\N	PRESENT	0
66758	66757	14133K	PARTICIPANT	\N	PRESENT	0
66759	66757	14097Y	PARTICIPANT	\N	PRESENT	0
66761	66760	14133K	PARTICIPANT	\N	PRESENT	0
66762	66760	14097Y	PARTICIPANT	\N	PRESENT	0
67140	66880	14187A	PARTICIPANT	\N	PRESENT	0
67141	66880	92031P	PARTICIPANT	\N	PRESENT	0
67142	66880	08034U	PARTICIPANT	\N	PRESENT	0
67143	66880	04035D	PARTICIPANT	\N	PRESENT	0
67144	66880	13002U	PARTICIPANT	\N	PRESENT	0
67145	66880	08060W	PARTICIPANT	\N	PRESENT	0
67191	66880	07032N	PARTICIPANT	\N	PRESENT	0
67157	66880	14089Y	PARTICIPANT	\N	PRESENT	0
67148	66880	08051V	PARTICIPANT	\N	PRESENT	0
67193	66880	11088W	PARTICIPANT	\N	PRESENT	0
67150	66880	11100Y	PARTICIPANT	\N	PRESENT	0
67151	66880	14255U	PARTICIPANT	\N	PRESENT	0
67209	66880	14069U	PARTICIPANT	\N	PRESENT	0
67153	66880	14157T	PARTICIPANT	\N	PRESENT	0
67216	66880	11026G	PARTICIPANT	\N	PRESENT	0
67211	66880	11103C	PARTICIPANT	\N	PRESENT	0
67156	66880	08047A	PARTICIPANT	\N	PRESENT	0
67158	66880	14199E	PARTICIPANT	\N	PRESENT	0
67162	66880	14061L	PARTICIPANT	\N	PRESENT	0
67189	66880	08048B	PARTICIPANT	\N	PRESENT	0
67161	66880	11071M	PARTICIPANT	\N	PRESENT	0
67186	66880	14217N	PARTICIPANT	\N	PRESENT	0
67188	66880	97011G	PARTICIPANT	\N	PRESENT	0
67165	66880	14079W	PARTICIPANT	\N	PRESENT	0
67187	66880	14249W	PARTICIPANT	\N	PRESENT	0
67214	66880	14273W	PARTICIPANT	\N	PRESENT	0
67168	66880	14151M	PARTICIPANT	\N	PRESENT	0
67195	66880	04045F	PARTICIPANT	\N	PRESENT	0
67170	66880	11065P	PARTICIPANT	\N	PRESENT	0
67171	66880	04067M	PARTICIPANT	\N	PRESENT	0
67172	66880	04061F	PARTICIPANT	\N	PRESENT	0
67173	66880	14205J	PARTICIPANT	\N	PRESENT	0
67192	66880	14265W	PARTICIPANT	\N	PRESENT	0
67175	66880	07024N	PARTICIPANT	\N	PRESENT	0
67176	66880	98021N	PARTICIPANT	\N	PRESENT	0
67177	66880	04057K	PARTICIPANT	\N	PRESENT	0
67190	66880	04055H	PARTICIPANT	\N	PRESENT	0
67179	66880	14193X	PARTICIPANT	\N	PRESENT	0
67180	66880	04043D	PARTICIPANT	\N	PRESENT	0
67210	66880	11101A	PARTICIPANT	\N	PRESENT	0
67208	66880	14093U	PARTICIPANT	\N	PRESENT	0
67183	66880	08049C	PARTICIPANT	\N	PRESENT	0
67184	66880	01057W	PARTICIPANT	\N	PRESENT	0
67185	66880	14267Y	PARTICIPANT	\N	PRESENT	0
67194	66880	04092N	PARTICIPANT	\N	PRESENT	0
67196	66880	11111C	PARTICIPANT	\N	PRESENT	0
67197	66880	14179A	PARTICIPANT	\N	PRESENT	0
67198	66880	14195A	PARTICIPANT	\N	PRESENT	0
67203	66880	01013J	PARTICIPANT	\N	PRESENT	0
67201	66880	11027H	PARTICIPANT	\N	PRESENT	0
67202	66880	11064N	PARTICIPANT	\N	PRESENT	0
67204	66880	14219Q	PARTICIPANT	\N	PRESENT	0
67205	66880	14103D	PARTICIPANT	\N	PRESENT	0
67206	66880	11085T	PARTICIPANT	\N	PRESENT	0
67207	66880	05008E	PARTICIPANT	\N	PRESENT	0
67213	66880	08068F	PARTICIPANT	\N	PRESENT	0
67215	66880	11095V	PARTICIPANT	\N	PRESENT	0
67516	66605	86034E	PARTICIPANT	\N	PRESENT	0
67517	66605	01013J	PARTICIPANT	\N	PRESENT	0
67518	66605	14263U	PARTICIPANT	\N	PRESENT	0
67519	66605	92018S	PARTICIPANT	\N	PRESENT	0
67520	66605	11031D	PARTICIPANT	\N	PRESENT	0
67521	66605	12041X	PARTICIPANT	\N	PRESENT	0
67522	66605	01059Y	PARTICIPANT	\N	PRESENT	0
67524	66605	08016S	PARTICIPANT	\N	PRESENT	0
67525	66605	98035U	PARTICIPANT	\N	PRESENT	0
67526	66605	01016M	PARTICIPANT	\N	PRESENT	0
67527	66605	04056J	PARTICIPANT	\N	PRESENT	0
67528	66605	11039M	PARTICIPANT	\N	PRESENT	0
67529	66605	98053W	PARTICIPANT	\N	PRESENT	0
67530	66605	04054G	PARTICIPANT	\N	PRESENT	0
67531	66605	11040E	PARTICIPANT	\N	PRESENT	0
67532	66605	14013P	PARTICIPANT	\N	PRESENT	0
67533	66605	11063M	PARTICIPANT	\N	PRESENT	0
67534	66605	14235Q	PARTICIPANT	\N	PRESENT	0
67535	66605	14133K	PARTICIPANT	\N	PRESENT	0
67536	66605	01044R	PARTICIPANT	\N	PRESENT	0
67537	66605	11029K	PARTICIPANT	\N	PRESENT	0
67538	66605	11083R	PARTICIPANT	\N	PRESENT	0
67539	66605	11076S	PARTICIPANT	\N	PRESENT	0
67540	66605	01008M	PARTICIPANT	\N	PRESENT	0
67541	66605	05008E	PARTICIPANT	\N	PRESENT	0
67542	66605	04067M	PARTICIPANT	\N	PRESENT	0
67543	66605	11030C	PARTICIPANT	\N	PRESENT	0
67545	66605	96004D	PARTICIPANT	\N	PRESENT	0
67546	66605	01060R	PARTICIPANT	\N	PRESENT	0
67547	66605	14247U	PARTICIPANT	\N	PRESENT	0
67548	66605	14069U	PARTICIPANT	\N	PRESENT	0
67549	66605	14055N	PARTICIPANT	\N	PRESENT	0
67550	66605	14105F	PARTICIPANT	\N	PRESENT	0
67551	66605	08021P	PARTICIPANT	\N	PRESENT	0
67552	66605	14175V	PARTICIPANT	\N	PRESENT	0
67553	66605	04047H	PARTICIPANT	\N	PRESENT	0
67554	66605	11101A	PARTICIPANT	\N	PRESENT	0
67555	66605	04042C	PARTICIPANT	\N	PRESENT	0
67556	66605	89017R	PARTICIPANT	\N	PRESENT	0
67557	66605	14053L	PARTICIPANT	\N	PRESENT	0
67558	66605	77002U	PARTICIPANT	\N	PRESENT	0
67560	66605	01046T	PARTICIPANT	\N	PRESENT	0
67561	66605	95015C	PARTICIPANT	\N	PRESENT	0
67562	66605	04078Q	PARTICIPANT	\N	PRESENT	0
67563	66605	88008L	PARTICIPANT	\N	PRESENT	0
67564	66605	08031R	PARTICIPANT	\N	PRESENT	0
67565	66605	08049C	PARTICIPANT	\N	PRESENT	0
67566	66605	11012A	PARTICIPANT	\N	PRESENT	0
67567	66605	14018U	PARTICIPANT	\N	PRESENT	0
67568	66605	14261S	PARTICIPANT	\N	PRESENT	0
67569	66605	01003G	PARTICIPANT	\N	PRESENT	0
67570	66605	14201E	PARTICIPANT	\N	PRESENT	0
67571	66605	11044J	PARTICIPANT	\N	PRESENT	0
67572	66605	95049N	PARTICIPANT	\N	PRESENT	0
67573	66605	01034P	PARTICIPANT	\N	PRESENT	0
67574	66605	11094U	PARTICIPANT	\N	PRESENT	0
67575	66605	11053K	PARTICIPANT	\N	PRESENT	0
67576	66605	14329V	PARTICIPANT	\N	PRESENT	0
67577	66605	11080N	PARTICIPANT	\N	PRESENT	0
67578	66605	11096W	PARTICIPANT	\N	PRESENT	0
67579	66605	14038Y	PARTICIPANT	\N	PRESENT	0
67580	66605	14239U	PARTICIPANT	\N	PRESENT	0
67581	66605	98022P	PARTICIPANT	\N	PRESENT	0
67582	66605	04040A	PARTICIPANT	\N	PRESENT	0
67583	66605	04055H	PARTICIPANT	\N	PRESENT	0
67584	66605	04038G	PARTICIPANT	\N	PRESENT	0
67585	66605	11093T	PARTICIPANT	\N	PRESENT	0
67586	66605	11064N	PARTICIPANT	\N	PRESENT	0
67587	66605	98023Q	PARTICIPANT	\N	PRESENT	0
67588	66605	11070L	PARTICIPANT	\N	PRESENT	0
67589	66605	04086Q	PARTICIPANT	\N	PRESENT	0
67590	66605	14079W	PARTICIPANT	\N	PRESENT	0
67591	66605	98018T	PARTICIPANT	\N	PRESENT	0
67592	66605	14042U	PARTICIPANT	\N	PRESENT	0
67593	66605	11088W	PARTICIPANT	\N	PRESENT	0
67594	66605	14219Q	PARTICIPANT	\N	PRESENT	0
67595	66605	98024R	PARTICIPANT	\N	PRESENT	0
67597	66605	10006L	PARTICIPANT	\N	PRESENT	0
67598	66605	14030Q	PARTICIPANT	\N	PRESENT	0
67599	66605	08022Q	PARTICIPANT	\N	PRESENT	0
67600	66605	14221J	PARTICIPANT	\N	PRESENT	0
67601	66605	11082Q	PARTICIPANT	\N	PRESENT	0
67602	66605	11111C	PARTICIPANT	\N	PRESENT	0
67603	66605	14073Q	PARTICIPANT	\N	PRESENT	0
67604	66605	14089Y	PARTICIPANT	\N	PRESENT	0
67605	66605	14217N	PARTICIPANT	\N	PRESENT	0
67606	66605	14179A	PARTICIPANT	\N	PRESENT	0
67607	66605	14205J	PARTICIPANT	\N	PRESENT	0
67608	66605	14231L	PARTICIPANT	\N	PRESENT	0
67609	66605	01027Q	PARTICIPANT	\N	PRESENT	0
67610	66605	14083S	PARTICIPANT	\N	PRESENT	0
67611	66605	04071H	PARTICIPANT	\N	PRESENT	0
67612	66605	07004J	PARTICIPANT	\N	PRESENT	0
75286	75285	88008L	PARTICIPANT	\N	PRESENT	0
75287	75285	04061F	PARTICIPANT	\N	PRESENT	0
75313	75304	88008L	PARTICIPANT	\N	PRESENT	0
75314	75304	04061F	PARTICIPANT	\N	PRESENT	0
75317	75316	88008L	PARTICIPANT	\N	PRESENT	0
75318	75316	04061F	PARTICIPANT	\N	PRESENT	0
75323	75322	88008L	PARTICIPANT	\N	PRESENT	0
75324	75322	04061F	PARTICIPANT	\N	PRESENT	0
75330	75329	88008L	PARTICIPANT	\N	PRESENT	0
75332	75329	04061F	PARTICIPANT	\N	PRESENT	0
75336	75335	88008L	PARTICIPANT	\N	PRESENT	0
75337	75335	04061F	PARTICIPANT	\N	PRESENT	0
75343	75341	88008L	PARTICIPANT	\N	PRESENT	0
75344	75341	04061F	PARTICIPANT	\N	PRESENT	0
75347	75346	88008L	PARTICIPANT	\N	PRESENT	0
75349	75346	04061F	PARTICIPANT	\N	PRESENT	0
75617	75614	07029T	PARTICIPANT	\N	PRESENT	0
75634	75632	07029T	PARTICIPANT	\N	PRESENT	0
75696	75695	01057W	PARTICIPANT	\N	PRESENT	0
75698	75695	14225N	PARTICIPANT	\N	PRESENT	0
75711	75709	11040E	PARTICIPANT	\N	PRESENT	0
75730	75725	11085T	PARTICIPANT	\N	PRESENT	0
76492	76491	05008E	PRESIDENT	0	PRESENT	0
76493	76491	14065Q	PARTICIPANT	\N	PRESENT	0
76494	76491	04047H	PARTICIPANT	\N	PRESENT	0
76495	76491	04038G	PARTICIPANT	\N	PRESENT	0
76496	76491	11056N	PARTICIPANT	\N	PRESENT	0
76497	76491	14259Y	PARTICIPANT	\N	PRESENT	0
76498	76491	11035H	PARTICIPANT	\N	PRESENT	0
76499	76491	14041T	PARTICIPANT	\N	PRESENT	0
76500	76491	01024M	PARTICIPANT	\N	PRESENT	0
76501	76491	14215L	PARTICIPANT	\N	EXCUSE	0
76502	76491	11049P	PARTICIPANT	\N	PRESENT	0
76503	76491	01007L	PARTICIPANT	\N	PRESENT	0
76504	76491	11084S	PARTICIPANT	\N	PRESENT	0
76505	76491	11026G	PARTICIPANT	\N	PRESENT	0
76506	76491	14001X	PARTICIPANT	\N	PRESENT	0
76507	76491	14147R	PARTICIPANT	\N	PRESENT	0
76508	76491	95049N	PARTICIPANT	\N	PRESENT	0
76509	76491	11072N	PARTICIPANT	\N	PRESENT	0
76510	76491	07034Q	PARTICIPANT	\N	PRESENT	0
76511	76491	04074L	PARTICIPANT	\N	PRESENT	0
76512	76491	95063L	PARTICIPANT	\N	PRESENT	0
76513	76491	01028R	PARTICIPANT	\N	PRESENT	0
76514	76491	04056J	PARTICIPANT	\N	PRESENT	0
76515	76491	14275Y	PARTICIPANT	\N	PRESENT	0
76516	76491	11037K	PARTICIPANT	\N	PRESENT	0
76517	76491	01047U	PARTICIPANT	\N	PRESENT	0
76518	76491	92045V	PARTICIPANT	\N	PRESENT	0
76519	76491	95067Q	PARTICIPANT	\N	PRESENT	0
82432	82431	89017R	PARTICIPANT	\N	PRESENT	0
82433	82431	01031L	PRESIDENT	0	PRESENT	0
82434	82431	05004A	PARTICIPANT	\N	PRESENT	0
82435	82431	01013J	PARTICIPANT	\N	PRESENT	0
82436	82431	08014Q	PARTICIPANT	\N	PRESENT	0
82437	82431	14083S	PARTICIPANT	\N	PRESENT	0
82438	82431	14085U	PARTICIPANT	\N	PRESENT	0
82439	82431	11042G	PARTICIPANT	\N	PRESENT	0
82441	82431	88008L	PARTICIPANT	\N	PRESENT	0
82442	82431	04086Q	PARTICIPANT	\N	EXCUSE	0
82500	82431	11088W	PARTICIPANT	\N	PRESENT	0
82501	82431	01027Q	PARTICIPANT	\N	PRESENT	0
82502	82431	04071H	PARTICIPANT	\N	PRESENT	0
82503	82431	11074Q	PARTICIPANT	\N	PRESENT	0
82504	82431	11083R	PARTICIPANT	\N	PRESENT	0
82505	82431	01057W	PARTICIPANT	\N	PRESENT	0
82506	82431	08069G	PARTICIPANT	\N	PRESENT	0
82507	82431	99004R	PARTICIPANT	\N	PRESENT	0
82509	82431	04061F	PARTICIPANT	\N	PRESENT	0
82510	82431	14159V	PARTICIPANT	\N	PRESENT	0
82511	82431	07029T	PARTICIPANT	\N	PRESENT	0
82512	82431	08010L	PARTICIPANT	\N	PRESENT	0
82513	82431	08034U	PARTICIPANT	\N	PRESENT	0
82514	82431	98046X	PARTICIPANT	\N	PRESENT	0
82515	82431	11085T	PARTICIPANT	\N	PRESENT	0
82516	82431	08011M	PARTICIPANT	\N	EXCUSE	0
82517	82431	08073C	PARTICIPANT	\N	PRESENT	0
82518	82431	08061X	PARTICIPANT	\N	PRESENT	0
82519	82431	01016M	PARTICIPANT	\N	PRESENT	0
82520	82431	11012A	PARTICIPANT	\N	PRESENT	0
82521	82431	11057P	PARTICIPANT	\N	PRESENT	0
82522	82431	14173T	PARTICIPANT	\N	PRESENT	0
82523	82431	04034C	PARTICIPANT	\N	PRESENT	0
82624	82431	11048N	PARTICIPANT	\N	PRESENT	0
82768	80435	01007L	PARTICIPANT	\N	PRESENT	0
82891	80435	11040E	PARTICIPANT	\N	PRESENT	0
82892	80435	04085P	PARTICIPANT	\N	PRESENT	0
82893	80435	11098Y	PARTICIPANT	\N	PRESENT	0
82894	80435	01022K	PARTICIPANT	\N	PRESENT	0
82895	80435	80013X	PARTICIPANT	\N	PRESENT	0
82896	80435	14107H	PARTICIPANT	\N	PRESENT	0
82897	80435	08014Q	PARTICIPANT	\N	PRESENT	0
82898	80435	83047W	PARTICIPANT	\N	PRESENT	0
82899	80435	11036J	PARTICIPANT	\N	PRESENT	0
82900	80435	08060W	PARTICIPANT	\N	PRESENT	0
82901	80435	14207L	PARTICIPANT	\N	PRESENT	0
82902	80435	14103D	PARTICIPANT	\N	PRESENT	0
82903	80435	11111C	PARTICIPANT	\N	PRESENT	0
82904	80435	07004J	PARTICIPANT	\N	PRESENT	0
82905	80435	01008M	PARTICIPANT	\N	PRESENT	0
82906	80435	07029T	PARTICIPANT	\N	PRESENT	0
82907	80435	04088S	PARTICIPANT	\N	PRESENT	0
82908	80435	11011M	PARTICIPANT	\N	PRESENT	0
82909	80435	14033T	PARTICIPANT	\N	PRESENT	0
82910	80435	14249W	PARTICIPANT	\N	PRESENT	0
82911	80435	14265W	PARTICIPANT	\N	PRESENT	0
82912	80435	11100Y	PARTICIPANT	\N	PRESENT	0
82914	80435	11043H	PARTICIPANT	\N	PRESENT	0
82915	80435	14257W	PARTICIPANT	\N	PRESENT	0
82916	80435	14197C	PARTICIPANT	\N	PRESENT	0
82917	80435	11112D	PARTICIPANT	\N	PRESENT	0
82918	80435	11099A	PARTICIPANT	\N	PRESENT	0
82919	80435	13002U	PARTICIPANT	\N	PRESENT	0
82920	80435	14030Q	PARTICIPANT	\N	PRESENT	0
82921	80435	14083S	PARTICIPANT	\N	PRESENT	0
82922	80435	88008L	PARTICIPANT	\N	PRESENT	0
82923	80435	14105F	PARTICIPANT	\N	PRESENT	0
82924	80435	14037X	PARTICIPANT	\N	PRESENT	0
82925	80435	08015R	PARTICIPANT	\N	PRESENT	0
82926	80435	14213J	PARTICIPANT	\N	PRESENT	0
82927	80435	14097Y	PARTICIPANT	\N	PRESENT	0
82928	80435	14121F	PARTICIPANT	\N	PRESENT	0
82930	80435	08039A	PARTICIPANT	\N	PRESENT	0
82931	80435	14237S	PARTICIPANT	\N	PRESENT	0
82933	80435	14273W	PARTICIPANT	\N	PRESENT	0
82942	80435	14147R	PARTICIPANT	\N	PRESENT	0
82943	80435	14221J	PARTICIPANT	\N	PRESENT	0
82944	80435	14263U	PARTICIPANT	\N	PRESENT	0
82945	80435	08043V	PARTICIPANT	\N	PRESENT	0
82946	80435	14119M	PARTICIPANT	\N	PRESENT	0
82947	80435	08034U	PARTICIPANT	\N	PRESENT	0
82950	80435	90003B	PARTICIPANT	\N	PRESENT	0
82951	80435	97011G	PARTICIPANT	\N	PRESENT	0
82952	80435	11104D	PARTICIPANT	\N	PRESENT	0
82953	80435	01003G	PARTICIPANT	\N	PRESENT	0
82954	80435	11107G	PARTICIPANT	\N	PRESENT	0
82955	80435	14109K	PARTICIPANT	\N	PRESENT	0
82956	80435	08069G	PARTICIPANT	\N	PRESENT	0
82957	80435	11088W	PARTICIPANT	\N	PRESENT	0
82958	80435	87003B	PARTICIPANT	\N	PRESENT	0
82959	80435	14223L	PARTICIPANT	\N	PRESENT	0
82960	80435	95030B	PARTICIPANT	\N	PRESENT	0
82961	80435	04048J	PARTICIPANT	\N	PRESENT	0
82962	80435	89017R	PARTICIPANT	\N	PRESENT	0
82963	80435	08017T	PARTICIPANT	\N	PRESENT	0
82964	80435	98046X	PARTICIPANT	\N	PRESENT	0
82965	80435	14014Q	PARTICIPANT	\N	PRESENT	0
82966	80435	11066Q	PARTICIPANT	\N	PRESENT	0
82967	80435	14013P	PARTICIPANT	\N	PRESENT	0
82968	80435	08068F	PARTICIPANT	\N	PRESENT	0
82969	80435	11095V	PARTICIPANT	\N	PRESENT	0
82970	80435	11014C	PARTICIPANT	\N	PRESENT	0
82971	80435	01016M	PARTICIPANT	\N	PRESENT	0
82972	80435	11029K	PARTICIPANT	\N	PRESENT	0
82973	80435	14031R	PARTICIPANT	\N	PRESENT	0
82974	80435	08019V	PARTICIPANT	\N	PRESENT	0
82975	80435	04074L	PARTICIPANT	\N	PRESENT	0
82976	80435	08010L	PARTICIPANT	\N	PRESENT	0
82977	80435	11097X	PARTICIPANT	\N	PRESENT	0
82978	80435	00003C	PARTICIPANT	\N	PRESENT	0
82979	80435	04059M	PARTICIPANT	\N	PRESENT	0
82981	80435	01041N	PARTICIPANT	\N	PRESENT	0
82987	80435	14229S	PARTICIPANT	\N	PRESENT	0
82989	80435	12041X	PARTICIPANT	\N	PRESENT	0
82996	80435	11103C	PARTICIPANT	\N	PRESENT	0
82997	80435	14195A	PARTICIPANT	\N	PRESENT	0
82998	80435	08049C	PARTICIPANT	\N	PRESENT	0
83000	80435	11048N	PARTICIPANT	\N	PRESENT	0
83001	80435	14173T	PARTICIPANT	\N	PRESENT	0
69150	66885	11099A	PARTICIPANT	\N	PRESENT	0
69151	66885	11090Q	PARTICIPANT	\N	PRESENT	0
69152	66885	14159V	PARTICIPANT	\N	PRESENT	0
69153	66885	14083S	PARTICIPANT	\N	PRESENT	0
69159	66885	14219Q	PARTICIPANT	\N	PRESENT	0
69155	66885	11097X	PARTICIPANT	\N	PRESENT	0
69156	66885	01007L	PARTICIPANT	\N	PRESENT	0
69157	66885	14235Q	PARTICIPANT	\N	PRESENT	0
69158	66885	01016M	PARTICIPANT	\N	PRESENT	0
69160	66885	95049N	PARTICIPANT	\N	PRESENT	0
69161	66885	08068F	PARTICIPANT	\N	PRESENT	0
69162	66885	14073Q	PARTICIPANT	\N	PRESENT	0
69163	66885	14034U	PARTICIPANT	\N	PRESENT	0
69164	66885	14103D	PARTICIPANT	\N	PRESENT	0
69165	66885	14237S	PARTICIPANT	\N	PRESENT	0
69166	66885	14061L	PARTICIPANT	\N	PRESENT	0
69167	66885	11110B	PARTICIPANT	\N	PRESENT	0
69168	66885	14249W	PARTICIPANT	\N	PRESENT	0
69169	66885	14207L	PARTICIPANT	\N	PRESENT	0
69170	66885	14097Y	PARTICIPANT	\N	PRESENT	0
69171	66885	11061K	PARTICIPANT	\N	PRESENT	0
69547	68964	98053W	PARTICIPANT	\N	PRESENT	0
69548	68964	11043H	PARTICIPANT	\N	PRESENT	0
69549	68964	04088S	PARTICIPANT	\N	PRESENT	0
69550	68964	11091R	PARTICIPANT	\N	PRESENT	0
69551	68964	14105F	PARTICIPANT	\N	PRESENT	0
69552	68964	14331P	PARTICIPANT	\N	PRESENT	0
69553	68964	14327T	PARTICIPANT	\N	PRESENT	0
69554	68964	01057W	PARTICIPANT	\N	PRESENT	0
69555	68964	14103D	PARTICIPANT	\N	PRESENT	0
69556	68964	14063N	PARTICIPANT	\N	PRESENT	0
69557	68964	11049P	PARTICIPANT	\N	PRESENT	0
69558	68964	14111D	PARTICIPANT	\N	PRESENT	0
69559	68964	08069G	PARTICIPANT	\N	PRESENT	0
69560	68964	14071N	PARTICIPANT	\N	PRESENT	0
69561	68964	86044G	PARTICIPANT	\N	PRESENT	0
69562	68964	11034G	PARTICIPANT	\N	PRESENT	0
69563	68964	01058X	PARTICIPANT	\N	PRESENT	0
69564	68964	11037K	PARTICIPANT	\N	PRESENT	0
69565	68964	11103C	PARTICIPANT	\N	PRESENT	0
69566	68964	01007L	PARTICIPANT	\N	PRESENT	0
69567	68964	05008E	PARTICIPANT	\N	PRESENT	0
69568	68964	11083R	PARTICIPANT	\N	PRESENT	0
69569	68964	14273W	PARTICIPANT	\N	PRESENT	0
69570	68964	01028R	PARTICIPANT	\N	PRESENT	0
69571	68964	14263U	PARTICIPANT	\N	PRESENT	0
69572	68964	14157T	PARTICIPANT	\N	PRESENT	0
69573	68964	14073Q	PARTICIPANT	\N	PRESENT	0
69574	68964	08025T	PARTICIPANT	\N	PRESENT	0
69575	68964	01024M	PARTICIPANT	\N	PRESENT	0
69576	68964	11114F	PARTICIPANT	\N	PRESENT	0
69577	68964	07004J	PARTICIPANT	\N	PRESENT	0
69578	68964	08014Q	PARTICIPANT	\N	PRESENT	0
69579	68964	01027Q	PARTICIPANT	\N	PRESENT	0
69580	68964	14135M	PARTICIPANT	\N	PRESENT	0
69581	68964	97011G	PARTICIPANT	\N	PRESENT	0
69582	68964	01060R	PARTICIPANT	\N	PRESENT	0
69583	68964	95063L	PARTICIPANT	\N	PRESENT	0
69584	68964	87003B	PARTICIPANT	\N	PRESENT	0
69588	68964	14087W	PARTICIPANT	\N	PRESENT	0
69586	68964	08028W	PARTICIPANT	\N	PRESENT	0
69587	68964	11095V	PARTICIPANT	\N	PRESENT	0
69589	68964	11059R	PARTICIPANT	\N	PRESENT	0
69590	68964	01022K	PARTICIPANT	\N	PRESENT	0
69591	68964	14089Y	PARTICIPANT	\N	PRESENT	0
69592	68964	14237S	PARTICIPANT	\N	PRESENT	0
69593	68964	04038G	PARTICIPANT	\N	PRESENT	0
69594	68964	14215L	PARTICIPANT	\N	PRESENT	0
69595	68964	14041T	PARTICIPANT	\N	PRESENT	0
69596	68964	14069U	PARTICIPANT	\N	PRESENT	0
69597	68964	01008M	PARTICIPANT	\N	PRESENT	0
69598	68964	11100Y	PARTICIPANT	\N	PRESENT	0
69599	68964	14147R	PARTICIPANT	\N	PRESENT	0
69600	68964	14199E	PARTICIPANT	\N	PRESENT	0
69601	68964	14173T	PARTICIPANT	\N	PRESENT	0
69602	68964	14038Y	PARTICIPANT	\N	PRESENT	0
69603	68964	11107G	PARTICIPANT	\N	PRESENT	0
69604	68964	11012A	PARTICIPANT	\N	PRESENT	0
69605	68964	11040E	PARTICIPANT	\N	PRESENT	0
69606	68964	14159V	PARTICIPANT	\N	PRESENT	0
69607	68964	14219Q	PARTICIPANT	\N	PRESENT	0
69608	68964	14223L	PARTICIPANT	\N	PRESENT	0
69609	68964	14133K	PARTICIPANT	\N	PRESENT	0
69610	68964	08015R	PARTICIPANT	\N	PRESENT	0
69611	68964	08062Y	PARTICIPANT	\N	PRESENT	0
69612	68964	08065C	PARTICIPANT	\N	PRESENT	0
69613	68964	11036J	PARTICIPANT	\N	PRESENT	0
69614	68964	14121F	PARTICIPANT	\N	PRESENT	0
69615	68964	14225N	PARTICIPANT	\N	PRESENT	0
69616	68964	11105E	PARTICIPANT	\N	PRESENT	0
69617	68964	08051V	PARTICIPANT	\N	PRESENT	0
69618	68964	08041T	PARTICIPANT	\N	PRESENT	0
69619	68964	14267Y	PARTICIPANT	\N	PRESENT	0
69620	68964	07026Q	PARTICIPANT	\N	PRESENT	0
69621	68964	01013J	PARTICIPANT	\N	PRESENT	0
69622	68964	01015L	PARTICIPANT	\N	PRESENT	0
69623	68964	14205J	PARTICIPANT	\N	PRESENT	0
69624	68964	92015P	PARTICIPANT	\N	PRESENT	0
69625	68964	14257W	PARTICIPANT	\N	PRESENT	0
69626	68964	08055A	PARTICIPANT	\N	PRESENT	0
69627	68964	90003B	PARTICIPANT	\N	PRESENT	0
69628	68964	14231L	PARTICIPANT	\N	PRESENT	0
69629	68964	14265W	PARTICIPANT	\N	PRESENT	0
69630	68964	13002U	PARTICIPANT	\N	PRESENT	0
69631	68964	04085P	PARTICIPANT	\N	PRESENT	0
69632	68964	11042G	PARTICIPANT	\N	PRESENT	0
69633	68964	14201E	PARTICIPANT	\N	PRESENT	0
69634	68964	07034Q	PARTICIPANT	\N	PRESENT	0
69635	68964	04048J	PARTICIPANT	\N	PRESENT	0
69636	68964	14037X	PARTICIPANT	\N	PRESENT	0
69637	68964	14061L	PARTICIPANT	\N	PRESENT	0
69638	68964	14247U	PARTICIPANT	\N	PRESENT	0
69639	68964	04095R	PARTICIPANT	\N	PRESENT	0
69640	68964	11098Y	PARTICIPANT	\N	PRESENT	0
69641	68964	14187A	PARTICIPANT	\N	PRESENT	0
69642	68964	14053L	PARTICIPANT	\N	PRESENT	0
69643	68964	10015M	PARTICIPANT	\N	PRESENT	0
69646	68964	95041E	PARTICIPANT	\N	PRESENT	0
69647	68964	14227Q	PARTICIPANT	\N	PRESENT	0
69648	68964	11020A	PARTICIPANT	\N	PRESENT	0
69649	68964	01044R	PARTICIPANT	\N	PRESENT	0
69650	68964	89029V	PARTICIPANT	\N	PRESENT	0
69651	68964	98042T	PARTICIPANT	\N	PRESENT	0
69652	68964	11053K	PARTICIPANT	\N	PRESENT	0
69653	68964	14034U	PARTICIPANT	\N	PRESENT	0
69654	68964	98022P	PARTICIPANT	\N	PRESENT	0
69655	68964	14085U	PARTICIPANT	\N	PRESENT	0
69656	68964	92045V	PARTICIPANT	\N	PRESENT	0
69657	68964	14031R	PARTICIPANT	\N	PRESENT	0
69658	68964	14030Q	PARTICIPANT	\N	PRESENT	0
69659	68964	08049C	PARTICIPANT	\N	PRESENT	0
69770	68966	86034E	PARTICIPANT	\N	PRESENT	0
69771	68966	01059Y	PARTICIPANT	\N	PRESENT	0
69772	68966	11031D	PARTICIPANT	\N	PRESENT	0
69773	68966	07026Q	PARTICIPANT	\N	PRESENT	0
69774	68966	01015L	PARTICIPANT	\N	PRESENT	0
69775	68966	11040E	PARTICIPANT	\N	PRESENT	0
69776	68966	92018S	PARTICIPANT	\N	PRESENT	0
69777	68966	14263U	PARTICIPANT	\N	PRESENT	0
69778	68966	01013J	PARTICIPANT	\N	PRESENT	0
69779	68966	11034G	PARTICIPANT	\N	PRESENT	0
69780	68966	11098Y	PARTICIPANT	\N	PRESENT	0
69781	68966	14013P	PARTICIPANT	\N	PRESENT	0
69782	68966	95062K	PARTICIPANT	\N	PRESENT	0
69783	68966	11076S	PARTICIPANT	\N	PRESENT	0
69784	68966	01044R	PARTICIPANT	\N	PRESENT	0
69785	68966	14018U	PARTICIPANT	\N	PRESENT	0
69786	68966	11096W	PARTICIPANT	\N	PRESENT	0
69787	68966	11012A	PARTICIPANT	\N	PRESENT	0
69788	68966	08051V	PARTICIPANT	\N	PRESENT	0
69789	68966	01046T	PARTICIPANT	\N	PRESENT	0
69790	68966	04078Q	PARTICIPANT	\N	PRESENT	0
69791	68966	88008L	PARTICIPANT	\N	PRESENT	0
69792	68966	01027Q	PARTICIPANT	\N	PRESENT	0
69793	68966	04041B	PARTICIPANT	\N	PRESENT	0
69794	68966	14247U	PARTICIPANT	\N	PRESENT	0
69795	68966	14253S	PARTICIPANT	\N	PRESENT	0
69796	68966	98022P	PARTICIPANT	\N	PRESENT	0
69797	68966	14239U	PARTICIPANT	\N	PRESENT	0
69798	68966	14111D	PARTICIPANT	\N	PRESENT	0
69799	68966	11063M	PARTICIPANT	\N	PRESENT	0
69800	68966	01058X	PARTICIPANT	\N	PRESENT	0
69801	68966	08028W	PARTICIPANT	\N	PRESENT	0
69802	68966	87003B	PARTICIPANT	\N	PRESENT	0
69803	68966	04074L	PARTICIPANT	\N	PRESENT	0
69804	68966	14031R	PARTICIPANT	\N	PRESENT	0
69805	68966	92040Q	PARTICIPANT	\N	PRESENT	0
69806	68966	08034U	PARTICIPANT	\N	PRESENT	0
72108	72105	98018T	PARTICIPANT	\N	PRESENT	0
72109	72105	04033B	PARTICIPANT	\N	PRESENT	0
72112	72105	14041T	PARTICIPANT	\N	PRESENT	0
72114	72105	04036E	PARTICIPANT	\N	PRESENT	0
72115	72105	98029W	PARTICIPANT	\N	PRESENT	0
72116	72105	95059Q	PARTICIPANT	\N	PRESENT	0
72117	72105	86034E	PARTICIPANT	\N	PRESENT	0
80585	80433	07026Q	PARTICIPANT	\N	PRESENT	0
80586	80433	11109J	PARTICIPANT	\N	PRESENT	0
80587	80433	10015M	PARTICIPANT	\N	PRESENT	0
80588	80433	04088S	PARTICIPANT	\N	PRESENT	0
80589	80433	92040Q	PARTICIPANT	\N	PRESENT	0
80590	80433	04074L	PARTICIPANT	\N	PRESENT	0
80591	80433	11101A	PARTICIPANT	\N	PRESENT	0
80592	80433	14105F	PARTICIPANT	\N	PRESENT	0
80593	80433	11081P	PARTICIPANT	\N	PRESENT	0
80594	80433	11111C	PARTICIPANT	\N	PRESENT	0
80595	80433	12042Y	PARTICIPANT	\N	PRESENT	0
80596	80433	08025T	PARTICIPANT	\N	PRESENT	0
80597	80433	01015L	PARTICIPANT	\N	PRESENT	0
80598	80433	08021P	PARTICIPANT	\N	PRESENT	0
80599	80433	08058D	PARTICIPANT	\N	PRESENT	0
80600	80433	11112D	PARTICIPANT	\N	PRESENT	0
80601	80433	11067R	PARTICIPANT	\N	PRESENT	0
80602	80433	01011G	PARTICIPANT	\N	PRESENT	0
80603	80433	01022K	PARTICIPANT	\N	PRESENT	0
80604	80433	14247U	PARTICIPANT	\N	PRESENT	0
80605	80433	11097X	PARTICIPANT	\N	PRESENT	0
80606	80433	14213J	PARTICIPANT	\N	PRESENT	0
80607	80433	04057K	PARTICIPANT	\N	PRESENT	0
80608	80433	11049P	PARTICIPANT	\N	PRESENT	0
80609	80433	14273W	PARTICIPANT	\N	PRESENT	0
80610	80433	11098Y	PARTICIPANT	\N	PRESENT	0
80611	80433	14235Q	PARTICIPANT	\N	PRESENT	0
80612	80433	12041X	PARTICIPANT	\N	PRESENT	0
80613	80433	11034G	PARTICIPANT	\N	PRESENT	0
80614	80433	11029K	PARTICIPANT	\N	PRESENT	0
80615	80433	11113E	PARTICIPANT	\N	PRESENT	0
80616	80433	08028W	PARTICIPANT	\N	PRESENT	0
80617	80433	08065C	PARTICIPANT	\N	PRESENT	0
80618	80433	14079W	PARTICIPANT	\N	PRESENT	0
80619	80433	14026U	PARTICIPANT	\N	PRESENT	0
80620	80433	05012A	PARTICIPANT	\N	PRESENT	0
80621	80433	98029W	PARTICIPANT	\N	PRESENT	0
80622	80433	14271U	PARTICIPANT	\N	PRESENT	0
80623	80433	14199E	PARTICIPANT	\N	PRESENT	0
80624	80433	14259Y	PARTICIPANT	\N	PRESENT	0
80625	80433	08051V	PARTICIPANT	\N	PRESENT	0
80627	80433	92020L	PARTICIPANT	\N	PRESENT	0
80631	80433	95030B	PARTICIPANT	\N	PRESENT	0
80634	80433	11040E	PARTICIPANT	\N	PRESENT	0
80638	80433	11096W	PARTICIPANT	\N	PRESENT	0
80639	80433	04085P	PARTICIPANT	\N	PRESENT	0
80640	80433	04054G	PARTICIPANT	\N	PRESENT	0
80642	80433	11056N	PARTICIPANT	\N	PRESENT	0
80643	80433	95063L	PARTICIPANT	\N	PRESENT	0
80644	80433	08053X	PARTICIPANT	\N	PRESENT	0
80694	80433	08012N	PARTICIPANT	\N	PRESENT	0
80695	80433	83042R	PARTICIPANT	\N	PRESENT	0
80697	80433	14121F	PARTICIPANT	\N	PRESENT	0
80698	80433	01028R	PARTICIPANT	\N	PRESENT	0
80699	80433	11104D	PARTICIPANT	\N	PRESENT	0
80700	80433	14014Q	PARTICIPANT	\N	PRESENT	0
80701	80433	11012A	PARTICIPANT	\N	PRESENT	0
80702	80433	88008L	PARTICIPANT	\N	PRESENT	0
80703	80433	11089X	PARTICIPANT	\N	PRESENT	0
80706	80433	14241N	PARTICIPANT	\N	PRESENT	0
80707	80433	08031R	PARTICIPANT	\N	PRESENT	0
80709	80433	14028W	PARTICIPANT	\N	PRESENT	0
80712	80433	08049C	PARTICIPANT	\N	PRESENT	0
80713	80433	14197C	PARTICIPANT	\N	PRESENT	0
80714	80433	01044R	PARTICIPANT	\N	PRESENT	0
80716	80433	14281W	PARTICIPANT	\N	PRESENT	0
80717	80433	08068F	PARTICIPANT	\N	PRESENT	0
80719	80433	11106F	PARTICIPANT	\N	PRESENT	0
80720	80433	01003G	PARTICIPANT	\N	PRESENT	0
80721	80433	92015P	PARTICIPANT	\N	PRESENT	0
80723	80433	11023D	PARTICIPANT	\N	PRESENT	0
80724	80433	01034P	PARTICIPANT	\N	PRESENT	0
80725	80433	11083R	PARTICIPANT	\N	PRESENT	0
80727	80433	11072N	PARTICIPANT	\N	PRESENT	0
80729	80433	14109K	PARTICIPANT	\N	PRESENT	0
80731	80433	11100Y	PARTICIPANT	\N	PRESENT	0
80732	80433	14239U	PARTICIPANT	\N	PRESENT	0
80733	80433	11091R	PARTICIPANT	\N	PRESENT	0
80734	80433	11099A	PARTICIPANT	\N	PRESENT	0
80736	80433	11014C	PARTICIPANT	\N	PRESENT	0
80738	80433	14034U	PARTICIPANT	\N	PRESENT	0
80739	80433	04080J	PARTICIPANT	\N	PRESENT	0
80741	80433	83047W	PARTICIPANT	\N	PRESENT	0
80742	80433	14159V	PARTICIPANT	\N	PRESENT	0
80743	80433	11070L	PARTICIPANT	\N	PRESENT	0
80744	80433	04089T	PARTICIPANT	\N	PRESENT	0
80747	80433	14030Q	PARTICIPANT	\N	PRESENT	0
80748	80433	14042U	PARTICIPANT	\N	PRESENT	0
80750	80433	04040A	PARTICIPANT	\N	PRESENT	0
80752	80433	11065P	PARTICIPANT	\N	PRESENT	0
80753	80433	14227Q	PARTICIPANT	\N	PRESENT	0
80754	80433	04049K	PARTICIPANT	\N	PRESENT	0
80755	80433	08017T	PARTICIPANT	\N	PRESENT	0
80756	80433	14229S	PARTICIPANT	\N	PRESENT	0
80757	80433	14191V	PARTICIPANT	\N	PRESENT	0
80758	80433	11077T	PARTICIPANT	\N	PRESENT	0
80759	80433	08055A	PARTICIPANT	\N	PRESENT	0
80760	80433	14123H	PARTICIPANT	\N	PRESENT	0
80761	80433	11054L	PARTICIPANT	\N	PRESENT	0
80762	80433	08069G	PARTICIPANT	\N	PRESENT	0
80763	80433	08024S	PARTICIPANT	\N	PRESENT	0
80764	80433	11068S	PARTICIPANT	\N	PRESENT	0
80765	80433	01043Q	PARTICIPANT	\N	PRESENT	0
80766	80433	01007L	PARTICIPANT	\N	PRESENT	0
80767	80433	01025N	PARTICIPANT	\N	PRESENT	0
80768	80433	09001P	PARTICIPANT	\N	PRESENT	0
80769	80433	08009T	PARTICIPANT	\N	PRESENT	0
80771	80433	07004J	PARTICIPANT	\N	PRESENT	0
80772	80433	98042T	PARTICIPANT	\N	PRESENT	0
80773	80433	04034C	PARTICIPANT	\N	PRESENT	0
80774	80433	01031L	PARTICIPANT	\N	PRESENT	0
80775	80433	14083S	PARTICIPANT	\N	PRESENT	0
80776	80433	14147R	PARTICIPANT	\N	PRESENT	0
80777	80433	92044U	PARTICIPANT	\N	PRESENT	0
80778	80433	11082Q	PARTICIPANT	\N	PRESENT	0
80780	80433	11046L	PARTICIPANT	\N	PRESENT	0
80781	80433	11080N	PARTICIPANT	\N	PRESENT	0
80782	80433	14205J	PARTICIPANT	\N	PRESENT	0
80783	80433	14089Y	PARTICIPANT	\N	PRESENT	0
80784	80433	08014Q	PARTICIPANT	\N	PRESENT	0
80785	80433	11107G	PARTICIPANT	\N	PRESENT	0
80787	80433	04059M	PARTICIPANT	\N	PRESENT	0
80788	80433	14107H	PARTICIPANT	\N	PRESENT	0
80789	80433	11048N	PARTICIPANT	\N	PRESENT	0
80790	80433	14051J	PARTICIPANT	\N	PRESENT	0
80791	80433	11033F	PARTICIPANT	\N	PRESENT	0
80792	80433	11030C	PARTICIPANT	\N	PRESENT	0
80793	80433	11057P	PARTICIPANT	\N	PRESENT	0
80794	80433	14209N	PARTICIPANT	\N	PRESENT	0
80795	80433	11044J	PARTICIPANT	\N	PRESENT	0
80796	80433	14069U	PARTICIPANT	\N	PRESENT	0
80797	80433	14031R	PARTICIPANT	\N	PRESENT	0
80798	80433	11026G	PARTICIPANT	\N	PRESENT	0
80799	80433	04035D	PARTICIPANT	\N	PRESENT	0
80800	80433	08022Q	PARTICIPANT	\N	PRESENT	0
80801	80433	92031P	PARTICIPANT	\N	PRESENT	0
80802	80433	04086Q	PARTICIPANT	\N	PRESENT	0
80803	80433	10006L	PARTICIPANT	\N	PRESENT	0
80804	80433	04033B	PARTICIPANT	\N	PRESENT	0
80805	80433	08044W	PARTICIPANT	\N	PRESENT	0
80806	80433	14257W	PARTICIPANT	\N	PRESENT	0
80807	80433	14087W	PARTICIPANT	\N	PRESENT	0
65422	65421	98023Q	PARTICIPANT	\N	PRESENT	0
65423	65421	08015R	PARTICIPANT	\N	PRESENT	0
65424	65421	08056B	PARTICIPANT	\N	PRESENT	0
65425	65421	04035D	PARTICIPANT	\N	PRESENT	0
65426	65421	92020L	PARTICIPANT	\N	PRESENT	0
65427	65421	98029W	PARTICIPANT	\N	PRESENT	0
65428	65421	01003G	PARTICIPANT	\N	PRESENT	0
66773	66772	07024N	PARTICIPANT	\N	PRESENT	0
67613	66605	11091R	PARTICIPANT	\N	PRESENT	0
66806	66803	08039A	PARTICIPANT	\N	EXCUSE	0
66807	66803	01058X	PARTICIPANT	\N	EXCUSE	0
67615	66605	14249W	PARTICIPANT	\N	PRESENT	0
67616	66605	98042T	PARTICIPANT	\N	PRESENT	0
67617	66605	01041N	PARTICIPANT	\N	PRESENT	0
67618	66605	04089T	PARTICIPANT	\N	PRESENT	0
67619	66605	95030B	PARTICIPANT	\N	PRESENT	0
67620	66605	14187A	PARTICIPANT	\N	PRESENT	0
67621	66605	95031C	PARTICIPANT	\N	PRESENT	0
67622	66605	11085T	PARTICIPANT	\N	PRESENT	0
67623	66605	08044W	PARTICIPANT	\N	PRESENT	0
67624	66605	01047U	PARTICIPANT	\N	PRESENT	0
67625	66605	04070G	PARTICIPANT	\N	PRESENT	0
67626	66605	01024M	PARTICIPANT	\N	PRESENT	0
67627	66605	08056B	PARTICIPANT	\N	PRESENT	0
67628	66605	09001P	PARTICIPANT	\N	PRESENT	0
67629	66605	14087W	PARTICIPANT	\N	PRESENT	0
67630	66605	01025N	PARTICIPANT	\N	PRESENT	0
67631	66605	02002K	PARTICIPANT	\N	PRESENT	0
67632	66605	14241N	PARTICIPANT	\N	PRESENT	0
67633	66605	01007L	PARTICIPANT	\N	PRESENT	0
67634	66605	14327T	PARTICIPANT	\N	PRESENT	0
67635	66605	01043Q	PARTICIPANT	\N	PRESENT	0
67636	66605	14267Y	PARTICIPANT	\N	PRESENT	0
67637	66605	08065C	PARTICIPANT	\N	PRESENT	0
67638	66605	97011G	PARTICIPANT	\N	PRESENT	0
67639	66605	08018U	PARTICIPANT	\N	PRESENT	0
67640	66605	04035D	PARTICIPANT	\N	PRESENT	0
67641	66605	89029V	PARTICIPANT	\N	PRESENT	0
67642	66605	07024N	PARTICIPANT	\N	PRESENT	0
67643	66605	08048B	PARTICIPANT	\N	PRESENT	0
67644	66605	04085P	PARTICIPANT	\N	PRESENT	0
67645	66605	95035G	PARTICIPANT	\N	PRESENT	0
67646	66605	14211G	PARTICIPANT	\N	PRESENT	0
67647	66605	11056N	PARTICIPANT	\N	PRESENT	0
67648	66605	11098Y	PARTICIPANT	\N	PRESENT	0
67649	66605	14123H	PARTICIPANT	\N	PRESENT	0
67650	66605	01015L	PARTICIPANT	\N	PRESENT	0
67651	66605	92015P	PARTICIPANT	\N	PRESENT	0
67652	66605	98046X	PARTICIPANT	\N	PRESENT	0
67653	66605	14093U	PARTICIPANT	\N	PRESENT	0
67654	66605	08052W	PARTICIPANT	\N	PRESENT	0
67655	66605	95063L	PARTICIPANT	\N	PRESENT	0
67656	66605	08025T	PARTICIPANT	\N	PRESENT	0
67657	66605	14051J	PARTICIPANT	\N	PRESENT	0
67658	66605	08055A	PARTICIPANT	\N	PRESENT	0
67659	66605	08043V	PARTICIPANT	\N	PRESENT	0
67660	66605	11033F	PARTICIPANT	\N	PRESENT	0
67661	66605	04066L	PARTICIPANT	\N	PRESENT	0
67662	66605	11027H	PARTICIPANT	\N	PRESENT	0
67663	66605	01011G	PARTICIPANT	\N	PRESENT	0
67664	66605	11057P	PARTICIPANT	\N	PRESENT	0
67665	66605	08053X	PARTICIPANT	\N	PRESENT	0
67666	66605	08060W	PARTICIPANT	\N	PRESENT	0
67667	66605	00003C	PARTICIPANT	\N	PRESENT	0
67668	66605	80013X	PARTICIPANT	\N	PRESENT	0
67670	66605	14028W	PARTICIPANT	\N	PRESENT	0
67671	66605	01022K	PARTICIPANT	\N	PRESENT	0
67672	66605	14197C	PARTICIPANT	\N	PRESENT	0
67673	66605	14065Q	PARTICIPANT	\N	PRESENT	0
67674	66605	11015D	PARTICIPANT	\N	PRESENT	0
67675	66605	08068F	PARTICIPANT	\N	PRESENT	0
67676	66605	11105E	PARTICIPANT	\N	PRESENT	0
67677	66605	11089X	PARTICIPANT	\N	PRESENT	0
67678	66605	08012N	PARTICIPANT	\N	PRESENT	0
67679	66605	11036J	PARTICIPANT	\N	PRESENT	0
67680	66605	11059R	PARTICIPANT	\N	PRESENT	0
67681	66605	98029W	PARTICIPANT	\N	PRESENT	0
67682	66605	08041T	PARTICIPANT	\N	PRESENT	0
67683	66605	11046L	PARTICIPANT	\N	PRESENT	0
67684	66605	11067R	PARTICIPANT	\N	PRESENT	0
67685	66605	14026U	PARTICIPANT	\N	PRESENT	0
67686	66605	01057W	PARTICIPANT	\N	PRESENT	0
67687	66605	83042R	PARTICIPANT	\N	PRESENT	0
67688	66605	04041B	PARTICIPANT	\N	PRESENT	0
67689	66605	14034U	PARTICIPANT	\N	PRESENT	0
67690	66605	11048N	PARTICIPANT	\N	PRESENT	0
67691	66605	11099A	PARTICIPANT	\N	PRESENT	0
67692	66605	14213J	PARTICIPANT	\N	PRESENT	0
67693	66605	08051V	PARTICIPANT	\N	PRESENT	0
67694	66605	08015R	PARTICIPANT	\N	PRESENT	0
67695	66605	07029T	PARTICIPANT	\N	PRESENT	0
67696	66605	01031L	PARTICIPANT	\N	PRESENT	0
67697	66605	08017T	PARTICIPANT	\N	PRESENT	0
67698	66605	04034C	PARTICIPANT	\N	PRESENT	0
67699	66605	95037J	PARTICIPANT	\N	PRESENT	0
67700	66605	14273W	PARTICIPANT	\N	PRESENT	0
67701	66605	08062Y	PARTICIPANT	\N	PRESENT	0
67702	66605	08058D	PARTICIPANT	\N	PRESENT	0
67703	66605	14271U	PARTICIPANT	\N	PRESENT	0
67704	66605	04057K	PARTICIPANT	\N	PRESENT	0
67705	66605	14147R	PARTICIPANT	\N	PRESENT	0
67706	66605	14014Q	PARTICIPANT	\N	PRESENT	0
67707	66605	14223L	PARTICIPANT	\N	PRESENT	0
67708	66605	14109K	PARTICIPANT	\N	PRESENT	0
67709	66605	14225N	PARTICIPANT	\N	PRESENT	0
67710	66605	08014Q	PARTICIPANT	\N	PRESENT	0
67711	66605	14107H	PARTICIPANT	\N	PRESENT	0
67712	66605	11095V	PARTICIPANT	\N	PRESENT	0
67713	66605	14097Y	PARTICIPANT	\N	PRESENT	0
67714	66605	14167V	PARTICIPANT	\N	PRESENT	0
67715	66605	11014C	PARTICIPANT	\N	PRESENT	0
67716	66605	04036E	PARTICIPANT	\N	PRESENT	0
67717	66605	14257W	PARTICIPANT	\N	PRESENT	0
67718	66605	13002U	PARTICIPANT	\N	PRESENT	0
67719	66605	11112D	PARTICIPANT	\N	PRESENT	0
67720	66605	11074Q	PARTICIPANT	\N	PRESENT	0
67721	66605	14063N	PARTICIPANT	\N	PRESENT	0
67722	66605	14121F	PARTICIPANT	\N	PRESENT	0
67723	66605	14227Q	PARTICIPANT	\N	PRESENT	0
67724	66605	14207L	PARTICIPANT	\N	PRESENT	0
67725	66605	14281W	PARTICIPANT	\N	PRESENT	0
67726	66605	80027E	PARTICIPANT	\N	PRESENT	0
67727	66605	14253S	PARTICIPANT	\N	PRESENT	0
67728	66605	83047W	PARTICIPANT	\N	PRESENT	0
67729	66605	14191V	PARTICIPANT	\N	PRESENT	0
67730	66605	08047A	PARTICIPANT	\N	PRESENT	0
67731	66605	14237S	PARTICIPANT	\N	PRESENT	0
67732	66605	04079R	PARTICIPANT	\N	PRESENT	0
67733	66605	11054L	PARTICIPANT	\N	PRESENT	0
67734	66605	08009T	PARTICIPANT	\N	PRESENT	0
67735	66605	14193X	PARTICIPANT	\N	PRESENT	0
67736	66605	04088S	PARTICIPANT	\N	PRESENT	0
67737	66605	04059M	PARTICIPANT	\N	PRESENT	0
67738	66605	07034Q	PARTICIPANT	\N	PRESENT	0
67739	66605	08061X	PARTICIPANT	\N	PRESENT	0
67740	66605	98021N	PARTICIPANT	\N	PRESENT	0
67741	66605	07032N	PARTICIPANT	\N	PRESENT	0
67742	66605	08073C	PARTICIPANT	\N	PRESENT	0
67743	66605	05012A	PARTICIPANT	\N	PRESENT	0
67744	66605	04053F	PARTICIPANT	\N	PRESENT	0
67745	66605	04074L	PARTICIPANT	\N	PRESENT	0
67746	66605	11090Q	PARTICIPANT	\N	PRESENT	0
67747	66605	01028R	PARTICIPANT	\N	PRESENT	0
67748	66605	04043D	PARTICIPANT	\N	PRESENT	0
67749	66605	11104D	PARTICIPANT	\N	PRESENT	0
67750	66605	11110B	PARTICIPANT	\N	PRESENT	0
67751	66605	86044G	PARTICIPANT	\N	PRESENT	0
67752	66605	08038Y	PARTICIPANT	\N	PRESENT	0
67753	66605	14135M	PARTICIPANT	\N	PRESENT	0
67754	66605	10015M	PARTICIPANT	\N	PRESENT	0
67755	66605	92039X	PARTICIPANT	\N	PRESENT	0
67756	66605	04033B	PARTICIPANT	\N	PRESENT	0
67757	66605	14229S	PARTICIPANT	\N	PRESENT	0
67758	66605	95062K	PARTICIPANT	\N	PRESENT	0
67759	66605	11035H	PARTICIPANT	\N	PRESENT	0
67760	66605	01037S	PARTICIPANT	\N	PRESENT	0
67761	66605	14331P	PARTICIPANT	\N	PRESENT	0
67762	66605	11061K	PARTICIPANT	\N	PRESENT	0
67763	66605	08024S	PARTICIPANT	\N	PRESENT	0
67764	66605	11071M	PARTICIPANT	\N	PRESENT	0
67765	66605	11106F	PARTICIPANT	\N	PRESENT	0
67766	66605	99002P	PARTICIPANT	\N	PRESENT	0
67767	66605	11066Q	PARTICIPANT	\N	PRESENT	0
67768	66605	92045V	PARTICIPANT	\N	PRESENT	0
72017	72016	14053L	PARTICIPANT	\N	PRESENT	0
72018	72016	12042Y	PARTICIPANT	\N	PRESENT	0
72020	72019	14053L	PARTICIPANT	\N	PRESENT	0
72021	72019	12042Y	PARTICIPANT	\N	PRESENT	0
72023	72022	14053L	PARTICIPANT	\N	PRESENT	0
72024	72022	12042Y	PARTICIPANT	\N	PRESENT	0
72026	72025	14053L	PARTICIPANT	\N	PRESENT	0
72027	72025	12042Y	PARTICIPANT	\N	PRESENT	0
72029	72028	14053L	PARTICIPANT	\N	PRESENT	0
72030	72028	12042Y	PARTICIPANT	\N	PRESENT	0
83919	83918	11068S	PARTICIPANT	\N	PRESENT	0
83921	83920	11068S	PARTICIPANT	\N	PRESENT	0
85446	84158	14079W	PARTICIPANT	\N	PRESENT	0
85447	84158	01008M	PARTICIPANT	\N	PRESENT	0
85448	84158	01028R	PARTICIPANT	\N	PRESENT	0
85449	84158	14159V	PARTICIPANT	\N	PRESENT	0
85450	84158	14197C	PARTICIPANT	\N	PRESENT	0
85451	84158	14217N	PARTICIPANT	\N	PRESENT	0
85452	84158	14265W	PARTICIPANT	\N	PRESENT	0
85453	84158	14087W	PARTICIPANT	\N	PRESENT	0
85454	84158	14195A	PARTICIPANT	\N	PRESENT	0
85455	84158	11012A	PARTICIPANT	\N	PRESENT	0
85456	84158	04070G	PARTICIPANT	\N	PRESENT	0
85457	84158	04088S	PARTICIPANT	\N	PRESENT	0
85458	84158	04057K	PARTICIPANT	\N	PRESENT	0
85459	84158	11097X	PARTICIPANT	\N	PRESENT	0
85460	84158	14107H	PARTICIPANT	\N	PRESENT	0
85461	84158	10006L	PARTICIPANT	\N	PRESENT	0
85462	84158	14169X	PARTICIPANT	\N	PRESENT	0
85463	84158	08039A	PARTICIPANT	\N	PRESENT	0
85464	84158	14017T	PARTICIPANT	\N	PRESENT	0
85465	84158	04085P	PARTICIPANT	\N	PRESENT	0
85466	84158	11056N	PARTICIPANT	\N	PRESENT	0
85467	84158	01027Q	PARTICIPANT	\N	PRESENT	0
85468	84158	11098Y	PARTICIPANT	\N	PRESENT	0
85469	84158	14235Q	PARTICIPANT	\N	PRESENT	0
85470	84158	08019V	PARTICIPANT	\N	PRESENT	0
85471	84158	14179A	PARTICIPANT	\N	PRESENT	0
85472	84158	14267Y	PARTICIPANT	\N	PRESENT	0
85473	84158	14073Q	PARTICIPANT	\N	PRESENT	0
85474	84158	11112D	PARTICIPANT	\N	PRESENT	0
85475	84158	11044J	PARTICIPANT	\N	PRESENT	0
85476	84158	02002K	PARTICIPANT	\N	PRESENT	0
85477	84158	08010L	PARTICIPANT	\N	PRESENT	0
85478	84158	11036J	PARTICIPANT	\N	PRESENT	0
85479	84158	14030Q	PARTICIPANT	\N	PRESENT	0
85480	84158	14053L	PARTICIPANT	\N	PRESENT	0
85481	84158	04045F	PARTICIPANT	\N	PRESENT	0
85482	84158	08015R	PARTICIPANT	\N	PRESENT	0
85483	84158	11099A	PARTICIPANT	\N	PRESENT	0
85484	84158	11043H	PARTICIPANT	\N	PRESENT	0
85485	84158	14042U	PARTICIPANT	\N	PRESENT	0
85486	84158	14205J	PARTICIPANT	\N	PRESENT	0
85487	84158	14014Q	PARTICIPANT	\N	PRESENT	0
85488	84158	01031L	PARTICIPANT	\N	PRESENT	0
85489	84158	01059Y	PARTICIPANT	\N	PRESENT	0
85490	84158	01016M	PARTICIPANT	\N	PRESENT	0
85491	84158	04033B	PARTICIPANT	\N	PRESENT	0
85492	84158	14083S	PARTICIPANT	\N	PRESENT	0
85493	84158	14034U	PARTICIPANT	\N	PRESENT	0
85494	84158	92045V	PARTICIPANT	\N	PRESENT	0
85495	84158	14213J	PARTICIPANT	\N	PRESENT	0
85496	84158	14257W	PARTICIPANT	\N	PRESENT	0
85497	84158	04047H	PARTICIPANT	\N	PRESENT	0
85512	84158	08051V	PARTICIPANT	\N	PRESENT	0
86359	80749	14038Y	PARTICIPANT	\N	PRESENT	0
86360	80749	11026G	PARTICIPANT	\N	PRESENT	0
86741	86739	14239U	PARTICIPANT	\N	PRESENT	0
86743	86739	14133K	PARTICIPANT	\N	PRESENT	0
86744	86739	14065Q	PARTICIPANT	\N	PRESENT	0
86746	86739	14217N	PARTICIPANT	\N	PRESENT	0
86747	86739	14041T	PARTICIPANT	\N	PRESENT	0
86748	86739	14281W	PRESIDENT	0	PRESENT	0
86749	86739	07004J	PARTICIPANT	\N	PRESENT	0
86750	86739	11049P	PARTICIPANT	\N	PRESENT	0
86751	86739	14123H	PARTICIPANT	\N	PRESENT	0
86752	86739	10015M	PARTICIPANT	\N	PRESENT	0
86753	86739	14269B	PARTICIPANT	\N	PRESENT	0
86754	86739	14193X	PARTICIPANT	\N	EXCUSE	0
86756	86755	14065Q	PARTICIPANT	\N	PRESENT	0
86757	86755	14217N	PARTICIPANT	\N	PRESENT	0
86758	86755	14281W	PRESIDENT	0	PRESENT	0
86759	86755	07004J	PARTICIPANT	\N	PRESENT	0
86760	86755	99004R	PARTICIPANT	\N	PRESENT	0
86761	86755	04061F	PARTICIPANT	\N	PRESENT	0
86763	86755	08053X	PARTICIPANT	\N	PRESENT	0
86764	86755	11082Q	PARTICIPANT	\N	PRESENT	0
86765	86755	14269B	PARTICIPANT	\N	PRESENT	0
86766	86755	10015M	PARTICIPANT	\N	PRESENT	0
86767	86755	11025F	PARTICIPANT	\N	PRESENT	0
87012	87011	14059S	PARTICIPANT	\N	PRESENT	0
87013	87011	07034Q	PARTICIPANT	\N	PRESENT	0
87014	87011	98029W	PARTICIPANT	\N	PRESENT	0
87015	87011	14187A	PARTICIPANT	\N	PRESENT	0
87016	87011	14239U	PARTICIPANT	\N	PRESENT	0
87017	87011	04036E	PARTICIPANT	\N	PRESENT	0
87018	87011	14097Y	PARTICIPANT	\N	PRESENT	0
87019	87011	11084S	PARTICIPANT	\N	PRESENT	0
87020	87011	04033B	PARTICIPANT	\N	PRESENT	0
87021	87011	95062K	PARTICIPANT	\N	PRESENT	0
87022	87011	14105F	PARTICIPANT	\N	PRESENT	0
87023	87011	14079W	PARTICIPANT	\N	PRESENT	0
87024	87011	08015R	PARTICIPANT	\N	PRESENT	0
87025	87011	11091R	PARTICIPANT	\N	PRESENT	0
87026	87011	01008M	PARTICIPANT	\N	PRESENT	0
87027	87011	97011G	PARTICIPANT	\N	PRESENT	0
87877	87876	01056V	PARTICIPANT	\N	PRESENT	0
88205	88203	14133K	PARTICIPANT	\N	PRESENT	0
88206	88203	14265W	PARTICIPANT	\N	PRESENT	0
88207	88203	07024N	PARTICIPANT	\N	PRESENT	0
88219	88218	05012A	PARTICIPANT	\N	PRESENT	0
88220	88218	11101A	PARTICIPANT	\N	PRESENT	0
88221	88218	08038Y	PARTICIPANT	\N	PRESENT	0
88222	88218	11037K	PARTICIPANT	\N	PRESENT	0
88233	88232	11076S	PARTICIPANT	\N	EXCUSE	0
88234	88232	08021P	PARTICIPANT	\N	EXCUSE	0
88235	88232	08049C	PARTICIPANT	\N	EXCUSE	0
88242	88232	95067Q	PARTICIPANT	\N	PRESENT	0
88244	88232	14133K	PARTICIPANT	\N	PRESENT	0
88245	88232	04085P	PARTICIPANT	\N	PRESENT	0
88246	88232	04054G	PARTICIPANT	\N	PRESENT	0
88256	88232	14089Y	PARTICIPANT	\N	PRESENT	0
88257	88232	04047H	PARTICIPANT	\N	PRESENT	0
88258	88232	14079W	PARTICIPANT	\N	PRESENT	0
88260	88232	14041T	PARTICIPANT	\N	PRESENT	0
88261	88232	04035D	PARTICIPANT	\N	PRESENT	0
88262	88232	08041T	PARTICIPANT	\N	PRESENT	0
88263	88232	95037J	PARTICIPANT	\N	PRESENT	0
88264	88232	14097Y	PARTICIPANT	\N	PRESENT	0
88265	88232	11084S	PARTICIPANT	\N	PRESENT	0
88266	88232	11026G	PARTICIPANT	\N	PRESENT	0
88267	88232	92031P	PRESIDENT	0	PRESENT	0
88268	88232	14251Q	PARTICIPANT	\N	PRESENT	0
88269	88232	08053X	PARTICIPANT	\N	PRESENT	0
88270	88232	14237S	PARTICIPANT	\N	PRESENT	0
88271	88232	04080J	PARTICIPANT	\N	PRESENT	0
88272	88232	14331P	PARTICIPANT	\N	PRESENT	0
88292	88290	11095V	PARTICIPANT	\N	PRESENT	0
88293	88290	92020L	PARTICIPANT	\N	PRESENT	0
88294	88290	04035D	PARTICIPANT	\N	PRESENT	0
88295	88290	14211G	PARTICIPANT	\N	PRESENT	0
88296	88290	11100Y	PARTICIPANT	\N	PRESENT	0
88297	88290	08047A	PARTICIPANT	\N	PRESENT	0
88298	88290	04034C	PARTICIPANT	\N	PRESENT	0
88305	87186	11055M	PARTICIPANT	\N	PRESENT	0
88306	87186	14257W	PARTICIPANT	\N	PRESENT	0
88307	87186	14219Q	PARTICIPANT	\N	PRESENT	0
88359	88358	04085P	PARTICIPANT	\N	PRESENT	0
88360	88358	05008E	PRESIDENT	1	PRESENT	0
88361	88358	14065Q	PARTICIPANT	\N	PRESENT	0
88362	88358	14069U	PARTICIPANT	\N	PRESENT	0
88363	88358	04047H	PARTICIPANT	\N	PRESENT	0
88364	88358	04038G	PARTICIPANT	\N	PRESENT	0
88365	88358	11035H	PARTICIPANT	\N	PRESENT	0
88366	88358	14041T	PARTICIPANT	\N	PRESENT	0
88367	88358	11113E	PARTICIPANT	\N	PRESENT	0
88368	88358	01024M	PARTICIPANT	\N	PRESENT	0
88369	88358	14215L	PARTICIPANT	\N	PRESENT	0
88370	88358	01007L	PARTICIPANT	\N	PRESENT	0
88371	88358	11084S	PARTICIPANT	\N	PRESENT	0
88372	88358	11026G	PARTICIPANT	\N	PRESENT	0
88373	88358	14147R	PARTICIPANT	\N	PRESENT	0
88374	88358	95049N	PARTICIPANT	\N	PRESENT	0
88375	88358	11072N	PARTICIPANT	\N	PRESENT	0
88376	88358	07034Q	PARTICIPANT	\N	PRESENT	0
66610	66609	14209N	PARTICIPANT	\N	PRESENT	0
66611	66609	14197C	PARTICIPANT	\N	PRESENT	0
66612	66609	11111C	PARTICIPANT	\N	PRESENT	0
66613	66609	08010L	PARTICIPANT	\N	PRESENT	0
66614	66609	14063N	PARTICIPANT	\N	PRESENT	0
66615	66609	14135M	PARTICIPANT	\N	PRESENT	0
66616	66609	11066Q	PARTICIPANT	\N	PRESENT	0
66652	66645	11098Y	PARTICIPANT	\N	PRESENT	0
66658	66657	11098Y	PARTICIPANT	\N	PRESENT	0
66660	66659	11098Y	PARTICIPANT	\N	PRESENT	0
66662	66661	11098Y	PARTICIPANT	\N	PRESENT	0
66664	66663	14030Q	PARTICIPANT	\N	PRESENT	0
66665	66663	14157T	PARTICIPANT	\N	PRESENT	0
66666	66663	14083S	PARTICIPANT	\N	PRESENT	0
66668	66667	14093U	PARTICIPANT	\N	PRESENT	0
66669	66667	14157T	PARTICIPANT	\N	PRESENT	0
66670	66667	95062K	PARTICIPANT	\N	PRESENT	0
66671	66667	14031R	PARTICIPANT	\N	PRESENT	0
66672	66667	14083S	PARTICIPANT	\N	PRESENT	0
66674	66673	14031R	PARTICIPANT	\N	PRESENT	0
66675	66673	14157T	PARTICIPANT	\N	PRESENT	0
66677	66676	14031R	PARTICIPANT	\N	PRESENT	0
66678	66676	14157T	PARTICIPANT	\N	PRESENT	0
66679	66676	95062K	PARTICIPANT	\N	PRESENT	0
66681	66680	14031R	PARTICIPANT	\N	PRESENT	0
66682	66680	14157T	PARTICIPANT	\N	PRESENT	0
66683	66680	95062K	PARTICIPANT	\N	PRESENT	0
66685	66684	14031R	PARTICIPANT	\N	PRESENT	0
66686	66684	01022K	PARTICIPANT	\N	PRESENT	0
66687	66684	14030Q	PARTICIPANT	\N	PRESENT	0
66688	66684	14157T	PARTICIPANT	\N	PRESENT	0
66689	66684	95062K	PARTICIPANT	\N	PRESENT	0
66690	66684	14083S	PARTICIPANT	\N	PRESENT	0
66692	66691	14031R	PARTICIPANT	\N	PRESENT	0
66693	66691	14030Q	PARTICIPANT	\N	PRESENT	0
66694	66691	01022K	PARTICIPANT	\N	PRESENT	0
66695	66691	14157T	PARTICIPANT	\N	PRESENT	0
66696	66691	95062K	PARTICIPANT	\N	PRESENT	0
66697	66691	14083S	PARTICIPANT	\N	PRESENT	0
66777	66776	11076S	PARTICIPANT	\N	PRESENT	0
66778	66776	04054G	PARTICIPANT	\N	PRESENT	0
66779	66776	04040A	PARTICIPANT	\N	PRESENT	0
66780	66776	08058D	PARTICIPANT	\N	PRESENT	0
66781	66776	11027H	PARTICIPANT	\N	PRESENT	0
66782	66776	92020L	PARTICIPANT	\N	PRESENT	0
66783	66776	98018T	PARTICIPANT	\N	PRESENT	0
66784	66776	07024N	PARTICIPANT	\N	PRESENT	0
66785	66776	07004J	PARTICIPANT	\N	PRESENT	0
66786	66776	95035G	PARTICIPANT	\N	PRESENT	0
66787	66776	08056B	PARTICIPANT	\N	PRESENT	0
66788	66776	14211G	PARTICIPANT	\N	PRESENT	0
66789	66776	98022P	PARTICIPANT	\N	PRESENT	0
66790	66776	04077P	PARTICIPANT	\N	PRESENT	0
66791	66776	92031P	PARTICIPANT	\N	PRESENT	0
66792	66776	83042R	PARTICIPANT	\N	PRESENT	0
66793	66776	11082Q	PARTICIPANT	\N	PRESENT	0
66794	66776	11105E	PARTICIPANT	\N	PRESENT	0
66795	66776	14253S	PARTICIPANT	\N	PRESENT	0
66796	66776	08047A	PARTICIPANT	\N	PRESENT	0
66797	66776	14028W	PARTICIPANT	\N	PRESENT	0
66798	66776	14193X	PARTICIPANT	\N	PRESENT	0
66799	66776	98021N	PARTICIPANT	\N	PRESENT	0
66800	66776	95059Q	PARTICIPANT	\N	PRESENT	0
66801	66776	01014K	PARTICIPANT	\N	PRESENT	0
66802	66776	04035D	PARTICIPANT	\N	PRESENT	0
69493	69492	00003C	PARTICIPANT	\N	PRESENT	0
69494	69492	14071N	PARTICIPANT	\N	PRESENT	0
69496	69495	05008E	PRESIDENT	0	PRESENT	0
69497	69495	14065Q	PARTICIPANT	\N	PRESENT	0
69498	69495	14069U	PARTICIPANT	\N	PRESENT	0
69499	69495	11035H	PARTICIPANT	\N	PRESENT	0
69500	69495	14041T	PARTICIPANT	\N	PRESENT	0
69501	69495	01024M	PARTICIPANT	\N	PRESENT	0
69502	69495	11034G	PARTICIPANT	\N	PRESENT	0
69503	69495	08018U	PARTICIPANT	\N	PRESENT	0
69504	69495	01007L	PARTICIPANT	\N	PRESENT	0
69505	69495	11049P	PARTICIPANT	\N	PRESENT	0
69506	69495	11026G	PARTICIPANT	\N	PRESENT	0
69507	69495	14111D	PARTICIPANT	\N	PRESENT	0
69508	69495	14273W	PARTICIPANT	\N	PRESENT	0
69509	69495	14147R	PARTICIPANT	\N	PRESENT	0
69510	69495	95049N	PARTICIPANT	\N	PRESENT	0
69511	69495	07034Q	PARTICIPANT	\N	PRESENT	0
69512	69495	95063L	PARTICIPANT	\N	PRESENT	0
69513	69495	01028R	PARTICIPANT	\N	PRESENT	0
69514	69495	04056J	PARTICIPANT	\N	PRESENT	0
69515	69495	11037K	PARTICIPANT	\N	PRESENT	0
69542	69495	04085P	PARTICIPANT	\N	PRESENT	0
69543	69495	04047H	PARTICIPANT	\N	PRESENT	0
69544	69495	11032E	PARTICIPANT	\N	PRESENT	0
69545	69495	14215L	PARTICIPANT	\N	PRESENT	0
69546	69495	08051V	PARTICIPANT	\N	PRESENT	0
69807	68966	04088S	PARTICIPANT	\N	PRESENT	0
69808	68966	08041T	PARTICIPANT	\N	PRESENT	0
69809	68966	11043H	PARTICIPANT	\N	PRESENT	0
69810	68966	01048V	PARTICIPANT	\N	PRESENT	0
69811	68966	14223L	PARTICIPANT	\N	PRESENT	0
69812	68966	11100Y	PARTICIPANT	\N	PRESENT	0
69813	68966	04071H	PARTICIPANT	\N	PRESENT	0
69814	68966	14251Q	PARTICIPANT	\N	PRESENT	0
69815	68966	14135M	PARTICIPANT	\N	PRESENT	0
69816	68966	11049P	PARTICIPANT	\N	PRESENT	0
69817	68966	08047A	PARTICIPANT	\N	PRESENT	0
69818	68966	08062Y	PARTICIPANT	\N	PRESENT	0
69819	68966	01057W	PARTICIPANT	\N	PRESENT	0
69820	68966	07029T	PARTICIPANT	\N	PRESENT	0
69821	68966	95030B	PARTICIPANT	\N	PRESENT	0
69822	68966	86044G	PARTICIPANT	\N	PRESENT	0
69823	68966	95059Q	PARTICIPANT	\N	PRESENT	0
69824	68966	98018T	PARTICIPANT	\N	PRESENT	0
69825	68966	01041N	PARTICIPANT	\N	PRESENT	0
69826	68966	14331P	PARTICIPANT	\N	PRESENT	0
69827	68966	11048N	PARTICIPANT	\N	PRESENT	0
69828	68966	11097X	PARTICIPANT	\N	PRESENT	0
69829	68966	92045V	PARTICIPANT	\N	PRESENT	0
69830	68966	14133K	PARTICIPANT	\N	PRESENT	0
69831	68966	14119M	PARTICIPANT	\N	PRESENT	0
69832	68966	08015R	PARTICIPANT	\N	PRESENT	0
69833	68966	14033T	PARTICIPANT	\N	PRESENT	0
69834	68966	14211G	PARTICIPANT	\N	PRESENT	0
69835	68966	04042C	PARTICIPANT	\N	PRESENT	0
69836	68966	14026U	PARTICIPANT	\N	PRESENT	0
69837	68966	08022Q	PARTICIPANT	\N	PRESENT	0
69838	68966	77002U	PARTICIPANT	\N	PRESENT	0
69839	68966	10006L	PARTICIPANT	\N	PRESENT	0
69840	68966	04033B	PARTICIPANT	\N	PRESENT	0
69841	68966	01056V	PARTICIPANT	\N	PRESENT	0
69842	68966	04085P	PARTICIPANT	\N	PRESENT	0
69843	68966	14169X	PARTICIPANT	\N	PRESENT	0
69844	68966	98053W	PARTICIPANT	\N	PRESENT	0
69845	68966	12041X	PARTICIPANT	\N	PRESENT	0
69846	68966	98024R	PARTICIPANT	\N	PRESENT	0
69847	68966	11055M	PARTICIPANT	\N	PRESENT	0
69848	68966	11099A	PARTICIPANT	\N	PRESENT	0
69849	68966	11083R	PARTICIPANT	\N	PRESENT	0
69850	68966	11090Q	PARTICIPANT	\N	PRESENT	0
69851	68966	89017R	PARTICIPANT	\N	PRESENT	0
69852	68966	14175V	PARTICIPANT	\N	PRESENT	0
69853	68966	01061S	PARTICIPANT	\N	PRESENT	0
69854	68966	08018U	PARTICIPANT	\N	PRESENT	0
69855	68966	04054G	PARTICIPANT	\N	PRESENT	0
69856	68966	08065C	PARTICIPANT	\N	PRESENT	0
69857	68966	01003G	PARTICIPANT	\N	PRESENT	0
69858	68966	14201E	PARTICIPANT	\N	PRESENT	0
71093	71061	14257W	PARTICIPANT	\N	PRESENT	0
71094	71061	08021P	PARTICIPANT	\N	PRESENT	0
71095	71061	04088S	PARTICIPANT	\N	PRESENT	0
71161	71160	01008M	PARTICIPANT	\N	PRESENT	0
71097	71061	11090Q	PARTICIPANT	\N	PRESENT	0
71098	71061	11046L	PARTICIPANT	\N	PRESENT	0
71099	71061	01058X	PARTICIPANT	\N	PRESENT	0
71100	71061	11094U	PARTICIPANT	\N	PRESENT	0
71101	71061	11066Q	PARTICIPANT	\N	PRESENT	0
71116	71061	14013P	PARTICIPANT	\N	EXCUSE	0
71117	71061	08019V	PARTICIPANT	\N	EXCUSE	0
71162	71160	11036J	PARTICIPANT	\N	PRESENT	0
71201	71118	11076S	PARTICIPANT	\N	PRESENT	0
71202	71118	04054G	PARTICIPANT	\N	PRESENT	0
71165	71160	08068F	PARTICIPANT	\N	PRESENT	0
71203	71118	04040A	PARTICIPANT	\N	PRESENT	0
71204	71118	08058D	PARTICIPANT	\N	PRESENT	0
71168	71160	90003B	PARTICIPANT	\N	PRESENT	0
71354	71310	14038Y	PARTICIPANT	\N	EXCUSE	0
71170	71160	80013X	PARTICIPANT	\N	PRESENT	0
71206	71118	11027H	PARTICIPANT	\N	PRESENT	0
71207	71118	98018T	PARTICIPANT	\N	PRESENT	0
71173	71160	14197C	PARTICIPANT	\N	PRESENT	0
71208	71118	92020L	PARTICIPANT	\N	PRESENT	0
71209	71118	95030B	PARTICIPANT	\N	PRESENT	0
71176	71160	14033T	PARTICIPANT	\N	PRESENT	0
71210	71118	11096W	PARTICIPANT	\N	PRESENT	0
71211	71118	97011G	PARTICIPANT	\N	PRESENT	0
71179	71160	11099A	PARTICIPANT	\N	PRESENT	0
71180	71160	04049K	PRESIDENT	0	PRESENT	0
71181	71160	04094Q	PARTICIPANT	\N	PRESENT	0
71212	71118	08065C	PARTICIPANT	\N	PRESENT	0
71183	71160	08015R	PARTICIPANT	\N	PRESENT	0
71213	71118	07024N	PARTICIPANT	\N	PRESENT	0
71214	71118	04095R	PARTICIPANT	\N	PRESENT	0
71186	71160	11098Y	PARTICIPANT	\N	PRESENT	0
71215	71118	14014Q	PARTICIPANT	\N	PRESENT	0
71216	71118	11064N	PARTICIPANT	\N	PRESENT	0
71189	71160	14205J	PARTICIPANT	\N	PRESENT	0
71217	71118	04078Q	PARTICIPANT	\N	PRESENT	0
71191	71160	14257W	PARTICIPANT	\N	PRESENT	0
71218	71118	11106F	PARTICIPANT	\N	PRESENT	0
71219	71118	86044G	PARTICIPANT	\N	PRESENT	0
71220	71118	01014K	PARTICIPANT	\N	PRESENT	0
71195	71160	11090Q	PARTICIPANT	\N	PRESENT	0
71221	71118	11054L	PARTICIPANT	\N	PRESENT	0
71222	71118	08049C	PARTICIPANT	\N	PRESENT	0
71198	71160	11094U	PARTICIPANT	\N	PRESENT	0
71199	71160	11066Q	PARTICIPANT	\N	PRESENT	0
71223	71118	98046X	PARTICIPANT	\N	PRESENT	0
71224	71118	01016M	PARTICIPANT	\N	PRESENT	0
71225	71118	96004D	PARTICIPANT	\N	PRESENT	0
71227	71118	14001X	PARTICIPANT	\N	PRESENT	0
71228	71118	14097Y	PARTICIPANT	\N	PRESENT	0
71229	71118	14133K	PARTICIPANT	\N	PRESENT	0
71230	71118	11012A	PARTICIPANT	\N	PRESENT	0
71231	71118	14026U	PARTICIPANT	\N	PRESENT	0
71232	71118	04045F	PARTICIPANT	\N	PRESENT	0
71233	71118	14089Y	PARTICIPANT	\N	PRESENT	0
71234	71118	14135M	PARTICIPANT	\N	PRESENT	0
71235	71118	11026G	PARTICIPANT	\N	PRESENT	0
71352	71310	08060W	PARTICIPANT	\N	EXCUSE	0
71356	71310	14041T	PARTICIPANT	\N	EXCUSE	0
71358	71310	14281W	PARTICIPANT	\N	EXCUSE	0
71360	71310	95035G	PARTICIPANT	\N	EXCUSE	0
71364	71310	08031R	PARTICIPANT	\N	EXCUSE	0
71370	71310	08017T	PARTICIPANT	\N	EXCUSE	0
71372	71310	14237S	PARTICIPANT	\N	EXCUSE	0
71375	71310	14014Q	PARTICIPANT	\N	PRESENT	0
71376	71310	07029T	PARTICIPANT	\N	PRESENT	0
71377	71310	11027H	PARTICIPANT	\N	PRESENT	0
71379	71310	11067R	PARTICIPANT	\N	PRESENT	0
71380	71310	11014C	PARTICIPANT	\N	PRESENT	0
71381	71310	08043V	PARTICIPANT	\N	PRESENT	0
71383	71310	14031R	PARTICIPANT	\N	PRESENT	0
71384	71310	07026Q	PARTICIPANT	\N	PRESENT	0
71385	71310	14241N	PARTICIPANT	\N	PRESENT	0
71387	71310	09001P	PRESIDENT	0	PRESENT	0
71389	71310	14030Q	PARTICIPANT	\N	PRESENT	0
71391	71310	11031D	PARTICIPANT	\N	PRESENT	0
71434	71310	11061K	PARTICIPANT	\N	PRESENT	0
71446	71310	04035D	PARTICIPANT	\N	PRESENT	0
71567	71566	98035U	PARTICIPANT	\N	PRESENT	0
71569	71566	96004D	PARTICIPANT	\N	PRESENT	0
77841	77840	04089T	PARTICIPANT	\N	PRESENT	0
77842	77795	04043D	PARTICIPANT	\N	EXCUSE	0
77843	75076	08073C	PARTICIPANT	\N	EXCUSE	0
77937	77936	14151M	PARTICIPANT	\N	PRESENT	0
80809	80433	14207L	PARTICIPANT	\N	PRESENT	0
80810	80433	11110B	PARTICIPANT	\N	PRESENT	0
80811	80433	11064N	PARTICIPANT	\N	PRESENT	0
80812	80433	11094U	PARTICIPANT	\N	PRESENT	0
80813	80433	14093U	PARTICIPANT	\N	PRESENT	0
80814	80433	14217N	PARTICIPANT	\N	PRESENT	0
80815	80433	14249W	PARTICIPANT	\N	PRESENT	0
80816	80433	01041N	PARTICIPANT	\N	PRESENT	0
80817	80433	14329V	PARTICIPANT	\N	PRESENT	0
80818	80433	14187A	PARTICIPANT	\N	PRESENT	0
80819	80433	08042U	PARTICIPANT	\N	PRESENT	0
80820	80433	14038Y	PARTICIPANT	\N	PRESENT	0
80821	80433	11095V	PARTICIPANT	\N	PRESENT	0
80822	80433	14037X	PARTICIPANT	\N	PRESENT	0
80823	80433	14061L	PARTICIPANT	\N	PRESENT	0
80824	80433	11088W	PARTICIPANT	\N	PRESENT	0
80825	80433	14041T	PARTICIPANT	\N	PRESENT	0
80826	80433	01014K	PARTICIPANT	\N	PRESENT	0
80827	80433	01056V	PARTICIPANT	\N	PRESENT	0
80828	80433	01013J	PARTICIPANT	\N	PRESENT	0
80829	80433	99004R	PARTICIPANT	\N	PRESENT	0
80830	80433	11053K	PARTICIPANT	\N	PRESENT	0
80831	80433	95035G	PARTICIPANT	\N	PRESENT	0
80832	80433	95059Q	PARTICIPANT	\N	PRESENT	0
80833	80433	14033T	PARTICIPANT	\N	PRESENT	0
80834	80433	14193X	PARTICIPANT	\N	PRESENT	0
80835	80433	01008M	PARTICIPANT	\N	PRESENT	0
80836	80433	07029T	PARTICIPANT	\N	PRESENT	0
80837	80433	98005N	PARTICIPANT	\N	PRESENT	0
80838	80433	08015R	PARTICIPANT	\N	PRESENT	0
80839	80433	08034U	PARTICIPANT	\N	PRESENT	0
80840	80433	14195A	PARTICIPANT	\N	PRESENT	0
80841	80433	90003B	PARTICIPANT	\N	PRESENT	0
80842	80433	01061S	PARTICIPANT	\N	PRESENT	0
80843	80433	08019V	PARTICIPANT	\N	PRESENT	0
80866	80433	14211G	PARTICIPANT	\N	PRESENT	0
80845	80433	02002K	PARTICIPANT	\N	PRESENT	0
80846	80433	04042C	PARTICIPANT	\N	PRESENT	0
80847	80433	14175V	PARTICIPANT	\N	PRESENT	0
80848	80433	05004A	PARTICIPANT	\N	PRESENT	0
80849	80433	01027Q	PARTICIPANT	\N	PRESENT	0
80850	80433	04036E	PARTICIPANT	\N	PRESENT	0
80851	80433	04097T	PARTICIPANT	\N	PRESENT	0
80852	80433	14169X	PARTICIPANT	\N	PRESENT	0
80853	80433	14119M	PARTICIPANT	\N	PRESENT	0
80854	80433	14253S	PARTICIPANT	\N	PRESENT	0
80855	80433	04043D	PARTICIPANT	\N	PRESENT	0
80856	80433	14265W	PARTICIPANT	\N	PRESENT	0
80857	80433	95062K	PARTICIPANT	\N	PRESENT	0
80858	80433	01019Q	PARTICIPANT	\N	PRESENT	0
80859	80433	01058X	PARTICIPANT	\N	PRESENT	0
80860	80433	08047A	PARTICIPANT	\N	PRESENT	0
80861	80433	14111D	PARTICIPANT	\N	PRESENT	0
80862	80433	08039A	PARTICIPANT	\N	PRESENT	0
80863	80433	08011M	PARTICIPANT	\N	PRESENT	0
80864	80433	08010L	PARTICIPANT	\N	PRESENT	0
80865	80433	08018U	PARTICIPANT	\N	PRESENT	0
80867	80433	04081K	PARTICIPANT	\N	PRESENT	0
80868	80433	11043H	PARTICIPANT	\N	PRESENT	0
80869	80433	11071M	PARTICIPANT	\N	PRESENT	0
80870	80433	07024N	PARTICIPANT	\N	PRESENT	0
80871	80433	14157T	PARTICIPANT	\N	PRESENT	0
80872	80433	08060W	PARTICIPANT	\N	PRESENT	0
80873	80433	95067Q	PARTICIPANT	\N	PRESENT	0
80874	80433	14173T	PARTICIPANT	\N	PRESENT	0
80875	80433	01057W	PARTICIPANT	\N	PRESENT	0
80876	80433	14053L	PARTICIPANT	\N	PRESENT	0
80877	80433	01060R	PARTICIPANT	\N	PRESENT	0
80878	80433	95041E	PARTICIPANT	\N	PRESENT	0
80879	80433	86034E	PARTICIPANT	\N	PRESENT	0
80882	80433	04056J	PARTICIPANT	\N	PRESENT	0
80883	80433	04045F	PARTICIPANT	\N	PRESENT	0
80884	80433	04061F	PARTICIPANT	\N	PRESENT	0
80885	80433	98046X	PARTICIPANT	\N	PRESENT	0
80886	80433	11074Q	PARTICIPANT	\N	PRESENT	0
80887	80433	04079R	PARTICIPANT	\N	PRESENT	0
80888	80433	04055H	PARTICIPANT	\N	PRESENT	0
80889	80433	04078Q	PARTICIPANT	\N	PRESENT	0
80890	80433	98022P	PARTICIPANT	\N	PRESENT	0
64011	64010	90003B	PARTICIPANT	\N	PRESENT	0
66079	63782	01048V	PARTICIPANT	\N	PRESENT	0
66715	66714	01031L	PARTICIPANT	\N	PRESENT	0
66716	66714	08011M	PARTICIPANT	\N	PRESENT	0
66853	66852	98018T	PARTICIPANT	\N	PRESENT	0
66866	66865	14087W	PARTICIPANT	\N	PRESENT	0
67771	66605	14173T	PARTICIPANT	\N	PRESENT	0
67772	66605	01056V	PARTICIPANT	\N	PRESENT	0
67773	66605	11042G	PARTICIPANT	\N	PRESENT	0
67774	66605	14159V	PARTICIPANT	\N	PRESENT	0
67775	66605	14031R	PARTICIPANT	\N	PRESENT	0
67776	66605	12042Y	PARTICIPANT	\N	PRESENT	0
67777	66605	14251Q	PARTICIPANT	\N	PRESENT	0
67778	66605	01014K	PARTICIPANT	\N	PRESENT	0
67779	66605	11107G	PARTICIPANT	\N	PRESENT	0
67780	66605	14255U	PARTICIPANT	\N	PRESENT	0
67781	66605	11100Y	PARTICIPANT	\N	PRESENT	0
67782	66605	11032E	PARTICIPANT	\N	PRESENT	0
67783	66605	92031P	PARTICIPANT	\N	PRESENT	0
67784	66605	08035V	PARTICIPANT	\N	PRESENT	0
67785	66605	11113E	PARTICIPANT	\N	PRESENT	0
67786	66605	14039A	PARTICIPANT	\N	PRESENT	0
67787	66605	11109J	PARTICIPANT	\N	PRESENT	0
67788	66605	11037K	PARTICIPANT	\N	PRESENT	0
67789	66605	90003B	PARTICIPANT	\N	PRESENT	0
67790	66605	14195A	PARTICIPANT	\N	PRESENT	0
67791	66605	11043H	PARTICIPANT	\N	PRESENT	0
67792	66605	08028W	PARTICIPANT	\N	PRESENT	0
67793	66605	14215L	PARTICIPANT	\N	PRESENT	0
67794	66605	14199E	PARTICIPANT	\N	PRESENT	0
67795	66605	11049P	PARTICIPANT	\N	PRESENT	0
67796	66605	08069G	PARTICIPANT	\N	PRESENT	0
67797	66605	08010L	PARTICIPANT	\N	PRESENT	0
67798	66605	95041E	PARTICIPANT	\N	PRESENT	0
67814	66605	14059S	PARTICIPANT	\N	PRESENT	0
67800	66605	08034U	PARTICIPANT	\N	PRESENT	0
67801	66605	14037X	PARTICIPANT	\N	PRESENT	0
67802	66605	14071N	PARTICIPANT	\N	PRESENT	0
67803	66605	14119M	PARTICIPANT	\N	PRESENT	0
67804	66605	14265W	PARTICIPANT	\N	PRESENT	0
67815	66605	04044E	PARTICIPANT	\N	PRESENT	0
67806	66605	14111D	PARTICIPANT	\N	PRESENT	0
67807	66605	04092N	PARTICIPANT	\N	PRESENT	0
67808	66605	92040Q	PARTICIPANT	\N	PRESENT	0
67809	66605	14169X	PARTICIPANT	\N	PRESENT	0
67810	66605	08042U	PARTICIPANT	\N	PRESENT	0
67811	66605	11026G	PARTICIPANT	\N	PRESENT	0
67812	66605	14061L	PARTICIPANT	\N	PRESENT	0
67813	66605	11097X	PARTICIPANT	\N	PRESENT	0
67816	66605	14157T	PARTICIPANT	\N	PRESENT	0
67817	66605	04061F	PARTICIPANT	\N	PRESENT	0
67818	66605	11065P	PARTICIPANT	\N	PRESENT	0
67819	66605	01058X	PARTICIPANT	\N	PRESENT	0
67769	66605	04045F	PARTICIPANT	\N	PRESENT	0
67770	66605	11077T	PARTICIPANT	\N	PRESENT	0
67820	66605	14081Q	PARTICIPANT	\N	PRESENT	0
67821	66605	11034G	PARTICIPANT	\N	PRESENT	0
67822	66605	04049K	PARTICIPANT	\N	PRESENT	0
67823	66605	14085U	PARTICIPANT	\N	PRESENT	0
67824	66605	14103D	PARTICIPANT	\N	PRESENT	0
67825	66605	04080J	PARTICIPANT	\N	PRESENT	0
67826	66605	01019Q	PARTICIPANT	\N	PRESENT	0
68131	66606	08024S	PARTICIPANT	\N	PRESENT	0
68132	66606	04067M	PARTICIPANT	\N	PRESENT	0
68133	66606	00003C	PARTICIPANT	\N	PRESENT	0
68134	66606	11031D	PARTICIPANT	\N	PRESENT	0
68135	66606	12042Y	PARTICIPANT	\N	PRESENT	0
68136	66606	04045F	PARTICIPANT	\N	PRESENT	0
68137	66606	14271U	PARTICIPANT	\N	PRESENT	0
68138	66606	11027H	PARTICIPANT	\N	PRESENT	0
68139	66606	11067R	PARTICIPANT	\N	PRESENT	0
68140	66606	14121F	PARTICIPANT	\N	PRESENT	0
68141	66606	14014Q	PARTICIPANT	\N	PRESENT	0
68142	66606	11061K	PARTICIPANT	\N	PRESENT	0
68143	66606	01044R	PARTICIPANT	\N	PRESENT	0
68144	66606	11076S	PARTICIPANT	\N	PRESENT	0
68145	66606	01059Y	PARTICIPANT	\N	PRESENT	0
68146	66606	11034G	PARTICIPANT	\N	PRESENT	0
68147	66606	11063M	PARTICIPANT	\N	PRESENT	0
68148	66606	14219Q	PARTICIPANT	\N	PRESENT	0
68149	66606	14103D	PARTICIPANT	\N	PRESENT	0
68150	66606	11093T	PARTICIPANT	\N	PRESENT	0
68151	66606	14089Y	PARTICIPANT	\N	PRESENT	0
68152	66606	14273W	PARTICIPANT	\N	PRESENT	0
68153	66606	14237S	PARTICIPANT	\N	PRESENT	0
68154	66606	01043Q	PARTICIPANT	\N	PRESENT	0
68155	66606	14026U	PARTICIPANT	\N	PRESENT	0
68156	66606	08022Q	PARTICIPANT	\N	PRESENT	0
68157	66606	01027Q	PARTICIPANT	\N	PRESENT	0
68158	66606	14223L	PARTICIPANT	\N	PRESENT	0
68159	66606	14251Q	PARTICIPANT	\N	PRESENT	0
68160	66606	08048B	PARTICIPANT	\N	PRESENT	0
68161	66606	01025N	PARTICIPANT	\N	PRESENT	0
68162	66606	97011G	PARTICIPANT	\N	PRESENT	0
68163	66606	14265W	PARTICIPANT	\N	PRESENT	0
68164	66606	11091R	PARTICIPANT	\N	PRESENT	0
68165	66606	08062Y	PARTICIPANT	\N	PRESENT	0
68166	66606	07032N	PARTICIPANT	\N	PRESENT	0
68167	66606	07029T	PARTICIPANT	\N	PRESENT	0
68168	66606	14157T	PARTICIPANT	\N	PRESENT	0
68169	66606	14038Y	PARTICIPANT	\N	PRESENT	0
68170	66606	14073Q	PARTICIPANT	\N	PRESENT	0
68171	66606	04043D	PARTICIPANT	\N	PRESENT	0
68172	66606	14267Y	PARTICIPANT	\N	PRESENT	0
68173	66606	11082Q	PARTICIPANT	\N	PRESENT	0
68179	66606	14105F	PARTICIPANT	\N	PRESENT	0
68175	66606	11096W	PARTICIPANT	\N	PRESENT	0
68176	66606	14263U	PARTICIPANT	\N	PRESENT	0
68177	66606	14231L	PARTICIPANT	\N	PRESENT	0
68178	66606	14281W	PARTICIPANT	\N	PRESENT	0
68180	66606	92039X	PARTICIPANT	\N	PRESENT	0
68181	66606	11012A	PARTICIPANT	\N	PRESENT	0
68182	66606	14191V	PARTICIPANT	\N	PRESENT	0
68183	66606	14059S	PARTICIPANT	\N	PRESENT	0
68184	66880	11034G	PARTICIPANT	\N	PRESENT	0
68185	66880	04079R	PARTICIPANT	\N	PRESENT	0
68186	66880	04071H	PARTICIPANT	\N	PRESENT	0
68187	66880	14169X	PARTICIPANT	\N	PRESENT	0
68188	66605	14151M	PARTICIPANT	\N	PRESENT	0
68189	66606	14235Q	PARTICIPANT	\N	PRESENT	0
68190	66606	11056N	PARTICIPANT	\N	PRESENT	0
68191	66606	04053F	PARTICIPANT	\N	PRESENT	0
68192	66606	11042G	PARTICIPANT	\N	PRESENT	0
68193	66606	14159V	PARTICIPANT	\N	PRESENT	0
68194	66606	14018U	PARTICIPANT	\N	PRESENT	0
68195	66606	95062K	PARTICIPANT	\N	PRESENT	0
68196	66606	95030B	PARTICIPANT	\N	PRESENT	0
68258	66607	04066L	PARTICIPANT	\N	PRESENT	0
68276	66607	11034G	PARTICIPANT	\N	PRESENT	0
68277	66607	11026G	PARTICIPANT	\N	PRESENT	0
68278	66607	01028R	PARTICIPANT	\N	PRESENT	0
68279	66607	14055N	PARTICIPANT	\N	PRESENT	0
68280	66607	14331P	PARTICIPANT	\N	PRESENT	0
68281	66607	04047H	PARTICIPANT	\N	PRESENT	0
68282	66607	14038Y	PARTICIPANT	\N	PRESENT	0
68283	66607	95030B	PARTICIPANT	\N	PRESENT	0
68284	66607	11033F	PARTICIPANT	\N	PRESENT	0
68285	66607	01027Q	PARTICIPANT	\N	PRESENT	0
68286	66607	14253S	PARTICIPANT	\N	PRESENT	0
68287	66607	04035D	PARTICIPANT	\N	PRESENT	0
68288	66607	01008M	PARTICIPANT	\N	PRESENT	0
68289	66607	95015C	PARTICIPANT	\N	PRESENT	0
68290	66607	01043Q	PARTICIPANT	\N	PRESENT	0
68291	66607	01025N	PARTICIPANT	\N	PRESENT	0
68292	66607	14059S	PARTICIPANT	\N	PRESENT	0
68293	66607	14215L	PARTICIPANT	\N	PRESENT	0
68294	66607	14273W	PARTICIPANT	\N	PRESENT	0
68295	66607	04085P	PARTICIPANT	\N	PRESENT	0
68296	66607	11056N	PARTICIPANT	\N	PRESENT	0
68297	66607	11031D	PARTICIPANT	\N	PRESENT	0
68298	66607	14263U	PARTICIPANT	\N	PRESENT	0
68299	66607	14235Q	PARTICIPANT	\N	PRESENT	0
68300	66607	11105E	PARTICIPANT	\N	PRESENT	0
68301	66607	14065Q	PARTICIPANT	\N	PRESENT	0
68302	66607	04038G	PARTICIPANT	\N	PRESENT	0
68303	66607	04033B	PARTICIPANT	\N	PRESENT	0
68304	66607	07029T	PARTICIPANT	\N	PRESENT	0
68305	66607	14205J	PARTICIPANT	\N	PRESENT	0
68306	66607	14133K	PARTICIPANT	\N	PRESENT	0
68307	66607	12042Y	PARTICIPANT	\N	PRESENT	0
68308	66607	04045F	PARTICIPANT	\N	PRESENT	0
68309	66607	11057P	PARTICIPANT	\N	PRESENT	0
68310	66607	14089Y	PARTICIPANT	\N	PRESENT	0
75123	75073	14259Y	PARTICIPANT	\N	EXCUSE	0
75124	75073	08065C	PARTICIPANT	\N	EXCUSE	0
75125	71343	08065C	PARTICIPANT	\N	EXCUSE	0
75126	71343	08019V	PARTICIPANT	\N	EXCUSE	0
75127	75073	08019V	PARTICIPANT	\N	EXCUSE	0
75128	71343	11054L	PARTICIPANT	\N	EXCUSE	0
75129	75076	04094Q	PARTICIPANT	\N	EXCUSE	0
75130	75076	96003C	PARTICIPANT	\N	EXCUSE	0
75133	75076	96004D	PARTICIPANT	\N	EXCUSE	0
75218	75076	11010L	PARTICIPANT	\N	EXCUSE	0
75266	75265	01031L	PARTICIPANT	\N	PRESENT	0
75267	75265	98046X	PARTICIPANT	\N	PRESENT	0
75271	75270	01031L	PARTICIPANT	\N	PRESENT	0
75272	75270	98046X	PARTICIPANT	\N	PRESENT	0
75291	75273	11053K	PARTICIPANT	\N	PRESENT	0
75292	75273	88008L	PARTICIPANT	\N	PRESENT	0
75294	75273	08022Q	PARTICIPANT	\N	PRESENT	0
75295	75273	98053W	PARTICIPANT	\N	PRESENT	0
75296	75273	99004R	PARTICIPANT	\N	PRESENT	0
75297	75273	04061F	PARTICIPANT	\N	PRESENT	0
75298	75273	08061X	PARTICIPANT	\N	PRESENT	0
75299	75273	01016M	PARTICIPANT	\N	PRESENT	0
75301	75300	11053K	PARTICIPANT	\N	PRESENT	0
75302	75300	88008L	PARTICIPANT	\N	PRESENT	0
75305	75300	08022Q	PARTICIPANT	\N	PRESENT	0
75306	75300	98053W	PARTICIPANT	\N	PRESENT	0
75307	75300	99004R	PARTICIPANT	\N	PRESENT	0
75308	75300	04061F	PARTICIPANT	\N	PRESENT	0
75309	75300	08061X	PARTICIPANT	\N	PRESENT	0
75311	75300	01016M	PARTICIPANT	\N	PRESENT	0
75400	75398	08011M	PARTICIPANT	\N	PRESENT	0
75402	75398	01031L	PARTICIPANT	\N	PRESENT	0
75432	75426	08011M	PARTICIPANT	\N	PRESENT	0
75433	75426	01031L	PARTICIPANT	\N	PRESENT	0
75479	75473	08011M	PARTICIPANT	\N	PRESENT	0
75480	75473	01031L	PARTICIPANT	\N	PRESENT	0
75545	75542	08011M	PARTICIPANT	\N	PRESENT	0
75546	75542	01031L	PARTICIPANT	\N	PRESENT	0
75682	75679	08011M	PARTICIPANT	\N	PRESENT	0
75683	75679	01031L	PARTICIPANT	\N	PRESENT	0
75702	75700	08011M	PARTICIPANT	\N	PRESENT	0
75703	75700	01031L	PARTICIPANT	\N	PRESENT	0
75716	75712	08011M	PARTICIPANT	\N	PRESENT	0
75717	75712	01031L	PARTICIPANT	\N	PRESENT	0
75722	75721	08011M	PARTICIPANT	\N	PRESENT	0
75723	75721	01031L	PARTICIPANT	\N	PRESENT	0
75739	75738	08011M	PARTICIPANT	\N	PRESENT	0
75740	75738	01031L	PARTICIPANT	\N	PRESENT	0
75743	75742	08011M	PARTICIPANT	\N	PRESENT	0
75744	75742	01031L	PARTICIPANT	\N	PRESENT	0
75747	75746	98046X	PARTICIPANT	\N	PRESENT	0
75748	75746	01031L	PARTICIPANT	\N	PRESENT	0
83933	83932	04071H	PARTICIPANT	\N	PRESENT	0
84073	84072	14034U	PARTICIPANT	\N	PRESENT	0
84074	84072	14087W	PARTICIPANT	\N	PRESENT	0
84075	84072	14037X	PARTICIPANT	\N	PRESENT	0
84077	84076	14034U	PARTICIPANT	\N	PRESENT	0
84078	84076	14087W	PARTICIPANT	\N	PRESENT	0
84079	84076	14037X	PARTICIPANT	\N	PRESENT	0
84081	84080	14034U	PARTICIPANT	\N	PRESENT	0
84082	84080	14037X	PARTICIPANT	\N	PRESENT	0
84083	84080	14087W	PARTICIPANT	\N	PRESENT	0
85382	85339	08061X	PARTICIPANT	\N	PRESENT	0
85383	85339	01016M	PARTICIPANT	\N	PRESENT	0
85384	85339	14225N	PARTICIPANT	\N	PRESENT	0
85685	85636	92031P	PARTICIPANT	\N	PRESENT	0
85386	85339	11057P	PARTICIPANT	\N	PRESENT	0
85686	85636	98018T	PARTICIPANT	\N	PRESENT	0
85388	85339	04034C	PARTICIPANT	\N	PRESENT	0
85684	85636	07024N	PARTICIPANT	\N	PRESENT	0
85688	85636	04038G	PARTICIPANT	\N	PRESENT	0
85689	85636	14041T	PARTICIPANT	\N	PRESENT	0
85690	85636	01028R	PARTICIPANT	\N	PRESENT	0
85692	85636	95067Q	PARTICIPANT	\N	PRESENT	0
85693	85636	98022P	PARTICIPANT	\N	PRESENT	0
85694	85636	14273W	PARTICIPANT	\N	PRESENT	0
85695	85636	14065Q	PARTICIPANT	\N	PRESENT	0
85851	85849	89017R	PARTICIPANT	\N	PRESENT	0
85852	85849	11039M	PARTICIPANT	\N	PRESENT	0
85853	85849	08055A	PARTICIPANT	\N	PRESENT	0
85854	85849	04066L	PARTICIPANT	\N	PRESENT	0
85855	85849	04042C	PARTICIPANT	\N	PRESENT	0
85856	85849	04081K	PARTICIPANT	\N	PRESENT	0
85857	85849	04067M	PARTICIPANT	\N	PRESENT	0
85858	85849	98042T	PARTICIPANT	\N	PRESENT	0
85859	85849	11110B	PARTICIPANT	\N	PRESENT	0
85860	85849	01003G	PARTICIPANT	\N	PRESENT	0
85861	85849	98053W	PARTICIPANT	\N	PRESENT	0
85862	85849	01007L	PARTICIPANT	\N	PRESENT	0
85863	85849	95037J	PARTICIPANT	\N	PRESENT	0
85864	85849	86034E	PARTICIPANT	\N	PRESENT	0
85865	85849	04094Q	PARTICIPANT	\N	PRESENT	0
85866	85849	08039A	PARTICIPANT	\N	PRESENT	0
85867	85849	01043Q	PARTICIPANT	\N	PRESENT	0
85868	85849	11085T	PARTICIPANT	\N	PRESENT	0
85869	85849	04057K	PARTICIPANT	\N	PRESENT	0
85871	85849	92040Q	PARTICIPANT	\N	PRESENT	0
85872	85849	04088S	PARTICIPANT	\N	PRESENT	0
85873	85849	01019Q	PARTICIPANT	\N	PRESENT	0
85874	85849	04056J	PARTICIPANT	\N	PRESENT	0
85883	85882	14001X	PARTICIPANT	\N	PRESENT	0
86071	86070	89017R	PARTICIPANT	\N	PRESENT	0
86073	86072	89017R	PARTICIPANT	\N	PRESENT	0
86075	86074	89017R	PARTICIPANT	\N	PRESENT	0
86077	86076	04086Q	PARTICIPANT	\N	PRESENT	0
86721	86719	07004J	PARTICIPANT	\N	PRESENT	0
86722	86719	04040A	PARTICIPANT	\N	PRESENT	0
86723	86719	11082Q	PARTICIPANT	\N	PRESENT	0
86724	86719	10015M	PARTICIPANT	\N	PRESENT	0
86895	86892	04061F	PARTICIPANT	\N	PRESENT	0
86896	86892	08061X	PARTICIPANT	\N	PRESENT	0
86897	86892	01016M	PARTICIPANT	\N	PRESENT	0
86899	86898	92031P	PARTICIPANT	\N	PRESENT	0
86900	86898	11015D	PARTICIPANT	\N	PRESENT	0
86904	86903	11105E	PARTICIPANT	\N	PRESENT	0
86906	86905	92031P	PARTICIPANT	\N	PRESENT	0
86907	86905	11015D	PARTICIPANT	\N	PRESENT	0
86908	86905	11105E	PARTICIPANT	\N	PRESENT	0
86913	86912	14237S	PARTICIPANT	\N	PRESENT	0
86915	86914	14237S	PARTICIPANT	\N	PRESENT	0
86917	86916	14237S	PARTICIPANT	\N	PRESENT	0
86919	86918	14237S	PARTICIPANT	\N	PRESENT	0
86921	86920	14237S	PARTICIPANT	\N	PRESENT	0
86923	86922	14327T	PARTICIPANT	\N	PRESENT	0
86960	86959	14083S	PARTICIPANT	\N	PRESENT	0
86962	86961	01044R	PARTICIPANT	\N	PRESENT	0
86963	86961	08038Y	PARTICIPANT	\N	PRESENT	0
86964	86961	14281W	PARTICIPANT	\N	PRESENT	0
86965	86961	11077T	PARTICIPANT	\N	PRESENT	0
86966	86961	11072N	PARTICIPANT	\N	PRESENT	0
86967	86961	11094U	PARTICIPANT	\N	PRESENT	0
86968	86961	14227Q	PARTICIPANT	\N	PRESENT	0
86979	86978	98046X	PARTICIPANT	\N	PRESENT	0
86990	83952	14231L	PARTICIPANT	\N	PRESENT	0
86991	83952	01057W	PARTICIPANT	\N	PRESENT	0
86992	83952	11112D	PARTICIPANT	\N	PRESENT	0
86993	83952	11099A	PARTICIPANT	\N	EXCUSE	0
86994	83952	08010L	PARTICIPANT	\N	PRESENT	0
86995	83952	08034U	PARTICIPANT	\N	PRESENT	0
86996	83952	14063N	PARTICIPANT	\N	PRESENT	0
86997	83952	07032N	PARTICIPANT	\N	PRESENT	0
86998	83952	14051J	PARTICIPANT	\N	PRESENT	0
86999	83952	11037K	PARTICIPANT	\N	PRESENT	0
87000	83952	95067Q	PARTICIPANT	\N	EXCUSE	0
87001	83952	11049P	PARTICIPANT	\N	EXCUSE	0
87002	83952	11044J	PARTICIPANT	\N	EXCUSE	0
87003	83952	11101A	PARTICIPANT	\N	EXCUSE	0
62159	62060	01043Q	PARTICIPANT	\N	EXCUSE	0
62160	62060	14081Q	PARTICIPANT	\N	EXCUSE	0
62089	62060	14205J	PARTICIPANT	\N	PRESENT	0
62090	62060	08019V	PARTICIPANT	\N	PRESENT	0
62091	62060	14257W	PARTICIPANT	\N	PRESENT	0
62161	62060	01061S	PARTICIPANT	\N	EXCUSE	0
62093	62060	04088S	PARTICIPANT	\N	PRESENT	0
64007	60592	14053L	PARTICIPANT	\N	EXCUSE	0
62095	62060	11090Q	PARTICIPANT	\N	PRESENT	0
62096	62060	11046L	PARTICIPANT	\N	PRESENT	0
62097	62060	01058X	PARTICIPANT	\N	PRESENT	0
62098	62060	11094U	PARTICIPANT	\N	PRESENT	0
62099	62060	11066Q	PARTICIPANT	\N	PRESENT	0
64008	60592	14201E	PARTICIPANT	\N	EXCUSE	0
69861	68966	97011G	PARTICIPANT	\N	PRESENT	0
69862	68966	14037X	PARTICIPANT	\N	PRESENT	0
69863	68966	92044U	PARTICIPANT	\N	PRESENT	0
69864	68966	11080N	PARTICIPANT	\N	PRESENT	0
69865	68966	14261S	PARTICIPANT	\N	PRESENT	0
69866	68966	14069U	PARTICIPANT	\N	PRESENT	0
69867	68966	08010L	PARTICIPANT	\N	PRESENT	0
69868	68966	10015M	PARTICIPANT	\N	PRESENT	0
69869	68966	08031R	PARTICIPANT	\N	PRESENT	0
69870	68966	04038G	PARTICIPANT	\N	PRESENT	0
69871	68966	14241N	PARTICIPANT	\N	PRESENT	0
69872	68966	01008M	PARTICIPANT	\N	PRESENT	0
69873	68966	08049C	PARTICIPANT	\N	PRESENT	0
69874	68966	05008E	PARTICIPANT	\N	PRESENT	0
69875	68966	08016S	PARTICIPANT	\N	PRESENT	0
69876	68966	04048J	PARTICIPANT	\N	PRESENT	0
69877	68966	01016M	PARTICIPANT	\N	PRESENT	0
69878	68966	08069G	PARTICIPANT	\N	PRESENT	0
69879	68966	11039M	PARTICIPANT	\N	PRESENT	0
69880	68966	92015P	PARTICIPANT	\N	PRESENT	0
69881	68966	98046X	PARTICIPANT	\N	PRESENT	0
69859	68966	14093U	PARTICIPANT	\N	PRESENT	0
69860	68966	14147R	PARTICIPANT	\N	PRESENT	0
69882	68966	04086Q	PARTICIPANT	\N	PRESENT	0
69883	68966	08052W	PARTICIPANT	\N	PRESENT	0
69884	68966	98023Q	PARTICIPANT	\N	PRESENT	0
69885	68966	95063L	PARTICIPANT	\N	PRESENT	0
69886	68966	05012A	PARTICIPANT	\N	PRESENT	0
69887	68966	08025T	PARTICIPANT	\N	PRESENT	0
69888	68966	14151M	PARTICIPANT	\N	PRESENT	0
69889	68966	08055A	PARTICIPANT	\N	PRESENT	0
69890	68966	04066L	PARTICIPANT	\N	PRESENT	0
69891	68966	11027H	PARTICIPANT	\N	PRESENT	0
69892	68966	11044J	PARTICIPANT	\N	PRESENT	0
69893	68966	01011G	PARTICIPANT	\N	PRESENT	0
69894	68966	92020L	PARTICIPANT	\N	PRESENT	0
69895	68966	95015C	PARTICIPANT	\N	PRESENT	0
69896	68966	08060W	PARTICIPANT	\N	PRESENT	0
69897	68966	00003C	PARTICIPANT	\N	PRESENT	0
69898	68966	80013X	PARTICIPANT	\N	PRESENT	0
69899	68966	01022K	PARTICIPANT	\N	PRESENT	0
69900	68966	14197C	PARTICIPANT	\N	PRESENT	0
69901	68966	14065Q	PARTICIPANT	\N	PRESENT	0
69902	68966	11015D	PARTICIPANT	\N	PRESENT	0
69903	68966	08043V	PARTICIPANT	\N	PRESENT	0
69904	68966	08068F	PARTICIPANT	\N	PRESENT	0
69905	68966	11088W	PARTICIPANT	\N	PRESENT	0
69906	68966	11105E	PARTICIPANT	\N	PRESENT	0
69907	68966	11059R	PARTICIPANT	\N	PRESENT	0
69908	68966	11036J	PARTICIPANT	\N	PRESENT	0
69909	68966	80027E	PARTICIPANT	\N	PRESENT	0
69910	68966	11046L	PARTICIPANT	\N	PRESENT	0
69911	68966	14071N	PARTICIPANT	\N	PRESENT	0
69912	68966	08042U	PARTICIPANT	\N	PRESENT	0
69913	68966	83042R	PARTICIPANT	\N	PRESENT	0
69914	68966	08017T	PARTICIPANT	\N	PRESENT	0
69915	68966	04081K	PARTICIPANT	\N	PRESENT	0
69916	68966	11089X	PARTICIPANT	\N	PRESENT	0
69917	68966	95035G	PARTICIPANT	\N	PRESENT	0
69918	68966	08012N	PARTICIPANT	\N	PRESENT	0
69919	68966	08058D	PARTICIPANT	\N	PRESENT	0
69920	68966	11030C	PARTICIPANT	\N	PRESENT	0
69921	68966	14271U	PARTICIPANT	\N	PRESENT	0
69922	68966	90003B	PARTICIPANT	\N	PRESENT	0
69923	68966	14014Q	PARTICIPANT	\N	PRESENT	0
69924	68966	04043D	PARTICIPANT	\N	PRESENT	0
69925	68966	14109K	PARTICIPANT	\N	PRESENT	0
69926	68966	14207L	PARTICIPANT	\N	PRESENT	0
69927	68966	08014Q	PARTICIPANT	\N	PRESENT	0
69928	68966	14187A	PARTICIPANT	\N	PRESENT	0
69929	68966	11095V	PARTICIPANT	\N	PRESENT	0
69930	68966	14001X	PARTICIPANT	\N	PRESENT	0
69931	68966	11020A	PARTICIPANT	\N	PRESENT	0
69932	68966	14227Q	PARTICIPANT	\N	PRESENT	0
69933	68966	14087W	PARTICIPANT	\N	PRESENT	0
69934	68966	14167V	PARTICIPANT	\N	PRESENT	0
69935	68966	14097Y	PARTICIPANT	\N	PRESENT	0
69936	68966	04047H	PARTICIPANT	\N	PRESENT	0
69937	68966	11054L	PARTICIPANT	\N	PRESENT	0
69938	68966	11014C	PARTICIPANT	\N	PRESENT	0
69939	68966	14257W	PARTICIPANT	\N	PRESENT	0
69940	68966	14105F	PARTICIPANT	\N	PRESENT	0
69941	68966	13002U	PARTICIPANT	\N	PRESENT	0
69942	68966	05004A	PARTICIPANT	\N	PRESENT	0
69943	68966	11074Q	PARTICIPANT	\N	PRESENT	0
69944	68966	14063N	PARTICIPANT	\N	PRESENT	0
69945	68966	14121F	PARTICIPANT	\N	PRESENT	0
69946	68966	98021N	PARTICIPANT	\N	PRESENT	0
69947	68966	14229S	PARTICIPANT	\N	PRESENT	0
69948	68966	14281W	PARTICIPANT	\N	PRESENT	0
69949	68966	07024N	PARTICIPANT	\N	PRESENT	0
69950	68966	11061K	PARTICIPANT	\N	PRESENT	0
69951	68966	14225N	PARTICIPANT	\N	PRESENT	0
69952	68966	89029V	PARTICIPANT	\N	PRESENT	0
69953	68966	08061X	PARTICIPANT	\N	PRESENT	0
69954	68966	04053F	PARTICIPANT	\N	PRESENT	0
69955	68966	01028R	PARTICIPANT	\N	PRESENT	0
69956	68966	11104D	PARTICIPANT	\N	PRESENT	0
69957	68966	04049K	PARTICIPANT	\N	PRESENT	0
69958	68966	08038Y	PARTICIPANT	\N	PRESENT	0
69959	68966	14061L	PARTICIPANT	\N	PRESENT	0
69960	68966	11032E	PARTICIPANT	\N	PRESENT	0
69961	68966	11035H	PARTICIPANT	\N	PRESENT	0
69962	68966	01037S	PARTICIPANT	\N	PRESENT	0
69963	68966	08024S	PARTICIPANT	\N	PRESENT	0
69964	68966	08039A	PARTICIPANT	\N	PRESENT	0
69965	68966	04059M	PARTICIPANT	\N	PRESENT	0
69966	68966	11066Q	PARTICIPANT	\N	PRESENT	0
69967	68966	14085U	PARTICIPANT	\N	PRESENT	0
69968	68966	11106F	PARTICIPANT	\N	PRESENT	0
69969	68966	04092N	PARTICIPANT	\N	PRESENT	0
69970	68966	04057K	PARTICIPANT	\N	PRESENT	0
69971	68966	99002P	PARTICIPANT	\N	PRESENT	0
69972	68966	11067R	PARTICIPANT	\N	PRESENT	0
69973	68966	14123H	PARTICIPANT	\N	PRESENT	0
69974	68966	04045F	PARTICIPANT	\N	PRESENT	0
69976	68966	11077T	PARTICIPANT	\N	PRESENT	0
69977	68966	04094Q	PARTICIPANT	\N	PRESENT	0
69978	68966	11103C	PARTICIPANT	\N	PRESENT	0
69979	68966	04095R	PARTICIPANT	\N	PRESENT	0
69981	68966	14059S	PARTICIPANT	\N	PRESENT	0
69982	68966	14159V	PARTICIPANT	\N	PRESENT	0
69983	68966	12042Y	PARTICIPANT	\N	PRESENT	0
69985	68966	11042G	PARTICIPANT	\N	PRESENT	0
69986	68966	14213J	PARTICIPANT	\N	PRESENT	0
69988	68966	08035V	PARTICIPANT	\N	PRESENT	0
69990	68966	08073C	PARTICIPANT	\N	PRESENT	0
69993	68966	11023D	PARTICIPANT	\N	PRESENT	0
69995	68966	11037K	PARTICIPANT	\N	PRESENT	0
69996	68966	14053L	PARTICIPANT	\N	PRESENT	0
69997	68966	01014K	PARTICIPANT	\N	PRESENT	0
69998	68966	11107G	PARTICIPANT	\N	PRESENT	0
70000	68966	14173T	PARTICIPANT	\N	PRESENT	0
70003	68966	11114F	PARTICIPANT	\N	PRESENT	0
70006	68966	14041T	PARTICIPANT	\N	PRESENT	0
70007	68966	95049N	PARTICIPANT	\N	PRESENT	0
70008	68966	01043Q	PARTICIPANT	\N	PRESENT	0
70009	68966	11091R	PARTICIPANT	\N	PRESENT	0
70010	68966	01007L	PARTICIPANT	\N	PRESENT	0
70011	68966	14327T	PARTICIPANT	\N	PRESENT	0
70012	68966	04040A	PARTICIPANT	\N	PRESENT	0
70013	68966	14209N	PARTICIPANT	\N	PRESENT	0
70014	68966	01025N	PARTICIPANT	\N	PRESENT	0
70015	68966	11094U	PARTICIPANT	\N	PRESENT	0
70016	68966	01034P	PARTICIPANT	\N	PRESENT	0
70017	68966	01024M	PARTICIPANT	\N	PRESENT	0
70018	68966	07034Q	PARTICIPANT	\N	PRESENT	0
70019	68966	09001P	PARTICIPANT	\N	PRESENT	0
70020	68966	01047U	PARTICIPANT	\N	PRESENT	0
70021	68966	11053K	PARTICIPANT	\N	PRESENT	0
70022	68966	98042T	PARTICIPANT	\N	PRESENT	0
70023	68966	14255U	PARTICIPANT	\N	PRESENT	0
94527	94526	01057W	PARTICIPANT	\N	PRESENT	0
94528	94526	14225N	PARTICIPANT	\N	PRESENT	0
94530	94529	01057W	PARTICIPANT	\N	PRESENT	0
94531	94529	14225N	PARTICIPANT	\N	PRESENT	0
94532	94529	98046X	PARTICIPANT	\N	PRESENT	0
94533	94529	14175V	PARTICIPANT	\N	PRESENT	0
94534	94529	04086Q	PARTICIPANT	\N	PRESENT	0
94535	94529	11088W	PARTICIPANT	\N	PRESENT	0
94536	94529	01013J	PARTICIPANT	\N	PRESENT	0
94537	94529	14327T	PARTICIPANT	\N	PRESENT	0
94539	94538	01057W	PARTICIPANT	\N	PRESENT	0
94540	94538	14225N	PARTICIPANT	\N	PRESENT	0
94541	94538	04086Q	PARTICIPANT	\N	PRESENT	0
94542	94538	11070L	PARTICIPANT	\N	PRESENT	0
94543	94538	14327T	PARTICIPANT	\N	PRESENT	0
94544	94538	14175V	PARTICIPANT	\N	PRESENT	0
94545	94538	01013J	PARTICIPANT	\N	PRESENT	0
94546	94538	98046X	PARTICIPANT	\N	PRESENT	0
94547	94538	11012A	PARTICIPANT	\N	PRESENT	0
94549	94548	89017R	PARTICIPANT	\N	PRESENT	0
95651	95650	11076S	PARTICIPANT	\N	PRESENT	0
95715	95650	95037J	PARTICIPANT	\N	PRESENT	0
95653	95650	04040A	PARTICIPANT	\N	PRESENT	0
95654	95650	08058D	PARTICIPANT	\N	PRESENT	0
95655	95650	04042C	PARTICIPANT	\N	PRESENT	0
95656	95650	77002U	PARTICIPANT	\N	PRESENT	0
95657	95650	98029W	PARTICIPANT	\N	PRESENT	0
95658	95650	11080N	PARTICIPANT	\N	PRESENT	0
95659	95650	11027H	PARTICIPANT	\N	PRESENT	0
95660	95650	98018T	PARTICIPANT	\N	PRESENT	0
95661	95650	92018S	PARTICIPANT	\N	PRESENT	0
95662	95650	92020L	PARTICIPANT	\N	PRESENT	0
95663	95650	95030B	PARTICIPANT	\N	PRESENT	0
95664	95650	11096W	PARTICIPANT	\N	PRESENT	0
95665	95650	95031C	PARTICIPANT	\N	PRESENT	0
95666	95650	97011G	PARTICIPANT	\N	PRESENT	0
95667	95650	08065C	PARTICIPANT	\N	PRESENT	0
95668	95650	04035D	PARTICIPANT	\N	PRESENT	0
95669	95650	07024N	PARTICIPANT	\N	EXCUSE	0
95670	95650	04095R	PARTICIPANT	\N	PRESENT	0
95671	95650	14014Q	PARTICIPANT	\N	PRESENT	0
95672	95650	11015D	PARTICIPANT	\N	EXCUSE	0
95673	95650	07004J	PRESIDENT	0	PRESENT	0
95674	95650	95035G	PARTICIPANT	\N	EXCUSE	0
95675	95650	08056B	PARTICIPANT	\N	PRESENT	0
95720	95719	11076S	PARTICIPANT	\N	PRESENT	0
95677	95650	98022P	PARTICIPANT	\N	PRESENT	0
95678	95650	11064N	PARTICIPANT	\N	PRESENT	0
96141	89162	11068S	PARTICIPANT	\N	PRESENT	0
95681	95650	14097Y	PARTICIPANT	\N	PRESENT	0
95682	95650	95041E	PARTICIPANT	\N	PRESENT	0
95722	95719	04040A	PARTICIPANT	\N	PRESENT	0
95723	95719	08058D	PARTICIPANT	\N	PRESENT	0
95724	95719	04042C	PRESIDENT	0	PRESENT	0
95725	95719	77002U	PARTICIPANT	\N	PRESENT	0
95687	95650	92031P	PARTICIPANT	\N	PRESENT	0
95688	95650	11106F	PARTICIPANT	\N	PRESENT	0
95689	95650	14251Q	PARTICIPANT	\N	PRESENT	0
95690	95650	83042R	PARTICIPANT	\N	PRESENT	0
95691	95650	08053X	PARTICIPANT	\N	PRESENT	0
95692	95650	11082Q	PARTICIPANT	\N	EXCUSE	0
95693	95650	11105E	PARTICIPANT	\N	PRESENT	0
95694	95650	14253S	PARTICIPANT	\N	PRESENT	0
95695	95650	08047A	PARTICIPANT	\N	PRESENT	0
95696	95650	14028W	PARTICIPANT	\N	PRESENT	0
95697	95650	14193X	PARTICIPANT	\N	PRESENT	0
95698	95650	98021N	PARTICIPANT	\N	PRESENT	0
95699	95650	04080J	PARTICIPANT	\N	PRESENT	0
95700	95650	95059Q	PARTICIPANT	\N	EXCUSE	0
95701	95650	86044G	PARTICIPANT	\N	PRESENT	0
95702	95650	01014K	PARTICIPANT	\N	PRESENT	0
95703	95650	11054L	PARTICIPANT	\N	PRESENT	0
95704	95650	01056V	PARTICIPANT	\N	EXCUSE	0
95705	95650	92044U	PARTICIPANT	\N	PRESENT	0
95706	95650	08049C	PARTICIPANT	\N	PRESENT	0
95707	95650	04050C	PARTICIPANT	\N	PRESENT	0
95726	95719	98029W	PARTICIPANT	\N	PRESENT	0
95727	95719	11080N	PARTICIPANT	\N	PRESENT	0
95728	95719	11027H	PARTICIPANT	\N	PRESENT	0
95729	95719	98018T	PARTICIPANT	\N	PRESENT	0
95730	95719	92018S	PARTICIPANT	\N	PRESENT	0
95731	95719	92020L	PARTICIPANT	\N	PRESENT	0
95732	95719	95030B	PARTICIPANT	\N	PRESENT	0
95733	95719	11096W	PARTICIPANT	\N	PRESENT	0
95734	95719	95031C	PARTICIPANT	\N	PRESENT	0
95735	95719	97011G	PARTICIPANT	\N	PRESENT	0
95736	95719	08065C	PARTICIPANT	\N	PRESENT	0
95737	95719	04035D	PARTICIPANT	\N	PRESENT	0
95738	95719	07024N	PARTICIPANT	\N	PRESENT	0
95739	95719	04095R	PARTICIPANT	\N	PRESENT	0
95740	95719	14014Q	PARTICIPANT	\N	PRESENT	0
95741	95719	11015D	PARTICIPANT	\N	EXCUSE	0
95742	95719	07004J	PARTICIPANT	\N	PRESENT	0
95743	95719	95035G	PARTICIPANT	\N	PRESENT	0
95744	95719	08056B	PARTICIPANT	\N	PRESENT	0
97415	97214	14257W	PARTICIPANT	\N	EXCUSE	0
95746	95719	98022P	PARTICIPANT	\N	PRESENT	0
95747	95719	11064N	PARTICIPANT	\N	PRESENT	0
95748	95719	95037J	PARTICIPANT	\N	PRESENT	0
97552	94613	11106F	PARTICIPANT	\N	EXCUSE	0
95750	95719	14097Y	PARTICIPANT	\N	PRESENT	0
95751	95719	95041E	PARTICIPANT	\N	PRESENT	0
97814	97811	04040A	PARTICIPANT	\N	PRESENT	0
95756	95719	92031P	PARTICIPANT	\N	PRESENT	0
95757	95719	11106F	PARTICIPANT	\N	PRESENT	0
95758	95719	14251Q	PARTICIPANT	\N	PRESENT	0
95759	95719	83042R	PARTICIPANT	\N	PRESENT	0
95760	95719	08053X	PARTICIPANT	\N	PRESENT	0
95761	95719	11082Q	PARTICIPANT	\N	EXCUSE	0
95762	95719	11105E	PARTICIPANT	\N	PRESENT	0
95763	95719	14253S	PARTICIPANT	\N	PRESENT	0
95764	95719	08047A	PARTICIPANT	\N	PRESENT	0
95765	95719	14028W	PARTICIPANT	\N	PRESENT	0
95766	95719	14193X	PARTICIPANT	\N	PRESENT	0
95767	95719	98021N	PARTICIPANT	\N	PRESENT	0
95768	95719	04080J	PARTICIPANT	\N	PRESENT	0
95769	95719	95059Q	PARTICIPANT	\N	EXCUSE	0
95770	95719	86044G	PARTICIPANT	\N	PRESENT	0
95771	95719	01014K	PARTICIPANT	\N	PRESENT	0
95772	95719	11054L	PARTICIPANT	\N	PRESENT	0
95773	95719	01056V	PARTICIPANT	\N	PRESENT	0
95774	95719	92044U	PARTICIPANT	\N	PRESENT	0
95775	95719	08049C	PARTICIPANT	\N	PRESENT	0
95776	95719	04050C	PARTICIPANT	\N	PRESENT	0
97816	97811	04042C	PARTICIPANT	\N	PRESENT	0
97821	97811	98018T	PARTICIPANT	\N	PRESENT	0
97822	97811	92018S	PARTICIPANT	\N	PRESENT	0
97823	97811	92020L	PARTICIPANT	\N	EXCUSE	0
97824	97811	95030B	PARTICIPANT	\N	PRESENT	0
97826	97811	95031C	PARTICIPANT	\N	PRESENT	0
97827	97811	97011G	PARTICIPANT	\N	PRESENT	0
97829	97811	04035D	PARTICIPANT	\N	PRESENT	0
97830	97811	07024N	PARTICIPANT	\N	PRESENT	0
97834	97811	07004J	PARTICIPANT	\N	EXCUSE	0
97835	97811	95035G	PARTICIPANT	\N	PRESENT	0
97840	97811	95037J	PARTICIPANT	\N	PRESENT	0
97841	97811	04078Q	PARTICIPANT	\N	PRESENT	0
97844	97811	04036E	PARTICIPANT	\N	PRESENT	0
97845	97811	14039A	PARTICIPANT	\N	EXCUSE	0
97848	97811	92031P	PARTICIPANT	\N	PRESENT	0
97849	97811	11106F	PARTICIPANT	\N	EXCUSE	0
97854	97811	11105E	PARTICIPANT	\N	EXCUSE	0
119755	119730	07034Q	PARTICIPANT	\N	EXCUSE	0
119756	119730	95063L	PARTICIPANT	\N	PRESENT	0
119757	119730	01019Q	PARTICIPANT	\N	PRESENT	0
119758	119730	01028R	PARTICIPANT	\N	EXCUSE	0
119759	119730	04056J	PARTICIPANT	\N	PRESENT	0
119760	119730	04044E	PRESIDENT	1	PRESENT	0
119761	119730	11037K	PARTICIPANT	\N	PRESENT	0
119762	119730	95067Q	PARTICIPANT	\N	PRESENT	0
119763	119632	04071H	PARTICIPANT	\N	PRESENT	0
119764	119632	11074Q	PARTICIPANT	\N	PRESENT	0
119765	119632	98053W	PARTICIPANT	\N	EXCUSE	0
119766	119632	08016S	PARTICIPANT	\N	PRESENT	0
119767	119632	08069G	PARTICIPANT	\N	PRESENT	0
119768	119632	11048N	PARTICIPANT	\N	PRESENT	0
119769	119632	99004R	PARTICIPANT	\N	PRESENT	0
119770	119632	04061F	PARTICIPANT	\N	PRESENT	0
119771	119632	14159V	PARTICIPANT	\N	PRESENT	0
119772	119632	07029T	PARTICIPANT	\N	EXCUSE	0
119773	119632	08010L	PARTICIPANT	\N	PRESENT	0
119774	119632	01048V	PARTICIPANT	\N	PRESENT	0
119775	119632	98046X	PARTICIPANT	\N	PRESENT	0
119776	119632	08011M	PARTICIPANT	\N	PRESENT	0
119777	119632	08061X	PARTICIPANT	\N	EXCUSE	0
119778	119632	14225N	PARTICIPANT	\N	PRESENT	0
119779	119632	11012A	PARTICIPANT	\N	PRESENT	0
119780	119632	11057P	PARTICIPANT	\N	PRESENT	0
119781	119632	14173T	PARTICIPANT	\N	PRESENT	0
119782	119632	04034C	PARTICIPANT	\N	PRESENT	0
119784	119783	08010L	PARTICIPANT	\N	PRESENT	0
119786	119785	08010L	PARTICIPANT	\N	PRESENT	0
119788	119787	08010L	PARTICIPANT	\N	PRESENT	0
119790	119789	04054G	PARTICIPANT	\N	PRESENT	0
119791	119789	92031P	PRESIDENT	0	PRESENT	0
119792	119789	11026G	PARTICIPANT	\N	PRESENT	0
119793	119789	11084S	PARTICIPANT	\N	PRESENT	0
119794	119789	14001X	PARTICIPANT	\N	PRESENT	0
119796	119795	04086Q	PARTICIPANT	\N	PRESENT	0
119797	119795	12042Y	PRESIDENT	0	PRESENT	0
119798	119795	11061K	PARTICIPANT	\N	PRESENT	0
119799	119795	14014Q	PARTICIPANT	\N	PRESENT	0
119800	119795	11112D	PARTICIPANT	\N	PRESENT	0
119801	119795	14037X	PARTICIPANT	\N	PRESENT	0
119802	119795	14205J	PARTICIPANT	\N	PRESENT	0
119803	119795	11100Y	PARTICIPANT	\N	PRESENT	0
119804	119795	11097X	PARTICIPANT	\N	PRESENT	0
119805	119795	04050C	PARTICIPANT	\N	PRESENT	0
119806	119795	14255U	PARTICIPANT	\N	EXCUSE	0
119807	119795	04067M	PARTICIPANT	\N	EXCUSE	0
119808	119795	11107G	PARTICIPANT	\N	EXCUSE	0
119809	119795	01027Q	PARTICIPANT	\N	EXCUSE	0
119810	119795	14227Q	PARTICIPANT	\N	EXCUSE	0
119811	119795	04092N	PARTICIPANT	\N	EXCUSE	0
119812	119795	04049K	PARTICIPANT	\N	EXCUSE	0
119835	119834	01034P	PARTICIPANT	\N	PRESENT	0
119837	119836	01034P	PARTICIPANT	\N	PRESENT	0
119841	119840	14331P	PARTICIPANT	\N	PRESENT	0
119843	119842	14331P	PARTICIPANT	\N	PRESENT	0
119845	119844	14331P	PARTICIPANT	\N	PRESENT	0
119891	119890	04086Q	PARTICIPANT	\N	PRESENT	0
119893	119892	04086Q	PARTICIPANT	\N	PRESENT	0
119895	119894	04086Q	PARTICIPANT	\N	PRESENT	0
119901	119900	08017T	PARTICIPANT	\N	PRESENT	0
119902	119900	01041N	PARTICIPANT	\N	PRESENT	0
119904	119903	08017T	PARTICIPANT	\N	PRESENT	0
119905	119903	01041N	PARTICIPANT	\N	PRESENT	0
119907	119906	14133K	PARTICIPANT	\N	PRESENT	0
119909	119908	14133K	PARTICIPANT	\N	PRESENT	0
119915	119914	14215L	PARTICIPANT	\N	PRESENT	0
119917	119916	01047U	PARTICIPANT	\N	PRESENT	0
119918	119916	04047H	PARTICIPANT	\N	PRESENT	0
119919	119916	05008E	PARTICIPANT	\N	PRESENT	0
119920	119916	01024M	PARTICIPANT	\N	PRESENT	0
119922	119921	14215L	PARTICIPANT	\N	PRESENT	0
119924	119923	01034P	PARTICIPANT	\N	PRESENT	0
119926	119925	11093T	PARTICIPANT	\N	PRESENT	0
119927	119925	01034P	PARTICIPANT	\N	PRESENT	0
119929	119928	01034P	PARTICIPANT	\N	PRESENT	0
119993	119992	14071N	PARTICIPANT	\N	PRESENT	0
119999	119998	05008E	PRESIDENT	0	PRESENT	0
120000	119998	11033F	PARTICIPANT	\N	PRESENT	0
120001	119998	14065Q	PARTICIPANT	\N	PRESENT	0
120002	119998	14069U	PARTICIPANT	\N	PRESENT	0
120003	119998	04047H	PARTICIPANT	\N	PRESENT	0
120004	119998	11056N	PARTICIPANT	\N	EXCUSE	0
120005	119998	14259Y	PARTICIPANT	\N	PRESENT	0
120006	119998	14041T	PARTICIPANT	\N	PRESENT	0
120007	119998	01024M	PARTICIPANT	\N	PRESENT	0
120008	119998	11010L	PARTICIPANT	\N	PRESENT	0
120009	119998	01007L	PARTICIPANT	\N	PRESENT	0
120010	119998	11026G	PARTICIPANT	\N	PRESENT	0
120011	119998	14111D	PARTICIPANT	\N	PRESENT	0
120012	119998	14273W	PARTICIPANT	\N	PRESENT	0
120013	119998	08051V	PARTICIPANT	\N	PRESENT	0
120014	119998	11072N	PARTICIPANT	\N	PRESENT	0
120015	119998	07034Q	PARTICIPANT	\N	PRESENT	0
120016	119998	04074L	PARTICIPANT	\N	PRESENT	0
120017	119998	95063L	PARTICIPANT	\N	PRESENT	0
120018	119998	01028R	PARTICIPANT	\N	PRESENT	0
120019	119998	04056J	PARTICIPANT	\N	PRESENT	0
120020	119998	04044E	PARTICIPANT	\N	PRESENT	0
120022	120021	01046T	PARTICIPANT	\N	PRESENT	0
120024	120023	14071N	PARTICIPANT	\N	PRESENT	0
120166	118920	09001P	PARTICIPANT	\N	PRESENT	0
120167	118920	11091R	PARTICIPANT	\N	PRESENT	0
120168	118920	97011G	PARTICIPANT	\N	PRESENT	0
120170	120169	11036J	PARTICIPANT	\N	PRESENT	0
120171	120169	14030Q	PARTICIPANT	\N	PRESENT	0
120172	120169	01044R	PARTICIPANT	\N	PRESENT	0
120173	120169	11029K	PARTICIPANT	\N	PRESENT	0
120174	120169	14038Y	PARTICIPANT	\N	PRESENT	0
120175	120169	80013X	PARTICIPANT	\N	PRESENT	0
120176	120169	01015L	PARTICIPANT	\N	PRESENT	0
120177	120169	14197C	PARTICIPANT	\N	PRESENT	0
120178	120169	11049P	PARTICIPANT	\N	PRESENT	0
120179	120169	14219Q	PARTICIPANT	\N	PRESENT	0
120180	120169	14031R	PARTICIPANT	\N	PRESENT	0
120181	120169	04057K	PARTICIPANT	\N	PRESENT	0
120182	120169	14237S	PARTICIPANT	\N	PRESENT	0
120183	120169	01016M	PARTICIPANT	\N	PRESENT	0
120184	118920	14257W	PARTICIPANT	\N	PRESENT	0
120185	120169	04043D	PARTICIPANT	\N	EXCUSE	0
120187	120169	14107H	PARTICIPANT	\N	EXCUSE	0
120188	118920	08022Q	PARTICIPANT	\N	PRESENT	0
120189	118920	11030C	PARTICIPANT	\N	PRESENT	0
120190	118920	14199E	PARTICIPANT	\N	PRESENT	0
120192	120191	11039M	PARTICIPANT	\N	PRESENT	0
120193	120191	98042T	PARTICIPANT	\N	PRESENT	0
120194	120191	01019Q	PARTICIPANT	\N	PRESENT	0
120252	118920	08060W	PARTICIPANT	\N	PRESENT	0
120253	118920	11026G	PARTICIPANT	\N	PRESENT	0
120254	118920	14111D	PARTICIPANT	\N	PRESENT	0
120255	118920	95062K	PARTICIPANT	\N	PRESENT	0
120256	118920	01058X	PARTICIPANT	\N	PRESENT	0
120257	118920	01015L	PARTICIPANT	\N	PRESENT	0
120258	118920	04038G	PARTICIPANT	\N	PRESENT	0
120259	118920	08053X	PARTICIPANT	\N	PRESENT	0
120260	118920	11098Y	PARTICIPANT	\N	PRESENT	0
120261	118920	95030B	PARTICIPANT	\N	PRESENT	0
120262	118920	01043Q	PARTICIPANT	\N	PRESENT	0
120263	118920	14187A	PARTICIPANT	\N	PRESENT	0
120264	119913	04049K	PARTICIPANT	\N	PRESENT	0
120265	119913	04055H	PARTICIPANT	\N	PRESENT	0
120266	119913	11063M	PARTICIPANT	\N	PRESENT	0
120267	119913	14151M	PARTICIPANT	\N	PRESENT	0
120268	119913	14030Q	PARTICIPANT	\N	PRESENT	0
120269	119913	14253S	PARTICIPANT	\N	PRESENT	0
120270	119913	14041T	PARTICIPANT	\N	PRESENT	0
120271	119913	11090Q	PARTICIPANT	\N	PRESENT	0
120272	119913	14255U	PARTICIPANT	\N	PRESENT	0
120273	119913	14207L	PARTICIPANT	\N	PRESENT	0
120274	119913	89017R	PARTICIPANT	\N	PRESENT	0
120275	119913	14105F	PARTICIPANT	\N	PRESENT	0
120276	119913	14087W	PARTICIPANT	\N	PRESENT	0
120277	119913	14265W	PARTICIPANT	\N	PRESENT	0
120278	119913	14061L	PARTICIPANT	\N	PRESENT	0
120279	119913	14157T	PARTICIPANT	\N	PRESENT	0
120280	119913	08068F	PARTICIPANT	\N	PRESENT	0
120281	119913	14083S	PARTICIPANT	\N	PRESENT	0
120282	119913	14034U	PARTICIPANT	\N	PRESENT	0
120283	118920	14042U	PARTICIPANT	\N	PRESENT	0
120284	119913	14065Q	PARTICIPANT	\N	EXCUSE	0
120285	119913	14013P	PARTICIPANT	\N	EXCUSE	0
120286	119913	14261S	PARTICIPANT	\N	EXCUSE	0
120287	119913	14079W	PARTICIPANT	\N	EXCUSE	0
120288	119913	11088W	PARTICIPANT	\N	EXCUSE	0
120289	119913	04053F	PARTICIPANT	\N	EXCUSE	0
94073	94072	96004D	PARTICIPANT	\N	PRESENT	0
94074	94072	14073Q	PARTICIPANT	\N	PRESENT	0
94075	94072	01016M	PARTICIPANT	\N	PRESENT	0
94076	94072	04034C	PARTICIPANT	\N	PRESENT	0
94457	94456	86044G	PARTICIPANT	\N	PRESENT	0
94459	94458	86044G	PARTICIPANT	\N	PRESENT	0
94460	94458	11027H	PARTICIPANT	\N	PRESENT	0
94462	94461	86044G	PARTICIPANT	\N	PRESENT	0
94463	94461	11027H	PARTICIPANT	\N	PRESENT	0
94465	94464	04042C	PARTICIPANT	\N	PRESENT	0
94466	94464	14028W	PARTICIPANT	\N	PRESENT	0
94467	94464	01056V	PARTICIPANT	\N	PRESENT	0
94469	94468	04040A	PARTICIPANT	\N	PRESENT	0
94470	94468	14097Y	PARTICIPANT	\N	PRESENT	0
94471	94468	08058D	PARTICIPANT	\N	PRESENT	0
94473	94472	04040A	PARTICIPANT	\N	PRESENT	0
94474	94472	14097Y	PARTICIPANT	\N	PRESENT	0
94476	94475	08058D	PARTICIPANT	\N	PRESENT	0
94478	94477	04040A	PARTICIPANT	\N	PRESENT	0
94479	94477	14097Y	PARTICIPANT	\N	PRESENT	0
94480	94477	08058D	PARTICIPANT	\N	PRESENT	0
94482	94481	07024N	PARTICIPANT	\N	PRESENT	0
94483	94481	01014K	PARTICIPANT	\N	PRESENT	0
94484	94481	04040A	PARTICIPANT	\N	PRESENT	0
94485	94481	11106F	PARTICIPANT	\N	PRESENT	0
94486	94481	14193X	PARTICIPANT	\N	PRESENT	0
94488	94487	07024N	PARTICIPANT	\N	PRESENT	0
94489	94487	01014K	PARTICIPANT	\N	PRESENT	0
94490	94487	11106F	PARTICIPANT	\N	PRESENT	0
94491	94487	14193X	PARTICIPANT	\N	PRESENT	0
94492	94487	11054L	PARTICIPANT	\N	PRESENT	0
94494	94493	07024N	PARTICIPANT	\N	PRESENT	0
94495	94493	01014K	PARTICIPANT	\N	PRESENT	0
94496	94493	14193X	PARTICIPANT	\N	PRESENT	0
94498	94497	11064N	PARTICIPANT	\N	PRESENT	0
94500	94499	01014K	PARTICIPANT	\N	PRESENT	0
94501	91448	14017T	PARTICIPANT	\N	EXCUSE	0
98813	98812	01008M	PARTICIPANT	\N	PRESENT	0
98814	98812	11036J	PARTICIPANT	\N	PRESENT	0
98815	98812	11081P	PARTICIPANT	\N	PRESENT	0
98816	98812	14013P	PARTICIPANT	\N	PRESENT	0
98817	98812	08068F	PARTICIPANT	\N	PRESENT	0
98818	98812	14207L	PARTICIPANT	\N	PRESENT	0
98819	98812	11101A	PARTICIPANT	\N	PRESENT	0
98820	98812	90003B	PARTICIPANT	\N	EXCUSE	0
98821	98812	08028W	PARTICIPANT	\N	PRESENT	0
98822	98812	80013X	PARTICIPANT	\N	PRESENT	0
98823	98812	08038Y	PARTICIPANT	\N	PRESENT	0
98824	98812	04089T	PARTICIPANT	\N	PRESENT	0
98825	98812	14197C	PARTICIPANT	\N	PRESENT	0
98853	98852	01008M	PARTICIPANT	\N	PRESENT	0
98827	98812	14187A	PARTICIPANT	\N	PRESENT	0
98828	98812	14033T	PARTICIPANT	\N	PRESENT	0
98854	98852	11036J	PARTICIPANT	\N	PRESENT	0
98830	98812	04048J	PARTICIPANT	\N	PRESENT	0
98831	98812	11099A	PARTICIPANT	\N	PRESENT	0
98832	98812	04049K	PARTICIPANT	\N	PRESENT	0
98833	98812	04094Q	PARTICIPANT	\N	PRESENT	0
98855	98852	11081P	PARTICIPANT	\N	PRESENT	0
98835	98812	08015R	PARTICIPANT	\N	PRESENT	0
98836	98812	11100Y	PRESIDENT	0	PRESENT	0
98837	98812	01061S	PARTICIPANT	\N	EXCUSE	0
98838	98812	11098Y	PARTICIPANT	\N	PRESENT	0
98839	98812	01043Q	PARTICIPANT	\N	PRESENT	0
98840	98812	11077T	PARTICIPANT	\N	PRESENT	0
98841	98812	14205J	PARTICIPANT	\N	PRESENT	0
98842	98812	08019V	PARTICIPANT	\N	PRESENT	0
98843	98812	14257W	PARTICIPANT	\N	PRESENT	0
98844	98812	08021P	PARTICIPANT	\N	PRESENT	0
98845	98812	04088S	PARTICIPANT	\N	PRESENT	0
98846	98812	98050T	PARTICIPANT	\N	PRESENT	0
98953	98812	11110B	PARTICIPANT	\N	PRESENT	0
98848	98812	11046L	PARTICIPANT	\N	PRESENT	0
98849	98812	01058X	PARTICIPANT	\N	PRESENT	0
98850	98812	11094U	PARTICIPANT	\N	PRESENT	0
98851	98812	11066Q	PARTICIPANT	\N	PRESENT	0
98856	98852	14013P	PARTICIPANT	\N	PRESENT	0
98857	98852	08068F	PARTICIPANT	\N	PRESENT	0
98858	98852	14207L	PARTICIPANT	\N	PRESENT	0
98859	98852	11101A	PARTICIPANT	\N	PRESENT	0
98860	98852	90003B	PARTICIPANT	\N	EXCUSE	0
98861	98852	08028W	PARTICIPANT	\N	PRESENT	0
98862	98852	80013X	PARTICIPANT	\N	PRESENT	0
98863	98852	08038Y	PARTICIPANT	\N	PRESENT	0
98864	98852	04089T	PARTICIPANT	\N	PRESENT	0
98865	98852	14197C	PARTICIPANT	\N	PRESENT	0
98866	98852	11110B	PARTICIPANT	\N	PRESENT	0
98867	98852	14187A	PARTICIPANT	\N	PRESENT	0
98868	98852	14033T	PARTICIPANT	\N	PRESENT	0
98954	98812	11111C	PARTICIPANT	\N	PRESENT	0
98870	98852	04048J	PARTICIPANT	\N	PRESENT	0
98871	98852	11099A	PARTICIPANT	\N	PRESENT	0
98872	98852	04049K	PARTICIPANT	\N	PRESENT	0
98873	98852	04094Q	PARTICIPANT	\N	PRESENT	0
98874	98852	11111C	PARTICIPANT	\N	PRESENT	0
98875	98852	08015R	PARTICIPANT	\N	PRESENT	0
98876	98852	11100Y	PRESIDENT	0	PRESENT	0
98877	98852	01061S	PARTICIPANT	\N	EXCUSE	0
98878	98852	11098Y	PARTICIPANT	\N	PRESENT	0
98879	98852	01043Q	PARTICIPANT	\N	PRESENT	0
98880	98852	11077T	PARTICIPANT	\N	PRESENT	0
98881	98852	14205J	PARTICIPANT	\N	PRESENT	0
98882	98852	08019V	PARTICIPANT	\N	PRESENT	0
98883	98852	14257W	PARTICIPANT	\N	PRESENT	0
98884	98852	08021P	PARTICIPANT	\N	PRESENT	0
98885	98852	04088S	PARTICIPANT	\N	PRESENT	0
98886	98852	98050T	PARTICIPANT	\N	PRESENT	0
98887	98852	11090Q	PARTICIPANT	\N	PRESENT	0
98888	98852	11046L	PARTICIPANT	\N	PRESENT	0
98889	98852	01058X	PARTICIPANT	\N	PRESENT	0
98890	98852	11094U	PARTICIPANT	\N	PRESENT	0
98891	98852	11066Q	PARTICIPANT	\N	PRESENT	0
98955	98812	11090Q	PARTICIPANT	\N	PRESENT	0
99733	99732	04053F	PARTICIPANT	\N	PRESENT	0
99734	99732	14255U	PARTICIPANT	\N	PRESENT	0
99735	99732	04066L	PARTICIPANT	\N	PRESENT	0
99736	99732	14053L	PARTICIPANT	\N	PRESENT	0
99737	99732	11103C	PARTICIPANT	\N	PRESENT	0
99738	99732	11044J	PARTICIPANT	\N	PRESENT	0
99739	99732	08052W	PARTICIPANT	\N	PRESENT	0
99741	99732	01059Y	PARTICIPANT	\N	PRESENT	0
99742	99732	14217N	PARTICIPANT	\N	PRESENT	0
99743	99732	14042U	PARTICIPANT	\N	PRESENT	0
99744	99732	14151M	PARTICIPANT	\N	PRESENT	0
99745	99732	14281W	PARTICIPANT	\N	PRESENT	0
99746	99732	14087W	PARTICIPANT	\N	PRESENT	0
99747	99732	14034U	PARTICIPANT	\N	PRESENT	0
99748	99732	14231L	PARTICIPANT	\N	PRESENT	0
99749	99732	11061K	PARTICIPANT	\N	PRESENT	0
99750	99732	08041T	PARTICIPANT	\N	EXCUSE	0
99751	99732	14213J	PARTICIPANT	\N	PRESENT	0
99752	99732	11112D	PARTICIPANT	\N	PRESENT	0
99753	99732	14037X	PARTICIPANT	\N	PRESENT	0
99754	99732	11067R	PARTICIPANT	\N	PRESENT	0
99755	99732	14223L	PARTICIPANT	\N	PRESENT	0
99756	99732	04092N	PRESIDENT	0	PRESENT	0
99757	99732	14265W	PARTICIPANT	\N	PRESENT	0
99758	99732	14071N	PARTICIPANT	\N	PRESENT	0
99759	99732	14271U	PARTICIPANT	\N	PRESENT	0
99760	99732	11093T	PARTICIPANT	\N	PRESENT	0
99761	99732	11097X	PARTICIPANT	\N	PRESENT	0
99762	99732	14227Q	PARTICIPANT	\N	PRESENT	0
99763	99732	11063M	PARTICIPANT	\N	PRESENT	0
99876	99875	01008M	PARTICIPANT	\N	PRESENT	0
99877	99875	14069U	PARTICIPANT	\N	PRESENT	0
99881	99875	14033T	PARTICIPANT	\N	PRESENT	0
99879	99875	88008L	PARTICIPANT	\N	PRESENT	0
99880	99875	01003G	PARTICIPANT	\N	PRESENT	0
99882	99875	04097T	PARTICIPANT	\N	PRESENT	0
99883	99875	14265W	PARTICIPANT	\N	PRESENT	0
99884	99875	14119M	PARTICIPANT	\N	PRESENT	0
99885	99875	04088S	PARTICIPANT	\N	PRESENT	0
99886	99875	95062K	PARTICIPANT	\N	PRESENT	0
99887	99875	92045V	PARTICIPANT	\N	PRESENT	0
99893	99892	04038G	PARTICIPANT	\N	PRESENT	0
100053	100052	14030Q	PARTICIPANT	\N	PRESENT	0
100054	100052	11029K	PARTICIPANT	\N	PRESENT	0
100055	100052	80013X	PARTICIPANT	\N	PRESENT	0
100056	100052	09001P	PARTICIPANT	\N	PRESENT	0
100057	100052	14109K	PARTICIPANT	\N	PRESENT	0
100058	100052	08043V	PARTICIPANT	\N	EXCUSE	0
100059	100052	08060W	PARTICIPANT	\N	EXCUSE	0
100060	100052	14038Y	PARTICIPANT	\N	EXCUSE	0
100061	100052	14041T	PARTICIPANT	\N	EXCUSE	0
100062	100052	07026Q	PARTICIPANT	\N	EXCUSE	0
100063	100052	95035G	PARTICIPANT	\N	EXCUSE	0
100064	100052	04036E	PARTICIPANT	\N	EXCUSE	0
100066	100065	14030Q	PARTICIPANT	\N	PRESENT	0
100067	100065	11029K	PARTICIPANT	\N	PRESENT	0
105509	103512	10006L	PARTICIPANT	\N	PRESENT	0
105510	103512	08017T	PARTICIPANT	\N	PRESENT	0
105511	103512	11112D	PARTICIPANT	\N	PRESENT	0
105512	103512	01061S	PARTICIPANT	\N	PRESENT	0
105513	103512	14135M	PARTICIPANT	\N	PRESENT	0
105514	103512	08056B	PARTICIPANT	\N	PRESENT	0
105515	103512	11097X	PARTICIPANT	\N	PRESENT	0
105516	103512	14201E	PARTICIPANT	\N	PRESENT	0
105517	103512	04066L	PARTICIPANT	\N	PRESENT	0
105518	103512	14205J	PARTICIPANT	\N	PRESENT	0
105519	103512	01047U	PARTICIPANT	\N	PRESENT	0
105520	103512	01056V	PARTICIPANT	\N	PRESENT	0
105521	103512	08055A	PARTICIPANT	\N	PRESENT	0
105522	103512	14271U	PARTICIPANT	\N	PRESENT	0
105523	103512	14265W	PARTICIPANT	\N	PRESENT	0
105524	103512	01060R	PARTICIPANT	\N	PRESENT	0
105525	103512	14042U	PARTICIPANT	\N	PRESENT	0
105526	103512	80013X	PARTICIPANT	\N	PRESENT	0
105527	103512	14014Q	PARTICIPANT	\N	PRESENT	0
105528	103512	95030B	PARTICIPANT	\N	PRESENT	0
105529	103512	14105F	PARTICIPANT	\N	PRESENT	0
105530	103512	14039A	PARTICIPANT	\N	PRESENT	0
105531	103512	14331P	PARTICIPANT	\N	PRESENT	0
105532	103512	11046L	PARTICIPANT	\N	PRESENT	0
105533	103512	14173T	PARTICIPANT	\N	PRESENT	0
105534	103512	14241N	PARTICIPANT	\N	PRESENT	0
105536	103512	11056N	PARTICIPANT	\N	PRESENT	0
105537	103512	01048V	PARTICIPANT	\N	PRESENT	0
105538	103512	98018T	PARTICIPANT	\N	PRESENT	0
105539	103512	04057K	PARTICIPANT	\N	PRESENT	0
105540	103512	14073Q	PARTICIPANT	\N	PRESENT	0
105592	103512	14273W	PARTICIPANT	\N	PRESENT	0
105593	103512	86044G	PARTICIPANT	\N	PRESENT	0
105605	103512	08038Y	PARTICIPANT	\N	PRESENT	0
105622	103512	11053K	PARTICIPANT	\N	PRESENT	0
105623	103512	11074Q	PARTICIPANT	\N	PRESENT	0
105624	103512	14119M	PARTICIPANT	\N	PRESENT	0
105653	103512	11105E	PARTICIPANT	\N	PRESENT	0
105654	103512	14251Q	PARTICIPANT	\N	PRESENT	0
105655	103512	11090Q	PARTICIPANT	\N	PRESENT	0
105657	103512	14237S	PARTICIPANT	\N	PRESENT	0
105658	103512	14221J	PARTICIPANT	\N	PRESENT	0
105659	103512	92045V	PARTICIPANT	\N	PRESENT	0
105678	103512	11012A	PARTICIPANT	\N	PRESENT	0
105679	103512	14255U	PARTICIPANT	\N	PRESENT	0
105680	103512	95062K	PARTICIPANT	\N	PRESENT	0
105694	103512	08022Q	PARTICIPANT	\N	PRESENT	0
105695	103512	11044J	PARTICIPANT	\N	PRESENT	0
105696	103512	97011G	PARTICIPANT	\N	PRESENT	0
105697	103512	14169X	PARTICIPANT	\N	PRESENT	0
105698	103512	11040E	PARTICIPANT	\N	PRESENT	0
105699	103512	92018S	PARTICIPANT	\N	PRESENT	0
105700	103512	07029T	PARTICIPANT	\N	PRESENT	0
105712	103512	04042C	PARTICIPANT	\N	PRESENT	0
105713	103512	14329V	PARTICIPANT	\N	PRESENT	0
105714	103512	14157T	PARTICIPANT	\N	PRESENT	0
105715	103512	14085U	PARTICIPANT	\N	PRESENT	0
105716	103512	14217N	PARTICIPANT	\N	PRESENT	0
105717	103512	14065Q	PARTICIPANT	\N	PRESENT	0
105718	103512	92020L	PARTICIPANT	\N	PRESENT	0
105719	103512	14159V	PARTICIPANT	\N	PRESENT	0
105720	103512	04071H	PARTICIPANT	\N	PRESENT	0
105721	103512	01027Q	PARTICIPANT	\N	PRESENT	0
105739	103512	99004R	PARTICIPANT	\N	PRESENT	0
105802	103512	14059S	PARTICIPANT	\N	PRESENT	0
105803	103512	08034U	PARTICIPANT	\N	PRESENT	0
105804	103512	05012A	PARTICIPANT	\N	PRESENT	0
105805	103512	04049K	PARTICIPANT	\N	PRESENT	0
105812	103512	95067Q	PARTICIPANT	\N	PRESENT	0
105813	103512	04050C	PARTICIPANT	\N	PRESENT	0
105814	103512	98053W	PARTICIPANT	\N	PRESENT	0
105823	103512	14097Y	PARTICIPANT	\N	PRESENT	0
105832	103512	95063L	PARTICIPANT	\N	PRESENT	0
105833	103512	11061K	PARTICIPANT	\N	PRESENT	0
105834	103512	98046X	PARTICIPANT	\N	PRESENT	0
105914	103513	08052W	PARTICIPANT	\N	PRESENT	0
105915	103513	04092N	PARTICIPANT	\N	PRESENT	0
105916	103513	14037X	PARTICIPANT	\N	PRESENT	0
105917	103513	11063M	PARTICIPANT	\N	PRESENT	0
105918	103513	01059Y	PARTICIPANT	\N	PRESENT	0
105919	103513	11031D	PARTICIPANT	\N	PRESENT	0
105920	103513	11098Y	PARTICIPANT	\N	PRESENT	0
105921	103513	14235Q	PARTICIPANT	\N	PRESENT	0
105922	103513	14231L	PARTICIPANT	\N	PRESENT	0
105923	103513	14083S	PARTICIPANT	\N	PRESENT	0
105924	103513	08031R	PARTICIPANT	\N	PRESENT	0
105925	103513	01015L	PARTICIPANT	\N	PRESENT	0
105926	103513	14269B	PARTICIPANT	\N	PRESENT	0
105927	103513	14087W	PARTICIPANT	\N	PRESENT	0
105928	103513	14089Y	PARTICIPANT	\N	PRESENT	0
105929	103513	04053F	PARTICIPANT	\N	PRESENT	0
105930	103513	04085P	PARTICIPANT	\N	PRESENT	0
105931	103513	04054G	PARTICIPANT	\N	PRESENT	0
105932	103513	11089X	PARTICIPANT	\N	PRESENT	0
105933	103513	98024R	PARTICIPANT	\N	PRESENT	0
105934	103513	14097Y	PARTICIPANT	\N	PRESENT	0
105935	103513	11112D	PARTICIPANT	\N	PRESENT	0
105936	103513	14207L	PARTICIPANT	\N	PRESENT	0
105937	103513	80013X	PARTICIPANT	\N	PRESENT	0
105938	103513	14271U	PARTICIPANT	\N	PRESENT	0
105939	103513	14281W	PARTICIPANT	\N	PRESENT	0
105940	103513	11067R	PARTICIPANT	\N	PRESENT	0
105941	103513	12042Y	PARTICIPANT	\N	PRESENT	0
105942	103513	14265W	PARTICIPANT	\N	PRESENT	0
105943	103513	14033T	PARTICIPANT	\N	PRESENT	0
105944	103513	04049K	PARTICIPANT	\N	PRESENT	0
105945	103513	11090Q	PARTICIPANT	\N	PRESENT	0
105946	103513	14217N	PARTICIPANT	\N	PRESENT	0
105947	103513	92031P	PARTICIPANT	\N	PRESENT	0
105948	103513	11061K	PARTICIPANT	\N	PRESENT	0
105949	103513	11056N	PARTICIPANT	\N	PRESENT	0
105950	103513	98053W	PARTICIPANT	\N	PRESENT	0
105952	103513	14030Q	PARTICIPANT	\N	PRESENT	0
105953	103513	95063L	PARTICIPANT	\N	PRESENT	0
105954	103513	14105F	PARTICIPANT	\N	PRESENT	0
105955	103513	04071H	PARTICIPANT	\N	PRESENT	0
105956	103513	11077T	PARTICIPANT	\N	PRESENT	0
105957	103513	04045F	PARTICIPANT	\N	PRESENT	0
105958	103513	04067M	PARTICIPANT	\N	PRESENT	0
105959	103513	92045V	PARTICIPANT	\N	PRESENT	0
105960	103513	14255U	PARTICIPANT	\N	PRESENT	0
105972	103513	08051V	PARTICIPANT	\N	PRESENT	0
105973	103513	14257W	PARTICIPANT	\N	PRESENT	0
105974	103513	14061L	PARTICIPANT	\N	PRESENT	0
105975	103513	14071N	PARTICIPANT	\N	PRESENT	0
105976	103513	08061X	PARTICIPANT	\N	PRESENT	0
105977	103513	11066Q	PARTICIPANT	\N	PRESENT	0
105978	103513	11057P	PARTICIPANT	\N	PRESENT	0
105979	103513	08068F	PARTICIPANT	\N	PRESENT	0
105980	103513	14197C	PARTICIPANT	\N	PRESENT	0
105981	103513	11012A	PARTICIPANT	\N	PRESENT	0
105992	103513	14073Q	PARTICIPANT	\N	PRESENT	0
105993	103513	14219Q	PARTICIPANT	\N	PRESENT	0
105994	103513	14221J	PARTICIPANT	\N	PRESENT	0
105995	103513	14259Y	PARTICIPANT	\N	PRESENT	0
105996	103513	11044J	PARTICIPANT	\N	PRESENT	0
105997	103513	10006L	PARTICIPANT	\N	PRESENT	0
106012	103513	11053K	PARTICIPANT	\N	PRESENT	0
106013	103513	08038Y	PARTICIPANT	\N	PRESENT	0
106033	106032	01008M	PARTICIPANT	\N	PRESENT	0
106034	106032	14013P	PARTICIPANT	\N	PRESENT	0
106035	106032	08068F	PARTICIPANT	\N	PRESENT	0
106036	106032	14207L	PARTICIPANT	\N	PRESENT	0
106037	106032	11101A	PARTICIPANT	\N	PRESENT	0
106038	106032	90003B	PARTICIPANT	\N	PRESENT	0
106039	106032	80013X	PARTICIPANT	\N	PRESENT	0
106040	106032	04089T	PARTICIPANT	\N	PRESENT	0
105912	103513	08024S	PARTICIPANT	\N	PRESENT	0
105913	103513	14026U	PARTICIPANT	\N	PRESENT	0
106041	106032	14197C	PARTICIPANT	\N	PRESENT	0
106042	106032	14187A	PARTICIPANT	\N	PRESENT	0
106043	106032	14033T	PARTICIPANT	\N	PRESENT	0
106044	106032	04049K	PARTICIPANT	\N	PRESENT	0
106045	106032	11111C	PARTICIPANT	\N	PRESENT	0
106046	106032	08015R	PARTICIPANT	\N	PRESENT	0
106047	106032	11100Y	PRESIDENT	0	PRESENT	0
106048	106032	01061S	PARTICIPANT	\N	PRESENT	0
106049	106032	11098Y	PARTICIPANT	\N	PRESENT	0
106050	106032	01043Q	PARTICIPANT	\N	PRESENT	0
106051	106032	14205J	PARTICIPANT	\N	PRESENT	0
106053	106032	14257W	PARTICIPANT	\N	PRESENT	0
106054	106032	04088S	PARTICIPANT	\N	PRESENT	0
106055	106032	98050T	PARTICIPANT	\N	PRESENT	0
106056	106032	11090Q	PARTICIPANT	\N	PRESENT	0
106057	106032	11046L	PARTICIPANT	\N	PRESENT	0
106058	106032	11094U	PARTICIPANT	\N	PRESENT	0
106059	106032	11066Q	PARTICIPANT	\N	PRESENT	0
106062	106032	11036J	PARTICIPANT	\N	EXCUSE	0
106063	106032	08028W	PARTICIPANT	\N	EXCUSE	0
94595	94594	01043Q	PARTICIPANT	\N	PRESENT	0
94596	94594	04049K	PARTICIPANT	\N	PRESENT	0
96132	96131	11072N	PARTICIPANT	\N	PRESENT	0
96133	96131	10015M	PARTICIPANT	\N	PRESENT	0
97857	97811	14028W	PARTICIPANT	\N	PRESENT	0
97858	97811	14193X	PARTICIPANT	\N	PRESENT	0
102823	102817	05008E	PRESIDENT	0	PRESENT	0
102824	102817	11033F	PARTICIPANT	\N	PRESENT	0
97861	97811	95059Q	PRESIDENT	0	PRESENT	0
102827	102817	04047H	PRESIDENT	2	PRESENT	0
97863	97811	01014K	PARTICIPANT	\N	PRESENT	0
97864	97811	11054L	PARTICIPANT	\N	PRESENT	0
102828	102817	14259Y	PARTICIPANT	\N	PRESENT	0
102829	102817	11113E	PARTICIPANT	\N	PRESENT	0
102830	102817	01024M	PARTICIPANT	\N	PRESENT	0
102832	102817	14215L	PARTICIPANT	\N	PRESENT	0
102833	102817	14147R	PARTICIPANT	\N	PRESENT	0
102834	102817	95049N	PARTICIPANT	\N	PRESENT	0
102835	102817	07034Q	PRESIDENT	1	PRESENT	0
102836	102817	10015M	PARTICIPANT	\N	PRESENT	0
102837	102817	01028R	PARTICIPANT	\N	PRESENT	0
102838	102817	98035U	PARTICIPANT	\N	PRESENT	0
102839	102817	11037K	PARTICIPANT	\N	PRESENT	0
102840	102817	92045V	PARTICIPANT	\N	PRESENT	0
102855	102854	89017R	PARTICIPANT	\N	PRESENT	0
105123	105122	14187A	PARTICIPANT	\N	PRESENT	0
105124	105122	01043Q	PARTICIPANT	\N	PRESENT	0
105125	105122	11046L	PARTICIPANT	\N	PRESENT	0
105126	105122	11094U	PARTICIPANT	\N	PRESENT	0
105133	105132	14263U	PARTICIPANT	\N	PRESENT	0
105656	99612	95062K	PARTICIPANT	\N	EXCUSE	0
108333	108332	01008M	PARTICIPANT	\N	PRESENT	0
105136	105132	04059M	PARTICIPANT	\N	PRESENT	0
108334	108332	11036J	PARTICIPANT	\N	PRESENT	0
105138	105132	01044R	PARTICIPANT	\N	PRESENT	0
105139	105132	08043V	PARTICIPANT	\N	PRESENT	0
105140	105132	14089Y	PARTICIPANT	\N	PRESENT	0
105141	105132	14105F	PARTICIPANT	\N	PRESENT	0
105142	105132	11029K	PARTICIPANT	\N	PRESENT	0
105143	105132	95015C	PARTICIPANT	\N	PRESENT	0
105144	105132	92015P	PARTICIPANT	\N	PRESENT	0
105145	105132	08024S	PARTICIPANT	\N	PRESENT	0
105146	105132	14201E	PARTICIPANT	\N	PRESENT	0
108335	108332	11081P	PARTICIPANT	\N	PRESENT	0
108336	108332	14013P	PARTICIPANT	\N	PRESENT	0
108337	108332	08068F	PARTICIPANT	\N	PRESENT	0
105150	105132	11091R	PARTICIPANT	\N	PRESENT	0
108338	108332	14207L	PARTICIPANT	\N	PRESENT	0
108339	108332	11101A	PARTICIPANT	\N	PRESENT	0
108340	108332	90003B	PARTICIPANT	\N	PRESENT	0
105154	105132	01041N	PARTICIPANT	\N	EXCUSE	0
105155	105132	01025N	PARTICIPANT	\N	PRESENT	0
105156	105132	01037S	PARTICIPANT	\N	PRESENT	0
108341	108332	08028W	PARTICIPANT	\N	EXCUSE	0
108342	108332	80013X	PARTICIPANT	\N	PRESENT	0
108343	108332	08038Y	PARTICIPANT	\N	PRESENT	0
105160	105132	07026Q	PARTICIPANT	\N	PRESENT	0
105161	105132	14123H	PARTICIPANT	\N	PRESENT	0
105162	105132	14179A	PARTICIPANT	\N	PRESENT	0
108344	108332	04089T	PARTICIPANT	\N	PRESENT	0
105164	105132	14241N	PARTICIPANT	\N	PRESENT	0
105165	105132	14061L	PARTICIPANT	\N	PRESENT	0
105166	105132	14073Q	PARTICIPANT	\N	PRESENT	0
105167	105132	08031R	PARTICIPANT	\N	PRESENT	0
108345	108332	14197C	PARTICIPANT	\N	PRESENT	0
105169	105132	08039A	PARTICIPANT	\N	PRESENT	0
105170	105132	08017T	PARTICIPANT	\N	PRESENT	0
105171	105132	14059S	PARTICIPANT	\N	PRESENT	0
105172	105132	08012N	PARTICIPANT	\N	EXCUSE	0
105173	105132	14103D	PARTICIPANT	\N	PRESENT	0
105174	105132	11104D	PARTICIPANT	\N	PRESENT	0
105175	105132	14063N	PARTICIPANT	\N	PRESENT	0
105176	105132	04057K	PARTICIPANT	\N	PRESENT	0
105177	105132	11014C	PARTICIPANT	\N	PRESENT	0
105178	105132	14109K	PARTICIPANT	\N	PRESENT	0
105179	105132	04070G	PRESIDENT	0	PRESENT	0
108423	108332	14033T	PARTICIPANT	\N	EXCUSE	0
105181	105132	14191V	PARTICIPANT	\N	PRESENT	0
105182	105132	83047W	PARTICIPANT	\N	PRESENT	0
105183	105132	14235Q	PARTICIPANT	\N	PRESENT	0
108347	108332	14187A	PARTICIPANT	\N	PRESENT	0
108427	108425	14261S	PARTICIPANT	\N	PRESENT	0
105186	105132	14229S	PARTICIPANT	\N	PRESENT	0
105187	105132	11043H	PARTICIPANT	\N	PRESENT	0
108428	108425	08055A	PARTICIPANT	\N	PRESENT	0
105189	105132	11011M	PARTICIPANT	\N	PRESENT	0
108350	108332	04048J	PARTICIPANT	\N	PRESENT	0
108818	108817	11039M	PARTICIPANT	\N	PRESENT	0
108352	108332	04049K	PARTICIPANT	\N	PRESENT	0
108353	108332	04094Q	PARTICIPANT	\N	PRESENT	0
108354	108332	11111C	PARTICIPANT	\N	PRESENT	0
108430	108425	14030Q	PARTICIPANT	\N	PRESENT	0
108356	108332	11100Y	PRESIDENT	0	PRESENT	0
108357	108332	01061S	PARTICIPANT	\N	EXCUSE	0
108358	108332	11098Y	PARTICIPANT	\N	PRESENT	0
108359	108332	01043Q	PARTICIPANT	\N	PRESENT	0
108819	108817	98042T	PARTICIPANT	\N	PRESENT	0
108361	108332	14205J	PARTICIPANT	\N	PRESENT	0
108362	108332	08019V	PARTICIPANT	\N	PRESENT	0
108363	108332	14257W	PARTICIPANT	\N	PRESENT	0
108820	108817	01019Q	PARTICIPANT	\N	PRESENT	0
108365	108332	04088S	PARTICIPANT	\N	PRESENT	0
110112	106488	14231L	PARTICIPANT	\N	PRESENT	0
108367	108332	11090Q	PARTICIPANT	\N	PRESENT	0
108368	108332	11046L	PARTICIPANT	\N	PRESENT	0
108369	108332	01058X	PARTICIPANT	\N	PRESENT	0
108370	108332	11094U	PARTICIPANT	\N	PRESENT	0
108371	108332	11066Q	PARTICIPANT	\N	PRESENT	0
108434	108425	14038Y	PARTICIPANT	\N	PRESENT	0
108435	108425	11114F	PARTICIPANT	\N	PRESENT	0
108436	108425	98023Q	PARTICIPANT	\N	PRESENT	0
110113	106488	14071N	PARTICIPANT	\N	PRESENT	0
108438	108425	01015L	PARTICIPANT	\N	EXCUSE	0
108439	108425	11107G	PARTICIPANT	\N	PRESENT	0
110114	106488	04045F	PARTICIPANT	\N	PRESENT	0
108441	108425	02002K	PARTICIPANT	\N	PRESENT	0
108442	108425	01022K	PARTICIPANT	\N	PRESENT	0
108443	108425	04097T	PARTICIPANT	\N	PRESENT	0
108444	108425	09001P	PARTICIPANT	\N	EXCUSE	0
108445	108425	11059R	PARTICIPANT	\N	PRESENT	0
108446	108425	14219Q	PARTICIPANT	\N	PRESENT	0
108447	108425	80027E	PARTICIPANT	\N	PRESENT	0
108448	108425	14031R	PARTICIPANT	\N	PRESENT	0
108449	108425	08009T	PRESIDENT	0	PRESENT	0
108450	108425	08062Y	PARTICIPANT	\N	EXCUSE	0
108451	108425	14221J	PARTICIPANT	\N	PRESENT	0
108452	108425	92039X	PARTICIPANT	\N	PRESENT	0
108453	108425	08042U	PARTICIPANT	\N	PRESENT	0
108454	108425	14169X	PARTICIPANT	\N	PRESENT	0
108455	108425	14237S	PARTICIPANT	\N	PRESENT	0
108456	108425	13002U	PARTICIPANT	\N	PRESENT	0
108457	108425	05012A	PARTICIPANT	\N	PRESENT	0
110115	106488	08034U	PARTICIPANT	\N	PRESENT	0
108459	108425	14135M	PARTICIPANT	\N	PRESENT	0
108460	108425	14331P	PARTICIPANT	\N	PRESENT	0
108461	108425	95062K	PARTICIPANT	\N	EXCUSE	0
108462	108425	14107H	PARTICIPANT	\N	PRESENT	0
108463	108425	14051J	PARTICIPANT	\N	PRESENT	0
110116	106488	01057W	PARTICIPANT	\N	PRESENT	0
108465	108425	96003C	PARTICIPANT	\N	EXCUSE	0
110117	106488	95067Q	PARTICIPANT	\N	PRESENT	0
110118	106488	14051J	PARTICIPANT	\N	PRESENT	0
110119	106488	11037K	PARTICIPANT	\N	PRESENT	0
110120	106488	14063N	PARTICIPANT	\N	PRESENT	0
110121	106488	11098Y	PARTICIPANT	\N	PRESENT	0
110122	106488	95063L	PARTICIPANT	\N	PRESENT	0
110123	106488	05012A	PARTICIPANT	\N	PRESENT	0
110124	106488	11101A	PARTICIPANT	\N	PRESENT	0
110126	106488	08038Y	PARTICIPANT	\N	PRESENT	0
110129	106488	11099A	PARTICIPANT	\N	PRESENT	0
110190	110189	11053K	PARTICIPANT	\N	PRESENT	0
110194	110193	08034U	PARTICIPANT	\N	PRESENT	0
110199	110198	04071H	PARTICIPANT	\N	PRESENT	0
113006	112496	01031L	PARTICIPANT	\N	PRESENT	0
113007	112496	98046X	PARTICIPANT	\N	PRESENT	0
113012	112496	11077T	PARTICIPANT	\N	PRESENT	0
113005	112496	11083R	PARTICIPANT	\N	PRESENT	0
113004	112496	11057P	PARTICIPANT	\N	PRESENT	0
113000	112496	14089Y	PARTICIPANT	\N	PRESENT	0
113001	112496	11012A	PARTICIPANT	\N	PRESENT	0
113002	112496	11048N	PARTICIPANT	\N	PRESENT	0
113003	112496	11090Q	PARTICIPANT	\N	PRESENT	0
113013	112496	80013X	PARTICIPANT	\N	PRESENT	0
113014	112496	11036J	PARTICIPANT	\N	PRESENT	0
113015	112496	92045V	PARTICIPANT	\N	PRESENT	0
113016	112496	01016M	PARTICIPANT	\N	PRESENT	0
113017	112496	95041E	PARTICIPANT	\N	PRESENT	0
113018	112496	11110B	PARTICIPANT	\N	PRESENT	0
120290	118920	11111C	PARTICIPANT	\N	PRESENT	0
120291	119913	14121F	PARTICIPANT	\N	EXCUSE	0
120292	119913	95041E	PARTICIPANT	\N	EXCUSE	0
120293	119913	14039A	PARTICIPANT	\N	EXCUSE	0
120294	119913	95067Q	PARTICIPANT	\N	EXCUSE	0
120295	119913	04071H	PARTICIPANT	\N	EXCUSE	0
120296	119913	02002K	PARTICIPANT	\N	EXCUSE	0
120297	119913	10015M	PARTICIPANT	\N	EXCUSE	0
120298	118920	04047H	PARTICIPANT	\N	PRESENT	0
120299	118920	11064N	PARTICIPANT	\N	PRESENT	0
120374	118921	01024M	PARTICIPANT	\N	PRESENT	0
120375	118921	11098Y	PARTICIPANT	\N	PRESENT	0
120376	118921	11056N	PARTICIPANT	\N	PRESENT	0
120377	118921	14235Q	PARTICIPANT	\N	PRESENT	0
120378	118921	11036J	PARTICIPANT	\N	PRESENT	0
120379	118921	80013X	PARTICIPANT	\N	PRESENT	0
120380	118921	12042Y	PARTICIPANT	\N	PRESENT	0
120381	118921	14065Q	PARTICIPANT	\N	PRESENT	0
120382	118921	01028R	PARTICIPANT	\N	PRESENT	0
120383	118921	08053X	PARTICIPANT	\N	PRESENT	0
120384	118921	11026G	PARTICIPANT	\N	PRESENT	0
120385	118921	11033F	PARTICIPANT	\N	PRESENT	0
120386	118921	14215L	PARTICIPANT	\N	PRESENT	0
120387	118921	11094U	PARTICIPANT	\N	PRESENT	0
120388	118921	14079W	PARTICIPANT	\N	PRESENT	0
120389	118921	14217N	PARTICIPANT	\N	PRESENT	0
120390	118921	14038Y	PARTICIPANT	\N	PRESENT	0
120391	118921	01025N	PARTICIPANT	\N	PRESENT	0
120392	118921	07034Q	PARTICIPANT	\N	PRESENT	0
120393	118921	14331P	PARTICIPANT	\N	PRESENT	0
120394	118921	01008M	PARTICIPANT	\N	PRESENT	0
120395	118921	14033T	PARTICIPANT	\N	PRESENT	0
120396	118921	14031R	PARTICIPANT	\N	PRESENT	0
120397	118921	14053L	PARTICIPANT	\N	PRESENT	0
120398	118921	10015M	PARTICIPANT	\N	PRESENT	0
120399	118921	95030B	PARTICIPANT	\N	PRESENT	0
120400	118921	14147R	PARTICIPANT	\N	PRESENT	0
120401	118921	14231L	PARTICIPANT	\N	PRESENT	0
120402	118921	14265W	PARTICIPANT	\N	PRESENT	0
120403	118921	14089Y	PARTICIPANT	\N	PRESENT	0
120404	118921	14083S	PARTICIPANT	\N	PRESENT	0
120405	118921	08043V	PARTICIPANT	\N	PRESENT	0
120406	118921	14257W	PARTICIPANT	\N	PRESENT	0
120407	118921	04088S	PARTICIPANT	\N	PRESENT	0
120408	118921	04047H	PARTICIPANT	\N	PRESENT	0
120409	118921	11097X	PARTICIPANT	\N	PRESENT	0
120410	118921	08051V	PARTICIPANT	\N	PRESENT	0
120411	118921	11012A	PARTICIPANT	\N	PRESENT	0
120412	118921	08047A	PARTICIPANT	\N	PRESENT	0
120413	118921	14105F	PARTICIPANT	\N	PRESENT	0
120414	118921	95049N	PARTICIPANT	\N	PRESENT	0
120415	118921	11112D	PARTICIPANT	\N	PRESENT	0
120416	118921	98053W	PARTICIPANT	\N	PRESENT	0
120417	118921	14034U	PARTICIPANT	\N	PRESENT	0
120418	118921	11070L	PARTICIPANT	\N	PRESENT	0
120419	118921	07029T	PARTICIPANT	\N	PRESENT	0
120621	120562	89017R	PARTICIPANT	\N	PRESENT	0
120622	120562	01031L	PRESIDENT	0	PRESENT	0
120623	120562	01013J	PARTICIPANT	\N	PRESENT	0
120624	120562	11040E	PARTICIPANT	\N	PRESENT	0
120625	120562	08014Q	PARTICIPANT	\N	PRESENT	0
120626	120562	14175V	PARTICIPANT	\N	PRESENT	0
120627	120562	14083S	PARTICIPANT	\N	PRESENT	0
120628	120562	11053K	PARTICIPANT	\N	PRESENT	0
120629	120562	14085U	PARTICIPANT	\N	PRESENT	0
120630	120562	11042G	PARTICIPANT	\N	PRESENT	0
120631	120562	11070L	PARTICIPANT	\N	PRESENT	0
120632	120562	11088W	PARTICIPANT	\N	PRESENT	0
120633	120562	14327T	PARTICIPANT	\N	PRESENT	0
120634	120562	08022Q	PARTICIPANT	\N	PRESENT	0
120635	120562	01027Q	PARTICIPANT	\N	PRESENT	0
120636	120562	11074Q	PARTICIPANT	\N	PRESENT	0
120637	120562	98053W	PARTICIPANT	\N	PRESENT	0
120638	120562	11083R	PARTICIPANT	\N	PRESENT	0
120639	120562	14199E	PARTICIPANT	\N	PRESENT	0
120640	120562	08069G	PARTICIPANT	\N	PRESENT	0
120641	120562	11048N	PARTICIPANT	\N	PRESENT	0
120642	120562	99004R	PARTICIPANT	\N	PRESENT	0
120643	120562	04061F	PARTICIPANT	\N	PRESENT	0
120644	120562	14159V	PARTICIPANT	\N	PRESENT	0
120372	118921	08024S	PARTICIPANT	\N	PRESENT	0
120373	118921	05008E	PARTICIPANT	\N	PRESENT	0
120645	120562	07029T	PARTICIPANT	\N	PRESENT	0
120646	120562	08010L	PARTICIPANT	\N	PRESENT	0
120647	120562	08034U	PARTICIPANT	\N	PRESENT	0
120648	120562	01048V	PARTICIPANT	\N	PRESENT	0
120649	120562	98046X	PARTICIPANT	\N	PRESENT	0
120650	120562	08011M	PARTICIPANT	\N	PRESENT	0
120651	120562	08061X	PARTICIPANT	\N	EXCUSE	0
120652	120562	01016M	PARTICIPANT	\N	PRESENT	0
120653	120562	14225N	PARTICIPANT	\N	PRESENT	0
120654	120562	11012A	PARTICIPANT	\N	PRESENT	0
120655	120562	11057P	PARTICIPANT	\N	PRESENT	0
120656	120562	14173T	PARTICIPANT	\N	PRESENT	0
120657	120562	04034C	PARTICIPANT	\N	PRESENT	0
120658	120562	08060W	RAPPORTEUR_AVIS	\N	PRESENT	0
120659	120562	08042U	RAPPORTEUR_AVIS	\N	PRESENT	0
120777	120768	14239U	PARTICIPANT	\N	PRESENT	0
120778	120768	11055M	PARTICIPANT	\N	EXCUSE	0
120779	120768	01046T	PARTICIPANT	\N	PRESENT	0
120780	120768	04053F	PARTICIPANT	\N	PRESENT	0
120781	120768	14255U	PARTICIPANT	\N	EXCUSE	0
120993	120992	89017R	PARTICIPANT	\N	PRESENT	0
120783	120768	00003C	PARTICIPANT	\N	EXCUSE	0
120994	120992	01031L	PRESIDENT	0	PRESENT	0
120785	120768	11103C	PARTICIPANT	\N	PRESENT	0
120786	120768	11044J	PARTICIPANT	\N	PRESENT	0
120787	120768	14195A	PARTICIPANT	\N	PRESENT	0
120788	120768	14267Y	PARTICIPANT	\N	PRESENT	0
120789	120768	11023D	PARTICIPANT	\N	PRESENT	0
120790	120768	11031D	PARTICIPANT	\N	PRESENT	0
120791	120768	08052W	PARTICIPANT	\N	PRESENT	0
120995	120992	05004A	PARTICIPANT	\N	PRESENT	0
120793	120768	04081K	PARTICIPANT	\N	PRESENT	0
120794	120768	98024R	PARTICIPANT	\N	PRESENT	0
120795	120768	10006L	PARTICIPANT	\N	PRESENT	0
120796	120768	04067M	PARTICIPANT	\N	PRESENT	0
120797	120768	14217N	PARTICIPANT	\N	PRESENT	0
120798	120768	14042U	PARTICIPANT	\N	PRESENT	0
120799	120768	14151M	PARTICIPANT	\N	PRESENT	0
120800	120768	12042Y	PARTICIPANT	\N	PRESENT	0
120996	120992	01013J	PARTICIPANT	\N	PRESENT	0
120997	120992	08014Q	PARTICIPANT	\N	PRESENT	0
120803	120768	01003G	PARTICIPANT	\N	PRESENT	0
120804	120768	14034U	PARTICIPANT	\N	PRESENT	0
120998	120992	14083S	PARTICIPANT	\N	PRESENT	0
120806	120768	11061K	PARTICIPANT	\N	EXCUSE	0
120807	120768	08048B	PARTICIPANT	\N	PRESENT	0
120808	120768	08041T	PARTICIPANT	\N	PRESENT	0
120809	120768	01011G	PARTICIPANT	\N	PRESENT	0
120810	120768	14026U	PARTICIPANT	\N	PRESENT	0
120811	120768	14213J	PARTICIPANT	\N	EXCUSE	0
120812	120768	14121F	PARTICIPANT	\N	EXCUSE	0
120999	120992	11053K	PARTICIPANT	\N	PRESENT	0
120814	120768	14037X	PARTICIPANT	\N	PRESENT	0
120815	120768	14018U	PARTICIPANT	\N	PRESENT	0
120816	120768	11067R	PARTICIPANT	\N	EXCUSE	0
120817	120768	14223L	PARTICIPANT	\N	PRESENT	0
120818	120768	04092N	PRESIDENT	0	PRESENT	0
120819	120768	14265W	PARTICIPANT	\N	PRESENT	0
120820	120768	14119M	PARTICIPANT	\N	PRESENT	0
120821	120768	14071N	PARTICIPANT	\N	EXCUSE	0
120822	120768	07032N	PARTICIPANT	\N	PRESENT	0
121000	120992	14085U	PARTICIPANT	\N	PRESENT	0
120824	120768	14271U	PARTICIPANT	\N	PRESENT	0
120825	120768	14017T	PARTICIPANT	\N	EXCUSE	0
120826	120768	11093T	PARTICIPANT	\N	PRESENT	0
120827	120768	11097X	PARTICIPANT	\N	PRESENT	0
120828	120768	04045F	PARTICIPANT	\N	PRESENT	0
120829	120768	14227Q	PARTICIPANT	\N	PRESENT	0
120830	120768	01034P	PARTICIPANT	\N	PRESENT	0
121001	120992	11042G	PARTICIPANT	\N	PRESENT	0
120832	120768	11063M	PARTICIPANT	\N	PRESENT	0
120833	120768	14269B	PARTICIPANT	\N	EXCUSE	0
121002	120992	88008L	PARTICIPANT	\N	PRESENT	0
121003	120992	04055H	PARTICIPANT	\N	PRESENT	0
121004	120992	11070L	PARTICIPANT	\N	PRESENT	0
121005	120992	11088W	PARTICIPANT	\N	PRESENT	0
121006	120992	14327T	PARTICIPANT	\N	PRESENT	0
121007	120992	08022Q	PARTICIPANT	\N	PRESENT	0
121008	120992	01027Q	PARTICIPANT	\N	PRESENT	0
121009	120992	04071H	PARTICIPANT	\N	EXCUSE	0
121010	120992	98053W	PARTICIPANT	\N	EXCUSE	0
121011	120992	11083R	PARTICIPANT	\N	PRESENT	0
121012	120992	14199E	PARTICIPANT	\N	PRESENT	0
121013	120992	08016S	PARTICIPANT	\N	PRESENT	0
121014	120992	11048N	PARTICIPANT	\N	PRESENT	0
121015	120992	04061F	PARTICIPANT	\N	PRESENT	0
121016	120992	14159V	PARTICIPANT	\N	PRESENT	0
93977	93976	08060W	PARTICIPANT	\N	PRESENT	0
93978	93976	01037S	PARTICIPANT	\N	PRESENT	0
93979	93976	14061L	PARTICIPANT	\N	PRESENT	0
93980	93976	95067Q	PARTICIPANT	\N	PRESENT	0
93981	93976	11040E	PARTICIPANT	\N	PRESENT	0
93982	93976	11053K	PARTICIPANT	\N	PRESENT	0
94154	94153	08060W	PARTICIPANT	\N	PRESENT	0
94155	94153	04038G	PARTICIPANT	\N	PRESENT	0
94156	94153	01015L	PARTICIPANT	\N	PRESENT	0
94157	94153	01041N	PARTICIPANT	\N	PRESENT	0
94158	94153	14121F	PARTICIPANT	\N	PRESENT	0
94159	94153	11084S	PARTICIPANT	\N	PRESENT	0
94160	94153	99004R	PRESIDENT	0	PRESENT	0
94161	94153	08012N	PARTICIPANT	\N	PRESENT	0
94162	94153	11094U	PARTICIPANT	\N	PRESENT	0
94163	94153	11066Q	PARTICIPANT	\N	PRESENT	0
94164	94153	01008M	PARTICIPANT	\N	EXCUSE	0
94165	94153	14089Y	PARTICIPANT	\N	EXCUSE	0
94166	94153	11029K	PARTICIPANT	\N	EXCUSE	0
94167	94153	11080N	PARTICIPANT	\N	EXCUSE	0
94168	94153	08028W	PARTICIPANT	\N	EXCUSE	0
94169	94153	01059Y	PARTICIPANT	\N	EXCUSE	0
94170	94153	98018T	PARTICIPANT	\N	EXCUSE	0
94171	94153	11088W	PARTICIPANT	\N	EXCUSE	0
94172	94153	14187A	PARTICIPANT	\N	EXCUSE	0
94173	94153	02002K	PARTICIPANT	\N	EXCUSE	0
94174	94153	11089X	PARTICIPANT	\N	EXCUSE	0
94175	94153	14026U	PARTICIPANT	\N	EXCUSE	0
94176	94153	14179A	PARTICIPANT	\N	EXCUSE	0
94177	94153	04061F	PARTICIPANT	\N	EXCUSE	0
94178	94153	01061S	PARTICIPANT	\N	EXCUSE	0
94179	94153	08062Y	PARTICIPANT	\N	EXCUSE	0
94180	94153	14257W	PARTICIPANT	\N	EXCUSE	0
94181	94153	08021P	PARTICIPANT	\N	EXCUSE	0
94182	94153	14229S	PARTICIPANT	\N	EXCUSE	0
94183	94153	14107H	PARTICIPANT	\N	EXCUSE	0
94184	94153	01028R	PARTICIPANT	\N	EXCUSE	0
94185	94153	92045V	PARTICIPANT	\N	EXCUSE	0
95967	95212	14033T	PARTICIPANT	\N	PRESENT	0
99836	94613	01027Q	PRESIDENT	0	PRESENT	0
99838	94613	11114F	PARTICIPANT	\N	PRESENT	0
99840	94613	11113E	PARTICIPANT	\N	PRESENT	0
99844	94613	14059S	PARTICIPANT	\N	PRESENT	0
99846	94613	11025F	PARTICIPANT	\N	PRESENT	0
100068	100065	80013X	PARTICIPANT	\N	PRESENT	0
100069	100065	09001P	PARTICIPANT	\N	PRESENT	0
100070	100065	14109K	PARTICIPANT	\N	PRESENT	0
100071	100065	08043V	PARTICIPANT	\N	EXCUSE	0
100072	100065	08060W	PARTICIPANT	\N	EXCUSE	0
100073	100065	14038Y	PARTICIPANT	\N	EXCUSE	0
100074	100065	14041T	PARTICIPANT	\N	EXCUSE	0
100075	100065	07026Q	PARTICIPANT	\N	EXCUSE	0
100076	100065	95035G	PARTICIPANT	\N	EXCUSE	0
100077	100065	04036E	PARTICIPANT	\N	EXCUSE	0
100082	100080	11015D	PARTICIPANT	\N	PRESENT	0
100083	100080	92031P	PARTICIPANT	\N	PRESENT	0
100093	100092	07034Q	PARTICIPANT	\N	PRESENT	0
100097	100096	14133K	PARTICIPANT	\N	PRESENT	0
100098	100096	08024S	PARTICIPANT	\N	PRESENT	0
100113	100112	08061X	PARTICIPANT	\N	PRESENT	0
100114	100112	11012A	PARTICIPANT	\N	PRESENT	0
100133	100132	14199E	PARTICIPANT	\N	PRESENT	0
100135	100134	14199E	PARTICIPANT	\N	PRESENT	0
100137	100136	11048N	PARTICIPANT	\N	PRESENT	0
100139	100138	11048N	PARTICIPANT	\N	PRESENT	0
100141	100140	11039M	PARTICIPANT	\N	PRESENT	0
100142	100140	98042T	PARTICIPANT	\N	PRESENT	0
100143	100140	01019Q	PARTICIPANT	\N	PRESENT	0
100842	100841	14263U	PARTICIPANT	\N	PRESENT	0
100843	100841	14133K	PARTICIPANT	\N	PRESENT	0
102225	101190	14219Q	PARTICIPANT	\N	PRESENT	0
100845	100841	04059M	PARTICIPANT	\N	PRESENT	0
102226	101190	11082Q	PARTICIPANT	\N	PRESENT	0
100847	100841	01044R	PARTICIPANT	\N	PRESENT	0
100848	100841	08043V	PARTICIPANT	\N	PRESENT	0
100849	100841	14089Y	PARTICIPANT	\N	PRESENT	0
100850	100841	14105F	PARTICIPANT	\N	PRESENT	0
100851	100841	11029K	PARTICIPANT	\N	PRESENT	0
100852	100841	95015C	PARTICIPANT	\N	PRESENT	0
100853	100841	92015P	PARTICIPANT	\N	PRESENT	0
100854	100841	08024S	PARTICIPANT	\N	PRESENT	0
100855	100841	14201E	PARTICIPANT	\N	PRESENT	0
100856	100841	14329V	PARTICIPANT	\N	EXCUSE	0
100857	100841	14209N	PARTICIPANT	\N	EXCUSE	0
100858	100841	14079W	PARTICIPANT	\N	PRESENT	0
100859	100841	11091R	PARTICIPANT	\N	PRESENT	0
100860	100841	87003B	PARTICIPANT	\N	EXCUSE	0
100861	100841	98042T	PARTICIPANT	\N	PRESENT	0
100862	100841	14249W	PARTICIPANT	\N	PRESENT	0
100863	100841	01041N	PARTICIPANT	\N	EXCUSE	0
100864	100841	01025N	PARTICIPANT	\N	PRESENT	0
102227	101190	07026Q	PARTICIPANT	\N	PRESENT	0
100866	100841	89029V	PARTICIPANT	\N	EXCUSE	0
100867	100841	08035V	PARTICIPANT	\N	PRESENT	0
100868	100841	11089X	PARTICIPANT	\N	PRESENT	0
100869	100841	07026Q	PARTICIPANT	\N	PRESENT	0
100870	100841	14123H	PARTICIPANT	\N	PRESENT	0
100871	100841	14179A	PARTICIPANT	\N	PRESENT	0
100872	100841	04041B	PARTICIPANT	\N	EXCUSE	0
100873	100841	14241N	PARTICIPANT	\N	PRESENT	0
100874	100841	14061L	PARTICIPANT	\N	PRESENT	0
100875	100841	14073Q	PARTICIPANT	\N	PRESENT	0
100876	100841	08031R	PARTICIPANT	\N	PRESENT	0
102228	101190	12041X	PARTICIPANT	\N	PRESENT	0
100878	100841	08039A	PARTICIPANT	\N	PRESENT	0
102229	101190	14231L	PARTICIPANT	\N	PRESENT	0
100880	100841	14059S	PARTICIPANT	\N	PRESENT	0
102230	101190	14107H	PARTICIPANT	\N	PRESENT	0
100882	100841	14103D	PARTICIPANT	\N	EXCUSE	0
100883	100841	11104D	PARTICIPANT	\N	PRESENT	0
100884	100841	14063N	PARTICIPANT	\N	PRESENT	0
100885	100841	04057K	PARTICIPANT	\N	EXCUSE	0
100886	100841	11014C	PARTICIPANT	\N	PRESENT	0
100887	100841	14109K	PARTICIPANT	\N	PRESENT	0
100888	100841	04070G	PRESIDENT	0	PRESENT	0
100889	100841	92040Q	PARTICIPANT	\N	PRESENT	0
100890	100841	14191V	PARTICIPANT	\N	EXCUSE	0
100891	100841	83047W	PARTICIPANT	\N	PRESENT	0
100892	100841	14235Q	PARTICIPANT	\N	PRESENT	0
102231	101190	08065C	PARTICIPANT	\N	PRESENT	0
100894	100841	04033B	PARTICIPANT	\N	EXCUSE	0
100895	100841	14229S	PARTICIPANT	\N	PRESENT	0
100896	100841	11043H	PARTICIPANT	\N	PRESENT	0
100897	100841	11071M	PARTICIPANT	\N	EXCUSE	0
100898	100841	11011M	PARTICIPANT	\N	PRESENT	0
102232	101190	98022P	PARTICIPANT	\N	PRESENT	0
102233	101190	87003B	PARTICIPANT	\N	PRESENT	0
102235	101190	14227Q	PARTICIPANT	\N	PRESENT	0
102236	101190	14121F	PARTICIPANT	\N	PRESENT	0
102239	101190	04089T	PARTICIPANT	\N	PRESENT	0
102240	101190	01014K	PARTICIPANT	\N	PRESENT	0
102241	101190	07034Q	PARTICIPANT	\N	PRESENT	0
102242	101190	04043D	PARTICIPANT	\N	PRESENT	0
102243	101190	80013X	PARTICIPANT	\N	PRESENT	0
102244	101190	13002U	PARTICIPANT	\N	PRESENT	0
102245	101190	80027E	PARTICIPANT	\N	PRESENT	0
102246	101190	04088S	PARTICIPANT	\N	PRESENT	0
102247	101190	14225N	PARTICIPANT	\N	PRESENT	0
102248	101190	14271U	PARTICIPANT	\N	PRESENT	0
102249	101190	11012A	PARTICIPANT	\N	PRESENT	0
102250	101190	14028W	PARTICIPANT	\N	PRESENT	0
102251	101190	04036E	PARTICIPANT	\N	PRESENT	0
102252	101190	08011M	PARTICIPANT	\N	PRESENT	0
102253	101190	01058X	PARTICIPANT	\N	PRESENT	0
102254	101190	99004R	PARTICIPANT	\N	PRESENT	0
102255	101190	04071H	PARTICIPANT	\N	PRESENT	0
102256	101190	95030B	PARTICIPANT	\N	PRESENT	0
102257	101190	95015C	PARTICIPANT	\N	PRESENT	0
102258	101190	02002K	PARTICIPANT	\N	PRESENT	0
102259	101190	04047H	PARTICIPANT	\N	PRESENT	0
102260	101190	98018T	PARTICIPANT	\N	PRESENT	0
102261	101190	95041E	PARTICIPANT	\N	PRESENT	0
102262	101190	08022Q	PARTICIPANT	\N	PRESENT	0
102263	101190	01015L	PARTICIPANT	\N	PRESENT	0
102264	101190	04085P	PARTICIPANT	\N	PRESENT	0
102265	101190	04050C	PARTICIPANT	\N	PRESENT	0
102266	101190	04086Q	PARTICIPANT	\N	PRESENT	0
102267	101190	11034G	PARTICIPANT	\N	PRESENT	0
102268	101190	10006L	PARTICIPANT	\N	PRESENT	0
102269	101190	98053W	PARTICIPANT	\N	PRESENT	0
102270	101190	01013J	PARTICIPANT	\N	PRESENT	0
102271	101190	01027Q	PARTICIPANT	\N	PRESENT	0
102272	101190	05004A	PARTICIPANT	\N	PRESENT	0
102273	101190	14071N	PARTICIPANT	\N	PRESENT	0
102274	101190	11031D	PARTICIPANT	\N	PRESENT	0
102275	101190	14237S	PARTICIPANT	\N	PRESENT	0
102276	101190	11040E	PARTICIPANT	\N	PRESENT	0
102277	101190	14013P	PARTICIPANT	\N	PRESENT	0
102278	101190	11056N	PARTICIPANT	\N	PRESENT	0
106064	106032	08021P	PARTICIPANT	\N	EXCUSE	0
106065	106032	14173T	PARTICIPANT	\N	PRESENT	0
106066	106032	92045V	PARTICIPANT	\N	PRESENT	0
106072	106052	04081K	PARTICIPANT	\N	PRESENT	0
106073	106052	11063M	PARTICIPANT	\N	PRESENT	0
106074	106052	01059Y	PARTICIPANT	\N	PRESENT	0
106075	106052	11031D	PARTICIPANT	\N	PRESENT	0
106076	106052	11098Y	PARTICIPANT	\N	PRESENT	0
106317	106067	11098Y	PARTICIPANT	\N	PRESENT	0
106318	106067	04092N	PARTICIPANT	\N	PRESENT	0
106319	106067	14037X	PARTICIPANT	\N	PRESENT	0
106320	106067	04053F	PARTICIPANT	\N	PRESENT	0
106321	106067	01028R	PARTICIPANT	\N	PRESENT	0
106109	106108	04081K	PARTICIPANT	\N	PRESENT	0
106110	106108	11063M	PARTICIPANT	\N	PRESENT	0
106111	106108	01059Y	PARTICIPANT	\N	PRESENT	0
106112	106108	11031D	PARTICIPANT	\N	PRESENT	0
106113	106108	11098Y	PARTICIPANT	\N	PRESENT	0
106114	106108	04092N	PARTICIPANT	\N	PRESENT	0
106115	106108	14037X	PARTICIPANT	\N	PRESENT	0
106116	106108	14087W	PARTICIPANT	\N	PRESENT	0
106117	106108	11027H	PARTICIPANT	\N	PRESENT	0
106118	106108	08052W	PARTICIPANT	\N	PRESENT	0
106119	106108	04053F	PARTICIPANT	\N	PRESENT	0
106120	106108	14227Q	PARTICIPANT	\N	PRESENT	0
106121	106108	08068F	PARTICIPANT	\N	PRESENT	0
106122	106108	14097Y	PARTICIPANT	\N	PRESENT	0
106123	106108	14073Q	PARTICIPANT	\N	PRESENT	0
106124	106108	14219Q	PARTICIPANT	\N	PRESENT	0
106125	106108	14061L	PARTICIPANT	\N	PRESENT	0
106126	106108	11103C	PARTICIPANT	\N	PRESENT	0
106127	106108	14265W	PARTICIPANT	\N	PRESENT	0
106128	106108	10015M	PARTICIPANT	\N	PRESENT	0
106129	106108	98005N	PARTICIPANT	\N	PRESENT	0
106322	106067	14271U	PARTICIPANT	\N	PRESENT	0
106131	106108	14215L	PARTICIPANT	\N	PRESENT	0
106132	106108	14223L	PARTICIPANT	\N	PRESENT	0
106133	106108	11057P	PARTICIPANT	\N	PRESENT	0
106134	106108	11097X	PARTICIPANT	\N	PRESENT	0
106135	106108	11066Q	PARTICIPANT	\N	PRESENT	0
106136	106108	14197C	PARTICIPANT	\N	PRESENT	0
106137	106108	14151M	PARTICIPANT	\N	PRESENT	0
106138	106108	14089Y	PARTICIPANT	\N	PRESENT	0
106139	106108	08051V	PARTICIPANT	\N	PRESENT	0
106140	106108	14159V	PARTICIPANT	\N	PRESENT	0
106141	106108	14271U	PARTICIPANT	\N	PRESENT	0
106142	106108	04045F	PARTICIPANT	\N	PRESENT	0
106143	106108	14231L	PARTICIPANT	\N	PRESENT	0
106144	106108	04057K	PARTICIPANT	\N	PRESENT	0
106145	106108	11112D	PARTICIPANT	\N	PRESENT	0
106146	106108	14083S	PARTICIPANT	\N	PRESENT	0
106147	106108	14042U	PARTICIPANT	\N	PRESENT	0
106148	106108	04071H	PARTICIPANT	\N	PRESENT	0
106149	106108	14071N	PARTICIPANT	\N	PRESENT	0
106150	106108	14237S	PARTICIPANT	\N	PRESENT	0
106151	106108	01003G	PARTICIPANT	\N	PRESENT	0
106152	106108	14030Q	PARTICIPANT	\N	PRESENT	0
106153	106108	11091R	PARTICIPANT	\N	PRESENT	0
106154	106108	10006L	PARTICIPANT	\N	PRESENT	0
106155	106108	04067M	PARTICIPANT	\N	PRESENT	0
106156	106108	11053K	PARTICIPANT	\N	PRESENT	0
106157	106108	98050T	PARTICIPANT	\N	PRESENT	0
106158	106108	08034U	PARTICIPANT	\N	PRESENT	0
106159	106108	14269B	PARTICIPANT	\N	PRESENT	0
106160	106108	11054L	PARTICIPANT	\N	PRESENT	0
106161	106108	04066L	PARTICIPANT	\N	PRESENT	0
106162	106108	11061K	PARTICIPANT	\N	PRESENT	0
106163	106108	11089X	PARTICIPANT	\N	PRESENT	0
106164	106108	04085P	PARTICIPANT	\N	PRESENT	0
106165	106108	08038Y	PARTICIPANT	\N	PRESENT	0
106173	106172	11088W	PARTICIPANT	\N	PRESENT	0
106174	106108	07026Q	PARTICIPANT	\N	PRESENT	0
106175	106108	14157T	PARTICIPANT	\N	PRESENT	0
106181	106108	04049K	PARTICIPANT	\N	PRESENT	0
106187	106108	14053L	PARTICIPANT	\N	PRESENT	0
106188	106108	01044R	PARTICIPANT	\N	PRESENT	0
106191	106108	14281W	PARTICIPANT	\N	PRESENT	0
106195	106108	14207L	PARTICIPANT	\N	PRESENT	0
106196	106108	14085U	PARTICIPANT	\N	PRESENT	0
106197	106108	80013X	PARTICIPANT	\N	PRESENT	0
106212	106108	11015D	PARTICIPANT	\N	PRESENT	0
106213	106108	04034C	PARTICIPANT	\N	PRESENT	0
106214	106108	14217N	PARTICIPANT	\N	PRESENT	0
106216	106215	14237S	PARTICIPANT	\N	PRESENT	0
106218	106217	14033T	PARTICIPANT	\N	PRESENT	0
106219	106108	11036J	PARTICIPANT	\N	PRESENT	0
106232	106108	14105F	PARTICIPANT	\N	PRESENT	0
106323	106067	14269B	PARTICIPANT	\N	PRESENT	0
106324	106067	11112D	PARTICIPANT	\N	PRESENT	0
106325	106067	11027H	PARTICIPANT	\N	PRESENT	0
106326	106067	11067R	PARTICIPANT	\N	PRESENT	0
106327	106067	11054L	PARTICIPANT	\N	PRESENT	0
106328	106067	07026Q	PARTICIPANT	\N	PRESENT	0
106329	106067	08052W	PARTICIPANT	\N	PRESENT	0
106330	106067	04059M	PARTICIPANT	\N	PRESENT	0
106331	106067	11015D	PARTICIPANT	\N	PRESENT	0
106332	106067	92018S	PARTICIPANT	\N	PRESENT	0
106333	106067	04067M	PARTICIPANT	\N	PRESENT	0
106334	106067	14219Q	PARTICIPANT	\N	PRESENT	0
106335	106067	14042U	PARTICIPANT	\N	PRESENT	0
106336	106067	11011M	PARTICIPANT	\N	PRESENT	0
106337	106067	08016S	PARTICIPANT	\N	PRESENT	0
106338	106067	04081K	PARTICIPANT	\N	PRESENT	0
106339	106067	14087W	PARTICIPANT	\N	PRESENT	0
106340	106067	11012A	PARTICIPANT	\N	PRESENT	0
106342	106341	08034U	PARTICIPANT	\N	PRESENT	0
106343	106067	14097Y	PARTICIPANT	\N	PRESENT	0
106344	106067	11036J	PARTICIPANT	\N	PRESENT	0
106345	106067	98050T	PARTICIPANT	\N	PRESENT	0
106346	106067	11091R	PARTICIPANT	\N	PRESENT	0
106347	106067	14265W	PARTICIPANT	\N	PRESENT	0
106349	106067	11107G	PARTICIPANT	\N	PRESENT	0
106350	106348	11048N	PARTICIPANT	\N	PRESENT	0
106352	106351	11048N	PARTICIPANT	\N	PRESENT	0
106378	106067	99004R	PARTICIPANT	\N	PRESENT	0
106379	106067	14030Q	PARTICIPANT	\N	PRESENT	0
106380	106067	11100Y	PARTICIPANT	\N	PRESENT	0
106381	106067	10006L	PARTICIPANT	\N	PRESENT	0
106382	106067	04066L	PARTICIPANT	\N	PRESENT	0
106383	106067	11061K	PARTICIPANT	\N	PRESENT	0
106384	106067	14281W	PARTICIPANT	\N	PRESENT	0
106385	106067	14227Q	PARTICIPANT	\N	PRESENT	0
106386	106067	04049K	PARTICIPANT	\N	PRESENT	0
106387	106067	01011G	PARTICIPANT	\N	PRESENT	0
106388	106067	08051V	PARTICIPANT	\N	PRESENT	0
106389	106067	01034P	PARTICIPANT	\N	PRESENT	0
106390	106067	11034G	PARTICIPANT	\N	PRESENT	0
106391	106067	04085P	PARTICIPANT	\N	PRESENT	0
106392	106067	11029K	PARTICIPANT	\N	PRESENT	0
106315	106067	08055A	PARTICIPANT	\N	PRESENT	0
106316	106067	11031D	PARTICIPANT	\N	PRESENT	0
106393	106067	11089X	PARTICIPANT	\N	PRESENT	0
106394	106067	98005N	PARTICIPANT	\N	PRESENT	0
106395	106067	14157T	PARTICIPANT	\N	PRESENT	0
106396	106067	14215L	PARTICIPANT	\N	PRESENT	0
106397	106067	98018T	PARTICIPANT	\N	PRESENT	0
106398	106067	01048V	PARTICIPANT	\N	PRESENT	0
106399	106067	14013P	PARTICIPANT	\N	PRESENT	0
106400	106067	04050C	PARTICIPANT	\N	PRESENT	0
106401	106067	01059Y	PARTICIPANT	\N	PRESENT	0
106402	106067	04045F	PARTICIPANT	\N	PRESENT	0
106413	106067	11048N	PARTICIPANT	\N	PRESENT	0
98893	98892	04038G	PARTICIPANT	\N	PRESENT	0
98973	98972	89017R	PARTICIPANT	\N	PRESENT	0
98974	98972	01031L	PRESIDENT	0	PRESENT	0
99033	99032	08025T	PARTICIPANT	\N	PRESENT	0
98976	98972	01013J	PARTICIPANT	\N	PRESENT	0
98977	98972	11068S	PARTICIPANT	\N	EXCUSE	0
98978	98972	11040E	PARTICIPANT	\N	PRESENT	0
98979	98972	08014Q	PARTICIPANT	\N	PRESENT	0
99153	99152	08025T	PARTICIPANT	\N	PRESENT	0
98981	98972	14175V	PARTICIPANT	\N	PRESENT	0
98982	98972	14083S	PARTICIPANT	\N	PRESENT	0
98983	98972	11053K	PARTICIPANT	\N	PRESENT	0
98984	98972	14085U	PARTICIPANT	\N	PRESENT	0
98985	98972	11042G	PARTICIPANT	\N	PRESENT	0
98986	98972	88008L	PARTICIPANT	\N	PRESENT	0
98987	98972	04086Q	PARTICIPANT	\N	PRESENT	0
98988	98972	04055H	PARTICIPANT	\N	PRESENT	0
98989	98972	11070L	PARTICIPANT	\N	PRESENT	0
99035	99032	05008E	PRESIDENT	0	PRESENT	0
99036	99032	11030C	PARTICIPANT	\N	PRESENT	0
98992	98972	08022Q	PARTICIPANT	\N	PRESENT	0
98993	98972	01027Q	PARTICIPANT	\N	PRESENT	0
99037	99032	11033F	PARTICIPANT	\N	PRESENT	0
98995	98972	11074Q	PARTICIPANT	\N	PRESENT	0
98996	98972	98053W	PARTICIPANT	\N	EXCUSE	0
98997	98972	11083R	PARTICIPANT	\N	PRESENT	0
98999	98972	01057W	PARTICIPANT	\N	PRESENT	0
99000	98972	08016S	PARTICIPANT	\N	PRESENT	0
99001	98972	08069G	PARTICIPANT	\N	PRESENT	0
99002	98972	11048N	PARTICIPANT	\N	PRESENT	0
99003	98972	99004R	PARTICIPANT	\N	PRESENT	0
99004	98972	04061F	PARTICIPANT	\N	PRESENT	0
99005	98972	14159V	PARTICIPANT	\N	PRESENT	0
99006	98972	07029T	PARTICIPANT	\N	PRESENT	0
99039	99032	14069U	PARTICIPANT	\N	PRESENT	0
99008	98972	08010L	PARTICIPANT	\N	PRESENT	0
99009	98972	08034U	PARTICIPANT	\N	PRESENT	0
99010	98972	01048V	PARTICIPANT	\N	PRESENT	0
99011	98972	98046X	PARTICIPANT	\N	PRESENT	0
99040	99032	04047H	PARTICIPANT	\N	PRESENT	0
99013	98972	08011M	PARTICIPANT	\N	PRESENT	0
99041	99032	11032E	PARTICIPANT	\N	PRESENT	0
99015	98972	08061X	PARTICIPANT	\N	PRESENT	0
99016	98972	01016M	PARTICIPANT	\N	PRESENT	0
99017	98972	14225N	PARTICIPANT	\N	PRESENT	0
99155	99152	05008E	PRESIDENT	0	PRESENT	0
99019	98972	11057P	PARTICIPANT	\N	PRESENT	0
99020	98972	14173T	PARTICIPANT	\N	PRESENT	0
99042	99032	04038G	PARTICIPANT	\N	PRESENT	0
99043	99032	99002P	PARTICIPANT	\N	PRESENT	0
99044	99032	11056N	PARTICIPANT	\N	PRESENT	0
99045	99032	14259Y	PARTICIPANT	\N	PRESENT	0
99046	99032	11035H	PARTICIPANT	\N	PRESENT	0
99047	99032	14041T	PARTICIPANT	\N	EXCUSE	0
99048	99032	11113E	PARTICIPANT	\N	PRESENT	0
99049	99032	01024M	PARTICIPANT	\N	PRESENT	0
99156	99152	11030C	PARTICIPANT	\N	PRESENT	0
99051	99032	11034G	PARTICIPANT	\N	PRESENT	0
99052	99032	08018U	PARTICIPANT	\N	PRESENT	0
99053	99032	11010L	PARTICIPANT	\N	PRESENT	0
99054	99032	01007L	PARTICIPANT	\N	PRESENT	0
99157	99152	11033F	PARTICIPANT	\N	PRESENT	0
99056	99032	08044W	PARTICIPANT	\N	PRESENT	0
99058	99032	11026G	PARTICIPANT	\N	PRESENT	0
99059	99032	04079R	PARTICIPANT	\N	PRESENT	0
99060	99032	14111D	PARTICIPANT	\N	PRESENT	0
99061	99032	14001X	PARTICIPANT	\N	PRESENT	0
99062	99032	14273W	PARTICIPANT	\N	PRESENT	0
99063	99032	01060R	PARTICIPANT	\N	PRESENT	0
99159	99152	14069U	PARTICIPANT	\N	PRESENT	0
99065	99032	95049N	PARTICIPANT	\N	PRESENT	0
99066	99032	08051V	PARTICIPANT	\N	PRESENT	0
99067	99032	11072N	PARTICIPANT	\N	PRESENT	0
99068	99032	07034Q	PARTICIPANT	\N	PRESENT	0
99069	99032	04074L	PARTICIPANT	\N	PRESENT	0
99070	99032	10015M	PARTICIPANT	\N	PRESENT	0
99160	99152	04047H	PARTICIPANT	\N	PRESENT	0
99072	99032	01019Q	PARTICIPANT	\N	PRESENT	0
99073	99032	01028R	PARTICIPANT	\N	PRESENT	0
99074	99032	98035U	PARTICIPANT	\N	PRESENT	0
99075	99032	04056J	PARTICIPANT	\N	PRESENT	0
99076	99032	14275Y	PARTICIPANT	\N	PRESENT	0
99077	99032	04044E	PARTICIPANT	\N	PRESENT	0
99078	99032	11037K	PARTICIPANT	\N	PRESENT	0
99079	99032	92045V	PARTICIPANT	\N	PRESENT	0
99080	99032	95067Q	PARTICIPANT	\N	PRESENT	0
99215	99212	05008E	PRESIDENT	0	PRESENT	0
99161	99152	11032E	PARTICIPANT	\N	PRESENT	0
99162	99152	04038G	PARTICIPANT	\N	PRESENT	0
99163	99152	99002P	PARTICIPANT	\N	PRESENT	0
99164	99152	11056N	PARTICIPANT	\N	PRESENT	0
99165	99152	14259Y	PARTICIPANT	\N	PRESENT	0
99166	99152	11035H	PARTICIPANT	\N	PRESENT	0
99167	99152	14041T	PARTICIPANT	\N	EXCUSE	0
99168	99152	11113E	PARTICIPANT	\N	PRESENT	0
99169	99152	01024M	PARTICIPANT	\N	PRESENT	0
99171	99152	11034G	PARTICIPANT	\N	PRESENT	0
99172	99152	08018U	PARTICIPANT	\N	PRESENT	0
99173	99152	11010L	PARTICIPANT	\N	PRESENT	0
99174	99152	01007L	PARTICIPANT	\N	PRESENT	0
99176	99152	08044W	PARTICIPANT	\N	PRESENT	0
99177	99152	11084S	PARTICIPANT	\N	PRESENT	0
99178	99152	11026G	PARTICIPANT	\N	PRESENT	0
99179	99152	04079R	PARTICIPANT	\N	PRESENT	0
99180	99152	14111D	PARTICIPANT	\N	PRESENT	0
99181	99152	14001X	PARTICIPANT	\N	PRESENT	0
99182	99152	14273W	PARTICIPANT	\N	PRESENT	0
99183	99152	01060R	PARTICIPANT	\N	PRESENT	0
99185	99152	95049N	PARTICIPANT	\N	PRESENT	0
99186	99152	08051V	PARTICIPANT	\N	PRESENT	0
99187	99152	11072N	PARTICIPANT	\N	PRESENT	0
99188	99152	07034Q	PARTICIPANT	\N	PRESENT	0
99189	99152	04074L	PARTICIPANT	\N	PRESENT	0
99190	99152	10015M	PARTICIPANT	\N	PRESENT	0
99192	99152	01019Q	PARTICIPANT	\N	PRESENT	0
99193	99152	01028R	PARTICIPANT	\N	PRESENT	0
99194	99152	98035U	PARTICIPANT	\N	PRESENT	0
99195	99152	04056J	PARTICIPANT	\N	PRESENT	0
99196	99152	14275Y	PARTICIPANT	\N	PRESENT	0
99197	99152	04044E	PARTICIPANT	\N	PRESENT	0
99198	99152	11037K	PARTICIPANT	\N	PRESENT	0
99199	99152	92045V	PARTICIPANT	\N	PRESENT	0
99200	99152	95067Q	PARTICIPANT	\N	PRESENT	0
99201	99152	01047U	PARTICIPANT	\N	PRESENT	0
99219	99212	14069U	PARTICIPANT	\N	PRESENT	0
99220	99212	04047H	PARTICIPANT	\N	PRESENT	0
99222	99212	04038G	PARTICIPANT	\N	PRESENT	0
99226	99212	11035H	PARTICIPANT	\N	PRESENT	0
99227	99212	14041T	PARTICIPANT	\N	EXCUSE	0
99229	99212	01024M	PARTICIPANT	\N	PRESENT	0
99232	99212	08018U	PARTICIPANT	\N	PRESENT	0
99233	99212	11010L	PARTICIPANT	\N	PRESENT	0
99236	99212	08044W	PARTICIPANT	\N	PRESENT	0
99238	99212	11026G	PARTICIPANT	\N	PRESENT	0
99240	99212	14111D	PARTICIPANT	\N	PRESENT	0
99242	99212	14273W	PARTICIPANT	\N	PRESENT	0
99245	99212	95049N	PARTICIPANT	\N	PRESENT	0
99247	99212	11072N	PARTICIPANT	\N	PRESENT	0
99248	99212	07034Q	PARTICIPANT	\N	PRESENT	0
99249	99212	04074L	PARTICIPANT	\N	PRESENT	0
99250	99212	10015M	PARTICIPANT	\N	PRESENT	0
99252	99212	01019Q	PARTICIPANT	\N	PRESENT	0
99253	99212	01028R	PARTICIPANT	\N	PRESENT	0
99254	99212	98035U	PARTICIPANT	\N	PRESENT	0
99257	99212	04044E	PARTICIPANT	\N	PRESENT	0
121017	120992	07029T	PARTICIPANT	\N	PRESENT	0
121018	120992	08034U	PARTICIPANT	\N	PRESENT	0
121019	120992	98046X	PARTICIPANT	\N	PRESENT	0
121020	120992	11085T	PARTICIPANT	\N	PRESENT	0
121021	120992	08011M	PARTICIPANT	\N	PRESENT	0
121022	120992	08061X	PARTICIPANT	\N	EXCUSE	0
121023	120992	01016M	PARTICIPANT	\N	PRESENT	0
121024	120992	14225N	PARTICIPANT	\N	PRESENT	0
121025	120992	11012A	PARTICIPANT	\N	PRESENT	0
121026	120992	11057P	PARTICIPANT	\N	PRESENT	0
121027	120992	04034C	PARTICIPANT	\N	PRESENT	0
121029	121028	11055M	PARTICIPANT	\N	PRESENT	0
121030	121028	08043V	PARTICIPANT	\N	PRESENT	0
121065	119932	08055A	PARTICIPANT	\N	PRESENT	0
121032	121028	95015C	PARTICIPANT	\N	PRESENT	0
121066	119932	01027Q	PARTICIPANT	\N	PRESENT	0
121034	121028	11027H	PARTICIPANT	\N	PRESENT	0
121035	121028	04086Q	PARTICIPANT	\N	PRESENT	0
121036	121028	14079W	PARTICIPANT	\N	PRESENT	0
121067	119932	01031L	PARTICIPANT	\N	PRESENT	0
121038	121028	14215L	PARTICIPANT	\N	PRESENT	0
121039	121028	04089T	PARTICIPANT	\N	PRESENT	0
121040	121028	14187A	PARTICIPANT	\N	PRESENT	0
121041	121028	11034G	PARTICIPANT	\N	PRESENT	0
121068	119932	08016S	PARTICIPANT	\N	PRESENT	0
121043	121028	14231L	PARTICIPANT	\N	PRESENT	0
121044	121028	14179A	PARTICIPANT	\N	PRESENT	0
121045	121028	14213J	PARTICIPANT	\N	PRESENT	0
121046	121028	08031R	PARTICIPANT	\N	PRESENT	0
121047	121028	11100Y	PRESIDENT	0	PRESENT	0
121070	119932	04034C	PARTICIPANT	\N	PRESENT	0
121071	119932	14063N	PARTICIPANT	\N	PRESENT	0
121050	121028	11104D	PARTICIPANT	\N	PRESENT	0
121072	119932	11054L	PARTICIPANT	\N	PRESENT	0
121052	121028	07032N	PARTICIPANT	\N	PRESENT	0
121073	119932	04054G	PARTICIPANT	\N	PRESENT	0
121054	121028	11090Q	PARTICIPANT	\N	PRESENT	0
121055	121028	14235Q	PARTICIPANT	\N	PRESENT	0
121056	121028	95063L	PARTICIPANT	\N	PRESENT	0
121057	121028	11046L	PARTICIPANT	\N	PRESENT	0
121058	121028	01028R	PARTICIPANT	\N	PRESENT	0
121059	121028	11094U	PARTICIPANT	\N	PRESENT	0
121074	119932	98053W	PARTICIPANT	\N	PRESENT	0
121061	121028	14157T	PARTICIPANT	\N	PRESENT	0
121062	121028	92045V	PARTICIPANT	\N	PRESENT	0
121063	121028	11066Q	PARTICIPANT	\N	PRESENT	0
121064	121028	14269B	PARTICIPANT	\N	PRESENT	0
121076	119932	11083R	PARTICIPANT	\N	PRESENT	0
121077	119932	11076S	PARTICIPANT	\N	PRESENT	0
121078	119932	14089Y	PARTICIPANT	\N	PRESENT	0
121079	119932	07004J	PARTICIPANT	\N	PRESENT	0
121081	119932	14147R	PARTICIPANT	\N	PRESENT	0
121084	119932	11012A	PARTICIPANT	\N	PRESENT	0
121085	119932	04078Q	PARTICIPANT	\N	PRESENT	0
121089	119932	97011G	PARTICIPANT	\N	PRESENT	0
121091	119932	11027H	PARTICIPANT	\N	PRESENT	0
121092	119932	14014Q	PARTICIPANT	\N	PRESENT	0
121093	119932	04071H	PARTICIPANT	\N	PRESENT	0
121094	119932	08069G	PARTICIPANT	\N	PRESENT	0
121096	119932	08068F	PARTICIPANT	\N	PRESENT	0
121100	119932	13002U	PARTICIPANT	\N	PRESENT	0
121104	119932	14033T	PARTICIPANT	\N	PRESENT	0
121111	119932	14267Y	PARTICIPANT	\N	PRESENT	0
121126	119932	14041T	PARTICIPANT	\N	PRESENT	0
121127	119932	08019V	PARTICIPANT	\N	PRESENT	0
121145	119932	98046X	PARTICIPANT	\N	PRESENT	0
121146	119932	14223L	PARTICIPANT	\N	PRESENT	0
121147	119932	14265W	PARTICIPANT	\N	PRESENT	0
121148	119932	11036J	PARTICIPANT	\N	PRESENT	0
121149	119932	14119M	PARTICIPANT	\N	PRESENT	0
121150	119932	11066Q	PARTICIPANT	\N	PRESENT	0
121151	119932	14109K	PARTICIPANT	\N	PRESENT	0
121152	119932	98022P	PARTICIPANT	\N	PRESENT	0
121153	119932	01016M	PARTICIPANT	\N	PRESENT	0
121154	119932	14259Y	PARTICIPANT	\N	PRESENT	0
121155	119932	80013X	PARTICIPANT	\N	PRESENT	0
121158	119932	01037S	PARTICIPANT	\N	PRESENT	0
121202	119933	80013X	PARTICIPANT	\N	PRESENT	0
121203	119933	11036J	PARTICIPANT	\N	PRESENT	0
121204	119933	14063N	PARTICIPANT	\N	PRESENT	0
121205	119933	14109K	PARTICIPANT	\N	PRESENT	0
121206	119933	14014Q	PARTICIPANT	\N	PRESENT	0
121207	119933	11066Q	PARTICIPANT	\N	PRESENT	0
121208	119933	98046X	PARTICIPANT	\N	PRESENT	0
121209	119933	01037S	PARTICIPANT	\N	PRESENT	0
121210	119933	14147R	PARTICIPANT	\N	PRESENT	0
121211	119933	98022P	PARTICIPANT	\N	PRESENT	0
121212	119933	14267Y	PARTICIPANT	\N	PRESENT	0
121213	119933	97011G	PARTICIPANT	\N	PRESENT	0
121214	119933	14223L	PARTICIPANT	\N	PRESENT	0
121215	119933	14265W	PARTICIPANT	\N	PRESENT	0
121216	119933	14041T	PARTICIPANT	\N	PRESENT	0
121217	119933	14119M	PARTICIPANT	\N	PRESENT	0
121218	119933	04085P	PARTICIPANT	\N	PRESENT	0
121219	119933	01027Q	PARTICIPANT	\N	PRESENT	0
121220	119933	11084S	PARTICIPANT	\N	PRESENT	0
121221	119933	98018T	PARTICIPANT	\N	PRESENT	0
121222	119933	14187A	PARTICIPANT	\N	PRESENT	0
121223	119933	05008E	PARTICIPANT	\N	PRESENT	0
121224	119933	11012A	PARTICIPANT	\N	PRESENT	0
121225	119933	11033F	PARTICIPANT	\N	PRESENT	0
121227	119933	08051V	PARTICIPANT	\N	PRESENT	0
121228	119933	14033T	PARTICIPANT	\N	PRESENT	0
121229	119933	11014C	PARTICIPANT	\N	PRESENT	0
121230	119933	01028R	PARTICIPANT	\N	PRESENT	0
121231	119933	04067M	PARTICIPANT	\N	PRESENT	0
121235	119933	14241N	PARTICIPANT	\N	PRESENT	0
121237	119933	04088S	PARTICIPANT	\N	PRESENT	0
121248	119933	08019V	PARTICIPANT	\N	PRESENT	0
121249	119933	14069U	PARTICIPANT	\N	PRESENT	0
121251	121250	01034P	PARTICIPANT	\N	PRESENT	0
121252	121250	83047W	PARTICIPANT	\N	PRESENT	0
121253	121250	14235Q	PARTICIPANT	\N	PRESENT	0
121254	121250	01059Y	PARTICIPANT	\N	PRESENT	0
121200	119933	08055A	PARTICIPANT	\N	PRESENT	0
121201	119933	98053W	PARTICIPANT	\N	PRESENT	0
121255	121250	14042U	PARTICIPANT	\N	PRESENT	0
121256	121250	04045F	PARTICIPANT	\N	PRESENT	0
121257	121250	04067M	PARTICIPANT	\N	PRESENT	0
121258	121250	14195A	PARTICIPANT	\N	PRESENT	0
121260	121259	01059Y	PARTICIPANT	\N	PRESENT	0
121261	121259	04067M	PARTICIPANT	\N	PRESENT	0
121262	121259	14211G	PARTICIPANT	\N	PRESENT	0
121263	121259	08034U	PARTICIPANT	\N	PRESENT	0
121264	121259	14205J	PARTICIPANT	\N	PRESENT	0
121265	121259	14265W	PARTICIPANT	\N	PRESENT	0
121266	121259	83047W	PARTICIPANT	\N	PRESENT	0
121267	121259	14235Q	PARTICIPANT	\N	PRESENT	0
121268	121259	04045F	PARTICIPANT	\N	PRESENT	0
121269	121259	01034P	PRESIDENT	0	PRESENT	0
121270	121259	92045V	PARTICIPANT	\N	PRESENT	0
121271	121259	11066Q	PARTICIPANT	\N	PRESENT	0
121272	119933	98050T	PARTICIPANT	\N	PRESENT	0
121298	120701	96004D	PARTICIPANT	\N	EXCUSE	0
121300	121299	11088W	PARTICIPANT	\N	PRESENT	0
121302	121301	14085U	PARTICIPANT	\N	PRESENT	0
121303	121301	14175V	PARTICIPANT	\N	PRESENT	0
121305	121304	11088W	PARTICIPANT	\N	PRESENT	0
121307	121306	08010L	PARTICIPANT	\N	PRESENT	0
121309	121308	08010L	PARTICIPANT	\N	PRESENT	0
121311	121310	08010L	PARTICIPANT	\N	PRESENT	0
121313	121312	08016S	PARTICIPANT	\N	PRESENT	0
121315	121314	05004A	PARTICIPANT	\N	PRESENT	0
121317	121316	08011M	PARTICIPANT	\N	PRESENT	0
121321	121320	14261S	PARTICIPANT	\N	PRESENT	0
121323	121320	14093U	PARTICIPANT	\N	PRESENT	0
121324	121320	14030Q	PARTICIPANT	\N	PRESENT	0
121329	121320	11114F	PARTICIPANT	\N	PRESENT	0
121330	121320	98023Q	PARTICIPANT	\N	PRESENT	0
121331	121320	11065P	PARTICIPANT	\N	PRESENT	0
121296	120697	96004D	PARTICIPANT	\N	EXCUSE	0
121297	120699	96004D	PARTICIPANT	\N	EXCUSE	0
121338	121320	09001P	PARTICIPANT	\N	PRESENT	0
121341	121320	80027E	PARTICIPANT	\N	EXCUSE	0
121342	121320	14031R	PARTICIPANT	\N	PRESENT	0
121343	121320	08009T	PRESIDENT	0	PRESENT	0
94503	94502	08015R	PARTICIPANT	\N	PRESENT	0
94505	94504	08015R	PARTICIPANT	\N	PRESENT	0
95834	94734	95035G	PARTICIPANT	\N	PRESENT	0
95835	94734	14217N	PARTICIPANT	\N	PRESENT	0
95836	94734	14253S	PARTICIPANT	\N	PRESENT	0
95837	94734	14089Y	PARTICIPANT	\N	PRESENT	0
95838	94734	01056V	PARTICIPANT	\N	PRESENT	0
95839	94734	11100Y	PARTICIPANT	\N	PRESENT	0
95895	94735	04070G	PARTICIPANT	\N	PRESENT	0
95896	94735	08039A	PARTICIPANT	\N	PRESENT	0
95897	94735	14191V	PARTICIPANT	\N	PRESENT	0
95898	94735	14173T	PARTICIPANT	\N	PRESENT	0
95899	94735	14105F	PARTICIPANT	\N	PRESENT	0
95900	94735	14033T	PARTICIPANT	\N	PRESENT	0
95901	94735	14217N	PARTICIPANT	\N	PRESENT	0
95902	94735	14059S	PARTICIPANT	\N	PRESENT	0
95903	94735	14209N	PARTICIPANT	\N	PRESENT	0
95934	94735	13002U	PARTICIPANT	\N	PRESENT	0
95905	94735	14257W	PARTICIPANT	\N	PRESENT	0
95906	94735	04095R	PARTICIPANT	\N	PRESENT	0
95907	94735	11025F	PARTICIPANT	\N	PRESENT	0
95908	94735	01044R	PARTICIPANT	\N	PRESENT	0
95909	94735	92015P	PARTICIPANT	\N	PRESENT	0
95910	94735	14263U	PARTICIPANT	\N	PRESENT	0
95911	94735	14051J	PARTICIPANT	\N	PRESENT	0
95912	94735	95037J	PARTICIPANT	\N	PRESENT	0
95913	94735	01022K	PARTICIPANT	\N	PRESENT	0
95914	94735	14030Q	PARTICIPANT	\N	PRESENT	0
95915	94735	14219Q	PARTICIPANT	\N	PRESENT	0
95916	94735	14235Q	PARTICIPANT	\N	PRESENT	0
95917	94735	14063N	PARTICIPANT	\N	PRESENT	0
95918	94735	14107H	PARTICIPANT	\N	PRESENT	0
95919	94735	14109K	PARTICIPANT	\N	PRESENT	0
95920	94735	14229S	PARTICIPANT	\N	PRESENT	0
95921	94735	04059M	PARTICIPANT	\N	PRESENT	0
95922	94735	04088S	PARTICIPANT	\N	PRESENT	0
95923	94735	08031R	PARTICIPANT	\N	PRESENT	0
95924	94735	14241N	PARTICIPANT	\N	PRESENT	0
95925	94735	80013X	PARTICIPANT	\N	PRESENT	0
95926	94735	14213J	PARTICIPANT	\N	PRESENT	0
95927	94735	14061L	PARTICIPANT	\N	PRESENT	0
95928	94735	11071M	PARTICIPANT	\N	PRESENT	0
95929	94735	14265W	PARTICIPANT	\N	PRESENT	0
95930	94735	11091R	PARTICIPANT	\N	PRESENT	0
95931	94735	14251Q	PARTICIPANT	\N	PRESENT	0
95932	94735	04048J	PARTICIPANT	\N	PRESENT	0
95933	94735	95035G	PARTICIPANT	\N	PRESENT	0
95935	94735	08019V	PARTICIPANT	\N	PRESENT	0
95936	94735	97011G	PARTICIPANT	\N	PRESENT	0
95937	94735	14223L	PARTICIPANT	\N	PRESENT	0
95938	94735	14111D	PARTICIPANT	\N	PRESENT	0
95939	94735	04056J	PARTICIPANT	\N	PRESENT	0
95940	94735	95030B	PARTICIPANT	\N	PRESENT	0
95941	94735	01046T	PARTICIPANT	\N	PRESENT	0
95942	94735	11029K	PARTICIPANT	\N	PRESENT	0
95943	94735	01019Q	PARTICIPANT	\N	PRESENT	0
95944	94735	04081K	PARTICIPANT	\N	PRESENT	0
95945	94735	14079W	PARTICIPANT	\N	PRESENT	0
95946	94735	11106F	PARTICIPANT	\N	PRESENT	0
95947	94735	14169X	PARTICIPANT	\N	PRESENT	0
95948	94735	95067Q	PARTICIPANT	\N	PRESENT	0
95893	94735	98053W	PARTICIPANT	\N	PRESENT	0
95894	94735	01025N	PARTICIPANT	\N	PRESENT	0
95949	94735	14221J	PARTICIPANT	\N	PRESENT	0
95950	94735	14237S	PARTICIPANT	\N	PRESENT	0
95951	94735	98022P	PARTICIPANT	\N	PRESENT	0
95952	94735	01041N	PARTICIPANT	\N	PRESENT	0
95953	94735	08038Y	PARTICIPANT	\N	PRESENT	0
95954	94735	08043V	PARTICIPANT	\N	PRESENT	0
95955	94735	11093T	PARTICIPANT	\N	PRESENT	0
95956	94735	11039M	PARTICIPANT	\N	PRESENT	0
95958	94735	11061K	PARTICIPANT	\N	PRESENT	0
95959	94735	11067R	PARTICIPANT	\N	PRESENT	0
95960	94735	07026Q	PARTICIPANT	\N	PRESENT	0
95961	94735	11112D	PARTICIPANT	\N	PRESENT	0
95962	94735	14103D	PARTICIPANT	\N	PRESENT	0
95963	94735	14073Q	PARTICIPANT	\N	PRESENT	0
95964	94735	87003B	PARTICIPANT	\N	PRESENT	0
95965	94735	04035D	PARTICIPANT	\N	PRESENT	0
95966	94735	95062K	PARTICIPANT	\N	PRESENT	0
95968	94735	11043H	PARTICIPANT	\N	PRESENT	0
95975	94735	86044G	PARTICIPANT	\N	PRESENT	0
95976	94735	80027E	PARTICIPANT	\N	PRESENT	0
95977	94735	08056B	PARTICIPANT	\N	PRESENT	0
95982	94735	14121F	PARTICIPANT	\N	PRESENT	0
95983	94735	14259Y	PARTICIPANT	\N	PRESENT	0
95994	94735	11048N	PARTICIPANT	\N	PRESENT	0
96034	94735	14225N	PARTICIPANT	\N	PRESENT	0
96035	94735	01008M	PARTICIPANT	\N	PRESENT	0
96047	94735	14205J	PARTICIPANT	\N	PRESENT	0
96048	94735	12042Y	PARTICIPANT	\N	PRESENT	0
96049	94735	01037S	PARTICIPANT	\N	PRESENT	0
96050	94735	08048B	PARTICIPANT	\N	PRESENT	0
96051	94735	14069U	PARTICIPANT	\N	PRESENT	0
96052	94735	07004J	PARTICIPANT	\N	PRESENT	0
96053	94735	14018U	PARTICIPANT	\N	PRESENT	0
96054	94735	14327T	PARTICIPANT	\N	PRESENT	0
96055	94735	14199E	PARTICIPANT	\N	PRESENT	0
96056	94735	14038Y	PARTICIPANT	\N	PRESENT	0
96057	94735	01027Q	PARTICIPANT	\N	PRESENT	0
96058	94735	08068F	PARTICIPANT	\N	PRESENT	0
96059	94735	11012A	PARTICIPANT	\N	PRESENT	0
96060	94735	11105E	PARTICIPANT	\N	PRESENT	0
96073	94735	11066Q	PARTICIPANT	\N	PRESENT	0
96075	94735	14197C	PARTICIPANT	\N	PRESENT	0
96077	94735	14249W	PARTICIPANT	\N	PRESENT	0
96078	94735	92045V	PARTICIPANT	\N	PRESENT	0
96080	94735	01047U	PARTICIPANT	\N	PRESENT	0
96082	94735	14093U	PARTICIPANT	\N	PRESENT	0
96097	94735	08069G	PARTICIPANT	\N	PRESENT	0
96109	94735	14042U	PARTICIPANT	\N	PRESENT	0
96110	94735	01003G	PARTICIPANT	\N	PRESENT	0
96119	94735	14097Y	PARTICIPANT	\N	PRESENT	0
96120	94735	11044J	PARTICIPANT	\N	PRESENT	0
96121	94735	08015R	PARTICIPANT	\N	PRESENT	0
96122	94735	95049N	PARTICIPANT	\N	PRESENT	0
96123	94735	08014Q	PARTICIPANT	\N	PRESENT	0
96124	94735	08012N	PARTICIPANT	\N	PRESENT	0
96125	94735	11107G	PARTICIPANT	\N	PRESENT	0
96126	94735	12041X	PARTICIPANT	\N	PRESENT	0
96127	94735	01007L	PARTICIPANT	\N	PRESENT	0
96128	94735	14133K	PARTICIPANT	\N	PRESENT	0
96129	94735	14175V	PARTICIPANT	\N	PRESENT	0
96130	94735	01057W	PARTICIPANT	\N	PRESENT	0
96142	94736	08024S	PARTICIPANT	\N	PRESENT	0
96143	94736	08039A	PARTICIPANT	\N	PRESENT	0
96144	94736	01025N	PARTICIPANT	\N	PRESENT	0
96145	94736	14263U	PARTICIPANT	\N	PRESENT	0
96146	94736	04085P	PARTICIPANT	\N	PRESENT	0
96147	94736	11074Q	PARTICIPANT	\N	PRESENT	0
96148	94736	14097Y	PARTICIPANT	\N	PRESENT	0
96149	94736	01016M	PARTICIPANT	\N	PRESENT	0
96150	94736	01044R	PARTICIPANT	\N	PRESENT	0
96151	94736	11029K	PARTICIPANT	\N	PRESENT	0
96152	94736	14219Q	PARTICIPANT	\N	PRESENT	0
96153	94736	14109K	PARTICIPANT	\N	PRESENT	0
96154	94736	14031R	PARTICIPANT	\N	PRESENT	0
96155	94736	08019V	PARTICIPANT	\N	PRESENT	0
96156	94736	14105F	PARTICIPANT	\N	PRESENT	0
96157	94736	14038Y	PARTICIPANT	\N	PRESENT	0
96158	94736	14229S	PARTICIPANT	\N	PRESENT	0
96159	94736	04059M	PARTICIPANT	\N	PRESENT	0
96160	94736	11112D	PARTICIPANT	\N	PRESENT	0
96161	94736	14241N	PARTICIPANT	\N	PRESENT	0
96162	94736	11044J	PARTICIPANT	\N	PRESENT	0
96163	94736	08043V	PARTICIPANT	\N	PRESENT	0
96164	94736	08031R	PARTICIPANT	\N	PRESENT	0
96165	94736	01046T	PARTICIPANT	\N	PRESENT	0
96166	94736	14018U	PARTICIPANT	\N	PRESENT	0
96167	94736	11012A	PARTICIPANT	\N	PRESENT	0
96168	94736	80013X	PARTICIPANT	\N	PRESENT	0
96169	94736	14103D	PARTICIPANT	\N	PRESENT	0
96170	94736	14225N	PARTICIPANT	\N	PRESENT	0
96171	94736	14257W	PARTICIPANT	\N	PRESENT	0
96172	94736	10006L	PARTICIPANT	\N	PRESENT	0
96173	94736	14231L	PARTICIPANT	\N	PRESENT	0
96174	94736	11093T	PARTICIPANT	\N	PRESENT	0
96175	94736	89017R	PARTICIPANT	\N	PRESENT	0
96176	94736	04088S	PARTICIPANT	\N	PRESENT	0
96177	94736	14175V	PARTICIPANT	\N	PRESENT	0
96178	94736	14135M	PARTICIPANT	\N	PRESENT	0
96179	94736	14033T	PARTICIPANT	\N	PRESENT	0
96180	94736	01057W	PARTICIPANT	\N	PRESENT	0
96181	94736	08015R	PARTICIPANT	\N	PRESENT	0
96182	94736	14213J	PARTICIPANT	\N	PRESENT	0
96183	94736	14061L	PARTICIPANT	\N	PRESENT	0
96184	94736	14187A	PARTICIPANT	\N	PRESENT	0
96185	94736	14071N	PARTICIPANT	\N	PRESENT	0
106414	106067	14083S	PARTICIPANT	\N	PRESENT	0
106474	106067	14059S	PARTICIPANT	\N	PRESENT	0
106485	106067	11076S	PARTICIPANT	\N	PRESENT	0
106487	106067	14033T	PARTICIPANT	\N	PRESENT	0
106512	106067	14255U	PARTICIPANT	\N	PRESENT	0
106532	106067	11026G	PARTICIPANT	\N	PRESENT	0
106533	106067	12042Y	PARTICIPANT	\N	PRESENT	0
106552	106067	04057K	PARTICIPANT	\N	PRESENT	0
106572	106068	04066L	PARTICIPANT	\N	PRESENT	0
106573	106068	04092N	PARTICIPANT	\N	PRESENT	0
106574	106068	14037X	PARTICIPANT	\N	PRESENT	0
106575	106068	14034U	PARTICIPANT	\N	PRESENT	0
106576	106068	11063M	PARTICIPANT	\N	PRESENT	0
106577	106068	11031D	PARTICIPANT	\N	PRESENT	0
106578	106068	04050C	PARTICIPANT	\N	PRESENT	0
106579	106068	07026Q	PARTICIPANT	\N	PRESENT	0
106580	106068	08052W	PARTICIPANT	\N	PRESENT	0
106581	106068	12042Y	PARTICIPANT	\N	PRESENT	0
106582	106068	04053F	PARTICIPANT	\N	PRESENT	0
106583	106068	14271U	PARTICIPANT	\N	PRESENT	0
106584	106068	14269B	PARTICIPANT	\N	PRESENT	0
106585	106068	08016S	PARTICIPANT	\N	PRESENT	0
106586	106068	04067M	PARTICIPANT	\N	PRESENT	0
106587	106068	14219Q	PARTICIPANT	\N	PRESENT	0
106588	106068	14265W	PARTICIPANT	\N	PRESENT	0
106589	106068	10006L	PARTICIPANT	\N	PRESENT	0
106590	106068	01034P	PARTICIPANT	\N	PRESENT	0
106591	106068	11012A	PARTICIPANT	\N	PRESENT	0
106592	106068	11089X	PARTICIPANT	\N	PRESENT	0
106593	106068	14083S	PARTICIPANT	\N	PRESENT	0
106612	106068	11077T	PARTICIPANT	\N	PRESENT	0
106613	106068	14042U	PARTICIPANT	\N	PRESENT	0
106632	106068	04042C	PARTICIPANT	\N	PRESENT	0
106633	106068	14255U	PARTICIPANT	\N	PRESENT	0
106634	106068	11053K	PARTICIPANT	\N	PRESENT	0
106652	106068	08069G	PARTICIPANT	\N	PRESENT	0
106773	106772	04049K	PARTICIPANT	\N	PRESENT	0
106927	106926	04071H	PARTICIPANT	\N	PRESENT	0
106929	106928	04071H	PARTICIPANT	\N	PRESENT	0
106931	106930	04071H	PARTICIPANT	\N	PRESENT	0
106933	106932	04071H	PARTICIPANT	\N	PRESENT	0
107141	107140	14281W	PARTICIPANT	\N	PRESENT	0
107142	107140	07004J	PARTICIPANT	\N	PRESENT	0
107143	107140	10015M	PARTICIPANT	\N	PRESENT	0
107292	106812	08024S	PARTICIPANT	\N	PRESENT	0
107297	106812	11112D	PARTICIPANT	\N	PRESENT	0
107298	106812	14107H	PARTICIPANT	\N	PRESENT	0
107299	106812	11027H	PARTICIPANT	\N	PRESENT	0
107300	106812	11110B	PARTICIPANT	\N	PRESENT	0
107301	106812	08042U	PARTICIPANT	\N	PRESENT	0
107302	106812	05012A	PARTICIPANT	\N	PRESENT	0
107303	106812	14157T	PARTICIPANT	\N	PRESENT	0
107304	106812	07026Q	PARTICIPANT	\N	PRESENT	0
107305	106812	14028W	PARTICIPANT	\N	PRESENT	0
107306	106812	12042Y	PARTICIPANT	\N	PRESENT	0
107316	106812	14219Q	PARTICIPANT	\N	PRESENT	0
107317	106812	89017R	PARTICIPANT	\N	PRESENT	0
107318	106812	95035G	PARTICIPANT	\N	PRESENT	0
107319	106812	14265W	PARTICIPANT	\N	PRESENT	0
107320	106812	14221J	PARTICIPANT	\N	PRESENT	0
107321	106812	01025N	PARTICIPANT	\N	PRESENT	0
107322	106812	11098Y	PARTICIPANT	\N	PRESENT	0
107323	106812	14197C	PARTICIPANT	\N	PRESENT	0
107324	106812	14069U	PARTICIPANT	\N	PRESENT	0
107325	106812	11094U	PARTICIPANT	\N	PRESENT	0
107372	106812	14109K	PARTICIPANT	\N	PRESENT	0
107373	106812	14179A	PARTICIPANT	\N	PRESENT	0
107410	106812	11039M	PARTICIPANT	\N	PRESENT	0
107411	106812	14001X	PARTICIPANT	\N	PRESENT	0
107412	106812	01007L	PARTICIPANT	\N	PRESENT	0
107414	107413	89017R	PARTICIPANT	\N	PRESENT	0
107415	107413	01031L	PRESIDENT	0	PRESENT	0
107416	107413	11068S	PARTICIPANT	\N	EXCUSE	0
107417	107413	11040E	PARTICIPANT	\N	PRESENT	0
107418	107413	08014Q	PARTICIPANT	\N	PRESENT	0
107419	107413	11042G	PARTICIPANT	\N	PRESENT	0
107420	107413	04086Q	PARTICIPANT	\N	PRESENT	0
107421	107413	11088W	PARTICIPANT	\N	PRESENT	0
107422	107413	14327T	PARTICIPANT	\N	EXCUSE	0
107423	107413	04071H	PARTICIPANT	\N	PRESENT	0
107424	107413	11074Q	PARTICIPANT	\N	PRESENT	0
107425	107413	11083R	PARTICIPANT	\N	PRESENT	0
107426	107413	11048N	PARTICIPANT	\N	PRESENT	0
107427	107413	14159V	PARTICIPANT	\N	PRESENT	0
107428	107413	07029T	PARTICIPANT	\N	PRESENT	0
107429	107413	01048V	PARTICIPANT	\N	PRESENT	0
107430	107413	98046X	PARTICIPANT	\N	PRESENT	0
107431	107413	11085T	PARTICIPANT	\N	EXCUSE	0
107432	107413	08011M	PARTICIPANT	\N	PRESENT	0
107433	107413	08061X	PARTICIPANT	\N	PRESENT	0
107434	107413	14225N	PARTICIPANT	\N	PRESENT	0
107435	107413	11012A	PARTICIPANT	\N	EXCUSE	0
107436	107413	11057P	PARTICIPANT	\N	PRESENT	0
107437	107413	14173T	PARTICIPANT	\N	PRESENT	0
107438	107413	95030B	PARTICIPANT	\N	PRESENT	0
107439	107413	05008E	PARTICIPANT	\N	PRESENT	0
107440	107413	14069U	PARTICIPANT	\N	PRESENT	0
107441	107413	04047H	PARTICIPANT	\N	PRESENT	0
107442	107413	04038G	PARTICIPANT	\N	PRESENT	0
107443	107413	11035H	PARTICIPANT	\N	PRESENT	0
107444	107413	14041T	PARTICIPANT	\N	PRESENT	0
107445	107413	01024M	PARTICIPANT	\N	PRESENT	0
107446	107413	11026G	PARTICIPANT	\N	PRESENT	0
107447	107413	14111D	PARTICIPANT	\N	PRESENT	0
107448	107413	14147R	PARTICIPANT	\N	PRESENT	0
107449	107413	08051V	PARTICIPANT	\N	PRESENT	0
107450	107413	11072N	PARTICIPANT	\N	PRESENT	0
107451	107413	07034Q	PARTICIPANT	\N	PRESENT	0
107452	107413	01028R	PARTICIPANT	\N	PRESENT	0
107453	107413	04056J	PARTICIPANT	\N	PRESENT	0
107454	107413	14207L	PARTICIPANT	\N	PRESENT	0
107455	107413	80013X	PARTICIPANT	\N	PRESENT	0
107456	107413	08038Y	PARTICIPANT	\N	PRESENT	0
107457	107413	14197C	PARTICIPANT	\N	PRESENT	0
107458	107413	11110B	PARTICIPANT	\N	PRESENT	0
107459	107413	14187A	PARTICIPANT	\N	PRESENT	0
107460	107413	14033T	PARTICIPANT	\N	PRESENT	0
107461	107413	04049K	PARTICIPANT	\N	PRESENT	0
107462	107413	11111C	PARTICIPANT	\N	PRESENT	0
107463	107413	08015R	PARTICIPANT	\N	PRESENT	0
107464	107413	11100Y	PARTICIPANT	\N	PRESENT	0
107465	107413	14205J	PARTICIPANT	\N	PRESENT	0
107466	107413	08019V	PARTICIPANT	\N	PRESENT	0
107467	107413	98050T	PARTICIPANT	\N	PRESENT	0
107468	107413	11090Q	PARTICIPANT	\N	PRESENT	0
107469	107413	01058X	PARTICIPANT	\N	PRESENT	0
107470	107413	11066Q	PARTICIPANT	\N	PRESENT	0
107471	106812	14187A	PARTICIPANT	\N	PRESENT	0
107472	106812	07029T	PARTICIPANT	\N	PRESENT	0
107473	106812	14083S	PARTICIPANT	\N	PRESENT	0
107474	106812	10015M	PARTICIPANT	\N	PRESENT	0
107475	107413	98053W	PARTICIPANT	\N	EXCUSE	0
107477	107476	05008E	PRESIDENT	0	PRESENT	0
107478	107476	14069U	PARTICIPANT	\N	PRESENT	0
107479	107476	04047H	PARTICIPANT	\N	PRESENT	0
107482	107476	04038G	PARTICIPANT	\N	PRESENT	0
107483	107476	11035H	PARTICIPANT	\N	PRESENT	0
107484	107476	14041T	PARTICIPANT	\N	PRESENT	0
107485	107476	01024M	PARTICIPANT	\N	PRESENT	0
500961	500410	19713W	PARTICIPANT	\N	PRESENT	0
500962	500410	11045K	PARTICIPANT	\N	PRESENT	0
500963	500410	08045X	PARTICIPANT	\N	PRESENT	0
500964	500410	19663E	PARTICIPANT	\N	PRESENT	0
500965	500410	17965H	PARTICIPANT	\N	PRESENT	0
500966	500410	19301E	PARTICIPANT	\N	PRESENT	0
500967	500410	19715Y	PARTICIPANT	\N	PRESENT	0
500968	500410	19691J	PARTICIPANT	\N	PRESENT	0
500969	500410	19717B	PARTICIPANT	\N	PRESENT	0
500970	500410	19723Y	PARTICIPANT	\N	PRESENT	0
500971	500410	20066E	PARTICIPANT	\N	PRESENT	0
500972	500410	14071N	PARTICIPANT	\N	PRESENT	0
500973	500410	19657G	PARTICIPANT	\N	PRESENT	0
500974	500410	04043D	PARTICIPANT	\N	PRESENT	0
500975	500410	19760E	PARTICIPANT	\N	PRESENT	0
501642	495438	01028R	PARTICIPANT	\N	PRESENT	0
501649	495438	19643A	PARTICIPANT	\N	PRESENT	0
501795	501793	19637C	PARTICIPANT	\N	PRESENT	0
501796	501794	19637C	PARTICIPANT	\N	PRESENT	0
502302	502296	19629C	PARTICIPANT	\N	PRESENT	0
502303	502300	19629C	PARTICIPANT	\N	PRESENT	0
502419	502418	14229S	PARTICIPANT	\N	PRESENT	0
502648	502647	14267Y	PARTICIPANT	\N	PRESENT	0
502649	502647	19565D	PARTICIPANT	\N	PRESENT	0
502651	502650	14211G	PARTICIPANT	\N	PRESENT	0
502653	502652	14211G	PARTICIPANT	\N	PRESENT	0
502654	502652	11083R	PARTICIPANT	\N	PRESENT	0
502656	502655	14211G	PARTICIPANT	\N	PRESENT	0
502657	502655	11083R	PARTICIPANT	\N	PRESENT	0
99263	99262	08025T	PARTICIPANT	\N	PRESENT	0
94190	89157	11036J	PARTICIPANT	\N	PRESENT	0
94191	89157	80013X	PARTICIPANT	\N	PRESENT	0
94192	89157	14299H	PARTICIPANT	\N	PRESENT	0
94193	89157	11089X	PARTICIPANT	\N	PRESENT	0
94203	89157	01058X	PRESIDENT	0	PRESENT	0
94215	89162	11082Q	PARTICIPANT	\N	EXCUSE	0
94216	89162	04043D	PARTICIPANT	\N	PRESENT	0
94354	89162	11089X	PARTICIPANT	\N	PRESENT	0
94355	89162	08069G	PARTICIPANT	\N	EXCUSE	0
94356	89162	04061F	PARTICIPANT	\N	EXCUSE	0
94413	89162	13002U	PARTICIPANT	\N	PRESENT	0
94414	89162	14257W	PARTICIPANT	\N	PRESENT	0
94432	89162	11036J	PARTICIPANT	\N	PRESENT	0
94433	89162	14221J	PARTICIPANT	\N	EXCUSE	0
94434	89162	80013X	PARTICIPANT	\N	PRESENT	0
94435	89162	01058X	PARTICIPANT	\N	PRESENT	0
99258	99212	11037K	PARTICIPANT	\N	PRESENT	0
99259	99212	92045V	PARTICIPANT	\N	PRESENT	0
99260	99212	95067Q	PARTICIPANT	\N	PRESENT	0
99265	99262	11033F	PARTICIPANT	\N	PRESENT	0
99264	99262	05008E	PRESIDENT	0	PRESENT	0
99266	99262	04047H	PARTICIPANT	\N	PRESENT	0
99267	99262	11056N	PARTICIPANT	\N	PRESENT	0
99268	99262	14041T	PARTICIPANT	\N	EXCUSE	0
99269	99262	11113E	PARTICIPANT	\N	PRESENT	0
99270	99262	01024M	PARTICIPANT	\N	PRESENT	0
99271	99262	01007L	PARTICIPANT	\N	PRESENT	0
99272	99262	08044W	PARTICIPANT	\N	PRESENT	0
99273	99262	11084S	PARTICIPANT	\N	PRESENT	0
99274	99262	11026G	PARTICIPANT	\N	PRESENT	0
99275	99262	14001X	PARTICIPANT	\N	PRESENT	0
99276	99262	14273W	PARTICIPANT	\N	PRESENT	0
99277	99262	95049N	PARTICIPANT	\N	PRESENT	0
99278	99262	11072N	PARTICIPANT	\N	PRESENT	0
99279	99262	07034Q	PARTICIPANT	\N	PRESENT	0
99280	99262	10015M	PARTICIPANT	\N	PRESENT	0
99281	99262	01028R	PARTICIPANT	\N	PRESENT	0
99282	99262	04056J	PARTICIPANT	\N	PRESENT	0
102238	102234	04061F	PARTICIPANT	\N	PRESENT	0
99284	99262	11037K	PARTICIPANT	\N	PRESENT	0
99353	99262	04044E	PARTICIPANT	\N	PRESENT	0
102237	102234	88008L	PARTICIPANT	\N	PRESENT	0
102418	102414	08010L	PARTICIPANT	\N	PRESENT	0
102422	102414	01031L	PARTICIPANT	\N	PRESENT	0
102425	102414	08011M	PARTICIPANT	\N	PRESENT	0
102442	102437	01057W	PARTICIPANT	\N	PRESENT	0
102443	102437	14225N	PARTICIPANT	\N	PRESENT	0
102446	102114	11109J	PARTICIPANT	\N	PRESENT	0
102447	102114	04059M	PARTICIPANT	\N	PRESENT	0
102449	102114	08043V	PARTICIPANT	\N	EXCUSE	0
102457	102114	11029K	PARTICIPANT	\N	PRESENT	0
102459	102114	95015C	PARTICIPANT	\N	PRESENT	0
102461	102454	08010L	PARTICIPANT	\N	PRESENT	0
102462	102114	92015P	PARTICIPANT	\N	PRESENT	0
102463	102114	08024S	PARTICIPANT	\N	EXCUSE	0
102468	102114	14209N	PARTICIPANT	\N	PRESENT	0
102469	102114	11089X	PARTICIPANT	\N	PRESENT	0
102470	102114	07026Q	PARTICIPANT	\N	PRESENT	0
102471	102114	04041B	PARTICIPANT	\N	EXCUSE	0
102473	102114	14061L	PARTICIPANT	\N	PRESENT	0
102474	102114	08031R	PARTICIPANT	\N	EXCUSE	0
102475	102114	08039A	PARTICIPANT	\N	EXCUSE	0
102476	102114	14059S	PARTICIPANT	\N	PRESENT	0
102479	102114	08012N	PARTICIPANT	\N	PRESENT	0
102480	102114	14063N	PARTICIPANT	\N	EXCUSE	0
102481	102114	04057K	PARTICIPANT	\N	EXCUSE	0
102482	102114	14109K	PARTICIPANT	\N	PRESENT	0
102483	102114	04070G	PRESIDENT	0	PRESENT	0
102484	102114	11011M	PARTICIPANT	\N	PRESENT	0
102485	102114	96004D	PARTICIPANT	\N	PRESENT	0
102746	102114	01008M	PARTICIPANT	\N	PRESENT	0
102747	102114	11036J	PARTICIPANT	\N	PRESENT	0
102749	102114	11040E	PARTICIPANT	\N	PRESENT	0
102750	102114	14207L	PARTICIPANT	\N	PRESENT	0
102751	102114	80013X	PARTICIPANT	\N	PRESENT	0
102752	102114	08038Y	PARTICIPANT	\N	PRESENT	0
102753	102114	04089T	PARTICIPANT	\N	PRESENT	0
102754	102114	14187A	PARTICIPANT	\N	PRESENT	0
102826	102821	08011M	PARTICIPANT	\N	PRESENT	0
102756	102114	11100Y	PARTICIPANT	\N	PRESENT	0
102757	102114	14257W	PARTICIPANT	\N	PRESENT	0
102758	102114	04088S	PARTICIPANT	\N	PRESENT	0
102759	102114	98050T	PARTICIPANT	\N	PRESENT	0
102760	102114	11046L	PARTICIPANT	\N	PRESENT	0
102761	102114	01058X	PARTICIPANT	\N	PRESENT	0
102762	102114	11066Q	PARTICIPANT	\N	PRESENT	0
102763	102114	95030B	PARTICIPANT	\N	PRESENT	0
102764	102114	08018U	PARTICIPANT	\N	PRESENT	0
102765	102114	11083R	PARTICIPANT	\N	PRESENT	0
102766	102114	14097Y	PARTICIPANT	\N	PRESENT	0
102767	102114	08044W	PARTICIPANT	\N	PRESENT	0
102768	102114	14001X	PARTICIPANT	\N	PRESENT	0
102769	102114	04080J	PARTICIPANT	\N	PRESENT	0
102770	102114	14135M	PARTICIPANT	\N	PRESENT	0
102771	102114	11012A	PARTICIPANT	\N	PRESENT	0
102772	102114	04045F	PARTICIPANT	\N	PRESENT	0
102773	102114	92045V	PARTICIPANT	\N	PRESENT	0
102774	102114	08015R	PARTICIPANT	\N	PRESENT	0
102825	102821	01031L	PARTICIPANT	\N	PRESENT	0
102831	102821	08010L	PARTICIPANT	\N	PRESENT	0
103073	103072	14187A	PARTICIPANT	\N	PRESENT	0
103074	103072	11046L	PARTICIPANT	\N	PRESENT	0
103075	103072	11094U	PARTICIPANT	\N	PRESENT	0
105417	105416	11076S	PARTICIPANT	\N	PRESENT	0
105418	105416	04054G	PARTICIPANT	\N	PRESENT	0
105419	105416	04040A	PARTICIPANT	\N	PRESENT	0
105420	105416	08058D	PARTICIPANT	\N	PRESENT	0
105421	105416	04042C	PARTICIPANT	\N	EXCUSE	0
105496	105416	04047H	PARTICIPANT	\N	PRESENT	0
105541	105535	08025T	PARTICIPANT	\N	PRESENT	0
105425	105416	11027H	PARTICIPANT	\N	PRESENT	0
105426	105416	98018T	PARTICIPANT	\N	PRESENT	0
105427	105416	92018S	PARTICIPANT	\N	PRESENT	0
105428	105416	92020L	PARTICIPANT	\N	PRESENT	0
105429	105416	95030B	PARTICIPANT	\N	PRESENT	0
105543	105535	05008E	PRESIDENT	0	PRESENT	0
105544	105535	11030C	PARTICIPANT	\N	PRESENT	0
105432	105416	97011G	PARTICIPANT	\N	PRESENT	0
105545	105535	11033F	PARTICIPANT	\N	PRESENT	0
105434	105416	04035D	PARTICIPANT	\N	EXCUSE	0
105435	105416	07024N	PARTICIPANT	\N	PRESENT	0
105546	105535	14065Q	PARTICIPANT	\N	PRESENT	0
105437	105416	14014Q	PARTICIPANT	\N	PRESENT	0
105438	105416	11015D	PARTICIPANT	\N	PRESENT	0
105547	105535	14069U	PARTICIPANT	\N	PRESENT	0
105440	105416	95035G	PARTICIPANT	\N	PRESENT	0
105548	105535	04047H	PARTICIPANT	\N	PRESENT	0
105549	105535	11032E	PARTICIPANT	\N	PRESENT	0
105443	105416	98022P	PARTICIPANT	\N	PRESENT	0
105550	105535	04038G	PARTICIPANT	\N	PRESENT	0
105551	105535	99002P	PARTICIPANT	\N	PRESENT	0
105552	105535	11056N	PARTICIPANT	\N	PRESENT	0
105447	105416	14097Y	PARTICIPANT	\N	PRESENT	0
105553	105535	14259Y	PARTICIPANT	\N	PRESENT	0
105449	105416	04036E	PARTICIPANT	\N	PRESENT	0
105555	105535	14041T	PARTICIPANT	\N	EXCUSE	0
105452	105416	98005N	PARTICIPANT	\N	PRESENT	0
105453	105416	92031P	PARTICIPANT	\N	PRESENT	0
105454	105416	11106F	PARTICIPANT	\N	PRESENT	0
105455	105416	14251Q	PARTICIPANT	\N	PRESENT	0
105457	105416	08053X	PARTICIPANT	\N	PRESENT	0
105458	105416	11082Q	PARTICIPANT	\N	EXCUSE	0
105557	105535	01024M	PARTICIPANT	\N	PRESENT	0
105558	105535	14215L	PARTICIPANT	\N	PRESENT	0
105461	105416	08047A	PARTICIPANT	\N	EXCUSE	0
105462	105416	14028W	PARTICIPANT	\N	PRESENT	0
105560	105535	08018U	PARTICIPANT	\N	PRESENT	0
105466	105416	95059Q	PRESIDENT	0	PRESENT	0
105562	105535	01007L	PARTICIPANT	\N	PRESENT	0
105468	105416	01014K	PARTICIPANT	\N	PRESENT	0
105469	105416	11054L	PARTICIPANT	\N	PRESENT	0
105470	105416	01056V	PARTICIPANT	\N	PRESENT	0
105563	105535	11049P	PARTICIPANT	\N	PRESENT	0
105473	105416	04050C	PARTICIPANT	\N	PRESENT	0
105566	105535	11026G	PARTICIPANT	\N	PRESENT	0
105567	105535	04079R	PARTICIPANT	\N	PRESENT	0
105568	105535	14111D	PARTICIPANT	\N	PRESENT	0
121371	121368	89017R	PARTICIPANT	\N	PRESENT	0
121345	121320	14221J	PARTICIPANT	\N	PRESENT	0
121369	119934	14179A	PARTICIPANT	\N	PRESENT	0
121347	121320	08042U	PARTICIPANT	\N	EXCUSE	0
121370	119934	14193X	PARTICIPANT	\N	PRESENT	0
121349	121320	14237S	PARTICIPANT	\N	EXCUSE	0
121350	121320	13002U	PARTICIPANT	\N	PRESENT	0
121351	121320	05012A	PARTICIPANT	\N	PRESENT	0
121372	119934	14227Q	PARTICIPANT	\N	PRESENT	0
121353	121320	14135M	PARTICIPANT	\N	PRESENT	0
121354	121320	14331P	PARTICIPANT	\N	PRESENT	0
121355	121320	95062K	PARTICIPANT	\N	PRESENT	0
121356	121320	14107H	PARTICIPANT	\N	EXCUSE	0
121373	119934	90003B	PARTICIPANT	\N	PRESENT	0
121358	121320	14157T	PARTICIPANT	\N	PRESENT	0
121359	121320	96003C	PARTICIPANT	\N	EXCUSE	0
121360	121320	08055A	PARTICIPANT	\N	EXCUSE	0
121361	121320	08060W	PARTICIPANT	\N	EXCUSE	0
121362	121320	11107G	PARTICIPANT	\N	EXCUSE	0
121363	121320	02002K	PARTICIPANT	\N	EXCUSE	0
121364	121320	01022K	PARTICIPANT	\N	EXCUSE	0
121374	119934	11010L	PARTICIPANT	\N	PRESENT	0
121380	119934	04048J	PARTICIPANT	\N	PRESENT	0
121376	119934	14157T	PARTICIPANT	\N	PRESENT	0
121377	119934	01027Q	PARTICIPANT	\N	PRESENT	0
121378	119934	86044G	PARTICIPANT	\N	PRESENT	0
121379	119934	04074L	PARTICIPANT	\N	PRESENT	0
121381	119934	95062K	PARTICIPANT	\N	PRESENT	0
121383	119934	14059S	PARTICIPANT	\N	PRESENT	0
121384	119934	14331P	PARTICIPANT	\N	PRESENT	0
121385	119934	11103C	PARTICIPANT	\N	PRESENT	0
121386	119934	11080N	PARTICIPANT	\N	PRESENT	0
121387	119934	04088S	PARTICIPANT	\N	PRESENT	0
121388	119934	97011G	PARTICIPANT	\N	PRESENT	0
121389	119934	11097X	PARTICIPANT	\N	PRESENT	0
121390	119934	14030Q	PARTICIPANT	\N	PRESENT	0
121391	119934	14267Y	PARTICIPANT	\N	PRESENT	0
121392	119934	77002U	PARTICIPANT	\N	PRESENT	0
121393	119934	04097T	PARTICIPANT	\N	PRESENT	0
121394	119934	14031R	PARTICIPANT	\N	PRESENT	0
121395	119934	04055H	PARTICIPANT	\N	PRESENT	0
121397	119934	92031P	PARTICIPANT	\N	PRESENT	0
121398	119934	14223L	PARTICIPANT	\N	PRESENT	0
121399	119934	08015R	PARTICIPANT	\N	PRESENT	0
121400	119934	11088W	PARTICIPANT	\N	PRESENT	0
121401	119934	14111D	PARTICIPANT	\N	PRESENT	0
121402	119934	95063L	PARTICIPANT	\N	PRESENT	0
121403	119934	98023Q	PARTICIPANT	\N	PRESENT	0
121404	119934	04034C	PARTICIPANT	\N	PRESENT	0
121405	119934	01019Q	PARTICIPANT	\N	PRESENT	0
121406	119934	11033F	PARTICIPANT	\N	PRESENT	0
121407	119934	10015M	PARTICIPANT	\N	PRESENT	0
121408	119934	01011G	PARTICIPANT	\N	PRESENT	0
121409	119934	04059M	PARTICIPANT	\N	PRESENT	0
121410	119934	01037S	PARTICIPANT	\N	PRESENT	0
121411	119934	04056J	PARTICIPANT	\N	PRESENT	0
121412	119934	08014Q	PARTICIPANT	\N	PRESENT	0
121413	119934	11027H	PARTICIPANT	\N	PRESENT	0
121414	119934	07029T	PARTICIPANT	\N	PRESENT	0
121415	119934	14265W	PARTICIPANT	\N	PRESENT	0
121416	119934	04067M	PARTICIPANT	\N	PRESENT	0
121417	119934	11083R	PARTICIPANT	\N	PRESENT	0
121418	119934	13002U	PARTICIPANT	\N	PRESENT	0
121419	119934	05012A	PARTICIPANT	\N	PRESENT	0
121420	119934	98050T	PARTICIPANT	\N	PRESENT	0
121421	119934	14199E	PARTICIPANT	\N	PRESENT	0
121422	119934	08022Q	PARTICIPANT	\N	PRESENT	0
121423	119934	04057K	PARTICIPANT	\N	PRESENT	0
121424	119934	11074Q	PARTICIPANT	\N	PRESENT	0
121425	119934	08058D	PARTICIPANT	\N	PRESENT	0
121426	119934	11090Q	PARTICIPANT	\N	PRESENT	0
121427	119934	04081K	PARTICIPANT	\N	PRESENT	0
121428	119934	04086Q	PARTICIPANT	\N	PRESENT	0
121429	119934	11015D	PARTICIPANT	\N	PRESENT	0
121430	119934	04033B	PARTICIPANT	\N	PRESENT	0
121431	119934	14042U	PARTICIPANT	\N	PRESENT	0
121432	119934	11100Y	PARTICIPANT	\N	PRESENT	0
121433	119934	07024N	PARTICIPANT	\N	PRESENT	0
121434	119934	11076S	PARTICIPANT	\N	PRESENT	0
121435	119934	07032N	PARTICIPANT	\N	PRESENT	0
121436	119934	11110B	PARTICIPANT	\N	PRESENT	0
121437	119934	01031L	PARTICIPANT	\N	PRESENT	0
121438	119934	01013J	PARTICIPANT	\N	PRESENT	0
121440	119934	12041X	PARTICIPANT	\N	PRESENT	0
121441	119934	14253S	PARTICIPANT	\N	PRESENT	0
121442	119934	96004D	PARTICIPANT	\N	PRESENT	0
121443	119934	01028R	PARTICIPANT	\N	PRESENT	0
121444	119934	01016M	PARTICIPANT	\N	PRESENT	0
121445	119934	14037X	PARTICIPANT	\N	PRESENT	0
121446	119934	08055A	PARTICIPANT	\N	PRESENT	0
121447	119934	14093U	PARTICIPANT	\N	PRESENT	0
121448	119934	14069U	PARTICIPANT	\N	PRESENT	0
121449	119934	04045F	PARTICIPANT	\N	PRESENT	0
121450	119934	14187A	PARTICIPANT	\N	PRESENT	0
121451	119934	98018T	PARTICIPANT	\N	PRESENT	0
121452	119934	14205J	PARTICIPANT	\N	PRESENT	0
121453	119934	11043H	PARTICIPANT	\N	PRESENT	0
121454	119934	08056B	PARTICIPANT	\N	PRESENT	0
121455	119934	07004J	PARTICIPANT	\N	PRESENT	0
121456	119934	01057W	PARTICIPANT	\N	PRESENT	0
121457	119934	08011M	PARTICIPANT	\N	PRESENT	0
121458	119934	01058X	PARTICIPANT	\N	PRESENT	0
121459	119934	11048N	PARTICIPANT	\N	PRESENT	0
121460	119934	11091R	PARTICIPANT	\N	PRESENT	0
121461	119934	14249W	PARTICIPANT	\N	PRESENT	0
121462	119934	14213J	PARTICIPANT	\N	PRESENT	0
121463	119934	92045V	PARTICIPANT	\N	PRESENT	0
121464	119934	86034E	PARTICIPANT	\N	PRESENT	0
121465	119934	04054G	PARTICIPANT	\N	PRESENT	0
121466	119934	04085P	PARTICIPANT	\N	PRESENT	0
121467	119934	11031D	PARTICIPANT	\N	PRESENT	0
121468	119934	99004R	PARTICIPANT	\N	PRESENT	0
121469	119934	01015L	PARTICIPANT	\N	PRESENT	0
121470	119934	14263U	PARTICIPANT	\N	PRESENT	0
121471	119934	14013P	PARTICIPANT	\N	PRESENT	0
121472	119934	11056N	PARTICIPANT	\N	PRESENT	0
121473	119934	04050C	PARTICIPANT	\N	PRESENT	0
121474	119934	11098Y	PARTICIPANT	\N	PRESENT	0
121475	119934	11040E	PARTICIPANT	\N	PRESENT	0
121476	119934	11029K	PARTICIPANT	\N	PRESENT	0
121477	119934	14033T	PARTICIPANT	\N	PRESENT	0
121478	119934	08051V	PARTICIPANT	\N	PRESENT	0
121479	119934	11012A	PARTICIPANT	\N	PRESENT	0
121480	119934	04078Q	PARTICIPANT	\N	PRESENT	0
121481	119934	14241N	PARTICIPANT	\N	PRESENT	0
121482	119934	14261S	PARTICIPANT	\N	PRESENT	0
121483	119934	14201E	PARTICIPANT	\N	PRESENT	0
121484	119934	04038G	PARTICIPANT	\N	PRESENT	0
121485	119934	11096W	PARTICIPANT	\N	PRESENT	0
121486	119934	98022P	PARTICIPANT	\N	PRESENT	0
121487	119934	08016S	PARTICIPANT	\N	PRESENT	0
121488	119934	14273W	PARTICIPANT	\N	PRESENT	0
121489	119934	11039M	PARTICIPANT	\N	PRESENT	0
121490	119934	98046X	PARTICIPANT	\N	PRESENT	0
121491	119934	08052W	PARTICIPANT	\N	PRESENT	0
121492	119934	14251Q	PARTICIPANT	\N	PRESENT	0
121493	119934	14271U	PARTICIPANT	\N	PRESENT	0
121494	119934	80013X	PARTICIPANT	\N	PRESENT	0
121495	119934	01022K	PARTICIPANT	\N	PRESENT	0
121496	119934	14065Q	PARTICIPANT	\N	PRESENT	0
121497	119934	05008E	PARTICIPANT	\N	PRESENT	0
121498	119934	08043V	PARTICIPANT	\N	PRESENT	0
121499	119934	11036J	PARTICIPANT	\N	PRESENT	0
121500	119934	08068F	PARTICIPANT	\N	PRESENT	0
121501	119934	08012N	PARTICIPANT	\N	PRESENT	0
121502	119934	11046L	PARTICIPANT	\N	PRESENT	0
121503	119934	14038Y	PARTICIPANT	\N	PRESENT	0
121504	119934	08017T	PARTICIPANT	\N	PRESENT	0
121505	119934	95037J	PARTICIPANT	\N	PRESENT	0
121506	119934	08069G	PARTICIPANT	\N	PRESENT	0
121507	119934	14014Q	PARTICIPANT	\N	PRESENT	0
121508	119934	11054L	PARTICIPANT	\N	PRESENT	0
121509	119934	11014C	PARTICIPANT	\N	PRESENT	0
121510	119934	14257W	PARTICIPANT	\N	PRESENT	0
121511	119934	11061K	PARTICIPANT	\N	PRESENT	0
121512	119934	14097Y	PARTICIPANT	\N	PRESENT	0
121513	119934	14119M	PARTICIPANT	\N	PRESENT	0
121514	119934	14063N	PARTICIPANT	\N	PRESENT	0
121515	119934	14121F	PARTICIPANT	\N	PRESENT	0
121516	119934	14229S	PARTICIPANT	\N	PRESENT	0
121517	119934	11026G	PARTICIPANT	\N	PRESENT	0
121518	119934	11104D	PARTICIPANT	\N	PRESENT	0
121519	119934	14071N	PARTICIPANT	\N	PRESENT	0
121520	119934	08038Y	PARTICIPANT	\N	PRESENT	0
121521	119934	11032E	PARTICIPANT	\N	PRESENT	0
121522	119934	11066Q	PARTICIPANT	\N	PRESENT	0
121523	119934	14081Q	PARTICIPANT	\N	PRESENT	0
121524	119934	08019V	PARTICIPANT	\N	PRESENT	0
96186	94736	14237S	PARTICIPANT	\N	PRESENT	0
96187	94736	01027Q	PARTICIPANT	\N	PRESENT	0
96188	94736	92031P	PARTICIPANT	\N	PRESENT	0
96189	94736	14083S	PARTICIPANT	\N	PRESENT	0
96190	94736	14073Q	PARTICIPANT	\N	PRESENT	0
96191	94736	01008M	PARTICIPANT	\N	PRESENT	0
96192	94736	92045V	PARTICIPANT	\N	PRESENT	0
96193	94736	14197C	PARTICIPANT	\N	PRESENT	0
96212	94736	14030Q	PARTICIPANT	\N	PRESENT	0
96213	94736	14133K	PARTICIPANT	\N	PRESENT	0
96214	94736	14119M	PARTICIPANT	\N	PRESENT	0
96215	94736	11097X	PARTICIPANT	\N	PRESENT	0
96216	94736	10015M	PARTICIPANT	\N	PRESENT	0
96217	94736	14217N	PARTICIPANT	\N	PRESENT	0
96218	94736	11043H	PARTICIPANT	\N	PRESENT	0
96219	94736	14034U	PARTICIPANT	\N	PRESENT	0
96220	94736	14327T	PARTICIPANT	\N	PRESENT	0
96221	94736	14249W	PARTICIPANT	\N	PRESENT	0
96222	94736	14265W	PARTICIPANT	\N	PRESENT	0
96223	94736	14111D	PARTICIPANT	\N	PRESENT	0
96224	94736	01037S	PARTICIPANT	\N	PRESENT	0
96225	94736	01028R	PARTICIPANT	\N	PRESENT	0
96226	94736	14169X	PARTICIPANT	\N	PRESENT	0
96227	94736	14059S	PARTICIPANT	\N	PRESENT	0
96228	94736	11036J	PARTICIPANT	\N	PRESENT	0
96229	94736	14159V	PARTICIPANT	\N	PRESENT	0
96339	84089	89017R	PARTICIPANT	\N	PRESENT	0
96340	84089	14030Q	PARTICIPANT	\N	PRESENT	0
96341	84089	14105F	PARTICIPANT	\N	PRESENT	0
96342	84089	08068F	PARTICIPANT	\N	PRESENT	0
96343	84089	04053F	PARTICIPANT	\N	PRESENT	0
96344	84089	14207L	PARTICIPANT	\N	PRESENT	0
96345	84089	14083S	PARTICIPANT	\N	PRESENT	0
96346	84089	14087W	PARTICIPANT	\N	PRESENT	0
96347	84089	95041E	PARTICIPANT	\N	PRESENT	0
96348	84089	14061L	PARTICIPANT	\N	PRESENT	0
96350	84089	04049K	PARTICIPANT	\N	PRESENT	0
96351	84089	14265W	PARTICIPANT	\N	PRESENT	0
96352	84089	14253S	PARTICIPANT	\N	PRESENT	0
96353	84089	14195A	PARTICIPANT	\N	PRESENT	0
96355	84089	14261S	PARTICIPANT	\N	EXCUSE	0
96356	84089	14065Q	PARTICIPANT	\N	EXCUSE	0
96357	84089	14013P	PARTICIPANT	\N	EXCUSE	0
96358	84089	14255U	PARTICIPANT	\N	EXCUSE	0
96359	84089	14079W	PARTICIPANT	\N	EXCUSE	0
96360	84089	04055H	PARTICIPANT	\N	EXCUSE	0
96361	84089	11088W	PARTICIPANT	\N	EXCUSE	0
96362	84089	14041T	PARTICIPANT	\N	EXCUSE	0
96363	84089	04071H	PARTICIPANT	\N	EXCUSE	0
96364	84089	14034U	PARTICIPANT	\N	EXCUSE	0
96365	84089	14039A	PARTICIPANT	\N	EXCUSE	0
96366	84089	01043Q	PARTICIPANT	\N	EXCUSE	0
96367	84089	11090Q	PARTICIPANT	\N	EXCUSE	0
96368	84089	10015M	PARTICIPANT	\N	EXCUSE	0
96369	84089	14157T	PARTICIPANT	\N	EXCUSE	0
96370	84089	95067Q	PARTICIPANT	\N	EXCUSE	0
96371	84089	11063M	PARTICIPANT	\N	EXCUSE	0
97392	97214	11082Q	PARTICIPANT	\N	EXCUSE	0
97393	97214	01058X	PARTICIPANT	\N	PRESENT	0
97396	97214	14263U	PARTICIPANT	\N	EXCUSE	0
97397	97214	01046T	PARTICIPANT	\N	EXCUSE	0
97398	97214	11036J	PARTICIPANT	\N	EXCUSE	0
97399	97214	11068S	PARTICIPANT	\N	EXCUSE	0
97400	97214	14209N	PARTICIPANT	\N	EXCUSE	0
97401	97214	80013X	PARTICIPANT	\N	EXCUSE	0
97402	97214	11061K	PARTICIPANT	\N	EXCUSE	0
97403	97214	11089X	PARTICIPANT	\N	EXCUSE	0
97404	97214	08069G	PARTICIPANT	\N	EXCUSE	0
97405	97214	04061F	PARTICIPANT	\N	EXCUSE	0
97406	97214	08039A	PARTICIPANT	\N	EXCUSE	0
97407	97214	01048V	PARTICIPANT	\N	EXCUSE	0
97408	97214	14221J	PARTICIPANT	\N	EXCUSE	0
97409	97214	13002U	PARTICIPANT	\N	EXCUSE	0
99480	99479	08017T	PARTICIPANT	\N	PRESENT	0
99481	99479	01041N	PARTICIPANT	\N	PRESENT	0
99482	99479	14235Q	PARTICIPANT	\N	PRESENT	0
99533	99532	14239U	PARTICIPANT	\N	PRESENT	0
102279	101190	14235Q	PARTICIPANT	\N	PRESENT	0
102280	101190	01048V	PARTICIPANT	\N	PRESENT	0
99536	99532	04053F	PARTICIPANT	\N	PRESENT	0
99537	99532	14255U	PARTICIPANT	\N	PRESENT	0
99538	99532	04066L	PARTICIPANT	\N	PRESENT	0
102281	101190	04067M	PARTICIPANT	\N	PRESENT	0
99540	99532	14053L	PARTICIPANT	\N	PRESENT	0
99541	99532	11103C	PARTICIPANT	\N	PRESENT	0
99542	99532	11044J	PARTICIPANT	\N	PRESENT	0
99543	99532	14195A	PARTICIPANT	\N	PRESENT	0
99544	99532	14267Y	PARTICIPANT	\N	PRESENT	0
99545	99532	11023D	PARTICIPANT	\N	PRESENT	0
99546	99532	11031D	PARTICIPANT	\N	PRESENT	0
99547	99532	08052W	PARTICIPANT	\N	PRESENT	0
99548	99532	01059Y	PARTICIPANT	\N	PRESENT	0
99549	99532	04081K	PARTICIPANT	\N	PRESENT	0
99550	99532	98024R	PARTICIPANT	\N	PRESENT	0
99551	99532	10006L	PARTICIPANT	\N	PRESENT	0
99552	99532	04067M	PARTICIPANT	\N	PRESENT	0
99553	99532	14217N	PARTICIPANT	\N	PRESENT	0
99554	99532	14042U	PARTICIPANT	\N	PRESENT	0
99555	99532	14151M	PARTICIPANT	\N	PRESENT	0
99556	99532	12042Y	PARTICIPANT	\N	PRESENT	0
99557	99532	14281W	PARTICIPANT	\N	PRESENT	0
99558	99532	14087W	PARTICIPANT	\N	PRESENT	0
99559	99532	01003G	PARTICIPANT	\N	PRESENT	0
99560	99532	14034U	PARTICIPANT	\N	PRESENT	0
99561	99532	14231L	PARTICIPANT	\N	PRESENT	0
99562	99532	11061K	PARTICIPANT	\N	PRESENT	0
102282	101190	11083R	PARTICIPANT	\N	PRESENT	0
99564	99532	08041T	PARTICIPANT	\N	EXCUSE	0
99565	99532	01011G	PARTICIPANT	\N	PRESENT	0
99566	99532	14026U	PARTICIPANT	\N	PRESENT	0
99567	99532	14213J	PARTICIPANT	\N	PRESENT	0
99568	99532	14121F	PARTICIPANT	\N	PRESENT	0
99569	99532	11112D	PARTICIPANT	\N	PRESENT	0
99570	99532	14037X	PARTICIPANT	\N	PRESENT	0
99571	99532	14018U	PARTICIPANT	\N	PRESENT	0
99572	99532	11067R	PARTICIPANT	\N	PRESENT	0
99573	99532	14223L	PARTICIPANT	\N	PRESENT	0
99574	99532	04092N	PRESIDENT	0	PRESENT	0
99575	99532	14265W	PARTICIPANT	\N	PRESENT	0
99576	99532	14119M	PARTICIPANT	\N	PRESENT	0
99577	99532	14071N	PARTICIPANT	\N	PRESENT	0
102283	101190	01044R	PARTICIPANT	\N	PRESENT	0
99579	99532	04043D	PARTICIPANT	\N	EXCUSE	0
99580	99532	14271U	PARTICIPANT	\N	PRESENT	0
99581	99532	14017T	PARTICIPANT	\N	PRESENT	0
99582	99532	11093T	PARTICIPANT	\N	PRESENT	0
99583	99532	11097X	PARTICIPANT	\N	PRESENT	0
99584	99532	04045F	PARTICIPANT	\N	PRESENT	0
99585	99532	14227Q	PARTICIPANT	\N	PRESENT	0
99586	99532	01034P	PARTICIPANT	\N	PRESENT	0
99587	99532	11025F	PARTICIPANT	\N	PRESENT	0
99588	99532	11063M	PARTICIPANT	\N	PRESENT	0
99589	99532	14269B	PARTICIPANT	\N	PRESENT	0
102284	101190	11029K	PARTICIPANT	\N	PRESENT	0
102285	101190	14169X	PARTICIPANT	\N	PRESENT	0
102286	101190	08051V	PARTICIPANT	\N	PRESENT	0
102287	101190	01046T	PARTICIPANT	\N	PRESENT	0
102288	101190	88008L	PARTICIPANT	\N	PRESENT	0
102289	101190	08049C	PARTICIPANT	\N	PRESENT	0
102290	101190	01057W	PARTICIPANT	\N	PRESENT	0
102291	101190	08031R	PARTICIPANT	\N	PRESENT	0
102292	101190	14111D	PARTICIPANT	\N	PRESENT	0
102293	101190	14201E	PARTICIPANT	\N	PRESENT	0
102294	101190	11100Y	PARTICIPANT	\N	PRESENT	0
102295	101190	11080N	PARTICIPANT	\N	PRESENT	0
102296	101190	08016S	PARTICIPANT	\N	PRESENT	0
102297	101190	01016M	PARTICIPANT	\N	PRESENT	0
102298	101190	14123H	PARTICIPANT	\N	PRESENT	0
102299	101190	04056J	PARTICIPANT	\N	PRESENT	0
102300	101190	92015P	PARTICIPANT	\N	PRESENT	0
102301	101190	11010L	PARTICIPANT	\N	PRESENT	0
102302	101190	98046X	PARTICIPANT	\N	PRESENT	0
102303	101190	11011M	PARTICIPANT	\N	PRESENT	0
102304	101190	92045V	PARTICIPANT	\N	PRESENT	0
102305	101190	14151M	PARTICIPANT	\N	PRESENT	0
102306	101190	14051J	PARTICIPANT	\N	PRESENT	0
102307	101190	08055A	PARTICIPANT	\N	PRESENT	0
102308	101190	14026U	PARTICIPANT	\N	PRESENT	0
102309	101190	08017T	PARTICIPANT	\N	PRESENT	0
102310	101190	04066L	PARTICIPANT	\N	PRESENT	0
102311	101190	11084S	PARTICIPANT	\N	PRESENT	0
102312	101190	14087W	PARTICIPANT	\N	PRESENT	0
102313	101190	01011G	PARTICIPANT	\N	PRESENT	0
107519	107476	08051V	PARTICIPANT	\N	PRESENT	0
107516	107476	11026G	PARTICIPANT	\N	PRESENT	0
107517	107476	14111D	PARTICIPANT	\N	PRESENT	0
107518	107476	14147R	PARTICIPANT	\N	PRESENT	0
107520	107476	11072N	PARTICIPANT	\N	PRESENT	0
107521	107476	07034Q	PARTICIPANT	\N	PRESENT	0
107522	107476	01028R	PARTICIPANT	\N	PRESENT	0
107523	107476	04056J	PARTICIPANT	\N	PRESENT	0
107525	107524	95067Q	PARTICIPANT	\N	PRESENT	0
107526	107524	04036E	PARTICIPANT	\N	PRESENT	0
107527	107476	11088W	PARTICIPANT	\N	PRESENT	0
107528	107476	95030B	PARTICIPANT	\N	PRESENT	0
107529	107476	11083R	PARTICIPANT	\N	PRESENT	0
107530	107476	14205J	PARTICIPANT	\N	PRESENT	0
107531	107476	11100Y	PARTICIPANT	\N	PRESENT	0
107532	107476	08019V	PARTICIPANT	\N	PRESENT	0
107533	107476	11040E	PARTICIPANT	\N	PRESENT	0
107537	107524	98029W	PARTICIPANT	\N	PRESENT	0
107535	107476	14197C	PARTICIPANT	\N	PRESENT	0
107536	107476	01031L	PARTICIPANT	\N	PRESENT	0
107538	107476	11090Q	PARTICIPANT	\N	PRESENT	0
107539	107476	04086Q	PARTICIPANT	\N	PRESENT	0
107540	107476	04071H	PARTICIPANT	\N	PRESENT	0
107541	107476	14207L	PARTICIPANT	\N	PRESENT	0
107542	107476	98046X	PARTICIPANT	\N	PRESENT	0
107543	107476	98050T	PARTICIPANT	\N	PRESENT	0
107544	107476	08011M	PARTICIPANT	\N	PRESENT	0
107545	107476	07029T	PARTICIPANT	\N	PRESENT	0
107546	107476	14173T	PARTICIPANT	\N	PRESENT	0
107547	107476	11111C	PARTICIPANT	\N	PRESENT	0
107548	107476	04049K	PARTICIPANT	\N	PRESENT	0
107549	107476	01058X	PARTICIPANT	\N	PRESENT	0
107550	107476	11042G	PARTICIPANT	\N	PRESENT	0
107551	107476	11110B	PARTICIPANT	\N	PRESENT	0
107552	107476	08014Q	PARTICIPANT	\N	PRESENT	0
107553	107476	01048V	PARTICIPANT	\N	PRESENT	0
107554	107476	14225N	PARTICIPANT	\N	PRESENT	0
107555	107476	08061X	PARTICIPANT	\N	PRESENT	0
107556	107476	08038Y	PARTICIPANT	\N	PRESENT	0
107557	107476	11066Q	PARTICIPANT	\N	PRESENT	0
107558	107476	14187A	PARTICIPANT	\N	PRESENT	0
107559	107476	14033T	PARTICIPANT	\N	PRESENT	0
107560	107476	11057P	PARTICIPANT	\N	PRESENT	0
107561	107476	89017R	PARTICIPANT	\N	PRESENT	0
107562	107476	80013X	PARTICIPANT	\N	PRESENT	0
107563	107476	11048N	PARTICIPANT	\N	PRESENT	0
107564	107476	11074Q	PARTICIPANT	\N	PRESENT	0
107565	107476	14159V	PARTICIPANT	\N	PRESENT	0
107592	107093	11113E	PARTICIPANT	\N	PRESENT	0
107567	107476	08015R	PARTICIPANT	\N	PRESENT	0
107572	107093	08024S	PARTICIPANT	\N	PRESENT	0
107593	107093	14121F	PARTICIPANT	\N	PRESENT	0
107594	107093	11112D	PARTICIPANT	\N	PRESENT	0
107595	107093	14227Q	PARTICIPANT	\N	PRESENT	0
107596	107093	01022K	PARTICIPANT	\N	PRESENT	0
107597	107093	11089X	PARTICIPANT	\N	PRESENT	0
107598	107093	08014Q	PARTICIPANT	\N	PRESENT	0
107599	107093	11067R	PARTICIPANT	\N	PRESENT	0
107600	107093	08052W	PARTICIPANT	\N	PRESENT	0
107601	107093	11061K	PARTICIPANT	\N	PRESENT	0
107602	107093	11034G	PARTICIPANT	\N	PRESENT	0
107603	107093	01059Y	PARTICIPANT	\N	PRESENT	0
107604	107093	04053F	PARTICIPANT	\N	PRESENT	0
107605	107093	04045F	PARTICIPANT	\N	PRESENT	0
107606	107093	14269B	PARTICIPANT	\N	PRESENT	0
107607	107093	12042Y	PARTICIPANT	\N	PRESENT	0
107608	107093	13002U	PARTICIPANT	\N	PRESENT	0
107609	107093	11029K	PARTICIPANT	\N	PRESENT	0
107610	107093	11031D	PARTICIPANT	\N	PRESENT	0
107611	107093	14030Q	PARTICIPANT	\N	PRESENT	0
107612	107093	11040E	PARTICIPANT	\N	PRESENT	0
107613	107093	07026Q	PARTICIPANT	\N	PRESENT	0
107614	107093	04092N	PARTICIPANT	\N	PRESENT	0
107615	107093	14037X	PARTICIPANT	\N	PRESENT	0
107616	107093	14087W	PARTICIPANT	\N	PRESENT	0
107617	107093	14221J	PARTICIPANT	\N	PRESENT	0
107618	107093	11093T	PARTICIPANT	\N	PRESENT	0
107619	107093	14327T	PARTICIPANT	\N	PRESENT	0
107620	107093	14255U	PARTICIPANT	\N	PRESENT	0
107621	107093	01047U	PARTICIPANT	\N	PRESENT	0
107622	107093	14042U	PARTICIPANT	\N	PRESENT	0
107623	107093	14103D	PARTICIPANT	\N	PRESENT	0
107624	107093	14073Q	PARTICIPANT	\N	PRESENT	0
107625	107093	11094U	PARTICIPANT	\N	PRESENT	0
107626	107093	11053K	PARTICIPANT	\N	PRESENT	0
107627	107093	01034P	PARTICIPANT	\N	PRESENT	0
107628	107093	01046T	PARTICIPANT	\N	PRESENT	0
107629	107093	08031R	PARTICIPANT	\N	PRESENT	0
107630	107093	08042U	PARTICIPANT	\N	PRESENT	0
107631	107093	86044G	PARTICIPANT	\N	PRESENT	0
107632	107093	04086Q	PARTICIPANT	\N	PRESENT	0
107633	107093	10006L	PARTICIPANT	\N	PRESENT	0
107634	107093	04043D	PARTICIPANT	\N	PRESENT	0
107635	107093	11103C	PARTICIPANT	\N	PRESENT	0
107636	107093	14026U	PARTICIPANT	\N	PRESENT	0
107637	107093	14059S	PARTICIPANT	\N	PRESENT	0
107638	107093	14151M	PARTICIPANT	\N	PRESENT	0
107639	107093	11111C	PARTICIPANT	\N	PRESENT	0
107640	107093	04097T	PARTICIPANT	\N	PRESENT	0
107641	107093	14265W	PARTICIPANT	\N	PRESENT	0
107642	107093	14147R	PARTICIPANT	\N	PRESENT	0
107643	107093	11097X	PARTICIPANT	\N	PRESENT	0
107644	107093	14223L	PARTICIPANT	\N	PRESENT	0
107645	107093	87003B	PARTICIPANT	\N	PRESENT	0
107646	107093	14253S	PARTICIPANT	\N	PRESENT	0
107647	107093	14033T	PARTICIPANT	\N	PRESENT	0
107648	107093	04088S	PARTICIPANT	\N	PRESENT	0
107649	107093	98018T	PARTICIPANT	\N	PRESENT	0
107650	107093	11065P	PARTICIPANT	\N	PRESENT	0
107651	107093	14083S	PARTICIPANT	\N	PRESENT	0
107652	107093	14187A	PARTICIPANT	\N	PRESENT	0
107653	107093	14111D	PARTICIPANT	\N	PRESENT	0
107654	107093	08069G	PARTICIPANT	\N	PRESENT	0
107655	107093	14034U	PARTICIPANT	\N	PRESENT	0
107656	107093	14225N	PARTICIPANT	\N	PRESENT	0
107657	107093	08010L	PARTICIPANT	\N	PRESENT	0
107658	107093	08041T	PARTICIPANT	\N	PRESENT	0
107659	107093	14159V	PARTICIPANT	\N	PRESENT	0
107660	107093	80013X	PARTICIPANT	\N	PRESENT	0
107661	107093	04071H	PARTICIPANT	\N	PRESENT	0
107662	107093	14271U	PARTICIPANT	\N	PRESENT	0
107663	107093	08016S	PARTICIPANT	\N	PRESENT	0
107672	107093	14053L	PARTICIPANT	\N	PRESENT	0
107673	107093	11011M	PARTICIPANT	\N	PRESENT	0
107674	107093	04066L	PARTICIPANT	\N	PRESENT	0
107675	107093	11070L	PARTICIPANT	\N	PRESENT	0
107676	107093	11063M	PARTICIPANT	\N	PRESENT	0
107677	107093	14273W	PARTICIPANT	\N	PRESENT	0
107678	107093	89017R	PARTICIPANT	\N	PRESENT	0
107679	107093	14085U	PARTICIPANT	\N	PRESENT	0
107680	107093	11081P	PARTICIPANT	\N	PRESENT	0
107681	107093	14267Y	PARTICIPANT	\N	PRESENT	0
107682	107093	04033B	PARTICIPANT	\N	PRESENT	0
107683	107093	04085P	PARTICIPANT	\N	PRESENT	0
107684	107093	14215L	PARTICIPANT	\N	PRESENT	0
107692	107093	04067M	PARTICIPANT	\N	PRESENT	0
107693	107093	14209N	PARTICIPANT	\N	PRESENT	0
107694	107093	14195A	PARTICIPANT	\N	PRESENT	0
107695	107093	14107H	PARTICIPANT	\N	PRESENT	0
107696	107093	14217N	PARTICIPANT	\N	PRESENT	0
107697	107093	14213J	PARTICIPANT	\N	PRESENT	0
107698	107093	11091R	PARTICIPANT	\N	PRESENT	0
107699	107093	14231L	PARTICIPANT	\N	PRESENT	0
107700	107093	11084S	PARTICIPANT	\N	PRESENT	0
107701	107093	11014C	PARTICIPANT	\N	PRESENT	0
107702	107093	14109K	PARTICIPANT	\N	PRESENT	0
107703	107093	08044W	PARTICIPANT	\N	PRESENT	0
107704	107093	08017T	PARTICIPANT	\N	PRESENT	0
107705	107093	01025N	PARTICIPANT	\N	PRESENT	0
107706	107093	04059M	PARTICIPANT	\N	PRESENT	0
107707	107093	11104D	PARTICIPANT	\N	PRESENT	0
107708	107093	14061L	PARTICIPANT	\N	PRESENT	0
107709	107093	14041T	PARTICIPANT	\N	PRESENT	0
107710	107093	01044R	PARTICIPANT	\N	PRESENT	0
107711	107093	14201E	PARTICIPANT	\N	PRESENT	0
107712	107093	14219Q	PARTICIPANT	\N	PRESENT	0
107713	107093	01024M	PARTICIPANT	\N	PRESENT	0
107714	107093	14051J	PARTICIPANT	\N	PRESENT	0
107715	107093	14281W	PARTICIPANT	\N	PRESENT	0
107716	107093	11054L	PARTICIPANT	\N	PRESENT	0
107717	107093	14105F	PARTICIPANT	\N	PRESENT	0
107718	107093	95030B	PARTICIPANT	\N	PRESENT	0
107719	107093	99004R	PARTICIPANT	\N	PRESENT	0
107720	107093	08034U	PARTICIPANT	\N	PRESENT	0
107721	107093	14261S	PARTICIPANT	\N	PRESENT	0
107722	107093	95035G	PARTICIPANT	\N	PRESENT	0
107723	107093	14205J	PARTICIPANT	\N	PRESENT	0
107724	107093	14119M	PARTICIPANT	\N	PRESENT	0
95957	91448	11106F	PARTICIPANT	\N	EXCUSE	0
96074	96072	89017R	PARTICIPANT	\N	PRESENT	0
96076	96072	01031L	PRESIDENT	0	PRESENT	0
96084	96072	08014Q	PARTICIPANT	\N	PRESENT	0
96081	96072	11068S	PARTICIPANT	\N	PRESENT	0
96083	96072	11040E	PARTICIPANT	\N	PRESENT	0
96085	96072	14175V	PARTICIPANT	\N	PRESENT	0
96086	96072	14083S	PARTICIPANT	\N	PRESENT	0
96087	96072	11053K	PARTICIPANT	\N	PRESENT	0
96088	96072	14085U	PARTICIPANT	\N	PRESENT	0
96089	96072	11042G	PARTICIPANT	\N	PRESENT	0
96090	96072	88008L	PARTICIPANT	\N	PRESENT	0
96091	96072	04055H	PARTICIPANT	\N	PRESENT	0
96092	96072	11070L	PARTICIPANT	\N	PRESENT	0
96093	96072	11088W	PARTICIPANT	\N	PRESENT	0
96094	96072	14327T	PARTICIPANT	\N	PRESENT	0
96095	96072	01027Q	PARTICIPANT	\N	PRESENT	0
96096	96072	04071H	PARTICIPANT	\N	PRESENT	0
96098	96072	98053W	PARTICIPANT	\N	EXCUSE	0
96099	96072	11083R	PARTICIPANT	\N	PRESENT	0
96100	96072	08016S	PARTICIPANT	\N	PRESENT	0
96101	96072	08069G	PARTICIPANT	\N	PRESENT	0
96102	96072	11048N	PARTICIPANT	\N	PRESENT	0
96103	96072	99004R	PARTICIPANT	\N	PRESENT	0
96104	96072	14159V	PARTICIPANT	\N	PRESENT	0
96105	96072	07029T	PARTICIPANT	\N	EXCUSE	0
96106	96072	08034U	PARTICIPANT	\N	PRESENT	0
96107	96072	01048V	PARTICIPANT	\N	PRESENT	0
96108	96072	98046X	PARTICIPANT	\N	PRESENT	0
96111	96072	11085T	PARTICIPANT	\N	PRESENT	0
96112	96072	08011M	PARTICIPANT	\N	PRESENT	0
96113	96072	08073C	PARTICIPANT	\N	PRESENT	0
96114	96072	08061X	PARTICIPANT	\N	PRESENT	0
96115	96072	01016M	PARTICIPANT	\N	PRESENT	0
96116	96072	11012A	PARTICIPANT	\N	PRESENT	0
96117	96072	11057P	PARTICIPANT	\N	PRESENT	0
96118	96072	04034C	PARTICIPANT	\N	PRESENT	0
96134	89162	14263U	PARTICIPANT	\N	EXCUSE	0
96135	89162	01046T	PARTICIPANT	\N	PRESENT	0
105595	105594	08025T	PARTICIPANT	\N	PRESENT	0
96137	89162	14209N	PARTICIPANT	\N	EXCUSE	0
96139	89162	08039A	PARTICIPANT	\N	EXCUSE	0
96140	89162	01048V	PARTICIPANT	\N	EXCUSE	0
105569	105535	14001X	PARTICIPANT	\N	PRESENT	0
105570	105535	14273W	PARTICIPANT	\N	PRESENT	0
105571	105535	01060R	PARTICIPANT	\N	PRESENT	0
105572	105535	14147R	PARTICIPANT	\N	PRESENT	0
105573	105535	95049N	PARTICIPANT	\N	PRESENT	0
105574	105535	08051V	PARTICIPANT	\N	PRESENT	0
105596	105594	05008E	PRESIDENT	0	PRESENT	0
105576	105535	07034Q	PARTICIPANT	\N	PRESENT	0
105577	105535	04074L	PARTICIPANT	\N	PRESENT	0
105578	105535	10015M	PARTICIPANT	\N	PRESENT	0
105579	105535	95063L	PARTICIPANT	\N	PRESENT	0
105580	105535	01019Q	PARTICIPANT	\N	PRESENT	0
105581	105535	01028R	PARTICIPANT	\N	PRESENT	0
105582	105535	98035U	PARTICIPANT	\N	PRESENT	0
105583	105535	04056J	PARTICIPANT	\N	PRESENT	0
105597	105594	14065Q	PARTICIPANT	\N	PRESENT	0
105585	105535	04044E	PARTICIPANT	\N	PRESENT	0
105586	105535	11037K	PARTICIPANT	\N	EXCUSE	0
105587	105535	92045V	PARTICIPANT	\N	PRESENT	0
105588	105535	95067Q	PARTICIPANT	\N	PRESENT	0
105598	105594	04038G	PARTICIPANT	\N	PRESENT	0
105599	105594	11056N	PARTICIPANT	\N	PRESENT	0
105600	105594	14259Y	PARTICIPANT	\N	PRESENT	0
105601	105594	01024M	PARTICIPANT	\N	PRESENT	0
105602	105594	01007L	PARTICIPANT	\N	PRESENT	0
105603	105594	11049P	PARTICIPANT	\N	PRESENT	0
105604	105594	11026G	PARTICIPANT	\N	PRESENT	0
105606	105594	14111D	PARTICIPANT	\N	PRESENT	0
105607	105594	14001X	PARTICIPANT	\N	PRESENT	0
105608	105594	14273W	PARTICIPANT	\N	PRESENT	0
105609	105594	14147R	PARTICIPANT	\N	PRESENT	0
105610	105594	95049N	PARTICIPANT	\N	PRESENT	0
105611	105594	08051V	PARTICIPANT	\N	PRESENT	0
105612	105594	07034Q	PARTICIPANT	\N	PRESENT	0
105613	105594	04074L	PARTICIPANT	\N	PRESENT	0
105614	105594	10015M	PARTICIPANT	\N	PRESENT	0
105615	105594	95063L	PARTICIPANT	\N	PRESENT	0
105616	105594	01019Q	PARTICIPANT	\N	PRESENT	0
105617	105594	01028R	PARTICIPANT	\N	PRESENT	0
105618	105594	98035U	PARTICIPANT	\N	PRESENT	0
105619	105594	04044E	PARTICIPANT	\N	PRESENT	0
105620	105594	92045V	PARTICIPANT	\N	PRESENT	0
105621	105594	95067Q	PARTICIPANT	\N	PRESENT	0
105625	105594	08016S	PARTICIPANT	\N	PRESENT	0
105626	105594	14207L	PARTICIPANT	\N	PRESENT	0
105627	105594	14257W	PARTICIPANT	\N	PRESENT	0
105628	105594	01016M	PARTICIPANT	\N	PRESENT	0
105629	105594	14197C	PARTICIPANT	\N	PRESENT	0
105630	105594	08038Y	PARTICIPANT	\N	PRESENT	0
105631	105594	11101A	PARTICIPANT	\N	PRESENT	0
105632	105594	11066Q	PARTICIPANT	\N	PRESENT	0
105633	105594	01043Q	PARTICIPANT	\N	PRESENT	0
105634	105594	04049K	PARTICIPANT	\N	PRESENT	0
105635	105594	01027Q	PARTICIPANT	\N	PRESENT	0
105636	105594	08011M	PARTICIPANT	\N	PRESENT	0
105652	105594	01061S	PARTICIPANT	\N	PRESENT	0
105660	105594	08015R	PARTICIPANT	\N	PRESENT	0
105661	105594	04088S	PARTICIPANT	\N	PRESENT	0
105662	105594	01008M	PARTICIPANT	\N	PRESENT	0
105663	105594	11088W	PARTICIPANT	\N	PRESENT	0
105664	105594	14175V	PARTICIPANT	\N	PRESENT	0
105665	105594	11094U	PARTICIPANT	\N	PRESENT	0
105666	105594	04089T	PARTICIPANT	\N	PRESENT	0
105667	105594	08022Q	PARTICIPANT	\N	PRESENT	0
105668	105594	14033T	PARTICIPANT	\N	PRESENT	0
105669	105594	14205J	PARTICIPANT	\N	PRESENT	0
105670	105594	04071H	PARTICIPANT	\N	PRESENT	0
105671	105594	11100Y	PARTICIPANT	\N	PRESENT	0
105672	105594	08069G	PARTICIPANT	\N	PRESENT	0
105673	105594	08010L	PARTICIPANT	\N	PRESENT	0
105674	105594	01048V	PARTICIPANT	\N	PRESENT	0
105675	105594	08034U	PARTICIPANT	\N	PRESENT	0
105676	105594	90003B	PARTICIPANT	\N	PRESENT	0
105677	105594	07029T	PARTICIPANT	\N	PRESENT	0
105692	105594	14041T	PARTICIPANT	\N	EXCUSE	0
105693	105594	11037K	PARTICIPANT	\N	EXCUSE	0
108835	99612	11106F	PARTICIPANT	\N	EXCUSE	0
105754	105752	01031L	PRESIDENT	0	PRESENT	0
108836	99612	04094Q	PARTICIPANT	\N	EXCUSE	0
105756	105752	01013J	PARTICIPANT	\N	PRESENT	0
105757	105752	11068S	PARTICIPANT	\N	EXCUSE	0
105758	105752	11040E	PARTICIPANT	\N	EXCUSE	0
105759	105752	08014Q	PARTICIPANT	\N	PRESENT	0
108838	99612	11025F	PARTICIPANT	\N	EXCUSE	0
105761	105752	14175V	PARTICIPANT	\N	PRESENT	0
105762	105752	14083S	PARTICIPANT	\N	PRESENT	0
105763	105752	11053K	PARTICIPANT	\N	PRESENT	0
105764	105752	14085U	PARTICIPANT	\N	PRESENT	0
105765	105752	11042G	PARTICIPANT	\N	PRESENT	0
105766	105752	88008L	PARTICIPANT	\N	PRESENT	0
105767	105752	04086Q	PARTICIPANT	\N	PRESENT	0
108841	108840	11061K	PARTICIPANT	\N	PRESENT	0
105769	105752	11070L	PARTICIPANT	\N	PRESENT	0
105770	105752	11088W	PRESIDENT	1	PRESENT	0
105771	105752	14327T	PARTICIPANT	\N	PRESENT	0
105772	105752	08022Q	PARTICIPANT	\N	PRESENT	0
105773	105752	01027Q	PARTICIPANT	\N	PRESENT	0
105774	105752	04071H	PARTICIPANT	\N	PRESENT	0
108842	108840	01034P	PARTICIPANT	\N	PRESENT	0
105776	105752	98053W	PARTICIPANT	\N	EXCUSE	0
105777	105752	11083R	PARTICIPANT	\N	PRESENT	0
108843	108840	14121F	PARTICIPANT	\N	PRESENT	0
105779	105752	01057W	PARTICIPANT	\N	PRESENT	0
108844	108840	11100Y	PARTICIPANT	\N	PRESENT	0
108845	108840	07024N	PARTICIPANT	\N	PRESENT	0
108846	108840	98005N	PARTICIPANT	\N	PRESENT	0
105783	105752	99004R	PARTICIPANT	\N	PRESENT	0
105784	105752	04061F	PARTICIPANT	\N	PRESENT	0
105785	105752	14159V	PARTICIPANT	\N	PRESENT	0
105786	105752	07029T	PARTICIPANT	\N	PRESENT	0
109797	109796	14033T	PARTICIPANT	\N	PRESENT	0
109799	109798	14033T	PARTICIPANT	\N	PRESENT	0
105789	105752	08034U	PARTICIPANT	\N	PRESENT	0
109801	109800	14033T	PARTICIPANT	\N	PRESENT	0
105791	105752	98046X	PARTICIPANT	\N	PRESENT	0
113313	113312	14239U	PARTICIPANT	\N	PRESENT	0
105793	105752	08011M	PARTICIPANT	\N	PRESENT	0
105794	105752	08073C	PARTICIPANT	\N	PRESENT	0
105795	105752	08061X	PARTICIPANT	\N	PRESENT	0
105796	105752	01016M	PARTICIPANT	\N	PRESENT	0
105797	105752	14225N	PARTICIPANT	\N	PRESENT	0
113314	113312	14065Q	PARTICIPANT	\N	PRESENT	0
105799	105752	11057P	PARTICIPANT	\N	PRESENT	0
105800	105752	14173T	PARTICIPANT	\N	PRESENT	0
105801	105752	04034C	PARTICIPANT	\N	PRESENT	0
121525	119934	04079R	PARTICIPANT	\N	PRESENT	0
121754	120874	11036J	PARTICIPANT	\N	EXCUSE	0
121756	121755	11093T	PARTICIPANT	\N	PRESENT	0
121758	121757	11093T	PARTICIPANT	\N	PRESENT	0
121760	121759	11093T	PARTICIPANT	\N	PRESENT	0
121762	121761	11093T	PARTICIPANT	\N	PRESENT	0
121764	121763	11093T	PARTICIPANT	\N	PRESENT	0
121766	121765	11093T	PARTICIPANT	\N	PRESENT	0
121768	121767	11093T	PARTICIPANT	\N	PRESENT	0
121770	121769	11097X	PARTICIPANT	\N	PRESENT	0
121772	121771	11097X	PARTICIPANT	\N	PRESENT	0
121774	121773	11097X	PARTICIPANT	\N	PRESENT	0
122694	122693	95030B	PARTICIPANT	\N	PRESENT	0
122695	122693	14001X	PARTICIPANT	\N	PRESENT	0
123252	123251	01056V	PARTICIPANT	\N	PRESENT	0
123253	123251	11106F	PARTICIPANT	\N	PRESENT	0
123255	123254	92031P	PARTICIPANT	\N	PRESENT	0
123256	123254	11015D	PARTICIPANT	\N	PRESENT	0
123927	123436	14051J	PARTICIPANT	\N	PRESENT	0
123650	123437	14187A	PARTICIPANT	\N	PRESENT	0
123651	123437	14231L	PARTICIPANT	\N	PRESENT	0
123652	120697	11023D	PARTICIPANT	\N	EXCUSE	0
123653	123437	11055M	PARTICIPANT	\N	PRESENT	0
123654	123437	14159V	PARTICIPANT	\N	PRESENT	0
123655	123437	14081Q	PARTICIPANT	\N	PRESENT	0
123656	123437	11046L	PARTICIPANT	\N	PRESENT	0
123657	123437	04038G	PARTICIPANT	\N	PRESENT	0
123658	123437	08031R	PARTICIPANT	\N	PRESENT	0
123659	123437	14219Q	PARTICIPANT	\N	PRESENT	0
123660	123437	14235Q	PARTICIPANT	\N	PRESENT	0
123661	123437	11034G	PARTICIPANT	\N	PRESENT	0
123662	123437	04059M	PARTICIPANT	\N	PRESENT	0
123663	123437	14269B	PARTICIPANT	\N	PRESENT	0
123664	123437	11104D	PARTICIPANT	\N	PRESENT	0
123665	123437	04089T	PARTICIPANT	\N	PRESENT	0
123666	123437	04086Q	PARTICIPANT	\N	PRESENT	0
123667	123437	14041T	PARTICIPANT	\N	PRESENT	0
123668	123437	08019V	PARTICIPANT	\N	PRESENT	0
123669	123437	11090Q	PARTICIPANT	\N	PRESENT	0
123670	123437	14073Q	PARTICIPANT	\N	PRESENT	0
123671	123437	04042C	PARTICIPANT	\N	PRESENT	0
123672	123437	04045F	PARTICIPANT	\N	PRESENT	0
123673	123437	11029K	PARTICIPANT	\N	PRESENT	0
123674	123437	08034U	PARTICIPANT	\N	PRESENT	0
123675	123437	04043D	PARTICIPANT	\N	PRESENT	0
123676	123437	14229S	PARTICIPANT	\N	PRESENT	0
123690	123437	98050T	PARTICIPANT	\N	PRESENT	0
123691	123437	99004R	PARTICIPANT	\N	PRESENT	0
123692	123437	14205J	PARTICIPANT	\N	PRESENT	0
123693	123437	01013J	PARTICIPANT	\N	PRESENT	0
123699	123437	13002U	PARTICIPANT	\N	PRESENT	0
123700	123437	04080J	PARTICIPANT	\N	PRESENT	0
123701	123437	04033B	PARTICIPANT	\N	PRESENT	0
123702	123437	01028R	PARTICIPANT	\N	PRESENT	0
123704	123437	07032N	PARTICIPANT	\N	PRESENT	0
123705	123437	04057K	PARTICIPANT	\N	PRESENT	0
123706	123437	14079W	PARTICIPANT	\N	PRESENT	0
123707	123437	14215L	PARTICIPANT	\N	PRESENT	0
123708	123437	11066Q	PARTICIPANT	\N	PRESENT	0
123709	123437	14042U	PARTICIPANT	\N	PRESENT	0
123710	123437	14195A	PARTICIPANT	\N	PRESENT	0
123714	123437	11077T	PARTICIPANT	\N	PRESENT	0
123715	123437	14169X	PARTICIPANT	\N	PRESENT	0
123716	123437	14157T	PARTICIPANT	\N	PRESENT	0
123717	123437	08016S	PARTICIPANT	\N	PRESENT	0
123718	123437	08051V	PARTICIPANT	\N	PRESENT	0
123719	123437	08014Q	PARTICIPANT	\N	PRESENT	0
123760	123437	04050C	PARTICIPANT	\N	PRESENT	0
123765	123437	95035G	PARTICIPANT	\N	PRESENT	0
123766	123437	11042G	PARTICIPANT	\N	PRESENT	0
123767	123437	11011M	PARTICIPANT	\N	PRESENT	0
123648	123437	08055A	PARTICIPANT	\N	PRESENT	0
123649	123437	11100Y	PARTICIPANT	\N	PRESENT	0
123777	123437	11080N	PARTICIPANT	\N	PRESENT	0
123775	123437	04056J	PARTICIPANT	\N	PRESENT	0
123776	123437	04081K	PARTICIPANT	\N	PRESENT	0
123778	123437	04053F	PARTICIPANT	\N	PRESENT	0
123779	123437	14065Q	PARTICIPANT	\N	PRESENT	0
123780	123437	11085T	PARTICIPANT	\N	PRESENT	0
123781	123437	11109J	PARTICIPANT	\N	PRESENT	0
123789	123437	04079R	PARTICIPANT	\N	PRESENT	0
123795	123437	98018T	PARTICIPANT	\N	PRESENT	0
123796	123437	11089X	PARTICIPANT	\N	PRESENT	0
123799	123437	92045V	PARTICIPANT	\N	PRESENT	0
123801	123437	11099A	PARTICIPANT	\N	PRESENT	0
123802	123437	04085P	PARTICIPANT	\N	PRESENT	0
123803	123438	04066L	PARTICIPANT	\N	PRESENT	0
123804	123438	04085P	PARTICIPANT	\N	PRESENT	0
123805	123438	14235Q	PARTICIPANT	\N	PRESENT	0
123806	123438	11034G	PARTICIPANT	\N	PRESENT	0
123807	123438	01013J	PARTICIPANT	\N	PRESENT	0
123808	123438	04050C	PARTICIPANT	\N	PRESENT	0
123809	123438	14187A	PARTICIPANT	\N	PRESENT	0
123810	123438	14231L	PARTICIPANT	\N	PRESENT	0
123811	123438	11100Y	PARTICIPANT	\N	PRESENT	0
123812	123438	04059M	PARTICIPANT	\N	PRESENT	0
123813	123438	14269B	PARTICIPANT	\N	PRESENT	0
123814	123438	11046L	PARTICIPANT	\N	PRESENT	0
123815	123438	11042G	PARTICIPANT	\N	PRESENT	0
123816	123438	14081Q	PARTICIPANT	\N	PRESENT	0
123817	123438	14219Q	PARTICIPANT	\N	PRESENT	0
123818	123438	08031R	PARTICIPANT	\N	PRESENT	0
123819	123438	04038G	PARTICIPANT	\N	PRESENT	0
123820	123438	04089T	PARTICIPANT	\N	PRESENT	0
123821	123438	11090Q	PARTICIPANT	\N	PRESENT	0
123822	123438	08034U	PARTICIPANT	\N	PRESENT	0
123823	123438	08019V	PARTICIPANT	\N	PRESENT	0
123824	123438	01043Q	PARTICIPANT	\N	PRESENT	0
123825	123438	11099A	PARTICIPANT	\N	PRESENT	0
123826	123438	04045F	PARTICIPANT	\N	PRESENT	0
123827	123438	04043D	PARTICIPANT	\N	PRESENT	0
123828	123438	04086Q	PARTICIPANT	\N	PRESENT	0
123832	123438	14030Q	PARTICIPANT	\N	PRESENT	0
123833	123438	11109J	PARTICIPANT	\N	PRESENT	0
123834	123438	13002U	PARTICIPANT	\N	PRESENT	0
123835	123438	14037X	PARTICIPANT	\N	PRESENT	0
123925	123436	08016S	PARTICIPANT	\N	PRESENT	0
123926	123436	08014Q	PARTICIPANT	\N	PRESENT	0
123928	123436	08051V	PARTICIPANT	\N	PRESENT	0
123929	123436	07032N	PARTICIPANT	\N	PRESENT	0
123930	123436	14065Q	PARTICIPANT	\N	PRESENT	0
123931	123436	11085T	PARTICIPANT	\N	PRESENT	0
123932	123436	01024M	PARTICIPANT	\N	PRESENT	0
123933	123436	11029K	PARTICIPANT	\N	PRESENT	0
123934	123436	04053F	PARTICIPANT	\N	PRESENT	0
123935	123436	04050C	PARTICIPANT	\N	PRESENT	0
123936	123436	14159V	PARTICIPANT	\N	PRESENT	0
123937	123436	99004R	PARTICIPANT	\N	PRESENT	0
123938	123436	04042C	PARTICIPANT	\N	PRESENT	0
123939	123436	14042U	PARTICIPANT	\N	PRESENT	0
123940	123436	14107H	PARTICIPANT	\N	PRESENT	0
123941	123436	04080J	PARTICIPANT	\N	PRESENT	0
123947	123946	04040A	PARTICIPANT	\N	PRESENT	0
123948	123946	83042R	PARTICIPANT	\N	PRESENT	0
123950	123949	04040A	PARTICIPANT	\N	PRESENT	0
123951	123949	83042R	PARTICIPANT	\N	PRESENT	0
123953	123952	14259Y	PARTICIPANT	\N	PRESENT	0
123955	123954	14259Y	PARTICIPANT	\N	PRESENT	0
123957	123956	14259Y	PARTICIPANT	\N	PRESENT	0
123959	123958	14259Y	PARTICIPANT	\N	PRESENT	0
123961	123960	14259Y	PARTICIPANT	\N	PRESENT	0
123963	123962	14259Y	PARTICIPANT	\N	PRESENT	0
123965	123964	14259Y	PARTICIPANT	\N	PRESENT	0
123967	123966	14259Y	PARTICIPANT	\N	PRESENT	0
123969	123968	14259Y	PARTICIPANT	\N	PRESENT	0
124134	124133	14237S	PARTICIPANT	\N	PRESENT	0
124136	124135	04049K	PARTICIPANT	\N	PRESENT	0
124138	124137	04049K	PARTICIPANT	\N	PRESENT	0
124254	106052	11029K	PARTICIPANT	\N	PRESENT	0
124255	106052	08068F	PARTICIPANT	\N	PRESENT	0
124256	106052	04047H	PARTICIPANT	\N	PRESENT	0
124257	106052	11103C	PARTICIPANT	\N	PRESENT	0
124258	106052	11027H	PARTICIPANT	\N	PRESENT	0
124259	106052	08052W	PARTICIPANT	\N	PRESENT	0
124260	106052	14215L	PARTICIPANT	\N	PRESENT	0
124261	106052	14087W	PARTICIPANT	\N	PRESENT	0
124262	106052	14097Y	PARTICIPANT	\N	PRESENT	0
124263	106052	14061L	PARTICIPANT	\N	PRESENT	0
124264	106052	14073Q	PARTICIPANT	\N	PRESENT	0
124265	106052	98005N	PARTICIPANT	\N	PRESENT	0
124266	106052	14037X	PARTICIPANT	\N	PRESENT	0
124267	106052	14219Q	PARTICIPANT	\N	PRESENT	0
124268	106052	14223L	PARTICIPANT	\N	PRESENT	0
124269	106052	04092N	PARTICIPANT	\N	PRESENT	0
124270	106052	14265W	PARTICIPANT	\N	PRESENT	0
124271	106052	10015M	PARTICIPANT	\N	PRESENT	0
96413	96412	14227Q	PARTICIPANT	\N	PRESENT	0
96600	96598	07004J	PARTICIPANT	\N	PRESENT	0
96601	96598	10015M	PARTICIPANT	\N	PRESENT	0
96886	96885	11088W	PARTICIPANT	\N	PRESENT	0
96889	96888	11088W	PARTICIPANT	\N	PRESENT	0
96891	96890	11088W	PARTICIPANT	\N	PRESENT	0
97287	97214	04043D	PARTICIPANT	\N	EXCUSE	0
102314	101190	07032N	PARTICIPANT	\N	PRESENT	0
102315	101190	92020L	PARTICIPANT	\N	PRESENT	0
102316	101190	08060W	PARTICIPANT	\N	PRESENT	0
102317	101190	11088W	PARTICIPANT	\N	PRESENT	0
102318	101190	04074L	PARTICIPANT	\N	PRESENT	0
102319	101190	11114F	PARTICIPANT	\N	PRESENT	0
102320	101190	11020A	PARTICIPANT	\N	PRESENT	0
102321	101190	01022K	PARTICIPANT	\N	PRESENT	0
102322	101190	11059R	PARTICIPANT	\N	PRESENT	0
102323	101190	98005N	PARTICIPANT	\N	PRESENT	0
102324	101190	11015D	PARTICIPANT	\N	PRESENT	0
102325	101190	11105E	PARTICIPANT	\N	PRESENT	0
102326	101190	08012N	PARTICIPANT	\N	PRESENT	0
102327	101190	14331P	PARTICIPANT	\N	PRESENT	0
102328	101190	11089X	PARTICIPANT	\N	PRESENT	0
102329	101190	97011G	PARTICIPANT	\N	PRESENT	0
102330	101190	11036J	PARTICIPANT	\N	PRESENT	0
102331	101190	11097X	PARTICIPANT	\N	PRESENT	0
102332	101190	11042G	PARTICIPANT	\N	PRESENT	0
102333	101190	11046L	PARTICIPANT	\N	PRESENT	0
102334	101190	11032E	PARTICIPANT	\N	PRESENT	0
102335	101190	04034C	PARTICIPANT	\N	PRESENT	0
102336	101190	11091R	PARTICIPANT	\N	PRESENT	0
102337	101190	95037J	PARTICIPANT	\N	PRESENT	0
102338	101190	08058D	PARTICIPANT	\N	PRESENT	0
102339	101190	11110B	PARTICIPANT	\N	PRESENT	0
102340	101190	83047W	PARTICIPANT	\N	PRESENT	0
102341	101190	11054L	PARTICIPANT	\N	PRESENT	0
102342	101190	14001X	PARTICIPANT	\N	PRESENT	0
102343	101190	08014Q	PARTICIPANT	\N	PRESENT	0
102344	101190	92040Q	PARTICIPANT	\N	PRESENT	0
102345	101190	14109K	PARTICIPANT	\N	PRESENT	0
102346	101190	14265W	PARTICIPANT	\N	PRESENT	0
102347	101190	14014Q	PARTICIPANT	\N	PRESENT	0
102348	101190	14093U	PARTICIPANT	\N	PRESENT	0
102349	101190	04079R	PARTICIPANT	\N	PRESENT	0
102350	101190	11014C	PARTICIPANT	\N	PRESENT	0
102351	101190	14257W	PARTICIPANT	\N	PRESENT	0
102352	101190	08069G	PARTICIPANT	\N	PRESENT	0
102353	101190	04059M	PARTICIPANT	\N	PRESENT	0
102354	101190	01031L	PARTICIPANT	\N	PRESENT	0
102355	101190	95067Q	PARTICIPANT	\N	PRESENT	0
102356	101190	08041T	PARTICIPANT	\N	PRESENT	0
102357	101190	08061X	PARTICIPANT	\N	PRESENT	0
102358	101190	92039X	PARTICIPANT	\N	PRESENT	0
102359	101190	04077P	PARTICIPANT	\N	PRESENT	0
102360	101190	01028R	PARTICIPANT	\N	PRESENT	0
102361	101190	14033T	PARTICIPANT	\N	PRESENT	0
102362	101190	14097Y	PARTICIPANT	\N	PRESENT	0
102363	101190	14135M	PARTICIPANT	\N	PRESENT	0
102364	101190	08038Y	PARTICIPANT	\N	PRESENT	0
102365	101190	14069U	PARTICIPANT	\N	PRESENT	0
102366	101190	99002P	PARTICIPANT	\N	PRESENT	0
102367	101190	04092N	PARTICIPANT	\N	PRESENT	0
102368	101190	11066Q	PARTICIPANT	\N	PRESENT	0
102369	101190	11067R	PARTICIPANT	\N	PRESENT	0
102370	101190	08042U	PARTICIPANT	\N	PRESENT	0
102371	101190	04045F	PARTICIPANT	\N	PRESENT	0
102372	101190	14269B	PARTICIPANT	\N	PRESENT	0
102373	101190	11055M	PARTICIPANT	\N	PRESENT	0
102374	101190	95035G	PARTICIPANT	\N	PRESENT	0
102375	101190	14079W	PARTICIPANT	\N	PRESENT	0
102376	101190	14207L	PARTICIPANT	\N	PRESENT	0
102377	101190	14159V	PARTICIPANT	\N	PRESENT	0
102378	101190	11107G	PARTICIPANT	\N	PRESENT	0
102379	101190	14038Y	PARTICIPANT	\N	PRESENT	0
102380	101190	12042Y	PARTICIPANT	\N	PRESENT	0
102381	101190	14329V	PARTICIPANT	\N	PRESENT	0
102382	101190	11113E	PARTICIPANT	\N	PRESENT	0
102383	101190	11023D	PARTICIPANT	\N	PRESENT	0
102384	101190	08073C	PARTICIPANT	\N	PRESENT	0
102385	101190	14039A	PARTICIPANT	\N	PRESENT	0
102386	101190	11109J	PARTICIPANT	\N	PRESENT	0
102387	101190	14030Q	PARTICIPANT	\N	PRESENT	0
102388	101190	11044J	PARTICIPANT	\N	PRESENT	0
102389	101190	07004J	PARTICIPANT	\N	PRESENT	0
102390	101190	01034P	PARTICIPANT	\N	PRESENT	0
102391	101190	11094U	PARTICIPANT	\N	PRESENT	0
102392	101190	08009T	PARTICIPANT	\N	PRESENT	0
102393	101190	04080J	PARTICIPANT	\N	PRESENT	0
102394	101190	14217N	PARTICIPANT	\N	PRESENT	0
102395	101190	11096W	PARTICIPANT	\N	PRESENT	0
102396	101190	11076S	PARTICIPANT	\N	PRESENT	0
102397	101190	04097T	PARTICIPANT	\N	PRESENT	0
102398	101190	11070L	PARTICIPANT	\N	PRESENT	0
102399	101190	11064N	PARTICIPANT	\N	PRESENT	0
102400	101190	14061L	PARTICIPANT	\N	PRESENT	0
102401	101190	07029T	PARTICIPANT	\N	PRESENT	0
102402	101190	14042U	PARTICIPANT	\N	PRESENT	0
102403	101190	98050T	PARTICIPANT	\N	PRESENT	0
102404	101190	14267Y	PARTICIPANT	\N	PRESENT	0
102405	101190	14037X	PARTICIPANT	\N	PRESENT	0
102406	101190	11093T	PARTICIPANT	\N	PRESENT	0
102407	101190	14209N	PARTICIPANT	\N	PRESENT	0
102408	101190	14179A	PARTICIPANT	\N	PRESENT	0
102409	101190	08044W	PARTICIPANT	\N	PRESENT	0
102410	101190	08018U	PARTICIPANT	\N	PRESENT	0
102411	101190	14255U	PARTICIPANT	\N	PRESENT	0
102412	101190	04061F	PARTICIPANT	\N	PRESENT	0
102413	101190	04070G	PARTICIPANT	\N	PRESENT	0
102415	101190	08056B	PARTICIPANT	\N	PRESENT	0
102416	101190	09001P	PARTICIPANT	\N	PRESENT	0
102417	101190	01007L	PARTICIPANT	\N	PRESENT	0
102419	101190	14327T	PARTICIPANT	\N	PRESENT	0
102420	101190	14175V	PARTICIPANT	\N	PRESENT	0
102421	101190	08034U	PARTICIPANT	\N	PRESENT	0
102423	101190	92044U	PARTICIPANT	\N	PRESENT	0
102424	101190	89017R	PARTICIPANT	\N	PRESENT	0
102426	101190	14055N	PARTICIPANT	\N	PRESENT	0
102427	101190	14187A	PARTICIPANT	\N	PRESENT	0
102428	101190	11090Q	PARTICIPANT	\N	PRESENT	0
102429	101190	11027H	PARTICIPANT	\N	PRESENT	0
102430	101190	14157T	PARTICIPANT	\N	PRESENT	0
102431	101190	01008M	PARTICIPANT	\N	PRESENT	0
102432	101190	14059S	PARTICIPANT	\N	PRESENT	0
102433	101190	08010L	PARTICIPANT	\N	PRESENT	0
102434	101190	14031R	PARTICIPANT	\N	PRESENT	0
102435	101190	08035V	PARTICIPANT	\N	PRESENT	0
102436	101190	14249W	PARTICIPANT	\N	PRESENT	0
102438	101190	14213J	PARTICIPANT	\N	PRESENT	0
102439	101190	10015M	PARTICIPANT	\N	PRESENT	0
102440	101190	08015R	PARTICIPANT	\N	PRESENT	0
102441	101190	05012A	PARTICIPANT	\N	PRESENT	0
102445	101190	14119M	PARTICIPANT	\N	PRESENT	0
102448	101190	04042C	PARTICIPANT	\N	PRESENT	0
102451	101190	92031P	PARTICIPANT	\N	PRESENT	0
102452	101190	95063L	PARTICIPANT	\N	PRESENT	0
102453	101190	11063M	PARTICIPANT	\N	PRESENT	0
102456	101190	11077T	PARTICIPANT	\N	PRESENT	0
102467	101190	08062Y	PARTICIPANT	\N	PRESENT	0
102464	101190	04035D	PARTICIPANT	\N	PRESENT	0
102465	101190	14259Y	PARTICIPANT	\N	PRESENT	0
102466	101190	11049P	PARTICIPANT	\N	PRESENT	0
102472	101190	11026G	PARTICIPANT	\N	PRESENT	0
102486	101190	04054G	PARTICIPANT	\N	PRESENT	0
102490	101190	11053K	PARTICIPANT	\N	PRESENT	0
102488	101190	11085T	PARTICIPANT	\N	PRESENT	0
102489	101190	11065P	PARTICIPANT	\N	PRESENT	0
102491	101190	14034U	PARTICIPANT	\N	PRESENT	0
102495	101190	11074Q	PARTICIPANT	\N	PRESENT	0
102493	101190	04055H	PARTICIPANT	\N	PRESENT	0
102494	101190	04081K	PARTICIPANT	\N	PRESENT	0
107725	107093	98023Q	PARTICIPANT	\N	PRESENT	0
107726	107093	07024N	PARTICIPANT	\N	PRESENT	0
107727	107093	11056N	PARTICIPANT	\N	PRESENT	0
107728	107093	01011G	PARTICIPANT	\N	PRESENT	0
107734	107093	14028W	PARTICIPANT	\N	PRESENT	0
107736	107093	14329V	PARTICIPANT	\N	PRESENT	0
107737	107093	14199E	PARTICIPANT	\N	PRESENT	0
107738	107093	08038Y	PARTICIPANT	\N	PRESENT	0
107752	107093	14173T	PARTICIPANT	\N	PRESENT	0
107818	107093	04089T	PARTICIPANT	\N	PRESENT	0
107819	107093	11098Y	PARTICIPANT	\N	PRESENT	0
107820	107093	14237S	PARTICIPANT	\N	PRESENT	0
107821	107093	11090Q	PARTICIPANT	\N	PRESENT	0
107822	107093	11099A	PARTICIPANT	\N	PRESENT	0
107823	107093	11076S	PARTICIPANT	\N	PRESENT	0
107824	107093	04095R	PARTICIPANT	\N	PRESENT	0
107825	107093	11035H	PARTICIPANT	\N	PRESENT	0
107826	107093	11033F	PARTICIPANT	\N	PRESENT	0
107827	107093	04080J	PARTICIPANT	\N	PRESENT	0
107828	107093	01007L	PARTICIPANT	\N	PRESENT	0
107831	107093	95059Q	PARTICIPANT	\N	PRESENT	0
107832	107829	11029K	PARTICIPANT	\N	PRESENT	0
107833	107829	01003G	PARTICIPANT	\N	PRESENT	0
107834	107829	01007L	PARTICIPANT	\N	PRESENT	0
107835	107829	04088S	PARTICIPANT	\N	PRESENT	0
107836	107093	11036J	PARTICIPANT	\N	PRESENT	0
107837	107093	01056V	PARTICIPANT	\N	PRESENT	0
107838	107093	14157T	PARTICIPANT	\N	PRESENT	0
107839	107093	09001P	PARTICIPANT	\N	PRESENT	0
107840	107093	14257W	PARTICIPANT	\N	PRESENT	0
107855	107093	14089Y	PARTICIPANT	\N	PRESENT	0
107856	107093	04081K	PARTICIPANT	\N	PRESENT	0
107857	107093	04057K	PARTICIPANT	\N	PRESENT	0
107858	107093	08068F	PARTICIPANT	\N	PRESENT	0
107860	107859	14179A	PARTICIPANT	\N	PRESENT	0
107861	107093	11066Q	PARTICIPANT	\N	PRESENT	0
107862	107859	11011M	PARTICIPANT	\N	PRESENT	0
107864	107863	14179A	PARTICIPANT	\N	PRESENT	0
107865	107863	04070G	PARTICIPANT	\N	PRESENT	0
107866	107863	04057K	PARTICIPANT	\N	PRESENT	0
107867	107863	14038Y	PARTICIPANT	\N	PRESENT	0
107868	107863	11095V	PARTICIPANT	\N	PRESENT	0
107869	107863	08039A	PARTICIPANT	\N	PRESENT	0
107870	107863	11015D	PARTICIPANT	\N	PRESENT	0
107871	107093	98046X	PARTICIPANT	\N	PRESENT	0
107872	107093	14001X	PARTICIPANT	\N	PRESENT	0
107873	107093	14014Q	PARTICIPANT	\N	PRESENT	0
107986	107094	04088S	PARTICIPANT	\N	PRESENT	0
107987	107094	14033T	PARTICIPANT	\N	PRESENT	0
107988	107094	11091R	PARTICIPANT	\N	PRESENT	0
107989	107094	04049K	PARTICIPANT	\N	PRESENT	0
107990	107094	14257W	PARTICIPANT	\N	PRESENT	0
107991	107094	11035H	PARTICIPANT	\N	PRESENT	0
107992	107094	04045F	PARTICIPANT	\N	PRESENT	0
107993	107094	08038Y	PARTICIPANT	\N	PRESENT	0
107994	107094	08016S	PARTICIPANT	\N	PRESENT	0
107995	107094	14014Q	PARTICIPANT	\N	PRESENT	0
107996	107094	14097Y	PARTICIPANT	\N	PRESENT	0
107997	107094	14107H	PARTICIPANT	\N	PRESENT	0
107998	107094	14197C	PARTICIPANT	\N	PRESENT	0
107999	107094	14001X	PARTICIPANT	\N	PRESENT	0
108000	107094	14051J	PARTICIPANT	\N	PRESENT	0
108001	107094	14028W	PARTICIPANT	\N	PRESENT	0
108002	107094	08011M	PARTICIPANT	\N	PRESENT	0
108003	107094	80013X	PARTICIPANT	\N	PRESENT	0
108004	107094	96004D	PARTICIPANT	\N	PRESENT	0
108005	107094	07024N	PARTICIPANT	\N	PRESENT	0
108006	107094	11036J	PARTICIPANT	\N	PRESENT	0
108007	107094	14085U	PARTICIPANT	\N	PRESENT	0
108008	107094	11055M	PARTICIPANT	\N	PRESENT	0
108009	107094	04067M	PARTICIPANT	\N	PRESENT	0
108010	107094	11076S	PARTICIPANT	\N	PRESENT	0
108011	107094	11112D	PARTICIPANT	\N	PRESENT	0
108012	107094	14103D	PARTICIPANT	\N	PRESENT	0
108013	107094	09001P	PARTICIPANT	\N	PRESENT	0
108014	107094	14030Q	PARTICIPANT	\N	PRESENT	0
108015	107094	14042U	PARTICIPANT	\N	PRESENT	0
108016	107094	14219Q	PARTICIPANT	\N	PRESENT	0
108017	107094	08058D	PARTICIPANT	\N	PRESENT	0
108018	107094	14073Q	PARTICIPANT	\N	PRESENT	0
108019	107094	04080J	PARTICIPANT	\N	PRESENT	0
108020	107094	14205J	PARTICIPANT	\N	PRESENT	0
108021	107094	14231L	PARTICIPANT	\N	PRESENT	0
108022	107094	14083S	PARTICIPANT	\N	PRESENT	0
108023	107094	14089Y	PARTICIPANT	\N	PRESENT	0
108024	107094	14255U	PARTICIPANT	\N	PRESENT	0
108025	107094	14237S	PARTICIPANT	\N	PRESENT	0
108026	107094	14026U	PARTICIPANT	\N	PRESENT	0
108027	107094	01057W	PARTICIPANT	\N	PRESENT	0
108028	107094	08051V	PARTICIPANT	\N	PRESENT	0
108029	107094	08031R	PARTICIPANT	\N	PRESENT	0
108030	107094	14253S	PARTICIPANT	\N	PRESENT	0
108031	107094	01048V	PARTICIPANT	\N	PRESENT	0
108032	107094	95030B	PARTICIPANT	\N	PRESENT	0
108033	107094	11042G	PARTICIPANT	\N	PRESENT	0
108034	107094	98046X	PARTICIPANT	\N	PRESENT	0
108035	107094	11089X	PARTICIPANT	\N	PRESENT	0
108036	107094	14121F	PARTICIPANT	\N	PRESENT	0
108037	107094	01022K	PARTICIPANT	\N	PRESENT	0
108038	107094	04054G	PARTICIPANT	\N	PRESENT	0
108039	107094	04050C	PARTICIPANT	\N	PRESENT	0
108040	107094	11040E	PARTICIPANT	\N	PRESENT	0
108041	107094	11056N	PARTICIPANT	\N	PRESENT	0
108042	107094	14013P	PARTICIPANT	\N	PRESENT	0
108043	107094	14133K	PARTICIPANT	\N	PRESENT	0
108044	107094	14209N	PARTICIPANT	\N	PRESENT	0
108045	107094	90003B	PARTICIPANT	\N	PRESENT	0
108053	108052	11039M	PARTICIPANT	\N	PRESENT	0
108054	108052	98042T	PARTICIPANT	\N	PRESENT	0
108055	107094	95035G	PARTICIPANT	\N	PRESENT	0
108056	107094	01024M	PARTICIPANT	\N	PRESENT	0
108057	107094	14241N	PARTICIPANT	\N	PRESENT	0
108058	107094	11026G	PARTICIPANT	\N	PRESENT	0
108059	107094	11083R	PARTICIPANT	\N	PRESENT	0
108060	107094	01031L	PARTICIPANT	\N	PRESENT	0
108072	107094	04057K	PARTICIPANT	\N	PRESENT	0
108073	107094	11064N	PARTICIPANT	\N	PRESENT	0
108074	107094	14215L	PARTICIPANT	\N	PRESENT	0
108075	107094	92018S	PARTICIPANT	\N	PRESENT	0
108076	107094	14235Q	PARTICIPANT	\N	PRESENT	0
108077	107094	11098Y	PARTICIPANT	\N	PRESENT	0
108078	107094	08034U	PARTICIPANT	\N	PRESENT	0
108112	107094	14271U	PARTICIPANT	\N	PRESENT	0
108113	107094	11074Q	PARTICIPANT	\N	PRESENT	0
108114	107094	80027E	PARTICIPANT	\N	PRESENT	0
108115	107094	14221J	PARTICIPANT	\N	PRESENT	0
108172	107095	08055A	PARTICIPANT	\N	PRESENT	0
108192	107095	04092N	PARTICIPANT	\N	PRESENT	0
108193	107095	14037X	PARTICIPANT	\N	PRESENT	0
108194	107095	14087W	PARTICIPANT	\N	PRESENT	0
108195	107095	11063M	PARTICIPANT	\N	PRESENT	0
108196	107095	01059Y	PARTICIPANT	\N	PRESENT	0
108197	107095	11031D	PARTICIPANT	\N	PRESENT	0
108198	107095	14227Q	PARTICIPANT	\N	PRESENT	0
108199	107095	80013X	PARTICIPANT	\N	PRESENT	0
108200	107095	04045F	PARTICIPANT	\N	PRESENT	0
108201	107095	14097Y	PARTICIPANT	\N	PRESENT	0
108202	107095	11061K	PARTICIPANT	\N	PRESENT	0
108203	107095	14269B	PARTICIPANT	\N	PRESENT	0
108204	107095	04053F	PARTICIPANT	\N	PRESENT	0
108205	107095	12042Y	PARTICIPANT	\N	PRESENT	0
108206	107095	14271U	PARTICIPANT	\N	PRESENT	0
108207	107095	14281W	PARTICIPANT	\N	PRESENT	0
108208	107095	08052W	PARTICIPANT	\N	PRESENT	0
108209	107095	11029K	PARTICIPANT	\N	PRESENT	0
108210	107095	11055M	PARTICIPANT	\N	PRESENT	0
108211	107095	14327T	PARTICIPANT	\N	PRESENT	0
108212	107095	11089X	PARTICIPANT	\N	PRESENT	0
108213	107095	92018S	PARTICIPANT	\N	PRESENT	0
108214	107095	11112D	PARTICIPANT	\N	PRESENT	0
108215	107095	92039X	PARTICIPANT	\N	PRESENT	0
108216	107095	11067R	PARTICIPANT	\N	PRESENT	0
108217	107095	14195A	PARTICIPANT	\N	PRESENT	0
108218	107095	07032N	PARTICIPANT	\N	PRESENT	0
108219	107095	14265W	PARTICIPANT	\N	PRESENT	0
108220	107095	11090Q	PARTICIPANT	\N	PRESENT	0
108221	107095	14331P	PARTICIPANT	\N	PRESENT	0
107984	107094	89029V	PARTICIPANT	\N	PRESENT	0
107985	107094	14157T	PARTICIPANT	\N	PRESENT	0
108222	107095	14089Y	PARTICIPANT	\N	PRESENT	0
108223	107095	01034P	PARTICIPANT	\N	PRESENT	0
108224	107095	01046T	PARTICIPANT	\N	PRESENT	0
108225	107095	14241N	PARTICIPANT	\N	PRESENT	0
108226	107095	95041E	PARTICIPANT	\N	PRESENT	0
108227	107095	14013P	PARTICIPANT	\N	PRESENT	0
108228	107095	14135M	PARTICIPANT	\N	PRESENT	0
108229	107095	96004D	PARTICIPANT	\N	PRESENT	0
108230	107095	01025N	PARTICIPANT	\N	PRESENT	0
112554	112553	01059Y	PARTICIPANT	\N	EXCUSE	0
112555	112553	04067M	PARTICIPANT	\N	EXCUSE	0
112556	112553	14217N	PARTICIPANT	\N	EXCUSE	0
112557	112553	14265W	PARTICIPANT	\N	EXCUSE	0
112558	112553	14235Q	PARTICIPANT	\N	EXCUSE	0
112559	112553	04045F	PARTICIPANT	\N	EXCUSE	0
112560	112553	92045V	PARTICIPANT	\N	EXCUSE	0
112561	112553	14195A	PARTICIPANT	\N	PRESENT	0
112562	112553	14042U	PARTICIPANT	\N	PRESENT	0
112563	112553	08034U	PARTICIPANT	\N	PRESENT	0
112564	112553	83047W	PARTICIPANT	\N	PRESENT	0
112565	112553	01034P	PRESIDENT	0	PRESENT	0
113315	113312	14089Y	PARTICIPANT	\N	PRESENT	0
113316	113312	14217N	PARTICIPANT	\N	PRESENT	0
113317	113312	14281W	PARTICIPANT	\N	PRESENT	0
113318	113312	08041T	PARTICIPANT	\N	PRESENT	0
113319	113312	07004J	PARTICIPANT	\N	PRESENT	0
113320	113312	11049P	PARTICIPANT	\N	PRESENT	0
113321	113312	04061F	PARTICIPANT	\N	PRESENT	0
113322	113312	08053X	PARTICIPANT	\N	PRESENT	0
113323	113312	11082Q	PARTICIPANT	\N	PRESENT	0
113324	113312	10015M	PARTICIPANT	\N	PRESENT	0
113325	113312	11054L	PARTICIPANT	\N	PRESENT	0
113326	113312	14269B	PARTICIPANT	\N	PRESENT	0
113327	113312	92020L	PARTICIPANT	\N	EXCUSE	0
113328	113312	14193X	PARTICIPANT	\N	EXCUSE	0
113329	113312	14041T	PARTICIPANT	\N	EXCUSE	0
113373	113372	01041N	PARTICIPANT	\N	PRESENT	0
113374	113372	08017T	PARTICIPANT	\N	PRESENT	0
113375	113372	14235Q	PARTICIPANT	\N	PRESENT	0
113377	113376	11039M	PARTICIPANT	\N	PRESENT	0
113378	113376	87003B	PARTICIPANT	\N	PRESENT	0
113379	113376	14073Q	PARTICIPANT	\N	PRESENT	0
113380	113376	11029K	PARTICIPANT	\N	PRESENT	0
113381	113376	14235Q	PARTICIPANT	\N	PRESENT	0
113386	113384	14079W	PARTICIPANT	\N	PRESENT	0
113387	113384	01041N	PARTICIPANT	\N	PRESENT	0
113388	113384	08017T	PARTICIPANT	\N	PRESENT	0
113389	113384	14235Q	PARTICIPANT	\N	PRESENT	0
113393	113392	04086Q	PARTICIPANT	\N	PRESENT	0
113394	113392	04067M	PARTICIPANT	\N	PRESENT	0
113395	113392	01027Q	PARTICIPANT	\N	PRESENT	0
113396	113392	12042Y	PRESIDENT	0	PRESENT	0
113397	113392	11107G	PARTICIPANT	\N	PRESENT	0
113398	113392	11061K	PARTICIPANT	\N	PRESENT	0
113399	113392	11112D	PARTICIPANT	\N	PRESENT	0
113400	113392	14205J	PARTICIPANT	\N	PRESENT	0
113401	113392	14135M	PARTICIPANT	\N	PRESENT	0
113402	113392	11097X	PARTICIPANT	\N	PRESENT	0
113403	113392	04045F	PARTICIPANT	\N	PRESENT	0
113404	113392	14227Q	PARTICIPANT	\N	PRESENT	0
113405	113392	14014Q	PARTICIPANT	\N	EXCUSE	0
113406	113392	11100Y	PARTICIPANT	\N	EXCUSE	0
113785	113784	04040A	PARTICIPANT	\N	EXCUSE	0
113786	113784	08058D	PARTICIPANT	\N	EXCUSE	0
113787	113784	77002U	PARTICIPANT	\N	PRESENT	0
113788	113784	98029W	PARTICIPANT	\N	PRESENT	0
113789	113784	98018T	PARTICIPANT	\N	PRESENT	0
113790	113784	92018S	PARTICIPANT	\N	PRESENT	0
113791	113784	92020L	PARTICIPANT	\N	EXCUSE	0
113792	113784	95030B	PARTICIPANT	\N	PRESENT	0
113793	113784	97011G	PARTICIPANT	\N	PRESENT	0
113794	113784	04035D	PARTICIPANT	\N	EXCUSE	0
113795	113784	07024N	PRESIDENT	0	PRESENT	0
113796	113784	14014Q	PARTICIPANT	\N	PRESENT	0
113797	113784	08056B	PARTICIPANT	\N	EXCUSE	0
113798	113784	95035G	PARTICIPANT	\N	PRESENT	0
113799	113784	14211G	PARTICIPANT	\N	EXCUSE	0
113800	113784	95037J	PARTICIPANT	\N	PRESENT	0
113801	113784	04078Q	PARTICIPANT	\N	PRESENT	0
113802	113784	14097Y	PARTICIPANT	\N	PRESENT	0
113803	113784	14039A	PARTICIPANT	\N	PRESENT	0
113804	113784	92031P	PARTICIPANT	\N	PRESENT	0
113805	113784	11106F	PARTICIPANT	\N	PRESENT	0
113806	113784	14251Q	PARTICIPANT	\N	PRESENT	0
113807	113784	83042R	PARTICIPANT	\N	PRESENT	0
113808	113784	11105E	PARTICIPANT	\N	EXCUSE	0
113809	113784	14253S	PARTICIPANT	\N	PRESENT	0
113810	113784	08047A	PARTICIPANT	\N	PRESENT	0
113811	113784	14028W	PARTICIPANT	\N	PRESENT	0
113812	113784	98021N	PARTICIPANT	\N	PRESENT	0
113813	113784	04080J	PARTICIPANT	\N	PRESENT	0
113814	113784	01014K	PARTICIPANT	\N	PRESENT	0
113815	113784	11054L	PARTICIPANT	\N	EXCUSE	0
113816	113784	01056V	PARTICIPANT	\N	PRESENT	0
113817	113784	08049C	PARTICIPANT	\N	EXCUSE	0
113973	113972	01008M	PARTICIPANT	\N	PRESENT	0
113974	113972	11036J	PARTICIPANT	\N	PRESENT	0
114072	113972	14013P	PARTICIPANT	\N	EXCUSE	0
114014	114012	08055A	PARTICIPANT	\N	PRESENT	0
113977	113972	08068F	PARTICIPANT	\N	PRESENT	0
113978	113972	14207L	PARTICIPANT	\N	PRESENT	0
114015	114012	14093U	PARTICIPANT	\N	PRESENT	0
113980	113972	90003B	PARTICIPANT	\N	PRESENT	0
114016	114012	14030Q	PARTICIPANT	\N	PRESENT	0
113982	113972	80013X	PARTICIPANT	\N	PRESENT	0
113983	113972	08038Y	PARTICIPANT	\N	PRESENT	0
113984	113972	04089T	PARTICIPANT	\N	PRESENT	0
113985	113972	14197C	PARTICIPANT	\N	PRESENT	0
114017	114012	96004D	PARTICIPANT	\N	PRESENT	0
113987	113972	14187A	PARTICIPANT	\N	PRESENT	0
113988	113972	14033T	PARTICIPANT	\N	PRESENT	0
114018	114012	08060W	PARTICIPANT	\N	PRESENT	0
114019	114012	11095V	PARTICIPANT	\N	PRESENT	0
113991	113972	11099A	PARTICIPANT	\N	PRESENT	0
113992	113972	04049K	PRESIDENT	0	PRESENT	0
114181	114180	11039M	PARTICIPANT	\N	PRESENT	0
113994	113972	11111C	PARTICIPANT	\N	PRESENT	0
114021	114012	11114F	PARTICIPANT	\N	PRESENT	0
113996	113972	11100Y	PARTICIPANT	\N	EXCUSE	0
113997	113972	01061S	PARTICIPANT	\N	PRESENT	0
113998	113972	11098Y	PARTICIPANT	\N	PRESENT	0
113999	113972	01043Q	PARTICIPANT	\N	EXCUSE	0
114000	113972	11077T	PARTICIPANT	\N	PRESENT	0
114001	113972	14205J	PARTICIPANT	\N	PRESENT	0
114002	113972	08019V	PARTICIPANT	\N	PRESENT	0
114003	113972	14257W	PARTICIPANT	\N	PRESENT	0
114182	114180	98042T	PARTICIPANT	\N	PRESENT	0
114006	113972	98050T	PARTICIPANT	\N	PRESENT	0
114007	113972	11090Q	PARTICIPANT	\N	PRESENT	0
114008	113972	11046L	PARTICIPANT	\N	PRESENT	0
114009	113972	01058X	PARTICIPANT	\N	PRESENT	0
114010	113972	11094U	PARTICIPANT	\N	PRESENT	0
114011	113972	11066Q	PARTICIPANT	\N	PRESENT	0
114438	114437	95035G	PARTICIPANT	\N	PRESENT	0
114023	114012	11065P	PARTICIPANT	\N	PRESENT	0
114024	114012	01015L	PARTICIPANT	\N	PRESENT	0
114025	114012	11107G	PARTICIPANT	\N	PRESENT	0
114440	114439	95035G	PARTICIPANT	\N	PRESENT	0
114027	114012	02002K	PARTICIPANT	\N	PRESENT	0
114028	114012	01022K	PARTICIPANT	\N	EXCUSE	0
114029	114012	04097T	PARTICIPANT	\N	PRESENT	0
114030	114012	09001P	PARTICIPANT	\N	EXCUSE	0
114031	114012	11059R	PARTICIPANT	\N	PRESENT	0
114032	114012	14219Q	PARTICIPANT	\N	PRESENT	0
114033	114012	80027E	PARTICIPANT	\N	PRESENT	0
114034	114012	14031R	PARTICIPANT	\N	PRESENT	0
114035	114012	08009T	PRESIDENT	0	PRESENT	0
114036	114012	08062Y	PARTICIPANT	\N	EXCUSE	0
114441	114439	11084S	PARTICIPANT	\N	PRESENT	0
114038	114012	92039X	PARTICIPANT	\N	EXCUSE	0
114039	114012	08042U	PARTICIPANT	\N	PRESENT	0
114040	114012	14169X	PARTICIPANT	\N	PRESENT	0
114041	114012	14237S	PARTICIPANT	\N	PRESENT	0
114042	114012	13002U	PARTICIPANT	\N	PRESENT	0
114043	114012	05012A	PARTICIPANT	\N	PRESENT	0
114442	114439	04049K	PARTICIPANT	\N	PRESENT	0
114045	114012	14135M	PARTICIPANT	\N	PRESENT	0
114046	114012	14331P	PARTICIPANT	\N	PRESENT	0
114047	114012	95062K	PARTICIPANT	\N	PRESENT	0
114048	114012	14107H	PARTICIPANT	\N	PRESENT	0
114049	114012	14051J	PARTICIPANT	\N	PRESENT	0
114050	114012	14157T	PARTICIPANT	\N	PRESENT	0
114051	114012	96003C	PARTICIPANT	\N	EXCUSE	0
114525	99613	14059S	PARTICIPANT	\N	EXCUSE	0
114806	114804	04086Q	PARTICIPANT	\N	PRESENT	0
114855	114854	01041N	PARTICIPANT	\N	PRESENT	0
114856	114854	08017T	PARTICIPANT	\N	PRESENT	0
114993	114992	01008M	PARTICIPANT	\N	PRESENT	0
114994	114992	14207L	PARTICIPANT	\N	PRESENT	0
114995	114992	90003B	PARTICIPANT	\N	PRESENT	0
114996	114992	14195A	PARTICIPANT	\N	PRESENT	0
114997	114992	14042U	PARTICIPANT	\N	PRESENT	0
114998	114992	12042Y	PARTICIPANT	\N	PRESENT	0
114999	114992	14033T	PARTICIPANT	\N	PRESENT	0
115000	114992	14179A	PARTICIPANT	\N	PRESENT	0
115001	114992	01061S	PARTICIPANT	\N	PRESENT	0
115002	114992	14205J	PARTICIPANT	\N	PRESENT	0
121557	117652	01031L	PARTICIPANT	\N	PRESENT	0
121779	121778	04059M	PARTICIPANT	\N	PRESENT	0
122565	122564	11039M	PARTICIPANT	\N	PRESENT	0
122566	122564	98042T	PARTICIPANT	\N	PRESENT	0
122567	122564	01019Q	PARTICIPANT	\N	PRESENT	0
122692	121161	14327T	PARTICIPANT	\N	PRESENT	0
123020	123019	14239U	PARTICIPANT	\N	PRESENT	0
123165	121161	14034U	PARTICIPANT	\N	EXCUSE	0
123022	123019	01046T	PARTICIPANT	\N	PRESENT	0
123023	123019	04053F	PARTICIPANT	\N	PRESENT	0
123024	123019	14255U	PARTICIPANT	\N	PRESENT	0
123025	123019	04066L	PARTICIPANT	\N	PRESENT	0
123026	123019	00003C	PARTICIPANT	\N	EXCUSE	0
123027	123019	14053L	PARTICIPANT	\N	PRESENT	0
123028	123019	11103C	PARTICIPANT	\N	PRESENT	0
123195	123194	95030B	PARTICIPANT	\N	PRESENT	0
123030	123019	14195A	PARTICIPANT	\N	PRESENT	0
123031	123019	14267Y	PARTICIPANT	\N	PRESENT	0
123032	123019	11023D	PARTICIPANT	\N	PRESENT	0
123205	123204	01041N	PARTICIPANT	\N	PRESENT	0
123034	123019	08052W	PARTICIPANT	\N	PRESENT	0
123035	123019	01059Y	PARTICIPANT	\N	EXCUSE	0
123036	123019	04081K	PARTICIPANT	\N	PRESENT	0
123206	123204	08017T	PARTICIPANT	\N	PRESENT	0
123038	123019	10006L	PARTICIPANT	\N	PRESENT	0
123207	123204	11091R	PARTICIPANT	\N	PRESENT	0
123040	123019	14217N	PARTICIPANT	\N	PRESENT	0
123041	123019	14042U	PARTICIPANT	\N	PRESENT	0
123042	123019	14151M	PARTICIPANT	\N	PRESENT	0
123043	123019	12042Y	PARTICIPANT	\N	PRESENT	0
123044	123019	14281W	PARTICIPANT	\N	PRESENT	0
123045	123019	14087W	PARTICIPANT	\N	PRESENT	0
123046	123019	01003G	PARTICIPANT	\N	PRESENT	0
123047	123019	14034U	PARTICIPANT	\N	PRESENT	0
123048	123019	14231L	PARTICIPANT	\N	PRESENT	0
123049	123019	11061K	PARTICIPANT	\N	PRESENT	0
123050	123019	08048B	PARTICIPANT	\N	PRESENT	0
123051	123019	08041T	PARTICIPANT	\N	PRESENT	0
123052	123019	01011G	PARTICIPANT	\N	PRESENT	0
123053	123019	14026U	PARTICIPANT	\N	PRESENT	0
123054	123019	14213J	PARTICIPANT	\N	PRESENT	0
123209	123208	01041N	PARTICIPANT	\N	PRESENT	0
123056	123019	11112D	PARTICIPANT	\N	EXCUSE	0
123057	123019	14037X	PARTICIPANT	\N	PRESENT	0
123210	123208	08017T	PARTICIPANT	\N	PRESENT	0
123059	123019	11067R	PARTICIPANT	\N	EXCUSE	0
123060	123019	14223L	PARTICIPANT	\N	PRESENT	0
123061	123019	04092N	PRESIDENT	0	PRESENT	0
123062	123019	14265W	PARTICIPANT	\N	PRESENT	0
123063	123019	14119M	PARTICIPANT	\N	PRESENT	0
123064	123019	14071N	PARTICIPANT	\N	PRESENT	0
123065	123019	07032N	PARTICIPANT	\N	PRESENT	0
123066	123019	04043D	PARTICIPANT	\N	PRESENT	0
123067	123019	14271U	PARTICIPANT	\N	PRESENT	0
123263	123262	11076S	PARTICIPANT	\N	PRESENT	0
123069	123019	11093T	PARTICIPANT	\N	PRESENT	0
123472	121161	14014Q	PARTICIPANT	\N	EXCUSE	0
123071	123019	04045F	PARTICIPANT	\N	PRESENT	0
123072	123019	14227Q	PARTICIPANT	\N	PRESENT	0
123073	123019	01034P	PARTICIPANT	\N	PRESENT	0
123265	123262	04040A	PARTICIPANT	\N	PRESENT	0
123266	123262	08058D	PARTICIPANT	\N	PRESENT	0
123076	123019	14269B	PARTICIPANT	\N	PRESENT	0
123267	123262	04042C	PARTICIPANT	\N	PRESENT	0
123473	121161	04045F	PARTICIPANT	\N	EXCUSE	0
123269	123262	98029W	PARTICIPANT	\N	PRESENT	0
123270	123262	11080N	PARTICIPANT	\N	PRESENT	0
123271	123262	11027H	PARTICIPANT	\N	PRESENT	0
123272	123262	98018T	PARTICIPANT	\N	PRESENT	0
123273	123262	92018S	PARTICIPANT	\N	PRESENT	0
123274	123262	92020L	PARTICIPANT	\N	EXCUSE	0
123521	123520	08039A	PARTICIPANT	\N	PRESENT	0
123523	123522	08039A	PARTICIPANT	\N	PRESENT	0
123525	123524	08039A	PARTICIPANT	\N	PRESENT	0
123278	123262	97011G	PARTICIPANT	\N	PRESENT	0
123527	123526	11039M	PARTICIPANT	\N	PRESENT	0
123280	123262	04035D	PARTICIPANT	\N	PRESENT	0
123281	123262	07024N	PARTICIPANT	\N	EXCUSE	0
123282	123262	04095R	PARTICIPANT	\N	PRESENT	0
123283	123262	14014Q	PARTICIPANT	\N	PRESENT	0
123284	123262	11015D	PARTICIPANT	\N	PRESENT	0
123285	123262	07004J	PARTICIPANT	\N	EXCUSE	0
123286	123262	95035G	PARTICIPANT	\N	PRESENT	0
123287	123262	08056B	PARTICIPANT	\N	EXCUSE	0
123288	123262	14211G	PARTICIPANT	\N	PRESENT	0
123289	123262	98022P	PARTICIPANT	\N	PRESENT	0
123290	123262	11064N	PARTICIPANT	\N	PRESENT	0
123291	123262	95037J	PARTICIPANT	\N	PRESENT	0
123292	123262	04078Q	PARTICIPANT	\N	PRESENT	0
123293	123262	14097Y	PARTICIPANT	\N	EXCUSE	0
123294	123262	95041E	PARTICIPANT	\N	EXCUSE	0
123295	123262	04036E	PARTICIPANT	\N	PRESENT	0
123528	123526	08012N	PARTICIPANT	\N	PRESENT	0
123529	123526	11043H	PARTICIPANT	\N	PRESENT	0
123530	123526	14241N	PARTICIPANT	\N	PRESENT	0
123299	123262	92031P	PARTICIPANT	\N	PRESENT	0
123300	123262	11106F	PARTICIPANT	\N	PRESENT	0
123532	123531	11039M	PARTICIPANT	\N	PRESENT	0
123533	123531	14241N	PARTICIPANT	\N	PRESENT	0
123534	123531	11043H	PARTICIPANT	\N	PRESENT	0
123535	123531	87003B	PARTICIPANT	\N	PRESENT	0
123305	123262	11105E	PARTICIPANT	\N	PRESENT	0
123536	123531	08012N	PARTICIPANT	\N	PRESENT	0
123307	123262	08047A	PARTICIPANT	\N	PRESENT	0
123308	123262	14028W	PARTICIPANT	\N	PRESENT	0
123537	123531	14073Q	PARTICIPANT	\N	PRESENT	0
123794	123793	11089X	PARTICIPANT	\N	PRESENT	0
123311	123262	04080J	PARTICIPANT	\N	PRESENT	0
123312	123262	95059Q	PRESIDENT	0	PRESENT	0
123313	123262	86044G	PARTICIPANT	\N	PRESENT	0
123314	123262	01014K	PARTICIPANT	\N	PRESENT	0
123315	123262	11054L	PARTICIPANT	\N	PRESENT	0
123316	123262	01056V	PARTICIPANT	\N	PRESENT	0
123800	120697	04043D	PARTICIPANT	\N	EXCUSE	0
123867	123866	08010L	PARTICIPANT	\N	PRESENT	0
123869	123868	08010L	PARTICIPANT	\N	PRESENT	0
123871	123870	08010L	PARTICIPANT	\N	PRESENT	0
123873	123872	08010L	PARTICIPANT	\N	PRESENT	0
123875	123874	08010L	PARTICIPANT	\N	PRESENT	0
123880	123879	08010L	PARTICIPANT	\N	PRESENT	0
123943	123942	14071N	PARTICIPANT	\N	PRESENT	0
123944	123942	04040A	PRESIDENT	0	PRESENT	0
124139	123237	80013X	PARTICIPANT	\N	PRESENT	0
124140	123237	14263U	PARTICIPANT	\N	PRESENT	0
124141	123237	01046T	PARTICIPANT	\N	EXCUSE	0
124142	123237	11036J	PARTICIPANT	\N	EXCUSE	0
124143	123237	11089X	PARTICIPANT	\N	EXCUSE	0
124144	123237	04061F	PARTICIPANT	\N	EXCUSE	0
124145	123237	14221J	PARTICIPANT	\N	EXCUSE	0
124146	123237	14257W	PARTICIPANT	\N	EXCUSE	0
124151	120697	14275Y	PARTICIPANT	\N	EXCUSE	0
124152	120697	96003C	PARTICIPANT	\N	EXCUSE	0
124153	120697	11010L	PARTICIPANT	\N	EXCUSE	0
124172	124154	89029V	PARTICIPANT	\N	PRESENT	0
124173	120697	11025F	PARTICIPANT	\N	EXCUSE	0
124174	124154	11112D	PARTICIPANT	\N	PRESENT	0
124175	124154	01011G	PARTICIPANT	\N	PRESENT	0
124176	124154	14026U	PARTICIPANT	\N	PRESENT	0
124178	124154	14073Q	PARTICIPANT	\N	PRESENT	0
124179	124154	11011M	PARTICIPANT	\N	PRESENT	0
124180	124154	04035D	PARTICIPANT	\N	PRESENT	0
124181	124154	95015C	PARTICIPANT	\N	PRESENT	0
124182	124154	08010L	PARTICIPANT	\N	PRESENT	0
124183	124154	98023Q	PARTICIPANT	\N	PRESENT	0
124184	124154	14031R	PARTICIPANT	\N	PRESENT	0
124185	124154	01007L	PARTICIPANT	\N	PRESENT	0
124186	124154	11110B	PARTICIPANT	\N	PRESENT	0
124187	124154	14221J	PARTICIPANT	\N	PRESENT	0
124188	124154	11066Q	PARTICIPANT	\N	PRESENT	0
124194	124154	14169X	PARTICIPANT	\N	PRESENT	0
124195	124154	01060R	PARTICIPANT	\N	PRESENT	0
124196	124154	14201E	PARTICIPANT	\N	PRESENT	0
124197	124154	11026G	PARTICIPANT	\N	PRESENT	0
124198	124154	92015P	PARTICIPANT	\N	PRESENT	0
124199	124154	14001X	PARTICIPANT	\N	PRESENT	0
124200	124154	04053F	PARTICIPANT	\N	PRESENT	0
124201	124154	14105F	PARTICIPANT	\N	PRESENT	0
124202	124154	14197C	PARTICIPANT	\N	PRESENT	0
124203	124154	11055M	PARTICIPANT	\N	PRESENT	0
124204	124154	14147R	PARTICIPANT	\N	PRESENT	0
124205	124154	14033T	PARTICIPANT	\N	PRESENT	0
124206	124154	04044E	PARTICIPANT	\N	PRESENT	0
124207	124154	08022Q	PARTICIPANT	\N	PRESENT	0
124208	124154	11057P	PARTICIPANT	\N	PRESENT	0
124209	124154	14179A	PARTICIPANT	\N	PRESENT	0
124210	124154	14013P	PARTICIPANT	\N	PRESENT	0
124211	124154	14157T	PARTICIPANT	\N	PRESENT	0
124212	124154	11034G	PARTICIPANT	\N	PRESENT	0
124213	124154	86044G	PARTICIPANT	\N	PRESENT	0
93653	93652	14133K	PARTICIPANT	\N	PRESENT	0
93654	93652	96004D	PRESIDENT	0	PRESENT	0
93655	93652	14089Y	PARTICIPANT	\N	PRESENT	0
93656	93652	90003B	PARTICIPANT	\N	PRESENT	0
93657	93652	11035H	PARTICIPANT	\N	PRESENT	0
93658	93652	95030B	PARTICIPANT	\N	PRESENT	0
93659	93652	11083R	PARTICIPANT	\N	PRESENT	0
93660	93652	95037J	PARTICIPANT	\N	PRESENT	0
93661	93652	08044W	PARTICIPANT	\N	PRESENT	0
93664	93652	14097Y	PARTICIPANT	\N	PRESENT	0
93666	93652	11026G	PARTICIPANT	\N	PRESENT	0
93667	93652	04057K	PARTICIPANT	\N	PRESENT	0
93669	93652	08042U	PARTICIPANT	\N	PRESENT	0
93670	93652	01016M	PARTICIPANT	\N	PRESENT	0
93671	93652	11012A	PARTICIPANT	\N	PRESENT	0
93673	93652	04034C	PARTICIPANT	\N	PRESENT	0
93791	89157	13002U	PARTICIPANT	\N	EXCUSE	0
93689	93687	04085P	PARTICIPANT	\N	PRESENT	0
93690	93687	05008E	PRESIDENT	0	PRESENT	0
93691	93687	11030C	PARTICIPANT	\N	PRESENT	0
93692	93687	11033F	PARTICIPANT	\N	PRESENT	0
93693	93687	14065Q	PARTICIPANT	\N	PRESENT	0
93741	93738	04085P	PARTICIPANT	\N	PRESENT	0
93742	93738	05008E	PRESIDENT	0	PRESENT	0
93743	93738	11030C	PARTICIPANT	\N	PRESENT	0
93697	93687	04038G	PARTICIPANT	\N	PRESENT	0
93698	93687	99002P	PARTICIPANT	\N	PRESENT	0
93699	93687	11056N	PARTICIPANT	\N	PRESENT	0
93700	93687	14259Y	PARTICIPANT	\N	PRESENT	0
93701	93687	11035H	PARTICIPANT	\N	PRESENT	0
93702	93687	14041T	PARTICIPANT	\N	PRESENT	0
93703	93687	11113E	PARTICIPANT	\N	PRESENT	0
93704	93687	01024M	PARTICIPANT	\N	PRESENT	0
93705	93687	14215L	PARTICIPANT	\N	PRESENT	0
93706	93687	11034G	PARTICIPANT	\N	PRESENT	0
93707	93687	08018U	PARTICIPANT	\N	PRESENT	0
93708	93687	11010L	PARTICIPANT	\N	EXCUSE	0
93709	93687	01007L	PARTICIPANT	\N	PRESENT	0
93744	93738	11033F	PARTICIPANT	\N	PRESENT	0
93745	93738	14065Q	PARTICIPANT	\N	PRESENT	0
93746	93738	14069U	PARTICIPANT	\N	PRESENT	0
93713	93687	11026G	PARTICIPANT	\N	PRESENT	0
93714	93687	04079R	PARTICIPANT	\N	PRESENT	0
93715	93687	14111D	PARTICIPANT	\N	PRESENT	0
93716	93687	14001X	PARTICIPANT	\N	PRESENT	0
93717	93687	14273W	PARTICIPANT	\N	PRESENT	0
93718	93687	01060R	PARTICIPANT	\N	PRESENT	0
93719	93687	14147R	PARTICIPANT	\N	PRESENT	0
93792	89157	04043D	PARTICIPANT	\N	EXCUSE	0
93721	93687	08051V	PARTICIPANT	\N	PRESENT	0
93748	93738	11032E	PARTICIPANT	\N	PRESENT	0
93723	93687	07034Q	PARTICIPANT	\N	PRESENT	0
93724	93687	04074L	PARTICIPANT	\N	PRESENT	0
93725	93687	10015M	PARTICIPANT	\N	PRESENT	0
93726	93687	95063L	PARTICIPANT	\N	PRESENT	0
93727	93687	01019Q	PARTICIPANT	\N	PRESENT	0
93728	93687	01028R	PARTICIPANT	\N	PRESENT	0
93749	93738	04038G	PARTICIPANT	\N	PRESENT	0
93730	93687	04056J	PARTICIPANT	\N	PRESENT	0
93731	93687	14275Y	PARTICIPANT	\N	PRESENT	0
93750	93738	99002P	PARTICIPANT	\N	PRESENT	0
93793	89157	14209N	PARTICIPANT	\N	EXCUSE	0
93734	93687	92045V	PARTICIPANT	\N	PRESENT	0
93735	93687	95067Q	PARTICIPANT	\N	PRESENT	0
93736	93687	01047U	PARTICIPANT	\N	PRESENT	0
93751	93738	11056N	PARTICIPANT	\N	PRESENT	0
93752	93738	14259Y	PARTICIPANT	\N	PRESENT	0
93753	93738	11035H	PARTICIPANT	\N	PRESENT	0
93754	93738	14041T	PARTICIPANT	\N	PRESENT	0
93755	93738	11113E	PARTICIPANT	\N	PRESENT	0
93756	93738	01024M	PARTICIPANT	\N	PRESENT	0
93757	93738	14215L	PARTICIPANT	\N	PRESENT	0
93758	93738	11034G	PARTICIPANT	\N	PRESENT	0
93759	93738	08018U	PARTICIPANT	\N	PRESENT	0
93760	93738	11010L	PARTICIPANT	\N	EXCUSE	0
93761	93738	01007L	PARTICIPANT	\N	PRESENT	0
93794	89157	04061F	PARTICIPANT	\N	EXCUSE	0
93763	93738	08044W	PARTICIPANT	\N	PRESENT	0
93796	89157	08039A	PARTICIPANT	\N	EXCUSE	0
93765	93738	11026G	PARTICIPANT	\N	PRESENT	0
93766	93738	04079R	PARTICIPANT	\N	PRESENT	0
93767	93738	14111D	PARTICIPANT	\N	PRESENT	0
93768	93738	14001X	PARTICIPANT	\N	PRESENT	0
93769	93738	14273W	PARTICIPANT	\N	PRESENT	0
93802	89157	14221J	PARTICIPANT	\N	EXCUSE	0
93771	93738	14147R	PARTICIPANT	\N	PRESENT	0
93807	89157	14263U	PARTICIPANT	\N	EXCUSE	0
93773	93738	08051V	PARTICIPANT	\N	PRESENT	0
93808	89157	01046T	PARTICIPANT	\N	EXCUSE	0
93775	93738	07034Q	PARTICIPANT	\N	PRESENT	0
93776	93738	04074L	PARTICIPANT	\N	PRESENT	0
93809	89157	11068S	PARTICIPANT	\N	PRESENT	0
93778	93738	95063L	PARTICIPANT	\N	PRESENT	0
93779	93738	01019Q	PARTICIPANT	\N	PRESENT	0
93780	93738	01028R	PARTICIPANT	\N	PRESENT	0
94240	94233	12042Y	PARTICIPANT	\N	PRESENT	0
93782	93738	04056J	PARTICIPANT	\N	PRESENT	0
93783	93738	14275Y	PARTICIPANT	\N	PRESENT	0
94238	94233	08043V	PARTICIPANT	\N	PRESENT	0
94239	94233	11027H	PARTICIPANT	\N	PRESENT	0
93786	93738	92045V	PARTICIPANT	\N	PRESENT	0
93787	93738	95067Q	PARTICIPANT	\N	PRESENT	0
93788	93738	01047U	PARTICIPANT	\N	PRESENT	0
94241	94233	14014Q	PARTICIPANT	\N	PRESENT	0
94242	94233	07026Q	PRESIDENT	0	PRESENT	0
94243	94233	14030Q	PARTICIPANT	\N	EXCUSE	0
94244	94233	11029K	PARTICIPANT	\N	EXCUSE	0
94245	94233	11031D	PARTICIPANT	\N	EXCUSE	0
94246	94233	95035G	PARTICIPANT	\N	EXCUSE	0
94247	94233	08056B	PARTICIPANT	\N	EXCUSE	0
94248	94233	09001P	PARTICIPANT	\N	EXCUSE	0
94249	94233	14031R	PARTICIPANT	\N	EXCUSE	0
94250	94233	11067R	PARTICIPANT	\N	EXCUSE	0
94251	94233	11014C	PARTICIPANT	\N	EXCUSE	0
94252	94233	14265W	PARTICIPANT	\N	EXCUSE	0
94262	94261	14133K	PARTICIPANT	\N	PRESENT	0
94263	94261	04054G	PARTICIPANT	\N	PRESENT	0
94264	94261	96004D	PRESIDENT	0	PRESENT	0
94265	94261	14089Y	PARTICIPANT	\N	PRESENT	0
94266	94261	90003B	PARTICIPANT	\N	PRESENT	0
94267	94261	14249W	PARTICIPANT	\N	PRESENT	0
94268	94261	11083R	PARTICIPANT	\N	PRESENT	0
94269	94261	14073Q	PARTICIPANT	\N	PRESENT	0
94270	94261	11026G	PARTICIPANT	\N	PRESENT	0
94271	94261	14097Y	PARTICIPANT	\N	PRESENT	0
94272	94261	04080J	PARTICIPANT	\N	PRESENT	0
94273	94261	10015M	PARTICIPANT	\N	PRESENT	0
94274	94261	01016M	PARTICIPANT	\N	PRESENT	0
94275	94261	14026U	PARTICIPANT	\N	EXCUSE	0
94276	94261	98046X	PARTICIPANT	\N	EXCUSE	0
94277	94261	04057K	PARTICIPANT	\N	EXCUSE	0
94278	94261	14135M	PARTICIPANT	\N	EXCUSE	0
94279	94261	04034C	PARTICIPANT	\N	EXCUSE	0
94280	94261	08018U	PARTICIPANT	\N	EXCUSE	0
102748	101191	11085T	PARTICIPANT	\N	PRESENT	0
102792	101191	07029T	PARTICIPANT	\N	PRESENT	0
102793	101191	08062Y	PARTICIPANT	\N	PRESENT	0
102794	101191	11012A	PARTICIPANT	\N	PRESENT	0
102795	101191	14109K	PARTICIPANT	\N	PRESENT	0
102796	101191	04050C	PARTICIPANT	\N	PRESENT	0
102797	101191	11100Y	PARTICIPANT	\N	PRESENT	0
102798	101191	01016M	PARTICIPANT	\N	PRESENT	0
102812	101191	11042G	PARTICIPANT	\N	PRESENT	0
102800	101191	14013P	PARTICIPANT	\N	PRESENT	0
102801	101191	92015P	PARTICIPANT	\N	PRESENT	0
102802	101191	11083R	PARTICIPANT	\N	PRESENT	0
102803	101191	98018T	PARTICIPANT	\N	PRESENT	0
102805	101191	14061L	PARTICIPANT	\N	PRESENT	0
102806	101191	11064N	PARTICIPANT	\N	PRESENT	0
102807	102804	08022Q	PARTICIPANT	\N	PRESENT	0
102808	102804	01016M	PARTICIPANT	\N	PRESENT	0
102809	102804	08061X	PARTICIPANT	\N	PRESENT	0
102810	102804	98053W	PARTICIPANT	\N	PRESENT	0
102811	101191	04036E	PARTICIPANT	\N	PRESENT	0
102813	101191	04088S	PARTICIPANT	\N	PRESENT	0
102814	101191	14033T	PARTICIPANT	\N	PRESENT	0
102815	101191	08069G	PARTICIPANT	\N	PRESENT	0
102816	101191	11011M	PARTICIPANT	\N	PRESENT	0
102818	101191	14209N	PARTICIPANT	\N	PRESENT	0
102819	101191	11091R	PARTICIPANT	\N	PRESENT	0
102820	101191	11056N	PARTICIPANT	\N	PRESENT	0
102822	101191	96004D	PARTICIPANT	\N	PRESENT	0
102852	101191	97011G	PARTICIPANT	\N	PRESENT	0
102853	101191	98005N	PARTICIPANT	\N	PRESENT	0
103617	103112	01015L	PARTICIPANT	\N	PRESENT	0
103618	103112	10006L	PARTICIPANT	\N	PRESENT	0
103619	103112	98024R	PARTICIPANT	\N	PRESENT	0
103620	103112	14223L	PARTICIPANT	\N	PRESENT	0
103621	103112	95049N	PARTICIPANT	\N	PRESENT	0
108233	107095	08014Q	PARTICIPANT	\N	PRESENT	0
108234	107095	04067M	PARTICIPANT	\N	PRESENT	0
108235	107095	14030Q	PARTICIPANT	\N	PRESENT	0
108236	107095	14231L	PARTICIPANT	\N	PRESENT	0
108237	107095	14253S	PARTICIPANT	\N	PRESENT	0
108238	107095	14235Q	PARTICIPANT	\N	PRESENT	0
108239	107095	08038Y	PARTICIPANT	\N	PRESENT	0
108240	107095	14209N	PARTICIPANT	\N	PRESENT	0
108241	107095	04097T	PARTICIPANT	\N	PRESENT	0
108231	107095	14034U	PARTICIPANT	\N	PRESENT	0
108232	107095	14151M	PARTICIPANT	\N	PRESENT	0
108242	107095	14213J	PARTICIPANT	\N	PRESENT	0
108243	107095	14187A	PARTICIPANT	\N	PRESENT	0
108244	107095	14033T	PARTICIPANT	\N	PRESENT	0
108245	107095	14026U	PARTICIPANT	\N	PRESENT	0
108246	107095	14061L	PARTICIPANT	\N	PRESENT	0
108247	107095	14217N	PARTICIPANT	\N	PRESENT	0
108248	107095	04049K	PARTICIPANT	\N	PRESENT	0
108249	107095	04088S	PARTICIPANT	\N	PRESENT	0
108250	107095	11056N	PARTICIPANT	\N	PRESENT	0
108251	107095	08031R	PARTICIPANT	\N	PRESENT	0
108252	107095	14042U	PARTICIPANT	\N	PRESENT	0
108253	107095	14053L	PARTICIPANT	\N	PRESENT	0
108254	107095	92045V	PARTICIPANT	\N	PRESENT	0
108255	107095	14083S	PARTICIPANT	\N	PRESENT	0
108256	107095	95030B	PARTICIPANT	\N	PRESENT	0
108257	107095	11014C	PARTICIPANT	\N	PRESENT	0
108258	107095	11105E	PARTICIPANT	\N	PRESENT	0
108259	107095	14255U	PARTICIPANT	\N	PRESENT	0
108260	107095	10006L	PARTICIPANT	\N	PRESENT	0
108261	107095	11097X	PARTICIPANT	\N	PRESENT	0
108262	107095	14031R	PARTICIPANT	\N	PRESENT	0
108263	107095	14119M	PARTICIPANT	\N	PRESENT	0
108264	107095	14105F	PARTICIPANT	\N	PRESENT	0
108272	107095	14215L	PARTICIPANT	\N	PRESENT	0
108273	107095	14014Q	PARTICIPANT	\N	PRESENT	0
108274	107095	14111D	PARTICIPANT	\N	PRESENT	0
108275	107095	04033B	PARTICIPANT	\N	PRESENT	0
108276	107095	14219Q	PARTICIPANT	\N	PRESENT	0
108277	107095	11094U	PARTICIPANT	\N	PRESENT	0
108278	107095	08016S	PARTICIPANT	\N	PRESENT	0
108279	107095	14257W	PARTICIPANT	\N	PRESENT	0
108280	107095	01008M	PARTICIPANT	\N	PRESENT	0
108281	107095	14133K	PARTICIPANT	\N	PRESENT	0
108282	107095	10015M	PARTICIPANT	\N	PRESENT	0
108283	107095	01028R	PARTICIPANT	\N	PRESENT	0
108284	107095	08068F	PARTICIPANT	\N	PRESENT	0
108285	107095	14159V	PARTICIPANT	\N	PRESENT	0
108286	107095	11036J	PARTICIPANT	\N	PRESENT	0
108292	107095	08061X	PARTICIPANT	\N	PRESENT	0
108544	108543	08025T	PARTICIPANT	\N	PRESENT	0
108545	108543	04085P	PARTICIPANT	\N	PRESENT	0
108546	108543	05008E	PRESIDENT	0	PRESENT	0
108547	108543	11030C	PARTICIPANT	\N	PRESENT	0
108593	108543	11072N	PARTICIPANT	\N	PRESENT	0
108549	108543	14065Q	PARTICIPANT	\N	PRESENT	0
108550	108543	14069U	PARTICIPANT	\N	PRESENT	0
108551	108543	04047H	PARTICIPANT	\N	PRESENT	0
108552	108543	11032E	PARTICIPANT	\N	PRESENT	0
108553	108543	04038G	PARTICIPANT	\N	PRESENT	0
108554	108543	99002P	PARTICIPANT	\N	PRESENT	0
108555	108543	11056N	PARTICIPANT	\N	PRESENT	0
108556	108543	14259Y	PARTICIPANT	\N	PRESENT	0
108557	108543	11035H	PARTICIPANT	\N	PRESENT	0
108558	108543	14041T	PARTICIPANT	\N	PRESENT	0
108559	108543	11113E	PARTICIPANT	\N	PRESENT	0
108560	108543	01024M	PARTICIPANT	\N	PRESENT	0
108561	108543	14215L	PARTICIPANT	\N	PRESENT	0
108562	108543	11034G	PARTICIPANT	\N	PRESENT	0
108563	108543	08018U	PARTICIPANT	\N	PRESENT	0
108594	108543	14033T	PARTICIPANT	\N	PRESENT	0
108565	108543	01007L	PARTICIPANT	\N	PRESENT	0
108566	108543	11049P	PARTICIPANT	\N	PRESENT	0
108567	108543	08044W	PARTICIPANT	\N	PRESENT	0
108568	108543	11084S	PARTICIPANT	\N	PRESENT	0
108569	108543	11026G	PARTICIPANT	\N	PRESENT	0
108570	108543	04079R	PARTICIPANT	\N	PRESENT	0
108571	108543	14111D	PARTICIPANT	\N	PRESENT	0
108572	108543	14001X	PARTICIPANT	\N	PRESENT	0
108595	108543	08011M	PARTICIPANT	\N	PRESENT	0
108574	108543	01060R	PARTICIPANT	\N	PRESENT	0
110356	110252	86034E	PARTICIPANT	\N	PRESENT	0
110357	110252	14167V	PARTICIPANT	\N	PRESENT	0
108577	108543	08051V	PARTICIPANT	\N	PRESENT	0
110358	110252	01011G	PARTICIPANT	\N	PRESENT	0
108579	108543	07034Q	PARTICIPANT	\N	PRESENT	0
108580	108543	04074L	PARTICIPANT	\N	PRESENT	0
108581	108543	10015M	PARTICIPANT	\N	PRESENT	0
108582	108543	95063L	PARTICIPANT	\N	PRESENT	0
110359	110252	11076S	PARTICIPANT	\N	PRESENT	0
108584	108543	01028R	PARTICIPANT	\N	PRESENT	0
110360	110252	14247U	PARTICIPANT	\N	PRESENT	0
108586	108543	04056J	PARTICIPANT	\N	PRESENT	0
108587	108543	14275Y	PARTICIPANT	\N	PRESENT	0
108588	108543	04044E	PARTICIPANT	\N	EXCUSE	0
108589	108543	11037K	PARTICIPANT	\N	PRESENT	0
108590	108543	92045V	PARTICIPANT	\N	PRESENT	0
108591	108543	95067Q	PARTICIPANT	\N	PRESENT	0
108592	108543	01047U	PARTICIPANT	\N	PRESENT	0
110361	110252	04053F	PARTICIPANT	\N	PRESENT	0
110362	110252	08016S	PARTICIPANT	\N	PRESENT	0
110363	110252	14227Q	PARTICIPANT	\N	PRESENT	0
110364	110252	04056J	PARTICIPANT	\N	PRESENT	0
110365	110252	98035U	PARTICIPANT	\N	PRESENT	0
110366	110252	11067R	PARTICIPANT	\N	PRESENT	0
110367	110252	01022K	PARTICIPANT	\N	PRESENT	0
110368	110252	14197C	PARTICIPANT	\N	PRESENT	0
110369	110252	14063N	PARTICIPANT	\N	PRESENT	0
110370	110252	08060W	PARTICIPANT	\N	PRESENT	0
110371	110252	14235Q	PARTICIPANT	\N	PRESENT	0
110372	110252	14159V	PARTICIPANT	\N	PRESENT	0
110373	110252	13002U	PARTICIPANT	\N	PRESENT	0
110374	110252	11055M	PARTICIPANT	\N	PRESENT	0
110375	110252	92020L	PARTICIPANT	\N	PRESENT	0
110376	110252	14085U	PARTICIPANT	\N	PRESENT	0
110377	110252	83042R	PARTICIPANT	\N	PRESENT	0
110378	110252	14051J	PARTICIPANT	\N	PRESENT	0
110379	110252	01016M	PARTICIPANT	\N	PRESENT	0
110380	110252	11104D	PARTICIPANT	\N	PRESENT	0
110381	110252	11035H	PARTICIPANT	\N	PRESENT	0
110382	110252	95063L	PARTICIPANT	\N	PRESENT	0
110383	110252	92039X	PARTICIPANT	\N	PRESENT	0
110384	110252	11106F	PARTICIPANT	\N	PRESENT	0
110385	110252	14028W	PARTICIPANT	\N	PRESENT	0
110386	110252	83047W	PARTICIPANT	\N	PRESENT	0
110387	110252	80027E	PARTICIPANT	\N	PRESENT	0
110388	110252	14271U	PARTICIPANT	\N	PRESENT	0
110389	110252	11059R	PARTICIPANT	\N	PRESENT	0
110390	110252	04066L	PARTICIPANT	\N	PRESENT	0
110391	110252	08053X	PARTICIPANT	\N	PRESENT	0
110392	110252	11015D	PARTICIPANT	\N	PRESENT	0
110393	110252	01031L	PARTICIPANT	\N	PRESENT	0
110394	110252	08052W	PARTICIPANT	\N	PRESENT	0
110395	110252	11029K	PARTICIPANT	\N	PRESENT	0
110396	110252	01044R	PARTICIPANT	\N	PRESENT	0
110397	110252	11099A	PARTICIPANT	\N	PRESENT	0
110398	110252	11083R	PARTICIPANT	\N	PRESENT	0
110399	110252	04067M	PARTICIPANT	\N	PRESENT	0
110400	110252	11054L	PARTICIPANT	\N	PRESENT	0
110401	110252	08014Q	PARTICIPANT	\N	PRESENT	0
110402	110252	14001X	PARTICIPANT	\N	PRESENT	0
110403	110252	08025T	PARTICIPANT	\N	PRESENT	0
110404	110252	04036E	PARTICIPANT	\N	PRESENT	0
110405	110252	11036J	PARTICIPANT	\N	PRESENT	0
110406	110252	14065Q	PARTICIPANT	\N	PRESENT	0
110407	110252	01027Q	PARTICIPANT	\N	PRESENT	0
110408	110252	98046X	PARTICIPANT	\N	PRESENT	0
110409	110252	95031C	PARTICIPANT	\N	PRESENT	0
110410	110252	99004R	PARTICIPANT	\N	PRESENT	0
110411	110252	01058X	PARTICIPANT	\N	PRESENT	0
110412	110252	98029W	PARTICIPANT	\N	PRESENT	0
110413	110252	14211G	PARTICIPANT	\N	PRESENT	0
110414	110252	14223L	PARTICIPANT	\N	PRESENT	0
110415	110252	89029V	PARTICIPANT	\N	PRESENT	0
110416	110252	08017T	PARTICIPANT	\N	PRESENT	0
110417	110252	77002U	PARTICIPANT	\N	PRESENT	0
110418	110252	14014Q	PARTICIPANT	\N	PRESENT	0
110419	110252	08022Q	PARTICIPANT	\N	PRESENT	0
110420	110252	08010L	PARTICIPANT	\N	PRESENT	0
110421	110252	11100Y	PARTICIPANT	\N	PRESENT	0
110422	110252	11072N	PARTICIPANT	\N	PRESENT	0
110423	110252	14191V	PARTICIPANT	\N	PRESENT	0
110424	110252	11080N	PARTICIPANT	\N	PRESENT	0
110425	110252	14039A	PARTICIPANT	\N	PRESENT	0
110426	110252	11113E	PARTICIPANT	\N	PRESENT	0
110427	110252	01057W	PARTICIPANT	\N	PRESENT	0
110428	110252	04034C	PARTICIPANT	\N	PRESENT	0
110429	110252	87003B	PARTICIPANT	\N	PRESENT	0
115003	114992	14265W	PARTICIPANT	\N	PRESENT	0
115004	114992	14169X	PARTICIPANT	\N	PRESENT	0
115005	114992	14237S	PARTICIPANT	\N	PRESENT	0
115006	114992	11097X	PARTICIPANT	\N	PRESENT	0
115007	114992	14227Q	PARTICIPANT	\N	PRESENT	0
115164	113939	14014Q	PARTICIPANT	\N	PRESENT	0
115165	113939	14267Y	PARTICIPANT	\N	PRESENT	0
115166	113939	14001X	PARTICIPANT	\N	PRESENT	0
115167	113939	14227Q	PARTICIPANT	\N	PRESENT	0
115168	113939	14229S	PARTICIPANT	\N	PRESENT	0
115169	113939	14063N	PARTICIPANT	\N	PRESENT	0
115170	113939	14097Y	PARTICIPANT	\N	PRESENT	0
115171	113939	14207L	PARTICIPANT	\N	PRESENT	0
115172	113939	14039A	PARTICIPANT	\N	PRESENT	0
115173	113939	11114F	PARTICIPANT	\N	PRESENT	0
115174	113939	01034P	PARTICIPANT	\N	PRESENT	0
115179	113939	04095R	PARTICIPANT	\N	PRESENT	0
115189	113939	14219Q	PARTICIPANT	\N	PRESENT	0
115177	113939	11066Q	PARTICIPANT	\N	PRESENT	0
115178	113939	08053X	PARTICIPANT	\N	PRESENT	0
115180	113939	11042G	PARTICIPANT	\N	PRESENT	0
115181	113939	14159V	PARTICIPANT	\N	PRESENT	0
115182	113939	14269B	PARTICIPANT	\N	PRESENT	0
115183	113939	12042Y	PARTICIPANT	\N	PRESENT	0
115184	113939	11107G	PARTICIPANT	\N	PRESENT	0
115185	113939	14231L	PARTICIPANT	\N	PRESENT	0
115187	115186	95067Q	PARTICIPANT	\N	PRESENT	0
115191	113939	01041N	PARTICIPANT	\N	PRESENT	0
115190	113939	11099A	PARTICIPANT	\N	PRESENT	0
115193	115192	98029W	PARTICIPANT	\N	PRESENT	0
115217	113939	11074Q	PARTICIPANT	\N	PRESENT	0
115220	110312	04049K	PARTICIPANT	\N	PRESENT	0
115221	110312	04053F	PARTICIPANT	\N	PRESENT	0
115223	110312	14255U	PARTICIPANT	\N	PRESENT	0
115225	109939	04049K	PRESIDENT	0	PRESENT	0
115226	109939	14207L	PARTICIPANT	\N	PRESENT	0
115227	109939	04053F	PARTICIPANT	\N	PRESENT	0
115228	109939	14265W	PARTICIPANT	\N	PRESENT	0
115229	109939	14255U	PARTICIPANT	\N	PRESENT	0
115230	109939	14253S	PARTICIPANT	\N	PRESENT	0
115232	109939	95067Q	PARTICIPANT	\N	PRESENT	0
115233	109939	89017R	PARTICIPANT	\N	PRESENT	0
115234	109939	14205J	PARTICIPANT	\N	PRESENT	0
115236	109939	14105F	PARTICIPANT	\N	PRESENT	0
115238	109939	14065Q	PARTICIPANT	\N	EXCUSE	0
115239	109939	14030Q	PARTICIPANT	\N	EXCUSE	0
115240	113939	83047W	PARTICIPANT	\N	PRESENT	0
115241	109939	14013P	PARTICIPANT	\N	EXCUSE	0
115242	109939	08068F	PARTICIPANT	\N	EXCUSE	0
115243	109939	14083S	PARTICIPANT	\N	EXCUSE	0
115244	109939	14079W	PARTICIPANT	\N	EXCUSE	0
115245	109939	04055H	PARTICIPANT	\N	EXCUSE	0
115246	109939	11088W	PARTICIPANT	\N	EXCUSE	0
115247	109939	14041T	PARTICIPANT	\N	EXCUSE	0
115248	109939	04071H	PARTICIPANT	\N	EXCUSE	0
115249	109939	14151M	PARTICIPANT	\N	EXCUSE	0
115250	109939	14121F	PARTICIPANT	\N	EXCUSE	0
115251	109939	95041E	PARTICIPANT	\N	EXCUSE	0
115252	109939	14039A	PARTICIPANT	\N	EXCUSE	0
115253	109939	14061L	PARTICIPANT	\N	EXCUSE	0
115254	109939	11077T	PARTICIPANT	\N	EXCUSE	0
115255	109939	11090Q	PARTICIPANT	\N	EXCUSE	0
115256	109939	10015M	PARTICIPANT	\N	EXCUSE	0
115257	109939	14157T	PARTICIPANT	\N	EXCUSE	0
115258	109939	14087W	PARTICIPANT	\N	EXCUSE	0
115260	115259	95067Q	PARTICIPANT	\N	PRESENT	0
115261	113939	11061K	PARTICIPANT	\N	PRESENT	0
115263	115262	14255U	PARTICIPANT	\N	PRESENT	0
115264	115262	04086Q	PARTICIPANT	\N	PRESENT	0
115265	115262	01027Q	PARTICIPANT	\N	PRESENT	0
115266	115262	12042Y	PRESIDENT	0	PRESENT	0
115267	115262	11107G	PARTICIPANT	\N	PRESENT	0
115268	115262	11100Y	PARTICIPANT	\N	EXCUSE	0
115269	113939	11076S	PARTICIPANT	\N	PRESENT	0
115272	113939	01031L	PARTICIPANT	\N	PRESENT	0
115274	115273	11040E	PARTICIPANT	\N	PRESENT	0
115275	115273	04086Q	PARTICIPANT	\N	PRESENT	0
115276	115273	01057W	PARTICIPANT	\N	PRESENT	0
115277	115273	14147R	PARTICIPANT	\N	PRESENT	0
115278	115273	14235Q	PARTICIPANT	\N	PRESENT	0
115279	115273	04034C	PARTICIPANT	\N	PRESENT	0
115280	113939	05004A	PARTICIPANT	\N	PRESENT	0
115281	113939	89017R	PARTICIPANT	\N	PRESENT	0
115282	113939	11026G	PARTICIPANT	\N	PRESENT	0
115293	115292	11039M	PARTICIPANT	\N	PRESENT	0
115294	113939	07034Q	PARTICIPANT	\N	PRESENT	0
115296	115295	01031L	PARTICIPANT	\N	PRESENT	0
115297	115295	98018T	PARTICIPANT	\N	PRESENT	0
115299	115298	95063L	PARTICIPANT	\N	PRESENT	0
115301	115300	96004D	PRESIDENT	0	PRESENT	0
115302	115300	14089Y	PARTICIPANT	0	PRESENT	0
115303	115300	95030B	PARTICIPANT	\N	PRESENT	0
115304	115300	14097Y	PARTICIPANT	\N	PRESENT	0
115305	115300	04061F	PARTICIPANT	\N	PRESENT	0
115313	115312	11026G	PARTICIPANT	\N	PRESENT	0
115314	115300	04080J	PARTICIPANT	\N	PRESENT	0
115315	115300	11026G	PARTICIPANT	\N	PRESENT	0
115332	114752	11057P	PARTICIPANT	\N	PRESENT	0
115333	114752	11042G	PARTICIPANT	\N	PRESENT	0
115350	114752	11012A	PARTICIPANT	\N	PRESENT	0
115335	114752	08011M	PARTICIPANT	\N	PRESENT	0
115336	114752	11085T	PARTICIPANT	\N	PRESENT	0
115337	114752	01031L	PARTICIPANT	\N	PRESENT	0
115338	115300	14073Q	PARTICIPANT	\N	EXCUSE	0
115339	115300	04035D	PARTICIPANT	\N	EXCUSE	0
115340	114752	14175V	PARTICIPANT	\N	PRESENT	0
115341	114752	04086Q	PARTICIPANT	\N	PRESENT	0
115342	114752	11088W	PARTICIPANT	\N	PRESENT	0
115343	114752	11070L	PARTICIPANT	\N	PRESENT	0
115344	114752	14013P	PARTICIPANT	\N	PRESENT	0
115345	114752	14097Y	PARTICIPANT	\N	PRESENT	0
115346	114752	08052W	PARTICIPANT	\N	PRESENT	0
115347	114752	04034C	PARTICIPANT	\N	PRESENT	0
115348	114752	08031R	PARTICIPANT	\N	PRESENT	0
115349	114752	98046X	PARTICIPANT	\N	PRESENT	0
115351	114752	11083R	PARTICIPANT	\N	PRESENT	0
115352	114752	01034P	PARTICIPANT	\N	PRESENT	0
115354	115353	01031L	PARTICIPANT	\N	PRESENT	0
115355	115353	08052W	PARTICIPANT	\N	PRESENT	0
115356	115353	11107G	PARTICIPANT	\N	PRESENT	0
115357	115353	14157T	PARTICIPANT	\N	PRESENT	0
115372	114752	01041N	PARTICIPANT	\N	PRESENT	0
115373	114752	14219Q	PARTICIPANT	\N	PRESENT	0
115374	114752	14159V	PARTICIPANT	\N	PRESENT	0
115375	114752	14014Q	PARTICIPANT	\N	PRESENT	0
115376	114752	01016M	PARTICIPANT	\N	PRESENT	0
115377	114752	80013X	PARTICIPANT	\N	PRESENT	0
115378	114752	11089X	PARTICIPANT	\N	PRESENT	0
115379	114752	01013J	PARTICIPANT	\N	PRESENT	0
115380	114752	98053W	PARTICIPANT	\N	PRESENT	0
115381	114752	98018T	PARTICIPANT	\N	PRESENT	0
115382	114752	14033T	PARTICIPANT	\N	PRESENT	0
115392	114752	01048V	PARTICIPANT	\N	PRESENT	0
115421	114752	04053F	PARTICIPANT	\N	PRESENT	0
115442	114752	07034Q	PARTICIPANT	\N	PRESENT	0
115443	114752	90003B	PARTICIPANT	\N	PRESENT	0
115452	114752	04038G	PARTICIPANT	\N	PRESENT	0
115472	114752	04085P	PARTICIPANT	\N	PRESENT	0
115508	114753	11085T	PARTICIPANT	\N	PRESENT	0
115509	114753	05008E	PARTICIPANT	\N	PRESENT	0
115510	114753	07034Q	PARTICIPANT	\N	PRESENT	0
115511	114753	04085P	PARTICIPANT	\N	PRESENT	0
115512	114753	01013J	PARTICIPANT	\N	PRESENT	0
115513	114753	98053W	PARTICIPANT	\N	PRESENT	0
115514	114753	04034C	PARTICIPANT	\N	PRESENT	0
115532	114753	11057P	PARTICIPANT	\N	PRESENT	0
115533	114753	80013X	PARTICIPANT	\N	PRESENT	0
115534	114753	14097Y	PARTICIPANT	\N	PRESENT	0
115535	114753	01031L	PARTICIPANT	\N	PRESENT	0
115536	114753	98046X	PARTICIPANT	\N	PRESENT	0
115537	114753	11110B	PARTICIPANT	\N	PRESENT	0
115538	114753	04038G	PARTICIPANT	\N	PRESENT	0
115539	114753	01041N	PARTICIPANT	\N	PRESENT	0
115540	114753	08019V	PARTICIPANT	\N	PRESENT	0
115541	114753	14033T	PARTICIPANT	\N	PRESENT	0
115542	114753	14175V	PARTICIPANT	\N	PRESENT	0
115543	114753	92045V	PARTICIPANT	\N	PRESENT	0
115544	114753	90003B	PARTICIPANT	\N	PRESENT	0
115545	114753	04086Q	PARTICIPANT	\N	PRESENT	0
115546	114753	08011M	PARTICIPANT	\N	PRESENT	0
115547	114753	11077T	PARTICIPANT	\N	PRESENT	0
115548	114753	11083R	PARTICIPANT	\N	PRESENT	0
115552	114753	01016M	PARTICIPANT	\N	PRESENT	0
121526	119934	95041E	PARTICIPANT	\N	PRESENT	0
121527	119934	11042G	PARTICIPANT	\N	PRESENT	0
121528	119934	14207L	PARTICIPANT	\N	PRESENT	0
121529	119934	11114F	PARTICIPANT	\N	PRESENT	0
121530	119934	14225N	PARTICIPANT	\N	PRESENT	0
121531	119934	11023D	PARTICIPANT	\N	PRESENT	0
121532	119934	14039A	PARTICIPANT	\N	PRESENT	0
121533	119934	14159V	PARTICIPANT	\N	PRESENT	0
121534	119934	04094Q	PARTICIPANT	\N	PRESENT	0
121535	119934	14269B	PARTICIPANT	\N	PRESENT	0
121536	119934	14327T	PARTICIPANT	\N	PRESENT	0
121537	119934	11053K	PARTICIPANT	\N	PRESENT	0
121538	119934	09001P	PARTICIPANT	\N	PRESENT	0
121539	119934	01024M	PARTICIPANT	\N	PRESENT	0
121540	119934	04070G	PARTICIPANT	\N	PRESENT	0
121541	119934	08009T	PARTICIPANT	\N	PRESENT	0
121542	119934	14135M	PARTICIPANT	\N	PRESENT	0
121543	119934	04089T	PARTICIPANT	\N	PRESENT	0
121544	119934	11064N	PARTICIPANT	\N	PRESENT	0
121545	119934	11085T	PARTICIPANT	\N	PRESENT	0
121546	119934	14219Q	PARTICIPANT	\N	PRESENT	0
121547	119934	14221J	PARTICIPANT	\N	PRESENT	0
121548	119934	14231L	PARTICIPANT	\N	PRESENT	0
121549	119934	11093T	PARTICIPANT	\N	PRESENT	0
121550	119934	14089Y	PARTICIPANT	\N	PRESENT	0
121551	119934	14109K	PARTICIPANT	\N	PRESENT	0
121556	119934	14259Y	PARTICIPANT	\N	PRESENT	0
121558	119934	11068S	PARTICIPANT	\N	PRESENT	0
121560	119934	11089X	PARTICIPANT	\N	PRESENT	0
121593	119934	11065P	PARTICIPANT	\N	PRESENT	0
121583	119934	04061F	PARTICIPANT	\N	PRESENT	0
121584	119934	05004A	PARTICIPANT	\N	PRESENT	0
121594	119935	04081K	PARTICIPANT	\N	PRESENT	0
121612	119935	04070G	PARTICIPANT	\N	PRESENT	0
121613	119935	11029K	PARTICIPANT	\N	PRESENT	0
121614	119935	04088S	PARTICIPANT	\N	PRESENT	0
121615	119935	14195A	PARTICIPANT	\N	PRESENT	0
121616	119935	14059S	PARTICIPANT	\N	PRESENT	0
121617	119935	04057K	PARTICIPANT	\N	PRESENT	0
121618	119935	08019V	PARTICIPANT	\N	PRESENT	0
121619	119935	14241N	PARTICIPANT	\N	PRESENT	0
121620	119935	14263U	PARTICIPANT	\N	PRESENT	0
121622	119935	14089Y	PARTICIPANT	\N	PRESENT	0
121623	119935	12041X	PARTICIPANT	\N	PRESENT	0
121624	119935	04059M	PARTICIPANT	\N	PRESENT	0
121625	119935	07029T	PARTICIPANT	\N	PRESENT	0
121627	119935	08043V	PARTICIPANT	\N	PRESENT	0
121630	119935	14261S	PARTICIPANT	\N	PRESENT	0
121631	119935	14033T	PARTICIPANT	\N	PRESENT	0
121632	119935	11097X	PARTICIPANT	\N	PRESENT	0
121633	119935	14013P	PARTICIPANT	\N	PRESENT	0
121638	119935	14249W	PARTICIPANT	\N	PRESENT	0
121639	119935	11012A	PARTICIPANT	\N	PRESENT	0
121640	119935	07024N	PARTICIPANT	\N	PRESENT	0
121641	119935	11091R	PARTICIPANT	\N	PRESENT	0
121642	119935	08055A	PARTICIPANT	\N	PRESENT	0
121653	121652	14259Y	PARTICIPANT	\N	PRESENT	0
121655	121654	14259Y	PARTICIPANT	\N	PRESENT	0
121656	121654	11113E	PARTICIPANT	\N	PRESENT	0
122738	122737	04040A	PARTICIPANT	\N	PRESENT	0
121931	121929	08043V	PARTICIPANT	\N	PRESENT	0
121932	121929	14053L	PARTICIPANT	\N	PRESENT	0
121933	121929	95015C	PARTICIPANT	\N	PRESENT	0
122739	122737	08058D	PARTICIPANT	\N	PRESENT	0
121935	121929	11027H	PARTICIPANT	\N	PRESENT	0
121936	121929	04086Q	PARTICIPANT	\N	PRESENT	0
122740	122737	04042C	PARTICIPANT	\N	PRESENT	0
122741	122737	98029W	PARTICIPANT	\N	PRESENT	0
122742	122737	98018T	PARTICIPANT	\N	EXCUSE	0
121940	121929	04089T	PARTICIPANT	\N	PRESENT	0
121941	121929	14187A	PARTICIPANT	\N	PRESENT	0
122743	122737	92020L	PARTICIPANT	\N	EXCUSE	0
122744	122737	95030B	PARTICIPANT	\N	PRESENT	0
121944	121929	14231L	PARTICIPANT	\N	PRESENT	0
121945	121929	14179A	PARTICIPANT	\N	PRESENT	0
121946	121929	14213J	PARTICIPANT	\N	PRESENT	0
122745	122737	97011G	PARTICIPANT	\N	PRESENT	0
121948	121929	11100Y	PRESIDENT	0	PRESENT	0
122746	122737	04035D	PARTICIPANT	\N	PRESENT	0
121950	121929	08012N	PARTICIPANT	\N	PRESENT	0
121951	121929	11104D	PARTICIPANT	\N	PRESENT	0
122747	122737	07024N	PARTICIPANT	\N	EXCUSE	0
122748	122737	14014Q	PARTICIPANT	\N	PRESENT	0
122749	122737	07004J	PARTICIPANT	\N	EXCUSE	0
121955	121929	11090Q	PARTICIPANT	\N	PRESENT	0
121956	121929	14235Q	PARTICIPANT	\N	PRESENT	0
122750	122737	95035G	PARTICIPANT	\N	PRESENT	0
121958	121929	11046L	PARTICIPANT	\N	PRESENT	0
121959	121929	01028R	PARTICIPANT	\N	PRESENT	0
121960	121929	11094U	PARTICIPANT	\N	PRESENT	0
122751	122737	08056B	PARTICIPANT	\N	EXCUSE	0
121962	121929	14157T	PARTICIPANT	\N	PRESENT	0
122752	122737	98022P	PARTICIPANT	\N	PRESENT	0
121964	121929	11066Q	PARTICIPANT	\N	PRESENT	0
121965	121929	14269B	PARTICIPANT	\N	PRESENT	0
122753	122737	11064N	PARTICIPANT	\N	PRESENT	0
122754	122737	14097Y	PARTICIPANT	\N	PRESENT	0
122755	122737	95041E	PARTICIPANT	\N	EXCUSE	0
122756	122737	04036E	PARTICIPANT	\N	PRESENT	0
122757	122737	92031P	PARTICIPANT	\N	PRESENT	0
122759	122737	11106F	PARTICIPANT	\N	PRESENT	0
122760	122737	14251Q	PARTICIPANT	\N	PRESENT	0
122761	122737	83042R	PARTICIPANT	\N	PRESENT	0
122762	122737	08053X	PARTICIPANT	\N	PRESENT	0
122763	122737	11105E	PARTICIPANT	\N	PRESENT	0
122764	122737	14253S	PARTICIPANT	\N	PRESENT	0
122766	122737	08047A	PARTICIPANT	\N	PRESENT	0
122767	122737	14028W	PARTICIPANT	\N	PRESENT	0
122769	122737	14193X	PARTICIPANT	\N	PRESENT	0
122771	122737	98021N	PARTICIPANT	\N	PRESENT	0
122773	122737	95059Q	PRESIDENT	0	PRESENT	0
122774	122737	01014K	PARTICIPANT	\N	PRESENT	0
122775	122737	11054L	PARTICIPANT	\N	PRESENT	0
122777	122737	01056V	PARTICIPANT	\N	PRESENT	0
122778	122737	92044U	PARTICIPANT	\N	PRESENT	0
122779	122737	04050C	PARTICIPANT	\N	PRESENT	0
122974	122971	01031L	PRESIDENT	0	PRESENT	0
122975	122971	01013J	PARTICIPANT	\N	PRESENT	0
122976	122971	11068S	PARTICIPANT	\N	PRESENT	0
122977	122971	08014Q	PARTICIPANT	\N	PRESENT	0
122978	122971	14175V	PARTICIPANT	\N	EXCUSE	0
122979	122971	14083S	PARTICIPANT	\N	PRESENT	0
122982	122971	11053K	PARTICIPANT	\N	PRESENT	0
122983	122971	11042G	PARTICIPANT	\N	PRESENT	0
122984	122971	88008L	PARTICIPANT	\N	PRESENT	0
122985	122971	04086Q	PARTICIPANT	\N	PRESENT	0
122986	122971	04055H	PARTICIPANT	\N	PRESENT	0
122987	122971	11088W	PARTICIPANT	\N	PRESENT	0
122988	122971	14327T	PARTICIPANT	\N	PRESENT	0
122989	122971	08022Q	PARTICIPANT	\N	PRESENT	0
122990	122971	01027Q	PARTICIPANT	\N	PRESENT	0
122991	122971	04071H	PARTICIPANT	\N	PRESENT	0
122992	122971	98053W	PARTICIPANT	\N	EXCUSE	0
122993	122971	11083R	PARTICIPANT	\N	PRESENT	0
122994	122971	14199E	PARTICIPANT	\N	PRESENT	0
122995	122971	01057W	PARTICIPANT	\N	PRESENT	0
122996	122971	08016S	PARTICIPANT	\N	EXCUSE	0
122997	122971	08069G	PARTICIPANT	\N	PRESENT	0
122998	122971	11048N	PARTICIPANT	\N	PRESENT	0
122999	122971	99004R	PARTICIPANT	\N	PRESENT	0
123000	122971	04061F	PARTICIPANT	\N	PRESENT	0
123001	122971	14159V	PARTICIPANT	\N	PRESENT	0
123002	122971	07029T	PARTICIPANT	\N	PRESENT	0
123003	122971	14277B	PARTICIPANT	\N	PRESENT	0
123004	122971	08010L	PARTICIPANT	\N	PRESENT	0
123005	122971	08034U	PARTICIPANT	\N	PRESENT	0
123006	122971	98046X	PARTICIPANT	\N	PRESENT	0
123007	122971	11085T	PARTICIPANT	\N	EXCUSE	0
123008	122971	08011M	PARTICIPANT	\N	PRESENT	0
123009	122971	08073C	PARTICIPANT	\N	EXCUSE	0
123010	122971	08061X	PARTICIPANT	\N	EXCUSE	0
123011	122971	01016M	PARTICIPANT	\N	PRESENT	0
123012	122971	14225N	PARTICIPANT	\N	PRESENT	0
123013	122971	11012A	PARTICIPANT	\N	PRESENT	0
123014	122971	11057P	PARTICIPANT	\N	PRESENT	0
123015	122971	14173T	PARTICIPANT	\N	PRESENT	0
123016	122971	04034C	PARTICIPANT	\N	PRESENT	0
123017	122971	11072N	RAPPORTEUR_AVIS	\N	PRESENT	0
123018	122971	11040E	PARTICIPANT	\N	PRESENT	0
123474	120697	95062K	PARTICIPANT	\N	EXCUSE	0
123853	123852	08014Q	PARTICIPANT	\N	PRESENT	0
123854	123852	08069G	PARTICIPANT	\N	PRESENT	0
124107	124106	11090Q	PARTICIPANT	\N	PRESENT	0
124277	124276	11055M	PARTICIPANT	\N	PRESENT	0
124281	124276	08024S	PARTICIPANT	\N	PRESENT	0
92769	92217	14225N	PARTICIPANT	\N	PRESENT	0
92770	92217	95041E	PARTICIPANT	\N	PRESENT	0
92771	92217	14159V	PARTICIPANT	\N	PRESENT	0
92772	92217	14269B	PARTICIPANT	\N	PRESENT	0
92773	92217	01014K	PARTICIPANT	\N	PRESENT	0
92774	92217	11107G	PARTICIPANT	\N	PRESENT	0
92775	92217	14037X	PARTICIPANT	\N	PRESENT	0
92776	92217	04094Q	PARTICIPANT	\N	PRESENT	0
92777	92217	14273W	PARTICIPANT	\N	PRESENT	0
92778	92217	14039A	PARTICIPANT	\N	PRESENT	0
92779	92217	08073C	PARTICIPANT	\N	PRESENT	0
92780	92217	11113E	PARTICIPANT	\N	PRESENT	0
92781	92217	12042Y	PARTICIPANT	\N	PRESENT	0
92782	92217	01034P	PARTICIPANT	\N	PRESENT	0
92783	92217	11094U	PARTICIPANT	\N	PRESENT	0
92784	92217	14331P	PARTICIPANT	\N	PRESENT	0
92785	92217	11064N	PARTICIPANT	\N	PRESENT	0
92786	92217	11053K	PARTICIPANT	\N	PRESENT	0
92787	92217	14217N	PARTICIPANT	\N	PRESENT	0
92788	92217	14249W	PARTICIPANT	\N	PRESENT	0
92789	92217	04080J	PARTICIPANT	\N	PRESENT	0
92790	92217	14034U	PARTICIPANT	\N	PRESENT	0
92791	92217	04038G	PARTICIPANT	\N	PRESENT	0
92792	92217	11085T	PARTICIPANT	\N	PRESENT	0
92793	92217	08042U	PARTICIPANT	\N	PRESENT	0
92794	92217	14042U	PARTICIPANT	\N	PRESENT	0
92795	92217	14219Q	PARTICIPANT	\N	PRESENT	0
92796	92217	08048B	PARTICIPANT	\N	PRESENT	0
92797	92217	14267Y	PARTICIPANT	\N	PRESENT	0
92798	92217	14030Q	PARTICIPANT	\N	PRESENT	0
92799	92217	04061F	PARTICIPANT	\N	PRESENT	0
92800	92217	14073Q	PARTICIPANT	\N	PRESENT	0
92801	92217	11030C	PARTICIPANT	\N	PRESENT	0
92802	92217	01007L	PARTICIPANT	\N	PRESENT	0
92803	92217	14327T	PARTICIPANT	\N	PRESENT	0
92804	92217	01024M	PARTICIPANT	\N	PRESENT	0
92805	92217	01025N	PARTICIPANT	\N	PRESENT	0
92806	92217	14105F	PARTICIPANT	\N	PRESENT	0
92807	92217	04040A	PARTICIPANT	\N	PRESENT	0
92808	92217	08056B	PARTICIPANT	\N	PRESENT	0
92809	92217	01047U	PARTICIPANT	\N	PRESENT	0
92810	92217	98024R	PARTICIPANT	\N	PRESENT	0
92811	92217	04070G	PARTICIPANT	\N	PRESENT	0
92812	92217	08044W	PARTICIPANT	\N	PRESENT	0
92813	92217	14255U	PARTICIPANT	\N	PRESENT	0
92814	92217	07004J	PARTICIPANT	\N	PRESENT	0
92815	92217	98042T	PARTICIPANT	\N	PRESENT	0
92816	92217	14179A	PARTICIPANT	\N	PRESENT	0
92817	92217	14231L	PARTICIPANT	\N	PRESENT	0
92818	92217	11093T	PARTICIPANT	\N	PRESENT	0
92819	92217	14089Y	PARTICIPANT	\N	PRESENT	0
92820	92217	11111C	PARTICIPANT	\N	PRESENT	0
92821	92217	14275Y	PARTICIPANT	\N	PRESENT	0
92822	92217	14277B	PARTICIPANT	\N	PRESENT	0
92823	92217	08062Y	PARTICIPANT	\N	PRESENT	0
92824	92217	11076S	PARTICIPANT	\N	PRESENT	0
92825	92217	14093U	PARTICIPANT	\N	PRESENT	0
92826	92217	09001P	PARTICIPANT	\N	PRESENT	0
92827	92217	14087W	PARTICIPANT	\N	PRESENT	0
92828	92217	14199E	PARTICIPANT	\N	PRESENT	0
92829	92217	11082Q	PARTICIPANT	\N	PRESENT	0
92830	92217	14237S	PARTICIPANT	\N	PRESENT	0
92831	92217	14205J	PARTICIPANT	\N	PRESENT	0
92832	92217	14213J	PARTICIPANT	\N	PRESENT	0
92833	92217	98021N	PARTICIPANT	\N	PRESENT	0
92834	92217	08039A	PARTICIPANT	\N	PRESENT	0
92835	92217	11048N	PARTICIPANT	\N	PRESENT	0
92836	92217	11063M	PARTICIPANT	\N	PRESENT	0
92837	92217	01041N	PARTICIPANT	\N	PRESENT	0
92838	92217	11056N	PARTICIPANT	\N	PRESENT	0
92839	92217	04043D	PARTICIPANT	\N	PRESENT	0
92841	92217	01043Q	PARTICIPANT	\N	PRESENT	0
92860	92217	01028R	PARTICIPANT	\N	PRESENT	0
92861	92217	98018T	PARTICIPANT	\N	PRESENT	0
92862	92217	11065P	PARTICIPANT	\N	PRESENT	0
92863	92217	11068S	PARTICIPANT	\N	PRESENT	0
92864	92217	11026G	PARTICIPANT	\N	PRESENT	0
93153	92219	89029V	PARTICIPANT	\N	PRESENT	0
93154	92219	01048V	PARTICIPANT	\N	PRESENT	0
93155	92219	14135M	PARTICIPANT	\N	PRESENT	0
93156	92219	14013P	PARTICIPANT	\N	PRESENT	0
93157	92219	11098Y	PARTICIPANT	\N	PRESENT	0
93158	92219	14167V	PARTICIPANT	\N	PRESENT	0
93159	92219	08024S	PARTICIPANT	\N	PRESENT	0
93160	92219	14097Y	PARTICIPANT	\N	PRESENT	0
93161	92219	11077T	PARTICIPANT	\N	PRESENT	0
93187	92219	01060R	PARTICIPANT	\N	PRESENT	0
93163	92219	08069G	PARTICIPANT	\N	PRESENT	0
93164	92219	07029T	PARTICIPANT	\N	PRESENT	0
93165	92219	14014Q	PARTICIPANT	\N	PRESENT	0
93166	92219	08042U	PARTICIPANT	\N	PRESENT	0
93167	92219	11082Q	PARTICIPANT	\N	PRESENT	0
93168	92219	01024M	PARTICIPANT	\N	PRESENT	0
93169	92219	14205J	PARTICIPANT	\N	PRESENT	0
93170	92219	11059R	PARTICIPANT	\N	PRESENT	0
93171	92219	11026G	PARTICIPANT	\N	PRESENT	0
93172	92219	11068S	PARTICIPANT	\N	PRESENT	0
93173	92219	14089Y	PARTICIPANT	\N	PRESENT	0
93174	92219	14219Q	PARTICIPANT	\N	PRESENT	0
93175	92219	11065P	PARTICIPANT	\N	PRESENT	0
93176	92219	14209N	PARTICIPANT	\N	PRESENT	0
93177	92219	14179A	PARTICIPANT	\N	PRESENT	0
93178	92219	14263U	PARTICIPANT	\N	PRESENT	0
93179	92219	14241N	PARTICIPANT	\N	PRESENT	0
93180	92219	11100Y	PARTICIPANT	\N	PRESENT	0
93181	92219	97011G	PARTICIPANT	\N	PRESENT	0
93182	92219	14261S	PARTICIPANT	\N	PRESENT	0
93183	92219	95062K	PARTICIPANT	\N	PRESENT	0
93184	92219	14173T	PARTICIPANT	\N	PRESENT	0
93185	92219	11036J	PARTICIPANT	\N	PRESENT	0
93186	92219	14105F	PARTICIPANT	\N	PRESENT	0
93188	92219	80013X	PARTICIPANT	\N	PRESENT	0
93189	92219	08068F	PARTICIPANT	\N	PRESENT	0
93190	92219	14107H	PARTICIPANT	\N	PRESENT	0
93191	92219	14051J	PARTICIPANT	\N	PRESENT	0
93192	92219	11107G	PARTICIPANT	\N	PRESENT	0
93208	92219	14157T	PARTICIPANT	\N	PRESENT	0
93194	92219	05012A	PARTICIPANT	\N	PRESENT	0
93195	92219	04088S	PARTICIPANT	\N	PRESENT	0
93196	92219	01022K	PARTICIPANT	\N	PRESENT	0
93197	92219	01058X	PARTICIPANT	\N	PRESENT	0
93198	92219	98050T	PARTICIPANT	\N	PRESENT	0
93199	92219	14257W	PARTICIPANT	\N	PRESENT	0
93200	92219	11056N	PARTICIPANT	\N	PRESENT	0
93201	92219	01015L	PARTICIPANT	\N	PRESENT	0
93202	92219	08055A	PARTICIPANT	\N	PRESENT	0
93203	92219	08051V	PARTICIPANT	\N	PRESENT	0
93204	92219	11048N	PARTICIPANT	\N	PRESENT	0
93205	92219	14073Q	PARTICIPANT	\N	PRESENT	0
93206	92219	95067Q	PARTICIPANT	\N	PRESENT	0
93207	92219	14038Y	PARTICIPANT	\N	PRESENT	0
93209	92219	08031R	PARTICIPANT	\N	PRESENT	0
93210	92219	88008L	PARTICIPANT	\N	PRESENT	0
93211	92219	04066L	PARTICIPANT	\N	PRESENT	0
93212	92219	14235Q	PARTICIPANT	\N	PRESENT	0
93213	92219	08015R	PARTICIPANT	\N	PRESENT	0
93214	92219	01057W	PARTICIPANT	\N	PRESENT	0
93215	92219	14159V	PARTICIPANT	\N	PRESENT	0
93216	92219	14327T	PARTICIPANT	\N	PRESENT	0
93217	92219	14197C	PARTICIPANT	\N	PRESENT	0
93218	92219	14331P	PARTICIPANT	\N	PRESENT	0
93219	92219	08034U	PARTICIPANT	\N	PRESENT	0
93220	92219	01008M	PARTICIPANT	\N	PRESENT	0
93221	92219	14199E	PARTICIPANT	\N	PRESENT	0
93222	92219	11012A	PARTICIPANT	\N	PRESENT	0
93223	92219	14033T	PARTICIPANT	\N	PRESENT	0
93224	92219	01025N	PARTICIPANT	\N	PRESENT	0
93821	89552	14207L	PARTICIPANT	\N	PRESENT	0
93822	89556	14253S	PARTICIPANT	\N	PRESENT	0
93823	89556	04049K	PARTICIPANT	\N	PRESENT	0
93824	89556	04053F	PARTICIPANT	\N	PRESENT	0
93825	89556	14083S	PARTICIPANT	\N	PRESENT	0
93826	89556	14121F	PARTICIPANT	\N	PRESENT	0
93827	89556	14034U	PARTICIPANT	\N	PRESENT	0
93828	89556	14195A	PARTICIPANT	\N	PRESENT	0
93829	89558	14253S	PARTICIPANT	\N	PRESENT	0
93830	89558	04053F	PARTICIPANT	\N	PRESENT	0
93831	89558	04049K	PARTICIPANT	\N	PRESENT	0
93832	89558	14121F	PARTICIPANT	\N	PRESENT	0
93833	89558	14083S	PARTICIPANT	\N	PRESENT	0
93834	89558	14195A	PARTICIPANT	\N	PRESENT	0
93835	89558	14034U	PARTICIPANT	\N	PRESENT	0
93836	89559	14253S	PARTICIPANT	\N	PRESENT	0
93837	89559	04053F	PARTICIPANT	\N	PRESENT	0
93838	89559	04049K	PARTICIPANT	\N	PRESENT	0
93839	89559	14121F	PARTICIPANT	\N	PRESENT	0
93840	89559	14083S	PARTICIPANT	\N	PRESENT	0
93841	89559	14195A	PARTICIPANT	\N	PRESENT	0
110430	110252	11026G	PARTICIPANT	\N	PRESENT	0
110431	110252	14031R	PARTICIPANT	\N	PRESENT	0
110432	110252	14259Y	PARTICIPANT	\N	PRESENT	0
110433	110252	14229S	PARTICIPANT	\N	PRESENT	0
110434	110252	04042C	PARTICIPANT	\N	PRESENT	0
110435	110252	11042G	PARTICIPANT	\N	PRESENT	0
110436	110252	98023Q	PARTICIPANT	\N	PRESENT	0
110437	110252	11020A	PARTICIPANT	\N	PRESENT	0
110438	110252	11046L	PARTICIPANT	\N	PRESENT	0
110439	110252	11014C	PARTICIPANT	\N	PRESENT	0
110440	110252	14195A	PARTICIPANT	\N	PRESENT	0
110441	110252	01028R	PARTICIPANT	\N	PRESENT	0
110442	110252	11049P	PARTICIPANT	\N	PRESENT	0
110443	110252	14109K	PARTICIPANT	\N	PRESENT	0
110444	110252	08047A	PARTICIPANT	\N	PRESENT	0
110445	110252	11039M	PARTICIPANT	\N	PRESENT	0
110446	110252	04044E	PARTICIPANT	\N	PRESENT	0
110447	110252	04085P	PARTICIPANT	\N	PRESENT	0
110448	110252	14147R	PARTICIPANT	\N	PRESENT	0
110449	110252	01013J	PARTICIPANT	\N	PRESENT	0
110450	110252	92018S	PARTICIPANT	\N	PRESENT	0
110451	110252	14119M	PARTICIPANT	\N	PRESENT	0
110452	110252	11034G	PARTICIPANT	\N	PRESENT	0
110453	110252	07026Q	PARTICIPANT	\N	PRESENT	0
110454	110252	04057K	PARTICIPANT	\N	PRESENT	0
110455	110252	12041X	PARTICIPANT	\N	PRESENT	0
110456	110252	04050C	PARTICIPANT	\N	PRESENT	0
110457	110252	11040E	PARTICIPANT	\N	PRESENT	0
110458	110252	14157T	PARTICIPANT	\N	PRESENT	0
110459	110252	14263U	PARTICIPANT	\N	PRESENT	0
110460	110252	08035V	PARTICIPANT	\N	PRESENT	0
110461	110252	11057P	PARTICIPANT	\N	PRESENT	0
110462	110252	11033F	PARTICIPANT	\N	PRESENT	0
110463	110252	04074L	PARTICIPANT	\N	PRESENT	0
110464	110252	14281W	PARTICIPANT	\N	PRESENT	0
110465	110252	08034U	PARTICIPANT	\N	PRESENT	0
110472	110252	11012A	PARTICIPANT	\N	PRESENT	0
110467	110252	08051V	PARTICIPANT	\N	PRESENT	0
110468	110252	01046T	PARTICIPANT	\N	PRESENT	0
110469	110252	95062K	PARTICIPANT	\N	PRESENT	0
110470	110252	14261S	PARTICIPANT	\N	PRESENT	0
110471	110252	04047H	PARTICIPANT	\N	PRESENT	0
110473	110252	08049C	PARTICIPANT	\N	PRESENT	0
110474	110252	01003G	PARTICIPANT	\N	PRESENT	0
110475	110252	04038G	PARTICIPANT	\N	PRESENT	0
110476	110252	04086Q	PARTICIPANT	\N	PRESENT	0
110477	110252	14201E	PARTICIPANT	\N	PRESENT	0
110478	110252	04033B	PARTICIPANT	\N	PRESENT	0
110479	110252	11081P	PARTICIPANT	\N	PRESENT	0
110480	110252	98022P	PARTICIPANT	\N	PRESENT	0
110481	110252	14026U	PARTICIPANT	\N	PRESENT	0
110482	110252	14239U	PARTICIPANT	\N	PRESENT	0
110483	110252	04078Q	PARTICIPANT	\N	PRESENT	0
110484	110252	14071N	PARTICIPANT	\N	PRESENT	0
110485	110252	05004A	PARTICIPANT	\N	PRESENT	0
110486	110252	11096W	PARTICIPANT	\N	PRESENT	0
110487	110252	88008L	PARTICIPANT	\N	PRESENT	0
110488	110252	14331P	PARTICIPANT	\N	PRESENT	0
110489	110252	92015P	PARTICIPANT	\N	PRESENT	0
110490	110252	98018T	PARTICIPANT	\N	PRESENT	0
110491	110252	14265W	PARTICIPANT	\N	PRESENT	0
110492	110252	11048N	PARTICIPANT	\N	PRESENT	0
110493	110252	04081K	PARTICIPANT	\N	PRESENT	0
110494	110252	11043H	PARTICIPANT	\N	PRESENT	0
110495	110252	10006L	PARTICIPANT	\N	PRESENT	0
110496	110252	08048B	PARTICIPANT	\N	PRESENT	0
110497	110252	11077T	PARTICIPANT	\N	PRESENT	0
110498	110252	14111D	PARTICIPANT	\N	PRESENT	0
110499	110252	08012N	PARTICIPANT	\N	PRESENT	0
110500	110252	95015C	PARTICIPANT	\N	PRESENT	0
110501	110252	08041T	PARTICIPANT	\N	PRESENT	0
110502	110252	08058D	PARTICIPANT	\N	PRESENT	0
110503	110252	86044G	PARTICIPANT	\N	PRESENT	0
110504	110252	95059Q	PARTICIPANT	\N	PRESENT	0
110505	110252	96004D	PARTICIPANT	\N	PRESENT	0
110506	110252	14107H	PARTICIPANT	\N	PRESENT	0
110507	110252	04045F	PARTICIPANT	\N	PRESENT	0
110508	110252	01014K	PARTICIPANT	\N	PRESENT	0
110509	110252	14253S	PARTICIPANT	\N	PRESENT	0
110510	110252	14033T	PARTICIPANT	\N	PRESENT	0
110511	110252	14133K	PARTICIPANT	\N	PRESENT	0
110512	110252	14175V	PARTICIPANT	\N	PRESENT	0
110513	110252	14329V	PARTICIPANT	\N	PRESENT	0
110514	110252	08019V	PARTICIPANT	\N	PRESENT	0
110515	110252	08061X	PARTICIPANT	\N	PRESENT	0
110516	110252	11088W	PARTICIPANT	\N	PRESENT	0
110517	110252	08024S	PARTICIPANT	\N	PRESENT	0
110518	110252	04088S	PARTICIPANT	\N	PRESENT	0
110519	110252	01037S	PARTICIPANT	\N	PRESENT	0
110520	110252	14135M	PARTICIPANT	\N	PRESENT	0
110521	110252	14151M	PARTICIPANT	\N	PRESENT	0
110522	110252	11071M	PARTICIPANT	\N	PRESENT	0
110523	110252	12042Y	PARTICIPANT	\N	PRESENT	0
110524	110252	92040Q	PARTICIPANT	\N	PRESENT	0
110525	110252	07029T	PARTICIPANT	\N	PRESENT	0
110526	110252	14207L	PARTICIPANT	\N	PRESENT	0
110527	110252	98050T	PARTICIPANT	\N	PRESENT	0
110528	110252	95035G	PARTICIPANT	\N	PRESENT	0
110529	110252	08038Y	PARTICIPANT	\N	PRESENT	0
110530	110252	11097X	PARTICIPANT	\N	PRESENT	0
110531	110252	05008E	PARTICIPANT	\N	PRESENT	0
110532	110252	11061K	PARTICIPANT	\N	PRESENT	0
110533	110252	01008M	PARTICIPANT	\N	PRESENT	0
110534	110252	11098Y	PARTICIPANT	\N	PRESENT	0
110535	110252	14013P	PARTICIPANT	\N	PRESENT	0
110536	110252	11031D	PARTICIPANT	\N	PRESENT	0
110537	110252	04043D	PARTICIPANT	\N	PRESENT	0
110538	110252	14215L	PARTICIPANT	\N	PRESENT	0
110539	110252	14087W	PARTICIPANT	\N	PRESENT	0
110540	110252	04048J	PARTICIPANT	\N	PRESENT	0
110541	110252	11103C	PARTICIPANT	\N	PRESENT	0
110542	110252	07024N	PARTICIPANT	\N	PRESENT	0
110543	110252	04059M	PARTICIPANT	\N	PRESENT	0
110544	110252	11056N	PARTICIPANT	\N	PRESENT	0
110545	110252	08069G	PARTICIPANT	\N	PRESENT	0
110546	110252	11110B	PARTICIPANT	\N	PRESENT	0
110547	110252	01041N	PARTICIPANT	\N	PRESENT	0
110549	110252	14249W	PARTICIPANT	\N	PRESENT	0
110551	110252	14053L	PARTICIPANT	\N	PRESENT	0
110552	110252	11090Q	PARTICIPANT	\N	PRESENT	0
110553	110252	04092N	PARTICIPANT	\N	PRESENT	0
110554	110252	11091R	PARTICIPANT	\N	PRESENT	0
110555	110548	11029K	PARTICIPANT	\N	PRESENT	0
110556	110252	14061L	PARTICIPANT	\N	PRESENT	0
110557	110548	01025N	PARTICIPANT	\N	PRESENT	0
110558	110548	14061L	PARTICIPANT	\N	PRESENT	0
110559	110548	14073Q	PARTICIPANT	\N	PRESENT	0
110560	110252	14209N	PARTICIPANT	\N	PRESENT	0
110561	110548	14059S	PARTICIPANT	\N	PRESENT	0
110562	110252	14059S	PARTICIPANT	\N	PRESENT	0
110563	110548	11104D	PARTICIPANT	\N	PRESENT	0
110564	110252	14037X	PARTICIPANT	\N	PRESENT	0
110565	110252	14269B	PARTICIPANT	\N	PRESENT	0
110566	110252	11107G	PARTICIPANT	\N	PRESENT	0
110567	110252	08065C	PARTICIPANT	\N	PRESENT	0
110568	110252	14213J	PARTICIPANT	\N	PRESENT	0
110569	110252	14187A	PARTICIPANT	\N	PRESENT	0
110570	110252	14030Q	PARTICIPANT	\N	PRESENT	0
110571	110252	14079W	PARTICIPANT	\N	PRESENT	0
110572	110252	14221J	PARTICIPANT	\N	PRESENT	0
110573	110252	14267Y	PARTICIPANT	\N	PRESENT	0
110574	110252	14273W	PARTICIPANT	\N	PRESENT	0
110575	110252	14257W	PARTICIPANT	\N	PRESENT	0
110576	110252	95049N	PARTICIPANT	\N	PRESENT	0
110577	110252	11027H	PARTICIPANT	\N	PRESENT	0
110578	110252	01043Q	PARTICIPANT	\N	PRESENT	0
110579	110252	01007L	PARTICIPANT	\N	PRESENT	0
110580	110252	14327T	PARTICIPANT	\N	PRESENT	0
110581	110252	09001P	PARTICIPANT	\N	PRESENT	0
110582	110252	01025N	PARTICIPANT	\N	PRESENT	0
110583	110252	11094U	PARTICIPANT	\N	PRESENT	0
110584	110252	04040A	PARTICIPANT	\N	PRESENT	0
110585	110252	01024M	PARTICIPANT	\N	PRESENT	0
110586	110252	08056B	PARTICIPANT	\N	PRESENT	0
110587	110252	07004J	PARTICIPANT	\N	PRESENT	0
110588	110252	01047U	PARTICIPANT	\N	PRESENT	0
110589	110252	04070G	PARTICIPANT	\N	PRESENT	0
110590	110252	08044W	PARTICIPANT	\N	PRESENT	0
110591	110252	14255U	PARTICIPANT	\N	PRESENT	0
110592	110252	11085T	PARTICIPANT	\N	PRESENT	0
110593	110252	14205J	PARTICIPANT	\N	PRESENT	0
110594	110252	14179A	PARTICIPANT	\N	PRESENT	0
110595	110252	98042T	PARTICIPANT	\N	PRESENT	0
110596	110252	14219Q	PARTICIPANT	\N	PRESENT	0
110597	110252	14103D	PARTICIPANT	\N	PRESENT	0
110598	110252	11093T	PARTICIPANT	\N	PRESENT	0
110599	110252	14231L	PARTICIPANT	\N	PRESENT	0
110600	110252	14083S	PARTICIPANT	\N	PRESENT	0
115592	114772	11085T	PARTICIPANT	\N	PRESENT	0
115593	114772	05008E	PARTICIPANT	\N	PRESENT	0
115594	114772	07034Q	PARTICIPANT	\N	PRESENT	0
115595	114772	01013J	PARTICIPANT	\N	PRESENT	0
115596	114772	04034C	PARTICIPANT	\N	PRESENT	0
115597	114772	01031L	PARTICIPANT	\N	PRESENT	0
115598	114772	11053K	PARTICIPANT	\N	PRESENT	0
115599	114772	14041T	PARTICIPANT	\N	PRESENT	0
115600	114772	98053W	PARTICIPANT	\N	PRESENT	0
115612	114772	08019V	PARTICIPANT	\N	PRESENT	0
115613	114772	14033T	PARTICIPANT	\N	PRESENT	0
115614	114772	01041N	PARTICIPANT	\N	PRESENT	0
115615	114772	11083R	PARTICIPANT	\N	PRESENT	0
115616	114772	08011M	PARTICIPANT	\N	PRESENT	0
115617	114772	04038G	PARTICIPANT	\N	PRESENT	0
115632	114772	11077T	PARTICIPANT	\N	PRESENT	0
115633	114772	14175V	PARTICIPANT	\N	PRESENT	0
115634	114772	04086Q	PARTICIPANT	\N	PRESENT	0
115635	114772	01016M	PARTICIPANT	\N	PRESENT	0
115636	114772	98046X	PARTICIPANT	\N	PRESENT	0
115637	114772	11057P	PARTICIPANT	\N	PRESENT	0
115652	114772	01028R	PARTICIPANT	\N	PRESENT	0
115672	114808	04066L	PARTICIPANT	\N	PRESENT	0
115673	114808	98046X	PARTICIPANT	\N	PRESENT	0
115674	114808	11070L	PARTICIPANT	\N	PRESENT	0
115675	114808	14175V	PARTICIPANT	\N	PRESENT	0
115676	114808	04034C	PARTICIPANT	\N	PRESENT	0
115677	114808	11057P	PARTICIPANT	\N	PRESENT	0
115678	114808	01031L	PARTICIPANT	\N	PRESENT	0
115679	114808	07034Q	PARTICIPANT	\N	PRESENT	0
115680	114808	14033T	PARTICIPANT	\N	PRESENT	0
115681	114808	04085P	PARTICIPANT	\N	PRESENT	0
115682	114808	08011M	PARTICIPANT	\N	PRESENT	0
115683	114808	11083R	PARTICIPANT	\N	PRESENT	0
115685	115684	14237S	PARTICIPANT	\N	PRESENT	0
115686	114808	01016M	PARTICIPANT	\N	PRESENT	0
115712	114808	04050C	PARTICIPANT	\N	PRESENT	0
115732	114808	01041N	PARTICIPANT	\N	PRESENT	0
115777	114808	99004R	PARTICIPANT	\N	PRESENT	0
115913	115912	11029K	PARTICIPANT	\N	PRESENT	0
115914	115912	11091R	PARTICIPANT	\N	PRESENT	0
115915	115912	14249W	PARTICIPANT	\N	PRESENT	0
115916	115912	07026Q	PARTICIPANT	\N	PRESENT	0
115917	115912	04070G	PARTICIPANT	\N	PRESENT	0
115918	115912	92040Q	PARTICIPANT	\N	PRESENT	0
115919	115912	14061L	PARTICIPANT	\N	PRESENT	0
115920	115912	14059S	PARTICIPANT	\N	PRESENT	0
115933	115932	14107H	PARTICIPANT	\N	PRESENT	0
115934	115932	01008M	PARTICIPANT	\N	PRESENT	0
115935	115932	14038Y	PARTICIPANT	\N	PRESENT	0
115936	115932	14195A	PARTICIPANT	\N	PRESENT	0
115937	115932	14265W	PARTICIPANT	\N	PRESENT	0
115938	115932	14014Q	PARTICIPANT	\N	PRESENT	0
115939	115932	14207L	PARTICIPANT	\N	PRESENT	0
115954	115953	14199E	PARTICIPANT	\N	PRESENT	0
115956	115955	14199E	PARTICIPANT	\N	PRESENT	0
115973	115972	08055A	PARTICIPANT	\N	PRESENT	0
115974	115972	11091R	PARTICIPANT	\N	PRESENT	0
115975	115972	11056N	PARTICIPANT	\N	PRESENT	0
115976	115972	01041N	PARTICIPANT	\N	PRESENT	0
115977	115972	14026U	PARTICIPANT	\N	PRESENT	0
115978	115972	14179A	PARTICIPANT	\N	PRESENT	0
115979	115972	01061S	PARTICIPANT	\N	PRESENT	0
115980	115972	14119M	PARTICIPANT	\N	PRESENT	0
115981	115972	14265W	PARTICIPANT	\N	PRESENT	0
115982	115972	04045F	PARTICIPANT	\N	PRESENT	0
115983	115972	01056V	PARTICIPANT	\N	PRESENT	0
116013	116012	92031P	PARTICIPANT	\N	PRESENT	0
116014	116012	08017T	PARTICIPANT	\N	PRESENT	0
116016	116015	04054G	PARTICIPANT	\N	PRESENT	0
116073	116072	04042C	PARTICIPANT	\N	PRESENT	0
116074	116072	14028W	PARTICIPANT	\N	PRESENT	0
116075	116072	01056V	PARTICIPANT	\N	PRESENT	0
116076	116072	11082Q	PARTICIPANT	\N	PRESENT	0
116163	115814	01015L	PARTICIPANT	\N	PRESENT	0
116173	115814	11114F	PARTICIPANT	\N	PRESENT	0
116080	116077	14093U	PARTICIPANT	\N	PRESENT	0
116081	116077	14030Q	PARTICIPANT	\N	EXCUSE	0
116152	115814	08009T	PARTICIPANT	\N	PRESENT	0
116083	116077	08060W	PARTICIPANT	\N	PRESENT	0
116153	115814	14041T	PARTICIPANT	\N	PRESENT	0
116085	116077	14038Y	PARTICIPANT	\N	PRESENT	0
116086	116077	11114F	PARTICIPANT	\N	PRESENT	0
116154	115814	08060W	PARTICIPANT	\N	PRESENT	0
116088	116077	11065P	PARTICIPANT	\N	PRESENT	0
116089	116077	01015L	PARTICIPANT	\N	PRESENT	0
116090	116077	11107G	PARTICIPANT	\N	PRESENT	0
116155	115814	80027E	PARTICIPANT	\N	PRESENT	0
116156	115814	14051J	PARTICIPANT	\N	PRESENT	0
116093	116077	01022K	PARTICIPANT	\N	PRESENT	0
116157	115814	14107H	PARTICIPANT	\N	PRESENT	0
116095	116077	09001P	PARTICIPANT	\N	PRESENT	0
116158	115814	11107G	PARTICIPANT	\N	PRESENT	0
116159	115814	13002U	PARTICIPANT	\N	PRESENT	0
116098	116077	80027E	PARTICIPANT	\N	PRESENT	0
116160	115814	11012A	PARTICIPANT	\N	PRESENT	0
116100	116077	08009T	PRESIDENT	0	PRESENT	0
116101	116077	08062Y	PARTICIPANT	\N	EXCUSE	0
116161	115814	07024N	PARTICIPANT	\N	PRESENT	0
116162	115814	11103C	PARTICIPANT	\N	PRESENT	0
116172	115814	11091R	PARTICIPANT	\N	PRESENT	0
116192	115814	11065P	PARTICIPANT	\N	PRESENT	0
116193	115814	11036J	PARTICIPANT	\N	PRESENT	0
116107	116077	13002U	PARTICIPANT	\N	PRESENT	0
116212	115814	04085P	PARTICIPANT	\N	PRESENT	0
116214	116213	04059M	PARTICIPANT	\N	PRESENT	0
116215	116213	11084S	PARTICIPANT	\N	PRESENT	0
116232	115814	01022K	PARTICIPANT	\N	PRESENT	0
116112	116077	95062K	PARTICIPANT	\N	PRESENT	0
116272	115814	14093U	PARTICIPANT	\N	PRESENT	0
116292	115814	08016S	PARTICIPANT	\N	PRESENT	0
116305	115814	01041N	PARTICIPANT	\N	PRESENT	0
116309	115814	04043D	PARTICIPANT	\N	PRESENT	0
116312	115814	14219Q	PARTICIPANT	\N	PRESENT	0
116332	115814	08055A	PARTICIPANT	\N	PRESENT	0
116333	115814	01048V	PARTICIPANT	\N	PRESENT	0
116334	115814	95062K	PARTICIPANT	\N	PRESENT	0
116335	115814	11090Q	PARTICIPANT	\N	PRESENT	0
116352	115814	11100Y	PARTICIPANT	\N	PRESENT	0
116372	115814	14167V	PARTICIPANT	\N	PRESENT	0
116392	115814	92039X	PARTICIPANT	\N	PRESENT	0
116393	115814	98053W	PARTICIPANT	\N	PRESENT	0
116394	115814	11048N	PARTICIPANT	\N	PRESENT	0
116412	115814	01056V	PARTICIPANT	\N	PRESENT	0
116413	115814	08069G	PARTICIPANT	\N	PRESENT	0
116474	115815	80027E	PARTICIPANT	\N	PRESENT	0
116475	115815	01022K	PARTICIPANT	\N	PRESENT	0
116476	115815	11036J	PARTICIPANT	\N	PRESENT	0
116477	115815	08055A	PARTICIPANT	\N	PRESENT	0
116478	115815	11107G	PARTICIPANT	\N	PRESENT	0
116479	115815	13002U	PARTICIPANT	\N	PRESENT	0
116480	115815	11090Q	PARTICIPANT	\N	PRESENT	0
116481	115815	07024N	PARTICIPANT	\N	PRESENT	0
116482	115815	11012A	PARTICIPANT	\N	PRESENT	0
116483	115815	08009T	PARTICIPANT	\N	PRESENT	0
116484	115815	14093U	PARTICIPANT	\N	PRESENT	0
116492	115815	14219Q	PARTICIPANT	\N	PRESENT	0
116493	115815	08069G	PARTICIPANT	\N	PRESENT	0
116494	115815	95062K	PARTICIPANT	\N	PRESENT	0
116512	115815	14051J	PARTICIPANT	\N	PRESENT	0
116513	115815	14107H	PARTICIPANT	\N	PRESENT	0
116514	115815	92039X	PARTICIPANT	\N	PRESENT	0
116515	115815	96004D	PARTICIPANT	\N	PRESENT	0
116516	115815	14221J	PARTICIPANT	\N	PRESENT	0
116517	115815	14231L	PARTICIPANT	\N	PRESENT	0
116532	115815	92045V	PARTICIPANT	\N	PRESENT	0
116533	115815	14265W	PARTICIPANT	\N	PRESENT	0
116534	115815	05012A	PARTICIPANT	\N	PRESENT	0
116573	116572	14187A	PARTICIPANT	\N	PRESENT	0
116574	116572	11090Q	PARTICIPANT	\N	PRESENT	0
116575	116572	04086Q	PARTICIPANT	\N	PRESENT	0
116472	115815	98053W	PARTICIPANT	\N	PRESENT	0
116473	115815	01015L	PARTICIPANT	\N	PRESENT	0
116576	116572	04089T	PARTICIPANT	\N	PRESENT	0
116578	116577	14187A	PARTICIPANT	\N	PRESENT	0
116579	116577	11046L	PARTICIPANT	\N	PRESENT	0
116580	116577	04089T	PARTICIPANT	\N	PRESENT	0
116582	116581	08043V	PARTICIPANT	\N	PRESENT	0
116583	116581	14231L	PARTICIPANT	\N	PRESENT	0
116586	116585	08043V	PARTICIPANT	\N	PRESENT	0
116588	116585	14231L	PARTICIPANT	\N	PRESENT	0
116590	116589	14187A	PARTICIPANT	\N	PRESENT	0
116591	116589	04089T	PARTICIPANT	\N	PRESENT	0
116592	116589	11090Q	PARTICIPANT	\N	PRESENT	0
116613	116612	14187A	PARTICIPANT	\N	PRESENT	0
116614	116612	08031R	PARTICIPANT	\N	PRESENT	0
116616	116615	14231L	PARTICIPANT	\N	PRESENT	0
116617	116615	08031R	PARTICIPANT	\N	PRESENT	0
121553	121552	11039M	PARTICIPANT	\N	PRESENT	0
121554	121552	98042T	PARTICIPANT	\N	PRESENT	0
121555	121552	01019Q	PARTICIPANT	\N	PRESENT	0
121562	121559	04054G	PARTICIPANT	\N	PRESENT	0
121563	121559	11040E	PARTICIPANT	\N	PRESENT	0
121564	121559	96004D	PRESIDENT	0	PRESENT	0
121565	121559	14089Y	PARTICIPANT	\N	PRESENT	0
121566	121559	90003B	PARTICIPANT	\N	PRESENT	0
121567	121559	11035H	PARTICIPANT	\N	EXCUSE	0
121568	121559	08018U	PARTICIPANT	\N	EXCUSE	0
121569	121559	11083R	PARTICIPANT	\N	PRESENT	0
121570	121559	95037J	PARTICIPANT	\N	PRESENT	0
121571	121559	08044W	PARTICIPANT	\N	EXCUSE	0
121572	121559	14097Y	PARTICIPANT	\N	PRESENT	0
121573	121559	11026G	PARTICIPANT	\N	PRESENT	0
121574	121559	98046X	PARTICIPANT	\N	PRESENT	0
121575	121559	14001X	PARTICIPANT	\N	EXCUSE	0
121576	121559	04057K	PARTICIPANT	\N	PRESENT	0
121577	121559	14135M	PARTICIPANT	\N	PRESENT	0
121578	121559	01016M	PARTICIPANT	\N	PRESENT	0
121579	121559	11012A	PARTICIPANT	\N	EXCUSE	0
121580	121559	04045F	PARTICIPANT	\N	PRESENT	0
121581	121559	92045V	PARTICIPANT	\N	PRESENT	0
121582	121559	04034C	PARTICIPANT	\N	PRESENT	0
121585	121559	08042U	PARTICIPANT	\N	EXCUSE	0
121586	121559	01031L	PARTICIPANT	\N	PRESENT	0
121587	121559	08068F	PARTICIPANT	\N	PRESENT	0
121588	121559	11042G	PARTICIPANT	\N	PRESENT	0
121589	121559	08016S	PARTICIPANT	\N	PRESENT	0
121590	121559	08069G	PARTICIPANT	\N	PRESENT	0
121591	121559	11048N	PARTICIPANT	\N	PRESENT	0
121592	121559	14225N	PARTICIPANT	\N	PRESENT	0
124272	106052	11097X	PARTICIPANT	\N	PRESENT	0
124275	124155	08024S	PARTICIPANT	\N	PRESENT	0
124283	124276	04086Q	PARTICIPANT	\N	PRESENT	0
124434	124433	98023Q	PARTICIPANT	\N	PRESENT	0
124435	124433	92039X	PARTICIPANT	\N	PRESENT	0
124286	124276	14215L	PARTICIPANT	\N	PRESENT	0
124287	124276	04089T	PARTICIPANT	\N	PRESENT	0
124288	124276	14187A	PARTICIPANT	\N	PRESENT	0
124436	124433	08015R	PARTICIPANT	\N	PRESENT	0
124437	124433	04036E	PARTICIPANT	\N	PRESENT	0
124291	124276	14231L	PARTICIPANT	\N	PRESENT	0
124438	124433	04035D	PARTICIPANT	\N	PRESENT	0
124489	124488	04043D	PARTICIPANT	\N	PRESENT	0
124482	124155	98046X	PARTICIPANT	\N	PRESENT	0
124295	124276	11100Y	PRESIDENT	0	PRESENT	0
124483	124155	11105E	PARTICIPANT	\N	PRESENT	0
124491	124490	14259Y	PARTICIPANT	\N	PRESENT	0
124298	124276	11104D	PARTICIPANT	\N	PRESENT	0
124492	124490	04079R	PARTICIPANT	\N	PRESENT	0
124493	124490	95063L	PARTICIPANT	\N	PRESENT	0
124494	124490	11037K	PARTICIPANT	\N	PRESENT	0
124302	124276	11090Q	PARTICIPANT	\N	PRESENT	0
124496	124495	14259Y	PARTICIPANT	\N	PRESENT	0
124497	124495	11037K	PARTICIPANT	\N	PRESENT	0
124305	124276	11046L	PARTICIPANT	\N	PRESENT	0
124306	124276	01028R	PARTICIPANT	\N	PRESENT	0
124307	124276	11094U	PARTICIPANT	\N	PRESENT	0
124499	124498	04043D	PARTICIPANT	\N	PRESENT	0
124311	124276	11066Q	PARTICIPANT	\N	PRESENT	0
124503	124155	14121F	PARTICIPANT	\N	PRESENT	0
124505	124155	95067Q	PARTICIPANT	\N	PRESENT	0
124506	124155	04085P	PARTICIPANT	\N	PRESENT	0
124507	124155	04048J	PARTICIPANT	\N	PRESENT	0
124508	124155	11110B	PARTICIPANT	\N	PRESENT	0
124510	124509	04043D	PARTICIPANT	\N	PRESENT	0
124512	124155	01027Q	PARTICIPANT	\N	PRESENT	0
124513	124155	08055A	PARTICIPANT	\N	PRESENT	0
124514	124155	01028R	PARTICIPANT	\N	PRESENT	0
124515	124155	11054L	PARTICIPANT	\N	PRESENT	0
124516	124155	14157T	PARTICIPANT	\N	PRESENT	0
124517	124155	14207L	PARTICIPANT	\N	PRESENT	0
124518	124155	04050C	PARTICIPANT	\N	PRESENT	0
124519	124155	89017R	PARTICIPANT	\N	PRESENT	0
124524	124155	11064N	PARTICIPANT	\N	PRESENT	0
124522	124520	14215L	PARTICIPANT	\N	PRESENT	0
124523	124155	14030Q	PARTICIPANT	\N	PRESENT	0
124525	124155	14014Q	PARTICIPANT	\N	PRESENT	0
124527	124526	08031R	PARTICIPANT	\N	PRESENT	0
124528	124526	04070G	PARTICIPANT	\N	PRESENT	0
124529	124526	14123H	PARTICIPANT	\N	PRESENT	0
124530	124526	14073Q	PARTICIPANT	\N	PRESENT	0
124531	124526	14059S	PARTICIPANT	\N	PRESENT	0
124533	124532	04036E	PARTICIPANT	\N	PRESENT	0
124534	124532	11094U	PARTICIPANT	\N	PRESENT	0
124535	124155	11112D	PARTICIPANT	\N	PRESENT	0
124536	124155	98021N	PARTICIPANT	\N	PRESENT	0
124537	124155	11089X	PARTICIPANT	\N	PRESENT	0
124538	124155	01031L	PARTICIPANT	\N	PRESENT	0
124539	124155	11090Q	PARTICIPANT	\N	PRESENT	0
124636	124156	08055A	PARTICIPANT	\N	PRESENT	0
124637	124156	14197C	PARTICIPANT	\N	PRESENT	0
124638	124156	11046L	PARTICIPANT	\N	PRESENT	0
124639	124156	11104D	PARTICIPANT	\N	PRESENT	0
124640	124156	01028R	PARTICIPANT	\N	PRESENT	0
124641	124156	14231L	PARTICIPANT	\N	PRESENT	0
124642	124156	14187A	PARTICIPANT	\N	PRESENT	0
124643	124156	01044R	PARTICIPANT	\N	PRESENT	0
124644	124156	14030Q	PARTICIPANT	\N	PRESENT	0
124645	124156	14053L	PARTICIPANT	\N	PRESENT	0
124646	124156	14331P	PARTICIPANT	\N	PRESENT	0
124647	124156	04086Q	PARTICIPANT	\N	PRESENT	0
124648	124156	04045F	PARTICIPANT	\N	PRESENT	0
124649	124156	11034G	PARTICIPANT	\N	PRESENT	0
124650	124156	11098Y	PARTICIPANT	\N	PRESENT	0
124651	124156	11063M	PARTICIPANT	\N	PRESENT	0
124652	124156	08062Y	PARTICIPANT	\N	PRESENT	0
124653	124156	11043H	PARTICIPANT	\N	PRESENT	0
124654	124156	14147R	PARTICIPANT	\N	PRESENT	0
124655	124156	08010L	PARTICIPANT	\N	PRESENT	0
124656	124156	01043Q	PARTICIPANT	\N	PRESENT	0
124657	124156	80013X	PARTICIPANT	\N	PRESENT	0
124658	124156	04089T	PARTICIPANT	\N	PRESENT	0
124659	124156	14235Q	PARTICIPANT	\N	PRESENT	0
124660	124156	95049N	PARTICIPANT	\N	PRESENT	0
124661	124156	14081Q	PARTICIPANT	\N	PRESENT	0
124662	124156	95015C	PARTICIPANT	\N	PRESENT	0
124663	124156	11093T	PARTICIPANT	\N	PRESENT	0
124664	124156	14207L	PARTICIPANT	\N	PRESENT	0
124665	124156	11100Y	PARTICIPANT	\N	PRESENT	0
124666	124156	04050C	PARTICIPANT	\N	PRESENT	0
124667	124156	11048N	PARTICIPANT	\N	PRESENT	0
124668	124156	04038G	PARTICIPANT	\N	PRESENT	0
124669	124156	95041E	PARTICIPANT	\N	PRESENT	0
124670	124156	14159V	PARTICIPANT	\N	PRESENT	0
124671	124156	01047U	PARTICIPANT	\N	PRESENT	0
124672	124156	14089Y	PARTICIPANT	\N	PRESENT	0
124673	124156	14265W	PARTICIPANT	\N	PRESENT	0
124674	124156	14215L	PARTICIPANT	\N	PRESENT	0
124675	124156	14042U	PARTICIPANT	\N	PRESENT	0
124676	124156	11090Q	PARTICIPANT	\N	PRESENT	0
124677	124156	01025N	PARTICIPANT	\N	PRESENT	0
124678	124156	98046X	PARTICIPANT	\N	PRESENT	0
124679	124156	11094U	PARTICIPANT	\N	PRESENT	0
124680	124156	14033T	PARTICIPANT	\N	PRESENT	0
124681	124156	14026U	PARTICIPANT	\N	PRESENT	0
124682	124156	14195A	PARTICIPANT	\N	PRESENT	0
124683	124156	11077T	PARTICIPANT	\N	PRESENT	0
124684	124156	11061K	PARTICIPANT	\N	PRESENT	0
124685	124156	14105F	PARTICIPANT	\N	PRESENT	0
124686	124156	14071N	PARTICIPANT	\N	PRESENT	0
124687	124156	07029T	PARTICIPANT	\N	PRESENT	0
124688	124156	14083S	PARTICIPANT	\N	PRESENT	0
124689	124156	11012A	PARTICIPANT	\N	PRESENT	0
124690	124156	14069U	PARTICIPANT	\N	PRESENT	0
124691	124156	14271U	PARTICIPANT	\N	PRESENT	0
124692	124156	95063L	PARTICIPANT	\N	PRESENT	0
124693	124156	14031R	PARTICIPANT	\N	PRESENT	0
124694	124156	14217N	PARTICIPANT	\N	PRESENT	0
124695	124156	07032N	PARTICIPANT	\N	PRESENT	0
124696	124156	08015R	PARTICIPANT	\N	PRESENT	0
124697	124156	14014Q	PARTICIPANT	\N	PRESENT	0
124698	124156	14073Q	PARTICIPANT	\N	PRESENT	0
124699	124156	14059S	PARTICIPANT	\N	PRESENT	0
124700	124156	11036J	PARTICIPANT	\N	PRESENT	0
124701	124156	08051V	PARTICIPANT	\N	PRESENT	0
124702	124156	14219Q	PARTICIPANT	\N	PRESENT	0
124703	124156	11066Q	PARTICIPANT	\N	PRESENT	0
124704	124156	14179A	PARTICIPANT	\N	PRESENT	0
124705	124156	11105E	PARTICIPANT	\N	PRESENT	0
124706	124156	14225N	PARTICIPANT	\N	PRESENT	0
124707	124156	14079W	PARTICIPANT	\N	PRESENT	0
124708	124156	04049K	PARTICIPANT	\N	PRESENT	0
92842	92840	04086Q	PARTICIPANT	\N	PRESENT	0
92843	92840	12042Y	PRESIDENT	0	PRESENT	0
92844	92840	14014Q	PARTICIPANT	\N	PRESENT	0
92845	92840	14026U	PARTICIPANT	\N	PRESENT	0
92846	92840	11112D	PARTICIPANT	\N	PRESENT	0
92847	92840	04049K	PARTICIPANT	\N	PRESENT	0
92848	92840	11100Y	PARTICIPANT	\N	PRESENT	0
92849	92840	14205J	PARTICIPANT	\N	PRESENT	0
92850	92840	04092N	PARTICIPANT	\N	PRESENT	0
92851	92840	14135M	PARTICIPANT	\N	PRESENT	0
92852	92840	14227Q	PARTICIPANT	\N	PRESENT	0
92853	92840	04050C	PARTICIPANT	\N	PRESENT	0
92854	92840	01027Q	PARTICIPANT	\N	PRESENT	0
92855	92840	11097X	PARTICIPANT	\N	PRESENT	0
92856	92840	11107G	PARTICIPANT	\N	EXCUSE	0
92857	92840	11061K	PARTICIPANT	\N	EXCUSE	0
92858	92840	04067M	PARTICIPANT	\N	EXCUSE	0
92859	92840	04045F	PARTICIPANT	\N	EXCUSE	0
93233	93232	14239U	PARTICIPANT	\N	PRESENT	0
93290	93232	14187A	PARTICIPANT	\N	PRESENT	0
93235	93232	01046T	PARTICIPANT	\N	PRESENT	0
93236	93232	04053F	PARTICIPANT	\N	PRESENT	0
93237	93232	14255U	PARTICIPANT	\N	PRESENT	0
93238	93232	04066L	PARTICIPANT	\N	PRESENT	0
93239	93232	00003C	PARTICIPANT	\N	PRESENT	0
93240	93232	14053L	PARTICIPANT	\N	PRESENT	0
93241	93232	11103C	PARTICIPANT	\N	PRESENT	0
93291	93232	01008M	PARTICIPANT	\N	PRESENT	0
93243	93232	14195A	PARTICIPANT	\N	EXCUSE	0
93244	93232	14267Y	PARTICIPANT	\N	PRESENT	0
93292	93232	11057P	PARTICIPANT	\N	PRESENT	0
93246	93232	11031D	PARTICIPANT	\N	PRESENT	0
93247	93232	08052W	PARTICIPANT	\N	PRESENT	0
93248	93232	01059Y	PARTICIPANT	\N	PRESENT	0
93293	93232	11046L	PARTICIPANT	\N	PRESENT	0
93250	93232	98024R	PARTICIPANT	\N	PRESENT	0
93251	93232	10006L	PARTICIPANT	\N	PRESENT	0
93294	93232	14209N	PARTICIPANT	\N	PRESENT	0
93253	93232	14217N	PARTICIPANT	\N	PRESENT	0
93254	93232	14042U	PARTICIPANT	\N	PRESENT	0
93255	93232	14151M	PARTICIPANT	\N	PRESENT	0
93256	93232	12042Y	PARTICIPANT	\N	PRESENT	0
93257	93232	14281W	PARTICIPANT	\N	PRESENT	0
93258	93232	14087W	PARTICIPANT	\N	PRESENT	0
93295	93232	87003B	PARTICIPANT	\N	PRESENT	0
93260	93232	14034U	PARTICIPANT	\N	PRESENT	0
93261	93232	14231L	PARTICIPANT	\N	PRESENT	0
93262	93232	11061K	PARTICIPANT	\N	EXCUSE	0
93263	93232	08048B	PARTICIPANT	\N	EXCUSE	0
93264	93232	08041T	PARTICIPANT	\N	PRESENT	0
93265	93232	01011G	PARTICIPANT	\N	PRESENT	0
93266	93232	14026U	PARTICIPANT	\N	PRESENT	0
93267	93232	14213J	PARTICIPANT	\N	PRESENT	0
93268	93232	14121F	PARTICIPANT	\N	PRESENT	0
93269	93232	11112D	PARTICIPANT	\N	PRESENT	0
93270	93232	14037X	PARTICIPANT	\N	PRESENT	0
93271	93232	14018U	PARTICIPANT	\N	PRESENT	0
93272	93232	11067R	PARTICIPANT	\N	PRESENT	0
93273	93232	14223L	PARTICIPANT	\N	PRESENT	0
93274	93232	04092N	PRESIDENT	0	PRESENT	0
93275	93232	14265W	PARTICIPANT	\N	PRESENT	0
93276	93232	14119M	PARTICIPANT	\N	PRESENT	0
93277	93232	14071N	PARTICIPANT	\N	PRESENT	0
93278	93232	07032N	PARTICIPANT	\N	PRESENT	0
93279	93232	04043D	PARTICIPANT	\N	PRESENT	0
93280	93232	14271U	PARTICIPANT	\N	PRESENT	0
93296	93232	14030Q	PARTICIPANT	\N	PRESENT	0
93282	93232	11093T	PARTICIPANT	\N	PRESENT	0
93283	93232	11097X	PARTICIPANT	\N	PRESENT	0
93284	93232	04045F	PARTICIPANT	\N	EXCUSE	0
93285	93232	14227Q	PARTICIPANT	\N	PRESENT	0
93286	93232	01034P	PARTICIPANT	\N	PRESENT	0
93842	89559	14034U	PARTICIPANT	\N	PRESENT	0
93288	93232	11063M	PARTICIPANT	\N	PRESENT	0
93289	93232	14269B	PARTICIPANT	\N	PRESENT	0
93851	93850	11088W	PARTICIPANT	\N	PRESENT	0
93948	93947	08061X	PARTICIPANT	\N	PRESENT	0
93949	93947	11012A	PARTICIPANT	\N	PRESENT	0
96643	96639	01024M	PARTICIPANT	\N	PRESENT	0
96645	96644	01024M	PARTICIPANT	\N	PRESENT	0
96794	96788	11085T	PARTICIPANT	\N	PRESENT	0
96877	96876	04044E	PARTICIPANT	\N	PRESENT	0
96880	96876	95063L	PARTICIPANT	\N	PRESENT	0
96881	96876	95049N	PARTICIPANT	\N	PRESENT	0
97191	97190	11039M	PARTICIPANT	\N	PRESENT	0
97192	97190	98042T	PARTICIPANT	\N	PRESENT	0
97193	97190	01019Q	PARTICIPANT	\N	PRESENT	0
97208	97196	11039M	PARTICIPANT	\N	PRESENT	0
97209	97196	98042T	PARTICIPANT	\N	PRESENT	0
97210	97196	01019Q	PARTICIPANT	\N	PRESENT	0
97216	97215	04040A	PARTICIPANT	\N	PRESENT	0
97217	97215	04081K	PARTICIPANT	\N	PRESENT	0
97232	97215	11091R	PARTICIPANT	\N	PRESENT	0
97233	97215	01041N	PARTICIPANT	\N	PRESENT	0
97234	97215	87003B	PARTICIPANT	\N	PRESENT	0
97235	97215	97011G	PARTICIPANT	\N	PRESENT	0
97236	97215	04035D	PARTICIPANT	\N	PRESENT	0
97237	97215	04036E	PARTICIPANT	\N	PRESENT	0
97238	97215	08015R	PARTICIPANT	\N	PRESENT	0
97239	97215	11106F	PARTICIPANT	\N	PRESENT	0
103622	103112	14269B	PARTICIPANT	\N	PRESENT	0
103623	103112	14042U	PARTICIPANT	\N	PRESENT	0
103624	103112	04067M	PARTICIPANT	\N	PRESENT	0
103625	103112	14219Q	PARTICIPANT	\N	PRESENT	0
103626	103112	92015P	PARTICIPANT	\N	PRESENT	0
103627	103112	14063N	PARTICIPANT	\N	PRESENT	0
103628	103112	14257W	PARTICIPANT	\N	PRESENT	0
103629	103112	11014C	PARTICIPANT	\N	PRESENT	0
103630	103112	08068F	PARTICIPANT	\N	PRESENT	0
103631	103112	14030Q	PARTICIPANT	\N	PRESENT	0
103632	103112	01034P	PARTICIPANT	\N	PRESENT	0
103633	103112	14221J	PARTICIPANT	\N	PRESENT	0
103634	103112	14083S	PARTICIPANT	\N	PRESENT	0
103635	103112	04088S	PARTICIPANT	\N	PRESENT	0
103636	103112	14191V	PARTICIPANT	\N	PRESENT	0
103637	103112	14085U	PARTICIPANT	\N	PRESENT	0
103638	103112	14271U	PARTICIPANT	\N	PRESENT	0
103639	103112	14265W	PARTICIPANT	\N	PRESENT	0
103640	103112	01060R	PARTICIPANT	\N	PRESENT	0
103641	103112	08014Q	PARTICIPANT	\N	PRESENT	0
103642	103112	08061X	PARTICIPANT	\N	PRESENT	0
103643	103112	11071M	PARTICIPANT	\N	PRESENT	0
103644	103112	14273W	PARTICIPANT	\N	PRESENT	0
103645	103112	14253S	PARTICIPANT	\N	PRESENT	0
103646	103112	04045F	PARTICIPANT	\N	PRESENT	0
103647	103112	01043Q	PARTICIPANT	\N	PRESENT	0
103648	103112	14281W	PARTICIPANT	\N	PRESENT	0
103649	103112	92040Q	PARTICIPANT	\N	PRESENT	0
103650	103112	14105F	PARTICIPANT	\N	PRESENT	0
103651	103112	08069G	PARTICIPANT	\N	PRESENT	0
103652	103112	14071N	PARTICIPANT	\N	PRESENT	0
103653	103112	92020L	PARTICIPANT	\N	PRESENT	0
103654	103112	14229S	PARTICIPANT	\N	PRESENT	0
103655	103112	14001X	PARTICIPANT	\N	PRESENT	0
103656	103112	14227Q	PARTICIPANT	\N	PRESENT	0
103657	103112	89017R	PARTICIPANT	\N	PRESENT	0
103658	103112	14107H	PARTICIPANT	\N	PRESENT	0
103659	103112	14197C	PARTICIPANT	\N	PRESENT	0
103660	103112	11015D	PARTICIPANT	\N	PRESENT	0
103661	103112	14157T	PARTICIPANT	\N	PRESENT	0
103662	103112	11097X	PARTICIPANT	\N	PRESENT	0
103663	103112	11093T	PARTICIPANT	\N	PRESENT	0
103664	103112	95041E	PARTICIPANT	\N	PRESENT	0
103665	103112	14121F	PARTICIPANT	\N	PRESENT	0
103666	103112	14207L	PARTICIPANT	\N	PRESENT	0
103667	103112	14034U	PARTICIPANT	\N	PRESENT	0
103668	103112	11104D	PARTICIPANT	\N	PRESENT	0
103669	103112	11084S	PARTICIPANT	\N	PRESENT	0
103670	103112	14135M	PARTICIPANT	\N	PRESENT	0
103672	103112	98050T	PARTICIPANT	\N	PRESENT	0
103673	103112	08039A	PARTICIPANT	\N	PRESENT	0
103674	103112	14053L	PARTICIPANT	\N	PRESENT	0
103675	103112	11061K	PARTICIPANT	\N	PRESENT	0
103676	103112	11089X	PARTICIPANT	\N	PRESENT	0
103677	103112	12042Y	PARTICIPANT	\N	PRESENT	0
103678	103112	08012N	PARTICIPANT	\N	PRESENT	0
103679	103112	01022K	PARTICIPANT	\N	PRESENT	0
103680	103112	08058D	PARTICIPANT	\N	PRESENT	0
103681	103112	08056B	PARTICIPANT	\N	PRESENT	0
103682	103112	14097Y	PARTICIPANT	\N	PRESENT	0
103683	103112	11077T	PARTICIPANT	\N	PRESENT	0
103684	103112	11105E	PARTICIPANT	\N	PRESENT	0
103685	103112	08065C	PARTICIPANT	\N	PRESENT	0
103686	103112	04081K	PARTICIPANT	\N	PRESENT	0
103687	103112	11090Q	PARTICIPANT	\N	PRESENT	0
103688	103112	11103C	PARTICIPANT	\N	PRESENT	0
103689	103112	14255U	PARTICIPANT	\N	PRESENT	0
103690	103112	11111C	PARTICIPANT	\N	PRESENT	0
103692	103112	97011G	PARTICIPANT	\N	PRESENT	0
110601	110252	14277B	PARTICIPANT	\N	PRESENT	0
110602	110252	14275Y	PARTICIPANT	\N	PRESENT	0
110603	110252	14073Q	PARTICIPANT	\N	PRESENT	0
110604	110252	07034Q	PARTICIPANT	\N	PRESENT	0
110605	110252	95037J	PARTICIPANT	\N	PRESENT	0
110606	110252	04089T	PARTICIPANT	\N	PRESENT	0
110607	110252	14241N	PARTICIPANT	\N	PRESENT	0
110608	110252	89017R	PARTICIPANT	\N	PRESENT	0
110609	110252	14055N	PARTICIPANT	\N	PRESENT	0
110611	110252	01059Y	PARTICIPANT	\N	PRESENT	0
110612	110252	01015L	PARTICIPANT	\N	PRESENT	0
110613	110252	98053W	PARTICIPANT	\N	PRESENT	0
110614	110252	11111C	PARTICIPANT	\N	PRESENT	0
110615	110252	14042U	PARTICIPANT	\N	PRESENT	0
110616	110252	04080J	PARTICIPANT	\N	PRESENT	0
110617	110252	01034P	PARTICIPANT	\N	PRESENT	0
110619	110252	14173T	PARTICIPANT	\N	PRESENT	0
110621	110252	04097T	PARTICIPANT	\N	PRESENT	0
110624	110252	11063M	PARTICIPANT	\N	PRESENT	0
110629	110252	11025F	PARTICIPANT	\N	PRESENT	0
110631	110252	11070L	PARTICIPANT	\N	PRESENT	0
110637	110252	11082Q	PARTICIPANT	\N	PRESENT	0
110642	110252	11066Q	PARTICIPANT	\N	PRESENT	0
110644	110252	04071H	PARTICIPANT	\N	PRESENT	0
110645	110252	01061S	PARTICIPANT	\N	PRESENT	0
110651	110252	04049K	PARTICIPANT	\N	PRESENT	0
110647	110252	90003B	PARTICIPANT	\N	PRESENT	0
110648	110252	01060R	PARTICIPANT	\N	PRESENT	0
110649	110252	04061F	PARTICIPANT	\N	PRESENT	0
110650	110252	99002P	PARTICIPANT	\N	PRESENT	0
110652	110252	14069U	PARTICIPANT	\N	PRESENT	0
110653	110252	14251Q	PARTICIPANT	\N	PRESENT	0
110654	110252	14093U	PARTICIPANT	\N	PRESENT	0
110655	110252	14237S	PARTICIPANT	\N	PRESENT	0
110656	110252	92044U	PARTICIPANT	\N	PRESENT	0
110657	110252	11074Q	PARTICIPANT	\N	PRESENT	0
110658	110252	14217N	PARTICIPANT	\N	PRESENT	0
110659	110252	08009T	PARTICIPANT	\N	PRESENT	0
110663	110252	11030C	PARTICIPANT	\N	PRESENT	0
110661	110252	14169X	PARTICIPANT	\N	PRESENT	0
110662	110252	11112D	PARTICIPANT	\N	PRESENT	0
110664	110252	11053K	PARTICIPANT	\N	PRESENT	0
110665	110252	11089X	PARTICIPANT	\N	PRESENT	0
110666	110252	11105E	PARTICIPANT	\N	PRESENT	0
110667	110252	11037K	PARTICIPANT	\N	PRESENT	0
110668	110252	07032N	PARTICIPANT	\N	PRESENT	0
110669	110252	08018U	PARTICIPANT	\N	PRESENT	0
110673	110252	14121F	PARTICIPANT	\N	PRESENT	0
110671	110252	98021N	PARTICIPANT	\N	PRESENT	0
110672	110252	14089Y	PARTICIPANT	\N	PRESENT	0
110674	110252	14225N	PARTICIPANT	\N	PRESENT	0
110675	110252	14018U	PARTICIPANT	\N	PRESENT	0
110676	110252	14199E	PARTICIPANT	\N	PRESENT	0
110677	110252	14034U	PARTICIPANT	\N	PRESENT	0
110680	110252	92045V	PARTICIPANT	\N	PRESENT	0
110693	110252	95030B	PARTICIPANT	\N	PRESENT	0
110692	110252	11101A	PARTICIPANT	\N	PRESENT	0
110697	110252	80013X	PARTICIPANT	\N	PRESENT	0
110695	110252	14017T	PARTICIPANT	\N	PRESENT	0
110696	110252	11064N	PARTICIPANT	\N	PRESENT	0
110698	110252	08068F	PARTICIPANT	\N	PRESENT	0
110699	110610	86034E	PARTICIPANT	\N	PRESENT	0
110700	110610	04050C	PARTICIPANT	\N	PRESENT	0
110701	110610	04092N	PARTICIPANT	\N	PRESENT	0
110702	110610	14037X	PARTICIPANT	\N	PRESENT	0
110703	110610	04085P	PARTICIPANT	\N	PRESENT	0
110704	110610	11063M	PARTICIPANT	\N	PRESENT	0
110705	110610	11040E	PARTICIPANT	\N	PRESENT	0
110706	110610	11056N	PARTICIPANT	\N	PRESENT	0
110707	110610	01015L	PARTICIPANT	\N	PRESENT	0
110708	110610	11076S	PARTICIPANT	\N	PRESENT	0
110709	110610	01059Y	PARTICIPANT	\N	PRESENT	0
110710	110610	04067M	PARTICIPANT	\N	PRESENT	0
110711	110610	11029K	PARTICIPANT	\N	PRESENT	0
110712	110610	01044R	PARTICIPANT	\N	PRESENT	0
110713	110610	14087W	PARTICIPANT	\N	PRESENT	0
110714	110610	13002U	PARTICIPANT	\N	PRESENT	0
110715	110610	11055M	PARTICIPANT	\N	PRESENT	0
110716	110610	11099A	PARTICIPANT	\N	PRESENT	0
110717	110610	04047H	PARTICIPANT	\N	PRESENT	0
110718	110610	01058X	PARTICIPANT	\N	PRESENT	0
110719	110610	95030B	PARTICIPANT	\N	PRESENT	0
110720	110610	01060R	PARTICIPANT	\N	PRESENT	0
110721	110610	14247U	PARTICIPANT	\N	PRESENT	0
110722	110610	14055N	PARTICIPANT	\N	PRESENT	0
110723	110610	92044U	PARTICIPANT	\N	PRESENT	0
110724	110610	98024R	PARTICIPANT	\N	PRESENT	0
110725	110610	14239U	PARTICIPANT	\N	PRESENT	0
110726	110610	14261S	PARTICIPANT	\N	PRESENT	0
110727	110610	01046T	PARTICIPANT	\N	PRESENT	0
110728	110610	14026U	PARTICIPANT	\N	PRESENT	0
110729	110610	14201E	PARTICIPANT	\N	PRESENT	0
110730	110610	88008L	PARTICIPANT	\N	PRESENT	0
110731	110610	04044E	PARTICIPANT	\N	PRESENT	0
110732	110610	95062K	PARTICIPANT	\N	PRESENT	0
110733	110610	01003G	PARTICIPANT	\N	PRESENT	0
110734	110610	07026Q	PARTICIPANT	\N	PRESENT	0
110735	110610	04071H	PARTICIPANT	\N	PRESENT	0
110736	110610	14018U	PARTICIPANT	\N	PRESENT	0
110737	110610	14253S	PARTICIPANT	\N	PRESENT	0
110738	110610	98022P	PARTICIPANT	\N	PRESENT	0
110739	110610	01027Q	PARTICIPANT	\N	PRESENT	0
110740	110610	14211G	PARTICIPANT	\N	PRESENT	0
110741	110610	14191V	PARTICIPANT	\N	PRESENT	0
110742	110610	08052W	PARTICIPANT	\N	PRESENT	0
110743	110610	01057W	PARTICIPANT	\N	PRESENT	0
110744	110610	14169X	PARTICIPANT	\N	PRESENT	0
110745	110610	14151M	PARTICIPANT	\N	PRESENT	0
110746	110610	14051J	PARTICIPANT	\N	PRESENT	0
110747	110610	95063L	PARTICIPANT	\N	PRESENT	0
110748	110610	11043H	PARTICIPANT	\N	PRESENT	0
110749	110610	01011G	PARTICIPANT	\N	PRESENT	0
110750	110610	87003B	PARTICIPANT	\N	PRESENT	0
110751	110610	04043D	PARTICIPANT	\N	PRESENT	0
110752	110610	11012A	PARTICIPANT	\N	PRESENT	0
110753	110610	10006L	PARTICIPANT	\N	PRESENT	0
110754	110610	98046X	PARTICIPANT	\N	PRESENT	0
110755	110610	04086Q	PARTICIPANT	\N	PRESENT	0
110756	110610	01031L	PARTICIPANT	\N	PRESENT	0
110757	110610	04066L	PARTICIPANT	\N	PRESENT	0
110758	110610	04033B	PARTICIPANT	\N	PRESENT	0
110759	110610	08073C	PARTICIPANT	\N	PRESENT	0
110760	110610	14223L	PARTICIPANT	\N	PRESENT	0
110761	110610	11057P	PARTICIPANT	\N	PRESENT	0
110762	110610	04057K	PARTICIPANT	\N	PRESENT	0
110763	110610	92020L	PARTICIPANT	\N	PRESENT	0
110764	110610	08060W	PARTICIPANT	\N	PRESENT	0
110765	110610	14237S	PARTICIPANT	\N	PRESENT	0
110766	110610	80013X	PARTICIPANT	\N	PRESENT	0
110767	110610	95015C	PARTICIPANT	\N	PRESENT	0
110768	110610	14028W	PARTICIPANT	\N	PRESENT	0
110769	110610	14133K	PARTICIPANT	\N	PRESENT	0
110770	110610	01022K	PARTICIPANT	\N	PRESENT	0
110771	110610	14197C	PARTICIPANT	\N	PRESENT	0
110772	110610	14157T	PARTICIPANT	\N	PRESENT	0
110773	110610	11036J	PARTICIPANT	\N	PRESENT	0
110774	110610	11105E	PARTICIPANT	\N	PRESENT	0
110775	110610	04074L	PARTICIPANT	\N	PRESENT	0
110776	110610	11046L	PARTICIPANT	\N	PRESENT	0
110777	110610	14329V	PARTICIPANT	\N	PRESENT	0
110778	110610	08053X	PARTICIPANT	\N	PRESENT	0
110779	110610	83042R	PARTICIPANT	\N	PRESENT	0
110780	110610	11088W	PARTICIPANT	\N	PRESENT	0
110781	110610	14014Q	PARTICIPANT	\N	PRESENT	0
110782	110610	14109K	PARTICIPANT	\N	PRESENT	0
110783	110610	04088S	PARTICIPANT	\N	PRESENT	0
110784	110610	11095V	PARTICIPANT	\N	PRESENT	0
110785	110610	08034U	PARTICIPANT	\N	PRESENT	0
110786	110610	14001X	PARTICIPANT	\N	PRESENT	0
110787	110610	08069G	PARTICIPANT	\N	PRESENT	0
110788	110610	14227Q	PARTICIPANT	\N	PRESENT	0
110789	110610	14167V	PARTICIPANT	\N	PRESENT	0
110790	110610	08068F	PARTICIPANT	\N	PRESENT	0
110791	110610	07029T	PARTICIPANT	\N	PRESENT	0
110792	110610	14257W	PARTICIPANT	\N	PRESENT	0
110793	110610	11112D	PARTICIPANT	\N	PRESENT	0
110794	110610	14225N	PARTICIPANT	\N	PRESENT	0
110795	110610	04097T	PARTICIPANT	\N	PRESENT	0
110796	110610	14121F	PARTICIPANT	\N	PRESENT	0
110797	110610	14281W	PARTICIPANT	\N	PRESENT	0
110798	110610	11059R	PARTICIPANT	\N	PRESENT	0
110799	110610	11101A	PARTICIPANT	\N	PRESENT	0
110800	110610	11026G	PARTICIPANT	\N	PRESENT	0
110801	110610	14195A	PARTICIPANT	\N	PRESENT	0
110802	110610	14235Q	PARTICIPANT	\N	PRESENT	0
110803	110610	08061X	PARTICIPANT	\N	PRESENT	0
110804	110610	95037J	PARTICIPANT	\N	PRESENT	0
110805	110610	04053F	PARTICIPANT	\N	PRESENT	0
95136	89162	14299H	PARTICIPANT	\N	PRESENT	0
95969	95782	14199E	PARTICIPANT	\N	PRESENT	0
95970	95782	11110B	PARTICIPANT	\N	PRESENT	0
95971	95782	04048J	PARTICIPANT	\N	PRESENT	0
95972	95782	11098Y	PARTICIPANT	\N	PRESENT	0
95973	95782	14257W	PARTICIPANT	\N	PRESENT	0
95974	95782	04088S	PARTICIPANT	\N	PRESENT	0
95985	95984	14133K	PARTICIPANT	\N	PRESENT	0
95986	95984	04085P	PARTICIPANT	\N	PRESENT	0
95987	95984	04054G	PARTICIPANT	\N	PRESENT	0
95988	95984	14089Y	PARTICIPANT	\N	PRESENT	0
95989	95984	04047H	PARTICIPANT	\N	EXCUSE	0
95990	95984	14079W	PARTICIPANT	\N	PRESENT	0
95991	95984	14041T	PARTICIPANT	\N	PRESENT	0
95992	95984	95037J	PARTICIPANT	\N	PRESENT	0
95993	95984	14097Y	PARTICIPANT	\N	PRESENT	0
95995	95984	14073Q	PARTICIPANT	\N	PRESENT	0
95996	95984	92031P	PRESIDENT	0	PRESENT	0
95997	95984	14001X	PARTICIPANT	\N	PRESENT	0
95998	95984	08053X	PARTICIPANT	\N	PRESENT	0
95999	95984	14237S	PARTICIPANT	\N	PRESENT	0
96000	95984	14331P	PARTICIPANT	\N	EXCUSE	0
96001	95984	08049C	PARTICIPANT	\N	PRESENT	0
116618	116615	08043V	PARTICIPANT	\N	PRESENT	0
116624	116623	14231L	PARTICIPANT	\N	PRESENT	0
116625	116623	08031R	PARTICIPANT	\N	PRESENT	0
116626	116623	08043V	PARTICIPANT	\N	PRESENT	0
116627	116623	11066Q	PARTICIPANT	\N	PRESENT	0
116632	115993	86034E	PARTICIPANT	\N	PRESENT	0
116652	115993	01013J	PARTICIPANT	\N	PRESENT	0
116653	115993	14013P	PARTICIPANT	\N	PRESENT	0
116654	115993	11040E	PARTICIPANT	\N	PRESENT	0
116655	115993	04085P	PARTICIPANT	\N	PRESENT	0
116656	115993	04059M	PARTICIPANT	\N	PRESENT	0
116657	115993	08055A	PARTICIPANT	\N	PRESENT	0
116658	115993	11027H	PARTICIPANT	\N	PRESENT	0
116659	115993	14281W	PARTICIPANT	\N	PRESENT	0
116660	115993	11034G	PARTICIPANT	\N	PRESENT	0
116661	115993	11054L	PARTICIPANT	\N	PRESENT	0
116662	115993	14167V	PARTICIPANT	\N	PRESENT	0
116663	115993	11098Y	PARTICIPANT	\N	PRESENT	0
116664	115993	08016S	PARTICIPANT	\N	PRESENT	0
116665	115993	08024S	PARTICIPANT	\N	PRESENT	0
116666	115993	98046X	PARTICIPANT	\N	PRESENT	0
116667	115993	14263U	PARTICIPANT	\N	PRESENT	0
116668	115993	01011G	PARTICIPANT	\N	PRESENT	0
116672	115993	92020L	PARTICIPANT	\N	PRESENT	0
116673	115993	08060W	PARTICIPANT	\N	PRESENT	0
116674	115993	14197C	PARTICIPANT	\N	PRESENT	0
116675	115993	01022K	PARTICIPANT	\N	PRESENT	0
116676	115993	11059R	PARTICIPANT	\N	PRESENT	0
116677	115993	11105E	PARTICIPANT	\N	PRESENT	0
116678	115993	11089X	PARTICIPANT	\N	PRESENT	0
116679	115993	11036J	PARTICIPANT	\N	PRESENT	0
116680	115993	08014Q	PARTICIPANT	\N	PRESENT	0
116681	115993	11037K	PARTICIPANT	\N	PRESENT	0
116682	115993	08012N	PARTICIPANT	\N	PRESENT	0
116683	115993	80027E	PARTICIPANT	\N	PRESENT	0
116684	115993	11046L	PARTICIPANT	\N	PRESENT	0
116685	115993	14271U	PARTICIPANT	\N	PRESENT	0
116686	115993	14229S	PARTICIPANT	\N	PRESENT	0
116687	115993	83047W	PARTICIPANT	\N	PRESENT	0
116688	115993	11015D	PARTICIPANT	\N	PRESENT	0
116689	115993	11095V	PARTICIPANT	\N	PRESENT	0
116690	115993	14225N	PARTICIPANT	\N	PRESENT	0
116691	115993	14257W	PARTICIPANT	\N	PRESENT	0
116692	115993	14097Y	PARTICIPANT	\N	PRESENT	0
116693	115993	11112D	PARTICIPANT	\N	PRESENT	0
116694	115993	14121F	PARTICIPANT	\N	PRESENT	0
116712	115993	95037J	PARTICIPANT	\N	PRESENT	0
116713	115993	08061X	PARTICIPANT	\N	PRESENT	0
116714	115993	04053F	PARTICIPANT	\N	PRESENT	0
116715	115993	01028R	PARTICIPANT	\N	PRESENT	0
116716	115993	11042G	PARTICIPANT	\N	PRESENT	0
116717	115993	11110B	PARTICIPANT	\N	PRESENT	0
116718	115993	08038Y	PARTICIPANT	\N	PRESENT	0
116719	115993	92039X	PARTICIPANT	\N	PRESENT	0
116720	115993	14207L	PARTICIPANT	\N	PRESENT	0
116721	115993	14085U	PARTICIPANT	\N	PRESENT	0
116722	115993	11074Q	PARTICIPANT	\N	PRESENT	0
116723	115993	08052W	PARTICIPANT	\N	PRESENT	0
116724	115993	11067R	PARTICIPANT	\N	PRESENT	0
116725	115993	04045F	PARTICIPANT	\N	PRESENT	0
116726	115993	12042Y	PARTICIPANT	\N	PRESENT	0
116727	115993	11077T	PARTICIPANT	\N	PRESENT	0
116728	115993	14109K	PARTICIPANT	\N	PRESENT	0
116729	115993	11114F	PARTICIPANT	\N	PRESENT	0
116730	115993	11113E	PARTICIPANT	\N	PRESENT	0
116731	115993	14159V	PARTICIPANT	\N	PRESENT	0
116732	115993	14269B	PARTICIPANT	\N	PRESENT	0
116733	115993	11107G	PARTICIPANT	\N	PRESENT	0
116734	115993	11066Q	PARTICIPANT	\N	PRESENT	0
116735	115993	12041X	PARTICIPANT	\N	PRESENT	0
116736	115993	04067M	PARTICIPANT	\N	PRESENT	0
116737	115993	11055M	PARTICIPANT	\N	PRESENT	0
116738	115993	01044R	PARTICIPANT	\N	PRESENT	0
116739	115993	11029K	PARTICIPANT	\N	PRESENT	0
116740	115993	13002U	PARTICIPANT	\N	PRESENT	0
116741	115993	11099A	PARTICIPANT	\N	PRESENT	0
116742	115993	11083R	PARTICIPANT	\N	PRESENT	0
116743	115993	11065P	PARTICIPANT	\N	PRESENT	0
116744	115993	11057P	PARTICIPANT	\N	PRESENT	0
116745	115993	08051V	PARTICIPANT	\N	PRESENT	0
116746	115993	11012A	PARTICIPANT	\N	PRESENT	0
116747	115993	08031R	PARTICIPANT	\N	PRESENT	0
116748	115993	08058D	PARTICIPANT	\N	PRESENT	0
116749	115993	14018U	PARTICIPANT	\N	PRESENT	0
116751	115993	01003G	PARTICIPANT	\N	PRESENT	0
116752	115993	98022P	PARTICIPANT	\N	PRESENT	0
116753	115993	01031L	PARTICIPANT	\N	PRESENT	0
116754	115993	14239U	PARTICIPANT	\N	PRESENT	0
116755	115993	14327T	PARTICIPANT	\N	PRESENT	0
116756	115993	01007L	PARTICIPANT	\N	PRESENT	0
116757	115993	08056B	PARTICIPANT	\N	PRESENT	0
116758	116750	01016M	PARTICIPANT	\N	PRESENT	0
116759	115993	01024M	PARTICIPANT	\N	PRESENT	0
116760	116750	11053K	PARTICIPANT	\N	PRESENT	0
116761	115993	01047U	PARTICIPANT	\N	PRESENT	0
116762	116750	99004R	PARTICIPANT	\N	PRESENT	0
116763	115993	14073Q	PARTICIPANT	\N	PRESENT	0
116764	115993	09001P	PARTICIPANT	\N	PRESENT	0
116765	116750	08061X	PARTICIPANT	\N	PRESENT	0
116766	115993	14255U	PARTICIPANT	\N	PRESENT	0
116767	115993	14179A	PARTICIPANT	\N	PRESENT	0
116768	115993	14042U	PARTICIPANT	\N	PRESENT	0
116769	116750	04061F	PARTICIPANT	\N	PRESENT	0
116770	115993	14231L	PARTICIPANT	\N	PRESENT	0
116771	115993	14083S	PARTICIPANT	\N	PRESENT	0
116772	115993	04089T	PARTICIPANT	\N	PRESENT	0
116773	115993	98042T	PARTICIPANT	\N	PRESENT	0
116774	115993	11093T	PARTICIPANT	\N	PRESENT	0
116775	115993	11111C	PARTICIPANT	\N	PRESENT	0
116776	115993	14275Y	PARTICIPANT	\N	PRESENT	0
116777	115993	14221J	PARTICIPANT	\N	PRESENT	0
116778	115993	11096W	PARTICIPANT	\N	PRESENT	0
116779	115993	14219Q	PARTICIPANT	\N	PRESENT	0
116780	115993	14014Q	PARTICIPANT	\N	PRESENT	0
116781	115993	01034P	PARTICIPANT	\N	PRESENT	0
116782	115993	14205J	PARTICIPANT	\N	PRESENT	0
116783	115993	04080J	PARTICIPANT	\N	PRESENT	0
116784	115993	11064N	PARTICIPANT	\N	PRESENT	0
116785	115993	11053K	PARTICIPANT	\N	PRESENT	0
116786	115993	04040A	PARTICIPANT	\N	PRESENT	0
116787	115993	11094U	PARTICIPANT	\N	PRESENT	0
116788	115993	11031D	PARTICIPANT	\N	PRESENT	0
116789	115993	11063M	PARTICIPANT	\N	PRESENT	0
116790	115993	01015L	PARTICIPANT	\N	PRESENT	0
116791	115993	07004J	PARTICIPANT	\N	PRESENT	0
116792	115993	01027Q	PARTICIPANT	\N	PRESENT	0
116793	115993	04036E	PARTICIPANT	\N	PRESENT	0
116794	115993	08011M	PARTICIPANT	\N	PRESENT	0
116795	115993	95062K	PARTICIPANT	\N	PRESENT	0
116796	115993	02002K	PARTICIPANT	\N	PRESENT	0
116797	115993	95015C	PARTICIPANT	\N	PRESENT	0
116798	115993	04097T	PARTICIPANT	\N	PRESENT	0
116799	115993	14211G	PARTICIPANT	\N	PRESENT	0
116800	115993	14253S	PARTICIPANT	\N	PRESENT	0
116801	115993	04071H	PARTICIPANT	\N	PRESENT	0
116802	115993	08010L	PARTICIPANT	\N	PRESENT	0
116803	115993	11043H	PARTICIPANT	\N	PRESENT	0
116804	115993	89029V	PARTICIPANT	\N	PRESENT	0
116805	115993	11100Y	PARTICIPANT	\N	PRESENT	0
116806	115993	14223L	PARTICIPANT	\N	PRESENT	0
116807	115993	87003B	PARTICIPANT	\N	PRESENT	0
116808	115993	01057W	PARTICIPANT	\N	PRESENT	0
117673	117672	07024N	PARTICIPANT	\N	PRESENT	0
117675	117674	95059Q	PARTICIPANT	\N	PRESENT	0
117676	117674	07024N	PARTICIPANT	\N	PRESENT	0
117677	117674	01014K	PARTICIPANT	\N	PRESENT	0
117678	117674	98021N	PARTICIPANT	\N	PRESENT	0
117679	117674	04040A	PARTICIPANT	\N	PRESENT	0
117680	117674	14193X	PARTICIPANT	\N	PRESENT	0
117681	117674	11106F	PARTICIPANT	\N	PRESENT	0
117697	117696	04047H	PARTICIPANT	\N	PRESENT	0
117713	117712	04071H	PARTICIPANT	\N	PRESENT	0
117715	117714	04071H	PARTICIPANT	\N	PRESENT	0
117717	117716	11057P	PARTICIPANT	\N	PRESENT	0
117719	117718	01013J	PARTICIPANT	\N	PRESENT	0
119560	119255	01015L	PARTICIPANT	\N	EXCUSE	0
119561	119255	04043D	PARTICIPANT	\N	EXCUSE	0
119562	119255	08049C	PARTICIPANT	\N	EXCUSE	0
124214	124154	11059R	PARTICIPANT	\N	PRESENT	0
124313	124155	11034G	PARTICIPANT	\N	PRESENT	0
124314	124155	14235Q	PARTICIPANT	\N	PRESENT	0
124315	124155	11040E	PARTICIPANT	\N	PRESENT	0
124316	124155	11098Y	PARTICIPANT	\N	PRESENT	0
124317	124155	01022K	PARTICIPANT	\N	PRESENT	0
124318	124155	11066Q	PARTICIPANT	\N	PRESENT	0
124319	124155	11046L	PARTICIPANT	\N	PRESENT	0
124414	124155	11011M	PARTICIPANT	\N	PRESENT	0
124321	124155	11104D	PARTICIPANT	\N	PRESENT	0
124322	124155	11099A	PARTICIPANT	\N	PRESENT	0
124323	124155	11055M	PARTICIPANT	\N	PRESENT	0
124324	124155	04067M	PARTICIPANT	\N	PRESENT	0
124325	124155	04089T	PARTICIPANT	\N	PRESENT	0
124326	124155	14089Y	PARTICIPANT	\N	PRESENT	0
124327	124155	11094U	PARTICIPANT	\N	PRESENT	0
124328	124155	11012A	PARTICIPANT	\N	PRESENT	0
124329	124155	11100Y	PARTICIPANT	\N	PRESENT	0
124330	124155	14231L	PARTICIPANT	\N	PRESENT	0
124331	124155	14187A	PARTICIPANT	\N	PRESENT	0
124332	124155	11036J	PARTICIPANT	\N	PRESENT	0
124333	124155	14079W	PARTICIPANT	\N	PRESENT	0
124334	124155	14215L	PARTICIPANT	\N	PRESENT	0
124335	124155	04043D	PARTICIPANT	\N	PRESENT	0
124336	124155	14073Q	PARTICIPANT	\N	PRESENT	0
124337	124155	98023Q	PARTICIPANT	\N	PRESENT	0
124338	124155	04038G	PARTICIPANT	\N	PRESENT	0
124339	124155	08062Y	PARTICIPANT	\N	PRESENT	0
124340	124155	14265W	PARTICIPANT	\N	PRESENT	0
124341	124155	04088S	PARTICIPANT	\N	PRESENT	0
124342	124155	14195A	PARTICIPANT	\N	PRESENT	0
124343	124155	08034U	PARTICIPANT	\N	PRESENT	0
124344	124155	14105F	PARTICIPANT	\N	PRESENT	0
124345	124155	04086Q	PARTICIPANT	\N	PRESENT	0
124346	124155	14107H	PARTICIPANT	\N	PRESENT	0
124347	124155	01043Q	PARTICIPANT	\N	PRESENT	0
124348	124155	14241N	PARTICIPANT	\N	PRESENT	0
124273	106052	14227Q	PARTICIPANT	\N	PRESENT	0
124274	106052	11057P	PARTICIPANT	\N	PRESENT	0
124349	124155	14269B	PARTICIPANT	\N	PRESENT	0
124350	124155	14257W	PARTICIPANT	\N	PRESENT	0
124351	124155	14221J	PARTICIPANT	\N	PRESENT	0
124352	124155	01003G	PARTICIPANT	\N	PRESENT	0
124353	124155	11077T	PARTICIPANT	\N	PRESENT	0
124354	124155	14223L	PARTICIPANT	\N	PRESENT	0
124355	124155	98050T	PARTICIPANT	\N	PRESENT	0
124356	124155	11097X	PARTICIPANT	\N	PRESENT	0
124357	124155	08069G	PARTICIPANT	\N	PRESENT	0
124358	124155	08051V	PARTICIPANT	\N	PRESENT	0
124359	124155	11081P	PARTICIPANT	\N	PRESENT	0
124360	124155	10006L	PARTICIPANT	\N	PRESENT	0
124361	124155	95015C	PARTICIPANT	\N	PRESENT	0
124362	124155	14147R	PARTICIPANT	\N	PRESENT	0
124363	124155	95031C	PARTICIPANT	\N	PRESENT	0
124364	124155	14267Y	PARTICIPANT	\N	PRESENT	0
124365	124155	92015P	PARTICIPANT	\N	PRESENT	0
124366	124155	08016S	PARTICIPANT	\N	PRESENT	0
124367	124155	14251Q	PARTICIPANT	\N	PRESENT	0
124368	124155	11070L	PARTICIPANT	\N	PRESENT	0
124369	124155	14211G	PARTICIPANT	\N	PRESENT	0
124370	124155	14026U	PARTICIPANT	\N	PRESENT	0
124371	124155	87003B	PARTICIPANT	\N	PRESENT	0
124372	124155	95049N	PARTICIPANT	\N	PRESENT	0
124373	124155	14173T	PARTICIPANT	\N	PRESENT	0
124374	124155	01025N	PARTICIPANT	\N	PRESENT	0
124375	124155	08068F	PARTICIPANT	\N	PRESENT	0
124376	124155	04033B	PARTICIPANT	\N	PRESENT	0
124377	124155	14327T	PARTICIPANT	\N	PRESENT	0
124378	124155	04042C	PARTICIPANT	\N	PRESENT	0
124379	124155	14037X	PARTICIPANT	\N	PRESENT	0
124380	124155	14061L	PARTICIPANT	\N	PRESENT	0
124381	124155	11053K	PARTICIPANT	\N	PRESENT	0
124382	124155	95035G	PARTICIPANT	\N	PRESENT	0
124383	124155	99004R	PARTICIPANT	\N	PRESENT	0
124384	124155	08010L	PARTICIPANT	\N	PRESENT	0
124385	124155	14041T	PARTICIPANT	\N	PRESENT	0
124386	124155	11048N	PARTICIPANT	\N	PRESENT	0
124387	124155	14123H	PARTICIPANT	\N	PRESENT	0
124388	124155	08015R	PARTICIPANT	\N	PRESENT	0
124389	124155	14135M	PARTICIPANT	\N	PRESENT	0
124390	124155	14213J	PARTICIPANT	\N	PRESENT	0
124391	124155	14111D	PARTICIPANT	\N	PRESENT	0
124392	124155	04047H	PARTICIPANT	\N	PRESENT	0
124393	124155	14059S	PARTICIPANT	\N	PRESENT	0
124394	124155	13002U	PARTICIPANT	\N	PRESENT	0
124395	124155	11057P	PARTICIPANT	\N	PRESENT	0
124396	124155	11111C	PARTICIPANT	\N	PRESENT	0
124397	124155	14034U	PARTICIPANT	\N	PRESENT	0
124398	124155	11084S	PARTICIPANT	\N	PRESENT	0
124399	124155	08041T	PARTICIPANT	\N	PRESENT	0
124400	124155	14271U	PARTICIPANT	\N	PRESENT	0
124401	124155	01056V	PARTICIPANT	\N	PRESENT	0
124402	124155	11014C	PARTICIPANT	\N	PRESENT	0
124403	124155	14013P	PARTICIPANT	\N	PRESENT	0
124404	124155	04045F	PARTICIPANT	\N	PRESENT	0
124405	124155	11082Q	PARTICIPANT	\N	PRESENT	0
124406	124155	11032E	PARTICIPANT	\N	PRESENT	0
124407	124155	01044R	PARTICIPANT	\N	PRESENT	0
124408	124155	14053L	PARTICIPANT	\N	PRESENT	0
124409	124155	14217N	PARTICIPANT	\N	PRESENT	0
124410	124155	08048B	PARTICIPANT	\N	PRESENT	0
124411	124155	95030B	PARTICIPANT	\N	PRESENT	0
124412	124155	86044G	PARTICIPANT	\N	PRESENT	0
124413	124155	14081Q	PARTICIPANT	\N	PRESENT	0
124415	124155	08039A	PARTICIPANT	\N	PRESENT	0
124416	124155	95062K	PARTICIPANT	\N	PRESENT	0
124417	124155	07032N	PARTICIPANT	\N	PRESENT	0
124418	124155	11043H	PARTICIPANT	\N	PRESENT	0
124419	124155	11103C	PARTICIPANT	\N	PRESENT	0
124420	124155	14225N	PARTICIPANT	\N	PRESENT	0
124421	124155	14109K	PARTICIPANT	\N	PRESENT	0
124422	124155	08017T	PARTICIPANT	\N	PRESENT	0
124423	124155	08038Y	PARTICIPANT	\N	PRESENT	0
124424	124155	01047U	PARTICIPANT	\N	PRESENT	0
124425	124155	04049K	PARTICIPANT	\N	PRESENT	0
124426	124155	14038Y	PARTICIPANT	\N	PRESENT	0
124427	124155	14199E	PARTICIPANT	\N	PRESENT	0
124428	124155	01057W	PARTICIPANT	\N	PRESENT	0
124429	124155	92045V	PARTICIPANT	\N	PRESENT	0
124430	124155	11091R	PARTICIPANT	\N	PRESENT	0
124431	124155	80013X	PARTICIPANT	\N	PRESENT	0
124432	124155	08031R	PARTICIPANT	\N	PRESENT	0
124440	124155	04041B	PARTICIPANT	\N	PRESENT	0
124441	124155	11071M	PARTICIPANT	\N	PRESENT	0
124442	124155	14069U	PARTICIPANT	\N	PRESENT	0
124443	124155	14063N	PARTICIPANT	\N	PRESENT	0
124444	124155	08019V	PARTICIPANT	\N	PRESENT	0
124445	124155	14169X	PARTICIPANT	\N	PRESENT	0
124446	124155	14159V	PARTICIPANT	\N	PRESENT	0
124447	124155	08009T	PARTICIPANT	\N	PRESENT	0
124454	124155	11107G	PARTICIPANT	\N	PRESENT	0
124456	124455	04043D	PARTICIPANT	\N	PRESENT	0
124457	124155	01019Q	PARTICIPANT	\N	PRESENT	0
124458	124155	11085T	PARTICIPANT	\N	PRESENT	0
124459	124155	11059R	PARTICIPANT	\N	PRESENT	0
124460	124155	01008M	PARTICIPANT	\N	PRESENT	0
124461	124155	01013J	PARTICIPANT	\N	PRESENT	0
124462	124155	14201E	PARTICIPANT	\N	PRESENT	0
124463	124155	11095V	PARTICIPANT	\N	PRESENT	0
124464	124155	14281W	PARTICIPANT	\N	PRESENT	0
124465	124155	14103D	PARTICIPANT	\N	PRESENT	0
124469	124468	04043D	PARTICIPANT	\N	PRESENT	0
124470	124155	04055H	PARTICIPANT	\N	PRESENT	0
124471	124155	95063L	PARTICIPANT	\N	PRESENT	0
124472	124155	04097T	PARTICIPANT	\N	PRESENT	0
124473	124155	04081K	PARTICIPANT	\N	PRESENT	0
124474	124155	05008E	PARTICIPANT	\N	PRESENT	0
124476	124475	04043D	PARTICIPANT	\N	PRESENT	0
124477	124155	14197C	PARTICIPANT	\N	PRESENT	0
124479	124478	04043D	PARTICIPANT	\N	PRESENT	0
124480	124155	14097Y	PARTICIPANT	\N	PRESENT	0
124481	124155	14179A	PARTICIPANT	\N	PRESENT	0
97199	97195	08068F	PARTICIPANT	\N	PRESENT	0
97200	97195	14083S	PARTICIPANT	\N	PRESENT	0
97201	97195	08028W	PARTICIPANT	\N	PRESENT	0
97333	97332	12042Y	PARTICIPANT	\N	PRESENT	0
97334	97332	11091R	PARTICIPANT	\N	PRESENT	0
97335	97332	01008M	PARTICIPANT	\N	PRESENT	0
97336	97332	07029T	PARTICIPANT	\N	PRESENT	0
97206	97195	14257W	PARTICIPANT	\N	PRESENT	0
97207	97195	11066Q	PARTICIPANT	\N	PRESENT	0
97337	97332	11105E	PARTICIPANT	\N	PRESENT	0
97338	97332	01056V	PARTICIPANT	\N	PRESENT	0
97492	94613	14219Q	PARTICIPANT	\N	EXCUSE	0
97513	97512	01056V	PARTICIPANT	\N	PRESENT	0
97515	97514	86044G	PARTICIPANT	\N	PRESENT	0
97516	97514	11027H	PARTICIPANT	\N	PRESENT	0
97520	97519	01014K	PARTICIPANT	\N	PRESENT	0
97522	97521	01014K	PARTICIPANT	\N	PRESENT	0
97524	97523	11015D	PARTICIPANT	\N	PRESENT	0
97525	97523	92031P	PARTICIPANT	\N	PRESENT	0
97526	97523	04054G	PARTICIPANT	\N	PRESENT	0
103695	103112	14195A	PARTICIPANT	\N	PRESENT	0
103696	103112	04049K	PARTICIPANT	\N	PRESENT	0
103697	103112	08048B	PARTICIPANT	\N	PRESENT	0
103698	103112	08041T	PARTICIPANT	\N	PRESENT	0
103699	103112	95035G	PARTICIPANT	\N	PRESENT	0
103700	103112	11011M	PARTICIPANT	\N	PRESENT	0
103701	103112	14026U	PARTICIPANT	\N	PRESENT	0
103707	103112	14073Q	PARTICIPANT	\N	PRESENT	0
103709	103112	11044J	PARTICIPANT	\N	PRESENT	0
103715	103112	14051J	PARTICIPANT	\N	PRESENT	0
103736	103112	14329V	PARTICIPANT	\N	PRESENT	0
103737	103112	14039A	PARTICIPANT	\N	PRESENT	0
103739	103112	11101A	PARTICIPANT	\N	PRESENT	0
103740	103112	08073C	PARTICIPANT	\N	PRESENT	0
103741	103112	11053K	PARTICIPANT	\N	PRESENT	0
103742	103112	01003G	PARTICIPANT	\N	PRESENT	0
103743	103112	11112D	PARTICIPANT	\N	PRESENT	0
103744	103112	14251Q	PARTICIPANT	\N	PRESENT	0
103745	103112	14187A	PARTICIPANT	\N	PRESENT	0
103746	103112	04059M	PARTICIPANT	\N	PRESENT	0
103747	103112	04097T	PARTICIPANT	\N	PRESENT	0
103748	103112	14199E	PARTICIPANT	\N	PRESENT	0
103749	103112	90003B	PARTICIPANT	\N	PRESENT	0
103752	103112	14193X	PARTICIPANT	\N	PRESENT	0
103753	103112	04057K	PARTICIPANT	\N	PRESENT	0
97197	97195	11036J	PARTICIPANT	\N	PRESENT	0
97198	97195	14013P	PARTICIPANT	\N	PRESENT	0
103754	103112	98022P	PARTICIPANT	\N	PRESENT	0
103755	103112	14059S	PARTICIPANT	\N	PRESENT	0
103756	103112	04086Q	PARTICIPANT	\N	PRESENT	0
103757	103112	11034G	PARTICIPANT	\N	PRESENT	0
103758	103112	04050C	PARTICIPANT	\N	PRESENT	0
103911	103113	04085P	PARTICIPANT	\N	PRESENT	0
103907	103113	86034E	PARTICIPANT	\N	PRESENT	0
103909	103908	01028R	PARTICIPANT	\N	PRESENT	0
103910	103113	04050C	PARTICIPANT	\N	PRESENT	0
103912	103113	11056N	PARTICIPANT	\N	PRESENT	0
103913	103113	01059Y	PARTICIPANT	\N	PRESENT	0
103914	103113	98053W	PARTICIPANT	\N	PRESENT	0
103915	103113	01013J	PARTICIPANT	\N	PRESENT	0
103916	103113	01015L	PARTICIPANT	\N	PRESENT	0
103917	103113	04054G	PARTICIPANT	\N	PRESENT	0
103918	103113	14013P	PARTICIPANT	\N	PRESENT	0
103919	103113	11034G	PARTICIPANT	\N	PRESENT	0
103920	103113	92018S	PARTICIPANT	\N	PRESENT	0
103921	103113	08039A	PARTICIPANT	\N	PRESENT	0
103922	103113	08016S	PARTICIPANT	\N	PRESENT	0
103923	103113	95030B	PARTICIPANT	\N	PRESENT	0
103924	103113	08052W	PARTICIPANT	\N	PRESENT	0
103925	103113	98046X	PARTICIPANT	\N	PRESENT	0
103926	103113	08053X	PARTICIPANT	\N	PRESENT	0
103927	103113	14151M	PARTICIPANT	\N	PRESENT	0
103928	103113	14197C	PARTICIPANT	\N	PRESENT	0
103929	103113	01022K	PARTICIPANT	\N	PRESENT	0
103930	103113	80027E	PARTICIPANT	\N	PRESENT	0
103931	103113	11089X	PARTICIPANT	\N	PRESENT	0
103932	103113	11059R	PARTICIPANT	\N	PRESENT	0
103933	103113	11080N	PARTICIPANT	\N	PRESENT	0
103934	103113	08058D	PARTICIPANT	\N	PRESENT	0
103935	103113	98024R	PARTICIPANT	\N	PRESENT	0
103937	103113	14271U	PARTICIPANT	\N	PRESENT	0
103938	103113	14087W	PARTICIPANT	\N	PRESENT	0
103939	103113	10006L	PARTICIPANT	\N	PRESENT	0
103940	103113	04086Q	PARTICIPANT	\N	PRESENT	0
103941	103113	11104D	PARTICIPANT	\N	PRESENT	0
103942	103113	14193X	PARTICIPANT	\N	PRESENT	0
103943	103113	80013X	PARTICIPANT	\N	PRESENT	0
103944	103113	14069U	PARTICIPANT	\N	PRESENT	0
103945	103113	08012N	PARTICIPANT	\N	PRESENT	0
103946	103113	14026U	PARTICIPANT	\N	PRESENT	0
103947	103113	08017T	PARTICIPANT	\N	PRESENT	0
103948	103113	08043V	PARTICIPANT	\N	PRESENT	0
103949	103113	14123H	PARTICIPANT	\N	PRESENT	0
103950	103113	14014Q	PARTICIPANT	\N	PRESENT	0
103951	103113	11014C	PARTICIPANT	\N	PRESENT	0
103952	103113	14191V	PARTICIPANT	\N	PRESENT	0
103953	103113	14109K	PARTICIPANT	\N	PRESENT	0
103954	103113	14031R	PARTICIPANT	\N	PRESENT	0
103955	103113	14207L	PARTICIPANT	\N	PRESENT	0
103956	103113	11112D	PARTICIPANT	\N	PRESENT	0
103957	103113	11049P	PARTICIPANT	\N	PRESENT	0
103958	103113	14121F	PARTICIPANT	\N	PRESENT	0
103959	103113	11071M	PARTICIPANT	\N	PRESENT	0
103960	103113	14329V	PARTICIPANT	\N	PRESENT	0
103961	103113	11074Q	PARTICIPANT	\N	PRESENT	0
103962	103113	11046L	PARTICIPANT	\N	PRESENT	0
103963	103113	77002U	PARTICIPANT	\N	PRESENT	0
103964	103113	14107H	PARTICIPANT	\N	PRESENT	0
103965	103113	90003B	PARTICIPANT	\N	PRESENT	0
103966	103113	11077T	PARTICIPANT	\N	PRESENT	0
103967	103113	04057K	PARTICIPANT	\N	PRESENT	0
103968	103113	04049K	PARTICIPANT	\N	PRESENT	0
103969	103113	04053F	PARTICIPANT	\N	PRESENT	0
103970	103113	11097X	PARTICIPANT	\N	PRESENT	0
103972	103113	14159V	PARTICIPANT	\N	PRESENT	0
103973	103113	14195A	PARTICIPANT	\N	PRESENT	0
103974	103113	01016M	PARTICIPANT	\N	PRESENT	0
103975	103113	07032N	PARTICIPANT	\N	PRESENT	0
103976	103113	11042G	PARTICIPANT	\N	PRESENT	0
103977	103113	14173T	PARTICIPANT	\N	PRESENT	0
103978	103113	86044G	PARTICIPANT	\N	PRESENT	0
103979	103113	11061K	PARTICIPANT	\N	PRESENT	0
103980	103113	10015M	PARTICIPANT	\N	PRESENT	0
103981	103113	07029T	PARTICIPANT	\N	PRESENT	0
103982	103113	08073C	PARTICIPANT	\N	PRESENT	0
103983	103113	14039A	PARTICIPANT	\N	PRESENT	0
103984	103113	14147R	PARTICIPANT	\N	PRESENT	0
103985	103113	14111D	PARTICIPANT	\N	PRESENT	0
103986	103113	92039X	PARTICIPANT	\N	PRESENT	0
103987	103113	14187A	PARTICIPANT	\N	PRESENT	0
103988	103113	01037S	PARTICIPANT	\N	PRESENT	0
103989	103113	01048V	PARTICIPANT	\N	PRESENT	0
103990	103113	11103C	PARTICIPANT	\N	PRESENT	0
103693	103112	05012A	PARTICIPANT	\N	PRESENT	0
103694	103112	01048V	PARTICIPANT	\N	PRESENT	0
103991	103113	98022P	PARTICIPANT	\N	PRESENT	0
103992	103113	14201E	PARTICIPANT	\N	PRESENT	0
103993	103113	01046T	PARTICIPANT	\N	PRESENT	0
103994	103113	08031R	PARTICIPANT	\N	PRESENT	0
103995	103113	08049C	PARTICIPANT	\N	PRESENT	0
103996	103113	08048B	PARTICIPANT	\N	PRESENT	0
103997	103113	14083S	PARTICIPANT	\N	PRESENT	0
103998	103113	14267Y	PARTICIPANT	\N	PRESENT	0
103999	103113	98023Q	PARTICIPANT	\N	PRESENT	0
104000	103113	04081K	PARTICIPANT	\N	PRESENT	0
104001	103113	14103D	PARTICIPANT	\N	PRESENT	0
104002	103113	05012A	PARTICIPANT	\N	PRESENT	0
104003	103113	11096W	PARTICIPANT	\N	PRESENT	0
104004	103113	14265W	PARTICIPANT	\N	PRESENT	0
104005	103113	07026Q	PARTICIPANT	\N	PRESENT	0
104006	103113	01041N	PARTICIPANT	\N	PRESENT	0
104008	103113	01011G	PARTICIPANT	\N	PRESENT	0
104009	103113	14273W	PARTICIPANT	\N	PRESENT	0
104010	104007	95030B	PARTICIPANT	\N	PRESENT	0
104011	103113	14063N	PARTICIPANT	\N	PRESENT	0
104012	104007	04034C	PARTICIPANT	\N	PRESENT	0
104013	104007	01016M	PARTICIPANT	\N	PRESENT	0
104014	103113	14059S	PARTICIPANT	\N	PRESENT	0
104015	103113	04056J	PARTICIPANT	\N	PRESENT	0
104016	103113	08065C	PARTICIPANT	\N	PRESENT	0
104017	103113	11094U	PARTICIPANT	\N	PRESENT	0
104018	103113	14213J	PARTICIPANT	\N	PRESENT	0
104019	103113	08014Q	PARTICIPANT	\N	PRESENT	0
104020	103113	01019Q	PARTICIPANT	\N	PRESENT	0
104021	103113	14227Q	PARTICIPANT	\N	PRESENT	0
104022	103113	95041E	PARTICIPANT	\N	PRESENT	0
104023	103113	02002K	PARTICIPANT	\N	PRESENT	0
104024	103113	04074L	PARTICIPANT	\N	PRESENT	0
99954	99953	08022Q	PARTICIPANT	\N	PRESENT	0
99955	99953	01016M	PARTICIPANT	\N	PRESENT	0
99956	99953	08061X	PARTICIPANT	\N	PRESENT	0
99957	99953	88008L	PARTICIPANT	\N	PRESENT	0
99962	99961	08022Q	PARTICIPANT	\N	PRESENT	0
99963	99961	01016M	PARTICIPANT	\N	PRESENT	0
99964	99961	08061X	PARTICIPANT	\N	PRESENT	0
99966	99961	88008L	PARTICIPANT	\N	PRESENT	0
100157	100156	14097Y	PARTICIPANT	\N	PRESENT	0
107293	99612	01027Q	PARTICIPANT	\N	EXCUSE	0
107294	99612	14039A	PARTICIPANT	\N	EXCUSE	0
107295	99612	11010L	PARTICIPANT	\N	EXCUSE	0
107296	99612	11054L	PARTICIPANT	\N	EXCUSE	0
107307	99612	14053L	PARTICIPANT	\N	EXCUSE	0
110806	110610	08038Y	PARTICIPANT	\N	PRESENT	0
110807	110610	11035H	PARTICIPANT	\N	PRESENT	0
110808	110610	08041T	PARTICIPANT	\N	PRESENT	0
110809	110610	11074Q	PARTICIPANT	\N	PRESENT	0
110810	110610	11071M	PARTICIPANT	\N	PRESENT	0
110811	110610	14085U	PARTICIPANT	\N	PRESENT	0
110812	110610	11091R	PARTICIPANT	\N	PRESENT	0
110813	110610	11067R	PARTICIPANT	\N	PRESENT	0
110814	110610	14065Q	PARTICIPANT	\N	PRESENT	0
110815	110610	11077T	PARTICIPANT	\N	PRESENT	0
110816	110610	11097X	PARTICIPANT	\N	PRESENT	0
110817	110610	14159V	PARTICIPANT	\N	PRESENT	0
110818	110610	01014K	PARTICIPANT	\N	PRESENT	0
110819	110610	14147R	PARTICIPANT	\N	PRESENT	0
110820	110610	14061L	PARTICIPANT	\N	PRESENT	0
110821	110610	14039A	PARTICIPANT	\N	PRESENT	0
110822	110610	04049K	PARTICIPANT	\N	PRESENT	0
110823	110610	14059S	PARTICIPANT	\N	PRESENT	0
110824	110610	11113E	PARTICIPANT	\N	PRESENT	0
110825	110610	08065C	PARTICIPANT	\N	PRESENT	0
110826	110610	11072N	PARTICIPANT	\N	PRESENT	0
110827	110610	14213J	PARTICIPANT	\N	PRESENT	0
110828	110610	11061K	PARTICIPANT	\N	PRESENT	0
110829	110610	11107G	PARTICIPANT	\N	PRESENT	0
110830	110610	08048B	PARTICIPANT	\N	PRESENT	0
110831	110610	11081P	PARTICIPANT	\N	PRESENT	0
110832	110610	04078Q	PARTICIPANT	\N	PRESENT	0
110833	110610	14187A	PARTICIPANT	\N	PRESENT	0
110834	110610	98023Q	PARTICIPANT	\N	PRESENT	0
110835	110610	01008M	PARTICIPANT	\N	PRESENT	0
110836	110610	11090Q	PARTICIPANT	\N	PRESENT	0
110837	110610	01034P	PARTICIPANT	\N	PRESENT	0
110838	110610	11094U	PARTICIPANT	\N	PRESENT	0
110839	110610	14271U	PARTICIPANT	\N	PRESENT	0
110840	110610	05004A	PARTICIPANT	\N	PRESENT	0
110841	110610	04080J	PARTICIPANT	\N	PRESENT	0
110842	110610	14331P	PARTICIPANT	\N	PRESENT	0
110843	110610	01043Q	PARTICIPANT	\N	PRESENT	0
110844	110610	01041N	PARTICIPANT	\N	PRESENT	0
110845	110610	11096W	PARTICIPANT	\N	PRESENT	0
110846	110610	07034Q	PARTICIPANT	\N	PRESENT	0
110847	110610	14267Y	PARTICIPANT	\N	PRESENT	0
110848	110610	98021N	PARTICIPANT	\N	PRESENT	0
110849	110610	14205J	PARTICIPANT	\N	PRESENT	0
110850	110610	11080N	PARTICIPANT	\N	PRESENT	0
110851	110610	01037S	PARTICIPANT	\N	PRESENT	0
110852	110610	14030Q	PARTICIPANT	\N	PRESENT	0
110853	110610	04089T	PARTICIPANT	\N	PRESENT	0
110854	110610	14277B	PARTICIPANT	\N	PRESENT	0
110855	110610	14275Y	PARTICIPANT	\N	PRESENT	0
110856	110610	11103C	PARTICIPANT	\N	PRESENT	0
110857	110610	08017T	PARTICIPANT	\N	PRESENT	0
110858	110610	11093T	PARTICIPANT	\N	PRESENT	0
110859	110610	14083S	PARTICIPANT	\N	PRESENT	0
110860	110610	11082Q	PARTICIPANT	\N	PRESENT	0
110861	110610	11085T	PARTICIPANT	\N	PRESENT	0
110862	110610	14219Q	PARTICIPANT	\N	PRESENT	0
110863	110610	14255U	PARTICIPANT	\N	PRESENT	0
110864	110610	14089Y	PARTICIPANT	\N	PRESENT	0
110865	110610	04070G	PARTICIPANT	\N	PRESENT	0
110866	110610	04036E	PARTICIPANT	\N	PRESENT	0
110867	110610	11015D	PARTICIPANT	\N	PRESENT	0
110868	110610	14327T	PARTICIPANT	\N	PRESENT	0
110869	110610	08022Q	PARTICIPANT	\N	PRESENT	0
110870	110610	04081K	PARTICIPANT	\N	PRESENT	0
110871	110610	09001P	PARTICIPANT	\N	PRESENT	0
110872	110610	14079W	PARTICIPANT	\N	PRESENT	0
110873	110610	08025T	PARTICIPANT	\N	PRESENT	0
110874	110610	95059Q	PARTICIPANT	\N	PRESENT	0
110875	110610	14034U	PARTICIPANT	\N	PRESENT	0
110876	110610	08051V	PARTICIPANT	\N	PRESENT	0
110877	110610	95049N	PARTICIPANT	\N	PRESENT	0
110878	110610	98029W	PARTICIPANT	\N	PRESENT	0
110879	110610	14071N	PARTICIPANT	\N	PRESENT	0
110880	110610	14215L	PARTICIPANT	\N	PRESENT	0
110881	110610	14231L	PARTICIPANT	\N	PRESENT	0
110882	110610	08049C	PARTICIPANT	\N	PRESENT	0
110883	110610	99002P	PARTICIPANT	\N	PRESENT	0
110884	110610	07024N	PARTICIPANT	\N	PRESENT	0
110885	110610	98018T	PARTICIPANT	\N	PRESENT	0
110886	110610	14107H	PARTICIPANT	\N	PRESENT	0
110887	110610	14269B	PARTICIPANT	\N	PRESENT	0
110888	110610	95035G	PARTICIPANT	\N	PRESENT	0
110889	110610	14217N	PARTICIPANT	\N	PRESENT	0
110890	110610	12042Y	PARTICIPANT	\N	PRESENT	0
110891	110610	77002U	PARTICIPANT	\N	PRESENT	0
110892	110610	04045F	PARTICIPANT	\N	PRESENT	0
110893	110610	11053K	PARTICIPANT	\N	PRESENT	0
110894	110610	92039X	PARTICIPANT	\N	PRESENT	0
110895	110610	08035V	PARTICIPANT	\N	PRESENT	0
110896	110610	11106F	PARTICIPANT	\N	PRESENT	0
110897	110610	14209N	PARTICIPANT	\N	PRESENT	0
110898	110610	14135M	PARTICIPANT	\N	PRESENT	0
110899	110610	11030C	PARTICIPANT	\N	PRESENT	0
110900	110610	01007L	PARTICIPANT	\N	PRESENT	0
110901	110610	14103D	PARTICIPANT	\N	PRESENT	0
110902	110610	08056B	PARTICIPANT	\N	PRESENT	0
110903	110610	14273W	PARTICIPANT	\N	PRESENT	0
110904	110610	14111D	PARTICIPANT	\N	PRESENT	0
110905	110610	14241N	PARTICIPANT	\N	PRESENT	0
110910	110610	14263U	PARTICIPANT	\N	PRESENT	0
110907	110610	07032N	PARTICIPANT	\N	PRESENT	0
110908	110610	04061F	PARTICIPANT	\N	PRESENT	0
110909	110610	08018U	PARTICIPANT	\N	PRESENT	0
110911	110610	11100Y	PARTICIPANT	\N	PRESENT	0
110912	110610	08024S	PARTICIPANT	\N	PRESENT	0
110913	110610	11014C	PARTICIPANT	\N	PRESENT	0
110914	110610	11066Q	PARTICIPANT	\N	PRESENT	0
110915	110610	86044G	PARTICIPANT	\N	PRESENT	0
110916	110610	11031D	PARTICIPANT	\N	PRESENT	0
110917	110610	08019V	PARTICIPANT	\N	PRESENT	0
110918	110610	14265W	PARTICIPANT	\N	PRESENT	0
110919	110610	07004J	PARTICIPANT	\N	PRESENT	0
110920	110610	14119M	PARTICIPANT	\N	PRESENT	0
110921	110610	08014Q	PARTICIPANT	\N	PRESENT	0
110922	110610	08010L	PARTICIPANT	\N	PRESENT	0
110923	110610	08044W	PARTICIPANT	\N	PRESENT	0
110924	110610	01047U	PARTICIPANT	\N	PRESENT	0
110925	110610	11064N	PARTICIPANT	\N	PRESENT	0
110926	110610	08058D	PARTICIPANT	\N	PRESENT	0
110927	110610	98053W	PARTICIPANT	\N	PRESENT	0
110928	110610	11033F	PARTICIPANT	\N	PRESENT	0
110929	110610	14259Y	PARTICIPANT	\N	PRESENT	0
110930	110610	14175V	PARTICIPANT	\N	PRESENT	0
110931	110610	14063N	PARTICIPANT	\N	PRESENT	0
110940	110610	14173T	PARTICIPANT	\N	PRESENT	0
110942	110610	11048N	PARTICIPANT	\N	PRESENT	0
110951	110610	04048J	PARTICIPANT	\N	PRESENT	0
110950	110610	14093U	PARTICIPANT	\N	PRESENT	0
110936	110610	96004D	PARTICIPANT	\N	PRESENT	0
110937	110610	14073Q	PARTICIPANT	\N	PRESENT	0
110938	110610	04040A	PARTICIPANT	\N	PRESENT	0
110939	110610	92045V	PARTICIPANT	\N	PRESENT	0
110953	110610	14031R	PARTICIPANT	\N	PRESENT	0
110943	110610	14229S	PARTICIPANT	\N	PRESENT	0
110944	110610	14033T	PARTICIPANT	\N	PRESENT	0
110945	110610	11025F	PARTICIPANT	\N	PRESENT	0
110946	110610	08047A	PARTICIPANT	\N	PRESENT	0
110947	110610	14221J	PARTICIPANT	\N	PRESENT	0
110948	110610	11111C	PARTICIPANT	\N	PRESENT	0
110949	110610	05008E	PARTICIPANT	\N	PRESENT	0
110955	110610	04038G	PARTICIPANT	\N	PRESENT	0
110954	110610	11037K	PARTICIPANT	\N	PRESENT	0
110956	110610	14179A	PARTICIPANT	\N	PRESENT	0
110957	110610	14199E	PARTICIPANT	\N	PRESENT	0
110958	110610	01025N	PARTICIPANT	\N	PRESENT	0
110959	110610	04042C	PARTICIPANT	\N	PRESENT	0
110960	110610	92015P	PARTICIPANT	\N	PRESENT	0
110961	110610	11098Y	PARTICIPANT	\N	PRESENT	0
110962	110610	04059M	PARTICIPANT	\N	PRESENT	0
110963	110610	11104D	PARTICIPANT	\N	PRESENT	0
110964	110610	01028R	PARTICIPANT	\N	PRESENT	0
110965	110610	08016S	PARTICIPANT	\N	PRESENT	0
110966	110610	90003B	PARTICIPANT	\N	PRESENT	0
110967	110610	04079R	PARTICIPANT	\N	PRESENT	0
116809	115993	14259Y	PARTICIPANT	\N	PRESENT	0
116810	115993	11080N	PARTICIPANT	\N	PRESENT	0
116811	115993	14123H	PARTICIPANT	\N	PRESENT	0
116812	115993	14031R	PARTICIPANT	\N	PRESENT	0
116813	115993	14251Q	PARTICIPANT	\N	PRESENT	0
116814	115993	95067Q	PARTICIPANT	\N	PRESENT	0
116815	115993	11048N	PARTICIPANT	\N	PRESENT	0
116816	115993	14147R	PARTICIPANT	\N	PRESENT	0
116817	115993	11097X	PARTICIPANT	\N	PRESENT	0
116818	115993	08047A	PARTICIPANT	\N	PRESENT	0
116819	115993	11049P	PARTICIPANT	\N	PRESENT	0
116820	115993	14195A	PARTICIPANT	\N	PRESENT	0
116821	115993	92040Q	PARTICIPANT	\N	PRESENT	0
116822	115993	14169X	PARTICIPANT	\N	PRESENT	0
116823	115993	14173T	PARTICIPANT	\N	PRESENT	0
116824	115993	14105F	PARTICIPANT	\N	PRESENT	0
116825	115993	14157T	PARTICIPANT	\N	PRESENT	0
116826	115993	14033T	PARTICIPANT	\N	PRESENT	0
116827	115993	08034U	PARTICIPANT	\N	PRESENT	0
116828	115993	92045V	PARTICIPANT	\N	PRESENT	0
116829	115993	11091R	PARTICIPANT	\N	PRESENT	0
116830	115993	08048B	PARTICIPANT	\N	PRESENT	0
116831	115993	14265W	PARTICIPANT	\N	PRESENT	0
116832	115993	14037X	PARTICIPANT	\N	PRESENT	0
116833	115993	08065C	PARTICIPANT	\N	PRESENT	0
116834	115993	14213J	PARTICIPANT	\N	PRESENT	0
116835	115993	04055H	PARTICIPANT	\N	PRESENT	0
116836	115993	07032N	PARTICIPANT	\N	PRESENT	0
116837	115993	07029T	PARTICIPANT	\N	PRESENT	0
116838	115993	14041T	PARTICIPANT	\N	PRESENT	0
116839	115993	14135M	PARTICIPANT	\N	PRESENT	0
116840	115993	04088S	PARTICIPANT	\N	PRESENT	0
116841	115993	11088W	PARTICIPANT	\N	PRESENT	0
116842	115993	14199E	PARTICIPANT	\N	PRESENT	0
116843	115993	14133K	PARTICIPANT	\N	PRESENT	0
116844	115993	01058X	PARTICIPANT	\N	PRESENT	0
116845	115993	98024R	PARTICIPANT	\N	PRESENT	0
116846	115993	77002U	PARTICIPANT	\N	PRESENT	0
116847	115993	14026U	PARTICIPANT	\N	PRESENT	0
116848	115993	01048V	PARTICIPANT	\N	PRESENT	0
116849	115993	98018T	PARTICIPANT	\N	PRESENT	0
116850	115993	95041E	PARTICIPANT	\N	PRESENT	0
116852	115993	01043Q	PARTICIPANT	\N	PRESENT	0
116853	116851	11055M	PARTICIPANT	\N	PRESENT	0
116895	115993	86044G	PARTICIPANT	\N	PRESENT	0
116897	115993	14215L	PARTICIPANT	\N	PRESENT	0
116856	116851	95015C	PARTICIPANT	\N	PRESENT	0
116857	116851	08024S	PARTICIPANT	\N	PRESENT	0
116858	116851	11027H	PARTICIPANT	\N	PRESENT	0
116859	116851	04086Q	PARTICIPANT	\N	PRESENT	0
116860	116851	14079W	PARTICIPANT	\N	PRESENT	0
116861	116851	11088W	PARTICIPANT	\N	PRESENT	0
116862	116851	14215L	PARTICIPANT	\N	PRESENT	0
116863	116851	04089T	PARTICIPANT	\N	PRESENT	0
116864	116851	14187A	PARTICIPANT	\N	PRESENT	0
116865	116851	11034G	PARTICIPANT	\N	PRESENT	0
116928	115993	92018S	PARTICIPANT	\N	PRESENT	0
116867	116851	14231L	PARTICIPANT	\N	PRESENT	0
116868	116851	14179A	PARTICIPANT	\N	PRESENT	0
116869	116851	14213J	PARTICIPANT	\N	PRESENT	0
116870	116851	08031R	PARTICIPANT	\N	PRESENT	0
116871	116851	11100Y	PRESIDENT	0	PRESENT	0
116872	116851	11077T	PARTICIPANT	\N	PRESENT	0
116873	116851	08012N	PARTICIPANT	\N	PRESENT	0
116932	115993	08068F	PARTICIPANT	\N	PRESENT	0
116875	116851	08051V	PARTICIPANT	\N	PRESENT	0
116876	116851	07032N	PARTICIPANT	\N	PRESENT	0
116877	116851	04074L	PARTICIPANT	\N	PRESENT	0
116878	116851	11090Q	PARTICIPANT	\N	PRESENT	0
116933	115993	14111D	PARTICIPANT	\N	PRESENT	0
116952	115993	95049N	PARTICIPANT	\N	PRESENT	0
116881	116851	11046L	PARTICIPANT	\N	PRESENT	0
116882	116851	01028R	PARTICIPANT	\N	PRESENT	0
116883	116851	11094U	PARTICIPANT	\N	PRESENT	0
116884	116851	11037K	PARTICIPANT	\N	PRESENT	0
116885	116851	14157T	PARTICIPANT	\N	PRESENT	0
116886	116851	92045V	PARTICIPANT	\N	PRESENT	0
116887	116851	11066Q	PARTICIPANT	\N	PRESENT	0
116888	116851	14269B	PARTICIPANT	\N	PRESENT	0
116889	115993	04033B	PARTICIPANT	\N	PRESENT	0
116890	115993	10006L	PARTICIPANT	\N	PRESENT	0
116891	115993	04086Q	PARTICIPANT	\N	PRESENT	0
116892	115993	05008E	PARTICIPANT	\N	PRESENT	0
116893	115993	04043D	PARTICIPANT	\N	PRESENT	0
116894	115993	04081K	PARTICIPANT	\N	PRESENT	0
116896	115993	14069U	PARTICIPANT	\N	PRESENT	0
116898	115993	14237S	PARTICIPANT	\N	PRESENT	0
116899	115993	14193X	PARTICIPANT	\N	PRESENT	0
116900	115993	04057K	PARTICIPANT	\N	PRESENT	0
116901	115993	05012A	PARTICIPANT	\N	PRESENT	0
116902	115993	97011G	PARTICIPANT	\N	PRESENT	0
116903	115993	11103C	PARTICIPANT	\N	PRESENT	0
116912	115993	04092N	PARTICIPANT	\N	PRESENT	0
116913	115993	14331P	PARTICIPANT	\N	PRESENT	0
116914	115993	14249W	PARTICIPANT	\N	PRESENT	0
116915	115993	95035G	PARTICIPANT	\N	PRESENT	0
116916	115993	14079W	PARTICIPANT	\N	PRESENT	0
116917	115993	14053L	PARTICIPANT	\N	PRESENT	0
116918	115993	14187A	PARTICIPANT	\N	PRESENT	0
116919	115993	11090Q	PARTICIPANT	\N	PRESENT	0
116920	115993	14217N	PARTICIPANT	\N	PRESENT	0
116921	115993	01008M	PARTICIPANT	\N	PRESENT	0
116922	115993	01041N	PARTICIPANT	\N	PRESENT	0
116923	115993	98050T	PARTICIPANT	\N	PRESENT	0
116924	115993	14061L	PARTICIPANT	\N	PRESENT	0
116925	115993	14059S	PARTICIPANT	\N	PRESENT	0
116926	115993	04056J	PARTICIPANT	\N	PRESENT	0
116927	115993	01016M	PARTICIPANT	\N	PRESENT	0
116953	115993	01056V	PARTICIPANT	\N	PRESENT	0
116954	115993	04061F	PARTICIPANT	\N	PRESENT	0
116972	115993	89017R	PARTICIPANT	\N	PRESENT	0
116992	115993	14089Y	PARTICIPANT	\N	PRESENT	0
117012	115993	14273W	PARTICIPANT	\N	PRESENT	0
117056	117055	08043V	PARTICIPANT	\N	PRESENT	0
117057	117055	07026Q	PARTICIPANT	\N	PRESENT	0
117058	117055	08039A	PARTICIPANT	\N	PRESENT	0
117059	117055	04070G	PARTICIPANT	\N	PRESENT	0
117060	117055	14241N	PARTICIPANT	\N	PRESENT	0
117073	117072	05008E	PRESIDENT	0	PRESENT	0
117074	117072	14069U	PARTICIPANT	\N	PRESENT	0
117075	117072	04047H	PARTICIPANT	\N	PRESENT	0
117076	117072	04038G	PARTICIPANT	\N	PRESENT	0
117077	117072	14259Y	PARTICIPANT	\N	PRESENT	0
117078	117072	01024M	PARTICIPANT	\N	PRESENT	0
117079	117072	14215L	PARTICIPANT	\N	PRESENT	0
117080	117072	11026G	PARTICIPANT	\N	PRESENT	0
117081	117072	14273W	PARTICIPANT	\N	PRESENT	0
117082	117072	14147R	PARTICIPANT	\N	PRESENT	0
117083	117072	95049N	PARTICIPANT	\N	PRESENT	0
117084	117072	08051V	PARTICIPANT	\N	PRESENT	0
117085	117072	07034Q	PARTICIPANT	\N	PRESENT	0
117086	117072	04074L	PARTICIPANT	\N	PRESENT	0
117087	117072	95063L	PARTICIPANT	\N	PRESENT	0
117088	117072	01028R	PARTICIPANT	\N	PRESENT	0
117089	117072	98035U	PARTICIPANT	\N	PRESENT	0
117090	117072	04056J	PARTICIPANT	\N	PRESENT	0
117091	117072	04044E	PARTICIPANT	\N	PRESENT	0
117092	117072	92045V	PARTICIPANT	\N	PRESENT	0
117093	117072	95067Q	PARTICIPANT	\N	PRESENT	0
117094	117072	10015M	PARTICIPANT	\N	EXCUSE	0
117116	117112	01008M	PARTICIPANT	\N	PRESENT	0
117117	117112	11036J	PARTICIPANT	\N	PRESENT	0
117119	117112	14013P	PARTICIPANT	\N	PRESENT	0
117120	117112	08068F	PARTICIPANT	\N	PRESENT	0
117121	117112	14207L	PARTICIPANT	\N	PRESENT	0
117123	117112	90003B	PARTICIPANT	\N	EXCUSE	0
117125	117112	80013X	PARTICIPANT	\N	PRESENT	0
117128	117112	14197C	PARTICIPANT	\N	PRESENT	0
117129	117112	11110B	PARTICIPANT	\N	PRESENT	0
117130	117112	14187A	PARTICIPANT	\N	PRESENT	0
117131	117112	14033T	PARTICIPANT	\N	PRESENT	0
117133	117112	04048J	PARTICIPANT	\N	EXCUSE	0
117134	117112	11099A	PARTICIPANT	\N	PRESENT	0
117135	117112	04049K	PARTICIPANT	\N	PRESENT	0
117138	117112	08015R	PARTICIPANT	\N	EXCUSE	0
117139	117112	11100Y	PRESIDENT	0	PRESENT	0
117140	117112	01061S	PARTICIPANT	\N	EXCUSE	0
117141	117112	11098Y	PARTICIPANT	\N	EXCUSE	0
117144	117112	14205J	PARTICIPANT	\N	PRESENT	0
99592	94613	01022K	PARTICIPANT	\N	EXCUSE	0
99593	94613	14039A	PARTICIPANT	\N	EXCUSE	0
99594	94613	04095R	PARTICIPANT	\N	EXCUSE	0
99633	99632	04040A	PARTICIPANT	\N	PRESENT	0
99634	99632	11083R	PARTICIPANT	\N	PRESENT	0
99793	99792	14133K	PARTICIPANT	\N	PRESENT	0
99794	99792	96004D	PRESIDENT	0	PRESENT	0
99795	99792	14089Y	PARTICIPANT	\N	PRESENT	0
99796	99792	14097Y	PARTICIPANT	\N	PRESENT	0
99797	99792	14073Q	PARTICIPANT	\N	PRESENT	0
99798	99792	14001X	PARTICIPANT	\N	PRESENT	0
99799	99792	14135M	PARTICIPANT	\N	PRESENT	0
99800	99792	01016M	PARTICIPANT	\N	PRESENT	0
99801	99792	04045F	PARTICIPANT	\N	PRESENT	0
99802	99792	98035U	PARTICIPANT	\N	PRESENT	0
99803	99792	92045V	PARTICIPANT	\N	PRESENT	0
99804	99792	11040E	PARTICIPANT	\N	EXCUSE	0
99805	99792	08018U	PARTICIPANT	\N	EXCUSE	0
99806	99792	14026U	PARTICIPANT	\N	EXCUSE	0
99808	99792	04057K	PARTICIPANT	\N	EXCUSE	0
99809	99792	08042U	PARTICIPANT	\N	EXCUSE	0
99835	99834	04040A	PARTICIPANT	\N	PRESENT	0
99837	99834	04035D	PARTICIPANT	\N	PRESENT	0
99839	99834	08016S	PARTICIPANT	\N	PRESENT	0
99841	99834	14097Y	PARTICIPANT	\N	PRESENT	0
99842	99834	14241N	PARTICIPANT	\N	PRESENT	0
99843	99834	08010L	PARTICIPANT	\N	PRESENT	0
99845	99834	11026G	PARTICIPANT	\N	PRESENT	0
107052	106488	14327T	PARTICIPANT	\N	EXCUSE	0
110095	110094	01057W	PARTICIPANT	\N	PRESENT	0
110084	110083	01016M	PARTICIPANT	\N	PRESENT	0
110086	110085	01016M	PARTICIPANT	\N	PRESENT	0
110096	110094	14225N	PARTICIPANT	\N	PRESENT	0
114807	113912	01007L	PARTICIPANT	\N	PRESENT	0
114812	113912	04089T	PARTICIPANT	\N	PRESENT	0
114813	113913	01007L	PARTICIPANT	\N	PRESENT	0
114814	113913	04089T	PARTICIPANT	\N	PRESENT	0
114815	113913	11076S	PARTICIPANT	\N	PRESENT	0
114816	113913	04038G	PARTICIPANT	\N	PRESENT	0
114817	113913	11063M	PARTICIPANT	\N	PRESENT	0
114818	113913	04085P	PARTICIPANT	\N	PRESENT	0
114819	113913	11098Y	PARTICIPANT	\N	PRESENT	0
114820	113913	07034Q	PARTICIPANT	\N	PRESENT	0
114821	113913	14033T	PARTICIPANT	\N	PRESENT	0
114822	113913	04078Q	PARTICIPANT	\N	PRESENT	0
114823	113913	14215L	PARTICIPANT	\N	PRESENT	0
114824	113913	11066Q	PARTICIPANT	\N	PRESENT	0
114825	113913	11036J	PARTICIPANT	\N	PRESENT	0
114826	113913	14159V	PARTICIPANT	\N	PRESENT	0
114827	113913	11110B	PARTICIPANT	\N	PRESENT	0
114828	113913	14267Y	PARTICIPANT	\N	PRESENT	0
114829	113913	14205J	PARTICIPANT	\N	PRESENT	0
114830	113913	11099A	PARTICIPANT	\N	PRESENT	0
114831	113913	11105E	PARTICIPANT	\N	PRESENT	0
114832	113913	14265W	PARTICIPANT	\N	PRESENT	0
114833	113913	10015M	PARTICIPANT	\N	PRESENT	0
114834	113913	90003B	PARTICIPANT	\N	PRESENT	0
114835	113913	11012A	PARTICIPANT	\N	PRESENT	0
114836	113913	14253S	PARTICIPANT	\N	PRESENT	0
114837	113913	14041T	PARTICIPANT	\N	PRESENT	0
114838	113913	14042U	PARTICIPANT	\N	PRESENT	0
114839	113913	14331P	PARTICIPANT	\N	PRESENT	0
114840	113913	14207L	PARTICIPANT	\N	PRESENT	0
114841	113913	14103D	PARTICIPANT	\N	PRESENT	0
114842	113913	92045V	PARTICIPANT	\N	PRESENT	0
114852	113913	08051V	PARTICIPANT	\N	PRESENT	0
114853	113913	99004R	PARTICIPANT	\N	PRESENT	0
114915	113913	14097Y	PARTICIPANT	\N	PRESENT	0
114916	113913	04049K	PARTICIPANT	\N	PRESENT	0
114917	113913	98050T	PARTICIPANT	\N	PRESENT	0
114918	113913	80013X	PARTICIPANT	\N	PRESENT	0
114932	113913	04086Q	PARTICIPANT	\N	PRESENT	0
114933	113913	11104D	PARTICIPANT	\N	PRESENT	0
114934	113913	89017R	PARTICIPANT	\N	PRESENT	0
114935	113913	08069G	PARTICIPANT	\N	PRESENT	0
114936	113913	14195A	PARTICIPANT	\N	PRESENT	0
114937	113913	04045F	PARTICIPANT	\N	PRESENT	0
115074	113939	11077T	PARTICIPANT	\N	PRESENT	0
115075	113939	04053F	PARTICIPANT	\N	PRESENT	0
115076	113939	11039M	PARTICIPANT	\N	PRESENT	0
115077	113939	11070L	PARTICIPANT	\N	PRESENT	0
115078	113939	14042U	PARTICIPANT	\N	PRESENT	0
115079	113939	14205J	PARTICIPANT	\N	PRESENT	0
115080	113939	11012A	PARTICIPANT	\N	PRESENT	0
115081	113939	14265W	PARTICIPANT	\N	PRESENT	0
115082	113939	04071H	PARTICIPANT	\N	PRESENT	0
115083	113939	01024M	PARTICIPANT	\N	PRESENT	0
115084	113939	04043D	PARTICIPANT	\N	PRESENT	0
115085	113939	04057K	PARTICIPANT	\N	PRESENT	0
115086	113939	05008E	PARTICIPANT	\N	PRESENT	0
115087	113939	11032E	PARTICIPANT	\N	PRESENT	0
115088	113939	04045F	PARTICIPANT	\N	PRESENT	0
115089	113939	14271U	PARTICIPANT	\N	PRESENT	0
115090	113939	08009T	PARTICIPANT	\N	PRESENT	0
115091	113939	13002U	PARTICIPANT	\N	PRESENT	0
115092	113939	08061X	PARTICIPANT	\N	PRESENT	0
115093	113939	04056J	PARTICIPANT	\N	PRESENT	0
115094	113939	08069G	PARTICIPANT	\N	PRESENT	0
115095	113939	14175V	PARTICIPANT	\N	PRESENT	0
115096	113939	14041T	PARTICIPANT	\N	PRESENT	0
115097	113939	08051V	PARTICIPANT	\N	PRESENT	0
115098	113939	11083R	PARTICIPANT	\N	PRESENT	0
115099	113939	04066L	PARTICIPANT	\N	PRESENT	0
115100	113939	11080N	PARTICIPANT	\N	PRESENT	0
115101	113939	11033F	PARTICIPANT	\N	PRESENT	0
115102	113939	11088W	PARTICIPANT	\N	PRESENT	0
115103	113939	95062K	PARTICIPANT	\N	PRESENT	0
115104	113939	14038Y	PARTICIPANT	\N	PRESENT	0
115105	113939	04034C	PARTICIPANT	\N	PRESENT	0
115072	113939	01011G	PARTICIPANT	\N	PRESENT	0
115073	113939	11110B	PARTICIPANT	\N	PRESENT	0
115106	113939	14105F	PARTICIPANT	\N	PRESENT	0
115107	113939	11084S	PARTICIPANT	\N	PRESENT	0
115108	113939	08019V	PARTICIPANT	\N	PRESENT	0
115109	113939	11049P	PARTICIPANT	\N	PRESENT	0
115110	113939	01016M	PARTICIPANT	\N	PRESENT	0
115111	113939	95067Q	PARTICIPANT	\N	PRESENT	0
115112	113939	08034U	PARTICIPANT	\N	PRESENT	0
115113	113939	10015M	PARTICIPANT	\N	PRESENT	0
115114	113939	04089T	PARTICIPANT	\N	PRESENT	0
115115	113939	92045V	PARTICIPANT	\N	PRESENT	0
115116	113939	14275Y	PARTICIPANT	\N	PRESENT	0
115117	113939	04081K	PARTICIPANT	\N	PRESENT	0
115118	113939	14033T	PARTICIPANT	\N	PRESENT	0
115119	113939	04054G	PARTICIPANT	\N	PRESENT	0
115120	113939	01013J	PARTICIPANT	\N	PRESENT	0
115121	113939	90003B	PARTICIPANT	\N	PRESENT	0
115122	113939	05012A	PARTICIPANT	\N	PRESENT	0
115123	113939	04050C	PARTICIPANT	\N	PRESENT	0
115124	113939	04085P	PARTICIPANT	\N	PRESENT	0
115125	113939	07024N	PARTICIPANT	\N	PRESENT	0
115126	113939	11031D	PARTICIPANT	\N	PRESENT	0
115127	113939	11063M	PARTICIPANT	\N	PRESENT	0
115128	113939	11103C	PARTICIPANT	\N	PRESENT	0
115129	113939	14037X	PARTICIPANT	\N	PRESENT	0
115130	113939	01015L	PARTICIPANT	\N	PRESENT	0
115131	113939	14217N	PARTICIPANT	\N	PRESENT	0
115132	113939	98018T	PARTICIPANT	\N	PRESENT	0
115133	113939	04086Q	PARTICIPANT	\N	PRESENT	0
115134	113939	77002U	PARTICIPANT	\N	PRESENT	0
115135	113939	11040E	PARTICIPANT	\N	PRESENT	0
115136	113939	14013P	PARTICIPANT	\N	PRESENT	0
115137	113939	01027Q	PARTICIPANT	\N	PRESENT	0
115138	113939	04067M	PARTICIPANT	\N	PRESENT	0
115139	113939	01056V	PARTICIPANT	\N	PRESENT	0
115140	113939	08011M	PARTICIPANT	\N	PRESENT	0
115141	113939	99004R	PARTICIPANT	\N	PRESENT	0
115142	113939	11055M	PARTICIPANT	\N	PRESENT	0
115143	113939	11010L	PARTICIPANT	\N	PRESENT	0
115144	113939	08031R	PARTICIPANT	\N	PRESENT	0
115145	113939	14103D	PARTICIPANT	\N	PRESENT	0
115146	113939	11085T	PARTICIPANT	\N	PRESENT	0
115147	113939	14201E	PARTICIPANT	\N	PRESENT	0
115148	113939	14273W	PARTICIPANT	\N	PRESENT	0
115149	113939	14123H	PARTICIPANT	\N	PRESENT	0
115150	113939	98046X	PARTICIPANT	\N	PRESENT	0
115151	113939	08052W	PARTICIPANT	\N	PRESENT	0
115152	113939	98053W	PARTICIPANT	\N	PRESENT	0
115153	113939	08055A	PARTICIPANT	\N	PRESENT	0
115154	113939	14195A	PARTICIPANT	\N	PRESENT	0
115155	113939	11057P	PARTICIPANT	\N	PRESENT	0
115156	113939	80013X	PARTICIPANT	\N	PRESENT	0
115157	113939	11067R	PARTICIPANT	\N	PRESENT	0
115158	113939	04080J	PARTICIPANT	\N	PRESENT	0
115159	113939	08043V	PARTICIPANT	\N	PRESENT	0
115160	113939	11036J	PARTICIPANT	\N	PRESENT	0
115161	113939	11089X	PARTICIPANT	\N	PRESENT	0
115162	113939	95037J	PARTICIPANT	\N	PRESENT	0
115163	113939	98029W	PARTICIPANT	\N	PRESENT	0
97295	94188	14159V	PARTICIPANT	\N	PRESENT	0
97296	94188	04048J	PARTICIPANT	\N	PRESENT	0
97297	94188	14107H	PARTICIPANT	\N	EXCUSE	0
104027	103113	04078Q	PARTICIPANT	\N	PRESENT	0
104028	103113	14331P	PARTICIPANT	\N	PRESENT	0
104029	103113	95037J	PARTICIPANT	\N	PRESENT	0
104030	103113	97011G	PARTICIPANT	\N	PRESENT	0
104031	103113	04036E	PARTICIPANT	\N	PRESENT	0
104032	103113	11093T	PARTICIPANT	\N	PRESENT	0
104033	103113	11053K	PARTICIPANT	\N	PRESENT	0
104034	103113	14255U	PARTICIPANT	\N	PRESENT	0
104035	103113	14105F	PARTICIPANT	\N	PRESENT	0
104036	103113	11106F	PARTICIPANT	\N	PRESENT	0
104037	103113	04047H	PARTICIPANT	\N	PRESENT	0
104038	103113	01058X	PARTICIPANT	\N	PRESENT	0
104039	103113	11070L	PARTICIPANT	\N	PRESENT	0
104040	103113	01027Q	PARTICIPANT	\N	PRESENT	0
104041	103113	11012A	PARTICIPANT	\N	PRESENT	0
104042	103113	11043H	PARTICIPANT	\N	PRESENT	0
104043	103113	08035V	PARTICIPANT	\N	PRESENT	0
104044	103113	14211G	PARTICIPANT	\N	PRESENT	0
104045	103113	14018U	PARTICIPANT	\N	PRESENT	0
104046	103113	04097T	PARTICIPANT	\N	PRESENT	0
104047	103113	04066L	PARTICIPANT	\N	PRESENT	0
104048	103113	04059M	PARTICIPANT	\N	PRESENT	0
104049	103113	01056V	PARTICIPANT	\N	PRESENT	0
104050	103113	08038Y	PARTICIPANT	\N	PRESENT	0
104051	103113	08022Q	PARTICIPANT	\N	PRESENT	0
104052	103113	04095R	PARTICIPANT	\N	PRESENT	0
104053	103113	14215L	PARTICIPANT	\N	PRESENT	0
104054	103113	14231L	PARTICIPANT	\N	PRESENT	0
104055	103113	04033B	PARTICIPANT	\N	PRESENT	0
104056	103113	01007L	PARTICIPANT	\N	PRESENT	0
104057	103113	01047U	PARTICIPANT	\N	PRESENT	0
104058	103113	04043D	PARTICIPANT	\N	PRESENT	0
104059	103113	01008M	PARTICIPANT	\N	PRESENT	0
104060	103113	04089T	PARTICIPANT	\N	PRESENT	0
104026	103113	08041T	PARTICIPANT	\N	PRESENT	0
104061	103113	14038Y	PARTICIPANT	\N	PRESENT	0
104062	103113	14037X	PARTICIPANT	\N	PRESENT	0
104063	103113	98021N	PARTICIPANT	\N	PRESENT	0
104064	103113	14199E	PARTICIPANT	\N	PRESENT	0
104065	103113	08018U	PARTICIPANT	\N	PRESENT	0
104072	103113	14223L	PARTICIPANT	\N	PRESENT	0
104073	103113	05008E	PARTICIPANT	\N	PRESENT	0
104074	103113	95059Q	PARTICIPANT	\N	PRESENT	0
104075	103113	14051J	PARTICIPANT	\N	PRESENT	0
104076	103113	08025T	PARTICIPANT	\N	PRESENT	0
104077	103113	11098Y	PARTICIPANT	\N	PRESENT	0
104078	103113	11040E	PARTICIPANT	\N	PRESENT	0
104079	103113	08010L	PARTICIPANT	\N	PRESENT	0
104080	103113	12041X	PARTICIPANT	\N	PRESENT	0
104081	103113	14253S	PARTICIPANT	\N	PRESENT	0
104082	103113	95062K	PARTICIPANT	\N	PRESENT	0
104083	103113	11031D	PARTICIPANT	\N	PRESENT	0
104084	103113	14017T	PARTICIPANT	\N	PRESENT	0
104085	103113	95067Q	PARTICIPANT	\N	PRESENT	0
104086	103113	04067M	PARTICIPANT	\N	PRESENT	0
104087	103113	11076S	PARTICIPANT	\N	PRESENT	0
104088	103113	01044R	PARTICIPANT	\N	PRESENT	0
104089	103113	11033F	PARTICIPANT	\N	PRESENT	0
104090	103113	92031P	PARTICIPANT	\N	PRESENT	0
104091	103113	11029K	PARTICIPANT	\N	PRESENT	0
104092	103113	11055M	PARTICIPANT	\N	PRESENT	0
104093	103113	11099A	PARTICIPANT	\N	PRESENT	0
104094	103113	13002U	PARTICIPANT	\N	PRESENT	0
104095	103113	14251Q	PARTICIPANT	\N	PRESENT	0
104096	103113	95035G	PARTICIPANT	\N	PRESENT	0
104097	103113	89017R	PARTICIPANT	\N	PRESENT	0
104098	103113	01060R	PARTICIPANT	\N	PRESENT	0
104099	103113	14247U	PARTICIPANT	\N	PRESENT	0
104100	103113	14239U	PARTICIPANT	\N	PRESENT	0
104101	103113	14241N	PARTICIPANT	\N	PRESENT	0
104102	103113	11044J	PARTICIPANT	\N	PRESENT	0
104103	103113	08051V	PARTICIPANT	\N	PRESENT	0
104104	103113	11030C	PARTICIPANT	\N	PRESENT	0
104105	103113	11100Y	PARTICIPANT	\N	PRESENT	0
104106	103113	11101A	PARTICIPANT	\N	PRESENT	0
104107	103113	92015P	PARTICIPANT	\N	PRESENT	0
104108	103113	11011M	PARTICIPANT	\N	PRESENT	0
104109	103113	01031L	PARTICIPANT	\N	PRESENT	0
104110	103113	08055A	PARTICIPANT	\N	PRESENT	0
104111	103113	08047A	PARTICIPANT	\N	PRESENT	0
104112	103113	01061S	PARTICIPANT	\N	PRESENT	0
104113	103113	11027H	PARTICIPANT	\N	PRESENT	0
104114	103113	11084S	PARTICIPANT	\N	PRESENT	0
104115	103113	14028W	PARTICIPANT	\N	PRESENT	0
104116	103113	92020L	PARTICIPANT	\N	PRESENT	0
104117	103113	08060W	PARTICIPANT	\N	PRESENT	0
104118	103113	08068F	PARTICIPANT	\N	PRESENT	0
104119	103113	14249W	PARTICIPANT	\N	PRESENT	0
104120	103113	01057W	PARTICIPANT	\N	PRESENT	0
104121	103113	11105E	PARTICIPANT	\N	PRESENT	0
104122	103113	04071H	PARTICIPANT	\N	PRESENT	0
104123	103113	04034C	PARTICIPANT	\N	PRESENT	0
104124	103113	07024N	PARTICIPANT	\N	PRESENT	0
104125	103113	11015D	PARTICIPANT	\N	PRESENT	0
104126	103113	14167V	PARTICIPANT	\N	PRESENT	0
104127	103113	11054L	PARTICIPANT	\N	PRESENT	0
104128	103113	11026G	PARTICIPANT	\N	PRESENT	0
104129	103113	04092N	PARTICIPANT	\N	PRESENT	0
104130	103113	83047W	PARTICIPANT	\N	PRESENT	0
104131	103113	08011M	PARTICIPANT	\N	PRESENT	0
104132	103113	14281W	PARTICIPANT	\N	PRESENT	0
104133	103113	14229S	PARTICIPANT	\N	PRESENT	0
104134	103113	14033T	PARTICIPANT	\N	PRESENT	0
104135	103113	14135M	PARTICIPANT	\N	PRESENT	0
104136	103113	92045V	PARTICIPANT	\N	PRESENT	0
104137	103113	14097Y	PARTICIPANT	\N	PRESENT	0
104138	103113	98005N	PARTICIPANT	\N	PRESENT	0
104139	103113	14257W	PARTICIPANT	\N	PRESENT	0
104140	103113	08015R	PARTICIPANT	\N	PRESENT	0
104141	103113	14061L	PARTICIPANT	\N	PRESENT	0
104142	103113	14093U	PARTICIPANT	\N	PRESENT	0
104143	103113	14085U	PARTICIPANT	\N	PRESENT	0
104144	103113	98050T	PARTICIPANT	\N	PRESENT	0
104145	103113	83042R	PARTICIPANT	\N	PRESENT	0
104146	103113	14065Q	PARTICIPANT	\N	PRESENT	0
104147	103113	11109J	PARTICIPANT	\N	PRESENT	0
104148	103113	14269B	PARTICIPANT	\N	PRESENT	0
104150	103113	11088W	PARTICIPANT	\N	PRESENT	0
104151	103113	04045F	PARTICIPANT	\N	PRESENT	0
104152	103113	14133K	PARTICIPANT	\N	PRESENT	0
104153	103113	11083R	PARTICIPANT	\N	PRESENT	0
104154	103113	04079R	PARTICIPANT	\N	PRESENT	0
104155	103113	11067R	PARTICIPANT	\N	PRESENT	0
104156	103113	08034U	PARTICIPANT	\N	PRESENT	0
104157	103113	04088S	PARTICIPANT	\N	PRESENT	0
104158	103113	11091R	PARTICIPANT	\N	PRESENT	0
104159	103113	14053L	PARTICIPANT	\N	PRESENT	0
104160	103113	11035H	PARTICIPANT	\N	PRESENT	0
104161	103113	08024S	PARTICIPANT	\N	PRESENT	0
104162	103113	01028R	PARTICIPANT	\N	PRESENT	0
104163	103113	08061X	PARTICIPANT	\N	PRESENT	0
104164	103113	04077P	PARTICIPANT	\N	PRESENT	0
104165	103113	11090Q	PARTICIPANT	\N	PRESENT	0
104166	103113	99002P	PARTICIPANT	\N	PRESENT	0
104167	103113	11095V	PARTICIPANT	\N	PRESENT	0
104168	103113	14169X	PARTICIPANT	\N	PRESENT	0
104169	103113	11032E	PARTICIPANT	\N	PRESENT	0
104170	103113	01003G	PARTICIPANT	\N	PRESENT	0
104171	103113	05004A	PARTICIPANT	\N	PRESENT	0
104172	103113	14221J	PARTICIPANT	\N	PRESENT	0
104175	103113	14219Q	PARTICIPANT	\N	PRESENT	0
104176	103113	14205J	PARTICIPANT	\N	PRESENT	0
104177	103113	04040A	PARTICIPANT	\N	PRESENT	0
104178	103113	08009T	PARTICIPANT	\N	PRESENT	0
104179	103113	01034P	PARTICIPANT	\N	PRESENT	0
104180	103113	01043Q	PARTICIPANT	\N	PRESENT	0
104181	103113	01025N	PARTICIPANT	\N	PRESENT	0
104182	103113	09001P	PARTICIPANT	\N	PRESENT	0
104183	103113	08056B	PARTICIPANT	\N	PRESENT	0
104184	103113	04070G	PARTICIPANT	\N	PRESENT	0
104185	103113	98042T	PARTICIPANT	\N	PRESENT	0
104197	103113	11039M	PARTICIPANT	\N	PRESENT	0
104187	103113	14089Y	PARTICIPANT	\N	PRESENT	0
104188	103113	11111C	PARTICIPANT	\N	PRESENT	0
104189	103113	14034U	PARTICIPANT	\N	PRESENT	0
104190	103113	04038G	PARTICIPANT	\N	PRESENT	0
104191	103113	08069G	PARTICIPANT	\N	PRESENT	0
104192	103113	01014K	PARTICIPANT	\N	PRESENT	0
104193	103113	11037K	PARTICIPANT	\N	PRESENT	0
104194	103113	12042Y	PARTICIPANT	\N	PRESENT	0
104195	103113	11085T	PARTICIPANT	\N	PRESENT	0
104196	103113	11063M	PARTICIPANT	\N	PRESENT	0
100153	100152	11088W	PARTICIPANT	\N	PRESENT	0
100155	100154	11088W	PARTICIPANT	\N	PRESENT	0
100159	100158	14028W	PARTICIPANT	\N	PRESENT	0
100413	100411	04034C	PARTICIPANT	\N	PRESENT	0
100415	100411	01016M	PARTICIPANT	\N	PRESENT	0
102953	102952	14079W	PARTICIPANT	\N	PRESENT	0
102954	102952	04067M	PARTICIPANT	\N	PRESENT	0
102955	102952	14217N	PARTICIPANT	\N	PRESENT	0
102956	102952	14042U	PARTICIPANT	\N	PRESENT	0
102957	102952	14249W	PARTICIPANT	\N	PRESENT	0
102958	102952	08034U	PARTICIPANT	\N	PRESENT	0
102959	102952	14265W	PARTICIPANT	\N	PRESENT	0
102960	102952	83047W	PARTICIPANT	\N	PRESENT	0
102961	102952	14235Q	PARTICIPANT	\N	PRESENT	0
102962	102952	11046L	PARTICIPANT	\N	PRESENT	0
102963	102952	04045F	PARTICIPANT	\N	PRESENT	0
102964	102952	01034P	PRESIDENT	0	PRESENT	0
102965	102952	92045V	PARTICIPANT	\N	PRESENT	0
102966	102952	11066Q	PARTICIPANT	\N	PRESENT	0
102967	102952	01059Y	PARTICIPANT	\N	EXCUSE	0
102970	102969	04067M	PARTICIPANT	\N	PRESENT	0
102971	102969	14079W	PARTICIPANT	\N	PRESENT	0
110968	110610	11054L	PARTICIPANT	\N	PRESENT	0
102973	102969	14217N	PARTICIPANT	\N	PRESENT	0
110969	110610	04056J	PARTICIPANT	\N	PRESENT	0
110970	110610	11110B	PARTICIPANT	\N	PRESENT	0
102976	102969	83047W	PARTICIPANT	\N	PRESENT	0
110971	110610	11027H	PARTICIPANT	\N	PRESENT	0
102978	102969	11046L	PARTICIPANT	\N	PRESENT	0
110972	110610	98042T	PARTICIPANT	\N	PRESENT	0
102980	102969	01034P	PRESIDENT	\N	PRESENT	0
110973	110610	11083R	PARTICIPANT	\N	PRESENT	0
110974	110610	14053L	PARTICIPANT	\N	PRESENT	0
102983	102969	92045V	PARTICIPANT	\N	PRESENT	0
102984	102969	01059Y	PARTICIPANT	\N	EXCUSE	0
102993	102992	14083S	PARTICIPANT	\N	PRESENT	0
102994	102992	14038Y	PARTICIPANT	\N	PRESENT	0
102995	102992	14079W	PARTICIPANT	\N	PRESENT	0
102996	102992	04089T	PARTICIPANT	\N	PRESENT	0
102997	102992	14033T	PARTICIPANT	\N	PRESENT	0
102998	102992	11100Y	PARTICIPANT	\N	PRESENT	0
102999	102992	14257W	PARTICIPANT	\N	PRESENT	0
103000	102992	14071N	PARTICIPANT	\N	PRESENT	0
103001	102992	04088S	PARTICIPANT	\N	PRESENT	0
103002	102992	98050T	PARTICIPANT	\N	PRESENT	0
103003	102992	01016M	PARTICIPANT	\N	PRESENT	0
103004	102992	11012A	PARTICIPANT	\N	PRESENT	0
103005	102992	92045V	PARTICIPANT	\N	PRESENT	0
103006	102992	95067Q	PARTICIPANT	\N	PRESENT	0
103008	103007	14033T	PARTICIPANT	\N	PRESENT	0
103010	103009	14033T	PARTICIPANT	\N	PRESENT	0
103013	103012	11015D	PARTICIPANT	\N	PRESENT	0
103014	103012	92031P	PARTICIPANT	\N	PRESENT	0
103033	103032	11111C	PARTICIPANT	\N	PRESENT	0
103035	103034	11111C	PARTICIPANT	\N	PRESENT	0
110975	110610	98035U	PARTICIPANT	\N	PRESENT	0
110979	110610	14251Q	PARTICIPANT	\N	PRESENT	0
110977	110610	11042G	PARTICIPANT	\N	PRESENT	0
110981	110610	04034C	PARTICIPANT	\N	PRESENT	0
110980	110610	14207L	PARTICIPANT	\N	PRESENT	0
110982	110610	11089X	PARTICIPANT	\N	PRESENT	0
110983	110610	14017T	PARTICIPANT	\N	PRESENT	0
110984	110610	83047W	PARTICIPANT	\N	PRESENT	0
110985	110610	11039M	PARTICIPANT	\N	PRESENT	0
110992	110610	08039A	PARTICIPANT	\N	PRESENT	0
110993	110630	98053W	PARTICIPANT	\N	PRESENT	0
110994	110630	04038G	PARTICIPANT	\N	PRESENT	0
110995	110630	01022K	PARTICIPANT	\N	PRESENT	0
110996	110630	04034C	PARTICIPANT	\N	PRESENT	0
110997	110630	11034G	PARTICIPANT	\N	PRESENT	0
110998	110630	14014Q	PARTICIPANT	\N	PRESENT	0
110999	110630	14271U	PARTICIPANT	\N	PRESENT	0
111000	110630	11061K	PARTICIPANT	\N	PRESENT	0
111001	110630	11033F	PARTICIPANT	\N	PRESENT	0
111002	110630	11012A	PARTICIPANT	\N	PRESENT	0
111003	110630	08009T	PARTICIPANT	\N	PRESENT	0
111004	110630	14030Q	PARTICIPANT	\N	PRESENT	0
111005	110630	14042U	PARTICIPANT	\N	PRESENT	0
111006	110630	14205J	PARTICIPANT	\N	PRESENT	0
111007	110630	14275Y	PARTICIPANT	\N	PRESENT	0
111008	110630	01024M	PARTICIPANT	\N	PRESENT	0
111009	110630	01025N	PARTICIPANT	\N	PRESENT	0
111010	110630	14273W	PARTICIPANT	\N	PRESENT	0
111011	110630	04088S	PARTICIPANT	\N	PRESENT	0
111012	110630	14135M	PARTICIPANT	\N	PRESENT	0
111013	110630	08018U	PARTICIPANT	\N	PRESENT	0
111014	110630	07029T	PARTICIPANT	\N	PRESENT	0
111015	110630	14223L	PARTICIPANT	\N	PRESENT	0
111016	110630	98018T	PARTICIPANT	\N	PRESENT	0
111017	110630	11026G	PARTICIPANT	\N	PRESENT	0
111018	110630	08069G	PARTICIPANT	\N	PRESENT	0
111019	110630	95049N	PARTICIPANT	\N	PRESENT	0
111020	110630	08049C	PARTICIPANT	\N	PRESENT	0
111021	110630	14331P	PARTICIPANT	\N	PRESENT	0
111022	110630	14265W	PARTICIPANT	\N	PRESENT	0
111023	110630	11072N	PARTICIPANT	\N	PRESENT	0
111024	110630	08052W	PARTICIPANT	\N	PRESENT	0
111025	110630	14199E	PARTICIPANT	\N	PRESENT	0
111026	110630	11027H	PARTICIPANT	\N	PRESENT	0
111027	110630	14247U	PARTICIPANT	\N	PRESENT	0
111028	110630	14249W	PARTICIPANT	\N	PRESENT	0
111029	110630	14159V	PARTICIPANT	\N	PRESENT	0
111030	110630	11029K	PARTICIPANT	\N	PRESENT	0
111031	110630	04067M	PARTICIPANT	\N	PRESENT	0
111032	110630	14215L	PARTICIPANT	\N	PRESENT	0
111033	110630	95063L	PARTICIPANT	\N	PRESENT	0
111034	110630	04035D	PARTICIPANT	\N	PRESENT	0
111035	110630	14211G	PARTICIPANT	\N	PRESENT	0
111036	110630	01041N	PARTICIPANT	\N	PRESENT	0
111037	110630	95015C	PARTICIPANT	\N	PRESENT	0
111038	110630	05008E	PARTICIPANT	\N	PRESENT	0
111039	110630	11094U	PARTICIPANT	\N	PRESENT	0
111040	110630	04071H	PARTICIPANT	\N	PRESENT	0
111041	110630	14281W	PARTICIPANT	\N	PRESENT	0
111042	110630	11076S	PARTICIPANT	\N	PRESENT	0
111043	110630	01008M	PARTICIPANT	\N	PRESENT	0
111044	110630	14033T	PARTICIPANT	\N	PRESENT	0
111045	110630	14217N	PARTICIPANT	\N	PRESENT	0
111052	110630	14187A	PARTICIPANT	\N	PRESENT	0
111054	110253	01007L	PARTICIPANT	\N	PRESENT	0
111055	110253	04038G	PARTICIPANT	\N	PRESENT	0
111056	110253	05008E	PARTICIPANT	\N	PRESENT	0
111057	110253	11027H	PARTICIPANT	\N	PRESENT	0
111058	110253	11033F	PARTICIPANT	\N	PRESENT	0
111059	110253	11012A	PARTICIPANT	\N	PRESENT	0
111060	110253	14018U	PARTICIPANT	\N	PRESENT	0
111061	110253	11094U	PARTICIPANT	\N	PRESENT	0
111062	110253	14031R	PARTICIPANT	\N	PRESENT	0
111063	110253	14211G	PARTICIPANT	\N	PRESENT	0
111064	110253	14199E	PARTICIPANT	\N	PRESENT	0
111065	110253	11043H	PARTICIPANT	\N	PRESENT	0
111066	110253	01025N	PARTICIPANT	\N	PRESENT	0
111067	110253	95015C	PARTICIPANT	\N	PRESENT	0
111068	110253	11034G	PARTICIPANT	\N	PRESENT	0
111069	110253	14215L	PARTICIPANT	\N	PRESENT	0
111070	110253	11026G	PARTICIPANT	\N	PRESENT	0
111071	110253	11105E	PARTICIPANT	\N	PRESENT	0
111072	110253	98018T	PARTICIPANT	\N	PRESENT	0
111073	110253	14275Y	PARTICIPANT	\N	PRESENT	0
111074	110253	01041N	PARTICIPANT	\N	PRESENT	0
111075	110253	14033T	PARTICIPANT	\N	PRESENT	0
111076	110253	01008M	PARTICIPANT	\N	PRESENT	0
111077	110253	14147R	PARTICIPANT	\N	PRESENT	0
111078	110253	01024M	PARTICIPANT	\N	PRESENT	0
111092	110253	01046T	PARTICIPANT	\N	PRESENT	0
111093	110253	08051V	PARTICIPANT	\N	PRESENT	0
111094	110253	95063L	PARTICIPANT	\N	PRESENT	0
111095	110253	08018U	PARTICIPANT	\N	PRESENT	0
111096	110253	92045V	PARTICIPANT	\N	PRESENT	0
111097	110253	14265W	PARTICIPANT	\N	PRESENT	0
111098	110253	08047A	PARTICIPANT	\N	PRESENT	0
111099	110253	01028R	PARTICIPANT	\N	PRESENT	0
111100	110253	80013X	PARTICIPANT	\N	PRESENT	0
111101	110253	14135M	PARTICIPANT	\N	PRESENT	0
111102	110253	95049N	PARTICIPANT	\N	PRESENT	0
111103	110253	14331P	PARTICIPANT	\N	PRESENT	0
111104	110253	07029T	PARTICIPANT	\N	PRESENT	0
111105	110253	14213J	PARTICIPANT	\N	PRESENT	0
111106	110253	08048B	PARTICIPANT	\N	PRESENT	0
97632	95978	08024S	PARTICIPANT	\N	PRESENT	0
97655	95978	11023D	PARTICIPANT	\N	PRESENT	0
97656	95978	14269B	PARTICIPANT	\N	PRESENT	0
97658	95978	11103C	PARTICIPANT	\N	PRESENT	0
97660	95978	11031D	PARTICIPANT	\N	PRESENT	0
97661	95978	14271U	PARTICIPANT	\N	PRESENT	0
97662	95978	12042Y	PARTICIPANT	\N	PRESENT	0
97663	95978	11093T	PARTICIPANT	\N	PRESENT	0
97665	95978	11055M	PARTICIPANT	\N	PRESENT	0
97667	95978	11097X	PARTICIPANT	\N	PRESENT	0
97668	95978	95062K	PARTICIPANT	\N	PRESENT	0
97670	95978	14191V	PARTICIPANT	\N	PRESENT	0
97672	95978	04086Q	PARTICIPANT	\N	PRESENT	0
97674	95978	14085U	PARTICIPANT	\N	PRESENT	0
97675	95978	11067R	PARTICIPANT	\N	PRESENT	0
97676	95978	14051J	PARTICIPANT	\N	PRESENT	0
97677	95978	14213J	PARTICIPANT	\N	PRESENT	0
97678	95978	14151M	PARTICIPANT	\N	PRESENT	0
97679	95978	01059Y	PARTICIPANT	\N	PRESENT	0
97680	95978	11063M	PARTICIPANT	\N	PRESENT	0
97681	95978	11040E	PARTICIPANT	\N	PRESENT	0
97682	95978	14001X	PARTICIPANT	\N	PRESENT	0
97683	95978	11112D	PARTICIPANT	\N	PRESENT	0
97684	95978	04092N	PARTICIPANT	\N	PRESENT	0
97685	95978	98046X	PARTICIPANT	\N	PRESENT	0
97686	95978	08052W	PARTICIPANT	\N	PRESENT	0
117252	116619	08024S	PARTICIPANT	\N	PRESENT	0
97689	95978	11081P	PARTICIPANT	\N	PRESENT	0
97690	95978	11036J	PARTICIPANT	\N	PRESENT	0
97691	95978	14026U	PARTICIPANT	\N	PRESENT	0
97692	95978	08010L	PARTICIPANT	\N	PRESENT	0
97693	95978	14239U	PARTICIPANT	\N	PRESENT	0
97696	95978	14038Y	PARTICIPANT	\N	PRESENT	0
97698	95978	14223L	PARTICIPANT	\N	PRESENT	0
97699	95978	11014C	PARTICIPANT	\N	PRESENT	0
97700	95978	14241N	PARTICIPANT	\N	PRESENT	0
97701	95978	11061K	PARTICIPANT	\N	PRESENT	0
97702	95978	11046L	PARTICIPANT	\N	PRESENT	0
97703	95978	14042U	PARTICIPANT	\N	PRESENT	0
97704	95978	14221J	PARTICIPANT	\N	PRESENT	0
97705	95978	01027Q	PARTICIPANT	\N	PRESENT	0
97706	95978	14031R	PARTICIPANT	\N	PRESENT	0
97707	95978	87003B	PARTICIPANT	\N	PRESENT	0
97708	95978	05012A	PARTICIPANT	\N	PRESENT	0
97709	95978	14265W	PARTICIPANT	\N	PRESENT	0
97710	95978	08048B	PARTICIPANT	\N	PRESENT	0
97711	95978	14071N	PARTICIPANT	\N	PRESENT	0
97712	95978	11025F	PARTICIPANT	\N	PRESENT	0
97713	95978	14195A	PARTICIPANT	\N	PRESENT	0
97714	95978	14105F	PARTICIPANT	\N	PRESENT	0
97715	95978	11057P	PARTICIPANT	\N	PRESENT	0
97719	95978	01003G	PARTICIPANT	\N	PRESENT	0
97717	95978	04044E	PARTICIPANT	\N	PRESENT	0
97718	95978	14267Y	PARTICIPANT	\N	PRESENT	0
97720	95978	14030Q	PARTICIPANT	\N	PRESENT	0
97721	95978	98050T	PARTICIPANT	\N	PRESENT	0
97722	95978	08065C	PARTICIPANT	\N	PRESENT	0
97723	95978	14205J	PARTICIPANT	\N	PRESENT	0
97724	95978	01060R	PARTICIPANT	\N	PRESENT	0
97725	95978	01025N	PARTICIPANT	\N	PRESENT	0
97726	95978	14013P	PARTICIPANT	\N	PRESENT	0
97727	95978	01013J	PARTICIPANT	\N	PRESENT	0
97728	95978	07026Q	PARTICIPANT	\N	PRESENT	0
97729	95978	14235Q	PARTICIPANT	\N	PRESENT	0
97730	95978	08069G	PARTICIPANT	\N	PRESENT	0
97731	95978	14219Q	PARTICIPANT	\N	PRESENT	0
97732	95978	11101A	PARTICIPANT	\N	PRESENT	0
97733	95978	14063N	PARTICIPANT	\N	PRESENT	0
97734	95978	08049C	PARTICIPANT	\N	PRESENT	0
97735	95978	04053F	PARTICIPANT	\N	PRESENT	0
97736	95978	14187A	PARTICIPANT	\N	PRESENT	0
97737	95978	14225N	PARTICIPANT	\N	PRESENT	0
97738	95978	14083S	PARTICIPANT	\N	PRESENT	0
97739	95978	08019V	PARTICIPANT	\N	PRESENT	0
97740	95978	92045V	PARTICIPANT	\N	PRESENT	0
97741	95978	01048V	PARTICIPANT	\N	PRESENT	0
97742	95978	01031L	PARTICIPANT	\N	PRESENT	0
97743	95978	14133K	PARTICIPANT	\N	PRESENT	0
97773	95978	14053L	PARTICIPANT	\N	PRESENT	0
97774	95978	01056V	PARTICIPANT	\N	PRESENT	0
97775	95978	04088S	PARTICIPANT	\N	PRESENT	0
97776	95978	01024M	PARTICIPANT	\N	PRESENT	0
97777	95978	08055A	PARTICIPANT	\N	PRESENT	0
97778	95978	14331P	PARTICIPANT	\N	PRESENT	0
97780	95978	04045F	PARTICIPANT	\N	PRESENT	0
97781	95978	11084S	PARTICIPANT	\N	PRESENT	0
97782	95978	14159V	PARTICIPANT	\N	PRESENT	0
97783	95978	11034G	PARTICIPANT	\N	PRESENT	0
97784	95978	14255U	PARTICIPANT	\N	PRESENT	0
97785	95978	14215L	PARTICIPANT	\N	PRESENT	0
97786	95978	14327T	PARTICIPANT	\N	PRESENT	0
97787	95978	11082Q	PARTICIPANT	\N	PRESENT	0
97788	95978	80013X	PARTICIPANT	\N	PRESENT	0
97789	95978	92015P	PARTICIPANT	\N	PRESENT	0
97790	95978	14173T	PARTICIPANT	\N	PRESENT	0
97791	95978	08028W	PARTICIPANT	\N	PRESENT	0
97792	95978	11071M	PARTICIPANT	\N	PRESENT	0
97793	95978	14157T	PARTICIPANT	\N	PRESENT	0
97794	95978	14273W	PARTICIPANT	\N	PRESENT	0
97795	95978	86044G	PARTICIPANT	\N	PRESENT	0
97796	95978	11096W	PARTICIPANT	\N	PRESENT	0
97797	95978	95015C	PARTICIPANT	\N	PRESENT	0
97798	95978	14135M	PARTICIPANT	\N	PRESENT	0
97799	95978	95031C	PARTICIPANT	\N	PRESENT	0
97800	95978	04036E	PARTICIPANT	\N	PRESENT	0
97801	95978	11090Q	PARTICIPANT	\N	PRESENT	0
97802	95978	11098Y	PARTICIPANT	\N	PRESENT	0
97803	95978	14193X	PARTICIPANT	\N	PRESENT	0
97804	95978	14065Q	PARTICIPANT	\N	PRESENT	0
97805	95978	14107H	PARTICIPANT	\N	PRESENT	0
97806	95978	08031R	PARTICIPANT	\N	PRESENT	0
97807	95978	11104D	PARTICIPANT	\N	PRESENT	0
97808	95978	11035H	PARTICIPANT	\N	PRESENT	0
97809	95978	14201E	PARTICIPANT	\N	PRESENT	0
97810	95978	14197C	PARTICIPANT	\N	PRESENT	0
117272	116619	11040E	PARTICIPANT	\N	PRESENT	0
117146	117112	14257W	PARTICIPANT	\N	PRESENT	0
117147	117112	08021P	PARTICIPANT	\N	EXCUSE	0
117148	117112	04088S	PARTICIPANT	\N	PRESENT	0
117149	117112	98050T	PARTICIPANT	\N	PRESENT	0
117150	117112	11090Q	PARTICIPANT	\N	PRESENT	0
117151	117112	11046L	PARTICIPANT	\N	PRESENT	0
117152	117112	01058X	PARTICIPANT	\N	PRESENT	0
117153	117112	11094U	PARTICIPANT	\N	PRESENT	0
117154	117112	11066Q	PARTICIPANT	\N	PRESENT	0
117214	117212	08055A	PARTICIPANT	\N	PRESENT	0
117273	116619	08011M	PARTICIPANT	\N	PRESENT	0
117274	116619	01031L	PARTICIPANT	\N	PRESENT	0
117275	116619	11070L	PARTICIPANT	\N	PRESENT	0
117218	117212	08060W	PARTICIPANT	\N	PRESENT	0
117219	117212	11095V	PARTICIPANT	\N	PRESENT	0
117276	116619	04088S	PARTICIPANT	\N	PRESENT	0
117277	116619	14033T	PARTICIPANT	\N	PRESENT	0
117278	116619	14085U	PARTICIPANT	\N	PRESENT	0
117223	117212	11065P	PARTICIPANT	\N	PRESENT	0
117224	117212	01015L	PARTICIPANT	\N	PRESENT	0
117225	117212	11107G	PARTICIPANT	\N	PRESENT	0
117279	116619	14197C	PARTICIPANT	\N	PRESENT	0
117227	117212	02002K	PARTICIPANT	\N	PRESENT	0
117228	117212	01022K	PARTICIPANT	\N	PRESENT	0
117229	117212	04097T	PARTICIPANT	\N	PRESENT	0
117230	117212	09001P	PARTICIPANT	\N	PRESENT	0
117280	116619	14267Y	PARTICIPANT	\N	PRESENT	0
117232	117212	14219Q	PARTICIPANT	\N	PRESENT	0
117233	117212	80027E	PARTICIPANT	\N	PRESENT	0
117234	117212	14031R	PARTICIPANT	\N	PRESENT	0
117235	117212	08009T	PRESIDENT	0	PRESENT	0
117236	117212	08062Y	PARTICIPANT	\N	EXCUSE	0
117237	117212	14221J	PARTICIPANT	\N	PRESENT	0
117238	117212	92039X	PARTICIPANT	\N	PRESENT	0
117281	116619	11083R	PARTICIPANT	\N	PRESENT	0
117240	117212	14169X	PARTICIPANT	\N	PRESENT	0
117241	117212	14237S	PARTICIPANT	\N	PRESENT	0
117242	117212	13002U	PARTICIPANT	\N	PRESENT	0
117243	117212	05012A	PARTICIPANT	\N	PRESENT	0
117282	116619	14225N	PARTICIPANT	\N	PRESENT	0
117245	117212	14135M	PARTICIPANT	\N	PRESENT	0
117246	117212	14331P	PARTICIPANT	\N	PRESENT	0
117247	117212	95062K	PARTICIPANT	\N	PRESENT	0
117248	117212	14107H	PARTICIPANT	\N	PRESENT	0
117283	116619	01015L	PARTICIPANT	\N	PRESENT	0
117250	117212	14157T	PARTICIPANT	\N	PRESENT	0
117284	116619	99004R	PARTICIPANT	\N	PRESENT	0
117285	116619	01027Q	PARTICIPANT	\N	PRESENT	0
117286	116619	07004J	PARTICIPANT	\N	PRESENT	0
117287	116619	11111C	PARTICIPANT	\N	PRESENT	0
117288	116619	11012A	PARTICIPANT	\N	PRESENT	0
117289	116619	08016S	PARTICIPANT	\N	PRESENT	0
117290	116619	11039M	PARTICIPANT	\N	PRESENT	0
97869	95978	04033B	PARTICIPANT	\N	PRESENT	0
97870	95978	10006L	PARTICIPANT	\N	PRESENT	0
97871	95978	11110B	PARTICIPANT	\N	PRESENT	0
97872	95978	01022K	PARTICIPANT	\N	PRESENT	0
97873	95978	14059S	PARTICIPANT	\N	PRESENT	0
97874	95978	04048J	PARTICIPANT	\N	PRESENT	0
97875	95978	11026G	PARTICIPANT	\N	PRESENT	0
97876	95978	14259Y	PARTICIPANT	\N	PRESENT	0
97877	95978	14033T	PARTICIPANT	\N	PRESENT	0
97878	95978	04074L	PARTICIPANT	\N	PRESENT	0
97879	95978	14087W	PARTICIPANT	\N	PRESENT	0
98028	95979	95062K	PARTICIPANT	\N	PRESENT	0
98029	95979	95030B	PARTICIPANT	\N	PRESENT	0
98030	95979	14026U	PARTICIPANT	\N	PRESENT	0
98031	95979	95031C	PARTICIPANT	\N	PRESENT	0
98032	95979	95015C	PARTICIPANT	\N	PRESENT	0
98033	95979	98018T	PARTICIPANT	\N	PRESENT	0
98034	95979	04086Q	PARTICIPANT	\N	PRESENT	0
98035	95979	10006L	PARTICIPANT	\N	PRESENT	0
98036	95979	04044E	PARTICIPANT	\N	PRESENT	0
98037	95979	11043H	PARTICIPANT	\N	PRESENT	0
98038	95979	04097T	PARTICIPANT	\N	PRESENT	0
98039	95979	04092N	PARTICIPANT	\N	PRESENT	0
98040	95979	14213J	PARTICIPANT	\N	PRESENT	0
98041	95979	11080N	PARTICIPANT	\N	PRESENT	0
98042	95979	14223L	PARTICIPANT	\N	PRESENT	0
98043	95979	87003B	PARTICIPANT	\N	PRESENT	0
98044	95979	77002U	PARTICIPANT	\N	PRESENT	0
98045	95979	86044G	PARTICIPANT	\N	PRESENT	0
98046	95979	14169X	PARTICIPANT	\N	PRESENT	0
98047	95979	14191V	PARTICIPANT	\N	PRESENT	0
98048	95979	14259Y	PARTICIPANT	\N	PRESENT	0
98049	95979	01056V	PARTICIPANT	\N	PRESENT	0
98050	95979	14173T	PARTICIPANT	\N	PRESENT	0
98051	95979	14111D	PARTICIPANT	\N	PRESENT	0
98052	95979	14031R	PARTICIPANT	\N	PRESENT	0
98053	95979	14215L	PARTICIPANT	\N	PRESENT	0
98054	95979	08019V	PARTICIPANT	\N	PRESENT	0
98055	95979	14211G	PARTICIPANT	\N	PRESENT	0
98056	95979	01058X	PARTICIPANT	\N	PRESENT	0
98057	95979	89029V	PARTICIPANT	\N	PRESENT	0
98058	95979	11034G	PARTICIPANT	\N	PRESENT	0
98059	95979	11101A	PARTICIPANT	\N	PRESENT	0
98060	95979	99004R	PARTICIPANT	\N	PRESENT	0
98061	95979	14087W	PARTICIPANT	\N	PRESENT	0
98062	95979	08010L	PARTICIPANT	\N	PRESENT	0
98063	95979	04085P	PARTICIPANT	\N	PRESENT	0
98064	95979	01059Y	PARTICIPANT	\N	PRESENT	0
98065	95979	07034Q	PARTICIPANT	\N	PRESENT	0
98066	95979	92018S	PARTICIPANT	\N	PRESENT	0
98067	95979	04048J	PARTICIPANT	\N	PRESENT	0
98068	95979	11031D	PARTICIPANT	\N	PRESENT	0
98069	95979	14193X	PARTICIPANT	\N	PRESENT	0
98070	95979	07026Q	PARTICIPANT	\N	PRESENT	0
98071	95979	95059Q	PARTICIPANT	\N	PRESENT	0
98072	95979	11063M	PARTICIPANT	\N	PRESENT	0
98073	95979	05012A	PARTICIPANT	\N	PRESENT	0
98074	95979	14263U	PARTICIPANT	\N	PRESENT	0
98075	95979	14331P	PARTICIPANT	\N	PRESENT	0
98076	95979	11040E	PARTICIPANT	\N	PRESENT	0
98077	95979	04081K	PARTICIPANT	\N	PRESENT	0
98078	95979	14013P	PARTICIPANT	\N	PRESENT	0
98079	95979	14235Q	PARTICIPANT	\N	PRESENT	0
98080	95979	01015L	PARTICIPANT	\N	PRESENT	0
98081	95979	01048V	PARTICIPANT	\N	PRESENT	0
98082	95979	11044J	PARTICIPANT	\N	PRESENT	0
98083	95979	92045V	PARTICIPANT	\N	PRESENT	0
98084	95979	11076S	PARTICIPANT	\N	PRESENT	0
98085	95979	11055M	PARTICIPANT	\N	PRESENT	0
98086	95979	08022Q	PARTICIPANT	\N	PRESENT	0
98087	95979	11033F	PARTICIPANT	\N	PRESENT	0
98088	95979	01044R	PARTICIPANT	\N	PRESENT	0
98089	95979	07024N	PARTICIPANT	\N	PRESENT	0
98090	95979	11100Y	PARTICIPANT	\N	PRESENT	0
98091	95979	04067M	PARTICIPANT	\N	PRESENT	0
98092	95979	04071H	PARTICIPANT	\N	PRESENT	0
98093	95979	13002U	PARTICIPANT	\N	PRESENT	0
98094	95979	11083R	PARTICIPANT	\N	PRESENT	0
98095	95979	14069U	PARTICIPANT	\N	PRESENT	0
98096	95979	11103C	PARTICIPANT	\N	PRESENT	0
98097	95979	01060R	PARTICIPANT	\N	PRESENT	0
98098	95979	14055N	PARTICIPANT	\N	PRESENT	0
98099	95979	92044U	PARTICIPANT	\N	PRESENT	0
98100	95979	11097X	PARTICIPANT	\N	PRESENT	0
98101	95979	14147R	PARTICIPANT	\N	PRESENT	0
98102	95979	01046T	PARTICIPANT	\N	PRESENT	0
98103	95979	11030C	PARTICIPANT	\N	PRESENT	0
98104	95979	88008L	PARTICIPANT	\N	PRESENT	0
98105	95979	04078Q	PARTICIPANT	\N	PRESENT	0
98106	95979	08039A	PARTICIPANT	\N	PRESENT	0
98107	95979	08049C	PARTICIPANT	\N	PRESENT	0
98108	95979	11012A	PARTICIPANT	\N	PRESENT	0
98109	95979	11048N	PARTICIPANT	\N	PRESENT	0
98110	95979	11088W	PARTICIPANT	\N	PRESENT	0
98111	95979	14239U	PARTICIPANT	\N	PRESENT	0
98112	95979	98024R	PARTICIPANT	\N	PRESENT	0
98113	95979	14201E	PARTICIPANT	\N	PRESENT	0
98114	95979	14135M	PARTICIPANT	\N	PRESENT	0
98115	95979	07029T	PARTICIPANT	\N	PRESENT	0
98116	95979	14018U	PARTICIPANT	\N	PRESENT	0
98117	95979	08031R	PARTICIPANT	\N	PRESENT	0
98118	95979	05008E	PARTICIPANT	\N	PRESENT	0
98119	95979	14241N	PARTICIPANT	\N	PRESENT	0
98120	95979	04061F	PARTICIPANT	\N	PRESENT	0
98121	95979	11081P	PARTICIPANT	\N	PRESENT	0
98122	95979	08021P	PARTICIPANT	\N	PRESENT	0
98123	95979	11096W	PARTICIPANT	\N	PRESENT	0
98124	95979	95067Q	PARTICIPANT	\N	PRESENT	0
98125	95979	11020A	PARTICIPANT	\N	PRESENT	0
98126	95979	01028R	PARTICIPANT	\N	PRESENT	0
98127	95979	01008M	PARTICIPANT	\N	PRESENT	0
98128	95979	08016S	PARTICIPANT	\N	PRESENT	0
98129	95979	98035U	PARTICIPANT	\N	PRESENT	0
98130	95979	01027Q	PARTICIPANT	\N	PRESENT	0
98131	95979	11039M	PARTICIPANT	\N	PRESENT	0
98132	95979	14237S	PARTICIPANT	\N	PRESENT	0
98133	95979	01016M	PARTICIPANT	\N	PRESENT	0
98134	95979	92015P	PARTICIPANT	\N	PRESENT	0
98135	95979	98021N	PARTICIPANT	\N	PRESENT	0
98136	95979	98046X	PARTICIPANT	\N	PRESENT	0
98137	95979	08052W	PARTICIPANT	\N	PRESENT	0
98138	95979	14051J	PARTICIPANT	\N	PRESENT	0
98139	95979	14151M	PARTICIPANT	\N	PRESENT	0
98140	95979	14059S	PARTICIPANT	\N	PRESENT	0
98141	95979	08025T	PARTICIPANT	\N	PRESENT	0
98142	95979	14061L	PARTICIPANT	\N	PRESENT	0
98143	95979	11104D	PARTICIPANT	\N	PRESENT	0
98144	95979	11110B	PARTICIPANT	\N	PRESENT	0
98145	95979	08038Y	PARTICIPANT	\N	PRESENT	0
98146	95979	99002P	PARTICIPANT	\N	PRESENT	0
98147	95979	01037S	PARTICIPANT	\N	PRESENT	0
98148	95979	08024S	PARTICIPANT	\N	PRESENT	0
98149	95979	11035H	PARTICIPANT	\N	PRESENT	0
98150	95979	04059M	PARTICIPANT	\N	PRESENT	0
98026	95979	86034E	PARTICIPANT	\N	PRESENT	0
98027	95979	04036E	PARTICIPANT	\N	PRESENT	0
98151	95979	08055A	PARTICIPANT	\N	PRESENT	0
98152	95979	11027H	PARTICIPANT	\N	PRESENT	0
98153	95979	08069G	PARTICIPANT	\N	PRESENT	0
98154	95979	11084S	PARTICIPANT	\N	PRESENT	0
98155	95979	01011G	PARTICIPANT	\N	PRESENT	0
98156	95979	95063L	PARTICIPANT	\N	PRESENT	0
98157	95979	01022K	PARTICIPANT	\N	PRESENT	0
98158	95979	14028W	PARTICIPANT	\N	PRESENT	0
98159	95979	92031P	PARTICIPANT	\N	PRESENT	0
98160	95979	14197C	PARTICIPANT	\N	PRESENT	0
98161	95979	92040Q	PARTICIPANT	\N	PRESENT	0
98162	95979	80013X	PARTICIPANT	\N	PRESENT	0
98163	95979	08060W	PARTICIPANT	\N	PRESENT	0
98164	95979	14329V	PARTICIPANT	\N	PRESENT	0
98165	95979	14195A	PARTICIPANT	\N	PRESENT	0
98166	95979	11061K	PARTICIPANT	\N	PRESENT	0
98170	95979	11067R	PARTICIPANT	\N	PRESENT	0
98168	95979	11066Q	PARTICIPANT	\N	PRESENT	0
98169	95979	97011G	PARTICIPANT	\N	PRESENT	0
98171	95979	01003G	PARTICIPANT	\N	PRESENT	0
98172	95979	14085U	PARTICIPANT	\N	PRESENT	0
98173	95979	98023Q	PARTICIPANT	\N	PRESENT	0
98174	95979	14271U	PARTICIPANT	\N	PRESENT	0
98175	95979	14037X	PARTICIPANT	\N	PRESENT	0
98176	95979	11015D	PARTICIPANT	\N	PRESENT	0
98177	95979	08043V	PARTICIPANT	\N	PRESENT	0
98178	95979	08068F	PARTICIPANT	\N	PRESENT	0
98179	95979	11059R	PARTICIPANT	\N	PRESENT	0
98180	95979	11089X	PARTICIPANT	\N	PRESENT	0
98181	95979	08012N	PARTICIPANT	\N	PRESENT	0
98182	95979	04035D	PARTICIPANT	\N	PRESENT	0
98183	95979	11036J	PARTICIPANT	\N	PRESENT	0
104198	103113	04042C	PARTICIPANT	\N	PRESENT	0
104202	103113	14042U	PARTICIPANT	\N	PRESENT	0
104203	103113	14235Q	PARTICIPANT	\N	PRESENT	0
104201	103113	14030Q	PARTICIPANT	\N	PRESENT	0
104204	103113	14263U	PARTICIPANT	\N	PRESENT	0
104205	103113	14225N	PARTICIPANT	\N	PRESENT	0
104206	103113	14001X	PARTICIPANT	\N	PRESENT	0
104207	103113	95049N	PARTICIPANT	\N	PRESENT	0
104208	103113	04080J	PARTICIPANT	\N	PRESENT	0
104209	103113	11107G	PARTICIPANT	\N	PRESENT	0
104210	103113	04035D	PARTICIPANT	\N	PRESENT	0
104232	103113	11065P	PARTICIPANT	\N	PRESENT	0
104212	103113	14073Q	PARTICIPANT	\N	PRESENT	0
104213	103113	14119M	PARTICIPANT	\N	PRESENT	0
104233	103113	08021P	PARTICIPANT	\N	PRESENT	0
104234	103113	01024M	PARTICIPANT	\N	PRESENT	0
104235	103113	07034Q	PARTICIPANT	\N	PRESENT	0
104533	103114	98053W	PARTICIPANT	\N	PRESENT	0
104552	103114	11031D	PARTICIPANT	\N	PRESENT	0
104553	103114	01059Y	PARTICIPANT	\N	PRESENT	0
104554	103114	11063M	PARTICIPANT	\N	PRESENT	0
104555	103114	14013P	PARTICIPANT	\N	PRESENT	0
104556	103114	11054L	PARTICIPANT	\N	PRESENT	0
104557	103114	04092N	PARTICIPANT	\N	PRESENT	0
104558	103114	14037X	PARTICIPANT	\N	PRESENT	0
104559	103114	08038Y	PARTICIPANT	\N	PRESENT	0
104560	103114	14121F	PARTICIPANT	\N	PRESENT	0
104561	103114	04053F	PARTICIPANT	\N	PRESENT	0
104562	103114	11029K	PARTICIPANT	\N	PRESENT	0
104563	103114	01044R	PARTICIPANT	\N	PRESENT	0
104564	103114	12042Y	PARTICIPANT	\N	PRESENT	0
104565	103114	04045F	PARTICIPANT	\N	PRESENT	0
104566	103114	11077T	PARTICIPANT	\N	PRESENT	0
104567	103114	14207L	PARTICIPANT	\N	PRESENT	0
104568	103114	14255U	PARTICIPANT	\N	PRESENT	0
104569	103114	08031R	PARTICIPANT	\N	PRESENT	0
104570	103114	14018U	PARTICIPANT	\N	PRESENT	0
104571	103114	95041E	PARTICIPANT	\N	PRESENT	0
104572	103114	98005N	PARTICIPANT	\N	PRESENT	0
104573	103114	14195A	PARTICIPANT	\N	PRESENT	0
104574	103114	11105E	PARTICIPANT	\N	PRESENT	0
104575	103114	11061K	PARTICIPANT	\N	PRESENT	0
104576	103114	04043D	PARTICIPANT	\N	PRESENT	0
104577	103114	14223L	PARTICIPANT	\N	PRESENT	0
104578	103114	14026U	PARTICIPANT	\N	PRESENT	0
104579	103114	08052W	PARTICIPANT	\N	PRESENT	0
104580	103114	14271U	PARTICIPANT	\N	PRESENT	0
104581	103114	01022K	PARTICIPANT	\N	PRESENT	0
104582	103114	14097Y	PARTICIPANT	\N	PRESENT	0
104583	103114	14213J	PARTICIPANT	\N	PRESENT	0
104584	103114	14281W	PARTICIPANT	\N	PRESENT	0
104585	103114	14109K	PARTICIPANT	\N	PRESENT	0
104586	103114	11074Q	PARTICIPANT	\N	PRESENT	0
104587	103114	14265W	PARTICIPANT	\N	PRESENT	0
104588	103114	08048B	PARTICIPANT	\N	PRESENT	0
104589	103114	11097X	PARTICIPANT	\N	PRESENT	0
104590	103114	14215L	PARTICIPANT	\N	PRESENT	0
104591	103114	14157T	PARTICIPANT	\N	PRESENT	0
104592	103114	09001P	PARTICIPANT	\N	PRESENT	0
104593	103114	14042U	PARTICIPANT	\N	PRESENT	0
104594	103114	08068F	PARTICIPANT	\N	PRESENT	0
104595	103114	08016S	PARTICIPANT	\N	PRESENT	0
104596	103114	08058D	PARTICIPANT	\N	PRESENT	0
104597	103114	14329V	PARTICIPANT	\N	PRESENT	0
104598	103114	11091R	PARTICIPANT	\N	PRESENT	0
104599	103114	14059S	PARTICIPANT	\N	PRESENT	0
104600	103114	01011G	PARTICIPANT	\N	PRESENT	0
104601	103114	04066L	PARTICIPANT	\N	PRESENT	0
104602	103114	07026Q	PARTICIPANT	\N	PRESENT	0
104603	103114	14269B	PARTICIPANT	\N	PRESENT	0
104605	103114	04050C	PARTICIPANT	\N	PRESENT	0
104606	103114	14235Q	PARTICIPANT	\N	PRESENT	0
104607	103114	11056N	PARTICIPANT	\N	PRESENT	0
104608	104604	08018U	PARTICIPANT	\N	PRESENT	0
104609	103114	11112D	PARTICIPANT	\N	PRESENT	0
104610	104604	14111D	PARTICIPANT	\N	PRESENT	0
104611	104604	14059S	PARTICIPANT	\N	PRESENT	0
104612	104604	11023D	PARTICIPANT	\N	PRESENT	0
104613	104604	11083R	PARTICIPANT	\N	PRESENT	0
104614	103114	11015D	PARTICIPANT	\N	PRESENT	0
104615	103114	11089X	PARTICIPANT	\N	PRESENT	0
104616	103114	11096W	PARTICIPANT	\N	PRESENT	0
104617	103114	11012A	PARTICIPANT	\N	PRESENT	0
104618	103114	04088S	PARTICIPANT	\N	PRESENT	0
104619	103114	14103D	PARTICIPANT	\N	PRESENT	0
104620	103114	98022P	PARTICIPANT	\N	PRESENT	0
104621	103114	10006L	PARTICIPANT	\N	PRESENT	0
104622	103114	14227Q	PARTICIPANT	\N	PRESENT	0
104623	103114	14087W	PARTICIPANT	\N	PRESENT	0
104624	103114	08051V	PARTICIPANT	\N	PRESENT	0
104625	103114	11059R	PARTICIPANT	\N	PRESENT	0
104626	103114	11098Y	PARTICIPANT	\N	PRESENT	0
104627	103114	11109J	PARTICIPANT	\N	PRESENT	0
104628	103114	08043V	PARTICIPANT	\N	PRESENT	0
104629	103114	01008M	PARTICIPANT	\N	PRESENT	0
104630	103114	04033B	PARTICIPANT	\N	PRESENT	0
104631	103114	14231L	PARTICIPANT	\N	PRESENT	0
104638	103114	11100Y	PARTICIPANT	\N	PRESENT	0
104639	103114	01019Q	PARTICIPANT	\N	PRESENT	0
104640	103114	14259Y	PARTICIPANT	\N	PRESENT	0
104641	103114	14119M	PARTICIPANT	\N	PRESENT	0
104642	103114	95062K	PARTICIPANT	\N	PRESENT	0
104643	103114	11104D	PARTICIPANT	\N	PRESENT	0
104644	103114	08060W	PARTICIPANT	\N	PRESENT	0
104645	103114	14061L	PARTICIPANT	\N	PRESENT	0
104646	103114	14263U	PARTICIPANT	\N	PRESENT	0
104647	103114	01015L	PARTICIPANT	\N	PRESENT	0
104648	103114	92018S	PARTICIPANT	\N	PRESENT	0
104649	103114	04085P	PARTICIPANT	\N	PRESENT	0
104650	103114	14135M	PARTICIPANT	\N	PRESENT	0
104652	103114	11049P	PARTICIPANT	\N	PRESENT	0
104653	103114	08015R	PARTICIPANT	\N	PRESENT	0
104654	103114	04057K	PARTICIPANT	\N	PRESENT	0
104655	103114	14239U	PARTICIPANT	\N	PRESENT	0
104656	103114	14241N	PARTICIPANT	\N	PRESENT	0
104657	103114	11103C	PARTICIPANT	\N	PRESENT	0
104658	103114	05012A	PARTICIPANT	\N	PRESENT	0
104659	103114	01048V	PARTICIPANT	\N	PRESENT	0
104660	103114	14083S	PARTICIPANT	\N	PRESENT	0
104661	103114	08034U	PARTICIPANT	\N	PRESENT	0
104662	103114	14191V	PARTICIPANT	\N	PRESENT	0
104672	103115	08055A	PARTICIPANT	\N	PRESENT	0
104673	103115	11063M	PARTICIPANT	\N	PRESENT	0
104674	103115	04092N	PARTICIPANT	\N	PRESENT	0
104675	103115	14037X	PARTICIPANT	\N	PRESENT	0
104676	103115	08052W	PARTICIPANT	\N	PRESENT	0
104677	103115	04053F	PARTICIPANT	\N	PRESENT	0
104678	103115	04045F	PARTICIPANT	\N	PRESENT	0
104679	103115	11067R	PARTICIPANT	\N	PRESENT	0
104680	103115	14014Q	PARTICIPANT	\N	PRESENT	0
104681	103115	14227Q	PARTICIPANT	\N	PRESENT	0
104682	103115	07026Q	PARTICIPANT	\N	PRESENT	0
104683	103115	11093T	PARTICIPANT	\N	PRESENT	0
104684	103115	11029K	PARTICIPANT	\N	PRESENT	0
104685	103115	07032N	PARTICIPANT	\N	PRESENT	0
104686	103115	08048B	PARTICIPANT	\N	PRESENT	0
104687	103115	01044R	PARTICIPANT	\N	PRESENT	0
104688	103115	12042Y	PARTICIPANT	\N	PRESENT	0
104689	103115	10006L	PARTICIPANT	\N	PRESENT	0
104690	103115	14223L	PARTICIPANT	\N	PRESENT	0
104691	103115	14071N	PARTICIPANT	\N	PRESENT	0
104692	103115	14331P	PARTICIPANT	\N	PRESENT	0
104693	103115	90003B	PARTICIPANT	\N	PRESENT	0
104694	103115	11097X	PARTICIPANT	\N	PRESENT	0
104695	103115	14105F	PARTICIPANT	\N	PRESENT	0
104696	103115	01016M	PARTICIPANT	\N	PRESENT	0
104697	103115	11031D	PARTICIPANT	\N	PRESENT	0
104698	103115	14053L	PARTICIPANT	\N	PRESENT	0
104699	103115	14026U	PARTICIPANT	\N	PRESENT	0
104700	103115	14215L	PARTICIPANT	\N	PRESENT	0
104701	103115	14213J	PARTICIPANT	\N	PRESENT	0
104702	103115	14265W	PARTICIPANT	\N	PRESENT	0
104703	103115	04085P	PARTICIPANT	\N	PRESENT	0
104704	103115	14263U	PARTICIPANT	\N	PRESENT	0
104705	103115	14231L	PARTICIPANT	\N	PRESENT	0
104706	103115	14083S	PARTICIPANT	\N	PRESENT	0
104707	103115	14191V	PARTICIPANT	\N	PRESENT	0
104708	103115	14103D	PARTICIPANT	\N	PRESENT	0
104709	103115	01011G	PARTICIPANT	\N	PRESENT	0
104710	103115	14061L	PARTICIPANT	\N	PRESENT	0
104711	103115	14059S	PARTICIPANT	\N	PRESENT	0
104712	103115	95049N	PARTICIPANT	\N	PRESENT	0
104713	103115	04067M	PARTICIPANT	\N	PRESENT	0
104714	103115	14018U	PARTICIPANT	\N	PRESENT	0
104715	103115	11096W	PARTICIPANT	\N	PRESENT	0
104716	103115	08031R	PARTICIPANT	\N	PRESENT	0
104717	103115	11094U	PARTICIPANT	\N	PRESENT	0
104718	103115	11015D	PARTICIPANT	\N	PRESENT	0
111345	111343	01037S	PARTICIPANT	\N	PRESENT	0
111346	111343	11106F	PARTICIPANT	\N	PRESENT	0
111347	111343	14037X	PARTICIPANT	\N	PRESENT	0
111348	110313	07034Q	PARTICIPANT	\N	PRESENT	0
111349	111343	11099A	PARTICIPANT	\N	PRESENT	0
111350	111343	95062K	PARTICIPANT	\N	PRESENT	0
111352	110313	11035H	PARTICIPANT	\N	PRESENT	0
111394	111392	08024S	PARTICIPANT	\N	PRESENT	0
111395	111392	14265W	PARTICIPANT	\N	PRESENT	0
111355	111351	14093U	PARTICIPANT	\N	PRESENT	0
111356	111351	14030Q	PARTICIPANT	\N	PRESENT	0
111396	111392	14133K	PARTICIPANT	\N	PRESENT	0
111358	111351	08060W	PARTICIPANT	\N	PRESENT	0
111397	110313	14063N	PARTICIPANT	\N	PRESENT	0
111360	111351	14038Y	PARTICIPANT	\N	PRESENT	0
111342	110313	08024S	PARTICIPANT	\N	PRESENT	0
111344	111343	11027H	PARTICIPANT	\N	PRESENT	0
111398	110313	14030Q	PARTICIPANT	\N	PRESENT	0
111362	111351	98023Q	PARTICIPANT	\N	PRESENT	0
111399	110313	11094U	PARTICIPANT	\N	PRESENT	0
111400	110313	14207L	PARTICIPANT	\N	PRESENT	0
111365	111351	11107G	PARTICIPANT	\N	PRESENT	0
111401	110313	01028R	PARTICIPANT	\N	PRESENT	0
111367	111351	02002K	PARTICIPANT	\N	EXCUSE	0
111677	110314	08024S	PARTICIPANT	\N	PRESENT	0
111369	111351	04097T	PARTICIPANT	\N	PRESENT	0
111370	111351	09001P	PARTICIPANT	\N	PRESENT	0
111402	110313	13002U	PARTICIPANT	\N	PRESENT	0
111372	111351	14219Q	PARTICIPANT	\N	PRESENT	0
111373	111351	80027E	PARTICIPANT	\N	PRESENT	0
111374	111351	14031R	PARTICIPANT	\N	PRESENT	0
111375	111351	08009T	PRESIDENT	0	PRESENT	0
111376	111351	08062Y	PARTICIPANT	\N	EXCUSE	0
111377	111351	14221J	PARTICIPANT	\N	PRESENT	0
111403	110313	07029T	PARTICIPANT	\N	PRESENT	0
111379	111351	08042U	PARTICIPANT	\N	PRESENT	0
111380	111351	14169X	PARTICIPANT	\N	PRESENT	0
111381	111351	14237S	PARTICIPANT	\N	PRESENT	0
111382	111351	13002U	PARTICIPANT	\N	PRESENT	0
111383	111351	05012A	PARTICIPANT	\N	PRESENT	0
111405	111393	01008M	PARTICIPANT	\N	PRESENT	0
111385	111351	14135M	PARTICIPANT	\N	PRESENT	0
111386	111351	14331P	PARTICIPANT	\N	PRESENT	0
111387	111351	95062K	PARTICIPANT	\N	PRESENT	0
111388	111351	14107H	PARTICIPANT	\N	PRESENT	0
111406	111393	11036J	PARTICIPANT	\N	PRESENT	0
111390	111351	14157T	PARTICIPANT	\N	PRESENT	0
111391	111351	96003C	PARTICIPANT	\N	EXCUSE	0
111407	111393	11081P	PARTICIPANT	\N	PRESENT	0
111408	111393	14013P	PARTICIPANT	\N	PRESENT	0
111409	111393	08068F	PARTICIPANT	\N	PRESENT	0
111410	111393	14207L	PARTICIPANT	\N	PRESENT	0
111411	111393	11101A	PARTICIPANT	\N	PRESENT	0
111412	111393	90003B	PARTICIPANT	\N	PRESENT	0
111449	110313	14065Q	PARTICIPANT	\N	PRESENT	0
111414	111393	80013X	PARTICIPANT	\N	PRESENT	0
111415	111393	08038Y	PARTICIPANT	\N	PRESENT	0
111416	111393	04089T	PARTICIPANT	\N	PRESENT	0
111417	111393	14197C	PARTICIPANT	\N	PRESENT	0
111418	111393	11110B	PARTICIPANT	\N	PRESENT	0
111419	111393	14187A	PARTICIPANT	\N	PRESENT	0
111420	111393	14033T	PARTICIPANT	\N	PRESENT	0
111450	110313	11096W	PARTICIPANT	\N	PRESENT	0
111422	111393	04048J	PARTICIPANT	\N	PRESENT	0
111423	111393	11099A	PARTICIPANT	\N	PRESENT	0
111453	110313	04059M	PARTICIPANT	\N	PRESENT	0
111456	110313	08043V	PARTICIPANT	\N	PRESENT	0
111426	111393	11111C	PARTICIPANT	\N	PRESENT	0
111427	111393	08015R	PARTICIPANT	\N	EXCUSE	0
111428	111393	11100Y	PRESIDENT	0	PRESENT	0
111429	111393	01061S	PARTICIPANT	\N	PRESENT	0
111430	111393	11098Y	PARTICIPANT	\N	PRESENT	0
111458	110313	01046T	PARTICIPANT	\N	PRESENT	0
111432	111393	11077T	PARTICIPANT	\N	PRESENT	0
111433	111393	14205J	PARTICIPANT	\N	PRESENT	0
111434	111393	08019V	PARTICIPANT	\N	PRESENT	0
111435	111393	14257W	PARTICIPANT	\N	PRESENT	0
111436	111393	08021P	PARTICIPANT	\N	PRESENT	0
111437	111393	04088S	PARTICIPANT	\N	PRESENT	0
111438	111393	98050T	PARTICIPANT	\N	PRESENT	0
111439	111393	11090Q	PARTICIPANT	\N	PRESENT	0
111440	111393	11046L	PARTICIPANT	\N	PRESENT	0
111441	111393	01058X	PARTICIPANT	\N	PRESENT	0
111442	111393	11094U	PARTICIPANT	\N	PRESENT	0
111443	111393	11066Q	PARTICIPANT	\N	PRESENT	0
111444	110313	14031R	PARTICIPANT	\N	PRESENT	0
111463	110313	14119M	PARTICIPANT	\N	PRESENT	0
111467	110313	08065C	PARTICIPANT	\N	PRESENT	0
111486	110313	08069G	PARTICIPANT	\N	PRESENT	0
111491	110313	14273W	PARTICIPANT	\N	PRESENT	0
111503	110313	08039A	PARTICIPANT	\N	PRESENT	0
111505	110313	01025N	PARTICIPANT	\N	PRESENT	0
111506	111504	01008M	PARTICIPANT	\N	PRESENT	0
111507	111504	11036J	PARTICIPANT	\N	PRESENT	0
111508	111504	11081P	PARTICIPANT	\N	PRESENT	0
111546	110313	11036J	PARTICIPANT	\N	PRESENT	0
111510	111504	08068F	PARTICIPANT	\N	PRESENT	0
111553	110313	01003G	PARTICIPANT	\N	PRESENT	0
111556	110313	14267Y	PARTICIPANT	\N	PRESENT	0
111513	111504	90003B	PARTICIPANT	\N	PRESENT	0
111575	110313	14259Y	PARTICIPANT	\N	PRESENT	0
111576	111504	01022K	PARTICIPANT	\N	PRESENT	0
111516	111504	08038Y	PARTICIPANT	\N	PRESENT	0
111517	111504	04089T	PARTICIPANT	\N	PRESENT	0
111518	111504	14197C	PARTICIPANT	\N	PRESENT	0
111519	111504	11110B	PARTICIPANT	\N	PRESENT	0
111520	111504	14187A	PARTICIPANT	\N	PRESENT	0
111521	111504	14033T	PARTICIPANT	\N	PRESENT	0
111590	110313	11056N	PARTICIPANT	\N	PRESENT	0
111523	111504	04048J	PARTICIPANT	\N	PRESENT	0
111524	111504	11099A	PARTICIPANT	\N	PRESENT	0
111592	110313	04085P	PARTICIPANT	\N	PRESENT	0
111601	110313	14327T	PARTICIPANT	\N	PRESENT	0
111602	110313	11067R	PARTICIPANT	\N	PRESENT	0
111528	111504	08015R	PARTICIPANT	\N	EXCUSE	0
111529	111504	11100Y	PRESIDENT	0	PRESENT	0
111530	111504	01061S	PARTICIPANT	\N	PRESENT	0
111531	111504	11098Y	PARTICIPANT	\N	PRESENT	0
111634	110313	14263U	PARTICIPANT	\N	PRESENT	0
111533	111504	11077T	PARTICIPANT	\N	PRESENT	0
111534	111504	14205J	PARTICIPANT	\N	PRESENT	0
111535	111504	08019V	PARTICIPANT	\N	PRESENT	0
111536	111504	14257W	PARTICIPANT	\N	PRESENT	0
111537	111504	08021P	PARTICIPANT	\N	PRESENT	0
111538	111504	04088S	PARTICIPANT	\N	PRESENT	0
111539	111504	98050T	PARTICIPANT	\N	PRESENT	0
111540	111504	11090Q	PARTICIPANT	\N	PRESENT	0
111541	111504	11046L	PARTICIPANT	\N	PRESENT	0
111542	111504	01058X	PARTICIPANT	\N	PRESENT	0
111543	111504	11094U	PARTICIPANT	\N	PRESENT	0
111544	111504	11066Q	PARTICIPANT	\N	PRESENT	0
111545	110313	14038Y	PARTICIPANT	\N	PRESENT	0
111635	110313	14257W	PARTICIPANT	\N	PRESENT	0
111636	110313	14157T	PARTICIPANT	\N	PRESENT	0
111637	110313	86044G	PARTICIPANT	\N	PRESENT	0
111638	110313	95030B	PARTICIPANT	\N	PRESENT	0
111639	110313	11040E	PARTICIPANT	\N	PRESENT	0
111678	110314	08039A	PARTICIPANT	\N	PRESENT	0
111679	110314	01025N	PARTICIPANT	\N	PRESENT	0
111680	110314	14263U	PARTICIPANT	\N	PRESENT	0
111681	110314	11036J	PARTICIPANT	\N	PRESENT	0
111682	110314	11040E	PARTICIPANT	\N	PRESENT	0
111683	110314	01028R	PARTICIPANT	\N	PRESENT	0
111684	110314	08043V	PARTICIPANT	\N	PRESENT	0
111685	110314	14030Q	PARTICIPANT	\N	PRESENT	0
111686	110314	14273W	PARTICIPANT	\N	PRESENT	0
111687	110314	01003G	PARTICIPANT	\N	PRESENT	0
111688	110314	01044R	PARTICIPANT	\N	PRESENT	0
111689	110314	04048J	PARTICIPANT	\N	PRESENT	0
111690	110314	14133K	PARTICIPANT	\N	PRESENT	0
111691	110314	14109K	PARTICIPANT	\N	PRESENT	0
111692	110314	14265W	PARTICIPANT	\N	PRESENT	0
111693	110314	14013P	PARTICIPANT	\N	PRESENT	0
111694	110314	14063N	PARTICIPANT	\N	PRESENT	0
111695	110314	12041X	PARTICIPANT	\N	PRESENT	0
111696	110314	14229S	PARTICIPANT	\N	PRESENT	0
111697	110314	04059M	PARTICIPANT	\N	PRESENT	0
111698	110314	04070G	PARTICIPANT	\N	PRESENT	0
111699	110314	04057K	PARTICIPANT	\N	PRESENT	0
111700	110314	11098Y	PARTICIPANT	\N	PRESENT	0
111701	110314	08065C	PARTICIPANT	\N	PRESENT	0
111702	110314	14033T	PARTICIPANT	\N	PRESENT	0
111703	110314	14169X	PARTICIPANT	\N	PRESENT	0
111704	110314	14207L	PARTICIPANT	\N	PRESENT	0
111705	110314	14257W	PARTICIPANT	\N	PRESENT	0
111706	110314	95030B	PARTICIPANT	\N	PRESENT	0
111712	110314	95015C	PARTICIPANT	\N	PRESENT	0
111713	110314	14089Y	PARTICIPANT	\N	PRESENT	0
97572	94613	11054L	PARTICIPANT	\N	EXCUSE	0
117291	116619	14109K	PARTICIPANT	\N	PRESENT	0
117292	116619	11036J	PARTICIPANT	\N	PRESENT	0
117293	116619	01024M	PARTICIPANT	\N	PRESENT	0
117294	116619	14083S	PARTICIPANT	\N	PRESENT	0
117295	116619	14207L	PARTICIPANT	\N	PRESENT	0
117296	116619	14273W	PARTICIPANT	\N	PRESENT	0
117373	116619	01008M	PARTICIPANT	\N	PRESENT	0
117374	116619	01034P	PARTICIPANT	\N	PRESENT	0
117433	116619	14257W	PARTICIPANT	\N	PRESENT	0
117434	116619	95030B	PARTICIPANT	\N	PRESENT	0
117435	116619	98050T	PARTICIPANT	\N	PRESENT	0
117436	116619	11091R	PARTICIPANT	\N	PRESENT	0
117452	116619	14013P	PARTICIPANT	\N	PRESENT	0
117453	116619	11066Q	PARTICIPANT	\N	PRESENT	0
117456	116620	08024S	PARTICIPANT	\N	PRESENT	0
117485	116620	04067M	PARTICIPANT	\N	PRESENT	0
117458	116620	08011M	PARTICIPANT	\N	PRESENT	0
117529	116620	04081K	PARTICIPANT	\N	PRESENT	0
117460	116620	04088S	PARTICIPANT	\N	PRESENT	0
117461	116620	14033T	PARTICIPANT	\N	PRESENT	0
117574	117573	11107G	PARTICIPANT	\N	PRESENT	0
117575	117573	04035D	PARTICIPANT	\N	PRESENT	0
117464	116620	01015L	PARTICIPANT	\N	PRESENT	0
117465	116620	99004R	PARTICIPANT	\N	PRESENT	0
117576	117573	04036E	PARTICIPANT	\N	PRESENT	0
117496	117492	95015C	PARTICIPANT	\N	PRESENT	0
117577	117573	01047U	PARTICIPANT	\N	PRESENT	0
117469	116620	11012A	PARTICIPANT	\N	PRESENT	0
117470	116620	11036J	PARTICIPANT	\N	PRESENT	0
117471	116620	01024M	PARTICIPANT	\N	PRESENT	0
117498	117492	11027H	PARTICIPANT	\N	PRESENT	0
117473	116620	14273W	PARTICIPANT	\N	PRESENT	0
117578	117573	14063N	PARTICIPANT	\N	PRESENT	0
117499	117492	04086Q	PARTICIPANT	\N	PRESENT	0
117476	116620	95030B	PARTICIPANT	\N	PRESENT	0
117477	116620	98050T	PARTICIPANT	\N	PRESENT	0
117478	116620	11091R	PARTICIPANT	\N	PRESENT	0
117479	116620	14013P	PARTICIPANT	\N	PRESENT	0
117480	116620	11066Q	PARTICIPANT	\N	PRESENT	0
117483	116620	80013X	PARTICIPANT	\N	PRESENT	0
117500	117492	14079W	PARTICIPANT	\N	PRESENT	0
117501	117492	11088W	PARTICIPANT	\N	PRESENT	0
117579	117573	04070G	PARTICIPANT	\N	PRESENT	0
117503	117492	04089T	PARTICIPANT	\N	EXCUSE	0
117504	117492	14187A	PARTICIPANT	\N	PRESENT	0
117505	117492	11034G	PARTICIPANT	\N	PRESENT	0
117580	117573	01008M	PARTICIPANT	\N	PRESENT	0
117507	117492	14231L	PARTICIPANT	\N	PRESENT	0
117581	117573	14175V	PARTICIPANT	\N	PRESENT	0
117509	117492	14213J	PARTICIPANT	\N	PRESENT	0
117510	117492	08031R	PARTICIPANT	\N	PRESENT	0
117511	117492	11100Y	PRESIDENT	0	PRESENT	0
117582	117573	11091R	PARTICIPANT	\N	PRESENT	0
117583	117573	14249W	PARTICIPANT	\N	PRESENT	0
117584	117573	11061K	PARTICIPANT	\N	PRESENT	0
117585	117573	14179A	PARTICIPANT	\N	PRESENT	0
117586	117573	14059S	PARTICIPANT	\N	PRESENT	0
117587	117573	14001X	PARTICIPANT	\N	PRESENT	0
117588	117573	08042U	PARTICIPANT	\N	PRESENT	0
117589	117573	14135M	PARTICIPANT	\N	PRESENT	0
117590	117573	14157T	PARTICIPANT	\N	PRESENT	0
117613	117612	98018T	PARTICIPANT	\N	PRESENT	0
117522	117492	01028R	PARTICIPANT	\N	PRESENT	0
117735	117734	14187A	PARTICIPANT	\N	PRESENT	0
117524	117492	11037K	PARTICIPANT	\N	PRESENT	0
117736	117734	08031R	PARTICIPANT	\N	PRESENT	0
117526	117492	92045V	PARTICIPANT	\N	PRESENT	0
117527	117492	11066Q	PARTICIPANT	\N	PRESENT	0
117738	117737	14231L	PARTICIPANT	\N	PRESENT	0
117740	117739	14231L	PARTICIPANT	\N	PRESENT	0
117742	117741	14231L	PARTICIPANT	\N	PRESENT	0
118352	118348	11039M	PARTICIPANT	\N	PRESENT	0
118353	118348	98042T	PARTICIPANT	\N	PRESENT	0
118391	118390	01008M	PARTICIPANT	\N	PRESENT	0
118392	118390	12042Y	PARTICIPANT	\N	PRESENT	0
118394	118390	14033T	PARTICIPANT	\N	PRESENT	0
118397	118390	01022K	PARTICIPANT	\N	PRESENT	0
118401	118390	04097T	PARTICIPANT	\N	PRESENT	0
118403	118390	14121F	PARTICIPANT	\N	PRESENT	0
118406	118390	08051V	PARTICIPANT	\N	PRESENT	0
118407	118390	14265W	PARTICIPANT	\N	PRESENT	0
118408	118390	04088S	PARTICIPANT	\N	PRESENT	0
118409	118390	07032N	PARTICIPANT	\N	PRESENT	0
118410	118390	95062K	PARTICIPANT	\N	PRESENT	0
118513	118512	11053K	PARTICIPANT	\N	PRESENT	0
118517	118516	08014Q	PARTICIPANT	\N	PRESENT	0
118518	118516	08069G	PARTICIPANT	\N	PRESENT	0
118520	118519	08014Q	PARTICIPANT	\N	PRESENT	0
118521	118519	08069G	PARTICIPANT	\N	PRESENT	0
118523	118522	08014Q	PARTICIPANT	\N	PRESENT	0
118524	118522	08069G	PARTICIPANT	\N	PRESENT	0
118526	118525	14215L	PARTICIPANT	\N	PRESENT	0
118528	118527	14215L	PARTICIPANT	\N	PRESENT	0
118532	117825	86034E	PARTICIPANT	\N	PRESENT	0
118533	117825	14107H	PARTICIPANT	\N	PRESENT	0
118534	117825	11037K	PARTICIPANT	\N	PRESENT	0
118535	117825	12042Y	PARTICIPANT	\N	PRESENT	0
118536	117825	14219Q	PARTICIPANT	\N	PRESENT	0
118537	117825	14179A	PARTICIPANT	\N	PRESENT	0
118538	117825	14237S	PARTICIPANT	\N	PRESENT	0
118539	117825	14055N	PARTICIPANT	\N	PRESENT	0
118540	117825	07032N	PARTICIPANT	\N	PRESENT	0
118541	117825	04088S	PARTICIPANT	\N	PRESENT	0
118542	117825	14265W	PARTICIPANT	\N	PRESENT	0
118543	117825	14273W	PARTICIPANT	\N	PRESENT	0
118544	117825	07026Q	PARTICIPANT	\N	PRESENT	0
118545	117825	14247U	PARTICIPANT	\N	PRESENT	0
118546	117825	11064N	PARTICIPANT	\N	PRESENT	0
118547	117825	08052W	PARTICIPANT	\N	PRESENT	0
118548	117825	11107G	PARTICIPANT	\N	PRESENT	0
118549	117825	95049N	PARTICIPANT	\N	PRESENT	0
118550	117825	01048V	PARTICIPANT	\N	PRESENT	0
118551	117825	11090Q	PARTICIPANT	\N	PRESENT	0
118552	117825	11097X	PARTICIPANT	\N	PRESENT	0
118553	117825	14259Y	PARTICIPANT	\N	PRESENT	0
118554	117825	98005N	PARTICIPANT	\N	PRESENT	0
118555	117825	11091R	PARTICIPANT	\N	PRESENT	0
118556	117825	08068F	PARTICIPANT	\N	PRESENT	0
118557	117825	11032E	PARTICIPANT	\N	PRESENT	0
118558	117825	14331P	PARTICIPANT	\N	PRESENT	0
118559	117825	01022K	PARTICIPANT	\N	PRESENT	0
118560	117825	11094U	PARTICIPANT	\N	PRESENT	0
118561	117825	11080N	PARTICIPANT	\N	PRESENT	0
118562	117825	04074L	PARTICIPANT	\N	PRESENT	0
118563	117825	08062Y	PARTICIPANT	\N	PRESENT	0
118564	117825	11054L	PARTICIPANT	\N	PRESENT	0
118565	117825	11063M	PARTICIPANT	\N	PRESENT	0
118566	117825	08055A	PARTICIPANT	\N	PRESENT	0
118567	117825	11081P	PARTICIPANT	\N	PRESENT	0
118568	117825	01043Q	PARTICIPANT	\N	PRESENT	0
118569	117825	14275Y	PARTICIPANT	\N	PRESENT	0
118570	117825	14277B	PARTICIPANT	\N	PRESENT	0
118571	117825	11023D	PARTICIPANT	\N	PRESENT	0
118572	117825	11067R	PARTICIPANT	\N	PRESENT	0
118573	117825	13002U	PARTICIPANT	\N	PRESENT	0
118574	117825	11029K	PARTICIPANT	\N	PRESENT	0
118575	117825	08017T	PARTICIPANT	\N	PRESENT	0
118576	117825	14235Q	PARTICIPANT	\N	PRESENT	0
118577	117825	05008E	PARTICIPANT	\N	PRESENT	0
118578	117825	11015D	PARTICIPANT	\N	PRESENT	0
118579	117825	08058D	PARTICIPANT	\N	PRESENT	0
118580	117825	01028R	PARTICIPANT	\N	PRESENT	0
118581	117825	14097Y	PARTICIPANT	\N	PRESENT	0
118582	117825	04085P	PARTICIPANT	\N	PRESENT	0
118583	117825	11034G	PARTICIPANT	\N	PRESENT	0
118584	117825	11042G	PARTICIPANT	\N	PRESENT	0
118585	117825	01016M	PARTICIPANT	\N	PRESENT	0
118586	117825	11039M	PARTICIPANT	\N	PRESENT	0
118587	117825	04050C	PARTICIPANT	\N	PRESENT	0
118588	117825	08043V	PARTICIPANT	\N	PRESENT	0
118589	117825	04079R	PARTICIPANT	\N	PRESENT	0
118590	117825	11014C	PARTICIPANT	\N	PRESENT	0
118591	117825	14257W	PARTICIPANT	\N	PRESENT	0
118592	117825	95063L	PARTICIPANT	\N	PRESENT	0
118593	117825	98046X	PARTICIPANT	\N	PRESENT	0
118594	117825	11027H	PARTICIPANT	\N	PRESENT	0
118595	117825	92039X	PARTICIPANT	\N	PRESENT	0
118596	117825	98053W	PARTICIPANT	\N	PRESENT	0
118597	117825	11096W	PARTICIPANT	\N	PRESENT	0
118598	117825	11066Q	PARTICIPANT	\N	PRESENT	0
118599	117825	01015L	PARTICIPANT	\N	PRESENT	0
118600	117825	95037J	PARTICIPANT	\N	PRESENT	0
118601	117825	14281W	PARTICIPANT	\N	PRESENT	0
118602	117825	11026G	PARTICIPANT	\N	PRESENT	0
118603	117825	14207L	PARTICIPANT	\N	PRESENT	0
118604	117825	11095V	PARTICIPANT	\N	PRESENT	0
118605	117825	14014Q	PARTICIPANT	\N	PRESENT	0
118606	117825	08016S	PARTICIPANT	\N	PRESENT	0
98184	95979	04038G	PARTICIPANT	\N	PRESENT	0
98185	95979	01057W	PARTICIPANT	\N	PRESENT	0
98186	95979	90003B	PARTICIPANT	\N	PRESENT	0
98187	95979	08058D	PARTICIPANT	\N	PRESENT	0
98188	95979	08017T	PARTICIPANT	\N	PRESENT	0
98189	95979	01019Q	PARTICIPANT	\N	PRESENT	0
98190	95979	14257W	PARTICIPANT	\N	PRESENT	0
98191	95979	08053X	PARTICIPANT	\N	PRESENT	0
98192	95979	83042R	PARTICIPANT	\N	PRESENT	0
98193	95979	08028W	PARTICIPANT	\N	PRESENT	0
98194	95979	11046L	PARTICIPANT	\N	PRESENT	0
98195	95979	12042Y	PARTICIPANT	\N	PRESENT	0
98196	95979	04045F	PARTICIPANT	\N	PRESENT	0
98197	95979	08047A	PARTICIPANT	\N	PRESENT	0
98198	95979	11077T	PARTICIPANT	\N	PRESENT	0
98199	95979	11107G	PARTICIPANT	\N	PRESENT	0
98200	95979	14269B	PARTICIPANT	\N	PRESENT	0
98201	95979	11025F	PARTICIPANT	\N	PRESENT	0
98202	95979	11049P	PARTICIPANT	\N	PRESENT	0
98203	95979	04094Q	PARTICIPANT	\N	PRESENT	0
98204	95979	14033T	PARTICIPANT	\N	PRESENT	0
98205	95979	11023D	PARTICIPANT	\N	PRESENT	0
98206	95979	04074L	PARTICIPANT	\N	PRESENT	0
98207	95979	14093U	PARTICIPANT	\N	PRESENT	0
98208	95979	14225N	PARTICIPANT	\N	PRESENT	0
98209	95979	14133K	PARTICIPANT	\N	PRESENT	0
98210	95979	14207L	PARTICIPANT	\N	PRESENT	0
98211	95979	08014Q	PARTICIPANT	\N	PRESENT	0
98212	95979	14105F	PARTICIPANT	\N	PRESENT	0
98213	95979	11095V	PARTICIPANT	\N	PRESENT	0
98214	95979	14175V	PARTICIPANT	\N	PRESENT	0
98215	95979	14001X	PARTICIPANT	\N	PRESENT	0
98216	95979	14107H	PARTICIPANT	\N	PRESENT	0
98217	95979	14167V	PARTICIPANT	\N	PRESENT	0
98218	95979	04055H	PARTICIPANT	\N	PRESENT	0
98219	95979	11054L	PARTICIPANT	\N	PRESENT	0
98220	95979	14123H	PARTICIPANT	\N	PRESENT	0
98221	95979	14097Y	PARTICIPANT	\N	PRESENT	0
98222	95979	04047H	PARTICIPANT	\N	PRESENT	0
98223	95979	11026G	PARTICIPANT	\N	PRESENT	0
98224	95979	04079R	PARTICIPANT	\N	PRESENT	0
98225	95979	14014Q	PARTICIPANT	\N	PRESENT	0
98226	95979	14281W	PARTICIPANT	\N	PRESENT	0
98227	95979	98050T	PARTICIPANT	\N	PRESENT	0
98228	95979	01031L	PARTICIPANT	\N	PRESENT	0
98229	95979	14227Q	PARTICIPANT	\N	PRESENT	0
98230	95979	08015R	PARTICIPANT	\N	PRESENT	0
98231	95979	14229S	PARTICIPANT	\N	PRESENT	0
98232	95979	08034U	PARTICIPANT	\N	PRESENT	0
98233	95979	14121F	PARTICIPANT	\N	PRESENT	0
98234	95979	14063N	PARTICIPANT	\N	PRESENT	0
98235	95979	11074Q	PARTICIPANT	\N	PRESENT	0
98236	95979	10015M	PARTICIPANT	\N	PRESENT	0
98237	95979	11112D	PARTICIPANT	\N	PRESENT	0
98238	95979	11032E	PARTICIPANT	\N	PRESENT	0
98239	95979	08035V	PARTICIPANT	\N	PRESENT	0
98240	95979	11014C	PARTICIPANT	\N	PRESENT	0
98241	95979	14038Y	PARTICIPANT	\N	PRESENT	0
98242	95979	11109J	PARTICIPANT	\N	PRESENT	0
98243	95979	14187A	PARTICIPANT	\N	PRESENT	0
98244	95979	11114F	PARTICIPANT	\N	PRESENT	0
98245	95979	11113E	PARTICIPANT	\N	PRESENT	0
98246	95979	11072N	PARTICIPANT	\N	PRESENT	0
98247	95979	14251Q	PARTICIPANT	\N	PRESENT	0
98248	95979	14159V	PARTICIPANT	\N	PRESENT	0
98249	95979	08065C	PARTICIPANT	\N	PRESENT	0
98250	95979	11042G	PARTICIPANT	\N	PRESENT	0
98251	95979	08018U	PARTICIPANT	\N	PRESENT	0
98252	95979	01014K	PARTICIPANT	\N	PRESENT	0
98253	95979	14157T	PARTICIPANT	\N	PRESENT	0
98254	95979	08061X	PARTICIPANT	\N	PRESENT	0
98255	95979	08048B	PARTICIPANT	\N	PRESENT	0
98256	95979	04077P	PARTICIPANT	\N	PRESENT	0
98257	95979	95035G	PARTICIPANT	\N	PRESENT	0
98258	95979	95049N	PARTICIPANT	\N	PRESENT	0
98259	95979	08011M	PARTICIPANT	\N	PRESENT	0
98260	95979	01043Q	PARTICIPANT	\N	PRESENT	0
98261	95979	14327T	PARTICIPANT	\N	PRESENT	0
98262	95979	01007L	PARTICIPANT	\N	PRESENT	0
98263	95979	09001P	PARTICIPANT	\N	PRESENT	0
98264	95979	01025N	PARTICIPANT	\N	PRESENT	0
98265	95979	04040A	PARTICIPANT	\N	PRESENT	0
98266	95979	01047U	PARTICIPANT	\N	PRESENT	0
98267	95979	01034P	PARTICIPANT	\N	PRESENT	0
98268	95979	11094U	PARTICIPANT	\N	PRESENT	0
98269	95979	01024M	PARTICIPANT	\N	PRESENT	0
98270	95979	14273W	PARTICIPANT	\N	PRESENT	0
98271	95979	08056B	PARTICIPANT	\N	PRESENT	0
98272	95979	11093T	PARTICIPANT	\N	PRESENT	0
98273	95979	14053L	PARTICIPANT	\N	PRESENT	0
98274	95979	11085T	PARTICIPANT	\N	PRESENT	0
98275	95979	04054G	PARTICIPANT	\N	PRESENT	0
98276	95979	11053K	PARTICIPANT	\N	PRESENT	0
98277	95979	08042U	PARTICIPANT	\N	PRESENT	0
98278	95979	14034U	PARTICIPANT	\N	PRESENT	0
98279	95979	14255U	PARTICIPANT	\N	PRESENT	0
98280	95979	04070G	PARTICIPANT	\N	PRESENT	0
98281	95979	14253S	PARTICIPANT	\N	PRESENT	0
98282	95979	14073Q	PARTICIPANT	\N	PRESENT	0
98283	95979	14249W	PARTICIPANT	\N	PRESENT	0
98284	95979	04089T	PARTICIPANT	\N	PRESENT	0
98285	95979	01041N	PARTICIPANT	\N	PRESENT	0
98286	95979	08044W	PARTICIPANT	\N	PRESENT	0
98287	95979	14217N	PARTICIPANT	\N	PRESENT	0
98288	95979	98042T	PARTICIPANT	\N	PRESENT	0
98289	95979	11070L	PARTICIPANT	\N	PRESENT	0
98290	95979	11064N	PARTICIPANT	\N	PRESENT	0
98291	95979	14205J	PARTICIPANT	\N	PRESENT	0
98292	95979	14071N	PARTICIPANT	\N	PRESENT	0
98293	95979	14103D	PARTICIPANT	\N	PRESENT	0
98294	95979	14267Y	PARTICIPANT	\N	PRESENT	0
98295	95979	14219Q	PARTICIPANT	\N	PRESENT	0
98296	95979	14042U	PARTICIPANT	\N	PRESENT	0
98297	95979	04033B	PARTICIPANT	\N	PRESENT	0
98298	95979	14089Y	PARTICIPANT	\N	PRESENT	0
98299	95979	14275Y	PARTICIPANT	\N	PRESENT	0
98300	95979	11082Q	PARTICIPANT	\N	PRESENT	0
98301	95979	04042C	PARTICIPANT	\N	PRESENT	0
98302	95979	14221J	PARTICIPANT	\N	PRESENT	0
98303	95979	14209N	PARTICIPANT	\N	PRESENT	0
98304	95979	07004J	PARTICIPANT	\N	PRESENT	0
98305	95979	07032N	PARTICIPANT	\N	PRESENT	0
98306	95979	11111C	PARTICIPANT	\N	PRESENT	0
98307	95979	04088S	PARTICIPANT	\N	PRESENT	0
98308	95979	11090Q	PARTICIPANT	\N	PRESENT	0
98309	95979	89017R	PARTICIPANT	\N	PRESENT	0
98310	95979	14083S	PARTICIPANT	\N	PRESENT	0
98311	95979	11071M	PARTICIPANT	\N	PRESENT	0
98312	95979	11037K	PARTICIPANT	\N	PRESENT	0
98313	95979	11056N	PARTICIPANT	\N	PRESENT	0
98314	95979	01013J	PARTICIPANT	\N	PRESENT	0
98318	95979	98022P	PARTICIPANT	\N	PRESENT	0
98316	95979	11098Y	PARTICIPANT	\N	PRESENT	0
98317	95979	11099A	PARTICIPANT	\N	PRESENT	0
98319	95979	04053F	PARTICIPANT	\N	PRESENT	0
98320	95979	14079W	PARTICIPANT	\N	PRESENT	0
98321	95979	14199E	PARTICIPANT	\N	PRESENT	0
98322	95979	14265W	PARTICIPANT	\N	PRESENT	0
98323	95979	08009T	PARTICIPANT	\N	PRESENT	0
98324	95979	11057P	PARTICIPANT	\N	PRESENT	0
98325	95979	08051V	PARTICIPANT	\N	PRESENT	0
98326	95979	14179A	PARTICIPANT	\N	PRESENT	0
98327	95979	95037J	PARTICIPANT	\N	PRESENT	0
98328	95979	95041E	PARTICIPANT	\N	PRESENT	0
98329	95979	80027E	PARTICIPANT	\N	PRESENT	0
98332	95979	08073C	PARTICIPANT	\N	PRESENT	0
96283	96232	12041X	PARTICIPANT	\N	PRESENT	0
96284	96232	07026Q	PARTICIPANT	\N	PRESENT	0
96285	96232	92015P	PARTICIPANT	\N	PRESENT	0
96286	96232	01044R	PARTICIPANT	\N	PRESENT	0
96287	96232	08043V	PARTICIPANT	\N	PRESENT	0
96288	96232	04059M	PARTICIPANT	\N	PRESENT	0
96289	96232	04070G	PARTICIPANT	\N	PRESENT	0
96290	96232	95015C	PARTICIPANT	\N	PRESENT	0
96291	96232	11040E	PARTICIPANT	\N	PRESENT	0
96292	96232	14073Q	PARTICIPANT	\N	PRESENT	0
96293	96232	14089Y	PARTICIPANT	\N	PRESENT	0
96294	96232	14061L	PARTICIPANT	\N	PRESENT	0
96295	96232	14265W	PARTICIPANT	\N	PRESENT	0
96296	96232	14191V	PARTICIPANT	\N	PRESENT	0
96300	96232	86044G	PARTICIPANT	\N	PRESENT	0
96298	96232	14273W	PARTICIPANT	\N	PRESENT	0
96299	96232	14229S	PARTICIPANT	\N	PRESENT	0
96301	96232	14241N	PARTICIPANT	\N	PRESENT	0
96302	96232	14205J	PARTICIPANT	\N	PRESENT	0
96303	96232	08039A	PARTICIPANT	\N	PRESENT	0
96304	96232	01025N	PARTICIPANT	\N	PRESENT	0
96305	96232	08069G	PARTICIPANT	\N	PRESENT	0
96306	96232	14105F	PARTICIPANT	\N	PRESENT	0
96307	96232	14107H	PARTICIPANT	\N	PRESENT	0
96308	96232	11049P	PARTICIPANT	\N	PRESENT	0
96309	96232	14119M	PARTICIPANT	\N	PRESENT	0
96310	96232	08010L	PARTICIPANT	\N	PRESENT	0
96311	96232	14209N	PARTICIPANT	\N	PRESENT	0
96312	96232	14063N	PARTICIPANT	\N	PRESENT	0
96313	96232	04045F	PARTICIPANT	\N	PRESENT	0
96273	96232	08055A	PARTICIPANT	\N	PRESENT	0
96282	96232	14263U	PARTICIPANT	\N	PRESENT	0
96314	96232	14103D	PARTICIPANT	\N	PRESENT	0
96315	96232	14031R	PARTICIPANT	\N	PRESENT	0
96316	96232	87003B	PARTICIPANT	\N	PRESENT	0
96320	96232	11025F	PARTICIPANT	\N	PRESENT	0
96349	96232	14059S	PARTICIPANT	\N	PRESENT	0
96354	96232	11042G	PARTICIPANT	\N	PRESENT	0
96414	96232	11091R	PARTICIPANT	\N	PRESENT	0
96415	96232	14159V	PARTICIPANT	\N	PRESENT	0
96416	96232	01008M	PARTICIPANT	\N	PRESENT	0
96417	96232	04048J	PARTICIPANT	\N	PRESENT	0
96418	96232	11010L	PARTICIPANT	\N	PRESENT	0
96419	96232	95062K	PARTICIPANT	\N	PRESENT	0
96420	96232	90003B	PARTICIPANT	\N	PRESENT	0
96421	96232	07029T	PARTICIPANT	\N	PRESENT	0
96422	96232	11097X	PARTICIPANT	\N	PRESENT	0
96423	96232	11053K	PARTICIPANT	\N	PRESENT	0
96425	96232	11089X	PARTICIPANT	\N	PRESENT	0
96428	96232	11109J	PARTICIPANT	\N	PRESENT	0
96429	96232	08031R	PARTICIPANT	\N	PRESENT	0
96439	96232	11048N	PARTICIPANT	\N	PRESENT	0
96440	96232	11083R	PARTICIPANT	\N	PRESENT	0
96441	96232	11101A	PARTICIPANT	\N	PRESENT	0
96442	96232	04080J	PARTICIPANT	\N	PRESENT	0
96458	96232	08056B	PARTICIPANT	\N	PRESENT	0
96455	96232	11105E	PARTICIPANT	\N	PRESENT	0
96456	96232	08012N	PARTICIPANT	\N	PRESENT	0
96459	96232	01056V	PARTICIPANT	\N	PRESENT	0
96480	96232	14225N	PARTICIPANT	\N	PRESENT	0
96495	96232	04043D	PARTICIPANT	\N	PRESENT	0
96497	96232	14053L	PARTICIPANT	\N	PRESENT	0
96594	96233	92015P	PARTICIPANT	\N	PRESENT	0
96595	96233	08068F	PARTICIPANT	\N	PRESENT	0
96596	96233	08014Q	PARTICIPANT	\N	PRESENT	0
96597	96233	07026Q	PARTICIPANT	\N	PRESENT	0
96599	96233	08052W	PARTICIPANT	\N	PRESENT	0
96602	96233	11067R	PARTICIPANT	\N	PRESENT	0
96603	96233	11025F	PARTICIPANT	\N	PRESENT	0
96604	96233	14159V	PARTICIPANT	\N	PRESENT	0
96605	96233	98022P	PARTICIPANT	\N	PRESENT	0
96606	96233	14219Q	PARTICIPANT	\N	PRESENT	0
96607	96233	14013P	PARTICIPANT	\N	PRESENT	0
96608	96233	14109K	PARTICIPANT	\N	PRESENT	0
96609	96233	08053X	PARTICIPANT	\N	PRESENT	0
96610	96233	95063L	PARTICIPANT	\N	PRESENT	0
96611	96233	13002U	PARTICIPANT	\N	PRESENT	0
96612	96233	14063N	PARTICIPANT	\N	PRESENT	0
96613	96233	14277B	PARTICIPANT	\N	PRESENT	0
96614	96233	14275Y	PARTICIPANT	\N	PRESENT	0
96632	96233	11036J	PARTICIPANT	\N	PRESENT	0
96633	96233	14133K	PARTICIPANT	\N	PRESENT	0
96634	96233	04088S	PARTICIPANT	\N	PRESENT	0
96635	96233	14055N	PARTICIPANT	\N	PRESENT	0
96636	96233	04048J	PARTICIPANT	\N	PRESENT	0
96637	96233	14273W	PARTICIPANT	\N	PRESENT	0
96638	96233	04089T	PARTICIPANT	\N	PRESENT	0
96640	96233	08051V	PARTICIPANT	\N	PRESENT	0
96641	96233	01037S	PARTICIPANT	\N	PRESENT	0
96642	96233	11063M	PARTICIPANT	\N	PRESENT	0
96646	96233	08056B	PARTICIPANT	\N	PRESENT	0
96647	96233	80027E	PARTICIPANT	\N	PRESENT	0
96648	96233	11040E	PARTICIPANT	\N	PRESENT	0
96649	96233	11033F	PARTICIPANT	\N	PRESENT	0
96650	96233	14201E	PARTICIPANT	\N	PRESENT	0
96651	96233	04059M	PARTICIPANT	\N	PRESENT	0
96652	96233	01011G	PARTICIPANT	\N	PRESENT	0
96653	96233	14051J	PARTICIPANT	\N	PRESENT	0
96654	96233	08024S	PARTICIPANT	\N	PRESENT	0
96655	96233	11046L	PARTICIPANT	\N	PRESENT	0
96656	96233	04066L	PARTICIPANT	\N	PRESENT	0
96657	96233	01016M	PARTICIPANT	\N	PRESENT	0
96658	96233	14263U	PARTICIPANT	\N	PRESENT	0
96659	96233	12041X	PARTICIPANT	\N	PRESENT	0
96660	96233	04050C	PARTICIPANT	\N	PRESENT	0
96661	96233	04085P	PARTICIPANT	\N	PRESENT	0
96662	96233	11034G	PARTICIPANT	\N	PRESENT	0
96663	96233	11054L	PARTICIPANT	\N	PRESENT	0
96664	96233	08055A	PARTICIPANT	\N	PRESENT	0
96665	96233	00003C	PARTICIPANT	\N	PRESENT	0
96666	96233	01031L	PARTICIPANT	\N	PRESENT	0
96667	96233	08012N	PARTICIPANT	\N	PRESENT	0
96668	96233	04034C	PARTICIPANT	\N	PRESENT	0
96669	96233	95037J	PARTICIPANT	\N	PRESENT	0
96670	96233	14227Q	PARTICIPANT	\N	PRESENT	0
96671	96233	14281W	PARTICIPANT	\N	PRESENT	0
96672	96233	08058D	PARTICIPANT	\N	PRESENT	0
96673	96233	11015D	PARTICIPANT	\N	PRESENT	0
96674	96233	11105E	PARTICIPANT	\N	PRESENT	0
96675	96233	14229S	PARTICIPANT	\N	PRESENT	0
96676	96233	11112D	PARTICIPANT	\N	PRESENT	0
96677	96233	14001X	PARTICIPANT	\N	PRESENT	0
96592	96233	86034E	PARTICIPANT	\N	PRESENT	0
96593	96233	80013X	PARTICIPANT	\N	PRESENT	0
96678	96233	14207L	PARTICIPANT	\N	PRESENT	0
96679	96233	04053F	PARTICIPANT	\N	PRESENT	0
96680	96233	08016S	PARTICIPANT	\N	PRESENT	0
96681	96233	14257W	PARTICIPANT	\N	PRESENT	0
96682	96233	14097Y	PARTICIPANT	\N	PRESENT	0
96683	96233	04077P	PARTICIPANT	\N	PRESENT	0
96684	96233	08061X	PARTICIPANT	\N	PRESENT	0
96685	96233	08038Y	PARTICIPANT	\N	PRESENT	0
96686	96233	11110B	PARTICIPANT	\N	PRESENT	0
96687	96233	11066Q	PARTICIPANT	\N	PRESENT	0
96688	96233	14085U	PARTICIPANT	\N	PRESENT	0
96689	96233	04045F	PARTICIPANT	\N	PRESENT	0
96690	96233	11077T	PARTICIPANT	\N	PRESENT	0
96691	96233	11042G	PARTICIPANT	\N	PRESENT	0
96692	96233	01056V	PARTICIPANT	\N	PRESENT	0
96693	96233	04094Q	PARTICIPANT	\N	PRESENT	0
96694	96233	11089X	PARTICIPANT	\N	PRESENT	0
96695	96233	01027Q	PARTICIPANT	\N	PRESENT	0
96696	96233	14269B	PARTICIPANT	\N	PRESENT	0
96697	96233	08011M	PARTICIPANT	\N	PRESENT	0
96699	96233	04095R	PARTICIPANT	\N	PRESENT	0
96700	96233	04079R	PARTICIPANT	\N	PRESENT	0
96701	96233	02002K	PARTICIPANT	\N	PRESENT	0
96702	96233	12042Y	PARTICIPANT	\N	PRESENT	0
96703	96233	11072N	PARTICIPANT	\N	PRESENT	0
96704	96233	08073C	PARTICIPANT	\N	PRESENT	0
96706	96233	11109J	PARTICIPANT	\N	PRESENT	0
96707	96233	08035V	PARTICIPANT	\N	PRESENT	0
96708	96233	04047H	PARTICIPANT	\N	PRESENT	0
96709	96233	11029K	PARTICIPANT	\N	PRESENT	0
96710	96233	01044R	PARTICIPANT	\N	PRESENT	0
96711	96233	77002U	PARTICIPANT	\N	PRESENT	0
96712	96233	11055M	PARTICIPANT	\N	PRESENT	0
96713	96233	11083R	PARTICIPANT	\N	PRESENT	0
96714	96233	11099A	PARTICIPANT	\N	PRESENT	0
96715	96233	99004R	PARTICIPANT	\N	PRESENT	0
96716	96233	11107G	PARTICIPANT	\N	PRESENT	0
96717	96233	01058X	PARTICIPANT	\N	PRESENT	0
96718	96233	01014K	PARTICIPANT	\N	PRESENT	0
96719	96233	11037K	PARTICIPANT	\N	PRESENT	0
96720	96233	08039A	PARTICIPANT	\N	PRESENT	0
96721	96233	14014Q	PARTICIPANT	\N	PRESENT	0
96722	96233	95062K	PARTICIPANT	\N	PRESENT	0
96723	96233	14123H	PARTICIPANT	\N	PRESENT	0
111766	110314	04088S	PARTICIPANT	\N	PRESENT	0
111767	110314	14157T	PARTICIPANT	\N	PRESENT	0
111769	110314	11095V	PARTICIPANT	\N	PRESENT	0
111770	110314	14107H	PARTICIPANT	\N	PRESENT	0
111771	110314	11066Q	PARTICIPANT	\N	PRESENT	0
111764	110314	95063L	PARTICIPANT	\N	PRESENT	0
111765	110314	14241N	PARTICIPANT	\N	PRESENT	0
111772	110314	14215L	PARTICIPANT	\N	PRESENT	0
111823	111773	95049N	PARTICIPANT	\N	EXCUSE	0
111775	111773	04085P	PARTICIPANT	\N	PRESENT	0
111776	111773	05008E	PRESIDENT	0	PRESENT	0
111777	111773	11030C	PARTICIPANT	\N	PRESENT	0
111778	111773	11033F	PARTICIPANT	\N	PRESENT	0
111779	111773	14065Q	PARTICIPANT	\N	PRESENT	0
111832	110314	08060W	PARTICIPANT	\N	PRESENT	0
111781	111773	04047H	PARTICIPANT	\N	PRESENT	0
111782	111773	11032E	PARTICIPANT	\N	PRESENT	0
111783	111773	04038G	PARTICIPANT	\N	PRESENT	0
111784	111773	99002P	PARTICIPANT	\N	PRESENT	0
111785	111773	11056N	PARTICIPANT	\N	PRESENT	0
111786	111773	14259Y	PARTICIPANT	\N	PRESENT	0
111787	111773	11035H	PARTICIPANT	\N	PRESENT	0
111833	111351	01022K	PARTICIPANT	\N	PRESENT	0
111789	111773	11113E	PARTICIPANT	\N	PRESENT	0
111790	111773	01024M	PARTICIPANT	\N	PRESENT	0
111791	111773	14215L	PARTICIPANT	\N	PRESENT	0
111792	111773	11034G	PARTICIPANT	\N	EXCUSE	0
111793	111773	08018U	PARTICIPANT	\N	PRESENT	0
111794	111773	11010L	PARTICIPANT	\N	PRESENT	0
111795	111773	01007L	PARTICIPANT	\N	PRESENT	0
111796	111773	11049P	PARTICIPANT	\N	PRESENT	0
111797	111773	08044W	PARTICIPANT	\N	PRESENT	0
111834	110314	14073Q	PARTICIPANT	\N	PRESENT	0
111799	111773	11026G	PARTICIPANT	\N	PRESENT	0
111836	110314	11029K	PARTICIPANT	\N	PRESENT	0
111837	110314	14217N	PARTICIPANT	\N	PRESENT	0
111889	111888	04059M	PARTICIPANT	\N	PRESENT	0
111803	111773	14273W	PARTICIPANT	\N	PRESENT	0
111839	111835	04085P	PARTICIPANT	\N	PRESENT	0
111805	111773	14147R	PARTICIPANT	\N	PRESENT	0
111890	111888	04042C	PARTICIPANT	\N	PRESENT	0
111807	111773	08051V	PARTICIPANT	\N	PRESENT	0
111808	111773	11072N	PARTICIPANT	\N	PRESENT	0
111809	111773	07034Q	PARTICIPANT	\N	PRESENT	0
111810	111773	04074L	PARTICIPANT	\N	PRESENT	0
111841	111835	11030C	PARTICIPANT	\N	PRESENT	0
111812	111773	95063L	PARTICIPANT	\N	PRESENT	0
111898	110314	14219Q	PARTICIPANT	\N	PRESENT	0
111814	111773	01028R	PARTICIPANT	\N	PRESENT	0
111815	111773	98035U	PARTICIPANT	\N	PRESENT	0
111816	111773	04056J	PARTICIPANT	\N	PRESENT	0
111817	111773	14275Y	PARTICIPANT	\N	PRESENT	0
111818	111773	04044E	PRESIDENT	1	PRESENT	0
111819	111773	11037K	PARTICIPANT	\N	PRESENT	0
111820	111773	92045V	PARTICIPANT	\N	PRESENT	0
111843	111835	14065Q	PARTICIPANT	\N	PRESENT	0
111822	111773	01047U	PARTICIPANT	\N	PRESENT	0
111891	111888	95035G	PARTICIPANT	\N	PRESENT	0
111845	111835	04047H	PARTICIPANT	\N	PRESENT	0
111892	111888	04036E	PARTICIPANT	\N	PRESENT	0
111847	111835	04038G	PARTICIPANT	\N	PRESENT	0
111893	111888	04070G	PARTICIPANT	\N	PRESENT	0
111894	111888	04088S	PARTICIPANT	\N	PRESENT	0
111850	111835	14259Y	PARTICIPANT	\N	PRESENT	0
111851	111835	11035H	PARTICIPANT	\N	PRESENT	0
111895	111888	98035U	PARTICIPANT	\N	PRESENT	0
111853	111835	11113E	PARTICIPANT	\N	PRESENT	0
111854	111835	01024M	PARTICIPANT	\N	PRESENT	0
111855	111835	14215L	PARTICIPANT	\N	PRESENT	0
111856	111835	11034G	PARTICIPANT	\N	EXCUSE	0
111857	111835	08018U	PARTICIPANT	\N	PRESENT	0
111858	111835	11010L	PARTICIPANT	\N	PRESENT	0
111859	111835	01007L	PARTICIPANT	\N	PRESENT	0
111896	110314	04066L	PARTICIPANT	\N	PRESENT	0
111861	111835	08044W	PARTICIPANT	\N	PRESENT	0
111897	110314	01015L	PARTICIPANT	\N	PRESENT	0
111863	111835	11026G	PARTICIPANT	\N	PRESENT	0
111899	110314	95062K	PARTICIPANT	\N	PRESENT	0
111900	110314	80013X	PARTICIPANT	\N	PRESENT	0
111912	110314	11103C	PARTICIPANT	\N	PRESENT	0
111867	111835	14273W	PARTICIPANT	\N	PRESENT	0
111913	110314	14231L	PARTICIPANT	\N	PRESENT	0
111869	111835	14147R	PARTICIPANT	\N	PRESENT	0
111870	111835	95049N	PARTICIPANT	\N	EXCUSE	0
111914	110314	01047U	PARTICIPANT	\N	PRESENT	0
111872	111835	11072N	PARTICIPANT	\N	PRESENT	0
111873	111835	07034Q	PARTICIPANT	\N	PRESENT	0
111874	111835	04074L	PARTICIPANT	\N	PRESENT	0
111915	110314	08047A	PARTICIPANT	\N	PRESENT	0
111876	111835	95063L	PARTICIPANT	\N	PRESENT	0
111916	110314	08017T	PARTICIPANT	\N	PRESENT	0
111878	111835	01028R	PARTICIPANT	\N	PRESENT	0
112063	112061	14239U	PARTICIPANT	\N	PRESENT	0
112064	112061	11055M	PARTICIPANT	\N	PRESENT	0
112065	112061	01046T	PARTICIPANT	\N	PRESENT	0
111882	111835	04044E	PRESIDENT	0	PRESENT	0
112217	112179	07004J	PARTICIPANT	\N	PRESENT	0
111884	111835	92045V	PARTICIPANT	\N	PRESENT	0
112067	112061	14255U	PARTICIPANT	\N	PRESENT	0
111886	111835	01047U	PARTICIPANT	\N	PRESENT	0
111887	110314	11039M	PARTICIPANT	\N	PRESENT	0
112218	112179	08069G	PARTICIPANT	\N	PRESENT	0
112069	112061	00003C	PARTICIPANT	\N	EXCUSE	0
112070	112061	14053L	PARTICIPANT	\N	PRESENT	0
112071	112061	11103C	PARTICIPANT	\N	PRESENT	0
112072	112061	11044J	PARTICIPANT	\N	EXCUSE	0
112073	112061	14195A	PARTICIPANT	\N	PRESENT	0
112074	112061	14267Y	PARTICIPANT	\N	PRESENT	0
112219	112179	95015C	PARTICIPANT	\N	PRESENT	0
112076	112061	11031D	PARTICIPANT	\N	PRESENT	0
112077	112061	08052W	PARTICIPANT	\N	PRESENT	0
112078	112061	01059Y	PARTICIPANT	\N	PRESENT	0
112079	112061	04081K	PARTICIPANT	\N	PRESENT	0
112080	112061	98024R	PARTICIPANT	\N	PRESENT	0
112081	112061	10006L	PARTICIPANT	\N	PRESENT	0
112220	112179	01037S	PARTICIPANT	\N	PRESENT	0
112083	112061	14217N	PARTICIPANT	\N	PRESENT	0
112084	112061	14042U	PARTICIPANT	\N	PRESENT	0
112222	112061	11072N	PARTICIPANT	\N	PRESENT	0
112086	112061	12042Y	PARTICIPANT	\N	PRESENT	0
112087	112061	14281W	PARTICIPANT	\N	PRESENT	0
112268	112267	14133K	PARTICIPANT	\N	PRESENT	0
112089	112061	01003G	PARTICIPANT	\N	PRESENT	0
112269	112267	96004D	PRESIDENT	0	PRESENT	0
112091	112061	14231L	PARTICIPANT	\N	PRESENT	0
112092	112061	11061K	PARTICIPANT	\N	EXCUSE	0
112093	112061	08048B	PARTICIPANT	\N	PRESENT	0
112094	112061	08041T	PARTICIPANT	\N	PRESENT	0
112270	112267	11040E	PARTICIPANT	\N	PRESENT	0
112096	112061	14026U	PARTICIPANT	\N	PRESENT	0
112097	112061	14213J	PARTICIPANT	\N	PRESENT	0
112098	112061	14121F	PARTICIPANT	\N	PRESENT	0
112099	112061	11112D	PARTICIPANT	\N	PRESENT	0
112100	112061	14037X	PARTICIPANT	\N	PRESENT	0
112101	112061	14018U	PARTICIPANT	\N	PRESENT	0
112102	112061	11067R	PARTICIPANT	\N	PRESENT	0
112103	112061	14223L	PARTICIPANT	\N	PRESENT	0
112104	112061	04092N	PRESIDENT	0	PRESENT	0
112105	112061	14265W	PARTICIPANT	\N	PRESENT	0
112106	112061	14119M	PARTICIPANT	\N	PRESENT	0
112107	112061	14071N	PARTICIPANT	\N	PRESENT	0
112271	112267	11035H	PARTICIPANT	\N	PRESENT	0
112272	112267	14073Q	PARTICIPANT	\N	PRESENT	0
112110	112061	14271U	PARTICIPANT	\N	PRESENT	0
112111	112061	14017T	PARTICIPANT	\N	EXCUSE	0
112112	112061	11093T	PARTICIPANT	\N	PRESENT	0
112113	112061	11097X	PARTICIPANT	\N	PRESENT	0
112114	112061	04045F	PARTICIPANT	\N	PRESENT	0
112115	112061	14227Q	PARTICIPANT	\N	PRESENT	0
112116	112061	01034P	PARTICIPANT	\N	PRESENT	0
112117	112061	11025F	PARTICIPANT	\N	PRESENT	0
112118	112061	11063M	PARTICIPANT	\N	PRESENT	0
112119	112061	14269B	PARTICIPANT	\N	PRESENT	0
112273	112267	11026G	PARTICIPANT	\N	PRESENT	0
112275	112267	98046X	PARTICIPANT	\N	PRESENT	0
112276	112267	04080J	PARTICIPANT	\N	PRESENT	0
112277	112267	11012A	PARTICIPANT	\N	PRESENT	0
112278	112267	98035U	PARTICIPANT	\N	PRESENT	0
112279	112267	92045V	PARTICIPANT	\N	PRESENT	0
112280	112267	04034C	PARTICIPANT	\N	PRESENT	0
112281	112267	01016M	PARTICIPANT	\N	PRESENT	0
112283	112267	14026U	PARTICIPANT	\N	EXCUSE	0
112284	112267	04035D	PARTICIPANT	\N	EXCUSE	0
112285	112267	14097Y	PARTICIPANT	\N	EXCUSE	0
112286	112267	04057K	PARTICIPANT	\N	EXCUSE	0
112287	112267	08042U	PARTICIPANT	\N	EXCUSE	0
112516	112515	11036J	PARTICIPANT	\N	PRESENT	0
112517	112515	04043D	PARTICIPANT	\N	PRESENT	0
112532	103118	04049K	PARTICIPANT	\N	PRESENT	0
93813	93812	11027H	PARTICIPANT	\N	PRESENT	0
93814	93812	08038Y	PARTICIPANT	\N	PRESENT	0
93815	93812	92018S	PARTICIPANT	\N	PRESENT	0
93816	93812	14179A	PARTICIPANT	\N	PRESENT	0
93817	93812	11106F	PARTICIPANT	\N	PRESENT	0
93818	93812	08053X	PARTICIPANT	\N	PRESENT	0
93819	93812	11105E	PARTICIPANT	\N	PRESENT	0
93820	93812	14235Q	PARTICIPANT	\N	PRESENT	0
93845	93844	11039M	PARTICIPANT	\N	PRESENT	0
93846	93844	98042T	PARTICIPANT	\N	PRESENT	0
93847	93844	01019Q	PARTICIPANT	\N	PRESENT	0
118607	117825	08060W	PARTICIPANT	\N	PRESENT	0
118702	117825	08018U	PARTICIPANT	\N	PRESENT	0
118609	117825	01056V	PARTICIPANT	\N	PRESENT	0
118610	117825	01027Q	PARTICIPANT	\N	PRESENT	0
118611	117825	04036E	PARTICIPANT	\N	PRESENT	0
118612	117825	11025F	PARTICIPANT	\N	PRESENT	0
118613	117825	95062K	PARTICIPANT	\N	PRESENT	0
118614	117825	11046L	PARTICIPANT	\N	PRESENT	0
118615	117825	11104D	PARTICIPANT	\N	PRESENT	0
118616	117825	11061K	PARTICIPANT	\N	PRESENT	0
118617	117825	04097T	PARTICIPANT	\N	PRESENT	0
118618	117825	01058X	PARTICIPANT	\N	PRESENT	0
118619	117825	99004R	PARTICIPANT	\N	PRESENT	0
118620	117825	77002U	PARTICIPANT	\N	PRESENT	0
118621	117825	04047H	PARTICIPANT	\N	PRESENT	0
118622	117825	11033F	PARTICIPANT	\N	PRESENT	0
118623	117825	14026U	PARTICIPANT	\N	PRESENT	0
118624	117825	11055M	PARTICIPANT	\N	PRESENT	0
118625	117825	95030B	PARTICIPANT	\N	PRESENT	0
118626	117825	11099A	PARTICIPANT	\N	PRESENT	0
118627	117825	04067M	PARTICIPANT	\N	PRESENT	0
118628	117825	89017R	PARTICIPANT	\N	PRESENT	0
118629	117825	04035D	PARTICIPANT	\N	PRESENT	0
118630	117825	95041E	PARTICIPANT	\N	PRESENT	0
118631	117825	04044E	PARTICIPANT	\N	PRESENT	0
118632	117825	11083R	PARTICIPANT	\N	PRESENT	0
118633	117825	86044G	PARTICIPANT	\N	PRESENT	0
118634	117825	08051V	PARTICIPANT	\N	PRESENT	0
118635	117825	96004D	PARTICIPANT	\N	PRESENT	0
118636	117825	11012A	PARTICIPANT	\N	PRESENT	0
118637	117825	08049C	PARTICIPANT	\N	PRESENT	0
118638	117825	14241N	PARTICIPANT	\N	PRESENT	0
118639	117825	08031R	PARTICIPANT	\N	PRESENT	0
118640	117825	14251Q	PARTICIPANT	\N	PRESENT	0
118641	117825	14261S	PARTICIPANT	\N	PRESENT	0
118642	117825	14123H	PARTICIPANT	\N	PRESENT	0
118643	117825	08061X	PARTICIPANT	\N	PRESENT	0
118644	117825	04071H	PARTICIPANT	\N	PRESENT	0
118645	117825	14030Q	PARTICIPANT	\N	PRESENT	0
118646	117825	01007L	PARTICIPANT	\N	PRESENT	0
118647	117825	14169X	PARTICIPANT	\N	PRESENT	0
118648	117825	14327T	PARTICIPANT	\N	PRESENT	0
118649	117825	08010L	PARTICIPANT	\N	PRESENT	0
118650	117825	11043H	PARTICIPANT	\N	PRESENT	0
118651	117825	08034U	PARTICIPANT	\N	PRESENT	0
118652	117825	11077T	PARTICIPANT	\N	PRESENT	0
118653	117825	11105E	PARTICIPANT	\N	PRESENT	0
118654	117825	01057W	PARTICIPANT	\N	PRESENT	0
118655	117825	14042U	PARTICIPANT	\N	PRESENT	0
118656	117825	08056B	PARTICIPANT	\N	PRESENT	0
118657	117825	08009T	PARTICIPANT	\N	PRESENT	0
118658	117825	95067Q	PARTICIPANT	\N	PRESENT	0
118659	117825	11053K	PARTICIPANT	\N	PRESENT	0
118660	117825	11085T	PARTICIPANT	\N	PRESENT	0
118661	117825	11100Y	PARTICIPANT	\N	PRESENT	0
118662	117825	08044W	PARTICIPANT	\N	PRESENT	0
118663	117825	04040A	PARTICIPANT	\N	PRESENT	0
118664	117825	08069G	PARTICIPANT	\N	PRESENT	0
118665	117825	98042T	PARTICIPANT	\N	PRESENT	0
118666	117825	11049P	PARTICIPANT	\N	PRESENT	0
118667	117825	14073Q	PARTICIPANT	\N	PRESENT	0
118668	117825	14271U	PARTICIPANT	\N	PRESENT	0
118669	117825	11088W	PARTICIPANT	\N	PRESENT	0
118670	117825	14083S	PARTICIPANT	\N	PRESENT	0
118671	117825	14195A	PARTICIPANT	\N	PRESENT	0
118672	117825	01034P	PARTICIPANT	\N	PRESENT	0
118673	117825	14038Y	PARTICIPANT	\N	PRESENT	0
118674	117825	11082Q	PARTICIPANT	\N	PRESENT	0
118675	117825	14033T	PARTICIPANT	\N	PRESENT	0
118676	117825	14041T	PARTICIPANT	\N	PRESENT	0
118677	117825	11109J	PARTICIPANT	\N	PRESENT	0
118678	117825	14269B	PARTICIPANT	\N	PRESENT	0
118679	117825	14147R	PARTICIPANT	\N	PRESENT	0
118680	117825	04053F	PARTICIPANT	\N	PRESENT	0
118681	117825	04057K	PARTICIPANT	\N	PRESENT	0
118682	117825	05012A	PARTICIPANT	\N	PRESENT	0
118683	117825	11103C	PARTICIPANT	\N	PRESENT	0
118684	117825	01059Y	PARTICIPANT	\N	PRESENT	0
118685	117825	97011G	PARTICIPANT	\N	PRESENT	0
118686	117825	04054G	PARTICIPANT	\N	PRESENT	0
118687	117825	14187A	PARTICIPANT	\N	PRESENT	0
118688	117825	14329V	PARTICIPANT	\N	PRESENT	0
118689	117825	04056J	PARTICIPANT	\N	PRESENT	0
118690	117825	14037X	PARTICIPANT	\N	PRESENT	0
118691	117825	14061L	PARTICIPANT	\N	PRESENT	0
118692	117825	14059S	PARTICIPANT	\N	PRESENT	0
118693	117825	04055H	PARTICIPANT	\N	PRESENT	0
118694	117825	01008M	PARTICIPANT	\N	PRESENT	0
118695	117825	07034Q	PARTICIPANT	\N	PRESENT	0
118696	117825	04043D	PARTICIPANT	\N	PRESENT	0
118697	117825	14071N	PARTICIPANT	\N	PRESENT	0
118698	117825	14193X	PARTICIPANT	\N	PRESENT	0
118699	117825	04033B	PARTICIPANT	\N	PRESENT	0
118700	117825	08039A	PARTICIPANT	\N	PRESENT	0
118701	117825	04086Q	PARTICIPANT	\N	PRESENT	0
118715	117825	02002K	PARTICIPANT	\N	PRESENT	0
118704	117825	14069U	PARTICIPANT	\N	PRESENT	0
118705	117825	92031P	PARTICIPANT	\N	PRESENT	0
118706	117825	14215L	PARTICIPANT	\N	PRESENT	0
118707	117825	14079W	PARTICIPANT	\N	PRESENT	0
118708	117825	14217N	PARTICIPANT	\N	PRESENT	0
118709	117825	14249W	PARTICIPANT	\N	PRESENT	0
118710	117825	11057P	PARTICIPANT	\N	PRESENT	0
118711	117825	14213J	PARTICIPANT	\N	PRESENT	0
118712	117825	10006L	PARTICIPANT	\N	PRESENT	0
118713	117825	98018T	PARTICIPANT	\N	PRESENT	0
118714	117825	14119M	PARTICIPANT	\N	PRESENT	0
118716	117825	10015M	PARTICIPANT	\N	PRESENT	0
118717	117825	88008L	PARTICIPANT	\N	PRESENT	0
118718	117825	11113E	PARTICIPANT	\N	PRESENT	0
118719	117825	04061F	PARTICIPANT	\N	PRESENT	0
118720	117825	08038Y	PARTICIPANT	\N	PRESENT	0
118721	117825	01044R	PARTICIPANT	\N	PRESENT	0
118723	117825	12041X	PARTICIPANT	\N	PRESENT	0
118773	117825	08042U	PARTICIPANT	\N	PRESENT	0
118727	117825	04080J	PARTICIPANT	\N	PRESENT	0
118728	117825	11089X	PARTICIPANT	\N	PRESENT	0
118757	117825	08011M	PARTICIPANT	\N	PRESENT	0
118774	117825	04081K	PARTICIPANT	\N	PRESENT	0
118759	117825	14231L	PARTICIPANT	\N	PRESENT	0
118761	118760	11039M	PARTICIPANT	\N	PRESENT	0
118762	118760	14073Q	PARTICIPANT	\N	PRESENT	0
118763	118760	11043H	PARTICIPANT	\N	PRESENT	0
118764	118760	14241N	PARTICIPANT	\N	PRESENT	0
118765	118760	14235Q	PARTICIPANT	\N	PRESENT	0
118766	117825	04066L	PARTICIPANT	\N	PRESENT	0
118772	117825	11110B	PARTICIPANT	\N	PRESENT	0
118776	118775	04085P	PARTICIPANT	\N	PRESENT	0
118777	118775	05008E	PRESIDENT	0	PRESENT	0
118778	118775	04047H	PARTICIPANT	\N	PRESENT	0
118779	118775	11032E	PARTICIPANT	\N	PRESENT	0
118780	118775	14041T	PARTICIPANT	\N	PRESENT	0
118781	118775	01024M	PARTICIPANT	\N	EXCUSE	0
118782	118775	14215L	PARTICIPANT	\N	PRESENT	0
118783	118775	11034G	PARTICIPANT	\N	PRESENT	0
118784	118775	08018U	PARTICIPANT	\N	PRESENT	0
118785	118775	01007L	PARTICIPANT	\N	PRESENT	0
118786	118775	11049P	PARTICIPANT	\N	PRESENT	0
118787	118775	11026G	PARTICIPANT	\N	PRESENT	0
118788	118775	04079R	PARTICIPANT	\N	PRESENT	0
118789	118775	14111D	PARTICIPANT	\N	PRESENT	0
118790	118775	14273W	PARTICIPANT	\N	PRESENT	0
118791	118775	95049N	PARTICIPANT	\N	PRESENT	0
118792	118775	08051V	PARTICIPANT	\N	PRESENT	0
118793	118775	07034Q	PARTICIPANT	\N	PRESENT	0
118794	118775	04074L	PARTICIPANT	\N	PRESENT	0
118795	118775	95063L	PARTICIPANT	\N	PRESENT	0
118796	118775	01028R	PARTICIPANT	\N	PRESENT	0
118797	118775	98035U	PARTICIPANT	\N	PRESENT	0
118798	118775	04056J	PARTICIPANT	\N	PRESENT	0
118799	118775	04044E	PARTICIPANT	\N	PRESENT	0
118800	118775	11037K	PARTICIPANT	\N	PRESENT	0
118801	118775	92045V	PARTICIPANT	\N	EXCUSE	0
118802	118775	95067Q	PARTICIPANT	\N	PRESENT	0
118827	118826	92039X	PARTICIPANT	\N	PRESENT	0
118915	118914	04055H	PARTICIPANT	\N	PRESENT	0
118924	118923	01016M	PARTICIPANT	\N	PRESENT	0
118953	118952	01044R	PARTICIPANT	\N	PRESENT	0
98636	95980	08024S	PARTICIPANT	\N	PRESENT	0
98655	95980	14255U	PARTICIPANT	\N	PRESENT	0
98653	95980	14213J	PARTICIPANT	\N	PRESENT	0
98654	95980	11093T	PARTICIPANT	\N	PRESENT	0
98656	95980	14030Q	PARTICIPANT	\N	PRESENT	0
98657	95980	14219Q	PARTICIPANT	\N	PRESENT	0
98658	95980	04092N	PARTICIPANT	\N	PRESENT	0
98659	95980	04053F	PARTICIPANT	\N	PRESENT	0
98660	95980	14281W	PARTICIPANT	\N	PRESENT	0
98661	95980	14269B	PARTICIPANT	\N	PRESENT	0
98662	95980	14121F	PARTICIPANT	\N	PRESENT	0
98663	95980	14271U	PARTICIPANT	\N	PRESENT	0
98664	95980	11107G	PARTICIPANT	\N	PRESENT	0
98665	95980	14257W	PARTICIPANT	\N	PRESENT	0
98666	95980	14014Q	PARTICIPANT	\N	PRESENT	0
98667	95980	04045F	PARTICIPANT	\N	PRESENT	0
98668	95980	11067R	PARTICIPANT	\N	PRESENT	0
98669	95980	11059R	PARTICIPANT	\N	PRESENT	0
98670	95980	14207L	PARTICIPANT	\N	PRESENT	0
98671	95980	11095V	PARTICIPANT	\N	PRESENT	0
98672	95980	11112D	PARTICIPANT	\N	PRESENT	0
98673	95980	08052W	PARTICIPANT	\N	PRESENT	0
98674	95980	98046X	PARTICIPANT	\N	PRESENT	0
98675	95980	11061K	PARTICIPANT	\N	PRESENT	0
98676	95980	11063M	PARTICIPANT	\N	PRESENT	0
98677	95980	11031D	PARTICIPANT	\N	PRESENT	0
98678	95980	01024M	PARTICIPANT	\N	PRESENT	0
98679	95980	14215L	PARTICIPANT	\N	PRESENT	0
98680	95980	01003G	PARTICIPANT	\N	PRESENT	0
98681	95980	14205J	PARTICIPANT	\N	PRESENT	0
98682	95980	14259Y	PARTICIPANT	\N	PRESENT	0
98683	95980	14191V	PARTICIPANT	\N	PRESENT	0
98684	95980	14119M	PARTICIPANT	\N	PRESENT	0
98685	95980	14195A	PARTICIPANT	\N	PRESENT	0
98686	95980	08019V	PARTICIPANT	\N	PRESENT	0
98687	95980	14033T	PARTICIPANT	\N	PRESENT	0
98688	95980	07029T	PARTICIPANT	\N	PRESENT	0
98689	95980	11071M	PARTICIPANT	\N	PRESENT	0
98690	95980	07032N	PARTICIPANT	\N	PRESENT	0
98691	95980	04088S	PARTICIPANT	\N	PRESENT	0
98692	95980	14265W	PARTICIPANT	\N	PRESENT	0
98693	95980	95030B	PARTICIPANT	\N	PRESENT	0
98694	95980	04042C	PARTICIPANT	\N	PRESENT	0
98695	95980	14223L	PARTICIPANT	\N	PRESENT	0
98696	95980	01027Q	PARTICIPANT	\N	PRESENT	0
98697	95980	04044E	PARTICIPANT	\N	PRESENT	0
98698	95980	04033B	PARTICIPANT	\N	PRESENT	0
98699	95980	14071N	PARTICIPANT	\N	PRESENT	0
98700	95980	05012A	PARTICIPANT	\N	PRESENT	0
98701	95980	11103C	PARTICIPANT	\N	PRESENT	0
98702	95980	14053L	PARTICIPANT	\N	PRESENT	0
98703	95980	14273W	PARTICIPANT	\N	PRESENT	0
98704	95980	14079W	PARTICIPANT	\N	PRESENT	0
98705	95980	14135M	PARTICIPANT	\N	PRESENT	0
98706	95980	08069G	PARTICIPANT	\N	PRESENT	0
98707	95980	14159V	PARTICIPANT	\N	PRESENT	0
98708	95980	11025F	PARTICIPANT	\N	PRESENT	0
98709	95980	14059S	PARTICIPANT	\N	PRESENT	0
98710	95980	01025N	PARTICIPANT	\N	PRESENT	0
98711	95980	08010L	PARTICIPANT	\N	PRESENT	0
98712	95980	14085U	PARTICIPANT	\N	PRESENT	0
98713	95980	08048B	PARTICIPANT	\N	PRESENT	0
123213	120874	01046T	PARTICIPANT	\N	EXCUSE	0
123214	120874	14209N	PARTICIPANT	\N	EXCUSE	0
123215	120874	11089X	PARTICIPANT	\N	EXCUSE	0
123216	120874	04061F	PARTICIPANT	\N	EXCUSE	0
123217	120874	01048V	PARTICIPANT	\N	EXCUSE	0
123218	120874	14221J	PARTICIPANT	\N	EXCUSE	0
123219	120874	04043D	PARTICIPANT	\N	EXCUSE	0
123220	120874	11082Q	PARTICIPANT	\N	EXCUSE	0
123222	120874	80013X	PARTICIPANT	\N	EXCUSE	0
123224	120874	11068S	PARTICIPANT	\N	EXCUSE	0
123232	120874	14257W	PARTICIPANT	\N	EXCUSE	0
123233	120874	01058X	PARTICIPANT	\N	EXCUSE	0
123238	123237	01058X	PRESIDENT	0	PRESENT	0
123241	123237	11082Q	PARTICIPANT	\N	PRESENT	0
123321	123262	04034C	PARTICIPANT	\N	PRESENT	0
123882	123436	14231L	PARTICIPANT	\N	PRESENT	0
123883	123436	14187A	PARTICIPANT	\N	PRESENT	0
123884	123436	14041T	PARTICIPANT	\N	PRESENT	0
123885	123436	08019V	PARTICIPANT	\N	PRESENT	0
123886	123436	11034G	PARTICIPANT	\N	PRESENT	0
123887	123436	14235Q	PARTICIPANT	\N	PRESENT	0
123888	123436	11098Y	PARTICIPANT	\N	PRESENT	0
123889	123436	11104D	PARTICIPANT	\N	PRESENT	0
123890	123436	11066Q	PARTICIPANT	\N	PRESENT	0
123891	123436	11046L	PARTICIPANT	\N	PRESENT	0
123892	123436	14269B	PARTICIPANT	\N	PRESENT	0
123893	123436	13002U	PARTICIPANT	\N	PRESENT	0
123894	123436	04045F	PARTICIPANT	\N	PRESENT	0
123895	123436	11042G	PARTICIPANT	\N	PRESENT	0
123896	123436	11109J	PARTICIPANT	\N	PRESENT	0
123897	123436	11099A	PARTICIPANT	\N	PRESENT	0
123898	123436	14219Q	PARTICIPANT	\N	PRESENT	0
123899	123436	04089T	PARTICIPANT	\N	PRESENT	0
123900	123436	04038G	PARTICIPANT	\N	PRESENT	0
123901	123436	04043D	PARTICIPANT	\N	PRESENT	0
123902	123436	11100Y	PARTICIPANT	\N	PRESENT	0
123903	123436	11055M	PARTICIPANT	\N	PRESENT	0
123904	123436	14079W	PARTICIPANT	\N	PRESENT	0
123905	123436	04086Q	PARTICIPANT	\N	PRESENT	0
123906	123436	11077T	PARTICIPANT	\N	PRESENT	0
123907	123436	14197C	PARTICIPANT	\N	PRESENT	0
123908	123436	14215L	PARTICIPANT	\N	PRESENT	0
123909	123436	11011M	PARTICIPANT	\N	PRESENT	0
123910	123436	14207L	PARTICIPANT	\N	PRESENT	0
123911	123436	11103C	PARTICIPANT	\N	PRESENT	0
123912	123436	98053W	PARTICIPANT	\N	PRESENT	0
123913	123436	04085P	PARTICIPANT	\N	PRESENT	0
123914	123436	98050T	PARTICIPANT	\N	PRESENT	0
123915	123436	11090Q	PARTICIPANT	\N	PRESENT	0
123916	123436	01003G	PARTICIPANT	\N	PRESENT	0
123917	123436	14063N	PARTICIPANT	\N	PRESENT	0
123918	123436	08034U	PARTICIPANT	\N	PRESENT	0
123919	123436	14073Q	PARTICIPANT	\N	PRESENT	0
123920	123436	04059M	PARTICIPANT	\N	PRESENT	0
123921	123436	14157T	PARTICIPANT	\N	PRESENT	0
123922	123436	14195A	PARTICIPANT	\N	PRESENT	0
123923	123436	14217N	PARTICIPANT	\N	PRESENT	0
123924	123436	14229S	PARTICIPANT	\N	PRESENT	0
102067	102066	96004D	PRESIDENT	0	PRESENT	0
102068	102066	11040E	PARTICIPANT	\N	PRESENT	0
102069	102066	14089Y	PARTICIPANT	\N	EXCUSE	0
102070	102066	14079W	PARTICIPANT	\N	PRESENT	0
102071	102066	11035H	PARTICIPANT	\N	EXCUSE	0
102072	102066	14249W	PARTICIPANT	\N	EXCUSE	0
102073	102066	95030B	PARTICIPANT	\N	PRESENT	0
102074	102066	14026U	PARTICIPANT	\N	PRESENT	0
102075	102066	08044W	PARTICIPANT	\N	PRESENT	0
102076	102066	11026G	PARTICIPANT	\N	PRESENT	0
102077	102066	14097Y	PARTICIPANT	\N	PRESENT	0
102078	102066	95037J	PARTICIPANT	\N	PRESENT	0
102079	102066	98046X	PARTICIPANT	\N	PRESENT	0
102080	102066	14001X	PARTICIPANT	\N	PRESENT	0
102081	102066	08073C	PARTICIPANT	\N	PRESENT	0
102082	102066	04080J	PARTICIPANT	\N	PRESENT	0
102083	102066	01016M	PARTICIPANT	\N	PRESENT	0
102084	102066	10015M	PARTICIPANT	\N	PRESENT	0
102085	102066	98035U	PARTICIPANT	\N	PRESENT	0
102086	102066	04045F	PARTICIPANT	\N	PRESENT	0
102087	102066	92045V	PARTICIPANT	\N	PRESENT	0
102088	102066	04034C	PARTICIPANT	\N	PRESENT	0
102089	102066	04054G	PARTICIPANT	\N	PRESENT	0
102091	102090	96004D	PRESIDENT	0	PRESENT	0
102092	102090	11040E	PARTICIPANT	\N	PRESENT	0
102093	102090	95030B	PARTICIPANT	\N	PRESENT	0
102094	102090	08018U	PARTICIPANT	\N	PRESENT	0
102095	102090	11083R	PARTICIPANT	\N	PRESENT	0
102096	102090	14097Y	PARTICIPANT	\N	PRESENT	0
102097	102090	08044W	PARTICIPANT	\N	PRESENT	0
102098	102090	14001X	PARTICIPANT	\N	PRESENT	0
102099	102090	14135M	PARTICIPANT	\N	PRESENT	0
102100	102090	11012A	PARTICIPANT	\N	PRESENT	0
102101	102090	04045F	PARTICIPANT	\N	PRESENT	0
102102	102090	04080J	PARTICIPANT	\N	PRESENT	0
102103	102090	92045V	PARTICIPANT	\N	PRESENT	0
102104	102090	14089Y	PARTICIPANT	\N	EXCUSE	0
102105	102090	14249W	PARTICIPANT	\N	EXCUSE	0
102106	102090	11035H	PARTICIPANT	\N	EXCUSE	0
102107	102090	01008M	PARTICIPANT	\N	PRESENT	0
102108	102090	11036J	PARTICIPANT	\N	PRESENT	0
102109	102090	14207L	PARTICIPANT	\N	PRESENT	0
102110	102090	80013X	PARTICIPANT	\N	PRESENT	0
102111	102090	08038Y	PARTICIPANT	\N	PRESENT	0
102112	102090	04089T	PARTICIPANT	\N	PRESENT	0
102113	102090	14187A	PARTICIPANT	\N	PRESENT	0
102115	102090	08015R	PARTICIPANT	\N	PRESENT	0
102116	102090	11100Y	PARTICIPANT	\N	PRESENT	0
123881	123436	08055A	PARTICIPANT	\N	PRESENT	0
93298	93297	04047H	PARTICIPANT	\N	PRESENT	0
93300	93299	04047H	PARTICIPANT	\N	PRESENT	0
93302	93301	14261S	PARTICIPANT	\N	PRESENT	0
93303	93301	08055A	PARTICIPANT	\N	PRESENT	0
93304	93301	14093U	PARTICIPANT	\N	PRESENT	0
93305	93301	14030Q	PARTICIPANT	\N	PRESENT	0
93351	93350	01008M	PARTICIPANT	\N	PRESENT	0
93307	93301	08060W	PARTICIPANT	\N	PRESENT	0
93352	93350	11036J	PARTICIPANT	\N	PRESENT	0
93309	93301	14038Y	PARTICIPANT	\N	PRESENT	0
93353	93350	11081P	PARTICIPANT	\N	PRESENT	0
93354	93350	14013P	PARTICIPANT	\N	PRESENT	0
93312	93301	11065P	PARTICIPANT	\N	PRESENT	0
93313	93301	01015L	PARTICIPANT	\N	PRESENT	0
93314	93301	11107G	PARTICIPANT	\N	PRESENT	0
93392	93391	01008M	PARTICIPANT	\N	PRESENT	0
93356	93350	14207L	PARTICIPANT	\N	PRESENT	0
93317	93301	01022K	PARTICIPANT	\N	PRESENT	0
93393	93391	11036J	PARTICIPANT	\N	PRESENT	0
93319	93301	09001P	PARTICIPANT	\N	PRESENT	0
93358	93350	90003B	PARTICIPANT	\N	PRESENT	0
93359	93350	08028W	PARTICIPANT	\N	PRESENT	0
93322	93301	80027E	PARTICIPANT	\N	PRESENT	0
93323	93301	14031R	PARTICIPANT	\N	PRESENT	0
93324	93301	08009T	PRESIDENT	0	PRESENT	0
93325	93301	08062Y	PARTICIPANT	\N	PRESENT	0
93360	93350	80013X	PARTICIPANT	\N	PRESENT	0
93327	93301	92039X	PARTICIPANT	\N	PRESENT	0
93361	93350	08038Y	PARTICIPANT	\N	PRESENT	0
93362	93350	04089T	PARTICIPANT	\N	PRESENT	0
93330	93301	14237S	PARTICIPANT	\N	PRESENT	0
93363	93350	14197C	PARTICIPANT	\N	PRESENT	0
93332	93301	05012A	PARTICIPANT	\N	PRESENT	0
93364	93350	11110B	PARTICIPANT	\N	PRESENT	0
93334	93301	14135M	PARTICIPANT	\N	PRESENT	0
93335	93301	14331P	PARTICIPANT	\N	PRESENT	0
93336	93301	95062K	PARTICIPANT	\N	PRESENT	0
93337	93301	14107H	PARTICIPANT	\N	PRESENT	0
93338	93301	14051J	PARTICIPANT	\N	PRESENT	0
93339	93301	14157T	PARTICIPANT	\N	PRESENT	0
93340	93301	96003C	PARTICIPANT	\N	EXCUSE	0
93365	93350	14187A	PARTICIPANT	\N	PRESENT	0
93366	93350	14033T	PARTICIPANT	\N	PRESENT	0
93394	93391	11081P	PARTICIPANT	\N	PRESENT	0
93395	93391	14013P	PARTICIPANT	\N	PRESENT	0
93603	93391	14207L	PARTICIPANT	\N	PRESENT	0
93370	93350	04049K	PARTICIPANT	\N	PRESENT	0
93371	93350	04094Q	PARTICIPANT	\N	PRESENT	0
93372	93350	11111C	PARTICIPANT	\N	PRESENT	0
93373	93350	08015R	PARTICIPANT	\N	PRESENT	0
93374	93350	11100Y	PRESIDENT	0	PRESENT	0
93375	93350	01061S	PARTICIPANT	\N	EXCUSE	0
93376	93350	11098Y	PARTICIPANT	\N	PRESENT	0
93377	93350	01043Q	PARTICIPANT	\N	PRESENT	0
93378	93350	11077T	PARTICIPANT	\N	PRESENT	0
93379	93350	14205J	PARTICIPANT	\N	PRESENT	0
93380	93350	08019V	PARTICIPANT	\N	PRESENT	0
93381	93350	14257W	PARTICIPANT	\N	PRESENT	0
93604	93391	08038Y	PARTICIPANT	\N	PRESENT	0
93383	93350	04088S	PARTICIPANT	\N	PRESENT	0
93384	93350	98050T	PARTICIPANT	\N	PRESENT	0
93385	93350	11090Q	PARTICIPANT	\N	PRESENT	0
93386	93350	11046L	PARTICIPANT	\N	PRESENT	0
93387	93350	01058X	PARTICIPANT	\N	PRESENT	0
93388	93350	11094U	PARTICIPANT	\N	PRESENT	0
93389	93350	11066Q	PARTICIPANT	\N	PRESENT	0
93605	93391	14187A	PARTICIPANT	\N	PRESENT	0
93606	93391	04049K	PARTICIPANT	\N	PRESENT	0
93399	93391	90003B	PARTICIPANT	\N	PRESENT	0
93400	93391	08028W	PARTICIPANT	\N	PRESENT	0
93401	93391	80013X	PARTICIPANT	\N	PRESENT	0
93607	93391	01058X	PARTICIPANT	\N	PRESENT	0
93403	93391	04089T	PARTICIPANT	\N	PRESENT	0
93404	93391	14197C	PARTICIPANT	\N	PRESENT	0
93405	93391	11110B	PARTICIPANT	\N	PRESENT	0
94308	94307	01008M	PARTICIPANT	\N	PRESENT	0
93407	93391	14033T	PARTICIPANT	\N	PRESENT	0
94309	94307	14195A	PARTICIPANT	\N	PRESENT	0
94310	94307	14209N	PARTICIPANT	\N	PRESENT	0
94311	94307	14197C	PARTICIPANT	\N	PRESENT	0
94312	94307	11111C	PARTICIPANT	\N	PRESENT	0
93412	93391	04094Q	PARTICIPANT	\N	PRESENT	0
93413	93391	11111C	PARTICIPANT	\N	PRESENT	0
93414	93391	08015R	PARTICIPANT	\N	PRESENT	0
93415	93391	11100Y	PRESIDENT	0	PRESENT	0
93416	93391	01061S	PARTICIPANT	\N	EXCUSE	0
93417	93391	11098Y	PARTICIPANT	\N	PRESENT	0
93418	93391	01043Q	PARTICIPANT	\N	PRESENT	0
93419	93391	11077T	PARTICIPANT	\N	PRESENT	0
93420	93391	14205J	PARTICIPANT	\N	PRESENT	0
93421	93391	08019V	PARTICIPANT	\N	PRESENT	0
93422	93391	14257W	PARTICIPANT	\N	PRESENT	0
94313	94307	14219Q	PARTICIPANT	\N	PRESENT	0
93424	93391	04088S	PARTICIPANT	\N	PRESENT	0
93425	93391	98050T	PARTICIPANT	\N	PRESENT	0
93426	93391	11090Q	PARTICIPANT	\N	PRESENT	0
93427	93391	11046L	PARTICIPANT	\N	PRESENT	0
94314	94307	14063N	PARTICIPANT	\N	PRESENT	0
93429	93391	11094U	PARTICIPANT	\N	PRESENT	0
93430	93391	11066Q	PARTICIPANT	\N	PRESENT	0
94316	94315	01008M	PARTICIPANT	\N	PRESENT	0
94317	94315	04089T	PARTICIPANT	\N	PRESENT	0
94319	94315	11110B	PARTICIPANT	\N	PRESENT	0
94321	94315	14257W	PARTICIPANT	\N	PRESENT	0
94322	94315	11094U	PARTICIPANT	\N	PRESENT	0
94344	94343	11099A	PARTICIPANT	\N	PRESENT	0
94345	94343	11100Y	PARTICIPANT	\N	PRESENT	0
94398	94397	04086Q	PARTICIPANT	\N	PRESENT	0
94399	94397	01027Q	PARTICIPANT	\N	PRESENT	0
94400	94397	12042Y	PRESIDENT	0	PRESENT	0
94401	94397	11107G	PARTICIPANT	\N	PRESENT	0
94402	94397	14014Q	PARTICIPANT	\N	PRESENT	0
94403	94397	11112D	PARTICIPANT	\N	PRESENT	0
94404	94397	14205J	PARTICIPANT	\N	PRESENT	0
94405	94397	04067M	PARTICIPANT	\N	EXCUSE	0
94406	94397	11061K	PARTICIPANT	\N	EXCUSE	0
94407	94397	11097X	PARTICIPANT	\N	EXCUSE	0
94408	94397	04045F	PARTICIPANT	\N	EXCUSE	0
94410	94409	14071N	PARTICIPANT	\N	PRESENT	0
94411	94409	00003C	PARTICIPANT	\N	PRESENT	0
94416	94415	11043H	PARTICIPANT	\N	PRESENT	0
94417	94415	11039M	PARTICIPANT	\N	PRESENT	0
94418	94415	88008L	PARTICIPANT	\N	PRESENT	0
94419	94415	14073Q	PARTICIPANT	\N	PRESENT	0
94420	94415	14061L	PARTICIPANT	\N	PRESENT	0
94421	94415	14179A	PARTICIPANT	\N	PRESENT	0
94422	94415	83047W	PARTICIPANT	\N	PRESENT	0
94423	94415	14249W	PARTICIPANT	\N	PRESENT	0
94425	94424	08017T	PARTICIPANT	\N	PRESENT	0
94426	94424	01041N	PARTICIPANT	\N	PRESENT	0
94427	94424	11091R	PARTICIPANT	\N	PRESENT	0
96724	96233	11039M	PARTICIPANT	\N	PRESENT	0
96725	96233	14253S	PARTICIPANT	\N	PRESENT	0
96726	96233	01003G	PARTICIPANT	\N	PRESENT	0
96727	96233	88008L	PARTICIPANT	\N	PRESENT	0
96728	96233	04078Q	PARTICIPANT	\N	PRESENT	0
96729	96233	08031R	PARTICIPANT	\N	PRESENT	0
96730	96233	01046T	PARTICIPANT	\N	PRESENT	0
96731	96233	14018U	PARTICIPANT	\N	PRESENT	0
96732	96233	11096W	PARTICIPANT	\N	PRESENT	0
96733	96233	04038G	PARTICIPANT	\N	PRESENT	0
96734	96233	14241N	PARTICIPANT	\N	PRESENT	0
96735	96233	04042C	PARTICIPANT	\N	PRESENT	0
96736	96233	04097T	PARTICIPANT	\N	PRESENT	0
96737	96233	08022Q	PARTICIPANT	\N	PRESENT	0
96738	96233	04044E	PARTICIPANT	\N	PRESENT	0
96739	96233	01007L	PARTICIPANT	\N	PRESENT	0
96740	96233	14327T	PARTICIPANT	\N	PRESENT	0
96741	96233	01025N	PARTICIPANT	\N	PRESENT	0
96742	96233	14071N	PARTICIPANT	\N	PRESENT	0
96743	96233	11064N	PARTICIPANT	\N	PRESENT	0
96744	96233	95041E	PARTICIPANT	\N	PRESENT	0
96745	96233	09001P	PARTICIPANT	\N	PRESENT	0
96746	96233	11053K	PARTICIPANT	\N	PRESENT	0
96747	96233	04080J	PARTICIPANT	\N	PRESENT	0
96748	96233	95067Q	PARTICIPANT	\N	PRESENT	0
96749	96233	14205J	PARTICIPANT	\N	PRESENT	0
96750	96233	11070L	PARTICIPANT	\N	PRESENT	0
96751	96233	08010L	PARTICIPANT	\N	PRESENT	0
96752	96233	98042T	PARTICIPANT	\N	PRESENT	0
96753	96233	14042U	PARTICIPANT	\N	PRESENT	0
96754	96233	05008E	PARTICIPANT	\N	PRESENT	0
96755	96233	92031P	PARTICIPANT	\N	PRESENT	0
96756	96233	04086Q	PARTICIPANT	\N	PRESENT	0
96757	96233	14065Q	PARTICIPANT	\N	PRESENT	0
96758	96233	04033B	PARTICIPANT	\N	PRESENT	0
96759	96233	04067M	PARTICIPANT	\N	PRESENT	0
96760	96233	04035D	PARTICIPANT	\N	PRESENT	0
96761	96233	14103D	PARTICIPANT	\N	PRESENT	0
99660	99659	04040A	PARTICIPANT	\N	PRESENT	0
99661	99659	14097Y	PARTICIPANT	\N	PRESENT	0
99662	99659	08058D	PARTICIPANT	\N	PRESENT	0
99667	99666	04040A	PARTICIPANT	\N	PRESENT	0
99668	99666	14097Y	PARTICIPANT	\N	PRESENT	0
99669	99666	08058D	PARTICIPANT	\N	PRESENT	0
99670	99666	95035G	PARTICIPANT	\N	PRESENT	0
99677	99675	07024N	PARTICIPANT	\N	PRESENT	0
99692	99675	01014K	PARTICIPANT	\N	PRESENT	0
104893	104892	05008E	PRESIDENT	0	PRESENT	0
104894	104892	04047H	PARTICIPANT	\N	PRESENT	0
104895	104892	11035H	PARTICIPANT	\N	PRESENT	0
104896	104892	14041T	PARTICIPANT	\N	EXCUSE	0
104897	104892	01024M	PARTICIPANT	\N	PRESENT	0
104898	104892	11026G	PARTICIPANT	\N	PRESENT	0
104899	104892	95049N	PARTICIPANT	\N	PRESENT	0
104900	104892	07034Q	PARTICIPANT	\N	PRESENT	0
104901	104892	01028R	PARTICIPANT	\N	PRESENT	0
104902	104892	04056J	PARTICIPANT	\N	PRESENT	0
104903	104892	11037K	PARTICIPANT	\N	PRESENT	0
104904	104892	95067Q	PARTICIPANT	\N	PRESENT	0
104905	104892	01031L	PARTICIPANT	\N	PRESENT	0
104906	104892	08010L	PARTICIPANT	\N	PRESENT	0
104907	104892	11042G	PARTICIPANT	\N	PRESENT	0
104908	104892	14083S	PARTICIPANT	\N	PRESENT	0
104909	104892	04071H	PARTICIPANT	\N	PRESENT	0
104910	104892	08061X	PARTICIPANT	\N	PRESENT	0
104911	104892	01027Q	PARTICIPANT	\N	PRESENT	0
104912	104892	89017R	PARTICIPANT	\N	PRESENT	0
104913	104892	08011M	PARTICIPANT	\N	PRESENT	0
104914	104892	07029T	PARTICIPANT	\N	PRESENT	0
104915	104892	01016M	PARTICIPANT	\N	PRESENT	0
104916	104892	14225N	PARTICIPANT	\N	PRESENT	0
104917	104892	11074Q	PARTICIPANT	\N	PRESENT	0
104918	104892	11083R	PARTICIPANT	\N	PRESENT	0
104919	104892	11053K	PARTICIPANT	\N	PRESENT	0
104920	104892	01057W	PARTICIPANT	\N	PRESENT	0
104921	104892	14085U	PARTICIPANT	\N	PRESENT	0
104922	104892	04086Q	PARTICIPANT	\N	PRESENT	0
104933	104932	89017R	PARTICIPANT	\N	PRESENT	0
104934	104932	01031L	PRESIDENT	0	PRESENT	0
104935	104932	14083S	PARTICIPANT	\N	PRESENT	0
104936	104932	11053K	PARTICIPANT	\N	PRESENT	0
104937	104932	14085U	PARTICIPANT	\N	PRESENT	0
104938	104932	11042G	PARTICIPANT	\N	PRESENT	0
104939	104932	04086Q	PARTICIPANT	\N	PRESENT	0
104940	104932	08022Q	PARTICIPANT	\N	PRESENT	0
104941	104932	01027Q	PARTICIPANT	\N	PRESENT	0
104942	104932	04071H	PARTICIPANT	\N	PRESENT	0
104943	104932	11074Q	PARTICIPANT	\N	PRESENT	0
104944	104932	11083R	PARTICIPANT	\N	PRESENT	0
104945	104932	98053W	PARTICIPANT	\N	EXCUSE	0
104946	104932	01057W	PARTICIPANT	\N	PRESENT	0
104947	104932	08069G	PARTICIPANT	\N	PRESENT	0
104948	104932	07029T	PARTICIPANT	\N	PRESENT	0
104949	104932	08010L	PARTICIPANT	\N	PRESENT	0
104950	104932	08011M	PARTICIPANT	\N	PRESENT	0
104951	104932	08061X	PARTICIPANT	\N	PRESENT	0
104952	104932	01016M	PARTICIPANT	\N	PRESENT	0
104953	104932	14225N	PARTICIPANT	\N	PRESENT	0
104954	104932	05008E	PARTICIPANT	\N	PRESENT	0
104955	104932	14065Q	PARTICIPANT	\N	PRESENT	0
104956	104932	04047H	PARTICIPANT	\N	PRESENT	0
104957	104932	11035H	PARTICIPANT	\N	PRESENT	0
104958	104932	01024M	PARTICIPANT	\N	PRESENT	0
104959	104932	11026G	PARTICIPANT	\N	PRESENT	0
104960	104932	95049N	PARTICIPANT	\N	PRESENT	0
104961	104932	07034Q	PARTICIPANT	\N	PRESENT	0
104962	104932	01028R	PARTICIPANT	\N	PRESENT	0
104963	104932	04056J	PARTICIPANT	\N	PRESENT	0
104964	104932	11037K	PARTICIPANT	\N	PRESENT	0
104965	104932	95067Q	PARTICIPANT	\N	PRESENT	0
112052	112032	08024S	PARTICIPANT	\N	PRESENT	0
112053	112032	14331P	PARTICIPANT	\N	PRESENT	0
112054	112032	04042C	PARTICIPANT	\N	PRESENT	0
112055	112032	11027H	PARTICIPANT	\N	PRESENT	0
112056	112032	14030Q	PARTICIPANT	\N	PRESENT	0
112057	112032	01014K	PARTICIPANT	\N	PRESENT	0
112058	112032	14273W	PARTICIPANT	\N	PRESENT	0
112059	112032	14071N	PARTICIPANT	\N	PRESENT	0
112060	112032	01003G	PARTICIPANT	\N	PRESENT	0
112062	112032	80013X	PARTICIPANT	\N	PRESENT	0
112121	112032	11098Y	PARTICIPANT	\N	PRESENT	0
112221	112032	11111C	PARTICIPANT	\N	PRESENT	0
112252	112032	14275Y	PARTICIPANT	\N	PRESENT	0
112253	112032	14259Y	PARTICIPANT	\N	PRESENT	0
112254	112033	08024S	PARTICIPANT	\N	PRESENT	0
112255	112033	14275Y	PARTICIPANT	\N	PRESENT	0
112256	112033	14259Y	PARTICIPANT	\N	PRESENT	0
112257	112033	14273W	PARTICIPANT	\N	PRESENT	0
112258	112033	11012A	PARTICIPANT	\N	PRESENT	0
112259	112033	08019V	PARTICIPANT	\N	PRESENT	0
112260	112033	01028R	PARTICIPANT	\N	PRESENT	0
112261	112033	11055M	PARTICIPANT	\N	PRESENT	0
112262	112033	11091R	PARTICIPANT	\N	PRESENT	0
112263	112033	11111C	PARTICIPANT	\N	PRESENT	0
112264	112033	11082Q	PARTICIPANT	\N	PRESENT	0
112265	112033	04080J	PARTICIPANT	\N	PRESENT	0
112266	112033	14197C	PARTICIPANT	\N	PRESENT	0
112274	112033	14039A	PARTICIPANT	\N	PRESENT	0
112282	112033	11040E	PARTICIPANT	\N	PRESENT	0
112288	112033	14030Q	PARTICIPANT	\N	PRESENT	0
112289	112033	14042U	PARTICIPANT	\N	PRESENT	0
112290	112033	11098Y	PARTICIPANT	\N	PRESENT	0
112291	112033	11067R	PARTICIPANT	\N	PRESENT	0
112292	112033	04043D	PARTICIPANT	\N	PRESENT	0
112293	112033	04067M	PARTICIPANT	\N	PRESENT	0
112312	112033	04085P	PARTICIPANT	\N	PRESENT	0
112332	112033	04048J	PARTICIPANT	\N	PRESENT	0
112416	112035	04081K	PARTICIPANT	\N	PRESENT	0
112451	112035	11010L	PARTICIPANT	\N	PRESENT	0
112452	112035	11071M	PARTICIPANT	\N	PRESENT	0
112453	112035	11100Y	PARTICIPANT	\N	PRESENT	0
112455	112035	11111C	PARTICIPANT	\N	PRESENT	0
112456	112035	14257W	PARTICIPANT	\N	PRESENT	0
112457	112035	14207L	PARTICIPANT	\N	PRESENT	0
112458	112035	08014Q	PARTICIPANT	\N	PRESENT	0
112459	112035	08043V	PARTICIPANT	\N	PRESENT	0
112460	112035	11098Y	PARTICIPANT	\N	PRESENT	0
112461	112035	11035H	PARTICIPANT	\N	PRESENT	0
112462	112035	11099A	PARTICIPANT	\N	PRESENT	0
112463	112035	11113E	PARTICIPANT	\N	PRESENT	0
112464	112035	14237S	PARTICIPANT	\N	PRESENT	0
112466	112035	14269B	PARTICIPANT	\N	PRESENT	0
112472	112035	14195A	PARTICIPANT	\N	PRESENT	0
112473	112035	11091R	PARTICIPANT	\N	PRESENT	0
112475	112035	11036J	PARTICIPANT	\N	PRESENT	0
112493	112035	88008L	PARTICIPANT	\N	PRESENT	0
112512	112035	04080J	PARTICIPANT	\N	PRESENT	0
112513	112035	11083R	PARTICIPANT	\N	PRESENT	0
112514	112035	14259Y	PARTICIPANT	\N	PRESENT	0
112518	112035	98050T	PARTICIPANT	\N	PRESENT	0
112519	112035	11072N	PARTICIPANT	\N	PRESENT	0
112533	103118	14265W	PARTICIPANT	\N	PRESENT	0
112534	103118	14083S	PARTICIPANT	\N	PRESENT	0
112535	103118	14061L	PARTICIPANT	\N	PRESENT	0
112536	103118	14157T	PARTICIPANT	\N	PRESENT	0
112537	112035	08019V	PARTICIPANT	\N	PRESENT	0
112538	103119	14083S	PARTICIPANT	\N	PRESENT	0
112539	103119	14265W	PARTICIPANT	\N	PRESENT	0
112540	103119	14157T	PARTICIPANT	\N	PRESENT	0
112541	103119	14061L	PARTICIPANT	\N	PRESENT	0
112542	103119	04049K	PARTICIPANT	\N	PRESENT	0
112543	103120	14083S	PARTICIPANT	\N	PRESENT	0
112544	103120	14265W	PARTICIPANT	\N	PRESENT	0
112545	103120	14157T	PARTICIPANT	\N	PRESENT	0
112546	103120	14061L	PARTICIPANT	\N	PRESENT	0
112547	103120	04049K	PARTICIPANT	\N	PRESENT	0
112548	103121	14083S	PARTICIPANT	\N	PRESENT	0
112549	103121	14265W	PARTICIPANT	\N	PRESENT	0
112550	103121	14157T	PARTICIPANT	\N	PRESENT	0
112551	103121	14061L	PARTICIPANT	\N	PRESENT	0
112552	103121	04049K	PARTICIPANT	\N	PRESENT	0
112566	112035	11055M	PARTICIPANT	\N	PRESENT	0
112572	112036	01028R	PARTICIPANT	\N	PRESENT	0
112573	112036	04081K	PARTICIPANT	\N	PRESENT	0
112574	112036	11113E	PARTICIPANT	\N	PRESENT	0
112575	112036	08019V	PARTICIPANT	\N	PRESENT	0
112576	112036	11091R	PARTICIPANT	\N	PRESENT	0
112577	112036	11035H	PARTICIPANT	\N	PRESENT	0
112578	112036	14207L	PARTICIPANT	\N	PRESENT	0
112579	112036	14275Y	PARTICIPANT	\N	PRESENT	0
112612	112036	11071M	PARTICIPANT	\N	PRESENT	0
112581	112036	14259Y	PARTICIPANT	\N	PRESENT	0
112582	112036	11064N	PARTICIPANT	\N	PRESENT	0
112592	112036	11055M	PARTICIPANT	\N	PRESENT	0
112593	112036	11072N	PARTICIPANT	\N	PRESENT	0
112594	112036	04085P	PARTICIPANT	\N	PRESENT	0
112595	112036	11100Y	PARTICIPANT	\N	PRESENT	0
94551	94550	98046X	PARTICIPANT	\N	PRESENT	0
94553	94552	98046X	PARTICIPANT	\N	PRESENT	0
94555	94554	98046X	PARTICIPANT	\N	PRESENT	0
94557	94556	98046X	PARTICIPANT	\N	PRESENT	0
94559	94558	98046X	PARTICIPANT	\N	PRESENT	0
94561	94560	98046X	PARTICIPANT	\N	PRESENT	0
118954	118952	01015L	PARTICIPANT	\N	PRESENT	0
118955	118952	14219Q	PARTICIPANT	\N	PRESENT	0
118957	118956	14093U	PARTICIPANT	\N	EXCUSE	0
118958	118956	14030Q	PARTICIPANT	\N	PRESENT	0
118959	118956	01044R	PARTICIPANT	\N	PRESENT	0
118960	118956	80013X	PARTICIPANT	\N	EXCUSE	0
118961	118956	01015L	PARTICIPANT	\N	PRESENT	0
118962	118956	14197C	PARTICIPANT	\N	EXCUSE	0
118963	118956	14219Q	PARTICIPANT	\N	PRESENT	0
118964	118956	14031R	PARTICIPANT	\N	EXCUSE	0
118965	118956	04057K	PARTICIPANT	\N	EXCUSE	0
118966	118956	92039X	PARTICIPANT	\N	EXCUSE	0
118967	118956	14265W	PARTICIPANT	\N	EXCUSE	0
118968	118956	04043D	PARTICIPANT	\N	PRESENT	0
118969	118956	08049C	PARTICIPANT	\N	EXCUSE	0
118970	118956	05012A	PARTICIPANT	\N	EXCUSE	0
118971	118952	04043D	PARTICIPANT	\N	PRESENT	0
118973	118972	14147R	PARTICIPANT	\N	PRESENT	0
118992	118940	01048V	PARTICIPANT	\N	PRESENT	0
118976	118974	14147R	PARTICIPANT	\N	PRESENT	0
118978	118977	04047H	PARTICIPANT	\N	PRESENT	0
119070	119012	04040A	PARTICIPANT	\N	PRESENT	0
119071	119012	04042C	PARTICIPANT	\N	PRESENT	0
119072	119012	11082Q	PARTICIPANT	\N	PRESENT	0
119213	119212	14327T	PARTICIPANT	\N	PRESENT	0
119217	119215	14327T	PARTICIPANT	\N	PRESENT	0
119219	119218	14327T	PARTICIPANT	\N	PRESENT	0
119223	119222	14327T	PARTICIPANT	\N	PRESENT	0
119225	119224	01044R	PARTICIPANT	\N	PRESENT	0
119021	119012	11027H	PARTICIPANT	\N	EXCUSE	0
119226	119224	11029K	PARTICIPANT	\N	PRESENT	0
119227	119224	01015L	PARTICIPANT	\N	PRESENT	0
119024	119012	92020L	PARTICIPANT	\N	EXCUSE	0
119228	119224	11036J	PARTICIPANT	\N	EXCUSE	0
119257	119255	14093U	PARTICIPANT	\N	PRESENT	0
119230	119224	14030Q	PARTICIPANT	\N	EXCUSE	0
119251	119224	14219Q	PARTICIPANT	\N	EXCUSE	0
119029	119012	08065C	PARTICIPANT	\N	EXCUSE	0
119232	119224	14038Y	PARTICIPANT	\N	EXCUSE	0
119031	119012	07024N	PARTICIPANT	\N	PRESENT	0
119233	119224	80013X	PARTICIPANT	\N	EXCUSE	0
119033	119012	14014Q	PARTICIPANT	\N	EXCUSE	0
119234	119224	14197C	PARTICIPANT	\N	EXCUSE	0
119035	119012	07004J	PARTICIPANT	\N	EXCUSE	0
119256	119255	11036J	PARTICIPANT	\N	EXCUSE	0
119037	119012	08056B	PARTICIPANT	\N	EXCUSE	0
119038	119012	14211G	PARTICIPANT	\N	PRESENT	0
119258	119255	14030Q	PARTICIPANT	\N	EXCUSE	0
119237	119224	14031R	PARTICIPANT	\N	EXCUSE	0
119238	119224	14273W	PARTICIPANT	\N	EXCUSE	0
119259	119255	01044R	PARTICIPANT	\N	PRESENT	0
119240	119224	04057K	PARTICIPANT	\N	EXCUSE	0
119044	119012	95041E	PARTICIPANT	\N	EXCUSE	0
119260	119255	14038Y	PARTICIPANT	\N	EXCUSE	0
119242	119224	14265W	PARTICIPANT	\N	EXCUSE	0
119243	119224	14237S	PARTICIPANT	\N	EXCUSE	0
119244	119224	05012A	PARTICIPANT	\N	EXCUSE	0
119049	119012	92031P	PARTICIPANT	\N	EXCUSE	0
119245	119224	04043D	PARTICIPANT	\N	EXCUSE	0
119246	119224	01016M	PARTICIPANT	\N	EXCUSE	0
119052	119012	83042R	PARTICIPANT	\N	EXCUSE	0
119247	119224	14107H	PARTICIPANT	\N	EXCUSE	0
119261	119255	80013X	PARTICIPANT	\N	EXCUSE	0
119249	119224	01056V	PARTICIPANT	\N	EXCUSE	0
119056	119012	14253S	PARTICIPANT	\N	EXCUSE	0
119057	119012	08047A	PARTICIPANT	\N	EXCUSE	0
119250	119224	08049C	PARTICIPANT	\N	EXCUSE	0
119262	119255	04057K	PARTICIPANT	\N	EXCUSE	0
119263	119255	92039X	PARTICIPANT	\N	EXCUSE	0
119264	119255	14237S	PARTICIPANT	\N	PRESENT	0
119062	119012	95059Q	PRESIDENT	0	PRESENT	0
119265	119255	01056V	PARTICIPANT	\N	EXCUSE	0
119064	119012	01014K	PARTICIPANT	\N	EXCUSE	0
119293	119292	11055M	PARTICIPANT	\N	PRESENT	0
119269	119268	14231L	PARTICIPANT	\N	PRESENT	0
119270	119268	14157T	PARTICIPANT	\N	PRESENT	0
119068	119012	08049C	PARTICIPANT	\N	EXCUSE	0
119271	119266	14231L	PARTICIPANT	\N	PRESENT	0
119273	119272	14231L	PARTICIPANT	\N	PRESENT	0
119275	119274	14231L	PARTICIPANT	\N	PRESENT	0
119330	119329	04086Q	PARTICIPANT	\N	PRESENT	0
119295	119292	14053L	PARTICIPANT	\N	PRESENT	0
119296	119292	95015C	PARTICIPANT	\N	PRESENT	0
119332	119331	14030Q	PARTICIPANT	\N	EXCUSE	0
119298	119292	11027H	PARTICIPANT	\N	PRESENT	0
119333	119331	14038Y	PARTICIPANT	\N	EXCUSE	0
119300	119292	14079W	PARTICIPANT	\N	PRESENT	0
119335	119331	80013X	PARTICIPANT	\N	EXCUSE	0
119302	119292	14215L	PARTICIPANT	\N	PRESENT	0
119303	119292	04089T	PARTICIPANT	\N	PRESENT	0
119304	119292	14187A	PARTICIPANT	\N	PRESENT	0
119305	119292	11034G	PARTICIPANT	\N	PRESENT	0
119336	119334	04086Q	PARTICIPANT	\N	PRESENT	0
119307	119292	14231L	PARTICIPANT	\N	PRESENT	0
119337	119331	14041T	PARTICIPANT	\N	EXCUSE	0
119309	119292	14213J	PARTICIPANT	\N	PRESENT	0
119310	119292	08031R	PARTICIPANT	\N	PRESENT	0
119311	119292	11100Y	PRESIDENT	0	PRESENT	0
119312	119292	11077T	PARTICIPANT	\N	PRESENT	0
119338	119331	12042Y	PARTICIPANT	\N	PRESENT	0
119314	119292	11104D	PARTICIPANT	\N	PRESENT	0
119339	119331	07026Q	PARTICIPANT	\N	EXCUSE	0
119316	119292	07032N	PARTICIPANT	\N	PRESENT	0
119340	119331	95035G	PARTICIPANT	\N	EXCUSE	0
119318	119292	11090Q	PARTICIPANT	\N	PRESENT	0
119319	119292	14235Q	PARTICIPANT	\N	PRESENT	0
119320	119292	95063L	PARTICIPANT	\N	PRESENT	0
119341	119331	09001P	PRESIDENT	0	PRESENT	0
119322	119292	01028R	PARTICIPANT	\N	PRESENT	0
119323	119292	11094U	PARTICIPANT	\N	PRESENT	0
119324	119292	11037K	PARTICIPANT	\N	PRESENT	0
119325	119292	14157T	PARTICIPANT	\N	PRESENT	0
119326	119292	92045V	PARTICIPANT	\N	EXCUSE	0
119327	119292	11066Q	PARTICIPANT	\N	PRESENT	0
119328	119292	14269B	PARTICIPANT	\N	PRESENT	0
119342	119331	04036E	PARTICIPANT	\N	PRESENT	0
119343	119331	07029T	PARTICIPANT	\N	EXCUSE	0
119344	119331	08017T	PARTICIPANT	\N	EXCUSE	0
119345	119331	14265W	PARTICIPANT	\N	EXCUSE	0
119347	119331	14237S	PARTICIPANT	\N	EXCUSE	0
119348	119346	04086Q	PARTICIPANT	\N	PRESENT	0
119350	119331	11014C	PARTICIPANT	\N	EXCUSE	0
119351	119349	04086Q	PARTICIPANT	\N	PRESENT	0
119353	119352	04086Q	PARTICIPANT	\N	PRESENT	0
119355	119354	04086Q	PARTICIPANT	\N	PRESENT	0
119357	119356	04086Q	PARTICIPANT	\N	PRESENT	0
119373	119372	11055M	PARTICIPANT	\N	PRESENT	0
119375	119372	14053L	PARTICIPANT	\N	PRESENT	0
119376	119372	95015C	PARTICIPANT	\N	PRESENT	0
119378	119372	11027H	PARTICIPANT	\N	PRESENT	0
119380	119372	14079W	PARTICIPANT	\N	PRESENT	0
119413	119409	95015C	PARTICIPANT	\N	PRESENT	0
119382	119372	14215L	PARTICIPANT	\N	PRESENT	0
119383	119372	04089T	PARTICIPANT	\N	PRESENT	0
119384	119372	14187A	PARTICIPANT	\N	PRESENT	0
119385	119372	11034G	PARTICIPANT	\N	PRESENT	0
119387	119372	14231L	PARTICIPANT	\N	PRESENT	0
119388	119372	14179A	PARTICIPANT	\N	PRESENT	0
119389	119372	14213J	PARTICIPANT	\N	PRESENT	0
119390	119372	08031R	PARTICIPANT	\N	PRESENT	0
119391	119372	11100Y	PRESIDENT	0	PRESENT	0
119415	119409	11027H	PARTICIPANT	\N	PRESENT	0
119394	119372	11104D	PARTICIPANT	\N	PRESENT	0
119417	119409	14079W	PARTICIPANT	\N	PRESENT	0
119396	119372	07032N	PARTICIPANT	\N	PRESENT	0
119398	119372	11090Q	PARTICIPANT	\N	PRESENT	0
119399	119372	14235Q	PARTICIPANT	\N	PRESENT	0
119400	119372	95063L	PARTICIPANT	\N	PRESENT	0
119419	119409	14215L	PARTICIPANT	\N	PRESENT	0
119402	119372	01028R	PARTICIPANT	\N	PRESENT	0
119403	119372	11094U	PARTICIPANT	\N	PRESENT	0
119404	119372	11037K	PARTICIPANT	\N	PRESENT	0
119405	119372	14157T	PARTICIPANT	\N	PRESENT	0
119406	119372	92045V	PARTICIPANT	\N	EXCUSE	0
119407	119372	11066Q	PARTICIPANT	\N	PRESENT	0
119408	119372	14269B	PARTICIPANT	\N	PRESENT	0
119420	119409	04089T	PARTICIPANT	\N	PRESENT	0
119421	119409	14187A	PARTICIPANT	\N	PRESENT	0
100230	100160	89029V	PARTICIPANT	\N	PRESENT	0
100232	100160	01058X	PARTICIPANT	\N	PRESENT	0
100233	100160	97011G	PARTICIPANT	\N	PRESENT	0
100234	100160	14107H	PARTICIPANT	\N	PRESENT	0
100235	100160	08016S	PARTICIPANT	\N	PRESENT	0
100236	100160	14071N	PARTICIPANT	\N	PRESENT	0
100237	100160	14263U	PARTICIPANT	\N	PRESENT	0
100238	100160	11039M	PARTICIPANT	\N	PRESENT	0
100239	100160	11014C	PARTICIPANT	\N	PRESENT	0
100240	100160	14195A	PARTICIPANT	\N	PRESENT	0
100241	100160	11043H	PARTICIPANT	\N	PRESENT	0
100242	100160	08010L	PARTICIPANT	\N	PRESENT	0
100243	100160	14227Q	PARTICIPANT	\N	PRESENT	0
100244	100160	11040E	PARTICIPANT	\N	PRESENT	0
100245	100160	11053K	PARTICIPANT	\N	PRESENT	0
100246	100160	14179A	PARTICIPANT	\N	PRESENT	0
100247	100160	14267Y	PARTICIPANT	\N	PRESENT	0
100263	100160	14219Q	PARTICIPANT	\N	PRESENT	0
100264	100160	01060R	PARTICIPANT	\N	PRESENT	0
100265	100160	14265W	PARTICIPANT	\N	PRESENT	0
100266	100160	14034U	PARTICIPANT	\N	PRESENT	0
100270	100160	14105F	PARTICIPANT	\N	PRESENT	0
100271	100160	08051V	PARTICIPANT	\N	PRESENT	0
100279	100160	11054L	PARTICIPANT	\N	PRESENT	0
100280	100160	08073C	PARTICIPANT	\N	PRESENT	0
100281	100160	98035U	PARTICIPANT	\N	PRESENT	0
100282	100160	14089Y	PARTICIPANT	\N	PRESENT	0
100283	100160	11027H	PARTICIPANT	\N	PRESENT	0
100292	100161	86034E	PARTICIPANT	\N	PRESENT	0
100293	100161	08055A	PARTICIPANT	\N	PRESENT	0
100294	100161	11100Y	PARTICIPANT	\N	PRESENT	0
100295	100161	04042C	PARTICIPANT	\N	PRESENT	0
100296	100161	04092N	PARTICIPANT	\N	PRESENT	0
100297	100161	04070G	PARTICIPANT	\N	PRESENT	0
100298	100161	08009T	PARTICIPANT	\N	PRESENT	0
100299	100161	01031L	PARTICIPANT	\N	PRESENT	0
100300	100161	05008E	PARTICIPANT	\N	PRESENT	0
100301	100161	96004D	PARTICIPANT	\N	PRESENT	0
100302	100161	14215L	PARTICIPANT	\N	PRESENT	0
100303	100161	14265W	PARTICIPANT	\N	PRESENT	0
100304	100161	14187A	PARTICIPANT	\N	PRESENT	0
100305	100161	04097T	PARTICIPANT	\N	PRESENT	0
100306	100161	92031P	PARTICIPANT	\N	PRESENT	0
100307	100161	14033T	PARTICIPANT	\N	PRESENT	0
100308	100161	95030B	PARTICIPANT	\N	PRESENT	0
100309	100161	14013P	PARTICIPANT	\N	PRESENT	0
100310	100161	11097X	PARTICIPANT	\N	PRESENT	0
100311	100161	11012A	PARTICIPANT	\N	PRESENT	0
100312	100161	14028W	PARTICIPANT	\N	PRESENT	0
100313	100161	80013X	PARTICIPANT	\N	PRESENT	0
100314	100161	01028R	PARTICIPANT	\N	PRESENT	0
100315	100161	14213J	PARTICIPANT	\N	PRESENT	0
100316	100161	11040E	PARTICIPANT	\N	PRESENT	0
100317	100161	14157T	PARTICIPANT	\N	PRESENT	0
100318	100161	14219Q	PARTICIPANT	\N	PRESENT	0
100319	100161	11066Q	PARTICIPANT	\N	PRESENT	0
100320	100161	11036J	PARTICIPANT	\N	PRESENT	0
100321	100161	08060W	PARTICIPANT	\N	PRESENT	0
100322	100161	14227Q	PARTICIPANT	\N	PRESENT	0
100323	100161	11037K	PARTICIPANT	\N	PRESENT	0
100324	100161	95063L	PARTICIPANT	\N	PRESENT	0
100325	100161	14083S	PARTICIPANT	\N	PRESENT	0
100326	100161	01044R	PARTICIPANT	\N	PRESENT	0
100327	100161	11034G	PARTICIPANT	\N	PRESENT	0
100328	100161	88008L	PARTICIPANT	\N	PRESENT	0
100329	100161	97011G	PARTICIPANT	\N	PRESENT	0
100330	100161	14147R	PARTICIPANT	\N	PRESENT	0
100331	100161	01013J	PARTICIPANT	\N	PRESENT	0
100332	100161	04086Q	PARTICIPANT	\N	PRESENT	0
100333	100161	14235Q	PARTICIPANT	\N	PRESENT	0
100334	100161	14179A	PARTICIPANT	\N	PRESENT	0
100335	100161	95031C	PARTICIPANT	\N	PRESENT	0
100336	100161	14135M	PARTICIPANT	\N	PRESENT	0
100337	100161	14263U	PARTICIPANT	\N	PRESENT	0
100338	100161	14119M	PARTICIPANT	\N	PRESENT	0
100339	100161	01027Q	PARTICIPANT	\N	PRESENT	0
100340	100161	14063N	PARTICIPANT	\N	PRESENT	0
100403	100162	11098Y	PARTICIPANT	\N	PRESENT	0
100404	100162	14013P	PARTICIPANT	\N	PRESENT	0
100405	100162	80013X	PARTICIPANT	\N	PRESENT	0
100406	100162	11089X	PARTICIPANT	\N	PRESENT	0
100407	100162	14257W	PARTICIPANT	\N	PRESENT	0
100408	100162	08060W	PARTICIPANT	\N	PRESENT	0
100409	100162	14051J	PARTICIPANT	\N	PRESENT	0
100410	100162	11036J	PARTICIPANT	\N	PRESENT	0
100412	100162	14107H	PARTICIPANT	\N	PRESENT	0
100414	100162	14109K	PARTICIPANT	\N	PRESENT	0
100416	100162	11107G	PARTICIPANT	\N	PRESENT	0
100417	100162	13002U	PARTICIPANT	\N	PRESENT	0
100418	100162	11065P	PARTICIPANT	\N	PRESENT	0
100419	100162	14201E	PARTICIPANT	\N	PRESENT	0
100420	100162	14030Q	PARTICIPANT	\N	PRESENT	0
100421	100162	14219Q	PARTICIPANT	\N	PRESENT	0
100422	100162	08009T	PARTICIPANT	\N	PRESENT	0
100423	100162	14073Q	PARTICIPANT	\N	PRESENT	0
100424	100162	04088S	PARTICIPANT	\N	PRESENT	0
100425	100162	14033T	PARTICIPANT	\N	PRESENT	0
100426	100162	07032N	PARTICIPANT	\N	PRESENT	0
100427	100162	08062Y	PARTICIPANT	\N	PRESENT	0
100428	100162	08015R	PARTICIPANT	\N	PRESENT	0
100429	100162	14265W	PARTICIPANT	\N	PRESENT	0
100430	100162	11100Y	PARTICIPANT	\N	PRESENT	0
100431	100162	98050T	PARTICIPANT	\N	PRESENT	0
100432	100162	01008M	PARTICIPANT	\N	PRESENT	0
100433	100162	14042U	PARTICIPANT	\N	PRESENT	0
100434	100162	14331P	PARTICIPANT	\N	PRESENT	0
100435	100162	14273W	PARTICIPANT	\N	PRESENT	0
100436	100162	01048V	PARTICIPANT	\N	PRESENT	0
100437	100162	90003B	PARTICIPANT	\N	PRESENT	0
100438	100162	14083S	PARTICIPANT	\N	PRESENT	0
100439	100162	11048N	PARTICIPANT	\N	PRESENT	0
100440	100162	11012A	PARTICIPANT	\N	PRESENT	0
100441	100162	14241N	PARTICIPANT	\N	PRESENT	0
100442	100162	08014Q	PARTICIPANT	\N	PRESENT	0
100443	100162	95035G	PARTICIPANT	\N	PRESENT	0
100444	100162	14179A	PARTICIPANT	\N	PRESENT	0
100445	100162	14097Y	PARTICIPANT	\N	PRESENT	0
100446	100162	14119M	PARTICIPANT	\N	PRESENT	0
100447	100162	14031R	PARTICIPANT	\N	PRESENT	0
100448	100162	14111D	PARTICIPANT	\N	PRESENT	0
100512	100162	14121F	PARTICIPANT	\N	PRESENT	0
100513	100162	11054L	PARTICIPANT	\N	PRESENT	0
100514	100162	11067R	PARTICIPANT	\N	PRESENT	0
100515	100162	11104D	PARTICIPANT	\N	PRESENT	0
100516	100162	11042G	PARTICIPANT	\N	PRESENT	0
100517	100162	14221J	PARTICIPANT	\N	PRESENT	0
100401	100162	11085T	PARTICIPANT	\N	PRESENT	0
100402	100162	01015L	PARTICIPANT	\N	PRESENT	0
100518	100162	08042U	PARTICIPANT	\N	PRESENT	0
100519	100162	14038Y	PARTICIPANT	\N	PRESENT	0
100520	100162	04097T	PARTICIPANT	\N	PRESENT	0
100521	100162	11110B	PARTICIPANT	\N	PRESENT	0
100522	100162	11066Q	PARTICIPANT	\N	PRESENT	0
100523	100162	11059R	PARTICIPANT	\N	PRESENT	0
100524	100162	14105F	PARTICIPANT	\N	PRESENT	0
100525	100162	14159V	PARTICIPANT	\N	PRESENT	0
100527	100162	14157T	PARTICIPANT	\N	PRESENT	0
100528	100162	08048B	PARTICIPANT	\N	PRESENT	0
100529	100162	14231L	PARTICIPANT	\N	PRESENT	0
100530	100162	14267Y	PARTICIPANT	\N	PRESENT	0
500861	500860	14229S	PARTICIPANT	\N	PRESENT	0
500862	500860	08017T	PARTICIPANT	\N	PRESENT	0
500863	500860	19735D	PARTICIPANT	\N	PRESENT	0
500865	500864	14229S	PARTICIPANT	\N	PRESENT	0
500866	500864	08017T	PARTICIPANT	\N	PRESENT	0
500867	500864	19735D	PARTICIPANT	\N	PRESENT	0
500939	500410	19697Q	PARTICIPANT	\N	PRESENT	0
500940	500410	11067R	PARTICIPANT	\N	PRESENT	0
500941	500410	20090E	PARTICIPANT	\N	PRESENT	0
500942	500410	19569H	PARTICIPANT	\N	PRESENT	0
500943	500410	19798U	PARTICIPANT	\N	PRESENT	0
500944	500410	11097X	PARTICIPANT	\N	PRESENT	0
500945	500410	18193Q	PARTICIPANT	\N	PRESENT	0
500946	500410	14223L	PARTICIPANT	\N	PRESENT	0
500947	500410	14026U	PARTICIPANT	\N	PRESENT	0
500948	500410	11031D	PARTICIPANT	\N	PRESENT	0
500949	500410	19703U	PARTICIPANT	\N	PRESENT	0
500950	500410	19553Y	PARTICIPANT	\N	PRESENT	0
500951	500410	14281W	PARTICIPANT	\N	PRESENT	0
500952	500410	19679N	PARTICIPANT	\N	PRESENT	0
500953	500410	14042U	PARTICIPANT	\N	PRESENT	0
500954	500410	14195A	PARTICIPANT	\N	PRESENT	0
500955	500410	14213J	PARTICIPANT	\N	PRESENT	0
500956	500410	14217N	PARTICIPANT	\N	PRESENT	0
500957	500410	19683J	PARTICIPANT	\N	PRESENT	0
500958	500410	10006L	PRESIDENT	0	PRESENT	0
500959	500410	01034P	PARTICIPANT	\N	PRESENT	0
500960	500410	04092N	PARTICIPANT	\N	PRESENT	0
94453	94452	11088W	PARTICIPANT	\N	PRESENT	0
94455	94454	11088W	PARTICIPANT	\N	PRESENT	0
94518	94517	08010L	PARTICIPANT	\N	PRESENT	0
94520	94519	08010L	PARTICIPANT	\N	PRESENT	0
94522	94521	08010L	PARTICIPANT	\N	PRESENT	0
94524	94523	01031L	PARTICIPANT	\N	PRESENT	0
96762	96233	90003B	PARTICIPANT	\N	PRESENT	0
96763	96233	14030Q	PARTICIPANT	\N	PRESENT	0
96764	96233	14083S	PARTICIPANT	\N	PRESENT	0
96765	96233	10006L	PARTICIPANT	\N	PRESENT	0
96766	96233	14191V	PARTICIPANT	\N	PRESENT	0
96767	96233	14231L	PARTICIPANT	\N	PRESENT	0
96768	96233	14259Y	PARTICIPANT	\N	PRESENT	0
96769	96233	14111D	PARTICIPANT	\N	PRESENT	0
96770	96233	07004J	PARTICIPANT	\N	PRESENT	0
96771	96233	87003B	PARTICIPANT	\N	PRESENT	0
96772	96233	11100Y	PARTICIPANT	\N	PRESENT	0
96773	96233	04043D	PARTICIPANT	\N	PRESENT	0
96774	96233	14089Y	PARTICIPANT	\N	PRESENT	0
96775	96233	11088W	PARTICIPANT	\N	PRESENT	0
96776	96233	11085T	PARTICIPANT	\N	PRESENT	0
96777	96233	14087W	PARTICIPANT	\N	PRESENT	0
96778	96233	98035U	PARTICIPANT	\N	PRESENT	0
96779	96233	98046X	PARTICIPANT	\N	PRESENT	0
96780	96233	05012A	PARTICIPANT	\N	PRESENT	0
96781	96233	14271U	PARTICIPANT	\N	PRESENT	0
96782	96233	92045V	PARTICIPANT	\N	PRESENT	0
96783	96233	89017R	PARTICIPANT	\N	PRESENT	0
96784	96233	01060R	PARTICIPANT	\N	PRESENT	0
96785	96233	11010L	PARTICIPANT	\N	PRESENT	0
96786	96233	11097X	PARTICIPANT	\N	PRESENT	0
96787	96233	11049P	PARTICIPANT	\N	PRESENT	0
96789	96233	14033T	PARTICIPANT	\N	PRESENT	0
96790	96233	04049K	PARTICIPANT	\N	PRESENT	0
96791	96233	14251Q	PARTICIPANT	\N	PRESENT	0
96792	96233	01057W	PARTICIPANT	\N	PRESENT	0
96793	96233	14135M	PARTICIPANT	\N	PRESENT	0
96795	96233	11071M	PARTICIPANT	\N	PRESENT	0
96796	96233	10015M	PARTICIPANT	\N	PRESENT	0
96797	96233	11090Q	PARTICIPANT	\N	PRESENT	0
96798	96233	86044G	PARTICIPANT	\N	PRESENT	0
96799	96233	11044J	PARTICIPANT	\N	PRESENT	0
96800	96233	14169X	PARTICIPANT	\N	PRESENT	0
96801	96233	04074L	PARTICIPANT	\N	PRESENT	0
96802	96233	98050T	PARTICIPANT	\N	PRESENT	0
96803	96233	07032N	PARTICIPANT	\N	PRESENT	0
96804	96233	14037X	PARTICIPANT	\N	PRESENT	0
96805	96233	08015R	PARTICIPANT	\N	PRESENT	0
96806	96233	14213J	PARTICIPANT	\N	PRESENT	0
96807	96233	11032E	PARTICIPANT	\N	PRESENT	0
96808	96233	08034U	PARTICIPANT	\N	PRESENT	0
96809	96233	08069G	PARTICIPANT	\N	PRESENT	0
96810	96233	14217N	PARTICIPANT	\N	PRESENT	0
96811	96233	08019V	PARTICIPANT	\N	PRESENT	0
96812	96233	95035G	PARTICIPANT	\N	PRESENT	0
96813	96233	14059S	PARTICIPANT	\N	PRESENT	0
96814	96233	11030C	PARTICIPANT	\N	PRESENT	0
96815	96233	01008M	PARTICIPANT	\N	PRESENT	0
96816	96233	98018T	PARTICIPANT	\N	PRESENT	0
96817	96233	05004A	PARTICIPANT	\N	PRESENT	0
96818	96233	14093U	PARTICIPANT	\N	PRESENT	0
96819	96233	14034U	PARTICIPANT	\N	PRESENT	0
96820	96233	14175V	PARTICIPANT	\N	PRESENT	0
96821	96233	14105F	PARTICIPANT	\N	PRESENT	0
96822	96233	11101A	PARTICIPANT	\N	PRESENT	0
96823	96233	14053L	PARTICIPANT	\N	PRESENT	0
96824	96233	14038Y	PARTICIPANT	\N	PRESENT	0
96825	96233	14069U	PARTICIPANT	\N	PRESENT	0
96826	96233	14209N	PARTICIPANT	\N	PRESENT	0
96827	96233	07034Q	PARTICIPANT	\N	PRESENT	0
96841	96233	14249W	PARTICIPANT	\N	PRESENT	0
96829	96233	04071H	PARTICIPANT	\N	PRESENT	0
96830	96233	04081K	PARTICIPANT	\N	PRESENT	0
96831	96233	04092N	PARTICIPANT	\N	PRESENT	0
96832	96233	01019Q	PARTICIPANT	\N	PRESENT	0
96836	96233	07029T	PARTICIPANT	\N	PRESENT	0
96834	96233	14187A	PARTICIPANT	\N	PRESENT	0
96835	96233	14061L	PARTICIPANT	\N	PRESENT	0
96837	96233	11043H	PARTICIPANT	\N	PRESENT	0
96838	96233	08048B	PARTICIPANT	\N	PRESENT	0
96878	96233	11093T	PARTICIPANT	\N	PRESENT	0
96840	96233	08062Y	PARTICIPANT	\N	PRESENT	0
96842	96233	11080N	PARTICIPANT	\N	PRESENT	0
96854	96233	14195A	PARTICIPANT	\N	PRESENT	0
96859	96233	14119M	PARTICIPANT	\N	PRESENT	0
96864	96233	11091R	PARTICIPANT	\N	PRESENT	0
96867	96233	14265W	PARTICIPANT	\N	PRESENT	0
96869	96233	14073Q	PARTICIPANT	\N	PRESENT	0
96870	96233	14031R	PARTICIPANT	\N	PRESENT	0
96873	96233	14199E	PARTICIPANT	\N	PRESENT	0
96879	96233	04070G	PARTICIPANT	\N	PRESENT	0
96882	96233	01041N	PARTICIPANT	\N	PRESENT	0
96883	96233	11076S	PARTICIPANT	\N	PRESENT	0
96884	96233	11026G	PARTICIPANT	\N	PRESENT	0
96887	96233	07024N	PARTICIPANT	\N	PRESENT	0
96892	96233	11074Q	PARTICIPANT	\N	PRESENT	0
97146	96234	01007L	PARTICIPANT	\N	PRESENT	0
97147	96234	11071M	PARTICIPANT	\N	PRESENT	0
97148	96234	14033T	PARTICIPANT	\N	PRESENT	0
97149	96234	92015P	PARTICIPANT	\N	PRESENT	0
97150	96234	01044R	PARTICIPANT	\N	PRESENT	0
97151	96234	04070G	PARTICIPANT	\N	PRESENT	0
97152	96234	04074L	PARTICIPANT	\N	PRESENT	0
97153	96234	07026Q	PARTICIPANT	\N	PRESENT	0
97154	96234	14229S	PARTICIPANT	\N	PRESENT	0
97155	96234	14263U	PARTICIPANT	\N	PRESENT	0
97156	96234	08039A	PARTICIPANT	\N	PRESENT	0
97157	96234	04059M	PARTICIPANT	\N	PRESENT	0
97158	96234	11077T	PARTICIPANT	\N	PRESENT	0
97161	96234	14109K	PARTICIPANT	\N	PRESENT	0
97163	96234	01060R	PARTICIPANT	\N	PRESENT	0
97164	96234	14059S	PARTICIPANT	\N	PRESENT	0
97165	96234	14241N	PARTICIPANT	\N	PRESENT	0
97166	96234	86044G	PARTICIPANT	\N	PRESENT	0
97174	96234	04088S	PARTICIPANT	\N	PRESENT	0
97175	96234	11025F	PARTICIPANT	\N	PRESENT	0
97176	96234	11036J	PARTICIPANT	\N	PRESENT	0
97177	96234	08031R	PARTICIPANT	\N	PRESENT	0
97178	96234	14103D	PARTICIPANT	\N	PRESENT	0
97179	96234	14042U	PARTICIPANT	\N	PRESENT	0
97180	96234	01041N	PARTICIPANT	\N	PRESENT	0
97181	96234	14069U	PARTICIPANT	\N	PRESENT	0
97182	96234	08019V	PARTICIPANT	\N	PRESENT	0
97187	96234	11072N	PARTICIPANT	\N	PRESENT	0
97188	96234	14089Y	PARTICIPANT	\N	PRESENT	0
97189	96234	07029T	PARTICIPANT	\N	PRESENT	0
97194	96234	01046T	PARTICIPANT	\N	PRESENT	0
97212	96234	95035G	PARTICIPANT	\N	PRESENT	0
97213	96234	14038Y	PARTICIPANT	\N	PRESENT	0
97247	96234	07024N	PARTICIPANT	\N	PRESENT	0
97248	96234	14083S	PARTICIPANT	\N	PRESENT	0
97249	96234	08010L	PARTICIPANT	\N	PRESENT	0
97271	96234	08055A	PARTICIPANT	\N	PRESENT	0
97312	96234	14271U	PARTICIPANT	\N	PRESENT	0
97595	97594	95041E	PARTICIPANT	\N	PRESENT	0
97596	97594	95062K	PARTICIPANT	\N	PRESENT	0
97613	97612	04053F	PARTICIPANT	\N	PRESENT	0
97614	97612	14195A	PARTICIPANT	\N	EXCUSE	0
97615	97612	11023D	PARTICIPANT	\N	PRESENT	0
97616	97612	11031D	PARTICIPANT	\N	PRESENT	0
97617	97612	14087W	PARTICIPANT	\N	PRESENT	0
97618	97612	14034U	PARTICIPANT	\N	PRESENT	0
97619	97612	14231L	PARTICIPANT	\N	EXCUSE	0
97620	97612	11061K	PARTICIPANT	\N	PRESENT	0
97621	97612	08048B	PARTICIPANT	\N	PRESENT	0
97622	97612	08041T	PARTICIPANT	\N	EXCUSE	0
97623	97612	14026U	PARTICIPANT	\N	PRESENT	0
97624	97612	14213J	PARTICIPANT	\N	PRESENT	0
97625	97612	11112D	PARTICIPANT	\N	PRESENT	0
97626	97612	14223L	PARTICIPANT	\N	PRESENT	0
97627	97612	04092N	PRESIDENT	0	PRESENT	0
97628	97612	14071N	PARTICIPANT	\N	PRESENT	0
97629	97612	07032N	PARTICIPANT	\N	EXCUSE	0
97630	97612	11093T	PARTICIPANT	\N	PRESENT	0
97631	97612	11097X	PARTICIPANT	\N	PRESENT	0
97653	97652	14079W	PARTICIPANT	\N	PRESENT	0
97654	97652	04055H	PRESIDENT	0	PRESENT	0
97657	97652	11095V	PARTICIPANT	\N	EXCUSE	0
97659	97652	01059Y	PARTICIPANT	\N	PRESENT	0
97664	97652	14249W	PARTICIPANT	\N	PRESENT	0
97666	97652	11110B	PARTICIPANT	\N	PRESENT	0
97669	97652	08034U	PARTICIPANT	\N	PRESENT	0
97671	97652	11077T	PARTICIPANT	\N	PRESENT	0
97673	97652	14265W	PARTICIPANT	\N	PRESENT	0
97687	97652	14235Q	PARTICIPANT	\N	PRESENT	0
97694	97652	04045F	PARTICIPANT	\N	PRESENT	0
97695	97652	01034P	PRESIDENT	1	PRESENT	0
97697	97652	83047W	PARTICIPANT	\N	EXCUSE	0
97779	97652	14217N	PARTICIPANT	\N	PRESENT	0
99083	99082	14239U	PARTICIPANT	\N	PRESENT	0
99084	99082	11055M	PARTICIPANT	\N	PRESENT	0
99085	99082	01046T	PARTICIPANT	\N	PRESENT	0
99086	99082	04053F	PARTICIPANT	\N	PRESENT	0
99087	99082	14255U	PARTICIPANT	\N	PRESENT	0
99088	99082	04066L	PARTICIPANT	\N	PRESENT	0
103037	103036	14237S	PARTICIPANT	\N	PRESENT	0
99090	99082	14053L	PARTICIPANT	\N	PRESENT	0
99091	99082	11103C	PARTICIPANT	\N	PRESENT	0
99092	99082	11044J	PARTICIPANT	\N	PRESENT	0
99093	99082	14195A	PARTICIPANT	\N	PRESENT	0
99094	99082	14267Y	PARTICIPANT	\N	PRESENT	0
99095	99082	11023D	PARTICIPANT	\N	PRESENT	0
99096	99082	11031D	PARTICIPANT	\N	PRESENT	0
99097	99082	08052W	PARTICIPANT	\N	PRESENT	0
99098	99082	01059Y	PARTICIPANT	\N	PRESENT	0
99099	99082	04081K	PARTICIPANT	\N	PRESENT	0
99100	99082	98024R	PARTICIPANT	\N	PRESENT	0
99101	99082	10006L	PARTICIPANT	\N	PRESENT	0
99102	99082	04067M	PARTICIPANT	\N	PRESENT	0
99103	99082	14217N	PARTICIPANT	\N	PRESENT	0
99104	99082	14042U	PARTICIPANT	\N	PRESENT	0
99105	99082	14151M	PARTICIPANT	\N	PRESENT	0
99106	99082	12042Y	PARTICIPANT	\N	PRESENT	0
99107	99082	14281W	PARTICIPANT	\N	PRESENT	0
99108	99082	14087W	PARTICIPANT	\N	PRESENT	0
99109	99082	01003G	PARTICIPANT	\N	PRESENT	0
99110	99082	14034U	PARTICIPANT	\N	PRESENT	0
99111	99082	14231L	PARTICIPANT	\N	EXCUSE	0
99112	99082	11061K	PARTICIPANT	\N	PRESENT	0
99113	99082	08048B	PARTICIPANT	\N	PRESENT	0
99114	99082	08041T	PARTICIPANT	\N	EXCUSE	0
99115	99082	01011G	PARTICIPANT	\N	PRESENT	0
99116	99082	14026U	PARTICIPANT	\N	PRESENT	0
99117	99082	14213J	PARTICIPANT	\N	PRESENT	0
112633	112632	01008M	PARTICIPANT	\N	PRESENT	0
99119	99082	11112D	PARTICIPANT	\N	PRESENT	0
99120	99082	14037X	PARTICIPANT	\N	PRESENT	0
99121	99082	14018U	PARTICIPANT	\N	PRESENT	0
99122	99082	11067R	PARTICIPANT	\N	PRESENT	0
99123	99082	14223L	PARTICIPANT	\N	PRESENT	0
99124	99082	04092N	PRESIDENT	0	PRESENT	0
99125	99082	14265W	PARTICIPANT	\N	PRESENT	0
99126	99082	14119M	PARTICIPANT	\N	PRESENT	0
99127	99082	14071N	PARTICIPANT	\N	PRESENT	0
99128	99082	07032N	PARTICIPANT	\N	PRESENT	0
99129	99082	04043D	PARTICIPANT	\N	EXCUSE	0
99130	99082	14271U	PARTICIPANT	\N	PRESENT	0
99131	99082	14017T	PARTICIPANT	\N	PRESENT	0
99132	99082	11093T	PARTICIPANT	\N	PRESENT	0
99133	99082	11097X	PARTICIPANT	\N	PRESENT	0
99134	99082	04045F	PARTICIPANT	\N	PRESENT	0
99135	99082	14227Q	PARTICIPANT	\N	PRESENT	0
99136	99082	01034P	PARTICIPANT	\N	PRESENT	0
99137	99082	11025F	PARTICIPANT	\N	PRESENT	0
99138	99082	11063M	PARTICIPANT	\N	PRESENT	0
99139	99082	14269B	PARTICIPANT	\N	PRESENT	0
112634	112632	04089T	PARTICIPANT	\N	PRESENT	0
112635	112632	14257W	PARTICIPANT	\N	PRESENT	0
112652	103936	11061K	PARTICIPANT	\N	EXCUSE	0
112653	103936	11036J	PARTICIPANT	\N	PRESENT	0
112654	103936	14209N	PARTICIPANT	\N	EXCUSE	0
112655	103936	04061F	PARTICIPANT	\N	EXCUSE	0
112656	103936	01048V	PARTICIPANT	\N	EXCUSE	0
112657	103936	08039A	PARTICIPANT	\N	EXCUSE	0
112658	103936	14257W	PARTICIPANT	\N	EXCUSE	0
112659	103936	01046T	PARTICIPANT	\N	EXCUSE	0
112660	103936	11068S	PARTICIPANT	\N	EXCUSE	0
112661	103936	01058X	PARTICIPANT	\N	EXCUSE	0
112662	103936	11082Q	PARTICIPANT	\N	EXCUSE	0
112663	103936	13002U	PARTICIPANT	\N	EXCUSE	0
112664	103936	08069G	PARTICIPANT	\N	EXCUSE	0
112665	103936	14221J	PARTICIPANT	\N	EXCUSE	0
112666	103936	14263U	PARTICIPANT	\N	EXCUSE	0
112667	103936	11089X	PARTICIPANT	\N	EXCUSE	0
112668	103936	04043D	PARTICIPANT	\N	EXCUSE	0
112673	112672	04071H	PARTICIPANT	\N	PRESENT	0
112693	112692	04071H	PARTICIPANT	\N	PRESENT	0
112695	112694	04071H	PARTICIPANT	\N	PRESENT	0
112703	112702	01016M	PARTICIPANT	\N	PRESENT	0
112825	112494	08069G	PARTICIPANT	\N	PRESENT	0
112826	112494	14041T	PARTICIPANT	\N	PRESENT	0
112827	112494	01028R	PARTICIPANT	\N	PRESENT	0
112828	112494	07034Q	PARTICIPANT	\N	PRESENT	0
112829	112494	08014Q	PARTICIPANT	\N	PRESENT	0
112830	112494	08019V	PARTICIPANT	\N	PRESENT	0
112831	112494	99004R	PARTICIPANT	\N	PRESENT	0
112832	112494	04085P	PARTICIPANT	\N	PRESENT	0
112833	112494	14263U	PARTICIPANT	\N	PRESENT	0
112834	112494	07026Q	PARTICIPANT	\N	PRESENT	0
112835	112494	08025T	PARTICIPANT	\N	PRESENT	0
112823	112494	98053W	PARTICIPANT	\N	PRESENT	0
112824	112494	01007L	PARTICIPANT	\N	PRESENT	0
112836	112494	11040E	PARTICIPANT	\N	PRESENT	0
112837	112494	11083R	PARTICIPANT	\N	PRESENT	0
112838	112494	14033T	PARTICIPANT	\N	PRESENT	0
112839	112494	05008E	PARTICIPANT	\N	PRESENT	0
112840	112494	07029T	PARTICIPANT	\N	PRESENT	0
112841	112494	11053K	PARTICIPANT	\N	PRESENT	0
112842	112494	98046X	PARTICIPANT	\N	PRESENT	0
112843	112494	04034C	PARTICIPANT	\N	PRESENT	0
112844	112494	14001X	PARTICIPANT	\N	PRESENT	0
112845	112494	95063L	PARTICIPANT	\N	PRESENT	0
112846	112494	04044E	PARTICIPANT	\N	PRESENT	0
112847	112494	14269B	PARTICIPANT	\N	PRESENT	0
112848	112494	01044R	PARTICIPANT	\N	PRESENT	0
112849	112494	07004J	PARTICIPANT	\N	PRESENT	0
112850	112494	04038G	PARTICIPANT	\N	PRESENT	0
112851	112494	01031L	PARTICIPANT	\N	PRESENT	0
112852	112494	08011M	PARTICIPANT	\N	PRESENT	0
112853	112494	01027Q	PARTICIPANT	\N	PRESENT	0
112854	112495	98053W	PARTICIPANT	\N	PRESENT	0
112855	112495	01007L	PARTICIPANT	\N	PRESENT	0
112856	112495	08069G	PARTICIPANT	\N	PRESENT	0
112857	112495	14041T	PARTICIPANT	\N	PRESENT	0
112858	112495	01028R	PARTICIPANT	\N	PRESENT	0
112859	112495	07034Q	PARTICIPANT	\N	PRESENT	0
112860	112495	08014Q	PARTICIPANT	\N	PRESENT	0
112861	112495	08019V	PARTICIPANT	\N	PRESENT	0
112862	112495	99004R	PARTICIPANT	\N	PRESENT	0
112863	112495	04085P	PARTICIPANT	\N	PRESENT	0
112864	112495	14263U	PARTICIPANT	\N	PRESENT	0
112865	112495	07026Q	PARTICIPANT	\N	PRESENT	0
112866	112495	08025T	PARTICIPANT	\N	PRESENT	0
112867	112495	11040E	PARTICIPANT	\N	PRESENT	0
112868	112495	11083R	PARTICIPANT	\N	PRESENT	0
112869	112495	14033T	PARTICIPANT	\N	PRESENT	0
112870	112495	05008E	PARTICIPANT	\N	PRESENT	0
112871	112495	07029T	PARTICIPANT	\N	PRESENT	0
112872	112495	11053K	PARTICIPANT	\N	PRESENT	0
112873	112495	98046X	PARTICIPANT	\N	PRESENT	0
112874	112495	04034C	PARTICIPANT	\N	PRESENT	0
112875	112495	14001X	PARTICIPANT	\N	PRESENT	0
112876	112495	95063L	PARTICIPANT	\N	PRESENT	0
112877	112495	04044E	PARTICIPANT	\N	PRESENT	0
112878	112495	14269B	PARTICIPANT	\N	PRESENT	0
112879	112495	01044R	PARTICIPANT	\N	PRESENT	0
112880	112495	07004J	PARTICIPANT	\N	PRESENT	0
112881	112495	04038G	PARTICIPANT	\N	PRESENT	0
112882	112495	01031L	PARTICIPANT	\N	PRESENT	0
112883	112495	08011M	PARTICIPANT	\N	PRESENT	0
112884	112495	01027Q	PARTICIPANT	\N	PRESENT	0
112885	112495	11036J	PARTICIPANT	\N	PRESENT	0
112886	112495	11085T	PARTICIPANT	\N	PRESENT	0
112887	112495	11048N	PARTICIPANT	\N	PRESENT	0
112888	112495	11100Y	PARTICIPANT	\N	PRESENT	0
112889	112495	04049K	PARTICIPANT	\N	PRESENT	0
112914	112495	11110B	PARTICIPANT	\N	PRESENT	0
112915	112495	11074Q	PARTICIPANT	\N	PRESENT	0
112916	112495	04086Q	PARTICIPANT	\N	PRESENT	0
112925	112495	01041N	PARTICIPANT	\N	PRESENT	0
112944	112943	01031L	PARTICIPANT	\N	PRESENT	0
112946	112945	11057P	PARTICIPANT	\N	PRESENT	0
112948	112947	01031L	PARTICIPANT	\N	PRESENT	0
112950	112949	04071H	PARTICIPANT	\N	PRESENT	0
112951	112495	11042G	PARTICIPANT	\N	PRESENT	0
112952	112495	11103C	PARTICIPANT	\N	PRESENT	0
112953	112495	04071H	PARTICIPANT	\N	PRESENT	0
112954	112495	11066Q	PARTICIPANT	\N	PRESENT	0
112955	112495	11057P	PARTICIPANT	\N	PRESENT	0
112972	112496	98053W	PARTICIPANT	\N	PRESENT	0
112973	112496	01007L	PARTICIPANT	\N	PRESENT	0
112974	112496	14041T	PARTICIPANT	\N	PRESENT	0
112976	112496	07034Q	PARTICIPANT	\N	PRESENT	0
112977	112496	04085P	PARTICIPANT	\N	PRESENT	0
112978	112496	14263U	PARTICIPANT	\N	PRESENT	0
112980	112496	08025T	PARTICIPANT	\N	PRESENT	0
94598	94597	08016S	PARTICIPANT	\N	PRESENT	0
94599	94597	92020L	PARTICIPANT	\N	PRESENT	0
94600	94597	04080J	PARTICIPANT	\N	PRESENT	0
94601	94597	92031P	PARTICIPANT	\N	PRESENT	0
95213	95212	01008M	PARTICIPANT	\N	PRESENT	0
95214	95212	11036J	PARTICIPANT	\N	PRESENT	0
95263	95262	01008M	PARTICIPANT	\N	PRESENT	0
95216	95212	14013P	PARTICIPANT	\N	PRESENT	0
95217	95212	08068F	PARTICIPANT	\N	PRESENT	0
95218	95212	14207L	PARTICIPANT	\N	PRESENT	0
95219	95212	11101A	PARTICIPANT	\N	PRESENT	0
95220	95212	90003B	PARTICIPANT	\N	PRESENT	0
95221	95212	08028W	PARTICIPANT	\N	PRESENT	0
95222	95212	80013X	PARTICIPANT	\N	PRESENT	0
95223	95212	08038Y	PARTICIPANT	\N	PRESENT	0
95224	95212	04089T	PARTICIPANT	\N	PRESENT	0
95225	95212	14197C	PARTICIPANT	\N	PRESENT	0
95226	95212	11110B	PARTICIPANT	\N	PRESENT	0
95264	95262	11036J	PARTICIPANT	\N	PRESENT	0
95717	95262	14179A	PARTICIPANT	\N	PRESENT	0
95266	95262	14013P	PARTICIPANT	\N	PRESENT	0
95230	95212	04048J	PARTICIPANT	\N	PRESENT	0
95231	95212	11099A	PARTICIPANT	\N	PRESENT	0
95232	95212	04049K	PARTICIPANT	\N	PRESENT	0
95233	95212	04094Q	PARTICIPANT	\N	PRESENT	0
95234	95212	11111C	PARTICIPANT	\N	PRESENT	0
95235	95212	08015R	PARTICIPANT	\N	PRESENT	0
95236	95212	11100Y	PRESIDENT	0	PRESENT	0
95237	95212	01061S	PARTICIPANT	\N	PRESENT	0
95238	95212	11098Y	PARTICIPANT	\N	PRESENT	0
95239	95212	01043Q	PARTICIPANT	\N	EXCUSE	0
95267	95262	08068F	PARTICIPANT	\N	PRESENT	0
95241	95212	14205J	PARTICIPANT	\N	PRESENT	0
95242	95212	08019V	PARTICIPANT	\N	PRESENT	0
95243	95212	14257W	PARTICIPANT	\N	PRESENT	0
95268	95262	14207L	PARTICIPANT	\N	PRESENT	0
95245	95212	04088S	PARTICIPANT	\N	PRESENT	0
95246	95212	98050T	PARTICIPANT	\N	PRESENT	0
95269	95262	11101A	PARTICIPANT	\N	PRESENT	0
95270	95262	90003B	PARTICIPANT	\N	PRESENT	0
95249	95212	01058X	PARTICIPANT	\N	PRESENT	0
95250	95212	11094U	PARTICIPANT	\N	EXCUSE	0
95251	95212	11066Q	PARTICIPANT	\N	PRESENT	0
95271	95262	08028W	PARTICIPANT	\N	PRESENT	0
95272	95262	80013X	PARTICIPANT	\N	PRESENT	0
95273	95262	08038Y	PARTICIPANT	\N	PRESENT	0
95274	95262	04089T	PARTICIPANT	\N	PRESENT	0
95275	95262	14197C	PARTICIPANT	\N	PRESENT	0
95276	95262	11110B	PARTICIPANT	\N	PRESENT	0
96238	96236	11061K	PARTICIPANT	\N	PRESENT	0
95278	95262	14033T	PARTICIPANT	\N	PRESENT	0
95777	95212	14199E	PARTICIPANT	\N	PRESENT	0
95280	95262	04048J	PARTICIPANT	\N	PRESENT	0
95281	95262	11099A	PARTICIPANT	\N	PRESENT	0
95282	95262	04049K	PARTICIPANT	\N	PRESENT	0
95283	95262	04094Q	PARTICIPANT	\N	PRESENT	0
95284	95262	11111C	PARTICIPANT	\N	PRESENT	0
95285	95262	08015R	PARTICIPANT	\N	PRESENT	0
95286	95262	11100Y	PRESIDENT	0	PRESENT	0
95287	95262	01061S	PARTICIPANT	\N	PRESENT	0
95288	95262	11098Y	PARTICIPANT	\N	PRESENT	0
95289	95262	01043Q	PARTICIPANT	\N	EXCUSE	0
95783	95782	01008M	PARTICIPANT	\N	PRESENT	0
95291	95262	14205J	PARTICIPANT	\N	PRESENT	0
95292	95262	08019V	PARTICIPANT	\N	PRESENT	0
95293	95262	14257W	PARTICIPANT	\N	PRESENT	0
95784	95782	11036J	PARTICIPANT	\N	PRESENT	0
95295	95262	04088S	PARTICIPANT	\N	PRESENT	0
95296	95262	98050T	PARTICIPANT	\N	PRESENT	0
96237	96236	88008L	PARTICIPANT	\N	PRESENT	0
95786	95782	14013P	PARTICIPANT	\N	PRESENT	0
95299	95262	01058X	PARTICIPANT	\N	PRESENT	0
95300	95262	11094U	PARTICIPANT	\N	EXCUSE	0
95301	95262	11066Q	PARTICIPANT	\N	PRESENT	0
95787	95782	08068F	PARTICIPANT	\N	PRESENT	0
95788	95782	14207L	PARTICIPANT	\N	PRESENT	0
95789	95782	11101A	PARTICIPANT	\N	PRESENT	0
95790	95782	90003B	PARTICIPANT	\N	PRESENT	0
95791	95782	08028W	PARTICIPANT	\N	PRESENT	0
95792	95782	80013X	PARTICIPANT	\N	PRESENT	0
95793	95782	08038Y	PARTICIPANT	\N	PRESENT	0
95794	95782	04089T	PARTICIPANT	\N	PRESENT	0
95795	95782	14197C	PARTICIPANT	\N	PRESENT	0
96239	96236	01037S	PARTICIPANT	\N	PRESENT	0
96270	96236	11027H	PARTICIPANT	\N	PRESENT	0
95798	95782	14033T	PARTICIPANT	\N	PRESENT	0
96271	96236	14217N	PARTICIPANT	\N	PRESENT	0
96272	96236	11091R	PARTICIPANT	\N	PRESENT	0
95801	95782	11099A	PARTICIPANT	\N	PRESENT	0
95802	95782	04049K	PARTICIPANT	\N	PRESENT	0
95803	95782	04094Q	PARTICIPANT	\N	PRESENT	0
95804	95782	11111C	PARTICIPANT	\N	PRESENT	0
95805	95782	08015R	PARTICIPANT	\N	PRESENT	0
95806	95782	11100Y	PRESIDENT	0	PRESENT	0
95807	95782	01061S	PARTICIPANT	\N	PRESENT	0
96274	96236	92020L	PARTICIPANT	\N	PRESENT	0
95809	95782	01043Q	PARTICIPANT	\N	EXCUSE	0
96275	96236	08065C	PARTICIPANT	\N	PRESENT	0
95811	95782	14205J	PARTICIPANT	\N	PRESENT	0
95812	95782	08019V	PARTICIPANT	\N	PRESENT	0
96276	96236	14097Y	PARTICIPANT	\N	PRESENT	0
96277	96236	14105F	PARTICIPANT	\N	PRESENT	0
96278	96236	04036E	PARTICIPANT	\N	PRESENT	0
95816	95782	98050T	PARTICIPANT	\N	PRESENT	0
96279	96236	04070G	PARTICIPANT	\N	PRESENT	0
96280	96236	11026G	PARTICIPANT	\N	PRESENT	0
95819	95782	01058X	PARTICIPANT	\N	PRESENT	0
95820	95782	11094U	PARTICIPANT	\N	EXCUSE	0
95821	95782	11066Q	PARTICIPANT	\N	PRESENT	0
96281	96236	04092N	PARTICIPANT	\N	PRESENT	0
96430	96424	14030Q	PARTICIPANT	\N	EXCUSE	0
96431	96424	08060W	PARTICIPANT	\N	EXCUSE	0
96432	96424	14041T	PARTICIPANT	\N	EXCUSE	0
96433	96424	04041B	PARTICIPANT	\N	EXCUSE	0
96434	96424	04036E	PARTICIPANT	\N	EXCUSE	0
119447	119446	11055M	PARTICIPANT	\N	PRESENT	0
119493	119492	01034P	PARTICIPANT	\N	PRESENT	0
119494	119492	83047W	PARTICIPANT	\N	PRESENT	0
119450	119446	95015C	PARTICIPANT	\N	PRESENT	0
119422	119409	11034G	PARTICIPANT	\N	PRESENT	0
119495	119492	04067M	PARTICIPANT	\N	PRESENT	0
119424	119409	14231L	PARTICIPANT	\N	PRESENT	0
119425	119409	14179A	PARTICIPANT	\N	PRESENT	0
119426	119409	14213J	PARTICIPANT	\N	PRESENT	0
119427	119409	08031R	PARTICIPANT	\N	PRESENT	0
119428	119409	11100Y	PRESIDENT	0	PRESENT	0
119429	119409	11077T	PARTICIPANT	\N	PRESENT	0
119452	119446	11027H	PARTICIPANT	\N	PRESENT	0
119431	119409	11104D	PARTICIPANT	\N	PRESENT	0
119496	119492	14217N	PARTICIPANT	\N	PRESENT	0
119433	119409	07032N	PARTICIPANT	\N	PRESENT	0
119454	119446	14079W	PARTICIPANT	\N	PRESENT	0
119435	119409	11090Q	PARTICIPANT	\N	PRESENT	0
119436	119409	14235Q	PARTICIPANT	\N	PRESENT	0
119498	119497	01044R	PARTICIPANT	\N	PRESENT	0
119456	119446	14215L	PARTICIPANT	\N	PRESENT	0
119439	119409	01028R	PARTICIPANT	\N	PRESENT	0
119440	119409	11094U	PARTICIPANT	\N	PRESENT	0
119441	119409	11037K	PARTICIPANT	\N	PRESENT	0
119442	119409	14157T	PARTICIPANT	\N	PRESENT	0
119443	119409	92045V	PARTICIPANT	\N	EXCUSE	0
119444	119409	11066Q	PARTICIPANT	\N	PRESENT	0
119499	119497	11036J	PARTICIPANT	\N	EXCUSE	0
119457	119446	04089T	PARTICIPANT	\N	PRESENT	0
119458	119446	14187A	PARTICIPANT	\N	PRESENT	0
119459	119446	11034G	PARTICIPANT	\N	PRESENT	0
119500	119497	14030Q	PARTICIPANT	\N	EXCUSE	0
119461	119446	14231L	PARTICIPANT	\N	PRESENT	0
119462	119446	14179A	PARTICIPANT	\N	PRESENT	0
119463	119446	14213J	PARTICIPANT	\N	PRESENT	0
119464	119446	08031R	PARTICIPANT	\N	PRESENT	0
119465	119446	11100Y	PRESIDENT	0	PRESENT	0
119466	119446	11077T	PARTICIPANT	\N	PRESENT	0
119501	119497	14038Y	PARTICIPANT	\N	EXCUSE	0
119468	119446	11104D	PARTICIPANT	\N	PRESENT	0
119502	119497	80013X	PARTICIPANT	\N	EXCUSE	0
119470	119446	07032N	PARTICIPANT	\N	PRESENT	0
119503	119497	01015L	PARTICIPANT	\N	EXCUSE	0
119472	119446	11090Q	PARTICIPANT	\N	PRESENT	0
119473	119446	14235Q	PARTICIPANT	\N	PRESENT	0
119474	119446	95063L	PARTICIPANT	\N	PRESENT	0
119504	119497	14219Q	PARTICIPANT	\N	EXCUSE	0
119505	119497	04057K	PARTICIPANT	\N	EXCUSE	0
119506	119497	92039X	PARTICIPANT	\N	EXCUSE	0
119478	119446	11037K	PARTICIPANT	\N	PRESENT	0
119479	119446	14157T	PARTICIPANT	\N	PRESENT	0
119480	119446	92045V	PARTICIPANT	\N	EXCUSE	0
119481	119446	11066Q	PARTICIPANT	\N	PRESENT	0
119482	119446	14269B	PARTICIPANT	\N	PRESENT	0
100593	100163	11091R	PARTICIPANT	\N	PRESENT	0
100594	100163	08048B	PARTICIPANT	\N	PRESENT	0
100595	100163	04048J	PARTICIPANT	\N	PRESENT	0
100596	100163	14331P	PARTICIPANT	\N	PRESENT	0
100597	100163	14273W	PARTICIPANT	\N	PRESENT	0
100598	100163	14241N	PARTICIPANT	\N	PRESENT	0
100599	100163	14109K	PARTICIPANT	\N	PRESENT	0
100600	100163	11042G	PARTICIPANT	\N	PRESENT	0
100601	100163	14157T	PARTICIPANT	\N	PRESENT	0
100602	100163	95030B	PARTICIPANT	\N	PRESENT	0
100603	100163	11066Q	PARTICIPANT	\N	PRESENT	0
100604	100163	11036J	PARTICIPANT	\N	PRESENT	0
100605	100163	14107H	PARTICIPANT	\N	PRESENT	0
100606	100163	11059R	PARTICIPANT	\N	PRESENT	0
100607	100163	14030Q	PARTICIPANT	\N	PRESENT	0
100608	100163	08060W	PARTICIPANT	\N	PRESENT	0
100609	100163	14051J	PARTICIPANT	\N	PRESENT	0
100610	100163	13002U	PARTICIPANT	\N	PRESENT	0
100611	100163	11104D	PARTICIPANT	\N	PRESENT	0
100612	100163	14097Y	PARTICIPANT	\N	PRESENT	0
100613	100163	14281W	PARTICIPANT	\N	PRESENT	0
100614	100163	14121F	PARTICIPANT	\N	PRESENT	0
100615	100163	11054L	PARTICIPANT	\N	PRESENT	0
100616	100163	01015L	PARTICIPANT	\N	PRESENT	0
100617	100163	80013X	PARTICIPANT	\N	PRESENT	0
100618	100163	08068F	PARTICIPANT	\N	PRESENT	0
100619	100163	08009T	PARTICIPANT	\N	PRESENT	0
100620	100163	14031R	PARTICIPANT	\N	PRESENT	0
100621	100163	11065P	PARTICIPANT	\N	PRESENT	0
100622	100163	11012A	PARTICIPANT	\N	PRESENT	0
100632	100163	14221J	PARTICIPANT	\N	PRESENT	0
100633	100163	14219Q	PARTICIPANT	\N	PRESENT	0
100591	100163	11085T	PARTICIPANT	\N	PRESENT	0
100592	100163	14195A	PARTICIPANT	\N	PRESENT	0
100634	100163	14042U	PARTICIPANT	\N	PRESENT	0
100635	100163	14073Q	PARTICIPANT	\N	PRESENT	0
100636	100163	14267Y	PARTICIPANT	\N	PRESENT	0
100637	100163	11067R	PARTICIPANT	\N	PRESENT	0
100638	100163	11098Y	PARTICIPANT	\N	PRESENT	0
100639	100163	04097T	PARTICIPANT	\N	PRESENT	0
100640	100163	04088S	PARTICIPANT	\N	PRESENT	0
100641	100163	14231L	PARTICIPANT	\N	PRESENT	0
100642	100163	14179A	PARTICIPANT	\N	PRESENT	0
100643	100163	01056V	PARTICIPANT	\N	PRESENT	0
100644	100163	05012A	PARTICIPANT	\N	PRESENT	0
100645	100163	08053X	PARTICIPANT	\N	PRESENT	0
100646	100163	14235Q	PARTICIPANT	\N	PRESENT	0
100647	100163	11010L	PARTICIPANT	\N	PRESENT	0
100648	100163	14105F	PARTICIPANT	\N	PRESENT	0
100649	100163	14083S	PARTICIPANT	\N	PRESENT	0
100652	100163	95031C	PARTICIPANT	\N	PRESENT	0
100714	100164	14207L	PARTICIPANT	\N	PRESENT	0
100715	100164	08014Q	PARTICIPANT	\N	PRESENT	0
100716	100164	12042Y	PARTICIPANT	\N	PRESENT	0
100717	100164	14197C	PARTICIPANT	\N	PRESENT	0
100718	100164	11036J	PARTICIPANT	\N	PRESENT	0
100719	100164	11059R	PARTICIPANT	\N	PRESENT	0
100720	100164	01016M	PARTICIPANT	\N	PRESENT	0
100721	100164	04088S	PARTICIPANT	\N	PRESENT	0
100722	100164	14033T	PARTICIPANT	\N	PRESENT	0
100723	100164	14195A	PARTICIPANT	\N	PRESENT	0
100724	100164	14119M	PARTICIPANT	\N	PRESENT	0
100725	100164	04097T	PARTICIPANT	\N	PRESENT	0
100726	100164	14031R	PARTICIPANT	\N	PRESENT	0
100727	100164	14265W	PARTICIPANT	\N	PRESENT	0
100728	100164	14213J	PARTICIPANT	\N	PRESENT	0
100729	100164	95049N	PARTICIPANT	\N	PRESENT	0
100730	100164	11111C	PARTICIPANT	\N	PRESENT	0
100731	100164	01008M	PARTICIPANT	\N	PRESENT	0
100732	100164	14331P	PARTICIPANT	\N	PRESENT	0
100733	100164	14026U	PARTICIPANT	\N	PRESENT	0
100734	100164	14217N	PARTICIPANT	\N	PRESENT	0
100735	100164	11100Y	PARTICIPANT	\N	PRESENT	0
100736	100164	90003B	PARTICIPANT	\N	PRESENT	0
100737	100164	04067M	PARTICIPANT	\N	PRESENT	0
100738	100164	08049C	PARTICIPANT	\N	PRESENT	0
100739	100164	96004D	PARTICIPANT	\N	PRESENT	0
100740	100164	14235Q	PARTICIPANT	\N	PRESENT	0
100741	100164	11098Y	PARTICIPANT	\N	PRESENT	0
100742	100164	95030B	PARTICIPANT	\N	PRESENT	0
100743	100164	14135M	PARTICIPANT	\N	PRESENT	0
100752	100164	95031C	PARTICIPANT	\N	PRESENT	0
100753	100164	80013X	PARTICIPANT	\N	PRESENT	0
100754	100164	01057W	PARTICIPANT	\N	PRESENT	0
100755	100164	07029T	PARTICIPANT	\N	PRESENT	0
100756	100164	14105F	PARTICIPANT	\N	PRESENT	0
100757	100164	08055A	PARTICIPANT	\N	PRESENT	0
100758	100164	08016S	PARTICIPANT	\N	PRESENT	0
100759	100164	11095V	PARTICIPANT	\N	PRESENT	0
100712	100164	01007L	PARTICIPANT	\N	PRESENT	0
100713	100164	14257W	PARTICIPANT	\N	PRESENT	0
100760	100164	14083S	PARTICIPANT	\N	PRESENT	0
100761	100164	08051V	PARTICIPANT	\N	PRESENT	0
100773	100772	04086Q	PARTICIPANT	\N	PRESENT	0
100774	100772	12042Y	PRESIDENT	0	PRESENT	0
100775	100772	11107G	PARTICIPANT	\N	PRESENT	0
100776	100772	11061K	PARTICIPANT	\N	PRESENT	0
100777	100772	14014Q	PARTICIPANT	\N	PRESENT	0
100778	100772	14205J	PARTICIPANT	\N	PRESENT	0
100779	100772	14135M	PARTICIPANT	\N	PRESENT	0
100780	100772	11097X	PARTICIPANT	\N	PRESENT	0
100781	100772	04045F	PARTICIPANT	\N	PRESENT	0
100782	100772	04050C	PARTICIPANT	\N	PRESENT	0
100783	100772	01027Q	PARTICIPANT	\N	PRESENT	0
100784	100772	11100Y	PARTICIPANT	\N	EXCUSE	0
100794	100793	11039M	PARTICIPANT	\N	PRESENT	0
100795	100793	98042T	PARTICIPANT	\N	PRESENT	0
100796	100793	01019Q	PARTICIPANT	\N	PRESENT	0
100798	100797	01008M	PARTICIPANT	\N	PRESENT	0
100799	100797	11036J	PARTICIPANT	\N	PRESENT	0
100839	100797	14038Y	PARTICIPANT	\N	PRESENT	0
100840	100797	01043Q	PARTICIPANT	\N	EXCUSE	0
100802	100797	08068F	PARTICIPANT	\N	PRESENT	0
100803	100797	14207L	PARTICIPANT	\N	PRESENT	0
100804	100797	11101A	PARTICIPANT	\N	PRESENT	0
100805	100797	90003B	PARTICIPANT	\N	PRESENT	0
100806	100797	08028W	PARTICIPANT	\N	EXCUSE	0
100807	100797	80013X	PARTICIPANT	\N	PRESENT	0
100808	100797	08038Y	PARTICIPANT	\N	PRESENT	0
100809	100797	04089T	PARTICIPANT	\N	PRESENT	0
100810	100797	14197C	PARTICIPANT	\N	PRESENT	0
100812	100797	14187A	PARTICIPANT	\N	PRESENT	0
100813	100797	14033T	PARTICIPANT	\N	PRESENT	0
100815	100797	04048J	PARTICIPANT	\N	PRESENT	0
100816	100797	11099A	PARTICIPANT	\N	EXCUSE	0
100902	100899	14093U	PARTICIPANT	\N	PRESENT	0
100903	100899	14030Q	PARTICIPANT	\N	PRESENT	0
100819	100797	11111C	PARTICIPANT	\N	PRESENT	0
100820	100797	08015R	PARTICIPANT	\N	PRESENT	0
100821	100797	11100Y	PRESIDENT	0	PRESENT	0
100822	100797	01061S	PARTICIPANT	\N	EXCUSE	0
100823	100797	11098Y	PARTICIPANT	\N	PRESENT	0
100905	100899	08060W	PARTICIPANT	\N	PRESENT	0
100906	100899	11095V	PARTICIPANT	\N	PRESENT	0
100827	100797	08019V	PARTICIPANT	\N	EXCUSE	0
100828	100797	14257W	PARTICIPANT	\N	PRESENT	0
100830	100797	04088S	PARTICIPANT	\N	PRESENT	0
100831	100797	98050T	PARTICIPANT	\N	PRESENT	0
100907	100899	14038Y	PARTICIPANT	\N	EXCUSE	0
100833	100797	11046L	PARTICIPANT	\N	PRESENT	0
100834	100797	01058X	PARTICIPANT	\N	PRESENT	0
100835	100797	11094U	PARTICIPANT	\N	PRESENT	0
100836	100797	11066Q	PARTICIPANT	\N	PRESENT	0
100908	100899	11114F	PARTICIPANT	\N	PRESENT	0
100910	100899	11065P	PARTICIPANT	\N	PRESENT	0
100911	100899	01015L	PARTICIPANT	\N	PRESENT	0
100912	100899	11107G	PARTICIPANT	\N	PRESENT	0
100914	100899	02002K	PARTICIPANT	\N	PRESENT	0
100915	100899	01022K	PARTICIPANT	\N	PRESENT	0
100916	100899	04097T	PARTICIPANT	\N	PRESENT	0
100917	100899	09001P	PARTICIPANT	\N	PRESENT	0
100918	100899	11059R	PARTICIPANT	\N	PRESENT	0
100919	100899	14219Q	PARTICIPANT	\N	PRESENT	0
100920	100899	80027E	PARTICIPANT	\N	PRESENT	0
100921	100899	14031R	PARTICIPANT	\N	PRESENT	0
100922	100899	08009T	PRESIDENT	0	PRESENT	0
100923	100899	08062Y	PARTICIPANT	\N	PRESENT	0
100925	100899	92039X	PARTICIPANT	\N	PRESENT	0
100926	100899	08042U	PARTICIPANT	\N	PRESENT	0
100927	100899	14169X	PARTICIPANT	\N	PRESENT	0
100928	100899	14237S	PARTICIPANT	\N	PRESENT	0
100929	100899	13002U	PARTICIPANT	\N	PRESENT	0
104721	103115	11012A	PARTICIPANT	\N	PRESENT	0
104722	103115	11064N	PARTICIPANT	\N	PRESENT	0
104723	103115	14030Q	PARTICIPANT	\N	PRESENT	0
104724	103115	07029T	PARTICIPANT	\N	PRESENT	0
104725	103115	89017R	PARTICIPANT	\N	PRESENT	0
104726	103115	14147R	PARTICIPANT	\N	PRESENT	0
104727	103115	14273W	PARTICIPANT	\N	PRESENT	0
104728	103115	12041X	PARTICIPANT	\N	PRESENT	0
104729	103115	01059Y	PARTICIPANT	\N	PRESENT	0
104730	103115	08034U	PARTICIPANT	\N	PRESENT	0
104731	103115	11090Q	PARTICIPANT	\N	PRESENT	0
104732	103115	11043H	PARTICIPANT	\N	PRESENT	0
104733	103115	10015M	PARTICIPANT	\N	PRESENT	0
104734	103115	11044J	PARTICIPANT	\N	PRESENT	0
104735	103115	08053X	PARTICIPANT	\N	PRESENT	0
104736	103115	14329V	PARTICIPANT	\N	PRESENT	0
104737	103115	01025N	PARTICIPANT	\N	PRESENT	0
104738	103115	11112D	PARTICIPANT	\N	PRESENT	0
104739	103115	08015R	PARTICIPANT	\N	PRESENT	0
104740	103115	11077T	PARTICIPANT	\N	PRESENT	0
104752	103115	11089X	PARTICIPANT	\N	PRESENT	0
104753	103115	04097T	PARTICIPANT	\N	PRESENT	0
104754	103115	80013X	PARTICIPANT	\N	PRESENT	0
104755	103115	04049K	PARTICIPANT	\N	PRESENT	0
104756	103115	01057W	PARTICIPANT	\N	PRESENT	0
104757	103115	14031R	PARTICIPANT	\N	PRESENT	0
104758	103115	04033B	PARTICIPANT	\N	PRESENT	0
104759	103115	08039A	PARTICIPANT	\N	PRESENT	0
104760	103115	14257W	PARTICIPANT	\N	PRESENT	0
104761	103115	92031P	PARTICIPANT	\N	PRESENT	0
104762	103115	04050C	PARTICIPANT	\N	PRESENT	0
104763	103115	14217N	PARTICIPANT	\N	PRESENT	0
104764	103115	14195A	PARTICIPANT	\N	PRESENT	0
104765	103115	14281W	PARTICIPANT	\N	PRESENT	0
104766	103115	11066Q	PARTICIPANT	\N	PRESENT	0
104767	103115	14271U	PARTICIPANT	\N	PRESENT	0
104768	103115	14197C	PARTICIPANT	\N	PRESENT	0
104772	103115	14097Y	PARTICIPANT	\N	PRESENT	0
104773	103115	14119M	PARTICIPANT	\N	PRESENT	0
104792	103115	95041E	PARTICIPANT	\N	PRESENT	0
104793	103115	14123H	PARTICIPANT	\N	PRESENT	0
104794	103115	14033T	PARTICIPANT	\N	PRESENT	0
104795	103115	14235Q	PARTICIPANT	\N	PRESENT	0
104796	103115	11056N	PARTICIPANT	\N	PRESENT	0
104797	103115	11098Y	PARTICIPANT	\N	PRESENT	0
104798	103115	92018S	PARTICIPANT	\N	PRESENT	0
104799	103115	14187A	PARTICIPANT	\N	PRESENT	0
104800	103115	92045V	PARTICIPANT	\N	PRESENT	0
104801	103115	11061K	PARTICIPANT	\N	PRESENT	0
104802	103115	14159V	PARTICIPANT	\N	PRESENT	0
104803	103115	14229S	PARTICIPANT	\N	PRESENT	0
104804	103115	08043V	PARTICIPANT	\N	PRESENT	0
104805	103115	11042G	PARTICIPANT	\N	PRESENT	0
104806	103115	11105E	PARTICIPANT	\N	PRESENT	0
104807	103115	04059M	PARTICIPANT	\N	PRESENT	0
104808	103115	98053W	PARTICIPANT	\N	PRESENT	0
104809	103115	14107H	PARTICIPANT	\N	PRESENT	0
104810	103115	11039M	PARTICIPANT	\N	PRESENT	0
104811	103115	14051J	PARTICIPANT	\N	PRESENT	0
104812	103115	14065Q	PARTICIPANT	\N	PRESENT	0
104813	103115	11104D	PARTICIPANT	\N	PRESENT	0
104814	103115	14133K	PARTICIPANT	\N	PRESENT	0
104815	103115	14211G	PARTICIPANT	\N	PRESENT	0
104816	103115	01008M	PARTICIPANT	\N	PRESENT	0
104818	103115	14151M	PARTICIPANT	\N	PRESENT	0
104832	103115	14135M	PARTICIPANT	\N	PRESENT	0
104852	103115	14111D	PARTICIPANT	\N	PRESENT	0
104853	103115	14121F	PARTICIPANT	\N	PRESENT	0
104854	103115	98046X	PARTICIPANT	\N	PRESENT	0
104872	103115	01028R	PARTICIPANT	\N	PRESENT	0
104873	103115	14255U	PARTICIPANT	\N	PRESENT	0
104874	103115	01034P	PARTICIPANT	\N	PRESENT	0
104875	103115	14034U	PARTICIPANT	\N	PRESENT	0
104876	103115	14087W	PARTICIPANT	\N	PRESENT	0
105285	103512	14053L	PARTICIPANT	\N	PRESENT	0
105286	103512	04053F	PARTICIPANT	\N	PRESENT	0
105287	103512	14151M	PARTICIPANT	\N	PRESENT	0
105288	103512	11077T	PARTICIPANT	\N	PRESENT	0
105289	103512	08068F	PARTICIPANT	\N	PRESENT	0
105290	103512	14013P	PARTICIPANT	\N	PRESENT	0
105291	103512	11098Y	PARTICIPANT	\N	PRESENT	0
105292	103512	01011G	PARTICIPANT	\N	PRESENT	0
105293	103512	08043V	PARTICIPANT	\N	PRESENT	0
105294	103512	04067M	PARTICIPANT	\N	PRESENT	0
105295	103512	04045F	PARTICIPANT	\N	PRESENT	0
105296	103512	14121F	PARTICIPANT	\N	PRESENT	0
105297	103512	14239U	PARTICIPANT	\N	PRESENT	0
105298	103512	14037X	PARTICIPANT	\N	PRESENT	0
105299	103512	14219Q	PARTICIPANT	\N	PRESENT	0
105300	103512	11066Q	PARTICIPANT	\N	PRESENT	0
105301	103512	11110B	PARTICIPANT	\N	PRESENT	0
105302	103512	14107H	PARTICIPANT	\N	PRESENT	0
105303	103512	11100Y	PARTICIPANT	\N	PRESENT	0
105304	103512	14030Q	PARTICIPANT	\N	PRESENT	0
105305	103512	14215L	PARTICIPANT	\N	PRESENT	0
105306	103512	04085P	PARTICIPANT	\N	PRESENT	0
105307	103512	11063M	PARTICIPANT	\N	PRESENT	0
105308	103512	01059Y	PARTICIPANT	\N	PRESENT	0
105309	103512	14071N	PARTICIPANT	\N	PRESENT	0
105311	103512	14063N	PARTICIPANT	\N	PRESENT	0
105312	103512	14223L	PARTICIPANT	\N	PRESENT	0
105313	103512	14235Q	PARTICIPANT	\N	PRESENT	0
105314	103512	12042Y	PARTICIPANT	\N	PRESENT	0
105315	103512	04092N	PARTICIPANT	\N	PRESENT	0
105332	103512	14257W	PARTICIPANT	\N	PRESENT	0
105333	103512	14229S	PARTICIPANT	\N	PRESENT	0
105334	103512	11054L	PARTICIPANT	\N	PRESENT	0
105335	103512	14281W	PARTICIPANT	\N	PRESENT	0
105336	103512	08052W	PARTICIPANT	\N	PRESENT	0
105337	103512	01034P	PARTICIPANT	\N	PRESENT	0
105338	103512	04088S	PARTICIPANT	\N	PRESENT	0
105339	103512	11103C	PARTICIPANT	\N	PRESENT	0
105340	103512	14147R	PARTICIPANT	\N	PRESENT	0
105341	103512	14207L	PARTICIPANT	\N	PRESENT	0
105342	103512	98024R	PARTICIPANT	\N	PRESENT	0
105343	103512	14191V	PARTICIPANT	\N	PRESENT	0
105402	103512	11031D	PARTICIPANT	\N	PRESENT	0
105403	103512	14213J	PARTICIPANT	\N	PRESENT	0
105404	103512	01043Q	PARTICIPANT	\N	PRESENT	0
105405	103512	14231L	PARTICIPANT	\N	PRESENT	0
105406	103512	14197C	PARTICIPANT	\N	PRESENT	0
105407	103512	14018U	PARTICIPANT	\N	PRESENT	0
105408	103512	14227Q	PARTICIPANT	\N	PRESENT	0
105409	103512	98050T	PARTICIPANT	\N	PRESENT	0
105410	103512	14193X	PARTICIPANT	\N	PRESENT	0
105411	103512	14269B	PARTICIPANT	\N	PRESENT	0
105412	103512	14109K	PARTICIPANT	\N	PRESENT	0
105413	103512	11067R	PARTICIPANT	\N	PRESENT	0
105414	103512	04059M	PARTICIPANT	\N	PRESENT	0
105415	103512	13002U	PARTICIPANT	\N	PRESENT	0
105474	103512	11089X	PARTICIPANT	\N	PRESENT	0
105475	103512	80027E	PARTICIPANT	\N	PRESENT	0
105476	103512	11059R	PARTICIPANT	\N	PRESENT	0
104719	103115	14207L	PARTICIPANT	\N	PRESENT	0
104720	103115	08068F	PARTICIPANT	\N	PRESENT	0
105477	103512	11011M	PARTICIPANT	\N	PRESENT	0
105478	103512	14038Y	PARTICIPANT	\N	PRESENT	0
105479	103512	07032N	PARTICIPANT	\N	PRESENT	0
105480	103512	14087W	PARTICIPANT	\N	PRESENT	0
105481	103512	08060W	PARTICIPANT	\N	PRESENT	0
105482	103512	07026Q	PARTICIPANT	\N	PRESENT	0
105483	103512	11034G	PARTICIPANT	\N	PRESENT	0
105484	103512	01015L	PARTICIPANT	\N	PRESENT	0
105485	103512	11015D	PARTICIPANT	\N	PRESENT	0
105486	103512	11048N	PARTICIPANT	\N	PRESENT	0
105487	103512	08010L	PARTICIPANT	\N	PRESENT	0
105488	103512	95015C	PARTICIPANT	\N	PRESENT	0
105489	103512	01058X	PARTICIPANT	\N	PRESENT	0
105490	103512	90003B	PARTICIPANT	\N	PRESENT	0
105491	103512	08016S	PARTICIPANT	\N	PRESENT	0
105492	103512	14031R	PARTICIPANT	\N	PRESENT	0
105493	103512	14259Y	PARTICIPANT	\N	PRESENT	0
105494	103512	11107G	PARTICIPANT	\N	PRESENT	0
105495	103512	11093T	PARTICIPANT	\N	PRESENT	0
105497	103512	11091R	PARTICIPANT	\N	PRESENT	0
105498	103512	01003G	PARTICIPANT	\N	PRESENT	0
105499	103512	14263U	PARTICIPANT	\N	PRESENT	0
105500	103512	08015R	PARTICIPANT	\N	PRESENT	0
105501	103512	08051V	PARTICIPANT	\N	PRESENT	0
105502	103512	89017R	PARTICIPANT	\N	PRESENT	0
105503	103512	11104D	PARTICIPANT	\N	PRESENT	0
105504	103512	14034U	PARTICIPANT	\N	PRESENT	0
105505	103512	14026U	PARTICIPANT	\N	PRESENT	0
105506	103512	11029K	PARTICIPANT	\N	PRESENT	0
105507	103512	01044R	PARTICIPANT	\N	PRESENT	0
105508	103512	14267Y	PARTICIPANT	\N	PRESENT	0
105282	103512	04081K	PARTICIPANT	\N	PRESENT	0
105284	103512	14103D	PARTICIPANT	\N	PRESENT	0
100272	100252	01027Q	PARTICIPANT	\N	EXCUSE	0
100273	100252	11107G	PRESIDENT	0	PRESENT	0
100274	100252	12042Y	PARTICIPANT	\N	EXCUSE	0
100275	100252	04086Q	PARTICIPANT	\N	PRESENT	0
100276	100252	14014Q	PARTICIPANT	\N	PRESENT	0
100277	100252	11100Y	PARTICIPANT	\N	PRESENT	0
100278	100252	04092N	PARTICIPANT	\N	EXCUSE	0
103172	103165	04053F	PARTICIPANT	\N	PRESENT	0
103174	103165	14255U	PARTICIPANT	\N	PRESENT	0
103175	103165	04066L	PARTICIPANT	\N	PRESENT	0
103177	103165	11103C	PARTICIPANT	\N	PRESENT	0
103180	103165	11031D	PARTICIPANT	\N	PRESENT	0
103181	103165	08052W	PARTICIPANT	\N	PRESENT	0
103183	103165	01059Y	PARTICIPANT	\N	PRESENT	0
103185	103165	04081K	PARTICIPANT	\N	PRESENT	0
103188	103165	14217N	PARTICIPANT	\N	PRESENT	0
103189	103165	14042U	PARTICIPANT	\N	PRESENT	0
103191	103165	14151M	PARTICIPANT	\N	PRESENT	0
103192	103165	14087W	PARTICIPANT	\N	PRESENT	0
103193	103165	14034U	PARTICIPANT	\N	PRESENT	0
103195	103165	11061K	PARTICIPANT	\N	PRESENT	0
103197	103165	14026U	PARTICIPANT	\N	PRESENT	0
103198	103165	11112D	PARTICIPANT	\N	PRESENT	0
103200	103165	14037X	PARTICIPANT	\N	PRESENT	0
103202	103165	04092N	PRESIDENT	0	PRESENT	0
103204	103165	14119M	PARTICIPANT	\N	PRESENT	0
103206	103165	14071N	PARTICIPANT	\N	PRESENT	0
103209	103165	04043D	PARTICIPANT	\N	PRESENT	0
103211	103165	14271U	PARTICIPANT	\N	PRESENT	0
103212	103165	11093T	PARTICIPANT	\N	PRESENT	0
103214	103165	11097X	PARTICIPANT	\N	PRESENT	0
103216	103165	14227Q	PARTICIPANT	\N	PRESENT	0
103218	103165	01034P	PARTICIPANT	\N	PRESENT	0
103219	103165	14269B	PARTICIPANT	\N	PRESENT	0
103261	103260	14028W	PARTICIPANT	\N	PRESENT	0
103262	103260	01027Q	PARTICIPANT	\N	PRESENT	0
103264	103263	01027Q	PARTICIPANT	\N	PRESENT	0
103265	103263	14028W	PARTICIPANT	\N	PRESENT	0
103267	103266	01027Q	PARTICIPANT	\N	PRESENT	0
103268	103266	14028W	PARTICIPANT	\N	PRESENT	0
103270	103269	01027Q	PARTICIPANT	\N	PRESENT	0
103271	103269	14028W	PARTICIPANT	\N	PRESENT	0
103417	103415	04053F	PARTICIPANT	\N	PRESENT	0
103418	103415	14255U	PARTICIPANT	\N	PRESENT	0
103419	103415	04066L	PARTICIPANT	\N	PRESENT	0
103420	103415	11103C	PARTICIPANT	\N	PRESENT	0
103421	103415	11031D	PARTICIPANT	\N	PRESENT	0
103422	103415	08052W	PARTICIPANT	\N	PRESENT	0
103423	103415	14217N	PARTICIPANT	\N	PRESENT	0
103424	103415	14042U	PARTICIPANT	\N	PRESENT	0
103425	103415	14151M	PARTICIPANT	\N	PRESENT	0
103426	103415	14087W	PARTICIPANT	\N	PRESENT	0
103427	103415	14034U	PARTICIPANT	\N	PRESENT	0
103428	103415	11061K	PARTICIPANT	\N	PRESENT	0
103429	103415	14026U	PARTICIPANT	\N	PRESENT	0
103430	103415	11112D	PARTICIPANT	\N	PRESENT	0
103431	103415	14037X	PARTICIPANT	\N	PRESENT	0
103432	103415	11067R	PARTICIPANT	\N	PRESENT	0
103433	103415	14223L	PARTICIPANT	\N	PRESENT	0
103434	103415	04092N	PRESIDENT	0	PRESENT	0
103435	103415	14265W	PARTICIPANT	\N	PRESENT	0
103436	103415	14119M	PARTICIPANT	\N	PRESENT	0
103437	103415	14071N	PARTICIPANT	\N	PRESENT	0
103438	103415	14271U	PARTICIPANT	\N	PRESENT	0
103439	103415	11093T	PARTICIPANT	\N	PRESENT	0
103440	103415	11097X	PARTICIPANT	\N	PRESENT	0
103441	103415	04045F	PARTICIPANT	\N	PRESENT	0
103442	103415	14227Q	PARTICIPANT	\N	PRESENT	0
103444	103415	01034P	PARTICIPANT	\N	PRESENT	0
103445	103415	14269B	PARTICIPANT	\N	PRESENT	0
107133	107132	04040A	PARTICIPANT	\N	PRESENT	0
107134	107132	08038Y	PARTICIPANT	\N	PRESENT	0
107135	107132	11101A	PARTICIPANT	\N	PRESENT	0
107136	107132	05012A	PARTICIPANT	\N	PRESENT	0
108373	108372	01031L	PRESIDENT	0	PRESENT	0
108374	108372	05004A	PARTICIPANT	\N	PRESENT	0
108375	108372	01013J	PARTICIPANT	\N	PRESENT	0
108376	108372	11068S	PARTICIPANT	\N	EXCUSE	0
108377	108372	11040E	PARTICIPANT	\N	PRESENT	0
108378	108372	08014Q	PARTICIPANT	\N	PRESENT	0
108379	108372	14167V	PARTICIPANT	\N	PRESENT	0
108380	108372	14175V	PARTICIPANT	\N	PRESENT	0
108381	108372	14083S	PARTICIPANT	\N	PRESENT	0
108382	108372	11053K	PARTICIPANT	\N	PRESENT	0
108383	108372	14085U	PARTICIPANT	\N	PRESENT	0
108384	108372	11042G	PARTICIPANT	\N	PRESENT	0
108385	108372	88008L	PARTICIPANT	\N	PRESENT	0
108386	108372	11070L	PARTICIPANT	\N	PRESENT	0
108387	108372	11088W	PARTICIPANT	\N	PRESENT	0
108388	108372	14327T	PARTICIPANT	\N	PRESENT	0
108389	108372	08022Q	PARTICIPANT	\N	PRESENT	0
108390	108372	01027Q	PARTICIPANT	\N	EXCUSE	0
108391	108372	04071H	PARTICIPANT	\N	PRESENT	0
108392	108372	11074Q	PARTICIPANT	\N	PRESENT	0
108393	108372	11083R	PARTICIPANT	\N	PRESENT	0
108394	108372	14199E	PARTICIPANT	\N	PRESENT	0
108395	108372	01057W	PARTICIPANT	\N	PRESENT	0
108396	108372	08016S	PARTICIPANT	\N	PRESENT	0
108397	108372	08069G	PARTICIPANT	\N	PRESENT	0
108398	108372	11048N	PARTICIPANT	\N	PRESENT	0
108399	108372	14159V	PARTICIPANT	\N	PRESENT	0
108400	108372	07029T	PARTICIPANT	\N	PRESENT	0
108401	108372	08034U	PARTICIPANT	\N	PRESENT	0
108402	108372	01048V	PARTICIPANT	\N	PRESENT	0
108403	108372	98046X	PARTICIPANT	\N	PRESENT	0
108404	108372	11085T	PARTICIPANT	\N	EXCUSE	0
108405	108372	08011M	PARTICIPANT	\N	PRESENT	0
108406	108372	08073C	PARTICIPANT	\N	PRESENT	0
108407	108372	08061X	PARTICIPANT	\N	PRESENT	0
108408	108372	01016M	PARTICIPANT	\N	PRESENT	0
108409	108372	14225N	PARTICIPANT	\N	PRESENT	0
108410	108372	11012A	PARTICIPANT	\N	EXCUSE	0
108411	108372	11057P	PARTICIPANT	\N	PRESENT	0
108424	108372	14173T	PARTICIPANT	\N	PRESENT	0
108515	108512	11029K	PARTICIPANT	\N	PRESENT	0
108513	108512	11043H	PARTICIPANT	\N	PRESENT	0
108514	108512	11039M	PARTICIPANT	\N	PRESENT	0
108516	108512	14061L	PARTICIPANT	\N	PRESENT	0
108517	108512	08012N	PARTICIPANT	\N	PRESENT	0
108518	108512	11014C	PARTICIPANT	\N	PRESENT	0
110098	110097	14167V	PARTICIPANT	\N	PRESENT	0
110099	110097	14175V	PARTICIPANT	\N	PRESENT	0
110100	110097	98046X	PARTICIPANT	\N	PRESENT	0
110101	110097	14199E	PARTICIPANT	\N	PRESENT	0
110102	110097	01057W	PARTICIPANT	\N	PRESENT	0
110103	110097	04086Q	PARTICIPANT	\N	PRESENT	0
110104	110097	11070L	PARTICIPANT	\N	PRESENT	0
110105	110097	11088W	PARTICIPANT	\N	PRESENT	0
110106	110097	08073C	PARTICIPANT	\N	PRESENT	0
110107	110097	14225N	PARTICIPANT	\N	PRESENT	0
110108	110097	01013J	PARTICIPANT	\N	PRESENT	0
112181	112180	11055M	PARTICIPANT	\N	PRESENT	0
112182	112180	08043V	PARTICIPANT	\N	PRESENT	0
112183	112180	14053L	PARTICIPANT	\N	PRESENT	0
112184	112180	95015C	PARTICIPANT	\N	PRESENT	0
112396	112394	08022Q	PARTICIPANT	\N	PRESENT	0
112186	112180	11027H	PARTICIPANT	\N	PRESENT	0
112393	112392	14173T	PARTICIPANT	\N	PRESENT	0
112395	112394	01016M	PARTICIPANT	\N	PRESENT	0
112413	112412	11085T	PARTICIPANT	\N	PRESENT	0
112415	112414	01031L	PARTICIPANT	\N	PRESENT	0
112913	112912	14199E	PARTICIPANT	\N	PRESENT	0
112918	112917	14199E	PARTICIPANT	\N	PRESENT	0
112920	112919	14199E	PARTICIPANT	\N	PRESENT	0
112194	112180	04035D	PARTICIPANT	\N	PRESENT	0
112195	112180	14231L	PARTICIPANT	\N	PRESENT	0
112196	112180	14179A	PARTICIPANT	\N	PRESENT	0
112922	112921	14199E	PARTICIPANT	\N	PRESENT	0
112924	112923	11053K	PARTICIPANT	\N	PRESENT	0
112199	112180	11100Y	PRESIDENT	0	PRESENT	0
112981	112496	11040E	PARTICIPANT	\N	PRESENT	0
112201	112180	08012N	PARTICIPANT	\N	PRESENT	0
112982	112496	14033T	PARTICIPANT	\N	PRESENT	0
112983	112496	05008E	PARTICIPANT	\N	PRESENT	0
112206	112180	11090Q	PARTICIPANT	\N	PRESENT	0
112988	112496	04044E	PARTICIPANT	\N	PRESENT	0
112989	112496	01044R	PARTICIPANT	\N	PRESENT	0
112990	112496	07004J	PARTICIPANT	\N	PRESENT	0
112991	112496	04038G	PARTICIPANT	\N	PRESENT	0
112213	112180	14157T	PARTICIPANT	\N	PRESENT	0
112215	112180	11066Q	PARTICIPANT	\N	PRESENT	0
112216	112180	14269B	PARTICIPANT	\N	PRESENT	0
112994	112496	04049K	PARTICIPANT	\N	PRESENT	0
94525	91448	11025F	PARTICIPANT	\N	PRESENT	0
97533	97532	11103C	PARTICIPANT	\N	PRESENT	0
97534	97532	92045V	PARTICIPANT	\N	PRESENT	0
119507	119497	14265W	PARTICIPANT	\N	EXCUSE	0
119508	119497	04043D	PARTICIPANT	\N	EXCUSE	0
119509	119497	01056V	PARTICIPANT	\N	EXCUSE	0
119510	119497	08049C	PARTICIPANT	\N	EXCUSE	0
119518	119517	14083S	PARTICIPANT	\N	PRESENT	0
119520	119519	14083S	PARTICIPANT	\N	PRESENT	0
119522	119521	14083S	PARTICIPANT	\N	PRESENT	0
119524	119523	14083S	PARTICIPANT	\N	PRESENT	0
119526	119525	14083S	PARTICIPANT	\N	PRESENT	0
119528	119527	14083S	PARTICIPANT	\N	PRESENT	0
119530	119529	14175V	PARTICIPANT	\N	PRESENT	0
119531	119529	14085U	PARTICIPANT	\N	PRESENT	0
119573	119572	04067M	PARTICIPANT	\N	PRESENT	0
119574	119572	14037X	PARTICIPANT	\N	PRESENT	0
119575	119572	83047W	PARTICIPANT	\N	PRESENT	0
119576	119572	01034P	PARTICIPANT	\N	PRESENT	0
119577	119572	14079W	PARTICIPANT	\N	EXCUSE	0
119578	119572	14121F	PARTICIPANT	\N	EXCUSE	0
119585	119584	14135M	PARTICIPANT	\N	PRESENT	0
119586	119584	11083R	PARTICIPANT	\N	PRESENT	0
119587	119584	97011G	PARTICIPANT	\N	PRESENT	0
119588	119584	08069G	PARTICIPANT	\N	PRESENT	0
119589	119584	11068S	PARTICIPANT	\N	PRESENT	0
119590	119584	09001P	PARTICIPANT	\N	PRESENT	0
119591	119584	08025T	PARTICIPANT	\N	PRESENT	0
119592	119584	04036E	PARTICIPANT	\N	PRESENT	0
119593	119584	14239U	PARTICIPANT	\N	PRESENT	0
119594	119584	01037S	PARTICIPANT	\N	PRESENT	0
119595	119584	01028R	PARTICIPANT	\N	PRESENT	0
119596	119584	04067M	PARTICIPANT	\N	PRESENT	0
119597	119584	04070G	PARTICIPANT	\N	PRESENT	0
119614	119612	08060W	PARTICIPANT	\N	EXCUSE	0
119600	119598	11027H	PARTICIPANT	\N	PRESENT	0
119613	119612	08043V	PARTICIPANT	\N	EXCUSE	0
119615	119612	11029K	PARTICIPANT	\N	PRESENT	0
119616	119612	11031D	PARTICIPANT	\N	PRESENT	0
119617	119612	80013X	PARTICIPANT	\N	EXCUSE	0
119618	119612	14041T	PARTICIPANT	\N	EXCUSE	0
119619	119612	04041B	PARTICIPANT	\N	PRESENT	0
119620	119612	09001P	PRESIDENT	0	PRESENT	0
119621	119612	14241N	PARTICIPANT	\N	EXCUSE	0
119622	119612	04036E	PARTICIPANT	\N	PRESENT	0
119623	119612	08031R	PARTICIPANT	\N	PRESENT	0
119624	119612	14031R	PARTICIPANT	\N	EXCUSE	0
119625	119612	11014C	PARTICIPANT	\N	EXCUSE	0
119626	119612	14265W	PARTICIPANT	\N	EXCUSE	0
119627	119612	14237S	PARTICIPANT	\N	EXCUSE	0
119634	119633	14263U	PARTICIPANT	\N	PRESENT	0
119635	119633	14133K	PARTICIPANT	\N	PRESENT	0
119636	119632	89017R	PARTICIPANT	\N	PRESENT	0
119637	119633	04059M	PARTICIPANT	\N	PRESENT	0
119638	119633	11039M	PARTICIPANT	\N	PRESENT	0
119639	119632	01031L	PRESIDENT	0	PRESENT	0
119640	119633	01044R	PARTICIPANT	\N	EXCUSE	0
119641	119633	14089Y	PARTICIPANT	\N	PRESENT	0
119642	119633	14105F	PARTICIPANT	\N	EXCUSE	0
119643	119632	11068S	PARTICIPANT	\N	PRESENT	0
119644	119633	11029K	PARTICIPANT	\N	EXCUSE	0
119645	119633	95015C	PRESIDENT	1	PRESENT	0
119646	119632	11040E	PARTICIPANT	\N	PRESENT	0
119647	119633	92015P	PARTICIPANT	\N	EXCUSE	0
119648	119632	08014Q	PARTICIPANT	\N	PRESENT	0
119649	119633	08024S	PARTICIPANT	\N	EXCUSE	0
119650	119632	14175V	PARTICIPANT	\N	EXCUSE	0
119651	119633	14201E	PARTICIPANT	\N	EXCUSE	0
119652	119632	11053K	PARTICIPANT	\N	PRESENT	0
119653	119632	14085U	PARTICIPANT	\N	PRESENT	0
119654	119632	11042G	PARTICIPANT	\N	PRESENT	0
119655	119632	04086Q	PARTICIPANT	\N	PRESENT	0
119656	119632	04055H	PARTICIPANT	\N	PRESENT	0
119657	119633	14329V	PARTICIPANT	\N	PRESENT	0
119658	119633	14209N	PARTICIPANT	\N	PRESENT	0
119659	119633	11091R	PARTICIPANT	\N	PRESENT	0
119660	119633	98042T	PARTICIPANT	\N	PRESENT	0
119661	119633	14249W	PARTICIPANT	\N	EXCUSE	0
119662	119633	01041N	PARTICIPANT	\N	PRESENT	0
119663	119633	01025N	PARTICIPANT	\N	PRESENT	0
119664	119633	01037S	PARTICIPANT	\N	PRESENT	0
119665	119633	11089X	PARTICIPANT	\N	PRESENT	0
119666	119633	14123H	PARTICIPANT	\N	PRESENT	0
119667	119633	14179A	PARTICIPANT	\N	PRESENT	0
119668	119633	14241N	PARTICIPANT	\N	PRESENT	0
119669	119633	14061L	PARTICIPANT	\N	EXCUSE	0
119670	119633	14073Q	PARTICIPANT	\N	PRESENT	0
119671	119633	12041X	PARTICIPANT	\N	EXCUSE	0
119672	119633	08039A	PARTICIPANT	\N	PRESENT	0
119673	119633	08017T	PARTICIPANT	\N	PRESENT	0
119674	119633	14059S	PARTICIPANT	\N	PRESENT	0
119675	119633	08012N	PARTICIPANT	\N	PRESENT	0
119676	119633	11104D	PARTICIPANT	\N	PRESENT	0
119677	119633	04057K	PARTICIPANT	\N	PRESENT	0
119678	119633	11014C	PARTICIPANT	\N	PRESENT	0
119679	119633	14109K	PARTICIPANT	\N	PRESENT	0
119680	119633	04070G	PRESIDENT	0	PRESENT	0
119681	119633	92040Q	PARTICIPANT	\N	PRESENT	0
119682	119633	83047W	PARTICIPANT	\N	PRESENT	0
119683	119633	14235Q	PARTICIPANT	\N	EXCUSE	0
119684	119633	04033B	PARTICIPANT	\N	PRESENT	0
119685	119633	14229S	PARTICIPANT	\N	PRESENT	0
119686	119632	11070L	PARTICIPANT	\N	PRESENT	0
119687	119632	11088W	PARTICIPANT	\N	PRESENT	0
119688	119632	14327T	PARTICIPANT	\N	PRESENT	0
119689	119632	08022Q	PARTICIPANT	\N	PRESENT	0
119690	119632	01027Q	PARTICIPANT	\N	PRESENT	0
119692	119691	14133K	PARTICIPANT	\N	PRESENT	0
119693	119691	04059M	PARTICIPANT	\N	PRESENT	0
119694	119691	11039M	PARTICIPANT	\N	PRESENT	0
119695	119691	01044R	PARTICIPANT	\N	EXCUSE	0
119696	119691	14105F	PARTICIPANT	\N	EXCUSE	0
119697	119691	11029K	PARTICIPANT	\N	EXCUSE	0
119698	119691	95015C	PARTICIPANT	\N	PRESENT	0
119699	119691	92015P	PARTICIPANT	\N	EXCUSE	0
119700	119691	08024S	PARTICIPANT	\N	EXCUSE	0
119701	119691	14201E	PARTICIPANT	\N	EXCUSE	0
119702	119691	14329V	PARTICIPANT	\N	PRESENT	0
119703	119691	14209N	PARTICIPANT	\N	PRESENT	0
119704	119691	11091R	PARTICIPANT	\N	PRESENT	0
119705	119691	14249W	PARTICIPANT	\N	EXCUSE	0
119706	119691	01041N	PARTICIPANT	\N	PRESENT	0
119707	119691	01025N	PARTICIPANT	\N	PRESENT	0
119708	119691	01037S	PARTICIPANT	\N	PRESENT	0
119709	119691	11089X	PARTICIPANT	\N	PRESENT	0
119710	119691	14123H	PARTICIPANT	\N	PRESENT	0
119711	119691	14179A	PARTICIPANT	\N	PRESENT	0
119712	119691	14241N	PARTICIPANT	\N	PRESENT	0
119713	119691	14061L	PARTICIPANT	\N	EXCUSE	0
119714	119691	14073Q	PARTICIPANT	\N	PRESENT	0
119715	119691	08031R	PARTICIPANT	\N	PRESENT	0
119716	119691	12041X	PARTICIPANT	\N	EXCUSE	0
119717	119691	08039A	PARTICIPANT	\N	PRESENT	0
119718	119691	08017T	PARTICIPANT	\N	PRESENT	0
119719	119691	14059S	PARTICIPANT	\N	PRESENT	0
119720	119691	08012N	PARTICIPANT	\N	PRESENT	0
119721	119691	11104D	PARTICIPANT	\N	PRESENT	0
119722	119691	04057K	PARTICIPANT	\N	PRESENT	0
119723	119691	11014C	PARTICIPANT	\N	PRESENT	0
119724	119691	14109K	PARTICIPANT	\N	PRESENT	0
119725	119691	04070G	PRESIDENT	0	PRESENT	0
119726	119691	83047W	PARTICIPANT	\N	PRESENT	0
119727	119691	14235Q	PARTICIPANT	\N	EXCUSE	0
119728	119691	14229S	PARTICIPANT	\N	PRESENT	0
119729	119691	11043H	PARTICIPANT	\N	PRESENT	0
119731	119730	04085P	PARTICIPANT	\N	PRESENT	0
119732	119730	05008E	PRESIDENT	0	PRESENT	0
119733	119730	11033F	PARTICIPANT	\N	PRESENT	0
119734	119730	14065Q	PARTICIPANT	\N	PRESENT	0
119735	119730	14069U	PARTICIPANT	\N	PRESENT	0
119736	119730	04047H	PARTICIPANT	\N	PRESENT	0
119737	119730	11056N	PARTICIPANT	\N	PRESENT	0
119738	119730	14259Y	PARTICIPANT	\N	PRESENT	0
119739	119730	11035H	PARTICIPANT	\N	PRESENT	0
119740	119730	14041T	PARTICIPANT	\N	EXCUSE	0
119741	119730	11113E	PARTICIPANT	\N	PRESENT	0
119742	119730	01024M	PARTICIPANT	\N	PRESENT	0
119743	119730	14215L	PARTICIPANT	\N	PRESENT	0
119744	119730	08018U	PARTICIPANT	\N	EXCUSE	0
119745	119730	11010L	PARTICIPANT	\N	PRESENT	0
119746	119730	01007L	PARTICIPANT	\N	PRESENT	0
119747	119730	11084S	PARTICIPANT	\N	PRESENT	0
119748	119730	11026G	PARTICIPANT	\N	PRESENT	0
119749	119730	04079R	PARTICIPANT	\N	PRESENT	0
119750	119730	14273W	PARTICIPANT	\N	PRESENT	0
119751	119730	14147R	PARTICIPANT	\N	PRESENT	0
119752	119730	95049N	PARTICIPANT	\N	PRESENT	0
119753	119730	08051V	PARTICIPANT	\N	PRESENT	0
119754	119730	11072N	PARTICIPANT	\N	PRESENT	0
98952	98894	98035U	PARTICIPANT	\N	PRESENT	0
100930	100899	05012A	PARTICIPANT	\N	PRESENT	0
98897	98894	04040A	PARTICIPANT	\N	PRESENT	0
98898	98894	08058D	PARTICIPANT	\N	PRESENT	0
98899	98894	04042C	PARTICIPANT	\N	PRESENT	0
98900	98894	77002U	PARTICIPANT	\N	PRESENT	0
100931	100899	14247U	PARTICIPANT	\N	PRESENT	0
99295	99292	04040A	PARTICIPANT	\N	PRESENT	0
98903	98894	11027H	PARTICIPANT	\N	PRESENT	0
98904	98894	98018T	PARTICIPANT	\N	PRESENT	0
99296	99292	08058D	PARTICIPANT	\N	PRESENT	0
98906	98894	92020L	PARTICIPANT	\N	PRESENT	0
98907	98894	95030B	PARTICIPANT	\N	PRESENT	0
98908	98894	11096W	PARTICIPANT	\N	PRESENT	0
98909	98894	95031C	PARTICIPANT	\N	PRESENT	0
98910	98894	97011G	PARTICIPANT	\N	PRESENT	0
98911	98894	08065C	PARTICIPANT	\N	PRESENT	0
98912	98894	04035D	PARTICIPANT	\N	PRESENT	0
98913	98894	07024N	PARTICIPANT	\N	PRESENT	0
99297	99292	04042C	PARTICIPANT	\N	PRESENT	0
98915	98894	14014Q	PARTICIPANT	\N	PRESENT	0
98916	98894	11015D	PARTICIPANT	\N	PRESENT	0
98917	98894	07004J	PARTICIPANT	\N	EXCUSE	0
98918	98894	95035G	PARTICIPANT	\N	PRESENT	0
98919	98894	08056B	PARTICIPANT	\N	PRESENT	0
98920	98894	14211G	PARTICIPANT	\N	PRESENT	0
98921	98894	98022P	PARTICIPANT	\N	PRESENT	0
98922	98894	11064N	PARTICIPANT	\N	PRESENT	0
98923	98894	95037J	PARTICIPANT	\N	PRESENT	0
98924	98894	04078Q	PARTICIPANT	\N	PRESENT	0
98925	98894	14097Y	PARTICIPANT	\N	PRESENT	0
98926	98894	95041E	PARTICIPANT	\N	PRESENT	0
98927	98894	04036E	PARTICIPANT	\N	PRESENT	0
99298	99292	77002U	PARTICIPANT	\N	PRESENT	0
98929	98894	04077P	PARTICIPANT	\N	PRESENT	0
100932	100899	14135M	PARTICIPANT	\N	PRESENT	0
98931	98894	92031P	PARTICIPANT	\N	PRESENT	0
98932	98894	11106F	PARTICIPANT	\N	EXCUSE	0
98933	98894	14251Q	PARTICIPANT	\N	PRESENT	0
98934	98894	83042R	PARTICIPANT	\N	PRESENT	0
98935	98894	08053X	PARTICIPANT	\N	PRESENT	0
98936	98894	11082Q	PARTICIPANT	\N	PRESENT	0
98937	98894	11105E	PARTICIPANT	\N	EXCUSE	0
98938	98894	14253S	PARTICIPANT	\N	PRESENT	0
98939	98894	08047A	PARTICIPANT	\N	PRESENT	0
98940	98894	14028W	PARTICIPANT	\N	PRESENT	0
98941	98894	14193X	PARTICIPANT	\N	PRESENT	0
98942	98894	98021N	PARTICIPANT	\N	PRESENT	0
98943	98894	04080J	PARTICIPANT	\N	PRESENT	0
98944	98894	95059Q	PRESIDENT	0	PRESENT	0
98945	98894	86044G	PARTICIPANT	\N	PRESENT	0
98946	98894	01014K	PARTICIPANT	\N	PRESENT	0
98947	98894	11054L	PARTICIPANT	\N	PRESENT	0
98948	98894	01056V	PARTICIPANT	\N	PRESENT	0
98949	98894	92044U	PARTICIPANT	\N	PRESENT	0
100933	100899	14331P	PARTICIPANT	\N	PRESENT	0
98951	98894	04050C	PARTICIPANT	\N	PRESENT	0
99301	99292	11027H	PARTICIPANT	\N	PRESENT	0
99302	99292	98018T	PARTICIPANT	\N	PRESENT	0
100934	100899	95062K	PARTICIPANT	\N	EXCUSE	0
99304	99292	92020L	PARTICIPANT	\N	PRESENT	0
99305	99292	95030B	PARTICIPANT	\N	PRESENT	0
102117	102090	14257W	PARTICIPANT	\N	PRESENT	0
100936	100899	14051J	PARTICIPANT	\N	PRESENT	0
99308	99292	97011G	PARTICIPANT	\N	PRESENT	0
100937	100899	14157T	PARTICIPANT	\N	PRESENT	0
99310	99292	04035D	PARTICIPANT	\N	PRESENT	0
99311	99292	07024N	PARTICIPANT	\N	PRESENT	0
100938	100899	96003C	PARTICIPANT	\N	EXCUSE	0
99313	99292	14014Q	PARTICIPANT	\N	PRESENT	0
101421	101420	98024R	PARTICIPANT	\N	PRESENT	0
99315	99292	07004J	PARTICIPANT	\N	EXCUSE	0
99316	99292	95035G	PARTICIPANT	\N	PRESENT	0
99317	99292	08056B	PARTICIPANT	\N	PRESENT	0
102118	102090	04088S	PARTICIPANT	\N	PRESENT	0
102119	102090	98050T	PARTICIPANT	\N	PRESENT	0
99320	99292	11064N	PARTICIPANT	\N	PRESENT	0
102120	102090	11046L	PARTICIPANT	\N	PRESENT	0
99322	99292	04078Q	PARTICIPANT	\N	PRESENT	0
99323	99292	14097Y	PARTICIPANT	\N	PRESENT	0
102121	102090	01058X	PARTICIPANT	\N	PRESENT	0
99325	99292	04036E	PARTICIPANT	\N	PRESENT	0
99326	99292	14039A	PARTICIPANT	\N	EXCUSE	0
102122	102090	11066Q	PARTICIPANT	\N	PRESENT	0
102123	102090	11109J	PARTICIPANT	\N	PRESENT	0
99329	99292	92031P	PARTICIPANT	\N	PRESENT	0
99330	99292	11106F	PARTICIPANT	\N	EXCUSE	0
102124	102090	11029K	PARTICIPANT	\N	PRESENT	0
102125	102090	95015C	PARTICIPANT	\N	PRESENT	0
102126	102090	92015P	PARTICIPANT	\N	PRESENT	0
102127	102090	14209N	PARTICIPANT	\N	PRESENT	0
99335	99292	11105E	PARTICIPANT	\N	EXCUSE	0
102128	102090	07026Q	PARTICIPANT	\N	PRESENT	0
102129	102090	14061L	PARTICIPANT	\N	PRESENT	0
102130	102090	14059S	PARTICIPANT	\N	PRESENT	0
102131	102090	08012N	PARTICIPANT	\N	PRESENT	0
99340	99292	98021N	PARTICIPANT	\N	PRESENT	0
99341	99292	04080J	PARTICIPANT	\N	PRESENT	0
99342	99292	95059Q	PRESIDENT	0	PRESENT	0
102132	102090	14109K	PARTICIPANT	\N	PRESENT	0
99344	99292	01014K	PARTICIPANT	\N	PRESENT	0
99345	99292	11054L	PARTICIPANT	\N	PRESENT	0
102133	102090	04070G	PARTICIPANT	\N	PRESENT	0
99347	99292	92044U	PARTICIPANT	\N	PRESENT	0
102134	102090	11011M	PARTICIPANT	\N	PRESENT	0
102135	102090	11089X	PARTICIPANT	\N	PRESENT	0
102858	102857	11039M	PARTICIPANT	\N	PRESENT	0
102859	102857	08012N	PARTICIPANT	\N	PRESENT	0
102860	102857	14073Q	PARTICIPANT	\N	PRESENT	0
102861	102857	14235Q	PARTICIPANT	\N	PRESENT	0
102913	102912	98046X	PARTICIPANT	\N	PRESENT	0
102915	102914	98046X	PARTICIPANT	\N	PRESENT	0
102917	102916	98046X	PARTICIPANT	\N	PRESENT	0
102919	102918	98046X	PARTICIPANT	\N	PRESENT	0
102921	102920	98046X	PARTICIPANT	\N	PRESENT	0
102923	102922	98046X	PARTICIPANT	\N	PRESENT	0
102933	102932	98046X	PARTICIPANT	\N	PRESENT	0
102935	102934	98046X	PARTICIPANT	\N	PRESENT	0
102937	102936	98046X	PARTICIPANT	\N	PRESENT	0
103117	103116	04049K	PARTICIPANT	\N	PRESENT	0
103133	103132	08014Q	PARTICIPANT	\N	PRESENT	0
103134	103132	08069G	PARTICIPANT	\N	PRESENT	0
103235	103234	11015D	PARTICIPANT	\N	PRESENT	0
103236	103234	92031P	PARTICIPANT	\N	PRESENT	0
103572	103112	98053W	PARTICIPANT	\N	PRESENT	0
103573	103112	14037X	PARTICIPANT	\N	PRESENT	0
103574	103112	14247U	PARTICIPANT	\N	PRESENT	0
103575	103112	11054L	PARTICIPANT	\N	PRESENT	0
103576	103112	11074Q	PARTICIPANT	\N	PRESENT	0
103577	103112	14331P	PARTICIPANT	\N	PRESENT	0
103579	103112	14061L	PARTICIPANT	\N	PRESENT	0
103580	103112	14014Q	PARTICIPANT	\N	PRESENT	0
103581	103112	86044G	PARTICIPANT	\N	PRESENT	0
103582	103112	14267Y	PARTICIPANT	\N	PRESENT	0
103583	103112	01059Y	PARTICIPANT	\N	PRESENT	0
103584	103112	11063M	PARTICIPANT	\N	PRESENT	0
103585	103112	08052W	PARTICIPANT	\N	PRESENT	0
103586	103112	14173T	PARTICIPANT	\N	PRESENT	0
103587	103112	98046X	PARTICIPANT	\N	PRESENT	0
103588	103112	11066Q	PARTICIPANT	\N	PRESENT	0
103589	103112	04089T	PARTICIPANT	\N	PRESENT	0
103590	103112	09001P	PARTICIPANT	\N	PRESENT	0
103591	103112	14089Y	PARTICIPANT	\N	PRESENT	0
103592	103112	14103D	PARTICIPANT	\N	PRESENT	0
103593	103112	11037K	PARTICIPANT	\N	PRESENT	0
103594	103112	11042G	PARTICIPANT	\N	PRESENT	0
103595	103112	08043V	PARTICIPANT	\N	PRESENT	0
103596	103112	14151M	PARTICIPANT	\N	PRESENT	0
103597	103112	14213J	PARTICIPANT	\N	PRESENT	0
103598	103112	08015R	PARTICIPANT	\N	PRESENT	0
103599	103112	04053F	PARTICIPANT	\N	PRESENT	0
103600	103112	13002U	PARTICIPANT	\N	PRESENT	0
103601	103112	11067R	PARTICIPANT	\N	PRESENT	0
103602	103112	14111D	PARTICIPANT	\N	PRESENT	0
103603	103112	01013J	PARTICIPANT	\N	PRESENT	0
103604	103112	11031D	PARTICIPANT	\N	PRESENT	0
103605	103112	08053X	PARTICIPANT	\N	PRESENT	0
103606	103112	11029K	PARTICIPANT	\N	PRESENT	0
103607	103112	14018U	PARTICIPANT	\N	PRESENT	0
103608	103112	08049C	PARTICIPANT	\N	PRESENT	0
103609	103112	08031R	PARTICIPANT	\N	PRESENT	0
103610	103112	14231L	PARTICIPANT	\N	PRESENT	0
103611	103112	14215L	PARTICIPANT	\N	PRESENT	0
103612	103112	04092N	PARTICIPANT	\N	PRESENT	0
103613	103112	14087W	PARTICIPANT	\N	PRESENT	0
103614	103112	11100Y	PARTICIPANT	\N	PRESENT	0
103615	103112	14147R	PARTICIPANT	\N	PRESENT	0
103616	103112	07032N	PARTICIPANT	\N	PRESENT	0
106915	106914	14030Q	PARTICIPANT	\N	PRESENT	0
105113	105072	08011M	PARTICIPANT	\N	PRESENT	0
106916	106914	14237S	PARTICIPANT	\N	PRESENT	0
105115	105072	08061X	PARTICIPANT	\N	PRESENT	0
105116	105072	01016M	PARTICIPANT	\N	PRESENT	0
105117	105072	14225N	PARTICIPANT	\N	PRESENT	0
105118	105072	11012A	PARTICIPANT	\N	PRESENT	0
105119	105072	11057P	PARTICIPANT	\N	PRESENT	0
105120	105072	14173T	PARTICIPANT	\N	PRESENT	0
105121	105072	04034C	PARTICIPANT	\N	PRESENT	0
105283	104995	98018T	PARTICIPANT	\N	PRESENT	0
106917	106914	14105F	PARTICIPANT	\N	PRESENT	0
106919	106914	14073Q	PARTICIPANT	\N	PRESENT	0
106920	106914	14219Q	PARTICIPANT	\N	PRESENT	0
106921	106914	14221J	PARTICIPANT	\N	PRESENT	0
106953	106952	14097Y	PARTICIPANT	\N	PRESENT	0
106955	106954	99004R	PARTICIPANT	\N	PRESENT	0
106973	106972	01024M	PARTICIPANT	\N	PRESENT	0
106993	106992	01044R	PARTICIPANT	\N	PRESENT	0
106994	106992	11091R	PARTICIPANT	\N	PRESENT	0
106995	106992	01041N	PARTICIPANT	\N	PRESENT	0
106996	106992	08017T	PARTICIPANT	\N	PRESENT	0
107013	107012	07034Q	PARTICIPANT	\N	PRESENT	0
107015	107014	07034Q	PARTICIPANT	\N	PRESENT	0
107017	107016	11074Q	PARTICIPANT	\N	PRESENT	0
107019	107018	11085T	PARTICIPANT	\N	PRESENT	0
107021	107020	08014Q	PARTICIPANT	\N	PRESENT	0
107022	107020	08069G	PARTICIPANT	\N	PRESENT	0
107735	106488	14028W	PARTICIPANT	\N	EXCUSE	0
108413	108412	14263U	PARTICIPANT	\N	PRESENT	0
108414	108412	04059M	PARTICIPANT	\N	PRESENT	0
108415	108412	01044R	PARTICIPANT	\N	PRESENT	0
108416	108412	08043V	PARTICIPANT	\N	EXCUSE	0
108417	108412	14089Y	PARTICIPANT	\N	PRESENT	0
108418	108412	14105F	PARTICIPANT	\N	PRESENT	0
108419	108412	11029K	PARTICIPANT	\N	PRESENT	0
108420	108412	92015P	PARTICIPANT	\N	EXCUSE	0
108421	108412	08024S	PARTICIPANT	\N	PRESENT	0
108422	108412	14201E	PARTICIPANT	\N	PRESENT	0
108466	108412	14209N	PARTICIPANT	\N	PRESENT	0
108467	108412	11091R	PARTICIPANT	\N	PRESENT	0
108468	108412	87003B	PARTICIPANT	\N	PRESENT	0
108469	108412	14249W	PARTICIPANT	\N	EXCUSE	0
108470	108412	01025N	PARTICIPANT	\N	PRESENT	0
108471	108412	11089X	PARTICIPANT	\N	PRESENT	0
108472	108412	07026Q	PARTICIPANT	\N	PRESENT	0
108473	108412	14123H	PARTICIPANT	\N	PRESENT	0
108474	108412	14179A	PARTICIPANT	\N	PRESENT	0
108475	108412	14241N	PARTICIPANT	\N	PRESENT	0
108476	108412	14061L	PARTICIPANT	\N	PRESENT	0
108477	108412	14073Q	PARTICIPANT	\N	PRESENT	0
108478	108412	08031R	PARTICIPANT	\N	PRESENT	0
108479	108412	12041X	PARTICIPANT	\N	PRESENT	0
108480	108412	08039A	PARTICIPANT	\N	PRESENT	0
108481	108412	08017T	PARTICIPANT	\N	PRESENT	0
108482	108412	14059S	PARTICIPANT	\N	PRESENT	0
108483	108412	14103D	PARTICIPANT	\N	PRESENT	0
108484	108412	11104D	PARTICIPANT	\N	PRESENT	0
108485	108412	14063N	PARTICIPANT	\N	PRESENT	0
108486	108412	04057K	PARTICIPANT	\N	PRESENT	0
108487	108412	11014C	PARTICIPANT	\N	PRESENT	0
108488	108412	04070G	PRESIDENT	0	PRESENT	0
108489	108412	04033B	PARTICIPANT	\N	PRESENT	0
108490	108412	14229S	PARTICIPANT	\N	PRESENT	0
108491	108412	11043H	PARTICIPANT	\N	PRESENT	0
108492	108412	11011M	PARTICIPANT	\N	PRESENT	0
109452	107314	01057W	PARTICIPANT	\N	PRESENT	0
109453	107314	14269B	PARTICIPANT	\N	PRESENT	0
109454	107314	11107G	PARTICIPANT	\N	PRESENT	0
109455	107314	14159V	PARTICIPANT	\N	PRESENT	0
109456	107314	08053X	PARTICIPANT	\N	PRESENT	0
109457	107314	14329V	PARTICIPANT	\N	PRESENT	0
109458	107314	11114F	PARTICIPANT	\N	PRESENT	0
109459	107314	11072N	PARTICIPANT	\N	PRESENT	0
109460	107314	08073C	PARTICIPANT	\N	PRESENT	0
109461	107314	11113E	PARTICIPANT	\N	PRESENT	0
109462	107314	14042U	PARTICIPANT	\N	PRESENT	0
109463	107314	11037K	PARTICIPANT	\N	PRESENT	0
109464	107314	04050C	PARTICIPANT	\N	PRESENT	0
109465	107314	01034P	PARTICIPANT	\N	PRESENT	0
109466	107314	14275Y	PARTICIPANT	\N	PRESENT	0
109467	107314	04054G	PARTICIPANT	\N	PRESENT	0
109468	107314	01025N	PARTICIPANT	\N	PRESENT	0
109469	107314	04040A	PARTICIPANT	\N	PRESENT	0
109470	107314	14030Q	PARTICIPANT	\N	PRESENT	0
109471	107314	11053K	PARTICIPANT	\N	PRESENT	0
109472	107314	14083S	PARTICIPANT	\N	PRESENT	0
109473	107314	04080J	PARTICIPANT	\N	PRESENT	0
109522	107314	14235Q	PARTICIPANT	\N	PRESENT	0
109475	107314	14034U	PARTICIPANT	\N	PRESENT	0
109514	107314	08018U	PARTICIPANT	\N	PRESENT	0
109477	107314	04038G	PARTICIPANT	\N	PRESENT	0
109478	107314	01024M	PARTICIPANT	\N	PRESENT	0
109479	107314	11064N	PARTICIPANT	\N	PRESENT	0
109480	107314	14219Q	PARTICIPANT	\N	PRESENT	0
109481	107314	14221J	PARTICIPANT	\N	PRESENT	0
109482	107314	11082Q	PARTICIPANT	\N	PRESENT	0
109483	107314	04089T	PARTICIPANT	\N	PRESENT	0
109484	107314	09001P	PARTICIPANT	\N	PRESENT	0
109485	107314	14179A	PARTICIPANT	\N	PRESENT	0
109486	107314	14231L	PARTICIPANT	\N	PRESENT	0
109487	107314	01047U	PARTICIPANT	\N	PRESENT	0
109488	107314	14205J	PARTICIPANT	\N	PRESENT	0
109489	107314	14073Q	PARTICIPANT	\N	PRESENT	0
109490	107314	14033T	PARTICIPANT	\N	PRESENT	0
109491	107314	01043Q	PARTICIPANT	\N	PRESENT	0
109492	107314	14135M	PARTICIPANT	\N	PRESENT	0
109493	107314	87003B	PARTICIPANT	\N	PRESENT	0
109494	107314	92044U	PARTICIPANT	\N	PRESENT	0
109495	107314	01060R	PARTICIPANT	\N	PRESENT	0
109496	107314	14247U	PARTICIPANT	\N	PRESENT	0
109497	107314	11088W	PARTICIPANT	\N	PRESENT	0
109508	107314	14199E	PARTICIPANT	\N	PRESENT	0
109499	107314	08019V	PARTICIPANT	\N	PRESENT	0
109500	107314	11011M	PARTICIPANT	\N	PRESENT	0
109515	107314	11043H	PARTICIPANT	\N	PRESENT	0
109502	107314	07004J	PARTICIPANT	\N	PRESENT	0
109503	107314	95067Q	PARTICIPANT	\N	PRESENT	0
109504	107314	14273W	PARTICIPANT	\N	PRESENT	0
109505	107314	07024N	PARTICIPANT	\N	PRESENT	0
109506	107314	01027Q	PARTICIPANT	\N	PRESENT	0
109520	107314	08069G	PARTICIPANT	\N	PRESENT	0
109509	107314	10015M	PARTICIPANT	\N	PRESENT	0
109510	107314	11095V	PARTICIPANT	\N	PRESENT	0
109517	107314	11070L	PARTICIPANT	\N	PRESENT	0
109513	107314	98050T	PARTICIPANT	\N	PRESENT	0
109516	107314	14267Y	PARTICIPANT	\N	PRESENT	0
109518	107314	92031P	PARTICIPANT	\N	PRESENT	0
109521	107314	04035D	PARTICIPANT	\N	PRESENT	0
109523	107314	14097Y	PARTICIPANT	\N	PRESENT	0
109524	107314	11061K	PARTICIPANT	\N	PRESENT	0
109525	107314	08011M	PARTICIPANT	\N	PRESENT	0
109530	107314	14237S	PARTICIPANT	\N	PRESENT	0
109537	107314	01041N	PARTICIPANT	\N	PRESENT	0
109531	107314	11026G	PARTICIPANT	\N	PRESENT	0
109538	107314	01028R	PARTICIPANT	\N	PRESENT	0
109539	107314	95059Q	PARTICIPANT	\N	PRESENT	0
109540	107314	14089Y	PARTICIPANT	\N	PRESENT	0
109541	107314	14217N	PARTICIPANT	\N	PRESENT	0
109552	107314	08017T	PARTICIPANT	\N	PRESENT	0
501154	500418	19551W	PARTICIPANT	\N	PRESENT	0
501155	499452	19551W	PARTICIPANT	\N	PRESENT	0
501156	498855	19551W	PARTICIPANT	\N	PRESENT	0
501157	500461	19551W	PARTICIPANT	\N	PRESENT	0
501690	495438	19551W	PARTICIPANT	\N	PRESENT	0
501694	501596	19735D	PARTICIPANT	\N	PRESENT	0
501696	501596	04043D	PARTICIPANT	\N	PRESENT	0
501698	501596	19503N	PARTICIPANT	\N	PRESENT	0
501922	500478	11072N	PARTICIPANT	\N	PRESENT	0
501947	500478	19741B	PARTICIPANT	\N	PRESENT	0
501948	500478	11040E	PARTICIPANT	\N	PRESENT	0
501949	500478	14121F	PARTICIPANT	\N	PRESENT	0
501951	500478	20126Y	PARTICIPANT	\N	PRESENT	0
501952	500478	08011M	PARTICIPANT	\N	PRESENT	0
501953	500478	19762G	PARTICIPANT	\N	PRESENT	0
501954	500478	19479G	PARTICIPANT	\N	PRESENT	0
502366	502087	19719D	PARTICIPANT	\N	PRESENT	0
502373	502372	19719D	PARTICIPANT	\N	PRESENT	0
502375	502372	11104D	PARTICIPANT	\N	PRESENT	0
502376	502372	14109K	PARTICIPANT	\N	PRESENT	0
502384	502383	14123H	PARTICIPANT	\N	PRESENT	0
502385	502383	14109K	PARTICIPANT	\N	PRESENT	0
502420	502418	11104D	PARTICIPANT	\N	PRESENT	0
502422	502421	19758L	PARTICIPANT	\N	PRESENT	0
502423	502421	14123H	PARTICIPANT	\N	PRESENT	0
502424	502421	14030Q	PARTICIPANT	\N	PRESENT	0
502426	502421	20052X	PARTICIPANT	\N	PRESENT	0
100285	100284	08009T	PARTICIPANT	\N	PRESENT	0
100286	100284	11026G	PARTICIPANT	\N	PRESENT	0
100287	100284	14093U	PARTICIPANT	\N	PRESENT	0
101067	101058	11076S	PARTICIPANT	\N	PRESENT	0
101068	101058	04054G	PARTICIPANT	\N	PRESENT	0
101069	101058	04040A	PARTICIPANT	\N	EXCUSE	0
101070	101058	08058D	PARTICIPANT	\N	PRESENT	0
101071	101058	04042C	PARTICIPANT	\N	PRESENT	0
101072	101058	77002U	PARTICIPANT	\N	PRESENT	0
101950	101949	14259Y	PARTICIPANT	\N	PRESENT	0
102450	102444	08018U	PARTICIPANT	\N	PRESENT	0
101075	101058	11027H	PARTICIPANT	\N	PRESENT	0
101076	101058	98018T	PARTICIPANT	\N	PRESENT	0
102455	102444	14111D	PARTICIPANT	\N	PRESENT	0
101078	101058	92020L	PARTICIPANT	\N	PRESENT	0
101079	101058	95030B	PARTICIPANT	\N	PRESENT	0
101080	101058	11096W	PARTICIPANT	\N	PRESENT	0
101081	101058	95031C	PARTICIPANT	\N	PRESENT	0
101082	101058	97011G	PARTICIPANT	\N	PRESENT	0
101198	101194	04040A	PARTICIPANT	\N	EXCUSE	0
101084	101058	04035D	PARTICIPANT	\N	PRESENT	0
101085	101058	07024N	PARTICIPANT	\N	EXCUSE	0
101199	101194	08058D	PARTICIPANT	\N	PRESENT	0
101087	101058	14014Q	PARTICIPANT	\N	PRESENT	0
101088	101058	11015D	PARTICIPANT	\N	PRESENT	0
101089	101058	07004J	PARTICIPANT	\N	PRESENT	0
101090	101058	95035G	PARTICIPANT	\N	PRESENT	0
101200	101194	04042C	PARTICIPANT	\N	PRESENT	0
101092	101058	14211G	PARTICIPANT	\N	PRESENT	0
101093	101058	98022P	PARTICIPANT	\N	PRESENT	0
101094	101058	11064N	PARTICIPANT	\N	PRESENT	0
101095	101058	95037J	PARTICIPANT	\N	PRESENT	0
101096	101058	04078Q	PARTICIPANT	\N	PRESENT	0
101097	101058	14097Y	PARTICIPANT	\N	PRESENT	0
101098	101058	95041E	PARTICIPANT	\N	PRESENT	0
101099	101058	04036E	PARTICIPANT	\N	PRESENT	0
101100	101058	14039A	PARTICIPANT	\N	PRESENT	0
101101	101058	04077P	PARTICIPANT	\N	PRESENT	0
101102	101058	98005N	PARTICIPANT	\N	PRESENT	0
101103	101058	92031P	PARTICIPANT	\N	PRESENT	0
101104	101058	11106F	PARTICIPANT	\N	EXCUSE	0
101105	101058	14251Q	PARTICIPANT	\N	PRESENT	0
101106	101058	83042R	PARTICIPANT	\N	PRESENT	0
101107	101058	08053X	PARTICIPANT	\N	PRESENT	0
101108	101058	11082Q	PARTICIPANT	\N	PRESENT	0
101109	101058	11105E	PARTICIPANT	\N	EXCUSE	0
101110	101058	14253S	PARTICIPANT	\N	PRESENT	0
101111	101058	08047A	PARTICIPANT	\N	PRESENT	0
101112	101058	14028W	PARTICIPANT	\N	PRESENT	0
102458	102444	14059S	PARTICIPANT	\N	PRESENT	0
101114	101058	98021N	PARTICIPANT	\N	PRESENT	0
101115	101058	04080J	PARTICIPANT	\N	PRESENT	0
101116	101058	95059Q	PRESIDENT	0	PRESENT	0
101117	101058	86044G	PARTICIPANT	\N	PRESENT	0
101118	101058	01014K	PARTICIPANT	\N	PRESENT	0
101119	101058	11054L	PARTICIPANT	\N	PRESENT	0
101120	101058	01056V	PARTICIPANT	\N	PRESENT	0
101121	101058	92044U	PARTICIPANT	\N	PRESENT	0
101122	101058	08049C	PARTICIPANT	\N	PRESENT	0
101123	101058	04050C	PARTICIPANT	\N	PRESENT	0
101201	101194	77002U	PARTICIPANT	\N	PRESENT	0
102477	102444	11023D	PARTICIPANT	\N	PRESENT	0
102478	102444	11083R	PARTICIPANT	\N	PRESENT	0
101204	101194	11027H	PARTICIPANT	\N	PRESENT	0
101205	101194	98018T	PARTICIPANT	\N	PRESENT	0
102497	102496	14259Y	PARTICIPANT	\N	PRESENT	0
101207	101194	92020L	PARTICIPANT	\N	PRESENT	0
101208	101194	95030B	PARTICIPANT	\N	PRESENT	0
101209	101194	11096W	PARTICIPANT	\N	PRESENT	0
102879	102878	77002U	PARTICIPANT	\N	PRESENT	0
101211	101194	97011G	PARTICIPANT	\N	PRESENT	0
106472	99612	96004D	PARTICIPANT	\N	EXCUSE	0
101213	101194	04035D	PARTICIPANT	\N	PRESENT	0
101214	101194	07024N	PARTICIPANT	\N	EXCUSE	0
106473	99612	08065C	PARTICIPANT	\N	EXCUSE	0
101216	101194	14014Q	PARTICIPANT	\N	PRESENT	0
106486	99612	96003C	PARTICIPANT	\N	EXCUSE	0
110196	110195	11053K	PARTICIPANT	\N	PRESENT	0
101219	101194	95035G	PARTICIPANT	\N	PRESENT	0
101221	101194	14211G	PARTICIPANT	\N	PRESENT	0
101226	101194	14097Y	PARTICIPANT	\N	PRESENT	0
101228	101194	04036E	PARTICIPANT	\N	PRESENT	0
101229	101194	14039A	PARTICIPANT	\N	PRESENT	0
101231	101194	98005N	PARTICIPANT	\N	PRESENT	0
101232	101194	92031P	PARTICIPANT	\N	PRESENT	0
101233	101194	11106F	PARTICIPANT	\N	EXCUSE	0
101234	101194	14251Q	PARTICIPANT	\N	PRESENT	0
101236	101194	08053X	PARTICIPANT	\N	PRESENT	0
101238	101194	11105E	PARTICIPANT	\N	EXCUSE	0
101240	101194	08047A	PARTICIPANT	\N	PRESENT	0
101241	101194	14028W	PARTICIPANT	\N	PRESENT	0
101243	101194	98021N	PARTICIPANT	\N	PRESENT	0
101244	101194	04080J	PARTICIPANT	\N	PRESENT	0
101245	101194	95059Q	PRESIDENT	0	PRESENT	0
101246	101194	86044G	PARTICIPANT	\N	PRESENT	0
101247	101194	01014K	PARTICIPANT	\N	PRESENT	0
101249	101194	01056V	PARTICIPANT	\N	PRESENT	0
101250	101194	92044U	PARTICIPANT	\N	PRESENT	0
101251	101194	08049C	PARTICIPANT	\N	PRESENT	0
111053	110610	08012N	PARTICIPANT	\N	PRESENT	0
111169	111168	11039M	PARTICIPANT	\N	PRESENT	0
111170	111168	98042T	PARTICIPANT	\N	PRESENT	0
111172	111171	11039M	PARTICIPANT	\N	PRESENT	0
111173	111171	98042T	PARTICIPANT	\N	PRESENT	0
111715	111714	89017R	PARTICIPANT	\N	PRESENT	0
111716	111714	01031L	PRESIDENT	0	PRESENT	0
111717	111714	05004A	PARTICIPANT	\N	PRESENT	0
111719	111714	11068S	PARTICIPANT	\N	EXCUSE	0
111720	111714	11040E	PARTICIPANT	\N	PRESENT	0
111721	111714	08014Q	PARTICIPANT	\N	PRESENT	0
111722	111714	14167V	PARTICIPANT	\N	PRESENT	0
111723	111714	14175V	PARTICIPANT	\N	PRESENT	0
111724	111714	14083S	PARTICIPANT	\N	PRESENT	0
111725	111714	11053K	PARTICIPANT	\N	PRESENT	0
111726	111714	14085U	PARTICIPANT	\N	PRESENT	0
111727	111714	11042G	PARTICIPANT	\N	PRESENT	0
111729	111714	04086Q	PARTICIPANT	\N	PRESENT	0
111730	111714	04055H	PARTICIPANT	\N	EXCUSE	0
111731	111714	11070L	PARTICIPANT	\N	PRESENT	0
111732	111714	11088W	PARTICIPANT	\N	PRESENT	0
111733	111714	14327T	PARTICIPANT	\N	PRESENT	0
111734	111714	08022Q	PARTICIPANT	\N	PRESENT	0
111735	111714	01027Q	PARTICIPANT	\N	PRESENT	0
111736	111714	04071H	PARTICIPANT	\N	PRESENT	0
111737	111714	11074Q	PARTICIPANT	\N	PRESENT	0
111738	111714	98053W	PARTICIPANT	\N	EXCUSE	0
111739	111714	11083R	PARTICIPANT	\N	PRESENT	0
111740	111714	14199E	PARTICIPANT	\N	PRESENT	0
111741	111714	01057W	PARTICIPANT	\N	PRESENT	0
111742	111714	08016S	PARTICIPANT	\N	PRESENT	0
111743	111714	08069G	PARTICIPANT	\N	PRESENT	0
111744	111714	11048N	PARTICIPANT	\N	PRESENT	0
111745	111714	99004R	PARTICIPANT	\N	PRESENT	0
111746	111714	04061F	PARTICIPANT	\N	PRESENT	0
111747	111714	14159V	PARTICIPANT	\N	PRESENT	0
111748	111714	07029T	PARTICIPANT	\N	PRESENT	0
111749	111714	14277B	PARTICIPANT	\N	PRESENT	0
111750	111714	08010L	PARTICIPANT	\N	PRESENT	0
111751	111714	08034U	PARTICIPANT	\N	PRESENT	0
111753	111714	98046X	PARTICIPANT	\N	PRESENT	0
111754	111714	11085T	PARTICIPANT	\N	PRESENT	0
111755	111714	08011M	PARTICIPANT	\N	PRESENT	0
111757	111714	08061X	PARTICIPANT	\N	PRESENT	0
111758	111714	01016M	PARTICIPANT	\N	PRESENT	0
111759	111714	14225N	PARTICIPANT	\N	PRESENT	0
111760	111714	11012A	PARTICIPANT	\N	PRESENT	0
111761	111714	11057P	PARTICIPANT	\N	PRESENT	0
111762	111714	14173T	PARTICIPANT	\N	PRESENT	0
101750	101741	14053L	PARTICIPANT	\N	EXCUSE	0
101813	101812	04085P	PARTICIPANT	\N	PRESENT	0
101814	101812	04054G	PARTICIPANT	\N	PRESENT	0
101753	101741	14195A	PARTICIPANT	\N	PRESENT	0
101754	101741	14267Y	PARTICIPANT	\N	PRESENT	0
101815	101812	14089Y	PARTICIPANT	\N	EXCUSE	0
101756	101741	11031D	PARTICIPANT	\N	PRESENT	0
101757	101741	08052W	PARTICIPANT	\N	PRESENT	0
101758	101741	01059Y	PARTICIPANT	\N	PRESENT	0
101816	101812	04047H	PRESIDENT	1	PRESENT	0
101817	101812	14079W	PARTICIPANT	\N	PRESENT	0
101818	101812	14041T	PARTICIPANT	\N	EXCUSE	0
101819	101812	08041T	PARTICIPANT	\N	PRESENT	0
101763	101741	14217N	PARTICIPANT	\N	PRESENT	0
101764	101741	14042U	PARTICIPANT	\N	PRESENT	0
101765	101741	14151M	PARTICIPANT	\N	PRESENT	0
101766	101741	12042Y	PARTICIPANT	\N	PRESENT	0
101820	101812	14097Y	PARTICIPANT	\N	PRESENT	0
101821	101812	11026G	PARTICIPANT	\N	PRESENT	0
101822	101812	92031P	PRESIDENT	0	PRESENT	0
101770	101741	14034U	PARTICIPANT	\N	PRESENT	0
101823	101812	14001X	PARTICIPANT	\N	PRESENT	0
101772	101741	11061K	PARTICIPANT	\N	PRESENT	0
101824	101812	08021P	PARTICIPANT	\N	EXCUSE	0
101774	101741	08041T	PRESIDENT	1	PRESENT	0
101825	101812	14331P	PARTICIPANT	\N	PRESENT	0
101776	101741	14026U	PARTICIPANT	\N	PRESENT	0
101777	101741	14213J	PARTICIPANT	\N	PRESENT	0
101778	101741	14121F	PARTICIPANT	\N	PRESENT	0
101779	101741	11112D	PARTICIPANT	\N	PRESENT	0
101780	101741	14037X	PARTICIPANT	\N	PRESENT	0
101826	101812	95067Q	PARTICIPANT	\N	PRESENT	0
101782	101741	11067R	PARTICIPANT	\N	PRESENT	0
103039	103038	11088W	PARTICIPANT	\N	PRESENT	0
101784	101741	04092N	PRESIDENT	0	PRESENT	0
101785	101741	14265W	PARTICIPANT	\N	PRESENT	0
101786	101741	14119M	PARTICIPANT	\N	PRESENT	0
101787	101741	14071N	PARTICIPANT	\N	PRESENT	0
103041	103040	07034Q	PARTICIPANT	\N	PRESENT	0
103043	103042	07034Q	PARTICIPANT	\N	PRESENT	0
101790	101741	14271U	PARTICIPANT	\N	PRESENT	0
103053	103052	11027H	PARTICIPANT	\N	PRESENT	0
101792	101741	11093T	PARTICIPANT	\N	PRESENT	0
101793	101741	11097X	PARTICIPANT	\N	PRESENT	0
101794	101741	04045F	PARTICIPANT	\N	PRESENT	0
101795	101741	14227Q	PARTICIPANT	\N	PRESENT	0
101796	101741	01034P	PARTICIPANT	\N	PRESENT	0
103055	103054	07034Q	PARTICIPANT	\N	PRESENT	0
101798	101741	11063M	PARTICIPANT	\N	PRESENT	0
101799	101741	14269B	PARTICIPANT	\N	PRESENT	0
103152	101912	86034E	PARTICIPANT	\N	PRESENT	0
103153	101912	14037X	PARTICIPANT	\N	PRESENT	0
103154	101912	04092N	PARTICIPANT	\N	PRESENT	0
103155	101912	14034U	PARTICIPANT	\N	PRESENT	0
103156	101912	04066L	PARTICIPANT	\N	PRESENT	0
103157	101912	08052W	PARTICIPANT	\N	PRESENT	0
103158	101912	98046X	PARTICIPANT	\N	PRESENT	0
103159	101912	08016S	PARTICIPANT	\N	PRESENT	0
103160	101912	14269B	PARTICIPANT	\N	PRESENT	0
103161	101912	14151M	PARTICIPANT	\N	PRESENT	0
103162	101912	11031D	PARTICIPANT	\N	PRESENT	0
103163	101912	12041X	PARTICIPANT	\N	PRESENT	0
103164	101912	11089X	PARTICIPANT	\N	PRESENT	0
103166	101912	08014Q	PARTICIPANT	\N	PRESENT	0
103167	101912	14227Q	PARTICIPANT	\N	PRESENT	0
103168	101912	04045F	PARTICIPANT	\N	PRESENT	0
103169	101912	14271U	PARTICIPANT	\N	PRESENT	0
103170	101912	11061K	PARTICIPANT	\N	PRESENT	0
103171	101912	14039A	PARTICIPANT	\N	PRESENT	0
103173	101912	11055M	PARTICIPANT	\N	PRESENT	0
103176	101912	11029K	PARTICIPANT	\N	PRESENT	0
103178	101912	01003G	PARTICIPANT	\N	PRESENT	0
103179	101912	04053F	PARTICIPANT	\N	PRESENT	0
103182	101912	14042U	PARTICIPANT	\N	PRESENT	0
103184	101912	01034P	PARTICIPANT	\N	PRESENT	0
103186	101912	11093T	PARTICIPANT	\N	PRESENT	0
103187	101912	11053K	PARTICIPANT	\N	PRESENT	0
103190	101912	14071N	PARTICIPANT	\N	PRESENT	0
103194	101912	95041E	PARTICIPANT	\N	PRESENT	0
103196	101912	14247U	PARTICIPANT	\N	PRESENT	0
103199	101912	04086Q	PARTICIPANT	\N	PRESENT	0
103201	101912	04067M	PARTICIPANT	\N	PRESENT	0
103203	101912	14026U	PARTICIPANT	\N	PRESENT	0
103205	101912	14217N	PARTICIPANT	\N	PRESENT	0
103207	101912	04043D	PARTICIPANT	\N	PRESENT	0
103208	101912	11097X	PARTICIPANT	\N	PRESENT	0
103210	101912	11091R	PARTICIPANT	\N	PRESENT	0
103213	101912	11011M	PARTICIPANT	\N	PRESENT	0
103215	101912	11071M	PARTICIPANT	\N	PRESENT	0
103217	101912	11112D	PARTICIPANT	\N	PRESENT	0
103220	101912	11054L	PARTICIPANT	\N	PRESENT	0
103221	101912	11063M	PARTICIPANT	\N	PRESENT	0
103222	101912	04085P	PARTICIPANT	\N	PRESENT	0
103223	101912	98053W	PARTICIPANT	\N	PRESENT	0
103224	101912	11034G	PARTICIPANT	\N	PRESENT	0
103225	101912	04036E	PARTICIPANT	\N	PRESENT	0
103226	101912	04081K	PARTICIPANT	\N	PRESENT	0
103227	101912	01059Y	PARTICIPANT	\N	PRESENT	0
103228	101912	14119M	PARTICIPANT	\N	PRESENT	0
103232	101912	14087W	PARTICIPANT	\N	PRESENT	0
103233	101912	01031L	PARTICIPANT	\N	PRESENT	0
103237	101912	11077T	PARTICIPANT	\N	PRESENT	0
103238	101912	11103C	PARTICIPANT	\N	PRESENT	0
103239	101912	99004R	PARTICIPANT	\N	PRESENT	0
103240	101912	04055H	PARTICIPANT	\N	PRESENT	0
103241	101912	04049K	PARTICIPANT	\N	PRESENT	0
103252	101912	04078Q	PARTICIPANT	\N	PRESENT	0
103253	101912	11056N	PARTICIPANT	\N	PRESENT	0
103254	101912	14239U	PARTICIPANT	\N	PRESENT	0
103255	101912	14201E	PARTICIPANT	\N	PRESENT	0
103256	101912	14255U	PARTICIPANT	\N	PRESENT	0
103257	101912	83047W	PARTICIPANT	\N	PRESENT	0
103258	101912	01015L	PARTICIPANT	\N	PRESENT	0
103259	101912	04071H	PARTICIPANT	\N	PRESENT	0
103292	101912	14223L	PARTICIPANT	\N	PRESENT	0
103293	101912	11067R	PARTICIPANT	\N	PRESENT	0
103294	101912	11109J	PARTICIPANT	\N	PRESENT	0
103295	101912	14265W	PARTICIPANT	\N	PRESENT	0
103369	101913	01007L	PARTICIPANT	\N	PRESENT	0
103370	101913	04053F	PARTICIPANT	\N	PRESENT	0
103371	101913	08052W	PARTICIPANT	\N	PRESENT	0
103372	101913	04045F	PARTICIPANT	\N	PRESENT	0
103373	101913	14271U	PARTICIPANT	\N	PRESENT	0
103374	101913	11015D	PARTICIPANT	\N	PRESENT	0
103375	101913	14257W	PARTICIPANT	\N	PRESENT	0
103376	101913	14227Q	PARTICIPANT	\N	PRESENT	0
103377	101913	14151M	PARTICIPANT	\N	PRESENT	0
103378	101913	11029K	PARTICIPANT	\N	PRESENT	0
103379	101913	14042U	PARTICIPANT	\N	PRESENT	0
103380	101913	11056N	PARTICIPANT	\N	PRESENT	0
103381	101913	01059Y	PARTICIPANT	\N	PRESENT	0
103382	101913	14235Q	PARTICIPANT	\N	PRESENT	0
103383	101913	11093T	PARTICIPANT	\N	PRESENT	0
103384	101913	14119M	PARTICIPANT	\N	PRESENT	0
103385	101913	11112D	PARTICIPANT	\N	PRESENT	0
103386	101913	04092N	PARTICIPANT	\N	PRESENT	0
103387	101913	14037X	PARTICIPANT	\N	PRESENT	0
103388	101913	14034U	PARTICIPANT	\N	PRESENT	0
103389	101913	14087W	PARTICIPANT	\N	PRESENT	0
103390	101913	11031D	PARTICIPANT	\N	PRESENT	0
103391	101913	04085P	PARTICIPANT	\N	PRESENT	0
103392	101913	01015L	PARTICIPANT	\N	PRESENT	0
103393	101913	80013X	PARTICIPANT	\N	PRESENT	0
103394	101913	11089X	PARTICIPANT	\N	PRESENT	0
103395	101913	08068F	PARTICIPANT	\N	PRESENT	0
103396	101913	12042Y	PARTICIPANT	\N	PRESENT	0
103397	101913	11077T	PARTICIPANT	\N	PRESENT	0
103398	101913	11109J	PARTICIPANT	\N	PRESENT	0
103399	101913	14269B	PARTICIPANT	\N	PRESENT	0
103400	101913	11067R	PARTICIPANT	\N	PRESENT	0
103401	101913	14255U	PARTICIPANT	\N	PRESENT	0
103402	101913	01034P	PARTICIPANT	\N	PRESENT	0
103403	101913	14211G	PARTICIPANT	\N	PRESENT	0
103404	101913	04066L	PARTICIPANT	\N	PRESENT	0
103405	101913	14026U	PARTICIPANT	\N	PRESENT	0
103406	101913	14071N	PARTICIPANT	\N	PRESENT	0
103407	101913	01037S	PARTICIPANT	\N	PRESENT	0
103408	101913	14187A	PARTICIPANT	\N	PRESENT	0
103409	101913	14217N	PARTICIPANT	\N	PRESENT	0
103410	101913	11097X	PARTICIPANT	\N	PRESENT	0
103411	101913	08031R	PARTICIPANT	\N	PRESENT	0
103412	101913	14223L	PARTICIPANT	\N	PRESENT	0
103413	101913	14018U	PARTICIPANT	\N	PRESENT	0
103414	101913	95041E	PARTICIPANT	\N	PRESENT	0
103416	101913	11063M	PARTICIPANT	\N	PRESENT	0
103443	101913	11061K	PARTICIPANT	\N	PRESENT	0
103446	101913	14069U	PARTICIPANT	\N	PRESENT	0
103447	101913	92039X	PARTICIPANT	\N	PRESENT	0
103448	101913	11042G	PARTICIPANT	\N	PRESENT	0
94623	94622	07004J	PARTICIPANT	\N	PRESENT	0
95433	95432	89017R	PARTICIPANT	\N	PRESENT	0
94625	94622	95067Q	PARTICIPANT	\N	PRESENT	0
95372	95371	14239U	PARTICIPANT	\N	PRESENT	0
95373	95371	11055M	PARTICIPANT	\N	PRESENT	0
95374	95371	01046T	PARTICIPANT	\N	PRESENT	0
95375	95371	04053F	PARTICIPANT	\N	PRESENT	0
95376	95371	14255U	PARTICIPANT	\N	PRESENT	0
95377	95371	04066L	PARTICIPANT	\N	PRESENT	0
95378	95371	00003C	PARTICIPANT	\N	PRESENT	0
95379	95371	14053L	PARTICIPANT	\N	PRESENT	0
95380	95371	11103C	PARTICIPANT	\N	PRESENT	0
95381	95371	11044J	PARTICIPANT	\N	PRESENT	0
95382	95371	14195A	PARTICIPANT	\N	PRESENT	0
95434	95432	01031L	PRESIDENT	0	PRESENT	0
95528	95527	08025T	PARTICIPANT	\N	PRESENT	0
95385	95371	11031D	PARTICIPANT	\N	PRESENT	0
95386	95371	08052W	PARTICIPANT	\N	PRESENT	0
95387	95371	01059Y	PARTICIPANT	\N	PRESENT	0
95388	95371	04081K	PARTICIPANT	\N	PRESENT	0
95389	95371	98024R	PARTICIPANT	\N	PRESENT	0
95390	95371	10006L	PARTICIPANT	\N	PRESENT	0
95391	95371	04067M	PARTICIPANT	\N	PRESENT	0
95392	95371	14217N	PARTICIPANT	\N	PRESENT	0
95393	95371	14042U	PARTICIPANT	\N	PRESENT	0
95394	95371	14151M	PARTICIPANT	\N	PRESENT	0
95395	95371	12042Y	PARTICIPANT	\N	PRESENT	0
95396	95371	14281W	PARTICIPANT	\N	PRESENT	0
95397	95371	14087W	PARTICIPANT	\N	PRESENT	0
95398	95371	01003G	PARTICIPANT	\N	PRESENT	0
95399	95371	14034U	PARTICIPANT	\N	PRESENT	0
95400	95371	14231L	PARTICIPANT	\N	PRESENT	0
95401	95371	11061K	PARTICIPANT	\N	PRESENT	0
95402	95371	08048B	PARTICIPANT	\N	PRESENT	0
95403	95371	08041T	PARTICIPANT	\N	PRESENT	0
95404	95371	01011G	PARTICIPANT	\N	PRESENT	0
95405	95371	14026U	PARTICIPANT	\N	PRESENT	0
95406	95371	14213J	PARTICIPANT	\N	PRESENT	0
95407	95371	14121F	PARTICIPANT	\N	PRESENT	0
95408	95371	11112D	PARTICIPANT	\N	PRESENT	0
95409	95371	14037X	PARTICIPANT	\N	PRESENT	0
95410	95371	14018U	PARTICIPANT	\N	PRESENT	0
95411	95371	11067R	PARTICIPANT	\N	PRESENT	0
95412	95371	14223L	PARTICIPANT	\N	PRESENT	0
95413	95371	04092N	PRESIDENT	0	PRESENT	0
95414	95371	14265W	PARTICIPANT	\N	PRESENT	0
95415	95371	14119M	PARTICIPANT	\N	PRESENT	0
95416	95371	14071N	PARTICIPANT	\N	PRESENT	0
95417	95371	07032N	PARTICIPANT	\N	PRESENT	0
95418	95371	04043D	PARTICIPANT	\N	PRESENT	0
95419	95371	14271U	PARTICIPANT	\N	PRESENT	0
95420	95371	14017T	PARTICIPANT	\N	EXCUSE	0
95421	95371	11093T	PARTICIPANT	\N	PRESENT	0
95422	95371	11097X	PARTICIPANT	\N	PRESENT	0
95423	95371	04045F	PARTICIPANT	\N	PRESENT	0
95424	95371	14227Q	PARTICIPANT	\N	PRESENT	0
95425	95371	01034P	PARTICIPANT	\N	PRESENT	0
95426	95371	11025F	PARTICIPANT	\N	PRESENT	0
95427	95371	11063M	PARTICIPANT	\N	PRESENT	0
95428	95371	14269B	PARTICIPANT	\N	PRESENT	0
95436	95432	01013J	PARTICIPANT	\N	PRESENT	0
95437	95432	11068S	PARTICIPANT	\N	PRESENT	0
95438	95432	11040E	PARTICIPANT	\N	PRESENT	0
95439	95432	08014Q	PARTICIPANT	\N	PRESENT	0
95529	95527	04085P	PARTICIPANT	\N	PRESENT	0
95441	95432	14175V	PARTICIPANT	\N	PRESENT	0
95442	95432	14083S	PARTICIPANT	\N	PRESENT	0
95443	95432	11053K	PARTICIPANT	\N	PRESENT	0
95444	95432	14085U	PARTICIPANT	\N	PRESENT	0
95445	95432	11042G	PARTICIPANT	\N	PRESENT	0
95446	95432	88008L	PARTICIPANT	\N	PRESENT	0
95447	95432	04086Q	PARTICIPANT	\N	PRESENT	0
95448	95432	04055H	PARTICIPANT	\N	PRESENT	0
95449	95432	11070L	PARTICIPANT	\N	PRESENT	0
95450	95432	11088W	PARTICIPANT	\N	PRESENT	0
95451	95432	14327T	PARTICIPANT	\N	PRESENT	0
95530	95527	05008E	PRESIDENT	0	PRESENT	0
95453	95432	01027Q	PARTICIPANT	\N	PRESENT	0
95454	95432	04071H	PARTICIPANT	\N	PRESENT	0
95455	95432	11074Q	PARTICIPANT	\N	PRESENT	0
95456	95432	98053W	PARTICIPANT	\N	EXCUSE	0
95457	95432	11083R	PARTICIPANT	\N	PRESENT	0
95531	95527	11030C	PARTICIPANT	\N	PRESENT	0
95459	95432	01057W	PARTICIPANT	\N	PRESENT	0
95460	95432	08016S	PARTICIPANT	\N	PRESENT	0
95461	95432	08069G	PARTICIPANT	\N	PRESENT	0
95462	95432	11048N	PARTICIPANT	\N	PRESENT	0
95463	95432	99004R	PARTICIPANT	\N	PRESENT	0
95532	95527	11033F	PARTICIPANT	\N	PRESENT	0
95465	95432	14159V	PARTICIPANT	\N	PRESENT	0
95466	95432	07029T	PARTICIPANT	\N	PRESENT	0
95467	95432	14277B	PARTICIPANT	\N	PRESENT	0
95533	95527	14065Q	PARTICIPANT	\N	PRESENT	0
95469	95432	08034U	PARTICIPANT	\N	PRESENT	0
95592	95591	08025T	PARTICIPANT	\N	PRESENT	0
95471	95432	98046X	PARTICIPANT	\N	PRESENT	0
95593	95591	04085P	PARTICIPANT	\N	PRESENT	0
95473	95432	08011M	PARTICIPANT	\N	PRESENT	0
95474	95432	08073C	PARTICIPANT	\N	PRESENT	0
95475	95432	08061X	PARTICIPANT	\N	PRESENT	0
95476	95432	01016M	PARTICIPANT	\N	PRESENT	0
95477	95432	14225N	PARTICIPANT	\N	PRESENT	0
95478	95432	11012A	PARTICIPANT	\N	PRESENT	0
95479	95432	11057P	PARTICIPANT	\N	PRESENT	0
95480	95432	14173T	PARTICIPANT	\N	PRESENT	0
95481	95432	04034C	PARTICIPANT	\N	PRESENT	0
95534	95527	14069U	PARTICIPANT	\N	PRESENT	0
95535	95527	04047H	PARTICIPANT	\N	PRESENT	0
95536	95527	11032E	PARTICIPANT	\N	PRESENT	0
95537	95527	04038G	PARTICIPANT	\N	PRESENT	0
95594	95591	05008E	PRESIDENT	0	PRESENT	0
95539	95527	11056N	PARTICIPANT	\N	PRESENT	0
95540	95527	14259Y	PARTICIPANT	\N	PRESENT	0
95542	95527	14041T	PARTICIPANT	\N	PRESENT	0
95595	95591	11030C	PARTICIPANT	\N	PRESENT	0
95544	95527	01024M	PARTICIPANT	\N	PRESENT	0
95596	95591	11033F	PARTICIPANT	\N	PRESENT	0
95546	95527	11034G	PARTICIPANT	\N	PRESENT	0
95597	95591	14065Q	PARTICIPANT	\N	PRESENT	0
95548	95527	11010L	PARTICIPANT	\N	PRESENT	0
95549	95527	01007L	PARTICIPANT	\N	PRESENT	0
95550	95527	11049P	PARTICIPANT	\N	PRESENT	0
95551	95527	08044W	PARTICIPANT	\N	PRESENT	0
95598	95591	14069U	PARTICIPANT	\N	PRESENT	0
95553	95527	11026G	PARTICIPANT	\N	PRESENT	0
95599	95591	04047H	PARTICIPANT	\N	PRESENT	0
95555	95527	14111D	PARTICIPANT	\N	PRESENT	0
95556	95527	14001X	PARTICIPANT	\N	PRESENT	0
95557	95527	14273W	PARTICIPANT	\N	PRESENT	0
95558	95527	01060R	PARTICIPANT	\N	PRESENT	0
95559	95527	14147R	PARTICIPANT	\N	PRESENT	0
95560	95527	95049N	PARTICIPANT	\N	PRESENT	0
95561	95527	08051V	PARTICIPANT	\N	PRESENT	0
95562	95527	11072N	PARTICIPANT	\N	PRESENT	0
95563	95527	07034Q	PARTICIPANT	\N	PRESENT	0
95564	95527	04074L	PARTICIPANT	\N	PRESENT	0
95565	95527	10015M	PARTICIPANT	\N	PRESENT	0
95566	95527	95063L	PARTICIPANT	\N	PRESENT	0
95567	95527	01019Q	PARTICIPANT	\N	PRESENT	0
95568	95527	01028R	PARTICIPANT	\N	PRESENT	0
95569	95527	98035U	PARTICIPANT	\N	PRESENT	0
95570	95527	04056J	PARTICIPANT	\N	PRESENT	0
95571	95527	14275Y	PARTICIPANT	\N	PRESENT	0
95572	95527	04044E	PARTICIPANT	\N	PRESENT	0
95573	95527	11037K	PARTICIPANT	\N	EXCUSE	0
95574	95527	92045V	PARTICIPANT	\N	PRESENT	0
95575	95527	95067Q	PARTICIPANT	\N	PRESENT	0
95576	95527	01047U	PARTICIPANT	\N	PRESENT	0
95600	95591	11032E	PARTICIPANT	\N	PRESENT	0
95601	95591	04038G	PARTICIPANT	\N	PRESENT	0
95603	95591	11056N	PARTICIPANT	\N	PRESENT	0
95604	95591	14259Y	PARTICIPANT	\N	PRESENT	0
95606	95591	14041T	PARTICIPANT	\N	PRESENT	0
95608	95591	01024M	PARTICIPANT	\N	PRESENT	0
95610	95591	11034G	PARTICIPANT	\N	PRESENT	0
95611	95591	08018U	PARTICIPANT	\N	PRESENT	0
95612	95591	11010L	PARTICIPANT	\N	PRESENT	0
95613	95591	01007L	PARTICIPANT	\N	PRESENT	0
95614	95591	11049P	PARTICIPANT	\N	PRESENT	0
95615	95591	08044W	PARTICIPANT	\N	PRESENT	0
95617	95591	11026G	PARTICIPANT	\N	PRESENT	0
95618	95591	04079R	PARTICIPANT	\N	PRESENT	0
95619	95591	14111D	PARTICIPANT	\N	PRESENT	0
113093	113092	08025T	PARTICIPANT	\N	PRESENT	0
113094	113092	05008E	PRESIDENT	0	PRESENT	0
113095	113092	04038G	PARTICIPANT	\N	PRESENT	0
113096	113092	14041T	PARTICIPANT	\N	PRESENT	0
113097	113092	01024M	PARTICIPANT	\N	PRESENT	0
113098	113092	11010L	PARTICIPANT	\N	PRESENT	0
113099	113092	01007L	PARTICIPANT	\N	PRESENT	0
113100	113092	14111D	PARTICIPANT	\N	PRESENT	0
113101	113092	14001X	PARTICIPANT	\N	PRESENT	0
113102	113092	95049N	PARTICIPANT	\N	PRESENT	0
113103	113092	11072N	PARTICIPANT	\N	PRESENT	0
113104	113092	07034Q	PARTICIPANT	\N	PRESENT	0
113105	113092	01028R	PARTICIPANT	\N	PRESENT	0
113106	113092	04056J	PARTICIPANT	\N	PRESENT	0
113107	113092	04044E	PARTICIPANT	\N	PRESENT	0
113108	113092	95067Q	PARTICIPANT	\N	PRESENT	0
113109	113092	98035U	PARTICIPANT	\N	PRESENT	0
113132	112752	89029V	PARTICIPANT	\N	PRESENT	0
113152	112752	14030Q	PARTICIPANT	\N	PRESENT	0
113153	112752	14103D	PARTICIPANT	\N	PRESENT	0
113154	112752	14179A	PARTICIPANT	\N	PRESENT	0
113155	112752	14331P	PARTICIPANT	\N	PRESENT	0
113156	112752	04049K	PARTICIPANT	\N	PRESENT	0
113157	112752	01044R	PARTICIPANT	\N	PRESENT	0
113158	112752	08025T	PARTICIPANT	\N	PRESENT	0
113159	112752	07004J	PARTICIPANT	\N	PRESENT	0
113160	112752	01025N	PARTICIPANT	\N	PRESENT	0
113161	112752	11057P	PARTICIPANT	\N	PRESENT	0
113162	112752	05008E	PARTICIPANT	\N	PRESENT	0
113163	112752	07034Q	PARTICIPANT	\N	PRESENT	0
113164	112752	04085P	PARTICIPANT	\N	PRESENT	0
113165	112752	13002U	PARTICIPANT	\N	PRESENT	0
113166	112752	12042Y	PARTICIPANT	\N	PRESENT	0
113167	112752	11083R	PARTICIPANT	\N	PRESENT	0
113168	112752	11099A	PARTICIPANT	\N	PRESENT	0
113169	112752	11029K	PARTICIPANT	\N	PRESENT	0
113170	112752	11094U	PARTICIPANT	\N	PRESENT	0
113171	112752	04038G	PARTICIPANT	\N	PRESENT	0
113172	112752	11098Y	PARTICIPANT	\N	PRESENT	0
113173	112752	14033T	PARTICIPANT	\N	PRESENT	0
113174	112752	14265W	PARTICIPANT	\N	PRESENT	0
113175	112752	14059S	PARTICIPANT	\N	PRESENT	0
113176	112752	14327T	PARTICIPANT	\N	PRESENT	0
113177	112752	11103C	PARTICIPANT	\N	PRESENT	0
113178	112752	14219Q	PARTICIPANT	\N	PRESENT	0
113179	112752	88008L	PARTICIPANT	\N	PRESENT	0
113180	112752	04088S	PARTICIPANT	\N	PRESENT	0
113181	112752	01056V	PARTICIPANT	\N	PRESENT	0
113182	112752	11034G	PARTICIPANT	\N	PRESENT	0
113183	112752	14157T	PARTICIPANT	\N	PRESENT	0
113184	112752	01024M	PARTICIPANT	\N	PRESENT	0
113185	112752	14001X	PARTICIPANT	\N	PRESENT	0
113186	112752	11074Q	PARTICIPANT	\N	PRESENT	0
113187	112752	14135M	PARTICIPANT	\N	PRESENT	0
113188	112752	14147R	PARTICIPANT	\N	PRESENT	0
113189	112752	04034C	PARTICIPANT	\N	PRESENT	0
113190	112752	04067M	PARTICIPANT	\N	PRESENT	0
113191	112752	14175V	PARTICIPANT	\N	PRESENT	0
113192	112752	14215L	PARTICIPANT	\N	PRESENT	0
113193	112752	14197C	PARTICIPANT	\N	PRESENT	0
113194	112752	14207L	PARTICIPANT	\N	PRESENT	0
113195	112752	01003G	PARTICIPANT	\N	PRESENT	0
113196	112752	14257W	PARTICIPANT	\N	PRESENT	0
113197	112752	14083S	PARTICIPANT	\N	PRESENT	0
113198	112752	14061L	PARTICIPANT	\N	PRESENT	0
113199	112752	14041T	PARTICIPANT	\N	PRESENT	0
113200	112752	01007L	PARTICIPANT	\N	PRESENT	0
113201	112752	08051V	PARTICIPANT	\N	PRESENT	0
113202	112752	08061X	PARTICIPANT	\N	PRESENT	0
113203	112752	87003B	PARTICIPANT	\N	PRESENT	0
113204	112752	14159V	PARTICIPANT	\N	PRESENT	0
113205	112752	11090Q	PARTICIPANT	\N	PRESENT	0
113206	112752	92015P	PARTICIPANT	\N	PRESENT	0
113207	112752	14263U	PARTICIPANT	\N	PRESENT	0
113208	112752	14097Y	PARTICIPANT	\N	PRESENT	0
113209	112752	01047U	PARTICIPANT	\N	PRESENT	0
113210	112752	08055A	PARTICIPANT	\N	PRESENT	0
113211	112752	11104D	PARTICIPANT	\N	PRESENT	0
113212	112752	01013J	PARTICIPANT	\N	PRESENT	0
113213	112752	14255U	PARTICIPANT	\N	PRESENT	0
113214	112752	14053L	PARTICIPANT	\N	PRESENT	0
113215	112752	01015L	PARTICIPANT	\N	PRESENT	0
113216	112752	11114F	PARTICIPANT	\N	PRESENT	0
113217	112752	92045V	PARTICIPANT	\N	PRESENT	0
113218	112752	08039A	PARTICIPANT	\N	PRESENT	0
113219	112752	08010L	PARTICIPANT	\N	PRESENT	0
113220	112752	08048B	PARTICIPANT	\N	PRESENT	0
113221	112752	08069G	PARTICIPANT	\N	PRESENT	0
113222	112752	99004R	PARTICIPANT	\N	PRESENT	0
113223	112752	14013P	PARTICIPANT	\N	PRESENT	0
113224	112752	11036J	PARTICIPANT	\N	PRESENT	0
113225	112752	08068F	PARTICIPANT	\N	PRESENT	0
113227	112752	14063N	PARTICIPANT	\N	PRESENT	0
113228	112752	11053K	PARTICIPANT	\N	PRESENT	0
113229	112752	11040E	PARTICIPANT	\N	PRESENT	0
113232	112752	11097X	PARTICIPANT	\N	PRESENT	0
113233	112752	97011G	PARTICIPANT	\N	PRESENT	0
113234	112752	14329V	PARTICIPANT	\N	PRESENT	0
113235	112752	14199E	PARTICIPANT	\N	PRESENT	0
113236	112752	14173T	PARTICIPANT	\N	PRESENT	0
113237	112752	11110B	PARTICIPANT	\N	PRESENT	0
113238	112752	08017T	PARTICIPANT	\N	PRESENT	0
113239	112752	11026G	PARTICIPANT	\N	PRESENT	0
113240	112752	11084S	PARTICIPANT	\N	PRESENT	0
113241	112752	11112D	PARTICIPANT	\N	PRESENT	0
113242	112752	11067R	PARTICIPANT	\N	PRESENT	0
113243	112752	01028R	PARTICIPANT	\N	PRESENT	0
113244	112752	14213J	PARTICIPANT	\N	PRESENT	0
113245	112752	90003B	PARTICIPANT	\N	PRESENT	0
113246	112752	14089Y	PARTICIPANT	\N	PRESENT	0
113247	112752	14051J	PARTICIPANT	\N	PRESENT	0
113248	112752	08053X	PARTICIPANT	\N	PRESENT	0
113249	112752	14065Q	PARTICIPANT	\N	PRESENT	0
113252	112752	01027Q	PARTICIPANT	\N	PRESENT	0
113253	112752	95063L	PARTICIPANT	\N	PRESENT	0
113254	112752	11059R	PARTICIPANT	\N	PRESENT	0
113255	112752	08014Q	PARTICIPANT	\N	PRESENT	0
113256	112752	11066Q	PARTICIPANT	\N	PRESENT	0
113257	112752	11033F	PARTICIPANT	\N	PRESENT	0
113258	112752	98046X	PARTICIPANT	\N	PRESENT	0
113259	112752	11093T	PARTICIPANT	\N	PRESENT	0
113260	112752	04048J	PARTICIPANT	\N	PRESENT	0
113272	112752	14249W	PARTICIPANT	\N	PRESENT	0
113273	112752	89017R	PARTICIPANT	\N	PRESENT	0
113274	112752	80013X	PARTICIPANT	\N	PRESENT	0
113275	112752	04033B	PARTICIPANT	\N	PRESENT	0
113276	112752	98018T	PARTICIPANT	\N	PRESENT	0
113277	112752	14119M	PARTICIPANT	\N	PRESENT	0
113278	112752	08019V	PARTICIPANT	\N	PRESENT	0
113279	112752	11091R	PARTICIPANT	\N	PRESENT	0
113280	112752	04057K	PARTICIPANT	\N	PRESENT	0
113281	112752	14205J	PARTICIPANT	\N	PRESENT	0
113282	112752	01057W	PARTICIPANT	\N	PRESENT	0
113283	112752	14217N	PARTICIPANT	\N	PRESENT	0
113292	112752	01031L	PARTICIPANT	\N	PRESENT	0
113293	112752	11042G	PARTICIPANT	\N	PRESENT	0
113294	112752	11049P	PARTICIPANT	\N	PRESENT	0
113295	112752	11076S	PARTICIPANT	\N	PRESENT	0
113296	112752	01046T	PARTICIPANT	\N	PRESENT	0
113297	112752	14042U	PARTICIPANT	\N	PRESENT	0
113330	112752	14073Q	PARTICIPANT	\N	PRESENT	0
113331	112752	14267Y	PARTICIPANT	\N	PRESENT	0
113332	112752	10015M	PARTICIPANT	\N	PRESENT	0
113333	112752	95030B	PARTICIPANT	\N	PRESENT	0
113334	112752	04071H	PARTICIPANT	\N	PRESENT	0
113335	112752	11014C	PARTICIPANT	\N	PRESENT	0
113336	112752	10006L	PARTICIPANT	\N	PRESENT	0
113337	112752	08034U	PARTICIPANT	\N	PRESENT	0
113338	112752	04044E	PARTICIPANT	\N	PRESENT	0
113339	112752	11111C	PARTICIPANT	\N	PRESENT	0
113352	112752	14237S	PARTICIPANT	\N	PRESENT	0
113353	112752	14111D	PARTICIPANT	\N	PRESENT	0
113354	112752	14121F	PARTICIPANT	\N	PRESENT	0
113355	112752	11107G	PARTICIPANT	\N	PRESENT	0
113356	112752	14085U	PARTICIPANT	\N	PRESENT	0
113357	112752	04045F	PARTICIPANT	\N	PRESENT	0
113358	112752	14028W	PARTICIPANT	\N	PRESENT	0
113359	112752	14031R	PARTICIPANT	\N	PRESENT	0
113360	112752	14227Q	PARTICIPANT	\N	PRESENT	0
113361	112752	14271U	PARTICIPANT	\N	PRESENT	0
113362	112752	01008M	PARTICIPANT	\N	PRESENT	0
113382	112752	01058X	PARTICIPANT	\N	PRESENT	0
113383	112752	11012A	PARTICIPANT	\N	PRESENT	0
113385	112752	04092N	PARTICIPANT	\N	PRESENT	0
113390	112752	08011M	PARTICIPANT	\N	PRESENT	0
113407	112752	14223L	PARTICIPANT	\N	PRESENT	0
113408	112752	01016M	PARTICIPANT	\N	PRESENT	0
113409	112752	14151M	PARTICIPANT	\N	PRESENT	0
99967	99965	14205J	PARTICIPANT	\N	PRESENT	0
100016	100014	04040A	PARTICIPANT	\N	PRESENT	0
101572	101567	08043V	PARTICIPANT	\N	PRESENT	0
101573	101567	11029K	PARTICIPANT	\N	PRESENT	0
101574	101567	95015C	PARTICIPANT	\N	PRESENT	0
101575	101567	14249W	PARTICIPANT	\N	PRESENT	0
101576	101567	07026Q	PARTICIPANT	\N	PRESENT	0
101577	101567	14061L	PARTICIPANT	\N	PRESENT	0
101579	101567	14059S	PARTICIPANT	\N	PRESENT	0
101580	101567	11104D	PARTICIPANT	\N	PRESENT	0
101581	101567	11014C	PARTICIPANT	\N	PRESENT	0
101636	101633	04054G	PARTICIPANT	\N	PRESENT	0
101638	101633	01044R	PARTICIPANT	\N	PRESENT	0
101640	101633	10006L	PARTICIPANT	\N	PRESENT	0
101641	101633	11091R	PARTICIPANT	\N	PRESENT	0
101644	101633	07026Q	PARTICIPANT	\N	PRESENT	0
101647	101633	80027E	PARTICIPANT	\N	PRESENT	0
101648	101633	04092N	PARTICIPANT	\N	PRESENT	0
101649	101633	11063M	PARTICIPANT	\N	PRESENT	0
101669	101666	96004D	PRESIDENT	0	PRESENT	0
101670	101666	11083R	PARTICIPANT	\N	PRESENT	0
101671	101666	14026U	PARTICIPANT	\N	PRESENT	0
101672	101666	08044W	PARTICIPANT	\N	PRESENT	0
101673	101666	95037J	PARTICIPANT	\N	PRESENT	0
101674	101666	98046X	PARTICIPANT	\N	PRESENT	0
101675	101666	08073C	PARTICIPANT	\N	PRESENT	0
101676	101666	14135M	PARTICIPANT	\N	PRESENT	0
101677	101666	04080J	PARTICIPANT	\N	PRESENT	0
101678	101666	01016M	PARTICIPANT	\N	PRESENT	0
101679	101666	04045F	PARTICIPANT	\N	PRESENT	0
101680	101666	04034C	PARTICIPANT	\N	PRESENT	0
101681	101666	98035U	PARTICIPANT	\N	PRESENT	0
101682	101666	95030B	PARTICIPANT	\N	PRESENT	0
101687	101666	04057K	PARTICIPANT	\N	EXCUSE	0
101688	101666	90003B	PARTICIPANT	\N	EXCUSE	0
101690	101666	01031L	PARTICIPANT	\N	PRESENT	0
101691	101666	08014Q	PARTICIPANT	\N	PRESENT	0
101692	101666	14175V	PARTICIPANT	\N	PRESENT	0
101693	101666	14083S	PARTICIPANT	\N	PRESENT	0
101695	101666	11053K	PARTICIPANT	\N	PRESENT	0
101696	101666	11042G	PARTICIPANT	\N	PRESENT	0
101697	101666	04086Q	PARTICIPANT	\N	PRESENT	0
101698	101666	04055H	PARTICIPANT	\N	PRESENT	0
101699	101666	11088W	PARTICIPANT	\N	PRESENT	0
101700	101666	01027Q	PARTICIPANT	\N	PRESENT	0
101701	101666	01057W	PARTICIPANT	\N	PRESENT	0
101702	101666	99004R	PARTICIPANT	\N	PRESENT	0
101703	101666	14159V	PARTICIPANT	\N	PRESENT	0
101704	101666	07029T	PARTICIPANT	\N	PRESENT	0
101705	101666	08011M	PARTICIPANT	\N	PRESENT	0
101706	101666	08061X	PARTICIPANT	\N	PRESENT	0
101707	101666	14225N	PARTICIPANT	\N	PRESENT	0
101709	101666	14173T	PARTICIPANT	\N	PRESENT	0
101711	101666	08016S	PARTICIPANT	\N	PRESENT	0
101715	101666	08068F	PARTICIPANT	\N	PRESENT	0
101716	101666	14269B	PARTICIPANT	\N	PRESENT	0
101717	101666	89017R	PARTICIPANT	\N	EXCUSE	0
101718	101666	98053W	PARTICIPANT	\N	EXCUSE	0
101720	101666	11085T	PARTICIPANT	\N	EXCUSE	0
102153	102152	01008M	PARTICIPANT	\N	PRESENT	0
102154	102152	11036J	PARTICIPANT	\N	PRESENT	0
102192	102152	95030B	PARTICIPANT	\N	PRESENT	0
102193	102152	11040E	PARTICIPANT	\N	PRESENT	0
102194	102152	04080J	PARTICIPANT	\N	PRESENT	0
102158	102152	14207L	PARTICIPANT	\N	PRESENT	0
102195	102152	11083R	PARTICIPANT	\N	PRESENT	0
102160	102152	90003B	PARTICIPANT	\N	EXCUSE	0
102161	102152	08028W	PARTICIPANT	\N	EXCUSE	0
102162	102152	80013X	PARTICIPANT	\N	PRESENT	0
102163	102152	08038Y	PARTICIPANT	\N	PRESENT	0
102164	102152	04089T	PARTICIPANT	\N	PRESENT	0
102196	102152	14097Y	PARTICIPANT	\N	PRESENT	0
102197	102152	14001X	PARTICIPANT	\N	PRESENT	0
102167	102152	14187A	PARTICIPANT	\N	PRESENT	0
102198	102152	96004D	PARTICIPANT	\N	PRESENT	0
102199	102152	14135M	PARTICIPANT	\N	PRESENT	0
102200	102152	92045V	PARTICIPANT	\N	PRESENT	0
102171	102152	11099A	PARTICIPANT	\N	EXCUSE	0
102201	102152	08044W	PARTICIPANT	\N	PRESENT	0
102202	102152	11012A	PARTICIPANT	\N	PRESENT	0
102203	102152	08018U	PARTICIPANT	\N	PRESENT	0
102175	102152	08015R	PARTICIPANT	\N	PRESENT	0
102176	102152	11100Y	PRESIDENT	0	PRESENT	0
102177	102152	01061S	PARTICIPANT	\N	EXCUSE	0
102204	102152	04045F	PARTICIPANT	\N	PRESENT	0
102205	102152	11109J	PARTICIPANT	\N	PRESENT	0
102206	102152	04059M	PARTICIPANT	\N	PRESENT	0
102207	102152	11029K	PARTICIPANT	\N	PRESENT	0
102208	102152	95015C	PARTICIPANT	\N	PRESENT	0
102183	102152	14257W	PARTICIPANT	\N	PRESENT	0
102209	102152	92015P	PARTICIPANT	\N	PRESENT	0
102185	102152	04088S	PARTICIPANT	\N	PRESENT	0
102186	102152	98050T	PARTICIPANT	\N	PRESENT	0
102210	102152	14209N	PARTICIPANT	\N	PRESENT	0
102188	102152	11046L	PARTICIPANT	\N	PRESENT	0
102189	102152	01058X	PARTICIPANT	\N	PRESENT	0
102211	102152	11089X	PARTICIPANT	\N	PRESENT	0
102191	102152	11066Q	PARTICIPANT	\N	PRESENT	0
102212	102152	07026Q	PARTICIPANT	\N	PRESENT	0
102213	102152	14061L	PARTICIPANT	\N	PRESENT	0
102214	102152	14059S	PARTICIPANT	\N	PRESENT	0
102215	102152	08012N	PARTICIPANT	\N	PRESENT	0
102216	102152	14109K	PARTICIPANT	\N	PRESENT	0
102217	102152	04070G	PARTICIPANT	\N	PRESENT	0
102218	102152	11011M	PARTICIPANT	\N	PRESENT	0
102842	102841	11053K	PARTICIPANT	\N	PRESENT	0
102866	102856	11110B	PARTICIPANT	\N	PRESENT	0
102867	102856	11111C	PARTICIPANT	\N	PRESENT	0
102868	102856	14069U	PARTICIPANT	\N	PRESENT	0
102869	102856	95035G	PARTICIPANT	\N	PRESENT	0
108093	108092	14255U	PARTICIPANT	\N	PRESENT	0
108094	108092	04086Q	PARTICIPANT	\N	PRESENT	0
108095	108092	12042Y	PRESIDENT	0	PRESENT	0
108096	108092	11107G	PARTICIPANT	\N	PRESENT	0
108097	108092	14014Q	PARTICIPANT	\N	PRESENT	0
108098	108092	11112D	PARTICIPANT	\N	PRESENT	0
108099	108092	14205J	PARTICIPANT	\N	PRESENT	0
108100	108092	14135M	PARTICIPANT	\N	PRESENT	0
108101	108092	11097X	PARTICIPANT	\N	PRESENT	0
108102	108092	04045F	PARTICIPANT	\N	PRESENT	0
108103	108092	04050C	PARTICIPANT	\N	PRESENT	0
108104	108092	01027Q	PARTICIPANT	\N	EXCUSE	0
108533	108532	08009T	PARTICIPANT	\N	PRESENT	0
108534	108532	14030Q	PARTICIPANT	\N	PRESENT	0
108535	108532	11026G	PARTICIPANT	\N	PRESENT	0
108536	108532	92031P	PARTICIPANT	\N	PRESENT	0
111763	111714	04034C	PARTICIPANT	\N	PRESENT	0
114147	114146	89017R	PARTICIPANT	\N	PRESENT	0
114148	114146	01031L	PRESIDENT	0	PRESENT	0
114149	114146	01013J	PARTICIPANT	\N	PRESENT	0
114150	114146	11068S	PARTICIPANT	\N	EXCUSE	0
114151	114146	11040E	PARTICIPANT	\N	PRESENT	0
114152	114146	08014Q	PARTICIPANT	\N	PRESENT	0
114155	114146	14167V	PARTICIPANT	\N	PRESENT	0
114156	114146	14175V	PARTICIPANT	\N	PRESENT	0
114158	114146	14083S	PARTICIPANT	\N	PRESENT	0
114159	114146	11053K	PARTICIPANT	\N	PRESENT	0
114161	114146	14085U	PARTICIPANT	\N	PRESENT	0
114164	114146	11042G	PARTICIPANT	\N	PRESENT	0
114165	114146	88008L	PARTICIPANT	\N	PRESENT	0
114168	114146	04086Q	PARTICIPANT	\N	PRESENT	0
114169	114146	11070L	PARTICIPANT	\N	PRESENT	0
114170	114146	11088W	PARTICIPANT	\N	PRESENT	0
114171	114146	14327T	PARTICIPANT	\N	EXCUSE	0
114212	114146	01027Q	PARTICIPANT	\N	PRESENT	0
114213	114146	11074Q	PARTICIPANT	\N	PRESENT	0
114214	114146	98053W	PARTICIPANT	\N	EXCUSE	0
114215	114146	11083R	PARTICIPANT	\N	PRESENT	0
114216	114146	01057W	PARTICIPANT	\N	PRESENT	0
114217	114146	08016S	PARTICIPANT	\N	EXCUSE	0
114218	114146	08069G	PARTICIPANT	\N	PRESENT	0
114219	114146	11048N	PARTICIPANT	\N	PRESENT	0
114220	114146	99004R	PARTICIPANT	\N	PRESENT	0
114221	114146	04061F	PARTICIPANT	\N	PRESENT	0
114222	114146	14159V	PARTICIPANT	\N	PRESENT	0
114223	114146	07029T	PARTICIPANT	\N	EXCUSE	0
114224	114146	08010L	PARTICIPANT	\N	PRESENT	0
114225	114146	08034U	PARTICIPANT	\N	PRESENT	0
114226	114146	98046X	PARTICIPANT	\N	PRESENT	0
114227	114146	08011M	PARTICIPANT	\N	PRESENT	0
114228	114146	08061X	PARTICIPANT	\N	PRESENT	0
114229	114146	01016M	PARTICIPANT	\N	PRESENT	0
114230	114146	14225N	PARTICIPANT	\N	EXCUSE	0
114231	114146	11012A	PARTICIPANT	\N	PRESENT	0
114232	114146	11057P	PARTICIPANT	\N	EXCUSE	0
114233	114146	14173T	PARTICIPANT	\N	PRESENT	0
114234	114146	04034C	PARTICIPANT	\N	PRESENT	0
115012	99613	11023D	PARTICIPANT	\N	PRESENT	0
115013	99613	11114F	PARTICIPANT	\N	PRESENT	0
103451	101913	98053W	PARTICIPANT	\N	PRESENT	0
103452	101913	11105E	PARTICIPANT	\N	PRESENT	0
103453	101913	04042C	PARTICIPANT	\N	PRESENT	0
103454	101913	11048N	PARTICIPANT	\N	PRESENT	0
103455	101913	04049K	PARTICIPANT	\N	PRESENT	0
103472	101913	14111D	PARTICIPANT	\N	PRESENT	0
103449	101913	14059S	PARTICIPANT	\N	PRESENT	0
103450	101913	14265W	PARTICIPANT	\N	PRESENT	0
103473	101913	14195A	PARTICIPANT	\N	PRESENT	0
103474	101913	14014Q	PARTICIPANT	\N	PRESENT	0
103475	101913	08016S	PARTICIPANT	\N	PRESENT	0
106177	106176	01057W	PARTICIPANT	\N	PRESENT	0
106178	106176	14225N	PARTICIPANT	\N	PRESENT	0
106180	106179	14175V	PARTICIPANT	\N	PRESENT	0
106182	106179	14225N	PARTICIPANT	\N	PRESENT	0
106183	106179	11088W	PARTICIPANT	\N	PRESENT	0
106184	106179	08073C	PARTICIPANT	\N	PRESENT	0
106185	106179	98046X	PARTICIPANT	\N	PRESENT	0
106186	106179	11070L	PARTICIPANT	\N	PRESENT	0
106189	106179	14327T	PARTICIPANT	\N	PRESENT	0
106190	106179	04086Q	PARTICIPANT	\N	PRESENT	0
106192	106179	11012A	PARTICIPANT	\N	PRESENT	0
106193	106179	01057W	PARTICIPANT	\N	PRESENT	0
106194	106179	01013J	PARTICIPANT	\N	PRESENT	0
106672	106069	11085T	PARTICIPANT	\N	PRESENT	0
106692	106069	11063M	PARTICIPANT	\N	PRESENT	0
106693	106069	07026Q	PARTICIPANT	\N	PRESENT	0
106694	106069	11031D	PARTICIPANT	\N	PRESENT	0
106695	106069	11061K	PARTICIPANT	\N	PRESENT	0
106696	106069	08052W	PARTICIPANT	\N	PRESENT	0
106697	106069	08016S	PARTICIPANT	\N	PRESENT	0
106698	106069	04053F	PARTICIPANT	\N	PRESENT	0
106699	106069	12042Y	PARTICIPANT	\N	PRESENT	0
106700	106069	11029K	PARTICIPANT	\N	PRESENT	0
106701	106069	14255U	PARTICIPANT	\N	PRESENT	0
106702	106069	14219Q	PARTICIPANT	\N	PRESENT	0
106703	106069	01034P	PARTICIPANT	\N	PRESENT	0
106704	106069	14271U	PARTICIPANT	\N	PRESENT	0
106705	106069	10006L	PARTICIPANT	\N	PRESENT	0
106706	106069	04092N	PARTICIPANT	\N	PRESENT	0
106707	106069	14037X	PARTICIPANT	\N	PRESENT	0
106708	106069	11012A	PARTICIPANT	\N	PRESENT	0
106709	106069	04066L	PARTICIPANT	\N	PRESENT	0
106710	106069	14227Q	PARTICIPANT	\N	PRESENT	0
106711	106069	11011M	PARTICIPANT	\N	PRESENT	0
106712	106069	14034U	PARTICIPANT	\N	PRESENT	0
106713	106069	04086Q	PARTICIPANT	\N	PRESENT	0
106732	106069	14269B	PARTICIPANT	\N	PRESENT	0
106752	106069	07024N	PARTICIPANT	\N	PRESENT	0
106753	106069	04067M	PARTICIPANT	\N	PRESENT	0
106754	106069	11077T	PARTICIPANT	\N	PRESENT	0
106755	106069	14087W	PARTICIPANT	\N	PRESENT	0
106756	106069	04085P	PARTICIPANT	\N	PRESENT	0
106774	106069	98018T	PARTICIPANT	\N	PRESENT	0
106794	106069	14041T	PARTICIPANT	\N	PRESENT	0
106865	106070	14037X	PARTICIPANT	\N	PRESENT	0
106866	106070	14087W	PARTICIPANT	\N	PRESENT	0
106867	106070	14034U	PARTICIPANT	\N	PRESENT	0
106872	106070	11031D	PARTICIPANT	\N	PRESENT	0
106873	106070	07026Q	PARTICIPANT	\N	PRESENT	0
106874	106070	01013J	PARTICIPANT	\N	PRESENT	0
106875	106070	11063M	PARTICIPANT	\N	PRESENT	0
106876	106070	11061K	PARTICIPANT	\N	PRESENT	0
106877	106070	08052W	PARTICIPANT	\N	PRESENT	0
106878	106070	12042Y	PARTICIPANT	\N	PRESENT	0
106879	106070	04053F	PARTICIPANT	\N	PRESENT	0
106880	106070	14271U	PARTICIPANT	\N	PRESENT	0
106881	106070	14269B	PARTICIPANT	\N	PRESENT	0
106882	106070	08016S	PARTICIPANT	\N	PRESENT	0
106883	106070	11029K	PARTICIPANT	\N	PRESENT	0
106884	106070	14255U	PARTICIPANT	\N	PRESENT	0
106885	106070	01034P	PARTICIPANT	\N	PRESENT	0
106886	106070	10006L	PARTICIPANT	\N	PRESENT	0
106887	106070	04086Q	PARTICIPANT	\N	PRESENT	0
106888	106070	11012A	PARTICIPANT	\N	PRESENT	0
106889	106070	04050C	PARTICIPANT	\N	PRESENT	0
106890	106070	04085P	PARTICIPANT	\N	PRESENT	0
106891	106070	11056N	PARTICIPANT	\N	PRESENT	0
106892	106070	14041T	PARTICIPANT	\N	PRESENT	0
106904	106070	98018T	PARTICIPANT	\N	PRESENT	0
106918	106070	11011M	PARTICIPANT	\N	PRESENT	0
106956	106070	04095R	PARTICIPANT	\N	PRESENT	0
106957	106070	11089X	PARTICIPANT	\N	PRESENT	0
106958	106070	11077T	PARTICIPANT	\N	PRESENT	0
107032	106070	04067M	PARTICIPANT	\N	PRESENT	0
107374	107326	89017R	PARTICIPANT	\N	PRESENT	0
106863	106070	04066L	PARTICIPANT	\N	PRESENT	0
106864	106070	04092N	PARTICIPANT	\N	PRESENT	0
107375	107326	01031L	PARTICIPANT	\N	PRESENT	0
107376	107326	11040E	PARTICIPANT	\N	PRESENT	0
107330	107326	14013P	PARTICIPANT	\N	EXCUSE	0
107331	107326	08068F	PARTICIPANT	\N	EXCUSE	0
107332	107326	14207L	PARTICIPANT	\N	PRESENT	0
107377	107326	08014Q	PARTICIPANT	\N	PRESENT	0
107378	107326	11042G	PARTICIPANT	\N	PRESENT	0
107335	107326	08028W	PARTICIPANT	\N	EXCUSE	0
107336	107326	80013X	PARTICIPANT	\N	PRESENT	0
107337	107326	08038Y	PARTICIPANT	\N	PRESENT	0
107379	107326	04086Q	PARTICIPANT	\N	PRESENT	0
107339	107326	14197C	PARTICIPANT	\N	PRESENT	0
107340	107326	11110B	PARTICIPANT	\N	PRESENT	0
107341	107326	14187A	PARTICIPANT	\N	PRESENT	0
107342	107326	14033T	PARTICIPANT	\N	PRESENT	0
107380	107326	11088W	PARTICIPANT	\N	PRESENT	0
107381	107326	04071H	PARTICIPANT	\N	PRESENT	0
107382	107326	11074Q	PARTICIPANT	\N	PRESENT	0
107346	107326	04049K	PARTICIPANT	\N	PRESENT	0
107383	107326	11048N	PARTICIPANT	\N	PRESENT	0
107348	107326	11111C	PARTICIPANT	\N	PRESENT	0
107349	107326	08015R	PARTICIPANT	\N	PRESENT	0
107350	107326	11100Y	PRESIDENT	0	PRESENT	0
107351	107326	01061S	PARTICIPANT	\N	EXCUSE	0
107384	107326	14159V	PARTICIPANT	\N	PRESENT	0
107385	107326	07029T	PARTICIPANT	\N	PRESENT	0
107386	107326	01048V	PARTICIPANT	\N	PRESENT	0
107355	107326	14205J	PARTICIPANT	\N	PRESENT	0
107356	107326	08019V	PARTICIPANT	\N	PRESENT	0
107387	107326	98046X	PARTICIPANT	\N	PRESENT	0
107388	107326	08011M	PARTICIPANT	\N	PRESENT	0
107389	107326	08061X	PARTICIPANT	\N	PRESENT	0
107360	107326	98050T	PARTICIPANT	\N	PRESENT	0
107361	107326	11090Q	PARTICIPANT	\N	PRESENT	0
107390	107326	14225N	PARTICIPANT	\N	PRESENT	0
107363	107326	01058X	PARTICIPANT	\N	PRESENT	0
107391	107326	11057P	PARTICIPANT	\N	PRESENT	0
107365	107326	11066Q	PARTICIPANT	\N	PRESENT	0
107392	107326	14173T	PARTICIPANT	\N	PRESENT	0
107393	107326	11083R	PARTICIPANT	\N	PRESENT	0
107394	107326	05008E	PARTICIPANT	\N	PRESENT	0
107395	107326	04047H	PARTICIPANT	\N	PRESENT	0
107396	107326	04038G	PARTICIPANT	\N	PRESENT	0
107397	107326	11035H	PARTICIPANT	\N	PRESENT	0
107398	107326	14041T	PARTICIPANT	\N	PRESENT	0
107399	107326	11026G	PARTICIPANT	\N	PRESENT	0
107400	107326	14111D	PARTICIPANT	\N	PRESENT	0
107401	107326	14147R	PARTICIPANT	\N	PRESENT	0
107402	107326	08051V	PARTICIPANT	\N	PRESENT	0
107403	107326	11072N	PARTICIPANT	\N	PRESENT	0
107404	107326	07034Q	PARTICIPANT	\N	PRESENT	0
107405	107326	01028R	PARTICIPANT	\N	PRESENT	0
107406	107326	04056J	PARTICIPANT	\N	PRESENT	0
107407	107326	01024M	PARTICIPANT	\N	PRESENT	0
107408	107326	14069U	PARTICIPANT	\N	PRESENT	0
107409	107326	95030B	PARTICIPANT	\N	PRESENT	0
107756	107739	01008M	PARTICIPANT	\N	PRESENT	0
107757	107739	11036J	PARTICIPANT	\N	PRESENT	0
107759	107739	14013P	PARTICIPANT	\N	PRESENT	0
107760	107739	08068F	PARTICIPANT	\N	PRESENT	0
107763	107739	90003B	PARTICIPANT	\N	PRESENT	0
107764	107739	08028W	PARTICIPANT	\N	EXCUSE	0
107765	107739	80013X	PARTICIPANT	\N	PRESENT	0
107767	107739	04089T	PARTICIPANT	\N	PRESENT	0
107768	107739	14197C	PARTICIPANT	\N	PRESENT	0
107769	107739	11110B	PARTICIPANT	\N	PRESENT	0
107770	107739	14187A	PARTICIPANT	\N	PRESENT	0
107771	107739	14033T	PARTICIPANT	\N	PRESENT	0
107774	107739	11099A	PARTICIPANT	\N	PRESENT	0
107775	107739	04049K	PARTICIPANT	\N	PRESENT	0
107777	107739	11111C	PARTICIPANT	\N	PRESENT	0
107778	107739	08015R	PARTICIPANT	\N	PRESENT	0
107779	107739	11100Y	PRESIDENT	0	PRESENT	0
107780	107739	01061S	PARTICIPANT	\N	EXCUSE	0
93342	93341	08051V	PARTICIPANT	\N	PRESENT	0
93343	93341	04040A	PARTICIPANT	\N	PRESENT	0
93344	93341	04056J	PARTICIPANT	\N	PRESENT	0
93345	93341	11026G	PARTICIPANT	\N	PRESENT	0
93346	93341	01028R	PARTICIPANT	\N	PRESENT	0
93347	93341	10015M	PARTICIPANT	\N	PRESENT	0
93348	93341	80027E	PARTICIPANT	\N	PRESENT	0
93349	93341	11106F	PARTICIPANT	\N	PRESENT	0
94573	94572	08022Q	PARTICIPANT	\N	PRESENT	0
94574	94572	04061F	PARTICIPANT	\N	PRESENT	0
94575	94572	08061X	PARTICIPANT	\N	PRESENT	0
94576	94572	01016M	PARTICIPANT	\N	PRESENT	0
94891	94889	14001X	PARTICIPANT	\N	PRESENT	0
94628	94626	01031L	PRESIDENT	0	PRESENT	0
94904	94903	14217N	PARTICIPANT	\N	PRESENT	0
94905	94903	14281W	PARTICIPANT	\N	EXCUSE	0
94631	94626	11068S	PARTICIPANT	\N	PRESENT	0
94632	94626	11040E	PARTICIPANT	\N	PRESENT	0
94633	94626	08014Q	PARTICIPANT	\N	PRESENT	0
94906	94903	07004J	PARTICIPANT	\N	EXCUSE	0
94635	94626	14175V	PARTICIPANT	\N	EXCUSE	0
94907	94903	08041T	PRESIDENT	0	PRESENT	0
94908	94903	04061F	PARTICIPANT	\N	EXCUSE	0
94909	94903	14041T	PARTICIPANT	\N	EXCUSE	0
94639	94626	11042G	PARTICIPANT	\N	PRESENT	0
94910	94903	08053X	PARTICIPANT	\N	PRESENT	0
94641	94626	04086Q	PARTICIPANT	\N	PRESENT	0
94911	94903	11082Q	PARTICIPANT	\N	EXCUSE	0
94643	94626	11070L	PARTICIPANT	\N	PRESENT	0
94644	94626	11088W	PARTICIPANT	\N	PRESENT	0
94912	94903	14193X	PARTICIPANT	\N	EXCUSE	0
94646	94626	08022Q	PRESIDENT	1	PRESENT	0
94647	94626	01027Q	PARTICIPANT	\N	EXCUSE	0
94648	94626	04071H	PARTICIPANT	\N	PRESENT	0
94913	94903	10015M	PARTICIPANT	\N	PRESENT	0
94650	94626	98053W	PARTICIPANT	\N	EXCUSE	0
94651	94626	11083R	PARTICIPANT	\N	PRESENT	0
94949	94948	11109J	PARTICIPANT	\N	PRESENT	0
94950	94948	01044R	PARTICIPANT	\N	PRESENT	0
94951	94948	08043V	PARTICIPANT	\N	PRESENT	0
94952	94948	14089Y	PARTICIPANT	\N	PRESENT	0
94953	94948	11029K	PARTICIPANT	\N	PRESENT	0
94657	94626	99004R	PARTICIPANT	\N	PRESENT	0
94954	94948	92015P	PARTICIPANT	\N	PRESENT	0
94659	94626	14159V	PARTICIPANT	\N	PRESENT	0
94660	94626	07029T	PARTICIPANT	\N	EXCUSE	0
94955	94948	08024S	PARTICIPANT	\N	PRESENT	0
94662	94626	08010L	PARTICIPANT	\N	PRESENT	0
94956	94948	11091R	PARTICIPANT	\N	PRESENT	0
94957	94948	14249W	PARTICIPANT	\N	PRESENT	0
94958	94948	01025N	PARTICIPANT	\N	PRESENT	0
94666	94626	11085T	PARTICIPANT	\N	PRESENT	0
94667	94626	08011M	PARTICIPANT	\N	PRESENT	0
94959	94948	11089X	PARTICIPANT	\N	EXCUSE	0
94669	94626	08061X	PARTICIPANT	\N	PRESENT	0
94960	94948	07026Q	PARTICIPANT	\N	PRESENT	0
94671	94626	14225N	PARTICIPANT	\N	PRESENT	0
94961	94948	14241N	PARTICIPANT	\N	PRESENT	0
94962	94948	14061L	PARTICIPANT	\N	PRESENT	0
94674	94626	14173T	PARTICIPANT	\N	PRESENT	0
94675	94626	04034C	PARTICIPANT	\N	PRESENT	0
94963	94948	14073Q	PARTICIPANT	\N	PRESENT	0
94964	94948	08039A	PARTICIPANT	\N	PRESENT	0
94965	94948	14103D	PARTICIPANT	\N	PRESENT	0
94966	94948	11104D	PARTICIPANT	\N	PRESENT	0
94967	94948	04057K	PARTICIPANT	\N	EXCUSE	0
94968	94948	14109K	PARTICIPANT	\N	PRESENT	0
94969	94948	04070G	PRESIDENT	0	PRESENT	0
94970	94948	14235Q	PARTICIPANT	\N	PRESENT	0
94971	94948	14229S	PARTICIPANT	\N	PRESENT	0
94972	94948	11043H	PARTICIPANT	\N	PRESENT	0
94973	94948	11071M	PARTICIPANT	\N	PRESENT	0
95142	95141	14263U	PARTICIPANT	\N	PRESENT	0
95143	95141	14133K	PARTICIPANT	\N	PRESENT	0
95144	95141	11109J	PARTICIPANT	\N	PRESENT	0
95145	95141	04059M	PARTICIPANT	\N	PRESENT	0
95146	95141	11039M	PARTICIPANT	\N	PRESENT	0
95147	95141	01044R	PARTICIPANT	\N	PRESENT	0
95148	95141	08043V	PARTICIPANT	\N	PRESENT	0
95149	95141	14089Y	PARTICIPANT	\N	PRESENT	0
95620	95591	14001X	PARTICIPANT	\N	PRESENT	0
95151	95141	11029K	PARTICIPANT	\N	PRESENT	0
95152	95141	95015C	PRESIDENT	0	PRESENT	0
95153	95141	92015P	PARTICIPANT	\N	PRESENT	0
95154	95141	08024S	PARTICIPANT	\N	PRESENT	0
95155	95141	14201E	PARTICIPANT	\N	PRESENT	0
95156	95141	14329V	PARTICIPANT	\N	PRESENT	0
95157	95141	14209N	PARTICIPANT	\N	PRESENT	0
95158	95141	14079W	PARTICIPANT	\N	PRESENT	0
95159	95141	11091R	PARTICIPANT	\N	PRESENT	0
95160	95141	87003B	PARTICIPANT	\N	PRESENT	0
95161	95141	98042T	PARTICIPANT	\N	PRESENT	0
95162	95141	14249W	PARTICIPANT	\N	PRESENT	0
95163	95141	01041N	PARTICIPANT	\N	PRESENT	0
95164	95141	01025N	PARTICIPANT	\N	PRESENT	0
95165	95141	01037S	PARTICIPANT	\N	PRESENT	0
95166	95141	89029V	PARTICIPANT	\N	PRESENT	0
95621	95591	14273W	PARTICIPANT	\N	PRESENT	0
95168	95141	11089X	PARTICIPANT	\N	PRESENT	0
95169	95141	07026Q	PARTICIPANT	\N	PRESENT	0
95622	95591	01060R	PARTICIPANT	\N	PRESENT	0
95623	95591	14147R	PARTICIPANT	\N	PRESENT	0
95624	95591	95049N	PARTICIPANT	\N	PRESENT	0
95173	95141	14241N	PARTICIPANT	\N	PRESENT	0
95174	95141	14061L	PARTICIPANT	\N	PRESENT	0
95175	95141	14073Q	PARTICIPANT	\N	PRESENT	0
95176	95141	08031R	PARTICIPANT	\N	PRESENT	0
95177	95141	12041X	PARTICIPANT	\N	PRESENT	0
95178	95141	08039A	PARTICIPANT	\N	PRESENT	0
95625	95591	08051V	PARTICIPANT	\N	PRESENT	0
95180	95141	14059S	PARTICIPANT	\N	PRESENT	0
95181	95141	08012N	PARTICIPANT	\N	PRESENT	0
95182	95141	14103D	PARTICIPANT	\N	PRESENT	0
95183	95141	11104D	PARTICIPANT	\N	PRESENT	0
95184	95141	14063N	PARTICIPANT	\N	PRESENT	0
95185	95141	04057K	PARTICIPANT	\N	EXCUSE	0
95186	95141	11014C	PARTICIPANT	\N	PRESENT	0
95187	95141	14109K	PARTICIPANT	\N	PRESENT	0
95188	95141	04070G	PRESIDENT	1	PRESENT	0
95189	95141	92040Q	PARTICIPANT	\N	PRESENT	0
95190	95141	14191V	PARTICIPANT	\N	PRESENT	0
95626	95591	11072N	PARTICIPANT	\N	PRESENT	0
95192	95141	14235Q	PARTICIPANT	\N	PRESENT	0
95627	95591	07034Q	PRESIDENT	1	PRESENT	0
95194	95141	04033B	PARTICIPANT	\N	PRESENT	0
95195	95141	14229S	PARTICIPANT	\N	PRESENT	0
95196	95141	11043H	PARTICIPANT	\N	PRESENT	0
95197	95141	11071M	PARTICIPANT	\N	PRESENT	0
95628	95591	04074L	PARTICIPANT	\N	PRESENT	0
95629	95591	10015M	PARTICIPANT	\N	PRESENT	0
95630	95591	95063L	PARTICIPANT	\N	PRESENT	0
95631	95591	01019Q	PARTICIPANT	\N	PRESENT	0
95632	95591	01028R	PARTICIPANT	\N	PRESENT	0
95633	95591	98035U	PARTICIPANT	\N	PRESENT	0
95634	95591	04056J	PARTICIPANT	\N	PRESENT	0
95635	95591	14275Y	PARTICIPANT	\N	PRESENT	0
97352	94613	96003C	PARTICIPANT	\N	EXCUSE	0
95637	95591	11037K	PARTICIPANT	\N	EXCUSE	0
95638	95591	92045V	PARTICIPANT	\N	PRESENT	0
95639	95591	95067Q	PARTICIPANT	\N	PRESENT	0
95640	95591	01047U	PARTICIPANT	\N	PRESENT	0
95646	95591	14089Y	PARTICIPANT	\N	PRESENT	0
97372	94613	95062K	PARTICIPANT	\N	EXCUSE	0
97373	94613	04043D	PARTICIPANT	\N	EXCUSE	0
97416	94613	08019V	PARTICIPANT	\N	EXCUSE	0
102871	102870	14026U	PARTICIPANT	\N	PRESENT	0
102872	102870	11107G	PARTICIPANT	\N	PRESENT	0
102873	102870	04086Q	PARTICIPANT	\N	PRESENT	0
102874	102870	01027Q	PARTICIPANT	\N	PRESENT	0
102875	102870	12042Y	PRESIDENT	0	PRESENT	0
102876	102870	14135M	PARTICIPANT	\N	PRESENT	0
102877	102870	11100Y	PARTICIPANT	\N	EXCUSE	0
102893	102892	11107G	PARTICIPANT	\N	PRESENT	0
102894	102892	12042Y	PRESIDENT	0	PRESENT	0
102895	102892	14227Q	PARTICIPANT	\N	PRESENT	0
102896	102892	04086Q	PARTICIPANT	\N	PRESENT	0
102897	102892	11097X	PARTICIPANT	\N	PRESENT	0
102898	102892	04045F	PARTICIPANT	\N	PRESENT	0
102899	102892	14255U	PARTICIPANT	\N	PRESENT	0
102900	102892	14135M	PARTICIPANT	\N	PRESENT	0
103533	103532	04053F	PARTICIPANT	\N	PRESENT	0
103534	103532	14255U	PARTICIPANT	\N	PRESENT	0
103535	103532	04066L	PARTICIPANT	\N	PRESENT	0
103536	103532	14053L	PARTICIPANT	\N	PRESENT	0
103537	103532	11103C	PARTICIPANT	\N	PRESENT	0
103538	103532	11044J	PARTICIPANT	\N	PRESENT	0
103539	103532	14195A	PARTICIPANT	\N	PRESENT	0
103540	103532	14267Y	PARTICIPANT	\N	PRESENT	0
103541	103532	10006L	PARTICIPANT	\N	PRESENT	0
113410	112752	04053F	PARTICIPANT	\N	PRESENT	0
115212	115194	14195A	PARTICIPANT	\N	PRESENT	0
115213	115194	14217N	PARTICIPANT	\N	PRESENT	0
115214	115194	14037X	PARTICIPANT	\N	PRESENT	0
115215	115194	14205J	PARTICIPANT	\N	PRESENT	0
115216	115194	14265W	PARTICIPANT	\N	PRESENT	0
115218	115194	83047W	PARTICIPANT	\N	PRESENT	0
115219	115194	04045F	PARTICIPANT	\N	PRESENT	0
115222	115194	01034P	PRESIDENT	0	PRESENT	0
115224	115194	92045V	PARTICIPANT	\N	PRESENT	0
115231	115194	14079W	PARTICIPANT	\N	EXCUSE	0
115235	115194	14235Q	PARTICIPANT	\N	EXCUSE	0
115237	115194	14249W	PARTICIPANT	\N	EXCUSE	0
115689	115688	97011G	PARTICIPANT	\N	PRESENT	0
115691	115690	11084S	PARTICIPANT	\N	PRESENT	0
115695	115694	89017R	PARTICIPANT	\N	EXCUSE	0
115696	115694	01031L	PARTICIPANT	\N	PRESENT	0
115697	115694	01013J	PARTICIPANT	\N	PRESENT	0
115698	115694	11068S	PARTICIPANT	\N	EXCUSE	0
115699	115694	14175V	PARTICIPANT	\N	PRESENT	0
115700	115694	04086Q	PARTICIPANT	\N	PRESENT	0
115701	115694	11088W	PARTICIPANT	\N	PRESENT	0
115702	115694	98053W	PARTICIPANT	\N	PRESENT	0
115703	115694	11083R	PARTICIPANT	\N	PRESENT	0
115704	115694	08016S	PARTICIPANT	\N	EXCUSE	0
115705	115694	98046X	PARTICIPANT	\N	PRESENT	0
115706	115694	11085T	PARTICIPANT	\N	PRESENT	0
115707	115694	08011M	PARTICIPANT	\N	PRESENT	0
115708	115694	01016M	PARTICIPANT	\N	PRESENT	0
115709	115694	14225N	PARTICIPANT	\N	EXCUSE	0
115710	115694	04034C	PARTICIPANT	\N	PRESENT	0
115753	115752	14079W	PARTICIPANT	\N	EXCUSE	0
115754	115752	04067M	PARTICIPANT	\N	PRESENT	0
115755	115752	14249W	PARTICIPANT	\N	EXCUSE	0
115756	115752	08034U	PARTICIPANT	\N	PRESENT	0
115757	115752	83047W	PARTICIPANT	\N	PRESENT	0
115758	115752	14235Q	PARTICIPANT	\N	EXCUSE	0
115759	115752	01034P	PARTICIPANT	\N	EXCUSE	0
115760	115752	92045V	PARTICIPANT	\N	PRESENT	0
115795	115794	11053K	PARTICIPANT	\N	PRESENT	0
115813	115812	04055H	PARTICIPANT	\N	PRESENT	0
115817	115816	04086Q	PARTICIPANT	\N	PRESENT	0
115834	115833	08034U	PARTICIPANT	\N	PRESENT	0
115836	115835	08034U	PARTICIPANT	\N	PRESENT	0
117156	117155	89017R	PARTICIPANT	\N	EXCUSE	0
117157	117155	01031L	PRESIDENT	0	PRESENT	0
117205	117155	11097X	PARTICIPANT	\N	PRESENT	0
117159	117155	01013J	PARTICIPANT	\N	PRESENT	0
117160	117155	11068S	PARTICIPANT	\N	EXCUSE	0
117161	117155	11040E	PARTICIPANT	\N	PRESENT	0
117162	117155	08014Q	PARTICIPANT	\N	PRESENT	0
117432	117372	14193X	PARTICIPANT	\N	PRESENT	0
117376	117372	04054G	PARTICIPANT	\N	PRESENT	0
117165	117155	14083S	PARTICIPANT	\N	PRESENT	0
117166	117155	11053K	PARTICIPANT	\N	PRESENT	0
117167	117155	14085U	PARTICIPANT	\N	PRESENT	0
117168	117155	11042G	PARTICIPANT	\N	PRESENT	0
117377	117372	04040A	PARTICIPANT	\N	PRESENT	0
117170	117155	04086Q	PARTICIPANT	\N	PRESENT	0
117171	117155	04055H	PARTICIPANT	\N	PRESENT	0
117378	117372	08058D	PARTICIPANT	\N	PRESENT	0
117173	117155	11088W	PARTICIPANT	\N	PRESENT	0
117174	117155	14327T	PARTICIPANT	\N	PRESENT	0
117379	117372	04042C	PARTICIPANT	\N	PRESENT	0
117176	117155	01027Q	PARTICIPANT	\N	PRESENT	0
117455	117454	04086Q	PARTICIPANT	\N	PRESENT	0
117178	117155	11074Q	PARTICIPANT	\N	PRESENT	0
117482	117481	04086Q	PARTICIPANT	\N	PRESENT	0
117180	117155	11083R	PARTICIPANT	\N	PRESENT	0
117181	117155	14199E	PARTICIPANT	\N	PRESENT	0
117182	117155	01057W	PARTICIPANT	\N	PRESENT	0
117183	117155	08016S	PARTICIPANT	\N	PRESENT	0
117486	117484	04086Q	PARTICIPANT	\N	PRESENT	0
117185	117155	11048N	PARTICIPANT	\N	PRESENT	0
117186	117155	99004R	PARTICIPANT	\N	PRESENT	0
117187	117155	04061F	PARTICIPANT	\N	PRESENT	0
117188	117155	14159V	PARTICIPANT	\N	PRESENT	0
117189	117155	07029T	PARTICIPANT	\N	EXCUSE	0
117383	117372	11027H	PARTICIPANT	\N	PRESENT	0
117191	117155	08010L	PARTICIPANT	\N	PRESENT	0
117553	117552	14133K	PARTICIPANT	\N	PRESENT	0
117385	117372	92018S	PARTICIPANT	\N	PRESENT	0
117194	117155	98046X	PARTICIPANT	\N	PRESENT	0
117386	117372	92020L	PARTICIPANT	\N	PRESENT	0
117196	117155	08011M	PARTICIPANT	\N	PRESENT	0
117387	117372	95030B	PARTICIPANT	\N	PRESENT	0
117198	117155	08061X	PARTICIPANT	\N	PRESENT	0
117199	117155	01016M	PARTICIPANT	\N	PRESENT	0
117200	117155	14225N	PARTICIPANT	\N	PRESENT	0
117201	117155	11012A	PARTICIPANT	\N	PRESENT	0
117554	117552	96004D	PRESIDENT	0	PRESENT	0
117203	117155	14173T	PARTICIPANT	\N	PRESENT	0
117555	117552	04054G	PARTICIPANT	\N	PRESENT	0
117390	117372	97011G	PARTICIPANT	\N	PRESENT	0
117391	117372	08065C	PARTICIPANT	\N	PRESENT	0
117556	117552	95030B	PARTICIPANT	\N	PRESENT	0
117393	117372	07024N	PARTICIPANT	\N	PRESENT	0
117557	117552	11083R	PARTICIPANT	\N	PRESENT	0
117395	117372	14014Q	PARTICIPANT	\N	PRESENT	0
117396	117372	11015D	PARTICIPANT	\N	PRESENT	0
117397	117372	07004J	PARTICIPANT	\N	PRESENT	0
117558	117552	14097Y	PARTICIPANT	\N	PRESENT	0
117399	117372	08056B	PARTICIPANT	\N	EXCUSE	0
117559	117552	04080J	PARTICIPANT	\N	PRESENT	0
117560	117552	14135M	PARTICIPANT	\N	PRESENT	0
117402	117372	11064N	PARTICIPANT	\N	PRESENT	0
117403	117372	95037J	PARTICIPANT	\N	PRESENT	0
117561	117552	11012A	PARTICIPANT	\N	PRESENT	0
117405	117372	14097Y	PARTICIPANT	\N	PRESENT	0
117406	117372	95041E	PARTICIPANT	\N	PRESENT	0
117407	117372	04036E	PARTICIPANT	\N	PRESENT	0
117562	117552	92045V	PARTICIPANT	\N	PRESENT	0
117563	117552	04035D	PARTICIPANT	\N	EXCUSE	0
117564	117552	98046X	PARTICIPANT	\N	EXCUSE	0
117411	117372	92031P	PARTICIPANT	\N	PRESENT	0
117412	117372	11106F	PARTICIPANT	\N	PRESENT	0
117413	117372	14251Q	PARTICIPANT	\N	PRESENT	0
117414	117372	83042R	PARTICIPANT	\N	EXCUSE	0
117415	117372	08053X	PARTICIPANT	\N	PRESENT	0
117565	117552	04045F	PARTICIPANT	\N	EXCUSE	0
117417	117372	11105E	PARTICIPANT	\N	PRESENT	0
117418	117372	14253S	PARTICIPANT	\N	PRESENT	0
117419	117372	08047A	PARTICIPANT	\N	PRESENT	0
117420	117372	14028W	PARTICIPANT	\N	EXCUSE	0
117566	117552	10015M	PARTICIPANT	\N	EXCUSE	0
117422	117372	98021N	PARTICIPANT	\N	EXCUSE	0
117423	117372	04080J	PARTICIPANT	\N	PRESENT	0
117424	117372	95059Q	PRESIDENT	0	PRESENT	0
117593	117592	01016M	PARTICIPANT	\N	PRESENT	0
117426	117372	01014K	PARTICIPANT	\N	PRESENT	0
117427	117372	11054L	PARTICIPANT	\N	PRESENT	0
117428	117372	01056V	PARTICIPANT	\N	PRESENT	0
117595	117594	01016M	PARTICIPANT	\N	PRESENT	0
117632	117614	01016M	PARTICIPANT	\N	PRESENT	0
117634	117633	01016M	PARTICIPANT	\N	PRESENT	0
117693	117692	04086Q	PARTICIPANT	\N	PRESENT	0
117695	117694	04086Q	PARTICIPANT	\N	PRESENT	0
117753	117752	08034U	PARTICIPANT	\N	PRESENT	0
117755	117754	01027Q	PARTICIPANT	\N	PRESENT	0
117772	117732	04055H	PARTICIPANT	\N	PRESENT	0
117773	117733	04055H	PARTICIPANT	\N	PRESENT	0
117792	117572	04081K	PARTICIPANT	\N	PRESENT	0
117793	117572	14225N	PARTICIPANT	\N	PRESENT	0
117794	117572	11109J	PARTICIPANT	\N	PRESENT	0
117795	117572	11114F	PARTICIPANT	\N	PRESENT	0
117796	117572	07004J	PARTICIPANT	\N	PRESENT	0
117797	117572	14053L	PARTICIPANT	\N	PRESENT	0
117798	117572	04036E	PARTICIPANT	\N	PRESENT	0
117799	117572	14261S	PARTICIPANT	\N	PRESENT	0
117800	117572	11057P	PARTICIPANT	\N	PRESENT	0
117801	117572	14231L	PARTICIPANT	\N	PRESENT	0
117802	117572	14273W	PARTICIPANT	\N	PRESENT	0
117803	117572	14018U	PARTICIPANT	\N	PRESENT	0
117804	117572	14105F	PARTICIPANT	\N	PRESENT	0
117805	117572	14087W	PARTICIPANT	\N	PRESENT	0
117819	117572	08014Q	PARTICIPANT	\N	PRESENT	0
117820	117572	08060W	PARTICIPANT	\N	PRESENT	0
117821	117572	08028W	PARTICIPANT	\N	PRESENT	0
117822	117572	14041T	PARTICIPANT	\N	PRESENT	0
117823	117572	11039M	PARTICIPANT	\N	PRESENT	0
117824	117572	14257W	PARTICIPANT	\N	PRESENT	0
117826	117572	14327T	PARTICIPANT	\N	PRESENT	0
117827	117572	14217N	PARTICIPANT	\N	PRESENT	0
117828	117572	11066Q	PARTICIPANT	\N	PRESENT	0
117829	117572	14235Q	PARTICIPANT	\N	PRESENT	0
117830	117572	14241N	PARTICIPANT	\N	PRESENT	0
117831	117572	87003B	PARTICIPANT	\N	PRESENT	0
117832	117572	14038Y	PARTICIPANT	\N	PRESENT	0
93553	93547	11076S	PARTICIPANT	\N	PRESENT	0
93554	93547	04054G	PARTICIPANT	\N	PRESENT	0
93555	93547	04040A	PARTICIPANT	\N	PRESENT	0
93556	93547	08058D	PARTICIPANT	\N	PRESENT	0
93557	93547	04042C	PARTICIPANT	\N	PRESENT	0
93558	93547	77002U	PARTICIPANT	\N	PRESENT	0
93559	93547	11027H	PARTICIPANT	\N	PRESENT	0
93560	93547	98018T	PARTICIPANT	\N	PRESENT	0
93561	93547	92018S	PARTICIPANT	\N	EXCUSE	0
93562	93547	92020L	PARTICIPANT	\N	PRESENT	0
93563	93547	95030B	PARTICIPANT	\N	PRESENT	0
93564	93547	97011G	PARTICIPANT	\N	PRESENT	0
93565	93547	08065C	PARTICIPANT	\N	PRESENT	0
93566	93547	04035D	PARTICIPANT	\N	PRESENT	0
93567	93547	07024N	PARTICIPANT	\N	PRESENT	0
93568	93547	14014Q	PARTICIPANT	\N	PRESENT	0
93569	93547	07004J	PARTICIPANT	\N	PRESENT	0
93570	93547	95035G	PARTICIPANT	\N	PRESENT	0
93571	93547	08056B	PARTICIPANT	\N	PRESENT	0
93572	93547	14211G	PARTICIPANT	\N	PRESENT	0
93573	93547	98022P	PARTICIPANT	\N	EXCUSE	0
93574	93547	11064N	PARTICIPANT	\N	PRESENT	0
93575	93547	95037J	PARTICIPANT	\N	PRESENT	0
93576	93547	04078Q	PARTICIPANT	\N	PRESENT	0
93577	93547	14097Y	PARTICIPANT	\N	PRESENT	0
93578	93547	95041E	PARTICIPANT	\N	PRESENT	0
93579	93547	04036E	PARTICIPANT	\N	PRESENT	0
93580	93547	14039A	PARTICIPANT	\N	PRESENT	0
93581	93547	04077P	PARTICIPANT	\N	PRESENT	0
93582	93547	92031P	PARTICIPANT	\N	PRESENT	0
93583	93547	11106F	PARTICIPANT	\N	PRESENT	0
93584	93547	14251Q	PARTICIPANT	\N	PRESENT	0
93585	93547	08053X	PARTICIPANT	\N	PRESENT	0
93586	93547	11105E	PARTICIPANT	\N	PRESENT	0
93587	93547	14253S	PARTICIPANT	\N	PRESENT	0
93588	93547	08047A	PARTICIPANT	\N	PRESENT	0
93589	93547	14028W	PARTICIPANT	\N	PRESENT	0
93590	93547	14193X	PARTICIPANT	\N	PRESENT	0
93591	93547	98021N	PARTICIPANT	\N	EXCUSE	0
93592	93547	95059Q	PRESIDENT	0	PRESENT	0
93593	93547	86044G	PARTICIPANT	\N	PRESENT	0
93594	93547	01014K	PARTICIPANT	\N	PRESENT	0
93595	93547	11054L	PARTICIPANT	\N	PRESENT	0
93596	93547	01056V	PARTICIPANT	\N	PRESENT	0
93597	93547	92044U	PARTICIPANT	\N	PRESENT	0
93598	93547	08049C	PARTICIPANT	\N	EXCUSE	0
93599	93547	04050C	PARTICIPANT	\N	PRESENT	0
93600	93547	14093U	PARTICIPANT	\N	PRESENT	0
93601	93547	04061F	PARTICIPANT	\N	PRESENT	0
93602	93547	88008L	PARTICIPANT	\N	PRESENT	0
100526	100449	11105E	PARTICIPANT	\N	EXCUSE	0
103702	103691	14263U	PARTICIPANT	\N	EXCUSE	0
103704	103691	01046T	PARTICIPANT	\N	EXCUSE	0
103705	103691	11036J	PARTICIPANT	\N	EXCUSE	0
103706	103691	11061K	PARTICIPANT	\N	EXCUSE	0
103708	103691	08069G	PARTICIPANT	\N	EXCUSE	0
103710	103691	04061F	PARTICIPANT	\N	EXCUSE	0
103711	103691	08039A	PARTICIPANT	\N	EXCUSE	0
103712	103691	01048V	PARTICIPANT	\N	EXCUSE	0
103713	103691	14221J	PARTICIPANT	\N	EXCUSE	0
103714	103691	14257W	PARTICIPANT	\N	EXCUSE	0
103716	103691	11082Q	PARTICIPANT	\N	EXCUSE	0
103717	103691	04043D	PARTICIPANT	\N	EXCUSE	0
103718	103691	01058X	PARTICIPANT	\N	EXCUSE	0
103735	103691	14299H	PARTICIPANT	\N	PRESENT	0
103738	103691	80013X	PARTICIPANT	\N	EXCUSE	0
108731	108730	14239U	PARTICIPANT	\N	EXCUSE	0
108732	108730	11055M	PARTICIPANT	\N	PRESENT	0
108733	108730	01046T	PARTICIPANT	\N	PRESENT	0
108734	108730	04053F	PARTICIPANT	\N	PRESENT	0
108735	108730	14255U	PARTICIPANT	\N	PRESENT	0
108738	108730	14053L	PARTICIPANT	\N	PRESENT	0
108739	108730	11103C	PARTICIPANT	\N	PRESENT	0
108740	108730	11044J	PARTICIPANT	\N	EXCUSE	0
108741	108730	14195A	PARTICIPANT	\N	PRESENT	0
108890	108887	04040A	PARTICIPANT	\N	PRESENT	0
108891	108887	08058D	PARTICIPANT	\N	PRESENT	0
108744	108730	11031D	PARTICIPANT	\N	PRESENT	0
108745	108730	08052W	PARTICIPANT	\N	PRESENT	0
108747	108730	04081K	PARTICIPANT	\N	PRESENT	0
108748	108730	98024R	PARTICIPANT	\N	PRESENT	0
108750	108730	04067M	PARTICIPANT	\N	PRESENT	0
108751	108730	14217N	PARTICIPANT	\N	PRESENT	0
108752	108730	14042U	PARTICIPANT	\N	PRESENT	0
108753	108730	14151M	PARTICIPANT	\N	PRESENT	0
108754	108730	12042Y	PARTICIPANT	\N	PRESENT	0
108755	108730	14281W	PARTICIPANT	\N	PRESENT	0
108756	108730	14087W	PARTICIPANT	\N	PRESENT	0
108894	108887	98029W	PARTICIPANT	\N	PRESENT	0
108758	108730	14034U	PARTICIPANT	\N	PRESENT	0
108759	108730	14231L	PARTICIPANT	\N	PRESENT	0
108760	108730	11061K	PARTICIPANT	\N	PRESENT	0
108761	108730	08048B	PARTICIPANT	\N	PRESENT	0
108762	108730	08041T	PARTICIPANT	\N	PRESENT	0
108763	108730	01011G	PARTICIPANT	\N	PRESENT	0
108764	108730	14026U	PARTICIPANT	\N	PRESENT	0
108765	108730	14213J	PARTICIPANT	\N	PRESENT	0
108766	108730	14121F	PARTICIPANT	\N	PRESENT	0
108767	108730	11112D	PARTICIPANT	\N	PRESENT	0
108768	108730	14037X	PARTICIPANT	\N	PRESENT	0
108769	108730	14018U	PARTICIPANT	\N	PRESENT	0
108770	108730	11067R	PARTICIPANT	\N	PRESENT	0
108771	108730	14223L	PARTICIPANT	\N	PRESENT	0
108772	108730	04092N	PRESIDENT	0	PRESENT	0
108773	108730	14265W	PARTICIPANT	\N	PRESENT	0
108895	108887	11080N	PARTICIPANT	\N	PRESENT	0
108775	108730	14071N	PARTICIPANT	\N	PRESENT	0
108776	108730	07032N	PARTICIPANT	\N	PRESENT	0
108777	108730	04043D	PARTICIPANT	\N	PRESENT	0
108778	108730	14271U	PARTICIPANT	\N	PRESENT	0
108779	108730	14017T	PARTICIPANT	\N	EXCUSE	0
108896	108887	11027H	PARTICIPANT	\N	PRESENT	0
108781	108730	11097X	PARTICIPANT	\N	PRESENT	0
108782	108730	04045F	PARTICIPANT	\N	PRESENT	0
108783	108730	14227Q	PARTICIPANT	\N	PRESENT	0
108784	108730	01034P	PARTICIPANT	\N	PRESENT	0
108897	108887	98018T	PARTICIPANT	\N	PRESENT	0
108898	108887	92018S	PARTICIPANT	\N	PRESENT	0
108787	108730	14269B	PARTICIPANT	\N	PRESENT	0
108900	108887	95030B	PARTICIPANT	\N	PRESENT	0
108904	108887	08065C	PARTICIPANT	\N	EXCUSE	0
108905	108887	04035D	PARTICIPANT	\N	PRESENT	0
108906	108887	07024N	PARTICIPANT	\N	PRESENT	0
108908	108887	14014Q	PARTICIPANT	\N	PRESENT	0
108910	108887	07004J	PARTICIPANT	\N	EXCUSE	0
108911	108887	95035G	PARTICIPANT	\N	EXCUSE	0
108912	108887	08056B	PARTICIPANT	\N	EXCUSE	0
108916	108887	95037J	PARTICIPANT	\N	PRESENT	0
108918	108887	14097Y	PARTICIPANT	\N	PRESENT	0
108920	108887	04036E	PARTICIPANT	\N	PRESENT	0
108923	108887	98005N	PARTICIPANT	\N	PRESENT	0
108924	108887	92031P	PARTICIPANT	\N	PRESENT	0
108925	108887	11106F	PARTICIPANT	\N	PRESENT	0
108926	108887	14251Q	PARTICIPANT	\N	PRESENT	0
108927	108887	83042R	PARTICIPANT	\N	PRESENT	0
108930	108887	11105E	PARTICIPANT	\N	PRESENT	0
108932	108887	08047A	PARTICIPANT	\N	PRESENT	0
108933	108887	14028W	PARTICIPANT	\N	PRESENT	0
108934	108887	14193X	PARTICIPANT	\N	PRESENT	0
108937	108887	95059Q	PRESIDENT	0	PRESENT	0
108938	108887	86044G	PARTICIPANT	\N	PRESENT	0
108939	108887	01014K	PARTICIPANT	\N	PRESENT	0
107781	107739	11098Y	PARTICIPANT	\N	PRESENT	0
108312	108092	14026U	PARTICIPANT	\N	EXCUSE	0
107783	107739	11077T	PARTICIPANT	\N	PRESENT	0
108313	108092	11100Y	PARTICIPANT	\N	EXCUSE	0
107785	107739	08019V	PARTICIPANT	\N	PRESENT	0
108538	108537	11031D	PARTICIPANT	\N	PRESENT	0
108539	108537	11076S	PARTICIPANT	\N	PRESENT	0
107788	107739	04088S	PARTICIPANT	\N	PRESENT	0
108540	108537	04054G	PARTICIPANT	\N	PRESENT	0
107790	107739	11090Q	PARTICIPANT	\N	PRESENT	0
107791	107739	11046L	PARTICIPANT	\N	PRESENT	0
107792	107739	01058X	PARTICIPANT	\N	PRESENT	0
107793	107739	11094U	PARTICIPANT	\N	PRESENT	0
107794	107739	11066Q	PARTICIPANT	\N	PRESENT	0
108541	108537	11106F	PARTICIPANT	\N	PRESENT	0
108542	108537	95067Q	PARTICIPANT	\N	PRESENT	0
108596	107732	04081K	PARTICIPANT	\N	PRESENT	0
108597	107732	11031D	PARTICIPANT	\N	PRESENT	0
108598	107732	01059Y	PARTICIPANT	\N	PRESENT	0
108599	107732	04085P	PARTICIPANT	\N	PRESENT	0
108600	107732	14227Q	PARTICIPANT	\N	PRESENT	0
108601	107732	08052W	PARTICIPANT	\N	PRESENT	0
108602	107732	11055M	PARTICIPANT	\N	PRESENT	0
108603	107732	14231L	PARTICIPANT	\N	PRESENT	0
108604	107732	14087W	PARTICIPANT	\N	PRESENT	0
108605	107732	04092N	PARTICIPANT	\N	PRESENT	0
108606	107732	14269B	PARTICIPANT	\N	PRESENT	0
108607	107732	14271U	PARTICIPANT	\N	PRESENT	0
108608	107732	08016S	PARTICIPANT	\N	PRESENT	0
108609	107732	04053F	PARTICIPANT	\N	PRESENT	0
108610	107732	14197C	PARTICIPANT	\N	PRESENT	0
108611	107732	11066Q	PARTICIPANT	\N	PRESENT	0
108612	107732	04088S	PARTICIPANT	\N	PRESENT	0
108613	107732	14041T	PARTICIPANT	\N	PRESENT	0
108614	107732	11011M	PARTICIPANT	\N	PRESENT	0
108615	107732	14265W	PARTICIPANT	\N	PRESENT	0
108616	107732	14195A	PARTICIPANT	\N	PRESENT	0
108617	107732	14175V	PARTICIPANT	\N	PRESENT	0
108618	107732	14235Q	PARTICIPANT	\N	PRESENT	0
108619	107732	04050C	PARTICIPANT	\N	PRESENT	0
108620	107732	14263U	PARTICIPANT	\N	PRESENT	0
108621	107732	01031L	PARTICIPANT	\N	PRESENT	0
108622	107732	14107H	PARTICIPANT	\N	PRESENT	0
108623	107732	01047U	PARTICIPANT	\N	PRESENT	0
108624	107732	01046T	PARTICIPANT	\N	PRESENT	0
108625	107732	14037X	PARTICIPANT	\N	PRESENT	0
108626	107732	11103C	PARTICIPANT	\N	PRESENT	0
108627	107732	95067Q	PARTICIPANT	\N	PRESENT	0
108628	107732	14030Q	PARTICIPANT	\N	PRESENT	0
108629	107732	04067M	PARTICIPANT	\N	PRESENT	0
108630	107732	14083S	PARTICIPANT	\N	PRESENT	0
108632	107732	14059S	PARTICIPANT	\N	PRESENT	0
108633	107732	14053L	PARTICIPANT	\N	PRESENT	0
108634	107732	12042Y	PARTICIPANT	\N	PRESENT	0
108694	107732	11054L	PARTICIPANT	\N	PRESENT	0
108695	107732	14261S	PARTICIPANT	\N	PRESENT	0
108637	108631	04040A	PARTICIPANT	\N	PRESENT	0
108638	108631	08058D	PARTICIPANT	\N	PRESENT	0
108696	107732	14223L	PARTICIPANT	\N	PRESENT	0
108640	108631	77002U	PARTICIPANT	\N	PRESENT	0
108641	108631	98029W	PARTICIPANT	\N	PRESENT	0
108698	107732	14103D	PARTICIPANT	\N	PRESENT	0
108643	108631	11027H	PARTICIPANT	\N	PRESENT	0
108644	108631	98018T	PARTICIPANT	\N	PRESENT	0
108645	108631	92018S	PARTICIPANT	\N	PRESENT	0
108699	107732	14018U	PARTICIPANT	\N	PRESENT	0
108647	108631	95030B	PARTICIPANT	\N	PRESENT	0
108700	107732	01034P	PARTICIPANT	\N	PRESENT	0
108701	107732	08068F	PARTICIPANT	\N	PRESENT	0
108702	107732	11089X	PARTICIPANT	\N	PRESENT	0
108651	108631	08065C	PARTICIPANT	\N	EXCUSE	0
108652	108631	04035D	PARTICIPANT	\N	PRESENT	0
108703	107732	98018T	PARTICIPANT	\N	PRESENT	0
108704	107732	14071N	PARTICIPANT	\N	PRESENT	0
108655	108631	14014Q	PARTICIPANT	\N	PRESENT	0
108656	108631	11015D	PARTICIPANT	\N	PRESENT	0
108657	108631	07004J	PARTICIPANT	\N	EXCUSE	0
108658	108631	95035G	PARTICIPANT	\N	PRESENT	0
108659	108631	08056B	PARTICIPANT	\N	EXCUSE	0
108705	107732	90003B	PARTICIPANT	\N	PRESENT	0
108706	107732	14213J	PARTICIPANT	\N	PRESENT	0
108662	108631	11064N	PARTICIPANT	\N	PRESENT	0
108663	108631	95037J	PARTICIPANT	\N	PRESENT	0
108664	108631	04078Q	PARTICIPANT	\N	PRESENT	0
108665	108631	14097Y	PARTICIPANT	\N	PRESENT	0
108666	108631	95041E	PARTICIPANT	\N	PRESENT	0
108667	108631	04036E	PARTICIPANT	\N	PRESENT	0
108707	107732	14331P	PARTICIPANT	\N	PRESENT	0
108708	107732	14241N	PARTICIPANT	\N	PRESENT	0
108670	108631	98005N	PARTICIPANT	\N	PRESENT	0
108671	108631	92031P	PARTICIPANT	\N	PRESENT	0
108672	108631	11106F	PARTICIPANT	\N	PRESENT	0
108673	108631	14251Q	PARTICIPANT	\N	PRESENT	0
108674	108631	83042R	PARTICIPANT	\N	PRESENT	0
108709	107732	11067R	PARTICIPANT	\N	PRESENT	0
108710	107732	01025N	PARTICIPANT	\N	PRESENT	0
108677	108631	11105E	PARTICIPANT	\N	PRESENT	0
108711	107732	14327T	PARTICIPANT	\N	PRESENT	0
108712	107732	11097X	PARTICIPANT	\N	PRESENT	0
108680	108631	14028W	PARTICIPANT	\N	PRESENT	0
108681	108631	14193X	PARTICIPANT	\N	PRESENT	0
108713	107732	08042U	PARTICIPANT	\N	PRESENT	0
108714	108631	98021N	PARTICIPANT	\N	EXCUSE	0
108684	108631	95059Q	PRESIDENT	0	PRESENT	0
108685	108631	86044G	PARTICIPANT	\N	PRESENT	0
108686	108631	01014K	PARTICIPANT	\N	PRESENT	0
108715	108631	08049C	PARTICIPANT	\N	EXCUSE	0
108688	108631	01056V	PARTICIPANT	\N	PRESENT	0
108689	108631	92044U	PARTICIPANT	\N	PRESENT	0
108716	107732	10006L	PARTICIPANT	\N	PRESENT	0
108691	108631	04050C	PARTICIPANT	\N	PRESENT	0
108692	107732	14215L	PARTICIPANT	\N	PRESENT	0
108693	107732	11084S	PARTICIPANT	\N	PRESENT	0
108697	107732	11036J	PARTICIPANT	\N	PRESENT	0
108717	107732	14063N	PARTICIPANT	\N	PRESENT	0
108718	107732	08034U	PARTICIPANT	\N	PRESENT	0
108719	107732	04066L	PARTICIPANT	\N	PRESENT	0
108720	107732	08019V	PARTICIPANT	\N	PRESENT	0
108721	107732	04059M	PARTICIPANT	\N	PRESENT	0
108722	107732	08048B	PARTICIPANT	\N	PRESENT	0
108723	107732	14038Y	PARTICIPANT	\N	PRESENT	0
108724	107732	14105F	PARTICIPANT	\N	PRESENT	0
108725	107732	14061L	PARTICIPANT	\N	PRESENT	0
108726	107732	11061K	PARTICIPANT	\N	PRESENT	0
108727	107732	01048V	PARTICIPANT	\N	PRESENT	0
108728	107732	04086Q	PARTICIPANT	\N	PRESENT	0
108729	108631	07024N	PARTICIPANT	\N	PRESENT	0
108788	107732	86044G	PARTICIPANT	\N	PRESENT	0
108789	107732	87003B	PARTICIPANT	\N	PRESENT	0
108790	107732	14273W	PARTICIPANT	\N	PRESENT	0
108791	107732	11046L	PARTICIPANT	\N	PRESENT	0
108792	107732	07024N	PARTICIPANT	\N	PRESENT	0
108793	107732	04045F	PARTICIPANT	\N	PRESENT	0
108794	107732	09001P	PARTICIPANT	\N	PRESENT	0
108795	107732	04049K	PARTICIPANT	\N	PRESENT	0
108796	107732	14121F	PARTICIPANT	\N	PRESENT	0
108797	107732	14225N	PARTICIPANT	\N	PRESENT	0
108798	107732	08051V	PARTICIPANT	\N	PRESENT	0
108799	107732	98005N	PARTICIPANT	\N	PRESENT	0
108800	107732	14173T	PARTICIPANT	\N	PRESENT	0
108801	107732	04033B	PARTICIPANT	\N	PRESENT	0
108802	107732	14193X	PARTICIPANT	\N	PRESENT	0
108803	107732	14085U	PARTICIPANT	\N	PRESENT	0
108804	107732	11029K	PARTICIPANT	\N	PRESENT	0
108805	107732	11112D	PARTICIPANT	\N	PRESENT	0
108806	107732	14157T	PARTICIPANT	\N	PRESENT	0
108807	107732	04071H	PARTICIPANT	\N	PRESENT	0
108808	107732	01057W	PARTICIPANT	\N	PRESENT	0
108809	107732	80027E	PARTICIPANT	\N	PRESENT	0
108810	107732	11105E	PARTICIPANT	\N	PRESENT	0
108811	107732	14151M	PARTICIPANT	\N	PRESENT	0
108812	107732	14257W	PARTICIPANT	\N	PRESENT	0
108813	107732	14089Y	PARTICIPANT	\N	PRESENT	0
108814	107732	14207L	PARTICIPANT	\N	PRESENT	0
108815	107732	11043H	PARTICIPANT	\N	PRESENT	0
108816	107732	14199E	PARTICIPANT	\N	PRESENT	0
108821	107732	14119M	PARTICIPANT	\N	PRESENT	0
108822	107732	11091R	PARTICIPANT	\N	PRESENT	0
108823	107732	14069U	PARTICIPANT	\N	PRESENT	0
108824	107732	11064N	PARTICIPANT	\N	PRESENT	0
108825	107732	11035H	PARTICIPANT	\N	PRESENT	0
108826	107732	14065Q	PARTICIPANT	\N	PRESENT	0
108827	107732	11015D	PARTICIPANT	\N	PRESENT	0
108828	107732	11040E	PARTICIPANT	\N	PRESENT	0
108829	107732	01011G	PARTICIPANT	\N	PRESENT	0
108830	107732	80013X	PARTICIPANT	\N	PRESENT	0
108831	107732	01019Q	PARTICIPANT	\N	PRESENT	0
108832	107732	08038Y	PARTICIPANT	\N	PRESENT	0
108833	107732	13002U	PARTICIPANT	\N	PRESENT	0
93439	93438	14239U	PARTICIPANT	\N	PRESENT	0
93440	93438	11055M	PARTICIPANT	\N	PRESENT	0
93441	93438	01046T	PARTICIPANT	\N	PRESENT	0
93442	93438	04053F	PARTICIPANT	\N	PRESENT	0
93443	93438	14255U	PARTICIPANT	\N	PRESENT	0
93444	93438	04066L	PARTICIPANT	\N	PRESENT	0
93445	93438	00003C	PARTICIPANT	\N	PRESENT	0
93446	93438	14053L	PARTICIPANT	\N	PRESENT	0
93447	93438	11103C	PARTICIPANT	\N	PRESENT	0
93497	93496	89017R	PARTICIPANT	\N	PRESENT	0
93449	93438	14195A	PARTICIPANT	\N	PRESENT	0
93450	93438	14267Y	PARTICIPANT	\N	PRESENT	0
93451	93438	11023D	PARTICIPANT	\N	PRESENT	0
93452	93438	11031D	PARTICIPANT	\N	PRESENT	0
93453	93438	08052W	PARTICIPANT	\N	PRESENT	0
93454	93438	01059Y	PARTICIPANT	\N	PRESENT	0
93455	93438	04081K	PARTICIPANT	\N	PRESENT	0
93456	93438	98024R	PARTICIPANT	\N	PRESENT	0
93457	93438	10006L	PARTICIPANT	\N	PRESENT	0
93498	93496	01031L	PRESIDENT	0	PRESENT	0
93459	93438	14217N	PARTICIPANT	\N	PRESENT	0
93460	93438	14042U	PARTICIPANT	\N	PRESENT	0
93461	93438	14151M	PARTICIPANT	\N	PRESENT	0
93462	93438	12042Y	PARTICIPANT	\N	PRESENT	0
93463	93438	14281W	PARTICIPANT	\N	PRESENT	0
93464	93438	14087W	PARTICIPANT	\N	PRESENT	0
93549	93548	08022Q	PARTICIPANT	\N	PRESENT	0
93466	93438	14034U	PARTICIPANT	\N	PRESENT	0
93467	93438	14231L	PARTICIPANT	\N	PRESENT	0
93468	93438	11061K	PARTICIPANT	\N	EXCUSE	0
93469	93438	08048B	PARTICIPANT	\N	EXCUSE	0
93470	93438	08041T	PARTICIPANT	\N	PRESENT	0
93471	93438	01011G	PARTICIPANT	\N	PRESENT	0
93472	93438	14026U	PARTICIPANT	\N	PRESENT	0
93473	93438	14213J	PARTICIPANT	\N	PRESENT	0
93474	93438	14121F	PARTICIPANT	\N	PRESENT	0
93475	93438	11112D	PARTICIPANT	\N	PRESENT	0
93476	93438	14037X	PARTICIPANT	\N	PRESENT	0
93477	93438	14018U	PARTICIPANT	\N	PRESENT	0
93478	93438	11067R	PARTICIPANT	\N	PRESENT	0
93479	93438	14223L	PARTICIPANT	\N	PRESENT	0
93480	93438	04092N	PRESIDENT	0	PRESENT	0
93481	93438	14265W	PARTICIPANT	\N	PRESENT	0
93482	93438	14119M	PARTICIPANT	\N	PRESENT	0
93483	93438	14071N	PARTICIPANT	\N	EXCUSE	0
93484	93438	07032N	PARTICIPANT	\N	PRESENT	0
93485	93438	04043D	PARTICIPANT	\N	PRESENT	0
93486	93438	14271U	PARTICIPANT	\N	PRESENT	0
93500	93496	01013J	PARTICIPANT	\N	PRESENT	0
93488	93438	11093T	PARTICIPANT	\N	PRESENT	0
93489	93438	11097X	PARTICIPANT	\N	PRESENT	0
93490	93438	04045F	PARTICIPANT	\N	EXCUSE	0
93491	93438	14227Q	PARTICIPANT	\N	PRESENT	0
93492	93438	01034P	PARTICIPANT	\N	PRESENT	0
93550	93548	04061F	PARTICIPANT	\N	PRESENT	0
93494	93438	11063M	PARTICIPANT	\N	PRESENT	0
93495	93438	14269B	PARTICIPANT	\N	PRESENT	0
93501	93496	11068S	PARTICIPANT	\N	PRESENT	0
93502	93496	11040E	PARTICIPANT	\N	PRESENT	0
93503	93496	08014Q	PARTICIPANT	\N	PRESENT	0
93504	93496	14167V	PARTICIPANT	\N	PRESENT	0
93505	93496	14175V	PARTICIPANT	\N	PRESENT	0
93506	93496	14083S	PARTICIPANT	\N	PRESENT	0
93507	93496	11053K	PARTICIPANT	\N	PRESENT	0
93508	93496	14085U	PARTICIPANT	\N	PRESENT	0
93509	93496	11042G	PARTICIPANT	\N	PRESENT	0
93510	93496	88008L	PARTICIPANT	\N	PRESENT	0
93511	93496	04086Q	PARTICIPANT	\N	PRESENT	0
93512	93496	04055H	PARTICIPANT	\N	EXCUSE	0
93513	93496	11070L	PARTICIPANT	\N	PRESENT	0
93514	93496	11088W	PARTICIPANT	\N	PRESENT	0
93551	93548	08061X	PARTICIPANT	\N	PRESENT	0
93516	93496	08022Q	PARTICIPANT	\N	PRESENT	0
93517	93496	01027Q	PARTICIPANT	\N	PRESENT	0
93518	93496	04071H	PARTICIPANT	\N	PRESENT	0
93519	93496	11074Q	PARTICIPANT	\N	PRESENT	0
93520	93496	98053W	PARTICIPANT	\N	PRESENT	0
93521	93496	11083R	PARTICIPANT	\N	PRESENT	0
93552	93548	01016M	PARTICIPANT	\N	PRESENT	0
93674	93672	11026G	PARTICIPANT	\N	PRESENT	0
93524	93496	08016S	PARTICIPANT	\N	PRESENT	0
93525	93496	08069G	PARTICIPANT	\N	PRESENT	0
93526	93496	11048N	PARTICIPANT	\N	PRESENT	0
93527	93496	99004R	PARTICIPANT	\N	PRESENT	0
93528	93496	04061F	PARTICIPANT	\N	PRESENT	0
93529	93496	14159V	PARTICIPANT	\N	PRESENT	0
93530	93496	07029T	PARTICIPANT	\N	PRESENT	0
93680	93679	11026G	PARTICIPANT	\N	PRESENT	0
93532	93496	08010L	PARTICIPANT	\N	PRESENT	0
93533	93496	08034U	PARTICIPANT	\N	PRESENT	0
93676	93672	10015M	PARTICIPANT	\N	PRESENT	0
93535	93496	98046X	PARTICIPANT	\N	PRESENT	0
93681	93679	10015M	PARTICIPANT	\N	PRESENT	0
93537	93496	08011M	PARTICIPANT	\N	PRESENT	0
93683	93682	11026G	PARTICIPANT	\N	PRESENT	0
93539	93496	08061X	PARTICIPANT	\N	PRESENT	0
93540	93496	01016M	PARTICIPANT	\N	PRESENT	0
93685	93684	11026G	PARTICIPANT	\N	PRESENT	0
93542	93496	11012A	PARTICIPANT	\N	PRESENT	0
93543	93496	11057P	PARTICIPANT	\N	PRESENT	0
93544	93496	14173T	PARTICIPANT	\N	PRESENT	0
93545	93496	04034C	PARTICIPANT	\N	PRESENT	0
93686	93684	10015M	PARTICIPANT	\N	PRESENT	0
94228	94227	11026G	PARTICIPANT	\N	PRESENT	0
94229	94227	10015M	PARTICIPANT	\N	PRESENT	0
96026	96002	04067M	PARTICIPANT	\N	PRESENT	0
96027	96002	01027Q	PARTICIPANT	\N	PRESENT	0
96028	96002	12042Y	PRESIDENT	0	PRESENT	0
96029	96002	11107G	PARTICIPANT	\N	PRESENT	0
96030	96002	11061K	PARTICIPANT	\N	PRESENT	0
96031	96002	14014Q	PARTICIPANT	\N	PRESENT	0
96032	96002	14026U	PARTICIPANT	\N	PRESENT	0
96033	96002	11112D	PARTICIPANT	\N	PRESENT	0
96036	96002	04049K	PARTICIPANT	\N	PRESENT	0
96037	96002	14205J	PARTICIPANT	\N	PRESENT	0
96038	96002	04092N	PARTICIPANT	\N	PRESENT	0
96039	96002	14135M	PARTICIPANT	\N	PRESENT	0
96040	96002	11097X	PARTICIPANT	\N	PRESENT	0
96041	96002	04045F	PARTICIPANT	\N	PRESENT	0
96042	96002	14227Q	PARTICIPANT	\N	PRESENT	0
96043	96002	04050C	PARTICIPANT	\N	PRESENT	0
96044	96002	11100Y	PARTICIPANT	\N	PRESENT	0
96045	96002	14042U	PARTICIPANT	\N	PRESENT	0
96046	96002	08052W	PARTICIPANT	\N	PRESENT	0
96372	83996	11044J	PARTICIPANT	\N	EXCUSE	0
96373	83996	95067Q	PARTICIPANT	\N	PRESENT	0
96024	96002	14255U	PARTICIPANT	\N	PRESENT	0
96025	96002	04086Q	PARTICIPANT	\N	PRESENT	0
96374	83996	92040Q	PARTICIPANT	\N	EXCUSE	0
96375	83996	01027Q	PARTICIPANT	\N	EXCUSE	0
96377	83996	11101A	PARTICIPANT	\N	PRESENT	0
96380	83996	08038Y	PARTICIPANT	\N	PRESENT	0
96381	83996	04086Q	PARTICIPANT	\N	PRESENT	0
96384	83996	14231L	PARTICIPANT	\N	PRESENT	0
96387	83996	11049P	PARTICIPANT	\N	PRESENT	0
96388	83996	01057W	PARTICIPANT	\N	PRESENT	0
96389	83996	11112D	PARTICIPANT	\N	PRESENT	0
96390	83996	08010L	PARTICIPANT	\N	PRESENT	0
96391	83996	11048N	PARTICIPANT	\N	PRESENT	0
96392	83996	08034U	PARTICIPANT	\N	PRESENT	0
96393	83996	14063N	PARTICIPANT	\N	PRESENT	0
96394	83996	07032N	PARTICIPANT	\N	PRESENT	0
96395	83996	04044E	PARTICIPANT	\N	EXCUSE	0
96396	83996	11037K	PARTICIPANT	\N	PRESENT	0
96398	83996	14051J	PARTICIPANT	\N	PRESENT	0
96399	83996	04045F	PARTICIPANT	\N	PRESENT	0
96400	83996	05012A	PARTICIPANT	\N	PRESENT	0
97433	97432	11111C	PARTICIPANT	\N	PRESENT	0
97434	97432	14257W	PARTICIPANT	\N	PRESENT	0
97453	97452	89017R	PARTICIPANT	\N	PRESENT	0
97454	97452	11039M	PARTICIPANT	\N	PRESENT	0
97455	97452	11029K	PARTICIPANT	\N	PRESENT	0
97456	97452	01003G	PARTICIPANT	\N	PRESENT	0
97457	97452	01007L	PARTICIPANT	\N	PRESENT	0
97459	97458	89017R	PARTICIPANT	\N	PRESENT	0
97460	97458	11039M	PARTICIPANT	\N	PRESENT	0
97461	97458	08055A	PARTICIPANT	\N	PRESENT	0
97462	97458	11029K	PARTICIPANT	\N	PRESENT	0
97463	97458	04066L	PARTICIPANT	\N	PRESENT	0
97464	97458	04042C	PARTICIPANT	\N	PRESENT	0
97465	97458	08024S	PARTICIPANT	\N	PRESENT	0
97466	97458	04081K	PARTICIPANT	\N	PRESENT	0
97467	97458	98042T	PARTICIPANT	\N	PRESENT	0
97468	97458	11110B	PARTICIPANT	\N	PRESENT	0
97469	97458	01003G	PARTICIPANT	\N	PRESENT	0
117833	117572	04049K	PARTICIPANT	\N	PRESENT	0
117834	117572	14135M	PARTICIPANT	\N	PRESENT	0
117835	117572	95067Q	PARTICIPANT	\N	PRESENT	0
117836	117572	14107H	PARTICIPANT	\N	PRESENT	0
117874	117032	11109J	PARTICIPANT	\N	PRESENT	0
117875	117032	11037K	PARTICIPANT	\N	PRESENT	0
117876	117032	14267Y	PARTICIPANT	\N	PRESENT	0
117877	117032	14219Q	PARTICIPANT	\N	PRESENT	0
117878	117032	04053F	PARTICIPANT	\N	PRESENT	0
117879	117032	14042U	PARTICIPANT	\N	PRESENT	0
117880	117032	08052W	PARTICIPANT	\N	PRESENT	0
117881	117032	11094U	PARTICIPANT	\N	PRESENT	0
117882	117032	14097Y	PARTICIPANT	\N	PRESENT	0
117883	117032	04088S	PARTICIPANT	\N	PRESENT	0
117884	117032	14033T	PARTICIPANT	\N	PRESENT	0
117885	117032	14073Q	PARTICIPANT	\N	PRESENT	0
117886	117032	11082Q	PARTICIPANT	\N	PRESENT	0
117887	117032	12042Y	PARTICIPANT	\N	PRESENT	0
117888	117032	11081P	PARTICIPANT	\N	PRESENT	0
117889	117032	04089T	PARTICIPANT	\N	PRESENT	0
117892	117032	01044R	PARTICIPANT	\N	PRESENT	0
117893	117032	04080J	PARTICIPANT	\N	PRESENT	0
117894	117032	08009T	PARTICIPANT	\N	PRESENT	0
117895	117032	11053K	PARTICIPANT	\N	PRESENT	0
117898	117032	95037J	PARTICIPANT	\N	PRESENT	0
117899	117032	14281W	PARTICIPANT	\N	PRESENT	0
117900	117032	11063M	PARTICIPANT	\N	PRESENT	0
117901	117032	01015L	PARTICIPANT	\N	PRESENT	0
117902	117032	07026Q	PARTICIPANT	\N	PRESENT	0
117903	117756	12041X	PARTICIPANT	\N	PRESENT	0
117904	117756	01059Y	PARTICIPANT	\N	PRESENT	0
117872	117032	12041X	PARTICIPANT	\N	PRESENT	0
117873	117032	01059Y	PARTICIPANT	\N	PRESENT	0
117905	117756	11109J	PARTICIPANT	\N	PRESENT	0
117906	117756	11037K	PARTICIPANT	\N	PRESENT	0
117907	117756	14267Y	PARTICIPANT	\N	PRESENT	0
117908	117756	14219Q	PARTICIPANT	\N	PRESENT	0
117909	117756	04053F	PARTICIPANT	\N	PRESENT	0
117910	117756	14042U	PARTICIPANT	\N	PRESENT	0
117911	117756	08052W	PARTICIPANT	\N	PRESENT	0
117912	117756	11094U	PARTICIPANT	\N	PRESENT	0
117913	117756	14097Y	PARTICIPANT	\N	PRESENT	0
117914	117756	04088S	PARTICIPANT	\N	PRESENT	0
117915	117756	14033T	PARTICIPANT	\N	PRESENT	0
117916	117756	14073Q	PARTICIPANT	\N	PRESENT	0
117917	117756	11082Q	PARTICIPANT	\N	PRESENT	0
117918	117756	12042Y	PARTICIPANT	\N	PRESENT	0
117919	117756	11081P	PARTICIPANT	\N	PRESENT	0
117920	117756	04089T	PARTICIPANT	\N	PRESENT	0
117921	117756	14107H	PARTICIPANT	\N	PRESENT	0
117922	117756	11055M	PARTICIPANT	\N	PRESENT	0
117923	117756	01044R	PARTICIPANT	\N	PRESENT	0
117924	117756	04080J	PARTICIPANT	\N	PRESENT	0
117925	117756	08009T	PARTICIPANT	\N	PRESENT	0
117926	117756	11053K	PARTICIPANT	\N	PRESENT	0
117927	117756	98035U	PARTICIPANT	\N	PRESENT	0
117928	117756	11057P	PARTICIPANT	\N	PRESENT	0
117929	117756	95037J	PARTICIPANT	\N	PRESENT	0
117930	117756	14281W	PARTICIPANT	\N	PRESENT	0
117931	117756	11063M	PARTICIPANT	\N	PRESENT	0
117932	117756	01015L	PARTICIPANT	\N	PRESENT	0
117933	117756	07026Q	PARTICIPANT	\N	PRESENT	0
117934	117756	86034E	PARTICIPANT	\N	PRESENT	0
117935	117756	04092N	PARTICIPANT	\N	PRESENT	0
117936	117756	14037X	PARTICIPANT	\N	PRESENT	0
117937	117756	14034U	PARTICIPANT	\N	PRESENT	0
117938	117756	14087W	PARTICIPANT	\N	PRESENT	0
117939	117756	08016S	PARTICIPANT	\N	PRESENT	0
117940	117756	04056J	PARTICIPANT	\N	PRESENT	0
117941	117756	01016M	PARTICIPANT	\N	PRESENT	0
117942	117756	11089X	PARTICIPANT	\N	PRESENT	0
117943	117756	95062K	PARTICIPANT	\N	PRESENT	0
117944	117756	11042G	PARTICIPANT	\N	PRESENT	0
117945	117756	14211G	PARTICIPANT	\N	PRESENT	0
117946	117756	08068F	PARTICIPANT	\N	PRESENT	0
117947	117756	08055A	PARTICIPANT	\N	PRESENT	0
117948	117756	08028W	PARTICIPANT	\N	PRESENT	0
117949	117756	11114F	PARTICIPANT	\N	PRESENT	0
117950	117756	11113E	PARTICIPANT	\N	PRESENT	0
117951	117756	14257W	PARTICIPANT	\N	PRESENT	0
117952	117756	95015C	PARTICIPANT	\N	PRESENT	0
117953	117756	14014Q	PARTICIPANT	\N	PRESENT	0
117954	117756	11014C	PARTICIPANT	\N	PRESENT	0
117955	117756	02002K	PARTICIPANT	\N	PRESENT	0
117956	117756	14271U	PARTICIPANT	\N	PRESENT	0
117957	117756	08060W	PARTICIPANT	\N	PRESENT	0
117958	117756	01013J	PARTICIPANT	\N	PRESENT	0
117959	117756	04050C	PARTICIPANT	\N	PRESENT	0
117960	117756	11034G	PARTICIPANT	\N	PRESENT	0
117961	117756	08010L	PARTICIPANT	\N	PRESENT	0
117962	117756	04085P	PARTICIPANT	\N	PRESENT	0
117963	117756	11054L	PARTICIPANT	\N	PRESENT	0
117964	117756	14237S	PARTICIPANT	\N	PRESENT	0
117965	117756	14167V	PARTICIPANT	\N	PRESENT	0
117966	117756	14121F	PARTICIPANT	\N	PRESENT	0
117967	117756	95067Q	PARTICIPANT	\N	PRESENT	0
117968	117756	11095V	PARTICIPANT	\N	PRESENT	0
117969	117756	14051J	PARTICIPANT	\N	PRESENT	0
117970	117756	08041T	PARTICIPANT	\N	PRESENT	0
117971	117756	14225N	PARTICIPANT	\N	PRESENT	0
117972	117756	11061K	PARTICIPANT	\N	PRESENT	0
117973	117756	87003B	PARTICIPANT	\N	PRESENT	0
117974	117756	01028R	PARTICIPANT	\N	PRESENT	0
117975	117756	11110B	PARTICIPANT	\N	PRESENT	0
117976	117756	08038Y	PARTICIPANT	\N	PRESENT	0
117977	117756	01057W	PARTICIPANT	\N	PRESENT	0
117978	117756	11068S	PARTICIPANT	\N	PRESENT	0
117979	117756	11067R	PARTICIPANT	\N	PRESENT	0
117980	117756	11025F	PARTICIPANT	\N	PRESENT	0
117981	117756	11099A	PARTICIPANT	\N	PRESENT	0
117982	117756	11083R	PARTICIPANT	\N	PRESENT	0
117983	117756	14026U	PARTICIPANT	\N	PRESENT	0
117984	117756	04067M	PARTICIPANT	\N	PRESENT	0
117985	117756	13002U	PARTICIPANT	\N	PRESENT	0
117986	117756	90003B	PARTICIPANT	\N	PRESENT	0
117987	117756	11107G	PARTICIPANT	\N	PRESENT	0
117988	117756	14241N	PARTICIPANT	\N	PRESENT	0
117989	117756	11097X	PARTICIPANT	\N	PRESENT	0
117990	117756	14261S	PARTICIPANT	\N	PRESENT	0
117991	117756	08031R	PARTICIPANT	\N	PRESENT	0
117992	117756	01046T	PARTICIPANT	\N	PRESENT	0
117993	117756	11091R	PARTICIPANT	\N	PRESENT	0
117994	117756	04081K	PARTICIPANT	\N	PRESENT	0
117995	117756	11093T	PARTICIPANT	\N	PRESENT	0
117996	117756	14083S	PARTICIPANT	\N	PRESENT	0
117997	117756	11085T	PARTICIPANT	\N	PRESENT	0
117998	117756	07029T	PARTICIPANT	\N	PRESENT	0
117999	117756	01047U	PARTICIPANT	\N	PRESENT	0
118000	117756	14255U	PARTICIPANT	\N	PRESENT	0
118001	117756	01025N	PARTICIPANT	\N	PRESENT	0
118002	117756	01007L	PARTICIPANT	\N	PRESENT	0
118003	117756	14041T	PARTICIPANT	\N	PRESENT	0
118004	117756	14327T	PARTICIPANT	\N	PRESENT	0
118005	117756	95041E	PARTICIPANT	\N	PRESENT	0
118006	117756	11088W	PARTICIPANT	\N	PRESENT	0
118007	117756	92031P	PARTICIPANT	\N	PRESENT	0
118008	117756	14217N	PARTICIPANT	\N	PRESENT	0
118009	117756	01041N	PARTICIPANT	\N	PRESENT	0
118010	117756	01008M	PARTICIPANT	\N	PRESENT	0
118011	117756	14059S	PARTICIPANT	\N	PRESENT	0
118012	117756	14061L	PARTICIPANT	\N	PRESENT	0
118013	117756	97011G	PARTICIPANT	\N	PRESENT	0
118014	117756	08034U	PARTICIPANT	\N	PRESENT	0
118015	117756	11103C	PARTICIPANT	\N	PRESENT	0
118016	117756	05012A	PARTICIPANT	\N	PRESENT	0
118017	117756	04057K	PARTICIPANT	\N	PRESENT	0
118018	117756	04033B	PARTICIPANT	\N	PRESENT	0
118019	117756	10006L	PARTICIPANT	\N	PRESENT	0
118020	117756	98018T	PARTICIPANT	\N	PRESENT	0
118021	117756	86044G	PARTICIPANT	\N	PRESENT	0
118022	117756	99004R	PARTICIPANT	\N	PRESENT	0
118023	117756	04035D	PARTICIPANT	\N	PRESENT	0
118024	117756	14105F	PARTICIPANT	\N	PRESENT	0
118025	117756	14119M	PARTICIPANT	\N	PRESENT	0
118029	117756	01024M	PARTICIPANT	\N	PRESENT	0
118027	117756	04097T	PARTICIPANT	\N	PRESENT	0
118028	117756	04034C	PARTICIPANT	\N	PRESENT	0
118030	117756	08048B	PARTICIPANT	\N	PRESENT	0
118031	117756	14213J	PARTICIPANT	\N	PRESENT	0
118032	117756	14265W	PARTICIPANT	\N	PRESENT	0
118041	117756	08039A	PARTICIPANT	\N	PRESENT	0
118042	117756	11070L	PARTICIPANT	\N	PRESENT	0
118043	117756	11026G	PARTICIPANT	\N	PRESENT	0
118044	117756	80027E	PARTICIPANT	\N	PRESENT	0
96378	96376	01031L	PARTICIPANT	\N	PRESENT	0
96379	96376	08060W	PARTICIPANT	\N	PRESENT	0
96382	96376	11053K	PARTICIPANT	\N	PRESENT	0
96383	96376	01037S	PARTICIPANT	\N	PRESENT	0
96385	96376	14225N	PARTICIPANT	\N	PRESENT	0
96386	96376	95067Q	PARTICIPANT	\N	PRESENT	0
96427	96426	04044E	PARTICIPANT	\N	PRESENT	0
96453	96452	08009T	PARTICIPANT	\N	PRESENT	0
96454	96452	11026G	PARTICIPANT	\N	PRESENT	0
96460	96457	04054G	PARTICIPANT	\N	PRESENT	0
96461	96457	11027H	PARTICIPANT	\N	PRESENT	0
96462	96457	14255U	PARTICIPANT	\N	PRESENT	0
96463	96457	08055A	PARTICIPANT	\N	PRESENT	0
96464	96457	11100Y	PARTICIPANT	\N	PRESENT	0
96465	96457	05012A	PARTICIPANT	\N	PRESENT	0
96467	96457	98035U	PARTICIPANT	\N	PRESENT	0
96469	96457	92039X	PARTICIPANT	\N	PRESENT	0
96471	96457	14235Q	PARTICIPANT	\N	PRESENT	0
96473	96457	14028W	PARTICIPANT	\N	PRESENT	0
96481	91448	14259Y	PARTICIPANT	\N	PRESENT	0
96482	91448	01027Q	PARTICIPANT	\N	EXCUSE	0
96483	91448	11054L	PARTICIPANT	\N	PRESENT	0
96484	91448	04043D	PARTICIPANT	\N	PRESENT	0
96485	91448	11072N	PARTICIPANT	\N	PRESENT	0
96486	91448	08019V	PRESIDENT	0	PRESENT	0
96487	91448	14059S	PARTICIPANT	\N	PRESENT	0
108940	108887	11054L	PARTICIPANT	\N	PRESENT	0
96489	91448	11109J	PARTICIPANT	\N	PRESENT	0
96496	91448	08073C	PARTICIPANT	\N	EXCUSE	0
108941	108887	01056V	PARTICIPANT	\N	PRESENT	0
111445	111404	11076S	PARTICIPANT	\N	PRESENT	0
111446	111404	04054G	PARTICIPANT	\N	EXCUSE	0
111447	111404	04040A	PARTICIPANT	\N	PRESENT	0
111448	111404	08058D	PARTICIPANT	\N	PRESENT	0
111451	111404	04042C	PARTICIPANT	\N	PRESENT	0
111452	111404	77002U	PARTICIPANT	\N	PRESENT	0
111454	111404	98029W	PARTICIPANT	\N	PRESENT	0
111455	111404	11080N	PARTICIPANT	\N	PRESENT	0
111457	111404	11027H	PARTICIPANT	\N	PRESENT	0
111459	111404	98018T	PARTICIPANT	\N	PRESENT	0
111460	111404	92020L	PARTICIPANT	\N	PRESENT	0
111461	111404	95030B	PARTICIPANT	\N	PRESENT	0
111462	111404	11096W	PARTICIPANT	\N	PRESENT	0
111464	111404	08065C	PARTICIPANT	\N	PRESENT	0
111465	111404	04035D	PARTICIPANT	\N	PRESENT	0
111466	111404	07024N	PARTICIPANT	\N	PRESENT	0
111468	111404	14014Q	PARTICIPANT	\N	PRESENT	0
111469	111404	11015D	PARTICIPANT	\N	PRESENT	0
111470	111404	07004J	PARTICIPANT	\N	PRESENT	0
111471	111404	95035G	PARTICIPANT	\N	PRESENT	0
111472	111404	14211G	PARTICIPANT	\N	PRESENT	0
111473	111404	98022P	PARTICIPANT	\N	PRESENT	0
111474	111404	11064N	PARTICIPANT	\N	PRESENT	0
111475	111404	95037J	PARTICIPANT	\N	PRESENT	0
111476	111404	04078Q	PARTICIPANT	\N	PRESENT	0
111477	111404	95041E	PARTICIPANT	\N	PRESENT	0
111478	111404	04036E	PARTICIPANT	\N	PRESENT	0
111479	111404	14039A	PARTICIPANT	\N	PRESENT	0
111480	111404	92031P	PARTICIPANT	\N	EXCUSE	0
111481	111404	11106F	PARTICIPANT	\N	PRESENT	0
111482	111404	14251Q	PARTICIPANT	\N	PRESENT	0
111483	111404	83042R	PARTICIPANT	\N	PRESENT	0
111484	111404	08053X	PARTICIPANT	\N	PRESENT	0
111485	111404	11082Q	PARTICIPANT	\N	PRESENT	0
111487	111404	11105E	PARTICIPANT	\N	PRESENT	0
111488	111404	14253S	PARTICIPANT	\N	PRESENT	0
111489	111404	08047A	PARTICIPANT	\N	PRESENT	0
111490	111404	14028W	PARTICIPANT	\N	PRESENT	0
111492	111404	98021N	PARTICIPANT	\N	PRESENT	0
111493	111404	04080J	PARTICIPANT	\N	PRESENT	0
111494	111404	95059Q	PRESIDENT	0	PRESENT	0
111495	111404	86044G	PARTICIPANT	\N	PRESENT	0
111496	111404	01014K	PARTICIPANT	\N	PRESENT	0
111497	111404	11054L	PARTICIPANT	\N	PRESENT	0
111498	111404	92044U	PARTICIPANT	\N	PRESENT	0
111499	111404	08049C	PARTICIPANT	\N	PRESENT	0
111500	111404	04050C	PARTICIPANT	\N	PRESENT	0
111548	111547	11076S	PARTICIPANT	\N	PRESENT	0
111549	111547	04054G	PARTICIPANT	\N	EXCUSE	0
111550	111547	04040A	PARTICIPANT	\N	PRESENT	0
111551	111547	08058D	PARTICIPANT	\N	PRESENT	0
111552	111547	04042C	PARTICIPANT	\N	PRESENT	0
111554	111547	77002U	PARTICIPANT	\N	PRESENT	0
111555	111547	98029W	PARTICIPANT	\N	PRESENT	0
111557	111547	11080N	PARTICIPANT	\N	PRESENT	0
111558	111547	11027H	PARTICIPANT	\N	PRESENT	0
111559	111547	98018T	PARTICIPANT	\N	PRESENT	0
111560	111547	92020L	PARTICIPANT	\N	PRESENT	0
111561	111547	95030B	PARTICIPANT	\N	PRESENT	0
111562	111547	11096W	PARTICIPANT	\N	PRESENT	0
111563	111547	08065C	PARTICIPANT	\N	PRESENT	0
111564	111547	04035D	PARTICIPANT	\N	PRESENT	0
111565	111547	07024N	PARTICIPANT	\N	PRESENT	0
111566	111547	14014Q	PARTICIPANT	\N	PRESENT	0
111567	111547	11015D	PARTICIPANT	\N	PRESENT	0
111568	111547	07004J	PARTICIPANT	\N	PRESENT	0
111569	111547	95035G	PARTICIPANT	\N	PRESENT	0
111570	111547	14211G	PARTICIPANT	\N	PRESENT	0
111571	111547	98022P	PARTICIPANT	\N	PRESENT	0
111572	111547	11064N	PARTICIPANT	\N	PRESENT	0
111573	111547	95037J	PARTICIPANT	\N	PRESENT	0
111574	111547	04078Q	PARTICIPANT	\N	PRESENT	0
111577	111547	95041E	PARTICIPANT	\N	PRESENT	0
111578	111547	04036E	PARTICIPANT	\N	PRESENT	0
111579	111547	14039A	PARTICIPANT	\N	PRESENT	0
111580	111547	92031P	PARTICIPANT	\N	EXCUSE	0
111581	111547	11106F	PARTICIPANT	\N	PRESENT	0
111582	111547	14251Q	PARTICIPANT	\N	PRESENT	0
111583	111547	83042R	PARTICIPANT	\N	PRESENT	0
111584	111547	08053X	PARTICIPANT	\N	PRESENT	0
111585	111547	11082Q	PARTICIPANT	\N	PRESENT	0
111586	111547	11105E	PARTICIPANT	\N	PRESENT	0
111587	111547	14253S	PARTICIPANT	\N	PRESENT	0
111588	111547	08047A	PARTICIPANT	\N	PRESENT	0
111589	111547	14028W	PARTICIPANT	\N	PRESENT	0
111591	111547	98021N	PARTICIPANT	\N	PRESENT	0
111593	111547	04080J	PARTICIPANT	\N	PRESENT	0
111594	111547	95059Q	PRESIDENT	0	PRESENT	0
111595	111547	86044G	PARTICIPANT	\N	PRESENT	0
111596	111547	01014K	PARTICIPANT	\N	PRESENT	0
111597	111547	11054L	PARTICIPANT	\N	PRESENT	0
111598	111547	92044U	PARTICIPANT	\N	PRESENT	0
111599	111547	08049C	PARTICIPANT	\N	PRESENT	0
111600	111547	04050C	PARTICIPANT	\N	PRESENT	0
112123	112120	11055M	PARTICIPANT	\N	PRESENT	0
112124	112120	01046T	PARTICIPANT	\N	PRESENT	0
112125	112120	04053F	PARTICIPANT	\N	PRESENT	0
112128	112120	00003C	PARTICIPANT	\N	EXCUSE	0
112129	112120	14053L	PARTICIPANT	\N	PRESENT	0
112130	112120	11103C	PARTICIPANT	\N	PRESENT	0
112131	112120	11044J	PARTICIPANT	\N	EXCUSE	0
112132	112120	14195A	PARTICIPANT	\N	PRESENT	0
112133	112120	14267Y	PARTICIPANT	\N	PRESENT	0
112135	112120	11031D	PARTICIPANT	\N	PRESENT	0
112136	112120	08052W	PARTICIPANT	\N	PRESENT	0
112139	112120	98024R	PARTICIPANT	\N	PRESENT	0
112143	112120	14042U	PARTICIPANT	\N	PRESENT	0
112145	112120	12042Y	PARTICIPANT	\N	PRESENT	0
112146	112120	14281W	PARTICIPANT	\N	PRESENT	0
112149	112120	14034U	PARTICIPANT	\N	PRESENT	0
112150	112120	14231L	PARTICIPANT	\N	PRESENT	0
112155	112120	14026U	PARTICIPANT	\N	PRESENT	0
112156	112120	14213J	PARTICIPANT	\N	PRESENT	0
112157	112120	14121F	PARTICIPANT	\N	PRESENT	0
112158	112120	11112D	PARTICIPANT	\N	PRESENT	0
112159	112120	14037X	PARTICIPANT	\N	PRESENT	0
112161	112120	11067R	PARTICIPANT	\N	PRESENT	0
112163	112120	04092N	PRESIDENT	0	PRESENT	0
112165	112120	14119M	PARTICIPANT	\N	PRESENT	0
112166	112120	14071N	PARTICIPANT	\N	EXCUSE	0
108834	107732	04057K	PARTICIPANT	\N	PRESENT	0
108837	107732	14051J	PARTICIPANT	\N	PRESENT	0
108839	107732	14187A	PARTICIPANT	\N	PRESENT	0
108847	107732	11107G	PARTICIPANT	\N	PRESENT	0
108848	107732	11027H	PARTICIPANT	\N	PRESENT	0
108849	107732	14159V	PARTICIPANT	\N	PRESENT	0
108850	107732	11053K	PARTICIPANT	\N	PRESENT	0
108851	107732	14042U	PARTICIPANT	\N	PRESENT	0
108852	107732	14255U	PARTICIPANT	\N	PRESENT	0
108872	107732	14201E	PARTICIPANT	\N	PRESENT	0
108873	107732	11098Y	PARTICIPANT	\N	PRESENT	0
108874	107732	14209N	PARTICIPANT	\N	PRESENT	0
108875	107732	11104D	PARTICIPANT	\N	PRESENT	0
108876	107732	99004R	PARTICIPANT	\N	PRESENT	0
108877	107732	95030B	PARTICIPANT	\N	PRESENT	0
108878	107732	14135M	PARTICIPANT	\N	PRESENT	0
108879	107732	01016M	PARTICIPANT	\N	PRESENT	0
108880	107732	92045V	PARTICIPANT	\N	PRESENT	0
108881	107732	08039A	PARTICIPANT	\N	PRESENT	0
108882	107732	04095R	PARTICIPANT	\N	PRESENT	0
108883	107732	14014Q	PARTICIPANT	\N	PRESENT	0
108884	107732	11014C	PARTICIPANT	\N	PRESENT	0
108885	107732	04089T	PARTICIPANT	\N	PRESENT	0
108886	107732	14329V	PARTICIPANT	\N	PRESENT	0
108945	107732	04047H	PARTICIPANT	\N	PRESENT	0
108952	107733	98053W	PARTICIPANT	\N	PRESENT	0
108953	107733	04092N	PARTICIPANT	\N	PRESENT	0
108954	107733	14034U	PARTICIPANT	\N	PRESENT	0
108955	107733	11063M	PARTICIPANT	\N	PRESENT	0
108956	107733	01059Y	PARTICIPANT	\N	PRESENT	0
108957	107733	11031D	PARTICIPANT	\N	PRESENT	0
108958	107733	14235Q	PARTICIPANT	\N	PRESENT	0
108959	107733	14151M	PARTICIPANT	\N	PRESENT	0
108960	107733	14227Q	PARTICIPANT	\N	PRESENT	0
108961	107733	04053F	PARTICIPANT	\N	PRESENT	0
108962	107733	14271U	PARTICIPANT	\N	PRESENT	0
108963	107733	12042Y	PARTICIPANT	\N	PRESENT	0
108964	107733	11067R	PARTICIPANT	\N	PRESENT	0
108965	107733	11026G	PARTICIPANT	\N	PRESENT	0
108966	107733	14051J	PARTICIPANT	\N	PRESENT	0
108967	107733	11105E	PARTICIPANT	\N	PRESENT	0
108968	107733	14201E	PARTICIPANT	\N	PRESENT	0
108969	107733	11094U	PARTICIPANT	\N	PRESENT	0
108970	107733	14089Y	PARTICIPANT	\N	PRESENT	0
108971	107733	14329V	PARTICIPANT	\N	PRESENT	0
108972	107733	08019V	PARTICIPANT	\N	PRESENT	0
108973	107733	14157T	PARTICIPANT	\N	PRESENT	0
108974	107733	14215L	PARTICIPANT	\N	PRESENT	0
108975	107733	14231L	PARTICIPANT	\N	PRESENT	0
108976	107733	14053L	PARTICIPANT	\N	PRESENT	0
108977	107733	14187A	PARTICIPANT	\N	PRESENT	0
108978	107733	14061L	PARTICIPANT	\N	PRESENT	0
108979	107733	14217N	PARTICIPANT	\N	PRESENT	0
108980	107733	14265W	PARTICIPANT	\N	PRESENT	0
108981	107733	11097X	PARTICIPANT	\N	PRESENT	0
108982	107733	14223L	PARTICIPANT	\N	PRESENT	0
108983	107733	11061K	PARTICIPANT	\N	PRESENT	0
108984	107733	11098Y	PARTICIPANT	\N	PRESENT	0
108985	107733	14087W	PARTICIPANT	\N	PRESENT	0
108986	107733	14269B	PARTICIPANT	\N	PRESENT	0
108987	107733	80013X	PARTICIPANT	\N	PRESENT	0
108988	107733	14026U	PARTICIPANT	\N	PRESENT	0
108989	107733	04049K	PARTICIPANT	\N	PRESENT	0
108990	107733	04088S	PARTICIPANT	\N	PRESENT	0
108991	107733	14261S	PARTICIPANT	\N	PRESENT	0
108992	107733	01034P	PARTICIPANT	\N	PRESENT	0
108993	107733	14207L	PARTICIPANT	\N	PRESENT	0
108994	107733	08048B	PARTICIPANT	\N	PRESENT	0
108995	107733	14229S	PARTICIPANT	\N	PRESENT	0
108996	107733	01024M	PARTICIPANT	\N	PRESENT	0
108997	107733	14219Q	PARTICIPANT	\N	PRESENT	0
109003	107733	11043H	PARTICIPANT	\N	PRESENT	0
108999	107733	11112D	PARTICIPANT	\N	PRESENT	0
109000	107733	14018U	PARTICIPANT	\N	PRESENT	0
109001	107733	14083S	PARTICIPANT	\N	PRESENT	0
109002	107733	14030Q	PARTICIPANT	\N	PRESENT	0
109004	107733	14225N	PARTICIPANT	\N	PRESENT	0
109005	107733	14135M	PARTICIPANT	\N	PRESENT	0
109006	107733	14071N	PARTICIPANT	\N	PRESENT	0
109007	107733	11095V	PARTICIPANT	\N	PRESENT	0
109008	107733	08038Y	PARTICIPANT	\N	PRESENT	0
109009	107733	04045F	PARTICIPANT	\N	PRESENT	0
109010	107733	04050C	PARTICIPANT	\N	PRESENT	0
109011	107733	14281W	PARTICIPANT	\N	PRESENT	0
109012	107733	04054G	PARTICIPANT	\N	PRESENT	0
109013	107733	01057W	PARTICIPANT	\N	PRESENT	0
109014	107733	05012A	PARTICIPANT	\N	PRESENT	0
109015	107733	04067M	PARTICIPANT	\N	PRESENT	0
109016	107733	08052W	PARTICIPANT	\N	PRESENT	0
109017	107733	92045V	PARTICIPANT	\N	PRESENT	0
109018	107733	14257W	PARTICIPANT	\N	PRESENT	0
109019	107733	14331P	PARTICIPANT	\N	PRESENT	0
109020	107733	10006L	PARTICIPANT	\N	PRESENT	0
109021	107733	11056N	PARTICIPANT	\N	PRESENT	0
109022	107733	14042U	PARTICIPANT	\N	PRESENT	0
109023	107733	14259Y	PARTICIPANT	\N	PRESENT	0
109032	107733	11107G	PARTICIPANT	\N	PRESENT	0
109033	107733	14195A	PARTICIPANT	\N	PRESENT	0
109034	107733	14119M	PARTICIPANT	\N	PRESENT	0
109035	107733	04071H	PARTICIPANT	\N	PRESENT	0
109036	107733	11110B	PARTICIPANT	\N	PRESENT	0
109037	107733	14159V	PARTICIPANT	\N	PRESENT	0
109038	107733	08068F	PARTICIPANT	\N	PRESENT	0
109039	107733	08016S	PARTICIPANT	\N	PRESENT	0
109040	107733	14221J	PARTICIPANT	\N	PRESENT	0
109041	107733	14255U	PARTICIPANT	\N	PRESENT	0
109042	107733	14073Q	PARTICIPANT	\N	PRESENT	0
109043	107733	14179A	PARTICIPANT	\N	PRESENT	0
109044	107733	95063L	PARTICIPANT	\N	PRESENT	0
109045	107733	11074Q	PARTICIPANT	\N	PRESENT	0
109046	107733	04070G	PARTICIPANT	\N	PRESENT	0
109047	107733	14037X	PARTICIPANT	\N	PRESENT	0
109052	107733	08051V	PARTICIPANT	\N	PRESENT	0
109072	106488	14014Q	PARTICIPANT	\N	EXCUSE	0
109074	109073	04071H	PARTICIPANT	\N	PRESENT	0
109076	109075	04071H	PARTICIPANT	\N	PRESENT	0
109094	109093	08034U	PARTICIPANT	\N	PRESENT	0
109096	109095	01031L	PARTICIPANT	\N	PRESENT	0
109190	109189	14173T	PARTICIPANT	\N	PRESENT	0
109194	109193	14173T	PARTICIPANT	\N	PRESENT	0
112343	112342	14030Q	PARTICIPANT	\N	EXCUSE	0
112344	112342	08043V	PARTICIPANT	\N	PRESENT	0
112345	112342	08060W	PARTICIPANT	\N	EXCUSE	0
112346	112342	11029K	PARTICIPANT	\N	PRESENT	0
112347	112342	14038Y	PARTICIPANT	\N	EXCUSE	0
112348	112342	14041T	PARTICIPANT	\N	EXCUSE	0
112349	112342	04035D	PARTICIPANT	\N	EXCUSE	0
112350	112342	11061K	PARTICIPANT	\N	PRESENT	0
112351	112342	07026Q	PARTICIPANT	\N	PRESENT	0
112352	112342	08056B	PARTICIPANT	\N	EXCUSE	0
112353	112342	14237S	PARTICIPANT	\N	EXCUSE	0
112354	112342	09001P	PARTICIPANT	\N	PRESENT	0
112355	112342	80013X	PARTICIPANT	\N	PRESENT	0
112356	112342	11067R	PARTICIPANT	\N	PRESENT	0
112774	112772	11036J	PARTICIPANT	\N	PRESENT	0
112782	112772	80013X	PARTICIPANT	\N	EXCUSE	0
112788	112772	14033T	PARTICIPANT	\N	PRESENT	0
112792	112772	04049K	PARTICIPANT	\N	PRESENT	0
112796	112772	11100Y	PRESIDENT	0	PRESENT	0
112799	112772	01043Q	PARTICIPANT	\N	EXCUSE	0
112802	112772	08019V	PARTICIPANT	\N	PRESENT	0
94677	94676	14263U	PARTICIPANT	\N	PRESENT	0
97470	97458	98053W	PARTICIPANT	\N	PRESENT	0
97471	97458	89029V	PARTICIPANT	\N	PRESENT	0
94680	94676	04059M	PARTICIPANT	\N	PRESENT	0
97472	97458	08048B	PARTICIPANT	\N	PRESENT	0
94682	94676	01044R	PARTICIPANT	\N	PRESENT	0
94683	94676	08043V	PARTICIPANT	\N	PRESENT	0
94684	94676	14089Y	PARTICIPANT	\N	PRESENT	0
94685	94676	14105F	PARTICIPANT	\N	PRESENT	0
94686	94676	11029K	PARTICIPANT	\N	PRESENT	0
94687	94676	95015C	PARTICIPANT	\N	PRESENT	0
94688	94676	92015P	PARTICIPANT	\N	PRESENT	0
97473	97458	01007L	PARTICIPANT	\N	PRESENT	0
97474	97458	95037J	PARTICIPANT	\N	PRESENT	0
94691	94676	14329V	PARTICIPANT	\N	PRESENT	0
94692	94676	14209N	PARTICIPANT	\N	PRESENT	0
97475	97458	86034E	PARTICIPANT	\N	PRESENT	0
94694	94676	11091R	PARTICIPANT	\N	PRESENT	0
97476	97458	04094Q	PARTICIPANT	\N	PRESENT	0
94696	94676	98042T	PARTICIPANT	\N	PRESENT	0
97477	97458	08039A	PARTICIPANT	\N	PRESENT	0
94698	94676	01041N	PARTICIPANT	\N	PRESENT	0
94699	94676	01025N	PARTICIPANT	\N	PRESENT	0
94700	94676	01037S	PARTICIPANT	\N	PRESENT	0
97478	97458	11085T	PARTICIPANT	\N	PRESENT	0
101427	101426	08017T	PARTICIPANT	\N	PRESENT	0
94703	94676	11089X	PARTICIPANT	\N	PRESENT	0
94704	94676	07026Q	PARTICIPANT	\N	PRESENT	0
97480	97458	04088S	PARTICIPANT	\N	PRESENT	0
97481	97458	01019Q	PARTICIPANT	\N	PRESENT	0
97482	97458	04056J	PARTICIPANT	\N	PRESENT	0
101417	101416	95049N	PARTICIPANT	\N	PRESENT	0
94709	94676	14061L	PARTICIPANT	\N	PRESENT	0
94710	94676	14073Q	PARTICIPANT	\N	PRESENT	0
94711	94676	08031R	PARTICIPANT	\N	PRESENT	0
101418	101416	04085P	PARTICIPANT	\N	PRESENT	0
94713	94676	08039A	PARTICIPANT	\N	PRESENT	0
101428	101426	01041N	PARTICIPANT	\N	PRESENT	0
101429	101426	11091R	PARTICIPANT	\N	PRESENT	0
101430	101426	14235Q	PARTICIPANT	\N	PRESENT	0
103543	103532	14042U	PARTICIPANT	\N	PRESENT	0
101432	101426	14079W	PARTICIPANT	\N	PRESENT	0
103542	103532	14217N	PARTICIPANT	\N	PRESENT	0
94720	94676	04057K	PARTICIPANT	\N	EXCUSE	0
103544	103532	14151M	PARTICIPANT	\N	PRESENT	0
94722	94676	14109K	PARTICIPANT	\N	PRESENT	0
94723	94676	04070G	PRESIDENT	0	PRESENT	0
103545	103532	12042Y	PARTICIPANT	\N	PRESENT	0
103546	103532	14281W	PARTICIPANT	\N	PRESENT	0
103547	103532	14087W	PARTICIPANT	\N	PRESENT	0
103548	103532	14034U	PARTICIPANT	\N	PRESENT	0
103549	103532	11061K	PARTICIPANT	\N	PRESENT	0
103550	103532	08041T	PARTICIPANT	\N	PRESENT	0
103551	103532	14026U	PARTICIPANT	\N	PRESENT	0
103552	103532	14213J	PARTICIPANT	\N	PRESENT	0
94732	94676	11071M	PARTICIPANT	\N	PRESENT	0
103553	103532	14121F	PARTICIPANT	\N	PRESENT	0
103554	103532	11112D	PARTICIPANT	\N	PRESENT	0
103555	103532	14037X	PARTICIPANT	\N	PRESENT	0
103556	103532	14018U	PARTICIPANT	\N	PRESENT	0
103557	103532	11067R	PARTICIPANT	\N	PRESENT	0
103558	103532	14223L	PARTICIPANT	\N	PRESENT	0
103559	103532	04092N	PRESIDENT	0	PRESENT	0
103560	103532	14265W	PARTICIPANT	\N	PRESENT	0
103561	103532	14119M	PARTICIPANT	\N	PRESENT	0
103562	103532	14071N	PARTICIPANT	\N	PRESENT	0
103563	103532	07032N	PARTICIPANT	\N	PRESENT	0
103564	103532	14271U	PARTICIPANT	\N	PRESENT	0
103565	103532	11093T	PARTICIPANT	\N	PRESENT	0
103566	103532	11097X	PARTICIPANT	\N	PRESENT	0
103567	103532	04045F	PARTICIPANT	\N	PRESENT	0
103568	103532	01034P	PARTICIPANT	\N	PRESENT	0
103569	103532	11063M	PARTICIPANT	\N	PRESENT	0
103570	103532	14269B	PARTICIPANT	\N	PRESENT	0
104633	104632	07034Q	PARTICIPANT	\N	PRESENT	0
104635	104634	07034Q	PARTICIPANT	\N	PRESENT	0
104637	104636	07034Q	PARTICIPANT	\N	PRESENT	0
104819	104817	04053F	PARTICIPANT	\N	PRESENT	0
104820	104817	14053L	PARTICIPANT	\N	PRESENT	0
104821	104817	11103C	PARTICIPANT	\N	PRESENT	0
104822	104817	14267Y	PARTICIPANT	\N	PRESENT	0
104823	104817	08052W	PARTICIPANT	\N	PRESENT	0
104824	104817	01059Y	PARTICIPANT	\N	PRESENT	0
104825	104817	10006L	PARTICIPANT	\N	PRESENT	0
104826	104817	12042Y	PARTICIPANT	\N	PRESENT	0
104827	104817	08048B	PARTICIPANT	\N	PRESENT	0
104828	104817	14026U	PARTICIPANT	\N	PRESENT	0
104829	104817	14213J	PARTICIPANT	\N	PRESENT	0
104830	104817	11112D	PARTICIPANT	\N	PRESENT	0
104831	104817	14037X	PARTICIPANT	\N	PRESENT	0
104833	104817	11067R	PARTICIPANT	\N	PRESENT	0
104834	104817	14223L	PARTICIPANT	\N	PRESENT	0
104835	104817	04092N	PRESIDENT	0	PRESENT	0
104836	104817	14265W	PARTICIPANT	\N	PRESENT	0
104837	104817	14119M	PARTICIPANT	\N	PRESENT	0
104838	104817	14071N	PARTICIPANT	\N	PRESENT	0
104839	104817	11093T	PARTICIPANT	\N	PRESENT	0
104840	104817	11097X	PARTICIPANT	\N	PRESENT	0
104841	104817	04045F	PARTICIPANT	\N	PRESENT	0
104842	104817	14227Q	PARTICIPANT	\N	PRESENT	0
104843	104817	14269B	PARTICIPANT	\N	PRESENT	0
105310	99613	14093U	PARTICIPANT	\N	EXCUSE	0
105345	105344	14239U	PARTICIPANT	\N	PRESENT	0
106514	106513	01016M	PARTICIPANT	\N	PRESENT	0
105347	105344	01046T	PARTICIPANT	\N	PRESENT	0
105348	105344	04053F	PARTICIPANT	\N	PRESENT	0
105349	105344	14255U	PARTICIPANT	\N	PRESENT	0
105350	105344	04066L	PARTICIPANT	\N	PRESENT	0
106515	106513	04034C	PARTICIPANT	\N	PRESENT	0
105352	105344	14053L	PARTICIPANT	\N	PRESENT	0
105353	105344	11103C	PARTICIPANT	\N	PRESENT	0
105354	105344	11044J	PARTICIPANT	\N	PRESENT	0
106974	106488	04044E	PARTICIPANT	\N	EXCUSE	0
105356	105344	14267Y	PARTICIPANT	\N	PRESENT	0
107741	107740	04053F	PARTICIPANT	\N	PRESENT	0
107742	107740	14255U	PARTICIPANT	\N	PRESENT	0
105359	105344	08052W	PARTICIPANT	\N	PRESENT	0
107743	107740	04066L	PARTICIPANT	\N	PRESENT	0
105361	105344	04081K	PARTICIPANT	\N	PRESENT	0
107744	107740	11103C	PARTICIPANT	\N	PRESENT	0
105363	105344	10006L	PARTICIPANT	\N	PRESENT	0
105364	105344	04067M	PARTICIPANT	\N	PRESENT	0
105365	105344	14217N	PARTICIPANT	\N	PRESENT	0
105366	105344	14042U	PARTICIPANT	\N	PRESENT	0
105367	105344	14151M	PARTICIPANT	\N	PRESENT	0
105368	105344	12042Y	PARTICIPANT	\N	PRESENT	0
105369	105344	14281W	PARTICIPANT	\N	PRESENT	0
105370	105344	14087W	PARTICIPANT	\N	PRESENT	0
105371	105344	01003G	PARTICIPANT	\N	PRESENT	0
105372	105344	14034U	PARTICIPANT	\N	PRESENT	0
105373	105344	14231L	PARTICIPANT	\N	PRESENT	0
105374	105344	11061K	PARTICIPANT	\N	PRESENT	0
105375	105344	08048B	PARTICIPANT	\N	PRESENT	0
105376	105344	08041T	PARTICIPANT	\N	PRESENT	0
105377	105344	01011G	PARTICIPANT	\N	PRESENT	0
105378	105344	14026U	PARTICIPANT	\N	PRESENT	0
105379	105344	14213J	PARTICIPANT	\N	PRESENT	0
105380	105344	14121F	PARTICIPANT	\N	PRESENT	0
105381	105344	11112D	PARTICIPANT	\N	PRESENT	0
105382	105344	14037X	PARTICIPANT	\N	PRESENT	0
105383	105344	14018U	PARTICIPANT	\N	PRESENT	0
105384	105344	11067R	PARTICIPANT	\N	PRESENT	0
105385	105344	14223L	PARTICIPANT	\N	PRESENT	0
105386	105344	04092N	PRESIDENT	0	PRESENT	0
105387	105344	14265W	PARTICIPANT	\N	PRESENT	0
105388	105344	14119M	PARTICIPANT	\N	PRESENT	0
105389	105344	14071N	PARTICIPANT	\N	PRESENT	0
105390	105344	07032N	PARTICIPANT	\N	PRESENT	0
105391	105344	04043D	PARTICIPANT	\N	PRESENT	0
105392	105344	14271U	PARTICIPANT	\N	PRESENT	0
105393	105344	14017T	PARTICIPANT	\N	PRESENT	0
105394	105344	11093T	PARTICIPANT	\N	PRESENT	0
105395	105344	11097X	PARTICIPANT	\N	PRESENT	0
105396	105344	04045F	PARTICIPANT	\N	PRESENT	0
105397	105344	14227Q	PARTICIPANT	\N	PRESENT	0
105398	105344	01034P	PARTICIPANT	\N	PRESENT	0
107745	107740	14195A	PARTICIPANT	\N	PRESENT	0
105400	105344	11063M	PARTICIPANT	\N	PRESENT	0
105401	105344	14269B	PARTICIPANT	\N	PRESENT	0
107746	107740	14267Y	PARTICIPANT	\N	PRESENT	0
107747	107740	08052W	PARTICIPANT	\N	PRESENT	0
107748	107740	10006L	PARTICIPANT	\N	PRESENT	0
107749	107740	14217N	PARTICIPANT	\N	PRESENT	0
107750	107740	14042U	PARTICIPANT	\N	PRESENT	0
107751	107740	14151M	PARTICIPANT	\N	PRESENT	0
107753	107740	12042Y	PARTICIPANT	\N	PRESENT	0
107754	107740	14087W	PARTICIPANT	\N	PRESENT	0
107755	107740	14034U	PARTICIPANT	\N	PRESENT	0
107795	107740	14231L	PARTICIPANT	\N	PRESENT	0
118052	117756	14227Q	PARTICIPANT	\N	PRESENT	0
119583	119579	08034U	PARTICIPANT	\N	PRESENT	0
120741	119930	11029K	PARTICIPANT	\N	PRESENT	0
120742	119930	13002U	PARTICIPANT	\N	PRESENT	0
120743	119930	11046L	PARTICIPANT	\N	PRESENT	0
120744	119930	14013P	PARTICIPANT	\N	PRESENT	0
120745	119930	14041T	PARTICIPANT	\N	PRESENT	0
120746	119930	14265W	PARTICIPANT	\N	PRESENT	0
120747	119930	14173T	PARTICIPANT	\N	PRESENT	0
120748	119930	11012A	PARTICIPANT	\N	PRESENT	0
120749	119930	14089Y	PARTICIPANT	\N	PRESENT	0
120750	119930	04041B	PARTICIPANT	\N	PRESENT	0
120751	119930	01015L	PARTICIPANT	\N	PRESENT	0
120752	119930	11033F	PARTICIPANT	\N	PRESENT	0
120753	119930	08018U	PARTICIPANT	\N	PRESENT	0
120754	119930	04070G	PARTICIPANT	\N	PRESENT	0
120755	119930	95015C	PARTICIPANT	\N	PRESENT	0
120756	119930	01058X	PARTICIPANT	\N	PRESENT	0
120757	119930	95063L	PARTICIPANT	\N	PRESENT	0
120758	119930	14065Q	PARTICIPANT	\N	PRESENT	0
120759	119930	08009T	PARTICIPANT	\N	PRESENT	0
120760	119930	08019V	PARTICIPANT	\N	PRESENT	0
120761	119930	14038Y	PARTICIPANT	\N	PRESENT	0
120762	119930	14026U	PARTICIPANT	\N	PRESENT	0
120763	119930	14147R	PARTICIPANT	\N	PRESENT	0
120764	119930	08047A	PARTICIPANT	\N	PRESENT	0
120765	119930	01019Q	PARTICIPANT	\N	PRESENT	0
120766	119930	08041T	PARTICIPANT	\N	PRESENT	0
120739	119930	01007L	PARTICIPANT	\N	PRESENT	0
120740	119930	01028R	PARTICIPANT	\N	PRESENT	0
120767	119930	05008E	PARTICIPANT	\N	PRESENT	0
120769	119930	11089X	PARTICIPANT	\N	PRESENT	0
120770	119930	14207L	PARTICIPANT	\N	PRESENT	0
120771	119930	14261S	PARTICIPANT	\N	PRESENT	0
120772	119930	11104D	PARTICIPANT	\N	PRESENT	0
120773	119930	90003B	PARTICIPANT	\N	PRESENT	0
120774	119930	01008M	PARTICIPANT	\N	PRESENT	0
120775	119930	14267Y	PARTICIPANT	\N	PRESENT	0
120776	119930	04044E	PARTICIPANT	\N	PRESENT	0
120834	119930	11098Y	PARTICIPANT	\N	PRESENT	0
120835	119930	01025N	PARTICIPANT	\N	PRESENT	0
120836	119930	14030Q	PARTICIPANT	\N	PRESENT	0
120837	119930	14257W	PARTICIPANT	\N	PRESENT	0
120838	119930	14221J	PARTICIPANT	\N	PRESENT	0
120839	119930	14135M	PARTICIPANT	\N	PRESENT	0
120840	119930	11113E	PARTICIPANT	\N	PRESENT	0
120841	119930	04081K	PARTICIPANT	\N	PRESENT	0
120842	119930	04088S	PARTICIPANT	\N	PRESENT	0
120843	119930	14037X	PARTICIPANT	\N	PRESENT	0
120844	119930	08043V	PARTICIPANT	\N	PRESENT	0
120845	119930	95030B	PARTICIPANT	\N	PRESENT	0
120846	119930	04057K	PARTICIPANT	\N	PRESENT	0
120847	119930	14063N	PARTICIPANT	\N	PRESENT	0
120848	119930	14273W	PARTICIPANT	\N	PRESENT	0
120849	119930	14217N	PARTICIPANT	\N	PRESENT	0
120850	119930	11026G	PARTICIPANT	\N	PRESENT	0
120851	119930	14033T	PARTICIPANT	\N	PRESENT	0
120852	119930	14097Y	PARTICIPANT	\N	PRESENT	0
120853	119930	14031R	PARTICIPANT	\N	PRESENT	0
120854	119930	01047U	PARTICIPANT	\N	PRESENT	0
120855	119930	11027H	PARTICIPANT	\N	PRESENT	0
120856	119930	11036J	PARTICIPANT	\N	PRESENT	0
120857	119930	08015R	PARTICIPANT	\N	PRESENT	0
120858	119930	14223L	PARTICIPANT	\N	PRESENT	0
120859	119930	14209N	PARTICIPANT	\N	PRESENT	0
120860	119930	01024M	PARTICIPANT	\N	PRESENT	0
120861	119930	11049P	PARTICIPANT	\N	PRESENT	0
120862	119930	14111D	PARTICIPANT	\N	PRESENT	0
120863	119930	97011G	PARTICIPANT	\N	PRESENT	0
120892	119930	14251Q	PARTICIPANT	\N	PRESENT	0
120895	119930	01037S	PARTICIPANT	\N	PRESENT	0
120896	119930	14199E	PARTICIPANT	\N	PRESENT	0
120898	119931	01007L	PARTICIPANT	\N	PRESENT	0
120899	119931	01024M	PARTICIPANT	\N	PRESENT	0
120900	119931	11098Y	PARTICIPANT	\N	PRESENT	0
120901	119931	11026G	PARTICIPANT	\N	PRESENT	0
120902	119931	14065Q	PARTICIPANT	\N	PRESENT	0
120903	119931	14097Y	PARTICIPANT	\N	PRESENT	0
120904	119931	13002U	PARTICIPANT	\N	PRESENT	0
120905	119931	01037S	PARTICIPANT	\N	PRESENT	0
120906	119931	11033F	PARTICIPANT	\N	PRESENT	0
120907	119931	01015L	PARTICIPANT	\N	PRESENT	0
120908	119931	14030Q	PARTICIPANT	\N	PRESENT	0
120909	119931	14199E	PARTICIPANT	\N	PRESENT	0
120910	119931	08019V	PARTICIPANT	\N	PRESENT	0
120911	119931	14041T	PARTICIPANT	\N	PRESENT	0
120912	119931	14031R	PARTICIPANT	\N	PRESENT	0
120913	119931	11049P	PARTICIPANT	\N	PRESENT	0
120914	119931	14251Q	PARTICIPANT	\N	PRESENT	0
120915	119931	14223L	PARTICIPANT	\N	PRESENT	0
120916	119931	08056B	PARTICIPANT	\N	PRESENT	0
120917	119931	14217N	PARTICIPANT	\N	PRESENT	0
120918	119931	08060W	PARTICIPANT	\N	PRESENT	0
120919	119931	14063N	PARTICIPANT	\N	PRESENT	0
120921	119931	14038Y	PARTICIPANT	\N	PRESENT	0
120922	119931	11056N	PARTICIPANT	\N	PRESENT	0
120923	119931	14109K	PARTICIPANT	\N	PRESENT	0
120924	119931	08022Q	PARTICIPANT	\N	PRESENT	0
120925	119931	11113E	PARTICIPANT	\N	PRESENT	0
120926	119931	97011G	PARTICIPANT	\N	PRESENT	0
120927	119931	14219Q	PARTICIPANT	\N	PRESENT	0
120928	119931	14169X	PARTICIPANT	\N	PRESENT	0
120929	119931	01058X	PARTICIPANT	\N	PRESENT	0
120930	119931	04088S	PARTICIPANT	\N	PRESENT	0
120931	119931	14261S	PARTICIPANT	\N	PRESENT	0
120932	119931	08051V	PARTICIPANT	\N	PRESENT	0
120933	119931	14111D	PARTICIPANT	\N	PRESENT	0
120934	119931	14119M	PARTICIPANT	\N	PRESENT	0
120935	119931	14069U	PARTICIPANT	\N	PRESENT	0
120936	119931	14207L	PARTICIPANT	\N	PRESENT	0
120937	119931	14257W	PARTICIPANT	\N	PRESENT	0
120938	119931	14079W	PARTICIPANT	\N	PRESENT	0
120939	119931	14037X	PARTICIPANT	\N	PRESENT	0
120940	119931	11010L	PARTICIPANT	\N	PRESENT	0
120941	119931	04057K	PARTICIPANT	\N	PRESENT	0
120942	119931	08034U	PARTICIPANT	\N	PRESENT	0
120943	119931	14135M	PARTICIPANT	\N	PRESENT	0
120944	119931	14197C	PARTICIPANT	\N	PRESENT	0
120945	119931	14205J	PARTICIPANT	\N	PRESENT	0
120947	119931	14265W	PARTICIPANT	\N	PRESENT	0
120948	119931	14147R	PARTICIPANT	\N	PRESENT	0
120949	119931	80013X	PARTICIPANT	\N	PRESENT	0
120950	119931	07004J	PARTICIPANT	\N	PRESENT	0
120951	119931	95030B	PARTICIPANT	\N	PRESENT	0
120952	119931	08015R	PARTICIPANT	\N	PRESENT	0
120953	119931	14253S	PARTICIPANT	\N	PRESENT	0
120954	119931	04048J	PARTICIPANT	\N	PRESENT	0
120955	119931	14271U	PARTICIPANT	\N	PRESENT	0
120956	119931	14211G	PARTICIPANT	\N	PRESENT	0
120957	119931	08017T	PARTICIPANT	\N	PRESENT	0
120958	119931	05008E	PARTICIPANT	\N	PRESENT	0
120959	119931	11103C	PARTICIPANT	\N	PRESENT	0
120960	119931	08010L	PARTICIPANT	\N	PRESENT	0
120961	119931	11112D	PARTICIPANT	\N	PRESENT	0
120962	119931	05012A	PARTICIPANT	\N	PRESENT	0
121713	121712	14253S	PARTICIPANT	\N	PRESENT	0
121716	121715	14253S	PARTICIPANT	\N	PRESENT	0
121714	121712	14157T	PARTICIPANT	\N	PRESENT	0
121717	121715	14157T	PARTICIPANT	\N	PRESENT	0
121719	121718	14253S	PARTICIPANT	\N	PRESENT	0
121720	121718	14157T	PARTICIPANT	\N	PRESENT	0
121777	121776	04059M	PARTICIPANT	\N	PRESENT	0
122921	122920	11039M	PARTICIPANT	\N	PRESENT	0
122922	122920	98042T	PARTICIPANT	\N	PRESENT	0
122923	122920	01019Q	PARTICIPANT	\N	PRESENT	0
123429	122639	92045V	PARTICIPANT	\N	PRESENT	0
123430	122639	14089Y	PARTICIPANT	\N	PRESENT	0
123431	122639	11032E	PARTICIPANT	\N	PRESENT	0
123432	122639	11042G	PARTICIPANT	\N	PRESENT	0
123433	122639	11026G	PARTICIPANT	\N	PRESENT	0
123434	122639	01028R	PARTICIPANT	\N	PRESENT	0
123435	122639	04079R	PARTICIPANT	\N	PRESENT	0
123439	122639	11077T	PARTICIPANT	\N	PRESENT	0
123452	122639	14069U	PARTICIPANT	\N	PRESENT	0
123453	122639	11012A	PARTICIPANT	\N	PRESENT	0
123454	122639	14179A	PARTICIPANT	\N	PRESENT	0
123541	123540	14030Q	PARTICIPANT	\N	EXCUSE	0
123542	123540	08060W	PARTICIPANT	\N	EXCUSE	0
123544	123540	11029K	PARTICIPANT	\N	PRESENT	0
123545	123540	14038Y	PARTICIPANT	\N	EXCUSE	0
123546	123540	11031D	PARTICIPANT	\N	PRESENT	0
123547	123540	80013X	PARTICIPANT	\N	PRESENT	0
123548	123540	14041T	PARTICIPANT	\N	EXCUSE	0
123549	123540	14217N	PARTICIPANT	\N	PRESENT	0
123550	123540	14281W	PARTICIPANT	\N	PRESENT	0
123551	123540	07026Q	PARTICIPANT	\N	PRESENT	0
123552	123540	95035G	PARTICIPANT	\N	EXCUSE	0
104237	104236	11095V	PARTICIPANT	\N	PRESENT	0
104238	104236	08034U	PARTICIPANT	\N	PRESENT	0
104239	104236	83047W	PARTICIPANT	\N	PRESENT	0
104240	104236	11046L	PARTICIPANT	\N	PRESENT	0
104241	104236	01034P	PARTICIPANT	\N	PRESENT	0
104242	104236	92045V	PARTICIPANT	\N	PRESENT	0
109528	109526	11106F	PARTICIPANT	\N	PRESENT	0
109533	109532	04040A	PARTICIPANT	\N	PRESENT	0
109534	109532	14097Y	PARTICIPANT	\N	PRESENT	0
109535	109532	08058D	PARTICIPANT	\N	PRESENT	0
109536	109532	95035G	PARTICIPANT	\N	PRESENT	0
109554	109553	92020L	PARTICIPANT	\N	EXCUSE	0
109555	109553	11082Q	PARTICIPANT	\N	EXCUSE	0
109556	109553	11054L	PARTICIPANT	\N	EXCUSE	0
109557	109553	14089Y	PARTICIPANT	\N	PRESENT	0
109558	109553	98029W	PARTICIPANT	\N	PRESENT	0
109559	109553	14041T	PARTICIPANT	\N	PRESENT	0
109560	109553	14217N	PARTICIPANT	\N	PRESENT	0
109561	109553	14281W	PRESIDENT	0	PRESENT	0
109562	109553	07004J	PARTICIPANT	\N	PRESENT	0
109563	109553	11049P	PARTICIPANT	\N	PRESENT	0
109564	109553	08053X	PARTICIPANT	\N	PRESENT	0
109565	109553	14193X	PARTICIPANT	\N	PRESENT	0
109566	109553	10015M	PARTICIPANT	\N	PRESENT	0
109567	109553	11037K	PARTICIPANT	\N	PRESENT	0
109568	109553	14269B	PARTICIPANT	\N	PRESENT	0
112167	112120	07032N	PARTICIPANT	\N	PRESENT	0
112223	112120	01031L	PARTICIPANT	\N	PRESENT	0
112169	112120	14271U	PARTICIPANT	\N	PRESENT	0
112224	112120	14175V	PARTICIPANT	\N	PRESENT	0
112225	112120	14083S	PARTICIPANT	\N	PRESENT	0
112171	112120	11093T	PARTICIPANT	\N	PRESENT	0
112226	112120	11053K	PARTICIPANT	\N	PRESENT	0
112227	112120	14085U	PARTICIPANT	\N	PRESENT	0
112228	112120	11042G	PARTICIPANT	\N	PRESENT	0
112229	112120	04086Q	PARTICIPANT	\N	PRESENT	0
112230	112120	04055H	PARTICIPANT	\N	PRESENT	0
112231	112120	11070L	PARTICIPANT	\N	PRESENT	0
112232	112120	11088W	PARTICIPANT	\N	PRESENT	0
112233	112120	08022Q	PARTICIPANT	\N	PRESENT	0
112234	112120	01027Q	PARTICIPANT	\N	PRESENT	0
112235	112120	04071H	PARTICIPANT	\N	PRESENT	0
112236	112120	11083R	PARTICIPANT	\N	PRESENT	0
112237	112120	08069G	PARTICIPANT	\N	PRESENT	0
112238	112120	99004R	PARTICIPANT	\N	PRESENT	0
112239	112120	14159V	PARTICIPANT	\N	PRESENT	0
112240	112120	07029T	PARTICIPANT	\N	PRESENT	0
112241	112120	08010L	PARTICIPANT	\N	PRESENT	0
112242	112120	08034U	PARTICIPANT	\N	PRESENT	0
112243	112120	98046X	PARTICIPANT	\N	PRESENT	0
112244	112120	08011M	PARTICIPANT	\N	PRESENT	0
112245	112120	08061X	PARTICIPANT	\N	PRESENT	0
112246	112120	01016M	PARTICIPANT	\N	PRESENT	0
112247	112120	14225N	PARTICIPANT	\N	PRESENT	0
112248	112120	11057P	PARTICIPANT	\N	PRESENT	0
112172	112120	11097X	PARTICIPANT	\N	PRESENT	0
112173	112120	04045F	PARTICIPANT	\N	PRESENT	0
112249	112120	04034C	PARTICIPANT	\N	PRESENT	0
112175	112120	01034P	PARTICIPANT	\N	PRESENT	0
115014	99613	01027Q	PARTICIPANT	\N	PRESENT	0
115383	115194	08034U	PARTICIPANT	\N	EXCUSE	0
112178	112120	14269B	PARTICIPANT	\N	PRESENT	0
115413	115412	96004D	PARTICIPANT	\N	PRESENT	0
115414	115412	11040E	PARTICIPANT	\N	PRESENT	0
115415	115412	14089Y	PARTICIPANT	\N	PRESENT	0
115416	115412	90003B	PARTICIPANT	\N	PRESENT	0
115417	115412	11035H	PARTICIPANT	\N	PRESENT	0
115418	115412	11083R	PARTICIPANT	\N	PRESENT	0
115419	115412	14097Y	PARTICIPANT	\N	PRESENT	0
115420	115412	04061F	PARTICIPANT	\N	PRESENT	0
115422	115412	95037J	PARTICIPANT	\N	PRESENT	0
115423	115412	11026G	PARTICIPANT	\N	PRESENT	0
115424	115412	98046X	PARTICIPANT	\N	PRESENT	0
115425	115412	14001X	PARTICIPANT	\N	PRESENT	0
115426	115412	04057K	PARTICIPANT	\N	PRESENT	0
115427	115412	04080J	PARTICIPANT	\N	PRESENT	0
115428	115412	10015M	PARTICIPANT	\N	PRESENT	0
115429	115412	04045F	PARTICIPANT	\N	PRESENT	0
115430	115412	98035U	PARTICIPANT	\N	PRESENT	0
115431	115412	92045V	PARTICIPANT	\N	PRESENT	0
115432	115412	04034C	PARTICIPANT	\N	PRESENT	0
115433	115412	14133K	PARTICIPANT	\N	EXCUSE	0
115434	115412	95030B	PARTICIPANT	\N	EXCUSE	0
115435	115412	04035D	PARTICIPANT	\N	EXCUSE	0
115436	115412	14073Q	PARTICIPANT	\N	EXCUSE	0
115437	115412	08018U	PARTICIPANT	\N	EXCUSE	0
115439	115438	11074Q	PARTICIPANT	\N	PRESENT	0
115440	115438	04056J	PARTICIPANT	\N	PRESENT	0
115441	115438	88008L	PARTICIPANT	\N	PRESENT	0
119113	119112	14187A	PARTICIPANT	\N	PRESENT	0
119114	119112	14269B	PARTICIPANT	\N	PRESENT	0
119116	119115	14187A	PARTICIPANT	\N	PRESENT	0
119117	119115	14269B	PARTICIPANT	\N	PRESENT	0
119133	119132	11033F	PARTICIPANT	\N	PRESENT	0
119134	119132	04044E	PARTICIPANT	\N	PRESENT	0
119136	119135	11033F	PARTICIPANT	\N	PRESENT	0
119137	119135	04044E	PARTICIPANT	\N	PRESENT	0
119139	119138	11033F	PARTICIPANT	\N	PRESENT	0
119140	119138	04044E	PARTICIPANT	\N	PRESENT	0
119142	119141	11033F	PARTICIPANT	\N	PRESENT	0
119143	119141	04044E	PARTICIPANT	\N	PRESENT	0
119145	119144	11033F	PARTICIPANT	\N	PRESENT	0
119146	119144	04044E	PARTICIPANT	\N	PRESENT	0
119148	119147	11033F	PARTICIPANT	\N	PRESENT	0
119149	119147	04044E	PARTICIPANT	\N	PRESENT	0
119151	119150	11033F	PARTICIPANT	\N	PRESENT	0
119152	119150	04044E	PARTICIPANT	\N	PRESENT	0
119154	119153	11033F	PARTICIPANT	\N	PRESENT	0
119155	119153	04044E	PARTICIPANT	\N	PRESENT	0
119157	119156	14069U	PARTICIPANT	\N	PRESENT	0
119158	119156	11026G	PARTICIPANT	\N	PRESENT	0
119160	119159	14069U	PARTICIPANT	\N	PRESENT	0
119161	119159	11026G	PARTICIPANT	\N	PRESENT	0
119163	119162	14069U	PARTICIPANT	\N	PRESENT	0
119164	119162	11026G	PARTICIPANT	\N	PRESENT	0
119173	119172	14187A	PARTICIPANT	\N	PRESENT	0
119953	119952	08022Q	PARTICIPANT	\N	PRESENT	0
119954	119952	01016M	PARTICIPANT	\N	PRESENT	0
119955	119952	08061X	PARTICIPANT	\N	PRESENT	0
119956	119952	11053K	PARTICIPANT	\N	PRESENT	0
119957	119952	99004R	PARTICIPANT	\N	PRESENT	0
119959	119958	08022Q	PARTICIPANT	\N	PRESENT	0
119960	119958	01016M	PARTICIPANT	\N	PRESENT	0
119961	119958	04061F	PARTICIPANT	\N	PRESENT	0
119962	119958	98053W	PARTICIPANT	\N	PRESENT	0
119969	119968	14083S	PARTICIPANT	\N	PRESENT	0
119965	119963	14173T	PARTICIPANT	\N	PRESENT	0
119967	119966	11057P	PARTICIPANT	\N	PRESENT	0
119995	119994	04049K	PARTICIPANT	\N	PRESENT	0
119996	119994	14255U	PARTICIPANT	\N	PRESENT	0
119997	119994	14061L	PARTICIPANT	\N	PRESENT	0
122013	122012	98005N	PARTICIPANT	\N	PRESENT	0
122015	122012	08019V	PARTICIPANT	\N	PRESENT	0
122016	122012	11072N	PARTICIPANT	\N	PRESENT	0
122018	122012	14259Y	PARTICIPANT	\N	PRESENT	0
124059	124058	96004D	PRESIDENT	0	PRESENT	0
124060	124058	11040E	PARTICIPANT	\N	PRESENT	0
124061	124058	11083R	PARTICIPANT	\N	PRESENT	0
124062	124058	07024N	PARTICIPANT	\N	PRESENT	0
124063	124058	14014Q	PARTICIPANT	\N	PRESENT	0
124064	124058	04042C	PARTICIPANT	\N	PRESENT	0
124065	124058	04061F	PARTICIPANT	\N	PRESENT	0
124066	124058	83042R	PARTICIPANT	\N	PRESENT	0
124067	124058	04057K	PARTICIPANT	\N	PRESENT	0
124068	124058	04080J	PARTICIPANT	\N	PRESENT	0
124069	124058	95059Q	PRESIDENT	1	PRESENT	0
124070	124058	98035U	PARTICIPANT	\N	PRESENT	0
124071	124058	04034C	PARTICIPANT	\N	PRESENT	0
124073	124072	14071N	PARTICIPANT	\N	PRESENT	0
124075	124074	14071N	PARTICIPANT	\N	PRESENT	0
126431	125999	11077T	PARTICIPANT	\N	PRESENT	0
126432	125999	98005N	PARTICIPANT	\N	PRESENT	0
126433	125999	11104D	PARTICIPANT	\N	PRESENT	0
126434	125999	98035U	PARTICIPANT	\N	PRESENT	0
126435	125999	92031P	PARTICIPANT	\N	PRESENT	0
126436	125999	92015P	PARTICIPANT	\N	PRESENT	0
126437	125999	98046X	PARTICIPANT	\N	PRESENT	0
126438	125999	08052W	PARTICIPANT	\N	PRESENT	0
126439	125999	01011G	PARTICIPANT	\N	PRESENT	0
126440	125999	04066L	PARTICIPANT	\N	PRESENT	0
126441	125999	14249W	PARTICIPANT	\N	PRESENT	0
126442	125634	01058X	PARTICIPANT	\N	PRESENT	0
126443	125999	14213J	PARTICIPANT	\N	PRESENT	0
126444	125999	11066Q	PARTICIPANT	\N	PRESENT	0
126446	125999	11089X	PARTICIPANT	\N	PRESENT	0
126447	125999	14123H	PARTICIPANT	\N	PRESENT	0
126448	125999	14151M	PARTICIPANT	\N	PRESENT	0
126449	125999	01022K	PARTICIPANT	\N	PRESENT	0
112891	112890	08025T	PARTICIPANT	\N	PRESENT	0
112892	112890	04038G	PARTICIPANT	\N	PRESENT	0
112810	112772	11094U	PARTICIPANT	\N	EXCUSE	0
112893	112890	14041T	PARTICIPANT	\N	PRESENT	0
112894	112890	11010L	PARTICIPANT	\N	PRESENT	0
112895	112890	01007L	PARTICIPANT	\N	PRESENT	0
112896	112890	14001X	PARTICIPANT	\N	PRESENT	0
112897	112890	11072N	PARTICIPANT	\N	PRESENT	0
112898	112890	07034Q	PARTICIPANT	\N	PRESENT	0
112899	112890	01028R	PARTICIPANT	\N	PRESENT	0
112927	112926	04040A	PARTICIPANT	\N	PRESENT	0
112901	112890	04044E	PRESIDENT	0	PRESENT	0
112929	112928	08058D	PARTICIPANT	\N	PRESENT	0
112930	112928	95035G	PARTICIPANT	\N	PRESENT	0
112932	112931	04040A	PARTICIPANT	\N	PRESENT	0
112933	112931	95035G	PARTICIPANT	\N	PRESENT	0
112935	112934	08058D	PARTICIPANT	\N	PRESENT	0
112942	112928	04040A	PARTICIPANT	\N	PRESENT	0
113032	99613	11106F	PARTICIPANT	\N	EXCUSE	0
113034	113033	04040A	PARTICIPANT	\N	PRESENT	0
113035	113033	08058D	PARTICIPANT	\N	PRESENT	0
113036	113033	95035G	PARTICIPANT	\N	PRESENT	0
113038	113037	04040A	PARTICIPANT	\N	PRESENT	0
113040	113039	04040A	PARTICIPANT	\N	PRESENT	0
113041	113039	08058D	PARTICIPANT	\N	PRESENT	0
113042	113039	95035G	PARTICIPANT	\N	PRESENT	0
113044	113043	04040A	PARTICIPANT	\N	PRESENT	0
113045	113043	95035G	PARTICIPANT	\N	PRESENT	0
113047	113046	04040A	PARTICIPANT	\N	PRESENT	0
113048	113046	95035G	PARTICIPANT	\N	PRESENT	0
113050	113049	04040A	PARTICIPANT	\N	PRESENT	0
113051	113049	95035G	PARTICIPANT	\N	PRESENT	0
113053	113052	01031L	PRESIDENT	0	PRESENT	0
113054	113052	11068S	PARTICIPANT	\N	EXCUSE	0
113055	113052	11040E	PARTICIPANT	\N	PRESENT	0
113056	113052	08014Q	PARTICIPANT	\N	PRESENT	0
113057	113052	14175V	PARTICIPANT	\N	EXCUSE	0
113058	113052	11042G	PARTICIPANT	\N	EXCUSE	0
113059	113052	04086Q	PARTICIPANT	\N	PRESENT	0
113060	113052	11070L	PARTICIPANT	\N	PRESENT	0
113061	113052	04071H	PARTICIPANT	\N	PRESENT	0
113062	113052	11074Q	PARTICIPANT	\N	PRESENT	0
113063	113052	98053W	PARTICIPANT	\N	EXCUSE	0
113064	113052	11083R	PARTICIPANT	\N	PRESENT	0
113065	113052	08016S	PARTICIPANT	\N	EXCUSE	0
113066	113052	08069G	PARTICIPANT	\N	PRESENT	0
113067	113052	11048N	PARTICIPANT	\N	PRESENT	0
113068	113052	99004R	PARTICIPANT	\N	PRESENT	0
113069	113052	07029T	PARTICIPANT	\N	PRESENT	0
113070	113052	98046X	PARTICIPANT	\N	PRESENT	0
113071	113052	11085T	PARTICIPANT	\N	PRESENT	0
113072	113052	08011M	PARTICIPANT	\N	PRESENT	0
113073	113052	08061X	PARTICIPANT	\N	EXCUSE	0
113074	113052	14225N	PARTICIPANT	\N	EXCUSE	0
113075	113052	04034C	PARTICIPANT	\N	PRESENT	0
117807	117806	11036J	PARTICIPANT	\N	PRESENT	0
117808	117806	01044R	PARTICIPANT	\N	PRESENT	0
117809	117806	01015L	PARTICIPANT	\N	PRESENT	0
117810	117806	14219Q	PRESIDENT	0	PRESENT	0
117811	117806	14107H	PARTICIPANT	\N	PRESENT	0
117812	117806	14030Q	PARTICIPANT	\N	EXCUSE	0
117813	117806	11029K	PARTICIPANT	\N	EXCUSE	0
117814	117806	14038Y	PARTICIPANT	\N	EXCUSE	0
117815	117806	14197C	PARTICIPANT	\N	EXCUSE	0
117816	117806	04057K	PARTICIPANT	\N	EXCUSE	0
117817	117806	14265W	PARTICIPANT	\N	EXCUSE	0
117818	117806	05012A	PARTICIPANT	\N	EXCUSE	0
118034	118033	14187A	PARTICIPANT	\N	PRESENT	0
118035	118033	14269B	PARTICIPANT	\N	PRESENT	0
118037	118036	14187A	PARTICIPANT	\N	PRESENT	0
118038	118036	14231L	PARTICIPANT	\N	PRESENT	0
118039	118036	04089T	PARTICIPANT	\N	PRESENT	0
118040	118036	11090Q	PARTICIPANT	\N	PRESENT	0
118071	117032	04056J	PARTICIPANT	\N	PRESENT	0
118072	117032	01016M	PARTICIPANT	\N	PRESENT	0
118073	117032	11089X	PARTICIPANT	\N	PRESENT	0
118074	117032	95062K	PARTICIPANT	\N	PRESENT	0
118075	117032	11042G	PARTICIPANT	\N	PRESENT	0
118076	117032	14211G	PARTICIPANT	\N	PRESENT	0
118077	117032	08068F	PARTICIPANT	\N	PRESENT	0
118078	117032	08055A	PARTICIPANT	\N	PRESENT	0
118079	117032	08028W	PARTICIPANT	\N	PRESENT	0
118080	117032	11114F	PARTICIPANT	\N	PRESENT	0
118081	117032	11113E	PARTICIPANT	\N	PRESENT	0
118082	117032	14257W	PARTICIPANT	\N	PRESENT	0
118083	117032	95015C	PARTICIPANT	\N	PRESENT	0
118084	117032	14014Q	PARTICIPANT	\N	PRESENT	0
118085	117032	11014C	PARTICIPANT	\N	PRESENT	0
118086	117032	02002K	PARTICIPANT	\N	PRESENT	0
118087	117032	14271U	PARTICIPANT	\N	PRESENT	0
118088	117032	08060W	PARTICIPANT	\N	PRESENT	0
118089	117032	01013J	PARTICIPANT	\N	PRESENT	0
118090	117032	04050C	PARTICIPANT	\N	PRESENT	0
118091	117032	11034G	PARTICIPANT	\N	PRESENT	0
118092	117032	08010L	PARTICIPANT	\N	PRESENT	0
118093	117032	04085P	PARTICIPANT	\N	PRESENT	0
118094	117032	11054L	PARTICIPANT	\N	PRESENT	0
118095	117032	14237S	PARTICIPANT	\N	PRESENT	0
118096	117032	14167V	PARTICIPANT	\N	PRESENT	0
118097	117032	14121F	PARTICIPANT	\N	PRESENT	0
118098	117032	95067Q	PARTICIPANT	\N	PRESENT	0
118099	117032	11095V	PARTICIPANT	\N	PRESENT	0
118100	117032	14051J	PARTICIPANT	\N	PRESENT	0
118101	117032	08041T	PARTICIPANT	\N	PRESENT	0
118102	117032	14225N	PARTICIPANT	\N	PRESENT	0
118103	117032	11061K	PARTICIPANT	\N	PRESENT	0
118104	117032	87003B	PARTICIPANT	\N	PRESENT	0
118105	117032	01028R	PARTICIPANT	\N	PRESENT	0
118106	117032	11110B	PARTICIPANT	\N	PRESENT	0
118107	117032	08038Y	PARTICIPANT	\N	PRESENT	0
118108	117032	01057W	PARTICIPANT	\N	PRESENT	0
118109	117032	11068S	PARTICIPANT	\N	PRESENT	0
118110	117032	11067R	PARTICIPANT	\N	PRESENT	0
118111	117032	11025F	PARTICIPANT	\N	PRESENT	0
118112	117032	11099A	PARTICIPANT	\N	PRESENT	0
118113	117032	11083R	PARTICIPANT	\N	PRESENT	0
118114	117032	14026U	PARTICIPANT	\N	PRESENT	0
118115	117032	04067M	PARTICIPANT	\N	PRESENT	0
118116	117032	13002U	PARTICIPANT	\N	PRESENT	0
118117	117032	90003B	PARTICIPANT	\N	PRESENT	0
118118	117032	11107G	PARTICIPANT	\N	PRESENT	0
118119	117032	14241N	PARTICIPANT	\N	PRESENT	0
118120	117032	11097X	PARTICIPANT	\N	PRESENT	0
118121	117032	14261S	PARTICIPANT	\N	PRESENT	0
118122	117032	08031R	PARTICIPANT	\N	PRESENT	0
118123	117032	01046T	PARTICIPANT	\N	PRESENT	0
118124	117032	11091R	PARTICIPANT	\N	PRESENT	0
118125	117032	04081K	PARTICIPANT	\N	PRESENT	0
118126	117032	11093T	PARTICIPANT	\N	PRESENT	0
118127	117032	14083S	PARTICIPANT	\N	PRESENT	0
118128	117032	11085T	PARTICIPANT	\N	PRESENT	0
118129	117032	07029T	PARTICIPANT	\N	PRESENT	0
118130	117032	01047U	PARTICIPANT	\N	PRESENT	0
118131	117032	14255U	PARTICIPANT	\N	PRESENT	0
118132	117032	01025N	PARTICIPANT	\N	PRESENT	0
118133	117032	01007L	PARTICIPANT	\N	PRESENT	0
118134	117032	14041T	PARTICIPANT	\N	PRESENT	0
118135	117032	14327T	PARTICIPANT	\N	PRESENT	0
118136	117032	95041E	PARTICIPANT	\N	PRESENT	0
118137	117032	11088W	PARTICIPANT	\N	PRESENT	0
118138	117032	92031P	PARTICIPANT	\N	PRESENT	0
118139	117032	14217N	PARTICIPANT	\N	PRESENT	0
118140	117032	01041N	PARTICIPANT	\N	PRESENT	0
118141	117032	01008M	PARTICIPANT	\N	PRESENT	0
118142	117032	14059S	PARTICIPANT	\N	PRESENT	0
118143	117032	14061L	PARTICIPANT	\N	PRESENT	0
118144	117032	97011G	PARTICIPANT	\N	PRESENT	0
118145	117032	08034U	PARTICIPANT	\N	PRESENT	0
118146	117032	11103C	PARTICIPANT	\N	PRESENT	0
118147	117032	05012A	PARTICIPANT	\N	PRESENT	0
118148	117032	04057K	PARTICIPANT	\N	PRESENT	0
118149	117032	04033B	PARTICIPANT	\N	PRESENT	0
118150	117032	10006L	PARTICIPANT	\N	PRESENT	0
118151	117032	98018T	PARTICIPANT	\N	PRESENT	0
118152	117032	86044G	PARTICIPANT	\N	PRESENT	0
118153	117032	99004R	PARTICIPANT	\N	PRESENT	0
118154	117032	04035D	PARTICIPANT	\N	PRESENT	0
118155	117032	14105F	PARTICIPANT	\N	PRESENT	0
118156	117032	14119M	PARTICIPANT	\N	PRESENT	0
118157	117032	04097T	PARTICIPANT	\N	PRESENT	0
118158	117032	04034C	PARTICIPANT	\N	PRESENT	0
118159	117032	01024M	PARTICIPANT	\N	PRESENT	0
118160	117032	08048B	PARTICIPANT	\N	PRESENT	0
118161	117032	14213J	PARTICIPANT	\N	PRESENT	0
118162	117032	14265W	PARTICIPANT	\N	PRESENT	0
94137	94136	04047H	PARTICIPANT	\N	EXCUSE	0
94138	94136	14079W	PARTICIPANT	\N	EXCUSE	0
94139	94136	14041T	PARTICIPANT	\N	EXCUSE	0
94140	94136	08049C	PARTICIPANT	\N	EXCUSE	0
94141	94136	14089Y	PARTICIPANT	\N	PRESENT	0
94142	94136	04054G	PARTICIPANT	\N	PRESENT	0
94143	94136	14073Q	PARTICIPANT	\N	PRESENT	0
94144	94136	11015D	PARTICIPANT	\N	PRESENT	0
94145	94136	11026G	PARTICIPANT	\N	PRESENT	0
94146	94136	92031P	PRESIDENT	0	PRESENT	0
94147	94136	14251Q	PARTICIPANT	\N	PRESENT	0
94148	94136	14001X	PARTICIPANT	\N	PRESENT	0
94149	94136	08053X	PARTICIPANT	\N	PRESENT	0
94150	94136	95037J	PARTICIPANT	\N	PRESENT	0
94151	94136	95067Q	PARTICIPANT	\N	PRESENT	0
94152	94136	10015M	PARTICIPANT	\N	PRESENT	0
103493	103492	98018T	PARTICIPANT	\N	PRESENT	0
107796	107740	11061K	PARTICIPANT	\N	PRESENT	0
107797	107740	14026U	PARTICIPANT	\N	PRESENT	0
107798	107740	08041T	PARTICIPANT	\N	PRESENT	0
107799	107740	14213J	PARTICIPANT	\N	PRESENT	0
107800	107740	14121F	PARTICIPANT	\N	PRESENT	0
107801	107740	11112D	PARTICIPANT	\N	PRESENT	0
107802	107740	14037X	PARTICIPANT	\N	PRESENT	0
107803	107740	11067R	PARTICIPANT	\N	PRESENT	0
107804	107740	14223L	PARTICIPANT	\N	PRESENT	0
107805	107740	04092N	PRESIDENT	0	PRESENT	0
107806	107740	14265W	PARTICIPANT	\N	PRESENT	0
107807	107740	14119M	PARTICIPANT	\N	PRESENT	0
107808	107740	14071N	PARTICIPANT	\N	PRESENT	0
107809	107740	04043D	PARTICIPANT	\N	PRESENT	0
107810	107740	11093T	PARTICIPANT	\N	PRESENT	0
107811	107740	11097X	PARTICIPANT	\N	PRESENT	0
107812	107740	04045F	PARTICIPANT	\N	PRESENT	0
107813	107740	01034P	PARTICIPANT	\N	PRESENT	0
107814	107740	11063M	PARTICIPANT	\N	PRESENT	0
107815	107740	14269B	PARTICIPANT	\N	PRESENT	0
107816	107740	14239U	PARTICIPANT	\N	EXCUSE	0
107817	107740	14017T	PARTICIPANT	\N	EXCUSE	0
107852	107830	95035G	PARTICIPANT	\N	PRESENT	0
107854	107853	04040A	PARTICIPANT	\N	PRESENT	0
109158	109157	11040E	PARTICIPANT	\N	PRESENT	0
109159	109157	14089Y	PARTICIPANT	\N	PRESENT	0
109161	109157	11035H	PARTICIPANT	\N	PRESENT	0
109163	109157	11083R	PARTICIPANT	\N	PRESENT	0
109165	109157	14097Y	PARTICIPANT	\N	PRESENT	0
109166	109157	14073Q	PARTICIPANT	\N	PRESENT	0
109168	109157	98046X	PARTICIPANT	\N	PRESENT	0
109169	109157	08042U	PARTICIPANT	\N	PRESENT	0
109171	109157	10015M	PRESIDENT	0	PRESENT	0
109172	109157	01016M	PARTICIPANT	\N	PRESENT	0
109173	109157	92045V	PARTICIPANT	\N	PRESENT	0
109174	109157	96004D	PARTICIPANT	\N	EXCUSE	0
109175	109157	08018U	PARTICIPANT	\N	EXCUSE	0
109176	109157	04057K	PARTICIPANT	\N	EXCUSE	0
109177	109157	04061F	PARTICIPANT	\N	EXCUSE	0
109178	109157	11012A	PARTICIPANT	\N	EXCUSE	0
109784	109783	11095V	PARTICIPANT	\N	PRESENT	0
109785	109783	14217N	PARTICIPANT	\N	PRESENT	0
109786	109783	14042U	PARTICIPANT	\N	PRESENT	0
109787	109783	14249W	PARTICIPANT	\N	PRESENT	0
109788	109783	08034U	PARTICIPANT	\N	PRESENT	0
109789	109783	14265W	PARTICIPANT	\N	PRESENT	0
109790	109783	83047W	PARTICIPANT	\N	PRESENT	0
109791	109783	14235Q	PARTICIPANT	\N	PRESENT	0
109792	109783	01034P	PRESIDENT	0	PRESENT	0
109793	109783	92045V	PARTICIPANT	\N	PRESENT	0
109794	109783	11066Q	PARTICIPANT	\N	PRESENT	0
109795	109783	14079W	PARTICIPANT	\N	EXCUSE	0
109802	99612	14261S	PARTICIPANT	\N	PRESENT	0
109803	99612	14093U	PARTICIPANT	\N	PRESENT	0
109852	109849	08055A	PARTICIPANT	\N	PRESENT	0
109805	99612	11114F	PARTICIPANT	\N	PRESENT	0
109806	99612	14259Y	PARTICIPANT	\N	PRESENT	0
109807	99612	11113E	PARTICIPANT	\N	PRESENT	0
109808	99612	04095R	PARTICIPANT	\N	PRESENT	0
109809	99612	01022K	PARTICIPANT	\N	PRESENT	0
109810	99612	14097Y	PARTICIPANT	\N	PRESENT	0
109811	99612	98005N	PARTICIPANT	\N	PRESENT	0
109812	99612	14059S	PARTICIPANT	\N	PRESENT	0
109813	99612	08019V	PRESIDENT	0	PRESENT	0
109814	99612	04043D	PARTICIPANT	\N	EXCUSE	0
109815	99612	08073C	PARTICIPANT	\N	PRESENT	0
109816	99612	11072N	PARTICIPANT	\N	PRESENT	0
109817	99612	14275Y	PARTICIPANT	\N	PRESENT	0
109818	99612	11011M	PARTICIPANT	\N	PRESENT	0
109819	99612	11071M	PARTICIPANT	\N	EXCUSE	0
109850	109849	89017R	PARTICIPANT	\N	PRESENT	0
109851	109849	11039M	PARTICIPANT	\N	PRESENT	0
109853	109849	11029K	PARTICIPANT	\N	PRESENT	0
109854	109849	04066L	PARTICIPANT	\N	PRESENT	0
109855	109849	04042C	PARTICIPANT	\N	PRESENT	0
109856	109849	08024S	PARTICIPANT	\N	PRESENT	0
109857	109849	04081K	PARTICIPANT	\N	PRESENT	0
109858	109849	98042T	PARTICIPANT	\N	PRESENT	0
109859	109849	11110B	PARTICIPANT	\N	PRESENT	0
109860	109849	01003G	PARTICIPANT	\N	PRESENT	0
109861	109849	98053W	PARTICIPANT	\N	PRESENT	0
109862	109849	08048B	PARTICIPANT	\N	PRESENT	0
109863	109849	01007L	PARTICIPANT	\N	PRESENT	0
109864	109849	95037J	PARTICIPANT	\N	PRESENT	0
109865	109849	86034E	PARTICIPANT	\N	PRESENT	0
109866	109849	04094Q	PARTICIPANT	\N	PRESENT	0
109867	109849	08039A	PARTICIPANT	\N	PRESENT	0
109868	109849	01043Q	PARTICIPANT	\N	PRESENT	0
109869	109849	04057K	PARTICIPANT	\N	PRESENT	0
109870	109849	92040Q	PARTICIPANT	\N	PRESENT	0
109871	109849	04088S	PARTICIPANT	\N	PRESENT	0
109872	109849	01019Q	PARTICIPANT	\N	PRESENT	0
109873	109849	04056J	PARTICIPANT	\N	PRESENT	0
109891	109890	01056V	PARTICIPANT	\N	PRESENT	0
109892	109890	08058D	PARTICIPANT	\N	PRESENT	0
109893	109890	04036E	PARTICIPANT	\N	PRESENT	0
109894	109890	04045F	PARTICIPANT	\N	PRESENT	0
109915	109912	14030Q	PARTICIPANT	\N	PRESENT	0
109916	109912	08060W	PARTICIPANT	\N	EXCUSE	0
109917	109912	80013X	PARTICIPANT	\N	PRESENT	0
109918	109912	95035G	PARTICIPANT	\N	EXCUSE	0
109919	109912	04041B	PARTICIPANT	\N	EXCUSE	0
109920	109912	09001P	PRESIDENT	0	PRESENT	0
109921	109912	08031R	PARTICIPANT	\N	PRESENT	0
109922	109912	14031R	PARTICIPANT	\N	EXCUSE	0
109923	109912	11014C	PARTICIPANT	\N	PRESENT	0
109929	109928	11095V	PARTICIPANT	\N	PRESENT	0
109930	109928	14205J	PARTICIPANT	\N	PRESENT	0
109931	109928	83047W	PARTICIPANT	\N	PRESENT	0
109932	109928	11046L	PARTICIPANT	\N	PRESENT	0
109933	109928	01034P	PRESIDENT	0	PRESENT	0
109934	109928	92045V	PARTICIPANT	\N	PRESENT	0
109935	109928	14079W	PARTICIPANT	\N	EXCUSE	0
109936	109928	14265W	PARTICIPANT	\N	EXCUSE	0
110353	110352	98023Q	PARTICIPANT	\N	PRESENT	0
110354	110352	92039X	PARTICIPANT	\N	PRESENT	0
110355	110352	08056B	PARTICIPANT	\N	PRESENT	0
111213	111212	11055M	PARTICIPANT	\N	PRESENT	0
111214	111212	08043V	PARTICIPANT	\N	EXCUSE	0
111215	111212	14053L	PARTICIPANT	\N	PRESENT	0
111216	111212	95015C	PARTICIPANT	\N	PRESENT	0
111217	111212	08024S	PARTICIPANT	\N	PRESENT	0
111218	111212	11027H	PARTICIPANT	\N	PRESENT	0
111219	111212	04086Q	PARTICIPANT	\N	PRESENT	0
111221	111212	11088W	PARTICIPANT	\N	PRESENT	0
111222	111212	14215L	PARTICIPANT	\N	PRESENT	0
111223	111212	04089T	PARTICIPANT	\N	EXCUSE	0
111224	111212	14187A	PARTICIPANT	\N	PRESENT	0
111226	111212	04035D	PARTICIPANT	\N	PRESENT	0
111227	111212	14231L	PARTICIPANT	\N	PRESENT	0
111228	111212	14179A	PARTICIPANT	\N	PRESENT	0
111229	111212	14213J	PARTICIPANT	\N	PRESENT	0
111230	111212	08031R	PARTICIPANT	\N	EXCUSE	0
111231	111212	11100Y	PRESIDENT	0	PRESENT	0
111233	111212	08012N	PARTICIPANT	\N	PRESENT	0
111234	111212	11104D	PARTICIPANT	\N	PRESENT	0
111236	111212	07032N	PARTICIPANT	\N	PRESENT	0
111238	111212	11090Q	PARTICIPANT	\N	PRESENT	0
111239	111212	14235Q	PARTICIPANT	\N	PRESENT	0
111241	111212	11046L	PARTICIPANT	\N	PRESENT	0
111242	111212	01028R	PARTICIPANT	\N	PRESENT	0
111243	111212	11094U	PARTICIPANT	\N	PRESENT	0
111244	111212	11037K	PARTICIPANT	\N	PRESENT	0
111245	111212	14157T	PARTICIPANT	\N	PRESENT	0
111246	111212	92045V	PARTICIPANT	\N	PRESENT	0
111247	111212	11066Q	PARTICIPANT	\N	PRESENT	0
124033	124026	11083R	PARTICIPANT	\N	PRESENT	0
124034	124026	04057K	PARTICIPANT	\N	PRESENT	0
124047	124046	11083R	PARTICIPANT	\N	PRESENT	0
124048	124046	04057K	PARTICIPANT	\N	PRESENT	0
124055	124054	14157T	PARTICIPANT	\N	PRESENT	0
126148	120697	01027Q	PARTICIPANT	\N	PRESENT	0
124077	124076	96004D	PRESIDENT	0	PRESENT	0
124078	124076	04035D	PARTICIPANT	\N	PRESENT	0
124079	124076	11083R	PARTICIPANT	\N	PRESENT	0
124080	124076	14014Q	PARTICIPANT	\N	PRESENT	0
124081	124076	98022P	PARTICIPANT	\N	PRESENT	0
124082	124076	14097Y	PARTICIPANT	\N	PRESENT	0
124083	124076	04061F	PARTICIPANT	\N	PRESENT	0
124084	124076	83042R	PARTICIPANT	\N	PRESENT	0
124085	124076	04057K	PARTICIPANT	\N	PRESENT	0
124086	124076	98021N	PRESIDENT	1	PRESENT	0
124087	124076	04034C	PARTICIPANT	\N	PRESENT	0
124089	124088	04057K	PARTICIPANT	\N	PRESENT	0
124091	124090	04057K	PARTICIPANT	\N	PRESENT	0
124093	124092	04057K	PARTICIPANT	\N	PRESENT	0
124095	124094	04057K	PARTICIPANT	\N	PRESENT	0
126085	120697	14097Y	PARTICIPANT	\N	PRESENT	0
126269	123942	08051V	PARTICIPANT	\N	PRESENT	0
126270	123942	08010L	PARTICIPANT	\N	PRESENT	0
126271	123942	05012A	PARTICIPANT	\N	PRESENT	0
126272	123942	11032E	PARTICIPANT	\N	PRESENT	0
126273	123942	07032N	PARTICIPANT	\N	PRESENT	0
126274	123942	11112D	PARTICIPANT	\N	PRESENT	0
126275	123942	01057W	PARTICIPANT	\N	PRESENT	0
126292	126291	04086Q	PARTICIPANT	\N	PRESENT	0
126277	123942	14051J	PARTICIPANT	\N	PRESENT	0
126278	123942	14063N	PARTICIPANT	\N	PRESENT	0
126279	123942	11101A	PARTICIPANT	\N	PRESENT	0
126280	123942	95067Q	PARTICIPANT	\N	PRESENT	0
126281	123942	11044J	PARTICIPANT	\N	PRESENT	0
126282	123942	11049P	PARTICIPANT	\N	PRESENT	0
126283	123942	04045F	PARTICIPANT	\N	PRESENT	0
126284	123942	11098Y	PARTICIPANT	\N	PRESENT	0
126450	125634	11089X	PARTICIPANT	\N	PRESENT	0
126451	125999	08055A	PARTICIPANT	\N	PRESENT	0
126452	125999	11084S	PARTICIPANT	\N	PRESENT	0
126453	125999	14085U	PARTICIPANT	\N	PRESENT	0
126454	125999	98050T	PARTICIPANT	\N	PRESENT	0
126455	125999	14065Q	PARTICIPANT	\N	PRESENT	0
126456	125999	11015D	PARTICIPANT	\N	PRESENT	0
126457	125999	11105E	PARTICIPANT	\N	PRESENT	0
126458	125999	14237S	PARTICIPANT	\N	PRESENT	0
126459	125999	08068F	PARTICIPANT	\N	PRESENT	0
126460	125999	08012N	PARTICIPANT	\N	PRESENT	0
126461	125999	14093U	PARTICIPANT	\N	PRESENT	0
126462	125999	11036J	PARTICIPANT	\N	PRESENT	0
126463	125999	14069U	PARTICIPANT	\N	PRESENT	0
126464	125999	08058D	PARTICIPANT	\N	PRESENT	0
126465	125999	04061F	PARTICIPANT	\N	PRESENT	0
126466	125999	83042R	PARTICIPANT	\N	PRESENT	0
126467	125999	04045F	PARTICIPANT	\N	PRESENT	0
126468	125999	11046L	PARTICIPANT	\N	PRESENT	0
126469	125999	14225N	PARTICIPANT	\N	PRESENT	0
126470	125999	08014Q	PARTICIPANT	\N	PRESENT	0
126471	125999	11095V	PARTICIPANT	\N	PRESENT	0
126472	125999	11043H	PARTICIPANT	\N	PRESENT	0
126473	125999	14001X	PARTICIPANT	\N	PRESENT	0
126474	125999	11054L	PARTICIPANT	\N	PRESENT	0
126475	125999	83047W	PARTICIPANT	\N	PRESENT	0
126476	125999	01048V	PARTICIPANT	\N	PRESENT	0
126477	125999	11112D	PARTICIPANT	\N	PRESENT	0
126478	125999	95067Q	PARTICIPANT	\N	PRESENT	0
126482	125999	08035V	PARTICIPANT	\N	PRESENT	0
126480	125999	14037X	PARTICIPANT	\N	PRESENT	0
126481	125999	11088W	PARTICIPANT	\N	PRESENT	0
126483	125999	11014C	PARTICIPANT	\N	PRESENT	0
126484	125999	11031D	PARTICIPANT	\N	PRESENT	0
126485	125999	14271U	PARTICIPANT	\N	PRESENT	0
126486	125999	11056N	PARTICIPANT	\N	PRESENT	0
126487	125999	14257W	PARTICIPANT	\N	PRESENT	0
126488	125999	11029K	PARTICIPANT	\N	PRESENT	0
126489	125999	01014K	PARTICIPANT	\N	PRESENT	0
126490	125999	14097Y	PARTICIPANT	\N	PRESENT	0
126491	125999	04077P	PARTICIPANT	\N	PRESENT	0
126492	125999	04053F	PARTICIPANT	\N	PRESENT	0
126493	125999	01028R	PARTICIPANT	\N	PRESENT	0
126494	125999	11032E	PARTICIPANT	\N	PRESENT	0
126495	125999	08038Y	PARTICIPANT	\N	PRESENT	0
126496	125999	11081P	PARTICIPANT	\N	PRESENT	0
126497	125999	14119M	PARTICIPANT	\N	PRESENT	0
126498	125999	04059M	PARTICIPANT	\N	PRESENT	0
126499	125999	08024S	PARTICIPANT	\N	PRESENT	0
126500	125999	05008E	PARTICIPANT	\N	PRESENT	0
126501	125999	04071H	PARTICIPANT	\N	PRESENT	0
126502	125999	01031L	PARTICIPANT	\N	PRESENT	0
126503	125999	14207L	PARTICIPANT	\N	PRESENT	0
126504	125999	14133K	PARTICIPANT	\N	PRESENT	0
126505	125999	11059R	PARTICIPANT	\N	PRESENT	0
126506	125999	11107G	PARTICIPANT	\N	PRESENT	0
126507	125999	07024N	PARTICIPANT	\N	PRESENT	0
126508	125999	14281W	PARTICIPANT	\N	PRESENT	0
126509	125999	11064N	PARTICIPANT	\N	PRESENT	0
126510	125999	01034P	PARTICIPANT	\N	PRESENT	0
126511	125999	01060R	PARTICIPANT	\N	PRESENT	0
126512	125999	08009T	PARTICIPANT	\N	PRESENT	0
126513	125999	89017R	PARTICIPANT	\N	PRESENT	0
126514	125999	11053K	PARTICIPANT	\N	PRESENT	0
126515	125999	08056B	PARTICIPANT	\N	PRESENT	0
126516	125999	92044U	PARTICIPANT	\N	PRESENT	0
126517	125999	14030Q	PARTICIPANT	\N	PRESENT	0
126539	125999	04035D	PARTICIPANT	\N	PRESENT	0
126519	125999	04080J	PARTICIPANT	\N	PRESENT	0
126520	125999	14034U	PARTICIPANT	\N	PRESENT	0
126521	125999	14267Y	PARTICIPANT	\N	PRESENT	0
126522	125999	14205J	PARTICIPANT	\N	PRESENT	0
126523	125999	14042U	PARTICIPANT	\N	PRESENT	0
126524	125999	14219Q	PARTICIPANT	\N	PRESENT	0
126525	125999	11082Q	PARTICIPANT	\N	PRESENT	0
126526	125999	11093T	PARTICIPANT	\N	PRESENT	0
126527	125999	14083S	PARTICIPANT	\N	PRESENT	0
126528	125999	07029T	PARTICIPANT	\N	PRESENT	0
126529	125999	07004J	PARTICIPANT	\N	PRESENT	0
126530	125999	98042T	PARTICIPANT	\N	PRESENT	0
126531	125999	04089T	PARTICIPANT	\N	PRESENT	0
126532	125999	14073Q	PARTICIPANT	\N	PRESENT	0
126533	125999	04040A	PARTICIPANT	\N	PRESENT	0
126534	125999	14327T	PARTICIPANT	\N	PRESENT	0
126535	125999	04070G	PARTICIPANT	\N	PRESENT	0
126536	125999	01047U	PARTICIPANT	\N	PRESENT	0
126537	125999	08011M	PARTICIPANT	\N	PRESENT	0
126538	125999	14055N	PARTICIPANT	\N	PRESENT	0
126540	125999	01024M	PARTICIPANT	\N	PRESENT	0
126544	125999	05012A	PARTICIPANT	\N	PRESENT	0
126542	125999	11074Q	PARTICIPANT	\N	PRESENT	0
126543	125999	14179A	PARTICIPANT	\N	PRESENT	0
126545	125999	04079R	PARTICIPANT	\N	PRESENT	0
126546	125999	92039X	PARTICIPANT	\N	PRESENT	0
126547	125999	05004A	PARTICIPANT	\N	PRESENT	0
126548	122713	14195A	PARTICIPANT	\N	PRESENT	0
126549	122713	11112D	PARTICIPANT	\N	PRESENT	0
126550	122713	11063M	PARTICIPANT	\N	PRESENT	0
126552	126551	14028W	PARTICIPANT	\N	PRESENT	0
126553	125999	11026G	PARTICIPANT	\N	PRESENT	0
126554	125999	99002P	PARTICIPANT	\N	PRESENT	0
126573	126572	11036J	PARTICIPANT	\N	PRESENT	0
126575	125999	11076S	PARTICIPANT	\N	PRESENT	0
118163	117032	08039A	PARTICIPANT	\N	PRESENT	0
118164	117032	11070L	PARTICIPANT	\N	PRESENT	0
118165	117032	11026G	PARTICIPANT	\N	PRESENT	0
118166	117032	80027E	PARTICIPANT	\N	PRESENT	0
118167	117032	14227Q	PARTICIPANT	\N	PRESENT	0
118168	117032	14207L	PARTICIPANT	\N	PRESENT	0
118169	117032	14259Y	PARTICIPANT	\N	PRESENT	0
118170	117032	89017R	PARTICIPANT	\N	PRESENT	0
118171	117032	05008E	PARTICIPANT	\N	PRESENT	0
118172	117032	01048V	PARTICIPANT	\N	PRESENT	0
118173	117032	07032N	PARTICIPANT	\N	PRESENT	0
118174	117032	08062Y	PARTICIPANT	\N	PRESENT	0
118175	117032	14209N	PARTICIPANT	\N	PRESENT	0
118176	117032	14249W	PARTICIPANT	\N	PRESENT	0
118177	117032	11048N	PARTICIPANT	\N	PRESENT	0
118178	117032	14135M	PARTICIPANT	\N	PRESENT	0
118179	117032	11036J	PARTICIPANT	\N	PRESENT	0
118180	117033	01007L	PARTICIPANT	\N	PRESENT	0
118181	117033	04038G	PARTICIPANT	\N	PRESENT	0
118182	117033	01059Y	PARTICIPANT	\N	PRESENT	0
118183	117033	11034G	PARTICIPANT	\N	PRESENT	0
118184	117033	04050C	PARTICIPANT	\N	PRESENT	0
118185	117033	01022K	PARTICIPANT	\N	PRESENT	0
118186	117033	11026G	PARTICIPANT	\N	PRESENT	0
118187	117033	08017T	PARTICIPANT	\N	PRESENT	0
118188	117033	11042G	PARTICIPANT	\N	PRESENT	0
118190	117033	08052W	PARTICIPANT	\N	PRESENT	0
118191	117033	11036J	PARTICIPANT	\N	PRESENT	0
118195	117033	11029K	PARTICIPANT	\N	PRESENT	0
118196	117033	11012A	PARTICIPANT	\N	PRESENT	0
118197	117033	14261S	PARTICIPANT	\N	PRESENT	0
118198	117033	11070L	PARTICIPANT	\N	PRESENT	0
118199	117033	14083S	PARTICIPANT	\N	PRESENT	0
118200	117033	01024M	PARTICIPANT	\N	PRESENT	0
118201	117033	01057W	PARTICIPANT	\N	PRESENT	0
118202	117033	14059S	PARTICIPANT	\N	PRESENT	0
118203	117033	14061L	PARTICIPANT	\N	PRESENT	0
118204	117033	14041T	PARTICIPANT	\N	PRESENT	0
118205	117033	98018T	PARTICIPANT	\N	PRESENT	0
118206	117033	08018U	PARTICIPANT	\N	PRESENT	0
118207	117033	07029T	PARTICIPANT	\N	PRESENT	0
118208	117033	11033F	PARTICIPANT	\N	PRESENT	0
118209	117033	08062Y	PARTICIPANT	\N	PRESENT	0
118210	117033	14265W	PARTICIPANT	\N	PRESENT	0
118211	117033	11091R	PARTICIPANT	\N	PRESENT	0
118212	117033	08048B	PARTICIPANT	\N	PRESENT	0
118213	117033	08034U	PARTICIPANT	\N	PRESENT	0
118214	117033	01008M	PARTICIPANT	\N	PRESENT	0
118215	117033	97011G	PARTICIPANT	\N	PRESENT	0
118216	117033	04035D	PARTICIPANT	\N	PRESENT	0
118217	117033	95063L	PARTICIPANT	\N	PRESENT	0
118218	117033	14219Q	PARTICIPANT	\N	PRESENT	0
118219	117033	95049N	PARTICIPANT	\N	PRESENT	0
118220	117033	04085P	PARTICIPANT	\N	PRESENT	0
118221	117033	14235Q	PARTICIPANT	\N	PRESENT	0
118434	118417	95049N	PARTICIPANT	\N	PRESENT	0
118435	118417	08051V	PARTICIPANT	\N	PRESENT	0
118436	118417	07034Q	PARTICIPANT	\N	PRESENT	0
118437	118417	04074L	PARTICIPANT	\N	PRESENT	0
118438	118417	10015M	PARTICIPANT	\N	PRESENT	0
118439	118417	95063L	PARTICIPANT	\N	PRESENT	0
118440	118417	01028R	PARTICIPANT	\N	PRESENT	0
118441	118417	98035U	PARTICIPANT	\N	PRESENT	0
118442	118417	04056J	PARTICIPANT	\N	PRESENT	0
118443	118417	04044E	PARTICIPANT	\N	PRESENT	0
118444	118417	11037K	PARTICIPANT	\N	PRESENT	0
118445	118417	92045V	PARTICIPANT	\N	EXCUSE	0
118446	118417	95067Q	PARTICIPANT	\N	PRESENT	0
118447	118417	01047U	PARTICIPANT	\N	PRESENT	0
118452	118272	01015L	PARTICIPANT	\N	PRESENT	0
118853	117825	96003C	PARTICIPANT	\N	PRESENT	0
118854	118852	86034E	PARTICIPANT	\N	PRESENT	0
118855	118852	95049N	PARTICIPANT	\N	PRESENT	0
118856	118852	08051V	PARTICIPANT	\N	PRESENT	0
118857	118852	05008E	PARTICIPANT	\N	PRESENT	0
118858	118852	04085P	PARTICIPANT	\N	PRESENT	0
118859	118852	14273W	PARTICIPANT	\N	PRESENT	0
118860	118852	04088S	PARTICIPANT	\N	PRESENT	0
118861	118852	14033T	PARTICIPANT	\N	PRESENT	0
118862	118852	04036E	PARTICIPANT	\N	PRESENT	0
118863	118852	10006L	PARTICIPANT	\N	PRESENT	0
118864	118852	14265W	PARTICIPANT	\N	PRESENT	0
118865	118852	11097X	PARTICIPANT	\N	PRESENT	0
118866	118852	04053F	PARTICIPANT	\N	PRESENT	0
118867	118852	11090Q	PARTICIPANT	\N	PRESENT	0
118868	118852	14259Y	PARTICIPANT	\N	PRESENT	0
118869	118852	14030Q	PARTICIPANT	\N	PRESENT	0
118870	118852	11113E	PARTICIPANT	\N	PRESENT	0
118871	118852	07026Q	PARTICIPANT	\N	PRESENT	0
118872	118852	14079W	PARTICIPANT	\N	PRESENT	0
118873	118852	14071N	PARTICIPANT	\N	PRESENT	0
118874	118852	14059S	PARTICIPANT	\N	PRESENT	0
118875	118852	14195A	PARTICIPANT	\N	PRESENT	0
118876	118852	08069G	PARTICIPANT	\N	PRESENT	0
118877	118852	11080N	PARTICIPANT	\N	PRESENT	0
118878	118852	14327T	PARTICIPANT	\N	PRESENT	0
118879	118852	14041T	PARTICIPANT	\N	PRESENT	0
118880	118852	11083R	PARTICIPANT	\N	PRESENT	0
118881	118852	14269B	PARTICIPANT	\N	PRESENT	0
118882	118852	08044W	PARTICIPANT	\N	PRESENT	0
118883	118852	04074L	PARTICIPANT	\N	PRESENT	0
118884	118852	11048N	PARTICIPANT	\N	PRESENT	0
118885	118852	11091R	PARTICIPANT	\N	PRESENT	0
118886	118852	14213J	PARTICIPANT	\N	PRESENT	0
118887	118852	11025F	PARTICIPANT	\N	PRESENT	0
118888	118852	04081K	PARTICIPANT	\N	PRESENT	0
118889	118852	08043V	PARTICIPANT	\N	PRESENT	0
118890	118852	04034C	PARTICIPANT	\N	PRESENT	0
118891	118852	04057K	PARTICIPANT	\N	PRESENT	0
118892	118852	14179A	PARTICIPANT	\N	PRESENT	0
118893	118852	95062K	PARTICIPANT	\N	PRESENT	0
118894	118852	11089X	PARTICIPANT	\N	PRESENT	0
118895	118852	01028R	PARTICIPANT	\N	PRESENT	0
118896	118852	01015L	PARTICIPANT	\N	PRESENT	0
118897	118852	01047U	PARTICIPANT	\N	PRESENT	0
118898	118852	07004J	PARTICIPANT	\N	PRESENT	0
118899	118852	04086Q	PARTICIPANT	\N	PRESENT	0
118900	118852	14271U	PARTICIPANT	\N	PRESENT	0
118901	118852	14219Q	PARTICIPANT	\N	PRESENT	0
118902	118852	04067M	PARTICIPANT	\N	PRESENT	0
118903	118852	01044R	PARTICIPANT	\N	PRESENT	0
118904	118852	04043D	PARTICIPANT	\N	PRESENT	0
118905	118852	04035D	PARTICIPANT	\N	PRESENT	0
118906	118852	99004R	PARTICIPANT	\N	PRESENT	0
118907	118852	14261S	PARTICIPANT	\N	PRESENT	0
118908	118852	08031R	PARTICIPANT	\N	PRESENT	0
118909	118852	04071H	PARTICIPANT	\N	PRESENT	0
118910	118852	14038Y	PARTICIPANT	\N	PRESENT	0
118911	118852	14037X	PARTICIPANT	\N	PRESENT	0
118912	118852	08018U	PARTICIPANT	\N	PRESENT	0
118913	118852	11096W	PARTICIPANT	\N	PRESENT	0
118916	118852	11065P	PARTICIPANT	\N	PRESENT	0
118917	118852	92031P	PARTICIPANT	\N	PRESENT	0
118925	118922	01016M	PARTICIPANT	\N	PRESENT	0
119193	119192	14071N	PARTICIPANT	\N	PRESENT	0
119195	119194	14071N	PARTICIPANT	\N	PRESENT	0
120946	120453	08044W	PARTICIPANT	\N	EXCUSE	0
120973	120972	14237S	PARTICIPANT	\N	PRESENT	0
121693	121161	01027Q	PARTICIPANT	\N	EXCUSE	0
121782	121157	86034E	PARTICIPANT	\N	PRESENT	0
121780	97592	86034E	PARTICIPANT	\N	PRESENT	0
121781	97592	14187A	PARTICIPANT	\N	PRESENT	0
121783	121157	14187A	PARTICIPANT	\N	PRESENT	0
121784	121157	14179A	PARTICIPANT	\N	PRESENT	0
121785	121157	11100Y	PARTICIPANT	\N	PRESENT	0
121786	121157	14231L	PARTICIPANT	\N	PRESENT	0
121787	121157	07026Q	PARTICIPANT	\N	PRESENT	0
121788	121157	11098Y	PARTICIPANT	\N	PRESENT	0
121789	121157	14331P	PARTICIPANT	\N	PRESENT	0
121790	121157	11035H	PARTICIPANT	\N	PRESENT	0
121791	121157	14265W	PARTICIPANT	\N	PRESENT	0
121792	121157	14207L	PARTICIPANT	\N	PRESENT	0
121793	121157	92018S	PARTICIPANT	\N	PRESENT	0
121794	121157	11056N	PARTICIPANT	\N	PRESENT	0
121795	121157	01013J	PARTICIPANT	\N	PRESENT	0
121796	121157	14263U	PARTICIPANT	\N	PRESENT	0
121797	121157	98053W	PARTICIPANT	\N	PRESENT	0
121798	121157	12041X	PARTICIPANT	\N	PRESENT	0
121799	121157	08014Q	PARTICIPANT	\N	PRESENT	0
121800	121157	14085U	PARTICIPANT	\N	PRESENT	0
121801	121157	11029K	PARTICIPANT	\N	PRESENT	0
121802	121157	08031R	PARTICIPANT	\N	PRESENT	0
121803	121157	95049N	PARTICIPANT	\N	PRESENT	0
121804	121157	04086Q	PARTICIPANT	\N	PRESENT	0
121805	121157	04088S	PARTICIPANT	\N	PRESENT	0
121806	121157	04041B	PARTICIPANT	\N	PRESENT	0
121807	121157	14030Q	PARTICIPANT	\N	PRESENT	0
120865	120864	01031L	PRESIDENT	0	PRESENT	0
120866	120864	11040E	PARTICIPANT	\N	PRESENT	0
120867	120864	08014Q	PARTICIPANT	\N	PRESENT	0
120868	120864	14083S	PARTICIPANT	\N	PRESENT	0
120869	120864	11053K	PARTICIPANT	\N	PRESENT	0
120870	120864	14085U	PARTICIPANT	\N	PRESENT	0
120871	120864	04086Q	PARTICIPANT	\N	PRESENT	0
120872	120864	04055H	PARTICIPANT	\N	PRESENT	0
120873	120864	11070L	PARTICIPANT	\N	PRESENT	0
120875	120864	11042G	PARTICIPANT	\N	PRESENT	0
120876	120864	11088W	PARTICIPANT	\N	PRESENT	0
120877	120864	14327T	PARTICIPANT	\N	PRESENT	0
120878	120864	08022Q	PARTICIPANT	\N	PRESENT	0
120879	120864	01027Q	PARTICIPANT	\N	PRESENT	0
120880	120864	98053W	PARTICIPANT	\N	EXCUSE	0
120881	120864	11083R	PARTICIPANT	\N	PRESENT	0
120882	120864	11048N	PARTICIPANT	\N	PRESENT	0
120883	120864	04061F	PARTICIPANT	\N	PRESENT	0
120884	120864	14159V	PARTICIPANT	\N	PRESENT	0
120885	120864	07029T	PARTICIPANT	\N	PRESENT	0
120886	120864	01048V	PARTICIPANT	\N	PRESENT	0
120887	120864	98046X	PARTICIPANT	\N	PRESENT	0
120888	120864	08011M	PARTICIPANT	\N	PRESENT	0
120889	120864	08061X	PARTICIPANT	\N	EXCUSE	0
120890	120864	01016M	PARTICIPANT	\N	PRESENT	0
120891	120864	14225N	PARTICIPANT	\N	PRESENT	0
120893	120864	11057P	PARTICIPANT	\N	PRESENT	0
120894	120864	04034C	PARTICIPANT	\N	PRESENT	0
123553	123540	08056B	PARTICIPANT	\N	EXCUSE	0
123695	123694	11044J	PARTICIPANT	\N	PRESENT	0
123696	123694	01034P	PARTICIPANT	\N	PRESENT	0
123697	123694	11093T	PARTICIPANT	\N	PRESENT	0
123698	123694	08052W	PARTICIPANT	\N	PRESENT	0
123945	120697	11054L	PARTICIPANT	\N	EXCUSE	0
124019	124018	01031L	PARTICIPANT	\N	PRESENT	0
124025	124024	96004D	PRESIDENT	0	PRESENT	0
124027	124024	04040A	PARTICIPANT	\N	PRESENT	0
124028	124024	11040E	PARTICIPANT	\N	PRESENT	0
124029	124024	04042C	PARTICIPANT	\N	PRESENT	0
124030	124024	11083R	PARTICIPANT	\N	PRESENT	0
124031	124024	07024N	PARTICIPANT	\N	PRESENT	0
124032	124024	14014Q	PARTICIPANT	\N	PRESENT	0
124035	124024	14097Y	PARTICIPANT	\N	PRESENT	0
124037	124024	04061F	PARTICIPANT	\N	PRESENT	0
124039	124024	14073Q	PARTICIPANT	\N	PRESENT	0
124040	124024	14001X	PARTICIPANT	\N	PRESENT	0
124041	124024	04057K	PARTICIPANT	\N	PRESENT	0
124042	124024	04080J	PARTICIPANT	\N	PRESENT	0
124043	124024	95059Q	PRESIDENT	1	PRESENT	0
124044	124024	98035U	PARTICIPANT	\N	PRESENT	0
124045	124024	04034C	PARTICIPANT	\N	PRESENT	0
124050	124049	14065Q	PARTICIPANT	\N	PRESENT	0
124051	124049	05008E	PARTICIPANT	\N	PRESENT	0
124711	124156	14259Y	PARTICIPANT	\N	PRESENT	0
124712	124156	92045V	PARTICIPANT	\N	PRESENT	0
124713	124156	14034U	PARTICIPANT	\N	PRESENT	0
124714	124156	01027Q	PARTICIPANT	\N	PRESENT	0
124715	124156	11026G	PARTICIPANT	\N	PRESENT	0
124774	121721	14030Q	PARTICIPANT	\N	PRESENT	0
124775	124054	14030Q	PARTICIPANT	\N	PRESENT	0
124777	124776	14253S	PARTICIPANT	\N	PRESENT	0
124778	124776	14157T	PARTICIPANT	\N	PRESENT	0
124780	124779	14253S	PARTICIPANT	\N	PRESENT	0
124781	124779	14157T	PARTICIPANT	\N	PRESENT	0
124784	124783	14157T	PARTICIPANT	\N	PRESENT	0
124785	124783	14253S	PARTICIPANT	\N	PRESENT	0
124786	124782	04054G	PARTICIPANT	\N	PRESENT	0
124787	124782	08058D	PARTICIPANT	\N	PRESENT	0
124788	124782	04042C	PRESIDENT	0	PRESENT	0
124789	124782	98029W	PARTICIPANT	\N	PRESENT	0
124790	124782	98018T	PARTICIPANT	\N	PRESENT	0
124791	124782	92018S	PARTICIPANT	\N	PRESENT	0
124792	124782	95030B	PRESIDENT	1	PRESENT	0
124793	124782	95031C	PARTICIPANT	\N	PRESENT	0
124709	124156	10006L	PARTICIPANT	\N	PRESENT	0
124710	124156	14213J	PARTICIPANT	\N	PRESENT	0
124794	124782	04035D	PARTICIPANT	\N	PRESENT	0
124795	124782	07024N	PARTICIPANT	\N	EXCUSE	0
124796	124782	14014Q	PARTICIPANT	\N	PRESENT	0
124797	124782	14097Y	PARTICIPANT	\N	PRESENT	0
124798	124782	92031P	PARTICIPANT	\N	PRESENT	0
124799	124782	14251Q	PARTICIPANT	\N	PRESENT	0
124800	124782	08047A	PARTICIPANT	\N	EXCUSE	0
124801	124782	14028W	PARTICIPANT	\N	PRESENT	0
124803	124782	98021N	PARTICIPANT	\N	PRESENT	0
124804	124782	11054L	PARTICIPANT	\N	PRESENT	0
124805	124782	01056V	PARTICIPANT	\N	PRESENT	0
124806	124782	04057K	PARTICIPANT	\N	PRESENT	0
124807	124782	14073Q	PARTICIPANT	\N	PRESENT	0
124808	124782	14026U	PARTICIPANT	\N	PRESENT	0
124809	124782	14135M	PARTICIPANT	\N	PRESENT	0
124810	124782	14089Y	PARTICIPANT	\N	PRESENT	0
124811	124782	14249W	PARTICIPANT	\N	PRESENT	0
124812	124782	11083R	PARTICIPANT	\N	PRESENT	0
124813	124782	01016M	PARTICIPANT	\N	PRESENT	0
124814	124782	11026G	PARTICIPANT	\N	PRESENT	0
124815	124782	98046X	PARTICIPANT	\N	PRESENT	0
124817	124816	14331P	PARTICIPANT	\N	PRESENT	0
124818	124782	11100Y	PARTICIPANT	\N	PRESENT	0
124819	124782	11111C	PARTICIPANT	\N	PRESENT	0
124820	124782	08028W	PARTICIPANT	\N	PRESENT	0
124821	124782	11094U	PARTICIPANT	\N	PRESENT	0
124822	124782	01008M	PARTICIPANT	\N	PRESENT	0
124823	124782	04048J	PARTICIPANT	\N	PRESENT	0
124824	124782	14257W	PARTICIPANT	\N	PRESENT	0
124825	124782	08068F	PARTICIPANT	\N	PRESENT	0
124826	124782	11066Q	PARTICIPANT	\N	PRESENT	0
124827	124782	80013X	PARTICIPANT	\N	PRESENT	0
124828	124782	11036J	PARTICIPANT	\N	PRESENT	0
124829	124782	11077T	PARTICIPANT	\N	PRESENT	0
124830	124782	14207L	PARTICIPANT	\N	PRESENT	0
124831	124782	14197C	PARTICIPANT	\N	PRESENT	0
124832	124782	08038Y	PARTICIPANT	\N	PRESENT	0
124833	124782	14081Q	PARTICIPANT	\N	PRESENT	0
124834	124782	14033T	PARTICIPANT	\N	PRESENT	0
124835	124782	14255U	PARTICIPANT	\N	PRESENT	0
124836	124782	08055A	PARTICIPANT	\N	PRESENT	0
124837	124782	11089X	PARTICIPANT	\N	PRESENT	0
124838	124782	11107G	PARTICIPANT	\N	PRESENT	0
124839	124782	01027Q	PARTICIPANT	\N	PRESENT	0
124840	124782	08017T	PARTICIPANT	\N	PRESENT	0
124841	124782	08041T	PARTICIPANT	\N	PRESENT	0
124842	124782	08060W	PARTICIPANT	\N	PRESENT	0
124843	124782	14269B	PARTICIPANT	\N	PRESENT	0
124844	124782	14159V	PARTICIPANT	\N	PRESENT	0
124845	124782	14107H	PARTICIPANT	\N	PRESENT	0
124846	124782	14271U	PARTICIPANT	\N	PRESENT	0
124847	124782	14281W	PARTICIPANT	\N	PRESENT	0
124848	124782	11056N	PARTICIPANT	\N	PRESENT	0
124850	124849	11082Q	PARTICIPANT	\N	PRESENT	0
124852	124851	11082Q	PARTICIPANT	\N	PRESENT	0
124857	124855	11082Q	PARTICIPANT	\N	PRESENT	0
124861	124860	04054G	PARTICIPANT	\N	PRESENT	0
124862	124860	96004D	PARTICIPANT	\N	EXCUSE	0
124863	124860	14089Y	PARTICIPANT	\N	PRESENT	0
124864	124860	90003B	PARTICIPANT	\N	EXCUSE	0
124865	124860	11035H	PARTICIPANT	\N	PRESENT	0
124866	124860	14249W	PARTICIPANT	\N	PRESENT	0
124867	124860	95030B	PRESIDENT	0	PRESENT	0
124868	124860	04035D	PARTICIPANT	\N	PRESENT	0
124869	124860	11083R	PARTICIPANT	\N	PRESENT	0
124870	124860	14026U	PARTICIPANT	\N	PRESENT	0
124871	124860	08044W	PARTICIPANT	\N	EXCUSE	0
124872	124860	14097Y	PARTICIPANT	\N	PRESENT	0
124873	124860	14073Q	PARTICIPANT	\N	PRESENT	0
124874	124860	11026G	PARTICIPANT	\N	PRESENT	0
124875	124860	98046X	PARTICIPANT	\N	PRESENT	0
124876	124860	04057K	PARTICIPANT	\N	PRESENT	0
124877	124860	14135M	PARTICIPANT	\N	PRESENT	0
124878	124860	01016M	PARTICIPANT	\N	PRESENT	0
124879	124860	04045F	PARTICIPANT	\N	PRESENT	0
124880	124860	14001X	PARTICIPANT	\N	EXCUSE	0
124881	124860	08058D	PARTICIPANT	\N	PRESENT	0
124882	124860	04042C	PARTICIPANT	\N	PRESENT	0
124883	124860	98029W	PARTICIPANT	\N	PRESENT	0
124884	124860	98018T	PARTICIPANT	\N	PRESENT	0
124885	124860	92018S	PARTICIPANT	\N	PRESENT	0
124945	124944	14033T	PARTICIPANT	\N	PRESENT	0
111248	111212	14269B	PARTICIPANT	\N	PRESENT	0
111250	111249	14263U	PARTICIPANT	\N	PRESENT	0
111251	111249	14133K	PARTICIPANT	\N	PRESENT	0
111768	111714	08051V	PARTICIPANT	\N	PRESENT	0
111253	111249	04059M	PARTICIPANT	\N	PRESENT	0
112334	112333	92039X	PARTICIPANT	\N	PRESENT	0
111255	111249	01044R	PARTICIPANT	\N	PRESENT	0
111256	111249	08043V	PARTICIPANT	\N	PRESENT	0
111257	111249	14089Y	PARTICIPANT	\N	PRESENT	0
111258	111249	14105F	PARTICIPANT	\N	EXCUSE	0
111259	111249	11029K	PARTICIPANT	\N	PRESENT	0
111260	111249	95015C	PARTICIPANT	\N	PRESENT	0
111261	111249	92015P	PARTICIPANT	\N	PRESENT	0
111262	111249	08024S	PARTICIPANT	\N	PRESENT	0
112335	112333	98035U	PARTICIPANT	\N	PRESENT	0
111264	111249	14329V	PARTICIPANT	\N	PRESENT	0
111265	111249	14209N	PARTICIPANT	\N	PRESENT	0
111266	111249	14079W	PARTICIPANT	\N	EXCUSE	0
111267	111249	11091R	PARTICIPANT	\N	EXCUSE	0
111268	111249	87003B	PARTICIPANT	\N	PRESENT	0
111269	111249	98042T	PARTICIPANT	\N	PRESENT	0
111270	111249	14249W	PARTICIPANT	\N	PRESENT	0
111271	111249	01041N	PARTICIPANT	\N	PRESENT	0
111272	111249	01025N	PARTICIPANT	\N	PRESENT	0
111273	111249	01037S	PARTICIPANT	\N	PRESENT	0
111274	111249	89029V	PARTICIPANT	\N	EXCUSE	0
111275	111249	08035V	PARTICIPANT	\N	PRESENT	0
111276	111249	11089X	PARTICIPANT	\N	PRESENT	0
111277	111249	07026Q	PARTICIPANT	\N	PRESENT	0
111278	111249	14123H	PARTICIPANT	\N	PRESENT	0
111279	111249	14179A	PARTICIPANT	\N	PRESENT	0
111280	111249	04041B	PARTICIPANT	\N	EXCUSE	0
111281	111249	14241N	PARTICIPANT	\N	PRESENT	0
111282	111249	14061L	PARTICIPANT	\N	PRESENT	0
111283	111249	14073Q	PARTICIPANT	\N	PRESENT	0
111284	111249	08031R	PARTICIPANT	\N	EXCUSE	0
112337	112336	04070G	PARTICIPANT	\N	PRESENT	0
111286	111249	08039A	PARTICIPANT	\N	PRESENT	0
112338	112336	11027H	PARTICIPANT	\N	PRESENT	0
111288	111249	14059S	PARTICIPANT	\N	PRESENT	0
111289	111249	08012N	PARTICIPANT	\N	PRESENT	0
112339	112336	04040A	PARTICIPANT	\N	PRESENT	0
111291	111249	11104D	PARTICIPANT	\N	PRESENT	0
111292	111249	14063N	PARTICIPANT	\N	PRESENT	0
111293	111249	04057K	PARTICIPANT	\N	PRESENT	0
111294	111249	11014C	PARTICIPANT	\N	PRESENT	0
111295	111249	14109K	PARTICIPANT	\N	PRESENT	0
111296	111249	04070G	PRESIDENT	0	PRESENT	0
111297	111249	92040Q	PARTICIPANT	\N	PRESENT	0
111298	111249	14191V	PARTICIPANT	\N	EXCUSE	0
111299	111249	83047W	PARTICIPANT	\N	PRESENT	0
111300	111249	14235Q	PARTICIPANT	\N	PRESENT	0
111301	111249	14055N	PARTICIPANT	\N	PRESENT	0
112340	112336	04036E	PARTICIPANT	\N	PRESENT	0
111303	111249	14229S	PARTICIPANT	\N	PRESENT	0
111304	111249	11043H	PARTICIPANT	\N	PRESENT	0
111305	111249	11071M	PARTICIPANT	\N	PRESENT	0
111306	111249	11011M	PARTICIPANT	\N	EXCUSE	0
112341	112336	14073Q	PARTICIPANT	\N	PRESENT	0
112373	112372	01008M	PARTICIPANT	\N	PRESENT	0
112433	112432	11036J	PARTICIPANT	\N	PRESENT	0
112434	112432	01044R	PARTICIPANT	\N	PRESENT	0
112435	112432	14013P	PARTICIPANT	\N	PRESENT	0
112436	112432	11029K	PARTICIPANT	\N	PRESENT	0
112437	112432	14038Y	PARTICIPANT	\N	PRESENT	0
112438	112432	80013X	PARTICIPANT	\N	PRESENT	0
112442	112432	14031R	PARTICIPANT	\N	PRESENT	0
112440	112432	14197C	PARTICIPANT	\N	PRESENT	0
112441	112432	14219Q	PARTICIPANT	\N	PRESENT	0
112443	112432	14273W	PARTICIPANT	\N	PRESENT	0
112444	112432	04057K	PARTICIPANT	\N	PRESENT	0
112445	112432	14265W	PARTICIPANT	\N	PRESENT	0
112446	112432	01016M	PARTICIPANT	\N	PRESENT	0
112447	112432	14107H	PARTICIPANT	\N	PRESENT	0
112448	112432	08049C	PARTICIPANT	\N	PRESENT	0
112449	112432	14030Q	PARTICIPANT	\N	EXCUSE	0
112450	112432	92039X	PARTICIPANT	\N	EXCUSE	0
112454	99613	01022K	PARTICIPANT	\N	EXCUSE	0
112465	99613	96003C	PARTICIPANT	\N	EXCUSE	0
112467	99613	11054L	PARTICIPANT	\N	EXCUSE	0
112468	99613	96004D	PARTICIPANT	\N	EXCUSE	0
112469	99613	98005N	PARTICIPANT	\N	EXCUSE	0
112470	99613	11072N	PARTICIPANT	\N	EXCUSE	0
112471	99613	14017T	PARTICIPANT	\N	EXCUSE	0
112474	99613	14053L	PARTICIPANT	\N	EXCUSE	0
112476	99613	14259Y	PARTICIPANT	\N	EXCUSE	0
112492	99613	04094Q	PARTICIPANT	\N	EXCUSE	0
112697	112696	11100Y	PARTICIPANT	\N	PRESENT	0
112698	112696	98050T	PARTICIPANT	\N	PRESENT	0
112700	112699	98050T	PARTICIPANT	\N	PRESENT	0
112701	99613	11025F	PARTICIPANT	\N	EXCUSE	0
112712	99613	11010L	PARTICIPANT	\N	EXCUSE	0
112736	103936	80013X	PARTICIPANT	\N	PRESENT	0
113226	99613	14275Y	PARTICIPANT	\N	EXCUSE	0
115015	99613	11020A	PARTICIPANT	\N	EXCUSE	0
115016	99613	14033T	PARTICIPANT	\N	EXCUSE	0
115017	99613	14097Y	PARTICIPANT	\N	PRESENT	0
115018	99613	14039A	PARTICIPANT	\N	PRESENT	0
115019	99613	08019V	PRESIDENT	0	PRESENT	0
115020	99613	04095R	PARTICIPANT	\N	PRESENT	0
115021	99613	04043D	PARTICIPANT	\N	PRESENT	0
115022	99613	95062K	PARTICIPANT	\N	PRESENT	0
115714	115713	08017T	PARTICIPANT	\N	PRESENT	0
115715	115713	14053L	PARTICIPANT	\N	PRESENT	0
115716	115713	14175V	PARTICIPANT	\N	PRESENT	0
115717	115713	11083R	PARTICIPANT	\N	PRESENT	0
115718	115713	08019V	PARTICIPANT	\N	PRESENT	0
115719	115713	14085U	PARTICIPANT	\N	PRESENT	0
115720	115713	04088S	PARTICIPANT	\N	PRESENT	0
115721	115713	08014Q	PARTICIPANT	\N	PRESENT	0
115773	115772	01031L	PARTICIPANT	\N	PRESENT	0
115774	115772	08052W	PARTICIPANT	\N	PRESENT	0
115775	115772	14157T	PARTICIPANT	\N	PRESENT	0
115776	115772	11107G	PARTICIPANT	\N	PRESENT	0
115793	115792	01016M	PARTICIPANT	\N	PRESENT	0
115797	115796	14199E	PARTICIPANT	\N	PRESENT	0
115799	115798	14199E	PARTICIPANT	\N	PRESENT	0
116294	116293	11036J	PARTICIPANT	\N	PRESENT	0
116295	116293	01044R	PARTICIPANT	\N	PRESENT	0
116296	116293	14219Q	PARTICIPANT	\N	PRESENT	0
116297	116293	14107H	PARTICIPANT	\N	PRESENT	0
116298	116293	14093U	PARTICIPANT	\N	EXCUSE	0
116299	116293	14030Q	PARTICIPANT	\N	EXCUSE	0
116300	116293	14013P	PARTICIPANT	\N	EXCUSE	0
116301	116293	14038Y	PARTICIPANT	\N	EXCUSE	0
116302	116293	80013X	PARTICIPANT	\N	EXCUSE	0
116303	116293	01015L	PARTICIPANT	\N	EXCUSE	0
116304	116293	14197C	PARTICIPANT	\N	EXCUSE	0
116306	116293	14031R	PARTICIPANT	\N	EXCUSE	0
116307	116293	14265W	PARTICIPANT	\N	EXCUSE	0
116308	116293	14237S	PARTICIPANT	\N	EXCUSE	0
116310	116293	01056V	PARTICIPANT	\N	EXCUSE	0
116311	116293	08049C	PARTICIPANT	\N	EXCUSE	0
116313	116293	04043D	PARTICIPANT	\N	EXCUSE	0
117114	117113	11039M	PARTICIPANT	\N	PRESENT	0
117115	117113	98042T	PARTICIPANT	\N	PRESENT	0
117298	117297	14239U	PARTICIPANT	\N	PRESENT	0
117301	117297	04053F	PARTICIPANT	\N	PRESENT	0
117302	117297	14255U	PARTICIPANT	\N	EXCUSE	0
117304	117297	00003C	PARTICIPANT	\N	EXCUSE	0
117305	117297	14053L	PARTICIPANT	\N	PRESENT	0
117306	117297	11103C	PARTICIPANT	\N	PRESENT	0
117308	117297	14195A	PARTICIPANT	\N	PRESENT	0
117309	117297	14267Y	PARTICIPANT	\N	PRESENT	0
117311	117297	11031D	PARTICIPANT	\N	PRESENT	0
117312	117297	08052W	PARTICIPANT	\N	PRESENT	0
117313	117297	01059Y	PARTICIPANT	\N	PRESENT	0
117314	117297	04081K	PARTICIPANT	\N	PRESENT	0
117315	117297	98024R	PARTICIPANT	\N	PRESENT	0
121808	121157	14223L	PARTICIPANT	\N	PRESENT	0
121809	121157	98021N	PARTICIPANT	\N	PRESENT	0
121810	121157	86044G	PARTICIPANT	\N	PRESENT	0
121811	121157	01015L	PARTICIPANT	\N	PRESENT	0
121812	121157	11104D	PARTICIPANT	\N	PRESENT	0
121813	121157	04054G	PARTICIPANT	\N	PRESENT	0
121814	121157	11040E	PARTICIPANT	\N	PRESENT	0
121815	121157	08041T	PARTICIPANT	\N	PRESENT	0
121816	121157	04097T	PARTICIPANT	\N	PRESENT	0
121817	121157	11011M	PARTICIPANT	\N	PRESENT	0
121818	121157	14033T	PARTICIPANT	\N	PRESENT	0
121819	121157	08028W	PARTICIPANT	\N	PRESENT	0
121820	121157	14041T	PARTICIPANT	\N	PRESENT	0
121821	121157	10015M	PARTICIPANT	\N	PRESENT	0
121822	121157	14235Q	PARTICIPANT	\N	PRESENT	0
121823	121157	01031L	PARTICIPANT	\N	PRESENT	0
121824	121157	01028R	PARTICIPANT	\N	PRESENT	0
121825	121157	04050C	PARTICIPANT	\N	PRESENT	0
121826	121157	01059Y	PARTICIPANT	\N	PRESENT	0
121827	121157	11034G	PARTICIPANT	\N	PRESENT	0
121828	121157	11039M	PARTICIPANT	\N	PRESENT	0
121829	121157	95062K	PARTICIPANT	\N	PRESENT	0
121830	121157	95015C	PARTICIPANT	\N	PRESENT	0
121831	121157	08060W	PARTICIPANT	\N	PRESENT	0
121832	121157	14089Y	PARTICIPANT	\N	PRESENT	0
121833	121157	04043D	PARTICIPANT	\N	PRESENT	0
121834	121157	11066Q	PARTICIPANT	\N	PRESENT	0
121835	121157	14271U	PARTICIPANT	\N	PRESENT	0
121836	121157	11099A	PARTICIPANT	\N	PRESENT	0
121837	121157	01027Q	PARTICIPANT	\N	PRESENT	0
121838	121157	14069U	PARTICIPANT	\N	PRESENT	0
121839	121157	13002U	PARTICIPANT	\N	PRESENT	0
121840	121157	14229S	PARTICIPANT	\N	PRESENT	0
121841	121157	14063N	PARTICIPANT	\N	PRESENT	0
121842	121157	14055N	PARTICIPANT	\N	PRESENT	0
121843	121157	14247U	PARTICIPANT	\N	PRESENT	0
121844	121157	08017T	PARTICIPANT	\N	PRESENT	0
121845	121157	11036J	PARTICIPANT	\N	PRESENT	0
121846	121157	11048N	PARTICIPANT	\N	PRESENT	0
121847	121157	01037S	PARTICIPANT	\N	PRESENT	0
121848	121157	11068S	PARTICIPANT	\N	PRESENT	0
121849	121157	01044R	PARTICIPANT	\N	PRESENT	0
121850	121157	11042G	PARTICIPANT	\N	PRESENT	0
121851	121157	14109K	PARTICIPANT	\N	PRESENT	0
121852	121157	95037J	PARTICIPANT	\N	PRESENT	0
121853	121157	80027E	PARTICIPANT	\N	PRESENT	0
121854	121157	04033B	PARTICIPANT	\N	PRESENT	0
121855	121157	14097Y	PARTICIPANT	\N	PRESENT	0
121856	121157	14079W	PARTICIPANT	\N	PRESENT	0
121857	121157	04059M	PARTICIPANT	\N	PRESENT	0
121858	121157	08043V	PARTICIPANT	\N	PRESENT	0
121859	121157	95031C	PARTICIPANT	\N	PRESENT	0
121860	121157	11089X	PARTICIPANT	\N	PRESENT	0
121861	121157	11072N	PARTICIPANT	\N	PRESENT	0
121862	121157	14159V	PARTICIPANT	\N	PRESENT	0
121863	121157	08024S	PARTICIPANT	\N	PRESENT	0
121864	121157	14261S	PARTICIPANT	\N	PRESENT	0
121865	121157	11055M	PARTICIPANT	\N	PRESENT	0
121866	121157	04067M	PARTICIPANT	\N	PRESENT	0
121867	121157	11015D	PARTICIPANT	\N	PRESENT	0
121868	121157	11109J	PARTICIPANT	\N	PRESENT	0
121869	121157	14253S	PARTICIPANT	\N	PRESENT	0
121870	121157	14031R	PARTICIPANT	\N	PRESENT	0
121871	121157	11046L	PARTICIPANT	\N	PRESENT	0
121872	121157	14195A	PARTICIPANT	\N	PRESENT	0
121873	121157	08015R	PARTICIPANT	\N	PRESENT	0
121874	121157	14213J	PARTICIPANT	\N	PRESENT	0
121875	121157	11074Q	PARTICIPANT	\N	PRESENT	0
121876	121157	08034U	PARTICIPANT	\N	PRESENT	0
121877	121157	14111D	PARTICIPANT	\N	PRESENT	0
121878	121157	10006L	PARTICIPANT	\N	PRESENT	0
121879	121157	11111C	PARTICIPANT	\N	PRESENT	0
121880	121157	14061L	PARTICIPANT	\N	PRESENT	0
121881	121157	97011G	PARTICIPANT	\N	PRESENT	0
121882	121157	04089T	PARTICIPANT	\N	PRESENT	0
121883	121157	01024M	PARTICIPANT	\N	PRESENT	0
121884	121157	14026U	PARTICIPANT	\N	PRESENT	0
121885	121157	04081K	PARTICIPANT	\N	PRESENT	0
121886	121157	01043Q	PARTICIPANT	\N	PRESENT	0
121887	121157	14105F	PARTICIPANT	\N	PRESENT	0
121888	121157	14215L	PARTICIPANT	\N	PRESENT	0
121889	121157	14327T	PARTICIPANT	\N	PRESENT	0
121890	121157	04085P	PARTICIPANT	\N	PRESENT	0
121891	121157	14013P	PARTICIPANT	\N	PRESENT	0
121892	121157	14087W	PARTICIPANT	\N	PRESENT	0
121893	121157	01025N	PARTICIPANT	\N	PRESENT	0
121894	121157	14119M	PARTICIPANT	\N	PRESENT	0
121895	121157	01056V	PARTICIPANT	\N	PRESENT	0
121896	121157	11043H	PARTICIPANT	\N	PRESENT	0
121897	121157	14221J	PARTICIPANT	\N	PRESENT	0
121898	121157	14225N	PARTICIPANT	\N	PRESENT	0
121899	121157	11061K	PARTICIPANT	\N	PRESENT	0
121900	121157	14281W	PARTICIPANT	\N	PRESENT	0
121901	121157	11054L	PARTICIPANT	\N	PRESENT	0
121902	121157	95063L	PARTICIPANT	\N	PRESENT	0
121903	121157	14269B	PARTICIPANT	\N	PRESENT	0
121904	121157	14073Q	PARTICIPANT	\N	PRESENT	0
121905	121157	14249W	PARTICIPANT	\N	PRESENT	0
121906	121157	08051V	PARTICIPANT	\N	PRESENT	0
121907	121157	11110B	PARTICIPANT	\N	PRESENT	0
121908	121157	11094U	PARTICIPANT	\N	PRESENT	0
121909	121157	12042Y	PARTICIPANT	\N	PRESENT	0
121910	121157	14014Q	PARTICIPANT	\N	PRESENT	0
121911	121157	08021P	PARTICIPANT	\N	PRESENT	0
121912	121157	14028W	PARTICIPANT	\N	PRESENT	0
121913	121157	14217N	PARTICIPANT	\N	PRESENT	0
121914	121157	08016S	PARTICIPANT	\N	PRESENT	0
121915	121157	11112D	PARTICIPANT	\N	PRESENT	0
121916	121157	14219Q	PARTICIPANT	\N	PRESENT	0
121917	121157	14267Y	PARTICIPANT	\N	PRESENT	0
121918	121157	14037X	PARTICIPANT	\N	PRESENT	0
121919	121157	14053L	PARTICIPANT	\N	PRESENT	0
121920	121157	08053X	PARTICIPANT	\N	PRESENT	0
121921	121157	87003B	PARTICIPANT	\N	PRESENT	0
121922	121157	04095R	PARTICIPANT	\N	PRESENT	0
121923	121157	14059S	PARTICIPANT	\N	PRESENT	0
121924	121157	04035D	PARTICIPANT	\N	PRESENT	0
121925	121157	04042C	PARTICIPANT	\N	PRESENT	0
121926	121157	11049P	PARTICIPANT	\N	PRESENT	0
121927	121157	11082Q	PARTICIPANT	\N	PRESENT	0
121928	121157	88008L	PARTICIPANT	\N	PRESENT	0
121966	121157	08012N	PARTICIPANT	\N	PRESENT	0
121967	121157	04055H	PARTICIPANT	\N	PRESENT	0
121968	121157	08062Y	PARTICIPANT	\N	PRESENT	0
121969	121157	11027H	PARTICIPANT	\N	PRESENT	0
121981	121157	01060R	PARTICIPANT	\N	PRESENT	0
121986	121157	99004R	PARTICIPANT	\N	PRESENT	0
121988	121157	01022K	PARTICIPANT	\N	PRESENT	0
121989	121157	14147R	PARTICIPANT	\N	PRESENT	0
121991	121990	11089X	PARTICIPANT	\N	PRESENT	0
121993	121157	14173T	PARTICIPANT	\N	PRESENT	0
121994	121157	08058D	PARTICIPANT	\N	PRESENT	0
121995	121157	08068F	PARTICIPANT	\N	PRESENT	0
121996	121157	14209N	PARTICIPANT	\N	PRESENT	0
121997	121157	14157T	PARTICIPANT	\N	PRESENT	0
121998	121157	07004J	PARTICIPANT	\N	PRESENT	0
121999	121157	11103C	PARTICIPANT	\N	PRESENT	0
122000	121157	14201E	PARTICIPANT	\N	PRESENT	0
122001	121157	01047U	PARTICIPANT	\N	PRESENT	0
122002	121157	01008M	PARTICIPANT	\N	PRESENT	0
122003	121157	14038Y	PARTICIPANT	\N	PRESENT	0
122004	121157	14121F	PARTICIPANT	\N	PRESENT	0
122005	121157	05012A	PARTICIPANT	\N	PRESENT	0
122006	121157	14259Y	PARTICIPANT	\N	PRESENT	0
122007	121157	04048J	PARTICIPANT	\N	PRESENT	0
122008	121157	98022P	PARTICIPANT	\N	PRESENT	0
122009	121157	14083S	PARTICIPANT	\N	PRESENT	0
122010	121157	08019V	PARTICIPANT	\N	PRESENT	0
122011	121157	98050T	PARTICIPANT	\N	PRESENT	0
122014	121157	77002U	PARTICIPANT	\N	PRESENT	0
122017	121157	11101A	PARTICIPANT	\N	PRESENT	0
122019	121157	14001X	PARTICIPANT	\N	PRESENT	0
122020	121157	11064N	PARTICIPANT	\N	PRESENT	0
122021	121157	08010L	PARTICIPANT	\N	PRESENT	0
122022	121157	11059R	PARTICIPANT	\N	PRESENT	0
122023	121157	01046T	PARTICIPANT	\N	PRESENT	0
122024	121157	80013X	PARTICIPANT	\N	PRESENT	0
122025	121157	14051J	PARTICIPANT	\N	PRESENT	0
122026	121157	11106F	PARTICIPANT	\N	PRESENT	0
122027	121157	04040A	PARTICIPANT	\N	PRESENT	0
122028	121157	14257W	PARTICIPANT	\N	PRESENT	0
124947	124946	14033T	PARTICIPANT	\N	PRESENT	0
124948	124860	95031C	PARTICIPANT	\N	PRESENT	0
124949	124860	14014Q	PARTICIPANT	\N	PRESENT	0
124950	124860	92031P	PARTICIPANT	\N	PRESENT	0
124951	124860	14251Q	PARTICIPANT	\N	PRESENT	0
124952	124860	14028W	PARTICIPANT	\N	PRESENT	0
124953	124860	98021N	PARTICIPANT	\N	PRESENT	0
124954	124860	11054L	PARTICIPANT	\N	PRESENT	0
124955	124860	01056V	PARTICIPANT	\N	PRESENT	0
124957	124956	14221J	PARTICIPANT	\N	PRESENT	0
124958	124860	01008M	PARTICIPANT	\N	PRESENT	0
124959	124860	11036J	PARTICIPANT	\N	PRESENT	0
124960	124860	08055A	PARTICIPANT	\N	PRESENT	0
124961	124860	08068F	PARTICIPANT	\N	PRESENT	0
124962	124860	14207L	PARTICIPANT	\N	PRESENT	0
124963	124860	14255U	PARTICIPANT	\N	PRESENT	0
124964	124860	11056N	PARTICIPANT	\N	PRESENT	0
124965	124860	08028W	PARTICIPANT	\N	PRESENT	0
124966	124860	80013X	PARTICIPANT	\N	PRESENT	0
124967	124860	08038Y	PARTICIPANT	\N	PRESENT	0
124968	124860	14033T	PARTICIPANT	\N	PRESENT	0
124969	124860	14081Q	PARTICIPANT	\N	PRESENT	0
124970	124860	08041T	PARTICIPANT	\N	PRESENT	0
124971	124860	11089X	PARTICIPANT	\N	PRESENT	0
124972	124860	11111C	PARTICIPANT	\N	PRESENT	0
124973	124860	11100Y	PARTICIPANT	\N	PRESENT	0
124974	124860	01043Q	PARTICIPANT	\N	PRESENT	0
124975	124860	11077T	PARTICIPANT	\N	PRESENT	0
124976	124860	14257W	PARTICIPANT	\N	PRESENT	0
124977	124860	04048J	PARTICIPANT	\N	PRESENT	0
124978	124860	14197C	PARTICIPANT	\N	PRESENT	0
124979	124860	11094U	PARTICIPANT	\N	PRESENT	0
124980	124860	11066Q	PARTICIPANT	\N	PRESENT	0
124981	124860	14269B	PARTICIPANT	\N	PRESENT	0
124983	124982	04043D	PARTICIPANT	\N	PRESENT	0
124984	124860	08060W	PARTICIPANT	\N	PRESENT	0
124985	124860	01027Q	PARTICIPANT	\N	PRESENT	0
124986	124860	14281W	PARTICIPANT	\N	PRESENT	0
124987	124860	11107G	PARTICIPANT	\N	PRESENT	0
124988	124860	14159V	PARTICIPANT	\N	PRESENT	0
124989	124860	08017T	PARTICIPANT	\N	PRESENT	0
124990	124860	14107H	PARTICIPANT	\N	PRESENT	0
124991	124860	14271U	PARTICIPANT	\N	PRESENT	0
124994	124993	04085P	PARTICIPANT	\N	PRESENT	0
124995	124993	05008E	PRESIDENT	0	PRESENT	0
124996	124993	11030C	PARTICIPANT	\N	PRESENT	0
124997	124993	11033F	PARTICIPANT	\N	PRESENT	0
124998	124993	14065Q	PARTICIPANT	\N	PRESENT	0
124999	124993	14069U	PARTICIPANT	\N	PRESENT	0
125000	124993	04047H	PARTICIPANT	\N	PRESENT	0
125001	124993	04038G	PARTICIPANT	\N	PRESENT	0
125002	124993	99002P	PARTICIPANT	\N	PRESENT	0
125003	124993	11056N	PARTICIPANT	\N	PRESENT	0
125004	124993	14259Y	PARTICIPANT	\N	PRESENT	0
125005	124993	11035H	PARTICIPANT	\N	PRESENT	0
125006	124993	14041T	PARTICIPANT	\N	PRESENT	0
125007	124993	11113E	PARTICIPANT	\N	PRESENT	0
125008	124993	01024M	PARTICIPANT	\N	PRESENT	0
125009	124993	14215L	PARTICIPANT	\N	PRESENT	0
125010	124993	11034G	PARTICIPANT	\N	PRESENT	0
125011	124993	08018U	PARTICIPANT	\N	PRESENT	0
125012	124993	01007L	PARTICIPANT	\N	PRESENT	0
125013	124993	11049P	PARTICIPANT	\N	PRESENT	0
125014	124993	08044W	PARTICIPANT	\N	EXCUSE	0
125015	124993	11084S	PARTICIPANT	\N	PRESENT	0
125016	124993	11026G	PARTICIPANT	\N	PRESENT	0
125017	124993	04079R	PARTICIPANT	\N	PRESENT	0
125018	124993	14111D	PARTICIPANT	\N	PRESENT	0
125019	124993	14001X	PARTICIPANT	\N	PRESENT	0
125020	124993	01060R	PARTICIPANT	\N	PRESENT	0
125021	124993	14147R	PARTICIPANT	\N	PRESENT	0
125023	124993	95049N	PARTICIPANT	\N	PRESENT	0
125024	124993	08051V	PARTICIPANT	\N	PRESENT	0
125025	124993	07034Q	PARTICIPANT	\N	PRESENT	0
125026	124993	04074L	PARTICIPANT	\N	PRESENT	0
125027	124993	10015M	PARTICIPANT	\N	PRESENT	0
125028	124993	95063L	PARTICIPANT	\N	PRESENT	0
125029	125022	14263U	PARTICIPANT	\N	EXCUSE	0
125095	124157	04081K	PARTICIPANT	\N	PRESENT	0
125096	124157	14187A	PARTICIPANT	\N	PRESENT	0
125032	125022	04059M	PARTICIPANT	\N	PRESENT	0
125033	125022	11039M	PARTICIPANT	\N	PRESENT	0
125034	125022	01044R	PARTICIPANT	\N	PRESENT	0
125097	124157	14231L	PARTICIPANT	\N	PRESENT	0
125036	125022	14089Y	PARTICIPANT	\N	PRESENT	0
125037	125022	14105F	PARTICIPANT	\N	PRESENT	0
125038	125022	11029K	PARTICIPANT	\N	PRESENT	0
125039	125022	95015C	PARTICIPANT	\N	PRESENT	0
125040	125022	92015P	PARTICIPANT	\N	PRESENT	0
125041	125022	08024S	PARTICIPANT	\N	PRESENT	0
125042	125022	14201E	PARTICIPANT	\N	PRESENT	0
125098	124157	11100Y	PARTICIPANT	\N	PRESENT	0
125157	124157	04086Q	PARTICIPANT	\N	PRESENT	0
125045	125022	14079W	PARTICIPANT	\N	PRESENT	0
125046	125022	11091R	PARTICIPANT	\N	PRESENT	0
125047	125022	87003B	PARTICIPANT	\N	PRESENT	0
125048	125022	98042T	PARTICIPANT	\N	PRESENT	0
125049	125022	14249W	PARTICIPANT	\N	PRESENT	0
125158	124157	11055M	PARTICIPANT	\N	PRESENT	0
125051	125022	01025N	PARTICIPANT	\N	PRESENT	0
125052	125022	01037S	PARTICIPANT	\N	EXCUSE	0
125053	125022	89029V	PARTICIPANT	\N	PRESENT	0
125054	125022	08035V	PARTICIPANT	\N	PRESENT	0
125055	125022	11089X	PARTICIPANT	\N	PRESENT	0
125056	125022	07026Q	PARTICIPANT	\N	PRESENT	0
125057	125022	14123H	PARTICIPANT	\N	PRESENT	0
125058	125022	14179A	PARTICIPANT	\N	PRESENT	0
125059	125022	04041B	PARTICIPANT	\N	PRESENT	0
125060	125022	14241N	PARTICIPANT	\N	PRESENT	0
125061	125022	14061L	PARTICIPANT	\N	PRESENT	0
125062	125022	14073Q	PARTICIPANT	\N	PRESENT	0
125063	125022	08031R	PARTICIPANT	\N	PRESENT	0
125159	124157	11011M	PARTICIPANT	\N	PRESENT	0
125065	125022	08039A	PARTICIPANT	\N	PRESENT	0
125066	125022	08017T	PARTICIPANT	\N	PRESENT	0
125067	125022	14059S	PARTICIPANT	\N	PRESENT	0
125068	125022	08012N	PARTICIPANT	\N	PRESENT	0
125069	125022	14103D	PARTICIPANT	\N	PRESENT	0
125070	125022	11104D	PARTICIPANT	\N	PRESENT	0
125071	125022	14063N	PARTICIPANT	\N	PRESENT	0
125072	125022	04057K	PARTICIPANT	\N	PRESENT	0
125073	125022	11014C	PARTICIPANT	\N	PRESENT	0
125074	125022	14109K	PARTICIPANT	\N	PRESENT	0
125075	125022	04070G	PRESIDENT	0	PRESENT	0
125076	125022	92040Q	PARTICIPANT	\N	PRESENT	0
125160	124157	13002U	PARTICIPANT	\N	PRESENT	0
125078	125022	83047W	PARTICIPANT	\N	PRESENT	0
125079	125022	14235Q	PARTICIPANT	\N	PRESENT	0
125080	125022	14055N	PARTICIPANT	\N	PRESENT	0
125081	125022	04033B	PARTICIPANT	\N	PRESENT	0
125161	124157	92015P	PARTICIPANT	\N	PRESENT	0
125083	125022	11043H	PARTICIPANT	\N	PRESENT	0
125084	125022	11071M	PARTICIPANT	\N	PRESENT	0
125085	125022	11011M	PARTICIPANT	\N	PRESENT	0
125086	124993	01019Q	PARTICIPANT	\N	PRESENT	0
125087	124993	01028R	PARTICIPANT	\N	PRESENT	0
125088	124993	98035U	PARTICIPANT	\N	PRESENT	0
125089	124993	04056J	PARTICIPANT	\N	PRESENT	0
125090	124993	04044E	PARTICIPANT	\N	PRESENT	0
125091	124993	11037K	PARTICIPANT	\N	PRESENT	0
125092	124993	92045V	PARTICIPANT	\N	PRESENT	0
125093	124993	95067Q	PARTICIPANT	\N	PRESENT	0
125094	124993	01047U	PARTICIPANT	\N	PRESENT	0
125162	124157	04050C	PARTICIPANT	\N	PRESENT	0
125163	124157	11034G	PARTICIPANT	\N	PRESENT	0
125164	124157	14235Q	PARTICIPANT	\N	PRESENT	0
125165	124157	04067M	PARTICIPANT	\N	PRESENT	0
125166	124157	14026U	PARTICIPANT	\N	PRESENT	0
125167	124157	07029T	PARTICIPANT	\N	PRESENT	0
125168	124157	04088S	PARTICIPANT	\N	PRESENT	0
125169	124157	04089T	PARTICIPANT	\N	PRESENT	0
125170	124157	14119M	PARTICIPANT	\N	PRESENT	0
125171	124157	14103D	PARTICIPANT	\N	PRESENT	0
125172	124157	11094U	PARTICIPANT	\N	PRESENT	0
125173	124157	11046L	PARTICIPANT	\N	PRESENT	0
125174	124157	11066Q	PARTICIPANT	\N	PRESENT	0
125176	124157	11104D	PARTICIPANT	\N	PRESENT	0
125234	124157	08031R	PARTICIPANT	\N	PRESENT	0
125235	124157	07034Q	PARTICIPANT	\N	PRESENT	0
125236	124157	08069G	PARTICIPANT	\N	PRESENT	0
125237	124157	08062Y	PARTICIPANT	\N	PRESENT	0
125238	124157	14213J	PARTICIPANT	\N	PRESENT	0
125239	124157	14033T	PARTICIPANT	\N	PRESENT	0
125240	124157	14079W	PARTICIPANT	\N	PRESENT	0
125241	124157	14179A	PARTICIPANT	\N	PRESENT	0
125242	124157	04045F	PARTICIPANT	\N	PRESENT	0
125243	124157	14147R	PARTICIPANT	\N	PRESENT	0
125244	124157	95015C	PARTICIPANT	\N	PRESENT	0
125245	124157	11098Y	PARTICIPANT	\N	PRESENT	0
119873	119872	98042T	PARTICIPANT	\N	PRESENT	0
119874	119872	01019Q	PARTICIPANT	\N	PRESENT	0
119876	119875	11039M	PARTICIPANT	\N	PRESENT	0
119877	119875	98042T	PARTICIPANT	\N	PRESENT	0
119878	119875	01019Q	PARTICIPANT	\N	PRESENT	0
119880	119879	04067M	PARTICIPANT	\N	PRESENT	0
119881	119879	14217N	PARTICIPANT	\N	PRESENT	0
119882	119879	14249W	PARTICIPANT	\N	PRESENT	0
119883	119879	14265W	PARTICIPANT	\N	PRESENT	0
119884	119879	83047W	PARTICIPANT	\N	PRESENT	0
119885	119879	11046L	PARTICIPANT	\N	PRESENT	0
119886	119879	01034P	PARTICIPANT	\N	PRESENT	0
119887	119879	92045V	PARTICIPANT	\N	PRESENT	0
119888	119879	14079W	PARTICIPANT	\N	EXCUSE	0
119889	119879	14195A	PARTICIPANT	\N	EXCUSE	0
119897	119896	11039M	PARTICIPANT	\N	PRESENT	0
119898	119896	08012N	PARTICIPANT	\N	PRESENT	0
119899	119896	14073Q	PARTICIPANT	\N	PRESENT	0
119911	119910	08025T	PARTICIPANT	\N	PRESENT	0
119912	119910	11083R	PARTICIPANT	\N	PRESENT	0
120698	120697	08065C	PARTICIPANT	\N	EXCUSE	0
120700	120699	11010L	PARTICIPANT	\N	EXCUSE	0
120702	120701	08065C	PARTICIPANT	\N	EXCUSE	0
121098	121095	14030Q	PARTICIPANT	\N	PRESENT	0
121101	121095	11029K	PARTICIPANT	\N	PRESENT	0
121102	121095	11031D	PARTICIPANT	\N	PRESENT	0
121103	121095	80013X	PARTICIPANT	\N	PRESENT	0
121106	121095	14041T	PARTICIPANT	\N	PRESENT	0
121107	121095	14217N	PARTICIPANT	\N	PRESENT	0
121109	121095	09001P	PRESIDENT	0	PRESENT	0
121110	121095	04036E	PARTICIPANT	\N	EXCUSE	0
121112	121095	08031R	PARTICIPANT	\N	PRESENT	0
121114	121095	07029T	PARTICIPANT	\N	EXCUSE	0
121116	121095	14031R	PARTICIPANT	\N	PRESENT	0
121119	121095	11067R	PARTICIPANT	\N	EXCUSE	0
121120	121095	11014C	PARTICIPANT	\N	EXCUSE	0
121122	121095	14109K	PARTICIPANT	\N	PRESENT	0
121125	121095	14237S	PARTICIPANT	\N	EXCUSE	0
121129	121128	14041T	PARTICIPANT	\N	PRESENT	0
121132	121131	14041T	PARTICIPANT	\N	PRESENT	0
121139	121136	14041T	PARTICIPANT	\N	PRESENT	0
121162	121161	04040A	PRESIDENT	0	PRESENT	0
121239	121238	11048N	PARTICIPANT	\N	PRESENT	0
121233	121232	11048N	PARTICIPANT	\N	PRESENT	0
121236	121234	11048N	PARTICIPANT	\N	PRESENT	0
121241	121240	11048N	PARTICIPANT	\N	PRESENT	0
121243	121242	14199E	PARTICIPANT	\N	PRESENT	0
121245	121244	14199E	PARTICIPANT	\N	PRESENT	0
121247	121246	11048N	PARTICIPANT	\N	PRESENT	0
121295	121161	14071N	PARTICIPANT	\N	EXCUSE	0
126804	126002	08024S	PARTICIPANT	\N	PRESENT	0
126805	126002	14013P	PARTICIPANT	\N	PRESENT	0
126806	126002	04067M	PARTICIPANT	\N	PRESENT	0
126807	126002	13002U	PARTICIPANT	\N	PRESENT	0
126808	126002	14219Q	PARTICIPANT	\N	PRESENT	0
126809	126002	14034U	PARTICIPANT	\N	PRESENT	0
126810	126002	11076S	PARTICIPANT	\N	PRESENT	0
126811	126002	14215L	PARTICIPANT	\N	PRESENT	0
126812	126002	07034Q	PARTICIPANT	\N	PRESENT	0
126822	126002	04047H	PARTICIPANT	\N	PRESENT	0
126814	126002	08069G	PARTICIPANT	\N	PRESENT	0
126825	126002	01056V	PARTICIPANT	\N	PRESENT	0
126816	126002	08019V	PARTICIPANT	\N	PRESENT	0
126817	126002	07029T	PARTICIPANT	\N	PRESENT	0
126818	126002	14065Q	PARTICIPANT	\N	PRESENT	0
126823	126002	01024M	PARTICIPANT	\N	PRESENT	0
126820	126002	11066Q	PARTICIPANT	\N	PRESENT	0
126821	126002	11056N	PARTICIPANT	\N	PRESENT	0
126824	126002	11084S	PARTICIPANT	\N	PRESENT	0
126826	126002	08051V	PARTICIPANT	\N	PRESENT	0
126827	126002	04038G	PARTICIPANT	\N	PRESENT	0
126828	126002	95067Q	PARTICIPANT	\N	PRESENT	0
126829	126002	11049P	PARTICIPANT	\N	PRESENT	0
126830	126002	98005N	PARTICIPANT	\N	PRESENT	0
126831	126002	04085P	PARTICIPANT	\N	PRESENT	0
126832	126002	11101A	PARTICIPANT	\N	PRESENT	0
126833	126002	11026G	PARTICIPANT	\N	PRESENT	0
126834	126002	11080N	PARTICIPANT	\N	PRESENT	0
126835	126002	92015P	PARTICIPANT	\N	PRESENT	0
126836	126002	11091R	PARTICIPANT	\N	PRESENT	0
126837	126002	14213J	PARTICIPANT	\N	PRESENT	0
126838	126002	14179A	PARTICIPANT	\N	PRESENT	0
126839	126002	01015L	PARTICIPANT	\N	PRESENT	0
126840	126002	14209N	PARTICIPANT	\N	PRESENT	0
126841	126002	14237S	PARTICIPANT	\N	PRESENT	0
126842	126002	07024N	PARTICIPANT	\N	PRESENT	0
126843	126002	09001P	PARTICIPANT	\N	PRESENT	0
126844	126002	08014Q	PARTICIPANT	\N	PRESENT	0
126845	126002	11107G	PARTICIPANT	\N	PRESENT	0
126847	126846	08015R	PARTICIPANT	\N	PRESENT	0
126848	126846	11026G	PARTICIPANT	\N	PRESENT	0
126849	126846	04040A	PARTICIPANT	\N	PRESENT	0
126850	126846	04036E	PARTICIPANT	\N	PRESENT	0
126851	126846	04070G	PARTICIPANT	\N	PRESENT	0
126852	126846	04035D	PARTICIPANT	\N	PRESENT	0
126853	126846	95067Q	PARTICIPANT	\N	PRESENT	0
126854	126002	01028R	PARTICIPANT	\N	PRESENT	0
126855	126002	04057K	PARTICIPANT	\N	PRESENT	0
126856	126002	05008E	PARTICIPANT	\N	PRESENT	0
126861	126858	14079W	PARTICIPANT	\N	PRESENT	0
126859	126858	14239U	PARTICIPANT	\N	PRESENT	0
126860	126858	11095V	PARTICIPANT	\N	PRESENT	0
126862	126858	04067M	PARTICIPANT	\N	PRESENT	0
126863	126858	14217N	PARTICIPANT	\N	PRESENT	0
126864	126858	14042U	PARTICIPANT	\N	PRESENT	0
126865	126858	14249W	PARTICIPANT	\N	PRESENT	0
126866	126858	11110B	PARTICIPANT	\N	PRESENT	0
126867	126858	08034U	PARTICIPANT	\N	PRESENT	0
126868	126858	14037X	PARTICIPANT	\N	PRESENT	0
126869	126858	11077T	PARTICIPANT	\N	PRESENT	0
126870	126858	14205J	PARTICIPANT	\N	PRESENT	0
126871	126858	14265W	PARTICIPANT	\N	PRESENT	0
126872	126858	83047W	PARTICIPANT	\N	PRESENT	0
126873	126858	14235Q	PARTICIPANT	\N	PRESENT	0
126874	126858	11046L	PARTICIPANT	\N	PRESENT	0
126875	126858	04045F	PARTICIPANT	\N	PRESENT	0
126876	126858	01034P	PARTICIPANT	\N	PRESENT	0
126877	126858	92045V	PARTICIPANT	\N	EXCUSE	0
126878	126858	11066Q	PARTICIPANT	\N	PRESENT	0
126879	120699	11023D	PARTICIPANT	\N	EXCUSE	0
126880	126002	11036J	PARTICIPANT	\N	PRESENT	0
126882	126881	11036J	PARTICIPANT	\N	PRESENT	0
126885	126884	11036J	PARTICIPANT	\N	PRESENT	0
126887	123773	04043D	PARTICIPANT	\N	PRESENT	0
126888	126002	08034U	PARTICIPANT	\N	PRESENT	0
126889	126002	98021N	PARTICIPANT	\N	PRESENT	0
126890	126002	08055A	PARTICIPANT	\N	PRESENT	0
126930	126003	01015L	PARTICIPANT	\N	PRESENT	0
126931	126003	11107G	PARTICIPANT	\N	PRESENT	0
126932	126003	08055A	PARTICIPANT	\N	PRESENT	0
126933	126003	14219Q	PARTICIPANT	\N	PRESENT	0
126934	126003	14179A	PARTICIPANT	\N	PRESENT	0
126935	126003	14209N	PARTICIPANT	\N	PRESENT	0
126936	126003	07029T	PARTICIPANT	\N	PRESENT	0
126937	126003	08019V	PARTICIPANT	\N	PRESENT	0
126938	126003	98005N	PARTICIPANT	\N	PRESENT	0
126939	126003	01056V	PARTICIPANT	\N	PRESENT	0
126940	126003	98021N	PARTICIPANT	\N	PRESENT	0
126942	126941	08022Q	PARTICIPANT	\N	PRESENT	0
126944	126943	08022Q	PARTICIPANT	\N	PRESENT	0
126946	126945	08022Q	PARTICIPANT	\N	PRESENT	0
126947	126003	14237S	PARTICIPANT	\N	PRESENT	0
126948	126003	08009T	PARTICIPANT	\N	PRESENT	0
126949	126003	07024N	PARTICIPANT	\N	PRESENT	0
126950	126003	14215L	PARTICIPANT	\N	PRESENT	0
126951	126003	02002K	PARTICIPANT	\N	PRESENT	0
126952	126003	08010L	PARTICIPANT	\N	PRESENT	0
126953	126003	04066L	PARTICIPANT	\N	PRESENT	0
126954	126003	11076S	PARTICIPANT	\N	PRESENT	0
126973	126004	04066L	PARTICIPANT	\N	PRESENT	0
126974	126004	14231L	PARTICIPANT	\N	PRESENT	0
126975	126004	01015L	PARTICIPANT	\N	PRESENT	0
126976	126004	07026Q	PARTICIPANT	\N	PRESENT	0
126977	126004	14065Q	PARTICIPANT	\N	PRESENT	0
126978	126004	11032E	PARTICIPANT	\N	PRESENT	0
126979	126004	14329V	PARTICIPANT	\N	PRESENT	0
126980	126004	07029T	PARTICIPANT	\N	PRESENT	0
126981	126004	11085T	PARTICIPANT	\N	PRESENT	0
126982	126004	14219Q	PARTICIPANT	\N	PRESENT	0
126983	126004	11083R	PARTICIPANT	\N	PRESENT	0
126984	126004	11055M	PARTICIPANT	\N	PRESENT	0
126985	126004	11084S	PARTICIPANT	\N	PRESENT	0
126986	126004	14215L	PARTICIPANT	\N	PRESENT	0
126987	126004	14079W	PARTICIPANT	\N	PRESENT	0
126928	126003	08024S	PARTICIPANT	\N	PRESENT	0
126929	126003	04085P	PARTICIPANT	\N	PRESENT	0
97160	97159	01057W	PARTICIPANT	\N	PRESENT	0
97162	97159	14225N	PARTICIPANT	\N	PRESENT	0
97173	97172	01031L	PARTICIPANT	\N	PRESENT	0
97250	94188	11066Q	PARTICIPANT	\N	PRESENT	0
97251	94188	92045V	PARTICIPANT	\N	PRESENT	0
97252	94188	01028R	PARTICIPANT	\N	PRESENT	0
97253	94188	11094U	PARTICIPANT	\N	EXCUSE	0
97254	94188	11046L	PARTICIPANT	\N	EXCUSE	0
97255	94188	14229S	PARTICIPANT	\N	PRESENT	0
97256	94188	08021P	PARTICIPANT	\N	EXCUSE	0
97257	94188	14257W	PARTICIPANT	\N	PRESENT	0
97258	94188	08062Y	PARTICIPANT	\N	EXCUSE	0
97259	94188	01008M	PARTICIPANT	\N	PRESENT	0
97260	94188	14089Y	PARTICIPANT	\N	EXCUSE	0
97261	94188	08060W	PARTICIPANT	\N	EXCUSE	0
97262	94188	11029K	PARTICIPANT	\N	PRESENT	0
97263	94188	11080N	PARTICIPANT	\N	EXCUSE	0
97264	94188	08028W	PARTICIPANT	\N	EXCUSE	0
97265	94188	88008L	PARTICIPANT	\N	PRESENT	0
97266	94188	04038G	PARTICIPANT	\N	PRESENT	0
97267	94188	01059Y	PARTICIPANT	\N	PRESENT	0
97268	94188	98018T	PARTICIPANT	\N	EXCUSE	0
97269	94188	11088W	PARTICIPANT	\N	EXCUSE	0
97270	94188	01041N	PARTICIPANT	\N	PRESENT	0
97272	94188	02002K	PARTICIPANT	\N	EXCUSE	0
97273	94188	08048B	PARTICIPANT	\N	EXCUSE	0
97274	94188	11089X	PARTICIPANT	\N	EXCUSE	0
97275	94188	14026U	PARTICIPANT	\N	EXCUSE	0
97276	94188	14179A	PARTICIPANT	\N	EXCUSE	0
97277	94188	14121F	PARTICIPANT	\N	EXCUSE	0
97278	94188	11084S	PARTICIPANT	\N	EXCUSE	0
97279	94188	99004R	PRESIDENT	0	PRESENT	0
97280	94188	04061F	PARTICIPANT	\N	EXCUSE	0
97281	94188	01061S	PARTICIPANT	\N	EXCUSE	0
97282	94188	08012N	PARTICIPANT	\N	PRESENT	0
97283	94188	14205J	PARTICIPANT	\N	PRESENT	0
97284	94188	04088S	PARTICIPANT	\N	PRESENT	0
97285	94188	14277B	PARTICIPANT	\N	PRESENT	0
97286	94188	04071H	PARTICIPANT	\N	PRESENT	0
97289	97288	08016S	PARTICIPANT	\N	PRESENT	0
97292	97288	04080J	PARTICIPANT	\N	PRESENT	0
97293	97288	14225N	PARTICIPANT	\N	PRESENT	0
97294	97288	92031P	PARTICIPANT	\N	PRESENT	0
97299	97298	89017R	PARTICIPANT	\N	PRESENT	0
117533	117532	01016M	PARTICIPANT	\N	PRESENT	0
117318	117297	14217N	PARTICIPANT	\N	PRESENT	0
117319	117297	14042U	PARTICIPANT	\N	PRESENT	0
117321	117297	12042Y	PARTICIPANT	\N	PRESENT	0
117322	117297	14281W	PARTICIPANT	\N	PRESENT	0
117323	117297	14087W	PARTICIPANT	\N	EXCUSE	0
117324	117297	01003G	PARTICIPANT	\N	PRESENT	0
117325	117297	14034U	PARTICIPANT	\N	PRESENT	0
117326	117297	14231L	PARTICIPANT	\N	PRESENT	0
117327	117297	11061K	PARTICIPANT	\N	PRESENT	0
119253	119252	04042C	PARTICIPANT	\N	PRESENT	0
117331	117297	14026U	PARTICIPANT	\N	PRESENT	0
117332	117297	14213J	PARTICIPANT	\N	PRESENT	0
117333	117297	14121F	PARTICIPANT	\N	PRESENT	0
119254	119252	01056V	PARTICIPANT	\N	PRESENT	0
117335	117297	14037X	PARTICIPANT	\N	PRESENT	0
117336	117297	14018U	PARTICIPANT	\N	PRESENT	0
117337	117297	11067R	PARTICIPANT	\N	PRESENT	0
117338	117297	14223L	PARTICIPANT	\N	PRESENT	0
117339	117297	04092N	PRESIDENT	0	PRESENT	0
119849	119846	14037X	PARTICIPANT	\N	PRESENT	0
119582	119581	08034U	PARTICIPANT	\N	PRESENT	0
117342	117297	14071N	PARTICIPANT	\N	PRESENT	0
117343	117297	07032N	PARTICIPANT	\N	PRESENT	0
117344	117297	04043D	PARTICIPANT	\N	PRESENT	0
117345	117297	14271U	PARTICIPANT	\N	PRESENT	0
119847	119846	14239U	PARTICIPANT	\N	PRESENT	0
117347	117297	11093T	PARTICIPANT	\N	PRESENT	0
117348	117297	11097X	PARTICIPANT	\N	PRESENT	0
117349	117297	04045F	PARTICIPANT	\N	PRESENT	0
117350	117297	14227Q	PARTICIPANT	\N	PRESENT	0
117351	117297	01034P	PARTICIPANT	\N	PRESENT	0
119848	119846	01059Y	PARTICIPANT	\N	PRESENT	0
117353	117297	11063M	PARTICIPANT	\N	PRESENT	0
117354	117297	14269B	PARTICIPANT	\N	PRESENT	0
119850	119846	14205J	PARTICIPANT	\N	PRESENT	0
119851	119846	14265W	PARTICIPANT	\N	PRESENT	0
119852	119846	83047W	PARTICIPANT	\N	PRESENT	0
119853	119846	14235Q	PARTICIPANT	\N	PRESENT	0
119854	119846	11046L	PARTICIPANT	\N	PRESENT	0
119855	119846	01034P	PARTICIPANT	\N	PRESENT	0
119856	119846	11066Q	PARTICIPANT	\N	PRESENT	0
119857	119846	14079W	PARTICIPANT	\N	EXCUSE	0
119865	119863	01034P	PARTICIPANT	\N	PRESENT	0
119859	119846	14121F	PARTICIPANT	\N	EXCUSE	0
119860	119846	14195A	PARTICIPANT	\N	EXCUSE	0
119861	119846	92045V	PARTICIPANT	\N	EXCUSE	0
119862	119846	04067M	PARTICIPANT	\N	EXCUSE	0
119864	119863	14265W	PARTICIPANT	\N	PRESENT	0
119866	119863	92045V	PARTICIPANT	\N	PRESENT	0
119867	119863	14079W	PARTICIPANT	\N	EXCUSE	0
119868	119863	04067M	PARTICIPANT	\N	EXCUSE	0
119869	119863	14195A	PARTICIPANT	\N	EXCUSE	0
119973	119972	14231L	PARTICIPANT	\N	PRESENT	0
120564	120563	14263U	PARTICIPANT	\N	PRESENT	0
120565	120563	14133K	PARTICIPANT	\N	PRESENT	0
120567	120563	04059M	PARTICIPANT	\N	PRESENT	0
120568	120563	11039M	PARTICIPANT	\N	PRESENT	0
120569	120563	01044R	PARTICIPANT	\N	PRESENT	0
120570	120563	08043V	PARTICIPANT	\N	EXCUSE	0
120571	120563	14089Y	PARTICIPANT	\N	PRESENT	0
120572	120563	14105F	PARTICIPANT	\N	PRESENT	0
120573	120563	11029K	PARTICIPANT	\N	PRESENT	0
120575	120563	92015P	PARTICIPANT	\N	PRESENT	0
120576	120563	08024S	PARTICIPANT	\N	PRESENT	0
120577	120563	14201E	PARTICIPANT	\N	PRESENT	0
120578	120563	14329V	PARTICIPANT	\N	PRESENT	0
120579	120563	14209N	PARTICIPANT	\N	PRESENT	0
120581	120563	11091R	PARTICIPANT	\N	PRESENT	0
120582	120563	87003B	PARTICIPANT	\N	PRESENT	0
120583	120563	98042T	PARTICIPANT	\N	PRESENT	0
120584	120563	14249W	PARTICIPANT	\N	PRESENT	0
120585	120563	01041N	PARTICIPANT	\N	PRESENT	0
120586	120563	01025N	PARTICIPANT	\N	PRESENT	0
120587	120563	01037S	PARTICIPANT	\N	EXCUSE	0
120588	120563	89029V	PARTICIPANT	\N	PRESENT	0
120590	120563	11089X	PARTICIPANT	\N	PRESENT	0
120591	120563	07026Q	PARTICIPANT	\N	EXCUSE	0
120594	120563	04041B	PARTICIPANT	\N	PRESENT	0
120595	120563	14241N	PARTICIPANT	\N	PRESENT	0
120597	120563	14073Q	PARTICIPANT	\N	EXCUSE	0
120598	120563	08031R	PARTICIPANT	\N	EXCUSE	0
120600	120563	08039A	PARTICIPANT	\N	EXCUSE	0
120601	120563	08017T	PARTICIPANT	\N	PRESENT	0
120602	120563	14059S	PARTICIPANT	\N	PRESENT	0
120603	120563	08012N	PARTICIPANT	\N	PRESENT	0
120606	120563	14063N	PARTICIPANT	\N	PRESENT	0
120607	120563	04057K	PARTICIPANT	\N	PRESENT	0
120608	120563	11014C	PARTICIPANT	\N	PRESENT	0
120609	120563	14109K	PARTICIPANT	\N	PRESENT	0
120610	120563	04070G	PRESIDENT	0	PRESENT	0
120613	120563	83047W	PARTICIPANT	\N	PRESENT	0
120614	120563	14235Q	PARTICIPANT	\N	PRESENT	0
120616	120563	04033B	PARTICIPANT	\N	PRESENT	0
120617	120563	14229S	PARTICIPANT	\N	PRESENT	0
120618	120563	11043H	PARTICIPANT	\N	PRESENT	0
111113	111112	89017R	PARTICIPANT	\N	PRESENT	0
111114	111112	01031L	PRESIDENT	0	PRESENT	0
125246	124157	14195A	PARTICIPANT	\N	PRESENT	0
125247	124157	14205J	PARTICIPANT	\N	PRESENT	0
111117	111112	11068S	PARTICIPANT	\N	EXCUSE	0
111118	111112	11040E	PARTICIPANT	\N	PRESENT	0
111119	111112	08014Q	PARTICIPANT	\N	PRESENT	0
111120	111112	14167V	PARTICIPANT	\N	PRESENT	0
111121	111112	14175V	PARTICIPANT	\N	PRESENT	0
111122	111112	14083S	PARTICIPANT	\N	PRESENT	0
125248	124157	08024S	PARTICIPANT	\N	PRESENT	0
111124	111112	14085U	PARTICIPANT	\N	PRESENT	0
111125	111112	11042G	PARTICIPANT	\N	PRESENT	0
125249	124157	14271U	PARTICIPANT	\N	PRESENT	0
111127	111112	04086Q	PARTICIPANT	\N	PRESENT	0
111128	111112	04055H	PARTICIPANT	\N	EXCUSE	0
111129	111112	11070L	PARTICIPANT	\N	PRESENT	0
125250	124157	11014C	PARTICIPANT	\N	PRESENT	0
111131	111112	14327T	PARTICIPANT	\N	PRESENT	0
111132	111112	08022Q	PARTICIPANT	\N	PRESENT	0
111133	111112	01027Q	PARTICIPANT	\N	EXCUSE	0
111134	111112	04071H	PARTICIPANT	\N	PRESENT	0
111135	111112	11074Q	PARTICIPANT	\N	PRESENT	0
111136	111112	98053W	PARTICIPANT	\N	EXCUSE	0
111137	111112	11083R	PARTICIPANT	\N	PRESENT	0
111138	111112	14199E	PARTICIPANT	\N	PRESENT	0
111139	111112	01057W	PARTICIPANT	\N	PRESENT	0
111140	111112	08016S	PARTICIPANT	\N	PRESENT	0
111141	111112	08069G	PARTICIPANT	\N	PRESENT	0
111142	111112	11048N	PARTICIPANT	\N	PRESENT	0
111143	111112	99004R	PARTICIPANT	\N	PRESENT	0
111144	111112	04061F	PARTICIPANT	\N	PRESENT	0
111145	111112	14159V	PARTICIPANT	\N	PRESENT	0
111146	111112	07029T	PARTICIPANT	\N	PRESENT	0
111147	111112	14277B	PARTICIPANT	\N	PRESENT	0
111148	111112	08010L	PARTICIPANT	\N	PRESENT	0
111149	111112	08034U	PARTICIPANT	\N	PRESENT	0
125251	124157	98050T	PARTICIPANT	\N	PRESENT	0
111151	111112	98046X	PARTICIPANT	\N	PRESENT	0
111152	111112	11085T	PARTICIPANT	\N	PRESENT	0
111153	111112	08011M	PARTICIPANT	\N	PRESENT	0
125252	124157	14269B	PARTICIPANT	\N	PRESENT	0
111155	111112	08061X	PARTICIPANT	\N	PRESENT	0
111156	111112	01016M	PARTICIPANT	\N	PRESENT	0
111157	111112	14225N	PARTICIPANT	\N	PRESENT	0
111158	111112	11012A	PARTICIPANT	\N	PRESENT	0
111159	111112	11057P	PARTICIPANT	\N	PRESENT	0
111160	111112	14173T	PARTICIPANT	\N	PRESENT	0
111161	111112	04034C	PARTICIPANT	\N	PRESENT	0
125293	124157	14111D	PARTICIPANT	\N	PRESENT	0
125294	124157	11099A	PARTICIPANT	\N	PRESENT	0
125302	124157	14059S	PARTICIPANT	\N	PRESENT	0
125303	124157	14061L	PARTICIPANT	\N	PRESENT	0
125304	124157	14123H	PARTICIPANT	\N	PRESENT	0
125305	124157	14327T	PARTICIPANT	\N	PRESENT	0
125306	124157	08060W	PARTICIPANT	\N	PRESENT	0
125307	124157	14207L	PARTICIPANT	\N	PRESENT	0
125308	124157	08019V	PARTICIPANT	\N	PRESENT	0
125309	124157	14267Y	PARTICIPANT	\N	PRESENT	0
125310	124157	11036J	PARTICIPANT	\N	PRESENT	0
125311	124157	14081Q	PARTICIPANT	\N	PRESENT	0
125312	124157	14105F	PARTICIPANT	\N	PRESENT	0
125313	124157	11110B	PARTICIPANT	\N	PRESENT	0
125314	124157	01028R	PARTICIPANT	\N	PRESENT	0
125316	124157	14042U	PARTICIPANT	\N	PRESENT	0
125317	124157	11088W	PARTICIPANT	\N	PRESENT	0
125319	124157	87003B	PARTICIPANT	\N	PRESENT	0
125320	124157	14037X	PARTICIPANT	\N	PRESENT	0
125321	124157	14028W	PARTICIPANT	\N	PRESENT	0
125322	124782	11035H	PARTICIPANT	\N	PRESENT	0
125323	124782	04045F	PARTICIPANT	\N	PRESENT	0
125324	124782	01043Q	PARTICIPANT	\N	PRESENT	0
125325	124157	98053W	PARTICIPANT	\N	PRESENT	0
125326	124782	95059Q	PARTICIPANT	\N	EXCUSE	0
125327	124157	11103C	PARTICIPANT	\N	PRESENT	0
125328	124157	11032E	PARTICIPANT	\N	PRESENT	0
125329	124157	01025N	PARTICIPANT	\N	PRESENT	0
125330	124157	14083S	PARTICIPANT	\N	PRESENT	0
125331	124157	01058X	PARTICIPANT	\N	PRESENT	0
125332	124157	14215L	PARTICIPANT	\N	PRESENT	0
125333	124157	08034U	PARTICIPANT	\N	PRESENT	0
125374	124157	04042C	PARTICIPANT	\N	PRESENT	0
125375	124157	01046T	PARTICIPANT	\N	PRESENT	0
125376	124157	11090Q	PARTICIPANT	\N	PRESENT	0
125377	124157	14197C	PARTICIPANT	\N	PRESENT	0
125378	124157	14281W	PARTICIPANT	\N	PRESENT	0
125379	124157	14051J	PARTICIPANT	\N	PRESENT	0
125380	124157	14331P	PARTICIPANT	\N	PRESENT	0
125381	124157	11084S	PARTICIPANT	\N	PRESENT	0
125382	124157	14121F	PARTICIPANT	\N	PRESENT	0
125383	124157	11039M	PARTICIPANT	\N	PRESENT	0
125384	124157	95030B	PARTICIPANT	\N	PRESENT	0
125469	124157	01031L	PARTICIPANT	\N	PRESENT	0
125470	124157	11012A	PARTICIPANT	\N	PRESENT	0
125471	124157	14265W	PARTICIPANT	\N	PRESENT	0
125472	124157	14219Q	PARTICIPANT	\N	PRESENT	0
125513	124157	83042R	PARTICIPANT	\N	PRESENT	0
125514	124157	01016M	PARTICIPANT	\N	PRESENT	0
125515	124157	08015R	PARTICIPANT	\N	PRESENT	0
125516	124157	14193X	PARTICIPANT	\N	PRESENT	0
125518	124157	14053L	PARTICIPANT	\N	PRESENT	0
125520	124157	12042Y	PARTICIPANT	\N	PRESENT	0
125521	124157	98029W	PARTICIPANT	\N	PRESENT	0
125522	124157	04033B	PARTICIPANT	\N	PRESENT	0
125524	124157	11026G	PARTICIPANT	\N	PRESENT	0
125525	124157	95063L	PARTICIPANT	\N	PRESENT	0
125526	124157	14173T	PARTICIPANT	\N	PRESENT	0
125527	124157	01057W	PARTICIPANT	\N	PRESENT	0
125528	124157	11054L	PARTICIPANT	\N	PRESENT	0
125538	124157	80013X	PARTICIPANT	\N	PRESENT	0
125539	125536	04085P	PARTICIPANT	\N	PRESENT	0
125540	125536	05008E	PRESIDENT	0	PRESENT	0
125541	124157	14257W	PARTICIPANT	\N	PRESENT	0
125542	125536	11030C	PARTICIPANT	\N	PRESENT	0
125544	125536	11033F	PARTICIPANT	\N	PRESENT	0
125545	125536	14065Q	PARTICIPANT	\N	PRESENT	0
125546	125536	14069U	PARTICIPANT	\N	PRESENT	0
125548	125536	04047H	PARTICIPANT	\N	PRESENT	0
125550	125536	11032E	PARTICIPANT	\N	PRESENT	0
125551	125536	04038G	PARTICIPANT	\N	PRESENT	0
125552	125536	99002P	PARTICIPANT	\N	PRESENT	0
125553	125536	11056N	PARTICIPANT	\N	PRESENT	0
125554	125536	14259Y	PARTICIPANT	\N	PRESENT	0
125555	125536	11035H	PARTICIPANT	\N	PRESENT	0
125556	125536	14041T	PARTICIPANT	\N	PRESENT	0
125557	125536	11113E	PARTICIPANT	\N	PRESENT	0
125559	125536	01024M	PARTICIPANT	\N	PRESENT	0
125560	125536	14215L	PARTICIPANT	\N	PRESENT	0
125561	125536	11034G	PARTICIPANT	\N	PRESENT	0
125563	125536	08018U	PARTICIPANT	\N	PRESENT	0
125564	125536	01007L	PARTICIPANT	\N	PRESENT	0
125566	125536	11049P	PARTICIPANT	\N	PRESENT	0
125567	125536	08044W	PARTICIPANT	\N	EXCUSE	0
125569	125536	11084S	PARTICIPANT	\N	PRESENT	0
125570	125536	11026G	PARTICIPANT	\N	PRESENT	0
125572	125536	04079R	PARTICIPANT	\N	PRESENT	0
125573	125536	14111D	PARTICIPANT	\N	PRESENT	0
125575	125536	14001X	PARTICIPANT	\N	PRESENT	0
125576	125536	01060R	PARTICIPANT	\N	PRESENT	0
125578	125536	14147R	PARTICIPANT	\N	PRESENT	0
125579	125536	08051V	PARTICIPANT	\N	PRESENT	0
125581	125536	95049N	PARTICIPANT	\N	PRESENT	0
125582	125536	07034Q	PARTICIPANT	\N	PRESENT	0
125583	125536	04074L	PARTICIPANT	\N	PRESENT	0
125585	125536	10015M	PARTICIPANT	\N	PRESENT	0
125586	125536	95063L	PARTICIPANT	\N	PRESENT	0
125587	125536	01019Q	PARTICIPANT	\N	PRESENT	0
125589	125536	01028R	PARTICIPANT	\N	PRESENT	0
125590	125536	98035U	PARTICIPANT	\N	PRESENT	0
125591	125536	04056J	PARTICIPANT	\N	PRESENT	0
125593	125536	04044E	PARTICIPANT	\N	PRESENT	0
125594	125536	11037K	PARTICIPANT	\N	PRESENT	0
125595	124157	04049K	PARTICIPANT	\N	PRESENT	0
125596	125536	92045V	PARTICIPANT	\N	PRESENT	0
125597	125536	95067Q	PARTICIPANT	\N	PRESENT	0
125599	125536	01047U	PARTICIPANT	\N	PRESENT	0
125611	124157	11048N	PARTICIPANT	\N	PRESENT	0
125614	124157	01022K	PARTICIPANT	\N	PRESENT	0
125615	125523	08055A	PARTICIPANT	\N	PRESENT	0
125616	125523	14030Q	PARTICIPANT	\N	PRESENT	0
125617	125523	98023Q	PARTICIPANT	\N	PRESENT	0
125618	125523	01022K	PARTICIPANT	\N	PRESENT	0
125619	124157	14133K	PARTICIPANT	\N	PRESENT	0
125620	125523	11059R	PARTICIPANT	\N	PRESENT	0
125621	125523	14219Q	PARTICIPANT	\N	PRESENT	0
125622	125523	80027E	PARTICIPANT	\N	PRESENT	0
125623	124157	14199E	PARTICIPANT	\N	PRESENT	0
125624	125523	14031R	PARTICIPANT	\N	PRESENT	0
125625	125523	08009T	PARTICIPANT	\N	PRESENT	0
94078	94077	11076S	PARTICIPANT	\N	PRESENT	0
94135	94077	04035D	PARTICIPANT	\N	PRESENT	0
94080	94077	04040A	PARTICIPANT	\N	PRESENT	0
94081	94077	08058D	PARTICIPANT	\N	PRESENT	0
94082	94077	04042C	PARTICIPANT	\N	PRESENT	0
94306	94305	98029W	PARTICIPANT	\N	PRESENT	0
94325	94324	96004D	PARTICIPANT	\N	PRESENT	0
94326	94324	14133K	PARTICIPANT	\N	PRESENT	0
94086	94077	11027H	PARTICIPANT	\N	PRESENT	0
94087	94077	98018T	PARTICIPANT	\N	PRESENT	0
94088	94077	92018S	PARTICIPANT	\N	EXCUSE	0
94089	94077	92020L	PARTICIPANT	\N	PRESENT	0
94090	94077	95030B	PARTICIPANT	\N	PRESENT	0
94327	94324	01016M	PARTICIPANT	\N	PRESENT	0
94332	94331	01013J	PARTICIPANT	\N	PRESENT	0
94333	94331	11053K	PARTICIPANT	\N	PRESENT	0
94094	94077	08065C	PARTICIPANT	\N	PRESENT	0
94334	94331	11080N	PARTICIPANT	\N	EXCUSE	0
94096	94077	07024N	PARTICIPANT	\N	PRESENT	0
94335	94331	04067M	PARTICIPANT	\N	EXCUSE	0
94098	94077	14014Q	PARTICIPANT	\N	PRESENT	0
94099	94077	11015D	PARTICIPANT	\N	EXCUSE	0
94336	94331	01027Q	PRESIDENT	0	PRESENT	0
94101	94077	95035G	PARTICIPANT	\N	PRESENT	0
94337	94331	01057W	PARTICIPANT	\N	PRESENT	0
94103	94077	14211G	PARTICIPANT	\N	PRESENT	0
94104	94077	98022P	PARTICIPANT	\N	EXCUSE	0
94338	94331	14159V	PARTICIPANT	\N	PRESENT	0
94106	94077	95037J	PARTICIPANT	\N	PRESENT	0
94107	94077	04078Q	PARTICIPANT	\N	PRESENT	0
94108	94077	14097Y	PARTICIPANT	\N	PRESENT	0
94339	94331	92039X	PARTICIPANT	\N	EXCUSE	0
94110	94077	04036E	PARTICIPANT	\N	PRESENT	0
94340	94331	14225N	PARTICIPANT	\N	PRESENT	0
94112	94077	04077P	PARTICIPANT	\N	PRESENT	0
94341	94331	11012A	PARTICIPANT	\N	EXCUSE	0
94342	94331	14157T	PARTICIPANT	\N	PRESENT	0
94347	94346	11039M	PARTICIPANT	\N	PRESENT	0
94348	94346	08012N	PARTICIPANT	\N	PRESENT	0
94117	94077	83042R	PARTICIPANT	\N	PRESENT	0
94349	94346	14073Q	PARTICIPANT	\N	PRESENT	0
94350	94346	14235Q	PARTICIPANT	\N	PRESENT	0
94351	94346	11043H	PARTICIPANT	\N	PRESENT	0
94592	83996	04040A	PRESIDENT	0	PRESENT	0
97240	97215	14223L	PARTICIPANT	\N	PRESENT	0
94123	94077	14028W	PARTICIPANT	\N	PRESENT	0
94124	94077	14193X	PARTICIPANT	\N	PRESENT	0
94125	94077	98021N	PARTICIPANT	\N	EXCUSE	0
94612	91448	14093U	PARTICIPANT	\N	EXCUSE	0
94127	94077	95059Q	PRESIDENT	0	PRESENT	0
94128	94077	86044G	PARTICIPANT	\N	PRESENT	0
94129	94077	01014K	PARTICIPANT	\N	PRESENT	0
94130	94077	11054L	PARTICIPANT	\N	PRESENT	0
94615	94614	11026G	PARTICIPANT	\N	PRESENT	0
94617	94616	11026G	PARTICIPANT	\N	PRESENT	0
94133	94077	08049C	PARTICIPANT	\N	EXCUSE	0
94619	94618	00003C	PARTICIPANT	\N	PRESENT	0
94620	94618	14071N	PARTICIPANT	\N	PRESENT	0
95137	91448	14053L	PARTICIPANT	\N	EXCUSE	0
94837	94835	08055A	PARTICIPANT	\N	PRESENT	0
94838	94835	14093U	PARTICIPANT	\N	PRESENT	0
95138	91448	95062K	PARTICIPANT	\N	PRESENT	0
95139	91448	01022K	PARTICIPANT	\N	EXCUSE	0
95140	91448	04095R	PARTICIPANT	\N	PRESENT	0
94842	94835	11095V	PARTICIPANT	\N	PRESENT	0
94843	94835	14038Y	PARTICIPANT	\N	PRESENT	0
97241	97215	04077P	PARTICIPANT	\N	PRESENT	0
94845	94835	98023Q	PARTICIPANT	\N	PRESENT	0
97242	97215	14265W	PARTICIPANT	\N	PRESENT	0
94847	94835	01015L	PARTICIPANT	\N	EXCUSE	0
94848	94835	11107G	PARTICIPANT	\N	PRESENT	0
97243	97215	14237S	PARTICIPANT	\N	PRESENT	0
94850	94835	02002K	PARTICIPANT	\N	PRESENT	0
94851	94835	01022K	PARTICIPANT	\N	PRESENT	0
97244	97215	11066Q	PARTICIPANT	\N	PRESENT	0
97245	97215	04033B	PARTICIPANT	\N	PRESENT	0
94854	94835	11059R	PARTICIPANT	\N	PRESENT	0
94855	94835	14219Q	PARTICIPANT	\N	PRESENT	0
94856	94835	80027E	PARTICIPANT	\N	PRESENT	0
94857	94835	14031R	PARTICIPANT	\N	PRESENT	0
94858	94835	08009T	PRESIDENT	0	PRESENT	0
94859	94835	08062Y	PARTICIPANT	\N	PRESENT	0
94860	94835	14221J	PARTICIPANT	\N	PRESENT	0
94861	94835	92039X	PARTICIPANT	\N	PRESENT	0
94862	94835	08042U	PARTICIPANT	\N	PRESENT	0
97246	97215	95067Q	PARTICIPANT	\N	PRESENT	0
94864	94835	14237S	PARTICIPANT	\N	PRESENT	0
94865	94835	13002U	PARTICIPANT	\N	PRESENT	0
94866	94835	05012A	PARTICIPANT	\N	PRESENT	0
100193	100192	07004J	PARTICIPANT	\N	PRESENT	0
94868	94835	14135M	PARTICIPANT	\N	PRESENT	0
94869	94835	14331P	PARTICIPANT	\N	PRESENT	0
94870	94835	95062K	PARTICIPANT	\N	EXCUSE	0
94871	94835	14107H	PARTICIPANT	\N	PRESENT	0
94872	94835	14051J	PARTICIPANT	\N	PRESENT	0
100194	100192	10015M	PARTICIPANT	\N	PRESENT	0
94874	94835	96003C	PARTICIPANT	\N	EXCUSE	0
105816	105815	11039M	PARTICIPANT	\N	PRESENT	0
105817	105815	98042T	PARTICIPANT	\N	PRESENT	0
105818	105815	01019Q	PARTICIPANT	\N	PRESENT	0
105820	105819	11039M	PARTICIPANT	\N	PRESENT	0
105821	105819	98042T	PARTICIPANT	\N	PRESENT	0
105822	105819	01019Q	PARTICIPANT	\N	PRESENT	0
111992	111932	11055M	PARTICIPANT	\N	PRESENT	0
111934	111932	01031L	PRESIDENT	0	PRESENT	0
111993	111932	01046T	PARTICIPANT	\N	PRESENT	0
111994	111932	04053F	PARTICIPANT	\N	PRESENT	0
111937	111932	11068S	PARTICIPANT	\N	EXCUSE	0
111995	111932	14053L	PARTICIPANT	\N	PRESENT	0
111996	111932	11103C	PARTICIPANT	\N	PRESENT	0
111997	111932	14195A	PARTICIPANT	\N	PRESENT	0
111941	111932	14175V	PARTICIPANT	\N	PRESENT	0
111942	111932	14083S	PARTICIPANT	\N	PRESENT	0
111943	111932	11053K	PARTICIPANT	\N	PRESENT	0
111944	111932	14085U	PARTICIPANT	\N	PRESENT	0
111945	111932	11042G	PARTICIPANT	\N	PRESENT	0
111998	111932	14267Y	PARTICIPANT	\N	PRESENT	0
111947	111932	04086Q	PARTICIPANT	\N	PRESENT	0
111948	111932	04055H	PARTICIPANT	\N	PRESENT	0
111949	111932	11070L	PARTICIPANT	\N	PRESENT	0
111950	111932	11088W	PARTICIPANT	\N	PRESENT	0
111999	111932	11031D	PARTICIPANT	\N	PRESENT	0
111952	111932	08022Q	PARTICIPANT	\N	PRESENT	0
111953	111932	01027Q	PARTICIPANT	\N	PRESENT	0
111954	111932	04071H	PARTICIPANT	\N	PRESENT	0
112000	111932	08052W	PARTICIPANT	\N	PRESENT	0
111956	111932	98053W	PARTICIPANT	\N	EXCUSE	0
111957	111932	11083R	PARTICIPANT	\N	PRESENT	0
112001	111932	98024R	PARTICIPANT	\N	PRESENT	0
112002	111932	14042U	PARTICIPANT	\N	PRESENT	0
112003	111932	12042Y	PARTICIPANT	\N	PRESENT	0
111961	111932	08069G	PARTICIPANT	\N	PRESENT	0
112004	111932	14281W	PARTICIPANT	\N	PRESENT	0
111963	111932	99004R	PARTICIPANT	\N	PRESENT	0
112005	111932	14034U	PARTICIPANT	\N	PRESENT	0
111965	111932	14159V	PARTICIPANT	\N	PRESENT	0
111966	111932	07029T	PARTICIPANT	\N	PRESENT	0
112006	111932	14231L	PARTICIPANT	\N	PRESENT	0
111968	111932	08010L	PARTICIPANT	\N	PRESENT	0
111969	111932	08034U	PARTICIPANT	\N	PRESENT	0
112007	111932	14026U	PARTICIPANT	\N	PRESENT	0
111971	111932	98046X	PARTICIPANT	\N	PRESENT	0
112008	111932	14213J	PARTICIPANT	\N	PRESENT	0
111973	111932	08011M	PARTICIPANT	\N	PRESENT	0
112009	111932	14121F	PARTICIPANT	\N	PRESENT	0
111975	111932	08061X	PARTICIPANT	\N	PRESENT	0
111976	111932	01016M	PARTICIPANT	\N	PRESENT	0
111977	111932	14225N	PARTICIPANT	\N	PRESENT	0
112010	111932	11112D	PARTICIPANT	\N	PRESENT	0
111979	111932	11057P	PARTICIPANT	\N	PRESENT	0
112011	111932	14037X	PARTICIPANT	\N	PRESENT	0
111981	111932	04034C	PARTICIPANT	\N	PRESENT	0
112012	111932	11067R	PARTICIPANT	\N	PRESENT	0
112013	111932	04092N	PARTICIPANT	\N	PRESENT	0
112014	111932	14119M	PARTICIPANT	\N	PRESENT	0
112015	111932	07032N	PARTICIPANT	\N	PRESENT	0
112016	111932	14271U	PARTICIPANT	\N	PRESENT	0
112017	111932	11093T	PARTICIPANT	\N	PRESENT	0
112018	111932	11097X	PARTICIPANT	\N	PRESENT	0
112019	111932	04045F	PARTICIPANT	\N	PRESENT	0
112020	111932	01034P	PARTICIPANT	\N	PRESENT	0
112021	111932	14269B	PARTICIPANT	\N	PRESENT	0
115873	115872	11057P	PARTICIPANT	\N	PRESENT	0
115893	115892	11036J	PARTICIPANT	\N	PRESENT	0
115894	115892	08055A	PARTICIPANT	\N	PRESENT	0
115895	115892	14207L	PARTICIPANT	\N	PRESENT	0
115896	115892	11103C	PARTICIPANT	\N	PRESENT	0
115897	115892	92015P	PARTICIPANT	\N	PRESENT	0
115898	115892	04089T	PARTICIPANT	\N	PRESENT	0
122181	121156	14235Q	PARTICIPANT	\N	PRESENT	0
122182	121156	95031C	PARTICIPANT	\N	PRESENT	0
122183	121156	01013J	PARTICIPANT	\N	PRESENT	0
122184	121156	04097T	PARTICIPANT	\N	PRESENT	0
122185	121156	07026Q	PARTICIPANT	\N	PRESENT	0
122186	121156	12041X	PARTICIPANT	\N	PRESENT	0
122187	121156	08039A	PARTICIPANT	\N	PRESENT	0
122188	121156	14211G	PARTICIPANT	\N	PRESENT	0
122189	121156	11063M	PARTICIPANT	\N	PRESENT	0
122190	121156	11056N	PARTICIPANT	\N	PRESENT	0
122191	121156	95062K	PARTICIPANT	\N	PRESENT	0
122192	121156	14013P	PARTICIPANT	\N	PRESENT	0
122193	121156	01027Q	PARTICIPANT	\N	PRESENT	0
122194	121156	98053W	PARTICIPANT	\N	PRESENT	0
122195	121156	04085P	PARTICIPANT	\N	PRESENT	0
122196	121156	14241N	PARTICIPANT	\N	PRESENT	0
122197	121156	08028W	PARTICIPANT	\N	PRESENT	0
122198	121156	98022P	PARTICIPANT	\N	PRESENT	0
122199	121156	04041B	PARTICIPANT	\N	PRESENT	0
122201	121156	14169X	PARTICIPANT	\N	PRESENT	0
122202	121156	04050C	PARTICIPANT	\N	PRESENT	0
122203	121156	08011M	PARTICIPANT	\N	PRESENT	0
122204	121156	01056V	PARTICIPANT	\N	PRESENT	0
122205	121156	92018S	PARTICIPANT	\N	PRESENT	0
122206	121156	11055M	PARTICIPANT	\N	PRESENT	0
122207	121156	01019Q	PARTICIPANT	\N	PRESENT	0
122208	121156	01044R	PARTICIPANT	\N	PRESENT	0
122209	121156	11065P	PARTICIPANT	\N	PRESENT	0
122210	121156	08010L	PARTICIPANT	\N	PRESENT	0
122211	121156	11029K	PARTICIPANT	\N	PRESENT	0
122212	121156	11043H	PARTICIPANT	\N	PRESENT	0
122213	121156	13002U	PARTICIPANT	\N	PRESENT	0
122214	121156	11083R	PARTICIPANT	\N	PRESENT	0
122215	121156	11080N	PARTICIPANT	\N	PRESENT	0
122216	121156	11099A	PARTICIPANT	\N	PRESENT	0
122217	121156	01059Y	PARTICIPANT	\N	PRESENT	0
122218	121156	14123H	PARTICIPANT	\N	PRESENT	0
122219	121156	14111D	PARTICIPANT	\N	PRESENT	0
122220	121156	14247U	PARTICIPANT	\N	PRESENT	0
122221	121156	87003B	PARTICIPANT	\N	PRESENT	0
122222	121156	92044U	PARTICIPANT	\N	PRESENT	0
122223	121156	08051V	PARTICIPANT	\N	PRESENT	0
122224	121156	11010L	PARTICIPANT	\N	PRESENT	0
122225	121156	01046T	PARTICIPANT	\N	PRESENT	0
122226	121156	88008L	PARTICIPANT	\N	PRESENT	0
122227	121156	04078Q	PARTICIPANT	\N	PRESENT	0
122228	121156	08031R	PARTICIPANT	\N	PRESENT	0
122229	121156	11011M	PARTICIPANT	\N	PRESENT	0
122230	121156	08049C	PARTICIPANT	\N	PRESENT	0
122231	121156	11096W	PARTICIPANT	\N	PRESENT	0
122232	121156	14031R	PARTICIPANT	\N	PRESENT	0
122233	121156	11012A	PARTICIPANT	\N	PRESENT	0
122234	121156	11101A	PARTICIPANT	\N	PRESENT	0
122235	121156	14201E	PARTICIPANT	\N	PRESENT	0
122236	121156	14261S	PARTICIPANT	\N	PRESENT	0
122237	121156	01057W	PARTICIPANT	\N	PRESENT	0
122238	121156	04074L	PARTICIPANT	\N	PRESENT	0
122239	121156	08016S	PARTICIPANT	\N	PRESENT	0
122240	121156	14173T	PARTICIPANT	\N	PRESENT	0
122241	121156	98035U	PARTICIPANT	\N	PRESENT	0
122242	121156	01016M	PARTICIPANT	\N	PRESENT	0
122243	121156	04056J	PARTICIPANT	\N	PRESENT	0
122244	121156	08069G	PARTICIPANT	\N	PRESENT	0
122245	121156	11039M	PARTICIPANT	\N	PRESENT	0
122246	121156	04059M	PARTICIPANT	\N	PRESENT	0
122247	121156	92040Q	PARTICIPANT	\N	PRESENT	0
122248	121156	98046X	PARTICIPANT	\N	PRESENT	0
122249	121156	08052W	PARTICIPANT	\N	PRESENT	0
122250	121156	95063L	PARTICIPANT	\N	PRESENT	0
122251	121156	08025T	PARTICIPANT	\N	PRESENT	0
122252	121156	14151M	PARTICIPANT	\N	PRESENT	0
122253	121156	08055A	PARTICIPANT	\N	PRESENT	0
122254	121156	01031L	PARTICIPANT	\N	PRESENT	0
122255	121156	14253S	PARTICIPANT	\N	PRESENT	0
122256	121156	14107H	PARTICIPANT	\N	PRESENT	0
122257	121156	11027H	PARTICIPANT	\N	PRESENT	0
122258	121156	01011G	PARTICIPANT	\N	PRESENT	0
122259	121156	11084S	PARTICIPANT	\N	PRESENT	0
122260	121156	92020L	PARTICIPANT	\N	PRESENT	0
122261	121156	08060W	PARTICIPANT	\N	PRESENT	0
122262	121156	14038Y	PARTICIPANT	\N	PRESENT	0
122263	121156	11057P	PARTICIPANT	\N	PRESENT	0
122264	121156	80013X	PARTICIPANT	\N	PRESENT	0
122265	121156	08068F	PARTICIPANT	\N	PRESENT	0
122266	121156	14028W	PARTICIPANT	\N	PRESENT	0
122267	121156	14105F	PARTICIPANT	\N	PRESENT	0
122268	121156	01022K	PARTICIPANT	\N	PRESENT	0
122269	121156	14197C	PARTICIPANT	\N	PRESENT	0
122270	121156	14065Q	PARTICIPANT	\N	PRESENT	0
122271	121156	14119M	PARTICIPANT	\N	PRESENT	0
122272	121156	11015D	PARTICIPANT	\N	PRESENT	0
122273	121156	11076S	PARTICIPANT	\N	PRESENT	0
122275	121156	08043V	PARTICIPANT	\N	PRESENT	0
122276	121156	11105E	PARTICIPANT	\N	PRESENT	0
122277	121156	08034U	PARTICIPANT	\N	PRESENT	0
122278	121156	14157T	PARTICIPANT	\N	PRESENT	0
122279	121156	11089X	PARTICIPANT	\N	PRESENT	0
122280	121156	08012N	PARTICIPANT	\N	PRESENT	0
122281	121156	14033T	PARTICIPANT	\N	PRESENT	0
122282	121156	11036J	PARTICIPANT	\N	PRESENT	0
122283	121156	80027E	PARTICIPANT	\N	PRESENT	0
122284	121156	08018U	PARTICIPANT	\N	PRESENT	0
122285	121156	14041T	PARTICIPANT	\N	PRESENT	0
122286	121156	98029W	PARTICIPANT	\N	PRESENT	0
122287	121156	11046L	PARTICIPANT	\N	PRESENT	0
122288	121156	04088S	PARTICIPANT	\N	PRESENT	0
122289	121156	08053X	PARTICIPANT	\N	PRESENT	0
122290	121156	11088W	PARTICIPANT	\N	PRESENT	0
122291	121156	04066L	PARTICIPANT	\N	PRESENT	0
122292	121156	08017T	PARTICIPANT	\N	PRESENT	0
122293	121156	14199E	PARTICIPANT	\N	PRESENT	0
122294	121156	04034C	PARTICIPANT	\N	PRESENT	0
122295	121156	95037J	PARTICIPANT	\N	PRESENT	0
122296	121156	08058D	PARTICIPANT	\N	PRESENT	0
122297	121156	83047W	PARTICIPANT	\N	PRESENT	0
122298	121156	07029T	PARTICIPANT	\N	PRESENT	0
122179	121156	04054G	PARTICIPANT	\N	PRESENT	0
122180	121156	11034G	PARTICIPANT	\N	PRESENT	0
122299	121156	11031D	PARTICIPANT	\N	PRESENT	0
122300	121156	98050T	PARTICIPANT	\N	PRESENT	0
122301	121156	11098Y	PARTICIPANT	\N	PRESENT	0
122302	121156	14014Q	PARTICIPANT	\N	PRESENT	0
122303	121156	14109K	PARTICIPANT	\N	PRESENT	0
122304	121156	08014Q	PARTICIPANT	\N	PRESENT	0
122305	121156	14001X	PARTICIPANT	\N	PRESENT	0
122306	121156	08062Y	PARTICIPANT	\N	PRESENT	0
122307	121156	14051J	PARTICIPANT	\N	PRESENT	0
122308	121156	08015R	PARTICIPANT	\N	PRESENT	0
122309	121156	11074Q	PARTICIPANT	\N	PRESENT	0
122310	121156	14213J	PARTICIPANT	\N	PRESENT	0
122311	121156	14147R	PARTICIPANT	\N	PRESENT	0
122312	121156	14167V	PARTICIPANT	\N	PRESENT	0
122313	121156	14265W	PARTICIPANT	\N	PRESENT	0
122314	121156	11054L	PARTICIPANT	\N	PRESENT	0
122315	121156	11091R	PARTICIPANT	\N	PRESENT	0
122316	121156	11059R	PARTICIPANT	\N	PRESENT	0
122317	121156	10015M	PARTICIPANT	\N	PRESENT	0
122318	121156	14227Q	PARTICIPANT	\N	PRESENT	0
122319	121156	14175V	PARTICIPANT	\N	PRESENT	0
122320	121156	14281W	PARTICIPANT	\N	PRESENT	0
122321	121156	11049P	PARTICIPANT	\N	PRESENT	0
122322	121156	92045V	PARTICIPANT	\N	PRESENT	0
122323	121156	11097X	PARTICIPANT	\N	PRESENT	0
122324	121156	04055H	PARTICIPANT	\N	PRESENT	0
122325	121156	14229S	PARTICIPANT	\N	PRESENT	0
122326	121156	08048B	PARTICIPANT	\N	PRESENT	0
122327	121156	14063N	PARTICIPANT	\N	PRESENT	0
122328	121156	04067M	PARTICIPANT	\N	PRESENT	0
122329	121156	98023Q	PARTICIPANT	\N	PRESENT	0
122330	121156	11112D	PARTICIPANT	\N	PRESENT	0
122334	121156	14251Q	PARTICIPANT	\N	PRESENT	0
122332	121156	11048N	PARTICIPANT	\N	PRESENT	0
122333	121156	14097Y	PARTICIPANT	\N	PRESENT	0
122335	121156	95067Q	PARTICIPANT	\N	PRESENT	0
122336	121156	14257W	PARTICIPANT	\N	PRESENT	0
122337	121156	11014C	PARTICIPANT	\N	PRESENT	0
122338	121156	14225N	PARTICIPANT	\N	PRESENT	0
122339	121156	01028R	PARTICIPANT	\N	PRESENT	0
122340	121156	08041T	PARTICIPANT	\N	PRESENT	0
122341	121156	04042C	PARTICIPANT	\N	PRESENT	0
122342	121156	04053F	PARTICIPANT	\N	PRESENT	0
122343	121156	11100Y	PARTICIPANT	\N	PRESENT	0
122344	121156	11032E	PARTICIPANT	\N	PRESENT	0
122345	121156	08038Y	PARTICIPANT	\N	PRESENT	0
122346	121156	11104D	PARTICIPANT	\N	PRESENT	0
122347	121156	11081P	PARTICIPANT	\N	PRESENT	0
93951	93950	14133K	PARTICIPANT	\N	PRESENT	0
93952	93950	14239U	PARTICIPANT	\N	PRESENT	0
93953	93950	14089Y	PARTICIPANT	\N	PRESENT	0
93954	93950	14217N	PARTICIPANT	\N	PRESENT	0
93955	93950	14281W	PRESIDENT	0	PRESENT	0
93956	93950	07004J	PARTICIPANT	\N	PRESENT	0
93957	93950	04061F	PARTICIPANT	\N	PRESENT	0
93958	93950	10015M	PARTICIPANT	\N	PRESENT	0
93959	93950	14269B	PARTICIPANT	\N	PRESENT	0
93960	93950	11054L	PARTICIPANT	\N	EXCUSE	0
118233	118232	14038Y	PARTICIPANT	\N	EXCUSE	0
118234	118232	11029K	PARTICIPANT	\N	EXCUSE	0
118235	118232	04057K	PARTICIPANT	\N	EXCUSE	0
118236	118232	14197C	PARTICIPANT	\N	EXCUSE	0
118237	118232	05012A	PARTICIPANT	\N	EXCUSE	0
118238	118232	14265W	PARTICIPANT	\N	EXCUSE	0
118239	118232	01044R	PARTICIPANT	\N	PRESENT	0
118240	118232	11036J	PARTICIPANT	\N	PRESENT	0
118241	118232	14219Q	PRESIDENT	\N	PRESENT	0
118242	118232	01015L	PARTICIPANT	\N	PRESENT	0
118243	118232	14030Q	PARTICIPANT	\N	EXCUSE	0
118244	118232	14107H	PARTICIPANT	\N	PRESENT	0
118246	118245	14038Y	PARTICIPANT	\N	EXCUSE	0
118247	118245	11029K	PARTICIPANT	\N	EXCUSE	0
118248	118245	04057K	PARTICIPANT	\N	EXCUSE	0
118249	118245	14197C	PARTICIPANT	\N	EXCUSE	0
118250	118245	05012A	PARTICIPANT	\N	EXCUSE	0
118251	118245	14265W	PARTICIPANT	\N	EXCUSE	0
118252	118245	01044R	PARTICIPANT	\N	PRESENT	0
118253	118245	11036J	PARTICIPANT	\N	PRESENT	0
118254	118245	14219Q	PRESIDENT	\N	PRESENT	0
118255	118245	01015L	PARTICIPANT	\N	PRESENT	0
118256	118245	14030Q	PARTICIPANT	\N	EXCUSE	0
118257	118245	14107H	PARTICIPANT	\N	PRESENT	0
121646	121645	11039M	PARTICIPANT	\N	PRESENT	0
121647	121645	08012N	PARTICIPANT	\N	PRESENT	0
121648	121645	11043H	PARTICIPANT	\N	PRESENT	0
121649	121645	14241N	PARTICIPANT	\N	PRESENT	0
125626	125523	92039X	PARTICIPANT	\N	PRESENT	0
125627	125523	14237S	PARTICIPANT	\N	PRESENT	0
125628	125523	14135M	PARTICIPANT	\N	PRESENT	0
125629	125523	14331P	PARTICIPANT	\N	PRESENT	0
125630	125523	95062K	PARTICIPANT	\N	PRESENT	0
125631	124157	14069U	PARTICIPANT	\N	PRESENT	0
125633	124157	01003G	PARTICIPANT	\N	PRESENT	0
125638	124157	01007L	PARTICIPANT	\N	PRESENT	0
125639	124157	08068F	PARTICIPANT	\N	PRESENT	0
125640	124157	11101A	PARTICIPANT	\N	PRESENT	0
125641	124157	07032N	PARTICIPANT	\N	PRESENT	0
125642	124157	14329V	PARTICIPANT	\N	PRESENT	0
125643	124157	08055A	PARTICIPANT	\N	PRESENT	0
125644	124157	98046X	PARTICIPANT	\N	PRESENT	0
125645	124157	10015M	PARTICIPANT	\N	PRESENT	0
125646	124157	88008L	PARTICIPANT	\N	PRESENT	0
125647	124157	95049N	PARTICIPANT	\N	PRESENT	0
125648	124157	14241N	PARTICIPANT	\N	PRESENT	0
125649	124157	14073Q	PARTICIPANT	\N	PRESENT	0
125650	124157	11029K	PARTICIPANT	\N	PRESENT	0
125651	124157	14237S	PARTICIPANT	\N	PRESENT	0
125655	124157	08051V	PARTICIPANT	\N	PRESENT	0
125669	124157	14085U	PARTICIPANT	\N	PRESENT	0
125674	124157	14089Y	PARTICIPANT	\N	PRESENT	0
125675	124860	01058X	PARTICIPANT	\N	PRESENT	0
125676	125334	14271U	PARTICIPANT	\N	PRESENT	0
125678	124157	11043H	PARTICIPANT	\N	PRESENT	0
125679	124157	14018U	PARTICIPANT	\N	PRESENT	0
125743	124157	01019Q	PARTICIPANT	\N	PRESENT	0
125685	125683	14133K	PARTICIPANT	\N	PRESENT	0
125750	125683	14263U	PARTICIPANT	\N	EXCUSE	0
125751	125749	11048N	PARTICIPANT	\N	PRESENT	0
125752	124157	08039A	PARTICIPANT	\N	PRESENT	0
125689	125683	01044R	PARTICIPANT	\N	PRESENT	0
125753	124157	86044G	PARTICIPANT	\N	PRESENT	0
125691	125683	14089Y	PARTICIPANT	\N	PRESENT	0
125754	124157	04057K	PARTICIPANT	\N	PRESENT	0
125693	125683	11029K	PARTICIPANT	\N	PRESENT	0
125755	123942	14231L	PARTICIPANT	\N	EXCUSE	0
125695	125683	92015P	PARTICIPANT	\N	PRESENT	0
125756	124157	11082Q	PARTICIPANT	\N	PRESENT	0
125757	124157	14030Q	PARTICIPANT	\N	PRESENT	0
125758	124157	95067Q	PARTICIPANT	\N	PRESENT	0
125759	124157	89017R	PARTICIPANT	\N	PRESENT	0
125760	124157	01047U	PARTICIPANT	\N	PRESENT	0
125761	124157	14014Q	PARTICIPANT	\N	PRESENT	0
125702	125683	87003B	PARTICIPANT	\N	PRESENT	0
125775	124158	98053W	PARTICIPANT	\N	PRESENT	0
125773	120697	11106F	PARTICIPANT	\N	EXCUSE	0
125774	125683	11011M	PARTICIPANT	\N	PRESENT	0
125776	124158	11034G	PARTICIPANT	\N	PRESENT	0
125707	125683	01037S	PARTICIPANT	\N	EXCUSE	0
125777	124158	14231L	PARTICIPANT	\N	PRESENT	0
125778	124158	14187A	PARTICIPANT	\N	PRESENT	0
125710	125683	11089X	PARTICIPANT	\N	PRESENT	0
125779	124158	11100Y	PARTICIPANT	\N	PRESENT	0
125712	125683	14123H	PARTICIPANT	\N	PRESENT	0
125713	125683	14179A	PARTICIPANT	\N	PRESENT	0
125780	124158	14235Q	PARTICIPANT	\N	PRESENT	0
125715	125683	14241N	PARTICIPANT	\N	PRESENT	0
125716	125683	14061L	PARTICIPANT	\N	PRESENT	0
125781	124158	11098Y	PARTICIPANT	\N	PRESENT	0
125782	124158	11084S	PARTICIPANT	\N	PRESENT	0
125783	124158	11032E	PARTICIPANT	\N	PRESENT	0
125720	125683	08039A	PARTICIPANT	\N	PRESENT	0
125721	125683	08017T	PARTICIPANT	\N	PRESENT	0
125722	125683	14059S	PARTICIPANT	\N	PRESENT	0
125784	124158	14269B	PARTICIPANT	\N	PRESENT	0
125785	124158	11104D	PARTICIPANT	\N	PRESENT	0
125786	124158	98046X	PARTICIPANT	\N	PRESENT	0
125726	125683	14063N	PARTICIPANT	\N	PRESENT	0
125727	125683	04057K	PARTICIPANT	\N	PRESENT	0
125787	124158	14257W	PARTICIPANT	\N	PRESENT	0
125788	124158	80013X	PARTICIPANT	\N	PRESENT	0
125730	125683	04070G	PRESIDENT	0	PRESENT	0
125789	124158	14219Q	PARTICIPANT	\N	PRESENT	0
125790	124158	14327T	PARTICIPANT	\N	PRESENT	0
125791	124158	04070G	PARTICIPANT	\N	PRESENT	0
125792	124158	11055M	PARTICIPANT	\N	PRESENT	0
125793	124158	14215L	PARTICIPANT	\N	PRESENT	0
125794	124158	14079W	PARTICIPANT	\N	PRESENT	0
125795	124158	04086Q	PARTICIPANT	\N	PRESENT	0
125738	125683	11043H	PARTICIPANT	\N	PRESENT	0
125796	124158	14217N	PARTICIPANT	\N	PRESENT	0
125797	124158	14265W	PARTICIPANT	\N	PRESENT	0
125798	124158	14329V	PARTICIPANT	\N	PRESENT	0
125799	124158	01027Q	PARTICIPANT	\N	PRESENT	0
125800	124158	14069U	PARTICIPANT	\N	PRESENT	0
125801	124158	07034Q	PARTICIPANT	\N	PRESENT	0
125802	124158	07032N	PARTICIPANT	\N	PRESENT	0
125803	124158	04089T	PARTICIPANT	\N	PRESENT	0
125804	124158	14059S	PARTICIPANT	\N	PRESENT	0
125805	124158	04035D	PARTICIPANT	\N	PRESENT	0
125806	124158	11043H	PARTICIPANT	\N	PRESENT	0
125807	124158	14207L	PARTICIPANT	\N	PRESENT	0
125808	124158	08068F	PARTICIPANT	\N	PRESENT	0
125809	124158	14030Q	PARTICIPANT	\N	PRESENT	0
125810	124158	04047H	PARTICIPANT	\N	PRESENT	0
125811	124158	08031R	PARTICIPANT	\N	PRESENT	0
125812	124158	11089X	PARTICIPANT	\N	PRESENT	0
125813	124158	14014Q	PARTICIPANT	\N	PRESENT	0
125814	124158	14119M	PARTICIPANT	\N	PRESENT	0
125815	124158	08015R	PARTICIPANT	\N	PRESENT	0
125816	124158	14213J	PARTICIPANT	\N	PRESENT	0
125817	124158	01031L	PARTICIPANT	\N	PRESENT	0
125818	124158	14073Q	PARTICIPANT	\N	PRESENT	0
125819	124158	11066Q	PARTICIPANT	\N	PRESENT	0
125820	124158	11056N	PARTICIPANT	\N	PRESENT	0
125821	124158	04067M	PARTICIPANT	\N	PRESENT	0
125822	124158	14083S	PARTICIPANT	\N	PRESENT	0
125823	124158	95015C	PARTICIPANT	\N	PRESENT	0
125824	124158	04033B	PARTICIPANT	\N	PRESENT	0
125825	124158	01028R	PARTICIPANT	\N	PRESENT	0
125826	124158	11061K	PARTICIPANT	\N	PRESENT	0
125827	124158	14033T	PARTICIPANT	\N	PRESENT	0
125828	124158	14205J	PARTICIPANT	\N	PRESENT	0
125829	124158	14061L	PARTICIPANT	\N	PRESENT	0
125830	124158	11046L	PARTICIPANT	\N	PRESENT	0
125831	124158	14081Q	PARTICIPANT	\N	PRESENT	0
125832	124158	11026G	PARTICIPANT	\N	PRESENT	0
125833	124158	11097X	PARTICIPANT	\N	PRESENT	0
125834	124158	04088S	PARTICIPANT	\N	PRESENT	0
125835	124158	04049K	PARTICIPANT	\N	PRESENT	0
125836	124158	08010L	PARTICIPANT	\N	PRESENT	0
125837	124158	11031D	PARTICIPANT	\N	PRESENT	0
125838	124158	09001P	PARTICIPANT	\N	PRESENT	0
125839	124158	05008E	PARTICIPANT	\N	PRESENT	0
125840	124158	14089Y	PARTICIPANT	\N	PRESENT	0
125841	124158	14179A	PARTICIPANT	\N	PRESENT	0
125842	124158	04059M	PARTICIPANT	\N	PRESENT	0
125843	124158	11112D	PARTICIPANT	\N	PRESENT	0
111192	103971	01046T	PARTICIPANT	\N	PRESENT	0
111194	103971	11036J	PARTICIPANT	\N	PRESENT	0
111195	103971	11068S	PARTICIPANT	\N	EXCUSE	0
111196	103971	14209N	PARTICIPANT	\N	PRESENT	0
111197	103971	80013X	PARTICIPANT	\N	PRESENT	0
111198	103971	11089X	PARTICIPANT	\N	PRESENT	0
111199	103971	14299H	PARTICIPANT	\N	PRESENT	0
111200	103971	04061F	PARTICIPANT	\N	EXCUSE	0
111202	103971	14257W	PARTICIPANT	\N	EXCUSE	0
111203	103971	01058X	PARTICIPANT	\N	PRESENT	0
111205	103971	11082Q	PARTICIPANT	\N	PRESENT	0
111206	103971	04043D	PARTICIPANT	\N	PRESENT	0
111207	103971	14263U	PARTICIPANT	\N	PRESENT	0
111208	103971	01048V	PARTICIPANT	\N	EXCUSE	0
111209	103971	14221J	PARTICIPANT	\N	EXCUSE	0
111210	103971	08069G	PARTICIPANT	\N	EXCUSE	0
111211	103971	11061K	PARTICIPANT	\N	EXCUSE	0
118448	118378	11090Q	PARTICIPANT	\N	PRESENT	0
118473	118472	14261S	PARTICIPANT	\N	PRESENT	0
118474	118472	08055A	PARTICIPANT	\N	PRESENT	0
118475	118472	14093U	PARTICIPANT	\N	PRESENT	0
118476	118472	14030Q	PARTICIPANT	\N	PRESENT	0
118477	118472	96004D	PARTICIPANT	\N	PRESENT	0
118478	118472	08060W	PARTICIPANT	\N	PRESENT	0
118479	118472	11095V	PARTICIPANT	\N	PRESENT	0
118480	118472	14038Y	PARTICIPANT	\N	PRESENT	0
118481	118472	11114F	PARTICIPANT	\N	PRESENT	0
118722	118472	09001P	PARTICIPANT	\N	EXCUSE	0
118725	118472	11059R	PARTICIPANT	\N	EXCUSE	0
118484	118472	01015L	PARTICIPANT	\N	PRESENT	0
118485	118472	11107G	PARTICIPANT	\N	PRESENT	0
118726	118472	96003C	PARTICIPANT	\N	EXCUSE	0
118487	118472	02002K	PARTICIPANT	\N	PRESENT	0
118488	118472	01022K	PARTICIPANT	\N	PRESENT	0
118489	118472	04097T	PARTICIPANT	\N	PRESENT	0
119971	119970	11015D	PARTICIPANT	\N	PRESENT	0
123554	123540	09001P	PRESIDENT	0	PRESENT	0
118492	118472	14219Q	PARTICIPANT	\N	PRESENT	0
118493	118472	80027E	PARTICIPANT	\N	PRESENT	0
118494	118472	14031R	PARTICIPANT	\N	PRESENT	0
118495	118472	08009T	PARTICIPANT	\N	PRESENT	0
118496	118472	08062Y	PARTICIPANT	\N	PRESENT	0
123556	123540	08031R	PARTICIPANT	\N	PRESENT	0
118734	118730	01044R	PARTICIPANT	\N	PRESENT	0
118499	118472	08042U	PARTICIPANT	\N	PRESENT	0
118500	118472	14169X	PARTICIPANT	\N	PRESENT	0
118501	118472	14237S	PARTICIPANT	\N	PRESENT	0
118502	118472	13002U	PARTICIPANT	\N	PRESENT	0
118503	118472	05012A	PARTICIPANT	\N	PRESENT	0
120456	120453	05008E	PRESIDENT	0	PRESENT	0
118505	118472	14135M	PARTICIPANT	\N	PRESENT	0
118506	118472	14331P	PARTICIPANT	\N	PRESENT	0
118507	118472	95062K	PARTICIPANT	\N	PRESENT	0
118508	118472	14107H	PARTICIPANT	\N	PRESENT	0
118736	118730	11029K	PARTICIPANT	\N	PRESENT	0
118510	118472	14157T	PARTICIPANT	\N	PRESENT	0
123555	123540	04036E	PARTICIPANT	\N	EXCUSE	0
118738	118730	80013X	PARTICIPANT	\N	EXCUSE	0
118739	118730	01015L	PARTICIPANT	\N	PRESENT	0
118740	118730	14197C	PARTICIPANT	\N	EXCUSE	0
123557	123540	07029T	PARTICIPANT	\N	EXCUSE	0
118742	118730	14219Q	PARTICIPANT	\N	PRESENT	0
118743	118730	14031R	PARTICIPANT	\N	EXCUSE	0
118744	118730	14273W	PARTICIPANT	\N	PRESENT	0
120459	120453	14065Q	PARTICIPANT	\N	PRESENT	0
118746	118730	04057K	PARTICIPANT	\N	EXCUSE	0
118747	118730	92039X	PARTICIPANT	\N	PRESENT	0
118748	118730	14265W	PARTICIPANT	\N	EXCUSE	0
118749	118730	14237S	PARTICIPANT	\N	PRESENT	0
118750	118730	05012A	PARTICIPANT	\N	EXCUSE	0
120460	120453	14069U	PARTICIPANT	\N	PRESENT	0
123558	123540	11014C	PARTICIPANT	\N	EXCUSE	0
118753	118730	14107H	PARTICIPANT	\N	PRESENT	0
123560	123559	96004D	PARTICIPANT	\N	EXCUSE	0
120463	120453	04038G	PARTICIPANT	\N	PRESENT	0
118756	118730	08049C	PARTICIPANT	\N	PRESENT	0
123561	123559	14089Y	PARTICIPANT	\N	PRESENT	0
123562	123559	14079W	PARTICIPANT	\N	PRESENT	0
120466	120453	14259Y	PARTICIPANT	\N	PRESENT	0
123563	123559	11035H	PARTICIPANT	\N	PRESENT	0
120468	120453	14041T	PARTICIPANT	\N	PRESENT	0
120469	120453	11113E	PARTICIPANT	\N	PRESENT	0
120470	120453	01024M	PARTICIPANT	\N	PRESENT	0
120471	120453	14215L	PARTICIPANT	\N	PRESENT	0
123564	123559	11083R	PARTICIPANT	\N	PRESENT	0
123565	123559	14097Y	PARTICIPANT	\N	PRESENT	0
120474	120453	11010L	PARTICIPANT	\N	PRESENT	0
120475	120453	01007L	PARTICIPANT	\N	PRESENT	0
120476	120453	11049P	PARTICIPANT	\N	PRESENT	0
123566	123559	14073Q	PARTICIPANT	\N	PRESENT	0
120478	120453	11084S	PARTICIPANT	\N	PRESENT	0
120479	120453	11026G	PARTICIPANT	\N	PRESENT	0
120480	120453	04079R	PARTICIPANT	\N	PRESENT	0
120481	120453	14111D	PARTICIPANT	\N	PRESENT	0
123567	123559	14001X	PARTICIPANT	\N	PRESENT	0
123568	123559	04057K	PRESIDENT	0	PRESENT	0
123569	123559	14135M	PARTICIPANT	\N	PRESENT	0
120485	120453	14147R	PARTICIPANT	\N	PRESENT	0
120486	120453	95049N	PARTICIPANT	\N	PRESENT	0
120487	120453	08051V	PARTICIPANT	\N	PRESENT	0
120488	120453	11072N	PARTICIPANT	\N	PRESENT	0
120489	120453	07034Q	PARTICIPANT	\N	PRESENT	0
120490	120453	04074L	PARTICIPANT	\N	PRESENT	0
120491	120453	10015M	PARTICIPANT	\N	PRESENT	0
120492	120453	95063L	PARTICIPANT	\N	PRESENT	0
120493	120453	01019Q	PARTICIPANT	\N	PRESENT	0
120494	120453	01028R	PARTICIPANT	\N	PRESENT	0
123570	123559	01016M	PARTICIPANT	\N	PRESENT	0
120496	120453	04056J	PARTICIPANT	\N	PRESENT	0
123571	123559	04034C	PARTICIPANT	\N	PRESENT	0
120498	120453	04044E	PARTICIPANT	\N	PRESENT	0
123572	123559	04045F	PARTICIPANT	\N	EXCUSE	0
120500	120453	92045V	PARTICIPANT	\N	PRESENT	0
123573	123559	10015M	PARTICIPANT	\N	EXCUSE	0
123574	123559	11026G	PARTICIPANT	\N	EXCUSE	0
123575	123559	98046X	PARTICIPANT	\N	EXCUSE	0
123576	123559	08018U	PARTICIPANT	\N	EXCUSE	0
123577	123559	90003B	PARTICIPANT	\N	EXCUSE	0
123580	121715	14207L	PARTICIPANT	\N	PRESENT	0
123581	121718	11090Q	PARTICIPANT	\N	PRESENT	0
123582	123237	08069G	PARTICIPANT	\N	EXCUSE	0
123721	123720	14261S	PARTICIPANT	\N	PRESENT	0
124190	124189	04043D	PARTICIPANT	\N	PRESENT	0
123723	123720	14093U	PARTICIPANT	\N	PRESENT	0
123724	123720	14030Q	PARTICIPANT	\N	PRESENT	0
124191	124189	98005N	PARTICIPANT	\N	PRESENT	0
124192	124189	11036J	PARTICIPANT	\N	PRESENT	0
123727	123720	11095V	PARTICIPANT	\N	EXCUSE	0
123728	123720	14038Y	PARTICIPANT	\N	EXCUSE	0
124193	124189	14219Q	PARTICIPANT	\N	PRESENT	0
123730	123720	98023Q	PARTICIPANT	\N	PRESENT	0
124887	124886	14239U	PARTICIPANT	\N	PRESENT	0
123732	123720	01015L	PARTICIPANT	\N	PRESENT	0
123733	123720	11107G	PARTICIPANT	\N	PRESENT	0
124888	124886	11055M	PARTICIPANT	\N	PRESENT	0
123735	123720	02002K	PARTICIPANT	\N	PRESENT	0
123736	123720	01022K	PARTICIPANT	\N	EXCUSE	0
124889	124886	01046T	PARTICIPANT	\N	PRESENT	0
123738	123720	09001P	PARTICIPANT	\N	PRESENT	0
124890	124886	04053F	PARTICIPANT	\N	PRESENT	0
123740	123720	14219Q	PARTICIPANT	\N	PRESENT	0
123741	123720	80027E	PARTICIPANT	\N	PRESENT	0
124891	124886	14255U	PARTICIPANT	\N	PRESENT	0
123743	123720	08009T	PRESIDENT	0	PRESENT	0
123744	123720	08062Y	PARTICIPANT	\N	PRESENT	0
124893	124886	00003C	PARTICIPANT	\N	EXCUSE	0
123747	123720	08042U	PARTICIPANT	\N	PRESENT	0
124894	124886	14053L	PARTICIPANT	\N	PRESENT	0
123749	123720	14237S	PARTICIPANT	\N	PRESENT	0
123750	123720	13002U	PARTICIPANT	\N	PRESENT	0
123751	123720	05012A	PARTICIPANT	\N	PRESENT	0
124895	124886	11103C	PARTICIPANT	\N	PRESENT	0
123753	123720	14135M	PARTICIPANT	\N	PRESENT	0
123754	123720	14331P	PARTICIPANT	\N	EXCUSE	0
123755	123720	95062K	PARTICIPANT	\N	PRESENT	0
123756	123720	14107H	PARTICIPANT	\N	PRESENT	0
123757	123720	14051J	PARTICIPANT	\N	PRESENT	0
123758	123720	14157T	PARTICIPANT	\N	PRESENT	0
123759	123720	96003C	PARTICIPANT	\N	EXCUSE	0
124896	124886	11044J	PARTICIPANT	\N	PRESENT	0
124897	124886	14195A	PARTICIPANT	\N	PRESENT	0
104992	104892	14065Q	PARTICIPANT	\N	PRESENT	0
104993	104892	08022Q	PARTICIPANT	\N	PRESENT	0
104994	104892	08069G	PARTICIPANT	\N	PRESENT	0
104996	104995	11076S	PARTICIPANT	\N	PRESENT	0
104997	104995	04054G	PARTICIPANT	\N	PRESENT	0
104998	104995	04040A	PARTICIPANT	\N	PRESENT	0
104999	104995	08058D	PARTICIPANT	\N	PRESENT	0
105000	104995	04042C	PARTICIPANT	\N	EXCUSE	0
105001	104995	77002U	PARTICIPANT	\N	PRESENT	0
115899	115892	87003B	PARTICIPANT	\N	PRESENT	0
105003	104995	11080N	PARTICIPANT	\N	PRESENT	0
105004	104995	11027H	PARTICIPANT	\N	PRESENT	0
115900	115892	14199E	PARTICIPANT	\N	PRESENT	0
105006	104995	92018S	PARTICIPANT	\N	PRESENT	0
105007	104995	92020L	PARTICIPANT	\N	PRESENT	0
105008	104995	95030B	PARTICIPANT	\N	PRESENT	0
105009	104995	11096W	PARTICIPANT	\N	PRESENT	0
115901	115892	11112D	PARTICIPANT	\N	PRESENT	0
105011	104995	97011G	PARTICIPANT	\N	PRESENT	0
105012	104995	08065C	PARTICIPANT	\N	PRESENT	0
105013	104995	04035D	PARTICIPANT	\N	EXCUSE	0
105014	104995	07024N	PARTICIPANT	\N	PRESENT	0
105015	104995	04095R	PARTICIPANT	\N	PRESENT	0
105016	104995	14014Q	PARTICIPANT	\N	PRESENT	0
105017	104995	11015D	PARTICIPANT	\N	PRESENT	0
105018	104995	07004J	PARTICIPANT	\N	PRESENT	0
105019	104995	95035G	PARTICIPANT	\N	PRESENT	0
105020	104995	08056B	PARTICIPANT	\N	PRESENT	0
105021	104995	14211G	PARTICIPANT	\N	PRESENT	0
105022	104995	98022P	PARTICIPANT	\N	PRESENT	0
105023	104995	11064N	PARTICIPANT	\N	PRESENT	0
105024	104995	95037J	PARTICIPANT	\N	PRESENT	0
115902	115892	14059S	PARTICIPANT	\N	PRESENT	0
105026	104995	14097Y	PARTICIPANT	\N	PRESENT	0
115903	115892	14063N	PARTICIPANT	\N	PRESENT	0
105028	104995	04036E	PARTICIPANT	\N	PRESENT	0
105029	104995	14039A	PARTICIPANT	\N	PRESENT	0
105030	104995	04077P	PARTICIPANT	\N	PRESENT	0
105031	104995	98005N	PARTICIPANT	\N	PRESENT	0
105032	104995	92031P	PARTICIPANT	\N	PRESENT	0
105033	104995	11106F	PARTICIPANT	\N	PRESENT	0
105034	104995	14251Q	PARTICIPANT	\N	PRESENT	0
105035	104995	83042R	PARTICIPANT	\N	PRESENT	0
105036	104995	08053X	PARTICIPANT	\N	PRESENT	0
105037	104995	11082Q	PARTICIPANT	\N	EXCUSE	0
105038	104995	11105E	PARTICIPANT	\N	PRESENT	0
105039	104995	14253S	PARTICIPANT	\N	PRESENT	0
105040	104995	08047A	PARTICIPANT	\N	EXCUSE	0
105041	104995	14028W	PARTICIPANT	\N	PRESENT	0
105042	104995	14193X	PARTICIPANT	\N	PRESENT	0
105043	104995	98021N	PARTICIPANT	\N	PRESENT	0
105044	104995	04080J	PARTICIPANT	\N	PRESENT	0
105045	104995	95059Q	PRESIDENT	0	PRESENT	0
105046	104995	86044G	PARTICIPANT	\N	PRESENT	0
105047	104995	01014K	PARTICIPANT	\N	PRESENT	0
105048	104995	11054L	PARTICIPANT	\N	PRESENT	0
105049	104995	01056V	PARTICIPANT	\N	PRESENT	0
115904	115892	14273W	PARTICIPANT	\N	PRESENT	0
105051	104995	08049C	PARTICIPANT	\N	PRESENT	0
105052	104995	04050C	PARTICIPANT	\N	PRESENT	0
115905	115892	08053X	PARTICIPANT	\N	PRESENT	0
115906	115892	14119M	PARTICIPANT	\N	PRESENT	0
115907	115892	98050T	PARTICIPANT	\N	PRESENT	0
115908	115892	14331P	PARTICIPANT	\N	PRESENT	0
115909	115892	14107H	PARTICIPANT	\N	PRESENT	0
115910	115892	01056V	PARTICIPANT	\N	PRESENT	0
115911	115892	92045V	PARTICIPANT	\N	PRESENT	0
121319	121318	11057P	PARTICIPANT	\N	PRESENT	0
121366	121365	01031L	PARTICIPANT	\N	PRESENT	0
121621	121069	08068F	PARTICIPANT	\N	PRESENT	0
121626	121069	08022Q	PARTICIPANT	\N	EXCUSE	0
121628	121069	04061F	PARTICIPANT	\N	EXCUSE	0
121629	121069	99004R	PARTICIPANT	\N	EXCUSE	0
121635	121634	14331P	PARTICIPANT	\N	PRESENT	0
121637	121636	14331P	PARTICIPANT	\N	PRESENT	0
121644	121643	14331P	PARTICIPANT	\N	PRESENT	0
122348	121156	14018U	PARTICIPANT	\N	PRESENT	0
122349	121156	14055N	PARTICIPANT	\N	PRESENT	0
122350	121156	89029V	PARTICIPANT	\N	PRESENT	0
122351	121156	08024S	PARTICIPANT	\N	PRESENT	0
122352	121156	11035H	PARTICIPANT	\N	PRESENT	0
122353	121156	92039X	PARTICIPANT	\N	PRESENT	0
122354	121156	11068S	PARTICIPANT	\N	PRESENT	0
122355	121156	04071H	PARTICIPANT	\N	PRESENT	0
122356	121156	11106F	PARTICIPANT	\N	PRESENT	0
122357	121156	14085U	PARTICIPANT	\N	PRESENT	0
122358	121156	11066Q	PARTICIPANT	\N	PRESENT	0
122359	121156	14271U	PARTICIPANT	\N	PRESENT	0
122360	121156	11077T	PARTICIPANT	\N	PRESENT	0
122361	121156	95015C	PARTICIPANT	\N	PRESENT	0
122362	121156	02002K	PARTICIPANT	\N	PRESENT	0
122363	121156	11042G	PARTICIPANT	\N	PRESENT	0
122364	121156	08035V	PARTICIPANT	\N	PRESENT	0
122365	121156	14207L	PARTICIPANT	\N	PRESENT	0
122366	121156	04095R	PARTICIPANT	\N	PRESENT	0
122367	121156	04094Q	PARTICIPANT	\N	PRESENT	0
122368	121156	14159V	PARTICIPANT	\N	PRESENT	0
122369	121156	14269B	PARTICIPANT	\N	PRESENT	0
122370	121156	01014K	PARTICIPANT	\N	PRESENT	0
122371	121156	11107G	PARTICIPANT	\N	PRESENT	0
122372	121156	01058X	PARTICIPANT	\N	PRESENT	0
122373	121156	95059Q	PARTICIPANT	\N	PRESENT	0
122374	121156	12042Y	PARTICIPANT	\N	PRESENT	0
122375	121156	11109J	PARTICIPANT	\N	PRESENT	0
122376	121156	95030B	PARTICIPANT	\N	PRESENT	0
122377	121156	11072N	PARTICIPANT	\N	PRESENT	0
122378	121156	11023D	PARTICIPANT	\N	PRESENT	0
122379	121156	98024R	PARTICIPANT	\N	PRESENT	0
122380	121156	01037S	PARTICIPANT	\N	PRESENT	0
122381	121156	01043Q	PARTICIPANT	\N	PRESENT	0
122382	121156	14030Q	PARTICIPANT	\N	PRESENT	0
122383	121156	14026U	PARTICIPANT	\N	PRESENT	0
122384	121156	14221J	PARTICIPANT	\N	PRESENT	0
122385	121156	04047H	PARTICIPANT	\N	PRESENT	0
122386	121156	77002U	PARTICIPANT	\N	PRESENT	0
122387	121156	14239U	PARTICIPANT	\N	PRESENT	0
122388	121156	04044E	PARTICIPANT	\N	PRESENT	0
122389	121156	04038G	PARTICIPANT	\N	PRESENT	0
122390	121156	11033F	PARTICIPANT	\N	PRESENT	0
122391	121156	08022Q	PARTICIPANT	\N	PRESENT	0
122392	121156	98018T	PARTICIPANT	\N	PRESENT	0
122393	121156	14267Y	PARTICIPANT	\N	PRESENT	0
122394	121156	86044G	PARTICIPANT	\N	PRESENT	0
122395	121156	14219Q	PARTICIPANT	\N	PRESENT	0
122396	121156	04033B	PARTICIPANT	\N	PRESENT	0
122397	121156	14042U	PARTICIPANT	\N	PRESENT	0
122398	121156	10006L	PARTICIPANT	\N	PRESENT	0
122399	121156	14103D	PARTICIPANT	\N	PRESENT	0
122400	121156	04086Q	PARTICIPANT	\N	PRESENT	0
122401	121156	11070L	PARTICIPANT	\N	PRESENT	0
122402	121156	05008E	PARTICIPANT	\N	PRESENT	0
122403	121156	11064N	PARTICIPANT	\N	PRESENT	0
122404	121156	04080J	PARTICIPANT	\N	PRESENT	0
122405	121156	92031P	PARTICIPANT	\N	PRESENT	0
122406	121156	04040A	PARTICIPANT	\N	PRESENT	0
122407	121156	14071N	PARTICIPANT	\N	PRESENT	0
122408	121156	11110B	PARTICIPANT	\N	PRESENT	0
122409	121156	14069U	PARTICIPANT	\N	PRESENT	0
122410	121156	07004J	PARTICIPANT	\N	PRESENT	0
122411	121156	05004A	PARTICIPANT	\N	PRESENT	0
122412	121156	01060R	PARTICIPANT	\N	PRESENT	0
122413	121156	04081K	PARTICIPANT	\N	PRESENT	0
122414	121156	11094U	PARTICIPANT	\N	PRESENT	0
122415	121156	95049N	PARTICIPANT	\N	PRESENT	0
122416	121156	04043D	PARTICIPANT	\N	PRESENT	0
122417	121156	05012A	PARTICIPANT	\N	PRESENT	0
122418	121156	01007L	PARTICIPANT	\N	PRESENT	0
122419	121156	04057K	PARTICIPANT	\N	PRESENT	0
122420	121156	14327T	PARTICIPANT	\N	PRESENT	0
122421	121156	01025N	PARTICIPANT	\N	PRESENT	0
122422	121156	14331P	PARTICIPANT	\N	PRESENT	0
122423	121156	01024M	PARTICIPANT	\N	PRESENT	0
122424	121156	01047U	PARTICIPANT	\N	PRESENT	0
122425	121156	08009T	PARTICIPANT	\N	PRESENT	0
122426	121156	14255U	PARTICIPANT	\N	PRESENT	0
122427	121156	98021N	PARTICIPANT	\N	PRESENT	0
122428	121156	01034P	PARTICIPANT	\N	PRESENT	0
122429	121156	98042T	PARTICIPANT	\N	PRESENT	0
122430	121156	04089T	PARTICIPANT	\N	PRESENT	0
122431	121156	14179A	PARTICIPANT	\N	PRESENT	0
122432	121156	97011G	PARTICIPANT	\N	PRESENT	0
122433	121156	14073Q	PARTICIPANT	\N	PRESENT	0
122434	121156	14079W	PARTICIPANT	\N	PRESENT	0
122435	121156	14231L	PARTICIPANT	\N	PRESENT	0
113713	113712	88008L	PARTICIPANT	\N	PRESENT	0
113714	113712	14028W	PARTICIPANT	\N	PRESENT	0
113715	113712	11012A	PARTICIPANT	\N	PRESENT	0
113733	113732	04054G	PARTICIPANT	\N	PRESENT	0
113734	113732	96004D	PRESIDENT	0	PRESENT	0
113735	113732	14089Y	PARTICIPANT	\N	PRESENT	0
113736	113732	90003B	PARTICIPANT	\N	EXCUSE	0
113737	113732	14079W	PARTICIPANT	\N	PRESENT	0
113738	113732	11035H	PARTICIPANT	\N	PRESENT	0
113739	113732	14249W	PARTICIPANT	\N	PRESENT	0
113740	113732	95030B	PARTICIPANT	\N	PRESENT	0
113741	113732	08018U	PARTICIPANT	\N	EXCUSE	0
113742	113732	04035D	PARTICIPANT	\N	EXCUSE	0
113743	113732	11083R	PARTICIPANT	\N	PRESENT	0
113744	113732	14026U	PARTICIPANT	\N	PRESENT	0
113745	113732	14097Y	PARTICIPANT	\N	PRESENT	0
113746	113732	14073Q	PARTICIPANT	\N	PRESENT	0
113747	113732	14001X	PARTICIPANT	\N	PRESENT	0
113748	113732	04057K	PARTICIPANT	\N	PRESENT	0
113749	113732	08042U	PARTICIPANT	\N	EXCUSE	0
113750	113732	04080J	PARTICIPANT	\N	PRESENT	0
113751	113732	14135M	PARTICIPANT	\N	PRESENT	0
113752	113732	01016M	PARTICIPANT	\N	PRESENT	0
113753	113732	10015M	PARTICIPANT	\N	PRESENT	0
113754	113732	11012A	PARTICIPANT	\N	PRESENT	0
113755	113732	04045F	PARTICIPANT	\N	PRESENT	0
113756	113732	98035U	PARTICIPANT	\N	PRESENT	0
113757	113732	92045V	PARTICIPANT	\N	PRESENT	0
113758	113732	04034C	PARTICIPANT	\N	PRESENT	0
113759	113732	14331P	PARTICIPANT	\N	PRESENT	0
113760	113732	95067Q	PARTICIPANT	\N	PRESENT	0
113761	113732	14065Q	PARTICIPANT	\N	PRESENT	0
113762	113732	92031P	PARTICIPANT	\N	PRESENT	0
113763	113732	97011G	PARTICIPANT	\N	PRESENT	0
113764	113732	14271U	PARTICIPANT	\N	PRESENT	0
113772	113732	11066Q	PARTICIPANT	\N	PRESENT	0
113773	113732	14051J	PARTICIPANT	\N	PRESENT	0
113774	113732	14237S	PARTICIPANT	\N	PRESENT	0
113775	113732	14179A	PARTICIPANT	\N	PRESENT	0
113776	113732	14071N	PARTICIPANT	\N	PRESENT	0
113777	113732	14215L	PARTICIPANT	\N	PRESENT	0
113778	113732	04089T	PARTICIPANT	\N	PRESENT	0
113779	113732	14281W	PARTICIPANT	\N	PRESENT	0
113780	113732	14257W	PARTICIPANT	\N	PRESENT	0
113781	113732	14263U	PARTICIPANT	\N	PRESENT	0
113782	113732	01008M	PARTICIPANT	\N	PRESENT	0
113783	113732	04042C	PARTICIPANT	\N	PRESENT	0
125844	124158	14053L	PARTICIPANT	\N	PRESENT	0
125845	124158	08051V	PARTICIPANT	\N	PRESENT	0
125846	124158	11083R	PARTICIPANT	\N	PRESENT	0
125847	124158	10006L	PARTICIPANT	\N	PRESENT	0
125848	124158	88008L	PARTICIPANT	\N	PRESENT	0
125849	124158	11094U	PARTICIPANT	\N	PRESENT	0
125850	124158	04042C	PARTICIPANT	\N	PRESENT	0
125851	124158	01047U	PARTICIPANT	\N	PRESENT	0
125852	124158	10015M	PARTICIPANT	\N	PRESENT	0
125853	124158	92045V	PARTICIPANT	\N	PRESENT	0
125854	124158	11077T	PARTICIPANT	\N	PRESENT	0
125872	123942	01027Q	PARTICIPANT	\N	EXCUSE	0
125873	123942	14014Q	PARTICIPANT	\N	EXCUSE	0
125875	125874	14239U	PARTICIPANT	\N	PRESENT	0
125932	125874	11088W	RAPPORTEUR_AVIS	\N	PRESENT	0
125877	125874	01046T	PARTICIPANT	\N	PRESENT	0
125878	125874	04053F	PARTICIPANT	\N	PRESENT	0
125879	125874	14255U	PARTICIPANT	\N	PRESENT	0
125933	120697	98005N	PARTICIPANT	\N	PRESENT	0
125881	125874	00003C	PARTICIPANT	\N	EXCUSE	0
125882	125874	14053L	PARTICIPANT	\N	EXCUSE	0
125883	125874	11103C	PARTICIPANT	\N	PRESENT	0
125934	120697	01022K	PARTICIPANT	\N	PRESENT	0
125885	125874	14195A	PARTICIPANT	\N	PRESENT	0
125886	125874	14267Y	PARTICIPANT	\N	PRESENT	0
125887	125874	11023D	PARTICIPANT	\N	EXCUSE	0
125935	120697	14059S	PARTICIPANT	\N	PRESENT	0
125889	125874	08052W	PARTICIPANT	\N	PRESENT	0
125890	125874	01059Y	PARTICIPANT	\N	EXCUSE	0
125936	120697	08019V	PRESIDENT	0	PRESENT	0
125892	125874	98024R	PRESIDENT	1	PRESENT	0
125893	125874	10006L	PARTICIPANT	\N	PRESENT	0
125937	120023	11097X	PARTICIPANT	\N	PRESENT	0
125895	125874	14217N	PARTICIPANT	\N	PRESENT	0
125938	120023	14195A	PARTICIPANT	\N	PRESENT	0
125897	125874	14151M	PARTICIPANT	\N	PRESENT	0
125898	125874	12042Y	PARTICIPANT	\N	PRESENT	0
125899	125874	14281W	PARTICIPANT	\N	PRESENT	0
126081	125998	08055A	PARTICIPANT	\N	PRESENT	0
126082	125998	08018U	PARTICIPANT	\N	PRESENT	0
125902	125874	14034U	PARTICIPANT	\N	PRESENT	0
125903	125874	14231L	PARTICIPANT	\N	PRESENT	0
125904	125874	11061K	PARTICIPANT	\N	PRESENT	0
126084	125998	01015L	PARTICIPANT	\N	PRESENT	0
126086	125998	14207L	PARTICIPANT	\N	PRESENT	0
126087	125998	12042Y	PARTICIPANT	\N	PRESENT	0
126088	125998	14151M	PARTICIPANT	\N	PRESENT	0
125909	125874	14213J	PARTICIPANT	\N	PRESENT	0
125910	125874	14121F	PARTICIPANT	\N	PRESENT	0
125911	125874	11112D	PARTICIPANT	\N	PRESENT	0
126089	125998	14001X	PARTICIPANT	\N	PRESENT	0
126090	125998	04088S	PARTICIPANT	\N	PRESENT	0
126091	125998	11040E	PARTICIPANT	\N	PRESENT	0
126092	125998	08068F	PARTICIPANT	\N	PRESENT	0
125916	125874	04092N	PRESIDENT	0	PRESENT	0
125917	125874	14265W	PARTICIPANT	\N	PRESENT	0
125918	125874	14119M	PARTICIPANT	\N	PRESENT	0
125919	125874	14071N	PARTICIPANT	\N	PRESENT	0
126093	125998	11066Q	PARTICIPANT	\N	PRESENT	0
125921	125874	04043D	PARTICIPANT	\N	PRESENT	0
125922	125874	14271U	PARTICIPANT	\N	PRESENT	0
126094	125998	04057K	PARTICIPANT	\N	PRESENT	0
125924	125874	11093T	PARTICIPANT	\N	PRESENT	0
125925	125874	11097X	PARTICIPANT	\N	PRESENT	0
125926	125874	04045F	PARTICIPANT	\N	PRESENT	0
125927	125874	14227Q	PARTICIPANT	\N	EXCUSE	0
125928	125874	01034P	PARTICIPANT	\N	PRESENT	0
126095	125998	14205J	PARTICIPANT	\N	PRESENT	0
126096	125998	11099A	PARTICIPANT	\N	PRESENT	0
126097	125998	14034U	PARTICIPANT	\N	PRESENT	0
126098	125998	04086Q	PARTICIPANT	\N	PRESENT	0
126099	125998	95015C	PARTICIPANT	\N	PRESENT	0
126100	124057	14121F	PARTICIPANT	\N	PRESENT	0
126101	124057	08068F	PARTICIPANT	\N	PRESENT	0
126102	124057	14030Q	PARTICIPANT	\N	PRESENT	0
126103	124057	14255U	PARTICIPANT	\N	PRESENT	0
126104	124057	04049K	PRESIDENT	0	PRESENT	0
126105	124057	14061L	PARTICIPANT	\N	PRESENT	0
126106	125998	04049K	PARTICIPANT	\N	PRESENT	0
126107	124057	14265W	PARTICIPANT	\N	PRESENT	0
126108	124057	14083S	PARTICIPANT	\N	PRESENT	0
126109	125998	11103C	PARTICIPANT	\N	PRESENT	0
126110	124057	14157T	PARTICIPANT	\N	PRESENT	0
126111	124057	04071H	PARTICIPANT	\N	PRESENT	0
126112	124057	04053F	PARTICIPANT	\N	PRESENT	0
126113	125998	11014C	PARTICIPANT	\N	PRESENT	0
126114	125998	01028R	PARTICIPANT	\N	PRESENT	0
126115	124057	89017R	PARTICIPANT	\N	EXCUSE	0
126116	125998	88008L	PARTICIPANT	\N	PRESENT	0
126117	124057	14261S	PARTICIPANT	\N	EXCUSE	0
126118	124057	14065Q	PARTICIPANT	\N	EXCUSE	0
126119	124057	14013P	PARTICIPANT	\N	EXCUSE	0
126120	124057	14105F	PARTICIPANT	\N	EXCUSE	0
126121	124057	14079W	PARTICIPANT	\N	EXCUSE	0
126122	124057	04055H	PARTICIPANT	\N	EXCUSE	0
126123	124057	11088W	PARTICIPANT	\N	EXCUSE	0
126124	124057	14041T	PARTICIPANT	\N	EXCUSE	0
126125	124057	14151M	PARTICIPANT	\N	EXCUSE	0
126126	124057	14034U	PARTICIPANT	\N	EXCUSE	0
126127	124057	95041E	PARTICIPANT	\N	EXCUSE	0
126128	124057	14039A	PARTICIPANT	\N	EXCUSE	0
126129	124057	14205J	PARTICIPANT	\N	EXCUSE	0
126130	124057	14253S	PARTICIPANT	\N	EXCUSE	0
126131	124057	11090Q	PARTICIPANT	\N	EXCUSE	0
126132	124057	10015M	PARTICIPANT	\N	EXCUSE	0
126133	124057	95067Q	PARTICIPANT	\N	EXCUSE	0
126134	124057	11063M	PARTICIPANT	\N	EXCUSE	0
126136	126135	05008E	PARTICIPANT	\N	PRESENT	0
126137	126135	04047H	PARTICIPANT	\N	PRESENT	0
126138	126135	11056N	PARTICIPANT	\N	PRESENT	0
126139	124057	14207L	PARTICIPANT	\N	EXCUSE	0
126140	125998	87003B	PARTICIPANT	\N	PRESENT	0
126141	125998	01003G	PARTICIPANT	\N	PRESENT	0
126142	125998	14267Y	PARTICIPANT	\N	PRESENT	0
126143	125998	11036J	PARTICIPANT	\N	PRESENT	0
126144	125998	04061F	PARTICIPANT	\N	PRESENT	0
126145	125998	14063N	PARTICIPANT	\N	PRESENT	0
126146	125998	14030Q	PARTICIPANT	\N	PRESENT	0
126147	125998	04055H	PARTICIPANT	\N	PRESENT	0
126149	125998	14257W	PARTICIPANT	\N	PRESENT	0
126150	125998	11029K	PARTICIPANT	\N	PRESENT	0
126151	125998	14069U	PARTICIPANT	\N	PRESENT	0
116587	116584	08062Y	PARTICIPANT	\N	PRESENT	0
119216	119214	14071N	PARTICIPANT	\N	PRESENT	0
119221	119220	14071N	PARTICIPANT	\N	PRESENT	0
122707	122706	98029W	PARTICIPANT	\N	PRESENT	0
122708	122706	04036E	PARTICIPANT	\N	PRESENT	0
122709	122706	95067Q	PARTICIPANT	\N	PRESENT	0
122710	122706	14253S	PARTICIPANT	\N	PRESENT	0
122711	122706	14071N	PARTICIPANT	\N	PRESENT	0
122765	122758	04036E	PARTICIPANT	\N	PRESENT	0
122768	122758	11027H	PARTICIPANT	\N	PRESENT	0
122770	122758	01041N	PARTICIPANT	\N	PRESENT	0
122772	122758	04034C	PARTICIPANT	\N	PRESENT	0
122776	122758	11026G	PARTICIPANT	\N	PRESENT	0
122780	122758	14041T	PARTICIPANT	\N	PRESENT	0
122781	122758	14255U	PARTICIPANT	\N	PRESENT	0
122836	122832	14261S	PARTICIPANT	\N	PRESENT	0
122837	122832	08055A	PARTICIPANT	\N	PRESENT	0
122838	122832	14093U	PARTICIPANT	\N	PRESENT	0
122839	122832	14030Q	PARTICIPANT	\N	PRESENT	0
122840	122832	96004D	PARTICIPANT	\N	PRESENT	0
122841	122832	08060W	PARTICIPANT	\N	PRESENT	0
122842	122832	11095V	PARTICIPANT	\N	EXCUSE	0
122843	122832	14038Y	PARTICIPANT	\N	EXCUSE	0
125940	125939	11076S	PARTICIPANT	\N	PRESENT	0
122845	122832	98023Q	PARTICIPANT	\N	PRESENT	0
122876	122875	01008M	PARTICIPANT	\N	PRESENT	0
122847	122832	01015L	PARTICIPANT	\N	PRESENT	0
122848	122832	11107G	PARTICIPANT	\N	PRESENT	0
122877	122875	11036J	PARTICIPANT	\N	PRESENT	0
122850	122832	02002K	PARTICIPANT	\N	PRESENT	0
122851	122832	01022K	PARTICIPANT	\N	PRESENT	0
122852	122832	04097T	PARTICIPANT	\N	PRESENT	0
122853	122832	09001P	PARTICIPANT	\N	PRESENT	0
122854	122832	11059R	PARTICIPANT	\N	PRESENT	0
122855	122832	14219Q	PARTICIPANT	\N	PRESENT	0
122856	122832	80027E	PARTICIPANT	\N	PRESENT	0
122857	122832	14031R	PARTICIPANT	\N	PRESENT	0
122858	122832	08009T	PRESIDENT	0	PRESENT	0
122859	122832	08062Y	PARTICIPANT	\N	PRESENT	0
122860	122832	14221J	PARTICIPANT	\N	PRESENT	0
122878	122875	11081P	PARTICIPANT	\N	PRESENT	0
122862	122832	08042U	PARTICIPANT	\N	PRESENT	0
122863	122832	14169X	PARTICIPANT	\N	PRESENT	0
122864	122832	14237S	PARTICIPANT	\N	PRESENT	0
122865	122832	13002U	PARTICIPANT	\N	PRESENT	0
122866	122832	05012A	PARTICIPANT	\N	PRESENT	0
122867	122832	14247U	PARTICIPANT	\N	PRESENT	0
122868	122832	14135M	PARTICIPANT	\N	PRESENT	0
122869	122832	14331P	PARTICIPANT	\N	PRESENT	0
122870	122832	95062K	PARTICIPANT	\N	PRESENT	0
122871	122832	14107H	PARTICIPANT	\N	PRESENT	0
122872	122832	14051J	PARTICIPANT	\N	PRESENT	0
122873	122832	14157T	PARTICIPANT	\N	PRESENT	0
122874	122832	96003C	PARTICIPANT	\N	EXCUSE	0
122879	122875	14013P	PARTICIPANT	\N	PRESENT	0
122880	122875	08068F	PARTICIPANT	\N	PRESENT	0
122881	122875	14207L	PARTICIPANT	\N	PRESENT	0
122882	122875	11101A	PARTICIPANT	\N	PRESENT	0
122883	122875	90003B	PARTICIPANT	\N	PRESENT	0
122884	122875	08028W	PARTICIPANT	\N	PRESENT	0
122885	122875	80013X	PARTICIPANT	\N	PRESENT	0
122886	122875	08038Y	PARTICIPANT	\N	PRESENT	0
122924	122875	14179A	PARTICIPANT	\N	PRESENT	0
122888	122875	14197C	PARTICIPANT	\N	PRESENT	0
124898	124886	14267Y	PARTICIPANT	\N	PRESENT	0
122890	122875	14187A	PARTICIPANT	\N	PRESENT	0
122891	122875	14033T	PARTICIPANT	\N	PRESENT	0
122892	122875	14081Q	PARTICIPANT	\N	PRESENT	0
122893	122875	04048J	PARTICIPANT	\N	PRESENT	0
122894	122875	11099A	PARTICIPANT	\N	PRESENT	0
122895	122875	04049K	PARTICIPANT	\N	PRESENT	0
122896	122875	04094Q	PARTICIPANT	\N	PRESENT	0
122897	122875	11111C	PARTICIPANT	\N	PRESENT	0
122898	122875	08015R	PARTICIPANT	\N	PRESENT	0
122899	122875	11100Y	PRESIDENT	0	PRESENT	0
124899	124886	11023D	PARTICIPANT	\N	EXCUSE	0
122901	122875	11098Y	PARTICIPANT	\N	PRESENT	0
122902	122875	01043Q	PARTICIPANT	\N	PRESENT	0
122903	122875	11077T	PARTICIPANT	\N	PRESENT	0
122904	122875	14205J	PARTICIPANT	\N	PRESENT	0
122905	122875	08019V	PARTICIPANT	\N	PRESENT	0
122906	122875	14257W	PARTICIPANT	\N	PRESENT	0
124900	124886	11031D	PARTICIPANT	\N	PRESENT	0
122908	122875	04088S	PARTICIPANT	\N	PRESENT	0
122909	122875	98050T	PARTICIPANT	\N	PRESENT	0
122910	122875	11090Q	PARTICIPANT	\N	PRESENT	0
122911	122875	11046L	PARTICIPANT	\N	PRESENT	0
122912	122875	01058X	PARTICIPANT	\N	PRESENT	0
122913	122875	11094U	PARTICIPANT	\N	PRESENT	0
122914	122875	11066Q	PARTICIPANT	\N	PRESENT	0
124901	124886	08052W	PARTICIPANT	\N	PRESENT	0
124902	124886	01059Y	PARTICIPANT	\N	PRESENT	0
124903	124886	04081K	PARTICIPANT	\N	PRESENT	0
124904	124886	98024R	PARTICIPANT	\N	PRESENT	0
124905	124886	10006L	PARTICIPANT	\N	PRESENT	0
125941	125939	04054G	PARTICIPANT	\N	PRESENT	0
124907	124886	14217N	PARTICIPANT	\N	PRESENT	0
124908	124886	14042U	PARTICIPANT	\N	PRESENT	0
124909	124886	14151M	PARTICIPANT	\N	PRESENT	0
124910	124886	12042Y	PARTICIPANT	\N	PRESENT	0
124911	124886	14281W	PARTICIPANT	\N	PRESENT	0
125942	125939	04040A	PARTICIPANT	\N	PRESENT	0
124913	124886	01003G	PARTICIPANT	\N	PRESENT	0
124914	124886	14034U	PARTICIPANT	\N	PRESENT	0
124915	124886	14231L	PARTICIPANT	\N	PRESENT	0
124916	124886	11061K	PARTICIPANT	\N	PRESENT	0
124917	124886	08048B	PARTICIPANT	\N	PRESENT	0
124918	124886	08041T	PARTICIPANT	\N	PRESENT	0
125943	125939	08058D	PARTICIPANT	\N	PRESENT	0
124920	124886	14026U	PARTICIPANT	\N	PRESENT	0
124921	124886	14213J	PARTICIPANT	\N	PRESENT	0
124922	124886	14121F	PARTICIPANT	\N	PRESENT	0
124923	124886	11112D	PARTICIPANT	\N	PRESENT	0
124924	124886	14037X	PARTICIPANT	\N	PRESENT	0
124925	124886	14018U	PARTICIPANT	\N	PRESENT	0
124927	124886	14223L	PARTICIPANT	\N	PRESENT	0
124928	124886	04092N	PRESIDENT	0	PRESENT	0
124929	124886	14265W	PARTICIPANT	\N	PRESENT	0
124930	124886	14119M	PARTICIPANT	\N	PRESENT	0
124931	124886	14071N	PARTICIPANT	\N	PRESENT	0
124932	124886	07032N	PARTICIPANT	\N	PRESENT	0
124933	124886	04043D	PARTICIPANT	\N	PRESENT	0
124934	124886	14271U	PARTICIPANT	\N	PRESENT	0
124936	124886	11093T	PARTICIPANT	\N	PRESENT	0
124937	124886	11097X	PARTICIPANT	\N	PRESENT	0
124938	124886	04045F	PARTICIPANT	\N	PRESENT	0
124939	124886	14227Q	PARTICIPANT	\N	EXCUSE	0
124940	124886	01034P	PARTICIPANT	\N	PRESENT	0
124942	124886	11063M	PARTICIPANT	\N	PRESENT	0
124943	124886	14269B	PARTICIPANT	\N	PRESENT	0
125946	125939	98029W	PARTICIPANT	\N	PRESENT	0
125947	125939	11080N	PARTICIPANT	\N	PRESENT	0
125949	125939	98018T	PARTICIPANT	\N	PRESENT	0
125950	125939	92018S	PARTICIPANT	\N	PRESENT	0
125952	125939	95030B	PARTICIPANT	\N	PRESENT	0
125957	125939	04035D	PARTICIPANT	\N	PRESENT	0
125958	125939	07024N	PARTICIPANT	\N	PRESENT	0
125960	125939	14014Q	PARTICIPANT	\N	PRESENT	0
125964	125939	08056B	PARTICIPANT	\N	EXCUSE	0
125966	125939	98022P	PARTICIPANT	\N	PRESENT	0
125970	125939	14097Y	PARTICIPANT	\N	PRESENT	0
125972	125939	04036E	PARTICIPANT	\N	PRESENT	0
113933	113932	14255U	PARTICIPANT	\N	PRESENT	0
113934	113932	14079W	PARTICIPANT	\N	PRESENT	0
113935	113932	14179A	PARTICIPANT	\N	PRESENT	0
113839	113833	04059M	PARTICIPANT	\N	PRESENT	0
113936	113932	04036E	PARTICIPANT	\N	PRESENT	0
113841	113833	01044R	PARTICIPANT	\N	PRESENT	0
113842	113833	08043V	PARTICIPANT	\N	PRESENT	0
113843	113833	14089Y	PARTICIPANT	\N	PRESENT	0
113937	113932	14237S	PARTICIPANT	\N	PRESENT	0
113845	113833	11029K	PARTICIPANT	\N	PRESENT	0
113938	113932	04044E	PARTICIPANT	\N	PRESENT	0
113847	113833	92015P	PARTICIPANT	\N	PRESENT	0
114472	114470	08025T	PARTICIPANT	\N	PRESENT	0
113849	113833	14201E	PARTICIPANT	\N	PRESENT	0
114473	114470	04085P	PARTICIPANT	\N	PRESENT	0
113851	113833	14209N	PARTICIPANT	\N	PRESENT	0
113852	113833	14079W	PARTICIPANT	\N	PRESENT	0
113853	113833	11091R	PARTICIPANT	\N	EXCUSE	0
113854	113833	87003B	PARTICIPANT	\N	PRESENT	0
114474	114470	05008E	PRESIDENT	0	PRESENT	0
114475	114470	11030C	PARTICIPANT	\N	PRESENT	0
114476	114470	11033F	PARTICIPANT	\N	PRESENT	0
114477	114470	14065Q	PARTICIPANT	\N	PRESENT	0
114478	114470	14069U	PARTICIPANT	\N	PRESENT	0
113860	113833	89029V	PARTICIPANT	\N	PRESENT	0
114522	114470	14147R	PARTICIPANT	\N	PRESENT	0
113862	113833	11089X	PARTICIPANT	\N	PRESENT	0
122436	121156	14083S	PARTICIPANT	\N	PRESENT	0
113864	113833	14123H	PARTICIPANT	\N	PRESENT	0
113865	113833	14179A	PARTICIPANT	\N	PRESENT	0
114481	114470	04038G	PARTICIPANT	\N	PRESENT	0
113867	113833	14241N	PARTICIPANT	\N	EXCUSE	0
113868	113833	14061L	PARTICIPANT	\N	PRESENT	0
113869	113833	14073Q	PARTICIPANT	\N	EXCUSE	0
113870	113833	08031R	PARTICIPANT	\N	PRESENT	0
122437	121156	14089Y	PARTICIPANT	\N	PRESENT	0
113872	113833	08039A	PARTICIPANT	\N	PRESENT	0
113873	113833	08017T	PARTICIPANT	\N	PRESENT	0
113874	113833	14059S	PARTICIPANT	\N	PRESENT	0
114483	114470	11056N	PARTICIPANT	\N	PRESENT	0
122438	121156	11103C	PARTICIPANT	\N	PRESENT	0
113877	113833	11104D	PARTICIPANT	\N	PRESENT	0
113878	113833	14063N	PARTICIPANT	\N	PRESENT	0
113879	113833	04057K	PARTICIPANT	\N	PRESENT	0
114485	114470	11035H	PARTICIPANT	\N	PRESENT	0
113881	113833	14109K	PARTICIPANT	\N	EXCUSE	0
113882	113833	04070G	PRESIDENT	0	PRESENT	0
114486	114470	14041T	PARTICIPANT	\N	PRESENT	0
122439	121156	04092N	PARTICIPANT	\N	PRESENT	0
113885	113833	83047W	PARTICIPANT	\N	PRESENT	0
113886	113833	14235Q	PARTICIPANT	\N	PRESENT	0
114488	114470	01024M	PARTICIPANT	\N	PRESENT	0
114489	114470	14215L	PARTICIPANT	\N	PRESENT	0
113889	113833	14229S	PARTICIPANT	\N	PRESENT	0
113890	113833	11043H	PARTICIPANT	\N	PRESENT	0
122440	121156	11082Q	PARTICIPANT	\N	PRESENT	0
122441	121156	14053L	PARTICIPANT	\N	PRESENT	0
122442	121156	14187A	PARTICIPANT	\N	PRESENT	0
114493	114470	01007L	PARTICIPANT	\N	PRESENT	0
122443	121156	11111C	PARTICIPANT	\N	PRESENT	0
122444	121156	11093T	PARTICIPANT	\N	PRESENT	0
114496	114470	11084S	PARTICIPANT	\N	PRESENT	0
122445	121156	08042U	PARTICIPANT	\N	PRESENT	0
114498	114470	04079R	PARTICIPANT	\N	PRESENT	0
114499	114470	14111D	PARTICIPANT	\N	PRESENT	0
114500	114470	14001X	PARTICIPANT	\N	PRESENT	0
114501	114470	14273W	PARTICIPANT	\N	PRESENT	0
122446	121156	14275Y	PARTICIPANT	\N	PRESENT	0
122447	121156	14277B	PARTICIPANT	\N	PRESENT	0
122448	121156	11090Q	PARTICIPANT	\N	PRESENT	0
114505	114470	08051V	PARTICIPANT	\N	PRESENT	0
114506	114470	11072N	PARTICIPANT	\N	PRESENT	0
114507	114470	07034Q	PARTICIPANT	\N	PRESENT	0
114508	114470	04074L	PARTICIPANT	\N	PRESENT	0
114509	114470	10015M	PARTICIPANT	\N	PRESENT	0
114510	114470	95063L	PARTICIPANT	\N	PRESENT	0
122449	121156	14034U	PARTICIPANT	\N	PRESENT	0
114512	114470	01028R	PARTICIPANT	\N	PRESENT	0
114513	114470	98035U	PARTICIPANT	\N	PRESENT	0
114514	114470	04056J	PARTICIPANT	\N	PRESENT	0
114515	114470	14275Y	PARTICIPANT	\N	PRESENT	0
114516	114470	04044E	PARTICIPANT	\N	PRESENT	0
122450	121156	01008M	PARTICIPANT	\N	PRESENT	0
114518	114470	92045V	PARTICIPANT	\N	PRESENT	0
114519	114470	95067Q	PARTICIPANT	\N	PRESENT	0
114520	114470	01047U	PARTICIPANT	\N	PRESENT	0
122451	121156	14209N	PARTICIPANT	\N	PRESENT	0
122452	121156	14059S	PARTICIPANT	\N	PRESENT	0
122453	121156	08019V	PARTICIPANT	\N	PRESENT	0
122454	121156	14037X	PARTICIPANT	\N	PRESENT	0
122455	121156	14061L	PARTICIPANT	\N	PRESENT	0
122456	121156	99004R	PARTICIPANT	\N	PRESENT	0
122457	121156	96004D	PARTICIPANT	\N	PRESENT	0
122458	121156	01048V	PARTICIPANT	\N	PRESENT	0
122459	121156	14223L	PARTICIPANT	\N	PRESENT	0
122460	121156	14093U	PARTICIPANT	\N	PRESENT	0
122461	121156	14249W	PARTICIPANT	\N	PRESENT	0
122462	121156	04035D	PARTICIPANT	\N	PRESENT	0
122463	121156	14259Y	PARTICIPANT	\N	PRESENT	0
122464	121156	08047A	PARTICIPANT	\N	PRESENT	0
122465	121156	14087W	PARTICIPANT	\N	PRESENT	0
122466	121156	14195A	PARTICIPANT	\N	PRESENT	0
122474	121156	04061F	PARTICIPANT	\N	PRESENT	0
122468	121156	11053K	PARTICIPANT	\N	PRESENT	0
122469	121156	14237S	PARTICIPANT	\N	PRESENT	0
122470	121156	14193X	PARTICIPANT	\N	PRESENT	0
122471	121156	11085T	PARTICIPANT	\N	PRESENT	0
122472	121156	04049K	PARTICIPANT	\N	PRESENT	0
122473	121156	86034E	PARTICIPANT	\N	PRESENT	0
122475	121156	14215L	PARTICIPANT	\N	PRESENT	0
122476	121156	01003G	PARTICIPANT	\N	PRESENT	0
122477	121156	14217N	PARTICIPANT	\N	PRESENT	0
122491	121159	98024R	PARTICIPANT	\N	PRESENT	0
122486	121156	04070G	PARTICIPANT	\N	PRESENT	0
122487	121156	09001P	PARTICIPANT	\N	PRESENT	0
122488	121156	01041N	PARTICIPANT	\N	PRESENT	0
122489	121156	04048J	PARTICIPANT	\N	PRESENT	0
122485	121156	14263U	PARTICIPANT	\N	PRESENT	0
122484	121156	08021P	PARTICIPANT	\N	PRESENT	0
122490	121159	89029V	PARTICIPANT	\N	PRESENT	0
122492	121159	04035D	PARTICIPANT	\N	PRESENT	0
122493	121159	04044E	PARTICIPANT	\N	PRESENT	0
122494	121159	04086Q	PARTICIPANT	\N	PRESENT	0
122502	121159	08019V	PARTICIPANT	\N	PRESENT	0
122496	121159	14331P	PARTICIPANT	\N	PRESENT	0
122497	121159	01008M	PARTICIPANT	\N	PRESENT	0
122498	121159	07029T	PARTICIPANT	\N	PRESENT	0
122499	121159	11011M	PARTICIPANT	\N	PRESENT	0
122500	121159	14041T	PARTICIPANT	\N	PRESENT	0
122501	121159	14079W	PARTICIPANT	\N	PRESENT	0
122503	121159	14187A	PARTICIPANT	\N	PRESENT	0
122505	121159	14235Q	PARTICIPANT	\N	PRESENT	0
122506	121159	11034G	PARTICIPANT	\N	PRESENT	0
122507	121159	11084S	PARTICIPANT	\N	PRESENT	0
122508	121159	01022K	PARTICIPANT	\N	PRESENT	0
122509	121159	80013X	PARTICIPANT	\N	PRESENT	0
122510	121159	11066Q	PARTICIPANT	\N	PRESENT	0
122511	121159	14109K	PARTICIPANT	\N	PRESENT	0
122512	121159	14229S	PARTICIPANT	\N	PRESENT	0
122513	121159	95062K	PARTICIPANT	\N	PRESENT	0
122514	121159	11104D	PARTICIPANT	\N	PRESENT	0
122515	121159	04057K	PARTICIPANT	\N	PRESENT	0
122516	121159	14231L	PARTICIPANT	\N	PRESENT	0
122517	121159	11055M	PARTICIPANT	\N	PRESENT	0
122518	121159	14103D	PARTICIPANT	\N	PRESENT	0
122519	121159	14261S	PARTICIPANT	\N	PRESENT	0
122520	121159	01027Q	PARTICIPANT	\N	PRESENT	0
122521	121159	14215L	PARTICIPANT	\N	PRESENT	0
122522	121159	14247U	PARTICIPANT	\N	PRESENT	0
122523	121159	01060R	PARTICIPANT	\N	PRESENT	0
122524	121159	14197C	PARTICIPANT	\N	PRESENT	0
122525	121159	04089T	PARTICIPANT	\N	PRESENT	0
122526	121159	95015C	PARTICIPANT	\N	PRESENT	0
122527	121159	07004J	PARTICIPANT	\N	PRESENT	0
122528	121159	11036J	PARTICIPANT	\N	PRESENT	0
122529	121159	11094U	PARTICIPANT	\N	PRESENT	0
122530	121159	14069U	PARTICIPANT	\N	PRESENT	0
122531	121159	11056N	PARTICIPANT	\N	PRESENT	0
122532	121159	11065P	PARTICIPANT	\N	PRESENT	0
122533	121159	08017T	PARTICIPANT	\N	PRESENT	0
122534	121159	11089X	PARTICIPANT	\N	PRESENT	0
122535	121159	08043V	PARTICIPANT	\N	PRESENT	0
122536	121159	11015D	PARTICIPANT	\N	PRESENT	0
122537	121159	14195A	PARTICIPANT	\N	PRESENT	0
122538	121159	14014Q	PARTICIPANT	\N	PRESENT	0
122539	121159	14207L	PARTICIPANT	\N	PRESENT	0
122540	121159	11077T	PARTICIPANT	\N	PRESENT	0
122541	121159	08058D	PARTICIPANT	\N	PRESENT	0
121673	121672	11039M	PARTICIPANT	\N	PRESENT	0
125653	125652	11076S	PARTICIPANT	\N	PRESENT	0
125654	125652	04085P	PARTICIPANT	\N	PRESENT	0
125656	125652	04054G	PARTICIPANT	\N	PRESENT	0
125657	125652	14089Y	PARTICIPANT	\N	PRESENT	0
125658	125652	04047H	PARTICIPANT	\N	PRESENT	0
125659	125652	14041T	PARTICIPANT	\N	PRESENT	0
125660	125652	04035D	PARTICIPANT	\N	PRESENT	0
125661	125652	14097Y	PARTICIPANT	\N	PRESENT	0
125662	125652	14073Q	PARTICIPANT	\N	PRESENT	0
125664	125652	11026G	PARTICIPANT	\N	PRESENT	0
125665	125652	92031P	PRESIDENT	0	PRESENT	0
125666	125652	14251Q	PARTICIPANT	\N	PRESENT	0
125667	125652	14001X	PARTICIPANT	\N	PRESENT	0
125668	125652	08053X	PARTICIPANT	\N	PRESENT	0
125670	125652	14331P	PARTICIPANT	\N	PRESENT	0
125671	125652	95067Q	PARTICIPANT	\N	PRESENT	0
125747	125746	11033F	PARTICIPANT	\N	PRESENT	0
125748	125746	04044E	PARTICIPANT	\N	PRESENT	0
126154	125998	14259Y	PARTICIPANT	\N	PRESENT	0
126155	125998	14031R	PARTICIPANT	\N	PRESENT	0
126156	125998	05008E	PARTICIPANT	\N	PRESENT	0
126157	125998	98005N	PARTICIPANT	\N	PRESENT	0
126158	125998	11104D	PARTICIPANT	\N	PRESENT	0
126159	125998	14121F	PARTICIPANT	\N	PRESENT	0
126161	126160	08010L	PARTICIPANT	\N	PRESENT	0
126162	125998	14219Q	PARTICIPANT	\N	PRESENT	0
126152	125998	86044G	PARTICIPANT	\N	PRESENT	0
126153	125998	08069G	PARTICIPANT	\N	PRESENT	0
126163	125998	01048V	PARTICIPANT	\N	PRESENT	0
126164	125998	14073Q	PARTICIPANT	\N	PRESENT	0
126165	125998	98050T	PARTICIPANT	\N	PRESENT	0
126166	125998	14159V	PARTICIPANT	\N	PRESENT	0
126167	125998	14265W	PARTICIPANT	\N	PRESENT	0
126168	125998	14061L	PARTICIPANT	\N	PRESENT	0
126169	125998	14213J	PARTICIPANT	\N	PRESENT	0
126171	125998	11043H	PARTICIPANT	\N	PRESENT	0
126172	126170	11048N	PARTICIPANT	\N	PRESENT	0
126173	125998	11105E	PARTICIPANT	\N	PRESENT	0
126174	125998	14119M	PARTICIPANT	\N	PRESENT	0
126175	125998	14193X	PARTICIPANT	\N	PRESENT	0
126176	125998	07024N	PARTICIPANT	\N	PRESENT	0
126177	125998	80013X	PARTICIPANT	\N	PRESENT	0
126178	125998	14225N	PARTICIPANT	\N	PRESENT	0
126179	125998	14033T	PARTICIPANT	\N	PRESENT	0
126180	125998	08056B	PARTICIPANT	\N	PRESENT	0
126182	126181	11082Q	PARTICIPANT	\N	PRESENT	0
126184	126183	11082Q	PARTICIPANT	\N	PRESENT	0
126186	126185	11082Q	PARTICIPANT	\N	PRESENT	0
126188	126187	11082Q	PARTICIPANT	\N	PRESENT	0
126189	125998	04053F	PARTICIPANT	\N	PRESENT	0
126190	125998	01056V	PARTICIPANT	\N	PRESENT	0
126191	125998	11110B	PARTICIPANT	\N	PRESENT	0
126192	125998	01031L	PARTICIPANT	\N	PRESENT	0
126193	125998	04067M	PARTICIPANT	\N	PRESENT	0
126194	125998	14079W	PARTICIPANT	\N	PRESENT	0
126195	125998	04045F	PARTICIPANT	\N	PRESENT	0
126196	125998	14037X	PARTICIPANT	\N	PRESENT	0
126197	125998	11048N	PARTICIPANT	\N	PRESENT	0
126198	125998	14237S	PARTICIPANT	\N	PRESENT	0
126199	125998	14065Q	PARTICIPANT	\N	PRESENT	0
126319	125999	14247U	PARTICIPANT	\N	PRESENT	0
126320	125999	04081K	PARTICIPANT	\N	PRESENT	0
126321	125999	92045V	PARTICIPANT	\N	PRESENT	0
126322	125999	86034E	PARTICIPANT	\N	PRESENT	0
126324	125999	04043D	PARTICIPANT	\N	PRESENT	0
126325	125999	07034Q	PARTICIPANT	\N	PRESENT	0
126326	125999	86044G	PARTICIPANT	\N	PRESENT	0
126327	125999	13002U	PARTICIPANT	\N	PRESENT	0
126328	125999	98029W	PARTICIPANT	\N	PRESENT	0
126329	125999	14059S	PARTICIPANT	\N	PRESENT	0
126330	125999	80013X	PARTICIPANT	\N	PRESENT	0
126331	125999	11097X	PARTICIPANT	\N	PRESENT	0
126332	125999	14081Q	PARTICIPANT	\N	PRESENT	0
126333	125999	87003B	PARTICIPANT	\N	PRESENT	0
126334	125999	14063N	PARTICIPANT	\N	PRESENT	0
126335	125999	08053X	PARTICIPANT	\N	PRESENT	0
126336	125999	01044R	PARTICIPANT	\N	PRESENT	0
126337	125999	10006L	PARTICIPANT	\N	PRESENT	0
126338	125999	14121F	PARTICIPANT	\N	PRESENT	0
126339	125999	11037K	PARTICIPANT	\N	PRESENT	0
126340	125999	90003B	PARTICIPANT	\N	PRESENT	0
126341	125999	11061K	PARTICIPANT	\N	PRESENT	0
126342	125999	14051J	PARTICIPANT	\N	PRESENT	0
126343	125999	95035G	PARTICIPANT	\N	PRESENT	0
126344	125999	12042Y	PARTICIPANT	\N	PRESENT	0
126345	125999	14041T	PARTICIPANT	\N	PRESENT	0
126346	125999	14159V	PARTICIPANT	\N	PRESENT	0
126347	125999	98022P	PARTICIPANT	\N	PRESENT	0
126348	125999	14157T	PARTICIPANT	\N	PRESENT	0
126349	125999	04088S	PARTICIPANT	\N	PRESENT	0
126350	125999	14215L	PARTICIPANT	\N	PRESENT	0
126351	125999	14209N	PARTICIPANT	\N	PRESENT	0
126352	125999	04036E	PARTICIPANT	\N	PRESENT	0
126353	125999	02002K	PARTICIPANT	\N	PRESENT	0
126354	125999	98023Q	PARTICIPANT	\N	PRESENT	0
126355	125999	77002U	PARTICIPANT	\N	PRESENT	0
126356	125999	01056V	PARTICIPANT	\N	PRESENT	0
126357	125999	04047H	PARTICIPANT	\N	PRESENT	0
126358	125999	14259Y	PARTICIPANT	\N	PRESENT	0
126359	125999	14033T	PARTICIPANT	\N	PRESENT	0
126360	125999	04044E	PARTICIPANT	\N	PRESENT	0
126361	125999	11103C	PARTICIPANT	\N	PRESENT	0
126362	125999	04074L	PARTICIPANT	\N	PRESENT	0
126363	125999	14031R	PARTICIPANT	\N	PRESENT	0
126364	125999	99004R	PARTICIPANT	\N	PRESENT	0
126365	125999	14199E	PARTICIPANT	\N	PRESENT	0
126366	125999	04057K	PARTICIPANT	\N	PRESENT	0
126367	125999	14217N	PARTICIPANT	\N	PRESENT	0
126368	125999	01027Q	PARTICIPANT	\N	PRESENT	0
126369	125999	95015C	PARTICIPANT	\N	PRESENT	0
126370	125999	11080N	PARTICIPANT	\N	PRESENT	0
126371	125999	11100Y	PARTICIPANT	\N	PRESENT	0
126372	125999	04086Q	PARTICIPANT	\N	PRESENT	0
126373	125999	07032N	PARTICIPANT	\N	PRESENT	0
126374	125999	08062Y	PARTICIPANT	\N	PRESENT	0
126375	125999	98021N	PARTICIPANT	\N	PRESENT	0
126376	125999	04049K	PARTICIPANT	\N	PRESENT	0
126377	125999	08034U	PARTICIPANT	\N	PRESENT	0
126378	125999	11071M	PARTICIPANT	\N	PRESENT	0
126379	125999	10015M	PARTICIPANT	\N	PRESENT	0
126380	125999	08015R	PARTICIPANT	\N	PRESENT	0
126381	125999	14071N	PARTICIPANT	\N	PRESENT	0
126382	125999	11048N	PARTICIPANT	\N	PRESENT	0
126383	125999	11049P	PARTICIPANT	\N	PRESENT	0
126384	125999	14331P	PARTICIPANT	\N	PRESENT	0
126385	125999	08018U	PARTICIPANT	\N	PRESENT	0
126386	125999	04042C	PARTICIPANT	\N	PRESENT	0
126387	125999	11091R	PARTICIPANT	\N	PRESENT	0
126388	125999	95059Q	PARTICIPANT	\N	PRESENT	0
126296	125999	11101A	PARTICIPANT	\N	PRESENT	0
126315	125999	14061L	PARTICIPANT	\N	PRESENT	0
126389	125999	14053L	PARTICIPANT	\N	PRESENT	0
126390	125999	14079W	PARTICIPANT	\N	PRESENT	0
126391	125999	04055H	PARTICIPANT	\N	PRESENT	0
126392	125999	11044J	PARTICIPANT	\N	PRESENT	0
126393	125999	11039M	PARTICIPANT	\N	PRESENT	0
126394	125999	04056J	PARTICIPANT	\N	PRESENT	0
126395	125999	14193X	PARTICIPANT	\N	PRESENT	0
126396	125999	01016M	PARTICIPANT	\N	PRESENT	0
126397	125999	04085P	PARTICIPANT	\N	PRESENT	0
126398	125999	04050C	PARTICIPANT	\N	PRESENT	0
126399	125999	11063M	PARTICIPANT	\N	PRESENT	0
126400	125999	14265W	PARTICIPANT	\N	PRESENT	0
126401	125999	07026Q	PARTICIPANT	\N	PRESENT	0
126402	125999	08010L	PARTICIPANT	\N	PRESENT	0
126403	125999	11110B	PARTICIPANT	\N	PRESENT	0
126404	125999	04054G	PARTICIPANT	\N	PRESENT	0
126405	125999	14013P	PARTICIPANT	\N	PRESENT	0
126406	125999	01015L	PARTICIPANT	\N	PRESENT	0
126407	125999	08069G	PARTICIPANT	\N	PRESENT	0
126408	125999	11040E	PARTICIPANT	\N	PRESENT	0
126409	125999	14235Q	PARTICIPANT	\N	PRESENT	0
126410	125999	98018T	PARTICIPANT	\N	PRESENT	0
126411	125999	04067M	PARTICIPANT	\N	PRESENT	0
126412	125999	08019V	PARTICIPANT	\N	PRESENT	0
126413	125999	11055M	PARTICIPANT	\N	PRESENT	0
126414	125999	11083R	PARTICIPANT	\N	PRESENT	0
126415	125999	11099A	PARTICIPANT	\N	PRESENT	0
126416	125999	88008L	PARTICIPANT	\N	PRESENT	0
126417	125999	04078Q	PARTICIPANT	\N	PRESENT	0
126418	125999	14329V	PARTICIPANT	\N	PRESENT	0
126419	125999	08031R	PARTICIPANT	\N	PRESENT	0
126420	125999	08051V	PARTICIPANT	\N	PRESENT	0
126421	125999	04038G	PARTICIPANT	\N	PRESENT	0
126422	125999	96004D	PARTICIPANT	\N	PRESENT	0
126423	125999	14201E	PARTICIPANT	\N	PRESENT	0
126424	125999	04048J	PARTICIPANT	\N	PRESENT	0
125997	125939	08034U	PARTICIPANT	\N	PRESENT	0
125975	125939	98005N	PARTICIPANT	\N	PRESENT	0
125976	125939	92031P	PARTICIPANT	\N	PRESENT	0
125977	125939	11106F	PARTICIPANT	\N	PRESENT	0
125978	125939	14251Q	PARTICIPANT	\N	PRESENT	0
125979	125939	83042R	PARTICIPANT	\N	PRESENT	0
125980	125939	08053X	PARTICIPANT	\N	PRESENT	0
126989	126004	11100Y	PARTICIPANT	\N	PRESENT	0
125982	125939	11105E	PARTICIPANT	\N	PRESENT	0
126990	126004	11026G	PARTICIPANT	\N	PRESENT	0
125984	125939	08047A	PARTICIPANT	\N	EXCUSE	0
125985	125939	14028W	PARTICIPANT	\N	PRESENT	0
125986	125939	14193X	PARTICIPANT	\N	PRESENT	0
125987	125939	98021N	PARTICIPANT	\N	PRESENT	0
125988	125939	04080J	PARTICIPANT	\N	PRESENT	0
125989	125939	95059Q	PRESIDENT	0	PRESENT	0
125990	125939	86044G	PARTICIPANT	\N	PRESENT	0
125991	125939	01014K	PARTICIPANT	\N	PRESENT	0
125992	125939	11054L	PARTICIPANT	\N	PRESENT	0
125993	125939	01056V	PARTICIPANT	\N	PRESENT	0
126991	126004	08019V	PARTICIPANT	\N	PRESENT	0
125995	125939	08049C	PARTICIPANT	\N	PRESENT	0
126992	126004	04038G	PARTICIPANT	\N	PRESENT	0
126993	126004	14269B	PARTICIPANT	\N	PRESENT	0
126994	126004	98005N	PARTICIPANT	\N	PRESENT	0
126995	126004	04086Q	PARTICIPANT	\N	PRESENT	0
126996	126004	01048V	PARTICIPANT	\N	PRESENT	0
126997	126004	11090Q	PARTICIPANT	\N	PRESENT	0
126998	126004	99004R	PARTICIPANT	\N	PRESENT	0
127000	126999	08039A	PARTICIPANT	\N	PRESENT	0
127002	127001	11039M	PARTICIPANT	\N	PRESENT	0
127003	126004	14331P	PARTICIPANT	\N	PRESENT	0
127005	127004	14253S	PARTICIPANT	\N	PRESENT	0
127006	127004	14157T	PARTICIPANT	\N	PRESENT	0
127008	127007	14253S	PARTICIPANT	\N	PRESENT	0
127009	127007	14157T	PARTICIPANT	\N	PRESENT	0
127010	124802	04049K	PARTICIPANT	\N	PRESENT	0
127011	124802	04053F	PARTICIPANT	\N	PRESENT	0
127012	124802	14207L	PARTICIPANT	\N	PRESENT	0
127013	124802	14039A	PARTICIPANT	\N	PRESENT	0
127014	124802	11090Q	PARTICIPANT	\N	PRESENT	0
127015	124802	95067Q	PARTICIPANT	\N	PRESENT	0
127016	126004	11061K	PARTICIPANT	\N	PRESENT	0
127017	126004	09001P	PARTICIPANT	\N	PRESENT	0
127018	126004	11089X	PARTICIPANT	\N	PRESENT	0
127020	127019	14093U	PARTICIPANT	\N	PRESENT	0
127022	127021	14331P	PARTICIPANT	\N	PRESENT	0
127023	119928	08052W	PARTICIPANT	\N	PRESENT	0
127024	119928	11093T	PARTICIPANT	\N	PRESENT	0
127025	119928	11061K	PARTICIPANT	\N	PRESENT	0
127026	119928	04053F	PARTICIPANT	\N	PRESENT	0
127028	127027	08009T	PARTICIPANT	\N	PRESENT	0
127029	127027	14093U	PARTICIPANT	\N	PRESENT	0
127030	127027	14030Q	PARTICIPANT	\N	PRESENT	0
127031	127027	98023Q	PARTICIPANT	\N	PRESENT	0
127032	127027	11107G	PARTICIPANT	\N	PRESENT	0
127033	127027	04097T	PARTICIPANT	\N	PRESENT	0
127034	127027	14031R	PARTICIPANT	\N	PRESENT	0
127035	127027	92039X	PARTICIPANT	\N	PRESENT	0
127036	127027	08042U	PARTICIPANT	\N	PRESENT	0
127037	127027	14237S	PARTICIPANT	\N	PRESENT	0
127038	127027	14107H	PARTICIPANT	\N	PRESENT	0
127040	127039	14083S	PARTICIPANT	\N	PRESENT	0
127041	126004	04067M	PARTICIPANT	\N	PRESENT	0
127043	127042	08010L	PARTICIPANT	\N	PRESENT	0
127050	127049	08010L	PARTICIPANT	\N	PRESENT	0
127046	127044	14083S	PARTICIPANT	\N	PRESENT	0
127048	127047	14083S	PARTICIPANT	\N	PRESENT	0
127051	120699	14093U	PARTICIPANT	\N	EXCUSE	0
127052	126004	11031D	PARTICIPANT	\N	PRESENT	0
127054	127053	14083S	PARTICIPANT	\N	PRESENT	0
127056	127055	04042C	PARTICIPANT	\N	PRESENT	0
127057	127055	11076S	PARTICIPANT	\N	PRESENT	0
127059	126004	04035D	PARTICIPANT	\N	PRESENT	0
127060	127058	07029T	PARTICIPANT	\N	PRESENT	0
127062	127061	14173T	PARTICIPANT	\N	PRESENT	0
127064	127063	11088W	PARTICIPANT	\N	PRESENT	0
127093	126080	04066L	PARTICIPANT	\N	PRESENT	0
127067	127065	08016S	PARTICIPANT	\N	PRESENT	0
127097	127096	11027H	PARTICIPANT	\N	PRESENT	0
127098	127096	86044G	PARTICIPANT	\N	PRESENT	0
127100	127099	04040A	PARTICIPANT	\N	PRESENT	0
127101	127099	83042R	PARTICIPANT	\N	PRESENT	0
127103	127102	01056V	PARTICIPANT	\N	PRESENT	0
127104	127102	11106F	PARTICIPANT	\N	PRESENT	0
127105	126080	14231L	PARTICIPANT	\N	PRESENT	0
127106	126080	07026Q	PARTICIPANT	\N	PRESENT	0
127107	126080	11031D	PARTICIPANT	\N	PRESENT	0
127108	126080	14269B	PARTICIPANT	\N	PRESENT	0
127109	126080	14079W	PARTICIPANT	\N	PRESENT	0
127110	126080	07029T	PARTICIPANT	\N	PRESENT	0
127111	126080	04086Q	PARTICIPANT	\N	PRESENT	0
127112	126080	11090Q	PARTICIPANT	\N	PRESENT	0
127113	126080	11083R	PARTICIPANT	\N	PRESENT	0
127114	126080	11084S	PARTICIPANT	\N	PRESENT	0
127115	126080	14215L	PARTICIPANT	\N	PRESENT	0
127116	126080	08019V	PARTICIPANT	\N	PRESENT	0
126972	120699	14259Y	PARTICIPANT	\N	EXCUSE	0
126988	126004	07034Q	PARTICIPANT	\N	PRESENT	0
127117	126080	11026G	PARTICIPANT	\N	PRESENT	0
127118	126080	09001P	PARTICIPANT	\N	PRESENT	0
127120	127119	11074Q	PARTICIPANT	\N	PRESENT	0
127121	127119	11083R	PARTICIPANT	\N	PRESENT	0
127123	126080	01015L	PARTICIPANT	\N	PRESENT	0
127124	127122	11074Q	PARTICIPANT	\N	PRESENT	0
127125	127122	11083R	PARTICIPANT	\N	PRESENT	0
127095	127094	01048V	PARTICIPANT	\N	PRESENT	0
127127	127126	11074Q	PARTICIPANT	\N	PRESENT	0
127128	127126	11083R	PARTICIPANT	\N	PRESENT	0
127129	126080	04038G	PARTICIPANT	\N	PRESENT	0
127131	127130	11074Q	PARTICIPANT	\N	PRESENT	0
127132	127130	11083R	PARTICIPANT	\N	PRESENT	0
127134	127133	04055H	PARTICIPANT	\N	PRESENT	0
127135	126080	14331P	PARTICIPANT	\N	PRESENT	0
127137	127136	01031L	PARTICIPANT	\N	PRESENT	0
127139	127138	07024N	PARTICIPANT	\N	PRESENT	0
127140	127138	01014K	PARTICIPANT	\N	PRESENT	0
127141	127138	11106F	PARTICIPANT	\N	PRESENT	0
127143	127142	01056V	PARTICIPANT	\N	PRESENT	0
127144	127142	11106F	PARTICIPANT	\N	PRESENT	0
127146	127145	04071H	PARTICIPANT	\N	PRESENT	0
127147	126080	04067M	PARTICIPANT	\N	PRESENT	0
127148	126080	04080J	PARTICIPANT	\N	PRESENT	0
127149	126080	11077T	PARTICIPANT	\N	PRESENT	0
127151	127150	14028W	PARTICIPANT	\N	PRESENT	0
127152	127150	01027Q	PARTICIPANT	\N	PRESENT	0
127154	127153	14028W	PARTICIPANT	\N	PRESENT	0
127155	127153	01027Q	PARTICIPANT	\N	PRESENT	0
127157	127156	01027Q	PARTICIPANT	\N	PRESENT	0
127158	127156	14028W	PARTICIPANT	\N	PRESENT	0
127159	126080	04035D	PARTICIPANT	\N	PRESENT	0
127173	127172	14215L	PARTICIPANT	\N	PRESENT	0
127175	127174	14215L	PARTICIPANT	\N	PRESENT	0
127176	120699	14017T	PARTICIPANT	\N	EXCUSE	0
127177	120699	14039A	PARTICIPANT	\N	EXCUSE	0
127181	127180	08042U	PARTICIPANT	\N	PRESENT	0
127183	127182	08042U	PARTICIPANT	\N	PRESENT	0
127185	127184	08042U	PARTICIPANT	\N	PRESENT	0
127186	127178	08042U	PARTICIPANT	\N	PRESENT	0
127187	127179	08042U	PARTICIPANT	\N	PRESENT	0
127213	120699	96003C	PARTICIPANT	\N	EXCUSE	0
127195	120699	14219Q	PARTICIPANT	\N	EXCUSE	0
127212	120699	14053L	PARTICIPANT	\N	EXCUSE	0
127216	127214	11093T	PARTICIPANT	\N	PRESENT	0
127217	127215	11093T	PARTICIPANT	\N	PRESENT	0
127219	127218	11093T	PARTICIPANT	\N	PRESENT	0
127221	127220	11097X	PARTICIPANT	\N	PRESENT	0
127223	127222	11097X	PARTICIPANT	\N	PRESENT	0
127229	127228	14253S	PARTICIPANT	\N	PRESENT	0
127226	127224	14253S	PARTICIPANT	\N	PRESENT	0
127227	127224	14157T	PARTICIPANT	\N	PRESENT	0
127230	127228	14157T	PARTICIPANT	\N	PRESENT	0
127232	127231	14253S	PARTICIPANT	\N	PRESENT	0
127233	127231	14157T	PARTICIPANT	\N	PRESENT	0
127235	127234	14253S	PARTICIPANT	\N	PRESENT	0
127236	127234	14157T	PARTICIPANT	\N	PRESENT	0
115853	115852	14038Y	PARTICIPANT	\N	PRESENT	0
115854	115852	14219Q	PARTICIPANT	\N	PRESENT	0
115855	115852	14169X	PARTICIPANT	\N	PRESENT	0
115856	115852	14051J	PARTICIPANT	\N	PRESENT	0
115857	115852	08009T	PARTICIPANT	\N	PRESENT	0
117053	117052	98035U	PARTICIPANT	\N	PRESENT	0
117054	117052	14209N	PARTICIPANT	\N	PRESENT	0
118515	118514	89017R	PARTICIPANT	\N	PRESENT	0
119533	119532	04067M	PARTICIPANT	\N	PRESENT	0
119534	119532	14217N	PARTICIPANT	\N	PRESENT	0
119535	119532	14037X	PARTICIPANT	\N	PRESENT	0
119536	119532	14265W	PARTICIPANT	\N	PRESENT	0
119537	119532	83047W	PARTICIPANT	\N	PRESENT	0
119538	119532	01034P	PRESIDENT	0	PRESENT	0
119539	119532	11066Q	PARTICIPANT	\N	PRESENT	0
119540	119532	14079W	PARTICIPANT	\N	EXCUSE	0
120964	120963	96004D	PARTICIPANT	\N	PRESENT	0
120965	120963	11012A	PARTICIPANT	\N	PRESENT	0
120966	120963	04045F	PARTICIPANT	\N	PRESENT	0
120967	120963	04057K	PARTICIPANT	\N	PRESENT	0
122542	121159	11105E	PARTICIPANT	\N	PRESENT	0
122543	121159	08031R	PARTICIPANT	\N	PRESENT	0
122544	121159	14263U	PARTICIPANT	\N	PRESENT	0
122545	121159	04050C	PARTICIPANT	\N	PRESENT	0
122546	121159	04088S	PARTICIPANT	\N	PRESENT	0
122547	121159	14026U	PARTICIPANT	\N	PRESENT	0
122548	121159	14031R	PARTICIPANT	\N	PRESENT	0
119552	119532	14121F	PARTICIPANT	\N	EXCUSE	0
122549	121159	14157T	PARTICIPANT	\N	PRESENT	0
122550	121159	11053K	PARTICIPANT	\N	PRESENT	0
122551	121159	14030Q	PARTICIPANT	\N	PRESENT	0
122552	121159	11012A	PARTICIPANT	\N	PRESENT	0
122553	121159	88008L	PARTICIPANT	\N	PRESENT	0
122554	121159	11100Y	PARTICIPANT	\N	PRESENT	0
122555	121159	14059S	PARTICIPANT	\N	PRESENT	0
122556	121159	14213J	PARTICIPANT	\N	PRESENT	0
122557	121159	14159V	PARTICIPANT	\N	PRESENT	0
122558	121159	11109J	PARTICIPANT	\N	PRESENT	0
122559	121159	04095R	PARTICIPANT	\N	PRESENT	0
122560	121159	01013J	PARTICIPANT	\N	PRESENT	0
122561	121159	01024M	PARTICIPANT	\N	PRESENT	0
122562	121159	08041T	PARTICIPANT	\N	PRESENT	0
122563	121159	14223L	PARTICIPANT	\N	PRESENT	0
122568	121159	11046L	PARTICIPANT	\N	PRESENT	0
122569	121159	87003B	PARTICIPANT	\N	PRESENT	0
122570	121159	11043H	PARTICIPANT	\N	PRESENT	0
122571	121159	14033T	PARTICIPANT	\N	PRESENT	0
122572	121159	14219Q	PARTICIPANT	\N	PRESENT	0
122573	121159	11097X	PARTICIPANT	\N	PRESENT	0
122574	121159	11090Q	PARTICIPANT	\N	PRESENT	0
122575	121159	05012A	PARTICIPANT	\N	PRESENT	0
122576	121159	11112D	PARTICIPANT	\N	PRESENT	0
122577	121159	11098Y	PARTICIPANT	\N	PRESENT	0
122578	121159	14201E	PARTICIPANT	\N	PRESENT	0
122579	121159	14042U	PARTICIPANT	\N	PRESENT	0
122580	121159	98053W	PARTICIPANT	\N	PRESENT	0
122581	121159	08024S	PARTICIPANT	\N	PRESENT	0
122584	121159	01048V	PARTICIPANT	\N	PRESENT	0
122585	121159	92045V	PARTICIPANT	\N	PRESENT	0
122586	121159	01025N	PARTICIPANT	\N	PRESENT	0
122587	121159	11088W	PARTICIPANT	\N	PRESENT	0
122588	121159	08069G	PARTICIPANT	\N	PRESENT	0
122589	121159	08034U	PARTICIPANT	\N	PRESENT	0
122590	121159	01057W	PARTICIPANT	\N	PRESENT	0
122591	121159	14269B	PARTICIPANT	\N	PRESENT	0
122592	121159	08010L	PARTICIPANT	\N	PRESENT	0
122593	121159	14327T	PARTICIPANT	\N	PRESENT	0
122594	121159	11064N	PARTICIPANT	\N	PRESENT	0
122606	121159	14265W	PARTICIPANT	\N	PRESENT	0
122596	121159	14083S	PARTICIPANT	\N	PRESENT	0
122597	121159	14053L	PARTICIPANT	\N	PRESENT	0
122598	121159	97011G	PARTICIPANT	\N	PRESENT	0
122599	121159	10015M	PARTICIPANT	\N	PRESENT	0
122600	121159	14119M	PARTICIPANT	\N	PRESENT	0
122601	121159	14217N	PARTICIPANT	\N	PRESENT	0
122602	121159	04067M	PARTICIPANT	\N	PRESENT	0
122603	121159	86044G	PARTICIPANT	\N	PRESENT	0
122604	121159	11059R	PARTICIPANT	\N	PRESENT	0
122605	121159	11042G	PARTICIPANT	\N	PRESENT	0
122607	121159	14105F	PARTICIPANT	\N	PRESENT	0
122608	121159	11039M	PARTICIPANT	\N	PRESENT	0
122609	121160	01007L	PARTICIPANT	\N	PRESENT	0
122610	121160	14235Q	PARTICIPANT	\N	PRESENT	0
122611	121160	11034G	PARTICIPANT	\N	PRESENT	0
122612	121160	11089X	PARTICIPANT	\N	PRESENT	0
122613	121160	11104D	PARTICIPANT	\N	PRESENT	0
122614	121160	01028R	PARTICIPANT	\N	PRESENT	0
122615	121160	08043V	PARTICIPANT	\N	PRESENT	0
122616	121160	14207L	PARTICIPANT	\N	PRESENT	0
122617	121160	11109J	PARTICIPANT	\N	PRESENT	0
122618	121160	11055M	PARTICIPANT	\N	PRESENT	0
122619	121160	14187A	PARTICIPANT	\N	PRESENT	0
122620	121160	14231L	PARTICIPANT	\N	PRESENT	0
122621	121160	88008L	PARTICIPANT	\N	PRESENT	0
122622	121160	80013X	PARTICIPANT	\N	PRESENT	0
122623	121160	11094U	PARTICIPANT	\N	PRESENT	0
122624	121160	14269B	PARTICIPANT	\N	PRESENT	0
122625	121160	14042U	PARTICIPANT	\N	PRESENT	0
122626	121160	11098Y	PARTICIPANT	\N	PRESENT	0
122627	121160	04089T	PARTICIPANT	\N	PRESENT	0
122628	121160	01025N	PARTICIPANT	\N	PRESENT	0
122629	121160	14069U	PARTICIPANT	\N	PRESENT	0
122630	121160	14059S	PARTICIPANT	\N	PRESENT	0
122631	121160	08010L	PARTICIPANT	\N	PRESENT	0
122632	121160	11042G	PARTICIPANT	\N	PRESENT	0
122633	121160	11105E	PARTICIPANT	\N	PRESENT	0
122634	121160	14105F	PARTICIPANT	\N	PRESENT	0
122635	121160	08053X	PARTICIPANT	\N	PRESENT	0
122636	121160	14147R	PARTICIPANT	\N	PRESENT	0
122640	121160	14213J	PARTICIPANT	\N	PRESENT	0
122641	121160	11090Q	PARTICIPANT	\N	PRESENT	0
122642	121160	14119M	PARTICIPANT	\N	PRESENT	0
122643	121160	14031R	PARTICIPANT	\N	PRESENT	0
122644	121160	14053L	PARTICIPANT	\N	PRESENT	0
122645	121160	08015R	PARTICIPANT	\N	PRESENT	0
122646	121160	11048N	PARTICIPANT	\N	PRESENT	0
122647	121160	14265W	PARTICIPANT	\N	PRESENT	0
122648	121160	95030B	PARTICIPANT	\N	PRESENT	0
122649	121160	14195A	PARTICIPANT	\N	PRESENT	0
122650	121160	14033T	PARTICIPANT	\N	PRESENT	0
122651	121160	14229S	PARTICIPANT	\N	PRESENT	0
122652	121160	04088S	PARTICIPANT	\N	PRESENT	0
122653	121160	14083S	PARTICIPANT	\N	PRESENT	0
122654	121160	14215L	PARTICIPANT	\N	PRESENT	0
122655	121160	04086Q	PARTICIPANT	\N	PRESENT	0
122656	121160	14219Q	PARTICIPANT	\N	PRESENT	0
122657	121160	95015C	PARTICIPANT	\N	PRESENT	0
122658	121160	92045V	PARTICIPANT	\N	PRESENT	0
122659	121160	11063M	PARTICIPANT	\N	PRESENT	0
122660	121160	01008M	PARTICIPANT	\N	PRESENT	0
122661	121160	14073Q	PARTICIPANT	\N	PRESENT	0
122662	121160	14030Q	PARTICIPANT	\N	PRESENT	0
122663	121160	11043H	PARTICIPANT	\N	PRESENT	0
122664	121160	11112D	PARTICIPANT	\N	PRESENT	0
122665	121160	14097Y	PARTICIPANT	\N	PRESENT	0
122666	121160	14257W	PARTICIPANT	\N	PRESENT	0
122667	121160	11065P	PARTICIPANT	\N	PRESENT	0
122668	121160	14014Q	PARTICIPANT	\N	PRESENT	0
122669	121160	11036J	PARTICIPANT	\N	PRESENT	0
122670	121160	08068F	PARTICIPANT	\N	PRESENT	0
122671	121160	14107H	PARTICIPANT	\N	PRESENT	0
122672	121160	11066Q	PARTICIPANT	\N	PRESENT	0
122673	121160	08031R	PARTICIPANT	\N	PRESENT	0
122674	121160	11039M	PARTICIPANT	\N	PRESENT	0
122675	121160	10015M	PARTICIPANT	\N	PRESENT	0
122676	121160	14193X	PARTICIPANT	\N	PRESENT	0
122677	121160	14079W	PARTICIPANT	\N	PRESENT	0
122678	121160	95062K	PARTICIPANT	\N	PRESENT	0
122679	121160	14211G	PARTICIPANT	\N	PRESENT	0
122680	121160	11100Y	PARTICIPANT	\N	PRESENT	0
122681	121160	11012A	PARTICIPANT	\N	PRESENT	0
122682	121160	14034U	PARTICIPANT	\N	PRESENT	0
122683	121160	14271U	PARTICIPANT	\N	PRESENT	0
122714	122713	11097X	PARTICIPANT	\N	PRESENT	0
122716	122715	11097X	PARTICIPANT	\N	PRESENT	0
122718	122717	11097X	PARTICIPANT	\N	PRESENT	0
122720	122719	11097X	PARTICIPANT	\N	PRESENT	0
122722	122721	11097X	PARTICIPANT	\N	PRESENT	0
122724	122723	11097X	PARTICIPANT	\N	PRESENT	0
122726	122725	11097X	PARTICIPANT	\N	PRESENT	0
122728	122727	11097X	PARTICIPANT	\N	PRESENT	0
122730	122729	11093T	PARTICIPANT	\N	PRESENT	0
122732	122731	11093T	PARTICIPANT	\N	PRESENT	0
122734	122733	11093T	PARTICIPANT	\N	PRESENT	0
122736	122735	11093T	PARTICIPANT	\N	PRESENT	0
114052	113112	04081K	PARTICIPANT	\N	PRESENT	0
114131	113112	11056N	PARTICIPANT	\N	PRESENT	0
114132	113112	04044E	PARTICIPANT	\N	PRESENT	0
114133	113112	07034Q	PARTICIPANT	\N	PRESENT	0
114134	113112	01047U	PARTICIPANT	\N	PRESENT	0
114135	113112	04074L	PARTICIPANT	\N	PRESENT	0
114136	113112	14033T	PARTICIPANT	\N	PRESENT	0
114137	113112	07024N	PARTICIPANT	\N	PRESENT	0
114138	113112	14267Y	PARTICIPANT	\N	PRESENT	0
114139	113112	01034P	PARTICIPANT	\N	PRESENT	0
114140	113112	95030B	PARTICIPANT	\N	PRESENT	0
114141	113112	08051V	PARTICIPANT	\N	PRESENT	0
114142	113112	14219Q	PARTICIPANT	\N	PRESENT	0
114143	113112	14253S	PARTICIPANT	\N	PRESENT	0
114144	113112	95067Q	PARTICIPANT	\N	PRESENT	0
114145	113112	11072N	PARTICIPANT	\N	PRESENT	0
114153	113112	11033F	PARTICIPANT	\N	PRESENT	0
114154	113112	14063N	PARTICIPANT	\N	PRESENT	0
114157	113112	11040E	PARTICIPANT	\N	PRESENT	0
114160	113112	11099A	PARTICIPANT	\N	PRESENT	0
114162	113112	04038G	PARTICIPANT	\N	PRESENT	0
114163	113112	14119M	PARTICIPANT	\N	PRESENT	0
114166	113112	14103D	PARTICIPANT	\N	PRESENT	0
114167	113112	95035G	PARTICIPANT	\N	PRESENT	0
114172	113112	14053L	PARTICIPANT	\N	PRESENT	0
114173	113112	11049P	PARTICIPANT	\N	PRESENT	0
114174	113112	11088W	PARTICIPANT	\N	PRESENT	0
114175	113112	08048B	PARTICIPANT	\N	PRESENT	0
114176	113112	14083S	PARTICIPANT	\N	PRESENT	0
114177	113112	08055A	PARTICIPANT	\N	PRESENT	0
114178	113112	14065Q	PARTICIPANT	\N	PRESENT	0
114179	113112	01003G	PARTICIPANT	\N	PRESENT	0
114183	113112	01013J	PARTICIPANT	\N	PRESENT	0
114184	113112	11029K	PARTICIPANT	\N	PRESENT	0
114185	113112	11077T	PARTICIPANT	\N	PRESENT	0
114186	113112	95062K	PARTICIPANT	\N	PRESENT	0
114187	113112	14169X	PARTICIPANT	\N	PRESENT	0
114188	113112	14031R	PARTICIPANT	\N	PRESENT	0
114189	113112	95063L	PARTICIPANT	\N	PRESENT	0
114192	113112	11103C	PARTICIPANT	\N	PRESENT	0
114193	113112	11093T	PARTICIPANT	\N	PRESENT	0
114194	113112	08069G	PARTICIPANT	\N	PRESENT	0
114235	113112	14179A	PARTICIPANT	\N	PRESENT	0
114236	113112	14030Q	PARTICIPANT	\N	PRESENT	0
114237	113112	11105E	PARTICIPANT	\N	PRESENT	0
114238	113112	80027E	PARTICIPANT	\N	PRESENT	0
114239	113112	01057W	PARTICIPANT	\N	PRESENT	0
114240	113112	97011G	PARTICIPANT	\N	PRESENT	0
114289	113114	07034Q	PARTICIPANT	\N	PRESENT	0
114290	113114	95062K	PARTICIPANT	\N	PRESENT	0
114291	113114	01057W	PARTICIPANT	\N	PRESENT	0
114292	113114	08069G	PARTICIPANT	\N	PRESENT	0
114293	113114	92045V	PARTICIPANT	\N	PRESENT	0
114294	113114	14213J	PARTICIPANT	\N	PRESENT	0
114295	113114	90003B	PARTICIPANT	\N	PRESENT	0
114296	113114	08048B	PARTICIPANT	\N	PRESENT	0
114297	113114	14053L	PARTICIPANT	\N	PRESENT	0
114298	113114	97011G	PARTICIPANT	\N	PRESENT	0
114299	113114	11103C	PARTICIPANT	\N	PRESENT	0
114300	113114	11093T	PARTICIPANT	\N	PRESENT	0
114301	113114	14083S	PARTICIPANT	\N	PRESENT	0
114302	113114	14030Q	PARTICIPANT	\N	PRESENT	0
114303	113114	14219Q	PARTICIPANT	\N	PRESENT	0
114304	113114	14267Y	PARTICIPANT	\N	PRESENT	0
114305	113114	14179A	PARTICIPANT	\N	PRESENT	0
114306	113114	14103D	PARTICIPANT	\N	PRESENT	0
114307	113114	11099A	PARTICIPANT	\N	PRESENT	0
114308	113114	11029K	PARTICIPANT	\N	PRESENT	0
114309	113114	14169X	PARTICIPANT	\N	PRESENT	0
114310	113114	01028R	PARTICIPANT	\N	PRESENT	0
114311	113114	04045F	PARTICIPANT	\N	PRESENT	0
114312	113114	11066Q	PARTICIPANT	\N	PRESENT	0
114313	113114	14001X	PARTICIPANT	\N	PRESENT	0
114314	113114	04034C	PARTICIPANT	\N	PRESENT	0
114315	113114	80027E	PARTICIPANT	\N	PRESENT	0
114316	113114	01013J	PARTICIPANT	\N	PRESENT	0
114317	113114	11040E	PARTICIPANT	\N	PRESENT	0
114318	113114	14051J	PARTICIPANT	\N	PRESENT	0
114319	113114	95063L	PARTICIPANT	\N	PRESENT	0
114320	113114	14063N	PARTICIPANT	\N	PRESENT	0
114321	113114	07024N	PARTICIPANT	\N	PRESENT	0
114322	113114	11083R	PARTICIPANT	\N	PRESENT	0
114323	113114	07004J	PARTICIPANT	\N	PRESENT	0
114324	113114	08061X	PARTICIPANT	\N	PRESENT	0
114325	113114	88008L	PARTICIPANT	\N	PRESENT	0
114326	113114	08031R	PARTICIPANT	\N	PRESENT	0
114327	113114	04038G	PARTICIPANT	\N	PRESENT	0
114328	113114	08051V	PARTICIPANT	\N	PRESENT	0
114329	113114	80013X	PARTICIPANT	\N	PRESENT	0
114330	113114	14013P	PARTICIPANT	\N	PRESENT	0
114331	113114	98053W	PARTICIPANT	\N	PRESENT	0
114332	113114	01015L	PARTICIPANT	\N	PRESENT	0
114333	113114	13002U	PARTICIPANT	\N	PRESENT	0
114334	113114	08025T	PARTICIPANT	\N	PRESENT	0
114287	113114	04081K	PARTICIPANT	\N	PRESENT	0
114336	113114	14038Y	PARTICIPANT	\N	PRESENT	0
114335	113114	04044E	PARTICIPANT	\N	PRESENT	0
114337	113114	14175V	PARTICIPANT	\N	PRESENT	0
114338	113114	08024S	PARTICIPANT	\N	PRESENT	0
114339	113114	14147R	PARTICIPANT	\N	PRESENT	0
114340	113114	11049P	PARTICIPANT	\N	PRESENT	0
114341	113114	14041T	PARTICIPANT	\N	PRESENT	0
114342	113114	14033T	PARTICIPANT	\N	PRESENT	0
114352	113114	14195A	PARTICIPANT	\N	PRESENT	0
114353	113114	04057K	PARTICIPANT	\N	PRESENT	0
114354	113114	11097X	PARTICIPANT	\N	PRESENT	0
114355	113114	14265W	PARTICIPANT	\N	PRESENT	0
114356	113114	14217N	PARTICIPANT	\N	PRESENT	0
114357	113114	14331P	PARTICIPANT	\N	PRESENT	0
114358	113114	11036J	PARTICIPANT	\N	PRESENT	0
114359	113114	14097Y	PARTICIPANT	\N	PRESENT	0
114360	113114	10015M	PARTICIPANT	\N	PRESENT	0
114361	113114	01031L	PARTICIPANT	\N	PRESENT	0
114362	113114	11107G	PARTICIPANT	\N	PRESENT	0
114363	113114	14329V	PARTICIPANT	\N	PRESENT	0
114364	113114	11067R	PARTICIPANT	\N	PRESENT	0
114365	113114	08039A	PARTICIPANT	\N	PRESENT	0
114366	113114	01056V	PARTICIPANT	\N	PRESENT	0
114367	113114	11012A	PARTICIPANT	\N	PRESENT	0
114368	113114	11053K	PARTICIPANT	\N	PRESENT	0
114369	113114	01027Q	PARTICIPANT	\N	PRESENT	0
114370	113114	11010L	PARTICIPANT	\N	PRESENT	0
114371	113114	14215L	PARTICIPANT	\N	PRESENT	0
114372	113114	14069U	PARTICIPANT	\N	PRESENT	0
114373	113114	14031R	PARTICIPANT	\N	PRESENT	0
114374	113114	11042G	PARTICIPANT	\N	PRESENT	0
114375	113114	14207L	PARTICIPANT	\N	PRESENT	0
114376	113114	14159V	PARTICIPANT	\N	PRESENT	0
114377	113114	01007L	PARTICIPANT	\N	PRESENT	0
114392	113114	14059S	PARTICIPANT	\N	PRESENT	0
114393	113114	11077T	PARTICIPANT	\N	PRESENT	0
114394	113114	04067M	PARTICIPANT	\N	PRESENT	0
114395	113114	12042Y	PARTICIPANT	\N	PRESENT	0
114396	113114	14111D	PARTICIPANT	\N	PRESENT	0
114397	113114	14061L	PARTICIPANT	\N	PRESENT	0
114398	113114	08019V	PARTICIPANT	\N	PRESENT	0
114399	113114	95030B	PARTICIPANT	\N	PRESENT	0
114400	113114	01016M	PARTICIPANT	\N	PRESENT	0
114401	113114	14014Q	PARTICIPANT	\N	PRESENT	0
114402	113114	11112D	PARTICIPANT	\N	PRESENT	0
114403	113114	11057P	PARTICIPANT	\N	PRESENT	0
114404	113114	14231L	PARTICIPANT	\N	PRESENT	0
114405	113114	14089Y	PARTICIPANT	\N	PRESENT	0
114406	113114	04080J	PARTICIPANT	\N	PRESENT	0
114412	113114	08068F	PARTICIPANT	\N	PRESENT	0
114413	113114	14121F	PARTICIPANT	\N	PRESENT	0
114432	113114	11090Q	PARTICIPANT	\N	PRESENT	0
114433	113114	11023D	PARTICIPANT	\N	PRESENT	0
114434	113114	01058X	PARTICIPANT	\N	PRESENT	0
114443	113114	14271U	PARTICIPANT	\N	PRESENT	0
114444	113114	11039M	PARTICIPANT	\N	PRESENT	0
114445	113114	08052W	PARTICIPANT	\N	PRESENT	0
114446	113114	14273W	PARTICIPANT	\N	PRESENT	0
114447	113114	98050T	PARTICIPANT	\N	PRESENT	0
114448	113114	04049K	PARTICIPANT	\N	PRESENT	0
114449	113114	95067Q	PARTICIPANT	\N	PRESENT	0
114450	113114	14085U	PARTICIPANT	\N	PRESENT	0
114451	113114	11104D	PARTICIPANT	\N	PRESENT	0
114452	113114	01047U	PARTICIPANT	\N	PRESENT	0
114467	113114	04053F	PARTICIPANT	\N	PRESENT	0
114468	113114	11110B	PARTICIPANT	\N	PRESENT	0
114469	113114	11098Y	PARTICIPANT	\N	PRESENT	0
114521	113114	08034U	PARTICIPANT	\N	PRESENT	0
114523	113114	11043H	PARTICIPANT	\N	PRESENT	0
114524	113114	14253S	PARTICIPANT	\N	PRESENT	0
114526	113114	08011M	PARTICIPANT	\N	PRESENT	0
114527	113114	08055A	PARTICIPANT	\N	PRESENT	0
114532	113114	04085P	PARTICIPANT	\N	PRESENT	0
92634	92217	14239U	PARTICIPANT	\N	PRESENT	0
92635	92217	14241N	PARTICIPANT	\N	PRESENT	0
92636	92217	08051V	PARTICIPANT	\N	PRESENT	0
92637	92217	14251Q	PARTICIPANT	\N	PRESENT	0
92638	92217	04050C	PARTICIPANT	\N	PRESENT	0
92639	92217	92045V	PARTICIPANT	\N	PRESENT	0
92640	92217	08016S	PARTICIPANT	\N	PRESENT	0
92641	92217	01016M	PARTICIPANT	\N	PRESENT	0
92642	92217	11039M	PARTICIPANT	\N	PRESENT	0
92643	92217	98023Q	PARTICIPANT	\N	PRESENT	0
92644	92217	05012A	PARTICIPANT	\N	PRESENT	0
92645	92217	92015P	PARTICIPANT	\N	PRESENT	0
92646	92217	14193X	PARTICIPANT	\N	PRESENT	0
92647	92217	98046X	PARTICIPANT	\N	PRESENT	0
92648	92217	14033T	PARTICIPANT	\N	PRESENT	0
92649	92217	08052W	PARTICIPANT	\N	PRESENT	0
92650	92217	95063L	PARTICIPANT	\N	PRESENT	0
92651	92217	14151M	PARTICIPANT	\N	PRESENT	0
92652	92217	01027Q	PARTICIPANT	\N	PRESENT	0
92653	92217	08055A	PARTICIPANT	\N	PRESENT	0
92654	92217	01031L	PARTICIPANT	\N	PRESENT	0
92655	92217	95030B	PARTICIPANT	\N	PRESENT	0
92656	92217	04066L	PARTICIPANT	\N	PRESENT	0
92657	92217	14107H	PARTICIPANT	\N	PRESENT	0
92658	92217	01060R	PARTICIPANT	\N	PRESENT	0
92659	92217	86044G	PARTICIPANT	\N	PRESENT	0
92660	92217	14135M	PARTICIPANT	\N	PRESENT	0
92661	92217	01011G	PARTICIPANT	\N	PRESENT	0
92662	92217	11057P	PARTICIPANT	\N	PRESENT	0
92663	92217	92020L	PARTICIPANT	\N	PRESENT	0
92664	92217	08060W	PARTICIPANT	\N	PRESENT	0
92665	92217	04035D	PARTICIPANT	\N	PRESENT	0
92666	92217	00003C	PARTICIPANT	\N	PRESENT	0
92667	92217	80013X	PARTICIPANT	\N	PRESENT	0
92668	92217	07024N	PARTICIPANT	\N	PRESENT	0
92669	92217	14028W	PARTICIPANT	\N	PRESENT	0
92670	92217	04092N	PARTICIPANT	\N	PRESENT	0
92671	92217	14197C	PARTICIPANT	\N	PRESENT	0
92672	92217	11099A	PARTICIPANT	\N	PRESENT	0
92673	92217	04057K	PARTICIPANT	\N	PRESENT	0
92674	92217	14065Q	PARTICIPANT	\N	PRESENT	0
92675	92217	97011G	PARTICIPANT	\N	PRESENT	0
92676	92217	11015D	PARTICIPANT	\N	PRESENT	0
92677	92217	11103C	PARTICIPANT	\N	PRESENT	0
92678	92217	08068F	PARTICIPANT	\N	PRESENT	0
92679	92217	11105E	PARTICIPANT	\N	PRESENT	0
92680	92217	14147R	PARTICIPANT	\N	PRESENT	0
92681	92217	11027H	PARTICIPANT	\N	PRESENT	0
92682	92217	08047A	PARTICIPANT	\N	PRESENT	0
92683	92217	11089X	PARTICIPANT	\N	PRESENT	0
92684	92217	11036J	PARTICIPANT	\N	PRESENT	0
92685	92217	11097X	PARTICIPANT	\N	PRESENT	0
92686	92217	11100Y	PARTICIPANT	\N	PRESENT	0
92687	92217	08012N	PARTICIPANT	\N	PRESENT	0
92688	92217	08069G	PARTICIPANT	\N	PRESENT	0
92689	92217	80027E	PARTICIPANT	\N	PRESENT	0
92690	92217	11059R	PARTICIPANT	\N	PRESENT	0
92691	92217	10015M	PARTICIPANT	\N	PRESENT	0
92692	92217	11046L	PARTICIPANT	\N	PRESENT	0
92693	92217	08053X	PARTICIPANT	\N	PRESENT	0
92694	92217	08034U	PARTICIPANT	\N	PRESENT	0
92695	92217	83042R	PARTICIPANT	\N	PRESENT	0
92696	92217	14157T	PARTICIPANT	\N	PRESENT	0
92697	92217	04034C	PARTICIPANT	\N	PRESENT	0
92698	92217	95037J	PARTICIPANT	\N	PRESENT	0
92699	92217	01056V	PARTICIPANT	\N	PRESENT	0
92700	92217	11095V	PARTICIPANT	\N	PRESENT	0
92701	92217	08058D	PARTICIPANT	\N	PRESENT	0
92702	92217	14038Y	PARTICIPANT	\N	PRESENT	0
92703	92217	14271U	PARTICIPANT	\N	PRESENT	0
92704	92217	14133K	PARTICIPANT	\N	PRESENT	0
92705	92217	83047W	PARTICIPANT	\N	PRESENT	0
92706	92217	14175V	PARTICIPANT	\N	PRESENT	0
92707	92217	14014Q	PARTICIPANT	\N	PRESENT	0
92708	92217	07029T	PARTICIPANT	\N	PRESENT	0
92709	92217	14109K	PARTICIPANT	\N	PRESENT	0
92710	92217	11032E	PARTICIPANT	\N	PRESENT	0
92711	92217	14207L	PARTICIPANT	\N	PRESENT	0
92712	92217	14041T	PARTICIPANT	\N	PRESENT	0
92713	92217	08014Q	PARTICIPANT	\N	PRESENT	0
92714	92217	14209N	PARTICIPANT	\N	PRESENT	0
92715	92217	14001X	PARTICIPANT	\N	PRESENT	0
92716	92217	14119M	PARTICIPANT	\N	PRESENT	0
92717	92217	04079R	PARTICIPANT	\N	PRESENT	0
92718	92217	11054L	PARTICIPANT	\N	PRESENT	0
92719	92217	98050T	PARTICIPANT	\N	PRESENT	0
92720	92217	14227Q	PARTICIPANT	\N	PRESENT	0
92721	92217	08019V	PARTICIPANT	\N	PRESENT	0
92722	92217	14167V	PARTICIPANT	\N	PRESENT	0
92723	92217	14059S	PARTICIPANT	\N	PRESENT	0
92724	92217	14329V	PARTICIPANT	\N	PRESENT	0
92725	92217	11014C	PARTICIPANT	\N	PRESENT	0
92726	92217	14257W	PARTICIPANT	\N	PRESENT	0
92727	92217	01008M	PARTICIPANT	\N	PRESENT	0
92728	92217	14097Y	PARTICIPANT	\N	PRESENT	0
92729	92217	07032N	PARTICIPANT	\N	PRESENT	0
92730	92217	11074Q	PARTICIPANT	\N	PRESENT	0
92731	92217	14063N	PARTICIPANT	\N	PRESENT	0
92732	92217	07034Q	PARTICIPANT	\N	PRESENT	0
92733	92217	14121F	PARTICIPANT	\N	PRESENT	0
92734	92217	04088S	PARTICIPANT	\N	PRESENT	0
92735	92217	14229S	PARTICIPANT	\N	PRESENT	0
92736	92217	14281W	PARTICIPANT	\N	PRESENT	0
92737	92217	08018U	PARTICIPANT	\N	PRESENT	0
92738	92217	04077P	PARTICIPANT	\N	PRESENT	0
92739	92217	08061X	PARTICIPANT	\N	PRESENT	0
92740	92217	11090Q	PARTICIPANT	\N	PRESENT	0
92741	92217	04056J	PARTICIPANT	\N	PRESENT	0
92742	92217	14061L	PARTICIPANT	\N	PRESENT	0
92743	92217	04053F	PARTICIPANT	\N	PRESENT	0
92744	92217	14187A	PARTICIPANT	\N	PRESENT	0
92745	92217	11042G	PARTICIPANT	\N	PRESENT	0
93608	92318	14105F	PARTICIPANT	\N	PRESENT	0
92747	92217	11110B	PARTICIPANT	\N	PRESENT	0
92748	92217	08015R	PARTICIPANT	\N	PRESENT	0
92749	92217	08038Y	PARTICIPANT	\N	PRESENT	0
92750	92217	99002P	PARTICIPANT	\N	PRESENT	0
92751	92217	92039X	PARTICIPANT	\N	PRESENT	0
92752	92217	14053L	PARTICIPANT	\N	PRESENT	0
92753	92217	11035H	PARTICIPANT	\N	PRESENT	0
92754	92217	08024S	PARTICIPANT	\N	PRESENT	0
92755	92217	11091R	PARTICIPANT	\N	PRESENT	0
92756	92217	04059M	PARTICIPANT	\N	PRESENT	0
92757	92217	11067R	PARTICIPANT	\N	PRESENT	0
92758	92217	11033F	PARTICIPANT	\N	PRESENT	0
92759	92217	14085U	PARTICIPANT	\N	PRESENT	0
92760	92217	11106F	PARTICIPANT	\N	PRESENT	0
92761	92217	11066Q	PARTICIPANT	\N	PRESENT	0
92762	92217	14265W	PARTICIPANT	\N	PRESENT	0
92763	92217	04086Q	PARTICIPANT	\N	PRESENT	0
92764	92217	05008E	PARTICIPANT	\N	PRESENT	0
92765	92217	08065C	PARTICIPANT	\N	PRESENT	0
92766	92217	11084S	PARTICIPANT	\N	PRESENT	0
92767	92217	11112D	PARTICIPANT	\N	PRESENT	0
92768	92217	11077T	PARTICIPANT	\N	PRESENT	0
93546	92318	08055A	PARTICIPANT	\N	PRESENT	0
93609	92318	14273W	PARTICIPANT	\N	PRESENT	0
93610	92318	11066Q	PARTICIPANT	\N	PRESENT	0
93611	92318	08068F	PARTICIPANT	\N	PRESENT	0
93612	92318	01031L	PARTICIPANT	\N	PRESENT	0
93613	92318	11040E	PARTICIPANT	\N	PRESENT	0
93614	92318	07029T	PARTICIPANT	\N	PRESENT	0
93615	92318	11029K	PARTICIPANT	\N	PRESENT	0
93616	92318	01013J	PARTICIPANT	\N	PRESENT	0
93617	92318	11077T	PARTICIPANT	\N	PRESENT	0
93618	92318	11042G	PARTICIPANT	\N	PRESENT	0
93619	92318	01022K	PARTICIPANT	\N	PRESENT	0
93620	92318	04038G	PARTICIPANT	\N	PRESENT	0
93621	92318	04071H	PARTICIPANT	\N	PRESENT	0
93622	92318	14061L	PARTICIPANT	\N	PRESENT	0
93623	92318	11034G	PARTICIPANT	\N	PRESENT	0
93624	92318	01015L	PARTICIPANT	\N	PRESENT	0
93625	92318	07026Q	PARTICIPANT	\N	PRESENT	0
93626	92318	11057P	PARTICIPANT	\N	PRESENT	0
93627	92318	11053K	PARTICIPANT	\N	PRESENT	0
93628	92318	11083R	PARTICIPANT	\N	PRESENT	0
93629	92318	08056B	PARTICIPANT	\N	PRESENT	0
93630	92318	14031R	PARTICIPANT	\N	PRESENT	0
93631	92318	04050C	PARTICIPANT	\N	PRESENT	0
93632	92318	98053W	PARTICIPANT	\N	PRESENT	0
93633	92318	04085P	PARTICIPANT	\N	PRESENT	0
93634	92318	11056N	PARTICIPANT	\N	PRESENT	0
93635	92318	14235Q	PARTICIPANT	\N	PRESENT	0
93636	92318	11098Y	PARTICIPANT	\N	PRESENT	0
93637	92318	04035D	PARTICIPANT	\N	PRESENT	0
93638	92318	11091R	PARTICIPANT	\N	PRESENT	0
93639	92318	14259Y	PARTICIPANT	\N	PRESENT	0
93640	92318	14225N	PARTICIPANT	\N	PRESENT	0
122834	122782	95049N	PARTICIPANT	\N	PRESENT	0
122835	122782	11033F	PARTICIPANT	\N	PRESENT	0
122916	122915	14259Y	PARTICIPANT	\N	PRESENT	0
122917	122915	98005N	PARTICIPANT	\N	PRESENT	0
122918	122915	11072N	PARTICIPANT	\N	PRESENT	0
122919	122915	08019V	PARTICIPANT	\N	PRESENT	0
122973	122972	14259Y	PARTICIPANT	\N	PRESENT	0
122981	122980	14259Y	PARTICIPANT	\N	PRESENT	0
123077	122637	08024S	PARTICIPANT	\N	PRESENT	0
123089	122637	14041T	PARTICIPANT	\N	PRESENT	0
123090	122637	11080N	PARTICIPANT	\N	PRESENT	0
123091	122637	11090Q	PARTICIPANT	\N	PRESENT	0
123092	122637	04038G	PARTICIPANT	\N	PRESENT	0
123093	122637	14211G	PARTICIPANT	\N	PRESENT	0
123094	122637	87003B	PARTICIPANT	\N	PRESENT	0
123095	122637	14231L	PARTICIPANT	\N	PRESENT	0
123096	122637	14187A	PARTICIPANT	\N	PRESENT	0
123097	122637	01028R	PARTICIPANT	\N	PRESENT	0
123098	122637	95015C	PARTICIPANT	\N	PRESENT	0
123099	122637	14135M	PARTICIPANT	\N	PRESENT	0
123100	122637	14105F	PARTICIPANT	\N	PRESENT	0
123101	122637	14030Q	PARTICIPANT	\N	PRESENT	0
123102	122637	14063N	PARTICIPANT	\N	PRESENT	0
123103	122637	08031R	PARTICIPANT	\N	PRESENT	0
123104	122637	14267Y	PARTICIPANT	\N	PRESENT	0
123105	122637	11034G	PARTICIPANT	\N	PRESENT	0
123106	122637	14235Q	PARTICIPANT	\N	PRESENT	0
123107	122637	11098Y	PARTICIPANT	\N	PRESENT	0
123108	122637	01015L	PARTICIPANT	\N	PRESENT	0
123109	122637	14271U	PARTICIPANT	\N	PRESENT	0
123110	122637	14229S	PARTICIPANT	\N	PRESENT	0
123111	122637	11066Q	PARTICIPANT	\N	PRESENT	0
123112	122637	08055A	PARTICIPANT	\N	PRESENT	0
123113	122637	11104D	PARTICIPANT	\N	PRESENT	0
123114	122637	14269B	PARTICIPANT	\N	PRESENT	0
123115	122637	14081Q	PARTICIPANT	\N	PRESENT	0
123116	122637	11029K	PARTICIPANT	\N	PRESENT	0
123117	122637	11099A	PARTICIPANT	\N	PRESENT	0
123118	122637	14042U	PARTICIPANT	\N	PRESENT	0
123119	122637	14219Q	PARTICIPANT	\N	PRESENT	0
123120	122637	14205J	PARTICIPANT	\N	PRESENT	0
123121	122637	11094U	PARTICIPANT	\N	PRESENT	0
123122	122637	11012A	PARTICIPANT	\N	PRESENT	0
123123	122637	01046T	PARTICIPANT	\N	PRESENT	0
123124	122637	14089Y	PARTICIPANT	\N	PRESENT	0
123125	122637	01043Q	PARTICIPANT	\N	PRESENT	0
123127	122637	04089T	PARTICIPANT	\N	PRESENT	0
123128	122637	14179A	PARTICIPANT	\N	PRESENT	0
123129	123126	14199E	PARTICIPANT	\N	PRESENT	0
123130	122637	95035G	PARTICIPANT	\N	PRESENT	0
123131	122637	11036J	PARTICIPANT	\N	PRESENT	0
123132	122637	04086Q	PARTICIPANT	\N	PRESENT	0
123133	122637	14059S	PARTICIPANT	\N	PRESENT	0
123134	122637	04088S	PARTICIPANT	\N	PRESENT	0
123135	122637	14327T	PARTICIPANT	\N	PRESENT	0
123136	122637	11042G	PARTICIPANT	\N	PRESENT	0
123137	122637	14026U	PARTICIPANT	\N	PRESENT	0
123138	122637	14265W	PARTICIPANT	\N	PRESENT	0
123139	122637	92045V	PARTICIPANT	\N	PRESENT	0
123140	122637	08041T	PARTICIPANT	\N	PRESENT	0
123141	122637	14199E	PARTICIPANT	\N	PRESENT	0
123142	122637	08069G	PARTICIPANT	\N	PRESENT	0
123143	122637	11011M	PARTICIPANT	\N	PRESENT	0
123144	122637	08039A	PARTICIPANT	\N	PRESENT	0
123145	122637	95062K	PARTICIPANT	\N	PRESENT	0
123146	122637	14051J	PARTICIPANT	\N	PRESENT	0
123147	122637	11109J	PARTICIPANT	\N	PRESENT	0
123148	122637	04067M	PARTICIPANT	\N	PRESENT	0
123149	122637	14147R	PARTICIPANT	\N	PRESENT	0
123150	122637	04045F	PARTICIPANT	\N	PRESENT	0
123151	122637	08017T	PARTICIPANT	\N	PRESENT	0
123152	122637	14159V	PARTICIPANT	\N	PRESENT	0
123153	122637	11027H	PARTICIPANT	\N	PRESENT	0
123154	122637	14079W	PARTICIPANT	\N	PRESENT	0
123155	122637	14107H	PARTICIPANT	\N	PRESENT	0
123156	122637	11054L	PARTICIPANT	\N	PRESENT	0
123157	122637	13002U	PARTICIPANT	\N	PRESENT	0
123158	122637	11055M	PARTICIPANT	\N	PRESENT	0
123159	122637	14237S	PARTICIPANT	\N	PRESENT	0
123160	122637	14053L	PARTICIPANT	\N	PRESENT	0
123161	122637	98050T	PARTICIPANT	\N	PRESENT	0
123162	122637	08034U	PARTICIPANT	\N	PRESENT	0
123163	122637	14119M	PARTICIPANT	\N	PRESENT	0
123164	122637	11035H	PARTICIPANT	\N	PRESENT	0
123166	122637	01008M	PARTICIPANT	\N	PRESENT	0
123167	122637	07034Q	PARTICIPANT	\N	PRESENT	0
123168	122637	04050C	PARTICIPANT	\N	PRESENT	0
123169	122637	14193X	PARTICIPANT	\N	PRESENT	0
123170	122637	11015D	PARTICIPANT	\N	PRESENT	0
123171	122637	14097Y	PARTICIPANT	\N	PRESENT	0
123172	122637	14197C	PARTICIPANT	\N	PRESENT	0
123173	122637	11105E	PARTICIPANT	\N	PRESENT	0
123174	122637	14281W	PARTICIPANT	\N	PRESENT	0
123175	122637	01003G	PARTICIPANT	\N	PRESENT	0
123176	122637	04070G	PARTICIPANT	\N	PRESENT	0
123177	122637	14037X	PARTICIPANT	\N	PRESENT	0
123178	122637	11010L	PARTICIPANT	\N	PRESENT	0
123179	122637	14261S	PARTICIPANT	\N	PRESENT	0
123180	122637	01031L	PARTICIPANT	\N	PRESENT	0
123181	122637	08015R	PARTICIPANT	\N	PRESENT	0
123182	122637	11057P	PARTICIPANT	\N	PRESENT	0
123183	122637	14207L	PARTICIPANT	\N	PRESENT	0
123184	122637	14213J	PARTICIPANT	\N	PRESENT	0
123185	122637	14225N	PARTICIPANT	\N	PRESENT	0
123186	122637	11037K	PARTICIPANT	\N	PRESENT	0
123187	122637	07032N	PARTICIPANT	\N	PRESENT	0
123188	122637	14217N	PARTICIPANT	\N	PRESENT	0
123189	122637	04081K	PARTICIPANT	\N	PRESENT	0
123190	122637	14215L	PARTICIPANT	\N	PRESENT	0
123191	122637	14083S	PARTICIPANT	\N	PRESENT	0
123192	122637	01025N	PARTICIPANT	\N	PRESENT	0
123193	118921	13002U	PARTICIPANT	\N	PRESENT	0
123196	122637	14031R	PARTICIPANT	\N	PRESENT	0
123197	122637	80013X	PARTICIPANT	\N	PRESENT	0
123198	122637	11085T	PARTICIPANT	\N	PRESENT	0
123199	122637	11061K	PARTICIPANT	\N	PRESENT	0
123200	122637	08019V	PARTICIPANT	\N	PRESENT	0
123201	122637	14173T	PARTICIPANT	\N	PRESENT	0
123202	122637	98046X	PARTICIPANT	\N	PRESENT	0
123203	122637	08062Y	PARTICIPANT	\N	PRESENT	0
123211	122637	04095R	PARTICIPANT	\N	PRESENT	0
123212	122637	14157T	PARTICIPANT	\N	PRESENT	0
123221	122637	01016M	PARTICIPANT	\N	PRESENT	0
123223	122637	10006L	PARTICIPANT	\N	PRESENT	0
123225	122637	14195A	PARTICIPANT	\N	PRESENT	0
123226	122637	14073Q	PARTICIPANT	\N	PRESENT	0
123234	122637	95030B	PARTICIPANT	\N	PRESENT	0
123235	122637	04043D	PARTICIPANT	\N	PRESENT	0
123236	122637	14241N	PARTICIPANT	\N	PRESENT	0
123239	122637	01047U	PARTICIPANT	\N	PRESENT	0
123240	122637	08051V	PARTICIPANT	\N	PRESENT	0
123242	122637	01024M	PARTICIPANT	\N	PRESENT	0
123243	122637	01057W	PARTICIPANT	\N	PRESENT	0
123244	122637	11103C	PARTICIPANT	\N	PRESENT	0
123245	122637	14033T	PARTICIPANT	\N	PRESENT	0
123247	122637	99004R	PARTICIPANT	\N	PRESENT	0
123248	122637	90003B	PARTICIPANT	\N	PRESENT	0
123249	122637	11084S	PARTICIPANT	\N	PRESENT	0
123250	122637	14253S	PARTICIPANT	\N	PRESENT	0
123257	122637	04085P	PARTICIPANT	\N	PRESENT	0
123258	122637	01048V	PARTICIPANT	\N	PRESENT	0
123259	122637	11039M	PARTICIPANT	\N	PRESENT	0
123260	122637	14065Q	PARTICIPANT	\N	PRESENT	0
123261	122637	14014Q	PARTICIPANT	\N	PRESENT	0
123320	122637	14034U	PARTICIPANT	\N	PRESENT	0
123322	122637	04035D	PARTICIPANT	\N	PRESENT	0
123323	122637	11082Q	PARTICIPANT	\N	PRESENT	0
123324	122637	05012A	PARTICIPANT	\N	PRESENT	0
123325	122637	11100Y	PARTICIPANT	\N	PRESENT	0
123326	122637	11046L	PARTICIPANT	\N	PRESENT	0
123327	122637	97011G	PARTICIPANT	\N	PRESENT	0
123328	122637	11089X	PARTICIPANT	\N	PRESENT	0
123329	122637	11064N	PARTICIPANT	\N	PRESENT	0
96705	96698	11053K	PARTICIPANT	\N	PRESENT	0
96853	96852	04086Q	PARTICIPANT	\N	PRESENT	0
96855	96852	04067M	PARTICIPANT	\N	PRESENT	0
96856	96852	01027Q	PARTICIPANT	\N	PRESENT	0
96857	96852	12042Y	PRESIDENT	0	PRESENT	0
96858	96852	11107G	PARTICIPANT	\N	PRESENT	0
96860	96852	14014Q	PARTICIPANT	\N	PRESENT	0
96861	96852	11112D	PARTICIPANT	\N	PRESENT	0
96862	96852	04049K	PARTICIPANT	\N	PRESENT	0
96863	96852	14205J	PARTICIPANT	\N	PRESENT	0
96865	96852	11097X	PARTICIPANT	\N	PRESENT	0
96866	96852	14227Q	PARTICIPANT	\N	PRESENT	0
96868	96852	04050C	PARTICIPANT	\N	PRESENT	0
96872	96871	01013J	PARTICIPANT	\N	PRESENT	0
96875	96874	01013J	PARTICIPANT	\N	PRESENT	0
97184	97183	98046X	PARTICIPANT	\N	PRESENT	0
97186	97185	98046X	PARTICIPANT	\N	PRESENT	0
101035	100267	86034E	PARTICIPANT	\N	PRESENT	0
101131	100267	98018T	PARTICIPANT	\N	PRESENT	0
101151	100267	14105F	PARTICIPANT	\N	PRESENT	0
101167	100267	14013P	PARTICIPANT	\N	PRESENT	0
101168	100267	13002U	PARTICIPANT	\N	PRESENT	0
101169	100267	09001P	PARTICIPANT	\N	PRESENT	0
101170	100267	11049P	PARTICIPANT	\N	PRESENT	0
101171	100267	01044R	PARTICIPANT	\N	PRESENT	0
101172	100267	01022K	PARTICIPANT	\N	PRESENT	0
101173	100267	11054L	PARTICIPANT	\N	PRESENT	0
101174	100267	08055A	PARTICIPANT	\N	PRESENT	0
101175	100267	98046X	PARTICIPANT	\N	PRESENT	0
101176	100267	11107G	PARTICIPANT	\N	PRESENT	0
101177	100267	14273W	PARTICIPANT	\N	PRESENT	0
101178	100267	04042C	PARTICIPANT	\N	PRESENT	0
101179	100267	01015L	PARTICIPANT	\N	PRESENT	0
101180	100267	11067R	PARTICIPANT	\N	PRESENT	0
101181	100267	11065P	PARTICIPANT	\N	PRESENT	0
101182	100267	95035G	PARTICIPANT	\N	PRESENT	0
101183	100267	11098Y	PARTICIPANT	\N	PRESENT	0
101184	100267	08009T	PARTICIPANT	\N	PRESENT	0
101185	100267	92015P	PARTICIPANT	\N	PRESENT	0
101187	100267	14253S	PARTICIPANT	\N	PRESENT	0
101188	100267	11048N	PARTICIPANT	\N	PRESENT	0
101189	100267	14014Q	PARTICIPANT	\N	PRESENT	0
101192	100267	14093U	PARTICIPANT	\N	PRESENT	0
101193	100267	14051J	PARTICIPANT	\N	PRESENT	0
101195	100267	96004D	PARTICIPANT	\N	PRESENT	0
101253	100267	14107H	PARTICIPANT	\N	PRESENT	0
101254	100267	97011G	PARTICIPANT	\N	PRESENT	0
101255	100267	98050T	PARTICIPANT	\N	PRESENT	0
101256	100267	95059Q	PARTICIPANT	\N	PRESENT	0
101257	100267	08065C	PARTICIPANT	\N	PRESENT	0
101258	100267	14063N	PARTICIPANT	\N	PRESENT	0
101259	100267	14257W	PARTICIPANT	\N	PRESENT	0
101260	100267	14263U	PARTICIPANT	\N	PRESENT	0
101261	100267	04050C	PARTICIPANT	\N	PRESENT	0
101262	100267	14247U	PARTICIPANT	\N	PRESENT	0
101263	100267	04061F	PARTICIPANT	\N	PRESENT	0
101264	100267	14241N	PARTICIPANT	\N	PRESENT	0
101265	100267	14030Q	PARTICIPANT	\N	PRESENT	0
101266	100267	04067M	PARTICIPANT	\N	PRESENT	0
101267	100267	14133K	PARTICIPANT	\N	PRESENT	0
101268	100267	08058D	PARTICIPANT	\N	PRESENT	0
101269	100267	98021N	PARTICIPANT	\N	PRESENT	0
101270	100267	14169X	PARTICIPANT	\N	PRESENT	0
101271	100267	14259Y	PARTICIPANT	\N	PRESENT	0
101272	100267	01013J	PARTICIPANT	\N	PRESENT	0
101273	100267	14119M	PARTICIPANT	\N	PRESENT	0
101274	100267	14179A	PARTICIPANT	\N	PRESENT	0
101275	100267	04080J	PARTICIPANT	\N	PRESENT	0
101276	100267	08016S	PARTICIPANT	\N	PRESENT	0
101277	100267	14173T	PARTICIPANT	\N	PRESENT	0
101278	100267	04097T	PARTICIPANT	\N	PRESENT	0
101279	100267	14195A	PARTICIPANT	\N	PRESENT	0
101280	100267	08048B	PARTICIPANT	\N	PRESENT	0
101281	100267	14219Q	PARTICIPANT	\N	PRESENT	0
101282	100267	14267Y	PARTICIPANT	\N	PRESENT	0
101283	100267	11027H	PARTICIPANT	\N	PRESENT	0
101284	100267	14235Q	PARTICIPANT	\N	PRESENT	0
101285	100267	14199E	PARTICIPANT	\N	PRESENT	0
101286	100267	04081K	PARTICIPANT	\N	PRESENT	0
101287	100267	11010L	PARTICIPANT	\N	PRESENT	0
101288	100267	08015R	PARTICIPANT	\N	PRESENT	0
101289	100267	14217N	PARTICIPANT	\N	PRESENT	0
101292	100267	08053X	PARTICIPANT	\N	PRESENT	0
101293	100267	05012A	PARTICIPANT	\N	PRESENT	0
101294	100267	14197C	PARTICIPANT	\N	PRESENT	0
101295	100267	11091R	PARTICIPANT	\N	PRESENT	0
101296	100267	14265W	PARTICIPANT	\N	PRESENT	0
101297	100267	07004J	PARTICIPANT	\N	PRESENT	0
101298	100267	11040E	PARTICIPANT	\N	PRESENT	0
101299	100267	04088S	PARTICIPANT	\N	PRESENT	0
101300	100267	11011M	PARTICIPANT	\N	PRESENT	0
101301	100267	80013X	PARTICIPANT	\N	PRESENT	0
101302	100267	11036J	PARTICIPANT	\N	PRESENT	0
101303	100267	14121F	PARTICIPANT	\N	PRESENT	0
101304	100267	83047W	PARTICIPANT	\N	PRESENT	0
101305	100267	11100Y	PARTICIPANT	\N	PRESENT	0
101306	100267	14071N	PARTICIPANT	\N	PRESENT	0
101307	100267	11064N	PARTICIPANT	\N	PRESENT	0
101308	100267	92020L	PARTICIPANT	\N	PRESENT	0
101309	100267	14201E	PARTICIPANT	\N	PRESENT	0
101311	100267	08038Y	PARTICIPANT	\N	PRESENT	0
101332	100267	11082Q	PARTICIPANT	\N	PRESENT	0
101333	100267	14157T	PARTICIPANT	\N	PRESENT	0
101334	100267	04035D	PARTICIPANT	\N	PRESENT	0
101335	100267	04077P	PARTICIPANT	\N	PRESENT	0
101371	100267	11097X	PARTICIPANT	\N	PRESENT	0
101412	100267	14059S	PARTICIPANT	\N	PRESENT	0
101413	100267	01008M	PARTICIPANT	\N	PRESENT	0
101414	100267	14037X	PARTICIPANT	\N	PRESENT	0
101415	100267	04043D	PARTICIPANT	\N	PRESENT	0
101419	100267	14028W	PARTICIPANT	\N	PRESENT	0
101422	100267	14073Q	PARTICIPANT	\N	PRESENT	0
101423	100267	01048V	PARTICIPANT	\N	PRESENT	0
101424	100267	11076S	PARTICIPANT	\N	PRESENT	0
101425	100267	11066Q	PARTICIPANT	\N	PRESENT	0
101528	100268	08055A	PARTICIPANT	\N	PRESENT	0
101529	100268	92020L	PARTICIPANT	\N	PRESENT	0
101530	100268	04050C	PARTICIPANT	\N	PRESENT	0
101531	100268	11040E	PARTICIPANT	\N	PRESENT	0
101532	100268	14013P	PARTICIPANT	\N	PRESENT	0
101533	100268	01015L	PARTICIPANT	\N	PRESENT	0
101552	100268	08058D	PARTICIPANT	\N	PRESENT	0
101553	100268	11054L	PARTICIPANT	\N	PRESENT	0
101554	100268	80013X	PARTICIPANT	\N	PRESENT	0
101555	100268	14109K	PARTICIPANT	\N	PRESENT	0
101556	100268	11066Q	PARTICIPANT	\N	PRESENT	0
101557	100268	11026G	PARTICIPANT	\N	PRESENT	0
101558	100268	01014K	PARTICIPANT	\N	PRESENT	0
101559	100268	98035U	PARTICIPANT	\N	PRESENT	0
101560	100268	11027H	PARTICIPANT	\N	PRESENT	0
101561	100268	11076S	PARTICIPANT	\N	PRESENT	0
101562	100268	08009T	PARTICIPANT	\N	PRESENT	0
101563	100268	07004J	PARTICIPANT	\N	PRESENT	0
101564	100268	14073Q	PARTICIPANT	\N	PRESENT	0
101565	100268	88008L	PARTICIPANT	\N	PRESENT	0
101566	100268	01022K	PARTICIPANT	\N	PRESENT	0
101568	100268	95037J	PARTICIPANT	\N	PRESENT	0
101569	100268	01008M	PARTICIPANT	\N	PRESENT	0
101570	100268	14061L	PARTICIPANT	\N	PRESENT	0
101571	100268	14059S	PARTICIPANT	\N	PRESENT	0
101578	100268	05012A	PARTICIPANT	\N	PRESENT	0
101582	100268	11049P	PARTICIPANT	\N	PRESENT	0
101583	100268	01048V	PARTICIPANT	\N	PRESENT	0
101584	100268	11091R	PARTICIPANT	\N	PRESENT	0
101585	100268	04055H	PARTICIPANT	\N	PRESENT	0
101586	100268	04088S	PARTICIPANT	\N	PRESENT	0
101587	100268	14251Q	PARTICIPANT	\N	PRESENT	0
101588	100268	14133K	PARTICIPANT	\N	PRESENT	0
101589	100268	14038Y	PARTICIPANT	\N	PRESENT	0
101590	100268	02002K	PARTICIPANT	\N	PRESENT	0
101591	100268	97011G	PARTICIPANT	\N	PRESENT	0
101592	100268	04035D	PARTICIPANT	\N	PRESENT	0
101593	100268	11011M	PARTICIPANT	\N	PRESENT	0
101594	100268	08051V	PARTICIPANT	\N	PRESENT	0
101595	100268	04097T	PARTICIPANT	\N	PRESENT	0
101596	100268	92031P	PARTICIPANT	\N	PRESENT	0
101597	100268	14079W	PARTICIPANT	\N	PRESENT	0
101598	100268	98018T	PARTICIPANT	\N	PRESENT	0
101599	100268	95059Q	PARTICIPANT	\N	PRESENT	0
101600	100268	04077P	PARTICIPANT	\N	PRESENT	0
101601	100268	14093U	PARTICIPANT	\N	PRESENT	0
101602	100268	11107G	PARTICIPANT	\N	PRESENT	0
101603	100268	14157T	PARTICIPANT	\N	PRESENT	0
101604	100268	14225N	PARTICIPANT	\N	PRESENT	0
101605	100268	14263U	PARTICIPANT	\N	PRESENT	0
101606	100268	01056V	PARTICIPANT	\N	PRESENT	0
101607	100268	96004D	PARTICIPANT	\N	PRESENT	0
101608	100268	14249W	PARTICIPANT	\N	PRESENT	0
109821	107315	11063M	PARTICIPANT	\N	PRESENT	0
109822	107315	11031D	PARTICIPANT	\N	PRESENT	0
109823	107315	07026Q	PARTICIPANT	\N	PRESENT	0
109824	107315	01059Y	PARTICIPANT	\N	PRESENT	0
109825	107315	01015L	PARTICIPANT	\N	PRESENT	0
109826	107315	14013P	PARTICIPANT	\N	PRESENT	0
109827	107315	11098Y	PARTICIPANT	\N	PRESENT	0
109828	107315	14227Q	PARTICIPANT	\N	PRESENT	0
109829	107315	11067R	PARTICIPANT	\N	PRESENT	0
109830	107315	13002U	PARTICIPANT	\N	PRESENT	0
109831	107315	11036J	PARTICIPANT	\N	PRESENT	0
109832	107315	14030Q	PARTICIPANT	\N	PRESENT	0
109833	107315	14089Y	PARTICIPANT	\N	PRESENT	0
109834	107315	04067M	PARTICIPANT	\N	PRESENT	0
109835	107315	14261S	PARTICIPANT	\N	PRESENT	0
109836	107315	08031R	PARTICIPANT	\N	PRESENT	0
109782	107315	04081K	PARTICIPANT	\N	PRESENT	0
109820	107315	04053F	PARTICIPANT	\N	PRESENT	0
109837	107315	14083S	PARTICIPANT	\N	PRESENT	0
109838	107315	14215L	PARTICIPANT	\N	PRESENT	0
109839	107315	08051V	PARTICIPANT	\N	PRESENT	0
109840	107315	04036E	PARTICIPANT	\N	PRESENT	0
109841	107315	04088S	PARTICIPANT	\N	PRESENT	0
109842	107315	14041T	PARTICIPANT	\N	PRESENT	0
109843	107315	14157T	PARTICIPANT	\N	PRESENT	0
109844	107315	04057K	PARTICIPANT	\N	PRESENT	0
109845	107315	98018T	PARTICIPANT	\N	PRESENT	0
109846	107315	04092N	PARTICIPANT	\N	PRESENT	0
109847	107315	11093T	PARTICIPANT	\N	PRESENT	0
109848	107315	11061K	PARTICIPANT	\N	PRESENT	0
109874	107315	14033T	PARTICIPANT	\N	PRESENT	0
109875	107315	11082Q	PARTICIPANT	\N	PRESENT	0
109876	107315	01043Q	PARTICIPANT	\N	PRESENT	0
109877	107315	14257W	PARTICIPANT	\N	PRESENT	0
109878	107315	14209N	PARTICIPANT	\N	PRESENT	0
109879	107315	14271U	PARTICIPANT	\N	PRESENT	0
109880	107315	14034U	PARTICIPANT	\N	PRESENT	0
109881	107315	12041X	PARTICIPANT	\N	PRESENT	0
109882	107315	14249W	PARTICIPANT	\N	PRESENT	0
109883	107315	14087W	PARTICIPANT	\N	PRESENT	0
109884	107315	14281W	PARTICIPANT	\N	PRESENT	0
109885	107315	12042Y	PARTICIPANT	\N	PRESENT	0
109886	107315	04049K	PARTICIPANT	\N	PRESENT	0
109887	107315	14037X	PARTICIPANT	\N	PRESENT	0
109888	107315	08038Y	PARTICIPANT	\N	PRESENT	0
109889	107315	04050C	PARTICIPANT	\N	PRESENT	0
109895	107315	04043D	PARTICIPANT	\N	PRESENT	0
109896	107315	11091R	PARTICIPANT	\N	PRESENT	0
109897	107315	08017T	PARTICIPANT	\N	PRESENT	0
109898	107315	04071H	PARTICIPANT	\N	PRESENT	0
109913	107315	11090Q	PARTICIPANT	\N	PRESENT	0
109914	107315	14135M	PARTICIPANT	\N	PRESENT	0
109924	107315	11054L	PARTICIPANT	\N	PRESENT	0
109925	107315	14255U	PARTICIPANT	\N	PRESENT	0
109926	107315	08052W	PARTICIPANT	\N	PRESENT	0
109927	107315	01034P	PARTICIPANT	\N	PRESENT	0
109937	107315	10006L	PARTICIPANT	\N	PRESENT	0
109938	107315	14119M	PARTICIPANT	\N	PRESENT	0
109940	107315	08034U	PARTICIPANT	\N	PRESENT	0
109941	107315	80013X	PARTICIPANT	\N	PRESENT	0
109942	107315	08055A	PARTICIPANT	\N	PRESENT	0
109943	107315	14269B	PARTICIPANT	\N	PRESENT	0
109944	107315	08019V	PARTICIPANT	\N	PRESENT	0
109945	107315	01057W	PARTICIPANT	\N	PRESENT	0
109994	107313	14087W	PARTICIPANT	\N	PRESENT	0
109995	107313	11031D	PARTICIPANT	\N	PRESENT	0
109996	107313	01059Y	PARTICIPANT	\N	PRESENT	0
109997	107313	04050C	PARTICIPANT	\N	PRESENT	0
109998	107313	07026Q	PARTICIPANT	\N	PRESENT	0
109999	107313	11063M	PARTICIPANT	\N	PRESENT	0
110000	107313	14235Q	PARTICIPANT	\N	PRESENT	0
110001	107313	12041X	PARTICIPANT	\N	PRESENT	0
110002	107313	11098Y	PARTICIPANT	\N	PRESENT	0
110003	107313	14281W	PARTICIPANT	\N	PRESENT	0
110004	107313	08031R	PARTICIPANT	\N	PRESENT	0
110005	107313	14030Q	PARTICIPANT	\N	PRESENT	0
110006	107313	08019V	PARTICIPANT	\N	PRESENT	0
110007	107313	14157T	PARTICIPANT	\N	PRESENT	0
110008	107313	08034U	PARTICIPANT	\N	PRESENT	0
110009	107313	14259Y	PARTICIPANT	\N	PRESENT	0
110010	107313	14215L	PARTICIPANT	\N	PRESENT	0
110011	107313	14034U	PARTICIPANT	\N	PRESENT	0
110012	107313	01034P	PARTICIPANT	\N	PRESENT	0
110013	107313	10006L	PARTICIPANT	\N	PRESENT	0
110014	107313	14037X	PARTICIPANT	\N	PRESENT	0
110015	107313	11089X	PARTICIPANT	\N	PRESENT	0
110016	107313	14271U	PARTICIPANT	\N	PRESENT	0
110017	107313	14261S	PARTICIPANT	\N	PRESENT	0
110018	107313	14269B	PARTICIPANT	\N	PRESENT	0
110019	107313	08052W	PARTICIPANT	\N	PRESENT	0
110020	107313	01015L	PARTICIPANT	\N	PRESENT	0
110021	107313	12042Y	PARTICIPANT	\N	PRESENT	0
110022	107313	11113E	PARTICIPANT	\N	PRESENT	0
110023	107313	04067M	PARTICIPANT	\N	PRESENT	0
110024	107313	11093T	PARTICIPANT	\N	PRESENT	0
110025	107313	04043D	PARTICIPANT	\N	PRESENT	0
110026	107313	04053F	PARTICIPANT	\N	PRESENT	0
110027	107313	14135M	PARTICIPANT	\N	PRESENT	0
110028	107313	11061K	PARTICIPANT	\N	PRESENT	0
110032	107313	04042C	PARTICIPANT	\N	PRESENT	0
110033	107313	14119M	PARTICIPANT	\N	PRESENT	0
110034	107313	14255U	PARTICIPANT	\N	PRESENT	0
110035	107313	11077T	PARTICIPANT	\N	PRESENT	0
110036	107313	08051V	PARTICIPANT	\N	PRESENT	0
109992	107313	04066L	PARTICIPANT	\N	PRESENT	0
109993	107313	04092N	PARTICIPANT	\N	PRESENT	0
110052	109217	04081K	PARTICIPANT	\N	PRESENT	0
110053	109217	11063M	PARTICIPANT	\N	PRESENT	0
110054	109217	11031D	PARTICIPANT	\N	PRESENT	0
110055	109217	14013P	PARTICIPANT	\N	PRESENT	0
110056	109217	11098Y	PARTICIPANT	\N	PRESENT	0
110057	109217	04053F	PARTICIPANT	\N	PRESENT	0
110058	109217	08052W	PARTICIPANT	\N	PRESENT	0
110059	109217	95037J	PARTICIPANT	\N	PRESENT	0
110060	109217	14261S	PARTICIPANT	\N	PRESENT	0
110061	109217	14030Q	PARTICIPANT	\N	PRESENT	0
110062	109217	14215L	PARTICIPANT	\N	PRESENT	0
110063	109217	12042Y	PARTICIPANT	\N	PRESENT	0
110064	109217	14269B	PARTICIPANT	\N	PRESENT	0
110065	109217	14271U	PARTICIPANT	\N	PRESENT	0
110066	109217	01034P	PARTICIPANT	\N	PRESENT	0
110067	109217	08019V	PARTICIPANT	\N	PRESENT	0
110068	109217	14041T	PARTICIPANT	\N	PRESENT	0
110069	109217	14157T	PARTICIPANT	\N	PRESENT	0
110070	109217	14037X	PARTICIPANT	\N	PRESENT	0
110071	109217	04092N	PARTICIPANT	\N	PRESENT	0
110072	109217	14087W	PARTICIPANT	\N	PRESENT	0
110073	109217	11055M	PARTICIPANT	\N	PRESENT	0
110074	109217	14281W	PARTICIPANT	\N	PRESENT	0
110075	109217	04043D	PARTICIPANT	\N	PRESENT	0
110076	109217	04085P	PARTICIPANT	\N	PRESENT	0
110077	109217	11061K	PARTICIPANT	\N	PRESENT	0
110078	109217	14034U	PARTICIPANT	\N	PRESENT	0
110079	109217	14255U	PARTICIPANT	\N	PRESENT	0
110080	109217	14135M	PARTICIPANT	\N	PRESENT	0
110081	109217	08034U	PARTICIPANT	\N	PRESENT	0
110082	109217	01041N	PARTICIPANT	\N	PRESENT	0
110092	109217	04056J	PARTICIPANT	\N	PRESENT	0
110093	109217	08073C	PARTICIPANT	\N	PRESENT	0
110109	109217	99004R	PARTICIPANT	\N	PRESENT	0
501503	501502	14187A	PARTICIPANT	\N	PRESENT	0
502427	502421	14109K	PARTICIPANT	\N	PRESENT	0
502430	502429	19758L	PARTICIPANT	\N	PRESENT	0
502431	502429	14123H	PARTICIPANT	\N	PRESENT	0
502432	502429	14109K	PARTICIPANT	\N	PRESENT	0
502434	502433	14123H	PARTICIPANT	\N	PRESENT	0
502435	502433	19593H	PARTICIPANT	\N	PRESENT	0
502436	502433	04070G	PARTICIPANT	\N	PRESENT	0
502437	502433	20058E	PARTICIPANT	\N	PRESENT	0
502439	502438	14123H	PARTICIPANT	\N	PRESENT	0
502441	502440	14123H	PARTICIPANT	\N	PRESENT	0
502443	502442	14123H	PARTICIPANT	\N	PRESENT	0
502444	502442	14109K	PARTICIPANT	\N	PRESENT	0
502588	500466	19691J	PARTICIPANT	\N	PRESENT	0
502624	501761	04086Q	PARTICIPANT	\N	PRESENT	0
502659	502658	11083R	PARTICIPANT	\N	PRESENT	0
502813	502810	04086Q	PARTICIPANT	\N	PRESENT	0
502816	502815	04086Q	PARTICIPANT	\N	PRESENT	0
502819	502818	08034U	PARTICIPANT	\N	PRESENT	0
502826	502824	99004R	PARTICIPANT	\N	PRESENT	0
502830	502829	11074Q	PARTICIPANT	\N	PRESENT	0
502831	502829	19349W	PARTICIPANT	\N	PRESENT	0
502833	502832	11074Q	PARTICIPANT	\N	PRESENT	0
502834	502832	19349W	PARTICIPANT	\N	PRESENT	0
502838	502836	19711U	PARTICIPANT	\N	PRESENT	0
502841	502840	19711U	PARTICIPANT	\N	PRESENT	0
502843	502842	19711U	PARTICIPANT	\N	PRESENT	0
502846	502845	14179A	PARTICIPANT	\N	PRESENT	0
93641	92318	83047W	PARTICIPANT	\N	PRESENT	0
93642	92318	08069G	PARTICIPANT	\N	PRESENT	0
93643	92318	14195A	PARTICIPANT	\N	PRESENT	0
93644	92318	14041T	PARTICIPANT	\N	PRESENT	0
93645	92318	14249W	PARTICIPANT	\N	PRESENT	0
93646	92318	14219Q	PARTICIPANT	\N	PRESENT	0
93647	92318	01057W	PARTICIPANT	\N	PRESENT	0
93648	92318	95030B	PARTICIPANT	\N	PRESENT	0
93649	92318	14175V	PARTICIPANT	\N	PRESENT	0
93650	92318	14205J	PARTICIPANT	\N	PRESENT	0
93651	92318	11012A	PARTICIPANT	\N	PRESENT	0
93662	92318	14085U	PARTICIPANT	\N	PRESENT	0
93663	92318	11043H	PARTICIPANT	\N	PRESENT	0
93665	92318	97011G	PARTICIPANT	\N	PRESENT	0
93668	92318	14265W	PARTICIPANT	\N	PRESENT	0
93675	92318	04034C	PARTICIPANT	\N	PRESENT	0
93677	92318	04088S	PARTICIPANT	\N	PRESENT	0
93678	92318	14209N	PARTICIPANT	\N	PRESENT	0
93737	92318	14331P	PARTICIPANT	\N	PRESENT	0
93739	92318	01003G	PARTICIPANT	\N	PRESENT	0
93789	92318	14267Y	PARTICIPANT	\N	PRESENT	0
93790	92318	01024M	PARTICIPANT	\N	PRESENT	0
93795	92318	14030Q	PARTICIPANT	\N	PRESENT	0
93797	92318	11093T	PARTICIPANT	\N	PRESENT	0
93798	92318	14231L	PARTICIPANT	\N	PRESENT	0
93799	92318	99004R	PARTICIPANT	\N	PRESENT	0
93800	92318	08010L	PARTICIPANT	\N	PRESENT	0
93801	92318	04080J	PARTICIPANT	\N	PRESENT	0
93803	92318	11048N	PARTICIPANT	\N	PRESENT	0
93804	92318	00003C	PARTICIPANT	\N	PRESENT	0
93805	92318	14207L	PARTICIPANT	\N	PRESENT	0
93806	92318	14159V	PARTICIPANT	\N	PRESENT	0
93810	92318	14223L	PARTICIPANT	\N	PRESENT	0
93811	92318	11103C	PARTICIPANT	\N	PRESENT	0
93843	92318	11090Q	PARTICIPANT	\N	PRESENT	0
93848	92318	11067R	PARTICIPANT	\N	PRESENT	0
93849	92318	11036J	PARTICIPANT	\N	PRESENT	0
93852	92319	08055A	PARTICIPANT	\N	PRESENT	0
93924	92319	80013X	PARTICIPANT	\N	PRESENT	0
93922	92319	14111D	PARTICIPANT	\N	PRESENT	0
93923	92319	14065Q	PARTICIPANT	\N	PRESENT	0
93925	92319	11063M	PARTICIPANT	\N	PRESENT	0
93926	92319	14269B	PARTICIPANT	\N	PRESENT	0
93858	92319	11040E	PARTICIPANT	\N	PRESENT	0
93927	92319	14271U	PARTICIPANT	\N	PRESENT	0
93860	92319	11029K	PARTICIPANT	\N	PRESENT	0
93937	92319	11090Q	PARTICIPANT	\N	PRESENT	0
93862	92319	11077T	PARTICIPANT	\N	PRESENT	0
93928	92319	11033F	PARTICIPANT	\N	PRESENT	0
93864	92319	01022K	PARTICIPANT	\N	PRESENT	0
93865	92319	04038G	PARTICIPANT	\N	PRESENT	0
93929	92319	14179A	PARTICIPANT	\N	PRESENT	0
93867	92319	14061L	PARTICIPANT	\N	PRESENT	0
93868	92319	11034G	PARTICIPANT	\N	PRESENT	0
93869	92319	01015L	PARTICIPANT	\N	PRESENT	0
93870	92319	07026Q	PARTICIPANT	\N	PRESENT	0
93930	92319	14042U	PARTICIPANT	\N	PRESENT	0
93931	92319	14083S	PARTICIPANT	\N	PRESENT	0
93932	92319	14215L	PARTICIPANT	\N	PRESENT	0
93874	92319	04050C	PARTICIPANT	\N	PRESENT	0
93875	92319	98053W	PARTICIPANT	\N	PRESENT	0
93876	92319	04085P	PARTICIPANT	\N	PRESENT	0
93877	92319	11056N	PARTICIPANT	\N	PRESENT	0
93878	92319	14235Q	PARTICIPANT	\N	PRESENT	0
93933	92319	04080J	PARTICIPANT	\N	PRESENT	0
93934	92319	11031D	PARTICIPANT	\N	PRESENT	0
93881	92319	11091R	PARTICIPANT	\N	PRESENT	0
93935	92319	14013P	PARTICIPANT	\N	PRESENT	0
93936	92319	08061X	PARTICIPANT	\N	PRESENT	0
93938	92319	14259Y	PARTICIPANT	\N	PRESENT	0
93939	92319	14173T	PARTICIPANT	\N	PRESENT	0
93940	92319	14249W	PARTICIPANT	\N	PRESENT	0
93887	92319	14041T	PARTICIPANT	\N	PRESENT	0
93941	92319	14219Q	PARTICIPANT	\N	PRESENT	0
93942	92319	05008E	PARTICIPANT	\N	PRESENT	0
93943	92319	14089Y	PARTICIPANT	\N	PRESENT	0
93944	92319	01027Q	PARTICIPANT	\N	PRESENT	0
93945	92319	14157T	PARTICIPANT	\N	PRESENT	0
93946	92319	14241N	PARTICIPANT	\N	PRESENT	0
93894	92319	11012A	PARTICIPANT	\N	PRESENT	0
93964	92319	08060W	PARTICIPANT	\N	PRESENT	0
93965	92319	14207L	PARTICIPANT	\N	PRESENT	0
93966	92319	14197C	PARTICIPANT	\N	PRESENT	0
93898	92319	14265W	PARTICIPANT	\N	PRESENT	0
93967	92319	08019V	PARTICIPANT	\N	PRESENT	0
93900	92319	04088S	PARTICIPANT	\N	PRESENT	0
93968	92319	01048V	PARTICIPANT	\N	PRESENT	0
93969	92319	14069U	PARTICIPANT	\N	PRESENT	0
93970	92319	04081K	PARTICIPANT	\N	PRESENT	0
93971	92319	14073Q	PARTICIPANT	\N	PRESENT	0
93905	92319	01024M	PARTICIPANT	\N	PRESENT	0
93972	92319	14205J	PARTICIPANT	\N	PRESENT	0
93973	92319	11085T	PARTICIPANT	\N	PRESENT	0
93908	92319	14231L	PARTICIPANT	\N	PRESENT	0
93974	92319	01046T	PARTICIPANT	\N	PRESENT	0
93910	92319	08010L	PARTICIPANT	\N	PRESENT	0
93975	92319	95062K	PARTICIPANT	\N	PRESENT	0
93983	92319	10015M	PARTICIPANT	\N	PRESENT	0
93984	92319	14121F	PARTICIPANT	\N	PRESENT	0
93985	92319	11042G	PARTICIPANT	\N	PRESENT	0
94034	92320	04034C	PARTICIPANT	\N	PRESENT	0
94035	92320	12042Y	PARTICIPANT	\N	PRESENT	0
94036	92320	11107G	PARTICIPANT	\N	PRESENT	0
94037	92320	08060W	PARTICIPANT	\N	PRESENT	0
94038	92320	14014Q	PARTICIPANT	\N	PRESENT	0
93920	92319	11036J	PARTICIPANT	\N	PRESENT	0
94039	92320	14121F	PARTICIPANT	\N	PRESENT	0
94040	92320	11042G	PARTICIPANT	\N	PRESENT	0
94041	92320	11077T	PARTICIPANT	\N	PRESENT	0
94042	92320	11083R	PARTICIPANT	\N	PRESENT	0
94043	92320	14205J	PARTICIPANT	\N	PRESENT	0
94044	92320	14083S	PARTICIPANT	\N	PRESENT	0
94045	92320	14217N	PARTICIPANT	\N	PRESENT	0
94046	92320	08019V	PARTICIPANT	\N	PRESENT	0
94047	92320	14157T	PARTICIPANT	\N	PRESENT	0
94048	92320	10015M	PARTICIPANT	\N	PRESENT	0
94049	92320	11088W	PARTICIPANT	\N	PRESENT	0
94050	92320	01016M	PARTICIPANT	\N	PRESENT	0
94051	92320	04038G	PARTICIPANT	\N	PRESENT	0
94052	92320	98053W	PARTICIPANT	\N	PRESENT	0
94053	92320	08010L	PARTICIPANT	\N	PRESENT	0
94054	92320	14207L	PARTICIPANT	\N	PRESENT	0
94055	92320	14065Q	PARTICIPANT	\N	PRESENT	0
94056	92320	98046X	PARTICIPANT	\N	PRESENT	0
94057	92320	95062K	PARTICIPANT	\N	PRESENT	0
94058	92320	14195A	PARTICIPANT	\N	PRESENT	0
94059	92320	04067M	PARTICIPANT	\N	PRESENT	0
94060	92320	11100Y	PARTICIPANT	\N	PRESENT	0
94061	92320	11112D	PARTICIPANT	\N	PRESENT	0
94062	92320	01024M	PARTICIPANT	\N	PRESENT	0
94197	93961	08055A	PARTICIPANT	\N	PRESENT	0
94198	93961	01043Q	PARTICIPANT	\N	PRESENT	0
94199	93961	11098Y	PARTICIPANT	\N	PRESENT	0
94200	93961	11054L	PARTICIPANT	\N	PRESENT	0
94201	93961	11077T	PARTICIPANT	\N	PRESENT	0
94202	93961	11046L	PARTICIPANT	\N	PRESENT	0
94204	93961	11066Q	PARTICIPANT	\N	PRESENT	0
94205	93961	08068F	PARTICIPANT	\N	PRESENT	0
94206	93961	11099A	PARTICIPANT	\N	PRESENT	0
94207	93961	01003G	PARTICIPANT	\N	PRESENT	0
94208	93961	11094U	PARTICIPANT	\N	PRESENT	0
94209	93961	11091R	PARTICIPANT	\N	PRESENT	0
94210	93961	04038G	PARTICIPANT	\N	PRESENT	0
94211	93961	04086Q	PARTICIPANT	\N	PRESENT	0
94212	93961	11103C	PARTICIPANT	\N	PRESENT	0
94213	93961	14121F	PARTICIPANT	\N	PRESENT	0
94214	93961	04049K	PARTICIPANT	\N	PRESENT	0
94032	92320	08055A	PARTICIPANT	\N	PRESENT	0
94033	92320	08016S	PARTICIPANT	\N	PRESENT	0
94217	93961	14159V	PARTICIPANT	\N	PRESENT	0
94218	93961	01041N	PARTICIPANT	\N	PRESENT	0
94219	93961	14041T	PARTICIPANT	\N	PRESENT	0
94222	93961	14071N	PARTICIPANT	\N	PRESENT	0
94223	93961	14157T	PARTICIPANT	\N	PRESENT	0
94224	93961	98050T	PARTICIPANT	\N	PRESENT	0
94225	93961	14089Y	PARTICIPANT	\N	PRESENT	0
94226	93961	11100Y	PARTICIPANT	\N	PRESENT	0
94230	93961	14061L	PARTICIPANT	\N	PRESENT	0
94231	93961	01027Q	PARTICIPANT	\N	PRESENT	0
94232	93961	99004R	PARTICIPANT	\N	PRESENT	0
94234	93961	14197C	PARTICIPANT	\N	PRESENT	0
94235	93961	14207L	PARTICIPANT	\N	PRESENT	0
94236	93961	01015L	PARTICIPANT	\N	PRESENT	0
94253	93961	04081K	PARTICIPANT	\N	PRESENT	0
94254	93961	14205J	PARTICIPANT	\N	PRESENT	0
94255	93961	01013J	PARTICIPANT	\N	PRESENT	0
94256	93961	04067M	PARTICIPANT	\N	PRESENT	0
94257	93961	11084S	PARTICIPANT	\N	PRESENT	0
111163	111162	08043V	PARTICIPANT	\N	PRESENT	0
111164	111162	08039A	PARTICIPANT	\N	PRESENT	0
111165	111162	14119M	PARTICIPANT	\N	PRESENT	0
111166	111162	11026G	PARTICIPANT	\N	PRESENT	0
111167	111162	01008M	PARTICIPANT	\N	PRESENT	0
122926	122925	08025T	PARTICIPANT	\N	PRESENT	0
122927	122925	04085P	PARTICIPANT	\N	PRESENT	0
122928	122925	05008E	PRESIDENT	0	PRESENT	0
122929	122925	11033F	PARTICIPANT	\N	PRESENT	0
122930	122925	14065Q	PARTICIPANT	\N	PRESENT	0
122931	122925	14069U	PARTICIPANT	\N	PRESENT	0
122932	122925	04047H	PARTICIPANT	\N	PRESENT	0
122933	122925	11032E	PARTICIPANT	\N	PRESENT	0
122934	122925	04038G	PARTICIPANT	\N	PRESENT	0
122935	122925	11056N	PARTICIPANT	\N	PRESENT	0
122936	122925	14259Y	PARTICIPANT	\N	PRESENT	0
122937	122925	11035H	PARTICIPANT	\N	PRESENT	0
122938	122925	14041T	PARTICIPANT	\N	PRESENT	0
122939	122925	01024M	PARTICIPANT	\N	PRESENT	0
122940	122925	11034G	PARTICIPANT	\N	PRESENT	0
122941	122925	08018U	PARTICIPANT	\N	PRESENT	0
122942	122925	11010L	PARTICIPANT	\N	PRESENT	0
122943	122925	01007L	PARTICIPANT	\N	PRESENT	0
122944	122925	11049P	PARTICIPANT	\N	PRESENT	0
122945	122925	11084S	PARTICIPANT	\N	PRESENT	0
122946	122925	11026G	PARTICIPANT	\N	PRESENT	0
122947	122925	04079R	PARTICIPANT	\N	PRESENT	0
122948	122925	14111D	PARTICIPANT	\N	PRESENT	0
122949	122925	14001X	PARTICIPANT	\N	PRESENT	0
122950	122925	01060R	PARTICIPANT	\N	PRESENT	0
122951	122925	14147R	PARTICIPANT	\N	PRESENT	0
122952	122925	95049N	PARTICIPANT	\N	PRESENT	0
122953	122925	08051V	PARTICIPANT	\N	PRESENT	0
122954	122925	11072N	PARTICIPANT	\N	PRESENT	0
122955	122925	07034Q	PARTICIPANT	\N	PRESENT	0
122956	122925	04074L	PARTICIPANT	\N	PRESENT	0
122957	122925	10015M	PARTICIPANT	\N	PRESENT	0
122958	122925	95063L	PARTICIPANT	\N	PRESENT	0
122959	122925	01019Q	PARTICIPANT	\N	PRESENT	0
122960	122925	01028R	PARTICIPANT	\N	PRESENT	0
122961	122925	98035U	PARTICIPANT	\N	PRESENT	0
122962	122925	04056J	PARTICIPANT	\N	PRESENT	0
122963	122925	14275Y	PARTICIPANT	\N	PRESENT	0
122964	122925	04044E	PARTICIPANT	\N	PRESENT	0
122965	122925	11037K	PARTICIPANT	\N	PRESENT	0
122966	122925	92045V	PARTICIPANT	\N	PRESENT	0
122967	122925	95067Q	PARTICIPANT	\N	PRESENT	0
122968	122925	01047U	PARTICIPANT	\N	PRESENT	0
122969	122925	08044W	PARTICIPANT	\N	EXCUSE	0
124216	123237	04043D	PARTICIPANT	\N	PRESENT	0
124735	124734	01008M	PARTICIPANT	\N	PRESENT	0
124736	124734	11036J	PARTICIPANT	\N	PRESENT	0
124737	124734	11081P	PARTICIPANT	\N	PRESENT	0
124738	124734	14013P	PARTICIPANT	\N	EXCUSE	0
124739	124734	08068F	PARTICIPANT	\N	PRESENT	0
124740	124734	14207L	PARTICIPANT	\N	PRESENT	0
124741	124734	11101A	PARTICIPANT	\N	PRESENT	0
125335	125334	01008M	PARTICIPANT	\N	PRESENT	0
124743	124734	08028W	PARTICIPANT	\N	PRESENT	0
124744	124734	80013X	PARTICIPANT	\N	PRESENT	0
124745	124734	08038Y	PARTICIPANT	\N	PRESENT	0
124746	124734	04089T	PARTICIPANT	\N	PRESENT	0
124747	124734	14197C	PARTICIPANT	\N	PRESENT	0
124748	124734	11110B	PARTICIPANT	\N	PRESENT	0
124749	124734	14187A	PARTICIPANT	\N	PRESENT	0
124750	124734	14033T	PARTICIPANT	\N	PRESENT	0
124751	124734	14081Q	PARTICIPANT	\N	PRESENT	0
125255	125253	08055A	PARTICIPANT	\N	PRESENT	0
124753	124734	11099A	PARTICIPANT	\N	PRESENT	0
124754	124734	04049K	PARTICIPANT	\N	PRESENT	0
125256	125253	14093U	PARTICIPANT	\N	PRESENT	0
124756	124734	11111C	PARTICIPANT	\N	PRESENT	0
124757	124734	08015R	PARTICIPANT	\N	PRESENT	0
124758	124734	11100Y	PRESIDENT	0	PRESENT	0
124759	124734	01061S	PARTICIPANT	\N	PRESENT	0
124760	124734	11098Y	PARTICIPANT	\N	PRESENT	0
124761	124734	01043Q	PARTICIPANT	\N	PRESENT	0
124762	124734	11077T	PARTICIPANT	\N	PRESENT	0
124763	124734	14205J	PARTICIPANT	\N	PRESENT	0
124764	124734	08019V	PARTICIPANT	\N	PRESENT	0
124765	124734	14257W	PARTICIPANT	\N	PRESENT	0
124766	124734	08021P	PARTICIPANT	\N	PRESENT	0
124767	124734	04088S	PARTICIPANT	\N	PRESENT	0
124768	124734	98050T	PARTICIPANT	\N	PRESENT	0
125257	125253	14030Q	PARTICIPANT	\N	PRESENT	0
125318	124734	11046L	PARTICIPANT	\N	PRESENT	0
124771	124734	01058X	PARTICIPANT	\N	PRESENT	0
124772	124734	11094U	PARTICIPANT	\N	PRESENT	0
124773	124734	11066Q	PARTICIPANT	\N	PRESENT	0
125336	125334	11036J	PARTICIPANT	\N	PRESENT	0
125259	125253	08060W	PARTICIPANT	\N	PRESENT	0
125261	125253	14038Y	PARTICIPANT	\N	PRESENT	0
125338	125334	14013P	PARTICIPANT	\N	EXCUSE	0
125263	125253	98023Q	PARTICIPANT	\N	PRESENT	0
125339	125334	08068F	PARTICIPANT	\N	PRESENT	0
125265	125253	01015L	PARTICIPANT	\N	PRESENT	0
125266	125253	11107G	PARTICIPANT	\N	PRESENT	0
125340	125334	14207L	PARTICIPANT	\N	PRESENT	0
125269	125253	01022K	PARTICIPANT	\N	PRESENT	0
125270	125253	04097T	PARTICIPANT	\N	PRESENT	0
125271	125253	09001P	PARTICIPANT	\N	PRESENT	0
125272	125253	11059R	PARTICIPANT	\N	PRESENT	0
125273	125253	14219Q	PARTICIPANT	\N	PRESENT	0
125275	125253	14031R	PARTICIPANT	\N	PRESENT	0
125276	125253	08009T	PARTICIPANT	0	PRESENT	0
125277	125253	08062Y	PARTICIPANT	\N	PRESENT	0
125278	125253	14221J	PARTICIPANT	\N	PRESENT	0
125279	125253	92039X	PARTICIPANT	\N	PRESENT	0
125343	125334	08028W	PARTICIPANT	\N	PRESENT	0
125344	125334	80013X	PARTICIPANT	\N	PRESENT	0
125282	125253	14237S	PARTICIPANT	\N	PRESENT	0
125283	125253	13002U	PARTICIPANT	\N	PRESENT	0
125284	125253	05012A	PRESIDENT	0	PRESENT	0
125345	125334	08038Y	PARTICIPANT	\N	PRESENT	0
125286	125253	14135M	PARTICIPANT	\N	PRESENT	0
125287	125253	14331P	PARTICIPANT	\N	PRESENT	0
125288	125253	95062K	PARTICIPANT	\N	PRESENT	0
125289	125253	14107H	PARTICIPANT	\N	PRESENT	0
125290	125253	14051J	PARTICIPANT	\N	PRESENT	0
125292	125253	96003C	PARTICIPANT	\N	EXCUSE	0
125347	125334	14197C	PARTICIPANT	\N	PRESENT	0
125350	125334	14033T	PARTICIPANT	\N	PRESENT	0
125351	125334	14081Q	PARTICIPANT	\N	PRESENT	0
125352	125334	04048J	PARTICIPANT	\N	PRESENT	0
125356	125334	11111C	PARTICIPANT	\N	PRESENT	0
125358	125334	11100Y	PRESIDENT	0	PRESENT	0
125359	125334	01061S	PARTICIPANT	\N	EXCUSE	0
125361	125334	01043Q	PARTICIPANT	\N	PRESENT	0
125362	125334	11077T	PARTICIPANT	\N	PRESENT	0
125365	125334	14257W	PARTICIPANT	\N	PRESENT	0
125371	125334	01058X	PARTICIPANT	\N	PRESENT	0
125372	125334	11094U	PARTICIPANT	\N	PRESENT	0
125373	125334	11066Q	PARTICIPANT	\N	PRESENT	0
101627	100268	08034U	PARTICIPANT	\N	PRESENT	0
101628	100268	08068F	PARTICIPANT	\N	PRESENT	0
101639	100268	14030Q	PARTICIPANT	\N	PRESENT	0
101642	100268	14327T	PARTICIPANT	\N	PRESENT	0
101645	100268	14219Q	PARTICIPANT	\N	PRESENT	0
101653	100268	14255U	PARTICIPANT	\N	PRESENT	0
101662	100268	01003G	PARTICIPANT	\N	PRESENT	0
101663	100268	11042G	PARTICIPANT	\N	PRESENT	0
101664	100268	14257W	PARTICIPANT	\N	PRESENT	0
101665	100268	07032N	PARTICIPANT	\N	PRESENT	0
101667	100268	95015C	PARTICIPANT	\N	PRESENT	0
101668	100268	95030B	PARTICIPANT	\N	PRESENT	0
101683	100268	08044W	PARTICIPANT	\N	PRESENT	0
101684	100268	11053K	PARTICIPANT	\N	PRESENT	0
101685	100268	10015M	PARTICIPANT	\N	PRESENT	0
101686	100268	14097Y	PARTICIPANT	\N	PRESENT	0
101689	100268	86044G	PARTICIPANT	\N	PRESENT	0
101694	100268	14014Q	PARTICIPANT	\N	PRESENT	0
101708	100268	04042C	PARTICIPANT	\N	PRESENT	0
101710	100268	14175V	PARTICIPANT	\N	PRESENT	0
101719	100268	14147R	PARTICIPANT	\N	PRESENT	0
101722	100268	08016S	PARTICIPANT	\N	PRESENT	0
101723	100268	01031L	PARTICIPANT	\N	PRESENT	0
101724	100268	14159V	PARTICIPANT	\N	PRESENT	0
101725	100268	01047U	PARTICIPANT	\N	PRESENT	0
101726	100268	14031R	PARTICIPANT	\N	PRESENT	0
101732	100268	11010L	PARTICIPANT	\N	PRESENT	0
101733	100268	95035G	PARTICIPANT	\N	PRESENT	0
101734	100268	01058X	PARTICIPANT	\N	PRESENT	0
101735	100268	01013J	PARTICIPANT	\N	PRESENT	0
101736	100268	11036J	PARTICIPANT	\N	PRESENT	0
101737	100268	14001X	PARTICIPANT	\N	PRESENT	0
101738	100268	14042U	PARTICIPANT	\N	PRESENT	0
101739	100268	04080J	PARTICIPANT	\N	PRESENT	0
101740	100268	14179A	PARTICIPANT	\N	PRESENT	0
101742	100268	04038G	PARTICIPANT	\N	PRESENT	0
101800	100268	14213J	PARTICIPANT	\N	PRESENT	0
101801	100268	14135M	PARTICIPANT	\N	PRESENT	0
101802	100268	11112D	PARTICIPANT	\N	PRESENT	0
101803	100268	11093T	PARTICIPANT	\N	PRESENT	0
101804	100268	11012A	PARTICIPANT	\N	PRESENT	0
101805	100268	11094U	PARTICIPANT	\N	PRESENT	0
101619	100268	14247U	PARTICIPANT	\N	PRESENT	0
101621	100268	08018U	PARTICIPANT	\N	PRESENT	0
101806	100268	14187A	PARTICIPANT	\N	PRESENT	0
101807	100268	14071N	PARTICIPANT	\N	PRESENT	0
101808	100268	01046T	PARTICIPANT	\N	PRESENT	0
101809	100268	14265W	PARTICIPANT	\N	PRESENT	0
101827	100268	08015R	PARTICIPANT	\N	PRESENT	0
101828	100268	01016M	PARTICIPANT	\N	PRESENT	0
101829	100268	14217N	PARTICIPANT	\N	PRESENT	0
101830	100268	11097X	PARTICIPANT	\N	PRESENT	0
101831	100268	01057W	PARTICIPANT	\N	PRESENT	0
101832	100268	14026U	PARTICIPANT	\N	PRESENT	0
101852	100269	01007L	PARTICIPANT	\N	PRESENT	0
101872	100269	08011M	PARTICIPANT	\N	PRESENT	0
101873	100269	01031L	PARTICIPANT	\N	PRESENT	0
101874	100269	11083R	PARTICIPANT	\N	PRESENT	0
101875	100269	88008L	PARTICIPANT	\N	PRESENT	0
101876	100269	11053K	PARTICIPANT	\N	PRESENT	0
101877	100269	14257W	PARTICIPANT	\N	PRESENT	0
101878	100269	01013J	PARTICIPANT	\N	PRESENT	0
101879	100269	80013X	PARTICIPANT	\N	PRESENT	0
101880	100269	14225N	PARTICIPANT	\N	PRESENT	0
101881	100269	95030B	PARTICIPANT	\N	PRESENT	0
101882	100269	14079W	PARTICIPANT	\N	PRESENT	0
101883	100269	14083S	PARTICIPANT	\N	PRESENT	0
101884	100269	14119M	PARTICIPANT	\N	PRESENT	0
101885	100269	11036J	PARTICIPANT	\N	PRESENT	0
101892	100269	14219Q	PARTICIPANT	\N	PRESENT	0
101952	101186	14257W	PARTICIPANT	\N	PRESENT	0
101953	101186	14207L	PARTICIPANT	\N	PRESENT	0
101954	101186	14225N	PARTICIPANT	\N	PRESENT	0
101955	101186	13002U	PARTICIPANT	\N	PRESENT	0
101956	101186	11037K	PARTICIPANT	\N	PRESENT	0
101957	101186	14219Q	PARTICIPANT	\N	PRESENT	0
101958	101186	14267Y	PARTICIPANT	\N	PRESENT	0
101959	101186	07004J	PARTICIPANT	\N	PRESENT	0
101960	101186	14231L	PARTICIPANT	\N	PRESENT	0
101961	101186	11064N	PARTICIPANT	\N	PRESENT	0
101962	101186	04089T	PARTICIPANT	\N	PRESENT	0
101963	101186	14083S	PARTICIPANT	\N	PRESENT	0
101964	101186	14209N	PARTICIPANT	\N	PRESENT	0
101965	101186	07029T	PARTICIPANT	\N	PRESENT	0
101966	101186	14195A	PARTICIPANT	\N	PRESENT	0
101967	101186	14119M	PARTICIPANT	\N	PRESENT	0
101948	101186	08055A	PARTICIPANT	\N	PRESENT	0
101951	101186	11040E	PARTICIPANT	\N	PRESENT	0
101968	101186	01057W	PARTICIPANT	\N	PRESENT	0
101969	101186	01003G	PARTICIPANT	\N	PRESENT	0
101970	101186	11012A	PARTICIPANT	\N	PRESENT	0
101971	101186	88008L	PARTICIPANT	\N	PRESENT	0
101972	101186	08051V	PARTICIPANT	\N	PRESENT	0
101973	101186	14087W	PARTICIPANT	\N	PRESENT	0
101974	101186	04086Q	PARTICIPANT	\N	PRESENT	0
101975	101186	01008M	PARTICIPANT	\N	PRESENT	0
101976	101186	11011M	PARTICIPANT	\N	PRESENT	0
101977	101186	14079W	PARTICIPANT	\N	PRESENT	0
101978	101186	08031R	PARTICIPANT	\N	PRESENT	0
101979	101186	04088S	PARTICIPANT	\N	PRESENT	0
101980	101186	08034U	PARTICIPANT	\N	PRESENT	0
101981	101186	14026U	PARTICIPANT	\N	PRESENT	0
101982	101186	14327T	PARTICIPANT	\N	PRESENT	0
101983	101186	11042G	PARTICIPANT	\N	PRESENT	0
101984	101186	14159V	PARTICIPANT	\N	PRESENT	0
101985	101186	11067R	PARTICIPANT	\N	PRESENT	0
101986	101186	08015R	PARTICIPANT	\N	PRESENT	0
101992	101186	14033T	PARTICIPANT	\N	PRESENT	0
101993	101186	14265W	PARTICIPANT	\N	PRESENT	0
101994	101186	14187A	PARTICIPANT	\N	PRESENT	0
101995	101186	14073Q	PARTICIPANT	\N	PRESENT	0
101996	101186	04034C	PARTICIPANT	\N	PRESENT	0
101997	101186	14109K	PARTICIPANT	\N	PRESENT	0
101998	101186	14121F	PARTICIPANT	\N	PRESENT	0
101999	101186	14235Q	PARTICIPANT	\N	PRESENT	0
102000	101186	80013X	PARTICIPANT	\N	PRESENT	0
102001	101186	11036J	PARTICIPANT	\N	PRESENT	0
102002	101186	08069G	PARTICIPANT	\N	PRESENT	0
102003	101186	08056B	PARTICIPANT	\N	PRESENT	0
102004	101186	14259Y	PARTICIPANT	\N	PRESENT	0
102005	101186	14030Q	PARTICIPANT	\N	PRESENT	0
102006	101186	14042U	PARTICIPANT	\N	PRESENT	0
102007	101186	14107H	PARTICIPANT	\N	PRESENT	0
102008	101186	14169X	PARTICIPANT	\N	PRESENT	0
102219	101190	86034E	PARTICIPANT	\N	PRESENT	0
102220	101190	08025T	PARTICIPANT	\N	PRESENT	0
102221	101190	04053F	PARTICIPANT	\N	PRESENT	0
102222	101190	11037K	PARTICIPANT	\N	PRESENT	0
102223	101190	95062K	PARTICIPANT	\N	PRESENT	0
102224	101190	08052W	PARTICIPANT	\N	PRESENT	0
107056	107053	04081K	PARTICIPANT	\N	PRESENT	0
107057	107053	11063M	PARTICIPANT	\N	PRESENT	0
107058	107053	07026Q	PARTICIPANT	\N	PRESENT	0
107059	107053	04092N	PARTICIPANT	\N	PRESENT	0
107060	107053	14037X	PARTICIPANT	\N	PRESENT	0
107061	107053	04053F	PARTICIPANT	\N	PRESENT	0
107062	107053	11061K	PARTICIPANT	\N	PRESENT	0
107063	107053	08052W	PARTICIPANT	\N	PRESENT	0
107064	107053	14271U	PARTICIPANT	\N	PRESENT	0
107065	107053	14269B	PARTICIPANT	\N	PRESENT	0
107066	107053	11093T	PARTICIPANT	\N	PRESENT	0
107067	107053	98005N	PARTICIPANT	\N	PRESENT	0
107068	107053	14041T	PARTICIPANT	\N	PRESENT	0
107069	107053	04067M	PARTICIPANT	\N	PRESENT	0
107070	107053	08031R	PARTICIPANT	\N	PRESENT	0
107071	107053	95037J	PARTICIPANT	\N	PRESENT	0
107073	107053	11011M	PARTICIPANT	\N	PRESENT	0
107074	107053	98018T	PARTICIPANT	\N	PRESENT	0
107075	107053	11077T	PARTICIPANT	\N	PRESENT	0
107076	107053	01048V	PARTICIPANT	\N	PRESENT	0
107096	107053	10006L	PARTICIPANT	\N	PRESENT	0
107097	107053	11103C	PARTICIPANT	\N	PRESENT	0
107112	107053	11031D	PARTICIPANT	\N	PRESENT	0
107113	107053	04085P	PARTICIPANT	\N	PRESENT	0
107114	107053	08016S	PARTICIPANT	\N	PRESENT	0
107115	107053	01059Y	PARTICIPANT	\N	PRESENT	0
107137	107054	98053W	PARTICIPANT	\N	PRESENT	0
107138	107054	04092N	PARTICIPANT	\N	PRESENT	0
107139	107054	14037X	PARTICIPANT	\N	PRESENT	0
107144	107054	07026Q	PARTICIPANT	\N	PRESENT	0
107145	107054	11063M	PARTICIPANT	\N	PRESENT	0
107146	107054	11054L	PARTICIPANT	\N	PRESENT	0
107147	107054	14034U	PARTICIPANT	\N	PRESENT	0
107148	107054	04053F	PARTICIPANT	\N	PRESENT	0
107149	107054	04067M	PARTICIPANT	\N	PRESENT	0
107150	107054	08052W	PARTICIPANT	\N	PRESENT	0
107151	107054	14269B	PARTICIPANT	\N	PRESENT	0
107152	107054	01059Y	PARTICIPANT	\N	PRESENT	0
110166	109218	14087W	PARTICIPANT	\N	PRESENT	0
110167	109218	04053F	PARTICIPANT	\N	PRESENT	0
110168	109218	01034P	PARTICIPANT	\N	PRESENT	0
110169	109218	14261S	PARTICIPANT	\N	PRESENT	0
110164	109218	04066L	PARTICIPANT	\N	PRESENT	0
110165	109218	04092N	PARTICIPANT	\N	PRESENT	0
110170	109218	08052W	PARTICIPANT	\N	PRESENT	0
110171	109218	11031D	PARTICIPANT	\N	PRESENT	0
110172	109218	14034U	PARTICIPANT	\N	PRESENT	0
110173	109218	14037X	PARTICIPANT	\N	PRESENT	0
110174	109218	14041T	PARTICIPANT	\N	PRESENT	0
110175	109218	14030Q	PARTICIPANT	\N	PRESENT	0
110176	109218	14269B	PARTICIPANT	\N	PRESENT	0
110177	109218	04059M	PARTICIPANT	\N	PRESENT	0
110178	109218	14281W	PARTICIPANT	\N	PRESENT	0
110179	109218	14271U	PARTICIPANT	\N	PRESENT	0
110180	109218	08019V	PARTICIPANT	\N	PRESENT	0
110181	109218	08049C	PARTICIPANT	\N	PRESENT	0
110182	109218	11061K	PARTICIPANT	\N	PRESENT	0
110183	109218	95037J	PARTICIPANT	\N	PRESENT	0
110184	109218	14135M	PARTICIPANT	\N	PRESENT	0
110185	109218	14157T	PARTICIPANT	\N	PRESENT	0
110186	109218	11055M	PARTICIPANT	\N	PRESENT	0
110187	109218	12042Y	PARTICIPANT	\N	PRESENT	0
110188	109218	04085P	PARTICIPANT	\N	PRESENT	0
110197	109218	99004R	PARTICIPANT	\N	PRESENT	0
110200	109218	11027H	PARTICIPANT	\N	PRESENT	0
110279	109219	11061K	PARTICIPANT	\N	PRESENT	0
110202	109218	11072N	PARTICIPANT	\N	PRESENT	0
110203	109218	11077T	PARTICIPANT	\N	PRESENT	0
110204	109218	11063M	PARTICIPANT	\N	PRESENT	0
110205	109218	01041N	PARTICIPANT	\N	PRESENT	0
110212	109218	11089X	PARTICIPANT	\N	PRESENT	0
110213	109218	11083R	PARTICIPANT	\N	PRESENT	0
110214	109218	11029K	PARTICIPANT	\N	PRESENT	0
110215	109218	14255U	PARTICIPANT	\N	PRESENT	0
110232	109218	12041X	PARTICIPANT	\N	PRESENT	0
113411	112752	11072N	PARTICIPANT	\N	PRESENT	0
110234	109218	04036E	PARTICIPANT	\N	PRESENT	0
110255	109218	14026U	PARTICIPANT	\N	PRESENT	0
110256	109218	04086Q	PARTICIPANT	\N	PRESENT	0
110257	109218	14259Y	PARTICIPANT	\N	PRESENT	0
110258	109218	04050C	PARTICIPANT	\N	PRESENT	0
110259	109219	04066L	PARTICIPANT	\N	PRESENT	0
110260	109219	04092N	PARTICIPANT	\N	PRESENT	0
110261	109219	14087W	PARTICIPANT	\N	PRESENT	0
110262	109219	04053F	PARTICIPANT	\N	PRESENT	0
110263	109219	14261S	PARTICIPANT	\N	PRESENT	0
110264	109219	08052W	PARTICIPANT	\N	PRESENT	0
110265	109219	14034U	PARTICIPANT	\N	PRESENT	0
110266	109219	14037X	PARTICIPANT	\N	PRESENT	0
110267	109219	14041T	PARTICIPANT	\N	PRESENT	0
110268	109219	14269B	PARTICIPANT	\N	PRESENT	0
110269	109219	14271U	PARTICIPANT	\N	PRESENT	0
113412	112752	14026U	PARTICIPANT	\N	PRESENT	0
110271	109219	04085P	PARTICIPANT	\N	PRESENT	0
110272	109219	11063M	PARTICIPANT	\N	PRESENT	0
110273	109219	01041N	PARTICIPANT	\N	PRESENT	0
110274	109219	14255U	PARTICIPANT	\N	PRESENT	0
110275	109219	14026U	PARTICIPANT	\N	PRESENT	0
110276	109219	04086Q	PARTICIPANT	\N	PRESENT	0
110277	109219	14259Y	PARTICIPANT	\N	PRESENT	0
110278	109219	04050C	PARTICIPANT	\N	PRESENT	0
113432	112752	14235Q	PARTICIPANT	\N	PRESENT	0
113433	112752	14034U	PARTICIPANT	\N	PRESENT	0
113434	112752	11039M	PARTICIPANT	\N	PRESENT	0
113435	112752	14169X	PARTICIPANT	\N	PRESENT	0
113436	112752	08024S	PARTICIPANT	\N	PRESENT	0
113437	112752	14038Y	PARTICIPANT	\N	PRESENT	0
113554	112753	05008E	PARTICIPANT	\N	PRESENT	0
113572	112753	11098Y	PARTICIPANT	\N	PRESENT	0
113573	112753	11056N	PARTICIPANT	\N	PRESENT	0
113574	112753	14001X	PARTICIPANT	\N	PRESENT	0
113575	112753	14207L	PARTICIPANT	\N	PRESENT	0
113576	112753	08025T	PARTICIPANT	\N	PRESENT	0
113577	112753	11036J	PARTICIPANT	\N	PRESENT	0
113578	112753	04067M	PARTICIPANT	\N	PRESENT	0
113579	112753	11053K	PARTICIPANT	\N	PRESENT	0
113580	112753	14219Q	PARTICIPANT	\N	PRESENT	0
113581	112753	14273W	PARTICIPANT	\N	PRESENT	0
113582	112753	89017R	PARTICIPANT	\N	PRESENT	0
113583	112753	14215L	PARTICIPANT	\N	PRESENT	0
113584	112753	14331P	PARTICIPANT	\N	PRESENT	0
113585	112753	14033T	PARTICIPANT	\N	PRESENT	0
113586	112753	92045V	PARTICIPANT	\N	PRESENT	0
113587	112753	14187A	PARTICIPANT	\N	PRESENT	0
113588	112753	14265W	PARTICIPANT	\N	PRESENT	0
113589	112753	14053L	PARTICIPANT	\N	PRESENT	0
113593	112753	88008L	PARTICIPANT	\N	PRESENT	0
113591	112753	08039A	PARTICIPANT	\N	PRESENT	0
113592	112753	14231L	PARTICIPANT	\N	PRESENT	0
113594	112753	14175V	PARTICIPANT	\N	PRESENT	0
113595	112753	08055A	PARTICIPANT	\N	PRESENT	0
113596	112753	11094U	PARTICIPANT	\N	PRESENT	0
113597	112753	14147R	PARTICIPANT	\N	PRESENT	0
113598	112753	01024M	PARTICIPANT	\N	PRESENT	0
113599	112753	01007L	PARTICIPANT	\N	PRESENT	0
113600	112753	92018S	PARTICIPANT	\N	PRESENT	0
113601	112753	14235Q	PARTICIPANT	\N	PRESENT	0
113602	112753	12042Y	PARTICIPANT	\N	PRESENT	0
113603	112753	14327T	PARTICIPANT	\N	PRESENT	0
113604	112753	04071H	PARTICIPANT	\N	PRESENT	0
113605	112753	14173T	PARTICIPANT	\N	PRESENT	0
113606	112753	14157T	PARTICIPANT	\N	PRESENT	0
113607	112753	04049K	PARTICIPANT	\N	PRESENT	0
113608	112753	11097X	PARTICIPANT	\N	PRESENT	0
113609	112753	14217N	PARTICIPANT	\N	PRESENT	0
113612	112753	14263U	PARTICIPANT	\N	PRESENT	0
113613	112753	14257W	PARTICIPANT	\N	PRESENT	0
113614	112753	01027Q	PARTICIPANT	\N	PRESENT	0
113615	112753	14159V	PARTICIPANT	\N	PRESENT	0
113616	112753	11099A	PARTICIPANT	\N	PRESENT	0
113617	112753	08038Y	PARTICIPANT	\N	PRESENT	0
113618	112753	95030B	PARTICIPANT	\N	PRESENT	0
113619	112753	08053X	PARTICIPANT	\N	PRESENT	0
113620	112753	14169X	PARTICIPANT	\N	PRESENT	0
113621	112753	08034U	PARTICIPANT	\N	PRESENT	0
113622	112753	80013X	PARTICIPANT	\N	PRESENT	0
113632	112753	14097Y	PARTICIPANT	\N	PRESENT	0
113633	112753	11077T	PARTICIPANT	\N	PRESENT	0
113634	112753	14119M	PARTICIPANT	\N	PRESENT	0
113635	112753	08051V	PARTICIPANT	\N	PRESENT	0
113636	112753	14239U	PARTICIPANT	\N	PRESENT	0
113637	112753	01028R	PARTICIPANT	\N	PRESENT	0
113638	112753	08031R	PARTICIPANT	\N	PRESENT	0
113639	112753	11012A	PARTICIPANT	\N	PRESENT	0
113640	112753	14030Q	PARTICIPANT	\N	PRESENT	0
113641	112753	96004D	PARTICIPANT	\N	PRESENT	0
113642	112753	14059S	PARTICIPANT	\N	PRESENT	0
113643	112753	14123H	PARTICIPANT	\N	PRESENT	0
113644	112753	14135M	PARTICIPANT	\N	PRESENT	0
113645	112753	14031R	PARTICIPANT	\N	PRESENT	0
113646	112753	04070G	PARTICIPANT	\N	PRESENT	0
113647	112753	01031L	PARTICIPANT	\N	PRESENT	0
113652	112753	14071N	PARTICIPANT	\N	PRESENT	0
113653	112753	14249W	PARTICIPANT	\N	PRESENT	0
113654	112753	14073Q	PARTICIPANT	\N	PRESENT	0
113655	112753	04033B	PARTICIPANT	\N	PRESENT	0
113656	112753	10006L	PARTICIPANT	\N	PRESENT	0
113657	112753	14034U	PARTICIPANT	\N	PRESENT	0
113658	112753	14083S	PARTICIPANT	\N	PRESENT	0
113659	112753	01008M	PARTICIPANT	\N	PRESENT	0
113672	112753	14038Y	PARTICIPANT	\N	PRESENT	0
113673	112753	01016M	PARTICIPANT	\N	PRESENT	0
113674	112753	08061X	PARTICIPANT	\N	PRESENT	0
113675	112753	14026U	PARTICIPANT	\N	PRESENT	0
113676	112753	08011M	PARTICIPANT	\N	PRESENT	0
113677	112753	14069U	PARTICIPANT	\N	PRESENT	0
113692	112753	14213J	PARTICIPANT	\N	PRESENT	0
113693	112753	14079W	PARTICIPANT	\N	PRESENT	0
113552	112753	08024S	PARTICIPANT	\N	PRESENT	0
113553	112753	07034Q	PARTICIPANT	\N	PRESENT	0
94258	93961	14083S	PARTICIPANT	\N	PRESENT	0
94259	93961	11012A	PARTICIPANT	\N	PRESENT	0
94260	93961	14073Q	PARTICIPANT	\N	PRESENT	0
94281	93962	04066L	PARTICIPANT	\N	PRESENT	0
94282	93962	14235Q	PARTICIPANT	\N	PRESENT	0
94283	93962	07026Q	PARTICIPANT	\N	PRESENT	0
94284	93962	11063M	PARTICIPANT	\N	PRESENT	0
94285	93962	11031D	PARTICIPANT	\N	PRESENT	0
94286	93962	04053F	PARTICIPANT	\N	PRESENT	0
94287	93962	04067M	PARTICIPANT	\N	PRESENT	0
94288	93962	01044R	PARTICIPANT	\N	PRESENT	0
94289	93962	11055M	PARTICIPANT	\N	PRESENT	0
94290	93962	08055A	PARTICIPANT	\N	PRESENT	0
94291	93962	14041T	PARTICIPANT	\N	PRESENT	0
94292	93962	11048N	PARTICIPANT	\N	PRESENT	0
94293	93962	88008L	PARTICIPANT	\N	PRESENT	0
94294	93962	01034P	PARTICIPANT	\N	PRESENT	0
94295	93962	14249W	PARTICIPANT	\N	PRESENT	0
94296	93962	83047W	PARTICIPANT	\N	PRESENT	0
94297	93962	11054L	PARTICIPANT	\N	PRESENT	0
94298	93962	01059Y	PARTICIPANT	\N	PRESENT	0
94299	93962	04085P	PARTICIPANT	\N	PRESENT	0
94300	93962	14159V	PARTICIPANT	\N	PRESENT	0
94301	93962	11033F	PARTICIPANT	\N	PRESENT	0
94302	93962	11099A	PARTICIPANT	\N	PRESENT	0
94303	93962	14037X	PARTICIPANT	\N	PRESENT	0
94304	93962	11098Y	PARTICIPANT	\N	PRESENT	0
94318	93962	14042U	PARTICIPANT	\N	PRESENT	0
94320	93962	11036J	PARTICIPANT	\N	PRESENT	0
94323	93962	14269B	PARTICIPANT	\N	PRESENT	0
94328	93962	07024N	PARTICIPANT	\N	PRESENT	0
94329	93962	04043D	PARTICIPANT	\N	PRESENT	0
94330	93962	11100Y	PARTICIPANT	\N	PRESENT	0
94352	93962	11076S	PARTICIPANT	\N	PRESENT	0
94353	93962	11107G	PARTICIPANT	\N	PRESENT	0
94357	93963	04066L	PARTICIPANT	\N	PRESENT	0
94358	93963	14235Q	PARTICIPANT	\N	PRESENT	0
94389	93963	01059Y	PARTICIPANT	\N	PRESENT	0
94391	93963	11094U	PARTICIPANT	\N	PRESENT	0
94392	93963	04094Q	PARTICIPANT	\N	PRESENT	0
94393	93963	08060W	PARTICIPANT	\N	PRESENT	0
94363	93963	04067M	PARTICIPANT	\N	PRESENT	0
94364	93963	01044R	PARTICIPANT	\N	PRESENT	0
94394	93963	01041N	PARTICIPANT	\N	PRESENT	0
94366	93963	08055A	PARTICIPANT	\N	PRESENT	0
94367	93963	14041T	PARTICIPANT	\N	PRESENT	0
94395	93963	11113E	PARTICIPANT	\N	PRESENT	0
94396	93963	14169X	PARTICIPANT	\N	PRESENT	0
94412	93963	14197C	PARTICIPANT	\N	PRESENT	0
94371	93963	14249W	PARTICIPANT	\N	PRESENT	0
94513	94512	08009T	PARTICIPANT	\N	PRESENT	0
94514	94512	14169X	PARTICIPANT	\N	PRESENT	0
94515	94512	08060W	PARTICIPANT	\N	PRESENT	0
94516	94512	11107G	PARTICIPANT	\N	PRESENT	0
94752	94220	08024S	PARTICIPANT	\N	PRESENT	0
94377	93963	11033F	PARTICIPANT	\N	PRESENT	0
94378	93963	11099A	PARTICIPANT	\N	PRESENT	0
94753	94220	04059M	PARTICIPANT	\N	PRESENT	0
94380	93963	11098Y	PARTICIPANT	\N	PRESENT	0
94754	94220	04070G	PARTICIPANT	\N	PRESENT	0
94382	93963	11036J	PARTICIPANT	\N	PRESENT	0
94755	94220	14265W	PARTICIPANT	\N	PRESENT	0
94384	93963	07024N	PARTICIPANT	\N	PRESENT	0
94385	93963	04043D	PARTICIPANT	\N	PRESENT	0
94756	94220	14231L	PARTICIPANT	\N	PRESENT	0
94387	93963	11076S	PARTICIPANT	\N	PRESENT	0
94757	94220	04089T	PARTICIPANT	\N	PRESENT	0
94758	94220	08043V	PARTICIPANT	\N	PRESENT	0
94759	94220	11104D	PARTICIPANT	\N	PRESENT	0
94760	94220	11042G	PARTICIPANT	\N	PRESENT	0
94761	94220	11025F	PARTICIPANT	\N	PRESENT	0
94762	94220	14073Q	PARTICIPANT	\N	PRESENT	0
94763	94220	07026Q	PARTICIPANT	\N	PRESENT	0
94764	94220	14235Q	PARTICIPANT	\N	PRESENT	0
94765	94220	01025N	PARTICIPANT	\N	PRESENT	0
94766	94220	08039A	PARTICIPANT	\N	PRESENT	0
94767	94220	01044R	PARTICIPANT	\N	PRESENT	0
94768	94220	01041N	PARTICIPANT	\N	PRESENT	0
94769	94220	11029K	PARTICIPANT	\N	PRESENT	0
94770	94220	14263U	PARTICIPANT	\N	PRESENT	0
94771	94220	11014C	PARTICIPANT	\N	PRESENT	0
94772	94220	92015P	PARTICIPANT	\N	PRESENT	0
94773	94220	14103D	PARTICIPANT	\N	PRESENT	0
94774	94220	11091R	PARTICIPANT	\N	PRESENT	0
94775	94220	14111D	PARTICIPANT	\N	PRESENT	0
94776	94220	14033T	PARTICIPANT	\N	PRESENT	0
94777	94220	11048N	PARTICIPANT	\N	PRESENT	0
94778	94220	14061L	PARTICIPANT	\N	PRESENT	0
94779	94220	95063L	PARTICIPANT	\N	PRESENT	0
94780	94220	01028R	PARTICIPANT	\N	PRESENT	0
94781	94220	04056J	PARTICIPANT	\N	PRESENT	0
94782	94220	01003G	PARTICIPANT	\N	PRESENT	0
94783	94220	14109K	PARTICIPANT	\N	PRESENT	0
94784	94220	14229S	PARTICIPANT	\N	PRESENT	0
94785	94220	14251Q	PARTICIPANT	\N	PRESENT	0
94786	94220	11040E	PARTICIPANT	\N	PRESENT	0
94787	94220	14241N	PARTICIPANT	\N	PRESENT	0
94788	94220	95015C	PARTICIPANT	\N	PRESENT	0
94789	94220	14257W	PARTICIPANT	\N	PRESENT	0
94790	94220	08016S	PARTICIPANT	\N	PRESENT	0
94791	94220	14223L	PARTICIPANT	\N	PRESENT	0
94792	94220	11101A	PARTICIPANT	\N	PRESENT	0
94793	94220	95030B	PARTICIPANT	\N	PRESENT	0
94794	94220	97011G	PARTICIPANT	\N	PRESENT	0
94795	94220	01047U	PARTICIPANT	\N	PRESENT	0
94796	94220	98050T	PARTICIPANT	\N	PRESENT	0
94797	94220	14059S	PARTICIPANT	\N	PRESENT	0
94798	94220	87003B	PARTICIPANT	\N	PRESENT	0
94799	94220	12041X	PARTICIPANT	\N	PRESENT	0
94800	94220	11036J	PARTICIPANT	\N	PRESENT	0
94801	94220	11071M	PARTICIPANT	\N	PRESENT	0
94802	94220	14063N	PARTICIPANT	\N	PRESENT	0
94803	94220	86044G	PARTICIPANT	\N	PRESENT	0
94804	94220	95049N	PARTICIPANT	\N	PRESENT	0
94805	94220	14209N	PARTICIPANT	\N	PRESENT	0
94806	94220	08031R	PARTICIPANT	\N	PRESENT	0
94807	94220	14097Y	PARTICIPANT	\N	PRESENT	0
94808	94220	08051V	PARTICIPANT	\N	PRESENT	0
94809	94220	08061X	PARTICIPANT	\N	PRESENT	0
94810	94220	14249W	PARTICIPANT	\N	PRESENT	0
94811	94220	11103C	PARTICIPANT	\N	PRESENT	0
94812	94220	14001X	PARTICIPANT	\N	PRESENT	0
94813	94220	04081K	PARTICIPANT	\N	PRESENT	0
94814	94220	14147R	PARTICIPANT	\N	PRESENT	0
94815	94220	99004R	PARTICIPANT	\N	PRESENT	0
94816	94220	08010L	PARTICIPANT	\N	PRESENT	0
94817	94220	11093T	PARTICIPANT	\N	PRESENT	0
94818	94220	90003B	PARTICIPANT	\N	PRESENT	0
94819	94220	08022Q	PARTICIPANT	\N	PRESENT	0
94820	94220	08019V	PARTICIPANT	\N	PRESENT	0
94821	94220	14327T	PARTICIPANT	\N	PRESENT	0
94822	94220	11097X	PARTICIPANT	\N	PRESENT	0
94823	94220	14069U	PARTICIPANT	\N	PRESENT	0
94824	94220	14031R	PARTICIPANT	\N	PRESENT	0
94825	94220	14331P	PARTICIPANT	\N	PRESENT	0
94826	94220	13002U	PARTICIPANT	\N	PRESENT	0
94827	94220	01031L	PARTICIPANT	\N	PRESENT	0
94828	94220	14159V	PARTICIPANT	\N	PRESENT	0
94829	94220	14173T	PARTICIPANT	\N	PRESENT	0
94830	94220	14079W	PARTICIPANT	\N	PRESENT	0
94831	94220	08048B	PARTICIPANT	\N	PRESENT	0
94832	94220	04080J	PARTICIPANT	\N	PRESENT	0
94833	94220	04044E	PARTICIPANT	\N	PRESENT	0
94834	94220	80013X	PARTICIPANT	\N	PRESENT	0
94875	94220	01022K	PARTICIPANT	\N	PRESENT	0
94876	94220	04066L	PARTICIPANT	\N	PRESENT	0
94877	94220	11074Q	PARTICIPANT	\N	PRESENT	0
94878	94220	14219Q	PARTICIPANT	\N	PRESENT	0
94879	94220	04049K	PARTICIPANT	\N	PRESENT	0
94880	94220	14013P	PARTICIPANT	\N	PRESENT	0
94881	94220	11095V	PARTICIPANT	\N	PRESENT	0
94882	94220	11111C	PARTICIPANT	\N	PRESENT	0
94883	94220	14217N	PARTICIPANT	\N	PRESENT	0
94884	94220	04088S	PARTICIPANT	\N	PRESENT	0
94885	94220	14107H	PARTICIPANT	\N	PRESENT	0
94886	94220	14237S	PARTICIPANT	\N	PRESENT	0
94887	94220	08028W	PARTICIPANT	\N	PRESENT	0
94888	94220	11083R	PARTICIPANT	\N	PRESENT	0
94890	94220	14221J	PARTICIPANT	\N	PRESENT	0
94892	94220	01056V	PARTICIPANT	\N	PRESENT	0
94893	94220	01057W	PARTICIPANT	\N	PRESENT	0
94894	94220	01048V	PARTICIPANT	\N	PRESENT	0
94895	94220	11098Y	PARTICIPANT	\N	PRESENT	0
94896	94220	14197C	PARTICIPANT	\N	PRESENT	0
94897	94220	14121F	PARTICIPANT	\N	PRESENT	0
94898	94220	14239U	PARTICIPANT	\N	PRESENT	0
94899	94220	08068F	PARTICIPANT	\N	PRESENT	0
94900	94220	14259Y	PARTICIPANT	\N	PRESENT	0
119093	119092	11104D	PARTICIPANT	\N	PRESENT	0
119094	119092	95063L	PARTICIPANT	\N	PRESENT	0
119095	119092	11046L	PARTICIPANT	\N	PRESENT	0
119096	119092	04035D	PARTICIPANT	\N	PRESENT	0
119097	119092	11100Y	PARTICIPANT	\N	PRESENT	0
119098	119092	14269B	PARTICIPANT	\N	PRESENT	0
119100	119099	11100Y	PARTICIPANT	\N	PRESENT	0
119101	119099	11104D	PARTICIPANT	\N	PRESENT	0
119102	119099	14235Q	PARTICIPANT	\N	PRESENT	0
119103	119099	01028R	PARTICIPANT	\N	PRESENT	0
119104	119099	11066Q	PARTICIPANT	\N	PRESENT	0
119105	119099	14269B	PARTICIPANT	\N	PRESENT	0
119106	119099	11046L	PARTICIPANT	\N	PRESENT	0
123079	123078	96004D	PARTICIPANT	\N	PRESENT	0
123080	123078	90003B	PARTICIPANT	\N	PRESENT	0
123081	123078	04067M	PARTICIPANT	\N	PRESENT	0
123082	123078	04036E	PARTICIPANT	\N	PRESENT	0
123083	123078	08010L	PARTICIPANT	\N	PRESENT	0
123084	123078	14059S	PARTICIPANT	\N	PRESENT	0
123085	123078	04057K	PARTICIPANT	\N	PRESENT	0
123086	123078	04088S	PARTICIPANT	\N	PRESENT	0
123087	123078	95062K	PARTICIPANT	\N	PRESENT	0
123088	123078	04044E	PARTICIPANT	\N	PRESENT	0
123856	123855	08025T	PARTICIPANT	\N	PRESENT	0
123858	123857	08025T	PARTICIPANT	\N	PRESENT	0
123861	123859	08025T	PARTICIPANT	\N	PRESENT	0
123863	123862	08025T	PARTICIPANT	\N	PRESENT	0
123865	123864	08025T	PARTICIPANT	\N	PRESENT	0
123877	123876	04067M	PARTICIPANT	\N	PRESENT	0
123878	123876	04045F	PARTICIPANT	\N	PRESENT	0
124097	124096	96004D	PRESIDENT	0	PRESENT	0
124098	124096	04040A	PARTICIPANT	\N	PRESENT	0
124099	124096	04042C	PARTICIPANT	\N	PRESENT	0
124100	124096	04035D	PARTICIPANT	\N	PRESENT	0
124101	124096	11083R	PARTICIPANT	\N	PRESENT	0
124102	124096	14014Q	PARTICIPANT	\N	PRESENT	0
124103	124096	98022P	PARTICIPANT	\N	PRESENT	0
124104	124096	14097Y	PARTICIPANT	\N	PRESENT	0
124105	124096	04061F	PARTICIPANT	\N	PRESENT	0
124108	124096	14073Q	PARTICIPANT	\N	PRESENT	0
124109	124096	14001X	PARTICIPANT	\N	PRESENT	0
124110	124096	04057K	PARTICIPANT	\N	PRESENT	0
124111	124096	98021N	PARTICIPANT	\N	PRESENT	0
124112	124096	04080J	PARTICIPANT	\N	PRESENT	0
124113	124096	95059Q	PRESIDENT	1	PRESENT	0
124114	124096	98035U	PARTICIPANT	\N	PRESENT	0
124115	124096	04034C	PARTICIPANT	\N	PRESENT	0
124116	124096	08058D	PARTICIPANT	\N	PRESENT	0
125100	125099	11076S	PARTICIPANT	\N	PRESENT	0
125177	125175	11076S	PARTICIPANT	\N	PRESENT	0
125102	125099	04040A	PARTICIPANT	\N	PRESENT	0
125103	125099	08058D	PARTICIPANT	\N	PRESENT	0
125104	125099	04042C	PARTICIPANT	\N	PRESENT	0
125105	125099	77002U	PARTICIPANT	\N	PRESENT	0
125106	125099	98029W	PARTICIPANT	\N	PRESENT	0
125107	125099	11080N	PARTICIPANT	\N	PRESENT	0
125315	119925	11112D	PARTICIPANT	\N	PRESENT	0
125109	125099	98018T	PARTICIPANT	\N	PRESENT	0
125110	125099	92018S	PARTICIPANT	\N	PRESENT	0
125179	125175	04040A	PARTICIPANT	\N	PRESENT	0
125112	125099	95030B	PARTICIPANT	\N	PRESENT	0
125180	125175	08058D	PARTICIPANT	\N	PRESENT	0
125114	125099	95031C	PARTICIPANT	\N	PRESENT	0
125181	125175	04042C	PARTICIPANT	\N	PRESENT	0
125529	125523	89017R	PARTICIPANT	\N	PRESENT	0
125117	125099	04035D	PARTICIPANT	\N	PRESENT	0
125118	125099	07024N	PARTICIPANT	\N	PRESENT	0
125183	125175	98029W	PARTICIPANT	\N	PRESENT	0
125120	125099	14014Q	PARTICIPANT	\N	PRESENT	0
125121	125099	11015D	PARTICIPANT	\N	PRESENT	0
125184	125175	11080N	PARTICIPANT	\N	PRESENT	0
125123	125099	95035G	PARTICIPANT	\N	PRESENT	0
125530	125523	01031L	PRESIDENT	0	PRESENT	0
125125	125099	14211G	PARTICIPANT	\N	PRESENT	0
125126	125099	98022P	PARTICIPANT	\N	PRESENT	0
125127	125099	11064N	PARTICIPANT	\N	PRESENT	0
125186	125175	98018T	PARTICIPANT	\N	PRESENT	0
125187	125175	92018S	PARTICIPANT	\N	PRESENT	0
125130	125099	14097Y	PARTICIPANT	\N	PRESENT	0
125131	125099	95041E	PARTICIPANT	\N	PRESENT	0
125132	125099	04036E	PARTICIPANT	\N	PRESENT	0
125531	125523	11040E	PARTICIPANT	\N	PRESENT	0
125134	125099	04077P	PARTICIPANT	\N	PRESENT	0
125135	125099	98005N	PARTICIPANT	\N	PRESENT	0
125136	125099	92031P	PARTICIPANT	\N	PRESENT	0
125137	125099	11106F	PARTICIPANT	\N	PRESENT	0
125138	125099	14251Q	PARTICIPANT	\N	PRESENT	0
125139	125099	83042R	PARTICIPANT	\N	PRESENT	0
125140	125099	08053X	PARTICIPANT	\N	PRESENT	0
125141	125099	11082Q	PARTICIPANT	\N	PRESENT	0
125142	125099	11105E	PARTICIPANT	\N	PRESENT	0
125143	125099	14253S	PARTICIPANT	\N	PRESENT	0
125532	125523	14175V	PARTICIPANT	\N	PRESENT	0
125145	125099	14028W	PARTICIPANT	\N	PRESENT	0
125146	125099	14193X	PARTICIPANT	\N	PRESENT	0
125147	125099	98021N	PARTICIPANT	\N	PRESENT	0
125148	125099	04080J	PARTICIPANT	\N	PRESENT	0
125149	125099	95059Q	PARTICIPANT	\N	PRESENT	0
125150	125099	86044G	PARTICIPANT	\N	PRESENT	0
125151	125099	01014K	PARTICIPANT	\N	PRESENT	0
125152	125099	11054L	PARTICIPANT	\N	PRESENT	0
125153	125099	01056V	PARTICIPANT	\N	PRESENT	0
125154	125099	92044U	PARTICIPANT	\N	PRESENT	0
125155	125099	08049C	PARTICIPANT	\N	PRESENT	0
125533	125523	14083S	PARTICIPANT	\N	PRESENT	0
125189	125175	95030B	PARTICIPANT	\N	PRESENT	0
125534	125523	11053K	PARTICIPANT	\N	PRESENT	0
125191	125175	95031C	PARTICIPANT	\N	PRESENT	0
125535	125523	14085U	PARTICIPANT	\N	PRESENT	0
125537	125523	88008L	PARTICIPANT	\N	PRESENT	0
125194	125175	04035D	PARTICIPANT	\N	PRESENT	0
125195	125175	07024N	PARTICIPANT	\N	PRESENT	0
125543	125523	04086Q	PARTICIPANT	\N	PRESENT	0
125197	125175	14014Q	PARTICIPANT	\N	PRESENT	0
125547	125523	11070L	PARTICIPANT	\N	PRESENT	0
125549	125523	11088W	PARTICIPANT	\N	PRESENT	0
125558	125523	08022Q	PARTICIPANT	\N	PRESENT	0
125562	125523	01027Q	PARTICIPANT	\N	PRESENT	0
125202	125175	14211G	PARTICIPANT	\N	PRESENT	0
125203	125175	98022P	PARTICIPANT	\N	PRESENT	0
125204	125175	11064N	PARTICIPANT	\N	PRESENT	0
125565	125523	04071H	PARTICIPANT	\N	PRESENT	0
125568	125523	11074Q	PARTICIPANT	\N	PRESENT	0
125207	125175	14097Y	PARTICIPANT	\N	PRESENT	0
125208	125175	95041E	PARTICIPANT	\N	PRESENT	0
125209	125175	04036E	PARTICIPANT	\N	PRESENT	0
125571	125523	98053W	PARTICIPANT	\N	EXCUSE	0
125211	125175	04077P	PARTICIPANT	\N	PRESENT	0
125212	125175	98005N	PARTICIPANT	\N	PRESENT	0
125213	125175	92031P	PARTICIPANT	\N	PRESENT	0
125214	125175	11106F	PARTICIPANT	\N	PRESENT	0
125215	125175	14251Q	PARTICIPANT	\N	PRESENT	0
125216	125175	83042R	PARTICIPANT	\N	PRESENT	0
125217	125175	08053X	PARTICIPANT	\N	PRESENT	0
125218	125175	11082Q	PARTICIPANT	\N	PRESENT	0
125219	125175	11105E	PARTICIPANT	\N	PRESENT	0
125220	125175	14253S	PARTICIPANT	\N	PRESENT	0
125221	125175	08047A	PARTICIPANT	\N	EXCUSE	0
125222	125175	14028W	PARTICIPANT	\N	PRESENT	0
125223	125175	14193X	PARTICIPANT	\N	PRESENT	0
125224	125175	98021N	PARTICIPANT	\N	PRESENT	0
125225	125175	04080J	PARTICIPANT	\N	PRESENT	0
125226	125175	95059Q	PARTICIPANT	\N	PRESENT	0
125227	125175	86044G	PARTICIPANT	\N	PRESENT	0
125228	125175	01014K	PARTICIPANT	\N	PRESENT	0
125229	125175	11054L	PARTICIPANT	\N	PRESENT	0
125230	125175	01056V	PARTICIPANT	\N	PRESENT	0
125231	125175	92044U	PARTICIPANT	\N	PRESENT	0
125232	125175	08049C	PARTICIPANT	\N	PRESENT	0
125574	125523	11083R	PARTICIPANT	\N	PRESENT	0
125577	125523	14199E	PARTICIPANT	\N	PRESENT	0
125580	125523	01057W	PARTICIPANT	\N	PRESENT	0
125584	125523	08069G	PARTICIPANT	\N	PRESENT	0
125588	125523	11048N	PARTICIPANT	\N	PRESENT	0
125592	125523	99004R	PARTICIPANT	\N	EXCUSE	0
125598	125523	14159V	PARTICIPANT	\N	PRESENT	0
125600	125523	07029T	PARTICIPANT	\N	PRESENT	0
125601	125523	08010L	PARTICIPANT	\N	PRESENT	0
125602	125523	08034U	PARTICIPANT	\N	PRESENT	0
125603	125523	01048V	PARTICIPANT	\N	PRESENT	0
125604	125523	98046X	PARTICIPANT	\N	PRESENT	0
125605	125523	11085T	PARTICIPANT	\N	EXCUSE	0
125606	125523	08011M	PARTICIPANT	\N	PRESENT	0
125607	125523	08061X	PARTICIPANT	\N	EXCUSE	0
125608	125523	01016M	PARTICIPANT	\N	PRESENT	0
125609	125523	14225N	PARTICIPANT	\N	PRESENT	0
125610	125523	11012A	PARTICIPANT	\N	PRESENT	0
125612	125523	14173T	PARTICIPANT	\N	PRESENT	0
125613	125523	08060W	PARTICIPANT	\N	PRESENT	0
105734	105732	14089Y	PARTICIPANT	\N	PRESENT	0
105735	105732	04047H	PARTICIPANT	\N	PRESENT	0
105736	105732	14079W	PARTICIPANT	\N	EXCUSE	0
105737	105732	14041T	PARTICIPANT	\N	EXCUSE	0
105738	105732	14097Y	PARTICIPANT	\N	PRESENT	0
105740	105732	14073Q	PARTICIPANT	\N	PRESENT	0
105741	105732	11026G	PARTICIPANT	\N	PRESENT	0
105742	105732	92031P	PRESIDENT	0	PRESENT	0
105743	105732	14251Q	PARTICIPANT	\N	PRESENT	0
105744	105732	14001X	PARTICIPANT	\N	PRESENT	0
104973	104972	08031R	PARTICIPANT	\N	PRESENT	0
105733	105732	04054G	PARTICIPANT	\N	PRESENT	0
105745	105732	14237S	PARTICIPANT	\N	PRESENT	0
105746	105732	95067Q	PARTICIPANT	\N	PRESENT	0
106253	106252	07004J	PARTICIPANT	\N	PRESENT	0
106354	106353	04053F	PARTICIPANT	\N	PRESENT	0
106355	106353	14255U	PARTICIPANT	\N	PRESENT	0
106356	106353	14053L	PARTICIPANT	\N	PRESENT	0
106357	106353	11103C	PARTICIPANT	\N	PRESENT	0
106358	106353	11044J	PARTICIPANT	\N	PRESENT	0
106359	106353	08052W	PARTICIPANT	\N	PRESENT	0
106360	106353	10006L	PARTICIPANT	\N	PRESENT	0
106361	106353	14217N	PARTICIPANT	\N	PRESENT	0
106362	106353	14042U	PARTICIPANT	\N	PRESENT	0
106363	106353	14281W	PARTICIPANT	\N	PRESENT	0
106364	106353	14087W	PARTICIPANT	\N	PRESENT	0
106365	106353	01003G	PARTICIPANT	\N	PRESENT	0
106366	106353	14231L	PARTICIPANT	\N	PRESENT	0
106367	106353	11061K	PARTICIPANT	\N	PRESENT	0
106368	106353	14037X	PARTICIPANT	\N	PRESENT	0
106369	106353	14223L	PARTICIPANT	\N	PRESENT	0
106370	106353	04092N	PRESIDENT	0	PRESENT	0
106371	106353	14265W	PARTICIPANT	\N	PRESENT	0
106372	106353	14071N	PARTICIPANT	\N	PRESENT	0
106373	106353	14271U	PARTICIPANT	\N	PRESENT	0
106374	106353	11097X	PARTICIPANT	\N	PRESENT	0
106375	106353	04045F	PARTICIPANT	\N	PRESENT	0
106376	106353	14227Q	PARTICIPANT	\N	PRESENT	0
106377	106353	14034U	PARTICIPANT	\N	PRESENT	0
106404	106403	14033T	PARTICIPANT	\N	PRESENT	0
106406	106405	14033T	PARTICIPANT	\N	PRESENT	0
106408	106407	14033T	PARTICIPANT	\N	PRESENT	0
106410	106409	14033T	PARTICIPANT	\N	PRESENT	0
106412	106411	14033T	PARTICIPANT	\N	PRESENT	0
106475	106415	98042T	PARTICIPANT	\N	PRESENT	0
106417	106415	08055A	PARTICIPANT	\N	PRESENT	0
106418	106415	08043V	PARTICIPANT	\N	PRESENT	0
106419	106415	08060W	PARTICIPANT	\N	PRESENT	0
106420	106415	14105F	PARTICIPANT	\N	PRESENT	0
106421	106415	08068F	PARTICIPANT	\N	PRESENT	0
106422	106415	14207L	PARTICIPANT	\N	PRESENT	0
106423	106415	11101A	PARTICIPANT	\N	PRESENT	0
106424	106415	14085U	PARTICIPANT	\N	PRESENT	0
106425	106415	92015P	PARTICIPANT	\N	PRESENT	0
106426	106415	14038Y	PARTICIPANT	\N	PRESENT	0
106476	106415	11107G	PARTICIPANT	\N	PRESENT	0
106428	106415	11042G	PARTICIPANT	\N	PRESENT	0
106429	106415	04038G	PARTICIPANT	\N	PRESENT	0
106430	106415	14209N	PARTICIPANT	\N	PRESENT	0
106431	106415	11027H	PARTICIPANT	\N	PRESENT	0
106432	106415	80013X	PARTICIPANT	\N	PRESENT	0
106477	106415	95037J	PARTICIPANT	\N	PRESENT	0
106434	106415	14197C	PARTICIPANT	\N	PRESENT	0
106435	106415	11110B	PARTICIPANT	\N	PRESENT	0
106436	106415	14187A	PARTICIPANT	\N	PRESENT	0
106437	106415	08065C	PARTICIPANT	\N	PRESENT	0
106438	106415	14199E	PARTICIPANT	\N	PRESENT	0
106439	106415	11061K	PARTICIPANT	\N	PRESENT	0
106440	106415	14014Q	PARTICIPANT	\N	PRESENT	0
106478	106415	01022K	PARTICIPANT	\N	PRESENT	0
106479	106415	14213J	PARTICIPANT	\N	PRESENT	0
106480	106415	14018U	PARTICIPANT	\N	PRESENT	0
106481	106415	92039X	PARTICIPANT	\N	PRESENT	0
106445	106415	08016S	PARTICIPANT	\N	PRESENT	0
106446	106415	14097Y	PARTICIPANT	\N	PRESENT	0
106482	106415	14257W	PARTICIPANT	\N	PRESENT	0
106448	106415	14159V	PARTICIPANT	\N	PRESENT	0
106449	106415	11059R	PARTICIPANT	\N	PRESENT	0
106483	106415	92040Q	PARTICIPANT	\N	PRESENT	0
106451	106415	14059S	PARTICIPANT	\N	PRESENT	0
106484	106415	11097X	PARTICIPANT	\N	PRESENT	0
106453	106415	14111D	PARTICIPANT	\N	PRESENT	0
106454	106415	08053X	PARTICIPANT	\N	PRESENT	0
106489	106488	04040A	PRESIDENT	0	PRESENT	0
106456	106415	08051V	PARTICIPANT	\N	PRESENT	0
106457	106415	11014C	PARTICIPANT	\N	PRESENT	0
106458	106415	04092N	PARTICIPANT	\N	PRESENT	0
106459	106415	14109K	PARTICIPANT	\N	PRESENT	0
106460	106415	14265W	PARTICIPANT	\N	PRESENT	0
106490	106488	11044J	PARTICIPANT	\N	EXCUSE	0
106491	106488	11035H	PARTICIPANT	\N	EXCUSE	0
106463	106415	14135M	PARTICIPANT	\N	PRESENT	0
106492	106488	11048N	PARTICIPANT	\N	EXCUSE	0
106465	106415	11012A	PARTICIPANT	\N	PRESENT	0
106466	106415	14271U	PARTICIPANT	\N	PRESENT	0
106793	106792	04086Q	PARTICIPANT	\N	PRESENT	0
106468	106415	04045F	PARTICIPANT	\N	PRESENT	0
106469	106415	98035U	PARTICIPANT	\N	PRESENT	0
106470	106415	92045V	PARTICIPANT	\N	PRESENT	0
106796	106795	04086Q	PARTICIPANT	\N	PRESENT	0
106894	106893	04061F	PARTICIPANT	\N	PRESENT	0
106895	106893	08022Q	PARTICIPANT	\N	PRESENT	0
106897	106896	14327T	PARTICIPANT	\N	PRESENT	0
106899	106898	14327T	PARTICIPANT	\N	PRESENT	0
106901	106900	14327T	PARTICIPANT	\N	PRESENT	0
106903	106902	14327T	PARTICIPANT	\N	PRESENT	0
106913	106912	08061X	PARTICIPANT	\N	PRESENT	0
106923	106922	11053K	PARTICIPANT	\N	PRESENT	0
106925	106924	11053K	PARTICIPANT	\N	PRESENT	0
107153	107054	11103C	PARTICIPANT	\N	PRESENT	0
107154	107054	11031D	PARTICIPANT	\N	PRESENT	0
107155	107054	11093T	PARTICIPANT	\N	PRESENT	0
107156	107054	14087W	PARTICIPANT	\N	PRESENT	0
107157	107054	08031R	PARTICIPANT	\N	PRESENT	0
107158	107054	14271U	PARTICIPANT	\N	PRESENT	0
107159	107054	10006L	PARTICIPANT	\N	PRESENT	0
107160	107054	98005N	PARTICIPANT	\N	PRESENT	0
107161	107054	14255U	PARTICIPANT	\N	PRESENT	0
107162	107054	11077T	PARTICIPANT	\N	PRESENT	0
107163	107054	01041N	PARTICIPANT	\N	PRESENT	0
107164	107054	08016S	PARTICIPANT	\N	PRESENT	0
107165	107054	01048V	PARTICIPANT	\N	PRESENT	0
107166	107054	95037J	PARTICIPANT	\N	PRESENT	0
107167	107054	11089X	PARTICIPANT	\N	PRESENT	0
107168	107054	11061K	PARTICIPANT	\N	PRESENT	0
107169	107054	98018T	PARTICIPANT	\N	PRESENT	0
107170	107054	11011M	PARTICIPANT	\N	PRESENT	0
107171	107054	04034C	PARTICIPANT	\N	PRESENT	0
107172	107054	77002U	PARTICIPANT	\N	PRESENT	0
107173	107054	08017T	PARTICIPANT	\N	PRESENT	0
107192	107054	14038Y	PARTICIPANT	\N	PRESENT	0
107193	107054	14041T	PARTICIPANT	\N	PRESENT	0
107194	107054	04036E	PARTICIPANT	\N	PRESENT	0
107195	107054	14219Q	PARTICIPANT	\N	PRESENT	0
107196	107054	14147R	PARTICIPANT	\N	PRESENT	0
107197	107054	04049K	PARTICIPANT	\N	PRESENT	0
107198	107054	14071N	PARTICIPANT	\N	PRESENT	0
107199	107054	11035H	PARTICIPANT	\N	PRESENT	0
107200	107054	11026G	PARTICIPANT	\N	PRESENT	0
107201	107054	04085P	PARTICIPANT	\N	PRESENT	0
107202	107054	14205J	PARTICIPANT	\N	PRESENT	0
107203	107054	11076S	PARTICIPANT	\N	PRESENT	0
107204	107054	01044R	PARTICIPANT	\N	PRESENT	0
107205	107054	80013X	PARTICIPANT	\N	PRESENT	0
107206	107054	14042U	PARTICIPANT	\N	PRESENT	0
107212	107054	95041E	PARTICIPANT	\N	PRESENT	0
107213	107055	08024S	PARTICIPANT	\N	PRESENT	0
107214	107055	04092N	PARTICIPANT	\N	PRESENT	0
107215	107055	14037X	PARTICIPANT	\N	PRESENT	0
107216	107055	01059Y	PARTICIPANT	\N	PRESENT	0
107217	107055	11063M	PARTICIPANT	\N	PRESENT	0
107218	107055	07026Q	PARTICIPANT	\N	PRESENT	0
107219	107055	11031D	PARTICIPANT	\N	PRESENT	0
107220	107055	14087W	PARTICIPANT	\N	PRESENT	0
107221	107055	14034U	PARTICIPANT	\N	PRESENT	0
107222	107055	04053F	PARTICIPANT	\N	PRESENT	0
107223	107055	14271U	PARTICIPANT	\N	PRESENT	0
107224	107055	11110B	PARTICIPANT	\N	PRESENT	0
107225	107055	08016S	PARTICIPANT	\N	PRESENT	0
107226	107055	95037J	PARTICIPANT	\N	PRESENT	0
107227	107055	80013X	PARTICIPANT	\N	PRESENT	0
107228	107055	08052W	PARTICIPANT	\N	PRESENT	0
107229	107055	14219Q	PARTICIPANT	\N	PRESENT	0
107230	107055	14042U	PARTICIPANT	\N	PRESENT	0
107231	107055	11093T	PARTICIPANT	\N	PRESENT	0
107232	107055	14026U	PARTICIPANT	\N	PRESENT	0
107233	107055	14265W	PARTICIPANT	\N	PRESENT	0
107234	107055	08031R	PARTICIPANT	\N	PRESENT	0
107235	107055	98053W	PARTICIPANT	\N	PRESENT	0
114612	113115	11040E	PARTICIPANT	\N	PRESENT	0
114613	113115	11098Y	PARTICIPANT	\N	PRESENT	0
114614	113115	80013X	PARTICIPANT	\N	PRESENT	0
114615	113115	14207L	PARTICIPANT	\N	PRESENT	0
114616	113115	14097Y	PARTICIPANT	\N	PRESENT	0
114617	113115	11099A	PARTICIPANT	\N	PRESENT	0
114618	113115	11110B	PARTICIPANT	\N	PRESENT	0
114619	113115	14267Y	PARTICIPANT	\N	PRESENT	0
114620	113115	14219Q	PARTICIPANT	\N	PRESENT	0
114621	113115	04089T	PARTICIPANT	\N	PRESENT	0
114622	113115	07034Q	PARTICIPANT	\N	PRESENT	0
114623	113115	14331P	PARTICIPANT	\N	PRESENT	0
114624	113115	14205J	PARTICIPANT	\N	PRESENT	0
114625	113115	14265W	PARTICIPANT	\N	PRESENT	0
114626	113115	11090Q	PARTICIPANT	\N	PRESENT	0
114627	113115	14253S	PARTICIPANT	\N	PRESENT	0
114628	113115	96004D	PARTICIPANT	\N	PRESENT	0
114629	113115	95062K	PARTICIPANT	\N	PRESENT	0
114630	113115	04085P	PARTICIPANT	\N	PRESENT	0
114631	113115	14061L	PARTICIPANT	\N	PRESENT	0
114632	113115	14217N	PARTICIPANT	\N	PRESENT	0
114633	113115	11056N	PARTICIPANT	\N	PRESENT	0
114634	113115	14215L	PARTICIPANT	\N	PRESENT	0
114635	113115	08031R	PARTICIPANT	\N	PRESENT	0
114636	113115	14195A	PARTICIPANT	\N	PRESENT	0
114637	113115	08051V	PARTICIPANT	\N	PRESENT	0
114638	113115	14231L	PARTICIPANT	\N	PRESENT	0
114639	113115	01057W	PARTICIPANT	\N	PRESENT	0
114640	113115	11012A	PARTICIPANT	\N	PRESENT	0
114652	113115	08055A	PARTICIPANT	\N	PRESENT	0
114672	113115	01024M	PARTICIPANT	\N	PRESENT	0
114673	113115	04049K	PARTICIPANT	\N	PRESENT	0
114674	113115	11077T	PARTICIPANT	\N	PRESENT	0
114601	113115	01007L	PARTICIPANT	\N	PRESENT	0
114602	113115	14033T	PARTICIPANT	\N	PRESENT	0
114675	113115	11029K	PARTICIPANT	\N	PRESENT	0
114692	113115	04033B	PARTICIPANT	\N	PRESENT	0
114693	113115	14111D	PARTICIPANT	\N	PRESENT	0
114694	113115	11053K	PARTICIPANT	\N	PRESENT	0
114695	113115	14059S	PARTICIPANT	\N	PRESENT	0
114696	113115	92045V	PARTICIPANT	\N	PRESENT	0
114697	113115	08034U	PARTICIPANT	\N	PRESENT	0
114712	113115	14083S	PARTICIPANT	\N	PRESENT	0
114713	113115	80027E	PARTICIPANT	\N	PRESENT	0
114714	113115	11036J	PARTICIPANT	\N	PRESENT	0
114732	113115	01016M	PARTICIPANT	\N	PRESENT	0
114733	113115	14089Y	PARTICIPANT	\N	PRESENT	0
123246	120874	13002U	PARTICIPANT	\N	EXCUSE	0
123971	123970	04034C	PARTICIPANT	\N	PRESENT	0
123972	123970	01027Q	PARTICIPANT	\N	PRESENT	0
123974	123973	08016S	PARTICIPANT	\N	PRESENT	0
123976	123975	11076S	PARTICIPANT	\N	PRESENT	0
123977	123975	04054G	PARTICIPANT	\N	PRESENT	0
123978	123975	04040A	PRESIDENT	0	PRESENT	0
123979	123975	08058D	PARTICIPANT	\N	PRESENT	0
123980	123975	04042C	PRESIDENT	1	PRESENT	0
123981	123975	77002U	PARTICIPANT	\N	EXCUSE	0
123982	123975	92015P	PARTICIPANT	\N	PRESENT	0
123983	123975	11080N	PARTICIPANT	\N	PRESENT	0
123984	123975	11027H	PARTICIPANT	\N	EXCUSE	0
123985	123975	98018T	PARTICIPANT	\N	PRESENT	0
123986	123975	92018S	PARTICIPANT	\N	PRESENT	0
123987	123975	92020L	PARTICIPANT	\N	PRESENT	0
123988	123975	95031C	PARTICIPANT	\N	PRESENT	0
123989	123975	08065C	PARTICIPANT	\N	PRESENT	0
123990	123975	11010L	PARTICIPANT	\N	PRESENT	0
123991	123975	04035D	PARTICIPANT	\N	PRESENT	0
123992	123975	07024N	PARTICIPANT	\N	PRESENT	0
123993	123975	04095R	PARTICIPANT	\N	PRESENT	0
123994	123975	14014Q	PARTICIPANT	\N	PRESENT	0
123995	123975	11015D	PARTICIPANT	\N	PRESENT	0
123996	123975	07004J	PARTICIPANT	\N	PRESENT	0
123997	123975	95035G	PARTICIPANT	\N	PRESENT	0
123998	123975	98022P	PARTICIPANT	\N	PRESENT	0
123999	123975	11064N	PARTICIPANT	\N	PRESENT	0
124000	123975	04078Q	PARTICIPANT	\N	PRESENT	0
124001	123975	98005N	PARTICIPANT	\N	PRESENT	0
124002	123975	11106F	PARTICIPANT	\N	PRESENT	0
124003	123975	08053X	PARTICIPANT	\N	PRESENT	0
124004	123975	11082Q	PARTICIPANT	\N	PRESENT	0
124005	123975	11105E	PARTICIPANT	\N	PRESENT	0
124006	123975	08047A	PARTICIPANT	\N	PRESENT	0
124007	123975	98021N	PARTICIPANT	\N	PRESENT	0
124008	123975	04080J	PARTICIPANT	\N	PRESENT	0
124009	123975	95059Q	PARTICIPANT	\N	PRESENT	0
124010	123975	01014K	PARTICIPANT	\N	PRESENT	0
124011	123975	11012A	PARTICIPANT	\N	PRESENT	0
124012	123975	11054L	PARTICIPANT	\N	PRESENT	0
124013	123975	01056V	PARTICIPANT	\N	PRESENT	0
124014	123975	86034E	PARTICIPANT	\N	PRESENT	0
124021	124020	14173T	PARTICIPANT	\N	PRESENT	0
124023	124022	99004R	PARTICIPANT	\N	PRESENT	0
124038	124036	05004A	PARTICIPANT	\N	PRESENT	0
124053	124052	11088W	PARTICIPANT	\N	PRESENT	0
124449	124448	10006L	PARTICIPANT	\N	PRESENT	0
124450	124448	98042T	PARTICIPANT	\N	PRESENT	0
124451	124448	11048N	PARTICIPANT	\N	PRESENT	0
124452	124448	04088S	PARTICIPANT	\N	PRESENT	0
124453	124448	11043H	PARTICIPANT	\N	PRESENT	0
124485	124484	11039M	PARTICIPANT	\N	PRESENT	0
124486	124484	98042T	PARTICIPANT	\N	PRESENT	0
124487	124484	01019Q	PARTICIPANT	\N	PRESENT	0
124854	124853	98029W	PARTICIPANT	\N	PRESENT	0
125296	125295	08039A	PARTICIPANT	\N	PRESENT	0
125297	125295	11026G	PARTICIPANT	\N	PRESENT	0
125298	125295	95062K	PARTICIPANT	\N	PRESENT	0
125299	125295	11054L	PARTICIPANT	\N	PRESENT	0
125300	125295	04045F	PARTICIPANT	\N	PRESENT	0
125301	125295	01008M	PARTICIPANT	\N	PRESENT	0
125425	125334	04054G	PARTICIPANT	\N	PRESENT	0
125426	125334	08058D	PARTICIPANT	\N	PRESENT	0
125427	125334	04042C	PARTICIPANT	\N	PRESENT	0
125428	125334	98029W	PARTICIPANT	\N	PRESENT	0
125429	125334	98018T	PARTICIPANT	\N	PRESENT	0
125430	125334	92018S	PARTICIPANT	\N	PRESENT	0
125431	125334	95030B	PARTICIPANT	\N	PRESENT	0
125432	125334	95031C	PARTICIPANT	\N	PRESENT	0
125433	125334	04035D	PARTICIPANT	\N	PRESENT	0
125434	125334	14014Q	PARTICIPANT	\N	PRESENT	0
125435	125334	14097Y	PARTICIPANT	\N	PRESENT	0
125436	125334	92031P	PARTICIPANT	\N	PRESENT	0
125437	125334	14251Q	PARTICIPANT	\N	PRESENT	0
125438	125334	14028W	PARTICIPANT	\N	PRESENT	0
125439	125334	98021N	PARTICIPANT	\N	PRESENT	0
125440	125334	11054L	PARTICIPANT	\N	PRESENT	0
125441	125334	01056V	PARTICIPANT	\N	PRESENT	0
125442	125334	04057K	PARTICIPANT	\N	PRESENT	0
125443	125334	14073Q	PARTICIPANT	\N	PRESENT	0
125444	125334	14026U	PARTICIPANT	\N	PRESENT	0
125445	125334	14135M	PARTICIPANT	\N	PRESENT	0
125446	125334	14089Y	PARTICIPANT	\N	PRESENT	0
125447	125334	14249W	PARTICIPANT	\N	PRESENT	0
125448	125334	11083R	PARTICIPANT	\N	PRESENT	0
125449	125334	01016M	PARTICIPANT	\N	PRESENT	0
125450	125334	11026G	PARTICIPANT	\N	PRESENT	0
125451	125334	98046X	PARTICIPANT	\N	PRESENT	0
125452	125334	04045F	PARTICIPANT	\N	PRESENT	0
125453	125334	11035H	PARTICIPANT	\N	PRESENT	0
125454	125334	14255U	PARTICIPANT	\N	PRESENT	0
125455	125334	08055A	PARTICIPANT	\N	PRESENT	0
125456	125334	11089X	PARTICIPANT	\N	PRESENT	0
125457	125334	11107G	PARTICIPANT	\N	PRESENT	0
125458	125334	01027Q	PARTICIPANT	\N	PRESENT	0
125459	125334	08017T	PARTICIPANT	\N	PRESENT	0
125460	125334	08041T	PARTICIPANT	\N	PRESENT	0
125461	125334	08060W	PARTICIPANT	\N	PRESENT	0
125462	125334	14269B	PARTICIPANT	\N	PRESENT	0
125463	125334	14159V	PARTICIPANT	\N	PRESENT	0
94901	94220	08034U	PARTICIPANT	\N	PRESENT	0
94902	94220	04048J	PARTICIPANT	\N	PRESENT	0
94932	94220	14030Q	PARTICIPANT	\N	PRESENT	0
94933	94220	14041T	PARTICIPANT	\N	PRESENT	0
94934	94220	14199E	PARTICIPANT	\N	PRESENT	0
94935	94220	14135M	PARTICIPANT	\N	PRESENT	0
94936	94220	14225N	PARTICIPANT	\N	PRESENT	0
94937	94220	14051J	PARTICIPANT	\N	PRESENT	0
94938	94220	01037S	PARTICIPANT	\N	PRESENT	0
94939	94220	14089Y	PARTICIPANT	\N	PRESENT	0
94940	94220	11043H	PARTICIPANT	\N	PRESENT	0
94941	94220	11090Q	PARTICIPANT	\N	PRESENT	0
94942	94220	08056B	PARTICIPANT	\N	PRESENT	0
94943	94220	11059R	PARTICIPANT	\N	PRESENT	0
94944	94220	01016M	PARTICIPANT	\N	PRESENT	0
94945	94220	11109J	PARTICIPANT	\N	PRESENT	0
94946	94220	14042U	PARTICIPANT	\N	PRESENT	0
94947	94220	14133K	PARTICIPANT	\N	PRESENT	0
95053	94221	01025N	PARTICIPANT	\N	PRESENT	0
95054	94221	08039A	PARTICIPANT	\N	PRESENT	0
95055	94221	14263U	PARTICIPANT	\N	PRESENT	0
95056	94221	14235Q	PARTICIPANT	\N	PRESENT	0
95057	94221	07026Q	PARTICIPANT	\N	PRESENT	0
95058	94221	11074Q	PARTICIPANT	\N	PRESENT	0
95059	94221	14257W	PARTICIPANT	\N	PRESENT	0
95060	94221	11036J	PARTICIPANT	\N	PRESENT	0
95061	94221	14028W	PARTICIPANT	\N	PRESENT	0
95062	94221	01044R	PARTICIPANT	\N	PRESENT	0
95063	94221	01016M	PARTICIPANT	\N	PRESENT	0
95064	94221	11029K	PARTICIPANT	\N	PRESENT	0
95065	94221	08043V	PARTICIPANT	\N	PRESENT	0
95066	94221	04059M	PARTICIPANT	\N	PRESENT	0
95067	94221	14109K	PARTICIPANT	\N	PRESENT	0
95068	94221	14229S	PARTICIPANT	\N	PRESENT	0
95069	94221	95049N	PARTICIPANT	\N	PRESENT	0
95070	94221	08019V	PARTICIPANT	\N	PRESENT	0
95071	94221	14061L	PARTICIPANT	\N	PRESENT	0
95072	94221	14026U	PARTICIPANT	\N	PRESENT	0
95073	94221	14147R	PARTICIPANT	\N	PRESENT	0
95074	94221	14215L	PARTICIPANT	\N	PRESENT	0
95075	94221	95031C	PARTICIPANT	\N	PRESENT	0
95076	94221	14087W	PARTICIPANT	\N	PRESENT	0
95077	94221	14169X	PARTICIPANT	\N	PRESENT	0
95078	94221	11109J	PARTICIPANT	\N	PRESENT	0
95079	94221	14241N	PARTICIPANT	\N	PRESENT	0
95080	94221	14073Q	PARTICIPANT	\N	PRESENT	0
95092	94221	14030Q	PARTICIPANT	\N	PRESENT	0
95093	94221	14249W	PARTICIPANT	\N	PRESENT	0
95094	94221	04033B	PARTICIPANT	\N	PRESENT	0
95095	94221	14219Q	PARTICIPANT	\N	PRESENT	0
95096	94221	14042U	PARTICIPANT	\N	PRESENT	0
95097	94221	14103D	PARTICIPANT	\N	PRESENT	0
95098	94221	14231L	PARTICIPANT	\N	PRESENT	0
95099	94221	01034P	PARTICIPANT	\N	PRESENT	0
95100	94221	14083S	PARTICIPANT	\N	PRESENT	0
95101	94221	04088S	PARTICIPANT	\N	PRESENT	0
95102	94221	11012A	PARTICIPANT	\N	PRESENT	0
95103	94221	14059S	PARTICIPANT	\N	PRESENT	0
95104	94221	14217N	PARTICIPANT	\N	PRESENT	0
95105	94221	80013X	PARTICIPANT	\N	PRESENT	0
95106	94221	14265W	PARTICIPANT	\N	PRESENT	0
95107	94221	01028R	PARTICIPANT	\N	PRESENT	0
95108	94221	14031R	PARTICIPANT	\N	PRESENT	0
95109	94221	11097X	PARTICIPANT	\N	PRESENT	0
95110	94221	08031R	PARTICIPANT	\N	PRESENT	0
95111	94221	14033T	PARTICIPANT	\N	PRESENT	0
95112	94221	14053L	PARTICIPANT	\N	PRESENT	0
95113	94221	14123H	PARTICIPANT	\N	PRESENT	0
95114	94221	14037X	PARTICIPANT	\N	PRESENT	0
95115	94221	14119M	PARTICIPANT	\N	PRESENT	0
95116	94221	14089Y	PARTICIPANT	\N	PRESENT	0
95117	94221	11095V	PARTICIPANT	\N	PRESENT	0
95118	94221	01008M	PARTICIPANT	\N	PRESENT	0
95119	94221	01057W	PARTICIPANT	\N	PRESENT	0
95120	94221	11043H	PARTICIPANT	\N	PRESENT	0
95121	94221	92045V	PARTICIPANT	\N	PRESENT	0
95122	94221	14111D	PARTICIPANT	\N	PRESENT	0
95123	94221	14133K	PARTICIPANT	\N	PRESENT	0
95577	94734	95049N	PARTICIPANT	\N	PRESENT	0
95578	94734	11025F	PARTICIPANT	\N	PRESENT	0
95579	94734	14103D	PARTICIPANT	\N	PRESENT	0
95580	94734	01022K	PARTICIPANT	\N	PRESENT	0
95581	94734	92015P	PARTICIPANT	\N	PRESENT	0
95582	94734	95015C	PARTICIPANT	\N	PRESENT	0
95583	94734	04038G	PARTICIPANT	\N	PRESENT	0
95584	94734	14263U	PARTICIPANT	\N	PRESENT	0
95585	94734	08039A	PARTICIPANT	\N	PRESENT	0
95586	94734	11056N	PARTICIPANT	\N	PRESENT	0
95587	94734	14207L	PARTICIPANT	\N	PRESENT	0
95588	94734	14038Y	PARTICIPANT	\N	PRESENT	0
95589	94734	14065Q	PARTICIPANT	\N	PRESENT	0
95590	94734	92045V	PARTICIPANT	\N	PRESENT	0
95641	94734	14059S	PARTICIPANT	\N	PRESENT	0
95642	94734	14061L	PARTICIPANT	\N	PRESENT	0
95643	94734	11014C	PARTICIPANT	\N	PRESENT	0
95051	94221	01007L	PARTICIPANT	\N	PRESENT	0
95052	94221	04070G	PARTICIPANT	\N	PRESENT	0
95644	94734	14191V	PARTICIPANT	\N	PRESENT	0
95645	94734	14111D	PARTICIPANT	\N	PRESENT	0
95647	94734	04088S	PARTICIPANT	\N	PRESENT	0
95648	94734	08058D	PARTICIPANT	\N	PRESENT	0
95649	94734	08051V	PARTICIPANT	\N	PRESENT	0
95708	94734	14107H	PARTICIPANT	\N	PRESENT	0
95709	94734	08044W	PARTICIPANT	\N	PRESENT	0
95710	94734	14147R	PARTICIPANT	\N	PRESENT	0
95711	94734	08047A	PARTICIPANT	\N	PRESENT	0
95712	94734	14033T	PARTICIPANT	\N	PRESENT	0
95713	94734	14257W	PARTICIPANT	\N	PRESENT	0
95714	94734	14209N	PARTICIPANT	\N	PRESENT	0
95716	94734	04095R	PARTICIPANT	\N	PRESENT	0
95778	94734	11033F	PARTICIPANT	\N	PRESENT	0
95779	94734	01028R	PARTICIPANT	\N	PRESENT	0
95780	94734	14197C	PARTICIPANT	\N	PRESENT	0
95781	94734	08055A	PARTICIPANT	\N	PRESENT	0
95822	94734	14051J	PARTICIPANT	\N	PRESENT	0
95823	94734	11089X	PARTICIPANT	\N	PRESENT	0
95824	94734	14105F	PARTICIPANT	\N	PRESENT	0
95825	94734	11080N	PARTICIPANT	\N	PRESENT	0
95826	94734	14123H	PARTICIPANT	\N	PRESENT	0
95827	94734	08069G	PARTICIPANT	\N	PRESENT	0
95828	94734	01034P	PARTICIPANT	\N	PRESENT	0
95829	94734	11036J	PARTICIPANT	\N	PRESENT	0
95830	94734	87003B	PARTICIPANT	\N	PRESENT	0
95525	94734	98053W	PARTICIPANT	\N	PRESENT	0
95526	94734	01025N	PARTICIPANT	\N	PRESENT	0
95831	94734	14169X	PARTICIPANT	\N	PRESENT	0
95832	94734	01047U	PARTICIPANT	\N	PRESENT	0
95833	94734	14030Q	PARTICIPANT	\N	PRESENT	0
97756	97752	14207L	PARTICIPANT	\N	PRESENT	0
97754	97752	01008M	PARTICIPANT	\N	PRESENT	0
97755	97752	08055A	PARTICIPANT	\N	PRESENT	0
97757	97752	90003B	PARTICIPANT	\N	PRESENT	0
97758	97752	14195A	PARTICIPANT	\N	PRESENT	0
97759	97752	14042U	PARTICIPANT	\N	PRESENT	0
97760	97752	14197C	PARTICIPANT	\N	PRESENT	0
97761	97752	01037S	PARTICIPANT	\N	PRESENT	0
97762	97752	14033T	PARTICIPANT	\N	PRESENT	0
97763	97752	01061S	PARTICIPANT	\N	PRESENT	0
97764	97752	14205J	PARTICIPANT	\N	PRESENT	0
97765	97752	11014C	PARTICIPANT	\N	PRESENT	0
97766	97752	14265W	PARTICIPANT	\N	PRESENT	0
97767	97752	14169X	PARTICIPANT	\N	PRESENT	0
97768	97752	14237S	PARTICIPANT	\N	PRESENT	0
97769	97752	04088S	PARTICIPANT	\N	PRESENT	0
97770	97752	11097X	PARTICIPANT	\N	PRESENT	0
97771	97752	92045V	PARTICIPANT	\N	PRESENT	0
97895	97892	14281W	PRESIDENT	0	PRESENT	0
97893	97892	14217N	PARTICIPANT	\N	PRESENT	0
97894	97892	14041T	PARTICIPANT	\N	EXCUSE	0
97896	97892	07004J	PARTICIPANT	\N	PRESENT	0
97897	97892	92020L	PARTICIPANT	\N	EXCUSE	0
97898	97892	04061F	PARTICIPANT	\N	PRESENT	0
97899	97892	08053X	PARTICIPANT	\N	PRESENT	0
97900	97892	10015M	PARTICIPANT	\N	PRESENT	0
97901	97892	11054L	PARTICIPANT	\N	EXCUSE	0
97902	97892	14269B	PARTICIPANT	\N	EXCUSE	0
98714	95979	14030Q	PARTICIPANT	\N	PRESENT	0
98733	98732	14255U	PARTICIPANT	\N	PRESENT	0
98734	98732	04086Q	PARTICIPANT	\N	PRESENT	0
98735	98732	12042Y	PRESIDENT	0	PRESENT	0
98736	98732	11107G	PARTICIPANT	\N	PRESENT	0
98737	98732	14014Q	PARTICIPANT	\N	PRESENT	0
98738	98732	14026U	PARTICIPANT	\N	PRESENT	0
98739	98732	11112D	PARTICIPANT	\N	PRESENT	0
98740	98732	14205J	PARTICIPANT	\N	PRESENT	0
98741	98732	14135M	PARTICIPANT	\N	PRESENT	0
98742	98732	11097X	PARTICIPANT	\N	PRESENT	0
98743	98732	04045F	PARTICIPANT	\N	PRESENT	0
98744	98732	11100Y	PARTICIPANT	\N	EXCUSE	0
120433	120432	08015R	PARTICIPANT	\N	PRESENT	0
120434	120432	11097X	PARTICIPANT	\N	PRESENT	0
120435	120432	14105F	PARTICIPANT	\N	PRESENT	0
120436	120432	14109K	PARTICIPANT	\N	PRESENT	0
120437	120432	95037J	PARTICIPANT	\N	PRESENT	0
120438	120432	08055A	PARTICIPANT	\N	PRESENT	0
120439	120432	01019Q	PARTICIPANT	\N	PRESENT	0
120440	120432	14059S	PARTICIPANT	\N	PRESENT	0
120441	120432	11012A	PARTICIPANT	\N	PRESENT	0
120442	120432	14197C	PARTICIPANT	\N	PRESENT	0
120443	120432	14207L	PARTICIPANT	\N	PRESENT	0
120444	120432	14085U	PARTICIPANT	\N	PRESENT	0
120445	120432	11042G	PARTICIPANT	\N	PRESENT	0
120446	120432	14038Y	PARTICIPANT	\N	PRESENT	0
120447	120432	08053X	PARTICIPANT	\N	PRESENT	0
120448	120432	14097Y	PARTICIPANT	\N	PRESENT	0
120449	120432	14209N	PARTICIPANT	\N	PRESENT	0
120450	120432	11110B	PARTICIPANT	\N	PRESENT	0
120451	120432	14069U	PARTICIPANT	\N	PRESENT	0
120452	120432	14187A	PARTICIPANT	\N	PRESENT	0
120504	120503	11076S	PARTICIPANT	\N	PRESENT	0
120505	120503	04054G	PARTICIPANT	\N	PRESENT	0
120506	120503	04040A	PARTICIPANT	\N	EXCUSE	0
120507	120503	08058D	PARTICIPANT	\N	PRESENT	0
120508	120503	04042C	PARTICIPANT	\N	PRESENT	0
120509	120503	77002U	PARTICIPANT	\N	PRESENT	0
120510	120503	98029W	PARTICIPANT	\N	PRESENT	0
120511	120503	11080N	PARTICIPANT	\N	PRESENT	0
120512	120503	11027H	PARTICIPANT	\N	PRESENT	0
120513	120503	98018T	PARTICIPANT	\N	PRESENT	0
120561	120503	83042R	PARTICIPANT	\N	PRESENT	0
120661	120660	11055M	PARTICIPANT	\N	PRESENT	0
120516	120503	95030B	PARTICIPANT	\N	PRESENT	0
120662	120660	08043V	PARTICIPANT	\N	PRESENT	0
121075	121069	01031L	PRESIDENT	0	PRESENT	0
120664	120660	95015C	PARTICIPANT	\N	PRESENT	0
120520	120503	08065C	PARTICIPANT	\N	EXCUSE	0
120521	120503	04035D	PARTICIPANT	\N	PRESENT	0
120522	120503	07024N	PARTICIPANT	\N	PRESENT	0
120523	120503	04095R	PARTICIPANT	\N	EXCUSE	0
120524	120503	14014Q	PARTICIPANT	\N	PRESENT	0
120525	120503	11015D	PARTICIPANT	\N	PRESENT	0
120526	120503	07004J	PARTICIPANT	\N	PRESENT	0
120527	120503	95035G	PARTICIPANT	\N	EXCUSE	0
120528	120503	08056B	PARTICIPANT	\N	PRESENT	0
120665	120660	08024S	PARTICIPANT	\N	PRESENT	0
121080	121069	11040E	PARTICIPANT	\N	PRESENT	0
120531	120503	11064N	PARTICIPANT	\N	PRESENT	0
120532	120503	95037J	PARTICIPANT	\N	PRESENT	0
120533	120503	04078Q	PARTICIPANT	\N	PRESENT	0
120534	120503	14097Y	PARTICIPANT	\N	PRESENT	0
120535	120503	95041E	PARTICIPANT	\N	PRESENT	0
120667	120660	04086Q	PARTICIPANT	\N	PRESENT	0
120537	120503	14039A	PARTICIPANT	\N	PRESENT	0
120668	120660	14079W	PARTICIPANT	\N	PRESENT	0
121082	121069	08014Q	PARTICIPANT	\N	PRESENT	0
120540	120503	92031P	PARTICIPANT	\N	PRESENT	0
120541	120503	11106F	PARTICIPANT	\N	PRESENT	0
120542	120503	14251Q	PARTICIPANT	\N	PRESENT	0
120670	120660	14215L	PARTICIPANT	\N	PRESENT	0
121083	121069	14083S	PARTICIPANT	\N	EXCUSE	0
120671	120660	04089T	PARTICIPANT	\N	PRESENT	0
120546	120503	11105E	PARTICIPANT	\N	PRESENT	0
120547	120503	14253S	PARTICIPANT	\N	PRESENT	0
120548	120503	08047A	PARTICIPANT	\N	PRESENT	0
120549	120503	14028W	PARTICIPANT	\N	EXCUSE	0
120550	120503	14193X	PARTICIPANT	\N	PRESENT	0
120551	120503	98021N	PARTICIPANT	\N	PRESENT	0
120672	120660	14187A	PARTICIPANT	\N	PRESENT	0
120553	120503	95059Q	PRESIDENT	0	PRESENT	0
120554	120503	86044G	PARTICIPANT	\N	PRESENT	0
120673	120660	11034G	PARTICIPANT	\N	PRESENT	0
120556	120503	11054L	PARTICIPANT	\N	PRESENT	0
120674	120660	04035D	PARTICIPANT	\N	PRESENT	0
120675	120660	14231L	PARTICIPANT	\N	PRESENT	0
120559	120503	08049C	PARTICIPANT	\N	PRESENT	0
120560	120503	04050C	PARTICIPANT	\N	PRESENT	0
121086	121069	11042G	PARTICIPANT	\N	PRESENT	0
120677	120660	14213J	PARTICIPANT	\N	PRESENT	0
120678	120660	08031R	PARTICIPANT	\N	PRESENT	0
120679	120660	11100Y	PRESIDENT	0	PRESENT	0
121087	121069	98053W	PARTICIPANT	\N	EXCUSE	0
121088	121069	11083R	PARTICIPANT	\N	PRESENT	0
120682	120660	11104D	PARTICIPANT	\N	PRESENT	0
121090	121069	08016S	PARTICIPANT	\N	PRESENT	0
120684	120660	07032N	PARTICIPANT	\N	PRESENT	0
121097	121069	08069G	PARTICIPANT	\N	PRESENT	0
120686	120660	11090Q	PARTICIPANT	\N	PRESENT	0
120687	120660	14235Q	PARTICIPANT	\N	PRESENT	0
120688	120660	95063L	PARTICIPANT	\N	PRESENT	0
120689	120660	11046L	PARTICIPANT	\N	PRESENT	0
120690	120660	01028R	PARTICIPANT	\N	PRESENT	0
120691	120660	11094U	PARTICIPANT	\N	PRESENT	0
121099	121069	11048N	PARTICIPANT	\N	PRESENT	0
120693	120660	14157T	PARTICIPANT	\N	PRESENT	0
120694	120660	92045V	PARTICIPANT	\N	PRESENT	0
120695	120660	11066Q	PARTICIPANT	\N	PRESENT	0
120696	120660	14269B	PARTICIPANT	\N	PRESENT	0
121105	121069	14159V	PARTICIPANT	\N	PRESENT	0
121108	121069	07029T	PARTICIPANT	\N	EXCUSE	0
121113	121069	98046X	PARTICIPANT	\N	PRESENT	0
121115	121069	08011M	PARTICIPANT	\N	EXCUSE	0
121117	121069	08061X	PARTICIPANT	\N	EXCUSE	0
121118	121069	01016M	PARTICIPANT	\N	PRESENT	0
121121	121069	14225N	PARTICIPANT	\N	PRESENT	0
121123	121069	11057P	PARTICIPANT	\N	EXCUSE	0
121124	121069	04034C	PARTICIPANT	\N	PRESENT	0
121130	121069	96004D	PARTICIPANT	\N	PRESENT	0
121133	121069	04054G	PARTICIPANT	\N	PRESENT	0
121134	121069	14089Y	PARTICIPANT	\N	PRESENT	0
121135	121069	14135M	PARTICIPANT	\N	PRESENT	0
121137	121069	04045F	PARTICIPANT	\N	PRESENT	0
121138	121069	04057K	PARTICIPANT	\N	PRESENT	0
121140	121069	90003B	PARTICIPANT	\N	PRESENT	0
121141	121069	92045V	PARTICIPANT	\N	PRESENT	0
121142	121069	95037J	PARTICIPANT	\N	PRESENT	0
121143	121069	14097Y	PARTICIPANT	\N	PRESENT	0
121144	121069	11026G	PARTICIPANT	\N	PRESENT	0
121722	121721	14253S	PARTICIPANT	\N	PRESENT	0
121723	121721	14157T	PARTICIPANT	\N	PRESENT	0
121725	121724	14253S	PARTICIPANT	\N	PRESENT	0
121726	121724	14157T	PARTICIPANT	\N	PRESENT	0
121728	121727	14253S	PARTICIPANT	\N	PRESENT	0
121729	121727	14157T	PARTICIPANT	\N	PRESENT	0
123384	122639	11085T	PARTICIPANT	\N	PRESENT	0
123386	122639	14235Q	PARTICIPANT	\N	PRESENT	0
123387	122639	11034G	PARTICIPANT	\N	PRESENT	0
123388	122639	11098Y	PARTICIPANT	\N	PRESENT	0
123389	122639	14081Q	PARTICIPANT	\N	PRESENT	0
123390	122639	14269B	PARTICIPANT	\N	PRESENT	0
123391	122639	11104D	PARTICIPANT	\N	PRESENT	0
123392	122639	11099A	PARTICIPANT	\N	PRESENT	0
123393	122639	14030Q	PARTICIPANT	\N	PRESENT	0
123394	122639	04089T	PARTICIPANT	\N	PRESENT	0
123395	122639	01024M	PARTICIPANT	\N	PRESENT	0
123396	122639	14157T	PARTICIPANT	\N	PRESENT	0
123397	122639	14187A	PARTICIPANT	\N	PRESENT	0
123398	122639	14231L	PARTICIPANT	\N	PRESENT	0
123399	122639	14215L	PARTICIPANT	\N	PRESENT	0
123400	122639	08031R	PARTICIPANT	\N	PRESENT	0
123401	122639	14079W	PARTICIPANT	\N	PRESENT	0
123402	122639	11064N	PARTICIPANT	\N	PRESENT	0
123403	122639	11109J	PARTICIPANT	\N	PRESENT	0
123404	122639	14073Q	PARTICIPANT	\N	PRESENT	0
123405	122639	04033B	PARTICIPANT	\N	PRESENT	0
123406	122639	14253S	PARTICIPANT	\N	PRESENT	0
123407	122639	08039A	PARTICIPANT	\N	PRESENT	0
123408	122639	14042U	PARTICIPANT	\N	PRESENT	0
123409	122639	07032N	PARTICIPANT	\N	PRESENT	0
123410	122639	14217N	PARTICIPANT	\N	PRESENT	0
123411	122639	14195A	PARTICIPANT	\N	PRESENT	0
123412	122639	14097Y	PARTICIPANT	\N	PRESENT	0
123413	122639	14265W	PARTICIPANT	\N	PRESENT	0
123414	122639	11066Q	PARTICIPANT	\N	PRESENT	0
123415	122639	14281W	PARTICIPANT	\N	PRESENT	0
123416	122639	11100Y	PARTICIPANT	\N	PRESENT	0
123417	122639	11090Q	PARTICIPANT	\N	PRESENT	0
123418	122639	14213J	PARTICIPANT	\N	PRESENT	0
123419	122639	14135M	PARTICIPANT	\N	PRESENT	0
123420	122639	04038G	PARTICIPANT	\N	PRESENT	0
123421	122639	04045F	PARTICIPANT	\N	PRESENT	0
123422	122639	14014Q	PARTICIPANT	\N	PRESENT	0
123423	122639	08034U	PARTICIPANT	\N	PRESENT	0
123424	122639	05012A	PARTICIPANT	\N	PRESENT	0
123385	122639	80013X	PARTICIPANT	\N	PRESENT	0
123425	122639	14119M	PARTICIPANT	\N	PRESENT	0
123426	122639	11046L	PARTICIPANT	\N	PRESENT	0
123427	122639	10006L	PARTICIPANT	\N	PRESENT	0
123428	122639	08051V	PARTICIPANT	\N	PRESENT	0
93432	93431	14041T	PARTICIPANT	\N	PRESENT	0
93433	93431	04036E	PARTICIPANT	\N	PRESENT	0
93435	93434	95067Q	PARTICIPANT	\N	PRESENT	0
93436	93434	08053X	PARTICIPANT	\N	PRESENT	0
93437	93434	14253S	PARTICIPANT	\N	PRESENT	0
100838	100837	08034U	PARTICIPANT	\N	PRESENT	0
101610	101609	01031L	PRESIDENT	0	PRESENT	0
101611	101609	08014Q	PARTICIPANT	\N	PRESENT	0
101612	101609	14175V	PARTICIPANT	\N	PRESENT	0
101613	101609	14083S	PARTICIPANT	\N	PRESENT	0
101614	101609	11053K	PARTICIPANT	\N	PRESENT	0
101615	101609	11042G	PARTICIPANT	\N	PRESENT	0
101616	101609	04086Q	PARTICIPANT	\N	PRESENT	0
101617	101609	04055H	PARTICIPANT	\N	PRESENT	0
101618	101609	11088W	PARTICIPANT	\N	PRESENT	0
101620	101609	01027Q	PARTICIPANT	\N	PRESENT	0
101622	101609	11083R	PARTICIPANT	\N	PRESENT	0
101623	101609	01057W	PARTICIPANT	\N	PRESENT	0
101624	101609	08016S	PARTICIPANT	\N	PRESENT	0
101625	101609	99004R	PARTICIPANT	\N	PRESENT	0
101626	101609	14159V	PARTICIPANT	\N	PRESENT	0
101629	101609	07029T	PARTICIPANT	\N	PRESENT	0
101630	101609	98046X	PARTICIPANT	\N	PRESENT	0
101631	101609	08011M	PARTICIPANT	\N	PRESENT	0
101632	101609	08073C	PARTICIPANT	\N	PRESENT	0
101634	101609	08061X	PARTICIPANT	\N	PRESENT	0
101635	101609	01016M	PARTICIPANT	\N	PRESENT	0
101637	101609	14225N	PARTICIPANT	\N	PRESENT	0
101643	101609	14173T	PARTICIPANT	\N	PRESENT	0
101646	101609	04034C	PARTICIPANT	\N	PRESENT	0
101650	101609	08068F	PARTICIPANT	\N	PRESENT	0
101651	101609	14269B	PARTICIPANT	\N	PRESENT	0
101652	101609	98035U	PARTICIPANT	\N	PRESENT	0
101654	101609	04080J	PARTICIPANT	\N	PRESENT	0
101655	101609	95030B	PARTICIPANT	\N	PRESENT	0
101656	101609	04045F	PARTICIPANT	\N	PRESENT	0
101657	101609	96004D	PARTICIPANT	\N	PRESENT	0
101658	101609	08044W	PARTICIPANT	\N	PRESENT	0
101659	101609	14135M	PARTICIPANT	\N	PRESENT	0
101660	101609	14026U	PARTICIPANT	\N	PRESENT	0
101661	101609	95037J	PARTICIPANT	\N	PRESENT	0
101712	101609	89017R	PARTICIPANT	\N	EXCUSE	0
101713	101609	98053W	PARTICIPANT	\N	EXCUSE	0
101714	101609	11085T	PARTICIPANT	\N	EXCUSE	0
107236	107055	14071N	PARTICIPANT	\N	PRESENT	0
107237	107055	10006L	PARTICIPANT	\N	PRESENT	0
107238	107055	01044R	PARTICIPANT	\N	PRESENT	0
107239	107055	11061K	PARTICIPANT	\N	PRESENT	0
107240	107055	08038Y	PARTICIPANT	\N	PRESENT	0
107241	107055	04085P	PARTICIPANT	\N	PRESENT	0
107242	107055	04067M	PARTICIPANT	\N	PRESENT	0
107252	107055	14147R	PARTICIPANT	\N	PRESENT	0
107253	107055	04049K	PARTICIPANT	\N	PRESENT	0
107254	107055	95030B	PARTICIPANT	\N	PRESENT	0
107255	107055	05012A	PARTICIPANT	\N	PRESENT	0
107272	107055	11064N	PARTICIPANT	\N	PRESENT	0
107273	107055	95041E	PARTICIPANT	\N	PRESENT	0
107274	107055	14255U	PARTICIPANT	\N	PRESENT	0
107275	107055	11099A	PARTICIPANT	\N	PRESENT	0
109092	107312	01007L	PARTICIPANT	\N	PRESENT	0
109097	107312	11063M	PARTICIPANT	\N	PRESENT	0
109098	107312	11031D	PARTICIPANT	\N	PRESENT	0
109099	107312	01059Y	PARTICIPANT	\N	PRESENT	0
109100	107312	11098Y	PARTICIPANT	\N	PRESENT	0
109101	107312	11040E	PARTICIPANT	\N	PRESENT	0
109102	107312	14235Q	PARTICIPANT	\N	PRESENT	0
109103	107312	14121F	PARTICIPANT	\N	PRESENT	0
109104	107312	08052W	PARTICIPANT	\N	PRESENT	0
109105	107312	11067R	PARTICIPANT	\N	PRESENT	0
109106	107312	11066Q	PARTICIPANT	\N	PRESENT	0
109107	107312	14151M	PARTICIPANT	\N	PRESENT	0
109108	107312	80013X	PARTICIPANT	\N	PRESENT	0
109109	107312	11105E	PARTICIPANT	\N	PRESENT	0
109110	107312	08068F	PARTICIPANT	\N	PRESENT	0
109111	107312	14257W	PARTICIPANT	\N	PRESENT	0
109112	107312	95015C	PARTICIPANT	\N	PRESENT	0
109113	107312	12042Y	PARTICIPANT	\N	PRESENT	0
109114	107312	98018T	PARTICIPANT	\N	PRESENT	0
109115	107312	14223L	PARTICIPANT	\N	PRESENT	0
109116	107312	04092N	PARTICIPANT	\N	PRESENT	0
109117	107312	14034U	PARTICIPANT	\N	PRESENT	0
109118	107312	01048V	PARTICIPANT	\N	PRESENT	0
109119	107312	11103C	PARTICIPANT	\N	PRESENT	0
109120	107312	14030Q	PARTICIPANT	\N	PRESENT	0
109121	107312	98050T	PARTICIPANT	\N	PRESENT	0
109122	107312	14042U	PARTICIPANT	\N	PRESENT	0
109123	107312	14105F	PARTICIPANT	\N	PRESENT	0
109124	107312	11093T	PARTICIPANT	\N	PRESENT	0
109125	107312	14026U	PARTICIPANT	\N	PRESENT	0
109126	107312	01034P	PARTICIPANT	\N	PRESENT	0
109127	107312	04053F	PARTICIPANT	\N	PRESENT	0
109128	107312	08031R	PARTICIPANT	\N	PRESENT	0
109129	107312	14061L	PARTICIPANT	\N	PRESENT	0
109130	107312	14273W	PARTICIPANT	\N	PRESENT	0
109135	107312	14227Q	PARTICIPANT	\N	PRESENT	0
109136	107312	11083R	PARTICIPANT	\N	PRESENT	0
109133	107312	14071N	PARTICIPANT	\N	PRESENT	0
109134	107312	11112D	PARTICIPANT	\N	PRESENT	0
109137	107312	01044R	PARTICIPANT	\N	PRESENT	0
109138	107312	14271U	PARTICIPANT	\N	PRESENT	0
109139	107312	11061K	PARTICIPANT	\N	PRESENT	0
109140	107312	11104D	PARTICIPANT	\N	PRESENT	0
109141	107312	14267Y	PARTICIPANT	\N	PRESENT	0
109142	107312	14018U	PARTICIPANT	\N	PRESENT	0
109143	107312	11042G	PARTICIPANT	\N	PRESENT	0
109144	107312	14037X	PARTICIPANT	\N	PRESENT	0
109145	107312	14199E	PARTICIPANT	\N	PRESENT	0
109146	107312	01056V	PARTICIPANT	\N	PRESENT	0
109147	107312	87003B	PARTICIPANT	\N	PRESENT	0
109148	107312	14083S	PARTICIPANT	\N	PRESENT	0
109149	107312	04067M	PARTICIPANT	\N	PRESENT	0
109150	107312	14197C	PARTICIPANT	\N	PRESENT	0
109151	107312	01031L	PARTICIPANT	\N	PRESENT	0
109152	107312	11107G	PARTICIPANT	\N	PRESENT	0
109153	107312	07026Q	PARTICIPANT	\N	PRESENT	0
109154	107312	14215L	PARTICIPANT	\N	PRESENT	0
109155	107312	11091R	PARTICIPANT	\N	PRESENT	0
109156	107312	07032N	PARTICIPANT	\N	PRESENT	0
109160	107312	08069G	PARTICIPANT	\N	PRESENT	0
109162	107312	14179A	PARTICIPANT	\N	PRESENT	0
109164	107312	08016S	PARTICIPANT	\N	PRESENT	0
109167	107312	14219Q	PARTICIPANT	\N	PRESENT	0
109170	107312	11014C	PARTICIPANT	\N	PRESENT	0
109179	107312	14157T	PARTICIPANT	\N	PRESENT	0
109180	107312	14119M	PARTICIPANT	\N	PRESENT	0
109181	107312	14231L	PARTICIPANT	\N	PRESENT	0
109182	107312	11036J	PARTICIPANT	\N	PRESENT	0
109183	107312	04085P	PARTICIPANT	\N	PRESENT	0
109184	107312	01024M	PARTICIPANT	\N	PRESENT	0
109186	107312	14221J	PARTICIPANT	\N	PRESENT	0
109187	107312	01022K	PARTICIPANT	\N	PRESENT	0
109188	107312	08051V	PARTICIPANT	\N	PRESENT	0
109191	107312	01028R	PARTICIPANT	\N	PRESENT	0
109192	107312	14073Q	PARTICIPANT	\N	PRESENT	0
109195	107312	92045V	PARTICIPANT	\N	PRESENT	0
109196	107312	86044G	PARTICIPANT	\N	PRESENT	0
109197	107312	99004R	PARTICIPANT	\N	PRESENT	0
109198	107312	04043D	PARTICIPANT	\N	PRESENT	0
109199	107312	14041T	PARTICIPANT	\N	PRESENT	0
109200	107312	04049K	PARTICIPANT	\N	PRESENT	0
109212	107312	14087W	PARTICIPANT	\N	PRESENT	0
109213	107312	14269B	PARTICIPANT	\N	PRESENT	0
109214	107312	14089Y	PARTICIPANT	\N	PRESENT	0
109215	107312	14175V	PARTICIPANT	\N	PRESENT	0
109216	107312	04071H	PARTICIPANT	\N	PRESENT	0
110293	110292	02002K	PARTICIPANT	\N	PRESENT	0
110294	110292	14031R	PARTICIPANT	\N	PRESENT	0
110295	110292	14221J	PARTICIPANT	\N	PRESENT	0
110296	110292	14237S	PARTICIPANT	\N	PRESENT	0
110297	110292	13002U	PARTICIPANT	\N	PRESENT	0
110298	110292	05012A	PARTICIPANT	\N	PRESENT	0
110299	110292	14051J	PARTICIPANT	\N	PRESENT	0
110300	110292	14157T	PARTICIPANT	\N	PRESENT	0
110302	110301	05012A	PARTICIPANT	\N	PRESENT	0
110304	110303	11112D	PARTICIPANT	\N	PRESENT	0
110305	110303	14205J	PARTICIPANT	\N	PRESENT	0
110306	110303	04057K	PARTICIPANT	\N	PRESENT	0
110307	110303	08042U	PARTICIPANT	\N	PRESENT	0
110316	110315	05008E	PRESIDENT	0	PRESENT	0
110317	110315	11033F	PARTICIPANT	\N	PRESENT	0
110318	110315	04047H	PARTICIPANT	\N	PRESENT	0
110319	110315	04038G	PARTICIPANT	\N	PRESENT	0
110320	110315	14041T	PARTICIPANT	\N	PRESENT	0
110321	110315	01007L	PARTICIPANT	\N	PRESENT	0
110322	110315	11026G	PARTICIPANT	\N	PRESENT	0
110323	110315	14273W	PARTICIPANT	\N	PRESENT	0
110324	110315	11072N	PARTICIPANT	\N	PRESENT	0
110325	110315	07034Q	PARTICIPANT	\N	PRESENT	0
110326	110315	95063L	PARTICIPANT	\N	PRESENT	0
110327	110315	01028R	PARTICIPANT	\N	PRESENT	0
110328	110315	98035U	PARTICIPANT	\N	PRESENT	0
110329	110315	04056J	PARTICIPANT	\N	PRESENT	0
110330	110315	11037K	PARTICIPANT	\N	PRESENT	0
110331	110315	14275Y	PARTICIPANT	\N	EXCUSE	0
110332	110315	14111D	PARTICIPANT	\N	PRESENT	0
113834	113832	04054G	PARTICIPANT	\N	PRESENT	0
113835	113832	14037X	PARTICIPANT	\N	PRESENT	0
113893	113832	04070G	PARTICIPANT	\N	PRESENT	0
113894	113832	14071N	PARTICIPANT	\N	PRESENT	0
113953	113952	95030B	PARTICIPANT	\N	PRESENT	0
113954	113952	14001X	PARTICIPANT	\N	PRESENT	0
118192	118189	11039M	PARTICIPANT	\N	PRESENT	0
118193	118189	98042T	PARTICIPANT	\N	PRESENT	0
118194	118189	01019Q	PARTICIPANT	\N	PRESENT	0
118273	118272	11036J	PARTICIPANT	\N	PRESENT	0
118274	118272	14030Q	PARTICIPANT	\N	PRESENT	0
118275	118272	01044R	PARTICIPANT	\N	PRESENT	0
118276	118272	11029K	PARTICIPANT	\N	PRESENT	0
118277	118272	14197C	PARTICIPANT	\N	PRESENT	0
118278	118272	14219Q	PRESIDENT	0	PRESENT	0
118279	118272	14031R	PARTICIPANT	\N	PRESENT	0
118280	118272	14237S	PARTICIPANT	\N	PRESENT	0
118281	118272	14107H	PARTICIPANT	\N	PRESENT	0
118282	118272	14093U	PARTICIPANT	\N	EXCUSE	0
118283	118272	80013X	PARTICIPANT	\N	EXCUSE	0
118284	118272	04057K	PARTICIPANT	\N	EXCUSE	0
118285	118272	92039X	PARTICIPANT	\N	EXCUSE	0
118286	118272	14265W	PARTICIPANT	\N	EXCUSE	0
118287	118272	05012A	PARTICIPANT	\N	EXCUSE	0
118288	118272	08049C	PARTICIPANT	\N	EXCUSE	0
118290	118289	11036J	PARTICIPANT	\N	PRESENT	0
118291	118289	14030Q	PARTICIPANT	\N	PRESENT	0
118292	118289	01044R	PARTICIPANT	\N	PRESENT	0
118293	118289	01015L	PARTICIPANT	\N	PRESENT	0
118294	118289	14197C	PARTICIPANT	\N	PRESENT	0
118295	118289	14219Q	PARTICIPANT	\N	PRESENT	0
118297	118296	14261S	PARTICIPANT	\N	PRESENT	0
118298	118296	08055A	PARTICIPANT	\N	PRESENT	0
118299	118296	14030Q	PARTICIPANT	\N	PRESENT	0
118300	118296	08060W	PARTICIPANT	\N	PRESENT	0
118301	118296	11095V	PARTICIPANT	\N	PRESENT	0
118302	118296	14038Y	PARTICIPANT	\N	PRESENT	0
118303	118296	11114F	PARTICIPANT	\N	PRESENT	0
118304	118296	11107G	PARTICIPANT	\N	PRESENT	0
118305	118296	01022K	PARTICIPANT	\N	PRESENT	0
118306	118296	04097T	PARTICIPANT	\N	PRESENT	0
118307	118296	14219Q	PARTICIPANT	\N	PRESENT	0
118308	118296	80027E	PARTICIPANT	\N	PRESENT	0
118309	118296	14031R	PARTICIPANT	\N	PRESENT	0
118310	118296	08009T	PRESIDENT	0	PRESENT	0
118311	118296	08062Y	PARTICIPANT	\N	PRESENT	0
118312	118296	14169X	PARTICIPANT	\N	PRESENT	0
118313	118296	14237S	PARTICIPANT	\N	PRESENT	0
118314	118296	13002U	PARTICIPANT	\N	PRESENT	0
118315	118296	05012A	PARTICIPANT	\N	PRESENT	0
118316	118296	14135M	PARTICIPANT	\N	PRESENT	0
118317	118296	14331P	PARTICIPANT	\N	PRESENT	0
118318	118296	95062K	PARTICIPANT	\N	PRESENT	0
118319	118296	14107H	PARTICIPANT	\N	PRESENT	0
118320	118296	14051J	PARTICIPANT	\N	PRESENT	0
118321	118296	14157T	PARTICIPANT	\N	PRESENT	0
118322	118296	11059R	PARTICIPANT	\N	EXCUSE	0
118323	118296	96003C	PARTICIPANT	\N	EXCUSE	0
118324	118296	09001P	PARTICIPANT	\N	EXCUSE	0
118325	118296	08028W	PARTICIPANT	\N	PRESENT	0
118326	118296	95067Q	PARTICIPANT	\N	PRESENT	0
118327	118296	90003B	PARTICIPANT	\N	PRESENT	0
118332	118296	14249W	PARTICIPANT	\N	PRESENT	0
118329	118296	01008M	PARTICIPANT	\N	PRESENT	0
118331	118296	11097X	PARTICIPANT	\N	PRESENT	0
118333	118296	14073Q	PARTICIPANT	\N	PRESENT	0
118339	118296	14217N	PARTICIPANT	\N	PRESENT	0
118336	118296	14083S	PARTICIPANT	\N	PRESENT	0
118337	118296	01057W	PARTICIPANT	\N	PRESENT	0
118345	118344	11055M	PARTICIPANT	\N	PRESENT	0
118346	118344	08043V	PARTICIPANT	\N	PRESENT	0
118347	118344	95015C	PARTICIPANT	\N	PRESENT	0
118349	118344	08024S	PARTICIPANT	\N	PRESENT	0
118350	118344	11027H	PARTICIPANT	\N	PRESENT	0
118351	118344	04086Q	PARTICIPANT	\N	PRESENT	0
118354	118344	14079W	PARTICIPANT	\N	PRESENT	0
118355	118344	14215L	PARTICIPANT	\N	PRESENT	0
118356	118344	04089T	PARTICIPANT	\N	PRESENT	0
118357	118344	14187A	PARTICIPANT	\N	PRESENT	0
118358	118344	14231L	PARTICIPANT	\N	PRESENT	0
118359	118344	08031R	PARTICIPANT	\N	PRESENT	0
118360	118344	11100Y	PRESIDENT	0	PRESENT	0
118361	118344	11104D	PARTICIPANT	\N	PRESENT	0
118362	118344	08051V	PARTICIPANT	\N	PRESENT	0
118363	118344	11090Q	PARTICIPANT	\N	PRESENT	0
118364	118344	14235Q	PARTICIPANT	\N	PRESENT	0
118365	118344	95063L	PARTICIPANT	\N	PRESENT	0
118366	118344	11046L	PARTICIPANT	\N	PRESENT	0
118367	118344	01028R	PARTICIPANT	\N	PRESENT	0
118368	118344	11094U	PARTICIPANT	\N	PRESENT	0
118369	118344	11037K	PARTICIPANT	\N	PRESENT	0
118370	118344	14157T	PARTICIPANT	\N	PRESENT	0
118371	118344	11066Q	PARTICIPANT	\N	PRESENT	0
118372	118344	14269B	PARTICIPANT	\N	PRESENT	0
118379	118378	11055M	PARTICIPANT	\N	PRESENT	0
118380	118378	08043V	PARTICIPANT	\N	PRESENT	0
118381	118378	95015C	PARTICIPANT	\N	PRESENT	0
118382	118378	08024S	PARTICIPANT	\N	PRESENT	0
118383	118378	11027H	PARTICIPANT	\N	PRESENT	0
118384	118378	04086Q	PARTICIPANT	\N	PRESENT	0
118385	118378	14079W	PARTICIPANT	\N	PRESENT	0
118386	118378	14215L	PARTICIPANT	\N	PRESENT	0
118387	118378	14187A	PARTICIPANT	\N	PRESENT	0
118388	118378	14231L	PARTICIPANT	\N	PRESENT	0
118389	118378	14213J	PARTICIPANT	\N	PRESENT	0
118393	118378	08031R	PARTICIPANT	\N	PRESENT	0
118395	118378	11100Y	PRESIDENT	0	PRESENT	0
118396	118378	11104D	PARTICIPANT	\N	PRESENT	0
118398	118378	07032N	PARTICIPANT	\N	PRESENT	0
118399	118378	92045V	PARTICIPANT	\N	PRESENT	0
118400	118378	11094U	PARTICIPANT	\N	PRESENT	0
118402	118378	14157T	PARTICIPANT	\N	PRESENT	0
118404	118378	11066Q	PARTICIPANT	\N	PRESENT	0
118405	118378	14269B	PARTICIPANT	\N	PRESENT	0
118411	118378	11067R	PARTICIPANT	\N	PRESENT	0
118413	118412	01034P	PARTICIPANT	\N	PRESENT	0
118414	118412	83047W	PARTICIPANT	\N	PRESENT	0
118415	118412	11048N	PARTICIPANT	\N	PRESENT	0
118416	118412	11095V	PARTICIPANT	\N	PRESENT	0
118418	118417	04085P	PARTICIPANT	\N	PRESENT	0
118419	118417	05008E	PRESIDENT	0	PRESENT	0
118420	118417	04047H	PARTICIPANT	\N	PRESENT	0
118421	118417	11032E	PARTICIPANT	\N	PRESENT	0
118422	118417	14259Y	PARTICIPANT	\N	PRESENT	0
118423	118417	14041T	PARTICIPANT	\N	PRESENT	0
118424	118417	11113E	PARTICIPANT	\N	PRESENT	0
118425	118417	01024M	PARTICIPANT	\N	EXCUSE	0
118426	118417	14215L	PARTICIPANT	\N	PRESENT	0
118427	118417	11034G	PARTICIPANT	\N	PRESENT	0
118428	118417	08018U	PARTICIPANT	\N	PRESENT	0
118429	118417	01007L	PARTICIPANT	\N	PRESENT	0
118430	118417	11049P	PARTICIPANT	\N	PRESENT	0
118431	118417	11026G	PARTICIPANT	\N	PRESENT	0
118432	118417	04079R	PARTICIPANT	\N	PRESENT	0
118433	118417	14111D	PARTICIPANT	\N	PRESENT	0
99420	99419	04054G	PARTICIPANT	\N	PRESENT	0
98754	98752	08055A	PARTICIPANT	\N	PRESENT	0
98755	98752	14093U	PARTICIPANT	\N	PRESENT	0
98756	98752	14030Q	PARTICIPANT	\N	PRESENT	0
98757	98752	96004D	PARTICIPANT	\N	PRESENT	0
98758	98752	08060W	PARTICIPANT	\N	PRESENT	0
98759	98752	11095V	PARTICIPANT	\N	PRESENT	0
98760	98752	14038Y	PARTICIPANT	\N	PRESENT	0
98761	98752	11114F	PARTICIPANT	\N	PRESENT	0
98762	98752	98023Q	PARTICIPANT	\N	PRESENT	0
98763	98752	11065P	PARTICIPANT	\N	PRESENT	0
98764	98752	01015L	PARTICIPANT	\N	PRESENT	0
98765	98752	11107G	PARTICIPANT	\N	PRESENT	0
98766	98752	11020A	PARTICIPANT	\N	PRESENT	0
98767	98752	02002K	PARTICIPANT	\N	EXCUSE	0
98768	98752	01022K	PARTICIPANT	\N	PRESENT	0
98769	98752	04097T	PARTICIPANT	\N	PRESENT	0
98770	98752	09001P	PARTICIPANT	\N	PRESENT	0
98771	98752	11059R	PARTICIPANT	\N	PRESENT	0
98772	98752	14219Q	PARTICIPANT	\N	PRESENT	0
98773	98752	80027E	PARTICIPANT	\N	PRESENT	0
98774	98752	14031R	PARTICIPANT	\N	PRESENT	0
99421	99419	14089Y	PARTICIPANT	\N	PRESENT	0
98776	98752	08062Y	PARTICIPANT	\N	PRESENT	0
98777	98752	14221J	PARTICIPANT	\N	PRESENT	0
99422	99419	04047H	PARTICIPANT	\N	EXCUSE	0
99423	99419	14079W	PARTICIPANT	\N	PRESENT	0
98780	98752	14169X	PARTICIPANT	\N	PRESENT	0
98781	98752	14237S	PARTICIPANT	\N	PRESENT	0
98782	98752	13002U	PARTICIPANT	\N	PRESENT	0
98783	98752	05012A	PRESIDENT	0	PRESENT	0
98784	98752	14247U	PARTICIPANT	\N	PRESENT	0
98785	98752	14135M	PARTICIPANT	\N	PRESENT	0
98786	98752	14331P	PARTICIPANT	\N	PRESENT	0
98787	98752	95062K	PARTICIPANT	\N	PRESENT	0
98788	98752	14107H	PARTICIPANT	\N	PRESENT	0
99424	99419	14041T	PARTICIPANT	\N	EXCUSE	0
98790	98752	14157T	PARTICIPANT	\N	PRESENT	0
98791	98752	96003C	PARTICIPANT	\N	EXCUSE	0
99425	99419	11015D	PARTICIPANT	\N	PRESENT	0
99426	99419	95037J	PARTICIPANT	\N	PRESENT	0
99427	99419	14097Y	PARTICIPANT	\N	PRESENT	0
99428	99419	11084S	PARTICIPANT	\N	PRESENT	0
99429	99419	11026G	PARTICIPANT	\N	PRESENT	0
99430	99419	92031P	PRESIDENT	0	PRESENT	0
99431	99419	14001X	PARTICIPANT	\N	PRESENT	0
99432	99419	08053X	PARTICIPANT	\N	PRESENT	0
99433	99419	08021P	PARTICIPANT	\N	EXCUSE	0
99434	99419	14237S	PARTICIPANT	\N	PRESENT	0
99435	99419	14331P	PARTICIPANT	\N	PRESENT	0
99436	99419	95067Q	PARTICIPANT	\N	PRESENT	0
99652	98793	08051V	PARTICIPANT	\N	PRESENT	0
99653	98793	11029K	PARTICIPANT	\N	PRESENT	0
99654	98793	08022Q	PARTICIPANT	\N	PRESENT	0
99655	98793	14083S	PARTICIPANT	\N	PRESENT	0
99656	98793	11056N	PARTICIPANT	\N	PRESENT	0
99657	98793	95063L	PARTICIPANT	\N	PRESENT	0
99658	98793	08031R	PARTICIPANT	\N	PRESENT	0
99663	98793	14265W	PARTICIPANT	\N	PRESENT	0
99664	98793	04081K	PARTICIPANT	\N	PRESENT	0
99665	98793	14089Y	PARTICIPANT	\N	PRESENT	0
99671	98793	11103C	PARTICIPANT	\N	PRESENT	0
99672	98793	98050T	PARTICIPANT	\N	PRESENT	0
99673	98793	14135M	PARTICIPANT	\N	PRESENT	0
99674	98793	14073Q	PARTICIPANT	\N	PRESENT	0
99676	98793	01003G	PARTICIPANT	\N	PRESENT	0
99693	98793	01031L	PARTICIPANT	\N	PRESENT	0
99694	98793	11025F	PARTICIPANT	\N	PRESENT	0
99695	98793	11083R	PARTICIPANT	\N	PRESENT	0
99696	98793	11036J	PARTICIPANT	\N	PRESENT	0
99712	98793	80013X	PARTICIPANT	\N	PRESENT	0
99713	98793	07034Q	PARTICIPANT	\N	PRESENT	0
99714	98793	14030Q	PARTICIPANT	\N	PRESENT	0
99715	98793	98035U	PARTICIPANT	\N	PRESENT	0
99716	98793	14121F	PARTICIPANT	\N	PRESENT	0
99740	98793	14217N	PARTICIPANT	\N	PRESENT	0
99772	98793	14105F	PARTICIPANT	\N	PRESENT	0
99773	98793	14109K	PARTICIPANT	\N	PRESENT	0
99774	98793	98046X	PARTICIPANT	\N	PRESENT	0
99775	98793	01016M	PARTICIPANT	\N	PRESENT	0
99776	98793	11067R	PARTICIPANT	\N	PRESENT	0
99807	98793	11012A	PARTICIPANT	\N	PRESENT	0
99810	98793	14257W	PARTICIPANT	\N	PRESENT	0
99811	98793	92039X	PARTICIPANT	\N	PRESENT	0
99812	98793	01048V	PARTICIPANT	\N	PRESENT	0
99813	98793	14133K	PARTICIPANT	\N	PRESENT	0
99832	98793	14237S	PARTICIPANT	\N	PRESENT	0
99833	98793	14259Y	PARTICIPANT	\N	PRESENT	0
99847	98793	14211G	PARTICIPANT	\N	PRESENT	0
99848	98793	08069G	PARTICIPANT	\N	PRESENT	0
99849	98793	14038Y	PARTICIPANT	\N	PRESENT	0
99850	98793	99004R	PARTICIPANT	\N	PRESENT	0
99852	98793	14195A	PARTICIPANT	\N	PRESENT	0
99853	98793	04070G	PARTICIPANT	\N	PRESENT	0
99854	98793	08043V	PARTICIPANT	\N	PRESENT	0
99872	98793	04047H	PARTICIPANT	\N	PRESENT	0
99873	98793	14147R	PARTICIPANT	\N	PRESENT	0
99874	98793	14179A	PARTICIPANT	\N	PRESENT	0
100015	98794	01024M	PARTICIPANT	\N	PRESENT	0
100017	98794	07034Q	PARTICIPANT	\N	PRESENT	0
100018	98794	04047H	PARTICIPANT	\N	PRESENT	0
100019	98794	04036E	PARTICIPANT	\N	PRESENT	0
100020	98794	14013P	PARTICIPANT	\N	PRESENT	0
100021	98794	08051V	PARTICIPANT	\N	PRESENT	0
100022	98794	01028R	PARTICIPANT	\N	PRESENT	0
100023	98794	11067R	PARTICIPANT	\N	PRESENT	0
100024	98794	14109K	PARTICIPANT	\N	PRESENT	0
100025	98794	08010L	PARTICIPANT	\N	PRESENT	0
100026	98794	11056N	PARTICIPANT	\N	PRESENT	0
100027	98794	08069G	PARTICIPANT	\N	PRESENT	0
100032	98794	11033F	PARTICIPANT	\N	PRESENT	0
100078	98794	14271U	PARTICIPANT	\N	PRESENT	0
100079	98794	08034U	PARTICIPANT	\N	PRESENT	0
100081	98794	11025F	PARTICIPANT	\N	PRESENT	0
100953	100952	14133K	PARTICIPANT	\N	PRESENT	0
100954	100952	96004D	PARTICIPANT	\N	PRESENT	0
100012	98794	04081K	PARTICIPANT	\N	PRESENT	0
100013	98794	14219Q	PARTICIPANT	\N	PRESENT	0
100955	100952	04055H	PARTICIPANT	\N	PRESENT	0
100956	100952	08018U	PARTICIPANT	\N	PRESENT	0
100957	100952	14175V	PARTICIPANT	\N	PRESENT	0
100958	100952	95030B	PARTICIPANT	\N	PRESENT	0
100959	100952	02002K	PARTICIPANT	\N	PRESENT	0
100960	100952	98035U	PARTICIPANT	\N	PRESENT	0
100961	100952	04080J	PARTICIPANT	\N	PRESENT	0
100962	100952	08051V	PARTICIPANT	\N	PRESENT	0
100963	100952	92031P	PARTICIPANT	\N	PRESENT	0
100964	100952	11026G	PARTICIPANT	\N	PRESENT	0
100965	100952	04097T	PARTICIPANT	\N	PRESENT	0
100966	100952	01048V	PARTICIPANT	\N	PRESENT	0
100974	100972	11055M	PARTICIPANT	\N	PRESENT	0
100975	100972	01046T	PARTICIPANT	\N	PRESENT	0
100976	100972	04053F	PARTICIPANT	\N	PRESENT	0
100978	100972	04066L	PARTICIPANT	\N	PRESENT	0
100980	100972	14053L	PARTICIPANT	\N	EXCUSE	0
100981	100972	11103C	PARTICIPANT	\N	PRESENT	0
100982	100972	11044J	PARTICIPANT	\N	PRESENT	0
100983	100972	14195A	PARTICIPANT	\N	PRESENT	0
100984	100972	14267Y	PARTICIPANT	\N	PRESENT	0
100986	100972	11031D	PARTICIPANT	\N	PRESENT	0
100987	100972	08052W	PARTICIPANT	\N	PRESENT	0
100989	100972	04081K	PARTICIPANT	\N	PRESENT	0
100990	100972	98024R	PARTICIPANT	\N	PRESENT	0
100991	100972	10006L	PARTICIPANT	\N	PRESENT	0
100993	100972	14217N	PARTICIPANT	\N	PRESENT	0
100994	100972	14042U	PARTICIPANT	\N	PRESENT	0
100995	100972	14151M	PARTICIPANT	\N	PRESENT	0
100996	100972	12042Y	PARTICIPANT	\N	PRESENT	0
101001	100972	14231L	PARTICIPANT	\N	PRESENT	0
101002	100972	11061K	PARTICIPANT	\N	PRESENT	0
101003	100972	08048B	PARTICIPANT	\N	PRESENT	0
101004	100972	08041T	PARTICIPANT	\N	PRESENT	0
101005	100972	01011G	PARTICIPANT	\N	PRESENT	0
101006	100972	14026U	PARTICIPANT	\N	PRESENT	0
101007	100972	14213J	PARTICIPANT	\N	PRESENT	0
101008	100972	14121F	PARTICIPANT	\N	PRESENT	0
101009	100972	11112D	PARTICIPANT	\N	PRESENT	0
101011	100972	14018U	PARTICIPANT	\N	PRESENT	0
110111	110110	14187A	PARTICIPANT	\N	PRESENT	0
110127	110125	08022Q	PARTICIPANT	\N	PRESENT	0
110128	110125	01016M	PARTICIPANT	\N	PRESENT	0
118813	118812	14227Q	PARTICIPANT	\N	PRESENT	0
118933	118932	11057P	PARTICIPANT	\N	PRESENT	0
118935	118934	11057P	PARTICIPANT	\N	PRESENT	0
118937	118936	04071H	PARTICIPANT	\N	PRESENT	0
118939	118938	08061X	PARTICIPANT	\N	PRESENT	0
118942	118941	08034U	PARTICIPANT	\N	PRESENT	0
118943	118941	01031L	PARTICIPANT	\N	PRESENT	0
120195	120186	11076S	PARTICIPANT	\N	PRESENT	0
121731	121730	14001X	PARTICIPANT	\N	PRESENT	0
120197	120186	04040A	PARTICIPANT	\N	EXCUSE	0
120198	120186	08058D	PARTICIPANT	\N	PRESENT	0
120199	120186	04042C	PARTICIPANT	\N	PRESENT	0
121732	121730	98035U	PARTICIPANT	\N	PRESENT	0
120201	120186	98029W	PARTICIPANT	\N	PRESENT	0
121735	121734	14253S	PARTICIPANT	\N	PRESENT	0
120203	120186	11027H	PARTICIPANT	\N	PRESENT	0
120204	120186	98018T	PARTICIPANT	\N	PRESENT	0
121736	121734	14157T	PARTICIPANT	\N	PRESENT	0
120206	120186	92020L	PARTICIPANT	\N	PRESENT	0
120207	120186	95030B	PARTICIPANT	\N	PRESENT	0
121737	120874	14263U	PARTICIPANT	\N	EXCUSE	0
120209	120186	95031C	PARTICIPANT	\N	PRESENT	0
120210	120186	97011G	PARTICIPANT	\N	PRESENT	0
120211	120186	08065C	PARTICIPANT	\N	EXCUSE	0
120212	120186	04035D	PARTICIPANT	\N	PRESENT	0
120213	120186	07024N	PARTICIPANT	\N	PRESENT	0
121738	120874	08069G	PARTICIPANT	\N	EXCUSE	0
120215	120186	14014Q	PARTICIPANT	\N	PRESENT	0
120216	120186	11015D	PARTICIPANT	\N	PRESENT	0
120217	120186	07004J	PARTICIPANT	\N	EXCUSE	0
120218	120186	95035G	PARTICIPANT	\N	EXCUSE	0
121740	121739	14253S	PARTICIPANT	\N	PRESENT	0
121741	121739	14157T	PARTICIPANT	\N	PRESENT	0
120221	120186	98022P	PARTICIPANT	\N	PRESENT	0
121743	121742	11100Y	PARTICIPANT	\N	PRESENT	0
120223	120186	95037J	PARTICIPANT	\N	PRESENT	0
120224	120186	04078Q	PARTICIPANT	\N	PRESENT	0
120225	120186	14097Y	PARTICIPANT	\N	PRESENT	0
120226	120186	95041E	PARTICIPANT	\N	PRESENT	0
121745	121744	14253S	PARTICIPANT	\N	PRESENT	0
121746	121744	14157T	PARTICIPANT	\N	PRESENT	0
121971	121970	14255U	PARTICIPANT	\N	PRESENT	0
121972	121970	04086Q	PARTICIPANT	\N	PRESENT	0
120231	120186	92031P	PARTICIPANT	\N	PRESENT	0
120232	120186	11106F	PARTICIPANT	\N	PRESENT	0
120233	120186	14251Q	PARTICIPANT	\N	PRESENT	0
120234	120186	83042R	PARTICIPANT	\N	PRESENT	0
120235	120186	08053X	PARTICIPANT	\N	PRESENT	0
120236	120186	11082Q	PARTICIPANT	\N	PRESENT	0
121973	121970	04067M	PARTICIPANT	\N	PRESENT	0
120238	120186	14253S	PARTICIPANT	\N	PRESENT	0
121974	121970	12042Y	PRESIDENT	0	PRESENT	0
120240	120186	14028W	PARTICIPANT	\N	EXCUSE	0
120241	120186	14193X	PARTICIPANT	\N	PRESENT	0
120242	120186	98021N	PARTICIPANT	\N	PRESENT	0
120243	120186	04080J	PARTICIPANT	\N	PRESENT	0
120244	120186	95059Q	PRESIDENT	0	PRESENT	0
120245	120186	86044G	PARTICIPANT	\N	PRESENT	0
121975	121970	11107G	PARTICIPANT	\N	PRESENT	0
120247	120186	11054L	PARTICIPANT	\N	PRESENT	0
121976	121970	14037X	PARTICIPANT	\N	PRESENT	0
121977	121970	11100Y	PARTICIPANT	\N	PRESENT	0
120250	120186	08049C	PARTICIPANT	\N	PRESENT	0
121978	121970	04045F	PARTICIPANT	\N	PRESENT	0
121979	121970	04050C	PARTICIPANT	\N	PRESENT	0
121980	121970	14135M	PARTICIPANT	\N	EXCUSE	0
121982	121970	01027Q	PARTICIPANT	\N	EXCUSE	0
121983	121970	14014Q	PARTICIPANT	\N	EXCUSE	0
121984	121970	11112D	PARTICIPANT	\N	EXCUSE	0
121985	121970	14026U	PARTICIPANT	\N	EXCUSE	0
121987	121970	04049K	PARTICIPANT	\N	EXCUSE	0
123677	121161	11035H	PARTICIPANT	\N	PRESENT	0
123678	121161	14231L	PARTICIPANT	\N	PRESENT	0
123679	121161	01057W	PARTICIPANT	\N	PRESENT	0
123680	121161	08034U	PARTICIPANT	\N	PRESENT	0
123681	121161	11098Y	PARTICIPANT	\N	PRESENT	0
123682	121161	14063N	PARTICIPANT	\N	PRESENT	0
123683	121161	08051V	PARTICIPANT	\N	PRESENT	0
123684	121161	14028W	PARTICIPANT	\N	PRESENT	0
123685	121161	07032N	PARTICIPANT	\N	PRESENT	0
123686	121161	05012A	PARTICIPANT	\N	PRESENT	0
123687	121161	14051J	PARTICIPANT	\N	PRESENT	0
123688	121161	11037K	PARTICIPANT	\N	PRESENT	0
123711	119923	11093T	PARTICIPANT	\N	PRESENT	0
123712	119923	11044J	PARTICIPANT	\N	PRESENT	0
123713	119923	08052W	PARTICIPANT	\N	PRESENT	0
123762	123761	08052W	PARTICIPANT	\N	PRESENT	0
123763	123761	01034P	PARTICIPANT	\N	PRESENT	0
123764	123761	11093T	PARTICIPANT	\N	PRESENT	0
123770	123769	01034P	PARTICIPANT	\N	PRESENT	0
123772	123771	01034P	PARTICIPANT	\N	PRESENT	0
124016	124015	14263U	PARTICIPANT	\N	PRESENT	0
124215	120697	14093U	PARTICIPANT	\N	EXCUSE	0
124253	120699	14275Y	PARTICIPANT	\N	EXCUSE	0
125464	125334	14107H	PARTICIPANT	\N	PRESENT	0
125465	125334	14281W	PARTICIPANT	\N	PRESENT	0
125466	125334	11056N	PARTICIPANT	\N	PRESENT	0
125468	125467	01034P	PARTICIPANT	\N	PRESENT	0
125474	125473	01008M	PARTICIPANT	\N	PRESENT	0
125475	125473	11036J	PARTICIPANT	\N	PRESENT	0
125476	125473	11081P	PARTICIPANT	\N	PRESENT	0
125477	125473	14013P	PARTICIPANT	\N	EXCUSE	0
125478	125473	08068F	PARTICIPANT	\N	PRESENT	0
125479	125473	14207L	PARTICIPANT	\N	PRESENT	0
125480	125473	11101A	PARTICIPANT	\N	PRESENT	0
125672	125663	14175V	PARTICIPANT	\N	PRESENT	0
125673	125663	14085U	PARTICIPANT	\N	PRESENT	0
125483	125473	80013X	PARTICIPANT	\N	PRESENT	0
125677	124782	01058X	PARTICIPANT	\N	PRESENT	0
125485	125473	04089T	PARTICIPANT	\N	PRESENT	0
125486	125473	14197C	PARTICIPANT	\N	PRESENT	0
125681	125680	11048N	PARTICIPANT	\N	PRESENT	0
125488	125473	14187A	PARTICIPANT	\N	PRESENT	0
125489	125473	14033T	PARTICIPANT	\N	PRESENT	0
125490	125473	14081Q	PARTICIPANT	\N	PRESENT	0
125742	125741	95049N	PARTICIPANT	\N	PRESENT	0
125745	125744	11048N	PARTICIPANT	\N	PRESENT	0
125493	125473	04049K	PARTICIPANT	\N	PRESENT	0
126286	126285	14259Y	PARTICIPANT	\N	PRESENT	0
126288	126287	14259Y	PARTICIPANT	\N	PRESENT	0
126290	126289	14259Y	PARTICIPANT	\N	PRESENT	0
125497	125473	11100Y	PRESIDENT	0	PRESENT	0
125498	125473	01061S	PARTICIPANT	\N	PRESENT	0
125499	125473	11098Y	PARTICIPANT	\N	PRESENT	0
125500	125473	01043Q	PARTICIPANT	\N	PRESENT	0
125501	125473	11077T	PARTICIPANT	\N	PRESENT	0
125502	125473	14205J	PARTICIPANT	\N	PRESENT	0
125503	125473	08019V	PARTICIPANT	\N	PRESENT	0
125504	125473	14257W	PARTICIPANT	\N	PRESENT	0
125505	125473	08021P	PARTICIPANT	\N	PRESENT	0
125506	125473	04088S	PARTICIPANT	\N	PRESENT	0
125507	125473	98050T	PARTICIPANT	\N	PRESENT	0
126294	126293	14133K	PARTICIPANT	\N	PRESENT	0
125509	125473	11046L	PARTICIPANT	\N	PRESENT	0
125510	125473	01058X	PARTICIPANT	\N	PRESENT	0
125511	125473	11094U	PARTICIPANT	\N	PRESENT	0
125512	125473	11066Q	PARTICIPANT	\N	PRESENT	0
126295	126293	04054G	PARTICIPANT	\N	PRESENT	0
126297	126293	96004D	PRESIDENT	0	PRESENT	0
126298	126293	11040E	PARTICIPANT	\N	PRESENT	0
126299	126293	14089Y	PARTICIPANT	\N	PRESENT	0
126300	126293	90003B	PARTICIPANT	\N	EXCUSE	0
126301	126293	14079W	PARTICIPANT	\N	PRESENT	0
126302	126293	14249W	PARTICIPANT	\N	PRESENT	0
126303	126293	11083R	PARTICIPANT	\N	PRESENT	0
126304	126293	08044W	PARTICIPANT	\N	EXCUSE	0
126305	126293	14097Y	PARTICIPANT	\N	PRESENT	0
126306	126293	04061F	PARTICIPANT	\N	PRESENT	0
126307	126293	14073Q	PARTICIPANT	\N	PRESENT	0
126308	126293	11026G	PARTICIPANT	\N	PRESENT	0
126309	126293	98046X	PARTICIPANT	\N	PRESENT	0
126310	126293	14001X	PARTICIPANT	\N	PRESENT	0
126311	126293	04057K	PARTICIPANT	\N	PRESENT	0
126312	126293	08042U	PARTICIPANT	\N	EXCUSE	0
126313	126293	01016M	PARTICIPANT	\N	PRESENT	0
126314	126293	10015M	PARTICIPANT	\N	PRESENT	0
126316	126293	04045F	PARTICIPANT	\N	PRESENT	0
126317	126293	92045V	PARTICIPANT	\N	PRESENT	0
126318	126293	98035U	PARTICIPANT	\N	PRESENT	0
126323	126293	08018U	PARTICIPANT	\N	EXCUSE	0
126425	125999	14269B	PARTICIPANT	\N	PRESENT	0
126426	125999	11113E	PARTICIPANT	\N	PRESENT	0
126427	125999	95041E	PARTICIPANT	\N	PRESENT	0
126428	125999	14239U	PARTICIPANT	\N	PRESENT	0
126429	125999	14241N	PARTICIPANT	\N	PRESENT	0
126430	125999	14251Q	PARTICIPANT	\N	PRESENT	0
100254	100253	14093U	PARTICIPANT	\N	PRESENT	0
100255	100253	13002U	PARTICIPANT	\N	PRESENT	0
100256	100253	01015L	PARTICIPANT	\N	PRESENT	0
100257	100253	01022K	PARTICIPANT	\N	PRESENT	0
100258	100253	11094U	PARTICIPANT	\N	PRESENT	0
100259	100253	11026G	PARTICIPANT	\N	PRESENT	0
100260	100253	11048N	PARTICIPANT	\N	PRESENT	0
100261	100253	01044R	PARTICIPANT	\N	PRESENT	0
100262	100253	11049P	PARTICIPANT	\N	PRESENT	0
109314	107314	11080N	PARTICIPANT	\N	PRESENT	0
109315	107314	14223L	PARTICIPANT	\N	PRESENT	0
100452	100449	04040A	PARTICIPANT	\N	EXCUSE	0
100453	100449	08058D	PARTICIPANT	\N	EXCUSE	0
109316	107314	95041E	PARTICIPANT	\N	PRESENT	0
109317	107314	04057K	PARTICIPANT	\N	PRESENT	0
109318	107314	86044G	PARTICIPANT	\N	PRESENT	0
109319	107314	08022Q	PARTICIPANT	\N	PRESENT	0
109320	107314	11090Q	PARTICIPANT	\N	PRESENT	0
100459	100449	98018T	PARTICIPANT	\N	PRESENT	0
100460	100449	92018S	PARTICIPANT	\N	PRESENT	0
109321	107314	14061L	PARTICIPANT	\N	PRESENT	0
100462	100449	95030B	PARTICIPANT	\N	PRESENT	0
109322	107314	14255U	PARTICIPANT	\N	PRESENT	0
100464	100449	95031C	PARTICIPANT	\N	PRESENT	0
109323	107314	01056V	PARTICIPANT	\N	PRESENT	0
100466	100449	08065C	PARTICIPANT	\N	EXCUSE	0
100467	100449	04035D	PARTICIPANT	\N	PRESENT	0
100468	100449	07024N	PARTICIPANT	\N	EXCUSE	0
109324	107314	99004R	PARTICIPANT	\N	PRESENT	0
109325	107314	11093T	PARTICIPANT	\N	PRESENT	0
109326	107314	14215L	PARTICIPANT	\N	PRESENT	0
109327	107314	98005N	PARTICIPANT	\N	PRESENT	0
100473	100449	95035G	PARTICIPANT	\N	PRESENT	0
109328	107314	07032N	PARTICIPANT	\N	PRESENT	0
109312	107314	86034E	PARTICIPANT	\N	PRESENT	0
109329	107314	08034U	PARTICIPANT	\N	PRESENT	0
109330	107314	14209N	PARTICIPANT	\N	PRESENT	0
109331	107314	92040Q	PARTICIPANT	\N	PRESENT	0
109332	107314	04088S	PARTICIPANT	\N	PRESENT	0
100480	100449	14097Y	PARTICIPANT	\N	PRESENT	0
109333	107314	14041T	PARTICIPANT	\N	PRESENT	0
100482	100449	04036E	PARTICIPANT	\N	PRESENT	0
109334	107314	95015C	PARTICIPANT	\N	PRESENT	0
109335	107314	04092N	PARTICIPANT	\N	PRESENT	0
109336	107314	01031L	PARTICIPANT	\N	PRESENT	0
100486	100449	92031P	PARTICIPANT	\N	PRESENT	0
100487	100449	11106F	PARTICIPANT	\N	EXCUSE	0
109337	107314	05012A	PARTICIPANT	\N	PRESENT	0
109338	107314	08055A	PARTICIPANT	\N	PRESENT	0
100490	100449	08053X	PARTICIPANT	\N	PRESENT	0
109339	107314	95063L	PARTICIPANT	\N	PRESENT	0
109340	107314	14059S	PARTICIPANT	\N	PRESENT	0
109341	107314	08068F	PARTICIPANT	\N	PRESENT	0
109342	107314	14026U	PARTICIPANT	\N	PRESENT	0
109343	107314	14187A	PARTICIPANT	\N	PRESENT	0
109344	107314	98046X	PARTICIPANT	\N	PRESENT	0
100497	100449	98021N	PARTICIPANT	\N	EXCUSE	0
100498	100449	04080J	PARTICIPANT	\N	PRESENT	0
100499	100449	95059Q	PRESIDENT	0	PRESENT	0
109345	107314	04053F	PARTICIPANT	\N	PRESENT	0
100501	100449	01014K	PARTICIPANT	\N	PRESENT	0
100502	100449	11054L	PARTICIPANT	\N	PRESENT	0
100503	100449	01056V	PARTICIPANT	\N	PRESENT	0
109346	107314	04086Q	PARTICIPANT	\N	PRESENT	0
109347	107314	04067M	PARTICIPANT	\N	PRESENT	0
109348	107314	95062K	PARTICIPANT	\N	PRESENT	0
109349	107314	14249W	PARTICIPANT	\N	PRESENT	0
109350	107314	14253S	PARTICIPANT	\N	PRESENT	0
109351	107314	14259Y	PARTICIPANT	\N	PRESENT	0
109387	107314	08016S	PARTICIPANT	\N	PRESENT	0
109353	107314	07026Q	PARTICIPANT	\N	PRESENT	0
109354	107314	01059Y	PARTICIPANT	\N	PRESENT	0
109355	107314	11101A	PARTICIPANT	\N	PRESENT	0
109356	107314	12041X	PARTICIPANT	\N	PRESENT	0
109357	107314	01015L	PARTICIPANT	\N	PRESENT	0
109358	107314	04042C	PARTICIPANT	\N	PRESENT	0
109359	107314	01013J	PARTICIPANT	\N	PRESENT	0
109360	107314	11040E	PARTICIPANT	\N	PRESENT	0
109361	107314	11031D	PARTICIPANT	\N	PRESENT	0
109362	107314	04043D	PARTICIPANT	\N	PRESENT	0
109363	107314	11098Y	PARTICIPANT	\N	PRESENT	0
109364	107314	14013P	PARTICIPANT	\N	PRESENT	0
109365	107314	04085P	PARTICIPANT	\N	PRESENT	0
109366	107314	14193X	PARTICIPANT	\N	PRESENT	0
109367	107314	11029K	PARTICIPANT	\N	PRESENT	0
109368	107314	01044R	PARTICIPANT	\N	PRESENT	0
109369	107314	01058X	PARTICIPANT	\N	PRESENT	0
109370	107314	13002U	PARTICIPANT	\N	PRESENT	0
109371	107314	11099A	PARTICIPANT	\N	PRESENT	0
109372	107314	14037X	PARTICIPANT	\N	PRESENT	0
109373	107314	11083R	PARTICIPANT	\N	PRESENT	0
109374	107314	08039A	PARTICIPANT	\N	PRESENT	0
109375	107314	01003G	PARTICIPANT	\N	PRESENT	0
109313	107314	14087W	PARTICIPANT	\N	PRESENT	0
109376	107314	14157T	PARTICIPANT	\N	PRESENT	0
109377	107314	08051V	PARTICIPANT	\N	PRESENT	0
109378	107314	88008L	PARTICIPANT	\N	PRESENT	0
109379	107314	08031R	PARTICIPANT	\N	PRESENT	0
109380	107314	04036E	PARTICIPANT	\N	PRESENT	0
109381	107314	14018U	PARTICIPANT	\N	PRESENT	0
109382	107314	14261S	PARTICIPANT	\N	PRESENT	0
109383	107314	14201E	PARTICIPANT	\N	PRESENT	0
109384	107314	14119M	PARTICIPANT	\N	PRESENT	0
109385	107314	98022P	PARTICIPANT	\N	PRESENT	0
109386	107314	11063M	PARTICIPANT	\N	PRESENT	0
109388	107314	11103C	PARTICIPANT	\N	PRESENT	0
109389	107314	01016M	PARTICIPANT	\N	PRESENT	0
109390	107314	04056J	PARTICIPANT	\N	PRESENT	0
109391	107314	11039M	PARTICIPANT	\N	PRESENT	0
109392	107314	14265W	PARTICIPANT	\N	PRESENT	0
109393	107314	14051J	PARTICIPANT	\N	PRESENT	0
109394	107314	04081K	PARTICIPANT	\N	PRESENT	0
109395	107314	08052W	PARTICIPANT	\N	PRESENT	0
109396	107314	11027H	PARTICIPANT	\N	PRESENT	0
109397	107314	77002U	PARTICIPANT	\N	PRESENT	0
109398	107314	14151M	PARTICIPANT	\N	PRESENT	0
109399	107314	01011G	PARTICIPANT	\N	PRESENT	0
109400	107314	11057P	PARTICIPANT	\N	PRESENT	0
109401	107314	11066Q	PARTICIPANT	\N	PRESENT	0
109402	107314	14105F	PARTICIPANT	\N	PRESENT	0
109403	107314	04074L	PARTICIPANT	\N	PRESENT	0
109404	107314	80013X	PARTICIPANT	\N	PRESENT	0
109405	107314	14028W	PARTICIPANT	\N	PRESENT	0
109406	107314	01022K	PARTICIPANT	\N	PRESENT	0
109407	107314	14197C	PARTICIPANT	\N	PRESENT	0
109408	107314	14257W	PARTICIPANT	\N	PRESENT	0
109409	107314	11015D	PARTICIPANT	\N	PRESENT	0
109410	107314	11105E	PARTICIPANT	\N	PRESENT	0
109411	107314	80027E	PARTICIPANT	\N	PRESENT	0
109412	107314	11036J	PARTICIPANT	\N	PRESENT	0
109413	107314	98029W	PARTICIPANT	\N	PRESENT	0
109414	107314	11046L	PARTICIPANT	\N	PRESENT	0
109415	107314	04049K	PARTICIPANT	\N	PRESENT	0
109416	107314	83042R	PARTICIPANT	\N	PRESENT	0
109417	107314	95037J	PARTICIPANT	\N	PRESENT	0
109418	107314	08058D	PARTICIPANT	\N	PRESENT	0
109419	107314	11030C	PARTICIPANT	\N	PRESENT	0
109420	107314	14271U	PARTICIPANT	\N	PRESENT	0
109421	107314	04071H	PARTICIPANT	\N	PRESENT	0
109422	107314	14225N	PARTICIPANT	\N	PRESENT	0
109423	107314	14227Q	PARTICIPANT	\N	PRESENT	0
109424	107314	11091R	PARTICIPANT	\N	PRESENT	0
109425	107314	14167V	PARTICIPANT	\N	PRESENT	0
109426	107314	11054L	PARTICIPANT	\N	PRESENT	0
109427	107314	83047W	PARTICIPANT	\N	PRESENT	0
109428	107314	14281W	PARTICIPANT	\N	PRESENT	0
109429	107314	04079R	PARTICIPANT	\N	PRESENT	0
109430	107314	14063N	PARTICIPANT	\N	PRESENT	0
109431	107314	11112D	PARTICIPANT	\N	PRESENT	0
109432	107314	11100Y	PARTICIPANT	\N	PRESENT	0
109433	107314	08035V	PARTICIPANT	\N	PRESENT	0
109434	107314	11014C	PARTICIPANT	\N	PRESENT	0
109435	107314	92045V	PARTICIPANT	\N	PRESENT	0
109436	107314	11104D	PARTICIPANT	\N	PRESENT	0
109437	107314	08038Y	PARTICIPANT	\N	PRESENT	0
109438	107314	04059M	PARTICIPANT	\N	PRESENT	0
109439	107314	11049P	PARTICIPANT	\N	PRESENT	0
109440	107314	04066L	PARTICIPANT	\N	PRESENT	0
109441	107314	11084S	PARTICIPANT	\N	PRESENT	0
109442	107314	14085U	PARTICIPANT	\N	PRESENT	0
109443	107314	11067R	PARTICIPANT	\N	PRESENT	0
109444	107314	14175V	PARTICIPANT	\N	PRESENT	0
109445	107314	11077T	PARTICIPANT	\N	PRESENT	0
109446	107314	14093U	PARTICIPANT	\N	PRESENT	0
109447	107314	14251Q	PARTICIPANT	\N	PRESENT	0
109448	107314	11042G	PARTICIPANT	\N	PRESENT	0
109449	107314	04094Q	PARTICIPANT	\N	PRESENT	0
109450	107314	14069U	PARTICIPANT	\N	PRESENT	0
109451	107314	04095R	PARTICIPANT	\N	PRESENT	0
118814	118775	14259Y	PARTICIPANT	\N	PRESENT	0
118816	118815	14187A	PARTICIPANT	\N	PRESENT	0
118817	118815	11100Y	PARTICIPANT	\N	PRESENT	0
118818	118815	11094U	PARTICIPANT	\N	PRESENT	0
118819	118815	08031R	PARTICIPANT	\N	PRESENT	0
118820	118815	11090Q	PARTICIPANT	\N	PRESENT	0
118821	118815	14269B	PARTICIPANT	\N	PRESENT	0
118823	118822	14187A	PARTICIPANT	\N	PRESENT	0
118825	118824	14231L	PARTICIPANT	\N	PRESENT	0
118829	118828	01044R	PARTICIPANT	\N	PRESENT	0
118830	118828	11029K	PARTICIPANT	\N	PRESENT	0
118834	118828	80013X	PARTICIPANT	\N	EXCUSE	0
118832	118828	01015L	PARTICIPANT	\N	PRESENT	0
118833	118828	14219Q	PRESIDENT	0	PRESENT	0
118835	118828	14197C	PARTICIPANT	\N	EXCUSE	0
118836	118828	14031R	PARTICIPANT	\N	EXCUSE	0
118837	118828	04057K	PARTICIPANT	\N	EXCUSE	0
118838	118828	92039X	PARTICIPANT	\N	EXCUSE	0
118839	118828	14265W	PARTICIPANT	\N	EXCUSE	0
118840	118828	05012A	PARTICIPANT	\N	EXCUSE	0
118841	118828	08049C	PARTICIPANT	\N	EXCUSE	0
120027	118920	86034E	PARTICIPANT	\N	PRESENT	0
120028	118920	01061S	PARTICIPANT	\N	PRESENT	0
120029	118920	14249W	PARTICIPANT	\N	PRESENT	0
120030	118920	98050T	PARTICIPANT	\N	PRESENT	0
120031	118920	14331P	PARTICIPANT	\N	PRESENT	0
120032	118920	14179A	PARTICIPANT	\N	PRESENT	0
120033	118920	01019Q	PARTICIPANT	\N	PRESENT	0
120034	118920	11094U	PARTICIPANT	\N	PRESENT	0
120035	118920	05008E	PARTICIPANT	\N	PRESENT	0
120036	118920	01024M	PARTICIPANT	\N	PRESENT	0
120037	118920	08016S	PARTICIPANT	\N	PRESENT	0
120038	118920	04056J	PARTICIPANT	\N	PRESENT	0
120039	118920	92015P	PARTICIPANT	\N	PRESENT	0
120040	118920	08055A	PARTICIPANT	\N	PRESENT	0
120041	118920	14271U	PARTICIPANT	\N	PRESENT	0
120042	118920	14065Q	PARTICIPANT	\N	PRESENT	0
120043	118920	01027Q	PARTICIPANT	\N	PRESENT	0
120044	118920	04071H	PARTICIPANT	\N	PRESENT	0
120045	118920	08017T	PARTICIPANT	\N	PRESENT	0
120046	118920	98024R	PARTICIPANT	\N	PRESENT	0
120047	118920	11014C	PARTICIPANT	\N	PRESENT	0
120048	118920	99004R	PARTICIPANT	\N	PRESENT	0
120049	118920	14265W	PARTICIPANT	\N	PRESENT	0
120050	118920	14223L	PARTICIPANT	\N	PRESENT	0
120051	118920	89029V	PARTICIPANT	\N	PRESENT	0
120052	118920	01048V	PARTICIPANT	\N	PRESENT	0
120053	118920	04033B	PARTICIPANT	\N	PRESENT	0
120054	118920	10006L	PARTICIPANT	\N	PRESENT	0
120055	118920	14041T	PARTICIPANT	\N	PRESENT	0
120056	118920	01008M	PARTICIPANT	\N	PRESENT	0
120057	118920	04045F	PARTICIPANT	\N	PRESENT	0
120062	118920	87003B	PARTICIPANT	\N	PRESENT	0
120059	118920	14225N	PARTICIPANT	\N	PRESENT	0
120060	118920	11042G	PARTICIPANT	\N	PRESENT	0
120061	118920	08014Q	PARTICIPANT	\N	PRESENT	0
120063	118920	04034C	PARTICIPANT	\N	PRESENT	0
120064	118920	11036J	PARTICIPANT	\N	PRESENT	0
120065	118920	01031L	PARTICIPANT	\N	PRESENT	0
120066	118920	11010L	PARTICIPANT	\N	PRESENT	0
120067	118920	14197C	PARTICIPANT	\N	PRESENT	0
120068	118920	04057K	PARTICIPANT	\N	PRESENT	0
120069	118920	14207L	PARTICIPANT	\N	PRESENT	0
120070	118920	01007L	PARTICIPANT	\N	PRESENT	0
120071	118920	01025N	PARTICIPANT	\N	PRESENT	0
120072	118920	01028R	PARTICIPANT	\N	PRESENT	0
120073	118920	14033T	PARTICIPANT	\N	PRESENT	0
120074	118920	10015M	PARTICIPANT	\N	PRESENT	0
120075	118920	14135M	PARTICIPANT	\N	PRESENT	0
120076	118920	07034Q	PARTICIPANT	\N	PRESENT	0
120077	118920	11103C	PARTICIPANT	\N	PRESENT	0
120078	118920	14031R	PARTICIPANT	\N	PRESENT	0
120079	118920	08062Y	PARTICIPANT	\N	PRESENT	0
120080	118920	14038Y	PARTICIPANT	\N	PRESENT	0
120081	118920	08047A	PARTICIPANT	\N	PRESENT	0
120082	118920	98053W	PARTICIPANT	\N	PRESENT	0
120083	118920	04085P	PARTICIPANT	\N	PRESENT	0
120084	118920	01059Y	PARTICIPANT	\N	PRESENT	0
120085	118920	14213J	PARTICIPANT	\N	PRESENT	0
120086	118920	11031D	PARTICIPANT	\N	PRESENT	0
120087	118920	11056N	PARTICIPANT	\N	PRESENT	0
120088	118920	08015R	PARTICIPANT	\N	PRESENT	0
120089	118920	14235Q	PARTICIPANT	\N	PRESENT	0
120090	118920	08069G	PARTICIPANT	\N	PRESENT	0
120091	118920	11040E	PARTICIPANT	\N	PRESENT	0
120092	118920	08019V	PARTICIPANT	\N	PRESENT	0
120093	118920	11057P	PARTICIPANT	\N	PRESENT	0
120094	118920	14059S	PARTICIPANT	\N	PRESENT	0
120095	118920	01022K	PARTICIPANT	\N	PRESENT	0
120096	118920	14105F	PARTICIPANT	\N	PRESENT	0
120097	118920	11089X	PARTICIPANT	\N	PRESENT	0
120098	118920	95063L	PARTICIPANT	\N	PRESENT	0
120099	118920	01057W	PARTICIPANT	\N	PRESENT	0
120100	118920	08068F	PARTICIPANT	\N	PRESENT	0
120101	118920	92018S	PARTICIPANT	\N	PRESENT	0
120102	118920	11104D	PARTICIPANT	\N	PRESENT	0
120103	118920	11066Q	PARTICIPANT	\N	PRESENT	0
120104	118920	14085U	PARTICIPANT	\N	PRESENT	0
120105	118920	11029K	PARTICIPANT	\N	PRESENT	0
120106	118920	08043V	PARTICIPANT	\N	PRESENT	0
120107	118920	12042Y	PARTICIPANT	\N	PRESENT	0
120108	118920	14039A	PARTICIPANT	\N	PRESENT	0
120109	118920	08073C	PARTICIPANT	\N	PRESENT	0
120110	118920	14269B	PARTICIPANT	\N	PRESENT	0
120111	118920	14159V	PARTICIPANT	\N	PRESENT	0
120112	118920	08051V	PARTICIPANT	\N	PRESENT	0
120113	118920	08031R	PARTICIPANT	\N	PRESENT	0
120114	118920	14018U	PARTICIPANT	\N	PRESENT	0
120115	118920	14081Q	PARTICIPANT	\N	PRESENT	0
120116	118920	08009T	PARTICIPANT	\N	PRESENT	0
120117	118920	14034U	PARTICIPANT	\N	PRESENT	0
120118	118920	14201E	PARTICIPANT	\N	PRESENT	0
120119	118920	14261S	PARTICIPANT	\N	PRESENT	0
120120	118920	14241N	PARTICIPANT	\N	PRESENT	0
120121	118920	14221J	PARTICIPANT	\N	PRESENT	0
120122	118920	14089Y	PARTICIPANT	\N	PRESENT	0
120123	118920	14327T	PARTICIPANT	\N	PRESENT	0
120124	118920	11093T	PARTICIPANT	\N	PRESENT	0
120125	118920	11053K	PARTICIPANT	\N	PRESENT	0
120126	118920	01047U	PARTICIPANT	\N	PRESENT	0
120127	118920	08056B	PARTICIPANT	\N	PRESENT	0
120128	118920	14087W	PARTICIPANT	\N	PRESENT	0
120129	118920	14079W	PARTICIPANT	\N	PRESENT	0
120130	118920	14217N	PARTICIPANT	\N	PRESENT	0
120131	118920	01041N	PARTICIPANT	\N	PRESENT	0
120132	118920	14026U	PARTICIPANT	\N	PRESENT	0
120133	118920	08034U	PARTICIPANT	\N	PRESENT	0
120134	118920	14147R	PARTICIPANT	\N	PRESENT	0
120135	118920	11097X	PARTICIPANT	\N	PRESENT	0
120136	118920	08048B	PARTICIPANT	\N	PRESENT	0
120137	118920	07029T	PARTICIPANT	\N	PRESENT	0
120138	118920	08028W	PARTICIPANT	\N	PRESENT	0
120139	118920	01003G	PARTICIPANT	\N	PRESENT	0
120140	118920	14157T	PARTICIPANT	\N	PRESENT	0
120141	118920	04055H	PARTICIPANT	\N	PRESENT	0
120142	118920	14069U	PARTICIPANT	\N	PRESENT	0
120143	118920	14237S	PARTICIPANT	\N	PRESENT	0
120144	118920	14013P	PARTICIPANT	\N	PRESENT	0
120145	118920	11114F	PARTICIPANT	\N	PRESENT	0
120146	118920	11072N	PARTICIPANT	\N	PRESENT	0
120147	118920	14239U	PARTICIPANT	\N	PRESENT	0
120148	118920	04081K	PARTICIPANT	\N	PRESENT	0
120149	118920	14063N	PARTICIPANT	\N	PRESENT	0
120150	118920	14083S	PARTICIPANT	\N	PRESENT	0
120151	118920	04088S	PARTICIPANT	\N	PRESENT	0
120152	118920	08041T	PARTICIPANT	\N	PRESENT	0
120153	118920	14215L	PARTICIPANT	\N	PRESENT	0
120154	118920	11033F	PARTICIPANT	\N	PRESENT	0
120155	118920	14263U	PARTICIPANT	\N	PRESENT	0
120156	118920	11059R	PARTICIPANT	\N	PRESENT	0
120157	118920	11049P	PARTICIPANT	\N	PRESENT	0
120158	118920	89017R	PARTICIPANT	\N	PRESENT	0
120159	118920	11012A	PARTICIPANT	\N	PRESENT	0
120160	118920	11090Q	PARTICIPANT	\N	PRESENT	0
120161	118920	80013X	PARTICIPANT	\N	PRESENT	0
120162	118920	11082Q	PARTICIPANT	\N	PRESENT	0
120163	118920	14267Y	PARTICIPANT	\N	PRESENT	0
120164	118920	14219Q	PARTICIPANT	\N	PRESENT	0
120165	118920	11112D	PARTICIPANT	\N	PRESENT	0
100693	100692	05012A	PARTICIPANT	\N	PRESENT	0
100694	100692	11101A	PARTICIPANT	\N	PRESENT	0
100695	100692	08038Y	PARTICIPANT	\N	PRESENT	0
101012	100972	11067R	PARTICIPANT	\N	PRESENT	0
101033	101032	89017R	PARTICIPANT	\N	EXCUSE	0
101014	100972	04092N	PRESIDENT	0	PRESENT	0
101015	100972	14265W	PARTICIPANT	\N	PRESENT	0
101016	100972	14119M	PARTICIPANT	\N	PRESENT	0
101017	100972	14071N	PARTICIPANT	\N	PRESENT	0
101018	100972	07032N	PARTICIPANT	\N	PRESENT	0
101019	100972	04043D	PARTICIPANT	\N	PRESENT	0
101020	100972	14271U	PARTICIPANT	\N	PRESENT	0
101034	101032	01031L	PRESIDENT	0	PRESENT	0
101022	100972	11093T	PARTICIPANT	\N	PRESENT	0
101023	100972	11097X	PARTICIPANT	\N	PRESENT	0
101024	100972	04045F	PARTICIPANT	\N	PRESENT	0
101025	100972	14227Q	PARTICIPANT	\N	PRESENT	0
101026	100972	01034P	PARTICIPANT	\N	PRESENT	0
101036	101032	01013J	PARTICIPANT	\N	PRESENT	0
101028	100972	11063M	PARTICIPANT	\N	PRESENT	0
101029	100972	14269B	PARTICIPANT	\N	PRESENT	0
101037	101032	11040E	PARTICIPANT	\N	PRESENT	0
101038	101032	08014Q	PARTICIPANT	\N	PRESENT	0
101039	101032	14167V	PARTICIPANT	\N	PRESENT	0
101040	101032	14175V	PARTICIPANT	\N	PRESENT	0
101041	101032	14083S	PARTICIPANT	\N	PRESENT	0
101042	101032	14085U	PARTICIPANT	\N	PRESENT	0
101043	101032	11042G	PARTICIPANT	\N	PRESENT	0
101044	101032	88008L	PARTICIPANT	\N	PRESENT	0
101045	101032	04086Q	PARTICIPANT	\N	PRESENT	0
101046	101032	11070L	PARTICIPANT	\N	PRESENT	0
101047	101032	11088W	PARTICIPANT	\N	PRESENT	0
101048	101032	08022Q	PARTICIPANT	\N	PRESENT	0
101049	101032	01027Q	PARTICIPANT	\N	PRESENT	0
101050	101032	11074Q	PARTICIPANT	\N	PRESENT	0
101051	101032	98053W	PARTICIPANT	\N	EXCUSE	0
101052	101032	11083R	PARTICIPANT	\N	PRESENT	0
101053	101032	01057W	PARTICIPANT	\N	PRESENT	0
101054	101032	08016S	PARTICIPANT	\N	PRESENT	0
101055	101032	08069G	PARTICIPANT	\N	PRESENT	0
101056	101032	11048N	PARTICIPANT	\N	PRESENT	0
101057	101032	99004R	PARTICIPANT	\N	PRESENT	0
101059	101032	04061F	PARTICIPANT	\N	PRESENT	0
101060	101032	14159V	PARTICIPANT	\N	PRESENT	0
101061	101032	07029T	PARTICIPANT	\N	PRESENT	0
101062	101032	08010L	PARTICIPANT	\N	PRESENT	0
101063	101032	08034U	PARTICIPANT	\N	PRESENT	0
101064	101032	01048V	PARTICIPANT	\N	PRESENT	0
101065	101032	11085T	PARTICIPANT	\N	EXCUSE	0
101066	101032	98046X	PARTICIPANT	\N	PRESENT	0
101124	101032	08011M	PARTICIPANT	\N	PRESENT	0
101125	101032	08061X	PARTICIPANT	\N	PRESENT	0
101126	101032	01016M	PARTICIPANT	\N	PRESENT	0
101127	101032	14225N	PARTICIPANT	\N	PRESENT	0
101128	101032	11012A	PARTICIPANT	\N	PRESENT	0
101129	101032	14173T	PARTICIPANT	\N	PRESENT	0
101130	101032	04034C	PARTICIPANT	\N	PRESENT	0
101132	101032	08025T	PARTICIPANT	\N	PRESENT	0
101133	101032	05008E	PARTICIPANT	\N	PRESENT	0
101134	101032	14065Q	PARTICIPANT	\N	PRESENT	0
101135	101032	14069U	PARTICIPANT	\N	PRESENT	0
101136	101032	04047H	PARTICIPANT	\N	PRESENT	0
101137	101032	04038G	PARTICIPANT	\N	PRESENT	0
101138	101032	14259Y	PARTICIPANT	\N	PRESENT	0
101139	101032	11113E	PARTICIPANT	\N	PRESENT	0
101140	101032	01024M	PARTICIPANT	\N	PRESENT	0
101141	101032	14215L	PARTICIPANT	\N	PRESENT	0
101142	101032	08018U	PARTICIPANT	\N	PRESENT	0
101143	101032	01007L	PARTICIPANT	\N	PRESENT	0
101144	101032	11049P	PARTICIPANT	\N	PRESENT	0
101145	101032	08044W	PARTICIPANT	\N	PRESENT	0
101146	101032	11084S	PARTICIPANT	\N	PRESENT	0
101147	101032	11026G	PARTICIPANT	\N	PRESENT	0
101148	101032	04079R	PARTICIPANT	\N	PRESENT	0
101149	101032	14111D	PARTICIPANT	\N	PRESENT	0
101150	101032	14001X	PARTICIPANT	\N	PRESENT	0
101152	101032	14273W	PARTICIPANT	\N	PRESENT	0
101153	101032	14147R	PARTICIPANT	\N	PRESENT	0
101154	101032	95049N	PARTICIPANT	\N	PRESENT	0
101155	101032	08051V	PARTICIPANT	\N	PRESENT	0
101156	101032	07034Q	PARTICIPANT	\N	PRESENT	0
101157	101032	04074L	PARTICIPANT	\N	PRESENT	0
101158	101032	95063L	PARTICIPANT	\N	PRESENT	0
101159	101032	01028R	PARTICIPANT	\N	PRESENT	0
101160	101032	98035U	PARTICIPANT	\N	PRESENT	0
101161	101032	04056J	PARTICIPANT	\N	PRESENT	0
101162	101032	04044E	PARTICIPANT	\N	PRESENT	0
101163	101032	11037K	PARTICIPANT	\N	PRESENT	0
101164	101032	92045V	PARTICIPANT	\N	PRESENT	0
101165	101032	95067Q	PARTICIPANT	\N	PRESENT	0
101166	101032	01047U	PARTICIPANT	\N	PRESENT	0
101310	100177	14219Q	PARTICIPANT	\N	PRESENT	0
101312	100177	14259Y	PARTICIPANT	\N	PRESENT	0
101337	101336	08025T	PARTICIPANT	\N	PRESENT	0
101338	101336	05008E	PRESIDENT	0	PRESENT	0
101339	101336	14065Q	PARTICIPANT	\N	PRESENT	0
101340	101336	14069U	PARTICIPANT	\N	PRESENT	0
101341	101336	04047H	PARTICIPANT	\N	PRESENT	0
101342	101336	04038G	PARTICIPANT	\N	PRESENT	0
101343	101336	14259Y	PARTICIPANT	\N	PRESENT	0
101344	101336	11113E	PARTICIPANT	\N	PRESENT	0
101345	101336	01024M	PARTICIPANT	\N	PRESENT	0
101346	101336	14215L	PARTICIPANT	\N	PRESENT	0
101347	101336	08018U	PARTICIPANT	\N	PRESENT	0
101348	101336	01007L	PARTICIPANT	\N	PRESENT	0
101349	101336	11049P	PARTICIPANT	\N	PRESENT	0
101350	101336	08044W	PARTICIPANT	\N	PRESENT	0
101351	101336	11084S	PARTICIPANT	\N	PRESENT	0
101352	101336	11026G	PARTICIPANT	\N	PRESENT	0
101353	101336	04079R	PARTICIPANT	\N	PRESENT	0
101354	101336	14111D	PARTICIPANT	\N	PRESENT	0
101355	101336	14001X	PARTICIPANT	\N	PRESENT	0
101356	101336	14273W	PARTICIPANT	\N	PRESENT	0
101357	101336	14147R	PARTICIPANT	\N	PRESENT	0
101358	101336	95049N	PARTICIPANT	\N	PRESENT	0
101359	101336	08051V	PARTICIPANT	\N	PRESENT	0
101360	101336	07034Q	PARTICIPANT	\N	PRESENT	0
101361	101336	04074L	PARTICIPANT	\N	PRESENT	0
101362	101336	95063L	PARTICIPANT	\N	PRESENT	0
101363	101336	01028R	PARTICIPANT	\N	PRESENT	0
101364	101336	98035U	PARTICIPANT	\N	PRESENT	0
101365	101336	04056J	PARTICIPANT	\N	PRESENT	0
101366	101336	04044E	PARTICIPANT	\N	PRESENT	0
101367	101336	11037K	PARTICIPANT	\N	PRESENT	0
101368	101336	92045V	PARTICIPANT	\N	PRESENT	0
101369	101336	95067Q	PARTICIPANT	\N	PRESENT	0
101370	101336	01047U	PARTICIPANT	\N	PRESENT	0
101372	101336	04034C	PARTICIPANT	\N	PRESENT	0
101373	101336	14085U	PARTICIPANT	\N	PRESENT	0
101374	101336	14173T	PARTICIPANT	\N	PRESENT	0
101375	101336	08010L	PARTICIPANT	\N	PRESENT	0
101376	101336	04061F	PARTICIPANT	\N	PRESENT	0
101377	101336	01031L	PARTICIPANT	\N	PRESENT	0
101378	101336	08011M	PARTICIPANT	\N	PRESENT	0
101379	101336	08034U	PARTICIPANT	\N	PRESENT	0
101380	101336	11012A	PARTICIPANT	\N	PRESENT	0
101381	101336	11083R	PARTICIPANT	\N	PRESENT	0
101382	101336	88008L	PARTICIPANT	\N	PRESENT	0
101383	101336	04086Q	PARTICIPANT	\N	PRESENT	0
101384	101336	08022Q	PARTICIPANT	\N	PRESENT	0
101385	101336	01013J	PARTICIPANT	\N	PRESENT	0
101386	101336	14167V	PARTICIPANT	\N	PRESENT	0
101387	101336	11070L	PARTICIPANT	\N	PRESENT	0
101388	101336	11088W	PARTICIPANT	\N	PRESENT	0
101389	101336	11048N	PARTICIPANT	\N	PRESENT	0
101390	101336	07029T	PARTICIPANT	\N	PRESENT	0
101391	101336	14083S	PARTICIPANT	\N	PRESENT	0
101392	101336	14159V	PARTICIPANT	\N	PRESENT	0
101393	101336	01048V	PARTICIPANT	\N	PRESENT	0
101394	101336	99004R	PARTICIPANT	\N	PRESENT	0
101395	101336	01057W	PARTICIPANT	\N	PRESENT	0
101396	101336	08014Q	PARTICIPANT	\N	PRESENT	0
101397	101336	11042G	PARTICIPANT	\N	PRESENT	0
101398	101336	08061X	PARTICIPANT	\N	PRESENT	0
101399	101336	08069G	PARTICIPANT	\N	PRESENT	0
101400	101336	08016S	PARTICIPANT	\N	PRESENT	0
101401	101336	11040E	PARTICIPANT	\N	PRESENT	0
101402	101336	11074Q	PARTICIPANT	\N	PRESENT	0
101403	101336	01027Q	PARTICIPANT	\N	PRESENT	0
101404	101336	98046X	PARTICIPANT	\N	PRESENT	0
101405	101336	14225N	PARTICIPANT	\N	PRESENT	0
101721	100899	14221J	PARTICIPANT	\N	PRESENT	0
101744	101741	11055M	PARTICIPANT	\N	PRESENT	0
101746	101741	04053F	PARTICIPANT	\N	PRESENT	0
114074	114073	14239U	PARTICIPANT	\N	PRESENT	0
114454	114453	11036J	PARTICIPANT	\N	PRESENT	0
114076	114073	01046T	PARTICIPANT	\N	PRESENT	0
114077	114073	04053F	PARTICIPANT	\N	PRESENT	0
114078	114073	14255U	PARTICIPANT	\N	EXCUSE	0
114455	114453	01044R	PARTICIPANT	\N	PRESENT	0
114080	114073	00003C	PARTICIPANT	\N	EXCUSE	0
114081	114073	14053L	PARTICIPANT	\N	PRESENT	0
114082	114073	11103C	PARTICIPANT	\N	PRESENT	0
114456	114453	14038Y	PARTICIPANT	\N	PRESENT	0
114084	114073	14195A	PARTICIPANT	\N	PRESENT	0
114085	114073	14267Y	PARTICIPANT	\N	PRESENT	0
114457	114453	14219Q	PRESIDENT	0	PRESENT	0
114087	114073	11031D	PARTICIPANT	\N	PRESENT	0
114088	114073	08052W	PARTICIPANT	\N	PRESENT	0
114458	114453	14031R	PARTICIPANT	\N	PRESENT	0
114090	114073	04081K	PARTICIPANT	\N	PRESENT	0
114091	114073	98024R	PARTICIPANT	\N	PRESENT	0
114092	114073	10006L	PARTICIPANT	\N	PRESENT	0
114459	114453	14273W	PARTICIPANT	\N	PRESENT	0
114094	114073	14217N	PARTICIPANT	\N	PRESENT	0
114095	114073	14042U	PARTICIPANT	\N	PRESENT	0
114096	114073	14151M	PARTICIPANT	\N	PRESENT	0
114097	114073	12042Y	PARTICIPANT	\N	PRESENT	0
114098	114073	14281W	PARTICIPANT	\N	PRESENT	0
114460	114453	14265W	PARTICIPANT	\N	PRESENT	0
114461	114453	14107H	PARTICIPANT	\N	PRESENT	0
114101	114073	14034U	PARTICIPANT	\N	PRESENT	0
114102	114073	14231L	PARTICIPANT	\N	PRESENT	0
114103	114073	11061K	PARTICIPANT	\N	PRESENT	0
114104	114073	08048B	PARTICIPANT	\N	PRESENT	0
114105	114073	08041T	PARTICIPANT	\N	PRESENT	0
114462	114453	14051J	PARTICIPANT	\N	PRESENT	0
114107	114073	14026U	PARTICIPANT	\N	PRESENT	0
114108	114073	14213J	PARTICIPANT	\N	PRESENT	0
114109	114073	14121F	PARTICIPANT	\N	PRESENT	0
114110	114073	11112D	PARTICIPANT	\N	EXCUSE	0
114111	114073	14037X	PARTICIPANT	\N	PRESENT	0
114463	114453	11029K	PARTICIPANT	\N	EXCUSE	0
114113	114073	11067R	PARTICIPANT	\N	PRESENT	0
114114	114073	14223L	PARTICIPANT	\N	PRESENT	0
114115	114073	04092N	PRESIDENT	0	PRESENT	0
114116	114073	14265W	PARTICIPANT	\N	PRESENT	0
114117	114073	14119M	PARTICIPANT	\N	PRESENT	0
114118	114073	14071N	PARTICIPANT	\N	PRESENT	0
114464	114453	14197C	PARTICIPANT	\N	EXCUSE	0
114465	114453	04057K	PARTICIPANT	\N	EXCUSE	0
114121	114073	14271U	PARTICIPANT	\N	PRESENT	0
114466	114453	14237S	PARTICIPANT	\N	EXCUSE	0
114123	114073	11093T	PARTICIPANT	\N	PRESENT	0
114124	114073	11097X	PARTICIPANT	\N	PRESENT	0
114125	114073	04045F	PARTICIPANT	\N	PRESENT	0
114126	114073	14227Q	PARTICIPANT	\N	PRESENT	0
114127	114073	01034P	PARTICIPANT	\N	PRESENT	0
114793	114792	04054G	PARTICIPANT	\N	PRESENT	0
114129	114073	11063M	PARTICIPANT	\N	PRESENT	0
114130	114073	14269B	PARTICIPANT	\N	PRESENT	0
114794	114792	14089Y	PARTICIPANT	\N	PRESENT	0
114795	114792	14079W	PARTICIPANT	\N	PRESENT	0
114796	114792	14041T	PARTICIPANT	\N	PRESENT	0
114797	114792	14097Y	PARTICIPANT	\N	PRESENT	0
114798	114792	11026G	PARTICIPANT	\N	PRESENT	0
114799	114792	92031P	PRESIDENT	0	PRESENT	0
114800	114792	14001X	PARTICIPANT	\N	PRESENT	0
114801	114792	14331P	PARTICIPANT	\N	PRESENT	0
114802	114792	14133K	PARTICIPANT	\N	EXCUSE	0
114803	114792	04047H	PARTICIPANT	\N	EXCUSE	0
114805	114792	04035D	PARTICIPANT	\N	EXCUSE	0
114953	114952	95015C	PARTICIPANT	\N	PRESENT	0
114954	114952	11061K	PARTICIPANT	\N	PRESENT	0
114956	114955	01031L	PARTICIPANT	\N	PRESENT	0
114957	114955	95015C	PARTICIPANT	\N	PRESENT	0
114958	114955	08043V	PARTICIPANT	\N	PRESENT	0
114959	114955	01027Q	PARTICIPANT	\N	PRESENT	0
114960	114955	97011G	PARTICIPANT	\N	PRESENT	0
114961	114955	11083R	PARTICIPANT	\N	PRESENT	0
114962	114955	11100Y	PARTICIPANT	\N	PRESENT	0
114963	114955	14175V	PARTICIPANT	\N	PRESENT	0
114964	114955	08019V	PARTICIPANT	\N	PRESENT	0
114966	114965	95015C	PARTICIPANT	\N	PRESENT	0
114967	114965	97011G	PARTICIPANT	\N	PRESENT	0
114968	114965	08043V	PARTICIPANT	\N	PRESENT	0
114970	114969	96004D	PARTICIPANT	\N	PRESENT	0
114971	114969	01016M	PARTICIPANT	\N	PRESENT	0
114973	114972	95015C	PARTICIPANT	\N	PRESENT	0
114975	114974	95015C	PARTICIPANT	\N	PRESENT	0
114977	114976	95015C	PARTICIPANT	\N	PRESENT	0
114978	114976	01058X	PARTICIPANT	\N	PRESENT	0
114980	114979	14037X	PARTICIPANT	\N	PRESENT	0
114981	114979	95015C	PARTICIPANT	\N	PRESENT	0
114982	114979	08019V	PARTICIPANT	\N	PRESENT	0
114983	114979	11083R	PARTICIPANT	\N	PRESENT	0
114984	114979	01027Q	PARTICIPANT	\N	PRESENT	0
114986	114985	95015C	PARTICIPANT	\N	PRESENT	0
118053	117756	14207L	PARTICIPANT	\N	PRESENT	0
118054	117756	14259Y	PARTICIPANT	\N	PRESENT	0
118055	117756	89017R	PARTICIPANT	\N	PRESENT	0
118056	117756	05008E	PARTICIPANT	\N	PRESENT	0
118057	117756	01048V	PARTICIPANT	\N	PRESENT	0
118058	117756	07032N	PARTICIPANT	\N	PRESENT	0
118059	117756	08062Y	PARTICIPANT	\N	PRESENT	0
118060	117756	14209N	PARTICIPANT	\N	PRESENT	0
118061	117756	14249W	PARTICIPANT	\N	PRESENT	0
118062	117756	11048N	PARTICIPANT	\N	PRESENT	0
118063	117756	14135M	PARTICIPANT	\N	PRESENT	0
118064	117756	11036J	PARTICIPANT	\N	PRESENT	0
118065	117032	86034E	PARTICIPANT	\N	PRESENT	0
118066	117032	04092N	PARTICIPANT	\N	PRESENT	0
118067	117032	14037X	PARTICIPANT	\N	PRESENT	0
118068	117032	14034U	PARTICIPANT	\N	PRESENT	0
118069	117032	14087W	PARTICIPANT	\N	PRESENT	0
118070	117032	08016S	PARTICIPANT	\N	PRESENT	0
95253	95252	11039M	PARTICIPANT	\N	PRESENT	0
95254	95252	08012N	PARTICIPANT	\N	PRESENT	0
95255	95252	14073Q	PARTICIPANT	\N	PRESENT	0
95256	95252	87003B	PARTICIPANT	\N	PRESENT	0
95257	95252	14241N	PARTICIPANT	\N	PRESENT	0
95258	95252	14235Q	PARTICIPANT	\N	PRESENT	0
95259	95252	14191V	PARTICIPANT	\N	PRESENT	0
95260	95252	11043H	PARTICIPANT	\N	PRESENT	0
95261	95252	14229S	PARTICIPANT	\N	PRESENT	0
95313	95312	14239U	PARTICIPANT	\N	PRESENT	0
95314	95312	11055M	PARTICIPANT	\N	PRESENT	0
95315	95312	01046T	PARTICIPANT	\N	PRESENT	0
95316	95312	04053F	PARTICIPANT	\N	PRESENT	0
95317	95312	14255U	PARTICIPANT	\N	PRESENT	0
95318	95312	04066L	PARTICIPANT	\N	PRESENT	0
95319	95312	00003C	PARTICIPANT	\N	PRESENT	0
95320	95312	14053L	PARTICIPANT	\N	PRESENT	0
95321	95312	11103C	PARTICIPANT	\N	PRESENT	0
95322	95312	11044J	PARTICIPANT	\N	PRESENT	0
95323	95312	14195A	PARTICIPANT	\N	PRESENT	0
95370	95312	14030Q	PARTICIPANT	\N	PRESENT	0
95326	95312	11031D	PARTICIPANT	\N	PRESENT	0
95327	95312	08052W	PARTICIPANT	\N	PRESENT	0
95328	95312	01059Y	PARTICIPANT	\N	PRESENT	0
95330	95312	98024R	PARTICIPANT	\N	PRESENT	0
95331	95312	10006L	PARTICIPANT	\N	PRESENT	0
95332	95312	04067M	PARTICIPANT	\N	PRESENT	0
95333	95312	14217N	PARTICIPANT	\N	PRESENT	0
95334	95312	14042U	PARTICIPANT	\N	PRESENT	0
95335	95312	14151M	PARTICIPANT	\N	PRESENT	0
95336	95312	12042Y	PARTICIPANT	\N	PRESENT	0
95337	95312	14281W	PARTICIPANT	\N	PRESENT	0
95338	95312	14087W	PARTICIPANT	\N	PRESENT	0
95339	95312	01003G	PARTICIPANT	\N	PRESENT	0
95340	95312	14034U	PARTICIPANT	\N	PRESENT	0
95341	95312	14231L	PARTICIPANT	\N	PRESENT	0
95342	95312	11061K	PARTICIPANT	\N	PRESENT	0
95343	95312	08048B	PARTICIPANT	\N	PRESENT	0
95344	95312	08041T	PARTICIPANT	\N	PRESENT	0
95345	95312	01011G	PARTICIPANT	\N	PRESENT	0
95346	95312	14026U	PARTICIPANT	\N	PRESENT	0
95347	95312	14213J	PARTICIPANT	\N	PRESENT	0
95348	95312	14121F	PARTICIPANT	\N	PRESENT	0
95349	95312	11112D	PARTICIPANT	\N	PRESENT	0
95350	95312	14037X	PARTICIPANT	\N	PRESENT	0
95351	95312	14018U	PARTICIPANT	\N	PRESENT	0
95352	95312	11067R	PARTICIPANT	\N	PRESENT	0
95353	95312	14223L	PARTICIPANT	\N	PRESENT	0
95354	95312	04092N	PRESIDENT	0	PRESENT	0
95355	95312	14265W	PARTICIPANT	\N	PRESENT	0
95356	95312	14119M	PARTICIPANT	\N	PRESENT	0
95357	95312	14071N	PARTICIPANT	\N	PRESENT	0
95358	95312	07032N	PARTICIPANT	\N	PRESENT	0
95359	95312	04043D	PARTICIPANT	\N	PRESENT	0
95360	95312	14271U	PARTICIPANT	\N	PRESENT	0
95361	95312	14017T	PARTICIPANT	\N	EXCUSE	0
95362	95312	11093T	PARTICIPANT	\N	PRESENT	0
95363	95312	11097X	PARTICIPANT	\N	PRESENT	0
95364	95312	04045F	PARTICIPANT	\N	PRESENT	0
95365	95312	14227Q	PARTICIPANT	\N	PRESENT	0
95366	95312	01034P	PARTICIPANT	\N	PRESENT	0
95367	95312	11025F	PARTICIPANT	\N	PRESENT	0
95368	95312	11063M	PARTICIPANT	\N	PRESENT	0
95369	95312	14269B	PARTICIPANT	\N	PRESENT	0
96322	96321	14133K	PARTICIPANT	\N	PRESENT	0
96323	96321	96004D	PRESIDENT	0	PRESENT	0
96324	96321	11040E	PARTICIPANT	\N	PRESENT	0
96325	96321	14089Y	PARTICIPANT	\N	PRESENT	0
96326	96321	14079W	PARTICIPANT	\N	PRESENT	0
96327	96321	11083R	PARTICIPANT	\N	PRESENT	0
96328	96321	14097Y	PARTICIPANT	\N	PRESENT	0
96329	96321	14073Q	PARTICIPANT	\N	PRESENT	0
96330	96321	11026G	PARTICIPANT	\N	PRESENT	0
96331	96321	14001X	PARTICIPANT	\N	PRESENT	0
96332	96321	04080J	PARTICIPANT	\N	PRESENT	0
96333	96321	01016M	PARTICIPANT	\N	PRESENT	0
96334	96321	04045F	PARTICIPANT	\N	PRESENT	0
96335	96321	98035U	PARTICIPANT	\N	PRESENT	0
96336	96321	08018U	PARTICIPANT	\N	EXCUSE	0
96337	96321	14249W	PARTICIPANT	\N	EXCUSE	0
96338	96321	04057K	PARTICIPANT	\N	EXCUSE	0
96468	96466	14030Q	PARTICIPANT	\N	EXCUSE	0
96445	96424	07026Q	PARTICIPANT	\N	PRESENT	0
96446	96424	11067R	PARTICIPANT	\N	PRESENT	0
96447	96424	08031R	PARTICIPANT	\N	PRESENT	0
96448	96424	09001P	PARTICIPANT	\N	PRESENT	0
96449	96424	08043V	PARTICIPANT	\N	PRESENT	0
96450	96424	11029K	PARTICIPANT	\N	PRESENT	0
96451	96424	11031D	PARTICIPANT	\N	PRESENT	0
96470	96466	08060W	PARTICIPANT	\N	EXCUSE	0
96472	96466	14041T	PARTICIPANT	\N	EXCUSE	0
96474	96466	04041B	PARTICIPANT	\N	EXCUSE	0
96475	96466	04036E	PARTICIPANT	\N	EXCUSE	0
96476	96466	80013X	PARTICIPANT	\N	PRESENT	0
96477	96466	14031R	PARTICIPANT	\N	PRESENT	0
96478	96466	09001P	PRESIDENT	0	PRESENT	0
96479	96466	14281W	PARTICIPANT	\N	PRESENT	0
96491	96490	09001P	PARTICIPANT	\N	PRESENT	0
96492	96490	08043V	PARTICIPANT	\N	PRESENT	0
96493	96490	08031R	PARTICIPANT	\N	PRESENT	0
96494	96490	11067R	PARTICIPANT	\N	PRESENT	0
96499	96498	08022Q	PARTICIPANT	\N	PRESENT	0
96500	96498	11053K	PARTICIPANT	\N	PRESENT	0
96501	96498	99004R	PARTICIPANT	\N	PRESENT	0
96502	96498	08061X	PARTICIPANT	\N	PRESENT	0
96503	96498	01016M	PARTICIPANT	\N	PRESENT	0
98640	98637	07024N	PARTICIPANT	\N	PRESENT	0
98638	98637	98018T	PARTICIPANT	\N	PRESENT	0
98639	98637	10006L	PARTICIPANT	\N	PRESENT	0
98641	98637	11026G	PARTICIPANT	\N	PRESENT	0
98642	98637	98042T	PARTICIPANT	\N	PRESENT	0
98643	98637	08018U	PARTICIPANT	\N	PRESENT	0
100095	100094	01013J	PARTICIPANT	\N	PRESENT	0
100173	100172	14133K	PARTICIPANT	\N	PRESENT	0
100174	100172	96004D	PARTICIPANT	\N	PRESENT	0
100175	100172	14089Y	PARTICIPANT	\N	PRESENT	0
100176	100172	01016M	PARTICIPANT	\N	PRESENT	0
100178	100177	14237S	PARTICIPANT	\N	PRESENT	0
100179	100177	08010L	PARTICIPANT	\N	PRESENT	0
100180	100177	11010L	PARTICIPANT	\N	PRESENT	0
100181	100177	14073Q	PARTICIPANT	\N	PRESENT	0
100182	100177	14179A	PARTICIPANT	\N	PRESENT	0
100342	100341	04092N	PARTICIPANT	\N	PRESENT	0
105073	105072	89017R	PARTICIPANT	\N	PRESENT	0
100344	100341	14231L	PARTICIPANT	\N	PRESENT	0
100345	100341	14267Y	PARTICIPANT	\N	PRESENT	0
100346	100341	11067R	PARTICIPANT	\N	PRESENT	0
100347	100341	14135M	PARTICIPANT	\N	PRESENT	0
100348	100341	10006L	PARTICIPANT	\N	PRESENT	0
105074	105072	01031L	PRESIDENT	0	PRESENT	0
105076	105072	01013J	PARTICIPANT	\N	EXCUSE	0
105077	105072	11068S	PARTICIPANT	\N	EXCUSE	0
105078	105072	11040E	PARTICIPANT	\N	EXCUSE	0
105079	105072	08014Q	PARTICIPANT	\N	PRESENT	0
105081	105072	14175V	PARTICIPANT	\N	PRESENT	0
105082	105072	14083S	PARTICIPANT	\N	PRESENT	0
105084	105072	14085U	PARTICIPANT	\N	PRESENT	0
105085	105072	11042G	PARTICIPANT	\N	PRESENT	0
105087	105072	04086Q	PARTICIPANT	\N	PRESENT	0
105090	105072	11088W	PARTICIPANT	\N	PRESENT	0
105091	105072	14327T	PARTICIPANT	\N	EXCUSE	0
105092	105072	08022Q	PARTICIPANT	\N	PRESENT	0
105093	105072	01027Q	PARTICIPANT	\N	PRESENT	0
105094	105072	04071H	PARTICIPANT	\N	PRESENT	0
105095	105072	11074Q	PARTICIPANT	\N	PRESENT	0
105096	105072	98053W	PARTICIPANT	\N	EXCUSE	0
105097	105072	11083R	PARTICIPANT	\N	PRESENT	0
105099	105072	01057W	PARTICIPANT	\N	PRESENT	0
105100	105072	08016S	PARTICIPANT	\N	PRESENT	0
105101	105072	08069G	PARTICIPANT	\N	PRESENT	0
105102	105072	11048N	PARTICIPANT	\N	PRESENT	0
105103	105072	99004R	PARTICIPANT	\N	PRESENT	0
105105	105072	14159V	PARTICIPANT	\N	EXCUSE	0
105106	105072	07029T	PARTICIPANT	\N	PRESENT	0
105108	105072	08010L	PARTICIPANT	\N	PRESENT	0
105109	105072	08034U	PARTICIPANT	\N	PRESENT	0
105110	105072	01048V	PARTICIPANT	\N	PRESENT	0
105111	105072	98046X	PARTICIPANT	\N	PRESENT	0
135539	135538	04042C	PARTICIPANT	\N	PRESENT	0
135541	135540	11076S	PARTICIPANT	\N	PRESENT	0
135543	135542	95059Q	PARTICIPANT	\N	PRESENT	0
135544	135542	92031P	PARTICIPANT	\N	PRESENT	0
135545	135542	11106F	PARTICIPANT	\N	PRESENT	0
135546	135542	86044G	PARTICIPANT	\N	PRESENT	0
135547	135542	01014K	PARTICIPANT	\N	PRESENT	0
135548	135542	11076S	PARTICIPANT	\N	PRESENT	0
149413	149412	04034C	PARTICIPANT	\N	PRESENT	0
149414	149412	14133K	PARTICIPANT	\N	PRESENT	0
149415	149412	01016M	PARTICIPANT	\N	PRESENT	0
148120	148116	04053F	PARTICIPANT	\N	PRESENT	0
148121	148116	14255U	PARTICIPANT	\N	PRESENT	0
148122	148116	04066L	PARTICIPANT	\N	PRESENT	0
148123	148116	00003C	PARTICIPANT	\N	EXCUSE	0
148124	148116	14053L	PARTICIPANT	\N	PRESENT	0
148125	148116	11103C	PARTICIPANT	\N	PRESENT	0
149497	149496	04057K	PARTICIPANT	\N	PRESENT	0
148127	148116	14195A	PARTICIPANT	\N	PRESENT	0
148128	148116	14267Y	PARTICIPANT	\N	PRESENT	0
149498	149496	04034C	PARTICIPANT	\N	PRESENT	0
149500	149499	04057K	PARTICIPANT	\N	PRESENT	0
148131	148116	08052W	PARTICIPANT	\N	PRESENT	0
149501	149499	04034C	PARTICIPANT	\N	PRESENT	0
148133	148116	04081K	PARTICIPANT	\N	PRESENT	0
148134	148116	98024R	PARTICIPANT	\N	PRESENT	0
149503	149502	04057K	PARTICIPANT	\N	PRESENT	0
149504	149502	04034C	PARTICIPANT	\N	PRESENT	0
148137	148116	14217N	PARTICIPANT	\N	PRESENT	0
148138	148116	14042U	PARTICIPANT	\N	PRESENT	0
149506	149505	04057K	PARTICIPANT	\N	PRESENT	0
148140	148116	12042Y	PARTICIPANT	\N	PRESENT	0
148141	148116	14281W	PARTICIPANT	\N	PRESENT	0
148142	148116	14087W	PARTICIPANT	\N	PRESENT	0
148143	148116	01003G	PARTICIPANT	\N	PRESENT	0
148144	148116	14034U	PARTICIPANT	\N	PRESENT	0
148145	148116	14231L	PARTICIPANT	\N	PRESENT	0
148146	148116	11061K	PARTICIPANT	\N	PRESENT	0
149507	149505	04034C	PARTICIPANT	\N	PRESENT	0
148148	148116	08048B	PARTICIPANT	\N	PRESENT	0
148149	148116	08041T	PARTICIPANT	\N	PRESENT	0
149509	149508	04057K	PARTICIPANT	\N	PRESENT	0
148151	148116	14026U	PARTICIPANT	\N	PRESENT	0
148152	148116	14213J	PARTICIPANT	\N	PRESENT	0
148153	148116	14121F	PARTICIPANT	\N	PRESENT	0
148154	148116	11112D	PARTICIPANT	\N	EXCUSE	0
148155	148116	14037X	PARTICIPANT	\N	PRESENT	0
149514	149512	04034C	PARTICIPANT	\N	PRESENT	0
148157	148116	11067R	PARTICIPANT	\N	EXCUSE	0
148158	148116	14223L	PARTICIPANT	\N	PRESENT	0
148159	148116	04092N	PRESIDENT	0	PRESENT	0
148160	148116	14265W	PARTICIPANT	\N	PRESENT	0
148161	148116	14119M	PARTICIPANT	\N	PRESENT	0
148162	148116	14071N	PARTICIPANT	\N	PRESENT	0
148163	148116	04043D	PARTICIPANT	\N	PRESENT	0
149511	149508	04034C	PARTICIPANT	\N	PRESENT	0
149513	149512	04057K	PARTICIPANT	\N	PRESENT	0
148166	148116	11093T	PARTICIPANT	\N	PRESENT	0
148167	148116	11097X	PARTICIPANT	\N	PRESENT	0
148168	148116	04045F	PARTICIPANT	\N	PRESENT	0
148169	148116	14227Q	PARTICIPANT	\N	PRESENT	0
148170	148116	01034P	PARTICIPANT	\N	PRESENT	0
151013	151012	14059S	PARTICIPANT	\N	PRESENT	0
148172	148116	11063M	PARTICIPANT	\N	PRESENT	0
148173	148116	14269B	PARTICIPANT	\N	PRESENT	0
151293	151292	14217N	PARTICIPANT	\N	PRESENT	0
151295	151294	14217N	PARTICIPANT	\N	PRESENT	0
151312	125636	80013X	PARTICIPANT	\N	PRESENT	0
151315	125636	11068S	PARTICIPANT	\N	EXCUSE	0
151716	128998	11068S	PARTICIPANT	\N	PRESENT	0
160475	160474	14249W	PARTICIPANT	\N	PRESENT	0
160476	160474	07026Q	PARTICIPANT	\N	PRESENT	0
160478	160477	14241N	PARTICIPANT	\N	PRESENT	0
160513	160512	95015C	PARTICIPANT	\N	PRESENT	0
160514	160512	14241N	PARTICIPANT	\N	PRESENT	0
160515	160512	98053W	PARTICIPANT	\N	PRESENT	0
164673	159492	80013X	PARTICIPANT	\N	PRESENT	0
164674	159492	11061K	PARTICIPANT	\N	PRESENT	0
164675	159492	11068S	PARTICIPANT	\N	PRESENT	0
164676	159492	04043D	PARTICIPANT	\N	PRESENT	0
164677	159492	01058X	PARTICIPANT	\N	PRESENT	0
164713	159492	13002U	PARTICIPANT	\N	EXCUSE	0
165440	164855	14265W	PARTICIPANT	\N	PRESENT	0
165441	164855	01031L	PARTICIPANT	\N	PRESENT	0
165452	164855	14213J	PARTICIPANT	\N	PRESENT	0
165453	164855	14361V	PARTICIPANT	\N	PRESENT	0
165455	165143	80013X	PARTICIPANT	\N	PRESENT	0
165472	164855	92018S	PARTICIPANT	\N	PRESENT	0
165473	164855	14235Q	PARTICIPANT	\N	PRESENT	0
165474	164856	08024S	PARTICIPANT	\N	PRESENT	0
165492	164856	08047A	PARTICIPANT	\N	PRESENT	0
165493	164856	11033F	PARTICIPANT	\N	PRESENT	0
165494	164856	11101A	PARTICIPANT	\N	PRESENT	0
165495	164856	04085P	PARTICIPANT	\N	PRESENT	0
165438	164855	04088S	PARTICIPANT	\N	PRESENT	0
165439	164855	95049N	PARTICIPANT	\N	PRESENT	0
165496	164856	14211G	PARTICIPANT	\N	PRESENT	0
165497	164856	14065Q	PARTICIPANT	\N	PRESENT	0
165498	164856	11049P	PARTICIPANT	\N	PRESENT	0
165499	164856	14053L	PARTICIPANT	\N	PRESENT	0
165500	164856	04047H	PARTICIPANT	\N	PRESENT	0
165501	164856	01025N	PARTICIPANT	\N	PRESENT	0
165502	164856	14195A	PARTICIPANT	\N	PRESENT	0
165503	164856	95067Q	PARTICIPANT	\N	PRESENT	0
165504	164856	95063L	PARTICIPANT	\N	PRESENT	0
165505	164856	14197C	PARTICIPANT	\N	PRESENT	0
165506	164856	05008E	PARTICIPANT	\N	PRESENT	0
165512	164856	11112D	PARTICIPANT	\N	PRESENT	0
165513	164856	11090Q	PARTICIPANT	\N	PRESENT	0
165514	164856	14331P	PARTICIPANT	\N	PRESENT	0
165515	164856	95030B	PARTICIPANT	\N	PRESENT	0
165516	164856	14147R	PARTICIPANT	\N	PRESENT	0
165517	164856	14033T	PARTICIPANT	\N	PRESENT	0
165532	164856	14217N	PARTICIPANT	\N	PRESENT	0
165533	164856	98022P	PARTICIPANT	\N	PRESENT	0
165534	164856	04088S	PARTICIPANT	\N	PRESENT	0
165535	164856	14215L	PARTICIPANT	\N	PRESENT	0
165536	164856	11056N	PARTICIPANT	\N	PRESENT	0
165537	164856	14265W	PARTICIPANT	\N	PRESENT	0
165538	164856	01024M	PARTICIPANT	\N	PRESENT	0
165539	164856	11097X	PARTICIPANT	\N	PRESENT	0
165540	164856	14026U	PARTICIPANT	\N	PRESENT	0
165541	164856	14014Q	PARTICIPANT	\N	PRESENT	0
165542	164856	07029T	PARTICIPANT	\N	PRESENT	0
165543	164856	14235Q	PARTICIPANT	\N	PRESENT	0
165544	164856	14219Q	PARTICIPANT	\N	PRESENT	0
165545	164856	14030Q	PARTICIPANT	\N	PRESENT	0
165546	164856	14073Q	PARTICIPANT	\N	PRESENT	0
165547	164856	14357A	PARTICIPANT	\N	PRESENT	0
165548	164856	14231L	PARTICIPANT	\N	PRESENT	0
165549	164856	10015M	PARTICIPANT	\N	PRESENT	0
165550	164856	14037X	PARTICIPANT	\N	PRESENT	0
165552	164856	04044E	PARTICIPANT	\N	PRESENT	0
165553	164856	14361V	PARTICIPANT	\N	PRESENT	0
165554	164856	04035D	PARTICIPANT	\N	PRESENT	0
165555	164856	14059S	PARTICIPANT	\N	PRESENT	0
165556	164856	92045V	PARTICIPANT	\N	PRESENT	0
165557	164856	01028R	PARTICIPANT	\N	PRESENT	0
165558	164856	14083S	PARTICIPANT	\N	PRESENT	0
165559	164856	14105F	PARTICIPANT	\N	PRESENT	0
165560	164856	14069U	PARTICIPANT	\N	PRESENT	0
165561	164856	14089Y	PARTICIPANT	\N	PRESENT	0
165562	164856	14034U	PARTICIPANT	\N	PRESENT	0
165572	164856	14271U	PARTICIPANT	\N	PRESENT	0
165613	165612	96004D	PRESIDENT	0	PRESENT	0
165614	165612	04040A	PARTICIPANT	\N	PRESENT	0
165615	165612	11040E	PARTICIPANT	\N	PRESENT	0
165616	165612	11083R	PARTICIPANT	\N	PRESENT	0
165617	165612	98022P	PARTICIPANT	\N	PRESENT	0
165618	165612	14097Y	PARTICIPANT	\N	PRESENT	0
165619	165612	04061F	PARTICIPANT	\N	PRESENT	0
165620	165612	14073Q	PARTICIPANT	\N	PRESENT	0
165621	165612	14001X	PARTICIPANT	\N	PRESENT	0
165622	165612	83042R	PRESIDENT	1	PRESENT	0
165623	165612	04080J	PARTICIPANT	\N	PRESENT	0
165624	165612	95059Q	PARTICIPANT	\N	EXCUSE	0
165626	165625	04080J	PARTICIPANT	\N	PRESENT	0
165627	165625	04043D	PARTICIPANT	\N	PRESENT	0
165633	165632	11039M	PARTICIPANT	\N	PRESENT	0
165634	165632	98042T	PARTICIPANT	\N	PRESENT	0
165635	165632	01019Q	PARTICIPANT	\N	PRESENT	0
138677	138661	14173T	PARTICIPANT	\N	PRESENT	0
138678	138661	08014Q	PARTICIPANT	\N	PRESENT	0
138679	138661	01031L	PARTICIPANT	\N	PRESENT	0
138680	138661	04071H	PARTICIPANT	\N	PRESENT	0
138681	138661	14199E	PARTICIPANT	\N	PRESENT	0
138682	138661	01027Q	PARTICIPANT	\N	PRESENT	0
138683	138661	01016M	PARTICIPANT	\N	PRESENT	0
138684	138661	89017R	PARTICIPANT	\N	PRESENT	0
138685	138661	11085T	PARTICIPANT	\N	PRESENT	0
138686	138661	01057W	PARTICIPANT	\N	PRESENT	0
138687	138661	11057P	PARTICIPANT	\N	PRESENT	0
138688	138661	11083R	PARTICIPANT	\N	PRESENT	0
138689	138661	04086Q	PARTICIPANT	\N	PRESENT	0
138690	138661	11048N	PARTICIPANT	\N	PRESENT	0
138691	138661	08011M	PARTICIPANT	\N	PRESENT	0
138692	138661	11070L	PARTICIPANT	\N	PRESENT	0
138693	138661	14085U	PARTICIPANT	\N	PRESENT	0
138694	138661	14083S	PARTICIPANT	\N	PRESENT	0
138695	138661	08034U	PARTICIPANT	\N	PRESENT	0
138696	138661	11042G	PARTICIPANT	\N	PRESENT	0
138697	138661	14327T	PARTICIPANT	\N	PRESENT	0
138698	138661	08016S	PARTICIPANT	\N	PRESENT	0
138774	138773	89017R	PARTICIPANT	\N	PRESENT	0
138775	138773	01031L	PRESIDENT	0	PRESENT	0
138776	138773	05004A	PARTICIPANT	\N	PRESENT	0
138777	138773	01013J	PARTICIPANT	\N	PRESENT	0
138778	138773	11068S	PARTICIPANT	\N	PRESENT	0
138779	138773	08014Q	PARTICIPANT	\N	PRESENT	0
138780	138773	14175V	PARTICIPANT	\N	PRESENT	0
138781	138773	14083S	PARTICIPANT	\N	PRESENT	0
138782	138773	11053K	PARTICIPANT	\N	PRESENT	0
138783	138773	14085U	PARTICIPANT	\N	PRESENT	0
138784	138773	11042G	PARTICIPANT	\N	PRESENT	0
138785	138773	88008L	PARTICIPANT	\N	PRESENT	0
138786	138773	04086Q	PARTICIPANT	\N	PRESENT	0
138787	138773	04055H	PARTICIPANT	\N	PRESENT	0
138788	138773	11070L	PARTICIPANT	\N	PRESENT	0
138789	138773	11088W	PARTICIPANT	\N	PRESENT	0
138790	138773	14327T	PARTICIPANT	\N	PRESENT	0
138791	138773	08022Q	PARTICIPANT	\N	PRESENT	0
138792	138773	01027Q	PARTICIPANT	\N	PRESENT	0
138793	138773	04071H	PARTICIPANT	\N	PRESENT	0
138794	138773	11074Q	PARTICIPANT	\N	PRESENT	0
138795	138773	98053W	PARTICIPANT	\N	EXCUSE	0
138796	138773	11083R	PARTICIPANT	\N	PRESENT	0
138797	138773	14199E	PARTICIPANT	\N	PRESENT	0
138798	138773	01057W	PARTICIPANT	\N	PRESENT	0
138799	138773	08016S	PARTICIPANT	\N	PRESENT	0
138800	138773	99004R	PARTICIPANT	\N	PRESENT	0
138801	138773	04061F	PARTICIPANT	\N	PRESENT	0
138802	138773	14159V	PARTICIPANT	\N	PRESENT	0
138803	138773	07029T	PARTICIPANT	\N	PRESENT	0
138804	138773	08010L	PARTICIPANT	\N	PRESENT	0
138805	138773	01048V	PARTICIPANT	\N	PRESENT	0
138806	138773	98046X	PARTICIPANT	\N	PRESENT	0
138807	138773	11085T	PARTICIPANT	\N	PRESENT	0
138808	138773	08011M	PARTICIPANT	\N	PRESENT	0
138809	138773	08061X	PARTICIPANT	\N	PRESENT	0
138810	138773	01016M	PARTICIPANT	\N	PRESENT	0
138811	138773	11057P	PARTICIPANT	\N	PRESENT	0
138812	138773	14173T	PARTICIPANT	\N	PRESENT	0
138813	138773	04034C	PARTICIPANT	\N	PRESENT	0
140097	139236	11031D	PARTICIPANT	\N	PRESENT	0
139058	139057	11076S	PARTICIPANT	\N	PRESENT	0
139059	139057	04054G	PARTICIPANT	\N	EXCUSE	0
139060	139057	04040A	PARTICIPANT	\N	PRESENT	0
139061	139057	08058D	PARTICIPANT	\N	PRESENT	0
139063	139057	77002U	PARTICIPANT	\N	PRESENT	0
139064	139057	98029W	PARTICIPANT	\N	PRESENT	0
139065	139057	11080N	PARTICIPANT	\N	PRESENT	0
139066	139057	98018T	PARTICIPANT	\N	PRESENT	0
139067	139057	92020L	PARTICIPANT	\N	PRESENT	0
139068	139057	95030B	PARTICIPANT	\N	PRESENT	0
139069	139057	11096W	PARTICIPANT	\N	PRESENT	0
139070	139057	97011G	PARTICIPANT	\N	PRESENT	0
139071	139057	04035D	PARTICIPANT	\N	PRESENT	0
139072	139057	07024N	PARTICIPANT	\N	PRESENT	0
139073	139057	14014Q	PARTICIPANT	\N	PRESENT	0
139074	139057	11015D	PARTICIPANT	\N	PRESENT	0
139075	139057	07004J	PARTICIPANT	\N	PRESENT	0
139076	139057	95035G	PARTICIPANT	\N	PRESENT	0
139077	139057	08056B	PARTICIPANT	\N	EXCUSE	0
139079	139057	14211G	PARTICIPANT	\N	PRESENT	0
139080	139057	98022P	PARTICIPANT	\N	PRESENT	0
139081	139057	11064N	PARTICIPANT	\N	PRESENT	0
139082	139057	95037J	PARTICIPANT	\N	PRESENT	0
139083	139057	14097Y	PARTICIPANT	\N	PRESENT	0
139085	139057	95041E	PARTICIPANT	\N	PRESENT	0
139086	139057	04036E	PARTICIPANT	\N	PRESENT	0
139087	139057	14039A	PARTICIPANT	\N	PRESENT	0
139088	139057	04077P	PARTICIPANT	\N	PRESENT	0
139089	139057	92031P	PARTICIPANT	\N	PRESENT	0
139090	139057	11106F	PARTICIPANT	\N	PRESENT	0
139091	139057	14251Q	PARTICIPANT	\N	PRESENT	0
139092	139057	83042R	PARTICIPANT	\N	PRESENT	0
139093	139057	08053X	PARTICIPANT	\N	PRESENT	0
139094	139057	11082Q	PARTICIPANT	\N	PRESENT	0
139095	139057	11105E	PARTICIPANT	\N	PRESENT	0
139096	139057	14253S	PARTICIPANT	\N	PRESENT	0
139097	139057	08047A	PARTICIPANT	\N	PRESENT	0
139098	139057	14028W	PARTICIPANT	\N	PRESENT	0
139099	139057	14193X	PARTICIPANT	\N	PRESENT	0
139100	139057	98021N	PARTICIPANT	\N	PRESENT	0
139101	139057	04080J	PARTICIPANT	\N	PRESENT	0
139102	139057	95059Q	PRESIDENT	0	PRESENT	0
139103	139057	86044G	PARTICIPANT	\N	PRESENT	0
139104	139057	01014K	PARTICIPANT	\N	PRESENT	0
139105	139057	11054L	PARTICIPANT	\N	PRESENT	0
139106	139057	01056V	PARTICIPANT	\N	PRESENT	0
139107	139057	92044U	PARTICIPANT	\N	PRESENT	0
139108	139057	08049C	PARTICIPANT	\N	PRESENT	0
139109	139057	04050C	PARTICIPANT	\N	PRESENT	0
139175	139174	11076S	PARTICIPANT	\N	PRESENT	0
139176	139174	04054G	PARTICIPANT	\N	EXCUSE	0
139177	139174	04040A	PARTICIPANT	\N	PRESENT	0
139178	139174	08058D	PARTICIPANT	\N	PRESENT	0
139179	139174	77002U	PARTICIPANT	\N	PRESENT	0
139180	139174	98029W	PARTICIPANT	\N	PRESENT	0
139181	139174	11080N	PARTICIPANT	\N	PRESENT	0
139182	139174	98018T	PARTICIPANT	\N	PRESENT	0
139183	139174	92020L	PARTICIPANT	\N	PRESENT	0
139184	139174	95030B	PARTICIPANT	\N	PRESENT	0
139185	139174	11096W	PARTICIPANT	\N	PRESENT	0
139186	139174	97011G	PARTICIPANT	\N	PRESENT	0
139187	139174	04035D	PARTICIPANT	\N	PRESENT	0
139188	139174	07024N	PARTICIPANT	\N	PRESENT	0
139189	139174	14014Q	PARTICIPANT	\N	PRESENT	0
139190	139174	11015D	PARTICIPANT	\N	PRESENT	0
139191	139174	07004J	PARTICIPANT	\N	PRESENT	0
139192	139174	95035G	PARTICIPANT	\N	PRESENT	0
139193	139174	08056B	PARTICIPANT	\N	EXCUSE	0
139194	139174	14211G	PARTICIPANT	\N	PRESENT	0
139195	139174	98022P	PARTICIPANT	\N	PRESENT	0
139196	139174	11064N	PARTICIPANT	\N	PRESENT	0
139197	139174	95037J	PARTICIPANT	\N	PRESENT	0
139198	139174	04078Q	PARTICIPANT	\N	PRESENT	0
139199	139174	14097Y	PARTICIPANT	\N	PRESENT	0
139200	139174	95041E	PARTICIPANT	\N	PRESENT	0
139201	139174	04036E	PARTICIPANT	\N	PRESENT	0
139202	139174	14039A	PARTICIPANT	\N	PRESENT	0
139203	139174	04077P	PARTICIPANT	\N	PRESENT	0
139204	139174	92031P	PARTICIPANT	\N	PRESENT	0
139205	139174	11106F	PARTICIPANT	\N	PRESENT	0
139206	139174	14251Q	PARTICIPANT	\N	PRESENT	0
139207	139174	83042R	PARTICIPANT	\N	PRESENT	0
139208	139174	08053X	PARTICIPANT	\N	PRESENT	0
139209	139174	11082Q	PARTICIPANT	\N	PRESENT	0
139210	139174	11105E	PARTICIPANT	\N	PRESENT	0
139211	139174	14253S	PARTICIPANT	\N	PRESENT	0
139212	139174	08047A	PARTICIPANT	\N	PRESENT	0
139213	139174	14028W	PARTICIPANT	\N	PRESENT	0
139214	139174	14193X	PARTICIPANT	\N	PRESENT	0
139215	139174	98021N	PARTICIPANT	\N	PRESENT	0
139216	139174	04080J	PARTICIPANT	\N	PRESENT	0
139217	139174	95059Q	PRESIDENT	0	PRESENT	0
139218	139174	86044G	PARTICIPANT	\N	PRESENT	0
139219	139174	01014K	PARTICIPANT	\N	PRESENT	0
139220	139174	11054L	PARTICIPANT	\N	PRESENT	0
139221	139174	01056V	PARTICIPANT	\N	PRESENT	0
139222	139174	92044U	PARTICIPANT	\N	PRESENT	0
139223	139174	08049C	PARTICIPANT	\N	PRESENT	0
139224	139174	04050C	PARTICIPANT	\N	PRESENT	0
140089	139236	04081K	PARTICIPANT	\N	PRESENT	0
140096	139236	01059Y	PARTICIPANT	\N	PRESENT	0
140098	139236	11063M	PARTICIPANT	\N	PRESENT	0
140099	139236	08058D	PARTICIPANT	\N	PRESENT	0
140100	139236	14107H	PARTICIPANT	\N	PRESENT	0
140108	139236	14121F	PARTICIPANT	\N	PRESENT	0
140109	139236	14197C	PARTICIPANT	\N	PRESENT	0
128942	124956	11082Q	PARTICIPANT	\N	PRESENT	0
130232	130231	89017R	PARTICIPANT	\N	PRESENT	0
130173	130172	11044J	PARTICIPANT	\N	PRESENT	0
130174	130172	14281W	PARTICIPANT	\N	PRESENT	0
130238	130236	04086Q	PARTICIPANT	\N	PRESENT	0
130242	130239	04086Q	PARTICIPANT	\N	PRESENT	0
130246	130244	04086Q	PARTICIPANT	\N	PRESENT	0
130248	130247	01016M	PARTICIPANT	\N	PRESENT	0
130274	130273	04071H	PARTICIPANT	\N	PRESENT	0
133133	133132	08025T	PARTICIPANT	\N	EXCUSE	0
133134	133132	04085P	PARTICIPANT	\N	PRESENT	0
133135	133132	05008E	PRESIDENT	0	PRESENT	0
133312	133311	14263U	PARTICIPANT	\N	PRESENT	0
133137	133132	11033F	PARTICIPANT	\N	PRESENT	0
133313	133311	14133K	PARTICIPANT	\N	PRESENT	0
133314	133311	11109J	PARTICIPANT	\N	PRESENT	0
133140	133132	04047H	PARTICIPANT	\N	PRESENT	0
133315	133311	04059M	PARTICIPANT	\N	PRESENT	0
133369	133311	11068S	PARTICIPANT	\N	PRESENT	0
133143	133132	99002P	PARTICIPANT	\N	PRESENT	0
133144	133132	11056N	PARTICIPANT	\N	EXCUSE	0
133145	133132	14259Y	PARTICIPANT	\N	PRESENT	0
133317	133311	01044R	PARTICIPANT	\N	PRESENT	0
133147	133132	14041T	PARTICIPANT	\N	PRESENT	0
133318	133311	08043V	PARTICIPANT	\N	PRESENT	0
133149	133132	01024M	PARTICIPANT	\N	EXCUSE	0
133150	133132	14215L	PARTICIPANT	\N	PRESENT	0
133151	133132	11034G	PARTICIPANT	\N	EXCUSE	0
133152	133132	08018U	PARTICIPANT	\N	PRESENT	0
133153	133132	11010L	PARTICIPANT	\N	PRESENT	0
133154	133132	01007L	PARTICIPANT	\N	PRESENT	0
133155	133132	11049P	PARTICIPANT	\N	PRESENT	0
133156	133132	08044W	PARTICIPANT	\N	EXCUSE	0
133157	133132	11084S	PARTICIPANT	\N	PRESENT	0
133319	133311	14089Y	PARTICIPANT	\N	PRESENT	0
133159	133132	04079R	PARTICIPANT	\N	PRESENT	0
133320	133311	14105F	PARTICIPANT	\N	PRESENT	0
133161	133132	14001X	PARTICIPANT	\N	PRESENT	0
133321	133311	11029K	PARTICIPANT	\N	PRESENT	0
133322	133311	95015C	PARTICIPANT	\N	PRESENT	0
133164	133132	14147R	PARTICIPANT	\N	PRESENT	0
133165	133132	95049N	PARTICIPANT	\N	PRESENT	0
133166	133132	08051V	PARTICIPANT	\N	PRESENT	0
133323	133311	92015P	PARTICIPANT	\N	PRESENT	0
133168	133132	07034Q	PARTICIPANT	\N	PRESENT	0
133169	133132	04074L	PARTICIPANT	\N	PRESENT	0
133170	133132	10015M	PARTICIPANT	\N	PRESENT	0
133171	133132	95063L	PARTICIPANT	\N	PRESENT	0
133324	133311	08024S	PARTICIPANT	\N	PRESENT	0
133173	133132	01028R	PARTICIPANT	\N	PRESENT	0
133174	133132	98035U	PARTICIPANT	\N	PRESENT	0
133175	133132	04056J	PARTICIPANT	\N	PRESENT	0
133176	133132	14275Y	PARTICIPANT	\N	PRESENT	0
133177	133132	04044E	PARTICIPANT	\N	PRESENT	0
133178	133132	11037K	PARTICIPANT	\N	PRESENT	0
133179	133132	92045V	PARTICIPANT	\N	PRESENT	0
133180	133132	95067Q	PARTICIPANT	\N	PRESENT	0
133370	133311	01043Q	PARTICIPANT	\N	PRESENT	0
133823	133822	11089X	PARTICIPANT	\N	PRESENT	0
137852	137517	11082Q	PARTICIPANT	\N	EXCUSE	0
133327	133311	14209N	PARTICIPANT	\N	PRESENT	0
137853	137517	04043D	PARTICIPANT	\N	PRESENT	0
133329	133311	11091R	PARTICIPANT	\N	PRESENT	0
137854	137517	01046T	PARTICIPANT	\N	EXCUSE	0
133331	133311	98042T	PARTICIPANT	\N	PRESENT	0
138716	138715	04059M	PARTICIPANT	\N	PRESENT	0
138717	138715	04036E	PARTICIPANT	\N	PRESENT	0
133334	133311	01025N	PARTICIPANT	\N	PRESENT	0
133335	133311	01037S	PARTICIPANT	\N	PRESENT	0
138718	138715	98022P	PARTICIPANT	\N	PRESENT	0
133337	133311	08035V	PARTICIPANT	\N	PRESENT	0
133338	133311	11089X	PARTICIPANT	\N	PRESENT	0
133339	133311	07026Q	PARTICIPANT	\N	PRESENT	0
133340	133311	14123H	PARTICIPANT	\N	PRESENT	0
133341	133311	14179A	PARTICIPANT	\N	PRESENT	0
138719	138715	04077P	PARTICIPANT	\N	PRESENT	0
133343	133311	14241N	PARTICIPANT	\N	EXCUSE	0
133344	133311	14061L	PARTICIPANT	\N	PRESENT	0
133345	133311	14073Q	PARTICIPANT	\N	PRESENT	0
133346	133311	08031R	PARTICIPANT	\N	EXCUSE	0
138720	138715	04042C	PARTICIPANT	\N	PRESENT	0
133348	133311	08039A	PARTICIPANT	\N	EXCUSE	0
133349	133311	08017T	PARTICIPANT	\N	PRESENT	0
133350	133311	14059S	PARTICIPANT	\N	PRESENT	0
133351	133311	08012N	PARTICIPANT	\N	PRESENT	0
133352	133311	14103D	PARTICIPANT	\N	PRESENT	0
133353	133311	11104D	PARTICIPANT	\N	PRESENT	0
133354	133311	14063N	PARTICIPANT	\N	PRESENT	0
133355	133311	04057K	PARTICIPANT	\N	PRESENT	0
133356	133311	11014C	PARTICIPANT	\N	PRESENT	0
133357	133311	14109K	PARTICIPANT	\N	PRESENT	0
133358	133311	04070G	PRESIDENT	0	PRESENT	0
138721	138715	86044G	PARTICIPANT	\N	PRESENT	0
138929	138928	01008M	PARTICIPANT	\N	PRESENT	0
138930	138928	11036J	PARTICIPANT	\N	PRESENT	0
133363	133311	14055N	PARTICIPANT	\N	PRESENT	0
138932	138928	14013P	PARTICIPANT	\N	EXCUSE	0
133365	133311	14229S	PARTICIPANT	\N	PRESENT	0
133366	133311	11043H	PARTICIPANT	\N	PRESENT	0
138933	138928	08068F	PARTICIPANT	\N	PRESENT	0
138934	138928	14207L	PARTICIPANT	\N	PRESENT	0
138935	138928	11101A	PARTICIPANT	\N	PRESENT	0
138936	138928	90003B	PARTICIPANT	\N	PRESENT	0
138937	138928	08028W	PARTICIPANT	\N	PRESENT	0
138938	138928	80013X	PARTICIPANT	\N	PRESENT	0
138939	138928	08038Y	PARTICIPANT	\N	PRESENT	0
138940	138928	04089T	PARTICIPANT	\N	PRESENT	0
138941	138928	14197C	PARTICIPANT	\N	PRESENT	0
138942	138928	11110B	PARTICIPANT	\N	PRESENT	0
138943	138928	14187A	PARTICIPANT	\N	PRESENT	0
138944	138928	14033T	PARTICIPANT	\N	EXCUSE	0
138945	138928	14081Q	PARTICIPANT	\N	PRESENT	0
138946	138928	04048J	PARTICIPANT	\N	PRESENT	0
138947	138928	11099A	PARTICIPANT	\N	PRESENT	0
138948	138928	04049K	PARTICIPANT	\N	EXCUSE	0
138949	138928	04094Q	PARTICIPANT	\N	PRESENT	0
138950	138928	11111C	PARTICIPANT	\N	PRESENT	0
138951	138928	08015R	PARTICIPANT	\N	PRESENT	0
138952	138928	11100Y	PRESIDENT	0	PRESENT	0
138953	138928	01061S	PARTICIPANT	\N	PRESENT	0
138954	138928	11098Y	PARTICIPANT	\N	PRESENT	0
139117	139115	11055M	PARTICIPANT	\N	PRESENT	0
139118	139115	01046T	PARTICIPANT	\N	PRESENT	0
139119	139115	04053F	PARTICIPANT	\N	PRESENT	0
138958	138928	08019V	PARTICIPANT	\N	PRESENT	0
138959	138928	14257W	PARTICIPANT	\N	PRESENT	0
139120	139115	14255U	PARTICIPANT	\N	PRESENT	0
138961	138928	04088S	PARTICIPANT	\N	PRESENT	0
138962	138928	98050T	PARTICIPANT	\N	PRESENT	0
138963	138928	11090Q	PARTICIPANT	\N	PRESENT	0
138965	138928	01058X	PARTICIPANT	\N	PRESENT	0
138966	138928	11094U	PARTICIPANT	\N	PRESENT	0
138967	138928	11066Q	PARTICIPANT	\N	PRESENT	0
139121	139115	04066L	PARTICIPANT	\N	PRESENT	0
139122	139115	00003C	PARTICIPANT	\N	EXCUSE	0
139123	139115	14053L	PARTICIPANT	\N	PRESENT	0
139124	139115	11103C	PARTICIPANT	\N	PRESENT	0
139126	139115	14195A	PARTICIPANT	\N	PRESENT	0
139127	139115	14267Y	PARTICIPANT	\N	PRESENT	0
139128	139115	11023D	PARTICIPANT	\N	PRESENT	0
139129	139115	11031D	PARTICIPANT	\N	PRESENT	0
139130	139115	08052W	PARTICIPANT	\N	PRESENT	0
139132	139115	04081K	PARTICIPANT	\N	PRESENT	0
139133	139115	98024R	PARTICIPANT	\N	PRESENT	0
139134	139115	10006L	PARTICIPANT	\N	PRESENT	0
139135	139115	04067M	PARTICIPANT	\N	PRESENT	0
139136	139115	14217N	PARTICIPANT	\N	PRESENT	0
139137	139115	14042U	PARTICIPANT	\N	PRESENT	0
139138	139115	14151M	PARTICIPANT	\N	PRESENT	0
139139	139115	12042Y	PARTICIPANT	\N	PRESENT	0
139140	139115	14281W	PARTICIPANT	\N	PRESENT	0
139141	139115	14087W	PARTICIPANT	\N	PRESENT	0
139142	139115	01003G	PARTICIPANT	\N	PRESENT	0
139143	139115	14034U	PARTICIPANT	\N	PRESENT	0
139144	139115	14231L	PARTICIPANT	\N	PRESENT	0
139145	139115	11061K	PARTICIPANT	\N	PRESENT	0
139146	139115	08048B	PARTICIPANT	\N	PRESENT	0
139147	139115	08041T	PARTICIPANT	\N	PRESENT	0
139148	139115	01011G	PARTICIPANT	\N	PRESENT	0
139149	139115	14026U	PARTICIPANT	\N	PRESENT	0
139150	139115	14213J	PARTICIPANT	\N	PRESENT	0
139151	139115	14121F	PARTICIPANT	\N	PRESENT	0
139152	139115	11112D	PARTICIPANT	\N	PRESENT	0
139154	139115	14018U	PARTICIPANT	\N	PRESENT	0
137858	137855	14249W	PARTICIPANT	\N	PRESENT	0
137859	137855	11014C	PARTICIPANT	\N	PRESENT	0
137884	137883	08015R	PARTICIPANT	\N	PRESENT	0
138029	137569	14028W	PARTICIPANT	\N	EXCUSE	0
138030	137569	04044E	PARTICIPANT	\N	EXCUSE	0
138560	138559	89017R	PARTICIPANT	\N	PRESENT	0
138561	138559	01031L	PRESIDENT	0	PRESENT	0
138562	138559	08014Q	PARTICIPANT	\N	PRESENT	0
138563	138559	14083S	PARTICIPANT	\N	PRESENT	0
138564	138559	14085U	PARTICIPANT	\N	PRESENT	0
138565	138559	11042G	PARTICIPANT	\N	PRESENT	0
138566	138559	04086Q	PARTICIPANT	\N	PRESENT	0
138567	138559	11070L	PARTICIPANT	\N	PRESENT	0
138568	138559	14327T	PARTICIPANT	\N	PRESENT	0
138569	138559	01027Q	PARTICIPANT	\N	PRESENT	0
138571	138559	11083R	PARTICIPANT	\N	PRESENT	0
138572	138559	14199E	PARTICIPANT	\N	PRESENT	0
138573	138559	01057W	PARTICIPANT	\N	PRESENT	0
138574	138559	08016S	PARTICIPANT	\N	PRESENT	0
138575	138559	11048N	PARTICIPANT	\N	PRESENT	0
138630	138559	11057P	PARTICIPANT	\N	PRESENT	0
138577	138570	01031L	PRESIDENT	0	PRESENT	0
138631	138559	14173T	PARTICIPANT	\N	PRESENT	0
138579	138570	01013J	PARTICIPANT	\N	PRESENT	0
138580	138570	11068S	PARTICIPANT	\N	PRESENT	0
138632	138559	98053W	PARTICIPANT	\N	EXCUSE	0
138582	138570	08014Q	PARTICIPANT	\N	PRESENT	0
138633	138559	99004R	PARTICIPANT	\N	EXCUSE	0
138584	138570	14175V	PARTICIPANT	\N	PRESENT	0
138585	138570	14083S	PARTICIPANT	\N	PRESENT	0
138586	138570	11053K	PARTICIPANT	\N	PRESENT	0
138587	138570	14085U	PARTICIPANT	\N	PRESENT	0
138588	138570	11042G	PARTICIPANT	\N	PRESENT	0
138634	138559	05008E	PARTICIPANT	\N	PRESENT	0
138590	138570	04086Q	PARTICIPANT	\N	PRESENT	0
138635	138559	14065Q	PARTICIPANT	\N	PRESENT	0
138592	138570	11070L	PARTICIPANT	\N	PRESENT	0
138636	138559	04038G	PARTICIPANT	\N	PRESENT	0
138637	138559	11056N	PARTICIPANT	\N	PRESENT	0
138638	138559	11113E	PARTICIPANT	\N	PRESENT	0
138596	138570	01027Q	PARTICIPANT	\N	PRESENT	0
138597	138570	04071H	PARTICIPANT	\N	PRESENT	0
138598	138570	11074Q	PARTICIPANT	\N	PRESENT	0
138599	138570	98053W	PARTICIPANT	\N	EXCUSE	0
138600	138570	11083R	PARTICIPANT	\N	PRESENT	0
138639	138559	14215L	PARTICIPANT	\N	PRESENT	0
138602	138570	01057W	PARTICIPANT	\N	PRESENT	0
138603	138570	08016S	PARTICIPANT	\N	PRESENT	0
138640	138559	11026G	PARTICIPANT	\N	PRESENT	0
138605	138570	11048N	PARTICIPANT	\N	PRESENT	0
138606	138570	99004R	PARTICIPANT	\N	PRESENT	0
138641	138559	14111D	PARTICIPANT	\N	PRESENT	0
138608	138570	14159V	PARTICIPANT	\N	PRESENT	0
138609	138570	07029T	PARTICIPANT	\N	PRESENT	0
138642	138559	01028R	PARTICIPANT	\N	PRESENT	0
138611	138570	08010L	PARTICIPANT	\N	PRESENT	0
138612	138570	08034U	PARTICIPANT	\N	PRESENT	0
138643	138559	04044E	PARTICIPANT	\N	PRESENT	0
138614	138570	98046X	PARTICIPANT	\N	PRESENT	0
138644	138559	11037K	PARTICIPANT	\N	PRESENT	0
138616	138570	08011M	PARTICIPANT	\N	PRESENT	0
138645	138570	04059M	RAPPORTEUR_AVIS	\N	PRESENT	0
138618	138570	08061X	PARTICIPANT	\N	PRESENT	0
138619	138570	01016M	PARTICIPANT	\N	PRESENT	0
138646	138570	92031P	RAPPORTEUR_AVIS	\N	PRESENT	0
138658	138559	04071H	PARTICIPANT	\N	PRESENT	0
138622	138570	11057P	PARTICIPANT	\N	PRESENT	0
138623	138570	14173T	PARTICIPANT	\N	PRESENT	0
138624	138570	04034C	PARTICIPANT	\N	PRESENT	0
138625	138559	08034U	PARTICIPANT	\N	PRESENT	0
138626	138559	11085T	PARTICIPANT	\N	PRESENT	0
138627	138559	08011M	PARTICIPANT	\N	PRESENT	0
138628	138559	01016M	PARTICIPANT	\N	PRESENT	0
138815	138814	14263U	PARTICIPANT	\N	PRESENT	0
138816	138814	14133K	PARTICIPANT	\N	PRESENT	0
138817	138814	11109J	PARTICIPANT	\N	PRESENT	0
138818	138814	04059M	PARTICIPANT	\N	PRESENT	0
138819	138814	11039M	PARTICIPANT	\N	PRESENT	0
138820	138814	01044R	PARTICIPANT	\N	PRESENT	0
138821	138814	08043V	PARTICIPANT	\N	PRESENT	0
138822	138814	14089Y	PARTICIPANT	\N	PRESENT	0
138823	138814	14105F	PARTICIPANT	\N	PRESENT	0
138824	138814	11029K	PARTICIPANT	\N	PRESENT	0
138825	138814	95015C	PARTICIPANT	\N	PRESENT	0
138826	138814	92015P	PARTICIPANT	\N	PRESENT	0
140056	140054	01044R	PARTICIPANT	\N	PRESENT	0
138828	138814	14201E	PARTICIPANT	\N	PRESENT	0
140055	140054	11109J	PARTICIPANT	\N	PRESENT	0
138830	138814	14209N	PARTICIPANT	\N	PRESENT	0
138831	138814	14079W	PARTICIPANT	\N	PRESENT	0
138832	138814	11091R	PARTICIPANT	\N	PRESENT	0
138833	138814	87003B	PARTICIPANT	\N	PRESENT	0
138834	138814	98042T	PARTICIPANT	\N	PRESENT	0
138835	138814	14249W	PARTICIPANT	\N	PRESENT	0
138836	138814	01041N	PARTICIPANT	\N	PRESENT	0
138837	138814	01025N	PARTICIPANT	\N	PRESENT	0
138838	138814	01037S	PARTICIPANT	\N	PRESENT	0
138839	138814	89029V	PARTICIPANT	\N	PRESENT	0
138840	138814	08035V	PARTICIPANT	\N	PRESENT	0
140057	140054	08043V	PARTICIPANT	\N	PRESENT	0
138842	138814	07026Q	PARTICIPANT	\N	PRESENT	0
138843	138814	14123H	PARTICIPANT	\N	PRESENT	0
138844	138814	14179A	PARTICIPANT	\N	PRESENT	0
140058	140054	14089Y	PARTICIPANT	\N	PRESENT	0
138846	138814	14241N	PARTICIPANT	\N	PRESENT	0
138847	138814	14061L	PARTICIPANT	\N	PRESENT	0
138848	138814	14073Q	PARTICIPANT	\N	PRESENT	0
138849	138814	08031R	PARTICIPANT	\N	PRESENT	0
138850	138814	12041X	PARTICIPANT	\N	EXCUSE	0
140059	140054	11029K	PARTICIPANT	\N	PRESENT	0
138852	138814	08017T	PARTICIPANT	\N	PRESENT	0
138853	138814	14059S	PARTICIPANT	\N	PRESENT	0
138854	138814	08012N	PARTICIPANT	\N	PRESENT	0
138855	138814	14103D	PARTICIPANT	\N	PRESENT	0
138856	138814	11104D	PARTICIPANT	\N	PRESENT	0
138857	138814	14063N	PARTICIPANT	\N	PRESENT	0
138858	138814	04057K	PARTICIPANT	\N	PRESENT	0
138859	138814	11014C	PARTICIPANT	\N	PRESENT	0
138860	138814	14109K	PARTICIPANT	\N	PRESENT	0
138861	138814	04070G	PRESIDENT	0	PRESENT	0
138862	138814	92040Q	PARTICIPANT	\N	PRESENT	0
138863	138814	14191V	PARTICIPANT	\N	PRESENT	0
138864	138814	83047W	PARTICIPANT	\N	PRESENT	0
138865	138814	14235Q	PARTICIPANT	\N	PRESENT	0
140060	140054	95015C	PARTICIPANT	\N	PRESENT	0
138867	138814	04033B	PARTICIPANT	\N	PRESENT	0
138868	138814	14229S	PARTICIPANT	\N	PRESENT	0
138869	138814	11043H	PARTICIPANT	\N	PRESENT	0
140061	140054	92015P	PARTICIPANT	\N	EXCUSE	0
140062	140054	08024S	PARTICIPANT	\N	PRESENT	0
140063	140054	11091R	PARTICIPANT	\N	EXCUSE	0
140064	140054	98042T	PARTICIPANT	\N	EXCUSE	0
140065	140054	14249W	PARTICIPANT	\N	PRESENT	0
140066	140054	01025N	PARTICIPANT	\N	PRESENT	0
140067	140054	01037S	PARTICIPANT	\N	PRESENT	0
140068	140054	11089X	PARTICIPANT	\N	PRESENT	0
140069	140054	07026Q	PARTICIPANT	\N	PRESENT	0
140070	140054	14123H	PARTICIPANT	\N	PRESENT	0
140071	140054	14179A	PARTICIPANT	\N	PRESENT	0
140072	140054	14241N	PARTICIPANT	\N	PRESENT	0
140073	140054	14061L	PARTICIPANT	\N	PRESENT	0
140074	140054	14073Q	PARTICIPANT	\N	PRESENT	0
140075	140054	08031R	PARTICIPANT	\N	PRESENT	0
140076	140054	12041X	PARTICIPANT	\N	EXCUSE	0
140077	140054	08017T	PARTICIPANT	\N	PRESENT	0
140078	140054	08012N	PARTICIPANT	\N	PRESENT	0
140079	140054	14103D	PARTICIPANT	\N	PRESENT	0
140080	140054	11104D	PARTICIPANT	\N	PRESENT	0
140081	140054	14063N	PARTICIPANT	\N	PRESENT	0
140082	140054	04057K	PARTICIPANT	\N	EXCUSE	0
140083	140054	11014C	PARTICIPANT	\N	PRESENT	0
140084	140054	14109K	PARTICIPANT	\N	PRESENT	0
140085	140054	04070G	PRESIDENT	0	PRESENT	0
140086	140054	14191V	PARTICIPANT	\N	PRESENT	0
140087	140054	14229S	PARTICIPANT	\N	PRESENT	0
140088	140054	11043H	PARTICIPANT	\N	PRESENT	0
140160	140159	08061X	PARTICIPANT	\N	PRESENT	0
140161	140159	11012A	PARTICIPANT	\N	PRESENT	0
140841	140840	08055A	PARTICIPANT	\N	PRESENT	0
140842	140840	11114F	PARTICIPANT	\N	PRESENT	0
140843	140840	98023Q	PARTICIPANT	\N	PRESENT	0
140844	140840	11059R	PARTICIPANT	\N	PRESENT	0
140845	140840	14219Q	PARTICIPANT	\N	PRESENT	0
140846	140840	14031R	PARTICIPANT	\N	PRESENT	0
140847	140840	08009T	PRESIDENT	0	PRESENT	0
140848	140840	14169X	PARTICIPANT	\N	PRESENT	0
140849	140840	05012A	PARTICIPANT	\N	PRESENT	0
140850	140840	14331P	PARTICIPANT	\N	PRESENT	0
141019	141018	01041N	PARTICIPANT	\N	PRESENT	0
130698	130697	14119M	PARTICIPANT	\N	PRESENT	0
130805	130803	14263U	PARTICIPANT	\N	PRESENT	0
130807	130806	14103D	PARTICIPANT	\N	PRESENT	0
132467	132466	95059Q	PARTICIPANT	\N	PRESENT	0
132468	132466	11054L	PARTICIPANT	\N	PRESENT	0
132469	132466	92020L	PARTICIPANT	\N	PRESENT	0
132470	132466	92018S	PARTICIPANT	\N	PRESENT	0
132471	132466	01014K	PARTICIPANT	\N	PRESENT	0
132472	132466	92031P	PARTICIPANT	\N	PRESENT	0
132473	132466	11064N	PARTICIPANT	\N	PRESENT	0
132474	132466	04042C	PARTICIPANT	\N	PRESENT	0
132475	132466	11076S	PARTICIPANT	\N	PRESENT	0
132476	132466	07024N	PARTICIPANT	\N	PRESENT	0
143687	143686	89017R	PARTICIPANT	\N	PRESENT	0
143688	143686	01031L	PRESIDENT	0	PRESENT	0
147989	147987	01008M	PARTICIPANT	\N	EXCUSE	0
143690	143686	01013J	PARTICIPANT	\N	PRESENT	0
143691	143686	11068S	PARTICIPANT	\N	PRESENT	0
147990	147987	11036J	PARTICIPANT	\N	PRESENT	0
147991	147987	11081P	PARTICIPANT	\N	PRESENT	0
148101	147668	08028W	PARTICIPANT	\N	EXCUSE	0
143695	143686	14175V	PARTICIPANT	\N	EXCUSE	0
143696	143686	14083S	PARTICIPANT	\N	PRESENT	0
143697	143686	11053K	PARTICIPANT	\N	PRESENT	0
143698	143686	14085U	PARTICIPANT	\N	PRESENT	0
143699	143686	11042G	PARTICIPANT	\N	PRESENT	0
147993	147987	08068F	PARTICIPANT	\N	PRESENT	0
143701	143686	04086Q	PARTICIPANT	\N	PRESENT	0
147994	147987	14207L	PARTICIPANT	\N	PRESENT	0
147995	147987	11101A	PARTICIPANT	\N	PRESENT	0
147996	147987	90003B	PARTICIPANT	\N	PRESENT	0
148115	147987	08028W	PARTICIPANT	\N	EXCUSE	0
147998	147987	80013X	PARTICIPANT	\N	PRESENT	0
160972	149495	08051V	PARTICIPANT	\N	PRESENT	0
143708	143686	04071H	PARTICIPANT	\N	PRESENT	0
143709	143686	11074Q	PARTICIPANT	\N	PRESENT	0
143710	143686	98053W	PARTICIPANT	\N	EXCUSE	0
143711	143686	11083R	PARTICIPANT	\N	PRESENT	0
143712	143686	14199E	PARTICIPANT	\N	PRESENT	0
143713	143686	01057W	PARTICIPANT	\N	PRESENT	0
143714	143686	08016S	PARTICIPANT	\N	PRESENT	0
148000	147987	08038Y	PARTICIPANT	\N	PRESENT	0
143716	143686	11048N	PARTICIPANT	\N	PRESENT	0
143717	143686	99004R	PARTICIPANT	\N	PRESENT	0
148001	147987	04089T	PARTICIPANT	\N	PRESENT	0
143719	143686	14159V	PARTICIPANT	\N	PRESENT	0
143720	143686	07029T	PARTICIPANT	\N	EXCUSE	0
148002	147987	14197C	PARTICIPANT	\N	PRESENT	0
143722	143686	08010L	PARTICIPANT	\N	PRESENT	0
160973	149495	14071N	PARTICIPANT	\N	PRESENT	0
143724	143686	01048V	PARTICIPANT	\N	PRESENT	0
143725	143686	98046X	PARTICIPANT	\N	PRESENT	0
148004	147987	14187A	PARTICIPANT	\N	PRESENT	0
143727	143686	08011M	PARTICIPANT	\N	PRESENT	0
148005	147987	14033T	PARTICIPANT	\N	PRESENT	0
143729	143686	08061X	PARTICIPANT	\N	EXCUSE	0
143730	143686	01016M	PARTICIPANT	\N	PRESENT	0
143731	143686	14225N	PARTICIPANT	\N	PRESENT	0
165637	165636	89017R	PARTICIPANT	\N	EXCUSE	0
143733	143686	11057P	PARTICIPANT	\N	PRESENT	0
143734	143686	14173T	PARTICIPANT	\N	PRESENT	0
165638	165636	01031L	PRESIDENT	0	PRESENT	0
165639	165636	05004A	PARTICIPANT	\N	PRESENT	0
148007	147987	11099A	PARTICIPANT	\N	PRESENT	0
148008	147987	04049K	PARTICIPANT	\N	PRESENT	0
165640	165636	01013J	PARTICIPANT	\N	PRESENT	0
148010	147987	11111C	PARTICIPANT	\N	PRESENT	0
148011	147987	08015R	PARTICIPANT	\N	PRESENT	0
148012	147987	11100Y	PARTICIPANT	\N	PRESENT	0
148013	147987	01061S	PARTICIPANT	\N	EXCUSE	0
148014	147987	11098Y	PARTICIPANT	\N	PRESENT	0
148015	147987	01043Q	PARTICIPANT	\N	PRESENT	0
148016	147987	11077T	PARTICIPANT	\N	PRESENT	0
148017	147987	14205J	PARTICIPANT	\N	PRESENT	0
148018	147987	08019V	PARTICIPANT	\N	PRESENT	0
148019	147987	14257W	PARTICIPANT	\N	PRESENT	0
148020	147987	08021P	PARTICIPANT	\N	PRESENT	0
148021	147987	04088S	PARTICIPANT	\N	PRESENT	0
148022	147987	98050T	PARTICIPANT	\N	PRESENT	0
148023	147987	11090Q	PARTICIPANT	\N	PRESENT	0
148024	147987	11046L	PARTICIPANT	\N	PRESENT	0
148025	147987	01058X	PARTICIPANT	\N	PRESENT	0
148026	147987	11094U	PARTICIPANT	\N	PRESENT	0
148027	147987	11066Q	PARTICIPANT	\N	PRESENT	0
165641	165636	11068S	PARTICIPANT	\N	PRESENT	0
165642	165636	11040E	PARTICIPANT	\N	PRESENT	0
165643	165636	08014Q	PARTICIPANT	\N	PRESENT	0
165644	165636	14167V	PARTICIPANT	\N	PRESENT	0
165645	165636	14175V	PARTICIPANT	\N	PRESENT	0
165646	165636	14083S	PARTICIPANT	\N	PRESENT	0
165647	165636	11053K	PARTICIPANT	\N	PRESENT	0
165648	165636	14085U	PARTICIPANT	\N	PRESENT	0
165649	165636	11042G	PARTICIPANT	\N	PRESENT	0
165650	165636	88008L	PARTICIPANT	\N	PRESENT	0
165651	165636	04086Q	PARTICIPANT	\N	PRESENT	0
165687	165686	14263U	PARTICIPANT	\N	PRESENT	0
165653	165636	11070L	PARTICIPANT	\N	PRESENT	0
165654	165636	11088W	PARTICIPANT	\N	PRESENT	0
165655	165636	14327T	PARTICIPANT	\N	PRESENT	0
165657	165636	01027Q	PARTICIPANT	\N	PRESENT	0
165658	165636	04071H	PARTICIPANT	\N	PRESENT	0
165659	165636	11074Q	PARTICIPANT	\N	PRESENT	0
165660	165636	98053W	PARTICIPANT	\N	PRESENT	0
165661	165636	11083R	PARTICIPANT	\N	PRESENT	0
165662	165636	14199E	PARTICIPANT	\N	PRESENT	0
165663	165636	01057W	PARTICIPANT	\N	PRESENT	0
165664	165636	08016S	PARTICIPANT	\N	PRESENT	0
165689	165686	04059M	PARTICIPANT	\N	PRESENT	0
165666	165636	11048N	PARTICIPANT	\N	PRESENT	0
165667	165636	99004R	PARTICIPANT	\N	PRESENT	0
165668	165636	04061F	PARTICIPANT	\N	PRESENT	0
165669	165636	14159V	PARTICIPANT	\N	PRESENT	0
165670	165636	07029T	PARTICIPANT	\N	PRESENT	0
165671	165636	14277B	PARTICIPANT	\N	PRESENT	0
165690	165686	11039M	PARTICIPANT	\N	PRESENT	0
165673	165636	08034U	PARTICIPANT	\N	PRESENT	0
165674	165636	01048V	PARTICIPANT	\N	PRESENT	0
165675	165636	98046X	PARTICIPANT	\N	PRESENT	0
165677	165636	08011M	PARTICIPANT	\N	PRESENT	0
165678	165636	08073C	PARTICIPANT	\N	PRESENT	0
165679	165636	08061X	PARTICIPANT	\N	PRESENT	0
165680	165636	01016M	PARTICIPANT	\N	PRESENT	0
165682	165636	11012A	PARTICIPANT	\N	PRESENT	0
165683	165636	11057P	PARTICIPANT	\N	PRESENT	0
165684	165636	14173T	PARTICIPANT	\N	PRESENT	0
165685	165636	04034C	PARTICIPANT	\N	PRESENT	0
165691	165686	01044R	PARTICIPANT	\N	PRESENT	0
165692	165686	08043V	PARTICIPANT	\N	EXCUSE	0
165693	165686	14089Y	PARTICIPANT	\N	PRESENT	0
165694	165686	14105F	PARTICIPANT	\N	PRESENT	0
165695	165686	11029K	PARTICIPANT	\N	PRESENT	0
165696	165686	95015C	PARTICIPANT	\N	PRESENT	0
165697	165686	92015P	PARTICIPANT	\N	PRESENT	0
165698	165686	08024S	PARTICIPANT	\N	PRESENT	0
165699	165686	14201E	PARTICIPANT	\N	PRESENT	0
165700	165686	14329V	PARTICIPANT	\N	PRESENT	0
165701	165686	14209N	PARTICIPANT	\N	PRESENT	0
165704	165686	87003B	PARTICIPANT	\N	PRESENT	0
165705	165686	98042T	PARTICIPANT	\N	PRESENT	0
165706	165686	14249W	PARTICIPANT	\N	EXCUSE	0
165707	165686	01041N	PARTICIPANT	\N	PRESENT	0
165708	165686	01025N	PARTICIPANT	\N	PRESENT	0
165709	165686	89029V	PARTICIPANT	\N	PRESENT	0
165712	165686	07026Q	PARTICIPANT	\N	EXCUSE	0
165713	165686	14123H	PARTICIPANT	\N	PRESENT	0
165714	165686	14179A	PARTICIPANT	\N	PRESENT	0
165716	165686	14241N	PARTICIPANT	\N	PRESENT	0
165717	165686	14061L	PARTICIPANT	\N	PRESENT	0
165718	165686	14073Q	PARTICIPANT	\N	PRESENT	0
165719	165686	08031R	PARTICIPANT	\N	PRESENT	0
165720	165686	12041X	PARTICIPANT	\N	PRESENT	0
165721	165686	08039A	PARTICIPANT	\N	PRESENT	0
165722	165686	08017T	PARTICIPANT	\N	PRESENT	0
165723	165686	14059S	PARTICIPANT	\N	PRESENT	0
165724	165686	08012N	PARTICIPANT	\N	PRESENT	0
165725	165686	14103D	PARTICIPANT	\N	PRESENT	0
165726	165686	11104D	PARTICIPANT	\N	PRESENT	0
165727	165686	14063N	PARTICIPANT	\N	PRESENT	0
165728	165686	04057K	PARTICIPANT	\N	PRESENT	0
165729	165686	11014C	PARTICIPANT	\N	PRESENT	0
165730	165686	14109K	PARTICIPANT	\N	PRESENT	0
165731	165686	04070G	PARTICIPANT	\N	PRESENT	0
165732	165686	92040Q	PARTICIPANT	\N	PRESENT	0
140110	139236	14207L	PARTICIPANT	\N	PRESENT	0
140111	139236	11109J	PARTICIPANT	\N	PRESENT	0
140112	139236	11023D	PARTICIPANT	\N	PRESENT	0
140113	139236	14039A	PARTICIPANT	\N	PRESENT	0
140114	139236	12042Y	PARTICIPANT	\N	PRESENT	0
140115	139236	14269B	PARTICIPANT	\N	PRESENT	0
140116	139236	04092N	PARTICIPANT	\N	PRESENT	0
140117	139236	01034P	PARTICIPANT	\N	PRESENT	0
140118	139236	11061K	PARTICIPANT	\N	PRESENT	0
140119	139236	08052W	PARTICIPANT	\N	PRESENT	0
140120	139236	14281W	PARTICIPANT	\N	PRESENT	0
140121	139236	14227Q	PARTICIPANT	\N	PRESENT	0
140122	139236	14159V	PARTICIPANT	\N	PRESENT	0
140123	139236	11055M	PARTICIPANT	\N	PRESENT	0
140124	139236	08049C	PARTICIPANT	\N	PRESENT	0
140125	139236	01046T	PARTICIPANT	\N	PRESENT	0
140126	139236	11093T	PARTICIPANT	\N	PRESENT	0
140127	139236	14267Y	PARTICIPANT	\N	PRESENT	0
140128	139236	14042U	PARTICIPANT	\N	PRESENT	0
140129	139236	14103D	PARTICIPANT	\N	PRESENT	0
140130	139236	01027Q	PARTICIPANT	\N	PRESENT	0
140131	139236	98024R	PARTICIPANT	\N	PRESENT	0
140132	139236	14071N	PARTICIPANT	\N	PRESENT	0
140133	139236	14087W	PARTICIPANT	\N	PRESENT	0
140134	139236	10006L	PARTICIPANT	\N	PRESENT	0
140135	139236	04043D	PARTICIPANT	\N	PRESENT	0
140136	139236	11103C	PARTICIPANT	\N	PRESENT	0
140137	139236	97011G	PARTICIPANT	\N	PRESENT	0
140138	139236	14217N	PARTICIPANT	\N	PRESENT	0
140139	139236	14059S	PARTICIPANT	\N	PRESENT	0
140140	139236	14265W	PARTICIPANT	\N	PRESENT	0
140141	139236	08048B	PARTICIPANT	\N	PRESENT	0
140142	139236	08015R	PARTICIPANT	\N	PRESENT	0
140143	139236	14213J	PARTICIPANT	\N	PRESENT	0
140144	139236	11091R	PARTICIPANT	\N	PRESENT	0
140145	139236	14223L	PARTICIPANT	\N	PRESENT	0
140146	139236	14221J	PARTICIPANT	\N	PRESENT	0
140149	139236	14041T	PARTICIPANT	\N	PRESENT	0
140151	139236	04088S	PARTICIPANT	\N	PRESENT	0
140152	139236	08019V	PARTICIPANT	\N	PRESENT	0
140153	139236	14135M	PARTICIPANT	\N	PRESENT	0
140154	139236	14195A	PARTICIPANT	\N	PRESENT	0
140155	139236	14031R	PARTICIPANT	\N	PRESENT	0
140156	139236	14231L	PARTICIPANT	\N	PRESENT	0
140157	139236	14018U	PARTICIPANT	\N	PRESENT	0
140158	139236	14063N	PARTICIPANT	\N	PRESENT	0
140164	139236	14179A	PARTICIPANT	\N	PRESENT	0
140165	139236	14219Q	PARTICIPANT	\N	PRESENT	0
140166	139236	14191V	PARTICIPANT	\N	PRESENT	0
140167	139236	07026Q	PARTICIPANT	\N	PRESENT	0
140168	139236	14079W	PARTICIPANT	\N	PRESENT	0
140170	139236	14111D	PARTICIPANT	\N	PRESENT	0
140173	139236	11112D	PARTICIPANT	\N	PRESENT	0
140174	139236	14331P	PARTICIPANT	\N	PRESENT	0
140189	139236	14089Y	PARTICIPANT	\N	PRESENT	0
140190	139236	14073Q	PARTICIPANT	\N	PRESENT	0
140192	139236	14109K	PARTICIPANT	\N	PRESENT	0
140194	139236	11066Q	PARTICIPANT	\N	PRESENT	0
140195	139236	11054L	PARTICIPANT	\N	PRESENT	0
140196	139236	14241N	PARTICIPANT	\N	PRESENT	0
140197	139236	80013X	PARTICIPANT	\N	PRESENT	0
140198	139236	04053F	PARTICIPANT	\N	PRESENT	0
140199	139236	14271U	PARTICIPANT	\N	PRESENT	0
140200	139236	08055A	PARTICIPANT	\N	PRESENT	0
140201	139236	14119M	PARTICIPANT	\N	PRESENT	0
140202	139236	14069U	PARTICIPANT	\N	PRESENT	0
140203	139236	04067M	PARTICIPANT	\N	PRESENT	0
140204	139236	08016S	PARTICIPANT	\N	PRESENT	0
140205	139236	14030Q	PARTICIPANT	\N	PRESENT	0
140207	139236	01022K	PARTICIPANT	\N	PRESENT	0
140209	139236	98050T	PARTICIPANT	\N	PRESENT	0
140210	139236	11101A	PARTICIPANT	\N	PRESENT	0
140226	139236	11044J	PARTICIPANT	\N	PRESENT	0
140227	139236	11104D	PARTICIPANT	\N	PRESENT	0
140228	139236	01028R	PARTICIPANT	\N	PRESENT	0
140229	139236	14259Y	PARTICIPANT	\N	PRESENT	0
140230	139236	11097X	PARTICIPANT	\N	PRESENT	0
140247	139236	14061L	PARTICIPANT	\N	PRESENT	0
140248	139236	01014K	PARTICIPANT	\N	PRESENT	0
140249	139236	07024N	PARTICIPANT	\N	PRESENT	0
140250	139236	89017R	PARTICIPANT	\N	PRESENT	0
140251	139236	92045V	PARTICIPANT	\N	PRESENT	0
140252	139236	88008L	PARTICIPANT	\N	PRESENT	0
140253	139236	11084S	PARTICIPANT	\N	PRESENT	0
140254	139236	14205J	PARTICIPANT	\N	PRESENT	0
140269	139236	13002U	PARTICIPANT	\N	PRESENT	0
140290	139236	07029T	PARTICIPANT	\N	PRESENT	0
140420	139237	14179A	PARTICIPANT	\N	PRESENT	0
140421	139237	80027E	PARTICIPANT	\N	PRESENT	0
140422	139237	14097Y	PARTICIPANT	\N	PRESENT	0
140423	139237	98022P	PARTICIPANT	\N	PRESENT	0
140424	139237	11066Q	PARTICIPANT	\N	PRESENT	0
140425	139237	11032E	PARTICIPANT	\N	PRESENT	0
140426	139237	98029W	PARTICIPANT	\N	PRESENT	0
140427	139237	07026Q	PARTICIPANT	\N	PRESENT	0
140428	139237	01011G	PARTICIPANT	\N	PRESENT	0
140429	139237	11023D	PARTICIPANT	\N	PRESENT	0
140430	139237	14103D	PARTICIPANT	\N	PRESENT	0
140431	139237	01056V	PARTICIPANT	\N	PRESENT	0
140432	139237	11105E	PARTICIPANT	\N	PRESENT	0
140433	139237	08022Q	PARTICIPANT	\N	PRESENT	0
140434	139237	11093T	PARTICIPANT	\N	PRESENT	0
140435	139237	14267Y	PARTICIPANT	\N	PRESENT	0
140436	139237	01043Q	PARTICIPANT	\N	PRESENT	0
140437	139237	07024N	PARTICIPANT	\N	PRESENT	0
140438	139237	14191V	PARTICIPANT	\N	PRESENT	0
140439	139237	04088S	PARTICIPANT	\N	PRESENT	0
140440	139237	14195A	PARTICIPANT	\N	PRESENT	0
140441	139237	14227Q	PARTICIPANT	\N	PRESENT	0
140442	139237	89029V	PARTICIPANT	\N	PRESENT	0
140443	139237	11027H	PARTICIPANT	\N	PRESENT	0
140444	139237	05004A	PARTICIPANT	\N	PRESENT	0
140445	139237	11090Q	PARTICIPANT	\N	PRESENT	0
140446	139237	14259Y	PARTICIPANT	\N	PRESENT	0
140447	139237	14215L	PARTICIPANT	\N	PRESENT	0
140449	139237	14061L	PARTICIPANT	\N	PRESENT	0
140450	139237	11091R	PARTICIPANT	\N	PRESENT	0
140451	139237	04097T	PARTICIPANT	\N	PRESENT	0
140452	139237	11101A	PARTICIPANT	\N	PRESENT	0
140453	139237	11103C	PARTICIPANT	\N	PRESENT	0
140454	139237	92045V	PARTICIPANT	\N	PRESENT	0
140455	139237	04057K	PARTICIPANT	\N	PRESENT	0
140456	139237	14105F	PARTICIPANT	\N	PRESENT	0
140457	139237	08052W	PARTICIPANT	\N	PRESENT	0
140458	139237	04092N	PARTICIPANT	\N	PRESENT	0
140459	139237	14107H	PARTICIPANT	\N	PRESENT	0
140460	139237	11054L	PARTICIPANT	\N	PRESENT	0
140461	139237	07029T	PARTICIPANT	\N	PRESENT	0
140462	139237	14271U	PARTICIPANT	\N	PRESENT	0
140463	139237	04086Q	PARTICIPANT	\N	PRESENT	0
140464	139237	80013X	PARTICIPANT	\N	PRESENT	0
140465	139237	83042R	PARTICIPANT	\N	PRESENT	0
140466	139237	14133K	PARTICIPANT	\N	PRESENT	0
140467	139237	08034U	PARTICIPANT	\N	PRESENT	0
140468	139237	14207L	PARTICIPANT	\N	PRESENT	0
140469	139237	11042G	PARTICIPANT	\N	PRESENT	0
140470	139237	99004R	PARTICIPANT	\N	PRESENT	0
140471	139237	14041T	PARTICIPANT	\N	PRESENT	0
140472	139237	08018U	PARTICIPANT	\N	PRESENT	0
140473	139237	14187A	PARTICIPANT	\N	PRESENT	0
140474	139237	14111D	PARTICIPANT	\N	PRESENT	0
140475	139237	96004D	PARTICIPANT	\N	PRESENT	0
140476	139237	14033T	PARTICIPANT	\N	PRESENT	0
140477	139237	14249W	PARTICIPANT	\N	PRESENT	0
140478	139237	11100Y	PARTICIPANT	\N	PRESENT	0
140479	139237	77002U	PARTICIPANT	\N	PRESENT	0
140418	139237	86034E	PARTICIPANT	\N	PRESENT	0
140419	139237	14223L	PARTICIPANT	\N	PRESENT	0
140480	139237	14217N	PARTICIPANT	\N	PRESENT	0
140481	139237	14265W	PARTICIPANT	\N	PRESENT	0
140482	139237	11097X	PARTICIPANT	\N	PRESENT	0
140483	139237	08048B	PARTICIPANT	\N	PRESENT	0
140484	139237	14071N	PARTICIPANT	\N	PRESENT	0
140485	139237	14251Q	PARTICIPANT	\N	PRESENT	0
140486	139237	14031R	PARTICIPANT	\N	PRESENT	0
140487	139237	86044G	PARTICIPANT	\N	PRESENT	0
140488	139237	01058X	PARTICIPANT	\N	PRESENT	0
140489	139237	05008E	PARTICIPANT	\N	PRESENT	0
140490	139237	95035G	PARTICIPANT	\N	PRESENT	0
140491	139237	14059S	PARTICIPANT	\N	PRESENT	0
140493	139237	97011G	PARTICIPANT	\N	PRESENT	0
140495	139237	08015R	PARTICIPANT	\N	PRESENT	0
140496	139237	14213J	PARTICIPANT	\N	PRESENT	0
140497	139237	92040Q	PARTICIPANT	\N	PRESENT	0
140498	139237	11088W	PARTICIPANT	\N	PRESENT	0
140500	139237	01008M	PARTICIPANT	\N	PRESENT	0
140501	139237	92031P	PARTICIPANT	\N	PRESENT	0
129890	129889	95049N	PARTICIPANT	\N	PRESENT	0
129891	129889	95063L	PARTICIPANT	\N	PRESENT	0
129892	129889	08051V	PARTICIPANT	\N	PRESENT	0
129893	129889	05008E	PARTICIPANT	\N	PRESENT	0
129994	129993	01044R	PARTICIPANT	\N	PRESENT	0
129995	129993	11029K	PARTICIPANT	\N	PRESENT	0
129996	129993	14038Y	PARTICIPANT	\N	PRESENT	0
129997	129993	04067M	PARTICIPANT	\N	PRESENT	0
129998	129993	14241N	PARTICIPANT	\N	PRESENT	0
130164	120701	01027Q	PARTICIPANT	\N	EXCUSE	0
130165	120701	11054L	PARTICIPANT	\N	EXCUSE	0
130166	120701	04043D	PARTICIPANT	\N	EXCUSE	0
130167	120701	96003C	PARTICIPANT	\N	EXCUSE	0
130168	120701	11023D	PARTICIPANT	\N	EXCUSE	0
135555	135554	08014Q	PARTICIPANT	\N	PRESENT	0
135556	135554	08069G	PARTICIPANT	\N	PRESENT	0
139155	139115	11067R	PARTICIPANT	\N	EXCUSE	0
139156	139115	14223L	PARTICIPANT	\N	PRESENT	0
139157	139115	04092N	PRESIDENT	0	PRESENT	0
139158	139115	14265W	PARTICIPANT	\N	PRESENT	0
139159	139115	14119M	PARTICIPANT	\N	PRESENT	0
139160	139115	14071N	PARTICIPANT	\N	PRESENT	0
139161	139115	07032N	PARTICIPANT	\N	PRESENT	0
139162	139115	04043D	PARTICIPANT	\N	PRESENT	0
139163	139115	14271U	PARTICIPANT	\N	PRESENT	0
144208	144193	11044J	PARTICIPANT	\N	PRESENT	0
139165	139115	11093T	PARTICIPANT	\N	PRESENT	0
139166	139115	11097X	PARTICIPANT	\N	PRESENT	0
139167	139115	04045F	PARTICIPANT	\N	PRESENT	0
139168	139115	14227Q	PARTICIPANT	\N	PRESENT	0
139169	139115	01034P	PARTICIPANT	\N	PRESENT	0
144209	144193	11097X	PARTICIPANT	\N	PRESENT	0
139171	139115	11063M	PARTICIPANT	\N	PRESENT	0
139172	139115	14269B	PARTICIPANT	\N	PRESENT	0
144753	144752	11054L	PARTICIPANT	\N	PRESENT	0
145013	145012	07024N	PARTICIPANT	\N	PRESENT	0
145014	145012	01014K	PARTICIPANT	\N	PRESENT	0
144197	144193	08052W	PARTICIPANT	\N	PRESENT	0
144198	144193	01059Y	PARTICIPANT	\N	PRESENT	0
145015	145012	98021N	PARTICIPANT	\N	PRESENT	0
145017	145016	11027H	PARTICIPANT	\N	PRESENT	0
144201	144193	14281W	PARTICIPANT	\N	PRESENT	0
144202	144193	11061K	PARTICIPANT	\N	PRESENT	0
144203	144193	04092N	PARTICIPANT	\N	PRESENT	0
145713	145712	04045F	PARTICIPANT	\N	PRESENT	0
145715	145714	14026U	PARTICIPANT	\N	PRESENT	0
145717	145716	14026U	PARTICIPANT	\N	PRESENT	0
144207	144193	01034P	PARTICIPANT	\N	PRESENT	0
145719	145718	14026U	PARTICIPANT	\N	PRESENT	0
145720	145718	04045F	PARTICIPANT	\N	PRESENT	0
146213	146212	14259Y	PARTICIPANT	\N	PRESENT	0
147236	147235	05008E	PRESIDENT	0	PRESENT	0
147237	147235	14069U	PARTICIPANT	\N	PRESENT	0
147238	147235	11056N	PARTICIPANT	\N	EXCUSE	0
147239	147235	14259Y	PARTICIPANT	\N	EXCUSE	0
147240	147235	11035H	PARTICIPANT	\N	PRESENT	0
147241	147235	11113E	PARTICIPANT	\N	PRESENT	0
147242	147235	01024M	PARTICIPANT	\N	PRESENT	0
147243	147235	14215L	PARTICIPANT	\N	PRESENT	0
147244	147235	11034G	PARTICIPANT	\N	PRESENT	0
147245	147235	01007L	PARTICIPANT	\N	PRESENT	0
147246	147235	08044W	PARTICIPANT	\N	EXCUSE	0
147247	147235	14111D	PARTICIPANT	\N	PRESENT	0
147248	147235	14147R	PARTICIPANT	\N	PRESENT	0
147249	147235	08051V	PARTICIPANT	\N	PRESENT	0
147250	147235	11072N	PARTICIPANT	\N	PRESENT	0
147251	147235	04074L	PARTICIPANT	\N	PRESENT	0
147252	147235	95063L	PARTICIPANT	\N	PRESENT	0
147253	147235	01028R	PARTICIPANT	\N	PRESENT	0
147254	147235	98035U	PARTICIPANT	\N	PRESENT	0
147255	147235	04056J	PARTICIPANT	\N	PRESENT	0
147256	147235	04044E	PARTICIPANT	\N	PRESENT	0
147257	147235	11037K	PARTICIPANT	\N	PRESENT	0
147258	147235	95067Q	PARTICIPANT	\N	PRESENT	0
147377	147373	11095V	PARTICIPANT	\N	EXCUSE	0
147378	147373	14065Q	PARTICIPANT	\N	PRESENT	0
147379	147373	14089Y	PARTICIPANT	\N	PRESENT	0
147380	147373	11029K	PARTICIPANT	\N	PRESENT	0
147381	147373	14207L	PRESIDENT	1	PRESENT	0
147382	147373	14053L	PARTICIPANT	\N	PRESENT	0
147432	147373	04035D	PARTICIPANT	\N	EXCUSE	0
149213	149212	14259Y	PARTICIPANT	\N	PRESENT	0
149214	149212	14059S	PARTICIPANT	\N	PRESENT	0
147386	147373	14215L	PARTICIPANT	\N	PRESENT	0
147387	147373	04089T	PARTICIPANT	\N	PRESENT	0
147388	147373	14249W	PARTICIPANT	\N	PRESENT	0
149216	149215	14259Y	PARTICIPANT	\N	PRESENT	0
149433	149432	04049K	PARTICIPANT	\N	PRESENT	0
147391	147373	14087W	PRESIDENT	0	PRESENT	0
149434	149432	14255U	PARTICIPANT	\N	PRESENT	0
147393	147373	14231L	PARTICIPANT	\N	PRESENT	0
147394	147373	11061K	PARTICIPANT	\N	PRESENT	0
147395	147373	95035G	PARTICIPANT	\N	PRESENT	0
147396	147373	14031R	PARTICIPANT	\N	PRESENT	0
147397	147373	04057K	PARTICIPANT	\N	PRESENT	0
147398	147373	11014C	PARTICIPANT	\N	PRESENT	0
149436	149435	04049K	PARTICIPANT	\N	PRESENT	0
147400	147373	14237S	PARTICIPANT	\N	PRESENT	0
147401	147373	14135M	PARTICIPANT	\N	PRESENT	0
147402	147373	14229S	PARTICIPANT	\N	PRESENT	0
149437	149435	14255U	PARTICIPANT	\N	PRESENT	0
149439	149438	04049K	PARTICIPANT	\N	PRESENT	0
149440	149438	14255U	PARTICIPANT	\N	PRESENT	0
149452	125637	11068S	PARTICIPANT	\N	PRESENT	0
149453	125637	11089X	PARTICIPANT	\N	PRESENT	0
149459	125637	04043D	PARTICIPANT	\N	EXCUSE	0
149460	125637	14257W	PARTICIPANT	\N	EXCUSE	0
149461	125637	14221J	PARTICIPANT	\N	EXCUSE	0
149462	125637	01048V	PARTICIPANT	\N	EXCUSE	0
149463	125637	04061F	PARTICIPANT	\N	EXCUSE	0
149464	125637	11061K	PARTICIPANT	\N	EXCUSE	0
149465	125637	80013X	PARTICIPANT	\N	EXCUSE	0
149466	125637	14209N	PARTICIPANT	\N	EXCUSE	0
149467	125637	11036J	PARTICIPANT	\N	EXCUSE	0
149468	125637	14263U	PARTICIPANT	\N	EXCUSE	0
149653	149652	14259Y	PARTICIPANT	\N	PRESENT	0
151460	151458	08025T	PARTICIPANT	\N	EXCUSE	0
151461	151458	04085P	PARTICIPANT	\N	PRESENT	0
151463	151458	05008E	PRESIDENT	0	PRESENT	0
151464	151458	11033F	PARTICIPANT	\N	PRESENT	0
151465	151458	14065Q	PARTICIPANT	\N	PRESENT	0
151466	151458	14069U	PARTICIPANT	\N	PRESENT	0
151467	151458	04047H	PARTICIPANT	\N	EXCUSE	0
151469	151458	04038G	PARTICIPANT	\N	PRESENT	0
151470	151458	11056N	PARTICIPANT	\N	PRESENT	0
151472	151458	11035H	PARTICIPANT	\N	PRESENT	0
151473	151458	14041T	PARTICIPANT	\N	PRESENT	0
151474	151458	11113E	PARTICIPANT	\N	PRESENT	0
151476	151458	01024M	PARTICIPANT	\N	EXCUSE	0
151478	151458	14215L	PARTICIPANT	\N	EXCUSE	0
151479	151458	01007L	PARTICIPANT	\N	EXCUSE	0
151480	151458	11049P	PARTICIPANT	\N	PRESENT	0
151481	151458	08044W	PARTICIPANT	\N	EXCUSE	0
151482	151458	11026G	PARTICIPANT	\N	PRESENT	0
151483	151458	14111D	PARTICIPANT	\N	PRESENT	0
151484	151458	01060R	PARTICIPANT	\N	PRESENT	0
151485	151458	95049N	PARTICIPANT	\N	PRESENT	0
155037	155036	01031L	PRESIDENT	0	PRESENT	0
155038	155036	04086Q	PARTICIPANT	\N	PRESENT	0
155039	155036	04055H	PARTICIPANT	\N	EXCUSE	0
155040	155036	11088W	PARTICIPANT	\N	PRESENT	0
155041	155036	01027Q	PARTICIPANT	\N	PRESENT	0
155042	155036	04071H	PARTICIPANT	\N	PRESENT	0
155043	155036	11074Q	PARTICIPANT	\N	PRESENT	0
155044	155036	98053W	PARTICIPANT	\N	PRESENT	0
155045	155036	11083R	PARTICIPANT	\N	PRESENT	0
155046	155036	07029T	PARTICIPANT	\N	PRESENT	0
155047	155036	08034U	PARTICIPANT	\N	PRESENT	0
155048	155036	11085T	PARTICIPANT	\N	EXCUSE	0
155049	155036	08011M	PARTICIPANT	\N	PRESENT	0
155050	155036	08061X	PARTICIPANT	\N	EXCUSE	0
155051	155036	04034C	PARTICIPANT	\N	PRESENT	0
157820	157818	11055M	PARTICIPANT	\N	PRESENT	0
157822	157818	04053F	PARTICIPANT	\N	PRESENT	0
157823	157818	14255U	PARTICIPANT	\N	PRESENT	0
157824	157818	04066L	PARTICIPANT	\N	PRESENT	0
157825	157818	00003C	PARTICIPANT	\N	EXCUSE	0
157826	157818	14053L	PARTICIPANT	\N	PRESENT	0
157827	157818	11103C	PARTICIPANT	\N	PRESENT	0
141020	141018	08017T	PARTICIPANT	\N	PRESENT	0
141025	141024	95067Q	PARTICIPANT	\N	PRESENT	0
141026	141024	14237S	PARTICIPANT	\N	PRESENT	0
141027	141024	14014Q	PARTICIPANT	\N	PRESENT	0
141028	141024	14195A	PARTICIPANT	\N	PRESENT	0
141033	141032	04040A	PRESIDENT	0	PRESENT	0
144419	144416	04040A	PARTICIPANT	\N	PRESENT	0
141053	141035	14255U	PARTICIPANT	\N	PRESENT	0
142740	142739	05008E	PRESIDENT	0	PRESENT	0
142741	142739	14069U	PARTICIPANT	\N	PRESENT	0
142742	142739	11056N	PARTICIPANT	\N	PRESENT	0
142743	142739	11035H	PARTICIPANT	\N	PRESENT	0
142744	142739	01024M	PARTICIPANT	\N	PRESENT	0
142745	142739	08044W	PARTICIPANT	\N	EXCUSE	0
142746	142739	11026G	PARTICIPANT	\N	PRESENT	0
142747	142739	14001X	PARTICIPANT	\N	PRESENT	0
142748	142739	14147R	PARTICIPANT	\N	PRESENT	0
142749	142739	07034Q	PARTICIPANT	\N	PRESENT	0
142750	142739	04074L	PARTICIPANT	\N	PRESENT	0
142751	142739	95063L	PARTICIPANT	\N	PRESENT	0
142752	142739	01028R	PARTICIPANT	\N	PRESENT	0
142753	142739	04056J	PARTICIPANT	\N	PRESENT	0
142754	142739	08010L	PARTICIPANT	\N	PRESENT	0
142755	141032	04044E	PARTICIPANT	\N	EXCUSE	0
142764	142763	01008M	PARTICIPANT	\N	PRESENT	0
142765	142763	14195A	PARTICIPANT	\N	PRESENT	0
142766	142763	14209N	PARTICIPANT	\N	PRESENT	0
142767	142763	11111C	PARTICIPANT	\N	PRESENT	0
142768	142763	14063N	PARTICIPANT	\N	PRESENT	0
142769	142763	14265W	PARTICIPANT	\N	PRESENT	0
142770	142763	04070G	PARTICIPANT	\N	PRESENT	0
142771	142763	14169X	PARTICIPANT	\N	PRESENT	0
142772	142763	14331P	PARTICIPANT	\N	PRESENT	0
142773	142763	11043H	PARTICIPANT	\N	PRESENT	0
142774	142763	08031R	PARTICIPANT	\N	PRESENT	0
142893	142892	08042U	PARTICIPANT	\N	PRESENT	0
142895	142894	08043V	PARTICIPANT	\N	PRESENT	0
142896	142894	14069U	PARTICIPANT	\N	PRESENT	0
142897	142894	14105F	PARTICIPANT	\N	PRESENT	0
142898	142894	14085U	PARTICIPANT	\N	PRESENT	0
142899	142894	11042G	PARTICIPANT	\N	PRESENT	0
142900	142894	11027H	PARTICIPANT	\N	PRESENT	0
142901	142894	87003B	PARTICIPANT	\N	PRESENT	0
142902	142894	14187A	PARTICIPANT	\N	PRESENT	0
142903	142894	11061K	PARTICIPANT	\N	PRESENT	0
142904	142894	95037J	PARTICIPANT	\N	PRESENT	0
142905	142894	01022K	PARTICIPANT	\N	PRESENT	0
142906	142894	14213J	PARTICIPANT	\N	PRESENT	0
142907	142894	14097Y	PARTICIPANT	\N	PRESENT	0
142908	142894	08015R	PARTICIPANT	\N	PRESENT	0
142909	142894	14059S	PARTICIPANT	\N	PRESENT	0
142910	142894	14111D	PARTICIPANT	\N	PRESENT	0
142911	142894	08053X	PARTICIPANT	\N	PRESENT	0
142912	142894	14109K	PARTICIPANT	\N	PRESENT	0
142913	142894	14265W	PARTICIPANT	\N	PRESENT	0
142914	142894	11012A	PARTICIPANT	\N	PRESENT	0
142916	142894	11097X	PARTICIPANT	\N	PRESENT	0
142933	142932	11039M	PARTICIPANT	\N	PRESENT	0
142934	142932	98042T	PARTICIPANT	\N	PRESENT	0
142935	142932	01019Q	PARTICIPANT	\N	PRESENT	0
143382	143380	14271U	PARTICIPANT	\N	PRESENT	0
144417	144416	96004D	PRESIDENT	0	PRESENT	0
144420	144416	11040E	PARTICIPANT	\N	PRESENT	0
144421	144416	04042C	PARTICIPANT	\N	PRESENT	0
144422	144416	04035D	PARTICIPANT	\N	PRESENT	0
144423	144416	11083R	PARTICIPANT	\N	PRESENT	0
144424	144416	14014Q	PARTICIPANT	\N	PRESENT	0
144425	144416	98022P	PARTICIPANT	\N	PRESENT	0
144426	144416	14097Y	PARTICIPANT	\N	PRESENT	0
144427	144416	04061F	PARTICIPANT	\N	PRESENT	0
144428	144416	14001X	PARTICIPANT	\N	PRESENT	0
144429	144416	95059Q	PRESIDENT	1	PRESENT	0
144430	144416	04034C	PARTICIPANT	\N	PRESENT	0
144431	144416	04080J	PARTICIPANT	\N	PRESENT	0
144432	144416	98021N	PARTICIPANT	\N	PRESENT	0
144434	144416	01031L	PARTICIPANT	\N	PRESENT	0
144435	144416	08011M	PARTICIPANT	\N	PRESENT	0
144513	144512	04038G	PARTICIPANT	\N	PRESENT	0
144516	144515	04038G	PARTICIPANT	\N	PRESENT	0
144521	141034	14028W	PARTICIPANT	\N	PRESENT	0
144522	141032	14028W	PARTICIPANT	\N	PRESENT	0
144524	141032	08010L	PARTICIPANT	\N	PRESENT	0
144525	141034	08010L	PARTICIPANT	\N	PRESENT	0
144595	144594	14263U	PARTICIPANT	\N	PRESENT	0
144596	144594	14133K	PARTICIPANT	\N	PRESENT	0
144597	144594	11109J	PARTICIPANT	\N	PRESENT	0
144598	144594	04059M	PARTICIPANT	\N	PRESENT	0
144599	144594	11039M	PARTICIPANT	\N	PRESENT	0
144600	144594	01044R	PARTICIPANT	\N	PRESENT	0
144601	144594	08043V	PARTICIPANT	\N	PRESENT	0
144602	144594	14089Y	PARTICIPANT	\N	PRESENT	0
144603	144594	14105F	PARTICIPANT	\N	PRESENT	0
144604	144594	11029K	PARTICIPANT	\N	PRESENT	0
144605	144594	95015C	PARTICIPANT	\N	PRESENT	0
144606	144594	92015P	PARTICIPANT	\N	PRESENT	0
144607	144594	08024S	PARTICIPANT	\N	PRESENT	0
144608	144594	14201E	PARTICIPANT	\N	PRESENT	0
144609	144594	14329V	PARTICIPANT	\N	PRESENT	0
144610	144594	14209N	PARTICIPANT	\N	PRESENT	0
144611	144594	14079W	PARTICIPANT	\N	PRESENT	0
144612	144594	11091R	PARTICIPANT	\N	PRESENT	0
144613	144594	87003B	PARTICIPANT	\N	PRESENT	0
144614	144594	98042T	PARTICIPANT	\N	PRESENT	0
144615	144594	14249W	PARTICIPANT	\N	EXCUSE	0
144616	144594	01041N	PARTICIPANT	\N	PRESENT	0
144617	144594	01025N	PARTICIPANT	\N	PRESENT	0
144618	144594	01037S	PARTICIPANT	\N	PRESENT	0
144713	144712	01008M	PARTICIPANT	\N	PRESENT	0
144620	144594	08035V	PARTICIPANT	\N	PRESENT	0
144621	144594	11089X	PARTICIPANT	\N	PRESENT	0
144622	144594	07026Q	PARTICIPANT	\N	PRESENT	0
144623	144594	14123H	PARTICIPANT	\N	PRESENT	0
144624	144594	14179A	PARTICIPANT	\N	PRESENT	0
144625	144594	04041B	PARTICIPANT	\N	PRESENT	0
144626	144594	14241N	PARTICIPANT	\N	PRESENT	0
144627	144594	14061L	PARTICIPANT	\N	PRESENT	0
144628	144594	14073Q	PARTICIPANT	\N	PRESENT	0
144629	144594	08031R	PARTICIPANT	\N	PRESENT	0
144630	144594	12041X	PARTICIPANT	\N	PRESENT	0
144631	144594	08039A	PARTICIPANT	\N	PRESENT	0
144632	144594	08017T	PARTICIPANT	\N	PRESENT	0
144633	144594	14059S	PARTICIPANT	\N	PRESENT	0
144634	144594	08012N	PARTICIPANT	\N	PRESENT	0
144635	144594	14103D	PARTICIPANT	\N	PRESENT	0
144636	144594	11104D	PARTICIPANT	\N	PRESENT	0
144637	144594	14063N	PARTICIPANT	\N	PRESENT	0
144638	144594	04057K	PARTICIPANT	\N	PRESENT	0
144639	144594	11014C	PARTICIPANT	\N	PRESENT	0
144640	144594	14109K	PARTICIPANT	\N	PRESENT	0
144641	144594	04070G	PARTICIPANT	\N	PRESENT	0
144642	144594	92040Q	PARTICIPANT	\N	PRESENT	0
144643	144594	14191V	PARTICIPANT	\N	PRESENT	0
144644	144594	83047W	PARTICIPANT	\N	PRESENT	0
144645	144594	14235Q	PARTICIPANT	\N	PRESENT	0
144646	144594	14055N	PARTICIPANT	\N	PRESENT	0
144715	144714	01008M	PARTICIPANT	\N	PRESENT	0
144648	144594	14229S	PARTICIPANT	\N	PRESENT	0
144649	144594	11043H	PARTICIPANT	\N	PRESENT	0
144650	144594	11071M	PARTICIPANT	\N	PRESENT	0
144717	144716	01008M	PARTICIPANT	\N	PRESENT	0
144719	144718	01008M	PARTICIPANT	\N	PRESENT	0
144721	144720	08068F	PARTICIPANT	\N	PRESENT	0
144723	144722	08009T	PARTICIPANT	\N	PRESENT	0
144724	144722	14169X	PARTICIPANT	\N	PRESENT	0
144728	144727	92018S	PARTICIPANT	\N	PRESENT	0
144738	144737	04049K	PARTICIPANT	\N	PRESENT	0
144739	144737	14255U	PARTICIPANT	\N	PRESENT	0
144773	144772	04049K	PARTICIPANT	\N	PRESENT	0
144774	144772	14255U	PARTICIPANT	\N	PRESENT	0
144832	141034	11049P	PARTICIPANT	\N	PRESENT	0
144833	141032	11049P	PARTICIPANT	\N	EXCUSE	0
144852	141032	11044J	PARTICIPANT	\N	EXCUSE	0
144853	141034	11044J	PARTICIPANT	\N	PRESENT	0
144854	141034	14231L	PARTICIPANT	\N	PRESENT	0
144872	141032	08051V	PARTICIPANT	\N	EXCUSE	0
144873	141034	08051V	PARTICIPANT	\N	EXCUSE	0
144874	141034	08038Y	PARTICIPANT	\N	PRESENT	0
144892	141034	04045F	PARTICIPANT	\N	EXCUSE	0
144893	141032	04045F	PARTICIPANT	\N	EXCUSE	0
144912	141032	95063L	PARTICIPANT	\N	PRESENT	0
144913	141034	95063L	PARTICIPANT	\N	EXCUSE	0
144934	141034	11112D	PARTICIPANT	\N	PRESENT	0
144935	141032	11112D	PARTICIPANT	\N	PRESENT	0
144955	141032	11035H	PARTICIPANT	\N	EXCUSE	0
144956	141034	11035H	PARTICIPANT	\N	EXCUSE	0
144972	141034	04086Q	PARTICIPANT	\N	EXCUSE	0
144973	141032	04086Q	PARTICIPANT	\N	EXCUSE	0
145072	141032	11074Q	PARTICIPANT	\N	EXCUSE	0
129935	129934	14259Y	PARTICIPANT	\N	PRESENT	0
129937	129936	14259Y	PARTICIPANT	\N	PRESENT	0
129939	129938	14259Y	PARTICIPANT	\N	PRESENT	0
129941	129940	14259Y	PARTICIPANT	\N	PRESENT	0
130087	120699	11109J	PARTICIPANT	\N	PRESENT	0
130088	120699	11114F	PARTICIPANT	\N	PRESENT	0
130089	120699	11113E	PARTICIPANT	\N	PRESENT	0
130090	120699	01027Q	PARTICIPANT	\N	PRESENT	0
130091	120699	04095R	PARTICIPANT	\N	PRESENT	0
130092	120699	14033T	PARTICIPANT	\N	EXCUSE	0
130093	120699	14097Y	PARTICIPANT	\N	PRESENT	0
130094	120699	98005N	PARTICIPANT	\N	PRESENT	0
130095	120699	11106F	PARTICIPANT	\N	EXCUSE	0
130096	120699	08019V	PRESIDENT	0	PRESENT	0
130097	120699	08073C	PARTICIPANT	\N	PRESENT	0
130098	120699	04043D	PARTICIPANT	\N	PRESENT	0
130099	120699	11054L	PARTICIPANT	\N	PRESENT	0
130100	120699	11011M	PARTICIPANT	\N	PRESENT	0
130101	120699	11025F	PARTICIPANT	\N	PRESENT	0
130102	120699	14059S	PARTICIPANT	\N	PRESENT	0
130364	130363	11044J	PARTICIPANT	\N	PRESENT	0
130365	130363	14281W	PARTICIPANT	\N	PRESENT	0
130912	120701	11106F	PARTICIPANT	\N	EXCUSE	0
130945	124956	04043D	PARTICIPANT	\N	PRESENT	0
130963	124956	14299H	PARTICIPANT	\N	PRESENT	0
131665	124148	11082Q	PARTICIPANT	\N	EXCUSE	0
131666	124148	01046T	PARTICIPANT	\N	PRESENT	0
131667	124148	14209N	PARTICIPANT	\N	PRESENT	0
131668	124148	11061K	PARTICIPANT	\N	EXCUSE	0
131669	124148	08069G	PARTICIPANT	\N	PRESENT	0
131670	124148	14221J	PARTICIPANT	\N	PRESENT	0
147874	147812	95049N	RAPPORTEUR_AVIS	\N	PRESENT	0
141014	141012	14255U	PARTICIPANT	\N	PRESENT	0
141016	141015	04049K	PARTICIPANT	\N	PRESENT	0
141017	141015	14255U	PARTICIPANT	\N	PRESENT	0
141022	141021	14253S	PARTICIPANT	\N	PRESENT	0
141023	141021	14157T	PARTICIPANT	\N	PRESENT	0
141056	141055	11039M	PARTICIPANT	\N	PRESENT	0
141057	141055	98042T	PARTICIPANT	\N	PRESENT	0
141058	141055	01019Q	PARTICIPANT	\N	PRESENT	0
141093	141092	14265W	PARTICIPANT	\N	PRESENT	0
141095	141094	14265W	PARTICIPANT	\N	PRESENT	0
141098	141097	14265W	PARTICIPANT	\N	PRESENT	0
141099	141096	14265W	PARTICIPANT	\N	PRESENT	0
141101	141100	14265W	PARTICIPANT	\N	PRESENT	0
141103	141102	14265W	PARTICIPANT	\N	PRESENT	0
141105	141104	14265W	PARTICIPANT	\N	PRESENT	0
141109	141108	14265W	PARTICIPANT	\N	PRESENT	0
141111	141110	14265W	PARTICIPANT	\N	PRESENT	0
142865	142864	14026U	PARTICIPANT	\N	PRESENT	0
142866	142864	95037J	PARTICIPANT	\N	PRESENT	0
142867	142864	96004D	PARTICIPANT	\N	PRESENT	0
143800	136163	11023D	PARTICIPANT	\N	PRESENT	0
143802	136163	14033T	PARTICIPANT	\N	PRESENT	0
143803	136163	08019V	PRESIDENT	0	PRESENT	0
143804	136163	11072N	PARTICIPANT	\N	PRESENT	0
143805	136163	08073C	PARTICIPANT	\N	PRESENT	0
143806	136163	11054L	PARTICIPANT	\N	PRESENT	0
143807	136163	11025F	PARTICIPANT	\N	PRESENT	0
143808	136163	14059S	PARTICIPANT	\N	PRESENT	0
143809	136163	04094Q	PARTICIPANT	\N	PRESENT	0
143810	136163	14039A	PARTICIPANT	\N	PRESENT	0
143811	136163	01027Q	PARTICIPANT	\N	EXCUSE	0
143812	136163	14097Y	PARTICIPANT	\N	EXCUSE	0
147233	147232	96004D	PARTICIPANT	\N	PRESENT	0
147234	147232	83042R	PARTICIPANT	\N	PRESENT	0
147814	147812	11055M	PARTICIPANT	\N	PRESENT	0
147875	147812	09001P	PARTICIPANT	\N	PRESENT	0
147816	147812	04053F	PARTICIPANT	\N	PRESENT	0
147930	147928	14263U	PARTICIPANT	\N	PRESENT	0
147931	147928	14133K	PARTICIPANT	\N	PRESENT	0
147819	147812	00003C	PARTICIPANT	\N	EXCUSE	0
147820	147812	14053L	PARTICIPANT	\N	PRESENT	0
147821	147812	11103C	PARTICIPANT	\N	PRESENT	0
147822	147812	11044J	PARTICIPANT	\N	PRESENT	0
147823	147812	14195A	PARTICIPANT	\N	PRESENT	0
147824	147812	14267Y	PARTICIPANT	\N	PRESENT	0
147825	147812	11023D	PARTICIPANT	\N	PRESENT	0
147826	147812	11031D	PARTICIPANT	\N	PRESENT	0
147827	147812	08052W	PARTICIPANT	\N	PRESENT	0
147828	147812	01059Y	PARTICIPANT	\N	PRESENT	0
147829	147812	04081K	PARTICIPANT	\N	PRESENT	0
147830	147812	98024R	PARTICIPANT	\N	PRESENT	0
147831	147812	10006L	PARTICIPANT	\N	PRESENT	0
147832	147812	04067M	PARTICIPANT	\N	EXCUSE	0
147833	147812	14217N	PARTICIPANT	\N	PRESENT	0
147834	147812	14042U	PARTICIPANT	\N	PRESENT	0
147835	147812	14151M	PARTICIPANT	\N	PRESENT	0
147836	147812	12042Y	PARTICIPANT	\N	PRESENT	0
147837	147812	14281W	PARTICIPANT	\N	PRESENT	0
147838	147812	14087W	PARTICIPANT	\N	PRESENT	0
147840	147812	14034U	PARTICIPANT	\N	PRESENT	0
147841	147812	14231L	PARTICIPANT	\N	PRESENT	0
147842	147812	11061K	PARTICIPANT	\N	PRESENT	0
147843	147812	14355X	PARTICIPANT	\N	PRESENT	0
147844	147812	08048B	PARTICIPANT	\N	PRESENT	0
147845	147812	08041T	PARTICIPANT	\N	PRESENT	0
147933	147928	04059M	PARTICIPANT	\N	PRESENT	0
147847	147812	14026U	PARTICIPANT	\N	PRESENT	0
147934	147928	11039M	PARTICIPANT	\N	PRESENT	0
147849	147812	14121F	PARTICIPANT	\N	PRESENT	0
147850	147812	11112D	PARTICIPANT	\N	EXCUSE	0
147851	147812	14037X	PARTICIPANT	\N	PRESENT	0
147935	147928	01044R	PARTICIPANT	\N	PRESENT	0
147853	147812	11067R	PARTICIPANT	\N	EXCUSE	0
147854	147812	14223L	PARTICIPANT	\N	PRESENT	0
147855	147812	04092N	PRESIDENT	0	PRESENT	0
147856	147812	14265W	PARTICIPANT	\N	PRESENT	0
147857	147812	14119M	PARTICIPANT	\N	PRESENT	0
147858	147812	14071N	PARTICIPANT	\N	EXCUSE	0
147859	147812	04043D	PARTICIPANT	\N	PRESENT	0
147860	147812	14271U	PARTICIPANT	\N	PRESENT	0
147936	147928	08043V	PARTICIPANT	\N	PRESENT	0
147862	147812	11093T	PRESIDENT	1	PRESENT	0
147863	147812	11097X	PARTICIPANT	\N	PRESENT	0
147864	147812	04045F	PARTICIPANT	\N	PRESENT	0
147865	147812	14227Q	PARTICIPANT	\N	PRESENT	0
147866	147812	01034P	PARTICIPANT	\N	PRESENT	0
147937	147928	14089Y	PARTICIPANT	\N	PRESENT	0
147938	147928	14105F	PARTICIPANT	\N	PRESENT	0
147869	147812	14269B	PARTICIPANT	\N	PRESENT	0
147939	147928	11029K	PARTICIPANT	\N	PRESENT	0
147940	147928	95015C	PARTICIPANT	\N	EXCUSE	0
147943	147928	14201E	PARTICIPANT	\N	EXCUSE	0
147945	147928	14209N	PARTICIPANT	\N	PRESENT	0
147947	147928	11091R	PARTICIPANT	\N	EXCUSE	0
147948	147928	87003B	PARTICIPANT	\N	PRESENT	0
147949	147928	98042T	PARTICIPANT	\N	PRESENT	0
147951	147928	01041N	PARTICIPANT	\N	PRESENT	0
147952	147928	01025N	PARTICIPANT	\N	PRESENT	0
147953	147928	01037S	PARTICIPANT	\N	PRESENT	0
147954	147928	89029V	PARTICIPANT	\N	PRESENT	0
147955	147928	08035V	PARTICIPANT	\N	PRESENT	0
147957	147928	07026Q	PARTICIPANT	\N	PRESENT	0
147958	147928	14123H	PARTICIPANT	\N	PRESENT	0
147959	147928	14179A	PARTICIPANT	\N	PRESENT	0
147961	147928	14241N	PARTICIPANT	\N	PRESENT	0
147962	147928	14061L	PARTICIPANT	\N	PRESENT	0
147963	147928	14073Q	PARTICIPANT	\N	PRESENT	0
147964	147928	08031R	PARTICIPANT	\N	PRESENT	0
147965	147928	12041X	PARTICIPANT	\N	PRESENT	0
147966	147928	08039A	PARTICIPANT	\N	PRESENT	0
147967	147928	08017T	PARTICIPANT	\N	PRESENT	0
147968	147928	14059S	PARTICIPANT	\N	PRESENT	0
147969	147928	08012N	PARTICIPANT	\N	PRESENT	0
147971	147928	11104D	PARTICIPANT	\N	PRESENT	0
147972	147928	14063N	PARTICIPANT	\N	PRESENT	0
147973	147928	04057K	PARTICIPANT	\N	EXCUSE	0
147974	147928	11014C	PARTICIPANT	\N	PRESENT	0
140502	139237	01041N	PARTICIPANT	\N	PRESENT	0
140503	139237	04054G	PARTICIPANT	\N	PRESENT	0
140504	139237	11031D	PARTICIPANT	\N	PRESENT	0
140505	139237	14331P	PARTICIPANT	\N	PRESENT	0
140506	139237	04085P	PARTICIPANT	\N	PRESENT	0
140507	139237	98053W	PARTICIPANT	\N	PRESENT	0
140508	139237	11034G	PARTICIPANT	\N	PRESENT	0
140509	139237	95067Q	PARTICIPANT	\N	PRESENT	0
140510	139237	01015L	PARTICIPANT	\N	PRESENT	0
140511	139237	11098Y	PARTICIPANT	\N	PRESENT	0
140512	139237	04033B	PARTICIPANT	\N	PRESENT	0
140513	139237	14069U	PARTICIPANT	\N	PRESENT	0
140514	139237	08016S	PARTICIPANT	\N	PRESENT	0
140515	139237	08011M	PARTICIPANT	\N	PRESENT	0
140516	139237	98035U	PARTICIPANT	\N	PRESENT	0
140517	139237	04056J	PARTICIPANT	\N	PRESENT	0
140518	139237	01016M	PARTICIPANT	\N	PRESENT	0
140519	139237	14038Y	PARTICIPANT	\N	PRESENT	0
140520	139237	95063L	PARTICIPANT	\N	PRESENT	0
140521	139237	14119M	PARTICIPANT	\N	PRESENT	0
140522	139237	14013P	PARTICIPANT	\N	PRESENT	0
140523	139237	98046X	PARTICIPANT	\N	PRESENT	0
140532	139237	14329V	PARTICIPANT	\N	PRESENT	0
140525	139237	08025T	PARTICIPANT	\N	PRESENT	0
140526	139237	11049P	PARTICIPANT	\N	PRESENT	0
140527	139237	08055A	PARTICIPANT	\N	PRESENT	0
140528	139237	04066L	PARTICIPANT	\N	PRESENT	0
140529	139237	08019V	PARTICIPANT	\N	PRESENT	0
140530	139237	01022K	PARTICIPANT	\N	PRESENT	0
140531	139237	11080N	PARTICIPANT	\N	PRESENT	0
140533	139237	14197C	PARTICIPANT	\N	PRESENT	0
140534	139237	14065Q	PARTICIPANT	\N	PRESENT	0
140671	139237	14247U	PARTICIPANT	\N	PRESENT	0
140536	139237	11015D	PARTICIPANT	\N	PRESENT	0
140537	139237	08068F	PARTICIPANT	\N	PRESENT	0
140538	139237	98024R	PARTICIPANT	\N	PRESENT	0
140540	139237	11036J	PARTICIPANT	\N	PRESENT	0
140541	139237	98050T	PARTICIPANT	\N	PRESENT	0
140542	139237	10006L	PARTICIPANT	\N	PRESENT	0
140543	139237	08058D	PARTICIPANT	\N	PRESENT	0
140544	139237	04034C	PARTICIPANT	\N	PRESENT	0
140545	139237	95037J	PARTICIPANT	\N	PRESENT	0
140546	139237	08017T	PARTICIPANT	\N	PRESENT	0
140547	139237	11059R	PARTICIPANT	\N	PRESENT	0
140548	139237	14199E	PARTICIPANT	\N	PRESENT	0
140549	139237	11046L	PARTICIPANT	\N	PRESENT	0
140550	139237	08010L	PARTICIPANT	\N	PRESENT	0
140551	139237	14109K	PARTICIPANT	\N	PRESENT	0
140552	139237	14175V	PARTICIPANT	\N	PRESENT	0
140553	139237	08014Q	PARTICIPANT	\N	PRESENT	0
140554	139237	14039A	PARTICIPANT	\N	PRESENT	0
140555	139237	14281W	PARTICIPANT	\N	PRESENT	0
140556	139237	98018T	PARTICIPANT	\N	PRESENT	0
140557	139237	14121F	PARTICIPANT	\N	PRESENT	0
140558	139237	11074Q	PARTICIPANT	\N	PRESENT	0
140559	139237	10015M	PARTICIPANT	\N	PRESENT	0
140560	139237	04077P	PARTICIPANT	\N	PRESENT	0
140561	139237	04053F	PARTICIPANT	\N	PRESENT	0
140562	139237	01028R	PARTICIPANT	\N	PRESENT	0
140563	139237	11104D	PARTICIPANT	\N	PRESENT	0
140564	139237	12041X	PARTICIPANT	\N	PRESENT	0
140565	139237	04071H	PARTICIPANT	\N	PRESENT	0
140566	139237	04059M	PARTICIPANT	\N	PRESENT	0
140567	139237	08024S	PARTICIPANT	\N	PRESENT	0
140568	139237	04061F	PARTICIPANT	\N	PRESENT	0
140569	139237	01037S	PARTICIPANT	\N	PRESENT	0
140570	139237	04081K	PARTICIPANT	\N	PRESENT	0
140571	139237	14085U	PARTICIPANT	\N	PRESENT	0
140572	139237	14037X	PARTICIPANT	\N	PRESENT	0
140573	139237	14081Q	PARTICIPANT	\N	PRESENT	0
140574	139237	99002P	PARTICIPANT	\N	PRESENT	0
140575	139237	14225N	PARTICIPANT	\N	PRESENT	0
140576	139237	04045F	PARTICIPANT	\N	PRESENT	0
140577	139237	01057W	PARTICIPANT	\N	PRESENT	0
140578	139237	11077T	PARTICIPANT	\N	PRESENT	0
140579	139237	04079R	PARTICIPANT	\N	PRESENT	0
140580	139237	14269B	PARTICIPANT	\N	PRESENT	0
140581	139237	98021N	PARTICIPANT	\N	PRESENT	0
140582	139237	14159V	PARTICIPANT	\N	PRESENT	0
140583	139237	04094Q	PARTICIPANT	\N	PRESENT	0
140584	139237	11014C	PARTICIPANT	\N	PRESENT	0
140585	139237	11114F	PARTICIPANT	\N	PRESENT	0
140586	139237	11113E	PARTICIPANT	\N	PRESENT	0
140587	139237	14123H	PARTICIPANT	\N	PRESENT	0
140588	139237	11109J	PARTICIPANT	\N	PRESENT	0
140589	139237	12042Y	PARTICIPANT	\N	PRESENT	0
140590	139237	08051V	PARTICIPANT	\N	PRESENT	0
140591	139237	11112D	PARTICIPANT	\N	PRESENT	0
140592	139237	04043D	PARTICIPANT	\N	PRESENT	0
140593	139237	14135M	PARTICIPANT	\N	PRESENT	0
140594	139237	04078Q	PARTICIPANT	\N	PRESENT	0
140595	139237	88008L	PARTICIPANT	\N	PRESENT	0
140596	139237	01046T	PARTICIPANT	\N	PRESENT	0
140597	139237	08031R	PARTICIPANT	\N	PRESENT	0
140598	139237	04035D	PARTICIPANT	\N	PRESENT	0
140599	139237	14018U	PARTICIPANT	\N	PRESENT	0
140600	139237	14001X	PARTICIPANT	\N	PRESENT	0
140601	139237	01014K	PARTICIPANT	\N	PRESENT	0
140602	139237	14169X	PARTICIPANT	\N	PRESENT	0
140603	139237	08049C	PARTICIPANT	\N	PRESENT	0
140604	139237	04038G	PARTICIPANT	\N	PRESENT	0
140605	139237	04042C	PARTICIPANT	\N	PRESENT	0
140606	139237	11096W	PARTICIPANT	\N	PRESENT	0
140607	139237	14201E	PARTICIPANT	\N	PRESENT	0
140608	139237	14087W	PARTICIPANT	\N	PRESENT	0
140609	139237	14241N	PARTICIPANT	\N	PRESENT	0
140610	139237	04067M	PARTICIPANT	\N	PRESENT	0
140611	139237	11076S	PARTICIPANT	\N	PRESENT	0
140612	139237	11029K	PARTICIPANT	\N	PRESENT	0
140613	139237	01044R	PARTICIPANT	\N	PRESENT	0
140614	139237	13002U	PARTICIPANT	\N	PRESENT	0
140615	139237	11083R	PARTICIPANT	\N	PRESENT	0
140616	139237	01027Q	PARTICIPANT	\N	PRESENT	0
140617	139237	11033F	PARTICIPANT	\N	PRESENT	0
140618	139237	11099A	PARTICIPANT	\N	PRESENT	0
140619	139237	14055N	PARTICIPANT	\N	PRESENT	0
140620	139237	08021P	PARTICIPANT	\N	PRESENT	0
140621	139237	92044U	PARTICIPANT	\N	PRESENT	0
140622	139237	01059Y	PARTICIPANT	\N	PRESENT	0
140623	139237	01048V	PARTICIPANT	\N	PRESENT	0
140624	139237	14030Q	PARTICIPANT	\N	PRESENT	0
140625	139237	01007L	PARTICIPANT	\N	PRESENT	0
140626	139237	14327T	PARTICIPANT	\N	PRESENT	0
140627	139237	01024M	PARTICIPANT	\N	PRESENT	0
140628	139237	01034P	PARTICIPANT	\N	PRESENT	0
140629	139237	11053K	PARTICIPANT	\N	PRESENT	0
140630	139237	08009T	PARTICIPANT	\N	PRESENT	0
140631	139237	04040A	PARTICIPANT	\N	PRESENT	0
140632	139237	14255U	PARTICIPANT	\N	PRESENT	0
140633	139237	14073Q	PARTICIPANT	\N	PRESENT	0
140634	139237	11085T	PARTICIPANT	\N	PRESENT	0
140635	139237	04080J	PARTICIPANT	\N	PRESENT	0
140636	139237	14205J	PARTICIPANT	\N	PRESENT	0
140637	139237	07004J	PARTICIPANT	\N	PRESENT	0
140638	139237	04089T	PARTICIPANT	\N	PRESENT	0
140639	139237	14219Q	PARTICIPANT	\N	PRESENT	0
140640	139237	14221J	PARTICIPANT	\N	PRESENT	0
140641	139237	11082Q	PARTICIPANT	\N	PRESENT	0
140642	139237	98042T	PARTICIPANT	\N	PRESENT	0
140643	139237	14089Y	PARTICIPANT	\N	PRESENT	0
140644	139237	05012A	PARTICIPANT	\N	PRESENT	0
140645	139237	04070G	PARTICIPANT	\N	PRESENT	0
140646	139237	08039A	PARTICIPANT	\N	PRESENT	0
140650	139237	98023Q	PARTICIPANT	\N	PRESENT	0
140651	139237	14231L	PARTICIPANT	\N	PRESENT	0
140652	139237	14042U	PARTICIPANT	\N	PRESENT	0
140653	139237	04050C	PARTICIPANT	\N	PRESENT	0
140654	139237	08069G	PARTICIPANT	\N	PRESENT	0
140659	139237	11064N	PARTICIPANT	\N	PRESENT	0
140666	139237	14093U	PARTICIPANT	\N	PRESENT	0
140664	139237	11084S	PARTICIPANT	\N	PRESENT	0
140665	139237	95041E	PARTICIPANT	\N	PRESENT	0
140667	139237	11039M	PARTICIPANT	\N	PRESENT	0
140668	139237	14229S	PARTICIPANT	\N	PRESENT	0
140669	139237	11089X	PARTICIPANT	\N	PRESENT	0
140670	139237	04036E	PARTICIPANT	\N	PRESENT	0
140672	139237	11044J	PARTICIPANT	\N	PRESENT	0
140673	139237	89017R	PARTICIPANT	\N	PRESENT	0
140697	139238	01007L	PARTICIPANT	\N	PRESENT	0
140699	139238	04092N	PARTICIPANT	\N	PRESENT	0
140700	139238	01034P	PARTICIPANT	\N	PRESENT	0
140704	139238	08052W	PARTICIPANT	\N	PRESENT	0
140706	139238	14121F	PARTICIPANT	\N	PRESENT	0
140707	139238	11082Q	PARTICIPANT	\N	PRESENT	0
140708	139238	14215L	PARTICIPANT	\N	PRESENT	0
140709	139238	14041T	PARTICIPANT	\N	PRESENT	0
140710	139238	07029T	PARTICIPANT	\N	PRESENT	0
129203	129202	14259Y	PARTICIPANT	\N	PRESENT	0
129206	129205	14259Y	PARTICIPANT	\N	PRESENT	0
132836	132835	11026G	PARTICIPANT	\N	PRESENT	0
132838	132837	11026G	PARTICIPANT	\N	PRESENT	0
132855	132854	89017R	PARTICIPANT	\N	PRESENT	0
132861	132860	01031L	PARTICIPANT	\N	PRESENT	0
132862	131784	04086Q	PARTICIPANT	\N	PRESENT	0
135418	135417	01056V	PARTICIPANT	\N	PRESENT	0
135419	135417	11106F	PARTICIPANT	\N	PRESENT	0
135423	135422	01056V	PARTICIPANT	\N	PRESENT	0
135424	135422	11106F	PARTICIPANT	\N	PRESENT	0
154953	154952	01031L	PARTICIPANT	\N	PRESENT	0
157093	157092	05008E	PARTICIPANT	\N	PRESENT	0
157112	156825	05012A	PARTICIPANT	\N	PRESENT	0
157133	157132	09001P	PRESIDENT	0	PRESENT	0
157134	157132	11065P	PARTICIPANT	\N	PRESENT	0
157135	157132	01056V	PARTICIPANT	\N	PRESENT	0
157136	157132	14093U	PARTICIPANT	\N	PRESENT	0
157137	157132	14033T	PARTICIPANT	\N	PRESENT	0
157138	157132	80013X	PARTICIPANT	\N	EXCUSE	0
157139	157132	11090Q	PARTICIPANT	\N	EXCUSE	0
157140	157132	08049C	PARTICIPANT	\N	EXCUSE	0
157141	157132	92045V	PARTICIPANT	\N	EXCUSE	0
157829	157818	14195A	PARTICIPANT	\N	PRESENT	0
157830	157818	14267Y	PARTICIPANT	\N	PRESENT	0
157831	157818	11023D	PARTICIPANT	\N	EXCUSE	0
157832	157818	11031D	PARTICIPANT	\N	PRESENT	0
157879	155101	95062K	PARTICIPANT	\N	PRESENT	0
157834	157818	01059Y	PARTICIPANT	\N	PRESENT	0
157835	157818	04081K	PARTICIPANT	\N	PRESENT	0
157836	157818	98024R	PARTICIPANT	\N	PRESENT	0
157880	155101	14225N	PARTICIPANT	\N	PRESENT	0
157881	155101	14357A	PARTICIPANT	\N	PRESENT	0
157839	157818	14217N	PARTICIPANT	\N	PRESENT	0
157840	157818	14042U	PARTICIPANT	\N	PRESENT	0
157841	157818	14151M	PARTICIPANT	\N	PRESENT	0
157842	157818	12042Y	PARTICIPANT	\N	PRESENT	0
157843	157818	14281W	PARTICIPANT	\N	PRESENT	0
157934	155101	11081P	PARTICIPANT	\N	PRESENT	0
157883	155101	01027Q	PARTICIPANT	\N	PRESENT	0
157846	157818	14034U	PARTICIPANT	\N	PRESENT	0
157847	157818	14231L	PARTICIPANT	\N	PRESENT	0
157848	157818	11061K	PARTICIPANT	\N	PRESENT	0
157849	157818	14355X	PARTICIPANT	\N	PRESENT	0
157850	157818	08048B	PARTICIPANT	\N	PRESENT	0
157851	157818	08041T	PARTICIPANT	\N	PRESENT	0
157852	157818	01011G	PARTICIPANT	\N	EXCUSE	0
157853	157818	14026U	PARTICIPANT	\N	PRESENT	0
157854	157818	14213J	PARTICIPANT	\N	PRESENT	0
157884	155101	11042G	PARTICIPANT	\N	PRESENT	0
157856	157818	11112D	PARTICIPANT	\N	PRESENT	0
157885	155101	14073Q	PARTICIPANT	\N	PRESENT	0
157886	155101	14179A	PARTICIPANT	\N	PRESENT	0
157859	157818	11067R	PARTICIPANT	\N	PRESENT	0
157860	157818	14223L	PARTICIPANT	\N	PRESENT	0
157861	157818	04092N	PRESIDENT	0	PRESENT	0
157862	157818	14265W	PARTICIPANT	\N	PRESENT	0
157863	157818	14119M	PARTICIPANT	\N	PRESENT	0
157864	157818	14071N	PARTICIPANT	\N	PRESENT	0
157887	155101	08010L	PARTICIPANT	\N	PRESENT	0
157888	155101	14069U	PARTICIPANT	\N	PRESENT	0
157889	155101	04086Q	PARTICIPANT	\N	PRESENT	0
157868	157818	11093T	PARTICIPANT	\N	PRESENT	0
157869	157818	11097X	PARTICIPANT	\N	PRESENT	0
157870	157818	04045F	PARTICIPANT	\N	PRESENT	0
157930	155101	90003B	PARTICIPANT	\N	PRESENT	0
157932	155101	08062Y	PARTICIPANT	\N	PRESENT	0
157933	155101	07029T	PARTICIPANT	\N	PRESENT	0
157874	157818	11063M	PARTICIPANT	\N	PRESENT	0
157875	157818	14269B	PARTICIPANT	\N	PRESENT	0
157876	155101	11012A	PARTICIPANT	\N	PRESENT	0
157877	155101	11107G	PARTICIPANT	\N	PRESENT	0
157878	155101	01022K	PARTICIPANT	\N	PRESENT	0
157935	155101	14109K	PARTICIPANT	\N	PRESENT	0
157937	155101	14187A	PARTICIPANT	\N	PRESENT	0
157987	155101	14031R	PARTICIPANT	\N	PRESENT	0
157988	155101	08028W	PARTICIPANT	\N	PRESENT	0
157989	155101	11083R	PARTICIPANT	\N	PRESENT	0
157990	155101	95030B	PARTICIPANT	\N	PRESENT	0
157992	155101	01058X	PARTICIPANT	\N	PRESENT	0
157993	155101	14253S	PARTICIPANT	\N	PRESENT	0
157994	155101	08019V	PARTICIPANT	\N	PRESENT	0
157995	155101	01016M	PARTICIPANT	\N	PRESENT	0
157996	155101	14281W	PARTICIPANT	\N	PRESENT	0
157997	155101	11027H	PARTICIPANT	\N	PRESENT	0
157998	155101	11061K	PARTICIPANT	\N	PRESENT	0
157999	155101	14030Q	PARTICIPANT	\N	PRESENT	0
158000	155101	05012A	PARTICIPANT	\N	PRESENT	0
158001	155101	13002U	PARTICIPANT	\N	PRESENT	0
158002	155101	14199E	PARTICIPANT	\N	PRESENT	0
158003	155101	87003B	PARTICIPANT	\N	PRESENT	0
158044	155101	14363X	PARTICIPANT	\N	PRESENT	0
158045	155101	14231L	PARTICIPANT	\N	PRESENT	0
158046	155101	11090Q	PARTICIPANT	\N	PRESENT	0
158112	155102	04066L	PARTICIPANT	\N	PRESENT	0
158132	155102	01027Q	PARTICIPANT	\N	PRESENT	0
158133	155102	14028W	PARTICIPANT	\N	PRESENT	0
158134	155102	13002U	PARTICIPANT	\N	PRESENT	0
158135	155102	11037K	PARTICIPANT	\N	PRESENT	0
158136	155102	04038G	PARTICIPANT	\N	PRESENT	0
158137	155102	11012A	PARTICIPANT	\N	PRESENT	0
158138	155102	04040A	PARTICIPANT	\N	PRESENT	0
158139	155102	92031P	PARTICIPANT	\N	PRESENT	0
158140	155102	14119M	PARTICIPANT	\N	PRESENT	0
158141	155102	14059S	PARTICIPANT	\N	PRESENT	0
158142	155102	14187A	PARTICIPANT	\N	PRESENT	0
158143	155102	97011G	PARTICIPANT	\N	PRESENT	0
158144	155102	11044J	PARTICIPANT	\N	PRESENT	0
158145	155102	14199E	PARTICIPANT	\N	PRESENT	0
158146	155102	14265W	PARTICIPANT	\N	PRESENT	0
158147	155102	08034U	PARTICIPANT	\N	PRESENT	0
158148	155102	01057W	PARTICIPANT	\N	PRESENT	0
158149	155102	11048N	PARTICIPANT	\N	PRESENT	0
158150	155102	14195A	PARTICIPANT	\N	PRESENT	0
158151	155102	01043Q	PARTICIPANT	\N	PRESENT	0
158152	155102	14253S	PARTICIPANT	\N	PRESENT	0
158153	155102	04085P	PARTICIPANT	\N	PRESENT	0
158154	155102	14235Q	PARTICIPANT	\N	PRESENT	0
158155	155102	11056N	PARTICIPANT	\N	PRESENT	0
158156	155102	14034U	PARTICIPANT	\N	PRESENT	0
158157	155102	05012A	PARTICIPANT	\N	PRESENT	0
158158	155102	14069U	PARTICIPANT	\N	PRESENT	0
158159	155102	14133K	PARTICIPANT	\N	PRESENT	0
158160	155102	04097T	PARTICIPANT	\N	PRESENT	0
158172	155102	14105F	PARTICIPANT	\N	PRESENT	0
158173	155102	04067M	PARTICIPANT	\N	PRESENT	0
158174	155102	14213J	PARTICIPANT	\N	PRESENT	0
158175	155102	14257W	PARTICIPANT	\N	PRESENT	0
158192	155102	11099A	PARTICIPANT	\N	PRESENT	0
158193	155102	14079W	PARTICIPANT	\N	PRESENT	0
158194	155102	08015R	PARTICIPANT	\N	PRESENT	0
158195	155102	01008M	PARTICIPANT	\N	PRESENT	0
158196	155102	14231L	PARTICIPANT	\N	PRESENT	0
158514	158513	01056V	PARTICIPANT	\N	PRESENT	0
158515	158513	09001P	PRESIDENT	0	PRESENT	0
158516	158513	11065P	PARTICIPANT	\N	PRESENT	0
158517	158513	80013X	PARTICIPANT	\N	PRESENT	0
158518	158513	90003B	PARTICIPANT	\N	PRESENT	0
158519	158513	01008M	PARTICIPANT	\N	PRESENT	0
159156	159154	11049P	PARTICIPANT	\N	PRESENT	0
159209	159208	14239U	PARTICIPANT	\N	PRESENT	0
159210	159208	08043V	PARTICIPANT	\N	PRESENT	0
159211	159208	08024S	PARTICIPANT	\N	PRESENT	0
159212	159208	14195A	PARTICIPANT	\N	PRESENT	0
159213	159208	11031D	PARTICIPANT	\N	PRESENT	0
159214	159208	08052W	PARTICIPANT	\N	PRESENT	0
159215	159208	87003B	PARTICIPANT	\N	PRESENT	0
145074	141034	11098Y	PARTICIPANT	\N	EXCUSE	0
145075	141032	11098Y	PARTICIPANT	\N	EXCUSE	0
145132	141032	14327T	PARTICIPANT	\N	PRESENT	0
145133	141034	14327T	PARTICIPANT	\N	EXCUSE	0
145513	145512	05008E	PRESIDENT	0	PRESENT	0
145514	145512	14065Q	PARTICIPANT	\N	PRESENT	0
145515	145512	04047H	PARTICIPANT	\N	PRESENT	0
145516	145512	01024M	PARTICIPANT	\N	PRESENT	0
145517	145512	08044W	PARTICIPANT	\N	EXCUSE	0
145518	145512	14001X	PARTICIPANT	\N	PRESENT	0
145519	145512	14147R	PARTICIPANT	\N	PRESENT	0
145520	145512	07034Q	PARTICIPANT	\N	PRESENT	0
145521	145512	01028R	PARTICIPANT	\N	PRESENT	0
145539	145538	01024M	PARTICIPANT	\N	PRESENT	0
145540	145538	01015L	PARTICIPANT	\N	PRESENT	0
145541	145538	14073Q	PARTICIPANT	\N	PRESENT	0
145542	145538	14031R	PARTICIPANT	\N	PRESENT	0
145543	145538	92039X	PARTICIPANT	\N	PRESENT	0
145544	145538	95063L	PARTICIPANT	\N	PRESENT	0
145925	145522	04067M	PARTICIPANT	\N	PRESENT	0
145926	145522	11083R	PARTICIPANT	\N	PRESENT	0
145927	145522	11029K	PARTICIPANT	\N	PRESENT	0
145928	145522	95062K	PARTICIPANT	\N	PRESENT	0
145929	145522	01031L	PARTICIPANT	\N	PRESENT	0
145930	145522	98053W	PARTICIPANT	\N	PRESENT	0
145931	145522	11098Y	PARTICIPANT	\N	PRESENT	0
145932	145522	04094Q	PARTICIPANT	\N	PRESENT	0
145933	145522	01015L	PARTICIPANT	\N	PRESENT	0
145934	145522	04085P	PARTICIPANT	\N	PRESENT	0
145935	145522	14013P	PARTICIPANT	\N	PRESENT	0
145936	145522	14211G	PARTICIPANT	\N	PRESENT	0
145937	145522	04054G	PARTICIPANT	\N	PRESENT	0
145938	145522	11072N	PARTICIPANT	\N	PRESENT	0
145939	145522	08039A	PARTICIPANT	\N	PRESENT	0
145940	145522	01058X	PARTICIPANT	\N	PRESENT	0
145941	145522	04035D	PARTICIPANT	\N	PRESENT	0
145942	145522	01019Q	PARTICIPANT	\N	PRESENT	0
145943	145522	11096W	PARTICIPANT	\N	PRESENT	0
145944	145522	99004R	PARTICIPANT	\N	PRESENT	0
145945	145522	86044G	PARTICIPANT	\N	PRESENT	0
145946	145522	14087W	PARTICIPANT	\N	PRESENT	0
145947	145522	90003B	PARTICIPANT	\N	PRESENT	0
145948	145522	95067Q	PARTICIPANT	\N	PRESENT	0
145950	145522	11012A	PARTICIPANT	\N	PRESENT	0
145951	145949	04045F	PARTICIPANT	\N	PRESENT	0
145952	145949	92045V	PARTICIPANT	\N	PRESENT	0
145953	145522	11044J	PARTICIPANT	\N	PRESENT	0
145954	145522	01003G	PARTICIPANT	\N	PRESENT	0
145955	145522	98050T	PARTICIPANT	\N	PRESENT	0
145956	145522	08031R	PARTICIPANT	\N	PRESENT	0
145957	145522	04061F	PARTICIPANT	\N	PRESENT	0
145958	145522	14071N	PARTICIPANT	\N	PRESENT	0
145959	145522	14083S	PARTICIPANT	\N	PRESENT	0
145960	145522	11070L	PARTICIPANT	\N	PRESENT	0
145961	145522	14193X	PARTICIPANT	\N	PRESENT	0
145962	145522	12041X	PARTICIPANT	\N	PRESENT	0
145964	145522	08009T	PARTICIPANT	\N	PRESENT	0
145965	145522	11094U	PARTICIPANT	\N	PRESENT	0
145966	145522	04080J	PARTICIPANT	\N	PRESENT	0
145967	145963	92045V	PARTICIPANT	\N	PRESENT	0
145968	145522	11065P	PARTICIPANT	\N	PRESENT	0
145969	145522	11048N	PARTICIPANT	\N	PRESENT	0
145970	145522	05012A	PARTICIPANT	\N	PRESENT	0
145971	145522	07004J	PARTICIPANT	\N	PRESENT	0
145972	145522	14205J	PARTICIPANT	\N	PRESENT	0
145973	145522	14209N	PARTICIPANT	\N	PRESENT	0
145974	145522	11063M	PARTICIPANT	\N	PRESENT	0
145975	145522	14231L	PARTICIPANT	\N	PRESENT	0
145976	145522	14147R	PARTICIPANT	\N	PRESENT	0
145977	145522	11111C	PARTICIPANT	\N	PRESENT	0
145978	145522	08047A	PARTICIPANT	\N	PRESENT	0
145979	145522	04070G	PARTICIPANT	\N	PRESENT	0
145980	145522	01047U	PARTICIPANT	\N	PRESENT	0
145981	145522	04040A	PARTICIPANT	\N	PRESENT	0
145982	145522	01007L	PARTICIPANT	\N	PRESENT	0
145983	145522	89017R	PARTICIPANT	\N	PRESENT	0
145984	145522	14247U	PARTICIPANT	\N	PRESENT	0
145985	145522	11103C	PARTICIPANT	\N	PRESENT	0
145986	145522	14055N	PARTICIPANT	\N	PRESENT	0
145987	145522	01057W	PARTICIPANT	\N	PRESENT	0
145988	145522	14249W	PARTICIPANT	\N	PRESENT	0
145989	145522	08011M	PARTICIPANT	\N	PRESENT	0
145990	145522	01034P	PARTICIPANT	\N	PRESENT	0
146002	145522	14034U	PARTICIPANT	\N	PRESENT	0
145992	145522	14179A	PARTICIPANT	\N	PRESENT	0
145993	145522	10015M	PARTICIPANT	\N	PRESENT	0
145994	145522	95041E	PARTICIPANT	\N	PRESENT	0
145995	145522	14135M	PARTICIPANT	\N	PRESENT	0
145996	145522	11031D	PARTICIPANT	\N	PRESENT	0
145997	145522	14069U	PARTICIPANT	\N	PRESENT	0
145998	145522	92040Q	PARTICIPANT	\N	PRESENT	0
145999	145522	01024M	PARTICIPANT	\N	PRESENT	0
146000	145522	08015R	PARTICIPANT	\N	PRESENT	0
146001	145522	77002U	PARTICIPANT	\N	PRESENT	0
146003	145522	11090Q	PARTICIPANT	\N	PRESENT	0
146012	145522	08010L	PARTICIPANT	\N	PRESENT	0
146005	145522	14053L	PARTICIPANT	\N	PRESENT	0
146006	145522	01041N	PARTICIPANT	\N	PRESENT	0
146007	145522	08048B	PARTICIPANT	\N	PRESENT	0
146008	145522	08042U	PARTICIPANT	\N	PRESENT	0
146009	145522	08034U	PARTICIPANT	\N	PRESENT	0
146010	145522	14213J	PARTICIPANT	\N	PRESENT	0
146014	145522	14018U	PARTICIPANT	\N	PRESENT	0
146013	145522	14241N	PARTICIPANT	\N	PRESENT	0
146015	145522	14329V	PARTICIPANT	\N	PRESENT	0
146016	145522	04050C	PARTICIPANT	\N	PRESENT	0
146017	145522	14253S	PARTICIPANT	\N	PRESENT	0
146018	145522	11071M	PARTICIPANT	\N	PRESENT	0
146019	145522	08018U	PARTICIPANT	\N	PRESENT	0
146020	145522	14042U	PARTICIPANT	\N	PRESENT	0
146021	145522	14093U	PARTICIPANT	\N	PRESENT	0
146022	145522	08022Q	PARTICIPANT	\N	PRESENT	0
146031	145522	01059Y	PARTICIPANT	\N	PRESENT	0
146029	145522	05004A	PARTICIPANT	\N	PRESENT	0
146025	145522	08069G	PARTICIPANT	\N	PRESENT	0
146026	145522	14199E	PARTICIPANT	\N	PRESENT	0
146027	145522	14111D	PARTICIPANT	\N	PRESENT	0
146030	145522	11056N	PARTICIPANT	\N	PRESENT	0
146032	145522	88008L	PARTICIPANT	\N	PRESENT	0
146033	145522	04038G	PARTICIPANT	\N	PRESENT	0
146034	145522	01043Q	PARTICIPANT	\N	PRESENT	0
146039	145522	09001P	PARTICIPANT	\N	PRESENT	0
146040	145522	01048V	PARTICIPANT	\N	PRESENT	0
146041	145522	14119M	PARTICIPANT	\N	PRESENT	0
146053	145522	01046T	PARTICIPANT	\N	PRESENT	0
146085	145522	98021N	PARTICIPANT	\N	PRESENT	0
146058	145522	14251Q	PARTICIPANT	\N	PRESENT	0
146059	145522	14037X	PARTICIPANT	\N	PRESENT	0
146086	145522	01008M	PARTICIPANT	\N	PRESENT	0
146087	145522	11109J	PARTICIPANT	\N	PRESENT	0
146088	145522	14265W	PARTICIPANT	\N	PRESENT	0
146089	145522	14133K	PARTICIPANT	\N	PRESENT	0
146090	145522	05008E	PARTICIPANT	\N	PRESENT	0
146091	145522	14038Y	PARTICIPANT	\N	PRESENT	0
146092	145522	04044E	PARTICIPANT	\N	PRESENT	0
146093	145522	11099A	PARTICIPANT	\N	PRESENT	0
146094	145522	11112D	PARTICIPANT	\N	PRESENT	0
146095	145522	04055H	PARTICIPANT	\N	PRESENT	0
146096	145522	98042T	PARTICIPANT	\N	PRESENT	0
146098	146097	14030Q	PARTICIPANT	\N	PRESENT	0
146099	146097	14083S	PARTICIPANT	\N	PRESENT	0
146100	146097	14209N	PARTICIPANT	\N	PRESENT	0
146101	146097	11098Y	PARTICIPANT	\N	PRESENT	0
146102	146097	13002U	PARTICIPANT	\N	PRESENT	0
146103	146097	14331P	PARTICIPANT	\N	PRESENT	0
146104	146097	95062K	PARTICIPANT	\N	PRESENT	0
146105	146097	14157T	PARTICIPANT	\N	PRESENT	0
146232	146193	04092N	PARTICIPANT	\N	PRESENT	0
146233	146193	01034P	PARTICIPANT	\N	PRESENT	0
146234	146193	08055A	PARTICIPANT	\N	PRESENT	0
146235	146193	01022K	PARTICIPANT	\N	PRESENT	0
146236	146193	14227Q	PARTICIPANT	\N	PRESENT	0
146237	146193	11063M	PARTICIPANT	\N	PRESENT	0
146238	146193	08052W	PARTICIPANT	\N	PRESENT	0
146239	146193	14121F	PARTICIPANT	\N	PRESENT	0
146240	146193	11066Q	PARTICIPANT	\N	PRESENT	0
146241	146193	12042Y	PARTICIPANT	\N	PRESENT	0
146242	146193	04053F	PARTICIPANT	\N	PRESENT	0
146243	146193	01046T	PARTICIPANT	\N	PRESENT	0
146244	146193	08016S	PARTICIPANT	\N	PRESENT	0
146245	146193	14191V	PARTICIPANT	\N	PRESENT	0
146246	146193	14031R	PARTICIPANT	\N	PRESENT	0
146247	146193	14105F	PARTICIPANT	\N	PRESENT	0
146248	146193	11044J	PARTICIPANT	\N	PRESENT	0
146249	146193	10006L	PARTICIPANT	\N	PRESENT	0
146250	146193	11093T	PARTICIPANT	\N	PRESENT	0
130012	127240	11114F	PARTICIPANT	\N	PRESENT	0
130024	127240	01022K	PARTICIPANT	\N	PRESENT	0
130850	130849	14135M	PARTICIPANT	\N	PRESENT	0
130851	130849	04070G	PARTICIPANT	\N	PRESENT	0
130853	130852	14135M	PARTICIPANT	\N	PRESENT	0
130914	130913	11055M	PARTICIPANT	\N	EXCUSE	0
130915	130913	01046T	PARTICIPANT	\N	PRESENT	0
130916	130913	04053F	PARTICIPANT	\N	PRESENT	0
130917	130913	14255U	PARTICIPANT	\N	PRESENT	0
130918	130913	00003C	PARTICIPANT	\N	EXCUSE	0
130919	130913	14053L	PARTICIPANT	\N	PRESENT	0
130920	130913	11103C	PARTICIPANT	\N	PRESENT	0
130921	130913	14195A	PARTICIPANT	\N	PRESENT	0
130922	130913	14267Y	PARTICIPANT	\N	PRESENT	0
130923	130913	08052W	PARTICIPANT	\N	PRESENT	0
130924	130913	01059Y	PARTICIPANT	\N	PRESENT	0
130925	130913	04081K	PARTICIPANT	\N	PRESENT	0
130926	130913	98024R	PARTICIPANT	\N	PRESENT	0
130927	130913	10006L	PARTICIPANT	\N	PRESENT	0
130928	130913	14217N	PARTICIPANT	\N	PRESENT	0
130929	130913	14042U	PARTICIPANT	\N	PRESENT	0
130930	130913	12042Y	PARTICIPANT	\N	PRESENT	0
130931	130913	14281W	PARTICIPANT	\N	PRESENT	0
130932	130913	01003G	PARTICIPANT	\N	PRESENT	0
130933	130913	14231L	PARTICIPANT	\N	PRESENT	0
130934	130913	11061K	PARTICIPANT	\N	PRESENT	0
130935	130913	08048B	PARTICIPANT	\N	PRESENT	0
130936	130913	08041T	PARTICIPANT	\N	PRESENT	0
130937	130913	14026U	PARTICIPANT	\N	PRESENT	0
130938	130913	14213J	PARTICIPANT	\N	PRESENT	0
130939	130913	11112D	PARTICIPANT	\N	PRESENT	0
130940	130913	14037X	PARTICIPANT	\N	PRESENT	0
130941	130913	14087W	PARTICIPANT	\N	EXCUSE	0
130943	130913	11067R	PARTICIPANT	\N	EXCUSE	0
130944	130913	14223L	PARTICIPANT	\N	PRESENT	0
130946	130913	04092N	PRESIDENT	0	PRESENT	0
130947	130913	14265W	PARTICIPANT	\N	PRESENT	0
130948	130913	14119M	PARTICIPANT	\N	PRESENT	0
130950	130913	14071N	PARTICIPANT	\N	PRESENT	0
130952	130913	07032N	PARTICIPANT	\N	PRESENT	0
130953	130913	04043D	PARTICIPANT	\N	PRESENT	0
130954	130913	11097X	PARTICIPANT	\N	PRESENT	0
130955	130913	04045F	PARTICIPANT	\N	PRESENT	0
130956	130913	14227Q	PARTICIPANT	\N	PRESENT	0
130958	130913	01034P	PARTICIPANT	\N	PRESENT	0
130959	130913	11063M	PARTICIPANT	\N	PRESENT	0
130961	130913	14269B	PARTICIPANT	\N	PRESENT	0
131032	131031	14215L	PARTICIPANT	\N	PRESENT	0
131656	131650	11072N	PARTICIPANT	\N	PRESENT	0
131658	131657	11072N	PARTICIPANT	\N	PRESENT	0
131662	131661	11033F	PARTICIPANT	\N	PRESENT	0
131664	131661	04044E	PARTICIPANT	\N	PRESENT	0
132288	132283	92031P	PARTICIPANT	\N	PRESENT	0
132290	132283	11015D	PARTICIPANT	\N	PRESENT	0
132341	132336	08058D	PARTICIPANT	\N	PRESENT	0
132344	132336	95035G	PARTICIPANT	\N	PRESENT	0
132462	132445	86044G	PARTICIPANT	\N	PRESENT	0
132463	132445	11027H	PARTICIPANT	\N	PRESENT	0
132840	132839	11089X	PARTICIPANT	\N	PRESENT	0
132842	132841	11089X	PARTICIPANT	\N	PRESENT	0
132844	132843	11089X	PARTICIPANT	\N	PRESENT	0
133075	133074	11036J	PARTICIPANT	\N	PRESENT	0
133243	133242	11036J	PARTICIPANT	\N	PRESENT	0
133244	133242	11081P	PARTICIPANT	\N	PRESENT	0
133078	133074	14013P	PARTICIPANT	\N	PRESENT	0
133245	133242	14013P	PARTICIPANT	\N	PRESENT	0
133246	133242	14207L	PARTICIPANT	\N	PRESENT	0
133247	133242	11101A	PARTICIPANT	\N	PRESENT	0
133082	133074	80013X	PARTICIPANT	\N	PRESENT	0
133248	133242	80013X	PARTICIPANT	\N	PRESENT	0
133249	133242	04089T	PARTICIPANT	\N	PRESENT	0
133250	133242	14197C	PARTICIPANT	\N	PRESENT	0
133251	133242	14033T	PARTICIPANT	\N	PRESENT	0
133252	133242	08015R	PARTICIPANT	\N	PRESENT	0
133253	133242	11100Y	PRESIDENT	0	PRESENT	0
133254	133242	01043Q	PARTICIPANT	\N	PRESENT	0
133255	133242	11077T	PARTICIPANT	\N	PRESENT	0
133256	133242	14205J	PARTICIPANT	\N	PRESENT	0
133257	133242	08019V	PARTICIPANT	\N	PRESENT	0
133258	133242	14257W	PARTICIPANT	\N	PRESENT	0
133259	133242	08021P	PARTICIPANT	\N	PRESENT	0
133260	133242	04088S	PARTICIPANT	\N	PRESENT	0
133261	133242	98050T	PARTICIPANT	\N	PRESENT	0
133262	133242	11046L	PARTICIPANT	\N	PRESENT	0
133098	133074	04097T	PARTICIPANT	\N	PRESENT	0
133099	133074	11048N	PARTICIPANT	\N	PRESENT	0
133263	133242	01058X	PARTICIPANT	\N	PRESENT	0
133264	133242	11066Q	PARTICIPANT	\N	PRESENT	0
133265	133242	01008M	PARTICIPANT	\N	EXCUSE	0
133103	133074	11100Y	PARTICIPANT	\N	PRESENT	0
133104	133074	14257W	PARTICIPANT	\N	PRESENT	0
133266	133242	90003B	PARTICIPANT	\N	EXCUSE	0
133267	133242	01061S	PARTICIPANT	\N	EXCUSE	0
133268	133242	11090Q	PARTICIPANT	\N	EXCUSE	0
133269	133242	11094U	PARTICIPANT	\N	EXCUSE	0
135614	135613	08060W	PARTICIPANT	\N	PRESENT	0
133110	133074	98050T	PARTICIPANT	\N	PRESENT	0
135615	135613	14038Y	PARTICIPANT	\N	PRESENT	0
135616	135613	11114F	PARTICIPANT	\N	PRESENT	0
133113	133074	11012A	PARTICIPANT	\N	PRESENT	0
135617	135613	01015L	PARTICIPANT	\N	PRESENT	0
135618	135613	14221J	PARTICIPANT	\N	PRESENT	0
135619	135613	08042U	PARTICIPANT	\N	PRESENT	0
133117	133074	92045V	PARTICIPANT	\N	PRESENT	0
135620	135613	14107H	PARTICIPANT	\N	PRESENT	0
133119	133074	95067Q	PARTICIPANT	\N	PRESENT	0
135621	135613	14030Q	PARTICIPANT	\N	EXCUSE	0
135622	135613	11095V	PARTICIPANT	\N	EXCUSE	0
135623	135613	08062Y	PARTICIPANT	\N	EXCUSE	0
135624	135613	05012A	PARTICIPANT	\N	EXCUSE	0
135625	135613	95062K	PARTICIPANT	\N	EXCUSE	0
135626	135613	96003C	PARTICIPANT	\N	EXCUSE	0
135756	135754	04038G	PARTICIPANT	\N	PRESENT	0
135771	135769	04044E	PARTICIPANT	\N	PRESENT	0
137710	137708	11111C	PARTICIPANT	\N	PRESENT	0
137711	137708	90003B	PARTICIPANT	\N	PRESENT	0
137715	137714	11111C	PARTICIPANT	\N	PRESENT	0
137716	137714	90003B	PARTICIPANT	\N	PRESENT	0
137722	137721	90003B	PARTICIPANT	\N	PRESENT	0
137735	137734	08042U	PARTICIPANT	\N	PRESENT	0
137736	137734	14107H	PARTICIPANT	\N	PRESENT	0
137738	137737	08042U	PARTICIPANT	\N	PRESENT	0
137739	137737	14107H	PARTICIPANT	\N	PRESENT	0
137741	137740	14038Y	PARTICIPANT	\N	PRESENT	0
137742	137740	14237S	PARTICIPANT	\N	PRESENT	0
137743	137740	14327T	PARTICIPANT	\N	PRESENT	0
137744	137740	01008M	PARTICIPANT	\N	PRESENT	0
137748	137747	14038Y	PARTICIPANT	\N	PRESENT	0
137749	137747	14237S	PARTICIPANT	\N	PRESENT	0
137750	137747	14327T	PARTICIPANT	\N	PRESENT	0
137773	137772	01031L	PARTICIPANT	\N	PRESENT	0
137775	137774	08014Q	PARTICIPANT	\N	PRESENT	0
137867	137866	08009T	PARTICIPANT	\N	PRESENT	0
138074	138072	11036J	PARTICIPANT	\N	PRESENT	0
138076	138072	14013P	PARTICIPANT	\N	EXCUSE	0
138077	138072	08068F	PARTICIPANT	\N	PRESENT	0
138078	138072	14207L	PARTICIPANT	\N	PRESENT	0
138080	138072	90003B	PARTICIPANT	\N	PRESENT	0
138081	138072	08028W	PARTICIPANT	\N	PRESENT	0
138082	138072	80013X	PARTICIPANT	\N	PRESENT	0
138083	138072	08038Y	PARTICIPANT	\N	PRESENT	0
138087	138072	14187A	PARTICIPANT	\N	EXCUSE	0
138088	138072	14033T	PARTICIPANT	\N	PRESENT	0
138090	138072	04048J	PARTICIPANT	\N	PRESENT	0
138092	138072	04049K	PARTICIPANT	\N	PRESENT	0
138095	138072	08015R	PARTICIPANT	\N	PRESENT	0
138096	138072	11100Y	PRESIDENT	0	PRESENT	0
138097	138072	01061S	PARTICIPANT	\N	PRESENT	0
138099	138072	01043Q	PARTICIPANT	\N	PRESENT	0
140711	139238	14042U	PARTICIPANT	\N	PRESENT	0
140712	139238	11023D	PARTICIPANT	\N	PRESENT	0
140716	139238	11063M	PARTICIPANT	\N	PRESENT	0
140718	139238	11031D	PARTICIPANT	\N	PRESENT	0
140721	139238	14018U	PARTICIPANT	\N	PRESENT	0
140722	139238	11103C	PARTICIPANT	\N	PRESENT	0
140723	139238	12042Y	PARTICIPANT	\N	PRESENT	0
140724	139238	01015L	PARTICIPANT	\N	PRESENT	0
140725	139238	01046T	PARTICIPANT	\N	PRESENT	0
140726	139238	11093T	PARTICIPANT	\N	PRESENT	0
140727	139238	14267Y	PARTICIPANT	\N	PRESENT	0
140728	139238	11044J	PARTICIPANT	\N	PRESENT	0
140729	139238	14281W	PARTICIPANT	\N	PRESENT	0
140730	139238	13002U	PARTICIPANT	\N	PRESENT	0
140731	139238	11066Q	PARTICIPANT	\N	PRESENT	0
140732	139238	04067M	PARTICIPANT	\N	PRESENT	0
140733	139238	14195A	PARTICIPANT	\N	PRESENT	0
140734	139238	11112D	PARTICIPANT	\N	PRESENT	0
140735	139238	01059Y	PARTICIPANT	\N	PRESENT	0
140736	139238	11097X	PARTICIPANT	\N	PRESENT	0
140737	139238	11042G	PARTICIPANT	\N	PRESENT	0
140738	139238	14269B	PARTICIPANT	\N	PRESENT	0
140739	139238	14217N	PARTICIPANT	\N	PRESENT	0
140740	139238	14071N	PARTICIPANT	\N	PRESENT	0
140741	139238	07024N	PARTICIPANT	\N	PRESENT	0
140742	139238	04086Q	PARTICIPANT	\N	PRESENT	0
140743	139238	98050T	PARTICIPANT	\N	PRESENT	0
140744	139238	04045F	PARTICIPANT	\N	PRESENT	0
140745	139238	14249W	PARTICIPANT	\N	PRESENT	0
140746	139238	04035D	PARTICIPANT	\N	PRESENT	0
140747	139238	14103D	PARTICIPANT	\N	PRESENT	0
140748	139238	14199E	PARTICIPANT	\N	PRESENT	0
140749	139238	95035G	PARTICIPANT	\N	PRESENT	0
140750	139238	14271U	PARTICIPANT	\N	PRESENT	0
140751	139238	04053F	PARTICIPANT	\N	PRESENT	0
140753	139238	08019V	PARTICIPANT	\N	PRESENT	0
140754	139238	04057K	PARTICIPANT	\N	PRESENT	0
140755	139238	08034U	PARTICIPANT	\N	PRESENT	0
140756	139238	04066L	PARTICIPANT	\N	PRESENT	0
140757	139238	01011G	PARTICIPANT	\N	PRESENT	0
140758	139238	04043D	PARTICIPANT	\N	PRESENT	0
140759	139238	14265W	PARTICIPANT	\N	PRESENT	0
140761	139238	01048V	PARTICIPANT	\N	PRESENT	0
140764	139238	14123H	PARTICIPANT	\N	PRESENT	0
140765	139238	04036E	PARTICIPANT	\N	PRESENT	0
140767	139238	08010L	PARTICIPANT	\N	PRESENT	0
140770	139238	14231L	PARTICIPANT	\N	PRESENT	0
140771	139238	14059S	PARTICIPANT	\N	PRESENT	0
140772	139238	01058X	PARTICIPANT	\N	PRESENT	0
140773	139238	98024R	PARTICIPANT	\N	PRESENT	0
140774	139238	11054L	PARTICIPANT	\N	PRESENT	0
140775	139238	14073Q	PARTICIPANT	\N	PRESENT	0
140776	139238	10015M	PARTICIPANT	\N	PRESENT	0
140777	139238	08016S	PARTICIPANT	\N	PRESENT	0
140778	139238	11061K	PARTICIPANT	\N	PRESENT	0
140779	139238	14219Q	PARTICIPANT	\N	PRESENT	0
140780	139238	11055M	PARTICIPANT	\N	PRESENT	0
140782	139238	08055A	PARTICIPANT	\N	PRESENT	0
140783	139238	11064N	PARTICIPANT	\N	PRESENT	0
140784	139238	14169X	PARTICIPANT	\N	PRESENT	0
140785	139239	04066L	PARTICIPANT	\N	PRESENT	0
140786	139239	04092N	PARTICIPANT	\N	PRESENT	0
140787	139239	98024R	PARTICIPANT	\N	PRESENT	0
140788	139239	01034P	PARTICIPANT	\N	PRESENT	0
140789	139239	01011G	PARTICIPANT	\N	PRESENT	0
140790	139239	11031D	PARTICIPANT	\N	PRESENT	0
140791	139239	04045F	PARTICIPANT	\N	PRESENT	0
140792	139239	14219Q	PARTICIPANT	\N	PRESENT	0
140793	139239	14231L	PARTICIPANT	\N	PRESENT	0
140794	139239	11097X	PARTICIPANT	\N	PRESENT	0
140795	139239	14217N	PARTICIPANT	\N	PRESENT	0
140796	139239	04067M	PARTICIPANT	\N	PRESENT	0
140797	139239	08052W	PARTICIPANT	\N	PRESENT	0
140798	139239	11063M	PARTICIPANT	\N	PRESENT	0
140799	139239	01059Y	PARTICIPANT	\N	PRESENT	0
140800	139239	14195A	PARTICIPANT	\N	PRESENT	0
140801	139239	14269B	PARTICIPANT	\N	PRESENT	0
140802	139239	11061K	PARTICIPANT	\N	PRESENT	0
140803	139239	01046T	PARTICIPANT	\N	PRESENT	0
140804	139239	11093T	PARTICIPANT	\N	PRESENT	0
140805	139239	14197C	PARTICIPANT	\N	PRESENT	0
140806	139239	14042U	PARTICIPANT	\N	PRESENT	0
140807	139239	11109J	PARTICIPANT	\N	PRESENT	0
140808	139239	04053F	PARTICIPANT	\N	PRESENT	0
140832	140831	08017T	PARTICIPANT	\N	PRESENT	0
140834	140833	08012N	PARTICIPANT	\N	PRESENT	0
140836	140835	08039A	PARTICIPANT	\N	PRESENT	0
140838	140837	08039A	PARTICIPANT	\N	PRESENT	0
140993	140992	10015M	PARTICIPANT	\N	PRESENT	0
141193	141072	86034E	PARTICIPANT	\N	PRESENT	0
141194	141072	89029V	PARTICIPANT	\N	PRESENT	0
141195	141072	14191V	PARTICIPANT	\N	PRESENT	0
141196	141072	11044J	PARTICIPANT	\N	PRESENT	0
141197	141072	14059S	PARTICIPANT	\N	PRESENT	0
141198	141072	04044E	PARTICIPANT	\N	PRESENT	0
141199	141072	95041E	PARTICIPANT	\N	PRESENT	0
141200	141072	07034Q	PARTICIPANT	\N	PRESENT	0
141201	141072	14193X	PARTICIPANT	\N	PRESENT	0
141202	141072	14331P	PARTICIPANT	\N	PRESENT	0
141203	141072	14107H	PARTICIPANT	\N	PRESENT	0
141204	141072	14197C	PARTICIPANT	\N	PRESENT	0
141205	141072	14063N	PARTICIPANT	\N	PRESENT	0
141206	141072	08052W	PARTICIPANT	\N	PRESENT	0
141207	141072	04053F	PARTICIPANT	\N	PRESENT	0
141208	141072	11100Y	PARTICIPANT	\N	PRESENT	0
141209	141072	11031D	PARTICIPANT	\N	PRESENT	0
141210	141072	07024N	PARTICIPANT	\N	PRESENT	0
141211	141072	08053X	PARTICIPANT	\N	PRESENT	0
141212	141072	04045F	PARTICIPANT	\N	PRESENT	0
141213	141072	14259Y	PARTICIPANT	\N	PRESENT	0
141214	141072	14097Y	PARTICIPANT	\N	PRESENT	0
141215	141072	95031C	PARTICIPANT	\N	PRESENT	0
141216	141072	14069U	PARTICIPANT	\N	PRESENT	0
141217	141072	05012A	PARTICIPANT	\N	PRESENT	0
141218	141072	14041T	PARTICIPANT	\N	PRESENT	0
141219	141072	04086Q	PARTICIPANT	\N	PRESENT	0
141223	141072	04088S	PARTICIPANT	\N	PRESENT	0
141224	141072	14033T	PARTICIPANT	\N	PRESENT	0
141225	141072	95049N	PARTICIPANT	\N	PRESENT	0
141226	141072	04080J	PARTICIPANT	\N	PRESENT	0
141227	141072	01041N	PARTICIPANT	\N	PRESENT	0
141228	141072	08018U	PARTICIPANT	\N	PRESENT	0
141229	141072	98024R	PARTICIPANT	\N	PRESENT	0
141230	141072	14205J	PARTICIPANT	\N	PRESENT	0
141231	141072	04097T	PARTICIPANT	\N	PRESENT	0
141232	141072	11093T	PARTICIPANT	\N	PRESENT	0
141233	141072	14219Q	PARTICIPANT	\N	PRESENT	0
141234	141072	08015R	PARTICIPANT	\N	PRESENT	0
141235	141072	92040Q	PARTICIPANT	\N	PRESENT	0
141236	141072	02002K	PARTICIPANT	\N	PRESENT	0
141237	141072	11103C	PARTICIPANT	\N	PRESENT	0
141238	141072	04057K	PARTICIPANT	\N	PRESENT	0
141239	141072	08041T	PARTICIPANT	\N	PRESENT	0
141240	141072	04055H	PARTICIPANT	\N	PRESENT	0
141241	141072	08011M	PARTICIPANT	\N	PRESENT	0
141242	141072	90003B	PARTICIPANT	\N	PRESENT	0
141243	141072	11080N	PARTICIPANT	\N	PRESENT	0
141244	141072	95035G	PARTICIPANT	\N	PRESENT	0
141245	141072	95015C	PARTICIPANT	\N	PRESENT	0
141246	141072	04092N	PARTICIPANT	\N	PRESENT	0
141247	141072	97011G	PARTICIPANT	\N	PRESENT	0
141248	141072	08047A	PARTICIPANT	\N	PRESENT	0
141249	141072	01019Q	PARTICIPANT	\N	PRESENT	0
141250	141072	14147R	PARTICIPANT	\N	PRESENT	0
141251	141072	04085P	PARTICIPANT	\N	PRESENT	0
141252	141072	04049K	PARTICIPANT	\N	PRESENT	0
141253	141072	92018S	PARTICIPANT	\N	PRESENT	0
141254	141072	07026Q	PARTICIPANT	\N	PRESENT	0
141255	141072	14093U	PARTICIPANT	\N	PRESENT	0
141256	141072	04050C	PARTICIPANT	\N	PRESENT	0
141257	141072	07029T	PARTICIPANT	\N	PRESENT	0
141258	141072	11063M	PARTICIPANT	\N	PRESENT	0
141259	141072	08019V	PARTICIPANT	\N	PRESENT	0
141260	141072	12041X	PARTICIPANT	\N	PRESENT	0
141261	141072	08022Q	PARTICIPANT	\N	PRESENT	0
141262	141072	14013P	PARTICIPANT	\N	PRESENT	0
141263	141072	14235Q	PARTICIPANT	\N	PRESENT	0
141264	141072	11098Y	PARTICIPANT	\N	PRESENT	0
141265	141072	87003B	PARTICIPANT	\N	PRESENT	0
141266	141072	05001W	PARTICIPANT	\N	PRESENT	0
141267	141072	01059Y	PARTICIPANT	\N	PRESENT	0
141268	141072	08062Y	PARTICIPANT	\N	PRESENT	0
141269	141072	11034G	PARTICIPANT	\N	PRESENT	0
141270	141072	11040E	PARTICIPANT	\N	PRESENT	0
141271	141072	14329V	PARTICIPANT	\N	PRESENT	0
141272	141072	14031R	PARTICIPANT	\N	PRESENT	0
141273	141072	01056V	PARTICIPANT	\N	PRESENT	0
141274	141072	14263U	PARTICIPANT	\N	PRESENT	0
128773	127192	11089X	PARTICIPANT	\N	PRESENT	0
128774	127192	95067Q	PARTICIPANT	\N	PRESENT	0
128775	127240	01003G	PARTICIPANT	\N	PRESENT	0
128776	127240	01016M	PARTICIPANT	\N	PRESENT	0
130050	129849	08009T	PARTICIPANT	\N	EXCUSE	0
130054	129894	08009T	PARTICIPANT	\N	EXCUSE	0
130779	130621	04061F	PARTICIPANT	\N	EXCUSE	0
130780	130621	99004R	PARTICIPANT	\N	EXCUSE	0
130781	130621	04038G	PARTICIPANT	\N	EXCUSE	0
130782	130621	01059Y	PARTICIPANT	\N	EXCUSE	0
130783	130621	01015L	PARTICIPANT	\N	EXCUSE	0
130784	130621	01041N	PARTICIPANT	\N	EXCUSE	0
130785	130621	02002K	PARTICIPANT	\N	EXCUSE	0
130786	130621	08012N	PARTICIPANT	\N	EXCUSE	0
132806	132805	05008E	PARTICIPANT	\N	PRESENT	0
132807	132805	11056N	PARTICIPANT	\N	PRESENT	0
132808	132805	01047U	PARTICIPANT	\N	PRESENT	0
132810	132809	04059M	PARTICIPANT	\N	PRESENT	0
132846	132845	01046T	PARTICIPANT	\N	PRESENT	0
132847	132845	14042U	PARTICIPANT	\N	PRESENT	0
132848	132845	01034P	PARTICIPANT	\N	PRESENT	0
132850	132849	14042U	PARTICIPANT	\N	PRESENT	0
132851	132849	11061K	PARTICIPANT	\N	PRESENT	0
132852	132849	08052W	PARTICIPANT	\N	PRESENT	0
132853	132849	01034P	PARTICIPANT	\N	PRESENT	0
133015	133014	14081Q	PARTICIPANT	\N	PRESENT	0
133017	133016	04094Q	PARTICIPANT	\N	PRESENT	0
133019	133018	01058X	PARTICIPANT	\N	PRESENT	0
133021	133020	14093U	PARTICIPANT	\N	PRESENT	0
133023	133022	14081Q	PARTICIPANT	\N	PRESENT	0
133025	133024	14081Q	PARTICIPANT	\N	PRESENT	0
133027	133026	14331P	PARTICIPANT	\N	PRESENT	0
133029	133028	14187A	PARTICIPANT	\N	PRESENT	0
133031	133030	14331P	PARTICIPANT	\N	PRESENT	0
133033	133032	04094Q	PARTICIPANT	\N	PRESENT	0
133035	133034	14331P	PARTICIPANT	\N	PRESENT	0
133037	133036	14331P	PARTICIPANT	\N	PRESENT	0
135600	124150	11089X	PARTICIPANT	\N	PRESENT	0
137500	137498	11053K	PARTICIPANT	\N	PRESENT	0
135603	124150	04043D	PARTICIPANT	\N	PRESENT	0
137501	137498	11080N	PARTICIPANT	\N	PRESENT	0
137499	137498	01013J	PARTICIPANT	\N	PRESENT	0
137502	137498	01027Q	PRESIDENT	0	PRESENT	0
137503	137498	11083R	PARTICIPANT	\N	PRESENT	0
137504	137498	01057W	PARTICIPANT	\N	PRESENT	0
137505	137498	14159V	PARTICIPANT	\N	PRESENT	0
137506	137498	92039X	PARTICIPANT	\N	PRESENT	0
137507	137498	14225N	PARTICIPANT	\N	PRESENT	0
137508	137498	11012A	PARTICIPANT	\N	PRESENT	0
137509	137498	14157T	PARTICIPANT	\N	PRESENT	0
137511	137510	95015C	PARTICIPANT	\N	PRESENT	0
137513	137512	95015C	PARTICIPANT	\N	PRESENT	0
137515	137514	95015C	PARTICIPANT	\N	PRESENT	0
142813	142759	14255U	PARTICIPANT	\N	PRESENT	0
142815	142759	01027Q	PARTICIPANT	\N	PRESENT	0
142816	142759	11106F	PARTICIPANT	\N	PRESENT	0
142817	142759	04040A	PARTICIPANT	\N	PRESENT	0
142818	142759	04038G	PARTICIPANT	\N	PRESENT	0
144813	144812	04049K	PARTICIPANT	\N	PRESENT	0
144814	144812	14255U	PARTICIPANT	\N	PRESENT	0
149253	149252	14083S	PARTICIPANT	\N	PRESENT	0
149255	149254	14083S	PARTICIPANT	\N	PRESENT	0
157572	157432	95062K	PARTICIPANT	\N	EXCUSE	0
157891	157890	01008M	PARTICIPANT	\N	PRESENT	0
157931	157890	14187A	PARTICIPANT	\N	PRESENT	0
159216	159208	11061K	PARTICIPANT	\N	PRESENT	0
157894	157890	14013P	PARTICIPANT	\N	PRESENT	0
157895	157890	08068F	PARTICIPANT	\N	PRESENT	0
157896	157890	14207L	PARTICIPANT	\N	PRESENT	0
158006	158004	08055A	PARTICIPANT	\N	PRESENT	0
157898	157890	90003B	PARTICIPANT	\N	PRESENT	0
157899	157890	08028W	PARTICIPANT	\N	PRESENT	0
157900	157890	80013X	PARTICIPANT	\N	PRESENT	0
157901	157890	14357A	PARTICIPANT	\N	PRESENT	0
157902	157890	08038Y	PARTICIPANT	\N	PRESENT	0
159217	159208	14213J	PARTICIPANT	\N	PRESENT	0
158008	158004	14030Q	PARTICIPANT	\N	PRESENT	0
159218	159208	14147R	PARTICIPANT	\N	PRESENT	0
158010	158004	08060W	PARTICIPANT	\N	PRESENT	0
157907	157890	14033T	PARTICIPANT	\N	PRESENT	0
157908	157890	14081Q	PARTICIPANT	\N	PRESENT	0
157909	157890	11099A	PARTICIPANT	\N	PRESENT	0
157910	157890	04049K	PARTICIPANT	\N	PRESENT	0
157911	157890	04094Q	PARTICIPANT	\N	PRESENT	0
157912	157890	11111C	PARTICIPANT	\N	PRESENT	0
159219	159208	14223L	PARTICIPANT	\N	PRESENT	0
157914	157890	11100Y	PRESIDENT	0	PRESENT	0
157915	157890	01061S	PARTICIPANT	\N	EXCUSE	0
157916	157890	11098Y	PARTICIPANT	\N	PRESENT	0
158012	158004	14038Y	PARTICIPANT	\N	PRESENT	0
158013	158004	11114F	PARTICIPANT	\N	PRESENT	0
158014	158004	98023Q	PARTICIPANT	\N	PRESENT	0
157920	157890	08019V	PARTICIPANT	\N	PRESENT	0
157921	157890	14257W	PARTICIPANT	\N	PRESENT	0
157922	157890	08021P	PARTICIPANT	\N	EXCUSE	0
157923	157890	04088S	PARTICIPANT	\N	PRESENT	0
157924	157890	98050T	PARTICIPANT	\N	PRESENT	0
157925	157890	11090Q	PARTICIPANT	\N	PRESENT	0
157926	157890	11046L	PARTICIPANT	\N	PRESENT	0
157927	157890	01058X	PARTICIPANT	\N	PRESENT	0
157928	157890	11094U	PARTICIPANT	\N	PRESENT	0
157929	157890	11066Q	PARTICIPANT	\N	PRESENT	0
159220	159208	04092N	PRESIDENT	0	PRESENT	0
158016	158004	01015L	PARTICIPANT	\N	PRESENT	0
158017	158004	11107G	PARTICIPANT	\N	PRESENT	0
159221	159208	14265W	PARTICIPANT	\N	PRESENT	0
159222	159208	14028W	PARTICIPANT	\N	PRESENT	0
158020	158004	01022K	PARTICIPANT	\N	PRESENT	0
158021	158004	05001W	PARTICIPANT	\N	PRESENT	0
158022	158004	04097T	PARTICIPANT	\N	PRESENT	0
159223	159208	11094U	PARTICIPANT	\N	EXCUSE	0
158024	158004	11059R	PARTICIPANT	\N	PRESENT	0
159352	157272	14231L	PARTICIPANT	\N	EXCUSE	0
158026	158004	80027E	PARTICIPANT	\N	PRESENT	0
158027	158004	14031R	PARTICIPANT	\N	PRESENT	0
158028	158004	08009T	PRESIDENT	0	PRESENT	0
158029	158004	08062Y	PARTICIPANT	\N	PRESENT	0
158030	158004	14221J	PARTICIPANT	\N	PRESENT	0
159353	157272	04045F	PARTICIPANT	\N	EXCUSE	0
158032	158004	08042U	PARTICIPANT	\N	PRESENT	0
158033	158004	14169X	PARTICIPANT	\N	PRESENT	0
158034	158004	14237S	PARTICIPANT	\N	PRESENT	0
159513	159512	07024N	PARTICIPANT	\N	PRESENT	0
158036	158004	05012A	PARTICIPANT	\N	PRESENT	0
159514	159512	04043D	PARTICIPANT	\N	PRESENT	0
158038	158004	14135M	PARTICIPANT	\N	PRESENT	0
159515	159512	14041T	PARTICIPANT	\N	PRESENT	0
158040	158004	95062K	PARTICIPANT	\N	PRESENT	0
158041	158004	14107H	PARTICIPANT	\N	PRESENT	0
158042	158004	14051J	PARTICIPANT	\N	PRESENT	0
158043	158004	14157T	PARTICIPANT	\N	PRESENT	0
159516	159512	08012N	PARTICIPANT	\N	PRESENT	0
159754	158052	14221J	PARTICIPANT	\N	PRESENT	0
159755	158052	11039M	PARTICIPANT	\N	PRESENT	0
159756	158052	01016M	PARTICIPANT	\N	PRESENT	0
159757	158052	04033B	PARTICIPANT	\N	PRESENT	0
159758	158052	14331P	PARTICIPANT	\N	PRESENT	0
159759	158052	14135M	PARTICIPANT	\N	PRESENT	0
159760	158052	14193X	PARTICIPANT	\N	PRESENT	0
159761	158052	98023Q	PARTICIPANT	\N	PRESENT	0
159762	158052	10015M	PARTICIPANT	\N	PRESENT	0
159763	158052	11010L	PARTICIPANT	\N	PRESENT	0
159764	158052	14255U	PARTICIPANT	\N	PRESENT	0
159765	158052	08056B	PARTICIPANT	\N	PRESENT	0
159766	158052	01022K	PARTICIPANT	\N	PRESENT	0
159767	158052	12041X	PARTICIPANT	\N	PRESENT	0
159768	158052	01013J	PARTICIPANT	\N	PRESENT	0
159769	158052	04085P	PARTICIPANT	\N	PRESENT	0
159770	158052	14235Q	PARTICIPANT	\N	PRESENT	0
159771	158052	04050C	PARTICIPANT	\N	PRESENT	0
159772	158052	11034G	PARTICIPANT	\N	PRESENT	0
159773	158052	14133K	PARTICIPANT	\N	PRESENT	0
159774	158052	98046X	PARTICIPANT	\N	PRESENT	0
159775	158052	14207L	PARTICIPANT	\N	PRESENT	0
159776	158052	04053F	PARTICIPANT	\N	PRESENT	0
159777	158052	11088W	PARTICIPANT	\N	PRESENT	0
159778	158052	04035D	PARTICIPANT	\N	PRESENT	0
159779	158052	01059Y	PARTICIPANT	\N	PRESENT	0
159780	158052	04066L	PARTICIPANT	\N	PRESENT	0
159781	158052	14038Y	PARTICIPANT	\N	PRESENT	0
159782	158052	04059M	PARTICIPANT	\N	PRESENT	0
159783	158052	04054G	PARTICIPANT	\N	PRESENT	0
159784	158052	14031R	PARTICIPANT	\N	PRESENT	0
159785	158052	04034C	PARTICIPANT	\N	PRESENT	0
159786	158052	14199E	PARTICIPANT	\N	PRESENT	0
159787	158052	08058D	PARTICIPANT	\N	PRESENT	0
146251	146193	14223L	PARTICIPANT	\N	PRESENT	0
146252	146193	08041T	PARTICIPANT	\N	PRESENT	0
146254	146193	14265W	PARTICIPANT	\N	PRESENT	0
146255	146193	86044G	PARTICIPANT	\N	PRESENT	0
146267	146193	14018U	PARTICIPANT	\N	PRESENT	0
146268	146193	14267Y	PARTICIPANT	\N	PRESENT	0
146269	146193	14219Q	PARTICIPANT	\N	PRESENT	0
146270	146193	11105E	PARTICIPANT	\N	PRESENT	0
146271	146193	04088S	PARTICIPANT	\N	PRESENT	0
146272	146193	08056B	PARTICIPANT	\N	PRESENT	0
146273	146193	04045F	PARTICIPANT	\N	PRESENT	0
146274	146193	92015P	PARTICIPANT	\N	PRESENT	0
146275	146193	01011G	PARTICIPANT	\N	PRESENT	0
146276	146193	04067M	PARTICIPANT	\N	PRESENT	0
146277	146193	04081K	PARTICIPANT	\N	PRESENT	0
146278	146193	11103C	PARTICIPANT	\N	PRESENT	0
146279	146193	11014C	PARTICIPANT	\N	PRESENT	0
146280	146193	14217N	PARTICIPANT	\N	PRESENT	0
146281	146193	14061L	PARTICIPANT	\N	PRESENT	0
146282	146193	14087W	PARTICIPANT	\N	PRESENT	0
146283	146193	14071N	PARTICIPANT	\N	PRESENT	0
146284	146193	14033T	PARTICIPANT	\N	PRESENT	0
146285	146193	14119M	PARTICIPANT	\N	PRESENT	0
146286	146193	11061K	PARTICIPANT	\N	PRESENT	0
146287	146193	14281W	PARTICIPANT	\N	PRESENT	0
146288	146193	14187A	PARTICIPANT	\N	PRESENT	0
146289	146193	14269B	PARTICIPANT	\N	PRESENT	0
146290	146193	95015C	PARTICIPANT	\N	PRESENT	0
146291	146193	14069U	PARTICIPANT	\N	PRESENT	0
146292	146193	11031D	PARTICIPANT	\N	PRESENT	0
146293	146193	04056J	PARTICIPANT	\N	PRESENT	0
146294	146193	14209N	PARTICIPANT	\N	PRESENT	0
146295	146193	14133K	PARTICIPANT	\N	PRESENT	0
146296	146193	11036J	PARTICIPANT	\N	PRESENT	0
146297	146193	11112D	PARTICIPANT	\N	PRESENT	0
146298	146193	80013X	PARTICIPANT	\N	PRESENT	0
146299	146193	11082Q	PARTICIPANT	\N	PRESENT	0
146300	146193	11104D	PARTICIPANT	\N	PRESENT	0
146315	146193	14241N	PARTICIPANT	\N	PRESENT	0
146317	146193	14030Q	PARTICIPANT	\N	PRESENT	0
146327	146193	04041B	PARTICIPANT	\N	PRESENT	0
146328	146193	14107H	PARTICIPANT	\N	PRESENT	0
146356	146193	11012A	PARTICIPANT	\N	PRESENT	0
146398	146193	11081P	PARTICIPANT	\N	PRESENT	0
146399	146193	04066L	PARTICIPANT	\N	PRESENT	0
146400	146193	14037X	PARTICIPANT	\N	PRESENT	0
146401	146193	14053L	PARTICIPANT	\N	PRESENT	0
146402	146193	11048N	PARTICIPANT	\N	PRESENT	0
146440	146193	08015R	PARTICIPANT	\N	PRESENT	0
146443	146193	14199E	PARTICIPANT	\N	PRESENT	0
146463	146193	11084S	PARTICIPANT	\N	PRESENT	0
146464	146193	14221J	PARTICIPANT	\N	PRESENT	0
146465	146193	11083R	PARTICIPANT	\N	PRESENT	0
146475	146193	14073Q	PARTICIPANT	\N	PRESENT	0
146477	146193	14083S	PARTICIPANT	\N	PRESENT	0
146534	146195	86034E	PARTICIPANT	\N	PRESENT	0
146567	146195	95062K	PARTICIPANT	\N	PRESENT	0
146568	146195	14211G	PARTICIPANT	\N	PRESENT	0
146569	146195	04036E	PARTICIPANT	\N	PRESENT	0
146570	146195	04035D	PARTICIPANT	\N	PRESENT	0
146571	146195	96004D	PARTICIPANT	\N	PRESENT	0
146572	146195	95031C	PARTICIPANT	\N	PRESENT	0
146573	146195	95030B	PARTICIPANT	\N	PRESENT	0
146574	146195	92040Q	PARTICIPANT	\N	PRESENT	0
146575	146195	86044G	PARTICIPANT	\N	PRESENT	0
146576	146195	04042C	PARTICIPANT	\N	PRESENT	0
146577	146195	11080N	PARTICIPANT	\N	PRESENT	0
146578	146195	04044E	PARTICIPANT	\N	PRESENT	0
146579	146195	14223L	PARTICIPANT	\N	PRESENT	0
146580	146195	08011M	PARTICIPANT	\N	PRESENT	0
146581	146195	95015C	PARTICIPANT	\N	PRESENT	0
146582	146195	95041E	PARTICIPANT	\N	PRESENT	0
146583	146195	11048N	PARTICIPANT	\N	PRESENT	0
146584	146195	14026U	PARTICIPANT	\N	PRESENT	0
146585	146195	14071N	PARTICIPANT	\N	PRESENT	0
146586	146195	14069U	PARTICIPANT	\N	PRESENT	0
146587	146195	04041B	PARTICIPANT	\N	PRESENT	0
146588	146195	14253S	PARTICIPANT	\N	PRESENT	0
146589	146195	08041T	PARTICIPANT	\N	PRESENT	0
146590	146195	77002U	PARTICIPANT	\N	PRESENT	0
146591	146195	11043H	PARTICIPANT	\N	PRESENT	0
146592	146195	11049P	PARTICIPANT	\N	PRESENT	0
146593	146195	11103C	PARTICIPANT	\N	PRESENT	0
146594	146195	14217N	PARTICIPANT	\N	PRESENT	0
146595	146195	14193X	PARTICIPANT	\N	PRESENT	0
146596	146195	14259Y	PARTICIPANT	\N	PRESENT	0
146597	146195	14111D	PARTICIPANT	\N	PRESENT	0
146598	146195	14209N	PARTICIPANT	\N	PRESENT	0
146599	146195	14191V	PARTICIPANT	\N	PRESENT	0
146600	146195	04061F	PARTICIPANT	\N	PRESENT	0
146601	146195	08010L	PARTICIPANT	\N	PRESENT	0
146602	146195	01027Q	PARTICIPANT	\N	PRESENT	0
146603	146195	04086Q	PARTICIPANT	\N	PRESENT	0
146604	146195	98053W	PARTICIPANT	\N	PRESENT	0
146605	146195	07026Q	PARTICIPANT	\N	PRESENT	0
146606	146195	95035G	PARTICIPANT	\N	PRESENT	0
146607	146195	11034G	PARTICIPANT	\N	PRESENT	0
146608	146195	04050C	PARTICIPANT	\N	PRESENT	0
146609	146195	14079W	PARTICIPANT	\N	PRESENT	0
146610	146195	11063M	PARTICIPANT	\N	PRESENT	0
146611	146195	04054G	PARTICIPANT	\N	PRESENT	0
146612	146195	98023Q	PARTICIPANT	\N	PRESENT	0
146613	146195	01048V	PARTICIPANT	\N	PRESENT	0
146614	146195	14013P	PARTICIPANT	\N	PRESENT	0
146615	146195	01058X	PARTICIPANT	\N	PRESENT	0
146616	146195	14031R	PARTICIPANT	\N	PRESENT	0
146617	146195	14033T	PARTICIPANT	\N	PRESENT	0
146618	146195	01059Y	PARTICIPANT	\N	PRESENT	0
146619	146195	08034U	PARTICIPANT	\N	PRESENT	0
146620	146195	01015L	PARTICIPANT	\N	PRESENT	0
146621	146195	05012A	PARTICIPANT	\N	PRESENT	0
146622	146195	11033F	PARTICIPANT	\N	PRESENT	0
146623	146195	04067M	PARTICIPANT	\N	PRESENT	0
146624	146195	01044R	PARTICIPANT	\N	PRESENT	0
146625	146195	11029K	PARTICIPANT	\N	PRESENT	0
146626	146195	11055M	PARTICIPANT	\N	PRESENT	0
146627	146195	11030C	PARTICIPANT	\N	PRESENT	0
146628	146195	11083R	PARTICIPANT	\N	PRESENT	0
146629	146195	11099A	PARTICIPANT	\N	PRESENT	0
146630	146195	07029T	PARTICIPANT	\N	PRESENT	0
146631	146195	14331P	PARTICIPANT	\N	PRESENT	0
146632	146195	14247U	PARTICIPANT	\N	PRESENT	0
146633	146195	14087W	PARTICIPANT	\N	PRESENT	0
146634	146195	07034Q	PARTICIPANT	\N	PRESENT	0
146635	146195	08021P	PARTICIPANT	\N	PRESENT	0
146637	146195	08051V	PARTICIPANT	\N	PRESENT	0
146638	146195	01046T	PARTICIPANT	\N	PRESENT	0
146639	146195	88008L	PARTICIPANT	\N	PRESENT	0
146640	146195	04078Q	PARTICIPANT	\N	PRESENT	0
146641	146195	14135M	PARTICIPANT	\N	PRESENT	0
146642	146195	11012A	PARTICIPANT	\N	PRESENT	0
146643	146195	08031R	PARTICIPANT	\N	PRESENT	0
146644	146195	04047H	PARTICIPANT	\N	PRESENT	0
146645	146195	11081P	PARTICIPANT	\N	PRESENT	0
146646	146195	01003G	PARTICIPANT	\N	PRESENT	0
146647	146195	11096W	PARTICIPANT	\N	PRESENT	0
146648	146195	90003B	PARTICIPANT	\N	PRESENT	0
146649	146195	98022P	PARTICIPANT	\N	PRESENT	0
146650	146195	14241N	PARTICIPANT	\N	PRESENT	0
146651	146195	14061L	PARTICIPANT	\N	PRESENT	0
146652	146195	14059S	PARTICIPANT	\N	PRESENT	0
146653	146195	08016S	PARTICIPANT	\N	PRESENT	0
146654	146195	04057K	PARTICIPANT	\N	PRESENT	0
146655	146195	98035U	PARTICIPANT	\N	PRESENT	0
146656	146195	01016M	PARTICIPANT	\N	PRESENT	0
146657	146195	04092N	PARTICIPANT	\N	PRESENT	0
146658	146195	04056J	PARTICIPANT	\N	PRESENT	0
146659	146195	04074L	PARTICIPANT	\N	PRESENT	0
146660	146195	11039M	PARTICIPANT	\N	PRESENT	0
146661	146195	04085P	PARTICIPANT	\N	PRESENT	0
146662	146195	11090Q	PARTICIPANT	\N	PRESENT	0
146663	146195	05008E	PARTICIPANT	\N	PRESENT	0
146664	146195	92015P	PARTICIPANT	\N	PRESENT	0
146665	146195	10006L	PARTICIPANT	\N	PRESENT	0
146666	146195	98046X	PARTICIPANT	\N	PRESENT	0
146667	146195	08052W	PARTICIPANT	\N	PRESENT	0
146668	146195	08055A	PARTICIPANT	\N	PRESENT	0
146669	146195	14107H	PARTICIPANT	\N	PRESENT	0
146670	146195	14249W	PARTICIPANT	\N	PRESENT	0
146671	146195	11027H	PARTICIPANT	\N	PRESENT	0
146672	146195	04066L	PARTICIPANT	\N	PRESENT	0
146673	146195	01011G	PARTICIPANT	\N	PRESENT	0
146674	146195	01008M	PARTICIPANT	\N	PRESENT	0
146675	146195	11061K	PARTICIPANT	\N	PRESENT	0
146676	146195	92020L	PARTICIPANT	\N	PRESENT	0
146677	146195	04033B	PARTICIPANT	\N	PRESENT	0
146678	146195	80013X	PARTICIPANT	\N	PRESENT	0
130700	130699	11100Y	PARTICIPANT	\N	PRESENT	0
130701	130699	14187A	PARTICIPANT	\N	PRESENT	0
130702	130699	14231L	PARTICIPANT	\N	PRESENT	0
130703	130699	04086Q	PARTICIPANT	\N	PRESENT	0
130704	130699	11104D	PARTICIPANT	\N	PRESENT	0
130705	130699	11046L	PARTICIPANT	\N	PRESENT	0
130706	130699	11034G	PARTICIPANT	\N	PRESENT	0
130707	130699	11090Q	PARTICIPANT	\N	PRESENT	0
130708	130699	01028R	PARTICIPANT	\N	PRESENT	0
131133	131132	01008M	PARTICIPANT	\N	EXCUSE	0
131134	131132	11036J	PARTICIPANT	\N	PRESENT	0
131135	131132	11081P	PARTICIPANT	\N	PRESENT	0
131136	131132	14013P	PARTICIPANT	\N	PRESENT	0
131172	131132	11057P	PARTICIPANT	\N	PRESENT	0
131138	131132	14207L	PARTICIPANT	\N	PRESENT	0
131139	131132	11101A	PARTICIPANT	\N	PRESENT	0
131140	131132	90003B	PARTICIPANT	\N	PRESENT	0
131141	131132	08028W	PARTICIPANT	\N	PRESENT	0
131142	131132	80013X	PARTICIPANT	\N	PRESENT	0
131143	131132	08038Y	PARTICIPANT	\N	PRESENT	0
131144	131132	04089T	PARTICIPANT	\N	EXCUSE	0
131145	131132	14197C	PARTICIPANT	\N	PRESENT	0
131146	131132	11110B	PARTICIPANT	\N	PRESENT	0
131147	131132	14187A	PARTICIPANT	\N	PRESENT	0
131148	131132	14033T	PARTICIPANT	\N	PRESENT	0
131149	131132	14081Q	PARTICIPANT	\N	PRESENT	0
131150	131132	04048J	PARTICIPANT	\N	EXCUSE	0
131152	131132	04049K	PARTICIPANT	\N	PRESENT	0
131153	131132	04094Q	PARTICIPANT	\N	PRESENT	0
131154	131132	11111C	PARTICIPANT	\N	PRESENT	0
131155	131132	08015R	PARTICIPANT	\N	PRESENT	0
131156	131132	11100Y	PRESIDENT	0	PRESENT	0
131158	131132	11098Y	PARTICIPANT	\N	PRESENT	0
131159	131132	01043Q	PARTICIPANT	\N	PRESENT	0
131160	131132	11077T	PARTICIPANT	\N	PRESENT	0
131161	131132	14205J	PARTICIPANT	\N	PRESENT	0
131163	131132	14257W	PARTICIPANT	\N	PRESENT	0
131164	131132	08021P	PARTICIPANT	\N	PRESENT	0
131165	131132	04088S	PARTICIPANT	\N	PRESENT	0
131534	131533	98046X	PARTICIPANT	\N	PRESENT	0
131167	131132	11090Q	PARTICIPANT	\N	PRESENT	0
131168	131132	11046L	PARTICIPANT	\N	PRESENT	0
131169	131132	01058X	PARTICIPANT	\N	PRESENT	0
131170	131132	11094U	PARTICIPANT	\N	PRESENT	0
131171	131132	11066Q	PARTICIPANT	\N	PRESENT	0
131535	131533	08015R	PARTICIPANT	\N	PRESENT	0
131536	131533	11026G	PARTICIPANT	\N	PRESENT	0
131537	131533	04070G	PARTICIPANT	\N	PRESENT	0
131538	131533	11090Q	PARTICIPANT	\N	PRESENT	0
131539	131533	14209N	PARTICIPANT	\N	PRESENT	0
131540	131533	04077P	PARTICIPANT	\N	PRESENT	0
132759	130821	11039M	PARTICIPANT	\N	PRESENT	0
132762	130821	11029K	PARTICIPANT	\N	PRESENT	0
136746	136745	01024M	PARTICIPANT	\N	PRESENT	0
136768	136767	01046T	PARTICIPANT	\N	PRESENT	0
136770	136769	01046T	PARTICIPANT	\N	PRESENT	0
137143	137142	11076S	PARTICIPANT	\N	PRESENT	0
137144	137142	04054G	PARTICIPANT	\N	PRESENT	0
137145	137142	04040A	PARTICIPANT	\N	EXCUSE	0
137146	137142	08058D	PARTICIPANT	\N	PRESENT	0
137274	137256	11076S	PARTICIPANT	\N	PRESENT	0
137148	137142	77002U	PARTICIPANT	\N	PRESENT	0
137149	137142	98029W	PARTICIPANT	\N	PRESENT	0
137275	137256	04054G	PARTICIPANT	\N	PRESENT	0
137151	137142	11027H	PARTICIPANT	\N	PRESENT	0
137276	137256	04040A	PARTICIPANT	\N	PRESENT	0
137153	137142	92018S	PARTICIPANT	\N	PRESENT	0
137154	137142	92020L	PARTICIPANT	\N	EXCUSE	0
137277	137256	08058D	PARTICIPANT	\N	PRESENT	0
137156	137142	11096W	PARTICIPANT	\N	PRESENT	0
137157	137142	95031C	PARTICIPANT	\N	PRESENT	0
137279	137256	77002U	PARTICIPANT	\N	PRESENT	0
137280	137256	98029W	PARTICIPANT	\N	PRESENT	0
137161	137142	07024N	PARTICIPANT	\N	PRESENT	0
137164	137142	11015D	PARTICIPANT	\N	PRESENT	0
137165	137142	07004J	PARTICIPANT	\N	PRESENT	0
137166	137142	95035G	PARTICIPANT	\N	PRESENT	0
137167	137142	08056B	PARTICIPANT	\N	PRESENT	0
137168	137142	14211G	PARTICIPANT	\N	PRESENT	0
137169	137142	98022P	PARTICIPANT	\N	EXCUSE	0
137170	137142	11064N	PARTICIPANT	\N	PRESENT	0
137171	137142	95037J	PARTICIPANT	\N	PRESENT	0
137172	137142	04078Q	PARTICIPANT	\N	PRESENT	0
137173	137142	14097Y	PARTICIPANT	\N	PRESENT	0
137174	137142	95041E	PARTICIPANT	\N	PRESENT	0
137284	137256	92018S	PARTICIPANT	\N	PRESENT	0
137285	137256	92020L	PARTICIPANT	\N	EXCUSE	0
137286	137256	95030B	PARTICIPANT	\N	PRESENT	0
137179	137142	92031P	PARTICIPANT	\N	PRESENT	0
137180	137142	11106F	PARTICIPANT	\N	PRESENT	0
137181	137142	14251Q	PARTICIPANT	\N	PRESENT	0
137182	137142	83042R	PARTICIPANT	\N	PRESENT	0
137183	137142	08053X	PARTICIPANT	\N	PRESENT	0
137184	137142	11082Q	PARTICIPANT	\N	PRESENT	0
137185	137142	11105E	PARTICIPANT	\N	PRESENT	0
137186	137142	14253S	PARTICIPANT	\N	PRESENT	0
137187	137142	08047A	PARTICIPANT	\N	PRESENT	0
137188	137142	14028W	PARTICIPANT	\N	EXCUSE	0
137189	137142	14193X	PARTICIPANT	\N	PRESENT	0
137190	137142	98021N	PARTICIPANT	\N	PRESENT	0
137191	137142	04080J	PARTICIPANT	\N	PRESENT	0
137192	137142	95059Q	PRESIDENT	0	PRESENT	0
137193	137142	86044G	PARTICIPANT	\N	EXCUSE	0
137194	137142	01014K	PARTICIPANT	\N	PRESENT	0
137195	137142	11054L	PARTICIPANT	\N	PRESENT	0
137197	137142	92044U	PARTICIPANT	\N	PRESENT	0
137198	137142	08049C	PARTICIPANT	\N	EXCUSE	0
137199	137142	04050C	PARTICIPANT	\N	PRESENT	0
137292	137256	07024N	PARTICIPANT	\N	PRESENT	0
137294	137256	14014Q	PARTICIPANT	\N	PRESENT	0
137295	137256	11015D	PARTICIPANT	\N	PRESENT	0
137296	137256	07004J	PARTICIPANT	\N	PRESENT	0
137297	137256	95035G	PARTICIPANT	\N	PRESENT	0
137298	137256	08056B	PARTICIPANT	\N	PRESENT	0
137299	137256	14211G	PARTICIPANT	\N	PRESENT	0
137300	137256	98022P	PARTICIPANT	\N	EXCUSE	0
137303	137256	04078Q	PARTICIPANT	\N	PRESENT	0
137304	137256	14097Y	PARTICIPANT	\N	PRESENT	0
141275	141072	01048V	PARTICIPANT	\N	PRESENT	0
141276	141072	14061L	PARTICIPANT	\N	PRESENT	0
141277	141072	01057W	PARTICIPANT	\N	PRESENT	0
141278	141072	11033F	PARTICIPANT	\N	PRESENT	0
141279	141072	14087W	PARTICIPANT	\N	PRESENT	0
141280	141072	04041B	PARTICIPANT	\N	PRESENT	0
141281	141072	01044R	PARTICIPANT	\N	PRESENT	0
141282	141072	95062K	PARTICIPANT	\N	PRESENT	0
141283	141072	11029K	PARTICIPANT	\N	PRESENT	0
141284	141072	11055M	PARTICIPANT	\N	PRESENT	0
141285	141072	01027Q	PARTICIPANT	\N	PRESENT	0
141286	141072	04067M	PARTICIPANT	\N	PRESENT	0
141287	141072	13002U	PARTICIPANT	\N	PRESENT	0
141288	141072	11083R	PARTICIPANT	\N	PRESENT	0
141289	141072	11065P	PARTICIPANT	\N	PRESENT	0
141290	141072	11076S	PARTICIPANT	\N	PRESENT	0
141291	141072	10015M	PARTICIPANT	\N	PRESENT	0
141292	141072	11097X	PARTICIPANT	\N	PRESENT	0
141293	141072	01060R	PARTICIPANT	\N	PRESENT	0
141294	141072	04074L	PARTICIPANT	\N	PRESENT	0
141295	141072	08021P	PARTICIPANT	\N	PRESENT	0
141296	141072	11088W	PARTICIPANT	\N	PRESENT	0
141297	141072	92045V	PARTICIPANT	\N	PRESENT	0
141298	141072	04071H	PARTICIPANT	\N	PRESENT	0
141299	141072	14111D	PARTICIPANT	\N	PRESENT	0
141300	141072	01046T	PARTICIPANT	\N	PRESENT	0
141301	141072	88008L	PARTICIPANT	\N	PRESENT	0
141302	141072	98050T	PARTICIPANT	\N	PRESENT	0
141303	141072	04078Q	PARTICIPANT	\N	PRESENT	0
141304	141072	11012A	PARTICIPANT	\N	PRESENT	0
141305	141072	08049C	PARTICIPANT	\N	PRESENT	0
141306	141072	14133K	PARTICIPANT	\N	PRESENT	0
141307	141072	08051V	PARTICIPANT	\N	PRESENT	0
141308	141072	05004A	PARTICIPANT	\N	PRESENT	0
141309	141072	14018U	PARTICIPANT	\N	PRESENT	0
141310	141072	08031R	PARTICIPANT	\N	PRESENT	0
141311	141072	04035D	PARTICIPANT	\N	PRESENT	0
141312	141072	01003G	PARTICIPANT	\N	PRESENT	0
141313	141072	11096W	PARTICIPANT	\N	PRESENT	0
141314	141072	14261S	PARTICIPANT	\N	PRESENT	0
141315	141072	08010L	PARTICIPANT	\N	PRESENT	0
141316	141072	14201E	PARTICIPANT	\N	PRESENT	0
141317	141072	04033B	PARTICIPANT	\N	PRESENT	0
141318	141072	98022P	PARTICIPANT	\N	PRESENT	0
141319	141072	14239U	PARTICIPANT	\N	PRESENT	0
141320	141072	08034U	PARTICIPANT	\N	PRESENT	0
141321	141072	77002U	PARTICIPANT	\N	PRESENT	0
141322	141072	04061F	PARTICIPANT	\N	PRESENT	0
141323	141072	04081K	PARTICIPANT	\N	PRESENT	0
141324	141072	08016S	PARTICIPANT	\N	PRESENT	0
141325	141072	98035U	PARTICIPANT	\N	PRESENT	0
141326	141072	01016M	PARTICIPANT	\N	PRESENT	0
141327	141072	04056J	PARTICIPANT	\N	PRESENT	0
141328	141072	14265W	PARTICIPANT	\N	PRESENT	0
141329	141072	11039M	PARTICIPANT	\N	PRESENT	0
141330	141072	14051J	PARTICIPANT	\N	PRESENT	0
141331	141072	08025T	PARTICIPANT	\N	PRESENT	0
141332	141072	95063L	PARTICIPANT	\N	PRESENT	0
141333	141072	14209N	PARTICIPANT	\N	PRESENT	0
141334	141072	14079W	PARTICIPANT	\N	PRESENT	0
141335	141072	92015P	PARTICIPANT	\N	PRESENT	0
141336	141072	08055A	PARTICIPANT	\N	PRESENT	0
141337	141072	92031P	PARTICIPANT	\N	PRESENT	0
141338	141072	04066L	PARTICIPANT	\N	PRESENT	0
141339	141072	14071N	PARTICIPANT	\N	PRESENT	0
141340	141072	01011G	PARTICIPANT	\N	PRESENT	0
141341	141072	11057P	PARTICIPANT	\N	PRESENT	0
141342	141072	01013J	PARTICIPANT	\N	PRESENT	0
141343	141072	98046X	PARTICIPANT	\N	PRESENT	0
141344	141072	99004R	PARTICIPANT	\N	PRESENT	0
141345	141072	98053W	PARTICIPANT	\N	PRESENT	0
141346	141072	98018T	PARTICIPANT	\N	PRESENT	0
141347	141072	01022K	PARTICIPANT	\N	PRESENT	0
141348	141072	14028W	PARTICIPANT	\N	PRESENT	0
141349	141072	08060W	PARTICIPANT	\N	PRESENT	0
141350	141072	98023Q	PARTICIPANT	\N	PRESENT	0
141351	141072	11084S	PARTICIPANT	\N	PRESENT	0
141352	141072	14065Q	PARTICIPANT	\N	PRESENT	0
141353	141072	95030B	PARTICIPANT	\N	PRESENT	0
141354	141072	08043V	PARTICIPANT	\N	PRESENT	0
141355	141072	04034C	PARTICIPANT	\N	PRESENT	0
141356	141072	11061K	PARTICIPANT	\N	PRESENT	0
141357	141072	08012N	PARTICIPANT	\N	PRESENT	0
141358	141072	11036J	PARTICIPANT	\N	PRESENT	0
141359	141072	14105F	PARTICIPANT	\N	PRESENT	0
141360	141072	08058D	PARTICIPANT	\N	PRESENT	0
141361	141072	95037J	PARTICIPANT	\N	PRESENT	0
141362	141072	11059R	PARTICIPANT	\N	PRESENT	0
141363	141072	83042R	PARTICIPANT	\N	PRESENT	0
141364	141072	14119M	PARTICIPANT	\N	PRESENT	0
141365	141072	14271U	PARTICIPANT	\N	PRESENT	0
141366	141072	14225N	PARTICIPANT	\N	PRESENT	0
141367	141072	08073C	PARTICIPANT	\N	PRESENT	0
141368	141072	14109K	PARTICIPANT	\N	PRESENT	0
141369	141072	08014Q	PARTICIPANT	\N	PRESENT	0
141370	141072	14001X	PARTICIPANT	\N	PRESENT	0
141371	141072	80027E	PARTICIPANT	\N	PRESENT	0
141372	141072	14037X	PARTICIPANT	\N	PRESENT	0
141373	141072	14167V	PARTICIPANT	\N	PRESENT	0
141374	141072	11054L	PARTICIPANT	\N	PRESENT	0
141375	141072	14187A	PARTICIPANT	\N	PRESENT	0
141376	141072	11014C	PARTICIPANT	\N	PRESENT	0
141377	141072	14169X	PARTICIPANT	\N	PRESENT	0
141378	141072	14253S	PARTICIPANT	\N	PRESENT	0
141379	141072	14227Q	PARTICIPANT	\N	PRESENT	0
141380	141072	14281W	PARTICIPANT	\N	PRESENT	0
141381	141072	04079R	PARTICIPANT	\N	PRESENT	0
141382	141072	11043H	PARTICIPANT	\N	PRESENT	0
141383	141072	14121F	PARTICIPANT	\N	PRESENT	0
141384	141072	14207L	PARTICIPANT	\N	PRESENT	0
141385	141072	14257W	PARTICIPANT	\N	PRESENT	0
141386	141072	11109J	PARTICIPANT	\N	PRESENT	0
141387	141072	04043D	PARTICIPANT	\N	PRESENT	0
141388	141072	04077P	PARTICIPANT	\N	PRESENT	0
141389	141072	98021N	PARTICIPANT	\N	PRESENT	0
141390	141072	11099A	PARTICIPANT	\N	PRESENT	0
141392	141072	14241N	PARTICIPANT	\N	PRESENT	0
141396	141391	14157T	PARTICIPANT	\N	PRESENT	0
141397	141072	11048N	PARTICIPANT	\N	PRESENT	0
141395	141391	14253S	PARTICIPANT	\N	PRESENT	0
141398	141072	01028R	PARTICIPANT	\N	PRESENT	0
141399	141072	99002P	PARTICIPANT	\N	PRESENT	0
141400	141072	08038Y	PARTICIPANT	\N	PRESENT	0
141401	141072	11035H	PARTICIPANT	\N	PRESENT	0
141402	141072	08024S	PARTICIPANT	\N	PRESENT	0
141403	141072	01037S	PARTICIPANT	\N	PRESENT	0
141404	141072	11106F	PARTICIPANT	\N	PRESENT	0
141405	141072	14085U	PARTICIPANT	\N	PRESENT	0
141406	141072	11066Q	PARTICIPANT	\N	PRESENT	0
141407	141072	14014Q	PARTICIPANT	\N	PRESENT	0
141408	141072	14081Q	PARTICIPANT	\N	PRESENT	0
141409	141072	11042G	PARTICIPANT	\N	PRESENT	0
141410	141072	04095R	PARTICIPANT	\N	PRESENT	0
141411	141072	04094Q	PARTICIPANT	\N	PRESENT	0
141412	141072	14213J	PARTICIPANT	\N	PRESENT	0
141414	141072	14159V	PARTICIPANT	\N	PRESENT	0
141416	141072	14217N	PARTICIPANT	\N	PRESENT	0
141417	141072	11025F	PARTICIPANT	\N	PRESENT	0
141418	141072	12042Y	PARTICIPANT	\N	PRESENT	0
141419	141072	11023D	PARTICIPANT	\N	PRESENT	0
141420	141072	11114F	PARTICIPANT	\N	PRESENT	0
141421	141072	11113E	PARTICIPANT	\N	PRESENT	0
141422	141072	11072N	PARTICIPANT	\N	PRESENT	0
141423	141072	14039A	PARTICIPANT	\N	PRESENT	0
141426	141072	10006L	PARTICIPANT	\N	PRESENT	0
141428	141072	11030C	PARTICIPANT	\N	PRESENT	0
141429	141072	11053K	PARTICIPANT	\N	PRESENT	0
141430	141072	11094U	PARTICIPANT	\N	PRESENT	0
141431	141072	14034U	PARTICIPANT	\N	PRESENT	0
141432	141072	11071M	PARTICIPANT	\N	PRESENT	0
141433	141072	11064N	PARTICIPANT	\N	PRESENT	0
141434	141072	14179A	PARTICIPANT	\N	PRESENT	0
141435	141072	11081P	PARTICIPANT	\N	PRESENT	0
141436	141072	14042U	PARTICIPANT	\N	PRESENT	0
141438	141072	14267Y	PARTICIPANT	\N	PRESENT	0
141439	141072	14103D	PARTICIPANT	\N	PRESENT	0
141440	141072	14030Q	PARTICIPANT	\N	PRESENT	0
141441	141072	04038G	PARTICIPANT	\N	PRESENT	0
141442	141072	11089X	PARTICIPANT	\N	PRESENT	0
141443	141072	01043Q	PARTICIPANT	\N	PRESENT	0
141444	141072	01007L	PARTICIPANT	\N	PRESENT	0
141445	141072	14026U	PARTICIPANT	\N	PRESENT	0
141446	141072	07004J	PARTICIPANT	\N	PRESENT	0
141447	141072	14327T	PARTICIPANT	\N	PRESENT	0
141448	141072	09001P	PARTICIPANT	\N	PRESENT	0
141449	141072	01025N	PARTICIPANT	\N	PRESENT	0
141450	141072	01024M	PARTICIPANT	\N	PRESENT	0
141451	141072	14255U	PARTICIPANT	\N	PRESENT	0
130487	130480	01008M	PARTICIPANT	\N	EXCUSE	0
130488	130480	14089Y	PARTICIPANT	\N	EXCUSE	0
130489	130480	08060W	PARTICIPANT	\N	EXCUSE	0
130490	130480	08028W	PARTICIPANT	\N	EXCUSE	0
130491	130480	88008L	PARTICIPANT	\N	EXCUSE	0
130492	130480	04038G	PARTICIPANT	\N	EXCUSE	0
130493	130480	01059Y	PARTICIPANT	\N	EXCUSE	0
130494	130480	01015L	PARTICIPANT	\N	EXCUSE	0
130495	130480	01041N	PARTICIPANT	\N	EXCUSE	0
130496	130480	02002K	PARTICIPANT	\N	EXCUSE	0
130497	130480	99004R	PRESIDENT	0	PRESENT	0
130498	130480	04061F	PARTICIPANT	\N	PRESENT	0
130499	130480	08012N	PARTICIPANT	\N	EXCUSE	0
130500	130480	11046L	PARTICIPANT	\N	EXCUSE	0
130501	130480	01028R	PARTICIPANT	\N	PRESENT	0
130502	130480	11094U	PARTICIPANT	\N	EXCUSE	0
130503	130480	11066Q	PARTICIPANT	\N	EXCUSE	0
130521	130520	01008M	PARTICIPANT	\N	EXCUSE	0
130595	130520	14089Y	PARTICIPANT	\N	EXCUSE	0
130596	130520	08060W	PARTICIPANT	\N	EXCUSE	0
130598	130520	08028W	PARTICIPANT	\N	EXCUSE	0
130599	130520	88008L	PARTICIPANT	\N	EXCUSE	0
130600	130520	04038G	PARTICIPANT	\N	EXCUSE	0
130601	130520	01059Y	PARTICIPANT	\N	EXCUSE	0
130602	130520	01015L	PARTICIPANT	\N	EXCUSE	0
130603	130520	01041N	PARTICIPANT	\N	EXCUSE	0
130605	130520	02002K	PARTICIPANT	\N	EXCUSE	0
130609	130520	99004R	PRESIDENT	0	PRESENT	0
130611	130520	04061F	PARTICIPANT	\N	PRESENT	0
130615	130520	08012N	PARTICIPANT	\N	EXCUSE	0
130616	130520	11046L	PARTICIPANT	\N	EXCUSE	0
130617	130520	01028R	PARTICIPANT	\N	PRESENT	0
130618	130520	11094U	PARTICIPANT	\N	EXCUSE	0
130620	130520	11066Q	PARTICIPANT	\N	EXCUSE	0
130622	130621	01008M	PARTICIPANT	\N	EXCUSE	0
130623	130621	14089Y	PARTICIPANT	\N	EXCUSE	0
130624	130621	08060W	PARTICIPANT	\N	EXCUSE	0
130625	130621	08028W	PARTICIPANT	\N	EXCUSE	0
130626	130621	88008L	PARTICIPANT	\N	EXCUSE	0
130627	130621	11046L	PARTICIPANT	\N	EXCUSE	0
130628	130621	01028R	PARTICIPANT	\N	PRESENT	0
130629	130621	11094U	PARTICIPANT	\N	EXCUSE	0
130630	130621	11066Q	PARTICIPANT	\N	EXCUSE	0
131022	131021	11089X	PARTICIPANT	\N	PRESENT	0
131024	131023	11089X	PARTICIPANT	\N	PRESENT	0
131632	131631	11035H	PARTICIPANT	\N	PRESENT	0
131076	131074	04054G	PARTICIPANT	\N	PRESENT	0
131077	131074	04040A	PARTICIPANT	\N	PRESENT	0
131078	131074	08058D	PARTICIPANT	\N	PRESENT	0
131079	131074	04042C	PARTICIPANT	\N	PRESENT	0
131636	131635	11035H	PARTICIPANT	\N	PRESENT	0
131081	131074	98029W	PARTICIPANT	\N	PRESENT	0
131082	131074	11080N	PARTICIPANT	\N	PRESENT	0
131083	131074	11027H	PARTICIPANT	\N	PRESENT	0
131084	131074	98018T	PARTICIPANT	\N	EXCUSE	0
131085	131074	92018S	PARTICIPANT	\N	PRESENT	0
131086	131074	92020L	PARTICIPANT	\N	EXCUSE	0
131087	131074	95030B	PARTICIPANT	\N	PRESENT	0
134593	127238	04049K	PRESIDENT	0	PRESENT	0
134594	127238	14105F	PARTICIPANT	\N	PRESENT	0
131090	131074	97011G	PARTICIPANT	\N	PRESENT	0
134595	127238	14253S	PARTICIPANT	\N	PRESENT	0
131092	131074	04035D	PARTICIPANT	\N	PRESENT	0
131093	131074	07024N	PARTICIPANT	\N	PRESENT	0
134596	127238	14061L	PARTICIPANT	\N	PRESENT	0
131095	131074	14014Q	PARTICIPANT	\N	PRESENT	0
134597	127238	08068F	PARTICIPANT	\N	PRESENT	0
134598	127238	14079W	PARTICIPANT	\N	PRESENT	0
131098	131074	95035G	PARTICIPANT	\N	PRESENT	0
131099	131074	08056B	PARTICIPANT	\N	PRESENT	0
131100	131074	14211G	PARTICIPANT	\N	PRESENT	0
131101	131074	98022P	PARTICIPANT	\N	PRESENT	0
131102	131074	11064N	PARTICIPANT	\N	PRESENT	0
134599	127238	14207L	PARTICIPANT	\N	PRESENT	0
131104	131074	04078Q	PARTICIPANT	\N	PRESENT	0
131105	131074	14097Y	PARTICIPANT	\N	PRESENT	0
131106	131074	95041E	PARTICIPANT	\N	PRESENT	0
131107	131074	04036E	PARTICIPANT	\N	PRESENT	0
131108	131074	14039A	PARTICIPANT	\N	PRESENT	0
134601	127238	95067Q	PARTICIPANT	\N	PRESENT	0
131110	131074	98005N	PARTICIPANT	\N	PRESENT	0
131111	131074	92031P	PARTICIPANT	\N	PRESENT	0
131112	131074	11106F	PARTICIPANT	\N	PRESENT	0
131113	131074	14251Q	PARTICIPANT	\N	PRESENT	0
131114	131074	83042R	PARTICIPANT	\N	PRESENT	0
134608	127238	14265W	PARTICIPANT	\N	PRESENT	0
134609	127238	04053F	PARTICIPANT	\N	PRESENT	0
131117	131074	11105E	PARTICIPANT	\N	PRESENT	0
134610	127238	14205J	PARTICIPANT	\N	PRESENT	0
131119	131074	08047A	PARTICIPANT	\N	PRESENT	0
131120	131074	14028W	PARTICIPANT	\N	PRESENT	0
134611	127238	14034U	PARTICIPANT	\N	PRESENT	0
131122	131074	98021N	PARTICIPANT	\N	PRESENT	0
131123	131074	04080J	PARTICIPANT	\N	PRESENT	0
131124	131074	95059Q	PRESIDENT	0	PRESENT	0
131125	131074	86044G	PARTICIPANT	\N	PRESENT	0
131126	131074	01014K	PARTICIPANT	\N	PRESENT	0
131127	131074	11054L	PARTICIPANT	\N	PRESENT	0
131128	131074	01056V	PARTICIPANT	\N	PRESENT	0
134614	127238	14065Q	PARTICIPANT	\N	EXCUSE	0
134615	127238	14030Q	PARTICIPANT	\N	EXCUSE	0
131131	131074	04050C	PARTICIPANT	\N	PRESENT	0
134616	127238	14013P	PARTICIPANT	\N	EXCUSE	0
134617	127238	14255U	PARTICIPANT	\N	EXCUSE	0
134618	127238	04055H	PARTICIPANT	\N	EXCUSE	0
134619	127238	11088W	PARTICIPANT	\N	EXCUSE	0
134620	127238	14041T	PARTICIPANT	\N	EXCUSE	0
134621	127238	14121F	PARTICIPANT	\N	EXCUSE	0
134622	127238	95041E	PARTICIPANT	\N	EXCUSE	0
134623	127238	14039A	PARTICIPANT	\N	EXCUSE	0
134624	127238	11077T	PARTICIPANT	\N	EXCUSE	0
134625	127238	11090Q	PARTICIPANT	\N	EXCUSE	0
134626	127238	10015M	PARTICIPANT	\N	EXCUSE	0
134627	127238	14157T	PARTICIPANT	\N	EXCUSE	0
134628	127238	14087W	PARTICIPANT	\N	EXCUSE	0
134690	132784	11023D	PARTICIPANT	\N	PRESENT	0
134691	132784	01027Q	PARTICIPANT	\N	PRESENT	0
134692	132784	14097Y	PARTICIPANT	\N	PRESENT	0
134693	132784	01022K	PARTICIPANT	\N	PRESENT	0
134694	132784	11106F	PARTICIPANT	\N	PRESENT	0
134696	132784	14059S	PARTICIPANT	\N	PRESENT	0
134697	132784	08019V	PRESIDENT	0	PRESENT	0
134698	132784	95062K	PARTICIPANT	\N	PRESENT	0
134699	132784	11109J	PARTICIPANT	\N	PRESENT	0
139394	139393	14119M	PARTICIPANT	\N	PRESENT	0
140232	140231	14030Q	PARTICIPANT	\N	PRESENT	0
140233	140231	08060W	PARTICIPANT	\N	EXCUSE	0
140234	140231	11029K	PARTICIPANT	\N	PRESENT	0
140235	140231	14038Y	PARTICIPANT	\N	EXCUSE	0
140236	140231	80013X	PARTICIPANT	\N	PRESENT	0
140237	140231	14217N	PARTICIPANT	\N	PRESENT	0
140238	140231	14187A	PARTICIPANT	\N	PRESENT	0
140239	140231	09001P	PARTICIPANT	\N	EXCUSE	0
140240	140231	04036E	PARTICIPANT	\N	EXCUSE	0
140241	140231	08031R	PRESIDENT	0	PRESENT	0
140242	140231	14031R	PARTICIPANT	\N	PRESENT	0
140243	140231	11067R	PARTICIPANT	\N	EXCUSE	0
140244	140231	11014C	PARTICIPANT	\N	PRESENT	0
140245	140231	14109K	PARTICIPANT	\N	PRESENT	0
140246	140231	07029T	PARTICIPANT	\N	EXCUSE	0
140256	140255	11032E	PARTICIPANT	\N	PRESENT	0
140257	140255	04040A	PARTICIPANT	\N	PRESENT	0
145033	145032	14253S	PARTICIPANT	\N	PRESENT	0
145034	145032	14157T	PARTICIPANT	\N	PRESENT	0
152941	152937	08068F	PARTICIPANT	\N	PRESENT	0
152950	152949	08055A	PARTICIPANT	\N	PRESENT	0
152952	152949	14105F	PARTICIPANT	\N	PRESENT	0
152953	152949	14207L	PARTICIPANT	\N	PRESENT	0
152954	152949	11095V	PARTICIPANT	\N	PRESENT	0
152955	152949	90003B	PARTICIPANT	\N	PRESENT	0
152956	152949	08018U	PARTICIPANT	\N	PRESENT	0
152958	152949	14061L	PARTICIPANT	\N	PRESENT	0
152960	152949	04049K	PARTICIPANT	\N	PRESENT	0
152961	152949	08015R	PARTICIPANT	\N	PRESENT	0
152963	152949	80027E	PARTICIPANT	\N	PRESENT	0
152964	152949	14257W	PARTICIPANT	\N	PRESENT	0
152965	152949	04088S	PARTICIPANT	\N	PRESENT	0
153623	153621	10015M	PARTICIPANT	\N	PRESENT	0
155353	155352	04045F	PARTICIPANT	\N	PRESENT	0
155354	155352	92045V	PARTICIPANT	\N	PRESENT	0
159788	158052	11066Q	PARTICIPANT	\N	PRESENT	0
159789	158052	11011M	PARTICIPANT	\N	PRESENT	0
159790	158052	11036J	PARTICIPANT	\N	PRESENT	0
159794	158052	80013X	PARTICIPANT	\N	PRESENT	0
159792	158052	01031L	PARTICIPANT	\N	PRESENT	0
159793	158052	08043V	PARTICIPANT	\N	PRESENT	0
159795	158052	11023D	PARTICIPANT	\N	PRESENT	0
159796	158052	01028R	PARTICIPANT	\N	PRESENT	0
159797	158052	08038Y	PARTICIPANT	\N	PRESENT	0
159798	158052	08016S	PARTICIPANT	\N	PRESENT	0
146679	146195	14028W	PARTICIPANT	\N	PRESENT	0
146680	146195	01022K	PARTICIPANT	\N	PRESENT	0
146681	146195	14265W	PARTICIPANT	\N	PRESENT	0
146682	146195	11015D	PARTICIPANT	\N	PRESENT	0
146683	146195	11105E	PARTICIPANT	\N	PRESENT	0
146684	146195	11089X	PARTICIPANT	\N	PRESENT	0
146685	146195	08012N	PARTICIPANT	\N	PRESENT	0
146686	146195	11036J	PARTICIPANT	\N	PRESENT	0
146687	146195	01057W	PARTICIPANT	\N	PRESENT	0
146688	146195	98029W	PARTICIPANT	\N	PRESENT	0
146689	146195	11020A	PARTICIPANT	\N	PRESENT	0
146690	146195	14038Y	PARTICIPANT	\N	PRESENT	0
146691	146195	14053L	PARTICIPANT	\N	PRESENT	0
146692	146195	11046L	PARTICIPANT	\N	PRESENT	0
146693	146195	14065Q	PARTICIPANT	\N	PRESENT	0
146694	146195	83042R	PARTICIPANT	\N	PRESENT	0
146695	146195	08053X	PARTICIPANT	\N	PRESENT	0
146696	146195	08017T	PARTICIPANT	\N	PRESENT	0
146697	146195	95037J	PARTICIPANT	\N	PRESENT	0
146698	146195	04034C	PARTICIPANT	\N	PRESENT	0
146699	146195	14014Q	PARTICIPANT	\N	PRESENT	0
146700	146195	01031L	PARTICIPANT	\N	PRESENT	0
146701	146195	14001X	PARTICIPANT	\N	PRESENT	0
146702	146195	14227Q	PARTICIPANT	\N	PRESENT	0
146703	146195	14167V	PARTICIPANT	\N	PRESENT	0
146704	146195	99004R	PARTICIPANT	\N	PRESENT	0
146705	146195	11014C	PARTICIPANT	\N	PRESENT	0
146706	146195	11068S	PARTICIPANT	\N	PRESENT	0
146707	146195	14097Y	PARTICIPANT	\N	PRESENT	0
146708	146195	04049K	PARTICIPANT	\N	PRESENT	0
146709	146195	14207L	PARTICIPANT	\N	PRESENT	0
146710	146195	11112D	PARTICIPANT	\N	PRESENT	0
146711	146195	11074Q	PARTICIPANT	\N	PRESENT	0
146712	146195	14063N	PARTICIPANT	\N	PRESENT	0
146713	146195	14121F	PARTICIPANT	\N	PRESENT	0
146714	146195	14187A	PARTICIPANT	\N	PRESENT	0
146715	146195	04079R	PARTICIPANT	\N	PRESENT	0
146716	146195	14281W	PARTICIPANT	\N	PRESENT	0
146717	146195	01041N	PARTICIPANT	\N	PRESENT	0
146718	146195	83047W	PARTICIPANT	\N	PRESENT	0
146719	146195	04077P	PARTICIPANT	\N	PRESENT	0
146720	146195	04059M	PARTICIPANT	\N	PRESENT	0
146721	146195	04053F	PARTICIPANT	\N	PRESENT	0
146722	146195	01028R	PARTICIPANT	\N	PRESENT	0
146723	146195	11088W	PARTICIPANT	\N	PRESENT	0
146724	146195	11104D	PARTICIPANT	\N	PRESENT	0
146725	146195	08038Y	PARTICIPANT	\N	PRESENT	0
146726	146195	14157T	PARTICIPANT	\N	PRESENT	0
146727	146195	11084S	PARTICIPANT	\N	PRESENT	0
146728	146195	14119M	PARTICIPANT	\N	PRESENT	0
146729	146195	14105F	PARTICIPANT	\N	PRESENT	0
146730	146195	11066Q	PARTICIPANT	\N	PRESENT	0
146731	146195	95067Q	PARTICIPANT	\N	PRESENT	0
146732	146195	14085U	PARTICIPANT	\N	PRESENT	0
146733	146195	14133K	PARTICIPANT	\N	PRESENT	0
146734	146195	11031D	PARTICIPANT	\N	PRESENT	0
146735	146195	14081Q	PARTICIPANT	\N	PRESENT	0
146755	146195	11076S	PARTICIPANT	\N	PRESENT	0
146737	146195	99002P	PARTICIPANT	\N	PRESENT	0
146738	146195	04045F	PARTICIPANT	\N	PRESENT	0
146739	146195	11077T	PARTICIPANT	\N	PRESENT	0
146740	146195	11042G	PARTICIPANT	\N	PRESENT	0
146741	146195	08035V	PARTICIPANT	\N	PRESENT	0
146758	146195	11070L	PARTICIPANT	\N	PRESENT	0
146743	146195	14257W	PARTICIPANT	\N	PRESENT	0
146744	146195	08018U	PARTICIPANT	\N	PRESENT	0
146745	146195	11109J	PARTICIPANT	\N	PRESENT	0
146746	146195	11072N	PARTICIPANT	\N	PRESENT	0
146747	146195	14159V	PARTICIPANT	\N	PRESENT	0
146748	146195	14093U	PARTICIPANT	\N	PRESENT	0
146749	146195	12042Y	PARTICIPANT	\N	PRESENT	0
146750	146195	11037K	PARTICIPANT	\N	PRESENT	0
146751	146195	04088S	PARTICIPANT	\N	PRESENT	0
146752	146195	14269B	PARTICIPANT	\N	PRESENT	0
146753	146195	01014K	PARTICIPANT	\N	PRESENT	0
146754	146195	08062Y	PARTICIPANT	\N	PRESENT	0
146756	146195	13002U	PARTICIPANT	\N	PRESENT	0
146757	146195	14199E	PARTICIPANT	\N	PRESENT	0
146759	146195	11094U	PARTICIPANT	\N	PRESENT	0
146760	146195	08009T	PARTICIPANT	\N	PRESENT	0
146761	146195	11053K	PARTICIPANT	\N	PRESENT	0
146762	146195	04080J	PARTICIPANT	\N	PRESENT	0
146763	146195	14034U	PARTICIPANT	\N	PRESENT	0
146764	146195	11093T	PARTICIPANT	\N	PRESENT	0
146765	146195	08015R	PARTICIPANT	\N	PRESENT	0
146766	146195	14205J	PARTICIPANT	\N	PRESENT	0
146767	146195	14042U	PARTICIPANT	\N	PRESENT	0
146768	146195	14219Q	PARTICIPANT	\N	PRESENT	0
146769	146195	14267Y	PARTICIPANT	\N	PRESENT	0
146770	146195	14030Q	PARTICIPANT	\N	PRESENT	0
146771	146195	14231L	PARTICIPANT	\N	PRESENT	0
146772	146195	14221J	PARTICIPANT	\N	PRESENT	0
146773	146195	14073Q	PARTICIPANT	\N	PRESENT	0
146774	146195	07004J	PARTICIPANT	\N	PRESENT	0
146775	146195	98042T	PARTICIPANT	\N	PRESENT	0
146776	146195	04089T	PARTICIPANT	\N	PRESENT	0
146777	146195	14179A	PARTICIPANT	\N	PRESENT	0
146778	146195	01034P	PARTICIPANT	\N	PRESENT	0
146779	146195	09001P	PARTICIPANT	\N	PRESENT	0
146780	146195	89017R	PARTICIPANT	\N	PRESENT	0
146781	146195	14255U	PARTICIPANT	\N	PRESENT	0
146782	146195	04070G	PARTICIPANT	\N	PRESENT	0
146783	146195	04040A	PARTICIPANT	\N	PRESENT	0
146784	146195	08056B	PARTICIPANT	\N	PRESENT	0
146785	146195	14251Q	PARTICIPANT	\N	PRESENT	0
146786	146195	01024M	PARTICIPANT	\N	PRESENT	0
146787	146195	01007L	PARTICIPANT	\N	PRESENT	0
146788	146195	01025N	PARTICIPANT	\N	PRESENT	0
146789	146195	14327T	PARTICIPANT	\N	PRESENT	0
146790	146195	14037X	PARTICIPANT	\N	PRESENT	0
146791	146195	11044J	PARTICIPANT	\N	PRESENT	0
146792	146195	08069G	PARTICIPANT	\N	PRESENT	0
146793	146195	92045V	PARTICIPANT	\N	PRESENT	0
146795	146195	14173T	PARTICIPANT	\N	PRESENT	0
146798	146195	11032E	PARTICIPANT	\N	PRESENT	0
146860	146195	07024N	PARTICIPANT	\N	PRESENT	0
146815	146195	14175V	PARTICIPANT	\N	PRESENT	0
146852	146195	14271U	PARTICIPANT	\N	PRESENT	0
146889	146888	98029W	PARTICIPANT	\N	PRESENT	0
146891	146890	14193X	PARTICIPANT	\N	PRESENT	0
147013	147012	08009T	PARTICIPANT	\N	PRESENT	0
147014	147012	14135M	PARTICIPANT	\N	PRESENT	0
147015	147012	95062K	PARTICIPANT	\N	PRESENT	0
147017	147016	08068F	PARTICIPANT	\N	PRESENT	0
147019	147018	08068F	PARTICIPANT	\N	PRESENT	0
147049	147048	08039A	PARTICIPANT	\N	PRESENT	0
147034	147032	04070G	PARTICIPANT	\N	PRESENT	0
147035	147032	88008L	PARTICIPANT	\N	PRESENT	0
147036	147032	11029K	PARTICIPANT	\N	PRESENT	0
147037	147032	14061L	PARTICIPANT	\N	PRESENT	0
147038	147032	14073Q	PARTICIPANT	\N	PRESENT	0
147039	147032	08031R	PARTICIPANT	\N	PRESENT	0
147040	147032	08012N	PARTICIPANT	\N	PRESENT	0
147041	147032	11014C	PARTICIPANT	\N	PRESENT	0
147042	147032	14071N	PARTICIPANT	\N	PRESENT	0
147043	147032	11043H	PARTICIPANT	\N	PRESENT	0
147045	147044	08039A	PARTICIPANT	\N	PRESENT	0
147047	147046	08039A	PARTICIPANT	\N	PRESENT	0
147051	147050	08039A	PARTICIPANT	\N	PRESENT	0
147133	147132	14051J	PARTICIPANT	\N	PRESENT	0
147135	147134	04049K	PARTICIPANT	\N	PRESENT	0
147193	147192	96004D	PARTICIPANT	\N	PRESENT	0
147194	147192	83042R	PARTICIPANT	\N	PRESENT	0
147195	147192	14097Y	PARTICIPANT	\N	PRESENT	0
147196	147192	04061F	PARTICIPANT	\N	PRESENT	0
148194	148192	08055A	PARTICIPANT	\N	PRESENT	0
148195	148192	14093U	PARTICIPANT	\N	PRESENT	0
148196	148192	14030Q	PARTICIPANT	\N	PRESENT	0
148197	148192	96004D	PARTICIPANT	\N	PRESENT	0
148200	148192	14038Y	PARTICIPANT	\N	PRESENT	0
148204	148192	01015L	PARTICIPANT	\N	PRESENT	0
148205	148192	11107G	PARTICIPANT	\N	EXCUSE	0
148207	148192	02002K	PARTICIPANT	\N	PRESENT	0
148208	148192	01022K	PARTICIPANT	\N	PRESENT	0
148210	148192	04097T	PARTICIPANT	\N	PRESENT	0
148211	148192	09001P	PARTICIPANT	\N	PRESENT	0
148212	148192	11059R	PARTICIPANT	\N	PRESENT	0
148213	148192	14219Q	PARTICIPANT	\N	PRESENT	0
148214	148192	80027E	PARTICIPANT	\N	PRESENT	0
148215	148192	14031R	PARTICIPANT	\N	PRESENT	0
131351	131350	14261S	PARTICIPANT	\N	PRESENT	0
131352	131350	08055A	PARTICIPANT	\N	PRESENT	0
131353	131350	14093U	PARTICIPANT	\N	PRESENT	0
131354	131350	14030Q	PARTICIPANT	\N	PRESENT	0
131355	131350	96004D	PARTICIPANT	\N	PRESENT	0
131356	131350	08060W	PARTICIPANT	\N	PRESENT	0
131357	131350	11095V	PARTICIPANT	\N	EXCUSE	0
131358	131350	14038Y	PARTICIPANT	\N	PRESENT	0
131359	131350	11114F	PARTICIPANT	\N	PRESENT	0
131360	131350	98023Q	PARTICIPANT	\N	PRESENT	0
131361	131350	11065P	PARTICIPANT	\N	PRESENT	0
131362	131350	01015L	PARTICIPANT	\N	PRESENT	0
131363	131350	11107G	PARTICIPANT	\N	PRESENT	0
131394	131393	14261S	PARTICIPANT	\N	PRESENT	0
131365	131350	02002K	PARTICIPANT	\N	PRESENT	0
131395	131393	08055A	PARTICIPANT	\N	PRESENT	0
131396	131393	14093U	PARTICIPANT	\N	PRESENT	0
131368	131350	09001P	PARTICIPANT	\N	PRESENT	0
131397	131393	14030Q	PARTICIPANT	\N	PRESENT	0
131370	131350	14219Q	PARTICIPANT	\N	PRESENT	0
131371	131350	80027E	PARTICIPANT	\N	PRESENT	0
131372	131350	14031R	PARTICIPANT	\N	PRESENT	0
131373	131350	08009T	PRESIDENT	0	PRESENT	0
131374	131350	08062Y	PARTICIPANT	\N	PRESENT	0
131375	131350	14221J	PARTICIPANT	\N	PRESENT	0
131376	131350	92039X	PARTICIPANT	\N	PRESENT	0
131377	131350	08042U	PARTICIPANT	\N	PRESENT	0
131378	131350	14169X	PARTICIPANT	\N	PRESENT	0
131379	131350	14237S	PARTICIPANT	\N	PRESENT	0
131380	131350	13002U	PARTICIPANT	\N	PRESENT	0
131381	131350	05012A	PARTICIPANT	\N	PRESENT	0
131382	131350	14247U	PARTICIPANT	\N	PRESENT	0
131383	131350	14135M	PARTICIPANT	\N	PRESENT	0
131384	131350	14331P	PARTICIPANT	\N	PRESENT	0
131385	131350	95062K	PARTICIPANT	\N	EXCUSE	0
131386	131350	14107H	PARTICIPANT	\N	PRESENT	0
131387	131350	14051J	PARTICIPANT	\N	PRESENT	0
131388	131350	14157T	PARTICIPANT	\N	PRESENT	0
131389	131350	96003C	PARTICIPANT	\N	EXCUSE	0
131398	131393	96004D	PARTICIPANT	\N	PRESENT	0
131399	131393	08060W	PARTICIPANT	\N	PRESENT	0
131400	131393	11095V	PARTICIPANT	\N	EXCUSE	0
131401	131393	14038Y	PARTICIPANT	\N	PRESENT	0
131402	131393	11114F	PARTICIPANT	\N	PRESENT	0
131403	131393	98023Q	PARTICIPANT	\N	PRESENT	0
131404	131393	11065P	PARTICIPANT	\N	PRESENT	0
131498	131393	13002U	PARTICIPANT	\N	PRESENT	0
131406	131393	11107G	PARTICIPANT	\N	PRESENT	0
131407	131393	11020A	PARTICIPANT	\N	PRESENT	0
131408	131393	02002K	PARTICIPANT	\N	PRESENT	0
132761	132760	01024M	PARTICIPANT	\N	PRESENT	0
136729	136726	14037X	PARTICIPANT	\N	PRESENT	0
131411	131393	09001P	PARTICIPANT	\N	PRESENT	0
136732	136731	14037X	PARTICIPANT	\N	PRESENT	0
131413	131393	14219Q	PARTICIPANT	\N	PRESENT	0
131414	131393	80027E	PARTICIPANT	\N	PRESENT	0
131415	131393	14031R	PARTICIPANT	\N	PRESENT	0
131416	131393	08009T	PRESIDENT	0	PRESENT	0
131417	131393	08062Y	PARTICIPANT	\N	PRESENT	0
131418	131393	14221J	PARTICIPANT	\N	PRESENT	0
131419	131393	92039X	PARTICIPANT	\N	PRESENT	0
131420	131393	08042U	PARTICIPANT	\N	PRESENT	0
131421	131393	14169X	PARTICIPANT	\N	PRESENT	0
131422	131393	14237S	PARTICIPANT	\N	PRESENT	0
137310	137256	92031P	PARTICIPANT	\N	PRESENT	0
131424	131393	05012A	PARTICIPANT	\N	PRESENT	0
131425	131393	14247U	PARTICIPANT	\N	PRESENT	0
131426	131393	14135M	PARTICIPANT	\N	PRESENT	0
131427	131393	14331P	PARTICIPANT	\N	PRESENT	0
131428	131393	95062K	PARTICIPANT	\N	EXCUSE	0
131429	131393	14107H	PARTICIPANT	\N	PRESENT	0
131430	131393	14051J	PARTICIPANT	\N	PRESENT	0
131431	131393	14157T	PARTICIPANT	\N	PRESENT	0
131432	131393	96003C	PARTICIPANT	\N	EXCUSE	0
137337	137256	14111D	PARTICIPANT	\N	PRESENT	0
137312	137256	14251Q	PARTICIPANT	\N	PRESENT	0
138133	138132	11054L	PARTICIPANT	\N	PRESENT	0
137314	137256	08053X	PARTICIPANT	\N	PRESENT	0
137315	137256	11082Q	PARTICIPANT	\N	PRESENT	0
137316	137256	11105E	PARTICIPANT	\N	PRESENT	0
137317	137256	14253S	PARTICIPANT	\N	PRESENT	0
137318	137256	08047A	PARTICIPANT	\N	PRESENT	0
137319	137256	14028W	PARTICIPANT	\N	EXCUSE	0
137320	137256	14193X	PARTICIPANT	\N	PRESENT	0
137321	137256	98021N	PARTICIPANT	\N	PRESENT	0
137322	137256	04080J	PARTICIPANT	\N	PRESENT	0
137323	137256	95059Q	PRESIDENT	0	PRESENT	0
137324	137256	86044G	PARTICIPANT	\N	EXCUSE	0
137325	137256	01014K	PARTICIPANT	\N	PRESENT	0
137326	137256	11054L	PARTICIPANT	\N	PRESENT	0
138102	138072	08019V	PARTICIPANT	\N	PRESENT	0
138103	138072	14257W	PARTICIPANT	\N	PRESENT	0
137329	137256	08049C	PARTICIPANT	\N	EXCUSE	0
137330	137256	04050C	PARTICIPANT	\N	PRESENT	0
138317	137956	92045V	PARTICIPANT	\N	EXCUSE	0
138358	135871	04094Q	PARTICIPANT	\N	EXCUSE	0
138235	138231	01046T	PARTICIPANT	\N	PRESENT	0
138107	138072	11090Q	PARTICIPANT	\N	PRESENT	0
138108	138072	11046L	PARTICIPANT	\N	PRESENT	0
138109	138072	01058X	PARTICIPANT	\N	PRESENT	0
138110	138072	11094U	PARTICIPANT	\N	PRESENT	0
138111	138072	11066Q	PARTICIPANT	\N	PRESENT	0
138236	138231	04053F	PARTICIPANT	\N	PRESENT	0
139949	135871	01022K	PARTICIPANT	\N	EXCUSE	0
139950	135871	11106F	PARTICIPANT	\N	EXCUSE	0
138239	138231	00003C	PARTICIPANT	\N	EXCUSE	0
139954	139953	01056V	PARTICIPANT	\N	PRESENT	0
138241	138231	11103C	PARTICIPANT	\N	PRESENT	0
138242	138231	11044J	PARTICIPANT	\N	PRESENT	0
138243	138231	14195A	PARTICIPANT	\N	PRESENT	0
138244	138231	14267Y	PARTICIPANT	\N	PRESENT	0
139956	139955	08018U	PARTICIPANT	\N	PRESENT	0
139957	139955	04040A	PARTICIPANT	\N	PRESENT	0
138247	138231	08052W	PARTICIPANT	\N	PRESENT	0
138248	138231	01059Y	PARTICIPANT	\N	PRESENT	0
138249	138231	04081K	PARTICIPANT	\N	PRESENT	0
138250	138231	98024R	PARTICIPANT	\N	PRESENT	0
138251	138231	10006L	PARTICIPANT	\N	PRESENT	0
139958	139955	95035G	PARTICIPANT	\N	PRESENT	0
138253	138231	14217N	PARTICIPANT	\N	PRESENT	0
138254	138231	14042U	PARTICIPANT	\N	PRESENT	0
139959	139955	14069U	PARTICIPANT	\N	PRESENT	0
138256	138231	12042Y	PARTICIPANT	\N	PRESENT	0
138257	138231	14281W	PARTICIPANT	\N	PRESENT	0
138258	138231	14087W	PARTICIPANT	\N	PRESENT	0
139960	139955	14030Q	PARTICIPANT	\N	PRESENT	0
138260	138231	14034U	PARTICIPANT	\N	PRESENT	0
138261	138231	14231L	PARTICIPANT	\N	PRESENT	0
138262	138231	11061K	PARTICIPANT	\N	PRESENT	0
139961	139955	14097Y	PARTICIPANT	\N	PRESENT	0
138264	138231	08041T	PARTICIPANT	\N	PRESENT	0
139962	139955	92031P	PARTICIPANT	\N	PRESENT	0
139963	139955	89017R	PARTICIPANT	\N	PRESENT	0
139965	139964	04070G	PARTICIPANT	\N	PRESENT	0
139967	139966	11094U	PARTICIPANT	\N	PRESENT	0
138269	138231	11112D	PARTICIPANT	\N	PRESENT	0
139968	139966	04036E	PARTICIPANT	\N	PRESENT	0
140680	140679	05008E	PARTICIPANT	\N	PRESENT	0
138272	138231	11067R	PARTICIPANT	\N	EXCUSE	0
138273	138231	14223L	PARTICIPANT	\N	PRESENT	0
138274	138231	04092N	PRESIDENT	0	PRESENT	0
138275	138231	14265W	PARTICIPANT	\N	PRESENT	0
138276	138231	14119M	PARTICIPANT	\N	PRESENT	0
138277	138231	14071N	PARTICIPANT	\N	PRESENT	0
140681	140679	01024M	PARTICIPANT	\N	PRESENT	0
138279	138231	04043D	PARTICIPANT	\N	PRESENT	0
138280	138231	14271U	PARTICIPANT	\N	PRESENT	0
140682	140679	01047U	PARTICIPANT	\N	PRESENT	0
138282	138231	11093T	PARTICIPANT	\N	PRESENT	0
138283	138231	11097X	PARTICIPANT	\N	PRESENT	0
138284	138231	04045F	PARTICIPANT	\N	PRESENT	0
138285	138231	14227Q	PARTICIPANT	\N	PRESENT	0
138286	138231	01034P	PARTICIPANT	\N	PRESENT	0
140684	140683	05008E	PARTICIPANT	\N	PRESENT	0
140685	140683	14065Q	PARTICIPANT	\N	PRESENT	0
138289	138231	14269B	PARTICIPANT	\N	PRESENT	0
140686	140683	01024M	PARTICIPANT	\N	PRESENT	0
140752	125632	14209N	PARTICIPANT	\N	EXCUSE	0
140781	125632	04043D	PARTICIPANT	\N	PRESENT	0
146257	146253	08060W	PARTICIPANT	\N	PRESENT	0
146258	146253	04053F	PARTICIPANT	\N	PRESENT	0
146259	146253	01015L	PARTICIPANT	\N	PRESENT	0
146261	146253	08009T	PRESIDENT	0	PRESENT	0
146263	146253	08042U	PARTICIPANT	\N	PRESENT	0
146264	146253	05012A	PARTICIPANT	\N	PRESENT	0
146265	146253	14051J	PARTICIPANT	\N	PRESENT	0
141452	141072	04040A	PARTICIPANT	\N	PRESENT	0
141453	141072	98042T	PARTICIPANT	\N	PRESENT	0
141454	141072	04089T	PARTICIPANT	\N	PRESENT	0
141455	141072	14083S	PARTICIPANT	\N	PRESENT	0
141456	141072	14089Y	PARTICIPANT	\N	PRESENT	0
141457	141072	11111C	PARTICIPANT	\N	PRESENT	0
141458	141072	14073Q	PARTICIPANT	\N	PRESENT	0
141459	141072	14277B	PARTICIPANT	\N	PRESENT	0
141460	141072	08017T	PARTICIPANT	\N	PRESENT	0
141461	141072	92039X	PARTICIPANT	\N	PRESENT	0
141462	141072	11104D	PARTICIPANT	\N	PRESENT	0
141464	141072	11090Q	PARTICIPANT	\N	PRESENT	0
141465	141072	01034P	PARTICIPANT	\N	PRESENT	0
141466	141072	14237S	PARTICIPANT	\N	PRESENT	0
141467	141072	14135M	PARTICIPANT	\N	PRESENT	0
141520	141072	08035V	PARTICIPANT	\N	PRESENT	0
141501	141072	11091R	PARTICIPANT	\N	PRESENT	0
141469	141463	89017R	PARTICIPANT	\N	EXCUSE	0
141470	141463	01031L	PRESIDENT	0	PRESENT	0
141522	141072	14157T	PARTICIPANT	\N	PRESENT	0
141472	141463	01013J	PARTICIPANT	\N	PRESENT	0
141473	141463	11068S	PARTICIPANT	\N	PRESENT	0
141474	141463	11040E	PARTICIPANT	\N	PRESENT	0
141475	141463	08014Q	PARTICIPANT	\N	PRESENT	0
141476	141463	14167V	PARTICIPANT	\N	PRESENT	0
141477	141463	14175V	PARTICIPANT	\N	EXCUSE	0
141478	141463	14083S	PARTICIPANT	\N	PRESENT	0
141479	141463	11053K	PARTICIPANT	\N	PRESENT	0
141480	141463	14085U	PARTICIPANT	\N	PRESENT	0
141481	141463	11042G	PARTICIPANT	\N	PRESENT	0
141482	141463	88008L	PARTICIPANT	\N	PRESENT	0
141483	141463	04086Q	PARTICIPANT	\N	PRESENT	0
141553	141463	01007L	RAPPORTEUR_AVIS	\N	PRESENT	0
141573	141572	14253S	PARTICIPANT	\N	PRESENT	0
141486	141463	11088W	PARTICIPANT	\N	PRESENT	0
141487	141463	14327T	PARTICIPANT	\N	PRESENT	0
141488	141463	08022Q	PARTICIPANT	\N	PRESENT	0
141489	141463	01027Q	PARTICIPANT	\N	PRESENT	0
141490	141463	04071H	PARTICIPANT	\N	PRESENT	0
141574	141572	14157T	PARTICIPANT	\N	PRESENT	0
142733	142732	11039M	PARTICIPANT	\N	PRESENT	0
141493	141463	11083R	PARTICIPANT	\N	PRESENT	0
141494	141463	14199E	PARTICIPANT	\N	PRESENT	0
141495	141463	01057W	PARTICIPANT	\N	PRESENT	0
141496	141463	08016S	PARTICIPANT	\N	PRESENT	0
141497	141463	08069G	PARTICIPANT	\N	PRESENT	0
141498	141463	11048N	PARTICIPANT	\N	PRESENT	0
142734	142732	98042T	PARTICIPANT	\N	PRESENT	0
141500	141463	04061F	PARTICIPANT	\N	PRESENT	0
141502	141463	14159V	PARTICIPANT	\N	PRESENT	0
141503	141463	07029T	PARTICIPANT	\N	PRESENT	0
142735	142732	01019Q	PARTICIPANT	\N	PRESENT	0
141505	141463	08010L	PARTICIPANT	\N	PRESENT	0
141506	141463	08034U	PARTICIPANT	\N	PRESENT	0
143313	143032	01007L	PARTICIPANT	\N	PRESENT	0
143314	143032	14223L	PARTICIPANT	\N	PRESENT	0
143315	143032	14061L	PARTICIPANT	\N	PRESENT	0
141510	141463	08011M	PARTICIPANT	\N	PRESENT	0
143316	143032	14105F	PARTICIPANT	\N	PRESENT	0
141512	141463	08061X	PARTICIPANT	\N	EXCUSE	0
141513	141463	01016M	PARTICIPANT	\N	PRESENT	0
141514	141463	14225N	PARTICIPANT	\N	PRESENT	0
143317	143032	08042U	PARTICIPANT	\N	PRESENT	0
141516	141463	11057P	PARTICIPANT	\N	PRESENT	0
143318	143032	11081P	PARTICIPANT	\N	PRESENT	0
141518	141463	04034C	PARTICIPANT	\N	PRESENT	0
141519	141072	05008E	PARTICIPANT	\N	PRESENT	0
141521	141072	04054G	PARTICIPANT	\N	PRESENT	0
141523	141072	11032E	PARTICIPANT	\N	PRESENT	0
141524	141072	14017T	PARTICIPANT	\N	PRESENT	0
143319	143032	01015L	PARTICIPANT	\N	PRESENT	0
143320	143032	04088S	PARTICIPANT	\N	PRESENT	0
143321	143032	14135M	PARTICIPANT	\N	PRESENT	0
143322	143032	80027E	PARTICIPANT	\N	PRESENT	0
143323	143032	01013J	PARTICIPANT	\N	PRESENT	0
143324	143032	01022K	PARTICIPANT	\N	PRESENT	0
143325	143032	08060W	PARTICIPANT	\N	PRESENT	0
143326	143032	14051J	PARTICIPANT	\N	PRESENT	0
143327	143032	14107H	PARTICIPANT	\N	PRESENT	0
143328	143032	01037S	PARTICIPANT	\N	PRESENT	0
143329	143032	13002U	PARTICIPANT	\N	PRESENT	0
143330	143032	01046T	PARTICIPANT	\N	PRESENT	0
143331	143032	11065P	PARTICIPANT	\N	PRESENT	0
143332	143032	08031R	PARTICIPANT	\N	PRESENT	0
143333	143032	08022Q	PARTICIPANT	\N	PRESENT	0
143334	143032	08009T	PARTICIPANT	\N	PRESENT	0
143335	143032	14241N	PARTICIPANT	\N	PRESENT	0
143336	143032	87003B	PARTICIPANT	\N	PRESENT	0
143337	143032	08047A	PARTICIPANT	\N	PRESENT	0
143338	143032	11098Y	PARTICIPANT	\N	PRESENT	0
143339	143032	08051V	PARTICIPANT	\N	PRESENT	0
143340	143032	04038G	PARTICIPANT	\N	PRESENT	0
143341	143032	14327T	PARTICIPANT	\N	PRESENT	0
143342	143032	14215L	PARTICIPANT	\N	PRESENT	0
143343	143032	95015C	PARTICIPANT	\N	PRESENT	0
143344	143032	14331P	PARTICIPANT	\N	PRESENT	0
143345	143032	14073Q	PARTICIPANT	\N	PRESENT	0
143359	143032	07024N	PARTICIPANT	\N	PRESENT	0
143360	143032	14121F	PARTICIPANT	\N	PRESENT	0
143361	143032	08056B	PARTICIPANT	\N	PRESENT	0
143362	143032	14219Q	PARTICIPANT	\N	PRESENT	0
143363	143032	95063L	PARTICIPANT	\N	PRESENT	0
143372	143032	08016S	PARTICIPANT	\N	PRESENT	0
143373	143032	14263U	PARTICIPANT	\N	PRESENT	0
143374	143032	14261S	PARTICIPANT	\N	PRESENT	0
143375	143032	01048V	PARTICIPANT	\N	PRESENT	0
143376	143032	08014Q	PARTICIPANT	\N	PRESENT	0
143377	143032	14225N	PARTICIPANT	\N	PRESENT	0
143378	143032	01008M	PARTICIPANT	\N	PRESENT	0
143379	143032	14179A	PARTICIPANT	\N	PRESENT	0
143381	143032	14197C	PARTICIPANT	\N	PRESENT	0
143383	143032	11042G	PARTICIPANT	\N	PRESENT	0
143384	143032	11012A	PARTICIPANT	\N	PRESENT	0
143385	143032	14157T	PARTICIPANT	\N	PRESENT	0
143386	143032	92031P	PARTICIPANT	\N	PRESENT	0
143387	143032	14147R	PARTICIPANT	\N	PRESENT	0
143388	143032	08015R	PARTICIPANT	\N	PRESENT	0
143389	143032	95035G	PARTICIPANT	\N	PRESENT	0
143390	143032	14085U	PARTICIPANT	\N	PRESENT	0
143391	143032	92039X	PARTICIPANT	\N	PRESENT	0
143392	143032	95049N	PARTICIPANT	\N	PRESENT	0
143393	143032	98050T	PARTICIPANT	\N	PRESENT	0
143412	143032	11066Q	PARTICIPANT	\N	PRESENT	0
143413	143032	14089Y	PARTICIPANT	\N	PRESENT	0
143414	143032	11105E	PARTICIPANT	\N	PRESENT	0
143415	143032	14201E	PARTICIPANT	\N	PRESENT	0
143416	143032	08068F	PARTICIPANT	\N	PRESENT	0
143417	143032	14069U	PARTICIPANT	\N	PRESENT	0
143418	143032	98022P	PARTICIPANT	\N	PRESENT	0
143461	143032	14265W	PARTICIPANT	\N	PRESENT	0
143462	143032	90003B	PARTICIPANT	\N	PRESENT	0
143463	143032	14267Y	PARTICIPANT	\N	PRESENT	0
143464	143032	14071N	PARTICIPANT	\N	PRESENT	0
143465	143032	14207L	PARTICIPANT	\N	PRESENT	0
143472	143032	14271U	PARTICIPANT	\N	PRESENT	0
143473	143032	14119M	PARTICIPANT	\N	PRESENT	0
143474	143032	14031R	PARTICIPANT	\N	PRESENT	0
143475	143032	01003G	PARTICIPANT	\N	PRESENT	0
143516	143032	92045V	PARTICIPANT	\N	PRESENT	0
143517	143032	04045F	PARTICIPANT	\N	PRESENT	0
143518	143032	14257W	PARTICIPANT	\N	PRESENT	0
143519	143032	14063N	PARTICIPANT	\N	PRESENT	0
143520	143032	12042Y	PARTICIPANT	\N	PRESENT	0
143521	143032	14033T	PARTICIPANT	\N	PRESENT	0
143522	143032	14205J	PARTICIPANT	\N	PRESENT	0
132874	132873	04074L	PARTICIPANT	\N	PRESENT	0
132885	132884	05012A	PARTICIPANT	\N	PRESENT	0
132887	132886	08060W	PARTICIPANT	\N	PRESENT	0
132889	132888	08060W	PARTICIPANT	\N	PRESENT	0
132891	132890	14051J	PARTICIPANT	\N	PRESENT	0
132893	132892	11098Y	PARTICIPANT	\N	PRESENT	0
132895	132894	11098Y	PARTICIPANT	\N	PRESENT	0
132897	132896	14105F	PARTICIPANT	\N	PRESENT	0
132898	132896	14207L	PARTICIPANT	\N	PRESENT	0
132900	132896	90003B	PARTICIPANT	\N	PRESENT	0
132901	132896	14038Y	PARTICIPANT	\N	PRESENT	0
132902	132896	01024M	PARTICIPANT	\N	PRESENT	0
132907	132896	08056B	PARTICIPANT	\N	PRESENT	0
132905	132896	01025N	PARTICIPANT	\N	PRESENT	0
132906	132896	11107G	PARTICIPANT	\N	PRESENT	0
132908	132896	04049K	PARTICIPANT	\N	PRESENT	0
132909	132896	08015R	PARTICIPANT	\N	PRESENT	0
132910	132896	08010L	PARTICIPANT	\N	PRESENT	0
132911	132896	14109K	PARTICIPANT	\N	PRESENT	0
132912	132896	14257W	PARTICIPANT	\N	PRESENT	0
132913	132896	05012A	PARTICIPANT	\N	PRESENT	0
132914	132896	11097X	PARTICIPANT	\N	PRESENT	0
132915	132896	11094U	PARTICIPANT	\N	PRESENT	0
132916	132896	01056V	PARTICIPANT	\N	PRESENT	0
135107	135106	14133K	PARTICIPANT	\N	PRESENT	0
135108	135106	96004D	PRESIDENT	0	PRESENT	0
135109	135106	14089Y	PARTICIPANT	\N	PRESENT	0
135110	135106	95030B	PARTICIPANT	\N	PRESENT	0
135111	135106	08018U	PARTICIPANT	\N	EXCUSE	0
135112	135106	11083R	PARTICIPANT	\N	PRESENT	0
135113	135106	95037J	PARTICIPANT	\N	PRESENT	0
135114	135106	14097Y	PARTICIPANT	\N	PRESENT	0
135115	135106	14073Q	PARTICIPANT	\N	PRESENT	0
135116	135106	04057K	PARTICIPANT	\N	PRESENT	0
135118	135106	90003B	PARTICIPANT	\N	EXCUSE	0
135119	135106	14135M	PARTICIPANT	\N	EXCUSE	0
135120	135106	04045F	PARTICIPANT	\N	PRESENT	0
135121	135106	98035U	PARTICIPANT	\N	PRESENT	0
135122	135106	92045V	PARTICIPANT	\N	PRESENT	0
135123	135106	04034C	PARTICIPANT	\N	PRESENT	0
135124	135106	01016M	PARTICIPANT	\N	PRESENT	0
139823	139822	04043D	PARTICIPANT	\N	PRESENT	0
139952	139951	01056V	PARTICIPANT	\N	PRESENT	0
140333	140332	89017R	PARTICIPANT	\N	PRESENT	0
140334	140332	11039M	PARTICIPANT	\N	PRESENT	0
140335	140332	08055A	PARTICIPANT	\N	PRESENT	0
140336	140332	11029K	PARTICIPANT	\N	PRESENT	0
140337	140332	04066L	PARTICIPANT	\N	PRESENT	0
140338	140332	04042C	PARTICIPANT	\N	PRESENT	0
140339	140332	08024S	PARTICIPANT	\N	PRESENT	0
140340	140332	04081K	PARTICIPANT	\N	PRESENT	0
140341	140332	98042T	PARTICIPANT	\N	PRESENT	0
140342	140332	01003G	PARTICIPANT	\N	PRESENT	0
140343	140332	98053W	PARTICIPANT	\N	PRESENT	0
140344	140332	89029V	PARTICIPANT	\N	PRESENT	0
140345	140332	08048B	PARTICIPANT	\N	PRESENT	0
140346	140332	01007L	PARTICIPANT	\N	PRESENT	0
140347	140332	95037J	PARTICIPANT	\N	PRESENT	0
140348	140332	86034E	PARTICIPANT	\N	PRESENT	0
140349	140332	04094Q	PARTICIPANT	\N	PRESENT	0
140350	140332	08039A	PARTICIPANT	\N	PRESENT	0
140351	140332	01043Q	PARTICIPANT	\N	PRESENT	0
140352	140332	11085T	PARTICIPANT	\N	PRESENT	0
140353	140332	04057K	PARTICIPANT	\N	PRESENT	0
140354	140332	92040Q	PARTICIPANT	\N	PRESENT	0
140355	140332	04088S	PARTICIPANT	\N	PRESENT	0
140356	140332	01019Q	PARTICIPANT	\N	PRESENT	0
140357	140332	04056J	PARTICIPANT	\N	PRESENT	0
151963	151959	96004D	PRESIDENT	0	PRESENT	0
151965	151959	04040A	PARTICIPANT	\N	EXCUSE	0
151966	151959	11083R	PARTICIPANT	\N	PRESENT	0
151968	151959	14097Y	PARTICIPANT	\N	PRESENT	0
151969	151959	04061F	PARTICIPANT	\N	PRESENT	0
151971	151959	14001X	PARTICIPANT	\N	EXCUSE	0
151972	151959	04057K	PARTICIPANT	\N	EXCUSE	0
151974	151959	98021N	PARTICIPANT	\N	PRESENT	0
151975	151959	98035U	PARTICIPANT	\N	EXCUSE	0
151976	151959	95059Q	PARTICIPANT	\N	EXCUSE	0
159799	158052	04036E	PARTICIPANT	\N	PRESENT	0
159800	158052	95063L	PARTICIPANT	\N	PRESENT	0
159801	158052	05012A	PARTICIPANT	\N	PRESENT	0
159802	158052	11042G	PARTICIPANT	\N	PRESENT	0
159803	158052	11055M	PARTICIPANT	\N	PRESENT	0
159804	158052	11080N	PARTICIPANT	\N	PRESENT	0
159806	158052	11074Q	PARTICIPANT	\N	PRESENT	0
159807	158052	04057K	PARTICIPANT	\N	PRESENT	0
159808	158052	14229S	PARTICIPANT	\N	PRESENT	0
159809	158052	14059S	PARTICIPANT	\N	PRESENT	0
159810	158052	11061K	PARTICIPANT	\N	PRESENT	0
159811	158052	05008E	PARTICIPANT	\N	PRESENT	0
159812	158052	14281W	PARTICIPANT	\N	PRESENT	0
159813	158052	11083R	PARTICIPANT	\N	PRESENT	0
159814	158052	05004A	PARTICIPANT	\N	PRESENT	0
159815	158052	11089X	PARTICIPANT	\N	PRESENT	0
159816	158052	95035G	PARTICIPANT	\N	PRESENT	0
159817	158052	08061X	PARTICIPANT	\N	PRESENT	0
159818	158052	04077P	PARTICIPANT	\N	PRESENT	0
159819	158052	14119M	PARTICIPANT	\N	PRESENT	0
159820	158052	08024S	PARTICIPANT	\N	PRESENT	0
159821	158052	14071N	PARTICIPANT	\N	PRESENT	0
159822	158052	07029T	PARTICIPANT	\N	PRESENT	0
159823	158052	01003G	PARTICIPANT	\N	PRESENT	0
159824	158052	92045V	PARTICIPANT	\N	PRESENT	0
159826	158052	14225N	PARTICIPANT	\N	PRESENT	0
159827	158052	14329V	PARTICIPANT	\N	PRESENT	0
159828	158052	07026Q	PARTICIPANT	\N	PRESENT	0
159829	158052	92031P	PARTICIPANT	\N	PRESENT	0
159830	158052	11077T	PARTICIPANT	\N	PRESENT	0
159831	158052	14269B	PARTICIPANT	\N	PRESENT	0
159832	158052	14037X	PARTICIPANT	\N	PRESENT	0
159833	158052	11099A	PARTICIPANT	\N	PRESENT	0
159834	158052	83042R	PARTICIPANT	\N	PRESENT	0
159835	158052	08034U	PARTICIPANT	\N	PRESENT	0
159836	158052	88008L	PARTICIPANT	\N	PRESENT	0
159837	158052	08051V	PARTICIPANT	\N	PRESENT	0
159838	158052	08049C	PARTICIPANT	\N	PRESENT	0
159839	158052	04038G	PARTICIPANT	\N	PRESENT	0
159840	158052	11020A	PARTICIPANT	\N	PRESENT	0
159841	158052	04079R	PARTICIPANT	\N	PRESENT	0
159842	158052	14251Q	PARTICIPANT	\N	PRESENT	0
159843	158052	95049N	PARTICIPANT	\N	PRESENT	0
159844	158052	11082Q	PARTICIPANT	\N	PRESENT	0
159845	158052	01007L	PARTICIPANT	\N	PRESENT	0
159846	158052	04040A	PARTICIPANT	\N	PRESENT	0
159847	158052	14089Y	PARTICIPANT	\N	PRESENT	0
159848	158052	04086Q	PARTICIPANT	\N	PRESENT	0
159849	158052	01034P	PARTICIPANT	\N	PRESENT	0
159850	158052	11093T	PARTICIPANT	\N	PRESENT	0
159851	158052	01024M	PARTICIPANT	\N	PRESENT	0
159852	158052	14041T	PARTICIPANT	\N	PRESENT	0
159853	158052	11053K	PARTICIPANT	\N	PRESENT	0
159854	158052	09001P	PARTICIPANT	\N	PRESENT	0
159855	158052	14205J	PARTICIPANT	\N	PRESENT	0
159856	158052	04089T	PARTICIPANT	\N	PRESENT	0
159857	158052	11072N	PARTICIPANT	\N	PRESENT	0
159858	158052	14231L	PARTICIPANT	\N	PRESENT	0
159859	158052	14219Q	PARTICIPANT	\N	PRESENT	0
159860	158052	01056V	PARTICIPANT	\N	PRESENT	0
159861	158052	01058X	PARTICIPANT	\N	PRESENT	0
159862	158052	14241N	PARTICIPANT	\N	PRESENT	0
159863	158052	96004D	PARTICIPANT	\N	PRESENT	0
159864	158052	04070G	PARTICIPANT	\N	PRESENT	0
159865	158052	14073Q	PARTICIPANT	\N	PRESENT	0
159866	158052	04047H	PARTICIPANT	\N	PRESENT	0
159868	158052	14083S	PARTICIPANT	\N	PRESENT	0
159870	158052	92040Q	PARTICIPANT	\N	PRESENT	0
159871	158052	14217N	PARTICIPANT	\N	PRESENT	0
159872	158052	11114F	PARTICIPANT	\N	PRESENT	0
159874	158052	95059Q	PARTICIPANT	\N	PRESENT	0
159875	158052	14239U	PARTICIPANT	\N	PRESENT	0
159878	158052	14247U	PARTICIPANT	\N	PRESENT	0
159879	158052	95067Q	PARTICIPANT	\N	PRESENT	0
159881	158052	14355X	PARTICIPANT	\N	PRESENT	0
159882	158052	08062Y	PARTICIPANT	\N	PRESENT	0
159884	158052	14253S	PARTICIPANT	\N	PRESENT	0
159886	158052	14033T	PARTICIPANT	\N	PRESENT	0
159887	158052	04094Q	PARTICIPANT	\N	PRESENT	0
159888	158052	08073C	PARTICIPANT	\N	PRESENT	0
159889	158052	11048N	PARTICIPANT	\N	PRESENT	0
159890	158052	01057W	PARTICIPANT	\N	PRESENT	0
159895	158052	14249W	PARTICIPANT	\N	PRESENT	0
159897	158052	04055H	PARTICIPANT	\N	PRESENT	0
159899	158052	04081K	PARTICIPANT	\N	PRESENT	0
159902	158052	04043D	PARTICIPANT	\N	PRESENT	0
159903	158052	04071H	PARTICIPANT	\N	PRESENT	0
159904	158052	10006L	PARTICIPANT	\N	PRESENT	0
159905	158052	14105F	PARTICIPANT	\N	PRESENT	0
148216	148192	08009T	PRESIDENT	0	PRESENT	0
148217	148192	08062Y	PARTICIPANT	\N	PRESENT	0
148218	148192	14221J	PARTICIPANT	\N	PRESENT	0
148219	148192	92039X	PARTICIPANT	\N	PRESENT	0
148220	148192	08042U	PARTICIPANT	\N	PRESENT	0
148221	148192	14169X	PARTICIPANT	\N	PRESENT	0
148222	148192	14237S	PARTICIPANT	\N	PRESENT	0
148223	148192	13002U	PARTICIPANT	\N	PRESENT	0
148224	148192	05012A	PARTICIPANT	\N	PRESENT	0
148474	147603	08016S	PARTICIPANT	\N	PRESENT	0
148226	148192	14135M	PARTICIPANT	\N	PRESENT	0
148227	148192	14331P	PARTICIPANT	\N	PRESENT	0
148228	148192	95062K	PARTICIPANT	\N	PRESENT	0
148229	148192	14107H	PARTICIPANT	\N	PRESENT	0
148230	148192	14051J	PARTICIPANT	\N	PRESENT	0
148231	148192	14157T	PARTICIPANT	\N	PRESENT	0
148232	148192	11095V	PARTICIPANT	\N	EXCUSE	0
148475	147603	04081K	PARTICIPANT	\N	PRESENT	0
148596	148551	14028W	PARTICIPANT	\N	PRESENT	0
148597	148551	14193X	PARTICIPANT	\N	PRESENT	0
148598	148551	98021N	PARTICIPANT	\N	EXCUSE	0
148599	148551	04080J	PARTICIPANT	\N	PRESENT	0
148600	148551	95059Q	PRESIDENT	0	PRESENT	0
148601	148551	86044G	PARTICIPANT	\N	PRESENT	0
148602	148551	01014K	PARTICIPANT	\N	PRESENT	0
148603	148551	11054L	PARTICIPANT	\N	EXCUSE	0
148604	148551	01056V	PARTICIPANT	\N	PRESENT	0
148605	148551	92044U	PARTICIPANT	\N	PRESENT	0
148606	148551	08049C	PARTICIPANT	\N	PRESENT	0
148607	148551	04050C	PARTICIPANT	\N	PRESENT	0
149134	149092	98053W	PARTICIPANT	\N	PRESENT	0
149152	149092	04057K	PARTICIPANT	\N	PRESENT	0
149153	149092	14191V	PARTICIPANT	\N	PRESENT	0
149154	149092	14041T	PARTICIPANT	\N	PRESENT	0
149155	149092	14195A	PARTICIPANT	\N	PRESENT	0
149156	149092	14213J	PARTICIPANT	\N	PRESENT	0
149157	149092	14089Y	PARTICIPANT	\N	PRESENT	0
149158	149092	80013X	PARTICIPANT	\N	PRESENT	0
149159	149092	11034G	PARTICIPANT	\N	PRESENT	0
149160	149092	14031R	PARTICIPANT	\N	PRESENT	0
149172	149092	14267Y	PARTICIPANT	\N	PRESENT	0
149173	149092	11081P	PARTICIPANT	\N	PRESENT	0
149174	149092	01031L	PARTICIPANT	\N	PRESENT	0
149175	149092	08012N	PARTICIPANT	\N	PRESENT	0
149176	147870	98053W	PARTICIPANT	\N	PRESENT	0
149177	147870	04057K	PARTICIPANT	\N	PRESENT	0
149178	147870	14191V	PARTICIPANT	\N	PRESENT	0
149179	147870	14041T	PARTICIPANT	\N	PRESENT	0
149180	147870	14195A	PARTICIPANT	\N	PRESENT	0
149181	147870	14213J	PARTICIPANT	\N	PRESENT	0
149182	147870	14089Y	PARTICIPANT	\N	PRESENT	0
149183	147870	80013X	PARTICIPANT	\N	PRESENT	0
149184	147870	11034G	PARTICIPANT	\N	PRESENT	0
149185	147870	14031R	PARTICIPANT	\N	PRESENT	0
149186	147870	14267Y	PARTICIPANT	\N	PRESENT	0
149187	147870	11081P	PARTICIPANT	\N	PRESENT	0
149188	147870	01031L	PARTICIPANT	\N	PRESENT	0
149189	147870	08012N	PARTICIPANT	\N	PRESENT	0
149190	147870	11056N	PARTICIPANT	\N	PRESENT	0
149191	147870	14159V	PARTICIPANT	\N	PRESENT	0
149192	147870	14121F	PARTICIPANT	\N	PRESENT	0
149193	147870	14197C	PARTICIPANT	\N	PRESENT	0
149194	147870	11083R	PARTICIPANT	\N	PRESENT	0
149195	147870	14219Q	PARTICIPANT	\N	PRESENT	0
149196	147870	04067M	PARTICIPANT	\N	PRESENT	0
149197	147870	11012A	PARTICIPANT	\N	PRESENT	0
149198	147870	14241N	PARTICIPANT	\N	PRESENT	0
149232	147870	14107H	PARTICIPANT	\N	PRESENT	0
149256	147870	08031R	PARTICIPANT	\N	PRESENT	0
149257	147870	11036J	PARTICIPANT	\N	PRESENT	0
149294	147871	11064N	PARTICIPANT	\N	PRESENT	0
149295	147871	14159V	PARTICIPANT	\N	PRESENT	0
149296	147871	11061K	PARTICIPANT	\N	PRESENT	0
149297	147871	11036J	PARTICIPANT	\N	PRESENT	0
149298	147871	04085P	PARTICIPANT	\N	PRESENT	0
149299	147871	07026Q	PARTICIPANT	\N	PRESENT	0
149300	147871	04050C	PARTICIPANT	\N	PRESENT	0
149301	147871	11098Y	PARTICIPANT	\N	PRESENT	0
149302	147871	11063M	PARTICIPANT	\N	PRESENT	0
149303	147871	11034G	PARTICIPANT	\N	PRESENT	0
149304	147871	14265W	PARTICIPANT	\N	PRESENT	0
149305	147871	11084S	PARTICIPANT	\N	PRESENT	0
149306	147871	04067M	PARTICIPANT	\N	PRESENT	0
149312	147871	11031D	PARTICIPANT	\N	PRESENT	0
149313	147871	14013P	PARTICIPANT	\N	PRESENT	0
149314	147871	11010L	PARTICIPANT	\N	PRESENT	0
149315	147871	04036E	PARTICIPANT	\N	PRESENT	0
149316	147871	08051V	PARTICIPANT	\N	PRESENT	0
149317	147871	98053W	PARTICIPANT	\N	PRESENT	0
149318	147871	14241N	PARTICIPANT	\N	PRESENT	0
149342	147871	95035G	PARTICIPANT	\N	PRESENT	0
149352	147871	11112D	PARTICIPANT	\N	PRESENT	0
149553	147872	14237S	PARTICIPANT	\N	PRESENT	0
149554	147872	11025F	PARTICIPANT	\N	PRESENT	0
149555	147872	14219Q	PARTICIPANT	\N	PRESENT	0
149292	147871	04081K	PARTICIPANT	\N	PRESENT	0
149293	147871	14055N	PARTICIPANT	\N	PRESENT	0
149556	147872	14327T	PARTICIPANT	\N	PRESENT	0
149557	147872	14331P	PARTICIPANT	\N	PRESENT	0
149558	147872	14179A	PARTICIPANT	\N	PRESENT	0
149559	147872	14107H	PARTICIPANT	\N	PRESENT	0
149560	147872	08009T	PARTICIPANT	\N	PRESENT	0
149561	147872	14038Y	PARTICIPANT	\N	PRESENT	0
149562	147872	01059Y	PARTICIPANT	\N	PRESENT	0
149572	147872	14121F	PARTICIPANT	\N	PRESENT	0
149573	147872	11056N	PARTICIPANT	\N	PRESENT	0
149574	147872	04085P	PARTICIPANT	\N	PRESENT	0
149575	147872	01015L	PARTICIPANT	\N	PRESENT	0
149576	147872	08052W	PARTICIPANT	\N	PRESENT	0
149577	147872	04067M	PARTICIPANT	\N	PRESENT	0
149578	147872	14265W	PARTICIPANT	\N	PRESENT	0
149579	147872	11081P	PARTICIPANT	\N	PRESENT	0
149580	147872	95037J	PARTICIPANT	\N	PRESENT	0
149581	147872	01022K	PARTICIPANT	\N	PRESENT	0
149582	147872	11065P	PARTICIPANT	\N	PRESENT	0
149583	147872	04053F	PARTICIPANT	\N	PRESENT	0
149584	147872	08016S	PARTICIPANT	\N	PRESENT	0
149585	147872	95067Q	PARTICIPANT	\N	PRESENT	0
149586	147872	01008M	PARTICIPANT	\N	PRESENT	0
149587	147872	01031L	PARTICIPANT	\N	PRESENT	0
149588	147872	11100Y	PARTICIPANT	\N	PRESENT	0
149589	147872	14175V	PARTICIPANT	\N	PRESENT	0
149590	147872	14014Q	PARTICIPANT	\N	PRESENT	0
149591	147872	11043H	PARTICIPANT	\N	PRESENT	0
149612	147872	04066L	PARTICIPANT	\N	PRESENT	0
149672	147872	11023D	PARTICIPANT	\N	PRESENT	0
149705	147872	08019V	PARTICIPANT	\N	PRESENT	0
149706	147872	14259Y	PARTICIPANT	\N	PRESENT	0
149707	147872	14111D	PARTICIPANT	\N	PRESENT	0
149712	147872	11103C	PARTICIPANT	\N	PRESENT	0
149713	147872	01016M	PARTICIPANT	\N	PRESENT	0
149714	147872	01027Q	PARTICIPANT	\N	PRESENT	0
149732	147872	11112D	PARTICIPANT	\N	PRESENT	0
149793	147873	01015L	PARTICIPANT	\N	PRESENT	0
149794	147873	14107H	PARTICIPANT	\N	PRESENT	0
149795	147873	01022K	PARTICIPANT	\N	PRESENT	0
149796	147873	11056N	PARTICIPANT	\N	PRESENT	0
149797	147873	04067M	PARTICIPANT	\N	PRESENT	0
149798	147873	14219Q	PARTICIPANT	\N	PRESENT	0
149799	147873	14327T	PARTICIPANT	\N	PRESENT	0
149800	147873	14179A	PARTICIPANT	\N	PRESENT	0
149801	147873	14038Y	PARTICIPANT	\N	PRESENT	0
149802	147873	08019V	PARTICIPANT	\N	PRESENT	0
149803	147873	14175V	PARTICIPANT	\N	PRESENT	0
149804	147873	11103C	PARTICIPANT	\N	PRESENT	0
149805	147873	11043H	PARTICIPANT	\N	PRESENT	0
149806	147873	11081P	PARTICIPANT	\N	PRESENT	0
149807	147873	14018U	PARTICIPANT	\N	PRESENT	0
149808	147873	08009T	PARTICIPANT	\N	PRESENT	0
149809	147873	14237S	PARTICIPANT	\N	PRESENT	0
149810	147873	95067Q	PARTICIPANT	\N	PRESENT	0
149811	147873	14265W	PARTICIPANT	\N	PRESENT	0
149812	147873	01031L	PARTICIPANT	\N	PRESENT	0
149813	147873	01016M	PARTICIPANT	\N	PRESENT	0
149832	147873	95063L	PARTICIPANT	\N	PRESENT	0
149833	147873	14014Q	PARTICIPANT	\N	PRESENT	0
149834	147873	14111D	PARTICIPANT	\N	PRESENT	0
149852	147873	14069U	PARTICIPANT	\N	PRESENT	0
149853	147873	11112D	PARTICIPANT	\N	PRESENT	0
149854	147873	92039X	PARTICIPANT	\N	PRESENT	0
149872	147873	01008M	PARTICIPANT	\N	PRESENT	0
149892	147873	11065P	PARTICIPANT	\N	PRESENT	0
149893	147873	92045V	PARTICIPANT	\N	PRESENT	0
149772	147873	04081K	PARTICIPANT	\N	PRESENT	0
149792	147873	01059Y	PARTICIPANT	\N	PRESENT	0
151253	151252	96004D	PARTICIPANT	\N	PRESENT	0
151254	151252	14097Y	PARTICIPANT	\N	PRESENT	0
151255	151252	11083R	PARTICIPANT	\N	PRESENT	0
151256	151252	14133K	PARTICIPANT	\N	PRESENT	0
131434	131433	04047H	PARTICIPANT	\N	EXCUSE	0
131435	131433	01024M	PARTICIPANT	\N	PRESENT	0
131436	131433	14215L	PARTICIPANT	\N	PRESENT	0
131437	131433	01007L	PARTICIPANT	\N	PRESENT	0
131438	131433	11049P	PARTICIPANT	\N	PRESENT	0
131439	131433	08044W	PARTICIPANT	\N	EXCUSE	0
131440	131433	14111D	PARTICIPANT	\N	EXCUSE	0
131441	131433	14147R	PARTICIPANT	\N	PRESENT	0
131442	131433	04074L	PARTICIPANT	\N	PRESENT	0
131443	131433	04044E	PRESIDENT	0	PRESENT	0
131444	131433	11037K	PARTICIPANT	\N	PRESENT	0
131445	131433	95067Q	PARTICIPANT	\N	PRESENT	0
131471	131433	11035H	PARTICIPANT	\N	EXCUSE	0
131472	131433	14041T	PARTICIPANT	\N	EXCUSE	0
131490	120701	14034U	PARTICIPANT	\N	EXCUSE	0
131543	131542	08022Q	PARTICIPANT	\N	PRESENT	0
131545	131544	08022Q	PARTICIPANT	\N	PRESENT	0
131547	131546	11053K	PARTICIPANT	\N	PRESENT	0
131551	131550	08022Q	PARTICIPANT	\N	PRESENT	0
134705	134704	11044J	PARTICIPANT	\N	PRESENT	0
134706	134704	01003G	PARTICIPANT	\N	PRESENT	0
134828	134827	01025N	PARTICIPANT	\N	PRESENT	0
134830	134829	01025N	PARTICIPANT	\N	PRESENT	0
134833	134832	14123H	PARTICIPANT	\N	PRESENT	0
134835	134834	14123H	PARTICIPANT	\N	PRESENT	0
134839	134838	98042T	PARTICIPANT	\N	PRESENT	0
134848	134846	98042T	PARTICIPANT	\N	PRESENT	0
134852	134851	98042T	PARTICIPANT	\N	PRESENT	0
134862	134859	01025N	PARTICIPANT	\N	PRESENT	0
140292	140291	89017R	PARTICIPANT	\N	PRESENT	0
140293	140291	01031L	PRESIDENT	0	PRESENT	0
140294	140291	08014Q	PARTICIPANT	\N	PRESENT	0
140295	140291	14175V	PARTICIPANT	\N	PRESENT	0
140296	140291	14085U	PARTICIPANT	\N	PRESENT	0
140297	140291	04086Q	PARTICIPANT	\N	PRESENT	0
140298	140291	04055H	PARTICIPANT	\N	PRESENT	0
140299	140291	11070L	PARTICIPANT	\N	PRESENT	0
140300	140291	11088W	PARTICIPANT	\N	PRESENT	0
140301	140291	14327T	PARTICIPANT	\N	PRESENT	0
140302	140291	08022Q	PARTICIPANT	\N	PRESENT	0
140303	140291	01027Q	PARTICIPANT	\N	PRESENT	0
140304	140291	04071H	PARTICIPANT	\N	PRESENT	0
140305	140291	11074Q	PARTICIPANT	\N	PRESENT	0
140306	140291	11083R	PARTICIPANT	\N	PRESENT	0
140307	140291	14199E	PARTICIPANT	\N	PRESENT	0
140308	140291	01057W	PARTICIPANT	\N	PRESENT	0
140309	140291	99004R	PARTICIPANT	\N	PRESENT	0
140310	140291	14159V	PARTICIPANT	\N	PRESENT	0
140311	140291	07029T	PARTICIPANT	\N	PRESENT	0
140312	140291	08010L	PARTICIPANT	\N	PRESENT	0
140313	140291	08034U	PARTICIPANT	\N	PRESENT	0
140314	140291	01048V	PARTICIPANT	\N	PRESENT	0
140315	140291	98046X	PARTICIPANT	\N	PRESENT	0
140316	140291	08011M	PARTICIPANT	\N	PRESENT	0
140317	140291	01016M	PARTICIPANT	\N	PRESENT	0
140318	140291	14225N	PARTICIPANT	\N	PRESENT	0
140322	140291	08016S	PARTICIPANT	\N	EXCUSE	0
140320	140291	04034C	PARTICIPANT	\N	PRESENT	0
140321	140291	98053W	PARTICIPANT	\N	EXCUSE	0
140323	140291	11097X	RAPPORTEUR_AVIS	\N	PRESENT	0
140324	140291	14081Q	RAPPORTEUR_AVIS	\N	PRESENT	0
140648	140647	04045F	PARTICIPANT	\N	PRESENT	0
140649	140647	92045V	PARTICIPANT	\N	PRESENT	0
140656	140655	92045V	PARTICIPANT	\N	PRESENT	0
140662	140660	92045V	PARTICIPANT	\N	PRESENT	0
140658	140655	04045F	PARTICIPANT	\N	PRESENT	0
140661	140660	04045F	PARTICIPANT	\N	PRESENT	0
147153	147152	04049K	PARTICIPANT	\N	PRESENT	0
140948	140946	14255U	PARTICIPANT	\N	PRESENT	0
140951	140950	04049K	PARTICIPANT	\N	PRESENT	0
140952	140950	14255U	PARTICIPANT	\N	PRESENT	0
147975	147928	14109K	PARTICIPANT	\N	EXCUSE	0
147154	147152	14255U	PARTICIPANT	\N	PRESENT	0
147976	147928	04070G	PRESIDENT	0	PRESENT	0
147977	147928	92040Q	PARTICIPANT	\N	PRESENT	0
147978	147928	14191V	PARTICIPANT	\N	PRESENT	0
147979	147928	83047W	PARTICIPANT	\N	PRESENT	0
147980	147928	14235Q	PARTICIPANT	\N	EXCUSE	0
147981	147928	14055N	PARTICIPANT	\N	PRESENT	0
148254	147092	11083R	PARTICIPANT	\N	PRESENT	0
147983	147928	14229S	PARTICIPANT	\N	PRESENT	0
148029	148028	14263U	PARTICIPANT	\N	PRESENT	0
148030	148028	14133K	PARTICIPANT	\N	PRESENT	0
148252	147092	14135M	PARTICIPANT	\N	PRESENT	0
148032	148028	04059M	PARTICIPANT	\N	PRESENT	0
148033	148028	11039M	PARTICIPANT	\N	PRESENT	0
148034	148028	01044R	PARTICIPANT	\N	PRESENT	0
148035	148028	08043V	PARTICIPANT	\N	PRESENT	0
148036	148028	14089Y	PARTICIPANT	\N	PRESENT	0
148037	148028	14105F	PARTICIPANT	\N	PRESENT	0
148038	148028	11029K	PARTICIPANT	\N	PRESENT	0
148039	148028	95015C	PARTICIPANT	\N	EXCUSE	0
148253	147092	97011G	PARTICIPANT	\N	PRESENT	0
148333	148332	08025T	PARTICIPANT	\N	PRESENT	0
148042	148028	14201E	PARTICIPANT	\N	EXCUSE	0
148334	148332	04085P	PARTICIPANT	\N	PRESENT	0
148044	148028	14209N	PARTICIPANT	\N	PRESENT	0
148335	148332	05008E	PRESIDENT	0	PRESENT	0
148046	148028	11091R	PARTICIPANT	\N	EXCUSE	0
148047	148028	87003B	PARTICIPANT	\N	PRESENT	0
148048	148028	98042T	PARTICIPANT	\N	PRESENT	0
148336	148332	11030C	PARTICIPANT	\N	PRESENT	0
148050	148028	01041N	PARTICIPANT	\N	PRESENT	0
148051	148028	01025N	PARTICIPANT	\N	PRESENT	0
148052	148028	01037S	PARTICIPANT	\N	PRESENT	0
148053	148028	89029V	PARTICIPANT	\N	PRESENT	0
148054	148028	08035V	PARTICIPANT	\N	PRESENT	0
148055	148028	11089X	PARTICIPANT	\N	PRESENT	0
148056	148028	07026Q	PARTICIPANT	\N	PRESENT	0
148057	148028	14123H	PARTICIPANT	\N	PRESENT	0
148058	148028	14179A	PARTICIPANT	\N	PRESENT	0
148337	148332	11033F	PARTICIPANT	\N	PRESENT	0
148060	148028	14241N	PARTICIPANT	\N	PRESENT	0
148061	148028	14061L	PARTICIPANT	\N	PRESENT	0
148062	148028	14073Q	PARTICIPANT	\N	PRESENT	0
148063	148028	08031R	PARTICIPANT	\N	PRESENT	0
148064	148028	12041X	PARTICIPANT	\N	PRESENT	0
148065	148028	08039A	PARTICIPANT	\N	PRESENT	0
148066	148028	08017T	PARTICIPANT	\N	PRESENT	0
148067	148028	14059S	PARTICIPANT	\N	PRESENT	0
148068	148028	08012N	PARTICIPANT	\N	PRESENT	0
148338	148332	14065Q	PARTICIPANT	\N	PRESENT	0
148070	148028	11104D	PARTICIPANT	\N	PRESENT	0
148071	148028	14063N	PARTICIPANT	\N	PRESENT	0
148072	148028	04057K	PARTICIPANT	\N	EXCUSE	0
148073	148028	11014C	PARTICIPANT	\N	PRESENT	0
148074	148028	14109K	PARTICIPANT	\N	EXCUSE	0
148075	148028	04070G	PRESIDENT	0	PRESENT	0
148076	148028	92040Q	PARTICIPANT	\N	PRESENT	0
148077	148028	14191V	PARTICIPANT	\N	PRESENT	0
148078	148028	83047W	PARTICIPANT	\N	PRESENT	0
148079	148028	14235Q	PARTICIPANT	\N	EXCUSE	0
148080	148028	14055N	PARTICIPANT	\N	PRESENT	0
148339	148332	14069U	PARTICIPANT	\N	PRESENT	0
148082	148028	14229S	PARTICIPANT	\N	PRESENT	0
148340	148332	04047H	PARTICIPANT	\N	PRESENT	0
148341	148332	11032E	PARTICIPANT	\N	PRESENT	0
148342	148332	04038G	PARTICIPANT	\N	PRESENT	0
148343	148332	99002P	PARTICIPANT	\N	PRESENT	0
148344	148332	11056N	PARTICIPANT	\N	EXCUSE	0
148345	148332	14259Y	PARTICIPANT	\N	PRESENT	0
148346	148332	14041T	PARTICIPANT	\N	PRESENT	0
148347	148332	11113E	PARTICIPANT	\N	PRESENT	0
148348	148332	01024M	PARTICIPANT	\N	EXCUSE	0
148349	148332	14215L	PARTICIPANT	\N	PRESENT	0
148350	148332	11034G	PARTICIPANT	\N	PRESENT	0
148351	148332	08018U	PARTICIPANT	\N	PRESENT	0
148352	148332	11010L	PARTICIPANT	\N	PRESENT	0
148353	148332	01007L	PARTICIPANT	\N	PRESENT	0
148354	148332	11049P	PARTICIPANT	\N	PRESENT	0
148355	148332	08044W	PARTICIPANT	\N	EXCUSE	0
148356	148332	11084S	PARTICIPANT	\N	PRESENT	0
148357	148332	14111D	PARTICIPANT	\N	PRESENT	0
148358	148332	14001X	PARTICIPANT	\N	PRESENT	0
148359	148332	01060R	PARTICIPANT	\N	PRESENT	0
148360	148332	14147R	PARTICIPANT	\N	PRESENT	0
148361	148332	95049N	PARTICIPANT	\N	PRESENT	0
148362	148332	08051V	PARTICIPANT	\N	PRESENT	0
148363	148332	11072N	PARTICIPANT	\N	PRESENT	0
148364	148332	07034Q	PARTICIPANT	\N	PRESENT	0
148365	148332	04074L	PARTICIPANT	\N	PRESENT	0
148366	148332	10015M	PARTICIPANT	\N	PRESENT	0
148367	148332	95063L	PARTICIPANT	\N	PRESENT	0
148368	148332	01019Q	PARTICIPANT	\N	PRESENT	0
148369	148332	01028R	PARTICIPANT	\N	PRESENT	0
148370	148332	98035U	PARTICIPANT	\N	PRESENT	0
148371	148332	04044E	PARTICIPANT	\N	PRESENT	0
148372	148332	11037K	PARTICIPANT	\N	PRESENT	0
148373	148332	92045V	PARTICIPANT	\N	PRESENT	0
143596	143033	11098Y	PARTICIPANT	\N	PRESENT	0
143597	143033	08014Q	PARTICIPANT	\N	PRESENT	0
143598	143033	11042G	PARTICIPANT	\N	PRESENT	0
143599	143033	04045F	PARTICIPANT	\N	PRESENT	0
143600	143033	97011G	PARTICIPANT	\N	PRESENT	0
143601	143033	14033T	PARTICIPANT	\N	PRESENT	0
143602	143033	12042Y	PARTICIPANT	\N	PRESENT	0
143603	143033	14257W	PARTICIPANT	\N	PRESENT	0
143604	143033	14063N	PARTICIPANT	\N	PRESENT	0
143605	143033	14207L	PARTICIPANT	\N	PRESENT	0
143606	143033	04038G	PARTICIPANT	\N	PRESENT	0
143607	143033	14261S	PARTICIPANT	\N	PRESENT	0
143608	143033	01046T	PARTICIPANT	\N	PRESENT	0
143609	143033	01003G	PARTICIPANT	\N	PRESENT	0
143610	143033	14205J	PARTICIPANT	\N	PRESENT	0
143611	143033	14111D	PARTICIPANT	\N	PRESENT	0
143615	143033	98022P	PARTICIPANT	\N	PRESENT	0
143613	143033	04088S	PARTICIPANT	\N	PRESENT	0
143614	143033	14241N	PARTICIPANT	\N	PRESENT	0
143616	143033	08042U	PARTICIPANT	\N	PRESENT	0
143617	143033	14071N	PARTICIPANT	\N	PRESENT	0
143618	143033	08060W	PARTICIPANT	\N	PRESENT	0
143619	143033	08016S	PARTICIPANT	\N	PRESENT	0
143620	143033	11099A	PARTICIPANT	\N	PRESENT	0
143621	143033	14201E	PARTICIPANT	\N	PRESENT	0
143622	143033	14031R	PARTICIPANT	\N	PRESENT	0
143623	143033	01008M	PARTICIPANT	\N	PRESENT	0
143631	143033	14265W	PARTICIPANT	\N	PRESENT	0
143656	143033	11012A	PARTICIPANT	\N	PRESENT	0
143657	143033	08031R	PARTICIPANT	\N	PRESENT	0
143658	143033	14073Q	PARTICIPANT	\N	PRESENT	0
143659	143033	11094U	PARTICIPANT	\N	PRESENT	0
143660	143033	11071M	PARTICIPANT	\N	PRESENT	0
143661	143033	92015P	PARTICIPANT	\N	PRESENT	0
143662	143033	14083S	PARTICIPANT	\N	PRESENT	0
143663	143033	14281W	PARTICIPANT	\N	PRESENT	0
143664	143033	04057K	PARTICIPANT	\N	PRESENT	0
143677	143033	14179A	PARTICIPANT	\N	PRESENT	0
143679	143033	14103D	PARTICIPANT	\N	PRESENT	0
143684	143033	11025F	PARTICIPANT	\N	PRESENT	0
143685	143033	14037X	PARTICIPANT	\N	PRESENT	0
143795	143033	11039M	PARTICIPANT	\N	PRESENT	0
143796	143033	04034C	PARTICIPANT	\N	PRESENT	0
143797	143033	08055A	PARTICIPANT	\N	PRESENT	0
143798	143033	01037S	PARTICIPANT	\N	PRESENT	0
143799	143033	95015C	PARTICIPANT	\N	PRESENT	0
143801	143033	14014Q	PARTICIPANT	\N	PRESENT	0
143816	143034	01007L	PARTICIPANT	\N	PRESENT	0
143594	143033	01007L	PARTICIPANT	\N	PRESENT	0
143595	143033	08051V	PARTICIPANT	\N	PRESENT	0
143852	143034	11113E	PARTICIPANT	\N	PRESENT	0
143853	143034	04095R	PARTICIPANT	\N	PRESENT	0
143854	143034	14261S	PARTICIPANT	\N	PRESENT	0
143855	143034	14039A	PARTICIPANT	\N	PRESENT	0
143856	143034	11025F	PARTICIPANT	\N	PRESENT	0
143857	143034	11072N	PARTICIPANT	\N	PRESENT	0
143858	143034	11042G	PARTICIPANT	\N	PRESENT	0
143859	143034	01037S	PARTICIPANT	\N	PRESENT	0
143860	143034	14281W	PARTICIPANT	\N	PRESENT	0
143861	143034	08073C	PARTICIPANT	\N	PRESENT	0
143862	143034	11029K	PARTICIPANT	\N	PRESENT	0
143863	143034	01016M	PARTICIPANT	\N	PRESENT	0
143864	143034	08016S	PARTICIPANT	\N	PRESENT	0
143865	143034	08055A	PARTICIPANT	\N	PRESENT	0
143866	143034	14271U	PARTICIPANT	\N	PRESENT	0
143867	143034	01031L	PARTICIPANT	\N	PRESENT	0
143868	143034	05001W	PARTICIPANT	\N	PRESENT	0
143869	143034	11098Y	PARTICIPANT	\N	PRESENT	0
143870	143034	04094Q	PARTICIPANT	\N	PRESENT	0
143871	143034	11109J	PARTICIPANT	\N	PRESENT	0
143872	143034	11114F	PARTICIPANT	\N	PRESENT	0
143873	143034	04040A	PARTICIPANT	\N	PRESENT	0
143874	143034	97011G	PARTICIPANT	\N	PRESENT	0
143875	143034	14265W	PARTICIPANT	\N	PRESENT	0
143876	143034	04092N	PARTICIPANT	\N	PRESENT	0
143877	143034	04088S	PARTICIPANT	\N	PRESENT	0
143878	143034	14105F	PARTICIPANT	\N	PRESENT	0
143879	143034	11023D	PARTICIPANT	\N	PRESENT	0
143880	143034	14083S	PARTICIPANT	\N	PRESENT	0
143881	143034	14159V	PARTICIPANT	\N	PRESENT	0
143882	143034	14219Q	PARTICIPANT	\N	PRESENT	0
143883	143034	04045F	PARTICIPANT	\N	PRESENT	0
143884	143034	11012A	PARTICIPANT	\N	PRESENT	0
143885	143034	08019V	PARTICIPANT	\N	PRESENT	0
143892	143034	14073Q	PARTICIPANT	\N	PRESENT	0
143893	143034	01022K	PARTICIPANT	\N	PRESENT	0
143894	143034	08051V	PARTICIPANT	\N	PRESENT	0
143895	143034	14275Y	PARTICIPANT	\N	PRESENT	0
143896	143034	11036J	PARTICIPANT	\N	PRESENT	0
143906	143034	01058X	PARTICIPANT	\N	PRESENT	0
143907	143034	14259Y	PARTICIPANT	\N	PRESENT	0
143908	143034	14042U	PARTICIPANT	\N	PRESENT	0
144273	144272	96004D	PRESIDENT	0	PRESENT	0
144275	144272	14089Y	PARTICIPANT	\N	PRESENT	0
144276	144272	14073Q	PARTICIPANT	\N	PRESENT	0
144277	144272	11026G	PARTICIPANT	\N	PRESENT	0
144278	144272	04057K	PARTICIPANT	\N	PRESENT	0
144279	144272	11012A	PARTICIPANT	\N	PRESENT	0
144280	144272	95063L	PARTICIPANT	\N	PRESENT	0
144281	144272	04045F	PARTICIPANT	\N	PRESENT	0
144282	144272	98035U	PARTICIPANT	\N	PRESENT	0
144292	144272	08018U	PARTICIPANT	\N	EXCUSE	0
144293	144272	11035H	PARTICIPANT	\N	EXCUSE	0
144294	144272	08044W	PARTICIPANT	\N	EXCUSE	0
144295	144272	10015M	PARTICIPANT	\N	EXCUSE	0
144318	144272	04044E	PARTICIPANT	\N	PRESENT	0
144319	144272	08039A	PARTICIPANT	\N	PRESENT	0
144320	144272	01028R	PARTICIPANT	\N	PRESENT	0
144321	144272	14179A	PARTICIPANT	\N	PRESENT	0
144322	144272	11029K	PARTICIPANT	\N	PRESENT	0
144323	144272	08017T	PARTICIPANT	\N	PRESENT	0
144324	144272	08043V	PARTICIPANT	\N	PRESENT	0
144325	144272	01044R	PARTICIPANT	\N	PRESENT	0
144326	144272	07026Q	PARTICIPANT	\N	PRESENT	0
144327	144272	14063N	PARTICIPANT	\N	PRESENT	0
144328	144272	11109J	PARTICIPANT	\N	PRESENT	0
144329	144272	08051V	PARTICIPANT	\N	PRESENT	0
144330	144272	14105F	PARTICIPANT	\N	PRESENT	0
144331	144272	04056J	PARTICIPANT	\N	PRESENT	0
144672	141032	11037K	PARTICIPANT	\N	PRESENT	0
144694	144693	11089X	PARTICIPANT	\N	PRESENT	0
144697	144692	11089X	PARTICIPANT	\N	PRESENT	0
144699	144698	11089X	PARTICIPANT	\N	PRESENT	0
144792	125635	01058X	PARTICIPANT	\N	PRESENT	0
144793	125635	08069G	PARTICIPANT	\N	PRESENT	0
144794	125635	14263U	PARTICIPANT	\N	EXCUSE	0
144795	125635	08039A	PARTICIPANT	\N	EXCUSE	0
144796	125635	04043D	PARTICIPANT	\N	EXCUSE	0
145172	144514	08024S	PARTICIPANT	\N	PRESENT	0
145173	144514	14159V	PARTICIPANT	\N	PRESENT	0
145174	144514	14167V	PARTICIPANT	\N	PRESENT	0
145175	144514	11039M	PARTICIPANT	\N	PRESENT	0
145176	144514	98035U	PARTICIPANT	\N	PRESENT	0
145177	144514	01056V	PARTICIPANT	\N	PRESENT	0
145178	144514	11106F	PARTICIPANT	\N	PRESENT	0
145179	144514	14033T	PARTICIPANT	\N	PRESENT	0
145180	144514	14331P	PARTICIPANT	\N	PRESENT	0
145181	144514	14197C	PARTICIPANT	\N	PRESENT	0
145182	144514	14051J	PARTICIPANT	\N	PRESENT	0
145183	144514	08055A	PARTICIPANT	\N	PRESENT	0
145184	144514	08060W	PARTICIPANT	\N	PRESENT	0
145185	144514	98029W	PARTICIPANT	\N	PRESENT	0
145186	144514	11036J	PARTICIPANT	\N	PRESENT	0
145187	144514	14063N	PARTICIPANT	\N	PRESENT	0
145188	144514	92015P	PARTICIPANT	\N	PRESENT	0
145189	144514	08043V	PARTICIPANT	\N	PRESENT	0
145190	144514	14207L	PARTICIPANT	\N	PRESENT	0
145191	144514	14281W	PARTICIPANT	\N	PRESENT	0
145192	144514	11059R	PARTICIPANT	\N	PRESENT	0
145193	144514	11054L	PARTICIPANT	\N	PRESENT	0
145194	144514	98046X	PARTICIPANT	\N	PRESENT	0
145195	144514	08016S	PARTICIPANT	\N	PRESENT	0
145196	144514	12042Y	PARTICIPANT	\N	PRESENT	0
145197	144514	14225N	PARTICIPANT	\N	PRESENT	0
145198	144514	14085U	PARTICIPANT	\N	PRESENT	0
145199	144514	92039X	PARTICIPANT	\N	PRESENT	0
145200	144514	11104D	PARTICIPANT	\N	PRESENT	0
130202	130201	11083R	PARTICIPANT	\N	PRESENT	0
130203	130201	04057K	PARTICIPANT	\N	PRESENT	0
133052	131026	08043V	PARTICIPANT	\N	PRESENT	0
133053	131026	14229S	PARTICIPANT	\N	PRESENT	0
133055	133054	08043V	PARTICIPANT	\N	PRESENT	0
133056	133054	14229S	PARTICIPANT	\N	PRESENT	0
134246	134245	92040Q	PARTICIPANT	\N	PRESENT	0
134248	134247	92040Q	PARTICIPANT	\N	PRESENT	0
135558	135557	89017R	PARTICIPANT	\N	PRESENT	0
135560	135559	04071H	PARTICIPANT	\N	PRESENT	0
135562	135561	04071H	PARTICIPANT	\N	PRESENT	0
135564	135563	04071H	PARTICIPANT	\N	PRESENT	0
135733	124149	11061K	PARTICIPANT	\N	EXCUSE	0
135785	135784	98018T	PARTICIPANT	\N	PRESENT	0
135786	135784	04035D	PARTICIPANT	\N	PRESENT	0
135787	135784	11076S	PARTICIPANT	\N	PRESENT	0
135792	135791	95035G	PARTICIPANT	\N	PRESENT	0
135793	135791	01014K	PARTICIPANT	\N	PRESENT	0
135794	135791	07024N	PARTICIPANT	\N	PRESENT	0
137752	137751	07024N	PARTICIPANT	\N	PRESENT	0
137753	137751	01014K	PARTICIPANT	\N	PRESENT	0
137754	137751	11027H	PARTICIPANT	\N	PRESENT	0
138711	137517	80013X	PARTICIPANT	\N	PRESENT	0
146796	146794	01031L	PARTICIPANT	\N	PRESENT	0
146797	146794	08011M	PARTICIPANT	\N	PRESENT	0
146806	146805	01031L	PRESIDENT	0	PRESENT	0
146808	146805	14083S	PARTICIPANT	\N	PRESENT	0
146810	146805	14085U	PARTICIPANT	\N	PRESENT	0
146812	146805	04086Q	PARTICIPANT	\N	PRESENT	0
146814	146805	11074Q	PARTICIPANT	\N	PRESENT	0
146816	146805	11083R	PARTICIPANT	\N	PRESENT	0
146817	146805	01057W	PARTICIPANT	\N	PRESENT	0
146818	146805	04061F	PARTICIPANT	\N	PRESENT	0
146819	146805	07029T	PARTICIPANT	\N	PRESENT	0
146820	146805	98046X	PARTICIPANT	\N	PRESENT	0
146821	146805	08011M	PARTICIPANT	\N	PRESENT	0
146822	146805	01016M	PARTICIPANT	\N	PRESENT	0
146823	146805	04034C	PARTICIPANT	\N	PRESENT	0
146824	146805	08061X	PARTICIPANT	\N	EXCUSE	0
146825	146805	11085T	PARTICIPANT	\N	EXCUSE	0
146826	146805	98053W	PARTICIPANT	\N	EXCUSE	0
146827	146805	14327T	PARTICIPANT	\N	EXCUSE	0
146832	146805	96004D	PARTICIPANT	\N	PRESENT	0
146855	146805	04070G	PARTICIPANT	\N	PRESENT	0
146856	146805	14079W	PARTICIPANT	\N	PRESENT	0
146857	146805	14026U	PARTICIPANT	\N	PRESENT	0
146858	146805	14001X	PARTICIPANT	\N	PRESENT	0
146859	146805	14135M	PARTICIPANT	\N	PRESENT	0
148397	148396	04042C	PARTICIPANT	\N	PRESENT	0
148398	148396	92018S	PARTICIPANT	\N	EXCUSE	0
148399	148396	92020L	PARTICIPANT	\N	EXCUSE	0
148400	148396	95030B	PARTICIPANT	\N	PRESENT	0
148401	148396	04035D	PARTICIPANT	\N	EXCUSE	0
148402	148396	07024N	PARTICIPANT	\N	PRESENT	0
148403	148396	14014Q	PARTICIPANT	\N	PRESENT	0
148404	148396	95035G	PARTICIPANT	\N	PRESENT	0
148405	148396	14211G	PARTICIPANT	\N	PRESENT	0
148406	148396	98022P	PARTICIPANT	\N	PRESENT	0
148407	148396	95037J	PARTICIPANT	\N	PRESENT	0
148408	148396	14097Y	PARTICIPANT	\N	PRESENT	0
148409	148396	04036E	PARTICIPANT	\N	PRESENT	0
148410	148396	14039A	PARTICIPANT	\N	PRESENT	0
148411	148396	04077P	PARTICIPANT	\N	PRESENT	0
148412	148396	92031P	PARTICIPANT	\N	PRESENT	0
148413	148396	83042R	PARTICIPANT	\N	PRESENT	0
148414	148396	11105E	PARTICIPANT	\N	EXCUSE	0
148415	148396	14253S	PARTICIPANT	\N	PRESENT	0
148416	148396	08047A	PARTICIPANT	\N	PRESENT	0
148417	148396	14028W	PARTICIPANT	\N	PRESENT	0
148418	148396	98021N	PARTICIPANT	\N	EXCUSE	0
148419	148396	95059Q	PRESIDENT	0	PRESENT	0
148420	148396	11054L	PARTICIPANT	\N	EXCUSE	0
148421	148396	08049C	PARTICIPANT	\N	PRESENT	0
148422	148396	96004D	PARTICIPANT	\N	PRESENT	0
148423	148396	98035U	PARTICIPANT	\N	PRESENT	0
148424	148396	04034C	PARTICIPANT	\N	PRESENT	0
148425	148396	14001X	PARTICIPANT	\N	PRESENT	0
148426	148396	14073Q	PARTICIPANT	\N	PRESENT	0
148432	148431	04054G	PARTICIPANT	\N	PRESENT	0
148433	148431	04040A	PARTICIPANT	\N	PRESENT	0
148434	148431	04042C	PARTICIPANT	\N	PRESENT	0
148435	148431	77002U	PARTICIPANT	\N	PRESENT	0
148436	148431	98029W	PARTICIPANT	\N	PRESENT	0
148437	148431	11080N	PARTICIPANT	\N	PRESENT	0
148438	148431	98018T	PARTICIPANT	\N	PRESENT	0
148439	148431	92018S	PARTICIPANT	\N	EXCUSE	0
148440	148431	92020L	PARTICIPANT	\N	EXCUSE	0
148441	148431	95030B	PARTICIPANT	\N	PRESENT	0
148442	148431	97011G	PARTICIPANT	\N	PRESENT	0
148443	148431	04035D	PARTICIPANT	\N	EXCUSE	0
148444	148431	07024N	PARTICIPANT	\N	PRESENT	0
148476	148431	14014Q	PARTICIPANT	\N	PRESENT	0
148493	148431	11015D	PARTICIPANT	\N	PRESENT	0
148495	148431	07004J	PARTICIPANT	\N	PRESENT	0
148496	148431	95035G	PARTICIPANT	\N	PRESENT	0
148498	148431	08056B	PARTICIPANT	\N	PRESENT	0
148499	148431	14211G	PARTICIPANT	\N	PRESENT	0
148500	148431	98022P	PARTICIPANT	\N	PRESENT	0
148502	148431	11064N	PARTICIPANT	\N	PRESENT	0
148503	148431	95037J	PARTICIPANT	\N	PRESENT	0
148507	148431	04078Q	PARTICIPANT	\N	PRESENT	0
148508	148431	14097Y	PARTICIPANT	\N	PRESENT	0
148509	148431	95041E	PARTICIPANT	\N	PRESENT	0
148511	148431	04036E	PARTICIPANT	\N	EXCUSE	0
148512	148431	14039A	PARTICIPANT	\N	PRESENT	0
148513	148431	04077P	PARTICIPANT	\N	PRESENT	0
148515	148431	92031P	PARTICIPANT	\N	PRESENT	0
148516	148431	11106F	PARTICIPANT	\N	PRESENT	0
148518	148431	14251Q	PARTICIPANT	\N	PRESENT	0
148519	148431	83042R	PARTICIPANT	\N	PRESENT	0
148520	148431	08053X	PARTICIPANT	\N	PRESENT	0
148521	148431	11082Q	PARTICIPANT	\N	PRESENT	0
148523	148431	11105E	PARTICIPANT	\N	PRESENT	0
148524	148431	14253S	PARTICIPANT	\N	PRESENT	0
148525	148431	08047A	PARTICIPANT	\N	PRESENT	0
148527	148431	14028W	PARTICIPANT	\N	PRESENT	0
148528	148431	14193X	PARTICIPANT	\N	PRESENT	0
148530	148431	98021N	PARTICIPANT	\N	EXCUSE	0
148531	148431	04080J	PARTICIPANT	\N	PRESENT	0
148532	148431	95059Q	PRESIDENT	0	PRESENT	0
148534	148431	86044G	PARTICIPANT	\N	PRESENT	0
148535	148431	01014K	PARTICIPANT	\N	PRESENT	0
148537	148431	11054L	PARTICIPANT	\N	EXCUSE	0
148538	148431	01056V	PARTICIPANT	\N	PRESENT	0
148539	148431	92044U	PARTICIPANT	\N	PRESENT	0
148540	148431	08049C	PARTICIPANT	\N	PRESENT	0
148541	148431	04050C	PARTICIPANT	\N	PRESENT	0
148552	148551	04054G	PARTICIPANT	\N	PRESENT	0
148553	148551	04040A	PARTICIPANT	\N	PRESENT	0
148554	148551	08058D	PARTICIPANT	\N	PRESENT	0
148555	148551	04042C	PRESIDENT	1	PRESENT	0
148556	148551	77002U	PARTICIPANT	\N	PRESENT	0
148557	148551	98029W	PARTICIPANT	\N	PRESENT	0
148558	148551	11080N	PARTICIPANT	\N	PRESENT	0
148559	148551	98018T	PARTICIPANT	\N	PRESENT	0
148560	148551	92018S	PARTICIPANT	\N	EXCUSE	0
148561	148551	92020L	PARTICIPANT	\N	EXCUSE	0
148562	148551	95030B	PARTICIPANT	\N	PRESENT	0
148564	148551	97011G	PARTICIPANT	\N	PRESENT	0
148566	148551	04035D	PARTICIPANT	\N	EXCUSE	0
148567	148551	07024N	PARTICIPANT	\N	PRESENT	0
148568	148551	14014Q	PARTICIPANT	\N	PRESENT	0
148569	148551	11015D	PARTICIPANT	\N	PRESENT	0
148570	148551	07004J	PARTICIPANT	\N	PRESENT	0
148571	148551	95035G	PARTICIPANT	\N	PRESENT	0
148572	148551	08056B	PARTICIPANT	\N	PRESENT	0
148573	148551	14211G	PARTICIPANT	\N	PRESENT	0
148574	148551	98022P	PARTICIPANT	\N	PRESENT	0
148576	148551	11064N	PARTICIPANT	\N	PRESENT	0
148577	148551	95037J	PARTICIPANT	\N	PRESENT	0
148578	148551	04078Q	PARTICIPANT	\N	PRESENT	0
148580	148551	14097Y	PARTICIPANT	\N	PRESENT	0
148581	148551	95041E	PARTICIPANT	\N	PRESENT	0
148582	148551	04036E	PARTICIPANT	\N	EXCUSE	0
148584	148551	14039A	PARTICIPANT	\N	PRESENT	0
148585	148551	04077P	PARTICIPANT	\N	PRESENT	0
148586	148551	92031P	PARTICIPANT	\N	PRESENT	0
148587	148551	11106F	PARTICIPANT	\N	PRESENT	0
148589	148551	14251Q	PARTICIPANT	\N	PRESENT	0
148590	148551	83042R	PARTICIPANT	\N	PRESENT	0
148591	148551	08053X	PARTICIPANT	\N	PRESENT	0
148592	148551	11082Q	PARTICIPANT	\N	PRESENT	0
148593	148551	11105E	PARTICIPANT	\N	PRESENT	0
148594	148551	14253S	PARTICIPANT	\N	PRESENT	0
148595	148551	08047A	PARTICIPANT	\N	PRESENT	0
151257	151252	14079W	PARTICIPANT	\N	PRESENT	0
151258	151252	98035U	PARTICIPANT	\N	PRESENT	0
152794	152732	08024S	PARTICIPANT	\N	PRESENT	0
152853	152732	01031L	PARTICIPANT	\N	PRESENT	0
152854	152732	11040E	PARTICIPANT	\N	PRESENT	0
152855	152732	01022K	PARTICIPANT	\N	PRESENT	0
152856	152732	14063N	PARTICIPANT	\N	PRESENT	0
152857	152732	08014Q	PARTICIPANT	\N	PRESENT	0
152858	152732	98046X	PARTICIPANT	\N	PRESENT	0
152859	152732	01016M	PARTICIPANT	\N	PRESENT	0
152860	152732	95063L	PARTICIPANT	\N	PRESENT	0
152861	152732	11066Q	PARTICIPANT	\N	PRESENT	0
152911	152732	14269B	PARTICIPANT	\N	PRESENT	0
152912	152732	92039X	PARTICIPANT	\N	PRESENT	0
152913	152732	11057P	PARTICIPANT	\N	PRESENT	0
152914	152732	14085U	PARTICIPANT	\N	PRESENT	0
152915	152732	11083R	PARTICIPANT	\N	PRESENT	0
152916	152732	14267Y	PARTICIPANT	\N	PRESENT	0
152917	152732	11070L	PARTICIPANT	\N	PRESENT	0
152918	152732	11012A	PARTICIPANT	\N	PRESENT	0
152919	152732	14061L	PARTICIPANT	\N	PRESENT	0
152920	152732	11088W	PARTICIPANT	\N	PRESENT	0
152921	152732	07029T	PARTICIPANT	\N	PRESENT	0
152922	152732	14175V	PARTICIPANT	\N	PRESENT	0
152923	152732	14031R	PARTICIPANT	\N	PRESENT	0
152924	152732	14191V	PARTICIPANT	\N	PRESENT	0
152925	152732	14193X	PARTICIPANT	\N	PRESENT	0
152926	152732	08011M	PARTICIPANT	\N	PRESENT	0
152927	152732	11097X	PARTICIPANT	\N	PRESENT	0
152928	152732	04034C	PARTICIPANT	\N	PRESENT	0
152929	152732	08034U	PARTICIPANT	\N	PRESENT	0
152930	152732	95062K	PARTICIPANT	\N	PRESENT	0
152932	152732	14042U	PARTICIPANT	\N	PRESENT	0
152933	152732	14030Q	PARTICIPANT	\N	PRESENT	0
152934	152732	04088S	PARTICIPANT	\N	PRESENT	0
152935	152732	14119M	PARTICIPANT	\N	PRESENT	0
152936	152732	04071H	PARTICIPANT	\N	PRESENT	0
152938	152732	01048V	PARTICIPANT	\N	PRESENT	0
152939	152732	04086Q	PARTICIPANT	\N	PRESENT	0
152940	152732	80013X	PARTICIPANT	\N	PRESENT	0
152942	152732	01027Q	PARTICIPANT	\N	PRESENT	0
152944	152943	99004R	PRESIDENT	0	PRESENT	0
152945	152732	14041T	PARTICIPANT	\N	PRESENT	0
152946	152732	11109J	PARTICIPANT	\N	PRESENT	0
152947	152943	04038G	PARTICIPANT	\N	PRESENT	0
152948	152943	01008M	PARTICIPANT	\N	PRESENT	0
152951	152943	11066Q	PARTICIPANT	\N	PRESENT	0
152957	152943	08012N	PARTICIPANT	\N	PRESENT	0
152959	152943	14257W	PARTICIPANT	\N	PRESENT	0
152962	152943	11084S	PARTICIPANT	\N	PRESENT	0
152966	152732	89017R	PARTICIPANT	\N	PRESENT	0
152967	152732	01057W	PARTICIPANT	\N	PRESENT	0
152968	152732	98005N	PARTICIPANT	\N	PRESENT	0
152969	152943	14089Y	PARTICIPANT	\N	EXCUSE	0
152970	152732	97011G	PARTICIPANT	\N	PRESENT	0
152971	152943	08060W	PARTICIPANT	\N	EXCUSE	0
152972	152943	11029K	PARTICIPANT	\N	EXCUSE	0
152973	152943	11080N	PARTICIPANT	\N	EXCUSE	0
152974	152943	08028W	PARTICIPANT	\N	EXCUSE	0
152975	152943	01059Y	PARTICIPANT	\N	EXCUSE	0
152976	152943	11088W	PARTICIPANT	\N	EXCUSE	0
152977	152943	98018T	PARTICIPANT	\N	EXCUSE	0
152978	152943	01015L	PARTICIPANT	\N	EXCUSE	0
152979	152943	01041N	PARTICIPANT	\N	EXCUSE	0
152980	152943	14187A	PARTICIPANT	\N	EXCUSE	0
152981	152943	02002K	PARTICIPANT	\N	EXCUSE	0
152982	152943	08048B	PARTICIPANT	\N	EXCUSE	0
152983	152943	11089X	PARTICIPANT	\N	EXCUSE	0
152984	152943	04061F	PARTICIPANT	\N	EXCUSE	0
152985	152943	01061S	PARTICIPANT	\N	EXCUSE	0
152986	152943	08062Y	PARTICIPANT	\N	EXCUSE	0
152987	152943	11046L	PARTICIPANT	\N	EXCUSE	0
152989	152943	14107H	PARTICIPANT	\N	EXCUSE	0
152990	152943	01028R	PARTICIPANT	\N	EXCUSE	0
152991	152943	92045V	PARTICIPANT	\N	EXCUSE	0
152992	152943	11094U	PARTICIPANT	\N	EXCUSE	0
152993	152732	14219Q	PARTICIPANT	\N	PRESENT	0
152994	152732	14257W	PARTICIPANT	\N	PRESENT	0
152995	152732	14069U	PARTICIPANT	\N	PRESENT	0
152996	152732	08073C	PARTICIPANT	\N	PRESENT	0
152997	152732	11043H	PARTICIPANT	\N	PRESENT	0
152998	152732	14089Y	PARTICIPANT	\N	PRESENT	0
152999	152732	98053W	PARTICIPANT	\N	PRESENT	0
153000	152732	08055A	PARTICIPANT	\N	PRESENT	0
153012	152732	14157T	PARTICIPANT	\N	PRESENT	0
153013	152732	14205J	PARTICIPANT	\N	PRESENT	0
153014	152732	14071N	PARTICIPANT	\N	PRESENT	0
153015	152732	14038Y	PARTICIPANT	\N	PRESENT	0
153016	152732	14195A	PARTICIPANT	\N	PRESENT	0
153017	152732	08010L	PARTICIPANT	\N	PRESENT	0
153018	152732	14083S	PARTICIPANT	\N	PRESENT	0
153041	152732	11084S	PARTICIPANT	\N	PRESENT	0
153042	152732	14255U	PARTICIPANT	\N	PRESENT	0
153043	152732	14034U	PARTICIPANT	\N	PRESENT	0
153056	152732	01043Q	PARTICIPANT	\N	PRESENT	0
153059	152732	14327T	PARTICIPANT	\N	PRESENT	0
153062	152732	08016S	PARTICIPANT	\N	PRESENT	0
153083	152733	86034E	PARTICIPANT	\N	PRESENT	0
153085	152733	08052W	PARTICIPANT	\N	PRESENT	0
153086	152733	98022P	PARTICIPANT	\N	PRESENT	0
153087	152733	14063N	PARTICIPANT	\N	PRESENT	0
153088	152733	11103C	PARTICIPANT	\N	PRESENT	0
153089	152733	04092N	PARTICIPANT	\N	PRESENT	0
153090	152733	04097T	PARTICIPANT	\N	PRESENT	0
153091	152733	08062Y	PARTICIPANT	\N	PRESENT	0
153092	152733	14231L	PARTICIPANT	\N	PRESENT	0
153093	152733	04045F	PARTICIPANT	\N	PRESENT	0
153094	152733	14051J	PARTICIPANT	\N	PRESENT	0
153095	152733	95062K	PARTICIPANT	\N	PRESENT	0
153096	152733	11043H	PARTICIPANT	\N	PRESENT	0
153097	152733	11097X	PARTICIPANT	\N	PRESENT	0
153098	152733	11080N	PARTICIPANT	\N	PRESENT	0
153099	152733	77002U	PARTICIPANT	\N	PRESENT	0
153100	152733	08010L	PARTICIPANT	\N	PRESENT	0
153101	152733	14265W	PARTICIPANT	\N	PRESENT	0
153102	152733	08042U	PARTICIPANT	\N	PRESENT	0
153103	152733	99004R	PARTICIPANT	\N	PRESENT	0
153104	152733	11011M	PARTICIPANT	\N	PRESENT	0
153105	152733	14173T	PARTICIPANT	\N	PRESENT	0
153106	152733	08034U	PARTICIPANT	\N	PRESENT	0
153107	152733	14217N	PARTICIPANT	\N	PRESENT	0
153108	152733	97011G	PARTICIPANT	\N	PRESENT	0
153109	152733	01027Q	PARTICIPANT	\N	PRESENT	0
153110	152733	14195A	PARTICIPANT	\N	PRESENT	0
153111	152733	14157T	PARTICIPANT	\N	PRESENT	0
153112	152733	14251Q	PARTICIPANT	\N	PRESENT	0
153113	152733	95030B	PARTICIPANT	\N	PRESENT	0
153114	152733	11100Y	PARTICIPANT	\N	PRESENT	0
153115	152733	11048N	PARTICIPANT	\N	PRESENT	0
153116	152733	04049K	PARTICIPANT	\N	PRESENT	0
153117	152733	14061L	PARTICIPANT	\N	PRESENT	0
153118	152733	07029T	PARTICIPANT	\N	PRESENT	0
153119	152733	14169X	PARTICIPANT	\N	PRESENT	0
153120	152733	92040Q	PARTICIPANT	\N	PRESENT	0
153121	152733	05012A	PARTICIPANT	\N	PRESENT	0
153122	152733	04043D	PARTICIPANT	\N	PRESENT	0
153123	152733	98050T	PARTICIPANT	\N	PRESENT	0
153124	152733	95059Q	PARTICIPANT	\N	PRESENT	0
153125	152733	01013J	PARTICIPANT	\N	PRESENT	0
153126	152733	11031D	PARTICIPANT	\N	PRESENT	0
153127	152733	01015L	PARTICIPANT	\N	PRESENT	0
153128	152733	05001W	PARTICIPANT	\N	PRESENT	0
153129	152733	11090Q	PARTICIPANT	\N	PRESENT	0
153130	152733	04085P	PARTICIPANT	\N	PRESENT	0
153131	152733	01048V	PARTICIPANT	\N	PRESENT	0
153132	152733	92018S	PARTICIPANT	\N	PRESENT	0
153133	152733	07026Q	PARTICIPANT	\N	PRESENT	0
153134	152733	11040E	PARTICIPANT	\N	PRESENT	0
153135	152733	04042C	PARTICIPANT	\N	PRESENT	0
153136	152733	04050C	PARTICIPANT	\N	PRESENT	0
153137	152733	14013P	PARTICIPANT	\N	PRESENT	0
153138	152733	14105F	PARTICIPANT	\N	PRESENT	0
153139	152733	11039M	PARTICIPANT	\N	PRESENT	0
153140	152733	04056J	PARTICIPANT	\N	PRESENT	0
153141	152733	08019V	PARTICIPANT	\N	PRESENT	0
153142	152733	01016M	PARTICIPANT	\N	PRESENT	0
153143	152733	08016S	PARTICIPANT	\N	PRESENT	0
153144	152733	14111D	PARTICIPANT	\N	PRESENT	0
153145	152733	92015P	PARTICIPANT	\N	PRESENT	0
153146	152733	98046X	PARTICIPANT	\N	PRESENT	0
153147	152733	04057K	PARTICIPANT	\N	PRESENT	0
153148	152733	95063L	PARTICIPANT	\N	PRESENT	0
153149	152733	14331P	PARTICIPANT	\N	PRESENT	0
153150	152733	08055A	PARTICIPANT	\N	PRESENT	0
153151	152733	01031L	PARTICIPANT	\N	PRESENT	0
153152	152733	14259Y	PARTICIPANT	\N	PRESENT	0
153153	152733	04066L	PARTICIPANT	\N	PRESENT	0
153154	152733	11027H	PARTICIPANT	\N	PRESENT	0
153155	152733	01011G	PARTICIPANT	\N	PRESENT	0
130104	130103	14253S	PARTICIPANT	\N	PRESENT	0
135436	124149	11068S	PARTICIPANT	\N	EXCUSE	0
130312	120701	95062K	PARTICIPANT	\N	EXCUSE	0
130313	120701	08019V	PARTICIPANT	\N	EXCUSE	0
130314	120701	14053L	PARTICIPANT	\N	EXCUSE	0
131565	131564	11042G	PARTICIPANT	\N	PRESENT	0
131566	131564	14159V	PARTICIPANT	\N	PRESENT	0
131568	131567	14175V	PARTICIPANT	\N	PRESENT	0
131569	131567	14085U	PARTICIPANT	\N	PRESENT	0
135435	124149	11082Q	PARTICIPANT	\N	EXCUSE	0
135437	124149	04061F	PARTICIPANT	\N	EXCUSE	0
135438	124149	01048V	PARTICIPANT	\N	EXCUSE	0
135439	124149	14257W	PARTICIPANT	\N	EXCUSE	0
135440	124149	11036J	PARTICIPANT	\N	PRESENT	0
135441	124149	01046T	PARTICIPANT	\N	PRESENT	0
135442	124149	14263U	PARTICIPANT	\N	EXCUSE	0
138390	138389	11039M	PARTICIPANT	\N	PRESENT	0
138391	138389	98042T	PARTICIPANT	\N	PRESENT	0
138392	138389	01019Q	PARTICIPANT	\N	PRESENT	0
138404	138403	04085P	PARTICIPANT	\N	EXCUSE	0
138405	138403	05008E	PRESIDENT	0	PRESENT	0
138406	138403	14065Q	PARTICIPANT	\N	PRESENT	0
138407	138403	14069U	PARTICIPANT	\N	PRESENT	0
138408	138403	04038G	PARTICIPANT	\N	PRESENT	0
138409	138403	11056N	PARTICIPANT	\N	EXCUSE	0
138410	138403	11113E	PARTICIPANT	\N	PRESENT	0
138411	138403	01024M	PARTICIPANT	\N	PRESENT	0
138412	138403	14215L	PARTICIPANT	\N	PRESENT	0
138413	138403	08044W	PARTICIPANT	\N	EXCUSE	0
138414	138403	11026G	PARTICIPANT	\N	PRESENT	0
138415	138403	14111D	PARTICIPANT	\N	PRESENT	0
138416	138403	14147R	PARTICIPANT	\N	PRESENT	0
138417	138403	07034Q	PARTICIPANT	\N	PRESENT	0
138418	138403	95063L	PARTICIPANT	\N	PRESENT	0
138419	138403	01028R	PARTICIPANT	\N	PRESENT	0
138420	138403	11037K	PARTICIPANT	\N	PRESENT	0
138421	138403	92045V	PARTICIPANT	\N	EXCUSE	0
138422	138403	95067Q	PARTICIPANT	\N	PRESENT	0
138724	138723	08025T	PARTICIPANT	\N	PRESENT	0
138725	138723	04085P	PARTICIPANT	\N	EXCUSE	0
138726	138723	05008E	PRESIDENT	0	PRESENT	0
138727	138723	11030C	PARTICIPANT	\N	PRESENT	0
138728	138723	11033F	PARTICIPANT	\N	PRESENT	0
138729	138723	14065Q	PARTICIPANT	\N	PRESENT	0
138730	138723	14069U	PARTICIPANT	\N	PRESENT	0
138731	138723	04047H	PARTICIPANT	\N	PRESENT	0
138732	138723	11032E	PARTICIPANT	\N	PRESENT	0
138733	138723	04038G	PARTICIPANT	\N	PRESENT	0
138734	138723	99002P	PARTICIPANT	\N	PRESENT	0
138735	138723	11056N	PARTICIPANT	\N	PRESENT	0
138736	138723	14259Y	PARTICIPANT	\N	PRESENT	0
138737	138723	11035H	PARTICIPANT	\N	PRESENT	0
138738	138723	14041T	PARTICIPANT	\N	PRESENT	0
138739	138723	11113E	PARTICIPANT	\N	PRESENT	0
138740	138723	01024M	PARTICIPANT	\N	PRESENT	0
138741	138723	14215L	PARTICIPANT	\N	PRESENT	0
140677	140674	98021N	PARTICIPANT	\N	PRESENT	0
138743	138723	08018U	PARTICIPANT	\N	PRESENT	0
140678	140674	11106F	PARTICIPANT	\N	PRESENT	0
138745	138723	01007L	PARTICIPANT	\N	PRESENT	0
138746	138723	11049P	PARTICIPANT	\N	PRESENT	0
138747	138723	08044W	PARTICIPANT	\N	EXCUSE	0
138748	138723	11084S	PARTICIPANT	\N	PRESENT	0
138749	138723	11026G	PARTICIPANT	\N	PRESENT	0
138750	138723	04079R	PARTICIPANT	\N	PRESENT	0
138751	138723	14111D	PARTICIPANT	\N	PRESENT	0
138752	138723	14001X	PARTICIPANT	\N	PRESENT	0
140688	140687	07024N	PARTICIPANT	\N	PRESENT	0
138754	138723	01060R	PARTICIPANT	\N	PRESENT	0
138755	138723	14147R	PARTICIPANT	\N	PRESENT	0
138756	138723	95049N	PARTICIPANT	\N	PRESENT	0
138757	138723	08051V	PARTICIPANT	\N	PRESENT	0
140689	140687	01014K	PARTICIPANT	\N	PRESENT	0
138759	138723	07034Q	PARTICIPANT	\N	PRESENT	0
138760	138723	04074L	PARTICIPANT	\N	PRESENT	0
138761	138723	10015M	PARTICIPANT	\N	PRESENT	0
138762	138723	95063L	PARTICIPANT	\N	PRESENT	0
138763	138723	01019Q	PARTICIPANT	\N	PRESENT	0
138764	138723	01028R	PARTICIPANT	\N	PRESENT	0
138765	138723	98035U	PARTICIPANT	\N	PRESENT	0
138766	138723	04056J	PARTICIPANT	\N	PRESENT	0
140690	140687	98021N	PARTICIPANT	\N	PRESENT	0
138768	138723	04044E	PARTICIPANT	\N	PRESENT	0
138769	138723	11037K	PARTICIPANT	\N	PRESENT	0
138770	138723	92045V	PARTICIPANT	\N	PRESENT	0
138771	138723	95067Q	PARTICIPANT	\N	PRESENT	0
140691	140687	11106F	PARTICIPANT	\N	PRESENT	0
140692	140687	01056V	PARTICIPANT	\N	PRESENT	0
140694	140693	07024N	PARTICIPANT	\N	PRESENT	0
140695	140693	01014K	PARTICIPANT	\N	PRESENT	0
140696	140693	98021N	PARTICIPANT	\N	PRESENT	0
140701	140698	01014K	PARTICIPANT	\N	PRESENT	0
140705	140703	04080J	PARTICIPANT	\N	PRESENT	0
140954	140953	01044R	PARTICIPANT	\N	PRESENT	0
140955	140953	08043V	PARTICIPANT	\N	PRESENT	0
140957	140953	11029K	PARTICIPANT	\N	PRESENT	0
140958	140953	04070G	PARTICIPANT	\N	PRESENT	0
140959	140953	14105F	PARTICIPANT	\N	PRESENT	0
140960	140953	08024S	PARTICIPANT	\N	PRESENT	0
140961	140953	87003B	PARTICIPANT	\N	PRESENT	0
140962	140953	14179A	PARTICIPANT	\N	PRESENT	0
140963	140953	08031R	PARTICIPANT	\N	PRESENT	0
140964	140953	14059S	PARTICIPANT	\N	PRESENT	0
140965	140953	08039A	PARTICIPANT	\N	PRESENT	0
140966	140953	14063N	PARTICIPANT	\N	PRESENT	0
140967	140953	14109K	PARTICIPANT	\N	PRESENT	0
140968	140953	14229S	PARTICIPANT	\N	PRESENT	0
140970	140969	08017T	PARTICIPANT	\N	PRESENT	0
140971	140969	01041N	PARTICIPANT	\N	PRESENT	0
140973	140972	08017T	PARTICIPANT	\N	PRESENT	0
140974	140972	01041N	PARTICIPANT	\N	PRESENT	0
140976	140975	08017T	PARTICIPANT	\N	PRESENT	0
140977	140975	01041N	PARTICIPANT	\N	PRESENT	0
141054	141034	01027Q	PARTICIPANT	\N	PRESENT	0
141173	141172	05008E	PARTICIPANT	\N	PRESENT	0
141174	141172	14065Q	PARTICIPANT	\N	PRESENT	0
141175	141172	08051V	PARTICIPANT	\N	PRESENT	0
143312	143052	08061X	PARTICIPANT	\N	EXCUSE	0
148374	148332	95067Q	PARTICIPANT	\N	PRESENT	0
148375	148332	01047U	PARTICIPANT	\N	PRESENT	0
148621	148620	04066L	PARTICIPANT	\N	PRESENT	0
148622	148620	11064N	PARTICIPANT	\N	PRESENT	0
148623	148620	11106F	PARTICIPANT	\N	PRESENT	0
148624	148620	08053X	PARTICIPANT	\N	PRESENT	0
148625	148620	11105E	PARTICIPANT	\N	PRESENT	0
148933	148932	14209N	PARTICIPANT	\N	PRESENT	0
148934	148932	14151M	PARTICIPANT	\N	PRESENT	0
148935	148932	04097T	PARTICIPANT	\N	PRESENT	0
148936	148932	01011G	PARTICIPANT	\N	PRESENT	0
148937	148932	08053X	PARTICIPANT	\N	PRESENT	0
148938	148932	95063L	PARTICIPANT	\N	PRESENT	0
148939	148932	14097Y	PARTICIPANT	\N	PRESENT	0
148940	148932	14225N	PARTICIPANT	\N	PRESENT	0
148941	148932	01037S	PARTICIPANT	\N	PRESENT	0
149357	149356	14217N	PARTICIPANT	\N	PRESENT	0
149359	149358	14217N	PARTICIPANT	\N	PRESENT	0
149362	149360	14217N	PARTICIPANT	\N	PRESENT	0
149363	149361	14089Y	PARTICIPANT	\N	PRESENT	0
149365	149364	14217N	PARTICIPANT	\N	PRESENT	0
149367	149366	14089Y	PARTICIPANT	\N	PRESENT	0
149369	149368	14217N	PARTICIPANT	\N	PRESENT	0
149371	149370	14217N	PARTICIPANT	\N	PRESENT	0
149373	149372	01041N	PARTICIPANT	\N	PRESENT	0
149374	149372	08017T	PARTICIPANT	\N	PRESENT	0
150483	125636	14263U	PARTICIPANT	\N	EXCUSE	0
150749	150748	96004D	PARTICIPANT	\N	PRESENT	0
150750	150748	95037J	PARTICIPANT	\N	PRESENT	0
150751	150748	14135M	PARTICIPANT	\N	PRESENT	0
151040	151039	14259Y	PARTICIPANT	\N	PRESENT	0
151393	151392	89017R	PARTICIPANT	\N	PRESENT	0
151394	151392	01031L	PRESIDENT	0	PRESENT	0
151395	151392	05004A	PARTICIPANT	\N	PRESENT	0
151396	151392	01013J	PARTICIPANT	\N	PRESENT	0
151397	151392	11068S	PARTICIPANT	\N	PRESENT	0
151398	151392	11040E	PARTICIPANT	\N	PRESENT	0
151399	151392	08014Q	PARTICIPANT	\N	PRESENT	0
151401	151392	14175V	PARTICIPANT	\N	PRESENT	0
151402	151392	14083S	PARTICIPANT	\N	PRESENT	0
151405	151392	11042G	PARTICIPANT	\N	PRESENT	0
151406	151392	88008L	PARTICIPANT	\N	PRESENT	0
140675	140674	07024N	PARTICIPANT	\N	PRESENT	0
140676	140674	01014K	PARTICIPANT	\N	PRESENT	0
151407	151392	04086Q	PARTICIPANT	\N	PRESENT	0
151408	151392	04055H	PARTICIPANT	\N	PRESENT	0
145201	144514	04053F	PARTICIPANT	\N	PRESENT	0
145202	144514	11046L	PARTICIPANT	\N	PRESENT	0
145203	144514	14109K	PARTICIPANT	\N	PRESENT	0
145204	144514	08017T	PARTICIPANT	\N	PRESENT	0
145205	144514	04086Q	PARTICIPANT	\N	PRESENT	0
145206	144514	14147R	PARTICIPANT	\N	PRESENT	0
145207	144514	11037K	PARTICIPANT	\N	PRESENT	0
145208	144514	01014K	PARTICIPANT	\N	PRESENT	0
145209	144514	08038Y	PARTICIPANT	\N	PRESENT	0
145210	144514	11066Q	PARTICIPANT	\N	PRESENT	0
145211	144514	04059M	PARTICIPANT	\N	PRESENT	0
145212	144514	14081Q	PARTICIPANT	\N	PRESENT	0
145213	144514	11074Q	PARTICIPANT	\N	PRESENT	0
145214	144514	11112D	PARTICIPANT	\N	PRESENT	0
145215	144514	14227Q	PARTICIPANT	\N	PRESENT	0
145216	144514	14121F	PARTICIPANT	\N	PRESENT	0
145217	144514	11061K	PARTICIPANT	\N	PRESENT	0
145218	144514	04034C	PARTICIPANT	\N	PRESENT	0
145219	144514	11103C	PARTICIPANT	\N	PRESENT	0
145220	144514	14083S	PARTICIPANT	\N	PRESENT	0
145221	144514	01025N	PARTICIPANT	\N	PRESENT	0
145222	144514	08051V	PARTICIPANT	\N	PRESENT	0
145223	144514	11111C	PARTICIPANT	\N	PRESENT	0
145224	144514	07029T	PARTICIPANT	\N	PRESENT	0
145225	144514	14037X	PARTICIPANT	\N	PRESENT	0
145226	144514	11090Q	PARTICIPANT	\N	PRESENT	0
145227	144514	04081K	PARTICIPANT	\N	PRESENT	0
145228	144514	01057W	PARTICIPANT	\N	PRESENT	0
145229	144514	95063L	PARTICIPANT	\N	PRESENT	0
145230	144514	08052W	PARTICIPANT	\N	PRESENT	0
145231	144514	11057P	PARTICIPANT	\N	PRESENT	0
145232	144514	14107H	PARTICIPANT	\N	PRESENT	0
145233	144514	04085P	PARTICIPANT	\N	PRESENT	0
145234	144514	01013J	PARTICIPANT	\N	PRESENT	0
145235	144514	07026Q	PARTICIPANT	\N	PRESENT	0
145236	144514	01015L	PARTICIPANT	\N	PRESENT	0
145237	144514	11034G	PARTICIPANT	\N	PRESENT	0
145238	144514	04067M	PARTICIPANT	\N	PRESENT	0
145239	144514	11065P	PARTICIPANT	\N	PRESENT	0
145240	144514	11083R	PARTICIPANT	\N	PRESENT	0
145241	144514	11033F	PARTICIPANT	\N	PRESENT	0
145242	144514	04088S	PARTICIPANT	\N	PRESENT	0
145243	144514	11068S	PARTICIPANT	\N	PRESENT	0
145244	144514	08034U	PARTICIPANT	\N	PRESENT	0
145245	144514	14169X	PARTICIPANT	\N	PRESENT	0
145246	144514	01031L	PARTICIPANT	\N	PRESENT	0
145247	144514	14065Q	PARTICIPANT	\N	PRESENT	0
145248	144514	08068F	PARTICIPANT	\N	PRESENT	0
145249	144514	80013X	PARTICIPANT	\N	PRESENT	0
145250	144514	01037S	PARTICIPANT	\N	PRESENT	0
145251	144514	11089X	PARTICIPANT	\N	PRESENT	0
145252	144514	14097Y	PARTICIPANT	\N	PRESENT	0
145253	144514	08012N	PARTICIPANT	\N	PRESENT	0
145254	144514	80027E	PARTICIPANT	\N	PRESENT	0
145255	144514	14001X	PARTICIPANT	\N	PRESENT	0
145256	144514	08053X	PARTICIPANT	\N	PRESENT	0
145257	144514	14229S	PARTICIPANT	\N	PRESENT	0
145258	144514	01027Q	PARTICIPANT	\N	PRESENT	0
145259	144514	99004R	PARTICIPANT	\N	PRESENT	0
145260	144514	95031C	PARTICIPANT	\N	PRESENT	0
145261	144514	11088W	PARTICIPANT	\N	PRESENT	0
145262	144514	11048N	PARTICIPANT	\N	PRESENT	0
145263	144514	14175V	PARTICIPANT	\N	PRESENT	0
145264	144514	11049P	PARTICIPANT	\N	PRESENT	0
145265	144514	08015R	PARTICIPANT	\N	PRESENT	0
145266	144514	08062Y	PARTICIPANT	\N	PRESENT	0
145267	144514	86044G	PARTICIPANT	\N	PRESENT	0
145268	144514	14087W	PARTICIPANT	\N	PRESENT	0
145269	144514	04047H	PARTICIPANT	\N	PRESENT	0
145270	144514	14133K	PARTICIPANT	\N	PRESENT	0
145271	144514	04078Q	PARTICIPANT	\N	PRESENT	0
145272	144514	88008L	PARTICIPANT	\N	PRESENT	0
145273	144514	08049C	PARTICIPANT	\N	PRESENT	0
145274	144514	14267Y	PARTICIPANT	\N	PRESENT	0
145275	144514	14069U	PARTICIPANT	\N	PRESENT	0
145276	144514	08011M	PARTICIPANT	\N	PRESENT	0
145277	144514	11071M	PARTICIPANT	\N	PRESENT	0
145278	144514	11012A	PARTICIPANT	\N	PRESENT	0
145279	144514	98053W	PARTICIPANT	\N	PRESENT	0
145280	144514	14031R	PARTICIPANT	\N	PRESENT	0
145281	144514	11063M	PARTICIPANT	\N	PRESENT	0
145282	144514	08039A	PARTICIPANT	\N	PRESENT	0
145283	144514	14219Q	PARTICIPANT	\N	PRESENT	0
145284	144514	11053K	PARTICIPANT	\N	PRESENT	0
145292	144514	11097X	PARTICIPANT	\N	PRESENT	0
145293	144514	11081P	PARTICIPANT	\N	PRESENT	0
145294	144514	14187A	PARTICIPANT	\N	PRESENT	0
145295	144514	13002U	PARTICIPANT	\N	PRESENT	0
145296	144514	11056N	PARTICIPANT	\N	PRESENT	0
145297	144514	98050T	PARTICIPANT	\N	PRESENT	0
145298	144514	14073Q	PARTICIPANT	\N	PRESENT	0
145299	144514	04057K	PARTICIPANT	\N	PRESENT	0
145300	144514	01043Q	PARTICIPANT	\N	PRESENT	0
145301	144514	01008M	PARTICIPANT	\N	PRESENT	0
145302	144514	14249W	PARTICIPANT	\N	PRESENT	0
145303	144514	01024M	PARTICIPANT	\N	PRESENT	0
145304	144514	14061L	PARTICIPANT	\N	PRESENT	0
145305	144514	08010L	PARTICIPANT	\N	PRESENT	0
145306	144514	14251Q	PARTICIPANT	\N	PRESENT	0
145312	144514	14105F	PARTICIPANT	\N	PRESENT	0
145313	144514	14327T	PARTICIPANT	\N	PRESENT	0
145314	144514	04040A	PARTICIPANT	\N	PRESENT	0
145315	144514	14030Q	PARTICIPANT	\N	PRESENT	0
145316	144514	92045V	PARTICIPANT	\N	PRESENT	0
145317	144514	14013P	PARTICIPANT	\N	PRESENT	0
145318	144514	14071N	PARTICIPANT	\N	PRESENT	0
145319	144514	11099A	PARTICIPANT	\N	PRESENT	0
145320	144514	87003B	PARTICIPANT	\N	PRESENT	0
145321	144514	14223L	PARTICIPANT	\N	PRESENT	0
145323	144514	08069G	PARTICIPANT	\N	PRESENT	0
145338	144514	04043D	PARTICIPANT	\N	PRESENT	0
145340	144514	14239U	PARTICIPANT	\N	PRESENT	0
145353	145352	14259Y	PARTICIPANT	\N	PRESENT	0
145372	144514	04055H	PARTICIPANT	\N	PRESENT	0
145373	144514	14026U	PARTICIPANT	\N	PRESENT	0
145374	144514	04061F	PARTICIPANT	\N	PRESENT	0
145375	144514	14199E	PARTICIPANT	\N	PRESENT	0
145376	144514	11094U	PARTICIPANT	\N	PRESENT	0
145377	144514	01034P	PARTICIPANT	\N	PRESENT	0
145378	144514	04097T	PARTICIPANT	\N	PRESENT	0
145379	144514	95062K	PARTICIPANT	\N	PRESENT	0
145380	144514	98018T	PARTICIPANT	\N	PRESENT	0
145381	144514	11093T	PARTICIPANT	\N	PRESENT	0
145382	144514	14231L	PARTICIPANT	\N	PRESENT	0
145383	144514	14213J	PARTICIPANT	\N	PRESENT	0
145384	144514	08041T	PARTICIPANT	\N	PRESENT	0
145385	144514	01048V	PARTICIPANT	\N	PRESENT	0
145386	144514	95035G	PARTICIPANT	\N	PRESENT	0
145387	144514	08048B	PARTICIPANT	\N	PRESENT	0
145388	144514	04089T	PARTICIPANT	\N	PRESENT	0
145389	144514	14173T	PARTICIPANT	\N	PRESENT	0
145390	144514	14217N	PARTICIPANT	\N	PRESENT	0
145391	144514	95030B	PARTICIPANT	\N	PRESENT	0
145392	144514	11098Y	PARTICIPANT	\N	PRESENT	0
145393	144514	01041N	PARTICIPANT	\N	PRESENT	0
145412	144514	14211G	PARTICIPANT	\N	PRESENT	0
145413	144514	04080J	PARTICIPANT	\N	PRESENT	0
145432	144514	14195A	PARTICIPANT	\N	PRESENT	0
145456	144514	14221J	PARTICIPANT	\N	PRESENT	0
145457	144514	14042U	PARTICIPANT	\N	PRESENT	0
145472	144514	14157T	PARTICIPANT	\N	PRESENT	0
145493	125635	14257W	PARTICIPANT	\N	PRESENT	0
146173	146172	04054G	PARTICIPANT	\N	PRESENT	0
146174	146172	04047H	PARTICIPANT	\N	PRESENT	0
146175	146172	14267Y	PARTICIPANT	\N	PRESENT	0
146176	146172	14079W	PARTICIPANT	\N	EXCUSE	0
146177	146172	11083R	PARTICIPANT	\N	PRESENT	0
146178	146172	14026U	PARTICIPANT	\N	PRESENT	0
146179	146172	14073Q	PARTICIPANT	\N	PRESENT	0
146180	146172	11026G	PARTICIPANT	\N	PRESENT	0
146181	146172	92031P	PARTICIPANT	\N	PRESENT	0
146182	146172	14001X	PARTICIPANT	\N	PRESENT	0
146183	146172	11012A	PARTICIPANT	\N	PRESENT	0
146184	146172	14227Q	PARTICIPANT	\N	PRESENT	0
146185	146172	95067Q	PARTICIPANT	\N	PRESENT	0
146503	146502	89017R	PARTICIPANT	\N	PRESENT	0
146504	146502	01031L	PRESIDENT	0	PRESENT	0
146505	146502	11040E	PARTICIPANT	\N	PRESENT	0
146506	146502	14175V	PARTICIPANT	\N	PRESENT	0
146507	146502	14083S	PARTICIPANT	\N	PRESENT	0
146508	146502	14085U	PARTICIPANT	\N	PRESENT	0
146509	146502	11042G	PARTICIPANT	\N	PRESENT	0
146510	146502	14327T	PARTICIPANT	\N	EXCUSE	0
146511	146502	01027Q	PARTICIPANT	\N	PRESENT	0
146512	146502	11074Q	PARTICIPANT	\N	PRESENT	0
146513	146502	11083R	PARTICIPANT	\N	PRESENT	0
129557	129556	11029K	PARTICIPANT	\N	PRESENT	0
129558	129556	08043V	PARTICIPANT	\N	PRESENT	0
131518	131517	04059M	PARTICIPANT	\N	PRESENT	0
131524	131523	05008E	PARTICIPANT	\N	PRESENT	0
131525	131523	14065Q	PARTICIPANT	\N	PRESENT	0
131526	131523	01047U	PARTICIPANT	\N	PRESENT	0
137746	137745	14327T	PARTICIPANT	\N	PRESENT	0
137756	137755	01057W	PARTICIPANT	\N	PRESENT	0
137757	137755	14225N	PARTICIPANT	\N	PRESENT	0
137759	137758	01057W	PARTICIPANT	\N	PRESENT	0
137760	137758	14225N	PARTICIPANT	\N	PRESENT	0
137762	137761	01057W	PARTICIPANT	\N	PRESENT	0
137763	137761	14225N	PARTICIPANT	\N	PRESENT	0
137804	137802	11114F	PARTICIPANT	\N	PRESENT	0
137806	137802	14259Y	PARTICIPANT	\N	PRESENT	0
137808	137802	11011M	PARTICIPANT	\N	PRESENT	0
137809	137802	08019V	PARTICIPANT	\N	PRESENT	0
137810	137802	14059S	PARTICIPANT	\N	PRESENT	0
137811	135871	14034U	PARTICIPANT	\N	EXCUSE	0
140052	137569	14014Q	PARTICIPANT	\N	EXCUSE	0
140053	137569	04045F	PARTICIPANT	\N	EXCUSE	0
140208	140206	07004J	PARTICIPANT	\N	PRESENT	0
140212	140211	14253S	PARTICIPANT	\N	PRESENT	0
144355	144353	98023Q	PARTICIPANT	\N	PRESENT	0
140215	140214	14253S	PARTICIPANT	\N	PRESENT	0
140216	140214	14157T	PARTICIPANT	\N	PRESENT	0
140218	140217	04049K	PARTICIPANT	\N	PRESENT	0
145850	145522	98022P	PARTICIPANT	\N	PRESENT	0
144459	141094	14018U	PARTICIPANT	\N	PRESENT	0
144356	144353	90003B	PARTICIPANT	\N	PRESENT	0
144460	141097	14018U	PARTICIPANT	\N	PRESENT	0
144461	141096	01059Y	PARTICIPANT	\N	PRESENT	0
144462	141096	01003G	PARTICIPANT	\N	PRESENT	0
144496	144495	01019Q	PARTICIPANT	\N	PRESENT	0
144497	144495	92039X	PARTICIPANT	\N	PRESENT	0
144498	144495	98042T	PARTICIPANT	\N	PRESENT	0
144499	144495	11084S	PARTICIPANT	\N	PRESENT	0
144518	144517	04040A	PARTICIPANT	\N	PRESENT	0
144519	144517	14255U	PARTICIPANT	\N	PRESENT	0
144520	144517	01041N	PARTICIPANT	\N	PRESENT	0
145848	145522	86034E	PARTICIPANT	\N	PRESENT	0
145849	145522	07026Q	PARTICIPANT	\N	PRESENT	0
145851	145522	14267Y	PARTICIPANT	\N	PRESENT	0
145852	145522	14219Q	PARTICIPANT	\N	PRESENT	0
145853	145522	14089Y	PARTICIPANT	\N	PRESENT	0
145854	145522	14237S	PARTICIPANT	\N	PRESENT	0
145855	145522	11040E	PARTICIPANT	\N	PRESENT	0
145856	145522	01013J	PARTICIPANT	\N	PRESENT	0
145857	145522	14030Q	PARTICIPANT	\N	PRESENT	0
145858	145522	14217N	PARTICIPANT	\N	PRESENT	0
145859	145522	14059S	PARTICIPANT	\N	PRESENT	0
145860	145522	07034Q	PARTICIPANT	\N	PRESENT	0
145861	145522	14331P	PARTICIPANT	\N	PRESENT	0
145862	145522	14175V	PARTICIPANT	\N	PRESENT	0
145863	145522	08062Y	PARTICIPANT	\N	PRESENT	0
145864	145522	11043H	PARTICIPANT	\N	PRESENT	0
145865	145522	14223L	PARTICIPANT	\N	PRESENT	0
145866	145522	87003B	PARTICIPANT	\N	PRESENT	0
145867	145522	11088W	PARTICIPANT	\N	PRESENT	0
145868	145522	14033T	PARTICIPANT	\N	PRESENT	0
145869	145522	04088S	PARTICIPANT	\N	PRESENT	0
145870	145522	14191V	PARTICIPANT	\N	PRESENT	0
145871	145522	11080N	PARTICIPANT	\N	PRESENT	0
145872	145522	11020A	PARTICIPANT	\N	PRESENT	0
145873	145522	14173T	PARTICIPANT	\N	PRESENT	0
145874	145522	14105F	PARTICIPANT	\N	PRESENT	0
145875	145522	08056B	PARTICIPANT	\N	PRESENT	0
145876	145522	04089T	PARTICIPANT	\N	PRESENT	0
145877	145522	14221J	PARTICIPANT	\N	PRESENT	0
145878	145522	14201E	PARTICIPANT	\N	PRESENT	0
145879	145522	04097T	PARTICIPANT	\N	PRESENT	0
145880	145522	14031R	PARTICIPANT	\N	PRESENT	0
145881	145522	11101A	PARTICIPANT	\N	PRESENT	0
145882	145522	11049P	PARTICIPANT	\N	PRESENT	0
145883	145522	11053K	PARTICIPANT	\N	PRESENT	0
145884	145522	04041B	PARTICIPANT	\N	PRESENT	0
145885	145522	07029T	PARTICIPANT	\N	PRESENT	0
145886	145522	08051V	PARTICIPANT	\N	PRESENT	0
145887	145522	14079W	PARTICIPANT	\N	PRESENT	0
145888	145522	04049K	PARTICIPANT	\N	PRESENT	0
145889	145522	04074L	PARTICIPANT	\N	PRESENT	0
145890	145522	04036E	PARTICIPANT	\N	PRESENT	0
145891	145522	95035G	PARTICIPANT	\N	PRESENT	0
145892	145522	07024N	PARTICIPANT	\N	PRESENT	0
145893	145522	04081K	PARTICIPANT	\N	PRESENT	0
145894	145522	04057K	PARTICIPANT	\N	PRESENT	0
145895	145522	04042C	PARTICIPANT	\N	PRESENT	0
145896	145522	96004D	PARTICIPANT	\N	PRESENT	0
145897	145522	08041T	PARTICIPANT	\N	PRESENT	0
145898	145522	11100Y	PARTICIPANT	\N	PRESENT	0
145899	145522	14195A	PARTICIPANT	\N	PRESENT	0
145900	145522	11030C	PARTICIPANT	\N	PRESENT	0
145901	145522	95030B	PARTICIPANT	\N	PRESENT	0
145902	145522	04078Q	PARTICIPANT	\N	PRESENT	0
145903	145522	11081P	PARTICIPANT	\N	PRESENT	0
145911	145522	04086Q	PARTICIPANT	\N	PRESENT	0
145905	145522	14187A	PARTICIPANT	\N	PRESENT	0
145906	145522	10006L	PARTICIPANT	\N	PRESENT	0
145907	145522	89029V	PARTICIPANT	\N	PRESENT	0
145909	145522	98023Q	PARTICIPANT	\N	PRESENT	0
145910	145522	14061L	PARTICIPANT	\N	PRESENT	0
145912	145522	14255U	PARTICIPANT	\N	PRESENT	0
145913	145522	14073Q	PARTICIPANT	\N	PRESENT	0
145914	145522	92031P	PARTICIPANT	\N	PRESENT	0
145915	145522	13002U	PARTICIPANT	\N	PRESENT	0
145916	145522	11033F	PARTICIPANT	\N	PRESENT	0
145917	145522	11093T	PARTICIPANT	\N	PRESENT	0
145919	145522	14239U	PARTICIPANT	\N	PRESENT	0
145920	145522	98018T	PARTICIPANT	\N	PRESENT	0
145921	145522	08049C	PARTICIPANT	\N	PRESENT	0
145922	145522	04092N	PARTICIPANT	\N	PRESENT	0
145923	145522	01027Q	PARTICIPANT	\N	PRESENT	0
145924	145522	04033B	PARTICIPANT	\N	PRESENT	0
153156	152733	14053L	PARTICIPANT	\N	PRESENT	0
153157	152733	11057P	PARTICIPANT	\N	PRESENT	0
153158	152733	11066Q	PARTICIPANT	\N	PRESENT	0
153159	152733	80013X	PARTICIPANT	\N	PRESENT	0
153160	152733	01008M	PARTICIPANT	\N	PRESENT	0
153161	152733	14028W	PARTICIPANT	\N	PRESENT	0
153162	152733	04035D	PARTICIPANT	\N	PRESENT	0
153163	152733	11110B	PARTICIPANT	\N	PRESENT	0
153164	152733	11067R	PARTICIPANT	\N	PRESENT	0
153165	152733	11015D	PARTICIPANT	\N	PRESENT	0
153166	152733	14037X	PARTICIPANT	\N	PRESENT	0
153167	152733	08012N	PARTICIPANT	\N	PRESENT	0
153168	152733	04086Q	PARTICIPANT	\N	PRESENT	0
153169	152733	11059R	PARTICIPANT	\N	PRESENT	0
153170	152733	14123H	PARTICIPANT	\N	PRESENT	0
153171	152733	11046L	PARTICIPANT	\N	PRESENT	0
153172	152733	92045V	PARTICIPANT	\N	PRESENT	0
153173	152733	08017T	PARTICIPANT	\N	PRESENT	0
153174	152733	04034C	PARTICIPANT	\N	PRESENT	0
153175	152733	95037J	PARTICIPANT	\N	PRESENT	0
153176	152733	11036J	PARTICIPANT	\N	PRESENT	0
153177	152733	92031P	PARTICIPANT	\N	PRESENT	0
153178	152733	14229S	PARTICIPANT	\N	PRESENT	0
153179	152733	08014Q	PARTICIPANT	\N	PRESENT	0
153180	152733	14207L	PARTICIPANT	\N	PRESENT	0
153181	152733	11014C	PARTICIPANT	\N	PRESENT	0
153182	152733	14257W	PARTICIPANT	\N	PRESENT	0
153183	152733	14059S	PARTICIPANT	\N	PRESENT	0
153184	152733	14097Y	PARTICIPANT	\N	PRESENT	0
153185	152733	14121F	PARTICIPANT	\N	PRESENT	0
153186	152733	11049P	PARTICIPANT	\N	PRESENT	0
153187	152733	01057W	PARTICIPANT	\N	PRESENT	0
153188	152733	14281W	PARTICIPANT	\N	PRESENT	0
153189	152733	11030C	PARTICIPANT	\N	PRESENT	0
153190	152733	14227Q	PARTICIPANT	\N	PRESENT	0
153191	152733	01056V	PARTICIPANT	\N	PRESENT	0
153192	152733	11054L	PARTICIPANT	\N	PRESENT	0
153193	152733	04036E	PARTICIPANT	\N	PRESENT	0
153194	152733	11061K	PARTICIPANT	\N	PRESENT	0
153195	152733	11089X	PARTICIPANT	\N	PRESENT	0
153196	152733	11044J	PARTICIPANT	\N	PRESENT	0
153197	152733	98005N	PARTICIPANT	\N	PRESENT	0
153198	152733	83047W	PARTICIPANT	\N	PRESENT	0
153199	152733	04095R	PARTICIPANT	\N	PRESENT	0
153200	152733	08073C	PARTICIPANT	\N	PRESENT	0
153201	152733	11113E	PARTICIPANT	\N	PRESENT	0
153202	152733	11109J	PARTICIPANT	\N	PRESENT	0
153212	152733	14249W	PARTICIPANT	\N	PRESENT	0
153204	152733	14271U	PARTICIPANT	\N	PRESENT	0
153323	152733	88008L	PARTICIPANT	\N	PRESENT	0
153206	152733	14039A	PARTICIPANT	\N	PRESENT	0
153207	152733	96004D	PARTICIPANT	\N	PRESENT	0
153208	152733	11025F	PARTICIPANT	\N	PRESENT	0
153209	152733	14269B	PARTICIPANT	\N	PRESENT	0
153210	152733	14041T	PARTICIPANT	\N	PRESENT	0
153211	152733	11077T	PARTICIPANT	\N	PRESENT	0
153213	152733	14107H	PARTICIPANT	\N	PRESENT	0
153214	152733	11084S	PARTICIPANT	\N	PRESENT	0
153215	152733	14085U	PARTICIPANT	\N	PRESENT	0
153216	152733	92039X	PARTICIPANT	\N	PRESENT	0
153217	152733	14187A	PARTICIPANT	\N	PRESENT	0
153218	152733	11035H	PARTICIPANT	\N	PRESENT	0
153219	152733	08024S	PARTICIPANT	\N	PRESENT	0
153220	152733	11104D	PARTICIPANT	\N	PRESENT	0
153221	152733	14193X	PARTICIPANT	\N	PRESENT	0
153222	152733	01059Y	PARTICIPANT	\N	PRESENT	0
153223	152733	11071M	PARTICIPANT	\N	PRESENT	0
153224	152733	04059M	PARTICIPANT	\N	PRESENT	0
153225	152733	04053F	PARTICIPANT	\N	PRESENT	0
153226	152733	08051V	PARTICIPANT	\N	PRESENT	0
153227	152733	14135M	PARTICIPANT	\N	PRESENT	0
153228	152733	01046T	PARTICIPANT	\N	PRESENT	0
153229	152733	04078Q	PARTICIPANT	\N	PRESENT	0
153230	152733	01003G	PARTICIPANT	\N	PRESENT	0
153231	152733	08031R	PARTICIPANT	\N	PRESENT	0
153232	152733	14329V	PARTICIPANT	\N	PRESENT	0
153233	152733	11012A	PARTICIPANT	\N	PRESENT	0
153234	152733	08049C	PARTICIPANT	\N	PRESENT	0
153235	152733	12042Y	PARTICIPANT	\N	PRESENT	0
153236	152733	11037K	PARTICIPANT	\N	PRESENT	0
153237	152733	04038G	PARTICIPANT	\N	PRESENT	0
153238	152733	11096W	PARTICIPANT	\N	PRESENT	0
153239	152733	14201E	PARTICIPANT	\N	PRESENT	0
153240	152733	95041E	PARTICIPANT	\N	PRESENT	0
153241	152733	11055M	PARTICIPANT	\N	PRESENT	0
153242	152733	01041N	PARTICIPANT	\N	PRESENT	0
153243	152733	11033F	PARTICIPANT	\N	PRESENT	0
153244	152733	11083R	PARTICIPANT	\N	PRESENT	0
153245	152733	04067M	PARTICIPANT	\N	PRESENT	0
153246	152733	04088S	PARTICIPANT	\N	PRESENT	0
153247	152733	11088W	PARTICIPANT	\N	PRESENT	0
153248	152733	07004J	PARTICIPANT	\N	PRESENT	0
153249	152733	11085T	PARTICIPANT	\N	PRESENT	0
153250	152733	04094Q	PARTICIPANT	\N	PRESENT	0
153251	152733	11068S	PARTICIPANT	\N	PRESENT	0
153252	152733	01025N	PARTICIPANT	\N	PRESENT	0
153253	152733	14205J	PARTICIPANT	\N	PRESENT	0
153254	152733	14253S	PARTICIPANT	\N	PRESENT	0
153255	152733	11042G	PARTICIPANT	\N	PRESENT	0
153256	152733	11029K	PARTICIPANT	\N	PRESENT	0
153257	152733	14119M	PARTICIPANT	\N	PRESENT	0
153258	152733	14219Q	PARTICIPANT	\N	PRESENT	0
153259	152733	14103D	PARTICIPANT	\N	PRESENT	0
153260	152733	14267Y	PARTICIPANT	\N	PRESENT	0
153261	152733	14042U	PARTICIPANT	\N	PRESENT	0
153262	152733	14030Q	PARTICIPANT	\N	PRESENT	0
153263	152733	14199E	PARTICIPANT	\N	PRESENT	0
153264	152733	14221J	PARTICIPANT	\N	PRESENT	0
153265	152733	04071H	PARTICIPANT	\N	PRESENT	0
153266	152733	13002U	PARTICIPANT	\N	PRESENT	0
153267	152733	95049N	PARTICIPANT	\N	PRESENT	0
153268	152733	11070L	PARTICIPANT	\N	PRESENT	0
153269	152733	14038Y	PARTICIPANT	\N	PRESENT	0
153296	152733	05008E	PARTICIPANT	\N	PRESENT	0
153271	152733	14083S	PARTICIPANT	\N	PRESENT	0
153272	152733	14073Q	PARTICIPANT	\N	PRESENT	0
153293	152733	11032E	PARTICIPANT	\N	PRESENT	0
153274	152733	11093T	PARTICIPANT	\N	PRESENT	0
153275	152733	11064N	PARTICIPANT	\N	PRESENT	0
153276	152733	14255U	PARTICIPANT	\N	PRESENT	0
153277	152733	98042T	PARTICIPANT	\N	PRESENT	0
153278	152733	08056B	PARTICIPANT	\N	PRESENT	0
153279	152733	01047U	PARTICIPANT	\N	PRESENT	0
153280	152733	09001P	PARTICIPANT	\N	PRESENT	0
153281	152733	14191V	PARTICIPANT	\N	PRESENT	0
153282	152733	14327T	PARTICIPANT	\N	PRESENT	0
153283	152733	01043Q	PARTICIPANT	\N	PRESENT	0
153292	152733	98018T	PARTICIPANT	\N	PRESENT	0
153294	152733	14069U	PARTICIPANT	\N	PRESENT	0
153300	152733	04074L	PARTICIPANT	\N	PRESENT	0
153297	152733	11065P	PARTICIPANT	\N	PRESENT	0
153298	152733	14065Q	PARTICIPANT	\N	PRESENT	0
153312	152733	95067Q	PARTICIPANT	\N	PRESENT	0
153301	152733	14055N	PARTICIPANT	\N	PRESENT	0
153313	152733	95015C	PARTICIPANT	\N	PRESENT	0
153314	152733	14031R	PARTICIPANT	\N	PRESENT	0
153315	152733	11098Y	PARTICIPANT	\N	PRESENT	0
153316	152733	11063M	PARTICIPANT	\N	PRESENT	0
153317	152733	95035G	PARTICIPANT	\N	PRESENT	0
153318	152733	86044G	PARTICIPANT	\N	PRESENT	0
153319	152733	14175V	PARTICIPANT	\N	PRESENT	0
153320	152733	14211G	PARTICIPANT	\N	PRESENT	0
153321	152733	14034U	PARTICIPANT	\N	PRESENT	0
153322	152733	14151M	PARTICIPANT	\N	PRESENT	0
153324	152733	11053K	PARTICIPANT	\N	PRESENT	0
153325	152733	04070G	PARTICIPANT	\N	PRESENT	0
153326	152733	08018U	PARTICIPANT	\N	PRESENT	0
153327	152733	08011M	PARTICIPANT	\N	PRESENT	0
153328	152733	04079R	PARTICIPANT	\N	PRESENT	0
153329	152733	89017R	PARTICIPANT	\N	PRESENT	0
153330	152733	01022K	PARTICIPANT	\N	PRESENT	0
127392	127391	14263U	PARTICIPANT	\N	PRESENT	0
127400	127399	14263U	PARTICIPANT	\N	PRESENT	0
129000	127242	08024S	PARTICIPANT	\N	PRESENT	0
129002	127242	07004J	PARTICIPANT	\N	PRESENT	0
129003	127242	14281W	PARTICIPANT	\N	PRESENT	0
129004	127242	14103D	PARTICIPANT	\N	PRESENT	0
129005	127242	14081Q	PARTICIPANT	\N	PRESENT	0
129006	127242	14065Q	PARTICIPANT	\N	PRESENT	0
129007	127242	12042Y	PARTICIPANT	\N	PRESENT	0
129008	127242	14121F	PARTICIPANT	\N	PRESENT	0
129009	127242	04085P	PARTICIPANT	\N	PRESENT	0
129010	127242	14013P	PARTICIPANT	\N	PRESENT	0
129011	127242	11098Y	PARTICIPANT	\N	PRESENT	0
129012	127242	14263U	PARTICIPANT	\N	PRESENT	0
129013	127242	08053X	PARTICIPANT	\N	PRESENT	0
129014	127242	14097Y	PARTICIPANT	\N	PRESENT	0
129015	127242	11033F	PARTICIPANT	\N	PRESENT	0
129016	127242	14239U	PARTICIPANT	\N	PRESENT	0
129017	127242	14267Y	PARTICIPANT	\N	PRESENT	0
129018	127242	04067M	PARTICIPANT	\N	PRESENT	0
129020	127242	14073Q	PARTICIPANT	\N	PRESENT	0
129021	127242	14105F	PARTICIPANT	\N	PRESENT	0
129079	127242	14217N	PARTICIPANT	\N	PRESENT	0
129080	127242	08058D	PARTICIPANT	\N	PRESENT	0
129170	127242	14213J	PARTICIPANT	\N	PRESENT	0
129082	127242	08041T	PARTICIPANT	\N	PRESENT	0
129083	127242	14271U	PARTICIPANT	\N	PRESENT	0
129084	127242	10015M	PARTICIPANT	\N	PRESENT	0
129085	127242	04047H	PARTICIPANT	\N	PRESENT	0
129086	127242	04077P	PARTICIPANT	\N	PRESENT	0
129087	127242	14079W	PARTICIPANT	\N	PRESENT	0
129088	127242	11082Q	PARTICIPANT	\N	PRESENT	0
129089	127242	86044G	PARTICIPANT	\N	PRESENT	0
129169	127242	11025F	PARTICIPANT	\N	PRESENT	0
129091	127242	95062K	PARTICIPANT	\N	PRESENT	0
129092	127242	08048B	PARTICIPANT	\N	PRESENT	0
129093	127242	01047U	PARTICIPANT	\N	PRESENT	0
129094	127242	04095R	PARTICIPANT	\N	PRESENT	0
129096	127242	14241N	PARTICIPANT	\N	PRESENT	0
129154	127242	08068F	PARTICIPANT	\N	PRESENT	0
129155	127242	11036J	PARTICIPANT	\N	PRESENT	0
129156	127242	97011G	PARTICIPANT	\N	PRESENT	0
129157	127242	01048V	PARTICIPANT	\N	PRESENT	0
129158	127242	95035G	PARTICIPANT	\N	PRESENT	0
129159	127242	08031R	PARTICIPANT	\N	PRESENT	0
129160	127242	14269B	PARTICIPANT	\N	PRESENT	0
129161	127242	95041E	PARTICIPANT	\N	PRESENT	0
129162	127242	14247U	PARTICIPANT	\N	PRESENT	0
129163	127242	11054L	PARTICIPANT	\N	PRESENT	0
129164	127242	98029W	PARTICIPANT	\N	PRESENT	0
129165	127242	87003B	PARTICIPANT	\N	PRESENT	0
129166	127242	14331P	PARTICIPANT	\N	PRESENT	0
129167	127242	14071N	PARTICIPANT	\N	PRESENT	0
129168	127242	11063M	PARTICIPANT	\N	PRESENT	0
129171	127242	14257W	PARTICIPANT	\N	PRESENT	0
129172	127242	11011M	PARTICIPANT	\N	PRESENT	0
129173	127242	04056J	PARTICIPANT	\N	PRESENT	0
129174	127242	14069U	PARTICIPANT	\N	PRESENT	0
129175	127242	14107H	PARTICIPANT	\N	PRESENT	0
129178	127242	11101A	PARTICIPANT	\N	PRESENT	0
129179	127242	07029T	PARTICIPANT	\N	PRESENT	0
129181	127242	14265W	PARTICIPANT	\N	PRESENT	0
129182	127242	14219Q	PARTICIPANT	\N	PRESENT	0
129183	127242	11066Q	PARTICIPANT	\N	PRESENT	0
129184	127242	11114F	PARTICIPANT	\N	PRESENT	0
129185	127242	11048N	PARTICIPANT	\N	PRESENT	0
129187	127242	11091R	PARTICIPANT	\N	PRESENT	0
129188	127242	14147R	PARTICIPANT	\N	PRESENT	0
129190	127242	98050T	PARTICIPANT	\N	PRESENT	0
129210	127242	14173T	PARTICIPANT	\N	PRESENT	0
129244	127242	11107G	PARTICIPANT	\N	PRESENT	0
129267	127242	14249W	PARTICIPANT	\N	PRESENT	0
129285	127242	08016S	PARTICIPANT	\N	PRESENT	0
129289	127242	14197C	PARTICIPANT	\N	PRESENT	0
129299	127242	11106F	PARTICIPANT	\N	PRESENT	0
129374	127243	80013X	PARTICIPANT	\N	PRESENT	0
129375	127243	11114F	PARTICIPANT	\N	PRESENT	0
129376	127243	11066Q	PARTICIPANT	\N	PRESENT	0
129377	127243	14079W	PARTICIPANT	\N	PRESENT	0
129378	127243	14247U	PARTICIPANT	\N	PRESENT	0
129379	127243	98050T	PARTICIPANT	\N	PRESENT	0
129383	127243	08048B	PARTICIPANT	\N	PRESENT	0
129381	127243	97011G	PARTICIPANT	\N	PRESENT	0
129382	127243	14026U	PARTICIPANT	\N	PRESENT	0
129389	127243	04050C	PARTICIPANT	\N	PRESENT	0
129390	127243	11098Y	PARTICIPANT	\N	PRESENT	0
129391	127243	07024N	PARTICIPANT	\N	PRESENT	0
129392	127243	01014K	PARTICIPANT	\N	PRESENT	0
129393	127243	11036J	PARTICIPANT	\N	PRESENT	0
129394	127243	14063N	PARTICIPANT	\N	PRESENT	0
129395	127243	11112D	PARTICIPANT	\N	PRESENT	0
129396	127243	98029W	PARTICIPANT	\N	PRESENT	0
129397	127243	11107G	PARTICIPANT	\N	PRESENT	0
129398	127243	11025F	PARTICIPANT	\N	PRESENT	0
129399	127243	11054L	PARTICIPANT	\N	PRESENT	0
129400	127243	14107H	PARTICIPANT	\N	PRESENT	0
129401	127243	08055A	PARTICIPANT	\N	PRESENT	0
129402	127243	14257W	PARTICIPANT	\N	PRESENT	0
129403	127243	11015D	PARTICIPANT	\N	PRESENT	0
129404	127243	92020L	PARTICIPANT	\N	PRESENT	0
129405	127243	01031L	PARTICIPANT	\N	PRESENT	0
129406	127243	14039A	PARTICIPANT	\N	PRESENT	0
129407	127243	11106F	PARTICIPANT	\N	PRESENT	0
129408	127243	11064N	PARTICIPANT	\N	PRESENT	0
129409	127243	98005N	PARTICIPANT	\N	PRESENT	0
129410	127243	14014Q	PARTICIPANT	\N	PRESENT	0
129411	127243	14169X	PARTICIPANT	\N	PRESENT	0
129412	127243	11080N	PARTICIPANT	\N	PRESENT	0
129413	127243	01056V	PARTICIPANT	\N	PRESENT	0
129414	127243	01028R	PARTICIPANT	\N	PRESENT	0
129415	127243	95062K	PARTICIPANT	\N	PRESENT	0
129416	127243	14119M	PARTICIPANT	\N	PRESENT	0
129417	127243	14195A	PARTICIPANT	\N	PRESENT	0
129418	127243	07029T	PARTICIPANT	\N	PRESENT	0
129419	127243	08034U	PARTICIPANT	\N	PRESENT	0
129420	127243	04053F	PARTICIPANT	\N	PRESENT	0
129421	127243	98018T	PARTICIPANT	\N	PRESENT	0
129422	127243	95015C	PARTICIPANT	\N	PRESENT	0
129423	127243	01027Q	PARTICIPANT	\N	PRESENT	0
129424	127243	95041E	PARTICIPANT	\N	PRESENT	0
129425	127243	04033B	PARTICIPANT	\N	PRESENT	0
129426	127243	05012A	PARTICIPANT	\N	PRESENT	0
129427	127243	04057K	PARTICIPANT	\N	PRESENT	0
129428	127243	08039A	PARTICIPANT	\N	PRESENT	0
129429	127243	04077P	PARTICIPANT	\N	PRESENT	0
129430	127243	14221J	PARTICIPANT	\N	PRESENT	0
129431	127243	14239U	PARTICIPANT	\N	PRESENT	0
129432	127243	98022P	PARTICIPANT	\N	PRESENT	0
129433	127243	11048N	PARTICIPANT	\N	PRESENT	0
129434	127243	04092N	PARTICIPANT	\N	PRESENT	0
129435	127243	04086Q	PARTICIPANT	\N	PRESENT	0
129436	127243	86044G	PARTICIPANT	\N	PRESENT	0
129437	127243	11091R	PARTICIPANT	\N	PRESENT	0
129438	127243	11011M	PARTICIPANT	\N	PRESENT	0
129439	127243	14038Y	PARTICIPANT	\N	PRESENT	0
129440	127243	87003B	PARTICIPANT	\N	PRESENT	0
129442	127243	01048V	PARTICIPANT	\N	PRESENT	0
129443	127243	04035D	PARTICIPANT	\N	PRESENT	0
129444	127243	04036E	PARTICIPANT	\N	PRESENT	0
129445	127243	11082Q	PARTICIPANT	\N	PRESENT	0
129446	127243	95037J	PARTICIPANT	\N	PRESENT	0
129447	127243	14147R	PARTICIPANT	\N	PRESENT	0
129452	127243	14031R	PARTICIPANT	\N	PRESENT	0
129453	127243	08016S	PARTICIPANT	\N	PRESENT	0
129454	127243	92018S	PARTICIPANT	\N	PRESENT	0
129372	127243	86034E	PARTICIPANT	\N	PRESENT	0
129373	127243	08053X	PARTICIPANT	\N	PRESENT	0
129455	127243	04061F	PARTICIPANT	\N	PRESENT	0
129456	127243	08019V	PARTICIPANT	\N	PRESENT	0
129457	127243	92039X	PARTICIPANT	\N	PRESENT	0
129458	127243	14227Q	PARTICIPANT	\N	PRESENT	0
129461	127243	11061K	PARTICIPANT	\N	PRESENT	0
129462	127243	11097X	PARTICIPANT	\N	PRESENT	0
129463	127243	14255U	PARTICIPANT	\N	PRESENT	0
129464	127243	08024S	PARTICIPANT	\N	PRESENT	0
129475	127243	77002U	PARTICIPANT	\N	PRESENT	0
129478	127243	14199E	PARTICIPANT	\N	PRESENT	0
129481	127243	13002U	PARTICIPANT	\N	PRESENT	0
129482	127243	11103C	PARTICIPANT	\N	PRESENT	0
129485	127243	11012A	PARTICIPANT	\N	PRESENT	0
129494	127243	95035G	PARTICIPANT	\N	PRESENT	0
129500	127243	11063M	PARTICIPANT	\N	PRESENT	0
129507	127243	04067M	PARTICIPANT	\N	PRESENT	0
129509	127243	04080J	PARTICIPANT	\N	PRESENT	0
129510	127243	14205J	PARTICIPANT	\N	PRESENT	0
129512	127243	04045F	PARTICIPANT	\N	PRESENT	0
129513	127243	14331P	PARTICIPANT	\N	PRESENT	0
129514	127243	11076S	PARTICIPANT	\N	PRESENT	0
129515	127243	14103D	PARTICIPANT	\N	PRESENT	0
146514	146502	11048N	PARTICIPANT	\N	PRESENT	0
146515	146502	99004R	PARTICIPANT	\N	PRESENT	0
146516	146502	14159V	PARTICIPANT	\N	PRESENT	0
146517	146502	08034U	PARTICIPANT	\N	PRESENT	0
146518	146502	01048V	PARTICIPANT	\N	PRESENT	0
146519	146502	07029T	PARTICIPANT	\N	EXCUSE	0
146520	146502	98046X	PARTICIPANT	\N	PRESENT	0
146521	146502	11085T	PARTICIPANT	\N	EXCUSE	0
146522	146502	08011M	PARTICIPANT	\N	PRESENT	0
146523	146502	98053W	PARTICIPANT	\N	EXCUSE	0
146524	146502	08061X	PARTICIPANT	\N	EXCUSE	0
146525	146502	01016M	PARTICIPANT	\N	PRESENT	0
146526	146502	04034C	PRESIDENT	1	PRESENT	0
146533	146532	14259Y	PARTICIPANT	\N	PRESENT	0
146799	141032	11101A	PARTICIPANT	\N	PRESENT	0
146800	141032	14231L	PARTICIPANT	\N	PRESENT	0
146801	141032	14014Q	PARTICIPANT	\N	PRESENT	0
146802	141032	01057W	PARTICIPANT	\N	PRESENT	0
146803	141032	14063N	PARTICIPANT	\N	PRESENT	0
146807	141032	05012A	PARTICIPANT	\N	PRESENT	0
146809	141032	14257W	PARTICIPANT	\N	PRESENT	0
146811	141032	14167V	PARTICIPANT	\N	PRESENT	0
146813	141032	11094U	PARTICIPANT	\N	PRESENT	0
146865	146864	96004D	PRESIDENT	0	PRESENT	0
146866	146864	14079W	PARTICIPANT	\N	PRESENT	0
146867	146864	14026U	PARTICIPANT	\N	PRESENT	0
146868	146864	11083R	PARTICIPANT	\N	PRESENT	0
146869	146864	98046X	PARTICIPANT	\N	PRESENT	0
146870	146864	14135M	PARTICIPANT	\N	PRESENT	0
146871	146864	01016M	PARTICIPANT	\N	PRESENT	0
146872	146864	04034C	PARTICIPANT	\N	PRESENT	0
146873	146864	14001X	PARTICIPANT	\N	PRESENT	0
146877	146864	04057K	PARTICIPANT	\N	EXCUSE	0
146875	146864	14073Q	PARTICIPANT	\N	EXCUSE	0
146876	146864	90003B	PARTICIPANT	\N	EXCUSE	0
146878	146864	10015M	PARTICIPANT	\N	EXCUSE	0
146879	146864	01031L	PARTICIPANT	\N	PRESENT	0
146880	146864	04070G	PARTICIPANT	\N	PRESENT	0
146881	146864	14083S	PARTICIPANT	\N	PRESENT	0
146882	146864	04086Q	PARTICIPANT	\N	PRESENT	0
146883	146864	11074Q	PARTICIPANT	\N	PRESENT	0
146884	146864	01057W	PARTICIPANT	\N	PRESENT	0
146885	146864	07029T	PARTICIPANT	\N	PRESENT	0
146886	146864	08011M	PARTICIPANT	\N	PRESENT	0
146887	146864	04061F	PARTICIPANT	\N	PRESENT	0
146913	146912	05008E	PARTICIPANT	\N	PRESENT	0
146914	146912	14065Q	PARTICIPANT	\N	PRESENT	0
146916	146915	05008E	PARTICIPANT	\N	PRESENT	0
146918	146917	05008E	PARTICIPANT	\N	PRESENT	0
146919	146917	14065Q	PARTICIPANT	\N	PRESENT	0
146920	146917	04047H	PARTICIPANT	\N	PRESENT	0
146921	146195	01013J	PARTICIPANT	\N	PRESENT	0
146922	146195	14083S	PARTICIPANT	\N	PRESENT	0
147073	147072	95067Q	PARTICIPANT	\N	PRESENT	0
147075	147074	95067Q	PARTICIPANT	\N	PRESENT	0
147077	147076	95067Q	PARTICIPANT	\N	PRESENT	0
147929	147892	14079W	PARTICIPANT	\N	PRESENT	0
147894	147892	08043V	PARTICIPANT	\N	PRESENT	0
147895	147892	14053L	PARTICIPANT	\N	PRESENT	0
148273	148272	89017R	PARTICIPANT	\N	PRESENT	0
148274	148272	01031L	PRESIDENT	0	PRESENT	0
148275	148272	01013J	PARTICIPANT	\N	PRESENT	0
148276	148272	11040E	PARTICIPANT	\N	PRESENT	0
148277	148272	08014Q	PARTICIPANT	\N	PRESENT	0
148278	148272	14175V	PARTICIPANT	\N	PRESENT	0
147902	147892	14215L	PARTICIPANT	\N	PRESENT	0
147903	147892	04089T	PARTICIPANT	\N	PRESENT	0
147904	147892	14187A	PARTICIPANT	\N	PRESENT	0
148279	148272	14083S	PARTICIPANT	\N	PRESENT	0
148280	148272	11053K	PARTICIPANT	\N	PRESENT	0
147907	147892	14231L	PARTICIPANT	\N	PRESENT	0
148281	148272	11042G	PARTICIPANT	\N	PRESENT	0
147909	147892	14213J	PARTICIPANT	\N	PRESENT	0
147910	147892	08031R	PARTICIPANT	\N	PRESENT	0
147911	147892	11100Y	PRESIDENT	0	PRESENT	0
148282	148272	04086Q	PARTICIPANT	\N	PRESENT	0
148283	148272	11070L	PARTICIPANT	\N	PRESENT	0
147914	147892	11104D	PARTICIPANT	\N	PRESENT	0
148284	148272	11088W	PARTICIPANT	\N	PRESENT	0
148285	148272	14327T	PARTICIPANT	\N	EXCUSE	0
147917	147892	11090Q	PARTICIPANT	\N	PRESENT	0
148286	148272	08022Q	PARTICIPANT	\N	PRESENT	0
148287	148272	01027Q	PARTICIPANT	\N	PRESENT	0
148288	148272	04071H	PARTICIPANT	\N	PRESENT	0
147921	147892	01028R	PARTICIPANT	\N	PRESENT	0
147922	147892	11094U	PARTICIPANT	\N	PRESENT	0
148289	148272	98053W	PARTICIPANT	\N	EXCUSE	0
147924	147892	14157T	PARTICIPANT	\N	PRESENT	0
147925	147892	92045V	PARTICIPANT	\N	PRESENT	0
148290	148272	11083R	PARTICIPANT	\N	PRESENT	0
147927	147892	14269B	PARTICIPANT	\N	PRESENT	0
148291	148272	14199E	PARTICIPANT	\N	PRESENT	0
148292	148272	01057W	PARTICIPANT	\N	PRESENT	0
148293	148272	08069G	PARTICIPANT	\N	PRESENT	0
148294	148272	11048N	PARTICIPANT	\N	PRESENT	0
148295	148272	99004R	PARTICIPANT	\N	PRESENT	0
148296	148272	04061F	PARTICIPANT	\N	PRESENT	0
148297	148272	14159V	PARTICIPANT	\N	PRESENT	0
148298	148272	07029T	PARTICIPANT	\N	PRESENT	0
148299	148272	08010L	PARTICIPANT	\N	PRESENT	0
148300	148272	08034U	PARTICIPANT	\N	PRESENT	0
148301	148272	01048V	PARTICIPANT	\N	PRESENT	0
148302	148272	98046X	PARTICIPANT	\N	PRESENT	0
148303	148272	11085T	PARTICIPANT	\N	EXCUSE	0
148304	148272	08011M	PARTICIPANT	\N	EXCUSE	0
148305	148272	08061X	PARTICIPANT	\N	EXCUSE	0
148306	148272	01016M	PARTICIPANT	\N	PRESENT	0
148307	148272	14225N	PARTICIPANT	\N	PRESENT	0
148308	148272	11012A	PARTICIPANT	\N	PRESENT	0
148309	148272	14173T	PARTICIPANT	\N	PRESENT	0
148310	148272	04034C	PARTICIPANT	\N	PRESENT	0
148311	148272	14187A	RAPPORTEUR_AVIS	\N	PRESENT	0
148312	148272	14119M	RAPPORTEUR_AVIS	\N	PRESENT	0
149552	147872	86034E	PARTICIPANT	\N	PRESENT	0
150212	149472	86034E	PARTICIPANT	\N	PRESENT	0
150232	149472	04088S	PARTICIPANT	\N	PRESENT	0
150233	149472	11010L	PARTICIPANT	\N	PRESENT	0
150234	149472	14039A	PARTICIPANT	\N	PRESENT	0
150235	149472	08073C	PARTICIPANT	\N	PRESENT	0
150236	149472	04050C	PARTICIPANT	\N	PRESENT	0
150237	149472	01016M	PARTICIPANT	\N	PRESENT	0
150238	149472	04056J	PARTICIPANT	\N	PRESENT	0
150239	149472	92015P	PARTICIPANT	\N	PRESENT	0
150240	149472	14257W	PARTICIPANT	\N	PRESENT	0
150241	149472	11040E	PARTICIPANT	\N	PRESENT	0
150242	149472	01013J	PARTICIPANT	\N	PRESENT	0
150243	149472	92018S	PARTICIPANT	\N	PRESENT	0
150244	149472	01059Y	PARTICIPANT	\N	PRESENT	0
150245	149472	11031D	PARTICIPANT	\N	PRESENT	0
150246	149472	11034G	PARTICIPANT	\N	PRESENT	0
150247	149472	11067R	PARTICIPANT	\N	PRESENT	0
150248	149472	11113E	PARTICIPANT	\N	PRESENT	0
150249	149472	01015L	PARTICIPANT	\N	PRESENT	0
150260	150258	86034E	PARTICIPANT	\N	PRESENT	0
150261	150258	04088S	PARTICIPANT	\N	PRESENT	0
150262	150258	14041T	PARTICIPANT	\N	PRESENT	0
150263	150258	11088W	PARTICIPANT	\N	PRESENT	0
150264	150258	14105F	PARTICIPANT	\N	PRESENT	0
150265	150258	14227Q	PARTICIPANT	\N	PRESENT	0
150266	150258	11042G	PARTICIPANT	\N	PRESENT	0
150267	150258	80027E	PARTICIPANT	\N	PRESENT	0
150268	150258	08055A	PARTICIPANT	\N	PRESENT	0
150269	150258	11061K	PARTICIPANT	\N	PRESENT	0
150270	150258	08052W	PARTICIPANT	\N	PRESENT	0
150271	150258	14051J	PARTICIPANT	\N	PRESENT	0
150272	150258	92039X	PARTICIPANT	\N	PRESENT	0
150273	150258	04053F	PARTICIPANT	\N	PRESENT	0
150274	150258	08038Y	PARTICIPANT	\N	PRESENT	0
150275	150258	01022K	PARTICIPANT	\N	PRESENT	0
150276	150258	14063N	PARTICIPANT	\N	PRESENT	0
150277	150258	11066Q	PARTICIPANT	\N	PRESENT	0
150278	150258	11106F	PARTICIPANT	\N	PRESENT	0
150279	150258	13002U	PARTICIPANT	\N	PRESENT	0
150280	150258	04067M	PARTICIPANT	\N	PRESENT	0
150292	150258	83047W	PARTICIPANT	\N	PRESENT	0
150293	150258	14107H	PARTICIPANT	\N	PRESENT	0
150294	150258	14197C	PARTICIPANT	\N	PRESENT	0
150295	150258	95063L	PARTICIPANT	\N	PRESENT	0
150296	150258	01015L	PARTICIPANT	\N	PRESENT	0
150297	150258	11098Y	PARTICIPANT	\N	PRESENT	0
150298	150258	11026G	PARTICIPANT	\N	PRESENT	0
150299	150258	14013P	PARTICIPANT	\N	PRESENT	0
150300	150258	01044R	PARTICIPANT	\N	PRESENT	0
150301	150258	11029K	PARTICIPANT	\N	PRESENT	0
150302	150258	11040E	PARTICIPANT	\N	PRESENT	0
150303	150258	04054G	PARTICIPANT	\N	PRESENT	0
150304	150258	11105E	PARTICIPANT	\N	PRESENT	0
150305	150258	01013J	PARTICIPANT	\N	PRESENT	0
150306	150258	11077T	PARTICIPANT	\N	PRESENT	0
128832	120699	04094Q	PARTICIPANT	\N	EXCUSE	0
128834	128833	11039M	PARTICIPANT	\N	PRESENT	0
128835	128833	98042T	PARTICIPANT	\N	PRESENT	0
128836	128833	01019Q	PARTICIPANT	\N	PRESENT	0
128838	128837	92031P	PARTICIPANT	\N	PRESENT	0
128839	128837	01014K	PARTICIPANT	\N	PRESENT	0
128840	128837	11054L	PARTICIPANT	\N	PRESENT	0
128841	128837	98021N	PARTICIPANT	\N	PRESENT	0
128843	128842	01014K	PARTICIPANT	\N	PRESENT	0
128844	128842	11054L	PARTICIPANT	\N	PRESENT	0
128846	128845	92031P	PARTICIPANT	\N	PRESENT	0
128847	128845	01014K	PARTICIPANT	\N	PRESENT	0
128848	128845	11054L	PARTICIPANT	\N	PRESENT	0
128850	128849	07004J	PARTICIPANT	\N	PRESENT	0
128853	128852	01008M	PARTICIPANT	\N	PRESENT	0
128854	128852	11036J	PARTICIPANT	\N	PRESENT	0
128855	128852	11081P	PARTICIPANT	\N	PRESENT	0
128856	128852	14013P	PARTICIPANT	\N	PRESENT	0
128857	128852	08068F	PARTICIPANT	\N	PRESENT	0
128858	128852	14207L	PARTICIPANT	\N	PRESENT	0
128859	128852	11101A	PARTICIPANT	\N	PRESENT	0
128860	128852	90003B	PARTICIPANT	\N	PRESENT	0
128861	128852	08028W	PARTICIPANT	\N	PRESENT	0
128862	128852	80013X	PARTICIPANT	\N	PRESENT	0
128892	128852	11034G	PARTICIPANT	\N	PRESENT	0
128997	128996	14133K	PARTICIPANT	\N	PRESENT	0
128865	128852	14197C	PARTICIPANT	\N	PRESENT	0
128866	128852	11110B	PARTICIPANT	\N	PRESENT	0
128867	128852	14187A	PARTICIPANT	\N	PRESENT	0
129191	129189	01031L	PRESIDENT	0	PRESENT	0
128869	128852	14081Q	PARTICIPANT	\N	PRESENT	0
129192	129189	01013J	PARTICIPANT	\N	PRESENT	0
129024	129019	04040A	PARTICIPANT	\N	EXCUSE	0
128872	128852	04049K	PARTICIPANT	\N	PRESENT	0
129025	129019	08058D	PARTICIPANT	\N	PRESENT	0
128874	128852	11111C	PARTICIPANT	\N	PRESENT	0
128875	128852	08015R	PARTICIPANT	\N	PRESENT	0
128876	128852	11100Y	PRESIDENT	0	PRESENT	0
128877	128852	01061S	PARTICIPANT	\N	PRESENT	0
128878	128852	11098Y	PARTICIPANT	\N	PRESENT	0
128879	128852	01043Q	PARTICIPANT	\N	EXCUSE	0
129193	129189	11040E	PARTICIPANT	\N	PRESENT	0
128881	128852	14205J	PARTICIPANT	\N	PRESENT	0
128882	128852	08019V	PARTICIPANT	\N	PRESENT	0
128883	128852	14257W	PARTICIPANT	\N	PRESENT	0
128884	128852	08021P	PARTICIPANT	\N	PRESENT	0
128885	128852	04088S	PARTICIPANT	\N	PRESENT	0
128886	128852	98050T	PARTICIPANT	\N	PRESENT	0
128887	128852	11090Q	PARTICIPANT	\N	PRESENT	0
128888	128852	11046L	PARTICIPANT	\N	PRESENT	0
128889	128852	01058X	PARTICIPANT	\N	PRESENT	0
128890	128852	11094U	PARTICIPANT	\N	PRESENT	0
128891	128852	11066Q	PARTICIPANT	\N	PRESENT	0
129194	129189	14175V	PARTICIPANT	\N	PRESENT	0
129195	129189	14083S	PARTICIPANT	\N	PRESENT	0
129196	129189	11053K	PARTICIPANT	\N	PRESENT	0
129197	129189	14085U	PARTICIPANT	\N	PRESENT	0
129031	129019	98018T	PARTICIPANT	\N	PRESENT	0
129032	129019	92018S	PARTICIPANT	\N	PRESENT	0
129198	129189	11042G	PARTICIPANT	\N	PRESENT	0
129034	129019	95030B	PARTICIPANT	\N	PRESENT	0
129199	129189	04086Q	PARTICIPANT	\N	PRESENT	0
129200	129189	11088W	PARTICIPANT	\N	PRESENT	0
129037	129019	97011G	PARTICIPANT	\N	PRESENT	0
129268	129189	08022Q	PARTICIPANT	\N	PRESENT	0
129039	129019	04035D	PARTICIPANT	\N	PRESENT	0
129040	129019	07024N	PRESIDENT	0	PRESENT	0
129041	129019	04095R	PARTICIPANT	\N	PRESENT	0
129042	129019	14014Q	PARTICIPANT	\N	PRESENT	0
129269	129189	01027Q	PARTICIPANT	\N	PRESENT	0
129270	129189	98053W	PARTICIPANT	\N	EXCUSE	0
129045	129019	95035G	PARTICIPANT	\N	PRESENT	0
129271	129189	11083R	PARTICIPANT	\N	PRESENT	0
129047	129019	14211G	PARTICIPANT	\N	PRESENT	0
129048	129019	98022P	PARTICIPANT	\N	PRESENT	0
129049	129019	11064N	PARTICIPANT	\N	PRESENT	0
129050	129019	95037J	PARTICIPANT	\N	PRESENT	0
129272	129189	14199E	PARTICIPANT	\N	PRESENT	0
129052	129019	14097Y	PARTICIPANT	\N	PRESENT	0
129053	129019	95041E	PARTICIPANT	\N	PRESENT	0
129054	129019	04036E	PARTICIPANT	\N	PRESENT	0
129055	129019	14039A	PARTICIPANT	\N	PRESENT	0
129273	129189	01057W	PARTICIPANT	\N	PRESENT	0
129057	129019	98005N	PARTICIPANT	\N	PRESENT	0
129058	129019	92031P	PARTICIPANT	\N	PRESENT	0
129059	129019	11106F	PARTICIPANT	\N	PRESENT	0
129060	129019	14251Q	PARTICIPANT	\N	PRESENT	0
129061	129019	83042R	PARTICIPANT	\N	PRESENT	0
129062	129019	08053X	PARTICIPANT	\N	PRESENT	0
129274	129189	08069G	PARTICIPANT	\N	PRESENT	0
129064	129019	11105E	PARTICIPANT	\N	PRESENT	0
129065	129019	14253S	PARTICIPANT	\N	PRESENT	0
129066	129019	08047A	PARTICIPANT	\N	PRESENT	0
129067	129019	14028W	PARTICIPANT	\N	PRESENT	0
129068	129019	14193X	PARTICIPANT	\N	PRESENT	0
129069	129019	98021N	PARTICIPANT	\N	PRESENT	0
129070	129019	04080J	PARTICIPANT	\N	PRESENT	0
129071	129019	95059Q	PARTICIPANT	\N	EXCUSE	0
129072	129019	86044G	PARTICIPANT	\N	PRESENT	0
129073	129019	01014K	PARTICIPANT	\N	PRESENT	0
129074	129019	11054L	PARTICIPANT	\N	PRESENT	0
129075	129019	01056V	PARTICIPANT	\N	PRESENT	0
129076	129019	92044U	PARTICIPANT	\N	PRESENT	0
129275	129189	11048N	PARTICIPANT	\N	PRESENT	0
129276	129189	14159V	PARTICIPANT	\N	PRESENT	0
129277	129189	07029T	PARTICIPANT	\N	PRESENT	0
129278	129189	08010L	PARTICIPANT	\N	PRESENT	0
129279	129189	08034U	PARTICIPANT	\N	PRESENT	0
129280	129189	01048V	PARTICIPANT	\N	PRESENT	0
129281	129189	98046X	PARTICIPANT	\N	PRESENT	0
129282	129189	08011M	PARTICIPANT	\N	PRESENT	0
129283	129189	08073C	PARTICIPANT	\N	PRESENT	0
129284	129189	01016M	PARTICIPANT	\N	PRESENT	0
129286	129189	11057P	PARTICIPANT	\N	PRESENT	0
129287	129189	14173T	PARTICIPANT	\N	PRESENT	0
129288	129189	04034C	PARTICIPANT	\N	PRESENT	0
129291	129189	11085T	PARTICIPANT	\N	EXCUSE	0
129292	129189	08061X	PARTICIPANT	\N	EXCUSE	0
130413	130175	89029V	PARTICIPANT	\N	PRESENT	0
130414	130175	11043H	PARTICIPANT	\N	PRESENT	0
130415	130175	14097Y	PARTICIPANT	\N	PRESENT	0
130416	130175	14014Q	PARTICIPANT	\N	PRESENT	0
130417	130175	14105F	PARTICIPANT	\N	PRESENT	0
130418	130175	13002U	PARTICIPANT	\N	PRESENT	0
130419	130175	04067M	PARTICIPANT	\N	PRESENT	0
130420	130175	11037K	PARTICIPANT	\N	PRESENT	0
130421	130175	04049K	PARTICIPANT	\N	PRESENT	0
130422	130175	01007L	PARTICIPANT	\N	PRESENT	0
130423	130175	86044G	PARTICIPANT	\N	PRESENT	0
130424	130175	08060W	PARTICIPANT	\N	PRESENT	0
130425	130175	14107H	PARTICIPANT	\N	PRESENT	0
130426	130175	14215L	PARTICIPANT	\N	PRESENT	0
130427	130175	04088S	PARTICIPANT	\N	PRESENT	0
130428	130175	08047A	PARTICIPANT	\N	PRESENT	0
130429	130175	04044E	PARTICIPANT	\N	PRESENT	0
130430	130175	11049P	PARTICIPANT	\N	PRESENT	0
130431	130175	14275Y	PARTICIPANT	\N	PRESENT	0
130432	130175	11056N	PARTICIPANT	\N	PRESENT	0
130433	130175	04038G	PARTICIPANT	\N	PRESENT	0
130434	130175	08043V	PARTICIPANT	\N	PRESENT	0
130435	130175	14071N	PARTICIPANT	\N	PRESENT	0
130436	130175	14213J	PARTICIPANT	\N	PRESENT	0
130437	130175	01058X	PARTICIPANT	\N	PRESENT	0
130438	130175	11080N	PARTICIPANT	\N	PRESENT	0
130439	130175	11103C	PARTICIPANT	\N	PRESENT	0
130440	130175	01057W	PARTICIPANT	\N	PRESENT	0
130441	130175	12042Y	PARTICIPANT	\N	PRESENT	0
130442	130175	04097T	PARTICIPANT	\N	PRESENT	0
130443	130175	14327T	PARTICIPANT	\N	PRESENT	0
130444	130175	11065P	PARTICIPANT	\N	PRESENT	0
130445	130175	14197C	PARTICIPANT	\N	PRESENT	0
130446	130175	14221J	PARTICIPANT	\N	PRESENT	0
130447	130175	14042U	PARTICIPANT	\N	PRESENT	0
130448	130175	14030Q	PARTICIPANT	\N	PRESENT	0
130449	130175	08051V	PARTICIPANT	\N	PRESENT	0
130450	130175	87003B	PARTICIPANT	\N	PRESENT	0
130451	130175	11066Q	PARTICIPANT	\N	PRESENT	0
130452	130175	08068F	PARTICIPANT	\N	PRESENT	0
130453	130175	11036J	PARTICIPANT	\N	PRESENT	0
130454	130175	14257W	PARTICIPANT	\N	PRESENT	0
130455	130175	14207L	PARTICIPANT	\N	PRESENT	0
130456	130175	14147R	PARTICIPANT	\N	PRESENT	0
130457	130175	14069U	PARTICIPANT	\N	PRESENT	0
130458	130175	97011G	PARTICIPANT	\N	PRESENT	0
130459	130175	14265W	PARTICIPANT	\N	PRESENT	0
130460	130175	11101A	PARTICIPANT	\N	PRESENT	0
130461	130175	14179A	PARTICIPANT	\N	PRESENT	0
130462	130175	01028R	PARTICIPANT	\N	PRESENT	0
130463	130175	14053L	PARTICIPANT	\N	PRESENT	0
153555	152734	04066L	PARTICIPANT	\N	PRESENT	0
153572	152734	95049N	PARTICIPANT	\N	PRESENT	0
153573	152734	95063L	PARTICIPANT	\N	PRESENT	0
153574	152734	07026Q	PARTICIPANT	\N	PRESENT	0
153575	152734	11057P	PARTICIPANT	\N	PRESENT	0
153576	152734	11036J	PARTICIPANT	\N	PRESENT	0
153577	152734	11109J	PARTICIPANT	\N	PRESENT	0
153578	152734	98022P	PARTICIPANT	\N	PRESENT	0
153579	152734	11037K	PARTICIPANT	\N	PRESENT	0
153580	152734	14329V	PARTICIPANT	\N	PRESENT	0
153581	152734	11088W	PARTICIPANT	\N	PRESENT	0
153582	152734	07029T	PARTICIPANT	\N	PRESENT	0
153583	152734	11071M	PARTICIPANT	\N	PRESENT	0
153584	152734	14281W	PARTICIPANT	\N	PRESENT	0
153585	152734	11113E	PARTICIPANT	\N	PRESENT	0
153586	152734	14267Y	PARTICIPANT	\N	PRESENT	0
153587	152734	14085U	PARTICIPANT	\N	PRESENT	0
153588	152734	11084S	PARTICIPANT	\N	PRESENT	0
153589	152734	11055M	PARTICIPANT	\N	PRESENT	0
153590	152734	11033F	PARTICIPANT	\N	PRESENT	0
153591	152734	01013J	PARTICIPANT	\N	PRESENT	0
153592	152734	11040E	PARTICIPANT	\N	PRESENT	0
153593	152734	14219Q	PARTICIPANT	\N	PRESENT	0
153594	152734	08034U	PARTICIPANT	\N	PRESENT	0
153595	152734	14207L	PARTICIPANT	\N	PRESENT	0
153596	152734	11042G	PARTICIPANT	\N	PRESENT	0
153597	152734	11104D	PARTICIPANT	\N	PRESENT	0
153598	152734	92039X	PARTICIPANT	\N	PRESENT	0
153599	152734	92015P	PARTICIPANT	\N	PRESENT	0
153600	152734	11029K	PARTICIPANT	\N	PRESENT	0
153601	152734	11053K	PARTICIPANT	\N	PRESENT	0
153602	152734	14034U	PARTICIPANT	\N	PRESENT	0
153603	152734	80027E	PARTICIPANT	\N	PRESENT	0
153604	152734	88008L	PARTICIPANT	\N	PRESENT	0
153605	152734	08031R	PARTICIPANT	\N	PRESENT	0
153606	152734	01025N	PARTICIPANT	\N	PRESENT	0
153607	152734	04067M	PARTICIPANT	\N	PRESENT	0
153608	152734	04086Q	PARTICIPANT	\N	PRESENT	0
153609	152734	14331P	PARTICIPANT	\N	PRESENT	0
153610	152734	14037X	PARTICIPANT	\N	PRESENT	0
153611	152734	99004R	PARTICIPANT	\N	PRESENT	0
153612	152734	04053F	PARTICIPANT	\N	PRESENT	0
153613	152734	14123H	PARTICIPANT	\N	PRESENT	0
153614	152734	14247U	PARTICIPANT	\N	PRESENT	0
153615	152734	08017T	PARTICIPANT	\N	PRESENT	0
153616	152734	04057K	PARTICIPANT	\N	PRESENT	0
153617	152734	01057W	PARTICIPANT	\N	PRESENT	0
153618	152734	11011M	PARTICIPANT	\N	PRESENT	0
153619	152734	11054L	PARTICIPANT	\N	PRESENT	0
153620	152734	11059R	PARTICIPANT	\N	PRESENT	0
153622	152734	14107H	PARTICIPANT	\N	PRESENT	0
153624	152734	04059M	PARTICIPANT	\N	PRESENT	0
153625	152734	05008E	PARTICIPANT	\N	PRESENT	0
153626	152734	92031P	PARTICIPANT	\N	PRESENT	0
153627	152734	11089X	PARTICIPANT	\N	PRESENT	0
153628	152734	13002U	PARTICIPANT	\N	PRESENT	0
153632	152734	01003G	PARTICIPANT	\N	PRESENT	0
153633	152734	01046T	PARTICIPANT	\N	PRESENT	0
153634	152734	08051V	PARTICIPANT	\N	PRESENT	0
153635	152734	14041T	PARTICIPANT	\N	PRESENT	0
153636	152734	14327T	PARTICIPANT	\N	PRESENT	0
153637	152734	14083S	PARTICIPANT	\N	PRESENT	0
153638	152734	14227Q	PARTICIPANT	\N	PRESENT	0
153639	152734	11048N	PARTICIPANT	\N	PRESENT	0
153641	152734	11097X	PARTICIPANT	\N	PRESENT	0
153643	152734	11077T	PARTICIPANT	\N	PRESENT	0
153644	152734	11090Q	PARTICIPANT	\N	PRESENT	0
153645	152734	11027H	PARTICIPANT	\N	PRESENT	0
153646	152734	14073Q	PARTICIPANT	\N	PRESENT	0
153652	152734	01016M	PARTICIPANT	\N	PRESENT	0
153653	152734	11015D	PARTICIPANT	\N	PRESENT	0
153654	152734	14269B	PARTICIPANT	\N	PRESENT	0
153655	152734	11083R	PARTICIPANT	\N	PRESENT	0
153656	152734	01031L	PARTICIPANT	\N	PRESENT	0
153658	152734	14259Y	PARTICIPANT	\N	PRESENT	0
153661	152734	98005N	PARTICIPANT	\N	PRESENT	0
153662	152734	14103D	PARTICIPANT	\N	PRESENT	0
153663	152734	14175V	PARTICIPANT	\N	PRESENT	0
153664	152734	11064N	PARTICIPANT	\N	PRESENT	0
153693	152736	04066L	PARTICIPANT	\N	PRESENT	0
153694	152736	01031L	PARTICIPANT	\N	PRESENT	0
153695	152736	08011M	PARTICIPANT	\N	PRESENT	0
153712	152736	80013X	PARTICIPANT	\N	PRESENT	0
153713	152736	92039X	PARTICIPANT	\N	PRESENT	0
153714	152736	11015D	PARTICIPANT	\N	PRESENT	0
153715	152736	11054L	PARTICIPANT	\N	PRESENT	0
153716	152736	14085U	PARTICIPANT	\N	PRESENT	0
153833	152735	14225N	PARTICIPANT	\N	PRESENT	0
153718	152736	14073Q	PARTICIPANT	\N	PRESENT	0
153719	152736	11113E	PARTICIPANT	\N	PRESENT	0
153720	152736	14327T	PARTICIPANT	\N	PRESENT	0
153721	152736	11012A	PARTICIPANT	\N	PRESENT	0
153722	152736	88008L	PARTICIPANT	\N	PRESENT	0
153723	152736	11036J	PARTICIPANT	\N	PRESENT	0
153724	152736	08034U	PARTICIPANT	\N	PRESENT	0
153725	152736	14175V	PARTICIPANT	\N	PRESENT	0
153726	152736	14041T	PARTICIPANT	\N	PRESENT	0
153727	152736	11097X	PARTICIPANT	\N	PRESENT	0
153728	152736	04043D	PARTICIPANT	\N	PRESENT	0
153729	152736	01013J	PARTICIPANT	\N	PRESENT	0
153730	152736	04086Q	PARTICIPANT	\N	PRESENT	0
153731	152736	01027Q	PARTICIPANT	\N	PRESENT	0
153732	152736	99004R	PARTICIPANT	\N	PRESENT	0
153733	152736	11040E	PARTICIPANT	\N	PRESENT	0
153734	152736	11057P	PARTICIPANT	\N	PRESENT	0
153735	152736	11027H	PARTICIPANT	\N	PRESENT	0
153736	152736	08073C	PARTICIPANT	\N	PRESENT	0
153737	152736	11053K	PARTICIPANT	\N	PRESENT	0
153738	152736	11048N	PARTICIPANT	\N	PRESENT	0
153739	152736	11083R	PARTICIPANT	\N	PRESENT	0
153740	152736	11042G	PARTICIPANT	\N	PRESENT	0
153741	152736	04034C	PARTICIPANT	\N	PRESENT	0
153742	152736	01057W	PARTICIPANT	\N	PRESENT	0
153743	152736	01016M	PARTICIPANT	\N	PRESENT	0
153744	152736	04071H	PARTICIPANT	\N	PRESENT	0
153745	152736	11077T	PARTICIPANT	\N	PRESENT	0
153746	152736	14083S	PARTICIPANT	\N	PRESENT	0
153747	152736	07029T	PARTICIPANT	\N	PRESENT	0
153748	152736	11088W	PARTICIPANT	\N	PRESENT	0
153752	152736	08010L	PARTICIPANT	\N	PRESENT	0
153753	152736	14219Q	PARTICIPANT	\N	PRESENT	0
153772	152736	11104D	PARTICIPANT	\N	PRESENT	0
153773	152736	98046X	PARTICIPANT	\N	PRESENT	0
153792	152735	04066L	PARTICIPANT	\N	PRESENT	0
153793	152735	01031L	PARTICIPANT	\N	PRESENT	0
153794	152735	08011M	PARTICIPANT	\N	PRESENT	0
153852	152735	80013X	PARTICIPANT	\N	PRESENT	0
153853	152735	14083S	PARTICIPANT	\N	PRESENT	0
153854	152735	11042G	PARTICIPANT	\N	PRESENT	0
153855	152735	11104D	PARTICIPANT	\N	PRESENT	0
153799	152735	14085U	PARTICIPANT	\N	PRESENT	0
153800	152735	14073Q	PARTICIPANT	\N	PRESENT	0
153856	152735	14215L	PARTICIPANT	\N	PRESENT	0
153802	152735	11012A	PARTICIPANT	\N	PRESENT	0
153803	152735	88008L	PARTICIPANT	\N	PRESENT	0
153857	152735	14327T	PARTICIPANT	\N	PRESENT	0
153805	152735	08034U	PARTICIPANT	\N	PRESENT	0
153806	152735	14175V	PARTICIPANT	\N	PRESENT	0
153807	152735	14041T	PARTICIPANT	\N	PRESENT	0
153872	152735	92039X	PARTICIPANT	\N	PRESENT	0
153873	152735	08069G	PARTICIPANT	\N	PRESENT	0
153810	152735	01013J	PARTICIPANT	\N	PRESENT	0
153811	152735	04086Q	PARTICIPANT	\N	PRESENT	0
153812	152735	01027Q	PARTICIPANT	\N	PRESENT	0
153813	152735	99004R	PARTICIPANT	\N	PRESENT	0
153814	152735	11040E	PARTICIPANT	\N	PRESENT	0
153815	152735	11057P	PARTICIPANT	\N	PRESENT	0
153835	152735	14207L	PARTICIPANT	\N	PRESENT	0
153892	152735	07029T	PARTICIPANT	\N	PRESENT	0
153818	152735	11048N	PARTICIPANT	\N	PRESENT	0
153819	152735	11083R	PARTICIPANT	\N	PRESENT	0
153893	152735	04071H	PARTICIPANT	\N	PRESENT	0
153821	152735	04034C	PARTICIPANT	\N	PRESENT	0
153822	152735	01057W	PARTICIPANT	\N	PRESENT	0
153823	152735	01016M	PARTICIPANT	\N	PRESENT	0
153912	152735	04047H	PARTICIPANT	\N	PRESENT	0
153913	152735	14037X	PARTICIPANT	\N	PRESENT	0
153914	152735	14219Q	PARTICIPANT	\N	PRESENT	0
153915	152735	11053K	PARTICIPANT	\N	PRESENT	0
153828	152735	11088W	PARTICIPANT	\N	PRESENT	0
153932	152735	11074Q	PARTICIPANT	\N	PRESENT	0
153952	152752	11085T	PARTICIPANT	\N	PRESENT	0
153976	152752	08011M	PARTICIPANT	\N	PRESENT	0
153832	152735	98046X	PARTICIPANT	\N	PRESENT	0
153834	152735	07004J	PARTICIPANT	\N	PRESENT	0
153977	152752	01031L	PARTICIPANT	\N	PRESENT	0
153978	152752	11040E	PARTICIPANT	\N	PRESENT	0
153979	152752	11057P	PARTICIPANT	\N	PRESENT	0
129516	127243	08051V	PARTICIPANT	\N	PRESENT	0
129517	127243	11101A	PARTICIPANT	\N	PRESENT	0
129518	127243	14211G	PARTICIPANT	\N	PRESENT	0
129519	127243	12042Y	PARTICIPANT	\N	PRESENT	0
129520	127243	08018U	PARTICIPANT	\N	PRESENT	0
129521	127243	08058D	PARTICIPANT	\N	PRESENT	0
129539	127243	01016M	PARTICIPANT	\N	PRESENT	0
129544	127243	14133K	PARTICIPANT	\N	PRESENT	0
129545	127243	98021N	PARTICIPANT	\N	PRESENT	0
129546	127243	14135M	PARTICIPANT	\N	PRESENT	0
129547	127243	11094U	PARTICIPANT	\N	PRESENT	0
129548	127243	08014Q	PARTICIPANT	\N	PRESENT	0
129549	127243	92031P	PARTICIPANT	\N	PRESENT	0
129550	127243	95049N	PARTICIPANT	\N	PRESENT	0
129551	127243	14237S	PARTICIPANT	\N	PRESENT	0
129552	127243	83047W	PARTICIPANT	\N	PRESENT	0
129553	127243	04054G	PARTICIPANT	\N	PRESENT	0
129554	127243	01057W	PARTICIPANT	\N	PRESENT	0
129555	127243	01058X	PARTICIPANT	\N	PRESENT	0
129640	127244	11098Y	PARTICIPANT	\N	PRESENT	0
129641	127244	80013X	PARTICIPANT	\N	PRESENT	0
129642	127244	95037J	PARTICIPANT	\N	PRESENT	0
129643	127244	14247U	PARTICIPANT	\N	PRESENT	0
129644	127244	08019V	PARTICIPANT	\N	PRESENT	0
129645	127244	14133K	PARTICIPANT	\N	PRESENT	0
129646	127244	11012A	PARTICIPANT	\N	PRESENT	0
129647	127244	13002U	PARTICIPANT	\N	PRESENT	0
129648	127244	11114F	PARTICIPANT	\N	PRESENT	0
129649	127244	98035U	PARTICIPANT	\N	PRESENT	0
129650	127244	14026U	PARTICIPANT	\N	PRESENT	0
129651	127244	14014Q	PARTICIPANT	\N	PRESENT	0
129652	127244	01015L	PARTICIPANT	\N	PRESENT	0
129653	127244	14265W	PARTICIPANT	\N	PRESENT	0
129654	127244	08053X	PARTICIPANT	\N	PRESENT	0
129655	127244	11083R	PARTICIPANT	\N	PRESENT	0
129656	127244	08058D	PARTICIPANT	\N	PRESENT	0
129657	127244	96004D	PARTICIPANT	\N	PRESENT	0
129658	127244	04054G	PARTICIPANT	\N	PRESENT	0
129659	127244	14038Y	PARTICIPANT	\N	PRESENT	0
129660	127244	14237S	PARTICIPANT	\N	PRESENT	0
129661	127244	95062K	PARTICIPANT	\N	PRESENT	0
129662	127244	04042C	PARTICIPANT	\N	PRESENT	0
129663	127244	04080J	PARTICIPANT	\N	PRESENT	0
129664	127244	14079W	PARTICIPANT	\N	PRESENT	0
129665	127244	01031L	PARTICIPANT	\N	PRESENT	0
129666	127244	01016M	PARTICIPANT	\N	PRESENT	0
129667	127244	04045F	PARTICIPANT	\N	PRESENT	0
129668	127244	08055A	PARTICIPANT	\N	PRESENT	0
129669	127244	01008M	PARTICIPANT	\N	PRESENT	0
129670	127244	11094U	PARTICIPANT	\N	PRESENT	0
129671	127244	14207L	PARTICIPANT	\N	PRESENT	0
129672	127244	98046X	PARTICIPANT	\N	PRESENT	0
129673	127244	14249W	PARTICIPANT	\N	PRESENT	0
129674	127244	14030Q	PARTICIPANT	\N	PRESENT	0
129675	127244	11103C	PARTICIPANT	\N	PRESENT	0
129676	127244	14031R	PARTICIPANT	\N	PRESENT	0
129677	127244	14033T	PARTICIPANT	\N	PRESENT	0
129678	127244	14217N	PARTICIPANT	\N	PRESENT	0
129699	127245	11094U	PARTICIPANT	\N	PRESENT	0
129700	127245	01015L	PARTICIPANT	\N	PRESENT	0
129701	127245	11098Y	PARTICIPANT	\N	PRESENT	0
129702	127245	14271U	PARTICIPANT	\N	PRESENT	0
129703	127245	11036J	PARTICIPANT	\N	PRESENT	0
129704	127245	13002U	PARTICIPANT	\N	PRESENT	0
129705	127245	14107H	PARTICIPANT	\N	PRESENT	0
129706	127245	08055A	PARTICIPANT	\N	PRESENT	0
129707	127245	14030Q	PARTICIPANT	\N	PRESENT	0
129708	127245	14331P	PARTICIPANT	\N	PRESENT	0
129709	127245	14069U	PARTICIPANT	\N	PRESENT	0
129710	127245	05012A	PARTICIPANT	\N	PRESENT	0
129711	127245	11103C	PARTICIPANT	\N	PRESENT	0
129712	127245	14265W	PARTICIPANT	\N	PRESENT	0
129713	127245	14033T	PARTICIPANT	\N	PRESENT	0
129714	127245	01008M	PARTICIPANT	\N	PRESENT	0
129715	127245	95062K	PARTICIPANT	\N	PRESENT	0
129716	127245	14219Q	PARTICIPANT	\N	PRESENT	0
129697	127245	04081K	PARTICIPANT	\N	PRESENT	0
129698	127245	08012N	PARTICIPANT	\N	PRESENT	0
129717	127245	11012A	PARTICIPANT	\N	PRESENT	0
129718	127245	99004R	PARTICIPANT	\N	PRESENT	0
129719	127245	11107G	PARTICIPANT	\N	PRESENT	0
129720	127245	14197C	PARTICIPANT	\N	PRESENT	0
129721	127245	80013X	PARTICIPANT	\N	PRESENT	0
130366	129541	14327T	PARTICIPANT	\N	PRESENT	0
131675	130821	08024S	PARTICIPANT	\N	PRESENT	0
131676	130821	01007L	PARTICIPANT	\N	PRESENT	0
131677	130821	14215L	PARTICIPANT	\N	PRESENT	0
131678	130821	14034U	PARTICIPANT	\N	PRESENT	0
131679	130821	14205J	PARTICIPANT	\N	PRESENT	0
131680	130821	14327T	PARTICIPANT	\N	PRESENT	0
131681	130821	14219Q	PARTICIPANT	\N	PRESENT	0
131682	130821	14103D	PARTICIPANT	\N	PRESENT	0
131683	130821	14030Q	PARTICIPANT	\N	PRESENT	0
131684	130821	01034P	PARTICIPANT	\N	PRESENT	0
131685	130821	11036J	PARTICIPANT	\N	PRESENT	0
131686	130821	80013X	PARTICIPANT	\N	PRESENT	0
131687	130821	13002U	PARTICIPANT	\N	PRESENT	0
131688	130821	01044R	PARTICIPANT	\N	PRESENT	0
129638	127244	08024S	PARTICIPANT	\N	PRESENT	0
129639	127244	11054L	PARTICIPANT	\N	PRESENT	0
131689	130821	14249W	PARTICIPANT	\N	PRESENT	0
131690	130821	14195A	PARTICIPANT	\N	PRESENT	0
131691	130821	04040A	PARTICIPANT	\N	PRESENT	0
131692	130821	14105F	PARTICIPANT	\N	PRESENT	0
131693	130821	14079W	PARTICIPANT	\N	PRESENT	0
131694	130821	11094U	PARTICIPANT	\N	PRESENT	0
131695	130821	08015R	PARTICIPANT	\N	PRESENT	0
131696	130821	14213J	PARTICIPANT	\N	PRESENT	0
131697	130821	04088S	PARTICIPANT	\N	PRESENT	0
131698	130821	04049K	PARTICIPANT	\N	PRESENT	0
131699	130821	14265W	PARTICIPANT	\N	PRESENT	0
131700	130821	04042C	PARTICIPANT	\N	PRESENT	0
131701	130821	11035H	PARTICIPANT	\N	PRESENT	0
131702	130821	14217N	PARTICIPANT	\N	PRESENT	0
131703	130821	14053L	PARTICIPANT	\N	PRESENT	0
131704	130821	14187A	PARTICIPANT	\N	PRESENT	0
131705	130821	97011G	PARTICIPANT	\N	PRESENT	0
131706	130821	14223L	PARTICIPANT	\N	PRESENT	0
131707	130821	04057K	PARTICIPANT	\N	PRESENT	0
131708	130821	14051J	PARTICIPANT	\N	PRESENT	0
131709	130821	14107H	PARTICIPANT	\N	PRESENT	0
131710	130821	14033T	PARTICIPANT	\N	PRESENT	0
131711	130821	11101A	PARTICIPANT	\N	PRESENT	0
131712	130821	08058D	PARTICIPANT	\N	PRESENT	0
131713	130821	95063L	PARTICIPANT	\N	PRESENT	0
131714	130821	01047U	PARTICIPANT	\N	PRESENT	0
131715	130821	11100Y	PARTICIPANT	\N	PRESENT	0
131716	130821	01028R	PARTICIPANT	\N	PRESENT	0
131717	130821	14119M	PARTICIPANT	\N	PRESENT	0
131718	130821	14031R	PARTICIPANT	\N	PRESENT	0
131719	130821	11012A	PARTICIPANT	\N	PRESENT	0
131720	130821	14038Y	PARTICIPANT	\N	PRESENT	0
131721	130821	08017T	PARTICIPANT	\N	PRESENT	0
131722	130821	95035G	PARTICIPANT	\N	PRESENT	0
131723	130821	11064N	PARTICIPANT	\N	PRESENT	0
131724	130821	01013J	PARTICIPANT	\N	PRESENT	0
131725	130821	11098Y	PARTICIPANT	\N	PRESENT	0
131726	130821	11031D	PARTICIPANT	\N	PRESENT	0
131727	130821	05008E	PARTICIPANT	\N	PRESENT	0
131728	130821	01025N	PARTICIPANT	\N	PRESENT	0
131729	130821	11072N	PARTICIPANT	\N	PRESENT	0
131730	130821	11099A	PARTICIPANT	\N	PRESENT	0
131731	130821	14169X	PARTICIPANT	\N	PRESENT	0
131732	130821	07026Q	PARTICIPANT	\N	PRESENT	0
131733	130821	11080N	PARTICIPANT	\N	PRESENT	0
131734	130821	11107G	PARTICIPANT	\N	PRESENT	0
131735	130821	08055A	PARTICIPANT	\N	PRESENT	0
131736	130821	14259Y	PARTICIPANT	\N	PRESENT	0
131737	130821	01057W	PARTICIPANT	\N	PRESENT	0
131738	130821	11048N	PARTICIPANT	\N	PRESENT	0
131739	130821	08031R	PARTICIPANT	\N	PRESENT	0
131740	130821	14179A	PARTICIPANT	\N	PRESENT	0
131741	130821	14135M	PARTICIPANT	\N	PRESENT	0
131742	130821	01024M	PARTICIPANT	\N	PRESENT	0
131743	130821	08051V	PARTICIPANT	\N	PRESENT	0
131744	130821	11053K	PARTICIPANT	\N	PRESENT	0
131745	130821	04044E	PARTICIPANT	\N	PRESENT	0
131746	130821	14237S	PARTICIPANT	\N	PRESENT	0
131747	130821	14071N	PARTICIPANT	\N	PRESENT	0
131748	130821	14014Q	PARTICIPANT	\N	PRESENT	0
131749	130821	04067M	PARTICIPANT	\N	PRESENT	0
131750	130821	14257W	PARTICIPANT	\N	PRESENT	0
131755	130821	04045F	PARTICIPANT	\N	PRESENT	0
131771	130821	14133K	PARTICIPANT	\N	PRESENT	0
131780	130821	11112D	PARTICIPANT	\N	PRESENT	0
131783	130821	14097Y	PARTICIPANT	\N	PRESENT	0
150307	150258	14085U	PARTICIPANT	\N	PRESENT	0
150308	150258	08016S	PARTICIPANT	\N	PRESENT	0
150309	150258	01016M	PARTICIPANT	\N	PRESENT	0
150310	150258	04056J	PARTICIPANT	\N	PRESENT	0
150311	150258	14039A	PARTICIPANT	\N	PRESENT	0
150312	150258	92015P	PARTICIPANT	\N	PRESENT	0
150313	150258	04066L	PARTICIPANT	\N	PRESENT	0
150314	150258	11027H	PARTICIPANT	\N	PRESENT	0
150315	150258	14207L	PARTICIPANT	\N	PRESENT	0
150316	150258	12042Y	PARTICIPANT	\N	PRESENT	0
150317	150258	14151M	PARTICIPANT	\N	PRESENT	0
150318	150258	14028W	PARTICIPANT	\N	PRESENT	0
150319	150258	11036J	PARTICIPANT	\N	PRESENT	0
150320	150258	14001X	PARTICIPANT	\N	PRESENT	0
150321	150258	11084S	PARTICIPANT	\N	PRESENT	0
150322	150258	04050C	PARTICIPANT	\N	PRESENT	0
150323	150258	14065Q	PARTICIPANT	\N	PRESENT	0
150324	150258	98029W	PARTICIPANT	\N	PRESENT	0
150325	150258	11046L	PARTICIPANT	\N	PRESENT	0
150326	150258	08068F	PARTICIPANT	\N	PRESENT	0
150327	150258	04034C	PARTICIPANT	\N	PRESENT	0
150328	150258	95037J	PARTICIPANT	\N	PRESENT	0
150329	150258	08058D	PARTICIPANT	\N	PRESENT	0
150330	150258	11054L	PARTICIPANT	\N	PRESENT	0
150331	150258	11032E	PARTICIPANT	\N	PRESENT	0
150332	150258	14014Q	PARTICIPANT	\N	PRESENT	0
150333	150258	14257W	PARTICIPANT	\N	PRESENT	0
150334	150258	11039M	PARTICIPANT	\N	PRESENT	0
150335	150258	14281W	PARTICIPANT	\N	PRESENT	0
150336	150258	12041X	PARTICIPANT	\N	PRESENT	0
150337	150258	01059Y	PARTICIPANT	\N	PRESENT	0
150338	150258	04085P	PARTICIPANT	\N	PRESENT	0
150339	150258	04045F	PARTICIPANT	\N	PRESENT	0
150340	150258	80013X	PARTICIPANT	\N	PRESENT	0
150341	150258	14269B	PARTICIPANT	\N	PRESENT	0
150342	150258	11025F	PARTICIPANT	\N	PRESENT	0
150343	150258	14159V	PARTICIPANT	\N	PRESENT	0
150344	150258	01031L	PARTICIPANT	\N	PRESENT	0
150345	150258	11067R	PARTICIPANT	\N	PRESENT	0
150346	150258	11035H	PARTICIPANT	\N	PRESENT	0
150347	150258	08024S	PARTICIPANT	\N	PRESENT	0
150348	150258	11065P	PARTICIPANT	\N	PRESENT	0
150349	150258	14225N	PARTICIPANT	\N	PRESENT	0
150350	150258	01014K	PARTICIPANT	\N	PRESENT	0
150351	150258	08051V	PARTICIPANT	\N	PRESENT	0
150352	150258	04078Q	PARTICIPANT	\N	PRESENT	0
150353	150258	14018U	PARTICIPANT	\N	PRESENT	0
150354	150258	08031R	PARTICIPANT	\N	PRESENT	0
150355	150258	14229S	PARTICIPANT	\N	PRESENT	0
150356	150258	01025N	PARTICIPANT	\N	PRESENT	0
150357	150258	08009T	PARTICIPANT	\N	PRESENT	0
150358	150258	01047U	PARTICIPANT	\N	PRESENT	0
150359	150258	04070G	PARTICIPANT	\N	PRESENT	0
150360	150258	04089T	PARTICIPANT	\N	PRESENT	0
150361	150258	04040A	PARTICIPANT	\N	PRESENT	0
150362	150258	98042T	PARTICIPANT	\N	PRESENT	0
150363	150258	14179A	PARTICIPANT	\N	PRESENT	0
150364	150258	14231L	PARTICIPANT	\N	PRESENT	0
150365	150258	14103D	PARTICIPANT	\N	PRESENT	0
150366	150258	14030Q	PARTICIPANT	\N	PRESENT	0
150367	150258	14069U	PARTICIPANT	\N	PRESENT	0
150368	150258	11049P	PARTICIPANT	\N	PRESENT	0
150369	150258	98018T	PARTICIPANT	\N	PRESENT	0
150370	150258	95030B	PARTICIPANT	\N	PRESENT	0
150371	150258	04086Q	PARTICIPANT	\N	PRESENT	0
150372	150258	04033B	PARTICIPANT	\N	PRESENT	0
150373	150258	11068S	PARTICIPANT	\N	PRESENT	0
150374	150258	05008E	PARTICIPANT	\N	PRESENT	0
150375	150258	14087W	PARTICIPANT	\N	PRESENT	0
150376	150258	08034U	PARTICIPANT	\N	PRESENT	0
150377	150258	05004A	PARTICIPANT	\N	PRESENT	0
150378	150258	14071N	PARTICIPANT	\N	PRESENT	0
150379	150258	14193X	PARTICIPANT	\N	PRESENT	0
150380	150258	11080N	PARTICIPANT	\N	PRESENT	0
150384	150258	08019V	PARTICIPANT	\N	PRESENT	0
150382	150258	04061F	PARTICIPANT	\N	PRESENT	0
150383	150258	11014C	PARTICIPANT	\N	PRESENT	0
150385	150258	11081P	PARTICIPANT	\N	PRESENT	0
150386	150258	11103C	PARTICIPANT	\N	PRESENT	0
150387	150258	11090Q	PARTICIPANT	\N	PRESENT	0
150388	150258	14053L	PARTICIPANT	\N	PRESENT	0
150389	150258	14037X	PARTICIPANT	\N	PRESENT	0
150390	150258	14059S	PARTICIPANT	\N	PRESENT	0
150391	150258	14061L	PARTICIPANT	\N	PRESENT	0
150392	150258	11053K	PARTICIPANT	\N	PRESENT	0
150393	150258	04036E	PARTICIPANT	\N	PRESENT	0
150394	150258	14111D	PARTICIPANT	\N	PRESENT	0
150395	150258	99004R	PARTICIPANT	\N	PRESENT	0
150396	150258	01058X	PARTICIPANT	\N	PRESENT	0
150397	150258	08039A	PARTICIPANT	\N	PRESENT	0
150398	150258	01034P	PARTICIPANT	\N	PRESENT	0
150399	150258	08042U	PARTICIPANT	\N	PRESENT	0
150400	150258	14211G	PARTICIPANT	\N	PRESENT	0
150401	150258	04097T	PARTICIPANT	\N	PRESENT	0
150402	150258	95015C	PARTICIPANT	\N	PRESENT	0
150403	150258	95059Q	PARTICIPANT	\N	PRESENT	0
150404	150258	01056V	PARTICIPANT	\N	PRESENT	0
150405	150258	11043H	PARTICIPANT	\N	PRESENT	0
150406	150258	14135M	PARTICIPANT	\N	PRESENT	0
150407	150258	08010L	PARTICIPANT	\N	PRESENT	0
150408	150258	04071H	PARTICIPANT	\N	PRESENT	0
150409	150258	08043V	PARTICIPANT	\N	PRESENT	0
150410	150258	11074Q	PARTICIPANT	\N	PRESENT	0
150411	150258	01057W	PARTICIPANT	\N	PRESENT	0
150412	150258	87003B	PARTICIPANT	\N	PRESENT	0
150413	150258	11100Y	PARTICIPANT	\N	PRESENT	0
150414	150258	95067Q	PARTICIPANT	\N	PRESENT	0
150415	150258	98023Q	PARTICIPANT	\N	PRESENT	0
150416	150258	11011M	PARTICIPANT	\N	PRESENT	0
150417	150258	11048N	PARTICIPANT	\N	PRESENT	0
150418	150258	11010L	PARTICIPANT	\N	PRESENT	0
150419	150258	11093T	PARTICIPANT	\N	PRESENT	0
150420	150258	10006L	PARTICIPANT	\N	PRESENT	0
150421	150258	14173T	PARTICIPANT	\N	PRESENT	0
150422	150258	14195A	PARTICIPANT	\N	PRESENT	0
150423	150258	04049K	PARTICIPANT	\N	PRESENT	0
150424	150258	14147R	PARTICIPANT	\N	PRESENT	0
150425	150258	08048B	PARTICIPANT	\N	PRESENT	0
150426	150258	14175V	PARTICIPANT	\N	PRESENT	0
150427	150258	14119M	PARTICIPANT	\N	PRESENT	0
150428	150258	14038Y	PARTICIPANT	\N	PRESENT	0
150429	150258	07029T	PARTICIPANT	\N	PRESENT	0
150430	150258	11071M	PARTICIPANT	\N	PRESENT	0
150431	150258	08062Y	PARTICIPANT	\N	PRESENT	0
150432	150258	08015R	PARTICIPANT	\N	PRESENT	0
150433	150258	14213J	PARTICIPANT	\N	PRESENT	0
150434	150258	14237S	PARTICIPANT	\N	PRESENT	0
150435	150258	14249W	PARTICIPANT	\N	PRESENT	0
150452	150258	11112D	PARTICIPANT	\N	PRESENT	0
150453	150258	04057K	PARTICIPANT	\N	PRESENT	0
150472	150258	14209N	PARTICIPANT	\N	PRESENT	0
150473	150258	14026U	PARTICIPANT	\N	PRESENT	0
150474	150258	08022Q	PARTICIPANT	\N	PRESENT	0
150475	150258	14265W	PARTICIPANT	\N	PRESENT	0
150476	150258	11111C	PARTICIPANT	\N	PRESENT	0
150477	150258	08018U	PARTICIPANT	\N	PRESENT	0
150478	150258	14327T	PARTICIPANT	\N	PRESENT	0
150479	150258	90003B	PARTICIPANT	\N	PRESENT	0
150480	150258	14073Q	PARTICIPANT	\N	PRESENT	0
150481	150258	11064N	PARTICIPANT	\N	PRESENT	0
150482	150258	14221J	PARTICIPANT	\N	PRESENT	0
150484	150258	11085T	PARTICIPANT	\N	PRESENT	0
150485	150258	14219Q	PARTICIPANT	\N	PRESENT	0
150486	150258	05012A	PARTICIPANT	\N	PRESENT	0
130464	130175	14038Y	PARTICIPANT	\N	PRESENT	0
130465	130175	04045F	PARTICIPANT	\N	PRESENT	0
130466	130175	14121F	PARTICIPANT	\N	PRESENT	0
130467	130175	14103D	PARTICIPANT	\N	PRESENT	0
130468	130175	14231L	PARTICIPANT	\N	PRESENT	0
130469	130175	01047U	PARTICIPANT	\N	PRESENT	0
130470	130175	08048B	PARTICIPANT	\N	PRESENT	0
130471	130175	01003G	PARTICIPANT	\N	PRESENT	0
130472	130175	14217N	PARTICIPANT	\N	PRESENT	0
130473	130175	14219Q	PARTICIPANT	\N	PRESENT	0
130474	130175	95030B	PARTICIPANT	\N	PRESENT	0
130475	130175	01024M	PARTICIPANT	\N	PRESENT	0
130476	130175	14187A	PARTICIPANT	\N	PRESENT	0
130477	130175	14026U	PARTICIPANT	\N	PRESENT	0
130478	130175	11100Y	PARTICIPANT	\N	PRESENT	0
130479	130175	14033T	PARTICIPANT	\N	PRESENT	0
130481	130175	14063N	PARTICIPANT	\N	PRESENT	0
130482	130175	14201E	PARTICIPANT	\N	PRESENT	0
130483	130175	14249W	PARTICIPANT	\N	PRESENT	0
130484	130175	90003B	PARTICIPANT	\N	PRESENT	0
130485	130175	14073Q	PARTICIPANT	\N	PRESENT	0
130486	130175	04081K	PARTICIPANT	\N	PRESENT	0
130504	130175	08055A	PARTICIPANT	\N	PRESENT	0
130505	130175	11109J	PARTICIPANT	\N	PRESENT	0
130518	130175	80013X	PARTICIPANT	\N	PRESENT	0
130519	130175	08016S	PARTICIPANT	\N	PRESENT	0
130632	130176	11101A	PARTICIPANT	\N	PRESENT	0
130633	130176	14265W	PARTICIPANT	\N	PRESENT	0
130634	130176	04049K	PARTICIPANT	\N	PRESENT	0
130635	130176	14026U	PARTICIPANT	\N	PRESENT	0
130636	130176	11043H	PARTICIPANT	\N	PRESENT	0
130637	130176	14014Q	PARTICIPANT	\N	PRESENT	0
130638	130176	08060W	PARTICIPANT	\N	PRESENT	0
130639	130176	14121F	PARTICIPANT	\N	PRESENT	0
130640	130176	80013X	PARTICIPANT	\N	PRESENT	0
130641	130176	01003G	PARTICIPANT	\N	PRESENT	0
130642	130176	14219Q	PARTICIPANT	\N	PRESENT	0
130643	130176	14247U	PARTICIPANT	\N	PRESENT	0
130644	130176	07029T	PARTICIPANT	\N	PRESENT	0
130645	130176	10006L	PARTICIPANT	\N	PRESENT	0
130646	130176	11012A	PARTICIPANT	\N	PRESENT	0
130647	130176	14013P	PARTICIPANT	\N	PRESENT	0
130648	130176	11094U	PARTICIPANT	\N	PRESENT	0
130649	130176	04045F	PARTICIPANT	\N	PRESENT	0
130650	130176	14081Q	PARTICIPANT	\N	PRESENT	0
130651	130176	14063N	PARTICIPANT	\N	PRESENT	0
130652	130176	11099A	PARTICIPANT	\N	PRESENT	0
130653	130176	04059M	PARTICIPANT	\N	PRESENT	0
130654	130176	14187A	PARTICIPANT	\N	PRESENT	0
130655	130176	08068F	PARTICIPANT	\N	PRESENT	0
130656	130176	08038Y	PARTICIPANT	\N	PRESENT	0
130657	130176	11104D	PARTICIPANT	\N	PRESENT	0
130658	130176	11053K	PARTICIPANT	\N	PRESENT	0
130659	130176	14073Q	PARTICIPANT	\N	PRESENT	0
130660	130176	14249W	PARTICIPANT	\N	PRESENT	0
130661	130176	08062Y	PARTICIPANT	\N	PRESENT	0
130662	130176	11100Y	PARTICIPANT	\N	PRESENT	0
130663	130176	07024N	PARTICIPANT	\N	PRESENT	0
130664	130176	97011G	PARTICIPANT	\N	PRESENT	0
130665	130176	05012A	PARTICIPANT	\N	PRESENT	0
130666	130176	11036J	PARTICIPANT	\N	PRESENT	0
130667	130176	14257W	PARTICIPANT	\N	PRESENT	0
130668	130176	08014Q	PARTICIPANT	\N	PRESENT	0
130669	130176	92015P	PARTICIPANT	\N	PRESENT	0
130670	130176	11097X	PARTICIPANT	\N	PRESENT	0
130671	130176	14327T	PARTICIPANT	\N	PRESENT	0
130672	130176	14231L	PARTICIPANT	\N	PRESENT	0
130673	130176	11048N	PARTICIPANT	\N	PRESENT	0
130674	130176	14225N	PARTICIPANT	\N	PRESENT	0
130675	130176	08043V	PARTICIPANT	\N	PRESENT	0
130676	130176	14281W	PARTICIPANT	\N	PRESENT	0
130677	130176	14109K	PARTICIPANT	\N	PRESENT	0
130678	130176	14229S	PARTICIPANT	\N	PRESENT	0
130679	130176	14263U	PARTICIPANT	\N	PRESENT	0
130680	130176	14038Y	PARTICIPANT	\N	PRESENT	0
130682	130176	04088S	PARTICIPANT	\N	PRESENT	0
130683	130176	86044G	PARTICIPANT	\N	PRESENT	0
130684	130176	14071N	PARTICIPANT	\N	PRESENT	0
130685	130176	14173T	PARTICIPANT	\N	PRESENT	0
130686	130176	14119M	PARTICIPANT	\N	PRESENT	0
130687	130176	14028W	PARTICIPANT	\N	PRESENT	0
130688	130176	95063L	PARTICIPANT	\N	PRESENT	0
130689	130176	14030Q	PARTICIPANT	\N	PRESENT	0
130690	130176	14221J	PARTICIPANT	\N	PRESENT	0
130691	130176	08034U	PARTICIPANT	\N	PRESENT	0
130692	130176	14215L	PARTICIPANT	\N	PRESENT	0
130694	130176	04040A	PARTICIPANT	\N	PRESENT	0
130713	130176	14199E	PARTICIPANT	\N	PRESENT	0
130714	130176	11057P	PARTICIPANT	\N	PRESENT	0
130715	130176	14217N	PARTICIPANT	\N	PRESENT	0
130717	130176	13002U	PARTICIPANT	\N	PRESENT	0
130718	130176	14083S	PARTICIPANT	\N	PRESENT	0
130719	130176	01027Q	PARTICIPANT	\N	PRESENT	0
130720	130176	08010L	PARTICIPANT	\N	PRESENT	0
130721	130176	14205J	PARTICIPANT	\N	PRESENT	0
130771	130176	01028R	PARTICIPANT	\N	PRESENT	0
130772	130176	14269B	PARTICIPANT	\N	PRESENT	0
130774	130176	95030B	PARTICIPANT	\N	PRESENT	0
130775	130176	14179A	PARTICIPANT	\N	PRESENT	0
130597	130176	89029V	PARTICIPANT	\N	PRESENT	0
130631	130176	14033T	PARTICIPANT	\N	PRESENT	0
130776	130176	11112D	PARTICIPANT	\N	PRESENT	0
130777	130176	87003B	PARTICIPANT	\N	PRESENT	0
130778	130176	11111C	PARTICIPANT	\N	PRESENT	0
130787	130176	08017T	PARTICIPANT	\N	PRESENT	0
130788	130176	08048B	PARTICIPANT	\N	PRESENT	0
130789	130176	08015R	PARTICIPANT	\N	PRESENT	0
130790	130176	11090Q	PARTICIPANT	\N	PRESENT	0
130791	130176	14147R	PARTICIPANT	\N	PRESENT	0
130792	130176	08058D	PARTICIPANT	\N	PRESENT	0
130793	130176	08024S	PARTICIPANT	\N	PRESENT	0
130794	130176	01048V	PARTICIPANT	\N	PRESENT	0
130795	130176	11107G	PARTICIPANT	\N	PRESENT	0
130796	130176	14107H	PARTICIPANT	\N	PRESENT	0
130797	130176	98046X	PARTICIPANT	\N	PRESENT	0
130798	130176	11103C	PARTICIPANT	\N	PRESENT	0
130799	130176	14241N	PARTICIPANT	\N	PRESENT	0
130800	130176	01024M	PARTICIPANT	\N	PRESENT	0
130801	130176	14103D	PARTICIPANT	\N	PRESENT	0
130802	130176	11066Q	PARTICIPANT	\N	PRESENT	0
130804	130176	11105E	PARTICIPANT	\N	PRESENT	0
130808	130176	08055A	PARTICIPANT	\N	PRESENT	0
130809	130176	08016S	PARTICIPANT	\N	PRESENT	0
130810	130176	14197C	PARTICIPANT	\N	PRESENT	0
130811	130176	11042G	PARTICIPANT	\N	PRESENT	0
130812	130176	14157T	PARTICIPANT	\N	PRESENT	0
130813	130176	11098Y	PARTICIPANT	\N	PRESENT	0
130814	130176	01047U	PARTICIPANT	\N	PRESENT	0
130818	130176	89017R	PARTICIPANT	\N	PRESENT	0
130819	130176	14042U	PARTICIPANT	\N	PRESENT	0
131936	131873	01007L	PARTICIPANT	\N	PRESENT	0
131941	131873	11031D	PARTICIPANT	\N	PRESENT	0
131942	131873	11063M	PARTICIPANT	\N	PRESENT	0
131943	131873	11061K	PARTICIPANT	\N	PRESENT	0
131944	131873	08052W	PARTICIPANT	\N	PRESENT	0
131945	131873	14269B	PARTICIPANT	\N	PRESENT	0
131946	131873	14121F	PARTICIPANT	\N	PRESENT	0
131947	131873	14281W	PARTICIPANT	\N	PRESENT	0
131948	131873	11055M	PARTICIPANT	\N	PRESENT	0
131949	131873	11112D	PARTICIPANT	\N	PRESENT	0
131950	131873	14042U	PARTICIPANT	\N	PRESENT	0
131951	131873	11091R	PARTICIPANT	\N	PRESENT	0
131952	131873	01046T	PARTICIPANT	\N	PRESENT	0
131953	131873	04092N	PARTICIPANT	\N	PRESENT	0
131954	131873	04053F	PARTICIPANT	\N	PRESENT	0
131955	131873	08056B	PARTICIPANT	\N	PRESENT	0
131956	131873	14195A	PARTICIPANT	\N	PRESENT	0
131957	131873	01059Y	PARTICIPANT	\N	PRESENT	0
131958	131873	11012A	PARTICIPANT	\N	PRESENT	0
131959	131873	14213J	PARTICIPANT	\N	PRESENT	0
131960	131873	11097X	PARTICIPANT	\N	PRESENT	0
131961	131873	01011G	PARTICIPANT	\N	PRESENT	0
131962	131873	98022P	PARTICIPANT	\N	PRESENT	0
131963	131873	14201E	PARTICIPANT	\N	PRESENT	0
131969	131873	14119M	PARTICIPANT	\N	PRESENT	0
131970	131873	14209N	PARTICIPANT	\N	PRESENT	0
131971	131873	14219Q	PARTICIPANT	\N	PRESENT	0
131972	131873	14041T	PARTICIPANT	\N	PRESENT	0
131973	131873	14227Q	PARTICIPANT	\N	PRESENT	0
131974	131873	14105F	PARTICIPANT	\N	PRESENT	0
131975	131873	14241N	PARTICIPANT	\N	PRESENT	0
131986	131873	11100Y	PARTICIPANT	\N	PRESENT	0
131987	131873	14249W	PARTICIPANT	\N	PRESENT	0
131988	131873	14179A	PARTICIPANT	\N	PRESENT	0
131989	131873	14073Q	PARTICIPANT	\N	PRESENT	0
131990	131873	14089Y	PARTICIPANT	\N	PRESENT	0
131991	131873	14267Y	PARTICIPANT	\N	PRESENT	0
131992	131873	14069U	PARTICIPANT	\N	PRESENT	0
153982	152752	11104D	PARTICIPANT	\N	PRESENT	0
153983	152752	92039X	PARTICIPANT	\N	PRESENT	0
153984	152752	11070L	PARTICIPANT	\N	PRESENT	0
153985	152752	11053K	PARTICIPANT	\N	PRESENT	0
153986	152752	14041T	PARTICIPANT	\N	PRESENT	0
153987	152752	07029T	PARTICIPANT	\N	PRESENT	0
153988	152752	14175V	PARTICIPANT	\N	PRESENT	0
153989	152752	88008L	PARTICIPANT	\N	PRESENT	0
153990	152752	04086Q	PARTICIPANT	\N	PRESENT	0
153991	152752	01013J	PARTICIPANT	\N	PRESENT	0
153992	152752	08034U	PARTICIPANT	\N	PRESENT	0
153993	152752	01057W	PARTICIPANT	\N	PRESENT	0
153994	152752	14225N	PARTICIPANT	\N	PRESENT	0
154012	152752	01016M	PARTICIPANT	\N	PRESENT	0
154013	152752	11083R	PARTICIPANT	\N	PRESENT	0
154014	152752	11077T	PARTICIPANT	\N	PRESENT	0
154015	152752	14085U	PARTICIPANT	\N	PRESENT	0
154016	152752	98005N	PARTICIPANT	\N	PRESENT	0
154017	152752	11011M	PARTICIPANT	\N	PRESENT	0
154018	152752	14327T	PARTICIPANT	\N	PRESENT	0
154032	152752	01056V	PARTICIPANT	\N	PRESENT	0
154033	152752	98046X	PARTICIPANT	\N	PRESENT	0
154034	152752	04053F	PARTICIPANT	\N	PRESENT	0
154052	152752	04043D	PARTICIPANT	\N	PRESENT	0
154053	152752	11048N	PARTICIPANT	\N	PRESENT	0
154072	152752	04071H	PARTICIPANT	\N	PRESENT	0
154073	152752	99004R	PARTICIPANT	\N	PRESENT	0
154092	152752	14329V	PARTICIPANT	\N	PRESENT	0
154093	152752	14105F	PARTICIPANT	\N	PRESENT	0
154094	152752	80013X	PARTICIPANT	\N	PRESENT	0
154095	152752	08073C	PARTICIPANT	\N	PRESENT	0
154112	152752	11068S	PARTICIPANT	\N	PRESENT	0
154113	152752	04081K	PARTICIPANT	\N	PRESENT	0
154114	152752	11088W	PARTICIPANT	\N	PRESENT	0
154132	152752	11113E	PARTICIPANT	\N	PRESENT	0
154213	152753	14329V	PARTICIPANT	\N	PRESENT	0
154214	152753	07029T	PARTICIPANT	\N	PRESENT	0
154215	152753	14169X	PARTICIPANT	\N	PRESENT	0
153980	152752	04034C	PARTICIPANT	\N	PRESENT	0
153981	152752	04059M	PARTICIPANT	\N	PRESENT	0
154216	152753	08034U	PARTICIPANT	\N	PRESENT	0
154217	152753	14175V	PARTICIPANT	\N	PRESENT	0
154218	152753	07004J	PARTICIPANT	\N	PRESENT	0
154219	152753	98053W	PARTICIPANT	\N	PRESENT	0
154220	152753	99004R	PARTICIPANT	\N	PRESENT	0
154221	152753	04086Q	PARTICIPANT	\N	PRESENT	0
154222	152753	08011M	PARTICIPANT	\N	PRESENT	0
154223	152753	01031L	PARTICIPANT	\N	PRESENT	0
154224	152753	11104D	PARTICIPANT	\N	PRESENT	0
154225	152753	92039X	PARTICIPANT	\N	PRESENT	0
154226	152753	11083R	PARTICIPANT	\N	PRESENT	0
154227	152753	08017T	PARTICIPANT	\N	PRESENT	0
154228	152753	11057P	PARTICIPANT	\N	PRESENT	0
154229	152753	98046X	PARTICIPANT	\N	PRESENT	0
154230	152753	04034C	PARTICIPANT	\N	PRESENT	0
154231	152753	80013X	PARTICIPANT	\N	PRESENT	0
154232	152753	01057W	PARTICIPANT	\N	PRESENT	0
154233	152753	11088W	PARTICIPANT	\N	PRESENT	0
154234	152753	14215L	PARTICIPANT	\N	PRESENT	0
154235	152753	04059M	PARTICIPANT	\N	PRESENT	0
154252	152753	04071H	PARTICIPANT	\N	PRESENT	0
154253	152753	11070L	PARTICIPANT	\N	PRESENT	0
154272	152753	11053K	PARTICIPANT	\N	PRESENT	0
154273	152753	88008L	PARTICIPANT	\N	PRESENT	0
154274	152753	11048N	PARTICIPANT	\N	PRESENT	0
154275	152753	14037X	PARTICIPANT	\N	PRESENT	0
154276	152753	14225N	PARTICIPANT	\N	PRESENT	0
154277	152753	01016M	PARTICIPANT	\N	PRESENT	0
154203	152753	04081K	PARTICIPANT	\N	PRESENT	0
154212	152753	14041T	PARTICIPANT	\N	PRESENT	0
154278	152753	14105F	PARTICIPANT	\N	PRESENT	0
154279	152753	14085U	PARTICIPANT	\N	PRESENT	0
154292	152753	11113E	PARTICIPANT	\N	PRESENT	0
154293	152753	11077T	PARTICIPANT	\N	PRESENT	0
154294	152753	01056V	PARTICIPANT	\N	PRESENT	0
154295	152753	04035D	PARTICIPANT	\N	PRESENT	0
154296	152753	11011M	PARTICIPANT	\N	PRESENT	0
154297	152753	11065P	PARTICIPANT	\N	PRESENT	0
154303	152753	04043D	PARTICIPANT	\N	PRESENT	0
154304	152753	08018U	PARTICIPANT	\N	PRESENT	0
154312	152753	01048V	PARTICIPANT	\N	PRESENT	0
154313	152753	01041N	PARTICIPANT	\N	PRESENT	0
154314	152753	98005N	PARTICIPANT	\N	PRESENT	0
154332	152753	04053F	PARTICIPANT	\N	PRESENT	0
154333	152753	08073C	PARTICIPANT	\N	PRESENT	0
154334	152753	14039A	PARTICIPANT	\N	PRESENT	0
154354	152753	11085T	PARTICIPANT	\N	PRESENT	0
154372	152753	01028R	PARTICIPANT	\N	PRESENT	0
154473	152755	11057P	PARTICIPANT	\N	PRESENT	0
154474	152755	04034C	PARTICIPANT	\N	PRESENT	0
154475	152755	01016M	PARTICIPANT	\N	PRESENT	0
154476	152755	92039X	PARTICIPANT	\N	PRESENT	0
154477	152755	11077T	PARTICIPANT	\N	PRESENT	0
154478	152755	11113E	PARTICIPANT	\N	PRESENT	0
154479	152755	14085U	PARTICIPANT	\N	PRESENT	0
154480	152755	11083R	PARTICIPANT	\N	PRESENT	0
154481	152755	14041T	PARTICIPANT	\N	PRESENT	0
154482	152755	07029T	PARTICIPANT	\N	PRESENT	0
154483	152755	08011M	PARTICIPANT	\N	PRESENT	0
154484	152755	01031L	PARTICIPANT	\N	PRESENT	0
154485	152755	07004J	PARTICIPANT	\N	PRESENT	0
154486	152755	11070L	PARTICIPANT	\N	PRESENT	0
154487	152755	08034U	PARTICIPANT	\N	PRESENT	0
154488	152755	01057W	PARTICIPANT	\N	PRESENT	0
154489	152755	04071H	PARTICIPANT	\N	PRESENT	0
154490	152755	11048N	PARTICIPANT	\N	PRESENT	0
154491	152755	14175V	PARTICIPANT	\N	PRESENT	0
154492	152755	04086Q	PARTICIPANT	\N	PRESENT	0
154493	152755	11053K	PARTICIPANT	\N	PRESENT	0
154494	152755	88008L	PARTICIPANT	\N	PRESENT	0
154512	152755	04035D	PARTICIPANT	\N	PRESENT	0
154532	152755	11104D	PARTICIPANT	\N	PRESENT	0
154533	152755	08010L	PARTICIPANT	\N	PRESENT	0
154534	152755	98053W	PARTICIPANT	\N	PRESENT	0
154535	152755	80013X	PARTICIPANT	\N	PRESENT	0
154536	152755	04053F	PARTICIPANT	\N	PRESENT	0
154552	152755	08060W	PARTICIPANT	\N	PRESENT	0
154612	152755	08073C	PARTICIPANT	\N	PRESENT	0
154632	152755	14225N	PARTICIPANT	\N	PRESENT	0
154633	152755	01028R	PARTICIPANT	\N	PRESENT	0
154652	154352	04081K	PARTICIPANT	\N	PRESENT	0
154672	154352	08011M	PARTICIPANT	\N	PRESENT	0
154673	154352	01031L	PARTICIPANT	\N	PRESENT	0
154674	154352	11057P	PARTICIPANT	\N	PRESENT	0
154675	154352	98046X	PARTICIPANT	\N	PRESENT	0
154812	154353	04081K	PARTICIPANT	\N	PRESENT	0
154677	154352	01016M	PARTICIPANT	\N	PRESENT	0
154678	154352	14085U	PARTICIPANT	\N	PRESENT	0
154679	154352	11083R	PARTICIPANT	\N	PRESENT	0
154452	152755	11085T	PARTICIPANT	\N	PRESENT	0
154472	152755	98046X	PARTICIPANT	\N	PRESENT	0
154680	154352	01013J	PARTICIPANT	\N	PRESENT	0
154681	154352	07004J	PARTICIPANT	\N	PRESENT	0
154682	154352	14175V	PARTICIPANT	\N	PRESENT	0
154683	154352	07029T	PARTICIPANT	\N	PRESENT	0
154684	154352	01057W	PARTICIPANT	\N	PRESENT	0
154685	154352	14041T	PARTICIPANT	\N	PRESENT	0
154686	154352	08010L	PARTICIPANT	\N	PRESENT	0
154687	154352	04086Q	PARTICIPANT	\N	PRESENT	0
154688	154352	08073C	PARTICIPANT	\N	PRESENT	0
154689	154352	14225N	PARTICIPANT	\N	PRESENT	0
154690	154352	04034C	PARTICIPANT	\N	PRESENT	0
154691	154352	11011M	PARTICIPANT	\N	PRESENT	0
154692	154352	98005N	PARTICIPANT	\N	PRESENT	0
154712	154352	80013X	PARTICIPANT	\N	PRESENT	0
154713	154352	11109J	PARTICIPANT	\N	PRESENT	0
154714	154352	11088W	PARTICIPANT	\N	PRESENT	0
154715	154352	04053F	PARTICIPANT	\N	PRESENT	0
154716	154352	08060W	PARTICIPANT	\N	PRESENT	0
154732	154352	04085P	PARTICIPANT	\N	PRESENT	0
154733	154352	11053K	PARTICIPANT	\N	PRESENT	0
154734	154352	11097X	PARTICIPANT	\N	PRESENT	0
154735	154352	01048V	PARTICIPANT	\N	PRESENT	0
154752	154352	11113E	PARTICIPANT	\N	PRESENT	0
154753	154352	14039A	PARTICIPANT	\N	PRESENT	0
154823	154353	14041T	PARTICIPANT	\N	PRESENT	0
154773	154352	04035D	PARTICIPANT	\N	PRESENT	0
154792	154352	01027Q	PARTICIPANT	\N	PRESENT	0
154813	154353	08011M	PARTICIPANT	\N	PRESENT	0
154814	154353	01031L	PARTICIPANT	\N	PRESENT	0
154815	154353	01016M	PARTICIPANT	\N	PRESENT	0
154816	154353	14085U	PARTICIPANT	\N	PRESENT	0
154817	154353	11083R	PARTICIPANT	\N	PRESENT	0
154818	154353	01013J	PARTICIPANT	\N	PRESENT	0
154819	154353	07004J	PARTICIPANT	\N	PRESENT	0
154820	154353	14175V	PARTICIPANT	\N	PRESENT	0
154821	154353	07029T	PARTICIPANT	\N	PRESENT	0
131832	130822	08024S	PARTICIPANT	\N	PRESENT	0
131833	130822	98042T	PARTICIPANT	\N	PRESENT	0
131834	130822	04070G	PARTICIPANT	\N	PRESENT	0
131835	130822	07026Q	PARTICIPANT	\N	PRESENT	0
131836	130822	14235Q	PARTICIPANT	\N	PRESENT	0
131837	130822	12041X	PARTICIPANT	\N	PRESENT	0
131838	130822	11089X	PARTICIPANT	\N	PRESENT	0
131839	130822	08043V	PARTICIPANT	\N	PRESENT	0
131840	130822	01044R	PARTICIPANT	\N	PRESENT	0
132872	132871	04061F	PARTICIPANT	\N	PRESENT	0
131842	130822	14267Y	PARTICIPANT	\N	PRESENT	0
131843	130822	14089Y	PARTICIPANT	\N	PRESENT	0
131844	130822	14053L	PARTICIPANT	\N	PRESENT	0
131845	130822	14071N	PARTICIPANT	\N	PRESENT	0
131846	130822	14059S	PARTICIPANT	\N	PRESENT	0
131847	130822	14249W	PARTICIPANT	\N	PRESENT	0
131848	130822	14123H	PARTICIPANT	\N	PRESENT	0
131849	130823	08024S	PARTICIPANT	\N	PRESENT	0
131850	130823	98042T	PARTICIPANT	\N	PRESENT	0
131851	130823	04070G	PARTICIPANT	\N	PRESENT	0
131852	130823	07026Q	PARTICIPANT	\N	PRESENT	0
131853	130823	14235Q	PARTICIPANT	\N	PRESENT	0
131854	130823	12041X	PARTICIPANT	\N	PRESENT	0
131855	130823	11089X	PARTICIPANT	\N	PRESENT	0
131856	130823	08043V	PARTICIPANT	\N	PRESENT	0
131857	130823	01044R	PARTICIPANT	\N	PRESENT	0
131858	130823	11029K	PARTICIPANT	\N	PRESENT	0
131859	130823	14267Y	PARTICIPANT	\N	PRESENT	0
131860	130823	14089Y	PARTICIPANT	\N	PRESENT	0
131861	130823	14053L	PARTICIPANT	\N	PRESENT	0
131862	130823	14071N	PARTICIPANT	\N	PRESENT	0
131863	130823	14059S	PARTICIPANT	\N	PRESENT	0
131864	130823	14249W	PARTICIPANT	\N	PRESENT	0
131865	130823	14123H	PARTICIPANT	\N	PRESENT	0
131866	130823	01034P	PARTICIPANT	\N	PRESENT	0
131867	130823	14073Q	PARTICIPANT	\N	PRESENT	0
131868	130823	04057K	PARTICIPANT	\N	PRESENT	0
131869	130823	14031R	PARTICIPANT	\N	PRESENT	0
131870	130823	80013X	PARTICIPANT	\N	PRESENT	0
131871	130823	14197C	PARTICIPANT	\N	PRESENT	0
131872	130823	08017T	PARTICIPANT	\N	PRESENT	0
131878	130823	11061K	PARTICIPANT	\N	PRESENT	0
131879	130823	14014Q	PARTICIPANT	\N	PRESENT	0
131880	130823	08012N	PARTICIPANT	\N	PRESENT	0
131881	130823	04045F	PARTICIPANT	\N	PRESENT	0
131882	130823	14069U	PARTICIPANT	\N	PRESENT	0
131883	130823	08051V	PARTICIPANT	\N	PRESENT	0
131884	130823	14119M	PARTICIPANT	\N	PRESENT	0
131885	130823	14261S	PARTICIPANT	\N	PRESENT	0
131886	130823	11068S	PARTICIPANT	\N	PRESENT	0
131887	130823	14061L	PARTICIPANT	\N	PRESENT	0
131888	130823	01059Y	PARTICIPANT	\N	PRESENT	0
131892	130823	14105F	PARTICIPANT	\N	PRESENT	0
131893	130823	14033T	PARTICIPANT	\N	PRESENT	0
131894	130823	14331P	PARTICIPANT	\N	PRESENT	0
131895	130823	11036J	PARTICIPANT	\N	PRESENT	0
131896	130823	14179A	PARTICIPANT	\N	PRESENT	0
131897	130823	04033B	PARTICIPANT	\N	PRESENT	0
131898	130823	11012A	PARTICIPANT	\N	PRESENT	0
131899	130823	14265W	PARTICIPANT	\N	PRESENT	0
132870	132869	01031L	PARTICIPANT	\N	PRESENT	0
132882	132881	11074Q	PARTICIPANT	\N	PRESENT	0
132883	132881	11083R	PARTICIPANT	\N	PRESENT	0
133421	133126	86034E	PARTICIPANT	\N	PRESENT	0
133423	133126	11063M	PARTICIPANT	\N	PRESENT	0
133424	133126	14235Q	PARTICIPANT	\N	PRESENT	0
133425	133126	98053W	PARTICIPANT	\N	PRESENT	0
133426	133126	01059Y	PARTICIPANT	\N	PRESENT	0
133427	133126	07026Q	PARTICIPANT	\N	PRESENT	0
133428	133126	12041X	PARTICIPANT	\N	PRESENT	0
133429	133126	14013P	PARTICIPANT	\N	PRESENT	0
133430	133126	11031D	PARTICIPANT	\N	PRESENT	0
133431	133126	01015L	PARTICIPANT	\N	PRESENT	0
133432	133126	04067M	PARTICIPANT	\N	PRESENT	0
133433	133126	11076S	PARTICIPANT	\N	PRESENT	0
133434	133126	95062K	PARTICIPANT	\N	PRESENT	0
133435	133126	01044R	PARTICIPANT	\N	PRESENT	0
133436	133126	11029K	PARTICIPANT	\N	PRESENT	0
133437	133126	11033F	PARTICIPANT	\N	PRESENT	0
133438	133126	04097T	PARTICIPANT	\N	PRESENT	0
133439	133126	11083R	PARTICIPANT	\N	PRESENT	0
133440	133126	04036E	PARTICIPANT	\N	PRESENT	0
133441	133126	01027Q	PARTICIPANT	\N	PRESENT	0
133442	133126	04085P	PARTICIPANT	\N	PRESENT	0
133443	133126	04050C	PARTICIPANT	\N	PRESENT	0
133444	133126	14211G	PARTICIPANT	\N	PRESENT	0
133445	133126	01013J	PARTICIPANT	\N	PRESENT	0
133446	133126	01058X	PARTICIPANT	\N	PRESENT	0
133447	133126	96004D	PARTICIPANT	\N	PRESENT	0
133448	133126	95031C	PARTICIPANT	\N	PRESENT	0
133449	133126	04041B	PARTICIPANT	\N	PRESENT	0
133450	133126	14169X	PARTICIPANT	\N	PRESENT	0
133451	133126	87003B	PARTICIPANT	\N	PRESENT	0
133452	133126	99004R	PARTICIPANT	\N	PRESENT	0
133453	133126	04086Q	PARTICIPANT	\N	PRESENT	0
133454	133126	86044G	PARTICIPANT	\N	PRESENT	0
133455	133126	08022Q	PARTICIPANT	\N	PRESENT	0
133456	133126	14026U	PARTICIPANT	\N	PRESENT	0
133457	133126	11099A	PARTICIPANT	\N	PRESENT	0
133458	133126	95015C	PARTICIPANT	\N	PRESENT	0
133459	133126	01046T	PARTICIPANT	\N	PRESENT	0
133460	133126	14133K	PARTICIPANT	\N	PRESENT	0
133461	133126	04078Q	PARTICIPANT	\N	PRESENT	0
133462	133126	14105F	PARTICIPANT	\N	PRESENT	0
133463	133126	14033T	PARTICIPANT	\N	PRESENT	0
133464	133126	14018U	PARTICIPANT	\N	PRESENT	0
133465	133126	11010L	PARTICIPANT	\N	PRESENT	0
133466	133126	01003G	PARTICIPANT	\N	PRESENT	0
133467	133126	08034U	PARTICIPANT	\N	PRESENT	0
133468	133126	11081P	PARTICIPANT	\N	PRESENT	0
133469	133126	14038Y	PARTICIPANT	\N	PRESENT	0
133470	133126	14201E	PARTICIPANT	\N	PRESENT	0
133471	133126	14173T	PARTICIPANT	\N	PRESENT	0
133472	133126	14261S	PARTICIPANT	\N	PRESENT	0
133473	133126	98005N	PARTICIPANT	\N	PRESENT	0
133474	133126	14239U	PARTICIPANT	\N	PRESENT	0
133475	133126	98022P	PARTICIPANT	\N	PRESENT	0
133476	133126	07029T	PARTICIPANT	\N	PRESENT	0
133477	133126	14135M	PARTICIPANT	\N	PRESENT	0
133478	133126	08047A	PARTICIPANT	\N	PRESENT	0
133479	133126	11097X	PARTICIPANT	\N	PRESENT	0
133480	133126	08016S	PARTICIPANT	\N	PRESENT	0
133481	133126	14147R	PARTICIPANT	\N	PRESENT	0
133482	133126	98035U	PARTICIPANT	\N	PRESENT	0
133483	133126	04056J	PARTICIPANT	\N	PRESENT	0
133484	133126	04081K	PARTICIPANT	\N	PRESENT	0
133485	133126	95067Q	PARTICIPANT	\N	PRESENT	0
133486	133126	92015P	PARTICIPANT	\N	PRESENT	0
133487	133126	08055A	PARTICIPANT	\N	PRESENT	0
133488	133126	05012A	PARTICIPANT	\N	PRESENT	0
133489	133126	01031L	PARTICIPANT	\N	PRESENT	0
133490	133126	11103C	PARTICIPANT	\N	PRESENT	0
133491	133126	04066L	PARTICIPANT	\N	PRESENT	0
133492	133126	04092N	PARTICIPANT	\N	PRESENT	0
133493	133126	14223L	PARTICIPANT	\N	PRESENT	0
133494	133126	11057P	PARTICIPANT	\N	PRESENT	0
133495	133126	11090Q	PARTICIPANT	\N	PRESENT	0
133496	133126	14197C	PARTICIPANT	\N	PRESENT	0
133497	133126	14187A	PARTICIPANT	\N	PRESENT	0
133498	133126	14028W	PARTICIPANT	\N	PRESENT	0
133499	133126	98050T	PARTICIPANT	\N	PRESENT	0
133500	133126	80013X	PARTICIPANT	\N	PRESENT	0
133501	133126	92020L	PARTICIPANT	\N	PRESENT	0
133502	133126	14209N	PARTICIPANT	\N	PRESENT	0
133503	133126	14229S	PARTICIPANT	\N	PRESENT	0
133504	133126	07034Q	PARTICIPANT	\N	PRESENT	0
133505	133126	08043V	PARTICIPANT	\N	PRESENT	0
133506	133126	14107H	PARTICIPANT	\N	PRESENT	0
133507	133126	14059S	PARTICIPANT	\N	PRESENT	0
133508	133126	08012N	PARTICIPANT	\N	PRESENT	0
133509	133126	95041E	PARTICIPANT	\N	PRESENT	0
133510	133126	14249W	PARTICIPANT	\N	PRESENT	0
133511	133126	14217N	PARTICIPANT	\N	PRESENT	0
133512	133126	80027E	PARTICIPANT	\N	PRESENT	0
133513	133126	01057W	PARTICIPANT	\N	PRESENT	0
133514	133126	11059R	PARTICIPANT	\N	PRESENT	0
133515	133126	95030B	PARTICIPANT	\N	PRESENT	0
133516	133126	11080N	PARTICIPANT	\N	PRESENT	0
133517	133126	08058D	PARTICIPANT	\N	PRESENT	0
133518	133126	95035G	PARTICIPANT	\N	PRESENT	0
133519	133126	14237S	PARTICIPANT	\N	PRESENT	0
133520	133126	04043D	PARTICIPANT	\N	PRESENT	0
133521	133126	04034C	PARTICIPANT	\N	PRESENT	0
133522	133126	04074L	PARTICIPANT	\N	PRESENT	0
133523	133126	08053X	PARTICIPANT	\N	PRESENT	0
133524	133126	83042R	PARTICIPANT	\N	PRESENT	0
133525	133126	14087W	PARTICIPANT	\N	PRESENT	0
133526	133126	11042G	PARTICIPANT	\N	PRESENT	0
150680	149473	01015L	PARTICIPANT	\N	PRESENT	0
150681	149473	01022K	PARTICIPANT	\N	PRESENT	0
150682	149473	80013X	PARTICIPANT	\N	PRESENT	0
150683	149473	14063N	PARTICIPANT	\N	PRESENT	0
150684	149473	14257W	PARTICIPANT	\N	PRESENT	0
150685	149473	11042G	PARTICIPANT	\N	PRESENT	0
150686	149473	14197C	PARTICIPANT	\N	PRESENT	0
150687	149473	01016M	PARTICIPANT	\N	PRESENT	0
150688	149473	14281W	PARTICIPANT	\N	PRESENT	0
150689	149473	14107H	PARTICIPANT	\N	PRESENT	0
150690	149473	14014Q	PARTICIPANT	\N	PRESENT	0
150691	149473	13002U	PARTICIPANT	\N	PRESENT	0
150692	149473	11065P	PARTICIPANT	\N	PRESENT	0
150693	149473	01044R	PARTICIPANT	\N	PRESENT	0
150697	149473	04067M	PARTICIPANT	\N	PRESENT	0
150698	149473	08017T	PARTICIPANT	\N	PRESENT	0
150699	149473	14201E	PARTICIPANT	\N	PRESENT	0
150700	149473	14327T	PARTICIPANT	\N	PRESENT	0
150701	149473	14219Q	PARTICIPANT	\N	PRESENT	0
150702	149473	14179A	PARTICIPANT	\N	PRESENT	0
150703	149473	11093T	PARTICIPANT	\N	PRESENT	0
150704	149473	08055A	PARTICIPANT	\N	PRESENT	0
150705	149473	14073Q	PARTICIPANT	\N	PRESENT	0
150706	149473	11111C	PARTICIPANT	\N	PRESENT	0
150707	149473	11053K	PARTICIPANT	\N	PRESENT	0
150708	149473	04089T	PARTICIPANT	\N	PRESENT	0
150709	149473	01008M	PARTICIPANT	\N	PRESENT	0
150710	149473	08022Q	PARTICIPANT	\N	PRESENT	0
150711	149473	14069U	PARTICIPANT	\N	PRESENT	0
150712	149473	90003B	PARTICIPANT	\N	PRESENT	0
150713	149473	05012A	PARTICIPANT	\N	PRESENT	0
150714	149473	11103C	PARTICIPANT	\N	PRESENT	0
150715	149473	08042U	PARTICIPANT	\N	PRESENT	0
150716	149473	08048B	PARTICIPANT	\N	PRESENT	0
150717	149473	95067Q	PARTICIPANT	\N	PRESENT	0
150718	149473	14265W	PARTICIPANT	\N	PRESENT	0
150719	149473	14175V	PARTICIPANT	\N	PRESENT	0
150720	149473	14041T	PARTICIPANT	\N	PRESENT	0
150721	149473	04088S	PARTICIPANT	\N	PRESENT	0
150723	149473	11101A	PARTICIPANT	\N	PRESENT	0
150725	149473	14199E	PARTICIPANT	\N	PRESENT	0
150726	149473	14031R	PARTICIPANT	\N	PRESENT	0
150727	149473	04049K	PARTICIPANT	\N	PRESENT	0
150728	149473	11097X	PARTICIPANT	\N	PRESENT	0
150729	149473	11036J	PARTICIPANT	\N	PRESENT	0
150730	149473	14061L	PARTICIPANT	\N	PRESENT	0
150731	149473	14111D	PARTICIPANT	\N	PRESENT	0
150732	149473	11043H	PARTICIPANT	\N	PRESENT	0
150733	149473	14030Q	PARTICIPANT	\N	PRESENT	0
150734	149473	08031R	PARTICIPANT	\N	PRESENT	0
150735	149473	14018U	PARTICIPANT	\N	PRESENT	0
150736	149473	11081P	PARTICIPANT	\N	PRESENT	0
150737	149473	11056N	PARTICIPANT	\N	PRESENT	0
150738	149473	14038Y	PARTICIPANT	\N	PRESENT	0
150739	149473	14173T	PARTICIPANT	\N	PRESENT	0
150740	149473	14051J	PARTICIPANT	\N	PRESENT	0
150741	149473	14157T	PARTICIPANT	\N	PRESENT	0
150742	149473	14135M	PARTICIPANT	\N	PRESENT	0
150743	149473	92045V	PARTICIPANT	\N	PRESENT	0
150744	149473	11066Q	PARTICIPANT	\N	PRESENT	0
150745	149473	08009T	PARTICIPANT	\N	PRESENT	0
150746	149473	14237S	PARTICIPANT	\N	PRESENT	0
150747	149473	08062Y	PARTICIPANT	\N	PRESENT	0
150752	149473	14103D	PARTICIPANT	\N	PRESENT	0
150753	149473	11098Y	PARTICIPANT	\N	PRESENT	0
150754	149473	14235Q	PARTICIPANT	\N	PRESENT	0
150772	149473	04053F	PARTICIPANT	\N	PRESENT	0
150773	149473	92015P	PARTICIPANT	\N	PRESENT	0
150792	149473	14231L	PARTICIPANT	\N	PRESENT	0
150793	149473	14026U	PARTICIPANT	\N	PRESENT	0
150812	149473	14225N	PARTICIPANT	\N	PRESENT	0
150813	149473	14042U	PARTICIPANT	\N	PRESENT	0
150832	149473	14269B	PARTICIPANT	\N	PRESENT	0
150833	149473	04043D	PARTICIPANT	\N	PRESENT	0
150834	149473	07029T	PARTICIPANT	\N	PRESENT	0
150835	149473	08051V	PARTICIPANT	\N	PRESENT	0
150836	149473	11089X	PARTICIPANT	\N	PRESENT	0
150837	149473	14159V	PARTICIPANT	\N	PRESENT	0
150838	149473	14119M	PARTICIPANT	\N	PRESENT	0
150839	149473	01003G	PARTICIPANT	\N	PRESENT	0
150840	149473	14079W	PARTICIPANT	\N	PRESENT	0
150841	149473	14207L	PARTICIPANT	\N	PRESENT	0
150842	149473	14331P	PARTICIPANT	\N	PRESENT	0
150843	149473	14097Y	PARTICIPANT	\N	PRESENT	0
150844	149473	14187A	PARTICIPANT	\N	PRESENT	0
150852	149473	04057K	PARTICIPANT	\N	PRESENT	0
150953	149474	14051J	PARTICIPANT	\N	PRESENT	0
150954	149474	14001X	PARTICIPANT	\N	PRESENT	0
150955	149474	14207L	PARTICIPANT	\N	PRESENT	0
150956	149474	04045F	PARTICIPANT	\N	PRESENT	0
150957	149474	04053F	PARTICIPANT	\N	PRESENT	0
150958	149474	14014Q	PARTICIPANT	\N	PRESENT	0
150959	149474	11012A	PARTICIPANT	\N	PRESENT	0
150960	149474	01003G	PARTICIPANT	\N	PRESENT	0
150961	149474	14103D	PARTICIPANT	\N	PRESENT	0
150962	149474	14327T	PARTICIPANT	\N	PRESENT	0
150963	149474	14179A	PARTICIPANT	\N	PRESENT	0
150964	149474	04061F	PARTICIPANT	\N	PRESENT	0
150965	149474	96004D	PARTICIPANT	\N	PRESENT	0
150966	149474	14059S	PARTICIPANT	\N	PRESENT	0
150967	149474	14187A	PARTICIPANT	\N	PRESENT	0
150968	149474	14026U	PARTICIPANT	\N	PRESENT	0
150969	149474	04057K	PARTICIPANT	\N	PRESENT	0
150970	149474	14079W	PARTICIPANT	\N	PRESENT	0
150971	149474	01008M	PARTICIPANT	\N	PRESENT	0
150972	149474	14265W	PARTICIPANT	\N	PRESENT	0
150973	149474	04088S	PARTICIPANT	\N	PRESENT	0
150974	149474	14041T	PARTICIPANT	\N	PRESENT	0
150975	149474	14135M	PARTICIPANT	\N	PRESENT	0
150976	149474	14195A	PARTICIPANT	\N	PRESENT	0
150977	149474	14157T	PARTICIPANT	\N	PRESENT	0
150978	149474	14119M	PARTICIPANT	\N	PRESENT	0
150979	149474	04097T	PARTICIPANT	\N	PRESENT	0
150980	149474	14147R	PARTICIPANT	\N	PRESENT	0
150981	149474	14215L	PARTICIPANT	\N	PRESENT	0
150982	149474	04080J	PARTICIPANT	\N	PRESENT	0
150983	149474	11048N	PARTICIPANT	\N	PRESENT	0
150984	149474	11097X	PARTICIPANT	\N	PRESENT	0
150985	149474	14073Q	PARTICIPANT	\N	PRESENT	0
150986	149474	14237S	PARTICIPANT	\N	PRESENT	0
150987	149474	11083R	PARTICIPANT	\N	PRESENT	0
150988	149474	04054G	PARTICIPANT	\N	PRESENT	0
150989	149474	95030B	PARTICIPANT	\N	PRESENT	0
150990	149474	95059Q	PARTICIPANT	\N	PRESENT	0
150992	149474	01016M	PARTICIPANT	\N	PRESENT	0
150993	149474	97011G	PARTICIPANT	\N	PRESENT	0
150994	149474	07024N	PARTICIPANT	\N	PRESENT	0
151014	149474	14097Y	PARTICIPANT	\N	PRESENT	0
151015	149474	10015M	PARTICIPANT	\N	PRESENT	0
151016	149474	87003B	PARTICIPANT	\N	PRESENT	0
151017	149474	08069G	PARTICIPANT	\N	PRESENT	0
151018	149474	14061L	PARTICIPANT	\N	PRESENT	0
151019	149474	01060R	PARTICIPANT	\N	PRESENT	0
151020	149474	01058X	PARTICIPANT	\N	PRESENT	0
151032	149474	08014Q	PARTICIPANT	\N	PRESENT	0
151033	149474	11114F	PARTICIPANT	\N	PRESENT	0
151034	149474	13002U	PARTICIPANT	\N	PRESENT	0
151035	149474	98053W	PARTICIPANT	\N	PRESENT	0
151036	149474	01031L	PARTICIPANT	\N	PRESENT	0
151037	149474	14033T	PARTICIPANT	\N	PRESENT	0
151038	149474	14089Y	PARTICIPANT	\N	PRESENT	0
151052	149475	08009T	PARTICIPANT	\N	PRESENT	0
151053	149475	08055A	PARTICIPANT	\N	PRESENT	0
151054	149475	01008M	PARTICIPANT	\N	PRESENT	0
151055	149475	14265W	PARTICIPANT	\N	PRESENT	0
151056	149475	01059Y	PARTICIPANT	\N	PRESENT	0
151057	149475	92018S	PARTICIPANT	\N	PRESENT	0
151058	149475	11098Y	PARTICIPANT	\N	PRESENT	0
151059	149475	01016M	PARTICIPANT	\N	PRESENT	0
151060	149475	14107H	PARTICIPANT	\N	PRESENT	0
151061	149475	14197C	PARTICIPANT	\N	PRESENT	0
151062	149475	14175V	PARTICIPANT	\N	PRESENT	0
151063	149475	11100Y	PARTICIPANT	\N	PRESENT	0
151064	149475	11043H	PARTICIPANT	\N	PRESENT	0
151065	149475	14187A	PARTICIPANT	\N	PRESENT	0
151066	149475	11097X	PARTICIPANT	\N	PRESENT	0
150667	149473	08024S	PARTICIPANT	\N	PRESENT	0
150679	149473	01059Y	PARTICIPANT	\N	PRESENT	0
150942	149474	08024S	PARTICIPANT	\N	PRESENT	0
150952	149474	14263U	PARTICIPANT	\N	PRESENT	0
151067	149475	11065P	PARTICIPANT	\N	PRESENT	0
151068	149475	14327T	PARTICIPANT	\N	PRESENT	0
151069	149475	14219Q	PARTICIPANT	\N	PRESENT	0
151070	149475	14179A	PARTICIPANT	\N	PRESENT	0
151071	149475	14267Y	PARTICIPANT	\N	PRESENT	0
151072	149475	04088S	PARTICIPANT	\N	PRESENT	0
151073	149475	14069U	PARTICIPANT	\N	PRESENT	0
151074	149475	12042Y	PARTICIPANT	\N	PRESENT	0
131993	131873	08069G	PARTICIPANT	\N	PRESENT	0
131994	131873	08017T	PARTICIPANT	\N	PRESENT	0
131995	131873	04045F	PARTICIPANT	\N	PRESENT	0
131996	131873	14109K	PARTICIPANT	\N	PRESENT	0
131997	131873	98005N	PARTICIPANT	\N	PRESENT	0
131998	131873	10006L	PARTICIPANT	\N	PRESENT	0
131999	131873	08010L	PARTICIPANT	\N	PRESENT	0
132000	131873	14223L	PARTICIPANT	\N	PRESENT	0
132001	131873	04086Q	PARTICIPANT	\N	PRESENT	0
132002	131873	11109J	PARTICIPANT	\N	PRESENT	0
132003	131873	11113E	PARTICIPANT	\N	PRESENT	0
132004	131873	14097Y	PARTICIPANT	\N	PRESENT	0
132005	131873	14107H	PARTICIPANT	\N	PRESENT	0
132006	131873	11027H	PARTICIPANT	\N	PRESENT	0
132007	131873	14261S	PARTICIPANT	\N	PRESENT	0
132008	131873	14031R	PARTICIPANT	\N	PRESENT	0
132009	131873	08043V	PARTICIPANT	\N	PRESENT	0
132010	131873	14221J	PARTICIPANT	\N	PRESENT	0
132011	131873	11042G	PARTICIPANT	\N	PRESENT	0
132012	131873	14207L	PARTICIPANT	\N	PRESENT	0
132013	131873	14030Q	PARTICIPANT	\N	PRESENT	0
132014	131873	80013X	PARTICIPANT	\N	PRESENT	0
132015	131873	14033T	PARTICIPANT	\N	PRESENT	0
132016	131873	07029T	PARTICIPANT	\N	PRESENT	0
132017	131873	08034U	PARTICIPANT	\N	PRESENT	0
132018	131873	14157T	PARTICIPANT	\N	PRESENT	0
132019	131873	08015R	PARTICIPANT	\N	PRESENT	0
132037	131873	11036J	PARTICIPANT	\N	PRESENT	0
132039	131874	01007L	PARTICIPANT	\N	PRESENT	0
132040	131874	11031D	PARTICIPANT	\N	PRESENT	0
132041	131874	11063M	PARTICIPANT	\N	PRESENT	0
132042	131874	11061K	PARTICIPANT	\N	PRESENT	0
132043	131874	08052W	PARTICIPANT	\N	PRESENT	0
132044	131874	14269B	PARTICIPANT	\N	PRESENT	0
132045	131874	14121F	PARTICIPANT	\N	PRESENT	0
132046	131874	14281W	PARTICIPANT	\N	PRESENT	0
132047	131874	11055M	PARTICIPANT	\N	PRESENT	0
132048	131874	11112D	PARTICIPANT	\N	PRESENT	0
132049	131874	14042U	PARTICIPANT	\N	PRESENT	0
132050	131874	11091R	PARTICIPANT	\N	PRESENT	0
132051	131874	01046T	PARTICIPANT	\N	PRESENT	0
132052	131874	04092N	PARTICIPANT	\N	PRESENT	0
132053	131874	04053F	PARTICIPANT	\N	PRESENT	0
132054	131874	08056B	PARTICIPANT	\N	PRESENT	0
132055	131874	14195A	PARTICIPANT	\N	PRESENT	0
132056	131874	01059Y	PARTICIPANT	\N	PRESENT	0
132057	131874	11012A	PARTICIPANT	\N	PRESENT	0
132058	131874	14213J	PARTICIPANT	\N	PRESENT	0
132059	131874	11097X	PARTICIPANT	\N	PRESENT	0
132060	131874	01011G	PARTICIPANT	\N	PRESENT	0
132061	131874	14201E	PARTICIPANT	\N	PRESENT	0
132062	131874	14119M	PARTICIPANT	\N	PRESENT	0
132063	131874	14209N	PARTICIPANT	\N	PRESENT	0
132064	131874	14219Q	PARTICIPANT	\N	PRESENT	0
132065	131874	14041T	PARTICIPANT	\N	PRESENT	0
132066	131874	14227Q	PARTICIPANT	\N	PRESENT	0
132067	131874	14105F	PARTICIPANT	\N	PRESENT	0
132068	131874	14241N	PARTICIPANT	\N	PRESENT	0
132069	131874	11100Y	PARTICIPANT	\N	PRESENT	0
132070	131874	14179A	PARTICIPANT	\N	PRESENT	0
132071	131874	14073Q	PARTICIPANT	\N	PRESENT	0
132072	131874	14089Y	PARTICIPANT	\N	PRESENT	0
132073	131874	14267Y	PARTICIPANT	\N	PRESENT	0
132074	131874	14069U	PARTICIPANT	\N	PRESENT	0
132075	131874	08069G	PARTICIPANT	\N	PRESENT	0
132076	131874	08017T	PARTICIPANT	\N	PRESENT	0
132077	131874	04045F	PARTICIPANT	\N	PRESENT	0
132078	131874	14109K	PARTICIPANT	\N	PRESENT	0
132079	131874	98005N	PARTICIPANT	\N	PRESENT	0
132080	131874	10006L	PARTICIPANT	\N	PRESENT	0
132081	131874	08010L	PARTICIPANT	\N	PRESENT	0
132082	131874	14223L	PARTICIPANT	\N	PRESENT	0
132083	131874	04086Q	PARTICIPANT	\N	PRESENT	0
132084	131874	11109J	PARTICIPANT	\N	PRESENT	0
132085	131874	11113E	PARTICIPANT	\N	PRESENT	0
132086	131874	14097Y	PARTICIPANT	\N	PRESENT	0
132087	131874	14107H	PARTICIPANT	\N	PRESENT	0
132088	131874	11027H	PARTICIPANT	\N	PRESENT	0
132089	131874	14261S	PARTICIPANT	\N	PRESENT	0
132090	131874	14031R	PARTICIPANT	\N	PRESENT	0
132091	131874	08043V	PARTICIPANT	\N	PRESENT	0
132092	131874	14221J	PARTICIPANT	\N	PRESENT	0
132093	131874	11042G	PARTICIPANT	\N	PRESENT	0
132094	131874	14207L	PARTICIPANT	\N	PRESENT	0
132095	131874	14030Q	PARTICIPANT	\N	PRESENT	0
132096	131874	80013X	PARTICIPANT	\N	PRESENT	0
132097	131874	14033T	PARTICIPANT	\N	PRESENT	0
132098	131874	07029T	PARTICIPANT	\N	PRESENT	0
132099	131874	08034U	PARTICIPANT	\N	PRESENT	0
132100	131874	14157T	PARTICIPANT	\N	PRESENT	0
132101	131874	08015R	PARTICIPANT	\N	PRESENT	0
132102	131874	11036J	PARTICIPANT	\N	PRESENT	0
132212	131875	14197C	PARTICIPANT	\N	PRESENT	0
132214	131875	80013X	PARTICIPANT	\N	PRESENT	0
132215	131875	14014Q	PARTICIPANT	\N	PRESENT	0
132216	131875	14269B	PARTICIPANT	\N	PRESENT	0
132218	131875	01014K	PARTICIPANT	\N	PRESENT	0
132219	131875	98022P	PARTICIPANT	\N	PRESENT	0
132225	131875	11030C	PARTICIPANT	\N	PRESENT	0
132226	131875	96004D	PARTICIPANT	\N	PRESENT	0
132227	131875	14175V	PARTICIPANT	\N	PRESENT	0
132228	131875	01013J	PARTICIPANT	\N	PRESENT	0
132229	131875	14093U	PARTICIPANT	\N	PRESENT	0
132230	131875	07026Q	PARTICIPANT	\N	PRESENT	0
132231	131875	14209N	PARTICIPANT	\N	PRESENT	0
132232	131875	01015L	PARTICIPANT	\N	PRESENT	0
132233	131875	04086Q	PARTICIPANT	\N	PRESENT	0
132234	131875	14079W	PARTICIPANT	\N	PRESENT	0
132235	131875	04085P	PARTICIPANT	\N	PRESENT	0
132236	131875	98053W	PARTICIPANT	\N	PRESENT	0
132237	131875	04050C	PARTICIPANT	\N	PRESENT	0
132238	131875	14187A	PARTICIPANT	\N	PRESENT	0
132239	131875	11040E	PARTICIPANT	\N	PRESENT	0
132240	131875	04054G	PARTICIPANT	\N	PRESENT	0
132241	131875	08010L	PARTICIPANT	\N	PRESENT	0
132242	131875	11034G	PARTICIPANT	\N	PRESENT	0
132243	131875	14013P	PARTICIPANT	\N	PRESENT	0
132244	131875	11056N	PARTICIPANT	\N	PRESENT	0
132245	131875	11098Y	PARTICIPANT	\N	PRESENT	0
132246	131875	14235Q	PARTICIPANT	\N	PRESENT	0
132247	131875	04067M	PARTICIPANT	\N	PRESENT	0
132248	131875	01044R	PARTICIPANT	\N	PRESENT	0
132249	131875	11029K	PARTICIPANT	\N	PRESENT	0
132250	131875	14071N	PARTICIPANT	\N	PRESENT	0
132251	131875	11055M	PARTICIPANT	\N	PRESENT	0
132252	131875	11099A	PARTICIPANT	\N	PRESENT	0
132253	131875	11033F	PARTICIPANT	\N	PRESENT	0
132254	131875	13002U	PARTICIPANT	\N	PRESENT	0
132255	131875	08039A	PARTICIPANT	\N	PRESENT	0
132256	131875	11100Y	PARTICIPANT	\N	PRESENT	0
132257	131875	14331P	PARTICIPANT	\N	PRESENT	0
132258	131875	14157T	PARTICIPANT	\N	PRESENT	0
132259	131875	01046T	PARTICIPANT	\N	PRESENT	0
132260	131875	14247U	PARTICIPANT	\N	PRESENT	0
132261	131875	14133K	PARTICIPANT	\N	PRESENT	0
132262	131875	04071H	PARTICIPANT	\N	PRESENT	0
132263	131875	08031R	PARTICIPANT	\N	PRESENT	0
132264	131875	08049C	PARTICIPANT	\N	PRESENT	0
132265	131875	01027Q	PARTICIPANT	\N	PRESENT	0
132266	131875	11012A	PARTICIPANT	\N	PRESENT	0
132267	131875	01003G	PARTICIPANT	\N	PRESENT	0
132268	131875	14201E	PARTICIPANT	\N	PRESENT	0
132269	131875	14261S	PARTICIPANT	\N	PRESENT	0
132270	131875	14241N	PARTICIPANT	\N	PRESENT	0
132271	131875	07029T	PARTICIPANT	\N	PRESENT	0
132272	131875	04049K	PARTICIPANT	\N	PRESENT	0
132273	131875	11039M	PARTICIPANT	\N	PRESENT	0
132274	131875	86034E	PARTICIPANT	\N	PRESENT	0
132275	131875	92015P	PARTICIPANT	\N	PRESENT	0
132287	131875	08060W	PARTICIPANT	\N	PRESENT	0
132277	131875	08015R	PARTICIPANT	\N	PRESENT	0
132278	131875	08052W	PARTICIPANT	\N	PRESENT	0
132279	131875	01031L	PARTICIPANT	\N	PRESENT	0
132280	131875	04066L	PARTICIPANT	\N	PRESENT	0
132281	131875	01011G	PARTICIPANT	\N	PRESENT	0
132282	131875	08034U	PARTICIPANT	\N	PRESENT	0
132209	131875	14051J	PARTICIPANT	\N	PRESENT	0
132210	131875	14107H	PARTICIPANT	\N	PRESENT	0
132284	131875	14151M	PARTICIPANT	\N	PRESENT	0
132285	131875	08055A	PARTICIPANT	\N	PRESENT	0
132286	131875	98005N	PARTICIPANT	\N	PRESENT	0
132289	131875	14028W	PARTICIPANT	\N	PRESENT	0
132291	131875	11080N	PARTICIPANT	\N	PRESENT	0
132292	131875	08053X	PARTICIPANT	\N	PRESENT	0
132293	131875	08017T	PARTICIPANT	\N	PRESENT	0
132294	131875	11036J	PARTICIPANT	\N	PRESENT	0
132295	131875	11089X	PARTICIPANT	\N	PRESENT	0
132296	131875	11027H	PARTICIPANT	\N	PRESENT	0
154824	154353	08010L	PARTICIPANT	\N	PRESENT	0
154825	154353	04086Q	PARTICIPANT	\N	PRESENT	0
154872	154353	11109J	PARTICIPANT	\N	PRESENT	0
154827	154353	04034C	PARTICIPANT	\N	PRESENT	0
154913	154912	01031L	PRESIDENT	0	PRESENT	0
154854	154353	88008L	PARTICIPANT	\N	PRESENT	0
154830	154353	80013X	PARTICIPANT	\N	PRESENT	0
154831	154353	11088W	PARTICIPANT	\N	PRESENT	0
154914	154912	08011M	PARTICIPANT	\N	PRESENT	0
154833	154353	08060W	PARTICIPANT	\N	PRESENT	0
154834	154353	04085P	PARTICIPANT	\N	PRESENT	0
154835	154353	11053K	PARTICIPANT	\N	PRESENT	0
154836	154353	11097X	PARTICIPANT	\N	PRESENT	0
154843	154353	08073C	PARTICIPANT	\N	PRESENT	0
154838	154353	04035D	PARTICIPANT	\N	PRESENT	0
154839	154353	01027Q	PARTICIPANT	\N	PRESENT	0
154840	154353	11070L	PARTICIPANT	\N	PRESENT	0
154841	154353	07024N	PARTICIPANT	\N	PRESENT	0
154842	154353	99004R	PARTICIPANT	\N	PRESENT	0
154844	154353	14039A	PARTICIPANT	\N	PRESENT	0
154852	154353	04071H	PARTICIPANT	\N	PRESENT	0
154853	154353	11113E	PARTICIPANT	\N	PRESENT	0
154855	154353	98005N	PARTICIPANT	\N	PRESENT	0
154915	154912	04086Q	PARTICIPANT	\N	PRESENT	0
154916	154912	04034C	PARTICIPANT	\N	PRESENT	0
154917	154912	98053W	PARTICIPANT	\N	PRESENT	0
154918	154912	04071H	PARTICIPANT	\N	PRESENT	0
155313	155312	05008E	PRESIDENT	0	PRESENT	0
155314	155312	04047H	PARTICIPANT	\N	PRESENT	0
155315	155312	11056N	PARTICIPANT	\N	EXCUSE	0
155332	155312	14041T	PARTICIPANT	\N	PRESENT	0
155333	155312	01024M	PARTICIPANT	\N	PRESENT	0
155334	155312	14215L	PARTICIPANT	\N	PRESENT	0
155335	155312	08044W	PARTICIPANT	\N	EXCUSE	0
155336	155312	14111D	PARTICIPANT	\N	PRESENT	0
155337	155312	14147R	PARTICIPANT	\N	PRESENT	0
155338	155312	07034Q	PARTICIPANT	\N	PRESENT	0
155339	155312	04074L	PARTICIPANT	\N	PRESENT	0
155340	155312	01028R	PARTICIPANT	\N	PRESENT	0
155341	155312	04056J	PARTICIPANT	\N	PRESENT	0
155342	155312	04044E	PRESIDENT	1	PRESENT	0
155343	155312	11037K	PARTICIPANT	\N	PRESENT	0
155344	155312	95067Q	PARTICIPANT	\N	PRESENT	0
155960	155959	09001P	PRESIDENT	0	PRESENT	0
155961	155959	11065P	PARTICIPANT	\N	PRESENT	0
155962	155959	01008M	PARTICIPANT	\N	PRESENT	0
155963	155959	14093U	PARTICIPANT	\N	PRESENT	0
155964	155959	01015L	PARTICIPANT	\N	PRESENT	0
155965	155959	05012A	PARTICIPANT	\N	PRESENT	0
155966	155959	90003B	PARTICIPANT	\N	PRESENT	0
155967	155959	01056V	PARTICIPANT	\N	PRESENT	0
155968	155959	08049C	PARTICIPANT	\N	EXCUSE	0
155969	155959	92045V	PARTICIPANT	\N	EXCUSE	0
155970	155959	80013X	PARTICIPANT	\N	EXCUSE	0
155971	155959	11035H	PARTICIPANT	\N	EXCUSE	0
156066	156065	04045F	PARTICIPANT	\N	PRESENT	0
156067	156065	92045V	PARTICIPANT	\N	PRESENT	0
156069	156068	96004D	PARTICIPANT	\N	PRESENT	0
156070	156068	11026G	PARTICIPANT	\N	PRESENT	0
156071	156068	10015M	PARTICIPANT	\N	PRESENT	0
156073	156072	04045F	PARTICIPANT	\N	PRESENT	0
156074	156072	92045V	PARTICIPANT	\N	PRESENT	0
156313	156312	05008E	PARTICIPANT	\N	PRESENT	0
156332	156312	04079R	PARTICIPANT	\N	PRESENT	0
156388	156382	89017R	PARTICIPANT	\N	PRESENT	0
156316	156312	14259Y	PARTICIPANT	\N	PRESENT	0
156317	156312	11034G	PARTICIPANT	\N	PRESENT	0
156389	156382	01031L	PRESIDENT	0	PRESENT	0
156390	156382	05004A	PARTICIPANT	\N	PRESENT	0
156321	156312	14111D	PARTICIPANT	\N	PRESENT	0
156322	156312	11072N	PARTICIPANT	\N	PRESENT	0
156323	156312	04080J	PARTICIPANT	\N	PRESENT	0
156324	156312	95063L	PARTICIPANT	\N	PRESENT	0
156325	156312	01028R	PARTICIPANT	\N	PRESENT	0
156392	156382	11068S	PARTICIPANT	\N	PRESENT	0
157053	157052	09001P	PRESIDENT	0	PRESENT	0
157054	157052	11065P	PARTICIPANT	\N	PRESENT	0
156395	156382	14167V	PARTICIPANT	\N	PRESENT	0
157063	157052	08049C	PARTICIPANT	\N	EXCUSE	0
156397	156382	14083S	PARTICIPANT	\N	PRESENT	0
156398	156382	11053K	PARTICIPANT	\N	PRESENT	0
156399	156382	14085U	PARTICIPANT	\N	PRESENT	0
156400	156382	11042G	PARTICIPANT	\N	PRESENT	0
157056	157052	14093U	PARTICIPANT	\N	EXCUSE	0
156402	156382	04086Q	PARTICIPANT	\N	PRESENT	0
156403	156382	04055H	PARTICIPANT	\N	EXCUSE	0
156404	156382	11070L	PARTICIPANT	\N	PRESENT	0
156405	156382	11088W	PARTICIPANT	\N	PRESENT	0
156406	156382	14327T	PARTICIPANT	\N	PRESENT	0
156407	156382	08022Q	PARTICIPANT	\N	PRESENT	0
156408	156382	01027Q	PARTICIPANT	\N	PRESENT	0
156409	156382	04071H	PARTICIPANT	\N	PRESENT	0
156410	156382	11074Q	PARTICIPANT	\N	PRESENT	0
156411	156382	98053W	PARTICIPANT	\N	EXCUSE	0
156412	156382	11083R	PARTICIPANT	\N	PRESENT	0
157057	157052	01056V	PARTICIPANT	\N	PRESENT	0
156414	156382	01057W	PARTICIPANT	\N	PRESENT	0
156415	156382	08016S	PARTICIPANT	\N	EXCUSE	0
156416	156382	08069G	PARTICIPANT	\N	PRESENT	0
156417	156382	11048N	PARTICIPANT	\N	PRESENT	0
157058	157052	80013X	PARTICIPANT	\N	EXCUSE	0
156419	156382	04061F	PARTICIPANT	\N	PRESENT	0
156420	156382	14159V	PARTICIPANT	\N	PRESENT	0
156421	156382	07029T	PARTICIPANT	\N	PRESENT	0
157059	157052	01008M	PARTICIPANT	\N	EXCUSE	0
156423	156382	08010L	PARTICIPANT	\N	PRESENT	0
156424	156382	08034U	PARTICIPANT	\N	PRESENT	0
157060	157052	01015L	PARTICIPANT	\N	EXCUSE	0
156426	156382	98046X	PARTICIPANT	\N	PRESENT	0
156427	156382	11085T	PARTICIPANT	\N	PRESENT	0
156428	156382	08011M	PARTICIPANT	\N	PRESENT	0
157061	157052	05012A	PARTICIPANT	\N	PRESENT	0
156430	156382	08061X	PARTICIPANT	\N	EXCUSE	0
156431	156382	01016M	PARTICIPANT	\N	PRESENT	0
157062	157052	92045V	PARTICIPANT	\N	EXCUSE	0
156433	156382	11012A	PARTICIPANT	\N	PRESENT	0
156434	156382	11057P	PARTICIPANT	\N	PRESENT	0
157064	157052	11090Q	PARTICIPANT	\N	EXCUSE	0
156436	156382	04034C	PARTICIPANT	\N	PRESENT	0
157065	157052	14033T	PARTICIPANT	\N	PRESENT	0
157152	157132	11035H	PARTICIPANT	\N	EXCUSE	0
157412	157272	11035H	PARTICIPANT	\N	EXCUSE	0
157413	157272	11049P	PARTICIPANT	\N	EXCUSE	0
157472	157272	11112D	PARTICIPANT	\N	EXCUSE	0
157473	157272	04044E	PARTICIPANT	\N	EXCUSE	0
157492	157272	14071N	PARTICIPANT	\N	EXCUSE	0
157613	157612	05008E	PRESIDENT	0	PRESENT	0
157614	157612	14065Q	PARTICIPANT	\N	PRESENT	0
157615	157612	14069U	PARTICIPANT	\N	PRESENT	0
157616	157612	04047H	PARTICIPANT	\N	PRESENT	0
157617	157612	14259Y	PARTICIPANT	\N	PRESENT	0
157618	157612	01024M	PARTICIPANT	\N	EXCUSE	0
157619	157612	14215L	PARTICIPANT	\N	PRESENT	0
157620	157612	01007L	PARTICIPANT	\N	PRESENT	0
157621	157612	11049P	PARTICIPANT	\N	PRESENT	0
157622	157612	08044W	PARTICIPANT	\N	EXCUSE	0
157623	157612	11084S	PARTICIPANT	\N	PRESENT	0
157624	157612	11072N	PARTICIPANT	\N	PRESENT	0
157625	157612	07034Q	PARTICIPANT	\N	PRESENT	0
157626	157612	01028R	PARTICIPANT	\N	PRESENT	0
157627	157612	04056J	PARTICIPANT	\N	PRESENT	0
157628	157612	04044E	PARTICIPANT	\N	EXCUSE	0
157629	157612	11037K	PARTICIPANT	\N	PRESENT	0
157630	157612	95067Q	PARTICIPANT	\N	EXCUSE	0
157938	157936	89017R	PARTICIPANT	\N	EXCUSE	0
157939	157936	01031L	PARTICIPANT	\N	EXCUSE	0
157941	157936	01013J	PARTICIPANT	\N	PRESENT	0
157943	157936	11040E	PARTICIPANT	\N	PRESENT	0
157946	157936	14175V	PARTICIPANT	\N	PRESENT	0
157947	157936	14083S	PARTICIPANT	\N	PRESENT	0
157948	157936	11053K	PARTICIPANT	\N	PRESENT	0
157950	157936	11042G	PARTICIPANT	\N	PRESENT	0
130353	130352	08060W	PARTICIPANT	\N	PRESENT	0
130355	130354	14221J	PARTICIPANT	\N	PRESENT	0
130360	130359	14051J	PARTICIPANT	\N	PRESENT	0
130362	130361	14051J	PARTICIPANT	\N	PRESENT	0
130369	130367	98005N	PARTICIPANT	\N	PRESENT	0
130409	130367	07024N	PARTICIPANT	\N	PRESENT	0
133527	133126	14215L	PARTICIPANT	\N	PRESENT	0
133528	133126	14193X	PARTICIPANT	\N	PRESENT	0
133529	133126	14207L	PARTICIPANT	\N	PRESENT	0
133530	133126	14109K	PARTICIPANT	\N	PRESENT	0
133531	133126	08014Q	PARTICIPANT	\N	PRESENT	0
133532	133126	11036J	PARTICIPANT	\N	PRESENT	0
133533	133126	14001X	PARTICIPANT	\N	PRESENT	0
133534	133126	95037J	PARTICIPANT	\N	PRESENT	0
133535	133126	14079W	PARTICIPANT	\N	PRESENT	0
133536	133126	14119M	PARTICIPANT	\N	PRESENT	0
133537	133126	11023D	PARTICIPANT	\N	PRESENT	0
133538	133126	08019V	PARTICIPANT	\N	PRESENT	0
133539	133126	11056N	PARTICIPANT	\N	PRESENT	0
133540	133126	04054G	PARTICIPANT	\N	PRESENT	0
133541	133126	14263U	PARTICIPANT	\N	PRESENT	0
133542	133126	08031R	PARTICIPANT	\N	PRESENT	0
133543	133126	14031R	PARTICIPANT	\N	PRESENT	0
133544	133126	11074Q	PARTICIPANT	\N	PRESENT	0
133545	133126	08015R	PARTICIPANT	\N	PRESENT	0
133546	133126	14063N	PARTICIPANT	\N	PRESENT	0
133547	133126	08062Y	PARTICIPANT	\N	PRESENT	0
133548	133126	14097Y	PARTICIPANT	\N	PRESENT	0
133549	133126	14121F	PARTICIPANT	\N	PRESENT	0
133550	133126	11014C	PARTICIPANT	\N	PRESENT	0
133551	133126	11044J	PARTICIPANT	\N	PRESENT	0
133552	133126	08061X	PARTICIPANT	\N	PRESENT	0
133553	133126	14061L	PARTICIPANT	\N	PRESENT	0
133554	133126	04077P	PARTICIPANT	\N	PRESENT	0
133555	133126	08038Y	PARTICIPANT	\N	PRESENT	0
133556	133126	11101A	PARTICIPANT	\N	PRESENT	0
133557	133126	14259Y	PARTICIPANT	\N	PRESENT	0
133558	133126	12042Y	PARTICIPANT	\N	PRESENT	0
133559	133126	14111D	PARTICIPANT	\N	PRESENT	0
133560	133126	11104D	PARTICIPANT	\N	PRESENT	0
133561	133126	08024S	PARTICIPANT	\N	PRESENT	0
133562	133126	01037S	PARTICIPANT	\N	PRESENT	0
133563	133126	14271U	PARTICIPANT	\N	PRESENT	0
133564	133126	04047H	PARTICIPANT	\N	PRESENT	0
133565	133126	08052W	PARTICIPANT	\N	PRESENT	0
133566	133126	14041T	PARTICIPANT	\N	PRESENT	0
133567	133126	11066Q	PARTICIPANT	\N	PRESENT	0
133568	133126	14085U	PARTICIPANT	\N	PRESENT	0
133569	133126	04088S	PARTICIPANT	\N	PRESENT	0
133570	133126	11106F	PARTICIPANT	\N	PRESENT	0
133571	133126	14329V	PARTICIPANT	\N	PRESENT	0
133572	133126	14081Q	PARTICIPANT	\N	PRESENT	0
133573	133126	08017T	PARTICIPANT	\N	PRESENT	0
133574	133126	14331P	PARTICIPANT	\N	PRESENT	0
133575	133126	14225N	PARTICIPANT	\N	PRESENT	0
133576	133126	14269B	PARTICIPANT	\N	PRESENT	0
133577	133126	04044E	PARTICIPANT	\N	PRESENT	0
133578	133126	01014K	PARTICIPANT	\N	PRESENT	0
133579	133126	11107G	PARTICIPANT	\N	PRESENT	0
133580	133126	98046X	PARTICIPANT	\N	PRESENT	0
133581	133126	95063L	PARTICIPANT	\N	PRESENT	0
133582	133126	14093U	PARTICIPANT	\N	PRESENT	0
133583	133126	08035V	PARTICIPANT	\N	PRESENT	0
133584	133126	11109J	PARTICIPANT	\N	PRESENT	0
133585	133126	11089X	PARTICIPANT	\N	PRESENT	0
133586	133126	14159V	PARTICIPANT	\N	PRESENT	0
133587	133126	11037K	PARTICIPANT	\N	PRESENT	0
133588	133126	08021P	PARTICIPANT	\N	PRESENT	0
133589	133126	14213J	PARTICIPANT	\N	PRESENT	0
133590	133126	14247U	PARTICIPANT	\N	PRESENT	0
133591	133126	14055N	PARTICIPANT	\N	PRESENT	0
133592	133126	92044U	PARTICIPANT	\N	PRESENT	0
133593	133126	14175V	PARTICIPANT	\N	PRESENT	0
133594	133126	88008L	PARTICIPANT	\N	PRESENT	0
133595	133126	04033B	PARTICIPANT	\N	PRESENT	0
133596	133126	11012A	PARTICIPANT	\N	PRESENT	0
133597	133126	14053L	PARTICIPANT	\N	PRESENT	0
133598	133126	04053F	PARTICIPANT	\N	PRESENT	0
133599	133126	11091R	PARTICIPANT	\N	PRESENT	0
133600	133126	14199E	PARTICIPANT	\N	PRESENT	0
133601	133126	14327T	PARTICIPANT	\N	PRESENT	0
133602	133126	08009T	PARTICIPANT	\N	PRESENT	0
133603	133126	11053K	PARTICIPANT	\N	PRESENT	0
133604	133126	04040A	PARTICIPANT	\N	PRESENT	0
133605	133126	11049P	PARTICIPANT	\N	PRESENT	0
133606	133126	04080J	PARTICIPANT	\N	PRESENT	0
133607	133126	14205J	PARTICIPANT	\N	PRESENT	0
133608	133126	08048B	PARTICIPANT	\N	PRESENT	0
133609	133126	14267Y	PARTICIPANT	\N	PRESENT	0
133610	133126	14042U	PARTICIPANT	\N	PRESENT	0
133611	133126	14219Q	PARTICIPANT	\N	PRESENT	0
133612	133126	04049K	PARTICIPANT	\N	PRESENT	0
133613	133126	99002P	PARTICIPANT	\N	PRESENT	0
133614	133126	11100Y	PARTICIPANT	\N	PRESENT	0
133615	133126	11077T	PARTICIPANT	\N	PRESENT	0
133616	133126	04095R	PARTICIPANT	\N	PRESENT	0
133617	133126	14257W	PARTICIPANT	\N	PRESENT	0
133618	133126	14030Q	PARTICIPANT	\N	PRESENT	0
133619	133126	14123H	PARTICIPANT	\N	PRESENT	0
133620	133126	14221J	PARTICIPANT	\N	PRESENT	0
133621	133126	01007L	PARTICIPANT	\N	PRESENT	0
133622	133126	14037X	PARTICIPANT	\N	PRESENT	0
133623	133126	04070G	PARTICIPANT	\N	PRESENT	0
133624	133126	04059M	PARTICIPANT	\N	PRESENT	0
133625	133126	14073Q	PARTICIPANT	\N	PRESENT	0
133626	133126	11082Q	PARTICIPANT	\N	PRESENT	0
133627	133126	08056B	PARTICIPANT	\N	PRESENT	0
133628	133126	14275Y	PARTICIPANT	\N	PRESENT	0
133629	133126	14277B	PARTICIPANT	\N	PRESENT	0
133630	133126	11093T	PARTICIPANT	\N	PRESENT	0
133631	133126	14231L	PARTICIPANT	\N	PRESENT	0
133632	133126	04061F	PARTICIPANT	\N	PRESENT	0
133633	133126	04089T	PARTICIPANT	\N	PRESENT	0
133634	133126	14251Q	PARTICIPANT	\N	PRESENT	0
133635	133126	11070L	PARTICIPANT	\N	PRESENT	0
133636	133126	98042T	PARTICIPANT	\N	PRESENT	0
133637	133126	14179A	PARTICIPANT	\N	PRESENT	0
133638	133126	08049C	PARTICIPANT	\N	PRESENT	0
133639	133126	11065P	PARTICIPANT	\N	PRESENT	0
133640	133126	14089Y	PARTICIPANT	\N	PRESENT	0
133641	133126	95049N	PARTICIPANT	\N	PRESENT	0
133642	133126	01056V	PARTICIPANT	\N	PRESENT	0
133643	133126	01047U	PARTICIPANT	\N	PRESENT	0
133644	133126	09001P	PARTICIPANT	\N	PRESENT	0
133645	133126	01025N	PARTICIPANT	\N	PRESENT	0
133646	133126	04042C	PARTICIPANT	\N	PRESENT	0
133647	133126	04048J	PARTICIPANT	\N	PRESENT	0
133648	133126	10006L	PARTICIPANT	\N	PRESENT	0
133649	133126	11020A	PARTICIPANT	\N	PRESENT	0
133650	133126	08018U	PARTICIPANT	\N	PRESENT	0
133651	133126	04038G	PARTICIPANT	\N	PRESENT	0
133652	133126	14014Q	PARTICIPANT	\N	PRESENT	0
133653	133126	11061K	PARTICIPANT	\N	PRESENT	0
133654	133126	14227Q	PARTICIPANT	\N	PRESENT	0
133655	133126	01016M	PARTICIPANT	\N	PRESENT	0
133656	133126	02002K	PARTICIPANT	\N	PRESENT	0
133657	133126	14253S	PARTICIPANT	\N	PRESENT	0
133658	133126	92031P	PARTICIPANT	\N	PRESENT	0
133659	133126	95059Q	PARTICIPANT	\N	PRESENT	0
133660	133126	01008M	PARTICIPANT	\N	PRESENT	0
133661	133126	11054L	PARTICIPANT	\N	PRESENT	0
133662	133126	77002U	PARTICIPANT	\N	PRESENT	0
133663	133126	01011G	PARTICIPANT	\N	PRESENT	0
133664	133126	98024R	PARTICIPANT	\N	PRESENT	0
133665	133126	14265W	PARTICIPANT	\N	PRESENT	0
133666	133126	92045V	PARTICIPANT	\N	PRESENT	0
133667	133126	11064N	PARTICIPANT	\N	PRESENT	0
133673	133126	10015M	PARTICIPANT	\N	PRESENT	0
133669	133126	11027H	PARTICIPANT	\N	PRESENT	0
133670	133126	11043H	PARTICIPANT	\N	PRESENT	0
133671	133126	01019Q	PARTICIPANT	\N	PRESENT	0
133672	133126	11088W	PARTICIPANT	\N	PRESENT	0
133674	133126	05008E	PARTICIPANT	\N	PRESENT	0
133680	133126	05004A	PARTICIPANT	\N	PRESENT	0
133681	133126	14103D	PARTICIPANT	\N	PRESENT	0
133677	133126	11111C	PARTICIPANT	\N	PRESENT	0
133678	133126	13002U	PARTICIPANT	\N	PRESENT	0
133679	133126	11048N	PARTICIPANT	\N	PRESENT	0
133682	133126	98029W	PARTICIPANT	\N	PRESENT	0
133683	133126	11084S	PARTICIPANT	\N	PRESENT	0
133684	133126	11085T	PARTICIPANT	\N	PRESENT	0
133685	133126	04057K	PARTICIPANT	\N	PRESENT	0
133686	133126	04071H	PARTICIPANT	\N	PRESENT	0
133687	133126	01043Q	PARTICIPANT	\N	PRESENT	0
133688	133126	11105E	PARTICIPANT	\N	PRESENT	0
133689	133126	14151M	PARTICIPANT	\N	PRESENT	0
133690	133126	01028R	PARTICIPANT	\N	PRESENT	0
133691	133126	11046L	PARTICIPANT	\N	PRESENT	0
151075	149475	11056N	PARTICIPANT	\N	PRESENT	0
151076	149475	07029T	PARTICIPANT	\N	PRESENT	0
151077	149475	14033T	PARTICIPANT	\N	PRESENT	0
151078	149475	14026U	PARTICIPANT	\N	PRESENT	0
151079	149475	14147R	PARTICIPANT	\N	PRESENT	0
151080	149475	14089Y	PARTICIPANT	\N	PRESENT	0
151081	149475	14135M	PARTICIPANT	\N	PRESENT	0
151082	149475	14195A	PARTICIPANT	\N	PRESENT	0
151083	149475	14014Q	PARTICIPANT	\N	PRESENT	0
151084	149475	01022K	PARTICIPANT	\N	PRESENT	0
151085	149475	14105F	PARTICIPANT	\N	PRESENT	0
151086	149475	14213J	PARTICIPANT	\N	PRESENT	0
151087	149475	08015R	PARTICIPANT	\N	PRESENT	0
151088	149475	95049N	PARTICIPANT	\N	PRESENT	0
151089	149475	14111D	PARTICIPANT	\N	PRESENT	0
151090	149475	11101A	PARTICIPANT	\N	PRESENT	0
151091	149475	80013X	PARTICIPANT	\N	PRESENT	0
151092	149475	95015C	PARTICIPANT	\N	PRESENT	0
151093	149475	14237S	PARTICIPANT	\N	PRESENT	0
151094	149475	14257W	PARTICIPANT	\N	PRESENT	0
151112	149475	13002U	PARTICIPANT	\N	PRESENT	0
151113	149475	11112D	PARTICIPANT	\N	PRESENT	0
151114	149475	98053W	PARTICIPANT	\N	PRESENT	0
151132	149475	08038Y	PARTICIPANT	\N	PRESENT	0
151133	149475	04049K	PARTICIPANT	\N	PRESENT	0
151134	149475	95067Q	PARTICIPANT	\N	PRESENT	0
151135	149475	92045V	PARTICIPANT	\N	PRESENT	0
151136	149475	08060W	PARTICIPANT	\N	PRESENT	0
151152	149475	14053L	PARTICIPANT	\N	PRESENT	0
151153	149475	14071N	PARTICIPANT	\N	PRESENT	0
151154	149475	14193X	PARTICIPANT	\N	PRESENT	0
151155	149475	11012A	PARTICIPANT	\N	PRESENT	0
151156	149475	11104D	PARTICIPANT	\N	PRESENT	0
151172	149475	14121F	PARTICIPANT	\N	PRESENT	0
151173	149475	11061K	PARTICIPANT	\N	PRESENT	0
151174	149475	11042G	PARTICIPANT	\N	PRESENT	0
151175	149475	14159V	PARTICIPANT	\N	PRESENT	0
151176	149475	14083S	PARTICIPANT	\N	PRESENT	0
151192	149475	11036J	PARTICIPANT	\N	PRESENT	0
151212	149475	04067M	PARTICIPANT	\N	PRESENT	0
151232	149475	08042U	PARTICIPANT	\N	PRESENT	0
151409	151392	11070L	PARTICIPANT	\N	PRESENT	0
151410	151392	11088W	PARTICIPANT	\N	PRESENT	0
151452	149972	08055A	PARTICIPANT	\N	PRESENT	0
151412	151392	08022Q	PARTICIPANT	\N	PRESENT	0
151413	151392	01027Q	PARTICIPANT	\N	PRESENT	0
151414	151392	04071H	PARTICIPANT	\N	PRESENT	0
151415	151392	11074Q	PARTICIPANT	\N	PRESENT	0
151416	151392	98053W	PARTICIPANT	\N	PRESENT	0
151417	151392	11083R	PARTICIPANT	\N	PRESENT	0
151418	151392	14199E	PARTICIPANT	\N	PRESENT	0
151419	151392	01057W	PARTICIPANT	\N	PRESENT	0
151420	151392	08016S	PARTICIPANT	\N	EXCUSE	0
151421	151392	08069G	PARTICIPANT	\N	PRESENT	0
151422	151392	11048N	PARTICIPANT	\N	PRESENT	0
151423	151392	99004R	PARTICIPANT	\N	PRESENT	0
151424	151392	04061F	PARTICIPANT	\N	PRESENT	0
151425	151392	14159V	PARTICIPANT	\N	PRESENT	0
151426	151392	07029T	PARTICIPANT	\N	PRESENT	0
151453	149972	11101A	PARTICIPANT	\N	PRESENT	0
151428	151392	08010L	PARTICIPANT	\N	PRESENT	0
151429	151392	08034U	PARTICIPANT	\N	PRESENT	0
151454	149972	14179A	PARTICIPANT	\N	PRESENT	0
151431	151392	98046X	PARTICIPANT	\N	PRESENT	0
151455	149972	14107H	PARTICIPANT	\N	PRESENT	0
151433	151392	08011M	PARTICIPANT	\N	PRESENT	0
151434	151392	08073C	PARTICIPANT	\N	PRESENT	0
151435	151392	08061X	PARTICIPANT	\N	EXCUSE	0
151436	151392	01016M	PARTICIPANT	\N	PRESENT	0
151437	151392	14225N	PARTICIPANT	\N	PRESENT	0
151438	151392	11012A	PARTICIPANT	\N	PRESENT	0
151456	149972	14265W	PARTICIPANT	\N	PRESENT	0
151440	151392	14173T	PARTICIPANT	\N	PRESENT	0
151441	151392	04034C	PARTICIPANT	\N	PRESENT	0
151457	149972	14063N	PARTICIPANT	\N	PRESENT	0
151459	149972	14221J	PARTICIPANT	\N	PRESENT	0
151462	149972	14103D	PARTICIPANT	\N	PRESENT	0
151468	149972	08069G	PARTICIPANT	\N	PRESENT	0
151471	149972	11043H	PARTICIPANT	\N	PRESENT	0
151475	149972	14209N	PARTICIPANT	\N	PRESENT	0
151477	149972	01008M	PARTICIPANT	\N	PRESENT	0
151488	149972	08042U	PARTICIPANT	\N	PRESENT	0
151493	149972	14033T	PARTICIPANT	\N	PRESENT	0
151494	149972	14175V	PARTICIPANT	\N	PRESENT	0
151495	151458	07034Q	PARTICIPANT	\N	EXCUSE	0
151496	151458	04074L	PARTICIPANT	\N	PRESENT	0
151497	151458	10015M	PARTICIPANT	\N	PRESENT	0
151498	151458	95063L	PARTICIPANT	\N	PRESENT	0
151499	151458	01019Q	PARTICIPANT	\N	EXCUSE	0
151500	151458	01028R	PARTICIPANT	\N	EXCUSE	0
151501	151458	04056J	PARTICIPANT	\N	PRESENT	0
151502	151458	04044E	PARTICIPANT	\N	EXCUSE	0
151503	151458	11037K	PARTICIPANT	\N	PRESENT	0
151504	151458	92045V	PARTICIPANT	\N	PRESENT	0
151505	151458	95067Q	PARTICIPANT	\N	PRESENT	0
151506	151458	01047U	PARTICIPANT	\N	PRESENT	0
151507	151458	08051V	PARTICIPANT	\N	PRESENT	0
151508	149972	11098Y	PARTICIPANT	\N	PRESENT	0
151509	149972	92015P	PARTICIPANT	\N	PRESENT	0
151513	149972	14197C	PARTICIPANT	\N	PRESENT	0
151528	149972	04088S	PARTICIPANT	\N	PRESENT	0
151529	149972	04089T	PARTICIPANT	\N	PRESENT	0
151534	149972	14201E	PARTICIPANT	\N	PRESENT	0
151539	149972	08009T	PARTICIPANT	\N	PRESENT	0
151542	149972	14237S	PARTICIPANT	\N	PRESENT	0
151544	149972	11081P	PARTICIPANT	\N	PRESENT	0
151547	149972	14327T	PARTICIPANT	\N	PRESENT	0
151550	149972	14079W	PARTICIPANT	\N	PRESENT	0
151552	149972	01059Y	PARTICIPANT	\N	PRESENT	0
151556	149972	14267Y	PARTICIPANT	\N	PRESENT	0
151563	149972	11065P	PARTICIPANT	\N	PRESENT	0
151570	151558	11103C	PRESIDENT	0	PRESENT	0
151573	151558	14053L	PARTICIPANT	\N	EXCUSE	0
151575	149972	01015L	PARTICIPANT	\N	PRESENT	0
151576	151558	10006L	PARTICIPANT	\N	EXCUSE	0
151577	151558	12042Y	PARTICIPANT	\N	PRESENT	0
151578	151558	98024R	PARTICIPANT	\N	PRESENT	0
151579	151558	01034P	PARTICIPANT	\N	PRESENT	0
151580	149972	14219Q	PARTICIPANT	\N	PRESENT	0
151581	151558	11061K	PARTICIPANT	\N	PRESENT	0
151582	149972	87003B	PARTICIPANT	\N	PRESENT	0
151583	151558	14071N	PARTICIPANT	\N	PRESENT	0
151584	151558	08052W	PARTICIPANT	\N	PRESENT	0
151585	149972	14089Y	PARTICIPANT	\N	PRESENT	0
151586	149972	14173T	PARTICIPANT	\N	PRESENT	0
151587	149972	11066Q	PARTICIPANT	\N	PRESENT	0
151588	149972	11093T	PARTICIPANT	\N	PRESENT	0
151589	149972	14199E	PARTICIPANT	\N	PRESENT	0
151590	149972	14014Q	PARTICIPANT	\N	PRESENT	0
151591	149972	04045F	PARTICIPANT	\N	PRESENT	0
151593	149972	01022K	PARTICIPANT	\N	PRESENT	0
151594	149972	11048N	PARTICIPANT	\N	PRESENT	0
151595	149972	14061L	PARTICIPANT	\N	PRESENT	0
151596	149972	11111C	PARTICIPANT	\N	PRESENT	0
151597	151558	11097X	PARTICIPANT	\N	PRESENT	0
151679	151558	11067R	PARTICIPANT	\N	PRESENT	0
151680	151558	14119M	PARTICIPANT	\N	PRESENT	0
151681	149972	14053L	PARTICIPANT	\N	PRESENT	0
151682	149972	11100Y	PARTICIPANT	\N	PRESENT	0
151683	149972	14111D	PARTICIPANT	\N	PRESENT	0
151686	149972	14030Q	PARTICIPANT	\N	PRESENT	0
151687	149972	14241N	PARTICIPANT	\N	PRESENT	0
151688	149972	95030B	PARTICIPANT	\N	PRESENT	0
151689	149972	86044G	PARTICIPANT	\N	PRESENT	0
151690	149972	14263U	PARTICIPANT	\N	PRESENT	0
151691	149972	14205J	PARTICIPANT	\N	PRESENT	0
151692	149972	14187A	PARTICIPANT	\N	PRESENT	0
151693	149972	95067Q	PARTICIPANT	\N	PRESENT	0
151704	149972	14239U	PARTICIPANT	\N	PRESENT	0
151714	149972	14135M	PARTICIPANT	\N	PRESENT	0
151718	149972	08039A	PARTICIPANT	\N	PRESENT	0
151733	149972	08051V	PARTICIPANT	\N	PRESENT	0
151734	151558	14034U	PARTICIPANT	\N	PRESENT	0
151735	149972	11010L	PARTICIPANT	\N	PRESENT	0
151736	149972	14051J	PARTICIPANT	\N	PRESENT	0
151737	149972	80027E	PARTICIPANT	\N	PRESENT	0
151738	151558	14271U	PARTICIPANT	\N	PRESENT	0
151739	149972	11053K	PARTICIPANT	\N	PRESENT	0
151740	149972	14231L	PARTICIPANT	\N	PRESENT	0
151741	149972	14147R	PARTICIPANT	\N	PRESENT	0
151742	149972	88008L	PARTICIPANT	\N	PRESENT	0
151743	149972	05012A	PARTICIPANT	\N	PRESENT	0
151744	149972	14119M	PARTICIPANT	\N	PRESENT	0
151745	149972	11011M	PARTICIPANT	\N	PRESENT	0
151746	149972	80013X	PARTICIPANT	\N	PRESENT	0
151747	149972	14151M	PARTICIPANT	\N	PRESENT	0
151748	149972	13002U	PARTICIPANT	\N	PRESENT	0
151749	149972	14105F	PARTICIPANT	\N	PRESENT	0
151750	149972	14269B	PARTICIPANT	\N	PRESENT	0
129523	129522	96004D	PRESIDENT	1	PRESENT	0
129524	129522	11040E	PARTICIPANT	\N	PRESENT	0
129525	129522	11083R	PARTICIPANT	\N	PRESENT	0
129526	129522	14073Q	PARTICIPANT	\N	PRESENT	0
129527	129522	14001X	PARTICIPANT	\N	PRESENT	0
129528	129522	04057K	PARTICIPANT	\N	PRESENT	0
129529	129522	98035U	PARTICIPANT	\N	PRESENT	0
129530	129522	04034C	PARTICIPANT	\N	PRESENT	0
129531	129522	04042C	PARTICIPANT	\N	PRESENT	0
129532	129522	04035D	PARTICIPANT	\N	PRESENT	0
129533	129522	07024N	PRESIDENT	0	PRESENT	0
129534	129522	14014Q	PARTICIPANT	\N	PRESENT	0
129535	129522	98022P	PARTICIPANT	\N	PRESENT	0
129536	129522	14097Y	PARTICIPANT	\N	PRESENT	0
129537	129522	83042R	PARTICIPANT	\N	PRESENT	0
129538	129522	98021N	PARTICIPANT	\N	PRESENT	0
129540	129522	14147R	PARTICIPANT	\N	PRESENT	0
129542	129522	14255U	PARTICIPANT	\N	PRESENT	0
132297	131875	04035D	PARTICIPANT	\N	PRESENT	0
132298	131875	08016S	PARTICIPANT	\N	PRESENT	0
132299	131875	04081K	PARTICIPANT	\N	PRESENT	0
132300	131875	08035V	PARTICIPANT	\N	PRESENT	0
132301	131875	14037X	PARTICIPANT	\N	PRESENT	0
132302	131875	98029W	PARTICIPANT	\N	PRESENT	0
132304	131875	11046L	PARTICIPANT	\N	PRESENT	0
132305	131875	95035G	PARTICIPANT	\N	PRESENT	0
132306	131875	11074Q	PARTICIPANT	\N	PRESENT	0
132307	131875	11015D	PARTICIPANT	\N	PRESENT	0
132308	131875	11083R	PARTICIPANT	\N	PRESENT	0
132309	131875	04055H	PARTICIPANT	\N	PRESENT	0
132310	131875	83042R	PARTICIPANT	\N	PRESENT	0
132311	131875	08012N	PARTICIPANT	\N	PRESENT	0
132312	131875	14259Y	PARTICIPANT	\N	PRESENT	0
132313	131875	04034C	PARTICIPANT	\N	PRESENT	0
132314	131875	95037J	PARTICIPANT	\N	PRESENT	0
132315	131875	08058D	PARTICIPANT	\N	PRESENT	0
132316	131875	10006L	PARTICIPANT	\N	PRESENT	0
132317	131875	83047W	PARTICIPANT	\N	PRESENT	0
132319	131875	14227Q	PARTICIPANT	\N	PRESENT	0
132320	131875	95030B	PARTICIPANT	\N	PRESENT	0
132321	131875	14121F	PARTICIPANT	\N	PRESENT	0
132322	131875	04057K	PARTICIPANT	\N	PRESENT	0
132323	131875	11095V	PARTICIPANT	\N	PRESENT	0
132324	131875	14109K	PARTICIPANT	\N	PRESENT	0
132325	131875	14229S	PARTICIPANT	\N	PRESENT	0
132326	131875	08018U	PARTICIPANT	\N	PRESENT	0
132327	131875	11061K	PARTICIPANT	\N	PRESENT	0
132328	131875	04079R	PARTICIPANT	\N	PRESENT	0
132329	131875	11063M	PARTICIPANT	\N	PRESENT	0
132330	131875	14327T	PARTICIPANT	\N	PRESENT	0
132331	131875	11014C	PARTICIPANT	\N	PRESENT	0
132332	131875	14257W	PARTICIPANT	\N	PRESENT	0
132333	131875	11112D	PARTICIPANT	\N	PRESENT	0
132334	131875	92031P	PARTICIPANT	\N	PRESENT	0
132335	131875	14097Y	PARTICIPANT	\N	PRESENT	0
132337	131875	14063N	PARTICIPANT	\N	PRESENT	0
132338	131875	14225N	PARTICIPANT	\N	PRESENT	0
132339	131875	14217N	PARTICIPANT	\N	PRESENT	0
132340	131875	14271U	PARTICIPANT	\N	PRESENT	0
132342	131875	14281W	PARTICIPANT	\N	PRESENT	0
132343	131875	04043D	PARTICIPANT	\N	PRESENT	0
132345	131875	04077P	PARTICIPANT	\N	PRESENT	0
132346	131875	04074L	PARTICIPANT	\N	PRESENT	0
132347	131875	11020A	PARTICIPANT	\N	PRESENT	0
132348	131875	08061X	PARTICIPANT	\N	PRESENT	0
132349	131875	02002K	PARTICIPANT	\N	PRESENT	0
132350	131875	04053F	PARTICIPANT	\N	PRESENT	0
132351	131875	11032E	PARTICIPANT	\N	PRESENT	0
132352	131875	98023Q	PARTICIPANT	\N	PRESENT	0
132353	131875	04059M	PARTICIPANT	\N	PRESENT	0
132354	131875	11042G	PARTICIPANT	\N	PRESENT	0
132355	131875	90003B	PARTICIPANT	\N	PRESENT	0
132356	131875	99002P	PARTICIPANT	\N	PRESENT	0
132357	131875	95067Q	PARTICIPANT	\N	PRESENT	0
132358	131875	92039X	PARTICIPANT	\N	PRESENT	0
132359	131875	01056V	PARTICIPANT	\N	PRESENT	0
132360	131875	01058X	PARTICIPANT	\N	PRESENT	0
132361	131875	08024S	PARTICIPANT	\N	PRESENT	0
132362	131875	01037S	PARTICIPANT	\N	PRESENT	0
132363	131875	11066Q	PARTICIPANT	\N	PRESENT	0
132364	131875	11068S	PARTICIPANT	\N	PRESENT	0
132366	131875	14081Q	PARTICIPANT	\N	PRESENT	0
132367	131875	04045F	PARTICIPANT	\N	PRESENT	0
132368	131875	11109J	PARTICIPANT	\N	PRESENT	0
132369	131875	04094Q	PARTICIPANT	\N	PRESENT	0
132370	131875	14039A	PARTICIPANT	\N	PRESENT	0
132371	131875	14159V	PARTICIPANT	\N	PRESENT	0
132372	131875	04042C	PARTICIPANT	\N	PRESENT	0
132373	131875	11107G	PARTICIPANT	\N	PRESENT	0
132374	131875	14207L	PARTICIPANT	\N	PRESENT	0
132375	131875	05008E	PARTICIPANT	\N	PRESENT	0
132376	131875	11114F	PARTICIPANT	\N	PRESENT	0
132377	131875	08073C	PARTICIPANT	\N	PRESENT	0
132378	131875	14237S	PARTICIPANT	\N	PRESENT	0
132379	131875	11113E	PARTICIPANT	\N	PRESENT	0
132380	131875	11072N	PARTICIPANT	\N	PRESENT	0
132381	131875	11037K	PARTICIPANT	\N	PRESENT	0
132382	131875	11031D	PARTICIPANT	\N	PRESENT	0
132383	131875	01059Y	PARTICIPANT	\N	PRESENT	0
132384	131875	11065P	PARTICIPANT	\N	PRESENT	0
132385	131875	14213J	PARTICIPANT	\N	PRESENT	0
132386	131875	04097T	PARTICIPANT	\N	PRESENT	0
132387	131875	95049N	PARTICIPANT	\N	PRESENT	0
132388	131875	11094U	PARTICIPANT	\N	PRESENT	0
132389	131875	11076S	PARTICIPANT	\N	PRESENT	0
132390	131875	04092N	PARTICIPANT	\N	PRESENT	0
132391	131875	14073Q	PARTICIPANT	\N	PRESENT	0
132392	131875	04040A	PARTICIPANT	\N	PRESENT	0
132393	131875	14030Q	PARTICIPANT	\N	PRESENT	0
132394	131875	14223L	PARTICIPANT	\N	PRESENT	0
132395	131875	14221J	PARTICIPANT	\N	PRESENT	0
132396	131875	14042U	PARTICIPANT	\N	PRESENT	0
132397	131875	14219Q	PARTICIPANT	\N	PRESENT	0
132398	131875	14267Y	PARTICIPANT	\N	PRESENT	0
132399	131875	01057W	PARTICIPANT	\N	PRESENT	0
132400	131875	14103D	PARTICIPANT	\N	PRESENT	0
132401	131875	08069G	PARTICIPANT	\N	PRESENT	0
132402	131875	11070L	PARTICIPANT	\N	PRESENT	0
132403	131875	08056B	PARTICIPANT	\N	PRESENT	0
132404	131875	98042T	PARTICIPANT	\N	PRESENT	0
132405	131875	14089Y	PARTICIPANT	\N	PRESENT	0
132406	131875	14111D	PARTICIPANT	\N	PRESENT	0
132407	131875	14275Y	PARTICIPANT	\N	PRESENT	0
132408	131875	11082Q	PARTICIPANT	\N	PRESENT	0
132409	131875	07004J	PARTICIPANT	\N	PRESENT	0
132410	131875	11085T	PARTICIPANT	\N	PRESENT	0
132411	131875	92040Q	PARTICIPANT	\N	PRESENT	0
132412	131875	09001P	PARTICIPANT	\N	PRESENT	0
132413	131875	04070G	PARTICIPANT	\N	PRESENT	0
132414	131875	01047U	PARTICIPANT	\N	PRESENT	0
132415	131875	14205J	PARTICIPANT	\N	PRESENT	0
132416	131875	14195A	PARTICIPANT	\N	PRESENT	0
132417	131875	01025N	PARTICIPANT	\N	PRESENT	0
132418	131875	01007L	PARTICIPANT	\N	PRESENT	0
132419	131875	14251Q	PARTICIPANT	\N	PRESENT	0
132420	131875	11044J	PARTICIPANT	\N	PRESENT	0
132422	131875	11097X	PARTICIPANT	\N	PRESENT	0
132423	131875	11026G	PARTICIPANT	\N	PRESENT	0
132425	131875	11091R	PARTICIPANT	\N	PRESENT	0
132426	131875	11071M	PARTICIPANT	\N	PRESENT	0
132428	131875	10015M	PARTICIPANT	\N	PRESENT	0
132430	131875	11049P	PARTICIPANT	\N	PRESENT	0
132431	131875	14033T	PARTICIPANT	\N	PRESENT	0
132432	131875	99004R	PARTICIPANT	\N	PRESENT	0
132433	131875	14135M	PARTICIPANT	\N	PRESENT	0
132434	131875	14061L	PARTICIPANT	\N	PRESENT	0
132435	131875	14059S	PARTICIPANT	\N	PRESENT	0
132436	131875	14041T	PARTICIPANT	\N	PRESENT	0
132437	131875	14253S	PARTICIPANT	\N	PRESENT	0
132438	131875	14123H	PARTICIPANT	\N	PRESENT	0
132439	131875	14031R	PARTICIPANT	\N	PRESENT	0
132440	131875	11101A	PARTICIPANT	\N	PRESENT	0
132441	131875	11010L	PARTICIPANT	\N	PRESENT	0
132442	131875	14119M	PARTICIPANT	\N	PRESENT	0
132444	131875	11090Q	PARTICIPANT	\N	PRESENT	0
132446	131875	14199E	PARTICIPANT	\N	PRESENT	0
132447	131875	14083S	PARTICIPANT	\N	PRESENT	0
132448	131875	07032N	PARTICIPANT	\N	PRESENT	0
132449	131875	14105F	PARTICIPANT	\N	PRESENT	0
132450	131875	92045V	PARTICIPANT	\N	PRESENT	0
132457	131875	14249W	PARTICIPANT	\N	PRESENT	0
132452	131875	11088W	PARTICIPANT	\N	PRESENT	0
132453	131875	01034P	PARTICIPANT	\N	PRESENT	0
132454	131875	04044E	PARTICIPANT	\N	PRESENT	0
132455	131875	04033B	PARTICIPANT	\N	PRESENT	0
132456	131875	04088S	PARTICIPANT	\N	PRESENT	0
157952	157936	04086Q	PARTICIPANT	\N	PRESENT	0
158047	157936	08011M	PARTICIPANT	\N	EXCUSE	0
157954	157936	11070L	PARTICIPANT	\N	PRESENT	0
158212	149494	08051V	PARTICIPANT	\N	PRESENT	0
157956	157936	14327T	PARTICIPANT	\N	EXCUSE	0
157957	157936	08022Q	PARTICIPANT	\N	PRESENT	0
157958	157936	01027Q	PARTICIPANT	\N	PRESENT	0
158213	149494	14071N	PARTICIPANT	\N	PRESENT	0
157960	157936	11074Q	PARTICIPANT	\N	PRESENT	0
157961	157936	98053W	PARTICIPANT	\N	EXCUSE	0
157962	157936	11083R	PARTICIPANT	\N	PRESENT	0
158215	158214	08051V	PARTICIPANT	\N	PRESENT	0
157964	157936	01057W	PARTICIPANT	\N	PRESENT	0
158216	158214	14071N	PARTICIPANT	\N	PRESENT	0
158218	149492	08051V	PARTICIPANT	\N	PRESENT	0
157967	157936	11048N	PARTICIPANT	\N	PRESENT	0
158219	149492	14071N	PARTICIPANT	\N	PRESENT	0
157969	157936	04061F	PARTICIPANT	\N	PRESENT	0
157970	157936	14159V	PARTICIPANT	\N	PRESENT	0
157971	157936	07029T	PARTICIPANT	\N	PRESENT	0
158974	158973	96004D	PRESIDENT	1	PRESENT	0
157973	157936	08010L	PARTICIPANT	\N	PRESENT	0
157974	157936	08034U	PARTICIPANT	\N	PRESENT	0
158975	158973	04042C	PARTICIPANT	\N	EXCUSE	0
157976	157936	98046X	PARTICIPANT	\N	PRESENT	0
157977	157936	11085T	PARTICIPANT	\N	EXCUSE	0
158976	158973	04035D	PARTICIPANT	\N	PRESENT	0
157979	157936	08073C	PRESIDENT	0	PRESENT	0
157980	157936	08061X	PARTICIPANT	\N	PRESENT	0
157981	157936	01016M	PARTICIPANT	\N	PRESENT	0
157982	157936	14225N	PARTICIPANT	\N	PRESENT	0
157983	157936	11012A	PARTICIPANT	\N	EXCUSE	0
158977	158973	14014Q	PARTICIPANT	\N	PRESENT	0
157985	157936	14173T	PARTICIPANT	\N	PRESENT	0
157986	157936	04034C	PARTICIPANT	\N	PRESENT	0
158978	158973	14097Y	PARTICIPANT	\N	PRESENT	0
158979	158973	04061F	PARTICIPANT	\N	PRESENT	0
158980	158973	14001X	PARTICIPANT	\N	EXCUSE	0
158981	158973	95059Q	PRESIDENT	0	PRESENT	0
158982	158973	04034C	PARTICIPANT	\N	PRESENT	0
159373	159372	14089Y	PARTICIPANT	\N	PRESENT	0
159374	159372	14207L	PRESIDENT	0	PRESENT	0
159375	159372	04038G	PARTICIPANT	\N	PRESENT	0
159376	159372	14031R	PARTICIPANT	\N	PRESENT	0
159377	159372	14135M	PARTICIPANT	\N	PRESENT	0
159378	159372	14229S	PARTICIPANT	\N	PRESENT	0
159379	159372	14087W	PARTICIPANT	\N	EXCUSE	0
159380	159372	11014C	PARTICIPANT	\N	EXCUSE	0
159381	159372	11029K	PARTICIPANT	\N	EXCUSE	0
159382	159372	04057K	PARTICIPANT	\N	EXCUSE	0
159393	159392	11049P	PARTICIPANT	\N	PRESENT	0
159428	157432	11106F	PARTICIPANT	\N	EXCUSE	0
159429	157432	11010L	PARTICIPANT	\N	EXCUSE	0
159493	159492	11089X	PARTICIPANT	0	PRESENT	0
159494	159492	14299H	PARTICIPANT	0	PRESENT	0
159906	158052	77002U	PARTICIPANT	\N	PRESENT	0
159907	158052	04056J	PARTICIPANT	\N	PRESENT	0
159908	158052	98024R	PARTICIPANT	\N	PRESENT	0
159913	158052	08069G	PARTICIPANT	\N	PRESENT	0
159915	158052	11090Q	PARTICIPANT	\N	PRESENT	0
159911	158052	04097T	PARTICIPANT	\N	PRESENT	0
159912	158052	14087W	PARTICIPANT	\N	PRESENT	0
159914	158052	86034E	PARTICIPANT	\N	PRESENT	0
159916	158052	14237S	PARTICIPANT	\N	PRESENT	0
159926	158052	11065P	PARTICIPANT	\N	PRESENT	0
159927	158052	14034U	PARTICIPANT	\N	PRESENT	0
159928	158052	11026G	PARTICIPANT	\N	PRESENT	0
159929	158052	08017T	PARTICIPANT	\N	PRESENT	0
159934	158052	11031D	PARTICIPANT	\N	PRESENT	0
159935	158052	01015L	PARTICIPANT	\N	PRESENT	0
159952	158052	98053W	PARTICIPANT	\N	PRESENT	0
159953	158052	11084S	PARTICIPANT	\N	PRESENT	0
159954	158052	14123H	PARTICIPANT	\N	PRESENT	0
159955	158052	14093U	PARTICIPANT	\N	PRESENT	0
160206	158053	01007L	PARTICIPANT	\N	PRESENT	0
159957	158052	11085T	PARTICIPANT	\N	PRESENT	0
159958	158052	99004R	PARTICIPANT	\N	PRESENT	0
160207	158053	04034C	PARTICIPANT	\N	PRESENT	0
160208	158053	11083R	PARTICIPANT	\N	PRESENT	0
160209	158053	98022P	PARTICIPANT	\N	PRESENT	0
160210	158053	14219Q	PARTICIPANT	\N	PRESENT	0
160211	158053	04038G	PARTICIPANT	\N	PRESENT	0
160212	158053	04088S	PARTICIPANT	\N	PRESENT	0
160213	158053	14033T	PARTICIPANT	\N	PRESENT	0
160214	158053	14133K	PARTICIPANT	\N	PRESENT	0
160215	158053	96004D	PARTICIPANT	\N	PRESENT	0
160216	158053	98053W	PARTICIPANT	\N	PRESENT	0
160217	158053	12041X	PARTICIPANT	\N	PRESENT	0
160218	158053	14083S	PARTICIPANT	\N	PRESENT	0
160232	158053	08043V	PARTICIPANT	\N	PRESENT	0
160233	158053	14247U	PARTICIPANT	\N	PRESENT	0
160234	158053	04092N	PARTICIPANT	\N	PRESENT	0
160235	158053	08055A	PARTICIPANT	\N	PRESENT	0
160237	160236	98021N	PARTICIPANT	\N	PRESENT	0
160240	160239	98021N	PARTICIPANT	\N	PRESENT	0
160245	158053	14267Y	PARTICIPANT	\N	PRESENT	0
160246	158053	11053K	PARTICIPANT	\N	PRESENT	0
160248	160247	14193X	PARTICIPANT	\N	PRESENT	0
160249	158053	01003G	PARTICIPANT	\N	PRESENT	0
160250	160247	04040A	PARTICIPANT	\N	PRESENT	0
160251	160247	11054L	PARTICIPANT	\N	PRESENT	0
160252	160247	08049C	PARTICIPANT	\N	PRESENT	0
160253	158053	14237S	PARTICIPANT	\N	PRESENT	0
160254	158053	04036E	PARTICIPANT	\N	PRESENT	0
160256	160255	14193X	PARTICIPANT	\N	PRESENT	0
160257	160255	04040A	PARTICIPANT	\N	PRESENT	0
160258	160255	11054L	PARTICIPANT	\N	PRESENT	0
160260	160255	08049C	PARTICIPANT	\N	PRESENT	0
160264	158053	04050C	PARTICIPANT	\N	PRESENT	0
160303	158053	14363X	PARTICIPANT	\N	PRESENT	0
160304	158053	07029T	PARTICIPANT	\N	PRESENT	0
160312	158053	01034P	PARTICIPANT	\N	PRESENT	0
160313	158054	01007L	PARTICIPANT	\N	PRESENT	0
160314	158054	11031D	PARTICIPANT	\N	PRESENT	0
160315	158054	04050C	PARTICIPANT	\N	PRESENT	0
160316	158054	01059Y	PARTICIPANT	\N	PRESENT	0
160317	158054	98053W	PARTICIPANT	\N	PRESENT	0
160318	158054	11034G	PARTICIPANT	\N	PRESENT	0
160319	158054	04085P	PARTICIPANT	\N	PRESENT	0
160320	158054	11083R	PARTICIPANT	\N	PRESENT	0
160321	158054	11055M	PARTICIPANT	\N	PRESENT	0
160322	158054	14239U	PARTICIPANT	\N	PRESENT	0
160323	158054	04092N	PARTICIPANT	\N	PRESENT	0
160324	158054	14083S	PARTICIPANT	\N	PRESENT	0
160325	158054	14111D	PARTICIPANT	\N	PRESENT	0
160326	158054	14237S	PARTICIPANT	\N	PRESENT	0
160327	158054	11061K	PARTICIPANT	\N	PRESENT	0
160352	158054	08073C	PARTICIPANT	\N	PRESENT	0
160353	158054	04067M	PARTICIPANT	\N	PRESENT	0
160419	160418	04080J	PARTICIPANT	\N	PRESENT	0
160433	160432	04080J	PARTICIPANT	\N	PRESENT	0
160453	160452	04080J	PARTICIPANT	\N	PRESENT	0
160454	160452	14014Q	PARTICIPANT	\N	PRESENT	0
160473	160472	07034Q	PARTICIPANT	\N	PRESENT	0
160593	160592	04074L	PARTICIPANT	\N	PRESENT	0
160613	160612	05008E	PARTICIPANT	\N	PRESENT	0
160614	160612	14065Q	PARTICIPANT	\N	PRESENT	0
160537	160532	14030Q	PARTICIPANT	\N	PRESENT	0
160616	160615	05008E	PARTICIPANT	\N	PRESENT	0
160653	160652	14028W	PARTICIPANT	\N	PRESENT	0
160654	160652	01027Q	PARTICIPANT	\N	PRESENT	0
160655	160652	04040A	PARTICIPANT	\N	PRESENT	0
160657	160656	01044R	PARTICIPANT	\N	PRESENT	0
160658	160656	08060W	PARTICIPANT	\N	PRESENT	0
160659	160656	11065P	PARTICIPANT	\N	PRESENT	0
160660	160656	98042T	PARTICIPANT	\N	PRESENT	0
160661	160656	14199E	PARTICIPANT	\N	PRESENT	0
160662	160656	95041E	PARTICIPANT	\N	PRESENT	0
160663	160656	14073Q	PARTICIPANT	\N	PRESENT	0
160549	160532	01022K	PARTICIPANT	\N	PRESENT	0
160664	160656	14031R	PARTICIPANT	\N	PRESENT	0
160665	160656	11072N	PARTICIPANT	\N	PRESENT	0
160666	160656	11012A	PARTICIPANT	\N	PRESENT	0
160667	160656	14173T	PARTICIPANT	\N	PRESENT	0
160668	160656	04034C	PARTICIPANT	\N	PRESENT	0
160673	160672	01028R	PARTICIPANT	\N	PRESENT	0
160556	160532	14031R	PARTICIPANT	\N	PRESENT	0
160675	160674	14207L	PARTICIPANT	\N	PRESENT	0
160676	160674	14089Y	PARTICIPANT	\N	PRESENT	0
160732	159492	14257W	PARTICIPANT	\N	EXCUSE	0
160733	159492	11082Q	PARTICIPANT	\N	EXCUSE	0
160753	160752	05008E	PRESIDENT	0	PRESENT	0
160754	160752	11033F	PARTICIPANT	\N	EXCUSE	0
160755	160752	14069U	PARTICIPANT	\N	PRESENT	0
160756	160752	14259Y	PARTICIPANT	\N	PRESENT	0
160757	160752	14041T	PARTICIPANT	\N	PRESENT	0
160758	160752	11113E	PARTICIPANT	\N	PRESENT	0
160568	160532	14331P	PARTICIPANT	\N	PRESENT	0
133692	133126	07032N	PARTICIPANT	\N	PRESENT	0
133693	133126	08010L	PARTICIPANT	\N	PRESENT	0
133694	133126	08051V	PARTICIPANT	\N	PRESENT	0
133695	133126	04079R	PARTICIPANT	\N	PRESENT	0
133699	133126	01034P	PARTICIPANT	\N	PRESENT	0
133697	133126	08025T	PARTICIPANT	\N	PRESENT	0
133698	133126	92040Q	PARTICIPANT	\N	PRESENT	0
134104	133128	08024S	PARTICIPANT	\N	PRESENT	0
134105	133128	14263U	PARTICIPANT	\N	PRESENT	0
134106	133128	11043H	PARTICIPANT	\N	PRESENT	0
134107	133128	11054L	PARTICIPANT	\N	PRESENT	0
134108	133128	14063N	PARTICIPANT	\N	PRESENT	0
134109	133128	80013X	PARTICIPANT	\N	PRESENT	0
134110	133128	14107H	PARTICIPANT	\N	PRESENT	0
134111	133128	11105E	PARTICIPANT	\N	PRESENT	0
134112	133128	11104D	PARTICIPANT	\N	PRESENT	0
134113	133128	92015P	PARTICIPANT	\N	PRESENT	0
134114	133128	14235Q	PARTICIPANT	\N	PRESENT	0
134115	133128	14013P	PARTICIPANT	\N	PRESENT	0
134116	133128	11099A	PARTICIPANT	\N	PRESENT	0
134117	133128	08012N	PARTICIPANT	\N	PRESENT	0
134118	133128	13002U	PARTICIPANT	\N	PRESENT	0
134119	133128	11029K	PARTICIPANT	\N	PRESENT	0
134120	133128	01003G	PARTICIPANT	\N	PRESENT	0
134121	133128	04067M	PARTICIPANT	\N	PRESENT	0
134122	133128	14261S	PARTICIPANT	\N	PRESENT	0
134123	133128	11107G	PARTICIPANT	\N	PRESENT	0
134124	133128	11037K	PARTICIPANT	\N	PRESENT	0
134125	133128	14103D	PARTICIPANT	\N	PRESENT	0
134126	133128	14219Q	PARTICIPANT	\N	PRESENT	0
134127	133128	14030Q	PARTICIPANT	\N	PRESENT	0
134128	133128	14073Q	PARTICIPANT	\N	PRESENT	0
134129	133128	11082Q	PARTICIPANT	\N	PRESENT	0
134130	133128	14231L	PARTICIPANT	\N	PRESENT	0
134131	133128	14249W	PARTICIPANT	\N	PRESENT	0
134132	133128	14237S	PARTICIPANT	\N	PRESENT	0
134133	133128	14193X	PARTICIPANT	\N	PRESENT	0
134134	133128	14059S	PARTICIPANT	\N	PRESENT	0
134135	133128	14061L	PARTICIPANT	\N	PRESENT	0
134136	133128	04049K	PARTICIPANT	\N	PRESENT	0
134137	133128	98050T	PARTICIPANT	\N	PRESENT	0
134138	133128	14187A	PARTICIPANT	\N	PRESENT	0
134139	133128	08060W	PARTICIPANT	\N	PRESENT	0
134140	133128	14265W	PARTICIPANT	\N	PRESENT	0
134141	133128	14093U	PARTICIPANT	\N	PRESENT	0
134142	133128	08016S	PARTICIPANT	\N	PRESENT	0
134143	133128	11049P	PARTICIPANT	\N	PRESENT	0
134144	133128	08048B	PARTICIPANT	\N	PRESENT	0
134145	133128	14041T	PARTICIPANT	\N	PRESENT	0
134146	133128	14221J	PARTICIPANT	\N	PRESENT	0
134147	133128	14038Y	PARTICIPANT	\N	PRESENT	0
134148	133128	14133K	PARTICIPANT	\N	PRESENT	0
134151	133128	14229S	PARTICIPANT	\N	PRESENT	0
134152	133128	11014C	PARTICIPANT	\N	PRESENT	0
134153	133128	08043V	PARTICIPANT	\N	PRESENT	0
134154	133128	14026U	PARTICIPANT	\N	PRESENT	0
134155	133128	11091R	PARTICIPANT	\N	PRESENT	0
134156	133128	14135M	PARTICIPANT	\N	PRESENT	0
134157	133128	87003B	PARTICIPANT	\N	PRESENT	0
134158	133128	04070G	PARTICIPANT	\N	PRESENT	0
134159	133128	01025N	PARTICIPANT	\N	PRESENT	0
134174	133128	04043D	PARTICIPANT	\N	PRESENT	0
134175	133128	14109K	PARTICIPANT	\N	PRESENT	0
134176	133128	14042U	PARTICIPANT	\N	PRESENT	0
134219	133130	92015P	PARTICIPANT	\N	PRESENT	0
134220	133130	08060W	PARTICIPANT	\N	PRESENT	0
134221	133130	11104D	PARTICIPANT	\N	PRESENT	0
134222	133130	14229S	PARTICIPANT	\N	PRESENT	0
134223	133130	14109K	PARTICIPANT	\N	PRESENT	0
134224	133130	11089X	PARTICIPANT	\N	PRESENT	0
134225	133130	11054L	PARTICIPANT	\N	PRESENT	0
134226	133130	01015L	PARTICIPANT	\N	PRESENT	0
134227	133130	14235Q	PARTICIPANT	\N	PRESENT	0
134228	133130	11014C	PARTICIPANT	\N	PRESENT	0
134229	133130	14231L	PARTICIPANT	\N	PRESENT	0
134230	133130	14042U	PARTICIPANT	\N	PRESENT	0
134231	133130	14073Q	PARTICIPANT	\N	PRESENT	0
134232	133130	14219Q	PARTICIPANT	\N	PRESENT	0
134233	133130	01025N	PARTICIPANT	\N	PRESENT	0
134234	133130	08055A	PARTICIPANT	\N	PRESENT	0
134235	133130	14263U	PARTICIPANT	\N	PRESENT	0
134236	133130	14209N	PARTICIPANT	\N	PRESENT	0
134237	133130	14059S	PARTICIPANT	\N	PRESENT	0
134238	133130	08048B	PARTICIPANT	\N	PRESENT	0
134239	133130	11091R	PARTICIPANT	\N	PRESENT	0
134240	133130	11049P	PARTICIPANT	\N	PRESENT	0
134241	133130	08010L	PARTICIPANT	\N	PRESENT	0
134242	133130	04071H	PARTICIPANT	\N	PRESENT	0
134243	133130	14079W	PARTICIPANT	\N	PRESENT	0
134244	133130	11107G	PARTICIPANT	\N	PRESENT	0
134249	133130	95030B	PARTICIPANT	\N	PRESENT	0
134250	133130	08009T	PARTICIPANT	\N	PRESENT	0
134251	133130	04043D	PARTICIPANT	\N	PRESENT	0
134252	133130	04057K	PARTICIPANT	\N	PRESENT	0
134253	133130	14327T	PARTICIPANT	\N	PRESENT	0
134254	133130	11053K	PARTICIPANT	\N	PRESENT	0
134255	133130	14107H	PARTICIPANT	\N	PRESENT	0
134256	133130	14038Y	PARTICIPANT	\N	PRESENT	0
134257	133130	14237S	PARTICIPANT	\N	PRESENT	0
134258	133130	08062Y	PARTICIPANT	\N	PRESENT	0
134259	133130	14135M	PARTICIPANT	\N	PRESENT	0
134260	133130	14217N	PARTICIPANT	\N	PRESENT	0
134261	133130	14169X	PARTICIPANT	\N	PRESENT	0
134262	133130	14215L	PARTICIPANT	\N	PRESENT	0
134217	133130	14331P	PARTICIPANT	\N	PRESENT	0
134218	133130	08024S	PARTICIPANT	\N	PRESENT	0
134263	133130	11082Q	PARTICIPANT	\N	PRESENT	0
134264	133130	98022P	PARTICIPANT	\N	PRESENT	0
134265	133130	08051V	PARTICIPANT	\N	PRESENT	0
134266	133130	95062K	PARTICIPANT	\N	PRESENT	0
134267	133130	04053F	PARTICIPANT	\N	PRESENT	0
134268	133130	04067M	PARTICIPANT	\N	PRESENT	0
134269	133130	14261S	PARTICIPANT	\N	PRESENT	0
134270	133130	14103D	PARTICIPANT	\N	PRESENT	0
134271	133130	14105F	PARTICIPANT	\N	PRESENT	0
134272	133130	11065P	PARTICIPANT	\N	PRESENT	0
134275	133130	14147R	PARTICIPANT	\N	PRESENT	0
134276	133130	14271U	PARTICIPANT	\N	PRESENT	0
134277	133130	14089Y	PARTICIPANT	\N	PRESENT	0
134290	133130	01022K	PARTICIPANT	\N	PRESENT	0
134291	133130	11097X	PARTICIPANT	\N	PRESENT	0
134292	133130	14197C	PARTICIPANT	\N	PRESENT	0
134293	133130	14014Q	PARTICIPANT	\N	PRESENT	0
134294	133130	11112D	PARTICIPANT	\N	PRESENT	0
134295	133130	14030Q	PARTICIPANT	\N	PRESENT	0
134296	133130	88008L	PARTICIPANT	\N	PRESENT	0
134297	133130	80013X	PARTICIPANT	\N	PRESENT	0
134298	133130	11036J	PARTICIPANT	\N	PRESENT	0
134299	133130	14205J	PARTICIPANT	\N	PRESENT	0
134300	133130	13002U	PARTICIPANT	\N	PRESENT	0
134301	133130	14259Y	PARTICIPANT	\N	PRESENT	0
134302	133130	14187A	PARTICIPANT	\N	PRESENT	0
134303	133130	08015R	PARTICIPANT	\N	PRESENT	0
134304	133130	14265W	PARTICIPANT	\N	PRESENT	0
134305	133130	04088S	PARTICIPANT	\N	PRESENT	0
134306	133130	11066Q	PARTICIPANT	\N	PRESENT	0
134307	133130	14159V	PARTICIPANT	\N	PRESENT	0
134348	133130	14175V	PARTICIPANT	\N	PRESENT	0
134349	133130	11012A	PARTICIPANT	\N	PRESENT	0
134350	133130	14031R	PARTICIPANT	\N	PRESENT	0
134351	133130	14053L	PARTICIPANT	\N	PRESENT	0
134352	133130	95063L	PARTICIPANT	\N	PRESENT	0
134353	133130	14033T	PARTICIPANT	\N	PRESENT	0
134354	133130	14199E	PARTICIPANT	\N	PRESENT	0
134404	133130	92045V	PARTICIPANT	\N	PRESENT	0
151751	149972	97011G	PARTICIPANT	\N	PRESENT	0
151752	149972	11036J	PARTICIPANT	\N	PRESENT	0
151753	149972	95015C	PARTICIPANT	\N	PRESENT	0
151754	149972	11070L	PARTICIPANT	\N	PRESENT	0
151755	149972	11033F	PARTICIPANT	\N	PRESENT	0
151756	149972	11025F	PARTICIPANT	\N	PRESENT	0
151772	149972	14034U	PARTICIPANT	\N	PRESENT	0
151773	149972	01034P	PARTICIPANT	\N	PRESENT	0
151774	149972	14073Q	PARTICIPANT	\N	PRESENT	0
151792	149972	14026U	PARTICIPANT	\N	PRESENT	0
151793	149972	11097X	PARTICIPANT	\N	PRESENT	0
151794	149972	14121F	PARTICIPANT	\N	PRESENT	0
151795	149972	11040E	PARTICIPANT	\N	PRESENT	0
151798	149972	95063L	PARTICIPANT	\N	PRESENT	0
151799	149972	14213J	PARTICIPANT	\N	PRESENT	0
151800	149972	11110B	PARTICIPANT	\N	PRESENT	0
151801	149972	14097Y	PARTICIPANT	\N	PRESENT	0
151802	149972	95049N	PARTICIPANT	\N	PRESENT	0
151803	149972	12042Y	PARTICIPANT	\N	PRESENT	0
151804	149972	04086Q	PARTICIPANT	\N	PRESENT	0
151814	149972	11104D	PARTICIPANT	\N	PRESENT	0
151807	149972	98022P	PARTICIPANT	\N	PRESENT	0
151808	149972	14225N	PARTICIPANT	\N	PRESENT	0
151809	149972	92045V	PARTICIPANT	\N	PRESENT	0
151812	149972	04057K	PARTICIPANT	\N	PRESENT	0
151813	149972	11112D	PARTICIPANT	\N	PRESENT	0
151815	149972	14281W	PARTICIPANT	\N	PRESENT	0
151917	149975	11066Q	PARTICIPANT	\N	PRESENT	0
151918	149975	11035H	PARTICIPANT	\N	PRESENT	0
151919	149975	11104D	PARTICIPANT	\N	PRESENT	0
151920	149975	13002U	PARTICIPANT	\N	PRESENT	0
151921	149975	14197C	PARTICIPANT	\N	PRESENT	0
151922	149975	11098Y	PARTICIPANT	\N	PRESENT	0
151923	149975	01059Y	PARTICIPANT	\N	PRESENT	0
151924	149975	11036J	PARTICIPANT	\N	PRESENT	0
151925	149975	14014Q	PARTICIPANT	\N	PRESENT	0
151926	149975	11025F	PARTICIPANT	\N	PRESENT	0
151927	149975	11056N	PARTICIPANT	\N	PRESENT	0
151928	149975	98022P	PARTICIPANT	\N	PRESENT	0
151929	149975	14225N	PARTICIPANT	\N	PRESENT	0
151930	149975	14073Q	PARTICIPANT	\N	PRESENT	0
151931	149975	11070L	PARTICIPANT	\N	PRESENT	0
151932	149975	14205J	PARTICIPANT	\N	PRESENT	0
151933	149975	14030Q	PARTICIPANT	\N	PRESENT	0
151934	149975	01025N	PARTICIPANT	\N	PRESENT	0
151935	149975	14281W	PARTICIPANT	\N	PRESENT	0
151936	149975	14227Q	PARTICIPANT	\N	PRESENT	0
151937	149975	11110B	PARTICIPANT	\N	PRESENT	0
151938	149975	14187A	PARTICIPANT	\N	PRESENT	0
151939	149975	14061L	PARTICIPANT	\N	PRESENT	0
151940	149975	14213J	PARTICIPANT	\N	PRESENT	0
151941	149975	14026U	PARTICIPANT	\N	PRESENT	0
151942	149975	04088S	PARTICIPANT	\N	PRESENT	0
151943	149975	08015R	PARTICIPANT	\N	PRESENT	0
151944	149975	08039A	PARTICIPANT	\N	PRESENT	0
151945	149975	11043H	PARTICIPANT	\N	PRESENT	0
151946	149975	04043D	PARTICIPANT	\N	PRESENT	0
151947	149975	77002U	PARTICIPANT	\N	PRESENT	0
151948	149975	14033T	PARTICIPANT	\N	PRESENT	0
151949	149975	11103C	PARTICIPANT	\N	PRESENT	0
151950	149975	01011G	PARTICIPANT	\N	PRESENT	0
151951	149975	14097Y	PARTICIPANT	\N	PRESENT	0
151952	149975	95030B	PARTICIPANT	\N	PRESENT	0
151953	149975	14147R	PARTICIPANT	\N	PRESENT	0
151954	149975	01027Q	PARTICIPANT	\N	PRESENT	0
151955	149975	11088W	PARTICIPANT	\N	PRESENT	0
151956	149975	04057K	PARTICIPANT	\N	PRESENT	0
151957	149975	14039A	PARTICIPANT	\N	PRESENT	0
151958	149975	04081K	PARTICIPANT	\N	PRESENT	0
151960	149975	80013X	PARTICIPANT	\N	PRESENT	0
151961	149975	11094U	PARTICIPANT	\N	PRESENT	0
151962	149975	92045V	PARTICIPANT	\N	PRESENT	0
151964	149975	14265W	PARTICIPANT	\N	PRESENT	0
151967	149975	04086Q	PARTICIPANT	\N	PRESENT	0
151970	149975	98046X	PARTICIPANT	\N	PRESENT	0
151973	149975	14249W	PARTICIPANT	\N	PRESENT	0
151977	149975	08055A	PARTICIPANT	\N	PRESENT	0
151978	149975	08014Q	PARTICIPANT	\N	PRESENT	0
151979	149975	14201E	PARTICIPANT	\N	PRESENT	0
151980	149975	11081P	PARTICIPANT	\N	PRESENT	0
151981	149975	11080N	PARTICIPANT	\N	PRESENT	0
151982	149975	14038Y	PARTICIPANT	\N	PRESENT	0
151983	149975	92015P	PARTICIPANT	\N	PRESENT	0
151984	149975	08052W	PARTICIPANT	\N	PRESENT	0
151985	149975	11093T	PARTICIPANT	\N	PRESENT	0
151986	149975	14267Y	PARTICIPANT	\N	PRESENT	0
151987	149975	14103D	PARTICIPANT	\N	PRESENT	0
151988	149975	11027H	PARTICIPANT	\N	PRESENT	0
151989	149975	08058D	PARTICIPANT	\N	PRESENT	0
151990	149975	12042Y	PARTICIPANT	\N	PRESENT	0
151991	149975	08051V	PARTICIPANT	\N	PRESENT	0
151992	149975	14063N	PARTICIPANT	\N	PRESENT	0
151993	149975	14121F	PARTICIPANT	\N	PRESENT	0
151994	149975	11112D	PARTICIPANT	\N	PRESENT	0
151995	149975	11065P	PARTICIPANT	\N	PRESENT	0
151996	149975	04053F	PARTICIPANT	\N	PRESENT	0
151997	149975	01015L	PARTICIPANT	\N	PRESENT	0
151998	149975	80027E	PARTICIPANT	\N	PRESENT	0
151999	149975	14235Q	PARTICIPANT	\N	PRESENT	0
152000	149975	11054L	PARTICIPANT	\N	PRESENT	0
152001	149975	04034C	PARTICIPANT	\N	PRESENT	0
152002	149975	04067M	PARTICIPANT	\N	PRESENT	0
152003	149975	11029K	PARTICIPANT	\N	PRESENT	0
152004	149975	11033F	PARTICIPANT	\N	PRESENT	0
152005	149975	11083R	PARTICIPANT	\N	PRESENT	0
152006	149975	89017R	PARTICIPANT	\N	PRESENT	0
152007	149975	01046T	PARTICIPANT	\N	PRESENT	0
152008	149975	88008L	PARTICIPANT	\N	PRESENT	0
152009	149975	11012A	PARTICIPANT	\N	PRESENT	0
152010	149975	14241N	PARTICIPANT	\N	PRESENT	0
152012	149975	11040E	PARTICIPANT	\N	PRESENT	0
152013	149975	95049N	PARTICIPANT	\N	PRESENT	0
152014	149975	11053K	PARTICIPANT	\N	PRESENT	0
152015	149975	14089Y	PARTICIPANT	\N	PRESENT	0
152016	149975	14034U	PARTICIPANT	\N	PRESENT	0
152018	149975	14042U	PARTICIPANT	\N	PRESENT	0
152020	149975	14219Q	PARTICIPANT	\N	PRESENT	0
152022	149975	14221J	PARTICIPANT	\N	PRESENT	0
152024	149975	11111C	PARTICIPANT	\N	PRESENT	0
152025	149975	98042T	PARTICIPANT	\N	PRESENT	0
152026	149975	14231L	PARTICIPANT	\N	PRESENT	0
152028	149975	14327T	PARTICIPANT	\N	PRESENT	0
152029	149975	01034P	PARTICIPANT	\N	PRESENT	0
152030	149975	01047U	PARTICIPANT	\N	PRESENT	0
152031	149975	08016S	PARTICIPANT	\N	PRESENT	0
152032	149975	11039M	PARTICIPANT	\N	PRESENT	0
151915	149975	86034E	PARTICIPANT	\N	PRESENT	0
151916	149975	14107H	PARTICIPANT	\N	PRESENT	0
152033	149975	04056J	PARTICIPANT	\N	PRESENT	0
152034	149975	01016M	PARTICIPANT	\N	PRESENT	0
152035	149975	04085P	PARTICIPANT	\N	PRESENT	0
152036	149975	14247U	PARTICIPANT	\N	PRESENT	0
152037	149975	14051J	PARTICIPANT	\N	PRESENT	0
152038	149975	08060W	PARTICIPANT	\N	PRESENT	0
152039	149975	11067R	PARTICIPANT	\N	PRESENT	0
152040	149975	11089X	PARTICIPANT	\N	PRESENT	0
152041	149975	01031L	PARTICIPANT	\N	PRESENT	0
152042	149975	98029W	PARTICIPANT	\N	PRESENT	0
152043	149975	14083S	PARTICIPANT	\N	PRESENT	0
152044	149975	04066L	PARTICIPANT	\N	PRESENT	0
152045	149975	14207L	PARTICIPANT	\N	PRESENT	0
152046	149975	14271U	PARTICIPANT	\N	PRESENT	0
152047	149975	14263U	PARTICIPANT	\N	PRESENT	0
152048	149975	11061K	PARTICIPANT	\N	PRESENT	0
152049	149975	11014C	PARTICIPANT	\N	PRESENT	0
152050	149975	04079R	PARTICIPANT	\N	PRESENT	0
152051	149975	08038Y	PARTICIPANT	\N	PRESENT	0
152052	149975	95063L	PARTICIPANT	\N	PRESENT	0
152053	149975	92039X	PARTICIPANT	\N	PRESENT	0
152054	149975	04045F	PARTICIPANT	\N	PRESENT	0
152055	149975	14269B	PARTICIPANT	\N	PRESENT	0
152056	149975	08073C	PARTICIPANT	\N	PRESENT	0
152057	149975	11042G	PARTICIPANT	\N	PRESENT	0
152058	149975	11113E	PARTICIPANT	\N	PRESENT	0
152059	149975	14037X	PARTICIPANT	\N	PRESENT	0
152060	149975	98053W	PARTICIPANT	\N	PRESENT	0
152061	149975	14159V	PARTICIPANT	\N	PRESENT	0
152062	149975	01056V	PARTICIPANT	\N	PRESENT	0
152063	149975	08010L	PARTICIPANT	\N	PRESENT	0
152064	149975	95015C	PARTICIPANT	\N	PRESENT	0
152065	149975	95067Q	PARTICIPANT	\N	PRESENT	0
152066	149975	01057W	PARTICIPANT	\N	PRESENT	0
152067	149975	11068S	PARTICIPANT	\N	PRESENT	0
152068	149975	11011M	PARTICIPANT	\N	PRESENT	0
152069	149975	14031R	PARTICIPANT	\N	PRESENT	0
152070	149975	08034U	PARTICIPANT	\N	PRESENT	0
152071	149975	14251Q	PARTICIPANT	\N	PRESENT	0
152072	149975	11097X	PARTICIPANT	\N	PRESENT	0
128893	128851	08025T	PARTICIPANT	\N	PRESENT	0
128894	128851	04085P	PARTICIPANT	\N	PRESENT	0
128895	128851	05008E	PARTICIPANT	\N	PRESENT	0
129204	129201	00003C	PARTICIPANT	\N	EXCUSE	0
130033	129541	14071N	PARTICIPANT	\N	PRESENT	0
128898	128851	14065Q	PARTICIPANT	\N	PRESENT	0
128899	128851	14069U	PARTICIPANT	\N	PRESENT	0
128900	128851	04047H	PARTICIPANT	\N	PRESENT	0
128901	128851	11032E	PARTICIPANT	\N	PRESENT	0
128902	128851	04038G	PARTICIPANT	\N	PRESENT	0
128903	128851	99002P	PARTICIPANT	\N	PRESENT	0
128904	128851	11056N	PARTICIPANT	\N	PRESENT	0
128905	128851	14259Y	PARTICIPANT	\N	PRESENT	0
129290	129201	14231L	PARTICIPANT	\N	EXCUSE	0
130117	130116	08058D	PARTICIPANT	\N	PRESENT	0
128908	128851	11113E	PARTICIPANT	\N	PRESENT	0
129211	129201	14239U	PARTICIPANT	\N	PRESENT	0
128910	128851	14215L	PARTICIPANT	\N	PRESENT	0
128911	128851	11034G	PARTICIPANT	\N	PRESENT	0
128912	128851	08018U	PARTICIPANT	\N	PRESENT	0
129212	129201	11055M	PARTICIPANT	\N	PRESENT	0
128914	128851	01007L	PARTICIPANT	\N	PRESENT	0
128915	128851	11049P	PARTICIPANT	\N	PRESENT	0
128916	128851	08044W	PARTICIPANT	\N	EXCUSE	0
128917	128851	11084S	PARTICIPANT	\N	PRESENT	0
129213	129201	01046T	PARTICIPANT	\N	PRESENT	0
128919	128851	04079R	PARTICIPANT	\N	PRESENT	0
128920	128851	14111D	PARTICIPANT	\N	PRESENT	0
128921	128851	14001X	PARTICIPANT	\N	PRESENT	0
129214	129201	04053F	PARTICIPANT	\N	PRESENT	0
128923	128851	01060R	PARTICIPANT	\N	PRESENT	0
128924	128851	14147R	PARTICIPANT	\N	PRESENT	0
128925	128851	95049N	PARTICIPANT	\N	PRESENT	0
128926	128851	08051V	PARTICIPANT	\N	PRESENT	0
129215	129201	14255U	PARTICIPANT	\N	PRESENT	0
129216	129201	04066L	PARTICIPANT	\N	PRESENT	0
128929	128851	04074L	PARTICIPANT	\N	PRESENT	0
128930	128851	10015M	PARTICIPANT	\N	PRESENT	0
128931	128851	95063L	PARTICIPANT	\N	PRESENT	0
128932	128851	01019Q	PARTICIPANT	\N	PRESENT	0
128933	128851	01028R	PARTICIPANT	\N	PRESENT	0
128934	128851	98035U	PARTICIPANT	\N	PRESENT	0
128935	128851	04056J	PARTICIPANT	\N	PRESENT	0
129217	129201	14053L	PARTICIPANT	\N	PRESENT	0
128937	128851	04044E	PARTICIPANT	\N	PRESENT	0
128938	128851	11037K	PARTICIPANT	\N	PRESENT	0
128939	128851	92045V	PARTICIPANT	\N	PRESENT	0
128940	128851	95067Q	PARTICIPANT	\N	PRESENT	0
128941	128851	01047U	PARTICIPANT	\N	PRESENT	0
129218	129201	11103C	PARTICIPANT	\N	PRESENT	0
129219	129201	11044J	PARTICIPANT	\N	PRESENT	0
129220	129201	14195A	PARTICIPANT	\N	PRESENT	0
129221	129201	14267Y	PARTICIPANT	\N	PRESENT	0
129222	129201	11031D	PARTICIPANT	\N	PRESENT	0
129223	129201	08052W	PARTICIPANT	\N	PRESENT	0
129224	129201	01059Y	PARTICIPANT	\N	PRESENT	0
129225	129201	04081K	PARTICIPANT	\N	PRESENT	0
129226	129201	98024R	PARTICIPANT	\N	PRESENT	0
129227	129201	10006L	PARTICIPANT	\N	PRESENT	0
129228	129201	04067M	PARTICIPANT	\N	PRESENT	0
129229	129201	14217N	PARTICIPANT	\N	PRESENT	0
129230	129201	14042U	PARTICIPANT	\N	PRESENT	0
129231	129201	14151M	PARTICIPANT	\N	PRESENT	0
129232	129201	12042Y	PARTICIPANT	\N	PRESENT	0
129233	129201	14281W	PARTICIPANT	\N	PRESENT	0
129234	129201	14087W	PARTICIPANT	\N	PRESENT	0
130118	130116	95035G	PARTICIPANT	\N	PRESENT	0
130129	130128	14211G	PARTICIPANT	\N	PRESENT	0
130130	130128	14028W	PARTICIPANT	\N	PRESENT	0
129238	129201	11061K	PARTICIPANT	\N	PRESENT	0
129239	129201	08048B	PARTICIPANT	\N	PRESENT	0
129240	129201	08041T	PARTICIPANT	\N	PRESENT	0
129241	129201	01011G	PARTICIPANT	\N	PRESENT	0
129242	129201	14026U	PARTICIPANT	\N	PRESENT	0
129243	129201	14213J	PARTICIPANT	\N	PRESENT	0
129245	129201	14121F	PARTICIPANT	\N	PRESENT	0
129246	129201	11112D	PARTICIPANT	\N	PRESENT	0
129247	129201	14037X	PARTICIPANT	\N	PRESENT	0
129248	129201	14018U	PARTICIPANT	\N	PRESENT	0
130178	120701	04094Q	PARTICIPANT	\N	EXCUSE	0
129250	129201	14223L	PARTICIPANT	\N	PRESENT	0
129251	129201	04092N	PARTICIPANT	\N	PRESENT	0
129252	129201	14265W	PARTICIPANT	\N	PRESENT	0
129253	129201	14119M	PARTICIPANT	\N	PRESENT	0
129254	129201	14071N	PARTICIPANT	\N	PRESENT	0
129255	129201	07032N	PARTICIPANT	\N	PRESENT	0
129256	129201	04043D	PARTICIPANT	\N	PRESENT	0
129257	129201	14271U	PARTICIPANT	\N	PRESENT	0
130179	122712	14253S	PARTICIPANT	\N	PRESENT	0
129259	129201	11093T	PARTICIPANT	\N	PRESENT	0
129260	129201	11097X	PARTICIPANT	\N	PRESENT	0
129261	129201	04045F	PARTICIPANT	\N	PRESENT	0
129262	129201	14227Q	PARTICIPANT	\N	PRESENT	0
129263	129201	01034P	PARTICIPANT	\N	PRESENT	0
129264	129201	11025F	PARTICIPANT	\N	PRESENT	0
129265	129201	11063M	PARTICIPANT	\N	PRESENT	0
130180	122712	14157T	PARTICIPANT	\N	PRESENT	0
130193	130192	01056V	PARTICIPANT	\N	PRESENT	0
130194	130192	11106F	PARTICIPANT	\N	PRESENT	0
130196	130195	01014K	PARTICIPANT	\N	PRESENT	0
130197	130195	07024N	PARTICIPANT	\N	PRESENT	0
130198	130195	95035G	PARTICIPANT	\N	PRESENT	0
130199	130195	11054L	PARTICIPANT	\N	PRESENT	0
130200	130195	01056V	PARTICIPANT	\N	PRESENT	0
132458	131875	04047H	PARTICIPANT	\N	PRESENT	0
132459	131875	05012A	PARTICIPANT	\N	PRESENT	0
132460	131875	97011G	PARTICIPANT	\N	PRESENT	0
132461	131875	14038Y	PARTICIPANT	\N	PRESENT	0
132478	131875	07034Q	PARTICIPANT	\N	PRESENT	0
132465	131875	01024M	PARTICIPANT	\N	PRESENT	0
132477	131875	08051V	PARTICIPANT	\N	PRESENT	0
132480	131875	89017R	PARTICIPANT	\N	PRESENT	0
132732	131876	04066L	PARTICIPANT	\N	PRESENT	0
132733	131876	11090Q	PARTICIPANT	\N	PRESENT	0
132734	131876	11034G	PARTICIPANT	\N	PRESENT	0
132735	131876	11070L	PARTICIPANT	\N	PRESENT	0
132736	131876	14269B	PARTICIPANT	\N	PRESENT	0
132737	131876	07026Q	PARTICIPANT	\N	PRESENT	0
132738	131876	98005N	PARTICIPANT	\N	PRESENT	0
132739	131876	14261S	PARTICIPANT	\N	PRESENT	0
132740	131876	04067M	PARTICIPANT	\N	PRESENT	0
132754	131876	08069G	PARTICIPANT	\N	PRESENT	0
132742	131876	14237S	PARTICIPANT	\N	PRESENT	0
132743	131876	14013P	PARTICIPANT	\N	PRESENT	0
132744	131876	07029T	PARTICIPANT	\N	PRESENT	0
132745	131876	14041T	PARTICIPANT	\N	PRESENT	0
132746	131876	04088S	PARTICIPANT	\N	PRESENT	0
132747	131876	11098Y	PARTICIPANT	\N	PRESENT	0
132748	131876	11066Q	PARTICIPANT	\N	PRESENT	0
132749	131876	14327T	PARTICIPANT	\N	PRESENT	0
132750	131876	14033T	PARTICIPANT	\N	PRESENT	0
132751	131876	04085P	PARTICIPANT	\N	PRESENT	0
132752	131876	11055M	PARTICIPANT	\N	PRESENT	0
132753	131876	11095V	PARTICIPANT	\N	PRESENT	0
132763	131876	04050C	PARTICIPANT	\N	PRESENT	0
132764	131876	11031D	PARTICIPANT	\N	PRESENT	0
132765	131876	11056N	PARTICIPANT	\N	PRESENT	0
132766	131876	04054G	PARTICIPANT	\N	PRESENT	0
132767	131876	01015L	PARTICIPANT	\N	PRESENT	0
132768	131876	01059Y	PARTICIPANT	\N	PRESENT	0
132769	131876	11040E	PARTICIPANT	\N	PRESENT	0
132770	131876	11091R	PARTICIPANT	\N	PRESENT	0
132771	131876	11042G	PARTICIPANT	\N	PRESENT	0
132772	131876	08055A	PARTICIPANT	\N	PRESENT	0
132773	131876	11036J	PARTICIPANT	\N	PRESENT	0
132774	131876	11012A	PARTICIPANT	\N	PRESENT	0
132775	131876	04042C	PARTICIPANT	\N	PRESENT	0
132776	131876	07004J	PARTICIPANT	\N	PRESENT	0
132785	132781	04066L	PARTICIPANT	\N	PRESENT	0
132787	132781	11042G	PARTICIPANT	\N	PRESENT	0
132788	132781	01031L	PARTICIPANT	\N	PRESENT	0
132789	132781	11012A	PARTICIPANT	\N	PRESENT	0
132790	132781	11040E	PARTICIPANT	\N	PRESENT	0
132791	132781	04050C	PARTICIPANT	\N	PRESENT	0
132792	132781	04054G	PARTICIPANT	\N	PRESENT	0
132793	132781	04085P	PARTICIPANT	\N	PRESENT	0
132794	132781	01059Y	PARTICIPANT	\N	PRESENT	0
132795	132781	11056N	PARTICIPANT	\N	PRESENT	0
132796	132781	07026Q	PARTICIPANT	\N	PRESENT	0
132797	132781	14219Q	PARTICIPANT	\N	PRESENT	0
132798	132781	14261S	PARTICIPANT	\N	PRESENT	0
132799	132781	11083R	PARTICIPANT	\N	PRESENT	0
132800	132781	07004J	PARTICIPANT	\N	PRESENT	0
132801	132781	14041T	PARTICIPANT	\N	PRESENT	0
132802	132781	14237S	PARTICIPANT	\N	PRESENT	0
132803	132781	98005N	PARTICIPANT	\N	PRESENT	0
132804	132781	11098Y	PARTICIPANT	\N	PRESENT	0
132811	132781	14209N	PARTICIPANT	\N	PRESENT	0
132812	132781	98053W	PARTICIPANT	\N	PRESENT	0
160575	160532	11065P	PARTICIPANT	\N	PRESENT	0
160759	160752	14215L	PARTICIPANT	\N	PRESENT	0
160760	160752	08044W	PARTICIPANT	\N	EXCUSE	0
160761	160752	11026G	PARTICIPANT	\N	PRESENT	0
160762	160752	14111D	PARTICIPANT	\N	PRESENT	0
160763	160752	14147R	PARTICIPANT	\N	PRESENT	0
160764	160752	11072N	PARTICIPANT	\N	PRESENT	0
160765	160752	01028R	PARTICIPANT	\N	PRESENT	0
160766	160752	04056J	PARTICIPANT	\N	PRESENT	0
160767	160752	14275Y	PARTICIPANT	\N	PRESENT	0
160768	160752	11037K	PARTICIPANT	\N	PRESENT	0
160769	160752	14217N	PARTICIPANT	\N	PRESENT	0
160906	160905	01031L	PRESIDENT	0	PRESENT	0
160907	160905	11040E	PARTICIPANT	\N	PRESENT	0
160908	160905	14175V	PARTICIPANT	\N	EXCUSE	0
160836	160832	04040A	PARTICIPANT	\N	PRESENT	0
160837	160832	08058D	PARTICIPANT	\N	PRESENT	0
160909	160905	14083S	PARTICIPANT	\N	PRESENT	0
160910	160905	11042G	PARTICIPANT	\N	PRESENT	0
160840	160832	98029W	PARTICIPANT	\N	PRESENT	0
160841	160832	11080N	PARTICIPANT	\N	PRESENT	0
160842	160832	11027H	PARTICIPANT	\N	PRESENT	0
160911	160905	04086Q	PARTICIPANT	\N	EXCUSE	0
160912	160905	01027Q	PARTICIPANT	\N	PRESENT	0
160913	160905	11074Q	PARTICIPANT	\N	PRESENT	0
160914	160905	98053W	PARTICIPANT	\N	EXCUSE	0
160915	160905	11083R	PARTICIPANT	\N	PRESENT	0
160916	160905	99004R	PARTICIPANT	\N	PRESENT	0
160849	160832	97011G	PARTICIPANT	\N	PRESENT	0
160917	160905	04061F	PARTICIPANT	\N	PRESENT	0
160932	160905	14159V	PARTICIPANT	\N	PRESENT	0
160933	160905	07029T	PARTICIPANT	\N	PRESENT	0
160934	160905	08010L	PARTICIPANT	\N	PRESENT	0
160935	160905	01048V	PARTICIPANT	\N	PRESENT	0
160936	160905	11085T	PARTICIPANT	\N	EXCUSE	0
160856	160832	95035G	PARTICIPANT	\N	PRESENT	0
160937	160905	08073C	PARTICIPANT	\N	PRESENT	0
160858	160832	14211G	PARTICIPANT	\N	PRESENT	0
160938	160905	14225N	PARTICIPANT	\N	PRESENT	0
160939	160905	14173T	PARTICIPANT	\N	PRESENT	0
160940	160905	04034C	PARTICIPANT	\N	EXCUSE	0
160862	160832	04078Q	PARTICIPANT	\N	PRESENT	0
161097	160995	11111C	PARTICIPANT	\N	PRESENT	0
160997	160995	11036J	PARTICIPANT	\N	PRESENT	0
160865	160832	04036E	PARTICIPANT	\N	PRESENT	0
161828	161826	11039M	PARTICIPANT	\N	PRESENT	0
160999	160995	14013P	PARTICIPANT	\N	PRESENT	0
160868	160832	98005N	PARTICIPANT	\N	PRESENT	0
160869	160832	92031P	PARTICIPANT	\N	PRESENT	0
161000	160995	08068F	PARTICIPANT	\N	PRESENT	0
160871	160832	14251Q	PARTICIPANT	\N	PRESENT	0
160872	160832	83042R	PARTICIPANT	\N	PRESENT	0
161001	160995	14207L	PARTICIPANT	\N	PRESENT	0
161893	161892	04047H	PRESIDENT	0	PRESENT	0
160875	160832	11105E	PARTICIPANT	\N	EXCUSE	0
161003	160995	90003B	PARTICIPANT	\N	PRESENT	0
160877	160832	08047A	PARTICIPANT	\N	PRESENT	0
161004	160995	08028W	PARTICIPANT	\N	PRESENT	0
161005	160995	80013X	PARTICIPANT	\N	PRESENT	0
160880	160832	98021N	PARTICIPANT	\N	EXCUSE	0
161006	160995	14357A	PARTICIPANT	\N	PRESENT	0
160882	160832	95059Q	PRESIDENT	0	PRESENT	0
160883	160832	86044G	PARTICIPANT	\N	PRESENT	0
161007	160995	08038Y	PARTICIPANT	\N	EXCUSE	0
160885	160832	11054L	PARTICIPANT	\N	PRESENT	0
160886	160832	01056V	PARTICIPANT	\N	PRESENT	0
161008	160995	04089T	PARTICIPANT	\N	PRESENT	0
161009	160995	14197C	PARTICIPANT	\N	PRESENT	0
161829	161826	98042T	PARTICIPANT	\N	PRESENT	0
161011	160995	14187A	PARTICIPANT	\N	PRESENT	0
161012	160995	14033T	PARTICIPANT	\N	PRESENT	0
161013	160995	14081Q	PARTICIPANT	\N	PRESENT	0
161830	161826	01019Q	PARTICIPANT	\N	PRESENT	0
161015	160995	04049K	PARTICIPANT	\N	PRESENT	0
161016	160995	04094Q	PARTICIPANT	\N	PRESENT	0
161894	161892	04054G	PARTICIPANT	\N	PRESENT	0
161018	160995	08015R	PARTICIPANT	\N	PRESENT	0
161019	160995	11100Y	PRESIDENT	0	PRESENT	0
161020	160995	01061S	PARTICIPANT	\N	EXCUSE	0
161895	161892	14133K	PARTICIPANT	\N	EXCUSE	0
161022	160995	01043Q	PARTICIPANT	\N	PRESENT	0
161896	161892	14267Y	PARTICIPANT	\N	PRESENT	0
161024	160995	14205J	PARTICIPANT	\N	PRESENT	0
161025	160995	08019V	PARTICIPANT	\N	PRESENT	0
161026	160995	14257W	PARTICIPANT	\N	PRESENT	0
161897	161892	14079W	PARTICIPANT	\N	PRESENT	0
161898	161892	11083R	PARTICIPANT	\N	PRESENT	0
161899	161892	14026U	PARTICIPANT	\N	PRESENT	0
161030	160995	11090Q	PARTICIPANT	\N	PRESENT	0
161900	161892	14073Q	PARTICIPANT	\N	PRESENT	0
161032	160995	01058X	PARTICIPANT	\N	PRESENT	0
161033	160995	11094U	PARTICIPANT	\N	PRESENT	0
161034	160995	11066Q	PARTICIPANT	\N	PRESENT	0
161901	161892	11026G	PARTICIPANT	\N	PRESENT	0
161902	161892	92031P	PARTICIPANT	\N	PRESENT	0
161903	161892	14001X	PARTICIPANT	\N	PRESENT	0
161904	161892	11012A	PARTICIPANT	\N	PRESENT	0
161905	161892	11066Q	PARTICIPANT	\N	PRESENT	0
161906	161892	95067Q	PARTICIPANT	\N	PRESENT	0
162633	162632	92045V	PARTICIPANT	\N	PRESENT	0
162637	162636	92045V	PARTICIPANT	\N	PRESENT	0
162753	162752	07034Q	PARTICIPANT	\N	PRESENT	0
162773	162772	04092N	PARTICIPANT	\N	PRESENT	0
162774	162772	01046T	PARTICIPANT	\N	PRESENT	0
162775	162772	14213J	PARTICIPANT	\N	PRESENT	0
162776	162772	14042U	PARTICIPANT	\N	PRESENT	0
162777	162772	08052W	PARTICIPANT	\N	PRESENT	0
162778	162772	11061K	PARTICIPANT	\N	PRESENT	0
162779	162772	01059Y	PARTICIPANT	\N	PRESENT	0
162780	162772	14265W	PARTICIPANT	\N	PRESENT	0
162782	162781	04092N	PARTICIPANT	\N	PRESENT	0
162783	162781	01046T	PARTICIPANT	\N	PRESENT	0
162784	162781	14213J	PARTICIPANT	\N	PRESENT	0
162785	162781	14042U	PARTICIPANT	\N	PRESENT	0
162786	162781	08052W	PARTICIPANT	\N	PRESENT	0
162787	162781	11061K	PARTICIPANT	\N	PRESENT	0
162788	162781	01059Y	PARTICIPANT	\N	PRESENT	0
162789	162781	14265W	PARTICIPANT	\N	PRESENT	0
162853	162852	14261S	PARTICIPANT	\N	PRESENT	0
162892	162852	11095V	PARTICIPANT	\N	EXCUSE	0
162855	162852	14093U	PARTICIPANT	\N	PRESENT	0
162856	162852	14030Q	PARTICIPANT	\N	PRESENT	0
162894	162893	89017R	PARTICIPANT	\N	PRESENT	0
162895	162893	01031L	PRESIDENT	0	PRESENT	0
162896	162893	05004A	PARTICIPANT	\N	PRESENT	0
162860	162852	14038Y	PARTICIPANT	\N	PRESENT	0
162861	162852	11114F	PARTICIPANT	\N	PRESENT	0
162897	162893	01013J	PARTICIPANT	\N	PRESENT	0
162863	162852	11065P	PARTICIPANT	\N	PRESENT	0
162864	162852	01015L	PARTICIPANT	\N	PRESENT	0
162865	162852	11107G	PARTICIPANT	\N	PRESENT	0
162898	162893	11068S	PARTICIPANT	\N	PRESENT	0
162867	162852	02002K	PARTICIPANT	\N	PRESENT	0
162868	162852	01022K	PARTICIPANT	\N	PRESENT	0
162869	162852	05001W	PARTICIPANT	\N	EXCUSE	0
162899	162893	11040E	PARTICIPANT	\N	PRESENT	0
162871	162852	09001P	PARTICIPANT	\N	PRESENT	0
162872	162852	11059R	PARTICIPANT	\N	PRESENT	0
162873	162852	14219Q	PARTICIPANT	\N	PRESENT	0
162874	162852	80027E	PARTICIPANT	\N	PRESENT	0
162875	162852	14031R	PARTICIPANT	\N	PRESENT	0
160569	160532	95062K	PRESIDENT	0	PRESENT	0
162876	162852	08009T	PRESIDENT	0	PRESENT	0
160571	160532	14051J	PARTICIPANT	\N	PRESENT	0
160572	160532	14157T	PARTICIPANT	\N	PRESENT	0
162877	162852	08062Y	PARTICIPANT	\N	PRESENT	0
162878	162852	14221J	PARTICIPANT	\N	PRESENT	0
162879	162852	92039X	PARTICIPANT	\N	PRESENT	0
162880	162852	08042U	PARTICIPANT	\N	PRESENT	0
162881	162852	14169X	PARTICIPANT	\N	PRESENT	0
162882	162852	14237S	PARTICIPANT	\N	PRESENT	0
162883	162852	13002U	PARTICIPANT	\N	PRESENT	0
162884	162852	05012A	PARTICIPANT	\N	PRESENT	0
162900	162893	08014Q	PARTICIPANT	\N	PRESENT	0
162886	162852	14135M	PARTICIPANT	\N	PRESENT	0
162887	162852	14331P	PARTICIPANT	\N	PRESENT	0
162888	162852	95062K	PARTICIPANT	\N	PRESENT	0
162901	162893	14167V	PARTICIPANT	\N	PRESENT	0
162902	162893	14175V	PARTICIPANT	\N	EXCUSE	0
162891	162852	14157T	PARTICIPANT	\N	PRESENT	0
162903	162893	14083S	PARTICIPANT	\N	PRESENT	0
162904	162893	11053K	PARTICIPANT	\N	PRESENT	0
162905	162893	14085U	PARTICIPANT	\N	PRESENT	0
162906	162893	11042G	PARTICIPANT	\N	PRESENT	0
162907	162893	88008L	PARTICIPANT	\N	PRESENT	0
162908	162893	04086Q	PARTICIPANT	\N	PRESENT	0
162910	162893	11070L	PARTICIPANT	\N	PRESENT	0
162911	162893	11088W	PARTICIPANT	\N	PRESENT	0
129301	129300	01048V	PARTICIPANT	\N	PRESENT	0
129508	129459	00003C	PARTICIPANT	\N	EXCUSE	0
129465	129459	01046T	PARTICIPANT	\N	PRESENT	0
129466	129459	04053F	PARTICIPANT	\N	PRESENT	0
129467	129459	14053L	PARTICIPANT	\N	PRESENT	0
129468	129459	11103C	PARTICIPANT	\N	PRESENT	0
129469	129459	14195A	PARTICIPANT	\N	PRESENT	0
129470	129459	14267Y	PARTICIPANT	\N	PRESENT	0
129471	129459	11031D	PARTICIPANT	\N	PRESENT	0
129472	129459	08052W	PARTICIPANT	\N	PRESENT	0
129473	129459	01059Y	PARTICIPANT	\N	PRESENT	0
129474	129459	98024R	PARTICIPANT	\N	PRESENT	0
129476	129459	10006L	PARTICIPANT	\N	PRESENT	0
129477	129459	14217N	PARTICIPANT	\N	PRESENT	0
129479	129459	14231L	PARTICIPANT	\N	EXCUSE	0
129480	129459	11061K	PARTICIPANT	\N	PRESENT	0
129483	129459	08048B	PARTICIPANT	\N	PRESENT	0
129484	129459	08041T	PARTICIPANT	\N	PRESENT	0
129486	129459	01011G	PARTICIPANT	\N	PRESENT	0
129487	129459	14026U	PARTICIPANT	\N	PRESENT	0
129488	129459	14213J	PARTICIPANT	\N	PRESENT	0
129489	129459	14121F	PARTICIPANT	\N	PRESENT	0
129490	129459	11112D	PARTICIPANT	\N	PRESENT	0
129491	129459	14018U	PARTICIPANT	\N	PRESENT	0
129492	129459	14223L	PARTICIPANT	\N	PRESENT	0
129493	129459	04092N	PRESIDENT	0	PRESENT	0
129495	129459	14265W	PARTICIPANT	\N	PRESENT	0
129496	129459	14119M	PARTICIPANT	\N	PRESENT	0
129497	129459	14071N	PARTICIPANT	\N	PRESENT	0
129498	129459	04043D	PARTICIPANT	\N	PRESENT	0
129499	129459	14271U	PARTICIPANT	\N	PRESENT	0
129501	129459	11093T	PARTICIPANT	\N	PRESENT	0
129502	129459	11097X	PARTICIPANT	\N	PRESENT	0
129503	129459	04045F	PARTICIPANT	\N	PRESENT	0
129504	129459	01034P	PARTICIPANT	\N	PRESENT	0
129505	129459	11025F	PARTICIPANT	\N	PRESENT	0
129506	129459	11063M	PARTICIPANT	\N	PRESENT	0
130076	130075	01031L	PARTICIPANT	\N	PRESENT	0
130077	130075	08011M	PARTICIPANT	\N	PRESENT	0
130078	130075	98046X	PARTICIPANT	\N	PRESENT	0
130079	130075	14175V	PARTICIPANT	\N	PRESENT	0
130108	130107	08010L	PARTICIPANT	\N	PRESENT	0
130111	130110	08010L	PARTICIPANT	\N	PRESENT	0
130113	130112	08010L	PARTICIPANT	\N	PRESENT	0
130120	130119	08011M	PARTICIPANT	\N	PRESENT	0
130121	130119	01031L	PARTICIPANT	\N	PRESENT	0
130122	130119	01013J	PARTICIPANT	\N	PRESENT	0
130123	130119	11068S	PARTICIPANT	\N	PRESENT	0
130124	130119	11088W	PARTICIPANT	\N	PRESENT	0
130125	130119	01057W	PARTICIPANT	\N	PRESENT	0
130126	130119	08034U	PARTICIPANT	\N	PRESENT	0
130127	130119	04061F	PARTICIPANT	\N	PRESENT	0
130163	130162	11048N	PARTICIPANT	\N	PRESENT	0
134456	133131	01007L	PARTICIPANT	\N	PRESENT	0
134457	133131	08009T	PARTICIPANT	\N	PRESENT	0
134458	133131	14331P	PARTICIPANT	\N	PRESENT	0
134459	133131	01015L	PARTICIPANT	\N	PRESENT	0
134460	133131	01022K	PARTICIPANT	\N	PRESENT	0
134461	133131	08055A	PARTICIPANT	\N	PRESENT	0
134462	133131	14107H	PARTICIPANT	\N	PRESENT	0
134463	133131	11053K	PARTICIPANT	\N	PRESENT	0
134464	133131	01025N	PARTICIPANT	\N	PRESENT	0
134465	133131	14237S	PARTICIPANT	\N	PRESENT	0
134466	133131	14059S	PARTICIPANT	\N	PRESENT	0
134467	133131	14053L	PARTICIPANT	\N	PRESENT	0
134468	133131	14175V	PARTICIPANT	\N	PRESENT	0
134469	133131	14105F	PARTICIPANT	\N	PRESENT	0
134470	133131	14031R	PARTICIPANT	\N	PRESENT	0
134471	133131	95062K	PARTICIPANT	\N	PRESENT	0
134472	133131	11064N	PARTICIPANT	\N	PRESENT	0
134473	133131	14261S	PARTICIPANT	\N	PRESENT	0
134474	133131	14271U	PARTICIPANT	\N	PRESENT	0
134475	133131	14089Y	PARTICIPANT	\N	PRESENT	0
134476	133131	01024M	PARTICIPANT	\N	PRESENT	0
134477	133131	95030B	PARTICIPANT	\N	PRESENT	0
134478	133131	04053F	PARTICIPANT	\N	PRESENT	0
134479	133131	04067M	PARTICIPANT	\N	PRESENT	0
134480	133131	14014Q	PARTICIPANT	\N	PRESENT	0
134481	133131	14265W	PARTICIPANT	\N	PRESENT	0
134482	133131	14187A	PARTICIPANT	\N	PRESENT	0
134483	133131	08060W	PARTICIPANT	\N	PRESENT	0
134484	133131	11036J	PARTICIPANT	\N	PRESENT	0
134485	133131	14033T	PARTICIPANT	\N	PRESENT	0
134486	133131	14135M	PARTICIPANT	\N	PRESENT	0
134487	133131	11097X	PARTICIPANT	\N	PRESENT	0
134488	133131	04088S	PARTICIPANT	\N	PRESENT	0
134489	133131	14038Y	PARTICIPANT	\N	PRESENT	0
134490	133131	14042U	PARTICIPANT	\N	PRESENT	0
134491	133131	11112D	PARTICIPANT	\N	PRESENT	0
134492	133131	14231L	PARTICIPANT	\N	PRESENT	0
134493	133131	14030Q	PARTICIPANT	\N	PRESENT	0
134494	133131	14197C	PARTICIPANT	\N	PRESENT	0
134495	133131	08031R	PARTICIPANT	\N	PRESENT	0
134496	133131	14209N	PARTICIPANT	\N	PRESENT	0
134497	133131	01034P	PARTICIPANT	\N	PRESENT	0
134498	133131	14219Q	PARTICIPANT	\N	PRESENT	0
134499	133131	11056N	PARTICIPANT	\N	PRESENT	0
134500	133131	14109K	PARTICIPANT	\N	PRESENT	0
134501	133131	92045V	PARTICIPANT	\N	PRESENT	0
134502	133131	08051V	PARTICIPANT	\N	PRESENT	0
134506	133131	14073Q	PARTICIPANT	\N	PRESENT	0
134504	133131	08015R	PARTICIPANT	\N	PRESENT	0
134505	133131	80013X	PARTICIPANT	\N	PRESENT	0
134540	134539	11033F	PARTICIPANT	\N	PRESENT	0
134541	134539	04044E	PARTICIPANT	\N	PRESENT	0
137594	137593	11033F	PARTICIPANT	\N	PRESENT	0
137595	137593	04044E	PARTICIPANT	\N	PRESENT	0
137597	137596	89017R	PARTICIPANT	\N	PRESENT	0
137599	137598	01016M	PARTICIPANT	\N	PRESENT	0
137792	137791	08011M	PARTICIPANT	\N	PRESENT	0
137872	137837	08024S	PARTICIPANT	\N	PRESENT	0
137873	137837	11054L	PARTICIPANT	\N	PRESENT	0
137874	137837	11023D	PARTICIPANT	\N	PRESENT	0
137875	137837	13002U	PARTICIPANT	\N	PRESENT	0
137876	137837	14223L	PARTICIPANT	\N	PRESENT	0
137877	137837	14229S	PARTICIPANT	\N	PRESENT	0
137878	137837	11027H	PARTICIPANT	\N	PRESENT	0
137879	137837	11098Y	PARTICIPANT	\N	PRESENT	0
137880	137837	14037X	PARTICIPANT	\N	PRESENT	0
137881	137837	08041T	PARTICIPANT	\N	PRESENT	0
137882	137837	14109K	PARTICIPANT	\N	PRESENT	0
137885	137837	14201E	PARTICIPANT	\N	PRESENT	0
137886	137837	14199E	PARTICIPANT	\N	PRESENT	0
137887	137837	97011G	PARTICIPANT	\N	PRESENT	0
137888	137837	14107H	PARTICIPANT	\N	PRESENT	0
137889	137837	11063M	PARTICIPANT	\N	PRESENT	0
137890	137837	11109J	PARTICIPANT	\N	PRESENT	0
137891	137837	14030Q	PARTICIPANT	\N	PRESENT	0
137892	137837	01043Q	PARTICIPANT	\N	PRESENT	0
137893	137837	05012A	PARTICIPANT	\N	PRESENT	0
137894	137837	80013X	PARTICIPANT	\N	PRESENT	0
137953	137837	14105F	PARTICIPANT	\N	PRESENT	0
137954	137837	14179A	PARTICIPANT	\N	PRESENT	0
137955	137837	14059S	PARTICIPANT	\N	PRESENT	0
138043	137837	04043D	PARTICIPANT	\N	PRESENT	0
138068	137837	14187A	PARTICIPANT	\N	PRESENT	0
138069	137837	08055A	PARTICIPANT	\N	PRESENT	0
138070	137837	14269B	PARTICIPANT	\N	PRESENT	0
138071	137837	14028W	PARTICIPANT	\N	PRESENT	0
138112	137837	04040A	PARTICIPANT	\N	PRESENT	0
138136	137838	11031D	PARTICIPANT	\N	PRESENT	0
138137	137838	01059Y	PARTICIPANT	\N	PRESENT	0
138138	137838	07026Q	PARTICIPANT	\N	PRESENT	0
138139	137838	01013J	PARTICIPANT	\N	PRESENT	0
138140	137838	11034G	PARTICIPANT	\N	PRESENT	0
138141	137838	14235Q	PARTICIPANT	\N	PRESENT	0
138134	137838	86034E	PARTICIPANT	\N	PRESENT	0
138135	137838	04050C	PARTICIPANT	\N	PRESENT	0
138142	137838	14263U	PARTICIPANT	\N	PRESENT	0
138143	137838	11098Y	PARTICIPANT	\N	PRESENT	0
138144	137838	14197C	PARTICIPANT	\N	PRESENT	0
138145	137838	11036J	PARTICIPANT	\N	PRESENT	0
138146	137838	14227Q	PARTICIPANT	\N	PRESENT	0
138147	137838	14121F	PARTICIPANT	\N	PRESENT	0
138148	137838	11112D	PARTICIPANT	\N	PRESENT	0
138149	137838	11042G	PARTICIPANT	\N	PRESENT	0
138150	137838	14207L	PARTICIPANT	\N	PRESENT	0
138151	137838	08016S	PARTICIPANT	\N	PRESENT	0
138152	137838	14271U	PARTICIPANT	\N	PRESENT	0
138153	137838	14281W	PARTICIPANT	\N	PRESENT	0
138154	137838	01025N	PARTICIPANT	\N	PRESENT	0
138155	137838	08052W	PARTICIPANT	\N	PRESENT	0
138156	137838	11061K	PARTICIPANT	\N	PRESENT	0
138157	137838	14107H	PARTICIPANT	\N	PRESENT	0
138158	137838	04092N	PARTICIPANT	\N	PRESENT	0
138159	137838	01034P	PARTICIPANT	\N	PRESENT	0
134173	134172	01016M	PARTICIPANT	\N	PRESENT	0
138160	137838	11066Q	PARTICIPANT	\N	PRESENT	0
138161	137838	04056J	PARTICIPANT	\N	PRESENT	0
152073	149975	14195A	PARTICIPANT	\N	PRESENT	0
152074	149975	14105F	PARTICIPANT	\N	PRESENT	0
152075	149975	14135M	PARTICIPANT	\N	PRESENT	0
152076	149975	14175V	PARTICIPANT	\N	PRESENT	0
152077	149975	04055H	PARTICIPANT	\N	PRESENT	0
152078	149975	07029T	PARTICIPANT	\N	PRESENT	0
152079	149975	11063M	PARTICIPANT	\N	PRESENT	0
152080	149975	11100Y	PARTICIPANT	\N	PRESENT	0
152081	149975	14199E	PARTICIPANT	\N	PRESENT	0
152082	149975	04059M	PARTICIPANT	\N	PRESENT	0
152083	149975	04094Q	PARTICIPANT	\N	PRESENT	0
152084	149975	08031R	PARTICIPANT	\N	PRESENT	0
152085	149975	96004D	PARTICIPANT	\N	PRESENT	0
152086	149975	98018T	PARTICIPANT	\N	PRESENT	0
152087	149975	86044G	PARTICIPANT	\N	PRESENT	0
152088	149975	05008E	PARTICIPANT	\N	PRESENT	0
152089	149975	14071N	PARTICIPANT	\N	PRESENT	0
152090	149975	04042C	PARTICIPANT	\N	PRESENT	0
152091	149975	14069U	PARTICIPANT	\N	PRESENT	0
152092	149975	14237S	PARTICIPANT	\N	PRESENT	0
152093	149975	97011G	PARTICIPANT	\N	PRESENT	0
152094	149975	14079W	PARTICIPANT	\N	PRESENT	0
152095	149975	08042U	PARTICIPANT	\N	PRESENT	0
152096	149975	11026G	PARTICIPANT	\N	PRESENT	0
152097	149975	11071M	PARTICIPANT	\N	PRESENT	0
152098	149975	14065Q	PARTICIPANT	\N	PRESENT	0
152099	149975	92031P	PARTICIPANT	\N	PRESENT	0
152100	149975	14151M	PARTICIPANT	\N	PRESENT	0
152101	149975	08069G	PARTICIPANT	\N	PRESENT	0
152102	149975	04035D	PARTICIPANT	\N	PRESENT	0
152104	152103	98046X	PARTICIPANT	\N	PRESENT	0
152105	152103	08031R	PARTICIPANT	\N	PRESENT	0
152106	152103	88008L	PARTICIPANT	\N	PRESENT	0
152107	152103	14209N	PARTICIPANT	\N	PRESENT	0
152108	152103	11065P	PARTICIPANT	\N	PRESENT	0
152109	152103	08015R	PARTICIPANT	\N	PRESENT	0
152110	152103	11026G	PARTICIPANT	\N	PRESENT	0
152111	152103	14051J	PARTICIPANT	\N	PRESENT	0
152112	149975	04036E	PARTICIPANT	\N	PRESENT	0
152113	149975	01008M	PARTICIPANT	\N	PRESENT	0
152114	149975	14119M	PARTICIPANT	\N	PRESENT	0
152115	149975	08009T	PARTICIPANT	\N	PRESENT	0
152116	149975	08022Q	PARTICIPANT	\N	PRESENT	0
152117	149975	14157T	PARTICIPANT	\N	PRESENT	0
152118	149975	11084S	PARTICIPANT	\N	PRESENT	0
152132	149975	14257W	PARTICIPANT	\N	PRESENT	0
152133	149975	14229S	PARTICIPANT	\N	PRESENT	0
152152	149975	14193X	PARTICIPANT	\N	PRESENT	0
152172	149975	05001W	PARTICIPANT	\N	PRESENT	0
152173	149975	95041E	PARTICIPANT	\N	PRESENT	0
152174	149975	90003B	PARTICIPANT	\N	PRESENT	0
152192	149975	05012A	PARTICIPANT	\N	PRESENT	0
152193	149975	14217N	PARTICIPANT	\N	PRESENT	0
152398	149973	08055A	PARTICIPANT	\N	PRESENT	0
152399	149973	01008M	PARTICIPANT	\N	PRESENT	0
152400	149973	01059Y	PARTICIPANT	\N	PRESENT	0
152401	149973	11056N	PARTICIPANT	\N	PRESENT	0
152402	149973	14111D	PARTICIPANT	\N	PRESENT	0
152403	149973	14197C	PARTICIPANT	\N	PRESENT	0
152404	149973	14121F	PARTICIPANT	\N	PRESENT	0
152405	149973	01015L	PARTICIPANT	\N	PRESENT	0
152406	149973	11098Y	PARTICIPANT	\N	PRESENT	0
152407	149973	14107H	PARTICIPANT	\N	PRESENT	0
152408	149973	14014Q	PARTICIPANT	\N	PRESENT	0
152409	149973	11065P	PARTICIPANT	\N	PRESENT	0
152410	149973	90003B	PARTICIPANT	\N	PRESENT	0
152411	149973	14327T	PARTICIPANT	\N	PRESENT	0
152412	149973	14038Y	PARTICIPANT	\N	PRESENT	0
152413	149973	14179A	PARTICIPANT	\N	PRESENT	0
152414	149973	14231L	PARTICIPANT	\N	PRESENT	0
152415	149973	08019V	PARTICIPANT	\N	PRESENT	0
152416	149973	14175V	PARTICIPANT	\N	PRESENT	0
152417	149973	95067Q	PARTICIPANT	\N	PRESENT	0
152418	149973	95015C	PARTICIPANT	\N	PRESENT	0
152419	149973	08022Q	PARTICIPANT	\N	PRESENT	0
152420	149973	14026U	PARTICIPANT	\N	PRESENT	0
152421	149973	05012A	PARTICIPANT	\N	PRESENT	0
152422	149973	14187A	PARTICIPANT	\N	PRESENT	0
152423	149973	14061L	PARTICIPANT	\N	PRESENT	0
152424	149973	14059S	PARTICIPANT	\N	PRESENT	0
152425	149973	14237S	PARTICIPANT	\N	PRESENT	0
152426	149973	14053L	PARTICIPANT	\N	PRESENT	0
152427	149973	14249W	PARTICIPANT	\N	PRESENT	0
152428	149973	14073Q	PARTICIPANT	\N	PRESENT	0
152429	149973	14195A	PARTICIPANT	\N	PRESENT	0
152430	149973	11043H	PARTICIPANT	\N	PRESENT	0
152431	149973	14157T	PARTICIPANT	\N	PRESENT	0
152432	149973	14217N	PARTICIPANT	\N	PRESENT	0
152433	149973	14097Y	PARTICIPANT	\N	PRESENT	0
152434	149973	14199E	PARTICIPANT	\N	PRESENT	0
152435	149973	14033T	PARTICIPANT	\N	PRESENT	0
152436	149973	14089Y	PARTICIPANT	\N	PRESENT	0
152437	149973	04057K	PARTICIPANT	\N	PRESENT	0
152452	149973	04067M	PARTICIPANT	\N	PRESENT	0
152453	149973	92039X	PARTICIPANT	\N	PRESENT	0
152454	149973	08031R	PARTICIPANT	\N	PRESENT	0
152455	149973	08038Y	PARTICIPANT	\N	PRESENT	0
152456	149973	11048N	PARTICIPANT	\N	PRESENT	0
152472	149973	08051V	PARTICIPANT	\N	PRESENT	0
152473	149973	11036J	PARTICIPANT	\N	PRESENT	0
152474	149973	97011G	PARTICIPANT	\N	PRESENT	0
152475	149973	11081P	PARTICIPANT	\N	PRESENT	0
152476	149973	08009T	PARTICIPANT	\N	PRESENT	0
152477	149973	01048V	PARTICIPANT	\N	PRESENT	0
152478	149973	14205J	PARTICIPANT	\N	PRESENT	0
152479	149973	01022K	PARTICIPANT	\N	PRESENT	0
152480	149973	14265W	PARTICIPANT	\N	PRESENT	0
152573	149974	11098Y	PARTICIPANT	\N	PRESENT	0
152574	149974	08009T	PARTICIPANT	\N	PRESENT	0
152575	149974	01008M	PARTICIPANT	\N	PRESENT	0
152576	149974	01022K	PARTICIPANT	\N	PRESENT	0
152577	149974	14197C	PARTICIPANT	\N	PRESENT	0
152578	149974	14107H	PARTICIPANT	\N	PRESENT	0
152579	149974	14014Q	PARTICIPANT	\N	PRESENT	0
152580	149974	11110B	PARTICIPANT	\N	PRESENT	0
152581	149974	14030Q	PARTICIPANT	\N	PRESENT	0
152582	149974	14327T	PARTICIPANT	\N	PRESENT	0
152583	149974	14187A	PARTICIPANT	\N	PRESENT	0
152584	149974	14061L	PARTICIPANT	\N	PRESENT	0
152585	149974	14205J	PARTICIPANT	\N	PRESENT	0
152586	149974	14195A	PARTICIPANT	\N	PRESENT	0
152587	149974	14265W	PARTICIPANT	\N	PRESENT	0
152588	149974	95067Q	PARTICIPANT	\N	PRESENT	0
152589	149974	95015C	PARTICIPANT	\N	PRESENT	0
152590	149974	14111D	PARTICIPANT	\N	PRESENT	0
152591	149974	14169X	PARTICIPANT	\N	PRESENT	0
152592	149974	11043H	PARTICIPANT	\N	PRESENT	0
152593	149974	14175V	PARTICIPANT	\N	PRESENT	0
152594	149974	14031R	PARTICIPANT	\N	PRESENT	0
152595	149974	14059S	PARTICIPANT	\N	PRESENT	0
152596	149974	14038Y	PARTICIPANT	\N	PRESENT	0
152597	149974	14257W	PARTICIPANT	\N	PRESENT	0
152598	149974	14199E	PARTICIPANT	\N	PRESENT	0
152599	149974	14053L	PARTICIPANT	\N	PRESENT	0
152600	149974	14217N	PARTICIPANT	\N	PRESENT	0
152601	149974	11081P	PARTICIPANT	\N	PRESENT	0
152602	149974	14026U	PARTICIPANT	\N	PRESENT	0
152603	149974	14179A	PARTICIPANT	\N	PRESENT	0
152604	149974	14259Y	PARTICIPANT	\N	PRESENT	0
152605	149974	04088S	PARTICIPANT	\N	PRESENT	0
152606	149974	95049N	PARTICIPANT	\N	PRESENT	0
152607	149974	08019V	PARTICIPANT	\N	PRESENT	0
152608	149974	14237S	PARTICIPANT	\N	PRESENT	0
152609	149974	14215L	PARTICIPANT	\N	PRESENT	0
152610	149974	14135M	PARTICIPANT	\N	PRESENT	0
152611	149974	01015L	PARTICIPANT	\N	PRESENT	0
152612	149974	98053W	PARTICIPANT	\N	PRESENT	0
152613	149974	08038Y	PARTICIPANT	\N	PRESENT	0
152614	149974	05012A	PARTICIPANT	\N	PRESENT	0
152632	149974	92039X	PARTICIPANT	\N	PRESENT	0
152633	149974	04045F	PARTICIPANT	\N	PRESENT	0
152634	149974	14207L	PARTICIPANT	\N	PRESENT	0
152635	149974	14089Y	PARTICIPANT	\N	PRESENT	0
152636	149974	12042Y	PARTICIPANT	\N	PRESENT	0
152637	149974	11065P	PARTICIPANT	\N	PRESENT	0
152638	149974	11036J	PARTICIPANT	\N	PRESENT	0
152639	149974	14069U	PARTICIPANT	\N	PRESENT	0
152640	149974	13002U	PARTICIPANT	\N	PRESENT	0
152652	149974	11048N	PARTICIPANT	\N	PRESENT	0
152653	149974	14105F	PARTICIPANT	\N	PRESENT	0
152654	149974	80013X	PARTICIPANT	\N	PRESENT	0
152552	149974	04066L	PARTICIPANT	\N	PRESENT	0
152572	149974	01059Y	PARTICIPANT	\N	PRESENT	0
152655	149974	92045V	PARTICIPANT	\N	PRESENT	0
152656	149974	14073Q	PARTICIPANT	\N	PRESENT	0
152657	149974	14231L	PARTICIPANT	\N	PRESENT	0
152658	149974	14249W	PARTICIPANT	\N	PRESENT	0
152672	149974	14121F	PARTICIPANT	\N	PRESENT	0
130245	130243	98046X	PARTICIPANT	\N	PRESENT	0
132813	132781	04034C	PARTICIPANT	\N	PRESENT	0
132832	130822	01007L	PARTICIPANT	\N	PRESENT	0
132927	132926	14259Y	PARTICIPANT	\N	PRESENT	0
132929	132926	11037K	PARTICIPANT	\N	PRESENT	0
132931	132926	04038G	PARTICIPANT	\N	PRESENT	0
132960	132959	14259Y	PARTICIPANT	\N	PRESENT	0
132961	132959	11037K	PARTICIPANT	\N	PRESENT	0
132962	132959	04038G	PARTICIPANT	\N	PRESENT	0
132963	132959	11084S	PARTICIPANT	\N	PRESENT	0
132964	132959	92045V	PARTICIPANT	\N	PRESENT	0
132965	132959	14001X	PARTICIPANT	\N	PRESENT	0
132967	132966	14259Y	PARTICIPANT	\N	PRESENT	0
132968	132966	11037K	PARTICIPANT	\N	PRESENT	0
132969	132966	04038G	PARTICIPANT	\N	PRESENT	0
132970	132966	04044E	PARTICIPANT	\N	PRESENT	0
132971	132966	01024M	PARTICIPANT	\N	PRESENT	0
132973	132972	14259Y	PARTICIPANT	\N	PRESENT	0
132974	132972	11037K	PARTICIPANT	\N	PRESENT	0
132975	132972	11084S	PARTICIPANT	\N	PRESENT	0
132976	132972	04038G	PARTICIPANT	\N	PRESENT	0
132978	132977	14259Y	PARTICIPANT	\N	PRESENT	0
132979	132977	11037K	PARTICIPANT	\N	PRESENT	0
132980	132977	04038G	PARTICIPANT	\N	PRESENT	0
132982	132981	14259Y	PARTICIPANT	\N	PRESENT	0
132983	132981	11037K	PARTICIPANT	\N	PRESENT	0
132984	132981	95067Q	PARTICIPANT	\N	PRESENT	0
132985	132981	95049N	PARTICIPANT	\N	PRESENT	0
132987	132986	14259Y	PARTICIPANT	\N	PRESENT	0
132988	132986	11037K	PARTICIPANT	\N	PRESENT	0
132989	132986	08051V	PARTICIPANT	\N	PRESENT	0
135513	135512	14087W	PARTICIPANT	\N	PRESENT	0
135515	135514	14087W	PARTICIPANT	\N	PRESENT	0
135517	135516	14087W	PARTICIPANT	\N	PRESENT	0
135519	135518	04034C	PARTICIPANT	\N	PRESENT	0
135520	135518	01027Q	PARTICIPANT	\N	PRESENT	0
135522	135521	04034C	PARTICIPANT	\N	PRESENT	0
135523	135521	01027Q	PARTICIPANT	\N	PRESENT	0
135525	135524	14087W	PARTICIPANT	\N	PRESENT	0
135527	135526	14087W	PARTICIPANT	\N	PRESENT	0
135531	135530	01057W	PARTICIPANT	\N	PRESENT	0
135532	135530	14225N	PARTICIPANT	\N	PRESENT	0
135534	135533	01057W	PARTICIPANT	\N	PRESENT	0
135535	135533	14225N	PARTICIPANT	\N	PRESENT	0
135537	135536	01031L	PARTICIPANT	\N	PRESENT	0
135553	135552	08010L	PARTICIPANT	\N	PRESENT	0
135831	135830	04071H	PARTICIPANT	\N	PRESENT	0
135834	135833	04071H	PARTICIPANT	\N	PRESENT	0
135843	135842	11015D	PARTICIPANT	\N	PRESENT	0
135844	135842	92031P	PARTICIPANT	\N	PRESENT	0
135849	135848	11015D	PARTICIPANT	\N	PRESENT	0
135850	135848	92031P	PARTICIPANT	\N	PRESENT	0
135853	135851	11015D	PARTICIPANT	\N	PRESENT	0
135867	124149	14209N	PARTICIPANT	\N	EXCUSE	0
135868	124149	11089X	PARTICIPANT	\N	EXCUSE	0
135869	124149	08069G	PARTICIPANT	\N	EXCUSE	0
135870	124149	14221J	PARTICIPANT	\N	EXCUSE	0
135872	124149	13002U	PARTICIPANT	\N	EXCUSE	0
135873	124149	01058X	PARTICIPANT	\N	PRESENT	0
135874	124149	04043D	PARTICIPANT	\N	EXCUSE	0
135875	124149	80013X	PARTICIPANT	\N	PRESENT	0
135896	135890	89017R	PARTICIPANT	\N	PRESENT	0
135897	135890	01031L	PRESIDENT	0	PRESENT	0
136853	136852	11036J	PARTICIPANT	\N	PRESENT	0
135899	135890	01013J	PARTICIPANT	\N	PRESENT	0
135902	135890	08014Q	PARTICIPANT	\N	PRESENT	0
135903	135890	14167V	PARTICIPANT	\N	PRESENT	0
135904	135890	14175V	PARTICIPANT	\N	PRESENT	0
136854	136852	08055A	PARTICIPANT	\N	PRESENT	0
135906	135890	11053K	PARTICIPANT	\N	PRESENT	0
135907	135890	14085U	PARTICIPANT	\N	PRESENT	0
135908	135890	11042G	PARTICIPANT	\N	PRESENT	0
136855	136852	14105F	PARTICIPANT	\N	PRESENT	0
135910	135890	04086Q	PARTICIPANT	\N	PRESENT	0
135911	135890	04055H	PARTICIPANT	\N	PRESENT	0
136856	136852	14207L	PARTICIPANT	\N	PRESENT	0
135913	135890	11088W	PARTICIPANT	\N	PRESENT	0
136857	136852	11103C	PARTICIPANT	\N	PRESENT	0
135915	135890	08022Q	PARTICIPANT	\N	PRESENT	0
135916	135890	01027Q	PARTICIPANT	\N	PRESENT	0
135917	135890	04071H	PARTICIPANT	\N	PRESENT	0
135918	135890	11074Q	PARTICIPANT	\N	PRESENT	0
135919	135890	98053W	PARTICIPANT	\N	EXCUSE	0
135920	135890	11083R	PARTICIPANT	\N	PRESENT	0
135921	135890	14199E	PARTICIPANT	\N	PRESENT	0
136858	136852	92015P	PARTICIPANT	\N	PRESENT	0
135923	135890	08016S	PARTICIPANT	\N	PRESENT	0
135924	135890	08069G	PARTICIPANT	\N	PRESENT	0
135925	135890	11048N	PARTICIPANT	\N	PRESENT	0
135926	135890	99004R	PARTICIPANT	\N	PRESENT	0
136859	136852	90003B	PARTICIPANT	\N	PRESENT	0
136860	136852	11080N	PARTICIPANT	\N	PRESENT	0
135929	135890	07029T	PARTICIPANT	\N	PRESENT	0
135930	135890	14277B	PARTICIPANT	\N	PRESENT	0
135931	135890	08010L	PARTICIPANT	\N	PRESENT	0
135932	135890	08034U	PARTICIPANT	\N	PRESENT	0
135933	135890	01048V	PARTICIPANT	\N	PRESENT	0
136861	136852	14079W	PARTICIPANT	\N	PRESENT	0
136862	136852	04089T	PARTICIPANT	\N	PRESENT	0
135936	135890	08011M	PARTICIPANT	\N	PRESENT	0
136863	136852	87003B	PARTICIPANT	\N	PRESENT	0
135938	135890	08061X	PARTICIPANT	\N	PRESENT	0
135939	135890	01016M	PARTICIPANT	\N	PRESENT	0
135940	135890	14225N	PARTICIPANT	\N	PRESENT	0
135941	135890	11012A	PARTICIPANT	\N	PRESENT	0
135942	135890	11057P	PARTICIPANT	\N	PRESENT	0
135943	135890	14173T	PARTICIPANT	\N	PRESENT	0
135944	135890	04034C	PARTICIPANT	\N	PRESENT	0
136864	136852	01007L	PARTICIPANT	\N	PRESENT	0
136865	136852	14037X	PARTICIPANT	\N	PRESENT	0
136866	136852	01043Q	PARTICIPANT	\N	PRESENT	0
136867	136852	08053X	PARTICIPANT	\N	PRESENT	0
136868	136852	04092N	PARTICIPANT	\N	PRESENT	0
136869	136852	14119M	PARTICIPANT	\N	PRESENT	0
136870	136852	08061X	PARTICIPANT	\N	PRESENT	0
136871	136852	07032N	PARTICIPANT	\N	PRESENT	0
136872	136852	98050T	PARTICIPANT	\N	PRESENT	0
136873	136852	14331P	PARTICIPANT	\N	PRESENT	0
136874	136852	14225N	PARTICIPANT	\N	PRESENT	0
136875	136852	14107H	PARTICIPANT	\N	PRESENT	0
136876	136852	92045V	PARTICIPANT	\N	PRESENT	0
136877	136852	11063M	PARTICIPANT	\N	PRESENT	0
136888	136887	11035H	PARTICIPANT	\N	PRESENT	0
136899	136898	01041N	PARTICIPANT	\N	PRESENT	0
136900	136898	08017T	PARTICIPANT	\N	PRESENT	0
136902	136901	01041N	PARTICIPANT	\N	PRESENT	0
136903	136901	08017T	PARTICIPANT	\N	PRESENT	0
136905	136904	01041N	PARTICIPANT	\N	PRESENT	0
136906	136904	08017T	PARTICIPANT	\N	PRESENT	0
136908	136907	01041N	PARTICIPANT	\N	PRESENT	0
136909	136907	08017T	PARTICIPANT	\N	PRESENT	0
136911	136910	01041N	PARTICIPANT	\N	PRESENT	0
136912	136910	08017T	PARTICIPANT	\N	PRESENT	0
136914	136913	01041N	PARTICIPANT	\N	PRESENT	0
136915	136913	08017T	PARTICIPANT	\N	PRESENT	0
136917	136916	01041N	PARTICIPANT	\N	PRESENT	0
136918	136916	08017T	PARTICIPANT	\N	PRESENT	0
137030	137029	01041N	PARTICIPANT	\N	PRESENT	0
137031	137029	08017T	PARTICIPANT	\N	PRESENT	0
137533	137532	89017R	PARTICIPANT	\N	PRESENT	0
137534	137532	01031L	PRESIDENT	0	PRESENT	0
137535	137532	01013J	PARTICIPANT	\N	EXCUSE	0
137536	137532	11068S	PARTICIPANT	\N	PRESENT	0
137537	137532	08014Q	PARTICIPANT	\N	PRESENT	0
137538	137532	14175V	PARTICIPANT	\N	PRESENT	0
137539	137532	14083S	PARTICIPANT	\N	PRESENT	0
137540	137532	11053K	PARTICIPANT	\N	PRESENT	0
137541	137532	14085U	PARTICIPANT	\N	PRESENT	0
137542	137532	11042G	PARTICIPANT	\N	PRESENT	0
137543	137532	11088W	PARTICIPANT	\N	PRESENT	0
137544	137532	11074Q	PARTICIPANT	\N	PRESENT	0
137545	137532	08069G	PARTICIPANT	\N	PRESENT	0
137546	137532	11048N	PARTICIPANT	\N	PRESENT	0
137547	137532	07029T	PARTICIPANT	\N	PRESENT	0
137548	137532	14277B	PARTICIPANT	\N	PRESENT	0
137549	137532	08010L	PARTICIPANT	\N	PRESENT	0
137550	137532	08034U	PARTICIPANT	\N	PRESENT	0
137551	137532	98046X	PARTICIPANT	\N	PRESENT	0
137552	137532	08011M	PARTICIPANT	\N	PRESENT	0
162912	162893	14327T	PARTICIPANT	\N	PRESENT	0
162913	162893	08022Q	PARTICIPANT	\N	PRESENT	0
162914	162893	01027Q	PARTICIPANT	\N	PRESENT	0
162915	162893	04071H	PARTICIPANT	\N	PRESENT	0
162916	162893	11074Q	PARTICIPANT	\N	PRESENT	0
162917	162893	98053W	PARTICIPANT	\N	EXCUSE	0
162918	162893	11083R	PARTICIPANT	\N	PRESENT	0
162919	162893	14199E	PARTICIPANT	\N	PRESENT	0
162920	162893	01057W	PARTICIPANT	\N	PRESENT	0
162944	162943	08025T	PARTICIPANT	\N	PRESENT	0
162922	162893	08069G	PARTICIPANT	\N	PRESENT	0
162923	162893	11048N	PARTICIPANT	\N	PRESENT	0
162924	162893	99004R	PARTICIPANT	\N	PRESENT	0
162925	162893	04061F	PARTICIPANT	\N	PRESENT	0
162926	162893	14159V	PARTICIPANT	\N	PRESENT	0
162927	162893	07029T	PARTICIPANT	\N	PRESENT	0
162945	162943	04085P	PARTICIPANT	\N	PRESENT	0
162929	162893	08010L	PARTICIPANT	\N	PRESENT	0
162930	162893	08034U	PARTICIPANT	\N	PRESENT	0
162946	162943	05008E	PRESIDENT	0	PRESENT	0
162932	162893	98046X	PARTICIPANT	\N	PRESENT	0
162933	162893	11085T	PARTICIPANT	\N	EXCUSE	0
162934	162893	08011M	PARTICIPANT	\N	PRESENT	0
162935	162893	08073C	PARTICIPANT	\N	PRESENT	0
162936	162893	08061X	PARTICIPANT	\N	PRESENT	0
162947	162943	11030C	PARTICIPANT	\N	PRESENT	0
162938	162893	14225N	PARTICIPANT	\N	PRESENT	0
162939	162893	11012A	PARTICIPANT	\N	PRESENT	0
162940	162893	11057P	PARTICIPANT	\N	PRESENT	0
162941	162893	14173T	PARTICIPANT	\N	PRESENT	0
162942	162893	04034C	PARTICIPANT	\N	EXCUSE	0
162948	162943	11033F	PARTICIPANT	\N	PRESENT	0
162949	162943	14069U	PARTICIPANT	\N	PRESENT	0
162950	162943	04047H	PARTICIPANT	\N	PRESENT	0
162951	162943	99002P	PARTICIPANT	\N	PRESENT	0
162952	162943	11056N	PARTICIPANT	\N	PRESENT	0
162953	162943	14259Y	PARTICIPANT	\N	PRESENT	0
162972	162943	11035H	PARTICIPANT	\N	PRESENT	0
162973	162943	14041T	PARTICIPANT	\N	PRESENT	0
162974	162943	11113E	PARTICIPANT	\N	PRESENT	0
162975	162943	01024M	PARTICIPANT	\N	PRESENT	0
162976	162943	14215L	PARTICIPANT	\N	PRESENT	0
162977	162943	11034G	PARTICIPANT	\N	PRESENT	0
162978	162943	01007L	PARTICIPANT	\N	PRESENT	0
162979	162943	11049P	PARTICIPANT	\N	PRESENT	0
162980	162943	08044W	PARTICIPANT	\N	EXCUSE	0
162981	162943	11084S	PARTICIPANT	\N	PRESENT	0
162982	162943	11026G	PARTICIPANT	\N	PRESENT	0
162983	162943	04079R	PARTICIPANT	\N	PRESENT	0
162984	162943	14111D	PARTICIPANT	\N	PRESENT	0
162985	162943	14001X	PARTICIPANT	\N	PRESENT	0
162986	162943	01060R	PARTICIPANT	\N	PRESENT	0
162987	162943	14147R	PARTICIPANT	\N	PRESENT	0
162988	162943	95049N	PARTICIPANT	\N	PRESENT	0
162989	162943	08051V	PARTICIPANT	\N	PRESENT	0
162990	162943	11072N	PARTICIPANT	\N	PRESENT	0
162991	162943	07034Q	PARTICIPANT	\N	PRESENT	0
162992	162943	04074L	PARTICIPANT	\N	PRESENT	0
162993	162943	95063L	PARTICIPANT	\N	PRESENT	0
162994	162943	01019Q	PARTICIPANT	\N	PRESENT	0
162995	162943	01028R	PARTICIPANT	\N	PRESENT	0
162996	162943	98035U	PARTICIPANT	\N	PRESENT	0
162997	162943	04056J	PARTICIPANT	\N	PRESENT	0
162998	162943	14275Y	PARTICIPANT	\N	PRESENT	0
162999	162943	04044E	PARTICIPANT	\N	PRESENT	0
163000	162943	11037K	PARTICIPANT	\N	PRESENT	0
163001	162943	92045V	PARTICIPANT	\N	PRESENT	0
163002	162943	95067Q	PARTICIPANT	\N	PRESENT	0
163003	162943	01047U	PARTICIPANT	\N	PRESENT	0
163202	163199	11090Q	PRESIDENT	0	PRESENT	0
163014	163012	01031L	PRESIDENT	0	PRESENT	0
163209	163199	11065P	PARTICIPANT	\N	PRESENT	0
163016	163012	01013J	PARTICIPANT	\N	PRESENT	0
163017	163012	11068S	PARTICIPANT	\N	PRESENT	0
163018	163012	11040E	PARTICIPANT	\N	PRESENT	0
163019	163012	08014Q	PARTICIPANT	\N	PRESENT	0
163020	163012	14167V	PARTICIPANT	\N	PRESENT	0
163021	163012	14175V	PARTICIPANT	\N	EXCUSE	0
163022	163012	14083S	PARTICIPANT	\N	PRESENT	0
163023	163012	11053K	PARTICIPANT	\N	PRESENT	0
163024	163012	14085U	PARTICIPANT	\N	PRESENT	0
163025	163012	11042G	PARTICIPANT	\N	PRESENT	0
163210	163199	01015L	PARTICIPANT	\N	PRESENT	0
163027	163012	04086Q	PARTICIPANT	\N	PRESENT	0
163028	163012	04055H	PARTICIPANT	\N	PRESENT	0
163029	163012	11070L	PARTICIPANT	\N	PRESENT	0
163030	163012	11088W	PARTICIPANT	\N	PRESENT	0
163031	163012	14327T	PARTICIPANT	\N	PRESENT	0
163032	163012	08022Q	PARTICIPANT	\N	PRESENT	0
163033	163012	01027Q	PARTICIPANT	\N	PRESENT	0
163211	163199	01008M	PARTICIPANT	\N	PRESENT	0
163035	163012	11074Q	PARTICIPANT	\N	PRESENT	0
163036	163012	98053W	PARTICIPANT	\N	EXCUSE	0
163037	163012	11083R	PARTICIPANT	\N	PRESENT	0
163216	163199	80013X	PARTICIPANT	\N	PRESENT	0
163039	163012	01057W	PARTICIPANT	\N	PRESENT	0
163219	163199	14219Q	PARTICIPANT	\N	EXCUSE	0
163041	163012	08069G	PARTICIPANT	\N	PRESENT	0
163042	163012	11048N	PARTICIPANT	\N	PRESENT	0
163223	163199	11035H	PARTICIPANT	\N	EXCUSE	0
163270	163199	14093U	PARTICIPANT	\N	PRESENT	0
163045	163012	14159V	PARTICIPANT	\N	PRESENT	0
163046	163012	07029T	PARTICIPANT	\N	PRESENT	0
163533	163532	14089Y	PARTICIPANT	\N	PRESENT	0
163048	163012	08010L	PARTICIPANT	\N	PRESENT	0
163049	163012	08034U	PARTICIPANT	\N	PRESENT	0
163534	163532	14207L	PARTICIPANT	\N	PRESENT	0
163051	163012	98046X	PARTICIPANT	\N	PRESENT	0
163052	163012	11085T	PARTICIPANT	\N	EXCUSE	0
163053	163012	08011M	PARTICIPANT	\N	PRESENT	0
163535	163532	14229S	PARTICIPANT	\N	PRESENT	0
163055	163012	08061X	PARTICIPANT	\N	PRESENT	0
163056	163012	01016M	PARTICIPANT	\N	PRESENT	0
163057	163012	14225N	PARTICIPANT	\N	PRESENT	0
163058	163012	11012A	PARTICIPANT	\N	PRESENT	0
163059	163012	11057P	PARTICIPANT	\N	PRESENT	0
163060	163012	14173T	PARTICIPANT	\N	PRESENT	0
163061	163012	04034C	PARTICIPANT	\N	EXCUSE	0
163536	163532	14031R	PARTICIPANT	\N	PRESENT	0
163537	163532	14135M	PARTICIPANT	\N	PRESENT	0
163538	163532	14281W	PARTICIPANT	\N	PRESENT	0
163539	163532	11014C	PARTICIPANT	\N	PRESENT	0
163573	163572	04040A	PARTICIPANT	\N	PRESENT	0
163574	163572	14030Q	PARTICIPANT	\N	PRESENT	0
163575	163572	98042T	PARTICIPANT	\N	PRESENT	0
163576	163572	11012A	PARTICIPANT	\N	PRESENT	0
163577	163572	92031P	PARTICIPANT	\N	PRESENT	0
163578	163572	14063N	PARTICIPANT	\N	PRESENT	0
163579	163572	14079W	PARTICIPANT	\N	PRESENT	0
163655	163654	01015L	PRESIDENT	0	PRESENT	0
163656	163654	11065P	PARTICIPANT	\N	PRESENT	0
163657	163654	14093U	PARTICIPANT	\N	PRESENT	0
163658	163654	11035H	PARTICIPANT	\N	EXCUSE	0
163659	163654	01056V	PARTICIPANT	\N	EXCUSE	0
163660	163654	11090Q	PARTICIPANT	\N	EXCUSE	0
163661	163654	14219Q	PARTICIPANT	\N	EXCUSE	0
163672	163654	80013X	PARTICIPANT	\N	PRESENT	0
163692	163654	92045V	PARTICIPANT	\N	PRESENT	0
163933	163932	04047H	PARTICIPANT	\N	PRESENT	0
163934	163932	14267Y	PARTICIPANT	\N	PRESENT	0
163935	163932	14079W	PARTICIPANT	\N	PRESENT	0
163936	163932	14026U	PARTICIPANT	\N	PRESENT	0
163937	163932	11084S	PARTICIPANT	\N	PRESENT	0
163938	163932	14073Q	PARTICIPANT	\N	PRESENT	0
163939	163932	92031P	PARTICIPANT	\N	PRESENT	0
163940	163932	11026G	PARTICIPANT	\N	PRESENT	0
163941	163932	14001X	PARTICIPANT	\N	PRESENT	0
163942	163932	11012A	PARTICIPANT	\N	PRESENT	0
163943	163932	14227Q	PARTICIPANT	\N	PRESENT	0
163944	163932	11066Q	PARTICIPANT	\N	PRESENT	0
163945	163932	95067Q	PARTICIPANT	\N	PRESENT	0
163954	163953	07034Q	PARTICIPANT	\N	PRESENT	0
163956	163955	07034Q	PARTICIPANT	\N	PRESENT	0
163992	163972	14026U	PARTICIPANT	\N	PRESENT	0
163993	163972	14257W	PARTICIPANT	\N	PRESENT	0
164194	164193	14219Q	PRESIDENT	0	PRESENT	0
164195	164193	11065P	PARTICIPANT	\N	PRESENT	0
164196	164193	80013X	PARTICIPANT	\N	PRESENT	0
164197	164193	09001P	PARTICIPANT	\N	PRESENT	0
164198	164193	05012A	PARTICIPANT	\N	PRESENT	0
164199	164193	01015L	PARTICIPANT	\N	PRESENT	0
164200	164193	11035H	PARTICIPANT	\N	EXCUSE	0
164333	163372	11048N	PARTICIPANT	\N	EXCUSE	0
164334	163372	04040A	PRESIDENT	0	PRESENT	0
164362	164357	01041N	PARTICIPANT	\N	PRESENT	0
164363	164357	08017T	PARTICIPANT	\N	PRESENT	0
164373	164372	01041N	PARTICIPANT	\N	PRESENT	0
164374	164372	08017T	PARTICIPANT	\N	PRESENT	0
164473	164472	04080J	PARTICIPANT	\N	PRESENT	0
134532	125517	04049K	PARTICIPANT	\N	PRESENT	0
134533	125517	95067Q	PARTICIPANT	\N	PRESENT	0
134534	125517	14061L	PARTICIPANT	\N	PRESENT	0
134535	125517	14105F	PARTICIPANT	\N	PRESENT	0
134536	125517	14265W	PARTICIPANT	\N	PRESENT	0
134588	134587	04044E	PARTICIPANT	\N	PRESENT	0
134589	134587	11029K	PARTICIPANT	\N	PRESENT	0
134590	134587	95035G	PARTICIPANT	\N	PRESENT	0
134591	134587	08017T	PARTICIPANT	\N	PRESENT	0
134592	134587	04057K	PARTICIPANT	\N	PRESENT	0
134643	134642	08043V	PARTICIPANT	\N	PRESENT	0
134644	134642	11029K	PARTICIPANT	\N	PRESENT	0
134645	134642	14030Q	PARTICIPANT	\N	PRESENT	0
134646	134642	11031D	PARTICIPANT	\N	PRESENT	0
134647	134642	14217N	PARTICIPANT	\N	PRESENT	0
134648	134642	08031R	PARTICIPANT	\N	PRESENT	0
134649	134642	08017T	PARTICIPANT	\N	PRESENT	0
134650	134642	09001P	PRESIDENT	0	PRESENT	0
134651	134642	07026Q	PARTICIPANT	\N	PRESENT	0
134652	134642	14031R	PARTICIPANT	\N	PRESENT	0
134653	134642	11014C	PARTICIPANT	\N	PRESENT	0
134654	134642	14109K	PARTICIPANT	\N	PRESENT	0
134655	134642	08060W	PARTICIPANT	\N	EXCUSE	0
134656	134642	80013X	PARTICIPANT	\N	EXCUSE	0
134657	134642	14041T	PARTICIPANT	\N	EXCUSE	0
134658	134642	95035G	PARTICIPANT	\N	EXCUSE	0
134659	134642	07029T	PARTICIPANT	\N	EXCUSE	0
134660	134642	11067R	PARTICIPANT	\N	EXCUSE	0
134670	134669	14030Q	PARTICIPANT	\N	PRESENT	0
134671	134669	08043V	PARTICIPANT	\N	PRESENT	0
134672	134669	11029K	PARTICIPANT	\N	PRESENT	0
134673	134669	11031D	PARTICIPANT	\N	PRESENT	0
134674	134669	14217N	PARTICIPANT	\N	PRESENT	0
134675	134669	07026Q	PARTICIPANT	\N	PRESENT	0
134676	134669	09001P	PRESIDENT	0	PRESENT	0
134677	134669	08031R	PARTICIPANT	\N	PRESENT	0
134678	134669	08017T	PARTICIPANT	\N	PRESENT	0
134679	134669	14031R	PARTICIPANT	\N	PRESENT	0
134680	134669	11014C	PARTICIPANT	\N	PRESENT	0
134681	134669	14109K	PARTICIPANT	\N	PRESENT	0
134682	134669	12042Y	PARTICIPANT	\N	PRESENT	0
134683	134669	08060W	PARTICIPANT	\N	EXCUSE	0
134684	134669	80013X	PARTICIPANT	\N	EXCUSE	0
134685	134669	14041T	PARTICIPANT	\N	EXCUSE	0
134686	134669	95035G	PARTICIPANT	\N	EXCUSE	0
134687	134669	07029T	PARTICIPANT	\N	EXCUSE	0
134688	134669	11067R	PARTICIPANT	\N	EXCUSE	0
134703	134702	92040Q	PARTICIPANT	\N	PRESENT	0
137645	136720	08009T	PARTICIPANT	\N	PRESENT	0
137646	136720	11065P	PARTICIPANT	\N	PRESENT	0
137647	136722	14207L	PARTICIPANT	\N	PRESENT	0
137648	136722	95015C	PARTICIPANT	\N	PRESENT	0
137649	136722	14038Y	PARTICIPANT	\N	PRESENT	0
137650	136722	14195A	PARTICIPANT	\N	PRESENT	0
137651	136722	14327T	PARTICIPANT	\N	PRESENT	0
137652	136722	14197C	PARTICIPANT	\N	PRESENT	0
137653	136722	14014Q	PARTICIPANT	\N	PRESENT	0
137654	136722	14179A	PARTICIPANT	\N	PRESENT	0
137655	136722	14237S	PARTICIPANT	\N	PRESENT	0
137656	136722	14107H	PARTICIPANT	\N	PRESENT	0
138162	137838	14269B	PARTICIPANT	\N	PRESENT	0
138163	137838	11023D	PARTICIPANT	\N	PRESENT	0
138164	137838	12042Y	PARTICIPANT	\N	PRESENT	0
138165	137838	01037S	PARTICIPANT	\N	PRESENT	0
138166	137838	11055M	PARTICIPANT	\N	PRESENT	0
138167	137838	11029K	PARTICIPANT	\N	PRESENT	0
138168	137838	04067M	PARTICIPANT	\N	PRESENT	0
138170	137838	14239U	PARTICIPANT	\N	PRESENT	0
138171	137838	14042U	PARTICIPANT	\N	PRESENT	0
138172	137838	11083R	PARTICIPANT	\N	PRESENT	0
138173	137838	14205J	PARTICIPANT	\N	PRESENT	0
138174	137838	14089Y	PARTICIPANT	\N	PRESENT	0
138175	137838	01046T	PARTICIPANT	\N	PRESENT	0
138176	137838	08031R	PARTICIPANT	\N	PRESENT	0
138177	137838	14231L	PARTICIPANT	\N	PRESENT	0
138178	137838	14083S	PARTICIPANT	\N	PRESENT	0
138179	137838	11093T	PARTICIPANT	\N	PRESENT	0
138181	137838	11053K	PARTICIPANT	\N	PRESENT	0
138182	137838	14179A	PARTICIPANT	\N	PRESENT	0
138183	137838	14215L	PARTICIPANT	\N	PRESENT	0
138184	137838	14071N	PARTICIPANT	\N	PRESENT	0
138185	137838	95037J	PARTICIPANT	\N	PRESENT	0
138186	137838	98029W	PARTICIPANT	\N	PRESENT	0
138187	137838	95030B	PARTICIPANT	\N	PRESENT	0
138188	137838	98024R	PARTICIPANT	\N	PRESENT	0
138189	137838	86044G	PARTICIPANT	\N	PRESENT	0
138190	137838	04043D	PARTICIPANT	\N	PRESENT	0
138191	137838	97011G	PARTICIPANT	\N	PRESENT	0
138192	137838	11103C	PARTICIPANT	\N	PRESENT	0
138193	137838	07024N	PARTICIPANT	\N	PRESENT	0
138194	137838	14053L	PARTICIPANT	\N	PRESENT	0
138195	137838	14059S	PARTICIPANT	\N	PRESENT	0
138196	137838	14028W	PARTICIPANT	\N	PRESENT	0
138197	137838	04055H	PARTICIPANT	\N	PRESENT	0
138198	137838	14213J	PARTICIPANT	\N	PRESENT	0
138199	137838	08015R	PARTICIPANT	\N	PRESENT	0
138200	137838	11071M	PARTICIPANT	\N	PRESENT	0
138201	137838	07029T	PARTICIPANT	\N	PRESENT	0
138202	137838	14135M	PARTICIPANT	\N	PRESENT	0
138203	137838	04088S	PARTICIPANT	\N	PRESENT	0
138204	137838	14026U	PARTICIPANT	\N	PRESENT	0
138205	137838	14265W	PARTICIPANT	\N	PRESENT	0
138206	137838	14147R	PARTICIPANT	\N	PRESENT	0
138207	137838	11097X	PARTICIPANT	\N	PRESENT	0
138208	137838	14223L	PARTICIPANT	\N	PRESENT	0
138209	137838	11049P	PARTICIPANT	\N	PRESENT	0
138210	137838	11044J	PARTICIPANT	\N	PRESENT	0
138211	137838	87003B	PARTICIPANT	\N	PRESENT	0
138212	137838	01057W	PARTICIPANT	\N	PRESENT	0
138213	137838	14195A	PARTICIPANT	\N	PRESENT	0
138214	137838	14033T	PARTICIPANT	\N	PRESENT	0
138215	137838	14119M	PARTICIPANT	\N	PRESENT	0
138216	137838	14105F	PARTICIPANT	\N	PRESENT	0
138217	137838	08039A	PARTICIPANT	\N	PRESENT	0
138218	137838	14217N	PARTICIPANT	\N	PRESENT	0
138219	137838	14331P	PARTICIPANT	\N	PRESENT	0
138220	137838	04045F	PARTICIPANT	\N	PRESENT	0
138221	137838	14257W	PARTICIPANT	\N	PRESENT	0
138222	137838	11063M	PARTICIPANT	\N	PRESENT	0
138223	137838	14111D	PARTICIPANT	\N	PRESENT	0
138224	137838	04081K	PARTICIPANT	\N	PRESENT	0
138225	137838	99004R	PARTICIPANT	\N	PRESENT	0
138226	137838	98046X	PARTICIPANT	\N	PRESENT	0
138227	137838	01027Q	PARTICIPANT	\N	PRESENT	0
138228	137838	08041T	PARTICIPANT	\N	PRESENT	0
138229	137838	10006L	PARTICIPANT	\N	PRESENT	0
138230	137838	14038Y	PARTICIPANT	\N	PRESENT	0
138296	137838	08010L	PARTICIPANT	\N	PRESENT	0
138297	137838	08017T	PARTICIPANT	\N	PRESENT	0
138301	137838	14093U	PARTICIPANT	\N	PRESENT	0
138306	137838	11104D	PARTICIPANT	\N	PRESENT	0
138307	137838	08019V	PARTICIPANT	\N	PRESENT	0
138309	137838	14109K	PARTICIPANT	\N	PRESENT	0
138311	137838	95035G	PARTICIPANT	\N	PRESENT	0
138312	137838	11064N	PARTICIPANT	\N	PRESENT	0
138313	137838	01028R	PARTICIPANT	\N	PRESENT	0
138314	137838	11088W	PARTICIPANT	\N	PRESENT	0
138315	137838	04033B	PARTICIPANT	\N	PRESENT	0
138316	137838	14123H	PARTICIPANT	\N	PRESENT	0
138318	137838	14221J	PARTICIPANT	\N	PRESENT	0
138319	137838	14030Q	PARTICIPANT	\N	PRESENT	0
138320	137838	14219Q	PARTICIPANT	\N	PRESENT	0
138321	137838	11094U	PARTICIPANT	\N	PRESENT	0
138322	137838	83047W	PARTICIPANT	\N	PRESENT	0
138323	137838	08062Y	PARTICIPANT	\N	PRESENT	0
138324	137838	14157T	PARTICIPANT	\N	PRESENT	0
138354	137838	80013X	PARTICIPANT	\N	PRESENT	0
138355	137838	01022K	PARTICIPANT	\N	PRESENT	0
138356	137838	01056V	PARTICIPANT	\N	PRESENT	0
138362	137838	08028W	PARTICIPANT	\N	PRESENT	0
138363	137838	14253S	PARTICIPANT	\N	PRESENT	0
138364	137838	14061L	PARTICIPANT	\N	PRESENT	0
138365	137838	14069U	PARTICIPANT	\N	PRESENT	0
138366	137838	11105E	PARTICIPANT	\N	PRESENT	0
138367	137838	04053F	PARTICIPANT	\N	PRESENT	0
138369	137838	08051V	PARTICIPANT	\N	PRESENT	0
138371	137838	92015P	PARTICIPANT	\N	PRESENT	0
138372	137838	14097Y	PARTICIPANT	\N	PRESENT	0
138373	137838	14151M	PARTICIPANT	\N	PRESENT	0
138375	137838	11043H	PARTICIPANT	\N	PRESENT	0
138377	137838	11048N	PARTICIPANT	\N	PRESENT	0
152712	149974	14034U	PARTICIPANT	\N	PRESENT	0
152812	152792	14031R	PARTICIPANT	\N	PRESENT	0
152835	152832	14193X	PARTICIPANT	\N	PRESENT	0
152837	152832	01058X	PARTICIPANT	\N	PRESENT	0
152836	152832	11046L	PARTICIPANT	\N	PRESENT	0
152839	152838	14105F	PARTICIPANT	\N	PRESENT	0
152840	152838	14207L	PARTICIPANT	\N	PRESENT	0
152841	152838	90003B	PARTICIPANT	\N	PRESENT	0
152842	152838	14038Y	PARTICIPANT	\N	PRESENT	0
152843	152838	88008L	PARTICIPANT	\N	PRESENT	0
152844	152838	80013X	PARTICIPANT	\N	PRESENT	0
152845	152838	14151M	PARTICIPANT	\N	PRESENT	0
152846	152838	95037J	PARTICIPANT	\N	PRESENT	0
152847	152838	08015R	PARTICIPANT	\N	PRESENT	0
152848	152838	14257W	PARTICIPANT	\N	PRESENT	0
152849	152838	05012A	PARTICIPANT	\N	PRESENT	0
152851	152850	08068F	PARTICIPANT	\N	PRESENT	0
153020	153019	89017R	PARTICIPANT	\N	PRESENT	0
153021	153019	11039M	PARTICIPANT	\N	PRESENT	0
153022	153019	08055A	PARTICIPANT	\N	PRESENT	0
153023	153019	11029K	PARTICIPANT	\N	PRESENT	0
153024	153019	04066L	PARTICIPANT	\N	PRESENT	0
153025	153019	04042C	PARTICIPANT	\N	PRESENT	0
153026	153019	08024S	PARTICIPANT	\N	PRESENT	0
153027	153019	04081K	PARTICIPANT	\N	PRESENT	0
153028	153019	98042T	PARTICIPANT	\N	PRESENT	0
153029	153019	11110B	PARTICIPANT	\N	PRESENT	0
153030	153019	01003G	PARTICIPANT	\N	PRESENT	0
153031	153019	98053W	PARTICIPANT	\N	PRESENT	0
153032	153019	95037J	PARTICIPANT	\N	PRESENT	0
153033	153019	86034E	PARTICIPANT	\N	PRESENT	0
153034	153019	04094Q	PARTICIPANT	\N	PRESENT	0
153035	153019	01043Q	PARTICIPANT	\N	PRESENT	0
153036	153019	11085T	PARTICIPANT	\N	PRESENT	0
153037	153019	04057K	PARTICIPANT	\N	PRESENT	0
153038	153019	92040Q	PARTICIPANT	\N	PRESENT	0
153039	153019	04088S	PARTICIPANT	\N	PRESENT	0
153040	153019	04056J	PARTICIPANT	\N	PRESENT	0
154020	154019	11039M	PARTICIPANT	\N	PRESENT	0
154021	154019	08012N	PARTICIPANT	\N	PRESENT	0
154022	154019	14073Q	PARTICIPANT	\N	PRESENT	0
154097	154096	04057K	PARTICIPANT	\N	PRESENT	0
154134	154133	05008E	PARTICIPANT	\N	PRESENT	0
154135	154133	14065Q	PARTICIPANT	\N	PRESENT	0
154137	154136	05008E	PARTICIPANT	\N	PRESENT	0
154139	154138	05008E	PARTICIPANT	\N	PRESENT	0
154141	154140	05008E	PARTICIPANT	\N	PRESENT	0
154143	154142	05008E	PARTICIPANT	\N	PRESENT	0
154144	154142	14065Q	PARTICIPANT	\N	PRESENT	0
154159	154158	14135M	PARTICIPANT	\N	PRESENT	0
154299	154298	96004D	PARTICIPANT	\N	PRESENT	0
154300	154298	04080J	PARTICIPANT	\N	PRESENT	0
154302	154301	96004D	PARTICIPANT	\N	PRESENT	0
156095	156094	11036J	PARTICIPANT	\N	PRESENT	0
156096	156094	04049K	PARTICIPANT	\N	PRESENT	0
156097	156094	98005N	PARTICIPANT	\N	PRESENT	0
156098	156094	14219Q	PARTICIPANT	\N	PRESENT	0
156099	156094	11011M	PARTICIPANT	\N	PRESENT	0
156100	156094	04043D	PARTICIPANT	\N	PRESENT	0
156214	156213	14261S	PARTICIPANT	\N	PRESENT	0
156215	156213	08055A	PARTICIPANT	\N	PRESENT	0
156216	156213	14093U	PARTICIPANT	\N	PRESENT	0
156217	156213	14030Q	PARTICIPANT	\N	PRESENT	0
156218	156213	96004D	PARTICIPANT	\N	PRESENT	0
156219	156213	08060W	PARTICIPANT	\N	PRESENT	0
156253	156213	05001W	PARTICIPANT	\N	EXCUSE	0
156221	156213	14038Y	PARTICIPANT	\N	PRESENT	0
156222	156213	11114F	PARTICIPANT	\N	PRESENT	0
156223	156213	98023Q	PARTICIPANT	\N	PRESENT	0
156224	156213	11065P	PARTICIPANT	\N	PRESENT	0
156225	156213	01015L	PARTICIPANT	\N	PRESENT	0
152692	149974	14083S	PARTICIPANT	\N	PRESENT	0
152693	149974	14219Q	PARTICIPANT	\N	PRESENT	0
156226	156213	11107G	PARTICIPANT	\N	EXCUSE	0
156227	156213	11020A	PARTICIPANT	\N	PRESENT	0
156273	156272	01008M	PARTICIPANT	\N	PRESENT	0
156274	156272	11036J	PARTICIPANT	\N	PRESENT	0
156334	156333	01008M	PARTICIPANT	\N	PRESENT	0
156231	156213	04097T	PARTICIPANT	\N	PRESENT	0
156232	156213	09001P	PARTICIPANT	\N	PRESENT	0
156233	156213	11059R	PARTICIPANT	\N	PRESENT	0
156234	156213	14219Q	PARTICIPANT	\N	PRESENT	0
156276	156272	14013P	PARTICIPANT	\N	PRESENT	0
156236	156213	14031R	PARTICIPANT	\N	PRESENT	0
156237	156213	08009T	PARTICIPANT	\N	EXCUSE	0
156238	156213	08062Y	PARTICIPANT	\N	PRESENT	0
156277	156272	08068F	PARTICIPANT	\N	PRESENT	0
156240	156213	92039X	PARTICIPANT	\N	EXCUSE	0
156241	156213	08042U	PARTICIPANT	\N	PRESENT	0
156278	156272	14207L	PARTICIPANT	\N	PRESENT	0
156335	156333	11036J	PARTICIPANT	\N	PRESENT	0
156244	156213	13002U	PARTICIPANT	\N	PRESENT	0
156245	156213	05012A	PRESIDENT	0	PRESENT	0
156246	156213	14247U	PARTICIPANT	\N	PRESENT	0
156247	156213	14135M	PARTICIPANT	\N	EXCUSE	0
156248	156213	14331P	PARTICIPANT	\N	PRESENT	0
156249	156213	95062K	PARTICIPANT	\N	PRESENT	0
156250	156213	14107H	PARTICIPANT	\N	PRESENT	0
156251	156213	14051J	PARTICIPANT	\N	PRESENT	0
156252	156213	14157T	PARTICIPANT	\N	PRESENT	0
156633	156632	14083S	PARTICIPANT	\N	PRESENT	0
156280	156272	90003B	PARTICIPANT	\N	PRESENT	0
156281	156272	08028W	PARTICIPANT	\N	PRESENT	0
156337	156333	14013P	PARTICIPANT	\N	PRESENT	0
156283	156272	14357A	PARTICIPANT	\N	PRESENT	0
156284	156272	08038Y	PARTICIPANT	\N	PRESENT	0
156338	156333	08068F	PARTICIPANT	\N	PRESENT	0
156286	156272	14197C	PARTICIPANT	\N	PRESENT	0
156339	156333	14207L	PARTICIPANT	\N	PRESENT	0
156288	156272	14187A	PARTICIPANT	\N	PRESENT	0
156289	156272	14033T	PARTICIPANT	\N	PRESENT	0
156290	156272	14081Q	PARTICIPANT	\N	PRESENT	0
156291	156272	11099A	PARTICIPANT	\N	PRESENT	0
156292	156272	04049K	PARTICIPANT	\N	PRESENT	0
156713	156712	14239U	PARTICIPANT	\N	PRESENT	0
156341	156333	90003B	PARTICIPANT	\N	PRESENT	0
156295	156272	08015R	PARTICIPANT	\N	PRESENT	0
156296	156272	11100Y	PRESIDENT	0	PRESENT	0
156297	156272	01061S	PARTICIPANT	\N	EXCUSE	0
156298	156272	11098Y	PARTICIPANT	\N	PRESENT	0
156299	156272	01043Q	PARTICIPANT	\N	PRESENT	0
156300	156272	11077T	PARTICIPANT	\N	PRESENT	0
156342	156333	08028W	PARTICIPANT	\N	PRESENT	0
156303	156272	14257W	PARTICIPANT	\N	PRESENT	0
156344	156333	14357A	PARTICIPANT	\N	PRESENT	0
156305	156272	04088S	PARTICIPANT	\N	PRESENT	0
156345	156333	08038Y	PARTICIPANT	\N	PRESENT	0
156309	156272	01058X	PARTICIPANT	\N	PRESENT	0
156310	156272	11094U	PARTICIPANT	\N	EXCUSE	0
156311	156272	11066Q	PARTICIPANT	\N	PRESENT	0
156347	156333	14197C	PARTICIPANT	\N	PRESENT	0
156349	156333	14187A	PARTICIPANT	\N	PRESENT	0
156350	156333	14033T	PARTICIPANT	\N	PRESENT	0
156351	156333	14081Q	PARTICIPANT	\N	PRESENT	0
156352	156333	11099A	PARTICIPANT	\N	PRESENT	0
156353	156333	04049K	PARTICIPANT	\N	PRESENT	0
156719	156712	11031D	PARTICIPANT	\N	PRESENT	0
156356	156333	08015R	PARTICIPANT	\N	PRESENT	0
156357	156333	11100Y	PRESIDENT	0	PRESENT	0
156358	156333	01061S	PARTICIPANT	\N	EXCUSE	0
156359	156333	11098Y	PARTICIPANT	\N	PRESENT	0
156360	156333	01043Q	PARTICIPANT	\N	PRESENT	0
156361	156333	11077T	PARTICIPANT	\N	PRESENT	0
156720	156712	08052W	PARTICIPANT	\N	PRESENT	0
156721	156712	14041T	PARTICIPANT	\N	PRESENT	0
156364	156333	14257W	PARTICIPANT	\N	PRESENT	0
156366	156333	04088S	PARTICIPANT	\N	PRESENT	0
156723	156712	87003B	PARTICIPANT	\N	EXCUSE	0
156724	156712	11061K	PARTICIPANT	\N	PRESENT	0
156725	156712	14213J	PARTICIPANT	\N	PRESENT	0
156370	156333	01058X	PARTICIPANT	\N	PRESENT	0
156371	156333	11094U	PARTICIPANT	\N	EXCUSE	0
156372	156333	11066Q	PARTICIPANT	\N	PRESENT	0
156728	156712	14147R	PARTICIPANT	\N	PRESENT	0
156730	156712	04092N	PRESIDENT	0	PRESENT	0
156731	156712	14265W	PARTICIPANT	\N	PRESENT	0
156732	156712	14028W	PARTICIPANT	\N	EXCUSE	0
156733	156712	14235Q	PARTICIPANT	\N	EXCUSE	0
156734	156712	14331P	PARTICIPANT	\N	PRESENT	0
156735	156712	14271U	PARTICIPANT	\N	EXCUSE	0
129543	129541	04040A	PRESIDENT	0	PRESENT	0
131965	131964	14071N	PARTICIPANT	\N	PRESENT	0
130711	130709	08009T	PARTICIPANT	\N	PRESENT	0
130712	130709	11026G	PARTICIPANT	\N	PRESENT	0
131966	131964	14281W	PARTICIPANT	\N	PRESENT	0
131967	131964	04053F	PARTICIPANT	\N	PRESENT	0
131968	131964	14227Q	PARTICIPANT	\N	PRESENT	0
131983	131982	01034P	PARTICIPANT	\N	PRESENT	0
131984	131982	01046T	PARTICIPANT	\N	PRESENT	0
131985	131982	14042U	PARTICIPANT	\N	PRESENT	0
133310	133270	08042U	PARTICIPANT	\N	EXCUSE	0
133761	133758	11097X	PARTICIPANT	\N	PRESENT	0
133763	133759	14037X	PARTICIPANT	\N	PRESENT	0
133821	133760	14037X	PARTICIPANT	\N	PRESENT	0
133825	133824	14037X	PARTICIPANT	\N	PRESENT	0
133827	133826	14037X	PARTICIPANT	\N	PRESENT	0
133829	133828	14037X	PARTICIPANT	\N	PRESENT	0
134150	134149	14119M	PARTICIPANT	\N	PRESENT	0
133271	133270	14261S	PARTICIPANT	\N	PRESENT	0
133272	133270	08055A	PARTICIPANT	\N	PRESENT	0
133273	133270	14093U	PARTICIPANT	\N	PRESENT	0
133274	133270	14030Q	PARTICIPANT	\N	PRESENT	0
133275	133270	96004D	PARTICIPANT	\N	PRESENT	0
133276	133270	08060W	PARTICIPANT	\N	PRESENT	0
133277	133270	11095V	PARTICIPANT	\N	EXCUSE	0
133278	133270	14038Y	PARTICIPANT	\N	PRESENT	0
134309	134308	01008M	PARTICIPANT	\N	PRESENT	0
133280	133270	98023Q	PARTICIPANT	\N	PRESENT	0
133281	133270	11065P	PARTICIPANT	\N	PRESENT	0
133282	133270	01015L	PARTICIPANT	\N	PRESENT	0
133283	133270	11107G	PARTICIPANT	\N	PRESENT	0
133284	133270	11020A	PARTICIPANT	\N	PRESENT	0
134310	134308	11036J	PARTICIPANT	\N	PRESENT	0
134356	134355	01031L	PRESIDENT	0	PRESENT	0
133287	133270	04097T	PARTICIPANT	\N	PRESENT	0
133288	133270	09001P	PARTICIPANT	\N	PRESENT	0
133289	133270	11059R	PARTICIPANT	\N	PRESENT	0
133290	133270	14219Q	PARTICIPANT	\N	PRESENT	0
133291	133270	80027E	PARTICIPANT	\N	PRESENT	0
133292	133270	14031R	PARTICIPANT	\N	PRESENT	0
133293	133270	08009T	PARTICIPANT	\N	PRESENT	0
133294	133270	08062Y	PARTICIPANT	\N	PRESENT	0
133295	133270	14221J	PARTICIPANT	\N	PRESENT	0
134312	134308	14013P	PARTICIPANT	\N	EXCUSE	0
134358	134355	14175V	PARTICIPANT	\N	PRESENT	0
133298	133270	14169X	PARTICIPANT	\N	PRESENT	0
133299	133270	14237S	PARTICIPANT	\N	PRESENT	0
133300	133270	13002U	PARTICIPANT	\N	PRESENT	0
133301	133270	05012A	PARTICIPANT	\N	PRESENT	0
133302	133270	14247U	PARTICIPANT	\N	PRESENT	0
133303	133270	14135M	PARTICIPANT	\N	PRESENT	0
133304	133270	14331P	PARTICIPANT	\N	PRESENT	0
133305	133270	95062K	PARTICIPANT	\N	PRESENT	0
133306	133270	14107H	PARTICIPANT	\N	PRESENT	0
134314	134308	14207L	PARTICIPANT	\N	PRESENT	0
134315	134308	11101A	PARTICIPANT	\N	PRESENT	0
133309	133270	96003C	PARTICIPANT	\N	EXCUSE	0
134316	134308	90003B	PARTICIPANT	\N	EXCUSE	0
134357	134355	08014Q	PARTICIPANT	\N	PRESENT	0
134318	134308	80013X	PARTICIPANT	\N	PRESENT	0
134319	134308	08038Y	PARTICIPANT	\N	PRESENT	0
134320	134308	04089T	PARTICIPANT	\N	PRESENT	0
134321	134308	14197C	PARTICIPANT	\N	PRESENT	0
134359	134355	11053K	PARTICIPANT	\N	PRESENT	0
134323	134308	14187A	PARTICIPANT	\N	PRESENT	0
134324	134308	14033T	PARTICIPANT	\N	PRESENT	0
134325	134308	14081Q	PARTICIPANT	\N	PRESENT	0
134360	134355	14085U	PARTICIPANT	\N	PRESENT	0
134327	134308	11099A	PARTICIPANT	\N	PRESENT	0
134328	134308	04049K	PARTICIPANT	\N	PRESENT	0
134361	134355	11042G	PARTICIPANT	\N	PRESENT	0
134330	134308	11111C	PARTICIPANT	\N	PRESENT	0
134331	134308	08015R	PARTICIPANT	\N	PRESENT	0
134332	134308	11100Y	PRESIDENT	0	PRESENT	0
134333	134308	01061S	PARTICIPANT	\N	EXCUSE	0
134362	134355	88008L	PARTICIPANT	\N	PRESENT	0
134363	134355	04086Q	PARTICIPANT	\N	PRESENT	0
134364	134355	11070L	PARTICIPANT	\N	PRESENT	0
134337	134308	14205J	PARTICIPANT	\N	PRESENT	0
134338	134308	08019V	PARTICIPANT	\N	PRESENT	0
134339	134308	14257W	PARTICIPANT	\N	PRESENT	0
134365	134355	11088W	PARTICIPANT	\N	PRESENT	0
134341	134308	04088S	PARTICIPANT	\N	PRESENT	0
134342	134308	98050T	PARTICIPANT	\N	PRESENT	0
134343	134308	11090Q	PARTICIPANT	\N	PRESENT	0
134344	134308	11046L	PARTICIPANT	\N	PRESENT	0
134345	134308	01058X	PARTICIPANT	\N	PRESENT	0
134346	134308	11094U	PARTICIPANT	\N	EXCUSE	0
134347	134308	11066Q	PARTICIPANT	\N	PRESENT	0
134366	134355	08022Q	PARTICIPANT	\N	PRESENT	0
134367	134355	04071H	PARTICIPANT	\N	PRESENT	0
134368	134355	11074Q	PARTICIPANT	\N	PRESENT	0
134369	134355	98053W	PARTICIPANT	\N	PRESENT	0
134370	134355	11083R	PARTICIPANT	\N	PRESENT	0
134371	134355	14199E	PARTICIPANT	\N	PRESENT	0
134372	134355	01057W	PARTICIPANT	\N	PRESENT	0
134373	134355	08016S	PARTICIPANT	\N	PRESENT	0
134374	134355	11048N	PARTICIPANT	\N	PRESENT	0
134375	134355	99004R	PARTICIPANT	\N	PRESENT	0
134376	134355	14159V	PARTICIPANT	\N	PRESENT	0
134377	134355	07029T	PARTICIPANT	\N	PRESENT	0
134378	134355	01048V	PARTICIPANT	\N	PRESENT	0
134379	134355	98046X	PARTICIPANT	\N	PRESENT	0
134380	134355	08011M	PARTICIPANT	\N	PRESENT	0
134381	134355	08061X	PARTICIPANT	\N	PRESENT	0
134382	134355	01016M	PARTICIPANT	\N	PRESENT	0
134383	134355	14225N	PARTICIPANT	\N	PRESENT	0
134384	134355	11012A	PARTICIPANT	\N	PRESENT	0
134385	134355	11057P	PARTICIPANT	\N	PRESENT	0
134386	134355	14173T	PARTICIPANT	\N	PRESENT	0
134387	134355	04034C	PARTICIPANT	\N	PRESENT	0
134388	134355	89017R	PARTICIPANT	\N	EXCUSE	0
134389	134355	14327T	PARTICIPANT	\N	EXCUSE	0
134390	134355	01027Q	PARTICIPANT	\N	EXCUSE	0
134391	134355	08069G	PARTICIPANT	\N	EXCUSE	0
134537	132784	11025F	PARTICIPANT	\N	EXCUSE	0
136879	136878	96004D	PRESIDENT	0	PRESENT	0
136880	136878	07024N	PRESIDENT	1	PRESENT	0
136881	136878	95059Q	PARTICIPANT	\N	EXCUSE	0
136882	136878	98035U	PARTICIPANT	\N	PRESENT	0
136883	136878	83042R	PARTICIPANT	\N	PRESENT	0
136884	136878	14097Y	PARTICIPANT	\N	PRESENT	0
136885	136878	04057K	PARTICIPANT	\N	EXCUSE	0
136886	136878	04040A	PARTICIPANT	\N	EXCUSE	0
137557	137532	11057P	PARTICIPANT	\N	PRESENT	0
137202	137200	08055A	PARTICIPANT	\N	PRESENT	0
137203	137200	14093U	PARTICIPANT	\N	PRESENT	0
137204	137200	14030Q	PARTICIPANT	\N	PRESENT	0
137205	137200	96004D	PARTICIPANT	\N	PRESENT	0
137555	137532	08073C	PARTICIPANT	\N	EXCUSE	0
137207	137200	11095V	PARTICIPANT	\N	PRESENT	0
137208	137200	14038Y	PARTICIPANT	\N	PRESENT	0
137209	137200	11114F	PARTICIPANT	\N	PRESENT	0
137210	137200	98023Q	PARTICIPANT	\N	PRESENT	0
137211	137200	11065P	PARTICIPANT	\N	PRESENT	0
137212	137200	01015L	PARTICIPANT	\N	PRESENT	0
137556	137532	01016M	PARTICIPANT	\N	PRESENT	0
137558	137532	04034C	PARTICIPANT	\N	EXCUSE	0
137215	137200	02002K	PARTICIPANT	\N	PRESENT	0
137216	137200	01022K	PARTICIPANT	\N	PRESENT	0
137217	137200	04097T	PARTICIPANT	\N	PRESENT	0
137218	137200	09001P	PARTICIPANT	\N	PRESENT	0
137219	137200	11059R	PARTICIPANT	\N	PRESENT	0
137220	137200	14219Q	PARTICIPANT	\N	PRESENT	0
137221	137200	80027E	PARTICIPANT	\N	PRESENT	0
137222	137200	14031R	PARTICIPANT	\N	PRESENT	0
137223	137200	08009T	PARTICIPANT	\N	PRESENT	0
137224	137200	08062Y	PARTICIPANT	\N	PRESENT	0
137225	137200	14221J	PARTICIPANT	\N	PRESENT	0
137226	137200	92039X	PARTICIPANT	\N	PRESENT	0
137227	137200	08042U	PARTICIPANT	\N	PRESENT	0
137228	137200	14169X	PARTICIPANT	\N	EXCUSE	0
137229	137200	14237S	PARTICIPANT	\N	PRESENT	0
137559	137532	14051J	PARTICIPANT	\N	PRESENT	0
137231	137200	05012A	PARTICIPANT	\N	EXCUSE	0
137232	137200	14247U	PARTICIPANT	\N	PRESENT	0
137233	137200	14135M	PARTICIPANT	\N	PRESENT	0
137234	137200	14331P	PARTICIPANT	\N	PRESENT	0
137235	137200	95062K	PARTICIPANT	\N	PRESENT	0
137236	137200	14107H	PARTICIPANT	\N	PRESENT	0
137237	137200	14051J	PARTICIPANT	\N	PRESENT	0
137238	137200	14157T	PARTICIPANT	\N	PRESENT	0
137706	137705	14327T	PARTICIPANT	\N	PRESENT	0
137709	137707	11054L	PARTICIPANT	\N	PRESENT	0
137713	137712	92018S	PARTICIPANT	\N	PRESENT	0
137720	137717	92018S	PARTICIPANT	\N	PRESENT	0
137724	137723	92018S	PARTICIPANT	\N	PRESENT	0
137836	135871	11010L	PARTICIPANT	\N	EXCUSE	0
137856	137855	01047U	PARTICIPANT	\N	PRESENT	0
137857	137855	14069U	PARTICIPANT	\N	PRESENT	0
164474	164472	04035D	PARTICIPANT	\N	PRESENT	0
164476	164475	04080J	PARTICIPANT	\N	PRESENT	0
164477	164475	04035D	PARTICIPANT	\N	PRESENT	0
164480	164478	04080J	PARTICIPANT	\N	PRESENT	0
164481	164478	04035D	PARTICIPANT	\N	PRESENT	0
164483	164482	11054L	PARTICIPANT	\N	PRESENT	0
164484	164482	04040A	PARTICIPANT	\N	PRESENT	0
164486	164485	14193X	PARTICIPANT	\N	PRESENT	0
164487	164485	11054L	PARTICIPANT	\N	PRESENT	0
164488	164485	04040A	PARTICIPANT	\N	PRESENT	0
164493	164492	95059Q	PARTICIPANT	\N	PRESENT	0
164494	164492	83042R	PARTICIPANT	\N	PRESENT	0
164495	164492	04040A	PARTICIPANT	\N	PRESENT	0
164496	164492	96004D	PARTICIPANT	\N	PRESENT	0
164533	164532	08069G	PARTICIPANT	\N	PRESENT	0
164536	164535	08014Q	PARTICIPANT	\N	PRESENT	0
164552	161240	14083S	PARTICIPANT	\N	PRESENT	0
164593	164592	96004D	PRESIDENT	0	PRESENT	0
164594	164592	14089Y	PARTICIPANT	\N	PRESENT	0
164595	164592	11083R	PARTICIPANT	\N	PRESENT	0
164596	164592	14073Q	PARTICIPANT	\N	PRESENT	0
164597	164592	04057K	PARTICIPANT	\N	PRESENT	0
164598	164592	01016M	PARTICIPANT	\N	PRESENT	0
164599	164592	04034C	PARTICIPANT	\N	PRESENT	0
164600	164592	95063L	PARTICIPANT	\N	PRESENT	0
164612	164592	04045F	PARTICIPANT	\N	EXCUSE	0
164613	164592	14133K	PARTICIPANT	\N	EXCUSE	0
164614	164592	90003B	PARTICIPANT	\N	EXCUSE	0
164615	164592	11035H	PARTICIPANT	\N	EXCUSE	0
164616	164592	08018U	PARTICIPANT	\N	EXCUSE	0
164617	164592	98046X	PARTICIPANT	\N	EXCUSE	0
164618	164592	08042U	PARTICIPANT	\N	EXCUSE	0
164632	163372	11035H	PARTICIPANT	\N	EXCUSE	0
164652	162265	11035H	PARTICIPANT	\N	EXCUSE	0
164653	164358	11035H	PARTICIPANT	\N	EXCUSE	0
164654	164358	90003B	PARTICIPANT	\N	EXCUSE	0
164655	164358	09001P	PARTICIPANT	\N	EXCUSE	0
164656	164358	05012A	PARTICIPANT	\N	EXCUSE	0
164657	164358	80013X	PARTICIPANT	\N	EXCUSE	0
164658	164358	01015L	PARTICIPANT	\N	EXCUSE	0
164672	164193	90003B	PARTICIPANT	\N	EXCUSE	0
164813	164812	14033T	PARTICIPANT	\N	PRESENT	0
164815	164814	14033T	PARTICIPANT	\N	PRESENT	0
164817	164816	14033T	PARTICIPANT	\N	PRESENT	0
164819	164818	08055A	PARTICIPANT	\N	PRESENT	0
164820	164818	08043V	PARTICIPANT	\N	PRESENT	0
164821	164818	14105F	PARTICIPANT	\N	PRESENT	0
164822	164818	14038Y	PARTICIPANT	\N	PRESENT	0
164823	164818	14187A	PARTICIPANT	\N	PRESENT	0
164824	164818	14014Q	PARTICIPANT	\N	PRESENT	0
164826	164818	95037J	PARTICIPANT	\N	PRESENT	0
164827	164825	01046T	PARTICIPANT	\N	PRESENT	0
164828	164818	08015R	PARTICIPANT	\N	PRESENT	0
164829	164818	14059S	PARTICIPANT	\N	PRESENT	0
164830	164818	14109K	PARTICIPANT	\N	PRESENT	0
164935	163372	14071N	PARTICIPANT	\N	PRESENT	0
164895	164893	11036J	PARTICIPANT	\N	PRESENT	0
164937	163372	11037K	PARTICIPANT	\N	EXCUSE	0
164897	164893	14013P	PARTICIPANT	\N	EXCUSE	0
164898	164893	08068F	PARTICIPANT	\N	PRESENT	0
165110	163372	04044E	PARTICIPANT	\N	EXCUSE	0
165144	165143	14219Q	PRESIDENT	0	PRESENT	0
164901	164893	90003B	PARTICIPANT	\N	PRESENT	0
164902	164893	08028W	PARTICIPANT	\N	PRESENT	0
164903	164893	80013X	PARTICIPANT	\N	PRESENT	0
164904	164893	14357A	PARTICIPANT	\N	PRESENT	0
165145	165143	11065P	PARTICIPANT	\N	PRESENT	0
165146	165143	90003B	PARTICIPANT	\N	PRESENT	0
165147	165143	05012A	PARTICIPANT	\N	PRESENT	0
165148	165143	01008M	PARTICIPANT	\N	PRESENT	0
164909	164893	14187A	PARTICIPANT	\N	PRESENT	0
165149	165143	92045V	PARTICIPANT	\N	PRESENT	0
165150	165143	14033T	PARTICIPANT	\N	EXCUSE	0
165219	164854	11077T	PARTICIPANT	\N	PRESENT	0
165220	164854	11067R	PARTICIPANT	\N	PRESENT	0
165221	163372	14231L	PARTICIPANT	\N	EXCUSE	0
165222	164854	01025N	PARTICIPANT	\N	PRESENT	0
164916	164893	08015R	PARTICIPANT	\N	PRESENT	0
164917	164893	11100Y	PRESIDENT	0	PRESENT	0
164918	164893	01061S	PARTICIPANT	\N	EXCUSE	0
164919	164893	11098Y	PARTICIPANT	\N	PRESENT	0
165223	164854	14037X	PARTICIPANT	\N	PRESENT	0
164925	164893	08021P	PARTICIPANT	\N	EXCUSE	0
164927	164893	98050T	PARTICIPANT	\N	PRESENT	0
165234	165233	11074Q	PARTICIPANT	\N	PRESENT	0
164930	164893	01058X	PARTICIPANT	\N	PRESENT	0
165235	165233	14041T	PARTICIPANT	\N	PRESENT	0
165236	165233	11083R	PARTICIPANT	\N	PRESENT	0
165237	165233	08015R	PARTICIPANT	\N	PRESENT	0
165239	165238	14239U	PARTICIPANT	\N	PRESENT	0
165240	165238	11055M	PARTICIPANT	\N	PRESENT	0
165265	165238	14235Q	PARTICIPANT	\N	EXCUSE	0
165272	164854	11112D	PARTICIPANT	\N	PRESENT	0
165273	164854	14173T	PARTICIPANT	\N	PRESENT	0
165245	165238	11031D	PARTICIPANT	\N	PRESENT	0
165274	164854	87003B	PARTICIPANT	\N	PRESENT	0
165247	165238	14041T	PARTICIPANT	\N	PRESENT	0
165248	165238	14217N	PARTICIPANT	\N	PRESENT	0
165249	165238	87003B	PARTICIPANT	\N	PRESENT	0
165275	164854	14215L	PARTICIPANT	\N	PRESENT	0
165251	165238	14213J	PRESIDENT	0	PRESENT	0
165276	164854	11082Q	PARTICIPANT	\N	PRESENT	0
165277	164854	95035G	PARTICIPANT	\N	PRESENT	0
165254	165238	14147R	PARTICIPANT	\N	PRESENT	0
165255	165238	14223L	PARTICIPANT	\N	PRESENT	0
165292	164854	14042U	PARTICIPANT	\N	PRESENT	0
165257	165238	14265W	PARTICIPANT	\N	PRESENT	0
165258	165238	14028W	PARTICIPANT	\N	EXCUSE	0
165374	164855	08024S	PARTICIPANT	\N	PRESENT	0
165260	165238	14331P	PARTICIPANT	\N	PRESENT	0
165375	164855	11049P	PARTICIPANT	\N	PRESENT	0
165262	165238	11097X	PARTICIPANT	\N	PRESENT	0
165376	164855	08047A	PARTICIPANT	\N	PRESENT	0
165264	165238	11094U	PARTICIPANT	\N	PRESENT	0
165377	164855	04085P	PARTICIPANT	\N	PRESENT	0
165378	164855	11056N	PARTICIPANT	\N	PRESENT	0
165379	164855	01028R	PARTICIPANT	\N	PRESENT	0
165380	164855	98022P	PARTICIPANT	\N	PRESENT	0
165381	164855	14042U	PARTICIPANT	\N	PRESENT	0
165382	164855	95063L	PARTICIPANT	\N	PRESENT	0
165383	164855	11033F	PARTICIPANT	\N	PRESENT	0
165384	164855	14065Q	PARTICIPANT	\N	PRESENT	0
165385	164855	05008E	PARTICIPANT	\N	PRESENT	0
165386	164855	08009T	PARTICIPANT	\N	PRESENT	0
165387	164855	14239U	PARTICIPANT	\N	PRESENT	0
165388	164855	14241N	PARTICIPANT	\N	PRESENT	0
165389	164855	14073Q	PARTICIPANT	\N	PRESENT	0
165390	164855	14231L	PARTICIPANT	\N	PRESENT	0
165391	164855	14083S	PARTICIPANT	\N	PRESENT	0
165392	164855	14215L	PARTICIPANT	\N	PRESENT	0
165393	164855	14087W	PARTICIPANT	\N	PRESENT	0
165394	164855	95035G	PARTICIPANT	\N	PRESENT	0
165395	164855	14247U	PARTICIPANT	\N	PRESENT	0
165396	164855	14069U	PARTICIPANT	\N	PRESENT	0
165397	164855	14199E	PARTICIPANT	\N	PRESENT	0
165398	164855	14217N	PARTICIPANT	\N	PRESENT	0
165399	164855	14223L	PARTICIPANT	\N	PRESENT	0
165400	164855	14105F	PARTICIPANT	\N	PRESENT	0
165401	164855	04047H	PARTICIPANT	\N	PRESENT	0
165402	164855	14119M	PARTICIPANT	\N	PRESENT	0
165403	164855	95062K	PARTICIPANT	\N	PRESENT	0
165404	164855	14211G	PARTICIPANT	\N	PRESENT	0
165405	164855	01025N	PARTICIPANT	\N	PRESENT	0
165406	164855	04044E	PARTICIPANT	\N	PRESENT	0
165407	164855	14030Q	PARTICIPANT	\N	PRESENT	0
165432	164855	01024M	PARTICIPANT	\N	PRESENT	0
165410	165408	11031D	PARTICIPANT	\N	PRESENT	0
165411	165408	10006L	PARTICIPANT	\N	PRESENT	0
165433	164855	11063M	PARTICIPANT	\N	PRESENT	0
165434	164855	14147R	PARTICIPANT	\N	PRESENT	0
165414	165408	14231L	PARTICIPANT	\N	PRESENT	0
165435	164855	11097X	PARTICIPANT	\N	PRESENT	0
165416	165408	14026U	PARTICIPANT	\N	PRESENT	0
165417	165408	14213J	PARTICIPANT	\N	PRESENT	0
165418	165408	95049N	PARTICIPANT	\N	PRESENT	0
165419	165408	04092N	PARTICIPANT	\N	PRESENT	0
165420	165408	14271U	PARTICIPANT	\N	PRESENT	0
165436	164855	11100Y	PARTICIPANT	\N	PRESENT	0
165422	165408	04045F	PARTICIPANT	\N	PRESENT	0
165437	164855	08010L	PARTICIPANT	\N	PRESENT	0
130207	130206	14031R	PARTICIPANT	\N	PRESENT	0
129793	129791	11055M	PARTICIPANT	\N	PRESENT	0
130208	130206	92039X	PARTICIPANT	\N	PRESENT	0
129795	129791	04053F	PARTICIPANT	\N	PRESENT	0
129796	129791	14255U	PARTICIPANT	\N	PRESENT	0
129797	129791	04066L	PARTICIPANT	\N	PRESENT	0
129798	129791	00003C	PARTICIPANT	\N	EXCUSE	0
130209	130206	14073Q	PARTICIPANT	\N	PRESENT	0
129800	129791	11103C	PARTICIPANT	\N	PRESENT	0
129801	129791	11044J	PARTICIPANT	\N	PRESENT	0
129802	129791	14195A	PARTICIPANT	\N	PRESENT	0
130210	130206	01015L	PARTICIPANT	\N	PRESENT	0
129804	129791	11023D	PARTICIPANT	\N	EXCUSE	0
129805	129791	11031D	PARTICIPANT	\N	PRESENT	0
129806	129791	08052W	PARTICIPANT	\N	PRESENT	0
129807	129791	01059Y	PARTICIPANT	\N	PRESENT	0
129808	129791	04081K	PARTICIPANT	\N	PRESENT	0
129809	129791	98024R	PARTICIPANT	\N	PRESENT	0
130211	130206	14030Q	PARTICIPANT	\N	PRESENT	0
129811	129791	04067M	PARTICIPANT	\N	PRESENT	0
130213	130212	08055A	PARTICIPANT	\N	PRESENT	0
129813	129791	14042U	PARTICIPANT	\N	PRESENT	0
129814	129791	14151M	PARTICIPANT	\N	PRESENT	0
129815	129791	12042Y	PARTICIPANT	\N	PRESENT	0
129816	129791	14281W	PARTICIPANT	\N	PRESENT	0
130214	130212	90003B	PARTICIPANT	\N	PRESENT	0
130215	130212	14195A	PARTICIPANT	\N	PRESENT	0
129819	129791	14034U	PARTICIPANT	\N	PRESENT	0
129820	129791	14231L	PARTICIPANT	\N	EXCUSE	0
129821	129791	11061K	PARTICIPANT	\N	PRESENT	0
129822	129791	08048B	PARTICIPANT	\N	PRESENT	0
130216	130212	14197C	PARTICIPANT	\N	PRESENT	0
130217	130212	12042Y	PARTICIPANT	\N	PRESENT	0
129825	129791	14026U	PARTICIPANT	\N	PRESENT	0
129826	129791	14213J	PARTICIPANT	\N	PRESENT	0
129827	129791	14121F	PARTICIPANT	\N	PRESENT	0
129828	129791	11112D	PARTICIPANT	\N	PRESENT	0
130218	130212	01061S	PARTICIPANT	\N	PRESENT	0
130219	130212	14205J	PARTICIPANT	\N	PRESENT	0
130220	130212	04088S	PARTICIPANT	\N	PRESENT	0
130221	130212	11097X	PARTICIPANT	\N	PRESENT	0
129833	129791	04092N	PRESIDENT	0	PRESENT	0
130223	130222	14033T	PARTICIPANT	\N	PRESENT	0
130228	130227	95062K	PARTICIPANT	\N	PRESENT	0
129836	129791	14071N	PARTICIPANT	\N	EXCUSE	0
131932	131931	11053K	PARTICIPANT	\N	PRESENT	0
129838	129791	04043D	PARTICIPANT	\N	PRESENT	0
129839	129791	14271U	PARTICIPANT	\N	PRESENT	0
131938	131937	04071H	PARTICIPANT	\N	PRESENT	0
129841	129791	11093T	PARTICIPANT	\N	PRESENT	0
129842	129791	11097X	PARTICIPANT	\N	PRESENT	0
129843	129791	04045F	PARTICIPANT	\N	PRESENT	0
129844	129791	14227Q	PARTICIPANT	\N	PRESENT	0
129845	129791	01034P	PARTICIPANT	\N	PRESENT	0
129846	129791	11025F	PARTICIPANT	\N	PRESENT	0
129847	129791	11063M	PARTICIPANT	\N	PRESENT	0
129848	129791	14269B	PARTICIPANT	\N	PRESENT	0
131940	131939	11057P	PARTICIPANT	\N	PRESENT	0
135648	135613	14169X	PARTICIPANT	\N	EXCUSE	0
137813	137812	11033F	PARTICIPANT	\N	PRESENT	0
138378	137838	14249W	PARTICIPANT	\N	PRESENT	0
138379	137838	95059Q	PARTICIPANT	\N	PRESENT	0
138380	137838	11014C	PARTICIPANT	\N	PRESENT	0
138381	137838	08043V	PARTICIPANT	\N	PRESENT	0
138382	137838	14169X	PARTICIPANT	\N	PRESENT	0
138383	137838	14199E	PARTICIPANT	\N	PRESENT	0
138401	137838	04035D	PARTICIPANT	\N	PRESENT	0
138385	137838	11100Y	PARTICIPANT	\N	PRESENT	0
138386	137838	08048B	PARTICIPANT	\N	PRESENT	0
138402	137838	90003B	PARTICIPANT	\N	PRESENT	0
138388	137838	14073Q	PARTICIPANT	\N	PRESENT	0
138393	137838	14209N	PARTICIPANT	\N	PRESENT	0
138394	137838	08058D	PARTICIPANT	\N	PRESENT	0
138395	137838	11114F	PARTICIPANT	\N	PRESENT	0
138396	137838	08024S	PARTICIPANT	\N	PRESENT	0
138397	137838	14014Q	PARTICIPANT	\N	PRESENT	0
138398	137838	92020L	PARTICIPANT	\N	PRESENT	0
138399	137838	08055A	PARTICIPANT	\N	PRESENT	0
138400	137838	01008M	PARTICIPANT	\N	PRESENT	0
138432	137839	08055A	PARTICIPANT	\N	PRESENT	0
138433	137839	08052W	PARTICIPANT	\N	PRESENT	0
138434	137839	01034P	PARTICIPANT	\N	PRESENT	0
138435	137839	11063M	PARTICIPANT	\N	PRESENT	0
138436	137839	08019V	PARTICIPANT	\N	PRESENT	0
138437	137839	14195A	PARTICIPANT	\N	PRESENT	0
138438	137839	11055M	PARTICIPANT	\N	PRESENT	0
138439	137839	14071N	PARTICIPANT	\N	PRESENT	0
138440	137839	14223L	PARTICIPANT	\N	PRESENT	0
138441	137839	04092N	PARTICIPANT	\N	PRESENT	0
138442	137839	14026U	PARTICIPANT	\N	PRESENT	0
138443	137839	14265W	PARTICIPANT	\N	PRESENT	0
138444	137839	04067M	PARTICIPANT	\N	PRESENT	0
138445	137839	11103C	PARTICIPANT	\N	PRESENT	0
138446	137839	14038Y	PARTICIPANT	\N	PRESENT	0
138447	137839	11031D	PARTICIPANT	\N	PRESENT	0
138448	137839	98024R	PARTICIPANT	\N	PRESENT	0
138449	137839	11097X	PARTICIPANT	\N	PRESENT	0
138450	137839	01059Y	PARTICIPANT	\N	PRESENT	0
138451	137839	14235Q	PARTICIPANT	\N	PRESENT	0
138452	137839	11093T	PARTICIPANT	\N	PRESENT	0
138453	137839	14217N	PARTICIPANT	\N	PRESENT	0
138454	137839	14014Q	PARTICIPANT	\N	PRESENT	0
138455	137839	14121F	PARTICIPANT	\N	PRESENT	0
138456	137839	95030B	PARTICIPANT	\N	PRESENT	0
138457	137839	11109J	PARTICIPANT	\N	PRESENT	0
138458	137839	14135M	PARTICIPANT	\N	PRESENT	0
138459	137839	04053F	PARTICIPANT	\N	PRESENT	0
138460	137839	04088S	PARTICIPANT	\N	PRESENT	0
138461	137839	95049N	PARTICIPANT	\N	PRESENT	0
138462	137839	14197C	PARTICIPANT	\N	PRESENT	0
138463	137839	14219Q	PARTICIPANT	\N	PRESENT	0
138464	137839	14221J	PARTICIPANT	\N	PRESENT	0
138465	137839	04045F	PARTICIPANT	\N	PRESENT	0
138466	137839	14257W	PARTICIPANT	\N	PRESENT	0
138467	137839	11036J	PARTICIPANT	\N	PRESENT	0
138468	137839	01008M	PARTICIPANT	\N	PRESENT	0
138469	137839	14053L	PARTICIPANT	\N	PRESENT	0
138470	137839	01046T	PARTICIPANT	\N	PRESENT	0
138471	137839	14231L	PARTICIPANT	\N	PRESENT	0
138472	137839	11023D	PARTICIPANT	\N	PRESENT	0
138473	137839	12042Y	PARTICIPANT	\N	PRESENT	0
138474	137839	11042G	PARTICIPANT	\N	PRESENT	0
138475	137839	14213J	PARTICIPANT	\N	PRESENT	0
138476	137839	10006L	PARTICIPANT	\N	PRESENT	0
138477	137839	80013X	PARTICIPANT	\N	PRESENT	0
138478	137839	08016S	PARTICIPANT	\N	PRESENT	0
138479	137839	14255U	PARTICIPANT	\N	PRESENT	0
138480	137839	14267Y	PARTICIPANT	\N	PRESENT	0
138481	137839	14281W	PARTICIPANT	\N	PRESENT	0
138482	137839	11113E	PARTICIPANT	\N	PRESENT	0
138483	137839	14061L	PARTICIPANT	\N	PRESENT	0
138484	137839	14271U	PARTICIPANT	\N	PRESENT	0
138485	137839	14059S	PARTICIPANT	\N	PRESENT	0
138486	137839	11061K	PARTICIPANT	\N	PRESENT	0
138487	137839	92045V	PARTICIPANT	\N	PRESENT	0
138488	137839	07029T	PARTICIPANT	\N	PRESENT	0
138489	137839	14147R	PARTICIPANT	\N	PRESENT	0
138490	137839	14042U	PARTICIPANT	\N	PRESENT	0
138491	137839	14034U	PARTICIPANT	\N	PRESENT	0
138503	137839	14151M	PARTICIPANT	\N	PRESENT	0
138529	137839	11112D	PARTICIPANT	\N	PRESENT	0
138530	137839	14119M	PARTICIPANT	\N	PRESENT	0
138531	137839	14089Y	PARTICIPANT	\N	PRESENT	0
138532	137839	14179A	PARTICIPANT	\N	PRESENT	0
138533	137839	04033B	PARTICIPANT	\N	PRESENT	0
138534	137839	14083S	PARTICIPANT	\N	PRESENT	0
138535	137839	08015R	PARTICIPANT	\N	PRESENT	0
138553	138552	14133K	PARTICIPANT	\N	PRESENT	0
138554	138552	08043V	PARTICIPANT	\N	PRESENT	0
138555	138552	08024S	PARTICIPANT	\N	PRESENT	0
138556	138552	10006L	PARTICIPANT	\N	PRESENT	0
138557	138552	01037S	PARTICIPANT	\N	PRESENT	0
138558	138552	14265W	PARTICIPANT	\N	PRESENT	0
138660	138659	01007L	PARTICIPANT	\N	PRESENT	0
138662	138661	04085P	PARTICIPANT	\N	EXCUSE	0
138663	138661	05008E	PRESIDENT	0	PRESENT	0
138664	138661	14065Q	PARTICIPANT	\N	PRESENT	0
138665	138661	04038G	PARTICIPANT	\N	PRESENT	0
138666	138661	11056N	PARTICIPANT	\N	PRESENT	0
138667	138661	11113E	PARTICIPANT	\N	PRESENT	0
138668	138661	01024M	PARTICIPANT	\N	EXCUSE	0
138669	138661	14215L	PARTICIPANT	\N	PRESENT	0
138670	138661	08044W	PARTICIPANT	\N	EXCUSE	0
138671	138661	11026G	PARTICIPANT	\N	PRESENT	0
138672	138661	14111D	PARTICIPANT	\N	PRESENT	0
138673	138661	01028R	PARTICIPANT	\N	PRESENT	0
138674	138661	04044E	PARTICIPANT	\N	PRESENT	0
138675	138661	11037K	PARTICIPANT	\N	PRESENT	0
138676	138661	92045V	PARTICIPANT	\N	EXCUSE	0
156736	156712	11097X	PARTICIPANT	\N	PRESENT	0
156737	156712	04045F	PARTICIPANT	\N	EXCUSE	0
156738	156712	11094U	PARTICIPANT	\N	EXCUSE	0
156826	156825	09001P	PRESIDENT	0	PRESENT	0
156827	156825	11065P	PARTICIPANT	\N	PRESENT	0
156828	156825	11090Q	PARTICIPANT	\N	PRESENT	0
156829	156825	01015L	PARTICIPANT	\N	PRESENT	0
156830	156825	01008M	PARTICIPANT	\N	PRESENT	0
156831	156825	01056V	PARTICIPANT	\N	PRESENT	0
156832	156825	14093U	PARTICIPANT	\N	PRESENT	0
156833	156825	14033T	PARTICIPANT	\N	PRESENT	0
156858	156825	08049C	PARTICIPANT	\N	EXCUSE	0
156859	156825	80013X	PARTICIPANT	\N	EXCUSE	0
156860	156825	92045V	PARTICIPANT	\N	EXCUSE	0
157294	157293	14259Y	PARTICIPANT	\N	PRESENT	0
157295	157293	14187A	PARTICIPANT	\N	PRESENT	0
157296	157293	14087W	PARTICIPANT	\N	PRESENT	0
157297	157293	97011G	PARTICIPANT	\N	PRESENT	0
157298	157293	01037S	PARTICIPANT	\N	PRESENT	0
157299	157293	14014Q	PARTICIPANT	\N	PRESENT	0
157300	157293	11084S	PARTICIPANT	\N	PRESENT	0
157313	157312	11084S	PARTICIPANT	\N	PRESENT	0
157314	157312	14259Y	PARTICIPANT	\N	PRESENT	0
157315	157312	04036E	PARTICIPANT	\N	PRESENT	0
157316	157312	11026G	PARTICIPANT	\N	PRESENT	0
157317	157312	01019Q	PARTICIPANT	\N	PRESENT	0
157318	157312	14239U	PARTICIPANT	\N	PRESENT	0
157512	157432	98005N	PARTICIPANT	\N	EXCUSE	0
157533	157532	04074L	PARTICIPANT	\N	PRESENT	0
157534	157532	11037K	PARTICIPANT	\N	PRESENT	0
157633	155100	14157T	PARTICIPANT	\N	PRESENT	0
157592	157272	14327T	PARTICIPANT	\N	EXCUSE	0
157632	155100	89029V	PARTICIPANT	\N	PRESENT	0
157634	155100	14041T	PARTICIPANT	\N	PRESENT	0
157635	155100	05008E	PARTICIPANT	\N	PRESENT	0
157636	155100	95049N	PARTICIPANT	\N	PRESENT	0
157637	155100	95063L	PARTICIPANT	\N	PRESENT	0
157638	155100	14107H	PARTICIPANT	\N	PRESENT	0
157639	155100	11054L	PARTICIPANT	\N	PRESENT	0
157640	155100	01028R	PARTICIPANT	\N	PRESENT	0
157641	155100	01003G	PARTICIPANT	\N	PRESENT	0
157642	155100	07029T	PARTICIPANT	\N	PRESENT	0
157643	155100	10015M	PARTICIPANT	\N	PRESENT	0
157644	155100	04061F	PARTICIPANT	\N	PRESENT	0
157645	155100	14030Q	PARTICIPANT	\N	PRESENT	0
157646	155100	87003B	PARTICIPANT	\N	PRESENT	0
157650	155100	08016S	PARTICIPANT	\N	PRESENT	0
157659	155100	08015R	PARTICIPANT	\N	PRESENT	0
157649	155100	14221J	PARTICIPANT	\N	PRESENT	0
157651	155100	14159V	PARTICIPANT	\N	PRESENT	0
157652	155100	14215L	PARTICIPANT	\N	PRESENT	0
157653	155100	07034Q	PARTICIPANT	\N	PRESENT	0
157654	155100	11056N	PARTICIPANT	\N	PRESENT	0
157655	155100	01007L	PARTICIPANT	\N	PRESENT	0
157656	155100	11081P	PARTICIPANT	\N	PRESENT	0
157657	155100	14363X	PARTICIPANT	\N	PRESENT	0
157658	155100	01024M	PARTICIPANT	\N	PRESENT	0
157660	155100	14133K	PARTICIPANT	\N	PRESENT	0
157661	155100	14038Y	PARTICIPANT	\N	PRESENT	0
157662	155100	11033F	PARTICIPANT	\N	PRESENT	0
157663	155100	08060W	PARTICIPANT	\N	PRESENT	0
157664	155100	11084S	PARTICIPANT	\N	PRESENT	0
157665	155100	14237S	PARTICIPANT	\N	PRESENT	0
157666	155100	08051V	PARTICIPANT	\N	PRESENT	0
157672	155100	04041B	PARTICIPANT	\N	PRESENT	0
157673	155100	11064N	PARTICIPANT	\N	PRESENT	0
157675	155100	13002U	PARTICIPANT	\N	PRESENT	0
157676	155100	14059S	PARTICIPANT	\N	PRESENT	0
157733	155100	14105F	PARTICIPANT	\N	PRESENT	0
157734	155100	11043H	PARTICIPANT	\N	PRESENT	0
157735	155100	14103D	PARTICIPANT	\N	PRESENT	0
157736	155100	97011G	PARTICIPANT	\N	PRESENT	0
157737	155100	11104D	PARTICIPANT	\N	PRESENT	0
157738	155100	11011M	PARTICIPANT	\N	PRESENT	0
157739	155100	14089Y	PARTICIPANT	\N	PRESENT	0
157743	155100	08022Q	PARTICIPANT	\N	PRESENT	0
157745	155100	14195A	PARTICIPANT	\N	PRESENT	0
157746	155100	01008M	PARTICIPANT	\N	PRESENT	0
157747	155100	04088S	PARTICIPANT	\N	PRESENT	0
157748	155100	14201E	PARTICIPANT	\N	PRESENT	0
157749	155100	11097X	PARTICIPANT	\N	PRESENT	0
157750	155100	14263U	PARTICIPANT	\N	PRESENT	0
157751	155100	14173T	PARTICIPANT	\N	PRESENT	0
157752	155100	07004J	PARTICIPANT	\N	PRESENT	0
157753	155100	14223L	PARTICIPANT	\N	PRESENT	0
157754	155100	14265W	PARTICIPANT	\N	PRESENT	0
157755	155100	14097Y	PARTICIPANT	\N	PRESENT	0
157756	155100	80013X	PARTICIPANT	\N	PRESENT	0
157772	155100	14119M	PARTICIPANT	\N	PRESENT	0
157773	155100	14033T	PARTICIPANT	\N	PRESENT	0
157774	155100	14001X	PARTICIPANT	\N	PRESENT	0
157775	155101	89029V	PARTICIPANT	\N	PRESENT	0
157776	155101	14041T	PARTICIPANT	\N	PRESENT	0
157777	155101	05008E	PARTICIPANT	\N	PRESENT	0
157778	155101	95049N	PARTICIPANT	\N	PRESENT	0
157779	155101	01028R	PARTICIPANT	\N	PRESENT	0
157780	155101	10015M	PARTICIPANT	\N	PRESENT	0
157781	155101	14215L	PARTICIPANT	\N	PRESENT	0
157782	155101	11056N	PARTICIPANT	\N	PRESENT	0
157785	155101	01024M	PARTICIPANT	\N	PRESENT	0
157788	155101	08051V	PARTICIPANT	\N	PRESENT	0
157789	155101	04041B	PARTICIPANT	\N	PRESENT	0
157791	155101	14059S	PARTICIPANT	\N	PRESENT	0
157792	155101	14105F	PARTICIPANT	\N	PRESENT	0
157794	155101	14103D	PARTICIPANT	\N	PRESENT	0
157795	155101	97011G	PARTICIPANT	\N	PRESENT	0
157796	155101	11104D	PARTICIPANT	\N	PRESENT	0
157797	155101	11011M	PARTICIPANT	\N	PRESENT	0
157798	155101	14089Y	PARTICIPANT	\N	PRESENT	0
157799	155101	08022Q	PARTICIPANT	\N	PRESENT	0
157800	155101	14195A	PARTICIPANT	\N	PRESENT	0
157801	155101	01008M	PARTICIPANT	\N	PRESENT	0
157802	155101	04088S	PARTICIPANT	\N	PRESENT	0
157803	155101	14201E	PARTICIPANT	\N	PRESENT	0
157804	155101	11097X	PARTICIPANT	\N	PRESENT	0
157805	155101	14263U	PARTICIPANT	\N	PRESENT	0
157806	155101	14173T	PARTICIPANT	\N	PRESENT	0
157807	155101	07004J	PARTICIPANT	\N	PRESENT	0
157808	155101	14223L	PARTICIPANT	\N	PRESENT	0
157809	155101	14265W	PARTICIPANT	\N	PRESENT	0
157810	155101	14097Y	PARTICIPANT	\N	PRESENT	0
157811	155101	80013X	PARTICIPANT	\N	PRESENT	0
157812	155101	14119M	PARTICIPANT	\N	PRESENT	0
157813	155101	14033T	PARTICIPANT	\N	PRESENT	0
157814	155101	14001X	PARTICIPANT	\N	PRESENT	0
157816	155101	11112D	PARTICIPANT	\N	PRESENT	0
157817	155101	11067R	PARTICIPANT	\N	PRESENT	0
138345	127239	11088W	PARTICIPANT	\N	EXCUSE	0
138346	127239	04055H	PARTICIPANT	\N	EXCUSE	0
138347	127239	14041T	PARTICIPANT	\N	EXCUSE	0
138348	127239	04071H	PARTICIPANT	\N	EXCUSE	0
138349	127239	14151M	PARTICIPANT	\N	EXCUSE	0
138350	127239	95041E	PARTICIPANT	\N	EXCUSE	0
138351	127239	14061L	PARTICIPANT	\N	EXCUSE	0
138352	127239	14205J	PARTICIPANT	\N	EXCUSE	0
138353	127239	14018U	PARTICIPANT	\N	EXCUSE	0
138357	127239	14034U	PARTICIPANT	\N	EXCUSE	0
138359	127239	10015M	PARTICIPANT	\N	EXCUSE	0
138361	138360	04059M	PARTICIPANT	\N	PRESENT	0
138493	138492	01046T	PARTICIPANT	\N	PRESENT	0
138494	138492	04066L	PARTICIPANT	\N	PRESENT	0
138495	138492	00003C	PARTICIPANT	\N	EXCUSE	0
138496	138492	11103C	PARTICIPANT	\N	PRESENT	0
138497	138492	14195A	PARTICIPANT	\N	PRESENT	0
138498	138492	11023D	PARTICIPANT	\N	PRESENT	0
138499	138492	11031D	PARTICIPANT	\N	PRESENT	0
138500	138492	08052W	PARTICIPANT	\N	PRESENT	0
138501	138492	01059Y	PARTICIPANT	\N	PRESENT	0
138502	138492	98024R	PARTICIPANT	\N	PRESENT	0
138504	138492	10006L	PARTICIPANT	\N	PRESENT	0
138505	138492	14217N	PARTICIPANT	\N	PRESENT	0
138506	138492	14042U	PARTICIPANT	\N	PRESENT	0
138507	138492	12042Y	PARTICIPANT	\N	PRESENT	0
138508	138492	14281W	PARTICIPANT	\N	PRESENT	0
138509	138492	14087W	PARTICIPANT	\N	PRESENT	0
138510	138492	14034U	PARTICIPANT	\N	PRESENT	0
138511	138492	11061K	PARTICIPANT	\N	PRESENT	0
138512	138492	08048B	PARTICIPANT	\N	PRESENT	0
138513	138492	14026U	PARTICIPANT	\N	PRESENT	0
138514	138492	14213J	PARTICIPANT	\N	PRESENT	0
138515	138492	11112D	PARTICIPANT	\N	PRESENT	0
138516	138492	11067R	PARTICIPANT	\N	EXCUSE	0
138517	138492	14223L	PARTICIPANT	\N	PRESENT	0
138518	138492	04092N	PRESIDENT	0	PRESENT	0
138519	138492	14265W	PARTICIPANT	\N	PRESENT	0
138520	138492	14119M	PARTICIPANT	\N	PRESENT	0
138521	138492	14071N	PARTICIPANT	\N	PRESENT	0
138522	138492	14271U	PARTICIPANT	\N	PRESENT	0
138523	138492	11093T	PARTICIPANT	\N	PRESENT	0
138524	138492	11097X	PARTICIPANT	\N	PRESENT	0
138525	138492	04045F	PARTICIPANT	\N	PRESENT	0
138526	138492	14227Q	PARTICIPANT	\N	PRESENT	0
138527	138492	01034P	PARTICIPANT	\N	PRESENT	0
138528	138492	14269B	PARTICIPANT	\N	PRESENT	0
139634	138874	08055A	PARTICIPANT	\N	PRESENT	0
139635	138874	07026Q	PARTICIPANT	\N	PRESENT	0
139636	138874	11054L	PARTICIPANT	\N	PRESENT	0
139637	138874	80027E	PARTICIPANT	\N	PRESENT	0
139638	138874	11057P	PARTICIPANT	\N	PRESENT	0
139639	138874	11059R	PARTICIPANT	\N	PRESENT	0
139640	138874	14001X	PARTICIPANT	\N	PRESENT	0
139641	138874	14207L	PARTICIPANT	\N	PRESENT	0
139642	138874	11014C	PARTICIPANT	\N	PRESENT	0
139643	138874	92020L	PARTICIPANT	\N	PRESENT	0
139644	138874	08014Q	PARTICIPANT	\N	PRESENT	0
139645	138874	11105E	PARTICIPANT	\N	PRESENT	0
139646	138874	08017T	PARTICIPANT	\N	PRESENT	0
139647	138874	95063L	PARTICIPANT	\N	PRESENT	0
139648	138874	11112D	PARTICIPANT	\N	PRESENT	0
139649	138874	05008E	PARTICIPANT	\N	PRESENT	0
139650	138874	04059M	PARTICIPANT	\N	PRESENT	0
139651	138874	11066Q	PARTICIPANT	\N	PRESENT	0
139652	138874	14081Q	PARTICIPANT	\N	PRESENT	0
139653	138874	12042Y	PARTICIPANT	\N	PRESENT	0
139654	138874	08016S	PARTICIPANT	\N	PRESENT	0
139655	138874	14197C	PARTICIPANT	\N	PRESENT	0
139656	138874	01016M	PARTICIPANT	\N	PRESENT	0
139657	138874	13002U	PARTICIPANT	\N	PRESENT	0
139658	138874	14159V	PARTICIPANT	\N	PRESENT	0
139659	138874	01037S	PARTICIPANT	\N	PRESENT	0
139660	138874	11037K	PARTICIPANT	\N	PRESENT	0
139661	138874	08043V	PARTICIPANT	\N	PRESENT	0
139662	138874	14263U	PARTICIPANT	\N	PRESENT	0
139663	138874	01015L	PARTICIPANT	\N	PRESENT	0
139664	138874	14201E	PARTICIPANT	\N	PRESENT	0
139665	138874	14097Y	PARTICIPANT	\N	PRESENT	0
139666	138874	08058D	PARTICIPANT	\N	PRESENT	0
139667	138874	08031R	PARTICIPANT	\N	PRESENT	0
139668	138874	04038G	PARTICIPANT	\N	PRESENT	0
139669	138874	04085P	PARTICIPANT	\N	PRESENT	0
139670	138874	14179A	PARTICIPANT	\N	PRESENT	0
139671	138874	14103D	PARTICIPANT	\N	PRESENT	0
139672	138874	14030Q	PARTICIPANT	\N	PRESENT	0
139550	138872	08055A	PARTICIPANT	\N	PRESENT	0
139551	138872	04092N	PARTICIPANT	\N	PRESENT	0
139552	138872	01034P	PARTICIPANT	\N	PRESENT	0
139553	138872	11061K	PARTICIPANT	\N	PRESENT	0
139554	138872	08052W	PARTICIPANT	\N	PRESENT	0
139555	138872	14281W	PARTICIPANT	\N	PRESENT	0
139556	138872	08016S	PARTICIPANT	\N	PRESENT	0
139557	138872	11089X	PARTICIPANT	\N	PRESENT	0
139558	138872	80013X	PARTICIPANT	\N	PRESENT	0
139559	138872	14107H	PARTICIPANT	\N	PRESENT	0
139560	138872	14014Q	PARTICIPANT	\N	PRESENT	0
139561	138872	14097Y	PARTICIPANT	\N	PRESENT	0
139562	138872	14227Q	PARTICIPANT	\N	PRESENT	0
139563	138872	08058D	PARTICIPANT	\N	PRESENT	0
139564	138872	11036J	PARTICIPANT	\N	PRESENT	0
139565	138872	01059Y	PARTICIPANT	\N	PRESENT	0
139566	138872	11031D	PARTICIPANT	\N	PRESENT	0
139567	138872	11063M	PARTICIPANT	\N	PRESENT	0
139568	138872	14271U	PARTICIPANT	\N	PRESENT	0
139569	138872	14269B	PARTICIPANT	\N	PRESENT	0
139570	138872	14121F	PARTICIPANT	\N	PRESENT	0
139571	138872	14081Q	PARTICIPANT	\N	PRESENT	0
139572	138872	08017T	PARTICIPANT	\N	PRESENT	0
139573	138872	14063N	PARTICIPANT	\N	PRESENT	0
139574	138872	13002U	PARTICIPANT	\N	PRESENT	0
139575	138872	14039A	PARTICIPANT	\N	PRESENT	0
139576	138872	11105E	PARTICIPANT	\N	PRESENT	0
139577	138872	04045F	PARTICIPANT	\N	PRESENT	0
139578	138872	12042Y	PARTICIPANT	\N	PRESENT	0
139579	138872	01037S	PARTICIPANT	\N	PRESENT	0
139580	138872	08043V	PARTICIPANT	\N	PRESENT	0
139581	138872	11029K	PARTICIPANT	\N	PRESENT	0
139582	138872	14030Q	PARTICIPANT	\N	PRESENT	0
139583	138872	14219Q	PARTICIPANT	\N	PRESENT	0
139584	138872	14089Y	PARTICIPANT	\N	PRESENT	0
139585	138872	11082Q	PARTICIPANT	\N	PRESENT	0
139586	138872	14231L	PARTICIPANT	\N	PRESENT	0
139587	138872	14073Q	PARTICIPANT	\N	PRESENT	0
139588	138872	01025N	PARTICIPANT	\N	PRESENT	0
139589	138872	14079W	PARTICIPANT	\N	PRESENT	0
139590	138872	14237S	PARTICIPANT	\N	PRESENT	0
139591	138872	11112D	PARTICIPANT	\N	PRESENT	0
139592	138872	14109K	PARTICIPANT	\N	PRESENT	0
139593	138872	04053F	PARTICIPANT	\N	PRESENT	0
139594	138872	14191V	PARTICIPANT	\N	PRESENT	0
139595	138872	14199E	PARTICIPANT	\N	PRESENT	0
139596	138872	14038Y	PARTICIPANT	\N	PRESENT	0
139597	138872	14105F	PARTICIPANT	\N	PRESENT	0
139598	138872	14041T	PARTICIPANT	\N	PRESENT	0
139599	138872	14195A	PARTICIPANT	\N	PRESENT	0
139600	138872	14119M	PARTICIPANT	\N	PRESENT	0
139601	138872	14213J	PARTICIPANT	\N	PRESENT	0
139602	138872	08048B	PARTICIPANT	\N	PRESENT	0
139603	138872	11103C	PARTICIPANT	\N	PRESENT	0
139604	138872	14061L	PARTICIPANT	\N	PRESENT	0
139605	138872	14053L	PARTICIPANT	\N	PRESENT	0
139606	138872	14217N	PARTICIPANT	\N	PRESENT	0
139607	138872	97011G	PARTICIPANT	\N	PRESENT	0
139608	138872	04043D	PARTICIPANT	\N	PRESENT	0
139609	138872	14175V	PARTICIPANT	\N	PRESENT	0
139610	138872	14111D	PARTICIPANT	\N	PRESENT	0
139611	138872	11091R	PARTICIPANT	\N	PRESENT	0
139612	138872	08018U	PARTICIPANT	\N	PRESENT	0
139613	138872	14069U	PARTICIPANT	\N	PRESENT	0
139614	138872	14071N	PARTICIPANT	\N	PRESENT	0
139615	138872	01046T	PARTICIPANT	\N	PRESENT	0
139616	138872	14018U	PARTICIPANT	\N	PRESENT	0
139617	138872	14201E	PARTICIPANT	\N	PRESENT	0
139618	138872	08024S	PARTICIPANT	\N	PRESENT	0
139619	138872	11053K	PARTICIPANT	\N	PRESENT	0
139620	138872	88008L	PARTICIPANT	\N	PRESENT	0
139621	138872	14223L	PARTICIPANT	\N	PRESENT	0
139622	138872	10006L	PARTICIPANT	\N	PRESENT	0
139623	138872	14042U	PARTICIPANT	\N	PRESENT	0
139624	138872	92020L	PARTICIPANT	\N	PRESENT	0
139625	138872	11042G	PARTICIPANT	\N	PRESENT	0
139626	138872	07026Q	PARTICIPANT	\N	PRESENT	0
139627	138872	11055M	PARTICIPANT	\N	PRESENT	0
139628	138872	14087W	PARTICIPANT	\N	PRESENT	0
139629	138872	95035G	PARTICIPANT	\N	PRESENT	0
139630	138872	14135M	PARTICIPANT	\N	PRESENT	0
139631	138872	08019V	PARTICIPANT	\N	PRESENT	0
139632	138872	04067M	PARTICIPANT	\N	PRESENT	0
130357	130356	11026G	PARTICIPANT	\N	PRESENT	0
130358	130356	08051V	PARTICIPANT	\N	PRESENT	0
130722	130716	89017R	PARTICIPANT	\N	PRESENT	0
130723	130716	01031L	PARTICIPANT	\N	EXCUSE	0
130773	130716	14037X	RAPPORTEUR_AVIS	\N	PRESENT	0
130725	130716	01013J	PARTICIPANT	\N	PRESENT	0
130726	130716	11068S	PARTICIPANT	\N	PRESENT	0
131934	131933	11042G	PARTICIPANT	\N	PRESENT	0
130728	130716	08014Q	PARTICIPANT	\N	PRESENT	0
131935	131933	14159V	PARTICIPANT	\N	PRESENT	0
130730	130716	14175V	PARTICIPANT	\N	PRESENT	0
130731	130716	14083S	PARTICIPANT	\N	PRESENT	0
130732	130716	11053K	PARTICIPANT	\N	PRESENT	0
130733	130716	14085U	PARTICIPANT	\N	PRESENT	0
130734	130716	11042G	PARTICIPANT	\N	PRESENT	0
131977	131976	04061F	PARTICIPANT	\N	PRESENT	0
130736	130716	04086Q	PARTICIPANT	\N	PRESENT	0
131978	131976	98046X	PARTICIPANT	\N	PRESENT	0
130738	130716	11070L	PARTICIPANT	\N	PRESENT	0
130739	130716	11088W	PARTICIPANT	\N	PRESENT	0
131980	131979	04061F	PARTICIPANT	\N	PRESENT	0
130741	130716	08022Q	PARTICIPANT	\N	PRESENT	0
130742	130716	01027Q	PARTICIPANT	\N	PRESENT	0
130743	130716	04071H	PARTICIPANT	\N	PRESENT	0
130744	130716	11074Q	PARTICIPANT	\N	PRESENT	0
130745	130716	98053W	PARTICIPANT	\N	EXCUSE	0
130746	130716	11083R	PARTICIPANT	\N	PRESENT	0
131981	131979	98046X	PARTICIPANT	\N	PRESENT	0
130748	130716	01057W	PARTICIPANT	\N	PRESENT	0
132169	124148	80013X	PARTICIPANT	\N	PRESENT	0
130750	130716	08069G	PARTICIPANT	\N	PRESENT	0
130751	130716	11048N	PARTICIPANT	\N	PRESENT	0
130752	130716	99004R	PARTICIPANT	\N	PRESENT	0
132303	124148	11036J	PARTICIPANT	\N	PRESENT	0
130754	130716	14159V	PARTICIPANT	\N	PRESENT	0
130755	130716	07029T	PARTICIPANT	\N	PRESENT	0
132318	124148	14093U	PARTICIPANT	\N	PRESENT	0
130757	130716	08010L	PARTICIPANT	\N	PRESENT	0
130758	130716	08034U	PARTICIPANT	\N	PRESENT	0
132755	124148	11089X	PARTICIPANT	\N	EXCUSE	0
132756	124148	04061F	PARTICIPANT	\N	EXCUSE	0
132757	124148	01048V	PARTICIPANT	\N	EXCUSE	0
130762	130716	08011M	PARTICIPANT	\N	PRESENT	0
130763	130716	08073C	PARTICIPANT	\N	PRESENT	0
130764	130716	08061X	PARTICIPANT	\N	PRESENT	0
132758	124148	14257W	PARTICIPANT	\N	EXCUSE	0
130766	130716	14225N	PARTICIPANT	\N	PRESENT	0
130767	130716	11012A	PARTICIPANT	\N	PRESENT	0
130768	130716	11057P	PARTICIPANT	\N	PRESENT	0
130769	130716	14173T	PARTICIPANT	\N	PRESENT	0
130770	130716	04034C	PRESIDENT	0	PRESENT	0
142760	142759	01041N	PARTICIPANT	\N	PRESENT	0
144745	144744	05008E	PARTICIPANT	\N	PRESENT	0
139335	139332	11109J	PARTICIPANT	\N	PRESENT	0
144746	144744	14065Q	PARTICIPANT	\N	PRESENT	0
144748	144747	05008E	PARTICIPANT	\N	PRESENT	0
139338	139332	01044R	PARTICIPANT	\N	PRESENT	0
139339	139332	08043V	PARTICIPANT	\N	PRESENT	0
139340	139332	14089Y	PARTICIPANT	\N	PRESENT	0
139341	139332	14105F	PARTICIPANT	\N	PRESENT	0
139342	139332	11029K	PARTICIPANT	\N	PRESENT	0
144749	144747	14065Q	PARTICIPANT	\N	PRESENT	0
139344	139332	92015P	PARTICIPANT	\N	EXCUSE	0
139345	139332	08024S	PARTICIPANT	\N	PRESENT	0
147172	144698	14299H	PARTICIPANT	\N	PRESENT	0
147174	147173	11089X	PARTICIPANT	\N	PRESENT	0
147175	147173	14299H	PARTICIPANT	\N	PRESENT	0
147573	147572	11039M	PARTICIPANT	\N	PRESENT	0
147574	147572	98042T	PARTICIPANT	\N	PRESENT	0
139351	139332	87003B	PARTICIPANT	\N	PRESENT	0
139352	139332	98042T	PARTICIPANT	\N	EXCUSE	0
147575	147572	01019Q	PARTICIPANT	\N	PRESENT	0
139354	139332	01041N	PARTICIPANT	\N	PRESENT	0
147669	147668	01008M	PARTICIPANT	\N	PRESENT	0
147670	147668	11036J	PARTICIPANT	\N	PRESENT	0
147671	147668	11081P	PARTICIPANT	\N	PRESENT	0
147672	147668	14013P	PARTICIPANT	\N	PRESENT	0
147673	147668	08068F	PARTICIPANT	\N	PRESENT	0
147674	147668	14207L	PARTICIPANT	\N	PRESENT	0
147720	147668	14237S	PARTICIPANT	\N	PRESENT	0
147676	147668	90003B	PARTICIPANT	\N	PRESENT	0
147721	147668	95067Q	PARTICIPANT	\N	PRESENT	0
139364	139332	14241N	PARTICIPANT	\N	PRESENT	0
147678	147668	80013X	PARTICIPANT	\N	PRESENT	0
152793	152792	14157T	PARTICIPANT	\N	PRESENT	0
139367	139332	08031R	PARTICIPANT	\N	EXCUSE	0
139368	139332	12041X	PARTICIPANT	\N	EXCUSE	0
139369	139332	08039A	PARTICIPANT	\N	PRESENT	0
139370	139332	08017T	PARTICIPANT	\N	PRESENT	0
147680	147668	08038Y	PARTICIPANT	\N	PRESENT	0
147681	147668	04089T	PARTICIPANT	\N	PRESENT	0
139373	139332	14103D	PARTICIPANT	\N	PRESENT	0
139374	139332	11104D	PARTICIPANT	\N	PRESENT	0
147682	147668	14197C	PARTICIPANT	\N	PRESENT	0
139376	139332	04057K	PARTICIPANT	\N	EXCUSE	0
152988	152852	11042G	PARTICIPANT	\N	PRESENT	0
147684	147668	14187A	PARTICIPANT	\N	PRESENT	0
139379	139332	04070G	PRESIDENT	0	PRESENT	0
147685	147668	14033T	PARTICIPANT	\N	PRESENT	0
152863	152852	01031L	PRESIDENT	0	PRESENT	0
147687	147668	11099A	PARTICIPANT	\N	PRESENT	0
147688	147668	04049K	PARTICIPANT	\N	PRESENT	0
155092	155036	14159V	PARTICIPANT	\N	EXCUSE	0
147690	147668	11111C	PARTICIPANT	\N	PRESENT	0
139386	139332	14229S	PARTICIPANT	\N	PRESENT	0
147691	147668	08015R	PARTICIPANT	\N	PRESENT	0
147692	147668	11100Y	PRESIDENT	0	PRESENT	0
147693	147668	01061S	PARTICIPANT	\N	EXCUSE	0
147694	147668	11098Y	PARTICIPANT	\N	PRESENT	0
147695	147668	01043Q	PARTICIPANT	\N	PRESENT	0
160346	160344	04040A	PARTICIPANT	\N	PRESENT	0
147697	147668	14205J	PARTICIPANT	\N	PRESENT	0
160347	160344	07004J	PARTICIPANT	\N	PRESENT	0
147699	147668	14257W	PARTICIPANT	\N	PRESENT	0
152867	152852	11040E	PARTICIPANT	\N	PRESENT	0
147701	147668	04088S	PARTICIPANT	\N	PRESENT	0
152868	152852	08014Q	PARTICIPANT	\N	PRESENT	0
147703	147668	11090Q	PARTICIPANT	\N	PRESENT	0
147704	147668	11046L	PARTICIPANT	\N	PRESENT	0
160348	160344	95035G	PARTICIPANT	\N	PRESENT	0
147706	147668	11094U	PARTICIPANT	\N	PRESENT	0
147707	147668	11066Q	PARTICIPANT	\N	PRESENT	0
152870	152852	14175V	PARTICIPANT	\N	PRESENT	0
152871	152852	14083S	PARTICIPANT	\N	PRESENT	0
152872	152852	11053K	PARTICIPANT	\N	PRESENT	0
152873	152852	14085U	PARTICIPANT	\N	PRESENT	0
160349	160344	83042R	PARTICIPANT	\N	PRESENT	0
160350	160344	10015M	PARTICIPANT	\N	PRESENT	0
152876	152852	04086Q	PARTICIPANT	\N	PRESENT	0
160393	160392	11049P	PARTICIPANT	\N	PRESENT	0
152878	152852	11070L	PARTICIPANT	\N	PRESENT	0
160395	160394	14089Y	PARTICIPANT	\N	PRESENT	0
160396	160394	14207L	PARTICIPANT	\N	PRESENT	0
152881	152852	08022Q	PARTICIPANT	\N	PRESENT	0
152882	152852	01027Q	PARTICIPANT	\N	PRESENT	0
152883	152852	04071H	PARTICIPANT	\N	PRESENT	0
160397	160394	04038G	PARTICIPANT	\N	PRESENT	0
152885	152852	98053W	PARTICIPANT	\N	EXCUSE	0
152886	152852	11083R	PARTICIPANT	\N	PRESENT	0
152887	152852	14199E	PARTICIPANT	\N	PRESENT	0
152888	152852	01057W	PARTICIPANT	\N	PRESENT	0
152889	152852	08016S	PARTICIPANT	\N	EXCUSE	0
160398	160394	11061K	PARTICIPANT	\N	PRESENT	0
160412	159552	01008M	PARTICIPANT	\N	PRESENT	0
160413	159552	14093U	PARTICIPANT	\N	PRESENT	0
160414	159552	90003B	PARTICIPANT	\N	EXCUSE	0
152894	152852	14159V	PARTICIPANT	\N	EXCUSE	0
152895	152852	07029T	PARTICIPANT	\N	PRESENT	0
160415	159552	01015L	PARTICIPANT	\N	PRESENT	0
152897	152852	08010L	PARTICIPANT	\N	PRESENT	0
152898	152852	08034U	PARTICIPANT	\N	PRESENT	0
152899	152852	01048V	PARTICIPANT	\N	PRESENT	0
152900	152852	98046X	PARTICIPANT	\N	PRESENT	0
160712	159492	08069G	PARTICIPANT	\N	EXCUSE	0
152902	152852	08011M	PARTICIPANT	\N	PRESENT	0
152903	152852	08073C	PARTICIPANT	\N	PRESENT	0
152904	152852	08061X	PARTICIPANT	\N	EXCUSE	0
152905	152852	01016M	PARTICIPANT	\N	PRESENT	0
160773	160772	14263U	PARTICIPANT	\N	PRESENT	0
152908	152852	11057P	PARTICIPANT	\N	PRESENT	0
160774	160772	11109J	PARTICIPANT	\N	PRESENT	0
152910	152852	04034C	PARTICIPANT	\N	PRESENT	0
160775	160772	04059M	PARTICIPANT	0	PRESENT	0
160778	160772	08043V	PARTICIPANT	\N	PRESENT	0
142121	141030	11113E	PARTICIPANT	\N	PRESENT	0
142122	141030	14263U	PARTICIPANT	\N	PRESENT	0
142123	141030	98053W	PARTICIPANT	\N	PRESENT	0
142124	141030	14225N	PARTICIPANT	\N	PRESENT	0
142125	141030	14173T	PARTICIPANT	\N	PRESENT	0
142126	141030	11037K	PARTICIPANT	\N	PRESENT	0
142127	141030	95067Q	PARTICIPANT	\N	PRESENT	0
142128	141030	11071M	PARTICIPANT	\N	PRESENT	0
142129	141030	14017T	PARTICIPANT	\N	PRESENT	0
142130	141030	95062K	PARTICIPANT	\N	PRESENT	0
142131	141030	11032E	PARTICIPANT	\N	PRESENT	0
142132	141030	10015M	PARTICIPANT	\N	PRESENT	0
142133	141030	11096W	PARTICIPANT	\N	PRESENT	0
142134	141030	14037X	PARTICIPANT	\N	PRESENT	0
142135	141030	01060R	PARTICIPANT	\N	PRESENT	0
142136	141030	11100Y	PARTICIPANT	\N	PRESENT	0
142137	141030	92031P	PARTICIPANT	\N	PRESENT	0
142138	141030	08034U	PARTICIPANT	\N	PRESENT	0
142139	141030	11026G	PARTICIPANT	\N	PRESENT	0
142140	141030	11056N	PARTICIPANT	\N	PRESENT	0
142141	141030	08010L	PARTICIPANT	\N	PRESENT	0
142142	141030	11090Q	PARTICIPANT	\N	PRESENT	0
142143	141030	01034P	PARTICIPANT	\N	PRESENT	0
142144	141030	11094U	PARTICIPANT	\N	PRESENT	0
142145	141030	14061L	PARTICIPANT	\N	PRESENT	0
142146	141030	11053K	PARTICIPANT	\N	PRESENT	0
142147	141030	14267Y	PARTICIPANT	\N	PRESENT	0
142148	141030	14083S	PARTICIPANT	\N	PRESENT	0
142149	141030	14255U	PARTICIPANT	\N	PRESENT	0
142150	141030	04080J	PARTICIPANT	\N	PRESENT	0
142151	141030	04040A	PARTICIPANT	\N	PRESENT	0
142152	141030	14205J	PARTICIPANT	\N	PRESENT	0
142153	141030	11064N	PARTICIPANT	\N	PRESENT	0
142154	141030	14199E	PARTICIPANT	\N	PRESENT	0
142155	141030	11070L	PARTICIPANT	\N	PRESENT	0
142156	141030	14042U	PARTICIPANT	\N	PRESENT	0
142157	141030	01058X	PARTICIPANT	\N	PRESENT	0
142158	141030	14219Q	PARTICIPANT	\N	PRESENT	0
142159	141030	14103D	PARTICIPANT	\N	PRESENT	0
142160	141030	04092N	PARTICIPANT	\N	PRESENT	0
142161	141030	08011M	PARTICIPANT	\N	PRESENT	0
142162	141030	14265W	PARTICIPANT	\N	PRESENT	0
142163	141030	11085T	PARTICIPANT	\N	PRESENT	0
142164	141030	14071N	PARTICIPANT	\N	PRESENT	0
142165	141030	11082Q	PARTICIPANT	\N	PRESENT	0
142166	141030	14191V	PARTICIPANT	\N	PRESENT	0
142167	141030	14277B	PARTICIPANT	\N	PRESENT	0
142168	141030	01043Q	PARTICIPANT	\N	PRESENT	0
142119	141030	11114F	PARTICIPANT	\N	PRESENT	0
142120	141030	11072N	PARTICIPANT	\N	PRESENT	0
142169	141030	14327T	PARTICIPANT	\N	PRESENT	0
142170	141030	09001P	PARTICIPANT	\N	PRESENT	0
142171	141030	01025N	PARTICIPANT	\N	PRESENT	0
142172	141030	98042T	PARTICIPANT	\N	PRESENT	0
142173	141030	01024M	PARTICIPANT	\N	PRESENT	0
142174	141030	04089T	PARTICIPANT	\N	PRESENT	0
142175	141030	14034U	PARTICIPANT	\N	PRESENT	0
142176	141030	04070G	PARTICIPANT	\N	PRESENT	0
142177	141030	08009T	PARTICIPANT	\N	PRESENT	0
142178	141030	07004J	PARTICIPANT	\N	PRESENT	0
142179	141030	01007L	PARTICIPANT	\N	PRESENT	0
142180	141030	08048B	PARTICIPANT	\N	PRESENT	0
142181	141030	14179A	PARTICIPANT	\N	PRESENT	0
142182	141030	14073Q	PARTICIPANT	\N	PRESENT	0
142183	141030	04044E	PARTICIPANT	\N	PRESENT	0
142184	141030	11093T	PARTICIPANT	\N	PRESENT	0
142185	141030	05012A	PARTICIPANT	\N	PRESENT	0
142186	141030	14089Y	PARTICIPANT	\N	PRESENT	0
142187	141030	11111C	PARTICIPANT	\N	PRESENT	0
142188	141030	14147R	PARTICIPANT	\N	PRESENT	0
142189	141030	11043H	PARTICIPANT	\N	PRESENT	0
142194	141030	01047U	PARTICIPANT	\N	PRESENT	0
142191	141030	14111D	PARTICIPANT	\N	PRESENT	0
142192	141030	86044G	PARTICIPANT	\N	PRESENT	0
142193	141030	04081K	PARTICIPANT	\N	PRESENT	0
142195	141030	04061F	PARTICIPANT	\N	PRESENT	0
142196	141030	99002P	PARTICIPANT	\N	PRESENT	0
142197	141030	14271U	PARTICIPANT	\N	PRESENT	0
142198	141030	92045V	PARTICIPANT	\N	PRESENT	0
142212	141030	01041N	PARTICIPANT	\N	PRESENT	0
142515	141029	08024S	PARTICIPANT	\N	PRESENT	0
142516	141029	09001P	PARTICIPANT	\N	PRESENT	0
142517	141029	95062K	PARTICIPANT	\N	PRESENT	0
142518	141029	14079W	PARTICIPANT	\N	PRESENT	0
142519	141029	08017T	PARTICIPANT	\N	PRESENT	0
142520	141029	01022K	PARTICIPANT	\N	PRESENT	0
142521	141029	04045F	PARTICIPANT	\N	PRESENT	0
142522	141029	08043V	PARTICIPANT	\N	PRESENT	0
142523	141029	14109K	PARTICIPANT	\N	PRESENT	0
142524	141029	14097Y	PARTICIPANT	\N	PRESENT	0
142525	141029	14014Q	PARTICIPANT	\N	PRESENT	0
142526	141029	11023D	PARTICIPANT	\N	PRESENT	0
142527	141029	08048B	PARTICIPANT	\N	PRESENT	0
142528	141029	08031R	PARTICIPANT	\N	PRESENT	0
142529	141029	97011G	PARTICIPANT	\N	PRESENT	0
142530	141029	11031D	PARTICIPANT	\N	PRESENT	0
142531	141029	07026Q	PARTICIPANT	\N	PRESENT	0
142593	141029	87003B	PARTICIPANT	\N	PRESENT	0
142533	141029	14219Q	PARTICIPANT	\N	PRESENT	0
142534	141029	14241N	PARTICIPANT	\N	PRESENT	0
142535	141029	98022P	PARTICIPANT	\N	PRESENT	0
142536	141029	11029K	PARTICIPANT	\N	PRESENT	0
142537	141029	12042Y	PARTICIPANT	\N	PRESENT	0
142538	141029	95035G	PARTICIPANT	\N	PRESENT	0
142539	141029	14030Q	PARTICIPANT	\N	PRESENT	0
142540	141029	14261S	PARTICIPANT	\N	PRESENT	0
142541	141029	14179A	PARTICIPANT	\N	PRESENT	0
142542	141029	14038Y	PARTICIPANT	\N	PRESENT	0
142543	141029	14018U	PARTICIPANT	\N	PRESENT	0
142544	141029	14269B	PARTICIPANT	\N	PRESENT	0
142545	141029	14265W	PARTICIPANT	\N	PRESENT	0
142546	141029	01025N	PARTICIPANT	\N	PRESENT	0
142547	141029	80013X	PARTICIPANT	\N	PRESENT	0
142548	141029	14235Q	PARTICIPANT	\N	PRESENT	0
142549	141029	14133K	PARTICIPANT	\N	PRESENT	0
142550	141029	14105F	PARTICIPANT	\N	PRESENT	0
142551	141029	04041B	PARTICIPANT	\N	PRESENT	0
142552	141029	07029T	PARTICIPANT	\N	PRESENT	0
142553	141029	04059M	PARTICIPANT	\N	PRESENT	0
142554	141029	04085P	PARTICIPANT	\N	PRESENT	0
142572	141029	14119M	PARTICIPANT	\N	PRESENT	0
142573	141029	14271U	PARTICIPANT	\N	PRESENT	0
142574	141029	14121F	PARTICIPANT	\N	PRESENT	0
142575	141029	14069U	PARTICIPANT	\N	PRESENT	0
142576	141029	14026U	PARTICIPANT	\N	PRESENT	0
142592	141029	14237S	PARTICIPANT	\N	PRESENT	0
142594	141029	14213J	PARTICIPANT	\N	PRESENT	0
142653	141031	04094Q	PARTICIPANT	\N	PRESENT	0
142654	141031	11113E	PARTICIPANT	\N	PRESENT	0
142655	141031	04095R	PARTICIPANT	\N	PRESENT	0
142656	141031	11025F	PARTICIPANT	\N	PRESENT	0
142657	141031	14261S	PARTICIPANT	\N	PRESENT	0
142658	141031	01025N	PARTICIPANT	\N	PRESENT	0
142659	141031	08019V	PARTICIPANT	\N	PRESENT	0
142660	141031	14097Y	PARTICIPANT	\N	PRESENT	0
142661	141031	01027Q	PARTICIPANT	\N	PRESENT	0
142662	141031	14133K	PARTICIPANT	\N	PRESENT	0
142663	141031	04043D	PARTICIPANT	\N	PRESENT	0
142664	141031	14059S	PARTICIPANT	\N	PRESENT	0
142665	141031	14119M	PARTICIPANT	\N	PRESENT	0
142666	141031	08047A	PARTICIPANT	\N	PRESENT	0
142667	141031	11099A	PARTICIPANT	\N	PRESENT	0
142668	141031	11098Y	PARTICIPANT	\N	PRESENT	0
142669	141031	11064N	PARTICIPANT	\N	PRESENT	0
142670	141031	11114F	PARTICIPANT	\N	PRESENT	0
142671	141031	11109J	PARTICIPANT	\N	PRESENT	0
142672	141031	14257W	PARTICIPANT	\N	PRESENT	0
142673	141031	14069U	PARTICIPANT	\N	PRESENT	0
142674	141031	04097T	PARTICIPANT	\N	PRESENT	0
142675	141031	11036J	PARTICIPANT	\N	PRESENT	0
142676	141031	01016M	PARTICIPANT	\N	PRESENT	0
142677	141031	11072N	PARTICIPANT	\N	PRESENT	0
142678	141031	08053X	PARTICIPANT	\N	PRESENT	0
142679	141031	14135M	PARTICIPANT	\N	PRESENT	0
142692	141031	14197C	PARTICIPANT	\N	PRESENT	0
142693	141031	14105F	PARTICIPANT	\N	PRESENT	0
142694	141031	07029T	PARTICIPANT	\N	PRESENT	0
142695	141031	92045V	PARTICIPANT	\N	PRESENT	0
142696	141031	01008M	PARTICIPANT	\N	PRESENT	0
142644	141031	08055A	PARTICIPANT	\N	PRESENT	0
142652	141031	05001W	PARTICIPANT	\N	PRESENT	0
142712	141031	14265W	PARTICIPANT	\N	PRESENT	0
142713	141031	14017T	PARTICIPANT	\N	PRESENT	0
142714	141031	14033T	PARTICIPANT	\N	PRESENT	0
142715	141031	14083S	PARTICIPANT	\N	PRESENT	0
142716	141031	14026U	PARTICIPANT	\N	PRESENT	0
142717	141031	08051V	PARTICIPANT	\N	PRESENT	0
142869	142868	96004D	PRESIDENT	0	PRESENT	0
132021	132020	14133K	PARTICIPANT	\N	PRESENT	0
132022	132020	04054G	PARTICIPANT	\N	PRESENT	0
132023	132020	96004D	PRESIDENT	0	PRESENT	0
132024	132020	14089Y	PARTICIPANT	\N	PRESENT	0
132025	132020	90003B	PARTICIPANT	\N	PRESENT	0
132026	132020	11035H	PARTICIPANT	\N	PRESENT	0
132027	132020	14249W	PARTICIPANT	\N	PRESENT	0
132028	132020	14097Y	PARTICIPANT	\N	PRESENT	0
132029	132020	04061F	PARTICIPANT	\N	PRESENT	0
132030	132020	14073Q	PARTICIPANT	\N	PRESENT	0
132031	132020	11026G	PARTICIPANT	\N	PRESENT	0
132032	132020	98046X	PARTICIPANT	\N	EXCUSE	0
132033	132020	08073C	PARTICIPANT	\N	PRESENT	0
132034	132020	14135M	PARTICIPANT	\N	PRESENT	0
132035	132020	10015M	PARTICIPANT	\N	PRESENT	0
132036	132020	04034C	PARTICIPANT	\N	PRESENT	0
132038	132020	04045F	PARTICIPANT	\N	PRESENT	0
132780	132779	08012N	PARTICIPANT	\N	PRESENT	0
132783	132782	08012N	PARTICIPANT	\N	PRESENT	0
134778	134777	89017R	PARTICIPANT	\N	PRESENT	0
134779	134777	01031L	PRESIDENT	0	PRESENT	0
135741	135740	14119M	PARTICIPANT	\N	PRESENT	0
134781	134777	01013J	PARTICIPANT	\N	PRESENT	0
134782	134777	11068S	PARTICIPANT	\N	PRESENT	0
141133	141132	01028R	PARTICIPANT	\N	PRESENT	0
134784	134777	08014Q	PARTICIPANT	\N	PRESENT	0
144592	144591	01041N	PARTICIPANT	\N	PRESENT	0
134786	134777	14175V	PARTICIPANT	\N	PRESENT	0
144593	144591	08017T	PARTICIPANT	\N	PRESENT	0
144932	141100	01059Y	PARTICIPANT	\N	PRESENT	0
144933	141100	01003G	PARTICIPANT	\N	PRESENT	0
134790	134777	11042G	PARTICIPANT	\N	PRESENT	0
134791	134777	88008L	PARTICIPANT	\N	PRESENT	0
134792	134777	04086Q	PARTICIPANT	\N	PRESENT	0
144975	144974	14281W	PARTICIPANT	\N	PRESENT	0
144976	144974	14271U	PARTICIPANT	\N	PRESENT	0
134795	134777	11088W	PARTICIPANT	\N	PRESENT	0
134796	134777	14327T	PARTICIPANT	\N	PRESENT	0
134797	134777	08022Q	PARTICIPANT	\N	PRESENT	0
134798	134777	01027Q	PARTICIPANT	\N	PRESENT	0
134799	134777	04071H	PARTICIPANT	\N	PRESENT	0
134801	134777	98053W	PARTICIPANT	\N	EXCUSE	0
134802	134777	11083R	PARTICIPANT	\N	PRESENT	0
134804	134777	01057W	PARTICIPANT	\N	PRESENT	0
134805	134777	08016S	PARTICIPANT	\N	EXCUSE	0
134806	134777	08069G	PARTICIPANT	\N	PRESENT	0
134808	134777	99004R	PARTICIPANT	\N	PRESENT	0
134809	134777	04061F	PARTICIPANT	\N	PRESENT	0
134810	134777	14159V	PARTICIPANT	\N	PRESENT	0
134811	134777	07029T	PARTICIPANT	\N	PRESENT	0
144995	125632	11068S	PARTICIPANT	\N	EXCUSE	0
134813	134777	08010L	PARTICIPANT	\N	PRESENT	0
134814	134777	08034U	PARTICIPANT	\N	PRESENT	0
144996	125632	08039A	PARTICIPANT	\N	EXCUSE	0
134816	134777	98046X	PARTICIPANT	\N	PRESENT	0
144997	125632	14257W	PARTICIPANT	\N	EXCUSE	0
134818	134777	08011M	PARTICIPANT	\N	EXCUSE	0
145035	125635	01046T	PARTICIPANT	\N	EXCUSE	0
134820	134777	08061X	PARTICIPANT	\N	PRESENT	0
134821	134777	01016M	PARTICIPANT	\N	PRESENT	0
134822	134777	14225N	PARTICIPANT	\N	PRESENT	0
145036	125635	11036J	PARTICIPANT	\N	EXCUSE	0
134824	134777	11057P	PARTICIPANT	\N	PRESENT	0
145037	125635	14209N	PARTICIPANT	\N	PRESENT	0
145038	125635	80013X	PARTICIPANT	\N	PRESENT	0
145039	125635	11089X	PARTICIPANT	\N	EXCUSE	0
145040	125635	11061K	PARTICIPANT	\N	EXCUSE	0
145041	125635	04061F	PARTICIPANT	\N	EXCUSE	0
145042	125635	01048V	PARTICIPANT	\N	EXCUSE	0
145573	145572	08025T	PARTICIPANT	\N	PRESENT	0
147775	147774	14249W	PARTICIPANT	\N	EXCUSE	0
145575	145572	05008E	PARTICIPANT	\N	PRESENT	0
145576	145572	11030C	PARTICIPANT	\N	PRESENT	0
145577	145572	11033F	PARTICIPANT	\N	EXCUSE	0
145578	145572	14065Q	PARTICIPANT	\N	PRESENT	0
145579	145572	14069U	PARTICIPANT	\N	PRESENT	0
145580	145572	04047H	PARTICIPANT	\N	PRESENT	0
145581	145572	11032E	PARTICIPANT	\N	PRESENT	0
145582	145572	04038G	PARTICIPANT	\N	PRESENT	0
145664	145662	08055A	PARTICIPANT	\N	PRESENT	0
145584	145572	11056N	PARTICIPANT	\N	EXCUSE	0
145585	145572	14259Y	PARTICIPANT	\N	PRESENT	0
145665	145662	14093U	PARTICIPANT	\N	PRESENT	0
145666	145662	14030Q	PARTICIPANT	\N	PRESENT	0
145667	145662	96004D	PARTICIPANT	\N	PRESENT	0
145589	145572	01024M	PARTICIPANT	\N	PRESENT	0
145668	145662	08060W	PARTICIPANT	\N	PRESENT	0
145669	145662	11095V	PARTICIPANT	\N	PRESENT	0
145592	145572	08018U	PARTICIPANT	\N	PRESENT	0
145670	145662	14038Y	PARTICIPANT	\N	PRESENT	0
145594	145572	01007L	PARTICIPANT	\N	PRESENT	0
145595	145572	11049P	PARTICIPANT	\N	PRESENT	0
145596	145572	08044W	PARTICIPANT	\N	EXCUSE	0
147776	147774	04057K	PARTICIPANT	\N	EXCUSE	0
145598	145572	11026G	PARTICIPANT	\N	PRESENT	0
145599	145572	04079R	PARTICIPANT	\N	PRESENT	0
145600	145572	14111D	PARTICIPANT	\N	PRESENT	0
145601	145572	14001X	PARTICIPANT	\N	PRESENT	0
145672	145662	98023Q	PARTICIPANT	\N	PRESENT	0
147777	147774	96004D	PRESIDENT	0	PRESENT	0
145604	145572	14147R	PARTICIPANT	\N	PRESENT	0
145674	145662	01015L	PARTICIPANT	\N	EXCUSE	0
145606	145572	08051V	PARTICIPANT	\N	PRESENT	0
145607	145572	11072N	PARTICIPANT	\N	PRESENT	0
145608	145572	07034Q	PARTICIPANT	\N	PRESENT	0
145609	145572	04074L	PARTICIPANT	\N	PRESENT	0
145610	145572	10015M	PARTICIPANT	\N	PRESENT	0
145611	145572	95063L	PARTICIPANT	\N	PRESENT	0
145675	145662	11107G	PARTICIPANT	\N	EXCUSE	0
145613	145572	01028R	PARTICIPANT	\N	PRESENT	0
145614	145572	98035U	PARTICIPANT	\N	PRESENT	0
145615	145572	04056J	PARTICIPANT	\N	PRESENT	0
145676	145662	11020A	PARTICIPANT	\N	PRESENT	0
145617	145572	04044E	PARTICIPANT	\N	PRESENT	0
145618	145572	11037K	PARTICIPANT	\N	PRESENT	0
145619	145572	92045V	PARTICIPANT	\N	EXCUSE	0
145620	145572	95067Q	PARTICIPANT	\N	PRESENT	0
145621	145572	01047U	PARTICIPANT	\N	PRESENT	0
147778	147774	14089Y	PARTICIPANT	\N	PRESENT	0
145678	145662	01022K	PARTICIPANT	\N	EXCUSE	0
147779	147774	90003B	PARTICIPANT	\N	PRESENT	0
147780	147774	11035H	PARTICIPANT	\N	PRESENT	0
147781	147774	95030B	PRESIDENT	1	PRESENT	0
145682	145662	11059R	PARTICIPANT	\N	PRESENT	0
145683	145662	14219Q	PARTICIPANT	\N	PRESENT	0
145684	145662	80027E	PARTICIPANT	\N	PRESENT	0
145685	145662	14031R	PARTICIPANT	\N	PRESENT	0
145686	145662	08009T	PRESIDENT	0	PRESENT	0
145687	145662	08062Y	PARTICIPANT	\N	PRESENT	0
145688	145662	14221J	PARTICIPANT	\N	PRESENT	0
145689	145662	92039X	PARTICIPANT	\N	PRESENT	0
145690	145662	08042U	PARTICIPANT	\N	PRESENT	0
145691	145662	14169X	PARTICIPANT	\N	PRESENT	0
145692	145662	14237S	PARTICIPANT	\N	PRESENT	0
145693	145662	13002U	PARTICIPANT	\N	PRESENT	0
145694	145662	05012A	PARTICIPANT	\N	PRESENT	0
147783	147774	95037J	PARTICIPANT	\N	PRESENT	0
145696	145662	14135M	PARTICIPANT	\N	PRESENT	0
145697	145662	14331P	PARTICIPANT	\N	PRESENT	0
145698	145662	95062K	PARTICIPANT	\N	PRESENT	0
147784	147774	14097Y	PARTICIPANT	\N	PRESENT	0
145700	145662	14051J	PARTICIPANT	\N	PRESENT	0
145701	145662	14157T	PARTICIPANT	\N	PRESENT	0
147786	147774	04061F	PARTICIPANT	\N	PRESENT	0
147787	147774	11026G	PARTICIPANT	\N	PRESENT	0
147788	147774	98046X	PARTICIPANT	\N	PRESENT	0
147789	147774	14001X	PARTICIPANT	\N	PRESENT	0
147790	147774	08042U	PARTICIPANT	\N	PRESENT	0
147791	147774	04080J	PARTICIPANT	\N	PRESENT	0
147792	147774	14135M	PARTICIPANT	\N	PRESENT	0
147794	147774	01016M	PARTICIPANT	\N	PRESENT	0
147795	147774	92045V	PARTICIPANT	\N	PRESENT	0
147797	147774	04034C	PARTICIPANT	\N	PRESENT	0
149593	149592	04053F	PARTICIPANT	\N	PRESENT	0
149594	149592	04066L	PARTICIPANT	\N	PRESENT	0
149595	149592	11103C	PRESIDENT	0	PRESENT	0
149596	149592	08052W	PARTICIPANT	\N	PRESENT	0
149597	149592	01059Y	PARTICIPANT	\N	PRESENT	0
149598	149592	04067M	PARTICIPANT	\N	PRESENT	0
149599	149592	14121F	PARTICIPANT	\N	PRESENT	0
149600	149592	14265W	PARTICIPANT	\N	PRESENT	0
149601	149592	11025F	PARTICIPANT	\N	PRESENT	0
140163	140162	01007L	PARTICIPANT	\N	PRESENT	0
140185	137569	14231L	PARTICIPANT	\N	PRESENT	0
140186	137569	11098Y	PARTICIPANT	\N	PRESENT	0
140187	137569	14063N	PARTICIPANT	\N	PRESENT	0
140188	137569	11112D	PARTICIPANT	\N	PRESENT	0
140191	137569	08010L	PARTICIPANT	\N	PRESENT	0
140193	137569	05012A	PARTICIPANT	\N	PRESENT	0
140908	140840	14030Q	PARTICIPANT	\N	EXCUSE	0
140909	140840	11095V	PARTICIPANT	\N	EXCUSE	0
140910	140840	11107G	PARTICIPANT	\N	EXCUSE	0
140911	140840	95062K	PARTICIPANT	\N	EXCUSE	0
141061	141059	14299H	PARTICIPANT	\N	PRESENT	0
141152	125634	11061K	PARTICIPANT	\N	PRESENT	0
141153	125632	11036J	PARTICIPANT	\N	PRESENT	0
141154	125632	80013X	PARTICIPANT	\N	EXCUSE	0
141155	125632	11061K	PARTICIPANT	\N	EXCUSE	0
141156	125632	11089X	PARTICIPANT	\N	EXCUSE	0
141157	125632	14221J	PARTICIPANT	\N	EXCUSE	0
141158	125632	11082Q	PARTICIPANT	\N	EXCUSE	0
141159	125632	01058X	PARTICIPANT	\N	EXCUSE	0
141221	141220	08051V	PARTICIPANT	\N	PRESENT	0
141222	141220	14071N	PARTICIPANT	\N	PRESENT	0
141413	125632	14263U	PARTICIPANT	\N	EXCUSE	0
141415	125632	01046T	PARTICIPANT	\N	EXCUSE	0
141424	125632	08069G	PARTICIPANT	\N	EXCUSE	0
141425	125632	04061F	PARTICIPANT	\N	EXCUSE	0
141427	125632	01048V	PARTICIPANT	\N	EXCUSE	0
141437	125632	13002U	PARTICIPANT	\N	EXCUSE	0
141592	135882	14219Q	PARTICIPANT	\N	EXCUSE	0
141593	135882	11054L	PARTICIPANT	\N	EXCUSE	0
142917	136163	95062K	PARTICIPANT	\N	EXCUSE	0
142994	136163	14219Q	PARTICIPANT	\N	EXCUSE	0
143420	143419	14261S	PARTICIPANT	\N	PRESENT	0
143421	143419	08055A	PARTICIPANT	\N	PRESENT	0
143422	143419	14093U	PARTICIPANT	\N	PRESENT	0
143423	143419	14030Q	PARTICIPANT	\N	PRESENT	0
143459	143419	11095V	PARTICIPANT	\N	EXCUSE	0
143425	143419	08060W	PARTICIPANT	\N	PRESENT	0
143460	143419	11107G	PARTICIPANT	\N	EXCUSE	0
143477	143476	14261S	PARTICIPANT	\N	PRESENT	0
143428	143419	11114F	PARTICIPANT	\N	PRESENT	0
143429	143419	98023Q	PARTICIPANT	\N	PRESENT	0
143430	143419	11065P	PARTICIPANT	\N	PRESENT	0
143431	143419	01015L	PARTICIPANT	\N	PRESENT	0
143478	143476	08055A	PARTICIPANT	\N	PRESENT	0
143479	143476	14093U	PARTICIPANT	\N	PRESENT	0
143434	143419	02002K	PARTICIPANT	\N	PRESENT	0
143435	143419	01022K	PARTICIPANT	\N	PRESENT	0
143480	143476	14030Q	PARTICIPANT	\N	PRESENT	0
143481	143476	96004D	PARTICIPANT	\N	PRESENT	0
143482	143476	08060W	PARTICIPANT	\N	PRESENT	0
143439	143419	11059R	PARTICIPANT	\N	PRESENT	0
143440	143419	14219Q	PARTICIPANT	\N	PRESENT	0
143441	143419	80027E	PARTICIPANT	\N	PRESENT	0
143442	143419	14031R	PARTICIPANT	\N	PRESENT	0
143443	143419	08009T	PRESIDENT	0	PRESENT	0
143444	143419	08062Y	PARTICIPANT	\N	PRESENT	0
143483	143476	11095V	PARTICIPANT	\N	EXCUSE	0
143446	143419	92039X	PARTICIPANT	\N	PRESENT	0
143447	143419	08042U	PARTICIPANT	\N	PRESENT	0
143448	143419	14169X	PARTICIPANT	\N	PRESENT	0
143449	143419	14237S	PARTICIPANT	\N	PRESENT	0
143450	143419	13002U	PARTICIPANT	\N	PRESENT	0
143451	143419	05012A	PARTICIPANT	\N	PRESENT	0
143815	143814	04053F	PARTICIPANT	\N	PRESENT	0
143453	143419	14135M	PARTICIPANT	\N	PRESENT	0
143454	143419	14331P	PARTICIPANT	\N	PRESENT	0
143455	143419	95062K	PARTICIPANT	\N	PRESENT	0
139633	138872	11043H	PARTICIPANT	\N	PRESENT	0
139673	138874	14151M	PARTICIPANT	\N	PRESENT	0
143456	143419	14107H	PARTICIPANT	\N	PRESENT	0
143457	143419	14051J	PARTICIPANT	\N	PRESENT	0
143458	143419	14157T	PARTICIPANT	\N	PRESENT	0
143817	143814	00003C	PARTICIPANT	\N	EXCUSE	0
143485	143476	11114F	PARTICIPANT	\N	PRESENT	0
143486	143476	98023Q	PARTICIPANT	\N	PRESENT	0
143487	143476	11065P	PARTICIPANT	\N	PRESENT	0
143488	143476	01015L	PARTICIPANT	\N	PRESENT	0
143489	143476	11107G	PARTICIPANT	\N	EXCUSE	0
143818	143814	14195A	PARTICIPANT	\N	PRESENT	0
143491	143476	02002K	PARTICIPANT	\N	PRESENT	0
143492	143476	01022K	PARTICIPANT	\N	PRESENT	0
143493	143476	05001W	PARTICIPANT	\N	PRESENT	0
143494	143476	04097T	PARTICIPANT	\N	PRESENT	0
143495	143476	09001P	PARTICIPANT	\N	PRESENT	0
143496	143476	11059R	PARTICIPANT	\N	PRESENT	0
143497	143476	14219Q	PARTICIPANT	\N	PRESENT	0
143498	143476	80027E	PARTICIPANT	\N	PRESENT	0
143499	143476	14031R	PARTICIPANT	\N	PRESENT	0
143500	143476	08009T	PRESIDENT	0	PRESENT	0
143501	143476	08062Y	PARTICIPANT	\N	PRESENT	0
143819	143814	08052W	PARTICIPANT	\N	PRESENT	0
143503	143476	92039X	PARTICIPANT	\N	PRESENT	0
143504	143476	08042U	PARTICIPANT	\N	PRESENT	0
143505	143476	14169X	PARTICIPANT	\N	PRESENT	0
143506	143476	14237S	PARTICIPANT	\N	PRESENT	0
143507	143476	13002U	PARTICIPANT	\N	PRESENT	0
143508	143476	05012A	PARTICIPANT	\N	PRESENT	0
143820	143814	04081K	PARTICIPANT	\N	PRESENT	0
143510	143476	14135M	PARTICIPANT	\N	PRESENT	0
143511	143476	14331P	PARTICIPANT	\N	PRESENT	0
143512	143476	95062K	PARTICIPANT	\N	PRESENT	0
143513	143476	14107H	PARTICIPANT	\N	PRESENT	0
143514	143476	14051J	PARTICIPANT	\N	PRESENT	0
143515	143476	14157T	PARTICIPANT	\N	PRESENT	0
143821	143814	14151M	PARTICIPANT	\N	PRESENT	0
143822	143814	12042Y	PARTICIPANT	\N	PRESENT	0
143823	143814	14087W	PARTICIPANT	\N	PRESENT	0
143824	143814	01003G	PARTICIPANT	\N	PRESENT	0
143825	143814	14231L	PARTICIPANT	\N	EXCUSE	0
143826	143814	08041T	PARTICIPANT	\N	PRESENT	0
143827	143814	14026U	PARTICIPANT	\N	PRESENT	0
143828	143814	14213J	PARTICIPANT	\N	PRESENT	0
143829	143814	11112D	PARTICIPANT	\N	PRESENT	0
143830	143814	14037X	PARTICIPANT	\N	PRESENT	0
143831	143814	11067R	PARTICIPANT	\N	EXCUSE	0
143832	143814	04092N	PRESIDENT	0	PRESENT	0
143833	143814	14265W	PARTICIPANT	\N	PRESENT	0
143834	143814	14119M	PARTICIPANT	\N	PRESENT	0
143835	143814	14071N	PARTICIPANT	\N	PRESENT	0
143836	143814	14271U	PARTICIPANT	\N	PRESENT	0
143837	143814	11093T	PARTICIPANT	\N	PRESENT	0
143838	143814	04045F	PARTICIPANT	\N	PRESENT	0
143839	143814	14227Q	PARTICIPANT	\N	PRESENT	0
143840	143814	01034P	PARTICIPANT	\N	PRESENT	0
143841	143814	11063M	PARTICIPANT	\N	PRESENT	0
143842	143814	14269B	PARTICIPANT	\N	EXCUSE	0
143898	143897	95067Q	PARTICIPANT	\N	PRESENT	0
143900	143899	95067Q	PARTICIPANT	\N	PRESENT	0
143901	143899	14195A	PARTICIPANT	\N	PRESENT	0
143903	143902	95067Q	PARTICIPANT	\N	PRESENT	0
143905	143904	95067Q	PARTICIPANT	\N	PRESENT	0
143910	143909	11037K	PARTICIPANT	\N	PRESENT	0
143912	143911	11037K	PARTICIPANT	\N	PRESENT	0
143914	143913	95067Q	PARTICIPANT	\N	PRESENT	0
144154	144153	08044W	PARTICIPANT	\N	EXCUSE	0
144155	144153	11026G	PARTICIPANT	\N	PRESENT	0
144156	144153	08051V	PARTICIPANT	\N	PRESENT	0
144158	144153	01028R	PARTICIPANT	\N	PRESENT	0
144159	144153	98035U	PARTICIPANT	\N	PRESENT	0
144160	144153	04056J	PARTICIPANT	\N	PRESENT	0
144161	144153	04044E	PRESIDENT	0	PRESENT	0
144162	144153	96004D	PARTICIPANT	\N	PRESENT	0
144163	144153	04057K	PARTICIPANT	\N	PRESENT	0
144164	144153	07026Q	PARTICIPANT	\N	PRESENT	0
144165	144153	08017T	PARTICIPANT	\N	PRESENT	0
144166	144153	08039A	PARTICIPANT	\N	PRESENT	0
144167	144153	11029K	PARTICIPANT	\N	PRESENT	0
144168	144153	14179A	PARTICIPANT	\N	PRESENT	0
144169	144153	14089Y	PARTICIPANT	\N	PRESENT	0
144170	144153	04045F	PARTICIPANT	\N	PRESENT	0
144171	144153	14063N	PARTICIPANT	\N	PRESENT	0
144172	144153	08043V	PARTICIPANT	\N	PRESENT	0
144173	144153	11012A	PARTICIPANT	\N	PRESENT	0
144174	144153	14105F	PARTICIPANT	\N	PRESENT	0
144175	144153	01044R	PARTICIPANT	\N	PRESENT	0
144176	144153	11109J	PARTICIPANT	\N	PRESENT	0
144177	144153	14073Q	PARTICIPANT	\N	PRESENT	0
144192	144153	95063L	PARTICIPANT	\N	PRESENT	0
144216	144212	01031L	PRESIDENT	0	PRESENT	0
144218	144212	01013J	PARTICIPANT	\N	PRESENT	0
144219	144212	11068S	PARTICIPANT	\N	PRESENT	0
144220	144212	11040E	PARTICIPANT	\N	PRESENT	0
144221	144212	08014Q	PARTICIPANT	\N	PRESENT	0
127405	127404	11026G	PARTICIPANT	\N	PRESENT	0
130036	130034	01031L	PRESIDENT	0	PRESENT	0
130037	130034	14175V	PARTICIPANT	\N	PRESENT	0
130038	130034	11053K	PARTICIPANT	\N	PRESENT	0
130039	130034	04086Q	PARTICIPANT	\N	PRESENT	0
130040	130034	01027Q	PARTICIPANT	\N	PRESENT	0
130041	130034	11083R	PARTICIPANT	\N	PRESENT	0
130042	130034	14159V	PARTICIPANT	\N	PRESENT	0
130043	130034	01048V	PARTICIPANT	\N	PRESENT	0
130047	130034	01016M	PARTICIPANT	\N	PRESENT	0
130045	130034	98046X	PARTICIPANT	\N	PRESENT	0
130046	130034	08011M	PARTICIPANT	\N	PRESENT	0
130048	130034	11012A	PARTICIPANT	\N	PRESENT	0
130049	130034	04034C	PARTICIPANT	\N	PRESENT	0
130051	130034	14327T	PARTICIPANT	\N	EXCUSE	0
130052	130034	98053W	PARTICIPANT	\N	EXCUSE	0
130053	130034	08061X	PARTICIPANT	\N	EXCUSE	0
130055	130034	92031P	RAPPORTEUR_AVIS	\N	PRESENT	0
130056	130034	04035D	PARTICIPANT	\N	PRESENT	0
130057	130034	14255U	PARTICIPANT	\N	PRESENT	0
130058	130034	11026G	PARTICIPANT	\N	PRESENT	0
137863	130293	04042C	PARTICIPANT	\N	PRESENT	0
137861	137860	04033B	PARTICIPANT	\N	PRESENT	0
137862	137860	04035D	PARTICIPANT	\N	PRESENT	0
137864	130293	04077P	PARTICIPANT	\N	PRESENT	0
138299	138298	08041T	PARTICIPANT	\N	PRESENT	0
138302	138298	14223L	PARTICIPANT	\N	PRESENT	0
138303	138298	11031D	PARTICIPANT	\N	PRESENT	0
148087	148086	96004D	PRESIDENT	0	PRESENT	0
148088	148086	04042C	PARTICIPANT	\N	PRESENT	0
148089	148086	04035D	PARTICIPANT	\N	EXCUSE	0
148090	148086	07024N	PARTICIPANT	\N	PRESENT	0
148091	148086	98022P	PARTICIPANT	\N	PRESENT	0
148095	148086	14001X	PARTICIPANT	\N	PRESENT	0
148093	148086	14097Y	PARTICIPANT	\N	PRESENT	0
148094	148086	14073Q	PARTICIPANT	\N	PRESENT	0
148096	148086	83042R	PARTICIPANT	\N	PRESENT	0
148097	148086	95059Q	PRESIDENT	1	PRESENT	0
148098	148086	98035U	PARTICIPANT	\N	PRESENT	0
148099	148086	04034C	PARTICIPANT	\N	PRESENT	0
148100	148086	14014Q	PARTICIPANT	\N	PRESENT	0
148102	148086	95030B	PARTICIPANT	\N	PRESENT	0
148103	148086	04036E	PARTICIPANT	\N	PRESENT	0
148104	148086	14211G	PARTICIPANT	\N	PRESENT	0
148105	148086	92031P	PARTICIPANT	\N	PRESENT	0
148106	148086	08047A	PARTICIPANT	\N	PRESENT	0
148107	148086	08049C	PARTICIPANT	\N	PRESENT	0
148108	148086	95037J	PARTICIPANT	\N	PRESENT	0
148109	148086	95035G	PARTICIPANT	\N	PRESENT	0
148110	148086	14039A	PARTICIPANT	\N	PRESENT	0
148111	148086	04077P	PARTICIPANT	\N	PRESENT	0
148112	148086	14253S	PARTICIPANT	\N	PRESENT	0
148113	148086	14028W	PARTICIPANT	\N	PRESENT	0
148114	148086	04057K	PARTICIPANT	\N	EXCUSE	0
150073	150072	14093U	PARTICIPANT	\N	PRESENT	0
150074	150072	04040A	PARTICIPANT	\N	PRESENT	0
150075	150072	14195A	PARTICIPANT	\N	PRESENT	0
150076	150072	08034U	PARTICIPANT	\N	PRESENT	0
150077	150072	10006L	PARTICIPANT	\N	PRESENT	0
150078	150072	14041T	PARTICIPANT	\N	PRESENT	0
150079	150072	14217N	PARTICIPANT	\N	PRESENT	0
150080	150072	01041N	PARTICIPANT	\N	PRESENT	0
150081	150072	04036E	PARTICIPANT	\N	PRESENT	0
150082	150072	08039A	PARTICIPANT	\N	PRESENT	0
150083	150072	14059S	PARTICIPANT	\N	PRESENT	0
150084	150072	14031R	PARTICIPANT	\N	PRESENT	0
150085	150072	04033B	PARTICIPANT	\N	PRESENT	0
150086	150072	95067Q	PARTICIPANT	\N	PRESENT	0
150196	150195	98050T	PARTICIPANT	\N	PRESENT	0
150198	150197	98050T	PARTICIPANT	\N	PRESENT	0
156033	156032	14087W	PARTICIPANT	\N	PRESENT	0
156034	156032	14089Y	PARTICIPANT	\N	PRESENT	0
156035	156032	14207L	PRESIDENT	0	PRESENT	0
156036	156032	04038G	PARTICIPANT	\N	PRESENT	0
156037	156032	14079W	PARTICIPANT	\N	PRESENT	0
156038	156032	14231L	PARTICIPANT	\N	PRESENT	0
156039	156032	14237S	PARTICIPANT	\N	PRESENT	0
156040	156032	14135M	PARTICIPANT	\N	EXCUSE	0
156041	156032	11023D	PARTICIPANT	\N	EXCUSE	0
156042	156032	14229S	PARTICIPANT	\N	EXCUSE	0
156043	156032	04057K	PARTICIPANT	\N	EXCUSE	0
156044	156032	14053L	PARTICIPANT	\N	EXCUSE	0
156053	156052	14089Y	PARTICIPANT	\N	PRESENT	0
156054	156052	14207L	PRESIDENT	0	PRESENT	0
156092	149493	14071N	PARTICIPANT	\N	PRESENT	0
156056	156052	14079W	PARTICIPANT	\N	PRESENT	0
156093	149493	08051V	PARTICIPANT	\N	PRESENT	0
156127	156123	14263U	PARTICIPANT	\N	PRESENT	0
156059	156052	14087W	PARTICIPANT	\N	PRESENT	0
156060	156052	14135M	PARTICIPANT	\N	EXCUSE	0
156061	156052	11023D	PARTICIPANT	\N	EXCUSE	0
156062	156052	14229S	PARTICIPANT	\N	EXCUSE	0
156063	156052	04057K	PARTICIPANT	\N	EXCUSE	0
156064	156052	14053L	PARTICIPANT	\N	EXCUSE	0
156128	156123	14133K	PARTICIPANT	\N	PRESENT	0
156459	156455	14239U	PARTICIPANT	\N	PRESENT	0
156131	156123	11039M	PARTICIPANT	\N	PRESENT	0
156132	156123	01044R	PARTICIPANT	\N	PRESENT	0
156133	156123	08043V	PARTICIPANT	\N	EXCUSE	0
156134	156123	14089Y	PARTICIPANT	\N	PRESENT	0
156135	156123	14105F	PARTICIPANT	\N	PRESENT	0
156136	156123	11029K	PARTICIPANT	\N	PRESENT	0
156137	156123	95015C	PARTICIPANT	\N	PRESENT	0
156138	156123	92015P	PARTICIPANT	\N	EXCUSE	0
156139	156123	08024S	PARTICIPANT	\N	PRESENT	0
156140	156123	14201E	PARTICIPANT	\N	PRESENT	0
156461	156455	01046T	PARTICIPANT	\N	PRESENT	0
156142	156123	14209N	PARTICIPANT	\N	PRESENT	0
156143	156123	14079W	PARTICIPANT	\N	PRESENT	0
156462	156455	04053F	PARTICIPANT	\N	PRESENT	0
156463	156455	14255U	PARTICIPANT	\N	PRESENT	0
156147	156123	14249W	PARTICIPANT	\N	PRESENT	0
156465	156455	00003C	PARTICIPANT	\N	EXCUSE	0
156466	156455	14053L	PARTICIPANT	\N	PRESENT	0
156467	156455	11103C	PARTICIPANT	\N	PRESENT	0
156152	156123	11089X	PARTICIPANT	\N	PRESENT	0
156153	156123	07026Q	PARTICIPANT	\N	PRESENT	0
156154	156123	14123H	PARTICIPANT	\N	PRESENT	0
156155	156123	14179A	PARTICIPANT	\N	PRESENT	0
156469	156455	14195A	PARTICIPANT	\N	EXCUSE	0
156157	156123	14241N	PARTICIPANT	\N	PRESENT	0
156158	156123	14061L	PARTICIPANT	\N	PRESENT	0
156159	156123	14073Q	PARTICIPANT	\N	PRESENT	0
156160	156123	08031R	PARTICIPANT	\N	PRESENT	0
156470	156455	14267Y	PARTICIPANT	\N	PRESENT	0
156162	156123	08039A	PARTICIPANT	\N	PRESENT	0
156163	156123	08017T	PARTICIPANT	\N	PRESENT	0
156165	156123	08012N	PARTICIPANT	\N	PRESENT	0
156472	156455	11031D	PARTICIPANT	\N	PRESENT	0
156473	156455	08052W	PARTICIPANT	\N	PRESENT	0
156168	156123	14063N	PARTICIPANT	\N	PRESENT	0
156169	156123	04057K	PARTICIPANT	\N	PRESENT	0
156500	156455	14223L	PARTICIPANT	\N	PRESENT	0
156171	156123	14109K	PARTICIPANT	\N	EXCUSE	0
156172	156123	04070G	PRESIDENT	0	PRESENT	0
156474	156455	01059Y	PARTICIPANT	\N	PRESENT	0
156475	156455	04081K	PARTICIPANT	\N	PRESENT	0
156175	156123	83047W	PARTICIPANT	\N	PRESENT	0
156176	156123	14235Q	PARTICIPANT	\N	EXCUSE	0
156476	156455	98024R	PARTICIPANT	\N	PRESENT	0
156178	156123	04033B	PARTICIPANT	\N	PRESENT	0
156478	156455	04067M	PARTICIPANT	\N	PRESENT	0
156181	156123	11071M	PARTICIPANT	\N	PRESENT	0
156480	156455	14042U	PARTICIPANT	\N	PRESENT	0
156481	156455	14151M	PARTICIPANT	\N	PRESENT	0
156482	156455	12042Y	PARTICIPANT	\N	EXCUSE	0
156483	156455	14281W	PARTICIPANT	\N	PRESENT	0
156484	156455	14087W	PARTICIPANT	\N	PRESENT	0
156486	156455	14034U	PARTICIPANT	\N	PRESENT	0
156487	156455	14231L	PARTICIPANT	\N	PRESENT	0
156488	156455	11061K	PARTICIPANT	\N	PRESENT	0
156489	156455	14355X	PARTICIPANT	\N	EXCUSE	0
156492	156455	01011G	PARTICIPANT	\N	PRESENT	0
156494	156455	14213J	PARTICIPANT	\N	PRESENT	0
156495	156455	14121F	PARTICIPANT	\N	PRESENT	0
156496	156455	11112D	PARTICIPANT	\N	PRESENT	0
156497	156455	14037X	PARTICIPANT	\N	PRESENT	0
156498	156455	14018U	PARTICIPANT	\N	PRESENT	0
156499	156455	11067R	PARTICIPANT	\N	PRESENT	0
142870	142868	04040A	PARTICIPANT	\N	PRESENT	0
142871	142868	11083R	PARTICIPANT	\N	PRESENT	0
142872	142868	07024N	PARTICIPANT	\N	EXCUSE	0
142873	142868	14014Q	PARTICIPANT	\N	EXCUSE	0
142874	142868	98022P	PARTICIPANT	\N	PRESENT	0
142875	142868	14073Q	PARTICIPANT	\N	PRESENT	0
142876	142868	83042R	PRESIDENT	1	PRESENT	0
142877	142868	14001X	PARTICIPANT	\N	PRESENT	0
142878	142868	04057K	PARTICIPANT	\N	EXCUSE	0
142879	142868	95059Q	PARTICIPANT	\N	EXCUSE	0
142880	142868	98035U	PARTICIPANT	\N	PRESENT	0
142881	142868	04034C	PARTICIPANT	\N	PRESENT	0
142993	142894	92039X	PARTICIPANT	\N	PRESENT	0
142938	142936	11055M	PARTICIPANT	\N	PRESENT	0
142939	142936	01046T	PARTICIPANT	\N	PRESENT	0
142940	142936	04053F	PARTICIPANT	\N	PRESENT	0
142941	142936	14255U	PARTICIPANT	\N	PRESENT	0
142942	142936	04066L	PARTICIPANT	\N	PRESENT	0
142943	142936	00003C	PARTICIPANT	\N	EXCUSE	0
142944	142936	14053L	PARTICIPANT	\N	PRESENT	0
142945	142936	11103C	PARTICIPANT	\N	PRESENT	0
142946	142936	11044J	PARTICIPANT	\N	PRESENT	0
142947	142936	14195A	PARTICIPANT	\N	PRESENT	0
142948	142936	14267Y	PARTICIPANT	\N	PRESENT	0
142949	142936	11023D	PARTICIPANT	\N	PRESENT	0
142950	142936	11031D	PARTICIPANT	\N	PRESENT	0
142951	142936	08052W	PARTICIPANT	\N	PRESENT	0
142952	142936	01059Y	PARTICIPANT	\N	PRESENT	0
142953	142936	04081K	PARTICIPANT	\N	PRESENT	0
142954	142936	98024R	PARTICIPANT	\N	PRESENT	0
143012	125635	11082Q	PARTICIPANT	\N	EXCUSE	0
142956	142936	04067M	PARTICIPANT	\N	PRESENT	0
142957	142936	14217N	PARTICIPANT	\N	PRESENT	0
142958	142936	14042U	PARTICIPANT	\N	PRESENT	0
142959	142936	14151M	PARTICIPANT	\N	PRESENT	0
142960	142936	12042Y	PARTICIPANT	\N	PRESENT	0
142961	142936	14281W	PARTICIPANT	\N	PRESENT	0
142962	142936	14087W	PARTICIPANT	\N	PRESENT	0
142963	142936	01003G	PARTICIPANT	\N	PRESENT	0
142964	142936	14034U	PARTICIPANT	\N	PRESENT	0
142965	142936	14231L	PARTICIPANT	\N	EXCUSE	0
142966	142936	11061K	PARTICIPANT	\N	PRESENT	0
143053	143052	89017R	PARTICIPANT	\N	PRESENT	0
142968	142936	08041T	PARTICIPANT	\N	PRESENT	0
142969	142936	01011G	PARTICIPANT	\N	PRESENT	0
142970	142936	14026U	PARTICIPANT	\N	PRESENT	0
142971	142936	14213J	PARTICIPANT	\N	PRESENT	0
142972	142936	14121F	PARTICIPANT	\N	PRESENT	0
142973	142936	11112D	PARTICIPANT	\N	PRESENT	0
142974	142936	14037X	PARTICIPANT	\N	PRESENT	0
142975	142936	14018U	PARTICIPANT	\N	PRESENT	0
142976	142936	11067R	PARTICIPANT	\N	EXCUSE	0
142977	142936	14223L	PARTICIPANT	\N	PRESENT	0
142978	142936	04092N	PRESIDENT	0	PRESENT	0
142979	142936	14265W	PARTICIPANT	\N	PRESENT	0
142980	142936	14119M	PARTICIPANT	\N	PRESENT	0
142981	142936	14071N	PARTICIPANT	\N	PRESENT	0
142982	142936	04043D	PARTICIPANT	\N	PRESENT	0
142983	142936	14271U	PARTICIPANT	\N	PRESENT	0
142984	142936	14017T	PARTICIPANT	\N	PRESENT	0
142985	142936	11093T	PARTICIPANT	\N	PRESENT	0
142986	142936	11097X	PARTICIPANT	\N	PRESENT	0
142987	142936	04045F	PARTICIPANT	\N	PRESENT	0
142988	142936	14227Q	PARTICIPANT	\N	PRESENT	0
142989	142936	01034P	PARTICIPANT	\N	PRESENT	0
142990	142936	11025F	PARTICIPANT	\N	PRESENT	0
142991	142936	11063M	PARTICIPANT	\N	PRESENT	0
142992	142936	14269B	PARTICIPANT	\N	PRESENT	0
143054	143052	01031L	PRESIDENT	0	PRESENT	0
143055	143052	05004A	PARTICIPANT	\N	PRESENT	0
143056	143052	01013J	PARTICIPANT	\N	PRESENT	0
143057	143052	11040E	PARTICIPANT	\N	PRESENT	0
143058	143052	08014Q	PARTICIPANT	\N	PRESENT	0
143059	143052	14167V	PARTICIPANT	\N	PRESENT	0
143060	143052	14175V	PARTICIPANT	\N	PRESENT	0
143061	143052	14083S	PARTICIPANT	\N	PRESENT	0
143062	143052	11053K	PARTICIPANT	\N	PRESENT	0
143063	143052	14085U	PARTICIPANT	\N	PRESENT	0
143064	143052	11042G	PARTICIPANT	\N	PRESENT	0
143065	143052	88008L	PARTICIPANT	\N	PRESENT	0
143066	143052	04086Q	PARTICIPANT	\N	PRESENT	0
143067	143052	11070L	PARTICIPANT	\N	PRESENT	0
143068	143052	11088W	PARTICIPANT	\N	PRESENT	0
143069	143052	14327T	PARTICIPANT	\N	PRESENT	0
143070	143052	08022Q	PARTICIPANT	\N	PRESENT	0
143071	143052	01027Q	PARTICIPANT	\N	PRESENT	0
143072	143052	04071H	PARTICIPANT	\N	PRESENT	0
143073	143052	11074Q	PARTICIPANT	\N	PRESENT	0
143074	143052	98053W	PARTICIPANT	\N	PRESENT	0
143075	143052	11083R	PARTICIPANT	\N	PRESENT	0
143076	143052	14199E	PARTICIPANT	\N	PRESENT	0
143077	143052	01057W	PARTICIPANT	\N	PRESENT	0
143078	143052	08016S	PARTICIPANT	\N	PRESENT	0
143079	143052	08069G	PARTICIPANT	\N	PRESENT	0
143080	143052	11048N	PARTICIPANT	\N	PRESENT	0
143081	143052	99004R	PARTICIPANT	\N	PRESENT	0
143082	143052	04061F	PARTICIPANT	\N	PRESENT	0
143083	143052	14159V	PARTICIPANT	\N	PRESENT	0
143084	143052	07029T	PARTICIPANT	\N	PRESENT	0
143085	143052	14277B	PARTICIPANT	\N	PRESENT	0
143086	143052	08010L	PARTICIPANT	\N	PRESENT	0
143087	143052	08034U	PARTICIPANT	\N	PRESENT	0
143088	143052	01048V	PARTICIPANT	\N	PRESENT	0
143089	143052	98046X	PARTICIPANT	\N	PRESENT	0
143090	143052	11085T	PARTICIPANT	\N	PRESENT	0
143091	143052	08011M	PARTICIPANT	\N	PRESENT	0
143092	143052	08073C	PARTICIPANT	\N	PRESENT	0
143093	143052	01016M	PARTICIPANT	\N	PRESENT	0
143094	143052	14225N	PARTICIPANT	\N	PRESENT	0
143095	143052	11012A	PARTICIPANT	\N	PRESENT	0
143096	143052	11057P	PARTICIPANT	\N	PRESENT	0
143097	143052	14173T	PARTICIPANT	\N	PRESENT	0
143098	143052	04034C	PARTICIPANT	\N	PRESENT	0
143099	143052	14119M	RAPPORTEUR_AVIS	\N	PRESENT	0
143100	143052	95015C	RAPPORTEUR_AVIS	\N	PRESENT	0
143738	143736	14133K	PARTICIPANT	\N	PRESENT	0
143739	143736	11109J	PARTICIPANT	\N	PRESENT	0
143740	143736	04059M	PARTICIPANT	\N	PRESENT	0
143743	143736	08043V	PARTICIPANT	\N	PRESENT	0
143744	143736	14089Y	PARTICIPANT	\N	PRESENT	0
143745	143736	14105F	PARTICIPANT	\N	PRESENT	0
143746	143736	11029K	PARTICIPANT	\N	PRESENT	0
143747	143736	95015C	PARTICIPANT	\N	PRESENT	0
143748	143736	92015P	PARTICIPANT	\N	PRESENT	0
143749	143736	08024S	PARTICIPANT	\N	PRESENT	0
143750	143736	14201E	PARTICIPANT	\N	EXCUSE	0
143752	143736	14209N	PARTICIPANT	\N	PRESENT	0
143753	143736	14079W	PARTICIPANT	\N	PRESENT	0
143754	143736	11091R	PARTICIPANT	\N	PRESENT	0
143757	143736	14249W	PARTICIPANT	\N	EXCUSE	0
143758	143736	01041N	PARTICIPANT	\N	PRESENT	0
143759	143736	01025N	PARTICIPANT	\N	PRESENT	0
143760	143736	01037S	PARTICIPANT	\N	PRESENT	0
143764	143736	07026Q	PARTICIPANT	\N	PRESENT	0
143765	143736	14123H	PARTICIPANT	\N	PRESENT	0
143769	143736	14061L	PARTICIPANT	\N	PRESENT	0
143770	143736	14073Q	PARTICIPANT	\N	PRESENT	0
143771	143736	08031R	PARTICIPANT	\N	EXCUSE	0
143773	143736	08039A	PARTICIPANT	\N	PRESENT	0
143774	143736	08017T	PARTICIPANT	\N	PRESENT	0
143775	143736	14059S	PARTICIPANT	\N	EXCUSE	0
143778	143736	11104D	PARTICIPANT	\N	PRESENT	0
143779	143736	14063N	PARTICIPANT	\N	PRESENT	0
143780	143736	04057K	PRESIDENT	0	PRESENT	0
143781	143736	11014C	PARTICIPANT	\N	PRESENT	0
143783	143736	04070G	PRESIDENT	1	PRESENT	0
143787	143736	14235Q	PARTICIPANT	\N	PRESENT	0
143788	143736	14055N	PARTICIPANT	\N	PRESENT	0
135743	135574	14259Y	PARTICIPANT	\N	PRESENT	0
135744	135574	12041X	PARTICIPANT	\N	PRESENT	0
135745	135574	07026Q	PARTICIPANT	\N	PRESENT	0
135746	135574	11034G	PARTICIPANT	\N	PRESENT	0
135747	135574	04079R	PARTICIPANT	\N	PRESENT	0
135748	135574	11066Q	PARTICIPANT	\N	PRESENT	0
135749	135574	04080J	PARTICIPANT	\N	PRESENT	0
135750	135574	14073Q	PARTICIPANT	\N	PRESENT	0
135751	135574	14263U	PARTICIPANT	\N	PRESENT	0
135752	135574	14119M	PARTICIPANT	\N	PRESENT	0
135753	135574	11080N	PARTICIPANT	\N	PRESENT	0
135755	135574	95031C	PARTICIPANT	\N	PRESENT	0
135757	135574	95015C	PARTICIPANT	\N	PRESENT	0
135758	135574	07024N	PARTICIPANT	\N	PRESENT	0
135759	135574	04059M	PARTICIPANT	\N	PRESENT	0
135775	135574	08019V	PARTICIPANT	\N	PRESENT	0
135761	135574	14105F	PARTICIPANT	\N	PRESENT	0
135762	135574	04038G	PARTICIPANT	\N	PRESENT	0
135763	135574	04086Q	PARTICIPANT	\N	PRESENT	0
135764	135574	14135M	PARTICIPANT	\N	PRESENT	0
135765	135574	04097T	PARTICIPANT	\N	PRESENT	0
135766	135574	04071H	PARTICIPANT	\N	PRESENT	0
135767	135574	08048B	PARTICIPANT	\N	PRESENT	0
135768	135574	95035G	PARTICIPANT	\N	PRESENT	0
135770	135574	11036J	PARTICIPANT	\N	PRESENT	0
135772	135574	14026U	PARTICIPANT	\N	PRESENT	0
135773	135574	01003G	PARTICIPANT	\N	PRESENT	0
135774	135574	14061L	PARTICIPANT	\N	PRESENT	0
135776	135574	11011M	PARTICIPANT	\N	PRESENT	0
135777	135574	14223L	PARTICIPANT	\N	PRESENT	0
135778	135574	14147R	PARTICIPANT	\N	PRESENT	0
135779	135574	99004R	PARTICIPANT	\N	PRESENT	0
135780	135574	14267Y	PARTICIPANT	\N	PRESENT	0
135781	135574	11029K	PARTICIPANT	\N	PRESENT	0
135782	135574	04044E	PARTICIPANT	\N	PRESENT	0
135783	135574	95063L	PARTICIPANT	\N	PRESENT	0
135788	135574	95049N	PARTICIPANT	\N	PRESENT	0
135789	135574	95041E	PARTICIPANT	\N	PRESENT	0
135790	135574	08056B	PARTICIPANT	\N	PRESENT	0
135795	135574	11033F	PARTICIPANT	\N	PRESENT	0
135796	135574	08060W	PARTICIPANT	\N	PRESENT	0
135797	135574	14199E	PARTICIPANT	\N	PRESENT	0
135798	135574	01025N	PARTICIPANT	\N	PRESENT	0
135799	135574	08062Y	PARTICIPANT	\N	PRESENT	0
135800	135574	04056J	PARTICIPANT	\N	PRESENT	0
135801	135574	14211G	PARTICIPANT	\N	PRESENT	0
135802	135574	11043H	PARTICIPANT	\N	PRESENT	0
135803	135574	14217N	PARTICIPANT	\N	PRESENT	0
135804	135574	04067M	PARTICIPANT	\N	PRESENT	0
135805	135574	11104D	PARTICIPANT	\N	PRESENT	0
135806	135574	14111D	PARTICIPANT	\N	PRESENT	0
135807	135574	08015R	PARTICIPANT	\N	PRESENT	0
135808	135574	11054L	PARTICIPANT	\N	PRESENT	0
135809	135574	14014Q	PARTICIPANT	\N	PRESENT	0
135810	135574	14079W	PARTICIPANT	\N	PRESENT	0
135811	135574	11103C	PARTICIPANT	\N	PRESENT	0
135812	135574	87003B	PARTICIPANT	\N	PRESENT	0
135813	135574	95062K	PARTICIPANT	\N	PRESENT	0
135814	135574	14229S	PARTICIPANT	\N	PRESENT	0
135815	135574	11085T	PARTICIPANT	\N	PRESENT	0
135816	135574	04081K	PARTICIPANT	\N	PRESENT	0
135817	135574	14271U	PARTICIPANT	\N	PRESENT	0
135818	135574	88008L	PARTICIPANT	\N	PRESENT	0
135819	135574	14269B	PARTICIPANT	\N	PRESENT	0
135820	135574	14109K	PARTICIPANT	\N	PRESENT	0
135821	135574	14069U	PARTICIPANT	\N	PRESENT	0
135822	135574	14213J	PARTICIPANT	\N	PRESENT	0
135823	135574	11081P	PARTICIPANT	\N	PRESENT	0
135824	135574	95059Q	PARTICIPANT	\N	PRESENT	0
135825	135574	07032N	PARTICIPANT	\N	PRESENT	0
135826	135574	01057W	PARTICIPANT	\N	PRESENT	0
135827	135574	11101A	PARTICIPANT	\N	PRESENT	0
135828	135574	14219Q	PARTICIPANT	\N	PRESENT	0
135829	135574	08068F	PARTICIPANT	\N	PRESENT	0
135832	135574	14063N	PARTICIPANT	\N	PRESENT	0
135835	135574	08069G	PARTICIPANT	\N	PRESENT	0
135836	135574	07034Q	PARTICIPANT	\N	PRESENT	0
135837	135574	14031R	PARTICIPANT	\N	PRESENT	0
135838	135574	01027Q	PARTICIPANT	\N	PRESENT	0
135839	135574	11053K	PARTICIPANT	\N	PRESENT	0
135840	135574	01048V	PARTICIPANT	\N	PRESENT	0
135841	135574	14173T	PARTICIPANT	\N	PRESENT	0
135845	135574	08051V	PARTICIPANT	\N	PRESENT	0
135846	135574	80027E	PARTICIPANT	\N	PRESENT	0
135847	135574	14215L	PARTICIPANT	\N	PRESENT	0
135852	135574	08043V	PARTICIPANT	\N	PRESENT	0
135854	135574	01022K	PARTICIPANT	\N	PRESENT	0
135855	135574	14001X	PARTICIPANT	\N	PRESENT	0
135856	135574	14175V	PARTICIPANT	\N	PRESENT	0
135857	135574	14331P	PARTICIPANT	\N	PRESENT	0
135858	135574	14157T	PARTICIPANT	\N	PRESENT	0
135859	135574	14121F	PARTICIPANT	\N	PRESENT	0
135860	135574	11083R	PARTICIPANT	\N	PRESENT	0
135861	135574	08041T	PARTICIPANT	\N	PRESENT	0
135862	135574	04050C	PARTICIPANT	\N	PRESENT	0
135863	135574	04085P	PARTICIPANT	\N	PRESENT	0
135864	135574	14030Q	PARTICIPANT	\N	PRESENT	0
135865	135574	80013X	PARTICIPANT	\N	PRESENT	0
135866	135574	04041B	PARTICIPANT	\N	PRESENT	0
135876	135574	14097Y	PARTICIPANT	\N	PRESENT	0
135877	135574	11042G	PARTICIPANT	\N	PRESENT	0
135879	135574	01061S	PARTICIPANT	\N	PRESENT	0
135880	135574	11088W	PARTICIPANT	\N	PRESENT	0
135881	135574	14237S	PARTICIPANT	\N	PRESENT	0
135884	135574	04055H	PARTICIPANT	\N	PRESENT	0
135885	135574	11049P	PARTICIPANT	\N	PRESENT	0
135886	135574	01060R	PARTICIPANT	\N	PRESENT	0
135887	135574	08016S	PARTICIPANT	\N	PRESENT	0
135888	135574	14281W	PARTICIPANT	\N	PRESENT	0
135889	135574	14089Y	PARTICIPANT	\N	PRESENT	0
135891	135574	11059R	PARTICIPANT	\N	PRESENT	0
135892	135574	08021P	PARTICIPANT	\N	PRESENT	0
135893	135574	14277B	PARTICIPANT	\N	PRESENT	0
135894	135574	14123H	PARTICIPANT	\N	PRESENT	0
135895	135574	14187A	PARTICIPANT	\N	PRESENT	0
136086	135575	14097Y	PARTICIPANT	\N	PRESENT	0
136057	135575	14199E	PARTICIPANT	\N	PRESENT	0
136058	135575	08019V	PARTICIPANT	\N	PRESENT	0
136059	135575	04074L	PARTICIPANT	\N	PRESENT	0
136060	135575	11088W	PARTICIPANT	\N	PRESENT	0
136061	135575	11010L	PARTICIPANT	\N	PRESENT	0
136062	135575	11101A	PARTICIPANT	\N	PRESENT	0
136063	135575	01061S	PARTICIPANT	\N	PRESENT	0
136064	135575	04041B	PARTICIPANT	\N	PRESENT	0
136065	135575	04097T	PARTICIPANT	\N	PRESENT	0
136066	135575	95062K	PARTICIPANT	\N	PRESENT	0
136067	135575	95031C	PARTICIPANT	\N	PRESENT	0
136068	135575	14223L	PARTICIPANT	\N	PRESENT	0
136069	135575	08041T	PARTICIPANT	\N	PRESENT	0
136070	135575	04049K	PARTICIPANT	\N	PRESENT	0
136071	135575	14147R	PARTICIPANT	\N	PRESENT	0
136072	135575	08048B	PARTICIPANT	\N	PRESENT	0
136073	135575	98024R	PARTICIPANT	\N	PRESENT	0
136074	135575	92018S	PARTICIPANT	\N	PRESENT	0
136075	135575	11103C	PARTICIPANT	\N	PRESENT	0
136076	135575	12041X	PARTICIPANT	\N	PRESENT	0
136077	135575	04050C	PARTICIPANT	\N	PRESENT	0
136078	135575	08062Y	PARTICIPANT	\N	PRESENT	0
136079	135575	07026Q	PARTICIPANT	\N	PRESENT	0
136080	135575	14175V	PARTICIPANT	\N	PRESENT	0
136081	135575	14167V	PARTICIPANT	\N	PRESENT	0
136082	135575	08028W	PARTICIPANT	\N	PRESENT	0
136083	135575	08035V	PARTICIPANT	\N	PRESENT	0
136084	135575	89029V	PARTICIPANT	\N	PRESENT	0
136085	135575	10006L	PARTICIPANT	\N	PRESENT	0
136087	135575	95041E	PARTICIPANT	\N	PRESENT	0
136088	135575	14107H	PARTICIPANT	\N	PRESENT	0
136089	135575	14135M	PARTICIPANT	\N	PRESENT	0
136090	135575	14197C	PARTICIPANT	\N	PRESENT	0
136091	135575	11100Y	PARTICIPANT	\N	PRESENT	0
136092	135575	01022K	PARTICIPANT	\N	PRESENT	0
136093	135575	08025T	PARTICIPANT	\N	PRESENT	0
136094	135575	11097X	PARTICIPANT	\N	PRESENT	0
136095	135575	08016S	PARTICIPANT	\N	PRESENT	0
136096	135575	01016M	PARTICIPANT	\N	PRESENT	0
136097	135575	14195A	PARTICIPANT	\N	PRESENT	0
136098	135575	04054G	PARTICIPANT	\N	PRESENT	0
136099	135575	14105F	PARTICIPANT	\N	PRESENT	0
136100	135575	14215L	PARTICIPANT	\N	PRESENT	0
136101	135575	14263U	PARTICIPANT	\N	PRESENT	0
136102	135575	14013P	PARTICIPANT	\N	PRESENT	0
136103	135575	14051J	PARTICIPANT	\N	PRESENT	0
136104	135575	14237S	PARTICIPANT	\N	PRESENT	0
136105	135575	11104D	PARTICIPANT	\N	PRESENT	0
136106	135575	14217N	PARTICIPANT	\N	PRESENT	0
136107	135575	92015P	PARTICIPANT	\N	PRESENT	0
136108	135575	04043D	PARTICIPANT	\N	PRESENT	0
136109	135575	11057P	PARTICIPANT	\N	PRESENT	0
144223	144212	14175V	PARTICIPANT	\N	PRESENT	0
144224	144212	14083S	PARTICIPANT	\N	PRESENT	0
144225	144212	11053K	PARTICIPANT	\N	PRESENT	0
144226	144212	14085U	PARTICIPANT	\N	PRESENT	0
144227	144212	11042G	PARTICIPANT	\N	PRESENT	0
144493	141030	08039A	PARTICIPANT	\N	PRESENT	0
144229	144212	04086Q	PARTICIPANT	\N	PRESENT	0
144465	144464	04040A	PARTICIPANT	\N	PRESENT	0
144231	144212	11070L	PARTICIPANT	\N	PRESENT	0
144232	144212	11088W	PARTICIPANT	\N	PRESENT	0
144233	144212	14327T	PARTICIPANT	\N	PRESENT	0
144466	144464	11032E	PARTICIPANT	\N	PRESENT	0
144235	144212	01027Q	PARTICIPANT	\N	EXCUSE	0
144236	144212	04071H	PARTICIPANT	\N	PRESENT	0
144237	144212	11074Q	PARTICIPANT	\N	PRESENT	0
144239	144212	11083R	PARTICIPANT	\N	PRESENT	0
144241	144212	01057W	PARTICIPANT	\N	PRESENT	0
144242	144212	08016S	PARTICIPANT	\N	PRESENT	0
144245	144212	99004R	PARTICIPANT	\N	PRESENT	0
144247	144212	14159V	PARTICIPANT	\N	PRESENT	0
144248	144212	07029T	PARTICIPANT	\N	PRESENT	0
144250	144212	08010L	PARTICIPANT	\N	PRESENT	0
144251	144212	08034U	PARTICIPANT	\N	PRESENT	0
144252	144212	01048V	PARTICIPANT	\N	PRESENT	0
144253	144212	98046X	PARTICIPANT	\N	PRESENT	0
144255	144212	08011M	PARTICIPANT	\N	PRESENT	0
144257	144212	08061X	PARTICIPANT	\N	EXCUSE	0
144258	144212	01016M	PARTICIPANT	\N	PRESENT	0
144259	144212	14225N	PARTICIPANT	\N	PRESENT	0
144261	144212	11057P	PARTICIPANT	\N	PRESENT	0
144263	144212	04034C	PARTICIPANT	\N	PRESENT	0
144730	144729	14237S	PARTICIPANT	\N	PRESENT	0
144726	144725	14237S	PARTICIPANT	\N	PRESENT	0
144732	144731	14237S	PARTICIPANT	\N	PRESENT	0
144734	144733	14237S	PARTICIPANT	\N	PRESENT	0
144736	144735	14237S	PARTICIPANT	\N	PRESENT	0
144741	144740	14237S	PARTICIPANT	\N	PRESENT	0
144743	144742	14237S	PARTICIPANT	\N	PRESENT	0
144953	144952	98029W	PARTICIPANT	\N	PRESENT	0
144954	144952	14249W	PARTICIPANT	\N	PRESENT	0
145324	145322	80013X	PARTICIPANT	\N	PRESENT	0
145325	145322	11090Q	PARTICIPANT	\N	PRESENT	0
145326	145322	09001P	PARTICIPANT	\N	PRESENT	0
145327	145322	01008M	PARTICIPANT	\N	PRESENT	0
145328	145322	08049C	PARTICIPANT	\N	PRESENT	0
145329	145322	11065P	PARTICIPANT	\N	PRESENT	0
145330	145322	01056V	PARTICIPANT	\N	PRESENT	0
145331	145322	14033T	PARTICIPANT	\N	PRESENT	0
145332	145322	01015L	PARTICIPANT	\N	PRESENT	0
145333	145322	11048N	PARTICIPANT	\N	PRESENT	0
145334	145322	90003B	PARTICIPANT	\N	PRESENT	0
145335	145322	13002U	PARTICIPANT	\N	PRESENT	0
145336	145322	14219Q	PARTICIPANT	\N	EXCUSE	0
145337	145322	05012A	PARTICIPANT	\N	EXCUSE	0
145339	145322	14093U	PARTICIPANT	\N	EXCUSE	0
145341	145322	92045V	PARTICIPANT	\N	EXCUSE	0
145453	145452	14042U	PARTICIPANT	\N	PRESENT	0
145454	145452	14231L	PARTICIPANT	\N	PRESENT	0
145455	145452	14271U	PARTICIPANT	\N	PRESENT	0
145733	145732	14263U	PARTICIPANT	\N	EXCUSE	0
145734	145732	14133K	PARTICIPANT	\N	PRESENT	0
145735	145732	11109J	PARTICIPANT	\N	PRESENT	0
145736	145732	04059M	PARTICIPANT	\N	PRESENT	0
145738	145732	01044R	PARTICIPANT	\N	PRESENT	0
145739	145732	08043V	PARTICIPANT	\N	EXCUSE	0
145741	145732	14105F	PARTICIPANT	\N	PRESENT	0
145742	145732	11029K	PARTICIPANT	\N	PRESENT	0
145744	145732	92015P	PARTICIPANT	\N	PRESENT	0
145745	145732	08024S	PARTICIPANT	\N	PRESENT	0
145746	145732	14201E	PARTICIPANT	\N	PRESENT	0
145747	145732	14329V	PARTICIPANT	\N	PRESENT	0
145748	145732	14209N	PARTICIPANT	\N	PRESENT	0
145749	145732	14079W	PARTICIPANT	\N	PRESENT	0
145750	145732	11091R	PARTICIPANT	\N	EXCUSE	0
145751	145732	87003B	PARTICIPANT	\N	PRESENT	0
145752	145732	98042T	PARTICIPANT	\N	EXCUSE	0
145753	145732	14249W	PARTICIPANT	\N	PRESENT	0
145754	145732	01041N	PARTICIPANT	\N	PRESENT	0
145755	145732	01025N	PARTICIPANT	\N	EXCUSE	0
145757	145732	89029V	PARTICIPANT	\N	PRESENT	0
145758	145732	08035V	PARTICIPANT	\N	PRESENT	0
145759	145732	11089X	PARTICIPANT	\N	PRESENT	0
145760	145732	07026Q	PARTICIPANT	\N	PRESENT	0
145761	145732	14123H	PARTICIPANT	\N	PRESENT	0
145764	145732	14241N	PARTICIPANT	\N	PRESENT	0
145765	145732	14061L	PARTICIPANT	\N	PRESENT	0
145766	145732	14073Q	PARTICIPANT	\N	PRESENT	0
145767	145732	08031R	PARTICIPANT	\N	PRESENT	0
145768	145732	12041X	PARTICIPANT	\N	EXCUSE	0
145769	145732	08039A	PARTICIPANT	\N	PRESENT	0
145770	145732	08017T	PARTICIPANT	\N	PRESENT	0
145771	145732	14059S	PARTICIPANT	\N	PRESENT	0
145774	145732	11104D	PARTICIPANT	\N	PRESENT	0
145775	145732	14063N	PARTICIPANT	\N	PRESENT	0
145776	145732	04057K	PARTICIPANT	\N	PRESENT	0
145777	145732	11014C	PARTICIPANT	\N	PRESENT	0
145779	145732	04070G	PRESIDENT	0	PRESENT	0
145780	145732	92040Q	PARTICIPANT	\N	PRESENT	0
145781	145732	14191V	PARTICIPANT	\N	PRESENT	0
145782	145732	83047W	PARTICIPANT	\N	PRESENT	0
145783	145732	14235Q	PARTICIPANT	\N	EXCUSE	0
145784	145732	14055N	PARTICIPANT	\N	PRESENT	0
145785	145732	04033B	PARTICIPANT	\N	PRESENT	0
145786	145732	14229S	PARTICIPANT	\N	PRESENT	0
129511	122723	11063M	PARTICIPANT	\N	PRESENT	0
130140	130139	14030Q	PARTICIPANT	\N	PRESENT	0
130141	130139	08043V	PARTICIPANT	\N	PRESENT	0
130142	130139	11029K	PARTICIPANT	\N	PRESENT	0
130143	130139	11031D	PARTICIPANT	\N	PRESENT	0
130144	130139	14217N	PARTICIPANT	\N	PRESENT	0
130145	130139	14281W	PARTICIPANT	\N	PRESENT	0
130146	130139	11061K	PARTICIPANT	\N	PRESENT	0
130147	130139	14014Q	PARTICIPANT	\N	PRESENT	0
130148	130139	07026Q	PARTICIPANT	\N	PRESENT	0
130149	130139	09001P	PRESIDENT	0	PRESENT	0
130150	130139	04036E	PARTICIPANT	\N	PRESENT	0
130151	130139	08031R	PARTICIPANT	\N	PRESENT	0
130152	130139	14031R	PARTICIPANT	\N	PRESENT	0
130153	130139	08060W	PARTICIPANT	\N	EXCUSE	0
130154	130139	14038Y	PARTICIPANT	\N	EXCUSE	0
130155	130139	80013X	PARTICIPANT	\N	EXCUSE	0
130156	130139	14041T	PARTICIPANT	\N	EXCUSE	0
130157	130139	95035G	PARTICIPANT	\N	EXCUSE	0
130158	130139	07029T	PARTICIPANT	\N	EXCUSE	0
130159	130139	11067R	PARTICIPANT	\N	EXCUSE	0
130160	130139	11014C	PARTICIPANT	\N	EXCUSE	0
130161	130139	14237S	PARTICIPANT	\N	EXCUSE	0
130252	130251	11033F	PARTICIPANT	\N	PRESENT	0
130257	130256	11033F	PARTICIPANT	\N	PRESENT	0
130258	130256	01028R	PARTICIPANT	\N	PRESENT	0
130412	130411	01024M	PARTICIPANT	\N	PRESENT	0
130371	130368	11036J	PARTICIPANT	\N	PRESENT	0
130816	130815	11039M	PARTICIPANT	\N	PRESENT	0
130373	130368	14013P	PARTICIPANT	\N	PRESENT	0
130374	130368	08068F	PARTICIPANT	\N	PRESENT	0
130375	130368	14207L	PARTICIPANT	\N	PRESENT	0
130817	130815	01019Q	PARTICIPANT	\N	PRESENT	0
130377	130368	90003B	PARTICIPANT	\N	EXCUSE	0
130378	130368	08028W	PARTICIPANT	\N	PRESENT	0
130379	130368	80013X	PARTICIPANT	\N	PRESENT	0
130380	130368	08038Y	PARTICIPANT	\N	PRESENT	0
130381	130368	04089T	PARTICIPANT	\N	EXCUSE	0
130949	130942	89017R	PARTICIPANT	\N	PRESENT	0
130951	130942	01031L	PRESIDENT	0	PRESENT	0
130384	130368	14187A	PARTICIPANT	\N	PRESENT	0
130385	130368	14033T	PARTICIPANT	\N	PRESENT	0
130386	130368	14081Q	PARTICIPANT	\N	PRESENT	0
130387	130368	04048J	PARTICIPANT	\N	EXCUSE	0
130388	130368	11099A	PARTICIPANT	\N	PRESENT	0
130389	130368	04049K	PARTICIPANT	\N	PRESENT	0
130957	130942	05004A	PARTICIPANT	\N	PRESENT	0
130391	130368	11111C	PARTICIPANT	\N	PRESENT	0
130392	130368	08015R	PARTICIPANT	\N	PRESENT	0
130393	130368	11100Y	PRESIDENT	0	PRESENT	0
130394	130368	01061S	PARTICIPANT	\N	EXCUSE	0
130395	130368	11098Y	PARTICIPANT	\N	PRESENT	0
130396	130368	01043Q	PARTICIPANT	\N	EXCUSE	0
130960	130942	01013J	PARTICIPANT	\N	EXCUSE	0
130964	130942	11068S	PARTICIPANT	\N	PRESENT	0
130966	130942	08014Q	PARTICIPANT	\N	EXCUSE	0
130968	130942	14167V	PARTICIPANT	\N	EXCUSE	0
130969	130942	14175V	PARTICIPANT	\N	PRESENT	0
130971	130942	14083S	PARTICIPANT	\N	PRESENT	0
130972	130942	11053K	PARTICIPANT	\N	PRESENT	0
130404	130368	11090Q	PARTICIPANT	\N	PRESENT	0
130975	130942	14085U	PARTICIPANT	\N	PRESENT	0
130406	130368	01058X	PARTICIPANT	\N	PRESENT	0
130407	130368	11094U	PARTICIPANT	\N	PRESENT	0
130408	130368	11066Q	PARTICIPANT	\N	PRESENT	0
130976	130942	11042G	PARTICIPANT	\N	PRESENT	0
130977	130942	04086Q	PARTICIPANT	\N	PRESENT	0
130978	130942	04055H	PARTICIPANT	\N	PRESENT	0
130979	130942	11070L	PARTICIPANT	\N	PRESENT	0
130980	130942	11088W	PARTICIPANT	\N	PRESENT	0
130981	130942	14327T	PARTICIPANT	\N	PRESENT	0
130982	130942	08022Q	PARTICIPANT	\N	PRESENT	0
130983	130942	01027Q	PARTICIPANT	\N	PRESENT	0
130984	130942	04071H	PARTICIPANT	\N	PRESENT	0
130985	130942	11074Q	PARTICIPANT	\N	PRESENT	0
130986	130942	98053W	PARTICIPANT	\N	PRESENT	0
130987	130942	11083R	PARTICIPANT	\N	PRESENT	0
130989	130942	14199E	PARTICIPANT	\N	PRESENT	0
130991	130942	01057W	PARTICIPANT	\N	PRESENT	0
130992	130942	08016S	PARTICIPANT	\N	PRESENT	0
130997	130942	08069G	PARTICIPANT	\N	PRESENT	0
130998	130942	11048N	PARTICIPANT	\N	PRESENT	0
130999	130942	99004R	PARTICIPANT	\N	PRESENT	0
131000	130942	04061F	PARTICIPANT	\N	PRESENT	0
131001	130942	14159V	PARTICIPANT	\N	PRESENT	0
131006	130942	01048V	PARTICIPANT	\N	PRESENT	0
131003	130942	07029T	PARTICIPANT	\N	PRESENT	0
131004	130942	08010L	PARTICIPANT	\N	PRESENT	0
131005	130942	08034U	PARTICIPANT	\N	PRESENT	0
131009	130942	98046X	PARTICIPANT	\N	PRESENT	0
131010	130942	11085T	PARTICIPANT	\N	PRESENT	0
131011	130942	08011M	PARTICIPANT	\N	PRESENT	0
131012	130942	08073C	PARTICIPANT	\N	PRESENT	0
131013	130942	08061X	PARTICIPANT	\N	PRESENT	0
131014	130942	01016M	PARTICIPANT	\N	EXCUSE	0
131015	130942	14225N	PARTICIPANT	\N	PRESENT	0
131016	130942	11012A	PARTICIPANT	\N	PRESENT	0
131017	130942	11057P	PARTICIPANT	\N	PRESENT	0
131018	130942	14173T	PARTICIPANT	\N	PRESENT	0
131019	130942	04034C	PARTICIPANT	\N	PRESENT	0
131020	130942	11026G	RAPPORTEUR_AVIS	\N	PRESENT	0
134393	134392	11032E	PARTICIPANT	\N	PRESENT	0
134394	134392	04040A	PARTICIPANT	\N	PRESENT	0
134512	133126	11068S	PARTICIPANT	\N	PRESENT	0
134513	133126	08060W	PARTICIPANT	\N	PRESENT	0
137959	137958	14239U	PARTICIPANT	\N	PRESENT	0
138067	137958	11067R	PARTICIPANT	\N	EXCUSE	0
145533	145532	11054L	PARTICIPANT	\N	PRESENT	0
137962	137958	04053F	PARTICIPANT	\N	PRESENT	0
145534	145532	01059Y	PARTICIPANT	\N	PRESENT	0
137964	137958	04066L	PARTICIPANT	\N	PRESENT	0
137965	137958	00003C	PARTICIPANT	\N	EXCUSE	0
137966	137958	14053L	PARTICIPANT	\N	PRESENT	0
137967	137958	11103C	PARTICIPANT	\N	PRESENT	0
145535	145532	11031D	PARTICIPANT	\N	PRESENT	0
137969	137958	14195A	PARTICIPANT	\N	PRESENT	0
145536	145532	95067Q	PARTICIPANT	\N	PRESENT	0
145537	145532	14013P	PARTICIPANT	\N	PRESENT	0
137972	137958	11031D	PARTICIPANT	\N	PRESENT	0
137973	137958	08052W	PARTICIPANT	\N	PRESENT	0
137974	137958	01059Y	PARTICIPANT	\N	EXCUSE	0
137975	137958	04081K	PARTICIPANT	\N	EXCUSE	0
137976	137958	98024R	PARTICIPANT	\N	PRESENT	0
137977	137958	10006L	PARTICIPANT	\N	PRESENT	0
145546	145545	08039A	PARTICIPANT	\N	PRESENT	0
145547	145545	11026G	PARTICIPANT	\N	PRESENT	0
137980	137958	14042U	PARTICIPANT	\N	PRESENT	0
137981	137958	14151M	PARTICIPANT	\N	PRESENT	0
137982	137958	12042Y	PARTICIPANT	\N	PRESENT	0
137983	137958	14281W	PARTICIPANT	\N	PRESENT	0
145548	145545	01008M	PARTICIPANT	\N	PRESENT	0
145549	145545	14079W	PARTICIPANT	\N	PRESENT	0
145550	145545	98050T	PARTICIPANT	\N	PRESENT	0
137987	137958	14231L	PARTICIPANT	\N	PRESENT	0
137988	137958	11061K	PARTICIPANT	\N	PRESENT	0
156501	156455	04092N	PRESIDENT	0	PRESENT	0
156502	156455	14265W	PARTICIPANT	\N	PRESENT	0
156503	156455	14119M	PARTICIPANT	\N	PRESENT	0
137992	137958	14026U	PARTICIPANT	\N	PRESENT	0
137993	137958	14213J	PARTICIPANT	\N	PRESENT	0
137994	137958	14121F	PARTICIPANT	\N	PRESENT	0
137995	137958	11112D	PARTICIPANT	\N	PRESENT	0
156504	156455	14071N	PARTICIPANT	\N	PRESENT	0
156505	156455	04043D	PARTICIPANT	\N	PRESENT	0
157012	156123	11091R	PARTICIPANT	\N	EXCUSE	0
156507	156455	14017T	PARTICIPANT	\N	EXCUSE	0
138000	137958	04092N	PRESIDENT	0	PRESENT	0
138001	137958	14265W	PARTICIPANT	\N	PRESENT	0
138002	137958	14119M	PARTICIPANT	\N	PRESENT	0
138003	137958	14071N	PARTICIPANT	\N	PRESENT	0
138004	137958	07032N	PARTICIPANT	\N	PRESENT	0
156508	156455	11093T	PARTICIPANT	\N	PRESENT	0
138006	137958	14271U	PARTICIPANT	\N	PRESENT	0
156509	156455	11097X	PARTICIPANT	\N	PRESENT	0
138008	137958	11093T	PARTICIPANT	\N	PRESENT	0
138009	137958	11097X	PARTICIPANT	\N	PRESENT	0
138010	137958	04045F	PARTICIPANT	\N	PRESENT	0
138011	137958	14227Q	PARTICIPANT	\N	PRESENT	0
138012	137958	01034P	PARTICIPANT	\N	PRESENT	0
157013	156123	01041N	PARTICIPANT	\N	EXCUSE	0
138014	137958	11063M	PARTICIPANT	\N	PRESENT	0
156511	156455	14227Q	PARTICIPANT	\N	PRESENT	0
156512	156455	01034P	PARTICIPANT	\N	PRESENT	0
157273	157272	04040A	PRESIDENT	0	PRESENT	0
156514	156455	11063M	PARTICIPANT	\N	PRESENT	0
156515	156455	14269B	PARTICIPANT	\N	PRESENT	0
157433	157432	14053L	PARTICIPANT	\N	EXCUSE	0
157434	157432	08065C	PARTICIPANT	\N	EXCUSE	0
143655	143652	11083R	PARTICIPANT	\N	PRESENT	0
143813	143736	14103D	PARTICIPANT	\N	PRESENT	0
144348	144347	04049K	PARTICIPANT	\N	PRESENT	0
143792	143736	11071M	PARTICIPANT	\N	PRESENT	0
144349	144347	14255U	PARTICIPANT	\N	PRESENT	0
143794	143736	14241N	PARTICIPANT	\N	EXCUSE	0
144351	144350	04049K	PARTICIPANT	\N	PRESENT	0
144352	144350	14255U	PARTICIPANT	\N	PRESENT	0
145623	145622	01008M	PARTICIPANT	\N	PRESENT	0
145624	145622	11036J	PARTICIPANT	\N	PRESENT	0
145625	145622	11081P	PARTICIPANT	\N	PRESENT	0
145626	145622	14013P	PARTICIPANT	\N	PRESENT	0
145627	145622	08068F	PARTICIPANT	\N	PRESENT	0
145628	145622	14207L	PARTICIPANT	\N	PRESENT	0
145629	145622	11101A	PARTICIPANT	\N	PRESENT	0
145630	145622	90003B	PARTICIPANT	\N	PRESENT	0
145631	145622	08028W	PARTICIPANT	\N	EXCUSE	0
145632	145622	80013X	PARTICIPANT	\N	PRESENT	0
145633	145622	08038Y	PARTICIPANT	\N	PRESENT	0
145634	145622	04089T	PARTICIPANT	\N	PRESENT	0
146036	146035	11039M	PARTICIPANT	\N	PRESENT	0
145636	145622	11110B	PARTICIPANT	\N	PRESENT	0
145637	145622	14187A	PARTICIPANT	\N	PRESENT	0
145638	145622	14033T	PARTICIPANT	\N	PRESENT	0
145639	145622	14081Q	PARTICIPANT	\N	PRESENT	0
146037	146035	98042T	PARTICIPANT	\N	PRESENT	0
145641	145622	11099A	PARTICIPANT	\N	PRESENT	0
145642	145622	04049K	PARTICIPANT	\N	PRESENT	0
145643	145622	04094Q	PARTICIPANT	\N	PRESENT	0
145644	145622	11111C	PARTICIPANT	\N	PRESENT	0
145645	145622	08015R	PARTICIPANT	\N	PRESENT	0
145646	145622	11100Y	PRESIDENT	0	PRESENT	0
145647	145622	01061S	PARTICIPANT	\N	EXCUSE	0
145648	145622	11098Y	PARTICIPANT	\N	PRESENT	0
145649	145622	01043Q	PARTICIPANT	\N	PRESENT	0
145650	145622	11077T	PARTICIPANT	\N	PRESENT	0
145651	145622	14205J	PARTICIPANT	\N	PRESENT	0
145652	145622	08019V	PARTICIPANT	\N	EXCUSE	0
145653	145622	14257W	PARTICIPANT	\N	PRESENT	0
146054	146052	11039M	PARTICIPANT	\N	PRESENT	0
145655	145622	04088S	PARTICIPANT	\N	PRESENT	0
145656	145622	98050T	PARTICIPANT	\N	PRESENT	0
145657	145622	11090Q	PARTICIPANT	\N	PRESENT	0
146055	146052	98042T	PARTICIPANT	\N	PRESENT	0
145659	145622	01058X	PARTICIPANT	\N	PRESENT	0
145660	145622	11094U	PARTICIPANT	\N	PRESENT	0
143653	143652	11074Q	PARTICIPANT	\N	PRESENT	0
143654	143652	04056J	PARTICIPANT	\N	PRESENT	0
145661	145622	11066Q	PARTICIPANT	\N	PRESENT	0
146038	146035	01019Q	PARTICIPANT	\N	PRESENT	0
146056	146052	01019Q	PARTICIPANT	\N	PRESENT	0
146853	141034	08034U	PARTICIPANT	\N	PRESENT	0
146854	141034	05012A	PARTICIPANT	\N	PRESENT	0
146862	146861	14059S	PARTICIPANT	\N	PRESENT	0
146863	146861	14259Y	PARTICIPANT	\N	PRESENT	0
146892	146864	14085U	PARTICIPANT	\N	PRESENT	0
146893	146466	95030B	PARTICIPANT	\N	EXCUSE	0
146894	146466	04061F	PARTICIPANT	\N	EXCUSE	0
146895	146466	08042U	PARTICIPANT	\N	EXCUSE	0
146896	146466	14249W	PARTICIPANT	\N	EXCUSE	0
146923	146864	14089Y	PARTICIPANT	\N	EXCUSE	0
150695	150694	14089Y	PARTICIPANT	\N	PRESENT	0
150696	150694	01016M	PARTICIPANT	\N	PRESENT	0
150724	150722	98046X	PARTICIPANT	\N	PRESENT	0
150854	150853	95030B	PARTICIPANT	\N	PRESENT	0
150855	150853	14001X	PARTICIPANT	\N	PRESENT	0
151710	150154	01019Q	PARTICIPANT	\N	EXCUSE	0
151712	150154	04044E	PARTICIPANT	\N	EXCUSE	0
151713	150154	01007L	PARTICIPANT	\N	EXCUSE	0
151715	150154	08025T	PARTICIPANT	\N	EXCUSE	0
151717	150154	14215L	PARTICIPANT	\N	EXCUSE	0
152660	152659	11074Q	PARTICIPANT	\N	PRESENT	0
152662	152661	11074Q	PARTICIPANT	\N	PRESENT	0
153659	153657	14249W	PARTICIPANT	\N	PRESENT	0
153660	153657	07026Q	PARTICIPANT	\N	PRESENT	0
156584	156583	89017R	PARTICIPANT	\N	PRESENT	0
156585	156583	01031L	PRESIDENT	0	PRESENT	0
156586	156583	11068S	PARTICIPANT	\N	PRESENT	0
156587	156583	14167V	PARTICIPANT	\N	PRESENT	0
156588	156583	14083S	PARTICIPANT	\N	PRESENT	0
156589	156583	11053K	PARTICIPANT	\N	PRESENT	0
156590	156583	14085U	PARTICIPANT	\N	PRESENT	0
156591	156583	11042G	PARTICIPANT	\N	PRESENT	0
156592	156583	04086Q	PARTICIPANT	\N	PRESENT	0
156593	156583	11088W	PARTICIPANT	\N	PRESENT	0
156594	156583	08022Q	PARTICIPANT	\N	PRESENT	0
156595	156583	11074Q	PARTICIPANT	\N	PRESENT	0
156596	156583	11083R	PARTICIPANT	\N	PRESENT	0
156597	156583	01057W	PARTICIPANT	\N	PRESENT	0
156598	156583	08069G	PARTICIPANT	\N	PRESENT	0
156599	156583	11048N	PARTICIPANT	\N	PRESENT	0
156600	156583	14159V	PARTICIPANT	\N	PRESENT	0
156601	156583	07029T	PARTICIPANT	\N	PRESENT	0
156602	156583	08010L	PARTICIPANT	\N	PRESENT	0
156603	156583	08034U	PARTICIPANT	\N	PRESENT	0
156604	156583	98046X	PARTICIPANT	\N	PRESENT	0
156605	156583	08011M	PARTICIPANT	\N	PRESENT	0
156606	156583	01016M	PARTICIPANT	\N	PRESENT	0
156607	156583	11012A	PARTICIPANT	\N	PRESENT	0
156608	156583	11057P	PARTICIPANT	\N	PRESENT	0
156609	156583	04034C	PARTICIPANT	\N	PRESENT	0
156610	156583	04055H	PARTICIPANT	\N	EXCUSE	0
156611	156583	98053W	PARTICIPANT	\N	EXCUSE	0
156612	156583	08016S	PARTICIPANT	\N	EXCUSE	0
156613	156583	11085T	PARTICIPANT	\N	EXCUSE	0
156614	156583	08061X	PARTICIPANT	\N	EXCUSE	0
156615	156583	11026G	PARTICIPANT	\N	PRESENT	0
156616	156583	95030B	PARTICIPANT	\N	PRESENT	0
156617	156583	96004D	PARTICIPANT	\N	PRESENT	0
156618	156583	14026U	PARTICIPANT	\N	PRESENT	0
156619	156583	14097Y	PARTICIPANT	\N	PRESENT	0
156620	156583	04080J	PARTICIPANT	\N	PRESENT	0
156621	156583	04035D	PARTICIPANT	\N	PRESENT	0
158670	158669	14133K	PARTICIPANT	\N	PRESENT	0
158671	158669	04040A	PARTICIPANT	\N	PRESENT	0
158672	158669	08058D	PARTICIPANT	\N	PRESENT	0
158687	158669	77002U	PARTICIPANT	\N	PRESENT	0
158688	158669	98029W	PARTICIPANT	\N	PRESENT	0
158689	158669	11027H	PARTICIPANT	\N	PRESENT	0
158690	158669	98018T	PARTICIPANT	\N	PRESENT	0
158691	158669	92018S	PARTICIPANT	\N	PRESENT	0
158692	158669	92020L	PARTICIPANT	\N	PRESENT	0
158693	158669	95030B	PARTICIPANT	\N	PRESENT	0
158694	158669	97011G	PARTICIPANT	\N	PRESENT	0
158696	158669	08065C	PARTICIPANT	\N	EXCUSE	0
158697	158669	04035D	PARTICIPANT	\N	PRESENT	0
158700	158669	95035G	PARTICIPANT	\N	PRESENT	0
158701	158669	08056B	PARTICIPANT	\N	EXCUSE	0
158702	158669	98022P	PARTICIPANT	\N	PRESENT	0
158703	158669	11064N	PARTICIPANT	\N	PRESENT	0
158704	158669	95037J	PARTICIPANT	\N	PRESENT	0
158712	158669	04078Q	PARTICIPANT	\N	PRESENT	0
158714	158669	14097Y	PARTICIPANT	\N	PRESENT	0
158715	158669	04036E	PARTICIPANT	\N	PRESENT	0
158716	158669	92031P	PARTICIPANT	\N	PRESENT	0
158718	158669	11106F	PARTICIPANT	\N	PRESENT	0
158719	158669	14251Q	PARTICIPANT	\N	PRESENT	0
158720	158669	83042R	PARTICIPANT	\N	PRESENT	0
158721	158669	11105E	PARTICIPANT	\N	PRESENT	0
158722	158669	14253S	PARTICIPANT	\N	PRESENT	0
158723	158669	08047A	PARTICIPANT	\N	PRESENT	0
158724	158669	14028W	PARTICIPANT	\N	PRESENT	0
158725	158669	14193X	PARTICIPANT	\N	PRESENT	0
158726	158669	98021N	PARTICIPANT	\N	PRESENT	0
158727	158669	04080J	PARTICIPANT	\N	PRESENT	0
158728	158669	95059Q	PRESIDENT	0	PRESENT	0
158730	158669	86044G	PARTICIPANT	\N	PRESENT	0
158732	158669	01014K	PARTICIPANT	\N	EXCUSE	0
158733	158669	11054L	PARTICIPANT	\N	PRESENT	0
158734	158669	01056V	PARTICIPANT	\N	PRESENT	0
158735	158669	04050C	PARTICIPANT	\N	PRESENT	0
159015	158314	14073Q	PARTICIPANT	\N	EXCUSE	0
159016	158314	04057K	PARTICIPANT	\N	EXCUSE	0
159017	158973	04040A	PARTICIPANT	\N	EXCUSE	0
159018	158973	14073Q	PARTICIPANT	\N	EXCUSE	0
159019	158973	04057K	PARTICIPANT	\N	EXCUSE	0
159867	159825	14030Q	PARTICIPANT	\N	PRESENT	0
159869	159825	08043V	PARTICIPANT	\N	PRESENT	0
159873	159825	11031D	PARTICIPANT	\N	PRESENT	0
159876	159825	11027H	PARTICIPANT	\N	PRESENT	0
159877	159825	80013X	PARTICIPANT	\N	PRESENT	0
159880	159825	14217N	PARTICIPANT	\N	PRESENT	0
159883	159825	04035D	PARTICIPANT	\N	PRESENT	0
127333	127332	05008E	PRESIDENT	0	PRESENT	0
127334	127332	14069U	PARTICIPANT	\N	PRESENT	0
127335	127332	14259Y	PARTICIPANT	\N	PRESENT	0
127336	127332	11034G	PARTICIPANT	\N	PRESENT	0
127338	127332	08018U	PARTICIPANT	\N	PRESENT	0
127339	127332	01007L	PARTICIPANT	\N	PRESENT	0
127340	127332	14111D	PARTICIPANT	\N	PRESENT	0
127341	127332	14147R	PARTICIPANT	\N	PRESENT	0
127342	127332	95049N	PARTICIPANT	\N	PRESENT	0
127343	127332	08051V	PARTICIPANT	\N	PRESENT	0
127369	127332	08044W	PARTICIPANT	\N	EXCUSE	0
127346	127332	01028R	PARTICIPANT	\N	PRESENT	0
127347	127332	98035U	PARTICIPANT	\N	PRESENT	0
127348	127332	04044E	PARTICIPANT	\N	PRESENT	0
127349	127332	11037K	PARTICIPANT	\N	PRESENT	0
127350	127332	92045V	PARTICIPANT	\N	EXCUSE	0
127351	127332	95067Q	PARTICIPANT	\N	PRESENT	0
127353	127332	07034Q	PARTICIPANT	\N	PRESENT	0
129294	129293	96004D	PRESIDENT	0	PRESENT	0
129295	129293	95030B	PARTICIPANT	\N	PRESENT	0
129296	129293	01016M	PARTICIPANT	\N	PRESENT	0
129297	129293	14133K	PARTICIPANT	\N	PRESENT	0
129298	129293	14073Q	PARTICIPANT	\N	PRESENT	0
129441	129387	95030B	PARTICIPANT	\N	PRESENT	0
129386	129384	95030B	PARTICIPANT	\N	PRESENT	0
129388	129387	14001X	PARTICIPANT	\N	PRESENT	0
130002	130000	14133K	PARTICIPANT	\N	PRESENT	0
130003	130000	11040E	PARTICIPANT	\N	PRESENT	0
130004	130000	96004D	PRESIDENT	0	PRESENT	0
130005	130000	14079W	PARTICIPANT	\N	PRESENT	0
130006	130000	14249W	PARTICIPANT	\N	PRESENT	0
130007	130000	04035D	PARTICIPANT	\N	PRESENT	0
130008	130000	04080J	PARTICIPANT	\N	PRESENT	0
130009	130000	10015M	PARTICIPANT	\N	EXCUSE	0
130010	130000	92045V	PARTICIPANT	\N	EXCUSE	0
130011	130000	04045F	PARTICIPANT	\N	EXCUSE	0
130013	130000	14135M	PARTICIPANT	\N	PRESENT	0
130016	130000	14001X	PARTICIPANT	\N	EXCUSE	0
130017	130000	01008M	PARTICIPANT	\N	PRESENT	0
130018	130000	11036J	PARTICIPANT	\N	PRESENT	0
130019	130000	80013X	PARTICIPANT	\N	PRESENT	0
130020	130000	14197C	PARTICIPANT	\N	PRESENT	0
130021	130000	14033T	PARTICIPANT	\N	PRESENT	0
130022	130000	11100Y	PARTICIPANT	\N	PRESENT	0
130028	130000	98050T	PARTICIPANT	\N	PRESENT	0
130025	130000	11098Y	PARTICIPANT	\N	PRESENT	0
130026	130000	11077T	PARTICIPANT	\N	PRESENT	0
130029	130000	11046L	PARTICIPANT	\N	PRESENT	0
130030	130000	01058X	PARTICIPANT	\N	PRESENT	0
130031	130000	11066Q	PARTICIPANT	\N	PRESENT	0
131752	131751	01031L	PRESIDENT	0	PRESENT	0
131753	131751	01013J	PARTICIPANT	\N	PRESENT	0
131754	131751	14175V	PARTICIPANT	\N	PRESENT	0
131756	131751	14083S	PARTICIPANT	\N	PRESENT	0
131757	131751	11053K	PARTICIPANT	\N	PRESENT	0
131758	131751	01027Q	PARTICIPANT	\N	PRESENT	0
131759	131751	04071H	PARTICIPANT	\N	PRESENT	0
131760	131751	11083R	PARTICIPANT	\N	PRESENT	0
131761	131751	01057W	PARTICIPANT	\N	PRESENT	0
131762	131751	07029T	PARTICIPANT	\N	PRESENT	0
131763	131751	08010L	PARTICIPANT	\N	PRESENT	0
131764	131751	08034U	PARTICIPANT	\N	PRESENT	0
131765	131751	14225N	PARTICIPANT	\N	PRESENT	0
131766	131751	04034C	PRESIDENT	1	PRESENT	0
131767	131751	98053W	PARTICIPANT	\N	EXCUSE	0
131768	131751	08011M	PARTICIPANT	\N	EXCUSE	0
131769	131751	08073C	PARTICIPANT	\N	EXCUSE	0
131770	131751	01014K	PARTICIPANT	\N	PRESENT	0
131773	131772	04086Q	PARTICIPANT	\N	PRESENT	0
131775	131774	89017R	PARTICIPANT	\N	PRESENT	0
131777	131776	89017R	PARTICIPANT	\N	PRESENT	0
131779	131778	89017R	PARTICIPANT	\N	PRESENT	0
131782	131781	89017R	PARTICIPANT	\N	PRESENT	0
136110	135575	04044E	PARTICIPANT	\N	PRESENT	0
132168	132167	14103D	PARTICIPANT	\N	PRESENT	0
132192	120701	14097Y	PARTICIPANT	\N	EXCUSE	0
132193	120701	11109J	PARTICIPANT	\N	PRESENT	0
132194	120701	14261S	PARTICIPANT	\N	PRESENT	0
132195	120701	11113E	PARTICIPANT	\N	PRESENT	0
132196	120701	14033T	PARTICIPANT	\N	PRESENT	0
132197	120701	14039A	PARTICIPANT	\N	PRESENT	0
132198	120701	98005N	PARTICIPANT	\N	PRESENT	0
132199	120701	14059S	PARTICIPANT	\N	PRESENT	0
132200	120701	11072N	PRESIDENT	0	PRESENT	0
132201	120701	14275Y	PARTICIPANT	\N	PRESENT	0
132203	129541	11099A	PARTICIPANT	\N	PRESENT	0
132204	129541	08010L	PARTICIPANT	\N	PRESENT	0
132205	129541	07032N	PARTICIPANT	\N	PRESENT	0
132206	129541	11037K	PARTICIPANT	\N	PRESENT	0
132207	129541	14051J	PARTICIPANT	\N	PRESENT	0
132208	129541	14063N	PARTICIPANT	\N	PRESENT	0
132211	129541	11101A	PARTICIPANT	\N	PRESENT	0
132213	129541	01057W	PARTICIPANT	\N	PRESENT	0
132217	129541	14028W	PARTICIPANT	\N	PRESENT	0
132220	129541	01027Q	PARTICIPANT	\N	PRESENT	0
132221	129541	04044E	PARTICIPANT	\N	PRESENT	0
132222	129541	11112D	PARTICIPANT	\N	PRESENT	0
132223	129541	14014Q	PARTICIPANT	\N	PRESENT	0
132224	129541	05012A	PARTICIPANT	\N	PRESENT	0
132786	132784	04094Q	PARTICIPANT	\N	EXCUSE	0
136112	135575	04092N	PARTICIPANT	\N	PRESENT	0
136113	135575	80027E	PARTICIPANT	\N	PRESENT	0
136114	135575	98050T	PARTICIPANT	\N	PRESENT	0
136115	135575	11036J	PARTICIPANT	\N	PRESENT	0
136116	135575	01048V	PARTICIPANT	\N	PRESENT	0
136117	135575	14221J	PARTICIPANT	\N	PRESENT	0
136118	135575	14031R	PARTICIPANT	\N	PRESENT	0
136119	135575	14030Q	PARTICIPANT	\N	PRESENT	0
136120	135575	14271U	PARTICIPANT	\N	PRESENT	0
136121	135575	14331P	PARTICIPANT	\N	PRESENT	0
136122	135575	14157T	PARTICIPANT	\N	PRESENT	0
136123	135575	07029T	PARTICIPANT	\N	PRESENT	0
136124	135575	14173T	PARTICIPANT	\N	PRESENT	0
136125	135575	14187A	PARTICIPANT	\N	PRESENT	0
136126	135575	11054L	PARTICIPANT	\N	PRESENT	0
136127	135575	07024N	PARTICIPANT	\N	PRESENT	0
136128	135575	14061L	PARTICIPANT	\N	PRESENT	0
136129	135575	11030C	PARTICIPANT	\N	PRESENT	0
136130	135575	95035G	PARTICIPANT	\N	PRESENT	0
136131	135575	99004R	PARTICIPANT	\N	PRESENT	0
136132	135575	92040Q	PARTICIPANT	\N	PRESENT	0
136133	135575	04081K	PARTICIPANT	\N	PRESENT	0
136134	135575	87003B	PARTICIPANT	\N	PRESENT	0
136135	135575	77002U	PARTICIPANT	\N	PRESENT	0
136136	135575	04086Q	PARTICIPANT	\N	PRESENT	0
136137	135575	08058D	PARTICIPANT	\N	PRESENT	0
136138	135575	14225N	PARTICIPANT	\N	PRESENT	0
136139	135575	11043H	PARTICIPANT	\N	PRESENT	0
136140	135575	14121F	PARTICIPANT	\N	PRESENT	0
136145	135575	14133K	PARTICIPANT	\N	PRESENT	0
136142	135575	11049P	PARTICIPANT	\N	PRESENT	0
136143	135575	04079R	PARTICIPANT	\N	PRESENT	0
136144	135575	11098Y	PARTICIPANT	\N	PRESENT	0
136146	135575	04085P	PARTICIPANT	\N	PRESENT	0
136147	135575	01013J	PARTICIPANT	\N	PRESENT	0
136148	135575	02002K	PARTICIPANT	\N	PRESENT	0
136149	135575	11080N	PARTICIPANT	\N	PRESENT	0
136150	135575	04057K	PARTICIPANT	\N	PRESENT	0
136151	135575	11029K	PARTICIPANT	\N	PRESENT	0
136152	135575	04067M	PARTICIPANT	\N	PRESENT	0
136153	135575	08069G	PARTICIPANT	\N	PRESENT	0
136154	135575	04048J	PARTICIPANT	\N	PRESENT	0
136155	135575	08015R	PARTICIPANT	\N	PRESENT	0
136156	135575	14026U	PARTICIPANT	\N	PRESENT	0
136157	135575	14055N	PARTICIPANT	\N	PRESENT	0
136158	135575	92044U	PARTICIPANT	\N	PRESENT	0
136159	135575	11039M	PARTICIPANT	\N	PRESENT	0
136160	135575	04056J	PARTICIPANT	\N	PRESENT	0
136161	135575	98035U	PARTICIPANT	\N	PRESENT	0
136162	135575	01057W	PARTICIPANT	\N	PRESENT	0
136164	135575	14079W	PARTICIPANT	\N	PRESENT	0
136165	135575	95037J	PARTICIPANT	\N	PRESENT	0
136168	135575	14227Q	PARTICIPANT	\N	PRESENT	0
136169	135575	04033B	PARTICIPANT	\N	PRESENT	0
136170	135575	14033T	PARTICIPANT	\N	PRESENT	0
136171	135575	14069U	PARTICIPANT	\N	PRESENT	0
136172	135575	08011M	PARTICIPANT	\N	PRESENT	0
136173	135575	11026G	PARTICIPANT	\N	PRESENT	0
136111	135575	01031L	PARTICIPANT	\N	PRESENT	0
136174	135575	98005N	PARTICIPANT	\N	PRESENT	0
136175	135575	14281W	PARTICIPANT	\N	PRESENT	0
136177	135575	14093U	PARTICIPANT	\N	PRESENT	0
136178	135575	14249W	PARTICIPANT	\N	PRESENT	0
136179	135575	08022Q	PARTICIPANT	\N	PRESENT	0
136180	135575	98046X	PARTICIPANT	\N	PRESENT	0
136181	135575	08047A	PARTICIPANT	\N	PRESENT	0
136182	135575	08052W	PARTICIPANT	\N	PRESENT	0
136183	135575	14151M	PARTICIPANT	\N	PRESENT	0
136184	135575	04055H	PARTICIPANT	\N	PRESENT	0
136185	135575	08068F	PARTICIPANT	\N	PRESENT	0
145787	145732	11043H	PARTICIPANT	\N	PRESENT	0
145788	145732	11071M	PARTICIPANT	\N	PRESENT	0
146113	146112	14239U	PARTICIPANT	\N	PRESENT	0
145791	145790	14263U	PARTICIPANT	\N	EXCUSE	0
145792	145790	14133K	PARTICIPANT	\N	PRESENT	0
145793	145790	11109J	PARTICIPANT	\N	PRESENT	0
145794	145790	04059M	PARTICIPANT	\N	PRESENT	0
146313	146312	14133K	PARTICIPANT	\N	PRESENT	0
145796	145790	01044R	PARTICIPANT	\N	PRESENT	0
145797	145790	08043V	PARTICIPANT	\N	EXCUSE	0
146115	146112	01046T	PARTICIPANT	\N	PRESENT	0
145799	145790	14105F	PARTICIPANT	\N	PRESENT	0
145800	145790	11029K	PARTICIPANT	\N	PRESENT	0
146116	146112	04053F	PARTICIPANT	\N	PRESENT	0
145802	145790	92015P	PARTICIPANT	\N	PRESENT	0
145803	145790	08024S	PARTICIPANT	\N	PRESENT	0
145804	145790	14201E	PARTICIPANT	\N	PRESENT	0
145805	145790	14329V	PARTICIPANT	\N	PRESENT	0
145806	145790	14209N	PARTICIPANT	\N	PRESENT	0
145807	145790	14079W	PARTICIPANT	\N	PRESENT	0
145808	145790	11091R	PARTICIPANT	\N	EXCUSE	0
145809	145790	87003B	PARTICIPANT	\N	PRESENT	0
145810	145790	98042T	PARTICIPANT	\N	EXCUSE	0
145811	145790	14249W	PARTICIPANT	\N	PRESENT	0
145812	145790	01041N	PARTICIPANT	\N	PRESENT	0
145813	145790	01025N	PARTICIPANT	\N	EXCUSE	0
145814	145790	01037S	PARTICIPANT	\N	PRESENT	0
146117	146112	14255U	PARTICIPANT	\N	PRESENT	0
145816	145790	08035V	PARTICIPANT	\N	PRESENT	0
146118	146112	04066L	PARTICIPANT	\N	PRESENT	0
145818	145790	07026Q	PARTICIPANT	\N	PRESENT	0
145819	145790	14123H	PARTICIPANT	\N	PRESENT	0
146119	146112	00003C	PARTICIPANT	\N	EXCUSE	0
146120	146112	14053L	PARTICIPANT	\N	PRESENT	0
145822	145790	14241N	PARTICIPANT	\N	PRESENT	0
145823	145790	14061L	PARTICIPANT	\N	PRESENT	0
145824	145790	14073Q	PARTICIPANT	\N	PRESENT	0
145825	145790	08031R	PARTICIPANT	\N	PRESENT	0
145826	145790	12041X	PARTICIPANT	\N	EXCUSE	0
145827	145790	08039A	PARTICIPANT	\N	PRESENT	0
145828	145790	08017T	PARTICIPANT	\N	PRESENT	0
145829	145790	14059S	PARTICIPANT	\N	PRESENT	0
146121	146112	11103C	PARTICIPANT	\N	PRESENT	0
146122	146112	11044J	PARTICIPANT	\N	PRESENT	0
145832	145790	11104D	PARTICIPANT	\N	PRESENT	0
145833	145790	14063N	PARTICIPANT	\N	PRESENT	0
145834	145790	04057K	PARTICIPANT	\N	PRESENT	0
145835	145790	11014C	PARTICIPANT	\N	PRESENT	0
146123	146112	14195A	PARTICIPANT	\N	PRESENT	0
145837	145790	04070G	PRESIDENT	0	PRESENT	0
145838	145790	92040Q	PARTICIPANT	\N	PRESENT	0
145839	145790	14191V	PARTICIPANT	\N	PRESENT	0
145840	145790	83047W	PARTICIPANT	\N	PRESENT	0
145841	145790	14235Q	PARTICIPANT	\N	EXCUSE	0
145842	145790	14055N	PARTICIPANT	\N	PRESENT	0
145843	145790	04033B	PARTICIPANT	\N	PRESENT	0
145844	145790	14229S	PARTICIPANT	\N	PRESENT	0
145845	145790	11043H	PARTICIPANT	\N	PRESENT	0
145846	145790	11071M	PARTICIPANT	\N	PRESENT	0
146314	146312	01008M	PARTICIPANT	\N	PRESENT	0
146124	146112	14267Y	PARTICIPANT	\N	PRESENT	0
146316	146312	01041N	PARTICIPANT	\N	PRESENT	0
146126	146112	11031D	PARTICIPANT	\N	PRESENT	0
146127	146112	08052W	PARTICIPANT	\N	PRESENT	0
146128	146112	01059Y	PARTICIPANT	\N	PRESENT	0
146129	146112	04081K	PARTICIPANT	\N	PRESENT	0
146130	146112	98024R	PARTICIPANT	\N	PRESENT	0
146131	146112	10006L	PARTICIPANT	\N	PRESENT	0
146132	146112	04067M	PARTICIPANT	\N	PRESENT	0
146133	146112	14217N	PARTICIPANT	\N	PRESENT	0
146134	146112	14042U	PARTICIPANT	\N	PRESENT	0
146318	146312	12042Y	PARTICIPANT	\N	PRESENT	0
146136	146112	12042Y	PARTICIPANT	\N	PRESENT	0
146137	146112	14281W	PARTICIPANT	\N	PRESENT	0
146138	146112	14087W	PARTICIPANT	\N	PRESENT	0
146139	146112	01003G	PARTICIPANT	\N	PRESENT	0
146140	146112	14034U	PARTICIPANT	\N	PRESENT	0
146141	146112	14231L	PARTICIPANT	\N	PRESENT	0
146142	146112	11061K	PARTICIPANT	\N	PRESENT	0
146319	146312	01037S	PARTICIPANT	\N	PRESENT	0
146144	146112	08048B	PARTICIPANT	\N	PRESENT	0
146145	146112	08041T	PARTICIPANT	\N	PRESENT	0
146146	146112	01011G	PARTICIPANT	\N	PRESENT	0
146147	146112	14026U	PARTICIPANT	\N	PRESENT	0
146148	146112	14213J	PARTICIPANT	\N	PRESENT	0
146149	146112	14121F	PARTICIPANT	\N	PRESENT	0
146150	146112	11112D	PARTICIPANT	\N	PRESENT	0
146151	146112	14037X	PARTICIPANT	\N	PRESENT	0
146152	146112	14018U	PARTICIPANT	\N	PRESENT	0
146153	146112	11067R	PARTICIPANT	\N	EXCUSE	0
146154	146112	14223L	PARTICIPANT	\N	PRESENT	0
146155	146112	04092N	PRESIDENT	0	PRESENT	0
146156	146112	14265W	PARTICIPANT	\N	PRESENT	0
146157	146112	14119M	PARTICIPANT	\N	PRESENT	0
146158	146112	14071N	PARTICIPANT	\N	PRESENT	0
146320	146312	07029T	PARTICIPANT	\N	PRESENT	0
146160	146112	14271U	PARTICIPANT	\N	PRESENT	0
146161	146112	14017T	PARTICIPANT	\N	EXCUSE	0
146162	146112	11093T	PARTICIPANT	\N	PRESENT	0
146163	146112	11097X	PARTICIPANT	\N	PRESENT	0
146164	146112	04045F	PARTICIPANT	\N	PRESENT	0
146165	146112	14227Q	PARTICIPANT	\N	PRESENT	0
146166	146112	01034P	PARTICIPANT	\N	PRESENT	0
146321	146312	14219Q	PARTICIPANT	\N	PRESENT	0
146168	146112	11063M	PARTICIPANT	\N	PRESENT	0
146169	146112	14269B	PARTICIPANT	\N	PRESENT	0
146322	146312	14179A	PARTICIPANT	\N	PRESENT	0
146323	146312	04088S	PARTICIPANT	\N	PRESENT	0
146324	146312	95062K	PARTICIPANT	\N	PRESENT	0
146325	146312	11105E	PARTICIPANT	\N	PRESENT	0
146326	146312	14265W	PARTICIPANT	\N	PRESENT	0
146535	146253	11053K	PARTICIPANT	\N	PRESENT	0
146536	146253	14038Y	PARTICIPANT	\N	PRESENT	0
146981	146980	04049K	PARTICIPANT	\N	PRESENT	0
146554	146552	08055A	PARTICIPANT	\N	PRESENT	0
146982	146980	14255U	PARTICIPANT	\N	PRESENT	0
146556	146552	11053K	PARTICIPANT	\N	PRESENT	0
146557	146552	14038Y	PARTICIPANT	\N	PRESENT	0
148392	148192	14265W	PARTICIPANT	\N	PRESENT	0
146559	146552	01015L	PARTICIPANT	\N	PRESENT	0
148393	148192	01008M	PARTICIPANT	\N	PRESENT	0
146561	146552	08009T	PARTICIPANT	\N	PRESENT	0
148394	148192	95067Q	PARTICIPANT	\N	PRESENT	0
146563	146552	05012A	PARTICIPANT	\N	PRESENT	0
146564	146552	14331P	PARTICIPANT	\N	PRESENT	0
146565	146552	14107H	PARTICIPANT	\N	PRESENT	0
146566	146552	14051J	PARTICIPANT	\N	PRESENT	0
148472	147603	14271U	PARTICIPANT	\N	PRESENT	0
148473	147603	01022K	PARTICIPANT	\N	PRESENT	0
148477	147603	08041T	PARTICIPANT	\N	PRESENT	0
148478	147603	14195A	PARTICIPANT	\N	PRESENT	0
148479	147603	11089X	PARTICIPANT	\N	PRESENT	0
148480	147603	80013X	PARTICIPANT	\N	PRESENT	0
148481	147603	14065Q	PARTICIPANT	\N	PRESENT	0
148482	147603	14281W	PARTICIPANT	\N	PRESENT	0
148483	147603	04085P	PARTICIPANT	\N	PRESENT	0
148484	147603	04079R	PARTICIPANT	\N	PRESENT	0
148485	147603	14241N	PARTICIPANT	\N	PRESENT	0
148486	147603	08031R	PARTICIPANT	\N	PRESENT	0
148487	147603	14030Q	PARTICIPANT	\N	PRESENT	0
148488	147603	14034U	PARTICIPANT	\N	PRESENT	0
148489	147603	14055N	PARTICIPANT	\N	PRESENT	0
148490	147603	01008M	PARTICIPANT	\N	PRESENT	0
148491	147603	14265W	PARTICIPANT	\N	PRESENT	0
148492	147603	14213J	PARTICIPANT	\N	PRESENT	0
148494	147603	04043D	PARTICIPANT	\N	PRESENT	0
130610	130607	04070G	PARTICIPANT	\N	PRESENT	0
130612	130607	11029K	PARTICIPANT	\N	PRESENT	0
130613	130607	11083R	PARTICIPANT	\N	PRESENT	0
130614	130607	14083S	PARTICIPANT	\N	PRESENT	0
132857	132856	11039M	PARTICIPANT	\N	PRESENT	0
132858	132856	98042T	PARTICIPANT	\N	PRESENT	0
132859	132856	01019Q	PARTICIPANT	\N	PRESENT	0
137461	137459	04057K	PARTICIPANT	\N	PRESENT	0
137462	137459	11083R	PARTICIPANT	\N	PRESENT	0
137481	137200	96003C	PARTICIPANT	\N	EXCUSE	0
137584	137583	01008M	PARTICIPANT	\N	PRESENT	0
137585	137583	14119M	PARTICIPANT	\N	PRESENT	0
137586	137583	07029T	PARTICIPANT	\N	PRESENT	0
137587	137583	01037S	PARTICIPANT	\N	PRESENT	0
137588	137583	95062K	PARTICIPANT	\N	PRESENT	0
137589	137583	01019Q	PARTICIPANT	\N	PRESENT	0
137590	137583	11091R	PARTICIPANT	\N	PRESENT	0
137591	137583	08055A	PARTICIPANT	\N	PRESENT	0
137592	137583	04045F	PARTICIPANT	\N	PRESENT	0
141192	141034	95067Q	PARTICIPANT	\N	PRESENT	0
151297	151296	11063M	PARTICIPANT	\N	PRESENT	0
151299	151298	11063M	PARTICIPANT	\N	PRESENT	0
157373	157372	14133K	PARTICIPANT	\N	PRESENT	0
157374	157372	04047H	PARTICIPANT	\N	PRESENT	0
157375	157372	14079W	PARTICIPANT	\N	PRESENT	0
157376	157372	11083R	PARTICIPANT	\N	PRESENT	0
157377	157372	11084S	PARTICIPANT	\N	PRESENT	0
157378	157372	14073Q	PARTICIPANT	\N	PRESENT	0
157379	157372	11026G	PARTICIPANT	\N	PRESENT	0
157380	157372	14193X	PARTICIPANT	\N	PRESENT	0
157381	157372	11012A	PARTICIPANT	\N	PRESENT	0
157382	157372	14227Q	PARTICIPANT	\N	PRESENT	0
157383	157372	95067Q	PARTICIPANT	\N	PRESENT	0
160618	160617	14239U	PARTICIPANT	\N	PRESENT	0
158854	158513	05012A	PARTICIPANT	\N	PRESENT	0
158972	158513	14219Q	PARTICIPANT	\N	PRESENT	0
159001	158513	14018U	PARTICIPANT	\N	PRESENT	0
159432	157272	01057W	PARTICIPANT	\N	PRESENT	0
159433	157272	14014Q	PARTICIPANT	\N	PRESENT	0
159434	157272	08034U	PARTICIPANT	\N	PRESENT	0
159435	157272	14051J	PARTICIPANT	\N	PRESENT	0
159436	157272	11037K	PARTICIPANT	\N	PRESENT	0
159437	157272	04086Q	PARTICIPANT	\N	PRESENT	0
159932	159930	14239U	PARTICIPANT	\N	PRESENT	0
159933	159930	08052W	PARTICIPANT	\N	PRESENT	0
159936	159930	14041T	PARTICIPANT	\N	PRESENT	0
159937	159930	11061K	PARTICIPANT	\N	PRESENT	0
159938	159930	14213J	PARTICIPANT	\N	PRESENT	0
159939	159930	14205J	PARTICIPANT	\N	PRESENT	0
159940	159930	14147R	PARTICIPANT	\N	PRESENT	0
159941	159930	14223L	PARTICIPANT	\N	PRESENT	0
159942	159930	04092N	PRESIDENT	0	PRESENT	0
159943	159930	14265W	PARTICIPANT	\N	PRESENT	0
159944	159930	14235Q	PARTICIPANT	\N	PRESENT	0
159945	159930	14331P	PARTICIPANT	\N	PRESENT	0
159946	159930	11097X	PARTICIPANT	\N	PRESENT	0
159947	159930	14028W	PARTICIPANT	\N	EXCUSE	0
159948	159930	11094U	PARTICIPANT	\N	EXCUSE	0
159949	159930	11031D	PARTICIPANT	\N	EXCUSE	0
159960	159959	96004D	PARTICIPANT	\N	PRESENT	0
159961	159959	14026U	PARTICIPANT	\N	PRESENT	0
159962	159959	95037J	PARTICIPANT	\N	PRESENT	0
159963	159959	14033T	PARTICIPANT	\N	PRESENT	0
159964	159959	14257W	PARTICIPANT	\N	PRESENT	0
159965	159959	11099A	PARTICIPANT	\N	PRESENT	0
159966	159959	11090Q	PARTICIPANT	\N	PRESENT	0
160273	160272	14133K	PARTICIPANT	\N	PRESENT	0
160274	160272	04054G	PARTICIPANT	\N	PRESENT	0
160275	160272	04047H	PARTICIPANT	\N	PRESENT	0
160276	160272	14267Y	PARTICIPANT	\N	PRESENT	0
160277	160272	14079W	PARTICIPANT	\N	PRESENT	0
160278	160272	11083R	PARTICIPANT	\N	PRESENT	0
160279	160272	14026U	PARTICIPANT	\N	PRESENT	0
160280	160272	14097Y	PARTICIPANT	\N	PRESENT	0
160281	160272	14073Q	PARTICIPANT	\N	PRESENT	0
160282	160272	92031P	PARTICIPANT	\N	PRESENT	0
160283	160272	14001X	PARTICIPANT	\N	PRESENT	0
160284	160272	10015M	PARTICIPANT	\N	PRESENT	0
160285	160272	11012A	PARTICIPANT	\N	PRESENT	0
160286	160272	14227Q	PARTICIPANT	\N	PRESENT	0
160287	160272	11066Q	PARTICIPANT	\N	PRESENT	0
160288	160272	95067Q	PARTICIPANT	\N	PRESENT	0
160290	160289	14133K	PARTICIPANT	\N	PRESENT	0
160291	160289	04054G	PARTICIPANT	\N	PRESENT	0
160292	160289	04047H	PARTICIPANT	\N	PRESENT	0
160293	160289	14267Y	PARTICIPANT	\N	PRESENT	0
160294	160289	14079W	PARTICIPANT	\N	PRESENT	0
160295	160289	14097Y	PARTICIPANT	\N	PRESENT	0
160296	160289	11084S	PARTICIPANT	\N	PRESENT	0
160297	160289	92031P	PARTICIPANT	\N	PRESENT	0
160298	160289	14001X	PARTICIPANT	\N	PRESENT	0
160299	160289	11012A	PARTICIPANT	\N	PRESENT	0
160300	160289	14227Q	PARTICIPANT	\N	PRESENT	0
160301	160289	11066Q	PARTICIPANT	\N	PRESENT	0
160302	160289	95067Q	PARTICIPANT	\N	PRESENT	0
160573	160533	04057K	PARTICIPANT	\N	PRESENT	0
160574	160533	04034C	PARTICIPANT	\N	PRESENT	0
160619	160617	14105F	PARTICIPANT	\N	PRESENT	0
160620	160617	10006L	PARTICIPANT	\N	PRESENT	0
160621	160617	14215L	PARTICIPANT	\N	PRESENT	0
160622	160617	97011G	PARTICIPANT	\N	PRESENT	0
160623	160617	04035D	PARTICIPANT	\N	PRESENT	0
160624	160617	04036E	PARTICIPANT	\N	PRESENT	0
160625	160617	14219Q	PARTICIPANT	\N	PRESENT	0
160626	160617	14031R	PARTICIPANT	\N	PRESENT	0
160627	160617	14265W	PARTICIPANT	\N	PRESENT	0
160628	160617	14225N	PARTICIPANT	\N	PRESENT	0
160629	160617	04033B	PARTICIPANT	\N	PRESENT	0
160630	160617	11093T	PARTICIPANT	\N	PRESENT	0
160631	160617	95067Q	PARTICIPANT	\N	PRESENT	0
160632	160617	11106F	PARTICIPANT	\N	PRESENT	0
160633	160617	14097Y	PARTICIPANT	\N	PRESENT	0
160780	160772	14105F	PARTICIPANT	\N	PRESENT	0
160781	160772	11029K	PARTICIPANT	\N	EXCUSE	0
160941	160772	14061L	PARTICIPANT	\N	PRESENT	0
160952	160752	04047H	PARTICIPANT	\N	PRESENT	0
160784	160772	08024S	PARTICIPANT	\N	PRESENT	0
160992	160259	86034E	PARTICIPANT	\N	PRESENT	0
160993	160259	14030Q	PARTICIPANT	\N	PRESENT	0
160787	160772	14209N	PARTICIPANT	\N	PRESENT	0
160994	160259	11023D	PARTICIPANT	\N	PRESENT	0
161035	160259	04088S	PARTICIPANT	\N	PRESENT	0
161036	160259	14033T	PARTICIPANT	\N	PRESENT	0
161037	160259	14259Y	PARTICIPANT	\N	PRESENT	0
161038	160259	14039A	PARTICIPANT	\N	PRESENT	0
160793	160772	01041N	PARTICIPANT	\N	PRESENT	0
160794	160772	01025N	PARTICIPANT	\N	EXCUSE	0
160795	160772	89029V	PARTICIPANT	\N	PRESENT	0
161039	160259	14059S	PARTICIPANT	\N	PRESENT	0
161041	161040	11055M	PARTICIPANT	\N	PRESENT	0
161042	161040	00003C	PARTICIPANT	\N	EXCUSE	0
161043	161040	14053L	PARTICIPANT	\N	PRESENT	0
161044	161040	14195A	PARTICIPANT	\N	PRESENT	0
161045	161040	11023D	PARTICIPANT	\N	PRESENT	0
161046	161040	08052W	PARTICIPANT	\N	PRESENT	0
161047	161040	98024R	PARTICIPANT	\N	PRESENT	0
160804	160772	14073Q	PARTICIPANT	\N	PRESENT	0
161048	161040	14217N	PARTICIPANT	\N	PRESENT	0
160806	160772	12041X	PARTICIPANT	\N	PRESENT	0
161049	161040	14042U	PARTICIPANT	\N	PRESENT	0
160808	160772	08017T	PARTICIPANT	\N	PRESENT	0
160809	160772	14059S	PARTICIPANT	\N	PRESENT	0
161050	161040	12042Y	PARTICIPANT	\N	PRESENT	0
160811	160772	14103D	PARTICIPANT	\N	PRESENT	0
161051	161040	14281W	PARTICIPANT	\N	PRESENT	0
161052	161040	14087W	PARTICIPANT	\N	PRESENT	0
161053	161040	14034U	PARTICIPANT	\N	PRESENT	0
160815	160772	11014C	PARTICIPANT	\N	PRESENT	0
160816	160772	14109K	PARTICIPANT	\N	PRESENT	0
160817	160772	04070G	PRESIDENT	0	PRESENT	0
161054	161040	14231L	PARTICIPANT	\N	PRESENT	0
160819	160772	14191V	PARTICIPANT	\N	PRESENT	0
160820	160772	83047W	PARTICIPANT	\N	EXCUSE	0
160821	160772	14235Q	PARTICIPANT	\N	PRESENT	0
161055	160259	14217N	PARTICIPANT	\N	PRESENT	0
161056	161040	14355X	PARTICIPANT	\N	PRESENT	0
160824	160772	14229S	PARTICIPANT	\N	PRESENT	0
160825	160772	14363X	PARTICIPANT	\N	PRESENT	0
160826	160772	11043H	PARTICIPANT	\N	EXCUSE	0
161057	161040	08048B	PARTICIPANT	\N	PRESENT	0
160828	160772	11011M	PARTICIPANT	\N	PRESENT	0
161058	161040	08041T	PRESIDENT	0	PRESENT	0
161059	161040	14213J	PARTICIPANT	\N	PRESENT	0
161060	161040	14121F	PARTICIPANT	\N	PRESENT	0
161061	160259	08019V	PARTICIPANT	\N	PRESENT	0
161062	161040	14018U	PARTICIPANT	\N	PRESENT	0
161063	161040	11067R	PARTICIPANT	\N	PRESENT	0
161064	161040	14223L	PARTICIPANT	\N	EXCUSE	0
161065	161040	04092N	PARTICIPANT	\N	EXCUSE	0
143678	143676	89017R	PARTICIPANT	\N	PRESENT	0
143680	143676	11039M	PARTICIPANT	\N	PRESENT	0
143681	143676	11029K	PARTICIPANT	\N	PRESENT	0
143682	143676	04042C	PARTICIPANT	\N	PRESENT	0
143683	143676	04094Q	PARTICIPANT	\N	PRESENT	0
159885	159825	11061K	PARTICIPANT	\N	PRESENT	0
159891	159825	08031R	PARTICIPANT	\N	PRESENT	0
159892	159825	08017T	PARTICIPANT	\N	PRESENT	0
159893	159825	07029T	PARTICIPANT	\N	PRESENT	0
159894	159825	14281W	PARTICIPANT	\N	PRESENT	0
159896	159825	09001P	PRESIDENT	0	PRESENT	0
159898	159825	07026Q	PARTICIPANT	\N	PRESENT	0
159900	159825	95035G	PARTICIPANT	\N	PRESENT	0
159901	159825	14031R	PARTICIPANT	\N	PRESENT	0
159918	159825	11029K	PARTICIPANT	\N	EXCUSE	0
159919	159825	14041T	PARTICIPANT	\N	EXCUSE	0
159920	159917	98029W	PARTICIPANT	\N	PRESENT	0
159921	159825	08056B	PARTICIPANT	\N	EXCUSE	0
159922	159825	04036E	PARTICIPANT	\N	EXCUSE	0
159923	159825	11067R	PARTICIPANT	\N	EXCUSE	0
159924	159825	11014C	PARTICIPANT	\N	EXCUSE	0
159925	159825	14237S	PARTICIPANT	\N	EXCUSE	0
161067	161040	14119M	PARTICIPANT	\N	PRESENT	0
160892	160890	14013P	PARTICIPANT	\N	PRESENT	0
160893	160890	08068F	PARTICIPANT	\N	PRESENT	0
160894	160890	14033T	PARTICIPANT	\N	PRESENT	0
161073	161040	04043D	PARTICIPANT	\N	PRESENT	0
161068	161040	14071N	PARTICIPANT	\N	PRESENT	0
161075	161040	11093T	PARTICIPANT	\N	PRESENT	0
160898	160890	11100Y	PARTICIPANT	\N	PRESENT	0
161077	161040	11097X	PARTICIPANT	\N	PRESENT	0
161079	161040	04045F	PARTICIPANT	\N	PRESENT	0
161081	161040	14269B	PARTICIPANT	\N	PRESENT	0
160902	160890	01058X	PARTICIPANT	\N	PRESENT	0
160903	160890	11094U	PARTICIPANT	\N	PRESENT	0
160904	160890	11066Q	PARTICIPANT	\N	PRESENT	0
161223	161222	01031L	PARTICIPANT	\N	PRESENT	0
161224	161222	04061F	PARTICIPANT	\N	PRESENT	0
161232	161222	98046X	PARTICIPANT	\N	PRESENT	0
161238	161236	01031L	PARTICIPANT	\N	PRESENT	0
161239	161236	08011M	PARTICIPANT	\N	PRESENT	0
161241	161240	08011M	PARTICIPANT	\N	PRESENT	0
161242	161240	04086Q	PARTICIPANT	\N	PRESENT	0
161674	160261	14167V	PARTICIPANT	\N	PRESENT	0
161675	160261	11054L	PARTICIPANT	\N	PRESENT	0
161676	160261	08010L	PARTICIPANT	\N	PRESENT	0
161677	160261	08058D	PARTICIPANT	\N	PRESENT	0
161678	160261	11089X	PARTICIPANT	\N	PRESENT	0
161679	160261	98005N	PARTICIPANT	\N	PRESENT	0
161680	160261	11020A	PARTICIPANT	\N	PRESENT	0
161681	160261	05001W	PARTICIPANT	\N	PRESENT	0
161682	160261	14263U	PARTICIPANT	\N	PRESENT	0
161683	160261	14147R	PARTICIPANT	\N	PRESENT	0
161684	160261	01013J	PARTICIPANT	\N	PRESENT	0
161685	160261	11040E	PARTICIPANT	\N	PRESENT	0
161686	160261	14061L	PARTICIPANT	\N	PRESENT	0
161687	160261	01019Q	PARTICIPANT	\N	PRESENT	0
161688	160261	98018T	PARTICIPANT	\N	PRESENT	0
161689	160261	11074Q	PARTICIPANT	\N	PRESENT	0
161690	160261	08060W	PARTICIPANT	\N	PRESENT	0
161691	160261	92020L	PARTICIPANT	\N	PRESENT	0
161692	160261	14363X	PARTICIPANT	\N	PRESENT	0
161693	160261	11036J	PARTICIPANT	\N	PRESENT	0
161694	160261	95059Q	PARTICIPANT	\N	PRESENT	0
161695	160261	14229S	PARTICIPANT	\N	PRESENT	0
161696	160261	14028W	PARTICIPANT	\N	PRESENT	0
161697	160261	11043H	PARTICIPANT	\N	PRESENT	0
161698	160261	98024R	PARTICIPANT	\N	PRESENT	0
161699	160261	14251Q	PARTICIPANT	\N	PRESENT	0
161700	160261	04095R	PARTICIPANT	\N	PRESENT	0
161701	160261	04047H	PARTICIPANT	\N	PRESENT	0
161702	160261	04045F	PARTICIPANT	\N	PRESENT	0
161703	160261	01028R	PARTICIPANT	\N	PRESENT	0
161704	160261	97011G	PARTICIPANT	\N	PRESENT	0
161705	160261	14265W	PARTICIPANT	\N	PRESENT	0
161706	160261	05008E	PARTICIPANT	\N	PRESENT	0
161707	160261	04033B	PARTICIPANT	\N	PRESENT	0
161708	160261	11035H	PARTICIPANT	\N	PRESENT	0
161709	160261	14169X	PARTICIPANT	\N	PRESENT	0
161710	160261	04053F	PARTICIPANT	\N	PRESENT	0
161711	160261	14017T	PARTICIPANT	\N	PRESENT	0
161712	160261	08024S	PARTICIPANT	\N	PRESENT	0
161713	160261	11106F	PARTICIPANT	\N	PRESENT	0
161714	160261	11091R	PARTICIPANT	\N	PRESENT	0
161715	160261	95037J	PARTICIPANT	\N	PRESENT	0
161716	160261	14191V	PARTICIPANT	\N	PRESENT	0
161717	160261	11083R	PARTICIPANT	\N	PRESENT	0
161718	160261	01044R	PARTICIPANT	\N	PRESENT	0
161719	160261	04067M	PARTICIPANT	\N	PRESENT	0
161720	160261	01046T	PARTICIPANT	\N	PRESENT	0
161721	160261	14071N	PARTICIPANT	\N	PRESENT	0
161722	160261	04078Q	PARTICIPANT	\N	PRESENT	0
161723	160261	14087W	PARTICIPANT	\N	PRESENT	0
161724	160261	14241N	PARTICIPANT	\N	PRESENT	0
161725	160261	08031R	PARTICIPANT	\N	PRESENT	0
161726	160261	14018U	PARTICIPANT	\N	PRESENT	0
161727	160261	14249W	PARTICIPANT	\N	PRESENT	0
161728	160261	11096W	PARTICIPANT	\N	PRESENT	0
161729	160261	04074L	PARTICIPANT	\N	PRESENT	0
161730	160261	11081P	PARTICIPANT	\N	PRESENT	0
161731	160261	14329V	PARTICIPANT	\N	PRESENT	0
161732	160261	14259Y	PARTICIPANT	\N	PRESENT	0
161733	160261	08035V	PARTICIPANT	\N	PRESENT	0
161734	160261	11084S	PARTICIPANT	\N	PRESENT	0
161735	160261	04035D	PARTICIPANT	\N	PRESENT	0
161736	160261	14039A	PARTICIPANT	\N	PRESENT	0
161737	160261	04077P	PARTICIPANT	\N	PRESENT	0
161738	160261	14031R	PARTICIPANT	\N	PRESENT	0
161739	160261	08061X	PARTICIPANT	\N	PRESENT	0
161740	160261	14105F	PARTICIPANT	\N	PRESENT	0
161741	160261	04088S	PARTICIPANT	\N	PRESENT	0
161742	160261	92044U	PARTICIPANT	\N	PRESENT	0
161743	160261	89017R	PARTICIPANT	\N	PRESENT	0
161744	160261	04059M	PARTICIPANT	\N	PRESENT	0
161745	160261	08019V	PARTICIPANT	\N	PRESENT	0
161746	160261	14065Q	PARTICIPANT	\N	PRESENT	0
161747	160261	14357A	PARTICIPANT	\N	PRESENT	0
161752	160261	07034Q	PARTICIPANT	\N	PRESENT	0
161753	160261	11032E	PARTICIPANT	\N	PRESENT	0
161754	160261	04044E	PARTICIPANT	\N	PRESENT	0
161755	160261	08051V	PARTICIPANT	\N	PRESENT	0
161756	160261	01060R	PARTICIPANT	\N	PRESENT	0
161757	160261	14239U	PARTICIPANT	\N	PRESENT	0
161773	160261	14030Q	PARTICIPANT	\N	PRESENT	0
161774	160261	01047U	PARTICIPANT	\N	PRESENT	0
161775	160261	83047W	PARTICIPANT	\N	PRESENT	0
161776	160261	01034P	PARTICIPANT	\N	PRESENT	0
161777	160261	11068S	PARTICIPANT	\N	PRESENT	0
161792	160261	11111C	PARTICIPANT	\N	PRESENT	0
161793	160261	04079R	PARTICIPANT	\N	PRESENT	0
161794	160261	11085T	PARTICIPANT	\N	PRESENT	0
161795	160261	08012N	PARTICIPANT	\N	PRESENT	0
161796	160261	04070G	PARTICIPANT	\N	PRESENT	0
161797	160261	11037K	PARTICIPANT	\N	PRESENT	0
161798	160261	14227Q	PARTICIPANT	\N	PRESENT	0
161799	160261	14275Y	PARTICIPANT	\N	PRESENT	0
161800	160261	11070L	PARTICIPANT	\N	PRESENT	0
161801	160261	14255U	PARTICIPANT	\N	PRESENT	0
161802	160261	01016M	PARTICIPANT	\N	PRESENT	0
161803	160261	14179A	PARTICIPANT	\N	PRESENT	0
161804	160261	04040A	PARTICIPANT	\N	PRESENT	0
161805	160261	11064N	PARTICIPANT	\N	PRESENT	0
161806	160261	01007L	PARTICIPANT	\N	PRESENT	0
161807	160261	08056B	PARTICIPANT	\N	PRESENT	0
161808	160261	07004J	PARTICIPANT	\N	PRESENT	0
161809	160261	14331P	PARTICIPANT	\N	PRESENT	0
161810	160261	14038Y	PARTICIPANT	\N	PRESENT	0
161818	160261	14213J	PARTICIPANT	\N	PRESENT	0
161819	160261	11048N	PARTICIPANT	\N	PRESENT	0
161825	160261	14205J	PARTICIPANT	\N	PRESENT	0
161832	160261	95049N	PARTICIPANT	\N	PRESENT	0
161833	160261	14253S	PARTICIPANT	\N	PRESENT	0
161834	160261	14119M	PARTICIPANT	\N	PRESENT	0
130066	124148	01058X	PARTICIPANT	\N	EXCUSE	0
130106	124148	04043D	PRESIDENT	0	PRESENT	0
131625	131573	01013J	PARTICIPANT	\N	PRESENT	0
131626	131573	14175V	PARTICIPANT	\N	PRESENT	0
131627	131573	14083S	PARTICIPANT	\N	PRESENT	0
131628	131573	14085U	PARTICIPANT	\N	PRESENT	0
131629	131573	04086Q	PARTICIPANT	\N	PRESENT	0
131630	131573	11070L	PARTICIPANT	\N	PRESENT	0
131633	131573	11088W	PARTICIPANT	\N	PRESENT	0
131634	131573	04071H	PARTICIPANT	\N	PRESENT	0
131637	131573	98053W	PARTICIPANT	\N	EXCUSE	0
131638	131573	01057W	PARTICIPANT	\N	PRESENT	0
131639	131573	08069G	PARTICIPANT	\N	PRESENT	0
131640	131573	99004R	PARTICIPANT	\N	PRESENT	0
131641	131573	14159V	PARTICIPANT	\N	PRESENT	0
131642	131573	07029T	PARTICIPANT	\N	PRESENT	0
131643	131573	08010L	PARTICIPANT	\N	PRESENT	0
131644	131573	08034U	PARTICIPANT	\N	PRESENT	0
131646	131573	98046X	PARTICIPANT	\N	PRESENT	0
131647	131573	08061X	PARTICIPANT	\N	PRESENT	0
131648	131573	14225N	PARTICIPANT	\N	PRESENT	0
131649	131573	04034C	PARTICIPANT	\N	PRESENT	0
131652	131573	08011M	PARTICIPANT	\N	EXCUSE	0
131653	131573	08073C	PARTICIPANT	\N	EXCUSE	0
132880	132879	11068S	PARTICIPANT	\N	PRESENT	0
134607	134606	11056N	PARTICIPANT	\N	PRESENT	0
136186	135575	95059Q	PARTICIPANT	\N	PRESENT	0
136187	135575	08010L	PARTICIPANT	\N	PRESENT	0
136188	135575	01059Y	PARTICIPANT	\N	PRESENT	0
136190	135575	01058X	PARTICIPANT	\N	PRESENT	0
136191	135575	14259Y	PARTICIPANT	\N	PRESENT	0
136192	135575	11056N	PARTICIPANT	\N	PRESENT	0
136193	135575	14111D	PARTICIPANT	\N	PRESENT	0
136194	135575	01015L	PARTICIPANT	\N	PRESENT	0
136195	135575	07034Q	PARTICIPANT	\N	PRESENT	0
136196	135575	11031D	PARTICIPANT	\N	PRESENT	0
136197	135575	11034G	PARTICIPANT	\N	PRESENT	0
136198	135575	14211G	PARTICIPANT	\N	PRESENT	0
136199	135575	11048N	PARTICIPANT	\N	PRESENT	0
136200	135575	11066Q	PARTICIPANT	\N	PRESENT	0
136201	135575	95015C	PARTICIPANT	\N	PRESENT	0
136203	135575	11083R	PARTICIPANT	\N	PRESENT	0
136204	135575	11033F	PARTICIPANT	\N	PRESENT	0
136205	135575	01044R	PARTICIPANT	\N	PRESENT	0
131623	131573	89017R	PARTICIPANT	\N	PRESENT	0
131624	131573	01031L	PRESIDENT	0	PRESENT	0
136206	135575	08042U	PARTICIPANT	\N	PRESENT	0
136207	135575	08034U	PARTICIPANT	\N	PRESENT	0
136208	135575	01060R	PARTICIPANT	\N	PRESENT	0
136209	135575	04047H	PARTICIPANT	\N	PRESENT	0
136210	135575	08021P	PARTICIPANT	\N	PRESENT	0
136211	135575	01046T	PARTICIPANT	\N	PRESENT	0
136212	135575	88008L	PARTICIPANT	\N	PRESENT	0
136213	135575	04078Q	PARTICIPANT	\N	PRESENT	0
136214	135575	01027Q	PARTICIPANT	\N	PRESENT	0
136215	135575	08051V	PARTICIPANT	\N	PRESENT	0
136216	135575	11012A	PARTICIPANT	\N	PRESENT	0
136218	135575	04071H	PARTICIPANT	\N	PRESENT	0
136219	135575	14018U	PARTICIPANT	\N	PRESENT	0
136220	135575	11081P	PARTICIPANT	\N	PRESENT	0
136221	135575	05008E	PARTICIPANT	\N	PRESENT	0
136222	135575	11096W	PARTICIPANT	\N	PRESENT	0
136223	135575	14193X	PARTICIPANT	\N	PRESENT	0
136224	135575	04038G	PARTICIPANT	\N	PRESENT	0
136225	135575	96004D	PARTICIPANT	\N	PRESENT	0
136226	135575	11113E	PARTICIPANT	\N	PRESENT	0
136227	135575	01003G	PARTICIPANT	\N	PRESENT	0
136228	135575	11071M	PARTICIPANT	\N	PRESENT	0
136229	135575	14251Q	PARTICIPANT	\N	PRESENT	0
136230	135575	14037X	PARTICIPANT	\N	PRESENT	0
136231	135575	95063L	PARTICIPANT	\N	PRESENT	0
136232	135575	14213J	PARTICIPANT	\N	PRESENT	0
136233	135575	08055A	PARTICIPANT	\N	PRESENT	0
136234	135575	11091R	PARTICIPANT	\N	PRESENT	0
136235	135575	92020L	PARTICIPANT	\N	PRESENT	0
136236	135575	08060W	PARTICIPANT	\N	PRESENT	0
136237	135575	80013X	PARTICIPANT	\N	PRESENT	0
136238	135575	07032N	PARTICIPANT	\N	PRESENT	0
136239	135575	14028W	PARTICIPANT	\N	PRESENT	0
136240	135575	11076S	PARTICIPANT	\N	PRESENT	0
136241	135575	92031P	PARTICIPANT	\N	PRESENT	0
136242	135575	08053X	PARTICIPANT	\N	PRESENT	0
136243	135575	11015D	PARTICIPANT	\N	PRESENT	0
136244	135575	08043V	PARTICIPANT	\N	PRESENT	0
136245	135575	11065P	PARTICIPANT	\N	PRESENT	0
136246	135575	11055M	PARTICIPANT	\N	PRESENT	0
136247	135575	10015M	PARTICIPANT	\N	PRESENT	0
136248	135575	98021N	PARTICIPANT	\N	PRESENT	0
136249	135575	11105E	PARTICIPANT	\N	PRESENT	0
136250	135575	08012N	PARTICIPANT	\N	PRESENT	0
136251	135575	04034C	PARTICIPANT	\N	PRESENT	0
136252	135575	08017T	PARTICIPANT	\N	PRESENT	0
136253	135575	14087W	PARTICIPANT	\N	PRESENT	0
136254	135575	11059R	PARTICIPANT	\N	PRESENT	0
136255	135575	83042R	PARTICIPANT	\N	PRESENT	0
136256	135575	11046L	PARTICIPANT	\N	PRESENT	0
136257	135575	14014Q	PARTICIPANT	\N	PRESENT	0
136258	135575	14109K	PARTICIPANT	\N	PRESENT	0
136259	135575	08014Q	PARTICIPANT	\N	PRESENT	0
136260	135575	95067Q	PARTICIPANT	\N	PRESENT	0
136261	135575	14001X	PARTICIPANT	\N	PRESENT	0
136262	135575	11090Q	PARTICIPANT	\N	PRESENT	0
136263	135575	01008M	PARTICIPANT	\N	PRESENT	0
136264	135575	11089X	PARTICIPANT	\N	PRESENT	0
136265	135575	11099A	PARTICIPANT	\N	PRESENT	0
136266	135575	14247U	PARTICIPANT	\N	PRESENT	0
136267	135575	98029W	PARTICIPANT	\N	PRESENT	0
136268	135575	14229S	PARTICIPANT	\N	PRESENT	0
136269	135575	14063N	PARTICIPANT	\N	PRESENT	0
136270	135575	11074Q	PARTICIPANT	\N	PRESENT	0
136271	135575	14257W	PARTICIPANT	\N	PRESENT	0
136272	135575	11014C	PARTICIPANT	\N	PRESENT	0
136273	135575	08061X	PARTICIPANT	\N	PRESENT	0
136274	135575	04053F	PARTICIPANT	\N	PRESENT	0
136275	135575	14329V	PARTICIPANT	\N	PRESENT	0
136276	135575	11110B	PARTICIPANT	\N	PRESENT	0
136277	135575	08018U	PARTICIPANT	\N	PRESENT	0
136278	135575	08038Y	PARTICIPANT	\N	PRESENT	0
136279	135575	92039X	PARTICIPANT	\N	PRESENT	0
136280	135575	11035H	PARTICIPANT	\N	PRESENT	0
136281	135575	08024S	PARTICIPANT	\N	PRESENT	0
136282	135575	01037S	PARTICIPANT	\N	PRESENT	0
136283	135575	04059M	PARTICIPANT	\N	PRESENT	0
136284	135575	14085U	PARTICIPANT	\N	PRESENT	0
136285	135575	11106F	PARTICIPANT	\N	PRESENT	0
136286	135575	14081Q	PARTICIPANT	\N	PRESENT	0
136287	135575	14253S	PARTICIPANT	\N	PRESENT	0
136288	135575	99002P	PARTICIPANT	\N	PRESENT	0
136289	135575	11032E	PARTICIPANT	\N	PRESENT	0
136290	135575	90003B	PARTICIPANT	\N	PRESENT	0
136291	135575	11077T	PARTICIPANT	\N	PRESENT	0
136292	135575	11042G	PARTICIPANT	\N	PRESENT	0
136293	135575	05012A	PARTICIPANT	\N	PRESENT	0
136294	135575	14269B	PARTICIPANT	\N	PRESENT	0
136295	135575	01014K	PARTICIPANT	\N	PRESENT	0
136296	135575	11061K	PARTICIPANT	\N	PRESENT	0
136297	135575	12042Y	PARTICIPANT	\N	PRESENT	0
136298	135575	14207L	PARTICIPANT	\N	PRESENT	0
136299	135575	11114F	PARTICIPANT	\N	PRESENT	0
136300	135575	08073C	PARTICIPANT	\N	PRESENT	0
136301	135575	95049N	PARTICIPANT	\N	PRESENT	0
136302	135575	11011M	PARTICIPANT	\N	PRESENT	0
136303	135575	01034P	PARTICIPANT	\N	PRESENT	0
136304	135575	11094U	PARTICIPANT	\N	PRESENT	0
136305	135575	14179A	PARTICIPANT	\N	PRESENT	0
136306	135575	11053K	PARTICIPANT	\N	PRESENT	0
136307	135575	04080J	PARTICIPANT	\N	PRESENT	0
136308	135575	14034U	PARTICIPANT	\N	PRESENT	0
136309	135575	11064N	PARTICIPANT	\N	PRESENT	0
136310	135575	14267Y	PARTICIPANT	\N	PRESENT	0
136311	135575	14219Q	PARTICIPANT	\N	PRESENT	0
136312	135575	14239U	PARTICIPANT	\N	PRESENT	0
136313	135575	01007L	PARTICIPANT	\N	PRESENT	0
136314	135575	07004J	PARTICIPANT	\N	PRESENT	0
136315	135575	08056B	PARTICIPANT	\N	PRESENT	0
136316	135575	01025N	PARTICIPANT	\N	PRESENT	0
136317	135575	11085T	PARTICIPANT	\N	PRESENT	0
136318	135575	01047U	PARTICIPANT	\N	PRESENT	0
136319	135575	14073Q	PARTICIPANT	\N	PRESENT	0
136320	135575	14205J	PARTICIPANT	\N	PRESENT	0
136321	135575	09001P	PARTICIPANT	\N	PRESENT	0
136322	135575	98042T	PARTICIPANT	\N	PRESENT	0
148497	147603	11039M	PARTICIPANT	\N	PRESENT	0
148501	147603	01047U	PARTICIPANT	\N	PRESENT	0
148504	147603	14215L	PARTICIPANT	\N	PRESENT	0
148505	147603	08051V	PARTICIPANT	\N	PRESENT	0
148506	147603	01046T	PARTICIPANT	\N	PRESENT	0
148510	147603	04045F	PARTICIPANT	\N	PRESENT	0
148514	147603	05008E	PARTICIPANT	\N	PRESENT	0
148517	147603	10006L	PARTICIPANT	\N	PRESENT	0
148522	147603	14169X	PARTICIPANT	\N	PRESENT	0
148526	147603	14031R	PARTICIPANT	\N	PRESENT	0
148529	147603	08034U	PARTICIPANT	\N	PRESENT	0
148533	147603	04088S	PARTICIPANT	\N	PRESENT	0
148536	147603	07029T	PARTICIPANT	\N	PRESENT	0
148542	147603	04061F	PARTICIPANT	\N	PRESENT	0
148543	147603	07034Q	PARTICIPANT	\N	PRESENT	0
148544	147603	04053F	PARTICIPANT	\N	PRESENT	0
148545	147603	11061K	PARTICIPANT	\N	PRESENT	0
148546	147603	14199E	PARTICIPANT	\N	PRESENT	0
148547	147603	14135M	PARTICIPANT	\N	PRESENT	0
148548	147603	92045V	PARTICIPANT	\N	PRESENT	0
148549	147603	14061L	PARTICIPANT	\N	PRESENT	0
148550	147603	11055M	PARTICIPANT	\N	PRESENT	0
148563	147603	04059M	PARTICIPANT	\N	PRESENT	0
148565	147603	01031L	PARTICIPANT	\N	PRESENT	0
148575	147603	08069G	PARTICIPANT	\N	PRESENT	0
148579	147603	14263U	PARTICIPANT	\N	PRESENT	0
148583	147603	14179A	PARTICIPANT	\N	PRESENT	0
148588	147603	14026U	PARTICIPANT	\N	PRESENT	0
148608	147603	08010L	PARTICIPANT	\N	PRESENT	0
148609	147603	01007L	PARTICIPANT	\N	PRESENT	0
148610	147603	01043Q	PARTICIPANT	\N	PRESENT	0
148612	147603	08053X	PARTICIPANT	\N	PRESENT	0
148613	147603	13002U	PARTICIPANT	\N	PRESENT	0
148614	147603	11042G	PARTICIPANT	\N	PRESENT	0
148615	147603	01003G	PARTICIPANT	\N	PRESENT	0
148616	147603	14327T	PARTICIPANT	\N	PRESENT	0
148617	147603	11010L	PARTICIPANT	\N	PRESENT	0
148618	147603	11105E	PARTICIPANT	\N	PRESENT	0
148619	147603	08017T	PARTICIPANT	\N	PRESENT	0
148626	147603	92031P	PARTICIPANT	\N	PRESENT	0
148627	147603	01011G	PARTICIPANT	\N	PRESENT	0
148628	147603	11012A	PARTICIPANT	\N	PRESENT	0
148629	147603	04067M	PARTICIPANT	\N	PRESENT	0
148630	147603	07026Q	PARTICIPANT	\N	PRESENT	0
148631	147603	01015L	PARTICIPANT	\N	PRESENT	0
148632	147603	14205J	PARTICIPANT	\N	PRESENT	0
148633	147603	08019V	PARTICIPANT	\N	PRESENT	0
148646	147603	14037X	PARTICIPANT	\N	PRESENT	0
148647	147603	14069U	PARTICIPANT	\N	PRESENT	0
148648	147603	97011G	PARTICIPANT	\N	PRESENT	0
148649	147603	08015R	PARTICIPANT	\N	PRESENT	0
148650	147603	98022P	PARTICIPANT	\N	PRESENT	0
148651	147603	14331P	PARTICIPANT	\N	PRESENT	0
148652	147603	04038G	PARTICIPANT	\N	PRESENT	0
148653	147603	14033T	PARTICIPANT	\N	PRESENT	0
148654	147603	14209N	PARTICIPANT	\N	PRESENT	0
148655	147603	14093U	PARTICIPANT	\N	PRESENT	0
148656	147603	01016M	PARTICIPANT	\N	PRESENT	0
148657	147603	14059S	PARTICIPANT	\N	PRESENT	0
148672	147603	14041T	PARTICIPANT	\N	PRESENT	0
148673	147603	11048N	PARTICIPANT	\N	PRESENT	0
148674	147603	95035G	PARTICIPANT	\N	PRESENT	0
148675	147603	05012A	PARTICIPANT	\N	PRESENT	0
148676	147603	98024R	PARTICIPANT	\N	PRESENT	0
148677	147603	11090Q	PARTICIPANT	\N	PRESENT	0
148678	147603	95063L	PARTICIPANT	\N	PRESENT	0
148712	147603	11084S	PARTICIPANT	\N	PRESENT	0
148735	147603	14097Y	PARTICIPANT	\N	PRESENT	0
148736	147603	14014Q	PARTICIPANT	\N	PRESENT	0
148738	148737	14239U	PARTICIPANT	\N	PRESENT	0
148795	147603	11064N	PARTICIPANT	\N	PRESENT	0
148796	147603	14225N	PARTICIPANT	\N	PRESENT	0
148741	148737	04053F	PARTICIPANT	\N	PRESENT	0
148742	148737	14255U	PARTICIPANT	\N	PRESENT	0
148743	148737	04066L	PARTICIPANT	\N	PRESENT	0
148744	148737	00003C	PARTICIPANT	\N	EXCUSE	0
148746	148737	11103C	PARTICIPANT	\N	PRESENT	0
148747	148737	11044J	PARTICIPANT	\N	PRESENT	0
148748	148737	14195A	PARTICIPANT	\N	PRESENT	0
148749	148737	14267Y	PARTICIPANT	\N	PRESENT	0
148954	147610	01007L	PARTICIPANT	\N	PRESENT	0
148751	148737	11031D	PARTICIPANT	\N	PRESENT	0
148752	148737	08052W	PARTICIPANT	\N	PRESENT	0
148754	148737	04081K	PARTICIPANT	\N	PRESENT	0
148755	148737	98024R	PARTICIPANT	\N	PRESENT	0
148756	148737	10006L	PARTICIPANT	\N	PRESENT	0
148972	147610	11036J	PARTICIPANT	\N	PRESENT	0
148758	148737	14217N	PARTICIPANT	\N	PRESENT	0
148759	148737	14042U	PARTICIPANT	\N	EXCUSE	0
148973	147610	14107H	PARTICIPANT	\N	PRESENT	0
148761	148737	12042Y	PARTICIPANT	\N	PRESENT	0
148974	147610	14225N	PARTICIPANT	\N	PRESENT	0
148763	148737	14087W	PARTICIPANT	\N	PRESENT	0
148975	147610	14159V	PARTICIPANT	\N	PRESENT	0
148765	148737	14034U	PARTICIPANT	\N	PRESENT	0
148766	148737	14231L	PARTICIPANT	\N	PRESENT	0
148976	147610	13002U	PARTICIPANT	\N	PRESENT	0
148768	148737	14355X	PARTICIPANT	\N	EXCUSE	0
148769	148737	08048B	PARTICIPANT	\N	PRESENT	0
148770	148737	08041T	PARTICIPANT	\N	PRESENT	0
148771	148737	01011G	PARTICIPANT	\N	PRESENT	0
148772	148737	14026U	PARTICIPANT	\N	PRESENT	0
148773	148737	14213J	PARTICIPANT	\N	PRESENT	0
148774	148737	14121F	PARTICIPANT	\N	PRESENT	0
148775	148737	11112D	PARTICIPANT	\N	EXCUSE	0
148977	147610	04067M	PARTICIPANT	\N	PRESENT	0
148978	147610	14030Q	PARTICIPANT	\N	PRESENT	0
148778	148737	11067R	PARTICIPANT	\N	EXCUSE	0
148779	148737	14223L	PARTICIPANT	\N	PRESENT	0
148780	148737	04092N	PRESIDENT	0	PRESENT	0
148781	148737	14265W	PARTICIPANT	\N	PRESENT	0
148782	148737	14119M	PARTICIPANT	\N	PRESENT	0
148783	148737	14071N	PARTICIPANT	\N	PRESENT	0
148979	147610	14089Y	PARTICIPANT	\N	PRESENT	0
148785	148737	14271U	PARTICIPANT	\N	PRESENT	0
148980	147610	14241N	PARTICIPANT	\N	PRESENT	0
148787	148737	11093T	PARTICIPANT	\N	PRESENT	0
148981	147610	11029K	PARTICIPANT	\N	PRESENT	0
148789	148737	04045F	PARTICIPANT	\N	PRESENT	0
148982	147610	11083R	PARTICIPANT	\N	PRESENT	0
148983	147610	14195A	PARTICIPANT	\N	PRESENT	0
148984	147610	01044R	PARTICIPANT	\N	PRESENT	0
148793	148737	11063M	PARTICIPANT	\N	PRESENT	0
148794	148737	14269B	PARTICIPANT	\N	PRESENT	0
148985	147610	11099A	PARTICIPANT	\N	PRESENT	0
148986	147610	11033F	PARTICIPANT	\N	PRESENT	0
148987	147610	01015L	PARTICIPANT	\N	PRESENT	0
148988	147610	05012A	PARTICIPANT	\N	PRESENT	0
148989	147610	08069G	PARTICIPANT	\N	PRESENT	0
148990	147610	08039A	PARTICIPANT	\N	PRESENT	0
148991	147610	14219Q	PARTICIPANT	\N	PRESENT	0
148992	147610	11012A	PARTICIPANT	\N	PRESENT	0
148993	147610	08017T	PARTICIPANT	\N	PRESENT	0
149012	147610	14179A	PARTICIPANT	\N	PRESENT	0
149013	147610	14231L	PARTICIPANT	\N	PRESENT	0
149032	147610	14327T	PARTICIPANT	\N	PRESENT	0
149052	147613	11029K	PARTICIPANT	\N	PRESENT	0
149053	147613	04059M	PARTICIPANT	\N	PRESENT	0
149054	147613	04045F	PARTICIPANT	\N	PRESENT	0
149055	147613	01044R	PARTICIPANT	\N	PRESENT	0
149056	147613	11083R	PARTICIPANT	\N	PRESENT	0
149057	147613	07026Q	PARTICIPANT	\N	PRESENT	0
149058	147613	14263U	PARTICIPANT	\N	PRESENT	0
149059	147613	11099A	PARTICIPANT	\N	PRESENT	0
149060	147613	13002U	PARTICIPANT	\N	PRESENT	0
149061	147613	14249W	PARTICIPANT	\N	PRESENT	0
149062	147613	08039A	PARTICIPANT	\N	PRESENT	0
149063	147613	08017T	PARTICIPANT	\N	PRESENT	0
149064	147613	14073Q	PARTICIPANT	\N	PRESENT	0
149065	147613	08031R	PARTICIPANT	\N	PRESENT	0
149066	147613	04070G	PARTICIPANT	\N	PRESENT	0
149067	147613	11061K	PARTICIPANT	\N	PRESENT	0
149068	147613	14135M	PARTICIPANT	\N	PRESENT	0
149069	147613	14219Q	PARTICIPANT	\N	PRESENT	0
149072	147613	04040A	PARTICIPANT	\N	PRESENT	0
149073	147613	14179A	PARTICIPANT	\N	PRESENT	0
149112	147613	14083S	PARTICIPANT	\N	PRESENT	0
149113	147613	14059S	PARTICIPANT	\N	PRESENT	0
149376	149375	14157T	PARTICIPANT	\N	PRESENT	0
149378	149377	14157T	PARTICIPANT	\N	PRESENT	0
149380	149379	14093U	PARTICIPANT	\N	PRESENT	0
149381	149379	14157T	PARTICIPANT	\N	PRESENT	0
149383	149382	14157T	PARTICIPANT	\N	PRESENT	0
149393	149392	11033F	PARTICIPANT	\N	PRESENT	0
149602	149592	00003C	PARTICIPANT	\N	EXCUSE	0
149603	149592	14042U	PARTICIPANT	\N	EXCUSE	0
149604	149592	14231L	PARTICIPANT	\N	EXCUSE	0
131556	131555	14175V	PARTICIPANT	\N	PRESENT	0
131557	131555	14085U	PARTICIPANT	\N	PRESENT	0
139549	137569	01027Q	PARTICIPANT	\N	EXCUSE	0
161066	161040	14265W	PARTICIPANT	\N	PRESENT	0
161072	160259	14191V	PARTICIPANT	\N	PRESENT	0
161074	160259	01022K	PARTICIPANT	\N	PRESENT	0
161076	160259	05001W	PARTICIPANT	\N	PRESENT	0
161078	160259	11037K	PARTICIPANT	\N	PRESENT	0
161080	160259	11106F	PARTICIPANT	\N	PRESENT	0
161082	160259	14355X	PARTICIPANT	\N	PRESENT	0
161083	160259	14083S	PARTICIPANT	\N	PRESENT	0
161084	160259	14179A	PARTICIPANT	\N	PRESENT	0
161085	160259	11072N	PARTICIPANT	\N	PRESENT	0
161086	160259	11055M	PARTICIPANT	\N	PRESENT	0
161087	160259	11036J	PARTICIPANT	\N	PRESENT	0
161088	160259	04085P	PARTICIPANT	\N	PRESENT	0
161089	160259	14061L	PARTICIPANT	\N	PRESENT	0
161090	160259	80013X	PARTICIPANT	\N	PRESENT	0
161091	160259	04095R	PARTICIPANT	\N	PRESENT	0
161092	160259	08055A	PARTICIPANT	\N	PRESENT	0
161093	160259	97011G	PARTICIPANT	\N	PRESENT	0
161094	160259	11081P	PARTICIPANT	\N	PRESENT	0
161095	160259	08062Y	PARTICIPANT	\N	PRESENT	0
161096	160259	11011M	PARTICIPANT	\N	PRESENT	0
161098	160259	14121F	PARTICIPANT	\N	PRESENT	0
161099	160259	04045F	PARTICIPANT	\N	PRESENT	0
161100	160259	12042Y	PARTICIPANT	\N	PRESENT	0
161101	160259	01028R	PARTICIPANT	\N	PRESENT	0
161102	160259	11067R	PARTICIPANT	\N	PRESENT	0
161103	160259	04094Q	PARTICIPANT	\N	PRESENT	0
161104	160259	11114F	PARTICIPANT	\N	PRESENT	0
161105	160259	14109K	PARTICIPANT	\N	PRESENT	0
161106	160259	08068F	PARTICIPANT	\N	PRESENT	0
161107	160259	14014Q	PARTICIPANT	\N	PRESENT	0
161108	160259	08073C	PARTICIPANT	\N	PRESENT	0
161109	160259	11026G	PARTICIPANT	\N	PRESENT	0
161110	160259	11063M	PARTICIPANT	\N	PRESENT	0
161111	160259	11040E	PARTICIPANT	\N	PRESENT	0
161112	160259	14079W	PARTICIPANT	\N	PRESENT	0
161113	160259	14275Y	PARTICIPANT	\N	PRESENT	0
161114	160259	14261S	PARTICIPANT	\N	PRESENT	0
161115	160259	14073Q	PARTICIPANT	\N	PRESENT	0
161116	160259	11111C	PARTICIPANT	\N	PRESENT	0
161117	160259	14017T	PARTICIPANT	\N	PRESENT	0
161118	160259	11020A	PARTICIPANT	\N	PRESENT	0
161119	160259	98005N	PARTICIPANT	\N	PRESENT	0
161120	160259	07029T	PARTICIPANT	\N	PRESENT	0
161121	160259	11071M	PARTICIPANT	\N	PRESENT	0
161122	160259	08015R	PARTICIPANT	\N	PRESENT	0
161123	160259	14071N	PARTICIPANT	\N	PRESENT	0
161132	160259	05008E	PARTICIPANT	\N	PRESENT	0
161133	160259	08028W	PARTICIPANT	\N	PRESENT	0
161134	160259	11100Y	PARTICIPANT	\N	PRESENT	0
161135	160259	95067Q	PARTICIPANT	\N	PRESENT	0
161136	160259	08039A	PARTICIPANT	\N	PRESENT	0
161137	160259	95062K	PARTICIPANT	\N	PRESENT	0
161138	160259	01057W	PARTICIPANT	\N	PRESENT	0
161139	160259	90003B	PARTICIPANT	\N	PRESENT	0
161140	160259	95031C	PARTICIPANT	\N	PRESENT	0
161141	160259	01027Q	PARTICIPANT	\N	PRESENT	0
161142	160259	95030B	PARTICIPANT	\N	PRESENT	0
161143	160259	14225N	PARTICIPANT	\N	PRESENT	0
161144	160259	14042U	PARTICIPANT	\N	PRESENT	0
161145	160259	14219Q	PARTICIPANT	\N	PRESENT	0
161146	160259	14103D	PARTICIPANT	\N	PRESENT	0
161147	160259	14267Y	PARTICIPANT	\N	PRESENT	0
161148	160259	14197C	PARTICIPANT	\N	PRESENT	0
161149	160259	14281W	PARTICIPANT	\N	PRESENT	0
161150	160259	01015L	PARTICIPANT	\N	PRESENT	0
161151	160259	14001X	PARTICIPANT	\N	PRESENT	0
161152	160259	11082Q	PARTICIPANT	\N	PRESENT	0
161153	160259	11093T	PARTICIPANT	\N	PRESENT	0
161154	160259	11066Q	PARTICIPANT	\N	PRESENT	0
161155	160259	08043V	PARTICIPANT	\N	PRESENT	0
161156	160259	14257W	PARTICIPANT	\N	PRESENT	0
161157	160259	92015P	PARTICIPANT	\N	PRESENT	0
161158	160259	14081Q	PARTICIPANT	\N	PRESENT	0
161159	160259	11042G	PARTICIPANT	\N	PRESENT	0
161160	160259	11113E	PARTICIPANT	\N	PRESENT	0
161161	160259	11109J	PARTICIPANT	\N	PRESENT	0
161162	160259	08009T	PARTICIPANT	\N	PRESENT	0
161163	160259	04043D	PARTICIPANT	\N	PRESENT	0
161164	160259	14363X	PARTICIPANT	\N	PRESENT	0
161165	160259	98053W	PARTICIPANT	\N	PRESENT	0
161166	160259	04097T	PARTICIPANT	\N	PRESENT	0
161167	160259	11049P	PARTICIPANT	\N	PRESENT	0
161168	160259	14221J	PARTICIPANT	\N	PRESENT	0
161169	160259	08010L	PARTICIPANT	\N	PRESENT	0
161172	160259	08056B	PARTICIPANT	\N	PRESENT	0
161192	160259	11027H	PARTICIPANT	\N	PRESENT	0
161193	160259	14026U	PARTICIPANT	\N	PRESENT	0
161194	160259	14265W	PARTICIPANT	\N	PRESENT	0
161195	160259	14167V	PARTICIPANT	\N	PRESENT	0
161196	160259	04057K	PARTICIPANT	\N	PRESENT	0
161197	160259	11104D	PARTICIPANT	\N	PRESENT	0
161198	160259	14361V	PARTICIPANT	\N	PRESENT	0
161199	160259	14231L	PARTICIPANT	\N	PRESENT	0
161200	160259	80027E	PARTICIPANT	\N	PRESENT	0
161201	160259	14063N	PARTICIPANT	\N	PRESENT	0
161202	160259	05012A	PARTICIPANT	\N	PRESENT	0
161203	160259	98050T	PARTICIPANT	\N	PRESENT	0
161204	160259	14269B	PARTICIPANT	\N	PRESENT	0
161205	160259	01043Q	PARTICIPANT	\N	PRESENT	0
161206	160259	14263U	PARTICIPANT	\N	PRESENT	0
161207	160259	14357A	PARTICIPANT	\N	PRESENT	0
161208	160259	92045V	PARTICIPANT	\N	PRESENT	0
161209	160259	14037X	PARTICIPANT	\N	PRESENT	0
161212	160259	11064N	PARTICIPANT	\N	PRESENT	0
161213	160259	14105F	PARTICIPANT	\N	PRESENT	0
161214	160259	95063L	PARTICIPANT	\N	PRESENT	0
161215	160259	14205J	PARTICIPANT	\N	PRESENT	0
161216	160259	86044G	PARTICIPANT	\N	PRESENT	0
161217	160259	04056J	PARTICIPANT	\N	PRESENT	0
161218	160259	04059M	PARTICIPANT	\N	PRESENT	0
161219	160259	14051J	PARTICIPANT	\N	PRESENT	0
161220	160259	01013J	PARTICIPANT	\N	PRESENT	0
161221	160259	08031R	PARTICIPANT	\N	PRESENT	0
161235	160259	14119M	PARTICIPANT	\N	PRESENT	0
161237	160259	04041B	PARTICIPANT	\N	PRESENT	0
161243	160259	14089Y	PARTICIPANT	\N	PRESENT	0
161244	160259	04044E	PARTICIPANT	\N	PRESENT	0
161245	160259	01047U	PARTICIPANT	\N	PRESENT	0
161246	160259	87003B	PARTICIPANT	\N	PRESENT	0
161247	160259	11012A	PARTICIPANT	\N	PRESENT	0
161248	160259	04067M	PARTICIPANT	\N	PRESENT	0
161249	160259	14327T	PARTICIPANT	\N	PRESENT	0
161250	160259	08053X	PARTICIPANT	\N	PRESENT	0
161251	160259	14041T	PARTICIPANT	\N	PRESENT	0
161252	160259	14135M	PARTICIPANT	\N	PRESENT	0
161272	160259	14159V	PARTICIPANT	\N	PRESENT	0
161273	160259	11101A	PARTICIPANT	\N	PRESENT	0
161292	160259	11103C	PARTICIPANT	\N	PRESENT	0
161312	160259	08017T	PARTICIPANT	\N	PRESENT	0
161313	160259	01046T	PARTICIPANT	\N	PRESENT	0
161314	160259	08065C	PARTICIPANT	\N	PRESENT	0
161315	160259	01058X	PARTICIPANT	\N	PRESENT	0
161316	160259	11107G	PARTICIPANT	\N	PRESENT	0
161317	160259	98022P	PARTICIPANT	\N	PRESENT	0
161318	160259	08041T	PARTICIPANT	\N	PRESENT	0
161332	160259	14069U	PARTICIPANT	\N	PRESENT	0
161333	160259	13002U	PARTICIPANT	\N	PRESENT	0
161334	160259	08021P	PARTICIPANT	\N	PRESENT	0
161352	160259	14173T	PARTICIPANT	\N	PRESENT	0
161353	160259	01031L	PARTICIPANT	\N	PRESENT	0
161372	160259	11059R	PARTICIPANT	\N	PRESENT	0
162267	162265	14219Q	PRESIDENT	1	PRESENT	0
162268	162265	11065P	PARTICIPANT	\N	PRESENT	0
162269	162265	01015L	PARTICIPANT	\N	PRESENT	0
162271	162265	13002U	PARTICIPANT	\N	PRESENT	0
162272	162265	90003B	PRESIDENT	0	PRESENT	0
162273	162265	09001P	PARTICIPANT	\N	PRESENT	0
162277	162265	01056V	PARTICIPANT	\N	PRESENT	0
162284	162265	01008M	PARTICIPANT	\N	PRESENT	0
162611	160263	95030B	PARTICIPANT	\N	PRESENT	0
162612	160263	14197C	PARTICIPANT	\N	PRESENT	0
162634	160263	14017T	PARTICIPANT	\N	PRESENT	0
162635	160263	01008M	PARTICIPANT	\N	PRESENT	0
162652	160263	08068F	PARTICIPANT	\N	PRESENT	0
162653	160263	14026U	PARTICIPANT	\N	PRESENT	0
162654	160263	14187A	PARTICIPANT	\N	PRESENT	0
162655	160263	08015R	PARTICIPANT	\N	PRESENT	0
162656	160263	14213J	PARTICIPANT	\N	PRESENT	0
162657	160263	01057W	PARTICIPANT	\N	PRESENT	0
162658	160263	14031R	PARTICIPANT	\N	PRESENT	0
162659	160263	11064N	PARTICIPANT	\N	PRESENT	0
162672	160263	80013X	PARTICIPANT	\N	PRESENT	0
162692	160263	01027Q	PARTICIPANT	\N	PRESENT	0
162712	160263	07029T	PARTICIPANT	\N	PRESENT	0
163072	162732	01007L	PARTICIPANT	\N	PRESENT	0
163073	162732	14259Y	PARTICIPANT	\N	PRESENT	0
162795	162792	01046T	PARTICIPANT	\N	PRESENT	0
162796	162792	04053F	PARTICIPANT	\N	PRESENT	0
162797	162792	14255U	PARTICIPANT	\N	EXCUSE	0
162798	162792	04066L	PARTICIPANT	\N	PRESENT	0
162799	162792	00003C	PARTICIPANT	\N	EXCUSE	0
162800	162792	14053L	PARTICIPANT	\N	PRESENT	0
162801	162792	11103C	PARTICIPANT	\N	PRESENT	0
163074	162732	14217N	PARTICIPANT	\N	PRESENT	0
162803	162792	14195A	PARTICIPANT	\N	PRESENT	0
162804	162792	14267Y	PARTICIPANT	\N	PRESENT	0
162805	162792	11023D	PARTICIPANT	\N	PRESENT	0
162806	162792	11031D	PARTICIPANT	\N	PRESENT	0
162807	162792	08052W	PARTICIPANT	\N	PRESENT	0
163075	162732	05008E	PARTICIPANT	\N	PRESENT	0
162809	162792	04081K	PARTICIPANT	\N	PRESENT	0
162810	162792	98024R	PARTICIPANT	\N	PRESENT	0
162811	162792	10006L	PARTICIPANT	\N	PRESENT	0
163076	162732	04094Q	PARTICIPANT	\N	PRESENT	0
162813	162792	14217N	PARTICIPANT	\N	PRESENT	0
162814	162792	14042U	PARTICIPANT	\N	PRESENT	0
162815	162792	14151M	PARTICIPANT	\N	PRESENT	0
162816	162792	12042Y	PARTICIPANT	\N	PRESENT	0
162817	162792	14281W	PARTICIPANT	\N	PRESENT	0
162818	162792	14087W	PARTICIPANT	\N	PRESENT	0
162609	160263	14355X	PARTICIPANT	\N	PRESENT	0
162610	160263	04049K	PARTICIPANT	\N	PRESENT	0
163077	162732	14039A	PARTICIPANT	\N	PRESENT	0
162820	162792	14034U	PARTICIPANT	\N	PRESENT	0
162821	162792	14231L	PARTICIPANT	\N	PRESENT	0
162822	162792	11061K	PARTICIPANT	\N	PRESENT	0
162823	162792	14355X	PARTICIPANT	\N	PRESENT	0
162824	162792	08048B	PARTICIPANT	\N	PRESENT	0
162825	162792	08041T	PARTICIPANT	\N	PRESENT	0
163078	162732	04095R	PARTICIPANT	\N	PRESENT	0
162827	162792	14026U	PARTICIPANT	\N	PRESENT	0
162828	162792	14213J	PARTICIPANT	\N	PRESENT	0
162829	162792	14121F	PARTICIPANT	\N	PRESENT	0
162830	162792	11112D	PARTICIPANT	\N	PRESENT	0
162831	162792	14037X	PARTICIPANT	\N	PRESENT	0
163079	162732	08019V	PARTICIPANT	\N	PRESENT	0
162833	162792	11067R	PARTICIPANT	\N	PRESENT	0
162834	162792	14223L	PARTICIPANT	\N	EXCUSE	0
162835	162792	04092N	PRESIDENT	0	PRESENT	0
162836	162792	14265W	PARTICIPANT	\N	PRESENT	0
162837	162792	14119M	PARTICIPANT	\N	PRESENT	0
162838	162792	14071N	PARTICIPANT	\N	PRESENT	0
162839	162792	04043D	PARTICIPANT	\N	PRESENT	0
162840	162792	14271U	PARTICIPANT	\N	PRESENT	0
163080	162732	11109J	PARTICIPANT	\N	PRESENT	0
162842	162792	11093T	PARTICIPANT	\N	PRESENT	0
162843	162792	11097X	PARTICIPANT	\N	PRESENT	0
162844	162792	04045F	PARTICIPANT	\N	PRESENT	0
162845	162792	14227Q	PARTICIPANT	\N	PRESENT	0
162846	162792	01034P	PARTICIPANT	\N	PRESENT	0
163081	162732	11023D	PARTICIPANT	\N	PRESENT	0
162848	162792	11063M	PARTICIPANT	\N	PRESENT	0
162849	162792	14269B	PARTICIPANT	\N	PRESENT	0
163259	162732	11042G	PARTICIPANT	\N	PRESENT	0
163083	162732	11113E	PARTICIPANT	\N	PRESENT	0
163085	162732	12042Y	PARTICIPANT	\N	PRESENT	0
163152	162732	14061L	PARTICIPANT	\N	PRESENT	0
163153	162732	11055M	PARTICIPANT	\N	PRESENT	0
163154	162732	11066Q	PARTICIPANT	\N	PRESENT	0
163155	162732	14261S	PARTICIPANT	\N	PRESENT	0
163156	162732	11072N	PARTICIPANT	\N	PRESENT	0
163160	162732	11031D	PARTICIPANT	\N	PRESENT	0
163163	162732	07026Q	PARTICIPANT	\N	PRESENT	0
163170	162732	07029T	PARTICIPANT	\N	PRESENT	0
163183	162732	14073Q	PARTICIPANT	\N	PRESENT	0
163184	162732	01047U	PARTICIPANT	\N	PRESENT	0
163185	162732	08055A	PARTICIPANT	\N	PRESENT	0
163192	162732	08015R	PARTICIPANT	\N	PRESENT	0
163194	162732	11012A	PARTICIPANT	\N	PRESENT	0
163196	162732	14361V	PARTICIPANT	\N	PRESENT	0
163200	162732	04085P	PARTICIPANT	\N	PRESENT	0
163204	162732	05001W	PARTICIPANT	\N	PRESENT	0
163207	162732	14063N	PARTICIPANT	\N	PRESENT	0
163213	162732	11107G	PARTICIPANT	\N	PRESENT	0
163217	162732	14030Q	PARTICIPANT	\N	PRESENT	0
163220	162732	14237S	PARTICIPANT	\N	PRESENT	0
163225	162732	14083S	PARTICIPANT	\N	PRESENT	0
163229	162732	14267Y	PARTICIPANT	\N	PRESENT	0
163233	162732	14059S	PARTICIPANT	\N	PRESENT	0
163235	162732	01022K	PARTICIPANT	\N	PRESENT	0
163236	162732	80027E	PARTICIPANT	\N	PRESENT	0
163237	162732	14041T	PARTICIPANT	\N	PRESENT	0
163238	162732	11020A	PARTICIPANT	\N	PRESENT	0
163239	162732	11114F	PARTICIPANT	\N	PRESENT	0
163240	162732	11067R	PARTICIPANT	\N	PRESENT	0
163241	162732	14103D	PARTICIPANT	\N	PRESENT	0
163242	162732	04043D	PARTICIPANT	\N	PRESENT	0
163243	162732	14026U	PARTICIPANT	\N	PRESENT	0
163244	162732	04088S	PARTICIPANT	\N	PRESENT	0
163245	162732	01057W	PARTICIPANT	\N	PRESENT	0
163247	163246	11103C	PRESIDENT	0	PRESENT	0
163248	163246	08052W	PARTICIPANT	\N	PRESENT	0
163249	162732	14038Y	PARTICIPANT	\N	PRESENT	0
163250	163246	14151M	PARTICIPANT	\N	PRESENT	0
163251	163246	12042Y	PARTICIPANT	\N	PRESENT	0
163252	162732	14105F	PARTICIPANT	\N	PRESENT	0
163253	163246	11093T	PARTICIPANT	\N	PRESENT	0
163254	162732	90003B	PARTICIPANT	\N	PRESENT	0
163255	163246	04092N	PARTICIPANT	\N	EXCUSE	0
163256	163246	14053L	PARTICIPANT	\N	EXCUSE	0
163257	162732	11104D	PARTICIPANT	\N	PRESENT	0
163258	162732	08016S	PARTICIPANT	\N	PRESENT	0
163260	162732	14017T	PARTICIPANT	\N	PRESENT	0
163261	162732	11036J	PARTICIPANT	\N	PRESENT	0
163262	162732	14257W	PARTICIPANT	\N	PRESENT	0
163263	162732	11040E	PARTICIPANT	\N	PRESENT	0
163264	162732	08041T	PARTICIPANT	\N	PRESENT	0
163265	162732	08073C	PARTICIPANT	\N	PRESENT	0
163266	162732	14179A	PARTICIPANT	\N	PRESENT	0
163267	162732	95062K	PARTICIPANT	\N	PRESENT	0
163268	162732	13002U	PARTICIPANT	\N	PRESENT	0
163269	162732	14205J	PARTICIPANT	\N	PRESENT	0
163271	162732	11071M	PARTICIPANT	\N	PRESENT	0
163272	162732	14069U	PARTICIPANT	\N	PRESENT	0
163292	162732	14275Y	PARTICIPANT	\N	PRESENT	0
163293	162732	04056J	PARTICIPANT	\N	PRESENT	0
163294	162732	95030B	PARTICIPANT	\N	PRESENT	0
163295	162732	08010L	PARTICIPANT	\N	PRESENT	0
163296	162732	11093T	PARTICIPANT	\N	PRESENT	0
163297	162732	14355X	PARTICIPANT	\N	PRESENT	0
163298	162732	11063M	PARTICIPANT	\N	PRESENT	0
163299	162732	14269B	PARTICIPANT	\N	PRESENT	0
163312	162732	14109K	PARTICIPANT	\N	PRESENT	0
163332	162732	14119M	PARTICIPANT	\N	PRESENT	0
163333	162732	11011M	PARTICIPANT	\N	PRESENT	0
163334	162732	01034P	PARTICIPANT	\N	PRESENT	0
163335	162732	01031L	PARTICIPANT	\N	PRESENT	0
163336	162732	97011G	PARTICIPANT	\N	PRESENT	0
163337	162732	14157T	PARTICIPANT	\N	PRESENT	0
163338	162732	04081K	PARTICIPANT	\N	PRESENT	0
163339	162732	14363X	PARTICIPANT	\N	PRESENT	0
163340	162732	14199E	PARTICIPANT	\N	PRESENT	0
163352	162732	04057K	PARTICIPANT	\N	PRESENT	0
163353	162732	14159V	PARTICIPANT	\N	PRESENT	0
163354	162732	01044R	PARTICIPANT	\N	PRESENT	0
163394	162732	11103C	PARTICIPANT	\N	PRESENT	0
163412	162732	98042T	PARTICIPANT	\N	PRESENT	0
163413	162732	14173T	PARTICIPANT	\N	PRESENT	0
163414	162732	14281W	PARTICIPANT	\N	PRESENT	0
163415	162732	14231L	PARTICIPANT	\N	PRESENT	0
127270	127191	92031P	PARTICIPANT	\N	PRESENT	0
127271	127191	04054G	PARTICIPANT	\N	PRESENT	0
127272	127191	14327T	PARTICIPANT	\N	PRESENT	0
127273	127191	04067M	PARTICIPANT	\N	PRESENT	0
127274	127191	11106F	PARTICIPANT	\N	PRESENT	0
127275	127191	07004J	PARTICIPANT	\N	PRESENT	0
127276	127191	08069G	PARTICIPANT	\N	PRESENT	0
127277	127191	07024N	PARTICIPANT	\N	PRESENT	0
127278	127191	95031C	PARTICIPANT	\N	PRESENT	0
127279	127191	86044G	PARTICIPANT	\N	PRESENT	0
127268	127191	86034E	PARTICIPANT	\N	PRESENT	0
127281	127191	14038Y	PARTICIPANT	\N	PRESENT	0
127280	127191	14199E	PARTICIPANT	\N	PRESENT	0
127282	127191	14033T	PARTICIPANT	\N	PRESENT	0
127283	127191	14251Q	PARTICIPANT	\N	PRESENT	0
127284	127191	92015P	PARTICIPANT	\N	PRESENT	0
127285	127191	11054L	PARTICIPANT	\N	PRESENT	0
127286	127191	04085P	PARTICIPANT	\N	PRESENT	0
127287	127191	92018S	PARTICIPANT	\N	PRESENT	0
127288	127191	95063L	PARTICIPANT	\N	PRESENT	0
127289	127191	83042R	PARTICIPANT	\N	PRESENT	0
127290	127191	14063N	PARTICIPANT	\N	PRESENT	0
127291	127191	11015D	PARTICIPANT	\N	PRESENT	0
127292	127191	14001X	PARTICIPANT	\N	PRESENT	0
127293	127191	14271U	PARTICIPANT	\N	PRESENT	0
127294	127191	12042Y	PARTICIPANT	\N	PRESENT	0
127295	127191	08016S	PARTICIPANT	\N	PRESENT	0
127296	127191	04078Q	PARTICIPANT	\N	PRESENT	0
127297	127191	95049N	PARTICIPANT	\N	PRESENT	0
127298	127191	01014K	PARTICIPANT	\N	PRESENT	0
127299	127191	08051V	PARTICIPANT	\N	PRESENT	0
127300	127191	14267Y	PARTICIPANT	\N	PRESENT	0
127301	127191	14087W	PARTICIPANT	\N	PRESENT	0
127302	127191	11049P	PARTICIPANT	\N	PRESENT	0
127303	127191	04036E	PARTICIPANT	\N	PRESENT	0
127304	127191	11100Y	PARTICIPANT	\N	PRESENT	0
127305	127191	97011G	PARTICIPANT	\N	PRESENT	0
127306	127191	11043H	PARTICIPANT	\N	PRESENT	0
127307	127191	87003B	PARTICIPANT	\N	PRESENT	0
127308	127191	04042C	PARTICIPANT	\N	PRESENT	0
127309	127191	98005N	PARTICIPANT	\N	PRESENT	0
127310	127191	04041B	PARTICIPANT	\N	PRESENT	0
127311	127191	04088S	PARTICIPANT	\N	PRESENT	0
127312	127191	14237S	PARTICIPANT	\N	PRESENT	0
127313	127191	14221J	PARTICIPANT	\N	PRESENT	0
127314	127191	14257W	PARTICIPANT	\N	PRESENT	0
127315	127191	14201E	PARTICIPANT	\N	PRESENT	0
127316	127191	14089Y	PARTICIPANT	\N	PRESENT	0
127317	127191	98050T	PARTICIPANT	\N	PRESENT	0
127318	127191	14247U	PARTICIPANT	\N	PRESENT	0
127319	127191	11066Q	PARTICIPANT	\N	PRESENT	0
127320	127191	04089T	PARTICIPANT	\N	PRESENT	0
127321	127191	11025F	PARTICIPANT	\N	PRESENT	0
127322	127191	08041T	PARTICIPANT	\N	PRESENT	0
127323	127191	14253S	PARTICIPANT	\N	PRESENT	0
127324	127191	95035G	PARTICIPANT	\N	PRESENT	0
127325	127191	08028W	PARTICIPANT	\N	PRESENT	0
127326	127191	11076S	PARTICIPANT	\N	PRESENT	0
127327	127191	14223L	PARTICIPANT	\N	PRESENT	0
127328	127191	95067Q	PARTICIPANT	\N	PRESENT	0
127329	127191	08015R	PARTICIPANT	\N	PRESENT	0
127330	127191	98018T	PARTICIPANT	\N	PRESENT	0
127331	127191	14235Q	PARTICIPANT	\N	PRESENT	0
127337	127191	11036J	PARTICIPANT	\N	PRESENT	0
127344	127191	01025N	PARTICIPANT	\N	PRESENT	0
127352	127191	14073Q	PARTICIPANT	\N	PRESENT	0
127354	127191	14119M	PARTICIPANT	\N	PRESENT	0
127355	127191	14211G	PARTICIPANT	\N	PRESENT	0
127356	127191	08068F	PARTICIPANT	\N	PRESENT	0
127357	127191	14028W	PARTICIPANT	\N	PRESENT	0
127358	127191	14147R	PARTICIPANT	\N	PRESENT	0
127359	127191	14265W	PARTICIPANT	\N	PRESENT	0
127360	127191	04048J	PARTICIPANT	\N	PRESENT	0
127361	127191	14069U	PARTICIPANT	\N	PRESENT	0
127362	127191	14105F	PARTICIPANT	\N	PRESENT	0
127363	127191	95015C	PARTICIPANT	\N	PRESENT	0
127364	127191	04077P	PARTICIPANT	\N	PRESENT	0
127365	127191	01048V	PARTICIPANT	\N	PRESENT	0
127366	127191	14026U	PARTICIPANT	\N	PRESENT	0
127367	127191	11027H	PARTICIPANT	\N	PRESENT	0
127368	127191	11091R	PARTICIPANT	\N	PRESENT	0
127370	127191	11011M	PARTICIPANT	\N	PRESENT	0
127371	127191	14123H	PARTICIPANT	\N	PRESENT	0
127372	127191	08053X	PARTICIPANT	\N	PRESENT	0
127373	127191	08048B	PARTICIPANT	\N	PRESENT	0
127374	127191	04080J	PARTICIPANT	\N	PRESENT	0
127375	127191	01057W	PARTICIPANT	\N	PRESENT	0
127376	127191	14109K	PARTICIPANT	\N	PRESENT	0
127377	127191	13002U	PARTICIPANT	\N	PRESENT	0
127378	127191	11095V	PARTICIPANT	\N	PRESENT	0
127379	127191	14197C	PARTICIPANT	\N	PRESENT	0
127380	127191	14207L	PARTICIPANT	\N	PRESENT	0
127381	127191	08062Y	PARTICIPANT	\N	PRESENT	0
127382	127191	08014Q	PARTICIPANT	\N	PRESENT	0
127383	127191	04053F	PARTICIPANT	\N	PRESENT	0
127384	127191	77002U	PARTICIPANT	\N	PRESENT	0
127385	127191	14219Q	PARTICIPANT	\N	PRESENT	0
127386	127191	08019V	PARTICIPANT	\N	PRESENT	0
127387	127191	01013J	PARTICIPANT	\N	PRESENT	0
127408	127191	14263U	PARTICIPANT	\N	PRESENT	0
127389	127191	11105E	PARTICIPANT	\N	PRESENT	0
127390	127191	95030B	PARTICIPANT	\N	PRESENT	0
127393	127191	14097Y	PARTICIPANT	\N	PRESENT	0
127394	127191	14133K	PARTICIPANT	\N	PRESENT	0
127395	127191	01008M	PARTICIPANT	\N	PRESENT	0
127396	127191	08010L	PARTICIPANT	\N	PRESENT	0
127397	127191	14249W	PARTICIPANT	\N	PRESENT	0
127398	127191	11026G	PARTICIPANT	\N	PRESENT	0
127401	127191	14053L	PARTICIPANT	\N	PRESENT	0
127402	127191	98022P	PARTICIPANT	\N	PRESENT	0
127403	127191	14173T	PARTICIPANT	\N	PRESENT	0
127406	127191	04043D	PARTICIPANT	\N	PRESENT	0
127407	127191	14083S	PARTICIPANT	\N	PRESENT	0
127409	127191	11057P	PARTICIPANT	\N	PRESENT	0
127410	127191	07032N	PARTICIPANT	\N	PRESENT	0
127411	127191	80013X	PARTICIPANT	\N	PRESENT	0
127412	127191	11097X	PARTICIPANT	\N	PRESENT	0
127413	127191	92020L	PARTICIPANT	\N	PRESENT	0
127414	127191	14059S	PARTICIPANT	\N	PRESENT	0
127415	127191	04095R	PARTICIPANT	\N	PRESENT	0
127416	127191	14031R	PARTICIPANT	\N	PRESENT	0
127417	127191	11101A	PARTICIPANT	\N	PRESENT	0
127418	127191	04045F	PARTICIPANT	\N	PRESENT	0
127419	127191	11053K	PARTICIPANT	\N	PRESENT	0
127420	127191	11082Q	PARTICIPANT	\N	PRESENT	0
127421	127191	08018U	PARTICIPANT	\N	PRESENT	0
127422	127191	98023Q	PARTICIPANT	\N	PRESENT	0
127423	127191	11042G	PARTICIPANT	\N	PRESENT	0
127424	127191	11059R	PARTICIPANT	\N	PRESENT	0
127425	127191	14205J	PARTICIPANT	\N	PRESENT	0
127552	127192	86034E	PARTICIPANT	\N	PRESENT	0
127553	127192	01013J	PARTICIPANT	\N	PRESENT	0
127554	127192	04054G	PARTICIPANT	\N	PRESENT	0
127555	127192	14263U	PARTICIPANT	\N	PRESENT	0
127556	127192	11054L	PARTICIPANT	\N	PRESENT	0
127557	127192	11057P	PARTICIPANT	\N	PRESENT	0
127558	127192	11105E	PARTICIPANT	\N	PRESENT	0
127559	127192	80013X	PARTICIPANT	\N	PRESENT	0
127560	127192	14227Q	PARTICIPANT	\N	PRESENT	0
127561	127192	11059R	PARTICIPANT	\N	PRESENT	0
127562	127192	08052W	PARTICIPANT	\N	PRESENT	0
127563	127192	08053X	PARTICIPANT	\N	PRESENT	0
127564	127192	14167V	PARTICIPANT	\N	PRESENT	0
127565	127192	14051J	PARTICIPANT	\N	PRESENT	0
127566	127192	08060W	PARTICIPANT	\N	PRESENT	0
127567	127192	01014K	PARTICIPANT	\N	PRESENT	0
127568	127192	99004R	PARTICIPANT	\N	PRESENT	0
127569	127192	04041B	PARTICIPANT	\N	PRESENT	0
127570	127192	14173T	PARTICIPANT	\N	PRESENT	0
127571	127192	92020L	PARTICIPANT	\N	PRESENT	0
127572	127192	01057W	PARTICIPANT	\N	PRESENT	0
127573	127192	14063N	PARTICIPANT	\N	PRESENT	0
127574	127192	14251Q	PARTICIPANT	\N	PRESENT	0
127575	127192	08031R	PARTICIPANT	\N	PRESENT	0
127576	127192	11012A	PARTICIPANT	\N	PRESENT	0
127577	127192	14169X	PARTICIPANT	\N	PRESENT	0
127578	127192	11049P	PARTICIPANT	\N	PRESENT	0
127579	127192	01046T	PARTICIPANT	\N	PRESENT	0
127580	127192	04036E	PARTICIPANT	\N	PRESENT	0
127581	127192	14018U	PARTICIPANT	\N	PRESENT	0
127582	127192	14087W	PARTICIPANT	\N	PRESENT	0
127583	127192	11027H	PARTICIPANT	\N	PRESENT	0
127584	127192	04097T	PARTICIPANT	\N	PRESENT	0
127585	127192	11035H	PARTICIPANT	\N	PRESENT	0
127586	127192	08039A	PARTICIPANT	\N	PRESENT	0
127587	127192	08021P	PARTICIPANT	\N	PRESENT	0
127588	127192	98005N	PARTICIPANT	\N	PRESENT	0
127589	127192	98022P	PARTICIPANT	\N	PRESENT	0
149693	125636	14209N	PARTICIPANT	\N	EXCUSE	0
149694	125636	11061K	PARTICIPANT	\N	EXCUSE	0
149695	125636	11089X	PARTICIPANT	\N	EXCUSE	0
149696	125636	08069G	PARTICIPANT	\N	EXCUSE	0
149697	125636	04061F	PARTICIPANT	\N	EXCUSE	0
149698	125636	01048V	PARTICIPANT	\N	EXCUSE	0
149699	125636	14221J	PARTICIPANT	\N	EXCUSE	0
149700	125636	04043D	PARTICIPANT	\N	EXCUSE	0
149701	128998	11036J	PARTICIPANT	\N	PRESENT	0
149702	128998	11061K	PARTICIPANT	\N	PRESENT	0
149703	128998	14221J	PARTICIPANT	\N	PRESENT	0
149704	128998	04043D	PARTICIPANT	\N	PRESENT	0
150088	150087	89017R	PARTICIPANT	\N	PRESENT	0
150089	150087	01031L	PRESIDENT	0	PRESENT	0
151276	146458	04049K	PARTICIPANT	\N	PRESENT	0
150091	150087	01013J	PARTICIPANT	\N	PRESENT	0
151277	146458	04053F	PARTICIPANT	\N	PRESENT	0
150093	150087	11040E	PARTICIPANT	\N	PRESENT	0
151278	146458	14105F	PARTICIPANT	\N	PRESENT	0
151279	146458	14255U	PARTICIPANT	\N	PRESENT	0
151280	146458	14151M	PARTICIPANT	\N	PRESENT	0
150097	150087	14083S	PARTICIPANT	\N	PRESENT	0
150098	150087	11053K	PARTICIPANT	\N	PRESENT	0
150099	150087	14085U	PARTICIPANT	\N	PRESENT	0
150100	150087	11042G	PARTICIPANT	\N	PRESENT	0
151284	151282	04040A	PRESIDENT	1	PRESENT	0
150102	150087	04086Q	PARTICIPANT	\N	PRESENT	0
151283	151282	96004D	PRESIDENT	0	PRESENT	0
150104	150087	11070L	PARTICIPANT	\N	PRESENT	0
150105	150087	11088W	PARTICIPANT	\N	PRESENT	0
151285	151282	14097Y	PARTICIPANT	\N	PRESENT	0
150107	150087	08022Q	PARTICIPANT	\N	PRESENT	0
150108	150087	01027Q	PARTICIPANT	\N	EXCUSE	0
150109	150087	04071H	PARTICIPANT	\N	PRESENT	0
150110	150087	11074Q	PARTICIPANT	\N	PRESENT	0
150111	150087	98053W	PARTICIPANT	\N	PRESENT	0
151286	151282	04057K	PARTICIPANT	\N	EXCUSE	0
151287	151282	14001X	PARTICIPANT	\N	PRESENT	0
151288	151282	04034C	PARTICIPANT	\N	PRESENT	0
150115	150087	08016S	PARTICIPANT	\N	EXCUSE	0
151289	151282	95059Q	PARTICIPANT	\N	EXCUSE	0
150117	150087	11048N	PARTICIPANT	\N	PRESENT	0
150118	150087	99004R	PARTICIPANT	\N	PRESENT	0
151290	151282	98035U	PARTICIPANT	\N	EXCUSE	0
150120	150087	14159V	PARTICIPANT	\N	EXCUSE	0
150121	150087	07029T	PARTICIPANT	\N	PRESENT	0
151333	151332	11076S	PARTICIPANT	\N	EXCUSE	0
150123	150087	08010L	PARTICIPANT	\N	PRESENT	0
150124	150087	08034U	PARTICIPANT	\N	PRESENT	0
150125	150087	01048V	PARTICIPANT	\N	PRESENT	0
150126	150087	98046X	PARTICIPANT	\N	PRESENT	0
151334	151332	04054G	PARTICIPANT	\N	PRESENT	0
150128	150087	08011M	PARTICIPANT	\N	PRESENT	0
151335	151332	04040A	PARTICIPANT	\N	PRESENT	0
150130	150087	08061X	PARTICIPANT	\N	EXCUSE	0
150131	150087	01016M	PARTICIPANT	\N	PRESENT	0
150132	150087	14225N	PARTICIPANT	\N	PRESENT	0
150133	150087	11012A	PARTICIPANT	\N	PRESENT	0
150134	150087	11057P	PARTICIPANT	\N	EXCUSE	0
150135	150087	14173T	PARTICIPANT	\N	PRESENT	0
150136	150087	04034C	PARTICIPANT	\N	PRESENT	0
149605	149592	14223L	PARTICIPANT	\N	EXCUSE	0
149692	125636	11036J	PARTICIPANT	\N	PRESENT	0
151336	151332	08058D	PARTICIPANT	\N	PRESENT	0
151337	151332	04042C	PARTICIPANT	\N	PRESENT	0
151338	151332	77002U	PARTICIPANT	\N	PRESENT	0
151339	151332	98029W	PARTICIPANT	\N	PRESENT	0
151340	151332	11080N	PARTICIPANT	\N	PRESENT	0
151341	151332	11027H	PARTICIPANT	\N	PRESENT	0
151342	151332	98018T	PARTICIPANT	\N	PRESENT	0
151343	151332	92018S	PARTICIPANT	\N	PRESENT	0
151344	151332	92020L	PARTICIPANT	\N	EXCUSE	0
151345	151332	95030B	PARTICIPANT	\N	PRESENT	0
151346	151332	11096W	PARTICIPANT	\N	PRESENT	0
151347	151332	97011G	PARTICIPANT	\N	PRESENT	0
151348	151332	04035D	PARTICIPANT	\N	PRESENT	0
151349	151332	07024N	PARTICIPANT	\N	PRESENT	0
151350	151332	04095R	PARTICIPANT	\N	PRESENT	0
151351	151332	14014Q	PARTICIPANT	\N	PRESENT	0
151352	151332	11015D	PARTICIPANT	\N	PRESENT	0
151353	151332	07004J	PARTICIPANT	\N	PRESENT	0
151354	151332	95035G	PARTICIPANT	\N	EXCUSE	0
151355	151332	08056B	PARTICIPANT	\N	PRESENT	0
151356	151332	98022P	PARTICIPANT	\N	PRESENT	0
151357	151332	11064N	PARTICIPANT	\N	PRESENT	0
151358	151332	95037J	PARTICIPANT	\N	PRESENT	0
151359	151332	04078Q	PARTICIPANT	\N	PRESENT	0
151360	151332	14097Y	PARTICIPANT	\N	PRESENT	0
151361	151332	04036E	PARTICIPANT	\N	PRESENT	0
151362	151332	14039A	PARTICIPANT	\N	PRESENT	0
151363	151332	04077P	PARTICIPANT	\N	EXCUSE	0
151364	151332	98005N	PARTICIPANT	\N	PRESENT	0
151365	151332	92031P	PARTICIPANT	\N	PRESENT	0
151366	151332	11106F	PARTICIPANT	\N	PRESENT	0
151367	151332	14251Q	PARTICIPANT	\N	PRESENT	0
151368	151332	83042R	PARTICIPANT	\N	EXCUSE	0
151369	151332	11105E	PARTICIPANT	\N	PRESENT	0
151370	151332	14253S	PARTICIPANT	\N	PRESENT	0
151371	151332	08047A	PARTICIPANT	\N	PRESENT	0
151372	151332	14028W	PARTICIPANT	\N	PRESENT	0
151373	151332	14193X	PARTICIPANT	\N	PRESENT	0
151374	151332	98021N	PARTICIPANT	\N	PRESENT	0
151375	151332	95059Q	PRESIDENT	0	PRESENT	0
151376	151332	86044G	PARTICIPANT	\N	PRESENT	0
151377	151332	11054L	PARTICIPANT	\N	PRESENT	0
151378	151332	01056V	PARTICIPANT	\N	PRESENT	0
151379	151332	92044U	PARTICIPANT	\N	PRESENT	0
151510	151487	11076S	PARTICIPANT	\N	EXCUSE	0
151511	151487	04054G	PARTICIPANT	\N	PRESENT	0
151512	151487	04040A	PARTICIPANT	\N	PRESENT	0
151514	151487	08058D	PARTICIPANT	\N	PRESENT	0
151515	151487	04042C	PARTICIPANT	\N	PRESENT	0
151516	151487	77002U	PARTICIPANT	\N	PRESENT	0
151517	151487	98029W	PARTICIPANT	\N	PRESENT	0
151518	151487	11080N	PARTICIPANT	\N	PRESENT	0
151519	151487	11027H	PARTICIPANT	\N	PRESENT	0
151520	151487	98018T	PARTICIPANT	\N	PRESENT	0
151521	151487	92018S	PARTICIPANT	\N	PRESENT	0
151522	151487	92020L	PARTICIPANT	\N	EXCUSE	0
151523	151487	95030B	PARTICIPANT	\N	PRESENT	0
151524	151487	11096W	PARTICIPANT	\N	PRESENT	0
151525	151487	97011G	PARTICIPANT	\N	PRESENT	0
151532	151487	04095R	PARTICIPANT	\N	PRESENT	0
151530	151487	04035D	PARTICIPANT	\N	PRESENT	0
151531	151487	07024N	PARTICIPANT	\N	PRESENT	0
151533	151487	14014Q	PARTICIPANT	\N	PRESENT	0
151535	151487	11015D	PARTICIPANT	\N	PRESENT	0
151536	151487	07004J	PARTICIPANT	\N	PRESENT	0
151537	151487	95035G	PARTICIPANT	\N	EXCUSE	0
151538	151487	08056B	PARTICIPANT	\N	PRESENT	0
151540	151487	98022P	PARTICIPANT	\N	PRESENT	0
151541	151487	11064N	PARTICIPANT	\N	PRESENT	0
151543	151487	95037J	PARTICIPANT	\N	PRESENT	0
151545	151487	04078Q	PARTICIPANT	\N	PRESENT	0
151546	151487	14097Y	PARTICIPANT	\N	PRESENT	0
151548	151487	04036E	PARTICIPANT	\N	PRESENT	0
151549	151487	14039A	PARTICIPANT	\N	PRESENT	0
151551	151487	04077P	PARTICIPANT	\N	EXCUSE	0
151553	151487	98005N	PARTICIPANT	\N	PRESENT	0
151554	151458	14147R	PARTICIPANT	\N	PRESENT	0
151555	151487	92031P	PARTICIPANT	\N	PRESENT	0
151557	151487	11106F	PARTICIPANT	\N	PRESENT	0
151559	151487	14251Q	PARTICIPANT	\N	PRESENT	0
151560	151487	83042R	PARTICIPANT	\N	EXCUSE	0
151561	151487	11105E	PARTICIPANT	\N	PRESENT	0
151562	151487	14253S	PARTICIPANT	\N	PRESENT	0
151564	151487	08047A	PARTICIPANT	\N	PRESENT	0
151565	151487	14028W	PARTICIPANT	\N	PRESENT	0
151566	151487	14193X	PARTICIPANT	\N	PRESENT	0
151567	151487	98021N	PARTICIPANT	\N	PRESENT	0
151568	151487	95059Q	PRESIDENT	0	PRESENT	0
151569	151487	86044G	PARTICIPANT	\N	PRESENT	0
151571	151487	11054L	PARTICIPANT	\N	PRESENT	0
151572	151487	01056V	PARTICIPANT	\N	PRESENT	0
151574	151487	92044U	PARTICIPANT	\N	PRESENT	0
151601	151599	04085P	PARTICIPANT	\N	PRESENT	0
151600	151599	08025T	PARTICIPANT	\N	EXCUSE	0
151602	151599	05008E	PRESIDENT	0	PRESENT	0
151628	151599	11033F	PARTICIPANT	\N	PRESENT	0
151659	151599	14065Q	PARTICIPANT	\N	PRESENT	0
151604	151598	11055M	PARTICIPANT	\N	PRESENT	0
151605	151598	01046T	PARTICIPANT	\N	PRESENT	0
151606	151598	04053F	PARTICIPANT	\N	PRESENT	0
151607	151598	14255U	PARTICIPANT	\N	PRESENT	0
151609	151598	00003C	PARTICIPANT	\N	PRESENT	0
151610	151598	14053L	PARTICIPANT	\N	PRESENT	0
151611	151598	11103C	PARTICIPANT	\N	PRESENT	0
131571	131570	99004R	PARTICIPANT	\N	PRESENT	0
140272	135871	14039A	PARTICIPANT	\N	PRESENT	0
140277	135871	98005N	PARTICIPANT	\N	EXCUSE	0
140279	135871	11114F	PARTICIPANT	\N	EXCUSE	0
140280	135871	14259Y	PARTICIPANT	\N	PRESENT	0
140282	135871	01027Q	PARTICIPANT	\N	PRESENT	0
140287	135871	04043D	PARTICIPANT	\N	PRESENT	0
140288	135871	08019V	PRESIDENT	0	PRESENT	0
140289	135871	14059S	PARTICIPANT	\N	PRESENT	0
140714	140713	14253S	PARTICIPANT	\N	PRESENT	0
140715	140713	14157T	PARTICIPANT	\N	PRESENT	0
140762	140760	14221J	PARTICIPANT	\N	PRESENT	0
140763	140760	14237S	PARTICIPANT	\N	PRESENT	0
140766	140760	01008M	PARTICIPANT	\N	PRESENT	0
140768	140760	14265W	PARTICIPANT	\N	PRESENT	0
140769	140760	95067Q	PARTICIPANT	\N	PRESENT	0
143272	143160	01008M	PARTICIPANT	\N	PRESENT	0
142821	142819	11036J	PARTICIPANT	\N	PRESENT	0
143273	143160	11036J	PARTICIPANT	\N	PRESENT	0
142823	142819	14013P	PARTICIPANT	\N	PRESENT	0
142824	142819	08068F	PARTICIPANT	\N	PRESENT	0
142825	142819	14207L	PARTICIPANT	\N	PRESENT	0
143274	143160	11081P	PARTICIPANT	\N	PRESENT	0
142827	142819	90003B	PARTICIPANT	\N	PRESENT	0
143275	143160	14013P	PARTICIPANT	\N	PRESENT	0
142829	142819	80013X	PARTICIPANT	\N	PRESENT	0
142830	142819	08038Y	PARTICIPANT	\N	PRESENT	0
142831	142819	04089T	PARTICIPANT	\N	PRESENT	0
142832	142819	14197C	PARTICIPANT	\N	PRESENT	0
143276	143160	08068F	PARTICIPANT	\N	PRESENT	0
142834	142819	14187A	PARTICIPANT	\N	PRESENT	0
142835	142819	14033T	PARTICIPANT	\N	PRESENT	0
142836	142819	14081Q	PARTICIPANT	\N	PRESENT	0
142837	142819	04048J	PARTICIPANT	\N	EXCUSE	0
143277	143160	14207L	PARTICIPANT	\N	PRESENT	0
145052	141032	14034U	PARTICIPANT	\N	EXCUSE	0
143279	143160	90003B	PARTICIPANT	\N	PRESENT	0
145053	141034	14034U	PARTICIPANT	\N	PRESENT	0
142842	142819	08015R	PARTICIPANT	\N	PRESENT	0
142843	142819	11100Y	PRESIDENT	0	PRESENT	0
142844	142819	01061S	PARTICIPANT	\N	EXCUSE	0
142845	142819	11098Y	PARTICIPANT	\N	PRESENT	0
142846	142819	01043Q	PARTICIPANT	\N	PRESENT	0
142847	142819	11077T	PARTICIPANT	\N	PRESENT	0
142848	142819	14205J	PARTICIPANT	\N	PRESENT	0
142849	142819	08019V	PARTICIPANT	\N	EXCUSE	0
142850	142819	14257W	PARTICIPANT	\N	PRESENT	0
143281	143160	80013X	PARTICIPANT	\N	PRESENT	0
142852	142819	04088S	PARTICIPANT	\N	PRESENT	0
142853	142819	98050T	PARTICIPANT	\N	PRESENT	0
143282	143160	08038Y	PARTICIPANT	\N	PRESENT	0
142855	142819	11046L	PARTICIPANT	\N	PRESENT	0
142856	142819	01058X	PARTICIPANT	\N	PRESENT	0
142857	142819	11094U	PARTICIPANT	\N	PRESENT	0
142858	142819	11066Q	PARTICIPANT	\N	PRESENT	0
143283	143160	04089T	PARTICIPANT	\N	PRESENT	0
143284	143160	14197C	PARTICIPANT	\N	PRESENT	0
145415	145414	11074Q	PARTICIPANT	\N	PRESENT	0
143286	143160	14187A	PARTICIPANT	\N	PRESENT	0
143287	143160	14033T	PARTICIPANT	\N	PRESENT	0
143288	143160	14081Q	PARTICIPANT	\N	PRESENT	0
145416	145414	88008L	PARTICIPANT	\N	PRESENT	0
143290	143160	11099A	PARTICIPANT	\N	PRESENT	0
146372	146170	14239U	PARTICIPANT	\N	PRESENT	0
143292	143160	04094Q	PARTICIPANT	\N	PRESENT	0
143293	143160	11111C	PARTICIPANT	\N	PRESENT	0
143294	143160	08015R	PARTICIPANT	\N	PRESENT	0
143295	143160	11100Y	PRESIDENT	0	PRESENT	0
146436	146435	14030Q	PARTICIPANT	\N	PRESENT	0
143297	143160	11098Y	PARTICIPANT	\N	PRESENT	0
143298	143160	01043Q	PARTICIPANT	\N	PRESENT	0
143299	143160	11077T	PARTICIPANT	\N	PRESENT	0
143300	143160	14205J	PARTICIPANT	\N	PRESENT	0
143301	143160	08019V	PARTICIPANT	\N	PRESENT	0
143302	143160	14257W	PARTICIPANT	\N	PRESENT	0
146374	146170	14065Q	PARTICIPANT	\N	PRESENT	0
143304	143160	04088S	PARTICIPANT	\N	PRESENT	0
143305	143160	98050T	PARTICIPANT	\N	PRESENT	0
146437	146435	11029K	PARTICIPANT	\N	PRESENT	0
143307	143160	11046L	PARTICIPANT	\N	PRESENT	0
143308	143160	01058X	PARTICIPANT	\N	PRESENT	0
143309	143160	11094U	PARTICIPANT	\N	PRESENT	0
143310	143160	11066Q	PARTICIPANT	\N	PRESENT	0
146376	146170	08024S	PARTICIPANT	\N	PRESENT	0
146377	146170	14195A	PARTICIPANT	\N	PRESENT	0
146378	146170	11031D	PARTICIPANT	\N	PRESENT	0
146379	146170	08052W	PARTICIPANT	\N	PRESENT	0
146438	146435	11031D	PARTICIPANT	\N	PRESENT	0
146381	146170	14217N	PARTICIPANT	\N	PRESENT	0
146382	146170	87003B	PARTICIPANT	\N	PRESENT	0
146383	146170	11061K	PARTICIPANT	\N	PRESENT	0
146384	146170	14213J	PARTICIPANT	\N	PRESENT	0
146385	146170	14205J	PARTICIPANT	\N	PRESENT	0
146386	146170	14221J	PARTICIPANT	\N	PRESENT	0
146387	146170	14147R	PARTICIPANT	\N	PRESENT	0
146388	146170	14223L	PARTICIPANT	\N	PRESENT	0
146389	146170	04092N	PRESIDENT	0	PRESENT	0
146390	146170	14265W	PARTICIPANT	\N	PRESENT	0
146391	146170	14028W	PARTICIPANT	\N	PRESENT	0
146392	146170	14235Q	PARTICIPANT	\N	EXCUSE	0
146393	146170	14331P	PARTICIPANT	\N	PRESENT	0
146394	146170	14271U	PARTICIPANT	\N	PRESENT	0
146395	146170	11097X	PARTICIPANT	\N	PRESENT	0
146396	146170	04045F	PARTICIPANT	\N	PRESENT	0
146397	146170	11094U	PARTICIPANT	\N	PRESENT	0
146439	146435	11027H	PARTICIPANT	\N	PRESENT	0
146441	146435	80013X	PARTICIPANT	\N	PRESENT	0
146442	146435	14217N	PARTICIPANT	\N	PRESENT	0
146444	146435	12042Y	PARTICIPANT	\N	PRESENT	0
146445	146435	14187A	PARTICIPANT	\N	PRESENT	0
146446	146435	14281W	PARTICIPANT	\N	PRESENT	0
146447	146435	11061K	PARTICIPANT	\N	PRESENT	0
146448	146435	04041B	PARTICIPANT	\N	PRESENT	0
146449	146435	14241N	PARTICIPANT	\N	PRESENT	0
146450	146435	08031R	PARTICIPANT	\N	PRESENT	0
146451	146435	08017T	PARTICIPANT	\N	PRESENT	0
146452	146435	14031R	PARTICIPANT	\N	PRESENT	0
146453	146435	08043V	PARTICIPANT	\N	EXCUSE	0
146454	146435	14038Y	PARTICIPANT	\N	EXCUSE	0
146455	146435	14041T	PARTICIPANT	\N	EXCUSE	0
146456	146435	04035D	PARTICIPANT	\N	EXCUSE	0
146457	146435	04036E	PARTICIPANT	\N	EXCUSE	0
146459	146435	07029T	PARTICIPANT	\N	EXCUSE	0
147785	147782	14259Y	PARTICIPANT	\N	PRESENT	0
146461	146435	09001P	PRESIDENT	0	PRESENT	0
146462	146435	11014C	PARTICIPANT	\N	EXCUSE	0
147796	147793	14259Y	PARTICIPANT	\N	PRESENT	0
147798	147793	11113E	PARTICIPANT	\N	PRESENT	0
147800	147799	14259Y	PARTICIPANT	\N	PRESENT	0
147801	147799	11113E	PARTICIPANT	\N	PRESENT	0
147803	147802	14259Y	PARTICIPANT	\N	PRESENT	0
149333	149332	98050T	PARTICIPANT	\N	PRESENT	0
149339	149338	08009T	PARTICIPANT	\N	PRESENT	0
149340	149338	14169X	PARTICIPANT	\N	PRESENT	0
149341	149338	14093U	PARTICIPANT	\N	PRESENT	0
161520	160261	86034E	PARTICIPANT	\N	PRESENT	0
161521	160261	11057P	PARTICIPANT	\N	PRESENT	0
161525	160261	11042G	PARTICIPANT	\N	PRESENT	0
161523	160261	14197C	PARTICIPANT	\N	PRESENT	0
161524	160261	14121F	PARTICIPANT	\N	PRESENT	0
161526	160261	01031L	PARTICIPANT	\N	PRESENT	0
161527	160261	13002U	PARTICIPANT	\N	PRESENT	0
161528	160261	14097Y	PARTICIPANT	\N	PRESENT	0
161529	160261	14014Q	PARTICIPANT	\N	PRESENT	0
161530	160261	14081Q	PARTICIPANT	\N	PRESENT	0
161531	160261	11104D	PARTICIPANT	\N	PRESENT	0
161532	160261	04056J	PARTICIPANT	\N	PRESENT	0
161533	160261	11072N	PARTICIPANT	\N	PRESENT	0
161534	160261	08017T	PARTICIPANT	\N	PRESENT	0
161535	160261	11107G	PARTICIPANT	\N	PRESENT	0
161536	160261	08021P	PARTICIPANT	\N	PRESENT	0
161537	160261	98022P	PARTICIPANT	\N	PRESENT	0
161538	160261	11012A	PARTICIPANT	\N	PRESENT	0
161539	160261	12042Y	PARTICIPANT	\N	PRESENT	0
161540	160261	08055A	PARTICIPANT	\N	PRESENT	0
161541	160261	11055M	PARTICIPANT	\N	PRESENT	0
161542	160261	04041B	PARTICIPANT	\N	PRESENT	0
161543	160261	01027Q	PARTICIPANT	\N	PRESENT	0
161544	160261	14026U	PARTICIPANT	\N	PRESENT	0
161545	160261	14069U	PARTICIPANT	\N	PRESENT	0
161546	160261	05012A	PARTICIPANT	\N	PRESENT	0
161547	160261	08041T	PARTICIPANT	\N	PRESENT	0
161548	160261	08028W	PARTICIPANT	\N	PRESENT	0
161549	160261	11101A	PARTICIPANT	\N	PRESENT	0
161550	160261	88008L	PARTICIPANT	\N	PRESENT	0
163086	163084	11076S	PARTICIPANT	\N	PRESENT	0
163087	163084	14133K	PARTICIPANT	\N	PRESENT	0
163088	163084	04054G	PARTICIPANT	\N	PRESENT	0
163089	163084	04040A	PARTICIPANT	\N	PRESENT	0
163090	163084	08058D	PARTICIPANT	\N	PRESENT	0
163091	163084	04042C	PARTICIPANT	\N	PRESENT	0
163092	163084	77002U	PARTICIPANT	\N	PRESENT	0
163093	163084	98029W	PARTICIPANT	\N	PRESENT	0
163158	163157	11076S	PARTICIPANT	\N	PRESENT	0
163095	163084	11027H	PARTICIPANT	\N	PRESENT	0
163096	163084	98018T	PARTICIPANT	\N	PRESENT	0
163159	163157	14133K	PARTICIPANT	\N	PRESENT	0
163098	163084	92020L	PARTICIPANT	\N	PRESENT	0
163099	163084	95030B	PARTICIPANT	\N	PRESENT	0
163100	163084	11096W	PARTICIPANT	\N	PRESENT	0
163101	163084	95031C	PARTICIPANT	\N	PRESENT	0
163102	163084	97011G	PARTICIPANT	\N	PRESENT	0
163103	163084	08065C	PARTICIPANT	\N	PRESENT	0
163104	163084	04035D	PARTICIPANT	\N	PRESENT	0
163105	163084	04095R	PARTICIPANT	\N	PRESENT	0
163106	163084	14014Q	PARTICIPANT	\N	PRESENT	0
163107	163084	11015D	PARTICIPANT	\N	PRESENT	0
163108	163084	07004J	PARTICIPANT	\N	PRESENT	0
163109	163084	95035G	PARTICIPANT	\N	PRESENT	0
163110	163084	08056B	PARTICIPANT	\N	PRESENT	0
163161	163157	04054G	PARTICIPANT	\N	PRESENT	0
163112	163084	98022P	PARTICIPANT	\N	PRESENT	0
163113	163084	11064N	PARTICIPANT	\N	PRESENT	0
163114	163084	95037J	PARTICIPANT	\N	PRESENT	0
163115	163084	04078Q	PARTICIPANT	\N	PRESENT	0
163116	163084	14097Y	PARTICIPANT	\N	PRESENT	0
163117	163084	95041E	PARTICIPANT	\N	PRESENT	0
163118	163084	04036E	PARTICIPANT	\N	PRESENT	0
163119	163084	14039A	PARTICIPANT	\N	PRESENT	0
163120	163084	04077P	PARTICIPANT	\N	PRESENT	0
163121	163084	98005N	PARTICIPANT	\N	PRESENT	0
163122	163084	92031P	PARTICIPANT	\N	PRESENT	0
163123	163084	11106F	PARTICIPANT	\N	PRESENT	0
163124	163084	14251Q	PARTICIPANT	\N	PRESENT	0
163125	163084	83042R	PARTICIPANT	\N	PRESENT	0
163162	163157	04040A	PARTICIPANT	\N	PRESENT	0
163127	163084	11082Q	PARTICIPANT	\N	PRESENT	0
163128	163084	11105E	PARTICIPANT	\N	PRESENT	0
163129	163084	14253S	PARTICIPANT	\N	PRESENT	0
163164	163157	08058D	PARTICIPANT	\N	PRESENT	0
163131	163084	14028W	PARTICIPANT	\N	PRESENT	0
163132	163084	14193X	PARTICIPANT	\N	PRESENT	0
163133	163084	98021N	PARTICIPANT	\N	PRESENT	0
163134	163084	04080J	PARTICIPANT	\N	PRESENT	0
163135	163084	95059Q	PRESIDENT	0	PRESENT	0
163136	163084	86044G	PARTICIPANT	\N	PRESENT	0
163165	163157	04042C	PARTICIPANT	\N	PRESENT	0
163138	163084	11054L	PARTICIPANT	\N	PRESENT	0
163139	163084	01056V	PARTICIPANT	\N	PRESENT	0
163140	163084	92044U	PARTICIPANT	\N	PRESENT	0
163141	163084	08049C	PARTICIPANT	\N	PRESENT	0
163142	163084	04050C	PARTICIPANT	\N	PRESENT	0
163166	163157	77002U	PARTICIPANT	\N	PRESENT	0
163167	163157	98029W	PARTICIPANT	\N	PRESENT	0
163168	163157	11027H	PARTICIPANT	\N	PRESENT	0
163169	163157	98018T	PARTICIPANT	\N	PRESENT	0
163171	163157	92020L	PARTICIPANT	\N	PRESENT	0
163172	163157	95030B	PARTICIPANT	\N	PRESENT	0
163173	163157	11096W	PARTICIPANT	\N	PRESENT	0
163174	163157	95031C	PARTICIPANT	\N	PRESENT	0
163175	163157	97011G	PARTICIPANT	\N	PRESENT	0
163176	163157	08065C	PARTICIPANT	\N	PRESENT	0
163177	163157	04035D	PARTICIPANT	\N	PRESENT	0
163178	163157	04095R	PARTICIPANT	\N	PRESENT	0
163179	163157	14014Q	PARTICIPANT	\N	PRESENT	0
163180	163157	11015D	PARTICIPANT	\N	PRESENT	0
163181	163157	07004J	PARTICIPANT	\N	PRESENT	0
163182	163157	95035G	PARTICIPANT	\N	PRESENT	0
163186	163157	08056B	PARTICIPANT	\N	PRESENT	0
163187	163157	98022P	PARTICIPANT	\N	PRESENT	0
163188	163157	11064N	PARTICIPANT	\N	PRESENT	0
163189	163157	95037J	PARTICIPANT	\N	PRESENT	0
163190	163157	04078Q	PARTICIPANT	\N	PRESENT	0
163191	163157	14097Y	PARTICIPANT	\N	PRESENT	0
163193	163157	95041E	PARTICIPANT	\N	PRESENT	0
163195	163157	04036E	PARTICIPANT	\N	PRESENT	0
163197	163157	14039A	PARTICIPANT	\N	PRESENT	0
163198	163157	04077P	PARTICIPANT	\N	PRESENT	0
163201	163157	98005N	PARTICIPANT	\N	PRESENT	0
163203	163157	92031P	PARTICIPANT	\N	PRESENT	0
163205	163157	11106F	PARTICIPANT	\N	PRESENT	0
163206	163157	14251Q	PARTICIPANT	\N	PRESENT	0
163208	163157	83042R	PARTICIPANT	\N	PRESENT	0
163212	163157	11082Q	PARTICIPANT	\N	PRESENT	0
163214	163157	11105E	PARTICIPANT	\N	PRESENT	0
163215	163157	14253S	PARTICIPANT	\N	PRESENT	0
163218	163157	14028W	PARTICIPANT	\N	PRESENT	0
163221	163157	14193X	PARTICIPANT	\N	PRESENT	0
163222	163157	98021N	PARTICIPANT	\N	PRESENT	0
163224	163157	04080J	PARTICIPANT	\N	PRESENT	0
163226	163157	95059Q	PRESIDENT	0	PRESENT	0
163227	163157	86044G	PARTICIPANT	\N	PRESENT	0
163228	163157	11054L	PARTICIPANT	\N	PRESENT	0
163230	163157	01056V	PARTICIPANT	\N	PRESENT	0
163231	163157	92044U	PARTICIPANT	\N	PRESENT	0
163232	163157	08049C	PARTICIPANT	\N	PRESENT	0
163234	163157	04050C	PARTICIPANT	\N	PRESENT	0
163947	163946	04040A	PARTICIPANT	\N	PRESENT	0
164074	164072	14041T	PARTICIPANT	\N	PRESENT	0
163950	163949	11032E	PARTICIPANT	\N	PRESENT	0
164073	164072	11026G	PARTICIPANT	\N	PRESENT	0
164075	164072	98042T	PARTICIPANT	\N	PRESENT	0
164076	164072	08012N	PARTICIPANT	\N	PRESENT	0
164077	164072	04043D	PARTICIPANT	\N	PRESENT	0
164177	159492	04061F	PARTICIPANT	\N	EXCUSE	0
164173	159492	14263U	PARTICIPANT	\N	EXCUSE	0
164174	159492	01046T	PARTICIPANT	\N	EXCUSE	0
164175	159492	11036J	PARTICIPANT	\N	EXCUSE	0
164176	159492	14209N	PARTICIPANT	\N	EXCUSE	0
164178	159492	14221J	PARTICIPANT	\N	EXCUSE	0
164359	164358	14219Q	PRESIDENT	0	PRESENT	0
164360	164358	11065P	PARTICIPANT	\N	PRESENT	0
164361	164358	14033T	PARTICIPANT	\N	PRESENT	0
164452	164433	14207L	PRESIDENT	0	PRESENT	0
164453	164433	14089Y	PARTICIPANT	\N	PRESENT	0
164454	164433	14281W	PARTICIPANT	\N	PRESENT	0
164455	164433	14231L	PARTICIPANT	\N	PRESENT	0
164456	164433	11061K	PARTICIPANT	\N	PRESENT	0
164457	164433	11014C	PARTICIPANT	\N	PRESENT	0
164458	164433	11029K	PARTICIPANT	\N	EXCUSE	0
164459	164433	14053L	PARTICIPANT	\N	EXCUSE	0
164460	164433	04038G	PARTICIPANT	\N	EXCUSE	0
164461	164433	14215L	PARTICIPANT	\N	EXCUSE	0
164462	164433	14135M	PARTICIPANT	\N	EXCUSE	0
164463	164433	14229S	PARTICIPANT	\N	EXCUSE	0
164479	163913	04044E	PARTICIPANT	\N	PRESENT	0
164512	163913	08051V	PARTICIPANT	\N	PRESENT	0
164534	163913	99004R	PARTICIPANT	\N	PRESENT	0
164572	163913	08016S	PARTICIPANT	\N	PRESENT	0
164693	164692	14028W	PARTICIPANT	\N	PRESENT	0
164733	164732	11039M	PARTICIPANT	\N	PRESENT	0
164734	164732	14073Q	PARTICIPANT	\N	PRESENT	0
164735	164732	14241N	PARTICIPANT	\N	PRESENT	0
164736	164732	87003B	PARTICIPANT	\N	PRESENT	0
164737	164732	11043H	PARTICIPANT	\N	PRESENT	0
164753	164752	01048V	PARTICIPANT	\N	PRESENT	0
164755	164754	01048V	PARTICIPANT	\N	PRESENT	0
164757	164756	98053W	PARTICIPANT	\N	PRESENT	0
164759	164758	98053W	PARTICIPANT	\N	PRESENT	0
164773	164772	11076S	PARTICIPANT	\N	PRESENT	0
164774	164772	14133K	PARTICIPANT	\N	PRESENT	0
164775	164772	04040A	PARTICIPANT	\N	PRESENT	0
164776	164772	98029W	PARTICIPANT	\N	PRESENT	0
164777	164772	95035G	PARTICIPANT	\N	PRESENT	0
164778	164772	14097Y	PARTICIPANT	\N	PRESENT	0
164779	164772	04036E	PARTICIPANT	\N	PRESENT	0
164780	164772	98005N	PARTICIPANT	\N	PRESENT	0
164781	164772	11106F	PARTICIPANT	\N	PRESENT	0
164782	164772	08047A	PARTICIPANT	\N	PRESENT	0
164783	164772	14193X	PARTICIPANT	\N	PRESENT	0
164784	164772	11054L	PARTICIPANT	\N	PRESENT	0
164785	164772	01056V	PARTICIPANT	\N	PRESENT	0
164857	164852	89029V	PARTICIPANT	\N	PRESENT	0
164858	164852	14051J	PARTICIPANT	\N	PRESENT	0
164859	164852	14271U	PARTICIPANT	\N	PRESENT	0
164860	164852	14241N	PARTICIPANT	\N	PRESENT	0
164861	164852	14083S	PARTICIPANT	\N	PRESENT	0
164862	164852	14135M	PARTICIPANT	\N	PRESENT	0
164863	164852	14195A	PARTICIPANT	\N	PRESENT	0
164864	164852	11011M	PARTICIPANT	\N	PRESENT	0
127592	127192	14247U	PARTICIPANT	\N	PRESENT	0
127593	127192	08025T	PARTICIPANT	\N	PRESENT	0
127594	127192	95031C	PARTICIPANT	\N	PRESENT	0
127595	127192	08068F	PARTICIPANT	\N	PRESENT	0
127596	127192	92040Q	PARTICIPANT	\N	PRESENT	0
127597	127192	14271U	PARTICIPANT	\N	PRESENT	0
127598	127192	05012A	PARTICIPANT	\N	PRESENT	0
127599	127192	08058D	PARTICIPANT	\N	PRESENT	0
127600	127192	14031R	PARTICIPANT	\N	PRESENT	0
127601	127192	01011G	PARTICIPANT	\N	PRESENT	0
127602	127192	14111D	PARTICIPANT	\N	PRESENT	0
127603	127192	04066L	PARTICIPANT	\N	PRESENT	0
127604	127192	87003B	PARTICIPANT	\N	PRESENT	0
127605	127192	89029V	PARTICIPANT	\N	PRESENT	0
127606	127192	11104D	PARTICIPANT	\N	PRESENT	0
127607	127192	98050T	PARTICIPANT	\N	PRESENT	0
127608	127192	11066Q	PARTICIPANT	\N	PRESENT	0
127609	127192	86044G	PARTICIPANT	\N	PRESENT	0
127610	127192	04059M	PARTICIPANT	\N	PRESENT	0
127611	127192	14085U	PARTICIPANT	\N	PRESENT	0
127612	127192	13002U	PARTICIPANT	\N	PRESENT	0
127613	127192	14033T	PARTICIPANT	\N	PRESENT	0
127614	127192	04067M	PARTICIPANT	\N	PRESENT	0
127615	127192	14135M	PARTICIPANT	\N	PRESENT	0
127616	127192	11076S	PARTICIPANT	\N	PRESENT	0
127617	127192	11025F	PARTICIPANT	\N	PRESENT	0
127618	127192	08018U	PARTICIPANT	\N	PRESENT	0
127619	127192	77002U	PARTICIPANT	\N	PRESENT	0
127620	127192	14039A	PARTICIPANT	\N	PRESENT	0
127621	127192	04043D	PARTICIPANT	\N	PRESENT	0
127622	127192	04095R	PARTICIPANT	\N	PRESENT	0
127623	127192	98023Q	PARTICIPANT	\N	PRESENT	0
127624	127192	11033F	PARTICIPANT	\N	PRESENT	0
127625	127192	08028W	PARTICIPANT	\N	PRESENT	0
127626	127192	11026G	PARTICIPANT	\N	PRESENT	0
127627	127192	01027Q	PARTICIPANT	\N	PRESENT	0
127628	127192	14097Y	PARTICIPANT	\N	PRESENT	0
127629	127192	11031D	PARTICIPANT	\N	PRESENT	0
127630	127192	14331P	PARTICIPANT	\N	PRESENT	0
127631	127192	12041X	PARTICIPANT	\N	PRESENT	0
127632	127192	04050C	PARTICIPANT	\N	PRESENT	0
127633	127192	14105F	PARTICIPANT	\N	PRESENT	0
127634	127192	08019V	PARTICIPANT	\N	PRESENT	0
127635	127192	11098Y	PARTICIPANT	\N	PRESENT	0
127636	127192	11091R	PARTICIPANT	\N	PRESENT	0
127637	127192	92018S	PARTICIPANT	\N	PRESENT	0
127638	127192	90003B	PARTICIPANT	\N	PRESENT	0
127639	127192	11043H	PARTICIPANT	\N	PRESENT	0
127640	127192	11110B	PARTICIPANT	\N	PRESENT	0
127641	127192	10015M	PARTICIPANT	\N	PRESENT	0
127642	127192	11015D	PARTICIPANT	\N	PRESENT	0
127643	127192	08041T	PARTICIPANT	\N	PRESENT	0
127644	127192	14197C	PARTICIPANT	\N	PRESENT	0
127645	127192	04092N	PARTICIPANT	\N	PRESENT	0
127646	127192	14223L	PARTICIPANT	\N	PRESENT	0
127647	127192	14147R	PARTICIPANT	\N	PRESENT	0
127648	127192	11101A	PARTICIPANT	\N	PRESENT	0
127649	127192	96004D	PARTICIPANT	\N	PRESENT	0
127650	127192	11034G	PARTICIPANT	\N	PRESENT	0
127651	127192	11080N	PARTICIPANT	\N	PRESENT	0
127652	127192	04085P	PARTICIPANT	\N	PRESENT	0
127653	127192	14151M	PARTICIPANT	\N	PRESENT	0
127654	127192	08069G	PARTICIPANT	\N	PRESENT	0
127655	127192	95062K	PARTICIPANT	\N	PRESENT	0
127656	127192	01058X	PARTICIPANT	\N	PRESENT	0
127657	127192	98029W	PARTICIPANT	\N	PRESENT	0
127658	127192	98024R	PARTICIPANT	\N	PRESENT	0
127659	127192	83047W	PARTICIPANT	\N	PRESENT	0
127660	127192	95035G	PARTICIPANT	\N	PRESENT	0
127661	127192	92031P	PARTICIPANT	\N	PRESENT	0
127662	127192	04042C	PARTICIPANT	\N	PRESENT	0
127663	127192	01059Y	PARTICIPANT	\N	PRESENT	0
127664	127192	11036J	PARTICIPANT	\N	PRESENT	0
127665	127192	04086Q	PARTICIPANT	\N	PRESENT	0
127666	127192	98018T	PARTICIPANT	\N	PRESENT	0
127667	127192	11011M	PARTICIPANT	\N	PRESENT	0
127668	127192	01015L	PARTICIPANT	\N	PRESENT	0
127669	127192	14013P	PARTICIPANT	\N	PRESENT	0
127670	127192	97011G	PARTICIPANT	\N	PRESENT	0
127671	127192	11099A	PARTICIPANT	\N	PRESENT	0
127672	127192	11097X	PARTICIPANT	\N	PRESENT	0
127673	127192	11083R	PARTICIPANT	\N	PRESENT	0
127674	127192	95015C	PARTICIPANT	\N	PRESENT	0
127675	127192	11029K	PARTICIPANT	\N	PRESENT	0
127676	127192	08048B	PARTICIPANT	\N	PRESENT	0
127677	127192	11063M	PARTICIPANT	\N	PRESENT	0
127678	127192	08047A	PARTICIPANT	\N	PRESENT	0
127679	127192	08016S	PARTICIPANT	\N	PRESENT	0
127590	127192	14195A	PARTICIPANT	\N	PRESENT	0
127591	127192	14211G	PARTICIPANT	\N	PRESENT	0
127680	127192	04074L	PARTICIPANT	\N	PRESENT	0
127681	127192	98035U	PARTICIPANT	\N	PRESENT	0
127682	127192	01016M	PARTICIPANT	\N	PRESENT	0
127683	127192	04049K	PARTICIPANT	\N	PRESENT	0
127684	127192	92015P	PARTICIPANT	\N	PRESENT	0
127685	127192	14038Y	PARTICIPANT	\N	PRESENT	0
127686	127192	11044J	PARTICIPANT	\N	PRESENT	0
127687	127192	11068S	PARTICIPANT	\N	PRESENT	0
127688	127192	01019Q	PARTICIPANT	\N	PRESENT	0
127689	127192	14329V	PARTICIPANT	\N	PRESENT	0
127690	127192	11103C	PARTICIPANT	\N	PRESENT	0
127691	127192	14133K	PARTICIPANT	\N	PRESENT	0
127692	127192	14028W	PARTICIPANT	\N	PRESENT	0
127693	127192	11030C	PARTICIPANT	\N	PRESENT	0
127694	127192	04071H	PARTICIPANT	\N	PRESENT	0
127695	127192	08012N	PARTICIPANT	\N	PRESENT	0
127696	127192	14119M	PARTICIPANT	\N	PRESENT	0
127697	127192	14071N	PARTICIPANT	\N	PRESENT	0
127698	127192	08038Y	PARTICIPANT	\N	PRESENT	0
127699	127192	14215L	PARTICIPANT	\N	PRESENT	0
127700	127192	11084S	PARTICIPANT	\N	PRESENT	0
127701	127192	05008E	PARTICIPANT	\N	PRESENT	0
127702	127192	10006L	PARTICIPANT	\N	PRESENT	0
127703	127192	95037J	PARTICIPANT	\N	PRESENT	0
127704	127192	14059S	PARTICIPANT	\N	PRESENT	0
127705	127192	83042R	PARTICIPANT	\N	PRESENT	0
127706	127192	07029T	PARTICIPANT	\N	PRESENT	0
127707	127192	04088S	PARTICIPANT	\N	PRESENT	0
127708	127192	11046L	PARTICIPANT	\N	PRESENT	0
127709	127192	14069U	PARTICIPANT	\N	PRESENT	0
127710	127192	11088W	PARTICIPANT	\N	PRESENT	0
127711	127192	14014Q	PARTICIPANT	\N	PRESENT	0
127712	127192	14107H	PARTICIPANT	\N	PRESENT	0
127713	127192	04033B	PARTICIPANT	\N	PRESENT	0
127714	127192	11095V	PARTICIPANT	\N	PRESENT	0
127715	127192	14001X	PARTICIPANT	\N	PRESENT	0
127716	127192	07034Q	PARTICIPANT	\N	PRESENT	0
127717	127192	01008M	PARTICIPANT	\N	PRESENT	0
127718	127192	11014C	PARTICIPANT	\N	PRESENT	0
127719	127192	14157T	PARTICIPANT	\N	PRESENT	0
127720	127192	11100Y	PARTICIPANT	\N	PRESENT	0
127721	127192	07032N	PARTICIPANT	\N	PRESENT	0
127722	127192	14121F	PARTICIPANT	\N	PRESENT	0
127723	127192	14093U	PARTICIPANT	\N	PRESENT	0
127724	127192	14257W	PARTICIPANT	\N	PRESENT	0
127725	127192	14259Y	PARTICIPANT	\N	PRESENT	0
127726	127192	14207L	PARTICIPANT	\N	PRESENT	0
127727	127192	11112D	PARTICIPANT	\N	PRESENT	0
127728	127192	04081K	PARTICIPANT	\N	PRESENT	0
127729	127192	04053F	PARTICIPANT	\N	PRESENT	0
127730	127192	11048N	PARTICIPANT	\N	PRESENT	0
127731	127192	04044E	PARTICIPANT	\N	PRESENT	0
127732	127192	99002P	PARTICIPANT	\N	PRESENT	0
127733	127192	08024S	PARTICIPANT	\N	PRESENT	0
127734	127192	07024N	PARTICIPANT	\N	PRESENT	0
127735	127192	92039X	PARTICIPANT	\N	PRESENT	0
127736	127192	11106F	PARTICIPANT	\N	PRESENT	0
127737	127192	14061L	PARTICIPANT	\N	PRESENT	0
127738	127192	08015R	PARTICIPANT	\N	PRESENT	0
127739	127192	14081Q	PARTICIPANT	\N	PRESENT	0
127740	127192	11077T	PARTICIPANT	\N	PRESENT	0
127741	127192	04045F	PARTICIPANT	\N	PRESENT	0
127742	127192	95059Q	PARTICIPANT	\N	PRESENT	0
127743	127192	14265W	PARTICIPANT	\N	PRESENT	0
127744	127192	14065Q	PARTICIPANT	\N	PRESENT	0
127745	127192	14269B	PARTICIPANT	\N	PRESENT	0
127746	127192	14159V	PARTICIPANT	\N	PRESENT	0
127747	127192	14281W	PARTICIPANT	\N	PRESENT	0
127748	127192	95030B	PARTICIPANT	\N	PRESENT	0
127749	127192	14229S	PARTICIPANT	\N	PRESENT	0
127750	127192	04034C	PARTICIPANT	\N	PRESENT	0
127751	127192	08043V	PARTICIPANT	\N	PRESENT	0
127752	127192	11032E	PARTICIPANT	\N	PRESENT	0
127753	127192	11042G	PARTICIPANT	\N	PRESENT	0
127754	127192	14249W	PARTICIPANT	\N	PRESENT	0
127755	127192	11114F	PARTICIPANT	\N	PRESENT	0
127756	127192	14237S	PARTICIPANT	\N	PRESENT	0
127757	127192	11109J	PARTICIPANT	\N	PRESENT	0
151671	151599	08018U	PARTICIPANT	\N	PRESENT	0
151613	151598	14195A	PARTICIPANT	\N	PRESENT	0
151614	151598	14267Y	PARTICIPANT	\N	PRESENT	0
151672	151599	01007L	PARTICIPANT	\N	EXCUSE	0
151673	151599	11049P	PARTICIPANT	\N	PRESENT	0
151617	151598	08052W	PARTICIPANT	\N	PRESENT	0
151618	151598	01059Y	PARTICIPANT	\N	PRESENT	0
151619	151598	04081K	PARTICIPANT	\N	PRESENT	0
151620	151598	98024R	PRESIDENT	0	PRESENT	0
151675	151599	11084S	PARTICIPANT	\N	PRESENT	0
151677	151599	04079R	PARTICIPANT	\N	PRESENT	0
151623	151598	14217N	PARTICIPANT	\N	PRESENT	0
151678	151599	14111D	PARTICIPANT	\N	PRESENT	0
151625	151598	14151M	PARTICIPANT	\N	PRESENT	0
151626	151598	12042Y	PARTICIPANT	\N	PRESENT	0
151627	151598	14281W	PARTICIPANT	\N	PRESENT	0
151629	151598	14087W	PARTICIPANT	\N	PRESENT	0
151694	151599	01060R	PARTICIPANT	\N	PRESENT	0
151695	151599	14147R	PARTICIPANT	\N	PRESENT	0
151696	151599	95049N	PARTICIPANT	\N	PRESENT	0
151633	151598	11061K	PARTICIPANT	\N	PRESENT	0
151634	151598	14355X	PARTICIPANT	\N	EXCUSE	0
151697	151599	08051V	PARTICIPANT	\N	PRESENT	0
151698	151599	07034Q	PARTICIPANT	\N	EXCUSE	0
151637	151598	01011G	PARTICIPANT	\N	PRESENT	0
151638	151598	14026U	PARTICIPANT	\N	PRESENT	0
151639	151598	14213J	PARTICIPANT	\N	PRESENT	0
151640	151598	14121F	PARTICIPANT	\N	PRESENT	0
151641	151598	11112D	PARTICIPANT	\N	PRESENT	0
151642	151598	14037X	PARTICIPANT	\N	PRESENT	0
151699	151599	04074L	PARTICIPANT	\N	PRESENT	0
151644	151598	11067R	PARTICIPANT	\N	PRESENT	0
151645	151598	14223L	PARTICIPANT	\N	EXCUSE	0
151646	151598	04092N	PARTICIPANT	0	PRESENT	0
151647	151598	14265W	PARTICIPANT	\N	PRESENT	0
151648	151598	14119M	PARTICIPANT	\N	PRESENT	0
151649	151598	14071N	PARTICIPANT	\N	PRESENT	0
151700	151599	10015M	PARTICIPANT	\N	PRESENT	0
151651	151598	14271U	PARTICIPANT	\N	EXCUSE	0
151701	151599	95063L	PARTICIPANT	\N	PRESENT	0
151653	151598	11093T	PARTICIPANT	\N	PRESENT	0
151654	151598	11097X	PARTICIPANT	\N	PRESENT	0
151655	151598	04045F	PARTICIPANT	\N	PRESENT	0
151656	151598	14227Q	PARTICIPANT	\N	PRESENT	0
151657	151598	01034P	PARTICIPANT	\N	PRESENT	0
151658	151598	11025F	PARTICIPANT	\N	PRESENT	0
151660	151598	11063M	PARTICIPANT	\N	PRESENT	0
151661	151598	14269B	PARTICIPANT	\N	PRESENT	0
151662	151599	14069U	PARTICIPANT	\N	PRESENT	0
151663	151599	04047H	PARTICIPANT	\N	EXCUSE	0
151664	151599	04038G	PARTICIPANT	\N	PRESENT	0
151665	151599	11056N	PARTICIPANT	\N	PRESENT	0
151666	151599	11035H	PARTICIPANT	\N	PRESENT	0
151667	151599	14041T	PARTICIPANT	\N	PRESENT	0
151668	151599	11113E	PARTICIPANT	\N	PRESENT	0
151669	151599	01024M	PARTICIPANT	\N	EXCUSE	0
151670	151599	14215L	PARTICIPANT	\N	EXCUSE	0
151674	151599	08044W	PARTICIPANT	\N	EXCUSE	0
151676	151599	11026G	PARTICIPANT	\N	PRESENT	0
151702	151599	01019Q	PARTICIPANT	\N	EXCUSE	0
151703	151599	01028R	PARTICIPANT	\N	EXCUSE	0
151705	151599	04056J	PARTICIPANT	\N	PRESENT	0
151706	151599	04044E	PARTICIPANT	\N	EXCUSE	0
151707	151599	11037K	PARTICIPANT	\N	PRESENT	0
151708	151599	92045V	PARTICIPANT	\N	PRESENT	0
151709	151599	95067Q	PARTICIPANT	\N	PRESENT	0
151711	151599	01047U	PARTICIPANT	\N	PRESENT	0
151732	151598	14231L	PARTICIPANT	\N	PRESENT	0
152019	152011	01046T	PARTICIPANT	\N	PRESENT	0
151805	151796	95049N	PARTICIPANT	\N	PRESENT	0
152017	152011	04092N	PARTICIPANT	\N	PRESENT	0
152021	152011	08052W	PARTICIPANT	\N	PRESENT	0
152023	152011	95015C	PARTICIPANT	\N	PRESENT	0
152027	152011	11067R	PARTICIPANT	\N	PRESENT	0
153053	153052	11026G	PARTICIPANT	\N	PRESENT	0
153054	153052	10015M	PARTICIPANT	\N	PRESENT	0
153057	153055	11026G	PARTICIPANT	\N	PRESENT	0
153058	153055	10015M	PARTICIPANT	\N	PRESENT	0
153060	153055	14073Q	PARTICIPANT	\N	PRESENT	0
153061	153055	04054G	PARTICIPANT	\N	PRESENT	0
153073	153072	01008M	PARTICIPANT	\N	PRESENT	0
153074	153072	11035H	PARTICIPANT	\N	PRESENT	0
153075	153072	11065P	PARTICIPANT	\N	PRESENT	0
153076	153072	11090Q	PARTICIPANT	\N	PRESENT	0
153077	153072	05012A	PARTICIPANT	\N	PRESENT	0
153642	153640	95049N	PARTICIPANT	\N	PRESENT	0
153079	153072	13002U	PARTICIPANT	\N	PRESENT	0
153080	153072	80013X	PARTICIPANT	\N	PRESENT	0
153081	153072	09001P	PRESIDENT	0	PRESENT	0
153082	153072	14033T	PARTICIPANT	\N	EXCUSE	0
153084	153072	08049C	PARTICIPANT	\N	PRESENT	0
153973	153972	11039M	PARTICIPANT	\N	PRESENT	0
153974	153972	98042T	PARTICIPANT	\N	PRESENT	0
153975	153972	01019Q	PARTICIPANT	\N	PRESENT	0
154153	154152	98050T	PARTICIPANT	\N	PRESENT	0
154155	154154	98050T	PARTICIPANT	\N	PRESENT	0
154157	154156	98050T	PARTICIPANT	\N	PRESENT	0
154573	154572	14083S	PARTICIPANT	\N	PRESENT	0
154575	154574	14083S	PARTICIPANT	\N	PRESENT	0
154593	154592	14083S	PARTICIPANT	\N	PRESENT	0
155493	155492	98050T	PARTICIPANT	\N	PRESENT	0
155513	155512	89017R	PARTICIPANT	\N	PRESENT	0
155514	155512	01044R	PARTICIPANT	\N	PRESENT	0
155515	155512	10006L	PARTICIPANT	\N	PRESENT	0
155516	155512	04036E	PARTICIPANT	\N	PRESENT	0
155517	155512	98005N	PARTICIPANT	\N	PRESENT	0
155767	155762	11039M	PARTICIPANT	\N	PRESENT	0
155768	155762	98042T	PARTICIPANT	\N	PRESENT	0
155769	155762	01019Q	PARTICIPANT	\N	PRESENT	0
155977	155095	14042U	PARTICIPANT	\N	PRESENT	0
155978	155095	08031R	PARTICIPANT	\N	PRESENT	0
155979	155095	11012A	PARTICIPANT	\N	PRESENT	0
155980	155095	11036J	PARTICIPANT	\N	PRESENT	0
155981	155095	14257W	PARTICIPANT	\N	PRESENT	0
155992	155095	05008E	PARTICIPANT	\N	PRESENT	0
155993	155095	95049N	PARTICIPANT	\N	PRESENT	0
155994	155095	14083S	PARTICIPANT	\N	PRESENT	0
155995	155095	14231L	PARTICIPANT	\N	PRESENT	0
155996	155095	14111D	PARTICIPANT	\N	PRESENT	0
155997	155095	14133K	PARTICIPANT	\N	PRESENT	0
156012	155095	01057W	PARTICIPANT	\N	PRESENT	0
156013	155095	14187A	PARTICIPANT	\N	PRESENT	0
156102	156101	08025T	PARTICIPANT	\N	PRESENT	0
156103	156101	05008E	PRESIDENT	0	PRESENT	0
156104	156101	11033F	PARTICIPANT	\N	PRESENT	0
156105	156101	14069U	PARTICIPANT	\N	PRESENT	0
156106	156101	04047H	PARTICIPANT	\N	PRESENT	0
156107	156101	04038G	PARTICIPANT	\N	PRESENT	0
156108	156101	11056N	PARTICIPANT	\N	EXCUSE	0
156109	156101	14259Y	PARTICIPANT	\N	PRESENT	0
156110	156101	01024M	PARTICIPANT	\N	PRESENT	0
156111	156101	14215L	PARTICIPANT	\N	PRESENT	0
156112	156101	01007L	PARTICIPANT	\N	PRESENT	0
156113	156101	11049P	PARTICIPANT	\N	PRESENT	0
156114	156101	08044W	PARTICIPANT	\N	EXCUSE	0
156115	156101	11026G	PARTICIPANT	\N	PRESENT	0
156116	156101	04079R	PARTICIPANT	\N	PRESENT	0
156117	156101	01060R	PARTICIPANT	\N	PRESENT	0
156118	156101	14147R	PARTICIPANT	\N	PRESENT	0
156120	156101	95049N	PARTICIPANT	\N	PRESENT	0
156121	156101	08051V	PARTICIPANT	\N	PRESENT	0
156122	156101	11072N	PARTICIPANT	\N	PRESENT	0
156124	156101	07034Q	PARTICIPANT	\N	PRESENT	0
156125	156101	04074L	PARTICIPANT	\N	PRESENT	0
156126	156101	10015M	PARTICIPANT	\N	PRESENT	0
156183	156101	95063L	PARTICIPANT	\N	PRESENT	0
156184	156101	01019Q	PARTICIPANT	\N	PRESENT	0
156185	156101	01028R	PARTICIPANT	\N	PRESENT	0
156186	156101	11037K	PARTICIPANT	\N	PRESENT	0
156187	156101	95067Q	PARTICIPANT	\N	PRESENT	0
156193	156192	14133K	PARTICIPANT	\N	PRESENT	0
156194	156192	14079W	PARTICIPANT	\N	PRESENT	0
156195	156192	07024N	PARTICIPANT	\N	PRESENT	0
156196	156192	04036E	PARTICIPANT	\N	PRESENT	0
156197	156192	11026G	PARTICIPANT	\N	PRESENT	0
156198	156192	92031P	PARTICIPANT	\N	PRESENT	0
156199	156192	08034U	PARTICIPANT	\N	PRESENT	0
156200	156192	04088S	PARTICIPANT	\N	PRESENT	0
156201	156192	04080J	PARTICIPANT	\N	PRESENT	0
156212	156101	92045V	PARTICIPANT	\N	EXCUSE	0
136709	125519	04049K	PARTICIPANT	\N	PRESENT	0
144214	144213	14147R	PARTICIPANT	\N	PRESENT	0
136712	125519	04053F	PARTICIPANT	\N	PRESENT	0
136714	125519	14255U	PARTICIPANT	\N	PRESENT	0
136716	125519	14265W	PARTICIPANT	\N	PRESENT	0
144314	144312	04040A	PARTICIPANT	\N	PRESENT	0
136718	125519	95067Q	PARTICIPANT	\N	PRESENT	0
144313	144312	96004D	PARTICIPANT	\N	PRESENT	0
144315	144312	14097Y	PARTICIPANT	\N	PRESENT	0
144316	144312	14073Q	PARTICIPANT	\N	PRESENT	0
144317	144312	14001X	PARTICIPANT	\N	PRESENT	0
144335	136202	01027Q	PARTICIPANT	\N	EXCUSE	0
144336	136202	14033T	PARTICIPANT	\N	PRESENT	0
144337	136202	08019V	PRESIDENT	0	PRESENT	0
144338	136202	11072N	PARTICIPANT	\N	PRESENT	0
144339	136202	95062K	PARTICIPANT	\N	EXCUSE	0
144340	136202	11054L	PARTICIPANT	\N	EXCUSE	0
144341	136202	11025F	PARTICIPANT	\N	PRESENT	0
144342	136202	14059S	PARTICIPANT	\N	PRESENT	0
144343	136202	14097Y	PARTICIPANT	\N	EXCUSE	0
144344	136202	14219Q	PARTICIPANT	\N	EXCUSE	0
144345	136202	05001W	PARTICIPANT	\N	PRESENT	0
144346	136202	14039A	PARTICIPANT	\N	PRESENT	0
146192	145522	14259Y	PARTICIPANT	\N	PRESENT	0
146194	145522	92045V	PARTICIPANT	\N	PRESENT	0
148635	148634	14249W	PARTICIPANT	\N	PRESENT	0
148636	148634	07026Q	PARTICIPANT	\N	PRESENT	0
148638	148637	14249W	PARTICIPANT	\N	PRESENT	0
148639	148637	07026Q	PARTICIPANT	\N	PRESENT	0
158092	157272	11098Y	PARTICIPANT	\N	EXCUSE	0
160372	157432	11023D	PARTICIPANT	\N	PRESENT	0
160373	157432	11114F	PARTICIPANT	\N	PRESENT	0
160374	157432	11113E	PARTICIPANT	\N	PRESENT	0
160375	157432	01027Q	PARTICIPANT	\N	PRESENT	0
160376	157432	04094Q	PARTICIPANT	\N	PRESENT	0
160377	157432	14059S	PARTICIPANT	\N	PRESENT	0
160378	157432	08019V	PRESIDENT	0	PRESENT	0
160379	157432	08073C	PARTICIPANT	\N	PRESENT	0
160380	157432	11054L	PARTICIPANT	\N	PRESENT	0
160381	157432	11011M	PARTICIPANT	\N	PRESENT	0
161553	160261	08065C	PARTICIPANT	\N	PRESENT	0
161554	160261	08062Y	PARTICIPANT	\N	PRESENT	0
161555	160261	14111D	PARTICIPANT	\N	PRESENT	0
161556	160261	07029T	PARTICIPANT	\N	PRESENT	0
161557	160261	14187A	PARTICIPANT	\N	PRESENT	0
161558	160261	14055N	PARTICIPANT	\N	PRESENT	0
161559	160261	14041T	PARTICIPANT	\N	PRESENT	0
161560	160261	14085U	PARTICIPANT	\N	PRESENT	0
161561	160261	14051J	PARTICIPANT	\N	PRESENT	0
161562	160261	14001X	PARTICIPANT	\N	PRESENT	0
161563	160261	08073C	PARTICIPANT	\N	PRESENT	0
161564	160261	11109J	PARTICIPANT	\N	PRESENT	0
161565	160261	11077T	PARTICIPANT	\N	PRESENT	0
161566	160261	01056V	PARTICIPANT	\N	PRESENT	0
161567	160261	92015P	PARTICIPANT	\N	PRESENT	0
161568	160261	89029V	PARTICIPANT	\N	PRESENT	0
161569	160261	14215L	PARTICIPANT	\N	PRESENT	0
161570	160261	04094Q	PARTICIPANT	\N	PRESENT	0
161571	160261	80027E	PARTICIPANT	\N	PRESENT	0
161572	160261	01022K	PARTICIPANT	\N	PRESENT	0
161573	160261	86044G	PARTICIPANT	\N	PRESENT	0
161574	160261	98046X	PARTICIPANT	\N	PRESENT	0
161575	160261	04086Q	PARTICIPANT	\N	PRESENT	0
161576	160261	08022Q	PARTICIPANT	\N	PRESENT	0
161577	160261	11059R	PARTICIPANT	\N	PRESENT	0
161578	160261	08025T	PARTICIPANT	\N	PRESENT	0
161579	160261	11100Y	PARTICIPANT	\N	PRESENT	0
161580	160261	98029W	PARTICIPANT	\N	PRESENT	0
161581	160261	14123H	PARTICIPANT	\N	PRESENT	0
161582	160261	14211G	PARTICIPANT	\N	PRESENT	0
161624	160261	08043V	PARTICIPANT	\N	PRESENT	0
161584	160261	14257W	PARTICIPANT	\N	PRESENT	0
161585	160261	01048V	PARTICIPANT	\N	PRESENT	0
161586	160261	14281W	PARTICIPANT	\N	PRESENT	0
161587	160261	14033T	PARTICIPANT	\N	PRESENT	0
161588	160261	11014C	PARTICIPANT	\N	PRESENT	0
161589	160261	98021N	PARTICIPANT	\N	PRESENT	0
161590	160261	08068F	PARTICIPANT	\N	PRESENT	0
161591	160261	04071H	PARTICIPANT	\N	PRESENT	0
161592	160261	11066Q	PARTICIPANT	\N	PRESENT	0
161593	160261	01059Y	PARTICIPANT	\N	PRESENT	0
161594	160261	04085P	PARTICIPANT	\N	PRESENT	0
161595	160261	04057K	PARTICIPANT	\N	PRESENT	0
161596	160261	92018S	PARTICIPANT	\N	PRESENT	0
161597	160261	12041X	PARTICIPANT	\N	PRESENT	0
161598	160261	08048B	PARTICIPANT	\N	PRESENT	0
161599	160261	14013P	PARTICIPANT	\N	PRESENT	0
161600	160261	11103C	PARTICIPANT	\N	PRESENT	0
161601	160261	77002U	PARTICIPANT	\N	PRESENT	0
161602	160261	11063M	PARTICIPANT	\N	PRESENT	0
161603	160261	04050C	PARTICIPANT	\N	PRESENT	0
161604	160261	14235Q	PARTICIPANT	\N	PRESENT	0
161605	160261	01015L	PARTICIPANT	\N	PRESENT	0
161606	160261	14217N	PARTICIPANT	\N	PRESENT	0
161607	160261	04034C	PARTICIPANT	\N	PRESENT	0
161608	160261	99002P	PARTICIPANT	\N	PRESENT	0
161609	160261	14037X	PARTICIPANT	\N	PRESENT	0
161610	160261	14063N	PARTICIPANT	\N	PRESENT	0
161611	160261	92031P	PARTICIPANT	\N	PRESENT	0
161612	160261	04036E	PARTICIPANT	\N	PRESENT	0
161613	160261	01008M	PARTICIPANT	\N	PRESENT	0
161614	160261	14151M	PARTICIPANT	\N	PRESENT	0
161615	160261	11113E	PARTICIPANT	\N	PRESENT	0
161616	160261	14133K	PARTICIPANT	\N	PRESENT	0
161617	160261	14159V	PARTICIPANT	\N	PRESENT	0
161618	160261	11027H	PARTICIPANT	\N	PRESENT	0
161619	160261	14355X	PARTICIPANT	\N	PRESENT	0
161620	160261	11114F	PARTICIPANT	\N	PRESENT	0
161621	160261	11097X	PARTICIPANT	\N	PRESENT	0
161622	160261	80013X	PARTICIPANT	\N	PRESENT	0
161623	160261	14209N	PARTICIPANT	\N	PRESENT	0
161625	160261	98023Q	PARTICIPANT	\N	PRESENT	0
161626	160261	92039X	PARTICIPANT	\N	PRESENT	0
161627	160261	04097T	PARTICIPANT	\N	PRESENT	0
161628	160261	14269B	PARTICIPANT	\N	PRESENT	0
161629	160261	95031C	PARTICIPANT	\N	PRESENT	0
161630	160261	95030B	PARTICIPANT	\N	PRESENT	0
161631	160261	14361V	PARTICIPANT	\N	PRESENT	0
161632	160261	14079W	PARTICIPANT	\N	PRESENT	0
161633	160261	98053W	PARTICIPANT	\N	PRESENT	0
161634	160261	11031D	PARTICIPANT	\N	PRESENT	0
161635	160261	04066L	PARTICIPANT	\N	PRESENT	0
161636	160261	08042U	PARTICIPANT	\N	PRESENT	0
161637	160261	11088W	PARTICIPANT	\N	PRESENT	0
161638	160261	14135M	PARTICIPANT	\N	PRESENT	0
161639	160261	95015C	PARTICIPANT	\N	PRESENT	0
161640	160261	04081K	PARTICIPANT	\N	PRESENT	0
161641	160261	04054G	PARTICIPANT	\N	PRESENT	0
161642	160261	02002K	PARTICIPANT	\N	PRESENT	0
161643	160261	11056N	PARTICIPANT	\N	PRESENT	0
161644	160261	01058X	PARTICIPANT	\N	PRESENT	0
161645	160261	95062K	PARTICIPANT	\N	PRESENT	0
161646	160261	08039A	PARTICIPANT	\N	PRESENT	0
161647	160261	08052W	PARTICIPANT	\N	PRESENT	0
161551	160261	87003B	PARTICIPANT	\N	PRESENT	0
161552	160261	11023D	PARTICIPANT	\N	PRESENT	0
161648	160261	90003B	PARTICIPANT	\N	PRESENT	0
161649	160261	95063L	PARTICIPANT	\N	PRESENT	0
161650	160261	01057W	PARTICIPANT	\N	PRESENT	0
161651	160261	98035U	PARTICIPANT	\N	PRESENT	0
161652	160261	11039M	PARTICIPANT	\N	PRESENT	0
161653	160261	96004D	PARTICIPANT	\N	PRESENT	0
161654	160261	04061F	PARTICIPANT	\N	PRESENT	0
161655	160261	01011G	PARTICIPANT	\N	PRESENT	0
161656	160261	98050T	PARTICIPANT	\N	PRESENT	0
161657	160261	08053X	PARTICIPANT	\N	PRESENT	0
161658	160261	04049K	PARTICIPANT	\N	PRESENT	0
161659	160261	14059S	PARTICIPANT	\N	PRESENT	0
161660	160261	11067R	PARTICIPANT	\N	PRESENT	0
161661	160261	11046L	PARTICIPANT	\N	PRESENT	0
161662	160261	95041E	PARTICIPANT	\N	PRESENT	0
161663	160261	95035G	PARTICIPANT	\N	PRESENT	0
161664	160261	14207L	PARTICIPANT	\N	PRESENT	0
161665	160261	11080N	PARTICIPANT	\N	PRESENT	0
161666	160261	11030C	PARTICIPANT	\N	PRESENT	0
161667	160261	11049P	PARTICIPANT	\N	PRESENT	0
161668	160261	95067Q	PARTICIPANT	\N	PRESENT	0
161669	160261	14109K	PARTICIPANT	\N	PRESENT	0
161670	160261	83042R	PARTICIPANT	\N	PRESENT	0
161671	160261	14225N	PARTICIPANT	\N	PRESENT	0
161672	160261	92040Q	PARTICIPANT	\N	PRESENT	0
161673	160261	08069G	PARTICIPANT	\N	PRESENT	0
161867	160261	14261S	PARTICIPANT	\N	PRESENT	0
161864	160261	14034U	PARTICIPANT	\N	PRESENT	0
161856	160261	14042U	PARTICIPANT	\N	PRESENT	0
161839	160261	05004A	PARTICIPANT	\N	PRESENT	0
161840	160261	08015R	PARTICIPANT	\N	PRESENT	0
161861	160261	09001P	PARTICIPANT	\N	PRESENT	0
161842	160261	08047A	PARTICIPANT	\N	PRESENT	0
161843	160261	14195A	PARTICIPANT	\N	PRESENT	0
161844	160261	11010L	PARTICIPANT	\N	PRESENT	0
161845	160261	14173T	PARTICIPANT	\N	PRESENT	0
161846	160261	11011M	PARTICIPANT	\N	PRESENT	0
161847	160261	10006L	PARTICIPANT	\N	PRESENT	0
161848	160261	14093U	PARTICIPANT	\N	PRESENT	0
161849	160261	14053L	PARTICIPANT	\N	PRESENT	0
161850	160261	08011M	PARTICIPANT	\N	PRESENT	0
161851	160261	11076S	PARTICIPANT	\N	PRESENT	0
161852	160261	14219Q	PARTICIPANT	\N	PRESENT	0
161853	160261	04080J	PARTICIPANT	\N	PRESENT	0
161854	160261	14083S	PARTICIPANT	\N	PRESENT	0
161855	160261	14267Y	PARTICIPANT	\N	PRESENT	0
161857	160261	11065P	PARTICIPANT	\N	PRESENT	0
161858	160261	14089Y	PARTICIPANT	\N	PRESENT	0
161859	160261	14327T	PARTICIPANT	\N	PRESENT	0
161860	160261	01024M	PARTICIPANT	\N	PRESENT	0
161862	160261	01043Q	PARTICIPANT	\N	PRESENT	0
161863	160261	14103D	PARTICIPANT	\N	PRESENT	0
161865	160261	08009T	PARTICIPANT	\N	PRESENT	0
161866	160261	11082Q	PARTICIPANT	\N	PRESENT	0
161868	160261	11026G	PARTICIPANT	\N	PRESENT	0
161869	160261	11061K	PARTICIPANT	\N	PRESENT	0
161870	160261	14231L	PARTICIPANT	\N	PRESENT	0
161871	160261	11093T	PARTICIPANT	\N	PRESENT	0
161872	160261	11094U	PARTICIPANT	\N	PRESENT	0
161873	160261	98042T	PARTICIPANT	\N	PRESENT	0
161874	160261	14221J	PARTICIPANT	\N	PRESENT	0
161875	160261	14199E	PARTICIPANT	\N	PRESENT	0
161876	160261	14073Q	PARTICIPANT	\N	PRESENT	0
161877	160261	11071M	PARTICIPANT	\N	PRESENT	0
161878	160261	11033F	PARTICIPANT	\N	PRESENT	0
161879	160261	01041N	PARTICIPANT	\N	PRESENT	0
162236	160262	08024S	PARTICIPANT	\N	PRESENT	0
162237	160262	05008E	PARTICIPANT	\N	PRESENT	0
162238	160262	14259Y	PARTICIPANT	\N	PRESENT	0
162239	160262	80013X	PARTICIPANT	\N	PRESENT	0
162240	160262	01022K	PARTICIPANT	\N	PRESENT	0
162241	160262	08031R	PARTICIPANT	\N	PRESENT	0
162242	160262	11012A	PARTICIPANT	\N	PRESENT	0
162243	160262	11023D	PARTICIPANT	\N	PRESENT	0
162244	160262	11114F	PARTICIPANT	\N	PRESENT	0
162245	160262	14121F	PARTICIPANT	\N	PRESENT	0
162246	160262	14225N	PARTICIPANT	\N	PRESENT	0
162247	160262	14215L	PARTICIPANT	\N	PRESENT	0
162248	160262	11101A	PARTICIPANT	\N	PRESENT	0
162249	160262	14191V	PARTICIPANT	\N	PRESENT	0
162250	160262	08019V	PARTICIPANT	\N	PRESENT	0
162251	160262	11071M	PARTICIPANT	\N	PRESENT	0
162252	160262	14093U	PARTICIPANT	\N	PRESENT	0
162253	160262	14147R	PARTICIPANT	\N	PRESENT	0
162254	160262	14059S	PARTICIPANT	\N	PRESENT	0
162255	160262	08042U	PARTICIPANT	\N	PRESENT	0
162256	160262	14241N	PARTICIPANT	\N	PRESENT	0
162257	160262	14267Y	PARTICIPANT	\N	PRESENT	0
162258	160262	11082Q	PARTICIPANT	\N	PRESENT	0
162259	160262	14205J	PARTICIPANT	\N	PRESENT	0
162260	160262	14231L	PARTICIPANT	\N	PRESENT	0
162261	160262	14083S	PARTICIPANT	\N	PRESENT	0
162263	160262	11036J	PARTICIPANT	\N	PRESENT	0
162264	160262	11113E	PARTICIPANT	\N	PRESENT	0
162266	160262	14119M	PARTICIPANT	\N	PRESENT	0
162270	160262	01060R	PARTICIPANT	\N	PRESENT	0
162274	160262	14275Y	PARTICIPANT	\N	PRESENT	0
162275	160262	04094Q	PARTICIPANT	\N	PRESENT	0
162276	160262	04085P	PARTICIPANT	\N	PRESENT	0
162278	160262	14355X	PARTICIPANT	\N	PRESENT	0
162279	160262	14173T	PARTICIPANT	\N	PRESENT	0
162280	160262	11055M	PARTICIPANT	\N	PRESENT	0
162281	160262	14030Q	PARTICIPANT	\N	PRESENT	0
162282	160262	08056B	PARTICIPANT	\N	PRESENT	0
162283	160262	11064N	PARTICIPANT	\N	PRESENT	0
162285	160262	01047U	PARTICIPANT	\N	PRESENT	0
162286	160262	14261S	PARTICIPANT	\N	PRESENT	0
162292	160262	11109J	PARTICIPANT	\N	PRESENT	0
162293	160262	08073C	PARTICIPANT	\N	PRESENT	0
162312	160262	14039A	PARTICIPANT	\N	PRESENT	0
162313	160262	04088S	PARTICIPANT	\N	PRESENT	0
162332	160262	14363X	PARTICIPANT	\N	PRESENT	0
162333	160262	14014Q	PARTICIPANT	\N	PRESENT	0
162334	160262	04049K	PARTICIPANT	\N	PRESENT	0
162335	162265	80013X	PARTICIPANT	\N	PRESENT	0
162336	160262	14069U	PARTICIPANT	\N	PRESENT	0
162337	162265	05012A	PARTICIPANT	\N	PRESENT	0
162338	160262	05001W	PARTICIPANT	\N	PRESENT	0
162339	160262	14361V	PARTICIPANT	\N	PRESENT	0
162340	160262	11072N	PARTICIPANT	\N	PRESENT	0
162341	160262	14026U	PARTICIPANT	\N	PRESENT	0
162342	160262	95062K	PARTICIPANT	\N	PRESENT	0
162343	160262	08043V	PARTICIPANT	\N	PRESENT	0
162344	160262	14357A	PARTICIPANT	\N	PRESENT	0
162345	160262	11081P	PARTICIPANT	\N	PRESENT	0
162346	160262	14034U	PARTICIPANT	\N	PRESENT	0
162347	160262	11093T	PARTICIPANT	\N	PRESENT	0
162348	160262	14179A	PARTICIPANT	\N	PRESENT	0
162349	160262	01034P	PARTICIPANT	\N	PRESENT	0
162350	160262	14249W	PARTICIPANT	\N	PRESENT	0
162351	160262	14217N	PARTICIPANT	\N	PRESENT	0
162352	160262	11042G	PARTICIPANT	\N	PRESENT	0
162353	160262	14042U	PARTICIPANT	\N	PRESENT	0
162354	160262	01043Q	PARTICIPANT	\N	PRESENT	0
162355	160262	14187A	PARTICIPANT	\N	PRESENT	0
162356	160262	95030B	PARTICIPANT	\N	PRESENT	0
162357	160262	14087W	PARTICIPANT	\N	PRESENT	0
162358	160262	98053W	PARTICIPANT	\N	PRESENT	0
162372	160262	14017T	PARTICIPANT	\N	PRESENT	0
162373	160262	08068F	PARTICIPANT	\N	PRESENT	0
162374	160262	07029T	PARTICIPANT	\N	PRESENT	0
162375	160262	04095R	PARTICIPANT	\N	PRESENT	0
162376	160262	14269B	PARTICIPANT	\N	PRESENT	0
162377	160262	98005N	PARTICIPANT	\N	PRESENT	0
162392	160262	08015R	PARTICIPANT	\N	PRESENT	0
162412	160262	08028W	PARTICIPANT	\N	PRESENT	0
162432	160262	95049N	PARTICIPANT	\N	PRESENT	0
162433	160262	04057K	PARTICIPANT	\N	PRESENT	0
162434	160262	14167V	PARTICIPANT	\N	PRESENT	0
162435	160262	14197C	PARTICIPANT	\N	PRESENT	0
162436	160262	14097Y	PARTICIPANT	\N	PRESENT	0
162437	162265	11067R	PARTICIPANT	\N	PRESENT	0
162438	160262	01027Q	PARTICIPANT	\N	PRESENT	0
162439	160262	08010L	PARTICIPANT	\N	PRESENT	0
162452	160262	14195A	PARTICIPANT	\N	PRESENT	0
162453	160262	14123H	PARTICIPANT	\N	PRESENT	0
162552	160263	08055A	PARTICIPANT	\N	PRESENT	0
162572	160263	04088S	PARTICIPANT	\N	PRESENT	0
162573	160263	11020A	PARTICIPANT	\N	PRESENT	0
162574	160263	14147R	PARTICIPANT	\N	PRESENT	0
162575	160263	14059S	PARTICIPANT	\N	PRESENT	0
162576	160263	14217N	PARTICIPANT	\N	PRESENT	0
162577	160263	14083S	PARTICIPANT	\N	PRESENT	0
162578	160263	14275Y	PARTICIPANT	\N	PRESENT	0
162579	160263	14215L	PARTICIPANT	\N	PRESENT	0
162580	160263	14261S	PARTICIPANT	\N	PRESENT	0
162581	160263	14259Y	PARTICIPANT	\N	PRESENT	0
162582	160263	08019V	PARTICIPANT	\N	PRESENT	0
162583	160263	11113E	PARTICIPANT	\N	PRESENT	0
162584	160263	08073C	PARTICIPANT	\N	PRESENT	0
162585	160263	11023D	PARTICIPANT	\N	PRESENT	0
162586	160263	11109J	PARTICIPANT	\N	PRESENT	0
162587	160263	14039A	PARTICIPANT	\N	PRESENT	0
162588	160263	04094Q	PARTICIPANT	\N	PRESENT	0
162589	160263	11072N	PARTICIPANT	\N	PRESENT	0
162590	160263	14361V	PARTICIPANT	\N	PRESENT	0
162591	160263	04085P	PARTICIPANT	\N	PRESENT	0
162592	160263	05001W	PARTICIPANT	\N	PRESENT	0
162593	160263	14103D	PARTICIPANT	\N	PRESENT	0
162594	160263	14219Q	PARTICIPANT	\N	PRESENT	0
162595	160263	04095R	PARTICIPANT	\N	PRESENT	0
162596	160263	05008E	PARTICIPANT	\N	PRESENT	0
162597	160263	14089Y	PARTICIPANT	\N	PRESENT	0
162598	160263	04097T	PARTICIPANT	\N	PRESENT	0
162599	160263	14357A	PARTICIPANT	\N	PRESENT	0
162600	160263	11114F	PARTICIPANT	\N	PRESENT	0
162601	160263	98005N	PARTICIPANT	\N	PRESENT	0
162602	160263	14119M	PARTICIPANT	\N	PRESENT	0
162603	160263	14265W	PARTICIPANT	\N	PRESENT	0
162604	160263	14231L	PARTICIPANT	\N	PRESENT	0
162605	160263	14257W	PARTICIPANT	\N	PRESENT	0
162606	160263	11112D	PARTICIPANT	\N	PRESENT	0
162607	160263	11055M	PARTICIPANT	\N	PRESENT	0
162608	160263	14030Q	PARTICIPANT	\N	PRESENT	0
127758	127192	08035V	PARTICIPANT	\N	PRESENT	0
127759	127192	11113E	PARTICIPANT	\N	PRESENT	0
127760	127192	11061K	PARTICIPANT	\N	PRESENT	0
127761	127192	14187A	PARTICIPANT	\N	PRESENT	0
127762	127192	08073C	PARTICIPANT	\N	PRESENT	0
127763	127192	11037K	PARTICIPANT	\N	PRESENT	0
127764	127192	12042Y	PARTICIPANT	\N	PRESENT	0
127765	127192	11107G	PARTICIPANT	\N	PRESENT	0
127766	127192	08014Q	PARTICIPANT	\N	PRESENT	0
127767	127192	14253S	PARTICIPANT	\N	PRESENT	0
127768	127192	01044R	PARTICIPANT	\N	PRESENT	0
127769	127192	02002K	PARTICIPANT	\N	PRESENT	0
127770	127192	08022Q	PARTICIPANT	\N	PRESENT	0
127771	127192	14199E	PARTICIPANT	\N	PRESENT	0
127772	127192	14026U	PARTICIPANT	\N	PRESENT	0
127773	127192	04056J	PARTICIPANT	\N	PRESENT	0
127774	127192	92045V	PARTICIPANT	\N	PRESENT	0
127775	127192	04035D	PARTICIPANT	\N	PRESENT	0
127776	127192	08051V	PARTICIPANT	\N	PRESENT	0
127777	127192	04078Q	PARTICIPANT	\N	PRESENT	0
127778	127192	14079W	PARTICIPANT	\N	PRESENT	0
127779	127192	08049C	PARTICIPANT	\N	PRESENT	0
127780	127192	11081P	PARTICIPANT	\N	PRESENT	0
127781	127192	01003G	PARTICIPANT	\N	PRESENT	0
127782	127192	14123H	PARTICIPANT	\N	PRESENT	0
127783	127192	11096W	PARTICIPANT	\N	PRESENT	0
127784	127192	04038G	PARTICIPANT	\N	PRESENT	0
127785	127192	14201E	PARTICIPANT	\N	PRESENT	0
127786	127192	14239U	PARTICIPANT	\N	PRESENT	0
127787	127192	14213J	PARTICIPANT	\N	PRESENT	0
127788	127192	14055N	PARTICIPANT	\N	PRESENT	0
127789	127192	89017R	PARTICIPANT	\N	PRESENT	0
127790	127192	92044U	PARTICIPANT	\N	PRESENT	0
127791	127192	01060R	PARTICIPANT	\N	PRESENT	0
127792	127192	08010L	PARTICIPANT	\N	PRESENT	0
127793	127192	14030Q	PARTICIPANT	\N	PRESENT	0
127794	127192	95049N	PARTICIPANT	\N	PRESENT	0
127795	127192	14221J	PARTICIPANT	\N	PRESENT	0
127796	127192	11053K	PARTICIPANT	\N	PRESENT	0
127797	127192	04080J	PARTICIPANT	\N	PRESENT	0
127798	127192	14034U	PARTICIPANT	\N	PRESENT	0
127799	127192	14053L	PARTICIPANT	\N	PRESENT	0
127800	127192	11064N	PARTICIPANT	\N	PRESENT	0
127801	127192	11070L	PARTICIPANT	\N	PRESENT	0
127802	127192	04047H	PARTICIPANT	\N	PRESENT	0
127803	127192	14042U	PARTICIPANT	\N	PRESENT	0
127804	127192	14219Q	PARTICIPANT	\N	PRESENT	0
127805	127192	14103D	PARTICIPANT	\N	PRESENT	0
127806	127192	14267Y	PARTICIPANT	\N	PRESENT	0
127807	127192	08062Y	PARTICIPANT	\N	PRESENT	0
127808	127192	14231L	PARTICIPANT	\N	PRESENT	0
127809	127192	04057K	PARTICIPANT	\N	PRESENT	0
127810	127192	09001P	PARTICIPANT	\N	PRESENT	0
127811	127192	01025N	PARTICIPANT	\N	PRESENT	0
127812	127192	11085T	PARTICIPANT	\N	PRESENT	0
127813	127192	01047U	PARTICIPANT	\N	PRESENT	0
127814	127192	07004J	PARTICIPANT	\N	PRESENT	0
127815	127192	04070G	PARTICIPANT	\N	PRESENT	0
127816	127192	14255U	PARTICIPANT	\N	PRESENT	0
127817	127192	14205J	PARTICIPANT	\N	PRESENT	0
127818	127192	98042T	PARTICIPANT	\N	PRESENT	0
127819	127192	04089T	PARTICIPANT	\N	PRESENT	0
127820	127192	01061S	PARTICIPANT	\N	PRESENT	0
127821	127192	11093T	PARTICIPANT	\N	PRESENT	0
127822	127192	14083S	PARTICIPANT	\N	PRESENT	0
127823	127192	11111C	PARTICIPANT	\N	PRESENT	0
127824	127192	04061F	PARTICIPANT	\N	PRESENT	0
127825	127192	14327T	PARTICIPANT	\N	PRESENT	0
127826	127192	05004A	PARTICIPANT	\N	PRESENT	0
127827	127192	14089Y	PARTICIPANT	\N	PRESENT	0
127828	127192	11082Q	PARTICIPANT	\N	PRESENT	0
127829	127192	14073Q	PARTICIPANT	\N	PRESENT	0
127830	127192	98021N	PARTICIPANT	\N	PRESENT	0
127831	127192	01034P	PARTICIPANT	\N	PRESENT	0
127832	127192	11090Q	PARTICIPANT	\N	PRESENT	0
127833	127192	88008L	PARTICIPANT	\N	PRESENT	0
127834	127192	14235Q	PARTICIPANT	\N	PRESENT	0
127835	127192	11056N	PARTICIPANT	\N	PRESENT	0
127836	127192	11039M	PARTICIPANT	\N	PRESENT	0
127837	127192	04077P	PARTICIPANT	\N	PRESENT	0
127838	127192	08055A	PARTICIPANT	\N	PRESENT	0
127839	127192	04079R	PARTICIPANT	\N	PRESENT	0
127840	127192	14109K	PARTICIPANT	\N	PRESENT	0
127841	127192	08034U	PARTICIPANT	\N	PRESENT	0
127842	127192	01048V	PARTICIPANT	\N	PRESENT	0
127843	127192	14241N	PARTICIPANT	\N	PRESENT	0
128136	127240	02002K	PARTICIPANT	\N	PRESENT	0
128137	127240	01027Q	PARTICIPANT	\N	PRESENT	0
128138	127240	95062K	PARTICIPANT	\N	PRESENT	0
128139	127240	96004D	PARTICIPANT	\N	PRESENT	0
128140	127240	99004R	PARTICIPANT	\N	PRESENT	0
128141	127240	04044E	PARTICIPANT	\N	PRESENT	0
128142	127240	04041B	PARTICIPANT	\N	PRESENT	0
128143	127240	14223L	PARTICIPANT	\N	PRESENT	0
128144	127240	07034Q	PARTICIPANT	\N	PRESENT	0
128145	127240	95030B	PARTICIPANT	\N	PRESENT	0
128146	127240	14087W	PARTICIPANT	\N	PRESENT	0
128147	127240	04092N	PARTICIPANT	\N	PRESENT	0
128148	127240	14169X	PARTICIPANT	\N	PRESENT	0
128149	127240	08010L	PARTICIPANT	\N	PRESENT	0
128150	127240	01061S	PARTICIPANT	\N	PRESENT	0
128151	127240	11049P	PARTICIPANT	\N	PRESENT	0
128152	127240	98005N	PARTICIPANT	\N	PRESENT	0
128153	127240	89029V	PARTICIPANT	\N	PRESENT	0
128154	127240	07029T	PARTICIPANT	\N	PRESENT	0
128155	127240	14227Q	PARTICIPANT	\N	PRESENT	0
128156	127240	11054L	PARTICIPANT	\N	PRESENT	0
128157	127240	11095V	PARTICIPANT	\N	PRESENT	0
128158	127240	14063N	PARTICIPANT	\N	PRESENT	0
128159	127240	14085U	PARTICIPANT	\N	PRESENT	0
128160	127240	04066L	PARTICIPANT	\N	PRESENT	0
128161	127240	92020L	PARTICIPANT	\N	PRESENT	0
128162	127240	08034U	PARTICIPANT	\N	PRESENT	0
128163	127240	11035H	PARTICIPANT	\N	PRESENT	0
128164	127240	11104D	PARTICIPANT	\N	PRESENT	0
128165	127240	11100Y	PARTICIPANT	\N	PRESENT	0
128166	127240	11037K	PARTICIPANT	\N	PRESENT	0
128167	127240	14059S	PARTICIPANT	\N	PRESENT	0
128168	127240	08021P	PARTICIPANT	\N	PRESENT	0
128169	127240	98022P	PARTICIPANT	\N	PRESENT	0
128170	127240	08031R	PARTICIPANT	\N	PRESENT	0
128171	127240	14018U	PARTICIPANT	\N	PRESENT	0
128172	127240	14269B	PARTICIPANT	\N	PRESENT	0
128173	127240	04095R	PARTICIPANT	\N	PRESENT	0
128174	127240	04054G	PARTICIPANT	\N	PRESENT	0
128175	127240	87003B	PARTICIPANT	\N	PRESENT	0
128176	127240	14121F	PARTICIPANT	\N	PRESENT	0
128177	127240	14061L	PARTICIPANT	\N	PRESENT	0
128178	127240	14093U	PARTICIPANT	\N	PRESENT	0
128179	127240	14159V	PARTICIPANT	\N	PRESENT	0
128180	127240	11107G	PARTICIPANT	\N	PRESENT	0
128181	127240	10015M	PARTICIPANT	\N	PRESENT	0
128182	127240	14331P	PARTICIPANT	\N	PRESENT	0
128183	127240	14107H	PARTICIPANT	\N	PRESENT	0
128184	127240	14239U	PARTICIPANT	\N	PRESENT	0
128185	127240	08019V	PARTICIPANT	\N	PRESENT	0
128186	127240	14105F	PARTICIPANT	\N	PRESENT	0
128187	127240	14329V	PARTICIPANT	\N	PRESENT	0
128188	127240	04097T	PARTICIPANT	\N	PRESENT	0
128189	127240	98035U	PARTICIPANT	\N	PRESENT	0
128190	127240	11098Y	PARTICIPANT	\N	PRESENT	0
128191	127240	08048B	PARTICIPANT	\N	PRESENT	0
128192	127240	13002U	PARTICIPANT	\N	PRESENT	0
128193	127240	08041T	PARTICIPANT	\N	PRESENT	0
128194	127240	77002U	PARTICIPANT	\N	PRESENT	0
128195	127240	08016S	PARTICIPANT	\N	PRESENT	0
128196	127240	05004A	PARTICIPANT	\N	PRESENT	0
128197	127240	08014Q	PARTICIPANT	\N	PRESENT	0
128198	127240	08028W	PARTICIPANT	\N	PRESENT	0
128199	127240	04056J	PARTICIPANT	\N	PRESENT	0
128200	127240	04047H	PARTICIPANT	\N	PRESENT	0
128201	127240	11039M	PARTICIPANT	\N	PRESENT	0
128202	127240	14265W	PARTICIPANT	\N	PRESENT	0
128203	127240	01056V	PARTICIPANT	\N	PRESENT	0
128204	127240	14039A	PARTICIPANT	\N	PRESENT	0
128205	127240	08073C	PARTICIPANT	\N	PRESENT	0
128206	127240	04086Q	PARTICIPANT	\N	PRESENT	0
128207	127240	11109J	PARTICIPANT	\N	PRESENT	0
128208	127240	11088W	PARTICIPANT	\N	PRESENT	0
128209	127240	08051V	PARTICIPANT	\N	PRESENT	0
128210	127240	01059Y	PARTICIPANT	\N	PRESENT	0
128211	127240	14235Q	PARTICIPANT	\N	PRESENT	0
128212	127240	11034G	PARTICIPANT	\N	PRESENT	0
128213	127240	11101A	PARTICIPANT	\N	PRESENT	0
128214	127240	11063M	PARTICIPANT	\N	PRESENT	0
128215	127240	14026U	PARTICIPANT	\N	PRESENT	0
128216	127240	14028W	PARTICIPANT	\N	PRESENT	0
128217	127240	80013X	PARTICIPANT	\N	PRESENT	0
156672	155097	08039A	PARTICIPANT	\N	PRESENT	0
156673	155097	11048N	PARTICIPANT	\N	PRESENT	0
156674	155097	04043D	PARTICIPANT	\N	PRESENT	0
156675	155097	04057K	PARTICIPANT	\N	PRESENT	0
156676	155097	14331P	PARTICIPANT	\N	PRESENT	0
156677	155097	14038Y	PARTICIPANT	\N	PRESENT	0
156678	155097	14105F	PARTICIPANT	\N	PRESENT	0
156679	155097	14073Q	PARTICIPANT	\N	PRESENT	0
156680	155097	14179A	PARTICIPANT	\N	PRESENT	0
156681	155097	14083S	PARTICIPANT	\N	PRESENT	0
156682	155097	14267Y	PARTICIPANT	\N	PRESENT	0
156683	155097	14042U	PARTICIPANT	\N	PRESENT	0
156684	155097	14219Q	PARTICIPANT	\N	PRESENT	0
156685	155097	14159V	PARTICIPANT	\N	PRESENT	0
156686	155097	14107H	PARTICIPANT	\N	PRESENT	0
156687	155097	11027H	PARTICIPANT	\N	PRESENT	0
156688	155097	11036J	PARTICIPANT	\N	PRESENT	0
156689	155097	97011G	PARTICIPANT	\N	PRESENT	0
156690	155097	11083R	PARTICIPANT	\N	PRESENT	0
156691	155097	11099A	PARTICIPANT	\N	PRESENT	0
156692	155097	14261S	PARTICIPANT	\N	PRESENT	0
156693	155097	08068F	PARTICIPANT	\N	PRESENT	0
156694	155097	95063L	PARTICIPANT	\N	PRESENT	0
156517	156453	08024S	PARTICIPANT	\N	PRESENT	0
156518	156453	95030B	PARTICIPANT	\N	PRESENT	0
156519	156453	14223L	PARTICIPANT	\N	PRESENT	0
156521	156453	14038Y	PARTICIPANT	\N	PRESENT	0
156522	156453	11083R	PARTICIPANT	\N	PRESENT	0
156523	156453	11027H	PARTICIPANT	\N	PRESENT	0
156524	156453	11066Q	PARTICIPANT	\N	PRESENT	0
156525	156453	11057P	PARTICIPANT	\N	PRESENT	0
156526	156453	11040E	PARTICIPANT	\N	PRESENT	0
156527	156453	07024N	PARTICIPANT	\N	PRESENT	0
156528	156453	95015C	PARTICIPANT	\N	PRESENT	0
156529	156453	14133K	PARTICIPANT	\N	PRESENT	0
156530	156453	07029T	PARTICIPANT	\N	PRESENT	0
156531	156453	14105F	PARTICIPANT	\N	PRESENT	0
156532	156453	04088S	PARTICIPANT	\N	PRESENT	0
156533	156453	11012A	PARTICIPANT	\N	PRESENT	0
156534	156453	14083S	PARTICIPANT	\N	PRESENT	0
156535	156453	14193X	PARTICIPANT	\N	PRESENT	0
156536	156453	13002U	PARTICIPANT	\N	PRESENT	0
156537	156453	04034C	PARTICIPANT	\N	PRESENT	0
156538	156453	14063N	PARTICIPANT	\N	PRESENT	0
156539	156453	14179A	PARTICIPANT	\N	PRESENT	0
156540	156453	14031R	PARTICIPANT	\N	PRESENT	0
156541	156453	14253S	PARTICIPANT	\N	PRESENT	0
156542	156453	11067R	PARTICIPANT	\N	PRESENT	0
156543	156453	08011M	PARTICIPANT	\N	PRESENT	0
156544	156453	01031L	PARTICIPANT	\N	PRESENT	0
156545	156453	14079W	PARTICIPANT	\N	PRESENT	0
156546	156453	11098Y	PARTICIPANT	\N	PRESENT	0
156547	156453	01044R	PARTICIPANT	\N	PRESENT	0
156548	156453	14219Q	PARTICIPANT	\N	PRESENT	0
156549	156453	08034U	PARTICIPANT	\N	PRESENT	0
156552	156453	04086Q	PARTICIPANT	\N	PRESENT	0
156553	156453	08010L	PARTICIPANT	\N	PRESENT	0
156554	156453	11088W	PARTICIPANT	\N	PRESENT	0
156573	156453	97011G	PARTICIPANT	\N	PRESENT	0
156556	156453	14042U	PARTICIPANT	\N	PRESENT	0
156572	156453	08069G	PARTICIPANT	\N	PRESENT	0
156574	156453	14073Q	PARTICIPANT	\N	PRESENT	0
156575	156453	08051V	PARTICIPANT	\N	PRESENT	0
156576	156453	14261S	PARTICIPANT	\N	PRESENT	0
156577	156453	14269B	PARTICIPANT	\N	PRESENT	0
156578	156453	11036J	PARTICIPANT	\N	PRESENT	0
156579	156453	14013P	PARTICIPANT	\N	PRESENT	0
156580	156453	11064N	PARTICIPANT	\N	PRESENT	0
156581	156453	14159V	PARTICIPANT	\N	PRESENT	0
156582	156453	04053F	PARTICIPANT	\N	PRESENT	0
156622	156453	04043D	PARTICIPANT	\N	PRESENT	0
156623	156453	11093T	PARTICIPANT	\N	PRESENT	0
156624	156453	11099A	PARTICIPANT	\N	PRESENT	0
156625	156453	95063L	PARTICIPANT	\N	PRESENT	0
156652	156453	14041T	PARTICIPANT	\N	PRESENT	0
156653	156453	14157T	PARTICIPANT	\N	PRESENT	0
156654	156453	08039A	PARTICIPANT	\N	PRESENT	0
156655	156453	11097X	PARTICIPANT	\N	PRESENT	0
156656	156453	14147R	PARTICIPANT	\N	PRESENT	0
156657	156453	11048N	PARTICIPANT	\N	PRESENT	0
156658	156453	04057K	PARTICIPANT	\N	PRESENT	0
156659	156453	08055A	PARTICIPANT	\N	PRESENT	0
156660	156453	14030Q	PARTICIPANT	\N	PRESENT	0
156661	156453	14239U	PARTICIPANT	\N	PRESENT	0
156662	155097	08024S	PARTICIPANT	\N	PRESENT	0
156695	155097	14033T	PARTICIPANT	\N	PRESENT	0
156696	155097	14013P	PARTICIPANT	\N	PRESENT	0
156697	155097	07029T	PARTICIPANT	\N	PRESENT	0
156698	155097	14265W	PARTICIPANT	\N	PRESENT	0
156699	155097	14269B	PARTICIPANT	\N	PRESENT	0
156700	155097	11112D	PARTICIPANT	\N	PRESENT	0
156739	155097	14089Y	PARTICIPANT	\N	PRESENT	0
156740	155097	01058X	PARTICIPANT	\N	PRESENT	0
156741	155097	14157T	PARTICIPANT	\N	PRESENT	0
156742	155097	14133K	PARTICIPANT	\N	PRESENT	0
156752	155097	08069G	PARTICIPANT	\N	PRESENT	0
156753	155097	14249W	PARTICIPANT	\N	PRESENT	0
156754	155097	01015L	PARTICIPANT	\N	PRESENT	0
156755	155097	04067M	PARTICIPANT	\N	PRESENT	0
156756	155097	11103C	PARTICIPANT	\N	PRESENT	0
156772	155097	10015M	PARTICIPANT	\N	PRESENT	0
156773	155097	11053K	PARTICIPANT	\N	PRESENT	0
156774	155097	14201E	PARTICIPANT	\N	PRESENT	0
156810	155098	04043D	PARTICIPANT	\N	PRESENT	0
156811	155098	14179A	PARTICIPANT	\N	PRESENT	0
156812	155098	14219Q	PARTICIPANT	\N	PRESENT	0
156813	155098	14331P	PARTICIPANT	\N	PRESENT	0
156814	155098	14089Y	PARTICIPANT	\N	PRESENT	0
156815	155098	14013P	PARTICIPANT	\N	PRESENT	0
156816	155098	01015L	PARTICIPANT	\N	PRESENT	0
156817	155098	14107H	PARTICIPANT	\N	PRESENT	0
156818	155098	14269B	PARTICIPANT	\N	PRESENT	0
156819	155098	14159V	PARTICIPANT	\N	PRESENT	0
156820	155098	14201E	PARTICIPANT	\N	PRESENT	0
156821	155098	14261S	PARTICIPANT	\N	PRESENT	0
156822	155098	11053K	PARTICIPANT	\N	PRESENT	0
156823	155098	11103C	PARTICIPANT	\N	PRESENT	0
156824	155098	97011G	PARTICIPANT	\N	PRESENT	0
156843	155098	01046T	PARTICIPANT	\N	PRESENT	0
156872	155098	11081P	PARTICIPANT	\N	PRESENT	0
156873	155098	14249W	PARTICIPANT	\N	PRESENT	0
156874	155098	14133K	PARTICIPANT	\N	PRESENT	0
156892	155099	08024S	PARTICIPANT	\N	PRESENT	0
156915	155099	08055A	PARTICIPANT	\N	PRESENT	0
156932	155099	14107H	PARTICIPANT	\N	PRESENT	0
156895	155099	14179A	PARTICIPANT	\N	PRESENT	0
156896	155099	14219Q	PARTICIPANT	\N	PRESENT	0
156914	155099	01008M	PARTICIPANT	\N	PRESENT	0
156933	155099	04067M	PARTICIPANT	\N	PRESENT	0
156899	155099	14013P	PARTICIPANT	\N	PRESENT	0
156900	155099	01015L	PARTICIPANT	\N	PRESENT	0
156935	155099	08010L	PARTICIPANT	\N	PRESENT	0
156902	155099	14201E	PARTICIPANT	\N	PRESENT	0
156903	155099	14261S	PARTICIPANT	\N	PRESENT	0
156934	155099	95067Q	PARTICIPANT	\N	PRESENT	0
156937	155099	05012A	PARTICIPANT	\N	PRESENT	0
156808	155098	08024S	PARTICIPANT	\N	PRESENT	0
156809	155098	08069G	PARTICIPANT	\N	PRESENT	0
156947	155099	11012A	PARTICIPANT	\N	PRESENT	0
156907	155099	01046T	PARTICIPANT	\N	PRESENT	0
156908	155099	11081P	PARTICIPANT	\N	PRESENT	0
156909	155099	14249W	PARTICIPANT	\N	PRESENT	0
156910	155099	14133K	PARTICIPANT	\N	PRESENT	0
156911	155099	11036J	PARTICIPANT	\N	PRESENT	0
156912	155099	14073Q	PARTICIPANT	\N	PRESENT	0
156913	155099	14237S	PARTICIPANT	\N	PRESENT	0
156948	155099	14265W	PARTICIPANT	\N	PRESENT	0
156949	155099	14089Y	PARTICIPANT	\N	PRESENT	0
156952	155099	08051V	PARTICIPANT	\N	PRESENT	0
156972	155099	01056V	PARTICIPANT	\N	PRESENT	0
156993	156992	07034Q	PARTICIPANT	\N	PRESENT	0
157173	157172	04054G	PARTICIPANT	\N	PRESENT	0
157174	157172	04047H	PARTICIPANT	\N	PRESENT	0
157175	157172	14267Y	PARTICIPANT	\N	PRESENT	0
157176	157172	14079W	PARTICIPANT	\N	PRESENT	0
157177	157172	11083R	PARTICIPANT	\N	PRESENT	0
157178	157172	14026U	PARTICIPANT	\N	PRESENT	0
157179	157172	92031P	PARTICIPANT	\N	PRESENT	0
157180	157172	11012A	PARTICIPANT	\N	PRESENT	0
157181	157172	14227Q	PARTICIPANT	\N	PRESENT	0
157182	157172	95067Q	PARTICIPANT	\N	PRESENT	0
130035	129001	08055A	PARTICIPANT	\N	PRESENT	0
130059	129001	11029K	PARTICIPANT	\N	PRESENT	0
130060	129001	11112D	PARTICIPANT	\N	PRESENT	0
130061	129001	14033T	PARTICIPANT	\N	PRESENT	0
130062	129001	14173T	PARTICIPANT	\N	PRESENT	0
130063	129001	14205J	PARTICIPANT	\N	PRESENT	0
130064	129001	07004J	PARTICIPANT	\N	PRESENT	0
130065	129001	14179A	PARTICIPANT	\N	PRESENT	0
130067	129001	11098Y	PARTICIPANT	\N	PRESENT	0
130068	129001	04067M	PARTICIPANT	\N	PRESENT	0
130069	129001	11100Y	PARTICIPANT	\N	PRESENT	0
130070	129001	14265W	PARTICIPANT	\N	PRESENT	0
130071	129001	01008M	PARTICIPANT	\N	PRESENT	0
130072	129001	98050T	PARTICIPANT	\N	PRESENT	0
130073	129001	01007L	PARTICIPANT	\N	PRESENT	0
130074	129001	14013P	PARTICIPANT	\N	PRESENT	0
130080	129001	09001P	PARTICIPANT	\N	PRESENT	0
130081	129001	11036J	PARTICIPANT	\N	PRESENT	0
130082	129001	98005N	PARTICIPANT	\N	PRESENT	0
130109	129001	08019V	PARTICIPANT	\N	PRESENT	0
130131	129001	01048V	PARTICIPANT	\N	PRESENT	0
134538	134514	08055A	PARTICIPANT	\N	PRESENT	0
134542	134514	01028R	PARTICIPANT	\N	PRESENT	0
134543	134514	07034Q	PARTICIPANT	\N	PRESENT	0
134544	134514	14033T	PARTICIPANT	\N	PRESENT	0
134545	134514	08025T	PARTICIPANT	\N	PRESENT	0
134546	134514	04034C	PARTICIPANT	\N	PRESENT	0
134547	134514	14063N	PARTICIPANT	\N	PRESENT	0
134548	134514	01044R	PARTICIPANT	\N	PRESENT	0
134549	134514	14073Q	PARTICIPANT	\N	PRESENT	0
134550	134514	14135M	PARTICIPANT	\N	PRESENT	0
134551	134514	14265W	PARTICIPANT	\N	PRESENT	0
134552	134514	08048B	PARTICIPANT	\N	PRESENT	0
134553	134514	14105F	PARTICIPANT	\N	PRESENT	0
134554	134514	14267Y	PARTICIPANT	\N	PRESENT	0
134555	134514	04038G	PARTICIPANT	\N	PRESENT	0
134556	134514	11091R	PARTICIPANT	\N	PRESENT	0
134557	134514	04085P	PARTICIPANT	\N	PRESENT	0
134558	134514	01047U	PARTICIPANT	\N	PRESENT	0
134559	134514	04067M	PARTICIPANT	\N	PRESENT	0
134560	134514	04088S	PARTICIPANT	\N	PRESENT	0
134561	134514	14213J	PARTICIPANT	\N	PRESENT	0
134562	134514	11053K	PARTICIPANT	\N	PRESENT	0
134563	134514	14219Q	PARTICIPANT	\N	PRESENT	0
134564	134514	95030B	PARTICIPANT	\N	PRESENT	0
134565	134514	14263U	PARTICIPANT	\N	PRESENT	0
134566	134514	14031R	PARTICIPANT	\N	PRESENT	0
134567	134514	08015R	PARTICIPANT	\N	PRESENT	0
134568	134514	14221J	PARTICIPANT	\N	PRESENT	0
134569	134514	14231L	PARTICIPANT	\N	PRESENT	0
134570	134514	14197C	PARTICIPANT	\N	PRESENT	0
134571	134514	14121F	PARTICIPANT	\N	PRESENT	0
134572	134514	95063L	PARTICIPANT	\N	PRESENT	0
134573	134514	14111D	PARTICIPANT	\N	PRESENT	0
134574	134514	11049P	PARTICIPANT	\N	PRESENT	0
134575	134514	87003B	PARTICIPANT	\N	PRESENT	0
134576	134514	08016S	PARTICIPANT	\N	PRESENT	0
134577	134514	14014Q	PARTICIPANT	\N	PRESENT	0
134578	134514	11084S	PARTICIPANT	\N	PRESENT	0
134579	134514	11088W	PARTICIPANT	\N	PRESENT	0
134580	134514	14103D	PARTICIPANT	\N	PRESENT	0
134581	134514	04043D	PARTICIPANT	\N	PRESENT	0
134582	134514	04057K	PARTICIPANT	\N	PRESENT	0
134583	134514	08062Y	PARTICIPANT	\N	PRESENT	0
134584	134514	14193X	PARTICIPANT	\N	PRESENT	0
134585	134514	08068F	PARTICIPANT	\N	PRESENT	0
134586	134514	11066Q	PARTICIPANT	\N	PRESENT	0
134600	134514	14018U	PARTICIPANT	\N	PRESENT	0
134602	134514	14215L	PARTICIPANT	\N	PRESENT	0
134603	134514	14207L	PARTICIPANT	\N	PRESENT	0
134604	134514	14257W	PARTICIPANT	\N	PRESENT	0
134605	134514	11036J	PARTICIPANT	\N	PRESENT	0
134612	134514	14107H	PARTICIPANT	\N	PRESENT	0
134613	134514	14201E	PARTICIPANT	\N	PRESENT	0
134629	134514	11064N	PARTICIPANT	\N	PRESENT	0
134630	134514	11056N	PARTICIPANT	\N	PRESENT	0
134631	134514	14133K	PARTICIPANT	\N	PRESENT	0
134632	134514	08056B	PARTICIPANT	\N	PRESENT	0
134633	134514	98022P	PARTICIPANT	\N	PRESENT	0
134634	134514	80013X	PARTICIPANT	\N	PRESENT	0
134635	134514	11039M	PARTICIPANT	\N	PRESENT	0
134636	134514	14089Y	PARTICIPANT	\N	PRESENT	0
134637	134514	11111C	PARTICIPANT	\N	PRESENT	0
134638	134514	01024M	PARTICIPANT	\N	PRESENT	0
134639	134514	14205J	PARTICIPANT	\N	PRESENT	0
134640	134514	86044G	PARTICIPANT	\N	PRESENT	0
134641	134514	14038Y	PARTICIPANT	\N	PRESENT	0
134661	134514	92015P	PARTICIPANT	\N	PRESENT	0
134662	134514	11057P	PARTICIPANT	\N	PRESENT	0
134663	134514	98005N	PARTICIPANT	\N	PRESENT	0
134664	134514	04092N	PARTICIPANT	\N	PRESENT	0
134665	134514	14147R	PARTICIPANT	\N	PRESENT	0
134666	134514	04049K	PARTICIPANT	\N	PRESENT	0
134667	134514	08011M	PARTICIPANT	\N	PRESENT	0
134668	134514	08019V	PARTICIPANT	\N	PRESENT	0
134689	134514	14195A	PARTICIPANT	\N	PRESENT	0
134695	134514	08069G	PARTICIPANT	\N	PRESENT	0
134700	134514	95067Q	PARTICIPANT	\N	PRESENT	0
134701	134514	11063M	PARTICIPANT	\N	PRESENT	0
134707	134514	14199E	PARTICIPANT	\N	PRESENT	0
134708	134514	01025N	PARTICIPANT	\N	PRESENT	0
134709	134514	07029T	PARTICIPANT	\N	PRESENT	0
134710	134514	04071H	PARTICIPANT	\N	PRESENT	0
134831	134515	86034E	PARTICIPANT	\N	PRESENT	0
134836	134515	14033T	PARTICIPANT	\N	PRESENT	0
134837	134515	14331P	PARTICIPANT	\N	PRESENT	0
134840	134515	04074L	PARTICIPANT	\N	PRESENT	0
134841	134515	08018U	PARTICIPANT	\N	PRESENT	0
134842	134515	04048J	PARTICIPANT	\N	PRESENT	0
134843	134515	01056V	PARTICIPANT	\N	PRESENT	0
134844	134515	77002U	PARTICIPANT	\N	PRESENT	0
134845	134515	14249W	PARTICIPANT	\N	PRESENT	0
134847	134515	14041T	PARTICIPANT	\N	PRESENT	0
134849	134515	87003B	PARTICIPANT	\N	PRESENT	0
134850	134515	98024R	PARTICIPANT	\N	PRESENT	0
134853	134515	14195A	PARTICIPANT	\N	PRESENT	0
134854	134515	11103C	PARTICIPANT	\N	PRESENT	0
134855	134515	98023Q	PARTICIPANT	\N	PRESENT	0
134856	134515	11088W	PARTICIPANT	\N	PRESENT	0
134857	134515	14133K	PARTICIPANT	\N	PRESENT	0
134858	134515	14147R	PARTICIPANT	\N	PRESENT	0
134860	134515	14217N	PARTICIPANT	\N	PRESENT	0
134861	134515	11091R	PARTICIPANT	\N	PRESENT	0
134863	134515	95035G	PARTICIPANT	\N	PRESENT	0
134864	134515	04047H	PARTICIPANT	\N	PRESENT	0
134865	134515	07034Q	PARTICIPANT	\N	PRESENT	0
134866	134515	11100Y	PARTICIPANT	\N	PRESENT	0
134867	134515	08022Q	PARTICIPANT	\N	PRESENT	0
134868	134515	14037X	PARTICIPANT	\N	PRESENT	0
134869	134515	05004A	PARTICIPANT	\N	PRESENT	0
134870	134515	95030B	PARTICIPANT	\N	PRESENT	0
134871	134515	92045V	PARTICIPANT	\N	PRESENT	0
134872	134515	11020A	PARTICIPANT	\N	PRESENT	0
134873	134515	08010L	PARTICIPANT	\N	PRESENT	0
134874	134515	04044E	PARTICIPANT	\N	PRESENT	0
134875	134515	04081K	PARTICIPANT	\N	PRESENT	0
134876	134515	14105F	PARTICIPANT	\N	PRESENT	0
134877	134515	14193X	PARTICIPANT	\N	PRESENT	0
134878	134515	14329V	PARTICIPANT	\N	PRESENT	0
134879	134515	14199E	PARTICIPANT	\N	PRESENT	0
134880	134515	01027Q	PARTICIPANT	\N	PRESENT	0
134881	134515	07032N	PARTICIPANT	\N	PRESENT	0
134882	134515	04057K	PARTICIPANT	\N	PRESENT	0
134883	134515	14187A	PARTICIPANT	\N	PRESENT	0
134884	134515	11049P	PARTICIPANT	\N	PRESENT	0
134885	134515	07029T	PARTICIPANT	\N	PRESENT	0
134886	134515	04088S	PARTICIPANT	\N	PRESENT	0
134887	134515	05012A	PARTICIPANT	\N	PRESENT	0
134888	134515	08047A	PARTICIPANT	\N	PRESENT	0
134889	134515	04049K	PARTICIPANT	\N	PRESENT	0
134890	134515	97011G	PARTICIPANT	\N	PRESENT	0
134891	134515	95062K	PARTICIPANT	\N	PRESENT	0
134892	134515	14175V	PARTICIPANT	\N	PRESENT	0
134893	134515	95059Q	PARTICIPANT	\N	PRESENT	0
134894	134515	14059S	PARTICIPANT	\N	PRESENT	0
134895	134515	86044G	PARTICIPANT	\N	PRESENT	0
134896	134515	11097X	PARTICIPANT	\N	PRESENT	0
134897	134515	92040Q	PARTICIPANT	\N	PRESENT	0
134898	134515	08015R	PARTICIPANT	\N	PRESENT	0
134899	134515	99004R	PARTICIPANT	\N	PRESENT	0
134900	134515	04085P	PARTICIPANT	\N	PRESENT	0
134901	134515	98053W	PARTICIPANT	\N	PRESENT	0
134902	134515	92018S	PARTICIPANT	\N	PRESENT	0
134903	134515	11056N	PARTICIPANT	\N	PRESENT	0
134904	134515	14253S	PARTICIPANT	\N	PRESENT	0
134905	134515	04036E	PARTICIPANT	\N	PRESENT	0
134906	134515	01013J	PARTICIPANT	\N	PRESENT	0
134907	134515	07026Q	PARTICIPANT	\N	PRESENT	0
163416	162732	14042U	PARTICIPANT	\N	PRESENT	0
163417	162732	98005N	PARTICIPANT	\N	PRESENT	0
163432	162732	86044G	PARTICIPANT	\N	PRESENT	0
163433	162732	80013X	PARTICIPANT	\N	PRESENT	0
163452	162732	14201E	PARTICIPANT	\N	PRESENT	0
163472	162732	14265W	PARTICIPANT	\N	PRESENT	0
162210	162209	14239U	PARTICIPANT	\N	PRESENT	0
163473	162732	14215L	PARTICIPANT	\N	PRESENT	0
163474	162732	01016M	PARTICIPANT	\N	PRESENT	0
162213	162209	08043V	PARTICIPANT	\N	PRESENT	0
162214	162209	08024S	PARTICIPANT	\N	PRESENT	0
162215	162209	14195A	PARTICIPANT	\N	PRESENT	0
162216	162209	11031D	PARTICIPANT	\N	PRESENT	0
162217	162209	08052W	PARTICIPANT	\N	PRESENT	0
163492	162732	04067M	PARTICIPANT	\N	PRESENT	0
163512	162732	11084S	PARTICIPANT	\N	PRESENT	0
162220	162209	87003B	PARTICIPANT	\N	PRESENT	0
162221	162209	11061K	PARTICIPANT	\N	PRESENT	0
162222	162209	14213J	PRESIDENT	0	PRESENT	0
163513	162732	01008M	PARTICIPANT	\N	PRESENT	0
163552	162732	14097Y	PARTICIPANT	\N	PRESENT	0
162225	162209	14147R	PARTICIPANT	\N	PRESENT	0
163553	162732	01046T	PARTICIPANT	\N	PRESENT	0
163593	163592	14239U	PARTICIPANT	\N	PRESENT	0
163619	162732	98053W	PARTICIPANT	\N	PRESENT	0
162229	162209	14028W	PARTICIPANT	\N	PRESENT	0
163620	162732	14089Y	PARTICIPANT	\N	PRESENT	0
162231	162209	14331P	PARTICIPANT	\N	PRESENT	0
163621	162732	14253S	PARTICIPANT	\N	PRESENT	0
162233	162209	11097X	PARTICIPANT	\N	PRESENT	0
163597	163592	08024S	PARTICIPANT	\N	PRESENT	0
162235	162209	11094U	PARTICIPANT	\N	PRESENT	0
163598	163592	14195A	PARTICIPANT	\N	PRESENT	0
163599	163592	11031D	PARTICIPANT	\N	PRESENT	0
163600	163592	08052W	PARTICIPANT	\N	PRESENT	0
163622	162732	04049K	PARTICIPANT	\N	PRESENT	0
163623	162732	11014C	PARTICIPANT	\N	PRESENT	0
163624	162732	01056V	PARTICIPANT	\N	PRESENT	0
163632	162732	08060W	PARTICIPANT	\N	PRESENT	0
163605	163592	14213J	PRESIDENT	0	PRESENT	0
163652	162732	14193X	PARTICIPANT	\N	PRESENT	0
163653	162732	01058X	PARTICIPANT	\N	PRESENT	0
163753	162733	01044R	PARTICIPANT	\N	PRESENT	0
163754	162733	14059S	PARTICIPANT	\N	PRESENT	0
163755	162733	14259Y	PARTICIPANT	\N	PRESENT	0
163611	163592	14265W	PARTICIPANT	\N	PRESENT	0
163756	162733	14039A	PARTICIPANT	\N	PRESENT	0
163613	163592	14235Q	PARTICIPANT	\N	EXCUSE	0
163757	162733	14275Y	PARTICIPANT	\N	PRESENT	0
163758	162733	14089Y	PARTICIPANT	\N	PRESENT	0
163616	163592	11097X	PARTICIPANT	\N	PRESENT	0
163759	162733	14231L	PARTICIPANT	\N	PRESENT	0
163618	163592	11094U	PARTICIPANT	\N	PRESENT	0
163760	162733	14083S	PARTICIPANT	\N	PRESENT	0
163761	162733	14357A	PARTICIPANT	\N	PRESENT	0
163762	162733	14217N	PARTICIPANT	\N	PRESENT	0
163763	162733	14215L	PARTICIPANT	\N	PRESENT	0
163764	162733	11072N	PARTICIPANT	\N	PRESENT	0
163765	162733	14265W	PARTICIPANT	\N	PRESENT	0
163766	162733	05008E	PARTICIPANT	\N	PRESENT	0
163767	162733	04085P	PARTICIPANT	\N	PRESENT	0
163768	162733	14159V	PARTICIPANT	\N	PRESENT	0
163769	162733	04094Q	PARTICIPANT	\N	PRESENT	0
163770	162733	11071M	PARTICIPANT	\N	PRESENT	0
163771	162733	01022K	PARTICIPANT	\N	PRESENT	0
163772	162733	11109J	PARTICIPANT	\N	PRESENT	0
163773	162733	11113E	PARTICIPANT	\N	PRESENT	0
163774	162733	08073C	PARTICIPANT	\N	PRESENT	0
163775	162733	08019V	PARTICIPANT	\N	PRESENT	0
163776	162733	14042U	PARTICIPANT	\N	PRESENT	0
163777	162733	14257W	PARTICIPANT	\N	PRESENT	0
163792	162733	04095R	PARTICIPANT	\N	PRESENT	0
163812	162733	14197C	PARTICIPANT	\N	PRESENT	0
163813	162733	11114F	PARTICIPANT	\N	PRESENT	0
163814	162733	04049K	PARTICIPANT	\N	PRESENT	0
163832	162733	14261S	PARTICIPANT	\N	PRESENT	0
163852	162733	05001W	PARTICIPANT	\N	PRESENT	0
163853	162733	04035D	PARTICIPANT	\N	PRESENT	0
163872	162733	80013X	PARTICIPANT	\N	PRESENT	0
163873	162733	04067M	PARTICIPANT	\N	PRESENT	0
163892	162733	14179A	PARTICIPANT	\N	PRESENT	0
163893	162733	14017T	PARTICIPANT	\N	PRESENT	0
163952	163912	04081K	PARTICIPANT	\N	PRESENT	0
164012	163912	04044E	PARTICIPANT	\N	PRESENT	0
163750	162733	11085T	PARTICIPANT	\N	PRESENT	0
163752	162733	01016M	PARTICIPANT	\N	PRESENT	0
164013	163912	14259Y	PARTICIPANT	\N	PRESENT	0
164014	163912	14217N	PARTICIPANT	\N	PRESENT	0
164015	163912	04085P	PARTICIPANT	\N	PRESENT	0
164016	163912	05001W	PARTICIPANT	\N	PRESENT	0
164017	163912	14063N	PARTICIPANT	\N	PRESENT	0
164018	163912	01022K	PARTICIPANT	\N	PRESENT	0
164019	163912	14281W	PARTICIPANT	\N	PRESENT	0
164020	163912	11113E	PARTICIPANT	\N	PRESENT	0
164021	163912	04094Q	PARTICIPANT	\N	PRESENT	0
164022	163912	11066Q	PARTICIPANT	\N	PRESENT	0
164023	163912	11072N	PARTICIPANT	\N	PRESENT	0
164024	163912	11055M	PARTICIPANT	\N	PRESENT	0
164025	163912	14039A	PARTICIPANT	\N	PRESENT	0
164026	163912	14219Q	PARTICIPANT	\N	PRESENT	0
164027	163912	14089Y	PARTICIPANT	\N	PRESENT	0
164028	163912	11103C	PARTICIPANT	\N	PRESENT	0
164029	163912	04057K	PARTICIPANT	\N	PRESENT	0
164030	163912	08019V	PARTICIPANT	\N	PRESENT	0
164031	163912	11011M	PARTICIPANT	\N	PRESENT	0
164032	163912	14261S	PARTICIPANT	\N	PRESENT	0
164033	163912	08073C	PARTICIPANT	\N	PRESENT	0
164034	163912	14157T	PARTICIPANT	\N	PRESENT	0
164035	163912	11114F	PARTICIPANT	\N	PRESENT	0
164036	163912	11071M	PARTICIPANT	\N	PRESENT	0
164037	163912	14083S	PARTICIPANT	\N	PRESENT	0
164038	163912	14363X	PARTICIPANT	\N	PRESENT	0
164052	163912	14275Y	PARTICIPANT	\N	PRESENT	0
164078	163912	14037X	PARTICIPANT	\N	PRESENT	0
164079	163912	14041T	PARTICIPANT	\N	PRESENT	0
164080	163912	14159V	PARTICIPANT	\N	PRESENT	0
164081	163912	01015L	PARTICIPANT	\N	PRESENT	0
164082	163912	14269B	PARTICIPANT	\N	PRESENT	0
164092	163912	11109J	PARTICIPANT	\N	PRESENT	0
164093	163912	98050T	PARTICIPANT	\N	PRESENT	0
164112	163912	80027E	PARTICIPANT	\N	PRESENT	0
164113	163912	11112D	PARTICIPANT	\N	PRESENT	0
164114	163912	04095R	PARTICIPANT	\N	PRESENT	0
164132	163912	14231L	PARTICIPANT	\N	PRESENT	0
164213	163913	08019V	PARTICIPANT	\N	PRESENT	0
164232	163913	14275Y	PARTICIPANT	\N	PRESENT	0
164233	163913	04056J	PARTICIPANT	\N	PRESENT	0
164252	163913	11072N	PARTICIPANT	\N	PRESENT	0
164253	163913	05001W	PARTICIPANT	\N	PRESENT	0
164254	163913	11055M	PARTICIPANT	\N	PRESENT	0
164255	163913	04094Q	PARTICIPANT	\N	PRESENT	0
164256	163913	14217N	PARTICIPANT	\N	PRESENT	0
164257	163913	14083S	PARTICIPANT	\N	PRESENT	0
164258	163913	07026Q	PARTICIPANT	\N	PRESENT	0
164259	163913	14271U	PARTICIPANT	\N	PRESENT	0
164260	163913	01022K	PARTICIPANT	\N	PRESENT	0
164261	163913	14013P	PARTICIPANT	\N	PRESENT	0
164262	163913	08073C	PARTICIPANT	\N	PRESENT	0
164263	163913	04085P	PARTICIPANT	\N	PRESENT	0
164264	163913	14331P	PARTICIPANT	\N	PRESENT	0
164265	163913	04095R	PARTICIPANT	\N	PRESENT	0
164266	163913	14041T	PARTICIPANT	\N	PRESENT	0
164267	163913	11109J	PARTICIPANT	\N	PRESENT	0
164268	163913	14039A	PARTICIPANT	\N	PRESENT	0
164269	163913	11011M	PARTICIPANT	\N	PRESENT	0
164272	163913	04034C	PARTICIPANT	\N	PRESENT	0
164273	163913	14261S	PARTICIPANT	\N	PRESENT	0
164292	163913	04043D	PARTICIPANT	\N	PRESENT	0
164293	163913	14033T	PARTICIPANT	\N	PRESENT	0
164294	163913	04035D	PARTICIPANT	\N	PRESENT	0
164295	163913	14363X	PARTICIPANT	\N	PRESENT	0
164296	163913	11071M	PARTICIPANT	\N	PRESENT	0
164312	163913	11113E	PARTICIPANT	\N	PRESENT	0
164313	163913	11039M	PARTICIPANT	\N	PRESENT	0
164314	163913	10006L	PARTICIPANT	\N	PRESENT	0
164332	163913	11010L	PARTICIPANT	\N	PRESENT	0
164353	164352	14249W	PARTICIPANT	\N	PRESENT	0
164355	164354	14249W	PARTICIPANT	\N	PRESENT	0
164356	164354	07026Q	PARTICIPANT	\N	PRESENT	0
164376	164375	95015C	PARTICIPANT	\N	PRESENT	0
164392	163913	04057K	PARTICIPANT	\N	PRESENT	0
164393	163913	11084S	PARTICIPANT	\N	PRESENT	0
164394	163913	14269B	PARTICIPANT	\N	PRESENT	0
164192	163913	04066L	PARTICIPANT	\N	PRESENT	0
164212	163913	14259Y	PARTICIPANT	\N	PRESENT	0
164395	163913	11114F	PARTICIPANT	\N	PRESENT	0
164396	163913	04053F	PARTICIPANT	\N	PRESENT	0
164412	163913	14201E	PARTICIPANT	\N	PRESENT	0
164432	163913	04081K	PARTICIPANT	\N	PRESENT	0
128218	127240	07024N	PARTICIPANT	\N	PRESENT	0
128219	127240	08055A	PARTICIPANT	\N	PRESENT	0
128220	127240	14001X	PARTICIPANT	\N	PRESENT	0
128221	127240	11080N	PARTICIPANT	\N	PRESENT	0
128222	127240	10006L	PARTICIPANT	\N	PRESENT	0
128223	127240	86044G	PARTICIPANT	\N	PRESENT	0
128224	127240	08022Q	PARTICIPANT	\N	PRESENT	0
128225	127240	11106F	PARTICIPANT	\N	PRESENT	0
128226	127240	95015C	PARTICIPANT	\N	PRESENT	0
128227	127240	08053X	PARTICIPANT	\N	PRESENT	0
128228	127240	01013J	PARTICIPANT	\N	PRESENT	0
128229	127240	14069U	PARTICIPANT	\N	PRESENT	0
128230	127240	04036E	PARTICIPANT	\N	PRESENT	0
128231	127240	14013P	PARTICIPANT	\N	PRESENT	0
128232	127240	14051J	PARTICIPANT	\N	PRESENT	0
128233	127240	92018S	PARTICIPANT	\N	PRESENT	0
128234	127240	11015D	PARTICIPANT	\N	PRESENT	0
128235	127240	04057K	PARTICIPANT	\N	PRESENT	0
128236	127240	04050C	PARTICIPANT	\N	PRESENT	0
128237	127240	11097X	PARTICIPANT	\N	PRESENT	0
128238	127240	08058D	PARTICIPANT	\N	PRESENT	0
128239	127240	08042U	PARTICIPANT	\N	PRESENT	0
128240	127240	11089X	PARTICIPANT	\N	PRESENT	0
128241	127240	14237S	PARTICIPANT	\N	PRESENT	0
128242	127240	04085P	PARTICIPANT	\N	PRESENT	0
128243	127240	92031P	PARTICIPANT	\N	PRESENT	0
128244	127240	11057P	PARTICIPANT	\N	PRESENT	0
128245	127240	11090Q	PARTICIPANT	\N	PRESENT	0
128246	127240	98024R	PARTICIPANT	\N	PRESENT	0
128247	127240	95031C	PARTICIPANT	\N	PRESENT	0
128248	127240	08018U	PARTICIPANT	\N	PRESENT	0
128249	127240	04033B	PARTICIPANT	\N	PRESENT	0
128250	127240	90003B	PARTICIPANT	\N	PRESENT	0
128251	127240	98050T	PARTICIPANT	\N	PRESENT	0
128280	127240	14033T	PARTICIPANT	\N	PRESENT	0
128253	127240	95059Q	PARTICIPANT	\N	PRESENT	0
128254	127240	14147R	PARTICIPANT	\N	PRESENT	0
128255	127240	14215L	PARTICIPANT	\N	PRESENT	0
128256	127240	04043D	PARTICIPANT	\N	PRESENT	0
128257	127240	14071N	PARTICIPANT	\N	PRESENT	0
128258	127240	11056N	PARTICIPANT	\N	PRESENT	0
128259	127240	14259Y	PARTICIPANT	\N	PRESENT	0
128260	127240	92045V	PARTICIPANT	\N	PRESENT	0
128261	127240	08052W	PARTICIPANT	\N	PRESENT	0
128262	127240	11011M	PARTICIPANT	\N	PRESENT	0
128263	127240	14014Q	PARTICIPANT	\N	PRESENT	0
128264	127240	08043V	PARTICIPANT	\N	PRESENT	0
128265	127240	14038Y	PARTICIPANT	\N	PRESENT	0
128266	127240	14065Q	PARTICIPANT	\N	PRESENT	0
128267	127240	14119M	PARTICIPANT	\N	PRESENT	0
128268	127240	11046L	PARTICIPANT	\N	PRESENT	0
128269	127240	14157T	PARTICIPANT	\N	PRESENT	0
128270	127240	14109K	PARTICIPANT	\N	PRESENT	0
128271	127240	04074L	PARTICIPANT	\N	PRESENT	0
128272	127240	11030C	PARTICIPANT	\N	PRESENT	0
128273	127240	11061K	PARTICIPANT	\N	PRESENT	0
128274	127240	11112D	PARTICIPANT	\N	PRESENT	0
128275	127240	14031R	PARTICIPANT	\N	PRESENT	0
128276	127240	14281W	PARTICIPANT	\N	PRESENT	0
128277	127240	14173T	PARTICIPANT	\N	PRESENT	0
128278	127240	11036J	PARTICIPANT	\N	PRESENT	0
128279	127240	95037J	PARTICIPANT	\N	PRESENT	0
128281	127240	01057W	PARTICIPANT	\N	PRESENT	0
128282	127240	04081K	PARTICIPANT	\N	PRESENT	0
128283	127240	04034C	PARTICIPANT	\N	PRESENT	0
128284	127240	14213J	PARTICIPANT	\N	PRESENT	0
128285	127240	11084S	PARTICIPANT	\N	PRESENT	0
128286	127240	14111D	PARTICIPANT	\N	PRESENT	0
128287	127240	05012A	PARTICIPANT	\N	PRESENT	0
128288	127240	08062Y	PARTICIPANT	\N	PRESENT	0
128289	127240	08025T	PARTICIPANT	\N	PRESENT	0
128290	127240	98021N	PARTICIPANT	\N	PRESENT	0
128291	127240	11077T	PARTICIPANT	\N	PRESENT	0
128292	127240	07032N	PARTICIPANT	\N	PRESENT	0
128293	127240	98029W	PARTICIPANT	\N	PRESENT	0
128294	127240	14249W	PARTICIPANT	\N	PRESENT	0
128295	127240	12042Y	PARTICIPANT	\N	PRESENT	0
128296	127240	04045F	PARTICIPANT	\N	PRESENT	0
128297	127240	11042G	PARTICIPANT	\N	PRESENT	0
128298	127240	14079W	PARTICIPANT	\N	PRESENT	0
128299	127240	11043H	PARTICIPANT	\N	PRESENT	0
128300	127240	08047A	PARTICIPANT	\N	PRESENT	0
128301	127240	04053F	PARTICIPANT	\N	PRESENT	0
128302	127240	11025F	PARTICIPANT	\N	PRESENT	0
128303	127240	01019Q	PARTICIPANT	\N	PRESENT	0
128304	127240	01011G	PARTICIPANT	\N	PRESENT	0
128305	127240	14209N	PARTICIPANT	\N	PRESENT	0
128306	127240	01044R	PARTICIPANT	\N	PRESENT	0
128307	127240	11033F	PARTICIPANT	\N	PRESENT	0
128308	127240	04067M	PARTICIPANT	\N	PRESENT	0
128309	127240	01058X	PARTICIPANT	\N	PRESENT	0
128310	127240	11055M	PARTICIPANT	\N	PRESENT	0
128311	127240	04061F	PARTICIPANT	\N	PRESENT	0
128312	127240	98018T	PARTICIPANT	\N	PRESENT	0
128313	127240	04035D	PARTICIPANT	\N	PRESENT	0
128314	127240	04059M	PARTICIPANT	\N	PRESENT	0
128315	127240	11083R	PARTICIPANT	\N	PRESENT	0
128316	127240	11029K	PARTICIPANT	\N	PRESENT	0
128317	127240	14123H	PARTICIPANT	\N	PRESENT	0
128318	127240	11081P	PARTICIPANT	\N	PRESENT	0
128319	127240	11012A	PARTICIPANT	\N	PRESENT	0
128320	127240	11103C	PARTICIPANT	\N	PRESENT	0
128321	127240	11096W	PARTICIPANT	\N	PRESENT	0
128322	127240	05008E	PARTICIPANT	\N	PRESENT	0
128323	127240	01046T	PARTICIPANT	\N	PRESENT	0
128324	127240	88008L	PARTICIPANT	\N	PRESENT	0
128325	127240	04038G	PARTICIPANT	\N	PRESENT	0
128326	127240	04049K	PARTICIPANT	\N	PRESENT	0
128327	127240	08015R	PARTICIPANT	\N	PRESENT	0
128328	127240	11026G	PARTICIPANT	\N	PRESENT	0
128329	127240	14211G	PARTICIPANT	\N	PRESENT	0
128330	127240	01060R	PARTICIPANT	\N	PRESENT	0
128331	127240	08039A	PARTICIPANT	\N	PRESENT	0
128332	127240	14055N	PARTICIPANT	\N	PRESENT	0
128333	127240	04088S	PARTICIPANT	\N	PRESENT	0
128334	127240	89017R	PARTICIPANT	\N	PRESENT	0
128335	127240	14253S	PARTICIPANT	\N	PRESENT	0
128336	127240	01014K	PARTICIPANT	\N	PRESENT	0
128337	127240	11091R	PARTICIPANT	\N	PRESENT	0
128338	127240	04078Q	PARTICIPANT	\N	PRESENT	0
128339	127240	92040Q	PARTICIPANT	\N	PRESENT	0
128340	127240	08069G	PARTICIPANT	\N	PRESENT	0
128341	127240	14030Q	PARTICIPANT	\N	PRESENT	0
128342	127240	14221J	PARTICIPANT	\N	PRESENT	0
128343	127240	14042U	PARTICIPANT	\N	PRESENT	0
128344	127240	11070L	PARTICIPANT	\N	PRESENT	0
128345	127240	11064N	PARTICIPANT	\N	PRESENT	0
128346	127240	04080J	PARTICIPANT	\N	PRESENT	0
128347	127240	11053K	PARTICIPANT	\N	PRESENT	0
128348	127240	01047U	PARTICIPANT	\N	PRESENT	0
128349	127240	07004J	PARTICIPANT	\N	PRESENT	0
128350	127240	04070G	PARTICIPANT	\N	PRESENT	0
128351	127240	14205J	PARTICIPANT	\N	PRESENT	0
128352	127240	11093T	PARTICIPANT	\N	PRESENT	0
128353	127240	11066Q	PARTICIPANT	\N	PRESENT	0
128354	127240	12041X	PARTICIPANT	\N	PRESENT	0
128355	127240	14083S	PARTICIPANT	\N	PRESENT	0
128356	127240	11082Q	PARTICIPANT	\N	PRESENT	0
128357	127240	14089Y	PARTICIPANT	\N	PRESENT	0
128358	127240	98042T	PARTICIPANT	\N	PRESENT	0
128359	127240	14247U	PARTICIPANT	\N	PRESENT	0
128360	127240	14133K	PARTICIPANT	\N	PRESENT	0
128361	127240	14241N	PARTICIPANT	\N	PRESENT	0
128362	127240	01025N	PARTICIPANT	\N	PRESENT	0
128363	127240	08035V	PARTICIPANT	\N	PRESENT	0
128364	127240	09001P	PARTICIPANT	\N	PRESENT	0
128365	127240	14255U	PARTICIPANT	\N	PRESENT	0
128366	127240	14197C	PARTICIPANT	\N	PRESENT	0
128367	127240	14195A	PARTICIPANT	\N	PRESENT	0
128368	127240	01048V	PARTICIPANT	\N	PRESENT	0
128369	127240	14081Q	PARTICIPANT	\N	PRESENT	0
128370	127240	14193X	PARTICIPANT	\N	PRESENT	0
128371	127240	83047W	PARTICIPANT	\N	PRESENT	0
128372	127240	14187A	PARTICIPANT	\N	PRESENT	0
128373	127240	14231L	PARTICIPANT	\N	PRESENT	0
128374	127240	04055H	PARTICIPANT	\N	PRESENT	0
128375	127240	14199E	PARTICIPANT	\N	PRESENT	0
128376	127240	14034U	PARTICIPANT	\N	PRESENT	0
128377	127240	11048N	PARTICIPANT	\N	PRESENT	0
128381	127240	11027H	PARTICIPANT	\N	PRESENT	0
128379	127240	04042C	PARTICIPANT	\N	PRESENT	0
128380	127240	11110B	PARTICIPANT	\N	PRESENT	0
128382	127240	14073Q	PARTICIPANT	\N	PRESENT	0
128383	127240	14053L	PARTICIPANT	\N	PRESENT	0
128384	127240	14097Y	PARTICIPANT	\N	PRESENT	0
128385	127240	14135M	PARTICIPANT	\N	PRESENT	0
128386	127240	95067Q	PARTICIPANT	\N	PRESENT	0
128387	127240	11085T	PARTICIPANT	\N	PRESENT	0
157213	157212	04054G	PARTICIPANT	\N	PRESENT	0
157214	157212	04047H	PARTICIPANT	\N	PRESENT	0
157215	157212	14267Y	PARTICIPANT	\N	PRESENT	0
157216	157212	14079W	PARTICIPANT	\N	PRESENT	0
157217	157212	11083R	PARTICIPANT	\N	PRESENT	0
157218	157212	14026U	PARTICIPANT	\N	PRESENT	0
157219	157212	11084S	PARTICIPANT	\N	PRESENT	0
157220	157212	11026G	PARTICIPANT	\N	PRESENT	0
157221	157212	92031P	PARTICIPANT	\N	PRESENT	0
157222	157212	08053X	PARTICIPANT	\N	PRESENT	0
157223	157212	11012A	PARTICIPANT	\N	PRESENT	0
157224	157212	14227Q	PARTICIPANT	\N	PRESENT	0
157225	157212	11066Q	PARTICIPANT	\N	PRESENT	0
157226	157212	95067Q	PARTICIPANT	\N	PRESENT	0
157333	157332	14133K	PARTICIPANT	\N	PRESENT	0
157334	157332	04047H	PARTICIPANT	\N	PRESENT	0
157335	157332	14267Y	PARTICIPANT	\N	PRESENT	0
157336	157332	14079W	PARTICIPANT	\N	PRESENT	0
157337	157332	11083R	PARTICIPANT	\N	PRESENT	0
157338	157332	14026U	PARTICIPANT	\N	PRESENT	0
157339	157332	11084S	PARTICIPANT	\N	PRESENT	0
157340	157332	14073Q	PARTICIPANT	\N	PRESENT	0
157341	157332	11026G	PARTICIPANT	\N	PRESENT	0
157342	157332	92031P	PARTICIPANT	\N	PRESENT	0
157343	157332	08053X	PARTICIPANT	\N	PRESENT	0
157344	157332	14193X	PARTICIPANT	\N	PRESENT	0
157345	157332	11012A	PARTICIPANT	\N	PRESENT	0
157346	157332	14227Q	PARTICIPANT	\N	PRESENT	0
157347	157332	11066Q	PARTICIPANT	\N	PRESENT	0
157348	157332	95067Q	PARTICIPANT	\N	PRESENT	0
157744	157742	96004D	PARTICIPANT	\N	PRESENT	0
158272	157432	14097Y	PARTICIPANT	\N	EXCUSE	0
158274	157432	01022K	PARTICIPANT	\N	EXCUSE	0
158512	157272	14063N	PARTICIPANT	\N	EXCUSE	0
158546	158545	08025T	PARTICIPANT	\N	PRESENT	0
158547	158545	04085P	PARTICIPANT	\N	PRESENT	0
158548	158545	05008E	PRESIDENT	0	PRESENT	0
158549	158545	14065Q	PARTICIPANT	\N	PRESENT	0
158550	158545	14069U	PARTICIPANT	\N	PRESENT	0
158551	158545	11032E	PARTICIPANT	\N	PRESENT	0
158552	158545	99002P	PARTICIPANT	\N	PRESENT	0
158553	158545	04038G	PARTICIPANT	\N	PRESENT	0
158554	158545	11056N	PARTICIPANT	\N	PRESENT	0
158556	158545	14259Y	PARTICIPANT	\N	PRESENT	0
158557	158545	11035H	PARTICIPANT	\N	PRESENT	0
158558	158545	14041T	PARTICIPANT	\N	PRESENT	0
158559	158545	11113E	PARTICIPANT	\N	PRESENT	0
158560	158545	01024M	PARTICIPANT	\N	PRESENT	0
158561	158545	14215L	PARTICIPANT	\N	PRESENT	0
158562	158545	11034G	PARTICIPANT	\N	PRESENT	0
158563	158545	08018U	PARTICIPANT	\N	PRESENT	0
158564	158545	11010L	PARTICIPANT	\N	PRESENT	0
158565	158545	01007L	PARTICIPANT	\N	PRESENT	0
158566	158545	11049P	PARTICIPANT	\N	PRESENT	0
158567	158545	11084S	PARTICIPANT	\N	PRESENT	0
158569	158545	04079R	PARTICIPANT	\N	PRESENT	0
158570	158545	14111D	PARTICIPANT	\N	PRESENT	0
158571	158545	14001X	PARTICIPANT	\N	PRESENT	0
158573	158545	01060R	PARTICIPANT	\N	PRESENT	0
158574	158545	14147R	PARTICIPANT	\N	PRESENT	0
158575	158545	08051V	PARTICIPANT	\N	PRESENT	0
158576	158545	95049N	PARTICIPANT	\N	PRESENT	0
158579	158545	11072N	PARTICIPANT	\N	PRESENT	0
158581	158545	07034Q	PARTICIPANT	\N	PRESENT	0
158582	158545	04074L	PARTICIPANT	\N	PRESENT	0
158585	158545	10015M	PARTICIPANT	\N	PRESENT	0
158586	158545	95063L	PARTICIPANT	\N	PRESENT	0
158587	158545	01019Q	PARTICIPANT	\N	PRESENT	0
158589	158545	01028R	PARTICIPANT	\N	PRESENT	0
158590	158545	98035U	PARTICIPANT	\N	PRESENT	0
158592	158545	04056J	PARTICIPANT	\N	PRESENT	0
158593	158545	14275Y	PARTICIPANT	\N	PRESENT	0
158595	158545	04044E	PRESIDENT	1	PRESENT	0
158597	158545	11037K	PARTICIPANT	\N	PRESENT	0
158598	158545	92045V	PARTICIPANT	\N	PRESENT	0
158600	158545	95067Q	PARTICIPANT	\N	PRESENT	0
158601	158545	01047U	PARTICIPANT	\N	PRESENT	0
158606	158545	08044W	PARTICIPANT	\N	EXCUSE	0
158609	158545	14059S	PARTICIPANT	\N	PRESENT	0
158612	158608	04059M	PARTICIPANT	\N	PRESENT	0
158615	158608	08043V	PARTICIPANT	\N	PRESENT	0
158616	158608	14089Y	PARTICIPANT	\N	PRESENT	0
158617	158608	14105F	PARTICIPANT	\N	PRESENT	0
158618	158608	11029K	PARTICIPANT	\N	EXCUSE	0
158620	158608	92015P	PARTICIPANT	\N	EXCUSE	0
158622	158608	14201E	PARTICIPANT	\N	PRESENT	0
158625	158608	14079W	PARTICIPANT	\N	PRESENT	0
158626	158608	14363X	PARTICIPANT	\N	PRESENT	0
158627	158608	11091R	PARTICIPANT	\N	PRESENT	0
158628	158608	87003B	PARTICIPANT	\N	PRESENT	0
158630	158608	14249W	PARTICIPANT	\N	PRESENT	0
158632	158608	01025N	PARTICIPANT	\N	EXCUSE	0
158635	158608	11089X	PARTICIPANT	\N	PRESENT	0
158636	158608	07026Q	PARTICIPANT	\N	PRESENT	0
158637	158608	14123H	PARTICIPANT	\N	PRESENT	0
158638	158608	14179A	PARTICIPANT	\N	PRESENT	0
158639	158608	04041B	PARTICIPANT	\N	EXCUSE	0
158640	158608	14241N	PARTICIPANT	\N	PRESENT	0
158641	158608	14061L	PARTICIPANT	\N	EXCUSE	0
158642	158608	14073Q	PARTICIPANT	\N	PRESENT	0
158643	158608	08031R	PARTICIPANT	\N	EXCUSE	0
158644	158608	12041X	PARTICIPANT	\N	PRESENT	0
158645	158608	08039A	PARTICIPANT	\N	EXCUSE	0
158646	158608	08017T	PARTICIPANT	\N	PRESENT	0
158648	158608	08012N	PARTICIPANT	\N	PRESENT	0
158649	158608	14103D	PARTICIPANT	\N	PRESENT	0
158650	158608	11104D	PARTICIPANT	\N	PRESENT	0
158651	158608	14063N	PARTICIPANT	\N	EXCUSE	0
158652	158608	04057K	PRESIDENT	0	PRESENT	0
134910	134515	12041X	PARTICIPANT	\N	PRESENT	0
134908	134515	04092N	PARTICIPANT	\N	PRESENT	0
134909	134515	11063M	PARTICIPANT	\N	PRESENT	0
134911	134515	04054G	PARTICIPANT	\N	PRESENT	0
134912	134515	11031D	PARTICIPANT	\N	PRESENT	0
134913	134515	98021N	PARTICIPANT	\N	PRESENT	0
134914	134515	14263U	PARTICIPANT	\N	PRESENT	0
134915	134515	14013P	PARTICIPANT	\N	PRESENT	0
134916	134515	01015L	PARTICIPANT	\N	PRESENT	0
134917	134515	14111D	PARTICIPANT	\N	PRESENT	0
134918	134515	11055M	PARTICIPANT	\N	PRESENT	0
134919	134515	01044R	PARTICIPANT	\N	PRESENT	0
134920	134515	13002U	PARTICIPANT	\N	PRESENT	0
134921	134515	11076S	PARTICIPANT	\N	PRESENT	0
134922	134515	14038Y	PARTICIPANT	\N	PRESENT	0
134923	134515	04067M	PARTICIPANT	\N	PRESENT	0
134924	134515	11033F	PARTICIPANT	\N	PRESENT	0
134925	134515	11080N	PARTICIPANT	\N	PRESENT	0
134926	134515	11034G	PARTICIPANT	\N	PRESENT	0
134927	134515	95067Q	PARTICIPANT	\N	PRESENT	0
134928	134515	89017R	PARTICIPANT	\N	PRESENT	0
134929	134515	14055N	PARTICIPANT	\N	PRESENT	0
134930	134515	01058X	PARTICIPANT	\N	PRESENT	0
134931	134515	01060R	PARTICIPANT	\N	PRESENT	0
134935	134515	08011M	PARTICIPANT	\N	PRESENT	0
134933	134515	14265W	PARTICIPANT	\N	PRESENT	0
134934	134515	11083R	PARTICIPANT	\N	PRESENT	0
134936	134515	98005N	PARTICIPANT	\N	PRESENT	0
134937	134515	11111C	PARTICIPANT	\N	PRESENT	0
134938	134515	14261S	PARTICIPANT	\N	PRESENT	0
134939	134515	01046T	PARTICIPANT	\N	PRESENT	0
134940	134515	88008L	PARTICIPANT	\N	PRESENT	0
134941	134515	11012A	PARTICIPANT	\N	PRESENT	0
134942	134515	08034U	PARTICIPANT	\N	PRESENT	0
134943	134515	08031R	PARTICIPANT	\N	PRESENT	0
134944	134515	14093U	PARTICIPANT	\N	PRESENT	0
134945	134515	04038G	PARTICIPANT	\N	PRESENT	0
134946	134515	11096W	PARTICIPANT	\N	PRESENT	0
134947	134515	14201E	PARTICIPANT	\N	PRESENT	0
134948	134515	11030C	PARTICIPANT	\N	PRESENT	0
134949	134515	08048B	PARTICIPANT	\N	PRESENT	0
134950	134515	14257W	PARTICIPANT	\N	PRESENT	0
134951	134515	01031L	PARTICIPANT	\N	PRESENT	0
134952	134515	01016M	PARTICIPANT	\N	PRESENT	0
134953	134515	14135M	PARTICIPANT	\N	PRESENT	0
134954	134515	98035U	PARTICIPANT	\N	PRESENT	0
134955	134515	04043D	PARTICIPANT	\N	PRESENT	0
134956	134515	08016S	PARTICIPANT	\N	PRESENT	0
134957	134515	92015P	PARTICIPANT	\N	PRESENT	0
134958	134515	98046X	PARTICIPANT	\N	PRESENT	0
134959	134515	08025T	PARTICIPANT	\N	PRESENT	0
134960	134515	14051J	PARTICIPANT	\N	PRESENT	0
134961	134515	14213J	PARTICIPANT	\N	PRESENT	0
134962	134515	98050T	PARTICIPANT	\N	PRESENT	0
134963	134515	01011G	PARTICIPANT	\N	PRESENT	0
134964	134515	11089X	PARTICIPANT	\N	PRESENT	0
134965	134515	11090Q	PARTICIPANT	\N	PRESENT	0
134966	134515	08055A	PARTICIPANT	\N	PRESENT	0
134967	134515	92020L	PARTICIPANT	\N	PRESENT	0
134968	134515	04055H	PARTICIPANT	\N	PRESENT	0
134969	134515	80013X	PARTICIPANT	\N	PRESENT	0
134970	134515	08062Y	PARTICIPANT	\N	PRESENT	0
134971	134515	14197C	PARTICIPANT	\N	PRESENT	0
134972	134515	14028W	PARTICIPANT	\N	PRESENT	0
134973	134515	80027E	PARTICIPANT	\N	PRESENT	0
134974	134515	11036J	PARTICIPANT	\N	PRESENT	0
134975	134515	01048V	PARTICIPANT	\N	PRESENT	0
134976	134515	14107H	PARTICIPANT	\N	PRESENT	0
134977	134515	11105E	PARTICIPANT	\N	PRESENT	0
134978	134515	08043V	PARTICIPANT	\N	PRESENT	0
134979	134515	08019V	PARTICIPANT	\N	PRESENT	0
134980	134515	08068F	PARTICIPANT	\N	PRESENT	0
134981	134515	98029W	PARTICIPANT	\N	PRESENT	0
134982	134515	11046L	PARTICIPANT	\N	PRESENT	0
134983	134515	04035D	PARTICIPANT	\N	PRESENT	0
134984	134515	83042R	PARTICIPANT	\N	PRESENT	0
134985	134515	11059R	PARTICIPANT	\N	PRESENT	0
134986	134515	08012N	PARTICIPANT	\N	PRESENT	0
134987	134515	04034C	PARTICIPANT	\N	PRESENT	0
134988	134515	95037J	PARTICIPANT	\N	PRESENT	0
134989	134515	14169X	PARTICIPANT	\N	PRESENT	0
134990	134515	11084S	PARTICIPANT	\N	PRESENT	0
134991	134515	11015D	PARTICIPANT	\N	PRESENT	0
134992	134515	11054L	PARTICIPANT	\N	PRESENT	0
134993	134515	04086Q	PARTICIPANT	\N	PRESENT	0
134994	134515	14227Q	PARTICIPANT	\N	PRESENT	0
134995	134515	11057P	PARTICIPANT	\N	PRESENT	0
134996	134515	08014Q	PARTICIPANT	\N	PRESENT	0
134997	134515	14207L	PARTICIPANT	\N	PRESENT	0
134998	134515	14109K	PARTICIPANT	\N	PRESENT	0
134999	134515	14014Q	PARTICIPANT	\N	PRESENT	0
135000	134515	08017T	PARTICIPANT	\N	PRESENT	0
135001	134515	04056J	PARTICIPANT	\N	PRESENT	0
135002	134515	11014C	PARTICIPANT	\N	PRESENT	0
135003	134515	95015C	PARTICIPANT	\N	PRESENT	0
135004	134515	14097Y	PARTICIPANT	\N	PRESENT	0
135005	134515	14259Y	PARTICIPANT	\N	PRESENT	0
135006	134515	14225N	PARTICIPANT	\N	PRESENT	0
135007	134515	14063N	PARTICIPANT	\N	PRESENT	0
135008	134515	14251Q	PARTICIPANT	\N	PRESENT	0
135009	134515	14121F	PARTICIPANT	\N	PRESENT	0
135010	134515	08053X	PARTICIPANT	\N	PRESENT	0
135011	134515	14229S	PARTICIPANT	\N	PRESENT	0
135012	134515	11039M	PARTICIPANT	\N	PRESENT	0
135013	134515	14061L	PARTICIPANT	\N	PRESENT	0
135014	134515	04059M	PARTICIPANT	\N	PRESENT	0
135015	134515	04077P	PARTICIPANT	\N	PRESENT	0
135016	134515	08061X	PARTICIPANT	\N	PRESENT	0
135017	134515	01028R	PARTICIPANT	\N	PRESENT	0
135018	134515	04045F	PARTICIPANT	\N	PRESENT	0
135019	134515	11104D	PARTICIPANT	\N	PRESENT	0
135020	134515	08052W	PARTICIPANT	\N	PRESENT	0
135021	134515	11032E	PARTICIPANT	\N	PRESENT	0
135022	134515	08024S	PARTICIPANT	\N	PRESENT	0
135023	134515	11066Q	PARTICIPANT	\N	PRESENT	0
135024	134515	11106F	PARTICIPANT	\N	PRESENT	0
135025	134515	05008E	PARTICIPANT	\N	PRESENT	0
135026	134515	14081Q	PARTICIPANT	\N	PRESENT	0
135027	134515	11042G	PARTICIPANT	\N	PRESENT	0
135028	134515	04095R	PARTICIPANT	\N	PRESENT	0
135029	134515	14269B	PARTICIPANT	\N	PRESENT	0
135030	134515	01014K	PARTICIPANT	\N	PRESENT	0
135031	134515	12042Y	PARTICIPANT	\N	PRESENT	0
135032	134515	11037K	PARTICIPANT	\N	PRESENT	0
135033	134515	11109J	PARTICIPANT	\N	PRESENT	0
135034	134515	14159V	PARTICIPANT	\N	PRESENT	0
135035	134515	11061K	PARTICIPANT	\N	PRESENT	0
135036	134515	14271U	PARTICIPANT	\N	PRESENT	0
135037	134515	11112D	PARTICIPANT	\N	PRESENT	0
135038	134515	14030Q	PARTICIPANT	\N	PRESENT	0
135039	134515	01034P	PARTICIPANT	\N	PRESENT	0
135040	134515	11064N	PARTICIPANT	\N	PRESENT	0
135041	134515	04080J	PARTICIPANT	\N	PRESENT	0
135042	134515	14034U	PARTICIPANT	\N	PRESENT	0
135043	134515	04079R	PARTICIPANT	\N	PRESENT	0
135044	134515	96004D	PARTICIPANT	\N	PRESENT	0
135045	134515	14205J	PARTICIPANT	\N	PRESENT	0
135046	134515	11070L	PARTICIPANT	\N	PRESENT	0
135047	134515	14087W	PARTICIPANT	\N	PRESENT	0
135048	134515	14042U	PARTICIPANT	\N	PRESENT	0
135049	134515	14219Q	PARTICIPANT	\N	PRESENT	0
135050	134515	14267Y	PARTICIPANT	\N	PRESENT	0
135051	134515	14103D	PARTICIPANT	\N	PRESENT	0
135052	134515	11085T	PARTICIPANT	\N	PRESENT	0
135053	134515	98022P	PARTICIPANT	\N	PRESENT	0
135054	134515	14221J	PARTICIPANT	\N	PRESENT	0
135055	134515	04070G	PARTICIPANT	\N	PRESENT	0
135056	134515	01007L	PARTICIPANT	\N	PRESENT	0
135057	134515	14327T	PARTICIPANT	\N	PRESENT	0
135058	134515	01025N	PARTICIPANT	\N	PRESENT	0
135059	134515	09001P	PARTICIPANT	\N	PRESENT	0
135060	134515	04089T	PARTICIPANT	\N	PRESENT	0
135061	134515	11093T	PARTICIPANT	\N	PRESENT	0
135062	134515	14231L	PARTICIPANT	\N	PRESENT	0
135063	134515	14089Y	PARTICIPANT	\N	PRESENT	0
135064	134515	11082Q	PARTICIPANT	\N	PRESENT	0
135065	134515	14275Y	PARTICIPANT	\N	PRESENT	0
135066	134515	14073Q	PARTICIPANT	\N	PRESENT	0
135067	134515	14277B	PARTICIPANT	\N	PRESENT	0
135068	134515	04097T	PARTICIPANT	\N	PRESENT	0
135069	134515	14247U	PARTICIPANT	\N	PRESENT	0
135070	134515	04053F	PARTICIPANT	\N	PRESENT	0
135071	134515	99002P	PARTICIPANT	\N	PRESENT	0
135072	134515	08051V	PARTICIPANT	\N	PRESENT	0
135073	134515	11068S	PARTICIPANT	\N	PRESENT	0
135074	134515	11044J	PARTICIPANT	\N	PRESENT	0
135075	134515	08056B	PARTICIPANT	\N	PRESENT	0
164865	164852	14038Y	PARTICIPANT	\N	PRESENT	0
164866	164852	14013P	PARTICIPANT	\N	PRESENT	0
164867	164852	14363X	PARTICIPANT	\N	PRESENT	0
164872	164852	80027E	PARTICIPANT	\N	PRESENT	0
164873	164852	11090Q	PARTICIPANT	\N	PRESENT	0
164874	164852	11049P	PARTICIPANT	\N	PRESENT	0
164876	164875	04047H	PARTICIPANT	\N	PRESENT	0
164877	164875	14267Y	PARTICIPANT	\N	PRESENT	0
164878	164875	11084S	PARTICIPANT	\N	PRESENT	0
164879	164875	11026G	PARTICIPANT	\N	PRESENT	0
164880	164875	11012A	PARTICIPANT	\N	PRESENT	0
164881	164852	14187A	PARTICIPANT	\N	PRESENT	0
164882	164852	14001X	PARTICIPANT	\N	PRESENT	0
164883	164852	08041T	PARTICIPANT	\N	PRESENT	0
164884	164852	13002U	PARTICIPANT	\N	PRESENT	0
164885	164852	14217N	PARTICIPANT	\N	PRESENT	0
164892	164852	11025F	PARTICIPANT	\N	PRESENT	0
164933	164852	07026Q	PARTICIPANT	\N	PRESENT	0
164934	164852	80013X	PARTICIPANT	\N	PRESENT	0
164936	164852	14257W	PARTICIPANT	\N	PRESENT	0
164938	164852	11112D	PARTICIPANT	\N	PRESENT	0
164939	164852	04081K	PARTICIPANT	\N	PRESENT	0
164940	164852	08058D	PARTICIPANT	\N	PRESENT	0
164941	164852	01058X	PARTICIPANT	\N	PRESENT	0
164942	164852	11039M	PARTICIPANT	\N	PRESENT	0
164943	164852	01008M	PARTICIPANT	\N	PRESENT	0
164945	164944	05008E	PRESIDENT	0	PRESENT	0
164946	164944	11033F	PARTICIPANT	\N	PRESENT	0
164947	164944	04047H	PARTICIPANT	\N	PRESENT	0
164948	164944	14041T	PARTICIPANT	\N	PRESENT	0
164949	164944	01024M	PARTICIPANT	\N	PRESENT	0
164950	164944	01007L	PARTICIPANT	\N	PRESENT	0
164951	164944	11049P	PARTICIPANT	\N	PRESENT	0
164952	164944	08044W	PARTICIPANT	\N	EXCUSE	0
164953	164944	07034Q	PARTICIPANT	\N	PRESENT	0
164954	164944	01028R	PARTICIPANT	\N	PRESENT	0
164955	164944	04056J	PARTICIPANT	\N	PRESENT	0
164956	164944	04044E	PARTICIPANT	\N	PRESENT	0
164957	164944	92045V	PARTICIPANT	\N	PRESENT	0
164958	164944	95067Q	PARTICIPANT	\N	PRESENT	0
164959	164852	08009T	PARTICIPANT	\N	PRESENT	0
164960	164852	11111C	PARTICIPANT	\N	PRESENT	0
164975	164974	14087W	PARTICIPANT	\N	PRESENT	0
164976	164852	02002K	PARTICIPANT	\N	PRESENT	0
164977	164852	14207L	PARTICIPANT	\N	PRESENT	0
164993	164992	14087W	PARTICIPANT	\N	PRESENT	0
164998	164997	14087W	PARTICIPANT	\N	PRESENT	0
164999	164852	14237S	PARTICIPANT	\N	PRESENT	0
165018	164853	99004R	PARTICIPANT	\N	PRESENT	0
165019	164853	11042G	PARTICIPANT	\N	PRESENT	0
165020	164853	14265W	PARTICIPANT	\N	PRESENT	0
165021	164853	08016S	PARTICIPANT	\N	PRESENT	0
165016	164853	86034E	PARTICIPANT	\N	PRESENT	0
165017	164853	14107H	PARTICIPANT	\N	PRESENT	0
165022	164853	11039M	PARTICIPANT	\N	PRESENT	0
165023	164853	08052W	PARTICIPANT	\N	PRESENT	0
165024	164853	95062K	PARTICIPANT	\N	PRESENT	0
165025	164853	11035H	PARTICIPANT	\N	PRESENT	0
165026	164853	04059M	PARTICIPANT	\N	PRESENT	0
165027	164853	14063N	PARTICIPANT	\N	PRESENT	0
165028	164853	92039X	PARTICIPANT	\N	PRESENT	0
165029	164853	08060W	PARTICIPANT	\N	PRESENT	0
165030	164853	98029W	PARTICIPANT	\N	PRESENT	0
165031	164853	14051J	PARTICIPANT	\N	PRESENT	0
165032	164853	14227Q	PARTICIPANT	\N	PRESENT	0
165033	164853	01059Y	PARTICIPANT	\N	PRESENT	0
165034	164853	04050C	PARTICIPANT	\N	PRESENT	0
165035	164853	01015L	PARTICIPANT	\N	PRESENT	0
165036	164853	11067R	PARTICIPANT	\N	PRESENT	0
165037	164853	11053K	PARTICIPANT	\N	PRESENT	0
165038	164853	14281W	PARTICIPANT	\N	PRESENT	0
165039	164853	11093T	PARTICIPANT	\N	PRESENT	0
165040	164853	14030Q	PARTICIPANT	\N	PRESENT	0
165041	164853	14121F	PARTICIPANT	\N	PRESENT	0
165042	164853	11036J	PARTICIPANT	\N	PRESENT	0
165081	164854	11012A	PARTICIPANT	\N	PRESENT	0
165082	164854	14030Q	PARTICIPANT	\N	PRESENT	0
165083	164854	14073Q	PARTICIPANT	\N	PRESENT	0
165084	164854	14231L	PARTICIPANT	\N	PRESENT	0
165085	164854	01024M	PARTICIPANT	\N	PRESENT	0
165086	164854	04050C	PARTICIPANT	\N	PRESENT	0
165087	164854	80027E	PARTICIPANT	\N	PRESENT	0
165088	164854	14227Q	PARTICIPANT	\N	PRESENT	0
165089	164854	11061K	PARTICIPANT	\N	PRESENT	0
165090	164854	14281W	PARTICIPANT	\N	PRESENT	0
165091	164854	14167V	PARTICIPANT	\N	PRESENT	0
165092	164854	01015L	PARTICIPANT	\N	PRESENT	0
165093	164854	80013X	PARTICIPANT	\N	PRESENT	0
165094	164854	14107H	PARTICIPANT	\N	PRESENT	0
165095	164854	08053X	PARTICIPANT	\N	PRESENT	0
165096	164854	08068F	PARTICIPANT	\N	PRESENT	0
165097	164854	11066Q	PARTICIPANT	\N	PRESENT	0
165098	164854	14121F	PARTICIPANT	\N	PRESENT	0
165099	164854	14051J	PARTICIPANT	\N	PRESENT	0
165100	164854	01014K	PARTICIPANT	\N	PRESENT	0
165101	164854	11025F	PARTICIPANT	\N	PRESENT	0
165102	164854	13002U	PARTICIPANT	\N	PRESENT	0
165103	164854	14081Q	PARTICIPANT	\N	PRESENT	0
165104	164854	11100Y	PARTICIPANT	\N	PRESENT	0
165105	164854	14267Y	PARTICIPANT	\N	PRESENT	0
165106	164854	14147R	PARTICIPANT	\N	PRESENT	0
165107	164854	14105F	PARTICIPANT	\N	PRESENT	0
165079	164854	01007L	PARTICIPANT	\N	PRESENT	0
165080	164854	98050T	PARTICIPANT	\N	PRESENT	0
165108	164854	14119M	PARTICIPANT	\N	PRESENT	0
165109	164854	14175V	PARTICIPANT	\N	PRESENT	0
165111	164854	04057K	PARTICIPANT	\N	PRESENT	0
165112	164854	04049K	PARTICIPANT	\N	PRESENT	0
165113	164854	14061L	PARTICIPANT	\N	PRESENT	0
165114	164854	14059S	PARTICIPANT	\N	PRESENT	0
165115	164854	14211G	PARTICIPANT	\N	PRESENT	0
165116	164854	11090Q	PARTICIPANT	\N	PRESENT	0
165117	164854	14187A	PARTICIPANT	\N	PRESENT	0
165118	164854	05012A	PARTICIPANT	\N	PRESENT	0
165119	164854	14157T	PARTICIPANT	\N	PRESENT	0
165120	164854	11011M	PARTICIPANT	\N	PRESENT	0
165121	164854	14357A	PARTICIPANT	\N	PRESENT	0
165122	164854	95062K	PARTICIPANT	\N	PRESENT	0
165123	164854	14013P	PARTICIPANT	\N	PRESENT	0
165124	164854	11098Y	PARTICIPANT	\N	PRESENT	0
165126	165125	04070G	PARTICIPANT	\N	PRESENT	0
165127	164854	14257W	PARTICIPANT	\N	PRESENT	0
165128	164854	01043Q	PARTICIPANT	\N	PRESENT	0
165132	164854	08062Y	PARTICIPANT	\N	PRESENT	0
165133	164854	04088S	PARTICIPANT	\N	PRESENT	0
165134	164854	95030B	PARTICIPANT	\N	PRESENT	0
165135	164854	14205J	PARTICIPANT	\N	PRESENT	0
165136	164854	01058X	PARTICIPANT	\N	PRESENT	0
165137	164854	01027Q	PARTICIPANT	\N	PRESENT	0
165138	164854	14201E	PARTICIPANT	\N	PRESENT	0
165139	164854	11081P	PARTICIPANT	\N	PRESENT	0
165140	164854	14133K	PARTICIPANT	\N	PRESENT	0
165141	164854	08047A	PARTICIPANT	\N	PRESENT	0
165142	164854	14026U	PARTICIPANT	\N	PRESENT	0
165151	164854	14159V	PARTICIPANT	\N	PRESENT	0
165152	164854	14014Q	PARTICIPANT	\N	PRESENT	0
165153	164854	14363X	PARTICIPANT	\N	PRESENT	0
165154	164854	11042G	PARTICIPANT	\N	PRESENT	0
165155	164854	14087W	PARTICIPANT	\N	PRESENT	0
165156	164854	01013J	PARTICIPANT	\N	PRESENT	0
165157	164854	11104D	PARTICIPANT	\N	PRESENT	0
165158	164854	14247U	PARTICIPANT	\N	PRESENT	0
165159	164854	92039X	PARTICIPANT	\N	PRESENT	0
165160	164854	08031R	PARTICIPANT	\N	PRESENT	0
165161	164854	08051V	PARTICIPANT	\N	PRESENT	0
165163	165162	14087W	PARTICIPANT	\N	PRESENT	0
165165	165164	14087W	PARTICIPANT	\N	PRESENT	0
165167	165166	14087W	PARTICIPANT	\N	PRESENT	0
165169	165168	14087W	PARTICIPANT	\N	PRESENT	0
165170	164854	11057P	PARTICIPANT	\N	PRESENT	0
165172	164854	14195A	PARTICIPANT	\N	PRESENT	0
165173	164854	11049P	PARTICIPANT	\N	PRESENT	0
165174	164854	14097Y	PARTICIPANT	\N	PRESENT	0
165175	164854	14207L	PARTICIPANT	\N	PRESENT	0
165176	164854	14197C	PARTICIPANT	\N	PRESENT	0
165192	164854	04089T	PARTICIPANT	\N	PRESENT	0
165193	164854	08041T	PARTICIPANT	\N	PRESENT	0
165194	164854	14265W	PARTICIPANT	\N	PRESENT	0
165195	164854	14071N	PARTICIPANT	\N	PRESENT	0
165196	164854	14223L	PARTICIPANT	\N	PRESENT	0
165212	164854	14041T	PARTICIPANT	\N	PRESENT	0
165213	164854	14217N	PARTICIPANT	\N	PRESENT	0
165214	164854	11103C	PARTICIPANT	\N	PRESENT	0
165215	164854	08010L	PARTICIPANT	\N	PRESENT	0
165216	164854	08028W	PARTICIPANT	\N	PRESENT	0
165217	164854	08015R	PARTICIPANT	\N	PRESENT	0
165218	164854	88008L	PARTICIPANT	\N	PRESENT	0
128390	127240	11032E	PARTICIPANT	\N	PRESENT	0
128391	127240	14219Q	PARTICIPANT	\N	PRESENT	0
128392	127240	14257W	PARTICIPANT	\N	PRESENT	0
128393	127240	04071H	PARTICIPANT	\N	PRESENT	0
128394	127240	14251Q	PARTICIPANT	\N	PRESENT	0
128395	127240	92015P	PARTICIPANT	\N	PRESENT	0
128396	127240	92039X	PARTICIPANT	\N	PRESENT	0
128397	127240	99002P	PARTICIPANT	\N	PRESENT	0
128398	127240	83042R	PARTICIPANT	\N	PRESENT	0
128399	127240	14167V	PARTICIPANT	\N	PRESENT	0
128400	127240	11014C	PARTICIPANT	\N	PRESENT	0
128401	127240	11059R	PARTICIPANT	\N	PRESENT	0
128402	127240	11105E	PARTICIPANT	\N	PRESENT	0
128403	127240	04077P	PARTICIPANT	\N	PRESENT	0
128404	127240	11099A	PARTICIPANT	\N	PRESENT	0
128405	127240	11113E	PARTICIPANT	\N	PRESENT	0
128406	127240	08012N	PARTICIPANT	\N	PRESENT	0
128407	127240	14103D	PARTICIPANT	\N	PRESENT	0
128408	127240	14267Y	PARTICIPANT	\N	PRESENT	0
128409	127240	04089T	PARTICIPANT	\N	PRESENT	0
128410	127240	08024S	PARTICIPANT	\N	PRESENT	0
128411	127240	97011G	PARTICIPANT	\N	PRESENT	0
128412	127240	11111C	PARTICIPANT	\N	PRESENT	0
128413	127240	14201E	PARTICIPANT	\N	PRESENT	0
128414	127240	14327T	PARTICIPANT	\N	PRESENT	0
128415	127240	01008M	PARTICIPANT	\N	PRESENT	0
128416	127240	95035G	PARTICIPANT	\N	PRESENT	0
128419	127241	02002K	PARTICIPANT	\N	PRESENT	0
128420	127241	01027Q	PARTICIPANT	\N	PRESENT	0
128421	127241	95062K	PARTICIPANT	\N	PRESENT	0
128422	127241	96004D	PARTICIPANT	\N	PRESENT	0
128423	127241	99004R	PARTICIPANT	\N	PRESENT	0
128424	127241	04044E	PARTICIPANT	\N	PRESENT	0
128425	127241	04041B	PARTICIPANT	\N	PRESENT	0
128426	127241	14223L	PARTICIPANT	\N	PRESENT	0
128427	127241	07034Q	PARTICIPANT	\N	PRESENT	0
128428	127241	95030B	PARTICIPANT	\N	PRESENT	0
128429	127241	14087W	PARTICIPANT	\N	PRESENT	0
128430	127241	04092N	PARTICIPANT	\N	PRESENT	0
128431	127241	14169X	PARTICIPANT	\N	PRESENT	0
128432	127241	08010L	PARTICIPANT	\N	PRESENT	0
128433	127241	01061S	PARTICIPANT	\N	PRESENT	0
128388	127240	14207L	PARTICIPANT	\N	PRESENT	0
128389	127240	08068F	PARTICIPANT	\N	PRESENT	0
128434	127241	11049P	PARTICIPANT	\N	PRESENT	0
128435	127241	98005N	PARTICIPANT	\N	PRESENT	0
128436	127241	89029V	PARTICIPANT	\N	PRESENT	0
128437	127241	07029T	PARTICIPANT	\N	PRESENT	0
128438	127241	14227Q	PARTICIPANT	\N	PRESENT	0
128439	127241	11054L	PARTICIPANT	\N	PRESENT	0
128440	127241	11095V	PARTICIPANT	\N	PRESENT	0
128441	127241	14063N	PARTICIPANT	\N	PRESENT	0
128442	127241	14085U	PARTICIPANT	\N	PRESENT	0
128443	127241	04066L	PARTICIPANT	\N	PRESENT	0
128444	127241	92020L	PARTICIPANT	\N	PRESENT	0
128445	127241	08034U	PARTICIPANT	\N	PRESENT	0
128446	127241	11035H	PARTICIPANT	\N	PRESENT	0
128447	127241	11104D	PARTICIPANT	\N	PRESENT	0
128448	127241	11100Y	PARTICIPANT	\N	PRESENT	0
128449	127241	11037K	PARTICIPANT	\N	PRESENT	0
128450	127241	14059S	PARTICIPANT	\N	PRESENT	0
128451	127241	08021P	PARTICIPANT	\N	PRESENT	0
128452	127241	98022P	PARTICIPANT	\N	PRESENT	0
128453	127241	08031R	PARTICIPANT	\N	PRESENT	0
128454	127241	14018U	PARTICIPANT	\N	PRESENT	0
128455	127241	14269B	PARTICIPANT	\N	PRESENT	0
128456	127241	04095R	PARTICIPANT	\N	PRESENT	0
128457	127241	04054G	PARTICIPANT	\N	PRESENT	0
128458	127241	87003B	PARTICIPANT	\N	PRESENT	0
128459	127241	14121F	PARTICIPANT	\N	PRESENT	0
128460	127241	14061L	PARTICIPANT	\N	PRESENT	0
128461	127241	14093U	PARTICIPANT	\N	PRESENT	0
128462	127241	14159V	PARTICIPANT	\N	PRESENT	0
128463	127241	11107G	PARTICIPANT	\N	PRESENT	0
128464	127241	10015M	PARTICIPANT	\N	PRESENT	0
128465	127241	14331P	PARTICIPANT	\N	PRESENT	0
128466	127241	14107H	PARTICIPANT	\N	PRESENT	0
128467	127241	14239U	PARTICIPANT	\N	PRESENT	0
128468	127241	08019V	PARTICIPANT	\N	PRESENT	0
128469	127241	14105F	PARTICIPANT	\N	PRESENT	0
128470	127241	14329V	PARTICIPANT	\N	PRESENT	0
128471	127241	04097T	PARTICIPANT	\N	PRESENT	0
128472	127241	98035U	PARTICIPANT	\N	PRESENT	0
128473	127241	11098Y	PARTICIPANT	\N	PRESENT	0
128474	127241	08048B	PARTICIPANT	\N	PRESENT	0
128475	127241	13002U	PARTICIPANT	\N	PRESENT	0
128476	127241	08041T	PARTICIPANT	\N	PRESENT	0
128477	127241	77002U	PARTICIPANT	\N	PRESENT	0
128478	127241	08016S	PARTICIPANT	\N	PRESENT	0
128479	127241	05004A	PARTICIPANT	\N	PRESENT	0
128480	127241	08014Q	PARTICIPANT	\N	PRESENT	0
128481	127241	08028W	PARTICIPANT	\N	PRESENT	0
128482	127241	04056J	PARTICIPANT	\N	PRESENT	0
128483	127241	04047H	PARTICIPANT	\N	PRESENT	0
128484	127241	11039M	PARTICIPANT	\N	PRESENT	0
128485	127241	14265W	PARTICIPANT	\N	PRESENT	0
128486	127241	01056V	PARTICIPANT	\N	PRESENT	0
128487	127241	14039A	PARTICIPANT	\N	PRESENT	0
128488	127241	08073C	PARTICIPANT	\N	PRESENT	0
128489	127241	04086Q	PARTICIPANT	\N	PRESENT	0
128490	127241	11109J	PARTICIPANT	\N	PRESENT	0
128491	127241	11088W	PARTICIPANT	\N	PRESENT	0
128492	127241	08051V	PARTICIPANT	\N	PRESENT	0
128493	127241	01059Y	PARTICIPANT	\N	PRESENT	0
128494	127241	14235Q	PARTICIPANT	\N	PRESENT	0
128495	127241	11034G	PARTICIPANT	\N	PRESENT	0
128496	127241	11101A	PARTICIPANT	\N	PRESENT	0
128497	127241	11063M	PARTICIPANT	\N	PRESENT	0
128498	127241	14026U	PARTICIPANT	\N	PRESENT	0
128499	127241	14028W	PARTICIPANT	\N	PRESENT	0
128500	127241	80013X	PARTICIPANT	\N	PRESENT	0
128501	127241	07024N	PARTICIPANT	\N	PRESENT	0
128502	127241	08055A	PARTICIPANT	\N	PRESENT	0
128503	127241	14001X	PARTICIPANT	\N	PRESENT	0
128504	127241	11080N	PARTICIPANT	\N	PRESENT	0
128505	127241	10006L	PARTICIPANT	\N	PRESENT	0
128506	127241	86044G	PARTICIPANT	\N	PRESENT	0
128507	127241	08022Q	PARTICIPANT	\N	PRESENT	0
128508	127241	11106F	PARTICIPANT	\N	PRESENT	0
128509	127241	95015C	PARTICIPANT	\N	PRESENT	0
128510	127241	08053X	PARTICIPANT	\N	PRESENT	0
128511	127241	01013J	PARTICIPANT	\N	PRESENT	0
128512	127241	14069U	PARTICIPANT	\N	PRESENT	0
128513	127241	04036E	PARTICIPANT	\N	PRESENT	0
128514	127241	14013P	PARTICIPANT	\N	PRESENT	0
128515	127241	14051J	PARTICIPANT	\N	PRESENT	0
128516	127241	92018S	PARTICIPANT	\N	PRESENT	0
128517	127241	11015D	PARTICIPANT	\N	PRESENT	0
128518	127241	04057K	PARTICIPANT	\N	PRESENT	0
128519	127241	04050C	PARTICIPANT	\N	PRESENT	0
128520	127241	11097X	PARTICIPANT	\N	PRESENT	0
128521	127241	08058D	PARTICIPANT	\N	PRESENT	0
128522	127241	08042U	PARTICIPANT	\N	PRESENT	0
128523	127241	11089X	PARTICIPANT	\N	PRESENT	0
128524	127241	14237S	PARTICIPANT	\N	PRESENT	0
128525	127241	04085P	PARTICIPANT	\N	PRESENT	0
128526	127241	92031P	PARTICIPANT	\N	PRESENT	0
128527	127241	11057P	PARTICIPANT	\N	PRESENT	0
128528	127241	11090Q	PARTICIPANT	\N	PRESENT	0
128529	127241	98024R	PARTICIPANT	\N	PRESENT	0
128530	127241	95031C	PARTICIPANT	\N	PRESENT	0
128531	127241	08018U	PARTICIPANT	\N	PRESENT	0
128532	127241	04033B	PARTICIPANT	\N	PRESENT	0
128533	127241	90003B	PARTICIPANT	\N	PRESENT	0
128534	127241	98050T	PARTICIPANT	\N	PRESENT	0
128535	127241	95059Q	PARTICIPANT	\N	PRESENT	0
128536	127241	14147R	PARTICIPANT	\N	PRESENT	0
128537	127241	14215L	PARTICIPANT	\N	PRESENT	0
128538	127241	04043D	PARTICIPANT	\N	PRESENT	0
128539	127241	14071N	PARTICIPANT	\N	PRESENT	0
128540	127241	11056N	PARTICIPANT	\N	PRESENT	0
128541	127241	14259Y	PARTICIPANT	\N	PRESENT	0
128542	127241	92045V	PARTICIPANT	\N	PRESENT	0
128543	127241	08052W	PARTICIPANT	\N	PRESENT	0
128544	127241	11011M	PARTICIPANT	\N	PRESENT	0
128545	127241	14014Q	PARTICIPANT	\N	PRESENT	0
128546	127241	08043V	PARTICIPANT	\N	PRESENT	0
128547	127241	14038Y	PARTICIPANT	\N	PRESENT	0
128548	127241	14065Q	PARTICIPANT	\N	PRESENT	0
128549	127241	14119M	PARTICIPANT	\N	PRESENT	0
128550	127241	11046L	PARTICIPANT	\N	PRESENT	0
128551	127241	14157T	PARTICIPANT	\N	PRESENT	0
128552	127241	14109K	PARTICIPANT	\N	PRESENT	0
128553	127241	04074L	PARTICIPANT	\N	PRESENT	0
128554	127241	11030C	PARTICIPANT	\N	PRESENT	0
128555	127241	11061K	PARTICIPANT	\N	PRESENT	0
128556	127241	11112D	PARTICIPANT	\N	PRESENT	0
128557	127241	14031R	PARTICIPANT	\N	PRESENT	0
140812	140492	11085T	PARTICIPANT	\N	PRESENT	0
140813	140492	04092N	PARTICIPANT	\N	PRESENT	0
140814	140492	01034P	PARTICIPANT	\N	PRESENT	0
140815	140492	01059Y	PARTICIPANT	\N	PRESENT	0
140816	140492	11031D	PARTICIPANT	\N	PRESENT	0
140817	140492	11063M	PARTICIPANT	\N	PRESENT	0
140818	140492	08052W	PARTICIPANT	\N	PRESENT	0
140819	140492	11055M	PARTICIPANT	\N	PRESENT	0
140820	140492	01046T	PARTICIPANT	\N	PRESENT	0
140821	140492	08019V	PARTICIPANT	\N	PRESENT	0
140822	140492	14041T	PARTICIPANT	\N	PRESENT	0
140823	140492	11093T	PARTICIPANT	\N	PRESENT	0
140824	140492	11103C	PARTICIPANT	\N	PRESENT	0
140825	140492	11097X	PARTICIPANT	\N	PRESENT	0
140826	140492	04043D	PARTICIPANT	\N	PRESENT	0
140827	140492	14269B	PARTICIPANT	\N	PRESENT	0
140828	140492	08034U	PARTICIPANT	\N	PRESENT	0
140829	140492	01041N	PARTICIPANT	\N	PRESENT	0
140830	140492	14231L	PARTICIPANT	\N	PRESENT	0
140839	140492	14217N	PARTICIPANT	\N	PRESENT	0
140851	140492	10006L	PARTICIPANT	\N	PRESENT	0
140858	140492	11061K	PARTICIPANT	\N	PRESENT	0
140859	140492	14121F	PARTICIPANT	\N	PRESENT	0
140870	140492	98018T	PARTICIPANT	\N	PRESENT	0
140876	140492	99004R	PARTICIPANT	\N	PRESENT	0
140883	140492	11114F	PARTICIPANT	\N	PRESENT	0
140884	140492	04067M	PARTICIPANT	\N	PRESENT	0
140912	140494	04086Q	PARTICIPANT	\N	PRESENT	0
140916	140494	11103C	PARTICIPANT	\N	PRESENT	0
140914	140494	01034P	PARTICIPANT	\N	PRESENT	0
140915	140494	04092N	PARTICIPANT	\N	PRESENT	0
140917	140494	01046T	PARTICIPANT	\N	PRESENT	0
140918	140494	11097X	PARTICIPANT	\N	PRESENT	0
140919	140494	04067M	PARTICIPANT	\N	PRESENT	0
140920	140494	11031D	PARTICIPANT	\N	PRESENT	0
140921	140494	11063M	PARTICIPANT	\N	PRESENT	0
140922	140494	11093T	PARTICIPANT	\N	PRESENT	0
140923	140494	14269B	PARTICIPANT	\N	PRESENT	0
140924	140494	10006L	PARTICIPANT	\N	PRESENT	0
140925	140494	08019V	PARTICIPANT	\N	PRESENT	0
140926	140494	04053F	PARTICIPANT	\N	PRESENT	0
140927	140494	98018T	PARTICIPANT	\N	PRESENT	0
140928	140494	14217N	PARTICIPANT	\N	PRESENT	0
140935	140494	11044J	PARTICIPANT	\N	PRESENT	0
140936	140494	11061K	PARTICIPANT	\N	PRESENT	0
140937	140494	11089X	PARTICIPANT	\N	PRESENT	0
140938	140494	04043D	PARTICIPANT	\N	PRESENT	0
140941	140494	14169X	PARTICIPANT	\N	PRESENT	0
140906	140494	04066L	PARTICIPANT	\N	PRESENT	0
140907	140494	08052W	PARTICIPANT	\N	PRESENT	0
140945	140494	01047U	PARTICIPANT	\N	PRESENT	0
140949	140494	11083R	PARTICIPANT	\N	PRESENT	0
140956	140494	11080N	PARTICIPANT	\N	PRESENT	0
158796	158273	04081K	PARTICIPANT	\N	EXCUSE	0
158654	158608	14109K	PARTICIPANT	\N	PRESENT	0
158655	158608	04070G	PRESIDENT	1	PRESENT	0
158833	158832	01019Q	PARTICIPANT	\N	PRESENT	0
159232	158075	08024S	PARTICIPANT	\N	PRESENT	0
159234	158075	14031R	PARTICIPANT	\N	PRESENT	0
158659	158608	14235Q	PARTICIPANT	\N	PRESENT	0
159235	158075	14331P	PARTICIPANT	\N	PRESENT	0
159236	158075	14030Q	PARTICIPANT	\N	PRESENT	0
158662	158608	14229S	PARTICIPANT	\N	PRESENT	0
159237	158075	08043V	PARTICIPANT	\N	PRESENT	0
159238	158075	14051J	PARTICIPANT	\N	PRESENT	0
158665	158608	11011M	PARTICIPANT	\N	PRESENT	0
158666	158545	08019V	PARTICIPANT	\N	PRESENT	0
158667	158545	14217N	PARTICIPANT	\N	PRESENT	0
158668	158545	14083S	PARTICIPANT	\N	PRESENT	0
159239	158075	11114F	PARTICIPANT	\N	PRESENT	0
159240	158075	01022K	PARTICIPANT	\N	PRESENT	0
159241	158075	08014Q	PARTICIPANT	\N	PRESENT	0
159242	158075	01015L	PARTICIPANT	\N	PRESENT	0
159243	158075	08009T	PARTICIPANT	\N	PRESENT	0
159244	158075	14157T	PARTICIPANT	\N	PRESENT	0
159245	158075	11077T	PARTICIPANT	\N	PRESENT	0
159246	158075	14235Q	PARTICIPANT	\N	PRESENT	0
159247	158075	11098Y	PARTICIPANT	\N	PRESENT	0
159248	158075	14237S	PARTICIPANT	\N	PRESENT	0
159233	158075	14195A	PARTICIPANT	\N	PRESENT	0
159249	158075	11099A	PARTICIPANT	\N	PRESENT	0
159250	158075	14093U	PARTICIPANT	\N	PRESENT	0
159251	158075	14053L	PARTICIPANT	\N	PRESENT	0
159252	158075	95062K	PARTICIPANT	\N	PRESENT	0
159272	158075	14207L	PARTICIPANT	\N	PRESENT	0
159273	158075	08055A	PARTICIPANT	\N	PRESENT	0
159274	158075	14111D	PARTICIPANT	\N	PRESENT	0
159275	158075	01016M	PARTICIPANT	\N	PRESENT	0
159276	158075	11065P	PARTICIPANT	\N	PRESENT	0
159277	158075	14059S	PARTICIPANT	\N	PRESENT	0
159278	158075	98023Q	PARTICIPANT	\N	PRESENT	0
159279	158075	08015R	PARTICIPANT	\N	PRESENT	0
159280	158075	01008M	PARTICIPANT	\N	PRESENT	0
159281	158075	98021N	PARTICIPANT	\N	PRESENT	0
159282	158075	96004D	PARTICIPANT	\N	PRESENT	0
159283	158075	14231L	PARTICIPANT	\N	PRESENT	0
159284	158075	14018U	PARTICIPANT	\N	PRESENT	0
159285	158075	14205J	PARTICIPANT	\N	PRESENT	0
159286	158075	14033T	PARTICIPANT	\N	PRESENT	0
159287	158075	14265W	PARTICIPANT	\N	PRESENT	0
159288	158075	14213J	PARTICIPANT	\N	PRESENT	0
159289	158075	04088S	PARTICIPANT	\N	PRESENT	0
159290	158075	05008E	PARTICIPANT	\N	PRESENT	0
159292	158075	14197C	PARTICIPANT	\N	PRESENT	0
159293	158075	83047W	PARTICIPANT	\N	PRESENT	0
159294	158075	14147R	PARTICIPANT	\N	PRESENT	0
159295	158075	14135M	PARTICIPANT	\N	PRESENT	0
159296	158075	14105F	PARTICIPANT	\N	PRESENT	0
159297	158075	14257W	PARTICIPANT	\N	PRESENT	0
159312	158075	14037X	PARTICIPANT	\N	PRESENT	0
159313	158075	14083S	PARTICIPANT	\N	PRESENT	0
159314	158075	14179A	PARTICIPANT	\N	PRESENT	0
159332	158075	04047H	PARTICIPANT	\N	PRESENT	0
159517	147272	04049K	PARTICIPANT	\N	PRESENT	0
159518	147272	89017R	PARTICIPANT	\N	PRESENT	0
159519	147272	14061L	PARTICIPANT	\N	PRESENT	0
159533	159532	09001P	PRESIDENT	0	PRESENT	0
159534	159532	11065P	PARTICIPANT	\N	PRESENT	0
159535	159532	14219Q	PARTICIPANT	\N	PRESENT	0
159536	159532	11090Q	PARTICIPANT	\N	PRESENT	0
159539	159532	80013X	PARTICIPANT	\N	PRESENT	0
159540	159532	05012A	PARTICIPANT	\N	PRESENT	0
159541	159532	01056V	PARTICIPANT	\N	PRESENT	0
159553	159552	09001P	PRESIDENT	0	PRESENT	0
159554	159552	11065P	PARTICIPANT	\N	PRESENT	0
159555	159552	14219Q	PARTICIPANT	\N	PRESENT	0
159556	159552	05012A	PARTICIPANT	\N	PRESENT	0
159557	159552	01056V	PARTICIPANT	\N	EXCUSE	0
159558	159552	80013X	PARTICIPANT	\N	PRESENT	0
159559	159532	92045V	PARTICIPANT	\N	PRESENT	0
159652	158052	08068F	PARTICIPANT	\N	PRESENT	0
159653	158052	14097Y	PARTICIPANT	\N	PRESENT	0
159654	158052	11106F	PARTICIPANT	\N	PRESENT	0
159655	158052	98022P	PARTICIPANT	\N	PRESENT	0
159656	158052	14265W	PARTICIPANT	\N	PRESENT	0
159657	158052	14081Q	PARTICIPANT	\N	PRESENT	0
159658	158052	07034Q	PARTICIPANT	\N	PRESENT	0
159659	158052	14215L	PARTICIPANT	\N	PRESENT	0
159660	158052	92044U	PARTICIPANT	\N	PRESENT	0
159661	158052	14085U	PARTICIPANT	\N	PRESENT	0
159662	158052	08052W	PARTICIPANT	\N	PRESENT	0
159663	158052	14014Q	PARTICIPANT	\N	PRESENT	0
159664	158052	14201E	PARTICIPANT	\N	PRESENT	0
159665	158052	08018U	PARTICIPANT	\N	PRESENT	0
159666	158052	11043H	PARTICIPANT	\N	PRESENT	0
159667	158052	01048V	PARTICIPANT	\N	PRESENT	0
159668	158052	87003B	PARTICIPANT	\N	PRESENT	0
159669	158052	11032E	PARTICIPANT	\N	PRESENT	0
159670	158052	11037K	PARTICIPANT	\N	PRESENT	0
159671	158052	14197C	PARTICIPANT	\N	PRESENT	0
159672	158052	11059R	PARTICIPANT	\N	PRESENT	0
159673	158052	95015C	PARTICIPANT	\N	PRESENT	0
159674	158052	11049P	PARTICIPANT	\N	PRESENT	0
159675	158052	14001X	PARTICIPANT	\N	PRESENT	0
159676	158052	14223L	PARTICIPANT	\N	PRESENT	0
159677	158052	95062K	PARTICIPANT	\N	PRESENT	0
159678	158052	07004J	PARTICIPANT	\N	PRESENT	0
159679	158052	08019V	PARTICIPANT	\N	PRESENT	0
159680	158052	04088S	PARTICIPANT	\N	PRESENT	0
159681	158052	08021P	PARTICIPANT	\N	PRESENT	0
159682	158052	08025T	PARTICIPANT	\N	PRESENT	0
159683	158052	11040E	PARTICIPANT	\N	PRESENT	0
159684	158052	08055A	PARTICIPANT	\N	PRESENT	0
159685	158052	11091R	PARTICIPANT	\N	PRESENT	0
130990	130988	08039A	PARTICIPANT	\N	PRESENT	0
130994	130993	98042T	PARTICIPANT	\N	PRESENT	0
130996	130995	98042T	PARTICIPANT	\N	PRESENT	0
131008	131007	98042T	PARTICIPANT	\N	PRESENT	0
135077	134515	04042C	PARTICIPANT	\N	PRESENT	0
135078	134515	04040A	PARTICIPANT	\N	PRESENT	0
135092	134515	14215L	PARTICIPANT	\N	PRESENT	0
135093	134515	92031P	PARTICIPANT	\N	PRESENT	0
135098	134515	01057W	PARTICIPANT	\N	PRESENT	0
135095	134515	04050C	PARTICIPANT	\N	PRESENT	0
135096	134515	04071H	PARTICIPANT	\N	PRESENT	0
135097	134515	11053K	PARTICIPANT	\N	PRESENT	0
135105	134515	11074Q	PARTICIPANT	\N	PRESENT	0
135100	134515	01024M	PARTICIPANT	\N	PRESENT	0
135101	134515	08069G	PARTICIPANT	\N	PRESENT	0
135102	134515	14151M	PARTICIPANT	\N	PRESENT	0
135103	134515	04061F	PARTICIPANT	\N	PRESENT	0
135104	134515	11029K	PARTICIPANT	\N	PRESENT	0
135117	134515	08058D	PARTICIPANT	\N	PRESENT	0
135125	134515	11065P	PARTICIPANT	\N	PRESENT	0
135378	134516	04081K	PARTICIPANT	\N	PRESENT	0
135127	134515	01043Q	PARTICIPANT	\N	PRESENT	0
135379	134516	07034Q	PARTICIPANT	\N	PRESENT	0
135380	134516	04085P	PARTICIPANT	\N	PRESENT	0
135381	134516	14263U	PARTICIPANT	\N	PRESENT	0
135382	134516	01028R	PARTICIPANT	\N	PRESENT	0
135383	134516	92015P	PARTICIPANT	\N	PRESENT	0
135384	134516	08025T	PARTICIPANT	\N	PRESENT	0
135385	134516	01044R	PARTICIPANT	\N	PRESENT	0
135386	134516	11036J	PARTICIPANT	\N	PRESENT	0
135387	134516	14207L	PARTICIPANT	\N	PRESENT	0
135388	134516	11053K	PARTICIPANT	\N	PRESENT	0
135390	134516	07029T	PARTICIPANT	\N	PRESENT	0
135391	134516	11090Q	PARTICIPANT	\N	PRESENT	0
135392	134516	14265W	PARTICIPANT	\N	PRESENT	0
135393	134516	04038G	PARTICIPANT	\N	PRESENT	0
135394	134516	14103D	PARTICIPANT	\N	PRESENT	0
135395	134516	14097Y	PARTICIPANT	\N	PRESENT	0
135396	134516	04049K	PARTICIPANT	\N	PRESENT	0
135397	134516	95030B	PARTICIPANT	\N	PRESENT	0
135398	134516	14033T	PARTICIPANT	\N	PRESENT	0
135399	134516	01015L	PARTICIPANT	\N	PRESENT	0
135400	134516	04043D	PARTICIPANT	\N	PRESENT	0
135401	134516	04034C	PARTICIPANT	\N	PRESENT	0
135402	134516	04057K	PARTICIPANT	\N	PRESENT	0
135403	134516	14135M	PARTICIPANT	\N	PRESENT	0
135404	134516	05012A	PARTICIPANT	\N	PRESENT	0
135405	134516	98050T	PARTICIPANT	\N	PRESENT	0
135409	134516	08034U	PARTICIPANT	\N	PRESENT	0
135407	134516	92045V	PARTICIPANT	\N	PRESENT	0
135408	134516	08019V	PARTICIPANT	\N	PRESENT	0
135410	134516	14249W	PARTICIPANT	\N	PRESENT	0
135411	134516	11083R	PARTICIPANT	\N	PRESENT	0
135412	134516	11042G	PARTICIPANT	\N	PRESENT	0
135413	134516	05008E	PARTICIPANT	\N	PRESENT	0
135414	134516	01048V	PARTICIPANT	\N	PRESENT	0
135415	134516	01031L	PARTICIPANT	\N	PRESENT	0
135416	134516	95035G	PARTICIPANT	\N	PRESENT	0
135427	134516	04036E	PARTICIPANT	\N	PRESENT	0
135428	134516	04067M	PARTICIPANT	\N	PRESENT	0
135433	134516	14073Q	PARTICIPANT	\N	PRESENT	0
135434	134516	08051V	PARTICIPANT	\N	PRESENT	0
135443	134516	08031R	PARTICIPANT	\N	PRESENT	0
135444	134516	14018U	PARTICIPANT	\N	PRESENT	0
135445	134516	14195A	PARTICIPANT	\N	PRESENT	0
135446	134516	14219Q	PARTICIPANT	\N	PRESENT	0
135449	134516	11010L	PARTICIPANT	\N	PRESENT	0
135452	134516	14089Y	PARTICIPANT	\N	PRESENT	0
135453	134516	08011M	PARTICIPANT	\N	PRESENT	0
135459	135458	01024M	PARTICIPANT	\N	PRESENT	0
135455	130411	08051V	PARTICIPANT	\N	PRESENT	0
135457	135456	01024M	PARTICIPANT	\N	PRESENT	0
135461	135460	01024M	PARTICIPANT	\N	PRESENT	0
135462	135460	04056J	PARTICIPANT	\N	PRESENT	0
135463	134517	04066L	PARTICIPANT	\N	PRESENT	0
135464	134517	07034Q	PARTICIPANT	\N	PRESENT	0
135465	134517	05008E	PARTICIPANT	\N	PRESENT	0
135466	134517	04034C	PARTICIPANT	\N	PRESENT	0
135467	134517	04085P	PARTICIPANT	\N	PRESENT	0
135468	134517	11083R	PARTICIPANT	\N	PRESENT	0
135469	134517	14033T	PARTICIPANT	\N	PRESENT	0
135470	134517	08069G	PARTICIPANT	\N	PRESENT	0
135471	134517	92045V	PARTICIPANT	\N	PRESENT	0
135472	134517	14219Q	PARTICIPANT	\N	PRESENT	0
135473	134517	14261S	PARTICIPANT	\N	PRESENT	0
135474	134517	04038G	PARTICIPANT	\N	PRESENT	0
135475	134517	11053K	PARTICIPANT	\N	PRESENT	0
135476	134517	14195A	PARTICIPANT	\N	PRESENT	0
135492	134517	11077T	PARTICIPANT	\N	PRESENT	0
135493	134517	08011M	PARTICIPANT	\N	PRESENT	0
135494	134517	08031R	PARTICIPANT	\N	PRESENT	0
135587	135565	04066L	PARTICIPANT	\N	PRESENT	0
135588	135565	08042U	PARTICIPANT	\N	PRESENT	0
135589	135565	04086Q	PARTICIPANT	\N	PRESENT	0
135590	135565	14221J	PARTICIPANT	\N	PRESENT	0
135591	135565	11054L	PARTICIPANT	\N	PRESENT	0
135592	135565	01015L	PARTICIPANT	\N	PRESENT	0
135593	135565	07026Q	PARTICIPANT	\N	PRESENT	0
135594	135565	04085P	PARTICIPANT	\N	PRESENT	0
135595	135565	11053K	PARTICIPANT	\N	PRESENT	0
135596	135565	04071H	PARTICIPANT	\N	PRESENT	0
135597	135565	08060W	PARTICIPANT	\N	PRESENT	0
135598	135565	99004R	PARTICIPANT	\N	PRESENT	0
135599	135565	14038Y	PARTICIPANT	\N	PRESENT	0
135601	135565	11055M	PARTICIPANT	\N	PRESENT	0
135604	135565	04078Q	PARTICIPANT	\N	PRESENT	0
135605	135565	04067M	PARTICIPANT	\N	PRESENT	0
135606	135565	14269B	PARTICIPANT	\N	PRESENT	0
135607	135565	14107H	PARTICIPANT	\N	PRESENT	0
135608	135565	95030B	PARTICIPANT	\N	PRESENT	0
135609	135565	04080J	PARTICIPANT	\N	PRESENT	0
135610	135565	04053F	PARTICIPANT	\N	PRESENT	0
135611	135565	11031D	PARTICIPANT	\N	PRESENT	0
135612	135565	08019V	PARTICIPANT	\N	PRESENT	0
135627	135565	08016S	PARTICIPANT	\N	PRESENT	0
135628	135565	04043D	PARTICIPANT	\N	PRESENT	0
135629	135565	11080N	PARTICIPANT	\N	PRESENT	0
135630	135565	04044E	PARTICIPANT	\N	PRESENT	0
135631	135565	14065Q	PARTICIPANT	\N	PRESENT	0
135632	135565	14119M	PARTICIPANT	\N	PRESENT	0
135635	135565	11012A	PARTICIPANT	\N	PRESENT	0
135636	135565	14259Y	PARTICIPANT	\N	PRESENT	0
135647	135565	04059M	PARTICIPANT	\N	PRESENT	0
135650	135565	01028R	PARTICIPANT	\N	PRESENT	0
135651	135565	08009T	PARTICIPANT	\N	PRESENT	0
135652	135565	11103C	PARTICIPANT	\N	PRESENT	0
135672	135567	04066L	PARTICIPANT	\N	PRESENT	0
135673	135567	04044E	PARTICIPANT	\N	PRESENT	0
135674	135567	14259Y	PARTICIPANT	\N	PRESENT	0
135675	135567	04079R	PARTICIPANT	\N	PRESENT	0
135676	135567	07026Q	PARTICIPANT	\N	PRESENT	0
135677	135567	01015L	PARTICIPANT	\N	PRESENT	0
135678	135567	11031D	PARTICIPANT	\N	PRESENT	0
135679	135567	11012A	PARTICIPANT	\N	PRESENT	0
135680	135567	04080J	PARTICIPANT	\N	PRESENT	0
135681	135567	11080N	PARTICIPANT	\N	PRESENT	0
135682	135567	04071H	PARTICIPANT	\N	PRESENT	0
135683	135567	11034G	PARTICIPANT	\N	PRESENT	0
135684	135567	11033F	PARTICIPANT	\N	PRESENT	0
135685	135567	12041X	PARTICIPANT	\N	PRESENT	0
135686	135567	04086Q	PARTICIPANT	\N	PRESENT	0
135687	135567	04043D	PARTICIPANT	\N	PRESENT	0
135688	135567	11103C	PARTICIPANT	\N	PRESENT	0
135689	135567	04059M	PARTICIPANT	\N	PRESENT	0
135690	135567	11085T	PARTICIPANT	\N	PRESENT	0
135691	135567	04085P	PARTICIPANT	\N	PRESENT	0
135692	135567	01031L	PARTICIPANT	\N	PRESENT	0
135693	135567	14269B	PARTICIPANT	\N	PRESENT	0
135694	135567	01007L	PARTICIPANT	\N	PRESENT	0
135695	135567	01048V	PARTICIPANT	\N	PRESENT	0
135696	135568	14259Y	PARTICIPANT	\N	PRESENT	0
135697	135568	04044E	PARTICIPANT	\N	PRESENT	0
135698	135568	01007L	PARTICIPANT	\N	PRESENT	0
135699	135568	12041X	PARTICIPANT	\N	PRESENT	0
135700	135568	11034G	PARTICIPANT	\N	PRESENT	0
135701	135568	04079R	PARTICIPANT	\N	PRESENT	0
135702	135568	11012A	PARTICIPANT	\N	PRESENT	0
135703	135568	11033F	PARTICIPANT	\N	PRESENT	0
135704	135568	04086Q	PARTICIPANT	\N	PRESENT	0
135705	135568	01031L	PARTICIPANT	\N	PRESENT	0
135706	135568	04059M	PARTICIPANT	\N	PRESENT	0
135707	135568	07026Q	PARTICIPANT	\N	PRESENT	0
135708	135568	04071H	PARTICIPANT	\N	PRESENT	0
135709	135568	11080N	PARTICIPANT	\N	PRESENT	0
135710	135568	96004D	PARTICIPANT	\N	PRESENT	0
135711	135568	95063L	PARTICIPANT	\N	PRESENT	0
135712	135568	04080J	PARTICIPANT	\N	PRESENT	0
135713	135568	01015L	PARTICIPANT	\N	PRESENT	0
140147	138715	04088S	PARTICIPANT	\N	PRESENT	0
142736	135882	01022K	PARTICIPANT	\N	EXCUSE	0
142737	135882	01027Q	PARTICIPANT	\N	PRESENT	0
142738	135882	11023D	PARTICIPANT	\N	PRESENT	0
142756	135882	14059S	PARTICIPANT	\N	PRESENT	0
142757	135882	08019V	PRESIDENT	0	PRESENT	0
142758	135882	11071M	PARTICIPANT	\N	PRESENT	0
142796	135882	14053L	PARTICIPANT	\N	EXCUSE	0
142812	136163	14053L	PARTICIPANT	\N	EXCUSE	0
142814	136163	01022K	PARTICIPANT	\N	EXCUSE	0
142915	136202	14053L	PARTICIPANT	\N	EXCUSE	0
143625	143624	04042C	PARTICIPANT	\N	PRESENT	0
143626	143624	92031P	PARTICIPANT	\N	PRESENT	0
143627	143624	11105E	PARTICIPANT	\N	PRESENT	0
143628	143624	11076S	PARTICIPANT	\N	PRESENT	0
143629	143624	98022P	PARTICIPANT	\N	PRESENT	0
143630	143624	07004J	PARTICIPANT	\N	PRESENT	0
143632	143624	01056V	PARTICIPANT	\N	PRESENT	0
143633	143624	08058D	PARTICIPANT	\N	PRESENT	0
143634	143624	14028W	PARTICIPANT	\N	PRESENT	0
143672	141034	11037K	PARTICIPANT	\N	PRESENT	0
143673	141034	04044E	PARTICIPANT	\N	EXCUSE	0
143674	141032	14071N	PARTICIPANT	\N	EXCUSE	0
143675	141034	14071N	PARTICIPANT	\N	PRESENT	0
144334	143036	86034E	PARTICIPANT	\N	PRESENT	0
144357	143036	01031L	PARTICIPANT	\N	PRESENT	0
144358	143036	08011M	PARTICIPANT	\N	PRESENT	0
144359	143036	11040E	PARTICIPANT	\N	PRESENT	0
144360	143036	01013J	PARTICIPANT	\N	PRESENT	0
144361	143036	12041X	PARTICIPANT	\N	PRESENT	0
144362	143036	04085P	PARTICIPANT	\N	PRESENT	0
144363	143036	01011G	PARTICIPANT	\N	PRESENT	0
158492	158072	04081K	PARTICIPANT	\N	PRESENT	0
144365	143036	01016M	PARTICIPANT	\N	PRESENT	0
144366	143036	08016S	PARTICIPANT	\N	PRESENT	0
144367	143036	08055A	PARTICIPANT	\N	PRESENT	0
144368	143036	04034C	PARTICIPANT	\N	PRESENT	0
144369	143036	11057P	PARTICIPANT	\N	PRESENT	0
144370	143036	08043V	PARTICIPANT	\N	PRESENT	0
144371	143036	11074Q	PARTICIPANT	\N	PRESENT	0
144372	143036	11042G	PARTICIPANT	\N	PRESENT	0
144373	143036	08014Q	PARTICIPANT	\N	PRESENT	0
144374	143036	11039M	PARTICIPANT	\N	PRESENT	0
144375	143036	14281W	PARTICIPANT	\N	PRESENT	0
144376	143036	08024S	PARTICIPANT	\N	PRESENT	0
144377	143036	11083R	PARTICIPANT	\N	PRESENT	0
144378	143036	14085U	PARTICIPANT	\N	PRESENT	0
144379	143036	14159V	PARTICIPANT	\N	PRESENT	0
144380	143036	07029T	PARTICIPANT	\N	PRESENT	0
144381	143036	08051V	PARTICIPANT	\N	PRESENT	0
144382	143036	11071M	PARTICIPANT	\N	PRESENT	0
144383	143036	11012A	PARTICIPANT	\N	PRESENT	0
144407	143036	04071H	PARTICIPANT	\N	PRESENT	0
144385	143036	08010L	PARTICIPANT	\N	PRESENT	0
144386	143036	14030Q	PARTICIPANT	\N	PRESENT	0
144387	143036	08034U	PARTICIPANT	\N	PRESENT	0
144388	143036	11097X	PARTICIPANT	\N	PRESENT	0
144389	143036	14157T	PARTICIPANT	\N	PRESENT	0
144390	143036	11088W	PARTICIPANT	\N	PRESENT	0
144391	143036	01057W	PARTICIPANT	\N	PRESENT	0
144392	143036	08019V	PARTICIPANT	\N	PRESENT	0
144393	143036	14083S	PARTICIPANT	\N	PRESENT	0
144394	143036	01027Q	PARTICIPANT	\N	PRESENT	0
144395	143036	96004D	PARTICIPANT	\N	PRESENT	0
144396	143036	01048V	PARTICIPANT	\N	PRESENT	0
144397	143036	04086Q	PARTICIPANT	\N	PRESENT	0
144398	143036	14225N	PARTICIPANT	\N	PRESENT	0
144399	143036	04033B	PARTICIPANT	\N	PRESENT	0
144400	143036	04057K	PARTICIPANT	\N	PRESENT	0
144401	143036	95035G	PARTICIPANT	\N	PRESENT	0
144402	143036	04044E	PARTICIPANT	\N	PRESENT	0
144403	143036	14327T	PARTICIPANT	\N	PRESENT	0
144404	143036	14269B	PARTICIPANT	\N	PRESENT	0
144405	143036	11070L	PARTICIPANT	\N	PRESENT	0
144406	143036	98053W	PARTICIPANT	\N	PRESENT	0
144412	143036	11053K	PARTICIPANT	\N	PRESENT	0
144413	143036	11061K	PARTICIPANT	\N	PRESENT	0
144414	143036	11027H	PARTICIPANT	\N	PRESENT	0
144415	143036	04067M	PARTICIPANT	\N	PRESENT	0
144418	143036	08069G	PARTICIPANT	\N	PRESENT	0
144433	143036	08017T	PARTICIPANT	\N	PRESENT	0
144436	143036	90003B	PARTICIPANT	\N	PRESENT	0
144437	143036	04070G	PARTICIPANT	\N	PRESENT	0
144438	143036	99004R	PARTICIPANT	\N	PRESENT	0
144439	143036	14013P	PARTICIPANT	\N	PRESENT	0
144440	143036	01024M	PARTICIPANT	\N	PRESENT	0
144441	143036	11031D	PARTICIPANT	\N	PRESENT	0
144442	143036	98050T	PARTICIPANT	\N	PRESENT	0
144452	143036	01034P	PARTICIPANT	\N	PRESENT	0
144453	143036	14331P	PARTICIPANT	\N	PRESENT	0
144454	143036	14105F	PARTICIPANT	\N	PRESENT	0
144455	143036	11044J	PARTICIPANT	\N	PRESENT	0
144456	143036	11036J	PARTICIPANT	\N	PRESENT	0
144457	143036	08039A	PARTICIPANT	\N	PRESENT	0
144458	143036	01046T	PARTICIPANT	\N	PRESENT	0
144463	143036	14039A	PARTICIPANT	\N	PRESENT	0
144467	143036	11084S	PARTICIPANT	\N	PRESENT	0
144468	143036	95059Q	PARTICIPANT	\N	PRESENT	0
144469	143036	77002U	PARTICIPANT	\N	PRESENT	0
144472	143036	11054L	PARTICIPANT	\N	PRESENT	0
144473	143036	08052W	PARTICIPANT	\N	PRESENT	0
144492	143036	11023D	PARTICIPANT	\N	PRESENT	0
144494	143036	11068S	PARTICIPANT	\N	PRESENT	0
144523	143036	08009T	PARTICIPANT	\N	PRESENT	0
144532	143036	14037X	PARTICIPANT	\N	PRESENT	0
144652	143036	98046X	PARTICIPANT	\N	PRESENT	0
158520	158072	08052W	PARTICIPANT	\N	PRESENT	0
158521	158072	04053F	PARTICIPANT	\N	PRESENT	0
158522	158072	04050C	PARTICIPANT	\N	PRESENT	0
158523	158072	11031D	PARTICIPANT	\N	PRESENT	0
158524	158072	80027E	PARTICIPANT	\N	PRESENT	0
158525	158072	11034G	PARTICIPANT	\N	PRESENT	0
158526	158072	01015L	PARTICIPANT	\N	PRESENT	0
158527	158072	14225N	PARTICIPANT	\N	PRESENT	0
158528	158072	11040E	PARTICIPANT	\N	PRESENT	0
158529	158072	14263U	PARTICIPANT	\N	PRESENT	0
158530	158072	12042Y	PARTICIPANT	\N	PRESENT	0
158531	158072	11066Q	PARTICIPANT	\N	PRESENT	0
158532	158072	14038Y	PARTICIPANT	\N	PRESENT	0
158533	158072	14133K	PARTICIPANT	\N	PRESENT	0
158534	158072	01011G	PARTICIPANT	\N	PRESENT	0
158535	158072	04067M	PARTICIPANT	\N	PRESENT	0
158536	158072	11063M	PARTICIPANT	\N	PRESENT	0
158537	158072	13002U	PARTICIPANT	\N	PRESENT	0
158538	158072	04092N	PARTICIPANT	\N	PRESENT	0
158539	158072	14267Y	PARTICIPANT	\N	PRESENT	0
158540	158072	14042U	PARTICIPANT	\N	PRESENT	0
158541	158072	04085P	PARTICIPANT	\N	PRESENT	0
158542	158072	14034U	PARTICIPANT	\N	PRESENT	0
158543	158072	14147R	PARTICIPANT	\N	PRESENT	0
158544	158072	14119M	PARTICIPANT	\N	PRESENT	0
158555	158072	11105E	PARTICIPANT	\N	PRESENT	0
158568	158072	14269B	PARTICIPANT	\N	PRESENT	0
158572	158072	14159V	PARTICIPANT	\N	PRESENT	0
158577	158072	14037X	PARTICIPANT	\N	PRESENT	0
158578	158072	14223L	PARTICIPANT	\N	PRESENT	0
158580	158072	14281W	PARTICIPANT	\N	PRESENT	0
158583	158072	14195A	PARTICIPANT	\N	PRESENT	0
158584	158072	14207L	PARTICIPANT	\N	PRESENT	0
158588	158072	11097X	PARTICIPANT	\N	PRESENT	0
158591	158072	08015R	PARTICIPANT	\N	PRESENT	0
158594	158072	14199E	PARTICIPANT	\N	PRESENT	0
158596	158072	11061K	PARTICIPANT	\N	PRESENT	0
158599	158072	11067R	PARTICIPANT	\N	PRESENT	0
158602	158072	92018S	PARTICIPANT	\N	PRESENT	0
158603	158072	12041X	PARTICIPANT	\N	PRESENT	0
158604	158072	14235Q	PARTICIPANT	\N	PRESENT	0
158605	158072	14013P	PARTICIPANT	\N	PRESENT	0
158607	158072	14089Y	PARTICIPANT	\N	PRESENT	0
158673	158072	11056N	PARTICIPANT	\N	PRESENT	0
158674	158072	14265W	PARTICIPANT	\N	PRESENT	0
158675	158072	11090Q	PARTICIPANT	\N	PRESENT	0
158676	158072	07026Q	PARTICIPANT	\N	PRESENT	0
158677	158072	14109K	PARTICIPANT	\N	PRESENT	0
158678	158072	11104D	PARTICIPANT	\N	PRESENT	0
158679	158072	14026U	PARTICIPANT	\N	PRESENT	0
158680	158072	04043D	PARTICIPANT	\N	PRESENT	0
158681	158072	08043V	PARTICIPANT	\N	PRESENT	0
158682	158072	14105F	PARTICIPANT	\N	PRESENT	0
158683	158072	01046T	PARTICIPANT	\N	PRESENT	0
158684	158072	14151M	PARTICIPANT	\N	PRESENT	0
158685	158072	04045F	PARTICIPANT	\N	PRESENT	0
158686	158072	14201E	PARTICIPANT	\N	PRESENT	0
158695	158072	01044R	PARTICIPANT	\N	PRESENT	0
158698	158072	01059Y	PARTICIPANT	\N	PRESENT	0
158699	158072	11011M	PARTICIPANT	\N	PRESENT	0
158713	158072	98053W	PARTICIPANT	\N	PRESENT	0
158717	158072	87003B	PARTICIPANT	\N	PRESENT	0
158729	158072	08010L	PARTICIPANT	\N	PRESENT	0
128558	127241	14281W	PARTICIPANT	\N	PRESENT	0
128559	127241	14173T	PARTICIPANT	\N	PRESENT	0
128560	127241	11036J	PARTICIPANT	\N	PRESENT	0
128561	127241	95037J	PARTICIPANT	\N	PRESENT	0
128562	127241	14033T	PARTICIPANT	\N	PRESENT	0
128563	127241	01057W	PARTICIPANT	\N	PRESENT	0
128564	127241	04081K	PARTICIPANT	\N	PRESENT	0
128565	127241	04034C	PARTICIPANT	\N	PRESENT	0
128566	127241	14213J	PARTICIPANT	\N	PRESENT	0
128567	127241	11084S	PARTICIPANT	\N	PRESENT	0
128568	127241	14111D	PARTICIPANT	\N	PRESENT	0
128569	127241	05012A	PARTICIPANT	\N	PRESENT	0
128570	127241	08062Y	PARTICIPANT	\N	PRESENT	0
128571	127241	08025T	PARTICIPANT	\N	PRESENT	0
128572	127241	98021N	PARTICIPANT	\N	PRESENT	0
128573	127241	11077T	PARTICIPANT	\N	PRESENT	0
128574	127241	07032N	PARTICIPANT	\N	PRESENT	0
128575	127241	98029W	PARTICIPANT	\N	PRESENT	0
128576	127241	14249W	PARTICIPANT	\N	PRESENT	0
128577	127241	12042Y	PARTICIPANT	\N	PRESENT	0
128578	127241	04045F	PARTICIPANT	\N	PRESENT	0
128579	127241	11042G	PARTICIPANT	\N	PRESENT	0
128580	127241	14079W	PARTICIPANT	\N	PRESENT	0
128581	127241	11043H	PARTICIPANT	\N	PRESENT	0
128582	127241	08047A	PARTICIPANT	\N	PRESENT	0
128583	127241	04053F	PARTICIPANT	\N	PRESENT	0
128584	127241	11025F	PARTICIPANT	\N	PRESENT	0
128585	127241	01019Q	PARTICIPANT	\N	PRESENT	0
128586	127241	01011G	PARTICIPANT	\N	PRESENT	0
128587	127241	14209N	PARTICIPANT	\N	PRESENT	0
128588	127241	01044R	PARTICIPANT	\N	PRESENT	0
128589	127241	11033F	PARTICIPANT	\N	PRESENT	0
128590	127241	04067M	PARTICIPANT	\N	PRESENT	0
128591	127241	01058X	PARTICIPANT	\N	PRESENT	0
128592	127241	11055M	PARTICIPANT	\N	PRESENT	0
128593	127241	04061F	PARTICIPANT	\N	PRESENT	0
128594	127241	98018T	PARTICIPANT	\N	PRESENT	0
128595	127241	04035D	PARTICIPANT	\N	PRESENT	0
128596	127241	04059M	PARTICIPANT	\N	PRESENT	0
128597	127241	11083R	PARTICIPANT	\N	PRESENT	0
128598	127241	11029K	PARTICIPANT	\N	PRESENT	0
128599	127241	14123H	PARTICIPANT	\N	PRESENT	0
128600	127241	11081P	PARTICIPANT	\N	PRESENT	0
128601	127241	11012A	PARTICIPANT	\N	PRESENT	0
128602	127241	11103C	PARTICIPANT	\N	PRESENT	0
128603	127241	11096W	PARTICIPANT	\N	PRESENT	0
128604	127241	05008E	PARTICIPANT	\N	PRESENT	0
128605	127241	01046T	PARTICIPANT	\N	PRESENT	0
128606	127241	88008L	PARTICIPANT	\N	PRESENT	0
128607	127241	04038G	PARTICIPANT	\N	PRESENT	0
128608	127241	04049K	PARTICIPANT	\N	PRESENT	0
128609	127241	08015R	PARTICIPANT	\N	PRESENT	0
128610	127241	11026G	PARTICIPANT	\N	PRESENT	0
128611	127241	14211G	PARTICIPANT	\N	PRESENT	0
128612	127241	01060R	PARTICIPANT	\N	PRESENT	0
128613	127241	08039A	PARTICIPANT	\N	PRESENT	0
128614	127241	14055N	PARTICIPANT	\N	PRESENT	0
128615	127241	04088S	PARTICIPANT	\N	PRESENT	0
128616	127241	89017R	PARTICIPANT	\N	PRESENT	0
128617	127241	14253S	PARTICIPANT	\N	PRESENT	0
128618	127241	01014K	PARTICIPANT	\N	PRESENT	0
128619	127241	11091R	PARTICIPANT	\N	PRESENT	0
128620	127241	04078Q	PARTICIPANT	\N	PRESENT	0
128621	127241	92040Q	PARTICIPANT	\N	PRESENT	0
128622	127241	08069G	PARTICIPANT	\N	PRESENT	0
128623	127241	14030Q	PARTICIPANT	\N	PRESENT	0
128624	127241	14221J	PARTICIPANT	\N	PRESENT	0
128625	127241	14042U	PARTICIPANT	\N	PRESENT	0
128626	127241	11070L	PARTICIPANT	\N	PRESENT	0
128627	127241	11064N	PARTICIPANT	\N	PRESENT	0
128628	127241	04080J	PARTICIPANT	\N	PRESENT	0
128629	127241	11053K	PARTICIPANT	\N	PRESENT	0
128630	127241	01047U	PARTICIPANT	\N	PRESENT	0
128631	127241	07004J	PARTICIPANT	\N	PRESENT	0
128632	127241	04070G	PARTICIPANT	\N	PRESENT	0
128633	127241	14205J	PARTICIPANT	\N	PRESENT	0
128634	127241	11093T	PARTICIPANT	\N	PRESENT	0
128635	127241	11066Q	PARTICIPANT	\N	PRESENT	0
128636	127241	12041X	PARTICIPANT	\N	PRESENT	0
128637	127241	14083S	PARTICIPANT	\N	PRESENT	0
128638	127241	11082Q	PARTICIPANT	\N	PRESENT	0
128639	127241	14089Y	PARTICIPANT	\N	PRESENT	0
128640	127241	98042T	PARTICIPANT	\N	PRESENT	0
128641	127241	14247U	PARTICIPANT	\N	PRESENT	0
128642	127241	14133K	PARTICIPANT	\N	PRESENT	0
128643	127241	14241N	PARTICIPANT	\N	PRESENT	0
128644	127241	01025N	PARTICIPANT	\N	PRESENT	0
128645	127241	08035V	PARTICIPANT	\N	PRESENT	0
128646	127241	09001P	PARTICIPANT	\N	PRESENT	0
128647	127241	14255U	PARTICIPANT	\N	PRESENT	0
128648	127241	14197C	PARTICIPANT	\N	PRESENT	0
128649	127241	14195A	PARTICIPANT	\N	PRESENT	0
128650	127241	01048V	PARTICIPANT	\N	PRESENT	0
128651	127241	14081Q	PARTICIPANT	\N	PRESENT	0
128652	127241	14193X	PARTICIPANT	\N	PRESENT	0
128653	127241	83047W	PARTICIPANT	\N	PRESENT	0
128654	127241	14187A	PARTICIPANT	\N	PRESENT	0
128655	127241	14231L	PARTICIPANT	\N	PRESENT	0
128656	127241	04055H	PARTICIPANT	\N	PRESENT	0
128657	127241	14199E	PARTICIPANT	\N	PRESENT	0
128658	127241	14034U	PARTICIPANT	\N	PRESENT	0
128659	127241	11048N	PARTICIPANT	\N	PRESENT	0
128660	127241	04042C	PARTICIPANT	\N	PRESENT	0
128661	127241	11110B	PARTICIPANT	\N	PRESENT	0
128662	127241	11027H	PARTICIPANT	\N	PRESENT	0
128663	127241	14073Q	PARTICIPANT	\N	PRESENT	0
128664	127241	14053L	PARTICIPANT	\N	PRESENT	0
128665	127241	14097Y	PARTICIPANT	\N	PRESENT	0
128666	127241	14135M	PARTICIPANT	\N	PRESENT	0
128667	127241	95067Q	PARTICIPANT	\N	PRESENT	0
128668	127241	11085T	PARTICIPANT	\N	PRESENT	0
128669	127241	14207L	PARTICIPANT	\N	PRESENT	0
128670	127241	08068F	PARTICIPANT	\N	PRESENT	0
128671	127241	11032E	PARTICIPANT	\N	PRESENT	0
128672	127241	14219Q	PARTICIPANT	\N	PRESENT	0
128673	127241	14257W	PARTICIPANT	\N	PRESENT	0
128674	127241	04071H	PARTICIPANT	\N	PRESENT	0
128675	127241	14251Q	PARTICIPANT	\N	PRESENT	0
128676	127241	92015P	PARTICIPANT	\N	PRESENT	0
128677	127241	92039X	PARTICIPANT	\N	PRESENT	0
128678	127241	99002P	PARTICIPANT	\N	PRESENT	0
128679	127241	83042R	PARTICIPANT	\N	PRESENT	0
128680	127241	14167V	PARTICIPANT	\N	PRESENT	0
128681	127241	11014C	PARTICIPANT	\N	PRESENT	0
128682	127241	11059R	PARTICIPANT	\N	PRESENT	0
128683	127241	11105E	PARTICIPANT	\N	PRESENT	0
128684	127241	04077P	PARTICIPANT	\N	PRESENT	0
128685	127241	11099A	PARTICIPANT	\N	PRESENT	0
128686	127241	11113E	PARTICIPANT	\N	PRESENT	0
128687	127241	08012N	PARTICIPANT	\N	PRESENT	0
128688	127241	14103D	PARTICIPANT	\N	PRESENT	0
128689	127241	14267Y	PARTICIPANT	\N	PRESENT	0
128690	127241	04089T	PARTICIPANT	\N	PRESENT	0
128691	127241	08024S	PARTICIPANT	\N	PRESENT	0
128692	127241	97011G	PARTICIPANT	\N	PRESENT	0
128693	127241	11111C	PARTICIPANT	\N	PRESENT	0
128694	127241	14201E	PARTICIPANT	\N	PRESENT	0
128695	127241	14327T	PARTICIPANT	\N	PRESENT	0
128696	127241	01008M	PARTICIPANT	\N	PRESENT	0
128697	127241	95035G	PARTICIPANT	\N	PRESENT	0
128698	127241	01022K	PARTICIPANT	\N	PRESENT	0
128699	127193	08055A	PARTICIPANT	\N	PRESENT	0
128700	127193	14263U	PARTICIPANT	\N	PRESENT	0
128701	127193	11063M	PARTICIPANT	\N	PRESENT	0
128702	127193	01022K	PARTICIPANT	\N	PRESENT	0
128703	127193	14197C	PARTICIPANT	\N	PRESENT	0
128704	127193	11036J	PARTICIPANT	\N	PRESENT	0
128705	127193	08058D	PARTICIPANT	\N	PRESENT	0
128706	127193	08053X	PARTICIPANT	\N	PRESENT	0
128707	127193	14121F	PARTICIPANT	\N	PRESENT	0
128708	127193	14107H	PARTICIPANT	\N	PRESENT	0
128709	127193	11105E	PARTICIPANT	\N	PRESENT	0
128710	127193	08012N	PARTICIPANT	\N	PRESENT	0
128711	127193	14097Y	PARTICIPANT	\N	PRESENT	0
128712	127193	14257W	PARTICIPANT	\N	PRESENT	0
128713	127193	14014Q	PARTICIPANT	\N	PRESENT	0
128714	127193	14109K	PARTICIPANT	\N	PRESENT	0
128715	127193	14281W	PARTICIPANT	\N	PRESENT	0
128716	127193	14271U	PARTICIPANT	\N	PRESENT	0
128717	127193	08043V	PARTICIPANT	\N	PRESENT	0
128718	127193	14065Q	PARTICIPANT	\N	PRESENT	0
128719	127193	11089X	PARTICIPANT	\N	PRESENT	0
128720	127193	01016M	PARTICIPANT	\N	PRESENT	0
128721	127193	92015P	PARTICIPANT	\N	PRESENT	0
128722	127193	11104D	PARTICIPANT	\N	PRESENT	0
128723	127193	14269B	PARTICIPANT	\N	PRESENT	0
128724	127193	14081Q	PARTICIPANT	\N	PRESENT	0
128725	127193	11014C	PARTICIPANT	\N	PRESENT	0
147212	146828	04057K	PARTICIPANT	\N	PRESENT	0
147213	146828	11034G	PARTICIPANT	\N	PRESENT	0
147214	146828	80013X	PARTICIPANT	\N	PRESENT	0
147215	146828	14107H	PARTICIPANT	\N	PRESENT	0
147216	146828	14089Y	PARTICIPANT	\N	PRESENT	0
147217	146828	11085T	PARTICIPANT	\N	PRESENT	0
147218	146828	14169X	PARTICIPANT	\N	PRESENT	0
147219	146828	14213J	PARTICIPANT	\N	PRESENT	0
147220	146828	14033T	PARTICIPANT	\N	PRESENT	0
147294	146829	11040E	PARTICIPANT	\N	PRESENT	0
147295	146829	13002U	PARTICIPANT	\N	PRESENT	0
147296	146829	11033F	PARTICIPANT	\N	PRESENT	0
147297	146829	14030Q	PARTICIPANT	\N	PRESENT	0
147298	146829	14267Y	PARTICIPANT	\N	PRESENT	0
147299	146829	07004J	PARTICIPANT	\N	PRESENT	0
147300	146829	04077P	PARTICIPANT	\N	PRESENT	0
147301	146829	14215L	PARTICIPANT	\N	PRESENT	0
147302	146829	14237S	PARTICIPANT	\N	PRESENT	0
147292	146829	01022K	PARTICIPANT	\N	PRESENT	0
147293	146829	14263U	PARTICIPANT	\N	PRESENT	0
147303	146829	07034Q	PARTICIPANT	\N	PRESENT	0
147304	146829	14331P	PARTICIPANT	\N	PRESENT	0
147305	146829	14061L	PARTICIPANT	\N	PRESENT	0
147306	146829	97011G	PARTICIPANT	\N	PRESENT	0
147307	146829	04057K	PARTICIPANT	\N	PRESENT	0
147308	146829	14147R	PARTICIPANT	\N	PRESENT	0
147309	146829	11097X	PARTICIPANT	\N	PRESENT	0
147310	146829	14041T	PARTICIPANT	\N	PRESENT	0
147311	146829	04088S	PARTICIPANT	\N	PRESENT	0
147312	146829	14105F	PARTICIPANT	\N	PRESENT	0
147313	146829	14195A	PARTICIPANT	\N	PRESENT	0
147314	146829	08034U	PARTICIPANT	\N	PRESENT	0
147315	146829	14031R	PARTICIPANT	\N	PRESENT	0
147316	146829	04034C	PARTICIPANT	\N	PRESENT	0
147317	146829	95067Q	PARTICIPANT	\N	PRESENT	0
147318	146829	95059Q	PARTICIPANT	\N	PRESENT	0
147319	146829	99004R	PARTICIPANT	\N	PRESENT	0
147320	146829	14037X	PARTICIPANT	\N	PRESENT	0
147321	146829	14063N	PARTICIPANT	\N	PRESENT	0
147322	146829	04061F	PARTICIPANT	\N	PRESENT	0
147323	146829	01047U	PARTICIPANT	\N	PRESENT	0
147324	146829	11084S	PARTICIPANT	\N	PRESENT	0
147325	146829	14097Y	PARTICIPANT	\N	PRESENT	0
147326	146829	14087W	PARTICIPANT	\N	PRESENT	0
147327	146829	14033T	PARTICIPANT	\N	PRESENT	0
147328	146829	08018U	PARTICIPANT	\N	PRESENT	0
147329	146829	01057W	PARTICIPANT	\N	PRESENT	0
147330	146829	14119M	PARTICIPANT	\N	PRESENT	0
147331	146829	14026U	PARTICIPANT	\N	PRESENT	0
147332	146829	08010L	PARTICIPANT	\N	PRESENT	0
147333	146829	14223L	PARTICIPANT	\N	PRESENT	0
147334	146829	08041T	PARTICIPANT	\N	PRESENT	0
147335	146829	14187A	PARTICIPANT	\N	PRESENT	0
147336	146829	04033B	PARTICIPANT	\N	PRESENT	0
147337	146829	10006L	PARTICIPANT	\N	PRESENT	0
147338	146829	86044G	PARTICIPANT	\N	PRESENT	0
147339	146829	09001P	PARTICIPANT	\N	PRESENT	0
147340	146829	04067M	PARTICIPANT	\N	PRESENT	0
147341	146829	11026G	PARTICIPANT	\N	PRESENT	0
147342	146829	04059M	PARTICIPANT	\N	PRESENT	0
147343	146829	88008L	PARTICIPANT	\N	PRESENT	0
147344	146829	04085P	PARTICIPANT	\N	PRESENT	0
147352	146829	14111D	PARTICIPANT	\N	PRESENT	0
147353	146829	80027E	PARTICIPANT	\N	PRESENT	0
147354	146829	01028R	PARTICIPANT	\N	PRESENT	0
147355	146829	01003G	PARTICIPANT	\N	PRESENT	0
147372	146829	87003B	PARTICIPANT	\N	PRESENT	0
147374	146829	14211G	PARTICIPANT	\N	PRESENT	0
147375	146829	08062Y	PARTICIPANT	\N	PRESENT	0
147376	146829	98018T	PARTICIPANT	\N	PRESENT	0
147404	146829	11048N	PARTICIPANT	\N	PRESENT	0
147405	146829	04086Q	PARTICIPANT	\N	PRESENT	0
147406	146829	14219Q	PARTICIPANT	\N	PRESENT	0
147407	146829	11113E	PARTICIPANT	\N	PRESENT	0
147408	146829	11089X	PARTICIPANT	\N	PRESENT	0
147409	146829	14107H	PARTICIPANT	\N	PRESENT	0
147410	146829	14059S	PARTICIPANT	\N	PRESENT	0
147411	146829	01058X	PARTICIPANT	\N	PRESENT	0
147412	146829	95062K	PARTICIPANT	\N	PRESENT	0
147413	146829	11111C	PARTICIPANT	\N	PRESENT	0
147414	146829	14028W	PARTICIPANT	\N	PRESENT	0
147415	146829	14209N	PARTICIPANT	\N	PRESENT	0
147416	146829	11059R	PARTICIPANT	\N	PRESENT	0
147417	146829	01044R	PARTICIPANT	\N	PRESENT	0
147418	146829	14327T	PARTICIPANT	\N	PRESENT	0
147419	146829	14001X	PARTICIPANT	\N	PRESENT	0
147420	146829	95035G	PARTICIPANT	\N	PRESENT	0
147512	146830	01022K	PARTICIPANT	\N	PRESENT	0
147513	146830	11059R	PARTICIPANT	\N	PRESENT	0
147514	146830	14107H	PARTICIPANT	\N	PRESENT	0
147515	146830	14063N	PARTICIPANT	\N	PRESENT	0
147516	146830	11084S	PARTICIPANT	\N	PRESENT	0
147517	146830	11026G	PARTICIPANT	\N	PRESENT	0
147518	146830	14001X	PARTICIPANT	\N	PRESENT	0
147519	146830	14159V	PARTICIPANT	\N	PRESENT	0
147520	146830	13002U	PARTICIPANT	\N	PRESENT	0
147521	146830	01044R	PARTICIPANT	\N	PRESENT	0
147522	146830	01003G	PARTICIPANT	\N	PRESENT	0
147523	146830	14327T	PARTICIPANT	\N	PRESENT	0
147552	146830	90003B	PARTICIPANT	\N	PRESENT	0
147525	146830	08062Y	PARTICIPANT	\N	PRESENT	0
147526	146830	97011G	PARTICIPANT	\N	PRESENT	0
147527	146830	14069U	PARTICIPANT	\N	PRESENT	0
147528	146830	95062K	PARTICIPANT	\N	PRESENT	0
147529	146830	01058X	PARTICIPANT	\N	PRESENT	0
147530	146830	01057W	PARTICIPANT	\N	PRESENT	0
147531	146830	08034U	PARTICIPANT	\N	PRESENT	0
147532	146830	98035U	PARTICIPANT	\N	PRESENT	0
147533	146830	14173T	PARTICIPANT	\N	PRESENT	0
147534	146830	14209N	PARTICIPANT	\N	PRESENT	0
147535	146830	95035G	PARTICIPANT	\N	PRESENT	0
147536	146830	11111C	PARTICIPANT	\N	PRESENT	0
147537	146830	14041T	PARTICIPANT	\N	PRESENT	0
147538	146830	04038G	PARTICIPANT	\N	PRESENT	0
147553	146830	14207L	PARTICIPANT	\N	PRESENT	0
147554	146830	01031L	PARTICIPANT	\N	PRESENT	0
147555	146830	08051V	PARTICIPANT	\N	PRESENT	0
147556	146830	14111D	PARTICIPANT	\N	PRESENT	0
147557	146830	95030B	PARTICIPANT	\N	PRESENT	0
147558	146830	14219Q	PARTICIPANT	\N	PRESENT	0
147559	146830	14123H	PARTICIPANT	\N	PRESENT	0
147560	146830	11037K	PARTICIPANT	\N	PRESENT	0
147561	146830	08017T	PARTICIPANT	\N	PRESENT	0
147562	146830	87003B	PARTICIPANT	\N	PRESENT	0
147576	146830	80013X	PARTICIPANT	\N	PRESENT	0
147577	146830	14059S	PARTICIPANT	\N	PRESENT	0
147578	146830	14026U	PARTICIPANT	\N	PRESENT	0
147579	146830	14073Q	PARTICIPANT	\N	PRESENT	0
147580	146830	14249W	PARTICIPANT	\N	PRESENT	0
147581	146830	14089Y	PARTICIPANT	\N	PRESENT	0
147582	146830	11053K	PARTICIPANT	\N	PRESENT	0
147583	146830	04089T	PARTICIPANT	\N	PRESENT	0
147584	146830	14221J	PARTICIPANT	\N	PRESENT	0
147585	146830	14257W	PARTICIPANT	\N	PRESENT	0
147586	146830	08056B	PARTICIPANT	\N	PRESENT	0
147587	146830	14061L	PARTICIPANT	\N	PRESENT	0
147588	146830	01034P	PARTICIPANT	\N	PRESENT	0
147589	146830	05008E	PARTICIPANT	\N	PRESENT	0
147590	146830	89017R	PARTICIPANT	\N	PRESENT	0
147598	146830	14199E	PARTICIPANT	\N	PRESENT	0
147600	146830	04088S	PARTICIPANT	\N	PRESENT	0
147602	146830	14147R	PARTICIPANT	\N	PRESENT	0
147614	146830	08055A	PARTICIPANT	\N	PRESENT	0
147605	146830	04059M	PARTICIPANT	\N	PRESENT	0
147606	146830	11104D	PARTICIPANT	\N	PRESENT	0
147510	146830	08024S	PARTICIPANT	\N	PRESENT	0
147511	146830	11034G	PARTICIPANT	\N	PRESENT	0
147607	146830	08015R	PARTICIPANT	\N	PRESENT	0
147608	146830	14237S	PARTICIPANT	\N	PRESENT	0
147609	146830	14105F	PARTICIPANT	\N	PRESENT	0
147611	146830	14187A	PARTICIPANT	\N	PRESENT	0
147612	146830	01008M	PARTICIPANT	\N	PRESENT	0
129943	129942	01008M	PARTICIPANT	\N	PRESENT	0
129851	129849	08055A	PARTICIPANT	\N	PRESENT	0
129852	129849	14093U	PARTICIPANT	\N	PRESENT	0
129853	129849	14030Q	PARTICIPANT	\N	PRESENT	0
129854	129849	96004D	PARTICIPANT	\N	PRESENT	0
129855	129849	08060W	PARTICIPANT	\N	PRESENT	0
129856	129849	11095V	PARTICIPANT	\N	EXCUSE	0
129857	129849	14038Y	PARTICIPANT	\N	PRESENT	0
129858	129849	11114F	PARTICIPANT	\N	PRESENT	0
129859	129849	98023Q	PARTICIPANT	\N	PRESENT	0
129896	129894	08055A	PARTICIPANT	\N	PRESENT	0
129861	129849	01015L	PARTICIPANT	\N	PRESENT	0
129862	129849	11107G	PARTICIPANT	\N	PRESENT	0
129897	129894	14093U	PARTICIPANT	\N	PRESENT	0
129864	129849	02002K	PARTICIPANT	\N	PRESENT	0
129865	129849	01022K	PARTICIPANT	\N	PRESENT	0
129866	129849	04097T	PARTICIPANT	\N	PRESENT	0
129867	129849	09001P	PARTICIPANT	\N	PRESENT	0
129868	129849	11059R	PARTICIPANT	\N	PRESENT	0
129869	129849	14219Q	PARTICIPANT	\N	PRESENT	0
129898	129894	14030Q	PARTICIPANT	\N	PRESENT	0
129871	129849	14031R	PARTICIPANT	\N	PRESENT	0
129899	129894	96004D	PARTICIPANT	\N	PRESENT	0
129873	129849	08062Y	PARTICIPANT	\N	EXCUSE	0
129874	129849	14221J	PARTICIPANT	\N	PRESENT	0
129875	129849	92039X	PARTICIPANT	\N	PRESENT	0
129876	129849	08042U	PARTICIPANT	\N	PRESENT	0
129877	129849	14169X	PARTICIPANT	\N	PRESENT	0
129878	129849	14237S	PARTICIPANT	\N	PRESENT	0
129879	129849	13002U	PARTICIPANT	\N	PRESENT	0
129880	129849	05012A	PRESIDENT	0	PRESENT	0
129881	129849	14247U	PARTICIPANT	\N	PRESENT	0
129882	129849	14135M	PARTICIPANT	\N	PRESENT	0
129883	129849	14331P	PARTICIPANT	\N	PRESENT	0
129884	129849	95062K	PARTICIPANT	\N	PRESENT	0
129885	129849	14107H	PARTICIPANT	\N	PRESENT	0
129886	129849	14051J	PARTICIPANT	\N	PRESENT	0
129887	129849	14157T	PARTICIPANT	\N	PRESENT	0
129888	129849	96003C	PARTICIPANT	\N	EXCUSE	0
129900	129894	08060W	PARTICIPANT	\N	PRESENT	0
129901	129894	11095V	PARTICIPANT	\N	EXCUSE	0
129902	129894	14038Y	PARTICIPANT	\N	PRESENT	0
129903	129894	11114F	PARTICIPANT	\N	PRESENT	0
129904	129894	98023Q	PARTICIPANT	\N	PRESENT	0
129944	129942	11036J	PARTICIPANT	\N	PRESENT	0
129906	129894	01015L	PARTICIPANT	\N	PRESENT	0
129907	129894	11107G	PARTICIPANT	\N	PRESENT	0
129982	129942	04080J	PARTICIPANT	\N	PRESENT	0
129909	129894	02002K	PARTICIPANT	\N	PRESENT	0
129910	129894	01022K	PARTICIPANT	\N	PRESENT	0
129911	129894	04097T	PARTICIPANT	\N	PRESENT	0
129912	129894	09001P	PARTICIPANT	\N	PRESENT	0
129913	129894	11059R	PARTICIPANT	\N	PRESENT	0
129914	129894	14219Q	PARTICIPANT	\N	PRESENT	0
129983	129942	04035D	PARTICIPANT	\N	PRESENT	0
129916	129894	14031R	PARTICIPANT	\N	PRESENT	0
129984	129942	14133K	PARTICIPANT	\N	PRESENT	0
129918	129894	08062Y	PARTICIPANT	\N	EXCUSE	0
129919	129894	14221J	PARTICIPANT	\N	PRESENT	0
129920	129894	92039X	PARTICIPANT	\N	PRESENT	0
129921	129894	08042U	PARTICIPANT	\N	PRESENT	0
129922	129894	14169X	PARTICIPANT	\N	PRESENT	0
129923	129894	14237S	PARTICIPANT	\N	PRESENT	0
129924	129894	13002U	PARTICIPANT	\N	PRESENT	0
129925	129894	05012A	PRESIDENT	0	PRESENT	0
129926	129894	14247U	PARTICIPANT	\N	PRESENT	0
129927	129894	14135M	PARTICIPANT	\N	PRESENT	0
129928	129894	14331P	PARTICIPANT	\N	PRESENT	0
129929	129894	95062K	PARTICIPANT	\N	PRESENT	0
129930	129894	14107H	PARTICIPANT	\N	PRESENT	0
129931	129894	14051J	PARTICIPANT	\N	PRESENT	0
129932	129894	14157T	PARTICIPANT	\N	PRESENT	0
129933	129894	96003C	PARTICIPANT	\N	EXCUSE	0
129985	129942	96004D	PARTICIPANT	\N	PRESENT	0
129986	129942	11040E	PARTICIPANT	\N	PRESENT	0
129950	129942	90003B	PARTICIPANT	\N	EXCUSE	0
129987	129942	14249W	PARTICIPANT	\N	PRESENT	0
129952	129942	80013X	PARTICIPANT	\N	PRESENT	0
129988	129942	14079W	PARTICIPANT	\N	PRESENT	0
129989	129942	14135M	PARTICIPANT	\N	PRESENT	0
129955	129942	14197C	PARTICIPANT	\N	PRESENT	0
132904	132899	08010L	PARTICIPANT	\N	PRESENT	0
132918	132917	01031L	PARTICIPANT	\N	PRESENT	0
129958	129942	14033T	PARTICIPANT	\N	PRESENT	0
132920	132919	11068S	PARTICIPANT	\N	PRESENT	0
132922	132921	11068S	PARTICIPANT	\N	PRESENT	0
135714	135568	11077T	PARTICIPANT	\N	PRESENT	0
135715	135568	08019V	PARTICIPANT	\N	PRESENT	0
135716	135568	11061K	PARTICIPANT	\N	PRESENT	0
135717	135568	07029T	PARTICIPANT	\N	PRESENT	0
129966	129942	11100Y	PRESIDENT	0	PRESENT	0
129967	129942	01061S	PARTICIPANT	\N	EXCUSE	0
129968	129942	11098Y	PARTICIPANT	\N	PRESENT	0
129969	129942	01043Q	PARTICIPANT	\N	EXCUSE	0
129970	129942	11077T	PARTICIPANT	\N	PRESENT	0
135718	135568	11085T	PARTICIPANT	\N	PRESENT	0
135719	135568	04066L	PARTICIPANT	\N	PRESENT	0
135720	135568	80013X	PARTICIPANT	\N	PRESENT	0
135721	135568	14069U	PARTICIPANT	\N	PRESENT	0
135742	135574	89029V	PARTICIPANT	\N	PRESENT	0
129976	129942	98050T	PARTICIPANT	\N	PRESENT	0
137141	136742	04081K	PARTICIPANT	\N	PRESENT	0
129978	129942	11046L	PARTICIPANT	\N	PRESENT	0
129979	129942	01058X	PARTICIPANT	\N	PRESENT	0
129980	129942	11094U	PARTICIPANT	\N	EXCUSE	0
129981	129942	11066Q	PARTICIPANT	\N	PRESENT	0
137240	136742	04050C	PARTICIPANT	\N	PRESENT	0
137241	136742	14263U	PARTICIPANT	\N	PRESENT	0
137242	136742	14259Y	PARTICIPANT	\N	PRESENT	0
137243	136742	14193X	PARTICIPANT	\N	PRESENT	0
137244	136742	04086Q	PARTICIPANT	\N	PRESENT	0
137245	136742	14147R	PARTICIPANT	\N	PRESENT	0
137246	136742	08058D	PARTICIPANT	\N	PRESENT	0
137247	136742	07026Q	PARTICIPANT	\N	PRESENT	0
137248	136742	11034G	PARTICIPANT	\N	PRESENT	0
137249	136742	11076S	PARTICIPANT	\N	PRESENT	0
137250	136742	14237S	PARTICIPANT	\N	PRESENT	0
137251	136742	11085T	PARTICIPANT	\N	PRESENT	0
137252	136742	14038Y	PARTICIPANT	\N	PRESENT	0
137253	136742	07024N	PARTICIPANT	\N	PRESENT	0
137254	136742	11103C	PARTICIPANT	\N	PRESENT	0
137255	136742	05008E	PARTICIPANT	\N	PRESENT	0
137257	136743	04081K	PARTICIPANT	\N	PRESENT	0
137258	136743	04050C	PARTICIPANT	\N	PRESENT	0
137259	136743	14263U	PARTICIPANT	\N	PRESENT	0
137260	136743	14259Y	PARTICIPANT	\N	PRESENT	0
137261	136743	14193X	PARTICIPANT	\N	PRESENT	0
137262	136743	04086Q	PARTICIPANT	\N	PRESENT	0
137263	136743	14147R	PARTICIPANT	\N	PRESENT	0
137264	136743	08058D	PARTICIPANT	\N	PRESENT	0
137265	136743	07026Q	PARTICIPANT	\N	PRESENT	0
137266	136743	11034G	PARTICIPANT	\N	PRESENT	0
137267	136743	11076S	PARTICIPANT	\N	PRESENT	0
137268	136743	14237S	PARTICIPANT	\N	PRESENT	0
137269	136743	11085T	PARTICIPANT	\N	PRESENT	0
137270	136743	14038Y	PARTICIPANT	\N	PRESENT	0
137271	136743	07024N	PARTICIPANT	\N	PRESENT	0
137272	136743	11103C	PARTICIPANT	\N	PRESENT	0
137273	136743	05008E	PARTICIPANT	\N	PRESENT	0
137331	136743	14199E	PARTICIPANT	\N	PRESENT	0
137332	136743	14026U	PARTICIPANT	\N	PRESENT	0
137333	136743	14205J	PARTICIPANT	\N	PRESENT	0
137334	136743	14119M	PARTICIPANT	\N	PRESENT	0
137335	136743	04038G	PARTICIPANT	\N	PRESENT	0
137336	136743	08062Y	PARTICIPANT	\N	PRESENT	0
137338	136743	11091R	PARTICIPANT	\N	PRESENT	0
137339	136743	11090Q	PARTICIPANT	\N	PRESENT	0
137340	136743	14033T	PARTICIPANT	\N	PRESENT	0
137341	136743	92015P	PARTICIPANT	\N	PRESENT	0
137342	136743	11033F	PARTICIPANT	\N	PRESENT	0
137343	136743	08019V	PARTICIPANT	\N	PRESENT	0
137344	136743	11071M	PARTICIPANT	\N	PRESENT	0
137345	136743	04066L	PARTICIPANT	\N	PRESENT	0
137346	136743	95062K	PARTICIPANT	\N	PRESENT	0
137347	136743	14269B	PARTICIPANT	\N	PRESENT	0
137348	136743	01047U	PARTICIPANT	\N	PRESENT	0
137349	136743	04053F	PARTICIPANT	\N	PRESENT	0
137350	136743	14061L	PARTICIPANT	\N	PRESENT	0
137351	136743	08051V	PARTICIPANT	\N	PRESENT	0
137352	136743	01028R	PARTICIPANT	\N	PRESENT	0
137432	136743	14207L	PARTICIPANT	\N	PRESENT	0
137435	136743	14063N	PARTICIPANT	\N	PRESENT	0
137438	136743	14014Q	PARTICIPANT	\N	PRESENT	0
137448	136743	14235Q	PARTICIPANT	\N	PRESENT	0
137451	136743	11105E	PARTICIPANT	\N	PRESENT	0
137452	136743	87003B	PARTICIPANT	\N	PRESENT	0
137453	136743	01024M	PARTICIPANT	\N	PRESENT	0
137454	136743	01025N	PARTICIPANT	\N	PRESENT	0
144816	144815	04080J	PARTICIPANT	\N	PRESENT	0
144817	144815	11084S	PARTICIPANT	\N	PRESENT	0
144819	144818	04080J	PARTICIPANT	\N	PRESENT	0
144820	144818	11084S	PARTICIPANT	\N	PRESENT	0
144822	144821	04080J	PARTICIPANT	\N	PRESENT	0
147592	125636	01058X	PARTICIPANT	\N	EXCUSE	0
147593	125636	11082Q	PARTICIPANT	\N	EXCUSE	0
147594	125637	01046T	PARTICIPANT	\N	EXCUSE	0
147595	125637	08069G	PARTICIPANT	\N	EXCUSE	0
147596	125637	08039A	PARTICIPANT	\N	EXCUSE	0
147597	125637	11082Q	PARTICIPANT	\N	EXCUSE	0
147599	125637	01058X	PARTICIPANT	\N	EXCUSE	0
147740	125636	08039A	PARTICIPANT	\N	EXCUSE	0
158731	158072	14073Q	PARTICIPANT	\N	PRESENT	0
158736	158072	14249W	PARTICIPANT	\N	PRESENT	0
158737	158072	86044G	PARTICIPANT	\N	PRESENT	0
158738	158072	14079W	PARTICIPANT	\N	PRESENT	0
158739	158072	14363X	PARTICIPANT	\N	PRESENT	0
158740	158072	14217N	PARTICIPANT	\N	PRESENT	0
158741	158072	11054L	PARTICIPANT	\N	PRESENT	0
158742	158072	14123H	PARTICIPANT	\N	PRESENT	0
158743	158072	01027Q	PARTICIPANT	\N	PRESENT	0
158752	158072	04088S	PARTICIPANT	\N	PRESENT	0
158753	158072	14213J	PARTICIPANT	\N	PRESENT	0
158754	158072	14059S	PARTICIPANT	\N	PRESENT	0
158755	158072	14179A	PARTICIPANT	\N	PRESENT	0
158756	158072	08061X	PARTICIPANT	\N	PRESENT	0
158757	158072	02002K	PARTICIPANT	\N	PRESENT	0
158758	158072	08038Y	PARTICIPANT	\N	PRESENT	0
158759	158072	14053L	PARTICIPANT	\N	PRESENT	0
158760	158072	11036J	PARTICIPANT	\N	PRESENT	0
158761	158072	08060W	PARTICIPANT	\N	PRESENT	0
158772	158072	14205J	PARTICIPANT	\N	PRESENT	0
158773	158072	14255U	PARTICIPANT	\N	PRESENT	0
158774	158072	11093T	PARTICIPANT	\N	PRESENT	0
158775	158072	14197C	PARTICIPANT	\N	PRESENT	0
158776	158072	04055H	PARTICIPANT	\N	PRESENT	0
158777	158072	14041T	PARTICIPANT	\N	PRESENT	0
158778	158072	11107G	PARTICIPANT	\N	PRESENT	0
158779	158072	95063L	PARTICIPANT	\N	PRESENT	0
158792	158072	14239U	PARTICIPANT	\N	PRESENT	0
158793	158072	14331P	PARTICIPANT	\N	PRESENT	0
158794	158072	97011G	PARTICIPANT	\N	PRESENT	0
158795	158072	95062K	PARTICIPANT	\N	PRESENT	0
158797	158072	14135M	PARTICIPANT	\N	PRESENT	0
158798	158072	11103C	PARTICIPANT	\N	PRESENT	0
158799	158072	80013X	PARTICIPANT	\N	PRESENT	0
158800	158072	14083S	PARTICIPANT	\N	PRESENT	0
158812	158072	98018T	PARTICIPANT	\N	PRESENT	0
158813	158072	99004R	PARTICIPANT	\N	PRESENT	0
158814	158072	01024M	PARTICIPANT	\N	PRESENT	0
158815	158072	04057K	PARTICIPANT	\N	PRESENT	0
158941	158073	04070G	PARTICIPANT	\N	PRESENT	0
158942	158073	14263U	PARTICIPANT	\N	PRESENT	0
158943	158073	04085P	PARTICIPANT	\N	PRESENT	0
158944	158073	12041X	PARTICIPANT	\N	PRESENT	0
158945	158073	11031D	PARTICIPANT	\N	PRESENT	0
158946	158073	11034G	PARTICIPANT	\N	PRESENT	0
158947	158073	14235Q	PARTICIPANT	\N	PRESENT	0
158948	158073	08017T	PARTICIPANT	\N	PRESENT	0
158949	158073	01044R	PARTICIPANT	\N	PRESENT	0
158950	158073	13002U	PARTICIPANT	\N	PRESENT	0
158951	158073	14030Q	PARTICIPANT	\N	PRESENT	0
158952	158073	14103D	PARTICIPANT	\N	PRESENT	0
158953	158073	14073Q	PARTICIPANT	\N	PRESENT	0
158954	158073	14083S	PARTICIPANT	\N	PRESENT	0
158955	158073	04045F	PARTICIPANT	\N	PRESENT	0
158956	158073	11061K	PARTICIPANT	\N	PRESENT	0
158957	158073	01024M	PARTICIPANT	\N	PRESENT	0
158958	158073	14331P	PARTICIPANT	\N	PRESENT	0
158959	158073	14363X	PARTICIPANT	\N	PRESENT	0
158960	158073	14053L	PARTICIPANT	\N	PRESENT	0
158961	158073	97011G	PARTICIPANT	\N	PRESENT	0
158962	158073	04057K	PARTICIPANT	\N	PRESENT	0
158963	158073	14265W	PARTICIPANT	\N	PRESENT	0
158964	158073	14223L	PARTICIPANT	\N	PRESENT	0
158965	158073	14253S	PARTICIPANT	\N	PRESENT	0
158966	158073	14195A	PARTICIPANT	\N	PRESENT	0
158967	158073	14041T	PARTICIPANT	\N	PRESENT	0
158968	158073	14059S	PARTICIPANT	\N	PRESENT	0
158969	158073	08019V	PARTICIPANT	\N	PRESENT	0
158970	158073	14119M	PARTICIPANT	\N	PRESENT	0
158971	158073	11036J	PARTICIPANT	\N	PRESENT	0
158992	158073	11089X	PARTICIPANT	\N	PRESENT	0
158993	158073	07026Q	PARTICIPANT	\N	PRESENT	0
158994	158073	04050C	PARTICIPANT	\N	PRESENT	0
158995	158073	08015R	PARTICIPANT	\N	PRESENT	0
158996	158073	14199E	PARTICIPANT	\N	PRESENT	0
158997	158073	14267Y	PARTICIPANT	\N	PRESENT	0
158998	158073	95062K	PARTICIPANT	\N	PRESENT	0
158999	158073	14105F	PARTICIPANT	\N	PRESENT	0
159000	158073	14241N	PARTICIPANT	\N	PRESENT	0
159002	158073	14201E	PARTICIPANT	\N	PRESENT	0
159012	158073	11098Y	PARTICIPANT	\N	PRESENT	0
159013	158073	98022P	PARTICIPANT	\N	PRESENT	0
159014	158073	14069U	PARTICIPANT	\N	PRESENT	0
159032	158073	08069G	PARTICIPANT	\N	PRESENT	0
159033	158073	11103C	PARTICIPANT	\N	PRESENT	0
159034	158073	14051J	PARTICIPANT	\N	PRESENT	0
159035	158073	01022K	PARTICIPANT	\N	PRESENT	0
159052	158073	11065P	PARTICIPANT	\N	PRESENT	0
159053	158073	08043V	PARTICIPANT	\N	PRESENT	0
159054	158073	14157T	PARTICIPANT	\N	PRESENT	0
159055	158073	14219Q	PARTICIPANT	\N	PRESENT	0
159056	158073	05012A	PARTICIPANT	\N	PRESENT	0
159057	158073	14231L	PARTICIPANT	\N	PRESENT	0
159058	158073	14079W	PARTICIPANT	\N	PRESENT	0
159059	158073	08010L	PARTICIPANT	\N	PRESENT	0
159060	158073	14133K	PARTICIPANT	\N	PRESENT	0
159119	158074	04081K	PARTICIPANT	\N	PRESENT	0
159120	158074	14157T	PARTICIPANT	\N	PRESENT	0
159121	158074	05008E	PARTICIPANT	\N	PRESENT	0
159122	158074	95062K	PARTICIPANT	\N	PRESENT	0
159123	158074	01015L	PARTICIPANT	\N	PRESENT	0
159124	158074	14018U	PARTICIPANT	\N	PRESENT	0
159125	158074	14030Q	PARTICIPANT	\N	PRESENT	0
159126	158074	11065P	PARTICIPANT	\N	PRESENT	0
159127	158074	14051J	PARTICIPANT	\N	PRESENT	0
159128	158074	14331P	PARTICIPANT	\N	PRESENT	0
159129	158074	01022K	PARTICIPANT	\N	PRESENT	0
159130	158074	14093U	PARTICIPANT	\N	PRESENT	0
159131	158074	14053L	PARTICIPANT	\N	PRESENT	0
159132	158074	14219Q	PARTICIPANT	\N	PRESENT	0
159133	158074	14231L	PARTICIPANT	\N	PRESENT	0
159134	158074	14083S	PARTICIPANT	\N	PRESENT	0
159135	158074	01024M	PARTICIPANT	\N	PRESENT	0
159136	158074	14079W	PARTICIPANT	\N	PRESENT	0
159137	158074	05012A	PARTICIPANT	\N	PRESENT	0
159138	158074	14059S	PARTICIPANT	\N	PRESENT	0
159139	158074	11103C	PARTICIPANT	\N	PRESENT	0
159140	158074	14069U	PARTICIPANT	\N	PRESENT	0
159141	158074	08010L	PARTICIPANT	\N	PRESENT	0
159142	158074	14031R	PARTICIPANT	\N	PRESENT	0
159143	158074	11114F	PARTICIPANT	\N	PRESENT	0
159144	158074	98021N	PARTICIPANT	\N	PRESENT	0
159145	158074	11098Y	PARTICIPANT	\N	PRESENT	0
158939	158073	04081K	PARTICIPANT	\N	PRESENT	0
158940	158073	14123H	PARTICIPANT	\N	PRESENT	0
159146	158074	97011G	PARTICIPANT	\N	PRESENT	0
159147	158074	98046X	PARTICIPANT	\N	PRESENT	0
159148	158074	14033T	PARTICIPANT	\N	PRESENT	0
159152	158074	11099A	PARTICIPANT	\N	PRESENT	0
159153	158074	04088S	PARTICIPANT	\N	PRESENT	0
159155	158074	14001X	PARTICIPANT	\N	PRESENT	0
159157	158074	08069G	PARTICIPANT	\N	PRESENT	0
159158	158074	80013X	PARTICIPANT	\N	PRESENT	0
159159	158074	14235Q	PARTICIPANT	\N	PRESENT	0
128726	127193	11042G	PARTICIPANT	\N	PRESENT	0
128727	127193	04095R	PARTICIPANT	\N	PRESENT	0
128728	127193	11114F	PARTICIPANT	\N	PRESENT	0
128729	127193	11109J	PARTICIPANT	\N	PRESENT	0
128730	127193	01044R	PARTICIPANT	\N	PRESENT	0
128731	127193	14159V	PARTICIPANT	\N	PRESENT	0
128732	127193	01003G	PARTICIPANT	\N	PRESENT	0
128733	127193	08031R	PARTICIPANT	\N	PRESENT	0
128734	127193	14241N	PARTICIPANT	\N	PRESENT	0
128735	127193	14042U	PARTICIPANT	\N	PRESENT	0
128736	127193	14030Q	PARTICIPANT	\N	PRESENT	0
128737	127193	14327T	PARTICIPANT	\N	PRESENT	0
128738	127193	14073Q	PARTICIPANT	\N	PRESENT	0
128739	127193	14231L	PARTICIPANT	\N	PRESENT	0
128740	127193	14205J	PARTICIPANT	\N	PRESENT	0
128741	127193	01025N	PARTICIPANT	\N	PRESENT	0
128742	127193	14193X	PARTICIPANT	\N	PRESENT	0
128743	127193	14079W	PARTICIPANT	\N	PRESENT	0
128744	127193	14249W	PARTICIPANT	\N	PRESENT	0
128745	127193	04044E	PARTICIPANT	\N	PRESENT	0
128746	127193	14069U	PARTICIPANT	\N	PRESENT	0
128747	127193	14071N	PARTICIPANT	\N	PRESENT	0
128748	127193	01008M	PARTICIPANT	\N	PRESENT	0
128749	127193	04057K	PARTICIPANT	\N	PRESENT	0
128750	127193	14187A	PARTICIPANT	\N	PRESENT	0
128751	127193	14061L	PARTICIPANT	\N	PRESENT	0
128752	127193	08042U	PARTICIPANT	\N	PRESENT	0
128753	127193	08015R	PARTICIPANT	\N	PRESENT	0
128754	127193	14026U	PARTICIPANT	\N	PRESENT	0
128755	127193	14053L	PARTICIPANT	\N	PRESENT	0
128756	127193	14223L	PARTICIPANT	\N	PRESENT	0
128757	127193	11043H	PARTICIPANT	\N	PRESENT	0
128758	127193	11048N	PARTICIPANT	\N	PRESENT	0
128759	127193	01056V	PARTICIPANT	\N	PRESENT	0
128760	127193	14195A	PARTICIPANT	\N	PRESENT	0
128761	127193	14033T	PARTICIPANT	\N	PRESENT	0
128762	127193	14157T	PARTICIPANT	\N	PRESENT	0
128763	127193	14105F	PARTICIPANT	\N	PRESENT	0
128764	127193	01027Q	PARTICIPANT	\N	PRESENT	0
128765	127193	14133K	PARTICIPANT	\N	PRESENT	0
128766	127193	01046T	PARTICIPANT	\N	PRESENT	0
128767	127193	04088S	PARTICIPANT	\N	PRESENT	0
128768	127193	04067M	PARTICIPANT	\N	PRESENT	0
128769	127193	07029T	PARTICIPANT	\N	PRESENT	0
128770	127193	14147R	PARTICIPANT	\N	PRESENT	0
128771	127193	11097X	PARTICIPANT	\N	PRESENT	0
128772	127193	14199E	PARTICIPANT	\N	PRESENT	0
128777	127193	14265W	PARTICIPANT	\N	PRESENT	0
128778	127193	89017R	PARTICIPANT	\N	PRESENT	0
128779	127193	11098Y	PARTICIPANT	\N	PRESENT	0
128780	127194	08055A	PARTICIPANT	\N	PRESENT	0
128781	127194	01059Y	PARTICIPANT	\N	PRESENT	0
128782	127194	14263U	PARTICIPANT	\N	PRESENT	0
128783	127194	11098Y	PARTICIPANT	\N	PRESENT	0
128784	127194	08024S	PARTICIPANT	\N	PRESENT	0
128785	127194	08043V	PARTICIPANT	\N	PRESENT	0
128786	127194	11104D	PARTICIPANT	\N	PRESENT	0
128787	127194	11089X	PARTICIPANT	\N	PRESENT	0
128788	127194	14229S	PARTICIPANT	\N	PRESENT	0
128789	127194	11014C	PARTICIPANT	\N	PRESENT	0
128790	127194	14159V	PARTICIPANT	\N	PRESENT	0
128791	127194	01044R	PARTICIPANT	\N	PRESENT	0
128792	127194	14073Q	PARTICIPANT	\N	PRESENT	0
128793	127194	01025N	PARTICIPANT	\N	PRESENT	0
128794	127194	14053L	PARTICIPANT	\N	PRESENT	0
128795	127194	14061L	PARTICIPANT	\N	PRESENT	0
128796	127194	14123H	PARTICIPANT	\N	PRESENT	0
128797	127194	14059S	PARTICIPANT	\N	PRESENT	0
128798	127194	04057K	PARTICIPANT	\N	PRESENT	0
128799	127194	14249W	PARTICIPANT	\N	PRESENT	0
128800	127194	11043H	PARTICIPANT	\N	PRESENT	0
128801	127194	07029T	PARTICIPANT	\N	PRESENT	0
128802	127194	14031R	PARTICIPANT	\N	PRESENT	0
128803	127194	14105F	PARTICIPANT	\N	PRESENT	0
128804	127194	04070G	PARTICIPANT	\N	PRESENT	0
128805	127194	08031R	PARTICIPANT	\N	PRESENT	0
128806	127194	14119M	PARTICIPANT	\N	PRESENT	0
128807	127194	14231L	PARTICIPANT	\N	PRESENT	0
128808	127194	14265W	PARTICIPANT	\N	PRESENT	0
128809	127194	01008M	PARTICIPANT	\N	PRESENT	0
128810	127194	14026U	PARTICIPANT	\N	PRESENT	0
128811	127194	11105E	PARTICIPANT	\N	PRESENT	0
128812	127194	92045V	PARTICIPANT	\N	PRESENT	0
130205	130204	04080J	PARTICIPANT	\N	PRESENT	0
130225	130224	14133K	PARTICIPANT	\N	PRESENT	0
130226	130224	01016M	PARTICIPANT	\N	PRESENT	0
130230	130229	01016M	PARTICIPANT	\N	PRESENT	0
130254	130253	05008E	PARTICIPANT	\N	PRESENT	0
130255	130253	14065Q	PARTICIPANT	\N	PRESENT	0
130276	130275	11068S	PARTICIPANT	\N	PRESENT	0
130278	130277	11068S	PARTICIPANT	\N	PRESENT	0
130280	130279	11068S	PARTICIPANT	\N	PRESENT	0
131446	129541	14034U	PARTICIPANT	\N	EXCUSE	0
131449	131447	01031L	PRESIDENT	0	PRESENT	0
131450	131447	01013J	PARTICIPANT	\N	PRESENT	0
131452	131447	14083S	PARTICIPANT	\N	PRESENT	0
131453	131447	11053K	PARTICIPANT	\N	PRESENT	0
131454	131447	14085U	PARTICIPANT	\N	PRESENT	0
131455	131447	11042G	PARTICIPANT	\N	PRESENT	0
131456	131447	04086Q	PARTICIPANT	\N	PRESENT	0
131457	131447	11070L	PARTICIPANT	\N	PRESENT	0
131459	131447	14327T	PARTICIPANT	\N	PRESENT	0
131460	131447	08022Q	PARTICIPANT	\N	PRESENT	0
131461	131447	01027Q	PARTICIPANT	\N	PRESENT	0
131462	131447	11083R	PARTICIPANT	\N	PRESENT	0
131463	131447	14199E	PARTICIPANT	\N	PRESENT	0
131464	131447	01057W	PARTICIPANT	\N	PRESENT	0
131465	131447	11048N	PARTICIPANT	\N	PRESENT	0
131466	131447	14159V	PARTICIPANT	\N	PRESENT	0
131467	131447	07029T	PARTICIPANT	\N	PRESENT	0
131468	131447	08010L	PARTICIPANT	\N	PRESENT	0
131469	131447	08034U	PARTICIPANT	\N	PRESENT	0
131477	131447	08011M	PARTICIPANT	\N	PRESENT	0
131475	131447	01048V	PARTICIPANT	\N	PRESENT	0
131476	131447	98046X	PARTICIPANT	\N	PRESENT	0
131478	131447	08061X	PARTICIPANT	\N	PRESENT	0
131479	131447	14225N	PARTICIPANT	\N	PRESENT	0
131480	131447	04034C	PARTICIPANT	\N	PRESENT	0
131912	130292	04059M	PARTICIPANT	\N	PRESENT	0
131913	130292	14030Q	PARTICIPANT	\N	PRESENT	0
131914	130292	14175V	PARTICIPANT	\N	PRESENT	0
131915	130292	14255U	PARTICIPANT	\N	PRESENT	0
131916	130292	04042C	PARTICIPANT	\N	PRESENT	0
131917	130292	11080N	PARTICIPANT	\N	PRESENT	0
131918	130292	14281W	PARTICIPANT	\N	PRESENT	0
131919	130292	14199E	PARTICIPANT	\N	PRESENT	0
131920	130292	95035G	PARTICIPANT	\N	PRESENT	0
131921	130292	14081Q	PARTICIPANT	\N	PRESENT	0
131922	130292	04036E	PARTICIPANT	\N	PRESENT	0
131923	130292	04077P	PARTICIPANT	\N	PRESENT	0
131924	130292	04049K	PARTICIPANT	\N	PRESENT	0
131925	130292	11026G	PARTICIPANT	\N	PRESENT	0
131926	130292	11085T	PARTICIPANT	\N	PRESENT	0
131927	130292	04070G	PARTICIPANT	\N	PRESENT	0
131928	130292	04088S	PARTICIPANT	\N	PRESENT	0
131929	130292	95067Q	PARTICIPANT	\N	PRESENT	0
131930	130292	11063M	PARTICIPANT	\N	PRESENT	0
132928	132925	89017R	PARTICIPANT	\N	PRESENT	0
132930	132925	11039M	PARTICIPANT	\N	PRESENT	0
132932	132925	08055A	PARTICIPANT	\N	PRESENT	0
132933	132925	11029K	PARTICIPANT	\N	PRESENT	0
132934	132925	04066L	PARTICIPANT	\N	PRESENT	0
132935	132925	04042C	PARTICIPANT	\N	PRESENT	0
132936	132925	08024S	PARTICIPANT	\N	PRESENT	0
132937	132925	04081K	PARTICIPANT	\N	PRESENT	0
132938	132925	98042T	PARTICIPANT	\N	PRESENT	0
132939	132925	01003G	PARTICIPANT	\N	PRESENT	0
132940	132925	98053W	PARTICIPANT	\N	PRESENT	0
132941	132925	89029V	PARTICIPANT	\N	PRESENT	0
132942	132925	01007L	PARTICIPANT	\N	PRESENT	0
132943	132925	95037J	PARTICIPANT	\N	PRESENT	0
132944	132925	86034E	PARTICIPANT	\N	PRESENT	0
132945	132925	04094Q	PARTICIPANT	\N	PRESENT	0
132946	132925	08039A	PARTICIPANT	\N	PRESENT	0
132947	132925	01043Q	PARTICIPANT	\N	PRESENT	0
132948	132925	11085T	PARTICIPANT	\N	PRESENT	0
132949	132925	04057K	PARTICIPANT	\N	PRESENT	0
132950	132925	92040Q	PARTICIPANT	\N	PRESENT	0
132951	132925	04088S	PARTICIPANT	\N	PRESENT	0
132952	132925	01019Q	PARTICIPANT	\N	PRESENT	0
132953	132925	04056J	PARTICIPANT	\N	PRESENT	0
132955	132954	01007L	PARTICIPANT	\N	PRESENT	0
132956	132954	89017R	PARTICIPANT	\N	PRESENT	0
132957	132954	11029K	PARTICIPANT	\N	PRESENT	0
132958	132954	04088S	PARTICIPANT	\N	PRESENT	0
132991	132990	14249W	PARTICIPANT	\N	PRESENT	0
132992	132990	07026Q	PARTICIPANT	\N	PRESENT	0
132994	132993	14133K	PARTICIPANT	\N	PRESENT	0
147657	146831	11098Y	PARTICIPANT	\N	PRESENT	0
147658	146831	14257W	PARTICIPANT	\N	PRESENT	0
147659	146831	14207L	PARTICIPANT	\N	PRESENT	0
147660	146831	14159V	PARTICIPANT	\N	PRESENT	0
147661	146831	01008M	PARTICIPANT	\N	PRESENT	0
147662	146831	04089T	PARTICIPANT	\N	PRESENT	0
147663	146831	14237S	PARTICIPANT	\N	PRESENT	0
147664	146831	14221J	PARTICIPANT	\N	PRESENT	0
147665	146831	14219Q	PARTICIPANT	\N	PRESENT	0
147666	146831	11053K	PARTICIPANT	\N	PRESENT	0
147667	146831	11094U	PARTICIPANT	\N	PRESENT	0
147708	146831	14105F	PARTICIPANT	\N	PRESENT	0
147709	146831	14041T	PARTICIPANT	\N	PRESENT	0
147710	146831	14119M	PARTICIPANT	\N	PRESENT	0
147711	146831	11100Y	PARTICIPANT	\N	PRESENT	0
147712	146831	14147R	PARTICIPANT	\N	PRESENT	0
147713	146831	14026U	PARTICIPANT	\N	PRESENT	0
147714	146831	08015R	PARTICIPANT	\N	PRESENT	0
147715	146831	14069U	PARTICIPANT	\N	PRESENT	0
147716	146831	14187A	PARTICIPANT	\N	PRESENT	0
147717	146831	14199E	PARTICIPANT	\N	PRESENT	0
147718	146831	08038Y	PARTICIPANT	\N	PRESENT	0
147719	146831	08055A	PARTICIPANT	\N	PRESENT	0
147722	146831	01007L	PARTICIPANT	\N	PRESENT	0
147655	146831	95062K	PARTICIPANT	\N	PRESENT	0
147656	146831	01022K	PARTICIPANT	\N	PRESENT	0
147723	146831	11101A	PARTICIPANT	\N	PRESENT	0
147724	146831	01048V	PARTICIPANT	\N	PRESENT	0
147725	146831	05012A	PARTICIPANT	\N	PRESENT	0
147726	146831	14121F	PARTICIPANT	\N	PRESENT	0
147727	146831	08052W	PARTICIPANT	\N	PRESENT	0
147728	146831	11081P	PARTICIPANT	\N	PRESENT	0
147732	146831	14265W	PARTICIPANT	\N	PRESENT	0
147733	146831	11093T	PARTICIPANT	\N	PRESENT	0
147734	146831	11099A	PARTICIPANT	\N	PRESENT	0
147735	146831	11066Q	PARTICIPANT	\N	PRESENT	0
147736	146831	14205J	PARTICIPANT	\N	PRESENT	0
147737	146831	14033T	PARTICIPANT	\N	PRESENT	0
147738	146831	14013P	PARTICIPANT	\N	PRESENT	0
147739	146831	14197C	PARTICIPANT	\N	PRESENT	0
147741	146831	14133K	PARTICIPANT	\N	PRESENT	0
147742	146831	08010L	PARTICIPANT	\N	PRESENT	0
147743	146831	80013X	PARTICIPANT	\N	PRESENT	0
147744	146831	08016S	PARTICIPANT	\N	PRESENT	0
147752	146831	96004D	PARTICIPANT	\N	PRESENT	0
147753	146831	11036J	PARTICIPANT	\N	PRESENT	0
147754	146831	14037X	PARTICIPANT	\N	PRESENT	0
147755	146831	14195A	PARTICIPANT	\N	PRESENT	0
147772	146831	14097Y	PARTICIPANT	\N	PRESENT	0
147773	146831	14107H	PARTICIPANT	\N	PRESENT	0
148395	147603	08055A	PARTICIPANT	\N	PRESENT	0
148427	147603	14191V	PARTICIPANT	\N	PRESENT	0
148428	147603	11066Q	PARTICIPANT	\N	PRESENT	0
148429	147603	14063N	PARTICIPANT	\N	PRESENT	0
148430	147603	11037K	PARTICIPANT	\N	PRESENT	0
148445	147603	14133K	PARTICIPANT	\N	PRESENT	0
148446	147603	14119M	PARTICIPANT	\N	PRESENT	0
148447	147603	04074L	PARTICIPANT	\N	PRESENT	0
148448	147603	08039A	PARTICIPANT	\N	PRESENT	0
148449	147603	14223L	PARTICIPANT	\N	PRESENT	0
148450	147603	08048B	PARTICIPANT	\N	PRESENT	0
148451	147603	11103C	PARTICIPANT	\N	PRESENT	0
148452	147603	14147R	PARTICIPANT	\N	PRESENT	0
148453	147603	95049N	PARTICIPANT	\N	PRESENT	0
148454	147603	14087W	PARTICIPANT	\N	PRESENT	0
148455	147603	14217N	PARTICIPANT	\N	PRESENT	0
148456	147603	14231L	PARTICIPANT	\N	PRESENT	0
148457	147603	09001P	PARTICIPANT	\N	PRESENT	0
148458	147603	11093T	PARTICIPANT	\N	PRESENT	0
148459	147603	14239U	PARTICIPANT	\N	PRESENT	0
148460	147603	14219Q	PARTICIPANT	\N	PRESENT	0
148461	147603	14267Y	PARTICIPANT	\N	PRESENT	0
148462	147603	11029K	PARTICIPANT	\N	PRESENT	0
148463	147603	08052W	PARTICIPANT	\N	PRESENT	0
148464	147603	14269B	PARTICIPANT	\N	PRESENT	0
148465	147603	12042Y	PARTICIPANT	\N	PRESENT	0
148466	147603	08043V	PARTICIPANT	\N	PRESENT	0
148467	147603	14121F	PARTICIPANT	\N	PRESENT	0
148468	147603	14227Q	PARTICIPANT	\N	PRESENT	0
148469	147603	95030B	PARTICIPANT	\N	PRESENT	0
148470	147603	11031D	PARTICIPANT	\N	PRESENT	0
148471	147603	04092N	PARTICIPANT	\N	PRESENT	0
154893	154892	08031R	PARTICIPANT	\N	PRESENT	0
154894	154892	14255U	PARTICIPANT	\N	PRESENT	0
154895	154892	11027H	PARTICIPANT	\N	PRESENT	0
154896	154892	14059S	PARTICIPANT	\N	PRESENT	0
154897	154892	14135M	PARTICIPANT	\N	PRESENT	0
158233	158232	14239U	PARTICIPANT	\N	PRESENT	0
158259	158232	14179A	PARTICIPANT	\N	PRESENT	0
158235	158232	14065Q	PARTICIPANT	\N	PRESENT	0
158236	158232	08043V	PARTICIPANT	\N	PRESENT	0
158275	158273	01046T	PARTICIPANT	\N	PRESENT	0
158238	158232	14195A	PARTICIPANT	\N	PRESENT	0
158239	158232	11031D	PARTICIPANT	\N	PRESENT	0
158276	158273	04053F	PARTICIPANT	\N	PRESENT	0
158241	158232	14041T	PARTICIPANT	\N	PRESENT	0
158242	158232	14217N	PARTICIPANT	\N	PRESENT	0
158243	158232	87003B	PARTICIPANT	\N	PRESENT	0
158244	158232	11061K	PARTICIPANT	\N	PRESENT	0
158245	158232	14213J	PARTICIPANT	\N	EXCUSE	0
158277	158273	14255U	PARTICIPANT	\N	PRESENT	0
158278	158273	00003C	PARTICIPANT	\N	EXCUSE	0
158248	158232	14147R	PARTICIPANT	\N	EXCUSE	0
158279	158273	14053L	PARTICIPANT	\N	PRESENT	0
158250	158232	04092N	PRESIDENT	0	PRESENT	0
158251	158232	14265W	PARTICIPANT	\N	PRESENT	0
158252	158232	14028W	PARTICIPANT	\N	PRESENT	0
158253	158232	14235Q	PARTICIPANT	\N	PRESENT	0
158254	158232	14331P	PARTICIPANT	\N	EXCUSE	0
158280	158273	11103C	PARTICIPANT	\N	PRESENT	0
158281	158273	14195A	PARTICIPANT	\N	PRESENT	0
158257	158232	04045F	PARTICIPANT	\N	PRESENT	0
158258	158232	11094U	PRESIDENT	1	PRESENT	0
158282	158273	14267Y	PARTICIPANT	\N	PRESENT	0
158283	158273	11023D	PARTICIPANT	\N	EXCUSE	0
158284	158273	08052W	PARTICIPANT	\N	PRESENT	0
158285	158273	98024R	PARTICIPANT	\N	PRESENT	0
158286	158273	10006L	PARTICIPANT	\N	PRESENT	0
158287	158273	04067M	PARTICIPANT	\N	PRESENT	0
158288	158273	14042U	PARTICIPANT	\N	PRESENT	0
158289	158273	14151M	PARTICIPANT	\N	PRESENT	0
158290	158273	12042Y	PARTICIPANT	\N	PRESENT	0
158291	158273	14281W	PARTICIPANT	\N	PRESENT	0
158292	158273	14231L	PARTICIPANT	\N	PRESENT	0
158293	158273	11061K	PARTICIPANT	\N	PRESENT	0
158294	158273	08041T	PARTICIPANT	\N	EXCUSE	0
158295	158273	01011G	PARTICIPANT	\N	PRESENT	0
158296	158273	14213J	PARTICIPANT	\N	PRESENT	0
158297	158273	14037X	PARTICIPANT	\N	PRESENT	0
158298	158273	11067R	PARTICIPANT	\N	PRESENT	0
158299	158273	14223L	PARTICIPANT	\N	PRESENT	0
158300	158273	04092N	PRESIDENT	0	PRESENT	0
158301	158273	14265W	PARTICIPANT	\N	PRESENT	0
158302	158273	14119M	PARTICIPANT	\N	PRESENT	0
158303	158273	14071N	PARTICIPANT	\N	PRESENT	0
158304	158273	04043D	PARTICIPANT	\N	PRESENT	0
158305	158273	11093T	PARTICIPANT	\N	PRESENT	0
158306	158273	11097X	PARTICIPANT	\N	PRESENT	0
158307	158273	04045F	PARTICIPANT	\N	PRESENT	0
158308	158273	14227Q	PARTICIPANT	\N	PRESENT	0
158309	158273	01034P	PARTICIPANT	\N	PRESENT	0
158310	158273	14269B	PARTICIPANT	\N	PRESENT	0
158315	158314	96004D	PRESIDENT	0	PRESENT	0
158316	158314	04040A	PARTICIPANT	\N	PRESENT	0
158317	158314	04042C	PARTICIPANT	\N	EXCUSE	0
158318	158314	04035D	PARTICIPANT	\N	PRESENT	0
158319	158314	14097Y	PARTICIPANT	\N	PRESENT	0
158320	158314	04061F	PARTICIPANT	\N	PRESENT	0
158321	158314	14001X	PARTICIPANT	\N	PRESENT	0
158322	158314	83042R	PRESIDENT	1	PRESENT	0
158323	158314	98035U	PARTICIPANT	\N	PRESENT	0
158324	158314	95059Q	PARTICIPANT	\N	EXCUSE	0
128417	119836	08052W	PARTICIPANT	\N	PRESENT	0
128418	119836	11093T	PARTICIPANT	\N	PRESENT	0
137457	136743	11014C	PARTICIPANT	\N	PRESENT	0
137458	136743	04043D	PARTICIPANT	\N	PRESENT	0
137460	136743	11036J	PARTICIPANT	\N	PRESENT	0
137463	136743	99004R	PARTICIPANT	\N	PRESENT	0
137464	136743	14173T	PARTICIPANT	\N	PRESENT	0
137465	136743	04080J	PARTICIPANT	\N	PRESENT	0
137466	136743	14271U	PARTICIPANT	\N	PRESENT	0
137477	136743	80013X	PARTICIPANT	\N	PRESENT	0
137468	136743	95015C	PARTICIPANT	\N	PRESENT	0
137469	136743	11011M	PARTICIPANT	\N	PRESENT	0
137470	136743	11061K	PARTICIPANT	\N	PRESENT	0
137471	136743	95035G	PARTICIPANT	\N	PRESENT	0
137472	136743	11066Q	PARTICIPANT	\N	PRESENT	0
137473	136743	14197C	PARTICIPANT	\N	PRESENT	0
137474	136743	11048N	PARTICIPANT	\N	PRESENT	0
137478	136743	14123H	PARTICIPANT	\N	PRESENT	0
137482	136743	14069U	PARTICIPANT	\N	PRESENT	0
137483	136743	11012A	PARTICIPANT	\N	PRESENT	0
137484	136743	14121F	PARTICIPANT	\N	PRESENT	0
137486	136743	14105F	PARTICIPANT	\N	PRESENT	0
137487	136743	11053K	PARTICIPANT	\N	PRESENT	0
137488	136743	11042G	PARTICIPANT	\N	PRESENT	0
137489	136743	04057K	PARTICIPANT	\N	PRESENT	0
137490	136743	04067M	PARTICIPANT	\N	PRESENT	0
137491	136743	14257W	PARTICIPANT	\N	PRESENT	0
137492	136743	14013P	PARTICIPANT	\N	PRESENT	0
137493	136743	11010L	PARTICIPANT	\N	PRESENT	0
137494	136743	11057P	PARTICIPANT	\N	PRESENT	0
137495	136743	14231L	PARTICIPANT	\N	PRESENT	0
137496	136743	14109K	PARTICIPANT	\N	PRESENT	0
137455	136743	11083R	PARTICIPANT	\N	PRESENT	0
137456	136743	08061X	PARTICIPANT	\N	PRESENT	0
137497	136743	01031L	PARTICIPANT	\N	PRESENT	0
137516	136743	11095V	PARTICIPANT	\N	PRESENT	0
137520	136743	95063L	PARTICIPANT	\N	PRESENT	0
137560	136743	04033B	PARTICIPANT	\N	PRESENT	0
137561	136743	14217N	PARTICIPANT	\N	PRESENT	0
137562	136743	14097Y	PARTICIPANT	\N	PRESENT	0
137563	136743	12041X	PARTICIPANT	\N	PRESENT	0
137564	136743	95030B	PARTICIPANT	\N	PRESENT	0
137565	136743	07029T	PARTICIPANT	\N	PRESENT	0
137573	136743	14089Y	PARTICIPANT	\N	PRESENT	0
137574	136743	14179A	PARTICIPANT	\N	PRESENT	0
137575	136743	08068F	PARTICIPANT	\N	PRESENT	0
137576	136743	14213J	PARTICIPANT	\N	PRESENT	0
137577	136743	04071H	PARTICIPANT	\N	PRESENT	0
137578	136743	08016S	PARTICIPANT	\N	PRESENT	0
137579	136743	04079R	PARTICIPANT	\N	PRESENT	0
137580	136743	04045F	PARTICIPANT	\N	PRESENT	0
137581	136743	04085P	PARTICIPANT	\N	PRESENT	0
137582	136743	14215L	PARTICIPANT	\N	PRESENT	0
137600	136743	08069G	PARTICIPANT	\N	PRESENT	0
137606	136743	01016M	PARTICIPANT	\N	PRESENT	0
137602	136743	11043H	PARTICIPANT	\N	PRESENT	0
137603	136743	08034U	PARTICIPANT	\N	PRESENT	0
137604	136743	92045V	PARTICIPANT	\N	PRESENT	0
137605	136743	14157T	PARTICIPANT	\N	PRESENT	0
137790	137789	11111C	PARTICIPANT	\N	PRESENT	0
141527	141072	11026G	PARTICIPANT	\N	PRESENT	0
137833	137569	14034U	PARTICIPANT	\N	EXCUSE	0
137834	137569	14071N	PARTICIPANT	\N	PRESENT	0
138722	137569	11048N	PARTICIPANT	\N	EXCUSE	0
139241	139240	10015M	PARTICIPANT	\N	PRESENT	0
141525	141072	14229S	PARTICIPANT	\N	PRESENT	0
139244	139242	08055A	PARTICIPANT	\N	PRESENT	0
139245	139242	14093U	PARTICIPANT	\N	PRESENT	0
139246	139242	14030Q	PARTICIPANT	\N	PRESENT	0
139247	139242	96004D	PARTICIPANT	\N	PRESENT	0
139248	139242	08060W	PARTICIPANT	\N	PRESENT	0
139249	139242	11095V	PARTICIPANT	\N	PRESENT	0
139250	139242	14038Y	PARTICIPANT	\N	PRESENT	0
139251	139242	11114F	PARTICIPANT	\N	PRESENT	0
139252	139242	98023Q	PARTICIPANT	\N	PRESENT	0
141526	141072	11046L	PARTICIPANT	\N	PRESENT	0
139254	139242	01015L	PARTICIPANT	\N	PRESENT	0
139255	139242	11107G	PARTICIPANT	\N	EXCUSE	0
139256	139242	11020A	PARTICIPANT	\N	EXCUSE	0
139257	139242	02002K	PARTICIPANT	\N	EXCUSE	0
139258	139242	01022K	PARTICIPANT	\N	PRESENT	0
139259	139242	04097T	PARTICIPANT	\N	EXCUSE	0
139260	139242	09001P	PARTICIPANT	\N	PRESENT	0
139261	139242	11059R	PARTICIPANT	\N	PRESENT	0
139262	139242	14219Q	PARTICIPANT	\N	PRESENT	0
139263	139242	80027E	PARTICIPANT	\N	PRESENT	0
139264	139242	14031R	PARTICIPANT	\N	PRESENT	0
139265	139242	08009T	PARTICIPANT	\N	EXCUSE	0
139266	139242	08062Y	PARTICIPANT	\N	PRESENT	0
139267	139242	14221J	PARTICIPANT	\N	PRESENT	0
139268	139242	92039X	PARTICIPANT	\N	PRESENT	0
139269	139242	08042U	PARTICIPANT	\N	EXCUSE	0
139270	139242	14169X	PARTICIPANT	\N	PRESENT	0
139271	139242	14237S	PARTICIPANT	\N	PRESENT	0
139272	139242	13002U	PARTICIPANT	\N	PRESENT	0
139273	139242	05012A	PRESIDENT	0	PRESENT	0
141528	141072	01047U	PARTICIPANT	\N	PRESENT	0
139275	139242	14135M	PARTICIPANT	\N	PRESENT	0
139276	139242	14331P	PARTICIPANT	\N	PRESENT	0
139277	139242	95062K	PARTICIPANT	\N	EXCUSE	0
139278	139242	14107H	PARTICIPANT	\N	PRESENT	0
139279	139242	14051J	PARTICIPANT	\N	EXCUSE	0
139280	139242	14157T	PARTICIPANT	\N	PRESENT	0
139293	139290	08055A	PARTICIPANT	\N	PRESENT	0
139294	139290	14093U	PARTICIPANT	\N	PRESENT	0
139295	139290	14030Q	PARTICIPANT	\N	PRESENT	0
139296	139290	96004D	PARTICIPANT	\N	PRESENT	0
139297	139290	08060W	PARTICIPANT	\N	PRESENT	0
139298	139290	11095V	PARTICIPANT	\N	PRESENT	0
139299	139290	14038Y	PARTICIPANT	\N	PRESENT	0
139300	139290	11114F	PARTICIPANT	\N	PRESENT	0
139301	139290	98023Q	PARTICIPANT	\N	PRESENT	0
141529	141072	14055N	PARTICIPANT	\N	PRESENT	0
139303	139290	01015L	PARTICIPANT	\N	PRESENT	0
139304	139290	11107G	PARTICIPANT	\N	EXCUSE	0
139305	139290	11020A	PARTICIPANT	\N	EXCUSE	0
139306	139290	02002K	PARTICIPANT	\N	EXCUSE	0
139307	139290	01022K	PARTICIPANT	\N	PRESENT	0
139308	139290	04097T	PARTICIPANT	\N	PRESENT	0
139309	139290	09001P	PARTICIPANT	\N	PRESENT	0
139310	139290	11059R	PARTICIPANT	\N	PRESENT	0
139311	139290	14219Q	PARTICIPANT	\N	PRESENT	0
139312	139290	80027E	PARTICIPANT	\N	PRESENT	0
139313	139290	14031R	PARTICIPANT	\N	PRESENT	0
139314	139290	08009T	PARTICIPANT	\N	EXCUSE	0
139315	139290	08062Y	PARTICIPANT	\N	PRESENT	0
139316	139290	14221J	PARTICIPANT	\N	PRESENT	0
139317	139290	92039X	PARTICIPANT	\N	PRESENT	0
139318	139290	08042U	PARTICIPANT	\N	EXCUSE	0
139319	139290	14169X	PARTICIPANT	\N	PRESENT	0
139320	139290	14237S	PARTICIPANT	\N	PRESENT	0
139321	139290	13002U	PARTICIPANT	\N	PRESENT	0
139322	139290	05012A	PARTICIPANT	\N	PRESENT	0
141530	141072	01015L	PARTICIPANT	\N	PRESENT	0
139324	139290	14135M	PARTICIPANT	\N	PRESENT	0
139325	139290	14331P	PARTICIPANT	\N	PRESENT	0
139326	139290	95062K	PARTICIPANT	\N	EXCUSE	0
139327	139290	14107H	PARTICIPANT	\N	PRESENT	0
139328	139290	14051J	PARTICIPANT	\N	EXCUSE	0
139329	139290	14157T	PARTICIPANT	\N	PRESENT	0
141531	141072	11056N	PARTICIPANT	\N	PRESENT	0
141532	141072	08009T	PARTICIPANT	\N	PRESENT	0
141533	141072	92044U	PARTICIPANT	\N	PRESENT	0
141534	141072	14053L	PARTICIPANT	\N	PRESENT	0
141535	141072	11077T	PARTICIPANT	\N	PRESENT	0
141536	141072	14251Q	PARTICIPANT	\N	PRESENT	0
141537	141072	14195A	PARTICIPANT	\N	PRESENT	0
141538	141072	95067Q	PARTICIPANT	\N	PRESENT	0
141539	141072	14199E	PARTICIPANT	\N	PRESENT	0
141540	141072	08048B	PARTICIPANT	\N	PRESENT	0
141541	141072	01031L	PARTICIPANT	\N	PRESENT	0
141542	141072	14173T	PARTICIPANT	\N	PRESENT	0
141543	141072	11037K	PARTICIPANT	\N	PRESENT	0
141544	141072	04059M	PARTICIPANT	\N	PRESENT	0
141545	141072	04070G	PARTICIPANT	\N	PRESENT	0
141549	141072	08069G	PARTICIPANT	\N	PRESENT	0
141547	141072	14123H	PARTICIPANT	\N	PRESENT	0
141551	141072	11082Q	PARTICIPANT	\N	PRESENT	0
141550	141072	14275Y	PARTICIPANT	\N	PRESENT	0
141552	141072	83047W	PARTICIPANT	\N	PRESENT	0
141554	141072	14038Y	PARTICIPANT	\N	PRESENT	0
141557	141072	14269B	PARTICIPANT	\N	PRESENT	0
141559	141072	11027H	PARTICIPANT	\N	PRESENT	0
141558	141072	11015D	PARTICIPANT	\N	PRESENT	0
141560	141072	01014K	PARTICIPANT	\N	PRESENT	0
141561	141072	80013X	PARTICIPANT	\N	PRESENT	0
141562	141072	11068S	PARTICIPANT	\N	PRESENT	0
141594	141072	01058X	PARTICIPANT	\N	PRESENT	0
149952	149912	14030Q	PARTICIPANT	\N	EXCUSE	0
149953	149912	11107G	PARTICIPANT	\N	EXCUSE	0
149915	149912	14093U	PARTICIPANT	\N	PRESENT	0
149954	149912	11020A	PARTICIPANT	\N	EXCUSE	0
149955	149912	09001P	PARTICIPANT	\N	EXCUSE	0
149956	149912	08062Y	PARTICIPANT	\N	EXCUSE	0
149957	149912	05012A	PARTICIPANT	\N	EXCUSE	0
149920	149912	14038Y	PARTICIPANT	\N	PRESENT	0
149921	149912	11114F	PARTICIPANT	\N	PRESENT	0
149958	149912	95062K	PARTICIPANT	\N	EXCUSE	0
149923	149912	11065P	PARTICIPANT	\N	PRESENT	0
149924	149912	01015L	PARTICIPANT	\N	PRESENT	0
149977	149976	01008M	PARTICIPANT	\N	PRESENT	0
150017	150016	01008M	PARTICIPANT	\N	PRESENT	0
149979	149976	11081P	PARTICIPANT	\N	PRESENT	0
149928	149912	01022K	PARTICIPANT	\N	PRESENT	0
154995	154972	14231L	PARTICIPANT	\N	PRESENT	0
150153	150152	14059S	PARTICIPANT	\N	PRESENT	0
150019	150016	11081P	PARTICIPANT	\N	PRESENT	0
154996	154972	14187A	PARTICIPANT	\N	PRESENT	0
149933	149912	14219Q	PARTICIPANT	\N	PRESENT	0
150021	150016	08068F	PARTICIPANT	\N	PRESENT	0
150022	150016	14207L	PARTICIPANT	\N	PRESENT	0
149936	149912	08009T	PRESIDENT	0	PRESENT	0
154997	154972	11104D	PARTICIPANT	\N	PRESENT	0
150024	150016	90003B	PARTICIPANT	\N	PRESENT	0
154998	154972	11066Q	PARTICIPANT	\N	PRESENT	0
150026	150016	80013X	PARTICIPANT	\N	PRESENT	0
154999	154972	11025F	PARTICIPANT	\N	PRESENT	0
149942	149912	14237S	PARTICIPANT	\N	PRESENT	0
155000	154972	11053K	PARTICIPANT	\N	PRESENT	0
155001	154972	04086Q	PARTICIPANT	\N	PRESENT	0
155002	154972	14215L	PARTICIPANT	\N	PRESENT	0
155003	154972	14081Q	PARTICIPANT	\N	PRESENT	0
149947	149912	14331P	PARTICIPANT	\N	PRESENT	0
149994	149976	14081Q	PARTICIPANT	\N	EXCUSE	0
149949	149912	14107H	PARTICIPANT	\N	PRESENT	0
149995	149976	11099A	PARTICIPANT	\N	EXCUSE	0
155004	154972	11100Y	PARTICIPANT	\N	PRESENT	0
155005	154972	95035G	PARTICIPANT	\N	PRESENT	0
150034	150016	14081Q	PARTICIPANT	\N	EXCUSE	0
155006	154972	11034G	PARTICIPANT	\N	PRESENT	0
150000	149976	11100Y	PRESIDENT	0	PRESENT	0
155007	154972	14041T	PARTICIPANT	\N	PRESENT	0
155008	154972	07029T	PARTICIPANT	\N	PRESENT	0
150003	149976	01043Q	PARTICIPANT	\N	EXCUSE	0
155009	154972	01028R	PARTICIPANT	\N	PRESENT	0
150039	150016	08015R	PARTICIPANT	\N	PRESENT	0
150040	150016	11100Y	PRESIDENT	0	PRESENT	0
155010	154972	11012A	PARTICIPANT	\N	PRESENT	0
150042	150016	11098Y	PARTICIPANT	\N	PRESENT	0
155011	154972	11088W	PARTICIPANT	\N	PRESENT	0
155012	154972	01027Q	PARTICIPANT	\N	PRESENT	0
155032	154972	11071M	PARTICIPANT	\N	PRESENT	0
154993	154972	04066L	PARTICIPANT	\N	PRESENT	0
154994	154972	14235Q	PARTICIPANT	\N	PRESENT	0
150014	149976	11094U	PARTICIPANT	\N	EXCUSE	0
155033	154972	14219Q	PARTICIPANT	\N	PRESENT	0
155034	154972	04085P	PARTICIPANT	\N	PRESENT	0
155035	154972	14269B	PARTICIPANT	\N	PRESENT	0
155052	154972	04041B	PARTICIPANT	\N	PRESENT	0
155053	154972	14241N	PARTICIPANT	\N	PRESENT	0
155072	154972	11011M	PARTICIPANT	\N	PRESENT	0
150053	150016	01058X	PARTICIPANT	\N	PRESENT	0
155073	154972	11036J	PARTICIPANT	\N	PRESENT	0
150055	150016	11066Q	PARTICIPANT	\N	PRESENT	0
155074	154972	01048V	PARTICIPANT	\N	PRESENT	0
155075	154972	95041E	PARTICIPANT	\N	PRESENT	0
155103	154972	04034C	PARTICIPANT	\N	PRESENT	0
155104	154972	11083R	PARTICIPANT	\N	PRESENT	0
155105	154972	08034U	PARTICIPANT	\N	PRESENT	0
155106	154972	14037X	PARTICIPANT	\N	PRESENT	0
155112	154972	98053W	PARTICIPANT	\N	PRESENT	0
155149	154973	11036J	PARTICIPANT	\N	PRESENT	0
155150	154973	11083R	PARTICIPANT	\N	PRESENT	0
155151	154973	95041E	PARTICIPANT	\N	PRESENT	0
155152	154973	04041B	PARTICIPANT	\N	PRESENT	0
155153	154973	11071M	PARTICIPANT	\N	PRESENT	0
155154	154973	14187A	PARTICIPANT	\N	PRESENT	0
155155	154973	08034U	PARTICIPANT	\N	PRESENT	0
155156	154973	11088W	PARTICIPANT	\N	PRESENT	0
155157	154973	04034C	PARTICIPANT	\N	PRESENT	0
155158	154973	01031L	PARTICIPANT	\N	PRESENT	0
155159	154973	14215L	PARTICIPANT	\N	PRESENT	0
155160	154973	01027Q	PARTICIPANT	\N	PRESENT	0
155161	154973	98053W	PARTICIPANT	\N	PRESENT	0
155162	154973	14235Q	PARTICIPANT	\N	PRESENT	0
155163	154973	14081Q	PARTICIPANT	\N	PRESENT	0
155164	154973	11012A	PARTICIPANT	\N	PRESENT	0
155172	154973	11053K	PARTICIPANT	\N	PRESENT	0
155173	154973	07029T	PARTICIPANT	\N	PRESENT	0
155174	154973	11066Q	PARTICIPANT	\N	PRESENT	0
155192	154973	04086Q	PARTICIPANT	\N	PRESENT	0
155193	154973	14231L	PARTICIPANT	\N	PRESENT	0
155212	154973	04071H	PARTICIPANT	\N	PRESENT	0
155232	155076	89029V	PARTICIPANT	\N	PRESENT	0
155233	155076	14197C	PARTICIPANT	\N	PRESENT	0
155294	155076	14221J	PARTICIPANT	\N	PRESENT	0
155235	155076	14038Y	PARTICIPANT	\N	PRESENT	0
155236	155076	14331P	PARTICIPANT	\N	PRESENT	0
155237	155076	14265W	PARTICIPANT	\N	PRESENT	0
155238	155076	92045V	PARTICIPANT	\N	PRESENT	0
155239	155076	01008M	PARTICIPANT	\N	PRESENT	0
155240	155076	14071N	PARTICIPANT	\N	PRESENT	0
155241	155076	14169X	PARTICIPANT	\N	PRESENT	0
155242	155076	14107H	PARTICIPANT	\N	PRESENT	0
155243	155076	14267Y	PARTICIPANT	\N	PRESENT	0
155147	154973	04066L	PARTICIPANT	\N	PRESENT	0
155148	154973	08011M	PARTICIPANT	\N	PRESENT	0
155244	155076	11066Q	PARTICIPANT	\N	PRESENT	0
155245	155076	14227Q	PARTICIPANT	\N	PRESENT	0
155246	155076	08017T	PARTICIPANT	\N	PRESENT	0
155247	155076	14053L	PARTICIPANT	\N	PRESENT	0
155248	155076	98053W	PARTICIPANT	\N	PRESENT	0
155249	155076	98042T	PARTICIPANT	\N	PRESENT	0
155250	155076	14097Y	PARTICIPANT	\N	PRESENT	0
155251	155076	11026G	PARTICIPANT	\N	PRESENT	0
155252	155076	14033T	PARTICIPANT	\N	PRESENT	0
155253	155076	04034C	PARTICIPANT	\N	PRESENT	0
155254	155076	01014K	PARTICIPANT	\N	PRESENT	0
155255	155076	14263U	PARTICIPANT	\N	PRESENT	0
155256	155076	01013J	PARTICIPANT	\N	PRESENT	0
155257	155076	14079W	PARTICIPANT	\N	PRESENT	0
155258	155076	14219Q	PARTICIPANT	\N	PRESENT	0
155259	155076	08015R	PARTICIPANT	\N	PRESENT	0
155272	155076	08016S	PARTICIPANT	\N	PRESENT	0
155292	155076	14041T	PARTICIPANT	\N	PRESENT	0
155293	155076	14223L	PARTICIPANT	\N	PRESENT	0
155295	155076	14179A	PARTICIPANT	\N	PRESENT	0
155296	155076	14037X	PARTICIPANT	\N	PRESENT	0
155432	155093	08055A	PARTICIPANT	\N	PRESENT	0
155433	155093	14263U	PARTICIPANT	\N	PRESENT	0
155434	155093	07026Q	PARTICIPANT	\N	PRESENT	0
155435	155093	04085P	PARTICIPANT	\N	PRESENT	0
155436	155093	14107H	PARTICIPANT	\N	PRESENT	0
155437	155093	14063N	PARTICIPANT	\N	PRESENT	0
155438	155093	14197C	PARTICIPANT	\N	PRESENT	0
155439	155093	11036J	PARTICIPANT	\N	PRESENT	0
155440	155093	11089X	PARTICIPANT	\N	PRESENT	0
155441	155093	08060W	PARTICIPANT	\N	PRESENT	0
155442	155093	14051J	PARTICIPANT	\N	PRESENT	0
155443	155093	14014Q	PARTICIPANT	\N	PRESENT	0
155444	155093	11066Q	PARTICIPANT	\N	PRESENT	0
155445	155093	04078Q	PARTICIPANT	\N	PRESENT	0
155446	155093	04067M	PARTICIPANT	\N	PRESENT	0
155447	155093	14261S	PARTICIPANT	\N	PRESENT	0
155448	155093	11053K	PARTICIPANT	\N	PRESENT	0
155449	155093	14219Q	PARTICIPANT	\N	PRESENT	0
155450	155093	14030Q	PARTICIPANT	\N	PRESENT	0
155451	155093	14013P	PARTICIPANT	\N	PRESENT	0
155452	155093	14026U	PARTICIPANT	\N	PRESENT	0
155453	155093	04047H	PARTICIPANT	\N	PRESENT	0
155454	155093	14215L	PARTICIPANT	\N	PRESENT	0
155455	155093	14237S	PARTICIPANT	\N	PRESENT	0
155456	155093	14187A	PARTICIPANT	\N	PRESENT	0
155457	155093	14223L	PARTICIPANT	\N	PRESENT	0
155458	155093	14147R	PARTICIPANT	\N	PRESENT	0
155459	155093	14073Q	PARTICIPANT	\N	PRESENT	0
155460	155093	14221J	PARTICIPANT	\N	PRESENT	0
155461	155093	05012A	PARTICIPANT	\N	PRESENT	0
155462	155093	04057K	PARTICIPANT	\N	PRESENT	0
155463	155093	90003B	PARTICIPANT	\N	PRESENT	0
155464	155093	04086Q	PARTICIPANT	\N	PRESENT	0
155465	155093	95062K	PARTICIPANT	\N	PRESENT	0
155466	155093	08039A	PARTICIPANT	\N	PRESENT	0
155467	155093	99004R	PARTICIPANT	\N	PRESENT	0
155468	155093	14031R	PARTICIPANT	\N	PRESENT	0
155469	155093	14119M	PARTICIPANT	\N	PRESENT	0
155470	155093	08069G	PARTICIPANT	\N	PRESENT	0
134274	134273	04047H	PARTICIPANT	\N	PRESENT	0
132995	132993	96004D	PARTICIPANT	\N	PRESENT	0
133701	133700	11076S	PARTICIPANT	\N	PRESENT	0
134279	134278	96004D	PRESIDENT	0	PRESENT	0
133703	133700	04040A	PARTICIPANT	\N	PRESENT	0
133704	133700	08058D	PARTICIPANT	\N	PRESENT	0
133705	133700	04042C	PARTICIPANT	\N	PRESENT	0
133706	133700	77002U	PARTICIPANT	\N	PRESENT	0
133766	133762	04040A	PARTICIPANT	\N	PRESENT	0
133708	133700	11080N	PARTICIPANT	\N	PRESENT	0
133709	133700	11027H	PARTICIPANT	\N	PRESENT	0
133710	133700	98018T	PARTICIPANT	\N	PRESENT	0
133711	133700	92018S	PARTICIPANT	\N	PRESENT	0
133712	133700	92020L	PARTICIPANT	\N	PRESENT	0
133713	133700	95030B	PARTICIPANT	\N	PRESENT	0
133767	133762	08058D	PARTICIPANT	\N	PRESENT	0
133715	133700	95031C	PARTICIPANT	\N	PRESENT	0
133768	133762	04042C	PARTICIPANT	\N	PRESENT	0
134280	134278	04040A	PARTICIPANT	\N	PRESENT	0
133718	133700	04035D	PARTICIPANT	\N	PRESENT	0
134281	134278	04042C	PRESIDENT	1	PRESENT	0
133720	133700	04095R	PARTICIPANT	\N	PRESENT	0
133721	133700	14014Q	PARTICIPANT	\N	PRESENT	0
133722	133700	11015D	PARTICIPANT	\N	EXCUSE	0
134282	134278	14014Q	PARTICIPANT	\N	PRESENT	0
133724	133700	95035G	PARTICIPANT	\N	PRESENT	0
133725	133700	08056B	PARTICIPANT	\N	PRESENT	0
133726	133700	14211G	PARTICIPANT	\N	PRESENT	0
133727	133700	98022P	PARTICIPANT	\N	PRESENT	0
133728	133700	11064N	PARTICIPANT	\N	PRESENT	0
133729	133700	95037J	PARTICIPANT	\N	PRESENT	0
133730	133700	04078Q	PARTICIPANT	\N	PRESENT	0
133731	133700	14097Y	PARTICIPANT	\N	PRESENT	0
133732	133700	95041E	PARTICIPANT	\N	PRESENT	0
133733	133700	04036E	PARTICIPANT	\N	PRESENT	0
133772	133762	11027H	PARTICIPANT	\N	PRESENT	0
133735	133700	04077P	PARTICIPANT	\N	PRESENT	0
133736	133700	98005N	PARTICIPANT	\N	PRESENT	0
133737	133700	92031P	PARTICIPANT	\N	PRESENT	0
133738	133700	11106F	PARTICIPANT	\N	PRESENT	0
133739	133700	14251Q	PARTICIPANT	\N	PRESENT	0
133740	133700	83042R	PARTICIPANT	\N	PRESENT	0
133741	133700	08053X	PARTICIPANT	\N	PRESENT	0
133742	133700	11082Q	PARTICIPANT	\N	PRESENT	0
133743	133700	11105E	PARTICIPANT	\N	PRESENT	0
133744	133700	14253S	PARTICIPANT	\N	PRESENT	0
133745	133700	08047A	PARTICIPANT	\N	PRESENT	0
133746	133700	14028W	PARTICIPANT	\N	PRESENT	0
133747	133700	14193X	PARTICIPANT	\N	PRESENT	0
133748	133700	98021N	PARTICIPANT	\N	EXCUSE	0
134283	134278	14097Y	PARTICIPANT	\N	PRESENT	0
133750	133700	95059Q	PRESIDENT	0	PRESENT	0
133751	133700	86044G	PARTICIPANT	\N	PRESENT	0
133752	133700	01014K	PARTICIPANT	\N	PRESENT	0
133753	133700	11054L	PARTICIPANT	\N	PRESENT	0
133754	133700	01056V	PARTICIPANT	\N	PRESENT	0
133755	133700	92044U	PARTICIPANT	\N	PRESENT	0
133756	133700	08049C	PARTICIPANT	\N	PRESENT	0
133757	133700	04050C	PARTICIPANT	\N	PRESENT	0
134284	134278	04061F	PARTICIPANT	\N	PRESENT	0
134285	134278	14073Q	PARTICIPANT	\N	PRESENT	0
133775	133762	92020L	PARTICIPANT	\N	PRESENT	0
133776	133762	95030B	PARTICIPANT	\N	PRESENT	0
134286	134278	14001X	PARTICIPANT	\N	PRESENT	0
134287	134278	83042R	PARTICIPANT	\N	PRESENT	0
134288	134278	04057K	PARTICIPANT	\N	PRESENT	0
134289	134278	04080J	PARTICIPANT	\N	PRESENT	0
134396	134395	01027Q	PARTICIPANT	\N	PRESENT	0
134397	134395	14028W	PARTICIPANT	\N	PRESENT	0
133783	133762	04095R	PARTICIPANT	\N	PRESENT	0
133784	133762	14014Q	PARTICIPANT	\N	PRESENT	0
133785	133762	11015D	PARTICIPANT	\N	EXCUSE	0
134399	134398	01027Q	PARTICIPANT	\N	PRESENT	0
133787	133762	95035G	PARTICIPANT	\N	PRESENT	0
133788	133762	08056B	PARTICIPANT	\N	PRESENT	0
134400	134398	14028W	PARTICIPANT	\N	PRESENT	0
134402	134401	01027Q	PARTICIPANT	\N	PRESENT	0
133791	133762	11064N	PARTICIPANT	\N	PRESENT	0
134403	134401	14028W	PARTICIPANT	\N	PRESENT	0
135389	135106	08044W	PARTICIPANT	\N	EXCUSE	0
133794	133762	14097Y	PARTICIPANT	\N	PRESENT	0
135448	135447	11068S	PARTICIPANT	\N	PRESENT	0
135451	135450	11068S	PARTICIPANT	\N	PRESENT	0
135735	135734	01027Q	PARTICIPANT	\N	PRESENT	0
135736	135734	14028W	PARTICIPANT	\N	PRESENT	0
133799	133762	98005N	PARTICIPANT	\N	PRESENT	0
133800	133762	92031P	PARTICIPANT	\N	PRESENT	0
133801	133762	11106F	PARTICIPANT	\N	PRESENT	0
133802	133762	14251Q	PARTICIPANT	\N	PRESENT	0
135738	135737	14028W	PARTICIPANT	\N	PRESENT	0
133804	133762	08053X	PARTICIPANT	\N	PRESENT	0
135739	135737	01027Q	PARTICIPANT	\N	PRESENT	0
133806	133762	11105E	PARTICIPANT	\N	PRESENT	0
136323	135575	04089T	PARTICIPANT	\N	PRESENT	0
136324	135575	11093T	PARTICIPANT	\N	PRESENT	0
133809	133762	14028W	PARTICIPANT	\N	PRESENT	0
133810	133762	14193X	PARTICIPANT	\N	PRESENT	0
133811	133762	98021N	PARTICIPANT	\N	EXCUSE	0
136325	135575	14231L	PARTICIPANT	\N	PRESENT	0
133813	133762	95059Q	PRESIDENT	0	PRESENT	0
133814	133762	86044G	PARTICIPANT	\N	PRESENT	0
133815	133762	01014K	PARTICIPANT	\N	PRESENT	0
136326	135575	14083S	PARTICIPANT	\N	PRESENT	0
136327	135575	14089Y	PARTICIPANT	\N	PRESENT	0
136328	135575	11111C	PARTICIPANT	\N	PRESENT	0
136329	135575	11082Q	PARTICIPANT	\N	PRESENT	0
133820	133762	04050C	PARTICIPANT	\N	PRESENT	0
136330	135575	14277B	PARTICIPANT	\N	PRESENT	0
136331	135575	14235Q	PARTICIPANT	\N	PRESENT	0
136332	135575	11063M	PARTICIPANT	\N	PRESENT	0
136333	135575	14191V	PARTICIPANT	\N	PRESENT	0
136339	135575	01043Q	PARTICIPANT	\N	PRESENT	0
136335	135575	04061F	PARTICIPANT	\N	PRESENT	0
136336	135575	14038Y	PARTICIPANT	\N	PRESENT	0
136342	135575	14327T	PARTICIPANT	\N	PRESENT	0
136345	135575	08009T	PARTICIPANT	\N	PRESENT	0
136350	135575	01024M	PARTICIPANT	\N	PRESENT	0
136352	135575	89017R	PARTICIPANT	\N	PRESENT	0
136353	135575	11044J	PARTICIPANT	\N	PRESENT	0
136354	135575	14119M	PARTICIPANT	\N	PRESENT	0
136355	135575	14065Q	PARTICIPANT	\N	PRESENT	0
136356	135575	01041N	PARTICIPANT	\N	PRESENT	0
136369	135575	05004A	PARTICIPANT	\N	PRESENT	0
136370	135575	11068S	PARTICIPANT	\N	PRESENT	0
141112	141034	04040A	PRESIDENT	0	PRESENT	0
141113	141034	14063N	PARTICIPANT	\N	PRESENT	0
143933	143932	01008M	PARTICIPANT	\N	PRESENT	0
143934	143932	11036J	PARTICIPANT	\N	PRESENT	0
143972	143932	14261S	PARTICIPANT	\N	PRESENT	0
143973	143932	08055A	PARTICIPANT	\N	PRESENT	0
143937	143932	08068F	PARTICIPANT	\N	PRESENT	0
143938	143932	14207L	PARTICIPANT	\N	PRESENT	0
143974	143932	14093U	PARTICIPANT	\N	PRESENT	0
143940	143932	90003B	PARTICIPANT	\N	PRESENT	0
143975	143932	11114F	PARTICIPANT	\N	PRESENT	0
143976	143932	11065P	PARTICIPANT	\N	PRESENT	0
143943	143932	08038Y	PARTICIPANT	\N	PRESENT	0
143977	143932	01015L	PARTICIPANT	\N	PRESENT	0
143978	143932	02002K	PARTICIPANT	\N	PRESENT	0
143979	143932	01022K	PARTICIPANT	\N	PRESENT	0
143980	143932	14219Q	PARTICIPANT	\N	PRESENT	0
143948	143932	14033T	PARTICIPANT	\N	PRESENT	0
143981	143932	80027E	PARTICIPANT	\N	PRESENT	0
143950	143932	04048J	PARTICIPANT	\N	EXCUSE	0
143982	143932	14031R	PARTICIPANT	\N	PRESENT	0
143983	143932	08009T	PARTICIPANT	\N	PRESENT	0
143984	143932	92039X	PARTICIPANT	\N	PRESENT	0
143985	143932	08042U	PARTICIPANT	\N	PRESENT	0
143986	143932	14157T	PARTICIPANT	\N	PRESENT	0
143956	143932	11100Y	PRESIDENT	0	PRESENT	0
143957	143932	01061S	PARTICIPANT	\N	EXCUSE	0
143988	143987	14261S	PARTICIPANT	\N	PRESENT	0
143989	143987	08055A	PARTICIPANT	\N	PRESENT	0
143990	143987	14093U	PARTICIPANT	\N	PRESENT	0
143991	143987	14030Q	PARTICIPANT	\N	EXCUSE	0
144027	143987	01008M	PARTICIPANT	\N	PRESENT	0
143963	143932	14257W	PARTICIPANT	\N	PRESENT	0
144028	143987	11036J	PARTICIPANT	\N	PRESENT	0
143994	143987	11095V	PARTICIPANT	\N	EXCUSE	0
143966	143932	98050T	PARTICIPANT	\N	PRESENT	0
144029	143987	08068F	PARTICIPANT	\N	PRESENT	0
143968	143932	11046L	PARTICIPANT	\N	PRESENT	0
143969	143932	01058X	PARTICIPANT	\N	PRESENT	0
143970	143932	11094U	PARTICIPANT	\N	PRESENT	0
143971	143932	11066Q	PARTICIPANT	\N	PRESENT	0
143996	143987	11114F	PARTICIPANT	\N	PRESENT	0
144030	143987	14207L	PARTICIPANT	\N	PRESENT	0
143998	143987	11065P	PARTICIPANT	\N	PRESENT	0
143999	143987	01015L	PARTICIPANT	\N	PRESENT	0
144000	143987	11107G	PARTICIPANT	\N	EXCUSE	0
144031	143987	90003B	PARTICIPANT	\N	PRESENT	0
144002	143987	02002K	PARTICIPANT	\N	PRESENT	0
144003	143987	01022K	PARTICIPANT	\N	PRESENT	0
144032	143987	08038Y	PARTICIPANT	\N	PRESENT	0
144033	143987	14033T	PARTICIPANT	\N	PRESENT	0
144034	143987	11100Y	PARTICIPANT	\N	PRESENT	0
144035	143987	14257W	PARTICIPANT	\N	PRESENT	0
144008	143987	14219Q	PARTICIPANT	\N	PRESENT	0
144009	143987	80027E	PARTICIPANT	\N	PRESENT	0
144010	143987	14031R	PARTICIPANT	\N	PRESENT	0
144011	143987	08009T	PRESIDENT	0	PRESENT	0
144036	143987	98050T	PARTICIPANT	\N	PRESENT	0
144040	143987	11094U	PARTICIPANT	\N	PRESENT	0
144014	143987	92039X	PARTICIPANT	\N	PRESENT	0
144015	143987	08042U	PARTICIPANT	\N	PRESENT	0
144038	143987	11046L	PARTICIPANT	\N	PRESENT	0
144039	143987	01058X	PARTICIPANT	\N	PRESENT	0
144041	143987	11066Q	PARTICIPANT	\N	PRESENT	0
144019	143987	05012A	PARTICIPANT	\N	EXCUSE	0
157393	157392	04043D	PARTICIPANT	\N	PRESENT	0
157677	157674	14263U	PARTICIPANT	\N	PRESENT	0
157740	157674	89029V	PARTICIPANT	\N	EXCUSE	0
157741	157674	14109K	PARTICIPANT	\N	PRESENT	0
157680	157674	04059M	PARTICIPANT	\N	PRESENT	0
159413	159412	01008M	PARTICIPANT	\N	PRESENT	0
144026	143987	14157T	PARTICIPANT	\N	PRESENT	0
157682	157674	01044R	PARTICIPANT	\N	PRESENT	0
157683	157674	08043V	PARTICIPANT	\N	EXCUSE	0
157684	157674	14089Y	PARTICIPANT	\N	PRESENT	0
157685	157674	14105F	PARTICIPANT	\N	PRESENT	0
157686	157674	11029K	PARTICIPANT	\N	EXCUSE	0
157687	157674	95015C	PARTICIPANT	\N	PRESENT	0
157688	157674	92015P	PARTICIPANT	\N	EXCUSE	0
159414	159412	14089Y	PARTICIPANT	\N	PRESENT	0
157690	157674	14201E	PARTICIPANT	\N	PRESENT	0
157691	157674	14329V	PARTICIPANT	\N	PRESENT	0
159415	159412	14079W	PARTICIPANT	\N	PRESENT	0
159416	159412	98018T	PARTICIPANT	\N	PRESENT	0
157694	157674	11091R	PARTICIPANT	\N	EXCUSE	0
157695	157674	87003B	PARTICIPANT	\N	PRESENT	0
159417	159412	08034U	PARTICIPANT	\N	PRESENT	0
159418	159412	01015L	PARTICIPANT	\N	PRESENT	0
157698	157674	01041N	PARTICIPANT	\N	EXCUSE	0
157699	157674	01025N	PARTICIPANT	\N	EXCUSE	0
159419	159412	97011G	PARTICIPANT	\N	PRESENT	0
159420	159412	08015R	PARTICIPANT	\N	PRESENT	0
159421	159412	14037X	PARTICIPANT	\N	PRESENT	0
157703	157674	07026Q	PARTICIPANT	\N	PRESENT	0
159422	159412	04070G	PARTICIPANT	\N	PRESENT	0
157705	157674	14179A	PARTICIPANT	\N	PRESENT	0
157706	157674	04041B	PARTICIPANT	\N	PRESENT	0
157707	157674	14241N	PARTICIPANT	\N	PRESENT	0
157708	157674	14061L	PARTICIPANT	\N	PRESENT	0
157709	157674	14073Q	PARTICIPANT	\N	PRESENT	0
157710	157674	08031R	PARTICIPANT	\N	PRESENT	0
157711	157674	12041X	PARTICIPANT	\N	PRESENT	0
157712	157674	08039A	PARTICIPANT	\N	PRESENT	0
157713	157674	08017T	PARTICIPANT	\N	PRESENT	0
157714	157674	14059S	PARTICIPANT	\N	PRESENT	0
157715	157674	08012N	PARTICIPANT	\N	PRESENT	0
157716	157674	14103D	PARTICIPANT	\N	PRESENT	0
157717	157674	11104D	PARTICIPANT	\N	PRESENT	0
157718	157674	14063N	PARTICIPANT	\N	EXCUSE	0
159423	159412	14071N	PARTICIPANT	\N	PRESENT	0
159424	159412	95062K	PARTICIPANT	\N	PRESENT	0
159425	159412	95067Q	PARTICIPANT	\N	PRESENT	0
157722	157674	04070G	PRESIDENT	0	PRESENT	0
159426	159412	04040A	PARTICIPANT	\N	PRESENT	0
159427	159412	14179A	PARTICIPANT	\N	PRESENT	0
157725	157674	83047W	PARTICIPANT	\N	EXCUSE	0
157726	157674	14235Q	PARTICIPANT	\N	PRESENT	0
159439	159438	14133K	PARTICIPANT	\N	PRESENT	0
157728	157674	04033B	PARTICIPANT	\N	PRESENT	0
157729	157674	14229S	PARTICIPANT	\N	PRESENT	0
157730	157674	11043H	PARTICIPANT	\N	PRESENT	0
159440	159438	96004D	PRESIDENT	0	PRESENT	0
157732	157674	11011M	PARTICIPANT	\N	PRESENT	0
159441	159438	14089Y	PARTICIPANT	\N	PRESENT	0
159442	159438	11040E	PARTICIPANT	\N	PRESENT	0
159443	159438	90003B	PARTICIPANT	\N	EXCUSE	0
159444	159438	14079W	PARTICIPANT	\N	PRESENT	0
159445	159438	11035H	PARTICIPANT	\N	EXCUSE	0
159446	159438	14249W	PARTICIPANT	\N	PRESENT	0
159447	159438	11083R	PARTICIPANT	\N	PRESENT	0
159448	159438	08044W	PARTICIPANT	\N	EXCUSE	0
159449	159438	14097Y	PARTICIPANT	\N	PRESENT	0
159450	159438	04061F	PARTICIPANT	\N	PRESENT	0
159451	159438	14073Q	PARTICIPANT	\N	PRESENT	0
159452	159438	14001X	PARTICIPANT	\N	PRESENT	0
159453	159438	08042U	PARTICIPANT	\N	EXCUSE	0
159454	159438	14135M	PARTICIPANT	\N	PRESENT	0
159455	159438	01016M	PARTICIPANT	\N	PRESENT	0
159456	159438	10015M	PARTICIPANT	\N	PRESENT	0
159457	159438	95063L	PARTICIPANT	\N	PRESENT	0
159458	159438	04045F	PARTICIPANT	\N	PRESENT	0
159459	159438	98035U	PARTICIPANT	\N	PRESENT	0
159460	159438	92045V	PARTICIPANT	\N	PRESENT	0
159472	158973	01031L	PARTICIPANT	\N	PRESENT	0
128944	128943	89017R	PARTICIPANT	\N	PRESENT	0
128945	128943	01031L	PRESIDENT	0	PRESENT	0
128946	128943	05004A	PARTICIPANT	\N	PRESENT	0
128947	128943	01013J	PARTICIPANT	\N	PRESENT	0
128993	128943	08012N	RAPPORTEUR_AVIS	\N	PRESENT	0
128949	128943	11040E	PARTICIPANT	\N	PRESENT	0
128950	128943	08014Q	PARTICIPANT	\N	PRESENT	0
128951	128943	14167V	PARTICIPANT	\N	PRESENT	0
128952	128943	14175V	PARTICIPANT	\N	PRESENT	0
128953	128943	14083S	PARTICIPANT	\N	PRESENT	0
128954	128943	11053K	PARTICIPANT	\N	PRESENT	0
128955	128943	14085U	PARTICIPANT	\N	PRESENT	0
128956	128943	11042G	PARTICIPANT	\N	PRESENT	0
128994	128943	11104D	RAPPORTEUR_AVIS	\N	PRESENT	0
128958	128943	04086Q	PARTICIPANT	\N	PRESENT	0
128959	128943	04055H	PARTICIPANT	\N	PRESENT	0
128995	128943	14071N	RAPPORTEUR_AVIS	\N	PRESENT	0
128961	128943	11088W	PARTICIPANT	\N	PRESENT	0
128962	128943	14327T	PARTICIPANT	\N	PRESENT	0
128963	128943	08022Q	PARTICIPANT	\N	PRESENT	0
128964	128943	01027Q	PARTICIPANT	\N	PRESENT	0
128965	128943	04071H	PARTICIPANT	\N	PRESENT	0
129097	129095	14263U	PARTICIPANT	\N	PRESENT	0
128967	128943	98053W	PARTICIPANT	\N	EXCUSE	0
128968	128943	11083R	PARTICIPANT	\N	PRESENT	0
128969	128943	14199E	PARTICIPANT	\N	PRESENT	0
128970	128943	01057W	PARTICIPANT	\N	PRESENT	0
128971	128943	08016S	PARTICIPANT	\N	PRESENT	0
128972	128943	08069G	PARTICIPANT	\N	PRESENT	0
128973	128943	11048N	PARTICIPANT	\N	PRESENT	0
128974	128943	99004R	PARTICIPANT	\N	PRESENT	0
128975	128943	04061F	PARTICIPANT	\N	PRESENT	0
128976	128943	14159V	PARTICIPANT	\N	PRESENT	0
128977	128943	07029T	PARTICIPANT	\N	PRESENT	0
129098	129095	14133K	PARTICIPANT	\N	PRESENT	0
128979	128943	08010L	PARTICIPANT	\N	PRESENT	0
128980	128943	08034U	PARTICIPANT	\N	PRESENT	0
128981	128943	01048V	PARTICIPANT	\N	PRESENT	0
128982	128943	98046X	PARTICIPANT	\N	PRESENT	0
128983	128943	11085T	PARTICIPANT	\N	EXCUSE	0
128984	128943	08011M	PARTICIPANT	\N	EXCUSE	0
128985	128943	08073C	PARTICIPANT	\N	PRESENT	0
128986	128943	08061X	PARTICIPANT	\N	EXCUSE	0
128987	128943	01016M	PARTICIPANT	\N	PRESENT	0
130832	129541	11098Y	PARTICIPANT	\N	EXCUSE	0
128989	128943	11012A	PARTICIPANT	\N	PRESENT	0
128990	128943	11057P	PARTICIPANT	\N	PRESENT	0
128991	128943	14173T	PARTICIPANT	\N	PRESENT	0
128992	128943	04034C	PARTICIPANT	\N	PRESENT	0
129100	129095	04059M	PARTICIPANT	\N	PRESENT	0
129101	129095	11039M	PARTICIPANT	\N	PRESENT	0
129102	129095	01044R	PARTICIPANT	\N	PRESENT	0
129103	129095	08043V	PARTICIPANT	\N	PRESENT	0
129104	129095	14089Y	PARTICIPANT	\N	EXCUSE	0
129105	129095	14105F	PARTICIPANT	\N	PRESENT	0
129106	129095	11029K	PARTICIPANT	\N	PRESENT	0
129107	129095	95015C	PARTICIPANT	\N	PRESENT	0
129108	129095	92015P	PARTICIPANT	\N	EXCUSE	0
129109	129095	08024S	PARTICIPANT	\N	PRESENT	0
131033	131029	08025T	PARTICIPANT	\N	PRESENT	0
131034	131029	04085P	PARTICIPANT	\N	PRESENT	0
129112	129095	14209N	PARTICIPANT	\N	PRESENT	0
131035	131029	05008E	PRESIDENT	0	PRESENT	0
129114	129095	11091R	PARTICIPANT	\N	PRESENT	0
129115	129095	87003B	PARTICIPANT	\N	PRESENT	0
129116	129095	98042T	PARTICIPANT	\N	PRESENT	0
131036	131029	11030C	PARTICIPANT	\N	PRESENT	0
131037	131029	11033F	PARTICIPANT	\N	PRESENT	0
129119	129095	01025N	PARTICIPANT	\N	PRESENT	0
131038	131029	14065Q	PARTICIPANT	\N	PRESENT	0
129121	129095	89029V	PARTICIPANT	\N	PRESENT	0
131039	131029	14069U	PARTICIPANT	\N	PRESENT	0
129123	129095	11089X	PARTICIPANT	\N	PRESENT	0
129124	129095	07026Q	PARTICIPANT	\N	PRESENT	0
129125	129095	14123H	PARTICIPANT	\N	PRESENT	0
131040	131029	04047H	PARTICIPANT	\N	PRESENT	0
131041	131029	11032E	PARTICIPANT	\N	PRESENT	0
129128	129095	14241N	PARTICIPANT	\N	PRESENT	0
129129	129095	14061L	PARTICIPANT	\N	PRESENT	0
131042	131029	04038G	PARTICIPANT	\N	PRESENT	0
129131	129095	08031R	PARTICIPANT	\N	PRESENT	0
131043	131029	99002P	PARTICIPANT	\N	PRESENT	0
129133	129095	08039A	PARTICIPANT	\N	PRESENT	0
131044	131029	11056N	PARTICIPANT	\N	PRESENT	0
129135	129095	14059S	PARTICIPANT	\N	PRESENT	0
129136	129095	08012N	PARTICIPANT	\N	PRESENT	0
129137	129095	14103D	PARTICIPANT	\N	PRESENT	0
129138	129095	11104D	PARTICIPANT	\N	PRESENT	0
129139	129095	14063N	PARTICIPANT	\N	PRESENT	0
129140	129095	04057K	PARTICIPANT	\N	PRESENT	0
131045	131029	14259Y	PARTICIPANT	\N	PRESENT	0
131046	131029	11035H	PARTICIPANT	\N	PRESENT	0
129143	129095	04070G	PRESIDENT	0	PRESENT	0
129144	129095	92040Q	PARTICIPANT	\N	PRESENT	0
131047	131029	14041T	PARTICIPANT	\N	PRESENT	0
129146	129095	83047W	PARTICIPANT	\N	PRESENT	0
129147	129095	14235Q	PARTICIPANT	\N	PRESENT	0
131048	131029	11113E	PARTICIPANT	\N	PRESENT	0
129149	129095	04033B	PARTICIPANT	\N	PRESENT	0
129150	129095	14229S	PARTICIPANT	\N	PRESENT	0
129151	129095	11043H	PARTICIPANT	\N	PRESENT	0
131049	131029	01024M	PARTICIPANT	\N	PRESENT	0
129153	129095	11011M	PARTICIPANT	\N	PRESENT	0
131050	131029	14215L	PARTICIPANT	\N	PRESENT	0
131051	131029	11034G	PARTICIPANT	\N	PRESENT	0
131052	131029	08018U	PARTICIPANT	\N	PRESENT	0
131053	131029	01007L	PARTICIPANT	\N	PRESENT	0
131054	131029	11049P	PARTICIPANT	\N	PRESENT	0
131055	131029	08044W	PARTICIPANT	\N	EXCUSE	0
131056	131029	11026G	PARTICIPANT	\N	PRESENT	0
131057	131029	04079R	PARTICIPANT	\N	PRESENT	0
131058	131029	14111D	PARTICIPANT	\N	PRESENT	0
131059	131029	14147R	PARTICIPANT	\N	PRESENT	0
131060	131029	08051V	PARTICIPANT	\N	PRESENT	0
131061	131029	11072N	PARTICIPANT	\N	PRESENT	0
131062	131029	07034Q	PARTICIPANT	\N	PRESENT	0
131063	131029	04074L	PARTICIPANT	\N	PRESENT	0
131064	131029	95063L	PARTICIPANT	\N	PRESENT	0
131065	131029	01019Q	PARTICIPANT	\N	PRESENT	0
131066	131029	01028R	PARTICIPANT	\N	PRESENT	0
131067	131029	14275Y	PARTICIPANT	\N	PRESENT	0
131068	131029	04044E	PARTICIPANT	\N	PRESENT	0
131069	131029	11037K	PARTICIPANT	\N	PRESENT	0
131070	131029	92045V	PARTICIPANT	\N	PRESENT	0
131071	131029	95067Q	PARTICIPANT	\N	PRESENT	0
131072	131029	01047U	PARTICIPANT	\N	PRESENT	0
131073	131029	14033T	PARTICIPANT	\N	PRESENT	0
133039	133038	01024M	PARTICIPANT	\N	PRESENT	0
133041	133040	14111D	PARTICIPANT	\N	PRESENT	0
133043	133042	14111D	PARTICIPANT	\N	PRESENT	0
133125	132784	96003C	PARTICIPANT	\N	EXCUSE	0
133241	132784	14017T	PARTICIPANT	\N	EXCUSE	0
133372	133371	89017R	PARTICIPANT	\N	EXCUSE	0
133373	133371	01031L	PRESIDENT	0	PRESENT	0
133375	133371	01013J	PARTICIPANT	\N	PRESENT	0
133378	133371	08014Q	PARTICIPANT	\N	PRESENT	0
133380	133371	14175V	PARTICIPANT	\N	PRESENT	0
133382	133371	11053K	PARTICIPANT	\N	PRESENT	0
133383	133371	14085U	PARTICIPANT	\N	PRESENT	0
133384	133371	11042G	PARTICIPANT	\N	PRESENT	0
133385	133371	88008L	PARTICIPANT	\N	PRESENT	0
133386	133371	04086Q	PARTICIPANT	\N	PRESENT	0
133388	133371	11070L	PARTICIPANT	\N	PRESENT	0
133389	133371	11088W	PARTICIPANT	\N	PRESENT	0
133390	133371	14327T	PARTICIPANT	\N	PRESENT	0
133391	133371	08022Q	PARTICIPANT	\N	PRESENT	0
133392	133371	01027Q	PARTICIPANT	\N	PRESENT	0
133393	133371	04071H	PARTICIPANT	\N	PRESENT	0
133394	133371	11074Q	PARTICIPANT	\N	PRESENT	0
133395	133371	98053W	PARTICIPANT	\N	EXCUSE	0
133397	133371	14199E	PARTICIPANT	\N	PRESENT	0
133398	133371	01057W	PARTICIPANT	\N	PRESENT	0
133399	133371	08016S	PARTICIPANT	\N	PRESENT	0
133400	133371	08069G	PARTICIPANT	\N	EXCUSE	0
133401	133371	11048N	PARTICIPANT	\N	PRESENT	0
133402	133371	99004R	PARTICIPANT	\N	PRESENT	0
133404	133371	14159V	PARTICIPANT	\N	PRESENT	0
133405	133371	07029T	PARTICIPANT	\N	PRESENT	0
133406	133371	14277B	PARTICIPANT	\N	PRESENT	0
133407	133371	08010L	PARTICIPANT	\N	PRESENT	0
145093	145092	89017R	PARTICIPANT	\N	PRESENT	0
145094	145092	01031L	PRESIDENT	0	PRESENT	0
145095	145092	01013J	PARTICIPANT	\N	PRESENT	0
145096	145092	14175V	PARTICIPANT	\N	PRESENT	0
145097	145092	14085U	PARTICIPANT	\N	PRESENT	0
145098	145092	11042G	PARTICIPANT	\N	PRESENT	0
145099	145092	04086Q	PARTICIPANT	\N	PRESENT	0
145100	145092	11088W	PARTICIPANT	\N	PRESENT	0
145101	145092	08022Q	PARTICIPANT	\N	PRESENT	0
145102	145092	11074Q	PARTICIPANT	\N	PRESENT	0
145103	145092	08069G	PARTICIPANT	\N	PRESENT	0
145104	145092	11048N	PARTICIPANT	\N	PRESENT	0
145105	145092	99004R	PARTICIPANT	\N	PRESENT	0
145106	145092	14159V	PARTICIPANT	\N	PRESENT	0
145107	145092	07029T	PARTICIPANT	\N	PRESENT	0
145108	145092	08010L	PARTICIPANT	\N	PRESENT	0
145109	145092	08034U	PARTICIPANT	\N	PRESENT	0
145110	145092	01048V	PARTICIPANT	\N	PRESENT	0
145111	145092	08011M	PARTICIPANT	\N	PRESENT	0
145112	145092	14225N	PARTICIPANT	\N	PRESENT	0
145113	145092	14173T	PARTICIPANT	\N	PRESENT	0
145114	145092	04034C	PARTICIPANT	\N	PRESENT	0
145115	145092	14327T	PARTICIPANT	\N	EXCUSE	0
145116	145092	98053W	PARTICIPANT	\N	EXCUSE	0
145117	145092	08061X	PARTICIPANT	\N	EXCUSE	0
145118	145092	11057P	PARTICIPANT	\N	EXCUSE	0
146972	146932	01008M	PARTICIPANT	\N	PRESENT	0
146934	146932	08055A	PARTICIPANT	\N	PRESENT	0
146973	146932	14327T	PARTICIPANT	\N	PRESENT	0
146936	146932	14030Q	PARTICIPANT	\N	EXCUSE	0
146974	146932	14179A	PARTICIPANT	\N	PRESENT	0
146975	146932	14265W	PARTICIPANT	\N	PRESENT	0
146939	146932	11095V	PARTICIPANT	\N	EXCUSE	0
146940	146932	14038Y	PARTICIPANT	\N	PRESENT	0
146976	146932	01031L	PARTICIPANT	\N	PRESENT	0
146942	146932	98023Q	PARTICIPANT	\N	PRESENT	0
146992	146932	14237S	PARTICIPANT	\N	EXCUSE	0
146944	146932	01015L	PARTICIPANT	\N	EXCUSE	0
146945	146932	11107G	PARTICIPANT	\N	EXCUSE	0
148641	148640	14030Q	PARTICIPANT	\N	PRESENT	0
148642	148640	11023D	PARTICIPANT	\N	PRESENT	0
148643	148640	01015L	PARTICIPANT	\N	PRESENT	0
148644	148640	14031R	PARTICIPANT	\N	PRESENT	0
148645	148640	92045V	PARTICIPANT	\N	PRESENT	0
148688	148687	96004D	PRESIDENT	0	PRESENT	0
148689	148687	04040A	PARTICIPANT	\N	PRESENT	0
146953	146932	14219Q	PARTICIPANT	\N	PRESENT	0
148690	148687	04042C	PARTICIPANT	\N	EXCUSE	0
146955	146932	14031R	PARTICIPANT	\N	PRESENT	0
146956	146932	08009T	PRESIDENT	0	PRESENT	0
146957	146932	08062Y	PARTICIPANT	\N	PRESENT	0
148691	148687	04035D	PARTICIPANT	\N	EXCUSE	0
148692	148687	07024N	PRESIDENT	1	PRESENT	0
148693	148687	14014Q	PARTICIPANT	\N	PRESENT	0
148694	148687	14097Y	PARTICIPANT	\N	PRESENT	0
148698	148687	04057K	PARTICIPANT	\N	PRESENT	0
146963	146932	13002U	PARTICIPANT	\N	PRESENT	0
146964	146932	05012A	PARTICIPANT	\N	PRESENT	0
148696	148687	04080J	PARTICIPANT	\N	PRESENT	0
146966	146932	14135M	PARTICIPANT	\N	PRESENT	0
148697	148687	95059Q	PARTICIPANT	\N	EXCUSE	0
149533	149532	04049K	PARTICIPANT	\N	PRESENT	0
146969	146932	14107H	PARTICIPANT	\N	PRESENT	0
149534	149532	14255U	PARTICIPANT	\N	PRESENT	0
146971	146932	14157T	PARTICIPANT	\N	PRESENT	0
155471	155093	11011M	PARTICIPANT	\N	PRESENT	0
155472	155093	04088S	PARTICIPANT	\N	PRESENT	0
155473	155093	11071M	PARTICIPANT	\N	PRESENT	0
155474	155093	07029T	PARTICIPANT	\N	PRESENT	0
155475	155093	14175V	PARTICIPANT	\N	PRESENT	0
155476	155093	97011G	PARTICIPANT	\N	PRESENT	0
155477	155093	11040E	PARTICIPANT	\N	PRESENT	0
155478	155093	14123H	PARTICIPANT	\N	PRESENT	0
155479	155093	01015L	PARTICIPANT	\N	PRESENT	0
155480	155093	14033T	PARTICIPANT	\N	PRESENT	0
155481	155093	04041B	PARTICIPANT	\N	PRESENT	0
155482	155093	08052W	PARTICIPANT	\N	PRESENT	0
155483	155093	08042U	PARTICIPANT	\N	PRESENT	0
155518	155093	11104D	PARTICIPANT	\N	PRESENT	0
155519	155093	14159V	PARTICIPANT	\N	PRESENT	0
155520	155093	04053F	PARTICIPANT	\N	PRESENT	0
155521	155093	08010L	PARTICIPANT	\N	PRESENT	0
155522	155093	14179A	PARTICIPANT	\N	PRESENT	0
155523	155093	14061L	PARTICIPANT	\N	PRESENT	0
155524	155093	11103C	PARTICIPANT	\N	PRESENT	0
155525	155093	87003B	PARTICIPANT	\N	PRESENT	0
155526	155093	11097X	PARTICIPANT	\N	PRESENT	0
155527	155093	08047A	PARTICIPANT	\N	PRESENT	0
155528	155093	14041T	PARTICIPANT	\N	PRESENT	0
155529	155093	14157T	PARTICIPANT	\N	PRESENT	0
155530	155093	14105F	PARTICIPANT	\N	PRESENT	0
155531	155093	07034Q	PARTICIPANT	\N	PRESENT	0
155613	155094	87003B	PARTICIPANT	\N	PRESENT	0
155614	155094	14031R	PARTICIPANT	\N	PRESENT	0
155615	155094	11020A	PARTICIPANT	\N	PRESENT	0
155616	155094	04043D	PARTICIPANT	\N	PRESENT	0
155617	155094	14331P	PARTICIPANT	\N	PRESENT	0
155618	155094	90003B	PARTICIPANT	\N	PRESENT	0
155619	155094	11103C	PARTICIPANT	\N	PRESENT	0
155620	155094	11090Q	PARTICIPANT	\N	PRESENT	0
155621	155094	14038Y	PARTICIPANT	\N	PRESENT	0
155622	155094	04088S	PARTICIPANT	\N	PRESENT	0
155623	155094	08028W	PARTICIPANT	\N	PRESENT	0
155624	155094	98023Q	PARTICIPANT	\N	PRESENT	0
155625	155094	98024R	PARTICIPANT	\N	PRESENT	0
155626	155094	14147R	PARTICIPANT	\N	PRESENT	0
155627	155094	07034Q	PARTICIPANT	\N	PRESENT	0
155628	155094	04047H	PARTICIPANT	\N	PRESENT	0
155629	155094	95015C	PARTICIPANT	\N	PRESENT	0
155630	155094	14193X	PARTICIPANT	\N	PRESENT	0
155631	155094	14071N	PARTICIPANT	\N	PRESENT	0
155632	155094	14265W	PARTICIPANT	\N	PRESENT	0
155633	155094	77002U	PARTICIPANT	\N	PRESENT	0
155652	155094	04092N	PARTICIPANT	\N	PRESENT	0
155653	155094	89029V	PARTICIPANT	\N	PRESENT	0
155654	155094	11080N	PARTICIPANT	\N	PRESENT	0
155655	155094	14111D	PARTICIPANT	\N	PRESENT	0
155656	155094	99004R	PARTICIPANT	\N	PRESENT	0
155657	155094	14026U	PARTICIPANT	\N	PRESENT	0
155658	155094	04044E	PARTICIPANT	\N	PRESENT	0
155659	155094	11097X	PARTICIPANT	\N	PRESENT	0
155660	155094	04086Q	PARTICIPANT	\N	PRESENT	0
155661	155094	86044G	PARTICIPANT	\N	PRESENT	0
155662	155094	04049K	PARTICIPANT	\N	PRESENT	0
155663	155094	11027H	PARTICIPANT	\N	PRESENT	0
155664	155094	95041E	PARTICIPANT	\N	PRESENT	0
155665	155094	08016S	PARTICIPANT	\N	PRESENT	0
155666	155094	08069G	PARTICIPANT	\N	PRESENT	0
155667	155094	98046X	PARTICIPANT	\N	PRESENT	0
155668	155094	04081K	PARTICIPANT	\N	PRESENT	0
155669	155094	04056J	PARTICIPANT	\N	PRESENT	0
155670	155094	14217N	PARTICIPANT	\N	PRESENT	0
155671	155094	95063L	PARTICIPANT	\N	PRESENT	0
155672	155094	01027Q	PARTICIPANT	\N	PRESENT	0
155673	155094	11074Q	PARTICIPANT	\N	PRESENT	0
155674	155094	14209N	PARTICIPANT	\N	PRESENT	0
155675	155094	01031L	PARTICIPANT	\N	PRESENT	0
155676	155094	04033B	PARTICIPANT	\N	PRESENT	0
155677	155094	08012N	PARTICIPANT	\N	PRESENT	0
155678	155094	14175V	PARTICIPANT	\N	PRESENT	0
155679	155094	01044R	PARTICIPANT	\N	PRESENT	0
155680	155094	01048V	PARTICIPANT	\N	PRESENT	0
155681	155094	11029K	PARTICIPANT	\N	PRESENT	0
155682	155094	14223L	PARTICIPANT	\N	PRESENT	0
155683	155094	13002U	PARTICIPANT	\N	PRESENT	0
155684	155094	11048N	PARTICIPANT	\N	PRESENT	0
155685	155094	95062K	PARTICIPANT	\N	PRESENT	0
155686	155094	92031P	PARTICIPANT	\N	PRESENT	0
155687	155094	95059Q	PARTICIPANT	\N	PRESENT	0
155688	155094	14123H	PARTICIPANT	\N	PRESENT	0
155689	155094	14211G	PARTICIPANT	\N	PRESENT	0
155690	155094	11100Y	PARTICIPANT	\N	PRESENT	0
155691	155094	08034U	PARTICIPANT	\N	PRESENT	0
155692	155094	08039A	PARTICIPANT	\N	PRESENT	0
155693	155094	96004D	PARTICIPANT	\N	PRESENT	0
155694	155094	04071H	PARTICIPANT	\N	PRESENT	0
155695	155094	01019Q	PARTICIPANT	\N	PRESENT	0
155597	155094	86034E	PARTICIPANT	\N	PRESENT	0
155612	155094	01056V	PARTICIPANT	\N	PRESENT	0
155696	155094	01058X	PARTICIPANT	\N	PRESENT	0
155697	155094	04085P	PARTICIPANT	\N	PRESENT	0
155699	155094	04041B	PARTICIPANT	\N	PRESENT	0
155700	155094	04050C	PARTICIPANT	\N	PRESENT	0
155701	155094	08011M	PARTICIPANT	\N	PRESENT	0
155702	155094	01059Y	PARTICIPANT	\N	PRESENT	0
155703	155094	04036E	PARTICIPANT	\N	PRESENT	0
155704	155094	01013J	PARTICIPANT	\N	PRESENT	0
130833	122725	14042U	PARTICIPANT	\N	PRESENT	0
130834	122727	14042U	PARTICIPANT	\N	PRESENT	0
130835	122727	11112D	PARTICIPANT	\N	PRESENT	0
132778	132777	92031P	PARTICIPANT	\N	PRESENT	0
132834	132833	11072N	PARTICIPANT	\N	PRESENT	0
135529	135528	01046T	PARTICIPANT	\N	PRESENT	0
135732	135613	08009T	PARTICIPANT	\N	EXCUSE	0
136657	135578	89029V	PARTICIPANT	\N	PRESENT	0
136658	127237	14157T	PARTICIPANT	\N	PRESENT	0
136659	127237	14253S	PARTICIPANT	\N	PRESENT	0
136660	127237	11090Q	PARTICIPANT	\N	PRESENT	0
136661	127237	04049K	PRESIDENT	0	PRESENT	0
136662	127237	14121F	PARTICIPANT	\N	PRESENT	0
136663	127237	04053F	PARTICIPANT	\N	PRESENT	0
136664	127237	14018U	PARTICIPANT	\N	PRESENT	0
136665	127237	14034U	PARTICIPANT	\N	PRESENT	0
136666	127237	14061L	PARTICIPANT	\N	PRESENT	0
136667	127237	14087W	PARTICIPANT	\N	PRESENT	0
136668	127237	14205J	PARTICIPANT	\N	PRESENT	0
136669	127237	89017R	PARTICIPANT	\N	EXCUSE	0
136670	127237	14261S	PARTICIPANT	\N	EXCUSE	0
136671	127237	14065Q	PARTICIPANT	\N	EXCUSE	0
136672	127237	14030Q	PARTICIPANT	\N	EXCUSE	0
136673	127237	14255U	PARTICIPANT	\N	EXCUSE	0
136674	127237	14079W	PARTICIPANT	\N	EXCUSE	0
136675	127237	04055H	PARTICIPANT	\N	EXCUSE	0
136676	127237	11088W	PARTICIPANT	\N	EXCUSE	0
136677	127237	14041T	PARTICIPANT	\N	EXCUSE	0
136678	127237	04071H	PARTICIPANT	\N	EXCUSE	0
136679	127237	14151M	PARTICIPANT	\N	EXCUSE	0
136680	127237	14039A	PARTICIPANT	\N	EXCUSE	0
136681	127237	14265W	PARTICIPANT	\N	EXCUSE	0
136682	127237	95067Q	PARTICIPANT	\N	EXCUSE	0
136685	127237	14013P	PARTICIPANT	\N	EXCUSE	0
136686	127237	14105F	PARTICIPANT	\N	EXCUSE	0
136687	135578	14259Y	PARTICIPANT	\N	PRESENT	0
136688	135578	14014Q	PARTICIPANT	\N	PRESENT	0
136689	135578	14109K	PARTICIPANT	\N	PRESENT	0
136690	135578	04079R	PARTICIPANT	\N	PRESENT	0
136691	135578	07026Q	PARTICIPANT	\N	PRESENT	0
136692	135578	11034G	PARTICIPANT	\N	PRESENT	0
136693	135578	04080J	PARTICIPANT	\N	PRESENT	0
136694	135578	11080N	PARTICIPANT	\N	PRESENT	0
136695	135578	09001P	PARTICIPANT	\N	PRESENT	0
136696	135578	95062K	PARTICIPANT	\N	PRESENT	0
136697	135578	04044E	PARTICIPANT	\N	PRESENT	0
136698	135578	11029K	PARTICIPANT	\N	PRESENT	0
136699	135578	04043D	PARTICIPANT	\N	PRESENT	0
136700	135578	04057K	PARTICIPANT	\N	PRESENT	0
136701	135578	04086Q	PARTICIPANT	\N	PRESENT	0
136702	135578	14111D	PARTICIPANT	\N	PRESENT	0
136703	135578	11077T	PARTICIPANT	\N	PRESENT	0
136704	135578	14079W	PARTICIPANT	\N	PRESENT	0
136707	135578	11103C	PARTICIPANT	\N	PRESENT	0
136708	135578	04059M	PARTICIPANT	\N	PRESENT	0
136710	135578	99004R	PARTICIPANT	\N	PRESENT	0
136713	135578	14069U	PARTICIPANT	\N	PRESENT	0
136741	135578	14331P	PARTICIPANT	\N	PRESENT	0
136719	135578	14089Y	PARTICIPANT	\N	PRESENT	0
136721	135578	96004D	PARTICIPANT	\N	PRESENT	0
136723	135578	12041X	PARTICIPANT	\N	PRESENT	0
136724	135578	11053K	PARTICIPANT	\N	PRESENT	0
136725	135578	14031R	PARTICIPANT	\N	PRESENT	0
136727	135578	14263U	PARTICIPANT	\N	PRESENT	0
136728	135578	14235Q	PARTICIPANT	\N	PRESENT	0
136730	135578	88008L	PARTICIPANT	\N	PRESENT	0
136733	135578	14157T	PARTICIPANT	\N	PRESENT	0
136736	135578	05008E	PARTICIPANT	\N	PRESENT	0
136737	135578	14097Y	PARTICIPANT	\N	PRESENT	0
136738	135578	14051J	PARTICIPANT	\N	PRESENT	0
136739	135578	95049N	PARTICIPANT	\N	PRESENT	0
136740	135578	01022K	PARTICIPANT	\N	PRESENT	0
136747	135578	11043H	PARTICIPANT	\N	PRESENT	0
136748	135578	04071H	PARTICIPANT	\N	PRESENT	0
136749	135578	04048J	PARTICIPANT	\N	PRESENT	0
136750	135578	14107H	PARTICIPANT	\N	PRESENT	0
136751	135578	14237S	PARTICIPANT	\N	PRESENT	0
136752	135578	04041B	PARTICIPANT	\N	PRESENT	0
136753	135578	01027Q	PARTICIPANT	\N	PRESENT	0
136754	135578	95067Q	PARTICIPANT	\N	PRESENT	0
136755	135578	08034U	PARTICIPANT	\N	PRESENT	0
136756	135578	14193X	PARTICIPANT	\N	PRESENT	0
136757	135578	08048B	PARTICIPANT	\N	PRESENT	0
136759	136758	11039M	PARTICIPANT	\N	PRESENT	0
136760	136758	98042T	PARTICIPANT	\N	PRESENT	0
136761	135578	95015C	PARTICIPANT	\N	PRESENT	0
136762	135578	01048V	PARTICIPANT	\N	PRESENT	0
136763	135578	14038Y	PARTICIPANT	\N	PRESENT	0
136764	135578	11097X	PARTICIPANT	\N	PRESENT	0
136765	135578	14215L	PARTICIPANT	\N	PRESENT	0
136766	135578	04097T	PARTICIPANT	\N	PRESENT	0
136771	135578	08024S	PARTICIPANT	\N	PRESENT	0
136773	136772	14239U	PARTICIPANT	\N	PRESENT	0
136774	136772	04053F	PARTICIPANT	\N	PRESENT	0
136775	136772	14255U	PARTICIPANT	\N	EXCUSE	0
136776	136772	00003C	PARTICIPANT	\N	EXCUSE	0
136777	136772	14195A	PARTICIPANT	\N	PRESENT	0
136778	135578	08056B	PARTICIPANT	\N	PRESENT	0
136779	136772	14267Y	PARTICIPANT	\N	PRESENT	0
136780	136772	08052W	PARTICIPANT	\N	PRESENT	0
136781	135578	01058X	PARTICIPANT	\N	PRESENT	0
136782	136772	04081K	PARTICIPANT	\N	EXCUSE	0
136783	136772	98024R	PARTICIPANT	\N	PRESENT	0
136784	136772	14217N	PARTICIPANT	\N	PRESENT	0
136785	136772	12042Y	PARTICIPANT	\N	PRESENT	0
136786	135578	14223L	PARTICIPANT	\N	PRESENT	0
136787	136772	14281W	PARTICIPANT	\N	PRESENT	0
136788	136772	14087W	PARTICIPANT	\N	PRESENT	0
136789	136772	14034U	PARTICIPANT	\N	PRESENT	0
136790	136772	11061K	PARTICIPANT	\N	PRESENT	0
136791	136772	08048B	PARTICIPANT	\N	PRESENT	0
136792	136772	14026U	PARTICIPANT	\N	PRESENT	0
136793	136772	14213J	PARTICIPANT	\N	PRESENT	0
136794	136772	14121F	PARTICIPANT	\N	PRESENT	0
136795	136772	11112D	PARTICIPANT	\N	EXCUSE	0
136796	136772	14018U	PARTICIPANT	\N	PRESENT	0
136797	136772	04092N	PRESIDENT	0	PRESENT	0
136798	136772	14265W	PARTICIPANT	\N	EXCUSE	0
136799	136772	14119M	PARTICIPANT	\N	PRESENT	0
136800	136772	14071N	PARTICIPANT	\N	EXCUSE	0
136801	136772	14271U	PARTICIPANT	\N	PRESENT	0
136802	136772	11097X	PARTICIPANT	\N	PRESENT	0
136803	136772	04045F	PARTICIPANT	\N	PRESENT	0
136804	136772	14227Q	PARTICIPANT	\N	PRESENT	0
136805	136772	01034P	PARTICIPANT	\N	PRESENT	0
136806	136772	11063M	PARTICIPANT	\N	PRESENT	0
136807	136772	14269B	PARTICIPANT	\N	PRESENT	0
136808	135578	04049K	PARTICIPANT	\N	PRESENT	0
136809	135578	14147R	PARTICIPANT	\N	PRESENT	0
136810	135578	11012A	PARTICIPANT	\N	PRESENT	0
136811	135578	14033T	PARTICIPANT	\N	PRESENT	0
136812	135578	14030Q	PARTICIPANT	\N	PRESENT	0
136813	135578	11033F	PARTICIPANT	\N	PRESENT	0
136814	135578	01025N	PARTICIPANT	\N	PRESENT	0
136815	135578	11085T	PARTICIPANT	\N	PRESENT	0
136816	135578	14018U	PARTICIPANT	\N	PRESENT	0
136817	135578	14257W	PARTICIPANT	\N	PRESENT	0
136818	135578	14197C	PARTICIPANT	\N	PRESENT	0
136819	135578	80013X	PARTICIPANT	\N	PRESENT	0
136820	135578	95031C	PARTICIPANT	\N	PRESENT	0
136821	135578	08062Y	PARTICIPANT	\N	PRESENT	0
136822	135578	07029T	PARTICIPANT	\N	PRESENT	0
136824	136823	89017R	PARTICIPANT	\N	PRESENT	0
136825	136823	01031L	PRESIDENT	0	PRESENT	0
136826	136823	01013J	PARTICIPANT	\N	PRESENT	0
136827	136823	08014Q	PARTICIPANT	\N	PRESENT	0
136828	136823	14083S	PARTICIPANT	\N	PRESENT	0
136829	136823	14085U	PARTICIPANT	\N	PRESENT	0
136830	136823	11042G	PARTICIPANT	\N	PRESENT	0
136831	136823	11088W	PARTICIPANT	\N	PRESENT	0
136832	136823	08022Q	PARTICIPANT	\N	PRESENT	0
136833	136823	11083R	PARTICIPANT	\N	PRESENT	0
136834	136823	07029T	PARTICIPANT	\N	PRESENT	0
136835	136823	98046X	PARTICIPANT	\N	PRESENT	0
136836	136823	08011M	PARTICIPANT	\N	PRESENT	0
136837	136823	01016M	PARTICIPANT	\N	PRESENT	0
136838	136823	04034C	PARTICIPANT	\N	PRESENT	0
136839	136823	98053W	PARTICIPANT	\N	EXCUSE	0
136840	136823	08042U	PARTICIPANT	\N	PRESENT	0
136920	136919	01008M	PARTICIPANT	\N	PRESENT	0
136921	136919	11036J	PARTICIPANT	\N	PRESENT	0
136922	136919	11081P	PARTICIPANT	\N	PRESENT	0
136923	136919	14013P	PARTICIPANT	\N	EXCUSE	0
136924	136919	08068F	PARTICIPANT	\N	PRESENT	0
136925	136919	11101A	PARTICIPANT	\N	PRESENT	0
136926	136919	90003B	PARTICIPANT	\N	PRESENT	0
136927	136919	08028W	PARTICIPANT	\N	PRESENT	0
136928	136919	80013X	PARTICIPANT	\N	PRESENT	0
136929	136919	08038Y	PARTICIPANT	\N	PRESENT	0
139674	138874	04089T	PARTICIPANT	\N	PRESENT	0
139675	138874	14271U	PARTICIPANT	\N	PRESENT	0
139676	138874	14014Q	PARTICIPANT	\N	PRESENT	0
139677	138874	14109K	PARTICIPANT	\N	PRESENT	0
139678	138874	14065Q	PARTICIPANT	\N	PRESENT	0
139679	138874	14231L	PARTICIPANT	\N	PRESENT	0
139680	138874	04070G	PARTICIPANT	\N	PRESENT	0
139681	138874	01007L	PARTICIPANT	\N	PRESENT	0
139682	138874	14215L	PARTICIPANT	\N	PRESENT	0
139683	138874	14071N	PARTICIPANT	\N	PRESENT	0
139684	138874	04086Q	PARTICIPANT	\N	PRESENT	0
139685	138874	98018T	PARTICIPANT	\N	PRESENT	0
139686	138874	07034Q	PARTICIPANT	\N	PRESENT	0
139687	138874	07024N	PARTICIPANT	\N	PRESENT	0
139688	138874	14053L	PARTICIPANT	\N	PRESENT	0
139689	138874	14061L	PARTICIPANT	\N	PRESENT	0
139690	138874	14026U	PARTICIPANT	\N	PRESENT	0
139691	138874	97011G	PARTICIPANT	\N	PRESENT	0
139692	138874	08062Y	PARTICIPANT	\N	PRESENT	0
139693	138874	11091R	PARTICIPANT	\N	PRESENT	0
139694	138874	07029T	PARTICIPANT	\N	PRESENT	0
139695	138874	14041T	PARTICIPANT	\N	PRESENT	0
139696	138874	14195A	PARTICIPANT	\N	PRESENT	0
139697	138874	14031R	PARTICIPANT	\N	PRESENT	0
139698	138874	14191V	PARTICIPANT	\N	PRESENT	0
139699	138874	14173T	PARTICIPANT	\N	PRESENT	0
139700	138874	14133K	PARTICIPANT	\N	PRESENT	0
139701	138874	14241N	PARTICIPANT	\N	PRESENT	0
139702	138874	04036E	PARTICIPANT	\N	PRESENT	0
139703	138874	98050T	PARTICIPANT	\N	PRESENT	0
139704	138874	04081K	PARTICIPANT	\N	PRESENT	0
139705	138874	11100Y	PARTICIPANT	\N	PRESENT	0
139706	138874	87003B	PARTICIPANT	\N	PRESENT	0
139707	138874	04092N	PARTICIPANT	\N	PRESENT	0
139708	138874	14251Q	PARTICIPANT	\N	PRESENT	0
139709	138874	08053X	PARTICIPANT	\N	PRESENT	0
139710	138874	11026G	PARTICIPANT	\N	PRESENT	0
139711	138874	11036J	PARTICIPANT	\N	PRESENT	0
139712	138874	11089X	PARTICIPANT	\N	PRESENT	0
139713	138874	14223L	PARTICIPANT	\N	PRESENT	0
139714	138874	04033B	PARTICIPANT	\N	PRESENT	0
139715	138874	04057K	PARTICIPANT	\N	PRESENT	0
139716	138874	14038Y	PARTICIPANT	\N	PRESENT	0
139717	138874	08015R	PARTICIPANT	\N	PRESENT	0
139718	138874	14221J	PARTICIPANT	\N	PRESENT	0
139719	138874	01027Q	PARTICIPANT	\N	PRESENT	0
139720	138874	04047H	PARTICIPANT	\N	PRESENT	0
139721	138874	08018U	PARTICIPANT	\N	PRESENT	0
139722	138874	04088S	PARTICIPANT	\N	PRESENT	0
139723	138874	11098Y	PARTICIPANT	\N	PRESENT	0
139724	138874	14107H	PARTICIPANT	\N	PRESENT	0
139725	138874	14087W	PARTICIPANT	\N	PRESENT	0
139726	138874	14079W	PARTICIPANT	\N	PRESENT	0
139727	138874	01003G	PARTICIPANT	\N	PRESENT	0
139728	138874	11106F	PARTICIPANT	\N	PRESENT	0
139729	138874	11029K	PARTICIPANT	\N	PRESENT	0
139730	138874	14269B	PARTICIPANT	\N	PRESENT	0
139731	138874	14239U	PARTICIPANT	\N	PRESENT	0
139732	138874	11082Q	PARTICIPANT	\N	PRESENT	0
139733	138874	11033F	PARTICIPANT	\N	PRESENT	0
139734	138874	14187A	PARTICIPANT	\N	PRESENT	0
139735	138874	14083S	PARTICIPANT	\N	PRESENT	0
139736	138874	11042G	PARTICIPANT	\N	PRESENT	0
139737	138874	14105F	PARTICIPANT	\N	PRESENT	0
139738	138874	01047U	PARTICIPANT	\N	PRESENT	0
139739	138874	14259Y	PARTICIPANT	\N	PRESENT	0
139740	138874	08010L	PARTICIPANT	\N	PRESENT	0
139741	138874	14267Y	PARTICIPANT	\N	PRESENT	0
139742	138874	08068F	PARTICIPANT	\N	PRESENT	0
139743	138874	98022P	PARTICIPANT	\N	PRESENT	0
139744	138874	08048B	PARTICIPANT	\N	PRESENT	0
139745	138874	11061K	PARTICIPANT	\N	PRESENT	0
139746	138874	14121F	PARTICIPANT	\N	PRESENT	0
139747	138874	11109J	PARTICIPANT	\N	PRESENT	0
139748	138874	14073Q	PARTICIPANT	\N	PRESENT	0
139749	138874	11113E	PARTICIPANT	\N	PRESENT	0
139750	138874	04080J	PARTICIPANT	\N	PRESENT	0
139751	138874	14193X	PARTICIPANT	\N	PRESENT	0
139752	138874	14147R	PARTICIPANT	\N	PRESENT	0
139753	138874	01014K	PARTICIPANT	\N	PRESENT	0
139754	138874	04053F	PARTICIPANT	\N	PRESENT	0
139755	138874	14219Q	PARTICIPANT	\N	PRESENT	0
139756	138874	11039M	PARTICIPANT	\N	PRESENT	0
139757	138874	14157T	PARTICIPANT	\N	PRESENT	0
139758	138874	14042U	PARTICIPANT	\N	PRESENT	0
139759	138874	14281W	PARTICIPANT	\N	PRESENT	0
139760	138874	08049C	PARTICIPANT	\N	PRESENT	0
139761	138874	04067M	PARTICIPANT	\N	PRESENT	0
139762	138874	90003B	PARTICIPANT	\N	PRESENT	0
139763	138874	01019Q	PARTICIPANT	\N	PRESENT	0
139764	138874	11097X	PARTICIPANT	\N	PRESENT	0
139765	138874	01022K	PARTICIPANT	\N	PRESENT	0
139766	138874	14039A	PARTICIPANT	\N	PRESENT	0
139767	138874	14237S	PARTICIPANT	\N	PRESENT	0
139768	138874	11103C	PARTICIPANT	\N	PRESENT	0
139769	138874	08051V	PARTICIPANT	\N	PRESENT	0
139770	138874	95049N	PARTICIPANT	\N	PRESENT	0
139771	138874	14069U	PARTICIPANT	\N	PRESENT	0
139772	138874	11080N	PARTICIPANT	\N	PRESENT	0
139773	138874	14055N	PARTICIPANT	\N	PRESENT	0
139774	138874	95035G	PARTICIPANT	\N	PRESENT	0
139775	138874	11043H	PARTICIPANT	\N	PRESENT	0
139776	138874	04043D	PARTICIPANT	\N	PRESENT	0
139777	138874	11084S	PARTICIPANT	\N	PRESENT	0
139778	138874	80013X	PARTICIPANT	\N	PRESENT	0
139779	138874	14227Q	PARTICIPANT	\N	PRESENT	0
139780	138874	11095V	PARTICIPANT	\N	PRESENT	0
139781	138874	14063N	PARTICIPANT	\N	PRESENT	0
139782	138874	14199E	PARTICIPANT	\N	PRESENT	0
139783	138874	14089Y	PARTICIPANT	\N	PRESENT	0
139784	138874	01025N	PARTICIPANT	\N	PRESENT	0
139785	138874	10006L	PARTICIPANT	\N	PRESENT	0
139786	138874	01046T	PARTICIPANT	\N	PRESENT	0
139815	138872	98024R	PARTICIPANT	\N	PRESENT	0
139816	138872	11093T	PARTICIPANT	\N	PRESENT	0
139817	138872	14159V	PARTICIPANT	\N	PRESENT	0
139819	138872	14249W	PARTICIPANT	\N	PRESENT	0
139826	138872	04088S	PARTICIPANT	\N	PRESENT	0
139827	138872	89017R	PARTICIPANT	\N	PRESENT	0
139828	138872	86044G	PARTICIPANT	\N	PRESENT	0
139829	138872	08034U	PARTICIPANT	\N	PRESENT	0
139830	138872	11088W	PARTICIPANT	\N	PRESENT	0
139831	138872	14265W	PARTICIPANT	\N	PRESENT	0
139832	138872	14187A	PARTICIPANT	\N	PRESENT	0
139833	138872	11066Q	PARTICIPANT	\N	PRESENT	0
139834	138872	04034C	PARTICIPANT	\N	PRESENT	0
139835	138872	14207L	PARTICIPANT	\N	PRESENT	0
139836	138872	11098Y	PARTICIPANT	\N	PRESENT	0
139837	138872	14179A	PARTICIPANT	\N	PRESENT	0
139838	138872	92031P	PARTICIPANT	\N	PRESENT	0
139839	138872	14123H	PARTICIPANT	\N	PRESENT	0
139840	138872	08015R	PARTICIPANT	\N	PRESENT	0
139841	138872	01022K	PARTICIPANT	\N	PRESENT	0
139842	138872	14034U	PARTICIPANT	\N	PRESENT	0
139843	138872	14221J	PARTICIPANT	\N	PRESENT	0
139844	138872	14255U	PARTICIPANT	\N	PRESENT	0
139845	138872	11099A	PARTICIPANT	\N	PRESENT	0
139969	138873	08024S	PARTICIPANT	\N	PRESENT	0
139972	138873	04092N	PARTICIPANT	\N	PRESENT	0
139973	138873	01034P	PARTICIPANT	\N	PRESENT	0
139974	138873	11031D	PARTICIPANT	\N	PRESENT	0
139975	138873	11063M	PARTICIPANT	\N	PRESENT	0
139976	138873	14227Q	PARTICIPANT	\N	PRESENT	0
139977	138873	80013X	PARTICIPANT	\N	PRESENT	0
139978	138873	08052W	PARTICIPANT	\N	PRESENT	0
139979	138873	14281W	PARTICIPANT	\N	PRESENT	0
139980	138873	08019V	PARTICIPANT	\N	PRESENT	0
139981	138873	04088S	PARTICIPANT	\N	PRESENT	0
139982	138873	14195A	PARTICIPANT	\N	PRESENT	0
139983	138873	14223L	PARTICIPANT	\N	PRESENT	0
139984	138873	11103C	PARTICIPANT	\N	PRESENT	0
139985	138873	14217N	PARTICIPANT	\N	PRESENT	0
139986	138873	08048B	PARTICIPANT	\N	PRESENT	0
139987	138873	14105F	PARTICIPANT	\N	PRESENT	0
139988	138873	14215L	PARTICIPANT	\N	PRESENT	0
139989	138873	14089Y	PARTICIPANT	\N	PRESENT	0
139990	138873	11097X	PARTICIPANT	\N	PRESENT	0
139991	138873	14071N	PARTICIPANT	\N	PRESENT	0
139992	138873	14213J	PARTICIPANT	\N	PRESENT	0
139993	138873	98024R	PARTICIPANT	\N	PRESENT	0
139994	138873	14041T	PARTICIPANT	\N	PRESENT	0
139995	138873	08015R	PARTICIPANT	\N	PRESENT	0
139996	138873	14059S	PARTICIPANT	\N	PRESENT	0
139997	138873	14265W	PARTICIPANT	\N	PRESENT	0
139998	138873	12042Y	PARTICIPANT	\N	PRESENT	0
139999	138873	08058D	PARTICIPANT	\N	PRESENT	0
140000	138873	11023D	PARTICIPANT	\N	PRESENT	0
140001	138873	14159V	PARTICIPANT	\N	PRESENT	0
130235	130233	14159V	PARTICIPANT	\N	PRESENT	0
130234	130233	11042G	PARTICIPANT	\N	PRESENT	0
130240	130237	14175V	PARTICIPANT	\N	PRESENT	0
130241	130237	14085U	PARTICIPANT	\N	PRESENT	0
130250	130249	07029T	PARTICIPANT	\N	PRESENT	0
133408	133371	08034U	PARTICIPANT	\N	PRESENT	0
133409	133371	01048V	PARTICIPANT	\N	PRESENT	0
133410	133371	98046X	PARTICIPANT	\N	PRESENT	0
133411	133371	11085T	PARTICIPANT	\N	PRESENT	0
133412	133371	08011M	PARTICIPANT	\N	PRESENT	0
135426	135425	08012N	PARTICIPANT	\N	PRESENT	0
133414	133371	08061X	PARTICIPANT	\N	PRESENT	0
133415	133371	01016M	PARTICIPANT	\N	PRESENT	0
133416	133371	14225N	PARTICIPANT	\N	PRESENT	0
133417	133371	11012A	PARTICIPANT	\N	PRESENT	0
133418	133371	11057P	PARTICIPANT	\N	PRESENT	0
133419	133371	14173T	PARTICIPANT	\N	PRESENT	0
133420	133371	04034C	PARTICIPANT	\N	PRESENT	0
133422	133371	11040E	PARTICIPANT	\N	PRESENT	0
135421	135420	08012N	PARTICIPANT	\N	PRESENT	0
135430	135429	95015C	PARTICIPANT	\N	PRESENT	0
135432	135431	95015C	PARTICIPANT	\N	PRESENT	0
135638	135637	11033F	PARTICIPANT	\N	PRESENT	0
135639	135637	14259Y	PARTICIPANT	\N	PRESENT	0
135640	135637	01007L	PARTICIPANT	\N	PRESENT	0
135641	135637	08044W	PARTICIPANT	\N	EXCUSE	0
135642	135637	04079R	PARTICIPANT	\N	PRESENT	0
135643	135637	01028R	PARTICIPANT	\N	PRESENT	0
135644	135637	04056J	PARTICIPANT	\N	PRESENT	0
135645	135637	04044E	PRESIDENT	0	PRESENT	0
135646	135637	11037K	PARTICIPANT	\N	EXCUSE	0
135649	135637	05008E	PARTICIPANT	\N	EXCUSE	0
137480	137479	11089X	PARTICIPANT	\N	PRESENT	0
137485	124150	11036J	PARTICIPANT	\N	PRESENT	0
137518	137517	01048V	PARTICIPANT	\N	EXCUSE	0
137519	137517	14221J	PARTICIPANT	\N	EXCUSE	0
141896	141030	86034E	PARTICIPANT	\N	PRESENT	0
141897	141030	14133K	PARTICIPANT	\N	PRESENT	0
141898	141030	01008M	PARTICIPANT	\N	PRESENT	0
141899	141030	05004A	PARTICIPANT	\N	PRESENT	0
141900	141030	05008E	PARTICIPANT	\N	PRESENT	0
141901	141030	11063M	PARTICIPANT	\N	PRESENT	0
141902	141030	11030C	PARTICIPANT	\N	PRESENT	0
141903	141030	14105F	PARTICIPANT	\N	PRESENT	0
141904	141030	07026Q	PARTICIPANT	\N	PRESENT	0
141905	141030	95015C	PARTICIPANT	\N	PRESENT	0
141906	141030	11103C	PARTICIPANT	\N	PRESENT	0
141907	141030	11098Y	PARTICIPANT	\N	PRESENT	0
141908	141030	14329V	PARTICIPANT	\N	PRESENT	0
141909	141030	11034G	PARTICIPANT	\N	PRESENT	0
141910	141030	14038Y	PARTICIPANT	\N	PRESENT	0
141911	141030	11080N	PARTICIPANT	\N	PRESENT	0
141912	141030	08047A	PARTICIPANT	\N	PRESENT	0
141913	141030	14235Q	PARTICIPANT	\N	PRESENT	0
141914	141030	04085P	PARTICIPANT	\N	PRESENT	0
141915	141030	04050C	PARTICIPANT	\N	PRESENT	0
141916	141030	04097T	PARTICIPANT	\N	PRESENT	0
141917	141030	01056V	PARTICIPANT	\N	PRESENT	0
141918	141030	12041X	PARTICIPANT	\N	PRESENT	0
141919	141030	01059Y	PARTICIPANT	\N	PRESENT	0
141920	141030	05001W	PARTICIPANT	\N	PRESENT	0
141921	141030	92018S	PARTICIPANT	\N	PRESENT	0
141922	141030	01015L	PARTICIPANT	\N	PRESENT	0
141923	141030	04053F	PARTICIPANT	\N	PRESENT	0
141924	141030	98035U	PARTICIPANT	\N	PRESENT	0
141925	141030	01027Q	PARTICIPANT	\N	PRESENT	0
141926	141030	04071H	PARTICIPANT	\N	PRESENT	0
141927	141030	95031C	PARTICIPANT	\N	PRESENT	0
141928	141030	14033T	PARTICIPANT	\N	PRESENT	0
141929	141030	89029V	PARTICIPANT	\N	PRESENT	0
141930	141030	10006L	PARTICIPANT	\N	PRESENT	0
141931	141030	02002K	PARTICIPANT	\N	PRESENT	0
141932	141030	01013J	PARTICIPANT	\N	PRESENT	0
141933	141030	14013P	PARTICIPANT	\N	PRESENT	0
141934	141030	04055H	PARTICIPANT	\N	PRESENT	0
141935	141030	11031D	PARTICIPANT	\N	PRESENT	0
141936	141030	01019Q	PARTICIPANT	\N	PRESENT	0
141937	141030	11055M	PARTICIPANT	\N	PRESENT	0
141938	141030	11033F	PARTICIPANT	\N	PRESENT	0
141939	141030	01044R	PARTICIPANT	\N	PRESENT	0
141940	141030	11029K	PARTICIPANT	\N	PRESENT	0
141941	141030	11065P	PARTICIPANT	\N	PRESENT	0
141942	141030	04067M	PARTICIPANT	\N	PRESENT	0
141943	141030	11083R	PARTICIPANT	\N	PRESENT	0
141944	141030	11099A	PARTICIPANT	\N	PRESENT	0
141945	141030	13002U	PARTICIPANT	\N	PRESENT	0
141946	141030	11076S	PARTICIPANT	\N	PRESENT	0
141947	141030	92044U	PARTICIPANT	\N	PRESENT	0
141948	141030	14026U	PARTICIPANT	\N	PRESENT	0
141949	141030	14055N	PARTICIPANT	\N	PRESENT	0
141950	141030	08021P	PARTICIPANT	\N	PRESENT	0
141951	141030	92040Q	PARTICIPANT	\N	PRESENT	0
141952	141030	14169X	PARTICIPANT	\N	PRESENT	0
141953	141030	14030Q	PARTICIPANT	\N	PRESENT	0
141954	141030	14253S	PARTICIPANT	\N	PRESENT	0
141955	141030	08051V	PARTICIPANT	\N	PRESENT	0
141956	141030	01046T	PARTICIPANT	\N	PRESENT	0
141957	141030	88008L	PARTICIPANT	\N	PRESENT	0
141958	141030	04078Q	PARTICIPANT	\N	PRESENT	0
141959	141030	11012A	PARTICIPANT	\N	PRESENT	0
141960	141030	11097X	PARTICIPANT	\N	PRESENT	0
141961	141030	01048V	PARTICIPANT	\N	PRESENT	0
141962	141030	14239U	PARTICIPANT	\N	PRESENT	0
141963	141030	14018U	PARTICIPANT	\N	PRESENT	0
141964	141030	01003G	PARTICIPANT	\N	PRESENT	0
141965	141030	04088S	PARTICIPANT	\N	PRESENT	0
141966	141030	04038G	PARTICIPANT	\N	PRESENT	0
141967	141030	08019V	PARTICIPANT	\N	PRESENT	0
141968	141030	14261S	PARTICIPANT	\N	PRESENT	0
141969	141030	14093U	PARTICIPANT	\N	PRESENT	0
141970	141030	98022P	PARTICIPANT	\N	PRESENT	0
141971	141030	14059S	PARTICIPANT	\N	PRESENT	0
141972	141030	14241N	PARTICIPANT	\N	PRESENT	0
141973	141030	96004D	PARTICIPANT	\N	PRESENT	0
141974	141030	14201E	PARTICIPANT	\N	PRESENT	0
141975	141030	14069U	PARTICIPANT	\N	PRESENT	0
141976	141030	11081P	PARTICIPANT	\N	PRESENT	0
141977	141030	08049C	PARTICIPANT	\N	PRESENT	0
141978	141030	11044J	PARTICIPANT	\N	PRESENT	0
141979	141030	04054G	PARTICIPANT	\N	PRESENT	0
141981	141030	08031R	PARTICIPANT	\N	PRESENT	0
141982	141030	90003B	PARTICIPANT	\N	PRESENT	0
141983	141030	01031L	PARTICIPANT	\N	PRESENT	0
141984	141030	14195A	PARTICIPANT	\N	PRESENT	0
141985	141030	87003B	PARTICIPANT	\N	PRESENT	0
141986	141030	11109J	PARTICIPANT	\N	PRESENT	0
141987	141030	14209N	PARTICIPANT	\N	PRESENT	0
141988	141030	98023Q	PARTICIPANT	\N	PRESENT	0
141989	141030	04086Q	PARTICIPANT	\N	PRESENT	0
141990	141030	14079W	PARTICIPANT	\N	PRESENT	0
141991	141030	08016S	PARTICIPANT	\N	PRESENT	0
141992	141030	14259Y	PARTICIPANT	\N	PRESENT	0
141993	141030	01016M	PARTICIPANT	\N	PRESENT	0
141994	141030	04056J	PARTICIPANT	\N	PRESENT	0
141995	141030	98018T	PARTICIPANT	\N	PRESENT	0
141996	141030	11039M	PARTICIPANT	\N	PRESENT	0
141997	141030	98024R	PARTICIPANT	\N	PRESENT	0
141998	141030	14051J	PARTICIPANT	\N	PRESENT	0
141999	141030	14151M	PARTICIPANT	\N	PRESENT	0
142000	141030	14041T	PARTICIPANT	\N	PRESENT	0
142001	141030	08025T	PARTICIPANT	\N	PRESENT	0
142002	141030	04059M	PARTICIPANT	\N	PRESENT	0
142003	141030	08022Q	PARTICIPANT	\N	PRESENT	0
142004	141030	14217N	PARTICIPANT	\N	PRESENT	0
142005	141030	08052W	PARTICIPANT	\N	PRESENT	0
142006	141030	92015P	PARTICIPANT	\N	PRESENT	0
142007	141030	11091R	PARTICIPANT	\N	PRESENT	0
142008	141030	98046X	PARTICIPANT	\N	PRESENT	0
142009	141030	08055A	PARTICIPANT	\N	PRESENT	0
142010	141030	04066L	PARTICIPANT	\N	PRESENT	0
142011	141030	01011G	PARTICIPANT	\N	PRESENT	0
142012	141030	11057P	PARTICIPANT	\N	PRESENT	0
142013	141030	14197C	PARTICIPANT	\N	PRESENT	0
142014	141030	01022K	PARTICIPANT	\N	PRESENT	0
142015	141030	98050T	PARTICIPANT	\N	PRESENT	0
142016	141030	14028W	PARTICIPANT	\N	PRESENT	0
142017	141030	95030B	PARTICIPANT	\N	PRESENT	0
142018	141030	95063L	PARTICIPANT	\N	PRESENT	0
142019	141030	14187A	PARTICIPANT	\N	PRESENT	0
142020	141030	80013X	PARTICIPANT	\N	PRESENT	0
142021	141030	08060W	PARTICIPANT	\N	PRESENT	0
142022	141030	14087W	PARTICIPANT	\N	PRESENT	0
142023	141030	14065Q	PARTICIPANT	\N	PRESENT	0
142024	141030	97011G	PARTICIPANT	\N	PRESENT	0
142762	142761	01031L	PRESIDENT	0	PRESENT	0
142775	142761	08014Q	PARTICIPANT	\N	PRESENT	0
142776	142761	14167V	PARTICIPANT	\N	PRESENT	0
142777	142761	14083S	PARTICIPANT	\N	PRESENT	0
142778	142761	11053K	PARTICIPANT	\N	PRESENT	0
142779	142761	14085U	PARTICIPANT	\N	PRESENT	0
142780	142761	11042G	PARTICIPANT	\N	PRESENT	0
142781	142761	88008L	PARTICIPANT	\N	PRESENT	0
142782	142761	04086Q	PARTICIPANT	\N	PRESENT	0
142783	142761	14327T	PARTICIPANT	\N	PRESENT	0
142784	142761	08022Q	PARTICIPANT	\N	PRESENT	0
142785	142761	04071H	PARTICIPANT	\N	PRESENT	0
142786	142761	11083R	PARTICIPANT	\N	PRESENT	0
142787	142761	01057W	PARTICIPANT	\N	PRESENT	0
142788	142761	08069G	PARTICIPANT	\N	PRESENT	0
142789	142761	11048N	PARTICIPANT	\N	PRESENT	0
142790	142761	14159V	PARTICIPANT	\N	PRESENT	0
142791	142761	08011M	PARTICIPANT	\N	PRESENT	0
142792	142761	01016M	PARTICIPANT	\N	PRESENT	0
142793	142761	14225N	PARTICIPANT	\N	PRESENT	0
142794	142761	11012A	PARTICIPANT	\N	PRESENT	0
142795	142761	04034C	PARTICIPANT	\N	PRESENT	0
142797	142761	07029T	PARTICIPANT	\N	PRESENT	0
142798	142761	14087W	PARTICIPANT	\N	PRESENT	0
142859	142761	89017R	PARTICIPANT	\N	EXCUSE	0
142860	142761	14175V	PARTICIPANT	\N	EXCUSE	0
142861	142761	01027Q	PARTICIPANT	\N	EXCUSE	0
142862	142761	98053W	PARTICIPANT	\N	EXCUSE	0
142863	142761	08061X	PARTICIPANT	\N	EXCUSE	0
144695	141032	14069U	PARTICIPANT	\N	PRESENT	0
144696	141034	14069U	PARTICIPANT	\N	PRESENT	0
146403	135128	04049K	PRESIDENT	0	PRESENT	0
146404	135128	14255U	PARTICIPANT	\N	PRESENT	0
146405	135128	14265W	PARTICIPANT	\N	PRESENT	0
146406	135128	14157T	PARTICIPANT	\N	PRESENT	0
146407	135128	89017R	PARTICIPANT	\N	PRESENT	0
146408	135128	14105F	PARTICIPANT	\N	PRESENT	0
146409	135128	14061L	PARTICIPANT	\N	PRESENT	0
146410	135128	14253S	PARTICIPANT	\N	PRESENT	0
146411	135128	14121F	PARTICIPANT	\N	PRESENT	0
146412	135128	14083S	PARTICIPANT	\N	PRESENT	0
146413	135128	14087W	PARTICIPANT	\N	PRESENT	0
146414	135128	04053F	PARTICIPANT	\N	PRESENT	0
146415	135128	14261S	PARTICIPANT	\N	EXCUSE	0
146416	135128	14065Q	PARTICIPANT	\N	EXCUSE	0
146417	135128	14030Q	PARTICIPANT	\N	EXCUSE	0
146418	135128	14013P	PARTICIPANT	\N	EXCUSE	0
146419	135128	08068F	PARTICIPANT	\N	EXCUSE	0
146420	135128	14207L	PARTICIPANT	\N	EXCUSE	0
146421	135128	14079W	PARTICIPANT	\N	EXCUSE	0
146422	135128	04055H	PARTICIPANT	\N	EXCUSE	0
146423	135128	11088W	PARTICIPANT	\N	EXCUSE	0
146424	135128	14041T	PARTICIPANT	\N	EXCUSE	0
146425	135128	04071H	PARTICIPANT	\N	EXCUSE	0
146426	135128	02002K	PARTICIPANT	\N	EXCUSE	0
146427	135128	14034U	PARTICIPANT	\N	EXCUSE	0
146428	135128	95041E	PARTICIPANT	\N	EXCUSE	0
146429	135128	14039A	PARTICIPANT	\N	EXCUSE	0
146430	135128	14205J	PARTICIPANT	\N	EXCUSE	0
146431	135128	11090Q	PARTICIPANT	\N	EXCUSE	0
146432	135128	10015M	PARTICIPANT	\N	EXCUSE	0
146433	135128	95067Q	PARTICIPANT	\N	EXCUSE	0
146434	135128	11063M	PARTICIPANT	\N	EXCUSE	0
146467	146466	14133K	PARTICIPANT	\N	PRESENT	0
146468	146466	96004D	PRESIDENT	0	PRESENT	0
146469	146466	04054G	PARTICIPANT	\N	PRESENT	0
146470	146466	14089Y	PARTICIPANT	\N	PRESENT	0
146471	146466	11040E	PARTICIPANT	\N	PRESENT	0
146472	146466	11035H	PARTICIPANT	\N	PRESENT	0
146473	146466	14079W	PARTICIPANT	\N	PRESENT	0
146474	146466	08018U	PARTICIPANT	\N	PRESENT	0
146476	146466	04035D	PARTICIPANT	\N	PRESENT	0
146478	146466	14097Y	PARTICIPANT	\N	PRESENT	0
146479	146466	95037J	PARTICIPANT	\N	PRESENT	0
146480	146466	14073Q	PARTICIPANT	\N	PRESENT	0
146481	146466	04057K	PARTICIPANT	\N	PRESENT	0
146482	146466	14135M	PARTICIPANT	\N	PRESENT	0
146483	146466	11012A	PARTICIPANT	\N	PRESENT	0
146484	146466	04045F	PARTICIPANT	\N	PRESENT	0
146485	146466	98035U	PARTICIPANT	\N	PRESENT	0
146486	146466	92045V	PARTICIPANT	\N	PRESENT	0
146487	146466	90003B	PARTICIPANT	\N	EXCUSE	0
146488	146466	14026U	PARTICIPANT	\N	EXCUSE	0
146489	146466	11026G	PARTICIPANT	\N	EXCUSE	0
146490	146466	10015M	PARTICIPANT	\N	EXCUSE	0
146491	146466	08044W	PARTICIPANT	\N	EXCUSE	0
146493	146492	99004R	PRESIDENT	0	PRESENT	0
146494	146492	08062Y	PARTICIPANT	\N	PRESENT	0
146495	146492	11084S	PARTICIPANT	\N	PRESENT	0
146496	146492	01008M	PARTICIPANT	\N	PRESENT	0
146497	146492	01059Y	PARTICIPANT	\N	PRESENT	0
146498	146492	11094U	PARTICIPANT	\N	PRESENT	0
146499	146492	11066Q	PARTICIPANT	\N	PRESENT	0
146500	146492	08012N	PARTICIPANT	\N	PRESENT	0
146501	146492	88008L	PARTICIPANT	\N	PRESENT	0
150155	150154	05008E	PRESIDENT	0	PRESENT	0
150156	150154	14069U	PARTICIPANT	\N	PRESENT	0
150157	150154	04047H	PARTICIPANT	\N	EXCUSE	0
150158	150154	14259Y	PARTICIPANT	\N	PRESENT	0
150159	150154	11035H	PARTICIPANT	\N	PRESENT	0
150160	150154	11113E	PARTICIPANT	\N	PRESENT	0
150161	150154	01024M	PARTICIPANT	\N	EXCUSE	0
150162	150154	11010L	PARTICIPANT	\N	PRESENT	0
150163	150154	08044W	PARTICIPANT	\N	EXCUSE	0
150164	150154	11026G	PARTICIPANT	\N	PRESENT	0
150165	150154	14111D	PARTICIPANT	\N	PRESENT	0
150166	150154	07034Q	PARTICIPANT	\N	EXCUSE	0
150167	150154	01028R	PARTICIPANT	\N	EXCUSE	0
150168	150154	04056J	PARTICIPANT	\N	PRESENT	0
150169	150154	92045V	PARTICIPANT	\N	EXCUSE	0
150170	150154	95067Q	PARTICIPANT	\N	PRESENT	0
150171	150154	08019V	PARTICIPANT	\N	PRESENT	0
150172	150154	14217N	PARTICIPANT	\N	PRESENT	0
150173	150154	14059S	PARTICIPANT	\N	PRESENT	0
150174	150154	05001W	PARTICIPANT	\N	PRESENT	0
150175	150154	08073C	PARTICIPANT	\N	PRESENT	0
150176	150154	11071M	PARTICIPANT	\N	PRESENT	0
150177	150154	98005N	PARTICIPANT	\N	PRESENT	0
150178	150154	14039A	PARTICIPANT	\N	PRESENT	0
150193	150192	92045V	PARTICIPANT	\N	PRESENT	0
150194	150192	04045F	PARTICIPANT	\N	PRESENT	0
150253	150252	01031L	PARTICIPANT	\N	PRESENT	0
150254	150252	08011M	PARTICIPANT	\N	PRESENT	0
150255	150252	04086Q	PARTICIPANT	\N	PRESENT	0
150256	150252	11088W	PARTICIPANT	\N	PRESENT	0
150257	150252	11070L	PARTICIPANT	\N	PRESENT	0
150259	150252	04055H	PARTICIPANT	\N	PRESENT	0
152773	152772	95067Q	PARTICIPANT	\N	PRESENT	0
152780	152772	97011G	PARTICIPANT	\N	PRESENT	0
152775	152772	04036E	PARTICIPANT	\N	PRESENT	0
152776	152772	01047U	PARTICIPANT	\N	PRESENT	0
155705	155094	07026Q	PARTICIPANT	\N	PRESENT	0
152779	152772	14249W	PARTICIPANT	\N	PRESENT	0
155706	155094	11031D	PARTICIPANT	\N	PRESENT	0
155707	155094	01008M	PARTICIPANT	\N	PRESENT	0
155708	155094	01015L	PARTICIPANT	\N	PRESENT	0
155709	155094	14263U	PARTICIPANT	\N	PRESENT	0
155710	155094	14013P	PARTICIPANT	\N	PRESENT	0
155711	155094	98005N	PARTICIPANT	\N	PRESENT	0
155712	155094	11040E	PARTICIPANT	\N	PRESENT	0
155713	155094	14235Q	PARTICIPANT	\N	PRESENT	0
155714	155094	14329V	PARTICIPANT	\N	PRESENT	0
155715	155094	12041X	PARTICIPANT	\N	PRESENT	0
155716	155094	14105F	PARTICIPANT	\N	PRESENT	0
155717	155094	11098Y	PARTICIPANT	\N	PRESENT	0
155718	155094	04074L	PARTICIPANT	\N	PRESENT	0
155719	155094	11099A	PARTICIPANT	\N	PRESENT	0
155720	155094	11011M	PARTICIPANT	\N	PRESENT	0
155721	155094	11033F	PARTICIPANT	\N	PRESENT	0
155722	155094	11083R	PARTICIPANT	\N	PRESENT	0
155723	155094	14119M	PARTICIPANT	\N	PRESENT	0
155724	155094	11065P	PARTICIPANT	\N	PRESENT	0
155725	155094	04067M	PARTICIPANT	\N	PRESENT	0
155726	155094	92040Q	PARTICIPANT	\N	PRESENT	0
155727	155094	14033T	PARTICIPANT	\N	PRESENT	0
155728	155094	89017R	PARTICIPANT	\N	PRESENT	0
155729	155094	14247U	PARTICIPANT	\N	PRESENT	0
155730	155094	14041T	PARTICIPANT	\N	PRESENT	0
155731	155094	08051V	PARTICIPANT	\N	PRESENT	0
155732	155094	04078Q	PARTICIPANT	\N	PRESENT	0
155733	155094	08031R	PARTICIPANT	\N	PRESENT	0
155734	155094	04038G	PARTICIPANT	\N	PRESENT	0
155735	155094	07029T	PARTICIPANT	\N	PRESENT	0
155736	155094	11012A	PARTICIPANT	\N	PRESENT	0
155737	155094	14018U	PARTICIPANT	\N	PRESENT	0
155738	155094	11081P	PARTICIPANT	\N	PRESENT	0
155739	155094	01003G	PARTICIPANT	\N	PRESENT	0
155740	155094	14093U	PARTICIPANT	\N	PRESENT	0
155741	155094	14201E	PARTICIPANT	\N	PRESENT	0
130260	130259	08022Q	PARTICIPANT	\N	PRESENT	0
130262	130261	08022Q	PARTICIPANT	\N	PRESENT	0
130264	130263	11053K	PARTICIPANT	\N	PRESENT	0
130266	130265	11053K	PARTICIPANT	\N	PRESENT	0
130268	130267	11053K	PARTICIPANT	\N	PRESENT	0
130270	130269	11053K	PARTICIPANT	\N	PRESENT	0
130272	130271	11053K	PARTICIPANT	\N	PRESENT	0
130836	120701	01022K	PARTICIPANT	\N	EXCUSE	0
130837	120701	11025F	PARTICIPANT	\N	EXCUSE	0
135573	135572	01043Q	PARTICIPANT	\N	PRESENT	0
135577	135576	14081Q	PARTICIPANT	\N	PRESENT	0
135581	135580	14187A	PARTICIPANT	\N	PRESENT	0
135583	135582	14187A	PARTICIPANT	\N	PRESENT	0
135585	135584	01043Q	PARTICIPANT	\N	PRESENT	0
136189	136176	14119M	PARTICIPANT	\N	PRESENT	0
136338	136337	08028W	PARTICIPANT	\N	PRESENT	0
136341	136340	01061S	PARTICIPANT	\N	PRESENT	0
136344	136343	01061S	PARTICIPANT	\N	PRESENT	0
136347	136346	14187A	PARTICIPANT	\N	PRESENT	0
136349	136348	14187A	PARTICIPANT	\N	PRESENT	0
136358	136357	01008M	PARTICIPANT	\N	PRESENT	0
136359	136357	11081P	PARTICIPANT	\N	PRESENT	0
136360	136357	14207L	PARTICIPANT	\N	PRESENT	0
136361	136357	14038Y	PARTICIPANT	\N	PRESENT	0
136362	136357	14195A	PARTICIPANT	\N	PRESENT	0
136363	136357	14327T	PARTICIPANT	\N	PRESENT	0
136364	136357	14197C	PARTICIPANT	\N	PRESENT	0
136365	136357	14014Q	PARTICIPANT	\N	PRESENT	0
136366	136357	11111C	PARTICIPANT	\N	PRESENT	0
136367	136357	14107H	PARTICIPANT	\N	PRESENT	0
136368	136357	11043H	PARTICIPANT	\N	PRESENT	0
136372	136371	14081Q	PARTICIPANT	\N	PRESENT	0
136706	136705	14093U	PARTICIPANT	\N	PRESENT	0
136735	136734	95062K	PARTICIPANT	\N	PRESENT	0
136930	136919	04089T	PARTICIPANT	\N	PRESENT	0
136931	136919	14197C	PARTICIPANT	\N	PRESENT	0
136932	136919	14187A	PARTICIPANT	\N	PRESENT	0
136933	136919	14033T	PARTICIPANT	\N	PRESENT	0
136934	136919	04049K	PARTICIPANT	\N	PRESENT	0
136935	136919	08015R	PARTICIPANT	\N	EXCUSE	0
136936	136919	11100Y	PARTICIPANT	\N	PRESENT	0
136937	136919	14257W	PARTICIPANT	\N	PRESENT	0
136938	136919	98050T	PARTICIPANT	\N	PRESENT	0
136939	136919	11046L	PARTICIPANT	\N	PRESENT	0
136940	136919	01058X	PARTICIPANT	\N	PRESENT	0
136941	136919	11094U	PARTICIPANT	\N	PRESENT	0
136942	136919	11066Q	PARTICIPANT	\N	PRESENT	0
136944	136943	89017R	PARTICIPANT	\N	PRESENT	0
136945	136943	01031L	PRESIDENT	0	PRESENT	0
136946	136943	01013J	PARTICIPANT	\N	PRESENT	0
136947	136943	11068S	PARTICIPANT	\N	PRESENT	0
136948	136943	08014Q	PARTICIPANT	\N	PRESENT	0
136949	136943	14167V	PARTICIPANT	\N	PRESENT	0
136950	136943	14175V	PARTICIPANT	\N	PRESENT	0
136951	136943	14083S	PARTICIPANT	\N	PRESENT	0
136952	136943	11053K	PARTICIPANT	\N	PRESENT	0
136953	136943	14085U	PARTICIPANT	\N	PRESENT	0
136954	136943	11042G	PARTICIPANT	\N	PRESENT	0
136955	136943	88008L	PARTICIPANT	\N	PRESENT	0
136956	136943	04086Q	PARTICIPANT	\N	PRESENT	0
136957	136943	11088W	PARTICIPANT	\N	PRESENT	0
136958	136943	14327T	PARTICIPANT	\N	PRESENT	0
136960	136943	08022Q	PARTICIPANT	\N	PRESENT	0
136961	136959	01008M	PARTICIPANT	\N	PRESENT	0
136962	136959	11036J	PARTICIPANT	\N	PRESENT	0
136963	136943	01027Q	PARTICIPANT	\N	PRESENT	0
136964	136959	11081P	PARTICIPANT	\N	PRESENT	0
136965	136959	14013P	PARTICIPANT	\N	PRESENT	0
136966	136943	04071H	PARTICIPANT	\N	PRESENT	0
136967	136959	08068F	PARTICIPANT	\N	PRESENT	0
136968	136959	14207L	PARTICIPANT	\N	PRESENT	0
136969	136959	11101A	PARTICIPANT	\N	PRESENT	0
136970	136959	90003B	PARTICIPANT	\N	PRESENT	0
136971	136959	80013X	PARTICIPANT	\N	PRESENT	0
136972	136959	08038Y	PARTICIPANT	\N	PRESENT	0
136973	136959	04089T	PARTICIPANT	\N	PRESENT	0
136974	136959	14197C	PARTICIPANT	\N	PRESENT	0
136975	136959	11110B	PARTICIPANT	\N	PRESENT	0
136976	136959	14187A	PARTICIPANT	\N	PRESENT	0
136977	136943	11074Q	PARTICIPANT	\N	PRESENT	0
136978	136959	14033T	PARTICIPANT	\N	PRESENT	0
136979	136943	98053W	PARTICIPANT	\N	PRESENT	0
136980	136959	14081Q	PARTICIPANT	\N	PRESENT	0
136981	136959	04048J	PARTICIPANT	\N	PRESENT	0
136982	136959	11099A	PARTICIPANT	\N	PRESENT	0
136983	136959	04049K	PARTICIPANT	\N	PRESENT	0
136984	136943	11083R	PARTICIPANT	\N	PRESENT	0
136985	136959	11111C	PARTICIPANT	\N	PRESENT	0
136986	136959	08015R	PARTICIPANT	\N	PRESENT	0
136987	136959	11100Y	PARTICIPANT	\N	PRESENT	0
136988	136959	01061S	PARTICIPANT	\N	PRESENT	0
136989	136959	11098Y	PARTICIPANT	\N	PRESENT	0
136990	136959	01043Q	PARTICIPANT	\N	PRESENT	0
136991	136959	14205J	PARTICIPANT	\N	PRESENT	0
136992	136959	08019V	PARTICIPANT	\N	PRESENT	0
136993	136959	14257W	PARTICIPANT	\N	PRESENT	0
136994	136959	08021P	PARTICIPANT	\N	PRESENT	0
136995	136943	14199E	PARTICIPANT	\N	PRESENT	0
136996	136959	98050T	PARTICIPANT	\N	PRESENT	0
136997	136959	11090Q	PARTICIPANT	\N	PRESENT	0
136998	136943	01057W	PARTICIPANT	\N	PRESENT	0
136999	136959	11046L	PARTICIPANT	\N	PRESENT	0
137000	136959	01058X	PARTICIPANT	\N	PRESENT	0
137001	136943	08016S	PARTICIPANT	\N	PRESENT	0
137002	136959	11094U	PARTICIPANT	\N	PRESENT	0
137003	136959	11066Q	PARTICIPANT	\N	PRESENT	0
137004	136943	08069G	PARTICIPANT	\N	PRESENT	0
137005	136943	11048N	PARTICIPANT	\N	PRESENT	0
137006	136943	99004R	PARTICIPANT	\N	PRESENT	0
137033	137032	14263U	PARTICIPANT	\N	PRESENT	0
137034	137032	14133K	PARTICIPANT	\N	PRESENT	0
137011	136943	04061F	PARTICIPANT	\N	PRESENT	0
137012	136943	14159V	PARTICIPANT	\N	PRESENT	0
137013	136943	07029T	PARTICIPANT	\N	PRESENT	0
137014	136943	14277B	PARTICIPANT	\N	PRESENT	0
137015	136943	08010L	PARTICIPANT	\N	PRESENT	0
137016	136943	08034U	PARTICIPANT	\N	PRESENT	0
137017	136943	01048V	PARTICIPANT	\N	PRESENT	0
137018	136943	98046X	PARTICIPANT	\N	PRESENT	0
137019	136943	11085T	PARTICIPANT	\N	PRESENT	0
137020	136943	08011M	PARTICIPANT	\N	PRESENT	0
137021	136943	08073C	PARTICIPANT	\N	PRESENT	0
137022	136943	08061X	PARTICIPANT	\N	PRESENT	0
137023	136943	01016M	PARTICIPANT	\N	PRESENT	0
137024	136943	14225N	PARTICIPANT	\N	PRESENT	0
137025	136943	11012A	PARTICIPANT	\N	PRESENT	0
137026	136943	11057P	PARTICIPANT	\N	PRESENT	0
137027	136943	14173T	PARTICIPANT	\N	PRESENT	0
137028	136943	04034C	PARTICIPANT	\N	PRESENT	0
137036	137032	04059M	PARTICIPANT	\N	EXCUSE	0
137037	137032	11039M	PARTICIPANT	\N	PRESENT	0
137038	137032	01044R	PARTICIPANT	\N	PRESENT	0
137039	137032	08043V	PARTICIPANT	\N	PRESENT	0
137041	137032	14105F	PARTICIPANT	\N	PRESENT	0
137042	137032	11029K	PARTICIPANT	\N	PRESENT	0
137043	137032	95015C	PRESIDENT	0	PRESENT	0
137044	137032	92015P	PARTICIPANT	\N	PRESENT	0
137046	137032	14201E	PARTICIPANT	\N	EXCUSE	0
137047	137032	14329V	PARTICIPANT	\N	PRESENT	0
136656	136655	11026G	PARTICIPANT	\N	PRESENT	0
136684	136683	01043Q	PARTICIPANT	\N	PRESENT	0
137049	137032	14079W	PARTICIPANT	\N	PRESENT	0
137050	137032	11091R	PARTICIPANT	\N	PRESENT	0
137051	137032	87003B	PARTICIPANT	\N	PRESENT	0
137052	137032	98042T	PARTICIPANT	\N	PRESENT	0
137053	137032	14249W	PARTICIPANT	\N	PRESENT	0
137055	137032	01025N	PARTICIPANT	\N	PRESENT	0
137056	137032	01037S	PARTICIPANT	\N	PRESENT	0
137057	137032	89029V	PARTICIPANT	\N	PRESENT	0
137058	137032	08035V	PARTICIPANT	\N	PRESENT	0
137059	137032	11089X	PARTICIPANT	\N	PRESENT	0
137060	137032	07026Q	PARTICIPANT	\N	PRESENT	0
137061	137032	14123H	PARTICIPANT	\N	PRESENT	0
137062	137032	14179A	PARTICIPANT	\N	PRESENT	0
137063	137032	04041B	PARTICIPANT	\N	PRESENT	0
137064	137032	14241N	PARTICIPANT	\N	EXCUSE	0
137065	137032	14061L	PARTICIPANT	\N	PRESENT	0
137067	137032	08031R	PARTICIPANT	\N	EXCUSE	0
137068	137032	12041X	PARTICIPANT	\N	PRESENT	0
137069	137032	08039A	PARTICIPANT	\N	EXCUSE	0
137070	137032	08017T	PARTICIPANT	\N	PRESENT	0
137071	137032	14059S	PARTICIPANT	\N	PRESENT	0
140004	138873	01059Y	PARTICIPANT	\N	PRESENT	0
140005	138873	11110B	PARTICIPANT	\N	PRESENT	0
140006	138873	14255U	PARTICIPANT	\N	PRESENT	0
140007	138873	14269B	PARTICIPANT	\N	PRESENT	0
140008	138873	95015C	PARTICIPANT	\N	PRESENT	0
140009	138873	14087W	PARTICIPANT	\N	PRESENT	0
140010	138873	14271U	PARTICIPANT	\N	PRESENT	0
140011	138873	14069U	PARTICIPANT	\N	PRESENT	0
140012	138873	14018U	PARTICIPANT	\N	PRESENT	0
140013	138873	01046T	PARTICIPANT	\N	PRESENT	0
140014	138873	14033T	PARTICIPANT	\N	PRESENT	0
140015	138873	14135M	PARTICIPANT	\N	PRESENT	0
140016	138873	10006L	PARTICIPANT	\N	PRESENT	0
140017	138873	92045V	PARTICIPANT	\N	PRESENT	0
140018	138873	14042U	PARTICIPANT	\N	PRESENT	0
140019	138873	04053F	PARTICIPANT	\N	PRESENT	0
140020	138873	11112D	PARTICIPANT	\N	PRESENT	0
140021	138873	11055M	PARTICIPANT	\N	PRESENT	0
140022	138873	11109J	PARTICIPANT	\N	PRESENT	0
140023	138873	14219Q	PARTICIPANT	\N	PRESENT	0
140024	138873	11061K	PARTICIPANT	\N	PRESENT	0
140025	138873	14119M	PARTICIPANT	\N	PRESENT	0
140026	138873	14083S	PARTICIPANT	\N	PRESENT	0
140027	138873	08031R	PARTICIPANT	\N	PRESENT	0
140028	138873	14037X	PARTICIPANT	\N	PRESENT	0
140029	138873	01024M	PARTICIPANT	\N	PRESENT	0
140030	138873	14207L	PARTICIPANT	\N	PRESENT	0
140031	138873	08051V	PARTICIPANT	\N	PRESENT	0
140032	138873	11105E	PARTICIPANT	\N	PRESENT	0
140033	138873	08039A	PARTICIPANT	\N	PRESENT	0
140034	138873	14179A	PARTICIPANT	\N	PRESENT	0
140035	138873	14073Q	PARTICIPANT	\N	PRESENT	0
140036	138873	14267Y	PARTICIPANT	\N	PRESENT	0
140037	138873	14097Y	PARTICIPANT	\N	PRESENT	0
140038	138873	96004D	PARTICIPANT	\N	PRESENT	0
140039	138873	14030Q	PARTICIPANT	\N	PRESENT	0
140040	138873	14231L	PARTICIPANT	\N	PRESENT	0
140041	138873	14197C	PARTICIPANT	\N	PRESENT	0
140042	138873	14014Q	PARTICIPANT	\N	PRESENT	0
140043	138873	11042G	PARTICIPANT	\N	PRESENT	0
140044	138873	01008M	PARTICIPANT	\N	PRESENT	0
140045	138873	04070G	PARTICIPANT	\N	PRESENT	0
140046	138873	14121F	PARTICIPANT	\N	PRESENT	0
140091	140090	89017R	PARTICIPANT	\N	PRESENT	0
140093	140092	08011M	PARTICIPANT	\N	PRESENT	0
140861	140860	01061S	PARTICIPANT	\N	PRESENT	0
140863	140862	01008M	PARTICIPANT	\N	PRESENT	0
140865	140864	08068F	PARTICIPANT	\N	PRESENT	0
140867	140866	01008M	PARTICIPANT	\N	PRESENT	0
140869	140868	01008M	PARTICIPANT	\N	PRESENT	0
140879	140877	11082Q	PARTICIPANT	\N	PRESENT	0
140882	140880	11082Q	PARTICIPANT	\N	PRESENT	0
143102	143101	11076S	PARTICIPANT	\N	PRESENT	0
143103	143101	04054G	PARTICIPANT	\N	PRESENT	0
143104	143101	04040A	PARTICIPANT	\N	PRESENT	0
143105	143101	08058D	PARTICIPANT	\N	PRESENT	0
143106	143101	04042C	PRESIDENT	1	PRESENT	0
143107	143101	77002U	PARTICIPANT	\N	PRESENT	0
143159	143101	92020L	PARTICIPANT	\N	EXCUSE	0
143109	143101	11080N	PARTICIPANT	\N	PRESENT	0
143110	143101	11027H	PARTICIPANT	\N	PRESENT	0
143111	143101	98018T	PARTICIPANT	\N	PRESENT	0
143112	143101	92018S	PARTICIPANT	\N	PRESENT	0
144110	144052	01041N	PARTICIPANT	\N	EXCUSE	0
143114	143101	95030B	PARTICIPANT	\N	PRESENT	0
143115	143101	11096W	PARTICIPANT	\N	PRESENT	0
143116	143101	95031C	PARTICIPANT	\N	PRESENT	0
143117	143101	97011G	PARTICIPANT	\N	PRESENT	0
140002	138873	11093T	PARTICIPANT	\N	PRESENT	0
140003	138873	04045F	PARTICIPANT	\N	PRESENT	0
144111	144052	01028R	PARTICIPANT	\N	PRESENT	0
143119	143101	04035D	PARTICIPANT	\N	PRESENT	0
143120	143101	07024N	PARTICIPANT	\N	PRESENT	0
143121	143101	04095R	PARTICIPANT	\N	PRESENT	0
143122	143101	14014Q	PARTICIPANT	\N	PRESENT	0
143123	143101	11015D	PARTICIPANT	\N	PRESENT	0
143124	143101	07004J	PARTICIPANT	\N	PRESENT	0
143125	143101	95035G	PARTICIPANT	\N	PRESENT	0
143126	143101	08056B	PARTICIPANT	\N	PRESENT	0
144055	144052	11109J	PARTICIPANT	\N	PRESENT	0
143128	143101	98022P	PARTICIPANT	\N	PRESENT	0
143129	143101	11064N	PARTICIPANT	\N	PRESENT	0
143130	143101	95037J	PARTICIPANT	\N	PRESENT	0
144112	144052	04044E	PARTICIPANT	\N	PRESENT	0
143132	143101	14097Y	PARTICIPANT	\N	PRESENT	0
143133	143101	95041E	PARTICIPANT	\N	PRESENT	0
144113	144052	11026G	PARTICIPANT	\N	PRESENT	0
143135	143101	14039A	PARTICIPANT	\N	PRESENT	0
144058	144052	01044R	PARTICIPANT	\N	PRESENT	0
144059	144052	08043V	PARTICIPANT	\N	PRESENT	0
143138	143101	92031P	PARTICIPANT	\N	PRESENT	0
143139	143101	11106F	PARTICIPANT	\N	PRESENT	0
143140	143101	14251Q	PARTICIPANT	\N	PRESENT	0
143141	143101	83042R	PARTICIPANT	\N	PRESENT	0
143142	143101	08053X	PARTICIPANT	\N	PRESENT	0
143143	143101	11082Q	PARTICIPANT	\N	PRESENT	0
143144	143101	11105E	PARTICIPANT	\N	PRESENT	0
143145	143101	14253S	PARTICIPANT	\N	PRESENT	0
143146	143101	08047A	PARTICIPANT	\N	PRESENT	0
143147	143101	14028W	PARTICIPANT	\N	PRESENT	0
143148	143101	14193X	PARTICIPANT	\N	PRESENT	0
143149	143101	98021N	PARTICIPANT	\N	PRESENT	0
143150	143101	04080J	PARTICIPANT	\N	PRESENT	0
143151	143101	95059Q	PRESIDENT	0	PRESENT	0
143152	143101	86044G	PARTICIPANT	\N	PRESENT	0
143153	143101	01014K	PARTICIPANT	\N	PRESENT	0
143154	143101	11054L	PARTICIPANT	\N	PRESENT	0
143155	143101	01056V	PARTICIPANT	\N	PRESENT	0
143156	143101	92044U	PARTICIPANT	\N	PRESENT	0
143157	143101	08049C	PARTICIPANT	\N	EXCUSE	0
143158	143101	04050C	PARTICIPANT	\N	PRESENT	0
144060	144052	14089Y	PARTICIPANT	\N	PRESENT	0
144061	144052	14105F	PARTICIPANT	\N	PRESENT	0
144062	144052	11029K	PARTICIPANT	\N	PRESENT	0
144114	144052	95063L	PARTICIPANT	\N	PRESENT	0
144115	144052	08051V	PARTICIPANT	\N	PRESENT	0
144116	144052	04056J	PARTICIPANT	\N	PRESENT	0
144117	144052	96004D	PARTICIPANT	\N	PRESENT	0
144118	144052	04045F	PARTICIPANT	\N	PRESENT	0
144119	144052	98035U	PARTICIPANT	\N	PRESENT	0
144120	144052	11012A	PARTICIPANT	\N	PRESENT	0
144333	144332	01025N	PARTICIPANT	\N	PRESENT	0
148733	148732	11100Y	PARTICIPANT	\N	PRESENT	0
148734	148732	92039X	PARTICIPANT	\N	PRESENT	0
144073	144052	14249W	PARTICIPANT	\N	EXCUSE	0
149133	149132	14059S	PARTICIPANT	\N	PRESENT	0
158313	158312	07034Q	PARTICIPANT	\N	PRESENT	0
144076	144052	01037S	PARTICIPANT	\N	EXCUSE	0
154934	154932	08043V	PARTICIPANT	\N	PRESENT	0
154935	154932	11029K	PARTICIPANT	\N	PRESENT	0
144080	144052	07026Q	PARTICIPANT	\N	PRESENT	0
155275	155273	01008M	PARTICIPANT	\N	PRESENT	0
144082	144052	14179A	PARTICIPANT	\N	PRESENT	0
155276	155273	14038Y	PARTICIPANT	\N	PRESENT	0
155277	155273	01015L	PARTICIPANT	\N	PRESENT	0
155278	155273	14197C	PARTICIPANT	\N	PRESENT	0
144086	144052	14073Q	PARTICIPANT	\N	PRESENT	0
155279	155273	14033T	PARTICIPANT	\N	PRESENT	0
158327	158325	08055A	PARTICIPANT	\N	PRESENT	0
144089	144052	08039A	PARTICIPANT	\N	PRESENT	0
144090	144052	08017T	PARTICIPANT	\N	PRESENT	0
155281	155273	08009T	PARTICIPANT	\N	PRESENT	0
155282	155273	14221J	PARTICIPANT	\N	PRESENT	0
155283	155273	14265W	PARTICIPANT	\N	PRESENT	0
155284	155273	14237S	PARTICIPANT	\N	PRESENT	0
144095	144052	14063N	PARTICIPANT	\N	PRESENT	0
144096	144052	04057K	PRESIDENT	0	PRESENT	0
155286	155273	14107H	PARTICIPANT	\N	PRESENT	0
144099	144052	04070G	PARTICIPANT	\N	EXCUSE	0
155287	155273	95067Q	PARTICIPANT	\N	PRESENT	0
158328	158325	14093U	PARTICIPANT	\N	PRESENT	0
158329	158325	14030Q	PARTICIPANT	\N	PRESENT	0
158330	158325	96004D	PARTICIPANT	\N	PRESENT	0
158331	158325	08060W	PARTICIPANT	\N	PRESENT	0
158334	158325	11114F	PARTICIPANT	\N	PRESENT	0
158335	158325	98023Q	PARTICIPANT	\N	PRESENT	0
158336	158325	11065P	PARTICIPANT	\N	PRESENT	0
158337	158325	01015L	PARTICIPANT	\N	PRESENT	0
158338	158325	11107G	PARTICIPANT	\N	PRESENT	0
158340	158325	02002K	PARTICIPANT	\N	PRESENT	0
158341	158325	01022K	PARTICIPANT	\N	PRESENT	0
130506	124956	14263U	PARTICIPANT	\N	PRESENT	0
130507	124956	01046T	PARTICIPANT	\N	EXCUSE	0
130508	124956	11036J	PARTICIPANT	\N	PRESENT	0
130509	124956	14209N	PARTICIPANT	\N	EXCUSE	0
130510	124956	11089X	PARTICIPANT	\N	EXCUSE	0
130511	124956	04061F	PARTICIPANT	\N	EXCUSE	0
130512	124956	01048V	PARTICIPANT	\N	EXCUSE	0
130513	124956	14257W	PARTICIPANT	\N	EXCUSE	0
130514	124956	13002U	PARTICIPANT	\N	EXCUSE	0
130515	124956	80013X	PARTICIPANT	\N	EXCUSE	0
130517	124148	13002U	PARTICIPANT	\N	PRESENT	0
130606	130604	04043D	PARTICIPANT	\N	PRESENT	0
130619	124148	14263U	PARTICIPANT	\N	EXCUSE	0
131214	131213	14263U	PARTICIPANT	\N	PRESENT	0
131215	131213	14133K	PARTICIPANT	\N	PRESENT	0
131495	131213	08039A	PARTICIPANT	\N	PRESENT	0
131217	131213	04059M	PARTICIPANT	\N	PRESENT	0
131218	131213	11039M	PARTICIPANT	\N	PRESENT	0
131219	131213	01044R	PARTICIPANT	\N	PRESENT	0
131220	131213	08043V	PARTICIPANT	\N	PRESENT	0
131221	131213	14089Y	PARTICIPANT	\N	EXCUSE	0
131222	131213	14105F	PARTICIPANT	\N	PRESENT	0
131223	131213	11029K	PARTICIPANT	\N	PRESENT	0
131224	131213	95015C	PARTICIPANT	\N	EXCUSE	0
131225	131213	92015P	PARTICIPANT	\N	PRESENT	0
131226	131213	08024S	PARTICIPANT	\N	PRESENT	0
131503	131502	92040Q	PARTICIPANT	\N	PRESENT	0
131228	131213	14329V	PARTICIPANT	\N	PRESENT	0
138304	138300	08051V	PARTICIPANT	\N	PRESENT	0
131230	131213	14079W	PARTICIPANT	\N	PRESENT	0
131231	131213	11091R	PARTICIPANT	\N	PRESENT	0
137897	137895	14133K	PARTICIPANT	\N	EXCUSE	0
137898	137895	11109J	PARTICIPANT	\N	PRESENT	0
137899	137895	04059M	PARTICIPANT	\N	PRESENT	0
131235	131213	01041N	PARTICIPANT	\N	EXCUSE	0
137900	137895	11039M	PARTICIPANT	\N	EXCUSE	0
137901	137895	01044R	PARTICIPANT	\N	EXCUSE	0
137902	137895	08043V	PARTICIPANT	\N	PRESENT	0
131239	131213	08035V	PARTICIPANT	\N	PRESENT	0
131240	131213	11089X	PARTICIPANT	\N	PRESENT	0
138305	138300	14071N	PARTICIPANT	\N	PRESENT	0
137904	137895	14105F	PARTICIPANT	\N	PRESENT	0
131243	131213	14179A	PARTICIPANT	\N	PRESENT	0
131244	131213	04041B	PARTICIPANT	\N	EXCUSE	0
131245	131213	14241N	PARTICIPANT	\N	PRESENT	0
131246	131213	14061L	PARTICIPANT	\N	PRESENT	0
131247	131213	14073Q	PARTICIPANT	\N	PRESENT	0
137905	137895	11029K	PARTICIPANT	\N	PRESENT	0
142025	141030	08018U	PARTICIPANT	\N	PRESENT	0
142026	141030	11015D	PARTICIPANT	\N	PRESENT	0
137908	137895	08024S	PARTICIPANT	\N	PRESENT	0
131252	131213	14059S	PARTICIPANT	\N	PRESENT	0
131253	131213	08012N	PARTICIPANT	\N	PRESENT	0
142027	141030	08043V	PARTICIPANT	\N	PRESENT	0
131255	131213	11104D	PARTICIPANT	\N	PRESENT	0
131256	131213	14063N	PARTICIPANT	\N	PRESENT	0
131257	131213	04057K	PARTICIPANT	\N	PRESENT	0
131258	131213	11014C	PARTICIPANT	\N	PRESENT	0
142028	141030	04035D	PARTICIPANT	\N	PRESENT	0
131260	131213	04070G	PRESIDENT	0	PRESENT	0
142029	141030	11105E	PARTICIPANT	\N	PRESENT	0
142030	141030	08053X	PARTICIPANT	\N	PRESENT	0
131263	131213	83047W	PARTICIPANT	\N	PRESENT	0
131264	131213	14235Q	PARTICIPANT	\N	PRESENT	0
142031	141030	11089X	PARTICIPANT	\N	PRESENT	0
142032	141030	08012N	PARTICIPANT	\N	PRESENT	0
131267	131213	14229S	PARTICIPANT	\N	PRESENT	0
131268	131213	11043H	PARTICIPANT	\N	PRESENT	0
131269	131213	11071M	PARTICIPANT	\N	PRESENT	0
142033	141030	08042U	PARTICIPANT	\N	PRESENT	0
142034	141030	80027E	PARTICIPANT	\N	PRESENT	0
137917	137895	01041N	PARTICIPANT	\N	PRESENT	0
142035	141030	07024N	PARTICIPANT	\N	PRESENT	0
137919	137895	01037S	PARTICIPANT	\N	PRESENT	0
142036	141030	11036J	PARTICIPANT	\N	PRESENT	0
142037	141030	08058D	PARTICIPANT	\N	PRESENT	0
142038	141030	95037J	PARTICIPANT	\N	PRESENT	0
142039	141030	08068F	PARTICIPANT	\N	PRESENT	0
137924	137895	14123H	PARTICIPANT	\N	PRESENT	0
142040	141030	08017T	PARTICIPANT	\N	PRESENT	0
142041	141030	11059R	PARTICIPANT	\N	PRESENT	0
142042	141030	83042R	PARTICIPANT	\N	PRESENT	0
137928	137895	14061L	PARTICIPANT	\N	PRESENT	0
137929	137895	14073Q	PARTICIPANT	\N	PRESENT	0
137930	137895	08031R	PARTICIPANT	\N	EXCUSE	0
142043	141030	11046L	PARTICIPANT	\N	PRESENT	0
142044	141030	11077T	PARTICIPANT	\N	PRESENT	0
142045	141030	14014Q	PARTICIPANT	\N	PRESENT	0
142046	141030	14119M	PARTICIPANT	\N	PRESENT	0
137935	137895	08012N	PARTICIPANT	\N	PRESENT	0
137936	137895	14103D	PARTICIPANT	\N	PRESENT	0
137937	137895	11104D	PARTICIPANT	\N	PRESENT	0
142047	141030	14109K	PARTICIPANT	\N	PRESENT	0
142048	141030	11084S	PARTICIPANT	\N	PRESENT	0
142049	141030	14207L	PARTICIPANT	\N	PRESENT	0
142050	141030	98021N	PARTICIPANT	\N	PRESENT	0
137942	137895	04070G	PRESIDENT	0	PRESENT	0
142051	141030	08014Q	PARTICIPANT	\N	PRESENT	0
142052	141030	07034Q	PARTICIPANT	\N	PRESENT	0
142053	141030	11095V	PARTICIPANT	\N	PRESENT	0
137946	137895	14235Q	PARTICIPANT	\N	PRESENT	0
142054	141030	14001X	PARTICIPANT	\N	PRESENT	0
142055	141030	11048N	PARTICIPANT	\N	PRESENT	0
137949	137895	14229S	PARTICIPANT	\N	PRESENT	0
137950	137895	11043H	PARTICIPANT	\N	PRESENT	0
142056	141030	04034C	PARTICIPANT	\N	PRESENT	0
142057	141030	14167V	PARTICIPANT	\N	PRESENT	0
142058	141030	14123H	PARTICIPANT	\N	PRESENT	0
142059	141030	11054L	PARTICIPANT	\N	PRESENT	0
142060	141030	11040E	PARTICIPANT	\N	PRESENT	0
142061	141030	01057W	PARTICIPANT	\N	PRESENT	0
142062	141030	83047W	PARTICIPANT	\N	PRESENT	0
142063	141030	08069G	PARTICIPANT	\N	PRESENT	0
142064	141030	14229S	PARTICIPANT	\N	PRESENT	0
142065	141030	04041B	PARTICIPANT	\N	PRESENT	0
142066	141030	14213J	PARTICIPANT	\N	PRESENT	0
142067	141030	14227Q	PARTICIPANT	\N	PRESENT	0
142068	141030	08015R	PARTICIPANT	\N	PRESENT	0
142069	141030	07029T	PARTICIPANT	\N	PRESENT	0
142070	141030	08035V	PARTICIPANT	\N	PRESENT	0
142071	141030	04077P	PARTICIPANT	\N	PRESENT	0
142072	141030	14281W	PARTICIPANT	\N	PRESENT	0
142073	141030	04057K	PARTICIPANT	\N	PRESENT	0
142074	141030	04079R	PARTICIPANT	\N	PRESENT	0
142075	141030	14107H	PARTICIPANT	\N	PRESENT	0
142076	141030	04045F	PARTICIPANT	\N	PRESENT	0
142077	141030	14121F	PARTICIPANT	\N	PRESENT	0
142078	141030	14063N	PARTICIPANT	\N	PRESENT	0
142079	141030	11112D	PARTICIPANT	\N	PRESENT	0
142080	141030	14053L	PARTICIPANT	\N	PRESENT	0
142081	141030	14097Y	PARTICIPANT	\N	PRESENT	0
142082	141030	08062Y	PARTICIPANT	\N	PRESENT	0
142083	141030	14257W	PARTICIPANT	\N	PRESENT	0
142084	141030	11014C	PARTICIPANT	\N	PRESENT	0
142085	141030	92039X	PARTICIPANT	\N	PRESENT	0
142086	141030	99004R	PARTICIPANT	\N	PRESENT	0
142087	141030	01028R	PARTICIPANT	\N	PRESENT	0
142088	141030	11104D	PARTICIPANT	\N	PRESENT	0
142089	141030	08038Y	PARTICIPANT	\N	PRESENT	0
142090	141030	95035G	PARTICIPANT	\N	PRESENT	0
142091	141030	08041T	PARTICIPANT	\N	PRESENT	0
142092	141030	11035H	PARTICIPANT	\N	PRESENT	0
142093	141030	11066Q	PARTICIPANT	\N	PRESENT	0
142094	141030	77002U	PARTICIPANT	\N	PRESENT	0
142095	141030	01037S	PARTICIPANT	\N	PRESENT	0
142096	141030	11106F	PARTICIPANT	\N	PRESENT	0
142097	141030	14275Y	PARTICIPANT	\N	PRESENT	0
142098	141030	14085U	PARTICIPANT	\N	PRESENT	0
142099	141030	11061K	PARTICIPANT	\N	PRESENT	0
142100	141030	14081Q	PARTICIPANT	\N	PRESENT	0
142101	141030	04074L	PARTICIPANT	\N	PRESENT	0
142102	141030	08073C	PARTICIPANT	\N	PRESENT	0
142103	141030	04095R	PARTICIPANT	\N	PRESENT	0
142104	141030	11068S	PARTICIPANT	\N	PRESENT	0
142105	141030	14237S	PARTICIPANT	\N	PRESENT	0
142106	141030	01014K	PARTICIPANT	\N	PRESENT	0
142107	141030	11042G	PARTICIPANT	\N	PRESENT	0
142108	141030	11027H	PARTICIPANT	\N	PRESENT	0
142109	141030	04043D	PARTICIPANT	\N	PRESENT	0
142110	141030	04094Q	PARTICIPANT	\N	PRESENT	0
142111	141030	14159V	PARTICIPANT	\N	PRESENT	0
142112	141030	11025F	PARTICIPANT	\N	PRESENT	0
142113	141030	14269B	PARTICIPANT	\N	PRESENT	0
142114	141030	08024S	PARTICIPANT	\N	PRESENT	0
142115	141030	12042Y	PARTICIPANT	\N	PRESENT	0
142116	141030	14251Q	PARTICIPANT	\N	PRESENT	0
142117	141030	14039A	PARTICIPANT	\N	PRESENT	0
142118	141030	11023D	PARTICIPANT	\N	PRESENT	0
140095	140094	14237S	PARTICIPANT	\N	PRESENT	0
140101	140094	14107H	PARTICIPANT	\N	PRESENT	0
140102	140094	01008M	PARTICIPANT	\N	PRESENT	0
140103	140094	14265W	PARTICIPANT	\N	PRESENT	0
140104	140094	95067Q	PARTICIPANT	\N	PRESENT	0
140105	140094	14197C	PARTICIPANT	\N	PRESENT	0
140106	140094	14195A	PARTICIPANT	\N	PRESENT	0
140107	140094	01003G	PARTICIPANT	\N	PRESENT	0
140171	140169	04088S	PARTICIPANT	\N	PRESENT	0
140172	140169	11098Y	PARTICIPANT	\N	PRESENT	0
140175	140169	01008M	PARTICIPANT	\N	PRESENT	0
140176	140169	11090Q	PARTICIPANT	\N	PRESENT	0
140177	140169	11036J	PARTICIPANT	\N	PRESENT	0
140178	140169	11094U	PARTICIPANT	\N	PRESENT	0
140179	140169	08055A	PARTICIPANT	\N	PRESENT	0
140180	140169	14083S	PARTICIPANT	\N	PRESENT	0
140181	140169	14059S	PARTICIPANT	\N	PRESENT	0
140182	140169	14331P	PARTICIPANT	\N	PRESENT	0
140183	140169	14026U	PARTICIPANT	\N	PRESENT	0
140184	140169	90003B	PARTICIPANT	\N	PRESENT	0
140853	140852	14253S	PARTICIPANT	\N	PRESENT	0
140854	140852	14157T	PARTICIPANT	\N	PRESENT	0
140874	140873	04049K	PARTICIPANT	\N	PRESENT	0
140875	140873	14255U	PARTICIPANT	\N	PRESENT	0
140933	140932	04049K	PARTICIPANT	\N	PRESENT	0
140934	140932	14255U	PARTICIPANT	\N	PRESENT	0
143162	143161	08025T	PARTICIPANT	\N	PRESENT	0
143163	143161	04085P	PARTICIPANT	\N	PRESENT	0
143164	143161	05008E	PRESIDENT	0	PRESENT	0
155743	155094	92045V	PARTICIPANT	\N	PRESENT	0
143166	143161	11033F	PARTICIPANT	\N	PRESENT	0
143167	143161	14065Q	PARTICIPANT	\N	PRESENT	0
143168	143161	14069U	PARTICIPANT	\N	PRESENT	0
143169	143161	04047H	PARTICIPANT	\N	PRESENT	0
143170	143161	11032E	PARTICIPANT	\N	PRESENT	0
143171	143161	04038G	PARTICIPANT	\N	PRESENT	0
143172	143161	99002P	PARTICIPANT	\N	PRESENT	0
143173	143161	11056N	PARTICIPANT	\N	PRESENT	0
143174	143161	14259Y	PARTICIPANT	\N	PRESENT	0
143175	143161	11035H	PARTICIPANT	\N	PRESENT	0
143348	143346	14215L	PARTICIPANT	\N	PRESENT	0
143177	143161	11113E	PARTICIPANT	\N	PRESENT	0
143178	143161	01024M	PARTICIPANT	\N	PRESENT	0
143179	143161	14215L	PARTICIPANT	\N	PRESENT	0
143180	143161	11034G	PARTICIPANT	\N	PRESENT	0
143181	143161	08018U	PARTICIPANT	\N	PRESENT	0
143349	143346	08018U	PARTICIPANT	\N	PRESENT	0
143183	143161	01007L	PARTICIPANT	\N	PRESENT	0
143350	143346	01037S	PARTICIPANT	\N	PRESENT	0
143185	143161	08044W	PARTICIPANT	\N	PRESENT	0
143186	143161	11084S	PARTICIPANT	\N	PRESENT	0
143187	143161	11026G	PARTICIPANT	\N	PRESENT	0
155742	155094	14261S	PARTICIPANT	\N	PRESENT	0
143189	143161	14111D	PARTICIPANT	\N	PRESENT	0
143190	143161	14001X	PARTICIPANT	\N	PRESENT	0
155744	155094	11071M	PARTICIPANT	\N	PRESENT	0
143192	143161	01060R	PARTICIPANT	\N	PRESENT	0
143193	143161	14147R	PARTICIPANT	\N	PRESENT	0
143194	143161	95049N	PARTICIPANT	\N	PRESENT	0
143195	143161	08051V	PARTICIPANT	\N	PRESENT	0
143196	143161	11072N	PARTICIPANT	\N	PRESENT	0
143197	143161	07034Q	PARTICIPANT	\N	PRESENT	0
143198	143161	04074L	PARTICIPANT	\N	PRESENT	0
143199	143161	10015M	PARTICIPANT	\N	PRESENT	0
143200	143161	95063L	PARTICIPANT	\N	PRESENT	0
143201	143161	01019Q	PARTICIPANT	\N	PRESENT	0
143202	143161	01028R	PRESIDENT	1	PRESENT	0
143203	143161	98035U	PARTICIPANT	\N	PRESENT	0
143204	143161	04056J	PARTICIPANT	\N	PRESENT	0
143205	143161	14275Y	PARTICIPANT	\N	PRESENT	0
143206	143161	04044E	PRESIDENT	2	PRESENT	0
143207	143161	11037K	PARTICIPANT	\N	PRESENT	0
143208	143161	92045V	PARTICIPANT	\N	PRESENT	0
143209	143161	95067Q	PARTICIPANT	\N	PRESENT	0
143210	143161	01047U	PARTICIPANT	\N	PRESENT	0
143353	143346	14001X	PARTICIPANT	\N	PRESENT	0
143354	143346	08053X	PARTICIPANT	\N	PRESENT	0
143355	143346	04070G	PARTICIPANT	\N	PRESENT	0
143356	143346	98035U	PARTICIPANT	\N	PRESENT	0
143357	143346	14014Q	PARTICIPANT	\N	PRESENT	0
155745	155094	01016M	PARTICIPANT	\N	PRESENT	0
155746	155094	08062Y	PARTICIPANT	\N	PRESENT	0
155747	155094	11039M	PARTICIPANT	\N	PRESENT	0
155748	155094	05004A	PARTICIPANT	\N	PRESENT	0
155749	155094	14157T	PARTICIPANT	\N	PRESENT	0
155750	155094	08018U	PARTICIPANT	\N	PRESENT	0
155751	155094	08052W	PARTICIPANT	\N	PRESENT	0
155752	155094	08025T	PARTICIPANT	\N	PRESENT	0
155753	155094	14151M	PARTICIPANT	\N	PRESENT	0
155754	155094	14051J	PARTICIPANT	\N	PRESENT	0
155755	155094	08055A	PARTICIPANT	\N	PRESENT	0
155756	155094	14259Y	PARTICIPANT	\N	PRESENT	0
155757	155094	01057W	PARTICIPANT	\N	PRESENT	0
155758	155094	14133K	PARTICIPANT	\N	PRESENT	0
155759	155094	01011G	PARTICIPANT	\N	PRESENT	0
155760	155094	92020L	PARTICIPANT	\N	PRESENT	0
155761	155094	08060W	PARTICIPANT	\N	PRESENT	0
155763	155094	95067Q	PARTICIPANT	\N	PRESENT	0
155764	155094	08053X	PARTICIPANT	\N	PRESENT	0
155765	155094	14197C	PARTICIPANT	\N	PRESENT	0
155766	155094	11030C	PARTICIPANT	\N	PRESENT	0
155770	155094	11067R	PARTICIPANT	\N	PRESENT	0
155771	155094	08068F	PARTICIPANT	\N	PRESENT	0
155772	155094	11059R	PARTICIPANT	\N	PRESENT	0
155773	155094	14213J	PARTICIPANT	\N	PRESENT	0
155774	155094	11089X	PARTICIPANT	\N	PRESENT	0
155775	155094	11036J	PARTICIPANT	\N	PRESENT	0
155776	155094	08042U	PARTICIPANT	\N	PRESENT	0
155777	155094	08047A	PARTICIPANT	\N	PRESENT	0
155778	155094	80027E	PARTICIPANT	\N	PRESENT	0
155779	155094	04034C	PARTICIPANT	\N	PRESENT	0
155780	155094	14079W	PARTICIPANT	\N	PRESENT	0
155781	155094	95037J	PARTICIPANT	\N	PRESENT	0
155782	155094	95035G	PARTICIPANT	\N	PRESENT	0
155783	155094	11049P	PARTICIPANT	\N	PRESENT	0
155784	155094	04053F	PARTICIPANT	\N	PRESENT	0
155785	155094	08058D	PARTICIPANT	\N	PRESENT	0
155786	155094	08015R	PARTICIPANT	\N	PRESENT	0
155787	155094	98029W	PARTICIPANT	\N	PRESENT	0
155788	155094	14014Q	PARTICIPANT	\N	PRESENT	0
155789	155094	14237S	PARTICIPANT	\N	PRESENT	0
155790	155094	14207L	PARTICIPANT	\N	PRESENT	0
155791	155094	14121F	PARTICIPANT	\N	PRESENT	0
155792	155094	14187A	PARTICIPANT	\N	PRESENT	0
155793	155094	14227Q	PARTICIPANT	\N	PRESENT	0
155794	155094	14167V	PARTICIPANT	\N	PRESENT	0
155795	155094	11054L	PARTICIPANT	\N	PRESENT	0
155796	155094	97011G	PARTICIPANT	\N	PRESENT	0
155797	155094	83047W	PARTICIPANT	\N	PRESENT	0
155798	155094	14061L	PARTICIPANT	\N	PRESENT	0
155799	155094	14281W	PARTICIPANT	\N	PRESENT	0
155800	155094	14271U	PARTICIPANT	\N	PRESENT	0
155801	155094	08022Q	PARTICIPANT	\N	PRESENT	0
155802	155094	04079R	PARTICIPANT	\N	PRESENT	0
155803	155094	14063N	PARTICIPANT	\N	PRESENT	0
155804	155094	11112D	PARTICIPANT	\N	PRESENT	0
155805	155094	14097Y	PARTICIPANT	\N	PRESENT	0
155806	155094	14087W	PARTICIPANT	\N	PRESENT	0
155807	155094	14257W	PARTICIPANT	\N	PRESENT	0
155808	155094	14215L	PARTICIPANT	\N	PRESENT	0
155809	155094	11014C	PARTICIPANT	\N	PRESENT	0
155810	155094	04077P	PARTICIPANT	\N	PRESENT	0
155811	155094	11104D	PARTICIPANT	\N	PRESENT	0
155812	155094	08038Y	PARTICIPANT	\N	PRESENT	0
155813	155094	11032E	PARTICIPANT	\N	PRESENT	0
155814	155094	14107H	PARTICIPANT	\N	PRESENT	0
155815	155094	14037X	PARTICIPANT	\N	PRESENT	0
155816	155094	08024S	PARTICIPANT	\N	PRESENT	0
155817	155094	11068S	PARTICIPANT	\N	PRESENT	0
155818	155094	11066Q	PARTICIPANT	\N	PRESENT	0
155819	155094	14085U	PARTICIPANT	\N	PRESENT	0
155820	155094	11106F	PARTICIPANT	\N	PRESENT	0
155821	155094	14251Q	PARTICIPANT	\N	PRESENT	0
155822	155094	14081Q	PARTICIPANT	\N	PRESENT	0
155823	155094	04045F	PARTICIPANT	\N	PRESENT	0
155824	155094	11061K	PARTICIPANT	\N	PRESENT	0
155825	155094	14053L	PARTICIPANT	\N	PRESENT	0
155826	155094	11042G	PARTICIPANT	\N	PRESENT	0
155827	155094	11077T	PARTICIPANT	\N	PRESENT	0
155828	155094	14159V	PARTICIPANT	\N	PRESENT	0
155829	155094	14269B	PARTICIPANT	\N	PRESENT	0
155830	155094	01014K	PARTICIPANT	\N	PRESENT	0
155831	155094	12042Y	PARTICIPANT	\N	PRESENT	0
155832	155094	11109J	PARTICIPANT	\N	PRESENT	0
155833	155094	11114F	PARTICIPANT	\N	PRESENT	0
155834	155094	14253S	PARTICIPANT	\N	PRESENT	0
137072	137032	08012N	PARTICIPANT	\N	PRESENT	0
137073	137032	14103D	PARTICIPANT	\N	PRESENT	0
137074	137032	11104D	PARTICIPANT	\N	PRESENT	0
137075	137032	14063N	PARTICIPANT	\N	PRESENT	0
137076	137032	04057K	PARTICIPANT	\N	PRESENT	0
137077	137032	11014C	PARTICIPANT	\N	PRESENT	0
137078	137032	14109K	PARTICIPANT	\N	PRESENT	0
137079	137032	04070G	PARTICIPANT	\N	EXCUSE	0
137080	137032	92040Q	PARTICIPANT	\N	PRESENT	0
137091	137090	14042U	PARTICIPANT	\N	PRESENT	0
137093	137090	11083R	PARTICIPANT	\N	PRESENT	0
137083	137032	14235Q	PARTICIPANT	\N	PRESENT	0
137084	137032	14055N	PARTICIPANT	\N	PRESENT	0
137085	137032	04033B	PARTICIPANT	\N	PRESENT	0
137086	137032	14229S	PARTICIPANT	\N	PRESENT	0
137087	137032	11043H	PARTICIPANT	\N	PRESENT	0
137088	137032	11071M	PARTICIPANT	\N	PRESENT	0
137089	137032	11011M	PARTICIPANT	\N	PRESENT	0
137092	137090	11043H	PARTICIPANT	\N	PRESENT	0
137094	137090	98046X	PARTICIPANT	\N	PRESENT	0
137096	137095	10015M	PARTICIPANT	\N	PRESENT	0
137098	137097	10015M	PARTICIPANT	\N	PRESENT	0
137100	137099	08025T	PARTICIPANT	\N	PRESENT	0
137101	137099	04085P	PARTICIPANT	\N	PRESENT	0
137102	137099	05008E	PRESIDENT	0	PRESENT	0
137103	137099	11030C	PARTICIPANT	\N	PRESENT	0
137104	137099	11033F	PARTICIPANT	\N	PRESENT	0
137105	137099	14069U	PARTICIPANT	\N	PRESENT	0
137106	137099	04047H	PARTICIPANT	\N	PRESENT	0
137107	137099	11032E	PARTICIPANT	\N	PRESENT	0
137108	137099	04038G	PARTICIPANT	\N	PRESENT	0
137109	137099	99002P	PARTICIPANT	\N	PRESENT	0
137110	137099	14259Y	PARTICIPANT	\N	PRESENT	0
137111	137099	11035H	PARTICIPANT	\N	PRESENT	0
137112	137099	11113E	PARTICIPANT	\N	PRESENT	0
137113	137099	01024M	PARTICIPANT	\N	PRESENT	0
137114	137099	14215L	PARTICIPANT	\N	PRESENT	0
137115	137099	11034G	PARTICIPANT	\N	PRESENT	0
137116	137099	08018U	PARTICIPANT	\N	PRESENT	0
137117	137099	11010L	PARTICIPANT	\N	PRESENT	0
137118	137099	01007L	PARTICIPANT	\N	PRESENT	0
137119	137099	11049P	PARTICIPANT	\N	PRESENT	0
137120	137099	08044W	PARTICIPANT	\N	EXCUSE	0
137121	137099	11026G	PARTICIPANT	\N	PRESENT	0
137122	137099	04079R	PARTICIPANT	\N	PRESENT	0
137123	137099	14111D	PARTICIPANT	\N	PRESENT	0
137124	137099	14001X	PARTICIPANT	\N	PRESENT	0
137125	137099	01060R	PARTICIPANT	\N	PRESENT	0
137126	137099	14147R	PARTICIPANT	\N	PRESENT	0
137127	137099	95049N	PARTICIPANT	\N	PRESENT	0
137128	137099	08051V	PARTICIPANT	\N	PRESENT	0
137129	137099	07034Q	PARTICIPANT	\N	PRESENT	0
137130	137099	04074L	PARTICIPANT	\N	PRESENT	0
137131	137099	10015M	PARTICIPANT	\N	PRESENT	0
137132	137099	95063L	PARTICIPANT	\N	PRESENT	0
137133	137099	01028R	PARTICIPANT	\N	PRESENT	0
137134	137099	98035U	PARTICIPANT	\N	PRESENT	0
137135	137099	04056J	PARTICIPANT	\N	PRESENT	0
137136	137099	04044E	PARTICIPANT	\N	PRESENT	0
137137	137099	11037K	PARTICIPANT	\N	EXCUSE	0
137138	137099	92045V	PARTICIPANT	\N	PRESENT	0
137139	137099	95067Q	PARTICIPANT	\N	PRESENT	0
137140	137099	01047U	PARTICIPANT	\N	PRESENT	0
137354	137353	08025T	PARTICIPANT	\N	PRESENT	0
137355	137353	04085P	PARTICIPANT	\N	PRESENT	0
137356	137353	05008E	PARTICIPANT	\N	PRESENT	0
137357	137353	11033F	PARTICIPANT	\N	PRESENT	0
137358	137353	14069U	PARTICIPANT	\N	PRESENT	0
137359	137353	04047H	PARTICIPANT	\N	PRESENT	0
137360	137353	04038G	PARTICIPANT	\N	PRESENT	0
137361	137353	99002P	PARTICIPANT	\N	PRESENT	0
137362	137353	14259Y	PARTICIPANT	\N	PRESENT	0
137363	137353	11035H	PARTICIPANT	\N	PRESENT	0
137364	137353	01024M	PARTICIPANT	\N	PRESENT	0
137365	137353	14215L	PARTICIPANT	\N	PRESENT	0
137366	137353	11034G	PARTICIPANT	\N	PRESENT	0
137367	137353	08018U	PARTICIPANT	\N	PRESENT	0
137368	137353	01007L	PARTICIPANT	\N	PRESENT	0
137369	137353	11049P	PARTICIPANT	\N	PRESENT	0
137371	137353	08044W	PARTICIPANT	\N	EXCUSE	0
137372	137353	11026G	PARTICIPANT	\N	PRESENT	0
137416	137353	14001X	PARTICIPANT	\N	PRESENT	0
137373	137370	14239U	PARTICIPANT	\N	PRESENT	0
137374	137370	11055M	PARTICIPANT	\N	PRESENT	0
137375	137370	01046T	PARTICIPANT	\N	PRESENT	0
137376	137370	04053F	PARTICIPANT	\N	PRESENT	0
137377	137370	14255U	PARTICIPANT	\N	EXCUSE	0
137378	137370	04066L	PARTICIPANT	\N	PRESENT	0
137379	137370	00003C	PARTICIPANT	\N	EXCUSE	0
137380	137370	14053L	PARTICIPANT	\N	PRESENT	0
137381	137370	11103C	PARTICIPANT	\N	PRESENT	0
137382	137370	11044J	PARTICIPANT	\N	PRESENT	0
137383	137370	14195A	PARTICIPANT	\N	PRESENT	0
137384	137370	14267Y	PARTICIPANT	\N	PRESENT	0
137476	137475	04047H	PARTICIPANT	\N	PRESENT	0
137386	137370	11031D	PARTICIPANT	\N	PRESENT	0
137387	137370	08052W	PARTICIPANT	\N	PRESENT	0
137388	137370	01059Y	PARTICIPANT	\N	PRESENT	0
137389	137370	04081K	PARTICIPANT	\N	PRESENT	0
137390	137370	98024R	PARTICIPANT	\N	PRESENT	0
137391	137370	10006L	PARTICIPANT	\N	PRESENT	0
137392	137370	04067M	PARTICIPANT	\N	PRESENT	0
137393	137370	14217N	PARTICIPANT	\N	PRESENT	0
137394	137370	14042U	PARTICIPANT	\N	PRESENT	0
137395	137370	14151M	PARTICIPANT	\N	PRESENT	0
137396	137370	12042Y	PARTICIPANT	\N	PRESENT	0
137397	137370	14281W	PARTICIPANT	\N	PRESENT	0
137398	137370	14087W	PARTICIPANT	\N	PRESENT	0
137554	137553	10015M	PARTICIPANT	\N	PRESENT	0
137567	137566	95030B	PARTICIPANT	\N	PRESENT	0
137401	137370	14231L	PARTICIPANT	\N	PRESENT	0
137402	137370	11061K	PARTICIPANT	\N	PRESENT	0
137403	137370	08048B	PARTICIPANT	\N	PRESENT	0
137404	137370	08041T	PARTICIPANT	\N	PRESENT	0
137405	137370	01011G	PARTICIPANT	\N	PRESENT	0
137406	137370	14026U	PARTICIPANT	\N	PRESENT	0
137407	137370	14213J	PARTICIPANT	\N	PRESENT	0
137408	137370	14121F	PARTICIPANT	\N	PRESENT	0
137409	137370	11112D	PARTICIPANT	\N	PRESENT	0
137410	137370	14037X	PARTICIPANT	\N	PRESENT	0
137411	137370	14018U	PARTICIPANT	\N	PRESENT	0
137412	137370	11067R	PARTICIPANT	\N	EXCUSE	0
137413	137370	14223L	PARTICIPANT	\N	PRESENT	0
137414	137370	04092N	PRESIDENT	0	PRESENT	0
137415	137370	14265W	PARTICIPANT	\N	EXCUSE	0
137417	137370	14119M	PARTICIPANT	\N	PRESENT	0
137418	137370	14071N	PARTICIPANT	\N	PRESENT	0
137419	137370	07032N	PARTICIPANT	\N	PRESENT	0
137420	137370	04043D	PARTICIPANT	\N	PRESENT	0
137421	137370	14271U	PARTICIPANT	\N	PRESENT	0
137568	137566	14001X	PARTICIPANT	\N	PRESENT	0
137423	137370	11093T	PARTICIPANT	\N	PRESENT	0
137424	137370	11097X	PARTICIPANT	\N	PRESENT	0
137425	137370	04045F	PARTICIPANT	\N	PRESENT	0
137426	137370	14227Q	PARTICIPANT	\N	PRESENT	0
137427	137370	01034P	PARTICIPANT	\N	PRESENT	0
137570	137569	04040A	PRESIDENT	0	PRESENT	0
137429	137370	11063M	PARTICIPANT	\N	PRESENT	0
137430	137370	14269B	PARTICIPANT	\N	PRESENT	0
137431	137353	01060R	PARTICIPANT	\N	PRESENT	0
137433	137353	14147R	PARTICIPANT	\N	PRESENT	0
137434	137353	95049N	PARTICIPANT	\N	PRESENT	0
137436	137353	08051V	PARTICIPANT	\N	PRESENT	0
137437	137353	07034Q	PARTICIPANT	\N	PRESENT	0
137439	137353	04074L	PARTICIPANT	\N	PRESENT	0
137440	137353	10015M	PARTICIPANT	\N	PRESENT	0
137441	137353	95063L	PARTICIPANT	\N	PRESENT	0
137442	137353	01028R	PARTICIPANT	\N	PRESENT	0
137443	137353	98035U	PARTICIPANT	\N	PRESENT	0
137444	137353	04056J	PARTICIPANT	\N	PRESENT	0
137445	137353	04044E	PARTICIPANT	\N	PRESENT	0
137446	137353	11037K	PARTICIPANT	\N	EXCUSE	0
137447	137353	92045V	PARTICIPANT	\N	PRESENT	0
137449	137353	95067Q	PARTICIPANT	\N	PRESENT	0
137450	137353	01047U	PARTICIPANT	\N	PRESENT	0
137572	137571	11056N	PARTICIPANT	\N	PRESENT	0
137613	137612	11083R	PARTICIPANT	\N	PRESENT	0
137614	137612	14263U	PARTICIPANT	\N	PRESENT	0
137615	137612	04059M	PARTICIPANT	\N	EXCUSE	0
137616	137612	01044R	PARTICIPANT	\N	PRESENT	0
137617	137612	08043V	PARTICIPANT	\N	PRESENT	0
137618	137612	14089Y	PARTICIPANT	\N	PRESENT	0
137619	137612	11029K	PARTICIPANT	\N	PRESENT	0
137620	137612	95015C	PARTICIPANT	\N	PRESENT	0
137621	137612	92015P	PARTICIPANT	\N	PRESENT	0
137622	137612	14201E	PARTICIPANT	\N	EXCUSE	0
137623	137612	01025N	PARTICIPANT	\N	PRESENT	0
137624	137612	01037S	PARTICIPANT	\N	PRESENT	0
137625	137612	14179A	PARTICIPANT	\N	PRESENT	0
146978	146977	97011G	PARTICIPANT	\N	PRESENT	0
149633	149632	14253S	PARTICIPANT	\N	PRESENT	0
147054	147052	04043D	PARTICIPANT	\N	PRESENT	0
149634	149632	14157T	PARTICIPANT	\N	PRESENT	0
150057	150056	08019V	PARTICIPANT	\N	PRESENT	0
150059	150058	08019V	PARTICIPANT	\N	PRESENT	0
150061	150060	08019V	PARTICIPANT	\N	PRESENT	0
150063	150062	08019V	PARTICIPANT	\N	PRESENT	0
150065	150064	08019V	PARTICIPANT	\N	PRESENT	0
151273	151272	11039M	PARTICIPANT	\N	PRESENT	0
151274	151272	98042T	PARTICIPANT	\N	PRESENT	0
151275	151272	01019Q	PARTICIPANT	\N	PRESENT	0
158413	158412	01008M	PARTICIPANT	\N	PRESENT	0
158343	158325	04097T	PARTICIPANT	\N	PRESENT	0
158344	158325	09001P	PARTICIPANT	\N	PRESENT	0
158345	158325	11059R	PARTICIPANT	\N	PRESENT	0
158346	158325	14219Q	PARTICIPANT	\N	PRESENT	0
158347	158325	80027E	PARTICIPANT	\N	PRESENT	0
158348	158325	14031R	PARTICIPANT	\N	PRESENT	0
158349	158325	08009T	PRESIDENT	0	PRESENT	0
158350	158325	08062Y	PARTICIPANT	\N	PRESENT	0
158351	158325	14221J	PARTICIPANT	\N	PRESENT	0
158414	158412	11036J	PARTICIPANT	\N	PRESENT	0
158415	158412	11081P	PARTICIPANT	\N	PRESENT	0
158354	158325	14169X	PARTICIPANT	\N	PRESENT	0
158355	158325	14237S	PARTICIPANT	\N	PRESENT	0
158356	158325	13002U	PARTICIPANT	\N	PRESENT	0
158357	158325	05012A	PARTICIPANT	\N	PRESENT	0
158358	158325	14247U	PARTICIPANT	\N	PRESENT	0
158359	158325	14135M	PARTICIPANT	\N	PRESENT	0
158360	158325	14331P	PARTICIPANT	\N	PRESENT	0
158361	158325	95062K	PARTICIPANT	\N	PRESENT	0
158362	158325	14107H	PARTICIPANT	\N	PRESENT	0
158363	158325	14051J	PARTICIPANT	\N	PRESENT	0
158364	158325	14157T	PARTICIPANT	\N	PRESENT	0
158367	158365	08055A	PARTICIPANT	\N	PRESENT	0
158368	158365	14093U	PARTICIPANT	\N	PRESENT	0
158369	158365	14030Q	PARTICIPANT	\N	PRESENT	0
158370	158365	96004D	PARTICIPANT	\N	PRESENT	0
158371	158365	08060W	PARTICIPANT	\N	PRESENT	0
158416	158412	14013P	PARTICIPANT	\N	PRESENT	0
158417	158412	08068F	PARTICIPANT	\N	PRESENT	0
158374	158365	11114F	PARTICIPANT	\N	PRESENT	0
158375	158365	98023Q	PARTICIPANT	\N	PRESENT	0
158376	158365	11065P	PARTICIPANT	\N	PRESENT	0
158377	158365	01015L	PARTICIPANT	\N	PRESENT	0
158378	158365	11107G	PARTICIPANT	\N	PRESENT	0
158379	158365	11020A	PARTICIPANT	\N	PRESENT	0
158380	158365	02002K	PARTICIPANT	\N	PRESENT	0
158381	158365	01022K	PARTICIPANT	\N	PRESENT	0
158418	158412	14207L	PARTICIPANT	\N	PRESENT	0
158383	158365	04097T	PARTICIPANT	\N	PRESENT	0
158384	158365	09001P	PARTICIPANT	\N	PRESENT	0
158385	158365	11059R	PARTICIPANT	\N	PRESENT	0
158386	158365	14219Q	PARTICIPANT	\N	PRESENT	0
158387	158365	80027E	PARTICIPANT	\N	PRESENT	0
158388	158365	14031R	PARTICIPANT	\N	PRESENT	0
158389	158365	08009T	PRESIDENT	0	PRESENT	0
158390	158365	08062Y	PARTICIPANT	\N	PRESENT	0
158391	158365	14221J	PARTICIPANT	\N	PRESENT	0
158453	158452	08012N	PARTICIPANT	\N	PRESENT	0
158420	158412	90003B	PARTICIPANT	\N	PRESENT	0
158394	158365	14169X	PARTICIPANT	\N	PRESENT	0
158421	158412	08028W	PARTICIPANT	\N	PRESENT	0
158396	158365	13002U	PARTICIPANT	\N	PRESENT	0
158397	158365	05012A	PARTICIPANT	\N	PRESENT	0
158454	158452	92040Q	PARTICIPANT	\N	PRESENT	0
158399	158365	14135M	PARTICIPANT	\N	PRESENT	0
158400	158365	14331P	PARTICIPANT	\N	PRESENT	0
158401	158365	95062K	PARTICIPANT	\N	PRESENT	0
158455	158452	95062K	PARTICIPANT	\N	PRESENT	0
158403	158365	14051J	PARTICIPANT	\N	PRESENT	0
158404	158365	14157T	PARTICIPANT	\N	PRESENT	0
158422	158412	80013X	PARTICIPANT	\N	PRESENT	0
158423	158412	14357A	PARTICIPANT	\N	PRESENT	0
158424	158412	08038Y	PARTICIPANT	\N	PRESENT	0
158425	158412	04089T	PARTICIPANT	\N	PRESENT	0
158426	158412	14197C	PARTICIPANT	\N	PRESENT	0
158427	158412	11110B	PARTICIPANT	\N	PRESENT	0
158456	158452	01008M	PARTICIPANT	\N	PRESENT	0
158429	158412	14033T	PARTICIPANT	\N	PRESENT	0
158430	158412	14081Q	PARTICIPANT	\N	PRESENT	0
158431	158412	11099A	PARTICIPANT	\N	PRESENT	0
158432	158412	04049K	PARTICIPANT	\N	PRESENT	0
158433	158412	04094Q	PARTICIPANT	\N	PRESENT	0
158434	158412	11111C	PARTICIPANT	\N	PRESENT	0
158435	158412	08015R	PARTICIPANT	\N	PRESENT	0
158436	158412	11100Y	PRESIDENT	0	PRESENT	0
158437	158412	01061S	PARTICIPANT	\N	EXCUSE	0
158438	158412	11098Y	PARTICIPANT	\N	PRESENT	0
158439	158412	01043Q	PARTICIPANT	\N	PRESENT	0
158440	158412	11077T	PARTICIPANT	\N	PRESENT	0
158441	158412	14205J	PARTICIPANT	\N	PRESENT	0
158442	158412	08019V	PARTICIPANT	\N	EXCUSE	0
158443	158412	14257W	PARTICIPANT	\N	PRESENT	0
158444	158412	08021P	PARTICIPANT	\N	EXCUSE	0
158445	158412	04088S	PARTICIPANT	\N	PRESENT	0
158446	158412	98050T	PARTICIPANT	\N	PRESENT	0
158447	158412	11090Q	PARTICIPANT	\N	PRESENT	0
158448	158412	11046L	PARTICIPANT	\N	PRESENT	0
158449	158412	01058X	PARTICIPANT	\N	PRESENT	0
158450	158412	11094U	PARTICIPANT	\N	PRESENT	0
158451	158412	11066Q	PARTICIPANT	\N	PRESENT	0
158457	158452	96004D	PARTICIPANT	\N	PRESENT	0
158472	158325	11020A	PARTICIPANT	\N	PRESENT	0
159688	158052	11113E	PARTICIPANT	\N	PRESENT	0
159689	158052	04067M	PARTICIPANT	\N	PRESENT	0
159690	158052	97011G	PARTICIPANT	\N	PRESENT	0
159691	158052	04074L	PARTICIPANT	\N	PRESENT	0
159692	158052	14267Y	PARTICIPANT	\N	PRESENT	0
159693	158052	14227Q	PARTICIPANT	\N	PRESENT	0
159694	158052	83047W	PARTICIPANT	\N	PRESENT	0
159695	158052	01011G	PARTICIPANT	\N	PRESENT	0
159696	158052	14257W	PARTICIPANT	\N	PRESENT	0
159697	158052	11076S	PARTICIPANT	\N	PRESENT	0
159698	158052	92015P	PARTICIPANT	\N	PRESENT	0
159686	158052	14061L	PARTICIPANT	\N	PRESENT	0
159687	158052	98018T	PARTICIPANT	\N	PRESENT	0
159699	158052	99002P	PARTICIPANT	\N	PRESENT	0
159700	158052	04045F	PARTICIPANT	\N	PRESENT	0
159701	158052	11054L	PARTICIPANT	\N	PRESENT	0
159702	158052	11104D	PARTICIPANT	\N	PRESENT	0
159712	158052	02002K	PARTICIPANT	\N	PRESENT	0
159713	158052	86044G	PARTICIPANT	\N	PRESENT	0
159714	158052	04042C	PARTICIPANT	\N	PRESENT	0
159715	158052	98035U	PARTICIPANT	\N	PRESENT	0
159716	158052	11046L	PARTICIPANT	\N	PRESENT	0
159717	158052	11033F	PARTICIPANT	\N	PRESENT	0
159718	158052	14042U	PARTICIPANT	\N	PRESENT	0
159732	158052	14159V	PARTICIPANT	\N	PRESENT	0
159733	158052	08015R	PARTICIPANT	\N	PRESENT	0
159734	158052	14111D	PARTICIPANT	\N	PRESENT	0
159735	158052	11097X	PARTICIPANT	\N	PRESENT	0
159736	158052	01044R	PARTICIPANT	\N	PRESENT	0
159737	158052	98042T	PARTICIPANT	\N	PRESENT	0
159738	158052	98029W	PARTICIPANT	\N	PRESENT	0
159739	158052	12042Y	PARTICIPANT	\N	PRESENT	0
159740	158052	11105E	PARTICIPANT	\N	PRESENT	0
159741	158052	11027H	PARTICIPANT	\N	PRESENT	0
159742	158052	14363X	PARTICIPANT	\N	PRESENT	0
159743	158052	04092N	PARTICIPANT	\N	PRESENT	0
159744	158052	14147R	PARTICIPANT	\N	PRESENT	0
159745	158052	11044J	PARTICIPANT	\N	PRESENT	0
159746	158052	08014Q	PARTICIPANT	\N	PRESENT	0
159747	158052	14028W	PARTICIPANT	\N	PRESENT	0
159748	158052	92020L	PARTICIPANT	\N	PRESENT	0
159749	158052	01027Q	PARTICIPANT	\N	PRESENT	0
159750	158052	14030Q	PARTICIPANT	\N	PRESENT	0
159751	158052	04080J	PARTICIPANT	\N	PRESENT	0
159752	158052	95031C	PARTICIPANT	\N	PRESENT	0
159753	158052	14275Y	PARTICIPANT	\N	PRESENT	0
160241	160238	11090Q	PRESIDENT	0	PRESENT	0
160242	160238	14093U	PARTICIPANT	\N	PRESENT	0
160243	160238	05012A	PARTICIPANT	\N	PRESENT	0
160244	160238	92045V	PARTICIPANT	\N	PRESENT	0
160265	160238	14219Q	PARTICIPANT	\N	PRESENT	0
160332	160238	11065P	PARTICIPANT	\N	PRESENT	0
160333	160238	14033T	PARTICIPANT	\N	EXCUSE	0
160334	160238	80013X	PARTICIPANT	\N	EXCUSE	0
160335	160238	01015L	PARTICIPANT	\N	EXCUSE	0
160336	160238	09001P	PARTICIPANT	\N	EXCUSE	0
160337	160238	01056V	PARTICIPANT	\N	EXCUSE	0
160339	160338	14239U	PARTICIPANT	\N	PRESENT	0
160340	160338	98022P	PARTICIPANT	\N	PRESENT	0
160341	160338	11084S	PARTICIPANT	\N	PRESENT	0
160342	160338	04036E	PARTICIPANT	\N	PRESENT	0
160343	160338	11105E	PARTICIPANT	\N	PRESENT	0
160345	160344	14133K	PARTICIPANT	\N	PRESENT	0
130336	130334	08042U	PARTICIPANT	\N	PRESENT	0
130338	130337	08042U	PARTICIPANT	\N	PRESENT	0
130340	130339	08042U	PARTICIPANT	\N	PRESENT	0
130342	130341	08042U	PARTICIPANT	\N	PRESENT	0
130343	120701	14017T	PARTICIPANT	\N	EXCUSE	0
130345	130344	04080J	PARTICIPANT	\N	PRESENT	0
130346	124956	08069G	PARTICIPANT	\N	EXCUSE	0
130348	124956	01058X	PRESIDENT	1	PRESENT	0
130839	130838	96004D	PARTICIPANT	\N	PRESENT	0
130840	130838	04040A	PARTICIPANT	\N	PRESENT	0
130841	130838	04042C	PARTICIPANT	\N	PRESENT	0
130842	130838	04035D	PARTICIPANT	\N	EXCUSE	0
130843	130838	07024N	PARTICIPANT	\N	PRESENT	0
130844	130838	14014Q	PARTICIPANT	\N	PRESENT	0
130845	130838	14097Y	PARTICIPANT	\N	PRESENT	0
130846	130838	83042R	PARTICIPANT	\N	PRESENT	0
130847	130838	04057K	PARTICIPANT	\N	EXCUSE	0
130848	130838	95059Q	PARTICIPANT	\N	EXCUSE	0
130855	130854	14263U	PARTICIPANT	\N	PRESENT	0
130856	130854	14133K	PARTICIPANT	\N	PRESENT	0
130857	130854	11109J	PARTICIPANT	\N	PRESENT	0
130858	130854	04059M	PARTICIPANT	\N	PRESENT	0
130859	130854	11039M	PARTICIPANT	\N	PRESENT	0
130860	130854	01044R	PARTICIPANT	\N	PRESENT	0
130861	130854	08043V	PARTICIPANT	\N	PRESENT	0
130862	130854	14089Y	PARTICIPANT	\N	EXCUSE	0
130863	130854	14105F	PARTICIPANT	\N	PRESENT	0
130864	130854	11029K	PARTICIPANT	\N	PRESENT	0
130865	130854	95015C	PARTICIPANT	\N	PRESENT	0
130866	130854	92015P	PARTICIPANT	\N	PRESENT	0
130867	130854	08024S	PARTICIPANT	\N	PRESENT	0
130868	130854	14201E	PARTICIPANT	\N	PRESENT	0
130869	130854	14329V	PARTICIPANT	\N	PRESENT	0
131027	131026	04059M	PARTICIPANT	\N	PRESENT	0
130871	130854	14079W	PARTICIPANT	\N	PRESENT	0
130872	130854	11091R	PARTICIPANT	\N	PRESENT	0
130873	130854	87003B	PARTICIPANT	\N	PRESENT	0
130874	130854	98042T	PARTICIPANT	\N	PRESENT	0
130875	130854	14249W	PARTICIPANT	\N	PRESENT	0
131030	131028	04059M	PARTICIPANT	\N	PRESENT	0
130877	130854	01025N	PARTICIPANT	\N	PRESENT	0
137957	137956	04085P	PARTICIPANT	\N	EXCUSE	0
130879	130854	89029V	PARTICIPANT	\N	PRESENT	0
130880	130854	08035V	PARTICIPANT	\N	PRESENT	0
130881	130854	11089X	PARTICIPANT	\N	PRESENT	0
130882	130854	07026Q	PARTICIPANT	\N	PRESENT	0
130883	130854	14123H	PARTICIPANT	\N	PRESENT	0
130884	130854	14179A	PARTICIPANT	\N	PRESENT	0
138016	137956	05008E	PRESIDENT	0	PRESENT	0
130886	130854	14241N	PARTICIPANT	\N	PRESENT	0
130887	130854	14061L	PARTICIPANT	\N	PRESENT	0
130888	130854	14073Q	PARTICIPANT	\N	PRESENT	0
130889	130854	08031R	PARTICIPANT	\N	PRESENT	0
130890	130854	12041X	PARTICIPANT	\N	PRESENT	0
130891	130854	08039A	PARTICIPANT	\N	PRESENT	0
130892	130854	08017T	PARTICIPANT	\N	PRESENT	0
130893	130854	14059S	PARTICIPANT	\N	PRESENT	0
130894	130854	08012N	PARTICIPANT	\N	PRESENT	0
130895	130854	14103D	PARTICIPANT	\N	PRESENT	0
130896	130854	11104D	PARTICIPANT	\N	PRESENT	0
130897	130854	14063N	PARTICIPANT	\N	PRESENT	0
130898	130854	04057K	PARTICIPANT	\N	PRESENT	0
130899	130854	11014C	PARTICIPANT	\N	PRESENT	0
130900	130854	14109K	PARTICIPANT	\N	PRESENT	0
130901	130854	04070G	PRESIDENT	0	PRESENT	0
130902	130854	92040Q	PARTICIPANT	\N	PRESENT	0
138017	137956	11033F	PARTICIPANT	\N	PRESENT	0
130904	130854	83047W	PARTICIPANT	\N	PRESENT	0
130905	130854	14235Q	PARTICIPANT	\N	PRESENT	0
138018	137956	14065Q	PARTICIPANT	\N	PRESENT	0
130907	130854	04033B	PARTICIPANT	\N	PRESENT	0
130908	130854	14229S	PARTICIPANT	\N	PRESENT	0
130909	130854	11043H	PARTICIPANT	\N	PRESENT	0
130910	130854	11071M	PARTICIPANT	\N	PRESENT	0
138019	137956	14069U	PARTICIPANT	\N	PRESENT	0
138020	137956	04047H	PARTICIPANT	\N	PRESENT	0
138021	137956	04038G	PARTICIPANT	\N	PRESENT	0
138022	137956	11056N	PARTICIPANT	\N	EXCUSE	0
138023	137956	11035H	PARTICIPANT	\N	PRESENT	0
138024	137956	14041T	PARTICIPANT	\N	PRESENT	0
138025	137956	11113E	PARTICIPANT	\N	PRESENT	0
138026	137956	01024M	PARTICIPANT	\N	PRESENT	0
138027	137956	08044W	PARTICIPANT	\N	EXCUSE	0
138028	137956	11026G	PARTICIPANT	\N	PRESENT	0
138031	137956	14111D	PARTICIPANT	\N	PRESENT	0
138032	137956	14001X	PARTICIPANT	\N	PRESENT	0
138033	137956	14147R	PARTICIPANT	\N	PRESENT	0
138034	137956	95049N	PARTICIPANT	\N	EXCUSE	0
138035	137956	07034Q	PARTICIPANT	\N	PRESENT	0
138036	137956	95063L	PARTICIPANT	\N	PRESENT	0
138037	137956	01028R	PARTICIPANT	\N	PRESENT	0
138038	137956	04056J	PARTICIPANT	\N	PRESENT	0
138039	137956	04044E	PARTICIPANT	\N	EXCUSE	0
138040	137956	11037K	PARTICIPANT	\N	PRESENT	0
138041	137956	95067Q	PARTICIPANT	\N	PRESENT	0
138042	137956	11015D	PARTICIPANT	\N	PRESENT	0
138044	137956	01058X	PARTICIPANT	\N	PRESENT	0
138045	137956	04036E	PARTICIPANT	\N	PRESENT	0
138046	137956	14157T	PARTICIPANT	\N	PRESENT	0
138047	137956	04097T	PARTICIPANT	\N	PRESENT	0
138048	137956	04086Q	PARTICIPANT	\N	PRESENT	0
138049	137956	07026Q	PARTICIPANT	\N	PRESENT	0
138050	137956	95035G	PARTICIPANT	\N	PRESENT	0
138051	137956	01031L	PARTICIPANT	\N	PRESENT	0
138052	137956	14219Q	PARTICIPANT	\N	PRESENT	0
138053	137956	08068F	PARTICIPANT	\N	PRESENT	0
138054	137956	14119M	PARTICIPANT	\N	PRESENT	0
138055	137956	04078Q	PARTICIPANT	\N	PRESENT	0
138056	137956	08010L	PARTICIPANT	\N	PRESENT	0
138057	137956	11083R	PARTICIPANT	\N	PRESENT	0
138058	137956	01056V	PARTICIPANT	\N	PRESENT	0
138059	137956	14179A	PARTICIPANT	\N	PRESENT	0
138060	137956	14251Q	PARTICIPANT	\N	PRESENT	0
138061	137956	14038Y	PARTICIPANT	\N	PRESENT	0
138062	137956	04033B	PARTICIPANT	\N	PRESENT	0
138063	137956	11071M	PARTICIPANT	\N	PRESENT	0
138064	137956	11042G	PARTICIPANT	\N	PRESENT	0
138065	137956	07029T	PARTICIPANT	\N	PRESENT	0
138066	137956	04048J	PARTICIPANT	\N	PRESENT	0
138648	138647	96004D	PRESIDENT	0	PRESENT	0
138649	138647	04035D	PARTICIPANT	\N	PRESENT	0
138650	138647	07024N	PRESIDENT	1	PRESENT	0
138651	138647	14014Q	PARTICIPANT	\N	PRESENT	0
138652	138647	14097Y	PARTICIPANT	\N	PRESENT	0
138653	138647	14001X	PARTICIPANT	\N	PRESENT	0
138654	138647	83042R	PARTICIPANT	\N	PRESENT	0
138655	138647	04057K	PARTICIPANT	\N	EXCUSE	0
138656	138647	95059Q	PARTICIPANT	\N	EXCUSE	0
138657	138647	98035U	PARTICIPANT	\N	PRESENT	0
138700	138699	14030Q	PARTICIPANT	\N	PRESENT	0
138701	138699	11023D	PARTICIPANT	\N	PRESENT	0
138702	138699	01024M	PARTICIPANT	\N	PRESENT	0
138703	138699	01015L	PARTICIPANT	\N	PRESENT	0
138704	138699	14073Q	PARTICIPANT	\N	PRESENT	0
138705	138699	14031R	PARTICIPANT	\N	PRESENT	0
138706	138699	11085T	PARTICIPANT	\N	PRESENT	0
138707	138699	92039X	PARTICIPANT	\N	PRESENT	0
138708	138699	14271U	PARTICIPANT	\N	PRESENT	0
138709	138699	92045V	PARTICIPANT	\N	PRESENT	0
500871	500870	19515S	PARTICIPANT	\N	PRESENT	0
500873	500872	19515S	PARTICIPANT	\N	PRESENT	0
500876	500875	19515S	PARTICIPANT	\N	PRESENT	0
501279	500571	18083K	PARTICIPANT	\N	PRESENT	0
501280	500571	19701S	PARTICIPANT	\N	EXCUSE	0
501281	500571	19525U	PARTICIPANT	\N	PRESENT	0
501282	500571	20068G	PARTICIPANT	\N	EXCUSE	0
501283	500571	05012A	PARTICIPANT	\N	PRESENT	0
501434	501433	01048V	PARTICIPANT	\N	PRESENT	0
501438	501437	01048V	PARTICIPANT	\N	PRESENT	0
501491	500411	19367Y	PARTICIPANT	\N	EXCUSE	0
501492	500411	19295A	PARTICIPANT	\N	EXCUSE	0
501806	500477	19741B	PARTICIPANT	\N	PRESENT	0
501807	500477	11040E	PARTICIPANT	\N	PRESENT	0
501808	500477	19545Y	PARTICIPANT	\N	PRESENT	0
501809	500477	14327T	PARTICIPANT	\N	PRESENT	0
501810	500477	11074Q	PARTICIPANT	\N	PRESENT	0
501811	500477	14121F	PARTICIPANT	\N	PRESENT	0
501812	500477	19335Q	PARTICIPANT	\N	PRESENT	0
501813	500477	19762G	PARTICIPANT	\N	PRESENT	0
501814	500477	19479G	PARTICIPANT	\N	PRESENT	0
501927	495438	20144B	PARTICIPANT	\N	PRESENT	0
501929	495438	95063L	PARTICIPANT	\N	PRESENT	0
502081	502080	14123H	PARTICIPANT	\N	PRESENT	0
502083	502082	19758L	PARTICIPANT	\N	PRESENT	0
502084	502082	19719D	PARTICIPANT	\N	PRESENT	0
502086	502085	19719D	PARTICIPANT	\N	PRESENT	0
502382	502379	01043Q	PARTICIPANT	\N	PRESENT	0
502388	502380	01043Q	PARTICIPANT	\N	PRESENT	0
139788	139787	01031L	PRESIDENT	0	PRESENT	0
139789	139787	01013J	PARTICIPANT	\N	PRESENT	0
139790	139787	08014Q	PARTICIPANT	\N	PRESENT	0
139791	139787	14175V	PARTICIPANT	\N	PRESENT	0
139792	139787	14083S	PARTICIPANT	\N	PRESENT	0
139793	139787	11053K	PARTICIPANT	\N	PRESENT	0
139794	139787	11042G	PARTICIPANT	\N	PRESENT	0
139795	139787	88008L	PARTICIPANT	\N	PRESENT	0
139796	139787	04086Q	PARTICIPANT	\N	PRESENT	0
139797	139787	11070L	PARTICIPANT	\N	PRESENT	0
139798	139787	11088W	PARTICIPANT	\N	PRESENT	0
139799	139787	08022Q	PARTICIPANT	\N	PRESENT	0
139800	139787	01027Q	PARTICIPANT	\N	PRESENT	0
139801	139787	04071H	PARTICIPANT	\N	PRESENT	0
139802	139787	11083R	PARTICIPANT	\N	PRESENT	0
139803	139787	01057W	PARTICIPANT	\N	PRESENT	0
139804	139787	99004R	PARTICIPANT	\N	PRESENT	0
139805	139787	14159V	PARTICIPANT	\N	PRESENT	0
139806	139787	07029T	PARTICIPANT	\N	PRESENT	0
139807	139787	08010L	PARTICIPANT	\N	PRESENT	0
139808	139787	08034U	PARTICIPANT	\N	PRESENT	0
139809	139787	98046X	PARTICIPANT	\N	PRESENT	0
139810	139787	08011M	PARTICIPANT	\N	PRESENT	0
139811	139787	01016M	PARTICIPANT	\N	PRESENT	0
139812	139787	11057P	PARTICIPANT	\N	PRESENT	0
139813	139787	14173T	PARTICIPANT	\N	PRESENT	0
139814	139787	04034C	PARTICIPANT	\N	PRESENT	0
139818	139787	11054L	RAPPORTEUR_AVIS	\N	PRESENT	0
139820	139787	01014K	RAPPORTEUR_AVIS	\N	PRESENT	0
139821	139787	01056V	RAPPORTEUR_AVIS	\N	PRESENT	0
139825	139787	98053W	PARTICIPANT	\N	EXCUSE	0
140150	140148	14327T	PARTICIPANT	\N	PRESENT	0
140221	140220	04086Q	PARTICIPANT	\N	PRESENT	0
140222	140220	14223L	PARTICIPANT	\N	PRESENT	0
140223	140220	04040A	PARTICIPANT	\N	PRESENT	0
140224	140220	04036E	PARTICIPANT	\N	PRESENT	0
140225	140220	10006L	PARTICIPANT	\N	PRESENT	0
140259	140258	14133K	PARTICIPANT	\N	PRESENT	0
140260	140258	04054G	PARTICIPANT	\N	PRESENT	0
140261	140258	96004D	PRESIDENT	0	PRESENT	0
140262	140258	14089Y	PARTICIPANT	\N	PRESENT	0
140263	140258	14079W	PARTICIPANT	\N	PRESENT	0
140264	140258	11083R	PARTICIPANT	\N	PRESENT	0
140265	140258	14097Y	PARTICIPANT	\N	PRESENT	0
140266	140258	14073Q	PARTICIPANT	\N	PRESENT	0
140267	140258	11026G	PARTICIPANT	\N	PRESENT	0
140268	140258	98046X	PARTICIPANT	\N	PRESENT	0
140270	140258	14135M	PARTICIPANT	\N	PRESENT	0
140271	140258	98035U	PARTICIPANT	\N	PRESENT	0
140273	140258	04034C	PARTICIPANT	\N	PRESENT	0
140274	140258	95063L	PARTICIPANT	\N	PRESENT	0
140275	140258	04045F	PARTICIPANT	\N	PRESENT	0
140276	140258	92045V	PARTICIPANT	\N	PRESENT	0
140278	140258	01016M	PARTICIPANT	\N	PRESENT	0
140281	140258	90003B	PARTICIPANT	\N	EXCUSE	0
140283	140258	11035H	PARTICIPANT	\N	EXCUSE	0
140284	140258	14001X	PARTICIPANT	\N	EXCUSE	0
140285	140258	04057K	PARTICIPANT	\N	EXCUSE	0
140286	140258	10015M	PARTICIPANT	\N	EXCUSE	0
140940	140939	01031L	PARTICIPANT	\N	PRESENT	0
140943	140942	01057W	PARTICIPANT	\N	PRESENT	0
140944	140942	14225N	PARTICIPANT	\N	PRESENT	0
153673	153672	96004D	PRESIDENT	0	PRESENT	0
153674	153672	14089Y	PARTICIPANT	\N	PRESENT	0
153675	153672	14079W	PARTICIPANT	\N	PRESENT	0
153676	153672	11035H	PARTICIPANT	\N	PRESENT	0
153677	153672	14249W	PARTICIPANT	\N	PRESENT	0
153678	153672	14026U	PARTICIPANT	\N	PRESENT	0
153679	153672	14097Y	PARTICIPANT	\N	PRESENT	0
153680	153672	14073Q	PARTICIPANT	\N	PRESENT	0
153681	153672	98046X	PARTICIPANT	\N	PRESENT	0
153682	153672	14135M	PARTICIPANT	\N	PRESENT	0
153683	153672	01016M	PARTICIPANT	\N	PRESENT	0
153684	153672	95063L	PARTICIPANT	\N	PRESENT	0
153685	153672	04045F	PARTICIPANT	\N	PRESENT	0
153686	153672	92045V	PARTICIPANT	\N	PRESENT	0
153687	153672	04034C	PARTICIPANT	\N	PRESENT	0
153688	153672	04054G	PARTICIPANT	\N	EXCUSE	0
153689	153672	04061F	PARTICIPANT	\N	EXCUSE	0
153690	153672	04057K	PARTICIPANT	\N	EXCUSE	0
153691	153672	08042U	PARTICIPANT	\N	EXCUSE	0
153692	153672	10015M	PARTICIPANT	\N	EXCUSE	0
155835	155094	11072N	PARTICIPANT	\N	PRESENT	0
155836	155094	11037K	PARTICIPANT	\N	PRESENT	0
155837	155094	14239U	PARTICIPANT	\N	PRESENT	0
155838	155094	05012A	PARTICIPANT	\N	PRESENT	0
155839	155094	14241N	PARTICIPANT	\N	PRESENT	0
155840	155094	95049N	PARTICIPANT	\N	PRESENT	0
155841	155094	01034P	PARTICIPANT	\N	PRESENT	0
155842	155094	11094U	PARTICIPANT	\N	PRESENT	0
155843	155094	09001P	PARTICIPANT	\N	PRESENT	0
155844	155094	10015M	PARTICIPANT	\N	PRESENT	0
155845	155094	11053K	PARTICIPANT	\N	PRESENT	0
155846	155094	04080J	PARTICIPANT	\N	PRESENT	0
155847	155094	14034U	PARTICIPANT	\N	PRESENT	0
155848	155094	04040A	PARTICIPANT	\N	PRESENT	0
155849	155094	04057K	PARTICIPANT	\N	PRESENT	0
155850	155094	14267Y	PARTICIPANT	\N	PRESENT	0
155851	155094	14042U	PARTICIPANT	\N	PRESENT	0
155852	155094	04061F	PARTICIPANT	\N	PRESENT	0
155853	155094	14219Q	PARTICIPANT	\N	PRESENT	0
155854	155094	14103D	PARTICIPANT	\N	PRESENT	0
155855	155094	07024N	PARTICIPANT	\N	PRESENT	0
155856	155094	14030Q	PARTICIPANT	\N	PRESENT	0
155857	155094	14073Q	PARTICIPANT	\N	PRESENT	0
155858	155094	14179A	PARTICIPANT	\N	PRESENT	0
155859	155094	14231L	PARTICIPANT	\N	PRESENT	0
155860	155094	14083S	PARTICIPANT	\N	PRESENT	0
155861	155094	14089Y	PARTICIPANT	\N	PRESENT	0
155862	155094	98042T	PARTICIPANT	\N	PRESENT	0
155863	155094	11093T	PARTICIPANT	\N	PRESENT	0
155864	155094	11085T	PARTICIPANT	\N	PRESENT	0
155865	155094	14255U	PARTICIPANT	\N	PRESENT	0
155866	155094	14069U	PARTICIPANT	\N	PRESENT	0
155867	155094	01047U	PARTICIPANT	\N	PRESENT	0
155868	155094	04070G	PARTICIPANT	\N	PRESENT	0
155869	155094	01024M	PARTICIPANT	\N	PRESENT	0
155870	155094	01025N	PARTICIPANT	\N	PRESENT	0
155871	155094	14327T	PARTICIPANT	\N	PRESENT	0
155872	155094	01043Q	PARTICIPANT	\N	PRESENT	0
155873	155094	08010L	PARTICIPANT	\N	PRESENT	0
155874	155094	95030B	PARTICIPANT	\N	PRESENT	0
155892	155094	11110B	PARTICIPANT	\N	PRESENT	0
155893	155094	11076S	PARTICIPANT	\N	PRESENT	0
155894	155094	11026G	PARTICIPANT	\N	PRESENT	0
155897	155094	05008E	PARTICIPANT	\N	PRESENT	0
155913	155095	04044E	PARTICIPANT	\N	PRESENT	0
155912	155095	89029V	PARTICIPANT	\N	PRESENT	0
155914	155095	04050C	PARTICIPANT	\N	PRESENT	0
155915	155095	14119M	PARTICIPANT	\N	PRESENT	0
155916	155095	04088S	PARTICIPANT	\N	PRESENT	0
155917	155095	08062Y	PARTICIPANT	\N	PRESENT	0
155918	155095	14197C	PARTICIPANT	\N	PRESENT	0
155919	155095	08052W	PARTICIPANT	\N	PRESENT	0
155920	155095	11109J	PARTICIPANT	\N	PRESENT	0
155921	155095	04079R	PARTICIPANT	\N	PRESENT	0
155922	155095	13002U	PARTICIPANT	\N	PRESENT	0
155923	155095	11099A	PARTICIPANT	\N	PRESENT	0
155924	155095	11068S	PARTICIPANT	\N	PRESENT	0
155925	155095	14207L	PARTICIPANT	\N	PRESENT	0
155926	155095	14267Y	PARTICIPANT	\N	PRESENT	0
155927	155095	08015R	PARTICIPANT	\N	PRESENT	0
155928	155095	14213J	PARTICIPANT	\N	PRESENT	0
155929	155095	14061L	PARTICIPANT	\N	PRESENT	0
155930	155095	14265W	PARTICIPANT	\N	PRESENT	0
155931	155095	95030B	PARTICIPANT	\N	PRESENT	0
155932	155095	14147R	PARTICIPANT	\N	PRESENT	0
155933	155095	11103C	PARTICIPANT	\N	PRESENT	0
155934	155095	14215L	PARTICIPANT	\N	PRESENT	0
155935	155095	14087W	PARTICIPANT	\N	PRESENT	0
155936	155095	14089Y	PARTICIPANT	\N	PRESENT	0
155937	155095	01024M	PARTICIPANT	\N	PRESENT	0
155938	155095	14237S	PARTICIPANT	\N	PRESENT	0
155939	155095	01027Q	PARTICIPANT	\N	PRESENT	0
155940	155095	14223L	PARTICIPANT	\N	PRESENT	0
155941	155095	14018U	PARTICIPANT	\N	PRESENT	0
155952	155095	11067R	PARTICIPANT	\N	PRESENT	0
155953	155095	14073Q	PARTICIPANT	\N	PRESENT	0
155954	155095	01003G	PARTICIPANT	\N	PRESENT	0
155955	155095	04067M	PARTICIPANT	\N	PRESENT	0
155956	155095	97011G	PARTICIPANT	\N	PRESENT	0
155957	155095	04057K	PARTICIPANT	\N	PRESENT	0
155958	155095	04085P	PARTICIPANT	\N	PRESENT	0
155972	155095	14031R	PARTICIPANT	\N	PRESENT	0
155973	155095	14038Y	PARTICIPANT	\N	PRESENT	0
155974	155095	14105F	PARTICIPANT	\N	PRESENT	0
155975	155095	14327T	PARTICIPANT	\N	PRESENT	0
155976	155095	14179A	PARTICIPANT	\N	PRESENT	0
132171	132170	14030Q	PARTICIPANT	\N	PRESENT	0
132172	132170	08043V	PARTICIPANT	\N	PRESENT	0
132173	132170	08060W	PARTICIPANT	\N	PRESENT	0
132174	132170	14217N	PARTICIPANT	\N	PRESENT	0
132175	132170	11061K	PARTICIPANT	\N	PRESENT	0
132176	132170	09001P	PRESIDENT	0	PRESENT	0
132177	132170	08031R	PARTICIPANT	\N	PRESENT	0
132178	132170	07029T	PARTICIPANT	\N	PRESENT	0
132179	132170	08017T	PARTICIPANT	\N	PRESENT	0
132180	132170	14031R	PARTICIPANT	\N	PRESENT	0
132181	132170	11014C	PARTICIPANT	\N	PRESENT	0
132182	132170	14109K	PARTICIPANT	\N	PRESENT	0
132183	132170	14237S	PARTICIPANT	\N	PRESENT	0
132184	132170	11029K	PARTICIPANT	\N	EXCUSE	0
132185	132170	14038Y	PARTICIPANT	\N	EXCUSE	0
132186	132170	80013X	PARTICIPANT	\N	EXCUSE	0
132187	132170	14041T	PARTICIPANT	\N	EXCUSE	0
132188	132170	98042T	PARTICIPANT	\N	EXCUSE	0
132189	132170	07026Q	PARTICIPANT	\N	EXCUSE	0
132190	132170	04041B	PARTICIPANT	\N	EXCUSE	0
132191	132170	04036E	PARTICIPANT	\N	EXCUSE	0
133013	133012	04047H	PARTICIPANT	\N	PRESENT	0
133073	133072	11033F	PARTICIPANT	\N	PRESENT	0
133121	133120	04042C	PARTICIPANT	\N	PRESENT	0
133123	133122	11076S	PARTICIPANT	\N	PRESENT	0
133124	133122	04042C	PARTICIPANT	\N	PRESENT	0
133183	133182	14239U	PARTICIPANT	\N	PRESENT	0
133184	133182	11055M	PARTICIPANT	\N	PRESENT	0
133240	133182	00003C	PARTICIPANT	\N	EXCUSE	0
137626	137612	14241N	PARTICIPANT	\N	EXCUSE	0
137627	137612	08031R	PARTICIPANT	\N	PRESENT	0
133188	133182	04066L	PARTICIPANT	\N	PRESENT	0
137628	137612	08039A	PARTICIPANT	\N	PRESENT	0
133190	133182	14053L	PARTICIPANT	\N	PRESENT	0
133191	133182	11103C	PARTICIPANT	\N	PRESENT	0
137629	137612	08017T	PARTICIPANT	\N	PRESENT	0
137630	137612	14103D	PARTICIPANT	\N	EXCUSE	0
133194	133182	14267Y	PARTICIPANT	\N	PRESENT	0
133195	133182	11023D	PARTICIPANT	\N	PRESENT	0
133196	133182	11031D	PARTICIPANT	\N	PRESENT	0
133197	133182	08052W	PARTICIPANT	\N	PRESENT	0
133198	133182	01059Y	PARTICIPANT	\N	PRESENT	0
133199	133182	04081K	PARTICIPANT	\N	PRESENT	0
137631	137612	14063N	PARTICIPANT	\N	PRESENT	0
133201	133182	10006L	PARTICIPANT	\N	PRESENT	0
137632	137612	04057K	PARTICIPANT	\N	PRESENT	0
133203	133182	14217N	PARTICIPANT	\N	PRESENT	0
133204	133182	14042U	PARTICIPANT	\N	PRESENT	0
137633	137612	14109K	PARTICIPANT	\N	PRESENT	0
133206	133182	12042Y	PARTICIPANT	\N	PRESENT	0
137634	137612	04070G	PARTICIPANT	\N	PRESENT	0
133208	133182	14087W	PARTICIPANT	\N	PRESENT	0
137635	137612	92040Q	PARTICIPANT	\N	PRESENT	0
137636	137612	14235Q	PARTICIPANT	\N	PRESENT	0
133211	133182	14231L	PARTICIPANT	\N	PRESENT	0
133212	133182	11061K	PARTICIPANT	\N	PRESENT	0
137637	137612	14229S	PARTICIPANT	\N	PRESENT	0
133214	133182	08041T	PARTICIPANT	\N	EXCUSE	0
137638	137612	11043H	PARTICIPANT	\N	PRESENT	0
133216	133182	14026U	PARTICIPANT	\N	PRESENT	0
133217	133182	14213J	PARTICIPANT	\N	PRESENT	0
133218	133182	14121F	PARTICIPANT	\N	PRESENT	0
133219	133182	11112D	PARTICIPANT	\N	PRESENT	0
133220	133182	14037X	PARTICIPANT	\N	PRESENT	0
133221	133182	14018U	PARTICIPANT	\N	PRESENT	0
137639	137612	11011M	PARTICIPANT	\N	PRESENT	0
133223	133182	14223L	PARTICIPANT	\N	PRESENT	0
133224	133182	04092N	PRESIDENT	0	PRESENT	0
133225	133182	14265W	PARTICIPANT	\N	PRESENT	0
133226	133182	14119M	PARTICIPANT	\N	PRESENT	0
133227	133182	14071N	PARTICIPANT	\N	EXCUSE	0
133228	133182	07032N	PARTICIPANT	\N	PRESENT	0
137640	137612	14059S	PARTICIPANT	\N	PRESENT	0
133230	133182	14271U	PARTICIPANT	\N	PRESENT	0
133231	133182	14017T	PARTICIPANT	\N	EXCUSE	0
133232	133182	11093T	PARTICIPANT	\N	PRESENT	0
133233	133182	11097X	PARTICIPANT	\N	PRESENT	0
133234	133182	04045F	PARTICIPANT	\N	PRESENT	0
133235	133182	14227Q	PARTICIPANT	\N	PRESENT	0
133236	133182	01034P	PARTICIPANT	\N	PRESENT	0
137642	137641	08017T	PARTICIPANT	\N	PRESENT	0
133238	133182	11063M	PARTICIPANT	\N	PRESENT	0
133239	133182	14269B	PARTICIPANT	\N	PRESENT	0
137644	137643	08012N	PARTICIPANT	\N	PRESENT	0
137658	137657	07024N	PARTICIPANT	\N	PRESENT	0
137659	137657	01014K	PARTICIPANT	\N	PRESENT	0
137660	137657	11106F	PARTICIPANT	\N	PRESENT	0
137661	137657	14193X	PARTICIPANT	\N	PRESENT	0
137663	137662	07024N	PARTICIPANT	\N	PRESENT	0
137664	137662	01014K	PARTICIPANT	\N	PRESENT	0
137665	137662	11106F	PARTICIPANT	\N	PRESENT	0
137667	137666	07024N	PARTICIPANT	\N	PRESENT	0
137668	137666	01014K	PARTICIPANT	\N	PRESENT	0
137669	137666	98021N	PARTICIPANT	\N	PRESENT	0
137670	137666	11054L	PARTICIPANT	\N	PRESENT	0
137672	137671	11104D	PARTICIPANT	\N	PRESENT	0
137674	137673	11104D	PARTICIPANT	\N	PRESENT	0
137676	137675	11033F	PARTICIPANT	\N	PRESENT	0
137678	137677	14133K	PARTICIPANT	\N	PRESENT	0
137679	137677	96004D	PRESIDENT	0	PRESENT	0
137680	137677	11040E	PARTICIPANT	\N	PRESENT	0
137681	137677	14089Y	PARTICIPANT	\N	PRESENT	0
137682	137677	90003B	PARTICIPANT	\N	EXCUSE	0
137683	137677	11035H	PARTICIPANT	\N	EXCUSE	0
137684	137677	14249W	PARTICIPANT	\N	PRESENT	0
137685	137677	95030B	PARTICIPANT	\N	PRESENT	0
137686	137677	11083R	PARTICIPANT	\N	PRESENT	0
137687	137677	08044W	PARTICIPANT	\N	EXCUSE	0
137688	137677	04061F	PARTICIPANT	\N	PRESENT	0
137689	137677	14073Q	PARTICIPANT	\N	EXCUSE	0
137690	137677	11026G	PARTICIPANT	\N	EXCUSE	0
137691	137677	98046X	PARTICIPANT	\N	PRESENT	0
137692	137677	14001X	PARTICIPANT	\N	PRESENT	0
137693	137677	04057K	PARTICIPANT	\N	PRESENT	0
137704	137703	04086Q	PARTICIPANT	\N	PRESENT	0
137695	137677	14135M	PARTICIPANT	\N	EXCUSE	0
137696	137677	01016M	PARTICIPANT	\N	PRESENT	0
137697	137677	10015M	PARTICIPANT	\N	EXCUSE	0
137698	137677	95063L	PARTICIPANT	\N	PRESENT	0
137699	137677	04045F	PARTICIPANT	\N	PRESENT	0
137700	137677	98035U	PARTICIPANT	\N	PRESENT	0
137701	137677	92045V	PARTICIPANT	\N	PRESENT	0
137702	137677	04034C	PARTICIPANT	\N	PRESENT	0
137777	137776	01031L	PARTICIPANT	\N	PRESENT	0
137779	137778	01031L	PARTICIPANT	\N	PRESENT	0
137780	137778	08011M	PARTICIPANT	\N	PRESENT	0
137784	137783	08034U	PARTICIPANT	\N	PRESENT	0
137786	137785	08034U	PARTICIPANT	\N	PRESENT	0
137788	137787	08034U	PARTICIPANT	\N	PRESENT	0
137794	137793	04044E	PARTICIPANT	\N	PRESENT	0
137795	137793	04057K	PARTICIPANT	\N	PRESENT	0
137796	137793	14073Q	PARTICIPANT	\N	PRESENT	0
137797	137793	92040Q	PARTICIPANT	\N	PRESENT	0
137798	137793	14061L	PARTICIPANT	\N	PRESENT	0
137799	137793	01008M	PARTICIPANT	\N	PRESENT	0
137800	137793	08017T	PARTICIPANT	\N	PRESENT	0
137801	137793	01059Y	PARTICIPANT	\N	PRESENT	0
137803	137793	14026U	PARTICIPANT	\N	PRESENT	0
137805	137793	08052W	PARTICIPANT	\N	PRESENT	0
137807	137793	14079W	PARTICIPANT	\N	PRESENT	0
137835	135871	14053L	PARTICIPANT	\N	EXCUSE	0
137865	137569	11035H	PARTICIPANT	\N	EXCUSE	0
138232	137517	01058X	PARTICIPANT	\N	PRESENT	0
138290	137517	08069G	PARTICIPANT	\N	EXCUSE	0
138291	137517	11089X	PARTICIPANT	\N	EXCUSE	0
138292	137517	11061K	PARTICIPANT	\N	EXCUSE	0
138293	137517	14209N	PARTICIPANT	\N	EXCUSE	0
138294	137517	11036J	PARTICIPANT	\N	PRESENT	0
138308	137517	11068S	PARTICIPANT	\N	EXCUSE	0
138325	127239	14039A	PARTICIPANT	\N	PRESENT	0
138326	127239	95067Q	PARTICIPANT	\N	PRESENT	0
138327	127239	14265W	PARTICIPANT	\N	PRESENT	0
138328	127239	14083S	PARTICIPANT	\N	PRESENT	0
138329	127239	14255U	PARTICIPANT	\N	PRESENT	0
138330	127239	14030Q	PARTICIPANT	\N	PRESENT	0
138331	127239	04049K	PRESIDENT	0	PRESENT	0
138332	127239	14253S	PARTICIPANT	\N	PRESENT	0
138333	127239	14087W	PARTICIPANT	\N	PRESENT	0
138334	127239	14105F	PARTICIPANT	\N	PRESENT	0
138335	127239	14207L	PARTICIPANT	\N	PRESENT	0
138336	127239	11090Q	PARTICIPANT	\N	PRESENT	0
138337	127239	14121F	PARTICIPANT	\N	PRESENT	0
138338	127239	14157T	PARTICIPANT	\N	PRESENT	0
138339	127239	89017R	PARTICIPANT	\N	EXCUSE	0
138340	127239	14065Q	PARTICIPANT	\N	EXCUSE	0
138341	127239	14013P	PARTICIPANT	\N	EXCUSE	0
138342	127239	08068F	PARTICIPANT	\N	EXCUSE	0
138343	127239	04053F	PARTICIPANT	\N	EXCUSE	0
138344	127239	14079W	PARTICIPANT	\N	EXCUSE	0
166441	163372	14069U	PARTICIPANT	\N	PRESENT	0
166442	163372	11101A	PARTICIPANT	\N	PRESENT	0
166444	163372	08038Y	PARTICIPANT	\N	PRESENT	0
166445	163372	14327T	PARTICIPANT	\N	PRESENT	0
166447	163372	01027Q	PARTICIPANT	\N	PRESENT	0
166448	163372	14034U	PARTICIPANT	\N	PRESENT	0
166450	163372	08010L	PARTICIPANT	\N	PRESENT	0
166451	163372	14028W	PARTICIPANT	\N	PRESENT	0
166452	163372	05012A	PARTICIPANT	\N	PRESENT	0
166454	163372	04045F	PARTICIPANT	\N	PRESENT	0
166455	163372	14051J	PARTICIPANT	\N	PRESENT	0
166457	163372	11066Q	PARTICIPANT	\N	PRESENT	0
166458	163372	11094U	PARTICIPANT	\N	PRESENT	0
166459	163372	14357A	PARTICIPANT	\N	PRESENT	0
170553	170552	14033T	PARTICIPANT	\N	PRESENT	0
170633	170632	95035G	PARTICIPANT	\N	PRESENT	0
170634	170632	11084S	PARTICIPANT	\N	PRESENT	0
170653	170652	14219Q	PRESIDENT	0	PRESENT	0
170654	170652	11065P	PARTICIPANT	\N	PRESENT	0
170655	170652	01056V	PARTICIPANT	\N	PRESENT	0
170656	170652	01008M	PARTICIPANT	\N	PRESENT	0
170657	170652	01015L	PARTICIPANT	\N	PRESENT	0
170658	170652	11035H	PARTICIPANT	\N	EXCUSE	0
170659	170652	08049C	PARTICIPANT	\N	EXCUSE	0
170660	170652	92045V	PARTICIPANT	\N	PRESENT	0
170661	170652	14093U	PARTICIPANT	\N	PRESENT	0
170672	170652	80013X	PARTICIPANT	\N	PRESENT	0
170673	170652	05012A	PARTICIPANT	\N	PRESENT	0
174133	174132	98021N	PARTICIPANT	\N	PRESENT	0
174134	174132	11106F	PARTICIPANT	\N	PRESENT	0
174136	174135	98021N	PARTICIPANT	\N	PRESENT	0
174137	174135	11106F	PARTICIPANT	\N	PRESENT	0
174139	174138	98021N	PARTICIPANT	\N	PRESENT	0
174140	174138	11106F	PARTICIPANT	\N	PRESENT	0
174142	174141	14193X	PARTICIPANT	\N	PRESENT	0
174143	174141	11054L	PARTICIPANT	\N	PRESENT	0
174964	174960	11076S	PARTICIPANT	\N	PRESENT	0
174965	174960	14133K	PARTICIPANT	\N	PRESENT	0
174968	174960	04054G	PARTICIPANT	\N	PRESENT	0
174969	174960	04040A	PARTICIPANT	\N	PRESENT	0
174971	174960	04042C	PARTICIPANT	\N	PRESENT	0
174975	174960	77002U	PARTICIPANT	\N	PRESENT	0
174978	174960	98029W	PARTICIPANT	\N	PRESENT	0
174983	174960	11027H	PARTICIPANT	\N	PRESENT	0
174988	174960	92018S	PARTICIPANT	\N	PRESENT	0
174996	174960	95031C	PARTICIPANT	\N	PRESENT	0
175000	174960	97011G	PARTICIPANT	\N	PRESENT	0
175002	174960	08065C	PARTICIPANT	\N	PRESENT	0
175004	174960	04035D	PARTICIPANT	\N	PRESENT	0
175009	174960	14014Q	PARTICIPANT	\N	PRESENT	0
175025	174960	14211G	PARTICIPANT	\N	PRESENT	0
175019	174960	07004J	PARTICIPANT	\N	PRESENT	0
175021	174960	95035G	PARTICIPANT	\N	PRESENT	0
175027	174960	98022P	PARTICIPANT	\N	PRESENT	0
175030	174960	11064N	PARTICIPANT	\N	PRESENT	0
175032	174960	95037J	PARTICIPANT	\N	PRESENT	0
175034	174960	04078Q	PARTICIPANT	\N	PRESENT	0
175040	174960	14097Y	PARTICIPANT	\N	PRESENT	0
175042	174960	95041E	PARTICIPANT	\N	PRESENT	0
175044	174960	04036E	PARTICIPANT	\N	PRESENT	0
175048	174960	92031P	PARTICIPANT	\N	PRESENT	0
175049	174960	11106F	PARTICIPANT	\N	PRESENT	0
175051	174960	14251Q	PARTICIPANT	\N	PRESENT	0
175055	174960	08053X	PARTICIPANT	\N	PRESENT	0
175058	174960	08047A	PARTICIPANT	\N	PRESENT	0
175062	174960	14028W	PARTICIPANT	\N	EXCUSE	0
175063	174960	14193X	PARTICIPANT	\N	PRESENT	0
175066	174960	98021N	PARTICIPANT	\N	PRESENT	0
175069	174960	04080J	PARTICIPANT	\N	PRESENT	0
175071	174960	95059Q	PRESIDENT	0	PRESENT	0
175072	174960	86044G	PARTICIPANT	\N	PRESENT	0
175074	174960	01014K	PARTICIPANT	\N	PRESENT	0
175077	174960	11054L	PARTICIPANT	\N	PRESENT	0
175078	174960	01056V	PARTICIPANT	\N	PRESENT	0
175079	174960	08049C	PARTICIPANT	\N	PRESENT	0
177192	175155	08044W	PARTICIPANT	\N	EXCUSE	0
177313	177312	11029K	PARTICIPANT	\N	PRESENT	0
177314	177312	14030Q	PARTICIPANT	\N	EXCUSE	0
177315	177312	08060W	PARTICIPANT	\N	EXCUSE	0
177316	177312	80013X	PARTICIPANT	\N	PRESENT	0
177317	177312	14281W	PARTICIPANT	\N	PRESENT	0
177318	177312	11061K	PARTICIPANT	\N	PRESENT	0
177319	177312	14014Q	PARTICIPANT	\N	PRESENT	0
177320	177312	07026Q	PARTICIPANT	\N	PRESENT	0
177321	177312	09001P	PRESIDENT	0	PRESENT	0
177322	177312	08031R	PARTICIPANT	\N	EXCUSE	0
177323	177312	07029T	PARTICIPANT	\N	EXCUSE	0
177324	177312	14031R	PARTICIPANT	\N	PRESENT	0
177325	177312	11067R	PARTICIPANT	\N	PRESENT	0
177326	177312	11014C	PARTICIPANT	\N	EXCUSE	0
177327	177312	14265W	PARTICIPANT	\N	EXCUSE	0
177328	177312	14237S	PARTICIPANT	\N	EXCUSE	0
177453	177452	96004D	PARTICIPANT	\N	PRESENT	0
177454	177452	14026U	PARTICIPANT	\N	PRESENT	0
177455	177452	95037J	PARTICIPANT	\N	PRESENT	0
177456	177452	90003B	PARTICIPANT	\N	PRESENT	0
177457	177452	14033T	PARTICIPANT	\N	PRESENT	0
177458	177452	14257W	PARTICIPANT	\N	PRESENT	0
177673	177672	98021N	PARTICIPANT	\N	PRESENT	0
177674	177672	11106F	PARTICIPANT	\N	PRESENT	0
177675	177672	01056V	PARTICIPANT	\N	PRESENT	0
177677	177676	98021N	PARTICIPANT	\N	PRESENT	0
177678	177676	11106F	PARTICIPANT	\N	PRESENT	0
177679	177676	14133K	PARTICIPANT	\N	PRESENT	0
177681	177680	98021N	PARTICIPANT	\N	PRESENT	0
177682	177680	11106F	PARTICIPANT	\N	PRESENT	0
177683	177680	01056V	PARTICIPANT	\N	PRESENT	0
177685	177684	98021N	PARTICIPANT	\N	PRESENT	0
177686	177684	01014K	PARTICIPANT	\N	PRESENT	0
177687	177684	11054L	PARTICIPANT	\N	PRESENT	0
177688	177684	11106F	PARTICIPANT	\N	PRESENT	0
177689	177684	14133K	PARTICIPANT	\N	PRESENT	0
177690	177684	95037J	PARTICIPANT	\N	PRESENT	0
177693	177692	08009T	PARTICIPANT	\N	PRESENT	0
177694	177692	14169X	PARTICIPANT	\N	PRESENT	0
177695	177692	11107G	PARTICIPANT	\N	PRESENT	0
177696	177692	14031R	PARTICIPANT	\N	PRESENT	0
183173	183172	14042U	PARTICIPANT	\N	PRESENT	0
183174	183172	01011G	PARTICIPANT	\N	PRESENT	0
183472	183096	95067Q	PARTICIPANT	\N	PRESENT	0
183473	183096	14065Q	PARTICIPANT	\N	PRESENT	0
183474	183096	10015M	PARTICIPANT	\N	PRESENT	0
183475	183096	14273W	PARTICIPANT	\N	PRESENT	0
183476	183096	01024M	PARTICIPANT	\N	PRESENT	0
183477	183096	04044E	PRESIDENT	1	PRESENT	0
183478	183096	04038G	PARTICIPANT	\N	PRESENT	0
183479	183096	01028R	PARTICIPANT	\N	PRESENT	0
183480	183096	05008E	PRESIDENT	0	PRESENT	0
183481	183096	11037K	PARTICIPANT	\N	PRESENT	0
183482	183096	04074L	PARTICIPANT	\N	PRESENT	0
183483	183096	14041T	PARTICIPANT	\N	PRESENT	0
183484	183096	11084S	PARTICIPANT	\N	PRESENT	0
183485	183096	14259Y	PARTICIPANT	\N	PRESENT	0
183486	183096	95049N	PARTICIPANT	\N	PRESENT	0
183487	183096	04079R	PARTICIPANT	\N	PRESENT	0
183488	183096	98035U	PARTICIPANT	\N	PRESENT	0
183489	183096	01047U	PARTICIPANT	\N	PRESENT	0
183490	183096	14147R	PARTICIPANT	\N	PRESENT	0
183491	183096	04047H	PARTICIPANT	\N	PRESENT	0
183492	183096	01007L	PARTICIPANT	\N	PRESENT	0
185193	185192	14089Y	PARTICIPANT	\N	PRESENT	0
185194	185192	14207L	PARTICIPANT	\N	PRESENT	0
185195	185192	14135M	PARTICIPANT	\N	PRESENT	0
185196	185192	04050C	PARTICIPANT	\N	PRESENT	0
185198	185197	14089Y	PARTICIPANT	\N	PRESENT	0
185199	185197	14207L	PARTICIPANT	\N	PRESENT	0
185200	185197	14135M	PARTICIPANT	\N	PRESENT	0
185201	185197	04050C	PARTICIPANT	\N	PRESENT	0
185203	185202	08010L	PARTICIPANT	\N	PRESENT	0
185205	185204	08010L	PARTICIPANT	\N	PRESENT	0
185213	185212	08010L	PARTICIPANT	\N	PRESENT	0
185215	185214	08010L	PARTICIPANT	\N	PRESENT	0
193152	192759	01047U	PARTICIPANT	\N	PRESENT	0
193153	192759	95063L	PARTICIPANT	\N	PRESENT	0
193154	192759	04074L	PARTICIPANT	\N	PRESENT	0
193172	192759	14147R	PARTICIPANT	\N	PRESENT	0
193313	190778	01015L	PARTICIPANT	\N	PRESENT	0
193292	190778	89029V	PARTICIPANT	\N	PRESENT	0
193312	190778	04085P	PARTICIPANT	\N	PRESENT	0
193314	190778	07026Q	PARTICIPANT	\N	PRESENT	0
193332	190778	14235Q	PARTICIPANT	\N	PRESENT	0
193333	190778	11040E	PARTICIPANT	\N	PRESENT	0
193334	190778	11045K	PARTICIPANT	\N	PRESENT	0
193335	190778	11104D	PARTICIPANT	\N	PRESENT	0
193336	190778	13002U	PARTICIPANT	\N	PRESENT	0
193337	190778	92020L	PARTICIPANT	\N	PRESENT	0
193352	190778	08060W	PARTICIPANT	\N	PRESENT	0
193353	190778	80013X	PARTICIPANT	\N	PRESENT	0
193354	190778	01022K	PARTICIPANT	\N	PRESENT	0
174445	167278	14069U	PARTICIPANT	\N	PRESENT	0
174446	167278	01011G	PARTICIPANT	\N	PRESENT	0
174447	167278	01046T	PARTICIPANT	\N	PRESENT	0
174448	167278	11081P	PARTICIPANT	\N	PRESENT	0
174449	167278	08031R	PARTICIPANT	\N	PRESENT	0
174450	167278	11027H	PARTICIPANT	\N	PRESENT	0
174451	167278	08055A	PARTICIPANT	\N	PRESENT	0
174452	167278	08017T	PARTICIPANT	\N	PRESENT	0
174453	167278	01013J	PARTICIPANT	\N	PRESENT	0
174454	167278	04041B	PARTICIPANT	\N	PRESENT	0
174455	167278	14031R	PARTICIPANT	\N	PRESENT	0
174456	167278	14055N	PARTICIPANT	\N	PRESENT	0
174457	167278	04089T	PARTICIPANT	\N	PRESENT	0
174458	167278	14187A	PARTICIPANT	\N	PRESENT	0
174459	167278	04061F	PARTICIPANT	\N	PRESENT	0
174460	167278	11040E	PARTICIPANT	\N	PRESENT	0
174461	167278	04043D	PARTICIPANT	\N	PRESENT	0
174492	167278	88008L	PARTICIPANT	\N	PRESENT	0
174493	167278	08024S	PARTICIPANT	\N	PRESENT	0
174494	167278	11014C	PARTICIPANT	\N	PRESENT	0
174495	167278	14241N	PARTICIPANT	\N	PRESENT	0
174496	167278	14059S	PARTICIPANT	\N	PRESENT	0
174497	167278	14061L	PARTICIPANT	\N	PRESENT	0
174498	167278	08047A	PARTICIPANT	\N	PRESENT	0
174499	167278	14217N	PARTICIPANT	\N	PRESENT	0
174500	167278	04080J	PARTICIPANT	\N	PRESENT	0
174501	167278	04053F	PARTICIPANT	\N	PRESENT	0
174502	167278	14361V	PARTICIPANT	\N	PRESENT	0
174503	167278	01022K	PARTICIPANT	\N	PRESENT	0
174504	167278	08028W	PARTICIPANT	\N	PRESENT	0
174505	167278	08015R	PARTICIPANT	\N	PRESENT	0
174506	167278	04067M	PARTICIPANT	\N	PRESENT	0
174508	167278	14229S	PARTICIPANT	\N	PRESENT	0
174509	167278	14107H	PARTICIPANT	\N	PRESENT	0
174512	167278	04081K	PARTICIPANT	\N	PRESENT	0
174513	167278	14211G	PARTICIPANT	\N	PRESENT	0
174514	167278	14205J	PARTICIPANT	\N	PRESENT	0
174515	167278	14219Q	PARTICIPANT	\N	PRESENT	0
174516	167278	14071N	PARTICIPANT	\N	PRESENT	0
174517	167278	14197C	PARTICIPANT	\N	PRESENT	0
174518	167278	01015L	PARTICIPANT	\N	PRESENT	0
174519	167278	14331P	PARTICIPANT	\N	PRESENT	0
174532	167278	04097T	PARTICIPANT	\N	PRESENT	0
174974	167279	14133K	PARTICIPANT	\N	PRESENT	0
174559	167278	14257W	PARTICIPANT	\N	PRESENT	0
174561	167278	14051J	PARTICIPANT	\N	PRESENT	0
174563	167278	80013X	PARTICIPANT	\N	PRESENT	0
174566	167278	04085P	PARTICIPANT	\N	PRESENT	0
174570	167278	14109K	PARTICIPANT	\N	PRESENT	0
174573	167278	01043Q	PARTICIPANT	\N	PRESENT	0
174577	167278	14037X	PARTICIPANT	\N	PRESENT	0
174580	167278	14157T	PARTICIPANT	\N	PRESENT	0
174581	167278	11101A	PARTICIPANT	\N	PRESENT	0
174582	167278	05012A	PARTICIPANT	\N	PRESENT	0
174583	167278	98050T	PARTICIPANT	\N	PRESENT	0
174584	167278	01008M	PARTICIPANT	\N	PRESENT	0
174585	167278	01047U	PARTICIPANT	\N	PRESENT	0
174586	167278	11043H	PARTICIPANT	\N	PRESENT	0
174587	167278	08019V	PARTICIPANT	\N	PRESENT	0
174973	167279	04059M	PARTICIPANT	\N	PRESENT	0
174976	167279	05004A	PARTICIPANT	\N	PRESENT	0
174977	167279	11030C	PARTICIPANT	\N	PRESENT	0
174979	167279	14207L	PARTICIPANT	\N	PRESENT	0
174980	167279	04053F	PARTICIPANT	\N	PRESENT	0
174981	167279	14175V	PARTICIPANT	\N	PRESENT	0
174982	167279	14229S	PARTICIPANT	\N	PRESENT	0
174984	167279	04047H	PARTICIPANT	\N	PRESENT	0
174985	167279	04042C	PARTICIPANT	\N	PRESENT	0
174986	167279	14281W	PARTICIPANT	\N	PRESENT	0
174987	167279	11061K	PARTICIPANT	\N	PRESENT	0
174989	167279	08035V	PARTICIPANT	\N	PRESENT	0
174990	167279	11068S	PARTICIPANT	\N	PRESENT	0
174991	167279	77002U	PARTICIPANT	\N	PRESENT	0
174992	167279	95015C	PARTICIPANT	\N	PRESENT	0
174993	167279	11044J	PARTICIPANT	\N	PRESENT	0
174994	167279	11072N	PARTICIPANT	\N	PRESENT	0
174995	167279	14038Y	PARTICIPANT	\N	PRESENT	0
174997	167279	14013P	PARTICIPANT	\N	PRESENT	0
174998	167279	11031D	PARTICIPANT	\N	PRESENT	0
174999	167279	14209N	PARTICIPANT	\N	PRESENT	0
175001	167279	08061X	PARTICIPANT	\N	PRESENT	0
175003	167279	01028R	PARTICIPANT	\N	PRESENT	0
175005	167279	98023Q	PARTICIPANT	\N	PRESENT	0
175006	167279	04086Q	PARTICIPANT	\N	PRESENT	0
175007	167279	14357A	PARTICIPANT	\N	PRESENT	0
175008	167279	11104D	PARTICIPANT	\N	PRESENT	0
175010	167279	92039X	PARTICIPANT	\N	PRESENT	0
175011	167279	08038Y	PARTICIPANT	\N	PRESENT	0
175012	167279	04081K	PARTICIPANT	\N	PRESENT	0
175013	167279	99002P	PARTICIPANT	\N	PRESENT	0
175023	167279	11106F	PARTICIPANT	\N	PRESENT	0
175016	167279	11032E	PARTICIPANT	\N	PRESENT	0
175017	167279	08024S	PARTICIPANT	\N	PRESENT	0
175018	167279	11066Q	PARTICIPANT	\N	PRESENT	0
175020	167279	11037K	PARTICIPANT	\N	PRESENT	0
175022	167279	11067R	PARTICIPANT	\N	PRESENT	0
175024	167279	11088W	PARTICIPANT	\N	PRESENT	0
175026	167279	14081Q	PARTICIPANT	\N	PRESENT	0
175028	167279	95059Q	PARTICIPANT	\N	PRESENT	0
175029	167279	11090Q	PARTICIPANT	\N	PRESENT	0
175031	167279	04045F	PARTICIPANT	\N	PRESENT	0
175033	167279	08073C	PARTICIPANT	\N	PRESENT	0
175035	167279	14225N	PARTICIPANT	\N	PRESENT	0
175036	167279	14031R	PARTICIPANT	\N	PRESENT	0
175037	167279	14111D	PARTICIPANT	\N	PRESENT	0
175038	167279	01014K	PARTICIPANT	\N	PRESENT	0
175039	167279	08011M	PARTICIPANT	\N	PRESENT	0
175041	167279	04095R	PARTICIPANT	\N	PRESENT	0
175043	167279	04035D	PARTICIPANT	\N	PRESENT	0
175045	167279	14159V	PARTICIPANT	\N	PRESENT	0
175046	167279	11025F	PARTICIPANT	\N	PRESENT	0
175047	167279	14269B	PARTICIPANT	\N	PRESENT	0
175050	167279	14169X	PARTICIPANT	\N	PRESENT	0
175052	167279	14237S	PARTICIPANT	\N	PRESENT	0
175053	167279	07034Q	PARTICIPANT	\N	PRESENT	0
175054	167279	11110B	PARTICIPANT	\N	PRESENT	0
175056	167279	98021N	PARTICIPANT	\N	PRESENT	0
175057	167279	11107G	PARTICIPANT	\N	PRESENT	0
175059	167279	04074L	PARTICIPANT	\N	PRESENT	0
175060	167279	12042Y	PARTICIPANT	\N	PRESENT	0
175061	167279	14135M	PARTICIPANT	\N	PRESENT	0
175064	167279	04097T	PARTICIPANT	\N	PRESENT	0
175065	167279	11113E	PARTICIPANT	\N	PRESENT	0
175067	167279	01056V	PARTICIPANT	\N	PRESENT	0
175068	167279	11042G	PARTICIPANT	\N	PRESENT	0
175070	167279	14039A	PARTICIPANT	\N	PRESENT	0
175073	167279	11109J	PARTICIPANT	\N	PRESENT	0
175075	167279	14259Y	PARTICIPANT	\N	PRESENT	0
175076	167279	11114F	PARTICIPANT	\N	PRESENT	0
175080	167279	95049N	PARTICIPANT	\N	PRESENT	0
175081	167279	04040A	PARTICIPANT	\N	PRESENT	0
175082	167279	11094U	PARTICIPANT	\N	PRESENT	0
175083	167279	11053K	PARTICIPANT	\N	PRESENT	0
175084	167279	04080J	PARTICIPANT	\N	PRESENT	0
175085	167279	14255U	PARTICIPANT	\N	PRESENT	0
175086	167279	11064N	PARTICIPANT	\N	PRESENT	0
175087	167279	14205J	PARTICIPANT	\N	PRESENT	0
175088	167279	14221J	PARTICIPANT	\N	PRESENT	0
175089	167279	95067Q	PARTICIPANT	\N	PRESENT	0
175090	167279	14042U	PARTICIPANT	\N	PRESENT	0
175091	167279	14093U	PARTICIPANT	\N	PRESENT	0
175092	167279	14219Q	PARTICIPANT	\N	PRESENT	0
175093	167279	14103D	PARTICIPANT	\N	PRESENT	0
175094	167279	87003B	PARTICIPANT	\N	PRESENT	0
175095	167279	11093T	PARTICIPANT	\N	PRESENT	0
175096	167279	92040Q	PARTICIPANT	\N	PRESENT	0
175097	167279	11082Q	PARTICIPANT	\N	PRESENT	0
175098	167279	11111C	PARTICIPANT	\N	PRESENT	0
175099	167279	14073Q	PARTICIPANT	\N	PRESENT	0
175100	167279	14275Y	PARTICIPANT	\N	PRESENT	0
175101	167279	14123H	PARTICIPANT	\N	PRESENT	0
175102	167279	14267Y	PARTICIPANT	\N	PRESENT	0
175103	167279	10015M	PARTICIPANT	\N	PRESENT	0
175104	167279	01043Q	PARTICIPANT	\N	PRESENT	0
175105	167279	01007L	PARTICIPANT	\N	PRESENT	0
175106	167279	07004J	PARTICIPANT	\N	PRESENT	0
175107	167279	95030B	PARTICIPANT	\N	PRESENT	0
175108	167279	14327T	PARTICIPANT	\N	PRESENT	0
175109	167279	01025N	PARTICIPANT	\N	PRESENT	0
175110	167279	01024M	PARTICIPANT	\N	PRESENT	0
175111	167279	08056B	PARTICIPANT	\N	PRESENT	0
175112	167279	95035G	PARTICIPANT	\N	PRESENT	0
175113	167279	01047U	PARTICIPANT	\N	PRESENT	0
175114	167279	09001P	PARTICIPANT	\N	PRESENT	0
175115	167279	11085T	PARTICIPANT	\N	PRESENT	0
175117	167279	04089T	PARTICIPANT	\N	PRESENT	0
175118	167279	98042T	PARTICIPANT	\N	PRESENT	0
169003	169002	96004D	PARTICIPANT	\N	PRESENT	0
170913	157438	95062K	PARTICIPANT	\N	EXCUSE	0
170914	157438	14053L	PARTICIPANT	\N	EXCUSE	0
170915	157438	11054L	PARTICIPANT	\N	EXCUSE	0
170916	157438	96004D	PARTICIPANT	\N	EXCUSE	0
170917	157438	11010L	PARTICIPANT	\N	EXCUSE	0
170918	157438	98005N	PARTICIPANT	\N	EXCUSE	0
177473	177472	04042C	PARTICIPANT	\N	PRESENT	0
177475	177474	04042C	PARTICIPANT	\N	PRESENT	0
177477	177476	04042C	PARTICIPANT	\N	PRESENT	0
177478	177476	04077P	PARTICIPANT	\N	PRESENT	0
177479	177476	04070G	PARTICIPANT	\N	PRESENT	0
177513	177512	11039M	PARTICIPANT	\N	PRESENT	0
177514	177512	08012N	PARTICIPANT	\N	PRESENT	0
177515	177512	14235Q	PARTICIPANT	\N	PRESENT	0
177516	177512	14241N	PARTICIPANT	\N	PRESENT	0
177522	177521	11039M	PARTICIPANT	\N	PRESENT	0
177524	177521	14235Q	PARTICIPANT	\N	PRESENT	0
177525	177521	08012N	PARTICIPANT	\N	PRESENT	0
177530	177528	11039M	PARTICIPANT	\N	PRESENT	0
183273	183272	04080J	PARTICIPANT	\N	PRESENT	0
183274	183272	98035U	PARTICIPANT	\N	PRESENT	0
183313	183312	08039A	PARTICIPANT	\N	PRESENT	0
183514	183096	04056J	PARTICIPANT	\N	EXCUSE	0
183512	183096	11056N	PARTICIPANT	\N	EXCUSE	0
183513	183096	07034Q	PARTICIPANT	\N	EXCUSE	0
183515	183096	92045V	PARTICIPANT	\N	EXCUSE	0
187073	187072	14249W	PARTICIPANT	\N	PRESENT	0
187074	187072	11089X	PARTICIPANT	\N	PRESENT	0
187075	187072	08031R	PARTICIPANT	\N	PRESENT	0
187077	187076	95015C	PARTICIPANT	\N	PRESENT	0
187079	187078	14249W	PARTICIPANT	\N	PRESENT	0
187080	187078	11089X	PARTICIPANT	\N	PRESENT	0
187081	187078	08031R	PARTICIPANT	\N	PRESENT	0
187253	187252	04049K	PARTICIPANT	\N	PRESENT	0
187513	187512	08011M	PARTICIPANT	\N	PRESENT	0
187593	187592	11074Q	PARTICIPANT	\N	PRESENT	0
187594	187592	11083R	PARTICIPANT	\N	PRESENT	0
187613	187612	95015C	PARTICIPANT	\N	PRESENT	0
187614	187612	14241N	PARTICIPANT	\N	PRESENT	0
187633	187632	95015C	PARTICIPANT	\N	PRESENT	0
187635	187634	95015C	PARTICIPANT	\N	PRESENT	0
187637	187636	95015C	PARTICIPANT	\N	PRESENT	0
187638	187636	14241N	PARTICIPANT	\N	PRESENT	0
188553	188552	14030Q	PARTICIPANT	\N	PRESENT	0
188554	188552	08043V	PARTICIPANT	\N	EXCUSE	0
188555	188552	08060W	PARTICIPANT	\N	EXCUSE	0
188556	188552	14038Y	PARTICIPANT	\N	EXCUSE	0
188557	188552	11027H	PARTICIPANT	\N	EXCUSE	0
188558	188552	80013X	PARTICIPANT	\N	EXCUSE	0
188559	188552	14217N	PARTICIPANT	\N	PRESENT	0
188560	188552	07026Q	PARTICIPANT	\N	PRESENT	0
188561	188552	95035G	PARTICIPANT	\N	EXCUSE	0
188562	188552	04036E	PARTICIPANT	\N	EXCUSE	0
188563	188552	08017T	PARTICIPANT	\N	EXCUSE	0
188564	188552	14031R	PARTICIPANT	\N	PRESENT	0
188565	188552	11067R	PARTICIPANT	\N	EXCUSE	0
188566	188552	14109K	PARTICIPANT	\N	EXCUSE	0
188567	188552	14265W	PARTICIPANT	\N	EXCUSE	0
188568	188552	08047A	PARTICIPANT	\N	EXCUSE	0
188569	188552	09001P	PRESIDENT	0	PRESENT	0
190414	190413	14133K	PARTICIPANT	\N	PRESENT	0
190415	190413	96004D	PRESIDENT	0	PRESENT	0
190416	190413	14089Y	PARTICIPANT	\N	PRESENT	0
190417	190413	14249W	PARTICIPANT	\N	PRESENT	0
190418	190413	04035D	PARTICIPANT	\N	PRESENT	0
190419	190413	11083R	PARTICIPANT	\N	PRESENT	0
190420	190413	14073Q	PARTICIPANT	\N	PRESENT	0
190421	190413	95063L	PARTICIPANT	\N	PRESENT	0
190422	190413	04045F	PARTICIPANT	\N	PRESENT	0
190423	190413	98035U	PARTICIPANT	\N	PRESENT	0
190424	190413	11035H	PARTICIPANT	\N	EXCUSE	0
190425	190413	95030B	PARTICIPANT	\N	EXCUSE	0
190426	190413	11012A	PARTICIPANT	\N	EXCUSE	0
190433	190432	11068S	PARTICIPANT	\N	PRESENT	0
190435	190434	11068S	PARTICIPANT	\N	PRESENT	0
190437	190436	11068S	PARTICIPANT	\N	PRESENT	0
190439	190438	11053K	PARTICIPANT	\N	PRESENT	0
190441	190440	11053K	PARTICIPANT	\N	PRESENT	0
190443	190442	11053K	PARTICIPANT	\N	PRESENT	0
190445	190444	11053K	PARTICIPANT	\N	PRESENT	0
192396	190533	96004D	PARTICIPANT	\N	PRESENT	0
190459	190458	05008E	PARTICIPANT	\N	PRESENT	0
190460	190458	01024M	PARTICIPANT	\N	PRESENT	0
190461	190458	04038G	PARTICIPANT	\N	PRESENT	0
190462	190458	11037K	PARTICIPANT	\N	PRESENT	0
190463	190458	11084S	PARTICIPANT	\N	PRESENT	0
192398	190533	95035G	PARTICIPANT	\N	PRESENT	0
190754	190497	08044W	PARTICIPANT	\N	EXCUSE	0
192397	190533	92045V	PARTICIPANT	\N	PRESENT	0
192473	192472	04034C	PARTICIPANT	\N	PRESENT	0
205233	205232	04086Q	PARTICIPANT	\N	PRESENT	0
205253	205252	01031L	PARTICIPANT	\N	PRESENT	0
205255	205254	04034C	PARTICIPANT	\N	PRESENT	0
205293	205292	14213J	PARTICIPANT	\N	PRESENT	0
205295	205294	14213J	PARTICIPANT	\N	PRESENT	0
210087	210042	14001X	PARTICIPANT	\N	EXCUSE	0
210065	210042	04097T	PARTICIPANT	\N	EXCUSE	0
210094	210043	14103D	PARTICIPANT	\N	EXCUSE	0
210067	210042	14097Y	PARTICIPANT	\N	EXCUSE	0
210068	210042	04061F	PARTICIPANT	\N	PRESENT	0
210069	210042	14061L	PARTICIPANT	\N	EXCUSE	0
210095	210043	04044E	PARTICIPANT	\N	EXCUSE	0
210071	210042	11026G	PARTICIPANT	\N	PRESENT	0
210072	210042	08039A	PARTICIPANT	\N	PRESENT	0
210097	210096	08009T	PARTICIPANT	\N	PRESENT	0
210074	210042	14221J	PARTICIPANT	\N	PRESENT	0
210075	210042	04057K	PARTICIPANT	\N	PRESENT	0
210076	210042	19563B	PARTICIPANT	\N	PRESENT	0
210078	210042	19593H	PARTICIPANT	\N	PRESENT	0
210079	210042	08073C	PARTICIPANT	\N	PRESENT	0
210080	210042	14237S	PARTICIPANT	\N	PRESENT	0
210104	210103	14042U	PARTICIPANT	\N	PRESENT	0
210082	210042	14331P	PARTICIPANT	\N	PRESENT	0
210083	210042	14225N	PARTICIPANT	\N	PRESENT	0
210108	210107	14231L	PARTICIPANT	\N	PRESENT	0
210110	210109	08039A	PARTICIPANT	\N	PRESENT	0
210086	210042	98035U	PARTICIPANT	\N	PRESENT	0
210112	210111	08039A	PARTICIPANT	\N	PRESENT	0
210114	210113	08039A	PARTICIPANT	\N	PRESENT	0
210119	210105	08052W	PARTICIPANT	\N	PRESENT	0
210122	210121	92031P	PARTICIPANT	\N	PRESENT	0
210123	210121	11026G	PARTICIPANT	\N	PRESENT	0
210124	210121	08009T	PARTICIPANT	\N	PRESENT	0
210126	210125	08009T	PARTICIPANT	\N	PRESENT	0
210128	210127	08009T	PARTICIPANT	\N	PRESENT	0
210147	210146	98050T	PARTICIPANT	\N	PRESENT	0
210156	210107	19483C	PARTICIPANT	\N	PRESENT	0
210163	210162	04086Q	PARTICIPANT	\N	PRESENT	0
210165	210164	04049K	PARTICIPANT	\N	PRESENT	0
210166	210164	19383Y	PARTICIPANT	\N	PRESENT	0
210168	210167	04049K	PARTICIPANT	\N	PRESENT	0
210170	210169	04049K	PARTICIPANT	\N	PRESENT	0
210171	210169	19383Y	PARTICIPANT	\N	PRESENT	0
210173	210172	11054L	PARTICIPANT	\N	PRESENT	0
210174	210172	11064N	PARTICIPANT	\N	PRESENT	0
210175	210172	04042C	PARTICIPANT	\N	PRESENT	0
210181	210180	14215L	PARTICIPANT	\N	PRESENT	0
210186	210185	10006L	PARTICIPANT	\N	PRESENT	0
210188	210187	10006L	PARTICIPANT	\N	PRESENT	0
210190	210189	10006L	PARTICIPANT	\N	PRESENT	0
186409	186397	14031R	PARTICIPANT	\N	EXCUSE	0
186410	186397	08009T	PRESIDENT	0	PRESENT	0
186411	186397	08062Y	PARTICIPANT	\N	EXCUSE	0
186412	186397	14221J	PARTICIPANT	\N	EXCUSE	0
186413	186397	05012A	PARTICIPANT	\N	EXCUSE	0
186414	186397	14331P	PARTICIPANT	\N	EXCUSE	0
186415	186397	95062K	PARTICIPANT	\N	EXCUSE	0
186416	186397	14051J	PARTICIPANT	\N	EXCUSE	0
186417	186397	14179A	PARTICIPANT	\N	PRESENT	0
186433	186432	14031R	PARTICIPANT	\N	PRESENT	0
186434	186432	14030Q	PARTICIPANT	\N	PRESENT	0
186435	186432	14271U	PARTICIPANT	\N	PRESENT	0
186436	186432	01024M	PARTICIPANT	\N	PRESENT	0
186437	186432	14073Q	PARTICIPANT	\N	PRESENT	0
186473	186472	08009T	PARTICIPANT	\N	PRESENT	0
186474	186472	08042U	PARTICIPANT	\N	PRESENT	0
186475	186472	14031R	PARTICIPANT	\N	PRESENT	0
186476	186472	80027E	PARTICIPANT	\N	PRESENT	0
186477	186472	14107H	PARTICIPANT	\N	PRESENT	0
186483	186482	01034P	PARTICIPANT	\N	PRESENT	0
186573	186572	04055H	PARTICIPANT	\N	PRESENT	0
186575	186574	04055H	PARTICIPANT	\N	PRESENT	0
186577	186576	11074Q	PARTICIPANT	\N	PRESENT	0
186578	186576	11083R	PARTICIPANT	\N	PRESENT	0
186593	186592	08034U	PARTICIPANT	\N	PRESENT	0
186595	186594	08034U	PARTICIPANT	\N	PRESENT	0
186613	186612	08011M	PARTICIPANT	\N	PRESENT	0
186615	186614	08011M	PARTICIPANT	\N	PRESENT	0
186617	186616	01031L	PARTICIPANT	\N	PRESENT	0
186753	186752	04034C	PARTICIPANT	\N	PRESENT	0
186754	186752	14038Y	PARTICIPANT	\N	PRESENT	0
186755	186752	04036E	PARTICIPANT	\N	PRESENT	0
186757	186756	04034C	PARTICIPANT	\N	PRESENT	0
187173	187172	11033F	PARTICIPANT	\N	PRESENT	0
187174	187172	04044E	PARTICIPANT	\N	PRESENT	0
187176	187175	11033F	PARTICIPANT	\N	PRESENT	0
187177	187175	04044E	PARTICIPANT	\N	PRESENT	0
187179	187178	14133K	PARTICIPANT	\N	PRESENT	0
187180	187178	96004D	PRESIDENT	0	PRESENT	0
187181	187178	14089Y	PARTICIPANT	\N	PRESENT	0
187182	187178	90003B	PARTICIPANT	\N	EXCUSE	0
187183	187178	14079W	PARTICIPANT	\N	EXCUSE	0
187184	187178	11035H	PARTICIPANT	\N	PRESENT	0
187185	187178	04035D	PARTICIPANT	\N	EXCUSE	0
187186	187178	11083R	PARTICIPANT	\N	PRESENT	0
187187	187178	95037J	PARTICIPANT	\N	PRESENT	0
187188	187178	08044W	PARTICIPANT	\N	PRESENT	0
187189	187178	14097Y	PARTICIPANT	\N	PRESENT	0
187190	187178	04061F	PARTICIPANT	\N	PRESENT	0
187191	187178	14073Q	PARTICIPANT	\N	PRESENT	0
187192	187178	11026G	PARTICIPANT	\N	PRESENT	0
187193	187178	98046X	PARTICIPANT	\N	PRESENT	0
187194	187178	04057K	PARTICIPANT	\N	EXCUSE	0
187195	187178	04080J	PARTICIPANT	\N	PRESENT	0
187196	187178	14135M	PARTICIPANT	\N	PRESENT	0
187197	187178	01016M	PARTICIPANT	\N	PRESENT	0
187198	187178	10015M	PARTICIPANT	\N	PRESENT	0
187199	187178	11012A	PARTICIPANT	\N	EXCUSE	0
187200	187178	04045F	PARTICIPANT	\N	EXCUSE	0
187201	187178	92045V	PARTICIPANT	\N	PRESENT	0
187233	187232	11039M	PARTICIPANT	\N	PRESENT	0
187234	187232	98042T	PARTICIPANT	\N	PRESENT	0
187235	187232	01019Q	PARTICIPANT	\N	PRESENT	0
187273	187272	08052W	PARTICIPANT	\N	PRESENT	0
187274	187272	14265W	PARTICIPANT	\N	PRESENT	0
187275	187272	14034U	PARTICIPANT	\N	PRESENT	0
187373	187372	08009T	PARTICIPANT	\N	PRESENT	0
187374	187372	08042U	PARTICIPANT	\N	PRESENT	0
187433	187432	14133K	PARTICIPANT	\N	PRESENT	0
187434	187432	08043V	PARTICIPANT	\N	PRESENT	0
187435	187432	08024S	PARTICIPANT	\N	PRESENT	0
187436	187432	10006L	PARTICIPANT	\N	PRESENT	0
187437	187432	14265W	PARTICIPANT	\N	PRESENT	0
187439	187438	14133K	PARTICIPANT	\N	PRESENT	0
187440	187438	08043V	PARTICIPANT	\N	PRESENT	0
187441	187438	08024S	PARTICIPANT	\N	PRESENT	0
187442	187438	14265W	PARTICIPANT	\N	PRESENT	0
187444	187443	14133K	PARTICIPANT	\N	PRESENT	0
187445	187443	08043V	PARTICIPANT	\N	PRESENT	0
187446	187443	08024S	PARTICIPANT	\N	PRESENT	0
187553	187552	07029T	PARTICIPANT	\N	PRESENT	0
187555	187554	07029T	PARTICIPANT	\N	PRESENT	0
187813	187812	11053K	PARTICIPANT	\N	PRESENT	0
187814	187812	01027Q	PARTICIPANT	\N	PRESENT	0
187815	187812	11083R	PARTICIPANT	\N	PRESENT	0
187816	187812	14159V	PARTICIPANT	\N	PRESENT	0
187817	187812	11012A	PARTICIPANT	\N	PRESENT	0
187819	187818	01013J	PARTICIPANT	\N	PRESENT	0
187820	187818	11053K	PARTICIPANT	\N	PRESENT	0
187821	187818	01027Q	PARTICIPANT	\N	PRESENT	0
187822	187818	11083R	PARTICIPANT	\N	PRESENT	0
187823	187818	01057W	PARTICIPANT	\N	PRESENT	0
187824	187818	14159V	PARTICIPANT	\N	PRESENT	0
187825	187818	14225N	PARTICIPANT	\N	PRESENT	0
187826	187818	14157T	PARTICIPANT	\N	PRESENT	0
187828	187827	01013J	PARTICIPANT	\N	PRESENT	0
187829	187827	11053K	PARTICIPANT	\N	PRESENT	0
187830	187827	01027Q	PARTICIPANT	\N	PRESENT	0
187831	187827	11083R	PARTICIPANT	\N	PRESENT	0
187832	187827	14159V	PARTICIPANT	\N	PRESENT	0
187833	187827	14225N	PARTICIPANT	\N	PRESENT	0
187834	187827	14157T	PARTICIPANT	\N	PRESENT	0
187852	187818	11080N	PARTICIPANT	\N	EXCUSE	0
187853	187818	92039X	PARTICIPANT	\N	EXCUSE	0
187854	187818	11012A	PARTICIPANT	\N	EXCUSE	0
187855	187827	11080N	PARTICIPANT	\N	EXCUSE	0
187856	187827	01057W	PARTICIPANT	\N	EXCUSE	0
187857	187827	92039X	PARTICIPANT	\N	EXCUSE	0
187858	187827	11012A	PARTICIPANT	\N	EXCUSE	0
187859	187812	01013J	PARTICIPANT	\N	EXCUSE	0
187860	187812	11080N	PARTICIPANT	\N	EXCUSE	0
187861	187812	01057W	PARTICIPANT	\N	EXCUSE	0
187862	187812	92039X	PARTICIPANT	\N	EXCUSE	0
187863	187812	14225N	PARTICIPANT	\N	EXCUSE	0
187864	187812	14157T	PARTICIPANT	\N	EXCUSE	0
188153	188152	11033F	PARTICIPANT	\N	PRESENT	0
188154	188152	04044E	PARTICIPANT	\N	PRESENT	0
188212	187693	11042G	PARTICIPANT	\N	PRESENT	0
188213	187693	11057P	PARTICIPANT	\N	PRESENT	0
188214	187693	08069G	PARTICIPANT	\N	EXCUSE	0
188215	187693	98053W	PARTICIPANT	\N	EXCUSE	0
188216	187693	89017R	PARTICIPANT	\N	EXCUSE	0
188217	187693	11085T	PARTICIPANT	\N	EXCUSE	0
188218	187693	08014Q	PARTICIPANT	\N	EXCUSE	0
188219	187693	08016S	PARTICIPANT	\N	EXCUSE	0
188220	187693	01013J	PARTICIPANT	\N	EXCUSE	0
188221	187693	14173T	PARTICIPANT	\N	EXCUSE	0
189053	189012	14111D	PARTICIPANT	\N	PRESENT	0
189054	189012	14065Q	PARTICIPANT	\N	PRESENT	0
189055	189012	07034Q	PARTICIPANT	\N	PRESENT	0
189056	189012	11026G	PARTICIPANT	\N	PRESENT	0
189057	189012	14001X	PARTICIPANT	\N	PRESENT	0
189058	189012	01024M	PARTICIPANT	\N	PRESENT	0
189059	189012	11113E	PARTICIPANT	\N	PRESENT	0
189060	189012	01007L	PARTICIPANT	\N	PRESENT	0
189061	189012	01028R	PARTICIPANT	\N	PRESENT	0
189062	189012	05008E	PRESIDENT	0	PRESENT	0
189063	189012	04085P	PARTICIPANT	\N	PRESENT	0
189064	189012	11035H	PARTICIPANT	\N	PRESENT	0
189065	189012	95063L	PARTICIPANT	\N	PRESENT	0
189066	189012	08025T	PARTICIPANT	\N	PRESENT	0
189067	189012	92045V	PARTICIPANT	\N	PRESENT	0
189068	189012	11037K	PARTICIPANT	\N	PRESENT	0
189069	189012	04056J	PARTICIPANT	\N	PRESENT	0
189070	189012	14147R	PARTICIPANT	\N	PRESENT	0
189071	189012	11084S	PARTICIPANT	\N	PRESENT	0
189072	189012	14069U	PARTICIPANT	\N	PRESENT	0
189073	189012	14215L	PARTICIPANT	\N	PRESENT	0
189074	189012	08018U	PARTICIPANT	\N	PRESENT	0
189075	189012	11049P	PARTICIPANT	\N	PRESENT	0
189076	189012	95049N	PARTICIPANT	\N	PRESENT	0
189077	189012	98035U	PARTICIPANT	\N	PRESENT	0
189078	189012	11056N	PARTICIPANT	\N	EXCUSE	0
189079	189012	14041T	PARTICIPANT	\N	EXCUSE	0
189080	189012	10015M	PARTICIPANT	\N	EXCUSE	0
189081	189012	04044E	PARTICIPANT	\N	EXCUSE	0
189082	189012	11033F	PARTICIPANT	\N	EXCUSE	0
189169	189168	11026G	PARTICIPANT	\N	PRESENT	0
189170	189168	10015M	PARTICIPANT	\N	PRESENT	0
189172	189171	04034C	PARTICIPANT	\N	PRESENT	0
189275	189274	04070G	PARTICIPANT	\N	PRESENT	0
189294	188273	05012A	PARTICIPANT	\N	PRESENT	0
189295	188273	08068F	PARTICIPANT	\N	PRESENT	0
189296	188273	14327T	PARTICIPANT	\N	PRESENT	0
189297	188273	01057W	PARTICIPANT	\N	PRESENT	0
189298	188273	08010L	PARTICIPANT	\N	PRESENT	0
189299	188273	11112D	PARTICIPANT	\N	PRESENT	0
189300	188273	95067Q	PARTICIPANT	\N	PRESENT	0
176137	174533	92045V	PARTICIPANT	\N	PRESENT	0
176138	174533	11084S	PARTICIPANT	\N	PRESENT	0
176139	174507	14327T	PARTICIPANT	\N	PRESENT	0
176140	174507	04071H	PARTICIPANT	\N	PRESENT	0
176141	174507	01057W	PARTICIPANT	\N	PRESENT	0
176142	174507	89017R	PARTICIPANT	\N	PRESENT	0
176143	174507	88008L	PARTICIPANT	\N	PRESENT	0
176144	174507	14225N	PARTICIPANT	\N	PRESENT	0
176145	174507	11068S	PARTICIPANT	\N	PRESENT	0
176146	174507	11088W	PARTICIPANT	\N	PRESENT	0
176147	174507	07029T	PARTICIPANT	\N	PRESENT	0
176148	174507	08010L	PARTICIPANT	\N	PRESENT	0
176149	174507	08061X	PARTICIPANT	\N	PRESENT	0
176150	174507	08016S	PARTICIPANT	\N	PRESENT	0
176151	174507	14175V	PARTICIPANT	\N	PRESENT	0
176152	174507	11048N	PARTICIPANT	\N	PRESENT	0
176153	174507	08034U	PARTICIPANT	\N	PRESENT	0
176154	174507	01016M	PARTICIPANT	\N	PRESENT	0
176155	174507	08011M	PARTICIPANT	\N	PRESENT	0
176156	174507	08014Q	PARTICIPANT	\N	PRESENT	0
176157	174507	14159V	PARTICIPANT	\N	PRESENT	0
176158	174507	14173T	PARTICIPANT	\N	PRESENT	0
176159	174507	11040E	PARTICIPANT	\N	PRESENT	0
176160	174507	04086Q	PARTICIPANT	\N	PRESENT	0
176161	174507	14083S	PARTICIPANT	\N	PRESENT	0
176162	174507	11012A	PARTICIPANT	\N	PRESENT	0
176163	174507	14199E	PARTICIPANT	\N	PRESENT	0
176164	174507	98046X	PARTICIPANT	\N	PRESENT	0
176165	174507	99004R	PARTICIPANT	\N	PRESENT	0
176166	174507	11085T	PARTICIPANT	\N	PRESENT	0
176167	174507	04061F	PRESIDENT	0	PRESENT	0
176168	174507	01013J	PARTICIPANT	\N	PRESENT	0
176169	174507	11042G	PARTICIPANT	\N	PRESENT	0
176170	174507	01031L	PARTICIPANT	\N	EXCUSE	0
176171	174507	11057P	PARTICIPANT	\N	EXCUSE	0
176172	174507	98053W	PARTICIPANT	\N	EXCUSE	0
176173	174507	01027Q	PARTICIPANT	\N	EXCUSE	0
177172	175155	95067Q	PARTICIPANT	\N	PRESENT	0
177173	175155	95063L	PARTICIPANT	\N	PRESENT	0
177174	175155	04074L	PARTICIPANT	\N	PRESENT	0
177175	175155	07034Q	PARTICIPANT	\N	PRESENT	0
177176	175155	14041T	PARTICIPANT	\N	PRESENT	0
177177	175155	10015M	PARTICIPANT	\N	PRESENT	0
177178	175155	04044E	PARTICIPANT	\N	PRESENT	0
177179	175155	01028R	PARTICIPANT	\N	PRESENT	0
177194	174511	04086Q	PARTICIPANT	\N	PRESENT	0
177195	174511	14327T	PARTICIPANT	\N	PRESENT	0
177196	174511	01031L	PRESIDENT	0	PRESENT	0
177197	174511	01057W	PARTICIPANT	\N	PRESENT	0
177198	174511	01016M	PARTICIPANT	\N	PRESENT	0
177199	174511	11074Q	PARTICIPANT	\N	PRESENT	0
177200	174511	99004R	PARTICIPANT	\N	PRESENT	0
177201	174511	14225N	PARTICIPANT	\N	PRESENT	0
177202	174511	14159V	PARTICIPANT	\N	PRESENT	0
177203	174511	11057P	PARTICIPANT	\N	EXCUSE	0
177204	174511	98053W	PARTICIPANT	\N	EXCUSE	0
177205	174511	08011M	PARTICIPANT	\N	EXCUSE	0
177206	174511	01027Q	PARTICIPANT	\N	EXCUSE	0
177212	167332	08055A	PARTICIPANT	\N	PRESENT	0
177214	167332	01057W	PARTICIPANT	\N	PRESENT	0
177215	167332	04050C	PARTICIPANT	\N	PRESENT	0
177216	167332	14063N	PARTICIPANT	\N	PRESENT	0
177217	167332	01016M	PARTICIPANT	\N	PRESENT	0
177218	167332	14225N	PARTICIPANT	\N	PRESENT	0
177219	167332	14219Q	PARTICIPANT	\N	PRESENT	0
177220	167332	04067M	PARTICIPANT	\N	PRESENT	0
177221	167332	14201E	PARTICIPANT	\N	PRESENT	0
177222	167332	08019V	PARTICIPANT	\N	PRESENT	0
177223	167332	14041T	PARTICIPANT	\N	PRESENT	0
177224	167332	14033T	PARTICIPANT	\N	PRESENT	0
177225	167332	11068S	PARTICIPANT	\N	PRESENT	0
177226	167332	11074Q	PARTICIPANT	\N	PRESENT	0
177227	167332	14207L	PARTICIPANT	\N	PRESENT	0
177228	167332	04086Q	PARTICIPANT	\N	PRESENT	0
177229	167332	01031L	PARTICIPANT	\N	PRESENT	0
177230	167332	14327T	PARTICIPANT	\N	PRESENT	0
177231	167332	04053F	PARTICIPANT	\N	PRESENT	0
177232	167332	14191V	PARTICIPANT	\N	PRESENT	0
177233	167332	11103C	PARTICIPANT	\N	PRESENT	0
177266	167332	08018U	PARTICIPANT	\N	PRESENT	0
177267	167332	14031R	PARTICIPANT	\N	PRESENT	0
177268	167332	14363X	PARTICIPANT	\N	PRESENT	0
177269	167332	04057K	PARTICIPANT	\N	PRESENT	0
177270	167332	01024M	PARTICIPANT	\N	PRESENT	0
177272	167332	14159V	PARTICIPANT	\N	PRESENT	0
177273	167332	95063L	PARTICIPANT	\N	PRESENT	0
177274	167332	80013X	PARTICIPANT	\N	PRESENT	0
177275	167332	14269B	PARTICIPANT	\N	PRESENT	0
177276	167332	14121F	PARTICIPANT	\N	PRESENT	0
177277	167332	11089X	PARTICIPANT	\N	PRESENT	0
177278	167332	11036J	PARTICIPANT	\N	PRESENT	0
177305	167332	11049P	PARTICIPANT	\N	PRESENT	0
177332	167332	04085P	PARTICIPANT	\N	PRESENT	0
177333	167332	04044E	PARTICIPANT	\N	PRESENT	0
177482	167315	14235Q	PARTICIPANT	\N	PRESENT	0
177483	167315	14063N	PARTICIPANT	\N	PRESENT	0
177484	167315	14105F	PARTICIPANT	\N	PRESENT	0
177485	167315	14191V	PARTICIPANT	\N	PRESENT	0
177486	167315	04081K	PARTICIPANT	\N	PRESENT	0
177487	167315	14201E	PARTICIPANT	\N	PRESENT	0
177488	167315	04074L	PARTICIPANT	\N	PRESENT	0
177489	167315	14269B	PARTICIPANT	\N	PRESENT	0
177490	167315	11084S	PARTICIPANT	\N	PRESENT	0
177491	167315	04067M	PARTICIPANT	\N	PRESENT	0
177492	167315	14071N	PARTICIPANT	\N	PRESENT	0
177493	167315	14357A	PARTICIPANT	\N	PRESENT	0
177494	167315	04044E	PARTICIPANT	\N	PRESENT	0
177519	167315	11099A	PARTICIPANT	\N	PRESENT	0
177480	167315	08024S	PARTICIPANT	\N	PRESENT	0
177481	167315	11034G	PARTICIPANT	\N	PRESENT	0
177520	167315	14363X	PARTICIPANT	\N	PRESENT	0
177523	167315	07034Q	PARTICIPANT	\N	PRESENT	0
177527	167315	08019V	PARTICIPANT	\N	PRESENT	0
177529	167315	14031R	PARTICIPANT	\N	PRESENT	0
177535	167315	14033T	PARTICIPANT	\N	PRESENT	0
177552	167315	04071H	PARTICIPANT	\N	PRESENT	0
177553	167315	14271U	PARTICIPANT	\N	PRESENT	0
182832	182792	01024M	PARTICIPANT	\N	PRESENT	0
182834	182833	05008E	PARTICIPANT	\N	PRESENT	0
182836	182835	05008E	PARTICIPANT	\N	PRESENT	0
182838	182837	05008E	PARTICIPANT	\N	PRESENT	0
182933	182932	14207L	PARTICIPANT	\N	PRESENT	0
182934	182932	14089Y	PARTICIPANT	\N	PRESENT	0
182938	182937	14089Y	PARTICIPANT	\N	PRESENT	0
182939	182937	14207L	PARTICIPANT	\N	PRESENT	0
182940	182937	11029K	PARTICIPANT	\N	PRESENT	0
182944	182943	14089Y	PARTICIPANT	\N	PRESENT	0
182945	182943	14207L	PARTICIPANT	\N	PRESENT	0
182949	182947	14207L	PARTICIPANT	\N	PRESENT	0
182950	182947	14089Y	PARTICIPANT	\N	PRESENT	0
182956	182955	14089Y	PARTICIPANT	\N	PRESENT	0
182957	182955	14207L	PRESIDENT	0	PRESENT	0
182958	182955	11023D	PARTICIPANT	\N	PRESENT	0
182959	182955	11095V	PARTICIPANT	\N	EXCUSE	0
182960	182955	14053L	PARTICIPANT	\N	EXCUSE	0
182961	182955	11014C	PARTICIPANT	\N	EXCUSE	0
182962	182955	04057K	PARTICIPANT	\N	EXCUSE	0
182963	182955	14229S	PARTICIPANT	\N	EXCUSE	0
175119	167279	14034U	PARTICIPANT	\N	PRESENT	0
175120	167279	14231L	PARTICIPANT	\N	PRESENT	0
175121	167279	08018U	PARTICIPANT	\N	PRESENT	0
175122	167279	14083S	PARTICIPANT	\N	PRESENT	0
175123	167279	01057W	PARTICIPANT	\N	PRESENT	0
175124	167279	89017R	PARTICIPANT	\N	PRESENT	0
175125	167279	14247U	PARTICIPANT	\N	PRESENT	0
175126	167279	14055N	PARTICIPANT	\N	PRESENT	0
175127	167279	14193X	PARTICIPANT	\N	PRESENT	0
175128	167279	01060R	PARTICIPANT	\N	PRESENT	0
175129	167279	11049P	PARTICIPANT	\N	PRESENT	0
175130	167279	07029T	PARTICIPANT	\N	PRESENT	0
175131	167279	01034P	PARTICIPANT	\N	PRESENT	0
175132	167279	11089X	PARTICIPANT	\N	PRESENT	0
175133	167279	11048N	PARTICIPANT	\N	PRESENT	0
175134	167279	14235Q	PARTICIPANT	\N	PRESENT	0
175135	167279	14329V	PARTICIPANT	\N	PRESENT	0
175136	167279	14249W	PARTICIPANT	\N	PRESENT	0
175137	167279	04071H	PARTICIPANT	\N	PRESENT	0
175138	167279	04077P	PARTICIPANT	\N	PRESENT	0
175139	167279	11014C	PARTICIPANT	\N	PRESENT	0
175140	167279	08031R	PARTICIPANT	\N	PRESENT	0
175141	167279	14251Q	PARTICIPANT	\N	PRESENT	0
175147	167279	14173T	PARTICIPANT	\N	PRESENT	0
175143	167279	08069G	PARTICIPANT	\N	PRESENT	0
175144	167279	92045V	PARTICIPANT	\N	PRESENT	0
175145	167279	01041N	PARTICIPANT	\N	PRESENT	0
175152	167279	14119M	PARTICIPANT	\N	PRESENT	0
175148	167279	04044E	PARTICIPANT	\N	PRESENT	0
175157	167279	08034U	PARTICIPANT	\N	PRESENT	0
175150	167279	92031P	PARTICIPANT	\N	PRESENT	0
175151	167279	04049K	PARTICIPANT	\N	PRESENT	0
175153	167279	08042U	PARTICIPANT	\N	PRESENT	0
175154	167279	14199E	PARTICIPANT	\N	PRESENT	0
175472	167288	89029V	PARTICIPANT	\N	PRESENT	0
180813	162262	89017R	PARTICIPANT	\N	PRESENT	0
180814	162262	14030Q	PARTICIPANT	\N	PRESENT	0
180815	162262	14105F	PARTICIPANT	\N	PRESENT	0
180816	162262	08068F	PARTICIPANT	\N	PRESENT	0
180817	162262	04053F	PARTICIPANT	\N	PRESENT	0
180818	162262	14207L	PARTICIPANT	\N	PRESENT	0
180819	162262	14083S	PARTICIPANT	\N	PRESENT	0
180820	162262	04071H	PARTICIPANT	\N	PRESENT	0
180821	162262	14061L	PARTICIPANT	\N	PRESENT	0
180823	162262	04049K	PRESIDENT	0	PRESENT	0
180824	162262	14205J	PARTICIPANT	\N	PRESENT	0
180825	162262	14265W	PARTICIPANT	\N	PRESENT	0
180826	162262	14253S	PARTICIPANT	\N	PRESENT	0
180827	162262	11090Q	PARTICIPANT	\N	PRESENT	0
180828	162262	14157T	PARTICIPANT	\N	PRESENT	0
180829	162262	11063M	PARTICIPANT	\N	PRESENT	0
180830	162262	14261S	PARTICIPANT	\N	EXCUSE	0
180831	162262	14065Q	PARTICIPANT	\N	EXCUSE	0
180832	162262	14013P	PARTICIPANT	\N	EXCUSE	0
180833	162262	14255U	PARTICIPANT	\N	EXCUSE	0
180834	162262	14079W	PARTICIPANT	\N	EXCUSE	0
180835	162262	11088W	PARTICIPANT	\N	EXCUSE	0
180836	162262	14041T	PARTICIPANT	\N	EXCUSE	0
180837	162262	14151M	PARTICIPANT	\N	EXCUSE	0
180838	162262	14087W	PARTICIPANT	\N	EXCUSE	0
180839	162262	02002K	PARTICIPANT	\N	EXCUSE	0
180840	162262	14034U	PARTICIPANT	\N	EXCUSE	0
180841	162262	14121F	PARTICIPANT	\N	EXCUSE	0
180842	162262	95041E	PARTICIPANT	\N	EXCUSE	0
180843	162262	14039A	PARTICIPANT	\N	EXCUSE	0
180845	162262	10015M	PARTICIPANT	\N	EXCUSE	0
180846	162262	95067Q	PARTICIPANT	\N	EXCUSE	0
180874	180873	14253S	PARTICIPANT	\N	PRESENT	0
180875	180873	14157T	PARTICIPANT	\N	PRESENT	0
182013	182012	08055A	PARTICIPANT	\N	PRESENT	0
182014	182012	11103C	PARTICIPANT	\N	PRESENT	0
182015	182012	90003B	PARTICIPANT	\N	PRESENT	0
182016	182012	11112D	PARTICIPANT	\N	PRESENT	0
182017	182012	14059S	PARTICIPANT	\N	PRESENT	0
182018	182012	14265W	PARTICIPANT	\N	PRESENT	0
182019	182012	14119M	PARTICIPANT	\N	PRESENT	0
182020	182012	08061X	PARTICIPANT	\N	PRESENT	0
182021	182012	04088S	PARTICIPANT	\N	PRESENT	0
182022	182012	14271U	PARTICIPANT	\N	PRESENT	0
182023	182012	14363X	PARTICIPANT	\N	PRESENT	0
182024	182012	14107H	PARTICIPANT	\N	PRESENT	0
182025	182012	92045V	PARTICIPANT	\N	PRESENT	0
182026	182012	95067Q	PARTICIPANT	\N	PRESENT	0
182032	181813	80013X	PARTICIPANT	\N	EXCUSE	0
182153	182152	14219Q	PARTICIPANT	\N	PRESENT	0
182154	182152	01056V	PARTICIPANT	\N	PRESENT	0
182155	182152	11065P	PARTICIPANT	\N	PRESENT	0
182156	182152	14093U	PARTICIPANT	\N	PRESENT	0
182172	182152	92045V	PARTICIPANT	\N	PRESENT	0
182177	182175	11065P	PARTICIPANT	\N	PRESENT	0
182174	182152	01008M	PARTICIPANT	\N	PRESENT	0
182176	182175	14219Q	PARTICIPANT	\N	PRESENT	0
182178	182175	90003B	PARTICIPANT	\N	PRESENT	0
182855	182854	98023Q	PARTICIPANT	\N	PRESENT	0
182856	182854	08015R	PARTICIPANT	\N	PRESENT	0
183292	165001	08069G	PARTICIPANT	\N	EXCUSE	0
185173	185172	99004R	PARTICIPANT	\N	PRESENT	0
185237	185236	14037X	PARTICIPANT	\N	PRESENT	0
185239	185238	14037X	PARTICIPANT	\N	PRESENT	0
185856	184963	14231L	PARTICIPANT	\N	EXCUSE	0
185857	184963	14327T	PARTICIPANT	\N	EXCUSE	0
186253	186252	14249W	PARTICIPANT	\N	PRESENT	0
186254	186252	07026Q	PARTICIPANT	\N	PRESENT	0
186256	186255	07026Q	PARTICIPANT	\N	PRESENT	0
186258	186257	11089X	PARTICIPANT	\N	PRESENT	0
186259	186257	07026Q	PARTICIPANT	\N	PRESENT	0
186293	186292	14071N	PARTICIPANT	\N	PRESENT	0
186294	186292	07034Q	PARTICIPANT	\N	PRESENT	0
186295	186292	10006L	PARTICIPANT	\N	PRESENT	0
186297	186296	07034Q	PARTICIPANT	\N	PRESENT	0
186299	186298	14071N	PARTICIPANT	\N	PRESENT	0
186300	186298	07034Q	PARTICIPANT	\N	PRESENT	0
186302	186301	07034Q	PARTICIPANT	\N	PRESENT	0
186303	186301	14071N	PARTICIPANT	\N	PRESENT	0
186305	186304	07034Q	PARTICIPANT	\N	PRESENT	0
186312	186304	10006L	PARTICIPANT	\N	PRESENT	0
186333	186332	07034Q	PARTICIPANT	\N	PRESENT	0
186353	186352	07034Q	PARTICIPANT	\N	PRESENT	0
186355	186354	07034Q	PARTICIPANT	\N	PRESENT	0
186357	186356	11083R	PARTICIPANT	\N	PRESENT	0
186359	186358	07034Q	PARTICIPANT	\N	PRESENT	0
186361	186360	07034Q	PARTICIPANT	\N	PRESENT	0
187557	187556	98053W	PARTICIPANT	\N	PRESENT	0
195384	190779	08031R	PARTICIPANT	\N	PRESENT	0
195385	190779	01046T	PARTICIPANT	\N	PRESENT	0
195386	190779	11070L	PARTICIPANT	\N	PRESENT	0
195387	190779	88008L	PARTICIPANT	\N	PRESENT	0
195388	190779	14261S	PARTICIPANT	\N	PRESENT	0
195389	190779	14267Y	PARTICIPANT	\N	PRESENT	0
195390	190779	08049C	PARTICIPANT	\N	PRESENT	0
195391	190779	11053K	PARTICIPANT	\N	PRESENT	0
195392	190779	14018U	PARTICIPANT	\N	PRESENT	0
195393	190779	11081P	PARTICIPANT	\N	PRESENT	0
195394	190779	14083S	PARTICIPANT	\N	PRESENT	0
195395	190779	19253P	PARTICIPANT	\N	PRESENT	0
195396	190779	14255U	PARTICIPANT	\N	PRESENT	0
195397	190779	11096W	PARTICIPANT	\N	PRESENT	0
195398	190779	14327T	PARTICIPANT	\N	PRESENT	0
195399	190779	98022P	PARTICIPANT	\N	PRESENT	0
195400	190779	04038G	PARTICIPANT	\N	PRESENT	0
195401	190779	01024M	PARTICIPANT	\N	PRESENT	0
195402	190779	14201E	PARTICIPANT	\N	PRESENT	0
195403	190779	14241N	PARTICIPANT	\N	PRESENT	0
195404	190779	14179A	PARTICIPANT	\N	PRESENT	0
195405	190779	01048V	PARTICIPANT	\N	PRESENT	0
167693	167692	05008E	PARTICIPANT	\N	PRESENT	0
167694	167692	14065Q	PARTICIPANT	\N	PRESENT	0
167695	167692	14069U	PARTICIPANT	\N	PRESENT	0
167696	167692	04047H	PARTICIPANT	\N	PRESENT	0
167697	167692	11035H	PARTICIPANT	\N	EXCUSE	0
167698	167692	14041T	PARTICIPANT	\N	PRESENT	0
167699	167692	01024M	PARTICIPANT	\N	PRESENT	0
167700	167692	14215L	PARTICIPANT	\N	PRESENT	0
167701	167692	01007L	PARTICIPANT	\N	PRESENT	0
167702	167692	08044W	PARTICIPANT	\N	EXCUSE	0
167703	167692	14111D	PARTICIPANT	\N	PRESENT	0
167704	167692	07034Q	PARTICIPANT	\N	PRESENT	0
167705	167692	04074L	PARTICIPANT	\N	PRESENT	0
167706	167692	01028R	PARTICIPANT	\N	PRESENT	0
167707	167692	98035U	PARTICIPANT	\N	PRESENT	0
167708	167692	04056J	PARTICIPANT	\N	PRESENT	0
167709	167692	11037K	PARTICIPANT	\N	PRESENT	0
167710	167692	92045V	PARTICIPANT	\N	PRESENT	0
167711	167692	95067Q	PARTICIPANT	\N	PRESENT	0
167832	166205	04040A	PARTICIPANT	\N	PRESENT	0
167840	167839	04040A	PARTICIPANT	\N	PRESENT	0
185773	185772	11076S	PARTICIPANT	\N	PRESENT	0
185994	184963	14063N	PARTICIPANT	\N	EXCUSE	0
186012	184963	14028W	PARTICIPANT	\N	EXCUSE	0
186713	186712	08010L	PARTICIPANT	\N	PRESENT	0
186714	186712	04040A	PARTICIPANT	\N	PRESENT	0
197614	197532	95067Q	PARTICIPANT	\N	PRESENT	0
186716	186712	90003B	PARTICIPANT	\N	PRESENT	0
186717	186712	08053X	PARTICIPANT	\N	PRESENT	0
187093	187092	04036E	PARTICIPANT	\N	PRESENT	0
197612	197294	11083R	PARTICIPANT	\N	PRESENT	0
197613	197294	08061X	PARTICIPANT	\N	PRESENT	0
197615	197532	01024M	PARTICIPANT	\N	PRESENT	0
197616	197532	04079R	PARTICIPANT	\N	PRESENT	0
197617	197294	88008L	PARTICIPANT	\N	PRESENT	0
197632	197552	07026Q	PARTICIPANT	\N	PRESENT	0
197633	197552	04070G	PRESIDENT	0	PRESENT	0
197634	197552	14103D	PARTICIPANT	\N	PRESENT	0
197635	197552	14061L	PARTICIPANT	\N	PRESENT	0
197636	197552	04057K	PARTICIPANT	\N	PRESENT	0
197637	197552	14073Q	PARTICIPANT	\N	PRESENT	0
197638	197552	11091R	PARTICIPANT	\N	PRESENT	0
197639	197552	08043V	PARTICIPANT	\N	PRESENT	0
197640	197552	11029K	PARTICIPANT	\N	PRESENT	0
197641	197552	04059M	PARTICIPANT	\N	PRESENT	0
197642	197552	08017T	PARTICIPANT	\N	PRESENT	0
197643	197552	14179A	PARTICIPANT	\N	PRESENT	0
197644	197552	08039A	PARTICIPANT	\N	PRESENT	0
197645	197552	08031R	PARTICIPANT	\N	EXCUSE	0
197674	190786	98053W	PARTICIPANT	\N	PRESENT	0
197692	190786	11034G	PARTICIPANT	\N	PRESENT	0
197693	190786	01022K	PARTICIPANT	\N	PRESENT	0
197694	190786	14063N	PARTICIPANT	\N	PRESENT	0
197695	190786	11112D	PARTICIPANT	\N	PRESENT	0
197696	190786	11037K	PARTICIPANT	\N	PRESENT	0
197697	190786	11061K	PARTICIPANT	\N	PRESENT	0
197698	190786	14269B	PARTICIPANT	\N	PRESENT	0
197699	190786	12042Y	PARTICIPANT	\N	PRESENT	0
197700	190786	95063L	PARTICIPANT	\N	PRESENT	0
197701	190786	14229S	PARTICIPANT	\N	PRESENT	0
197702	190786	11036J	PARTICIPANT	\N	PRESENT	0
197703	190786	14261S	PARTICIPANT	\N	PRESENT	0
197704	190786	08058D	PARTICIPANT	\N	PRESENT	0
197705	190786	95049N	PARTICIPANT	\N	PRESENT	0
197706	190786	07004J	PARTICIPANT	\N	PRESENT	0
197707	190786	11053K	PARTICIPANT	\N	PRESENT	0
197708	190786	14179A	PARTICIPANT	\N	PRESENT	0
197709	190786	14237S	PARTICIPANT	\N	PRESENT	0
197710	190786	11072N	PARTICIPANT	\N	PRESENT	0
197711	190786	13002U	PARTICIPANT	\N	PRESENT	0
197712	190786	14271U	PARTICIPANT	\N	PRESENT	0
197713	190786	14259Y	PARTICIPANT	\N	PRESENT	0
197714	190786	11014C	PARTICIPANT	\N	PRESENT	0
197715	190786	11067R	PARTICIPANT	\N	PRESENT	0
197716	190786	11107G	PARTICIPANT	\N	PRESENT	0
197717	190786	14051J	PARTICIPANT	\N	PRESENT	0
197718	190786	19251M	PARTICIPANT	\N	PRESENT	0
197719	190786	08049C	PARTICIPANT	\N	PRESENT	0
197720	190786	14089Y	PARTICIPANT	\N	PRESENT	0
197721	190786	14363X	PARTICIPANT	\N	PRESENT	0
197722	190786	14109K	PARTICIPANT	\N	PRESENT	0
197723	190786	11026G	PARTICIPANT	\N	PRESENT	0
197724	190786	14247U	PARTICIPANT	\N	PRESENT	0
197725	190786	04085P	PARTICIPANT	\N	PRESENT	0
197726	190786	11033F	PARTICIPANT	\N	PRESENT	0
197727	190786	86044G	PARTICIPANT	\N	PRESENT	0
197728	190786	04044E	PARTICIPANT	\N	PRESENT	0
197729	190786	14215L	PARTICIPANT	\N	PRESENT	0
197730	190786	98029W	PARTICIPANT	\N	PRESENT	0
197731	190786	14219Q	PARTICIPANT	\N	PRESENT	0
197732	190786	14097Y	PARTICIPANT	\N	PRESENT	0
197733	190786	14073Q	PARTICIPANT	\N	PRESENT	0
197734	190786	14083S	PARTICIPANT	\N	PRESENT	0
197735	190786	08043V	PARTICIPANT	\N	PRESENT	0
197736	190786	14065Q	PARTICIPANT	\N	PRESENT	0
197737	190786	08031R	PARTICIPANT	\N	PRESENT	0
197738	190786	04047H	PARTICIPANT	\N	PRESENT	0
197739	190786	01027Q	PARTICIPANT	\N	PRESENT	0
197740	190786	99004R	PARTICIPANT	\N	PRESENT	0
197741	190786	01013J	PARTICIPANT	\N	PRESENT	0
197742	190786	14038Y	PARTICIPANT	\N	PRESENT	0
197743	190786	98018T	PARTICIPANT	\N	PRESENT	0
197744	190786	95067Q	PARTICIPANT	\N	PRESENT	0
197745	190786	04074L	PARTICIPANT	\N	PRESENT	0
197746	190786	08019V	PARTICIPANT	\N	PRESENT	0
197747	190786	04088S	PARTICIPANT	\N	PRESENT	0
197748	190786	14033T	PARTICIPANT	\N	PRESENT	0
197749	190786	14157T	PARTICIPANT	\N	PRESENT	0
197750	190786	11011M	PARTICIPANT	\N	PRESENT	0
197751	190786	14111D	PARTICIPANT	\N	PRESENT	0
197752	190786	14211G	PARTICIPANT	\N	PRESENT	0
197753	190786	87003B	PARTICIPANT	\N	PRESENT	0
197754	190786	11043H	PARTICIPANT	\N	PRESENT	0
197755	190786	14223L	PARTICIPANT	\N	PRESENT	0
197756	190786	08041T	PARTICIPANT	\N	PRESENT	0
197757	190786	14041T	PARTICIPANT	\N	PRESENT	0
197758	190786	08062Y	PARTICIPANT	\N	PRESENT	0
197759	190786	07029T	PARTICIPANT	\N	PRESENT	0
197760	190786	14059S	PARTICIPANT	\N	PRESENT	0
197761	190786	08065C	PARTICIPANT	\N	PRESENT	0
197762	190786	14026U	PARTICIPANT	\N	PRESENT	0
197763	190786	14265W	PARTICIPANT	\N	PRESENT	0
197764	190786	14147R	PARTICIPANT	\N	PRESENT	0
197765	190786	08042U	PARTICIPANT	\N	PRESENT	0
197766	190786	14187A	PARTICIPANT	\N	PRESENT	0
197767	190786	11103C	PARTICIPANT	\N	PRESENT	0
197768	190786	14213J	PARTICIPANT	\N	PRESENT	0
197769	190786	14331P	PARTICIPANT	\N	PRESENT	0
197770	190786	14231L	PARTICIPANT	\N	PRESENT	0
197771	190786	01034P	PARTICIPANT	\N	PRESENT	0
197772	190786	14042U	PARTICIPANT	\N	PRESENT	0
197773	190786	01046T	PARTICIPANT	\N	PRESENT	0
197774	190786	01024M	PARTICIPANT	\N	PRESENT	0
197775	190786	04059M	PARTICIPANT	\N	PRESENT	0
197776	190786	11111C	PARTICIPANT	\N	PRESENT	0
197777	190786	08055A	PARTICIPANT	\N	PRESENT	0
197778	190786	14159V	PARTICIPANT	\N	PRESENT	0
197779	190786	14107H	PARTICIPANT	\N	PRESENT	0
197780	190786	04053F	PARTICIPANT	\N	PRESENT	0
197781	190786	07034Q	PARTICIPANT	\N	PRESENT	0
197782	190786	14071N	PARTICIPANT	\N	PRESENT	0
197783	190786	11088W	PARTICIPANT	\N	PRESENT	0
197784	190786	11066Q	PARTICIPANT	\N	PRESENT	0
197785	190786	11029K	PARTICIPANT	\N	PRESENT	0
197792	190786	04035D	PARTICIPANT	\N	PRESENT	0
197793	190786	11023D	PARTICIPANT	\N	PRESENT	0
197794	190786	14207L	PARTICIPANT	\N	PRESENT	0
197795	190786	11015D	PARTICIPANT	\N	PRESENT	0
197796	190786	11098Y	PARTICIPANT	\N	PRESENT	0
197797	190786	89017R	PARTICIPANT	\N	PRESENT	0
197798	190786	11083R	PARTICIPANT	\N	PRESENT	0
197799	190786	11089X	PARTICIPANT	\N	PRESENT	0
197800	190786	11093T	PARTICIPANT	\N	PRESENT	0
197801	190786	05008E	PARTICIPANT	\N	PRESENT	0
197802	190786	11077T	PARTICIPANT	\N	PRESENT	0
197803	190786	11085T	PARTICIPANT	\N	PRESENT	0
197804	190786	04045F	PARTICIPANT	\N	PRESENT	0
197805	190786	95062K	PARTICIPANT	\N	PRESENT	0
197806	190786	95030B	PARTICIPANT	\N	PRESENT	0
197807	190786	04033B	PARTICIPANT	\N	PRESENT	0
197808	190786	14119M	PARTICIPANT	\N	PRESENT	0
197809	190786	11091R	PARTICIPANT	\N	PRESENT	0
197810	190786	08028W	PARTICIPANT	\N	PRESENT	0
197811	190786	11042G	PARTICIPANT	\N	PRESENT	0
197812	190786	01047U	PARTICIPANT	\N	PRESENT	0
197813	190786	14241N	PARTICIPANT	\N	PRESENT	0
197814	190786	98022P	PARTICIPANT	\N	PRESENT	0
189301	188273	14034U	PARTICIPANT	\N	PRESENT	0
189302	188273	14083S	PARTICIPANT	\N	PRESENT	0
189355	189354	05008E	PARTICIPANT	\N	PRESENT	0
189356	189354	11084S	PARTICIPANT	\N	PRESENT	0
189357	189354	11026G	PARTICIPANT	\N	PRESENT	0
189358	189354	14069U	PARTICIPANT	\N	PRESENT	0
189359	189354	95063L	PARTICIPANT	\N	PRESENT	0
189361	189360	05008E	PARTICIPANT	\N	PRESENT	0
189362	189360	14069U	PARTICIPANT	\N	PRESENT	0
189363	189360	11026G	PARTICIPANT	\N	PRESENT	0
189433	189432	89017R	PARTICIPANT	\N	PRESENT	0
189453	189452	04040A	PARTICIPANT	\N	PRESENT	0
189454	189452	83042R	PARTICIPANT	\N	PRESENT	0
189456	189455	11054L	PARTICIPANT	\N	PRESENT	0
189458	189457	01014K	PARTICIPANT	\N	PRESENT	0
189459	189457	01056V	PARTICIPANT	\N	PRESENT	0
189461	189460	14028W	PARTICIPANT	\N	PRESENT	0
189462	189460	04042C	PARTICIPANT	\N	PRESENT	0
189465	189464	11083R	PARTICIPANT	\N	PRESENT	0
189466	189464	11074Q	PARTICIPANT	\N	PRESENT	0
189468	189467	11074Q	PARTICIPANT	\N	PRESENT	0
189469	188952	14261S	PARTICIPANT	\N	EXCUSE	0
189470	188952	98005N	PARTICIPANT	\N	EXCUSE	0
189533	189532	14187A	PARTICIPANT	\N	PRESENT	0
189572	188952	14034U	PARTICIPANT	\N	EXCUSE	0
190032	189773	92020L	PARTICIPANT	\N	EXCUSE	0
190033	189773	08065C	PARTICIPANT	\N	EXCUSE	0
190034	189773	07004J	PARTICIPANT	\N	EXCUSE	0
190035	189773	08056B	PARTICIPANT	\N	EXCUSE	0
190036	189773	14193X	PARTICIPANT	\N	EXCUSE	0
190153	190152	11053K	PARTICIPANT	\N	PRESENT	0
190277	189413	01031L	PRESIDENT	0	PRESENT	0
190278	189413	14225N	PARTICIPANT	\N	PRESENT	0
190279	189413	14085U	PARTICIPANT	\N	PRESENT	0
190280	189413	11057P	PARTICIPANT	\N	PRESENT	0
190281	189413	08061X	PARTICIPANT	\N	PRESENT	0
190282	189413	11048N	PARTICIPANT	\N	PRESENT	0
190283	189413	04086Q	PARTICIPANT	\N	PRESENT	0
190287	189413	08034U	PARTICIPANT	\N	PRESENT	0
190288	189413	01057W	PARTICIPANT	\N	PRESENT	0
190289	189413	89017R	PARTICIPANT	\N	PRESENT	0
190290	189413	08011M	PARTICIPANT	\N	PRESENT	0
190291	189413	11083R	PARTICIPANT	\N	PRESENT	0
190292	189413	01016M	PARTICIPANT	\N	PRESENT	0
190293	189413	08010L	PARTICIPANT	\N	PRESENT	0
190294	189413	14083S	PARTICIPANT	\N	PRESENT	0
190295	189413	04049K	PARTICIPANT	\N	PRESENT	0
190296	189413	14207L	PARTICIPANT	\N	PRESENT	0
190297	189413	04053F	PARTICIPANT	\N	PRESENT	0
190298	189413	14030Q	PARTICIPANT	\N	PRESENT	0
190299	189413	14079W	PARTICIPANT	\N	PRESENT	0
190300	189413	14061L	PARTICIPANT	\N	PRESENT	0
190301	189413	14265W	PARTICIPANT	\N	PRESENT	0
190302	189413	14157T	PARTICIPANT	\N	PRESENT	0
190303	189413	14105F	PARTICIPANT	\N	PRESENT	0
190333	189413	01013J	PARTICIPANT	\N	EXCUSE	0
190334	189413	11088W	PARTICIPANT	\N	EXCUSE	0
190335	189413	98053W	PARTICIPANT	\N	EXCUSE	0
190336	189413	07029T	PARTICIPANT	\N	EXCUSE	0
190337	189413	11085T	PARTICIPANT	\N	EXCUSE	0
190372	188952	14033T	PARTICIPANT	\N	EXCUSE	0
190377	189412	11053K	PARTICIPANT	\N	EXCUSE	0
190378	189413	11053K	PARTICIPANT	\N	EXCUSE	0
190472	190471	96004D	PARTICIPANT	\N	PRESENT	0
190474	190473	96004D	PARTICIPANT	\N	PRESENT	0
190476	190475	96004D	PARTICIPANT	\N	PRESENT	0
190478	190477	96004D	PARTICIPANT	\N	PRESENT	0
190712	190412	14034U	PARTICIPANT	\N	EXCUSE	0
190494	190492	14079W	PARTICIPANT	\N	PRESENT	0
190496	190495	14079W	PARTICIPANT	\N	PRESENT	0
190713	190412	11106F	PARTICIPANT	\N	EXCUSE	0
190714	190412	14219Q	PARTICIPANT	\N	EXCUSE	0
190715	190412	14017T	PARTICIPANT	\N	EXCUSE	0
190716	190412	14093U	PARTICIPANT	\N	EXCUSE	0
190717	190412	96004D	PARTICIPANT	\N	EXCUSE	0
190718	190412	11010L	PARTICIPANT	\N	EXCUSE	0
190819	190815	08034U	PARTICIPANT	\N	PRESENT	0
190817	190815	11043H	PARTICIPANT	\N	PRESENT	0
190818	190815	14235Q	PARTICIPANT	\N	PRESENT	0
190820	190815	14063N	PARTICIPANT	\N	PRESENT	0
191832	190772	86034E	PARTICIPANT	\N	PRESENT	0
191833	190772	92018S	PARTICIPANT	\N	PRESENT	0
191834	190772	11054L	PARTICIPANT	\N	PRESENT	0
191835	190772	08017T	PARTICIPANT	\N	PRESENT	0
191836	190772	14107H	PARTICIPANT	\N	PRESENT	0
191837	190772	11063M	PARTICIPANT	\N	PRESENT	0
191838	190772	14227Q	PARTICIPANT	\N	PRESENT	0
191839	190772	13002U	PARTICIPANT	\N	PRESENT	0
191840	190772	00003C	PARTICIPANT	\N	PRESENT	0
191841	190772	80013X	PARTICIPANT	\N	PRESENT	0
191842	190772	08060W	PARTICIPANT	\N	PRESENT	0
191843	190772	14257W	PARTICIPANT	\N	PRESENT	0
191844	190772	14097Y	PARTICIPANT	\N	PRESENT	0
191845	190772	14063N	PARTICIPANT	\N	PRESENT	0
191846	190772	11039M	PARTICIPANT	\N	PRESENT	0
191847	190772	01028R	PARTICIPANT	\N	PRESENT	0
191848	190772	08058D	PARTICIPANT	\N	PRESENT	0
191849	190772	14001X	PARTICIPANT	\N	PRESENT	0
191850	190772	14151M	PARTICIPANT	\N	PRESENT	0
191851	190772	04056J	PARTICIPANT	\N	PRESENT	0
191852	190772	05001W	PARTICIPANT	\N	PRESENT	0
191853	190772	07026Q	PARTICIPANT	\N	PRESENT	0
191854	190772	11040E	PARTICIPANT	\N	PRESENT	0
191855	190772	11031D	PARTICIPANT	\N	PRESENT	0
191856	190772	11034G	PARTICIPANT	\N	PRESENT	0
191857	190772	14361V	PARTICIPANT	\N	PRESENT	0
191858	190772	14235Q	PARTICIPANT	\N	PRESENT	0
191859	190772	11098Y	PARTICIPANT	\N	PRESENT	0
191860	190772	01056V	PARTICIPANT	\N	PRESENT	0
191861	190772	14211G	PARTICIPANT	\N	PRESENT	0
191862	190772	04097T	PARTICIPANT	\N	PRESENT	0
191863	190772	08039A	PARTICIPANT	\N	PRESENT	0
191864	190772	95015C	PARTICIPANT	\N	PRESENT	0
191871	190772	01027Q	PARTICIPANT	\N	PRESENT	0
191866	190772	08028W	PARTICIPANT	\N	PRESENT	0
191867	190772	95062K	PARTICIPANT	\N	PRESENT	0
191868	190772	04036E	PARTICIPANT	\N	PRESENT	0
191869	190772	95059Q	PARTICIPANT	\N	PRESENT	0
191870	190772	18127E	PARTICIPANT	\N	PRESENT	0
191872	190772	14223L	PARTICIPANT	\N	PRESENT	0
191873	190772	08010L	PARTICIPANT	\N	PRESENT	0
191874	190772	98018T	PARTICIPANT	\N	PRESENT	0
191875	190772	11023D	PARTICIPANT	\N	PRESENT	0
191876	190772	11100Y	PARTICIPANT	\N	PRESENT	0
191877	190772	95067Q	PARTICIPANT	\N	PRESENT	0
191878	190772	14259Y	PARTICIPANT	\N	PRESENT	0
191879	190772	12041X	PARTICIPANT	\N	PRESENT	0
191880	190772	04077P	PARTICIPANT	\N	PRESENT	0
191881	190772	87003B	PARTICIPANT	\N	PRESENT	0
191882	190772	86044G	PARTICIPANT	\N	PRESENT	0
191883	190772	08061X	PARTICIPANT	\N	PRESENT	0
191884	190772	04086Q	PARTICIPANT	\N	PRESENT	0
191885	190772	10006L	PARTICIPANT	\N	PRESENT	0
191886	190772	04053F	PARTICIPANT	\N	PRESENT	0
191887	190772	95063L	PARTICIPANT	\N	PRESENT	0
191888	190772	05004A	PARTICIPANT	\N	PRESENT	0
191889	190772	11104D	PARTICIPANT	\N	PRESENT	0
191890	190772	04044E	PARTICIPANT	\N	PRESENT	0
191891	190772	11036J	PARTICIPANT	\N	PRESENT	0
191892	190772	99004R	PARTICIPANT	\N	PRESENT	0
191893	190772	14271U	PARTICIPANT	\N	PRESENT	0
191894	190772	98029W	PARTICIPANT	\N	PRESENT	0
191895	190772	04066L	PARTICIPANT	\N	PRESENT	0
191896	190772	77002U	PARTICIPANT	\N	PRESENT	0
191897	190772	95037J	PARTICIPANT	\N	PRESENT	0
191898	190772	95030B	PARTICIPANT	\N	PRESENT	0
191899	190772	04045F	PARTICIPANT	\N	PRESENT	0
191900	190772	12042Y	PARTICIPANT	\N	PRESENT	0
191916	190772	14087W	PARTICIPANT	\N	PRESENT	0
191902	190772	11057P	PARTICIPANT	\N	PRESENT	0
191903	190772	11046L	PARTICIPANT	\N	PRESENT	0
191904	190772	01048V	PARTICIPANT	\N	PRESENT	0
191905	190772	11107G	PARTICIPANT	\N	PRESENT	0
191906	190772	05008E	PARTICIPANT	\N	PRESENT	0
191907	190772	11083R	PARTICIPANT	\N	PRESENT	0
191908	190772	14071N	PARTICIPANT	\N	PRESENT	0
191909	190772	92031P	PARTICIPANT	\N	PRESENT	0
191910	190772	11114F	PARTICIPANT	\N	PRESENT	0
191911	190772	14069U	PARTICIPANT	\N	PRESENT	0
191912	190772	14251Q	PARTICIPANT	\N	PRESENT	0
191913	190772	11113E	PARTICIPANT	\N	PRESENT	0
191914	190772	14191V	PARTICIPANT	\N	PRESENT	0
191915	190772	14215L	PARTICIPANT	\N	PRESENT	0
191917	190772	08073C	PARTICIPANT	\N	PRESENT	0
191918	190772	05012A	PARTICIPANT	\N	PRESENT	0
191919	190772	04057K	PARTICIPANT	\N	PRESENT	0
191920	190772	11072N	PARTICIPANT	\N	PRESENT	0
166265	166264	14089Y	PARTICIPANT	\N	PRESENT	0
166266	166264	14207L	PARTICIPANT	\N	PRESENT	0
166267	166264	14231L	PARTICIPANT	\N	PRESENT	0
166268	166264	14229S	PARTICIPANT	\N	PRESENT	0
167573	167572	14249W	PARTICIPANT	\N	PRESENT	0
171620	171619	96004D	PRESIDENT	0	PRESENT	0
171621	171619	04040A	PARTICIPANT	\N	PRESENT	0
171622	171619	11040E	PARTICIPANT	\N	PRESENT	0
171623	171619	14097Y	PARTICIPANT	\N	PRESENT	0
171624	171619	04057K	PARTICIPANT	\N	EXCUSE	0
171625	171619	95059Q	PARTICIPANT	\N	EXCUSE	0
171626	171619	04034C	PARTICIPANT	\N	PRESENT	0
171627	171619	14001X	PARTICIPANT	\N	PRESENT	0
171632	171619	92045V	PARTICIPANT	\N	PRESENT	0
177526	174352	14071N	PARTICIPANT	\N	EXCUSE	0
177653	177652	05008E	PARTICIPANT	\N	PRESENT	0
177655	177654	05008E	PARTICIPANT	\N	PRESENT	0
177657	177656	05008E	PARTICIPANT	\N	PRESENT	0
180632	174352	14014Q	PARTICIPANT	\N	EXCUSE	0
180633	174352	11098Y	PARTICIPANT	\N	EXCUSE	0
180893	180892	01008M	PARTICIPANT	\N	PRESENT	0
180895	180892	11089X	PARTICIPANT	\N	PRESENT	0
180896	180892	99004R	PRESIDENT	0	PRESENT	0
180917	180892	11094U	PARTICIPANT	\N	PRESENT	0
180927	180892	04038G	PARTICIPANT	\N	PRESENT	0
180928	180892	01059Y	PARTICIPANT	\N	PRESENT	0
180929	180892	11029K	PARTICIPANT	\N	PRESENT	0
180930	180892	14107H	PARTICIPANT	\N	PRESENT	0
180931	180892	02002K	PARTICIPANT	\N	PRESENT	0
180933	180892	08060W	PARTICIPANT	\N	EXCUSE	0
180934	180892	11080N	PARTICIPANT	\N	EXCUSE	0
180935	180892	08028W	PARTICIPANT	\N	EXCUSE	0
180936	180892	98018T	PARTICIPANT	\N	EXCUSE	0
180937	180892	11088W	PARTICIPANT	\N	EXCUSE	0
180938	180892	01015L	PARTICIPANT	\N	EXCUSE	0
180939	180892	01041N	PARTICIPANT	\N	EXCUSE	0
180940	180892	08048B	PARTICIPANT	\N	EXCUSE	0
180941	180892	14121F	PARTICIPANT	\N	EXCUSE	0
180944	180892	04061F	PARTICIPANT	\N	EXCUSE	0
180946	180892	01061S	PARTICIPANT	\N	EXCUSE	0
180949	180892	08012N	PARTICIPANT	\N	EXCUSE	0
180950	180892	14103D	PARTICIPANT	\N	EXCUSE	0
180951	180892	08062Y	PARTICIPANT	\N	EXCUSE	0
180952	180892	01028R	PARTICIPANT	\N	EXCUSE	0
180953	180892	92045V	PARTICIPANT	\N	EXCUSE	0
180954	180892	11066Q	PARTICIPANT	\N	EXCUSE	0
181137	181129	11090Q	PARTICIPANT	\N	PRESENT	0
183113	183112	98021N	PARTICIPANT	\N	PRESENT	0
181133	181129	97011G	PARTICIPANT	\N	PRESENT	0
181135	181129	04036E	PARTICIPANT	\N	PRESENT	0
181138	181129	95062K	PARTICIPANT	\N	PRESENT	0
181140	181129	95067Q	PARTICIPANT	\N	PRESENT	0
181141	181129	01047U	PARTICIPANT	\N	PRESENT	0
183095	183094	04055H	PARTICIPANT	\N	PRESENT	0
183114	183112	11106F	PARTICIPANT	\N	PRESENT	0
183115	183112	01056V	PARTICIPANT	\N	PRESENT	0
183116	183112	95037J	PARTICIPANT	\N	PRESENT	0
183118	183117	98021N	PARTICIPANT	\N	PRESENT	0
183119	183117	11106F	PARTICIPANT	\N	PRESENT	0
183120	183117	01056V	PARTICIPANT	\N	PRESENT	0
183122	183121	98021N	PARTICIPANT	\N	PRESENT	0
183123	183121	11106F	PARTICIPANT	\N	PRESENT	0
183124	183121	01056V	PARTICIPANT	\N	PRESENT	0
183125	183121	95037J	PARTICIPANT	\N	PRESENT	0
183127	183126	98021N	PARTICIPANT	\N	PRESENT	0
183128	183126	11106F	PARTICIPANT	\N	PRESENT	0
183129	183126	01056V	PARTICIPANT	\N	PRESENT	0
183130	183126	95037J	PARTICIPANT	\N	PRESENT	0
183132	183131	98021N	PARTICIPANT	\N	PRESENT	0
183133	183131	11106F	PARTICIPANT	\N	PRESENT	0
183134	183131	01056V	PARTICIPANT	\N	PRESENT	0
183136	183135	98021N	PARTICIPANT	\N	PRESENT	0
183137	183135	11106F	PARTICIPANT	\N	PRESENT	0
183333	183332	05008E	PARTICIPANT	\N	PRESENT	0
183335	183334	05008E	PARTICIPANT	\N	PRESENT	0
183339	183338	05008E	PARTICIPANT	\N	PRESENT	0
183553	183552	14133K	PARTICIPANT	\N	PRESENT	0
183554	183552	96004D	PRESIDENT	0	PRESENT	0
183555	183552	04040A	PARTICIPANT	\N	PRESENT	0
183556	183552	04042C	PARTICIPANT	\N	PRESENT	0
183557	183552	04035D	PARTICIPANT	\N	PRESENT	0
183558	183552	11083R	PARTICIPANT	\N	EXCUSE	0
183559	183552	14014Q	PARTICIPANT	\N	PRESENT	0
183560	183552	98022P	PARTICIPANT	\N	EXCUSE	0
183561	183552	04061F	PARTICIPANT	\N	PRESENT	0
183562	183552	14073Q	PARTICIPANT	\N	PRESENT	0
183563	183552	14001X	PARTICIPANT	\N	PRESENT	0
183564	183552	04057K	PARTICIPANT	\N	EXCUSE	0
183565	183552	04080J	PARTICIPANT	\N	PRESENT	0
183566	183552	04034C	PARTICIPANT	\N	EXCUSE	0
183567	183552	98035U	PARTICIPANT	\N	PRESENT	0
183568	183552	95059Q	PRESIDENT	1	PRESENT	0
183569	183552	14263U	PARTICIPANT	\N	PRESENT	0
183570	183552	04085P	PARTICIPANT	\N	PRESENT	0
183571	183552	04054G	PARTICIPANT	\N	PRESENT	0
183572	183552	04038G	PARTICIPANT	\N	PRESENT	0
183573	183552	04053F	PARTICIPANT	\N	PRESENT	0
183574	183552	01031L	PARTICIPANT	\N	PRESENT	0
183575	183552	14157T	PARTICIPANT	\N	PRESENT	0
183576	183552	04045F	PARTICIPANT	\N	PRESENT	0
183577	183552	14331P	PARTICIPANT	\N	PRESENT	0
183578	183552	14147R	PARTICIPANT	\N	PRESENT	0
183579	183552	11026G	PARTICIPANT	\N	PRESENT	0
183580	183552	11100Y	PARTICIPANT	\N	PRESENT	0
183581	183552	04036E	PARTICIPANT	\N	PRESENT	0
183582	183552	04097T	PARTICIPANT	\N	PRESENT	0
183583	183552	95030B	PARTICIPANT	\N	PRESENT	0
183584	183552	01041N	PARTICIPANT	\N	PRESENT	0
183585	183552	86034E	PARTICIPANT	\N	PRESENT	0
185593	185592	14219Q	PRESIDENT	0	PRESENT	0
185594	185592	11065P	PARTICIPANT	\N	PRESENT	0
185595	185592	09001P	PARTICIPANT	\N	PRESENT	0
185596	185592	13002U	PARTICIPANT	\N	PRESENT	0
185597	185592	05012A	PARTICIPANT	\N	PRESENT	0
185598	185592	01056V	PARTICIPANT	\N	PRESENT	0
185599	185592	08049C	PARTICIPANT	\N	EXCUSE	0
185600	185592	14033T	PARTICIPANT	\N	PRESENT	0
185601	185592	90003B	PARTICIPANT	\N	PRESENT	0
185602	185592	11035H	PARTICIPANT	\N	PRESENT	0
185603	185592	01008M	PARTICIPANT	\N	PRESENT	0
185673	185672	14135M	PARTICIPANT	\N	PRESENT	0
185605	185592	01015L	PARTICIPANT	\N	PRESENT	0
185606	185592	14093U	PARTICIPANT	\N	PRESENT	0
185713	185712	14042U	PARTICIPANT	\N	PRESENT	0
185714	185712	01011G	PARTICIPANT	\N	PRESENT	0
185716	185715	11031D	PARTICIPANT	\N	PRESENT	0
185717	185715	11061K	PARTICIPANT	\N	PRESENT	0
185718	185715	11097X	PARTICIPANT	\N	PRESENT	0
185720	185719	11031D	PARTICIPANT	\N	PRESENT	0
185721	185719	11061K	PARTICIPANT	\N	PRESENT	0
185722	185719	11097X	PARTICIPANT	\N	PRESENT	0
185797	185796	01027Q	PARTICIPANT	\N	PRESENT	0
185798	185796	14159V	PARTICIPANT	\N	PRESENT	0
185799	185796	11080N	PARTICIPANT	\N	PRESENT	0
185800	185796	11053K	PARTICIPANT	\N	PRESENT	0
186553	186552	04040A	PARTICIPANT	\N	PRESENT	0
186554	186552	14193X	PARTICIPANT	\N	PRESENT	0
186555	186552	11054L	PARTICIPANT	\N	PRESENT	0
186556	186552	08049C	PARTICIPANT	\N	PRESENT	0
186558	186557	14193X	PARTICIPANT	\N	PRESENT	0
186559	186557	11054L	PARTICIPANT	\N	PRESENT	0
186560	186557	08049C	PARTICIPANT	\N	PRESENT	0
186619	186618	14327T	PARTICIPANT	\N	PRESENT	0
186621	186620	01031L	PARTICIPANT	\N	PRESENT	0
186622	186620	08011M	PARTICIPANT	\N	PRESENT	0
186893	186892	96004D	PARTICIPANT	\N	PRESENT	0
186894	186892	14089Y	PARTICIPANT	\N	PRESENT	0
187133	187132	11103C	PARTICIPANT	\N	PRESENT	0
187134	187132	08052W	PARTICIPANT	\N	PRESENT	0
187153	187152	98046X	PARTICIPANT	\N	PRESENT	0
187155	187154	98046X	PARTICIPANT	\N	PRESENT	0
187157	187156	08010L	PARTICIPANT	\N	PRESENT	0
187159	187158	08010L	PARTICIPANT	\N	PRESENT	0
187161	187160	08010L	PARTICIPANT	\N	PRESENT	0
188571	188570	14263U	PARTICIPANT	\N	EXCUSE	0
188575	188570	01044R	PARTICIPANT	\N	EXCUSE	0
188576	188570	08043V	PARTICIPANT	\N	PRESENT	0
188577	188570	14089Y	PARTICIPANT	\N	EXCUSE	0
188579	188570	11029K	PARTICIPANT	\N	EXCUSE	0
188580	188570	95015C	PARTICIPANT	\N	PRESENT	0
188581	188570	92015P	PARTICIPANT	\N	EXCUSE	0
195406	190779	04049K	PARTICIPANT	\N	PRESENT	0
195407	190779	14030Q	PARTICIPANT	\N	PRESENT	0
195408	190779	14251Q	PARTICIPANT	\N	PRESENT	0
195409	190779	11064N	PARTICIPANT	\N	PRESENT	0
195410	190779	04080J	PARTICIPANT	\N	PRESENT	0
195411	190779	11094U	PARTICIPANT	\N	PRESENT	0
195412	190779	14034U	PARTICIPANT	\N	PRESENT	0
195413	190779	01028R	PARTICIPANT	\N	PRESENT	0
195414	190779	11104D	PARTICIPANT	\N	PRESENT	0
195415	190779	08044W	PARTICIPANT	\N	PRESENT	0
195416	190779	08024S	PARTICIPANT	\N	PRESENT	0
195417	190779	01019Q	PARTICIPANT	\N	PRESENT	0
195418	190779	04059M	PARTICIPANT	\N	PRESENT	0
195419	190779	04042C	PARTICIPANT	\N	PRESENT	0
195420	190779	14081Q	PARTICIPANT	\N	PRESENT	0
195421	190779	11083R	PARTICIPANT	\N	PRESENT	0
195422	190779	11042G	PARTICIPANT	\N	PRESENT	0
195423	190779	11066Q	PARTICIPANT	\N	PRESENT	0
195424	190779	14269B	PARTICIPANT	\N	PRESENT	0
195425	190779	11074Q	PARTICIPANT	\N	PRESENT	0
195426	190779	08056B	PARTICIPANT	\N	PRESENT	0
195427	190779	01014K	PARTICIPANT	\N	PRESENT	0
195428	190779	14231L	PARTICIPANT	\N	PRESENT	0
195429	190779	14225N	PARTICIPANT	\N	PRESENT	0
195430	190779	11037K	PARTICIPANT	\N	PRESENT	0
195431	190779	11067R	PARTICIPANT	\N	PRESENT	0
195432	190779	14042U	PARTICIPANT	\N	PRESENT	0
195433	190779	08035V	PARTICIPANT	\N	PRESENT	0
195434	190779	11076S	PARTICIPANT	\N	PRESENT	0
195435	190779	14073Q	PARTICIPANT	\N	PRESENT	0
195436	190779	14275Y	PARTICIPANT	\N	PRESENT	0
195437	190779	11082Q	PARTICIPANT	\N	PRESENT	0
195438	190779	11012A	PARTICIPANT	\N	PRESENT	0
195439	190779	14093U	PARTICIPANT	\N	PRESENT	0
195440	190779	11109J	PARTICIPANT	\N	PRESENT	0
195441	190779	14219Q	PARTICIPANT	\N	PRESENT	0
195442	190779	11106F	PARTICIPANT	\N	PRESENT	0
195443	190779	14205J	PARTICIPANT	\N	PRESENT	0
195444	190779	14159V	PARTICIPANT	\N	PRESENT	0
195445	190779	98042T	PARTICIPANT	\N	PRESENT	0
195446	190779	14071N	PARTICIPANT	\N	PRESENT	0
195452	190779	11039M	PARTICIPANT	\N	PRESENT	0
195448	190779	01057W	PARTICIPANT	\N	PRESENT	0
195449	190779	04067M	PARTICIPANT	\N	PRESENT	0
195453	190779	98050T	PARTICIPANT	\N	PRESENT	0
195746	190780	89029V	PARTICIPANT	\N	PRESENT	0
195455	190779	05008E	PARTICIPANT	\N	PRESENT	0
195472	190779	11048N	PARTICIPANT	\N	PRESENT	0
195752	190780	07034Q	PARTICIPANT	\N	PRESENT	0
195753	190780	05008E	PARTICIPANT	\N	PRESENT	0
195754	190780	95062K	PARTICIPANT	\N	PRESENT	0
195755	190780	08060W	PARTICIPANT	\N	PRESENT	0
195756	190780	11026G	PARTICIPANT	\N	PRESENT	0
195757	190780	14001X	PARTICIPANT	\N	PRESENT	0
195758	190780	14097Y	PARTICIPANT	\N	PRESENT	0
195759	190780	14207L	PARTICIPANT	\N	PRESENT	0
195760	190780	14159V	PARTICIPANT	\N	PRESENT	0
195761	190780	14227Q	PARTICIPANT	\N	PRESENT	0
195762	190780	14281W	PARTICIPANT	\N	PRESENT	0
195763	190780	11054L	PARTICIPANT	\N	PRESENT	0
195764	190780	14229S	PARTICIPANT	\N	PRESENT	0
195765	190780	14107H	PARTICIPANT	\N	PRESENT	0
195766	190780	11037K	PARTICIPANT	\N	PRESENT	0
195767	190780	11067R	PARTICIPANT	\N	PRESENT	0
195768	190780	01028R	PARTICIPANT	\N	PRESENT	0
195769	190780	08055A	PARTICIPANT	\N	PRESENT	0
195770	190780	11036J	PARTICIPANT	\N	PRESENT	0
195771	190780	11057P	PARTICIPANT	\N	PRESENT	0
195772	190780	14121F	PARTICIPANT	\N	PRESENT	0
195773	190780	11082Q	PARTICIPANT	\N	PRESENT	0
195774	190780	14275Y	PARTICIPANT	\N	PRESENT	0
195775	190780	07004J	PARTICIPANT	\N	PRESENT	0
195776	190780	11061K	PARTICIPANT	\N	PRESENT	0
195777	190780	14241N	PARTICIPANT	\N	PRESENT	0
195778	190780	98022P	PARTICIPANT	\N	PRESENT	0
195779	190780	14269B	PARTICIPANT	\N	PRESENT	0
195780	190780	11066Q	PARTICIPANT	\N	PRESENT	0
195781	190780	12042Y	PARTICIPANT	\N	PRESENT	0
195782	190780	95037J	PARTICIPANT	\N	PRESENT	0
195783	190780	11099A	PARTICIPANT	\N	PRESENT	0
195784	190780	14327T	PARTICIPANT	\N	PRESENT	0
195785	190780	11109J	PARTICIPANT	\N	PRESENT	0
195786	190780	14257W	PARTICIPANT	\N	PRESENT	0
195787	190780	14231L	PARTICIPANT	\N	PRESENT	0
195788	190780	11094U	PARTICIPANT	\N	PRESENT	0
195789	190780	11012A	PARTICIPANT	\N	PRESENT	0
195790	190780	01025N	PARTICIPANT	\N	PRESENT	0
195791	190780	14215L	PARTICIPANT	\N	PRESENT	0
195792	190780	08044W	PARTICIPANT	\N	PRESENT	0
195793	190780	14034U	PARTICIPANT	\N	PRESENT	0
195794	190780	11098Y	PARTICIPANT	\N	PRESENT	0
195795	190780	08019V	PARTICIPANT	\N	PRESENT	0
195796	190780	04074L	PARTICIPANT	\N	PRESENT	0
195797	190780	14031R	PARTICIPANT	\N	PRESENT	0
195798	190780	14157T	PARTICIPANT	\N	PRESENT	0
195799	190780	14195A	PARTICIPANT	\N	PRESENT	0
195800	190780	14135M	PARTICIPANT	\N	PRESENT	0
195801	190780	14033T	PARTICIPANT	\N	PRESENT	0
195802	190780	14041T	PARTICIPANT	\N	PRESENT	0
195806	190780	11091R	PARTICIPANT	\N	PRESENT	0
195804	190780	14038Y	PARTICIPANT	\N	PRESENT	0
195805	190780	11048N	PARTICIPANT	\N	PRESENT	0
195807	190780	07029T	PARTICIPANT	\N	PRESENT	0
195808	190780	14119M	PARTICIPANT	\N	PRESENT	0
195809	190780	11105E	PARTICIPANT	\N	PRESENT	0
195810	190780	04056J	PARTICIPANT	\N	PRESENT	0
195811	190780	08014Q	PARTICIPANT	\N	PRESENT	0
195812	190780	04045F	PARTICIPANT	\N	PRESENT	0
195813	190780	95049N	PARTICIPANT	\N	PRESENT	0
195814	190780	14261S	PARTICIPANT	\N	PRESENT	0
195815	190780	14018U	PARTICIPANT	\N	PRESENT	0
195816	190780	19253P	PARTICIPANT	\N	PRESENT	0
195817	190780	97011G	PARTICIPANT	\N	PRESENT	0
195818	190780	01022K	PARTICIPANT	\N	PRESENT	0
195819	190780	01059Y	PARTICIPANT	\N	PRESENT	0
195820	190780	14363X	PARTICIPANT	\N	PRESENT	0
195872	190780	14193X	PARTICIPANT	\N	PRESENT	0
195822	190780	11077T	PARTICIPANT	\N	PRESENT	0
195823	190780	88008L	PARTICIPANT	\N	PRESENT	0
195824	190780	04038G	PARTICIPANT	\N	PRESENT	0
195825	190780	11053K	PARTICIPANT	\N	PRESENT	0
195826	190780	01034P	PARTICIPANT	\N	PRESENT	0
195827	190780	14211G	PARTICIPANT	\N	PRESENT	0
195828	190780	14111D	PARTICIPANT	\N	PRESENT	0
195829	190780	10015M	PARTICIPANT	\N	PRESENT	0
195830	190780	05012A	PARTICIPANT	\N	PRESENT	0
195831	190780	98023Q	PARTICIPANT	\N	PRESENT	0
195832	190780	08028W	PARTICIPANT	\N	PRESENT	0
195833	190780	95030B	PARTICIPANT	\N	PRESENT	0
195834	190780	14201E	PARTICIPANT	\N	PRESENT	0
195835	190780	08068F	PARTICIPANT	\N	PRESENT	0
195836	190780	14357A	PARTICIPANT	\N	PRESENT	0
195837	190780	04088S	PARTICIPANT	\N	PRESENT	0
195838	190780	11081P	PARTICIPANT	\N	PRESENT	0
195839	190780	14199E	PARTICIPANT	\N	PRESENT	0
195840	190780	14249W	PARTICIPANT	\N	PRESENT	0
195841	190780	14217N	PARTICIPANT	\N	PRESENT	0
195842	190780	14087W	PARTICIPANT	\N	PRESENT	0
195843	190780	01008M	PARTICIPANT	\N	PRESENT	0
195844	190780	04059M	PARTICIPANT	\N	PRESENT	0
195845	190780	02002K	PARTICIPANT	\N	PRESENT	0
195846	190780	14103D	PARTICIPANT	\N	PRESENT	0
195847	190780	04085P	PARTICIPANT	\N	PRESENT	0
195848	190780	08010L	PARTICIPANT	\N	PRESENT	0
195849	190780	11076S	PARTICIPANT	\N	PRESENT	0
195850	190780	14187A	PARTICIPANT	\N	PRESENT	0
195852	190780	08053X	PARTICIPANT	\N	PRESENT	0
195853	190780	14151M	PARTICIPANT	\N	PRESENT	0
195854	190780	11033F	PARTICIPANT	\N	PRESENT	0
195855	190780	90003B	PARTICIPANT	\N	PRESENT	0
195856	190780	92045V	PARTICIPANT	\N	PRESENT	0
195857	190780	08024S	PARTICIPANT	\N	PRESENT	0
195858	190780	14191V	PARTICIPANT	\N	PRESENT	0
195859	190780	14073Q	PARTICIPANT	\N	PRESENT	0
195860	190780	04080J	PARTICIPANT	\N	PRESENT	0
195861	190780	08061X	PARTICIPANT	\N	PRESENT	0
195862	190780	01027Q	PARTICIPANT	\N	PRESENT	0
195863	190780	04067M	PARTICIPANT	\N	PRESENT	0
195864	190780	01016M	PARTICIPANT	\N	PRESENT	0
195865	190780	04066L	PARTICIPANT	\N	PRESENT	0
195866	190780	14069U	PARTICIPANT	\N	PRESENT	0
195867	190780	08062Y	PARTICIPANT	\N	PRESENT	0
195870	190780	14329V	PARTICIPANT	\N	PRESENT	0
195871	190780	14083S	PARTICIPANT	\N	PRESENT	0
195873	190780	11030C	PARTICIPANT	\N	PRESENT	0
195874	190780	14030Q	PARTICIPANT	\N	PRESENT	0
195875	190780	14219Q	PARTICIPANT	\N	PRESENT	0
195876	190780	14081Q	PARTICIPANT	\N	PRESENT	0
170912	169094	04044E	PARTICIPANT	\N	PRESENT	0
170919	169094	11044J	PARTICIPANT	\N	EXCUSE	0
171086	169094	11074Q	PARTICIPANT	\N	PRESENT	0
171735	171734	14255U	PARTICIPANT	\N	PRESENT	0
171736	171734	08024S	PARTICIPANT	\N	PRESENT	0
171737	171734	14042U	PARTICIPANT	\N	PRESENT	0
171738	171734	14231L	PARTICIPANT	\N	PRESENT	0
171739	171734	11083R	PARTICIPANT	\N	PRESENT	0
171740	171734	14059S	PARTICIPANT	\N	PRESENT	0
171741	171734	98046X	PARTICIPANT	\N	PRESENT	0
171742	171734	14071N	PARTICIPANT	\N	PRESENT	0
171743	171734	95063L	PARTICIPANT	\N	PRESENT	0
171744	171734	11043H	PARTICIPANT	\N	PRESENT	0
171753	171752	89017R	PARTICIPANT	\N	EXCUSE	0
171754	171752	01031L	PRESIDENT	0	PRESENT	0
172220	171870	92031P	PARTICIPANT	\N	PRESENT	0
171756	171752	01013J	PARTICIPANT	\N	PRESENT	0
171757	171752	11068S	PARTICIPANT	\N	PRESENT	0
171758	171752	11040E	PARTICIPANT	\N	PRESENT	0
171759	171752	08014Q	PARTICIPANT	\N	PRESENT	0
171814	171812	11109J	PARTICIPANT	\N	PRESENT	0
171761	171752	14175V	PARTICIPANT	\N	PRESENT	0
171762	171752	14083S	PARTICIPANT	\N	PRESENT	0
171763	171752	11053K	PARTICIPANT	\N	PRESENT	0
171764	171752	14085U	PARTICIPANT	\N	PRESENT	0
171765	171752	11042G	PARTICIPANT	\N	PRESENT	0
171815	171812	04059M	PARTICIPANT	\N	PRESENT	0
171767	171752	04086Q	PARTICIPANT	\N	PRESENT	0
171816	171812	11039M	PARTICIPANT	\N	PRESENT	0
171769	171752	11070L	PARTICIPANT	\N	PRESENT	0
171817	171812	01044R	PARTICIPANT	\N	PRESENT	0
171771	171752	14327T	PARTICIPANT	\N	PRESENT	0
171818	171812	08043V	PARTICIPANT	\N	PRESENT	0
171819	171812	14089Y	PARTICIPANT	\N	PRESENT	0
171774	171752	04071H	PARTICIPANT	\N	PRESENT	0
171820	171812	14105F	PARTICIPANT	\N	PRESENT	0
171776	171752	98053W	PARTICIPANT	\N	EXCUSE	0
171777	171752	11083R	PARTICIPANT	\N	PRESENT	0
171821	171812	11029K	PARTICIPANT	\N	PRESENT	0
171779	171752	01057W	PARTICIPANT	\N	PRESENT	0
171780	171752	08016S	PARTICIPANT	\N	PRESENT	0
171781	171752	08069G	PARTICIPANT	\N	PRESENT	0
171782	171752	11048N	PARTICIPANT	\N	PRESENT	0
171783	171752	99004R	PARTICIPANT	\N	PRESENT	0
171822	171812	95015C	PARTICIPANT	\N	PRESENT	0
171785	171752	14159V	PARTICIPANT	\N	PRESENT	0
171786	171752	07029T	PARTICIPANT	\N	EXCUSE	0
171823	171812	92015P	PARTICIPANT	\N	PRESENT	0
171788	171752	08010L	PARTICIPANT	\N	PRESENT	0
171789	171752	08034U	PARTICIPANT	\N	PRESENT	0
171824	171812	08024S	PARTICIPANT	\N	PRESENT	0
171791	171752	98046X	PARTICIPANT	\N	PRESENT	0
172505	172504	01013J	PARTICIPANT	\N	PRESENT	0
171793	171752	08011M	PARTICIPANT	\N	EXCUSE	0
171794	171752	08073C	PARTICIPANT	\N	PRESENT	0
171795	171752	08061X	PARTICIPANT	\N	PRESENT	0
171796	171752	01016M	PARTICIPANT	\N	PRESENT	0
171797	171752	14225N	PARTICIPANT	\N	PRESENT	0
171798	171752	11012A	PARTICIPANT	\N	PRESENT	0
171799	171752	11057P	PARTICIPANT	\N	PRESENT	0
171800	171752	14173T	PARTICIPANT	\N	PRESENT	0
171801	171752	04034C	PARTICIPANT	\N	PRESENT	0
171825	171812	14201E	PARTICIPANT	\N	PRESENT	0
171826	171812	14329V	PARTICIPANT	\N	PRESENT	0
171827	171812	14209N	PARTICIPANT	\N	PRESENT	0
171828	171812	14079W	PARTICIPANT	\N	PRESENT	0
171829	171812	11091R	PARTICIPANT	\N	EXCUSE	0
171830	171812	87003B	PARTICIPANT	\N	PRESENT	0
171831	171812	98042T	PARTICIPANT	\N	PRESENT	0
171832	171812	14249W	PARTICIPANT	\N	PRESENT	0
171833	171812	01041N	PARTICIPANT	\N	PRESENT	0
171834	171812	01025N	PARTICIPANT	\N	PRESENT	0
171835	171812	89029V	PARTICIPANT	\N	PRESENT	0
171836	171812	08035V	PARTICIPANT	\N	PRESENT	0
171837	171812	11089X	PARTICIPANT	\N	PRESENT	0
171838	171812	07026Q	PARTICIPANT	\N	PRESENT	0
171839	171812	14123H	PARTICIPANT	\N	PRESENT	0
171840	171812	14179A	PARTICIPANT	\N	PRESENT	0
171841	171812	04041B	PARTICIPANT	\N	PRESENT	0
171842	171812	14241N	PARTICIPANT	\N	PRESENT	0
171843	171812	14061L	PARTICIPANT	\N	PRESENT	0
171844	171812	14073Q	PARTICIPANT	\N	PRESENT	0
171845	171812	08031R	PARTICIPANT	\N	PRESENT	0
171846	171812	12041X	PARTICIPANT	\N	PRESENT	0
171847	171812	08039A	PARTICIPANT	\N	PRESENT	0
171848	171812	08017T	PARTICIPANT	\N	PRESENT	0
171849	171812	14059S	PARTICIPANT	\N	PRESENT	0
171850	171812	08012N	PARTICIPANT	\N	PRESENT	0
171851	171812	14103D	PARTICIPANT	\N	PRESENT	0
171852	171812	11104D	PARTICIPANT	\N	EXCUSE	0
171853	171812	14063N	PARTICIPANT	\N	PRESENT	0
171854	171812	04057K	PARTICIPANT	\N	EXCUSE	0
171855	171812	11014C	PARTICIPANT	\N	EXCUSE	0
172219	171870	11027H	PARTICIPANT	\N	PRESENT	0
171857	171812	04070G	PRESIDENT	0	PRESENT	0
171858	171812	92040Q	PARTICIPANT	\N	PRESENT	0
171859	171812	14191V	PARTICIPANT	\N	PRESENT	0
171860	171812	83047W	PARTICIPANT	\N	PRESENT	0
171861	171812	14235Q	PARTICIPANT	\N	PRESENT	0
171862	171812	14055N	PARTICIPANT	\N	PRESENT	0
172506	172504	11033F	PARTICIPANT	\N	PRESENT	0
171864	171812	14361V	PARTICIPANT	\N	PRESENT	0
171865	171812	14229S	PARTICIPANT	\N	EXCUSE	0
171866	171812	14363X	PARTICIPANT	\N	PRESENT	0
171867	171812	11043H	PARTICIPANT	\N	PRESENT	0
172507	172504	14013P	PARTICIPANT	\N	PRESENT	0
172508	172504	08014Q	PARTICIPANT	\N	PRESENT	0
172509	172504	11031D	PARTICIPANT	\N	PRESENT	0
172510	172504	01011G	PARTICIPANT	\N	PRESENT	0
171879	171870	11109J	PARTICIPANT	\N	PRESENT	0
172511	172504	14179A	PARTICIPANT	\N	PRESENT	0
172513	172504	04049K	PARTICIPANT	\N	PRESENT	0
172571	172504	14235Q	PARTICIPANT	\N	PRESENT	0
172572	172504	11076S	PARTICIPANT	\N	PRESENT	0
172573	172504	04056J	PARTICIPANT	\N	PRESENT	0
172574	172504	95067Q	PARTICIPANT	\N	PRESENT	0
172575	172504	14269B	PARTICIPANT	\N	PRESENT	0
172984	172980	08012N	PARTICIPANT	\N	PRESENT	0
172983	172980	11039M	PARTICIPANT	\N	PRESENT	0
172986	172980	14073Q	PARTICIPANT	\N	PRESENT	0
172989	172980	14241N	PARTICIPANT	\N	PRESENT	0
172992	172980	14235Q	PARTICIPANT	\N	PRESENT	0
173649	173648	07004J	PARTICIPANT	\N	PRESENT	0
173650	173648	11074Q	PARTICIPANT	\N	PRESENT	0
173651	173648	04036E	PARTICIPANT	\N	PRESENT	0
175812	174510	11034G	PARTICIPANT	\N	PRESENT	0
175813	174510	14001X	PARTICIPANT	\N	PRESENT	0
175814	174510	04044E	PARTICIPANT	\N	PRESENT	0
175815	174510	01019Q	PARTICIPANT	\N	PRESENT	0
175816	174510	11113E	PARTICIPANT	\N	PRESENT	0
175817	174510	04047H	PARTICIPANT	\N	PRESENT	0
175818	174510	01007L	PARTICIPANT	\N	PRESENT	0
171902	171870	01044R	PARTICIPANT	\N	PRESENT	0
171903	171870	08043V	PARTICIPANT	\N	PRESENT	0
175819	174510	01028R	PARTICIPANT	\N	PRESENT	0
175820	174510	05008E	PARTICIPANT	\N	PRESENT	0
175821	174510	11035H	PARTICIPANT	\N	PRESENT	0
175822	174510	14275Y	PARTICIPANT	\N	PRESENT	0
175823	174510	08025T	PARTICIPANT	\N	PRESENT	0
175824	174510	92045V	PARTICIPANT	\N	PRESENT	0
175825	174510	14041T	PARTICIPANT	\N	PRESENT	0
171911	171870	14105F	PARTICIPANT	\N	PRESENT	0
171912	171870	11029K	PARTICIPANT	\N	PRESENT	0
175826	174510	14215L	PARTICIPANT	\N	PRESENT	0
175827	174510	14259Y	PARTICIPANT	\N	PRESENT	0
175828	174510	98035U	PARTICIPANT	\N	PRESENT	0
175829	174510	14111D	PARTICIPANT	\N	PRESENT	0
175830	174510	95067Q	PARTICIPANT	\N	PRESENT	0
175831	174510	07034Q	PARTICIPANT	\N	PRESENT	0
175832	174510	10015M	PARTICIPANT	\N	PRESENT	0
175833	174510	01024M	PARTICIPANT	\N	PRESENT	0
175834	174510	04038G	PARTICIPANT	\N	PRESENT	0
175835	174510	11033F	PARTICIPANT	\N	PRESENT	0
175836	174510	11056N	PARTICIPANT	\N	PRESENT	0
175837	174510	95063L	PARTICIPANT	\N	PRESENT	0
175838	174510	11037K	PARTICIPANT	\N	PRESENT	0
175839	174510	04074L	PARTICIPANT	\N	PRESENT	0
175840	174510	11084S	PARTICIPANT	\N	PRESENT	0
175841	174510	14069U	PARTICIPANT	\N	PRESENT	0
175842	174510	11049P	PARTICIPANT	\N	PRESENT	0
175843	174510	95049N	PARTICIPANT	\N	PRESENT	0
175844	174510	01047U	PARTICIPANT	\N	PRESENT	0
175845	174510	04079R	PARTICIPANT	\N	PRESENT	0
171933	171870	92015P	PARTICIPANT	\N	PRESENT	0
175846	174510	11030C	PARTICIPANT	\N	PRESENT	0
175847	174510	14147R	PARTICIPANT	\N	PRESENT	0
175848	174510	11072N	PARTICIPANT	\N	PRESENT	0
175849	174510	99002P	PARTICIPANT	\N	PRESENT	0
175850	174510	11032E	PARTICIPANT	\N	PRESENT	0
191921	190772	95035G	PARTICIPANT	\N	PRESENT	0
191922	190772	04094Q	PARTICIPANT	\N	PRESENT	0
191923	190772	04061F	PARTICIPANT	\N	PRESENT	0
191924	190772	14331P	PARTICIPANT	\N	PRESENT	0
191925	190772	14249W	PARTICIPANT	\N	PRESENT	0
191926	190772	14079W	PARTICIPANT	\N	PRESENT	0
191927	190772	14039A	PARTICIPANT	\N	PRESENT	0
191928	190772	04033B	PARTICIPANT	\N	PRESENT	0
191929	190772	11029K	PARTICIPANT	\N	PRESENT	0
191930	190772	11099A	PARTICIPANT	\N	PRESENT	0
191931	190772	11080N	PARTICIPANT	\N	PRESENT	0
191932	190772	14111D	PARTICIPANT	\N	PRESENT	0
191933	190772	89017R	PARTICIPANT	\N	PRESENT	0
191934	190772	14026U	PARTICIPANT	\N	PRESENT	0
191935	190772	11033F	PARTICIPANT	\N	PRESENT	0
191936	190772	11065P	PARTICIPANT	\N	PRESENT	0
191937	190772	04047H	PARTICIPANT	\N	PRESENT	0
191938	190772	04067M	PARTICIPANT	\N	PRESENT	0
191939	190772	14247U	PARTICIPANT	\N	PRESENT	0
191940	190772	14209N	PARTICIPANT	\N	PRESENT	0
191941	190772	97011G	PARTICIPANT	\N	PRESENT	0
191942	190772	08031R	PARTICIPANT	\N	PRESENT	0
191943	190772	01046T	PARTICIPANT	\N	PRESENT	0
191944	190772	04078Q	PARTICIPANT	\N	PRESENT	0
191945	190772	14059S	PARTICIPANT	\N	PRESENT	0
191946	190772	11012A	PARTICIPANT	\N	PRESENT	0
191947	190772	11081P	PARTICIPANT	\N	PRESENT	0
191948	190772	11044J	PARTICIPANT	\N	PRESENT	0
191949	190772	83042R	PARTICIPANT	\N	PRESENT	0
191950	190772	19253P	PARTICIPANT	\N	PRESENT	0
191951	190772	04034C	PARTICIPANT	\N	PRESENT	0
191952	190772	04092N	PARTICIPANT	\N	PRESENT	0
191953	190772	98022P	PARTICIPANT	\N	PRESENT	0
191954	190772	14031R	PARTICIPANT	\N	PRESENT	0
191955	190772	14135M	PARTICIPANT	\N	PRESENT	0
191956	190772	08016S	PARTICIPANT	\N	PRESENT	0
191957	190772	04059M	PARTICIPANT	\N	PRESENT	0
191958	190772	07029T	PARTICIPANT	\N	PRESENT	0
191959	190772	08052W	PARTICIPANT	\N	PRESENT	0
191960	190772	14061L	PARTICIPANT	\N	PRESENT	0
191961	190772	11027H	PARTICIPANT	\N	PRESENT	0
191962	190772	01031L	PARTICIPANT	\N	PRESENT	0
191963	190772	14195A	PARTICIPANT	\N	PRESENT	0
191964	190772	14065Q	PARTICIPANT	\N	PRESENT	0
191965	190772	14363X	PARTICIPANT	\N	PRESENT	0
191966	190772	14028W	PARTICIPANT	\N	PRESENT	0
191967	190772	08042U	PARTICIPANT	\N	PRESENT	0
191968	190772	01022K	PARTICIPANT	\N	PRESENT	0
191969	190772	11069T	PARTICIPANT	\N	PRESENT	0
191970	190772	04074L	PARTICIPANT	\N	PRESENT	0
191971	190772	08012N	PARTICIPANT	\N	PRESENT	0
191972	190772	14038Y	PARTICIPANT	\N	PRESENT	0
191973	190772	11089X	PARTICIPANT	\N	PRESENT	0
191974	190772	14197C	PARTICIPANT	\N	PRESENT	0
191975	190772	08043V	PARTICIPANT	\N	PRESENT	0
191976	190772	01014K	PARTICIPANT	\N	PRESENT	0
191977	190772	14105F	PARTICIPANT	\N	PRESENT	0
191978	190772	11077T	PARTICIPANT	\N	PRESENT	0
191979	190772	08019V	PARTICIPANT	\N	PRESENT	0
191980	190772	14085U	PARTICIPANT	\N	PRESENT	0
191981	190772	04088S	PARTICIPANT	\N	PRESENT	0
191982	190772	08014Q	PARTICIPANT	\N	PRESENT	0
191983	190772	14041T	PARTICIPANT	\N	PRESENT	0
191984	190772	14207L	PARTICIPANT	\N	PRESENT	0
191985	190772	14225N	PARTICIPANT	\N	PRESENT	0
191986	190772	98046X	PARTICIPANT	\N	PRESENT	0
191987	190772	14187A	PARTICIPANT	\N	PRESENT	0
191988	190772	14229S	PARTICIPANT	\N	PRESENT	0
191989	190772	98023Q	PARTICIPANT	\N	PRESENT	0
191990	190772	11061K	PARTICIPANT	\N	PRESENT	0
191991	190772	14281W	PARTICIPANT	\N	PRESENT	0
191992	190772	19251M	PARTICIPANT	\N	PRESENT	0
191993	190772	95049N	PARTICIPANT	\N	PRESENT	0
191994	190772	10015M	PARTICIPANT	\N	PRESENT	0
191995	190772	01034P	PARTICIPANT	\N	PRESENT	0
191996	190772	11094U	PARTICIPANT	\N	PRESENT	0
191997	190772	08009T	PARTICIPANT	\N	PRESENT	0
191998	190772	11053K	PARTICIPANT	\N	PRESENT	0
191999	190772	14157T	PARTICIPANT	\N	PRESENT	0
192000	190772	04040A	PARTICIPANT	\N	PRESENT	0
192001	190772	14034U	PARTICIPANT	\N	PRESENT	0
192002	190772	11070L	PARTICIPANT	\N	PRESENT	0
192003	190772	11064N	PARTICIPANT	\N	PRESENT	0
192004	190772	14033T	PARTICIPANT	\N	PRESENT	0
192005	190772	14205J	PARTICIPANT	\N	PRESENT	0
192032	190772	14231L	PARTICIPANT	\N	PRESENT	0
192007	190772	14042U	PARTICIPANT	\N	PRESENT	0
192008	190772	04042C	PARTICIPANT	\N	PRESENT	0
192009	190772	14267Y	PARTICIPANT	\N	PRESENT	0
192010	190772	14103D	PARTICIPANT	\N	PRESENT	0
192011	190772	14221J	PARTICIPANT	\N	PRESENT	0
192012	190772	14089Y	PARTICIPANT	\N	PRESENT	0
192013	190772	11045K	PARTICIPANT	\N	PRESENT	0
192014	190772	11109J	PARTICIPANT	\N	PRESENT	0
192015	190772	04081K	PARTICIPANT	\N	PRESENT	0
192016	190772	11042G	PARTICIPANT	\N	PRESENT	0
192017	190772	11030C	PARTICIPANT	\N	PRESENT	0
192018	190772	14147R	PARTICIPANT	\N	PRESENT	0
192020	190772	11048N	PARTICIPANT	\N	PRESENT	0
192021	190772	11082Q	PARTICIPANT	\N	PRESENT	0
192023	190772	04049K	PARTICIPANT	\N	PRESENT	0
192024	190772	11111C	PARTICIPANT	\N	PRESENT	0
192025	190772	14073Q	PARTICIPANT	\N	PRESENT	0
192026	190772	08044W	PARTICIPANT	\N	PRESENT	0
192027	190772	14275Y	PARTICIPANT	\N	PRESENT	0
192028	190772	14093U	PARTICIPANT	\N	PRESENT	0
192029	190772	14277B	PARTICIPANT	\N	PRESENT	0
192030	190772	08047A	PARTICIPANT	\N	PRESENT	0
192031	190772	08069G	PARTICIPANT	\N	PRESENT	0
192033	190772	14083S	PARTICIPANT	\N	PRESENT	0
192034	190772	07004J	PARTICIPANT	\N	PRESENT	0
192035	190772	04089T	PARTICIPANT	\N	PRESENT	0
192036	190772	98042T	PARTICIPANT	\N	PRESENT	0
192037	190772	11085T	PARTICIPANT	\N	PRESENT	0
192038	190772	14255U	PARTICIPANT	\N	PRESENT	0
192039	190772	09001P	PARTICIPANT	\N	PRESENT	0
192040	190772	01047U	PARTICIPANT	\N	PRESENT	0
192041	190772	11010L	PARTICIPANT	\N	PRESENT	0
192042	190772	04070G	PARTICIPANT	\N	PRESENT	0
192043	190772	14219Q	PARTICIPANT	\N	PRESENT	0
192044	190772	01024M	PARTICIPANT	\N	PRESENT	0
192045	190772	01025N	PARTICIPANT	\N	PRESENT	0
192046	190772	14030Q	PARTICIPANT	\N	PRESENT	0
192047	190772	14327T	PARTICIPANT	\N	PRESENT	0
192048	190772	04071H	PARTICIPANT	\N	PRESENT	0
192049	190772	14357A	PARTICIPANT	\N	PRESENT	0
192050	190772	11067R	PARTICIPANT	\N	PRESENT	0
192051	190772	08011M	PARTICIPANT	\N	PRESENT	0
192053	190772	14159V	PARTICIPANT	\N	PRESENT	0
192055	190772	11066Q	PARTICIPANT	\N	PRESENT	0
192056	190772	14269B	PARTICIPANT	\N	PRESENT	0
192059	190772	08015R	PARTICIPANT	\N	PRESENT	0
192073	190772	14217N	PARTICIPANT	\N	PRESENT	0
192081	190772	14329V	PARTICIPANT	\N	PRESENT	0
192088	190772	04054G	PARTICIPANT	\N	PRESENT	0
192089	190772	01015L	PARTICIPANT	\N	PRESENT	0
192091	190533	14327T	PARTICIPANT	\N	PRESENT	0
192092	190533	04034C	PARTICIPANT	\N	PRESENT	0
192093	190533	01057W	PARTICIPANT	\N	PRESENT	0
192094	190533	11053K	PARTICIPANT	\N	PRESENT	0
192095	190533	11070L	PARTICIPANT	\N	PRESENT	0
192097	190533	14225N	PARTICIPANT	\N	PRESENT	0
192098	190533	88008L	PARTICIPANT	\N	PRESENT	0
192099	190533	11088W	PARTICIPANT	\N	PRESENT	0
192100	190533	07029T	PARTICIPANT	\N	PRESENT	0
192101	190533	14277B	PARTICIPANT	\N	PRESENT	0
192102	190533	14085U	PARTICIPANT	\N	PRESENT	0
192103	190533	08010L	PARTICIPANT	\N	PRESENT	0
192104	190533	14253S	PARTICIPANT	\N	PRESENT	0
192105	190533	08061X	PARTICIPANT	\N	PRESENT	0
192106	190533	08016S	PARTICIPANT	\N	PRESENT	0
192107	190533	01031L	PRESIDENT	0	PRESENT	0
192108	190533	11048N	PARTICIPANT	\N	PRESENT	0
192109	190533	08069G	PARTICIPANT	\N	PRESENT	0
192110	190533	08011M	PARTICIPANT	\N	PRESENT	0
192111	190533	01027Q	PARTICIPANT	\N	PRESENT	0
192112	190533	08014Q	PARTICIPANT	\N	PRESENT	0
192113	190533	14159V	PARTICIPANT	\N	PRESENT	0
192114	190533	04086Q	PARTICIPANT	\N	PRESENT	0
192115	190533	14083S	PARTICIPANT	\N	PRESENT	0
192116	190533	11057P	PARTICIPANT	\N	PRESENT	0
192117	190533	11012A	PARTICIPANT	\N	PRESENT	0
192118	190533	08073C	PARTICIPANT	\N	PRESENT	0
192119	190533	98046X	PARTICIPANT	\N	PRESENT	0
192120	190533	11083R	PARTICIPANT	\N	PRESENT	0
192121	190533	99004R	PARTICIPANT	\N	PRESENT	0
192122	190533	04061F	PARTICIPANT	\N	PRESENT	0
192123	190533	11042G	PARTICIPANT	\N	PRESENT	0
174353	174352	04040A	PRESIDENT	0	PRESENT	0
177555	177554	14193X	PARTICIPANT	\N	PRESENT	0
177556	177554	11054L	PARTICIPANT	\N	PRESENT	0
177557	177554	04040A	PARTICIPANT	\N	PRESENT	0
177558	177554	08049C	PARTICIPANT	\N	PRESENT	0
177573	177572	14193X	PARTICIPANT	\N	PRESENT	0
177574	177572	11054L	PARTICIPANT	\N	PRESENT	0
184812	184592	14263U	PARTICIPANT	\N	EXCUSE	0
184813	184592	11068S	PARTICIPANT	\N	EXCUSE	0
184814	184592	14209N	PARTICIPANT	\N	EXCUSE	0
184815	184592	08069G	PARTICIPANT	\N	EXCUSE	0
184816	184592	08039A	PARTICIPANT	\N	EXCUSE	0
184817	184592	14221J	PARTICIPANT	\N	EXCUSE	0
184818	184592	11082Q	PARTICIPANT	\N	PRESENT	0
184819	184592	01058X	PARTICIPANT	\N	PRESENT	0
184821	184592	80013X	PARTICIPANT	\N	EXCUSE	0
184822	184592	04061F	PARTICIPANT	\N	EXCUSE	0
184823	184592	11036J	PARTICIPANT	\N	PRESENT	0
184824	184592	11061K	PARTICIPANT	\N	EXCUSE	0
186453	186452	04070G	PARTICIPANT	\N	PRESENT	0
186454	186452	14263U	PARTICIPANT	\N	PRESENT	0
186455	186452	08039A	PARTICIPANT	\N	PRESENT	0
186456	186452	14179A	PARTICIPANT	\N	PRESENT	0
186633	186632	11026G	PARTICIPANT	\N	PRESENT	0
186634	186632	10015M	PARTICIPANT	\N	PRESENT	0
186733	186732	11039M	PARTICIPANT	\N	PRESENT	0
186734	186732	98042T	PARTICIPANT	\N	PRESENT	0
186735	186732	01019Q	PARTICIPANT	\N	PRESENT	0
187333	187332	01056V	PARTICIPANT	\N	PRESENT	0
187353	187352	98046X	PARTICIPANT	\N	PRESENT	0
187673	187672	14151M	PARTICIPANT	\N	PRESENT	0
187733	187732	14133K	PARTICIPANT	\N	PRESENT	0
187734	187732	04040A	PARTICIPANT	\N	PRESENT	0
187735	187732	08058D	PARTICIPANT	\N	PRESENT	0
187736	187732	04042C	PARTICIPANT	\N	PRESENT	0
187737	187732	98029W	PARTICIPANT	\N	PRESENT	0
187738	187732	11027H	PARTICIPANT	\N	PRESENT	0
187739	187732	98018T	PARTICIPANT	\N	PRESENT	0
187740	187732	92020L	PARTICIPANT	\N	PRESENT	0
187741	187732	95030B	PARTICIPANT	\N	PRESENT	0
187742	187732	04035D	PARTICIPANT	\N	PRESENT	0
187743	187732	14014Q	PARTICIPANT	\N	EXCUSE	0
187744	187732	07004J	PARTICIPANT	\N	EXCUSE	0
187745	187732	14211G	PARTICIPANT	\N	EXCUSE	0
187746	187732	11064N	PARTICIPANT	\N	PRESENT	0
187747	187732	95037J	PARTICIPANT	\N	PRESENT	0
187748	187732	04078Q	PARTICIPANT	\N	EXCUSE	0
187749	187732	14097Y	PARTICIPANT	\N	PRESENT	0
187750	187732	04036E	PARTICIPANT	\N	PRESENT	0
187751	187732	98005N	PARTICIPANT	\N	PRESENT	0
187752	187732	92031P	PARTICIPANT	\N	PRESENT	0
187753	187732	11106F	PARTICIPANT	\N	PRESENT	0
187754	187732	14251Q	PARTICIPANT	\N	PRESENT	0
187755	187732	08053X	PARTICIPANT	\N	PRESENT	0
187756	187732	11082Q	PARTICIPANT	\N	PRESENT	0
187757	187732	11105E	PARTICIPANT	\N	PRESENT	0
187758	187732	14253S	PARTICIPANT	\N	EXCUSE	0
187759	187732	08047A	PARTICIPANT	\N	PRESENT	0
187760	187732	14028W	PARTICIPANT	\N	EXCUSE	0
187761	187732	14193X	PARTICIPANT	\N	PRESENT	0
187762	187732	98021N	PARTICIPANT	\N	PRESENT	0
187763	187732	04080J	PARTICIPANT	\N	PRESENT	0
187764	187732	95059Q	PRESIDENT	0	PRESENT	0
187765	187732	86044G	PARTICIPANT	\N	PRESENT	0
187766	187732	01014K	PARTICIPANT	\N	PRESENT	0
187767	187732	11054L	PARTICIPANT	\N	PRESENT	0
187768	187732	01056V	PARTICIPANT	\N	PRESENT	0
187769	187732	08049C	PARTICIPANT	\N	PRESENT	0
188582	188570	08024S	PARTICIPANT	\N	PRESENT	0
188583	188570	14201E	PARTICIPANT	\N	EXCUSE	0
188644	188570	01031L	PARTICIPANT	\N	PRESENT	0
188645	188570	01016M	PARTICIPANT	\N	PRESENT	0
188646	188570	14085U	PARTICIPANT	\N	PRESENT	0
188587	188570	11091R	PARTICIPANT	\N	EXCUSE	0
188647	188570	04034C	PARTICIPANT	\N	PRESENT	0
188589	188570	98042T	PARTICIPANT	\N	EXCUSE	0
188590	188570	14249W	PARTICIPANT	\N	EXCUSE	0
188591	188570	01041N	PARTICIPANT	\N	EXCUSE	0
188592	188570	01025N	PARTICIPANT	\N	PRESENT	0
188648	188570	98053W	PARTICIPANT	\N	PRESENT	0
188649	188570	01048V	PARTICIPANT	\N	PRESENT	0
188595	188570	11089X	PARTICIPANT	\N	PRESENT	0
188650	188570	04086Q	PARTICIPANT	\N	PRESENT	0
188597	188570	14123H	PARTICIPANT	\N	PRESENT	0
188598	188570	14179A	PARTICIPANT	\N	PRESENT	0
188599	188570	04041B	PARTICIPANT	\N	EXCUSE	0
188600	188570	14241N	PARTICIPANT	\N	PRESENT	0
188601	188570	14061L	PARTICIPANT	\N	EXCUSE	0
188651	188570	01027Q	PARTICIPANT	\N	PRESENT	0
188603	188570	08031R	PARTICIPANT	\N	EXCUSE	0
188604	188570	12041X	PARTICIPANT	\N	PRESENT	0
188605	188570	08039A	PARTICIPANT	\N	PRESENT	0
188606	188570	08017T	PARTICIPANT	\N	EXCUSE	0
188607	188570	14059S	PARTICIPANT	\N	PRESENT	0
188608	188570	08012N	PARTICIPANT	\N	EXCUSE	0
188652	188570	08034U	PARTICIPANT	\N	PRESENT	0
188653	188570	08011M	PARTICIPANT	\N	PRESENT	0
190539	190538	11039M	PARTICIPANT	\N	PRESENT	0
188612	188570	04057K	PARTICIPANT	\N	PRESENT	0
188613	188570	11014C	PARTICIPANT	\N	EXCUSE	0
188614	188570	14109K	PARTICIPANT	\N	EXCUSE	0
188615	188570	04070G	PRESIDENT	0	PRESENT	0
190540	190538	08055A	PARTICIPANT	\N	PRESENT	0
190541	190538	11029K	PARTICIPANT	\N	PRESENT	0
188618	188570	83047W	PARTICIPANT	\N	PRESENT	0
188619	188570	14235Q	PARTICIPANT	\N	EXCUSE	0
190542	190538	04066L	PARTICIPANT	\N	PRESENT	0
190543	190538	04042C	PARTICIPANT	\N	PRESENT	0
190544	190538	08024S	PARTICIPANT	\N	PRESENT	0
190545	190538	04081K	PARTICIPANT	\N	PRESENT	0
188624	188570	14363X	PARTICIPANT	\N	PRESENT	0
188625	188570	11043H	PARTICIPANT	\N	EXCUSE	0
190546	190538	98042T	PARTICIPANT	\N	PRESENT	0
190550	190538	08048B	PARTICIPANT	\N	PRESENT	0
190548	190538	98053W	PARTICIPANT	\N	PRESENT	0
190549	190538	89029V	PARTICIPANT	\N	PRESENT	0
190551	190538	01007L	PARTICIPANT	\N	PRESENT	0
190552	190538	95037J	PARTICIPANT	\N	PRESENT	0
190553	190538	86034E	PARTICIPANT	\N	PRESENT	0
190554	190538	08039A	PARTICIPANT	\N	PRESENT	0
190555	190538	01043Q	PARTICIPANT	\N	PRESENT	0
190556	190538	11085T	PARTICIPANT	\N	PRESENT	0
190557	190538	04057K	PARTICIPANT	\N	PRESENT	0
190558	190538	92040Q	PARTICIPANT	\N	PRESENT	0
190559	190538	04088S	PARTICIPANT	\N	PRESENT	0
190560	190538	01019Q	PARTICIPANT	\N	PRESENT	0
190561	190538	04056J	PARTICIPANT	\N	PRESENT	0
190563	190562	89017R	PARTICIPANT	\N	PRESENT	0
190564	190562	08055A	PARTICIPANT	\N	PRESENT	0
190565	190562	11029K	PARTICIPANT	\N	PRESENT	0
190566	190562	04066L	PARTICIPANT	\N	PRESENT	0
190567	190562	04042C	PARTICIPANT	\N	PRESENT	0
190568	190562	08024S	PARTICIPANT	\N	PRESENT	0
190569	190562	04081K	PARTICIPANT	\N	PRESENT	0
190570	190562	98042T	PARTICIPANT	\N	PRESENT	0
190571	190562	11110B	PARTICIPANT	\N	PRESENT	0
190572	190562	98053W	PARTICIPANT	\N	PRESENT	0
190573	190562	08048B	PARTICIPANT	\N	PRESENT	0
190574	190562	95037J	PARTICIPANT	\N	PRESENT	0
190575	190562	86034E	PARTICIPANT	\N	PRESENT	0
190576	190562	04094Q	PARTICIPANT	\N	PRESENT	0
190577	190562	11085T	PARTICIPANT	\N	PRESENT	0
190578	190562	04057K	PARTICIPANT	\N	PRESENT	0
190579	190562	04088S	PARTICIPANT	\N	PRESENT	0
190580	190562	01019Q	PARTICIPANT	\N	PRESENT	0
190581	190562	04056J	PARTICIPANT	\N	PRESENT	0
190593	190592	01007L	PARTICIPANT	\N	PRESENT	0
190594	190592	11029K	PARTICIPANT	\N	PRESENT	0
190596	190595	89017R	PARTICIPANT	\N	PRESENT	0
190597	190595	01007L	PARTICIPANT	\N	PRESENT	0
190598	190595	11029K	PARTICIPANT	\N	PRESENT	0
190674	190673	92039X	PARTICIPANT	\N	PRESENT	0
190675	190673	98035U	PARTICIPANT	\N	PRESENT	0
190676	190673	14041T	PARTICIPANT	\N	PRESENT	0
190677	190673	04042C	PARTICIPANT	\N	PRESENT	0
190678	190673	86034E	PARTICIPANT	\N	PRESENT	0
190680	190679	08018U	PARTICIPANT	\N	PRESENT	0
190681	190679	98035U	PARTICIPANT	\N	PRESENT	0
190682	190679	14041T	PARTICIPANT	\N	PRESENT	0
190684	190683	98035U	PARTICIPANT	\N	PRESENT	0
190685	190683	92039X	PARTICIPANT	\N	PRESENT	0
190687	190686	92039X	PARTICIPANT	\N	PRESENT	0
190689	190688	98035U	PARTICIPANT	\N	PRESENT	0
190691	190690	98035U	PARTICIPANT	\N	PRESENT	0
190692	190690	04080J	PARTICIPANT	\N	PRESENT	0
190693	190690	14041T	PARTICIPANT	\N	PRESENT	0
190694	190690	04035D	PARTICIPANT	\N	PRESENT	0
192833	192832	01031L	PARTICIPANT	\N	PRESENT	0
195880	190780	01058X	PARTICIPANT	\N	PRESENT	0
195881	190780	11100Y	PARTICIPANT	\N	PRESENT	0
195882	190780	14197C	PARTICIPANT	\N	PRESENT	0
196053	193072	05008E	PARTICIPANT	\N	PRESENT	0
196054	193072	07034Q	PARTICIPANT	\N	PRESENT	0
196055	193072	07026Q	PARTICIPANT	\N	PRESENT	0
196056	193072	08017T	PARTICIPANT	\N	PRESENT	0
196057	193072	08043V	PARTICIPANT	\N	PRESENT	0
196058	193072	11067R	PARTICIPANT	\N	PRESENT	0
196059	193072	11037K	PARTICIPANT	\N	PRESENT	0
196060	193072	14269B	PARTICIPANT	\N	PRESENT	0
196061	193072	14001X	PARTICIPANT	\N	PRESENT	0
196062	193072	04056J	PARTICIPANT	\N	PRESENT	0
196063	193072	11029K	PARTICIPANT	\N	PRESENT	0
196064	193072	04038G	PARTICIPANT	\N	PRESENT	0
196065	193072	04085P	PARTICIPANT	\N	PRESENT	0
196066	193072	14215L	PARTICIPANT	\N	PRESENT	0
196067	193072	11099A	PARTICIPANT	\N	PRESENT	0
196068	193072	11014C	PARTICIPANT	\N	PRESENT	0
196069	193072	14207L	PARTICIPANT	\N	PRESENT	0
196070	193072	14193X	PARTICIPANT	\N	PRESENT	0
196071	193072	14059S	PARTICIPANT	\N	PRESENT	0
196072	193072	14069U	PARTICIPANT	\N	PRESENT	0
196073	193072	90003B	PARTICIPANT	\N	PRESENT	0
196074	193072	95062K	PARTICIPANT	\N	PRESENT	0
196075	193072	14211G	PARTICIPANT	\N	PRESENT	0
196076	193072	14191V	PARTICIPANT	\N	PRESENT	0
196077	193072	14157T	PARTICIPANT	\N	PRESENT	0
196078	193072	04033B	PARTICIPANT	\N	PRESENT	0
196079	193072	14105F	PARTICIPANT	\N	PRESENT	0
196080	193072	14199E	PARTICIPANT	\N	PRESENT	0
196081	193072	08019V	PARTICIPANT	\N	PRESENT	0
196082	193072	08060W	PARTICIPANT	\N	PRESENT	0
196083	193072	01028R	PARTICIPANT	\N	PRESENT	0
196084	193072	19251M	PARTICIPANT	\N	PRESENT	0
196085	193072	14147R	PARTICIPANT	\N	PRESENT	0
196086	193072	04057K	PARTICIPANT	\N	PRESENT	0
196087	193072	04045F	PARTICIPANT	\N	PRESENT	0
196088	193072	14257W	PARTICIPANT	\N	PRESENT	0
196089	193072	11031D	PARTICIPANT	\N	PRESENT	0
196090	193072	11098Y	PARTICIPANT	\N	PRESENT	0
196091	193072	01027Q	PARTICIPANT	\N	PRESENT	0
196092	193072	11048N	PARTICIPANT	\N	PRESENT	0
196093	193072	95030B	PARTICIPANT	\N	PRESENT	0
196094	193072	12042Y	PARTICIPANT	\N	PRESENT	0
196095	193072	11061K	PARTICIPANT	\N	PRESENT	0
196096	193072	04088S	PARTICIPANT	\N	PRESENT	0
196097	193072	92045V	PARTICIPANT	\N	PRESENT	0
196098	193072	10006L	PARTICIPANT	\N	PRESENT	0
196099	193072	04067M	PARTICIPANT	\N	PRESENT	0
196100	193072	08053X	PARTICIPANT	\N	PRESENT	0
196112	193072	14229S	PARTICIPANT	\N	PRESENT	0
196113	193072	08024S	PARTICIPANT	\N	PRESENT	0
196114	193072	11109J	PARTICIPANT	\N	PRESENT	0
196115	193072	14271U	PARTICIPANT	\N	PRESENT	0
196116	193072	14281W	PARTICIPANT	\N	PRESENT	0
196117	193072	14261S	PARTICIPANT	\N	PRESENT	0
196118	193072	14087W	PARTICIPANT	\N	PRESENT	0
196119	193072	11077T	PARTICIPANT	\N	PRESENT	0
196120	193072	14133K	PARTICIPANT	\N	PRESENT	0
196121	193072	08015R	PARTICIPANT	\N	PRESENT	0
196122	193072	14213J	PARTICIPANT	\N	PRESENT	0
196123	193072	14357A	PARTICIPANT	\N	PRESENT	0
196124	193072	11097X	PARTICIPANT	\N	PRESENT	0
196125	193072	14265W	PARTICIPANT	\N	PRESENT	0
196126	193072	01008M	PARTICIPANT	\N	PRESENT	0
196127	193072	14135M	PARTICIPANT	\N	PRESENT	0
196128	193072	11036J	PARTICIPANT	\N	PRESENT	0
196129	193072	08062Y	PARTICIPANT	\N	PRESENT	0
196130	193072	08028W	PARTICIPANT	\N	PRESENT	0
196131	193072	95067Q	PARTICIPANT	\N	PRESENT	0
196132	193072	14217N	PARTICIPANT	\N	PRESENT	0
196133	193072	80013X	PARTICIPANT	\N	PRESENT	0
196134	193072	11026G	PARTICIPANT	\N	PRESENT	0
196135	193072	01025N	PARTICIPANT	\N	PRESENT	0
196136	193072	14119M	PARTICIPANT	\N	PRESENT	0
196137	193072	08009T	PARTICIPANT	\N	PRESENT	0
196138	193072	08014Q	PARTICIPANT	\N	PRESENT	0
196139	193072	14327T	PARTICIPANT	\N	PRESENT	0
196140	193072	01016M	PARTICIPANT	\N	PRESENT	0
196141	193072	11112D	PARTICIPANT	\N	PRESENT	0
196142	193072	04049K	PARTICIPANT	\N	PRESENT	0
196152	193072	02002K	PARTICIPANT	\N	PRESENT	0
196153	193072	14079W	PARTICIPANT	\N	PRESENT	0
196154	193072	14042U	PARTICIPANT	\N	PRESENT	0
196155	193072	14159V	PARTICIPANT	\N	PRESENT	0
196156	193072	14053L	PARTICIPANT	\N	PRESENT	0
196157	193072	08061X	PARTICIPANT	\N	PRESENT	0
196158	193072	95049N	PARTICIPANT	\N	PRESENT	0
196159	193072	08039A	PARTICIPANT	\N	PRESENT	0
196160	193072	98053W	PARTICIPANT	\N	PRESENT	0
196161	193072	14107H	PARTICIPANT	\N	PRESENT	0
196172	193072	14038Y	PARTICIPANT	\N	PRESENT	0
196173	193072	01034P	PARTICIPANT	\N	PRESENT	0
196174	193072	18127E	PARTICIPANT	\N	PRESENT	0
196175	193072	11105E	PARTICIPANT	\N	PRESENT	0
196176	193072	08031R	PARTICIPANT	\N	PRESENT	0
196177	193072	14235Q	PARTICIPANT	\N	PRESENT	0
196178	193072	11012A	PARTICIPANT	\N	PRESENT	0
196179	193072	14030Q	PARTICIPANT	\N	PRESENT	0
196180	193072	14097Y	PARTICIPANT	\N	PRESENT	0
196181	193072	14179A	PARTICIPANT	\N	PRESENT	0
196182	193072	14231L	PARTICIPANT	\N	PRESENT	0
196183	193072	14219Q	PARTICIPANT	\N	PRESENT	0
196184	193072	95063L	PARTICIPANT	\N	PRESENT	0
196185	193072	04040A	PARTICIPANT	\N	PRESENT	0
196186	193072	14187A	PARTICIPANT	\N	PRESENT	0
196187	193072	14083S	PARTICIPANT	\N	PRESENT	0
196192	193072	14031R	PARTICIPANT	\N	PRESENT	0
196193	193072	07029T	PARTICIPANT	\N	PRESENT	0
196194	193072	14197C	PARTICIPANT	\N	PRESENT	0
196195	193072	98023Q	PARTICIPANT	\N	PRESENT	0
196196	193072	14089Y	PARTICIPANT	\N	PRESENT	0
196197	193072	04071H	PARTICIPANT	\N	PRESENT	0
196198	193072	14034U	PARTICIPANT	\N	PRESENT	0
196212	193072	14255U	PARTICIPANT	\N	PRESENT	0
196213	193072	01043Q	PARTICIPANT	\N	PRESENT	0
196214	193072	98042T	PARTICIPANT	\N	PRESENT	0
196232	193072	89017R	PARTICIPANT	\N	PRESENT	0
196233	193072	14033T	PARTICIPANT	\N	PRESENT	0
196252	193072	01031L	PARTICIPANT	\N	PRESENT	0
196392	196293	01043Q	PARTICIPANT	\N	PRESENT	0
196393	196293	14357A	PARTICIPANT	\N	PRESENT	0
196394	196293	11100Y	PRESIDENT	0	PRESENT	0
196395	196293	08038Y	PARTICIPANT	\N	PRESENT	0
196396	196293	11098Y	PARTICIPANT	\N	PRESENT	0
196397	196293	14081Q	PARTICIPANT	\N	PRESENT	0
196007	193212	04070G	PRESIDENT	0	PRESENT	0
196008	193212	95015C	PARTICIPANT	\N	PRESENT	0
196009	193212	14361V	PARTICIPANT	\N	PRESENT	0
196010	193212	14079W	PARTICIPANT	\N	PRESENT	0
196011	193212	11029K	PARTICIPANT	\N	PRESENT	0
196012	193212	14229S	PARTICIPANT	\N	PRESENT	0
196013	193212	11089X	PARTICIPANT	\N	PRESENT	0
196014	193212	83047W	PARTICIPANT	\N	PRESENT	0
196015	193212	08017T	PARTICIPANT	\N	PRESENT	0
196016	193212	14179A	PARTICIPANT	\N	PRESENT	0
196017	193212	08012N	PARTICIPANT	\N	PRESENT	0
196018	193212	08039A	PARTICIPANT	\N	PRESENT	0
196019	193212	07026Q	PARTICIPANT	\N	PRESENT	0
196020	193212	14059S	PARTICIPANT	\N	PRESENT	0
196021	193212	14061L	PARTICIPANT	\N	PRESENT	0
196022	193212	14235Q	PARTICIPANT	\N	PRESENT	0
196023	193212	08043V	PARTICIPANT	\N	PRESENT	0
196024	193212	87003B	PARTICIPANT	\N	PRESENT	0
196025	193212	18127E	PARTICIPANT	\N	PRESENT	0
196026	193212	14191V	PARTICIPANT	\N	PRESENT	0
196027	193212	98042T	PARTICIPANT	\N	PRESENT	0
196028	193212	14089Y	PARTICIPANT	\N	PRESENT	0
196029	193212	14105F	PARTICIPANT	\N	PRESENT	0
196030	193212	04059M	PARTICIPANT	\N	PRESENT	0
196031	193212	14109K	PARTICIPANT	\N	PRESENT	0
195877	190780	01024M	PARTICIPANT	\N	PRESENT	0
195878	190780	14213J	PARTICIPANT	\N	PRESENT	0
196032	193212	14063N	PARTICIPANT	\N	PRESENT	0
196033	193212	14123H	PARTICIPANT	\N	PRESENT	0
196034	193212	11104D	PARTICIPANT	\N	PRESENT	0
196035	193212	04057K	PARTICIPANT	\N	EXCUSE	0
196036	193212	92015P	PARTICIPANT	\N	EXCUSE	0
196037	193212	08024S	PARTICIPANT	\N	EXCUSE	0
196052	193072	08055A	PARTICIPANT	\N	PRESENT	0
196398	196293	14033T	PARTICIPANT	\N	PRESENT	0
196399	196293	11066Q	PARTICIPANT	\N	PRESENT	0
196400	196293	80013X	PARTICIPANT	\N	PRESENT	0
196401	196293	01008M	PARTICIPANT	\N	PRESENT	0
196402	196293	90003B	PARTICIPANT	\N	PRESENT	0
196403	196293	14205J	PARTICIPANT	\N	PRESENT	0
196404	196293	04088S	PARTICIPANT	\N	PRESENT	0
196405	196293	11094U	PARTICIPANT	\N	PRESENT	0
166133	166132	14089Y	PARTICIPANT	\N	PRESENT	0
166134	166132	11029K	PARTICIPANT	\N	PRESENT	0
166135	166132	14207L	PRESIDENT	0	PRESENT	0
170094	170036	14239U	PARTICIPANT	\N	PRESENT	0
166137	166132	14053L	PARTICIPANT	\N	PRESENT	0
166138	166132	14215L	PARTICIPANT	\N	PRESENT	0
166139	166132	14281W	PARTICIPANT	\N	PRESENT	0
166140	166132	14087W	PARTICIPANT	\N	EXCUSE	0
166144	166132	11014C	PARTICIPANT	\N	PRESENT	0
166142	166132	14231L	PARTICIPANT	\N	PRESENT	0
166143	166132	14031R	PARTICIPANT	\N	PRESENT	0
166145	166132	14237S	PARTICIPANT	\N	PRESENT	0
166146	166132	14135M	PARTICIPANT	\N	PRESENT	0
166147	166132	14229S	PARTICIPANT	\N	PRESENT	0
166148	166132	04050C	PARTICIPANT	\N	PRESENT	0
166149	166132	14249W	PARTICIPANT	\N	EXCUSE	0
166150	166132	04057K	PARTICIPANT	\N	EXCUSE	0
170152	170036	04092N	PRESIDENT	0	PRESENT	0
173274	157438	14259Y	PARTICIPANT	\N	PRESENT	0
170040	170036	08043V	PARTICIPANT	\N	PRESENT	0
171940	171870	14329V	PARTICIPANT	\N	PRESENT	0
173275	157438	01027Q	PARTICIPANT	\N	PRESENT	0
170043	170036	11031D	PARTICIPANT	\N	PRESENT	0
173276	157438	01022K	PARTICIPANT	\N	PRESENT	0
173277	157438	04094Q	PARTICIPANT	\N	PRESENT	0
173278	157438	14059S	PARTICIPANT	\N	PRESENT	0
173279	157438	08019V	PRESIDENT	0	PRESENT	0
173292	157438	11025F	PARTICIPANT	\N	PRESENT	0
170049	170036	14213J	PARTICIPANT	\N	PRESENT	0
173992	169094	14063N	PARTICIPANT	\N	PRESENT	0
173993	169094	95067Q	PARTICIPANT	\N	PRESENT	0
173994	169094	04086Q	PARTICIPANT	\N	PRESENT	0
173995	169094	14231L	PARTICIPANT	\N	PRESENT	0
173996	169094	05012A	PARTICIPANT	\N	PRESENT	0
170055	170036	14265W	PARTICIPANT	\N	PRESENT	0
170056	170036	14028W	PARTICIPANT	\N	PRESENT	0
170057	170036	14235Q	PARTICIPANT	\N	EXCUSE	0
170058	170036	14331P	PARTICIPANT	\N	EXCUSE	0
170059	170036	14271U	PARTICIPANT	\N	PRESENT	0
170060	170036	11097X	PARTICIPANT	\N	PRESENT	0
173272	157438	11023D	PARTICIPANT	\N	PRESENT	0
170062	170036	11094U	PARTICIPANT	\N	PRESENT	0
173998	169094	11049P	PARTICIPANT	\N	PRESENT	0
175852	174510	01060R	PARTICIPANT	\N	PRESENT	0
175853	174510	11026G	PARTICIPANT	\N	PRESENT	0
175854	174510	04085P	PARTICIPANT	\N	PRESENT	0
175855	174510	08018U	PARTICIPANT	\N	PRESENT	0
176093	174510	08051V	PARTICIPANT	\N	PRESENT	0
171959	171870	14079W	PARTICIPANT	\N	PRESENT	0
176095	174533	11035H	PARTICIPANT	\N	PRESENT	0
176096	174533	11037K	PARTICIPANT	\N	PRESENT	0
176097	174533	14147R	PARTICIPANT	\N	PRESENT	0
176098	174533	01024M	PARTICIPANT	\N	PRESENT	0
176099	174533	04044E	PARTICIPANT	\N	PRESENT	0
176292	167306	08024S	PARTICIPANT	\N	PRESENT	0
176297	167306	11025F	PARTICIPANT	\N	PRESENT	0
176102	174533	11113E	PARTICIPANT	\N	PRESENT	0
176103	174533	01028R	PARTICIPANT	\N	PRESENT	0
176106	174510	08044W	PARTICIPANT	\N	EXCUSE	0
176107	174533	07034Q	PARTICIPANT	\N	PRESENT	0
176108	174533	11026G	PARTICIPANT	\N	PRESENT	0
176109	174533	01007L	PARTICIPANT	\N	PRESENT	0
176110	174533	11033F	PARTICIPANT	\N	PRESENT	0
176111	174533	05008E	PRESIDENT	0	PRESENT	0
176112	174533	04085P	PARTICIPANT	\N	PRESENT	0
176113	174533	95063L	PARTICIPANT	\N	PRESENT	0
176114	174533	14041T	PARTICIPANT	\N	PRESENT	0
176115	174533	95049N	PARTICIPANT	\N	PRESENT	0
176293	167306	14033T	PARTICIPANT	\N	PRESENT	0
176298	167306	14107H	PARTICIPANT	\N	PRESENT	0
176299	167306	11100Y	PARTICIPANT	\N	PRESENT	0
176300	167306	04089T	PARTICIPANT	\N	PRESENT	0
176321	167306	14063N	PARTICIPANT	\N	PRESENT	0
176322	167306	11098Y	PARTICIPANT	\N	PRESENT	0
176324	167306	11014C	PARTICIPANT	\N	PRESENT	0
176327	167306	14257W	PARTICIPANT	\N	PRESENT	0
171987	171870	11091R	PARTICIPANT	\N	EXCUSE	0
173273	157438	11114F	PARTICIPANT	\N	PRESENT	0
176329	167306	14207L	PARTICIPANT	\N	PRESENT	0
176330	167306	08055A	PARTICIPANT	\N	PRESENT	0
176331	167306	04059M	PARTICIPANT	\N	PRESENT	0
176332	167306	11107G	PARTICIPANT	\N	PRESENT	0
176333	167306	14059S	PARTICIPANT	\N	PRESENT	0
171994	171870	01041N	PARTICIPANT	\N	PRESENT	0
176334	167306	14119M	PARTICIPANT	\N	PRESENT	0
176335	167306	14357A	PARTICIPANT	\N	PRESENT	0
176336	167306	04088S	PARTICIPANT	\N	PRESENT	0
176337	167306	04081K	PARTICIPANT	\N	PRESENT	0
176338	167306	14263U	PARTICIPANT	\N	PRESENT	0
176339	167306	14281W	PARTICIPANT	\N	PRESENT	0
176352	167306	11103C	PARTICIPANT	\N	PRESENT	0
176353	167306	14363X	PARTICIPANT	\N	PRESENT	0
176354	167306	14105F	PARTICIPANT	\N	PRESENT	0
176355	167306	11081P	PARTICIPANT	\N	PRESENT	0
176356	167306	14197C	PARTICIPANT	\N	PRESENT	0
176357	167306	14237S	PARTICIPANT	\N	PRESENT	0
176358	167306	14069U	PARTICIPANT	\N	PRESENT	0
176359	167306	08017T	PARTICIPANT	\N	PRESENT	0
176360	167306	14235Q	PARTICIPANT	\N	PRESENT	0
176361	167306	14361V	PARTICIPANT	\N	PRESENT	0
176362	167306	14133K	PARTICIPANT	\N	PRESENT	0
176363	167306	08047A	PARTICIPANT	\N	PRESENT	0
176364	167306	98050T	PARTICIPANT	\N	PRESENT	0
176365	167306	95015C	PARTICIPANT	\N	PRESENT	0
176424	167306	14103D	PARTICIPANT	\N	PRESENT	0
176425	167306	95062K	PARTICIPANT	\N	PRESENT	0
176426	167306	08016S	PARTICIPANT	\N	PRESENT	0
176427	167306	14205J	PARTICIPANT	\N	PRESENT	0
176428	167306	14199E	PARTICIPANT	\N	PRESENT	0
176429	167306	14269B	PARTICIPANT	\N	PRESENT	0
176430	167306	11042G	PARTICIPANT	\N	PRESENT	0
176431	167306	14041T	PARTICIPANT	\N	PRESENT	0
172023	171870	08035V	PARTICIPANT	\N	PRESENT	0
176432	167306	14109K	PARTICIPANT	\N	PRESENT	0
176433	167306	14061L	PARTICIPANT	\N	PRESENT	0
176434	167306	14037X	PARTICIPANT	\N	PRESENT	0
176452	167306	01022K	PARTICIPANT	\N	PRESENT	0
176453	167306	14267Y	PARTICIPANT	\N	PRESENT	0
176472	167306	14225N	PARTICIPANT	\N	PRESENT	0
172030	171870	07026Q	PARTICIPANT	\N	PRESENT	0
176492	167306	01058X	PARTICIPANT	\N	PRESENT	0
176493	167306	14071N	PARTICIPANT	\N	PRESENT	0
176494	167306	97011G	PARTICIPANT	\N	PRESENT	0
176495	167306	14327T	PARTICIPANT	\N	PRESENT	0
176496	167306	13002U	PARTICIPANT	\N	PRESENT	0
176497	167306	14223L	PARTICIPANT	\N	PRESENT	0
176498	167306	14081Q	PARTICIPANT	\N	PRESENT	0
176499	167306	14265W	PARTICIPANT	\N	PRESENT	0
176512	167306	08019V	PARTICIPANT	\N	PRESENT	0
176514	167306	11043H	PARTICIPANT	\N	PRESENT	0
176515	167306	80013X	PARTICIPANT	\N	PRESENT	0
176516	167306	04049K	PARTICIPANT	\N	PRESENT	0
176517	167306	87003B	PARTICIPANT	\N	PRESENT	0
176518	167306	14013P	PARTICIPANT	\N	PRESENT	0
176524	167306	95030B	PARTICIPANT	\N	PRESENT	0
176525	167306	11036J	PARTICIPANT	\N	PRESENT	0
172047	171870	14179A	PARTICIPANT	\N	PRESENT	0
176592	167306	14217N	PARTICIPANT	\N	PRESENT	0
176593	167306	04067M	PARTICIPANT	\N	PRESENT	0
176594	176296	08024S	PARTICIPANT	\N	PRESENT	0
176595	176296	14033T	PARTICIPANT	\N	PRESENT	0
176596	176296	11025F	PARTICIPANT	\N	PRESENT	0
176597	176296	14107H	PARTICIPANT	\N	PRESENT	0
176598	176296	11100Y	PARTICIPANT	\N	PRESENT	0
176600	176296	14063N	PARTICIPANT	\N	PRESENT	0
176601	176296	11098Y	PARTICIPANT	\N	PRESENT	0
176602	176296	14257W	PARTICIPANT	\N	PRESENT	0
172060	171870	14241N	PARTICIPANT	\N	PRESENT	0
176606	176296	14357A	PARTICIPANT	\N	PRESENT	0
176609	176296	14263U	PARTICIPANT	\N	PRESENT	0
176610	176296	11103C	PARTICIPANT	\N	PRESENT	0
176612	176296	14105F	PARTICIPANT	\N	PRESENT	0
176613	176296	14197C	PARTICIPANT	\N	PRESENT	0
176614	176296	14237S	PARTICIPANT	\N	PRESENT	0
172072	171870	08031R	PARTICIPANT	\N	PRESENT	0
176615	176296	14069U	PARTICIPANT	\N	PRESENT	0
176616	176296	14235Q	PARTICIPANT	\N	PRESENT	0
176617	176296	14361V	PARTICIPANT	\N	PRESENT	0
176618	176296	14133K	PARTICIPANT	\N	PRESENT	0
176619	176296	08047A	PARTICIPANT	\N	PRESENT	0
176620	176296	98050T	PARTICIPANT	\N	PRESENT	0
192124	190533	98053W	PARTICIPANT	\N	EXCUSE	0
192126	190772	14053L	PARTICIPANT	\N	PRESENT	0
192127	190772	11091R	PARTICIPANT	\N	PRESENT	0
192128	190772	08065C	PARTICIPANT	\N	PRESENT	0
192129	190772	14355X	PARTICIPANT	\N	PRESENT	0
192130	190772	14213J	PARTICIPANT	\N	PRESENT	0
192133	190772	08062Y	PARTICIPANT	\N	PRESENT	0
192135	190772	14265W	PARTICIPANT	\N	PRESENT	0
192140	190772	14193X	PARTICIPANT	\N	PRESENT	0
192143	190772	98050T	PARTICIPANT	\N	PRESENT	0
192145	190772	11097X	PARTICIPANT	\N	PRESENT	0
192146	190772	14199E	PARTICIPANT	\N	PRESENT	0
192165	192164	11043H	PARTICIPANT	\N	PRESENT	0
192166	192164	88008L	PARTICIPANT	\N	PRESENT	0
192167	192164	11039M	PARTICIPANT	\N	PRESENT	0
192168	192164	14073Q	PARTICIPANT	\N	PRESENT	0
192169	192164	08012N	PARTICIPANT	\N	PRESENT	0
192170	192164	11014C	PARTICIPANT	\N	PRESENT	0
192171	192164	19251M	PARTICIPANT	\N	PRESENT	0
192173	192172	95049N	PARTICIPANT	\N	PRESENT	0
192174	192172	14065Q	PARTICIPANT	\N	PRESENT	0
192175	192172	19253P	PARTICIPANT	\N	PRESENT	0
192176	192019	04086Q	PARTICIPANT	\N	PRESENT	0
192177	192019	11088W	PARTICIPANT	\N	PRESENT	0
192178	192019	01027Q	PARTICIPANT	\N	PRESENT	0
192179	192019	01057W	PARTICIPANT	\N	PRESENT	0
192180	192019	08069G	PARTICIPANT	\N	PRESENT	0
192181	192019	11048N	PARTICIPANT	\N	PRESENT	0
192182	192019	99004R	PARTICIPANT	\N	PRESENT	0
192183	192019	04061F	PARTICIPANT	\N	PRESENT	0
192184	192019	07029T	PARTICIPANT	\N	PRESENT	0
192185	192019	08010L	PARTICIPANT	\N	PRESENT	0
192186	192019	08011M	PARTICIPANT	\N	PRESENT	0
192187	192019	14253S	PARTICIPANT	\N	PRESENT	0
192188	192019	14083S	PARTICIPANT	\N	PRESENT	0
192189	192019	11053K	PARTICIPANT	\N	PRESENT	0
192190	192019	11070L	PARTICIPANT	\N	PRESENT	0
192191	192019	14327T	PARTICIPANT	\N	PRESENT	0
192192	192019	14277B	PARTICIPANT	\N	PRESENT	0
192193	192019	01031L	PARTICIPANT	\N	PRESENT	0
192194	192019	08014Q	PARTICIPANT	\N	PRESENT	0
192195	192019	14085U	PARTICIPANT	\N	PRESENT	0
192196	192019	11042G	PARTICIPANT	\N	PRESENT	0
192197	192019	08016S	PARTICIPANT	\N	PRESENT	0
192198	192019	14159V	PARTICIPANT	\N	PRESENT	0
192199	192019	98046X	PARTICIPANT	\N	PRESENT	0
192200	192019	14225N	PARTICIPANT	\N	PRESENT	0
192201	192019	11083R	PARTICIPANT	\N	PRESENT	0
192202	192019	08073C	PARTICIPANT	\N	PRESENT	0
192203	192019	08061X	PARTICIPANT	\N	PRESENT	0
192204	192019	11057P	PARTICIPANT	\N	PRESENT	0
192205	192019	04034C	PARTICIPANT	\N	PRESENT	0
192206	192019	88008L	PARTICIPANT	\N	PRESENT	0
192207	192019	11012A	PARTICIPANT	\N	PRESENT	0
192208	190772	92045V	PARTICIPANT	\N	PRESENT	0
192209	190772	14123H	PARTICIPANT	\N	PRESENT	0
192210	192019	95035G	PARTICIPANT	\N	PRESENT	0
192211	192019	92045V	PARTICIPANT	\N	PRESENT	0
192212	192019	96004D	PARTICIPANT	\N	PRESENT	0
192213	190772	01043Q	PARTICIPANT	\N	PRESENT	0
192232	190772	04038G	PARTICIPANT	\N	PRESENT	0
192233	190772	11110B	PARTICIPANT	\N	PRESENT	0
192234	190772	01016M	PARTICIPANT	\N	PRESENT	0
192235	190772	08024S	PARTICIPANT	\N	PRESENT	0
192236	190412	01027Q	PARTICIPANT	\N	EXCUSE	0
192237	190772	11026G	PARTICIPANT	\N	PRESENT	0
192252	190613	83042R	PARTICIPANT	\N	PRESENT	0
192253	190613	95059Q	PRESIDENT	0	PRESENT	0
192254	190613	08058D	PARTICIPANT	\N	PRESENT	0
192255	190613	14028W	PARTICIPANT	\N	PRESENT	0
192256	190613	08047A	PARTICIPANT	\N	PRESENT	0
192257	190613	04036E	PARTICIPANT	\N	PRESENT	0
192271	192270	05008E	PARTICIPANT	\N	PRESENT	0
192272	192270	14259Y	PARTICIPANT	\N	PRESENT	0
192275	190613	14251Q	PARTICIPANT	\N	PRESENT	0
192292	190513	04044E	PARTICIPANT	\N	PRESENT	0
192293	190513	11113E	PARTICIPANT	\N	PRESENT	0
192294	190513	04047H	PARTICIPANT	\N	PRESENT	0
192295	190513	14229S	PARTICIPANT	\N	PRESENT	0
192296	190513	05008E	PRESIDENT	0	PRESENT	0
192297	190513	92031P	PARTICIPANT	\N	PRESENT	0
192298	190513	14271U	PARTICIPANT	\N	PRESENT	0
192299	190513	08017T	PARTICIPANT	\N	PRESENT	0
192300	190513	14147R	PARTICIPANT	\N	PRESENT	0
192301	190513	14179A	PARTICIPANT	\N	PRESENT	0
192302	190513	14215L	PARTICIPANT	\N	PRESENT	0
192303	190513	11072N	PARTICIPANT	\N	PRESENT	0
192304	190513	14065Q	PARTICIPANT	\N	PRESENT	0
192305	190513	95067Q	PARTICIPANT	\N	PRESENT	0
192306	190513	11026G	PARTICIPANT	\N	PRESENT	0
192307	190513	08058D	PARTICIPANT	\N	PRESENT	0
192308	190513	01024M	PARTICIPANT	\N	PRESENT	0
192309	190513	19251M	PARTICIPANT	\N	PRESENT	0
192310	190513	08043V	PARTICIPANT	\N	PRESENT	0
192311	190513	04038G	PARTICIPANT	\N	PRESENT	0
192312	190513	95063L	PARTICIPANT	\N	PRESENT	0
192313	190513	04056J	PARTICIPANT	\N	PRESENT	0
192314	190513	08044W	PARTICIPANT	\N	PRESENT	0
192315	190513	14109K	PARTICIPANT	\N	PRESENT	0
192316	190513	14209N	PARTICIPANT	\N	PRESENT	0
192317	190513	95049N	PARTICIPANT	\N	PRESENT	0
192318	190513	04045F	PARTICIPANT	\N	PRESENT	0
192319	190513	08025T	PARTICIPANT	\N	EXCUSE	0
192346	190774	04066L	PARTICIPANT	\N	PRESENT	0
192347	190774	14215L	PARTICIPANT	\N	PRESENT	0
192348	190774	11070L	PARTICIPANT	\N	PRESENT	0
192349	190774	01031L	PARTICIPANT	\N	PRESENT	0
192350	190774	11072N	PARTICIPANT	\N	PRESENT	0
192351	190774	98053W	PARTICIPANT	\N	PRESENT	0
192352	190774	04038G	PARTICIPANT	\N	PRESENT	0
192373	190774	04044E	PARTICIPANT	\N	PRESENT	0
192374	190774	11067R	PARTICIPANT	\N	PRESENT	0
192375	190774	14063N	PARTICIPANT	\N	PRESENT	0
192376	190774	14231L	PARTICIPANT	\N	PRESENT	0
192377	190774	95062K	PARTICIPANT	\N	PRESENT	0
192378	190774	08039A	PARTICIPANT	\N	PRESENT	0
192379	190774	14105F	PARTICIPANT	\N	PRESENT	0
192380	190774	14357A	PARTICIPANT	\N	PRESENT	0
192381	190774	04088S	PARTICIPANT	\N	PRESENT	0
192382	190774	14041T	PARTICIPANT	\N	PRESENT	0
192384	190774	14157T	PARTICIPANT	\N	PRESENT	0
192388	190774	11012A	PARTICIPANT	\N	PRESENT	0
192391	190774	01046T	PARTICIPANT	\N	PRESENT	0
192392	190774	14033T	PARTICIPANT	\N	PRESENT	0
192393	190774	14265W	PARTICIPANT	\N	PRESENT	0
192394	190774	14069U	PARTICIPANT	\N	PRESENT	0
192395	190774	14038Y	PARTICIPANT	\N	PRESENT	0
192412	190774	01022K	PARTICIPANT	\N	PRESENT	0
192413	190774	11109J	PARTICIPANT	\N	PRESENT	0
192414	190774	11113E	PARTICIPANT	\N	PRESENT	0
192415	190774	19253P	PARTICIPANT	\N	PRESENT	0
192416	190774	11091R	PARTICIPANT	\N	PRESENT	0
192513	190775	95062K	PARTICIPANT	\N	PRESENT	0
192514	190775	14105F	PARTICIPANT	\N	PRESENT	0
192517	190775	14107H	PARTICIPANT	\N	PRESENT	0
192518	190775	00003C	PARTICIPANT	\N	PRESENT	0
192519	190775	80013X	PARTICIPANT	\N	PRESENT	0
192520	190775	01060R	PARTICIPANT	\N	PRESENT	0
192521	190775	99004R	PARTICIPANT	\N	PRESENT	0
192522	190775	11091R	PARTICIPANT	\N	PRESENT	0
192523	190775	14033T	PARTICIPANT	\N	PRESENT	0
192524	190775	14079W	PARTICIPANT	\N	PRESENT	0
192525	190775	14061L	PARTICIPANT	\N	PRESENT	0
192526	190775	14059S	PARTICIPANT	\N	PRESENT	0
192527	190775	10006L	PARTICIPANT	\N	PRESENT	0
192528	190775	04088S	PARTICIPANT	\N	PRESENT	0
192529	190775	14041T	PARTICIPANT	\N	PRESENT	0
192530	190775	14199E	PARTICIPANT	\N	PRESENT	0
192531	190775	98018T	PARTICIPANT	\N	PRESENT	0
192532	190775	11097X	PARTICIPANT	\N	PRESENT	0
192533	190775	05012A	PARTICIPANT	\N	PRESENT	0
192534	190775	14357A	PARTICIPANT	\N	PRESENT	0
192535	190775	14253S	PARTICIPANT	\N	PRESENT	0
192536	190775	14259Y	PARTICIPANT	\N	PRESENT	0
192537	190775	14123H	PARTICIPANT	\N	PRESENT	0
192538	190775	14119M	PARTICIPANT	\N	PRESENT	0
192539	190775	04081K	PARTICIPANT	\N	PRESENT	0
192540	190775	11010L	PARTICIPANT	\N	PRESENT	0
192541	190775	10015M	PARTICIPANT	\N	PRESENT	0
192542	190775	95059Q	PARTICIPANT	\N	PRESENT	0
192543	190775	04036E	PARTICIPANT	\N	PRESENT	0
192475	192474	14259Y	PARTICIPANT	\N	PRESENT	0
192512	190775	86034E	PARTICIPANT	\N	PRESENT	0
192544	190775	14071N	PARTICIPANT	\N	PRESENT	0
192545	190775	14193X	PARTICIPANT	\N	PRESENT	0
192546	190775	16813M	PARTICIPANT	\N	PRESENT	0
192547	190775	77002U	PARTICIPANT	\N	PRESENT	0
192548	190775	04086Q	PARTICIPANT	\N	PRESENT	0
192549	190775	04033B	PARTICIPANT	\N	PRESENT	0
174793	174792	05008E	PRESIDENT	0	PRESENT	0
174794	174792	04047H	PARTICIPANT	\N	PRESENT	0
177852	167337	89029V	PARTICIPANT	\N	PRESENT	0
174796	174792	14041T	PARTICIPANT	\N	PRESENT	0
177872	167337	14169X	PARTICIPANT	\N	PRESENT	0
174798	174792	11084S	PARTICIPANT	\N	PRESENT	0
177873	167337	11053K	PARTICIPANT	\N	PRESENT	0
177874	167337	14239U	PARTICIPANT	\N	PRESENT	0
174801	174792	07034Q	PARTICIPANT	\N	PRESENT	0
174802	174792	04074L	PARTICIPANT	\N	PRESENT	0
177875	167337	80013X	PARTICIPANT	\N	PRESENT	0
174804	174792	14275Y	PARTICIPANT	\N	PRESENT	0
174805	174792	11037K	PARTICIPANT	\N	PRESENT	0
177876	167337	04092N	PARTICIPANT	\N	PRESENT	0
177877	167337	14363X	PARTICIPANT	\N	PRESENT	0
177878	167337	05001W	PARTICIPANT	\N	PRESENT	0
177892	167337	14038Y	PARTICIPANT	\N	PRESENT	0
177912	167337	11091R	PARTICIPANT	\N	PRESENT	0
177913	167337	08052W	PARTICIPANT	\N	PRESENT	0
177932	167337	14209N	PARTICIPANT	\N	PRESENT	0
177933	167337	92045V	PARTICIPANT	\N	PRESENT	0
177952	167337	11054L	PARTICIPANT	\N	PRESENT	0
177953	167337	08043V	PARTICIPANT	\N	PRESENT	0
177954	167337	14197C	PARTICIPANT	\N	PRESENT	0
177955	167337	11101A	PARTICIPANT	\N	PRESENT	0
177972	167337	08028W	PARTICIPANT	\N	PRESENT	0
177973	167337	14071N	PARTICIPANT	\N	PRESENT	0
177974	177612	04056J	PARTICIPANT	\N	PRESENT	0
177975	177612	07034Q	PARTICIPANT	\N	PRESENT	0
177976	177612	14041T	PARTICIPANT	\N	PRESENT	0
177977	177612	14069U	PARTICIPANT	\N	PRESENT	0
177978	177612	04038G	PARTICIPANT	\N	PRESENT	0
177979	177612	04044E	PARTICIPANT	\N	PRESENT	0
177980	177612	01007L	PARTICIPANT	\N	PRESENT	0
177981	177612	04047H	PARTICIPANT	\N	PRESENT	0
177982	177612	11033F	PARTICIPANT	\N	PRESENT	0
177983	177612	01028R	PARTICIPANT	\N	PRESENT	0
177984	177612	05008E	PRESIDENT	0	PRESENT	0
177985	177612	14111D	PARTICIPANT	\N	PRESENT	0
177986	177612	92045V	PARTICIPANT	\N	PRESENT	0
177987	177612	11010L	PARTICIPANT	\N	EXCUSE	0
177988	177612	08044W	PARTICIPANT	\N	EXCUSE	0
177989	177612	01024M	PARTICIPANT	\N	EXCUSE	0
177990	167337	14111D	PARTICIPANT	\N	PRESENT	0
177992	167337	01028R	PARTICIPANT	\N	PRESENT	0
177993	167337	95031C	PARTICIPANT	\N	PRESENT	0
177994	167337	01008M	PARTICIPANT	\N	PRESENT	0
178012	167337	11039M	PARTICIPANT	\N	PRESENT	0
178013	167337	11049P	PARTICIPANT	\N	PRESENT	0
178032	167337	01025N	PARTICIPANT	\N	PRESENT	0
178052	167337	07026Q	PARTICIPANT	\N	PRESENT	0
178072	167337	11034G	PARTICIPANT	\N	PRESENT	0
178073	167337	14331P	PARTICIPANT	\N	PRESENT	0
178092	167337	14034U	PARTICIPANT	\N	PRESENT	0
178093	167337	11081P	PARTICIPANT	\N	PRESENT	0
178112	167338	01007L	PARTICIPANT	\N	PRESENT	0
178113	167338	05012A	PARTICIPANT	\N	PRESENT	0
178132	167338	08055A	PARTICIPANT	\N	PRESENT	0
178133	167338	14063N	PARTICIPANT	\N	PRESENT	0
178134	167338	14257W	PARTICIPANT	\N	PRESENT	0
178135	167338	11107G	PARTICIPANT	\N	PRESENT	0
178136	167338	14361V	PARTICIPANT	\N	PRESENT	0
178137	167338	11034G	PARTICIPANT	\N	PRESENT	0
178138	167338	14109K	PARTICIPANT	\N	PRESENT	0
178139	167338	01044R	PARTICIPANT	\N	PRESENT	0
178140	167338	11081P	PARTICIPANT	\N	PRESENT	0
178141	167338	14219Q	PARTICIPANT	\N	PRESENT	0
178142	167338	14030Q	PARTICIPANT	\N	PRESENT	0
178143	167338	14079W	PARTICIPANT	\N	PRESENT	0
178144	167338	14061L	PARTICIPANT	\N	PRESENT	0
178145	167338	11094U	PARTICIPANT	\N	PRESENT	0
178146	167338	14265W	PARTICIPANT	\N	PRESENT	0
178147	167338	07029T	PARTICIPANT	\N	PRESENT	0
178148	167338	14033T	PARTICIPANT	\N	PRESENT	0
178149	167338	14119M	PARTICIPANT	\N	PRESENT	0
178150	167338	04088S	PARTICIPANT	\N	PRESENT	0
178151	167338	14038Y	PARTICIPANT	\N	PRESENT	0
178152	167338	14169X	PARTICIPANT	\N	PRESENT	0
178153	167338	14069U	PARTICIPANT	\N	PRESENT	0
178154	167338	14026U	PARTICIPANT	\N	PRESENT	0
178155	167338	04067M	PARTICIPANT	\N	PRESENT	0
178156	167338	95062K	PARTICIPANT	\N	PRESENT	0
178157	167338	01013J	PARTICIPANT	\N	PRESENT	0
178158	167338	08015R	PARTICIPANT	\N	PRESENT	0
178159	167338	11036J	PARTICIPANT	\N	PRESENT	0
178160	167338	14107H	PARTICIPANT	\N	PRESENT	0
178161	167338	11035H	PARTICIPANT	\N	PRESENT	0
178162	167338	01022K	PARTICIPANT	\N	PRESENT	0
178163	167338	14199E	PARTICIPANT	\N	PRESENT	0
178164	167338	08028W	PARTICIPANT	\N	PRESENT	0
178165	167338	04042C	PARTICIPANT	\N	PRESENT	0
178166	167338	11067R	PARTICIPANT	\N	PRESENT	0
178167	167338	14031R	PARTICIPANT	\N	PRESENT	0
178168	167338	95063L	PARTICIPANT	\N	PRESENT	0
178169	167338	01025N	PARTICIPANT	\N	PRESENT	0
178170	167338	14059S	PARTICIPANT	\N	PRESENT	0
178171	167338	14357A	PARTICIPANT	\N	PRESENT	0
178172	167338	14083S	PARTICIPANT	\N	PRESENT	0
178173	167338	14197C	PARTICIPANT	\N	PRESENT	0
178174	167338	08062Y	PARTICIPANT	\N	PRESENT	0
178192	167338	14195A	PARTICIPANT	\N	PRESENT	0
178193	167338	87003B	PARTICIPANT	\N	PRESENT	0
178194	167338	97011G	PARTICIPANT	\N	PRESENT	0
178195	167338	14187A	PARTICIPANT	\N	PRESENT	0
178196	167338	14221J	PARTICIPANT	\N	PRESENT	0
178197	167338	14051J	PARTICIPANT	\N	PRESENT	0
178212	167338	08019V	PARTICIPANT	\N	PRESENT	0
178213	167338	14135M	PARTICIPANT	\N	PRESENT	0
178214	167338	11104D	PARTICIPANT	\N	PRESENT	0
178215	167338	01031L	PARTICIPANT	\N	PRESENT	0
178216	167338	01058X	PARTICIPANT	\N	PRESENT	0
178222	167338	14363X	PARTICIPANT	\N	PRESENT	0
178223	167338	14071N	PARTICIPANT	\N	PRESENT	0
178224	167338	14133K	PARTICIPANT	\N	PRESENT	0
178226	167338	14103D	PARTICIPANT	\N	PRESENT	0
178228	167338	14209N	PARTICIPANT	\N	PRESENT	0
178229	167338	14217N	PARTICIPANT	\N	PRESENT	0
178232	167338	14013P	PARTICIPANT	\N	PRESENT	0
178233	167338	95030B	PARTICIPANT	\N	PRESENT	0
178234	167338	08041T	PARTICIPANT	\N	PRESENT	0
178236	167338	14157T	PARTICIPANT	\N	PRESENT	0
178272	167338	01024M	PARTICIPANT	\N	PRESENT	0
178273	167338	95041E	PARTICIPANT	\N	PRESENT	0
178292	167338	08034U	PARTICIPANT	\N	PRESENT	0
178293	167338	11099A	PARTICIPANT	\N	PRESENT	0
178312	167338	01047U	PARTICIPANT	\N	PRESENT	0
178335	167338	14355X	PARTICIPANT	\N	PRESENT	0
178336	167338	08009T	PARTICIPANT	\N	PRESENT	0
178337	167338	08068F	PARTICIPANT	\N	PRESENT	0
178352	167339	01007L	PARTICIPANT	\N	PRESENT	0
178355	167339	14063N	PARTICIPANT	\N	PRESENT	0
178358	167339	14361V	PARTICIPANT	\N	PRESENT	0
178361	167339	01044R	PARTICIPANT	\N	PRESENT	0
178362	167339	11081P	PARTICIPANT	\N	PRESENT	0
178363	167339	14219Q	PARTICIPANT	\N	PRESENT	0
178365	167339	14079W	PARTICIPANT	\N	PRESENT	0
178367	167339	11094U	PARTICIPANT	\N	PRESENT	0
178369	167339	07029T	PARTICIPANT	\N	PRESENT	0
178372	167339	04088S	PARTICIPANT	\N	PRESENT	0
178377	167339	04067M	PARTICIPANT	\N	PRESENT	0
178378	167339	95062K	PARTICIPANT	\N	PRESENT	0
178381	167339	11036J	PARTICIPANT	\N	PRESENT	0
178382	167339	14107H	PARTICIPANT	\N	PRESENT	0
178384	167339	01022K	PARTICIPANT	\N	PRESENT	0
178386	167339	08028W	PARTICIPANT	\N	PRESENT	0
178389	167339	14031R	PARTICIPANT	\N	PRESENT	0
196406	196293	11036J	PARTICIPANT	\N	PRESENT	0
196407	196293	14105F	PARTICIPANT	\N	PRESENT	0
196408	196293	04049K	PARTICIPANT	\N	PRESENT	0
196409	196293	08015R	PARTICIPANT	\N	PRESENT	0
196410	196293	08019V	PARTICIPANT	\N	PRESENT	0
196411	196293	98050T	PARTICIPANT	\N	PRESENT	0
196412	196293	14197C	PARTICIPANT	\N	PRESENT	0
196413	196293	14207L	PARTICIPANT	\N	PRESENT	0
196414	196293	08028W	PARTICIPANT	\N	PRESENT	0
196415	196293	14257W	PARTICIPANT	\N	PRESENT	0
196416	196293	01061S	PARTICIPANT	\N	EXCUSE	0
196417	192774	11088W	PARTICIPANT	\N	PRESENT	0
196418	192774	11057P	PARTICIPANT	\N	PRESENT	0
196419	192774	11048N	PARTICIPANT	\N	PRESENT	0
196420	192774	04071H	PARTICIPANT	\N	PRESENT	0
196421	192774	08034U	PARTICIPANT	\N	PRESENT	0
196422	192774	89017R	PARTICIPANT	\N	PRESENT	0
196423	192774	14225N	PARTICIPANT	\N	PRESENT	0
196424	192774	11070L	PARTICIPANT	\N	PRESENT	0
196425	192774	14173T	PARTICIPANT	\N	PRESENT	0
196426	192774	14199E	PARTICIPANT	\N	PRESENT	0
196427	192774	08010L	PARTICIPANT	\N	PRESENT	0
196428	192774	08061X	PARTICIPANT	\N	PRESENT	0
196429	192774	98053W	PARTICIPANT	\N	EXCUSE	0
196433	192515	14231L	PARTICIPANT	\N	PRESENT	0
196434	192515	11067R	PARTICIPANT	\N	PRESENT	0
196435	192515	04053F	PARTICIPANT	\N	PRESENT	0
196436	192515	04043D	PARTICIPANT	\N	PRESENT	0
196437	192515	14071N	PARTICIPANT	\N	PRESENT	0
196438	192515	11097X	PARTICIPANT	\N	PRESENT	0
196439	192515	14265W	PARTICIPANT	\N	PRESENT	0
196452	192774	08011M	PARTICIPANT	\N	EXCUSE	0
196510	194372	14103D	PARTICIPANT	\N	PRESENT	0
196513	190781	04066L	PARTICIPANT	\N	PRESENT	0
196514	190781	14219Q	PARTICIPANT	\N	PRESENT	0
196456	194372	08043V	PARTICIPANT	\N	PRESENT	0
196532	190781	08024S	PARTICIPANT	\N	PRESENT	0
196458	194372	14105F	PARTICIPANT	\N	PRESENT	0
196459	194372	11029K	PARTICIPANT	\N	PRESENT	0
196533	190781	05008E	PARTICIPANT	\N	PRESENT	0
196461	194372	92015P	PARTICIPANT	\N	EXCUSE	0
196462	194372	08024S	PARTICIPANT	\N	PRESENT	0
196534	190781	08060W	PARTICIPANT	\N	PRESENT	0
196592	190781	08055A	PARTICIPANT	\N	PRESENT	0
196593	190781	14107H	PARTICIPANT	\N	PRESENT	0
196466	194372	14079W	PARTICIPANT	\N	PRESENT	0
196467	194372	11091R	PARTICIPANT	\N	PRESENT	0
196468	194372	87003B	PARTICIPANT	\N	PRESENT	0
196594	190781	08043V	PARTICIPANT	\N	PRESENT	0
196595	190781	11083R	PARTICIPANT	\N	PRESENT	0
196471	194372	14249W	PARTICIPANT	\N	PRESENT	0
196596	190781	11037K	PARTICIPANT	\N	PRESENT	0
196473	194372	01025N	PARTICIPANT	\N	PRESENT	0
196597	190781	07026Q	PARTICIPANT	\N	PRESENT	0
196598	190781	04085P	PARTICIPANT	\N	PRESENT	0
196599	190781	01015L	PARTICIPANT	\N	PRESENT	0
196600	190781	14235Q	PARTICIPANT	\N	PRESENT	0
196478	194372	14123H	PARTICIPANT	\N	PRESENT	0
196601	190781	08014Q	PARTICIPANT	\N	PRESENT	0
196602	190781	80013X	PARTICIPANT	\N	PRESENT	0
196481	194372	14241N	PARTICIPANT	\N	PRESENT	0
196482	194372	14061L	PARTICIPANT	\N	PRESENT	0
196483	194372	14073Q	PARTICIPANT	\N	PRESENT	0
196603	190781	11107G	PARTICIPANT	\N	PRESENT	0
196485	194372	12041X	PARTICIPANT	\N	PRESENT	0
196486	194372	08039A	PARTICIPANT	\N	PRESENT	0
196604	190781	08053X	PARTICIPANT	\N	PRESENT	0
196488	194372	14059S	PARTICIPANT	\N	PRESENT	0
196605	190781	14109K	PARTICIPANT	\N	PRESENT	0
196606	190781	98029W	PARTICIPANT	\N	PRESENT	0
196491	194372	11104D	PARTICIPANT	\N	PRESENT	0
196492	194372	14063N	PARTICIPANT	\N	PRESENT	0
196493	194372	04057K	PARTICIPANT	\N	PRESENT	0
196607	190781	04077P	PARTICIPANT	\N	PRESENT	0
196495	194372	14109K	PARTICIPANT	\N	PRESENT	0
196496	194372	04070G	PRESIDENT	0	PRESENT	0
196608	190781	95049N	PARTICIPANT	\N	PRESENT	0
196609	190781	04038G	PARTICIPANT	\N	PRESENT	0
196499	194372	83047W	PARTICIPANT	\N	PRESENT	0
196500	194372	14235Q	PARTICIPANT	\N	PRESENT	0
196610	190781	88008L	PARTICIPANT	\N	PRESENT	0
196611	190781	11012A	PARTICIPANT	\N	PRESENT	0
196612	190781	11094U	PARTICIPANT	\N	PRESENT	0
196504	194372	14229S	PARTICIPANT	\N	PRESENT	0
196505	194372	14363X	PARTICIPANT	\N	PRESENT	0
196663	196659	14261S	PARTICIPANT	\N	PRESENT	0
196664	196659	08055A	PARTICIPANT	\N	PRESENT	0
196665	196659	14093U	PARTICIPANT	\N	PRESENT	0
196509	194372	11011M	PARTICIPANT	\N	PRESENT	0
196666	196659	14030Q	PARTICIPANT	\N	PRESENT	0
196834	196659	14169X	PARTICIPANT	\N	PRESENT	0
196910	192792	14327T	PARTICIPANT	\N	PRESENT	0
196911	192792	01031L	PRESIDENT	0	PRESENT	0
196670	196659	14038Y	PARTICIPANT	\N	PRESENT	0
196912	192792	08034U	PARTICIPANT	\N	PRESENT	0
196672	196659	98023Q	PARTICIPANT	\N	PRESENT	0
196913	192792	01057W	PARTICIPANT	\N	PRESENT	0
196674	196659	01015L	PARTICIPANT	\N	PRESENT	0
196675	196659	11107G	PARTICIPANT	\N	PRESENT	0
196914	192792	01016M	PARTICIPANT	\N	PRESENT	0
196677	196659	02002K	PARTICIPANT	\N	PRESENT	0
196678	196659	01022K	PARTICIPANT	\N	PRESENT	0
196915	192792	08011M	PARTICIPANT	\N	PRESENT	0
196916	192792	11074Q	PARTICIPANT	\N	PRESENT	0
196917	192792	01027Q	PARTICIPANT	\N	PRESENT	0
196682	196659	11059R	PARTICIPANT	\N	PRESENT	0
196683	196659	14219Q	PARTICIPANT	\N	PRESENT	0
196684	196659	80027E	PARTICIPANT	\N	PRESENT	0
196685	196659	14031R	PARTICIPANT	\N	PRESENT	0
196686	196659	08009T	PRESIDENT	0	PRESENT	0
196687	196659	08062Y	PARTICIPANT	\N	PRESENT	0
196918	192792	11070L	PARTICIPANT	\N	PRESENT	0
196919	192792	14159V	PARTICIPANT	\N	PRESENT	0
196920	192792	14225N	PARTICIPANT	\N	PRESENT	0
196921	192792	88008L	PARTICIPANT	\N	PRESENT	0
196692	196659	14237S	PARTICIPANT	\N	PRESENT	0
196693	196659	13002U	PARTICIPANT	\N	PRESENT	0
196694	196659	05012A	PARTICIPANT	\N	PRESENT	0
196922	192792	04086Q	PARTICIPANT	\N	PRESENT	0
196696	196659	14135M	PARTICIPANT	\N	PRESENT	0
196697	196659	14331P	PARTICIPANT	\N	EXCUSE	0
196698	196659	95062K	PARTICIPANT	\N	EXCUSE	0
196699	196659	14107H	PARTICIPANT	\N	PRESENT	0
196923	192792	14083S	PARTICIPANT	\N	PRESENT	0
196701	196659	14157T	PARTICIPANT	\N	PRESENT	0
196924	192792	11057P	PARTICIPANT	\N	PRESENT	0
196925	192792	08073C	PARTICIPANT	\N	PRESENT	0
196926	192792	98046X	PARTICIPANT	\N	PRESENT	0
196927	192792	11083R	PARTICIPANT	\N	PRESENT	0
196928	192792	99004R	PARTICIPANT	\N	PRESENT	0
196929	192792	14253S	PARTICIPANT	\N	PRESENT	0
196930	192792	11085T	PARTICIPANT	\N	PRESENT	0
196931	192792	08061X	PARTICIPANT	\N	PRESENT	0
196932	192792	04061F	PARTICIPANT	\N	PRESENT	0
196954	190781	08016S	PARTICIPANT	\N	PRESENT	0
196955	190781	08039A	PARTICIPANT	\N	PRESENT	0
196956	190781	01058X	PARTICIPANT	\N	PRESENT	0
196957	190781	04070G	PARTICIPANT	\N	PRESENT	0
196958	190781	04057K	PARTICIPANT	\N	PRESENT	0
196959	190781	05012A	PARTICIPANT	\N	PRESENT	0
196978	190781	08011M	PARTICIPANT	\N	PRESENT	0
196979	190781	08031R	PARTICIPANT	\N	PRESENT	0
167613	167612	11105E	PARTICIPANT	\N	PRESENT	0
167615	167614	04040A	PARTICIPANT	\N	PRESENT	0
167616	167614	14001X	PARTICIPANT	\N	PRESENT	0
167878	167006	08053X	PARTICIPANT	\N	PRESENT	0
167880	167006	01015L	PARTICIPANT	\N	PRESENT	0
167881	167006	14097Y	PARTICIPANT	\N	PRESENT	0
167882	167006	14207L	PARTICIPANT	\N	PRESENT	0
167883	167006	11084S	PARTICIPANT	\N	PRESENT	0
167884	167006	14159V	PARTICIPANT	\N	PRESENT	0
167885	167006	13002U	PARTICIPANT	\N	PRESENT	0
167886	167006	14201E	PARTICIPANT	\N	PRESENT	0
167887	167006	08021P	PARTICIPANT	\N	PRESENT	0
167888	167006	01025N	PARTICIPANT	\N	PRESENT	0
167889	167006	14329V	PARTICIPANT	\N	PRESENT	0
167890	167006	04041B	PARTICIPANT	\N	PRESENT	0
167891	167006	08022Q	PARTICIPANT	\N	PRESENT	0
167892	167006	08041T	PARTICIPANT	\N	PRESENT	0
167893	167006	01008M	PARTICIPANT	\N	PRESENT	0
167894	167006	80013X	PARTICIPANT	\N	PRESENT	0
167895	167006	10006L	PARTICIPANT	\N	PRESENT	0
167896	167006	14037X	PARTICIPANT	\N	PRESENT	0
167897	167006	98022P	PARTICIPANT	\N	PRESENT	0
167898	167006	08068F	PARTICIPANT	\N	PRESENT	0
167899	167006	14033T	PARTICIPANT	\N	PRESENT	0
167900	167006	11029K	PARTICIPANT	\N	PRESENT	0
167901	167006	14227Q	PARTICIPANT	\N	PRESENT	0
167902	167006	01014K	PARTICIPANT	\N	PRESENT	0
167903	167006	11093T	PARTICIPANT	\N	PRESENT	0
167904	167006	04043D	PARTICIPANT	\N	PRESENT	0
167905	167006	11098Y	PARTICIPANT	\N	PRESENT	0
167906	167006	08069G	PARTICIPANT	\N	PRESENT	0
167907	167006	14109K	PARTICIPANT	\N	PRESENT	0
167908	167006	77002U	PARTICIPANT	\N	PRESENT	0
167909	167006	11036J	PARTICIPANT	\N	PRESENT	0
167910	167006	14001X	PARTICIPANT	\N	PRESENT	0
167911	167006	98053W	PARTICIPANT	\N	PRESENT	0
167912	167006	14014Q	PARTICIPANT	\N	PRESENT	0
168067	167007	86034E	PARTICIPANT	\N	PRESENT	0
168072	167007	95062K	PARTICIPANT	\N	PRESENT	0
168073	167007	89029V	PARTICIPANT	\N	PRESENT	0
168074	167007	14223L	PARTICIPANT	\N	PRESENT	0
168075	167007	77002U	PARTICIPANT	\N	PRESENT	0
168076	167007	08022Q	PARTICIPANT	\N	PRESENT	0
168077	167007	01027Q	PARTICIPANT	\N	PRESENT	0
168078	167007	04074L	PARTICIPANT	\N	PRESENT	0
168079	167007	14265W	PARTICIPANT	\N	PRESENT	0
168080	167007	14173T	PARTICIPANT	\N	PRESENT	0
168081	167007	14105F	PARTICIPANT	\N	PRESENT	0
168082	167007	90003B	PARTICIPANT	\N	PRESENT	0
168083	167007	11097X	PARTICIPANT	\N	PRESENT	0
168084	167007	08010L	PARTICIPANT	\N	PRESENT	0
168085	167007	08028W	PARTICIPANT	\N	PRESENT	0
168086	167007	86044G	PARTICIPANT	\N	PRESENT	0
168087	167007	14237S	PARTICIPANT	\N	PRESENT	0
168088	167007	14061L	PARTICIPANT	\N	PRESENT	0
168089	167007	01008M	PARTICIPANT	\N	PRESENT	0
168090	167007	08048B	PARTICIPANT	\N	PRESENT	0
168091	167007	11088W	PARTICIPANT	\N	PRESENT	0
168092	167007	87003B	PARTICIPANT	\N	PRESENT	0
168093	167007	95015C	PARTICIPANT	\N	PRESENT	0
168094	167007	10006L	PARTICIPANT	\N	PRESENT	0
168095	167007	11049P	PARTICIPANT	\N	PRESENT	0
168096	167007	14123H	PARTICIPANT	\N	PRESENT	0
168097	167007	08041T	PARTICIPANT	\N	PRESENT	0
168098	167007	14331P	PARTICIPANT	\N	PRESENT	0
168099	167007	01041N	PARTICIPANT	\N	PRESENT	0
168100	167007	14187A	PARTICIPANT	\N	PRESENT	0
168101	167007	98050T	PARTICIPANT	\N	PRESENT	0
168102	167007	14026U	PARTICIPANT	\N	PRESENT	0
168103	167007	14209N	PARTICIPANT	\N	PRESENT	0
168104	167007	14033T	PARTICIPANT	\N	PRESENT	0
168115	167007	14253S	PARTICIPANT	\N	PRESENT	0
168117	167007	14013P	PARTICIPANT	\N	PRESENT	0
168118	167007	08039A	PARTICIPANT	\N	PRESENT	0
168119	167007	11040E	PARTICIPANT	\N	PRESENT	0
168120	167007	04085P	PARTICIPANT	\N	PRESENT	0
168121	167007	98053W	PARTICIPANT	\N	PRESENT	0
168122	167007	04086Q	PARTICIPANT	\N	PRESENT	0
168124	167007	01059Y	PARTICIPANT	\N	PRESENT	0
168125	167007	92018S	PARTICIPANT	\N	PRESENT	0
168126	167007	04054G	PARTICIPANT	\N	PRESENT	0
168127	167007	07026Q	PARTICIPANT	\N	PRESENT	0
168128	167007	04081K	PARTICIPANT	\N	PRESENT	0
168129	167007	11056N	PARTICIPANT	\N	PRESENT	0
168130	167007	04042C	PARTICIPANT	\N	PRESENT	0
168131	167007	11034G	PARTICIPANT	\N	PRESENT	0
168132	167007	11063M	PARTICIPANT	\N	PRESENT	0
168133	167007	11098Y	PARTICIPANT	\N	PRESENT	0
168134	167007	14147R	PARTICIPANT	\N	PRESENT	0
168135	167007	14361V	PARTICIPANT	\N	PRESENT	0
168136	167007	11100Y	PARTICIPANT	\N	PRESENT	0
168137	167007	14213J	PARTICIPANT	\N	PRESENT	0
168138	167007	12042Y	PARTICIPANT	\N	PRESENT	0
168139	167007	11068S	PARTICIPANT	\N	PRESENT	0
168140	167007	02002K	PARTICIPANT	\N	PRESENT	0
168141	167007	04045F	PARTICIPANT	\N	PRESENT	0
168142	167007	11084S	PARTICIPANT	\N	PRESENT	0
168143	167007	08034U	PARTICIPANT	\N	PRESENT	0
168144	167007	08015R	PARTICIPANT	\N	PRESENT	0
168145	167007	07034Q	PARTICIPANT	\N	PRESENT	0
168146	167007	04088S	PARTICIPANT	\N	PRESENT	0
168147	167007	08016S	PARTICIPANT	\N	PRESENT	0
168148	167007	01016M	PARTICIPANT	\N	PRESENT	0
168149	167007	04056J	PARTICIPANT	\N	PRESENT	0
168150	167007	14017T	PARTICIPANT	\N	PRESENT	0
168151	167007	14363X	PARTICIPANT	\N	PRESENT	0
168152	167007	08031R	PARTICIPANT	\N	PRESENT	0
168153	167007	01019Q	PARTICIPANT	\N	PRESENT	0
168154	167007	88008L	PARTICIPANT	\N	PRESENT	0
168155	167007	04078Q	PARTICIPANT	\N	PRESENT	0
168156	167007	08051V	PARTICIPANT	\N	PRESENT	0
168157	167007	11081P	PARTICIPANT	\N	PRESENT	0
168158	167007	04044E	PARTICIPANT	\N	PRESENT	0
168159	167007	14201E	PARTICIPANT	\N	PRESENT	0
168160	167007	08049C	PARTICIPANT	\N	PRESENT	0
168161	167007	11012A	PARTICIPANT	\N	PRESENT	0
168162	167007	14239U	PARTICIPANT	\N	PRESENT	0
168163	167007	98022P	PARTICIPANT	\N	PRESENT	0
168164	167007	14111D	PARTICIPANT	\N	PRESENT	0
168165	167007	14241N	PARTICIPANT	\N	PRESENT	0
168166	167007	04067M	PARTICIPANT	\N	PRESENT	0
168167	167007	11080N	PARTICIPANT	\N	PRESENT	0
168168	167007	08021P	PARTICIPANT	\N	PRESENT	0
168169	167007	05008E	PARTICIPANT	\N	PRESENT	0
168170	167007	14247U	PARTICIPANT	\N	PRESENT	0
168171	167007	11030C	PARTICIPANT	\N	PRESENT	0
168172	167007	01060R	PARTICIPANT	\N	PRESENT	0
168173	167007	89017R	PARTICIPANT	\N	PRESENT	0
168174	167007	14069U	PARTICIPANT	\N	PRESENT	0
168175	167007	14055N	PARTICIPANT	\N	PRESENT	0
168176	167007	14175V	PARTICIPANT	\N	PRESENT	0
168177	167007	92044U	PARTICIPANT	\N	PRESENT	0
168178	167007	04047H	PARTICIPANT	\N	PRESENT	0
168179	167007	01044R	PARTICIPANT	\N	PRESENT	0
168180	167007	11103C	PARTICIPANT	\N	PRESENT	0
168181	167007	11029K	PARTICIPANT	\N	PRESENT	0
168182	167007	11033F	PARTICIPANT	\N	PRESENT	0
168183	167007	14038Y	PARTICIPANT	\N	PRESENT	0
168184	167007	04038G	PARTICIPANT	\N	PRESENT	0
168185	167007	11032E	PARTICIPANT	\N	PRESENT	0
168186	167007	13002U	PARTICIPANT	\N	PRESENT	0
168187	167007	11055M	PARTICIPANT	\N	PRESENT	0
168188	167007	14357A	PARTICIPANT	\N	PRESENT	0
168189	167007	14329V	PARTICIPANT	\N	PRESENT	0
168190	167007	99002P	PARTICIPANT	\N	PRESENT	0
168191	167007	11011M	PARTICIPANT	\N	PRESENT	0
168192	167007	08069G	PARTICIPANT	\N	PRESENT	0
168193	167007	11026G	PARTICIPANT	\N	PRESENT	0
168194	167007	95030B	PARTICIPANT	\N	PRESENT	0
168195	167007	14051J	PARTICIPANT	\N	PRESENT	0
168196	167007	14041T	PARTICIPANT	\N	PRESENT	0
168197	167007	08025T	PARTICIPANT	\N	PRESENT	0
168198	167007	08052W	PARTICIPANT	\N	PRESENT	0
168199	167007	92015P	PARTICIPANT	\N	PRESENT	0
168200	167007	95031C	PARTICIPANT	\N	PRESENT	0
168201	167007	08055A	PARTICIPANT	\N	PRESENT	0
168202	167007	04066L	PARTICIPANT	\N	PRESENT	0
168203	167007	11027H	PARTICIPANT	\N	PRESENT	0
168204	167007	95063L	PARTICIPANT	\N	PRESENT	0
168205	167007	01011G	PARTICIPANT	\N	PRESENT	0
168207	167007	14159V	PARTICIPANT	\N	PRESENT	0
168208	167007	01022K	PARTICIPANT	\N	PRESENT	0
168209	167007	08042U	PARTICIPANT	\N	PRESENT	0
168210	167007	14028W	PARTICIPANT	\N	PRESENT	0
168211	167007	14169X	PARTICIPANT	\N	PRESENT	0
168212	167007	80013X	PARTICIPANT	\N	PRESENT	0
168213	167007	04049K	PARTICIPANT	\N	PRESENT	0
192550	190775	08034U	PARTICIPANT	\N	PRESENT	0
192551	190775	04042C	PARTICIPANT	\N	PRESENT	0
192552	190775	95035G	PARTICIPANT	\N	PRESENT	0
192553	190775	08039A	PARTICIPANT	\N	PRESENT	0
192554	190775	08011M	PARTICIPANT	\N	PRESENT	0
192555	190775	11044J	PARTICIPANT	\N	PRESENT	0
192556	190775	14251Q	PARTICIPANT	\N	PRESENT	0
192557	190775	11049P	PARTICIPANT	\N	PRESENT	0
192558	190775	14069U	PARTICIPANT	\N	PRESENT	0
192559	190775	14217N	PARTICIPANT	\N	PRESENT	0
192560	190775	14363X	PARTICIPANT	\N	PRESENT	0
192561	190775	04061F	PARTICIPANT	\N	PRESENT	0
192562	190775	14331P	PARTICIPANT	\N	PRESENT	0
192563	190775	08065C	PARTICIPANT	\N	PRESENT	0
192564	190775	11100Y	PARTICIPANT	\N	PRESENT	0
192565	190775	92045V	PARTICIPANT	\N	PRESENT	0
192566	190775	98050T	PARTICIPANT	\N	PRESENT	0
192567	190775	04057K	PARTICIPANT	\N	PRESENT	0
192568	190775	98005N	PARTICIPANT	\N	PRESENT	0
192569	190775	04035D	PARTICIPANT	\N	PRESENT	0
192570	190775	04074L	PARTICIPANT	\N	PRESENT	0
192571	190775	14329V	PARTICIPANT	\N	PRESENT	0
192572	190775	04043D	PARTICIPANT	\N	PRESENT	0
192573	190775	14093U	PARTICIPANT	\N	PRESENT	0
192574	190775	04085P	PARTICIPANT	\N	PRESENT	0
192575	190775	14038Y	PARTICIPANT	\N	PRESENT	0
192576	190775	98053W	PARTICIPANT	\N	PRESENT	0
192577	190775	05001W	PARTICIPANT	\N	PRESENT	0
192578	190775	08019V	PARTICIPANT	\N	PRESENT	0
192579	190775	04054G	PARTICIPANT	\N	PRESENT	0
192580	190775	04055H	PARTICIPANT	\N	PRESENT	0
192581	190775	01013J	PARTICIPANT	\N	PRESENT	0
192582	190775	07026Q	PARTICIPANT	\N	PRESENT	0
192583	190775	14235Q	PARTICIPANT	\N	PRESENT	0
192584	190775	14213J	PARTICIPANT	\N	PRESENT	0
192585	190775	11034G	PARTICIPANT	\N	PRESENT	0
192586	190775	11031D	PARTICIPANT	\N	PRESENT	0
192587	190775	11063M	PARTICIPANT	\N	PRESENT	0
192597	190775	13002U	PARTICIPANT	\N	PRESENT	0
192589	190775	11039M	PARTICIPANT	\N	PRESENT	0
192590	190775	08016S	PARTICIPANT	\N	PRESENT	0
192591	190775	04056J	PARTICIPANT	\N	PRESENT	0
192592	190775	01016M	PARTICIPANT	\N	PRESENT	0
192593	190775	14265W	PARTICIPANT	\N	PRESENT	0
192594	190775	04059M	PARTICIPANT	\N	PRESENT	0
192595	190775	11027H	PARTICIPANT	\N	PRESENT	0
192596	190775	01041N	PARTICIPANT	\N	PRESENT	0
192598	190775	08038Y	PARTICIPANT	\N	PRESENT	0
192599	190775	08060W	PARTICIPANT	\N	PRESENT	0
192600	190775	11076S	PARTICIPANT	\N	PRESENT	0
192601	190775	08043V	PARTICIPANT	\N	PRESENT	0
192602	190775	08053X	PARTICIPANT	\N	PRESENT	0
192603	190775	14028W	PARTICIPANT	\N	PRESENT	0
192604	190775	14255U	PARTICIPANT	\N	PRESENT	0
192605	190775	18127E	PARTICIPANT	\N	PRESENT	0
192606	190775	04077P	PARTICIPANT	\N	PRESENT	0
192607	190775	14327T	PARTICIPANT	\N	PRESENT	0
192608	190775	08061X	PARTICIPANT	\N	PRESENT	0
192609	190775	01024M	PARTICIPANT	\N	PRESENT	0
192610	190775	11036J	PARTICIPANT	\N	PRESENT	0
192611	190775	14271U	PARTICIPANT	\N	PRESENT	0
192612	190775	04066L	PARTICIPANT	\N	PRESENT	0
192613	190775	95037J	PARTICIPANT	\N	PRESENT	0
192614	190775	04034C	PARTICIPANT	\N	PRESENT	0
192615	190775	11107G	PARTICIPANT	\N	PRESENT	0
192616	190775	11046L	PARTICIPANT	\N	PRESENT	0
192617	190775	11053K	PARTICIPANT	\N	PRESENT	0
192618	190775	04095R	PARTICIPANT	\N	PRESENT	0
192619	190775	11114F	PARTICIPANT	\N	PRESENT	0
192620	190775	11083R	PARTICIPANT	\N	PRESENT	0
192621	190775	14231L	PARTICIPANT	\N	PRESENT	0
192622	190775	08044W	PARTICIPANT	\N	PRESENT	0
192623	190775	14039A	PARTICIPANT	\N	PRESENT	0
192624	190775	14073Q	PARTICIPANT	\N	PRESENT	0
192625	190775	11109J	PARTICIPANT	\N	PRESENT	0
192626	190775	11113E	PARTICIPANT	\N	PRESENT	0
192627	190775	14205J	PARTICIPANT	\N	PRESENT	0
192628	190775	11072N	PARTICIPANT	\N	PRESENT	0
192629	190775	04089T	PARTICIPANT	\N	PRESENT	0
192630	190775	08073C	PARTICIPANT	\N	PRESENT	0
192631	190775	14103D	PARTICIPANT	\N	PRESENT	0
192632	190775	04045F	PARTICIPANT	\N	PRESENT	0
192633	190775	08009T	PARTICIPANT	\N	PRESENT	0
192634	190775	12042Y	PARTICIPANT	\N	PRESENT	0
192635	190775	11070L	PARTICIPANT	\N	PRESENT	0
192636	190775	04053F	PARTICIPANT	\N	PRESENT	0
192637	190775	95049N	PARTICIPANT	\N	PRESENT	0
192638	190775	04070G	PARTICIPANT	\N	PRESENT	0
192639	190775	11082Q	PARTICIPANT	\N	PRESENT	0
192640	190775	14247U	PARTICIPANT	\N	PRESENT	0
192641	190775	11055M	PARTICIPANT	\N	PRESENT	0
192642	190775	01047U	PARTICIPANT	\N	PRESENT	0
192643	190775	11065P	PARTICIPANT	\N	PRESENT	0
192644	190775	11099A	PARTICIPANT	\N	PRESENT	0
192645	190775	11029K	PARTICIPANT	\N	PRESENT	0
192646	190775	04067M	PARTICIPANT	\N	PRESENT	0
192647	190775	14249W	PARTICIPANT	\N	PRESENT	0
192648	190775	08058D	PARTICIPANT	\N	PRESENT	0
192649	190775	14225N	PARTICIPANT	\N	PRESENT	0
192650	190775	08014Q	PARTICIPANT	\N	PRESENT	0
192651	190775	14001X	PARTICIPANT	\N	PRESENT	0
192652	190775	14227Q	PARTICIPANT	\N	PRESENT	0
192653	190775	11054L	PARTICIPANT	\N	PRESENT	0
192654	190775	14281W	PARTICIPANT	\N	PRESENT	0
192655	190775	08069G	PARTICIPANT	\N	PRESENT	0
192656	190775	11061K	PARTICIPANT	\N	PRESENT	0
192657	190775	14063N	PARTICIPANT	\N	PRESENT	0
192658	190775	11074Q	PARTICIPANT	\N	PRESENT	0
192659	190775	04079R	PARTICIPANT	\N	PRESENT	0
192660	190775	11033F	PARTICIPANT	\N	PRESENT	0
192661	190775	01028R	PARTICIPANT	\N	PRESENT	0
192662	190775	11104D	PARTICIPANT	\N	PRESENT	0
192663	190775	08024S	PARTICIPANT	\N	PRESENT	0
192664	190775	11110B	PARTICIPANT	\N	PRESENT	0
192665	190775	11066Q	PARTICIPANT	\N	PRESENT	0
192666	190775	14269B	PARTICIPANT	\N	PRESENT	0
192667	190775	04094Q	PARTICIPANT	\N	PRESENT	0
192668	190775	98022P	PARTICIPANT	\N	PRESENT	0
192669	190775	14159V	PARTICIPANT	\N	PRESENT	0
192670	190775	11023D	PARTICIPANT	\N	PRESENT	0
192671	190775	01014K	PARTICIPANT	\N	PRESENT	0
192672	190775	04071H	PARTICIPANT	\N	PRESENT	0
192673	190775	01046T	PARTICIPANT	\N	PRESENT	0
192674	190775	11012A	PARTICIPANT	\N	PRESENT	0
192675	190775	19253P	PARTICIPANT	\N	PRESENT	0
192676	190775	04038G	PARTICIPANT	\N	PRESENT	0
192677	190775	11080N	PARTICIPANT	\N	PRESENT	0
192678	190775	95015C	PARTICIPANT	\N	PRESENT	0
192681	190775	11068S	PARTICIPANT	\N	PRESENT	0
192683	190775	11026G	PARTICIPANT	\N	PRESENT	0
192694	192693	95049N	PARTICIPANT	\N	PRESENT	0
192712	190672	96004D	PARTICIPANT	\N	PRESENT	0
192713	190672	04054G	PARTICIPANT	\N	PRESENT	0
192714	190672	14133K	PARTICIPANT	\N	EXCUSE	0
192715	190672	14089Y	PARTICIPANT	\N	PRESENT	0
192716	190672	14079W	PARTICIPANT	\N	PRESENT	0
192717	190672	11035H	PARTICIPANT	\N	EXCUSE	0
192718	190672	14249W	PARTICIPANT	\N	PRESENT	0
192719	190672	11083R	PARTICIPANT	\N	PRESENT	0
192720	190672	14097Y	PARTICIPANT	\N	PRESENT	0
192721	190672	14073Q	PARTICIPANT	\N	PRESENT	0
192722	190672	11026G	PARTICIPANT	\N	PRESENT	0
192723	190672	14001X	PARTICIPANT	\N	PRESENT	0
192724	190672	04057K	PARTICIPANT	\N	PRESENT	0
192725	190672	01016M	PARTICIPANT	\N	PRESENT	0
192726	190672	10015M	PARTICIPANT	\N	PRESENT	0
192727	190672	98035U	PARTICIPANT	\N	EXCUSE	0
192728	190672	04045F	PARTICIPANT	\N	PRESENT	0
192729	190672	08042U	PARTICIPANT	\N	PRESENT	0
192730	190672	90003B	PARTICIPANT	\N	EXCUSE	0
192813	192812	98042T	PARTICIPANT	\N	PRESENT	0
192814	192812	01019Q	PARTICIPANT	\N	PRESENT	0
192816	192815	11039M	PARTICIPANT	\N	PRESENT	0
192817	192815	98042T	PARTICIPANT	\N	PRESENT	0
192818	192815	01019Q	PARTICIPANT	\N	PRESENT	0
193112	192759	98035U	PARTICIPANT	\N	PRESENT	0
193113	192759	14111D	PARTICIPANT	\N	PRESENT	0
193114	192759	95067Q	PARTICIPANT	\N	PRESENT	0
193115	192759	07034Q	PARTICIPANT	\N	PRESENT	0
193116	192759	11026G	PARTICIPANT	\N	PRESENT	0
193117	192759	19253P	PARTICIPANT	\N	PRESENT	0
193118	192759	14001X	PARTICIPANT	\N	PRESENT	0
193119	192759	19251M	PARTICIPANT	\N	PRESENT	0
193120	192759	01024M	PARTICIPANT	\N	PRESENT	0
193121	192759	04038G	PARTICIPANT	\N	PRESENT	0
193122	192759	04044E	PRESIDENT	0	PRESENT	0
193123	192759	04047H	PARTICIPANT	\N	PRESENT	0
193124	192759	01028R	PARTICIPANT	\N	PRESENT	0
193125	192759	05008E	PARTICIPANT	\N	PRESENT	0
176174	174507	04034C	PARTICIPANT	\N	PRESENT	0
177713	177712	04057K	PARTICIPANT	\N	PRESENT	0
177714	177712	04045F	PARTICIPANT	\N	PRESENT	0
178218	178217	04086Q	PARTICIPANT	\N	PRESENT	0
178219	178217	10006L	PARTICIPANT	\N	PRESENT	0
178220	178217	14239U	PARTICIPANT	\N	PRESENT	0
178221	178217	01046T	PARTICIPANT	\N	PRESENT	0
178225	178217	11027H	PARTICIPANT	\N	PRESENT	0
178392	167339	14059S	PARTICIPANT	\N	PRESENT	0
178393	167339	14357A	PARTICIPANT	\N	PRESENT	0
178432	167339	95035G	PARTICIPANT	\N	PRESENT	0
178395	167339	14197C	PARTICIPANT	\N	PRESENT	0
178434	167339	14041T	PARTICIPANT	\N	PRESENT	0
178397	167339	14195A	PARTICIPANT	\N	PRESENT	0
178453	167339	14051J	PARTICIPANT	\N	PRESENT	0
178433	167339	11048N	PARTICIPANT	\N	PRESENT	0
178452	167339	11043H	PARTICIPANT	\N	PRESENT	0
178454	167339	11089X	PARTICIPANT	\N	PRESENT	0
178455	167339	08060W	PARTICIPANT	\N	PRESENT	0
178403	167339	08019V	PARTICIPANT	\N	PRESENT	0
178456	167339	95049N	PARTICIPANT	\N	PRESENT	0
178457	167339	08044W	PARTICIPANT	\N	PRESENT	0
178458	167339	14037X	PARTICIPANT	\N	PRESENT	0
178407	167339	01058X	PARTICIPANT	\N	PRESENT	0
178459	167339	01008M	PARTICIPANT	\N	PRESENT	0
178460	167339	14241N	PARTICIPANT	\N	PRESENT	0
178461	167339	14169X	PARTICIPANT	\N	PRESENT	0
178472	167339	98050T	PARTICIPANT	\N	PRESENT	0
178412	167339	14209N	PARTICIPANT	\N	PRESENT	0
178473	167339	11082Q	PARTICIPANT	\N	PRESENT	0
178414	167339	14013P	PARTICIPANT	\N	PRESENT	0
178415	167339	95030B	PARTICIPANT	\N	PRESENT	0
178416	167339	08041T	PARTICIPANT	\N	PRESENT	0
178417	167339	14157T	PARTICIPANT	\N	PRESENT	0
178418	167339	01024M	PARTICIPANT	\N	PRESENT	0
178419	167339	95041E	PARTICIPANT	\N	PRESENT	0
178474	167339	11084S	PARTICIPANT	\N	PRESENT	0
178421	167339	11099A	PARTICIPANT	\N	PRESENT	0
178492	167339	12042Y	PARTICIPANT	\N	PRESENT	0
178512	167339	98053W	PARTICIPANT	\N	PRESENT	0
178424	167339	08009T	PARTICIPANT	\N	PRESENT	0
178425	167339	08068F	PARTICIPANT	\N	PRESENT	0
178426	167339	80027E	PARTICIPANT	\N	PRESENT	0
178513	167339	14103D	PARTICIPANT	\N	PRESENT	0
178532	167339	14331P	PARTICIPANT	\N	PRESENT	0
178533	167339	14363X	PARTICIPANT	\N	PRESENT	0
178552	167339	14265W	PARTICIPANT	\N	PRESENT	0
178553	167339	14223L	PARTICIPANT	\N	PRESENT	0
178572	167339	14030Q	PARTICIPANT	\N	PRESENT	0
178578	167339	04081K	PARTICIPANT	\N	PRESENT	0
178579	167339	11101A	PARTICIPANT	\N	PRESENT	0
178592	167339	14038Y	PARTICIPANT	\N	PRESENT	0
178593	167339	11093T	PARTICIPANT	\N	PRESENT	0
178612	167339	11103C	PARTICIPANT	\N	PRESENT	0
178613	167339	14207L	PARTICIPANT	\N	PRESENT	0
178614	167339	14109K	PARTICIPANT	\N	PRESENT	0
178672	167339	14033T	PARTICIPANT	\N	PRESENT	0
178692	176714	01031L	PRESIDENT	0	PRESENT	0
178693	176714	08034U	PARTICIPANT	\N	PRESENT	0
178694	176714	04034C	PARTICIPANT	\N	PRESENT	0
178695	176714	01057W	PARTICIPANT	\N	PRESENT	0
178696	176714	01016M	PARTICIPANT	\N	PRESENT	0
178697	176714	11053K	PARTICIPANT	\N	PRESENT	0
178698	176714	08011M	PARTICIPANT	\N	PRESENT	0
178699	176714	89017R	PARTICIPANT	\N	PRESENT	0
178700	176714	11070L	PARTICIPANT	\N	PRESENT	0
178701	176714	14225N	PARTICIPANT	\N	PRESENT	0
178702	176714	88008L	PARTICIPANT	\N	PRESENT	0
178703	176714	14173T	PARTICIPANT	\N	PRESENT	0
178704	176714	07029T	PARTICIPANT	\N	PRESENT	0
178705	176714	14083S	PARTICIPANT	\N	PRESENT	0
178706	176714	11012A	PARTICIPANT	\N	PRESENT	0
178707	176714	98046X	PARTICIPANT	\N	PRESENT	0
178708	176714	08061X	PARTICIPANT	\N	PRESENT	0
178709	176714	04061F	PARTICIPANT	\N	PRESENT	0
178710	176714	01013J	PARTICIPANT	\N	PRESENT	0
178711	176714	11042G	PARTICIPANT	\N	PRESENT	0
178712	176714	11040E	PARTICIPANT	\N	EXCUSE	0
178713	176714	04086Q	PARTICIPANT	\N	EXCUSE	0
178714	176714	14175V	PARTICIPANT	\N	EXCUSE	0
178715	176714	14085U	PARTICIPANT	\N	EXCUSE	0
178716	176714	11085T	PARTICIPANT	\N	EXCUSE	0
178717	176714	14159V	PARTICIPANT	\N	EXCUSE	0
181454	181443	96004D	PRESIDENT	0	PRESENT	0
179365	179363	11055M	PARTICIPANT	\N	EXCUSE	0
181456	181443	14026U	PARTICIPANT	\N	PRESENT	0
179367	179363	04053F	PARTICIPANT	\N	PRESENT	0
181457	181443	04061F	PARTICIPANT	\N	PRESENT	0
181458	181443	11026G	PARTICIPANT	\N	PRESENT	0
179370	179363	00003C	PARTICIPANT	\N	EXCUSE	0
179371	179363	14053L	PARTICIPANT	\N	PRESENT	0
179372	179363	11103C	PARTICIPANT	\N	PRESENT	0
181461	181443	98046X	PARTICIPANT	\N	PRESENT	0
179374	179363	14195A	PARTICIPANT	\N	PRESENT	0
179375	179363	14267Y	PARTICIPANT	\N	PRESENT	0
181462	181443	04080J	PARTICIPANT	\N	PRESENT	0
179377	179363	11031D	PARTICIPANT	\N	PRESENT	0
181463	181443	95063L	PARTICIPANT	\N	PRESENT	0
181464	181443	92045V	PARTICIPANT	\N	PRESENT	0
179380	179363	04081K	PARTICIPANT	\N	PRESENT	0
179381	179363	98024R	PARTICIPANT	\N	PRESENT	0
179382	179363	10006L	PARTICIPANT	\N	PRESENT	0
181465	181443	04034C	PARTICIPANT	\N	PRESENT	0
179384	179363	14217N	PARTICIPANT	\N	PRESENT	0
179385	179363	14042U	PARTICIPANT	\N	PRESENT	0
179386	179363	14151M	PARTICIPANT	\N	PRESENT	0
179387	179363	12042Y	PARTICIPANT	\N	PRESENT	0
181466	181443	98035U	PARTICIPANT	\N	EXCUSE	0
181472	181443	14133K	PARTICIPANT	\N	EXCUSE	0
181473	181443	04054G	PARTICIPANT	\N	EXCUSE	0
179391	179363	14034U	PARTICIPANT	\N	PRESENT	0
179392	179363	14231L	PARTICIPANT	\N	PRESENT	0
179393	179363	11061K	PARTICIPANT	\N	PRESENT	0
181474	181443	14089Y	PARTICIPANT	\N	EXCUSE	0
181475	181443	90003B	PARTICIPANT	\N	EXCUSE	0
179396	179363	08041T	PARTICIPANT	\N	PRESENT	0
181476	181443	14079W	PARTICIPANT	\N	EXCUSE	0
179398	179363	14026U	PARTICIPANT	\N	PRESENT	0
181477	181443	95037J	PARTICIPANT	\N	EXCUSE	0
179400	179363	14121F	PARTICIPANT	\N	PRESENT	0
181478	181443	04057K	PARTICIPANT	\N	EXCUSE	0
179402	179363	14037X	PARTICIPANT	\N	PRESENT	0
181479	181443	08042U	PARTICIPANT	\N	EXCUSE	0
179404	179363	11067R	PARTICIPANT	\N	PRESENT	0
179405	179363	14223L	PARTICIPANT	\N	PRESENT	0
179406	179363	04092N	PRESIDENT	0	PRESENT	0
179407	179363	14265W	PARTICIPANT	\N	PRESENT	0
179408	179363	14119M	PARTICIPANT	\N	PRESENT	0
179409	179363	14071N	PARTICIPANT	\N	EXCUSE	0
181492	181443	95030B	PARTICIPANT	\N	EXCUSE	0
179411	179363	14271U	PARTICIPANT	\N	PRESENT	0
181512	181443	01016M	PARTICIPANT	\N	EXCUSE	0
179413	179363	11093T	PARTICIPANT	\N	PRESENT	0
179414	179363	11097X	PARTICIPANT	\N	PRESENT	0
181593	181592	04036E	PARTICIPANT	\N	PRESENT	0
179416	179363	14227Q	PARTICIPANT	\N	EXCUSE	0
179417	179363	01034P	PARTICIPANT	\N	PRESENT	0
181594	181592	14041T	PARTICIPANT	\N	PRESENT	0
181595	181592	95067Q	PARTICIPANT	\N	PRESENT	0
179420	179363	14269B	PARTICIPANT	\N	PRESENT	0
182817	182816	01031L	PARTICIPANT	\N	PRESENT	0
182818	182816	08011M	PARTICIPANT	\N	PRESENT	0
181598	181592	14217N	PARTICIPANT	\N	PRESENT	0
182819	182816	14083S	PARTICIPANT	\N	PRESENT	0
181600	181592	14215L	PARTICIPANT	\N	PRESENT	0
181601	181592	01027Q	PARTICIPANT	\N	PRESENT	0
182820	182816	88008L	PARTICIPANT	\N	PRESENT	0
182821	182816	08022Q	PARTICIPANT	\N	PRESENT	0
182822	182816	98046X	PARTICIPANT	\N	PRESENT	0
185793	185792	11068S	PARTICIPANT	\N	PRESENT	0
185794	185792	11083R	PARTICIPANT	\N	PRESENT	0
185795	185792	08053X	PARTICIPANT	\N	PRESENT	0
186773	186772	98046X	PARTICIPANT	\N	PRESENT	0
186793	186792	01043Q	PARTICIPANT	\N	PRESENT	0
186794	186792	14081Q	PARTICIPANT	\N	PRESENT	0
186796	186795	04049K	PARTICIPANT	\N	PRESENT	0
186813	186812	08009T	PARTICIPANT	\N	PRESENT	0
186816	186815	08009T	PARTICIPANT	\N	PRESENT	0
186819	186818	08009T	PARTICIPANT	\N	PRESENT	0
186822	186821	08009T	PARTICIPANT	\N	PRESENT	0
186825	186824	95037J	PARTICIPANT	\N	PRESENT	0
186826	186824	14207L	PARTICIPANT	\N	PRESENT	0
186827	186824	14257W	PARTICIPANT	\N	PRESENT	0
186833	186832	14026U	PARTICIPANT	\N	PRESENT	0
186834	186832	14357A	PARTICIPANT	\N	PRESENT	0
197572	197294	04086Q	PARTICIPANT	\N	PRESENT	0
197573	197294	01031L	PRESIDENT	0	PRESENT	0
197574	197294	14083S	PARTICIPANT	\N	PRESENT	0
197575	197294	04071H	PARTICIPANT	\N	PRESENT	0
197576	197294	14085U	PARTICIPANT	\N	PRESENT	0
197577	197294	01048V	PARTICIPANT	\N	PRESENT	0
197578	197294	01057W	PARTICIPANT	\N	PRESENT	0
197579	197294	14159V	PARTICIPANT	\N	PRESENT	0
197580	197294	14225N	PARTICIPANT	\N	PRESENT	0
197581	197294	01013J	PARTICIPANT	\N	PRESENT	0
197582	197294	07029T	PARTICIPANT	\N	EXCUSE	0
197583	197294	11012A	PARTICIPANT	\N	EXCUSE	0
197584	197532	14111D	PARTICIPANT	\N	PRESENT	0
197585	197532	07034Q	PARTICIPANT	\N	PRESENT	0
197586	197532	11026G	PARTICIPANT	\N	PRESENT	0
197587	197532	16813M	PARTICIPANT	\N	PRESENT	0
197588	197532	04047H	PARTICIPANT	\N	PRESENT	0
197589	197532	11033F	PARTICIPANT	\N	PRESENT	0
197590	197532	05008E	PRESIDENT	0	PRESENT	0
197591	197532	95063L	PARTICIPANT	\N	PRESENT	0
197592	197532	04074L	PARTICIPANT	\N	PRESENT	0
197593	197532	04056J	PARTICIPANT	\N	PRESENT	0
197594	197532	14041T	PARTICIPANT	\N	PRESENT	0
197595	197532	08044W	PARTICIPANT	\N	PRESENT	0
197596	197532	14069U	PARTICIPANT	\N	PRESENT	0
197597	197532	14259Y	PARTICIPANT	\N	PRESENT	0
197598	197532	95049N	PARTICIPANT	\N	PRESENT	0
197599	197532	11072N	PARTICIPANT	\N	PRESENT	0
197600	197532	14215L	PARTICIPANT	\N	PRESENT	0
197601	197532	11056N	PARTICIPANT	\N	EXCUSE	0
197602	197532	11037K	PARTICIPANT	\N	EXCUSE	0
197603	197532	04044E	PARTICIPANT	\N	EXCUSE	0
197604	197294	11048N	PARTICIPANT	\N	PRESENT	0
197605	197294	11077T	PARTICIPANT	\N	PRESENT	0
197606	197294	14187A	PARTICIPANT	\N	PRESENT	0
197607	197294	89017R	PARTICIPANT	\N	PRESENT	0
197608	197294	11070L	PARTICIPANT	\N	PRESENT	0
197609	197294	14173T	PARTICIPANT	\N	PRESENT	0
197610	197294	08010L	PARTICIPANT	\N	PRESENT	0
197611	197294	11042G	PARTICIPANT	\N	PRESENT	0
197652	197294	08011M	PARTICIPANT	\N	EXCUSE	0
197912	190786	11056N	PARTICIPANT	\N	PRESENT	0
197913	190786	01015L	PARTICIPANT	\N	PRESENT	0
197997	197943	00003C	PARTICIPANT	\N	EXCUSE	0
197998	190786	88008L	PARTICIPANT	\N	PRESENT	0
198014	190786	14031R	PARTICIPANT	\N	PRESENT	0
198063	197943	11097X	PARTICIPANT	\N	PRESENT	0
198072	197413	98053W	PARTICIPANT	\N	EXCUSE	0
198073	190786	14251Q	PARTICIPANT	\N	PRESENT	0
198074	190786	01048V	PARTICIPANT	\N	PRESENT	0
198075	190786	04057K	PARTICIPANT	\N	PRESENT	0
198076	190786	04067M	PARTICIPANT	\N	PRESENT	0
198077	190786	14173T	PARTICIPANT	\N	PRESENT	0
197072	190782	08024S	PARTICIPANT	\N	PRESENT	0
197555	197554	11026G	PARTICIPANT	\N	PRESENT	0
198432	196738	04040A	PARTICIPANT	\N	PRESENT	0
198534	197952	04067M	PARTICIPANT	\N	PRESENT	0
198535	197952	14087W	PARTICIPANT	\N	PRESENT	0
198552	197493	04047H	RAPPORTEUR_AVIS	\N	PRESENT	0
198632	197512	11048N	PARTICIPANT	\N	PRESENT	0
198633	197512	08034U	PARTICIPANT	\N	PRESENT	0
198634	197512	04034C	PARTICIPANT	\N	PRESENT	0
198635	197512	01016M	PARTICIPANT	\N	PRESENT	0
198636	197512	11053K	PARTICIPANT	\N	PRESENT	0
198637	197512	08011M	PARTICIPANT	\N	PRESENT	0
198638	197512	08014Q	PARTICIPANT	\N	PRESENT	0
198639	197512	14225N	PARTICIPANT	\N	PRESENT	0
198640	197512	11088W	PRESIDENT	0	PRESENT	0
198641	197512	07029T	PARTICIPANT	\N	PRESENT	0
198642	197512	11057P	PARTICIPANT	\N	PRESENT	0
198643	197512	14085U	PARTICIPANT	\N	PRESENT	0
198644	197512	98046X	PARTICIPANT	\N	PRESENT	0
198645	197512	08010L	PARTICIPANT	\N	PRESENT	0
198646	197512	99004R	PARTICIPANT	\N	PRESENT	0
198647	197512	14253S	PARTICIPANT	\N	PRESENT	0
198648	197512	04061F	PARTICIPANT	\N	PRESENT	0
198649	197512	11042G	PARTICIPANT	\N	PRESENT	0
198650	197512	04086Q	PARTICIPANT	\N	EXCUSE	0
198651	197512	01031L	PARTICIPANT	\N	EXCUSE	0
198652	197512	11012A	PARTICIPANT	\N	EXCUSE	0
198653	197512	98053W	PARTICIPANT	\N	EXCUSE	0
198654	197512	89017R	PARTICIPANT	\N	PRESENT	0
198655	197512	11068S	PARTICIPANT	\N	EXCUSE	0
198657	198656	14261S	PARTICIPANT	\N	PRESENT	0
198658	198656	08055A	PARTICIPANT	\N	PRESENT	0
198659	198656	14093U	PARTICIPANT	\N	PRESENT	0
198660	198656	14030Q	PARTICIPANT	\N	PRESENT	0
198774	197892	11090Q	PARTICIPANT	\N	PRESENT	0
198662	198656	08060W	PARTICIPANT	\N	PRESENT	0
198663	198656	11095V	PARTICIPANT	\N	PRESENT	0
198664	198656	14038Y	PARTICIPANT	\N	PRESENT	0
198775	197512	11083R	PARTICIPANT	\N	PRESENT	0
198832	198612	08011M	PARTICIPANT	\N	PRESENT	0
198667	198656	11065P	PARTICIPANT	\N	PRESENT	0
198668	198656	01015L	PARTICIPANT	\N	PRESENT	0
198669	198656	11107G	PARTICIPANT	\N	PRESENT	0
198833	198612	00003C	PARTICIPANT	\N	EXCUSE	0
198671	198656	02002K	PARTICIPANT	\N	PRESENT	0
198672	198656	01022K	PARTICIPANT	\N	PRESENT	0
198852	198066	04070G	PRESIDENT	0	PRESENT	0
198853	198066	12041X	PARTICIPANT	\N	PRESENT	0
198854	198066	14079W	PARTICIPANT	\N	PRESENT	0
198676	198656	11059R	PARTICIPANT	\N	PRESENT	0
198677	198656	14219Q	PARTICIPANT	\N	PRESENT	0
198678	198656	80027E	PARTICIPANT	\N	PRESENT	0
198679	198656	14031R	PARTICIPANT	\N	PRESENT	0
198680	198656	08009T	PRESIDENT	0	PRESENT	0
198681	198656	08062Y	PARTICIPANT	\N	PRESENT	0
198682	198656	14221J	PARTICIPANT	\N	PRESENT	0
198855	198066	11029K	PARTICIPANT	\N	PRESENT	0
198684	198656	08042U	PARTICIPANT	\N	PRESENT	0
198685	198656	14169X	PARTICIPANT	\N	PRESENT	0
198686	198656	14237S	PARTICIPANT	\N	PRESENT	0
198687	198656	13002U	PARTICIPANT	\N	PRESENT	0
198688	198656	05012A	PARTICIPANT	\N	PRESENT	0
198856	198066	14229S	PARTICIPANT	\N	PRESENT	0
198690	198656	14135M	PARTICIPANT	\N	PRESENT	0
198691	198656	14331P	PARTICIPANT	\N	PRESENT	0
198692	198656	95062K	PARTICIPANT	\N	PRESENT	0
198693	198656	14107H	PARTICIPANT	\N	PRESENT	0
198694	198656	14051J	PARTICIPANT	\N	PRESENT	0
198695	198656	14157T	PARTICIPANT	\N	PRESENT	0
198857	198066	11089X	PARTICIPANT	\N	PRESENT	0
198858	198066	14241N	PARTICIPANT	\N	PRESENT	0
198859	198066	83047W	PARTICIPANT	\N	PRESENT	0
198860	198066	08017T	PARTICIPANT	\N	PRESENT	0
198861	198066	08024S	PARTICIPANT	\N	PRESENT	0
198862	198066	14249W	PARTICIPANT	\N	PRESENT	0
198863	198066	08039A	PARTICIPANT	\N	PRESENT	0
198864	198066	08031R	PARTICIPANT	\N	PRESENT	0
198865	198066	07026Q	PARTICIPANT	\N	PRESENT	0
198866	198066	14061L	PARTICIPANT	\N	PRESENT	0
198867	198066	04057K	PARTICIPANT	\N	PRESENT	0
198868	198066	14073Q	PARTICIPANT	\N	PRESENT	0
198869	198066	08043V	PARTICIPANT	\N	PRESENT	0
198870	198066	14089Y	PARTICIPANT	\N	PRESENT	0
198871	198066	14363X	PARTICIPANT	\N	PRESENT	0
198872	198066	04059M	PARTICIPANT	\N	PRESENT	0
198873	198066	14063N	PARTICIPANT	\N	PRESENT	0
198874	198066	14109K	PARTICIPANT	\N	PRESENT	0
198875	198066	14123H	PARTICIPANT	\N	PRESENT	0
198876	198066	14209N	PARTICIPANT	\N	PRESENT	0
198877	198066	14179A	PARTICIPANT	\N	PRESENT	0
198878	198066	92040Q	PARTICIPANT	\N	EXCUSE	0
198879	198066	95015C	PARTICIPANT	\N	EXCUSE	0
198912	198064	14357A	PARTICIPANT	\N	PRESENT	0
198913	198064	11100Y	PRESIDENT	0	PRESENT	0
198914	198064	80013X	PARTICIPANT	\N	PRESENT	0
198915	198064	11066Q	PARTICIPANT	\N	PRESENT	0
198916	198064	90003B	PARTICIPANT	\N	PRESENT	0
198917	198064	11099A	PARTICIPANT	\N	PRESENT	0
198918	198064	11094U	PARTICIPANT	\N	PRESENT	0
198919	198064	08068F	PARTICIPANT	0	PRESENT	0
198920	198064	04049K	PARTICIPANT	\N	PRESENT	0
198921	198064	08015R	PARTICIPANT	\N	PRESENT	0
198922	198064	14197C	PARTICIPANT	\N	PRESENT	0
198923	198064	14187A	PARTICIPANT	\N	PRESENT	0
198924	198064	08038Y	PARTICIPANT	\N	PRESENT	0
198925	198064	11098Y	PARTICIPANT	\N	PRESENT	0
198926	198064	14033T	PARTICIPANT	\N	PRESENT	0
198927	198064	11090Q	PARTICIPANT	\N	PRESENT	0
198928	198064	08055A	PARTICIPANT	\N	PRESENT	0
198929	198064	01008M	PARTICIPANT	\N	PRESENT	0
198930	198064	14205J	PARTICIPANT	\N	PRESENT	0
198931	198064	04088S	PARTICIPANT	\N	PRESENT	0
198932	198064	04089T	PARTICIPANT	\N	PRESENT	0
198933	198064	11111C	PARTICIPANT	\N	PRESENT	0
198934	198064	98050T	PARTICIPANT	\N	PRESENT	0
198935	198064	14207L	PARTICIPANT	0	PRESENT	0
168216	167007	92020L	PARTICIPANT	\N	PRESENT	0
168217	167007	14065Q	PARTICIPANT	\N	PRESENT	0
168218	167007	95059Q	PARTICIPANT	\N	PRESENT	0
168219	167007	11015D	PARTICIPANT	\N	PRESENT	0
168214	167007	08060W	PARTICIPANT	\N	PRESENT	0
168215	167007	07029T	PARTICIPANT	\N	PRESENT	0
168220	167007	04043D	PARTICIPANT	\N	PRESENT	0
168221	167007	08043V	PARTICIPANT	\N	PRESENT	0
168222	167007	08068F	PARTICIPANT	\N	PRESENT	0
168223	167007	11105E	PARTICIPANT	\N	PRESENT	0
168224	167007	14107H	PARTICIPANT	\N	PRESENT	0
168225	167007	01056V	PARTICIPANT	\N	PRESENT	0
168226	167007	08012N	PARTICIPANT	\N	PRESENT	0
168227	167007	11036J	PARTICIPANT	\N	PRESENT	0
168228	167007	14030Q	PARTICIPANT	\N	PRESENT	0
168229	167007	11059R	PARTICIPANT	\N	PRESENT	0
168230	167007	14271U	PARTICIPANT	\N	PRESENT	0
168231	167007	04040A	PARTICIPANT	\N	PRESENT	0
168232	167007	08058D	PARTICIPANT	\N	PRESENT	0
168233	167007	98042T	PARTICIPANT	\N	PRESENT	0
168234	167007	95037J	PARTICIPANT	\N	PRESENT	0
168235	167007	14231L	PARTICIPANT	\N	PRESENT	0
168236	167007	14059S	PARTICIPANT	\N	PRESENT	0
168237	167007	01015L	PARTICIPANT	\N	PRESENT	0
168238	167007	14235Q	PARTICIPANT	\N	PRESENT	0
168239	167007	07004J	PARTICIPANT	\N	PRESENT	0
168240	167007	08018U	PARTICIPANT	\N	PRESENT	0
168241	167007	04092N	PARTICIPANT	\N	PRESENT	0
168242	167007	11070L	PARTICIPANT	\N	PRESENT	0
168243	167007	04034C	PARTICIPANT	\N	PRESENT	0
168244	167007	08011M	PARTICIPANT	\N	PRESENT	0
168245	167007	14255U	PARTICIPANT	\N	PRESENT	0
168246	167007	92040Q	PARTICIPANT	\N	PRESENT	0
168247	167007	11057P	PARTICIPANT	\N	PRESENT	0
168248	167007	08053X	PARTICIPANT	\N	PRESENT	0
168249	167007	04033B	PARTICIPANT	\N	PRESENT	0
168250	167007	08017T	PARTICIPANT	\N	PRESENT	0
168251	167007	14042U	PARTICIPANT	\N	PRESENT	0
168252	167007	83042R	PARTICIPANT	\N	PRESENT	0
168253	167007	11046L	PARTICIPANT	\N	PRESENT	0
168254	167007	98029W	PARTICIPANT	\N	PRESENT	0
168255	167007	01047U	PARTICIPANT	\N	PRESENT	0
168256	167007	14135M	PARTICIPANT	\N	PRESENT	0
168257	167007	04050C	PARTICIPANT	\N	PRESENT	0
168258	167007	08009T	PARTICIPANT	\N	PRESENT	0
168259	167007	11089X	PARTICIPANT	\N	PRESENT	0
168260	167007	14014Q	PARTICIPANT	\N	PRESENT	0
168261	167007	11053K	PARTICIPANT	\N	PRESENT	0
168262	167007	14207L	PARTICIPANT	\N	PRESENT	0
168263	167007	05012A	PARTICIPANT	\N	PRESENT	0
168264	167007	08014Q	PARTICIPANT	\N	PRESENT	0
168265	167007	14001X	PARTICIPANT	\N	PRESENT	0
168266	167007	14227Q	PARTICIPANT	\N	PRESENT	0
168267	167007	01034P	PARTICIPANT	\N	PRESENT	0
168268	167007	14167V	PARTICIPANT	\N	PRESENT	0
168269	167007	11054L	PARTICIPANT	\N	PRESENT	0
168270	167007	14229S	PARTICIPANT	\N	PRESENT	0
168271	167007	11109J	PARTICIPANT	\N	PRESENT	0
168272	167007	11037K	PARTICIPANT	\N	PRESENT	0
168273	167007	11061K	PARTICIPANT	\N	PRESENT	0
168274	167007	83047W	PARTICIPANT	\N	PRESENT	0
168275	167007	80027E	PARTICIPANT	\N	PRESENT	0
168276	167007	01028R	PARTICIPANT	\N	PRESENT	0
168277	167007	01024M	PARTICIPANT	\N	PRESENT	0
168278	167007	14281W	PARTICIPANT	\N	PRESENT	0
168279	167007	14109K	PARTICIPANT	\N	PRESENT	0
168280	167007	14225N	PARTICIPANT	\N	PRESENT	0
168281	167007	14121F	PARTICIPANT	\N	PRESENT	0
168282	167007	08061X	PARTICIPANT	\N	PRESENT	0
168283	167007	14063N	PARTICIPANT	\N	PRESENT	0
168284	167007	14205J	PARTICIPANT	\N	PRESENT	0
168285	167007	11074Q	PARTICIPANT	\N	PRESENT	0
168286	167007	11112D	PARTICIPANT	\N	PRESENT	0
168287	167007	04077P	PARTICIPANT	\N	PRESENT	0
168288	167007	14097Y	PARTICIPANT	\N	PRESENT	0
168289	167007	14257W	PARTICIPANT	\N	PRESENT	0
168290	167007	04053F	PARTICIPANT	\N	PRESENT	0
168291	167007	11104D	PARTICIPANT	\N	PRESENT	0
168292	167007	11110B	PARTICIPANT	\N	PRESENT	0
168293	167007	14267Y	PARTICIPANT	\N	PRESENT	0
168294	167007	08038Y	PARTICIPANT	\N	PRESENT	0
168295	167007	92039X	PARTICIPANT	\N	PRESENT	0
168296	167007	04059M	PARTICIPANT	\N	PRESENT	0
168297	167007	08024S	PARTICIPANT	\N	PRESENT	0
168298	167007	14087W	PARTICIPANT	\N	PRESENT	0
168299	167007	14073Q	PARTICIPANT	\N	PRESENT	0
168300	167007	11066Q	PARTICIPANT	\N	PRESENT	0
168301	167007	14215L	PARTICIPANT	\N	PRESENT	0
168302	167007	11067R	PARTICIPANT	\N	PRESENT	0
168303	167007	14083S	PARTICIPANT	\N	PRESENT	0
168304	167007	04061F	PARTICIPANT	\N	PRESENT	0
168806	167008	14059S	PARTICIPANT	\N	PRESENT	0
168807	167008	14273W	PARTICIPANT	\N	PRESENT	0
168808	167008	11090Q	PARTICIPANT	\N	PRESENT	0
168809	167008	14193X	PARTICIPANT	\N	PRESENT	0
168810	167008	14105F	PARTICIPANT	\N	PRESENT	0
168811	167008	14187A	PARTICIPANT	\N	PRESENT	0
168812	167008	04057K	PARTICIPANT	\N	PRESENT	0
168813	167008	14357A	PARTICIPANT	\N	PRESENT	0
168814	167008	14265W	PARTICIPANT	\N	PRESENT	0
168815	167008	14123H	PARTICIPANT	\N	PRESENT	0
168816	167008	14097Y	PARTICIPANT	\N	PRESENT	0
168832	167008	08010L	PARTICIPANT	\N	PRESENT	0
168833	167008	14103D	PARTICIPANT	\N	PRESENT	0
168834	167008	14065Q	PARTICIPANT	\N	PRESENT	0
168835	167008	04088S	PARTICIPANT	\N	PRESENT	0
168836	167008	14111D	PARTICIPANT	\N	PRESENT	0
168837	167008	01058X	PARTICIPANT	\N	PRESENT	0
168838	167008	14209N	PARTICIPANT	\N	PRESENT	0
168841	167008	14363X	PARTICIPANT	\N	PRESENT	0
168842	167008	01022K	PARTICIPANT	\N	PRESENT	0
168843	167008	08060W	PARTICIPANT	\N	PRESENT	0
168844	167008	14147R	PARTICIPANT	\N	PRESENT	0
168845	167008	95030B	PARTICIPANT	\N	PRESENT	0
168846	167008	14253S	PARTICIPANT	\N	PRESENT	0
168847	167008	11042G	PARTICIPANT	\N	PRESENT	0
168849	167008	95067Q	PARTICIPANT	\N	PRESENT	0
168850	167008	01025N	PARTICIPANT	\N	PRESENT	0
168851	167008	14038Y	PARTICIPANT	\N	PRESENT	0
168852	167008	01056V	PARTICIPANT	\N	PRESENT	0
168853	167008	11048N	PARTICIPANT	\N	PRESENT	0
168854	167008	02002K	PARTICIPANT	\N	PRESENT	0
168855	167008	11043H	PARTICIPANT	\N	PRESENT	0
168856	167008	08043V	PARTICIPANT	\N	PRESENT	0
168857	167008	95049N	PARTICIPANT	\N	PRESENT	0
168858	167008	14033T	PARTICIPANT	\N	PRESENT	0
168859	167008	14026U	PARTICIPANT	\N	PRESENT	0
168860	167008	11036J	PARTICIPANT	\N	PRESENT	0
168861	167008	11059R	PARTICIPANT	\N	PRESENT	0
168862	167008	05008E	PARTICIPANT	\N	PRESENT	0
168863	167008	14087W	PARTICIPANT	\N	PRESENT	0
168864	167008	14014Q	PARTICIPANT	\N	PRESENT	0
168872	167008	14215L	PARTICIPANT	\N	PRESENT	0
168873	167008	14199E	PARTICIPANT	\N	PRESENT	0
168874	167008	04049K	PARTICIPANT	\N	PRESENT	0
168875	167008	14213J	PARTICIPANT	\N	PRESENT	0
168876	167008	08015R	PARTICIPANT	\N	PRESENT	0
168877	167008	14157T	PARTICIPANT	\N	PRESENT	0
168878	167008	11097X	PARTICIPANT	\N	PRESENT	0
168879	167008	11064N	PARTICIPANT	\N	PRESENT	0
170172	167375	04033B	PARTICIPANT	\N	PRESENT	0
170292	159438	04057K	PARTICIPANT	\N	PRESENT	0
170313	170312	04040A	PARTICIPANT	\N	PRESENT	0
170314	170312	11032E	PARTICIPANT	\N	PRESENT	0
170352	157437	11109J	PARTICIPANT	\N	PRESENT	0
170353	157437	11023D	PARTICIPANT	\N	PRESENT	0
170354	157437	11064N	PARTICIPANT	\N	PRESENT	0
170355	157437	14039A	PARTICIPANT	\N	PRESENT	0
170356	157437	14033T	PARTICIPANT	\N	PRESENT	0
170357	157437	14097Y	PARTICIPANT	\N	PRESENT	0
170358	157437	08019V	PARTICIPANT	\N	EXCUSE	0
170359	157437	11072N	PRESIDENT	0	PRESENT	0
170360	157437	96004D	PARTICIPANT	\N	EXCUSE	0
170362	157437	08065C	PARTICIPANT	\N	EXCUSE	0
170363	157437	11010L	PARTICIPANT	\N	EXCUSE	0
170365	157437	04094Q	PARTICIPANT	\N	EXCUSE	0
170366	157437	98005N	PARTICIPANT	\N	EXCUSE	0
170367	157437	14219Q	PARTICIPANT	\N	EXCUSE	0
170368	157437	14059S	PARTICIPANT	\N	EXCUSE	0
170369	157437	11106F	PARTICIPANT	\N	EXCUSE	0
170370	157437	95062K	PARTICIPANT	\N	EXCUSE	0
170371	157437	14017T	PARTICIPANT	\N	EXCUSE	0
170374	157437	11054L	PARTICIPANT	\N	EXCUSE	0
170375	157438	05001W	PARTICIPANT	\N	EXCUSE	0
170433	170432	96004D	PRESIDENT	0	PRESENT	0
170434	170432	11040E	PARTICIPANT	\N	PRESENT	0
170435	170432	14089Y	PARTICIPANT	\N	PRESENT	0
170436	170432	90003B	PARTICIPANT	\N	PRESENT	0
170437	170432	14079W	PARTICIPANT	\N	PRESENT	0
193126	192759	14275Y	PARTICIPANT	\N	PRESENT	0
193127	192759	11037K	PARTICIPANT	\N	PRESENT	0
193128	192759	04056J	PARTICIPANT	\N	PRESENT	0
193129	192759	14041T	PARTICIPANT	\N	PRESENT	0
193130	192759	14069U	PARTICIPANT	\N	PRESENT	0
193131	192759	14215L	PARTICIPANT	\N	PRESENT	0
193132	192759	14259Y	PARTICIPANT	\N	PRESENT	0
193133	192759	95049N	PARTICIPANT	\N	PRESENT	0
193134	192759	11056N	PARTICIPANT	\N	EXCUSE	0
196314	192492	98005N	PARTICIPANT	\N	PRESENT	0
196276	192774	01031L	PRESIDENT	0	PRESENT	0
196277	192774	04034C	PARTICIPANT	\N	PRESENT	0
196278	192774	01057W	PARTICIPANT	\N	PRESENT	0
196279	192774	01016M	PARTICIPANT	\N	PRESENT	0
196280	192774	11074Q	PARTICIPANT	\N	PRESENT	0
196281	192774	01027Q	PARTICIPANT	\N	PRESENT	0
196282	192774	08014Q	PARTICIPANT	\N	PRESENT	0
196283	192774	14159V	PARTICIPANT	\N	PRESENT	0
196284	192774	88008L	PARTICIPANT	\N	PRESENT	0
196285	192774	04086Q	PARTICIPANT	\N	PRESENT	0
196286	192774	11040E	PARTICIPANT	\N	PRESENT	0
196287	192774	14083S	PARTICIPANT	\N	PRESENT	0
196288	192774	11083R	PARTICIPANT	\N	PRESENT	0
196289	192774	14253S	PARTICIPANT	\N	PRESENT	0
196290	192774	11042G	PARTICIPANT	\N	PRESENT	0
196291	192774	01013J	PARTICIPANT	\N	PRESENT	0
196292	192774	07029T	PARTICIPANT	\N	EXCUSE	0
196294	192492	77002U	PARTICIPANT	\N	PRESENT	0
196295	192492	83042R	PARTICIPANT	\N	PRESENT	0
196296	192492	95059Q	PRESIDENT	0	PRESENT	0
196297	192492	14133K	PARTICIPANT	\N	PRESENT	0
196298	192492	01056V	PARTICIPANT	\N	PRESENT	0
196299	192492	11041F	PARTICIPANT	\N	PRESENT	0
196300	192492	08058D	PARTICIPANT	\N	PRESENT	0
196301	192492	11054L	PARTICIPANT	\N	PRESENT	0
196302	192492	04042C	PRESIDENT	1	PRESENT	0
196303	192492	95035G	PARTICIPANT	\N	PRESENT	0
196304	192492	04078Q	PARTICIPANT	\N	PRESENT	0
196305	192492	04036E	PARTICIPANT	\N	PRESENT	0
196306	192492	98018T	PARTICIPANT	\N	PRESENT	0
196307	192492	98021N	PARTICIPANT	\N	PRESENT	0
196308	192492	98022P	PARTICIPANT	\N	PRESENT	0
196309	192492	14193X	PARTICIPANT	\N	PRESENT	0
196310	192492	86044G	PARTICIPANT	\N	PRESENT	0
196311	192492	14211G	PARTICIPANT	\N	PRESENT	0
196312	192492	11076S	PARTICIPANT	\N	PRESENT	0
196313	192492	08047A	PARTICIPANT	\N	PRESENT	0
196315	192492	95030B	PARTICIPANT	\N	PRESENT	0
196316	192492	04040A	PARTICIPANT	\N	PRESENT	0
196317	192492	08065C	PARTICIPANT	\N	PRESENT	0
196318	192492	07004J	PARTICIPANT	\N	PRESENT	0
196319	192492	08049C	PARTICIPANT	\N	PRESENT	0
196320	192492	97011G	PARTICIPANT	\N	PRESENT	0
196321	192492	14097Y	PARTICIPANT	\N	PRESENT	0
196322	192492	11105E	PARTICIPANT	\N	PRESENT	0
196323	192760	11034G	PARTICIPANT	\N	PRESENT	0
196324	192760	14001X	PARTICIPANT	\N	PRESENT	0
196325	192760	04044E	PARTICIPANT	\N	PRESENT	0
196326	192760	04047H	PARTICIPANT	\N	PRESENT	0
196327	192760	01028R	PARTICIPANT	\N	PRESENT	0
196328	192760	05008E	PRESIDENT	0	PRESENT	0
196329	192760	04079R	PARTICIPANT	\N	PRESENT	0
196330	192760	08025T	PARTICIPANT	\N	PRESENT	0
196331	192760	92045V	PARTICIPANT	\N	PRESENT	0
196332	192760	14041T	PARTICIPANT	\N	PRESENT	0
196333	192760	14147R	PARTICIPANT	\N	PRESENT	0
196334	192760	14215L	PARTICIPANT	\N	PRESENT	0
196335	192760	14259Y	PARTICIPANT	\N	PRESENT	0
196336	192760	98035U	PARTICIPANT	\N	PRESENT	0
196337	192760	14111D	PARTICIPANT	\N	PRESENT	0
196338	192760	14065Q	PARTICIPANT	\N	PRESENT	0
196339	192760	95067Q	PARTICIPANT	\N	PRESENT	0
196340	192760	07034Q	PRESIDENT	1	PRESENT	0
196341	192760	10015M	PARTICIPANT	\N	PRESENT	0
196342	192760	11026G	PARTICIPANT	\N	PRESENT	0
196343	192760	19253P	PARTICIPANT	\N	PRESENT	0
196344	192760	01024M	PARTICIPANT	\N	PRESENT	0
196345	192760	19251M	PARTICIPANT	\N	PRESENT	0
196346	192760	04038G	PARTICIPANT	\N	PRESENT	0
196347	192760	11033F	PARTICIPANT	\N	PRESENT	0
196348	192760	11056N	PARTICIPANT	\N	PRESENT	0
196349	192760	04074L	PARTICIPANT	\N	PRESENT	0
196350	192760	11037K	PARTICIPANT	\N	PRESENT	0
196351	192760	04056J	PARTICIPANT	\N	PRESENT	0
196352	192760	14069U	PARTICIPANT	\N	PRESENT	0
196353	192760	95049N	PARTICIPANT	\N	PRESENT	0
196354	192492	04077P	PARTICIPANT	\N	PRESENT	0
196355	192492	08056B	PARTICIPANT	\N	PRESENT	0
196356	192492	14028W	PARTICIPANT	\N	PRESENT	0
196357	192492	14251Q	PARTICIPANT	\N	PRESENT	0
196358	192492	11064N	PARTICIPANT	\N	PRESENT	0
196359	192492	92020L	PARTICIPANT	\N	PRESENT	0
196360	192492	11027H	PARTICIPANT	\N	PRESENT	0
196361	192492	95037J	PARTICIPANT	\N	PRESENT	0
196362	192492	98029W	PARTICIPANT	\N	PRESENT	0
196363	192772	08034U	PARTICIPANT	\N	EXCUSE	0
196364	192492	04054G	PARTICIPANT	\N	PRESENT	0
196365	192492	92031P	PARTICIPANT	\N	PRESENT	0
196366	192492	92018S	PARTICIPANT	\N	PRESENT	0
196367	192772	14028W	PARTICIPANT	\N	EXCUSE	0
196368	192772	11098Y	PARTICIPANT	\N	EXCUSE	0
196369	192772	11112D	PARTICIPANT	\N	EXCUSE	0
196370	192772	08010L	PARTICIPANT	\N	EXCUSE	0
196372	192492	11096W	PARTICIPANT	\N	PRESENT	0
196373	192492	04035D	PARTICIPANT	\N	PRESENT	0
196374	192492	11082Q	PARTICIPANT	\N	PRESENT	0
196375	192760	01047U	PARTICIPANT	\N	PRESENT	0
196376	192760	95063L	PARTICIPANT	\N	PRESENT	0
196377	192760	08044W	PARTICIPANT	\N	PRESENT	0
196378	192760	11030C	PARTICIPANT	\N	PRESENT	0
196379	192492	01014K	PARTICIPANT	\N	PRESENT	0
196613	190781	11099A	PARTICIPANT	\N	PRESENT	0
196614	190781	19251M	PARTICIPANT	\N	PRESENT	0
196615	190781	11067R	PARTICIPANT	\N	PRESENT	0
196616	190781	08009T	PARTICIPANT	\N	PRESENT	0
196617	190781	14327T	PARTICIPANT	\N	PRESENT	0
196618	190781	14231L	PARTICIPANT	\N	PRESENT	0
196619	190781	07004J	PARTICIPANT	\N	PRESENT	0
196620	190781	01028R	PARTICIPANT	\N	PRESENT	0
196621	190781	14030Q	PARTICIPANT	\N	PRESENT	0
196622	190781	01025N	PARTICIPANT	\N	PRESENT	0
196623	190781	99004R	PARTICIPANT	\N	PRESENT	0
196624	190781	04086Q	PARTICIPANT	\N	PRESENT	0
196625	190781	14211G	PARTICIPANT	\N	PRESENT	0
196626	190781	14223L	PARTICIPANT	\N	PRESENT	0
196627	190781	14147R	PARTICIPANT	\N	PRESENT	0
196628	190781	14059S	PARTICIPANT	\N	PRESENT	0
196629	190781	14215L	PARTICIPANT	\N	PRESENT	0
196630	190781	14133K	PARTICIPANT	\N	PRESENT	0
196631	190781	14199E	PARTICIPANT	\N	PRESENT	0
196632	190781	14105F	PARTICIPANT	\N	PRESENT	0
196633	190781	04074L	PARTICIPANT	\N	PRESENT	0
196634	190781	08034U	PARTICIPANT	\N	PRESENT	0
196635	190781	14357A	PARTICIPANT	\N	PRESENT	0
196636	190781	04088S	PARTICIPANT	\N	PRESENT	0
196637	190781	14135M	PARTICIPANT	\N	PRESENT	0
196638	190781	14033T	PARTICIPANT	\N	PRESENT	0
196639	190781	14205J	PARTICIPANT	\N	PRESENT	0
196640	190781	08015R	PARTICIPANT	\N	PRESENT	0
196641	190781	14079W	PARTICIPANT	\N	PRESENT	0
196642	190781	08041T	PARTICIPANT	\N	PRESENT	0
196643	190781	95037J	PARTICIPANT	\N	PRESENT	0
196644	190781	14251Q	PARTICIPANT	\N	PRESENT	0
196645	190781	11026G	PARTICIPANT	\N	PRESENT	0
196646	190781	11015D	PARTICIPANT	\N	PRESENT	0
196647	190781	98022P	PARTICIPANT	\N	PRESENT	0
196648	190781	14265W	PARTICIPANT	\N	PRESENT	0
196649	190781	14217N	PARTICIPANT	\N	PRESENT	0
196650	190781	14269B	PARTICIPANT	\N	PRESENT	0
196651	190781	14207L	PARTICIPANT	\N	PRESENT	0
196652	190781	14261S	PARTICIPANT	\N	PRESENT	0
196653	190781	14187A	PARTICIPANT	\N	PRESENT	0
196654	190781	11091R	PARTICIPANT	\N	PRESENT	0
196655	190781	04043D	PARTICIPANT	\N	PRESENT	0
196656	190781	98042T	PARTICIPANT	\N	PRESENT	0
196657	190781	14061L	PARTICIPANT	\N	PRESENT	0
196658	190781	08052W	PARTICIPANT	\N	PRESENT	0
196660	190781	11011M	PARTICIPANT	\N	PRESENT	0
196661	190781	14157T	PARTICIPANT	\N	PRESENT	0
196662	190781	08073C	PARTICIPANT	\N	PRESENT	0
196702	190781	89017R	PARTICIPANT	\N	PRESENT	0
196703	190781	14241N	PARTICIPANT	\N	PRESENT	0
196704	190781	08017T	PARTICIPANT	\N	PRESENT	0
196705	190781	11074Q	PARTICIPANT	\N	PRESENT	0
196712	190781	01008M	PARTICIPANT	\N	PRESENT	0
196713	190781	12042Y	PARTICIPANT	\N	PRESENT	0
196714	190781	14271U	PARTICIPANT	\N	PRESENT	0
196715	190781	98023Q	PARTICIPANT	\N	PRESENT	0
196718	190781	14053L	PARTICIPANT	\N	PRESENT	0
177293	177292	14239U	PARTICIPANT	\N	PRESENT	0
177294	177292	08043V	PARTICIPANT	\N	PRESENT	0
177295	177292	14195A	PARTICIPANT	\N	PRESENT	0
177296	177292	08052W	PRESIDENT	0	PRESENT	0
177297	177292	14217N	PARTICIPANT	\N	PRESENT	0
177298	177292	11061K	PARTICIPANT	\N	PRESENT	0
177299	177292	14213J	PARTICIPANT	\N	PRESENT	0
177300	177292	14147R	PARTICIPANT	\N	PRESENT	0
177301	177292	14223L	PARTICIPANT	\N	PRESENT	0
177302	177292	04092N	PRESIDENT	1	PRESENT	0
177303	177292	11097X	PARTICIPANT	\N	PRESENT	0
177304	177292	11094U	PARTICIPANT	\N	PRESENT	0
177329	177292	11055M	PARTICIPANT	\N	EXCUSE	0
179272	177613	08025T	PARTICIPANT	\N	PRESENT	0
179273	177613	04085P	PARTICIPANT	\N	PRESENT	0
179274	177613	05008E	PRESIDENT	0	PRESENT	0
179275	177613	11030C	PARTICIPANT	\N	PRESENT	0
179321	177614	11010L	PARTICIPANT	\N	EXCUSE	0
179277	177613	14065Q	PARTICIPANT	\N	PRESENT	0
179278	177613	14069U	PARTICIPANT	\N	PRESENT	0
179279	177613	04047H	PARTICIPANT	\N	PRESENT	0
186835	186832	14207L	PARTICIPANT	\N	PRESENT	0
179281	177613	04038G	PARTICIPANT	\N	PRESENT	0
186836	186832	14257W	PARTICIPANT	\N	PRESENT	0
179283	177613	11056N	PARTICIPANT	\N	PRESENT	0
179284	177613	14259Y	PARTICIPANT	\N	PRESENT	0
186853	186852	04049K	PARTICIPANT	\N	PRESENT	0
179286	177613	14041T	PARTICIPANT	\N	PRESENT	0
186854	186852	14083S	PARTICIPANT	\N	PRESENT	0
179288	177613	01024M	PARTICIPANT	\N	PRESENT	0
179289	177613	14215L	PARTICIPANT	\N	PRESENT	0
186855	186852	14157T	PARTICIPANT	\N	PRESENT	0
186856	186852	14105F	PARTICIPANT	\N	PRESENT	0
179292	177613	11010L	PARTICIPANT	\N	EXCUSE	0
179293	177613	01007L	PARTICIPANT	\N	PRESENT	0
179294	177613	11049P	PARTICIPANT	\N	PRESENT	0
179295	177613	08044W	PARTICIPANT	\N	PRESENT	0
179296	177613	11084S	PARTICIPANT	\N	PRESENT	0
179297	177613	11026G	PARTICIPANT	\N	PRESENT	0
179298	177613	04079R	PARTICIPANT	\N	PRESENT	0
179299	177613	14111D	PARTICIPANT	\N	PRESENT	0
179300	177613	14001X	PARTICIPANT	\N	PRESENT	0
186857	186852	14061L	PARTICIPANT	\N	PRESENT	0
179302	177613	01060R	PARTICIPANT	\N	PRESENT	0
179303	177613	14147R	PARTICIPANT	\N	PRESENT	0
179304	177613	95049N	PARTICIPANT	\N	PRESENT	0
179305	177613	08051V	PARTICIPANT	\N	PRESENT	0
186858	186852	14265W	PARTICIPANT	\N	PRESENT	0
179307	177613	07034Q	PARTICIPANT	\N	PRESENT	0
179308	177613	04074L	PARTICIPANT	\N	PRESENT	0
186859	186852	14253S	PARTICIPANT	\N	PRESENT	0
179310	177613	95063L	PARTICIPANT	\N	PRESENT	0
186861	186860	04049K	PARTICIPANT	\N	PRESENT	0
179312	177613	01028R	PARTICIPANT	\N	PRESENT	0
186862	186860	14083S	PARTICIPANT	\N	PRESENT	0
179314	177613	04056J	PARTICIPANT	\N	PRESENT	0
186863	186860	14157T	PARTICIPANT	\N	PRESENT	0
179316	177613	04044E	PARTICIPANT	\N	PRESENT	0
179317	177613	11037K	PARTICIPANT	\N	PRESENT	0
179318	177613	92045V	PARTICIPANT	\N	PRESENT	0
186864	186860	08014Q	PARTICIPANT	\N	PRESENT	0
179320	177613	01047U	PARTICIPANT	\N	PRESENT	0
186865	186860	14105F	PARTICIPANT	\N	PRESENT	0
186866	186860	14061L	PARTICIPANT	\N	PRESENT	0
186867	186860	14265W	PARTICIPANT	\N	PRESENT	0
186868	186860	14253S	PARTICIPANT	\N	PRESENT	0
186872	184239	14042U	PARTICIPANT	\N	PRESENT	0
188715	188695	01031L	PARTICIPANT	\N	PRESENT	0
191753	191752	14255U	PARTICIPANT	\N	EXCUSE	0
188115	188112	14093U	PARTICIPANT	\N	PRESENT	0
188116	188112	14030Q	PARTICIPANT	\N	EXCUSE	0
191754	191752	00003C	PARTICIPANT	\N	EXCUSE	0
188118	188112	08060W	PARTICIPANT	\N	EXCUSE	0
191755	191752	14034U	PARTICIPANT	\N	EXCUSE	0
191756	191752	14231L	PARTICIPANT	\N	EXCUSE	0
188121	188112	11114F	PARTICIPANT	\N	PRESENT	0
191757	191752	14017T	PARTICIPANT	\N	EXCUSE	0
188123	188112	11065P	PARTICIPANT	\N	PRESENT	0
188124	188112	01015L	PARTICIPANT	\N	EXCUSE	0
188125	188112	11107G	PARTICIPANT	\N	PRESENT	0
191758	191752	11093T	PARTICIPANT	\N	EXCUSE	0
188127	188112	02002K	PARTICIPANT	\N	PRESENT	0
191759	191752	11063M	PARTICIPANT	\N	EXCUSE	0
188129	188112	05001W	PARTICIPANT	\N	EXCUSE	0
188130	188112	04097T	PARTICIPANT	\N	EXCUSE	0
191760	191752	11103C	PARTICIPANT	\N	PRESENT	0
188132	188112	11059R	PARTICIPANT	\N	EXCUSE	0
188133	188112	14219Q	PARTICIPANT	\N	EXCUSE	0
191761	191752	14195A	PARTICIPANT	\N	PRESENT	0
188135	188112	14031R	PARTICIPANT	\N	EXCUSE	0
188136	188112	08009T	PRESIDENT	0	PRESENT	0
188137	188112	08062Y	PARTICIPANT	\N	EXCUSE	0
191762	191752	11023D	PARTICIPANT	\N	PRESENT	0
191763	191752	11031D	PARTICIPANT	\N	PRESENT	0
188140	188112	08042U	PARTICIPANT	\N	EXCUSE	0
188141	188112	14169X	PARTICIPANT	\N	PRESENT	0
191764	191752	08052W	PARTICIPANT	\N	PRESENT	0
191765	191752	01059Y	PARTICIPANT	\N	PRESENT	0
188144	188112	05012A	PARTICIPANT	\N	PRESENT	0
191766	191752	98024R	PARTICIPANT	\N	PRESENT	0
188146	188112	14135M	PARTICIPANT	\N	PRESENT	0
188147	188112	14331P	PARTICIPANT	\N	PRESENT	0
191767	191752	14217N	PARTICIPANT	\N	PRESENT	0
188149	188112	14107H	PARTICIPANT	\N	EXCUSE	0
188150	188112	14051J	PARTICIPANT	\N	PRESENT	0
191768	191752	12042Y	PARTICIPANT	\N	PRESENT	0
191769	191752	14281W	PARTICIPANT	\N	PRESENT	0
191770	191752	14355X	PARTICIPANT	\N	PRESENT	0
191771	191752	08048B	PARTICIPANT	\N	PRESENT	0
191772	191752	08041T	PARTICIPANT	\N	PRESENT	0
191773	191752	14026U	PARTICIPANT	\N	PRESENT	0
191774	191752	14213J	PARTICIPANT	\N	PRESENT	0
191775	191752	14223L	PARTICIPANT	\N	PRESENT	0
191776	191752	04092N	PRESIDENT	0	PRESENT	0
191777	191752	14119M	PARTICIPANT	\N	PRESENT	0
191778	191752	14071N	PARTICIPANT	\N	PRESENT	0
191779	191752	14271U	PARTICIPANT	\N	PRESENT	0
191780	191752	11097X	PARTICIPANT	\N	PRESENT	0
191781	191752	04045F	PARTICIPANT	\N	PRESENT	0
191782	191752	14227Q	PARTICIPANT	\N	PRESENT	0
191783	191752	14269B	PARTICIPANT	\N	PRESENT	0
191784	191752	08010L	PARTICIPANT	\N	PRESENT	0
192125	190533	04053F	PARTICIPANT	\N	PRESENT	0
192131	190533	14053L	PARTICIPANT	\N	PRESENT	0
192132	190533	14195A	PARTICIPANT	\N	PRESENT	0
192134	190533	14267Y	PARTICIPANT	\N	PRESENT	0
192136	190533	08052W	PARTICIPANT	\N	PRESENT	0
192137	190533	10006L	PARTICIPANT	\N	PRESENT	0
192138	190533	14217N	PARTICIPANT	\N	PRESENT	0
192139	190533	14151M	PARTICIPANT	\N	PRESENT	0
192141	190533	12042Y	PARTICIPANT	\N	PRESENT	0
192142	190533	14281W	PARTICIPANT	\N	PRESENT	0
192144	190533	14034U	PARTICIPANT	\N	PRESENT	0
192147	190533	11061K	PARTICIPANT	\N	PRESENT	0
192148	190533	08048B	PARTICIPANT	\N	PRESENT	0
192149	190533	08041T	PARTICIPANT	\N	PRESENT	0
192150	190533	14026U	PARTICIPANT	\N	PRESENT	0
192151	190533	14213J	PARTICIPANT	\N	PRESENT	0
192152	190533	14223L	PARTICIPANT	\N	PRESENT	0
192153	190533	04092N	PARTICIPANT	\N	PRESENT	0
192154	190533	14265W	PARTICIPANT	\N	PRESENT	0
192155	190533	14071N	PARTICIPANT	\N	PRESENT	0
192156	190533	14271U	PARTICIPANT	\N	PRESENT	0
192157	190533	11097X	PARTICIPANT	\N	PRESENT	0
192158	190533	04045F	PARTICIPANT	\N	PRESENT	0
192159	190533	01034P	PARTICIPANT	\N	PRESENT	0
192160	190533	14269B	PARTICIPANT	\N	PRESENT	0
192753	192752	11074Q	PARTICIPANT	\N	PRESENT	0
192755	192752	07034Q	PARTICIPANT	\N	PRESENT	0
192754	192752	04056J	PARTICIPANT	\N	PRESENT	0
192214	190533	14042U	PARTICIPANT	\N	PRESENT	0
192215	190533	14119M	PARTICIPANT	\N	PRESENT	0
192216	190533	14087W	PARTICIPANT	\N	PRESENT	0
192756	192752	11091R	PARTICIPANT	\N	PRESENT	0
192773	192772	04040A	PRESIDENT	0	PRESENT	0
192834	192832	11036J	PARTICIPANT	\N	PRESENT	0
192835	192832	14093U	PARTICIPANT	\N	PRESENT	0
192836	192832	96004D	PARTICIPANT	\N	PRESENT	0
192837	192832	14105F	PARTICIPANT	\N	PRESENT	0
192838	192832	14207L	PARTICIPANT	\N	PRESENT	0
192839	192832	11103C	PARTICIPANT	\N	PRESENT	0
192840	192832	90003B	PARTICIPANT	\N	PRESENT	0
192841	192832	14209N	PARTICIPANT	\N	PRESENT	0
192842	192832	14079W	PARTICIPANT	\N	PRESENT	0
192843	192832	04089T	PARTICIPANT	\N	PRESENT	0
192844	192832	14199E	PARTICIPANT	\N	PRESENT	0
192845	192832	14033T	PARTICIPANT	\N	PRESENT	0
192846	192832	01022K	PARTICIPANT	\N	PRESENT	0
192847	192832	11112D	PARTICIPANT	\N	PRESENT	0
198936	198064	14257W	PARTICIPANT	\N	PRESENT	0
198937	198064	01058X	PARTICIPANT	\N	EXCUSE	0
198938	198064	01061S	PARTICIPANT	\N	EXCUSE	0
199052	197996	11112D	PARTICIPANT	\N	PRESENT	0
199072	190790	04040A	PARTICIPANT	\N	PRESENT	0
199073	190790	19253P	PARTICIPANT	\N	PRESENT	0
199074	190790	14261S	PARTICIPANT	\N	PRESENT	0
199075	190790	11037K	PARTICIPANT	\N	PRESENT	0
199076	190790	11084S	PARTICIPANT	\N	PRESENT	0
199092	190790	04057K	PARTICIPANT	\N	PRESENT	0
199093	190790	04043D	PARTICIPANT	\N	PRESENT	0
199094	190790	08018U	PARTICIPANT	\N	PRESENT	0
199095	190790	01027Q	PARTICIPANT	\N	PRESENT	0
199132	190790	08010L	PARTICIPANT	\N	PRESENT	0
199133	190790	14039A	PARTICIPANT	\N	PRESENT	0
199134	190790	14187A	PARTICIPANT	\N	PRESENT	0
199135	190790	04088S	PARTICIPANT	\N	PRESENT	0
199152	190790	01048V	PARTICIPANT	\N	PRESENT	0
199153	190790	80013X	PARTICIPANT	\N	PRESENT	0
199172	190790	11067R	PARTICIPANT	\N	PRESENT	0
199173	190790	08031R	PARTICIPANT	\N	PRESENT	0
199174	190790	95063L	PARTICIPANT	\N	PRESENT	0
199199	190790	14223L	PARTICIPANT	\N	PRESENT	0
199200	190790	14159V	PARTICIPANT	\N	PRESENT	0
199212	190790	14193X	PARTICIPANT	\N	PRESENT	0
199213	190790	11097X	PARTICIPANT	\N	PRESENT	0
199214	190790	14225N	PARTICIPANT	\N	PRESENT	0
199215	190790	04061F	PARTICIPANT	\N	PRESENT	0
199216	190790	14071N	PARTICIPANT	\N	PRESENT	0
199217	190790	95035G	PARTICIPANT	\N	PRESENT	0
199235	199234	96004D	PRESIDENT	0	PRESENT	0
199236	199234	14089Y	PARTICIPANT	\N	PRESENT	0
199237	199234	90003B	PARTICIPANT	\N	EXCUSE	0
199238	199234	14079W	PARTICIPANT	\N	PRESENT	0
199239	199234	14026U	PARTICIPANT	\N	PRESENT	0
199240	199234	14097Y	PARTICIPANT	\N	PRESENT	0
199241	199234	04061F	PARTICIPANT	\N	PRESENT	0
199243	199234	04035D	PARTICIPANT	\N	PRESENT	0
199244	199234	14073Q	PARTICIPANT	\N	EXCUSE	0
199245	199234	98046X	PARTICIPANT	\N	PRESENT	0
199246	199234	04057K	PARTICIPANT	\N	PRESENT	0
199247	199234	10015M	PARTICIPANT	\N	PRESENT	0
199248	199234	11012A	PARTICIPANT	\N	EXCUSE	0
199249	199234	95063L	PARTICIPANT	\N	PRESENT	0
199250	199234	04034C	PARTICIPANT	\N	PRESENT	0
199251	199234	04045F	PARTICIPANT	\N	EXCUSE	0
199265	199263	96004D	PRESIDENT	0	PRESENT	0
199267	199263	14089Y	PARTICIPANT	\N	PRESENT	0
199268	199263	90003B	PARTICIPANT	\N	EXCUSE	0
199269	199263	14026U	PARTICIPANT	\N	PRESENT	0
199270	199263	14097Y	PARTICIPANT	\N	PRESENT	0
199271	199263	04061F	PARTICIPANT	\N	PRESENT	0
199273	199263	14073Q	PARTICIPANT	\N	EXCUSE	0
199274	199263	11026G	PARTICIPANT	\N	PRESENT	0
199291	199263	98046X	PARTICIPANT	\N	PRESENT	0
199329	199263	10015M	PARTICIPANT	\N	PRESENT	0
199330	199263	11012A	PARTICIPANT	\N	EXCUSE	0
199332	199263	95063L	PARTICIPANT	\N	PRESENT	0
199333	199263	04045F	PARTICIPANT	\N	EXCUSE	0
199334	199263	04034C	PARTICIPANT	\N	PRESENT	0
199340	199263	89017R	PARTICIPANT	\N	PRESENT	0
199341	199263	08014Q	PARTICIPANT	\N	PRESENT	0
199342	199263	14085U	PARTICIPANT	\N	PRESENT	0
199343	199263	11088W	PARTICIPANT	\N	PRESENT	0
199344	199263	01027Q	PARTICIPANT	\N	PRESENT	0
199345	199263	14159V	PARTICIPANT	\N	PRESENT	0
199346	199263	08010L	PARTICIPANT	\N	PRESENT	0
199347	199263	14225N	PARTICIPANT	\N	PRESENT	0
199348	199263	11057P	PARTICIPANT	\N	PRESENT	0
199349	199263	04086Q	PARTICIPANT	\N	PRESENT	0
199452	190791	86034E	PARTICIPANT	\N	PRESENT	0
200233	200232	08019V	PARTICIPANT	\N	PRESENT	0
200235	200234	11100Y	PARTICIPANT	\N	PRESENT	0
200373	200372	05008E	PRESIDENT	0	PRESENT	0
200392	192732	14179A	PARTICIPANT	\N	PRESENT	0
200692	190795	11063M	PARTICIPANT	\N	PRESENT	0
200693	190795	11031D	PARTICIPANT	\N	PRESENT	0
200694	190795	04085P	PARTICIPANT	\N	PRESENT	0
200695	190795	07026Q	PARTICIPANT	\N	PRESENT	0
200696	190795	12041X	PARTICIPANT	\N	PRESENT	0
200697	190795	14151M	PARTICIPANT	\N	PRESENT	0
200698	190795	14227Q	PARTICIPANT	\N	PRESENT	0
200699	190795	14269B	PARTICIPANT	\N	PRESENT	0
200700	190795	11089X	PARTICIPANT	\N	PRESENT	0
200701	190795	14281W	PARTICIPANT	\N	PRESENT	0
200702	190795	14121F	PARTICIPANT	\N	PRESENT	0
200703	190795	04059M	PARTICIPANT	\N	PRESENT	0
200704	190795	08052W	PARTICIPANT	\N	PRESENT	0
200705	190795	14039A	PARTICIPANT	\N	PRESENT	0
200706	190795	04067M	PARTICIPANT	\N	PRESENT	0
200707	190795	04053F	PARTICIPANT	\N	PRESENT	0
200708	190795	14261S	PARTICIPANT	\N	PRESENT	0
200709	190795	14034U	PARTICIPANT	\N	PRESENT	0
200710	190795	11085T	PARTICIPANT	\N	PRESENT	0
200711	190795	14255U	PARTICIPANT	\N	PRESENT	0
200712	190795	01027Q	PARTICIPANT	\N	PRESENT	0
200713	190795	14071N	PARTICIPANT	\N	PRESENT	0
200714	190795	99004R	PARTICIPANT	\N	PRESENT	0
200715	190795	11100Y	PARTICIPANT	\N	PRESENT	0
200716	190795	10006L	PARTICIPANT	\N	PRESENT	0
200717	190795	04071H	PARTICIPANT	\N	PRESENT	0
200718	190795	04055H	PARTICIPANT	\N	PRESENT	0
200719	190795	11103C	PARTICIPANT	\N	PRESENT	0
200720	190795	14217N	PARTICIPANT	\N	PRESENT	0
200721	190795	11097X	PARTICIPANT	\N	PRESENT	0
199327	199263	04057K	PARTICIPANT	\N	PRESENT	0
199328	199263	01016M	PARTICIPANT	\N	PRESENT	0
200722	190795	14265W	PARTICIPANT	\N	PRESENT	0
200723	190795	14157T	PARTICIPANT	\N	PRESENT	0
200724	190795	14041T	PARTICIPANT	\N	PRESENT	0
200725	190795	08019V	PARTICIPANT	\N	PRESENT	0
200726	190795	12042Y	PARTICIPANT	\N	PRESENT	0
200727	190795	19269X	PARTICIPANT	\N	PRESENT	0
200728	190795	14247U	PARTICIPANT	\N	PRESENT	0
200729	190795	14073Q	PARTICIPANT	\N	PRESENT	0
200730	190795	16813M	PARTICIPANT	\N	PRESENT	0
200732	190795	04056J	PARTICIPANT	\N	PRESENT	0
200733	190795	14229S	PARTICIPANT	\N	PRESENT	0
200734	190795	08016S	PARTICIPANT	\N	PRESENT	0
200735	190795	04045F	PARTICIPANT	\N	PRESENT	0
200736	190795	14179A	PARTICIPANT	\N	PRESENT	0
200737	190795	14363X	PARTICIPANT	\N	PRESENT	0
200738	190795	14111D	PARTICIPANT	\N	PRESENT	0
200796	190795	14249W	PARTICIPANT	\N	PRESENT	0
200797	190795	08068F	PARTICIPANT	\N	PRESENT	0
200798	190795	98024R	PARTICIPANT	\N	PRESENT	0
200812	190795	14271U	PARTICIPANT	\N	PRESENT	0
200813	190795	04043D	PARTICIPANT	\N	PRESENT	0
200814	190795	11080N	PARTICIPANT	\N	PRESENT	0
200815	190795	08061X	PARTICIPANT	\N	PRESENT	0
200832	190795	14087W	PARTICIPANT	\N	PRESENT	0
200852	190795	11107G	PARTICIPANT	\N	PRESENT	0
200853	190795	11091R	PARTICIPANT	\N	PRESENT	0
200932	190795	14225N	PARTICIPANT	\N	PRESENT	0
200892	190795	95067Q	PARTICIPANT	\N	PRESENT	0
200912	190795	08017T	PARTICIPANT	\N	PRESENT	0
202353	202352	04042C	PARTICIPANT	\N	PRESENT	0
202354	202352	14193X	PARTICIPANT	\N	PRESENT	0
202355	202352	11054L	PARTICIPANT	\N	PRESENT	0
202356	202352	04040A	PARTICIPANT	\N	PRESENT	0
202574	200595	04043D	PARTICIPANT	\N	EXCUSE	0
202992	200595	14209N	PARTICIPANT	\N	PRESENT	0
202993	200595	80013X	PARTICIPANT	\N	PRESENT	0
202994	200595	11089X	PARTICIPANT	\N	EXCUSE	0
202995	200595	01058X	PARTICIPANT	\N	EXCUSE	0
202996	200595	11036J	PARTICIPANT	\N	EXCUSE	0
203893	203892	04086Q	PARTICIPANT	\N	PRESENT	0
204372	190806	05001W	PARTICIPANT	\N	PRESENT	0
204373	190806	14235Q	PARTICIPANT	\N	PRESENT	0
204374	190806	14065Q	PARTICIPANT	\N	PRESENT	0
204375	190806	14121F	PARTICIPANT	\N	PRESENT	0
204376	190806	11112D	PARTICIPANT	\N	PRESENT	0
204377	190806	08012N	PARTICIPANT	\N	PRESENT	0
204693	204692	14225N	PARTICIPANT	\N	PRESENT	0
204752	204352	04044E	PRESIDENT	0	PRESENT	0
204732	204352	95063L	PARTICIPANT	\N	PRESENT	0
204733	204352	04056J	PARTICIPANT	\N	PRESENT	0
204734	204352	14041T	PARTICIPANT	\N	PRESENT	0
204735	204352	11026G	PARTICIPANT	\N	PRESENT	0
204736	204352	14147R	PARTICIPANT	\N	PRESENT	0
204737	204352	19253P	PARTICIPANT	\N	PRESENT	0
204738	204352	14069U	PARTICIPANT	\N	PRESENT	0
204739	204352	14215L	PARTICIPANT	\N	PRESENT	0
204740	204352	08018U	PARTICIPANT	\N	PRESENT	0
204741	204352	04047H	PARTICIPANT	\N	PRESENT	0
204742	204352	05008E	PARTICIPANT	\N	PRESENT	0
204743	204352	04085P	PARTICIPANT	\N	PRESENT	0
204753	204352	07034Q	PARTICIPANT	\N	EXCUSE	0
169384	169375	89017R	PARTICIPANT	\N	PRESENT	0
169385	169375	01031L	PRESIDENT	0	PRESENT	0
169386	169375	11068S	PARTICIPANT	\N	PRESENT	0
169387	169375	11040E	PARTICIPANT	\N	PRESENT	0
169388	169375	08014Q	PARTICIPANT	\N	PRESENT	0
169389	169375	14175V	PARTICIPANT	\N	PRESENT	0
169390	169375	14083S	PARTICIPANT	\N	PRESENT	0
169391	169375	11053K	PARTICIPANT	\N	PRESENT	0
169392	169375	14085U	PARTICIPANT	\N	PRESENT	0
169394	169375	11042G	PARTICIPANT	\N	PRESENT	0
169398	169375	88008L	PARTICIPANT	\N	PRESENT	0
169400	169375	04086Q	PARTICIPANT	\N	PRESENT	0
169401	169375	11088W	PARTICIPANT	\N	PRESENT	0
169402	169375	01027Q	PARTICIPANT	\N	PRESENT	0
169403	169375	04071H	PARTICIPANT	\N	PRESENT	0
169404	169375	11074Q	PARTICIPANT	\N	PRESENT	0
169405	169375	11083R	PARTICIPANT	\N	PRESENT	0
169407	169375	14199E	PARTICIPANT	\N	PRESENT	0
169408	169375	01057W	PARTICIPANT	\N	PRESENT	0
169410	169375	08016S	PARTICIPANT	\N	PRESENT	0
169411	169375	08069G	PARTICIPANT	\N	PRESENT	0
169412	169375	11048N	PARTICIPANT	\N	PRESENT	0
169413	169375	99004R	PARTICIPANT	\N	PRESENT	0
169414	169375	04061F	PARTICIPANT	\N	PRESENT	0
169415	169375	14159V	PARTICIPANT	\N	PRESENT	0
169416	169375	07029T	PARTICIPANT	\N	PRESENT	0
169417	169375	14277B	PARTICIPANT	\N	PRESENT	0
169418	169375	08010L	PARTICIPANT	\N	PRESENT	0
169419	169375	08034U	PARTICIPANT	\N	PRESENT	0
169420	169375	08011M	PARTICIPANT	\N	PRESENT	0
169421	169375	08061X	PARTICIPANT	\N	PRESENT	0
169427	169375	11012A	PARTICIPANT	\N	PRESENT	0
169425	169375	01016M	PARTICIPANT	\N	PRESENT	0
169426	169375	14225N	PARTICIPANT	\N	PRESENT	0
169429	169375	14173T	PARTICIPANT	\N	PRESENT	0
169430	169375	04034C	PARTICIPANT	\N	PRESENT	0
169432	169375	14327T	PARTICIPANT	\N	EXCUSE	0
170438	170432	11035H	PARTICIPANT	\N	EXCUSE	0
170439	170432	95030B	PARTICIPANT	\N	PRESENT	0
170440	170432	08018U	PARTICIPANT	\N	EXCUSE	0
170441	170432	11083R	PARTICIPANT	\N	PRESENT	0
170442	170432	14026U	PARTICIPANT	\N	PRESENT	0
170443	170432	14097Y	PARTICIPANT	\N	PRESENT	0
170444	170432	98046X	PARTICIPANT	\N	PRESENT	0
170445	170432	14001X	PARTICIPANT	\N	PRESENT	0
170446	170432	04057K	PARTICIPANT	\N	PRESENT	0
170447	170432	08042U	PARTICIPANT	\N	PRESENT	0
170448	170432	04080J	PARTICIPANT	\N	PRESENT	0
170449	170432	14135M	PARTICIPANT	\N	PRESENT	0
170450	170432	01016M	PARTICIPANT	\N	PRESENT	0
170451	170432	95063L	PARTICIPANT	\N	PRESENT	0
170452	170432	04045F	PARTICIPANT	\N	PRESENT	0
170453	170432	92045V	PARTICIPANT	\N	PRESENT	0
170454	170432	04034C	PARTICIPANT	\N	PRESENT	0
170455	170432	01031L	PARTICIPANT	\N	PRESENT	0
170456	170432	11042G	PARTICIPANT	\N	PRESENT	0
170457	170432	14083S	PARTICIPANT	\N	PRESENT	0
170458	170432	04071H	PARTICIPANT	\N	PRESENT	0
170459	170432	08034U	PARTICIPANT	\N	PRESENT	0
170460	170432	14225N	PARTICIPANT	\N	PRESENT	0
170461	170432	08061X	PARTICIPANT	\N	PRESENT	0
170462	170432	08011M	PARTICIPANT	\N	PRESENT	0
170463	170432	08010L	PARTICIPANT	\N	PRESENT	0
170464	170432	08069G	PARTICIPANT	\N	PRESENT	0
170465	170432	04086Q	PARTICIPANT	\N	PRESENT	0
171183	171180	14042U	PARTICIPANT	\N	PRESENT	0
171185	171180	01011G	PARTICIPANT	\N	PRESENT	0
171186	171180	14119M	PARTICIPANT	\N	PRESENT	0
171197	171196	14042U	PARTICIPANT	\N	PRESENT	0
171198	171196	01011G	PARTICIPANT	\N	PRESENT	0
171200	171199	14042U	PARTICIPANT	\N	PRESENT	0
171201	171199	01011G	PARTICIPANT	\N	PRESENT	0
171204	171202	14042U	PARTICIPANT	\N	PRESENT	0
171205	171202	01011G	PARTICIPANT	\N	PRESENT	0
172514	172512	14239U	PARTICIPANT	\N	PRESENT	0
172438	172435	14239U	PARTICIPANT	\N	PRESENT	0
172516	172512	01046T	PARTICIPANT	\N	PRESENT	0
172517	172512	04053F	PARTICIPANT	\N	PRESENT	0
172086	171870	08039A	PARTICIPANT	\N	PRESENT	0
172520	172512	00003C	PARTICIPANT	\N	EXCUSE	0
172521	172512	14053L	PARTICIPANT	\N	PRESENT	0
172089	171870	08017T	PARTICIPANT	\N	PRESENT	0
172522	172512	11103C	PARTICIPANT	\N	PRESENT	0
172523	172512	11044J	PARTICIPANT	\N	PRESENT	0
172524	172512	14195A	PARTICIPANT	\N	PRESENT	0
172525	172512	14267Y	PARTICIPANT	\N	PRESENT	0
172526	172512	11023D	PARTICIPANT	\N	PRESENT	0
172527	172512	11031D	PARTICIPANT	\N	PRESENT	0
172528	172512	08052W	PARTICIPANT	\N	PRESENT	0
172529	172512	01059Y	PARTICIPANT	\N	PRESENT	0
172098	171870	14059S	PARTICIPANT	\N	PRESENT	0
172530	172512	04081K	PARTICIPANT	\N	PRESENT	0
172531	172512	98024R	PARTICIPANT	\N	PRESENT	0
172440	172435	01046T	PARTICIPANT	\N	PRESENT	0
172532	172512	10006L	PARTICIPANT	\N	PRESENT	0
172533	172512	04067M	PARTICIPANT	\N	PRESENT	0
172104	171870	11104D	PARTICIPANT	\N	EXCUSE	0
172534	172512	14217N	PARTICIPANT	\N	PRESENT	0
172535	172512	14042U	PARTICIPANT	\N	PRESENT	0
172536	172512	14151M	PARTICIPANT	\N	PRESENT	0
172108	171870	14063N	PARTICIPANT	\N	PRESENT	0
172537	172512	12042Y	PARTICIPANT	\N	PRESENT	0
172538	172512	14281W	PARTICIPANT	\N	PRESENT	0
172539	172512	14087W	PARTICIPANT	\N	PRESENT	0
172540	172512	01003G	PARTICIPANT	\N	EXCUSE	0
172541	172512	14034U	PARTICIPANT	\N	PRESENT	0
172542	172512	14231L	PARTICIPANT	\N	PRESENT	0
172543	172512	11061K	PARTICIPANT	\N	PRESENT	0
172544	172512	14355X	PARTICIPANT	\N	PRESENT	0
172121	171870	04057K	PARTICIPANT	\N	EXCUSE	0
172126	171870	11014C	PARTICIPANT	\N	EXCUSE	0
172441	172435	04053F	PARTICIPANT	\N	PRESENT	0
172135	171870	04070G	PRESIDENT	0	PRESENT	0
172444	172435	00003C	PARTICIPANT	\N	EXCUSE	0
172445	172435	14053L	PARTICIPANT	\N	PRESENT	0
172446	172435	11103C	PARTICIPANT	\N	PRESENT	0
172447	172435	11044J	PARTICIPANT	\N	PRESENT	0
172448	172435	14195A	PARTICIPANT	\N	PRESENT	0
172449	172435	14267Y	PARTICIPANT	\N	PRESENT	0
172450	172435	11023D	PARTICIPANT	\N	PRESENT	0
172451	172435	11031D	PARTICIPANT	\N	PRESENT	0
172452	172435	08052W	PARTICIPANT	\N	PRESENT	0
172453	172435	01059Y	PARTICIPANT	\N	PRESENT	0
172454	172435	04081K	PARTICIPANT	\N	PRESENT	0
172455	172435	98024R	PARTICIPANT	\N	PRESENT	0
172456	172435	10006L	PARTICIPANT	\N	PRESENT	0
172457	172435	04067M	PARTICIPANT	\N	PRESENT	0
172458	172435	14217N	PARTICIPANT	\N	PRESENT	0
172459	172435	14042U	PARTICIPANT	\N	PRESENT	0
172460	172435	14151M	PARTICIPANT	\N	PRESENT	0
172461	172435	12042Y	PARTICIPANT	\N	PRESENT	0
172462	172435	14281W	PARTICIPANT	\N	PRESENT	0
172463	172435	14087W	PARTICIPANT	\N	PRESENT	0
172464	172435	01003G	PARTICIPANT	\N	EXCUSE	0
172465	172435	14034U	PARTICIPANT	\N	PRESENT	0
172466	172435	14231L	PARTICIPANT	\N	PRESENT	0
172467	172435	11061K	PARTICIPANT	\N	PRESENT	0
172468	172435	14355X	PARTICIPANT	\N	PRESENT	0
172469	172435	08048B	PARTICIPANT	\N	PRESENT	0
172470	172435	08041T	PARTICIPANT	\N	PRESENT	0
172471	172435	01011G	PARTICIPANT	\N	PRESENT	0
172472	172435	14026U	PARTICIPANT	\N	PRESENT	0
172473	172435	14213J	PARTICIPANT	\N	PRESENT	0
172474	172435	14121F	PARTICIPANT	\N	PRESENT	0
172475	172435	11112D	PARTICIPANT	\N	EXCUSE	0
172476	172435	14037X	PARTICIPANT	\N	PRESENT	0
172477	172435	14018U	PARTICIPANT	\N	PRESENT	0
172478	172435	11067R	PARTICIPANT	\N	PRESENT	0
172479	172435	14223L	PARTICIPANT	\N	PRESENT	0
172480	172435	04092N	PRESIDENT	0	PRESENT	0
172481	172435	14265W	PARTICIPANT	\N	PRESENT	0
172482	172435	14119M	PARTICIPANT	\N	PRESENT	0
172483	172435	14071N	PARTICIPANT	\N	PRESENT	0
172484	172435	04043D	PARTICIPANT	\N	PRESENT	0
172485	172435	14271U	PARTICIPANT	\N	PRESENT	0
172487	172435	11093T	PARTICIPANT	\N	PRESENT	0
172488	172435	11097X	PARTICIPANT	\N	PRESENT	0
172489	172435	04045F	PARTICIPANT	\N	PRESENT	0
172490	172435	14227Q	PARTICIPANT	\N	PRESENT	0
172491	172435	01034P	PARTICIPANT	\N	PRESENT	0
172492	172435	11025F	PARTICIPANT	\N	PRESENT	0
172493	172435	11063M	PARTICIPANT	\N	PRESENT	0
172494	172435	14269B	PARTICIPANT	\N	PRESENT	0
196719	190781	95035G	PARTICIPANT	\N	PRESENT	0
196720	190781	14237S	PARTICIPANT	\N	PRESENT	0
196721	190781	11089X	PARTICIPANT	\N	PRESENT	0
196722	190781	08058D	PARTICIPANT	\N	PRESENT	0
196723	190781	14227Q	PARTICIPANT	\N	PRESENT	0
196724	190781	04045F	PARTICIPANT	\N	PRESENT	0
196725	190781	11066Q	PARTICIPANT	\N	PRESENT	0
196726	190781	11031D	PARTICIPANT	\N	PRESENT	0
196727	190781	11070L	PARTICIPANT	\N	PRESENT	0
196728	190781	04033B	PARTICIPANT	\N	PRESENT	0
196729	190781	01027Q	PARTICIPANT	\N	PRESENT	0
196730	190781	86044G	PARTICIPANT	\N	PRESENT	0
196731	190781	04080J	PARTICIPANT	\N	PRESENT	0
196732	190781	14073Q	PARTICIPANT	\N	PRESENT	0
196733	190781	04081K	PARTICIPANT	\N	PRESENT	0
196734	190781	04044E	PARTICIPANT	\N	PRESENT	0
196735	190781	11034G	PARTICIPANT	\N	PRESENT	0
196736	190781	14329V	PARTICIPANT	\N	PRESENT	0
196737	190781	92045V	PARTICIPANT	\N	PRESENT	0
196739	190781	14363X	PARTICIPANT	\N	PRESENT	0
196740	190781	14195A	PARTICIPANT	\N	PRESENT	0
196741	190781	08056B	PARTICIPANT	\N	PRESENT	0
196742	190781	01047U	PARTICIPANT	\N	PRESENT	0
196743	190781	11054L	PARTICIPANT	\N	PRESENT	0
196744	190781	11039M	PARTICIPANT	\N	PRESENT	0
196745	190781	80027E	PARTICIPANT	\N	PRESENT	0
196746	190781	14257W	PARTICIPANT	\N	PRESENT	0
196747	190781	14249W	PARTICIPANT	\N	PRESENT	0
196748	190781	14071N	PARTICIPANT	\N	PRESENT	0
196749	190781	04035D	PARTICIPANT	\N	PRESENT	0
196750	190781	14193X	PARTICIPANT	\N	PRESENT	0
196751	190781	11027H	PARTICIPANT	\N	PRESENT	0
196752	190781	01024M	PARTICIPANT	\N	PRESENT	0
196753	190781	10006L	PARTICIPANT	\N	PRESENT	0
196754	190781	14197C	PARTICIPANT	\N	PRESENT	0
196755	190781	00003C	PARTICIPANT	\N	PRESENT	0
196756	190781	14159V	PARTICIPANT	\N	PRESENT	0
196757	190781	14169X	PARTICIPANT	\N	PRESENT	0
196758	190781	01057W	PARTICIPANT	\N	PRESENT	0
196759	190781	11053K	PARTICIPANT	\N	PRESENT	0
196760	190781	95030B	PARTICIPANT	\N	PRESENT	0
196761	190781	13002U	PARTICIPANT	\N	PRESENT	0
196773	190781	04067M	PARTICIPANT	\N	PRESENT	0
196774	190781	11029K	PARTICIPANT	\N	PRESENT	0
196775	196772	08055A	PARTICIPANT	\N	PRESENT	0
196776	196772	14207L	PARTICIPANT	\N	PRESENT	0
196777	196772	90003B	PARTICIPANT	\N	PRESENT	0
196778	196772	14038Y	PARTICIPANT	\N	PRESENT	0
196779	196772	88008L	PARTICIPANT	\N	PRESENT	0
196780	196772	80013X	PARTICIPANT	\N	PRESENT	0
196781	196772	87003B	PARTICIPANT	\N	PRESENT	0
196782	196772	11107G	PARTICIPANT	\N	PRESENT	0
196783	196772	14211G	PARTICIPANT	\N	PRESENT	0
196784	196772	95037J	PARTICIPANT	\N	PRESENT	0
196794	196772	01025N	PARTICIPANT	\N	PRESENT	0
196786	196772	14097Y	PARTICIPANT	\N	PRESENT	0
196787	196772	08015R	PARTICIPANT	\N	PRESENT	0
196788	196772	14257W	PARTICIPANT	\N	PRESENT	0
196789	196772	04088S	PARTICIPANT	\N	PRESENT	0
196790	196772	05012A	PARTICIPANT	\N	PRESENT	0
196791	196772	11097X	PARTICIPANT	\N	PRESENT	0
196792	196772	11094U	PARTICIPANT	\N	PRESENT	0
196793	196772	14213J	PARTICIPANT	\N	PRESENT	0
196795	194396	04070G	PRESIDENT	0	PRESENT	0
196796	194396	12041X	PARTICIPANT	\N	PRESENT	0
196797	194396	04057K	PARTICIPANT	\N	PRESENT	0
196798	194396	14073Q	PARTICIPANT	\N	PRESENT	0
196799	194396	11109J	PARTICIPANT	\N	PRESENT	0
196800	194396	14063N	PARTICIPANT	\N	PRESENT	0
196801	194396	11104D	PARTICIPANT	\N	PRESENT	0
196802	194396	08039A	PARTICIPANT	\N	PRESENT	0
196803	194396	14229S	PARTICIPANT	\N	PRESENT	0
196804	190781	14031R	PARTICIPANT	\N	PRESENT	0
196805	190781	04071H	PARTICIPANT	\N	PRESENT	0
196806	190781	14173T	PARTICIPANT	\N	PRESENT	0
196807	190781	11100Y	PARTICIPANT	\N	PRESENT	0
196808	190781	11097X	PARTICIPANT	\N	PRESENT	0
196809	190781	11088W	PARTICIPANT	\N	PRESENT	0
196810	190781	01031L	PARTICIPANT	\N	PRESENT	0
196811	190781	11061K	PARTICIPANT	\N	PRESENT	0
196822	190781	18127E	PARTICIPANT	\N	PRESENT	0
196823	190781	14281W	PARTICIPANT	\N	PRESENT	0
196824	190781	14121F	PARTICIPANT	\N	PRESENT	0
196825	190781	08062Y	PARTICIPANT	\N	PRESENT	0
196826	190781	11064N	PARTICIPANT	\N	PRESENT	0
196832	190781	14119M	PARTICIPANT	\N	PRESENT	0
196833	190781	02002K	PARTICIPANT	\N	PRESENT	0
196835	190781	11084S	PARTICIPANT	\N	PRESENT	0
196836	190781	01048V	PARTICIPANT	\N	PRESENT	0
196837	190781	98018T	PARTICIPANT	\N	PRESENT	0
196838	190781	14083S	PARTICIPANT	\N	PRESENT	0
196839	190781	11112D	PARTICIPANT	\N	PRESENT	0
196840	190781	14097Y	PARTICIPANT	\N	PRESENT	0
196841	190781	11036J	PARTICIPANT	\N	PRESENT	0
196852	190781	04061F	PARTICIPANT	\N	PRESENT	0
196853	190781	08061X	PARTICIPANT	\N	PRESENT	0
196854	190781	04034C	PARTICIPANT	\N	PRESENT	0
196855	190781	08044W	PARTICIPANT	\N	PRESENT	0
196856	190781	11068S	PARTICIPANT	\N	PRESENT	0
196857	190781	98046X	PARTICIPANT	\N	PRESENT	0
196859	196858	04035D	PARTICIPANT	\N	PRESENT	0
196860	196858	11064N	PARTICIPANT	\N	PRESENT	0
196861	196858	14097Y	PARTICIPANT	\N	PRESENT	0
196862	196858	14363X	PARTICIPANT	\N	PRESENT	0
196863	196858	08056B	PARTICIPANT	\N	PRESENT	0
196864	190781	92020L	PARTICIPANT	\N	PRESENT	0
196865	190781	04053F	PARTICIPANT	\N	PRESENT	0
196866	190781	14229S	PARTICIPANT	\N	PRESENT	0
196867	190781	14063N	PARTICIPANT	\N	PRESENT	0
196868	190781	04054G	PARTICIPANT	\N	PRESENT	0
196869	190781	01034P	PARTICIPANT	\N	PRESENT	0
196870	190781	01016M	PARTICIPANT	\N	PRESENT	0
196871	194396	11029K	PARTICIPANT	\N	PRESENT	0
196872	194396	11091R	PARTICIPANT	\N	EXCUSE	0
196873	194396	92015P	PARTICIPANT	\N	EXCUSE	0
196874	190781	11105E	PARTICIPANT	\N	PRESENT	0
196875	190781	11082Q	PARTICIPANT	\N	PRESENT	0
196876	190781	08069G	PARTICIPANT	\N	PRESENT	0
196877	190781	11109J	PARTICIPANT	\N	PRESENT	0
196907	190781	04056J	PARTICIPANT	\N	PRESENT	0
196908	190781	95067Q	PARTICIPANT	\N	PRESENT	0
196972	192792	04034C	PARTICIPANT	\N	PRESENT	0
196973	192792	11048N	PARTICIPANT	\N	PRESENT	0
196974	192792	04055H	PARTICIPANT	\N	PRESENT	0
196975	192792	07029T	PARTICIPANT	\N	EXCUSE	0
196976	192792	14199E	PARTICIPANT	\N	EXCUSE	0
196977	192792	98053W	PARTICIPANT	\N	EXCUSE	0
197092	190782	05008E	PARTICIPANT	\N	PRESENT	0
197093	190782	04054G	PARTICIPANT	\N	PRESENT	0
197094	190782	04085P	PARTICIPANT	\N	PRESENT	0
197095	190782	14269B	PARTICIPANT	\N	PRESENT	0
197096	190782	08014Q	PARTICIPANT	\N	PRESENT	0
197097	190782	14207L	PARTICIPANT	\N	PRESENT	0
197098	190782	11099A	PARTICIPANT	\N	PRESENT	0
197099	190782	11036J	PARTICIPANT	\N	PRESENT	0
197100	190782	11037K	PARTICIPANT	\N	PRESENT	0
197101	190782	07029T	PARTICIPANT	\N	PRESENT	0
197102	190782	08034U	PARTICIPANT	\N	PRESENT	0
197103	190782	11029K	PARTICIPANT	\N	PRESENT	0
197104	190782	14157T	PARTICIPANT	\N	PRESENT	0
197105	190782	14053L	PARTICIPANT	\N	PRESENT	0
197106	190782	14237S	PARTICIPANT	\N	PRESENT	0
197107	190782	14059S	PARTICIPANT	\N	PRESENT	0
197108	190782	04044E	PARTICIPANT	\N	PRESENT	0
197109	190782	11109J	PARTICIPANT	\N	PRESENT	0
197110	190782	11074Q	PARTICIPANT	\N	PRESENT	0
197111	190782	04033B	PARTICIPANT	\N	PRESENT	0
197112	190782	11034G	PARTICIPANT	\N	PRESENT	0
197113	190782	01027Q	PARTICIPANT	\N	PRESENT	0
197114	190782	08031R	PARTICIPANT	\N	PRESENT	0
197115	190782	95037J	PARTICIPANT	\N	PRESENT	0
197116	190782	04040A	PARTICIPANT	\N	PRESENT	0
197117	190782	10006L	PARTICIPANT	\N	PRESENT	0
197118	190782	04045F	PARTICIPANT	\N	PRESENT	0
197119	190782	14357A	PARTICIPANT	\N	PRESENT	0
197120	190782	04066L	PARTICIPANT	\N	PRESENT	0
197121	190782	14265W	PARTICIPANT	\N	PRESENT	0
197122	190782	14033T	PARTICIPANT	\N	PRESENT	0
197123	190782	11026G	PARTICIPANT	\N	PRESENT	0
197124	190782	14061L	PARTICIPANT	\N	PRESENT	0
197125	190782	14217N	PARTICIPANT	\N	PRESENT	0
197126	190782	14187A	PARTICIPANT	\N	PRESENT	0
197127	190782	14135M	PARTICIPANT	\N	PRESENT	0
197128	190782	05012A	PARTICIPANT	\N	PRESENT	0
197129	190782	14231L	PARTICIPANT	\N	PRESENT	0
197130	190782	14219Q	PARTICIPANT	\N	PRESENT	0
197131	190782	01028R	PARTICIPANT	\N	PRESENT	0
197132	190782	14215L	PARTICIPANT	\N	PRESENT	0
197133	190782	08061X	PARTICIPANT	\N	PRESENT	0
169478	167712	11043H	PARTICIPANT	\N	PRESENT	0
169480	167712	14014Q	PARTICIPANT	\N	PRESENT	0
169482	167712	05012A	PARTICIPANT	\N	PRESENT	0
169483	167712	08031R	PARTICIPANT	\N	PRESENT	0
170473	170472	95035G	PARTICIPANT	\N	PRESENT	0
170474	170472	10015M	PARTICIPANT	\N	PRESENT	0
170492	169094	01027Q	PARTICIPANT	\N	EXCUSE	0
170493	169094	08034U	PARTICIPANT	\N	PRESENT	0
173296	173293	14207L	PARTICIPANT	\N	PRESENT	0
173297	173293	04089T	PARTICIPANT	\N	PRESENT	0
173298	173293	14187A	PARTICIPANT	\N	PRESENT	0
173299	173293	14033T	PARTICIPANT	\N	PRESENT	0
173303	173293	11100Y	PRESIDENT	0	PRESENT	0
173304	173293	11098Y	PARTICIPANT	\N	PRESENT	0
173305	173293	14257W	PARTICIPANT	\N	PRESENT	0
174212	164994	14209N	PARTICIPANT	\N	EXCUSE	0
185013	185012	01058X	PARTICIPANT	\N	PRESENT	0
185093	185092	04054G	PARTICIPANT	\N	PRESENT	0
185094	185092	04047H	PARTICIPANT	\N	PRESENT	0
185095	185092	14079W	PARTICIPANT	\N	PRESENT	0
185096	185092	11083R	PARTICIPANT	\N	PRESENT	0
185097	185092	14026U	PARTICIPANT	\N	PRESENT	0
185098	185092	11084S	PARTICIPANT	\N	PRESENT	0
185099	185092	14073Q	PARTICIPANT	\N	PRESENT	0
185100	185092	11026G	PARTICIPANT	\N	PRESENT	0
185101	185092	92031P	PARTICIPANT	\N	PRESENT	0
185102	185092	14001X	PARTICIPANT	\N	PRESENT	0
185103	185092	11012A	PRESIDENT	0	PRESENT	0
185104	185092	14227Q	PARTICIPANT	\N	PRESENT	0
185105	185092	11066Q	PARTICIPANT	\N	PRESENT	0
185106	185092	95067Q	PARTICIPANT	\N	PRESENT	0
192848	192832	14059S	PARTICIPANT	\N	PRESENT	0
189932	189930	04059M	PARTICIPANT	\N	PRESENT	0
189933	189930	11039M	PARTICIPANT	\N	EXCUSE	0
189934	189930	01044R	PARTICIPANT	\N	PRESENT	0
189935	189930	08043V	PARTICIPANT	\N	EXCUSE	0
189936	189930	14089Y	PARTICIPANT	\N	PRESENT	0
189937	189930	14105F	PARTICIPANT	\N	PRESENT	0
189938	189930	11029K	PARTICIPANT	\N	PRESENT	0
189939	189930	95015C	PARTICIPANT	\N	PRESENT	0
192849	192832	14103D	PARTICIPANT	\N	PRESENT	0
189941	189930	08024S	PARTICIPANT	\N	PRESENT	0
192850	192832	04092N	PARTICIPANT	\N	PRESENT	0
192851	192832	14265W	PARTICIPANT	\N	PRESENT	0
189944	189930	14209N	PARTICIPANT	\N	PRESENT	0
192852	192832	14119M	PARTICIPANT	\N	PRESENT	0
189946	189930	11091R	PARTICIPANT	\N	EXCUSE	0
189947	189930	87003B	PARTICIPANT	\N	PRESENT	0
192853	192832	08061X	PARTICIPANT	\N	PRESENT	0
189949	189930	14249W	PARTICIPANT	\N	EXCUSE	0
189950	189930	01041N	PARTICIPANT	\N	PRESENT	0
189951	189930	01025N	PARTICIPANT	\N	PRESENT	0
192854	192832	04088S	PARTICIPANT	\N	PRESENT	0
192855	192832	05012A	PARTICIPANT	\N	PRESENT	0
192856	192832	98050T	PARTICIPANT	\N	PRESENT	0
189955	189930	07026Q	PARTICIPANT	\N	PRESENT	0
189956	189930	14123H	PARTICIPANT	\N	PRESENT	0
192857	192832	14135M	PARTICIPANT	\N	PRESENT	0
192858	192832	14271U	PARTICIPANT	\N	PRESENT	0
189959	189930	14241N	PARTICIPANT	\N	PRESENT	0
189960	189930	14061L	PARTICIPANT	\N	PRESENT	0
189961	189930	14073Q	PARTICIPANT	\N	EXCUSE	0
189962	189930	08031R	PARTICIPANT	\N	PRESENT	0
192859	192832	14107H	PARTICIPANT	\N	PRESENT	0
189964	189930	08039A	PARTICIPANT	\N	PRESENT	0
189965	189930	08017T	PARTICIPANT	\N	PRESENT	0
189966	189930	14059S	PARTICIPANT	\N	PRESENT	0
189967	189930	08012N	PARTICIPANT	\N	PRESENT	0
189968	189930	14103D	PARTICIPANT	\N	EXCUSE	0
189969	189930	11104D	PARTICIPANT	\N	PRESENT	0
189970	189930	14063N	PARTICIPANT	\N	PRESENT	0
189971	189930	04057K	PARTICIPANT	\N	EXCUSE	0
189972	189930	11014C	PARTICIPANT	\N	PRESENT	0
189973	189930	14109K	PARTICIPANT	\N	PRESENT	0
189974	189930	04070G	PRESIDENT	0	PRESENT	0
192860	192832	11094U	PARTICIPANT	\N	PRESENT	0
192861	192832	92045V	PARTICIPANT	\N	PRESENT	0
192862	192832	95067Q	PARTICIPANT	\N	PRESENT	0
189978	189930	14235Q	PARTICIPANT	\N	PRESENT	0
192863	192832	11063M	PARTICIPANT	\N	PRESENT	0
192864	192832	14173T	PARTICIPANT	\N	PRESENT	0
189981	189930	14361V	PARTICIPANT	\N	PRESENT	0
189982	189930	14229S	PARTICIPANT	\N	PRESENT	0
192873	192872	11054L	PARTICIPANT	\N	PRESENT	0
189984	189930	11043H	PARTICIPANT	\N	PRESENT	0
192875	192874	98018T	PARTICIPANT	\N	PRESENT	0
192893	192892	14151M	PARTICIPANT	\N	PRESENT	0
193355	190778	14159V	PARTICIPANT	\N	PRESENT	0
193356	190778	80027E	PARTICIPANT	\N	PRESENT	0
193357	190778	14085U	PARTICIPANT	\N	PRESENT	0
193358	190778	08017T	PARTICIPANT	\N	PRESENT	0
193359	190778	04034C	PARTICIPANT	\N	PRESENT	0
193372	190778	14063N	PARTICIPANT	\N	PRESENT	0
193373	190778	14097Y	PARTICIPANT	\N	PRESENT	0
193374	190778	14257W	PARTICIPANT	\N	PRESENT	0
193375	190778	04054G	PARTICIPANT	\N	PRESENT	0
193376	190778	11098Y	PARTICIPANT	\N	PRESENT	0
193377	190778	19251M	PARTICIPANT	\N	PRESENT	0
193392	190778	04056J	PARTICIPANT	\N	PRESENT	0
193393	190778	08043V	PARTICIPANT	\N	PRESENT	0
193394	190778	11026G	PARTICIPANT	\N	PRESENT	0
193395	190778	08038Y	PARTICIPANT	\N	PRESENT	0
193396	190778	14207L	PARTICIPANT	\N	PRESENT	0
193397	190778	11077T	PARTICIPANT	\N	PRESENT	0
193398	190778	11037K	PARTICIPANT	\N	PRESENT	0
193399	190778	11066Q	PARTICIPANT	\N	PRESENT	0
193400	190778	14269B	PARTICIPANT	\N	PRESENT	0
193401	190778	14229S	PARTICIPANT	\N	PRESENT	0
193402	190778	14081Q	PARTICIPANT	\N	PRESENT	0
193403	190778	04045F	PARTICIPANT	\N	PRESENT	0
193404	190778	01028R	PARTICIPANT	\N	PRESENT	0
193412	190778	11057P	PARTICIPANT	\N	PRESENT	0
193413	190778	14107H	PARTICIPANT	\N	PRESENT	0
193414	190778	14197C	PARTICIPANT	\N	PRESENT	0
193432	190778	07034Q	PARTICIPANT	\N	PRESENT	0
193433	190778	05008E	PARTICIPANT	\N	PRESENT	0
193434	190778	14239U	PARTICIPANT	\N	PRESENT	0
193435	190778	04066L	PARTICIPANT	\N	PRESENT	0
193436	190778	98029W	PARTICIPANT	\N	PRESENT	0
193452	190778	08068F	PARTICIPANT	\N	PRESENT	0
193453	190778	12042Y	PARTICIPANT	\N	PRESENT	0
193454	190778	08014Q	PARTICIPANT	\N	PRESENT	0
193455	190778	04067M	PARTICIPANT	\N	PRESENT	0
193456	190778	11029K	PARTICIPANT	\N	PRESENT	0
193472	190778	11099A	PARTICIPANT	\N	PRESENT	0
193473	190778	98022P	PARTICIPANT	\N	PRESENT	0
193474	190778	14241N	PARTICIPANT	\N	PRESENT	0
193475	190778	11107G	PARTICIPANT	\N	PRESENT	0
193477	190778	11081P	PARTICIPANT	\N	PRESENT	0
193481	190778	14028W	PARTICIPANT	\N	PRESENT	0
193482	190778	08058D	PARTICIPANT	\N	PRESENT	0
193483	190778	95063L	PARTICIPANT	\N	PRESENT	0
193484	190778	11089X	PARTICIPANT	\N	PRESENT	0
193492	190778	08025T	PARTICIPANT	\N	PRESENT	0
193493	190778	14225N	PARTICIPANT	\N	PRESENT	0
193494	190778	14109K	PARTICIPANT	\N	PRESENT	0
193495	190778	11070L	PARTICIPANT	\N	PRESENT	0
193496	190778	14221J	PARTICIPANT	\N	PRESENT	0
193512	190778	14042U	PARTICIPANT	\N	PRESENT	0
193513	190778	14219Q	PARTICIPANT	\N	PRESENT	0
193514	190778	14103D	PARTICIPANT	\N	PRESENT	0
193515	190778	14271U	PARTICIPANT	\N	PRESENT	0
193516	190778	08024S	PARTICIPANT	\N	PRESENT	0
193517	190778	14275Y	PARTICIPANT	\N	PRESENT	0
193518	190778	08009T	PARTICIPANT	\N	PRESENT	0
193519	190778	08061X	PARTICIPANT	\N	PRESENT	0
193520	190778	11094U	PARTICIPANT	\N	PRESENT	0
193532	190778	14365A	PARTICIPANT	\N	PRESENT	0
193533	190778	01034P	PARTICIPANT	\N	PRESENT	0
193566	190778	14018U	PARTICIPANT	\N	PRESENT	0
193567	190778	01046T	PARTICIPANT	\N	PRESENT	0
193568	190778	14261S	PARTICIPANT	\N	PRESENT	0
193569	190778	11012A	PARTICIPANT	\N	PRESENT	0
193570	190778	04059M	PARTICIPANT	\N	PRESENT	0
193571	190778	14327T	PARTICIPANT	\N	PRESENT	0
193572	190778	14089Y	PARTICIPANT	\N	PRESENT	0
193573	190778	18127E	PARTICIPANT	\N	PRESENT	0
193574	190778	11054L	PARTICIPANT	\N	PRESENT	0
193592	190778	08031R	PARTICIPANT	\N	PRESENT	0
193593	190778	08049C	PARTICIPANT	\N	PRESENT	0
205684	205683	11039M	PARTICIPANT	\N	PRESENT	0
205685	205683	98042T	PARTICIPANT	\N	PRESENT	0
205686	205683	01019Q	PARTICIPANT	\N	PRESENT	0
206230	206075	01057W	PARTICIPANT	\N	PRESENT	0
206231	206075	98022P	PARTICIPANT	\N	PRESENT	0
206232	206075	11064N	PARTICIPANT	\N	PRESENT	0
206233	206075	19691J	PARTICIPANT	\N	PRESENT	0
206234	206075	08016S	PARTICIPANT	\N	PRESENT	0
206235	206075	14081Q	PARTICIPANT	\N	PRESENT	0
206236	206075	19553Y	PARTICIPANT	\N	PRESENT	0
206237	206075	19725B	PARTICIPANT	\N	PRESENT	0
206238	206075	19329S	PARTICIPANT	\N	PRESENT	0
206239	206075	95037J	PARTICIPANT	\N	PRESENT	0
206240	206075	19569H	PARTICIPANT	\N	PRESENT	0
206241	206075	14179A	PARTICIPANT	\N	PRESENT	0
206242	206075	19685L	PARTICIPANT	\N	PRESENT	0
206243	206075	19333N	PARTICIPANT	\N	PRESENT	0
206244	206075	08069G	PARTICIPANT	\N	PRESENT	0
206245	206075	19399H	PARTICIPANT	\N	PRESENT	0
206246	206075	04097T	PARTICIPANT	\N	PRESENT	0
206247	206075	11048N	PARTICIPANT	\N	PRESENT	0
206248	206075	19591F	PARTICIPANT	\N	PRESENT	0
206249	206075	14213J	PARTICIPANT	\N	PRESENT	0
206250	206075	19551W	PARTICIPANT	\N	PRESENT	0
206251	206075	19511N	PARTICIPANT	\N	PRESENT	0
206252	206075	19715Y	PARTICIPANT	\N	PRESENT	0
206253	206075	14121F	PARTICIPANT	\N	PRESENT	0
206254	206075	08044W	PARTICIPANT	\N	PRESENT	0
206255	206075	19531S	PARTICIPANT	\N	PRESENT	0
206256	206075	19683J	PARTICIPANT	\N	PRESENT	0
206257	206075	14097Y	PARTICIPANT	\N	PRESENT	0
206258	206075	19447X	PARTICIPANT	\N	PRESENT	0
206259	206075	14241N	PARTICIPANT	\N	PRESENT	0
206261	206075	14021P	PARTICIPANT	\N	PRESENT	0
206262	206075	14039A	PARTICIPANT	\N	PRESENT	0
206263	206075	99004R	PARTICIPANT	\N	PRESENT	0
206264	206075	19731Y	PARTICIPANT	\N	PRESENT	0
206265	206075	04061F	PARTICIPANT	\N	PRESENT	0
204893	204892	14213J	PARTICIPANT	\N	PRESENT	0
204933	204932	11039M	PARTICIPANT	\N	PRESENT	0
204934	204932	98042T	PARTICIPANT	\N	PRESENT	0
204935	204932	01019Q	PARTICIPANT	\N	PRESENT	0
205313	205312	04070G	PARTICIPANT	\N	PRESENT	0
205452	205212	01048V	PARTICIPANT	\N	EXCUSE	0
205590	205589	14065Q	PARTICIPANT	\N	PRESENT	0
205591	205589	04047H	PARTICIPANT	\N	PRESENT	0
205599	205598	07034Q	PARTICIPANT	\N	PRESENT	0
206266	206075	14061L	PARTICIPANT	\N	PRESENT	0
206267	206075	14073Q	PARTICIPANT	\N	PRESENT	0
206268	206075	19489J	PARTICIPANT	\N	PRESENT	0
206269	206075	11099A	PARTICIPANT	\N	PRESENT	0
206270	206075	08031R	PARTICIPANT	\N	PRESENT	0
206271	206075	19611R	PARTICIPANT	\N	PRESENT	0
206272	206075	19583F	PARTICIPANT	\N	PRESENT	0
206273	206075	14159V	PARTICIPANT	\N	PRESENT	0
206274	206075	07029T	PARTICIPANT	\N	PRESENT	0
206275	206075	04049K	PARTICIPANT	\N	PRESENT	0
206276	206075	14029X	PARTICIPANT	\N	PRESENT	0
206277	206075	86034E	PARTICIPANT	\N	PRESENT	0
206278	206075	19723Y	PARTICIPANT	\N	PRESENT	0
206279	206075	98005N	PARTICIPANT	\N	PRESENT	0
206280	206075	19699S	PARTICIPANT	\N	PRESENT	0
206281	206075	08015R	PARTICIPANT	\N	PRESENT	0
206282	206075	12041X	PARTICIPANT	\N	PRESENT	0
206283	206075	14277B	PARTICIPANT	\N	PRESENT	0
206284	206075	19711U	PARTICIPANT	\N	PRESENT	0
206285	206075	19709B	PARTICIPANT	\N	PRESENT	0
206286	206075	16685X	PARTICIPANT	\N	PRESENT	0
206288	206075	19677L	PARTICIPANT	\N	PRESENT	0
206289	206075	08010L	PARTICIPANT	\N	PRESENT	0
206290	206075	08034U	PARTICIPANT	\N	PRESENT	0
206291	206075	08039A	PARTICIPANT	\N	PRESENT	0
206292	206075	19289C	PARTICIPANT	\N	PRESENT	0
206293	206075	08017T	PARTICIPANT	\N	PRESENT	0
206294	206075	19483C	PARTICIPANT	\N	PRESENT	0
206295	206075	19729F	PARTICIPANT	\N	PRESENT	0
206296	206075	01043Q	PARTICIPANT	\N	PRESENT	0
206297	206075	19697Q	PARTICIPANT	\N	PRESENT	0
206298	206075	19581D	PARTICIPANT	\N	PRESENT	0
206299	206075	11077T	PARTICIPANT	\N	PRESENT	0
206300	206075	14205J	PARTICIPANT	\N	PRESENT	0
206301	206075	14219Q	PARTICIPANT	\N	PRESENT	0
206302	206075	01048V	PARTICIPANT	\N	PRESENT	0
206303	206075	14059S	PARTICIPANT	\N	PRESENT	0
206304	206075	19441R	PARTICIPANT	\N	PRESENT	0
206305	206075	08012N	PARTICIPANT	\N	PRESENT	0
206306	206075	17779H	PARTICIPANT	\N	PRESENT	0
206307	206075	14103D	PARTICIPANT	\N	PRESENT	0
206308	206075	12016W	PARTICIPANT	\N	PRESENT	0
206309	206075	80027E	PARTICIPANT	\N	PRESENT	0
206310	206075	11104D	PARTICIPANT	\N	PRESENT	0
206311	206075	08019V	PARTICIPANT	\N	PRESENT	0
206312	206075	19657G	PARTICIPANT	\N	PRESENT	0
206313	206075	14251Q	PARTICIPANT	\N	PRESENT	0
206314	206075	14063N	PARTICIPANT	\N	PRESENT	0
206315	206075	14031R	PARTICIPANT	\N	PRESENT	0
206316	206075	14111D	PARTICIPANT	\N	PRESENT	0
206317	206075	19637C	PARTICIPANT	\N	PRESENT	0
206318	206075	14001X	PARTICIPANT	\N	PRESENT	0
206319	206075	11085T	PARTICIPANT	\N	PRESENT	0
206320	206075	01060R	PARTICIPANT	\N	PRESENT	0
206321	206075	08009T	PARTICIPANT	\N	PRESENT	0
206322	206075	08062Y	PARTICIPANT	\N	PRESENT	0
206323	206075	08053X	PARTICIPANT	\N	PRESENT	0
206324	206075	14221J	PARTICIPANT	\N	PRESENT	0
206325	206075	04057K	PARTICIPANT	\N	PRESENT	0
206326	206075	19563B	PARTICIPANT	\N	PRESENT	0
206327	206075	14147R	PARTICIPANT	\N	PRESENT	0
206328	206075	11067R	PARTICIPANT	\N	PRESENT	0
206329	206075	19671E	PARTICIPANT	\N	PRESENT	0
206330	206075	14223L	PARTICIPANT	\N	PRESENT	0
206331	206075	04092N	PARTICIPANT	\N	PRESENT	0
206332	206075	19335Q	PARTICIPANT	\N	PRESENT	0
206333	206075	19369B	PARTICIPANT	\N	PRESENT	0
206334	206075	11072N	PARTICIPANT	\N	PRESENT	0
206335	206075	14109K	PARTICIPANT	\N	PRESENT	0
206336	206075	14257W	PARTICIPANT	\N	PRESENT	0
206337	206075	08011M	PARTICIPANT	\N	PRESENT	0
206338	206075	14265W	PARTICIPANT	\N	PRESENT	0
206339	206075	04070G	PARTICIPANT	\N	PRESENT	0
206340	206075	14119M	PARTICIPANT	\N	PRESENT	0
206341	206075	14071N	PARTICIPANT	\N	PRESENT	0
206343	206075	08021P	PARTICIPANT	\N	PRESENT	0
206344	206075	14169X	PARTICIPANT	\N	PRESENT	0
206345	206075	14253S	PARTICIPANT	\N	PRESENT	0
206346	206075	19593H	PARTICIPANT	\N	PRESENT	0
206347	206075	19573D	PARTICIPANT	\N	PRESENT	0
206348	206075	14191V	PARTICIPANT	\N	PRESENT	0
206349	206075	08073C	PARTICIPANT	\N	PRESENT	0
206350	206075	08061X	PARTICIPANT	\N	PRESENT	0
206351	206075	08047A	PARTICIPANT	\N	PRESENT	0
206352	206075	14237S	PARTICIPANT	\N	PRESENT	0
206353	206075	17637T	PARTICIPANT	\N	PRESENT	0
206354	206075	14028W	PARTICIPANT	\N	PRESENT	0
206355	206075	14193X	PARTICIPANT	\N	PRESENT	0
206356	206075	19533U	PARTICIPANT	\N	PRESENT	0
206357	206075	04088S	PARTICIPANT	\N	PRESENT	0
206358	206075	07034Q	PARTICIPANT	\N	PRESENT	0
206359	206075	19319Q	PARTICIPANT	\N	PRESENT	0
206360	206075	05012A	PARTICIPANT	\N	PRESENT	0
206361	206075	98050T	PARTICIPANT	\N	PRESENT	0
206362	206075	19503N	PARTICIPANT	\N	PRESENT	0
206363	206075	11090Q	PARTICIPANT	\N	PRESENT	0
206364	206075	17583W	PARTICIPANT	\N	PRESENT	0
206365	206075	04043D	PARTICIPANT	\N	PRESENT	0
206366	206075	19735D	PARTICIPANT	\N	PRESENT	0
206367	206075	14235Q	PARTICIPANT	\N	PRESENT	0
206368	206075	19679N	PARTICIPANT	\N	PRESENT	0
206369	206075	95059Q	PARTICIPANT	\N	PRESENT	0
206370	206075	19443T	PARTICIPANT	\N	PRESENT	0
206371	206075	14135M	PARTICIPANT	\N	PRESENT	0
206372	206075	19349W	PARTICIPANT	\N	PRESENT	0
206373	206075	14331P	PARTICIPANT	\N	PRESENT	0
206374	206075	19269X	PARTICIPANT	\N	PRESENT	0
206375	206075	14055N	PARTICIPANT	\N	PRESENT	0
206376	206075	14225N	PARTICIPANT	\N	PRESENT	0
206378	206075	19705W	PARTICIPANT	\N	PRESENT	0
206379	206075	11012A	PARTICIPANT	\N	PRESENT	0
206380	206075	04033B	PARTICIPANT	\N	PRESENT	0
206381	206075	95062K	PARTICIPANT	\N	PRESENT	0
206382	206075	95063L	PARTICIPANT	\N	PRESENT	0
206383	206075	14229S	PARTICIPANT	\N	PRESENT	0
206384	206075	11054L	PARTICIPANT	\N	PRESENT	0
206385	206075	11045K	PARTICIPANT	\N	PRESENT	0
166273	166271	11089X	PARTICIPANT	\N	PRESENT	0
166274	166271	14299H	PARTICIPANT	\N	PRESENT	0
166461	166460	14239U	PARTICIPANT	\N	PRESENT	0
166488	166460	14241N	PARTICIPANT	\N	PRESENT	0
169371	169112	77002U	PARTICIPANT	\N	PRESENT	0
169380	169379	01007L	PARTICIPANT	\N	PRESENT	0
166465	166460	08024S	PARTICIPANT	\N	PRESENT	0
169381	169379	89017R	PARTICIPANT	\N	PRESENT	0
166467	166460	11031D	PRESIDENT	1	PRESENT	0
166468	166460	08052W	PARTICIPANT	\N	PRESENT	0
166469	166460	14041T	PARTICIPANT	\N	PRESENT	0
166470	166460	14217N	PARTICIPANT	\N	PRESENT	0
166471	166460	87003B	PARTICIPANT	\N	EXCUSE	0
169382	169379	11029K	PARTICIPANT	\N	PRESENT	0
166473	166460	14213J	PRESIDENT	0	PRESENT	0
172576	172512	11112D	PARTICIPANT	\N	EXCUSE	0
172545	172512	08048B	PARTICIPANT	\N	PRESENT	0
166476	166460	14147R	PARTICIPANT	\N	PRESENT	0
166477	166460	14223L	PARTICIPANT	\N	PRESENT	0
166478	166460	04092N	PARTICIPANT	\N	EXCUSE	0
166479	166460	14265W	PARTICIPANT	\N	PRESENT	0
166480	166460	14028W	PARTICIPANT	\N	EXCUSE	0
166481	166460	14235Q	PARTICIPANT	\N	PRESENT	0
166482	166460	14331P	PARTICIPANT	\N	PRESENT	0
172853	172852	14239U	PARTICIPANT	\N	PRESENT	0
166484	166460	11097X	PARTICIPANT	\N	PRESENT	0
166485	166460	04045F	PARTICIPANT	\N	PRESENT	0
166486	166460	11094U	PARTICIPANT	\N	PRESENT	0
173634	173633	01007L	PARTICIPANT	\N	PRESENT	0
173635	173633	14259Y	PARTICIPANT	\N	PRESENT	0
172179	171870	14361V	PARTICIPANT	\N	PRESENT	0
172856	172852	08043V	PARTICIPANT	\N	PRESENT	0
172181	171870	14229S	PARTICIPANT	\N	EXCUSE	0
172857	172852	08024S	PARTICIPANT	\N	PRESENT	0
174001	174000	01041N	PARTICIPANT	\N	PRESENT	0
172859	172852	11031D	PARTICIPANT	\N	PRESENT	0
172185	171870	14363X	PARTICIPANT	\N	PRESENT	0
172860	172852	08052W	PRESIDENT	1	PRESENT	0
174002	174000	01044R	PARTICIPANT	\N	PRESENT	0
174003	174000	14079W	PARTICIPANT	\N	PRESENT	0
172546	172512	08041T	PARTICIPANT	\N	PRESENT	0
174004	174000	08017T	PARTICIPANT	\N	PRESENT	0
175526	174472	05008E	PARTICIPANT	\N	PRESENT	0
172547	172512	01011G	PARTICIPANT	\N	PRESENT	0
175527	174472	14259Y	PARTICIPANT	\N	PRESENT	0
175528	174472	11113E	PARTICIPANT	\N	PRESENT	0
175529	174472	08044W	PARTICIPANT	\N	EXCUSE	0
172868	172852	14147R	PARTICIPANT	\N	PRESENT	0
175530	174472	14147R	PARTICIPANT	\N	PRESENT	0
172870	172852	04092N	PRESIDENT	0	PRESENT	0
172871	172852	14265W	PARTICIPANT	\N	PRESENT	0
172872	172852	14028W	PARTICIPANT	\N	PRESENT	0
172873	172852	14235Q	PARTICIPANT	\N	EXCUSE	0
175531	174472	11072N	PARTICIPANT	\N	PRESENT	0
172875	172852	14271U	PARTICIPANT	\N	PRESENT	0
172876	172852	11097X	PARTICIPANT	\N	PRESENT	0
175532	174472	01028R	PARTICIPANT	\N	PRESENT	0
175533	174472	04044E	PARTICIPANT	\N	PRESENT	0
175534	174472	11037K	PARTICIPANT	\N	PRESENT	0
175535	174472	01047U	PARTICIPANT	\N	PRESENT	0
175680	175676	04040A	PARTICIPANT	\N	PRESENT	0
175681	175676	14105F	PARTICIPANT	\N	PRESENT	0
175682	175676	11029K	PARTICIPANT	\N	PRESENT	0
175684	175676	01059Y	PARTICIPANT	\N	PRESENT	0
175685	175676	95035G	PARTICIPANT	\N	PRESENT	0
175686	175676	14081Q	PARTICIPANT	\N	PRESENT	0
175688	175676	14073Q	PARTICIPANT	\N	PRESENT	0
175689	175676	04057K	PARTICIPANT	\N	PRESENT	0
175691	175676	92040Q	PARTICIPANT	\N	PRESENT	0
175692	175676	95062K	PARTICIPANT	\N	PRESENT	0
172548	172512	14026U	PARTICIPANT	\N	PRESENT	0
172549	172512	14213J	PARTICIPANT	\N	PRESENT	0
172550	172512	14121F	PARTICIPANT	\N	PRESENT	0
175694	175676	04044E	PARTICIPANT	\N	PRESENT	0
172552	172512	14037X	PARTICIPANT	\N	PRESENT	0
172553	172512	14018U	PARTICIPANT	\N	PRESENT	0
172554	172512	11067R	PARTICIPANT	\N	PRESENT	0
172555	172512	14223L	PARTICIPANT	\N	PRESENT	0
172556	172512	04092N	PRESIDENT	0	PRESENT	0
172557	172512	14265W	PARTICIPANT	\N	PRESENT	0
172558	172512	14119M	PARTICIPANT	\N	PRESENT	0
172559	172512	14071N	PARTICIPANT	\N	PRESENT	0
172560	172512	04043D	PARTICIPANT	\N	PRESENT	0
172561	172512	14271U	PARTICIPANT	\N	PRESENT	0
175707	175705	11029K	PARTICIPANT	\N	PRESENT	0
172563	172512	11093T	PARTICIPANT	\N	PRESENT	0
172564	172512	11097X	PARTICIPANT	\N	PRESENT	0
172565	172512	04045F	PARTICIPANT	\N	PRESENT	0
172566	172512	14227Q	PARTICIPANT	\N	PRESENT	0
172567	172512	01034P	PARTICIPANT	\N	PRESENT	0
172568	172512	11025F	PARTICIPANT	\N	PRESENT	0
175708	175705	01059Y	PARTICIPANT	\N	PRESENT	0
172570	172512	14269B	PARTICIPANT	\N	PRESENT	0
175710	175705	95035G	PARTICIPANT	\N	PRESENT	0
175711	175705	04044E	PARTICIPANT	\N	PRESENT	0
175713	175705	04057K	PARTICIPANT	\N	PRESENT	0
175714	175705	92040Q	PARTICIPANT	\N	PRESENT	0
175932	175931	11043H	PARTICIPANT	\N	PRESENT	0
175990	175931	11039M	PARTICIPANT	\N	PRESENT	0
175991	175931	14199E	PARTICIPANT	\N	PRESENT	0
175992	175931	14073Q	PARTICIPANT	\N	PRESENT	0
175993	175931	08012N	PARTICIPANT	\N	PRESENT	0
175994	175931	11014C	PARTICIPANT	\N	PRESENT	0
175995	175931	87003B	PARTICIPANT	\N	PRESENT	0
175996	175931	14241N	PARTICIPANT	\N	PRESENT	0
176519	176513	01046T	PARTICIPANT	\N	PRESENT	0
176520	176513	11055M	PARTICIPANT	\N	EXCUSE	0
176521	176513	04053F	PARTICIPANT	\N	PRESENT	0
176522	176513	00003C	PARTICIPANT	\N	EXCUSE	0
176523	176513	14053L	PARTICIPANT	\N	EXCUSE	0
176526	176513	11103C	PARTICIPANT	\N	PRESENT	0
176527	176513	14195A	PARTICIPANT	\N	PRESENT	0
176528	176513	14267Y	PARTICIPANT	\N	PRESENT	0
176529	176513	11031D	PARTICIPANT	\N	PRESENT	0
176530	176513	08052W	PARTICIPANT	\N	PRESENT	0
176531	176513	98024R	PARTICIPANT	\N	PRESENT	0
176532	176513	04067M	PARTICIPANT	\N	PRESENT	0
176533	176513	14217N	PARTICIPANT	\N	PRESENT	0
176534	176513	14151M	PARTICIPANT	\N	PRESENT	0
176535	176513	12042Y	PARTICIPANT	\N	PRESENT	0
176536	176513	14281W	PARTICIPANT	\N	PRESENT	0
176537	176513	01003G	PARTICIPANT	\N	EXCUSE	0
176538	176513	14231L	PARTICIPANT	\N	PRESENT	0
176539	176513	11061K	PARTICIPANT	\N	PRESENT	0
176540	176513	14355X	PARTICIPANT	\N	PRESENT	0
176541	176513	08048B	PARTICIPANT	\N	PRESENT	0
176542	176513	08041T	PARTICIPANT	\N	PRESENT	0
176543	176513	01011G	PARTICIPANT	\N	PRESENT	0
176544	176513	14026U	PARTICIPANT	\N	PRESENT	0
176545	176513	14213J	PARTICIPANT	\N	PRESENT	0
176546	176513	14121F	PARTICIPANT	\N	PRESENT	0
176547	176513	11112D	PARTICIPANT	\N	PRESENT	0
176548	176513	14037X	PARTICIPANT	\N	PRESENT	0
176549	176513	14018U	PARTICIPANT	\N	PRESENT	0
176550	176513	11067R	PARTICIPANT	\N	PRESENT	0
176551	176513	14223L	PARTICIPANT	\N	PRESENT	0
176552	176513	04092N	PRESIDENT	0	PRESENT	0
176553	176513	14265W	PARTICIPANT	\N	PRESENT	0
176554	176513	14119M	PARTICIPANT	\N	PRESENT	0
176555	176513	14071N	PARTICIPANT	\N	PRESENT	0
176556	176513	14271U	PARTICIPANT	\N	PRESENT	0
176557	176513	14017T	PARTICIPANT	\N	EXCUSE	0
176558	176513	11093T	PARTICIPANT	\N	PRESENT	0
176559	176513	11097X	PARTICIPANT	\N	PRESENT	0
176560	176513	04045F	PARTICIPANT	\N	PRESENT	0
176561	176513	14227Q	PARTICIPANT	\N	PRESENT	0
176562	176513	01034P	PARTICIPANT	\N	PRESENT	0
176563	176513	11025F	PARTICIPANT	\N	PRESENT	0
176564	176513	11063M	PARTICIPANT	\N	PRESENT	0
176565	176513	14269B	PARTICIPANT	\N	PRESENT	0
176572	176513	92045V	PARTICIPANT	\N	PRESENT	0
176625	176296	14205J	PARTICIPANT	\N	PRESENT	0
176627	176296	14041T	PARTICIPANT	\N	PRESENT	0
176630	176296	14225N	PARTICIPANT	\N	PRESENT	0
176631	176296	01058X	PARTICIPANT	\N	PRESENT	0
176633	176296	97011G	PARTICIPANT	\N	PRESENT	0
176635	176296	13002U	PARTICIPANT	\N	PRESENT	0
176636	176296	14223L	PARTICIPANT	\N	PRESENT	0
176637	176296	14081Q	PARTICIPANT	\N	PRESENT	0
197134	190782	14327T	PARTICIPANT	\N	PRESENT	0
197135	190782	08016S	PARTICIPANT	\N	PRESENT	0
197136	190782	11039M	PARTICIPANT	\N	PRESENT	0
197137	190782	14107H	PARTICIPANT	\N	PRESENT	0
197138	190782	04088S	PARTICIPANT	\N	PRESENT	0
197139	190782	14281W	PARTICIPANT	\N	PRESENT	0
197140	190782	11061K	PARTICIPANT	\N	PRESENT	0
197141	190782	14197C	PARTICIPANT	\N	PRESENT	0
197142	190782	19251M	PARTICIPANT	\N	PRESENT	0
197143	190782	08017T	PARTICIPANT	\N	PRESENT	0
197144	190782	95049N	PARTICIPANT	\N	PRESENT	0
197145	190782	14069U	PARTICIPANT	\N	PRESENT	0
197146	190782	14083S	PARTICIPANT	\N	PRESENT	0
197147	190782	04053F	PARTICIPANT	\N	PRESENT	0
197148	190782	01031L	PARTICIPANT	\N	PRESENT	0
197149	190782	08069G	PARTICIPANT	\N	PRESENT	0
197296	197218	11048N	PARTICIPANT	\N	PRESENT	0
197221	197218	08055A	PARTICIPANT	\N	PRESENT	0
197458	197457	11039M	PARTICIPANT	\N	PRESENT	0
197223	197218	14030Q	PARTICIPANT	\N	PRESENT	0
197459	197457	98042T	PARTICIPANT	\N	PRESENT	0
197225	197218	08060W	PARTICIPANT	\N	PRESENT	0
197460	197457	01019Q	PARTICIPANT	\N	PRESENT	0
197227	197218	14038Y	PARTICIPANT	\N	EXCUSE	0
197462	196878	18003S	PARTICIPANT	\N	EXCUSE	0
197229	197218	98023Q	PARTICIPANT	\N	PRESENT	0
197231	197218	01015L	PARTICIPANT	\N	PRESENT	0
197232	197218	11107G	PARTICIPANT	\N	PRESENT	0
197234	197218	02002K	PARTICIPANT	\N	PRESENT	0
197235	197218	01022K	PARTICIPANT	\N	EXCUSE	0
197239	197218	11059R	PARTICIPANT	\N	PRESENT	0
197240	197218	14219Q	PARTICIPANT	\N	PRESENT	0
197241	197218	80027E	PARTICIPANT	\N	PRESENT	0
197242	197218	14031R	PARTICIPANT	\N	PRESENT	0
197243	197218	08009T	PRESIDENT	0	PRESENT	0
197244	197218	08062Y	PARTICIPANT	\N	PRESENT	0
197471	196878	14299H	PARTICIPANT	\N	PRESENT	0
197248	197218	14169X	PARTICIPANT	\N	PRESENT	0
197249	197218	14237S	PARTICIPANT	\N	PRESENT	0
197250	197218	13002U	PARTICIPANT	\N	PRESENT	0
197251	197218	05012A	PARTICIPANT	\N	PRESENT	0
197253	197218	14135M	PARTICIPANT	\N	PRESENT	0
197254	197218	14331P	PARTICIPANT	\N	EXCUSE	0
197255	197218	95062K	PARTICIPANT	\N	EXCUSE	0
197256	197218	14107H	PARTICIPANT	\N	PRESENT	0
197258	197218	14157T	PARTICIPANT	\N	PRESENT	0
197673	197672	98035U	PARTICIPANT	\N	PRESENT	0
197815	190786	14030Q	PARTICIPANT	\N	PRESENT	0
197816	190786	08061X	PARTICIPANT	\N	PRESENT	0
197832	190786	14327T	PARTICIPANT	\N	PRESENT	0
197833	190786	11096W	PARTICIPANT	\N	PRESENT	0
197834	190786	14169X	PARTICIPANT	\N	PRESENT	0
197835	190786	14235Q	PARTICIPANT	\N	PRESENT	0
197836	190786	14361V	PARTICIPANT	\N	PRESENT	0
197837	190786	14133K	PARTICIPANT	\N	PRESENT	0
197838	190786	14028W	PARTICIPANT	\N	PRESENT	0
197839	190786	04056J	PARTICIPANT	\N	PRESENT	0
197840	190786	11054L	PARTICIPANT	\N	PRESENT	0
197841	190786	14225N	PARTICIPANT	\N	PRESENT	0
197842	190786	14281W	PARTICIPANT	\N	PRESENT	0
197852	190786	14123H	PARTICIPANT	\N	PRESENT	0
197853	190786	80013X	PARTICIPANT	\N	PRESENT	0
197854	190786	14151M	PARTICIPANT	\N	PRESENT	0
197855	190786	11046L	PARTICIPANT	\N	PRESENT	0
197856	190786	16813M	PARTICIPANT	\N	PRESENT	0
197857	190786	11080N	PARTICIPANT	\N	PRESENT	0
197858	190786	08047A	PARTICIPANT	\N	PRESENT	0
197859	190786	14217N	PARTICIPANT	\N	PRESENT	0
197860	190786	08010L	PARTICIPANT	\N	PRESENT	0
197861	190786	08039A	PARTICIPANT	\N	PRESENT	0
197862	190786	98050T	PARTICIPANT	\N	PRESENT	0
197863	190786	11090Q	PARTICIPANT	\N	PRESENT	0
197864	190786	14053L	PARTICIPANT	\N	PRESENT	0
197865	190786	14069U	PARTICIPANT	\N	PRESENT	0
197866	190786	04086Q	PARTICIPANT	\N	PRESENT	0
197867	190786	11100Y	PARTICIPANT	\N	PRESENT	0
197868	190786	11104D	PARTICIPANT	\N	PRESENT	0
197869	190786	97011G	PARTICIPANT	\N	PRESENT	0
197870	190786	04081K	PARTICIPANT	\N	PRESENT	0
197871	190786	14239U	PARTICIPANT	\N	PRESENT	0
197872	190786	04043D	PARTICIPANT	\N	PRESENT	0
197873	190786	14257W	PARTICIPANT	\N	PRESENT	0
197874	190786	14034U	PARTICIPANT	\N	PRESENT	0
197875	190786	08068F	PARTICIPANT	\N	PRESENT	0
197876	190786	11065P	PARTICIPANT	\N	PRESENT	0
197877	190786	11082Q	PARTICIPANT	\N	PRESENT	0
197878	190786	14093U	PARTICIPANT	\N	PRESENT	0
197879	190786	10015M	PARTICIPANT	\N	PRESENT	0
197880	190786	14201E	PARTICIPANT	\N	PRESENT	0
197881	190786	11048N	PARTICIPANT	\N	PRESENT	0
197893	190786	08069G	PARTICIPANT	\N	PRESENT	0
197894	190786	14135M	PARTICIPANT	\N	PRESENT	0
197895	190786	14197C	PARTICIPANT	\N	PRESENT	0
197896	190786	05012A	PARTICIPANT	\N	PRESENT	0
197897	197413	04086Q	PARTICIPANT	\N	PRESENT	0
197898	197413	14083S	PARTICIPANT	\N	PRESENT	0
197899	197413	14085U	PARTICIPANT	\N	PRESENT	0
197900	197413	01057W	PARTICIPANT	\N	PRESENT	0
197901	197413	01016M	PARTICIPANT	\N	PRESENT	0
197902	197413	11083R	PARTICIPANT	\N	PRESENT	0
197903	197413	99004R	PARTICIPANT	\N	PRESENT	0
197904	197413	14159V	PARTICIPANT	\N	PRESENT	0
197905	197413	14225N	PARTICIPANT	\N	PRESENT	0
197906	197413	11042G	PARTICIPANT	\N	PRESENT	0
197907	197413	11088W	PRESIDENT	0	PRESENT	0
197908	197413	14173T	PARTICIPANT	\N	PRESENT	0
197909	197413	07029T	PARTICIPANT	\N	PRESENT	0
197910	197413	01031L	PARTICIPANT	\N	EXCUSE	0
197911	197413	11012A	PARTICIPANT	\N	EXCUSE	0
197932	197413	11048N	PARTICIPANT	\N	PRESENT	0
197933	197413	11053K	PARTICIPANT	\N	PRESENT	0
197934	197413	08011M	PARTICIPANT	\N	PRESENT	0
197935	197413	11070L	PARTICIPANT	\N	PRESENT	0
197936	197413	08010L	PARTICIPANT	\N	PRESENT	0
197937	190786	04097T	PARTICIPANT	\N	PRESENT	0
197938	197413	08034U	PARTICIPANT	\N	PRESENT	0
197939	197413	01027Q	PARTICIPANT	\N	PRESENT	0
197940	197413	04061F	PARTICIPANT	\N	PRESENT	0
197941	197413	01013J	PARTICIPANT	\N	PRESENT	0
197942	190786	04040A	PARTICIPANT	\N	PRESENT	0
197944	190786	02002K	PARTICIPANT	\N	PRESENT	0
197953	197943	04067M	PARTICIPANT	\N	PRESENT	0
197954	197943	11067R	PARTICIPANT	\N	PRESENT	0
197955	197943	01046T	PARTICIPANT	\N	PRESENT	0
197956	197943	11061K	PARTICIPANT	\N	PRESENT	0
197957	197943	14223L	PARTICIPANT	\N	PRESENT	0
197958	197943	04045F	PARTICIPANT	\N	PRESENT	0
197959	197943	14026U	PARTICIPANT	\N	PRESENT	0
197960	197943	14227Q	PARTICIPANT	\N	PRESENT	0
197961	197943	11112D	PARTICIPANT	\N	PRESENT	0
197962	197943	14269B	PARTICIPANT	\N	PRESENT	0
197963	197943	14231L	PARTICIPANT	\N	PRESENT	0
197964	197943	11063M	PARTICIPANT	\N	PRESENT	0
197965	197943	11031D	PARTICIPANT	\N	PRESENT	0
197966	197943	14239U	PARTICIPANT	\N	PRESENT	0
197967	197943	01059Y	PARTICIPANT	\N	PRESENT	0
197968	197943	14087W	PARTICIPANT	\N	PRESENT	0
197969	197943	14281W	PARTICIPANT	\N	PRESENT	0
197970	197943	14271U	PARTICIPANT	\N	PRESENT	0
197971	197943	14042U	PARTICIPANT	\N	PRESENT	0
197972	197943	14195A	PARTICIPANT	\N	PRESENT	0
197973	197943	14213J	PARTICIPANT	\N	PRESENT	0
197974	197943	14151M	PARTICIPANT	\N	PRESENT	0
197975	197943	14217N	PARTICIPANT	\N	PRESENT	0
197976	197943	10006L	PARTICIPANT	\N	PRESENT	0
197977	197943	98024R	PARTICIPANT	\N	PRESENT	0
197978	197943	14053L	PARTICIPANT	\N	PRESENT	0
197979	197943	01034P	PARTICIPANT	\N	PRESENT	0
197980	197943	04092N	PRESIDENT	0	PRESENT	0
197981	197943	08052W	PARTICIPANT	\N	PRESENT	0
197982	197943	12042Y	PARTICIPANT	\N	PRESENT	0
197983	197943	14034U	PARTICIPANT	\N	PRESENT	0
197984	197943	11093T	PARTICIPANT	\N	PRESENT	0
197985	197943	08041T	PARTICIPANT	\N	PRESENT	0
197986	197943	04081K	PARTICIPANT	\N	PRESENT	0
174293	174292	08010L	PARTICIPANT	\N	PRESENT	0
176856	176855	11076S	PARTICIPANT	\N	PRESENT	0
176857	176855	14133K	PARTICIPANT	\N	PRESENT	0
176932	176855	96004D	PARTICIPANT	\N	PRESENT	0
176859	176855	04040A	PARTICIPANT	\N	PRESENT	0
176860	176855	08058D	PARTICIPANT	\N	PRESENT	0
176861	176855	04042C	PARTICIPANT	\N	PRESENT	0
176933	176855	14026U	PARTICIPANT	\N	PRESENT	0
176863	176855	98029W	PARTICIPANT	\N	PRESENT	0
176934	176855	10015M	PARTICIPANT	\N	PRESENT	0
176935	176855	04061F	PARTICIPANT	\N	PRESENT	0
176866	176855	98018T	PARTICIPANT	\N	PRESENT	0
176936	176855	95063L	PARTICIPANT	\N	PRESENT	0
176868	176855	92020L	PARTICIPANT	\N	PRESENT	0
176869	176855	95030B	PARTICIPANT	\N	PRESENT	0
176937	176855	04034C	PARTICIPANT	\N	PRESENT	0
176938	176855	01016M	PARTICIPANT	\N	PRESENT	0
176872	176855	97011G	PARTICIPANT	\N	PRESENT	0
176939	176855	11026G	PARTICIPANT	\N	PRESENT	0
176940	176855	98046X	PARTICIPANT	\N	PRESENT	0
176954	176953	14133K	PARTICIPANT	\N	PRESENT	0
176876	176855	14014Q	PARTICIPANT	\N	PRESENT	0
176955	176953	96004D	PRESIDENT	0	PRESENT	0
176956	176953	95030B	PARTICIPANT	\N	PRESENT	0
176879	176855	95035G	PARTICIPANT	\N	PRESENT	0
176957	176953	04035D	PARTICIPANT	\N	PRESENT	0
176881	176855	14211G	PARTICIPANT	\N	PRESENT	0
176882	176855	98022P	PARTICIPANT	\N	PRESENT	0
176958	176953	14026U	PARTICIPANT	\N	PRESENT	0
176884	176855	95037J	PARTICIPANT	\N	PRESENT	0
176885	176855	04078Q	PARTICIPANT	\N	PRESENT	0
176886	176855	14097Y	PARTICIPANT	\N	PRESENT	0
176959	176953	95037J	PARTICIPANT	\N	PRESENT	0
176888	176855	04036E	PARTICIPANT	\N	PRESENT	0
176960	176953	14097Y	PARTICIPANT	\N	PRESENT	0
176961	176953	04061F	PARTICIPANT	\N	PRESENT	0
176962	176953	11026G	PARTICIPANT	\N	PRESENT	0
176892	176855	92031P	PARTICIPANT	\N	PRESENT	0
176963	176953	98046X	PARTICIPANT	\N	PRESENT	0
176894	176855	14251Q	PARTICIPANT	\N	PRESENT	0
176895	176855	83042R	PARTICIPANT	\N	PRESENT	0
177033	177002	08058D	PARTICIPANT	\N	PRESENT	0
176965	176953	04080J	PARTICIPANT	\N	PRESENT	0
176966	176953	01016M	PARTICIPANT	\N	PRESENT	0
176967	176953	10015M	PARTICIPANT	\N	PRESENT	0
176968	176953	95063L	PARTICIPANT	\N	PRESENT	0
176901	176855	14028W	PARTICIPANT	\N	EXCUSE	0
176969	176953	04034C	PARTICIPANT	\N	PRESENT	0
176970	176953	04045F	PARTICIPANT	\N	EXCUSE	0
176904	176855	04080J	PARTICIPANT	\N	PRESENT	0
176905	176855	95059Q	PRESIDENT	0	PRESENT	0
176971	176953	14001X	PARTICIPANT	\N	EXCUSE	0
176907	176855	01014K	PARTICIPANT	\N	PRESENT	0
176908	176855	11054L	PARTICIPANT	\N	PRESENT	0
176972	176953	14251Q	PARTICIPANT	\N	PRESENT	0
176973	176953	11076S	PARTICIPANT	\N	PRESENT	0
176974	176953	04040A	PARTICIPANT	\N	PRESENT	0
176975	176953	04042C	PARTICIPANT	\N	PRESENT	0
176976	176953	98029W	PARTICIPANT	\N	PRESENT	0
176977	176953	98018T	PARTICIPANT	\N	PRESENT	0
176978	176953	92020L	PARTICIPANT	\N	PRESENT	0
176979	176953	08058D	PARTICIPANT	\N	PRESENT	0
176980	176953	97011G	PARTICIPANT	\N	PRESENT	0
176981	176953	04078Q	PARTICIPANT	\N	PRESENT	0
176982	176953	95035G	PARTICIPANT	\N	PRESENT	0
176983	176953	04036E	PARTICIPANT	\N	PRESENT	0
176984	176953	14211G	PARTICIPANT	\N	PRESENT	0
176985	176953	14014Q	PARTICIPANT	\N	PRESENT	0
176986	176953	92031P	PARTICIPANT	\N	PRESENT	0
176987	176953	98022P	PARTICIPANT	\N	PRESENT	0
176988	176953	83042R	PARTICIPANT	\N	PRESENT	0
176989	176953	95059Q	PARTICIPANT	\N	PRESENT	0
176990	176953	01014K	PARTICIPANT	\N	PRESENT	0
176991	176953	11054L	PARTICIPANT	\N	PRESENT	0
177003	177002	14133K	PARTICIPANT	\N	PRESENT	0
177004	177002	96004D	PRESIDENT	0	PRESENT	0
177005	177002	04040A	PARTICIPANT	\N	PRESENT	0
177006	177002	04042C	PARTICIPANT	\N	PRESENT	0
177007	177002	04035D	PARTICIPANT	\N	PRESENT	0
177008	177002	14014Q	PARTICIPANT	\N	PRESENT	0
177009	177002	98022P	PARTICIPANT	\N	PRESENT	0
177010	177002	04061F	PARTICIPANT	\N	PRESENT	0
177011	177002	14097Y	PARTICIPANT	\N	PRESENT	0
177012	177002	14001X	PARTICIPANT	\N	EXCUSE	0
177013	177002	83042R	PARTICIPANT	\N	PRESENT	0
177014	177002	04057K	PARTICIPANT	\N	PRESENT	0
177015	177002	04080J	PARTICIPANT	\N	PRESENT	0
177016	177002	95059Q	PRESIDENT	1	PRESENT	0
177017	177002	04034C	PARTICIPANT	\N	PRESENT	0
177032	177002	11076S	PARTICIPANT	\N	PRESENT	0
177034	177002	98029W	PARTICIPANT	\N	PRESENT	0
177035	177002	98018T	PARTICIPANT	\N	PRESENT	0
177036	177002	95030B	PARTICIPANT	\N	PRESENT	0
177037	177002	97011G	PARTICIPANT	\N	PRESENT	0
177038	177002	14026U	PARTICIPANT	\N	PRESENT	0
177039	177002	04078Q	PARTICIPANT	\N	PRESENT	0
177040	177002	95037J	PARTICIPANT	\N	PRESENT	0
177041	177002	14211G	PARTICIPANT	\N	PRESENT	0
177042	177002	95035G	PARTICIPANT	\N	PRESENT	0
177043	177002	04036E	PARTICIPANT	\N	PRESENT	0
177044	177002	92031P	PARTICIPANT	\N	PRESENT	0
177045	177002	11026G	PARTICIPANT	\N	PRESENT	0
177046	177002	14251Q	PARTICIPANT	\N	PRESENT	0
177047	177002	01014K	PARTICIPANT	\N	PRESENT	0
177048	177002	10015M	PARTICIPANT	\N	PRESENT	0
177049	177002	11054L	PARTICIPANT	\N	PRESENT	0
177050	177002	92020L	PARTICIPANT	\N	PRESENT	0
177051	177002	98046X	PARTICIPANT	\N	PRESENT	0
177052	177002	95063L	PARTICIPANT	\N	PRESENT	0
177054	177053	14133K	PARTICIPANT	\N	PRESENT	0
177055	177053	96004D	PRESIDENT	0	PRESENT	0
177056	177053	04040A	PARTICIPANT	\N	PRESENT	0
177057	177053	11040E	PARTICIPANT	\N	PRESENT	0
177058	177053	04042C	PARTICIPANT	\N	PRESENT	0
177059	177053	04035D	PARTICIPANT	\N	PRESENT	0
177060	177053	14014Q	PARTICIPANT	\N	PRESENT	0
177061	177053	98022P	PARTICIPANT	\N	PRESENT	0
177062	177053	14097Y	PARTICIPANT	\N	PRESENT	0
177063	177053	04061F	PARTICIPANT	\N	PRESENT	0
177067	177053	04080J	PARTICIPANT	\N	PRESENT	0
177065	177053	83042R	PARTICIPANT	\N	PRESENT	0
177066	177053	04057K	PARTICIPANT	\N	PRESENT	0
177068	177053	95059Q	PRESIDENT	1	PRESENT	0
177069	177053	98035U	PARTICIPANT	\N	PRESENT	0
178227	178217	08018U	PARTICIPANT	\N	PRESENT	0
178428	178427	11048N	PARTICIPANT	\N	PRESENT	0
178429	178427	14059S	PARTICIPANT	\N	PRESENT	0
178431	178430	11048N	PARTICIPANT	\N	PRESENT	0
178574	178573	98029W	PARTICIPANT	\N	PRESENT	0
178575	178573	14249W	PARTICIPANT	\N	PRESENT	0
178576	178573	95067Q	PARTICIPANT	\N	PRESENT	0
178577	178573	04036E	PARTICIPANT	\N	PRESENT	0
178733	178732	04070G	PARTICIPANT	\N	PRESENT	0
178734	178732	04040A	PARTICIPANT	\N	PRESENT	0
178735	178732	14255U	PARTICIPANT	\N	PRESENT	0
178736	178732	08018U	PARTICIPANT	\N	PRESENT	0
178737	178732	11027H	PARTICIPANT	\N	PRESENT	0
178738	178732	08015R	PARTICIPANT	\N	PRESENT	0
178739	178732	04036E	PARTICIPANT	\N	PRESENT	0
178740	178732	88008L	PARTICIPANT	\N	PRESENT	0
178741	178732	14073Q	PARTICIPANT	\N	PRESENT	0
178753	178752	77002U	PARTICIPANT	\N	PRESENT	0
178754	178752	11042G	PARTICIPANT	\N	PRESENT	0
183993	183992	14207L	PARTICIPANT	\N	PRESENT	0
183994	183992	14089Y	PARTICIPANT	\N	PRESENT	0
183995	183992	11029K	PARTICIPANT	\N	PRESENT	0
183996	183992	14053L	PARTICIPANT	\N	PRESENT	0
184015	184012	11029K	PARTICIPANT	\N	PRESENT	0
184013	184012	14207L	PARTICIPANT	\N	PRESENT	0
184014	184012	14089Y	PARTICIPANT	\N	PRESENT	0
184032	184012	14281W	PARTICIPANT	\N	PRESENT	0
184033	184012	14053L	PARTICIPANT	\N	PRESENT	0
184052	184012	14237S	PARTICIPANT	\N	PRESENT	0
184054	184053	14089Y	PARTICIPANT	\N	PRESENT	0
184055	184053	14207L	PARTICIPANT	\N	PRESENT	0
184056	184053	11029K	PARTICIPANT	\N	PRESENT	0
184057	184053	14281W	PARTICIPANT	\N	PRESENT	0
184058	184053	14237S	PARTICIPANT	\N	PRESENT	0
184072	183732	14273W	PARTICIPANT	\N	PRESENT	0
184073	183732	11056N	PARTICIPANT	\N	EXCUSE	0
184074	183732	92045V	PARTICIPANT	\N	EXCUSE	0
184075	183732	07034Q	PARTICIPANT	\N	EXCUSE	0
184076	183732	14001X	PARTICIPANT	\N	EXCUSE	0
184092	183732	10015M	PARTICIPANT	\N	PRESENT	0
184093	183732	01028R	PARTICIPANT	\N	PRESENT	0
184094	183732	05008E	PRESIDENT	0	PRESENT	0
184095	183732	01024M	PARTICIPANT	\N	PRESENT	0
184096	183732	95049N	PARTICIPANT	\N	PRESENT	0
184097	183732	11037K	PARTICIPANT	\N	PRESENT	0
206386	206075	14107H	PARTICIPANT	\N	PRESENT	0
206387	206075	19619A	PARTICIPANT	\N	PRESENT	0
206388	206075	19421M	PARTICIPANT	\N	PRESENT	0
206389	206075	11097X	PARTICIPANT	\N	PRESENT	0
206390	206075	11043H	PARTICIPANT	\N	PRESENT	0
206391	206075	19687N	PARTICIPANT	\N	PRESENT	0
206392	206075	04045F	PARTICIPANT	\N	PRESENT	0
206393	206075	04018C	PARTICIPANT	\N	PRESENT	0
206394	206075	01058X	PARTICIPANT	\N	PRESENT	0
206395	206075	19703U	PARTICIPANT	\N	PRESENT	0
206396	206075	19713W	PARTICIPANT	\N	PRESENT	0
206397	206075	01028R	PARTICIPANT	\N	PRESENT	0
206398	206075	98035U	PARTICIPANT	\N	PRESENT	0
206399	206075	19689Q	PARTICIPANT	\N	PRESENT	0
206400	206075	19669L	PARTICIPANT	\N	PRESENT	0
206401	206075	14275Y	PARTICIPANT	\N	PRESENT	0
206402	206075	19301E	PARTICIPANT	\N	PRESENT	0
206403	206075	19675J	PARTICIPANT	\N	PRESENT	0
206404	206075	19413M	PARTICIPANT	\N	PRESENT	0
206405	206075	14051J	PARTICIPANT	\N	PRESENT	0
206406	206075	01062T	PARTICIPANT	\N	PRESENT	0
206407	206075	14227Q	PARTICIPANT	\N	PRESENT	0
206408	206075	04044E	PARTICIPANT	\N	PRESENT	0
206409	206075	11041F	PARTICIPANT	\N	PRESENT	0
206410	206075	08049C	PARTICIPANT	\N	PRESENT	0
206411	206075	19527W	PARTICIPANT	\N	PRESENT	0
206412	206075	01034P	PARTICIPANT	\N	PRESENT	0
206413	206075	14157T	PARTICIPANT	\N	PRESENT	0
206414	206075	11066Q	PARTICIPANT	\N	PRESENT	0
206415	206075	19479G	PARTICIPANT	\N	PRESENT	0
206416	206075	95067Q	PARTICIPANT	\N	PRESENT	0
206417	206075	14173T	PARTICIPANT	\N	PRESENT	0
206418	206075	19737F	PARTICIPANT	\N	PRESENT	0
206419	206075	11063M	PARTICIPANT	\N	PRESENT	0
206420	206075	19585H	PARTICIPANT	\N	PRESENT	0
206482	206480	04047H	PARTICIPANT	\N	PRESENT	0
206481	206480	14065Q	PARTICIPANT	\N	PRESENT	0
206488	206487	04047H	PRESIDENT	1	PRESENT	0
206489	206487	11080N	PARTICIPANT	\N	PRESENT	0
206490	206487	01057W	PARTICIPANT	\N	PRESENT	0
206491	206487	14021P	PARTICIPANT	\N	PRESENT	0
206492	206487	08049C	PRESIDENT	0	PRESENT	0
206493	206487	14157T	PARTICIPANT	\N	PRESENT	0
206532	204333	19717B	PARTICIPANT	\N	PRESENT	0
206729	206727	11026G	PARTICIPANT	\N	PRESENT	0
206581	206578	08055A	PARTICIPANT	\N	PRESENT	0
206582	206578	14093U	PARTICIPANT	\N	PRESENT	0
206583	206578	19549D	PARTICIPANT	\N	PRESENT	0
206730	206727	08034U	PARTICIPANT	\N	PRESENT	0
206585	206578	08060W	PARTICIPANT	\N	PRESENT	0
206586	206578	19733B	PARTICIPANT	\N	PRESENT	0
206732	206727	14281W	PARTICIPANT	\N	PRESENT	0
206588	206578	08024S	PARTICIPANT	\N	PRESENT	0
206747	206514	01043Q	PARTICIPANT	\N	PRESENT	0
206590	206578	18083K	PARTICIPANT	\N	PRESENT	0
206748	206514	11099A	PARTICIPANT	\N	PRESENT	0
206592	206578	19681G	PARTICIPANT	\N	PRESENT	0
206593	206578	98023Q	PARTICIPANT	\N	PRESENT	0
206594	206578	19525U	PARTICIPANT	\N	PRESENT	0
206595	206578	11065P	PARTICIPANT	\N	PRESENT	0
206749	206514	89017R	PARTICIPANT	\N	PRESENT	0
206750	206514	14026U	PARTICIPANT	\N	PRESENT	0
206598	206578	02002K	PARTICIPANT	\N	PRESENT	0
206599	206578	15447F	PARTICIPANT	\N	PRESENT	0
206600	206578	19387D	PARTICIPANT	\N	PRESENT	0
206601	206578	19347U	PARTICIPANT	\N	PRESENT	0
206751	206514	19591F	PARTICIPANT	\N	PRESENT	0
206752	206514	19413M	PARTICIPANT	\N	PRESENT	0
206604	206578	19333N	PARTICIPANT	\N	EXCUSE	0
206605	206578	04097T	PARTICIPANT	\N	PRESENT	0
206606	206578	19551W	PARTICIPANT	\N	PRESENT	0
206607	206578	14029X	PARTICIPANT	\N	PRESENT	0
206608	206578	19677L	PARTICIPANT	\N	PRESENT	0
206753	206514	14135M	PARTICIPANT	\N	PRESENT	0
206610	206578	14219Q	PARTICIPANT	\N	PRESENT	0
206611	206578	14103D	PARTICIPANT	\N	PRESENT	0
206612	206578	80027E	PARTICIPANT	\N	PRESENT	0
206613	206578	14031R	PARTICIPANT	\N	PRESENT	0
206614	206578	19637C	PARTICIPANT	\N	EXCUSE	0
206615	206578	08009T	PRESIDENT	0	PRESENT	0
206617	206578	14221J	PARTICIPANT	\N	PRESENT	0
206618	206578	14169X	PARTICIPANT	\N	PRESENT	0
206754	206514	19671E	PARTICIPANT	\N	PRESENT	0
206620	206578	14237S	PARTICIPANT	\N	PRESENT	0
206621	206578	17637T	PARTICIPANT	\N	PRESENT	0
206622	206578	05012A	PARTICIPANT	\N	PRESENT	0
206623	206578	19503N	PARTICIPANT	\N	PRESENT	0
206624	206578	17583W	PARTICIPANT	\N	PRESENT	0
206625	206578	95062K	PARTICIPANT	\N	PRESENT	0
206756	206755	14065Q	PARTICIPANT	\N	PRESENT	0
206627	206578	14051J	PARTICIPANT	\N	PRESENT	0
206757	206514	19693L	PARTICIPANT	\N	PRESENT	0
206758	206514	19521Q	PARTICIPANT	\N	PRESENT	0
206759	206514	14097Y	PARTICIPANT	\N	PRESENT	0
206760	206514	04059M	PARTICIPANT	\N	PRESENT	0
206761	206514	19669L	PARTICIPANT	\N	PRESENT	0
206762	206514	19443T	PARTICIPANT	\N	PRESENT	0
206763	206514	14223L	PARTICIPANT	\N	PRESENT	0
206764	206514	19515S	PARTICIPANT	\N	PRESENT	0
206765	206514	14087W	PARTICIPANT	\N	PRESENT	0
206766	206514	14231L	PARTICIPANT	\N	PRESENT	0
206773	206515	86034E	PARTICIPANT	\N	PRESENT	0
206774	206515	19679N	PARTICIPANT	\N	PRESENT	0
206775	206515	14237S	PARTICIPANT	\N	PRESENT	0
206771	206515	95030B	PARTICIPANT	\N	PRESENT	0
206772	206515	95062K	PARTICIPANT	\N	PRESENT	0
206776	206515	14087W	PARTICIPANT	\N	PRESENT	0
206777	206515	08041T	PARTICIPANT	\N	PRESENT	0
206778	206515	08062Y	PARTICIPANT	\N	PRESENT	0
206779	206515	87003B	PARTICIPANT	\N	PRESENT	0
206780	206515	14173T	PARTICIPANT	\N	PRESENT	0
206781	206515	19515S	PARTICIPANT	\N	PRESENT	0
206782	206515	15447F	PARTICIPANT	\N	PRESENT	0
206783	206515	11080N	PARTICIPANT	\N	PRESENT	0
206784	206515	19643A	PARTICIPANT	\N	PRESENT	0
206785	206515	17637T	PARTICIPANT	\N	PRESENT	0
206786	206515	19711U	PARTICIPANT	\N	PRESENT	0
206787	206515	04071H	PARTICIPANT	\N	PRESENT	0
206788	206515	14187A	PARTICIPANT	\N	PRESENT	0
206789	206515	99004R	PARTICIPANT	\N	PRESENT	0
206790	206515	08010L	PARTICIPANT	\N	PRESENT	0
206791	206515	11043H	PARTICIPANT	\N	PRESENT	0
206792	206515	04008A	PARTICIPANT	\N	PRESENT	0
206793	206515	11101A	PARTICIPANT	\N	PRESENT	0
206794	206515	14147R	PARTICIPANT	\N	PRESENT	0
206795	206515	04086Q	PARTICIPANT	\N	PRESENT	0
206796	206515	96004D	PARTICIPANT	\N	PRESENT	0
206797	206515	04097T	PARTICIPANT	\N	PRESENT	0
206798	206515	14211G	PARTICIPANT	\N	PRESENT	0
206799	206515	14026U	PARTICIPANT	\N	PRESENT	0
206800	206515	92040Q	PARTICIPANT	\N	PRESENT	0
206801	206515	14031R	PARTICIPANT	\N	PRESENT	0
206802	206515	08020N	PARTICIPANT	\N	PRESENT	0
206804	206515	01048V	PARTICIPANT	\N	PRESENT	0
206806	206515	14123H	PARTICIPANT	\N	PRESENT	0
206807	206515	04047H	PARTICIPANT	\N	PRESENT	0
206808	206515	04092N	PARTICIPANT	\N	PRESENT	0
206809	206515	14223L	PARTICIPANT	\N	PRESENT	0
206812	206515	98050T	PARTICIPANT	\N	PRESENT	0
206815	206515	04042C	PARTICIPANT	\N	PRESENT	0
206817	206515	04033B	PARTICIPANT	\N	PRESENT	0
206818	206515	08028W	PARTICIPANT	\N	PRESENT	0
206819	206515	04085P	PARTICIPANT	\N	PRESENT	0
206820	206515	11033F	PARTICIPANT	\N	PRESENT	0
206821	206515	04038G	PARTICIPANT	\N	PRESENT	0
206822	206515	01058X	PARTICIPANT	\N	PRESENT	0
206823	206515	11056N	PARTICIPANT	\N	PRESENT	0
206824	206515	10015M	PARTICIPANT	\N	PRESENT	0
206825	206515	12041X	PARTICIPANT	\N	PRESENT	0
206826	206515	11063M	PARTICIPANT	\N	PRESENT	0
206827	206515	19695N	PARTICIPANT	\N	PRESENT	0
206828	206515	19347U	PARTICIPANT	\N	PRESENT	0
206829	206515	19593H	PARTICIPANT	\N	PRESENT	0
206830	206515	98035U	PARTICIPANT	\N	PRESENT	0
206831	206515	14259Y	PARTICIPANT	\N	PRESENT	0
206832	206515	11077T	PARTICIPANT	\N	PRESENT	0
206833	206515	04059M	PARTICIPANT	\N	PRESENT	0
206834	206515	11048N	PARTICIPANT	\N	PRESENT	0
206835	206515	08068F	PARTICIPANT	\N	PRESENT	0
206836	206515	14051J	PARTICIPANT	\N	PRESENT	0
206837	206515	08052W	PARTICIPANT	\N	PRESENT	0
206838	206515	04035D	PARTICIPANT	\N	PRESENT	0
206839	206515	14229S	PARTICIPANT	\N	PRESENT	0
206840	206515	11103C	PARTICIPANT	\N	PRESENT	0
206841	206515	08055A	PARTICIPANT	\N	PRESENT	0
206842	206515	08016S	PARTICIPANT	\N	PRESENT	0
206843	206515	14069U	PARTICIPANT	\N	PRESENT	0
206844	206515	14107H	PARTICIPANT	\N	PRESENT	0
206845	206515	08045X	PARTICIPANT	\N	PRESENT	0
169773	169772	01031L	PRESIDENT	0	PRESENT	0
169774	169772	11040E	PARTICIPANT	\N	PRESENT	0
169775	169772	14083S	PARTICIPANT	\N	PRESENT	0
169776	169772	11042G	PARTICIPANT	\N	PRESENT	0
169777	169772	04086Q	PARTICIPANT	\N	PRESENT	0
169778	169772	04071H	PARTICIPANT	\N	PRESENT	0
169779	169772	11083R	PARTICIPANT	\N	PRESENT	0
169780	169772	01057W	PARTICIPANT	\N	PRESENT	0
169781	169772	08069G	PARTICIPANT	\N	PRESENT	0
169782	169772	08010L	PARTICIPANT	\N	PRESENT	0
169783	169772	08034U	PARTICIPANT	\N	PRESENT	0
169784	169772	98046X	PARTICIPANT	\N	PRESENT	0
169785	169772	08011M	PARTICIPANT	\N	PRESENT	0
169786	169772	01016M	PARTICIPANT	\N	PRESENT	0
169787	169772	14225N	PARTICIPANT	\N	PRESENT	0
169788	169772	04034C	PARTICIPANT	\N	PRESENT	0
169789	169772	14327T	PARTICIPANT	\N	EXCUSE	0
169790	169772	95063L	PARTICIPANT	\N	PRESENT	0
169791	169772	14001X	PARTICIPANT	\N	PRESENT	0
169792	169772	04045F	PARTICIPANT	\N	PRESENT	0
169793	169772	14097Y	PARTICIPANT	\N	PRESENT	0
169794	169772	96004D	PARTICIPANT	\N	PRESENT	0
169795	169772	08042U	PARTICIPANT	\N	PRESENT	0
169796	169772	90003B	PARTICIPANT	\N	PRESENT	0
169798	169772	14135M	PARTICIPANT	\N	PRESENT	0
169799	169772	95030B	PARTICIPANT	\N	PRESENT	0
169800	169772	14026U	PARTICIPANT	\N	PRESENT	0
169801	169772	92045V	PARTICIPANT	\N	PRESENT	0
169802	169772	04057K	PARTICIPANT	\N	PRESENT	0
169803	169772	14079W	PARTICIPANT	\N	PRESENT	0
169804	169772	04080J	PARTICIPANT	\N	PRESENT	0
169805	169772	14089Y	PARTICIPANT	\N	PRESENT	0
176639	176296	08019V	PARTICIPANT	\N	PRESENT	0
176640	176296	11043H	PARTICIPANT	\N	PRESENT	0
176641	176296	80013X	PARTICIPANT	\N	PRESENT	0
176642	176296	04049K	PARTICIPANT	\N	PRESENT	0
176659	176296	01046T	PARTICIPANT	\N	PRESENT	0
176644	176296	14013P	PARTICIPANT	\N	PRESENT	0
176658	176296	01022K	PARTICIPANT	\N	PRESENT	0
176646	176296	11036J	PARTICIPANT	\N	PRESENT	0
176660	176296	01031L	PARTICIPANT	\N	PRESENT	0
176648	176296	04067M	PARTICIPANT	\N	PRESENT	0
176649	176296	01014K	PARTICIPANT	\N	PRESENT	0
176650	176296	14083S	PARTICIPANT	\N	PRESENT	0
176651	176296	01025N	PARTICIPANT	\N	PRESENT	0
176652	176296	14193X	PARTICIPANT	\N	PRESENT	0
176653	176296	14147R	PARTICIPANT	\N	PRESENT	0
176654	176296	14195A	PARTICIPANT	\N	PRESENT	0
176655	176296	14191V	PARTICIPANT	\N	PRESENT	0
176656	176296	14157T	PARTICIPANT	\N	PRESENT	0
176657	176296	11067R	PARTICIPANT	\N	PRESENT	0
176672	176296	14159V	PARTICIPANT	\N	PRESENT	0
176673	176296	07026Q	PARTICIPANT	\N	PRESENT	0
176674	176296	11094U	PARTICIPANT	\N	PRESENT	0
176675	176296	11012A	PARTICIPANT	\N	PRESENT	0
176681	176296	11026G	PARTICIPANT	\N	PRESENT	0
176689	176296	14026U	PARTICIPANT	\N	PRESENT	0
176690	176296	08031R	PARTICIPANT	\N	PRESENT	0
176691	176296	08051V	PARTICIPANT	\N	PRESENT	0
176692	176296	14241N	PARTICIPANT	\N	PRESENT	0
176693	176296	14267Y	PARTICIPANT	\N	PRESENT	0
176694	176296	14331P	PARTICIPANT	\N	PRESENT	0
176695	176296	14038Y	PARTICIPANT	\N	PRESENT	0
176696	176296	14073Q	PARTICIPANT	\N	PRESENT	0
176712	176296	14151M	PARTICIPANT	\N	PRESENT	0
176713	176296	11014C	PARTICIPANT	\N	PRESENT	0
176715	167310	08024S	PARTICIPANT	\N	PRESENT	0
176716	167310	14033T	PARTICIPANT	\N	PRESENT	0
176784	167310	14249W	PARTICIPANT	\N	PRESENT	0
176718	167310	14107H	PARTICIPANT	\N	PRESENT	0
176719	167310	14063N	PARTICIPANT	\N	PRESENT	0
176720	167310	11098Y	PARTICIPANT	\N	PRESENT	0
176785	167310	08034U	PARTICIPANT	\N	PRESENT	0
176792	167310	08017T	PARTICIPANT	\N	PRESENT	0
176793	167310	14257W	PARTICIPANT	\N	PRESENT	0
176794	167310	11012A	PARTICIPANT	\N	PRESENT	0
176725	167310	14197C	PARTICIPANT	\N	PRESENT	0
176795	167310	14231L	PARTICIPANT	\N	PRESENT	0
176812	167310	14213J	PARTICIPANT	\N	PRESENT	0
176728	167310	14235Q	PARTICIPANT	\N	PRESENT	0
176813	167310	98050T	PARTICIPANT	\N	PRESENT	0
176730	167310	08047A	PARTICIPANT	\N	PRESENT	0
176731	167310	14041T	PARTICIPANT	\N	PRESENT	0
176732	167310	14225N	PARTICIPANT	\N	PRESENT	0
176733	167310	01058X	PARTICIPANT	\N	PRESENT	0
176832	167310	01024M	PARTICIPANT	\N	PRESENT	0
176735	167310	13002U	PARTICIPANT	\N	PRESENT	0
176852	167310	11054L	PARTICIPANT	\N	PRESENT	0
176853	167310	14059S	PARTICIPANT	\N	PRESENT	0
176738	167310	08019V	PARTICIPANT	\N	PRESENT	0
176739	167310	11043H	PARTICIPANT	\N	PRESENT	0
176740	167310	80013X	PARTICIPANT	\N	PRESENT	0
176741	167310	04049K	PARTICIPANT	\N	PRESENT	0
176742	167310	14013P	PARTICIPANT	\N	PRESENT	0
176743	167310	11036J	PARTICIPANT	\N	PRESENT	0
176744	167310	04067M	PARTICIPANT	\N	PRESENT	0
176854	167310	14237S	PARTICIPANT	\N	PRESENT	0
176941	167310	14097Y	PARTICIPANT	\N	PRESENT	0
176942	167310	14014Q	PARTICIPANT	\N	PRESENT	0
176943	167310	04057K	PARTICIPANT	\N	PRESENT	0
176944	167310	07034Q	PARTICIPANT	\N	PRESENT	0
176750	167310	14191V	PARTICIPANT	\N	PRESENT	0
177070	167312	08024S	PARTICIPANT	\N	PRESENT	0
176752	167310	11067R	PARTICIPANT	\N	PRESENT	0
177071	167312	05008E	PARTICIPANT	\N	PRESENT	0
177072	167312	95063L	PARTICIPANT	\N	PRESENT	0
176755	167310	14159V	PARTICIPANT	\N	PRESENT	0
176756	167310	07026Q	PARTICIPANT	\N	PRESENT	0
177073	167312	11104D	PARTICIPANT	\N	PRESENT	0
177074	167312	14097Y	PARTICIPANT	\N	PRESENT	0
177075	167312	04085P	PARTICIPANT	\N	PRESENT	0
177076	167312	14219Q	PARTICIPANT	\N	PRESENT	0
176761	167310	08031R	PARTICIPANT	\N	PRESENT	0
177077	167312	14069U	PARTICIPANT	\N	PRESENT	0
176763	167310	14241N	PARTICIPANT	\N	PRESENT	0
176764	167310	14331P	PARTICIPANT	\N	PRESENT	0
177078	167312	14249W	PARTICIPANT	\N	PRESENT	0
176766	167310	14073Q	PARTICIPANT	\N	PRESENT	0
177079	167312	14059S	PARTICIPANT	\N	PRESENT	0
176768	167310	11014C	PARTICIPANT	\N	PRESENT	0
176769	167310	11107G	PARTICIPANT	\N	PRESENT	0
176770	167310	11084S	PARTICIPANT	\N	PRESENT	0
176771	167310	08055A	PARTICIPANT	\N	PRESENT	0
176772	167310	08043V	PARTICIPANT	\N	PRESENT	0
176773	167310	11029K	PARTICIPANT	\N	PRESENT	0
176774	167310	01044R	PARTICIPANT	\N	PRESENT	0
176775	167310	11039M	PARTICIPANT	\N	PRESENT	0
176776	167310	04070G	PARTICIPANT	\N	PRESENT	0
176777	167310	14363X	PARTICIPANT	\N	PRESENT	0
176778	167310	11105E	PARTICIPANT	\N	PRESENT	0
176779	167310	05012A	PARTICIPANT	\N	PRESENT	0
176780	167310	07029T	PARTICIPANT	\N	PRESENT	0
176781	167310	08012N	PARTICIPANT	\N	PRESENT	0
176782	167310	08053X	PARTICIPANT	\N	PRESENT	0
176783	167310	11048N	PARTICIPANT	\N	PRESENT	0
177080	167312	14213J	PARTICIPANT	\N	PRESENT	0
177081	167312	01008M	PARTICIPANT	\N	PRESENT	0
177082	167312	14217N	PARTICIPANT	\N	PRESENT	0
177083	167312	08019V	PARTICIPANT	\N	PRESENT	0
177084	167312	11029K	PARTICIPANT	\N	PRESENT	0
177085	167312	08010L	PARTICIPANT	\N	PRESENT	0
177086	167312	01024M	PARTICIPANT	\N	PRESENT	0
177087	167312	14241N	PARTICIPANT	\N	PRESENT	0
177088	167312	14157T	PARTICIPANT	\N	PRESENT	0
177089	167312	07034Q	PARTICIPANT	\N	PRESENT	0
177092	167312	11056N	PARTICIPANT	\N	PRESENT	0
177112	167312	01028R	PARTICIPANT	\N	PRESENT	0
177122	167312	11033F	PARTICIPANT	\N	PRESENT	0
177123	167312	14231L	PARTICIPANT	\N	PRESENT	0
177132	167312	90003B	PARTICIPANT	\N	PRESENT	0
177133	167312	14191V	PARTICIPANT	\N	PRESENT	0
177152	167312	14033T	PARTICIPANT	\N	PRESENT	0
177153	167312	14331P	PARTICIPANT	\N	PRESENT	0
177154	167312	14235Q	PARTICIPANT	\N	PRESENT	0
177155	167312	14026U	PARTICIPANT	\N	PRESENT	0
177632	176312	92045V	PARTICIPANT	\N	EXCUSE	0
177633	176952	01008M	PARTICIPANT	\N	PRESENT	0
177634	176952	01015L	PARTICIPANT	\N	EXCUSE	0
177635	176952	11035H	PARTICIPANT	\N	EXCUSE	0
177637	177636	14219Q	PRESIDENT	0	PRESENT	0
177638	177636	11065P	PARTICIPANT	\N	PRESENT	0
177639	177636	92045V	PARTICIPANT	\N	PRESENT	0
177640	177636	80013X	PARTICIPANT	\N	PRESENT	0
177641	177636	01008M	PARTICIPANT	\N	EXCUSE	0
177642	177636	14093U	PARTICIPANT	\N	EXCUSE	0
177643	177636	90003B	PARTICIPANT	\N	EXCUSE	0
177644	177636	11035H	PARTICIPANT	\N	EXCUSE	0
177645	177636	01015L	PARTICIPANT	\N	EXCUSE	0
177646	177636	11090Q	PARTICIPANT	\N	EXCUSE	0
197987	197943	14119M	PARTICIPANT	\N	PRESENT	0
197988	197943	11103C	PARTICIPANT	\N	PRESENT	0
197989	197943	14121F	PARTICIPANT	\N	PRESENT	0
197990	197943	14071N	PARTICIPANT	\N	PRESENT	0
197991	197943	04043D	PARTICIPANT	\N	PRESENT	0
197992	197943	14255U	PARTICIPANT	\N	PRESENT	0
197993	197943	04053F	PARTICIPANT	\N	PRESENT	0
197994	197943	14017T	PARTICIPANT	\N	EXCUSE	0
197995	197943	14265W	PARTICIPANT	\N	EXCUSE	0
198032	197553	04070G	PRESIDENT	0	PRESENT	0
198033	197553	14361V	PARTICIPANT	\N	PRESENT	0
198034	197553	11029K	PARTICIPANT	\N	PRESENT	0
198035	197553	11089X	PARTICIPANT	\N	PRESENT	0
198036	197553	14241N	PARTICIPANT	\N	PRESENT	0
198037	197553	83047W	PARTICIPANT	\N	PRESENT	0
198038	197553	08017T	PARTICIPANT	\N	PRESENT	0
198039	197553	14179A	PARTICIPANT	\N	PRESENT	0
198040	197553	08012N	PARTICIPANT	\N	PRESENT	0
198041	197553	08024S	PARTICIPANT	\N	PRESENT	0
198042	197553	14249W	PARTICIPANT	\N	PRESENT	0
198043	197553	08031R	PARTICIPANT	\N	PRESENT	0
198044	197553	14061L	PARTICIPANT	\N	PRESENT	0
198045	197553	04057K	PARTICIPANT	\N	PRESENT	0
198046	197553	14073Q	PARTICIPANT	\N	PRESENT	0
198047	197553	14235Q	PARTICIPANT	\N	PRESENT	0
198048	197553	08043V	PARTICIPANT	\N	PRESENT	0
198049	197553	87003B	PARTICIPANT	\N	PRESENT	0
198050	197553	18127E	PARTICIPANT	\N	PRESENT	0
198051	197553	11014C	PARTICIPANT	\N	PRESENT	0
198052	197553	11039M	PARTICIPANT	\N	PRESENT	0
198053	197553	98042T	PARTICIPANT	\N	PRESENT	0
198054	197553	14363X	PARTICIPANT	\N	PRESENT	0
198055	197553	04059M	PARTICIPANT	\N	PRESENT	0
198056	197553	14063N	PARTICIPANT	\N	PRESENT	0
198057	197553	14109K	PARTICIPANT	\N	PRESENT	0
198058	197553	14123H	PARTICIPANT	\N	PRESENT	0
198059	197553	11043H	PARTICIPANT	\N	PRESENT	0
198060	197553	11104D	PARTICIPANT	\N	PRESENT	0
198061	197553	14209N	PARTICIPANT	\N	PRESENT	0
198062	190786	14209N	PARTICIPANT	\N	PRESENT	0
198078	197892	11077T	PARTICIPANT	\N	PRESENT	0
198079	197892	11100Y	PRESIDENT	0	PRESENT	0
198080	197892	14081Q	PARTICIPANT	\N	PRESENT	0
198081	197892	11066Q	PARTICIPANT	\N	PRESENT	0
198082	197892	80013X	PARTICIPANT	\N	PRESENT	0
198083	197892	11110B	PARTICIPANT	\N	PRESENT	0
198084	197892	90003B	PARTICIPANT	\N	PRESENT	0
198085	197892	11099A	PARTICIPANT	\N	PRESENT	0
198086	197892	05012A	PARTICIPANT	\N	PRESENT	0
198087	197892	08068F	PARTICIPANT	\N	PRESENT	0
198088	197892	11094U	PARTICIPANT	\N	PRESENT	0
198089	197892	04049K	PARTICIPANT	\N	PRESENT	0
198090	197892	11046L	PARTICIPANT	\N	PRESENT	0
198091	197892	08015R	PARTICIPANT	\N	PRESENT	0
198092	197892	08019V	PARTICIPANT	\N	PRESENT	0
198093	197892	14179A	PARTICIPANT	\N	PRESENT	0
198094	197892	14197C	PARTICIPANT	\N	PRESENT	0
198095	197892	08028W	PARTICIPANT	\N	PRESENT	0
198096	197892	11065P	PARTICIPANT	\N	PRESENT	0
198097	197892	14135M	PARTICIPANT	\N	PRESENT	0
198098	197892	14187A	PARTICIPANT	\N	PRESENT	0
198099	197892	11045K	PARTICIPANT	\N	PRESENT	0
198100	197892	08038Y	PARTICIPANT	\N	PRESENT	0
198101	197892	11098Y	PARTICIPANT	\N	PRESENT	0
198102	197892	14033T	PARTICIPANT	\N	PRESENT	0
198103	197892	01008M	PARTICIPANT	\N	PRESENT	0
198104	197892	14205J	PARTICIPANT	\N	PRESENT	0
198105	197892	04088S	PARTICIPANT	\N	PRESENT	0
198106	197892	11036J	PARTICIPANT	\N	PRESENT	0
198107	197892	04089T	PARTICIPANT	\N	PRESENT	0
198108	197892	11111C	PARTICIPANT	\N	PRESENT	0
198109	197892	11101A	PARTICIPANT	\N	PRESENT	0
198110	197892	98050T	PARTICIPANT	\N	PRESENT	0
198111	197892	14207L	PARTICIPANT	\N	PRESENT	0
198112	197892	14257W	PARTICIPANT	\N	PRESENT	0
198113	197892	01061S	PARTICIPANT	\N	EXCUSE	0
198133	197892	04067M	PARTICIPANT	\N	PRESENT	0
198134	190786	11095V	PARTICIPANT	\N	PRESENT	0
198152	190786	08034U	PARTICIPANT	\N	PRESENT	0
198194	190787	95049N	PARTICIPANT	\N	PRESENT	0
198195	190787	05008E	PARTICIPANT	\N	PRESENT	0
198196	190787	11033F	PARTICIPANT	\N	PRESENT	0
198197	190787	07004J	PARTICIPANT	\N	PRESENT	0
198198	190787	14211G	PARTICIPANT	\N	PRESENT	0
198199	190787	07029T	PARTICIPANT	\N	PRESENT	0
198200	190787	08062Y	PARTICIPANT	\N	PRESENT	0
198201	190787	14247U	PARTICIPANT	\N	PRESENT	0
198202	190787	07034Q	PARTICIPANT	\N	PRESENT	0
198203	190787	10015M	PARTICIPANT	\N	PRESENT	0
198204	190787	14271U	PARTICIPANT	\N	PRESENT	0
198205	190787	14079W	PARTICIPANT	\N	PRESENT	0
198206	190787	12042Y	PARTICIPANT	\N	PRESENT	0
198207	190787	14065Q	PARTICIPANT	\N	PRESENT	0
198208	190787	04085P	PARTICIPANT	\N	PRESENT	0
198209	190787	19251M	PARTICIPANT	\N	PRESENT	0
198210	190787	08058D	PARTICIPANT	\N	PRESENT	0
198211	190787	14147R	PARTICIPANT	\N	PRESENT	0
198212	190787	11026G	PARTICIPANT	\N	PRESENT	0
198216	190787	11077T	PARTICIPANT	\N	PRESENT	0
198214	190787	08031R	PARTICIPANT	\N	PRESENT	0
198215	190787	04042C	PARTICIPANT	\N	PRESENT	0
198217	190787	95063L	PARTICIPANT	\N	PRESENT	0
198218	190787	14215L	PARTICIPANT	\N	PRESENT	0
198232	190787	14119M	PARTICIPANT	\N	PRESENT	0
198233	190787	14089Y	PARTICIPANT	\N	PRESENT	0
198234	190787	14097Y	PARTICIPANT	\N	PRESENT	0
198235	190787	14235Q	PARTICIPANT	\N	PRESENT	0
198236	190787	11056N	PARTICIPANT	\N	PRESENT	0
198237	190787	08061X	PARTICIPANT	\N	PRESENT	0
198238	190787	01046T	PARTICIPANT	\N	PRESENT	0
198239	190787	14241N	PARTICIPANT	\N	PRESENT	0
198240	190787	14217N	PARTICIPANT	\N	PRESENT	0
198241	190787	14363X	PARTICIPANT	\N	PRESENT	0
198242	190787	14361V	PARTICIPANT	\N	PRESENT	0
198243	190787	14026U	PARTICIPANT	\N	PRESENT	0
198244	190787	14034U	PARTICIPANT	\N	PRESENT	0
198192	190787	08055A	PARTICIPANT	\N	PRESENT	0
198193	190787	11037K	PARTICIPANT	\N	PRESENT	0
198245	190787	11061K	PARTICIPANT	\N	PRESENT	0
198246	190787	04040A	PARTICIPANT	\N	PRESENT	0
198247	190787	14261S	PARTICIPANT	\N	PRESENT	0
198248	190787	14223L	PARTICIPANT	\N	PRESENT	0
198249	190787	11097X	PARTICIPANT	\N	PRESENT	0
198250	190787	10006L	PARTICIPANT	\N	PRESENT	0
198251	190787	14213J	PARTICIPANT	\N	PRESENT	0
198252	190787	14207L	PARTICIPANT	\N	PRESENT	0
198253	190787	14197C	PARTICIPANT	\N	PRESENT	0
198254	190787	14257W	PARTICIPANT	\N	PRESENT	0
198255	190787	11094U	PARTICIPANT	\N	PRESENT	0
198256	190787	14187A	PARTICIPANT	\N	PRESENT	0
198257	190787	11090Q	PARTICIPANT	\N	PRESENT	0
198258	190787	14069U	PARTICIPANT	\N	PRESENT	0
198259	190787	08019V	PARTICIPANT	\N	PRESENT	0
198260	190787	14033T	PARTICIPANT	\N	PRESENT	0
198261	190787	08015R	PARTICIPANT	\N	PRESENT	0
198262	190787	04049K	PARTICIPANT	\N	PRESENT	0
198263	190787	02002K	PARTICIPANT	\N	PRESENT	0
198264	190787	04035D	PARTICIPANT	\N	PRESENT	0
198265	190787	11036J	PARTICIPANT	\N	PRESENT	0
198269	190787	14357A	PARTICIPANT	\N	PRESENT	0
198267	190787	04047H	PARTICIPANT	\N	PRESENT	0
198268	190787	04033B	PARTICIPANT	\N	PRESENT	0
198270	190787	11098Y	PARTICIPANT	\N	PRESENT	0
198272	190787	01008M	PARTICIPANT	\N	PRESENT	0
198292	197892	14357A	PARTICIPANT	\N	EXCUSE	0
198293	197892	01058X	PARTICIPANT	\N	EXCUSE	0
198294	197952	11067R	PARTICIPANT	\N	PRESENT	0
198295	197952	01046T	PARTICIPANT	\N	PRESENT	0
198296	197952	11061K	PARTICIPANT	\N	PRESENT	0
198297	197952	11097X	PARTICIPANT	\N	PRESENT	0
198298	197952	14223L	PARTICIPANT	\N	PRESENT	0
198299	197952	04045F	PARTICIPANT	\N	PRESENT	0
198300	197952	14026U	PARTICIPANT	\N	PRESENT	0
198301	197952	14227Q	PARTICIPANT	\N	PRESENT	0
198302	197952	11112D	PARTICIPANT	\N	PRESENT	0
198303	197952	11063M	PARTICIPANT	\N	PRESENT	0
198304	197952	14231L	PARTICIPANT	\N	PRESENT	0
198305	197952	11031D	PARTICIPANT	\N	PRESENT	0
198306	197952	01059Y	PARTICIPANT	\N	PRESENT	0
198307	197952	14281W	PARTICIPANT	\N	PRESENT	0
198308	197952	14271U	PARTICIPANT	\N	PRESENT	0
198309	197952	14042U	PARTICIPANT	\N	PRESENT	0
198310	197952	14195A	PARTICIPANT	\N	PRESENT	0
198311	197952	14213J	PARTICIPANT	\N	PRESENT	0
198312	197952	14151M	PARTICIPANT	\N	PRESENT	0
198313	197952	14217N	PARTICIPANT	\N	PRESENT	0
198314	197952	10006L	PARTICIPANT	\N	PRESENT	0
198315	197952	98024R	PRESIDENT	0	PRESENT	0
198316	197952	14053L	PARTICIPANT	\N	PRESENT	0
184098	183732	11084S	PARTICIPANT	\N	PRESENT	0
184099	183732	14065Q	PARTICIPANT	\N	PRESENT	0
184100	183732	95067Q	PARTICIPANT	\N	PRESENT	0
184101	183732	01007L	PARTICIPANT	\N	PRESENT	0
184173	184172	04080J	PARTICIPANT	\N	PRESENT	0
185653	185652	04040A	PARTICIPANT	\N	PRESENT	0
185693	185692	11048N	PARTICIPANT	\N	PRESENT	0
185733	185732	08010L	PARTICIPANT	\N	PRESENT	0
188832	188823	14263U	PARTICIPANT	\N	PRESENT	0
188833	188823	04059M	PARTICIPANT	\N	PRESENT	0
188834	188823	08031R	PARTICIPANT	\N	PRESENT	0
188835	188823	08039A	PARTICIPANT	\N	PRESENT	0
188836	188823	04057K	PARTICIPANT	\N	PRESENT	0
188837	188823	04070G	PARTICIPANT	\N	PRESENT	0
188839	188838	04059M	PARTICIPANT	\N	PRESENT	0
188840	188838	14241N	PARTICIPANT	\N	PRESENT	0
188841	188838	04057K	PARTICIPANT	\N	PRESENT	0
188842	188838	04070G	PARTICIPANT	\N	PRESENT	0
188843	188838	08039A	PARTICIPANT	\N	PRESENT	0
188845	188844	08039A	PARTICIPANT	\N	PRESENT	0
188846	188844	04070G	PARTICIPANT	\N	PRESENT	0
188847	188844	04057K	PARTICIPANT	\N	PRESENT	0
188848	188844	14241N	PARTICIPANT	\N	PRESENT	0
188873	188872	01043Q	PARTICIPANT	\N	PRESENT	0
188874	188872	14081Q	PARTICIPANT	\N	PRESENT	0
193594	190778	04038G	PARTICIPANT	\N	PRESENT	0
193595	190778	11041F	PARTICIPANT	\N	PRESENT	0
193596	190778	11109J	PARTICIPANT	\N	PRESENT	0
193597	190778	14083S	PARTICIPANT	\N	PRESENT	0
193598	190778	01043Q	PARTICIPANT	\N	PRESENT	0
193599	190778	04089T	PARTICIPANT	\N	PRESENT	0
193600	190778	14267Y	PARTICIPANT	\N	PRESENT	0
193601	190778	07004J	PARTICIPANT	\N	PRESENT	0
193602	190778	01024M	PARTICIPANT	\N	PRESENT	0
193603	190778	08056B	PARTICIPANT	\N	PRESENT	0
193612	190778	14030Q	PARTICIPANT	\N	PRESENT	0
193613	190778	14217N	PARTICIPANT	\N	PRESENT	0
193614	190778	14179A	PARTICIPANT	\N	PRESENT	0
193615	190778	95035G	PARTICIPANT	\N	PRESENT	0
193616	190778	14087W	PARTICIPANT	\N	PRESENT	0
193617	190778	14215L	PARTICIPANT	\N	PRESENT	0
193632	190778	04044E	PARTICIPANT	\N	PRESENT	0
193633	190778	86044G	PARTICIPANT	\N	PRESENT	0
193634	190778	98018T	PARTICIPANT	\N	PRESENT	0
193635	190778	04086Q	PARTICIPANT	\N	PRESENT	0
193636	190778	05012A	PARTICIPANT	\N	PRESENT	0
193637	190778	97011G	PARTICIPANT	\N	PRESENT	0
193638	190778	11103C	PARTICIPANT	\N	PRESENT	0
193639	190778	14363X	PARTICIPANT	\N	PRESENT	0
193652	190778	04049K	PARTICIPANT	\N	PRESENT	0
193653	190778	14187A	PARTICIPANT	\N	PRESENT	0
193654	190778	14059S	PARTICIPANT	\N	PRESENT	0
193655	190778	14061L	PARTICIPANT	\N	PRESENT	0
193656	190778	14209N	PARTICIPANT	\N	PRESENT	0
193657	190778	01027Q	PARTICIPANT	\N	PRESENT	0
193659	190778	99004R	PARTICIPANT	\N	PRESENT	0
193660	190778	04036E	PARTICIPANT	\N	PRESENT	0
193661	190778	08028W	PARTICIPANT	\N	PRESENT	0
193663	190778	11100Y	PARTICIPANT	\N	PRESENT	0
193664	190778	98023Q	PARTICIPANT	\N	PRESENT	0
193665	190778	08041T	PARTICIPANT	\N	PRESENT	0
193666	190778	10015M	PARTICIPANT	\N	PRESENT	0
193667	190778	95030B	PARTICIPANT	\N	PRESENT	0
193668	190778	92045V	PARTICIPANT	\N	PRESENT	0
193669	190778	11082Q	PARTICIPANT	\N	PRESENT	0
193670	190778	08062Y	PARTICIPANT	\N	PRESENT	0
193671	190778	14147R	PARTICIPANT	\N	PRESENT	0
193672	190778	14265W	PARTICIPANT	\N	PRESENT	0
193673	190778	04081K	PARTICIPANT	\N	PRESENT	0
193674	190778	11091R	PARTICIPANT	\N	PRESENT	0
193675	190778	14213J	PARTICIPANT	\N	PRESENT	0
193676	190778	14053L	PARTICIPANT	\N	PRESENT	0
193677	190778	08015R	PARTICIPANT	\N	PRESENT	0
193678	190778	07029T	PARTICIPANT	\N	PRESENT	0
193679	190778	08010L	PARTICIPANT	\N	PRESENT	0
193680	190778	14041T	PARTICIPANT	\N	PRESENT	0
193681	190778	04088S	PARTICIPANT	\N	PRESENT	0
193682	190778	08019V	PARTICIPANT	\N	PRESENT	0
193683	190778	14329V	PARTICIPANT	\N	PRESENT	0
193684	190778	14199E	PARTICIPANT	\N	PRESENT	0
193685	190778	14133K	PARTICIPANT	\N	PRESENT	0
193686	190778	14038Y	PARTICIPANT	\N	PRESENT	0
193687	190778	14119M	PARTICIPANT	\N	PRESENT	0
193688	190778	14033T	PARTICIPANT	\N	PRESENT	0
193689	190778	14157T	PARTICIPANT	\N	PRESENT	0
193690	190778	04074L	PARTICIPANT	\N	PRESENT	0
193691	190778	14173T	PARTICIPANT	\N	PRESENT	0
193692	190778	01057W	PARTICIPANT	\N	PRESENT	0
193693	190778	14111D	PARTICIPANT	\N	PRESENT	0
193694	190778	14191V	PARTICIPANT	\N	PRESENT	0
193695	190778	14031R	PARTICIPANT	\N	PRESENT	0
193696	190778	11097X	PARTICIPANT	\N	PRESENT	0
193697	190778	14253S	PARTICIPANT	\N	PRESENT	0
193698	190778	08039A	PARTICIPANT	\N	PRESENT	0
193699	190778	95062K	PARTICIPANT	\N	PRESENT	0
193700	190778	01056V	PARTICIPANT	\N	PRESENT	0
193701	190778	04071H	PARTICIPANT	\N	PRESENT	0
193702	190778	01025N	PARTICIPANT	\N	PRESENT	0
193703	190778	11046L	PARTICIPANT	\N	PRESENT	0
193712	190778	11085T	PARTICIPANT	\N	PRESENT	0
193732	190778	14237S	PARTICIPANT	\N	PRESENT	0
193752	190778	14195A	PARTICIPANT	\N	PRESENT	0
193753	190778	14361V	PARTICIPANT	\N	PRESENT	0
193754	190778	14065Q	PARTICIPANT	\N	PRESENT	0
193755	190778	19253P	PARTICIPANT	\N	PRESENT	0
193772	190778	11034G	PARTICIPANT	\N	PRESENT	0
193773	190778	01013J	PARTICIPANT	\N	PRESENT	0
193774	190778	14073Q	PARTICIPANT	\N	PRESENT	0
193775	190778	95067Q	PARTICIPANT	\N	PRESENT	0
193792	190778	14223L	PARTICIPANT	\N	PRESENT	0
193812	190778	04035D	PARTICIPANT	\N	PRESENT	0
193832	190778	11042G	PARTICIPANT	\N	PRESENT	0
193852	190778	01008M	PARTICIPANT	\N	PRESENT	0
193872	190778	14034U	PARTICIPANT	\N	PRESENT	0
193892	190778	95037J	PARTICIPANT	\N	PRESENT	0
193912	190778	14105F	PARTICIPANT	\N	PRESENT	0
193932	190778	11059R	PARTICIPANT	\N	PRESENT	0
193952	190778	11101A	PARTICIPANT	\N	PRESENT	0
193972	190778	14205J	PARTICIPANT	\N	PRESENT	0
193992	190778	08065C	PARTICIPANT	\N	PRESENT	0
194012	190778	11014C	PARTICIPANT	\N	PRESENT	0
194032	190778	02002K	PARTICIPANT	\N	PRESENT	0
194052	190778	11011M	PARTICIPANT	\N	PRESENT	0
194072	190778	14169X	PARTICIPANT	\N	PRESENT	0
194092	190778	11027H	PARTICIPANT	\N	PRESENT	0
194112	190778	14227Q	PARTICIPANT	\N	PRESENT	0
194132	190778	04047H	PARTICIPANT	\N	PRESENT	0
194133	190778	11090Q	PARTICIPANT	\N	PRESENT	0
194152	190778	95015C	PARTICIPANT	\N	PRESENT	0
194153	190778	11067R	PARTICIPANT	\N	PRESENT	0
194172	190778	14281W	PARTICIPANT	\N	PRESENT	0
194192	190778	14231L	PARTICIPANT	\N	PRESENT	0
194212	190778	11056N	PARTICIPANT	\N	PRESENT	0
194213	190778	11112D	PARTICIPANT	\N	PRESENT	0
194214	190778	08053X	PARTICIPANT	\N	PRESENT	0
194232	190778	11061K	PARTICIPANT	\N	PRESENT	0
194252	190778	98053W	PARTICIPANT	\N	PRESENT	0
194253	190778	77002U	PARTICIPANT	\N	PRESENT	0
194272	190778	11076S	PARTICIPANT	\N	PRESENT	0
194292	190778	04043D	PARTICIPANT	\N	PRESENT	0
194312	190778	98024R	PARTICIPANT	\N	PRESENT	0
194332	190778	14069U	PARTICIPANT	\N	PRESENT	0
194352	190778	14201E	PARTICIPANT	\N	PRESENT	0
194353	190778	14151M	PARTICIPANT	\N	PRESENT	0
194373	190778	14121F	PARTICIPANT	\N	PRESENT	0
194392	190778	14001X	PARTICIPANT	\N	PRESENT	0
194393	190778	01016M	PARTICIPANT	\N	PRESENT	0
194394	190778	04053F	PARTICIPANT	\N	PRESENT	0
194395	190778	14211G	PARTICIPANT	\N	PRESENT	0
194397	190778	14249W	PARTICIPANT	\N	PRESENT	0
194398	190778	11096W	PARTICIPANT	\N	PRESENT	0
194399	190778	87003B	PARTICIPANT	\N	PRESENT	0
194412	190778	04033B	PARTICIPANT	\N	PRESENT	0
194413	190778	14259Y	PARTICIPANT	\N	PRESENT	0
206846	206515	14225N	PARTICIPANT	\N	PRESENT	0
206847	206515	14021P	PARTICIPANT	\N	PRESENT	0
206848	206515	14151M	PARTICIPANT	\N	PRESENT	0
206849	206515	11097X	PARTICIPANT	\N	PRESENT	0
206850	206515	01028R	PARTICIPANT	\N	PRESENT	0
206851	206515	08060W	PARTICIPANT	\N	PRESENT	0
206852	206515	08038Y	PARTICIPANT	\N	PRESENT	0
206853	206515	80013X	PARTICIPANT	\N	PRESENT	0
206854	206515	14135M	PARTICIPANT	\N	PRESENT	0
206855	206515	14028W	PARTICIPANT	\N	PRESENT	0
206856	206515	08024S	PARTICIPANT	\N	PRESENT	0
206857	206515	19443T	PARTICIPANT	\N	PRESENT	0
206858	206515	14197C	PARTICIPANT	\N	PRESENT	0
206859	206515	19647E	PARTICIPANT	\N	PRESENT	0
206860	206515	14059S	PARTICIPANT	\N	PRESENT	0
206861	206515	14061L	PARTICIPANT	\N	PRESENT	0
206862	206515	08039A	PARTICIPANT	\N	PRESENT	0
206863	206515	19649G	PARTICIPANT	\N	PRESENT	0
206864	206515	14193X	PARTICIPANT	\N	PRESENT	0
206865	206515	19531S	PARTICIPANT	\N	PRESENT	0
206866	206515	04044E	PARTICIPANT	\N	PRESENT	0
206867	206515	80027E	PARTICIPANT	\N	PRESENT	0
206868	206515	08012N	PARTICIPANT	\N	PRESENT	0
206869	206515	08058D	PARTICIPANT	\N	PRESENT	0
206870	206515	08069G	PARTICIPANT	\N	PRESENT	0
206871	206515	14053L	PARTICIPANT	\N	PRESENT	0
206872	206515	14281W	PARTICIPANT	\N	PRESENT	0
206873	206515	11104D	PARTICIPANT	\N	PRESENT	0
206874	206515	19693L	PARTICIPANT	\N	PRESENT	0
206875	206515	11066Q	PARTICIPANT	\N	PRESENT	0
206876	206515	19549D	PARTICIPANT	\N	PRESENT	0
206877	206515	14065Q	PARTICIPANT	\N	PRESENT	0
206878	206515	19399H	PARTICIPANT	\N	PRESENT	0
206879	206515	01062T	PARTICIPANT	\N	PRESENT	0
206880	206515	14071N	PARTICIPANT	\N	PRESENT	0
206881	206515	14081Q	PARTICIPANT	\N	PRESENT	0
206882	206515	11110B	PARTICIPANT	\N	PRESENT	0
206883	206515	19525U	PARTICIPANT	\N	PRESENT	0
206884	206515	08053X	PARTICIPANT	\N	PRESENT	0
206885	206515	08017T	PARTICIPANT	\N	PRESENT	0
206886	206515	14085U	PARTICIPANT	\N	PRESENT	0
206887	206515	14121F	PARTICIPANT	\N	PRESENT	0
206888	206515	11090Q	PARTICIPANT	\N	PRESENT	0
206889	206515	17779H	PARTICIPANT	\N	PRESENT	0
206890	206515	19489J	PARTICIPANT	\N	PRESENT	0
206892	206515	19689Q	PARTICIPANT	\N	PRESENT	0
206893	206515	04049K	PARTICIPANT	\N	PRESENT	0
206894	206515	11054L	PARTICIPANT	\N	PRESENT	0
206895	206515	19683J	PARTICIPANT	\N	PRESENT	0
206896	206515	14227Q	PARTICIPANT	\N	PRESENT	0
206897	206515	19447X	PARTICIPANT	\N	PRESENT	0
206898	206515	14001X	PARTICIPANT	\N	PRESENT	0
206899	206515	08014Q	PARTICIPANT	\N	PRESENT	0
206900	206515	19725B	PARTICIPANT	\N	PRESENT	0
206901	206515	14207L	PARTICIPANT	\N	PRESENT	0
206902	206515	14169X	PARTICIPANT	\N	PRESENT	0
206903	206515	19599P	PARTICIPANT	\N	PRESENT	0
206904	206515	11041F	PARTICIPANT	\N	PRESENT	0
206905	206515	19669L	PARTICIPANT	\N	PRESENT	0
206907	206515	14257W	PARTICIPANT	\N	PRESENT	0
206908	206515	14097Y	PARTICIPANT	\N	PRESENT	0
206909	206515	14109K	PARTICIPANT	\N	PRESENT	0
206911	206515	14063N	PARTICIPANT	\N	PRESENT	0
206912	206515	19527W	PARTICIPANT	\N	PRESENT	0
206913	206515	19551W	PARTICIPANT	\N	PRESENT	0
206914	206515	11067R	PARTICIPANT	\N	PRESENT	0
206915	206515	19503N	PARTICIPANT	\N	PRESENT	0
206916	206515	19591F	PARTICIPANT	\N	PRESENT	0
206917	206515	19251M	PARTICIPANT	\N	PRESENT	0
206918	206515	19413M	PARTICIPANT	\N	PRESENT	0
206921	206515	11074Q	PARTICIPANT	\N	PRESENT	0
206922	206515	19329S	PARTICIPANT	\N	PRESENT	0
206923	206515	95067Q	PARTICIPANT	\N	PRESENT	0
206924	206515	19301E	PARTICIPANT	\N	PRESENT	0
206925	206515	14038Y	PARTICIPANT	\N	PRESENT	0
206926	206515	19585H	PARTICIPANT	\N	PRESENT	0
206927	206515	19545Y	PARTICIPANT	\N	PRESENT	0
206928	206515	14111D	PARTICIPANT	\N	PRESENT	0
206929	206515	14029X	PARTICIPANT	\N	PRESENT	0
206930	206515	05012A	PARTICIPANT	\N	PRESENT	0
206931	206515	14251Q	PARTICIPANT	\N	PRESENT	0
206932	206515	02002K	PARTICIPANT	\N	PRESENT	0
206933	206515	14039A	PARTICIPANT	\N	PRESENT	0
206934	206515	07033P	PARTICIPANT	\N	PRESENT	0
206935	206515	19697Q	PARTICIPANT	\N	PRESENT	0
206936	206515	07034Q	PARTICIPANT	\N	PRESENT	0
206937	206515	11065P	PARTICIPANT	\N	PRESENT	0
206938	206515	11099A	PARTICIPANT	\N	PRESENT	0
206939	206515	19719D	PARTICIPANT	\N	PRESENT	0
206940	206515	19387D	PARTICIPANT	\N	PRESENT	0
206941	206515	98022P	PARTICIPANT	\N	PRESENT	0
206942	206515	14241N	PARTICIPANT	\N	PRESENT	0
206943	206515	19563B	PARTICIPANT	\N	PRESENT	0
206944	206515	19421M	PARTICIPANT	\N	PRESENT	0
206945	206515	19269X	PARTICIPANT	\N	PRESENT	0
206946	206515	19543W	PARTICIPANT	\N	PRESENT	0
206947	206515	19349W	PARTICIPANT	\N	PRESENT	0
206948	206515	19637C	PARTICIPANT	\N	PRESENT	0
206949	206515	14201E	PARTICIPANT	\N	PRESENT	0
206950	206515	11081P	PARTICIPANT	\N	PRESENT	0
206951	206515	08047A	PARTICIPANT	\N	PRESENT	0
206952	206515	14159V	PARTICIPANT	\N	PRESENT	0
206953	206515	14357A	PARTICIPANT	\N	PRESENT	0
206954	206515	98023Q	PARTICIPANT	\N	PRESENT	0
206955	206515	19651A	PARTICIPANT	\N	PRESENT	0
206956	206515	14079W	PARTICIPANT	\N	PRESENT	0
206957	206515	14239U	PARTICIPANT	\N	PRESENT	0
206958	206515	11083R	PARTICIPANT	\N	PRESENT	0
206959	206515	19629C	PARTICIPANT	\N	PRESENT	0
206960	206515	04034C	PARTICIPANT	\N	PRESENT	0
206961	206515	04045F	PARTICIPANT	\N	PRESENT	0
206962	206515	08034U	PARTICIPANT	\N	PRESENT	0
206963	206515	98029W	PARTICIPANT	\N	PRESENT	0
206964	206515	14261S	PARTICIPANT	\N	PRESENT	0
206965	206515	19253P	PARTICIPANT	\N	PRESENT	0
206967	206515	88008L	PARTICIPANT	\N	PRESENT	0
206968	206515	08031R	PARTICIPANT	\N	PRESENT	0
206969	206515	14034U	PARTICIPANT	\N	PRESENT	0
206970	206515	95037J	PARTICIPANT	\N	PRESENT	0
206971	206515	95063L	PARTICIPANT	\N	PRESENT	0
206972	206515	08061X	PARTICIPANT	\N	PRESENT	0
206973	206515	11012A	PARTICIPANT	\N	PRESENT	0
206974	206515	04089T	PARTICIPANT	\N	PRESENT	0
206975	206515	14231L	PARTICIPANT	\N	PRESENT	0
206976	206515	14265W	PARTICIPANT	\N	PRESENT	0
206977	206515	19691J	PARTICIPANT	\N	PRESENT	0
206979	206515	14119M	PARTICIPANT	\N	PRESENT	0
206980	206515	19511N	PARTICIPANT	\N	PRESENT	0
206981	206515	19611R	PARTICIPANT	\N	PRESENT	0
206982	206515	19619A	PARTICIPANT	\N	PRESENT	0
206983	206515	19721W	PARTICIPANT	\N	PRESENT	0
206984	206515	11115U	PARTICIPANT	\N	PRESENT	0
206985	206515	19699S	PARTICIPANT	\N	PRESENT	0
206986	206515	14041T	PARTICIPANT	\N	PRESENT	0
206988	206515	14217N	PARTICIPANT	\N	PRESENT	0
206989	206515	14199E	PARTICIPANT	\N	PRESENT	0
206990	206515	19569H	PARTICIPANT	\N	PRESENT	0
206992	206515	08048B	PARTICIPANT	\N	PRESENT	0
206993	206515	19735D	PARTICIPANT	\N	PRESENT	0
206994	206515	16685X	PARTICIPANT	\N	PRESENT	0
206995	206515	19717B	PARTICIPANT	\N	PRESENT	0
206996	206515	19553Y	PARTICIPANT	\N	PRESENT	0
206997	206515	14093U	PARTICIPANT	\N	PRESENT	0
206998	206515	04057K	PARTICIPANT	\N	PRESENT	0
206999	206515	19673G	PARTICIPANT	\N	PRESENT	0
207000	206515	14195A	PARTICIPANT	\N	PRESENT	0
207001	206515	19441R	PARTICIPANT	\N	PRESENT	0
207002	206515	19479G	PARTICIPANT	\N	PRESENT	0
207003	206515	10006L	PARTICIPANT	\N	PRESENT	0
207004	206515	14042U	PARTICIPANT	\N	PRESENT	0
207005	206515	19713W	PARTICIPANT	\N	PRESENT	0
207006	206515	19583F	PARTICIPANT	\N	PRESENT	0
207007	206515	11064N	PARTICIPANT	\N	PRESENT	0
207008	206515	17589D	PARTICIPANT	\N	PRESENT	0
207011	206515	14103D	PARTICIPANT	\N	PRESENT	0
207012	206515	19709B	PARTICIPANT	\N	PRESENT	0
177647	177636	01056V	PARTICIPANT	\N	EXCUSE	0
177648	177636	08049C	PARTICIPANT	\N	EXCUSE	0
177649	177636	09001P	PARTICIPANT	\N	EXCUSE	0
177733	177732	98050T	PARTICIPANT	\N	PRESENT	0
177735	177734	11089X	PARTICIPANT	\N	PRESENT	0
178660	178659	11039M	PARTICIPANT	\N	PRESENT	0
178661	178659	98042T	PARTICIPANT	\N	PRESENT	0
178662	178659	01019Q	PARTICIPANT	\N	PRESENT	0
178972	177252	98035U	PARTICIPANT	\N	PRESENT	0
178973	177252	11040E	PARTICIPANT	\N	EXCUSE	0
179133	179132	01008M	PARTICIPANT	\N	PRESENT	0
179094	179092	08055A	PARTICIPANT	\N	PRESENT	0
179095	179092	14093U	PARTICIPANT	\N	PRESENT	0
179096	179092	14030Q	PARTICIPANT	\N	PRESENT	0
179134	179132	11036J	PARTICIPANT	\N	PRESENT	0
179098	179092	08060W	PARTICIPANT	\N	PRESENT	0
179099	179092	11095V	PARTICIPANT	\N	EXCUSE	0
179100	179092	14038Y	PARTICIPANT	\N	PRESENT	0
179101	179092	11114F	PARTICIPANT	\N	PRESENT	0
179135	179132	11081P	PARTICIPANT	\N	PRESENT	0
179136	179132	14013P	PARTICIPANT	\N	PRESENT	0
179104	179092	01015L	PARTICIPANT	\N	EXCUSE	0
179105	179092	11107G	PARTICIPANT	\N	PRESENT	0
179137	179132	08068F	PARTICIPANT	\N	PRESENT	0
179107	179092	02002K	PARTICIPANT	\N	PRESENT	0
179108	179092	01022K	PARTICIPANT	\N	PRESENT	0
179138	179132	14207L	PARTICIPANT	\N	PRESENT	0
179110	179092	04097T	PARTICIPANT	\N	PRESENT	0
179139	179132	11101A	PARTICIPANT	\N	PRESENT	0
179140	179132	90003B	PARTICIPANT	\N	PRESENT	0
179113	179092	14219Q	PARTICIPANT	\N	PRESENT	0
179114	179092	80027E	PARTICIPANT	\N	PRESENT	0
179115	179092	14031R	PARTICIPANT	\N	PRESENT	0
179116	179092	08009T	PRESIDENT	0	PRESENT	0
179117	179092	08062Y	PARTICIPANT	\N	EXCUSE	0
179118	179092	14221J	PARTICIPANT	\N	PRESENT	0
179119	179092	92039X	PARTICIPANT	\N	EXCUSE	0
179141	179132	08028W	PARTICIPANT	\N	PRESENT	0
179121	179092	14169X	PARTICIPANT	\N	PRESENT	0
179142	179132	80013X	PARTICIPANT	\N	PRESENT	0
179143	179132	14357A	PARTICIPANT	\N	PRESENT	0
179124	179092	05012A	PARTICIPANT	\N	PRESENT	0
179173	179172	01008M	PARTICIPANT	\N	PRESENT	0
179126	179092	14135M	PARTICIPANT	\N	PRESENT	0
179127	179092	14331P	PARTICIPANT	\N	PRESENT	0
179128	179092	95062K	PARTICIPANT	\N	PRESENT	0
179129	179092	14107H	PARTICIPANT	\N	PRESENT	0
179130	179092	14051J	PARTICIPANT	\N	PRESENT	0
179131	179092	14157T	PARTICIPANT	\N	PRESENT	0
179144	179132	08038Y	PARTICIPANT	\N	PRESENT	0
179145	179132	04089T	PARTICIPANT	\N	PRESENT	0
179146	179132	14197C	PARTICIPANT	\N	PRESENT	0
179147	179132	11110B	PARTICIPANT	\N	PRESENT	0
179148	179132	14187A	PARTICIPANT	\N	PRESENT	0
179149	179132	14033T	PARTICIPANT	\N	PRESENT	0
179150	179132	14081Q	PARTICIPANT	\N	PRESENT	0
179151	179132	11099A	PARTICIPANT	\N	PRESENT	0
179152	179132	04049K	PRESIDENT	0	PRESENT	0
179153	179132	04094Q	PARTICIPANT	\N	PRESENT	0
179154	179132	11111C	PARTICIPANT	\N	PRESENT	0
179155	179132	08015R	PARTICIPANT	\N	PRESENT	0
179156	179132	11100Y	PARTICIPANT	\N	EXCUSE	0
179174	179172	11036J	PARTICIPANT	\N	PRESENT	0
179158	179132	11098Y	PARTICIPANT	\N	PRESENT	0
179159	179132	01043Q	PARTICIPANT	\N	PRESENT	0
179175	179172	11081P	PARTICIPANT	\N	PRESENT	0
179161	179132	14205J	PARTICIPANT	\N	PRESENT	0
179162	179132	08019V	PARTICIPANT	\N	PRESENT	0
179163	179132	14257W	PARTICIPANT	\N	PRESENT	0
179164	179132	08021P	PARTICIPANT	\N	PRESENT	0
179165	179132	04088S	PARTICIPANT	\N	PRESENT	0
179166	179132	98050T	PARTICIPANT	\N	PRESENT	0
179212	179172	11100Y	PARTICIPANT	\N	EXCUSE	0
179168	179132	11046L	PARTICIPANT	\N	PRESENT	0
179169	179132	01058X	PARTICIPANT	\N	PRESENT	0
179170	179132	11094U	PARTICIPANT	\N	PRESENT	0
179171	179132	11066Q	PARTICIPANT	\N	EXCUSE	0
179176	179172	14013P	PARTICIPANT	\N	PRESENT	0
179177	179172	08068F	PARTICIPANT	\N	PRESENT	0
179178	179172	14207L	PARTICIPANT	\N	PRESENT	0
179179	179172	11101A	PARTICIPANT	\N	PRESENT	0
179180	179172	90003B	PARTICIPANT	\N	PRESENT	0
179181	179172	08028W	PARTICIPANT	\N	PRESENT	0
179182	179172	80013X	PARTICIPANT	\N	PRESENT	0
179183	179172	14357A	PARTICIPANT	\N	PRESENT	0
179184	179172	08038Y	PARTICIPANT	\N	PRESENT	0
179185	179172	04089T	PARTICIPANT	\N	PRESENT	0
179186	179172	14197C	PARTICIPANT	\N	PRESENT	0
179187	179172	11110B	PARTICIPANT	\N	PRESENT	0
179188	179172	14187A	PARTICIPANT	\N	PRESENT	0
179189	179172	14033T	PARTICIPANT	\N	PRESENT	0
179190	179172	14081Q	PARTICIPANT	\N	PRESENT	0
179191	179172	11099A	PARTICIPANT	\N	PRESENT	0
179192	179172	04049K	PRESIDENT	0	PRESENT	0
179193	179172	04094Q	PARTICIPANT	\N	PRESENT	0
179194	179172	11111C	PARTICIPANT	\N	PRESENT	0
179195	179172	08015R	PARTICIPANT	\N	PRESENT	0
179637	167340	01031L	PARTICIPANT	\N	PRESENT	0
179198	179172	11098Y	PARTICIPANT	\N	PRESENT	0
179199	179172	01043Q	PARTICIPANT	\N	PRESENT	0
179201	179172	14205J	PARTICIPANT	\N	PRESENT	0
179202	179172	08019V	PARTICIPANT	\N	PRESENT	0
179203	179172	14257W	PARTICIPANT	\N	PRESENT	0
179204	179172	08021P	PARTICIPANT	\N	PRESENT	0
179205	179172	04088S	PARTICIPANT	\N	PRESENT	0
179206	179172	98050T	PARTICIPANT	\N	PRESENT	0
179641	179638	14093U	PARTICIPANT	\N	PRESENT	0
179208	179172	11046L	PARTICIPANT	\N	PRESENT	0
179209	179172	01058X	PARTICIPANT	\N	PRESENT	0
179210	179172	11094U	PARTICIPANT	\N	PRESENT	0
179211	179172	11066Q	PARTICIPANT	\N	EXCUSE	0
179645	179638	11095V	PARTICIPANT	\N	EXCUSE	0
179647	179638	11114F	PARTICIPANT	\N	PRESENT	0
179648	179638	98023Q	PARTICIPANT	\N	PRESENT	0
179649	179638	11065P	PARTICIPANT	\N	PRESENT	0
179650	179638	01015L	PARTICIPANT	\N	EXCUSE	0
179651	179638	11107G	PARTICIPANT	\N	PRESENT	0
179652	179638	11020A	PARTICIPANT	\N	PRESENT	0
179659	179638	14219Q	PARTICIPANT	\N	PRESENT	0
179660	179638	80027E	PARTICIPANT	\N	PRESENT	0
179662	179638	08009T	PRESIDENT	0	PRESENT	0
179663	179638	08062Y	PARTICIPANT	\N	EXCUSE	0
179664	179638	14221J	PARTICIPANT	\N	PRESENT	0
179665	179638	92039X	PARTICIPANT	\N	EXCUSE	0
179667	179638	14169X	PARTICIPANT	\N	PRESENT	0
179670	179638	05012A	PARTICIPANT	\N	PRESENT	0
198317	197952	01034P	PARTICIPANT	\N	PRESENT	0
198318	197952	04092N	PARTICIPANT	0	PRESENT	0
198319	197952	08052W	PARTICIPANT	\N	PRESENT	0
198320	197952	12042Y	PARTICIPANT	\N	PRESENT	0
198321	197952	14034U	PARTICIPANT	\N	PRESENT	0
198322	197952	11093T	PARTICIPANT	\N	PRESENT	0
198323	197952	08041T	PARTICIPANT	\N	PRESENT	0
198324	197952	04081K	PARTICIPANT	\N	PRESENT	0
198325	197952	01011G	PARTICIPANT	\N	PRESENT	0
198326	197952	11023D	PARTICIPANT	\N	PRESENT	0
198327	197952	14119M	PARTICIPANT	\N	PRESENT	0
198328	197952	11103C	PARTICIPANT	\N	PRESENT	0
198329	197952	14121F	PARTICIPANT	\N	PRESENT	0
198330	197952	14071N	PARTICIPANT	\N	PRESENT	0
198331	197952	04043D	PARTICIPANT	\N	PRESENT	0
198332	197952	14255U	PARTICIPANT	\N	PRESENT	0
198333	197952	04053F	PARTICIPANT	\N	PRESENT	0
198334	197952	14017T	PARTICIPANT	\N	EXCUSE	0
198335	197952	00003C	PARTICIPANT	\N	EXCUSE	0
198336	197952	14265W	PARTICIPANT	\N	EXCUSE	0
198352	196738	14097Y	PARTICIPANT	\N	PRESENT	0
198353	196738	14193X	PARTICIPANT	\N	PRESENT	0
198354	196738	11106F	PARTICIPANT	\N	PRESENT	0
198355	196738	04078Q	PARTICIPANT	\N	PRESENT	0
198356	196738	04036E	PARTICIPANT	\N	PRESENT	0
198357	196738	95041E	PARTICIPANT	\N	PRESENT	0
198358	196738	98018T	PARTICIPANT	\N	PRESENT	0
198359	196738	11027H	PARTICIPANT	\N	PRESENT	0
198360	196738	14028W	PARTICIPANT	\N	PRESENT	0
198361	196738	08053X	PARTICIPANT	\N	PRESENT	0
198362	196738	04042C	PRESIDENT	0	PRESENT	0
198363	196738	77002U	PARTICIPANT	\N	PRESENT	0
198364	196738	08058D	PARTICIPANT	\N	PRESENT	0
198365	196738	14133K	PARTICIPANT	\N	PRESENT	0
198366	196738	98029W	PARTICIPANT	\N	PRESENT	0
198367	196738	98005N	PARTICIPANT	\N	PRESENT	0
198368	196738	95030B	PARTICIPANT	\N	PRESENT	0
198369	196738	92020L	PARTICIPANT	\N	PRESENT	0
198370	196738	92031P	PARTICIPANT	\N	PRESENT	0
198371	196738	08065C	PARTICIPANT	\N	PRESENT	0
198372	196738	08047A	PARTICIPANT	\N	PRESENT	0
198392	197533	11034G	PARTICIPANT	\N	PRESENT	0
198393	197533	01047U	PARTICIPANT	\N	PRESENT	0
198394	197533	04044E	PARTICIPANT	\N	PRESENT	0
198395	197533	04047H	PARTICIPANT	\N	PRESENT	0
198396	197533	01028R	PARTICIPANT	\N	PRESENT	0
198397	197533	05008E	PRESIDENT	0	PRESENT	0
198398	197533	11035H	PARTICIPANT	\N	PRESENT	0
198399	197533	08025T	PARTICIPANT	\N	PRESENT	0
198400	197533	14041T	PARTICIPANT	\N	PRESENT	0
198401	197533	14147R	PARTICIPANT	\N	PRESENT	0
198402	197533	14215L	PARTICIPANT	\N	PRESENT	0
198403	197533	14259Y	PARTICIPANT	\N	PRESENT	0
198404	197533	11072N	PARTICIPANT	\N	PRESENT	0
198405	197533	14111D	PARTICIPANT	\N	PRESENT	0
198406	197533	95067Q	PARTICIPANT	\N	PRESENT	0
198407	197533	07034Q	PARTICIPANT	\N	PRESENT	0
198408	197533	10015M	PARTICIPANT	\N	PRESENT	0
198409	197533	19253P	PARTICIPANT	\N	PRESENT	0
198410	197533	19251M	PARTICIPANT	\N	PRESENT	0
198411	197533	04038G	PARTICIPANT	\N	PRESENT	0
198412	197533	95063L	PARTICIPANT	\N	PRESENT	0
198413	197533	11037K	PARTICIPANT	\N	PRESENT	0
198414	197533	04074L	PARTICIPANT	\N	PRESENT	0
198415	197533	04056J	PARTICIPANT	\N	PRESENT	0
198416	197533	14069U	PARTICIPANT	\N	PRESENT	0
198417	196738	14039A	PARTICIPANT	\N	PRESENT	0
198418	196738	14251Q	PARTICIPANT	\N	PRESENT	0
198419	196738	98022P	PARTICIPANT	\N	PRESENT	0
198420	196738	86044G	PARTICIPANT	\N	PRESENT	0
198421	196738	98021N	PARTICIPANT	\N	PRESENT	0
198433	197952	14269B	PARTICIPANT	\N	PRESENT	0
198434	197952	14239U	PARTICIPANT	\N	PRESENT	0
198452	198065	04070G	PRESIDENT	0	PRESENT	0
198453	198065	14361V	PARTICIPANT	\N	PRESENT	0
198454	198065	14079W	PARTICIPANT	\N	PRESENT	0
198455	198065	11029K	PARTICIPANT	\N	PRESENT	0
198456	198065	14229S	PARTICIPANT	\N	PRESENT	0
198457	198065	11089X	PARTICIPANT	\N	PRESENT	0
198458	198065	14241N	PARTICIPANT	\N	PRESENT	0
198459	198065	08017T	PARTICIPANT	\N	PRESENT	0
198460	198065	14179A	PARTICIPANT	\N	PRESENT	0
198461	198065	14249W	PARTICIPANT	\N	PRESENT	0
198462	198065	08039A	PARTICIPANT	\N	PRESENT	0
198463	198065	07026Q	PARTICIPANT	\N	PRESENT	0
198464	198065	14059S	PARTICIPANT	\N	PRESENT	0
198465	198065	14061L	PARTICIPANT	\N	PRESENT	0
198466	198065	04057K	PARTICIPANT	\N	PRESENT	0
198467	198065	14073Q	PARTICIPANT	\N	PRESENT	0
198468	198065	14235Q	PARTICIPANT	\N	PRESENT	0
198469	198065	11091R	PARTICIPANT	\N	PRESENT	0
198470	198065	08043V	PARTICIPANT	\N	PRESENT	0
198471	198065	87003B	PARTICIPANT	\N	PRESENT	0
198472	198065	14089Y	PARTICIPANT	\N	PRESENT	0
198473	198065	04059M	PARTICIPANT	\N	PRESENT	0
198474	198065	14363X	PARTICIPANT	\N	PRESENT	0
198475	198065	14109K	PARTICIPANT	\N	PRESENT	0
198476	198065	14123H	PARTICIPANT	\N	PRESENT	0
198477	198065	11104D	PARTICIPANT	\N	PRESENT	0
198478	198065	14209N	PARTICIPANT	\N	PRESENT	0
198479	198065	83047W	PARTICIPANT	\N	PRESENT	0
198480	198065	14063N	PARTICIPANT	\N	PRESENT	0
198481	198065	08024S	PARTICIPANT	\N	PRESENT	0
198482	198065	08031R	PARTICIPANT	\N	PRESENT	0
198483	198065	92040Q	PARTICIPANT	\N	EXCUSE	0
198484	197493	08034U	PARTICIPANT	\N	PRESENT	0
198485	197493	11053K	PARTICIPANT	\N	PRESENT	0
198486	197493	89017R	PARTICIPANT	\N	PRESENT	0
198487	197493	08011M	PARTICIPANT	\N	PRESENT	0
198488	197493	01027Q	PARTICIPANT	\N	PRESENT	0
198489	197493	08014Q	PARTICIPANT	\N	PRESENT	0
198490	197493	88008L	PARTICIPANT	\N	PRESENT	0
198491	197493	14159V	PARTICIPANT	\N	PRESENT	0
198492	197493	11068S	PARTICIPANT	\N	PRESENT	0
198493	197493	11088W	PRESIDENT	0	PRESENT	0
198494	197493	14173T	PARTICIPANT	\N	PRESENT	0
198495	197493	07029T	PARTICIPANT	\N	PRESENT	0
198496	197493	14083S	PARTICIPANT	\N	PRESENT	0
198497	197493	14085U	PARTICIPANT	\N	PRESENT	0
198498	197493	98046X	PARTICIPANT	\N	PRESENT	0
198499	197493	08010L	PARTICIPANT	\N	PRESENT	0
198500	197493	14253S	PARTICIPANT	\N	PRESENT	0
198501	197493	99004R	PARTICIPANT	\N	PRESENT	0
198502	197493	04061F	PARTICIPANT	\N	PRESENT	0
198503	197493	11042G	PARTICIPANT	\N	PRESENT	0
198504	197493	04086Q	PARTICIPANT	\N	PRESENT	0
198505	197493	11057P	PARTICIPANT	\N	PRESENT	0
198506	197493	11048N	PARTICIPANT	\N	PRESENT	0
198507	197493	01016M	PARTICIPANT	\N	PRESENT	0
198508	197493	11083R	PARTICIPANT	\N	PRESENT	0
198509	197493	08061X	PARTICIPANT	\N	PRESENT	0
198510	197493	11074Q	PARTICIPANT	\N	PRESENT	0
198511	197493	11070L	PARTICIPANT	\N	PRESENT	0
198512	197493	04055H	PARTICIPANT	\N	PRESENT	0
198513	197493	14225N	PARTICIPANT	\N	PRESENT	0
198514	197493	01031L	PARTICIPANT	\N	EXCUSE	0
198515	197493	11012A	PARTICIPANT	\N	EXCUSE	0
198516	197493	98053W	PARTICIPANT	\N	EXCUSE	0
198553	198067	01043Q	PARTICIPANT	\N	PRESENT	0
198554	198067	14357A	PARTICIPANT	\N	PRESENT	0
198555	198067	11100Y	PRESIDENT	0	PRESENT	0
198556	198067	14081Q	PARTICIPANT	\N	PRESENT	0
198557	198067	80013X	PARTICIPANT	\N	PRESENT	0
198558	198067	11066Q	PARTICIPANT	\N	PRESENT	0
198559	198067	90003B	PARTICIPANT	\N	PRESENT	0
198560	198067	08068F	PARTICIPANT	\N	PRESENT	0
198561	198067	11094U	PARTICIPANT	\N	PRESENT	0
198562	198067	04049K	PARTICIPANT	\N	PRESENT	0
198563	198067	08015R	PARTICIPANT	\N	PRESENT	0
198564	198067	08019V	PARTICIPANT	\N	PRESENT	0
198565	198067	14197C	PARTICIPANT	\N	PRESENT	0
198566	198067	08028W	PARTICIPANT	\N	PRESENT	0
198567	198067	14187A	PARTICIPANT	\N	PRESENT	0
198568	198067	08038Y	PARTICIPANT	\N	PRESENT	0
198569	198067	11098Y	PARTICIPANT	\N	PRESENT	0
198570	198067	14033T	PARTICIPANT	\N	PRESENT	0
198571	198067	11090Q	PARTICIPANT	\N	PRESENT	0
198572	198067	01008M	PARTICIPANT	\N	PRESENT	0
198573	198067	14205J	PARTICIPANT	\N	PRESENT	0
198574	198067	04088S	PARTICIPANT	\N	PRESENT	0
198575	198067	04089T	PARTICIPANT	\N	PRESENT	0
198576	198067	11036J	PARTICIPANT	\N	PRESENT	0
198577	198067	11111C	PARTICIPANT	\N	PRESENT	0
198578	198067	98050T	PARTICIPANT	\N	PRESENT	0
198579	198067	14207L	PARTICIPANT	\N	PRESENT	0
198580	198067	14257W	PARTICIPANT	\N	PRESENT	0
198581	198067	01058X	PARTICIPANT	\N	EXCUSE	0
198582	198067	01061S	PARTICIPANT	\N	EXCUSE	0
198696	197512	14083S	PARTICIPANT	\N	PRESENT	0
169813	169812	01008M	PARTICIPANT	\N	PRESENT	0
169814	169812	80013X	PARTICIPANT	\N	PRESENT	0
169815	169812	11065P	PARTICIPANT	\N	PRESENT	0
169816	169812	01015L	PARTICIPANT	\N	PRESENT	0
169817	169812	09001P	PARTICIPANT	\N	PRESENT	0
169818	169812	14219Q	PRESIDENT	0	PRESENT	0
169819	169812	11035H	PARTICIPANT	\N	EXCUSE	0
184593	184592	04043D	PARTICIPANT	\N	PRESENT	0
184912	184820	04086Q	PARTICIPANT	\N	PRESENT	0
184913	184820	11040E	PARTICIPANT	\N	PRESENT	0
184914	184820	14175V	PARTICIPANT	\N	PRESENT	0
184915	184820	01031L	PRESIDENT	0	PRESENT	0
184916	184820	01048V	PARTICIPANT	\N	PRESENT	0
184917	184820	04034C	PARTICIPANT	\N	PRESENT	0
184918	184820	08069G	PARTICIPANT	\N	PRESENT	0
184919	184820	01057W	PARTICIPANT	\N	PRESENT	0
184920	184820	08011M	PARTICIPANT	\N	PRESENT	0
184921	184820	14225N	PARTICIPANT	\N	PRESENT	0
184922	184820	14159V	PARTICIPANT	\N	PRESENT	0
184923	184820	11042G	PARTICIPANT	\N	PRESENT	0
184924	184820	14327T	PARTICIPANT	\N	EXCUSE	0
184925	184820	07029T	PARTICIPANT	\N	EXCUSE	0
184926	184820	11057P	PARTICIPANT	\N	EXCUSE	0
184927	184820	14085U	PARTICIPANT	\N	EXCUSE	0
184928	184820	08034U	PARTICIPANT	\N	EXCUSE	0
184929	184820	89017R	PARTICIPANT	\N	EXCUSE	0
184930	184820	01027Q	PARTICIPANT	\N	EXCUSE	0
184931	184820	08022Q	PARTICIPANT	\N	EXCUSE	0
184932	184820	88008L	PARTICIPANT	\N	EXCUSE	0
184933	184820	11070L	PARTICIPANT	\N	EXCUSE	0
184934	184820	04061F	PARTICIPANT	\N	EXCUSE	0
184935	184820	01013J	PARTICIPANT	\N	EXCUSE	0
184959	184820	04071H	PARTICIPANT	\N	PRESENT	0
184960	184820	01016M	PARTICIPANT	\N	PRESENT	0
184961	184820	11053K	PARTICIPANT	\N	PRESENT	0
184962	184820	08010L	PARTICIPANT	\N	PRESENT	0
184992	184453	14111D	PARTICIPANT	\N	PRESENT	0
184993	184453	95067Q	PARTICIPANT	\N	PRESENT	0
184994	184453	11037K	PARTICIPANT	\N	PRESENT	0
184995	184453	14147R	PARTICIPANT	\N	PRESENT	0
184996	184453	14273W	PARTICIPANT	\N	PRESENT	0
184997	184453	11084S	PARTICIPANT	\N	PRESENT	0
184998	184453	04047H	PARTICIPANT	\N	PRESENT	0
184999	184453	14259Y	PARTICIPANT	\N	PRESENT	0
185000	184453	95049N	PARTICIPANT	\N	PRESENT	0
185001	184453	11035H	PARTICIPANT	\N	EXCUSE	0
185002	184453	07034Q	PARTICIPANT	\N	EXCUSE	0
185003	184453	01024M	PARTICIPANT	\N	EXCUSE	0
185004	184453	04044E	PARTICIPANT	\N	EXCUSE	0
185005	184453	04038G	PARTICIPANT	\N	EXCUSE	0
185006	184453	01028R	PARTICIPANT	\N	EXCUSE	0
185133	185132	14030Q	PARTICIPANT	\N	PRESENT	0
185134	185132	08043V	PARTICIPANT	\N	EXCUSE	0
185135	185132	08060W	PARTICIPANT	\N	EXCUSE	0
185136	185132	11029K	PARTICIPANT	\N	PRESENT	0
185137	185132	14038Y	PARTICIPANT	\N	EXCUSE	0
185138	185132	14217N	PARTICIPANT	\N	PRESENT	0
185139	185132	14014Q	PARTICIPANT	\N	EXCUSE	0
185140	185132	07026Q	PARTICIPANT	\N	PRESENT	0
185141	185132	08056B	PARTICIPANT	\N	EXCUSE	0
185142	185132	09001P	PARTICIPANT	\N	EXCUSE	0
185143	185132	04036E	PARTICIPANT	\N	EXCUSE	0
185144	185132	08031R	PARTICIPANT	\N	PRESENT	0
185145	185132	07029T	PARTICIPANT	\N	EXCUSE	0
185146	185132	14031R	PARTICIPANT	\N	EXCUSE	0
185147	185132	11014C	PARTICIPANT	\N	EXCUSE	0
185148	185132	14109K	PARTICIPANT	\N	PRESENT	0
185149	185132	14265W	PARTICIPANT	\N	PRESENT	0
185150	185132	14237S	PARTICIPANT	\N	EXCUSE	0
185151	185132	95035G	PRESIDENT	0	PRESENT	0
185613	185612	11061K	PARTICIPANT	\N	PRESENT	0
185614	185612	11031D	PARTICIPANT	\N	PRESENT	0
185615	185612	11097X	PARTICIPANT	\N	PRESENT	0
185617	185616	11031D	PARTICIPANT	\N	PRESENT	0
185618	185616	11061K	PARTICIPANT	\N	PRESENT	0
185619	185616	11097X	PARTICIPANT	\N	PRESENT	0
186245	186244	95067Q	PARTICIPANT	\N	PRESENT	0
188913	187934	14261S	PARTICIPANT	\N	PRESENT	0
188914	187934	14105F	PARTICIPANT	\N	PRESENT	0
188915	187934	14157T	PARTICIPANT	\N	PRESENT	0
188916	187942	14030Q	PARTICIPANT	\N	PRESENT	0
188917	187942	14105F	PARTICIPANT	\N	PRESENT	0
188918	187942	14034U	PARTICIPANT	\N	PRESENT	0
188919	187942	14157T	PARTICIPANT	\N	PRESENT	0
188920	187942	11063M	PARTICIPANT	\N	PRESENT	0
188921	187942	04049K	PARTICIPANT	\N	PRESENT	0
188933	188932	89017R	PARTICIPANT	\N	PRESENT	0
188935	188934	08034U	PARTICIPANT	\N	PRESENT	0
189032	187934	14151M	PARTICIPANT	\N	PRESENT	0
189034	189033	14193X	PARTICIPANT	\N	PRESENT	0
189035	189033	11054L	PARTICIPANT	\N	PRESENT	0
189037	189036	01014K	PARTICIPANT	\N	PRESENT	0
189038	189036	14193X	PARTICIPANT	\N	PRESENT	0
194652	190779	86034E	PARTICIPANT	\N	PRESENT	0
194672	190779	01027Q	PARTICIPANT	\N	PRESENT	0
194673	190779	01056V	PARTICIPANT	\N	PRESENT	0
194674	190779	77002U	PARTICIPANT	\N	PRESENT	0
194675	190779	04033B	PARTICIPANT	\N	PRESENT	0
194692	190779	08028W	PARTICIPANT	\N	PRESENT	0
194693	190779	04086Q	PARTICIPANT	\N	PRESENT	0
194694	190779	04043D	PARTICIPANT	\N	PRESENT	0
194695	190779	14237S	PARTICIPANT	\N	PRESENT	0
194696	190779	11030C	PARTICIPANT	\N	PRESENT	0
194697	190779	05012A	PARTICIPANT	\N	PRESENT	0
194698	190779	98023Q	PARTICIPANT	\N	PRESENT	0
194699	190779	02002K	PARTICIPANT	\N	PRESENT	0
194812	190779	08041T	PARTICIPANT	\N	PRESENT	0
194713	190779	14217N	PARTICIPANT	\N	PRESENT	0
194714	190779	14249W	PARTICIPANT	\N	PRESENT	0
194715	190779	11090Q	PARTICIPANT	\N	PRESENT	0
194732	190779	10015M	PARTICIPANT	\N	PRESENT	0
194733	190779	11103C	PARTICIPANT	\N	PRESENT	0
194734	190779	14187A	PARTICIPANT	\N	PRESENT	0
194752	190779	14061L	PARTICIPANT	\N	PRESENT	0
194772	190779	90003B	PARTICIPANT	\N	PRESENT	0
194773	190779	95030B	PARTICIPANT	\N	PRESENT	0
194774	190779	08065C	PARTICIPANT	\N	PRESENT	0
194792	190779	98024R	PARTICIPANT	\N	PRESENT	0
194794	190779	11091R	PARTICIPANT	\N	PRESENT	0
194813	190779	87003B	PARTICIPANT	\N	PRESENT	0
194815	190779	89029V	PARTICIPANT	\N	PRESENT	0
194832	190779	08062Y	PARTICIPANT	\N	PRESENT	0
194833	190779	04074L	PARTICIPANT	\N	PRESENT	0
194835	190779	14213J	PARTICIPANT	\N	PRESENT	0
194852	190779	04044E	PARTICIPANT	\N	PRESENT	0
194872	190779	08019V	PARTICIPANT	\N	PRESENT	0
194873	190779	14123H	PARTICIPANT	\N	PRESENT	0
194874	190779	14079W	PARTICIPANT	\N	PRESENT	0
194892	190779	14223L	PARTICIPANT	\N	PRESENT	0
194893	190779	08039A	PARTICIPANT	\N	PRESENT	0
194912	190779	11080N	PARTICIPANT	\N	PRESENT	0
194932	190779	14169X	PARTICIPANT	\N	PRESENT	0
194952	190779	14357A	PARTICIPANT	\N	PRESENT	0
194953	190779	14173T	PARTICIPANT	\N	PRESENT	0
194972	190779	14041T	PARTICIPANT	\N	PRESENT	0
194992	190779	14105F	PARTICIPANT	\N	PRESENT	0
195012	190779	98018T	PARTICIPANT	\N	PRESENT	0
195032	190779	14265W	PARTICIPANT	\N	PRESENT	0
195052	190779	99004R	PARTICIPANT	\N	PRESENT	0
195072	190779	14031R	PARTICIPANT	\N	PRESENT	0
195092	190779	14133K	PARTICIPANT	\N	PRESENT	0
195112	190779	14053L	PARTICIPANT	\N	PRESENT	0
195132	190779	01008M	PARTICIPANT	\N	PRESENT	0
195152	190779	04092N	PARTICIPANT	\N	PRESENT	0
195172	190779	97011G	PARTICIPANT	\N	PRESENT	0
195192	190779	04097T	PARTICIPANT	\N	PRESENT	0
195212	190779	92040Q	PARTICIPANT	\N	PRESENT	0
195232	190779	95062K	PARTICIPANT	\N	PRESENT	0
195233	190779	14259Y	PARTICIPANT	\N	PRESENT	0
195234	190779	14215L	PARTICIPANT	\N	PRESENT	0
195235	190779	14059S	PARTICIPANT	\N	PRESENT	0
195236	190779	04088S	PARTICIPANT	\N	PRESENT	0
195237	190779	07029T	PARTICIPANT	\N	PRESENT	0
195238	190779	14147R	PARTICIPANT	\N	PRESENT	0
195239	190779	01059Y	PARTICIPANT	\N	PRESENT	0
195240	190779	07026Q	PARTICIPANT	\N	PRESENT	0
195241	190779	01013J	PARTICIPANT	\N	PRESENT	0
195242	190779	08015R	PARTICIPANT	\N	PRESENT	0
195243	190779	98005N	PARTICIPANT	\N	PRESENT	0
195244	190779	04085P	PARTICIPANT	\N	PRESENT	0
195245	190779	98053W	PARTICIPANT	\N	PRESENT	0
195246	190779	04035D	PARTICIPANT	\N	PRESENT	0
195247	190779	92018S	PARTICIPANT	\N	PRESENT	0
195248	190779	95015C	PARTICIPANT	\N	PRESENT	0
195249	190779	04054G	PARTICIPANT	\N	PRESENT	0
195250	190779	12041X	PARTICIPANT	\N	PRESENT	0
195251	190779	14211G	PARTICIPANT	\N	PRESENT	0
207101	206515	14133K	PARTICIPANT	\N	PRESENT	0
207015	206515	14073Q	PARTICIPANT	\N	PRESENT	0
207087	206515	14255U	PARTICIPANT	\N	PRESENT	0
207017	206515	19521Q	PARTICIPANT	\N	PRESENT	0
207089	206515	14267Y	PARTICIPANT	\N	PRESENT	0
207095	206515	08044W	PARTICIPANT	\N	PRESENT	0
207020	206515	19335Q	PARTICIPANT	\N	PRESENT	0
207021	206515	19581D	PARTICIPANT	\N	PRESENT	0
207106	206515	14115H	PARTICIPANT	\N	PRESENT	0
207023	206515	19507S	PARTICIPANT	\N	PRESENT	0
207024	206515	17583W	PARTICIPANT	\N	PRESENT	0
207025	206515	19705W	PARTICIPANT	\N	PRESENT	0
207026	206515	19483C	PARTICIPANT	\N	PRESENT	0
207099	206515	08009T	PARTICIPANT	\N	PRESENT	0
207092	206515	01025N	PARTICIPANT	\N	PRESENT	0
207086	206515	14089Y	PARTICIPANT	\N	PRESENT	0
207081	206515	01043Q	PARTICIPANT	\N	PRESENT	0
207085	206515	04040A	PARTICIPANT	\N	PRESENT	0
207091	206515	19577H	PARTICIPANT	\N	PRESENT	0
207093	206515	07004J	PARTICIPANT	\N	PRESENT	0
207034	206515	11010L	PARTICIPANT	\N	PRESENT	0
207035	206515	19727D	PARTICIPANT	\N	PRESENT	0
207036	206515	14033T	PARTICIPANT	\N	PRESENT	0
207037	206515	08011M	PARTICIPANT	\N	PRESENT	0
207041	206515	04043D	PARTICIPANT	\N	PRESENT	0
207253	207252	11010L	PARTICIPANT	\N	EXCUSE	0
207254	206477	98005N	PARTICIPANT	\N	PRESENT	0
207255	206477	19443T	PARTICIPANT	\N	PRESENT	0
207043	206515	14215L	PARTICIPANT	\N	PRESENT	0
207044	206515	19533U	PARTICIPANT	\N	PRESENT	0
207256	206477	04034C	PARTICIPANT	\N	PRESENT	0
207046	206515	04061F	PARTICIPANT	\N	PRESENT	0
207047	206515	19671E	PARTICIPANT	\N	PRESENT	0
207257	206477	14079W	PARTICIPANT	\N	PRESENT	0
207049	206515	04018C	PARTICIPANT	\N	PRESENT	0
207258	206477	01058X	PARTICIPANT	\N	PRESENT	0
207051	206515	01057W	PARTICIPANT	\N	PRESENT	0
207052	206515	19657G	PARTICIPANT	\N	PRESENT	0
207053	206515	08019V	PARTICIPANT	\N	PRESENT	0
207054	206515	01034P	PARTICIPANT	\N	PRESENT	0
207055	206515	14253S	PARTICIPANT	\N	PRESENT	0
207056	206515	19467C	PARTICIPANT	\N	PRESENT	0
207057	206515	18083K	PARTICIPANT	\N	PRESENT	0
207058	206515	19663E	PARTICIPANT	\N	PRESENT	0
207059	206515	04088S	PARTICIPANT	\N	PRESENT	0
207060	206515	19703U	PARTICIPANT	\N	PRESENT	0
207061	206515	19677L	PARTICIPANT	\N	PRESENT	0
207062	206515	08018U	PARTICIPANT	\N	PRESENT	0
207063	206515	14213J	PARTICIPANT	\N	PRESENT	0
207064	206515	07029T	PARTICIPANT	\N	PRESENT	0
207065	206515	14355X	PARTICIPANT	\N	PRESENT	0
207066	206515	19729F	PARTICIPANT	\N	PRESENT	0
207067	206515	19701S	PARTICIPANT	\N	PRESENT	0
207068	206515	19573D	PARTICIPANT	\N	PRESENT	0
207069	206515	19723Y	PARTICIPANT	\N	PRESENT	0
207071	206515	08015R	PARTICIPANT	\N	PRESENT	0
207072	207070	11048N	PARTICIPANT	\N	PRESENT	0
207073	207070	14059S	PARTICIPANT	\N	PRESENT	0
207074	206515	89017R	PARTICIPANT	\N	PRESENT	0
207075	206515	14055N	PARTICIPANT	\N	PRESENT	0
207076	207070	10006L	PARTICIPANT	\N	PRESENT	0
207077	207070	14193X	PARTICIPANT	\N	PRESENT	0
207078	206515	19369B	PARTICIPANT	\N	PRESENT	0
207079	206515	04070G	PARTICIPANT	\N	PRESENT	0
207080	206515	19687N	PARTICIPANT	\N	PRESENT	0
207082	206515	14235Q	PARTICIPANT	\N	PRESENT	0
207083	206515	11027H	PARTICIPANT	\N	PRESENT	0
207084	206515	14030Q	PARTICIPANT	\N	PRESENT	0
207088	206515	11053K	PARTICIPANT	\N	PRESENT	0
207090	206515	14327T	PARTICIPANT	\N	PRESENT	0
207094	206515	14179A	PARTICIPANT	\N	PRESENT	0
207096	206515	14205J	PARTICIPANT	\N	PRESENT	0
207097	206515	14219Q	PARTICIPANT	\N	PRESENT	0
207098	206515	11085T	PARTICIPANT	\N	PRESENT	0
207100	206515	14221J	PARTICIPANT	\N	PRESENT	0
207102	206515	19707Y	PARTICIPANT	\N	PRESENT	0
207103	206515	05008E	PARTICIPANT	\N	PRESENT	0
207104	206515	19667J	PARTICIPANT	\N	PRESENT	0
207105	206515	19575F	PARTICIPANT	\N	PRESENT	0
207259	206477	04040A	PARTICIPANT	\N	PRESENT	0
207260	206477	11027H	PARTICIPANT	\N	PRESENT	0
207261	206477	16685X	PARTICIPANT	\N	PRESENT	0
207262	206477	04042C	PRESIDENT	0	PRESENT	0
207263	206477	11054L	PARTICIPANT	\N	PRESENT	0
207264	206477	11066Q	PARTICIPANT	\N	PRESENT	0
207265	206477	08056B	PARTICIPANT	\N	PRESENT	0
207266	206477	95037J	PARTICIPANT	\N	PRESENT	0
207267	206477	19421M	PARTICIPANT	\N	PRESENT	0
207268	206477	19709B	PARTICIPANT	\N	PRESENT	0
207269	206477	14193X	PARTICIPANT	\N	PRESENT	0
207270	206477	08053X	PARTICIPANT	\N	PRESENT	0
207271	206477	08061X	PARTICIPANT	\N	PRESENT	0
207272	206477	08047A	PARTICIPANT	\N	PRESENT	0
207273	206477	98029W	PARTICIPANT	\N	PRESENT	0
207274	206477	14097Y	PARTICIPANT	\N	PRESENT	0
207275	206477	95067Q	PARTICIPANT	\N	PRESENT	0
207276	206477	14133K	PARTICIPANT	\N	PRESENT	0
207277	206477	01062T	PARTICIPANT	\N	PRESENT	0
207278	206477	11041F	PARTICIPANT	\N	PRESENT	0
207279	206477	14235Q	PARTICIPANT	\N	PRESENT	0
207280	206477	08058D	PARTICIPANT	\N	PRESENT	0
207281	206477	19251M	PARTICIPANT	\N	PRESENT	0
207282	206477	14028W	PARTICIPANT	\N	PRESENT	0
207283	206477	19721W	PARTICIPANT	\N	PRESENT	0
207284	206477	98022P	PARTICIPANT	\N	PRESENT	0
207285	206477	14267Y	PARTICIPANT	\N	PRESENT	0
207286	206477	11064N	PARTICIPANT	\N	PRESENT	0
207287	206477	98050T	PARTICIPANT	\N	PRESENT	0
207288	206477	19583F	PARTICIPANT	\N	PRESENT	0
207289	206477	14211G	PARTICIPANT	\N	PRESENT	0
207290	206477	14255U	PARTICIPANT	\N	PRESENT	0
207292	206477	11115U	PARTICIPANT	\N	PRESENT	0
207293	206477	04035D	PARTICIPANT	\N	PRESENT	0
207295	206486	19697Q	PARTICIPANT	\N	PRESENT	0
207296	206486	11067R	PARTICIPANT	\N	PRESENT	0
207297	206486	11077T	PARTICIPANT	\N	PRESENT	0
207298	206486	14355X	PARTICIPANT	\N	PRESENT	0
207299	206486	19569H	PARTICIPANT	\N	PRESENT	0
207300	206486	11097X	PARTICIPANT	\N	PRESENT	0
207301	206486	19415P	PARTICIPANT	\N	PRESENT	0
207302	206486	04045F	PARTICIPANT	\N	PRESENT	0
207303	206486	14223L	PARTICIPANT	\N	PRESENT	0
207304	206486	14026U	PARTICIPANT	\N	PRESENT	0
207305	206486	14227Q	PARTICIPANT	\N	PRESENT	0
207306	206486	17779H	PARTICIPANT	\N	PRESENT	0
207307	206486	11063M	PARTICIPANT	\N	PRESENT	0
207308	206486	14239U	PARTICIPANT	\N	PRESENT	0
207309	206486	19553Y	PARTICIPANT	\N	PRESENT	0
207310	206486	19703U	PARTICIPANT	\N	PRESENT	0
207311	206486	14281W	PARTICIPANT	\N	PRESENT	0
207312	206486	14087W	PARTICIPANT	\N	PRESENT	0
207313	206486	19679N	PARTICIPANT	\N	PRESENT	0
207314	206486	14042U	PARTICIPANT	\N	PRESENT	0
207315	206486	14195A	PARTICIPANT	\N	PRESENT	0
207316	206486	19575F	PARTICIPANT	\N	PRESENT	0
207317	206486	08048B	PARTICIPANT	\N	PRESENT	0
207318	206486	14213J	PARTICIPANT	\N	PRESENT	0
207319	206486	19367Y	PARTICIPANT	\N	PRESENT	0
207320	206486	14261S	PARTICIPANT	\N	PRESENT	0
207321	206486	14217N	PARTICIPANT	\N	PRESENT	0
207322	206486	19335Q	PARTICIPANT	\N	PRESENT	0
207323	206486	19683J	PARTICIPANT	\N	PRESENT	0
207324	206486	10006L	PARTICIPANT	\N	PRESENT	0
207325	206486	98024R	PARTICIPANT	\N	PRESENT	0
207326	206486	19521Q	PARTICIPANT	\N	PRESENT	0
207327	206486	19527W	PARTICIPANT	\N	PRESENT	0
207328	206486	01034P	PARTICIPANT	\N	PRESENT	0
207329	206486	04092N	PRESIDENT	0	PRESENT	0
207330	206486	11045K	PARTICIPANT	\N	PRESENT	0
207331	206486	08052W	PARTICIPANT	\N	PRESENT	0
207332	206486	19663E	PARTICIPANT	\N	PRESENT	0
207333	206486	19691J	PARTICIPANT	\N	PRESENT	0
207334	206486	19717B	PARTICIPANT	\N	PRESENT	0
207335	206486	08041T	PARTICIPANT	\N	PRESENT	0
207336	206486	19723Y	PARTICIPANT	\N	PRESENT	0
207337	206486	19727D	PARTICIPANT	\N	PRESENT	0
207338	206486	14119M	PARTICIPANT	\N	PRESENT	0
207339	206486	11103C	PARTICIPANT	\N	PRESENT	0
207340	206486	19657G	PARTICIPANT	\N	PRESENT	0
207341	206486	14071N	PARTICIPANT	\N	PRESENT	0
207342	206486	19577H	PARTICIPANT	\N	PRESENT	0
207343	206486	19715Y	PARTICIPANT	\N	EXCUSE	0
207344	206477	14105F	PARTICIPANT	\N	PRESENT	0
207345	206494	01060R	PARTICIPANT	\N	PRESENT	0
207346	206494	14001X	PARTICIPANT	\N	PRESENT	0
207347	206494	19543W	PARTICIPANT	\N	PRESENT	0
207348	206494	04044E	PARTICIPANT	\N	PRESENT	0
207349	206494	19581D	PARTICIPANT	\N	PRESENT	0
207350	206494	04047H	PRESIDENT	1	PRESENT	0
171222	171221	08051V	PARTICIPANT	\N	PRESENT	0
171223	171221	14071N	PARTICIPANT	\N	PRESENT	0
171233	171232	14215L	PARTICIPANT	\N	PRESENT	0
171252	171232	11070L	PARTICIPANT	\N	PRESENT	0
171396	171395	14239U	PARTICIPANT	\N	PRESENT	0
171434	171395	11067R	PARTICIPANT	\N	PRESENT	0
172784	172783	01008M	PARTICIPANT	\N	PRESENT	0
171399	171395	08043V	PARTICIPANT	\N	PRESENT	0
172785	172783	11036J	PARTICIPANT	\N	PRESENT	0
171401	171395	14195A	PARTICIPANT	\N	PRESENT	0
178794	178793	11039M	PARTICIPANT	\N	PRESENT	0
171403	171395	08052W	PARTICIPANT	\N	PRESENT	0
172787	172783	14013P	PARTICIPANT	\N	PRESENT	0
172788	172783	08068F	PARTICIPANT	\N	PRESENT	0
178795	178793	08012N	PARTICIPANT	\N	PRESENT	0
171407	171395	11061K	PARTICIPANT	\N	PRESENT	0
171408	171395	14213J	PARTICIPANT	\N	PRESENT	0
172790	172783	11101A	PARTICIPANT	\N	PRESENT	0
172791	172783	90003B	PARTICIPANT	\N	PRESENT	0
171411	171395	14147R	PARTICIPANT	\N	PRESENT	0
171412	171395	14223L	PARTICIPANT	\N	PRESENT	0
171413	171395	04092N	PRESIDENT	0	PRESENT	0
171414	171395	14265W	PARTICIPANT	\N	PRESENT	0
178796	178793	14073Q	PARTICIPANT	\N	PRESENT	0
171416	171395	14235Q	PARTICIPANT	\N	PRESENT	0
171417	171395	14331P	PARTICIPANT	\N	PRESENT	0
171418	171395	14271U	PARTICIPANT	\N	PRESENT	0
171419	171395	11097X	PARTICIPANT	\N	PRESENT	0
171420	171395	04045F	PARTICIPANT	\N	PRESENT	0
171421	171395	11094U	PARTICIPANT	\N	PRESENT	0
172792	172783	08028W	PARTICIPANT	\N	PRESENT	0
172793	172783	80013X	PARTICIPANT	\N	PRESENT	0
172794	172783	14357A	PARTICIPANT	\N	PRESENT	0
172795	172783	08038Y	PARTICIPANT	\N	PRESENT	0
172796	172783	04089T	PARTICIPANT	\N	PRESENT	0
178797	178793	14241N	PARTICIPANT	\N	PRESENT	0
178799	178793	14235Q	PARTICIPANT	\N	PRESENT	0
172799	172783	14187A	PARTICIPANT	\N	PRESENT	0
172800	172783	14033T	PARTICIPANT	\N	PRESENT	0
172801	172783	14081Q	PARTICIPANT	\N	PRESENT	0
178801	178793	11029K	PARTICIPANT	\N	PRESENT	0
172803	172783	04049K	PARTICIPANT	\N	PRESENT	0
179756	167340	11036J	PARTICIPANT	\N	PRESENT	0
172805	172783	11111C	PARTICIPANT	\N	PRESENT	0
172806	172783	08015R	PARTICIPANT	\N	PRESENT	0
172807	172783	11100Y	PRESIDENT	0	PRESENT	0
172808	172783	01061S	PARTICIPANT	\N	EXCUSE	0
172809	172783	11098Y	PARTICIPANT	\N	PRESENT	0
172810	172783	01043Q	PARTICIPANT	\N	PRESENT	0
179673	179638	14331P	PARTICIPANT	\N	PRESENT	0
172812	172783	14205J	PARTICIPANT	\N	PRESENT	0
172813	172783	08019V	PARTICIPANT	\N	PRESENT	0
172814	172783	14257W	PARTICIPANT	\N	PRESENT	0
179674	179638	95062K	PARTICIPANT	\N	PRESENT	0
172816	172783	04088S	PARTICIPANT	\N	PRESENT	0
172817	172783	98050T	PARTICIPANT	\N	PRESENT	0
172818	172783	11090Q	PARTICIPANT	\N	PRESENT	0
172819	172783	11046L	PARTICIPANT	\N	PRESENT	0
172820	172783	01058X	PARTICIPANT	\N	PRESENT	0
172821	172783	11094U	PARTICIPANT	\N	PRESENT	0
172822	172783	11066Q	PARTICIPANT	\N	PRESENT	0
179675	179638	14107H	PARTICIPANT	\N	PRESENT	0
179676	179638	14051J	PARTICIPANT	\N	PRESENT	0
179677	179638	14157T	PARTICIPANT	\N	PRESENT	0
179752	167340	01008M	PARTICIPANT	\N	PRESENT	0
179755	167340	05008E	PARTICIPANT	\N	PRESENT	0
179758	167340	04085P	PARTICIPANT	\N	PRESENT	0
179759	167340	96004D	PARTICIPANT	\N	PRESENT	0
179760	167340	14013P	PARTICIPANT	\N	PRESENT	0
179761	167340	11029K	PARTICIPANT	\N	PRESENT	0
179762	167340	08068F	PARTICIPANT	\N	PRESENT	0
179763	167340	04053F	PARTICIPANT	\N	PRESENT	0
179764	167340	11101A	PARTICIPANT	\N	PRESENT	0
179765	167340	04042C	PARTICIPANT	\N	PRESENT	0
179766	167340	14083S	PARTICIPANT	\N	PRESENT	0
179767	167340	88008L	PARTICIPANT	\N	PRESENT	0
179768	167340	80013X	PARTICIPANT	\N	PRESENT	0
179769	167340	04086Q	PARTICIPANT	\N	PRESENT	0
179770	167340	01024M	PARTICIPANT	\N	PRESENT	0
179771	167340	14215L	PARTICIPANT	\N	PRESENT	0
179772	167340	95030B	PARTICIPANT	\N	PRESENT	0
179773	167340	14187A	PARTICIPANT	\N	PRESENT	0
179774	167340	98053W	PARTICIPANT	\N	PRESENT	0
179775	167340	11061K	PARTICIPANT	\N	PRESENT	0
179776	167340	14033T	PARTICIPANT	\N	PRESENT	0
179777	167340	14026U	PARTICIPANT	\N	PRESENT	0
179778	167340	01057W	PARTICIPANT	\N	PRESENT	0
179779	167340	11064N	PARTICIPANT	\N	PRESENT	0
179818	177592	11067R	PARTICIPANT	\N	PRESENT	0
179833	177595	14119M	PARTICIPANT	\N	PRESENT	0
179835	177595	14269B	PARTICIPANT	\N	PRESENT	0
179836	177595	11067R	PARTICIPANT	\N	PRESENT	0
179872	177595	11097X	PARTICIPANT	\N	PRESENT	0
180034	167340	11048N	PARTICIPANT	\N	PRESENT	0
180035	167340	95041E	PARTICIPANT	\N	PRESENT	0
180036	167340	14061L	PARTICIPANT	\N	PRESENT	0
180037	167340	14073Q	PARTICIPANT	\N	PRESENT	0
180038	167340	04049K	PARTICIPANT	\N	PRESENT	0
180052	167340	86034E	PARTICIPANT	\N	PRESENT	0
180053	167340	08034U	PARTICIPANT	\N	PRESENT	0
180054	167340	14219Q	PARTICIPANT	\N	PRESENT	0
180055	167340	11106F	PARTICIPANT	\N	PRESENT	0
180056	167340	14103D	PARTICIPANT	\N	PRESENT	0
180057	167340	08009T	PARTICIPANT	\N	PRESENT	0
180058	167340	14223L	PARTICIPANT	\N	PRESENT	0
180059	167340	04092N	PARTICIPANT	\N	PRESENT	0
180060	167340	14265W	PARTICIPANT	\N	PRESENT	0
180061	167340	04070G	PARTICIPANT	\N	PRESENT	0
180062	167340	04088S	PARTICIPANT	\N	PRESENT	0
180063	167340	14331P	PARTICIPANT	\N	PRESENT	0
180064	167340	11012A	PARTICIPANT	\N	PRESENT	0
180065	167340	95062K	PARTICIPANT	\N	PRESENT	0
180066	167340	95063L	PARTICIPANT	\N	PRESENT	0
180067	167340	14361V	PARTICIPANT	\N	PRESENT	0
180068	167340	14229S	PARTICIPANT	\N	PRESENT	0
180069	167340	14363X	PARTICIPANT	\N	PRESENT	0
180070	167340	11097X	PARTICIPANT	\N	PRESENT	0
180071	167340	01058X	PARTICIPANT	\N	PRESENT	0
180073	167340	14157T	PARTICIPANT	\N	PRESENT	0
180141	180134	14026U	PARTICIPANT	\N	PRESENT	0
180077	167340	14173T	PARTICIPANT	\N	PRESENT	0
180078	167340	14269B	PARTICIPANT	\N	PRESENT	0
180136	180134	04047H	PARTICIPANT	\N	PRESENT	0
180137	180134	14267Y	PARTICIPANT	\N	PRESENT	0
180139	180134	14079W	PARTICIPANT	\N	PRESENT	0
180140	180134	11083R	PARTICIPANT	\N	PRESENT	0
180142	180134	11084S	PARTICIPANT	\N	PRESENT	0
180143	180134	11026G	PARTICIPANT	\N	PRESENT	0
180144	180134	92031P	PARTICIPANT	\N	PRESENT	0
180145	180134	14001X	PARTICIPANT	\N	PRESENT	0
180146	180134	11012A	PRESIDENT	0	PRESENT	0
180147	180134	95067Q	PARTICIPANT	\N	PRESENT	0
181773	181772	14089Y	PARTICIPANT	\N	PRESENT	0
181774	181772	11029K	PARTICIPANT	\N	PRESENT	0
181775	181772	14207L	PRESIDENT	0	PRESENT	0
181776	181772	14053L	PARTICIPANT	\N	PRESENT	0
181777	181772	14087W	PARTICIPANT	\N	PRESENT	0
181778	181772	04035D	PARTICIPANT	\N	PRESENT	0
181779	181772	14231L	PARTICIPANT	\N	PRESENT	0
181780	181772	14031R	PARTICIPANT	\N	PRESENT	0
181781	181772	04057K	PARTICIPANT	\N	PRESENT	0
181782	181772	14237S	PARTICIPANT	\N	PRESENT	0
181783	181772	14135M	PARTICIPANT	\N	PRESENT	0
181784	181772	14229S	PARTICIPANT	\N	PRESENT	0
181785	181772	04050C	PARTICIPANT	\N	PRESENT	0
181814	181813	14219Q	PRESIDENT	0	PRESENT	0
181815	181813	11065P	PARTICIPANT	\N	PRESENT	0
181816	181813	92045V	PARTICIPANT	\N	PRESENT	0
181817	181813	01008M	PARTICIPANT	\N	PRESENT	0
181818	181813	14033T	PARTICIPANT	\N	PRESENT	0
181819	181813	14093U	PARTICIPANT	\N	EXCUSE	0
181820	181813	90003B	PARTICIPANT	\N	EXCUSE	0
181821	181813	11035H	PARTICIPANT	\N	EXCUSE	0
181822	181813	01015L	PARTICIPANT	\N	EXCUSE	0
181823	181813	09001P	PARTICIPANT	\N	EXCUSE	0
181824	181813	05012A	PARTICIPANT	\N	EXCUSE	0
181853	181852	92020L	PARTICIPANT	\N	PRESENT	0
181854	181852	14097Y	PARTICIPANT	\N	PRESENT	0
181855	181852	11014C	PARTICIPANT	\N	PRESENT	0
181872	181852	08043V	PARTICIPANT	\N	PRESENT	0
181892	167352	14263U	PARTICIPANT	\N	PRESENT	0
181893	167352	04045F	PARTICIPANT	\N	PRESENT	0
182053	182052	14193X	PARTICIPANT	\N	PRESENT	0
182054	182052	04040A	PARTICIPANT	\N	PRESENT	0
182055	182052	11054L	PARTICIPANT	\N	PRESENT	0
182057	182056	11033F	PARTICIPANT	\N	PRESENT	0
182073	182072	14105F	PARTICIPANT	\N	PRESENT	0
182092	182072	14207L	PARTICIPANT	\N	PRESENT	0
182093	182072	90003B	PARTICIPANT	\N	PRESENT	0
198712	198612	11067R	PARTICIPANT	\N	PRESENT	0
198713	198612	11061K	PARTICIPANT	\N	PRESENT	0
198714	198612	11097X	PARTICIPANT	\N	PRESENT	0
198715	198612	14223L	PARTICIPANT	\N	PRESENT	0
198716	198612	04045F	PARTICIPANT	\N	PRESENT	0
198717	198612	14026U	PARTICIPANT	\N	PRESENT	0
198718	198612	14227Q	PARTICIPANT	\N	PRESENT	0
198719	198612	14269B	PARTICIPANT	\N	PRESENT	0
198720	198612	11112D	PARTICIPANT	\N	PRESENT	0
198721	198612	11063M	PARTICIPANT	\N	PRESENT	0
198722	198612	14231L	PARTICIPANT	\N	PRESENT	0
198723	198612	11031D	PARTICIPANT	\N	PRESENT	0
198724	198612	14281W	PARTICIPANT	\N	PRESENT	0
198725	198612	14271U	PARTICIPANT	\N	PRESENT	0
198726	198612	14195A	PARTICIPANT	\N	PRESENT	0
198727	198612	14151M	PARTICIPANT	\N	PRESENT	0
198728	198612	14213J	PARTICIPANT	\N	PRESENT	0
198729	198612	14217N	PARTICIPANT	\N	PRESENT	0
198730	198612	10006L	PARTICIPANT	\N	PRESENT	0
198731	198612	98024R	PRESIDENT	0	PRESENT	0
198732	198612	04092N	PARTICIPANT	\N	PRESENT	0
198733	198612	08052W	PARTICIPANT	\N	PRESENT	0
198734	198612	12042Y	PARTICIPANT	\N	PRESENT	0
198735	198612	14034U	PARTICIPANT	\N	PRESENT	0
198736	198612	04081K	PARTICIPANT	\N	PRESENT	0
198737	198612	14119M	PARTICIPANT	\N	PRESENT	0
198738	198612	14121F	PARTICIPANT	\N	PRESENT	0
198739	198612	14071N	PARTICIPANT	\N	PRESENT	0
198740	198612	04043D	PARTICIPANT	\N	PRESENT	0
198741	198612	14255U	PARTICIPANT	\N	PRESENT	0
198742	198612	04053F	PARTICIPANT	\N	PRESENT	0
198743	198612	14017T	PARTICIPANT	\N	EXCUSE	0
198744	198612	14265W	PARTICIPANT	\N	EXCUSE	0
198753	197512	01027Q	PARTICIPANT	\N	PRESENT	0
198772	198612	14053L	PARTICIPANT	\N	PRESENT	0
198773	198612	11023D	PARTICIPANT	\N	EXCUSE	0
199393	199392	89017R	PARTICIPANT	\N	PRESENT	0
199394	199392	08014Q	PARTICIPANT	\N	PRESENT	0
199395	199392	14085U	PARTICIPANT	\N	PRESENT	0
199396	199392	04086Q	PARTICIPANT	\N	PRESENT	0
199397	199392	01027Q	PARTICIPANT	\N	PRESENT	0
199398	199392	04061F	PARTICIPANT	\N	PRESENT	0
199399	199392	07029T	PARTICIPANT	\N	EXCUSE	0
199400	199392	08010L	PARTICIPANT	\N	PRESENT	0
199401	199392	98046X	PARTICIPANT	\N	PRESENT	0
199402	199392	01016M	PARTICIPANT	\N	PRESENT	0
199403	199392	11057P	PARTICIPANT	\N	PRESENT	0
199404	199392	04034C	PARTICIPANT	\N	PRESENT	0
199405	199392	14159V	PARTICIPANT	\N	PRESENT	0
199406	199392	11088W	PRESIDENT	0	PRESENT	0
199407	199392	96004D	PARTICIPANT	\N	PRESENT	0
199408	199392	14089Y	PARTICIPANT	\N	PRESENT	0
199409	199392	14026U	PARTICIPANT	\N	PRESENT	0
199410	199392	14097Y	PARTICIPANT	\N	PRESENT	0
199411	199392	11026G	PARTICIPANT	\N	PRESENT	0
199412	199392	04057K	PARTICIPANT	\N	PRESENT	0
199413	199392	10015M	PARTICIPANT	\N	PRESENT	0
199414	199392	95063L	PARTICIPANT	\N	PRESENT	0
199415	199392	01031L	PARTICIPANT	\N	EXCUSE	0
199416	199392	11012A	PARTICIPANT	\N	EXCUSE	0
200412	191732	08068F	PARTICIPANT	\N	PRESENT	0
200413	191732	04049K	PRESIDENT	0	PRESENT	0
200414	191732	14151M	PARTICIPANT	\N	PRESENT	0
200415	191732	14083S	PARTICIPANT	\N	PRESENT	0
200416	191732	14041T	PARTICIPANT	\N	PRESENT	0
200417	191732	14157T	PARTICIPANT	\N	PRESENT	0
200418	191732	14205J	PARTICIPANT	\N	PRESENT	0
200419	191732	14039A	PARTICIPANT	\N	PRESENT	0
200420	191732	14030Q	PARTICIPANT	\N	PRESENT	0
200421	191732	14034U	PARTICIPANT	\N	PRESENT	0
200422	191732	04053F	PARTICIPANT	\N	PRESENT	0
200423	191732	04040A	PARTICIPANT	\N	PRESENT	0
200424	191732	05012A	PARTICIPANT	\N	PRESENT	0
200425	191732	04086Q	PARTICIPANT	\N	PRESENT	0
200426	191732	11037K	PARTICIPANT	\N	PRESENT	0
200427	191732	14051J	PARTICIPANT	\N	PRESENT	0
200428	191732	14231L	PARTICIPANT	\N	PRESENT	0
200429	191732	19253P	PARTICIPANT	\N	PRESENT	0
200430	191732	08010L	PARTICIPANT	\N	PRESENT	0
200431	191732	11112D	PARTICIPANT	\N	PRESENT	0
200432	191732	14071N	PARTICIPANT	\N	PRESENT	0
200433	191732	04044E	PARTICIPANT	\N	PRESENT	0
200434	191732	14069U	PARTICIPANT	\N	PRESENT	0
200435	191732	89017R	PARTICIPANT	\N	EXCUSE	0
200436	191732	14065Q	PARTICIPANT	\N	EXCUSE	0
200437	191732	14105F	PARTICIPANT	\N	EXCUSE	0
200438	191732	14207L	PARTICIPANT	\N	EXCUSE	0
200439	191732	14255U	PARTICIPANT	\N	EXCUSE	0
200440	191732	14079W	PARTICIPANT	\N	EXCUSE	0
200441	191732	04055H	PARTICIPANT	\N	EXCUSE	0
200442	191732	11088W	PARTICIPANT	\N	EXCUSE	0
200443	191732	04071H	PARTICIPANT	\N	EXCUSE	0
200444	191732	14087W	PARTICIPANT	\N	EXCUSE	0
200445	191732	14121F	PARTICIPANT	\N	EXCUSE	0
200446	191732	95041E	PARTICIPANT	\N	EXCUSE	0
200447	191732	14061L	PARTICIPANT	\N	EXCUSE	0
200448	191732	14265W	PARTICIPANT	\N	EXCUSE	0
200449	191732	14253S	PARTICIPANT	\N	EXCUSE	0
200450	191732	11090Q	PARTICIPANT	\N	EXCUSE	0
200451	191732	10015M	PARTICIPANT	\N	EXCUSE	0
200452	191732	95067Q	PARTICIPANT	\N	EXCUSE	0
200472	191733	04049K	PRESIDENT	0	PRESENT	0
200473	191733	14151M	PARTICIPANT	\N	PRESENT	0
200474	191733	14034U	PARTICIPANT	\N	PRESENT	0
200475	191733	14083S	PARTICIPANT	\N	PRESENT	0
200476	191733	14157T	PARTICIPANT	\N	PRESENT	0
200477	191733	14205J	PARTICIPANT	\N	PRESENT	0
200478	191733	14030Q	PARTICIPANT	\N	PRESENT	0
200479	191733	04053F	PARTICIPANT	\N	PRESENT	0
200480	191733	14255U	PARTICIPANT	\N	PRESENT	0
200481	191733	89017R	PARTICIPANT	\N	EXCUSE	0
200482	191733	14065Q	PARTICIPANT	\N	EXCUSE	0
200483	191733	14105F	PARTICIPANT	\N	EXCUSE	0
200484	191733	08068F	PARTICIPANT	\N	EXCUSE	0
200485	191733	14207L	PARTICIPANT	\N	EXCUSE	0
200486	191733	14079W	PARTICIPANT	\N	EXCUSE	0
200487	191733	04055H	PARTICIPANT	\N	EXCUSE	0
200488	191733	11088W	PARTICIPANT	\N	EXCUSE	0
200489	191733	14041T	PARTICIPANT	\N	EXCUSE	0
200490	191733	04071H	PARTICIPANT	\N	EXCUSE	0
200491	191733	14087W	PARTICIPANT	\N	EXCUSE	0
200492	191733	14121F	PARTICIPANT	\N	EXCUSE	0
200493	191733	95041E	PARTICIPANT	\N	EXCUSE	0
200494	191733	14039A	PARTICIPANT	\N	EXCUSE	0
200495	191733	14061L	PARTICIPANT	\N	EXCUSE	0
200496	191733	14265W	PARTICIPANT	\N	EXCUSE	0
200497	191733	14253S	PARTICIPANT	\N	EXCUSE	0
200498	191733	11090Q	PARTICIPANT	\N	EXCUSE	0
200499	191733	10015M	PARTICIPANT	\N	EXCUSE	0
200512	191733	95067Q	PARTICIPANT	\N	EXCUSE	0
200533	200532	07034Q	PARTICIPANT	\N	PRESENT	0
200573	200572	01043Q	PARTICIPANT	\N	PRESENT	0
200574	200572	14081Q	PARTICIPANT	\N	PRESENT	0
200576	200575	08042U	PARTICIPANT	\N	PRESENT	0
200577	200575	08009T	PARTICIPANT	\N	PRESENT	0
200952	190796	11085T	PARTICIPANT	\N	PRESENT	0
200953	200613	14239U	PARTICIPANT	\N	PRESENT	0
200954	200613	11023D	PARTICIPANT	\N	PRESENT	0
200955	200613	04092N	PARTICIPANT	\N	PRESENT	0
200956	200613	14355X	PARTICIPANT	\N	PRESENT	0
200957	200613	11103C	PARTICIPANT	\N	PRESENT	0
200958	200613	08052W	PARTICIPANT	\N	PRESENT	0
200959	200613	12042Y	PARTICIPANT	\N	PRESENT	0
200960	200613	14071N	PARTICIPANT	\N	PRESENT	0
200961	200613	98024R	PRESIDENT	0	PRESENT	0
200962	200613	04053F	PARTICIPANT	\N	PRESENT	0
200963	200613	14017T	PARTICIPANT	\N	EXCUSE	0
200964	200613	00003C	PARTICIPANT	\N	EXCUSE	0
200972	200613	11061K	PARTICIPANT	\N	PRESENT	0
200973	200613	11097X	PARTICIPANT	\N	PRESENT	0
200974	200613	04045F	PARTICIPANT	\N	PRESENT	0
200975	200613	14227Q	PARTICIPANT	\N	PRESENT	0
200976	200613	14269B	PARTICIPANT	\N	PRESENT	0
200977	200613	11031D	PARTICIPANT	\N	PRESENT	0
200978	200613	14281W	PARTICIPANT	\N	PRESENT	0
200979	200613	14087W	PARTICIPANT	\N	PRESENT	0
200980	200613	14271U	PARTICIPANT	\N	PRESENT	0
200981	200613	14195A	PARTICIPANT	\N	PRESENT	0
200982	200613	14151M	PARTICIPANT	\N	PRESENT	0
200983	200613	14213J	PARTICIPANT	\N	PRESENT	0
200984	200613	14217N	PARTICIPANT	\N	PRESENT	0
200985	200613	10006L	PARTICIPANT	\N	PRESENT	0
200986	200613	14265W	PARTICIPANT	\N	PRESENT	0
200987	200613	14053L	PARTICIPANT	\N	PRESENT	0
200988	200613	14034U	PARTICIPANT	\N	PRESENT	0
200989	200613	14255U	PARTICIPANT	\N	PRESENT	0
200990	200613	14119M	PARTICIPANT	\N	PRESENT	0
200991	200613	14121F	PARTICIPANT	\N	PRESENT	0
200992	200613	04081K	PARTICIPANT	\N	PRESENT	0
200993	190796	80027E	PARTICIPANT	\N	PRESENT	0
171592	171196	14281W	PARTICIPANT	\N	PRESENT	0
171593	171196	14119M	PARTICIPANT	\N	PRESENT	0
171594	171196	14227Q	PARTICIPANT	\N	PRESENT	0
179033	179032	14133K	PARTICIPANT	\N	PRESENT	0
179034	179032	96004D	PRESIDENT	0	PRESENT	0
179035	179032	04040A	PARTICIPANT	\N	PRESENT	0
179036	179032	11040E	PARTICIPANT	\N	PRESENT	0
179037	179032	04042C	PRESIDENT	1	PRESENT	0
179038	179032	04035D	PARTICIPANT	\N	PRESENT	0
179039	179032	11083R	PARTICIPANT	\N	PRESENT	0
179040	179032	14014Q	PARTICIPANT	\N	PRESENT	0
179041	179032	98022P	PARTICIPANT	\N	PRESENT	0
179042	179032	14097Y	PARTICIPANT	\N	PRESENT	0
179043	179032	04061F	PARTICIPANT	\N	PRESENT	0
179044	179032	14001X	PARTICIPANT	\N	PRESENT	0
179045	179032	83042R	PARTICIPANT	\N	PRESENT	0
179046	179032	04057K	PARTICIPANT	\N	EXCUSE	0
179047	179032	95059Q	PARTICIPANT	\N	EXCUSE	0
179048	179032	98035U	PARTICIPANT	\N	PRESENT	0
181104	167352	14105F	PARTICIPANT	\N	PRESENT	0
181112	167352	14111D	PARTICIPANT	\N	PRESENT	0
181113	167352	95062K	PARTICIPANT	\N	PRESENT	0
181114	167352	14223L	PARTICIPANT	\N	PRESENT	0
181115	167352	04088S	PARTICIPANT	\N	PRESENT	0
181116	167352	04036E	PARTICIPANT	\N	PRESENT	0
181117	167352	14157T	PARTICIPANT	\N	PRESENT	0
181118	167352	14026U	PARTICIPANT	\N	PRESENT	0
181119	167352	11080N	PARTICIPANT	\N	PRESENT	0
181120	167352	14041T	PARTICIPANT	\N	PRESENT	0
181121	167352	14061L	PARTICIPANT	\N	PRESENT	0
181122	167352	04092N	PARTICIPANT	\N	PRESENT	0
181124	167352	87003B	PARTICIPANT	\N	PRESENT	0
181125	167352	04097T	PARTICIPANT	\N	PRESENT	0
181126	167352	04049K	PARTICIPANT	\N	PRESENT	0
181127	167352	08065C	PARTICIPANT	\N	PRESENT	0
181128	167352	14357A	PARTICIPANT	\N	PRESENT	0
181131	167352	05008E	PARTICIPANT	\N	PRESENT	0
181134	167352	98023Q	PARTICIPANT	\N	PRESENT	0
181136	167352	14042U	PARTICIPANT	\N	PRESENT	0
181139	167352	98024R	PARTICIPANT	\N	PRESENT	0
181142	167352	14187A	PARTICIPANT	\N	PRESENT	0
181143	167352	77002U	PARTICIPANT	\N	PRESENT	0
181144	167352	97011G	PARTICIPANT	\N	PRESENT	0
181145	167352	14147R	PARTICIPANT	\N	PRESENT	0
181146	167352	14030Q	PARTICIPANT	\N	PRESENT	0
181147	167352	11090Q	PARTICIPANT	\N	PRESENT	0
181148	167352	01027Q	PARTICIPANT	\N	PRESENT	0
181149	167352	11097X	PARTICIPANT	\N	PRESENT	0
181150	167352	11091R	PARTICIPANT	\N	PRESENT	0
181151	167352	08015R	PARTICIPANT	\N	PRESENT	0
181152	167352	14059S	PARTICIPANT	\N	PRESENT	0
181153	167352	95059Q	PARTICIPANT	\N	PRESENT	0
181154	167352	14037X	PARTICIPANT	\N	PRESENT	0
181172	167352	14173T	PARTICIPANT	\N	PRESENT	0
181192	167352	14119M	PARTICIPANT	\N	PRESENT	0
181213	167352	14199E	PARTICIPANT	\N	PRESENT	0
181214	167352	01058X	PARTICIPANT	\N	PRESENT	0
181216	167352	14251Q	PARTICIPANT	\N	PRESENT	0
181217	167352	11100Y	PARTICIPANT	\N	PRESENT	0
181218	167352	14259Y	PARTICIPANT	\N	PRESENT	0
181219	167352	11044J	PARTICIPANT	\N	PRESENT	0
181220	167352	04041B	PARTICIPANT	\N	PRESENT	0
181221	167352	11048N	PARTICIPANT	\N	PRESENT	0
181222	167352	14193X	PARTICIPANT	\N	PRESENT	0
181223	167352	08034U	PARTICIPANT	\N	PRESENT	0
181224	167352	92031P	PARTICIPANT	\N	PRESENT	0
181225	167352	01057W	PARTICIPANT	\N	PRESENT	0
181226	167352	14265W	PARTICIPANT	\N	PRESENT	0
181227	167352	95035G	PARTICIPANT	\N	PRESENT	0
181228	167352	95015C	PARTICIPANT	\N	PRESENT	0
181229	167352	99004R	PARTICIPANT	\N	PRESENT	0
181230	167352	04081K	PARTICIPANT	\N	PRESENT	0
181231	167352	14079W	PARTICIPANT	\N	PRESENT	0
181232	167352	04086Q	PARTICIPANT	\N	PRESENT	0
181233	167352	14331P	PARTICIPANT	\N	PRESENT	0
181234	176295	14327T	PARTICIPANT	\N	PRESENT	0
181235	176295	07029T	PARTICIPANT	\N	PRESENT	0
181236	176295	14083S	PARTICIPANT	\N	PRESENT	0
181237	176295	14085U	PARTICIPANT	\N	PRESENT	0
181238	176295	08069G	PARTICIPANT	\N	PRESENT	0
181239	176295	08014Q	PARTICIPANT	\N	PRESENT	0
181240	176295	08022Q	PRESIDENT	0	PRESENT	0
181241	176295	01013J	PARTICIPANT	\N	PRESENT	0
181242	176295	04086Q	PARTICIPANT	\N	PRESENT	0
181243	176295	11048N	PARTICIPANT	\N	PRESENT	0
181244	176295	08034U	PARTICIPANT	\N	PRESENT	0
181245	176295	01057W	PARTICIPANT	\N	PRESENT	0
181246	176295	98046X	PARTICIPANT	\N	PRESENT	0
181247	176295	01016M	PARTICIPANT	\N	PRESENT	0
181248	176295	11053K	PARTICIPANT	\N	PRESENT	0
181249	176295	11083R	PARTICIPANT	\N	PRESENT	0
181250	176295	14173T	PARTICIPANT	\N	PRESENT	0
181251	176295	01031L	PARTICIPANT	\N	EXCUSE	0
181252	176295	11012A	PARTICIPANT	\N	EXCUSE	0
181253	176295	08011M	PARTICIPANT	\N	EXCUSE	0
181254	176295	11085T	PARTICIPANT	\N	EXCUSE	0
181255	167352	11101A	PARTICIPANT	\N	PRESENT	0
181256	167352	01059Y	PARTICIPANT	\N	PRESENT	0
181257	167352	07026Q	PARTICIPANT	\N	PRESENT	0
181258	167352	11034G	PARTICIPANT	\N	PRESENT	0
181259	167352	08039A	PARTICIPANT	\N	PRESENT	0
181260	167352	08047A	PARTICIPANT	\N	PRESENT	0
181261	167352	10006L	PARTICIPANT	\N	PRESENT	0
181262	167352	08022Q	PARTICIPANT	\N	PRESENT	0
181263	167352	14069U	PARTICIPANT	\N	PRESENT	0
181264	167352	14195A	PARTICIPANT	\N	PRESENT	0
181265	167352	14031R	PARTICIPANT	\N	PRESENT	0
181266	167352	14355X	PARTICIPANT	\N	PRESENT	0
181267	167352	08018U	PARTICIPANT	\N	PRESENT	0
181268	167352	01008M	PARTICIPANT	\N	PRESENT	0
181269	167352	98053W	PARTICIPANT	\N	PRESENT	0
181270	167352	04042C	PARTICIPANT	\N	PRESENT	0
181271	167352	04085P	PARTICIPANT	\N	PRESENT	0
181272	167352	92018S	PARTICIPANT	\N	PRESENT	0
181273	167352	11071M	PARTICIPANT	\N	PRESENT	0
181274	167352	01013J	PARTICIPANT	\N	PRESENT	0
181275	167352	07029T	PARTICIPANT	\N	PRESENT	0
181276	167352	05012A	PARTICIPANT	\N	PRESENT	0
181277	167352	04033B	PARTICIPANT	\N	PRESENT	0
181278	167352	12041X	PARTICIPANT	\N	PRESENT	0
181279	167352	11040E	PARTICIPANT	\N	PRESENT	0
181280	167352	11063M	PARTICIPANT	\N	PRESENT	0
181281	167352	10015M	PARTICIPANT	\N	PRESENT	0
181282	167352	04054G	PARTICIPANT	\N	PRESENT	0
181283	167352	14013P	PARTICIPANT	\N	PRESENT	0
181284	167352	14235Q	PARTICIPANT	\N	PRESENT	0
181285	167352	11049P	PARTICIPANT	\N	PRESENT	0
181286	167352	14361V	PARTICIPANT	\N	PRESENT	0
181287	167352	14175V	PARTICIPANT	\N	PRESENT	0
181288	167352	05001W	PARTICIPANT	\N	PRESENT	0
181289	167352	04074L	PARTICIPANT	\N	PRESENT	0
181290	167352	14038Y	PARTICIPANT	\N	PRESENT	0
181291	167352	14329V	PARTICIPANT	\N	PRESENT	0
181292	167352	11031D	PARTICIPANT	\N	PRESENT	0
181293	167352	11098Y	PARTICIPANT	\N	PRESENT	0
181294	167352	04050C	PARTICIPANT	\N	PRESENT	0
181295	167352	08042U	PARTICIPANT	\N	PRESENT	0
181296	167352	14363X	PARTICIPANT	\N	PRESENT	0
181297	167352	11076S	PARTICIPANT	\N	PRESENT	0
181298	167352	04057K	PARTICIPANT	\N	PRESENT	0
181299	167352	01041N	PARTICIPANT	\N	PRESENT	0
181300	167352	11033F	PARTICIPANT	\N	PRESENT	0
181301	167352	01044R	PARTICIPANT	\N	PRESENT	0
181302	167352	11029K	PARTICIPANT	\N	PRESENT	0
181303	167352	04067M	PARTICIPANT	\N	PRESENT	0
181304	167352	11083R	PARTICIPANT	\N	PRESENT	0
181305	167352	11099A	PARTICIPANT	\N	PRESENT	0
181306	167352	13002U	PARTICIPANT	\N	PRESENT	0
181307	167352	04055H	PARTICIPANT	\N	PRESENT	0
181308	167352	14055N	PARTICIPANT	\N	PRESENT	0
181309	167352	08069G	PARTICIPANT	\N	PRESENT	0
181310	167352	92045V	PARTICIPANT	\N	PRESENT	0
181311	167352	04035D	PARTICIPANT	\N	PRESENT	0
181312	167352	14053L	PARTICIPANT	\N	PRESENT	0
181313	167352	08051V	PARTICIPANT	\N	PRESENT	0
181314	167352	14093U	PARTICIPANT	\N	PRESENT	0
181315	167352	01046T	PARTICIPANT	\N	PRESENT	0
181316	167352	88008L	PARTICIPANT	\N	PRESENT	0
181317	167352	04078Q	PARTICIPANT	\N	PRESENT	0
181318	167352	11012A	PARTICIPANT	\N	PRESENT	0
181319	167352	14018U	PARTICIPANT	\N	PRESENT	0
181320	167352	11081P	PARTICIPANT	\N	PRESENT	0
181321	167352	14201E	PARTICIPANT	\N	PRESENT	0
181322	167352	14033T	PARTICIPANT	\N	PRESENT	0
181323	167352	08021P	PARTICIPANT	\N	PRESENT	0
181324	167352	98022P	PARTICIPANT	\N	PRESENT	0
181325	167352	14237S	PARTICIPANT	\N	PRESENT	0
181326	167352	01016M	PARTICIPANT	\N	PRESENT	0
207351	206494	19673G	PARTICIPANT	\N	PRESENT	0
207352	206494	01028R	PARTICIPANT	\N	PRESENT	0
207353	206494	19447X	PARTICIPANT	\N	PRESENT	0
207354	206494	05008E	PRESIDENT	0	PRESENT	0
207355	206494	14041T	PARTICIPANT	\N	PRESENT	0
207356	206494	14147R	PARTICIPANT	\N	PRESENT	0
207357	206494	14179A	PARTICIPANT	\N	PRESENT	0
207358	206494	14151M	PARTICIPANT	\N	PRESENT	0
207359	206494	14215L	PARTICIPANT	\N	PRESENT	0
207360	206494	08018U	PARTICIPANT	\N	PRESENT	0
207361	206494	19483C	PARTICIPANT	\N	PRESENT	0
207362	206494	14259Y	PARTICIPANT	\N	PRESENT	0
207363	206494	98035U	PARTICIPANT	\N	PRESENT	0
207364	206494	14053L	PARTICIPANT	\N	PRESENT	0
207365	206494	14111D	PARTICIPANT	\N	PRESENT	0
207366	206494	19649G	PARTICIPANT	\N	PRESENT	0
207367	206494	14065Q	PARTICIPANT	\N	PRESENT	0
207368	206494	11010L	PARTICIPANT	\N	PRESENT	0
207369	206494	07034Q	PARTICIPANT	\N	PRESENT	0
207370	206494	11026G	PARTICIPANT	\N	PRESENT	0
207371	206494	08045X	PARTICIPANT	\N	PRESENT	0
207372	206494	10015M	PARTICIPANT	\N	PRESENT	0
207373	206494	19253P	PARTICIPANT	\N	PRESENT	0
207374	206494	01024M	PARTICIPANT	\N	PRESENT	0
207375	206494	04038G	PARTICIPANT	\N	PRESENT	0
207376	206494	19719D	PARTICIPANT	\N	PRESENT	0
207377	206494	11033F	PARTICIPANT	\N	PRESENT	0
207378	206494	14089Y	PARTICIPANT	\N	PRESENT	0
207379	206494	19725B	PARTICIPANT	\N	PRESENT	0
207380	206494	19729F	PARTICIPANT	\N	PRESENT	0
207381	206494	19629C	PARTICIPANT	\N	PRESENT	0
207382	206494	08044W	PARTICIPANT	\N	PRESENT	0
207383	206494	14069U	PARTICIPANT	\N	PRESENT	0
207384	206494	11049P	PARTICIPANT	\N	PRESENT	0
207385	206494	04008A	PARTICIPANT	\N	PRESENT	0
207386	206494	14021P	PARTICIPANT	\N	PRESENT	0
207387	206494	19489J	PARTICIPANT	\N	EXCUSE	0
207388	206494	11085T	PARTICIPANT	\N	EXCUSE	0
207390	207389	14105F	PARTICIPANT	\N	PRESENT	0
207391	207389	19709B	PARTICIPANT	\N	PRESENT	0
207392	207389	14065Q	PARTICIPANT	\N	PRESENT	0
207393	207389	04040A	PARTICIPANT	\N	PRESENT	0
207394	207389	14079W	PARTICIPANT	\N	PRESENT	0
207395	207389	08052W	PARTICIPANT	\N	PRESENT	0
207396	207389	14033T	PARTICIPANT	\N	PRESENT	0
207397	207389	14081Q	PARTICIPANT	\N	PRESENT	0
207398	207389	14061L	PARTICIPANT	\N	PRESENT	0
207399	207389	14073Q	PARTICIPANT	\N	PRESENT	0
207400	207389	08010L	PARTICIPANT	\N	PRESENT	0
207401	207389	92040Q	PARTICIPANT	\N	PRESENT	0
207402	207389	95062K	PARTICIPANT	\N	PRESENT	0
207403	207389	04045F	PARTICIPANT	\N	PRESENT	0
207404	207389	04044E	PARTICIPANT	\N	PRESENT	0
207405	207389	95067Q	PARTICIPANT	\N	PRESENT	0
207406	207291	04070G	PRESIDENT	0	PRESENT	0
207407	207291	19699S	PARTICIPANT	\N	PRESENT	0
207408	207291	19533U	PARTICIPANT	\N	PRESENT	0
207409	207291	95015C	PARTICIPANT	\N	PRESENT	0
207410	207291	14229S	PARTICIPANT	\N	PRESENT	0
207411	207291	14241N	PARTICIPANT	\N	PRESENT	0
207412	207291	19573D	PARTICIPANT	\N	PRESENT	0
207413	207291	14107H	PARTICIPANT	\N	PRESENT	0
207414	207291	08017T	PARTICIPANT	\N	PRESENT	0
207415	207291	07033P	PARTICIPANT	\N	PRESENT	0
207416	207291	08012N	PARTICIPANT	\N	PRESENT	0
207417	207291	08016S	PARTICIPANT	\N	PRESENT	0
207418	207291	08039A	PARTICIPANT	\N	PRESENT	0
207419	207291	08031R	PARTICIPANT	\N	PRESENT	0
207420	207291	19593H	PARTICIPANT	\N	PRESENT	0
207421	207291	14059S	PARTICIPANT	\N	PRESENT	0
207422	207291	19643A	PARTICIPANT	\N	PRESENT	0
207423	207291	14061L	PARTICIPANT	\N	PRESENT	0
207424	207291	04057K	PARTICIPANT	\N	PRESENT	0
207425	207291	19693L	PARTICIPANT	\N	PRESENT	0
207426	207291	87003B	PARTICIPANT	\N	PRESENT	0
207427	207291	19399H	PARTICIPANT	\N	PRESENT	0
207428	207291	14201E	PARTICIPANT	\N	PRESENT	0
207429	207291	14030Q	PARTICIPANT	\N	PRESENT	0
207430	207291	19731Y	PARTICIPANT	\N	PRESENT	0
207431	207291	08020N	PARTICIPANT	\N	PRESENT	0
207432	207291	14251Q	PARTICIPANT	\N	PRESENT	0
207433	207291	19735D	PARTICIPANT	\N	PRESENT	0
207434	207291	11083R	PARTICIPANT	\N	PRESENT	0
207435	207291	14109K	PARTICIPANT	\N	PRESENT	0
207436	207291	14123H	PARTICIPANT	\N	PRESENT	0
207437	207291	11104D	PARTICIPANT	\N	PRESENT	0
207438	207291	11043H	PARTICIPANT	\N	PRESENT	0
207439	207291	04018C	PARTICIPANT	\N	PRESENT	0
207440	207291	19621T	PARTICIPANT	\N	PRESENT	0
207441	207291	14039A	PARTICIPANT	\N	EXCUSE	0
207442	207291	08043V	PARTICIPANT	\N	EXCUSE	0
207443	207291	14249W	PARTICIPANT	\N	EXCUSE	0
207444	207291	14073Q	PARTICIPANT	\N	PRESENT	0
207445	207291	04059M	PARTICIPANT	\N	PRESENT	0
207446	206477	97011G	PARTICIPANT	\N	EXCUSE	0
207447	206477	19319Q	PARTICIPANT	\N	EXCUSE	0
207448	206477	08049C	PARTICIPANT	\N	EXCUSE	0
207450	207449	14239U	PARTICIPANT	\N	PRESENT	0
207451	207449	14261S	PARTICIPANT	\N	PRESENT	0
207452	207449	19717B	PARTICIPANT	\N	PRESENT	0
207453	207449	19575F	PARTICIPANT	\N	PRESENT	0
207454	207449	19367Y	PARTICIPANT	\N	PRESENT	0
207455	207449	19415P	PARTICIPANT	\N	PRESENT	0
207456	207449	11103C	PARTICIPANT	\N	PRESENT	0
207457	207449	14195A	PARTICIPANT	\N	PRESENT	0
207459	207449	08052W	PARTICIPANT	\N	PRESENT	0
207460	207449	19663E	PARTICIPANT	\N	PRESENT	0
207461	207449	98024R	PARTICIPANT	\N	PRESENT	0
207462	207449	10006L	PARTICIPANT	\N	PRESENT	0
207463	207449	14217N	PARTICIPANT	\N	PRESENT	0
207464	207449	19577H	PARTICIPANT	\N	PRESENT	0
207465	207449	14042U	PARTICIPANT	\N	PRESENT	0
207466	207449	14281W	PARTICIPANT	\N	PRESENT	0
207467	207449	14087W	PARTICIPANT	\N	PRESENT	0
207468	207449	19521Q	PARTICIPANT	\N	PRESENT	0
207469	207449	14355X	PARTICIPANT	\N	PRESENT	0
207470	207449	08048B	PARTICIPANT	\N	PRESENT	0
207471	207449	08041T	PARTICIPANT	\N	PRESENT	0
207472	207449	19727D	PARTICIPANT	\N	PRESENT	0
207473	207449	14026U	PARTICIPANT	\N	PRESENT	0
207474	207449	19691J	PARTICIPANT	\N	PRESENT	0
207475	207449	19553Y	PARTICIPANT	\N	PRESENT	0
207476	207449	19569H	PARTICIPANT	\N	PRESENT	0
207477	207449	14213J	PARTICIPANT	\N	PRESENT	0
207478	207449	19715Y	PARTICIPANT	\N	EXCUSE	0
207479	207449	19683J	PARTICIPANT	\N	PRESENT	0
207480	207449	19723Y	PARTICIPANT	\N	PRESENT	0
207481	207449	19697Q	PARTICIPANT	\N	PRESENT	0
207482	207449	11077T	PARTICIPANT	\N	PRESENT	0
207483	207449	17779H	PARTICIPANT	\N	PRESENT	0
207484	207449	19657G	PARTICIPANT	\N	PRESENT	0
207485	207449	11067R	PARTICIPANT	\N	PRESENT	0
207486	207449	14223L	PARTICIPANT	\N	PRESENT	0
207487	207449	04092N	PRESIDENT	0	PRESENT	0
207488	207449	19335Q	PARTICIPANT	\N	PRESENT	0
207489	207449	14119M	PARTICIPANT	\N	PRESENT	0
207490	207449	14071N	PARTICIPANT	\N	PRESENT	0
207491	207449	19679N	PARTICIPANT	\N	PRESENT	0
207492	207449	11045K	PARTICIPANT	\N	PRESENT	0
207493	207449	11097X	PARTICIPANT	\N	PRESENT	0
207494	207449	04045F	PARTICIPANT	\N	PRESENT	0
207495	207449	19703U	PARTICIPANT	\N	PRESENT	0
207497	207449	14227Q	PARTICIPANT	\N	PRESENT	0
207498	207449	19527W	PARTICIPANT	\N	PRESENT	0
207499	207449	01034P	PARTICIPANT	\N	PRESENT	0
207500	207449	11063M	PARTICIPANT	\N	PRESENT	0
170032	167015	98053W	PARTICIPANT	\N	PRESENT	0
169114	169112	14133K	PARTICIPANT	\N	PRESENT	0
170108	167015	11031D	PARTICIPANT	\N	PRESENT	0
169116	169112	04040A	PARTICIPANT	\N	PRESENT	0
169117	169112	08058D	PARTICIPANT	\N	PRESENT	0
170110	167015	95063L	PARTICIPANT	\N	PRESENT	0
170111	167015	11027H	PARTICIPANT	\N	PRESENT	0
169120	169112	98029W	PARTICIPANT	\N	PRESENT	0
170112	167015	14269B	PARTICIPANT	\N	PRESENT	0
169122	169112	11027H	PARTICIPANT	\N	PRESENT	0
169123	169112	98018T	PARTICIPANT	\N	PRESENT	0
170113	167015	11067R	PARTICIPANT	\N	PRESENT	0
169125	169112	92020L	PARTICIPANT	\N	PRESENT	0
169126	169112	95030B	PARTICIPANT	\N	PRESENT	0
170114	167015	11033F	PARTICIPANT	\N	PRESENT	0
170115	167015	11029K	PARTICIPANT	\N	PRESENT	0
169129	169112	97011G	PARTICIPANT	\N	PRESENT	0
170116	167015	01044R	PARTICIPANT	\N	PRESENT	0
169131	169112	04035D	PARTICIPANT	\N	PRESENT	0
170117	167015	14241N	PARTICIPANT	\N	PRESENT	0
169133	169112	14014Q	PARTICIPANT	\N	PRESENT	0
170118	167015	09001P	PARTICIPANT	\N	PRESENT	0
170119	167015	14089Y	PARTICIPANT	\N	PRESENT	0
169136	169112	95035G	PRESIDENT	1	PRESENT	0
170120	167015	14073Q	PARTICIPANT	\N	PRESENT	0
170121	167015	14249W	PARTICIPANT	\N	PRESENT	0
170122	167015	14265W	PARTICIPANT	\N	PRESENT	0
169140	169112	11064N	PARTICIPANT	\N	PRESENT	0
169141	169112	95037J	PARTICIPANT	\N	PRESENT	0
169142	169112	04078Q	PARTICIPANT	\N	PRESENT	0
169143	169112	14097Y	PARTICIPANT	\N	PRESENT	0
169144	169112	95041E	PARTICIPANT	\N	PRESENT	0
169145	169112	04036E	PARTICIPANT	\N	PRESENT	0
169146	169112	14039A	PARTICIPANT	\N	PRESENT	0
170123	167015	04057K	PARTICIPANT	\N	PRESENT	0
170124	167015	07026Q	PARTICIPANT	\N	PRESENT	0
169149	169112	92031P	PARTICIPANT	\N	PRESENT	0
169150	169112	11106F	PARTICIPANT	\N	PRESENT	0
169151	169112	14251Q	PARTICIPANT	\N	PRESENT	0
169152	169112	83042R	PARTICIPANT	\N	PRESENT	0
169153	169112	08053X	PARTICIPANT	\N	PRESENT	0
169154	169112	11082Q	PARTICIPANT	\N	EXCUSE	0
169155	169112	11105E	PARTICIPANT	\N	PRESENT	0
170125	167015	11089X	PARTICIPANT	\N	PRESENT	0
169157	169112	08047A	PARTICIPANT	\N	PRESENT	0
169158	169112	14028W	PARTICIPANT	\N	PRESENT	0
169159	169112	14193X	PARTICIPANT	\N	PRESENT	0
169160	169112	98021N	PARTICIPANT	\N	EXCUSE	0
170132	167015	11036J	PARTICIPANT	\N	PRESENT	0
169162	169112	95059Q	PRESIDENT	0	PRESENT	0
169163	169112	86044G	PARTICIPANT	\N	PRESENT	0
169164	169112	01014K	PARTICIPANT	\N	PRESENT	0
169165	169112	11054L	PARTICIPANT	\N	PRESENT	0
169166	169112	01056V	PARTICIPANT	\N	PRESENT	0
169167	169112	92044U	PARTICIPANT	\N	PRESENT	0
169168	169112	08049C	PARTICIPANT	\N	PRESENT	0
170133	167015	14329V	PARTICIPANT	\N	PRESENT	0
170134	167015	14133K	PARTICIPANT	\N	PRESENT	0
170135	167015	04053F	PARTICIPANT	\N	PRESENT	0
170136	167015	01046T	PARTICIPANT	\N	PRESENT	0
170192	167015	14357A	PARTICIPANT	\N	PRESENT	0
170193	167015	14041T	PARTICIPANT	\N	PRESENT	0
170194	167015	14159V	PARTICIPANT	\N	PRESENT	0
170195	167015	01031L	PARTICIPANT	\N	PRESENT	0
170196	167015	11084S	PARTICIPANT	\N	PRESENT	0
170212	167015	11083R	PARTICIPANT	\N	PRESENT	0
170232	167015	14231L	PARTICIPANT	\N	PRESENT	0
182094	182072	14038Y	PARTICIPANT	\N	PRESENT	0
182095	182072	87003B	PARTICIPANT	\N	PRESENT	0
182112	182072	01025N	PARTICIPANT	\N	PRESENT	0
182113	182072	95037J	PARTICIPANT	\N	PRESENT	0
182114	182072	14061L	PARTICIPANT	\N	PRESENT	0
182115	182072	04049K	PARTICIPANT	\N	PRESENT	0
182116	182072	08015R	PARTICIPANT	\N	PRESENT	0
182133	182132	01008M	PARTICIPANT	\N	PRESENT	0
182134	182132	14195A	PARTICIPANT	\N	PRESENT	0
182135	182132	14209N	PARTICIPANT	\N	PRESENT	0
182136	182132	14197C	PARTICIPANT	\N	PRESENT	0
182137	182132	11111C	PARTICIPANT	\N	PRESENT	0
182138	182132	14063N	PARTICIPANT	\N	PRESENT	0
182139	182132	11043H	PARTICIPANT	\N	PRESENT	0
182313	182312	14239U	PARTICIPANT	\N	PRESENT	0
182314	182312	11031D	PARTICIPANT	\N	PRESENT	0
182315	182312	08052W	PRESIDENT	0	PRESENT	0
182316	182312	14271U	PARTICIPANT	\N	PRESENT	0
182317	182312	11055M	PARTICIPANT	\N	EXCUSE	0
182318	182312	87003B	PARTICIPANT	\N	EXCUSE	0
182319	182312	14265W	PARTICIPANT	\N	EXCUSE	0
182320	182312	11094U	PARTICIPANT	\N	EXCUSE	0
182321	182312	14331P	PARTICIPANT	\N	EXCUSE	0
182322	182312	14195A	PARTICIPANT	\N	EXCUSE	0
182323	182312	14235Q	PARTICIPANT	\N	EXCUSE	0
182324	182312	04092N	PARTICIPANT	\N	EXCUSE	0
183613	183612	08053X	PARTICIPANT	\N	PRESENT	0
183614	183612	08010L	PARTICIPANT	\N	PRESENT	0
183633	183632	14193X	PARTICIPANT	\N	PRESENT	0
183634	183632	08049C	PARTICIPANT	\N	PRESENT	0
183661	183660	11042G	PARTICIPANT	\N	PRESENT	0
183662	183660	04086Q	PARTICIPANT	\N	PRESENT	0
183663	183660	14159V	PARTICIPANT	\N	PRESENT	0
183665	183664	04086Q	PARTICIPANT	\N	PRESENT	0
183666	183664	11042G	PARTICIPANT	\N	PRESENT	0
183667	183664	14159V	PARTICIPANT	\N	PRESENT	0
183669	183668	04086Q	PARTICIPANT	\N	PRESENT	0
183670	183668	11042G	PARTICIPANT	\N	PRESENT	0
183671	183668	14159V	PARTICIPANT	\N	PRESENT	0
183672	183668	14175V	PARTICIPANT	\N	PRESENT	0
183674	183673	04086Q	PARTICIPANT	\N	PRESENT	0
183675	183673	11042G	PARTICIPANT	\N	PRESENT	0
183676	183673	14159V	PARTICIPANT	\N	PRESENT	0
183677	183673	14175V	PARTICIPANT	\N	PRESENT	0
183713	183712	08069G	PARTICIPANT	\N	PRESENT	0
183714	183712	08014Q	PARTICIPANT	\N	PRESENT	0
183893	183892	95059Q	PARTICIPANT	\N	PRESENT	0
183894	183892	01014K	PARTICIPANT	\N	PRESENT	0
183913	183912	11103C	PARTICIPANT	\N	PRESENT	0
183914	183912	08052W	PARTICIPANT	\N	PRESENT	0
183916	183915	11103C	PARTICIPANT	\N	PRESENT	0
183917	183915	08052W	PARTICIPANT	\N	PRESENT	0
183919	183918	14037X	PARTICIPANT	\N	PRESENT	0
184242	184238	08034U	PARTICIPANT	\N	PRESENT	0
184244	184238	14281W	PARTICIPANT	\N	PRESENT	0
184257	184248	08034U	PARTICIPANT	\N	PRESENT	0
184258	184248	14281W	PARTICIPANT	\N	PRESENT	0
184273	184272	08034U	PARTICIPANT	\N	PRESENT	0
184274	184272	14281W	PARTICIPANT	\N	PRESENT	0
184294	184293	14133K	PARTICIPANT	\N	PRESENT	0
184295	184293	14265W	PARTICIPANT	\N	PRESENT	0
184297	184296	14133K	PARTICIPANT	\N	PRESENT	0
185293	185292	14193X	PARTICIPANT	\N	PRESENT	0
185294	185292	11054L	PARTICIPANT	\N	PRESENT	0
185295	185292	04040A	PARTICIPANT	\N	PRESENT	0
185753	185752	01014K	PARTICIPANT	\N	PRESENT	0
185754	185752	95059Q	PARTICIPANT	\N	PRESENT	0
185756	185755	95059Q	PARTICIPANT	\N	PRESENT	0
186373	186372	14093U	PARTICIPANT	\N	PRESENT	0
186374	186372	14030Q	PARTICIPANT	\N	EXCUSE	0
186375	186372	96004D	PARTICIPANT	\N	EXCUSE	0
186376	186372	11095V	PARTICIPANT	\N	EXCUSE	0
186377	186372	14038Y	PARTICIPANT	\N	EXCUSE	0
186378	186372	01015L	PARTICIPANT	\N	EXCUSE	0
186379	186372	11107G	PARTICIPANT	\N	PRESENT	0
186380	186372	01022K	PARTICIPANT	\N	PRESENT	0
186381	186372	05001W	PARTICIPANT	\N	EXCUSE	0
186382	186372	04097T	PARTICIPANT	\N	EXCUSE	0
186383	186372	11059R	PARTICIPANT	\N	EXCUSE	0
186384	186372	80027E	PARTICIPANT	\N	EXCUSE	0
186385	186372	14031R	PARTICIPANT	\N	EXCUSE	0
186386	186372	08009T	PRESIDENT	0	PRESENT	0
186387	186372	08062Y	PARTICIPANT	\N	EXCUSE	0
186388	186372	14221J	PARTICIPANT	\N	EXCUSE	0
186389	186372	08042U	PARTICIPANT	\N	EXCUSE	0
186390	186372	14169X	PARTICIPANT	\N	PRESENT	0
186391	186372	05012A	PARTICIPANT	\N	PRESENT	0
186392	186372	14135M	PARTICIPANT	\N	PRESENT	0
186393	186372	14331P	PARTICIPANT	\N	EXCUSE	0
186394	186372	95062K	PARTICIPANT	\N	EXCUSE	0
186395	186372	14107H	PARTICIPANT	\N	EXCUSE	0
186396	186372	14051J	PARTICIPANT	\N	EXCUSE	0
186398	186397	14093U	PARTICIPANT	\N	PRESENT	0
186399	186397	14030Q	PARTICIPANT	\N	EXCUSE	0
186400	186397	96004D	PARTICIPANT	\N	EXCUSE	0
186401	186397	11095V	PARTICIPANT	\N	EXCUSE	0
186402	186397	14038Y	PARTICIPANT	\N	EXCUSE	0
186403	186397	01015L	PARTICIPANT	\N	EXCUSE	0
186404	186397	11107G	PARTICIPANT	\N	EXCUSE	0
186405	186397	05001W	PARTICIPANT	\N	EXCUSE	0
186406	186397	04097T	PARTICIPANT	\N	EXCUSE	0
186407	186397	11059R	PARTICIPANT	\N	EXCUSE	0
200994	190796	80013X	PARTICIPANT	\N	PRESENT	0
200995	190796	08017T	PARTICIPANT	\N	PRESENT	0
200996	190796	14197C	PARTICIPANT	\N	PRESENT	0
200997	190796	95049N	PARTICIPANT	\N	PRESENT	0
200998	190796	14261S	PARTICIPANT	\N	PRESENT	0
200999	190796	14135M	PARTICIPANT	\N	PRESENT	0
201000	190796	08042U	PARTICIPANT	\N	PRESENT	0
201012	190796	14187A	PARTICIPANT	\N	PRESENT	0
201013	190796	08069G	PARTICIPANT	\N	PRESENT	0
201014	190796	14038Y	PARTICIPANT	\N	PRESENT	0
201032	190796	14259Y	PARTICIPANT	\N	PRESENT	0
201033	190796	14073Q	PARTICIPANT	\N	PRESENT	0
201034	190796	14179A	PARTICIPANT	\N	PRESENT	0
201035	190796	08009T	PARTICIPANT	\N	PRESENT	0
201036	190796	14195A	PARTICIPANT	\N	PRESENT	0
201037	190796	11097X	PARTICIPANT	\N	PRESENT	0
201038	190796	14265W	PARTICIPANT	\N	PRESENT	0
201039	190796	14219Q	PARTICIPANT	\N	PRESENT	0
201042	190796	14157T	PARTICIPANT	\N	PRESENT	0
201043	190796	04092N	PARTICIPANT	\N	PRESENT	0
201044	190796	11091R	PARTICIPANT	\N	PRESENT	0
201045	190796	08060W	PARTICIPANT	\N	PRESENT	0
201046	190796	14237S	PARTICIPANT	\N	PRESENT	0
201047	190796	11063M	PARTICIPANT	\N	PRESENT	0
201052	190796	11066Q	PARTICIPANT	\N	PRESENT	0
201053	190796	04081K	PARTICIPANT	\N	PRESENT	0
201054	190796	08010L	PARTICIPANT	\N	PRESENT	0
201072	190796	14147R	PARTICIPANT	\N	PRESENT	0
201073	190796	08014Q	PARTICIPANT	\N	PRESENT	0
201074	190796	95015C	PARTICIPANT	\N	PRESENT	0
201075	201041	11012A	PARTICIPANT	\N	EXCUSE	0
201092	190796	08055A	PARTICIPANT	\N	PRESENT	0
201093	190796	14053L	PARTICIPANT	\N	PRESENT	0
201094	190796	98053W	PARTICIPANT	\N	PRESENT	0
201095	190796	14205J	PARTICIPANT	\N	PRESENT	0
201096	190796	14083S	PARTICIPANT	\N	PRESENT	0
201112	190796	04057K	PARTICIPANT	\N	PRESENT	0
201132	190796	07029T	PARTICIPANT	\N	PRESENT	0
201214	190797	04074L	PARTICIPANT	\N	PRESENT	0
201215	190797	08042U	PARTICIPANT	\N	PRESENT	0
201293	190797	14073Q	PARTICIPANT	\N	PRESENT	0
201294	190797	14231L	PARTICIPANT	\N	PRESENT	0
201295	190797	14089Y	PARTICIPANT	\N	PRESENT	0
201296	190797	14083S	PARTICIPANT	\N	PRESENT	0
201297	190797	04070G	PARTICIPANT	\N	PRESENT	0
201298	190797	08056B	PARTICIPANT	\N	PRESENT	0
201299	190797	14071N	PARTICIPANT	\N	PRESENT	0
201300	190797	92031P	PARTICIPANT	\N	PRESENT	0
201301	190797	14215L	PARTICIPANT	\N	PRESENT	0
201212	190797	89029V	PARTICIPANT	\N	PRESENT	0
201213	190797	14041T	PARTICIPANT	\N	PRESENT	0
201302	190797	14087W	PARTICIPANT	\N	PRESENT	0
201303	190797	95049N	PARTICIPANT	\N	PRESENT	0
201304	190797	14079W	PARTICIPANT	\N	PRESENT	0
201401	190797	14257W	PARTICIPANT	\N	PRESENT	0
201402	201041	01027Q	PARTICIPANT	\N	PRESENT	0
201403	190797	14105F	PARTICIPANT	\N	PRESENT	0
201404	190797	08060W	PARTICIPANT	\N	PRESENT	0
201405	201041	11053K	PARTICIPANT	\N	PRESENT	0
201406	201041	98046X	PARTICIPANT	\N	PRESENT	0
201407	190797	08061X	PARTICIPANT	\N	PRESENT	0
201408	190797	95041E	PARTICIPANT	\N	PRESENT	0
201409	190797	14205J	PARTICIPANT	\N	PRESENT	0
201410	190797	95063L	PARTICIPANT	\N	PRESENT	0
201411	190797	14179A	PARTICIPANT	\N	PRESENT	0
201412	190797	04056J	PARTICIPANT	\N	PRESENT	0
201432	190797	11085T	PARTICIPANT	\N	PRESENT	0
201433	190797	14255U	PARTICIPANT	\N	PRESENT	0
201434	190797	14327T	PARTICIPANT	\N	PRESENT	0
201452	190797	14107H	PARTICIPANT	\N	PRESENT	0
201453	190797	08024S	PARTICIPANT	\N	PRESENT	0
201472	190797	95062K	PARTICIPANT	\N	PRESENT	0
201473	190797	14253S	PARTICIPANT	\N	PRESENT	0
201632	190797	88008L	PARTICIPANT	\N	PRESENT	0
201633	190797	02002K	PARTICIPANT	\N	PRESENT	0
201634	190797	98018T	PARTICIPANT	\N	PRESENT	0
201652	201254	04070G	PRESIDENT	0	PRESENT	0
201653	201254	11029K	PARTICIPANT	\N	PRESENT	0
201654	201254	01041N	PARTICIPANT	\N	PRESENT	0
201655	201254	14229S	PARTICIPANT	\N	PRESENT	0
201656	201254	11089X	PARTICIPANT	\N	PRESENT	0
201657	201254	14241N	PARTICIPANT	\N	PRESENT	0
201658	201254	83047W	PARTICIPANT	\N	PRESENT	0
201659	201254	08017T	PARTICIPANT	\N	PRESENT	0
201660	201254	14179A	PARTICIPANT	\N	PRESENT	0
201661	201254	08012N	PARTICIPANT	\N	PRESENT	0
201662	201254	08024S	PARTICIPANT	\N	PRESENT	0
201663	201254	14249W	PARTICIPANT	\N	PRESENT	0
201664	201254	08039A	PARTICIPANT	\N	PRESENT	0
201665	201254	08031R	PARTICIPANT	\N	PRESENT	0
201666	201254	07026Q	PARTICIPANT	\N	PRESENT	0
201667	201254	14061L	PARTICIPANT	\N	PRESENT	0
201668	201254	14103D	PARTICIPANT	\N	PRESENT	0
201669	201254	04057K	PARTICIPANT	\N	PRESENT	0
201670	201254	14073Q	PARTICIPANT	\N	PRESENT	0
201671	201254	14235Q	PARTICIPANT	\N	PRESENT	0
201672	201254	08043V	PARTICIPANT	\N	PRESENT	0
201673	201254	87003B	PARTICIPANT	\N	PRESENT	0
201674	201254	11014C	PARTICIPANT	\N	PRESENT	0
201675	201254	18127E	PARTICIPANT	\N	PRESENT	0
201676	201254	14089Y	PARTICIPANT	\N	PRESENT	0
201677	201254	98042T	PARTICIPANT	\N	PRESENT	0
201678	201254	14063N	PARTICIPANT	\N	PRESENT	0
201679	201254	11104D	PARTICIPANT	\N	PRESENT	0
201680	201254	14209N	PARTICIPANT	\N	PRESENT	0
201692	190797	18127E	PARTICIPANT	\N	PRESENT	0
201693	200632	11067R	PARTICIPANT	\N	PRESENT	0
201694	200632	11061K	PARTICIPANT	\N	PRESENT	0
201695	200632	14355X	PARTICIPANT	\N	PRESENT	0
201696	200632	11097X	PARTICIPANT	\N	PRESENT	0
201697	200632	04045F	PARTICIPANT	\N	PRESENT	0
201698	200632	14026U	PARTICIPANT	\N	PRESENT	0
201699	200632	14269B	PARTICIPANT	\N	PRESENT	0
201700	200632	11063M	PARTICIPANT	\N	PRESENT	0
201701	200632	14231L	PARTICIPANT	\N	PRESENT	0
201702	200632	11031D	PARTICIPANT	\N	PRESENT	0
201703	200632	14281W	PARTICIPANT	\N	PRESENT	0
201704	200632	14271U	PARTICIPANT	\N	PRESENT	0
201705	200632	14151M	PARTICIPANT	\N	PRESENT	0
201706	200632	14213J	PARTICIPANT	\N	PRESENT	0
201707	200632	10006L	PARTICIPANT	\N	PRESENT	0
201708	200632	98024R	PRESIDENT	0	PRESENT	0
201709	200632	14265W	PARTICIPANT	\N	PRESENT	0
201710	200632	14053L	PARTICIPANT	\N	PRESENT	0
201711	200632	04092N	PARTICIPANT	\N	PRESENT	0
201712	200632	08052W	PARTICIPANT	\N	PRESENT	0
201713	200632	12042Y	PARTICIPANT	\N	PRESENT	0
201714	200632	04081K	PARTICIPANT	\N	PRESENT	0
201715	200632	11023D	PARTICIPANT	\N	PRESENT	0
201716	200632	14119M	PARTICIPANT	\N	PRESENT	0
201717	200632	11103C	PARTICIPANT	\N	PRESENT	0
201718	200632	14071N	PARTICIPANT	\N	PRESENT	0
201719	200632	04053F	PARTICIPANT	\N	PRESENT	0
201720	200632	14017T	PARTICIPANT	\N	EXCUSE	0
201732	200632	14034U	PARTICIPANT	\N	PRESENT	0
201733	200632	14121F	PARTICIPANT	\N	PRESENT	0
201734	200632	14255U	PARTICIPANT	\N	PRESENT	0
201812	190798	04081K	PARTICIPANT	\N	PRESENT	0
201813	190798	04092N	PARTICIPANT	\N	PRESENT	0
201814	190798	11063M	PARTICIPANT	\N	PRESENT	0
201815	190798	01059Y	PARTICIPANT	\N	PRESENT	0
201816	190798	11031D	PARTICIPANT	\N	PRESENT	0
201817	190798	14361V	PARTICIPANT	\N	PRESENT	0
201818	190798	14227Q	PARTICIPANT	\N	PRESENT	0
201819	190798	98024R	PARTICIPANT	\N	PRESENT	0
201820	190798	04059M	PARTICIPANT	\N	PRESENT	0
201821	190798	14269B	PARTICIPANT	\N	PRESENT	0
201822	190798	04045F	PARTICIPANT	\N	PRESENT	0
201823	190798	04053F	PARTICIPANT	\N	PRESENT	0
201824	190798	14071N	PARTICIPANT	\N	PRESENT	0
201825	190798	14031R	PARTICIPANT	\N	PRESENT	0
201826	190798	14169X	PARTICIPANT	\N	PRESENT	0
201827	190798	14195A	PARTICIPANT	\N	PRESENT	0
201828	190798	14215L	PARTICIPANT	\N	PRESENT	0
201829	190798	11098Y	PARTICIPANT	\N	PRESENT	0
201830	190798	14281W	PARTICIPANT	\N	PRESENT	0
201831	190798	07029T	PARTICIPANT	\N	PRESENT	0
201832	190798	14053L	PARTICIPANT	\N	PRESENT	0
201833	190798	11103C	PARTICIPANT	\N	PRESENT	0
201834	190798	14157T	PARTICIPANT	\N	PRESENT	0
201835	190798	14355X	PARTICIPANT	\N	PRESENT	0
201836	190798	14213J	PARTICIPANT	\N	PRESENT	0
201837	190798	14147R	PARTICIPANT	\N	PRESENT	0
201838	190798	11097X	PARTICIPANT	\N	PRESENT	0
201839	190798	04061F	PARTICIPANT	\N	PRESENT	0
201840	190798	10006L	PARTICIPANT	\N	PRESENT	0
201841	190798	11067R	PARTICIPANT	\N	PRESENT	0
201842	190798	11061K	PARTICIPANT	\N	PRESENT	0
201843	190798	04097T	PARTICIPANT	\N	PRESENT	0
181327	167352	01019Q	PARTICIPANT	\N	PRESENT	0
181328	167352	11096W	PARTICIPANT	\N	PRESENT	0
181329	167352	04056J	PARTICIPANT	\N	PRESENT	0
181330	167352	92015P	PARTICIPANT	\N	PRESENT	0
181331	167352	98046X	PARTICIPANT	\N	PRESENT	0
181332	167352	08052W	PARTICIPANT	\N	PRESENT	0
181333	167352	98050T	PARTICIPANT	\N	PRESENT	0
181334	167352	08025T	PARTICIPANT	\N	PRESENT	0
181335	167352	14087W	PARTICIPANT	\N	PRESENT	0
181336	167352	14151M	PARTICIPANT	\N	PRESENT	0
181337	167352	14051J	PARTICIPANT	\N	PRESENT	0
181338	167352	01011G	PARTICIPANT	\N	PRESENT	0
181339	167352	95063L	PARTICIPANT	\N	PRESENT	0
181340	167352	11027H	PARTICIPANT	\N	PRESENT	0
181341	167352	08068F	PARTICIPANT	\N	PRESENT	0
181342	167352	92020L	PARTICIPANT	\N	PRESENT	0
181343	167352	14197C	PARTICIPANT	\N	PRESENT	0
181344	167352	14028W	PARTICIPANT	\N	PRESENT	0
181345	167352	01022K	PARTICIPANT	\N	PRESENT	0
181346	167352	11036J	PARTICIPANT	\N	PRESENT	0
181347	167352	80027E	PARTICIPANT	\N	PRESENT	0
181348	167352	95041E	PARTICIPANT	\N	PRESENT	0
181349	167352	95067Q	PARTICIPANT	\N	PRESENT	0
181350	167352	08012N	PARTICIPANT	\N	PRESENT	0
181351	167352	11089X	PARTICIPANT	\N	PRESENT	0
181352	167352	14107H	PARTICIPANT	\N	PRESENT	0
181353	167352	11065P	PARTICIPANT	\N	PRESENT	0
181354	167352	08043V	PARTICIPANT	\N	PRESENT	0
181355	167352	14065Q	PARTICIPANT	\N	PRESENT	0
181356	167352	98029W	PARTICIPANT	\N	PRESENT	0
181357	167352	01047U	PARTICIPANT	\N	PRESENT	0
181358	167352	01034P	PARTICIPANT	\N	PRESENT	0
181359	167352	11046L	PARTICIPANT	\N	PRESENT	0
181360	167352	11093T	PARTICIPANT	\N	PRESENT	0
181361	167352	83042R	PARTICIPANT	\N	PRESENT	0
181362	167352	08053X	PARTICIPANT	\N	PRESENT	0
181363	167352	95037J	PARTICIPANT	\N	PRESENT	0
181364	167352	08058D	PARTICIPANT	\N	PRESENT	0
181365	167352	14271U	PARTICIPANT	\N	PRESENT	0
181366	167352	11056N	PARTICIPANT	\N	PRESENT	0
181367	167352	14103D	PARTICIPANT	\N	PRESENT	0
181368	167352	08009T	PARTICIPANT	\N	PRESENT	0
181369	167352	11054L	PARTICIPANT	\N	PRESENT	0
181370	167352	04066L	PARTICIPANT	\N	PRESENT	0
181371	167352	04079R	PARTICIPANT	\N	PRESENT	0
181372	167352	14001X	PARTICIPANT	\N	PRESENT	0
181373	167352	11082Q	PARTICIPANT	\N	PRESENT	0
181374	167352	08014Q	PARTICIPANT	\N	PRESENT	0
181375	167352	14205J	PARTICIPANT	\N	PRESENT	0
181376	167352	14109K	PARTICIPANT	\N	PRESENT	0
181377	167352	14219Q	PARTICIPANT	\N	PRESENT	0
181378	167352	08035V	PARTICIPANT	\N	PRESENT	0
181431	167352	14255U	PARTICIPANT	\N	PRESENT	0
181442	167352	04043D	PARTICIPANT	\N	PRESENT	0
181381	167352	14014Q	PARTICIPANT	\N	PRESENT	0
181382	167352	14097Y	PARTICIPANT	\N	PRESENT	0
181435	167352	01024M	PARTICIPANT	\N	PRESENT	0
181384	167352	11014C	PARTICIPANT	\N	PRESENT	0
181385	167352	14257W	PARTICIPANT	\N	PRESENT	0
181386	167352	14207L	PARTICIPANT	\N	PRESENT	0
181387	167352	14063N	PARTICIPANT	\N	PRESENT	0
181388	167352	14121F	PARTICIPANT	\N	PRESENT	0
181389	167352	14229S	PARTICIPANT	\N	PRESENT	0
181390	167352	14135M	PARTICIPANT	\N	PRESENT	0
181391	167352	04077P	PARTICIPANT	\N	PRESENT	0
181392	167352	04053F	PARTICIPANT	\N	PRESENT	0
181393	167352	01028R	PARTICIPANT	\N	PRESENT	0
181394	167352	11043H	PARTICIPANT	\N	PRESENT	0
181395	167352	04059M	PARTICIPANT	\N	PRESENT	0
181396	167352	11032E	PARTICIPANT	\N	PRESENT	0
181397	167352	11084S	PARTICIPANT	\N	PRESENT	0
181398	167352	11067R	PARTICIPANT	\N	PRESENT	0
181399	167352	08024S	PARTICIPANT	\N	PRESENT	0
181400	167352	14085U	PARTICIPANT	\N	PRESENT	0
181401	167352	14081Q	PARTICIPANT	\N	PRESENT	0
181402	167352	11077T	PARTICIPANT	\N	PRESENT	0
181403	167352	11042G	PARTICIPANT	\N	PRESENT	0
181404	167352	04094Q	PARTICIPANT	\N	PRESENT	0
181405	167352	04095R	PARTICIPANT	\N	PRESENT	0
181406	167352	14159V	PARTICIPANT	\N	PRESENT	0
181407	167352	11025F	PARTICIPANT	\N	PRESENT	0
181408	167352	14269B	PARTICIPANT	\N	PRESENT	0
181409	167352	01014K	PARTICIPANT	\N	PRESENT	0
181410	167352	14249W	PARTICIPANT	\N	PRESENT	0
181411	167352	11107G	PARTICIPANT	\N	PRESENT	0
181412	167352	11037K	PARTICIPANT	\N	PRESENT	0
181413	167352	12042Y	PARTICIPANT	\N	PRESENT	0
181414	167352	11114F	PARTICIPANT	\N	PRESENT	0
181415	167352	08073C	PARTICIPANT	\N	PRESENT	0
181416	167352	01060R	PARTICIPANT	\N	PRESENT	0
181417	167352	89017R	PARTICIPANT	\N	PRESENT	0
181418	167352	11053K	PARTICIPANT	\N	PRESENT	0
181419	167352	04038G	PARTICIPANT	\N	PRESENT	0
181420	167352	14034U	PARTICIPANT	\N	PRESENT	0
181421	167352	11064N	PARTICIPANT	\N	PRESENT	0
181422	167352	14267Y	PARTICIPANT	\N	PRESENT	0
181423	167352	14089Y	PARTICIPANT	\N	PRESENT	0
181424	167352	14073Q	PARTICIPANT	\N	PRESENT	0
181425	167352	11111C	PARTICIPANT	\N	PRESENT	0
181426	167352	14231L	PARTICIPANT	\N	PRESENT	0
181427	167352	14083S	PARTICIPANT	\N	PRESENT	0
181428	167352	09001P	PARTICIPANT	\N	PRESENT	0
181429	167352	14179A	PARTICIPANT	\N	PRESENT	0
181430	167352	14221J	PARTICIPANT	\N	PRESENT	0
181432	167352	11094U	PARTICIPANT	\N	PRESENT	0
181433	167352	11020A	PARTICIPANT	\N	PRESENT	0
181436	167352	08056B	PARTICIPANT	\N	PRESENT	0
181437	167352	01025N	PARTICIPANT	\N	PRESENT	0
181438	167352	01007L	PARTICIPANT	\N	PRESENT	0
181439	167352	14327T	PARTICIPANT	\N	PRESENT	0
181440	167352	04070G	PARTICIPANT	\N	PRESENT	0
181441	167352	04061F	PARTICIPANT	\N	PRESENT	0
181452	167352	80013X	PARTICIPANT	\N	PRESENT	0
181453	167352	08044W	PARTICIPANT	\N	PRESENT	0
181455	167352	14217N	PARTICIPANT	\N	PRESENT	0
181459	167352	11110B	PARTICIPANT	\N	PRESENT	0
181460	167352	14253S	PARTICIPANT	\N	PRESENT	0
181493	167352	11085T	PARTICIPANT	\N	PRESENT	0
181532	167352	05004A	PARTICIPANT	\N	PRESENT	0
181552	167352	11072N	PARTICIPANT	\N	PRESENT	0
181573	167352	11068S	PARTICIPANT	\N	PRESENT	0
181612	167352	96004D	PARTICIPANT	\N	PRESENT	0
181613	167353	04081K	PARTICIPANT	\N	PRESENT	0
181635	167353	04050C	PARTICIPANT	\N	PRESENT	0
181640	167353	01013J	PARTICIPANT	\N	PRESENT	0
181652	167353	14271U	PARTICIPANT	\N	PRESENT	0
181653	167353	11036J	PARTICIPANT	\N	PRESENT	0
181654	167353	11068S	PARTICIPANT	\N	PRESENT	0
181655	167353	11107G	PARTICIPANT	\N	PRESENT	0
181656	167353	14107H	PARTICIPANT	\N	PRESENT	0
181657	167353	08052W	PARTICIPANT	\N	PRESENT	0
181658	167353	04053F	PARTICIPANT	\N	PRESENT	0
181659	167353	11037K	PARTICIPANT	\N	PRESENT	0
181660	167353	98022P	PARTICIPANT	\N	PRESENT	0
181661	167353	01024M	PARTICIPANT	\N	PRESENT	0
181662	167353	08044W	PARTICIPANT	\N	PRESENT	0
181663	167353	01060R	PARTICIPANT	\N	PRESENT	0
181664	167353	14059S	PARTICIPANT	\N	PRESENT	0
181665	167353	07029T	PARTICIPANT	\N	PRESENT	0
181666	167353	14041T	PARTICIPANT	\N	PRESENT	0
181667	167353	08069G	PARTICIPANT	\N	PRESENT	0
181668	167353	04067M	PARTICIPANT	\N	PRESENT	0
181669	167353	14327T	PARTICIPANT	\N	PRESENT	0
181670	167353	14267Y	PARTICIPANT	\N	PRESENT	0
181671	167353	01028R	PARTICIPANT	\N	PRESENT	0
181672	167353	08015R	PARTICIPANT	\N	PRESENT	0
181673	167353	12042Y	PARTICIPANT	\N	PRESENT	0
181674	167353	14079W	PARTICIPANT	\N	PRESENT	0
181675	167353	14089Y	PARTICIPANT	\N	PRESENT	0
181692	167353	04057K	PARTICIPANT	\N	PRESENT	0
181693	167353	01058X	PARTICIPANT	\N	PRESENT	0
181694	167353	04038G	PARTICIPANT	\N	PRESENT	0
181695	167353	99004R	PARTICIPANT	\N	PRESENT	0
181696	167353	13002U	PARTICIPANT	\N	PRESENT	0
181697	167353	14259Y	PARTICIPANT	\N	PRESENT	0
181712	167353	04088S	PARTICIPANT	\N	PRESENT	0
181713	167353	14199E	PARTICIPANT	\N	PRESENT	0
181732	167353	11071M	PARTICIPANT	\N	PRESENT	0
181733	167353	01014K	PARTICIPANT	\N	PRESENT	0
181734	167353	04085P	PARTICIPANT	\N	PRESENT	0
181735	167353	96004D	PARTICIPANT	\N	PRESENT	0
181752	167353	05012A	PARTICIPANT	\N	PRESENT	0
181753	167353	14073Q	PARTICIPANT	\N	PRESENT	0
181754	167353	11101A	PARTICIPANT	\N	PRESENT	0
181792	167353	14033T	PARTICIPANT	\N	PRESENT	0
181793	167353	98050T	PARTICIPANT	\N	PRESENT	0
181794	167353	11012A	PARTICIPANT	\N	PRESENT	0
181795	167353	14001X	PARTICIPANT	\N	PRESENT	0
207911	206656	19593H	PARTICIPANT	\N	PRESENT	0
207912	206656	19347U	PARTICIPANT	\N	PRESENT	0
207913	206656	04042C	PARTICIPANT	\N	PRESENT	0
207914	206656	11074Q	PARTICIPANT	\N	PRESENT	0
207915	206656	19503N	PARTICIPANT	\N	PRESENT	0
207916	206656	19551W	PARTICIPANT	\N	PRESENT	0
207917	206656	14085U	PARTICIPANT	\N	PRESENT	0
207918	206656	98035U	PARTICIPANT	\N	PRESENT	0
207919	206656	08055A	PARTICIPANT	\N	PRESENT	0
207920	206656	08016S	PARTICIPANT	\N	PRESENT	0
207921	206656	04034C	PARTICIPANT	\N	PRESENT	0
207922	206656	11067R	PARTICIPANT	\N	PRESENT	0
207923	206656	14281W	PARTICIPANT	\N	PRESENT	0
207924	206656	14001X	PARTICIPANT	\N	PRESENT	0
207925	206656	11026G	PARTICIPANT	\N	PRESENT	0
207926	206656	11041F	PARTICIPANT	\N	PRESENT	0
207927	206656	04085P	PARTICIPANT	\N	PRESENT	0
207928	206656	19725B	PARTICIPANT	\N	PRESENT	0
207929	206656	14257W	PARTICIPANT	\N	PRESENT	0
207930	206656	14107H	PARTICIPANT	\N	PRESENT	0
207931	206656	19549D	PARTICIPANT	\N	PRESENT	0
207932	206656	14229S	PARTICIPANT	\N	PRESENT	0
207933	206656	19651A	PARTICIPANT	\N	PRESENT	0
207934	206656	11083R	PARTICIPANT	\N	PRESENT	0
207935	206656	04057K	PARTICIPANT	\N	PRESENT	0
207936	206656	11064N	PARTICIPANT	\N	PRESENT	0
207937	206656	19717B	PARTICIPANT	\N	PRESENT	0
207938	206656	19713W	PARTICIPANT	\N	PRESENT	0
207939	206656	14030Q	PARTICIPANT	\N	PRESENT	0
207940	206656	19735D	PARTICIPANT	\N	PRESENT	0
207941	206656	14221J	PARTICIPANT	\N	PRESENT	0
207942	206656	14083S	PARTICIPANT	\N	PRESENT	0
207943	206656	19521Q	PARTICIPANT	\N	PRESENT	0
207944	206656	04038G	PARTICIPANT	\N	PRESENT	0
207945	206656	19695N	PARTICIPANT	\N	PRESENT	0
207946	206656	19421M	PARTICIPANT	\N	PRESENT	0
207947	206656	14079W	PARTICIPANT	\N	PRESENT	0
207948	206656	11012A	PARTICIPANT	\N	PRESENT	0
207949	206656	14261S	PARTICIPANT	\N	PRESENT	0
207950	206656	19711U	PARTICIPANT	\N	PRESENT	0
207951	206656	99004R	PARTICIPANT	\N	PRESENT	0
207952	206656	01058X	PARTICIPANT	\N	PRESENT	0
207953	206656	04033B	PARTICIPANT	\N	PRESENT	0
207954	206656	04061F	PARTICIPANT	\N	PRESENT	0
207955	206656	19483C	PARTICIPANT	\N	PRESENT	0
207956	206656	14061L	PARTICIPANT	\N	PRESENT	0
207957	206656	19707Y	PARTICIPANT	\N	PRESENT	0
207958	206656	19705W	PARTICIPANT	\N	PRESENT	0
207959	206656	19443T	PARTICIPANT	\N	PRESENT	0
207960	206656	19399H	PARTICIPANT	\N	PRESENT	0
207961	206656	14041T	PARTICIPANT	\N	PRESENT	0
207962	206656	19663E	PARTICIPANT	\N	PRESENT	0
207963	206656	18083K	PARTICIPANT	\N	PRESENT	0
207964	206656	14169X	PARTICIPANT	\N	PRESENT	0
207965	206656	14038Y	PARTICIPANT	\N	PRESENT	0
207966	206656	14157T	PARTICIPANT	\N	PRESENT	0
207967	206656	19447X	PARTICIPANT	\N	PRESENT	0
207968	206656	19643A	PARTICIPANT	\N	PRESENT	0
207969	206656	04071H	PARTICIPANT	\N	PRESENT	0
207970	206656	04097T	PARTICIPANT	\N	PRESENT	0
207971	206656	08020N	PARTICIPANT	\N	PRESENT	0
207972	206656	10015M	PARTICIPANT	\N	PRESENT	0
207973	206656	08061X	PARTICIPANT	\N	PRESENT	0
207974	206656	14237S	PARTICIPANT	\N	PRESENT	0
207975	206656	19553Y	PARTICIPANT	\N	PRESENT	0
207976	206656	19719D	PARTICIPANT	\N	PRESENT	0
207977	206656	14265W	PARTICIPANT	\N	PRESENT	0
207978	206656	19441R	PARTICIPANT	\N	PRESENT	0
207979	206656	14089Y	PARTICIPANT	\N	PRESENT	0
207980	206656	14231L	PARTICIPANT	\N	PRESENT	0
207981	206656	14119M	PARTICIPANT	\N	PRESENT	0
207982	206656	95063L	PARTICIPANT	\N	PRESENT	0
207983	206656	19543W	PARTICIPANT	\N	PRESENT	0
207984	206656	19349W	PARTICIPANT	\N	PRESENT	0
207985	206656	19697Q	PARTICIPANT	\N	PRESENT	0
207986	206656	14225N	PARTICIPANT	\N	PRESENT	0
207987	206656	19727D	PARTICIPANT	\N	PRESENT	0
207988	206656	19251M	PARTICIPANT	\N	PRESENT	0
207989	206656	08017T	PARTICIPANT	\N	PRESENT	0
207990	206656	19631V	PARTICIPANT	\N	PRESENT	0
207991	206656	04040A	PARTICIPANT	\N	PRESENT	0
207992	206656	14105F	PARTICIPANT	\N	PRESENT	0
207993	206656	08044W	PARTICIPANT	\N	PRESENT	0
207994	206656	19565D	PARTICIPANT	\N	PRESENT	0
207995	206656	01028R	PARTICIPANT	\N	PRESENT	0
207996	206656	19335Q	PARTICIPANT	\N	PRESENT	0
207909	206656	96004D	PARTICIPANT	\N	PRESENT	0
207910	206656	14235Q	PARTICIPANT	\N	PRESENT	0
207997	206656	14219Q	PARTICIPANT	\N	PRESENT	0
207998	206656	05012A	PARTICIPANT	\N	PRESENT	0
208000	206656	04059M	PARTICIPANT	\N	PRESENT	0
208001	206656	14073Q	PARTICIPANT	\N	PRESENT	0
208002	206656	19563B	PARTICIPANT	\N	PRESENT	0
208003	206656	14033T	PARTICIPANT	\N	PRESENT	0
208004	206656	19709B	PARTICIPANT	\N	PRESENT	0
208005	206656	14357A	PARTICIPANT	\N	PRESENT	0
208013	208012	98035U	PARTICIPANT	\N	PRESENT	0
208014	208012	11012A	PARTICIPANT	\N	PRESENT	0
208016	208015	11064N	PARTICIPANT	\N	PRESENT	0
208017	207999	14133K	PARTICIPANT	\N	PRESENT	0
208058	207999	14061L	PARTICIPANT	\N	EXCUSE	0
208019	207999	96004D	PRESIDENT	0	PRESENT	0
208020	207999	14089Y	PARTICIPANT	\N	PRESENT	0
208021	207999	08014Q	PARTICIPANT	\N	PRESENT	0
208022	207999	14079W	PARTICIPANT	\N	PRESENT	0
208059	207999	14065Q	PARTICIPANT	\N	EXCUSE	0
208060	207999	04097T	PARTICIPANT	\N	EXCUSE	0
208025	207999	19521Q	PARTICIPANT	\N	PRESENT	0
208067	208066	01034P	PARTICIPANT	\N	PRESENT	0
208068	208066	11097X	PARTICIPANT	\N	PRESENT	0
208028	207999	11083R	PARTICIPANT	\N	PRESENT	0
208029	207999	14033T	PARTICIPANT	\N	PRESENT	0
208070	208069	01034P	PARTICIPANT	\N	PRESENT	0
208031	207999	19553Y	PARTICIPANT	\N	PRESENT	0
208032	207999	19725B	PARTICIPANT	\N	PRESENT	0
208072	208071	01034P	PARTICIPANT	\N	PRESENT	0
208074	208073	11097X	PARTICIPANT	\N	PRESENT	0
208075	208073	01034P	PARTICIPANT	\N	PRESENT	0
208036	207999	08044W	PARTICIPANT	\N	PRESENT	0
208037	207999	14097Y	PARTICIPANT	\N	PRESENT	0
208038	207999	04061F	PARTICIPANT	\N	PRESENT	0
208077	208076	01034P	PARTICIPANT	\N	PRESENT	0
208079	208078	01034P	PARTICIPANT	\N	PRESENT	0
208041	207999	11026G	PARTICIPANT	\N	PRESENT	0
208043	207999	14001X	PARTICIPANT	\N	PRESENT	0
208044	207999	14221J	PARTICIPANT	\N	PRESENT	0
208045	207999	04057K	PARTICIPANT	\N	PRESENT	0
208046	207999	19563B	PARTICIPANT	\N	PRESENT	0
208047	207999	19335Q	PARTICIPANT	\N	PRESENT	0
208048	207999	19593H	PARTICIPANT	\N	PRESENT	0
208050	207999	14237S	PARTICIPANT	\N	PRESENT	0
208051	207999	14135M	PARTICIPANT	\N	PRESENT	0
208053	207999	14225N	PARTICIPANT	\N	EXCUSE	0
208054	207999	10015M	PARTICIPANT	\N	PRESENT	0
208055	207999	14229S	PARTICIPANT	\N	PRESENT	0
208056	207999	98035U	PARTICIPANT	\N	PRESENT	0
207725	207294	01043Q	PARTICIPANT	\N	PRESENT	0
207726	207294	19565D	PARTICIPANT	\N	PRESENT	0
207727	207294	14357A	PARTICIPANT	\N	PRESENT	0
207728	207294	19441R	PARTICIPANT	\N	PRESENT	0
166353	166352	01031L	PRESIDENT	0	PRESENT	0
166360	166352	11040E	PARTICIPANT	\N	PRESENT	0
166362	166352	14175V	PARTICIPANT	\N	PRESENT	0
166364	166352	14083S	PARTICIPANT	\N	EXCUSE	0
166366	166352	04086Q	PARTICIPANT	\N	EXCUSE	0
166380	166352	08022Q	PARTICIPANT	\N	PRESENT	0
166382	166352	01027Q	PARTICIPANT	\N	PRESENT	0
166383	166352	04071H	PARTICIPANT	\N	PRESENT	0
166385	166352	11083R	PARTICIPANT	\N	PRESENT	0
166387	166352	99004R	PARTICIPANT	\N	PRESENT	0
166388	166352	08010L	PARTICIPANT	\N	PRESENT	0
166390	166352	01048V	PARTICIPANT	\N	PRESENT	0
166391	166352	98046X	PARTICIPANT	\N	PRESENT	0
166422	166352	08011M	PARTICIPANT	\N	EXCUSE	0
166423	166352	08061X	PARTICIPANT	\N	PRESENT	0
166424	166352	01016M	PARTICIPANT	\N	PRESENT	0
166425	166352	14225N	PARTICIPANT	\N	PRESENT	0
166426	166352	98053W	PARTICIPANT	\N	EXCUSE	0
166432	166352	11053K	PARTICIPANT	\N	PRESENT	0
169092	168848	11035H	PARTICIPANT	\N	EXCUSE	0
169093	168848	08044W	PARTICIPANT	\N	EXCUSE	0
166715	166712	14093U	PARTICIPANT	\N	PRESENT	0
166716	166712	14030Q	PARTICIPANT	\N	PRESENT	0
169504	157435	08019V	PRESIDENT	0	PRESENT	0
169234	169232	11055M	PARTICIPANT	\N	PRESENT	0
166719	166712	11095V	PARTICIPANT	\N	EXCUSE	0
169235	169232	01046T	PARTICIPANT	\N	PRESENT	0
169236	169232	04053F	PARTICIPANT	\N	PRESENT	0
169237	169232	14255U	PARTICIPANT	\N	PRESENT	0
169238	169232	04066L	PARTICIPANT	\N	PRESENT	0
166724	166712	01015L	PARTICIPANT	\N	EXCUSE	0
166725	166712	11107G	PARTICIPANT	\N	PRESENT	0
169239	169232	00003C	PARTICIPANT	\N	EXCUSE	0
169294	169292	11055M	PARTICIPANT	\N	PRESENT	0
169241	169232	11103C	PARTICIPANT	\N	PRESENT	0
166729	166712	05001W	PARTICIPANT	\N	EXCUSE	0
169295	169292	01046T	PRESIDENT	0	PRESENT	0
169243	169232	14195A	PARTICIPANT	\N	PRESENT	0
169244	169232	14267Y	PARTICIPANT	\N	PRESENT	0
166733	166712	14219Q	PARTICIPANT	\N	PRESENT	0
166734	166712	80027E	PARTICIPANT	\N	PRESENT	0
166735	166712	14031R	PARTICIPANT	\N	PRESENT	0
166736	166712	08009T	PRESIDENT	0	PRESENT	0
169245	169232	11023D	PARTICIPANT	\N	PRESENT	0
169246	169232	11031D	PARTICIPANT	\N	PRESENT	0
169247	169232	08052W	PARTICIPANT	\N	PRESENT	0
166740	166712	08042U	PARTICIPANT	\N	PRESENT	0
166741	166712	14169X	PARTICIPANT	\N	PRESENT	0
166742	166712	14237S	PARTICIPANT	\N	PRESENT	0
166743	166712	13002U	PARTICIPANT	\N	PRESENT	0
166744	166712	05012A	PARTICIPANT	\N	PRESENT	0
169248	169232	01059Y	PARTICIPANT	\N	PRESENT	0
166746	166712	14135M	PARTICIPANT	\N	PRESENT	0
166747	166712	14331P	PARTICIPANT	\N	PRESENT	0
166748	166712	95062K	PARTICIPANT	\N	PRESENT	0
166749	166712	14107H	PARTICIPANT	\N	PRESENT	0
166750	166712	14051J	PARTICIPANT	\N	PRESENT	0
166751	166712	14157T	PARTICIPANT	\N	PRESENT	0
169249	169232	04081K	PARTICIPANT	\N	PRESENT	0
169296	169292	04053F	PARTICIPANT	\N	PRESENT	0
169297	169292	14255U	PARTICIPANT	\N	PRESENT	0
169252	169232	04067M	PARTICIPANT	\N	PRESENT	0
169253	169232	14217N	PARTICIPANT	\N	PRESENT	0
169254	169232	14042U	PARTICIPANT	\N	PRESENT	0
169255	169232	14151M	PARTICIPANT	\N	PRESENT	0
169256	169232	12042Y	PARTICIPANT	\N	PRESENT	0
169298	169292	04066L	PARTICIPANT	\N	PRESENT	0
169258	169232	14087W	PARTICIPANT	\N	PRESENT	0
169259	169232	01003G	PARTICIPANT	\N	EXCUSE	0
169260	169232	14034U	PARTICIPANT	\N	PRESENT	0
169299	169292	00003C	PARTICIPANT	\N	EXCUSE	0
169262	169232	11061K	PARTICIPANT	\N	PRESENT	0
169505	157435	11109J	PARTICIPANT	\N	PRESENT	0
169264	169232	08048B	PARTICIPANT	\N	PRESENT	0
169265	169232	08041T	PARTICIPANT	\N	PRESENT	0
169266	169232	01011G	PARTICIPANT	\N	PRESENT	0
169267	169232	14026U	PARTICIPANT	\N	PRESENT	0
169268	169232	14213J	PARTICIPANT	\N	PRESENT	0
169269	169232	14121F	PARTICIPANT	\N	PRESENT	0
169270	169232	11112D	PARTICIPANT	\N	PRESENT	0
169271	169232	14037X	PARTICIPANT	\N	PRESENT	0
169272	169232	14018U	PARTICIPANT	\N	PRESENT	0
169273	169232	11067R	PARTICIPANT	\N	PRESENT	0
169274	169232	14223L	PARTICIPANT	\N	PRESENT	0
169275	169232	04092N	PRESIDENT	0	PRESENT	0
169276	169232	14265W	PARTICIPANT	\N	PRESENT	0
169277	169232	14119M	PARTICIPANT	\N	PRESENT	0
169278	169232	14071N	PARTICIPANT	\N	PRESENT	0
169279	169232	04043D	PARTICIPANT	\N	PRESENT	0
169280	169232	14271U	PARTICIPANT	\N	PRESENT	0
169281	169232	14017T	PARTICIPANT	\N	PRESENT	0
169282	169232	11093T	PARTICIPANT	\N	PRESENT	0
169283	169232	11097X	PARTICIPANT	\N	PRESENT	0
169284	169232	04045F	PARTICIPANT	\N	PRESENT	0
169285	169232	14227Q	PARTICIPANT	\N	PRESENT	0
169286	169232	01034P	PARTICIPANT	\N	PRESENT	0
169288	169232	11063M	PARTICIPANT	\N	PRESENT	0
169289	169232	14269B	PARTICIPANT	\N	PRESENT	0
169301	169292	11103C	PARTICIPANT	\N	PRESENT	0
169303	169292	14195A	PARTICIPANT	\N	PRESENT	0
169304	169292	14267Y	PARTICIPANT	\N	PRESENT	0
169305	169292	11023D	PARTICIPANT	\N	PRESENT	0
169306	169292	11031D	PARTICIPANT	\N	PRESENT	0
169307	169292	08052W	PARTICIPANT	\N	PRESENT	0
169308	169292	01059Y	PARTICIPANT	\N	PRESENT	0
169309	169292	04081K	PARTICIPANT	\N	PRESENT	0
169312	169292	04067M	PARTICIPANT	\N	PRESENT	0
169313	169292	14217N	PARTICIPANT	\N	PRESENT	0
169314	169292	14042U	PARTICIPANT	\N	PRESENT	0
169315	169292	14151M	PARTICIPANT	\N	PRESENT	0
169316	169292	12042Y	PARTICIPANT	\N	PRESENT	0
169510	157435	96004D	PARTICIPANT	\N	EXCUSE	0
169318	169292	14087W	PARTICIPANT	\N	PRESENT	0
169319	169292	01003G	PARTICIPANT	\N	EXCUSE	0
169320	169292	14034U	PARTICIPANT	\N	PRESENT	0
169322	169292	11061K	PARTICIPANT	\N	PRESENT	0
169324	169292	08048B	PARTICIPANT	\N	PRESENT	0
169325	169292	08041T	PARTICIPANT	\N	PRESENT	0
169326	169292	01011G	PARTICIPANT	\N	PRESENT	0
169327	169292	14026U	PARTICIPANT	\N	PRESENT	0
169328	169292	14213J	PARTICIPANT	\N	PRESENT	0
169329	169292	14121F	PARTICIPANT	\N	PRESENT	0
169330	169292	11112D	PARTICIPANT	\N	PRESENT	0
169331	169292	14037X	PARTICIPANT	\N	PRESENT	0
169332	169292	14018U	PARTICIPANT	\N	PRESENT	0
169333	169292	11067R	PARTICIPANT	\N	PRESENT	0
169334	169292	14223L	PARTICIPANT	\N	PRESENT	0
169335	169292	04092N	PARTICIPANT	\N	PRESENT	0
169336	169292	14265W	PARTICIPANT	\N	PRESENT	0
169337	169292	14119M	PARTICIPANT	\N	PRESENT	0
169338	169292	14071N	PARTICIPANT	\N	PRESENT	0
169339	169292	04043D	PARTICIPANT	\N	PRESENT	0
169340	169292	14271U	PARTICIPANT	\N	PRESENT	0
169341	169292	14017T	PARTICIPANT	\N	PRESENT	0
169342	169292	11093T	PARTICIPANT	\N	PRESENT	0
169343	169292	11097X	PARTICIPANT	\N	PRESENT	0
169344	169292	04045F	PARTICIPANT	\N	PRESENT	0
169345	169292	14227Q	PARTICIPANT	\N	PRESENT	0
169346	169292	01034P	PARTICIPANT	\N	PRESENT	0
169348	169292	11063M	PARTICIPANT	\N	PRESENT	0
169349	169292	14269B	PARTICIPANT	\N	PRESENT	0
169519	157435	08065C	PARTICIPANT	\N	EXCUSE	0
169520	157435	11010L	PARTICIPANT	\N	EXCUSE	0
169523	157435	14033T	PARTICIPANT	\N	PRESENT	0
169529	157435	04094Q	PARTICIPANT	\N	EXCUSE	0
169530	157435	98005N	PARTICIPANT	\N	EXCUSE	0
169532	157435	14219Q	PARTICIPANT	\N	EXCUSE	0
169533	157435	14059S	PARTICIPANT	\N	EXCUSE	0
169534	157435	11106F	PARTICIPANT	\N	EXCUSE	0
201844	190798	08069G	PARTICIPANT	\N	PRESENT	0
201845	190798	11089X	PARTICIPANT	\N	PRESENT	0
201846	190798	04033B	PARTICIPANT	\N	PRESENT	0
201847	190798	12042Y	PARTICIPANT	\N	PRESENT	0
201848	190798	14271U	PARTICIPANT	\N	PRESENT	0
201849	190798	14030Q	PARTICIPANT	\N	PRESENT	0
201850	190798	14034U	PARTICIPANT	\N	PRESENT	0
201851	190798	11105E	PARTICIPANT	\N	PRESENT	0
201852	190798	14257W	PARTICIPANT	\N	PRESENT	0
201853	190798	14255U	PARTICIPANT	\N	PRESENT	0
201854	190798	08052W	PARTICIPANT	\N	PRESENT	0
201855	190798	14042U	PARTICIPANT	\N	PRESENT	0
201856	190798	14219Q	PARTICIPANT	\N	PRESENT	0
201857	190798	11077T	PARTICIPANT	\N	PRESENT	0
201858	190798	14205J	PARTICIPANT	\N	PRESENT	0
201859	190798	11109J	PARTICIPANT	\N	PRESENT	0
201860	190798	80013X	PARTICIPANT	\N	PRESENT	0
201861	190798	14231L	PARTICIPANT	\N	PRESENT	0
201862	190798	04067M	PARTICIPANT	\N	PRESENT	0
201863	190798	14187A	PARTICIPANT	\N	PRESENT	0
201864	190798	14357A	PARTICIPANT	\N	PRESENT	0
201865	190798	04088S	PARTICIPANT	\N	PRESENT	0
201866	190798	14079W	PARTICIPANT	\N	PRESENT	0
201867	190798	95063L	PARTICIPANT	\N	PRESENT	0
201868	190798	11057P	PARTICIPANT	\N	PRESENT	0
201869	190798	01034P	PARTICIPANT	\N	PRESENT	0
201870	190798	14261S	PARTICIPANT	\N	PRESENT	0
201871	190798	14179A	PARTICIPANT	\N	PRESENT	0
201872	190798	14089Y	PARTICIPANT	\N	PRESENT	0
202072	190798	14026U	PARTICIPANT	\N	PRESENT	0
201893	190798	01008M	PARTICIPANT	\N	PRESENT	0
201912	190798	14193X	PARTICIPANT	\N	PRESENT	0
201932	190798	14327T	PARTICIPANT	\N	PRESENT	0
201933	190798	11064N	PARTICIPANT	\N	PRESENT	0
201934	190798	14235Q	PARTICIPANT	\N	PRESENT	0
201935	190798	14059S	PARTICIPANT	\N	PRESENT	0
201936	190798	14069U	PARTICIPANT	\N	PRESENT	0
201937	190798	04040A	PARTICIPANT	\N	PRESENT	0
201938	190798	96004D	PARTICIPANT	\N	PRESENT	0
201939	190798	04047H	PARTICIPANT	\N	PRESENT	0
201940	190798	14209N	PARTICIPANT	\N	PRESENT	0
201941	190798	14111D	PARTICIPANT	\N	PRESENT	0
201952	190798	89017R	PARTICIPANT	\N	PRESENT	0
201953	190798	08061X	PARTICIPANT	\N	PRESENT	0
201972	190798	08068F	PARTICIPANT	\N	PRESENT	0
201973	190798	14083S	PARTICIPANT	\N	PRESENT	0
201974	190798	01031L	PARTICIPANT	\N	PRESENT	0
201975	190798	14329V	PARTICIPANT	\N	PRESENT	0
201992	190798	18127E	PARTICIPANT	\N	PRESENT	0
201993	190798	14119M	PARTICIPANT	\N	PRESENT	0
202012	190798	98022P	PARTICIPANT	\N	PRESENT	0
202032	190798	14097Y	PARTICIPANT	\N	PRESENT	0
202052	190798	14151M	PARTICIPANT	\N	PRESENT	0
203332	190803	04092N	PARTICIPANT	\N	PRESENT	0
203333	190803	98024R	PARTICIPANT	\N	PRESENT	0
203334	190803	14227Q	PARTICIPANT	\N	PRESENT	0
203335	190803	08052W	PARTICIPANT	\N	PRESENT	0
203336	190803	11109J	PARTICIPANT	\N	PRESENT	0
203337	190803	11089X	PARTICIPANT	\N	PRESENT	0
203338	190803	08068F	PARTICIPANT	\N	PRESENT	0
203339	190803	04053F	PARTICIPANT	\N	PRESENT	0
203340	190803	04045F	PARTICIPANT	\N	PRESENT	0
203341	190803	11063M	PARTICIPANT	\N	PRESENT	0
203342	190803	11067R	PARTICIPANT	\N	PRESENT	0
203343	190803	14215L	PARTICIPANT	\N	PRESENT	0
203344	190803	04033B	PARTICIPANT	\N	PRESENT	0
203345	190803	08019V	PARTICIPANT	\N	PRESENT	0
203346	190803	14261S	PARTICIPANT	\N	PRESENT	0
203347	190803	14033T	PARTICIPANT	\N	PRESENT	0
203348	190803	11091R	PARTICIPANT	\N	PRESENT	0
203349	190803	11090Q	PARTICIPANT	\N	PRESENT	0
203350	190803	11097X	PARTICIPANT	\N	PRESENT	0
203351	190803	14265W	PARTICIPANT	\N	PRESENT	0
203352	190803	14255U	PARTICIPANT	\N	PRESENT	0
203353	190803	04086Q	PARTICIPANT	\N	PRESENT	0
203354	190803	04059M	PARTICIPANT	\N	PRESENT	0
203355	190803	14081Q	PARTICIPANT	\N	PRESENT	0
203356	190803	11061K	PARTICIPANT	\N	PRESENT	0
203357	190803	14207L	PARTICIPANT	\N	PRESENT	0
203358	190803	14231L	PARTICIPANT	\N	PRESENT	0
203359	190803	12042Y	PARTICIPANT	\N	PRESENT	0
203360	190803	95063L	PARTICIPANT	\N	PRESENT	0
203361	190803	14281W	PARTICIPANT	\N	PRESENT	0
203362	190803	95015C	PARTICIPANT	\N	PRESENT	0
203363	190803	08043V	PARTICIPANT	\N	PRESENT	0
203364	190803	14217N	PARTICIPANT	\N	PRESENT	0
203365	190803	11031D	PARTICIPANT	\N	PRESENT	0
203366	190803	04088S	PARTICIPANT	\N	PRESENT	0
203367	190803	11034G	PARTICIPANT	\N	PRESENT	0
203368	190803	04061F	PARTICIPANT	\N	PRESENT	0
203369	190803	04049K	PARTICIPANT	\N	PRESENT	0
203370	190803	11107G	PARTICIPANT	\N	PRESENT	0
203371	190803	14121F	PARTICIPANT	\N	PRESENT	0
203372	190803	07029T	PARTICIPANT	\N	PRESENT	0
203373	190803	14195A	PARTICIPANT	\N	PRESENT	0
203374	190803	10006L	PARTICIPANT	\N	PRESENT	0
203375	190803	19251M	PARTICIPANT	\N	PRESENT	0
203376	190803	11036J	PARTICIPANT	\N	PRESENT	0
203377	190803	11077T	PARTICIPANT	\N	PRESENT	0
203378	190803	14257W	PARTICIPANT	\N	PRESENT	0
203379	190803	11029K	PARTICIPANT	\N	PRESENT	0
203380	190803	14034U	PARTICIPANT	\N	PRESENT	0
203381	190803	14053L	PARTICIPANT	\N	PRESENT	0
203382	190803	01059Y	PARTICIPANT	\N	PRESENT	0
203392	190803	14271U	PARTICIPANT	\N	PRESENT	0
203393	190803	14083S	PARTICIPANT	\N	PRESENT	0
203394	190803	14151M	PARTICIPANT	\N	PRESENT	0
203395	190803	14073Q	PARTICIPANT	\N	PRESENT	0
203396	190803	04043D	PARTICIPANT	\N	PRESENT	0
203412	190803	14157T	PARTICIPANT	\N	PRESENT	0
203413	190803	14159V	PARTICIPANT	\N	PRESENT	0
203414	190803	14133K	PARTICIPANT	\N	PRESENT	0
203415	190803	16813M	PARTICIPANT	\N	PRESENT	0
203416	190803	14357A	PARTICIPANT	\N	PRESENT	0
203417	190803	80013X	PARTICIPANT	\N	PRESENT	0
203418	190803	14219Q	PARTICIPANT	\N	PRESENT	0
203419	190803	14269B	PARTICIPANT	\N	PRESENT	0
203420	190803	08016S	PARTICIPANT	\N	PRESENT	0
203432	190803	11053K	PARTICIPANT	\N	PRESENT	0
203433	190803	01024M	PARTICIPANT	\N	PRESENT	0
203434	190803	08010L	PARTICIPANT	\N	PRESENT	0
203435	190803	04067M	PARTICIPANT	\N	PRESENT	0
203445	190803	04056J	PARTICIPANT	\N	PRESENT	0
203446	190803	08055A	PARTICIPANT	\N	PRESENT	0
203447	190803	08017T	PARTICIPANT	\N	PRESENT	0
203455	190803	98035U	PARTICIPANT	\N	PRESENT	0
203456	190803	04085P	PARTICIPANT	\N	PRESENT	0
203457	190803	14079W	PARTICIPANT	\N	PRESENT	0
203472	190803	04081K	PARTICIPANT	\N	PRESENT	0
203473	190803	11054L	PARTICIPANT	\N	PRESENT	0
203474	190803	14097Y	PARTICIPANT	\N	PRESENT	0
203492	190803	18127E	PARTICIPANT	\N	PRESENT	0
203512	190803	11025F	PARTICIPANT	\N	PRESENT	0
203604	190804	04066L	PARTICIPANT	\N	PRESENT	0
203612	190804	11063M	PARTICIPANT	\N	PRESENT	0
203613	190804	11031D	PARTICIPANT	\N	PRESENT	0
203614	190804	14151M	PARTICIPANT	\N	PRESENT	0
203615	190804	14227Q	PARTICIPANT	\N	PRESENT	0
203616	190804	08052W	PARTICIPANT	\N	PRESENT	0
203617	190804	04059M	PARTICIPANT	\N	PRESENT	0
203618	190804	08019V	PARTICIPANT	\N	PRESENT	0
203619	190804	08010L	PARTICIPANT	\N	PRESENT	0
203620	190804	14079W	PARTICIPANT	\N	PRESENT	0
203621	190804	14271U	PARTICIPANT	\N	PRESENT	0
203622	190804	14195A	PARTICIPANT	\N	PRESENT	0
203623	190804	11097X	PARTICIPANT	\N	PRESENT	0
203624	190804	14269B	PARTICIPANT	\N	PRESENT	0
203625	190804	14034U	PARTICIPANT	\N	PRESENT	0
203626	190804	98053W	PARTICIPANT	\N	PRESENT	0
203627	190804	04092N	PARTICIPANT	\N	PRESENT	0
203628	190804	98024R	PARTICIPANT	\N	PRESENT	0
203629	190804	04085P	PARTICIPANT	\N	PRESENT	0
203630	190804	11034G	PARTICIPANT	\N	PRESENT	0
203631	190804	18127E	PARTICIPANT	\N	PRESENT	0
203632	190804	14053L	PARTICIPANT	\N	PRESENT	0
203633	190804	04053F	PARTICIPANT	\N	PRESENT	0
203634	190804	11090Q	PARTICIPANT	\N	PRESENT	0
203635	190804	04067M	PARTICIPANT	\N	PRESENT	0
203636	190804	00003C	PARTICIPANT	\N	PRESENT	0
203637	190804	04043D	PARTICIPANT	\N	PRESENT	0
203638	190804	04081K	PARTICIPANT	\N	PRESENT	0
203639	190804	14261S	PARTICIPANT	\N	PRESENT	0
203640	190804	12042Y	PARTICIPANT	\N	PRESENT	0
203652	190804	11089X	PARTICIPANT	\N	PRESENT	0
203653	190804	11054L	PARTICIPANT	\N	PRESENT	0
203654	190804	07029T	PARTICIPANT	\N	PRESENT	0
203655	190804	04033B	PARTICIPANT	\N	PRESENT	0
203656	190804	04086Q	PARTICIPANT	\N	PRESENT	0
166575	166574	14133K	PARTICIPANT	\N	PRESENT	0
166576	166574	96004D	PRESIDENT	0	PRESENT	0
166577	166574	11040E	PARTICIPANT	\N	PRESENT	0
166578	166574	14089Y	PARTICIPANT	\N	PRESENT	0
166579	166574	14079W	PARTICIPANT	\N	PRESENT	0
166580	166574	11035H	PARTICIPANT	\N	PRESENT	0
166581	166574	11083R	PARTICIPANT	\N	PRESENT	0
166582	166574	14097Y	PARTICIPANT	\N	PRESENT	0
166583	166574	11026G	PARTICIPANT	\N	PRESENT	0
166584	166574	98046X	PARTICIPANT	\N	PRESENT	0
166585	166574	14001X	PARTICIPANT	\N	PRESENT	0
166586	166574	04057K	PARTICIPANT	\N	PRESENT	0
166587	166574	04080J	PARTICIPANT	\N	PRESENT	0
166588	166574	01016M	PARTICIPANT	\N	PRESENT	0
166590	166574	10015M	PARTICIPANT	\N	PRESENT	0
166591	166574	11012A	PARTICIPANT	\N	PRESENT	0
166592	166574	04045F	PARTICIPANT	\N	PRESENT	0
166593	166574	98035U	PARTICIPANT	\N	PRESENT	0
166594	166574	04034C	PARTICIPANT	\N	PRESENT	0
167473	167472	14199E	PARTICIPANT	\N	PRESENT	0
167477	167476	14199E	PARTICIPANT	\N	PRESENT	0
170096	170095	05008E	PARTICIPANT	\N	PRESENT	0
170097	170095	14065Q	PARTICIPANT	\N	PRESENT	0
170098	170095	14041T	PARTICIPANT	\N	PRESENT	0
170099	170095	01024M	PARTICIPANT	\N	PRESENT	0
170100	170095	95049N	PARTICIPANT	\N	PRESENT	0
170102	170101	05008E	PARTICIPANT	\N	PRESENT	0
170103	170101	14065Q	PARTICIPANT	\N	PRESENT	0
170105	170104	05008E	PARTICIPANT	\N	PRESENT	0
170106	170104	14065Q	PARTICIPANT	\N	PRESENT	0
170107	170104	11056N	PARTICIPANT	\N	PRESENT	0
170109	170104	01024M	PARTICIPANT	\N	PRESENT	0
170373	170372	95015C	PARTICIPANT	\N	PRESENT	0
170513	170512	01041N	PARTICIPANT	\N	PRESENT	0
170514	170512	08017T	PARTICIPANT	\N	PRESENT	0
170533	170532	01041N	PARTICIPANT	\N	PRESENT	0
170534	170532	08017T	PARTICIPANT	\N	PRESENT	0
170561	170560	04044E	PARTICIPANT	\N	PRESENT	0
181796	167353	14237S	PARTICIPANT	\N	PRESENT	0
181812	167353	01007L	PARTICIPANT	\N	PRESENT	0
181832	167353	95041E	PARTICIPANT	\N	PRESENT	0
181833	167353	11043H	PARTICIPANT	\N	PRESENT	0
181834	167353	14083S	PARTICIPANT	\N	PRESENT	0
181835	167353	14103D	PARTICIPANT	\N	PRESENT	0
181836	167353	14030Q	PARTICIPANT	\N	PRESENT	0
181932	167353	14034U	PARTICIPANT	\N	PRESENT	0
181952	167353	14037X	PARTICIPANT	\N	PRESENT	0
181972	167353	11064N	PARTICIPANT	\N	PRESENT	0
181973	167353	14219Q	PARTICIPANT	\N	PRESENT	0
181992	167353	11084S	PARTICIPANT	\N	PRESENT	0
182682	182492	01008M	PARTICIPANT	\N	EXCUSE	0
182936	165000	11082Q	PARTICIPANT	\N	PRESENT	0
182941	165000	14209N	PARTICIPANT	\N	EXCUSE	0
182942	165000	08039A	PARTICIPANT	\N	EXCUSE	0
182948	165000	01058X	PARTICIPANT	\N	EXCUSE	0
182972	165000	11089X	PARTICIPANT	\N	EXCUSE	0
183003	165000	11036J	PARTICIPANT	\N	PRESENT	0
183035	183034	14175V	PARTICIPANT	\N	PRESENT	0
183036	183034	14085U	PARTICIPANT	\N	PRESENT	0
183037	183034	11042G	PARTICIPANT	\N	PRESENT	0
183038	183034	14159V	PARTICIPANT	\N	PRESENT	0
183039	183034	01057W	PARTICIPANT	\N	PRESENT	0
183041	183040	14175V	PARTICIPANT	\N	PRESENT	0
183042	183040	14085U	PARTICIPANT	\N	PRESENT	0
183043	183040	11042G	PARTICIPANT	\N	PRESENT	0
183044	183040	14159V	PARTICIPANT	\N	PRESENT	0
183046	183045	11042G	PARTICIPANT	\N	PRESENT	0
183047	183045	14159V	PARTICIPANT	\N	PRESENT	0
183053	183052	14259Y	PARTICIPANT	\N	PRESENT	0
183054	183052	11037K	PARTICIPANT	\N	PRESENT	0
183055	183052	04038G	PARTICIPANT	\N	PRESENT	0
183056	183052	11084S	PARTICIPANT	\N	PRESENT	0
183057	183052	95067Q	PARTICIPANT	\N	PRESENT	0
183073	183072	11048N	PARTICIPANT	\N	PRESENT	0
184360	184359	11031D	PARTICIPANT	\N	PRESENT	0
184361	184359	08041T	PARTICIPANT	\N	PRESENT	0
184362	184359	14223L	PARTICIPANT	\N	PRESENT	0
187873	187872	08009T	PARTICIPANT	\N	PRESENT	0
187874	187872	14169X	PARTICIPANT	\N	PRESENT	0
187875	187872	11107G	PARTICIPANT	\N	PRESENT	0
187876	187872	08060W	PARTICIPANT	\N	PRESENT	0
187877	187872	14107H	PARTICIPANT	\N	PRESENT	0
187878	187872	02002K	PARTICIPANT	\N	PRESENT	0
187879	187872	11065P	PARTICIPANT	\N	PRESENT	0
187880	187872	04097T	PARTICIPANT	\N	PRESENT	0
188692	187658	14030Q	PARTICIPANT	\N	PRESENT	0
188693	187658	11083R	PARTICIPANT	\N	PRESENT	0
188694	187658	14135M	PARTICIPANT	\N	PRESENT	0
189803	189802	05008E	PARTICIPANT	\N	PRESENT	0
189805	189804	05008E	PARTICIPANT	\N	PRESENT	0
189806	189804	01047U	PARTICIPANT	\N	PRESENT	0
189808	189807	05008E	PARTICIPANT	\N	PRESENT	0
189821	189820	05008E	PARTICIPANT	\N	PRESENT	0
190633	190632	11074Q	PARTICIPANT	\N	PRESENT	0
190634	190632	11083R	PARTICIPANT	\N	PRESENT	0
190719	190497	98035U	PARTICIPANT	\N	PRESENT	0
190720	190497	14111D	PARTICIPANT	\N	PRESENT	0
190721	190497	11010L	PARTICIPANT	\N	PRESENT	0
190722	190497	07034Q	PARTICIPANT	\N	PRESENT	0
190723	190497	11026G	PARTICIPANT	\N	PRESENT	0
190724	190497	14001X	PARTICIPANT	\N	PRESENT	0
190725	190497	19253P	PARTICIPANT	\N	PRESENT	0
190726	190497	19251M	PARTICIPANT	\N	PRESENT	0
190727	190497	01024M	PARTICIPANT	\N	PRESENT	0
190728	190497	04044E	PARTICIPANT	\N	PRESENT	0
190729	190497	04047H	PARTICIPANT	\N	PRESENT	0
190730	190497	05008E	PRESIDENT	0	PRESENT	0
190731	190497	11035H	PARTICIPANT	\N	PRESENT	0
190732	190497	14275Y	PARTICIPANT	\N	PRESENT	0
190733	190497	95063L	PARTICIPANT	\N	PRESENT	0
190734	190497	04074L	PARTICIPANT	\N	PRESENT	0
190735	190497	04056J	PARTICIPANT	\N	PRESENT	0
190736	190497	14041T	PARTICIPANT	\N	PRESENT	0
190737	190497	14147R	PARTICIPANT	\N	PRESENT	0
190738	190497	14215L	PARTICIPANT	\N	PRESENT	0
190739	190497	11049P	PARTICIPANT	\N	PRESENT	0
190740	190497	14259Y	PARTICIPANT	\N	PRESENT	0
190741	190497	95049N	PARTICIPANT	\N	PRESENT	0
190742	190497	11072N	PARTICIPANT	\N	PRESENT	0
190743	190497	08025T	PARTICIPANT	\N	EXCUSE	0
191595	190757	11091R	PARTICIPANT	\N	PRESENT	0
191596	190757	14249W	PARTICIPANT	\N	PRESENT	0
191614	190757	99004R	PARTICIPANT	\N	PRESENT	0
191615	190757	08069G	PARTICIPANT	\N	PRESENT	0
191616	190757	14038Y	PARTICIPANT	\N	PRESENT	0
191617	190757	14147R	PARTICIPANT	\N	PRESENT	0
191618	190757	11097X	PARTICIPANT	\N	PRESENT	0
191619	190757	14030Q	PARTICIPANT	\N	PRESENT	0
191620	190757	04044E	PARTICIPANT	\N	PRESENT	0
191621	190757	01047U	PARTICIPANT	\N	PRESENT	0
191622	190757	14034U	PARTICIPANT	\N	PRESENT	0
191623	190757	04061F	PARTICIPANT	\N	PRESENT	0
191632	190532	07029T	PARTICIPANT	\N	PRESENT	0
191633	190532	01016M	PARTICIPANT	\N	PRESENT	0
191634	190532	04055H	PARTICIPANT	\N	PRESENT	0
195252	190779	14363X	PARTICIPANT	\N	PRESENT	0
195253	190779	11031D	PARTICIPANT	\N	PRESENT	0
195254	190779	11056N	PARTICIPANT	\N	PRESENT	0
195255	190779	11034G	PARTICIPANT	\N	PRESENT	0
195256	190779	14235Q	PARTICIPANT	\N	PRESENT	0
195257	190779	14135M	PARTICIPANT	\N	PRESENT	0
195258	190779	11063M	PARTICIPANT	\N	PRESENT	0
195259	190779	14033T	PARTICIPANT	\N	PRESENT	0
195260	190779	14361V	PARTICIPANT	\N	PRESENT	0
195261	190779	11098Y	PARTICIPANT	\N	PRESENT	0
195262	190779	01015L	PARTICIPANT	\N	PRESENT	0
195263	190779	14193X	PARTICIPANT	\N	PRESENT	0
195264	190779	07034Q	PARTICIPANT	\N	PRESENT	0
195265	190779	11100Y	PARTICIPANT	\N	PRESENT	0
195266	190779	01058X	PARTICIPANT	\N	PRESENT	0
195267	190779	11040E	PARTICIPANT	\N	PRESENT	0
195268	190779	04081K	PARTICIPANT	\N	PRESENT	0
195269	190779	04071H	PARTICIPANT	\N	PRESENT	0
195270	190779	08016S	PARTICIPANT	\N	PRESENT	0
195271	190779	14069U	PARTICIPANT	\N	PRESENT	0
195272	190779	98035U	PARTICIPANT	\N	PRESENT	0
195273	190779	04056J	PARTICIPANT	\N	PRESENT	0
195274	190779	01016M	PARTICIPANT	\N	PRESENT	0
195275	190779	95041E	PARTICIPANT	\N	PRESENT	0
195276	190779	08012N	PARTICIPANT	\N	PRESENT	0
195277	190779	98046X	PARTICIPANT	\N	PRESENT	0
195278	190779	95059Q	PARTICIPANT	\N	PRESENT	0
195279	190779	11045K	PARTICIPANT	\N	PRESENT	0
195280	190779	08025T	PARTICIPANT	\N	PRESENT	0
195281	190779	14111D	PARTICIPANT	\N	PRESENT	0
195282	190779	14151M	PARTICIPANT	\N	PRESENT	0
195283	190779	11101A	PARTICIPANT	\N	PRESENT	0
207729	207294	14081Q	PARTICIPANT	\N	PRESENT	0
207730	207294	19413M	PARTICIPANT	\N	PRESENT	0
207731	207294	80013X	PARTICIPANT	\N	PRESENT	0
207732	207294	19631V	PARTICIPANT	\N	PRESENT	0
207733	207294	19637C	PARTICIPANT	\N	PRESENT	0
207734	207294	11099A	PARTICIPANT	\N	PRESENT	0
207735	207294	08068F	PARTICIPANT	\N	PRESENT	0
207736	207294	04049K	PARTICIPANT	\N	PRESENT	0
207737	207294	19705W	PARTICIPANT	\N	PRESENT	0
207738	207294	19707Y	PARTICIPANT	\N	PRESENT	0
207739	207294	08015R	PARTICIPANT	\N	PRESENT	0
207740	207294	19347U	PARTICIPANT	\N	PRESENT	0
207741	207294	14193X	PARTICIPANT	\N	PRESENT	0
207742	207294	08019V	PARTICIPANT	\N	PRESENT	0
207743	207294	14197C	PARTICIPANT	\N	PRESENT	0
207744	207294	14157T	PARTICIPANT	\N	PRESENT	0
207745	207294	19369B	PARTICIPANT	\N	PRESENT	0
207746	207294	08028W	PARTICIPANT	\N	PRESENT	0
207747	207294	19563B	PARTICIPANT	\N	PRESENT	0
207748	207294	14265W	PARTICIPANT	\N	PRESENT	0
207749	207294	14329V	PARTICIPANT	\N	PRESENT	0
207750	207294	19591F	PARTICIPANT	\N	PRESENT	0
207751	207294	19467C	PARTICIPANT	\N	PRESENT	0
207752	207294	14187A	PARTICIPANT	\N	PRESENT	0
207753	207294	08038Y	PARTICIPANT	\N	PRESENT	0
207754	207294	08062Y	PARTICIPANT	\N	PRESENT	0
207755	207294	19695N	PARTICIPANT	\N	PRESENT	0
207756	207294	11090Q	PRESIDENT	0	PRESENT	0
207757	207294	01025N	PARTICIPANT	\N	PRESENT	0
207758	207294	14033T	PARTICIPANT	\N	PRESENT	0
207759	207294	19269X	PARTICIPANT	\N	PRESENT	0
207760	207294	14205J	PARTICIPANT	\N	PRESENT	0
207761	207294	04088S	PARTICIPANT	\N	PRESENT	0
207762	207294	11056N	PARTICIPANT	\N	PRESENT	0
207763	207294	04089T	PARTICIPANT	\N	PRESENT	0
207764	207294	14115H	PARTICIPANT	\N	PRESENT	0
207765	207294	19507S	PARTICIPANT	\N	PRESENT	0
207766	207294	08009T	PARTICIPANT	\N	PRESENT	0
207767	207294	14207L	PARTICIPANT	\N	PRESENT	0
207768	207294	04043D	PARTICIPANT	\N	PRESENT	0
207769	207294	04061F	PARTICIPANT	\N	PRESENT	0
207770	207294	17589D	PARTICIPANT	\N	PRESENT	0
207771	207294	19619A	PARTICIPANT	\N	PRESENT	0
207772	207294	14257W	PARTICIPANT	\N	PRESENT	0
207773	207294	19515S	PARTICIPANT	\N	PRESENT	0
207774	207294	14135M	PARTICIPANT	\N	EXCUSE	0
207775	207294	19511N	PARTICIPANT	\N	EXCUSE	0
207776	207294	19295A	PARTICIPANT	\N	EXCUSE	0
208427	208080	95067Q	PARTICIPANT	\N	PRESENT	0
208430	208429	04049K	PARTICIPANT	\N	PRESENT	0
208432	208431	04049K	PARTICIPANT	\N	PRESENT	0
208434	208433	04049K	PARTICIPANT	\N	PRESENT	0
208450	208448	19697Q	PARTICIPANT	\N	PRESENT	0
208451	208448	11067R	PARTICIPANT	\N	PRESENT	0
208452	208448	14355X	PARTICIPANT	\N	PRESENT	0
208453	208448	14223L	PARTICIPANT	\N	PRESENT	0
208454	208448	14227Q	PARTICIPANT	\N	PRESENT	0
208455	208448	19675J	PARTICIPANT	\N	PRESENT	0
208456	208448	17779H	PARTICIPANT	\N	PRESENT	0
208457	208448	19703U	PARTICIPANT	\N	PRESENT	0
208458	208448	14239U	PARTICIPANT	\N	PRESENT	0
208459	208448	14087W	PARTICIPANT	\N	PRESENT	0
208460	208448	14281W	PARTICIPANT	\N	PRESENT	0
208461	208448	14042U	PARTICIPANT	\N	PRESENT	0
208462	208448	19367Y	PARTICIPANT	\N	PRESENT	0
208463	208448	14213J	PARTICIPANT	\N	PRESENT	0
208464	208448	14217N	PARTICIPANT	\N	PRESENT	0
208465	208448	10006L	PARTICIPANT	\N	PRESENT	0
208466	208448	19683J	PARTICIPANT	\N	PRESENT	0
208467	208448	98024R	PARTICIPANT	\N	PRESENT	0
208468	208448	01034P	PARTICIPANT	\N	PRESENT	0
208469	208448	04092N	PRESIDENT	0	PRESENT	0
208470	208448	08052W	PARTICIPANT	\N	PRESENT	0
208471	208448	19663E	PARTICIPANT	\N	PRESENT	0
208472	208448	19691J	PARTICIPANT	\N	PRESENT	0
208473	208448	19715Y	PARTICIPANT	\N	PRESENT	0
208474	208448	19717B	PARTICIPANT	\N	PRESENT	0
208475	208448	19723Y	PARTICIPANT	\N	PRESENT	0
208476	208448	11103C	PARTICIPANT	\N	PRESENT	0
208477	208448	11031D	PARTICIPANT	\N	EXCUSE	0
208478	208064	98035U	PARTICIPANT	\N	PRESENT	0
208479	208064	14065Q	PARTICIPANT	\N	PRESENT	0
208480	208064	14111D	PARTICIPANT	\N	PRESENT	0
208481	208064	11010L	PARTICIPANT	\N	PRESENT	0
208482	208064	07034Q	PARTICIPANT	\N	PRESENT	0
208483	208064	08045X	PARTICIPANT	\N	PRESENT	0
208484	208064	19543W	PARTICIPANT	\N	PRESENT	0
208485	208064	01024M	PARTICIPANT	\N	PRESENT	0
208486	208064	04038G	PARTICIPANT	\N	PRESENT	0
208487	208064	19585H	PARTICIPANT	\N	PRESENT	0
208488	208064	19673G	PARTICIPANT	\N	PRESENT	0
208489	208064	19719D	PARTICIPANT	\N	PRESENT	0
208490	208064	19447X	PARTICIPANT	\N	PRESENT	0
208491	208064	14231L	PARTICIPANT	\N	PRESENT	0
208492	208064	05008E	PRESIDENT	0	PRESENT	0
208493	208064	14089Y	PARTICIPANT	\N	PRESENT	0
208494	208064	19729F	PARTICIPANT	\N	PRESENT	0
208495	208064	19489J	PARTICIPANT	\N	PRESENT	0
208496	208064	95063L	PARTICIPANT	\N	PRESENT	0
208497	208064	14069U	PARTICIPANT	\N	PRESENT	0
208498	208064	14151M	PARTICIPANT	\N	PRESENT	0
208499	208064	14215L	PARTICIPANT	\N	PRESENT	0
208500	208064	11072N	PARTICIPANT	\N	PRESENT	0
208501	208064	14053L	PARTICIPANT	\N	EXCUSE	0
208502	208064	14275Y	PARTICIPANT	\N	EXCUSE	0
208503	208064	04044E	PARTICIPANT	\N	EXCUSE	0
208504	208064	19483C	PARTICIPANT	\N	EXCUSE	0
208505	208064	04047H	PARTICIPANT	\N	EXCUSE	0
208506	208064	04008A	PARTICIPANT	\N	EXCUSE	0
208507	208448	19569H	PARTICIPANT	\N	PRESENT	0
208508	208448	14026U	PARTICIPANT	\N	PRESENT	0
208509	208448	11063M	PARTICIPANT	\N	PRESENT	0
208510	208448	19553Y	PARTICIPANT	\N	PRESENT	0
208511	208448	19679N	PARTICIPANT	\N	PRESENT	0
208512	208448	14195A	PARTICIPANT	\N	PRESENT	0
208513	208448	19335Q	PARTICIPANT	\N	PRESENT	0
208514	208448	11045K	PARTICIPANT	\N	PRESENT	0
208515	208448	08041T	PARTICIPANT	\N	PRESENT	0
208516	208448	19727D	PARTICIPANT	\N	PRESENT	0
208517	208448	14119M	PARTICIPANT	\N	PRESENT	0
208518	208448	14071N	PARTICIPANT	\N	PRESENT	0
208519	208448	11097X	PARTICIPANT	\N	PRESENT	0
208521	208448	04045F	PARTICIPANT	\N	PRESENT	0
208523	208448	19575F	PARTICIPANT	\N	EXCUSE	0
208532	207682	11077T	PARTICIPANT	\N	PRESENT	0
208533	207682	19585H	PARTICIPANT	\N	PRESENT	0
208534	207682	19629C	PARTICIPANT	\N	PRESENT	0
208535	207682	19681G	PARTICIPANT	\N	PRESENT	0
208536	207682	19737F	PARTICIPANT	\N	PRESENT	0
208537	207682	19507S	PARTICIPANT	\N	PRESENT	0
208538	207682	19467C	PARTICIPANT	\N	PRESENT	0
208539	207682	19677L	PARTICIPANT	\N	PRESENT	0
208540	207682	07034Q	PARTICIPANT	\N	PRESENT	0
208541	207682	19387D	PARTICIPANT	\N	PRESENT	0
208542	207682	19691J	PARTICIPANT	\N	PRESENT	0
208543	207682	14147R	PARTICIPANT	\N	PRESENT	0
208544	207682	14079W	PARTICIPANT	\N	PRESENT	0
208545	207682	18083K	PARTICIPANT	\N	PRESENT	0
208546	207682	14191V	PARTICIPANT	\N	PRESENT	0
208548	207682	08068F	PARTICIPANT	\N	PRESENT	0
208549	207682	14111D	PARTICIPANT	\N	PRESENT	0
208550	207682	14241N	PARTICIPANT	\N	PRESENT	0
208551	207682	19563B	PARTICIPANT	\N	PRESENT	0
208552	207682	19521Q	PARTICIPANT	\N	PRESENT	0
208553	207682	04047H	PARTICIPANT	\N	PRESENT	0
208554	207682	19447X	PARTICIPANT	\N	PRESENT	0
208555	207682	19489J	PARTICIPANT	\N	PRESENT	0
208556	207682	14065Q	PARTICIPANT	\N	PRESENT	0
208557	207682	19593H	PARTICIPANT	\N	PRESENT	0
208558	207682	19565D	PARTICIPANT	\N	PRESENT	0
208559	207682	04038G	PARTICIPANT	\N	PRESENT	0
208560	207682	15447F	PARTICIPANT	\N	PRESENT	0
208561	207682	19679N	PARTICIPANT	\N	PRESENT	0
208562	207682	14151M	PARTICIPANT	\N	PRESENT	0
208563	207682	01028R	PARTICIPANT	\N	PRESENT	0
208564	207682	19253P	PARTICIPANT	\N	PRESENT	0
208565	207682	19611R	PARTICIPANT	\N	PRESENT	0
208566	207682	19713W	PARTICIPANT	\N	PRESENT	0
208567	207682	19479G	PARTICIPANT	\N	PRESENT	0
208568	207682	14205J	PARTICIPANT	\N	PRESENT	0
208569	207682	14327T	PARTICIPANT	\N	PRESENT	0
208570	207682	19441R	PARTICIPANT	\N	PRESENT	0
208571	207682	19651A	PARTICIPANT	\N	PRESENT	0
208572	207682	19725B	PARTICIPANT	\N	PRESENT	0
208573	207682	08020N	PARTICIPANT	\N	PRESENT	0
208574	207682	19543W	PARTICIPANT	\N	PRESENT	0
208575	207682	14083S	PARTICIPANT	\N	PRESENT	0
208576	207682	14061L	PARTICIPANT	\N	PRESENT	0
165753	165752	01008M	PARTICIPANT	\N	PRESENT	0
165754	165752	11036J	PARTICIPANT	\N	PRESENT	0
166259	166258	14133K	PARTICIPANT	\N	PRESENT	0
165756	165752	14013P	PARTICIPANT	\N	EXCUSE	0
165757	165752	08068F	PARTICIPANT	\N	PRESENT	0
165758	165752	14207L	PARTICIPANT	\N	PRESENT	0
165759	165752	11101A	PARTICIPANT	\N	PRESENT	0
165760	165752	90003B	PARTICIPANT	\N	PRESENT	0
165761	165752	08028W	PARTICIPANT	\N	PRESENT	0
165762	165752	80013X	PARTICIPANT	\N	PRESENT	0
165763	165752	14357A	PARTICIPANT	\N	PRESENT	0
165764	165752	08038Y	PARTICIPANT	\N	PRESENT	0
165765	165752	04089T	PARTICIPANT	\N	PRESENT	0
165766	165752	14197C	PARTICIPANT	\N	PRESENT	0
166012	165952	08055A	PARTICIPANT	\N	PRESENT	0
165768	165752	14187A	PARTICIPANT	\N	PRESENT	0
165769	165752	14033T	PARTICIPANT	\N	PRESENT	0
166013	165952	14093U	PARTICIPANT	\N	PRESENT	0
166014	165952	14030Q	PARTICIPANT	\N	PRESENT	0
165772	165752	04049K	PARTICIPANT	\N	PRESENT	0
166254	166252	01016M	PARTICIPANT	\N	PRESENT	0
165774	165752	11111C	PARTICIPANT	\N	PRESENT	0
165775	165752	08015R	PARTICIPANT	\N	PRESENT	0
165776	165752	11100Y	PRESIDENT	0	PRESENT	0
165777	165752	01061S	PARTICIPANT	\N	EXCUSE	0
166016	165952	08060W	PARTICIPANT	\N	PRESENT	0
165779	165752	01043Q	PARTICIPANT	\N	PRESENT	0
166017	165952	11095V	PARTICIPANT	\N	EXCUSE	0
166018	165952	14038Y	PARTICIPANT	\N	PRESENT	0
166256	166255	14133K	PARTICIPANT	\N	PRESENT	0
165783	165752	14257W	PARTICIPANT	\N	PRESENT	0
165784	165752	08021P	PARTICIPANT	\N	EXCUSE	0
165785	165752	04088S	PARTICIPANT	\N	PRESENT	0
165786	165752	98050T	PARTICIPANT	\N	PRESENT	0
166257	166255	01016M	PARTICIPANT	\N	PRESENT	0
165788	165752	11046L	PARTICIPANT	\N	PRESENT	0
165789	165752	01058X	PARTICIPANT	\N	PRESENT	0
165790	165752	11094U	PARTICIPANT	\N	PRESENT	0
165791	165752	11066Q	PARTICIPANT	\N	PRESENT	0
166020	165952	98023Q	PARTICIPANT	\N	PRESENT	0
166260	166258	01016M	PARTICIPANT	\N	PRESENT	0
166022	165952	01015L	PARTICIPANT	\N	PRESENT	0
166023	165952	11107G	PARTICIPANT	\N	PRESENT	0
166262	166261	14133K	PARTICIPANT	\N	PRESENT	0
166025	165952	02002K	PARTICIPANT	\N	PRESENT	0
166263	166261	01016M	PARTICIPANT	\N	PRESENT	0
166270	166269	14133K	PARTICIPANT	\N	PRESENT	0
166272	166269	01016M	PARTICIPANT	\N	PRESENT	0
166276	166275	01016M	PARTICIPANT	\N	PRESENT	0
166030	165952	11059R	PARTICIPANT	\N	PRESENT	0
166031	165952	14219Q	PARTICIPANT	\N	PRESENT	0
166032	165952	80027E	PARTICIPANT	\N	PRESENT	0
166033	165952	14031R	PARTICIPANT	\N	PRESENT	0
166034	165952	08009T	PRESIDENT	0	PRESENT	0
166035	165952	08062Y	PARTICIPANT	\N	PRESENT	0
166278	166277	14133K	PARTICIPANT	\N	PRESENT	0
166037	165952	92039X	PARTICIPANT	\N	PRESENT	0
166038	165952	08042U	PARTICIPANT	\N	PRESENT	0
166039	165952	14169X	PARTICIPANT	\N	PRESENT	0
166040	165952	14237S	PARTICIPANT	\N	PRESENT	0
166041	165952	13002U	PARTICIPANT	\N	PRESENT	0
166042	165952	05012A	PARTICIPANT	\N	PRESENT	0
166279	166277	01016M	PARTICIPANT	\N	PRESENT	0
166044	165952	14135M	PARTICIPANT	\N	PRESENT	0
166346	166178	92031P	PARTICIPANT	\N	EXCUSE	0
166046	165952	95062K	PARTICIPANT	\N	PRESENT	0
166047	165952	14107H	PARTICIPANT	\N	PRESENT	0
166048	165952	14051J	PARTICIPANT	\N	PRESENT	0
166049	165952	14157T	PARTICIPANT	\N	PRESENT	0
169535	157435	11072N	PARTICIPANT	\N	PRESENT	0
171653	171652	14261S	PARTICIPANT	\N	PRESENT	0
171654	171652	08055A	PARTICIPANT	\N	PRESENT	0
171693	171692	01008M	PARTICIPANT	\N	PRESENT	0
169539	157435	95062K	PARTICIPANT	\N	EXCUSE	0
169540	157435	14017T	PARTICIPANT	\N	EXCUSE	0
171656	171652	14030Q	PARTICIPANT	\N	PRESENT	0
169542	157435	11071M	PARTICIPANT	\N	PRESENT	0
171694	171692	11036J	PARTICIPANT	\N	PRESENT	0
171732	171692	14193X	PARTICIPANT	\N	PRESENT	0
171696	171692	14013P	PARTICIPANT	\N	PRESENT	0
169720	169718	14199E	PARTICIPANT	\N	PRESENT	0
169807	169806	14073Q	PARTICIPANT	\N	PRESENT	0
169808	169806	01028R	PARTICIPANT	\N	PRESENT	0
169809	169806	04056J	PARTICIPANT	\N	PRESENT	0
169810	169806	95067Q	PARTICIPANT	\N	PRESENT	0
171697	171692	08068F	PARTICIPANT	\N	PRESENT	0
171659	171652	11095V	PARTICIPANT	\N	EXCUSE	0
171660	171652	14038Y	PARTICIPANT	\N	PRESENT	0
171698	171692	14207L	PARTICIPANT	\N	PRESENT	0
171699	171692	11101A	PARTICIPANT	\N	PRESENT	0
171700	171692	90003B	PARTICIPANT	\N	PRESENT	0
171664	171652	01015L	PARTICIPANT	\N	PRESENT	0
171665	171652	11107G	PARTICIPANT	\N	PRESENT	0
171701	171692	08028W	PARTICIPANT	\N	PRESENT	0
171667	171652	02002K	PARTICIPANT	\N	PRESENT	0
171668	171652	01022K	PARTICIPANT	\N	PRESENT	0
171702	171692	80013X	PARTICIPANT	\N	PRESENT	0
171703	171692	14357A	PARTICIPANT	\N	EXCUSE	0
171704	171692	08038Y	PARTICIPANT	\N	PRESENT	0
171672	171652	11059R	PARTICIPANT	\N	PRESENT	0
171673	171652	14219Q	PARTICIPANT	\N	PRESENT	0
171674	171652	80027E	PARTICIPANT	\N	PRESENT	0
171675	171652	14031R	PARTICIPANT	\N	PRESENT	0
171676	171652	08009T	PRESIDENT	0	PRESENT	0
171677	171652	08062Y	PARTICIPANT	\N	PRESENT	0
171678	171652	14221J	PARTICIPANT	\N	PRESENT	0
171679	171652	92039X	PARTICIPANT	\N	PRESENT	0
171733	171692	04061F	PARTICIPANT	\N	PRESENT	0
171681	171652	14169X	PARTICIPANT	\N	PRESENT	0
171682	171652	14237S	PARTICIPANT	\N	PRESENT	0
176677	176676	14133K	PARTICIPANT	\N	PRESENT	0
171684	171652	05012A	PARTICIPANT	\N	PRESENT	0
171707	171692	11110B	PARTICIPANT	\N	PRESENT	0
171686	171652	14135M	PARTICIPANT	\N	PRESENT	0
171687	171652	14331P	PARTICIPANT	\N	PRESENT	0
171688	171652	95062K	PARTICIPANT	\N	PRESENT	0
171689	171652	14107H	PARTICIPANT	\N	PRESENT	0
176678	176676	04047H	PARTICIPANT	\N	PRESENT	0
171691	171652	14157T	PARTICIPANT	\N	PRESENT	0
171708	171692	14187A	PARTICIPANT	\N	PRESENT	0
171709	171692	14033T	PARTICIPANT	\N	PRESENT	0
171710	171692	14081Q	PARTICIPANT	\N	PRESENT	0
176679	176676	14026U	PARTICIPANT	\N	PRESENT	0
171712	171692	04049K	PARTICIPANT	\N	PRESENT	0
171713	171692	04094Q	PARTICIPANT	\N	PRESENT	0
171714	171692	11111C	PARTICIPANT	\N	PRESENT	0
171715	171692	08015R	PARTICIPANT	\N	PRESENT	0
171716	171692	11100Y	PRESIDENT	0	PRESENT	0
176680	176676	14097Y	PARTICIPANT	\N	PRESENT	0
171718	171692	11098Y	PARTICIPANT	\N	PRESENT	0
171719	171692	01043Q	PARTICIPANT	\N	PRESENT	0
176682	176676	14073Q	PARTICIPANT	\N	PRESENT	0
171721	171692	14205J	PARTICIPANT	\N	PRESENT	0
171722	171692	08019V	PARTICIPANT	\N	PRESENT	0
171723	171692	14257W	PARTICIPANT	\N	PRESENT	0
176683	176676	92031P	PARTICIPANT	\N	PRESENT	0
171725	171692	04088S	PARTICIPANT	\N	PRESENT	0
171726	171692	98050T	PARTICIPANT	\N	PRESENT	0
176684	176676	14001X	PARTICIPANT	\N	PRESENT	0
171728	171692	11046L	PARTICIPANT	\N	PRESENT	0
171729	171692	01058X	PARTICIPANT	\N	PRESENT	0
171730	171692	11094U	PARTICIPANT	\N	PRESENT	0
171731	171692	11066Q	PARTICIPANT	\N	PRESENT	0
176685	176676	10015M	PARTICIPANT	\N	PRESENT	0
176686	176676	11012A	PARTICIPANT	\N	PRESENT	0
176687	176676	11066Q	PARTICIPANT	\N	PRESENT	0
176688	176676	14267Y	PARTICIPANT	\N	PRESENT	0
176698	176697	04047H	PARTICIPANT	\N	PRESENT	0
176699	176697	14267Y	PARTICIPANT	\N	PRESENT	0
176700	176697	14026U	PARTICIPANT	\N	PRESENT	0
176701	176697	14073Q	PARTICIPANT	\N	PRESENT	0
176702	176697	11026G	PARTICIPANT	\N	PRESENT	0
176703	176697	92031P	PARTICIPANT	\N	PRESENT	0
176704	176697	14001X	PARTICIPANT	\N	PRESENT	0
176705	176697	10015M	PARTICIPANT	\N	PRESENT	0
176706	176697	11012A	PARTICIPANT	\N	PRESENT	0
177114	177113	14207L	PRESIDENT	0	PRESENT	0
177115	177113	14089Y	PARTICIPANT	\N	EXCUSE	0
177116	177113	14281W	PARTICIPANT	\N	PRESENT	0
177117	177113	14231L	PARTICIPANT	\N	PRESENT	0
177118	177113	04057K	PARTICIPANT	\N	EXCUSE	0
177119	177113	14229S	PARTICIPANT	\N	PRESENT	0
177120	177113	14079W	PARTICIPANT	\N	EXCUSE	0
177121	177113	11029K	PARTICIPANT	\N	EXCUSE	0
177812	165000	04043D	PARTICIPANT	\N	PRESENT	0
178772	178755	10015M	PARTICIPANT	\N	PRESENT	0
178773	178755	04061F	PARTICIPANT	\N	PRESENT	0
178774	178755	11076S	PARTICIPANT	\N	PRESENT	0
203659	190804	14121F	PARTICIPANT	\N	PRESENT	0
203660	190804	14097Y	PARTICIPANT	\N	PRESENT	0
203661	190804	14055N	PARTICIPANT	\N	PRESENT	0
203662	190804	14281W	PARTICIPANT	\N	PRESENT	0
203663	190804	11091R	PARTICIPANT	\N	PRESENT	0
203664	190804	08055A	PARTICIPANT	\N	PRESENT	0
203665	190804	14257W	PARTICIPANT	\N	PRESENT	0
203666	190804	04088S	PARTICIPANT	\N	PRESENT	0
203667	190804	04049K	PARTICIPANT	\N	PRESENT	0
203668	190804	11023D	PARTICIPANT	\N	PRESENT	0
203672	190804	11061K	PARTICIPANT	\N	PRESENT	0
203673	190804	14159V	PARTICIPANT	\N	PRESENT	0
203674	190804	19251M	PARTICIPANT	\N	PRESENT	0
203675	190804	16813M	PARTICIPANT	\N	PRESENT	0
203676	190804	14255U	PARTICIPANT	\N	PRESENT	0
203692	190804	80013X	PARTICIPANT	\N	PRESENT	0
203693	190804	11025F	PARTICIPANT	\N	PRESENT	0
203694	190804	14081Q	PARTICIPANT	\N	PRESENT	0
203695	190804	14033T	PARTICIPANT	\N	PRESENT	0
203696	190804	14157T	PARTICIPANT	\N	PRESENT	0
203698	203697	95067Q	PARTICIPANT	\N	PRESENT	0
203699	190804	04056J	PARTICIPANT	\N	PRESENT	0
203712	200595	18003S	PARTICIPANT	\N	PRESENT	0
203716	200595	14299H	PARTICIPANT	\N	PRESENT	0
203726	190804	08016S	PARTICIPANT	\N	PRESENT	0
203657	190804	11107G	PARTICIPANT	\N	PRESENT	0
203658	190804	08068F	PARTICIPANT	\N	PRESENT	0
203732	190804	04034C	PARTICIPANT	\N	PRESENT	0
203733	190804	01024M	PARTICIPANT	\N	PRESENT	0
203734	190804	14363X	PARTICIPANT	\N	PRESENT	0
203735	190804	11109J	PARTICIPANT	\N	PRESENT	0
203736	190804	11036J	PARTICIPANT	\N	PRESENT	0
203752	190804	11026G	PARTICIPANT	\N	PRESENT	0
203773	203772	14187A	PARTICIPANT	\N	PRESENT	0
203793	203792	04071H	PARTICIPANT	\N	PRESENT	0
203833	203832	04086Q	PARTICIPANT	\N	PRESENT	0
203835	203834	08011M	PARTICIPANT	\N	PRESENT	0
203836	203834	01031L	PARTICIPANT	\N	PRESENT	0
203837	203834	01013J	PARTICIPANT	\N	PRESENT	0
203838	203834	04086Q	PARTICIPANT	\N	PRESENT	0
203839	203834	14225N	PARTICIPANT	\N	PRESENT	0
203840	203834	11057P	PARTICIPANT	\N	PRESENT	0
203853	203852	98042T	PARTICIPANT	\N	PRESENT	0
203854	203852	14147R	PARTICIPANT	\N	PRESENT	0
203855	203852	95067Q	PARTICIPANT	\N	PRESENT	0
203856	203852	14255U	PARTICIPANT	\N	PRESENT	0
204754	204352	95049N	PARTICIPANT	\N	EXCUSE	0
203874	203872	14133K	PARTICIPANT	\N	PRESENT	0
203876	203875	14133K	PARTICIPANT	\N	PRESENT	0
205033	205032	05012A	PARTICIPANT	\N	PRESENT	0
205034	205032	08068F	PARTICIPANT	\N	PRESENT	0
205055	205054	04070G	PARTICIPANT	\N	PRESENT	0
205057	205056	04070G	PARTICIPANT	\N	PRESENT	0
205059	205058	04070G	PARTICIPANT	\N	PRESENT	0
205132	204972	14327T	PARTICIPANT	\N	EXCUSE	0
205133	204972	11098Y	PARTICIPANT	\N	EXCUSE	0
205134	204972	04044E	PARTICIPANT	\N	EXCUSE	0
205152	204972	14231L	PARTICIPANT	\N	PRESENT	0
205153	204972	14071N	PARTICIPANT	\N	PRESENT	0
205154	204972	05012A	PARTICIPANT	\N	PRESENT	0
205173	205172	11039M	PARTICIPANT	\N	PRESENT	0
205174	205172	98042T	PARTICIPANT	\N	PRESENT	0
205175	205172	01019Q	PARTICIPANT	\N	PRESENT	0
205333	205332	07034Q	PARTICIPANT	\N	PRESENT	0
205335	205334	07034Q	PARTICIPANT	\N	PRESENT	0
205337	205336	07034Q	PARTICIPANT	\N	PRESENT	0
205433	205212	14209N	PARTICIPANT	\N	EXCUSE	0
205434	205212	04061F	PARTICIPANT	\N	EXCUSE	0
205435	205212	08039A	PARTICIPANT	\N	EXCUSE	0
205436	205212	04043D	PARTICIPANT	\N	PRESENT	0
205437	205212	01058X	PARTICIPANT	\N	PRESENT	0
205438	205212	14221J	PARTICIPANT	\N	PRESENT	0
205439	205212	14257W	PARTICIPANT	\N	PRESENT	0
205458	205372	14327T	PARTICIPANT	\N	PRESENT	0
205459	205372	01048V	PARTICIPANT	\N	PRESENT	0
205460	205372	04034C	PARTICIPANT	\N	PRESENT	0
205461	205372	01057W	PARTICIPANT	\N	PRESENT	0
205462	205372	11053K	PARTICIPANT	\N	PRESENT	0
205463	205372	11074Q	PARTICIPANT	\N	PRESENT	0
205464	205372	14225N	PARTICIPANT	\N	PRESENT	0
205465	205372	11070L	PARTICIPANT	\N	PRESENT	0
205466	205372	07029T	PARTICIPANT	\N	PRESENT	0
205467	205372	14085U	PARTICIPANT	\N	PRESENT	0
205468	205372	14277B	PARTICIPANT	\N	PRESENT	0
205469	205372	08010L	PARTICIPANT	\N	PRESENT	0
205470	205372	14253S	PARTICIPANT	\N	PRESENT	0
205471	205372	01031L	PRESIDENT	0	PRESENT	0
205472	205372	08034U	PARTICIPANT	\N	PRESENT	0
205473	205372	01016M	PARTICIPANT	\N	PRESENT	0
205474	205372	08011M	PARTICIPANT	\N	PRESENT	0
205475	205372	08014Q	PARTICIPANT	\N	PRESENT	0
205476	205372	01027Q	PARTICIPANT	\N	PRESENT	0
205477	205372	14159V	PARTICIPANT	\N	PRESENT	0
205478	205372	11040E	PARTICIPANT	\N	PRESENT	0
205479	205372	11057P	PARTICIPANT	\N	PRESENT	0
205480	205372	11083R	PARTICIPANT	\N	PRESENT	0
205481	205372	01013J	PARTICIPANT	\N	PRESENT	0
205482	205372	11042G	PARTICIPANT	\N	PRESENT	0
205483	205372	04086Q	PARTICIPANT	\N	PRESENT	0
205484	205372	11012A	PARTICIPANT	\N	PRESENT	0
205485	205372	89017R	PARTICIPANT	\N	PRESENT	0
205486	205372	04061F	PARTICIPANT	\N	PRESENT	0
205487	205372	98053W	PARTICIPANT	\N	EXCUSE	0
205488	205372	04055H	PARTICIPANT	\N	EXCUSE	0
205489	205373	14327T	PARTICIPANT	\N	PRESENT	0
205490	205373	01048V	PARTICIPANT	\N	PRESENT	0
205491	205373	04034C	PARTICIPANT	\N	PRESENT	0
205492	205373	01057W	PARTICIPANT	\N	PRESENT	0
205494	205373	11074Q	PARTICIPANT	\N	PRESENT	0
205495	205373	14225N	PARTICIPANT	\N	PRESENT	0
205582	205212	14299H	PARTICIPANT	\N	EXCUSE	0
205497	205373	07029T	PARTICIPANT	\N	PRESENT	0
205498	205373	14085U	PARTICIPANT	\N	PRESENT	0
205499	205373	14277B	PARTICIPANT	\N	PRESENT	0
205500	205373	08010L	PARTICIPANT	\N	PRESENT	0
205501	205373	14253S	PARTICIPANT	\N	PRESENT	0
205502	205373	01031L	PRESIDENT	0	PRESENT	0
205503	205373	08034U	PARTICIPANT	\N	PRESENT	0
205504	205373	01016M	PARTICIPANT	\N	PRESENT	0
205505	205373	08011M	PARTICIPANT	\N	PRESENT	0
205506	205373	08014Q	PARTICIPANT	\N	PRESENT	0
205507	205373	01027Q	PARTICIPANT	\N	PRESENT	0
205508	205373	14159V	PARTICIPANT	\N	PRESENT	0
205509	205373	11040E	PARTICIPANT	\N	PRESENT	0
205510	205373	11057P	PARTICIPANT	\N	PRESENT	0
205511	205373	11083R	PARTICIPANT	\N	PRESENT	0
205512	205373	01013J	PARTICIPANT	\N	PRESENT	0
205513	205373	11042G	PARTICIPANT	\N	PRESENT	0
205515	205373	11012A	PARTICIPANT	\N	PRESENT	0
205516	205373	89017R	PARTICIPANT	\N	PRESENT	0
205517	205373	04061F	PARTICIPANT	\N	PRESENT	0
205518	205373	98053W	PARTICIPANT	\N	EXCUSE	0
205519	205373	04055H	PARTICIPANT	\N	EXCUSE	0
205553	205373	08061X	PARTICIPANT	\N	PRESENT	0
205554	205373	08073C	PARTICIPANT	\N	PRESENT	0
205592	205215	01058X	PARTICIPANT	\N	PRESENT	0
205593	205215	04043D	PARTICIPANT	\N	PRESENT	0
205613	205612	01031L	PARTICIPANT	\N	PRESENT	0
205614	205612	04086Q	PARTICIPANT	\N	PRESENT	0
205615	205612	08011M	PARTICIPANT	\N	PRESENT	0
205616	205612	14173T	PARTICIPANT	\N	PRESENT	0
205617	205612	11057P	PARTICIPANT	\N	PRESENT	0
205618	205612	01013J	PARTICIPANT	\N	PRESENT	0
205619	205612	01057W	PARTICIPANT	\N	PRESENT	0
205620	205612	11070L	PARTICIPANT	\N	PRESENT	0
205624	205623	04040A	PARTICIPANT	\N	PRESENT	0
205626	205625	98021N	PARTICIPANT	\N	PRESENT	0
205628	205627	04042C	PARTICIPANT	\N	PRESENT	0
205629	205627	04040A	PARTICIPANT	\N	PRESENT	0
205630	205627	11106F	PARTICIPANT	\N	PRESENT	0
167452	166236	04038G	PARTICIPANT	\N	PRESENT	0
167454	167453	14219Q	PRESIDENT	0	PRESENT	0
167455	167453	11065P	PARTICIPANT	\N	PRESENT	0
167456	167453	01056V	PARTICIPANT	\N	PRESENT	0
167457	167453	01008M	PARTICIPANT	\N	PRESENT	0
167458	167453	14033T	PARTICIPANT	\N	PRESENT	0
167459	167453	90003B	PARTICIPANT	\N	EXCUSE	0
167460	167453	80013X	PARTICIPANT	\N	PRESENT	0
167461	167453	05012A	PARTICIPANT	\N	PRESENT	0
167462	167453	92045V	PARTICIPANT	\N	PRESENT	0
167475	167474	14026U	PARTICIPANT	\N	PRESENT	0
167478	167474	14073Q	PARTICIPANT	\N	PRESENT	0
167479	167474	96004D	PARTICIPANT	\N	PRESENT	0
184292	184192	11098Y	PARTICIPANT	\N	EXCUSE	0
184312	184192	11035H	PARTICIPANT	\N	EXCUSE	0
187413	187412	92039X	PARTICIPANT	\N	PRESENT	0
187414	187412	01019Q	PARTICIPANT	\N	PRESENT	0
187453	187452	14207L	PRESIDENT	0	PRESENT	0
187454	187452	14089Y	PARTICIPANT	\N	PRESENT	0
187455	187452	11029K	PARTICIPANT	\N	PRESENT	0
187495	187494	89017R	PARTICIPANT	\N	PRESENT	0
187497	187496	89017R	PARTICIPANT	\N	PRESENT	0
187458	187452	11095V	PARTICIPANT	\N	EXCUSE	0
187459	187452	14215L	PARTICIPANT	\N	EXCUSE	0
187460	187452	14249W	PARTICIPANT	\N	EXCUSE	0
187461	187452	14281W	PARTICIPANT	\N	PRESENT	0
187462	187452	14231L	PARTICIPANT	\N	PRESENT	0
187463	187452	11061K	PARTICIPANT	\N	PRESENT	0
187464	187452	95035G	PARTICIPANT	\N	PRESENT	0
187465	187452	14031R	PARTICIPANT	\N	PRESENT	0
187466	187452	14135M	PARTICIPANT	\N	PRESENT	0
187467	187452	14229S	PARTICIPANT	\N	PRESENT	0
187468	187452	04050C	PARTICIPANT	\N	PRESENT	0
187469	187452	14053L	PARTICIPANT	\N	EXCUSE	0
187470	187452	11014C	PARTICIPANT	\N	EXCUSE	0
187471	187452	14237S	PARTICIPANT	\N	EXCUSE	0
187472	187452	14079W	PARTICIPANT	\N	EXCUSE	0
187493	187492	89017R	PARTICIPANT	\N	PRESENT	0
187535	187514	14229S	PARTICIPANT	\N	PRESENT	0
187537	187536	08031R	PARTICIPANT	\N	PRESENT	0
187533	187514	08031R	PARTICIPANT	\N	PRESENT	0
187534	187514	87003B	PARTICIPANT	\N	PRESENT	0
187538	187536	14229S	PARTICIPANT	\N	PRESENT	0
187540	187539	04070G	PARTICIPANT	\N	PRESENT	0
187541	187539	08039A	PARTICIPANT	\N	PRESENT	0
187542	187539	14263U	PARTICIPANT	\N	PRESENT	0
187543	187539	04059M	PARTICIPANT	\N	PRESENT	0
187544	187539	04057K	PARTICIPANT	\N	PRESENT	0
187545	187539	08031R	PARTICIPANT	\N	PRESENT	0
187546	187539	14179A	PARTICIPANT	\N	PRESENT	0
187548	187547	04070G	PARTICIPANT	\N	PRESENT	0
187573	187572	95063L	PARTICIPANT	\N	PRESENT	0
188514	188513	04080J	PARTICIPANT	\N	PRESENT	0
188515	188513	11084S	PARTICIPANT	\N	PRESENT	0
188516	188513	04035D	PARTICIPANT	\N	PRESENT	0
194834	194793	10015M	PARTICIPANT	\N	PRESENT	0
195284	190779	08055A	PARTICIPANT	\N	PRESENT	0
195285	190779	14107H	PARTICIPANT	\N	PRESENT	0
195286	190779	14195A	PARTICIPANT	\N	PRESENT	0
195287	190779	13002U	PARTICIPANT	\N	PRESENT	0
195288	190779	08010L	PARTICIPANT	\N	PRESENT	0
195289	190779	11027H	PARTICIPANT	\N	PRESENT	0
195290	190779	01011G	PARTICIPANT	\N	PRESENT	0
195291	190779	04061F	PARTICIPANT	\N	PRESENT	0
195292	190779	92020L	PARTICIPANT	\N	PRESENT	0
195293	190779	08060W	PARTICIPANT	\N	PRESENT	0
195294	190779	92045V	PARTICIPANT	\N	PRESENT	0
195295	190779	14157T	PARTICIPANT	\N	PRESENT	0
195296	190779	80013X	PARTICIPANT	\N	PRESENT	0
195297	190779	14038Y	PARTICIPANT	\N	PRESENT	0
195298	190779	14197C	PARTICIPANT	\N	PRESENT	0
195299	190779	01022K	PARTICIPANT	\N	PRESENT	0
195300	190779	14028W	PARTICIPANT	\N	PRESENT	0
195302	190779	11069T	PARTICIPANT	\N	PRESENT	0
195303	190779	11097X	PARTICIPANT	\N	PRESENT	0
195304	190779	80027E	PARTICIPANT	\N	PRESENT	0
195305	190779	04036E	PARTICIPANT	\N	PRESENT	0
195306	190779	11089X	PARTICIPANT	\N	PRESENT	0
195307	190779	08068F	PARTICIPANT	\N	PRESENT	0
195308	190779	14119M	PARTICIPANT	\N	PRESENT	0
195310	190779	14065Q	PARTICIPANT	\N	PRESENT	0
195311	190779	08043V	PARTICIPANT	\N	PRESENT	0
195312	190779	11110B	PARTICIPANT	\N	PRESENT	0
195313	190779	11077T	PARTICIPANT	\N	PRESENT	0
195314	190779	01062T	PARTICIPANT	\N	PRESENT	0
195315	190779	08038Y	PARTICIPANT	\N	PRESENT	0
195316	190779	08017T	PARTICIPANT	\N	PRESENT	0
195317	190779	08053X	PARTICIPANT	\N	PRESENT	0
195318	190779	11071M	PARTICIPANT	\N	PRESENT	0
195319	190779	14085U	PARTICIPANT	\N	PRESENT	0
195320	190779	08058D	PARTICIPANT	\N	PRESENT	0
195321	190779	95067Q	PARTICIPANT	\N	PRESENT	0
195322	190779	11041F	PARTICIPANT	\N	PRESENT	0
195323	190779	14109K	PARTICIPANT	\N	PRESENT	0
195324	190779	14207L	PARTICIPANT	\N	PRESENT	0
195325	190779	08014Q	PARTICIPANT	\N	PRESENT	0
195326	190779	14191V	PARTICIPANT	\N	PRESENT	0
195327	190779	14001X	PARTICIPANT	\N	PRESENT	0
195328	190779	11059R	PARTICIPANT	\N	PRESENT	0
195329	190779	14087W	PARTICIPANT	\N	PRESENT	0
195330	190779	14167V	PARTICIPANT	\N	PRESENT	0
195331	190779	14209N	PARTICIPANT	\N	PRESENT	0
195332	190779	11061K	PARTICIPANT	\N	PRESENT	0
195333	190779	11054L	PARTICIPANT	\N	PRESENT	0
195334	190779	11011M	PARTICIPANT	\N	PRESENT	0
195335	190779	18127E	PARTICIPANT	\N	PRESENT	0
195336	190779	11014C	PARTICIPANT	\N	PRESENT	0
195337	190779	14257W	PARTICIPANT	\N	PRESENT	0
195338	190779	14097Y	PARTICIPANT	\N	PRESENT	0
195339	190779	11112D	PARTICIPANT	\N	PRESENT	0
195340	190779	14199E	PARTICIPANT	\N	PRESENT	0
195341	190779	14063N	PARTICIPANT	\N	PRESENT	0
195342	190779	14121F	PARTICIPANT	\N	PRESENT	0
195343	190779	14229S	PARTICIPANT	\N	PRESENT	0
195344	190779	14227Q	PARTICIPANT	\N	PRESENT	0
195345	190779	08018U	PARTICIPANT	\N	PRESENT	0
195346	190779	83047W	PARTICIPANT	\N	PRESENT	0
195347	190779	86044G	PARTICIPANT	\N	PRESENT	0
195348	190779	19251M	PARTICIPANT	\N	PRESENT	0
195349	190779	11026G	PARTICIPANT	\N	PRESENT	0
195350	190779	14281W	PARTICIPANT	\N	PRESENT	0
195351	190779	14239U	PARTICIPANT	\N	PRESENT	0
195352	190779	11036J	PARTICIPANT	\N	PRESENT	0
195353	190779	11068S	PARTICIPANT	\N	PRESENT	0
195354	190779	04053F	PARTICIPANT	\N	PRESENT	0
195355	190779	98029W	PARTICIPANT	\N	PRESENT	0
195356	190779	95035G	PARTICIPANT	\N	PRESENT	0
195357	190779	12042Y	PARTICIPANT	\N	PRESENT	0
195358	190779	11107G	PARTICIPANT	\N	PRESENT	0
195359	190779	11046L	PARTICIPANT	\N	PRESENT	0
195360	190779	08047A	PARTICIPANT	\N	PRESENT	0
195361	190779	95037J	PARTICIPANT	\N	PRESENT	0
195362	190779	83042R	PARTICIPANT	\N	PRESENT	0
195363	190779	08061X	PARTICIPANT	\N	PRESENT	0
195364	190779	14271U	PARTICIPANT	\N	PRESENT	0
195365	190779	04045F	PARTICIPANT	\N	PRESENT	0
195366	190779	04066L	PARTICIPANT	\N	PRESENT	0
195367	190779	11057P	PARTICIPANT	\N	PRESENT	0
195368	190779	14039A	PARTICIPANT	\N	PRESENT	0
195369	190779	04034C	PARTICIPANT	\N	PRESENT	0
195370	190779	95049N	PARTICIPANT	\N	PRESENT	0
195371	190779	01043Q	PARTICIPANT	\N	PRESENT	0
195372	190779	01025N	PARTICIPANT	\N	PRESENT	0
195373	190779	89017R	PARTICIPANT	\N	PRESENT	0
195374	190779	11099A	PARTICIPANT	\N	PRESENT	0
195375	190779	04040A	PARTICIPANT	\N	PRESENT	0
195376	190779	11029K	PARTICIPANT	\N	PRESENT	0
195377	190779	11033F	PARTICIPANT	\N	PRESENT	0
195378	190779	14089Y	PARTICIPANT	\N	PRESENT	0
195379	190779	11085T	PARTICIPANT	\N	PRESENT	0
195380	190779	01047U	PARTICIPANT	\N	PRESENT	0
195381	190779	08009T	PARTICIPANT	\N	PRESENT	0
194814	194793	07004J	PARTICIPANT	\N	PRESENT	0
194816	194793	04036E	PARTICIPANT	\N	PRESENT	0
195382	190779	14221J	PARTICIPANT	\N	PRESENT	0
195383	190779	14103D	PARTICIPANT	\N	PRESENT	0
208577	207682	14087W	PARTICIPANT	\N	PRESENT	0
208578	207682	19673G	PARTICIPANT	\N	PRESENT	0
208579	207682	97011G	PARTICIPANT	\N	PRESENT	0
208580	207682	08028W	PARTICIPANT	\N	PRESENT	0
208581	207682	95062K	PARTICIPANT	\N	PRESENT	0
208582	207682	11081P	PARTICIPANT	\N	PRESENT	0
208583	207682	14119M	PARTICIPANT	\N	PRESENT	0
208584	207682	01048V	PARTICIPANT	\N	PRESENT	0
208585	207682	04089T	PARTICIPANT	\N	PRESENT	0
208586	207682	19581D	PARTICIPANT	\N	PRESENT	0
208587	207682	04008A	PARTICIPANT	\N	PRESENT	0
208588	207682	14257W	PARTICIPANT	\N	PRESENT	0
208589	207682	19701S	PARTICIPANT	\N	PRESENT	0
208590	207682	08056B	PARTICIPANT	\N	PRESENT	0
208591	207682	14105F	PARTICIPANT	\N	PRESENT	0
208592	207682	08015R	PARTICIPANT	\N	PRESENT	0
208593	207682	14021P	PARTICIPANT	\N	PRESENT	0
208594	207682	11066Q	PARTICIPANT	\N	PRESENT	0
208595	207682	19573D	PARTICIPANT	\N	PRESENT	0
208596	207682	19483C	PARTICIPANT	\N	PRESENT	0
208597	207682	14029X	PARTICIPANT	\N	PRESENT	0
208598	207682	14221J	PARTICIPANT	\N	PRESENT	0
208599	207682	14265W	PARTICIPANT	\N	PRESENT	0
208600	207682	16685X	PARTICIPANT	\N	PRESENT	0
208601	207682	19663E	PARTICIPANT	\N	PRESENT	0
208602	207682	19349W	PARTICIPANT	\N	PRESENT	0
208603	207682	95063L	PARTICIPANT	\N	PRESENT	0
208604	208061	19443T	PARTICIPANT	\N	PRESENT	0
208605	208061	19251M	PARTICIPANT	\N	PRESENT	0
208606	208061	04042C	PRESIDENT	0	PRESENT	0
208607	208061	98053W	PARTICIPANT	\N	EXCUSE	0
208608	208061	19583F	PARTICIPANT	\N	EXCUSE	0
208609	207682	19569H	PARTICIPANT	\N	PRESENT	0
208610	207682	19631V	PARTICIPANT	\N	PRESENT	0
208611	207682	14267Y	PARTICIPANT	\N	PRESENT	0
208612	207682	19591F	PARTICIPANT	\N	PRESENT	0
208613	207682	19687N	PARTICIPANT	\N	PRESENT	0
208614	207682	14219Q	PARTICIPANT	\N	PRESENT	0
208615	207682	14231L	PARTICIPANT	\N	PRESENT	0
208616	207682	08010L	PARTICIPANT	\N	PRESENT	0
208618	207682	11040E	PARTICIPANT	\N	PRESENT	0
208619	208617	11097X	PARTICIPANT	\N	PRESENT	0
208620	207682	14033T	PARTICIPANT	\N	PRESENT	0
208621	207682	19335Q	PARTICIPANT	\N	PRESENT	0
208622	207682	14223L	PARTICIPANT	\N	PRESENT	0
208623	207682	19715Y	PARTICIPANT	\N	PRESENT	0
208624	207682	19295A	PARTICIPANT	\N	PRESENT	0
208625	207682	14197C	PARTICIPANT	\N	PRESENT	0
208626	207682	19511N	PARTICIPANT	\N	PRESENT	0
208627	207682	07004J	PARTICIPANT	\N	PRESENT	0
208628	207682	17637T	PARTICIPANT	\N	PRESENT	0
208629	207682	14225N	PARTICIPANT	\N	PRESENT	0
208630	207682	04057K	PARTICIPANT	\N	PRESENT	0
208631	207682	19415P	PARTICIPANT	\N	PRESENT	0
208632	207682	14157T	PARTICIPANT	\N	PRESENT	0
208633	207682	12016W	PARTICIPANT	\N	PRESENT	0
208634	207682	08034U	PARTICIPANT	\N	PRESENT	0
208635	207682	14089Y	PARTICIPANT	\N	PRESENT	0
208636	207682	14217N	PARTICIPANT	\N	PRESENT	0
208637	207682	19575F	PARTICIPANT	\N	PRESENT	0
208638	208061	98005N	PARTICIPANT	\N	PRESENT	0
208639	208061	95030B	PARTICIPANT	\N	PRESENT	0
208640	208061	14079W	PARTICIPANT	\N	PRESENT	0
208641	208061	04040A	PARTICIPANT	\N	PRESENT	0
208642	208061	01058X	PARTICIPANT	\N	PRESENT	0
208643	208061	11027H	PARTICIPANT	\N	PRESENT	0
208644	208061	11054L	PARTICIPANT	\N	PRESENT	0
208645	208061	11066Q	PARTICIPANT	\N	PRESENT	0
208646	208061	08056B	PARTICIPANT	\N	PRESENT	0
208647	208061	95037J	PARTICIPANT	\N	PRESENT	0
208648	208061	19421M	PARTICIPANT	\N	PRESENT	0
208649	208061	19709B	PARTICIPANT	\N	PRESENT	0
208650	208061	08049C	PARTICIPANT	\N	PRESENT	0
208651	208061	14193X	PARTICIPANT	\N	PRESENT	0
208652	208061	08061X	PARTICIPANT	\N	PRESENT	0
208653	208061	97011G	PARTICIPANT	\N	PRESENT	0
208654	208061	08047A	PARTICIPANT	\N	PRESENT	0
208655	208061	98029W	PARTICIPANT	\N	PRESENT	0
208656	208061	04035D	PARTICIPANT	\N	PRESENT	0
208657	208061	95067Q	PARTICIPANT	\N	PRESENT	0
208658	208061	01062T	PARTICIPANT	\N	PRESENT	0
208659	208061	14133K	PARTICIPANT	\N	PRESENT	0
208660	208061	11041F	PARTICIPANT	\N	PRESENT	0
208661	208061	14235Q	PARTICIPANT	\N	PRESENT	0
208662	208061	08058D	PARTICIPANT	\N	PRESENT	0
208663	208061	14028W	PARTICIPANT	\N	PRESENT	0
208664	208061	19721W	PARTICIPANT	\N	PRESENT	0
208665	208061	98022P	PARTICIPANT	\N	PRESENT	0
208666	208061	14267Y	PARTICIPANT	\N	PRESENT	0
208667	208061	11064N	PARTICIPANT	\N	PRESENT	0
208668	208061	98050T	PARTICIPANT	\N	PRESENT	0
208669	208061	14255U	PARTICIPANT	\N	PRESENT	0
208670	207682	14123H	PARTICIPANT	\N	PRESENT	0
208671	207682	04088S	PARTICIPANT	\N	PRESENT	0
208672	208061	14105F	PARTICIPANT	\N	PRESENT	0
208673	207682	19413M	PARTICIPANT	\N	PRESENT	0
208674	207682	14331P	PARTICIPANT	\N	PRESENT	0
208675	207682	14107H	PARTICIPANT	\N	PRESENT	0
208676	207682	19717B	PARTICIPANT	\N	PRESENT	0
208677	207682	19699S	PARTICIPANT	\N	PRESENT	0
208678	207682	19719D	PARTICIPANT	\N	PRESENT	0
208679	207682	14053L	PARTICIPANT	\N	PRESENT	0
208680	207682	11048N	PARTICIPANT	\N	PRESENT	0
208681	207682	04085P	PARTICIPANT	\N	PRESENT	0
208682	207682	14109K	PARTICIPANT	\N	PRESENT	0
208683	207682	19649G	PARTICIPANT	\N	PRESENT	0
208684	207682	11104D	PARTICIPANT	\N	PRESENT	0
208685	207682	19671E	PARTICIPANT	\N	PRESENT	0
208686	207682	08055A	PARTICIPANT	\N	PRESENT	0
208687	207682	11067R	PARTICIPANT	\N	PRESENT	0
208688	207682	04018C	PARTICIPANT	\N	PRESENT	0
208689	207682	14207L	PARTICIPANT	\N	PRESENT	0
208690	207682	14201E	PARTICIPANT	\N	PRESENT	0
208691	208061	16685X	PARTICIPANT	\N	PRESENT	0
208692	207682	19695N	PARTICIPANT	\N	PRESENT	0
208693	207682	14026U	PARTICIPANT	\N	PRESENT	0
208694	207682	11072N	PARTICIPANT	\N	PRESENT	0
208695	207682	87003B	PARTICIPANT	\N	PRESENT	0
208696	207682	08041T	PARTICIPANT	\N	PRESENT	0
208697	207682	89017R	PARTICIPANT	\N	PRESENT	0
208698	207682	14135M	PARTICIPANT	\N	PRESENT	0
208699	207682	80013X	PARTICIPANT	\N	PRESENT	0
208700	207682	14253S	PARTICIPANT	\N	PRESENT	0
208701	207682	19367Y	PARTICIPANT	\N	PRESENT	0
208883	207523	14265W	PARTICIPANT	\N	PRESENT	0
208884	207523	88008L	PARTICIPANT	\N	PRESENT	0
208885	207523	14187A	PARTICIPANT	\N	PRESENT	0
208886	207523	10015M	PARTICIPANT	\N	PRESENT	0
208887	207523	04033B	PARTICIPANT	\N	PRESENT	0
208888	207523	08048B	PARTICIPANT	\N	PRESENT	0
208889	207523	11048N	PARTICIPANT	\N	PRESENT	0
208890	207523	14071N	PARTICIPANT	\N	PRESENT	0
208891	207523	14223L	PARTICIPANT	\N	PRESENT	0
208892	207523	04085P	PARTICIPANT	\N	PRESENT	0
208893	207523	11040E	PARTICIPANT	\N	PRESENT	0
208894	207523	04038G	PARTICIPANT	\N	PRESENT	0
208895	207523	14069U	PARTICIPANT	\N	PRESENT	0
208896	207523	11033F	PARTICIPANT	\N	PRESENT	0
208897	207523	12041X	PARTICIPANT	\N	PRESENT	0
208898	207523	10006L	PARTICIPANT	\N	PRESENT	0
208899	207523	11063M	PARTICIPANT	\N	PRESENT	0
208900	207523	14235Q	PARTICIPANT	\N	PRESENT	0
208901	207523	19695N	PARTICIPANT	\N	PRESENT	0
208902	207523	19347U	PARTICIPANT	\N	PRESENT	0
208903	207523	19565D	PARTICIPANT	\N	PRESENT	0
208904	207523	08069G	PARTICIPANT	\N	PRESENT	0
208905	207523	19593H	PARTICIPANT	\N	PRESENT	0
208906	207523	01057W	PARTICIPANT	\N	PRESENT	0
208907	207523	08034U	PARTICIPANT	\N	PRESENT	0
208908	207523	14159V	PARTICIPANT	\N	PRESENT	0
208909	207523	14213J	PARTICIPANT	\N	PRESENT	0
208910	207523	11077T	PARTICIPANT	\N	PRESENT	0
208911	207523	04044E	PARTICIPANT	\N	PRESENT	0
208912	207523	14061L	PARTICIPANT	\N	PRESENT	0
208913	207523	14051J	PARTICIPANT	\N	PRESENT	0
208914	207523	14331P	PARTICIPANT	\N	PRESENT	0
208915	207523	01028R	PARTICIPANT	\N	PRESENT	0
208916	207523	95030B	PARTICIPANT	\N	PRESENT	0
208917	207523	08052W	PARTICIPANT	\N	PRESENT	0
208918	207523	04049K	PARTICIPANT	\N	PRESENT	0
208919	207523	14229S	PARTICIPANT	\N	PRESENT	0
208920	207523	08016S	PARTICIPANT	\N	PRESENT	0
208921	207523	96004D	PARTICIPANT	\N	PRESENT	0
208922	207523	14107H	PARTICIPANT	\N	PRESENT	0
208923	207523	08045X	PARTICIPANT	\N	PRESENT	0
208924	207523	14225N	PARTICIPANT	\N	PRESENT	0
208925	207523	95067Q	PARTICIPANT	\N	PRESENT	0
208926	207523	14021P	PARTICIPANT	\N	PRESENT	0
208927	207523	14151M	PARTICIPANT	\N	PRESENT	0
166974	166973	01013J	PARTICIPANT	\N	PRESENT	0
166975	166973	11080N	PARTICIPANT	\N	EXCUSE	0
166977	166973	01027Q	PRESIDENT	0	PRESENT	0
166978	166973	11083R	PARTICIPANT	\N	PRESENT	0
166979	166973	01057W	PARTICIPANT	\N	PRESENT	0
166980	166973	14159V	PARTICIPANT	\N	PRESENT	0
166981	166973	11012A	PARTICIPANT	\N	EXCUSE	0
166999	166996	11039M	PARTICIPANT	\N	PRESENT	0
167000	166996	08012N	PARTICIPANT	\N	PRESENT	0
167001	166996	14073Q	PARTICIPANT	\N	PRESENT	0
167002	166996	14191V	PARTICIPANT	\N	PRESENT	0
167003	166996	14241N	PARTICIPANT	\N	PRESENT	0
167004	166996	14235Q	PARTICIPANT	\N	PRESENT	0
167028	167027	04047H	PARTICIPANT	\N	PRESENT	0
167029	167027	11083R	PARTICIPANT	\N	PRESENT	0
167030	167027	14097Y	PARTICIPANT	\N	PRESENT	0
167031	167027	11084S	PARTICIPANT	\N	PRESENT	0
167033	167027	14073Q	PARTICIPANT	\N	PRESENT	0
167034	167027	11026G	PARTICIPANT	\N	PRESENT	0
167035	167027	14001X	PARTICIPANT	\N	PRESENT	0
167037	167027	11066Q	PARTICIPANT	\N	PRESENT	0
167038	167027	14026U	PARTICIPANT	\N	EXCUSE	0
167039	167027	11012A	PRESIDENT	0	PRESENT	0
167282	167277	96004D	PARTICIPANT	\N	PRESENT	0
167283	167277	04047H	PARTICIPANT	\N	PRESENT	0
167284	167277	14079W	PARTICIPANT	\N	PRESENT	0
167285	167277	14026U	PARTICIPANT	\N	EXCUSE	0
167286	167277	14097Y	PARTICIPANT	\N	PRESENT	0
167287	167277	14073Q	PARTICIPANT	\N	PRESENT	0
167289	167277	92031P	PARTICIPANT	\N	PRESENT	0
167290	167277	14001X	PARTICIPANT	\N	PRESENT	0
167292	167277	11012A	PARTICIPANT	\N	PRESENT	0
167293	167277	11066Q	PARTICIPANT	\N	PRESENT	0
167294	167277	95067Q	PARTICIPANT	\N	PRESENT	0
170364	170361	01016M	PARTICIPANT	\N	PRESENT	0
170613	170612	14193X	PARTICIPANT	\N	PRESENT	0
170614	170612	11054L	PARTICIPANT	\N	PRESENT	0
170615	170612	04040A	PARTICIPANT	\N	PRESENT	0
170616	170612	08049C	PARTICIPANT	\N	PRESENT	0
170618	170617	98021N	PARTICIPANT	\N	PRESENT	0
170619	170617	11106F	PARTICIPANT	\N	PRESENT	0
171613	171612	04040A	PARTICIPANT	\N	PRESENT	0
171614	171612	14175V	PARTICIPANT	\N	PRESENT	0
171615	171612	14079W	PARTICIPANT	\N	PRESENT	0
171616	171612	95035G	PARTICIPANT	\N	PRESENT	0
171617	171612	04049K	PARTICIPANT	\N	PRESENT	0
171618	171612	83042R	PARTICIPANT	\N	PRESENT	0
178775	178755	08051V	PARTICIPANT	\N	PRESENT	0
178776	178755	14327T	PARTICIPANT	\N	PRESENT	0
178777	178755	04035D	PARTICIPANT	\N	PRESENT	0
178778	178755	14081Q	PARTICIPANT	\N	PRESENT	0
178779	178755	04078Q	PARTICIPANT	\N	PRESENT	0
178780	178755	11026G	PARTICIPANT	\N	PRESENT	0
178781	178755	96004D	PARTICIPANT	\N	PRESENT	0
178782	178755	04045F	PARTICIPANT	\N	PRESENT	0
180652	167351	98053W	PARTICIPANT	\N	PRESENT	0
180653	167351	08068F	PARTICIPANT	\N	PRESENT	0
180654	167351	14063N	PARTICIPANT	\N	PRESENT	0
180655	167351	14207L	PARTICIPANT	\N	PRESENT	0
180656	167351	14089Y	PARTICIPANT	\N	PRESENT	0
180657	167351	14018U	PARTICIPANT	\N	PRESENT	0
180658	167351	14265W	PARTICIPANT	\N	PRESENT	0
180659	167351	14253S	PARTICIPANT	\N	PRESENT	0
180660	167351	11063M	PARTICIPANT	\N	PRESENT	0
180661	167351	14255U	PARTICIPANT	\N	PRESENT	0
180662	167351	04049K	PARTICIPANT	\N	PRESENT	0
180663	167351	14037X	PARTICIPANT	\N	PRESENT	0
180664	167351	14034U	PARTICIPANT	\N	PRESENT	0
180665	167351	11099A	PARTICIPANT	\N	PRESENT	0
180666	167351	04061F	PARTICIPANT	\N	PRESENT	0
180667	167351	11103C	PARTICIPANT	\N	PRESENT	0
180668	167351	14157T	PARTICIPANT	\N	PRESENT	0
180669	167351	08065C	PARTICIPANT	\N	PRESENT	0
180672	167351	14147R	PARTICIPANT	\N	PRESENT	0
180673	167351	14205J	PARTICIPANT	\N	PRESENT	0
180674	167351	04053F	PARTICIPANT	\N	PRESENT	0
180675	167351	87003B	PARTICIPANT	\N	PRESENT	0
180692	167351	14327T	PARTICIPANT	\N	PRESENT	0
180712	167351	14119M	PARTICIPANT	\N	PRESENT	0
180732	167351	14061L	PARTICIPANT	\N	PRESENT	0
180733	167351	95063L	PARTICIPANT	\N	PRESENT	0
180734	167351	98050T	PARTICIPANT	\N	PRESENT	0
180735	167351	14033T	PARTICIPANT	\N	PRESENT	0
180736	167351	04056J	PARTICIPANT	\N	PRESENT	0
180737	167351	14363X	PARTICIPANT	\N	PRESENT	0
180739	167351	95015C	PARTICIPANT	\N	PRESENT	0
180741	167351	13002U	PARTICIPANT	\N	PRESENT	0
180744	167351	14197C	PARTICIPANT	\N	PRESENT	0
180746	167351	14041T	PARTICIPANT	\N	PRESENT	0
180752	167351	14235Q	PARTICIPANT	\N	PRESENT	0
180805	167351	11101A	PARTICIPANT	\N	PRESENT	0
180809	167351	04088S	PARTICIPANT	\N	PRESENT	0
180810	167351	14215L	PARTICIPANT	\N	PRESENT	0
180811	167351	14069U	PARTICIPANT	\N	PRESENT	0
180812	167351	14135M	PARTICIPANT	\N	PRESENT	0
180822	167351	11025F	PARTICIPANT	\N	PRESENT	0
180844	167351	01022K	PARTICIPANT	\N	PRESENT	0
180847	167351	14083S	PARTICIPANT	\N	PRESENT	0
180872	167351	14107H	PARTICIPANT	\N	PRESENT	0
180876	167351	14026U	PARTICIPANT	\N	PRESENT	0
180877	167351	11107G	PARTICIPANT	\N	PRESENT	0
180878	167351	14223L	PARTICIPANT	\N	PRESENT	0
180894	167351	04045F	PARTICIPANT	\N	PRESENT	0
180912	167351	11067R	PARTICIPANT	\N	PRESENT	0
180913	167351	11048N	PARTICIPANT	\N	PRESENT	0
180932	167351	14151M	PARTICIPANT	\N	PRESENT	0
180942	167351	80013X	PARTICIPANT	\N	PRESENT	0
180943	167351	92015P	PARTICIPANT	\N	PRESENT	0
180945	167351	14361V	PARTICIPANT	\N	PRESENT	0
180947	167351	14219Q	PARTICIPANT	\N	PRESENT	0
180948	167351	14030Q	PARTICIPANT	\N	PRESENT	0
180976	167351	11042G	PARTICIPANT	\N	PRESENT	0
180983	167351	14038Y	PARTICIPANT	\N	PRESENT	0
180984	167351	14105F	PARTICIPANT	\N	PRESENT	0
180992	167351	01060R	PARTICIPANT	\N	PRESENT	0
181012	167351	08056B	PARTICIPANT	\N	PRESENT	0
181016	167351	01008M	PARTICIPANT	\N	PRESENT	0
181032	167351	14159V	PARTICIPANT	\N	PRESENT	0
181033	167352	86034E	PARTICIPANT	\N	PRESENT	0
181912	167353	92045V	PARTICIPANT	\N	PRESENT	0
182493	182492	14219Q	PRESIDENT	0	PRESENT	0
182494	182492	11065P	PARTICIPANT	\N	PRESENT	0
182495	182492	92045V	PARTICIPANT	\N	PRESENT	0
182512	182492	01056V	PARTICIPANT	\N	PRESENT	0
182513	182492	14033T	PARTICIPANT	\N	PRESENT	0
182533	182532	14219Q	PARTICIPANT	\N	PRESENT	0
182534	182532	11065P	PARTICIPANT	\N	PRESENT	0
182535	182532	01008M	PARTICIPANT	\N	PRESENT	0
183153	183152	95059Q	PARTICIPANT	\N	PRESENT	0
183154	183152	01014K	PARTICIPANT	\N	PRESENT	0
183156	183155	95059Q	PARTICIPANT	\N	PRESENT	0
183157	183155	01014K	PARTICIPANT	\N	PRESENT	0
183159	183158	11031D	PARTICIPANT	\N	PRESENT	0
183160	183158	11061K	PARTICIPANT	\N	PRESENT	0
183161	183158	11097X	PARTICIPANT	\N	PRESENT	0
183772	183752	08034U	PARTICIPANT	\N	PRESENT	0
183793	183792	08034U	PARTICIPANT	\N	PRESENT	0
184473	184472	14026U	PARTICIPANT	\N	PRESENT	0
184474	184472	96004D	PARTICIPANT	\N	PRESENT	0
184492	184472	14033T	PARTICIPANT	\N	PRESENT	0
184493	184472	14357A	PARTICIPANT	\N	PRESENT	0
184494	184472	14257W	PARTICIPANT	\N	PRESENT	0
184512	184192	14014Q	PARTICIPANT	\N	EXCUSE	0
184555	184192	14051J	PARTICIPANT	\N	EXCUSE	0
184572	184192	95067Q	PARTICIPANT	\N	PRESENT	0
184573	184192	14063N	PARTICIPANT	\N	EXCUSE	0
184574	184192	04040A	PRESIDENT	0	PRESENT	0
184892	184192	11112D	PARTICIPANT	\N	EXCUSE	0
184952	184192	11032E	PARTICIPANT	\N	PRESENT	0
184953	184192	11037K	PARTICIPANT	\N	PRESENT	0
184954	184192	92040Q	PARTICIPANT	\N	EXCUSE	0
185913	185912	11033F	PARTICIPANT	\N	PRESENT	0
185914	185912	04044E	PARTICIPANT	\N	PRESENT	0
185916	185915	11033F	PARTICIPANT	\N	PRESENT	0
185917	185915	04044E	PARTICIPANT	\N	PRESENT	0
185933	185932	08034U	PARTICIPANT	\N	PRESENT	0
185973	185972	01043Q	PARTICIPANT	\N	PRESENT	0
185974	185972	14081Q	PARTICIPANT	\N	PRESENT	0
186153	186152	01031L	PARTICIPANT	\N	PRESENT	0
186155	186154	08034U	PARTICIPANT	\N	PRESENT	0
186157	186156	08010L	PARTICIPANT	\N	PRESENT	0
186193	186192	11031D	PARTICIPANT	\N	PRESENT	0
186194	186192	11061K	PARTICIPANT	\N	PRESENT	0
186195	186192	11097X	PARTICIPANT	\N	PRESENT	0
186197	186196	11031D	PARTICIPANT	\N	PRESENT	0
186198	186196	11061K	PARTICIPANT	\N	PRESENT	0
186199	186196	11097X	PARTICIPANT	\N	PRESENT	0
186212	184963	04045F	PARTICIPANT	\N	EXCUSE	0
186408	186397	80027E	PARTICIPANT	\N	EXCUSE	0
205631	205627	14097Y	PARTICIPANT	\N	PRESENT	0
205632	205627	11054L	PARTICIPANT	\N	PRESENT	0
205633	205627	14193X	PARTICIPANT	\N	PRESENT	0
205634	205627	01014K	PARTICIPANT	\N	PRESENT	0
205635	205627	01056V	PARTICIPANT	\N	PRESENT	0
205636	205627	98018T	PARTICIPANT	\N	PRESENT	0
205637	205627	98021N	PARTICIPANT	\N	PRESENT	0
205638	205627	83042R	PARTICIPANT	\N	PRESENT	0
205639	205627	14028W	PARTICIPANT	\N	PRESENT	0
205677	205676	11084S	PARTICIPANT	\N	PRESENT	0
205678	205676	14259Y	PARTICIPANT	\N	PRESENT	0
205679	205676	04044E	PARTICIPANT	\N	PRESENT	0
205681	205680	14259Y	PARTICIPANT	\N	PRESENT	0
205682	205680	04044E	PARTICIPANT	\N	PRESENT	0
206076	206075	89017R	PARTICIPANT	\N	PRESENT	0
206077	206075	14133K	PARTICIPANT	\N	PRESENT	0
206078	206075	14239U	PARTICIPANT	\N	PRESENT	0
206079	206075	11109J	PARTICIPANT	\N	PRESENT	0
206080	206075	14261S	PARTICIPANT	\N	PRESENT	0
206082	206075	19631V	PARTICIPANT	\N	PRESENT	0
206083	206075	04085P	PARTICIPANT	\N	PRESENT	0
206084	206075	04059M	PARTICIPANT	\N	PRESENT	0
206085	206075	19515S	PARTICIPANT	\N	PRESENT	0
206087	206075	19651A	PARTICIPANT	\N	PRESENT	0
206088	206075	05008E	PARTICIPANT	\N	PRESENT	0
206089	206075	19667J	PARTICIPANT	\N	PRESENT	0
206090	206075	19543W	PARTICIPANT	\N	PRESENT	0
206091	206075	11033F	PARTICIPANT	\N	PRESENT	0
206092	206075	08055A	PARTICIPANT	\N	PRESENT	0
206093	206075	19575F	PARTICIPANT	\N	PRESENT	0
206094	206075	11081P	PARTICIPANT	\N	PRESENT	0
206095	206075	14115H	PARTICIPANT	\N	PRESENT	0
206096	206075	14093U	PARTICIPANT	\N	PRESENT	0
206097	206075	14065Q	PARTICIPANT	\N	PRESENT	0
206098	206075	19549D	PARTICIPANT	\N	PRESENT	0
206099	206075	14030Q	PARTICIPANT	\N	PRESENT	0
206100	206075	96004D	PARTICIPANT	\N	PRESENT	0
206101	206075	08043V	PARTICIPANT	\N	PRESENT	0
206102	206075	04040A	PARTICIPANT	\N	PRESENT	0
206103	206075	11040E	PARTICIPANT	\N	PRESENT	0
206104	206075	19367Y	PARTICIPANT	\N	PRESENT	0
206105	206075	14069U	PARTICIPANT	\N	PRESENT	0
206106	206075	19415P	PARTICIPANT	\N	PRESENT	0
206107	206075	14089Y	PARTICIPANT	\N	PRESENT	0
206108	206075	08060W	PARTICIPANT	\N	PRESENT	0
206109	206075	19733B	PARTICIPANT	\N	PRESENT	0
206110	206075	08014Q	PARTICIPANT	\N	PRESENT	0
206111	206075	14105F	PARTICIPANT	\N	PRESENT	0
206112	206075	19643A	PARTICIPANT	\N	PRESENT	0
206113	206075	08068F	PARTICIPANT	\N	PRESENT	0
206114	206075	08058D	PARTICIPANT	\N	PRESENT	0
206115	206075	19383Y	PARTICIPANT	\N	PRESENT	0
206116	206075	19621T	PARTICIPANT	\N	PRESENT	0
206117	206075	08020N	PARTICIPANT	\N	PRESENT	0
206118	206075	04047H	PARTICIPANT	\N	PRESENT	0
206119	206075	14207L	PARTICIPANT	\N	PRESENT	0
206121	206075	11101A	PARTICIPANT	\N	PRESENT	0
206122	206075	04042C	PARTICIPANT	\N	PRESENT	0
206123	206075	14053L	PARTICIPANT	\N	PRESENT	0
206124	206075	14083S	PARTICIPANT	\N	PRESENT	0
206125	206075	11053K	PARTICIPANT	\N	PRESENT	0
206126	206075	19545Y	PARTICIPANT	\N	PRESENT	0
206127	206075	14085U	PARTICIPANT	\N	PRESENT	0
206128	206075	11103C	PARTICIPANT	\N	PRESENT	0
206129	206075	95015C	PARTICIPANT	\N	PRESENT	0
206130	206075	19629C	PARTICIPANT	\N	PRESENT	0
206131	206075	08024S	PARTICIPANT	\N	PRESENT	0
206132	206075	14201E	PARTICIPANT	\N	PRESENT	0
206133	206075	19721W	PARTICIPANT	\N	PRESENT	0
206134	206075	98029W	PARTICIPANT	\N	PRESENT	0
206135	206075	14329V	PARTICIPANT	\N	PRESENT	0
206136	206075	14038Y	PARTICIPANT	\N	PRESENT	0
206137	206075	11080N	PARTICIPANT	\N	PRESENT	0
206138	206075	14195A	PARTICIPANT	\N	PRESENT	0
206139	206075	08028W	PARTICIPANT	\N	PRESENT	0
206140	206075	19467C	PARTICIPANT	\N	PRESENT	0
206141	206075	18083K	PARTICIPANT	\N	PRESENT	0
206142	206075	19701S	PARTICIPANT	\N	PRESENT	0
206143	206075	14267Y	PARTICIPANT	\N	PRESENT	0
206144	206075	11031D	PARTICIPANT	\N	PRESENT	0
206145	206075	88008L	PARTICIPANT	\N	PRESENT	0
206146	206075	04038G	PARTICIPANT	\N	PRESENT	0
206147	206075	19295A	PARTICIPANT	\N	PRESENT	0
206148	206075	11027H	PARTICIPANT	\N	PRESENT	0
206149	206075	19681G	PARTICIPANT	\N	PRESENT	0
206150	206075	98023Q	PARTICIPANT	\N	PRESENT	0
206151	206075	19253P	PARTICIPANT	\N	PRESENT	0
206152	206075	80013X	PARTICIPANT	\N	PRESENT	0
206153	206075	11115U	PARTICIPANT	\N	PRESENT	0
206154	206075	11056N	PARTICIPANT	\N	PRESENT	0
206155	206075	14357A	PARTICIPANT	\N	PRESENT	0
206156	206075	19525U	PARTICIPANT	\N	PRESENT	0
206157	206075	04086Q	PARTICIPANT	\N	PRESENT	0
206158	206075	14079W	PARTICIPANT	\N	PRESENT	0
206159	206075	11065P	PARTICIPANT	\N	PRESENT	0
206160	206075	19693L	PARTICIPANT	\N	PRESENT	0
206161	206075	14259Y	PARTICIPANT	\N	PRESENT	0
206162	206075	04008A	PARTICIPANT	\N	PRESENT	0
206163	206075	08052W	PARTICIPANT	\N	PRESENT	0
206164	206075	08038Y	PARTICIPANT	\N	PRESENT	0
206165	206075	17589D	PARTICIPANT	\N	PRESENT	0
206166	206075	11070L	PARTICIPANT	\N	PRESENT	0
206167	206075	19719D	PARTICIPANT	\N	PRESENT	0
206168	206075	14327T	PARTICIPANT	\N	PRESENT	0
206169	206075	19663E	PARTICIPANT	\N	PRESENT	0
206170	206075	98018T	PARTICIPANT	\N	PRESENT	0
206171	206075	19659J	PARTICIPANT	\N	PRESENT	0
206172	206075	98024R	PARTICIPANT	\N	PRESENT	0
206173	206075	10006L	PARTICIPANT	\N	PRESENT	0
206174	206075	14041T	PARTICIPANT	\N	PRESENT	0
206175	206075	14217N	PARTICIPANT	\N	PRESENT	0
206176	206075	01024M	PARTICIPANT	\N	PRESENT	0
206177	206075	19251M	PARTICIPANT	\N	PRESENT	0
206178	206075	14215L	PARTICIPANT	\N	PRESENT	0
206179	206075	19577H	PARTICIPANT	\N	PRESENT	0
206180	206075	14042U	PARTICIPANT	\N	PRESENT	0
206181	206075	04071H	PARTICIPANT	\N	PRESENT	0
206182	206075	04089T	PARTICIPANT	\N	PRESENT	0
206183	206075	87003B	PARTICIPANT	\N	PRESENT	0
206184	206075	07033P	PARTICIPANT	\N	PRESENT	0
206185	206075	19507S	PARTICIPANT	\N	PRESENT	0
206186	206075	14151M	PARTICIPANT	\N	PRESENT	0
206187	206075	14197C	PARTICIPANT	\N	PRESENT	0
206188	206075	14249W	PARTICIPANT	\N	PRESENT	0
206189	206075	11074Q	PARTICIPANT	\N	PRESENT	0
206190	206075	95030B	PARTICIPANT	\N	PRESENT	0
206191	206075	11110B	PARTICIPANT	\N	PRESENT	0
206192	206075	14187A	PARTICIPANT	\N	PRESENT	0
206193	206075	19673G	PARTICIPANT	\N	PRESENT	0
206194	206075	01025N	PARTICIPANT	\N	PRESENT	0
206195	206075	19647E	PARTICIPANT	\N	PRESENT	0
206196	206075	14281W	PARTICIPANT	\N	PRESENT	0
206197	206075	08045X	PARTICIPANT	\N	PRESENT	0
206198	206075	19599P	PARTICIPANT	\N	PRESENT	0
206199	206075	14087W	PARTICIPANT	\N	PRESENT	0
206200	206075	98053W	PARTICIPANT	\N	PRESENT	0
206201	206075	02002K	PARTICIPANT	\N	PRESENT	0
206202	206075	19521Q	PARTICIPANT	\N	PRESENT	0
206203	206075	97011G	PARTICIPANT	\N	PRESENT	0
206204	206075	08018U	PARTICIPANT	\N	PRESENT	0
206205	206075	11010L	PARTICIPANT	\N	PRESENT	0
206206	206075	14034U	PARTICIPANT	\N	PRESENT	0
206207	206075	04035D	PARTICIPANT	\N	PRESENT	0
206208	206075	14231L	PARTICIPANT	\N	PRESENT	0
206209	206075	11083R	PARTICIPANT	\N	PRESENT	0
206210	206075	19695N	PARTICIPANT	\N	PRESENT	0
206211	206075	14199E	PARTICIPANT	\N	PRESENT	0
206212	206075	14355X	PARTICIPANT	\N	PRESENT	0
206213	206075	08035V	PARTICIPANT	\N	PRESENT	0
206214	206075	08048B	PARTICIPANT	\N	PRESENT	0
206215	206075	15447F	PARTICIPANT	\N	PRESENT	0
206216	206075	08041T	PARTICIPANT	\N	PRESENT	0
206217	206075	19387D	PARTICIPANT	\N	PRESENT	0
206218	206075	19347U	PARTICIPANT	\N	PRESENT	0
206219	206075	19649G	PARTICIPANT	\N	PRESENT	0
206220	206075	07004J	PARTICIPANT	\N	PRESENT	0
206221	206075	01007L	PARTICIPANT	\N	PRESENT	0
206222	206075	08056B	PARTICIPANT	\N	PRESENT	0
206223	206075	14211G	PARTICIPANT	\N	PRESENT	0
206224	206075	19565D	PARTICIPANT	\N	PRESENT	0
206225	206075	19727D	PARTICIPANT	\N	PRESENT	0
206226	206075	14033T	PARTICIPANT	\N	PRESENT	0
206227	206075	11049P	PARTICIPANT	\N	PRESENT	0
206229	206075	14026U	PARTICIPANT	\N	PRESENT	0
169552	169551	01008M	PARTICIPANT	\N	PRESENT	0
169553	169551	11036J	PARTICIPANT	\N	PRESENT	0
169047	169044	14093U	PARTICIPANT	\N	PRESENT	0
169048	169044	14030Q	PARTICIPANT	\N	PRESENT	0
169049	169044	96004D	PARTICIPANT	\N	PRESENT	0
169050	169044	08060W	PARTICIPANT	\N	PRESENT	0
169051	169044	11095V	PARTICIPANT	\N	EXCUSE	0
169052	169044	14038Y	PARTICIPANT	\N	PRESENT	0
169554	169551	11081P	PARTICIPANT	\N	PRESENT	0
169054	169044	98023Q	PARTICIPANT	\N	PRESENT	0
169055	169044	11065P	PARTICIPANT	\N	PRESENT	0
169056	169044	01015L	PARTICIPANT	\N	PRESENT	0
169057	169044	11107G	PARTICIPANT	\N	PRESENT	0
169555	169551	14013P	PARTICIPANT	\N	PRESENT	0
169059	169044	02002K	PARTICIPANT	\N	PRESENT	0
169060	169044	01022K	PARTICIPANT	\N	PRESENT	0
169556	169551	08068F	PARTICIPANT	\N	PRESENT	0
169557	169551	14207L	PARTICIPANT	\N	PRESENT	0
169558	169551	11101A	PARTICIPANT	\N	PRESENT	0
169064	169044	11059R	PARTICIPANT	\N	PRESENT	0
169065	169044	14219Q	PARTICIPANT	\N	PRESENT	0
169066	169044	80027E	PARTICIPANT	\N	PRESENT	0
169067	169044	14031R	PARTICIPANT	\N	PRESENT	0
169068	169044	08009T	PRESIDENT	0	PRESENT	0
169069	169044	08062Y	PARTICIPANT	\N	PRESENT	0
169070	169044	14221J	PARTICIPANT	\N	PRESENT	0
169559	169551	90003B	PARTICIPANT	\N	PRESENT	0
169072	169044	08042U	PARTICIPANT	\N	PRESENT	0
169073	169044	14169X	PARTICIPANT	\N	PRESENT	0
169074	169044	14237S	PARTICIPANT	\N	PRESENT	0
169075	169044	13002U	PARTICIPANT	\N	PRESENT	0
169076	169044	05012A	PARTICIPANT	\N	PRESENT	0
169593	169592	01008M	PARTICIPANT	\N	PRESENT	0
169078	169044	14135M	PARTICIPANT	\N	PRESENT	0
169594	169592	11036J	PARTICIPANT	\N	PRESENT	0
169080	169044	95062K	PARTICIPANT	\N	PRESENT	0
169081	169044	14107H	PARTICIPANT	\N	PRESENT	0
169082	169044	14051J	PARTICIPANT	\N	PRESENT	0
169083	169044	14157T	PARTICIPANT	\N	PRESENT	0
169560	169551	08028W	PARTICIPANT	\N	EXCUSE	0
169561	169551	80013X	PARTICIPANT	\N	PRESENT	0
169562	169551	14357A	PARTICIPANT	\N	PRESENT	0
169563	169551	08038Y	PARTICIPANT	\N	PRESENT	0
169564	169551	04089T	PARTICIPANT	\N	PRESENT	0
169565	169551	14197C	PARTICIPANT	\N	PRESENT	0
169566	169551	11110B	PARTICIPANT	\N	PRESENT	0
169567	169551	14187A	PARTICIPANT	\N	PRESENT	0
169568	169551	14033T	PARTICIPANT	\N	PRESENT	0
169569	169551	14081Q	PARTICIPANT	\N	PRESENT	0
169693	169592	04061F	PARTICIPANT	\N	PRESENT	0
169571	169551	04049K	PARTICIPANT	\N	PRESENT	0
169811	169044	09001P	PARTICIPANT	\N	EXCUSE	0
169573	169551	11111C	PARTICIPANT	\N	PRESENT	0
169574	169551	08015R	PARTICIPANT	\N	PRESENT	0
169575	169551	11100Y	PRESIDENT	0	PRESENT	0
169576	169551	01061S	PARTICIPANT	\N	PRESENT	0
169577	169551	11098Y	PARTICIPANT	\N	PRESENT	0
169578	169551	01043Q	PARTICIPANT	\N	PRESENT	0
169579	169551	11077T	PARTICIPANT	\N	PRESENT	0
169580	169551	14205J	PARTICIPANT	\N	PRESENT	0
169581	169551	08019V	PARTICIPANT	\N	PRESENT	0
169582	169551	14257W	PARTICIPANT	\N	PRESENT	0
169583	169551	08021P	PARTICIPANT	\N	PRESENT	0
169584	169551	04088S	PARTICIPANT	\N	PRESENT	0
169585	169551	98050T	PARTICIPANT	\N	PRESENT	0
169586	169551	11090Q	PARTICIPANT	\N	PRESENT	0
169587	169551	11046L	PARTICIPANT	\N	PRESENT	0
169588	169551	01058X	PARTICIPANT	\N	PRESENT	0
169589	169551	11094U	PARTICIPANT	\N	PRESENT	0
169590	169551	11066Q	PARTICIPANT	\N	PRESENT	0
170034	170033	14259Y	PARTICIPANT	\N	PRESENT	0
169596	169592	14013P	PARTICIPANT	\N	PRESENT	0
170035	170033	11037K	PARTICIPANT	\N	PRESENT	0
169598	169592	14207L	PARTICIPANT	\N	PRESENT	0
169599	169592	11101A	PARTICIPANT	\N	PRESENT	0
169600	169592	90003B	PARTICIPANT	\N	PRESENT	0
169601	169592	08028W	PARTICIPANT	\N	EXCUSE	0
169602	169592	80013X	PARTICIPANT	\N	PRESENT	0
169603	169592	14357A	PARTICIPANT	\N	PRESENT	0
170712	169094	11112D	PARTICIPANT	\N	EXCUSE	0
169605	169592	04089T	PARTICIPANT	\N	PRESENT	0
169606	169592	14197C	PARTICIPANT	\N	PRESENT	0
170713	169094	14071N	PARTICIPANT	\N	PRESENT	0
169608	169592	14187A	PARTICIPANT	\N	PRESENT	0
169609	169592	14033T	PARTICIPANT	\N	PRESENT	0
169610	169592	14081Q	PARTICIPANT	\N	PRESENT	0
170732	169094	08038Y	PARTICIPANT	\N	EXCUSE	0
170733	169094	01057W	PARTICIPANT	\N	PRESENT	0
170734	169094	14028W	PARTICIPANT	\N	PRESENT	0
170735	169094	04045F	PARTICIPANT	\N	EXCUSE	0
169615	169592	08015R	PARTICIPANT	\N	PRESENT	0
169616	169592	11100Y	PRESIDENT	0	PRESENT	0
169617	169592	01061S	PARTICIPANT	\N	PRESENT	0
170736	169094	11034G	PARTICIPANT	\N	EXCUSE	0
169619	169592	01043Q	PARTICIPANT	\N	PRESENT	0
170737	169094	14034U	PARTICIPANT	\N	PRESENT	0
169621	169592	14205J	PARTICIPANT	\N	PRESENT	0
170752	169094	14327T	PARTICIPANT	\N	PRESENT	0
169623	169592	14257W	PARTICIPANT	\N	PRESENT	0
169624	169592	08021P	PARTICIPANT	\N	PRESENT	0
171135	167015	08010L	PARTICIPANT	\N	PRESENT	0
169626	169592	98050T	PARTICIPANT	\N	PRESENT	0
174173	174172	05008E	PARTICIPANT	\N	PRESENT	0
169628	169592	11046L	PARTICIPANT	\N	PRESENT	0
169629	169592	01058X	PARTICIPANT	\N	PRESENT	0
169630	169592	11094U	PARTICIPANT	\N	PRESENT	0
169631	169592	11066Q	PARTICIPANT	\N	PRESENT	0
174175	174174	05008E	PARTICIPANT	\N	PRESENT	0
174372	167278	89029V	PARTICIPANT	\N	PRESENT	0
174373	167278	08043V	PARTICIPANT	\N	PRESENT	0
174374	167278	14063N	PARTICIPANT	\N	PRESENT	0
174375	167278	08041T	PARTICIPANT	\N	PRESENT	0
174376	167278	08065C	PARTICIPANT	\N	PRESENT	0
174377	167278	86044G	PARTICIPANT	\N	PRESENT	0
174378	167278	12042Y	PARTICIPANT	\N	PRESENT	0
174379	167278	95062K	PARTICIPANT	\N	PRESENT	0
174392	167278	14042U	PARTICIPANT	\N	PRESENT	0
174393	167278	14121F	PARTICIPANT	\N	PRESENT	0
174394	167278	08016S	PARTICIPANT	\N	PRESENT	0
174395	167278	14281W	PARTICIPANT	\N	PRESENT	0
174396	167278	04045F	PARTICIPANT	\N	PRESENT	0
174397	167278	14269B	PARTICIPANT	\N	PRESENT	0
174398	167278	14081Q	PARTICIPANT	\N	PRESENT	0
174399	167278	04092N	PARTICIPANT	\N	PRESENT	0
174400	167278	14271U	PARTICIPANT	\N	PRESENT	0
174401	167278	11025F	PARTICIPANT	\N	PRESENT	0
174402	167278	08053X	PARTICIPANT	\N	PRESENT	0
174403	167278	92015P	PARTICIPANT	\N	PRESENT	0
174404	167278	11061K	PARTICIPANT	\N	PRESENT	0
174405	167278	11029K	PARTICIPANT	\N	PRESENT	0
174406	167278	11031D	PARTICIPANT	\N	PRESENT	0
174407	167278	14105F	PARTICIPANT	\N	PRESENT	0
174408	167278	11067R	PARTICIPANT	\N	PRESENT	0
174409	167278	14207L	PARTICIPANT	\N	PRESENT	0
174410	167278	11093T	PARTICIPANT	\N	PRESENT	0
174411	167278	14327T	PARTICIPANT	\N	PRESENT	0
174412	167278	14255U	PARTICIPANT	\N	PRESENT	0
174413	167278	14231L	PARTICIPANT	\N	PRESENT	0
174414	167278	14034U	PARTICIPANT	\N	PRESENT	0
174415	167278	14363X	PARTICIPANT	\N	PRESENT	0
174416	167278	95049N	PARTICIPANT	\N	PRESENT	0
174417	167278	95031C	PARTICIPANT	\N	PRESENT	0
174418	167278	08039A	PARTICIPANT	\N	PRESENT	0
174419	167278	11103C	PARTICIPANT	\N	PRESENT	0
174420	167278	97011G	PARTICIPANT	\N	PRESENT	0
174421	167278	04057K	PARTICIPANT	\N	PRESENT	0
174422	167278	14213J	PARTICIPANT	\N	PRESENT	0
174423	167278	08048B	PARTICIPANT	\N	PRESENT	0
174424	167278	14265W	PARTICIPANT	\N	PRESENT	0
174425	167278	14147R	PARTICIPANT	\N	PRESENT	0
174426	167278	11097X	PARTICIPANT	\N	PRESENT	0
174427	167278	14223L	PARTICIPANT	\N	PRESENT	0
174428	167278	14355X	PARTICIPANT	\N	PRESENT	0
174429	167278	14041T	PARTICIPANT	\N	PRESENT	0
174430	167278	04088S	PARTICIPANT	\N	PRESENT	0
174431	167278	14357A	PARTICIPANT	\N	PRESENT	0
174432	167278	14195A	PARTICIPANT	\N	PRESENT	0
174433	167278	14033T	PARTICIPANT	\N	PRESENT	0
174434	167278	07026Q	PARTICIPANT	\N	PRESENT	0
174435	167278	14235Q	PARTICIPANT	\N	PRESENT	0
174436	167278	08062Y	PARTICIPANT	\N	PRESENT	0
174437	167278	08051V	PARTICIPANT	\N	PRESENT	0
174438	167278	08034U	PARTICIPANT	\N	PRESENT	0
174439	167278	11112D	PARTICIPANT	\N	PRESENT	0
174440	167278	01048V	PARTICIPANT	\N	PRESENT	0
174441	167278	11100Y	PARTICIPANT	\N	PRESENT	0
174442	167278	14215L	PARTICIPANT	\N	PRESENT	0
174443	167278	14227Q	PARTICIPANT	\N	PRESENT	0
174444	167278	08010L	PARTICIPANT	\N	PRESENT	0
208930	207523	19649G	PARTICIPANT	\N	PRESENT	0
209091	207523	14267Y	PARTICIPANT	\N	PRESENT	0
209092	207523	11070L	PARTICIPANT	\N	PRESENT	0
209093	207523	01024M	PARTICIPANT	\N	PRESENT	0
209094	207523	04089T	PARTICIPANT	\N	PRESENT	0
209095	207523	01025N	PARTICIPANT	\N	PRESENT	0
209096	207523	19521Q	PARTICIPANT	\N	PRESENT	0
209097	207523	07004J	PARTICIPANT	\N	PRESENT	0
209098	207523	19533U	PARTICIPANT	\N	PRESENT	0
209099	207523	08056B	PARTICIPANT	\N	PRESENT	0
209100	207523	14059S	PARTICIPANT	\N	PRESENT	0
209101	207523	19569H	PARTICIPANT	\N	PRESENT	0
209102	207523	14073Q	PARTICIPANT	\N	PRESENT	0
209103	207523	19611R	PARTICIPANT	\N	PRESENT	0
209104	207523	19699S	PARTICIPANT	\N	PRESENT	0
209105	207523	14205J	PARTICIPANT	\N	PRESENT	0
209106	207523	14029X	PARTICIPANT	\N	PRESENT	0
209107	207523	14219Q	PARTICIPANT	\N	PRESENT	0
209108	207523	19441R	PARTICIPANT	\N	PRESENT	0
209109	207523	14103D	PARTICIPANT	\N	PRESENT	0
209110	207523	16685X	PARTICIPANT	\N	PRESENT	0
209111	207523	97011G	PARTICIPANT	\N	PRESENT	0
209112	207523	11085T	PARTICIPANT	\N	PRESENT	0
209113	207523	08009T	PARTICIPANT	\N	PRESENT	0
209114	207523	14221J	PARTICIPANT	\N	PRESENT	0
209115	207523	19335Q	PARTICIPANT	\N	PRESENT	0
209116	207523	14038Y	PARTICIPANT	\N	PRESENT	0
208928	207523	04035D	PARTICIPANT	\N	PRESENT	0
208929	207523	04042C	PARTICIPANT	\N	PRESENT	0
209117	207523	04088S	PARTICIPANT	\N	PRESENT	0
209118	207523	14133K	PARTICIPANT	\N	PRESENT	0
209119	207523	19735D	PARTICIPANT	\N	PRESENT	0
209120	207523	19619A	PARTICIPANT	\N	PRESENT	0
209125	207523	19737F	PARTICIPANT	\N	PRESENT	0
209122	207523	04070G	PARTICIPANT	\N	PRESENT	0
209123	207523	01034P	PARTICIPANT	\N	PRESENT	0
209124	207523	19479G	PARTICIPANT	\N	PRESENT	0
209126	207523	08018U	PARTICIPANT	\N	PRESENT	0
209127	207523	19687N	PARTICIPANT	\N	PRESENT	0
209128	207523	11056N	PARTICIPANT	\N	PRESENT	0
209129	207523	19701S	PARTICIPANT	\N	PRESENT	0
209130	207523	19681G	PARTICIPANT	\N	PRESENT	0
209131	207523	11090Q	PARTICIPANT	\N	PRESENT	0
209132	207523	04043D	PARTICIPANT	\N	PRESENT	0
209133	207523	19415P	PARTICIPANT	\N	PRESENT	0
209134	207523	14119M	PARTICIPANT	\N	PRESENT	0
209135	207523	19679N	PARTICIPANT	\N	PRESENT	0
209138	207523	18083K	PARTICIPANT	\N	PRESENT	0
209139	207523	19467C	PARTICIPANT	\N	PRESENT	0
209143	207523	19621T	PARTICIPANT	\N	PRESENT	0
209141	207523	04008A	PARTICIPANT	\N	PRESENT	0
209142	207523	19707Y	PARTICIPANT	\N	PRESENT	0
209144	207523	14281W	PARTICIPANT	\N	PRESENT	0
209145	207523	19269X	PARTICIPANT	\N	PRESENT	0
209146	207523	12016W	PARTICIPANT	\N	PRESENT	0
209147	207523	11110B	PARTICIPANT	\N	PRESENT	0
209148	207523	19647E	PARTICIPANT	\N	PRESENT	0
209149	207523	19591F	PARTICIPANT	\N	PRESENT	0
209150	207523	19715Y	PARTICIPANT	\N	PRESENT	0
209151	207523	19585H	PARTICIPANT	\N	PRESENT	0
209152	207523	11065P	PARTICIPANT	\N	PRESENT	0
209153	207523	04059M	PARTICIPANT	\N	PRESENT	0
209466	207519	11072N	PARTICIPANT	\N	PRESENT	0
209467	207519	07034Q	PARTICIPANT	\N	PRESENT	0
209468	207519	04038G	PARTICIPANT	\N	PRESENT	0
209469	207519	19593H	PARTICIPANT	\N	PRESENT	0
209470	207519	19347U	PARTICIPANT	\N	PRESENT	0
209471	207519	14151M	PARTICIPANT	\N	PRESENT	0
209472	207519	19503N	PARTICIPANT	\N	PRESENT	0
209473	207519	14065Q	PARTICIPANT	\N	PRESENT	0
209474	207519	19725B	PARTICIPANT	\N	PRESENT	0
209475	207519	19543W	PARTICIPANT	\N	PRESENT	0
209476	207519	19681G	PARTICIPANT	\N	PRESENT	0
209477	207519	04057K	PARTICIPANT	\N	PRESENT	0
209478	207519	17589D	PARTICIPANT	\N	PRESENT	0
209479	207519	19581D	PARTICIPANT	\N	PRESENT	0
209480	207519	04089T	PARTICIPANT	\N	PRESENT	0
209481	207519	14205J	PARTICIPANT	\N	PRESENT	0
209482	207519	19441R	PARTICIPANT	\N	PRESENT	0
209483	207519	19737F	PARTICIPANT	\N	PRESENT	0
209484	207519	14103D	PARTICIPANT	\N	PRESENT	0
209485	207519	14087W	PARTICIPANT	\N	PRESENT	0
209486	207519	19367Y	PARTICIPANT	\N	PRESENT	0
209487	207519	19369B	PARTICIPANT	\N	PRESENT	0
209488	207519	19685L	PARTICIPANT	\N	PRESENT	0
209489	207519	04061F	PARTICIPANT	\N	PRESENT	0
209490	207519	19483C	PARTICIPANT	\N	PRESENT	0
209491	207519	19675J	PARTICIPANT	\N	PRESENT	0
209492	207519	14061L	PARTICIPANT	\N	PRESENT	0
209493	207519	97011G	PARTICIPANT	\N	PRESENT	0
209517	207519	14029X	PARTICIPANT	\N	PRESENT	0
209518	207519	19415P	PARTICIPANT	\N	PRESENT	0
209519	207519	08044W	PARTICIPANT	\N	PRESENT	0
209520	207519	19575F	PARTICIPANT	\N	PRESENT	0
209521	207519	14026U	PARTICIPANT	\N	PRESENT	0
209522	207519	19565D	PARTICIPANT	\N	PRESENT	0
209523	207519	19585H	PARTICIPANT	\N	PRESENT	0
209524	207519	14079W	PARTICIPANT	\N	PRESENT	0
209525	207519	14123H	PARTICIPANT	\N	PRESENT	0
209526	207519	14033T	PARTICIPANT	\N	PRESENT	0
209527	207519	80013X	PARTICIPANT	\N	PRESENT	0
209528	207519	04047H	PARTICIPANT	\N	PRESENT	0
209529	207519	14191V	PARTICIPANT	\N	PRESENT	0
209530	207519	11067R	PARTICIPANT	\N	PRESENT	0
209531	207519	14217N	PARTICIPANT	\N	PRESENT	0
209532	207519	19695N	PARTICIPANT	\N	PRESENT	0
209533	207519	19349W	PARTICIPANT	\N	PRESENT	0
209534	207519	19651A	PARTICIPANT	\N	PRESENT	0
209535	207519	14195A	PARTICIPANT	\N	PRESENT	0
209536	207519	11097X	PARTICIPANT	\N	PRESENT	0
209537	207519	17583W	PARTICIPANT	\N	PRESENT	0
209538	208062	14105F	PARTICIPANT	\N	PRESENT	0
209539	208062	19443T	PARTICIPANT	\N	PRESENT	0
209540	208062	19421M	PARTICIPANT	\N	PRESENT	0
209541	208062	14267Y	PARTICIPANT	\N	PRESENT	0
209542	208062	14193X	PARTICIPANT	\N	PRESENT	0
209543	208062	11027H	PARTICIPANT	\N	PRESENT	0
209544	208062	04042C	PRESIDENT	0	PRESENT	0
209545	208062	14028W	PARTICIPANT	\N	PRESENT	0
209546	208062	14211G	PARTICIPANT	\N	PRESENT	0
209547	208062	08047A	PARTICIPANT	\N	PRESENT	0
209548	208062	98029W	PARTICIPANT	\N	PRESENT	0
209549	208062	95030B	PARTICIPANT	\N	PRESENT	0
209550	208062	14235Q	PARTICIPANT	\N	PRESENT	0
209551	208062	14079W	PARTICIPANT	\N	PRESENT	0
209552	208062	01058X	PARTICIPANT	\N	PRESENT	0
209553	208062	04040A	PARTICIPANT	\N	PRESENT	0
209554	208062	11066Q	PARTICIPANT	\N	PRESENT	0
209555	208062	08056B	PARTICIPANT	\N	PRESENT	0
209556	208062	95037J	PARTICIPANT	\N	PRESENT	0
209557	208062	19709B	PARTICIPANT	\N	PRESENT	0
209558	208062	98022P	PARTICIPANT	\N	PRESENT	0
209559	208062	98050T	PARTICIPANT	\N	PRESENT	0
209560	208062	08053X	PARTICIPANT	\N	PRESENT	0
209561	208062	98005N	PARTICIPANT	\N	PRESENT	0
209562	208062	04034C	PARTICIPANT	\N	PRESENT	0
209563	208062	11054L	PARTICIPANT	\N	PRESENT	0
209564	208062	97011G	PARTICIPANT	\N	PRESENT	0
209565	208062	14133K	PARTICIPANT	\N	PRESENT	0
209566	208062	14255U	PARTICIPANT	\N	PRESENT	0
209567	208062	98053W	PARTICIPANT	\N	EXCUSE	0
209568	208062	19583F	PARTICIPANT	\N	EXCUSE	0
209569	208062	11041F	PARTICIPANT	\N	PRESENT	0
209570	208062	01062T	PARTICIPANT	\N	PRESENT	0
209571	208062	11064N	PARTICIPANT	\N	PRESENT	0
209574	208062	16685X	PARTICIPANT	\N	PRESENT	0
209575	208062	95067Q	PARTICIPANT	\N	PRESENT	0
209671	208617	14195A	PARTICIPANT	\N	PRESENT	0
209673	208062	08061X	PARTICIPANT	\N	PRESENT	0
210037	208063	98029W	PARTICIPANT	\N	PRESENT	0
210038	208063	14255U	PARTICIPANT	\N	PRESENT	0
210046	210042	14133K	PARTICIPANT	\N	EXCUSE	0
210047	210042	14065Q	PARTICIPANT	\N	EXCUSE	0
210048	210042	96004D	PRESIDENT	0	PRESENT	0
210049	210042	14089Y	PARTICIPANT	\N	PRESENT	0
210051	210042	14357A	PARTICIPANT	\N	PRESENT	0
210052	210042	14079W	PARTICIPANT	\N	PRESENT	0
210053	210042	14249W	PARTICIPANT	\N	EXCUSE	0
210055	210042	19521Q	PARTICIPANT	\N	PRESENT	0
210056	210042	08018U	PARTICIPANT	\N	EXCUSE	0
210058	210042	11083R	PARTICIPANT	\N	PRESENT	0
210059	210042	14033T	PARTICIPANT	\N	PRESENT	0
210062	210042	19725B	PARTICIPANT	\N	PRESENT	0
179533	167345	04045F	PARTICIPANT	\N	PRESENT	0
179534	167345	14269B	PARTICIPANT	\N	PRESENT	0
179535	167345	14063N	PARTICIPANT	\N	PRESENT	0
179536	167345	11093T	PARTICIPANT	\N	PRESENT	0
179362	167345	01007L	PARTICIPANT	\N	PRESENT	0
179532	167345	01046T	PARTICIPANT	\N	PRESENT	0
179537	167345	14159V	PARTICIPANT	\N	PRESENT	0
179538	167345	96004D	PARTICIPANT	\N	PRESENT	0
179539	167345	04067M	PARTICIPANT	\N	PRESENT	0
179540	167345	14193X	PARTICIPANT	\N	PRESENT	0
179541	167345	01060R	PARTICIPANT	\N	PRESENT	0
179542	167345	14327T	PARTICIPANT	\N	PRESENT	0
179543	167345	01059Y	PARTICIPANT	\N	PRESENT	0
179544	167345	01044R	PARTICIPANT	\N	PRESENT	0
179545	167345	11061K	PARTICIPANT	\N	PRESENT	0
179546	167345	14271U	PARTICIPANT	\N	PRESENT	0
179547	167345	11094U	PARTICIPANT	\N	PRESENT	0
179548	167345	11099A	PARTICIPANT	\N	PRESENT	0
179549	167345	11029K	PARTICIPANT	\N	PRESENT	0
179550	167345	11033F	PARTICIPANT	\N	PRESENT	0
179551	167345	14249W	PARTICIPANT	\N	PRESENT	0
179552	167345	04088S	PARTICIPANT	\N	PRESENT	0
179553	167345	11067R	PARTICIPANT	\N	PRESENT	0
179554	167345	11104D	PARTICIPANT	\N	PRESENT	0
179555	167345	14179A	PARTICIPANT	\N	PRESENT	0
179556	167345	14267Y	PARTICIPANT	\N	PRESENT	0
179557	167345	11103C	PARTICIPANT	\N	PRESENT	0
179558	167345	14151M	PARTICIPANT	\N	PRESENT	0
179559	167345	01013J	PARTICIPANT	\N	PRESENT	0
179560	167345	08065C	PARTICIPANT	\N	PRESENT	0
179561	167345	11065P	PARTICIPANT	\N	PRESENT	0
179562	167345	14107H	PARTICIPANT	\N	PRESENT	0
179563	167345	12042Y	PARTICIPANT	\N	PRESENT	0
179572	167345	14051J	PARTICIPANT	\N	PRESENT	0
179573	167345	04053F	PARTICIPANT	\N	PRESENT	0
179574	167345	14281W	PARTICIPANT	\N	PRESENT	0
179575	167345	11083R	PARTICIPANT	\N	PRESENT	0
179576	167345	14219Q	PARTICIPANT	\N	PRESENT	0
179577	167345	04089T	PARTICIPANT	\N	PRESENT	0
179578	167345	98050T	PARTICIPANT	\N	PRESENT	0
179579	167345	14195A	PARTICIPANT	\N	PRESENT	0
179580	167345	14119M	PARTICIPANT	\N	PRESENT	0
179581	167345	92045V	PARTICIPANT	\N	PRESENT	0
179592	167345	11048N	PARTICIPANT	\N	PRESENT	0
179612	167345	80027E	PARTICIPANT	\N	PRESENT	0
179613	167345	14028W	PARTICIPANT	\N	PRESENT	0
179614	167345	01022K	PARTICIPANT	\N	PRESENT	0
179632	167345	14147R	PARTICIPANT	\N	PRESENT	0
179633	167345	14059S	PARTICIPANT	\N	PRESENT	0
179634	167345	14038Y	PARTICIPANT	\N	PRESENT	0
179635	167345	01016M	PARTICIPANT	\N	PRESENT	0
179636	167345	14205J	PARTICIPANT	\N	PRESENT	0
179692	167345	11063M	PARTICIPANT	\N	PRESENT	0
179712	167345	14331P	PARTICIPANT	\N	PRESENT	0
179732	167345	95030B	PARTICIPANT	\N	PRESENT	0
179753	167345	01043Q	PARTICIPANT	\N	PRESENT	0
179754	167345	80013X	PARTICIPANT	\N	PRESENT	0
179757	167345	14069U	PARTICIPANT	\N	PRESENT	0
179792	167345	14033T	PARTICIPANT	\N	PRESENT	0
179793	167345	11057P	PARTICIPANT	\N	PRESENT	0
179794	167345	14257W	PARTICIPANT	\N	PRESENT	0
179795	167345	01047U	PARTICIPANT	\N	PRESENT	0
179796	167345	14061L	PARTICIPANT	\N	PRESENT	0
179797	167345	14211G	PARTICIPANT	\N	PRESENT	0
179798	167345	95062K	PARTICIPANT	\N	PRESENT	0
179799	167345	05012A	PARTICIPANT	\N	PRESENT	0
179800	167345	14363X	PARTICIPANT	\N	PRESENT	0
179801	167345	08015R	PARTICIPANT	\N	PRESENT	0
179812	167345	14357A	PARTICIPANT	\N	PRESENT	0
179813	167345	14217N	PARTICIPANT	\N	PRESENT	0
179814	167345	14026U	PARTICIPANT	\N	PRESENT	0
179815	167345	04035D	PARTICIPANT	\N	PRESENT	0
179816	167345	08009T	PARTICIPANT	\N	PRESENT	0
179817	167345	14103D	PARTICIPANT	\N	PRESENT	0
179819	167345	04066L	PARTICIPANT	\N	PRESENT	0
179820	167345	90003B	PARTICIPANT	\N	PRESENT	0
179821	167345	14105F	PARTICIPANT	\N	PRESENT	0
179832	167345	95035G	PARTICIPANT	\N	PRESENT	0
179834	167345	14169X	PARTICIPANT	\N	PRESENT	0
179837	167345	08051V	PARTICIPANT	\N	PRESENT	0
179838	167345	11084S	PARTICIPANT	\N	PRESENT	0
179852	167345	14097Y	PARTICIPANT	\N	PRESENT	0
179853	167345	04050C	PARTICIPANT	\N	PRESENT	0
179854	167345	14013P	PARTICIPANT	\N	PRESENT	0
179969	167346	11065P	PARTICIPANT	\N	PRESENT	0
179970	167346	14199E	PARTICIPANT	\N	PRESENT	0
179971	167346	14105F	PARTICIPANT	\N	PRESENT	0
179972	167346	08019V	PARTICIPANT	\N	PRESENT	0
179973	167346	14357A	PARTICIPANT	\N	PRESENT	0
179974	167346	04088S	PARTICIPANT	\N	PRESENT	0
179975	167346	11101A	PARTICIPANT	\N	PRESENT	0
179976	167346	14157T	PARTICIPANT	\N	PRESENT	0
179977	167346	14195A	PARTICIPANT	\N	PRESENT	0
179978	167346	14119M	PARTICIPANT	\N	PRESENT	0
179979	167346	14169X	PARTICIPANT	\N	PRESENT	0
179980	167346	95062K	PARTICIPANT	\N	PRESENT	0
179981	167346	95067Q	PARTICIPANT	\N	PRESENT	0
179982	167346	11097X	PARTICIPANT	\N	PRESENT	0
179983	167346	08015R	PARTICIPANT	\N	PRESENT	0
179984	167346	08065C	PARTICIPANT	\N	PRESENT	0
179985	167346	14059S	PARTICIPANT	\N	PRESENT	0
179986	167346	14187A	PARTICIPANT	\N	PRESENT	0
179987	167346	14061L	PARTICIPANT	\N	PRESENT	0
179988	167346	14217N	PARTICIPANT	\N	PRESENT	0
179989	167346	10006L	PARTICIPANT	\N	PRESENT	0
179990	167346	14331P	PARTICIPANT	\N	PRESENT	0
179991	167346	05012A	PARTICIPANT	\N	PRESENT	0
179992	167346	04057K	PARTICIPANT	\N	PRESENT	0
179993	167346	90003B	PARTICIPANT	\N	PRESENT	0
179994	167346	14069U	PARTICIPANT	\N	PRESENT	0
179995	167346	95035G	PARTICIPANT	\N	PRESENT	0
179996	167346	14267Y	PARTICIPANT	\N	PRESENT	0
179997	167346	04067M	PARTICIPANT	\N	PRESENT	0
179998	167346	01044R	PARTICIPANT	\N	PRESENT	0
179999	167346	11029K	PARTICIPANT	\N	PRESENT	0
180000	167346	11084S	PARTICIPANT	\N	PRESENT	0
180001	167346	11083R	PARTICIPANT	\N	PRESENT	0
180002	167346	14107H	PARTICIPANT	\N	PRESENT	0
180003	167346	04053F	PARTICIPANT	\N	PRESENT	0
180004	167346	01016M	PARTICIPANT	\N	PRESENT	0
180005	167346	11107G	PARTICIPANT	\N	PRESENT	0
180006	167346	14097Y	PARTICIPANT	\N	PRESENT	0
180007	167346	14051J	PARTICIPANT	\N	PRESENT	0
180008	167346	14063N	PARTICIPANT	\N	PRESENT	0
180009	167346	11057P	PARTICIPANT	\N	PRESENT	0
180010	167346	01022K	PARTICIPANT	\N	PRESENT	0
180011	167346	80013X	PARTICIPANT	\N	PRESENT	0
180012	167346	80027E	PARTICIPANT	\N	PRESENT	0
180013	167346	04050C	PARTICIPANT	\N	PRESENT	0
180014	167346	14013P	PARTICIPANT	\N	PRESENT	0
180015	167346	88008L	PARTICIPANT	\N	PRESENT	0
180016	167346	11012A	PARTICIPANT	\N	PRESENT	0
180017	167346	14219Q	PARTICIPANT	\N	PRESENT	0
180018	167346	14329V	PARTICIPANT	\N	PRESENT	0
180032	167346	14033T	PARTICIPANT	\N	PRESENT	0
180033	167346	14135M	PARTICIPANT	\N	PRESENT	0
180072	167346	14121F	PARTICIPANT	\N	PRESENT	0
180074	167346	11099A	PARTICIPANT	\N	PRESENT	0
180076	167346	14026U	PARTICIPANT	\N	PRESENT	0
180079	167346	14265W	PARTICIPANT	\N	PRESENT	0
180092	167346	14201E	PARTICIPANT	\N	PRESENT	0
180093	167346	14197C	PARTICIPANT	\N	PRESENT	0
180112	167346	12042Y	PARTICIPANT	\N	PRESENT	0
180113	167346	97011G	PARTICIPANT	\N	PRESENT	0
180114	167346	01025N	PARTICIPANT	\N	PRESENT	0
180115	167346	14205J	PARTICIPANT	\N	PRESENT	0
180116	167346	08055A	PARTICIPANT	\N	PRESENT	0
180132	167346	87003B	PARTICIPANT	\N	PRESENT	0
180133	167346	04042C	PARTICIPANT	\N	PRESENT	0
180135	167346	14221J	PARTICIPANT	\N	PRESENT	0
180152	167346	14079W	PARTICIPANT	\N	PRESENT	0
180153	167346	14215L	PARTICIPANT	\N	PRESENT	0
180154	167346	14327T	PARTICIPANT	\N	PRESENT	0
180155	167346	14103D	PARTICIPANT	\N	PRESENT	0
180156	167346	11031D	PARTICIPANT	\N	PRESENT	0
180157	167346	08068F	PARTICIPANT	\N	PRESENT	0
180158	167346	11036J	PARTICIPANT	\N	PRESENT	0
180159	167346	11103C	PARTICIPANT	\N	PRESENT	0
180160	167346	11048N	PARTICIPANT	\N	PRESENT	0
179967	167346	04066L	PARTICIPANT	\N	PRESENT	0
179968	167346	08009T	PARTICIPANT	\N	PRESENT	0
180161	167346	14173T	PARTICIPANT	\N	PRESENT	0
180162	167346	01046T	PARTICIPANT	\N	PRESENT	0
180172	167346	01048V	PARTICIPANT	\N	PRESENT	0
180192	167346	14223L	PARTICIPANT	\N	PRESENT	0
180212	167346	08060W	PARTICIPANT	\N	PRESENT	0
180232	167346	14361V	PARTICIPANT	\N	PRESENT	0
180233	167346	14159V	PARTICIPANT	\N	PRESENT	0
172958	172956	01008M	PARTICIPANT	\N	PRESENT	0
172961	172956	04038G	PARTICIPANT	\N	PRESENT	0
172962	172956	01041N	PARTICIPANT	\N	PRESENT	0
172963	172956	14107H	PARTICIPANT	\N	PRESENT	0
172964	172956	99004R	PRESIDENT	0	PRESENT	0
172966	172956	11066Q	PARTICIPANT	\N	PRESENT	0
172967	172956	08012N	PARTICIPANT	\N	PRESENT	0
172968	172956	08062Y	PARTICIPANT	\N	PRESENT	0
172969	172956	01059Y	PARTICIPANT	\N	PRESENT	0
172971	172956	14257W	PARTICIPANT	\N	PRESENT	0
172974	172973	14133K	PARTICIPANT	\N	PRESENT	0
172975	172973	96004D	PRESIDENT	0	PRESENT	0
172976	172973	11040E	PARTICIPANT	\N	EXCUSE	0
172977	172973	14089Y	PARTICIPANT	\N	PRESENT	0
172978	172973	90003B	PARTICIPANT	\N	PRESENT	0
172979	172973	11035H	PARTICIPANT	\N	EXCUSE	0
172981	172973	95030B	PARTICIPANT	\N	EXCUSE	0
172982	172973	08018U	PARTICIPANT	\N	EXCUSE	0
172985	172973	14097Y	PARTICIPANT	\N	PRESENT	0
172987	172973	14073Q	PARTICIPANT	\N	PRESENT	0
172988	172973	11026G	PARTICIPANT	\N	PRESENT	0
172990	172973	98046X	PARTICIPANT	\N	PRESENT	0
172991	172973	14001X	PARTICIPANT	\N	PRESENT	0
172993	172973	04057K	PARTICIPANT	\N	EXCUSE	0
172994	172973	01016M	PARTICIPANT	\N	PRESENT	0
172995	172973	04045F	PARTICIPANT	\N	PRESENT	0
172996	172973	92045V	PARTICIPANT	\N	PRESENT	0
172997	172973	98035U	PARTICIPANT	\N	PRESENT	0
173012	159521	04049K	PRESIDENT	0	PRESENT	0
173013	159521	89017R	PARTICIPANT	\N	PRESENT	0
173014	159521	14255U	PARTICIPANT	\N	PRESENT	0
173015	159521	14157T	PARTICIPANT	\N	PRESENT	0
173016	159521	14061L	PARTICIPANT	\N	PRESENT	0
173017	159521	14030Q	PARTICIPANT	\N	PRESENT	0
173018	159521	14079W	PARTICIPANT	\N	PRESENT	0
173019	159521	14105F	PARTICIPANT	\N	PRESENT	0
173020	159521	14265W	PARTICIPANT	\N	PRESENT	0
173021	159521	08068F	PARTICIPANT	\N	PRESENT	0
173022	159521	14087W	PARTICIPANT	\N	PRESENT	0
173023	159521	04053F	PARTICIPANT	\N	PRESENT	0
173024	159521	14083S	PARTICIPANT	\N	PRESENT	0
173026	159521	14205J	PARTICIPANT	\N	PRESENT	0
173039	159521	14261S	PARTICIPANT	\N	EXCUSE	0
173040	159521	14065Q	PARTICIPANT	\N	EXCUSE	0
173042	159521	14013P	PARTICIPANT	\N	EXCUSE	0
173043	159521	14207L	PARTICIPANT	\N	EXCUSE	0
173045	159521	11088W	PARTICIPANT	\N	EXCUSE	0
173046	159521	14041T	PARTICIPANT	\N	EXCUSE	0
173048	159521	04071H	PARTICIPANT	\N	EXCUSE	0
173050	159521	14151M	PARTICIPANT	\N	EXCUSE	0
173051	159521	02002K	PARTICIPANT	\N	EXCUSE	0
173052	159521	14034U	PARTICIPANT	\N	EXCUSE	0
173053	159521	14121F	PARTICIPANT	\N	EXCUSE	0
173055	159521	95041E	PARTICIPANT	\N	EXCUSE	0
173057	159521	14039A	PARTICIPANT	\N	EXCUSE	0
173058	159521	14253S	PARTICIPANT	\N	EXCUSE	0
173060	159521	11090Q	PARTICIPANT	\N	EXCUSE	0
173063	159521	10015M	PARTICIPANT	\N	EXCUSE	0
173064	159521	95067Q	PARTICIPANT	\N	EXCUSE	0
173065	159521	11063M	PARTICIPANT	\N	EXCUSE	0
173153	173151	11039M	PARTICIPANT	\N	PRESENT	0
173154	173151	98042T	PARTICIPANT	\N	PRESENT	0
173155	173151	01019Q	PARTICIPANT	\N	PRESENT	0
173208	173207	14089Y	PARTICIPANT	\N	PRESENT	0
173209	173207	14207L	PARTICIPANT	\N	PRESENT	0
173610	173608	95015C	PARTICIPANT	\N	PRESENT	0
173631	173629	95015C	PARTICIPANT	\N	PRESENT	0
173632	173629	14241N	PARTICIPANT	\N	PRESENT	0
173653	173652	11053K	PARTICIPANT	\N	PRESENT	0
173654	173652	01031L	PARTICIPANT	\N	PRESENT	0
173655	173652	14083S	PARTICIPANT	\N	PRESENT	0
173656	173652	14041T	PARTICIPANT	\N	PRESENT	0
173657	173652	08028W	PARTICIPANT	\N	PRESENT	0
173658	173652	95067Q	PARTICIPANT	\N	PRESENT	0
173659	173652	04040A	PARTICIPANT	\N	PRESENT	0
173660	173652	11027H	PARTICIPANT	\N	PRESENT	0
180235	167346	95015C	PARTICIPANT	\N	PRESENT	0
180236	167346	04043D	PARTICIPANT	\N	PRESENT	0
180252	167346	14042U	PARTICIPANT	\N	PRESENT	0
180340	167347	04067M	PARTICIPANT	\N	PRESENT	0
180341	167347	11061K	PARTICIPANT	\N	PRESENT	0
180342	167347	04092N	PARTICIPANT	\N	PRESENT	0
180343	167347	11031D	PARTICIPANT	\N	PRESENT	0
180344	167347	11081P	PARTICIPANT	\N	PRESENT	0
180345	167347	08009T	PARTICIPANT	\N	PRESENT	0
180346	167347	11036J	PARTICIPANT	\N	PRESENT	0
180347	167347	14265W	PARTICIPANT	\N	PRESENT	0
180348	167347	14221J	PARTICIPANT	\N	PRESENT	0
180349	167347	14195A	PARTICIPANT	\N	PRESENT	0
180350	167347	14042U	PARTICIPANT	\N	PRESENT	0
180351	167347	10006L	PARTICIPANT	\N	PRESENT	0
180352	167347	14157T	PARTICIPANT	\N	PRESENT	0
180353	167347	14013P	PARTICIPANT	\N	PRESENT	0
180354	167347	14361V	PARTICIPANT	\N	PRESENT	0
180355	167347	80013X	PARTICIPANT	\N	PRESENT	0
180356	167347	11014C	PARTICIPANT	\N	PRESENT	0
180357	167347	14014Q	PARTICIPANT	\N	PRESENT	0
180358	167347	14103D	PARTICIPANT	\N	PRESENT	0
180359	167347	14083S	PARTICIPANT	\N	PRESENT	0
180360	167347	04043D	PARTICIPANT	\N	PRESENT	0
180361	167347	14217N	PARTICIPANT	\N	PRESENT	0
180362	167347	14187A	PARTICIPANT	\N	PRESENT	0
180363	167347	14053L	PARTICIPANT	\N	PRESENT	0
180364	167347	08015R	PARTICIPANT	\N	PRESENT	0
180365	167347	11103C	PARTICIPANT	\N	PRESENT	0
180366	167347	01057W	PARTICIPANT	\N	PRESENT	0
180367	167347	04088S	PARTICIPANT	\N	PRESENT	0
180368	167347	14119M	PARTICIPANT	\N	PRESENT	0
180369	167347	95062K	PARTICIPANT	\N	PRESENT	0
180373	167347	11048N	PARTICIPANT	\N	PRESENT	0
180371	167347	14331P	PARTICIPANT	\N	PRESENT	0
180372	167347	14037X	PARTICIPANT	\N	PRESENT	0
180374	167347	14223L	PARTICIPANT	\N	PRESENT	0
180375	167347	11097X	PARTICIPANT	\N	PRESENT	0
180392	167347	14271U	PARTICIPANT	\N	PRESENT	0
180393	167347	14147R	PARTICIPANT	\N	PRESENT	0
180394	167347	14231L	PARTICIPANT	\N	PRESENT	0
180395	167347	11112D	PARTICIPANT	\N	PRESENT	0
180396	167347	01008M	PARTICIPANT	\N	PRESENT	0
180414	167347	14327T	PARTICIPANT	\N	PRESENT	0
180415	167347	14215L	PARTICIPANT	\N	PRESENT	0
180416	167347	01059Y	PARTICIPANT	\N	PRESENT	0
180417	167347	11043H	PARTICIPANT	\N	PRESENT	0
180432	167347	14089Y	PARTICIPANT	\N	PRESENT	0
180433	167347	14097Y	PARTICIPANT	\N	PRESENT	0
180452	167347	11063M	PARTICIPANT	\N	PRESENT	0
180453	167347	14207L	PARTICIPANT	\N	PRESENT	0
180454	167347	08043V	PARTICIPANT	\N	PRESENT	0
180455	167347	14109K	PARTICIPANT	\N	PRESENT	0
180456	167347	14031R	PARTICIPANT	\N	PRESENT	0
180532	167350	04066L	PARTICIPANT	\N	PRESENT	0
180533	167350	05008E	PARTICIPANT	\N	PRESENT	0
180534	167350	14215L	PARTICIPANT	\N	PRESENT	0
180535	167350	95063L	PARTICIPANT	\N	PRESENT	0
180536	167350	95062K	PARTICIPANT	\N	PRESENT	0
180537	167350	04038G	PARTICIPANT	\N	PRESENT	0
180538	167350	04067M	PARTICIPANT	\N	PRESENT	0
180539	167350	14119M	PARTICIPANT	\N	PRESENT	0
180540	167350	14195A	PARTICIPANT	\N	PRESENT	0
180541	167350	98053W	PARTICIPANT	\N	PRESENT	0
180552	167350	14069U	PARTICIPANT	\N	PRESENT	0
180572	167350	14034U	PARTICIPANT	\N	PRESENT	0
180573	167350	11070L	PARTICIPANT	\N	PRESENT	0
180574	167350	14083S	PARTICIPANT	\N	PRESENT	0
180575	167350	14159V	PARTICIPANT	\N	PRESENT	0
180338	167347	04066L	PARTICIPANT	\N	PRESENT	0
180339	167347	14267Y	PARTICIPANT	\N	PRESENT	0
180576	167350	14173T	PARTICIPANT	\N	PRESENT	0
180577	167350	11048N	PARTICIPANT	\N	PRESENT	0
180578	167350	14249W	PARTICIPANT	\N	PRESENT	0
180592	167350	14271U	PARTICIPANT	\N	PRESENT	0
180612	167350	95041E	PARTICIPANT	\N	PRESENT	0
187113	187112	14093U	PARTICIPANT	\N	PRESENT	0
187114	187112	04036E	PARTICIPANT	\N	PRESENT	0
187115	187112	83042R	PARTICIPANT	\N	PRESENT	0
188393	188392	08018U	PARTICIPANT	\N	EXCUSE	0
188394	188392	04057K	PARTICIPANT	\N	EXCUSE	0
188395	188392	14079W	PARTICIPANT	\N	EXCUSE	0
188396	188392	14249W	PARTICIPANT	\N	EXCUSE	0
188397	188392	11026G	PARTICIPANT	\N	EXCUSE	0
188398	188392	04054G	PARTICIPANT	\N	EXCUSE	0
188399	188392	92045V	PARTICIPANT	\N	EXCUSE	0
188400	188392	11012A	PARTICIPANT	\N	EXCUSE	0
188401	188392	11035H	PARTICIPANT	\N	EXCUSE	0
188402	188392	04035D	PARTICIPANT	\N	EXCUSE	0
188403	188392	96004D	PARTICIPANT	\N	PRESENT	0
188404	188392	04061F	PARTICIPANT	\N	PRESENT	0
188405	188392	04080J	PARTICIPANT	\N	PRESENT	0
188406	188392	14001X	PARTICIPANT	\N	PRESENT	0
173179	167024	01046T	PARTICIPANT	\N	PRESENT	0
173180	167024	08031R	PARTICIPANT	\N	PRESENT	0
173181	167024	04078Q	PARTICIPANT	\N	PRESENT	0
173182	167024	08051V	PARTICIPANT	\N	PRESENT	0
173183	167024	01007L	PARTICIPANT	\N	PRESENT	0
173184	167024	14327T	PARTICIPANT	\N	PRESENT	0
173185	167024	01043Q	PARTICIPANT	\N	PRESENT	0
173186	167024	08009T	PARTICIPANT	\N	PRESENT	0
173187	167024	14157T	PARTICIPANT	\N	PRESENT	0
173188	167024	11085T	PARTICIPANT	\N	PRESENT	0
173189	167024	14255U	PARTICIPANT	\N	PRESENT	0
173190	167024	04089T	PARTICIPANT	\N	PRESENT	0
173191	167024	14179A	PARTICIPANT	\N	PRESENT	0
173192	167024	14083S	PARTICIPANT	\N	PRESENT	0
173193	167024	14073Q	PARTICIPANT	\N	PRESENT	0
173197	167024	14231L	PARTICIPANT	\N	PRESENT	0
173195	167024	14221J	PARTICIPANT	\N	PRESENT	0
173196	167024	11093T	PARTICIPANT	\N	PRESENT	0
173198	167024	11110B	PARTICIPANT	\N	PRESENT	0
173199	167024	08048B	PARTICIPANT	\N	PRESENT	0
173200	167024	95067Q	PARTICIPANT	\N	PRESENT	0
173201	167024	14042U	PARTICIPANT	\N	PRESENT	0
173202	167024	14034U	PARTICIPANT	\N	PRESENT	0
173203	167024	14059S	PARTICIPANT	\N	PRESENT	0
173204	167024	11025F	PARTICIPANT	\N	PRESENT	0
173205	167024	14259Y	PARTICIPANT	\N	PRESENT	0
173206	167024	10006L	PARTICIPANT	\N	PRESENT	0
173210	167024	14055N	PARTICIPANT	\N	PRESENT	0
173211	167024	89017R	PARTICIPANT	\N	PRESENT	0
173212	167024	14197C	PARTICIPANT	\N	PRESENT	0
173213	167024	98053W	PARTICIPANT	\N	PRESENT	0
173214	167024	01013J	PARTICIPANT	\N	PRESENT	0
173232	167024	14193X	PARTICIPANT	\N	PRESENT	0
173233	167024	14065Q	PARTICIPANT	\N	PRESENT	0
173234	167024	11061K	PARTICIPANT	\N	PRESENT	0
173235	167024	11027H	PARTICIPANT	\N	PRESENT	0
173236	167024	11026G	PARTICIPANT	\N	PRESENT	0
173308	167025	14179A	PARTICIPANT	\N	PRESENT	0
173309	167025	14261S	PARTICIPANT	\N	PRESENT	0
173310	167025	08060W	PARTICIPANT	\N	PRESENT	0
173311	167025	01044R	PARTICIPANT	\N	PRESENT	0
173312	167025	14227Q	PARTICIPANT	\N	PRESENT	0
173313	167025	14063N	PARTICIPANT	\N	PRESENT	0
173314	167025	11106F	PARTICIPANT	\N	PRESENT	0
173315	167025	14123H	PARTICIPANT	\N	PRESENT	0
173316	167025	14223L	PARTICIPANT	\N	PRESENT	0
173317	167025	90003B	PARTICIPANT	\N	PRESENT	0
173318	167025	07034Q	PARTICIPANT	\N	PRESENT	0
173319	167025	11101A	PARTICIPANT	\N	PRESENT	0
173320	167025	14041T	PARTICIPANT	\N	PRESENT	0
173321	167025	86034E	PARTICIPANT	\N	PRESENT	0
173322	167025	10006L	PARTICIPANT	\N	PRESENT	0
173323	167025	14175V	PARTICIPANT	\N	PRESENT	0
173324	167025	14331P	PARTICIPANT	\N	PRESENT	0
173325	167025	14205J	PARTICIPANT	\N	PRESENT	0
173326	167025	11037K	PARTICIPANT	\N	PRESENT	0
173327	167025	08062Y	PARTICIPANT	\N	PRESENT	0
173328	167025	14133K	PARTICIPANT	\N	PRESENT	0
173330	167025	08018U	PARTICIPANT	\N	PRESENT	0
173331	167025	08022Q	PARTICIPANT	\N	PRESENT	0
173332	167025	11103C	PARTICIPANT	\N	PRESENT	0
173333	167025	14033T	PARTICIPANT	\N	PRESENT	0
173334	167025	96004D	PARTICIPANT	\N	PRESENT	0
173338	167025	11088W	PARTICIPANT	\N	PRESENT	0
173341	167025	04074L	PARTICIPANT	\N	PRESENT	0
173346	167025	98050T	PARTICIPANT	\N	PRESENT	0
173347	167025	11044J	PARTICIPANT	\N	PRESENT	0
173348	167025	14135M	PARTICIPANT	\N	PRESENT	0
173349	167025	04088S	PARTICIPANT	\N	PRESENT	0
173354	167025	07029T	PARTICIPANT	\N	PRESENT	0
173355	167025	11048N	PARTICIPANT	\N	PRESENT	0
173356	167025	14357A	PARTICIPANT	\N	PRESENT	0
173357	167025	11015D	PARTICIPANT	\N	PRESENT	0
173358	167025	80027E	PARTICIPANT	\N	PRESENT	0
173359	167025	01022K	PARTICIPANT	\N	PRESENT	0
173360	167025	14028W	PARTICIPANT	\N	PRESENT	0
173361	167025	14107H	PARTICIPANT	\N	PRESENT	0
173362	167025	11074Q	PARTICIPANT	\N	PRESENT	0
173363	167025	08024S	PARTICIPANT	\N	PRESENT	0
173364	167025	95059Q	PARTICIPANT	\N	PRESENT	0
173365	167025	04059M	PARTICIPANT	\N	PRESENT	0
173366	167025	11066Q	PARTICIPANT	\N	PRESENT	0
173367	167025	97011G	PARTICIPANT	\N	PRESENT	0
173368	167025	14085U	PARTICIPANT	\N	PRESENT	0
173369	167025	14191V	PARTICIPANT	\N	PRESENT	0
173370	167025	11025F	PARTICIPANT	\N	PRESENT	0
173371	167025	11057P	PARTICIPANT	\N	PRESENT	0
173372	167025	08068F	PARTICIPANT	\N	PRESENT	0
173373	167025	14239U	PARTICIPANT	\N	PRESENT	0
173374	167025	14199E	PARTICIPANT	\N	PRESENT	0
173375	167025	04036E	PARTICIPANT	\N	PRESENT	0
173376	167025	04097T	PARTICIPANT	\N	PRESENT	0
173377	167025	77002U	PARTICIPANT	\N	PRESENT	0
173378	167025	95015C	PARTICIPANT	\N	PRESENT	0
173379	167025	11107G	PARTICIPANT	\N	PRESENT	0
173380	167025	12042Y	PARTICIPANT	\N	PRESENT	0
173381	167025	11100Y	PARTICIPANT	\N	PRESENT	0
173382	167025	98022P	PARTICIPANT	\N	PRESENT	0
173383	167025	14187A	PARTICIPANT	\N	PRESENT	0
173384	167025	04077P	PARTICIPANT	\N	PRESENT	0
173385	167025	14193X	PARTICIPANT	\N	PRESENT	0
173386	167025	98046X	PARTICIPANT	\N	PRESENT	0
173387	167025	11097X	PARTICIPANT	\N	PRESENT	0
173388	167025	98018T	PARTICIPANT	\N	PRESENT	0
173389	167025	07026Q	PARTICIPANT	\N	PRESENT	0
173390	167025	04092N	PARTICIPANT	\N	PRESENT	0
173391	167025	14013P	PARTICIPANT	\N	PRESENT	0
173392	167025	01015L	PARTICIPANT	\N	PRESENT	0
173393	167025	11098Y	PARTICIPANT	\N	PRESENT	0
173394	167025	08039A	PARTICIPANT	\N	PRESENT	0
173395	167025	95062K	PARTICIPANT	\N	PRESENT	0
173396	167025	04050C	PARTICIPANT	\N	PRESENT	0
173397	167025	14361V	PARTICIPANT	\N	PRESENT	0
173398	167025	14257W	PARTICIPANT	\N	PRESENT	0
173399	167025	05012A	PARTICIPANT	\N	PRESENT	0
173400	167025	08028W	PARTICIPANT	\N	PRESENT	0
173401	167025	01027Q	PARTICIPANT	\N	PRESENT	0
173402	167025	95030B	PARTICIPANT	\N	PRESENT	0
173403	167025	01041N	PARTICIPANT	\N	PRESENT	0
173404	167025	08041T	PARTICIPANT	\N	PRESENT	0
173405	167025	08048B	PARTICIPANT	\N	PRESENT	0
173406	167025	14265W	PARTICIPANT	\N	PRESENT	0
173407	167025	01008M	PARTICIPANT	\N	PRESENT	0
173408	167025	04043D	PARTICIPANT	\N	PRESENT	0
173409	167025	14059S	PARTICIPANT	\N	PRESENT	0
173410	167025	99004R	PARTICIPANT	\N	PRESENT	0
173411	167025	11043H	PARTICIPANT	\N	PRESENT	0
173412	167025	01058X	PARTICIPANT	\N	PRESENT	0
173413	167025	14061L	PARTICIPANT	\N	PRESENT	0
173414	167025	14037X	PARTICIPANT	\N	PRESENT	0
173415	167025	86044G	PARTICIPANT	\N	PRESENT	0
173416	167025	14111D	PARTICIPANT	\N	PRESENT	0
173417	167025	11080N	PARTICIPANT	\N	PRESENT	0
173418	167025	98023Q	PARTICIPANT	\N	PRESENT	0
173419	167025	14079W	PARTICIPANT	\N	PRESENT	0
173420	167025	04086Q	PARTICIPANT	\N	PRESENT	0
173421	167025	14087W	PARTICIPANT	\N	PRESENT	0
173422	167025	92031P	PARTICIPANT	\N	PRESENT	0
173423	167025	95035G	PARTICIPANT	\N	PRESENT	0
173424	167025	92045V	PARTICIPANT	\N	PRESENT	0
173425	167025	14249W	PARTICIPANT	\N	PRESENT	0
173426	167025	08034U	PARTICIPANT	\N	PRESENT	0
173427	167025	14105F	PARTICIPANT	\N	PRESENT	0
173428	167025	04044E	PARTICIPANT	\N	PRESENT	0
173429	167025	11030C	PARTICIPANT	\N	PRESENT	0
173430	167025	12041X	PARTICIPANT	\N	PRESENT	0
173431	167025	11049P	PARTICIPANT	\N	PRESENT	0
173432	167025	01013J	PARTICIPANT	\N	PRESENT	0
173433	167025	04085P	PARTICIPANT	\N	PRESENT	0
173434	167025	14209N	PARTICIPANT	\N	PRESENT	0
173435	167025	92040Q	PARTICIPANT	\N	PRESENT	0
173436	167025	14355X	PARTICIPANT	\N	PRESENT	0
173437	167025	11034G	PARTICIPANT	\N	PRESENT	0
173438	167025	08010L	PARTICIPANT	\N	PRESENT	0
173439	167025	14263U	PARTICIPANT	\N	PRESENT	0
173440	167025	11031D	PARTICIPANT	\N	PRESENT	0
173441	167025	98021N	PARTICIPANT	\N	PRESENT	0
173442	167025	04034C	PARTICIPANT	\N	PRESENT	0
173443	167025	95037J	PARTICIPANT	\N	PRESENT	0
173444	167025	08042U	PARTICIPANT	\N	PRESENT	0
173445	167025	08058D	PARTICIPANT	\N	PRESENT	0
173446	167025	08016S	PARTICIPANT	\N	PRESENT	0
173447	167025	01016M	PARTICIPANT	\N	PRESENT	0
173448	167025	98035U	PARTICIPANT	\N	PRESENT	0
173449	167025	14213J	PARTICIPANT	\N	PRESENT	0
173450	167025	04056J	PARTICIPANT	\N	PRESENT	0
173451	167025	14217N	PARTICIPANT	\N	PRESENT	0
173452	167025	11039M	PARTICIPANT	\N	PRESENT	0
167281	167280	11082Q	PARTICIPANT	\N	PRESENT	0
167387	167386	14089Y	PARTICIPANT	\N	PRESENT	0
167392	167386	14207L	PARTICIPANT	\N	PRESENT	0
167393	167386	11029K	PARTICIPANT	\N	PRESENT	0
167394	167386	14229S	PARTICIPANT	\N	PRESENT	0
167653	167652	14193X	PARTICIPANT	\N	PRESENT	0
167654	167652	11054L	PARTICIPANT	\N	PRESENT	0
167655	167652	04040A	PARTICIPANT	\N	PRESENT	0
167656	167652	08049C	PARTICIPANT	\N	PRESENT	0
167658	167657	14193X	PARTICIPANT	\N	PRESENT	0
167659	167657	11054L	PARTICIPANT	\N	PRESENT	0
167660	167657	08049C	PARTICIPANT	\N	PRESENT	0
167661	167657	04040A	PARTICIPANT	\N	PRESENT	0
171088	171087	14089Y	PARTICIPANT	\N	PRESENT	0
171089	171087	14207L	PRESIDENT	0	PRESENT	0
171090	171087	14087W	PRESIDENT	1	PRESENT	0
171091	171087	11014C	PARTICIPANT	\N	EXCUSE	0
171092	171087	14237S	PARTICIPANT	\N	PRESENT	0
171093	171087	04050C	PARTICIPANT	\N	PRESENT	0
171096	171087	14053L	PARTICIPANT	\N	EXCUSE	0
174536	174535	11055M	PARTICIPANT	\N	EXCUSE	0
174537	174535	04053F	PARTICIPANT	\N	PRESENT	0
174538	174535	14255U	PARTICIPANT	\N	PRESENT	0
174539	174535	04066L	PARTICIPANT	\N	PRESENT	0
174540	174535	00003C	PARTICIPANT	\N	EXCUSE	0
174541	174535	14053L	PARTICIPANT	\N	EXCUSE	0
174542	174535	11103C	PARTICIPANT	\N	PRESENT	0
174543	174535	11044J	PARTICIPANT	\N	PRESENT	0
174544	174535	14195A	PARTICIPANT	\N	PRESENT	0
174545	174535	11031D	PARTICIPANT	\N	PRESENT	0
174546	174535	04081K	PARTICIPANT	\N	PRESENT	0
174547	174535	14217N	PARTICIPANT	\N	PRESENT	0
174548	174535	14042U	PARTICIPANT	\N	PRESENT	0
174549	174535	14281W	PARTICIPANT	\N	PRESENT	0
174550	174535	14034U	PARTICIPANT	\N	PRESENT	0
174551	174535	14231L	PARTICIPANT	\N	PRESENT	0
174552	174535	11061K	PARTICIPANT	\N	PRESENT	0
174553	174535	14355X	PARTICIPANT	\N	PRESENT	0
174554	174535	01011G	PARTICIPANT	\N	PRESENT	0
174555	174535	14026U	PARTICIPANT	\N	PRESENT	0
174557	174535	14213J	PARTICIPANT	\N	PRESENT	0
174558	174535	14121F	PARTICIPANT	\N	PRESENT	0
174560	174535	11112D	PARTICIPANT	\N	PRESENT	0
174562	174535	11067R	PARTICIPANT	\N	PRESENT	0
174564	174535	14223L	PARTICIPANT	\N	PRESENT	0
174565	174535	04092N	PRESIDENT	0	PRESENT	0
174567	174535	14265W	PARTICIPANT	\N	PRESENT	0
174568	174535	14071N	PARTICIPANT	\N	PRESENT	0
174569	174535	04043D	PARTICIPANT	\N	PRESENT	0
174571	174535	14271U	PARTICIPANT	\N	PRESENT	0
174572	174535	11093T	PARTICIPANT	\N	PRESENT	0
174574	174535	11097X	PARTICIPANT	\N	PRESENT	0
174575	174535	04045F	PARTICIPANT	\N	PRESENT	0
174576	174535	01034P	PARTICIPANT	\N	PRESENT	0
174578	174535	11025F	PARTICIPANT	\N	PRESENT	0
174579	174535	14269B	PARTICIPANT	\N	PRESENT	0
177253	177252	96004D	PRESIDENT	0	PRESENT	0
177254	177252	90003B	PARTICIPANT	\N	PRESENT	0
177255	177252	11035H	PARTICIPANT	\N	PRESENT	0
177256	177252	14001X	PARTICIPANT	\N	PRESENT	0
177257	177252	04057K	PARTICIPANT	\N	PRESENT	0
177258	177252	01016M	PARTICIPANT	\N	PRESENT	0
177259	177252	92045V	PARTICIPANT	\N	PRESENT	0
177260	177252	10015M	PARTICIPANT	\N	PRESENT	0
177261	177252	04045F	PARTICIPANT	\N	EXCUSE	0
177262	177252	04034C	PARTICIPANT	\N	EXCUSE	0
177263	177252	14089Y	PARTICIPANT	\N	EXCUSE	0
177264	177252	98046X	PARTICIPANT	\N	EXCUSE	0
177265	177252	14073Q	PARTICIPANT	\N	EXCUSE	0
177271	177252	11012A	PARTICIPANT	\N	EXCUSE	0
180745	180743	14207L	PARTICIPANT	\N	PRESENT	0
180748	180747	14207L	PARTICIPANT	\N	PRESENT	0
180773	180772	14089Y	PARTICIPANT	\N	PRESENT	0
180792	180772	14207L	PRESIDENT	0	PRESENT	0
180793	180772	14053L	PARTICIPANT	\N	PRESENT	0
180794	180772	14079W	PARTICIPANT	\N	PRESENT	0
180795	180772	14215L	PARTICIPANT	\N	PRESENT	0
180796	180772	14249W	PARTICIPANT	\N	EXCUSE	0
180797	180772	14087W	PARTICIPANT	\N	EXCUSE	0
180798	180772	14231L	PARTICIPANT	\N	PRESENT	0
180799	180772	11061K	PARTICIPANT	\N	PRESENT	0
180800	180772	04057K	PARTICIPANT	\N	EXCUSE	0
180801	180772	11014C	PARTICIPANT	\N	PRESENT	0
180802	180772	14135M	PARTICIPANT	\N	EXCUSE	0
180803	180772	14229S	PARTICIPANT	\N	PRESENT	0
180804	180772	04050C	PARTICIPANT	\N	PRESENT	0
180806	180772	14031R	PARTICIPANT	\N	EXCUSE	0
180849	164995	01046T	PARTICIPANT	\N	EXCUSE	0
180973	180972	96004D	PRESIDENT	0	PRESENT	0
180974	180972	14089Y	PARTICIPANT	\N	PRESENT	0
180975	180972	14079W	PARTICIPANT	\N	PRESENT	0
180977	180972	11035H	PARTICIPANT	\N	PRESENT	0
180978	180972	14026U	PARTICIPANT	\N	PRESENT	0
180979	180972	08044W	PARTICIPANT	\N	PRESENT	0
180980	180972	14097Y	PARTICIPANT	\N	PRESENT	0
180981	180972	04061F	PARTICIPANT	\N	PRESENT	0
180982	180972	11026G	PARTICIPANT	\N	PRESENT	0
180985	180972	04057K	PARTICIPANT	\N	PRESENT	0
180986	180972	98046X	PARTICIPANT	\N	PRESENT	0
180987	180972	04080J	PARTICIPANT	\N	PRESENT	0
180988	180972	01016M	PARTICIPANT	\N	PRESENT	0
180989	180972	04034C	PARTICIPANT	\N	PRESENT	0
180990	180972	04045F	PARTICIPANT	\N	PRESENT	0
181013	180972	90003B	PARTICIPANT	\N	EXCUSE	0
181014	180972	95030B	PARTICIPANT	\N	EXCUSE	0
181015	180972	14073Q	PARTICIPANT	\N	EXCUSE	0
183092	181129	14249W	PARTICIPANT	\N	PRESENT	0
183195	183192	11097X	PARTICIPANT	\N	PRESENT	0
183193	183192	11031D	PARTICIPANT	\N	PRESENT	0
183194	183192	11061K	PARTICIPANT	\N	PRESENT	0
183197	183196	11031D	PARTICIPANT	\N	PRESENT	0
183198	183196	11061K	PARTICIPANT	\N	PRESENT	0
183199	183196	11097X	PARTICIPANT	\N	PRESENT	0
183413	183412	11039M	PARTICIPANT	\N	PRESENT	0
183414	183412	98042T	PARTICIPANT	\N	PRESENT	0
183415	183412	01019Q	PARTICIPANT	\N	PRESENT	0
183417	183416	11039M	PARTICIPANT	\N	PRESENT	0
183418	183416	98042T	PARTICIPANT	\N	PRESENT	0
183419	183416	01019Q	PARTICIPANT	\N	PRESENT	0
186653	186652	04040A	PARTICIPANT	\N	PRESENT	0
186655	186654	04040A	PARTICIPANT	\N	PRESENT	0
186656	186654	11032E	PARTICIPANT	\N	PRESENT	0
186692	186676	01015L	PARTICIPANT	\N	EXCUSE	0
186693	186676	09001P	PARTICIPANT	\N	EXCUSE	0
186694	186676	80013X	PARTICIPANT	\N	EXCUSE	0
190832	190756	86034E	PARTICIPANT	\N	PRESENT	0
190833	190756	14051J	PARTICIPANT	\N	PRESENT	0
190834	190756	01011G	PARTICIPANT	\N	PRESENT	0
190835	190756	08016S	PARTICIPANT	\N	PRESENT	0
190836	190756	08052W	PARTICIPANT	\N	PRESENT	0
190837	190756	13002U	PARTICIPANT	\N	PRESENT	0
190838	190756	11039M	PARTICIPANT	\N	PRESENT	0
190839	190756	14197C	PARTICIPANT	\N	PRESENT	0
190840	190756	01022K	PARTICIPANT	\N	PRESENT	0
190841	190756	98046X	PARTICIPANT	\N	PRESENT	0
190842	190756	00003C	PARTICIPANT	\N	PRESENT	0
190843	190756	14107H	PARTICIPANT	\N	PRESENT	0
190844	190756	14081Q	PARTICIPANT	\N	PRESENT	0
190845	190756	12042Y	PARTICIPANT	\N	PRESENT	0
190846	190756	98029W	PARTICIPANT	\N	PRESENT	0
190847	190756	04095R	PARTICIPANT	\N	PRESENT	0
190848	190756	11114F	PARTICIPANT	\N	PRESENT	0
190849	190756	11066Q	PARTICIPANT	\N	PRESENT	0
190850	190756	08012N	PARTICIPANT	\N	PRESENT	0
190851	190756	11059R	PARTICIPANT	\N	PRESENT	0
190852	190756	83047W	PARTICIPANT	\N	PRESENT	0
190853	190756	08058D	PARTICIPANT	\N	PRESENT	0
190854	190756	08053X	PARTICIPANT	\N	PRESENT	0
190855	190756	11015D	PARTICIPANT	\N	PRESENT	0
190856	190756	08068F	PARTICIPANT	\N	PRESENT	0
190857	190756	14229S	PARTICIPANT	\N	PRESENT	0
190858	190756	80013X	PARTICIPANT	\N	PRESENT	0
190859	190756	95063L	PARTICIPANT	\N	PRESENT	0
190860	190756	11104D	PARTICIPANT	\N	PRESENT	0
190861	190695	14327T	PARTICIPANT	\N	PRESENT	0
190862	190695	01048V	PARTICIPANT	\N	PRESENT	0
190863	190695	04034C	PARTICIPANT	\N	PRESENT	0
190864	190695	01057W	PARTICIPANT	\N	PRESENT	0
190865	190695	11053K	PARTICIPANT	\N	PRESENT	0
180234	167346	11081P	PARTICIPANT	\N	PRESENT	0
190163	188912	04049K	PRESIDENT	0	PRESENT	0
190164	188912	14083S	PARTICIPANT	\N	PRESENT	0
190165	188912	14157T	PARTICIPANT	\N	PRESENT	0
190166	188912	14207L	PARTICIPANT	\N	PRESENT	0
190167	188912	14105F	PARTICIPANT	\N	PRESENT	0
190168	188912	14030Q	PARTICIPANT	\N	PRESENT	0
190169	188912	14265W	PARTICIPANT	\N	PRESENT	0
190170	188912	11063M	PARTICIPANT	\N	PRESENT	0
190171	188912	14151M	PARTICIPANT	\N	PRESENT	0
190172	188912	14061L	PARTICIPANT	\N	PRESENT	0
190173	188912	14079W	PARTICIPANT	\N	PRESENT	0
190174	188912	14255U	PARTICIPANT	\N	PRESENT	0
190175	188912	89017R	PARTICIPANT	\N	EXCUSE	0
190176	188912	08068F	PARTICIPANT	\N	EXCUSE	0
190177	188912	11088W	PARTICIPANT	\N	EXCUSE	0
190234	188912	14041T	PARTICIPANT	\N	EXCUSE	0
190235	188912	04071H	PARTICIPANT	\N	EXCUSE	0
190236	188912	14087W	PARTICIPANT	\N	EXCUSE	0
190237	188912	14034U	PARTICIPANT	\N	EXCUSE	0
190238	188912	95041E	PARTICIPANT	\N	EXCUSE	0
190239	188912	11077T	PARTICIPANT	\N	EXCUSE	0
190240	188912	14205J	PARTICIPANT	\N	EXCUSE	0
190241	188912	14253S	PARTICIPANT	\N	EXCUSE	0
190242	188912	11090Q	PARTICIPANT	\N	EXCUSE	0
190243	188912	10015M	PARTICIPANT	\N	EXCUSE	0
190244	188912	95067Q	PARTICIPANT	\N	EXCUSE	0
190245	188912	04053F	PARTICIPANT	\N	EXCUSE	0
190318	187952	04049K	PARTICIPANT	\N	PRESENT	0
190319	187952	14207L	PARTICIPANT	\N	PRESENT	0
190320	187952	04053F	PARTICIPANT	\N	PRESENT	0
190321	187952	14030Q	PARTICIPANT	\N	PRESENT	0
190322	187952	14079W	PARTICIPANT	\N	PRESENT	0
190323	187952	14061L	PARTICIPANT	\N	PRESENT	0
190324	187952	14265W	PARTICIPANT	\N	PRESENT	0
190325	187952	14157T	PARTICIPANT	\N	PRESENT	0
190326	187952	14105F	PARTICIPANT	\N	PRESENT	0
190330	187952	14083S	PARTICIPANT	\N	PRESENT	0
190331	187952	14255U	PARTICIPANT	\N	PRESENT	0
190332	187952	89017R	PARTICIPANT	\N	PRESENT	0
190339	187952	01031L	PARTICIPANT	\N	PRESENT	0
190340	187952	14085U	PARTICIPANT	\N	PRESENT	0
190341	187952	14225N	PARTICIPANT	\N	PRESENT	0
190342	187952	01016M	PARTICIPANT	\N	PRESENT	0
190343	187952	11083R	PARTICIPANT	\N	PRESENT	0
190344	187952	11057P	PARTICIPANT	\N	PRESENT	0
190345	187952	04086Q	PARTICIPANT	\N	PRESENT	0
190346	187952	08010L	PARTICIPANT	\N	PRESENT	0
190347	187952	11048N	PARTICIPANT	\N	PRESENT	0
190348	187952	08011M	PARTICIPANT	\N	PRESENT	0
190349	187952	08034U	PARTICIPANT	\N	PRESENT	0
190350	187952	08061X	PARTICIPANT	\N	PRESENT	0
190351	187952	01057W	PARTICIPANT	\N	PRESENT	0
190352	187952	08068F	PARTICIPANT	\N	EXCUSE	0
190353	187952	11088W	PARTICIPANT	\N	EXCUSE	0
190354	187952	14041T	PARTICIPANT	\N	EXCUSE	0
190355	187952	04071H	PARTICIPANT	\N	EXCUSE	0
190356	187952	14151M	PARTICIPANT	\N	EXCUSE	0
190357	187952	14087W	PARTICIPANT	\N	EXCUSE	0
190358	187952	14034U	PARTICIPANT	\N	EXCUSE	0
190359	187952	95041E	PARTICIPANT	\N	EXCUSE	0
190360	187952	11077T	PARTICIPANT	\N	EXCUSE	0
190361	187952	14205J	PARTICIPANT	\N	EXCUSE	0
190362	187952	14253S	PARTICIPANT	\N	EXCUSE	0
190363	187952	11090Q	PARTICIPANT	\N	EXCUSE	0
190364	187952	10015M	PARTICIPANT	\N	EXCUSE	0
190365	187952	11063M	PARTICIPANT	\N	EXCUSE	0
190366	187952	95067Q	PARTICIPANT	\N	EXCUSE	0
196371	195879	09001P	PRESIDENT	0	PRESENT	0
198533	198532	14028W	PARTICIPANT	\N	EXCUSE	0
198584	198583	88008L	PARTICIPANT	\N	PRESENT	0
198585	198583	14041T	PARTICIPANT	\N	PRESENT	0
198586	198583	14217N	PARTICIPANT	\N	PRESENT	0
198587	198583	14215L	PARTICIPANT	\N	PRESENT	0
198588	198583	92020L	PARTICIPANT	\N	PRESENT	0
198589	198583	11061K	PARTICIPANT	\N	PRESENT	0
198590	198583	14026U	PARTICIPANT	\N	PRESENT	0
198591	198583	14097Y	PARTICIPANT	\N	PRESENT	0
198592	198583	04036E	PARTICIPANT	\N	PRESENT	0
198593	198583	08031R	PARTICIPANT	\N	PRESENT	0
198594	198583	11026G	PARTICIPANT	\N	PRESENT	0
198595	198583	04057K	PARTICIPANT	\N	PRESENT	0
198596	198583	04070G	PARTICIPANT	\N	PRESENT	0
198597	198583	95062K	PARTICIPANT	\N	PRESENT	0
198598	198583	95067Q	PARTICIPANT	\N	PRESENT	0
198746	198745	97011G	PARTICIPANT	\N	PRESENT	0
198747	198745	08043V	PARTICIPANT	\N	PRESENT	0
198748	198745	04038G	PARTICIPANT	\N	PRESENT	0
198749	198745	11067R	PARTICIPANT	\N	PRESENT	0
198750	198745	14179A	PARTICIPANT	\N	PRESENT	0
198751	198745	01027Q	PARTICIPANT	\N	PRESENT	0
198752	198745	05012A	PARTICIPANT	\N	PRESENT	0
198952	197996	11061K	PARTICIPANT	\N	PRESENT	0
198953	197996	04092N	PRESIDENT	0	PRESENT	0
198954	197996	11097X	PARTICIPANT	\N	PRESENT	0
198955	197996	08052W	PARTICIPANT	\N	PRESENT	0
198956	197996	12042Y	PARTICIPANT	\N	PRESENT	0
198957	197996	14195A	PARTICIPANT	\N	PRESENT	0
198958	197996	14217N	PARTICIPANT	\N	PRESENT	0
198959	197996	04045F	PARTICIPANT	\N	PRESENT	0
198960	197996	11093T	PARTICIPANT	\N	PRESENT	0
198961	197996	14223L	PARTICIPANT	\N	PRESENT	0
198962	197996	98024R	PARTICIPANT	\N	PRESENT	0
198963	197996	14017T	PARTICIPANT	\N	EXCUSE	0
198964	197996	00003C	PARTICIPANT	\N	EXCUSE	0
198965	197996	14265W	PARTICIPANT	\N	EXCUSE	0
198966	190790	08055A	PARTICIPANT	\N	PRESENT	0
198972	190790	14061L	PARTICIPANT	\N	PRESENT	0
198973	190790	95062K	PARTICIPANT	\N	PRESENT	0
198974	190790	07026Q	PARTICIPANT	\N	PRESENT	0
198975	190790	11034G	PARTICIPANT	\N	PRESENT	0
198976	190790	11105E	PARTICIPANT	\N	PRESENT	0
198977	190790	11035H	PARTICIPANT	\N	PRESENT	0
198978	190790	14063N	PARTICIPANT	\N	PRESENT	0
198979	190790	11076S	PARTICIPANT	\N	PRESENT	0
198980	190790	04078Q	PARTICIPANT	\N	PRESENT	0
198981	190790	11083R	PARTICIPANT	\N	PRESENT	0
198982	190790	98005N	PARTICIPANT	\N	PRESENT	0
198983	190790	11091R	PARTICIPANT	\N	PRESENT	0
198984	190790	04081K	PARTICIPANT	\N	PRESENT	0
198985	190790	99004R	PARTICIPANT	\N	PRESENT	0
198986	190790	14259Y	PARTICIPANT	\N	PRESENT	0
199018	190790	14041T	PARTICIPANT	\N	PRESENT	0
198988	190790	14038Y	PARTICIPANT	\N	PRESENT	0
198989	190790	11066Q	PARTICIPANT	\N	PRESENT	0
198990	190790	08016S	PARTICIPANT	\N	PRESENT	0
198992	190790	14119M	PARTICIPANT	\N	PRESENT	0
198993	190790	04044E	PARTICIPANT	\N	PRESENT	0
198994	190790	88008L	PARTICIPANT	\N	PRESENT	0
198995	190790	01056V	PARTICIPANT	\N	PRESENT	0
199012	197996	01034P	PARTICIPANT	\N	PRESENT	0
199013	197996	14269B	PARTICIPANT	\N	PRESENT	0
199014	197996	14071N	PARTICIPANT	\N	PRESENT	0
199015	197996	04043D	PARTICIPANT	\N	PRESENT	0
199016	190790	14089Y	PARTICIPANT	\N	PRESENT	0
199017	190790	08015R	PARTICIPANT	\N	PRESENT	0
199033	190790	98022P	PARTICIPANT	\N	PRESENT	0
199034	190790	14201E	PARTICIPANT	\N	PRESENT	0
199096	190790	05012A	PARTICIPANT	\N	PRESENT	0
199097	190790	92031P	PARTICIPANT	\N	PRESENT	0
199112	190790	14357A	PARTICIPANT	\N	PRESENT	0
199113	190790	08019V	PARTICIPANT	\N	PRESENT	0
199114	190790	14079W	PARTICIPANT	\N	PRESENT	0
199472	198068	14357A	PARTICIPANT	\N	PRESENT	0
199473	198068	14079W	PARTICIPANT	\N	PRESENT	0
199474	198068	11066Q	PARTICIPANT	\N	PRESENT	0
199475	198068	04045F	PARTICIPANT	\N	PRESENT	0
199476	198068	80013X	PARTICIPANT	\N	PRESENT	0
199477	198068	14026U	PARTICIPANT	\N	PRESENT	0
199478	198068	08068F	PARTICIPANT	\N	PRESENT	0
199479	198068	95037J	PARTICIPANT	\N	PRESENT	0
199480	198068	04049K	PRESIDENT	0	PRESENT	0
199481	198068	96004D	PARTICIPANT	\N	PRESENT	0
199482	198068	08019V	PARTICIPANT	\N	PRESENT	0
199483	198068	11081P	PARTICIPANT	\N	PRESENT	0
199484	198068	14135M	PARTICIPANT	\N	PRESENT	0
199485	198068	14187A	PARTICIPANT	\N	PRESENT	0
199486	198068	01016M	PARTICIPANT	\N	PRESENT	0
199487	198068	11090Q	PARTICIPANT	\N	PRESENT	0
199488	198068	14033T	PARTICIPANT	\N	PRESENT	0
199489	198068	01008M	PARTICIPANT	\N	PRESENT	0
199490	198068	14089Y	PARTICIPANT	\N	PRESENT	0
199491	198068	14205J	PARTICIPANT	\N	PRESENT	0
199492	198068	04088S	PARTICIPANT	\N	PRESENT	0
199493	198068	11036J	PARTICIPANT	\N	PRESENT	0
199494	198068	98050T	PARTICIPANT	\N	PRESENT	0
199495	198068	14207L	PARTICIPANT	\N	PRESENT	0
199496	198068	14257W	PARTICIPANT	\N	PRESENT	0
199497	198068	01058X	PARTICIPANT	\N	EXCUSE	0
167593	167592	11053K	PARTICIPANT	\N	PRESENT	0
167594	167592	01031L	PARTICIPANT	\N	PRESENT	0
167595	167592	04040A	PARTICIPANT	\N	PRESENT	0
167596	167592	14041T	PARTICIPANT	\N	PRESENT	0
167597	167592	14225N	PARTICIPANT	\N	PRESENT	0
168966	168848	14215L	PARTICIPANT	\N	PRESENT	0
168969	168848	01060R	PARTICIPANT	\N	PRESENT	0
168973	168848	05008E	PRESIDENT	0	PRESENT	0
168978	168848	14147R	PARTICIPANT	\N	PRESENT	0
168982	168848	08051V	PARTICIPANT	\N	PRESENT	0
168983	168848	11032E	PARTICIPANT	\N	PRESENT	0
168987	168848	95063L	PARTICIPANT	\N	PRESENT	0
168994	168848	14259Y	PARTICIPANT	\N	PRESENT	0
168996	168848	01047U	PARTICIPANT	\N	PRESENT	0
169000	168848	04074L	PARTICIPANT	\N	PRESENT	0
169004	168848	10015M	PARTICIPANT	\N	PRESENT	0
169005	168848	04038G	PARTICIPANT	\N	PRESENT	0
169006	168848	04079R	PARTICIPANT	\N	PRESENT	0
169007	168848	99002P	PARTICIPANT	\N	PRESENT	0
169008	168848	11056N	PARTICIPANT	\N	PRESENT	0
169012	168848	08018U	PARTICIPANT	\N	PRESENT	0
169290	167010	01007L	PARTICIPANT	\N	PRESENT	0
169353	167010	07026Q	PARTICIPANT	\N	PRESENT	0
169354	167010	14063N	PARTICIPANT	\N	PRESENT	0
169355	167010	08025T	PARTICIPANT	\N	PRESENT	0
169356	167010	11026G	PARTICIPANT	\N	PRESENT	0
169358	167010	14271U	PARTICIPANT	\N	PRESENT	0
169359	167010	11066Q	PARTICIPANT	\N	PRESENT	0
169360	167010	14219Q	PARTICIPANT	\N	PRESENT	0
169361	167010	01025N	PARTICIPANT	\N	PRESENT	0
169362	167010	04085P	PARTICIPANT	\N	PRESENT	0
169363	167010	14119M	PARTICIPANT	\N	PRESENT	0
169364	167010	14033T	PARTICIPANT	\N	PRESENT	0
169369	167010	14147R	PARTICIPANT	\N	PRESENT	0
169366	167010	95049N	PARTICIPANT	\N	PRESENT	0
169368	167010	14211G	PARTICIPANT	\N	PRESENT	0
169370	167010	92045V	PARTICIPANT	\N	PRESENT	0
169372	167010	95063L	PARTICIPANT	\N	PRESENT	0
169373	167010	14105F	PARTICIPANT	\N	PRESENT	0
169374	167010	11029K	PARTICIPANT	\N	PRESENT	0
169376	167010	14265W	PARTICIPANT	\N	PRESENT	0
169377	167010	04053F	PARTICIPANT	\N	PRESENT	0
169378	167010	08041T	PARTICIPANT	\N	PRESENT	0
169383	167010	88008L	PARTICIPANT	\N	PRESENT	0
169393	167010	01043Q	PARTICIPANT	\N	PRESENT	0
169395	167010	14257W	PARTICIPANT	\N	PRESENT	0
169396	167010	14361V	PARTICIPANT	\N	PRESENT	0
169397	167010	99004R	PARTICIPANT	\N	PRESENT	0
169399	167010	04045F	PARTICIPANT	\N	PRESENT	0
169406	167010	14225N	PARTICIPANT	\N	PRESENT	0
169409	167010	05008E	PARTICIPANT	\N	PRESENT	0
169423	167010	11093T	PARTICIPANT	\N	PRESENT	0
169424	167010	14109K	PARTICIPANT	\N	PRESENT	0
169428	167010	14215L	PARTICIPANT	\N	PRESENT	0
169431	167010	11098Y	PARTICIPANT	\N	PRESENT	0
169433	167010	01028R	PARTICIPANT	\N	PRESENT	0
169434	167010	95062K	PARTICIPANT	\N	PRESENT	0
169452	167010	14097Y	PARTICIPANT	\N	PRESENT	0
169453	167010	08034U	PARTICIPANT	\N	PRESENT	0
169454	167010	04088S	PARTICIPANT	\N	PRESENT	0
169472	167010	08015R	PARTICIPANT	\N	PRESENT	0
169473	167010	14059S	PARTICIPANT	\N	PRESENT	0
169474	167010	14237S	PARTICIPANT	\N	PRESENT	0
169475	167010	95030B	PARTICIPANT	\N	PRESENT	0
169476	167010	14135M	PARTICIPANT	\N	PRESENT	0
169477	167010	12042Y	PARTICIPANT	\N	PRESENT	0
169479	167010	14357A	PARTICIPANT	\N	PRESENT	0
169481	167010	14069U	PARTICIPANT	\N	PRESENT	0
169484	167010	14193X	PARTICIPANT	\N	PRESENT	0
169485	167010	14207L	PARTICIPANT	\N	PRESENT	0
169486	167010	14269B	PARTICIPANT	\N	PRESENT	0
169487	167010	14133K	PARTICIPANT	\N	PRESENT	0
169489	167010	14159V	PARTICIPANT	\N	PRESENT	0
169490	167010	13002U	PARTICIPANT	\N	PRESENT	0
169491	167010	11083R	PARTICIPANT	\N	PRESENT	0
169492	167010	14205J	PARTICIPANT	\N	PRESENT	0
169493	167010	14089Y	PARTICIPANT	\N	PRESENT	0
169494	167010	04067M	PARTICIPANT	\N	PRESENT	0
169495	167010	11081P	PARTICIPANT	\N	PRESENT	0
169496	167010	97011G	PARTICIPANT	\N	PRESENT	0
169497	167010	14103D	PARTICIPANT	\N	PRESENT	0
169498	167010	08010L	PARTICIPANT	\N	PRESENT	0
169501	167010	01046T	PARTICIPANT	\N	PRESENT	0
169502	167010	14331P	PARTICIPANT	\N	PRESENT	0
169503	167010	14363X	PARTICIPANT	\N	PRESENT	0
169546	167010	14195A	PARTICIPANT	\N	PRESENT	0
169547	167010	01027Q	PARTICIPANT	\N	PRESENT	0
169548	167010	10015M	PARTICIPANT	\N	PRESENT	0
169549	167010	14179A	PARTICIPANT	\N	PRESENT	0
169550	167010	14173T	PARTICIPANT	\N	PRESENT	0
169591	167010	14197C	PARTICIPANT	\N	PRESENT	0
169695	167011	04053F	PARTICIPANT	\N	PRESENT	0
169696	167011	14041T	PARTICIPANT	\N	PRESENT	0
169697	167011	14195A	PARTICIPANT	\N	PRESENT	0
169698	167011	14001X	PARTICIPANT	\N	PRESENT	0
169699	167011	14065Q	PARTICIPANT	\N	PRESENT	0
169700	167011	04067M	PARTICIPANT	\N	PRESENT	0
169701	167011	13002U	PARTICIPANT	\N	PRESENT	0
169703	167011	04085P	PARTICIPANT	\N	PRESENT	0
169704	167011	04088S	PARTICIPANT	\N	PRESENT	0
169705	167011	04049K	PARTICIPANT	\N	PRESENT	0
169706	167011	97011G	PARTICIPANT	\N	PRESENT	0
169707	167011	11103C	PARTICIPANT	\N	PRESENT	0
169708	167011	14363X	PARTICIPANT	\N	PRESENT	0
169709	167011	14205J	PARTICIPANT	\N	PRESENT	0
169710	167011	14179A	PARTICIPANT	\N	PRESENT	0
169711	167011	14267Y	PARTICIPANT	\N	PRESENT	0
169712	167011	14103D	PARTICIPANT	\N	PRESENT	0
169713	167011	95035G	PARTICIPANT	\N	PRESENT	0
169714	167011	14215L	PARTICIPANT	\N	PRESENT	0
169715	167011	14071N	PARTICIPANT	\N	PRESENT	0
169716	167011	11081P	PARTICIPANT	\N	PRESENT	0
169717	167011	01046T	PARTICIPANT	\N	PRESENT	0
169719	167011	11098Y	PARTICIPANT	\N	PRESENT	0
169732	167011	14269B	PARTICIPANT	\N	PRESENT	0
169733	167011	11107G	PARTICIPANT	\N	PRESENT	0
169734	167011	14159V	PARTICIPANT	\N	PRESENT	0
169735	167011	08016S	PARTICIPANT	\N	PRESENT	0
169736	167011	80013X	PARTICIPANT	\N	PRESENT	0
169737	167011	14217N	PARTICIPANT	\N	PRESENT	0
169752	167011	08069G	PARTICIPANT	\N	PRESENT	0
169753	167011	14209N	PARTICIPANT	\N	PRESENT	0
169754	167011	14157T	PARTICIPANT	\N	PRESENT	0
169755	167011	14107H	PARTICIPANT	\N	PRESENT	0
169756	167011	04044E	PARTICIPANT	\N	PRESENT	0
169757	167011	01028R	PARTICIPANT	\N	PRESENT	0
169758	167011	11029K	PARTICIPANT	\N	PRESENT	0
169759	167011	14265W	PARTICIPANT	\N	PRESENT	0
169760	167011	11084S	PARTICIPANT	\N	PRESENT	0
169797	167011	11042G	PARTICIPANT	\N	PRESENT	0
169820	167012	08024S	PARTICIPANT	\N	PRESENT	0
169847	167012	11081P	PARTICIPANT	\N	PRESENT	0
169848	167012	14267Y	PARTICIPANT	\N	PRESENT	0
169849	167012	04038G	PARTICIPANT	\N	PRESENT	0
169850	167012	14237S	PARTICIPANT	\N	PRESENT	0
169851	167012	14195A	PARTICIPANT	\N	PRESENT	0
169910	167012	14107H	PARTICIPANT	\N	PRESENT	0
169911	167012	14219Q	PARTICIPANT	\N	PRESENT	0
169912	167012	01059Y	PARTICIPANT	\N	PRESENT	0
169913	167012	01046T	PARTICIPANT	\N	PRESENT	0
169914	167012	14033T	PARTICIPANT	\N	PRESENT	0
169915	167012	11067R	PARTICIPANT	\N	PRESENT	0
169916	167012	14197C	PARTICIPANT	\N	PRESENT	0
169917	167012	14241N	PARTICIPANT	\N	PRESENT	0
169919	167012	01031L	PARTICIPANT	\N	PRESENT	0
169920	167012	11061K	PARTICIPANT	\N	PRESENT	0
169921	167012	14265W	PARTICIPANT	\N	PRESENT	0
169922	167012	11083R	PARTICIPANT	\N	PRESENT	0
169923	167012	14257W	PARTICIPANT	\N	PRESENT	0
169924	167012	08051V	PARTICIPANT	\N	PRESENT	0
169925	167012	11036J	PARTICIPANT	\N	PRESENT	0
169692	167011	01007L	PARTICIPANT	\N	PRESENT	0
169694	167011	08018U	PARTICIPANT	\N	PRESENT	0
169926	167012	98053W	PARTICIPANT	\N	PRESENT	0
169927	167012	10006L	PARTICIPANT	\N	PRESENT	0
169932	167012	08043V	PARTICIPANT	\N	PRESENT	0
169933	167012	11064N	PARTICIPANT	\N	PRESENT	0
169934	167012	14205J	PARTICIPANT	\N	PRESENT	0
169952	167012	01016M	PARTICIPANT	\N	PRESENT	0
169953	167012	11012A	PARTICIPANT	\N	PRESENT	0
169954	167012	14069U	PARTICIPANT	\N	PRESENT	0
169955	167012	04053F	PARTICIPANT	\N	PRESENT	0
169956	167012	14231L	PARTICIPANT	\N	PRESENT	0
169972	167014	08051V	PARTICIPANT	\N	PRESENT	0
169973	167014	04085P	PARTICIPANT	\N	PRESENT	0
169974	167014	11012A	PARTICIPANT	\N	PRESENT	0
169975	167014	01024M	PARTICIPANT	\N	PRESENT	0
169976	167014	11029K	PARTICIPANT	\N	PRESENT	0
173453	167025	01059Y	PARTICIPANT	\N	PRESENT	0
173454	167025	14247U	PARTICIPANT	\N	PRESENT	0
173455	167025	08069G	PARTICIPANT	\N	PRESENT	0
173456	167025	14271U	PARTICIPANT	\N	PRESENT	0
173457	167025	14051J	PARTICIPANT	\N	PRESENT	0
173458	167025	14157T	PARTICIPANT	\N	PRESENT	0
173459	167025	14151M	PARTICIPANT	\N	PRESENT	0
173460	167025	08052W	PARTICIPANT	\N	PRESENT	0
173461	167025	14119M	PARTICIPANT	\N	PRESENT	0
173462	167025	08055A	PARTICIPANT	\N	PRESENT	0
173463	167025	14093U	PARTICIPANT	\N	PRESENT	0
173465	167025	01031L	PARTICIPANT	\N	PRESENT	0
173466	167025	11027H	PARTICIPANT	\N	PRESENT	0
173467	167025	14169X	PARTICIPANT	\N	PRESENT	0
173468	167025	01011G	PARTICIPANT	\N	PRESENT	0
173469	167025	01048V	PARTICIPANT	\N	PRESENT	0
173471	167025	80013X	PARTICIPANT	\N	PRESENT	0
173473	167025	92020L	PARTICIPANT	\N	PRESENT	0
173476	167025	14329V	PARTICIPANT	\N	PRESENT	0
173477	167025	08043V	PARTICIPANT	\N	PRESENT	0
173478	167025	08019V	PARTICIPANT	\N	PRESENT	0
173479	167025	11059R	PARTICIPANT	\N	PRESENT	0
173480	167025	04057K	PARTICIPANT	\N	PRESENT	0
173481	167025	11036J	PARTICIPANT	\N	PRESENT	0
173482	167025	14363X	PARTICIPANT	\N	PRESENT	0
173483	167025	14069U	PARTICIPANT	\N	PRESENT	0
173582	167025	89017R	PARTICIPANT	\N	PRESENT	0
173485	167025	08053X	PARTICIPANT	\N	PRESENT	0
173486	167025	04049K	PARTICIPANT	\N	PRESENT	0
173487	167025	11046L	PARTICIPANT	\N	PRESENT	0
173488	167025	98029W	PARTICIPANT	\N	PRESENT	0
173489	167025	14207L	PARTICIPANT	\N	PRESENT	0
173490	167025	95063L	PARTICIPANT	\N	PRESENT	0
173491	167025	08014Q	PARTICIPANT	\N	PRESENT	0
173493	167025	14001X	PARTICIPANT	\N	PRESENT	0
173495	167025	11054L	PARTICIPANT	\N	PRESENT	0
173496	167025	14031R	PARTICIPANT	\N	PRESENT	0
173497	167025	83047W	PARTICIPANT	\N	PRESENT	0
173499	167025	11061K	PARTICIPANT	\N	PRESENT	0
173500	167025	14017T	PARTICIPANT	\N	PRESENT	0
173501	167025	14281W	PARTICIPANT	\N	PRESENT	0
173502	167025	04079R	PARTICIPANT	\N	PRESENT	0
173503	167025	14065Q	PARTICIPANT	\N	PRESENT	0
173504	167025	11112D	PARTICIPANT	\N	PRESENT	0
173505	167025	14097Y	PARTICIPANT	\N	PRESENT	0
173506	167025	11014C	PARTICIPANT	\N	PRESENT	0
173507	167025	04035D	PARTICIPANT	\N	PRESENT	0
173508	167025	04033B	PARTICIPANT	\N	PRESENT	0
173509	167025	08061X	PARTICIPANT	\N	PRESENT	0
173510	167025	04053F	PARTICIPANT	\N	PRESENT	0
173511	167025	08038Y	PARTICIPANT	\N	PRESENT	0
173512	167025	11084S	PARTICIPANT	\N	PRESENT	0
173513	167025	92039X	PARTICIPANT	\N	PRESENT	0
173514	167025	04081K	PARTICIPANT	\N	PRESENT	0
173515	167025	11067R	PARTICIPANT	\N	PRESENT	0
173516	167025	14081Q	PARTICIPANT	\N	PRESENT	0
173517	167025	95067Q	PARTICIPANT	\N	PRESENT	0
173518	167025	11077T	PARTICIPANT	\N	PRESENT	0
173519	167025	11032E	PARTICIPANT	\N	PRESENT	0
173520	167025	14225N	PARTICIPANT	\N	PRESENT	0
173521	167025	14159V	PARTICIPANT	\N	PRESENT	0
173522	167025	04094Q	PARTICIPANT	\N	PRESENT	0
173523	167025	14269B	PARTICIPANT	\N	PRESENT	0
173524	167025	01014K	PARTICIPANT	\N	PRESENT	0
173525	167025	11023D	PARTICIPANT	\N	PRESENT	0
173526	167025	08035V	PARTICIPANT	\N	PRESENT	0
173603	167025	14219Q	PARTICIPANT	\N	PRESENT	0
173528	167025	11113E	PARTICIPANT	\N	PRESENT	0
173593	167025	01034P	PARTICIPANT	\N	PRESENT	0
173530	167025	11114F	PARTICIPANT	\N	PRESENT	0
173594	167025	14275Y	PARTICIPANT	\N	PRESENT	0
173595	167025	01025N	PARTICIPANT	\N	PRESENT	0
173533	167025	11109J	PARTICIPANT	\N	PRESENT	0
173534	167025	13002U	PARTICIPANT	\N	PRESENT	0
173535	167025	11029K	PARTICIPANT	\N	PRESENT	0
173585	167025	14255U	PARTICIPANT	\N	PRESENT	0
173537	167025	04067M	PARTICIPANT	\N	PRESENT	0
173538	167025	14253S	PARTICIPANT	\N	PRESENT	0
173539	167025	11083R	PARTICIPANT	\N	PRESENT	0
173540	167025	11033F	PARTICIPANT	\N	PRESENT	0
173541	167025	11076S	PARTICIPANT	\N	PRESENT	0
173586	167025	11053K	PARTICIPANT	\N	PRESENT	0
173543	167025	92044U	PARTICIPANT	\N	PRESENT	0
173544	167025	14055N	PARTICIPANT	\N	PRESENT	0
173587	167025	14267Y	PARTICIPANT	\N	PRESENT	0
173588	167025	11070L	PARTICIPANT	\N	PRESENT	0
173547	167025	08051V	PARTICIPANT	\N	PRESENT	0
173589	167025	08015R	PARTICIPANT	\N	PRESENT	0
173549	167025	04078Q	PARTICIPANT	\N	PRESENT	0
173550	167025	08031R	PARTICIPANT	\N	PRESENT	0
173551	167025	01046T	PARTICIPANT	\N	PRESENT	0
173571	167025	11064N	PARTICIPANT	\N	PRESENT	0
173553	167025	11012A	PARTICIPANT	\N	PRESENT	0
173554	167025	11110B	PARTICIPANT	\N	PRESENT	0
173555	167025	11081P	PARTICIPANT	\N	PRESENT	0
173607	167025	11065P	PARTICIPANT	\N	PRESENT	0
173557	167025	14018U	PARTICIPANT	\N	PRESENT	0
173605	167025	11085T	PARTICIPANT	\N	PRESENT	0
173559	167025	14201E	PARTICIPANT	\N	PRESENT	0
173604	167025	14103D	PARTICIPANT	\N	PRESENT	0
173601	167025	14327T	PARTICIPANT	\N	PRESENT	0
173562	167025	14241N	PARTICIPANT	\N	PRESENT	0
173600	167025	14277B	PARTICIPANT	\N	PRESENT	0
173564	167025	14030Q	PARTICIPANT	\N	PRESENT	0
173565	167025	14034U	PARTICIPANT	\N	PRESENT	0
173566	167025	14083S	PARTICIPANT	\N	PRESENT	0
173598	167025	14042U	PARTICIPANT	\N	PRESENT	0
173597	167025	04089T	PARTICIPANT	\N	PRESENT	0
173596	167025	98042T	PARTICIPANT	\N	PRESENT	0
173602	167025	14073Q	PARTICIPANT	\N	PRESENT	0
173572	167025	04055H	PARTICIPANT	\N	PRESENT	0
173573	167025	14221J	PARTICIPANT	\N	PRESENT	0
173574	167025	04042C	PARTICIPANT	\N	PRESENT	0
173575	167025	01043Q	PARTICIPANT	\N	PRESENT	0
173576	167025	14231L	PARTICIPANT	\N	PRESENT	0
173577	167025	11093T	PARTICIPANT	\N	PRESENT	0
173578	167025	11082Q	PARTICIPANT	\N	PRESENT	0
173579	167025	98053W	PARTICIPANT	\N	PRESENT	0
173580	167025	08017T	PARTICIPANT	\N	PRESENT	0
173581	167025	11063M	PARTICIPANT	\N	PRESENT	0
173583	167025	01057W	PARTICIPANT	\N	PRESENT	0
173584	167025	04040A	PARTICIPANT	\N	PRESENT	0
173590	167025	14259Y	PARTICIPANT	\N	PRESENT	0
173591	167025	99002P	PARTICIPANT	\N	PRESENT	0
173592	167025	01047U	PARTICIPANT	\N	PRESENT	0
173606	167025	01007L	PARTICIPANT	\N	PRESENT	0
173609	167025	08009T	PARTICIPANT	\N	PRESENT	0
173612	167025	01028R	PARTICIPANT	\N	PRESENT	0
173627	167025	04071H	PARTICIPANT	\N	PRESENT	0
173636	167025	11026G	PARTICIPANT	\N	PRESENT	0
173624	167025	05004A	PARTICIPANT	\N	PRESENT	0
173626	167025	05008E	PARTICIPANT	\N	PRESENT	0
173630	167025	11068S	PARTICIPANT	\N	PRESENT	0
173925	167032	04081K	PARTICIPANT	\N	PRESENT	0
173926	167032	14087W	PARTICIPANT	\N	PRESENT	0
173927	167032	11063M	PARTICIPANT	\N	PRESENT	0
173928	167032	04067M	PARTICIPANT	\N	PRESENT	0
173929	167032	07029T	PARTICIPANT	\N	PRESENT	0
173930	167032	14041T	PARTICIPANT	\N	PRESENT	0
173939	167032	14083S	PARTICIPANT	\N	PRESENT	0
173940	167032	11097X	PARTICIPANT	\N	PRESENT	0
173941	167032	04053F	PARTICIPANT	\N	PRESENT	0
173942	167032	14269B	PARTICIPANT	\N	PRESENT	0
173943	167032	08052W	PARTICIPANT	\N	PRESENT	0
173944	167032	14261S	PARTICIPANT	\N	PRESENT	0
173945	167032	14034U	PARTICIPANT	\N	PRESENT	0
173946	167032	14018U	PARTICIPANT	\N	PRESENT	0
173947	167032	11036J	PARTICIPANT	\N	PRESENT	0
173948	167032	04088S	PARTICIPANT	\N	PRESENT	0
173958	167032	04043D	PARTICIPANT	\N	PRESENT	0
173959	167032	14225N	PARTICIPANT	\N	PRESENT	0
173960	167032	14069U	PARTICIPANT	\N	PRESENT	0
173972	167032	04092N	PARTICIPANT	\N	PRESENT	0
173980	167032	14037X	PARTICIPANT	\N	PRESENT	0
173982	167032	14103D	PARTICIPANT	\N	PRESENT	0
173985	167032	14033T	PARTICIPANT	\N	PRESENT	0
173997	167032	95030B	PARTICIPANT	\N	PRESENT	0
173999	167032	13002U	PARTICIPANT	\N	PRESENT	0
174005	167032	11012A	PARTICIPANT	\N	PRESENT	0
174006	167032	14219Q	PARTICIPANT	\N	PRESENT	0
174012	167032	08069G	PARTICIPANT	\N	PRESENT	0
184613	184612	98021N	PARTICIPANT	\N	PRESENT	0
184614	184612	01056V	PARTICIPANT	\N	PRESENT	0
184615	184612	14133K	PARTICIPANT	\N	PRESENT	0
184616	184612	95037J	PARTICIPANT	\N	PRESENT	0
184694	184672	04061F	PARTICIPANT	\N	PRESENT	0
184695	184672	88008L	PARTICIPANT	\N	PRESENT	0
184713	184712	89017R	PARTICIPANT	\N	PRESENT	0
185993	185992	08034U	PARTICIPANT	\N	PRESENT	0
186033	186032	11053K	PARTICIPANT	\N	PRESENT	0
186232	184963	04040A	PRESIDENT	0	PRESENT	0
186233	184963	04086Q	PARTICIPANT	\N	PRESENT	0
186234	184963	01027Q	PARTICIPANT	\N	PRESENT	0
186235	184963	11112D	PARTICIPANT	\N	PRESENT	0
186236	184963	08010L	PARTICIPANT	\N	PRESENT	0
186237	184963	08051V	PARTICIPANT	\N	PRESENT	0
186238	184963	14071N	PARTICIPANT	\N	PRESENT	0
186239	184963	95063L	PARTICIPANT	\N	PRESENT	0
186240	184963	14051J	PARTICIPANT	\N	PRESENT	0
186241	184963	95067Q	PARTICIPANT	\N	PRESENT	0
186242	184963	14069U	PARTICIPANT	\N	PRESENT	0
186243	184963	05012A	PARTICIPANT	\N	PRESENT	0
186273	186272	95015C	PARTICIPANT	\N	PRESENT	0
186274	186272	14241N	PARTICIPANT	\N	PRESENT	0
186276	186275	95015C	PARTICIPANT	\N	PRESENT	0
186277	186275	14241N	PARTICIPANT	\N	PRESENT	0
186677	186676	14219Q	PRESIDENT	0	PRESENT	0
186678	186676	14033T	PARTICIPANT	\N	PRESENT	0
186679	186676	05012A	PARTICIPANT	\N	PRESENT	0
186680	186676	01056V	PARTICIPANT	\N	PRESENT	0
186681	186676	08049C	PARTICIPANT	\N	PRESENT	0
186682	186676	11090Q	PARTICIPANT	\N	PRESENT	0
186683	186676	01008M	PARTICIPANT	\N	PRESENT	0
186684	186676	11065P	PARTICIPANT	\N	PRESENT	0
186685	186676	11048N	PARTICIPANT	\N	PRESENT	0
186686	186676	14093U	PARTICIPANT	\N	PRESENT	0
186687	186676	90003B	PARTICIPANT	\N	PRESENT	0
190866	190695	11074Q	PARTICIPANT	\N	PRESENT	0
190867	190695	89017R	PARTICIPANT	\N	PRESENT	0
190868	190695	11070L	PARTICIPANT	\N	PRESENT	0
190869	190695	14225N	PARTICIPANT	\N	PRESENT	0
190870	190695	11088W	PARTICIPANT	\N	PRESENT	0
190871	190695	07029T	PARTICIPANT	\N	PRESENT	0
190872	190695	14277B	PARTICIPANT	\N	PRESENT	0
190873	190695	14085U	PARTICIPANT	\N	PRESENT	0
190874	190695	08010L	PARTICIPANT	\N	PRESENT	0
190875	190695	08061X	PARTICIPANT	\N	PRESENT	0
190876	190695	14253S	PARTICIPANT	\N	PRESENT	0
190877	190695	01031L	PARTICIPANT	\N	PRESENT	0
190878	190695	11048N	PARTICIPANT	\N	PRESENT	0
190879	190695	08069G	PARTICIPANT	\N	PRESENT	0
190880	190695	01016M	PARTICIPANT	\N	PRESENT	0
190881	190695	08011M	PARTICIPANT	\N	PRESENT	0
190882	190695	08014Q	PARTICIPANT	\N	PRESENT	0
190883	190695	01027Q	PARTICIPANT	\N	PRESENT	0
190884	190695	14159V	PARTICIPANT	\N	PRESENT	0
190885	190695	14173T	PARTICIPANT	\N	PRESENT	0
190886	190695	11040E	PARTICIPANT	\N	PRESENT	0
190887	190695	04086Q	PARTICIPANT	\N	PRESENT	0
190888	190695	14083S	PARTICIPANT	\N	PRESENT	0
190889	190695	11057P	PARTICIPANT	\N	PRESENT	0
190890	190695	11012A	PARTICIPANT	\N	PRESENT	0
190891	190695	14199E	PARTICIPANT	\N	PRESENT	0
190892	190695	08073C	PARTICIPANT	\N	PRESENT	0
190893	190695	11083R	PARTICIPANT	\N	PRESENT	0
190894	190695	04061F	PARTICIPANT	\N	PRESENT	0
190895	190695	11042G	PARTICIPANT	\N	PRESENT	0
191792	191712	14030Q	PARTICIPANT	\N	PRESENT	0
191793	191712	08043V	PARTICIPANT	\N	PRESENT	0
191794	191712	11029K	PARTICIPANT	\N	PRESENT	0
191795	191712	14038Y	PARTICIPANT	\N	PRESENT	0
191796	191712	11031D	PARTICIPANT	\N	EXCUSE	0
191797	191712	14041T	PARTICIPANT	\N	EXCUSE	0
191798	191712	14217N	PARTICIPANT	\N	PRESENT	0
191799	191712	07026Q	PARTICIPANT	\N	PRESENT	0
191800	191712	95035G	PARTICIPANT	\N	PRESENT	0
191801	191712	08056B	PARTICIPANT	\N	EXCUSE	0
191802	191712	09001P	PRESIDENT	0	PRESENT	0
191803	191712	04036E	PARTICIPANT	\N	EXCUSE	0
191804	191712	08031R	PARTICIPANT	\N	PRESENT	0
191805	191712	14031R	PARTICIPANT	\N	PRESENT	0
191806	191712	11067R	PARTICIPANT	\N	PRESENT	0
191807	191712	11014C	PARTICIPANT	\N	EXCUSE	0
191808	191712	14109K	PARTICIPANT	\N	PRESENT	0
191809	191712	14265W	PARTICIPANT	\N	PRESENT	0
196892	196878	11082Q	PRESIDENT	0	PRESENT	0
196893	196878	04043D	PARTICIPANT	\N	PRESENT	0
196894	196878	01058X	PARTICIPANT	\N	PRESENT	0
196895	196878	11068S	PARTICIPANT	\N	PRESENT	0
196896	196878	11089X	PARTICIPANT	\N	PRESENT	0
196897	196878	01046T	PARTICIPANT	\N	EXCUSE	0
196898	196878	11036J	PARTICIPANT	\N	PRESENT	0
196899	196878	14209N	PARTICIPANT	\N	EXCUSE	0
196900	196878	80013X	PARTICIPANT	\N	EXCUSE	0
196901	196878	11061K	PARTICIPANT	\N	EXCUSE	0
196902	196878	08069G	PARTICIPANT	\N	EXCUSE	0
196903	196878	08039A	PARTICIPANT	\N	EXCUSE	0
196904	196878	01048V	PARTICIPANT	\N	EXCUSE	0
196905	196878	14221J	PARTICIPANT	\N	EXCUSE	0
196906	196878	14257W	PARTICIPANT	\N	EXCUSE	0
196953	196952	01013J	PARTICIPANT	\N	PRESENT	0
206450	205930	04097T	PARTICIPANT	\N	PRESENT	0
206474	205930	08044W	PARTICIPANT	\N	EXCUSE	0
206452	205930	14097Y	PARTICIPANT	\N	PRESENT	0
206453	205930	04061F	PARTICIPANT	\N	PRESENT	0
206454	205930	14061L	PARTICIPANT	\N	PRESENT	0
206455	205930	14073Q	PARTICIPANT	\N	PRESENT	0
206456	205930	11026G	PARTICIPANT	\N	PRESENT	0
206457	205930	08039A	PARTICIPANT	\N	PRESENT	0
206458	205930	14001X	PARTICIPANT	\N	PRESENT	0
206459	205930	14221J	PARTICIPANT	\N	PRESENT	0
206460	205930	04057K	PARTICIPANT	\N	PRESENT	0
206461	205930	19563B	PARTICIPANT	\N	PRESENT	0
206475	205930	19335Q	PARTICIPANT	\N	EXCUSE	0
206463	205930	19593H	PARTICIPANT	\N	PRESENT	0
206464	205930	08073C	PARTICIPANT	\N	PRESENT	0
206465	205930	14237S	PARTICIPANT	\N	PRESENT	0
206466	205930	14135M	PARTICIPANT	\N	PRESENT	0
206467	205930	14331P	PARTICIPANT	\N	PRESENT	0
206468	205930	14225N	PARTICIPANT	\N	PRESENT	0
206469	205930	10015M	PARTICIPANT	\N	PRESENT	0
206470	205930	14229S	PARTICIPANT	\N	PRESENT	0
206471	205930	98035U	PARTICIPANT	\N	PRESENT	0
206472	205930	95067Q	PARTICIPANT	\N	PRESENT	0
206473	205930	19521Q	PARTICIPANT	\N	EXCUSE	0
206476	205930	98053W	PARTICIPANT	\N	EXCUSE	0
206479	206478	07029T	PARTICIPANT	\N	PRESENT	0
206484	206483	07029T	PARTICIPANT	\N	PRESENT	0
206513	206512	07034Q	PARTICIPANT	\N	PRESENT	0
206518	206517	04047H	PRESIDENT	0	PRESENT	0
206519	206517	05008E	PARTICIPANT	\N	PRESENT	0
206520	206517	14041T	PARTICIPANT	\N	PRESENT	0
206521	206517	14089Y	PARTICIPANT	\N	PRESENT	0
206522	206517	14065Q	PARTICIPANT	\N	PRESENT	0
206523	206517	08058D	PARTICIPANT	\N	PRESENT	0
206524	206517	19543W	PARTICIPANT	\N	PRESENT	0
206525	206517	04085P	PARTICIPANT	\N	PRESENT	0
199498	198068	01061S	PARTICIPANT	\N	EXCUSE	0
208721	207682	14195A	PARTICIPANT	\N	PRESENT	0
208722	207682	19669L	PARTICIPANT	\N	PRESENT	0
208723	207682	19703U	PARTICIPANT	\N	PRESENT	0
208724	207682	19675J	PARTICIPANT	\N	PRESENT	0
208839	207523	19711U	PARTICIPANT	\N	PRESENT	0
208840	207523	19643A	PARTICIPANT	\N	PRESENT	0
208841	207523	08020N	PARTICIPANT	\N	PRESENT	0
208842	207523	04092N	PARTICIPANT	\N	PRESENT	0
208843	207523	15447F	PARTICIPANT	\N	PRESENT	0
208844	207523	11101A	PARTICIPANT	\N	PRESENT	0
208845	207523	04086Q	PARTICIPANT	\N	PRESENT	0
208846	207523	08028W	PARTICIPANT	\N	PRESENT	0
208847	207523	17637T	PARTICIPANT	\N	PRESENT	0
208848	207523	14169X	PARTICIPANT	\N	PRESENT	0
208849	207523	11080N	PARTICIPANT	\N	PRESENT	0
208850	207523	14157T	PARTICIPANT	\N	PRESENT	0
208851	207523	95015C	PARTICIPANT	\N	PRESENT	0
208852	207523	14211G	PARTICIPANT	\N	PRESENT	0
208853	207523	08010L	PARTICIPANT	\N	PRESENT	0
208854	207523	08041T	PARTICIPANT	\N	PRESENT	0
208855	207523	14031R	PARTICIPANT	\N	PRESENT	0
208856	207523	14147R	PARTICIPANT	\N	PRESENT	0
208857	207523	98023Q	PARTICIPANT	\N	PRESENT	0
208858	207523	14026U	PARTICIPANT	\N	PRESENT	0
208859	207523	01048V	PARTICIPANT	\N	PRESENT	0
208860	207523	95041E	PARTICIPANT	\N	PRESENT	0
208861	207523	14191V	PARTICIPANT	\N	PRESENT	0
208862	207523	14123H	PARTICIPANT	\N	PRESENT	0
208863	207523	04047H	PARTICIPANT	\N	PRESENT	0
208864	207523	98024R	PARTICIPANT	\N	PRESENT	0
208865	207523	14357A	PARTICIPANT	\N	PRESENT	0
208866	207523	11103C	PARTICIPANT	\N	PRESENT	0
208867	207523	14087W	PARTICIPANT	\N	PRESENT	0
208868	207523	86034E	PARTICIPANT	\N	PRESENT	0
208869	207523	08068F	PARTICIPANT	\N	PRESENT	0
208870	207523	11027H	PARTICIPANT	\N	PRESENT	0
208871	207523	19581D	PARTICIPANT	\N	PRESENT	0
208872	207523	98035U	PARTICIPANT	\N	PRESENT	0
208873	207523	19671E	PARTICIPANT	\N	PRESENT	0
208874	207523	04034C	PARTICIPANT	\N	PRESENT	0
208875	207523	17583W	PARTICIPANT	\N	PRESENT	0
208876	207523	19651A	PARTICIPANT	\N	PRESENT	0
208877	207523	11097X	PARTICIPANT	\N	PRESENT	0
208878	207523	08055A	PARTICIPANT	\N	PRESENT	0
208879	207523	07033P	PARTICIPANT	\N	PRESENT	0
208880	207523	95063L	PARTICIPANT	\N	PRESENT	0
208881	207523	04045F	PARTICIPANT	\N	PRESENT	0
208882	207523	07034Q	PARTICIPANT	\N	PRESENT	0
208931	207523	08024S	PARTICIPANT	\N	PRESENT	0
208932	207523	14028W	PARTICIPANT	\N	PRESENT	0
208933	207523	14197C	PARTICIPANT	\N	PRESENT	0
208934	207523	80013X	PARTICIPANT	\N	PRESENT	0
208935	207523	08038Y	PARTICIPANT	\N	PRESENT	0
208936	207523	14079W	PARTICIPANT	\N	PRESENT	0
208937	207523	11066Q	PARTICIPANT	\N	PRESENT	0
208938	207523	19733B	PARTICIPANT	\N	PRESENT	0
208939	207523	14065Q	PARTICIPANT	\N	PRESENT	0
208940	207523	19549D	PARTICIPANT	\N	PRESENT	0
208941	207523	14105F	PARTICIPANT	\N	PRESENT	0
208942	207523	08043V	PARTICIPANT	\N	PRESENT	0
208943	207523	14193X	PARTICIPANT	\N	PRESENT	0
208944	207523	11104D	PARTICIPANT	\N	PRESENT	0
208945	207523	08035V	PARTICIPANT	\N	PRESENT	0
208946	207523	08047A	PARTICIPANT	\N	PRESENT	0
208947	207523	08012N	PARTICIPANT	\N	PRESENT	0
208948	207523	80027E	PARTICIPANT	\N	PRESENT	0
208980	207523	11054L	PARTICIPANT	\N	PRESENT	0
208950	207523	19727D	PARTICIPANT	\N	PRESENT	0
208951	207523	19531S	PARTICIPANT	\N	PRESENT	0
208952	207523	05012A	PARTICIPANT	\N	PRESENT	0
208953	207523	19489J	PARTICIPANT	\N	PRESENT	0
208954	207523	17779H	PARTICIPANT	\N	PRESENT	0
208955	207523	08058D	PARTICIPANT	\N	PRESENT	0
208956	207523	14121F	PARTICIPANT	\N	PRESENT	0
208957	207523	14085U	PARTICIPANT	\N	PRESENT	0
208958	207523	08017T	PARTICIPANT	\N	PRESENT	0
208959	207523	19525U	PARTICIPANT	\N	PRESENT	0
208960	207523	19383Y	PARTICIPANT	\N	PRESENT	0
208961	207523	11045K	PARTICIPANT	\N	PRESENT	0
208962	207523	14081Q	PARTICIPANT	\N	PRESENT	0
208963	207523	19675J	PARTICIPANT	\N	PRESENT	0
208964	207523	11041F	PARTICIPANT	\N	PRESENT	0
208965	207523	19599P	PARTICIPANT	\N	PRESENT	0
208966	207523	98050T	PARTICIPANT	\N	PRESENT	0
208967	207523	14207L	PARTICIPANT	\N	PRESENT	0
208968	207523	01058X	PARTICIPANT	\N	PRESENT	0
208969	207523	19725B	PARTICIPANT	\N	PRESENT	0
208970	207523	87003B	PARTICIPANT	\N	PRESENT	0
208971	207523	19333N	PARTICIPANT	\N	PRESENT	0
208972	207523	08014Q	PARTICIPANT	\N	PRESENT	0
208973	207523	14227Q	PARTICIPANT	\N	PRESENT	0
208974	207523	11115U	PARTICIPANT	\N	PRESENT	0
208975	207523	19683J	PARTICIPANT	\N	PRESENT	0
208976	207523	08039A	PARTICIPANT	\N	PRESENT	0
208977	207523	11109J	PARTICIPANT	\N	PRESENT	0
208978	207523	19295A	PARTICIPANT	\N	PRESENT	0
208979	207523	19483C	PARTICIPANT	\N	PRESENT	0
208981	207523	19689Q	PARTICIPANT	\N	PRESENT	0
208982	207523	04097T	PARTICIPANT	\N	PRESENT	0
208983	207523	19413M	PARTICIPANT	\N	PRESENT	0
208984	207523	14215L	PARTICIPANT	\N	PRESENT	0
208985	207523	19669L	PARTICIPANT	\N	PRESENT	0
208986	207523	01062T	PARTICIPANT	\N	PRESENT	0
208987	207523	19703U	PARTICIPANT	\N	PRESENT	0
208988	207523	19251M	PARTICIPANT	\N	PRESENT	0
208989	207523	11026G	PARTICIPANT	\N	PRESENT	0
208990	207523	19503N	PARTICIPANT	\N	PRESENT	0
208991	207523	11067R	PARTICIPANT	\N	PRESENT	0
208992	207523	14249W	PARTICIPANT	\N	PRESENT	0
208993	207523	08053X	PARTICIPANT	\N	PRESENT	0
208994	207523	19673G	PARTICIPANT	\N	PRESENT	0
208995	207523	14063N	PARTICIPANT	\N	PRESENT	0
208996	207523	14135M	PARTICIPANT	\N	PRESENT	0
208997	207523	19447X	PARTICIPANT	\N	PRESENT	0
208837	207523	95062K	PARTICIPANT	\N	PRESENT	0
208838	207523	99004R	PARTICIPANT	\N	PRESENT	0
208998	207523	19631V	PARTICIPANT	\N	PRESENT	0
208999	207523	14109K	PARTICIPANT	\N	PRESENT	0
209000	207523	98005N	PARTICIPANT	\N	PRESENT	0
209001	207523	14257W	PARTICIPANT	\N	PRESENT	0
209002	207523	08062Y	PARTICIPANT	\N	PRESENT	0
209003	207523	14115H	PARTICIPANT	\N	PRESENT	0
209004	207523	11010L	PARTICIPANT	\N	PRESENT	0
209005	207523	19663E	PARTICIPANT	\N	PRESENT	0
209006	207523	08061X	PARTICIPANT	\N	PRESENT	0
209007	207523	08073C	PARTICIPANT	\N	PRESENT	0
209008	207523	19349W	PARTICIPANT	\N	PRESENT	0
209009	207523	11072N	PARTICIPANT	\N	PRESENT	0
209010	207523	05008E	PARTICIPANT	\N	PRESENT	0
209011	207523	19637C	PARTICIPANT	\N	PRESENT	0
209012	207523	19677L	PARTICIPANT	\N	PRESENT	0
209013	207523	19697Q	PARTICIPANT	\N	PRESENT	0
209014	207523	14039A	PARTICIPANT	\N	PRESENT	0
209015	207523	08019V	PARTICIPANT	\N	PRESENT	0
209016	207523	95037J	PARTICIPANT	\N	PRESENT	0
209017	207523	14173T	PARTICIPANT	\N	PRESENT	0
209018	207523	08021P	PARTICIPANT	\N	PRESENT	0
209019	207523	19543W	PARTICIPANT	\N	PRESENT	0
209020	207523	14239U	PARTICIPANT	\N	PRESENT	0
209021	207523	98029W	PARTICIPANT	\N	PRESENT	0
209022	207523	07029T	PARTICIPANT	\N	PRESENT	0
209023	207523	19723Y	PARTICIPANT	\N	PRESENT	0
209024	207523	19507S	PARTICIPANT	\N	PRESENT	0
209025	207523	11083R	PARTICIPANT	\N	PRESENT	0
209026	207523	19421M	PARTICIPANT	\N	PRESENT	0
209027	207523	89017R	PARTICIPANT	\N	PRESENT	0
209028	207523	19685L	PARTICIPANT	\N	PRESENT	0
209029	207523	01060R	PARTICIPANT	\N	PRESENT	0
209030	207523	14055N	PARTICIPANT	\N	PRESENT	0
209031	207523	19443T	PARTICIPANT	\N	PRESENT	0
209032	207523	19731Y	PARTICIPANT	\N	PRESENT	0
209033	207523	19717B	PARTICIPANT	\N	PRESENT	0
209034	207523	11081P	PARTICIPANT	\N	PRESENT	0
209035	207523	19573D	PARTICIPANT	\N	PRESENT	0
209036	207523	19629C	PARTICIPANT	\N	PRESENT	0
209037	207523	14253S	PARTICIPANT	\N	PRESENT	0
209038	207523	14201E	PARTICIPANT	\N	PRESENT	0
209039	207523	19575F	PARTICIPANT	\N	PRESENT	0
209040	207523	19253P	PARTICIPANT	\N	PRESENT	0
209041	207523	19719D	PARTICIPANT	\N	PRESENT	0
209042	207523	19693L	PARTICIPANT	\N	PRESENT	0
209043	207523	19387D	PARTICIPANT	\N	PRESENT	0
209044	207523	14034U	PARTICIPANT	\N	PRESENT	0
209045	207523	98022P	PARTICIPANT	\N	PRESENT	0
209046	207523	19729F	PARTICIPANT	\N	PRESENT	0
167673	167672	10015M	PARTICIPANT	\N	PRESENT	0
167674	167672	14191V	PARTICIPANT	\N	PRESENT	0
167675	167672	14201E	PARTICIPANT	\N	PRESENT	0
169992	167014	01028R	PARTICIPANT	\N	PRESENT	0
169993	167014	98053W	PARTICIPANT	\N	PRESENT	0
169994	167014	14257W	PARTICIPANT	\N	PRESENT	0
169995	167014	14241N	PARTICIPANT	\N	PRESENT	0
169996	167014	01046T	PARTICIPANT	\N	PRESENT	0
169997	167014	14123H	PARTICIPANT	\N	PRESENT	0
169998	167014	14195A	PARTICIPANT	\N	PRESENT	0
170012	167014	14249W	PARTICIPANT	\N	PRESENT	0
170013	167014	14217N	PARTICIPANT	\N	PRESENT	0
170014	167014	11036J	PARTICIPANT	\N	PRESENT	0
170015	167014	14033T	PARTICIPANT	\N	PRESENT	0
170016	167014	14265W	PARTICIPANT	\N	PRESENT	0
170017	167014	14133K	PARTICIPANT	\N	PRESENT	0
170018	167014	14073Q	PARTICIPANT	\N	PRESENT	0
170019	167014	14083S	PARTICIPANT	\N	PRESENT	0
170675	170674	04047H	PARTICIPANT	\N	PRESENT	0
170676	170674	14267Y	PARTICIPANT	\N	PRESENT	0
170677	170674	14079W	PARTICIPANT	\N	PRESENT	0
170678	170674	14026U	PARTICIPANT	\N	PRESENT	0
170679	170674	14073Q	PARTICIPANT	\N	PRESENT	0
170680	170674	10015M	PARTICIPANT	\N	PRESENT	0
170681	170674	11012A	PARTICIPANT	\N	PRESENT	0
170682	170674	11066Q	PARTICIPANT	\N	PRESENT	0
170683	170674	95067Q	PARTICIPANT	\N	PRESENT	0
170952	167017	01007L	PARTICIPANT	\N	PRESENT	0
170958	167017	14357A	PARTICIPANT	\N	PRESENT	0
170959	167017	04088S	PARTICIPANT	\N	PRESENT	0
170960	167017	14033T	PARTICIPANT	\N	PRESENT	0
170961	167017	11098Y	PARTICIPANT	\N	PRESENT	0
170972	167017	11100Y	PARTICIPANT	\N	PRESENT	0
170973	167017	07034Q	PARTICIPANT	\N	PRESENT	0
170974	167017	14223L	PARTICIPANT	\N	PRESENT	0
170992	167017	95062K	PARTICIPANT	\N	PRESENT	0
170993	167017	01058X	PARTICIPANT	\N	PRESENT	0
170994	167017	07029T	PARTICIPANT	\N	PRESENT	0
170995	167017	08015R	PARTICIPANT	\N	PRESENT	0
170996	167017	14265W	PARTICIPANT	\N	PRESENT	0
170997	167017	14147R	PARTICIPANT	\N	PRESENT	0
170998	167017	11103C	PARTICIPANT	\N	PRESENT	0
170999	167017	11081P	PARTICIPANT	\N	PRESENT	0
171000	167017	04067M	PARTICIPANT	\N	PRESENT	0
171001	167017	14257W	PARTICIPANT	\N	PRESENT	0
171002	167017	14207L	PARTICIPANT	\N	PRESENT	0
171003	167017	11066Q	PARTICIPANT	\N	PRESENT	0
171004	167017	11067R	PARTICIPANT	\N	PRESENT	0
171005	167017	12042Y	PARTICIPANT	\N	PRESENT	0
171006	167017	08053X	PARTICIPANT	\N	PRESENT	0
171007	167017	08034U	PARTICIPANT	\N	PRESENT	0
171008	167017	14026U	PARTICIPANT	\N	PRESENT	0
171009	167017	14105F	PARTICIPANT	\N	PRESENT	0
171010	167017	04081K	PARTICIPANT	\N	PRESENT	0
171011	167017	04089T	PARTICIPANT	\N	PRESENT	0
171012	167017	08014Q	PARTICIPANT	\N	PRESENT	0
171013	167017	95015C	PARTICIPANT	\N	PRESENT	0
171014	167017	01008M	PARTICIPANT	\N	PRESENT	0
171015	167017	07026Q	PARTICIPANT	\N	PRESENT	0
171016	167017	08068F	PARTICIPANT	\N	PRESENT	0
171017	167017	14361V	PARTICIPANT	\N	PRESENT	0
171018	167017	14119M	PARTICIPANT	\N	PRESENT	0
171019	167017	11037K	PARTICIPANT	\N	PRESENT	0
171021	167017	11025F	PARTICIPANT	\N	PRESENT	0
171022	167017	95063L	PARTICIPANT	\N	PRESENT	0
171023	167017	14038Y	PARTICIPANT	\N	PRESENT	0
171024	167017	14107H	PARTICIPANT	\N	PRESENT	0
171025	167017	14195A	PARTICIPANT	\N	PRESENT	0
171026	167017	14241N	PARTICIPANT	\N	PRESENT	0
171027	167017	14261S	PARTICIPANT	\N	PRESENT	0
171028	167017	01048V	PARTICIPANT	\N	PRESENT	0
171029	167017	90003B	PARTICIPANT	\N	PRESENT	0
171030	167017	14159V	PARTICIPANT	\N	PRESENT	0
171031	167017	11064N	PARTICIPANT	\N	PRESENT	0
171032	167017	11097X	PARTICIPANT	\N	PRESENT	0
171033	167017	11084S	PARTICIPANT	\N	PRESENT	0
171034	167017	04049K	PARTICIPANT	\N	PRESENT	0
171035	167017	95030B	PARTICIPANT	\N	PRESENT	0
171036	167017	14355X	PARTICIPANT	\N	PRESENT	0
171037	167017	14041T	PARTICIPANT	\N	PRESENT	0
171038	167017	14179A	PARTICIPANT	\N	PRESENT	0
171052	167017	14363X	PARTICIPANT	\N	PRESENT	0
171072	167017	05012A	PARTICIPANT	\N	PRESENT	0
171074	167017	14157T	PARTICIPANT	\N	PRESENT	0
171075	167017	14237S	PARTICIPANT	\N	PRESENT	0
171076	167017	11112D	PARTICIPANT	\N	PRESENT	0
171077	167017	92015P	PARTICIPANT	\N	PRESENT	0
171078	167017	14030Q	PARTICIPANT	\N	PRESENT	0
171079	167017	14037X	PARTICIPANT	\N	PRESENT	0
171080	167017	14187A	PARTICIPANT	\N	PRESENT	0
171082	167017	11036J	PARTICIPANT	\N	PRESENT	0
171083	167017	14063N	PARTICIPANT	\N	PRESENT	0
171084	167017	98050T	PARTICIPANT	\N	PRESENT	0
171085	167017	14083S	PARTICIPANT	\N	PRESENT	0
171094	167017	14169X	PARTICIPANT	\N	PRESENT	0
171095	167017	08062Y	PARTICIPANT	\N	PRESENT	0
171097	167017	92045V	PARTICIPANT	\N	PRESENT	0
171098	167017	14231L	PARTICIPANT	\N	PRESENT	0
171099	167017	14267Y	PARTICIPANT	\N	PRESENT	0
171100	167017	14201E	PARTICIPANT	\N	PRESENT	0
171101	167017	11054L	PARTICIPANT	\N	PRESENT	0
171102	167017	11040E	PARTICIPANT	\N	PRESENT	0
171103	167017	14087W	PARTICIPANT	\N	PRESENT	0
171104	167017	14197C	PARTICIPANT	\N	PRESENT	0
171112	167017	11111C	PARTICIPANT	\N	PRESENT	0
171132	167017	14151M	PARTICIPANT	\N	PRESENT	0
171133	167017	11059R	PARTICIPANT	\N	PRESENT	0
171134	167017	80027E	PARTICIPANT	\N	PRESENT	0
171136	167017	80013X	PARTICIPANT	\N	PRESENT	0
171139	167017	11093T	PARTICIPANT	\N	PRESENT	0
171140	167017	95049N	PARTICIPANT	\N	PRESENT	0
171141	167017	14211G	PARTICIPANT	\N	PRESENT	0
171142	167017	08039A	PARTICIPANT	\N	PRESENT	0
171143	167017	01047U	PARTICIPANT	\N	PRESENT	0
171144	167017	14089Y	PARTICIPANT	\N	PRESENT	0
171145	167017	14217N	PARTICIPANT	\N	PRESENT	0
171146	167017	10006L	PARTICIPANT	\N	PRESENT	0
171147	167017	97011G	PARTICIPANT	\N	PRESENT	0
171148	167017	11048N	PARTICIPANT	\N	PRESENT	0
171149	167017	14097Y	PARTICIPANT	\N	PRESENT	0
171150	167017	08055A	PARTICIPANT	\N	PRESENT	0
171152	167017	08016S	PARTICIPANT	\N	PRESENT	0
171153	167017	04059M	PARTICIPANT	\N	PRESENT	0
171172	167017	14121F	PARTICIPANT	\N	PRESENT	0
171173	167017	08017T	PARTICIPANT	\N	PRESENT	0
171174	167017	08043V	PARTICIPANT	\N	PRESENT	0
171175	167017	14329V	PARTICIPANT	\N	PRESENT	0
171176	167017	14191V	PARTICIPANT	\N	PRESENT	0
171177	167017	01024M	PARTICIPANT	\N	PRESENT	0
171178	167017	11012A	PARTICIPANT	\N	PRESENT	0
171179	167017	04070G	PARTICIPANT	\N	PRESENT	0
171181	167017	14073Q	PARTICIPANT	\N	PRESENT	0
171182	167017	14215L	PARTICIPANT	\N	PRESENT	0
171184	167017	14071N	PARTICIPANT	\N	PRESENT	0
171187	167017	08051V	PARTICIPANT	\N	PRESENT	0
171188	167017	01057W	PARTICIPANT	\N	PRESENT	0
171189	167017	14051J	PARTICIPANT	\N	PRESENT	0
171190	167017	11014C	PARTICIPANT	\N	PRESENT	0
171191	167017	14061L	PARTICIPANT	\N	PRESENT	0
171192	167017	01031L	PARTICIPANT	\N	PRESENT	0
171195	167017	11056N	PARTICIPANT	\N	PRESENT	0
171203	167017	14123H	PARTICIPANT	\N	PRESENT	0
171206	167017	11107G	PARTICIPANT	\N	PRESENT	0
171212	167017	14069U	PARTICIPANT	\N	PRESENT	0
171213	167017	01016M	PARTICIPANT	\N	PRESENT	0
171214	167017	04057K	PARTICIPANT	\N	PRESENT	0
171215	167017	08019V	PARTICIPANT	\N	PRESENT	0
171216	167017	11104D	PARTICIPANT	\N	PRESENT	0
171217	167017	08041T	PARTICIPANT	\N	PRESENT	0
171218	167017	87003B	PARTICIPANT	\N	PRESENT	0
171219	167017	11101A	PARTICIPANT	\N	PRESENT	0
171220	167017	14059S	PARTICIPANT	\N	PRESENT	0
171253	167017	11042G	PARTICIPANT	\N	PRESENT	0
171254	167017	08060W	PARTICIPANT	\N	PRESENT	0
171255	167017	11033F	PARTICIPANT	\N	PRESENT	0
171256	167017	11029K	PARTICIPANT	\N	PRESENT	0
171257	167017	11094U	PARTICIPANT	\N	PRESENT	0
171258	167017	14213J	PARTICIPANT	\N	PRESENT	0
171259	167017	14235Q	PARTICIPANT	\N	PRESENT	0
171260	167017	08056B	PARTICIPANT	\N	PRESENT	0
174253	174252	08055A	PARTICIPANT	\N	PRESENT	0
174254	174252	14207L	PARTICIPANT	\N	PRESENT	0
174255	174252	11103C	PARTICIPANT	\N	PRESENT	0
174256	174252	92015P	PARTICIPANT	\N	PRESENT	0
174257	174252	11044J	PARTICIPANT	\N	PRESENT	0
174258	174252	90003B	PARTICIPANT	\N	PRESENT	0
174259	174252	14209N	PARTICIPANT	\N	PRESENT	0
174260	174252	14199E	PARTICIPANT	\N	PRESENT	0
174261	174252	01022K	PARTICIPANT	\N	PRESENT	0
174262	174252	08069G	PARTICIPANT	\N	PRESENT	0
174263	174252	14037X	PARTICIPANT	\N	PRESENT	0
174264	174252	14103D	PARTICIPANT	\N	PRESENT	0
174265	174252	08053X	PARTICIPANT	\N	PRESENT	0
174266	174252	14221J	PARTICIPANT	\N	PRESENT	0
174267	174252	14257W	PARTICIPANT	\N	PRESENT	0
174268	174252	14265W	PARTICIPANT	\N	PRESENT	0
174269	174252	14119M	PARTICIPANT	\N	PRESENT	0
174270	174252	14169X	PARTICIPANT	\N	PRESENT	0
174274	174252	05012A	PARTICIPANT	\N	PRESENT	0
174272	174252	04088S	PARTICIPANT	\N	PRESENT	0
174273	174252	07034Q	PARTICIPANT	\N	PRESENT	0
174275	174252	98050T	PARTICIPANT	\N	PRESENT	0
174276	174252	14271U	PARTICIPANT	\N	PRESENT	0
174277	174252	14363X	PARTICIPANT	\N	PRESENT	0
174278	174252	14107H	PARTICIPANT	\N	PRESENT	0
174279	174252	11094U	PARTICIPANT	\N	PRESENT	0
174280	174252	92045V	PARTICIPANT	\N	PRESENT	0
174281	174252	95067Q	PARTICIPANT	\N	PRESENT	0
174283	174282	11065P	PARTICIPANT	\N	PRESENT	0
174285	174284	11065P	PARTICIPANT	\N	PRESENT	0
174333	174332	12042Y	PARTICIPANT	\N	PRESENT	0
174334	174332	11093T	PARTICIPANT	\N	PRESENT	0
174336	174335	12042Y	PARTICIPANT	\N	PRESENT	0
174337	174335	11093T	PARTICIPANT	\N	PRESENT	0
174339	174338	12042Y	PARTICIPANT	\N	PRESENT	0
174340	174338	11093T	PARTICIPANT	\N	PRESENT	0
177753	177752	07004J	PARTICIPANT	\N	PRESENT	0
177754	177752	04040A	PARTICIPANT	\N	PRESENT	0
189772	188952	11106F	PARTICIPANT	\N	EXCUSE	0
190155	190154	11097X	PARTICIPANT	\N	PRESENT	0
190156	190154	11031D	PARTICIPANT	\N	PRESENT	0
190222	189824	04040A	PARTICIPANT	\N	EXCUSE	0
190223	189824	92020L	PARTICIPANT	\N	EXCUSE	0
190224	189824	08065C	PARTICIPANT	\N	EXCUSE	0
190231	189824	07004J	PARTICIPANT	\N	EXCUSE	0
190232	189824	08056B	PARTICIPANT	\N	EXCUSE	0
190233	189824	14193X	PARTICIPANT	\N	EXCUSE	0
190466	190465	01027Q	PARTICIPANT	\N	PRESENT	0
190468	190467	01027Q	PARTICIPANT	\N	PRESENT	0
190470	190469	01031L	PARTICIPANT	\N	PRESENT	0
190535	190534	95049N	PARTICIPANT	\N	PRESENT	0
190537	190536	95049N	PARTICIPANT	\N	PRESENT	0
190920	190756	11063M	PARTICIPANT	\N	PRESENT	0
190921	190756	11098Y	PARTICIPANT	\N	PRESENT	0
190922	190756	14235Q	PARTICIPANT	\N	PRESENT	0
190923	190756	11031D	PARTICIPANT	\N	PRESENT	0
190924	190756	05001W	PARTICIPANT	\N	PRESENT	0
190925	190756	14361V	PARTICIPANT	\N	PRESENT	0
190926	190756	01059Y	PARTICIPANT	\N	PRESENT	0
190927	190756	11040E	PARTICIPANT	\N	PRESENT	0
190928	190756	01016M	PARTICIPANT	\N	PRESENT	0
190929	190756	11045K	PARTICIPANT	\N	PRESENT	0
190930	190756	14151M	PARTICIPANT	\N	PRESENT	0
190931	190756	11035H	PARTICIPANT	\N	PRESENT	0
190932	190756	01031L	PARTICIPANT	\N	PRESENT	0
190933	190756	92020L	PARTICIPANT	\N	PRESENT	0
190934	190756	08060W	PARTICIPANT	\N	PRESENT	0
190935	190756	04079R	PARTICIPANT	\N	PRESENT	0
190936	190756	14065Q	PARTICIPANT	\N	PRESENT	0
190937	190756	04056J	PARTICIPANT	\N	PRESENT	0
190938	190756	08038Y	PARTICIPANT	\N	PRESENT	0
190939	190756	08017T	PARTICIPANT	\N	PRESENT	0
190940	190756	01008M	PARTICIPANT	\N	PRESENT	0
190941	190756	11054L	PARTICIPANT	\N	PRESENT	0
190942	190756	14001X	PARTICIPANT	\N	PRESENT	0
190943	190756	96004D	PARTICIPANT	\N	PRESENT	0
190944	190756	11095V	PARTICIPANT	\N	PRESENT	0
190945	190756	08014Q	PARTICIPANT	\N	PRESENT	0
190946	190756	01027Q	PARTICIPANT	\N	PRESENT	0
190947	190756	14207L	PARTICIPANT	\N	PRESENT	0
190948	190756	11026G	PARTICIPANT	\N	PRESENT	0
190949	190756	04097T	PARTICIPANT	\N	PRESENT	0
190950	190756	04036E	PARTICIPANT	\N	PRESENT	0
190951	190756	01062T	PARTICIPANT	\N	PRESENT	0
190952	190756	14257W	PARTICIPANT	\N	PRESENT	0
190953	190756	14097Y	PARTICIPANT	\N	PRESENT	0
190954	190756	02002K	PARTICIPANT	\N	PRESENT	0
190955	190756	11112D	PARTICIPANT	\N	PRESENT	0
190956	190756	11074Q	PARTICIPANT	\N	PRESENT	0
190957	190756	14063N	PARTICIPANT	\N	PRESENT	0
190958	190756	08011M	PARTICIPANT	\N	PRESENT	0
190959	190756	14121F	PARTICIPANT	\N	PRESENT	0
190960	190756	14069U	PARTICIPANT	\N	PRESENT	0
190961	190756	14225N	PARTICIPANT	\N	PRESENT	0
190962	190756	01058X	PARTICIPANT	\N	PRESENT	0
190963	190756	14281W	PARTICIPANT	\N	PRESENT	0
190964	190756	04077P	PARTICIPANT	\N	PRESENT	0
190965	190756	08061X	PARTICIPANT	\N	PRESENT	0
190966	190756	08041T	PARTICIPANT	\N	PRESENT	0
190967	190756	11100Y	PARTICIPANT	\N	PRESENT	0
190968	190756	08039A	PARTICIPANT	\N	PRESENT	0
190969	190756	04053F	PARTICIPANT	\N	PRESENT	0
190970	190756	14169X	PARTICIPANT	\N	PRESENT	0
190971	190756	01028R	PARTICIPANT	\N	PRESENT	0
190972	190756	04071H	PARTICIPANT	\N	PRESENT	0
190973	190756	14223L	PARTICIPANT	\N	PRESENT	0
190974	190756	04042C	PARTICIPANT	\N	PRESENT	0
190975	190756	95030B	PARTICIPANT	\N	PRESENT	0
190976	190756	99004R	PARTICIPANT	\N	PRESENT	0
190977	190756	98024R	PARTICIPANT	\N	PRESENT	0
190978	190756	04035D	PARTICIPANT	\N	PRESENT	0
190979	190756	98018T	PARTICIPANT	\N	PRESENT	0
190980	190756	86044G	PARTICIPANT	\N	PRESENT	0
190981	190756	04044E	PARTICIPANT	\N	PRESENT	0
190982	190756	95041E	PARTICIPANT	\N	PRESENT	0
190983	190756	05008E	PARTICIPANT	\N	PRESENT	0
190984	190756	92031P	PARTICIPANT	\N	PRESENT	0
190985	190756	08024S	PARTICIPANT	\N	PRESENT	0
190986	190756	04086Q	PARTICIPANT	\N	PRESENT	0
190987	190756	11036J	PARTICIPANT	\N	PRESENT	0
190988	190756	14071N	PARTICIPANT	\N	PRESENT	0
190989	190756	14271U	PARTICIPANT	\N	PRESENT	0
190990	190756	04033B	PARTICIPANT	\N	PRESENT	0
190991	190756	01057W	PARTICIPANT	\N	PRESENT	0
190992	190756	11080N	PARTICIPANT	\N	PRESENT	0
190993	190756	01019Q	PARTICIPANT	\N	PRESENT	0
190994	190756	11057P	PARTICIPANT	\N	PRESENT	0
190995	190756	87003B	PARTICIPANT	\N	PRESENT	0
190996	190756	08010L	PARTICIPANT	\N	PRESENT	0
190997	190756	04045F	PARTICIPANT	\N	PRESENT	0
190998	190756	11061K	PARTICIPANT	\N	PRESENT	0
190999	190756	04034C	PARTICIPANT	\N	PRESENT	0
191000	190756	95067Q	PARTICIPANT	\N	PRESENT	0
191001	190756	11042G	PARTICIPANT	\N	PRESENT	0
191002	190756	14237S	PARTICIPANT	\N	PRESENT	0
191003	190756	14193X	PARTICIPANT	\N	PRESENT	0
191004	190756	11088W	PARTICIPANT	\N	PRESENT	0
191005	190756	04081K	PARTICIPANT	\N	PRESENT	0
191006	190756	14079W	PARTICIPANT	\N	PRESENT	0
191007	190756	08028W	PARTICIPANT	\N	PRESENT	0
191008	190756	19251M	PARTICIPANT	\N	PRESENT	0
191009	190756	14059S	PARTICIPANT	\N	PRESENT	0
191010	190756	11046L	PARTICIPANT	\N	PRESENT	0
191011	190756	04057K	PARTICIPANT	\N	PRESENT	0
191012	190756	11107G	PARTICIPANT	\N	PRESENT	0
191013	190756	07034Q	PARTICIPANT	\N	PRESENT	0
191014	190756	14269B	PARTICIPANT	\N	PRESENT	0
191015	190756	14251Q	PARTICIPANT	\N	PRESENT	0
191016	190756	14191V	PARTICIPANT	\N	PRESENT	0
191017	190756	14039A	PARTICIPANT	\N	PRESENT	0
191018	190756	11043H	PARTICIPANT	\N	PRESENT	0
191019	190756	01048V	PARTICIPANT	\N	PRESENT	0
191020	190756	11030C	PARTICIPANT	\N	PRESENT	0
191021	190756	01014K	PARTICIPANT	\N	PRESENT	0
191022	190756	11103C	PARTICIPANT	\N	PRESENT	0
191023	190756	04094Q	PARTICIPANT	\N	PRESENT	0
191024	190756	11109J	PARTICIPANT	\N	PRESENT	0
191025	190756	14159V	PARTICIPANT	\N	PRESENT	0
191026	190756	11049P	PARTICIPANT	\N	PRESENT	0
191027	190756	14123H	PARTICIPANT	\N	PRESENT	0
191028	190756	08031R	PARTICIPANT	\N	PRESENT	0
191029	190756	01046T	PARTICIPANT	\N	PRESENT	0
191030	190756	88008L	PARTICIPANT	\N	PRESENT	0
191031	190756	04055H	PARTICIPANT	\N	PRESENT	0
191032	190756	04078Q	PARTICIPANT	\N	PRESENT	0
167713	167712	11031D	PARTICIPANT	\N	PRESENT	0
167714	167712	04054G	PARTICIPANT	\N	PRESENT	0
167715	167712	14039A	PARTICIPANT	\N	PRESENT	0
167716	167712	04071H	PARTICIPANT	\N	PRESENT	0
170334	170332	14089Y	PARTICIPANT	\N	PRESENT	0
167718	167712	11106F	PARTICIPANT	\N	PRESENT	0
167719	167712	11026G	PARTICIPANT	\N	PRESENT	0
170335	170332	14026U	PARTICIPANT	\N	PRESENT	0
167874	167873	98042T	PARTICIPANT	\N	PRESENT	0
167875	167873	01019Q	PARTICIPANT	\N	PRESENT	0
168892	167007	14018U	PARTICIPANT	\N	PRESENT	0
168893	167007	04079R	PARTICIPANT	\N	PRESENT	0
170333	170332	96004D	PARTICIPANT	\N	PRESENT	0
170337	170336	96004D	PARTICIPANT	\N	PRESENT	0
170338	170336	14026U	PARTICIPANT	\N	PRESENT	0
170339	170336	14033T	PARTICIPANT	\N	PRESENT	0
170340	170336	14257W	PARTICIPANT	\N	PRESENT	0
170393	170392	14089Y	PARTICIPANT	\N	PRESENT	0
170394	170392	11029K	PARTICIPANT	\N	PRESENT	0
170395	170392	14207L	PRESIDENT	0	PRESENT	0
170396	170392	14079W	PARTICIPANT	\N	PRESENT	0
170397	170392	14231L	PARTICIPANT	\N	PRESENT	0
170398	170392	11061K	PARTICIPANT	\N	PRESENT	0
170399	170392	14229S	PARTICIPANT	\N	PRESENT	0
170400	170392	04050C	PARTICIPANT	\N	PRESENT	0
170401	170392	14031R	PARTICIPANT	\N	EXCUSE	0
170402	170392	11014C	PARTICIPANT	\N	EXCUSE	0
170403	170392	14053L	PARTICIPANT	\N	EXCUSE	0
170476	170475	14042U	PARTICIPANT	\N	PRESENT	0
170477	170475	01011G	PARTICIPANT	\N	PRESENT	0
182733	182732	14042U	PARTICIPANT	\N	PRESENT	0
182734	182732	01011G	PARTICIPANT	\N	PRESENT	0
182735	182732	11067R	PARTICIPANT	\N	PRESENT	0
182736	182732	14271U	PARTICIPANT	\N	PRESENT	0
182737	182732	14269B	PARTICIPANT	\N	PRESENT	0
182753	182752	95059Q	PARTICIPANT	\N	PRESENT	0
182754	182752	04042C	PARTICIPANT	\N	PRESENT	0
182755	182752	98018T	PARTICIPANT	\N	PRESENT	0
182756	182752	92020L	PARTICIPANT	\N	PRESENT	0
182757	182752	14097Y	PARTICIPANT	\N	PRESENT	0
182758	182752	04080J	PARTICIPANT	\N	PRESENT	0
182760	182759	98021N	PARTICIPANT	\N	PRESENT	0
182761	182759	11106F	PARTICIPANT	\N	PRESENT	0
182762	182759	01056V	PARTICIPANT	\N	PRESENT	0
182763	182759	95037J	PARTICIPANT	\N	PRESENT	0
182765	182764	98021N	PARTICIPANT	\N	PRESENT	0
182766	182764	11106F	PARTICIPANT	\N	PRESENT	0
182767	182764	01056V	PARTICIPANT	\N	PRESENT	0
182768	182764	95037J	PARTICIPANT	\N	PRESENT	0
182770	182769	98021N	PARTICIPANT	\N	PRESENT	0
182771	182769	11106F	PARTICIPANT	\N	PRESENT	0
182772	182769	01056V	PARTICIPANT	\N	PRESENT	0
182773	182769	14133K	PARTICIPANT	\N	PRESENT	0
182774	182769	95037J	PARTICIPANT	\N	PRESENT	0
182776	182775	98021N	PARTICIPANT	\N	PRESENT	0
182777	182775	11106F	PARTICIPANT	\N	PRESENT	0
182778	182775	01056V	PARTICIPANT	\N	PRESENT	0
182779	182775	14133K	PARTICIPANT	\N	PRESENT	0
182780	182775	95037J	PARTICIPANT	\N	PRESENT	0
182813	182812	14219Q	PARTICIPANT	\N	PRESENT	0
182814	182812	11065P	PARTICIPANT	\N	PRESENT	0
182815	182812	14093U	PARTICIPANT	\N	PRESENT	0
186512	184235	14195A	PARTICIPANT	\N	PRESENT	0
186513	184235	14042U	PARTICIPANT	\N	PRESENT	0
186514	184215	04053F	PARTICIPANT	\N	PRESENT	0
186515	184215	14042U	PARTICIPANT	\N	PRESENT	0
186516	184215	14271U	PARTICIPANT	\N	PRESENT	0
186518	186517	98021N	PARTICIPANT	\N	PRESENT	0
186519	186517	11106F	PARTICIPANT	\N	PRESENT	0
186520	186517	01056V	PARTICIPANT	\N	PRESENT	0
186533	186532	98021N	PARTICIPANT	\N	PRESENT	0
186534	186532	11106F	PARTICIPANT	\N	PRESENT	0
186535	186532	95037J	PARTICIPANT	\N	PRESENT	0
188628	188355	04086Q	PARTICIPANT	\N	PRESENT	0
188629	188355	01031L	PRESIDENT	0	PRESENT	0
188630	188355	01048V	PARTICIPANT	\N	PRESENT	0
188631	188355	08034U	PARTICIPANT	\N	PRESENT	0
188632	188355	14085U	PARTICIPANT	\N	PRESENT	0
188633	188355	04034C	PARTICIPANT	\N	PRESENT	0
188634	188355	01016M	PARTICIPANT	\N	PRESENT	0
188635	188355	98053W	PARTICIPANT	\N	PRESENT	0
188636	188355	08011M	PARTICIPANT	\N	PRESENT	0
188637	188355	01027Q	PARTICIPANT	\N	PRESENT	0
188638	188355	14327T	PARTICIPANT	\N	EXCUSE	0
188639	188355	07029T	PARTICIPANT	\N	EXCUSE	0
188640	188355	01057W	PARTICIPANT	\N	EXCUSE	0
188641	188355	08061X	PARTICIPANT	\N	EXCUSE	0
188642	188355	11085T	PARTICIPANT	\N	EXCUSE	0
188643	188355	11088W	PARTICIPANT	\N	EXCUSE	0
189113	189112	14030Q	PARTICIPANT	\N	PRESENT	0
189114	189112	08060W	PARTICIPANT	\N	EXCUSE	0
189115	189112	11029K	PARTICIPANT	\N	PRESENT	0
189116	189112	11031D	PARTICIPANT	\N	EXCUSE	0
189117	189112	14041T	PARTICIPANT	\N	EXCUSE	0
189118	189112	02002K	PARTICIPANT	\N	EXCUSE	0
189119	189112	07026Q	PARTICIPANT	\N	PRESENT	0
189120	189112	95035G	PARTICIPANT	\N	PRESENT	0
189121	189112	09001P	PRESIDENT	0	PRESENT	0
189122	189112	07029T	PARTICIPANT	\N	EXCUSE	0
189123	189112	14031R	PARTICIPANT	\N	EXCUSE	0
189124	189112	11067R	PARTICIPANT	\N	PRESENT	0
189125	189112	11014C	PARTICIPANT	\N	EXCUSE	0
189126	189112	14109K	PARTICIPANT	\N	PRESENT	0
189127	189112	14265W	PARTICIPANT	\N	EXCUSE	0
189128	189112	04088S	PARTICIPANT	\N	PRESENT	0
189129	189112	14357A	PARTICIPANT	\N	PRESENT	0
189130	189112	01008M	PARTICIPANT	\N	PRESENT	0
189131	189112	01022K	PARTICIPANT	\N	PRESENT	0
189132	189112	14207L	PARTICIPANT	\N	PRESENT	0
189133	188272	05012A	PARTICIPANT	\N	PRESENT	0
189134	188272	08068F	PARTICIPANT	\N	PRESENT	0
189135	188272	04045F	PARTICIPANT	\N	PRESENT	0
189136	188272	14051J	PARTICIPANT	\N	PRESENT	0
189137	188272	01057W	PARTICIPANT	\N	PRESENT	0
189138	188272	14327T	PARTICIPANT	\N	PRESENT	0
189139	188272	11112D	PARTICIPANT	\N	PRESENT	0
189140	188272	95067Q	PARTICIPANT	\N	PRESENT	0
189293	189292	95063L	PARTICIPANT	\N	PRESENT	0
200752	190793	04055H	PARTICIPANT	\N	PRESENT	0
200753	190793	98053W	PARTICIPANT	\N	PRESENT	0
200754	190793	19253P	PARTICIPANT	\N	PRESENT	0
200755	190793	11070L	PARTICIPANT	\N	PRESENT	0
200756	190793	08055A	PARTICIPANT	\N	PRESENT	0
200757	190793	01048V	PARTICIPANT	\N	PRESENT	0
200758	190793	04086Q	PARTICIPANT	\N	PRESENT	0
200759	190793	01027Q	PARTICIPANT	\N	PRESENT	0
200760	190793	11048N	PARTICIPANT	\N	PRESENT	0
200761	190793	14135M	PARTICIPANT	\N	PRESENT	0
200762	190793	04035D	PARTICIPANT	\N	PRESENT	0
200763	190793	04034C	PARTICIPANT	\N	PRESENT	0
200764	190793	11053K	PARTICIPANT	\N	PRESENT	0
200765	190793	11067R	PARTICIPANT	\N	PRESENT	0
200766	190793	14269B	PARTICIPANT	\N	PRESENT	0
200767	190793	14033T	PARTICIPANT	\N	PRESENT	0
200768	190793	14157T	PARTICIPANT	\N	PRESENT	0
200769	190793	11091R	PARTICIPANT	\N	PRESENT	0
200770	190793	14159V	PARTICIPANT	\N	PRESENT	0
200771	190793	01016M	PARTICIPANT	\N	PRESENT	0
200772	190793	08056B	PARTICIPANT	\N	PRESENT	0
200773	190793	14261S	PARTICIPANT	\N	PRESENT	0
200774	190793	11054L	PARTICIPANT	\N	PRESENT	0
200775	190793	04081K	PARTICIPANT	\N	PRESENT	0
200776	190793	86034E	PARTICIPANT	\N	PRESENT	0
200777	190793	11097X	PARTICIPANT	\N	PRESENT	0
200778	190793	14085U	PARTICIPANT	\N	PRESENT	0
200779	190793	98046X	PARTICIPANT	\N	PRESENT	0
200780	190793	08011M	PARTICIPANT	\N	PRESENT	0
200781	190793	11088W	PARTICIPANT	\N	PRESENT	0
200782	190793	11057P	PARTICIPANT	\N	PRESENT	0
200783	190793	11064N	PARTICIPANT	\N	PRESENT	0
200784	190793	01034P	PARTICIPANT	\N	PRESENT	0
200785	190793	11029K	PARTICIPANT	\N	PRESENT	0
200786	190793	14225N	PARTICIPANT	\N	PRESENT	0
200787	190793	14119M	PARTICIPANT	\N	PRESENT	0
200788	190793	07029T	PARTICIPANT	\N	PRESENT	0
200789	190793	98005N	PARTICIPANT	\N	PRESENT	0
200790	190793	83047W	PARTICIPANT	\N	PRESENT	0
200791	190793	14083S	PARTICIPANT	\N	PRESENT	0
200792	190793	08034U	PARTICIPANT	\N	PRESENT	0
200793	190793	14247U	PARTICIPANT	\N	PRESENT	0
200794	190793	04092N	PARTICIPANT	\N	PRESENT	0
200795	190793	08042U	PARTICIPANT	\N	PRESENT	0
205527	205526	89017R	PARTICIPANT	\N	EXCUSE	0
205529	205526	14065Q	PARTICIPANT	\N	EXCUSE	0
205530	205526	14030Q	PARTICIPANT	\N	PRESENT	0
205531	205526	14105F	PARTICIPANT	\N	PRESENT	0
205532	205526	08068F	PARTICIPANT	\N	EXCUSE	0
205533	205526	14207L	PARTICIPANT	\N	EXCUSE	0
209047	207523	19553Y	PARTICIPANT	\N	PRESENT	0
209048	207523	14241N	PARTICIPANT	\N	PRESENT	0
209049	207523	11099A	PARTICIPANT	\N	PRESENT	0
209050	207523	19399H	PARTICIPANT	\N	PRESENT	0
209051	207523	11049P	PARTICIPANT	\N	PRESENT	0
209052	207523	14033T	PARTICIPANT	\N	PRESENT	0
209053	207523	08031R	PARTICIPANT	\N	PRESENT	0
209054	207523	19563B	PARTICIPANT	\N	PRESENT	0
209055	207523	11012A	PARTICIPANT	\N	PRESENT	0
209056	207523	08049C	PARTICIPANT	\N	PRESENT	0
209057	207523	08015R	PARTICIPANT	\N	PRESENT	0
209058	207523	14355X	PARTICIPANT	\N	PRESENT	0
209059	207523	19545Y	PARTICIPANT	\N	PRESENT	0
209060	207523	14195A	PARTICIPANT	\N	PRESENT	0
209061	207523	14111D	PARTICIPANT	\N	PRESENT	0
209062	207523	14093U	PARTICIPANT	\N	PRESENT	0
209063	207523	17589D	PARTICIPANT	\N	PRESENT	0
209064	207523	02002K	PARTICIPANT	\N	PRESENT	0
209065	207523	11064N	PARTICIPANT	\N	PRESENT	0
209066	207523	14251Q	PARTICIPANT	\N	PRESENT	0
209067	207523	04057K	PARTICIPANT	\N	PRESENT	0
209068	207523	19367Y	PARTICIPANT	\N	PRESENT	0
209069	207523	19709B	PARTICIPANT	\N	PRESENT	0
209070	207523	14030Q	PARTICIPANT	\N	PRESENT	0
209071	207523	04040A	PARTICIPANT	\N	PRESENT	0
209072	207523	14089Y	PARTICIPANT	\N	PRESENT	0
209073	207523	14255U	PARTICIPANT	\N	PRESENT	0
209074	207523	19705W	PARTICIPANT	\N	PRESENT	0
209075	207523	14083S	PARTICIPANT	\N	PRESENT	0
209076	207523	14199E	PARTICIPANT	\N	PRESENT	0
209077	207523	01043Q	PARTICIPANT	\N	PRESENT	0
209078	207523	14327T	PARTICIPANT	\N	PRESENT	0
209079	207523	19721W	PARTICIPANT	\N	PRESENT	0
209080	207523	14042U	PARTICIPANT	\N	PRESENT	0
209081	207523	14231L	PARTICIPANT	\N	PRESENT	0
209082	207523	08044W	PARTICIPANT	\N	PRESENT	0
209083	207523	14179A	PARTICIPANT	\N	PRESENT	0
209084	207523	19511N	PARTICIPANT	\N	PRESENT	0
209085	207523	19369B	PARTICIPANT	\N	PRESENT	0
209086	207523	04018C	PARTICIPANT	\N	PRESENT	0
209087	207523	19691J	PARTICIPANT	\N	PRESENT	0
209088	207523	14217N	PARTICIPANT	\N	PRESENT	0
209089	207523	11053K	PARTICIPANT	\N	PRESENT	0
209090	207523	04061F	PARTICIPANT	\N	PRESENT	0
209136	208061	98018T	PARTICIPANT	\N	EXCUSE	0
209137	208061	19319Q	PARTICIPANT	\N	EXCUSE	0
209494	207519	14147R	PARTICIPANT	\N	PRESENT	0
209495	207519	14105F	PARTICIPANT	\N	PRESENT	0
209496	207519	14115H	PARTICIPANT	\N	PRESENT	0
209497	207519	19443T	PARTICIPANT	\N	PRESENT	0
209498	207519	14157T	PARTICIPANT	\N	PRESENT	0
209499	207519	14069U	PARTICIPANT	\N	PRESENT	0
209500	207519	14031R	PARTICIPANT	\N	PRESENT	0
209501	207519	19467C	PARTICIPANT	\N	PRESENT	0
209502	207519	19507S	PARTICIPANT	\N	PRESENT	0
209503	207519	04088S	PARTICIPANT	\N	PRESENT	0
209504	207519	19677L	PARTICIPANT	\N	PRESENT	0
209505	207519	19447X	PARTICIPANT	\N	PRESENT	0
209506	207519	14121F	PARTICIPANT	\N	PRESENT	0
209507	207519	14107H	PARTICIPANT	\N	PRESENT	0
209508	207519	01043Q	PARTICIPANT	\N	PRESENT	0
209509	207519	95030B	PARTICIPANT	\N	PRESENT	0
209510	207519	07004J	PARTICIPANT	\N	PRESENT	0
209511	207519	11103C	PARTICIPANT	\N	PRESENT	0
209512	207519	14265W	PARTICIPANT	\N	PRESENT	0
209513	207519	95062K	PARTICIPANT	\N	PRESENT	0
209514	207519	07029T	PARTICIPANT	\N	PRESENT	0
209515	207519	08031R	PARTICIPANT	\N	PRESENT	0
209516	207519	14038Y	PARTICIPANT	\N	PRESENT	0
209572	208066	11063M	PARTICIPANT	\N	PRESENT	0
209573	208066	08052W	PARTICIPANT	\N	PRESENT	0
209576	208449	11067R	PARTICIPANT	\N	PRESENT	0
209577	208449	11077T	PARTICIPANT	\N	PRESENT	0
209578	208449	19569H	PARTICIPANT	\N	PRESENT	0
209579	208449	11097X	PARTICIPANT	\N	PRESENT	0
209580	208449	19415P	PARTICIPANT	\N	PRESENT	0
209581	208449	04045F	PARTICIPANT	\N	PRESENT	0
209582	208449	14223L	PARTICIPANT	\N	PRESENT	0
209583	208449	14026U	PARTICIPANT	\N	PRESENT	0
209584	208449	14227Q	PARTICIPANT	\N	PRESENT	0
209585	208449	17779H	PARTICIPANT	\N	PRESENT	0
209586	208449	11063M	PARTICIPANT	\N	PRESENT	0
209587	208449	14239U	PARTICIPANT	\N	PRESENT	0
209588	208449	19553Y	PARTICIPANT	\N	PRESENT	0
209589	208449	19703U	PARTICIPANT	\N	PRESENT	0
209590	208449	14281W	PARTICIPANT	\N	PRESENT	0
209591	208449	14087W	PARTICIPANT	\N	PRESENT	0
209592	208449	19575F	PARTICIPANT	\N	PRESENT	0
209593	208449	14195A	PARTICIPANT	\N	PRESENT	0
209594	208449	08048B	PARTICIPANT	\N	PRESENT	0
209595	208449	19367Y	PARTICIPANT	\N	PRESENT	0
209596	208449	14213J	PARTICIPANT	\N	PRESENT	0
209597	208449	14217N	PARTICIPANT	\N	PRESENT	0
209598	208449	19683J	PARTICIPANT	\N	PRESENT	0
209599	208449	98024R	PARTICIPANT	\N	PRESENT	0
209600	208449	19521Q	PARTICIPANT	\N	PRESENT	0
209601	208449	01034P	PARTICIPANT	\N	PRESENT	0
209602	208449	04092N	PRESIDENT	0	PRESENT	0
209603	208449	08052W	PARTICIPANT	\N	PRESENT	0
209604	208449	19663E	PARTICIPANT	\N	PRESENT	0
209605	208449	19715Y	PARTICIPANT	\N	PRESENT	0
209606	208449	19691J	PARTICIPANT	\N	PRESENT	0
209607	208449	19717B	PARTICIPANT	\N	PRESENT	0
209608	208449	08041T	PARTICIPANT	\N	PRESENT	0
209609	208449	19723Y	PARTICIPANT	\N	PRESENT	0
209610	208449	19727D	PARTICIPANT	\N	PRESENT	0
209611	208449	14119M	PARTICIPANT	\N	PRESENT	0
209612	208449	11103C	PARTICIPANT	\N	PRESENT	0
209613	208449	11031D	PARTICIPANT	\N	PRESENT	0
209614	208062	11115U	PARTICIPANT	\N	PRESENT	0
209615	208062	14055N	PARTICIPANT	\N	PRESENT	0
209617	208449	19679N	PARTICIPANT	\N	PRESENT	0
209618	208449	14042U	PARTICIPANT	\N	PRESENT	0
209619	208449	14071N	PARTICIPANT	\N	PRESENT	0
209620	208062	19251M	PARTICIPANT	\N	PRESENT	0
209621	208449	19697Q	PARTICIPANT	\N	PRESENT	0
209622	208443	04085P	PARTICIPANT	\N	PRESENT	0
209623	208443	08055A	PARTICIPANT	\N	PRESENT	0
209672	208443	19549D	PARTICIPANT	\N	EXCUSE	0
209674	208062	98018T	PARTICIPANT	\N	EXCUSE	0
209626	208443	96004D	PARTICIPANT	\N	PRESENT	0
209675	208062	19319Q	PARTICIPANT	\N	EXCUSE	0
209628	208443	19733B	PARTICIPANT	\N	PRESENT	0
209629	208443	19383Y	PARTICIPANT	\N	PRESENT	0
209630	208443	08024S	PARTICIPANT	\N	PRESENT	0
209631	208443	14038Y	PARTICIPANT	\N	PRESENT	0
209632	208443	18083K	PARTICIPANT	\N	PRESENT	0
209633	208443	19701S	PARTICIPANT	\N	PRESENT	0
209634	208443	19681G	PARTICIPANT	\N	PRESENT	0
209635	208443	98023Q	PARTICIPANT	\N	PRESENT	0
209676	208062	08049C	PARTICIPANT	\N	EXCUSE	0
209637	208443	11065P	PARTICIPANT	\N	PRESENT	0
209677	208428	14327T	PARTICIPANT	\N	PRESENT	0
209639	208443	19599P	PARTICIPANT	\N	PRESENT	0
209640	208443	02002K	PARTICIPANT	\N	PRESENT	0
209641	208443	15447F	PARTICIPANT	\N	PRESENT	0
209642	208443	19387D	PARTICIPANT	\N	PRESENT	0
209643	208443	19347U	PARTICIPANT	\N	PRESENT	0
209678	208428	14331P	PARTICIPANT	\N	PRESENT	0
209645	208443	19685L	PARTICIPANT	\N	PRESENT	0
209646	208443	19333N	PARTICIPANT	\N	PRESENT	0
209679	208428	01048V	PARTICIPANT	\N	PRESENT	0
209680	208428	19545Y	PARTICIPANT	\N	PRESENT	0
209649	208443	14029X	PARTICIPANT	\N	PRESENT	0
209650	208443	19677L	PARTICIPANT	\N	PRESENT	0
209681	208428	01057W	PARTICIPANT	\N	PRESENT	0
209652	208443	14219Q	PARTICIPANT	\N	PRESENT	0
209653	208443	14103D	PARTICIPANT	\N	PRESENT	0
209654	208443	80027E	PARTICIPANT	\N	PRESENT	0
209655	208443	14031R	PARTICIPANT	\N	PRESENT	0
209656	208443	19637C	PARTICIPANT	\N	PRESENT	0
209657	208443	08009T	PRESIDENT	0	PRESENT	0
209658	208443	14221J	PARTICIPANT	\N	PRESENT	0
209659	208443	14169X	PARTICIPANT	\N	PRESENT	0
209682	208428	11053K	PARTICIPANT	\N	PRESENT	0
209661	208443	14237S	PARTICIPANT	\N	PRESENT	0
209662	208443	17637T	PARTICIPANT	\N	PRESENT	0
209663	208443	05012A	PARTICIPANT	\N	PRESENT	0
209664	208443	19503N	PARTICIPANT	\N	PRESENT	0
209665	208443	17583W	PARTICIPANT	\N	PRESENT	0
209666	208443	95062K	PARTICIPANT	\N	PRESENT	0
209667	208443	19713W	PARTICIPANT	\N	PRESENT	0
209668	208443	14051J	PARTICIPANT	\N	PRESENT	0
209669	208443	14157T	PARTICIPANT	\N	PRESENT	0
209670	208443	19737F	PARTICIPANT	\N	PRESENT	0
209683	208428	11074Q	PRESIDENT	0	PRESENT	0
209684	208428	89017R	PARTICIPANT	\N	PRESENT	0
209685	208428	14225N	PARTICIPANT	\N	PRESENT	0
209686	208428	19671E	PARTICIPANT	\N	PRESENT	0
170127	170126	14249W	PARTICIPANT	\N	PRESENT	0
170128	170126	07026Q	PARTICIPANT	\N	PRESENT	0
170130	170129	14249W	PARTICIPANT	\N	PRESENT	0
170131	170129	07026Q	PARTICIPANT	\N	PRESENT	0
170693	170692	11033F	PARTICIPANT	\N	PRESENT	0
170694	170692	04044E	PARTICIPANT	\N	PRESENT	0
171138	171137	04086Q	PARTICIPANT	\N	PRESENT	0
171423	167018	11033F	PARTICIPANT	\N	PRESENT	0
171424	167018	95063L	PARTICIPANT	\N	PRESENT	0
171425	167018	11056N	PARTICIPANT	\N	PRESENT	0
171426	167018	08051V	PARTICIPANT	\N	PRESENT	0
171427	167018	01024M	PARTICIPANT	\N	PRESENT	0
171428	167018	07034Q	PARTICIPANT	\N	PRESENT	0
171429	167018	14121F	PARTICIPANT	\N	PRESENT	0
171430	167018	14051J	PARTICIPANT	\N	PRESENT	0
171431	167018	08060W	PARTICIPANT	\N	PRESENT	0
171432	167018	11112D	PARTICIPANT	\N	PRESENT	0
171433	167018	14097Y	PARTICIPANT	\N	PRESENT	0
171435	167018	01031L	PARTICIPANT	\N	PRESENT	0
171436	167018	11042G	PARTICIPANT	\N	PRESENT	0
171437	167018	11025F	PARTICIPANT	\N	PRESENT	0
171438	167018	11084S	PARTICIPANT	\N	PRESENT	0
171439	167018	11067R	PARTICIPANT	\N	PRESENT	0
171440	167018	11104D	PARTICIPANT	\N	PRESENT	0
171441	167018	11029K	PARTICIPANT	\N	PRESENT	0
171442	167018	14159V	PARTICIPANT	\N	PRESENT	0
171443	167018	11037K	PARTICIPANT	\N	PRESENT	0
171444	167018	11012A	PARTICIPANT	\N	PRESENT	0
171445	167018	11094U	PARTICIPANT	\N	PRESENT	0
171446	167018	08056B	PARTICIPANT	\N	PRESENT	0
171447	167018	14083S	PARTICIPANT	\N	PRESENT	0
171448	167018	87003B	PARTICIPANT	\N	PRESENT	0
171449	167018	05008E	PARTICIPANT	\N	PRESENT	0
171450	167018	04085P	PARTICIPANT	\N	PRESENT	0
171451	167018	14059S	PARTICIPANT	\N	PRESENT	0
171452	167018	14061L	PARTICIPANT	\N	PRESENT	0
171453	167018	14187A	PARTICIPANT	\N	PRESENT	0
171454	167018	07029T	PARTICIPANT	\N	PRESENT	0
171455	167018	04088S	PARTICIPANT	\N	PRESENT	0
171456	167018	14357A	PARTICIPANT	\N	PRESENT	0
171457	167018	08048B	PARTICIPANT	\N	PRESENT	0
171458	167018	10006L	PARTICIPANT	\N	PRESENT	0
171459	167018	08041T	PARTICIPANT	\N	PRESENT	0
171460	167018	14191V	PARTICIPANT	\N	PRESENT	0
171461	167018	14123H	PARTICIPANT	\N	PRESENT	0
171462	167018	01028R	PARTICIPANT	\N	PRESENT	0
171463	167018	95049N	PARTICIPANT	\N	PRESENT	0
171464	167018	04066L	PARTICIPANT	\N	PRESENT	0
171472	167018	04057K	PARTICIPANT	\N	PRESENT	0
171473	167018	11054L	PARTICIPANT	\N	PRESENT	0
171474	167018	08017T	PARTICIPANT	\N	PRESENT	0
171475	167018	14199E	PARTICIPANT	\N	PRESENT	0
171476	167018	01008M	PARTICIPANT	\N	PRESENT	0
171477	167018	04059M	PARTICIPANT	\N	PRESENT	0
171479	167018	14271U	PARTICIPANT	\N	PRESENT	0
171480	167018	08015R	PARTICIPANT	\N	PRESENT	0
171481	167018	14235Q	PARTICIPANT	\N	PRESENT	0
171482	167018	14265W	PARTICIPANT	\N	PRESENT	0
171483	167018	14026U	PARTICIPANT	\N	PRESENT	0
171484	167018	95030B	PARTICIPANT	\N	PRESENT	0
171485	167018	14157T	PARTICIPANT	\N	PRESENT	0
171486	167018	14038Y	PARTICIPANT	\N	PRESENT	0
171487	167018	14259Y	PARTICIPANT	\N	PRESENT	0
171488	167018	11034G	PARTICIPANT	\N	PRESENT	0
171489	167018	14361V	PARTICIPANT	\N	PRESENT	0
171490	167018	11026G	PARTICIPANT	\N	PRESENT	0
171491	167018	11080N	PARTICIPANT	\N	PRESENT	0
171492	167018	04079R	PARTICIPANT	\N	PRESENT	0
171493	167018	14355X	PARTICIPANT	\N	PRESENT	0
171494	167018	14173T	PARTICIPANT	\N	PRESENT	0
171495	167018	08055A	PARTICIPANT	\N	PRESENT	0
171496	167018	08043V	PARTICIPANT	\N	PRESENT	0
171497	167018	11097X	PARTICIPANT	\N	PRESENT	0
171512	167020	04066L	PARTICIPANT	\N	PRESENT	0
171513	167020	11034G	PARTICIPANT	\N	PRESENT	0
171514	167020	11036J	PARTICIPANT	\N	PRESENT	0
171515	167020	11054L	PARTICIPANT	\N	PRESENT	0
171516	167020	08060W	PARTICIPANT	\N	PRESENT	0
171517	167020	11067R	PARTICIPANT	\N	PRESENT	0
171518	167020	04079R	PARTICIPANT	\N	PRESENT	0
171519	167020	11084S	PARTICIPANT	\N	PRESENT	0
171520	167020	08043V	PARTICIPANT	\N	PRESENT	0
171521	167020	08024S	PARTICIPANT	\N	PRESENT	0
171522	167020	14271U	PARTICIPANT	\N	PRESENT	0
171523	167020	11066Q	PARTICIPANT	\N	PRESENT	0
171524	167020	01028R	PARTICIPANT	\N	PRESENT	0
171525	167020	11029K	PARTICIPANT	\N	PRESENT	0
171526	167020	11033F	PARTICIPANT	\N	PRESENT	0
171532	167020	11037K	PARTICIPANT	\N	PRESENT	0
171533	167020	11083R	PARTICIPANT	\N	PRESENT	0
171534	167020	11012A	PARTICIPANT	\N	PRESENT	0
171535	167020	04080J	PARTICIPANT	\N	PRESENT	0
171536	167020	14215L	PARTICIPANT	\N	PRESENT	0
171537	167020	14087W	PARTICIPANT	\N	PRESENT	0
171538	167020	04086Q	PARTICIPANT	\N	PRESENT	0
171539	167020	10006L	PARTICIPANT	\N	PRESENT	0
171540	167020	14355X	PARTICIPANT	\N	PRESENT	0
171541	167020	04071H	PARTICIPANT	\N	PRESENT	0
171542	167020	11080N	PARTICIPANT	\N	PRESENT	0
171543	167020	14147R	PARTICIPANT	\N	PRESENT	0
171544	167020	95030B	PARTICIPANT	\N	PRESENT	0
171552	167020	14191V	PARTICIPANT	\N	PRESENT	0
171553	167020	04085P	PARTICIPANT	\N	PRESENT	0
171554	167020	14038Y	PARTICIPANT	\N	PRESENT	0
171555	167020	08031R	PARTICIPANT	\N	PRESENT	0
171556	167020	14361V	PARTICIPANT	\N	PRESENT	0
171557	167020	99004R	PARTICIPANT	\N	PRESENT	0
171558	167020	05008E	PARTICIPANT	\N	PRESENT	0
171559	167020	14259Y	PARTICIPANT	\N	PRESENT	0
171560	167020	14235Q	PARTICIPANT	\N	PRESENT	0
171561	167020	14119M	PARTICIPANT	\N	PRESENT	0
171562	167020	04088S	PARTICIPANT	\N	PRESENT	0
171563	167020	14033T	PARTICIPANT	\N	PRESENT	0
171564	167020	14061L	PARTICIPANT	\N	PRESENT	0
171565	167020	08015R	PARTICIPANT	\N	PRESENT	0
171566	167020	14217N	PARTICIPANT	\N	PRESENT	0
171567	167020	14213J	PARTICIPANT	\N	PRESENT	0
171568	167020	14265W	PARTICIPANT	\N	PRESENT	0
171569	167020	04049K	PARTICIPANT	\N	PRESENT	0
171570	167020	08062Y	PARTICIPANT	\N	PRESENT	0
171571	167020	14187A	PARTICIPANT	\N	PRESENT	0
171572	167020	01008M	PARTICIPANT	\N	PRESENT	0
171573	167020	08069G	PARTICIPANT	\N	PRESENT	0
172222	172221	14219Q	PRESIDENT	0	PRESENT	0
172223	172221	11065P	PARTICIPANT	\N	PRESENT	0
172224	172221	14093U	PARTICIPANT	\N	PRESENT	0
172284	170953	01015L	PARTICIPANT	\N	EXCUSE	0
172285	172221	01015L	PRESIDENT	1	PRESENT	0
172596	172221	01056V	PARTICIPANT	\N	PRESENT	0
172691	172221	08049C	PARTICIPANT	\N	EXCUSE	0
172692	172221	09001P	PARTICIPANT	\N	EXCUSE	0
172712	172221	05012A	PARTICIPANT	\N	PRESENT	0
172713	172221	01008M	PARTICIPANT	\N	PRESENT	0
171422	167018	04047H	PARTICIPANT	\N	PRESENT	0
172714	170953	09001P	PARTICIPANT	\N	EXCUSE	0
172715	172221	92045V	PARTICIPANT	\N	PRESENT	0
172716	172221	90003B	PARTICIPANT	\N	PRESENT	0
172717	172221	80013X	PARTICIPANT	\N	PRESENT	0
172953	172952	04086Q	PARTICIPANT	\N	PRESENT	0
172954	172952	04036E	PARTICIPANT	\N	PRESENT	0
172955	172952	11106F	PARTICIPANT	\N	PRESENT	0
172957	172952	10006L	PARTICIPANT	\N	PRESENT	0
172959	172952	11085T	PARTICIPANT	\N	PRESENT	0
172960	172952	14159V	PARTICIPANT	\N	PRESENT	0
172965	172952	14225N	PARTICIPANT	\N	PRESENT	0
172970	172952	14179A	PARTICIPANT	\N	PRESENT	0
174153	174152	08009T	PARTICIPANT	\N	PRESENT	0
174154	174152	14169X	PARTICIPANT	\N	PRESENT	0
174155	174152	11107G	PARTICIPANT	\N	PRESENT	0
174156	174152	14051J	PARTICIPANT	\N	PRESENT	0
174157	174152	14219Q	PARTICIPANT	\N	PRESENT	0
174158	174152	08062Y	PARTICIPANT	\N	PRESENT	0
174159	174152	14107H	PARTICIPANT	\N	PRESENT	0
174160	174152	11065P	PARTICIPANT	\N	PRESENT	0
175873	175872	14263U	PARTICIPANT	\N	PRESENT	0
175874	175872	11109J	PARTICIPANT	\N	PRESENT	0
175875	175872	04059M	PARTICIPANT	\N	PRESENT	0
175876	175872	11039M	PARTICIPANT	\N	PRESENT	0
175877	175872	01044R	PARTICIPANT	\N	PRESENT	0
175878	175872	08043V	PARTICIPANT	\N	PRESENT	0
175880	175872	14105F	PARTICIPANT	\N	PRESENT	0
175881	175872	11029K	PARTICIPANT	\N	PRESENT	0
175882	175872	95015C	PARTICIPANT	\N	PRESENT	0
175883	175872	92015P	PARTICIPANT	\N	PRESENT	0
175884	175872	08024S	PARTICIPANT	\N	PRESENT	0
175885	175872	14201E	PARTICIPANT	\N	PRESENT	0
190158	190157	14187A	PARTICIPANT	\N	PRESENT	0
190160	190159	08009T	PARTICIPANT	\N	PRESENT	0
190162	190161	08009T	PARTICIPANT	\N	PRESENT	0
190250	190249	96004D	PRESIDENT	0	PRESENT	0
190251	190249	14089Y	PARTICIPANT	\N	PRESENT	0
190252	190249	90003B	PARTICIPANT	\N	PRESENT	0
190253	190249	14079W	PARTICIPANT	\N	PRESENT	0
190254	190249	11035H	PARTICIPANT	\N	EXCUSE	0
190255	190249	14249W	PARTICIPANT	\N	EXCUSE	0
190256	190249	11083R	PARTICIPANT	\N	PRESENT	0
190257	190249	14026U	PARTICIPANT	\N	PRESENT	0
190258	190249	95037J	PARTICIPANT	\N	PRESENT	0
190259	190249	14097Y	PARTICIPANT	\N	PRESENT	0
190260	190249	04061F	PARTICIPANT	\N	PRESENT	0
190261	190249	98046X	PARTICIPANT	\N	PRESENT	0
190262	190249	04057K	PARTICIPANT	\N	PRESENT	0
190263	190249	08042U	PARTICIPANT	\N	EXCUSE	0
190264	190249	14135M	PARTICIPANT	\N	PRESENT	0
190265	190249	01016M	PARTICIPANT	\N	PRESENT	0
190266	190249	95063L	PARTICIPANT	\N	PRESENT	0
190267	190249	92045V	PARTICIPANT	\N	PRESENT	0
190268	190249	04034C	PARTICIPANT	\N	PRESENT	0
190269	190249	95030B	PARTICIPANT	\N	EXCUSE	0
190338	188372	08042U	PARTICIPANT	\N	PRESENT	0
191033	190756	08049C	PARTICIPANT	\N	PRESENT	0
191034	190756	11012A	PARTICIPANT	\N	PRESENT	0
191035	190756	11081P	PARTICIPANT	\N	PRESENT	0
191036	190756	14201E	PARTICIPANT	\N	PRESENT	0
191037	190756	98022P	PARTICIPANT	\N	PRESENT	0
191038	190756	14147R	PARTICIPANT	\N	PRESENT	0
191039	190756	19253P	PARTICIPANT	\N	PRESENT	0
191050	190756	14031R	PARTICIPANT	\N	PRESENT	0
191041	190756	11033F	PARTICIPANT	\N	PRESENT	0
191042	190756	11029K	PARTICIPANT	\N	PRESENT	0
191043	190756	04067M	PARTICIPANT	\N	PRESENT	0
191044	190756	11099A	PARTICIPANT	\N	PRESENT	0
191045	190756	05012A	PARTICIPANT	\N	PRESENT	0
191046	190756	14331P	PARTICIPANT	\N	PRESENT	0
191047	190756	11055M	PARTICIPANT	\N	PRESENT	0
191048	190756	89017R	PARTICIPANT	\N	PRESENT	0
191049	190756	11076S	PARTICIPANT	\N	PRESENT	0
191051	190756	08021P	PARTICIPANT	\N	PRESENT	0
191052	190756	01060R	PARTICIPANT	\N	PRESENT	0
191053	190756	14247U	PARTICIPANT	\N	PRESENT	0
191054	190756	14026U	PARTICIPANT	\N	PRESENT	0
191055	190756	04092N	PARTICIPANT	\N	PRESENT	0
191056	190756	95035G	PARTICIPANT	\N	PRESENT	0
191057	190756	11097X	PARTICIPANT	\N	PRESENT	0
191058	190756	95049N	PARTICIPANT	\N	PRESENT	0
191059	190756	04049K	PARTICIPANT	\N	PRESENT	0
191060	190756	01034P	PARTICIPANT	\N	PRESENT	0
191061	190756	11094U	PARTICIPANT	\N	PRESENT	0
191062	190756	11053K	PARTICIPANT	\N	PRESENT	0
191063	190756	04061F	PARTICIPANT	\N	PRESENT	0
191064	190756	08009T	PARTICIPANT	\N	PRESENT	0
191065	190756	14061L	PARTICIPANT	\N	PRESENT	0
191066	190756	14034U	PARTICIPANT	\N	PRESENT	0
191067	190756	98050T	PARTICIPANT	\N	PRESENT	0
191068	190756	11070L	PARTICIPANT	\N	PRESENT	0
191069	190756	97011G	PARTICIPANT	\N	PRESENT	0
191070	190756	11010L	PARTICIPANT	\N	PRESENT	0
189809	188952	14219Q	PARTICIPANT	\N	EXCUSE	0
191071	190756	14205J	PARTICIPANT	\N	PRESENT	0
191072	190756	08062Y	PARTICIPANT	\N	PRESENT	0
191073	190756	14042U	PARTICIPANT	\N	PRESENT	0
191074	190756	14135M	PARTICIPANT	\N	PRESENT	0
191075	190756	11071M	PARTICIPANT	\N	PRESENT	0
191076	190756	14219Q	PARTICIPANT	\N	PRESENT	0
191077	190756	14267Y	PARTICIPANT	\N	PRESENT	0
191078	190756	14195A	PARTICIPANT	\N	PRESENT	0
191079	190756	14103D	PARTICIPANT	\N	PRESENT	0
191080	190756	14221J	PARTICIPANT	\N	PRESENT	0
191081	190756	04074L	PARTICIPANT	\N	PRESENT	0
191082	190756	11082Q	PARTICIPANT	\N	PRESENT	0
191083	190756	14089Y	PARTICIPANT	\N	PRESENT	0
191084	190756	14173T	PARTICIPANT	\N	PRESENT	0
191085	190756	14073Q	PARTICIPANT	\N	PRESENT	0
191086	190756	04088S	PARTICIPANT	\N	PRESENT	0
191087	190756	14275Y	PARTICIPANT	\N	PRESENT	0
191088	190756	14277B	PARTICIPANT	\N	PRESENT	0
191089	190756	14231L	PARTICIPANT	\N	PRESENT	0
191090	190756	98042T	PARTICIPANT	\N	PRESENT	0
191091	190756	04089T	PARTICIPANT	\N	PRESENT	0
191092	190756	14179A	PARTICIPANT	\N	PRESENT	0
191093	190756	92045V	PARTICIPANT	\N	PRESENT	0
191094	190756	11085T	PARTICIPANT	\N	PRESENT	0
191095	190756	08044W	PARTICIPANT	\N	PRESENT	0
191096	190756	08069G	PARTICIPANT	\N	PRESENT	0
191097	190756	14255U	PARTICIPANT	\N	PRESENT	0
191098	190756	01047U	PARTICIPANT	\N	PRESENT	0
191099	190756	14265W	PARTICIPANT	\N	PRESENT	0
191100	190756	04070G	PARTICIPANT	\N	PRESENT	0
191101	190756	04040A	PARTICIPANT	\N	PRESENT	0
191102	190756	01024M	PARTICIPANT	\N	PRESENT	0
191103	190756	14033T	PARTICIPANT	\N	PRESENT	0
191104	190756	09001P	PARTICIPANT	\N	PRESENT	0
191105	190756	01025N	PARTICIPANT	\N	PRESENT	0
191106	190756	14030Q	PARTICIPANT	\N	PRESENT	0
191107	190756	14327T	PARTICIPANT	\N	PRESENT	0
191108	190756	14017T	PARTICIPANT	\N	PRESENT	0
191109	190756	11090Q	PARTICIPANT	\N	PRESENT	0
191110	190756	14041T	PARTICIPANT	\N	PRESENT	0
191111	190756	10006L	PARTICIPANT	\N	PRESENT	0
191112	190756	01056V	PARTICIPANT	\N	PRESENT	0
191113	190756	14157T	PARTICIPANT	\N	PRESENT	0
191114	190756	14259Y	PARTICIPANT	\N	PRESENT	0
191115	190756	77002U	PARTICIPANT	\N	PRESENT	0
191116	190756	14053L	PARTICIPANT	\N	PRESENT	0
191117	190756	14355X	PARTICIPANT	\N	PRESENT	0
191118	190756	08048B	PARTICIPANT	\N	PRESENT	0
191119	190756	08047A	PARTICIPANT	\N	PRESENT	0
191120	190756	14109K	PARTICIPANT	\N	PRESENT	0
191121	190756	07029T	PARTICIPANT	\N	PRESENT	0
191122	190756	08019V	PARTICIPANT	\N	PRESENT	0
191123	190756	14105F	PARTICIPANT	\N	PRESENT	0
191124	190756	14038Y	PARTICIPANT	\N	PRESENT	0
191125	190756	14363X	PARTICIPANT	\N	PRESENT	0
191126	190756	14329V	PARTICIPANT	\N	PRESENT	0
191127	190756	14357A	PARTICIPANT	\N	PRESENT	0
191128	190756	04043D	PARTICIPANT	\N	PRESENT	0
191129	190756	08042U	PARTICIPANT	\N	PRESENT	0
191130	190756	14253S	PARTICIPANT	\N	PRESENT	0
191131	190756	98021N	PARTICIPANT	\N	PRESENT	0
191132	190756	14215L	PARTICIPANT	\N	PRESENT	0
191133	190756	11091R	PARTICIPANT	\N	PRESENT	0
191134	190756	14249W	PARTICIPANT	\N	PRESENT	0
191135	190756	01041N	PARTICIPANT	\N	PRESENT	0
191136	190756	14187A	PARTICIPANT	\N	PRESENT	0
191137	190756	14087W	PARTICIPANT	\N	PRESENT	0
191138	190756	08065C	PARTICIPANT	\N	PRESENT	0
191139	190756	89029V	PARTICIPANT	\N	PRESENT	0
191140	190756	14199E	PARTICIPANT	\N	PRESENT	0
191141	190756	14213J	PARTICIPANT	\N	PRESENT	0
191142	190756	11048N	PARTICIPANT	\N	PRESENT	0
191143	190756	08015R	PARTICIPANT	\N	PRESENT	0
191144	190756	14119M	PARTICIPANT	\N	PRESENT	0
191145	190756	10015M	PARTICIPANT	\N	PRESENT	0
191146	190756	04066L	PARTICIPANT	\N	PRESENT	0
191147	190756	95037J	PARTICIPANT	\N	PRESENT	0
191148	190756	14111D	PARTICIPANT	\N	PRESENT	0
191149	190756	95015C	PARTICIPANT	\N	PRESENT	0
191150	190756	90003B	PARTICIPANT	\N	PRESENT	0
191152	190756	16813M	PARTICIPANT	\N	PRESENT	0
191172	190756	92040Q	PARTICIPANT	\N	PRESENT	0
170695	164994	08069G	PARTICIPANT	\N	EXCUSE	0
170696	164994	04043D	PARTICIPANT	\N	EXCUSE	0
173335	173329	14237S	PARTICIPANT	\N	PRESENT	0
173336	173329	08056B	PARTICIPANT	\N	PRESENT	0
173337	173329	04045F	PARTICIPANT	\N	PRESENT	0
173339	173329	95067Q	PARTICIPANT	\N	PRESENT	0
173340	173329	14255U	PARTICIPANT	\N	PRESENT	0
173342	173329	04044E	PARTICIPANT	\N	PRESENT	0
173343	173329	01008M	PARTICIPANT	\N	PRESENT	0
173344	173329	04036E	PARTICIPANT	\N	PRESENT	0
173345	173329	08053X	PARTICIPANT	\N	PRESENT	0
173351	173350	14237S	PARTICIPANT	\N	PRESENT	0
173352	173350	08056B	PARTICIPANT	\N	PRESENT	0
173353	173350	95067Q	PARTICIPANT	\N	PRESENT	0
173470	173464	14026U	PARTICIPANT	\N	PRESENT	0
173472	173464	95037J	PARTICIPANT	\N	PRESENT	0
173474	173464	11012A	PARTICIPANT	\N	PRESENT	0
173475	173464	90003B	PARTICIPANT	\N	PRESENT	0
173492	173464	14257W	PARTICIPANT	\N	PRESENT	0
173494	173464	14033T	PARTICIPANT	\N	PRESENT	0
173498	173464	14357A	PARTICIPANT	\N	PRESENT	0
177532	177531	92020L	PARTICIPANT	\N	PRESENT	0
177533	177531	04080J	PARTICIPANT	\N	PRESENT	0
177534	177531	04042C	PARTICIPANT	\N	PRESENT	0
177773	177772	04080J	PARTICIPANT	\N	PRESENT	0
184833	184832	01031L	PARTICIPANT	\N	PRESENT	0
184834	184832	08011M	PARTICIPANT	\N	PRESENT	0
184853	184852	08010L	PARTICIPANT	\N	PRESENT	0
184855	184854	11048N	PARTICIPANT	\N	PRESENT	0
185493	185492	08043V	PARTICIPANT	\N	PRESENT	0
185494	185492	14038Y	PARTICIPANT	\N	EXCUSE	0
185495	185492	14217N	PARTICIPANT	\N	PRESENT	0
185496	185492	02002K	PARTICIPANT	\N	EXCUSE	0
185497	185492	09001P	PRESIDENT	0	PRESENT	0
185498	185492	07029T	PARTICIPANT	\N	EXCUSE	0
185499	185492	14031R	PARTICIPANT	\N	EXCUSE	0
185500	185492	11014C	PARTICIPANT	\N	EXCUSE	0
185501	185492	14109K	PARTICIPANT	\N	PRESENT	0
185502	185492	14237S	PARTICIPANT	\N	PRESENT	0
187836	187835	98035U	PARTICIPANT	\N	PRESENT	0
187840	187839	04036E	PARTICIPANT	\N	PRESENT	0
187842	187841	14097Y	PARTICIPANT	\N	PRESENT	0
187843	187841	04036E	PARTICIPANT	\N	PRESENT	0
187844	187841	04088S	PARTICIPANT	\N	PRESENT	0
187845	187841	14041T	PARTICIPANT	\N	PRESENT	0
187847	187846	95015C	PARTICIPANT	\N	PRESENT	0
187848	187846	14179A	PARTICIPANT	\N	PRESENT	0
187849	187846	04038G	PARTICIPANT	\N	PRESENT	0
187850	187846	11067R	PARTICIPANT	\N	PRESENT	0
188293	188292	14327T	PARTICIPANT	\N	PRESENT	0
188294	188292	11037K	PARTICIPANT	\N	PRESENT	0
188313	188312	08011M	PARTICIPANT	\N	PRESENT	0
188314	188312	01031L	PARTICIPANT	\N	PRESENT	0
188316	188315	08011M	PARTICIPANT	\N	PRESENT	0
192022	192019	04053F	PARTICIPANT	\N	PRESENT	0
189194	189192	11055M	PARTICIPANT	\N	PRESENT	0
192052	192019	14053L	PARTICIPANT	\N	PRESENT	0
189196	189192	04053F	PARTICIPANT	\N	PRESENT	0
189197	189192	14255U	PARTICIPANT	\N	EXCUSE	0
189198	189192	04066L	PARTICIPANT	\N	PRESENT	0
189199	189192	00003C	PARTICIPANT	\N	EXCUSE	0
192054	192019	00003C	PARTICIPANT	\N	EXCUSE	0
189201	189192	11103C	PARTICIPANT	\N	PRESENT	0
192057	192019	14195A	PARTICIPANT	\N	PRESENT	0
189203	189192	14195A	PARTICIPANT	\N	PRESENT	0
192058	192019	14267Y	PARTICIPANT	\N	PRESENT	0
189205	189192	11023D	PARTICIPANT	\N	EXCUSE	0
192060	192019	08052W	PARTICIPANT	\N	PRESENT	0
189207	189192	08052W	PARTICIPANT	\N	PRESENT	0
189208	189192	01059Y	PARTICIPANT	\N	EXCUSE	0
189209	189192	04081K	PARTICIPANT	\N	PRESENT	0
189210	189192	98024R	PARTICIPANT	\N	PRESENT	0
189211	189192	10006L	PARTICIPANT	\N	PRESENT	0
192061	192019	10006L	PARTICIPANT	\N	PRESENT	0
189213	189192	14217N	PARTICIPANT	\N	PRESENT	0
189214	189192	14042U	PARTICIPANT	\N	PRESENT	0
189215	189192	14151M	PARTICIPANT	\N	PRESENT	0
192062	192019	14217N	PARTICIPANT	\N	PRESENT	0
192063	192019	14042U	PARTICIPANT	\N	PRESENT	0
192064	192019	14151M	PARTICIPANT	\N	PRESENT	0
189219	189192	14034U	PARTICIPANT	\N	PRESENT	0
189220	189192	14231L	PARTICIPANT	\N	EXCUSE	0
189221	189192	11061K	PARTICIPANT	\N	PRESENT	0
189222	189192	14355X	PARTICIPANT	\N	EXCUSE	0
192065	192019	12042Y	PARTICIPANT	\N	PRESENT	0
189224	189192	08041T	PARTICIPANT	\N	PRESENT	0
192066	192019	14281W	PARTICIPANT	\N	PRESENT	0
189226	189192	14026U	PARTICIPANT	\N	PRESENT	0
189227	189192	14213J	PARTICIPANT	\N	EXCUSE	0
192067	192019	14087W	PARTICIPANT	\N	PRESENT	0
189229	189192	11112D	PARTICIPANT	\N	PRESENT	0
189230	189192	14037X	PARTICIPANT	\N	PRESENT	0
192068	192019	14034U	PARTICIPANT	\N	PRESENT	0
189232	189192	11067R	PARTICIPANT	\N	PRESENT	0
189233	189192	14223L	PARTICIPANT	\N	EXCUSE	0
189234	189192	04092N	PRESIDENT	0	PRESENT	0
189235	189192	14265W	PARTICIPANT	\N	PRESENT	0
189236	189192	14119M	PARTICIPANT	\N	PRESENT	0
189237	189192	14071N	PARTICIPANT	\N	PRESENT	0
192069	192019	11061K	PARTICIPANT	\N	PRESENT	0
189239	189192	14271U	PARTICIPANT	\N	PRESENT	0
192070	192019	14231L	PARTICIPANT	\N	EXCUSE	0
189241	189192	11093T	PARTICIPANT	\N	PRESENT	0
192071	192019	08048B	PARTICIPANT	\N	PRESENT	0
192072	192019	08041T	PARTICIPANT	\N	PRESENT	0
192074	192019	14026U	PARTICIPANT	\N	PRESENT	0
189245	189192	01034P	PARTICIPANT	\N	PRESENT	0
192075	192019	14213J	PARTICIPANT	\N	PRESENT	0
189247	189192	11063M	PARTICIPANT	\N	EXCUSE	0
189248	189192	14269B	PARTICIPANT	\N	PRESENT	0
192076	192019	14223L	PARTICIPANT	\N	PRESENT	0
192077	192019	04092N	PRESIDENT	0	PRESENT	0
192078	192019	14265W	PARTICIPANT	\N	PRESENT	0
192079	192019	14119M	PARTICIPANT	\N	PRESENT	0
192080	192019	14071N	PARTICIPANT	\N	PRESENT	0
192082	192019	14271U	PARTICIPANT	\N	PRESENT	0
192083	192019	14017T	PARTICIPANT	\N	EXCUSE	0
192084	192019	11097X	PARTICIPANT	\N	PRESENT	0
192085	192019	04045F	PARTICIPANT	\N	PRESENT	0
192086	192019	01034P	PARTICIPANT	\N	PRESENT	0
192087	192019	14269B	PARTICIPANT	\N	PRESENT	0
192090	192019	11067R	PARTICIPANT	\N	EXCUSE	0
200212	190791	04045F	PARTICIPANT	\N	PRESENT	0
193272	193252	95049N	PARTICIPANT	\N	PRESENT	0
199432	199392	14225N	PARTICIPANT	\N	PRESENT	0
200213	190791	11057P	PARTICIPANT	\N	PRESENT	0
200214	190791	14247U	PARTICIPANT	\N	PRESENT	0
200215	190791	08009T	PARTICIPANT	\N	PRESENT	0
204916	204912	95063L	PARTICIPANT	\N	PRESENT	0
205534	205526	14255U	PARTICIPANT	\N	PRESENT	0
205535	205526	14079W	PARTICIPANT	\N	PRESENT	0
205536	205526	14041T	PARTICIPANT	\N	PRESENT	0
205537	205526	04071H	PARTICIPANT	\N	EXCUSE	0
205538	205526	14087W	PARTICIPANT	\N	PRESENT	0
205539	205526	02002K	PARTICIPANT	\N	EXCUSE	0
205540	205526	14034U	PARTICIPANT	\N	EXCUSE	0
205541	205526	14121F	PARTICIPANT	\N	EXCUSE	0
205542	205526	95041E	PARTICIPANT	\N	EXCUSE	0
205543	205526	14039A	PARTICIPANT	\N	PRESENT	0
205544	205526	14061L	PARTICIPANT	\N	PRESENT	0
205545	205526	04049K	PRESIDENT	0	PRESENT	0
205546	205526	14205J	PARTICIPANT	\N	PRESENT	0
205928	205693	04057K	PARTICIPANT	\N	PRESENT	0
205548	205526	14265W	PARTICIPANT	\N	PRESENT	0
205549	205526	14253S	PARTICIPANT	\N	EXCUSE	0
205550	205526	11090Q	PARTICIPANT	\N	PRESENT	0
205551	205526	14157T	PARTICIPANT	\N	PRESENT	0
205552	205526	14151M	PARTICIPANT	\N	EXCUSE	0
206805	206803	04040A	PARTICIPANT	\N	PRESENT	0
205929	205693	19735D	PARTICIPANT	\N	PRESENT	0
206526	206517	11026G	PARTICIPANT	\N	PRESENT	0
205392	205212	08069G	PARTICIPANT	\N	EXCUSE	0
210134	210133	08014Q	PARTICIPANT	\N	PRESENT	0
210135	210133	08069G	PARTICIPANT	\N	PRESENT	0
210137	210136	08069G	PARTICIPANT	\N	PRESENT	0
210138	210136	08014Q	PARTICIPANT	\N	PRESENT	0
210140	210139	07004J	PARTICIPANT	\N	PRESENT	0
210142	210141	08011M	PARTICIPANT	\N	PRESENT	0
210144	210143	19349W	PARTICIPANT	\N	PRESENT	0
210158	210157	14255U	PARTICIPANT	\N	PRESENT	0
210159	210157	08053X	PARTICIPANT	\N	PRESENT	0
210616	210613	95063L	PARTICIPANT	\N	PRESENT	0
210617	210613	14169X	PARTICIPANT	\N	PRESENT	0
210618	210613	14237S	PARTICIPANT	\N	PRESENT	0
210619	210613	04040A	PARTICIPANT	\N	PRESENT	0
210895	210894	07034Q	PARTICIPANT	\N	PRESENT	0
210896	210894	14071N	PARTICIPANT	\N	PRESENT	0
210901	210900	19415P	PARTICIPANT	\N	PRESENT	0
209687	208428	11070L	PARTICIPANT	\N	PRESENT	0
209688	208428	88008L	PARTICIPANT	\N	PRESENT	0
209689	208428	11110B	PARTICIPANT	\N	PRESENT	0
209690	208428	07029T	PARTICIPANT	\N	PRESENT	0
209691	208428	14085U	PARTICIPANT	\N	PRESENT	0
209692	208428	07004J	PARTICIPANT	\N	PRESENT	0
209693	208428	08010L	PARTICIPANT	\N	PRESENT	0
209694	208428	14253S	PARTICIPANT	\N	PRESENT	0
209695	208428	19479G	PARTICIPANT	\N	PRESENT	0
209696	208428	19647E	PARTICIPANT	\N	PRESENT	0
209697	208428	19711U	PARTICIPANT	\N	PRESENT	0
209698	208428	19651A	PARTICIPANT	\N	PRESENT	0
209699	208428	08034U	PARTICIPANT	\N	PRESENT	0
209700	208428	19531S	PARTICIPANT	\N	PRESENT	0
209701	208428	08069G	PARTICIPANT	\N	PRESENT	0
209702	208428	19687N	PARTICIPANT	\N	PRESENT	0
209703	208428	11026G	RAPPORTEUR_AVIS	\N	PRESENT	0
209704	208428	19689Q	PARTICIPANT	\N	PRESENT	0
209705	208428	12016W	PARTICIPANT	\N	PRESENT	0
209706	208428	08011M	PARTICIPANT	\N	PRESENT	0
209707	208428	04086Q	PARTICIPANT	\N	PRESENT	0
209708	208428	11040E	PARTICIPANT	\N	PRESENT	0
209709	208428	11012A	PARTICIPANT	\N	PRESENT	0
209710	208428	14199E	PARTICIPANT	\N	PRESENT	0
209711	208428	08073C	PARTICIPANT	\N	PRESENT	0
209712	208428	14121F	PARTICIPANT	\N	PRESENT	0
209713	208428	99004R	PARTICIPANT	\N	PRESENT	0
209714	208428	04061F	PARTICIPANT	\N	PRESENT	0
209715	208428	14083S	PARTICIPANT	\N	PRESENT	0
209716	208428	11048N	PARTICIPANT	\N	PRESENT	0
209717	208428	95041E	PARTICIPANT	\N	PRESENT	0
209718	208428	19349W	PARTICIPANT	\N	PRESENT	0
209719	208428	19667J	PARTICIPANT	\N	PRESENT	0
209720	208428	14034U	PARTICIPANT	\N	PRESENT	0
209721	208428	08014Q	PARTICIPANT	\N	PRESENT	0
209722	208428	14159V	PARTICIPANT	\N	PRESENT	0
209723	208428	14173T	PARTICIPANT	\N	PRESENT	0
210089	210088	98024R	PARTICIPANT	\N	PRESENT	0
210903	210902	19415P	PARTICIPANT	\N	PRESENT	0
210905	210904	19415P	PARTICIPANT	\N	PRESENT	0
210909	210908	19415P	PARTICIPANT	\N	PRESENT	0
210969	210968	19415P	PARTICIPANT	\N	PRESENT	0
210971	210970	19415P	PARTICIPANT	\N	PRESENT	0
210973	210972	19415P	PARTICIPANT	\N	PRESENT	0
210975	210974	19415P	PARTICIPANT	\N	PRESENT	0
210977	210976	19415P	PARTICIPANT	\N	PRESENT	0
210979	210978	19415P	PARTICIPANT	\N	PRESENT	0
210981	210980	19415P	PARTICIPANT	\N	PRESENT	0
211083	210132	14355X	PARTICIPANT	\N	EXCUSE	0
211084	210132	14281W	PARTICIPANT	\N	EXCUSE	0
211085	210132	19715Y	PARTICIPANT	\N	PRESENT	0
211086	210132	08041T	PARTICIPANT	\N	EXCUSE	0
211144	210132	14223L	PARTICIPANT	\N	PRESENT	0
211145	210132	11031D	PARTICIPANT	\N	PRESENT	0
211146	210132	14217N	PARTICIPANT	\N	PRESENT	0
211147	210132	14227Q	PARTICIPANT	\N	PRESENT	0
211148	210132	19527W	PARTICIPANT	\N	PRESENT	0
211149	210132	19521Q	PARTICIPANT	\N	PRESENT	0
211150	210132	11067R	PARTICIPANT	\N	PRESENT	0
211151	210132	19335Q	PARTICIPANT	\N	PRESENT	0
211181	210116	14001X	PARTICIPANT	\N	PRESENT	0
211182	210116	01060R	PARTICIPANT	\N	PRESENT	0
211183	210116	19543W	PARTICIPANT	\N	PRESENT	0
211184	210116	19581D	PARTICIPANT	\N	PRESENT	0
211185	210116	04044E	PARTICIPANT	\N	PRESENT	0
211186	210116	19585H	PARTICIPANT	\N	PRESENT	0
211187	210116	04047H	PARTICIPANT	\N	PRESENT	0
211188	210116	01028R	PARTICIPANT	\N	PRESENT	0
211189	210116	14231L	PARTICIPANT	\N	PRESENT	0
211190	210116	05008E	PRESIDENT	0	PRESENT	0
211191	210116	19447X	PARTICIPANT	\N	PRESENT	0
211192	210116	19489J	PARTICIPANT	\N	PRESENT	0
211193	210116	14275Y	PARTICIPANT	\N	PRESENT	0
211194	210116	14041T	PARTICIPANT	\N	PRESENT	0
211195	210116	14179A	PARTICIPANT	\N	PRESENT	0
211196	210116	14147R	PARTICIPANT	\N	PRESENT	0
211197	210116	14151M	PARTICIPANT	\N	PRESENT	0
211198	210116	14215L	PARTICIPANT	\N	PRESENT	0
211199	210116	19483C	PARTICIPANT	\N	PRESENT	0
211200	210116	08018U	PARTICIPANT	\N	PRESENT	0
211201	210116	14259Y	PARTICIPANT	\N	PRESENT	0
211202	210116	11072N	PARTICIPANT	\N	PRESENT	0
211203	210116	14053L	PARTICIPANT	\N	PRESENT	0
211204	210116	98035U	PARTICIPANT	\N	PRESENT	0
211205	210116	14111D	PARTICIPANT	\N	PRESENT	0
211206	210116	14065Q	PARTICIPANT	\N	PRESENT	0
211207	210116	08045X	PARTICIPANT	\N	PRESENT	0
211208	210116	11026G	PARTICIPANT	\N	PRESENT	0
211209	210116	07034Q	PARTICIPANT	\N	PRESENT	0
211210	210116	19253P	PARTICIPANT	\N	PRESENT	0
211211	210116	01024M	PARTICIPANT	\N	PRESENT	0
211212	210116	04038G	PARTICIPANT	\N	PRESENT	0
211213	210116	19719D	PARTICIPANT	\N	PRESENT	0
211214	210116	11033F	PARTICIPANT	\N	PRESENT	0
211215	210116	14089Y	PARTICIPANT	\N	PRESENT	0
211216	210116	19725B	PARTICIPANT	\N	PRESENT	0
211217	210116	19729F	PARTICIPANT	\N	PRESENT	0
211218	210116	19629C	PARTICIPANT	\N	PRESENT	0
211219	210116	08044W	PARTICIPANT	\N	PRESENT	0
211220	210116	14069U	PARTICIPANT	\N	PRESENT	0
211221	210116	11085T	PARTICIPANT	\N	PRESENT	0
211222	210116	11049P	PARTICIPANT	\N	PRESENT	0
211223	210116	04008A	PARTICIPANT	\N	PRESENT	0
211224	210116	14021P	PARTICIPANT	\N	PRESENT	0
211225	210116	19673G	PARTICIPANT	\N	EXCUSE	0
211228	210185	14195A	PARTICIPANT	\N	PRESENT	0
211229	210185	14042U	PARTICIPANT	\N	PRESENT	0
211231	210099	08061X	PARTICIPANT	\N	PRESENT	0
211232	210161	19383Y	PARTICIPANT	\N	PRESENT	0
211233	210161	19515S	PARTICIPANT	\N	PRESENT	0
211234	210161	01043Q	PARTICIPANT	\N	PRESENT	0
211235	210161	19565D	PARTICIPANT	\N	PRESENT	0
211236	210161	14357A	PARTICIPANT	\N	PRESENT	0
211237	210161	19441R	PARTICIPANT	\N	PRESENT	0
211238	210161	19413M	PARTICIPANT	\N	PRESENT	0
211239	210161	80013X	PARTICIPANT	\N	PRESENT	0
211240	210161	19631V	PARTICIPANT	\N	PRESENT	0
211241	210161	08021P	PARTICIPANT	\N	PRESENT	0
211242	210161	11099A	PARTICIPANT	\N	PRESENT	0
211243	210161	08068F	PARTICIPANT	\N	PRESENT	0
211244	210161	04049K	PARTICIPANT	\N	PRESENT	0
211245	210161	19705W	PARTICIPANT	\N	PRESENT	0
211246	210161	19707Y	PARTICIPANT	\N	PRESENT	0
211247	210161	08015R	PARTICIPANT	\N	PRESENT	0
211248	210161	08019V	PARTICIPANT	\N	PRESENT	0
211249	210161	14197C	PARTICIPANT	\N	PRESENT	0
211250	210161	19369B	PARTICIPANT	\N	PRESENT	0
211251	210161	19511N	PARTICIPANT	\N	PRESENT	0
211252	210161	08028W	PARTICIPANT	\N	PRESENT	0
211253	210161	14265W	PARTICIPANT	\N	PRESENT	0
211254	210161	14329V	PARTICIPANT	\N	PRESENT	0
211255	210161	19591F	PARTICIPANT	\N	PRESENT	0
211256	210161	14135M	PARTICIPANT	\N	PRESENT	0
211257	210161	19467C	PARTICIPANT	\N	PRESENT	0
211258	210161	14187A	PARTICIPANT	\N	PRESENT	0
211259	210161	08038Y	PARTICIPANT	\N	PRESENT	0
211260	210161	19695N	PARTICIPANT	\N	PRESENT	0
211261	210161	19301E	PARTICIPANT	\N	PRESENT	0
211262	210161	08062Y	PARTICIPANT	\N	PRESENT	0
211263	210161	14033T	PARTICIPANT	\N	PRESENT	0
211264	210161	11090Q	PRESIDENT	0	PRESENT	0
211265	210161	01025N	PARTICIPANT	\N	PRESENT	0
211266	210161	19269X	PARTICIPANT	\N	PRESENT	0
211267	210161	14205J	PARTICIPANT	\N	PRESENT	0
211268	210161	04088S	PARTICIPANT	\N	PRESENT	0
211269	210161	11056N	PARTICIPANT	\N	PRESENT	0
211270	210161	04089T	PARTICIPANT	\N	PRESENT	0
211271	210161	14115H	PARTICIPANT	\N	PRESENT	0
211272	210161	11101A	PARTICIPANT	\N	PRESENT	0
211273	210161	19507S	PARTICIPANT	\N	PRESENT	0
211274	210161	14207L	PARTICIPANT	\N	PRESENT	0
170073	170072	05008E	PARTICIPANT	\N	PRESENT	0
175933	175930	14263U	PARTICIPANT	\N	PRESENT	0
175934	175930	11109J	PARTICIPANT	\N	PRESENT	0
175889	175872	11091R	PARTICIPANT	\N	EXCUSE	0
175890	175872	87003B	PARTICIPANT	\N	PRESENT	0
175891	175872	98042T	PARTICIPANT	\N	PRESENT	0
175892	175872	14249W	PARTICIPANT	\N	PRESENT	0
175893	175872	01041N	PARTICIPANT	\N	PRESENT	0
175894	175872	01025N	PARTICIPANT	\N	PRESENT	0
175935	175930	04059M	PARTICIPANT	\N	PRESENT	0
175896	175872	08035V	PARTICIPANT	\N	PRESENT	0
175897	175872	11089X	PARTICIPANT	\N	PRESENT	0
175898	175872	07026Q	PARTICIPANT	\N	PRESENT	0
175936	175930	11039M	PARTICIPANT	\N	PRESENT	0
175900	175872	14179A	PARTICIPANT	\N	PRESENT	0
175937	175930	01044R	PARTICIPANT	\N	PRESENT	0
175902	175872	14241N	PARTICIPANT	\N	PRESENT	0
175903	175872	14061L	PARTICIPANT	\N	PRESENT	0
175904	175872	14073Q	PARTICIPANT	\N	PRESENT	0
175905	175872	08031R	PARTICIPANT	\N	PRESENT	0
175906	175872	12041X	PARTICIPANT	\N	PRESENT	0
175907	175872	08039A	PARTICIPANT	\N	PRESENT	0
175908	175872	08017T	PARTICIPANT	\N	PRESENT	0
175909	175872	14059S	PARTICIPANT	\N	PRESENT	0
175910	175872	08012N	PARTICIPANT	\N	PRESENT	0
175911	175872	14103D	PARTICIPANT	\N	PRESENT	0
175912	175872	11104D	PARTICIPANT	\N	PRESENT	0
175913	175872	14063N	PARTICIPANT	\N	PRESENT	0
175914	175872	04057K	PARTICIPANT	\N	PRESENT	0
175915	175872	11014C	PARTICIPANT	\N	PRESENT	0
175916	175872	14109K	PARTICIPANT	\N	PRESENT	0
175917	175872	04070G	PRESIDENT	0	PRESENT	0
175938	175930	08043V	PARTICIPANT	\N	PRESENT	0
175919	175872	14191V	PARTICIPANT	\N	PRESENT	0
175920	175872	83047W	PARTICIPANT	\N	PRESENT	0
175921	175872	14235Q	PARTICIPANT	\N	PRESENT	0
175922	175872	14055N	PARTICIPANT	\N	PRESENT	0
175923	175872	04033B	PARTICIPANT	\N	PRESENT	0
175924	175872	14361V	PARTICIPANT	\N	PRESENT	0
175925	175872	14229S	PARTICIPANT	\N	PRESENT	0
175926	175872	14363X	PARTICIPANT	\N	PRESENT	0
175927	175872	11043H	PARTICIPANT	\N	PRESENT	0
176053	176052	01008M	PARTICIPANT	\N	PRESENT	0
176014	176012	08055A	PARTICIPANT	\N	PRESENT	0
175940	175930	14105F	PARTICIPANT	\N	PRESENT	0
175941	175930	11029K	PARTICIPANT	\N	PRESENT	0
175942	175930	95015C	PARTICIPANT	\N	PRESENT	0
175943	175930	92015P	PARTICIPANT	\N	PRESENT	0
175944	175930	08024S	PARTICIPANT	\N	PRESENT	0
175945	175930	14201E	PARTICIPANT	\N	PRESENT	0
176015	176012	14093U	PARTICIPANT	\N	PRESENT	0
176054	176052	11036J	PARTICIPANT	\N	PRESENT	0
176055	176052	11081P	PARTICIPANT	\N	PRESENT	0
175949	175930	11091R	PARTICIPANT	\N	EXCUSE	0
175950	175930	87003B	PARTICIPANT	\N	PRESENT	0
175951	175930	98042T	PARTICIPANT	\N	PRESENT	0
175952	175930	14249W	PARTICIPANT	\N	PRESENT	0
175953	175930	01041N	PARTICIPANT	\N	PRESENT	0
175954	175930	01025N	PARTICIPANT	\N	PRESENT	0
176056	176052	14013P	PARTICIPANT	\N	PRESENT	0
175956	175930	08035V	PARTICIPANT	\N	PRESENT	0
175957	175930	11089X	PARTICIPANT	\N	PRESENT	0
175958	175930	07026Q	PARTICIPANT	\N	PRESENT	0
175959	175930	14123H	PARTICIPANT	\N	PRESENT	0
175960	175930	14179A	PARTICIPANT	\N	PRESENT	0
176019	176012	11095V	PARTICIPANT	\N	EXCUSE	0
175962	175930	14241N	PARTICIPANT	\N	PRESENT	0
175963	175930	14061L	PARTICIPANT	\N	PRESENT	0
175964	175930	14073Q	PARTICIPANT	\N	PRESENT	0
175965	175930	08031R	PARTICIPANT	\N	PRESENT	0
175966	175930	12041X	PARTICIPANT	\N	PRESENT	0
175967	175930	08039A	PARTICIPANT	\N	PRESENT	0
175968	175930	08017T	PARTICIPANT	\N	PRESENT	0
175969	175930	14059S	PARTICIPANT	\N	PRESENT	0
175970	175930	08012N	PARTICIPANT	\N	PRESENT	0
175971	175930	14103D	PARTICIPANT	\N	PRESENT	0
175972	175930	11104D	PARTICIPANT	\N	PRESENT	0
175973	175930	14063N	PARTICIPANT	\N	PRESENT	0
175974	175930	04057K	PARTICIPANT	\N	PRESENT	0
175975	175930	11014C	PARTICIPANT	\N	PRESENT	0
175976	175930	14109K	PARTICIPANT	\N	PRESENT	0
175977	175930	04070G	PRESIDENT	0	PRESENT	0
176020	176012	14038Y	PARTICIPANT	\N	PRESENT	0
175979	175930	14191V	PARTICIPANT	\N	PRESENT	0
175980	175930	83047W	PARTICIPANT	\N	PRESENT	0
175981	175930	14235Q	PARTICIPANT	\N	PRESENT	0
175982	175930	14055N	PARTICIPANT	\N	PRESENT	0
175983	175930	04033B	PARTICIPANT	\N	PRESENT	0
175984	175930	14361V	PARTICIPANT	\N	PRESENT	0
175985	175930	14229S	PARTICIPANT	\N	PRESENT	0
175986	175930	14363X	PARTICIPANT	\N	PRESENT	0
175987	175930	11043H	PARTICIPANT	\N	PRESENT	0
176021	176012	11114F	PARTICIPANT	\N	PRESENT	0
176092	176052	95015C	PARTICIPANT	\N	PRESENT	0
176022	176012	98023Q	PARTICIPANT	\N	PRESENT	0
176023	176012	11065P	PARTICIPANT	\N	PRESENT	0
176024	176012	01015L	PARTICIPANT	\N	PRESENT	0
176025	176012	11107G	PARTICIPANT	\N	PRESENT	0
176058	176052	14207L	PARTICIPANT	\N	PRESENT	0
176027	176012	02002K	PARTICIPANT	\N	PRESENT	0
176028	176012	01022K	PARTICIPANT	\N	PRESENT	0
176029	176012	05001W	PARTICIPANT	\N	PRESENT	0
176059	176052	11101A	PARTICIPANT	\N	PRESENT	0
176031	176012	09001P	PARTICIPANT	\N	PRESENT	0
176032	176012	11059R	PARTICIPANT	\N	PRESENT	0
176033	176012	14219Q	PARTICIPANT	\N	PRESENT	0
176034	176012	80027E	PARTICIPANT	\N	PRESENT	0
176035	176012	14031R	PARTICIPANT	\N	PRESENT	0
176036	176012	08009T	PARTICIPANT	\N	EXCUSE	0
176037	176012	08062Y	PARTICIPANT	\N	PRESENT	0
176038	176012	14221J	PARTICIPANT	\N	PRESENT	0
176039	176012	92039X	PARTICIPANT	\N	PRESENT	0
176040	176012	08042U	PARTICIPANT	\N	PRESENT	0
176041	176012	14169X	PARTICIPANT	\N	PRESENT	0
176042	176012	14237S	PARTICIPANT	\N	PRESENT	0
176043	176012	13002U	PARTICIPANT	\N	PRESENT	0
176044	176012	05012A	PRESIDENT	0	PRESENT	0
176045	176012	14247U	PARTICIPANT	\N	PRESENT	0
176046	176012	14135M	PARTICIPANT	\N	PRESENT	0
176047	176012	14331P	PARTICIPANT	\N	PRESENT	0
176048	176012	95062K	PARTICIPANT	\N	PRESENT	0
176049	176012	14107H	PARTICIPANT	\N	PRESENT	0
176050	176012	14051J	PARTICIPANT	\N	PRESENT	0
176051	176012	14157T	PARTICIPANT	\N	PRESENT	0
176060	176052	90003B	PARTICIPANT	\N	PRESENT	0
176061	176052	08028W	PARTICIPANT	\N	PRESENT	0
176062	176052	80013X	PARTICIPANT	\N	PRESENT	0
176063	176052	14357A	PARTICIPANT	\N	PRESENT	0
176064	176052	08038Y	PARTICIPANT	\N	PRESENT	0
176065	176052	04089T	PARTICIPANT	\N	PRESENT	0
176066	176052	14197C	PARTICIPANT	\N	PRESENT	0
176067	176052	11110B	PARTICIPANT	\N	PRESENT	0
176068	176052	14187A	PARTICIPANT	\N	PRESENT	0
176069	176052	14033T	PARTICIPANT	\N	PRESENT	0
176070	176052	14081Q	PARTICIPANT	\N	PRESENT	0
176094	176052	14059S	PARTICIPANT	\N	PRESENT	0
176072	176052	04049K	PARTICIPANT	\N	PRESENT	0
176104	176052	14265W	PARTICIPANT	\N	PRESENT	0
176074	176052	11111C	PARTICIPANT	\N	PRESENT	0
176075	176052	08015R	PARTICIPANT	\N	PRESENT	0
176076	176052	11100Y	PRESIDENT	0	PRESENT	0
176105	176052	01043Q	PARTICIPANT	\N	EXCUSE	0
176133	176132	08031R	PARTICIPANT	\N	PRESENT	0
176134	176132	14209N	PARTICIPANT	\N	PRESENT	0
176135	176132	11029K	PARTICIPANT	\N	PRESENT	0
176081	176052	14205J	PARTICIPANT	\N	PRESENT	0
176082	176052	08019V	PARTICIPANT	\N	PRESENT	0
176083	176052	14257W	PARTICIPANT	\N	PRESENT	0
176136	176132	08043V	PARTICIPANT	\N	PRESENT	0
176085	176052	04088S	PARTICIPANT	\N	PRESENT	0
176086	176052	98050T	PARTICIPANT	\N	PRESENT	0
176087	176052	11090Q	PARTICIPANT	\N	PRESENT	0
176088	176052	11046L	PARTICIPANT	\N	PRESENT	0
176089	176052	01058X	PARTICIPANT	\N	PRESENT	0
176192	174533	08044W	PARTICIPANT	\N	EXCUSE	0
176091	176052	11066Q	PARTICIPANT	\N	PRESENT	0
176213	176212	11040E	PARTICIPANT	\N	PRESENT	0
176215	176212	14085U	PARTICIPANT	\N	PRESENT	0
176216	176212	14159V	PARTICIPANT	\N	PRESENT	0
176219	176217	08011M	PARTICIPANT	\N	PRESENT	0
176221	176220	08011M	PARTICIPANT	\N	PRESENT	0
176222	176220	11042G	PARTICIPANT	\N	PRESENT	0
176223	176220	04086Q	PARTICIPANT	\N	PRESENT	0
176224	176220	11083R	PARTICIPANT	\N	PRESENT	0
176313	176312	14219Q	PRESIDENT	0	PRESENT	0
176314	176312	11065P	PARTICIPANT	\N	PRESENT	0
176315	176312	11090Q	PARTICIPANT	\N	PRESENT	0
191461	190757	11085T	PARTICIPANT	\N	PRESENT	0
191462	190757	14107H	PARTICIPANT	\N	PRESENT	0
191463	190757	19251M	PARTICIPANT	\N	PRESENT	0
191464	190757	14281W	PARTICIPANT	\N	PRESENT	0
191465	190757	08058D	PARTICIPANT	\N	PRESENT	0
191466	190757	80013X	PARTICIPANT	\N	PRESENT	0
191467	190757	11067R	PARTICIPANT	\N	PRESENT	0
191468	190757	00003C	PARTICIPANT	\N	PRESENT	0
191469	190757	08053X	PARTICIPANT	\N	PRESENT	0
191470	190757	14207L	PARTICIPANT	\N	PRESENT	0
191471	190757	14097Y	PARTICIPANT	\N	PRESENT	0
191472	190757	14197C	PARTICIPANT	\N	PRESENT	0
191473	190757	01022K	PARTICIPANT	\N	PRESENT	0
191474	190757	08012N	PARTICIPANT	\N	PRESENT	0
191475	190757	95063L	PARTICIPANT	\N	PRESENT	0
191476	190757	14271U	PARTICIPANT	\N	PRESENT	0
191477	190757	12042Y	PARTICIPANT	\N	PRESENT	0
191478	190757	14081Q	PARTICIPANT	\N	PRESENT	0
191479	190757	14001X	PARTICIPANT	\N	PRESENT	0
191480	190757	11026G	PARTICIPANT	\N	PRESENT	0
191481	190757	04045F	PARTICIPANT	\N	PRESENT	0
191482	190757	11113E	PARTICIPANT	\N	PRESENT	0
191483	190757	98022P	PARTICIPANT	\N	PRESENT	0
191484	190757	07026Q	PARTICIPANT	\N	PRESENT	0
191485	190757	95049N	PARTICIPANT	\N	PRESENT	0
191486	190757	05008E	PARTICIPANT	\N	PRESENT	0
191487	190757	14103D	PARTICIPANT	\N	PRESENT	0
191488	190532	14327T	PARTICIPANT	\N	PRESENT	0
191489	190532	01031L	PARTICIPANT	\N	PRESENT	0
191490	190532	01057W	PARTICIPANT	\N	PRESENT	0
191491	190532	08011M	PARTICIPANT	\N	PRESENT	0
191492	190532	14159V	PARTICIPANT	\N	PRESENT	0
191493	190532	88008L	PARTICIPANT	\N	PRESENT	0
191494	190532	14173T	PARTICIPANT	\N	PRESENT	0
191495	190532	04086Q	PARTICIPANT	\N	PRESENT	0
191496	190532	14083S	PARTICIPANT	\N	PRESENT	0
191497	190532	11057P	PARTICIPANT	\N	PRESENT	0
191498	190532	14199E	PARTICIPANT	\N	PRESENT	0
191499	190532	98046X	PARTICIPANT	\N	PRESENT	0
191500	190532	08010L	PARTICIPANT	\N	PRESENT	0
191501	190532	99004R	PARTICIPANT	\N	PRESENT	0
191502	190532	14253S	PARTICIPANT	\N	PRESENT	0
191503	190532	08069G	PARTICIPANT	\N	PRESENT	0
191504	190532	11085T	PARTICIPANT	\N	EXCUSE	0
191505	190757	04038G	PARTICIPANT	\N	PRESENT	0
191506	190757	11012A	PARTICIPANT	\N	PRESENT	0
191507	190757	11081P	PARTICIPANT	\N	PRESENT	0
191508	190757	14121F	PARTICIPANT	\N	PRESENT	0
191509	190757	08017T	PARTICIPANT	\N	PRESENT	0
191510	190757	14039A	PARTICIPANT	\N	PRESENT	0
191511	190757	19253P	PARTICIPANT	\N	PRESENT	0
191512	190757	01024M	PARTICIPANT	\N	PRESENT	0
191513	190757	08044W	PARTICIPANT	\N	PRESENT	0
191514	190757	14087W	PARTICIPANT	\N	PRESENT	0
191515	190757	14215L	PARTICIPANT	\N	PRESENT	0
191516	190757	11063M	PARTICIPANT	\N	PRESENT	0
191517	190757	11098Y	PARTICIPANT	\N	PRESENT	0
191518	190757	05001W	PARTICIPANT	\N	PRESENT	0
191519	190757	14201E	PARTICIPANT	\N	PRESENT	0
191520	190757	95035G	PARTICIPANT	\N	PRESENT	0
191521	190757	14247U	PARTICIPANT	\N	PRESENT	0
191522	190757	14042U	PARTICIPANT	\N	PRESENT	0
191523	190757	14363X	PARTICIPANT	\N	PRESENT	0
191524	190757	14059S	PARTICIPANT	\N	PRESENT	0
191525	190757	14187A	PARTICIPANT	\N	PRESENT	0
191526	190757	14069U	PARTICIPANT	\N	PRESENT	0
191527	190757	04043D	PARTICIPANT	\N	PRESENT	0
191528	190757	08065C	PARTICIPANT	\N	PRESENT	0
191529	190757	14223L	PARTICIPANT	\N	PRESENT	0
191530	190757	10015M	PARTICIPANT	\N	PRESENT	0
191531	190757	14265W	PARTICIPANT	\N	PRESENT	0
191532	190757	14119M	PARTICIPANT	\N	PRESENT	0
191533	190757	04088S	PARTICIPANT	\N	PRESENT	0
191534	190757	14357A	PARTICIPANT	\N	PRESENT	0
191535	190757	04074L	PARTICIPANT	\N	PRESENT	0
191536	190757	14191V	PARTICIPANT	\N	PRESENT	0
191537	190757	08068F	PARTICIPANT	\N	PRESENT	0
191538	190757	11036J	PARTICIPANT	\N	PRESENT	0
191539	190757	08039A	PARTICIPANT	\N	PRESENT	0
191540	190757	11094U	PARTICIPANT	\N	PRESENT	0
191541	190757	04085P	PARTICIPANT	\N	PRESENT	0
191542	190757	11034G	PARTICIPANT	\N	PRESENT	0
191552	190532	11048N	PARTICIPANT	\N	PRESENT	0
191553	190532	04034C	PARTICIPANT	\N	PRESENT	0
191554	190532	89017R	PARTICIPANT	\N	PRESENT	0
191555	190532	01027Q	PARTICIPANT	\N	PRESENT	0
191556	190532	08014Q	PARTICIPANT	\N	PRESENT	0
191557	190532	14225N	PARTICIPANT	\N	PRESENT	0
191558	190532	14085U	PARTICIPANT	\N	PRESENT	0
191559	190532	11083R	PARTICIPANT	\N	PRESENT	0
191560	190532	98053W	PARTICIPANT	\N	EXCUSE	0
191561	190757	11031D	PARTICIPANT	\N	PRESENT	0
191562	190757	14235Q	PARTICIPANT	\N	PRESENT	0
191563	190757	80027E	PARTICIPANT	\N	PRESENT	0
191564	190757	14257W	PARTICIPANT	\N	PRESENT	0
191565	190757	11077T	PARTICIPANT	\N	PRESENT	0
191566	190757	14065Q	PARTICIPANT	\N	PRESENT	0
191567	190757	08061X	PARTICIPANT	\N	PRESENT	0
191568	190757	01028R	PARTICIPANT	\N	PRESENT	0
191569	190757	04053F	PARTICIPANT	\N	PRESENT	0
191570	190757	11042G	PARTICIPANT	\N	PRESENT	0
191571	190757	14361V	PARTICIPANT	\N	PRESENT	0
191572	190757	11107G	PARTICIPANT	\N	PRESENT	0
191573	190757	11099A	PARTICIPANT	\N	PRESENT	0
191574	190757	11033F	PARTICIPANT	\N	PRESENT	0
191575	190757	14219Q	PARTICIPANT	\N	PRESENT	0
191576	190757	01046T	PARTICIPANT	\N	PRESENT	0
191577	190757	14205J	PARTICIPANT	\N	PRESENT	0
191578	190757	14211G	PARTICIPANT	\N	PRESENT	0
191579	190757	14105F	PARTICIPANT	\N	PRESENT	0
191580	190757	14041T	PARTICIPANT	\N	PRESENT	0
191581	190757	14033T	PARTICIPANT	\N	PRESENT	0
191582	190757	14213J	PARTICIPANT	\N	PRESENT	0
191583	190757	95030B	PARTICIPANT	\N	PRESENT	0
191584	190757	10006L	PARTICIPANT	\N	PRESENT	0
191585	190757	14071N	PARTICIPANT	\N	PRESENT	0
191587	190757	14179A	PARTICIPANT	\N	PRESENT	0
191588	190757	14109K	PARTICIPANT	\N	PRESENT	0
191589	191586	08038Y	PARTICIPANT	\N	PRESENT	0
191590	190757	11082Q	PARTICIPANT	\N	PRESENT	0
191591	190757	14079W	PARTICIPANT	\N	PRESENT	0
191592	190757	14237S	PARTICIPANT	\N	PRESENT	0
191593	190757	14073Q	PARTICIPANT	\N	PRESENT	0
191600	191597	14089Y	PARTICIPANT	\N	PRESENT	0
191598	191597	04070G	PARTICIPANT	\N	PRESENT	0
191599	191597	11026G	PARTICIPANT	\N	PRESENT	0
191613	191612	92039X	PARTICIPANT	\N	PRESENT	0
191635	190512	14001X	PARTICIPANT	\N	PRESENT	0
191636	190512	04044E	PARTICIPANT	\N	PRESENT	0
191637	190512	01028R	PARTICIPANT	\N	PRESENT	0
191638	190512	11030C	PARTICIPANT	\N	PRESENT	0
191639	190512	14041T	PARTICIPANT	\N	PRESENT	0
191640	190512	14147R	PARTICIPANT	\N	PRESENT	0
191641	190512	14215L	PARTICIPANT	\N	PRESENT	0
191642	190512	95067Q	PARTICIPANT	\N	PRESENT	0
191643	190512	14111D	PARTICIPANT	\N	PRESENT	0
191644	190512	14065Q	PARTICIPANT	\N	PRESENT	0
191645	190512	07034Q	PRESIDENT	0	PRESENT	0
191646	190512	10015M	PARTICIPANT	\N	PRESENT	0
191647	190512	11026G	PARTICIPANT	\N	PRESENT	0
191648	190512	19253P	PARTICIPANT	\N	PRESENT	0
191649	190512	01024M	PARTICIPANT	\N	PRESENT	0
191650	190512	19251M	PARTICIPANT	\N	PRESENT	0
191651	190512	04038G	PARTICIPANT	\N	PRESENT	0
191652	190512	08011M	PARTICIPANT	\N	PRESENT	0
191653	190512	11033F	PARTICIPANT	\N	PRESENT	0
191654	190512	04085P	PARTICIPANT	\N	PRESENT	0
191655	190512	95063L	PARTICIPANT	\N	PRESENT	0
191656	190512	04074L	PARTICIPANT	\N	PRESENT	0
191657	190512	08044W	PARTICIPANT	\N	PRESENT	0
191658	190512	14069U	PARTICIPANT	\N	PRESENT	0
191659	190512	95049N	PARTICIPANT	\N	PRESENT	0
191660	190512	92045V	PARTICIPANT	\N	PRESENT	0
191672	190512	05008E	PARTICIPANT	\N	PRESENT	0
191673	190512	01047U	PARTICIPANT	\N	PRESENT	0
191674	190512	08025T	PARTICIPANT	\N	EXCUSE	0
191675	190512	08018U	PARTICIPANT	\N	EXCUSE	0
191692	190512	14275Y	PARTICIPANT	\N	PRESENT	0
192332	190412	11109J	PARTICIPANT	\N	PRESENT	0
192333	190412	11113E	PARTICIPANT	\N	PRESENT	0
192334	190412	14033T	PARTICIPANT	\N	PRESENT	0
192335	190412	14097Y	PARTICIPANT	\N	PRESENT	0
192336	190412	14039A	PARTICIPANT	\N	PRESENT	0
192337	190412	98005N	PARTICIPANT	\N	PRESENT	0
192339	190412	14059S	PARTICIPANT	\N	PRESENT	0
192340	190412	08019V	PRESIDENT	0	PRESENT	0
192341	190412	11072N	PARTICIPANT	\N	PRESENT	0
192342	190412	08073C	PARTICIPANT	\N	PRESENT	0
167376	167375	01041N	PARTICIPANT	\N	PRESENT	0
167377	167375	98022P	PARTICIPANT	\N	PRESENT	0
167378	167375	04036E	PARTICIPANT	\N	PRESENT	0
167379	167375	08015R	PARTICIPANT	\N	PRESENT	0
167380	167375	14265W	PARTICIPANT	\N	PRESENT	0
167381	167375	14237S	PARTICIPANT	\N	PRESENT	0
167382	167375	95062K	PARTICIPANT	\N	PRESENT	0
167383	167375	11093T	PARTICIPANT	\N	PRESENT	0
167384	167375	95067Q	PARTICIPANT	\N	PRESENT	0
167385	167375	14030Q	PARTICIPANT	\N	PRESENT	0
167599	167598	98053W	PARTICIPANT	\N	PRESENT	0
167600	167598	01048V	PARTICIPANT	\N	PRESENT	0
167602	167601	98053W	PARTICIPANT	\N	PRESENT	0
167603	167601	01048V	PARTICIPANT	\N	PRESENT	0
167618	167617	08011M	PARTICIPANT	\N	PRESENT	0
168112	165592	14135M	PARTICIPANT	\N	PRESENT	0
168113	165592	14239U	PARTICIPANT	\N	PRESENT	0
168114	165592	11083R	PARTICIPANT	\N	PRESENT	0
168116	165592	14030Q	PARTICIPANT	\N	PRESENT	0
168123	165592	04049K	PARTICIPANT	\N	PRESENT	0
168758	168757	14259Y	PARTICIPANT	\N	PRESENT	0
168346	168344	01031L	PARTICIPANT	\N	EXCUSE	0
168759	168757	01007L	PARTICIPANT	\N	PRESENT	0
168761	168760	01007L	PARTICIPANT	\N	PRESENT	0
168762	168760	14259Y	PARTICIPANT	\N	PRESENT	0
172227	172226	11076S	PARTICIPANT	\N	PRESENT	0
168351	168344	08014Q	PARTICIPANT	\N	PRESENT	0
168352	168344	14167V	PARTICIPANT	\N	PRESENT	0
168353	168344	14175V	PARTICIPANT	\N	PRESENT	0
168354	168344	14083S	PARTICIPANT	\N	PRESENT	0
168355	168344	11053K	PARTICIPANT	\N	PRESENT	0
168356	168344	14085U	PARTICIPANT	\N	PRESENT	0
172313	172312	11076S	PARTICIPANT	\N	PRESENT	0
168358	168344	88008L	PRESIDENT	0	PRESENT	0
168359	168344	04086Q	PARTICIPANT	\N	PRESENT	0
172229	172226	04054G	PARTICIPANT	\N	EXCUSE	0
172230	172226	04040A	PARTICIPANT	\N	PRESENT	0
168362	168344	11088W	PARTICIPANT	\N	PRESENT	0
172231	172226	08058D	PARTICIPANT	\N	PRESENT	0
168364	168344	08022Q	PARTICIPANT	\N	PRESENT	0
168365	168344	01027Q	PARTICIPANT	\N	PRESENT	0
168366	168344	04071H	PARTICIPANT	\N	PRESENT	0
168367	168344	11074Q	PARTICIPANT	\N	PRESENT	0
172232	172226	04042C	PARTICIPANT	\N	PRESENT	0
168369	168344	11083R	PARTICIPANT	\N	PRESENT	0
168370	168344	14199E	PARTICIPANT	\N	PRESENT	0
168371	168344	01057W	PARTICIPANT	\N	PRESENT	0
172233	172226	77002U	PARTICIPANT	\N	PRESENT	0
172234	172226	98029W	PARTICIPANT	\N	PRESENT	0
172235	172226	11080N	PARTICIPANT	\N	PRESENT	0
168375	168344	99004R	PARTICIPANT	\N	PRESENT	0
168376	168344	04061F	PARTICIPANT	\N	EXCUSE	0
168377	168344	14159V	PARTICIPANT	\N	PRESENT	0
168378	168344	07029T	PARTICIPANT	\N	PRESENT	0
172236	172226	11027H	PARTICIPANT	\N	PRESENT	0
168380	168344	08010L	PARTICIPANT	\N	PRESENT	0
168381	168344	08034U	PARTICIPANT	\N	PRESENT	0
172237	172226	98018T	PARTICIPANT	\N	PRESENT	0
168383	168344	98046X	PARTICIPANT	\N	EXCUSE	0
172238	172226	92018S	PARTICIPANT	\N	PRESENT	0
168385	168344	08011M	PARTICIPANT	\N	PRESENT	0
172239	172226	92020L	PARTICIPANT	\N	PRESENT	0
168387	168344	08061X	PARTICIPANT	\N	PRESENT	0
168388	168344	01016M	PARTICIPANT	\N	PRESENT	0
168389	168344	14225N	PARTICIPANT	\N	PRESENT	0
168390	168344	11012A	PARTICIPANT	\N	PRESENT	0
168391	168344	11057P	PARTICIPANT	\N	PRESENT	0
172240	172226	95030B	PARTICIPANT	\N	PRESENT	0
168393	168344	04034C	PARTICIPANT	\N	PRESENT	0
172383	172312	01013J	PARTICIPANT	\N	PRESENT	0
172315	172312	04054G	PARTICIPANT	\N	EXCUSE	0
172316	172312	04040A	PARTICIPANT	\N	PRESENT	0
172245	172226	04035D	PARTICIPANT	\N	PRESENT	0
172317	172312	08058D	PARTICIPANT	\N	PRESENT	0
172247	172226	14014Q	PARTICIPANT	\N	PRESENT	0
172248	172226	11015D	PARTICIPANT	\N	PRESENT	0
172249	172226	07004J	PARTICIPANT	\N	PRESENT	0
172250	172226	95035G	PARTICIPANT	\N	PRESENT	0
172251	172226	08056B	PARTICIPANT	\N	PRESENT	0
172318	172312	04042C	PRESIDENT	0	PRESENT	0
172253	172226	98022P	PARTICIPANT	\N	EXCUSE	0
172254	172226	11064N	PARTICIPANT	\N	PRESENT	0
172255	172226	95037J	PARTICIPANT	\N	PRESENT	0
172256	172226	04078Q	PARTICIPANT	\N	PRESENT	0
172257	172226	14097Y	PARTICIPANT	\N	PRESENT	0
172258	172226	95041E	PARTICIPANT	\N	PRESENT	0
172259	172226	04036E	PARTICIPANT	\N	PRESENT	0
172319	172312	77002U	PARTICIPANT	\N	PRESENT	0
172261	172226	04077P	PARTICIPANT	\N	PRESENT	0
172320	172312	98029W	PARTICIPANT	\N	PRESENT	0
172263	172226	92031P	PARTICIPANT	\N	PRESENT	0
172264	172226	11106F	PARTICIPANT	\N	PRESENT	0
172265	172226	14251Q	PARTICIPANT	\N	PRESENT	0
172266	172226	83042R	PARTICIPANT	\N	PRESENT	0
172267	172226	08053X	PARTICIPANT	\N	PRESENT	0
172385	172312	14013P	PARTICIPANT	\N	PRESENT	0
172269	172226	11105E	PARTICIPANT	\N	PRESENT	0
172270	172226	14253S	PARTICIPANT	\N	PRESENT	0
172271	172226	08047A	PARTICIPANT	\N	PRESENT	0
172272	172226	14028W	PARTICIPANT	\N	PRESENT	0
172273	172226	14193X	PARTICIPANT	\N	PRESENT	0
172274	172226	98021N	PARTICIPANT	\N	PRESENT	0
172275	172226	04080J	PARTICIPANT	\N	PRESENT	0
172276	172226	95059Q	PRESIDENT	0	PRESENT	0
172277	172226	86044G	PARTICIPANT	\N	PRESENT	0
172278	172226	01014K	PARTICIPANT	\N	PRESENT	0
172279	172226	11054L	PARTICIPANT	\N	PRESENT	0
172280	172226	01056V	PARTICIPANT	\N	PRESENT	0
172281	172226	92044U	PARTICIPANT	\N	PRESENT	0
172282	172226	08049C	PARTICIPANT	\N	PRESENT	0
172283	172226	04050C	PARTICIPANT	\N	PRESENT	0
172321	172312	11080N	PARTICIPANT	\N	PRESENT	0
172322	172312	11027H	PARTICIPANT	\N	PRESENT	0
172323	172312	98018T	PARTICIPANT	\N	PRESENT	0
172324	172312	92018S	PARTICIPANT	\N	PRESENT	0
172325	172312	92020L	PARTICIPANT	\N	PRESENT	0
172326	172312	95030B	PARTICIPANT	\N	PRESENT	0
172387	172312	08014Q	PARTICIPANT	\N	PRESENT	0
172388	172312	11031D	PARTICIPANT	\N	PRESENT	0
172329	172312	97011G	PARTICIPANT	\N	PRESENT	0
172389	172312	01011G	PARTICIPANT	\N	PRESENT	0
172331	172312	04035D	PARTICIPANT	\N	PRESENT	0
172390	172312	14179A	PARTICIPANT	\N	PRESENT	0
172333	172312	14014Q	PARTICIPANT	\N	PRESENT	0
172391	172312	04049K	PARTICIPANT	\N	PRESENT	0
172392	172312	14235Q	PARTICIPANT	\N	PRESENT	0
172336	172312	95035G	PARTICIPANT	\N	PRESENT	0
172337	172312	08056B	PARTICIPANT	\N	PRESENT	0
172338	172312	14211G	PARTICIPANT	\N	PRESENT	0
172339	172312	98022P	PARTICIPANT	\N	EXCUSE	0
172340	172312	11064N	PARTICIPANT	\N	PRESENT	0
172393	172312	04056J	PARTICIPANT	\N	PRESENT	0
172342	172312	04078Q	PARTICIPANT	\N	PRESENT	0
172343	172312	14097Y	PARTICIPANT	\N	PRESENT	0
172394	172312	95067Q	PARTICIPANT	\N	PRESENT	0
172345	172312	04036E	PARTICIPANT	\N	PRESENT	0
172396	172312	14269B	PARTICIPANT	\N	PRESENT	0
172347	172312	04077P	PARTICIPANT	\N	PRESENT	0
172397	172312	11109J	PARTICIPANT	\N	PRESENT	0
172349	172312	92031P	PARTICIPANT	\N	PRESENT	0
172350	172312	11106F	PARTICIPANT	\N	PRESENT	0
172351	172312	14251Q	PARTICIPANT	\N	PRESENT	0
172398	172312	11067R	PARTICIPANT	\N	PRESENT	0
172353	172312	08053X	PARTICIPANT	\N	PRESENT	0
172355	172312	11105E	PARTICIPANT	\N	PRESENT	0
172356	172312	14253S	PARTICIPANT	\N	PRESENT	0
172357	172312	08047A	PARTICIPANT	\N	PRESENT	0
172358	172312	14028W	PARTICIPANT	\N	PRESENT	0
172359	172312	14193X	PARTICIPANT	\N	PRESENT	0
172360	172312	98021N	PARTICIPANT	\N	PRESENT	0
172361	172312	04080J	PARTICIPANT	\N	PRESENT	0
172362	172312	95059Q	PRESIDENT	1	PRESENT	0
172363	172312	86044G	PARTICIPANT	\N	PRESENT	0
172364	172312	01014K	PARTICIPANT	\N	PRESENT	0
172365	172312	11054L	PARTICIPANT	\N	PRESENT	0
172366	172312	01056V	PARTICIPANT	\N	PRESENT	0
172367	172312	92044U	PARTICIPANT	\N	PRESENT	0
172368	172312	08049C	PARTICIPANT	\N	PRESENT	0
172369	172312	04050C	PARTICIPANT	\N	PRESENT	0
186829	186828	11031D	PARTICIPANT	\N	PRESENT	0
186830	186828	11061K	PARTICIPANT	\N	PRESENT	0
186831	186828	11097X	PARTICIPANT	\N	PRESENT	0
188474	188473	11039M	PARTICIPANT	\N	PRESENT	0
188475	188473	98042T	PARTICIPANT	\N	PRESENT	0
188476	188473	01019Q	PARTICIPANT	\N	PRESENT	0
197320	192772	19253P	PARTICIPANT	\N	PRESENT	0
184332	184192	04044E	PARTICIPANT	\N	EXCUSE	0
184372	184192	14071N	PARTICIPANT	\N	PRESENT	0
184412	184192	14028W	PARTICIPANT	\N	EXCUSE	0
184432	184192	01027Q	PARTICIPANT	\N	EXCUSE	0
185253	185252	08034U	PARTICIPANT	\N	PRESENT	0
185273	185272	01048V	PARTICIPANT	\N	PRESENT	0
185275	185274	08034U	PARTICIPANT	\N	PRESENT	0
185277	185276	08034U	PARTICIPANT	\N	PRESENT	0
185279	185278	08034U	PARTICIPANT	\N	PRESENT	0
185281	185280	08034U	PARTICIPANT	\N	PRESENT	0
210120	210118	08031R	PARTICIPANT	\N	PRESENT	0
210130	210045	19349W	PARTICIPANT	\N	EXCUSE	0
210131	210045	19369B	PARTICIPANT	\N	PRESENT	0
210605	207685	14073Q	PARTICIPANT	\N	PRESENT	0
210606	207685	14030Q	PARTICIPANT	\N	PRESENT	0
210607	207685	11101A	PARTICIPANT	\N	PRESENT	0
210608	207685	19349W	PARTICIPANT	\N	PRESENT	0
210609	207685	11072N	PARTICIPANT	\N	PRESENT	0
210610	207685	19719D	PARTICIPANT	\N	PRESENT	0
210611	207685	87003B	PARTICIPANT	\N	PRESENT	0
210612	207685	19511N	PARTICIPANT	\N	PRESENT	0
210614	207685	19669L	PARTICIPANT	\N	PRESENT	0
210615	207685	14249W	PARTICIPANT	\N	PRESENT	0
210620	207685	08055A	PARTICIPANT	\N	PRESENT	0
210621	207685	14065Q	PARTICIPANT	\N	PRESENT	0
210623	207685	14053L	PARTICIPANT	\N	PRESENT	0
210624	207685	95030B	PARTICIPANT	\N	PRESENT	0
210625	207685	08044W	PARTICIPANT	\N	PRESENT	0
211087	210132	01034P	PARTICIPANT	\N	PRESENT	0
211088	210132	04092N	PRESIDENT	0	PRESENT	0
211089	210132	19569H	PARTICIPANT	\N	PRESENT	0
211090	210132	11097X	PARTICIPANT	\N	PRESENT	0
211091	210132	08052W	PARTICIPANT	\N	PRESENT	0
211092	210132	19415P	PARTICIPANT	\N	PRESENT	0
211093	210132	04045F	PARTICIPANT	\N	PRESENT	0
211094	210132	19727D	PARTICIPANT	\N	PRESENT	0
211095	210132	19703U	PARTICIPANT	\N	PRESENT	0
211096	210132	19553Y	PARTICIPANT	\N	PRESENT	0
211097	210132	11103C	PARTICIPANT	\N	PRESENT	0
211098	210132	19679N	PARTICIPANT	\N	PRESENT	0
211099	210132	14195A	PARTICIPANT	\N	PRESENT	0
211100	210132	19575F	PARTICIPANT	\N	PRESENT	0
211101	210132	08048B	PARTICIPANT	\N	PRESENT	0
211102	210132	19367Y	PARTICIPANT	\N	PRESENT	0
211103	210132	14213J	PARTICIPANT	\N	PRESENT	0
211104	210132	14261S	PARTICIPANT	\N	PRESENT	0
211105	210132	10006L	PARTICIPANT	\N	PRESENT	0
211106	210132	98024R	PARTICIPANT	\N	PRESENT	0
211107	210132	19691J	PARTICIPANT	\N	PRESENT	0
211108	210132	19723Y	PARTICIPANT	\N	PRESENT	0
211109	210132	14119M	PARTICIPANT	\N	PRESENT	0
211110	210132	14071N	PARTICIPANT	\N	PRESENT	0
211111	210099	19443T	PARTICIPANT	\N	PRESENT	0
211112	210099	04040A	PARTICIPANT	\N	PRESENT	0
211113	210099	01058X	PARTICIPANT	\N	PRESENT	0
211114	210099	14079W	PARTICIPANT	\N	PRESENT	0
211115	210099	11027H	PARTICIPANT	\N	PRESENT	0
211116	210099	04042C	PRESIDENT	0	PRESENT	0
211117	210099	11054L	PARTICIPANT	\N	PRESENT	0
211118	210099	11066Q	PARTICIPANT	\N	PRESENT	0
211119	210099	95037J	PARTICIPANT	\N	PRESENT	0
211120	210099	19421M	PARTICIPANT	\N	PRESENT	0
211121	210099	19709B	PARTICIPANT	\N	PRESENT	0
211122	210099	14193X	PARTICIPANT	\N	PRESENT	0
211123	210099	08049C	PARTICIPANT	\N	PRESENT	0
211124	210099	97011G	PARTICIPANT	\N	PRESENT	0
211125	210099	08047A	PARTICIPANT	\N	PRESENT	0
211126	210099	98029W	PARTICIPANT	\N	PRESENT	0
211127	210099	14097Y	PARTICIPANT	\N	PRESENT	0
211128	210099	95067Q	PARTICIPANT	\N	PRESENT	0
211129	210099	01062T	PARTICIPANT	\N	PRESENT	0
211130	210099	08058D	PARTICIPANT	\N	PRESENT	0
211131	210099	19251M	PARTICIPANT	\N	PRESENT	0
211132	210099	19721W	PARTICIPANT	\N	PRESENT	0
211133	210099	19319Q	PARTICIPANT	\N	PRESENT	0
211134	210099	98022P	PARTICIPANT	\N	PRESENT	0
211135	210099	11064N	PARTICIPANT	\N	PRESENT	0
211136	210099	14267Y	PARTICIPANT	\N	PRESENT	0
211137	210099	98050T	PARTICIPANT	\N	PRESENT	0
211138	210099	14211G	PARTICIPANT	\N	PRESENT	0
211139	210099	14255U	PARTICIPANT	\N	PRESENT	0
211140	210132	19697Q	PARTICIPANT	\N	PRESENT	0
211141	210132	14026U	PARTICIPANT	\N	PRESENT	0
211142	210132	14239U	PARTICIPANT	\N	PRESENT	0
211143	210132	14042U	PARTICIPANT	\N	PRESENT	0
211159	211158	14071N	PARTICIPANT	\N	PRESENT	0
211161	211160	14071N	PARTICIPANT	\N	PRESENT	0
211163	211162	14071N	PARTICIPANT	\N	PRESENT	0
211164	210132	14087W	PARTICIPANT	\N	PRESENT	0
211165	210132	19683J	PARTICIPANT	\N	PRESENT	0
211166	210132	19663E	PARTICIPANT	\N	PRESENT	0
211168	211167	14217N	PARTICIPANT	\N	PRESENT	0
211170	211169	14217N	PARTICIPANT	\N	PRESENT	0
211172	210099	95030B	PARTICIPANT	\N	PRESENT	0
211173	210099	16685X	PARTICIPANT	\N	PRESENT	0
211174	210099	08056B	PARTICIPANT	\N	PRESENT	0
211175	210099	14055N	PARTICIPANT	\N	PRESENT	0
211176	210099	08053X	PARTICIPANT	\N	PRESENT	0
211177	210099	11041F	PARTICIPANT	\N	PRESENT	0
211178	210099	14028W	PARTICIPANT	\N	PRESENT	0
211179	210099	14105F	PARTICIPANT	\N	PRESENT	0
211180	210099	04034C	PARTICIPANT	\N	PRESENT	0
211226	210132	19675J	PARTICIPANT	\N	PRESENT	0
211227	210132	11063M	PARTICIPANT	\N	PRESENT	0
211230	210132	17779H	PARTICIPANT	\N	PRESENT	0
211275	210161	19619A	PARTICIPANT	\N	PRESENT	0
211276	210161	17589D	PARTICIPANT	\N	PRESENT	0
211277	210161	14257W	PARTICIPANT	\N	PRESENT	0
211278	210161	04043D	PARTICIPANT	\N	EXCUSE	0
211279	210161	19563B	PARTICIPANT	\N	EXCUSE	0
211280	210117	19543W	PARTICIPANT	\N	PRESENT	0
211281	210117	19581D	PARTICIPANT	\N	PRESENT	0
211282	210117	04047H	PARTICIPANT	\N	PRESENT	0
211283	210117	14231L	PARTICIPANT	\N	PRESENT	0
211284	210117	19447X	PARTICIPANT	\N	PRESENT	0
211285	210117	05008E	PRESIDENT	0	PRESENT	0
211286	210117	19489J	PARTICIPANT	\N	PRESENT	0
211287	210117	14041T	PARTICIPANT	\N	PRESENT	0
211288	210117	14147R	PARTICIPANT	\N	PRESENT	0
211289	210117	14215L	PARTICIPANT	\N	PRESENT	0
211290	210117	08018U	PARTICIPANT	\N	PRESENT	0
211291	210117	11072N	PARTICIPANT	\N	PRESENT	0
211292	210117	14111D	PARTICIPANT	\N	PRESENT	0
211293	210117	08045X	PARTICIPANT	\N	PRESENT	0
211294	210117	19253P	PARTICIPANT	\N	PRESENT	0
211295	210117	01024M	PARTICIPANT	\N	PRESENT	0
211296	210117	04038G	PARTICIPANT	\N	PRESENT	0
211297	210117	19719D	PARTICIPANT	\N	PRESENT	0
211298	210117	14089Y	PARTICIPANT	\N	PRESENT	0
211299	210117	19725B	PARTICIPANT	\N	PRESENT	0
211300	210117	19729F	PARTICIPANT	\N	PRESENT	0
211301	210117	19629C	PARTICIPANT	\N	PRESENT	0
211302	210117	08044W	PARTICIPANT	\N	PRESENT	0
211303	210117	14069U	PARTICIPANT	\N	PRESENT	0
211304	210117	11085T	PARTICIPANT	\N	PRESENT	0
211305	210117	98035U	PARTICIPANT	\N	PRESENT	0
211306	210117	14053L	PARTICIPANT	\N	PRESENT	0
211307	210117	14065Q	PARTICIPANT	\N	PRESENT	0
211308	210117	11026G	PARTICIPANT	\N	PRESENT	0
211309	210117	01060R	PARTICIPANT	\N	PRESENT	0
211310	210117	14001X	PARTICIPANT	\N	PRESENT	0
211311	210117	04044E	PARTICIPANT	\N	PRESENT	0
211312	210117	19585H	PARTICIPANT	\N	PRESENT	0
211313	210117	11033F	PARTICIPANT	\N	PRESENT	0
211314	210117	01028R	PARTICIPANT	\N	PRESENT	0
211315	210117	14275Y	PARTICIPANT	\N	PRESENT	0
211316	210117	14151M	PARTICIPANT	\N	PRESENT	0
211317	210117	19483C	PARTICIPANT	\N	PRESENT	0
211318	210117	11049P	PARTICIPANT	\N	PRESENT	0
211319	210117	04008A	PARTICIPANT	\N	PRESENT	0
211320	210117	14259Y	PARTICIPANT	\N	PRESENT	0
211321	210117	14021P	PARTICIPANT	\N	PRESENT	0
211322	210117	19673G	PARTICIPANT	\N	EXCUSE	0
211323	205652	19683J	PARTICIPANT	\N	PRESENT	0
211324	205652	01048V	PARTICIPANT	\N	PRESENT	0
211325	205652	19503N	PARTICIPANT	\N	PRESENT	0
211327	210160	08055A	PARTICIPANT	\N	PRESENT	0
211328	210160	14093U	PARTICIPANT	\N	PRESENT	0
211329	210160	19549D	PARTICIPANT	\N	PRESENT	0
211331	210160	08060W	PARTICIPANT	\N	PRESENT	0
211332	210160	19733B	PARTICIPANT	\N	PRESENT	0
211333	210160	19383Y	PARTICIPANT	\N	PRESENT	0
211334	210160	08024S	PARTICIPANT	\N	PRESENT	0
211335	210160	14038Y	PARTICIPANT	\N	PRESENT	0
211336	210160	18083K	PARTICIPANT	\N	PRESENT	0
211337	210160	19701S	PARTICIPANT	\N	PRESENT	0
165833	165832	11076S	PARTICIPANT	\N	PRESENT	0
165834	165832	14133K	PARTICIPANT	\N	PRESENT	0
165835	165832	04054G	PARTICIPANT	\N	PRESENT	0
165836	165832	04040A	PARTICIPANT	\N	PRESENT	0
165837	165832	08058D	PARTICIPANT	\N	PRESENT	0
165838	165832	04042C	PARTICIPANT	\N	PRESENT	0
165839	165832	77002U	PARTICIPANT	\N	PRESENT	0
165840	165832	98029W	PARTICIPANT	\N	PRESENT	0
165841	165832	11027H	PARTICIPANT	\N	PRESENT	0
165842	165832	92018S	PARTICIPANT	\N	PRESENT	0
165843	165832	92020L	PARTICIPANT	\N	EXCUSE	0
165844	165832	95030B	PARTICIPANT	\N	PRESENT	0
165845	165832	08065C	PARTICIPANT	\N	PRESENT	0
165846	165832	04035D	PARTICIPANT	\N	PRESENT	0
165847	165832	14014Q	PARTICIPANT	\N	PRESENT	0
165848	165832	11015D	PARTICIPANT	\N	PRESENT	0
165849	165832	07004J	PARTICIPANT	\N	PRESENT	0
165850	165832	95035G	PARTICIPANT	\N	PRESENT	0
165851	165832	08056B	PARTICIPANT	\N	EXCUSE	0
165852	165832	14211G	PARTICIPANT	\N	PRESENT	0
165853	165832	98022P	PARTICIPANT	\N	PRESENT	0
165854	165832	95037J	PARTICIPANT	\N	PRESENT	0
165855	165832	04078Q	PARTICIPANT	\N	PRESENT	0
165856	165832	14097Y	PARTICIPANT	\N	PRESENT	0
165857	165832	95041E	PARTICIPANT	\N	PRESENT	0
165858	165832	04036E	PARTICIPANT	\N	PRESENT	0
165859	165832	14039A	PARTICIPANT	\N	PRESENT	0
165860	165832	98005N	PARTICIPANT	\N	PRESENT	0
165861	165832	92031P	PARTICIPANT	\N	PRESENT	0
165862	165832	11106F	PARTICIPANT	\N	PRESENT	0
165863	165832	14251Q	PARTICIPANT	\N	PRESENT	0
165864	165832	83042R	PARTICIPANT	\N	PRESENT	0
165865	165832	08053X	PARTICIPANT	\N	PRESENT	0
165866	165832	11082Q	PARTICIPANT	\N	PRESENT	0
165867	165832	14253S	PARTICIPANT	\N	PRESENT	0
165868	165832	08047A	PARTICIPANT	\N	PRESENT	0
165869	165832	14028W	PARTICIPANT	\N	PRESENT	0
165870	165832	14193X	PARTICIPANT	\N	PRESENT	0
165871	165832	98021N	PARTICIPANT	\N	PRESENT	0
165872	165832	04080J	PARTICIPANT	\N	PRESENT	0
165873	165832	95059Q	PRESIDENT	0	PRESENT	0
165874	165832	86044G	PARTICIPANT	\N	PRESENT	0
165875	165832	01014K	PARTICIPANT	\N	PRESENT	0
165876	165832	11054L	PARTICIPANT	\N	PRESENT	0
165877	165832	01056V	PARTICIPANT	\N	PRESENT	0
165878	165832	92044U	PARTICIPANT	\N	PRESENT	0
165879	165832	08049C	PARTICIPANT	\N	PRESENT	0
165880	165832	04050C	PARTICIPANT	\N	PRESENT	0
166051	166050	14133K	PARTICIPANT	\N	PRESENT	0
166052	166050	04054G	PARTICIPANT	\N	PRESENT	0
166053	166050	04040A	PARTICIPANT	\N	PRESENT	0
166054	166050	08058D	PARTICIPANT	\N	PRESENT	0
166055	166050	04042C	PRESIDENT	1	PRESENT	0
166056	166050	77002U	PARTICIPANT	\N	PRESENT	0
166057	166050	98029W	PARTICIPANT	\N	PRESENT	0
166058	166050	11027H	PARTICIPANT	\N	PRESENT	0
166059	166050	92018S	PARTICIPANT	\N	PRESENT	0
166060	166050	92020L	PARTICIPANT	\N	EXCUSE	0
166061	166050	95030B	PARTICIPANT	\N	PRESENT	0
166062	166050	08065C	PARTICIPANT	\N	PRESENT	0
166063	166050	14014Q	PARTICIPANT	\N	PRESENT	0
166064	166050	95035G	PARTICIPANT	\N	PRESENT	0
166065	166050	08056B	PARTICIPANT	\N	EXCUSE	0
166066	166050	98022P	PARTICIPANT	\N	PRESENT	0
166067	166050	04078Q	PARTICIPANT	\N	PRESENT	0
166068	166050	14097Y	PARTICIPANT	\N	PRESENT	0
166070	166050	04036E	PARTICIPANT	\N	PRESENT	0
166071	166050	14039A	PARTICIPANT	\N	PRESENT	0
166073	166050	98005N	PARTICIPANT	\N	PRESENT	0
166075	166050	11106F	PARTICIPANT	\N	PRESENT	0
166076	166050	14251Q	PARTICIPANT	\N	PRESENT	0
166079	166050	08053X	PARTICIPANT	\N	PRESENT	0
166081	166050	11082Q	PARTICIPANT	\N	PRESENT	0
166083	166050	11105E	PARTICIPANT	\N	PRESENT	0
166086	166050	14253S	PARTICIPANT	\N	PRESENT	0
166088	166050	08047A	PARTICIPANT	\N	PRESENT	0
166090	166050	14028W	PARTICIPANT	\N	PRESENT	0
166092	166050	98021N	PARTICIPANT	\N	PRESENT	0
166094	166050	04080J	PARTICIPANT	\N	PRESENT	0
166097	166050	95059Q	PRESIDENT	0	PRESENT	0
166099	166050	86044G	PARTICIPANT	\N	PRESENT	0
166101	166050	01014K	PARTICIPANT	\N	PRESENT	0
166103	166050	11054L	PARTICIPANT	\N	PRESENT	0
166106	166050	01056V	PARTICIPANT	\N	PRESENT	0
166108	166050	92044U	PARTICIPANT	\N	PRESENT	0
166110	166050	04050C	PARTICIPANT	\N	PRESENT	0
167633	167632	95015C	PARTICIPANT	\N	PRESENT	0
167635	167634	95015C	PARTICIPANT	\N	PRESENT	0
170197	157435	14039A	PARTICIPANT	\N	PRESENT	0
170198	157436	96004D	PARTICIPANT	\N	EXCUSE	0
170199	157436	08065C	PARTICIPANT	\N	EXCUSE	0
170200	157436	11010L	PARTICIPANT	\N	EXCUSE	0
170201	157436	14033T	PARTICIPANT	\N	PRESENT	0
170202	157436	14097Y	PARTICIPANT	\N	PRESENT	0
170203	157436	04094Q	PARTICIPANT	\N	EXCUSE	0
170204	157436	98005N	PARTICIPANT	\N	EXCUSE	0
170205	157436	14059S	PARTICIPANT	\N	EXCUSE	0
170206	157436	11106F	PARTICIPANT	\N	EXCUSE	0
170207	157436	08019V	PRESIDENT	0	PRESENT	0
170208	157436	11072N	PARTICIPANT	\N	PRESENT	0
170209	157436	95062K	PARTICIPANT	\N	EXCUSE	0
170210	157436	14017T	PARTICIPANT	\N	EXCUSE	0
170211	157436	11054L	PARTICIPANT	\N	EXCUSE	0
173237	164994	11036J	PARTICIPANT	\N	EXCUSE	0
173238	164994	14263U	PARTICIPANT	\N	EXCUSE	0
173239	164994	11089X	PARTICIPANT	\N	EXCUSE	0
173240	164994	11082Q	PARTICIPANT	\N	EXCUSE	0
173241	164994	04061F	PARTICIPANT	\N	EXCUSE	0
173242	164994	01058X	PARTICIPANT	\N	PRESENT	0
173243	164994	14221J	PARTICIPANT	\N	PRESENT	0
173244	164994	01048V	PARTICIPANT	\N	EXCUSE	0
173245	164994	11061K	PARTICIPANT	\N	PRESENT	0
176318	176312	80013X	PARTICIPANT	\N	PRESENT	0
173247	164994	11068S	PARTICIPANT	\N	EXCUSE	0
173248	164995	11036J	PARTICIPANT	\N	EXCUSE	0
173252	164994	14257W	PARTICIPANT	\N	PRESENT	0
176316	176312	05012A	PARTICIPANT	\N	PRESENT	0
176317	176312	01008M	PARTICIPANT	\N	PRESENT	0
176319	176312	09001P	PARTICIPANT	\N	EXCUSE	0
176320	176312	08049C	PARTICIPANT	\N	EXCUSE	0
176992	176952	14219Q	PRESIDENT	0	PRESENT	0
176325	176312	11035H	PARTICIPANT	\N	EXCUSE	0
176326	176312	90003B	PARTICIPANT	\N	EXCUSE	0
176328	176312	01015L	PARTICIPANT	\N	PRESENT	0
176993	176952	11065P	PARTICIPANT	\N	PRESENT	0
176994	176952	11090Q	PARTICIPANT	\N	PRESENT	0
176995	176952	92045V	PARTICIPANT	\N	PRESENT	0
176996	176952	05012A	PARTICIPANT	\N	PRESENT	0
176997	176952	14093U	PARTICIPANT	\N	PRESENT	0
176998	176952	08049C	PARTICIPANT	\N	EXCUSE	0
176999	176952	09001P	PARTICIPANT	\N	EXCUSE	0
177000	176952	80013X	PARTICIPANT	\N	EXCUSE	0
177001	176952	90003B	PARTICIPANT	\N	EXCUSE	0
177593	177592	14042U	PARTICIPANT	\N	PRESENT	0
177594	177592	01011G	PARTICIPANT	\N	PRESENT	0
177596	177595	14042U	PARTICIPANT	\N	PRESENT	0
177597	177595	01011G	PARTICIPANT	\N	PRESENT	0
177599	177598	14042U	PARTICIPANT	\N	PRESENT	0
177600	177598	01011G	PARTICIPANT	\N	PRESENT	0
177602	177601	14042U	PARTICIPANT	\N	PRESENT	0
177603	177601	01011G	PARTICIPANT	\N	PRESENT	0
178595	178594	04034C	PARTICIPANT	\N	PRESENT	0
178597	178596	04061F	PARTICIPANT	\N	PRESENT	0
178598	178596	04034C	PARTICIPANT	\N	PRESENT	0
179213	164995	14209N	PARTICIPANT	\N	EXCUSE	0
179214	164995	11061K	PARTICIPANT	\N	EXCUSE	0
179215	164995	08069G	PARTICIPANT	\N	EXCUSE	0
179216	164995	04061F	PARTICIPANT	\N	EXCUSE	0
179217	164995	08039A	PARTICIPANT	\N	EXCUSE	0
179218	164995	14221J	PARTICIPANT	\N	EXCUSE	0
179233	164995	11082Q	PARTICIPANT	\N	EXCUSE	0
179234	164995	04043D	PARTICIPANT	\N	EXCUSE	0
179235	164995	01058X	PARTICIPANT	\N	PRESENT	0
179236	164995	11068S	PARTICIPANT	\N	EXCUSE	0
179237	164995	80013X	PARTICIPANT	\N	EXCUSE	0
179238	164995	11089X	PARTICIPANT	\N	PRESENT	0
179239	164996	01046T	PARTICIPANT	\N	EXCUSE	0
179240	164996	11036J	PARTICIPANT	\N	PRESENT	0
179241	164996	14209N	PARTICIPANT	\N	EXCUSE	0
179242	164996	11061K	PARTICIPANT	\N	EXCUSE	0
179243	164996	08069G	PARTICIPANT	\N	EXCUSE	0
179244	164996	04061F	PARTICIPANT	\N	EXCUSE	0
179245	164996	08039A	PARTICIPANT	\N	EXCUSE	0
179246	164996	11068S	PARTICIPANT	\N	EXCUSE	0
179247	164996	80013X	PARTICIPANT	\N	EXCUSE	0
179248	164996	11089X	PARTICIPANT	\N	EXCUSE	0
179249	164996	14221J	PARTICIPANT	\N	PRESENT	0
179250	164996	11082Q	PARTICIPANT	\N	EXCUSE	0
179251	164996	04043D	PARTICIPANT	\N	EXCUSE	0
179252	164996	01058X	PARTICIPANT	\N	EXCUSE	0
192345	190412	11114F	PARTICIPANT	\N	PRESENT	0
192372	190412	11023D	PARTICIPANT	\N	PRESENT	0
192383	190613	04040A	PARTICIPANT	\N	EXCUSE	0
192385	190613	08056B	PARTICIPANT	\N	EXCUSE	0
192386	190613	95041E	PARTICIPANT	\N	EXCUSE	0
192387	190613	11106F	PARTICIPANT	\N	EXCUSE	0
192389	190613	11105E	PARTICIPANT	\N	EXCUSE	0
192390	190613	08049C	PARTICIPANT	\N	EXCUSE	0
192452	190412	04043D	PARTICIPANT	\N	PRESENT	0
192454	192453	98021N	PARTICIPANT	\N	PRESENT	0
192455	192453	11106F	PARTICIPANT	\N	PRESENT	0
192516	192515	04092N	PARTICIPANT	\N	PRESENT	0
192680	192679	08058D	PARTICIPANT	\N	PRESENT	0
192684	192682	11068S	PARTICIPANT	\N	PRESENT	0
192687	192685	08058D	PARTICIPANT	\N	PRESENT	0
192692	192686	01034P	PARTICIPANT	\N	PRESENT	0
192758	192757	04070G	PARTICIPANT	\N	PRESENT	0
193662	193658	14133K	PARTICIPANT	\N	PRESENT	0
196431	196430	04040A	PARTICIPANT	\N	PRESENT	0
196432	196430	11106F	PARTICIPANT	\N	PRESENT	0
196716	192492	95041E	PARTICIPANT	\N	EXCUSE	0
196717	192492	11106F	PARTICIPANT	\N	EXCUSE	0
196816	196815	11029K	PARTICIPANT	\N	PRESENT	0
196817	196815	95035G	PARTICIPANT	\N	PRESENT	0
196818	196815	08010L	PARTICIPANT	\N	PRESENT	0
196819	196815	08017T	PARTICIPANT	\N	PRESENT	0
196820	196815	04057K	PARTICIPANT	\N	PRESENT	0
196821	196815	04044E	PARTICIPANT	\N	PRESENT	0
197153	190783	04081K	PARTICIPANT	\N	PRESENT	0
197154	190783	05008E	PARTICIPANT	\N	PRESENT	0
197172	190783	04044E	PARTICIPANT	\N	PRESENT	0
197173	190783	08052W	PARTICIPANT	\N	PRESENT	0
197174	190783	11031D	PARTICIPANT	\N	PRESENT	0
197175	190783	01013J	PARTICIPANT	\N	PRESENT	0
197176	190783	14227Q	PARTICIPANT	\N	PRESENT	0
197177	190783	08055A	PARTICIPANT	\N	PRESENT	0
197178	190783	14207L	PARTICIPANT	\N	PRESENT	0
197179	190783	14107H	PARTICIPANT	\N	PRESENT	0
197180	190783	08043V	PARTICIPANT	\N	PRESENT	0
197181	190783	11067R	PARTICIPANT	\N	PRESENT	0
197182	190783	11107G	PARTICIPANT	\N	PRESENT	0
197183	190783	08031R	PARTICIPANT	\N	PRESENT	0
197184	190783	04038G	PARTICIPANT	\N	PRESENT	0
197185	190783	14215L	PARTICIPANT	\N	PRESENT	0
197186	190783	14217N	PARTICIPANT	\N	PRESENT	0
197187	190783	14249W	PARTICIPANT	\N	PRESENT	0
197188	190783	99004R	PARTICIPANT	\N	PRESENT	0
197189	190783	04088S	PARTICIPANT	\N	PRESENT	0
197190	190783	14357A	PARTICIPANT	\N	PRESENT	0
197191	190783	98005N	PARTICIPANT	\N	PRESENT	0
197192	190783	11089X	PARTICIPANT	\N	PRESENT	0
197193	190783	07029T	PARTICIPANT	\N	PRESENT	0
197194	190783	14033T	PARTICIPANT	\N	PRESENT	0
197195	190783	11091R	PARTICIPANT	\N	PRESENT	0
197196	190783	14271U	PARTICIPANT	\N	PRESENT	0
197197	190783	08016S	PARTICIPANT	\N	PRESENT	0
197198	190783	14281W	PARTICIPANT	\N	PRESENT	0
197199	190783	14069U	PARTICIPANT	\N	PRESENT	0
197200	190783	14219Q	PARTICIPANT	\N	PRESENT	0
197201	190783	14197C	PARTICIPANT	\N	PRESENT	0
197202	190783	16813M	PARTICIPANT	\N	PRESENT	0
197203	190783	01056V	PARTICIPANT	\N	PRESENT	0
197204	190783	19251M	PARTICIPANT	\N	PRESENT	0
197205	190783	11027H	PARTICIPANT	\N	PRESENT	0
197206	190783	11097X	PARTICIPANT	\N	PRESENT	0
197207	190783	14159V	PARTICIPANT	\N	PRESENT	0
197208	190783	01027Q	PARTICIPANT	\N	PRESENT	0
197209	190783	11070L	PARTICIPANT	\N	PRESENT	0
197210	190783	10015M	PARTICIPANT	\N	PRESENT	0
197211	190783	11036J	PARTICIPANT	\N	PRESENT	0
197212	190783	14061L	PARTICIPANT	\N	PRESENT	0
197213	190783	08058D	PARTICIPANT	\N	PRESENT	0
197214	190783	14157T	PARTICIPANT	\N	PRESENT	0
197215	190783	95063L	PARTICIPANT	\N	PRESENT	0
197216	190783	11061K	PARTICIPANT	\N	PRESENT	0
197217	190783	08014Q	PARTICIPANT	\N	PRESENT	0
197219	190783	11011M	PARTICIPANT	\N	PRESENT	0
197259	190783	95035G	PARTICIPANT	\N	PRESENT	0
197260	190783	14030Q	PARTICIPANT	\N	PRESENT	0
197261	190783	11099A	PARTICIPANT	\N	PRESENT	0
197262	190783	08039A	PARTICIPANT	\N	PRESENT	0
197263	190783	14329V	PARTICIPANT	\N	PRESENT	0
197264	190783	14269B	PARTICIPANT	\N	PRESENT	0
197265	190783	01031L	PARTICIPANT	\N	PRESENT	0
197266	190783	04071H	PARTICIPANT	\N	PRESENT	0
197267	190783	14073Q	PARTICIPANT	\N	PRESENT	0
197268	190783	11026G	PARTICIPANT	\N	PRESENT	0
197274	190783	04057K	PARTICIPANT	\N	PRESENT	0
197275	190783	11083R	PARTICIPANT	\N	PRESENT	0
197276	190783	14231L	PARTICIPANT	\N	PRESENT	0
197277	190783	14327T	PARTICIPANT	\N	PRESENT	0
197278	190783	11037K	PARTICIPANT	\N	PRESENT	0
192343	190412	01022K	PARTICIPANT	\N	PRESENT	0
192344	190412	05001W	PARTICIPANT	\N	PRESENT	0
197279	190783	14083S	PARTICIPANT	\N	PRESENT	0
197280	190783	01060R	PARTICIPANT	\N	PRESENT	0
197281	190783	14133K	PARTICIPANT	\N	PRESENT	0
197292	190783	08017T	PARTICIPANT	\N	PRESENT	0
197293	190783	04086Q	PARTICIPANT	\N	PRESENT	0
197295	190783	08044W	PARTICIPANT	\N	PRESENT	0
197298	197297	14133K	PARTICIPANT	\N	PRESENT	0
197299	196909	04085P	PARTICIPANT	\N	PRESENT	0
197300	197297	96004D	PRESIDENT	0	PRESENT	0
197301	196909	05008E	PARTICIPANT	\N	PRESENT	0
197302	196909	14069U	PARTICIPANT	\N	PRESENT	0
197303	196909	19251M	PARTICIPANT	\N	PRESENT	0
197304	196909	14215L	PARTICIPANT	\N	PRESENT	0
197305	196909	08018U	PARTICIPANT	\N	PRESENT	0
197306	196909	11026G	PARTICIPANT	\N	PRESENT	0
197307	196909	01028R	PARTICIPANT	\N	PRESENT	0
197308	196909	04044E	PRESIDENT	0	PRESENT	0
197309	196909	11037K	PARTICIPANT	\N	PRESENT	0
197310	190783	19253P	PARTICIPANT	\N	PRESENT	0
197311	197297	11083R	PARTICIPANT	\N	PRESENT	0
197312	197297	14097Y	PARTICIPANT	\N	PRESENT	0
197313	197297	04061F	PARTICIPANT	\N	PRESENT	0
197314	197297	14073Q	PARTICIPANT	\N	PRESENT	0
197315	197297	11026G	PARTICIPANT	\N	PRESENT	0
197316	197297	04057K	PARTICIPANT	\N	PRESENT	0
197317	197297	10015M	PARTICIPANT	\N	PRESENT	0
197318	197297	98035U	PARTICIPANT	\N	PRESENT	0
197319	197297	04034C	PARTICIPANT	\N	PRESENT	0
197324	197297	04045F	PARTICIPANT	\N	EXCUSE	0
197326	197297	14089Y	PARTICIPANT	\N	EXCUSE	0
197335	190783	01046T	PARTICIPANT	\N	PRESENT	0
197336	190783	11043H	PARTICIPANT	\N	PRESENT	0
197337	190783	04056J	PARTICIPANT	\N	PRESENT	0
197340	190783	08034U	PARTICIPANT	\N	PRESENT	0
197341	190783	04066L	PARTICIPANT	\N	PRESENT	0
197342	190783	04034C	PARTICIPANT	\N	PRESENT	0
197343	190783	08024S	PARTICIPANT	\N	PRESENT	0
197344	190783	04080J	PARTICIPANT	\N	PRESENT	0
197412	190784	04066L	PARTICIPANT	\N	PRESENT	0
197414	190784	14231L	PARTICIPANT	\N	PRESENT	0
197415	190784	01013J	PARTICIPANT	\N	PRESENT	0
197416	190784	04085P	PARTICIPANT	\N	PRESENT	0
197417	190784	05008E	PARTICIPANT	\N	PRESENT	0
197418	190784	04044E	PARTICIPANT	\N	PRESENT	0
197419	190784	08014Q	PARTICIPANT	\N	PRESENT	0
197420	190784	14269B	PARTICIPANT	\N	PRESENT	0
197421	190784	11037K	PARTICIPANT	\N	PRESENT	0
197422	190784	08017T	PARTICIPANT	\N	PRESENT	0
197423	190784	11036J	PARTICIPANT	\N	PRESENT	0
197424	190784	14327T	PARTICIPANT	\N	PRESENT	0
197425	190784	14329V	PARTICIPANT	\N	PRESENT	0
197426	190784	14357A	PARTICIPANT	\N	PRESENT	0
197427	190784	07029T	PARTICIPANT	\N	PRESENT	0
197428	190784	11097X	PARTICIPANT	\N	PRESENT	0
197429	190784	19253P	PARTICIPANT	\N	PRESENT	0
197430	190784	14033T	PARTICIPANT	\N	PRESENT	0
197431	190784	04057K	PARTICIPANT	\N	PRESENT	0
197432	190784	14069U	PARTICIPANT	\N	PRESENT	0
197433	190784	11099A	PARTICIPANT	\N	PRESENT	0
197434	190784	11027H	PARTICIPANT	\N	PRESENT	0
197435	190784	14207L	PARTICIPANT	\N	PRESENT	0
197436	190784	11061K	PARTICIPANT	\N	PRESENT	0
197437	190784	01041N	PARTICIPANT	\N	PRESENT	0
197438	190784	04043D	PARTICIPANT	\N	PRESENT	0
197439	190784	11083R	PARTICIPANT	\N	PRESENT	0
197440	190784	16813M	PARTICIPANT	\N	PRESENT	0
197441	190784	99004R	PARTICIPANT	\N	PRESENT	0
197442	190784	01027Q	PARTICIPANT	\N	PRESENT	0
197443	190784	11107G	PARTICIPANT	\N	PRESENT	0
197444	190784	04086Q	PARTICIPANT	\N	PRESENT	0
197445	190784	01028R	PARTICIPANT	\N	PRESENT	0
197446	190784	04088S	PARTICIPANT	\N	PRESENT	0
197447	190784	04035D	PARTICIPANT	\N	PRESENT	0
197452	190784	11011M	PARTICIPANT	\N	PRESENT	0
197453	190784	05012A	PARTICIPANT	\N	PRESENT	0
170234	170233	14133K	PARTICIPANT	\N	PRESENT	0
170235	170233	04054G	PARTICIPANT	\N	PRESENT	0
170236	170233	96004D	PARTICIPANT	\N	PRESENT	0
170237	170233	14089Y	PARTICIPANT	\N	PRESENT	0
170238	170233	14097Y	PARTICIPANT	\N	PRESENT	0
170239	170233	04061F	PARTICIPANT	\N	PRESENT	0
170240	170233	04057K	PARTICIPANT	\N	PRESENT	0
170241	170233	10015M	PARTICIPANT	\N	PRESENT	0
170242	170233	01016M	PARTICIPANT	\N	PRESENT	0
170243	170233	98035U	PARTICIPANT	\N	PRESENT	0
170244	170233	92045V	PARTICIPANT	\N	PRESENT	0
170245	170233	04034C	PARTICIPANT	\N	PRESENT	0
170246	170233	04080J	PARTICIPANT	\N	PRESENT	0
170252	170233	11035H	PARTICIPANT	\N	EXCUSE	0
170253	170233	11083R	PARTICIPANT	\N	EXCUSE	0
170254	170233	04045F	PARTICIPANT	\N	EXCUSE	0
170273	170272	98053W	PARTICIPANT	\N	PRESENT	0
172578	172226	97011G	PARTICIPANT	\N	PRESENT	0
173613	173611	01013J	PARTICIPANT	\N	PRESENT	0
173614	173611	11053K	PARTICIPANT	\N	PRESENT	0
173615	173611	11080N	PARTICIPANT	\N	PRESENT	0
173616	173611	01027Q	PRESIDENT	0	PRESENT	0
173617	173611	01057W	PARTICIPANT	\N	PRESENT	0
173618	173611	14159V	PARTICIPANT	\N	PRESENT	0
173619	173611	92039X	PARTICIPANT	\N	PRESENT	0
173620	173611	14225N	PARTICIPANT	\N	PRESENT	0
173621	173611	14157T	PARTICIPANT	\N	PRESENT	0
173628	173611	11012A	PARTICIPANT	\N	EXCUSE	0
173638	173637	14089Y	PARTICIPANT	\N	EXCUSE	0
173639	173637	11029K	PARTICIPANT	\N	PRESENT	0
173640	173637	14207L	PRESIDENT	0	PRESENT	0
173641	173637	11023D	PARTICIPANT	\N	PRESENT	0
173642	173637	14079W	PARTICIPANT	\N	PRESENT	0
173643	173637	14087W	PARTICIPANT	\N	PRESENT	0
173644	173637	11061K	PARTICIPANT	\N	PRESENT	0
173645	173637	14031R	PARTICIPANT	\N	PRESENT	0
173646	173637	11014C	PARTICIPANT	\N	PRESENT	0
173647	173637	14053L	PARTICIPANT	\N	EXCUSE	0
174032	165166	04045F	PARTICIPANT	\N	PRESENT	0
175544	175543	05008E	PRESIDENT	0	PRESENT	0
175573	175572	05008E	PRESIDENT	0	PRESENT	0
175546	175543	11034G	PARTICIPANT	\N	PRESENT	0
175574	175572	11049P	PARTICIPANT	\N	PRESENT	0
175548	175543	11084S	PARTICIPANT	\N	PRESENT	0
175575	175572	08047A	PARTICIPANT	\N	PRESENT	0
175576	175572	14275Y	PARTICIPANT	\N	PRESENT	0
175551	175543	04074L	PARTICIPANT	\N	PRESENT	0
175577	175572	11084S	PARTICIPANT	\N	PRESENT	0
175553	175543	14275Y	PARTICIPANT	\N	PRESENT	0
175578	175572	11037K	PARTICIPANT	\N	PRESENT	0
175555	175543	11037K	PARTICIPANT	\N	PRESENT	0
175579	175572	04085P	PARTICIPANT	\N	PRESENT	0
175580	175572	04047H	PARTICIPANT	\N	PRESENT	0
175581	175572	14041T	PARTICIPANT	\N	PRESENT	0
182793	182792	05008E	PARTICIPANT	\N	PRESENT	0
182795	182794	05008E	PARTICIPANT	\N	PRESENT	0
185033	185032	14089Y	PARTICIPANT	\N	PRESENT	0
185034	185032	14207L	PRESIDENT	0	PRESENT	0
185035	185032	11029K	PARTICIPANT	\N	PRESENT	0
185036	185032	14053L	PARTICIPANT	\N	PRESENT	0
185037	185032	14281W	PARTICIPANT	\N	PRESENT	0
185038	185032	14087W	PARTICIPANT	\N	PRESENT	0
185039	185032	11061K	PARTICIPANT	\N	PRESENT	0
185040	185032	95035G	PARTICIPANT	\N	PRESENT	0
185041	185032	04057K	PARTICIPANT	\N	EXCUSE	0
185042	185032	14031R	PARTICIPANT	\N	EXCUSE	0
185043	185032	14237S	PARTICIPANT	\N	EXCUSE	0
185044	185032	14065Q	PARTICIPANT	\N	EXCUSE	0
185045	185032	04089T	PARTICIPANT	\N	EXCUSE	0
185046	185032	11014C	PARTICIPANT	\N	EXCUSE	0
185052	185032	14231L	PARTICIPANT	\N	EXCUSE	0
185054	185053	14089Y	PARTICIPANT	\N	PRESENT	0
185055	185053	14207L	PRESIDENT	0	PRESENT	0
185056	185053	04057K	PARTICIPANT	\N	EXCUSE	0
185057	185053	14031R	PARTICIPANT	\N	EXCUSE	0
185058	185053	11014C	PARTICIPANT	\N	EXCUSE	0
185059	185053	04089T	PARTICIPANT	\N	EXCUSE	0
189365	189364	95059Q	PARTICIPANT	\N	PRESENT	0
189366	189364	14193X	PARTICIPANT	\N	PRESENT	0
189367	189364	11106F	PARTICIPANT	\N	PRESENT	0
189368	189364	08047A	PARTICIPANT	\N	PRESENT	0
189369	189364	04080J	PARTICIPANT	\N	PRESENT	0
189370	189364	01014K	PARTICIPANT	\N	PRESENT	0
189371	189364	04040A	PARTICIPANT	\N	PRESENT	0
189372	189364	14133K	PARTICIPANT	\N	PRESENT	0
189373	189364	11054L	PARTICIPANT	\N	PRESENT	0
189392	188952	08065C	PARTICIPANT	\N	EXCUSE	0
189393	188952	01022K	PARTICIPANT	\N	EXCUSE	0
189394	188952	11072N	PARTICIPANT	\N	EXCUSE	0
189633	189632	04070G	PARTICIPANT	\N	PRESENT	0
190367	189413	14255U	PARTICIPANT	\N	PRESENT	0
191458	190412	14053L	PARTICIPANT	\N	EXCUSE	0
191459	190412	11054L	PARTICIPANT	\N	EXCUSE	0
191460	190412	95062K	PARTICIPANT	\N	EXCUSE	0
197321	192772	04086Q	PARTICIPANT	\N	PRESENT	0
197322	192772	14327T	PARTICIPANT	\N	PRESENT	0
197323	192772	11034G	PARTICIPANT	\N	EXCUSE	0
197325	192772	14071N	PARTICIPANT	\N	PRESENT	0
197327	192772	05012A	PARTICIPANT	\N	PRESENT	0
197328	192772	04045F	PARTICIPANT	\N	PRESENT	0
197329	192772	11037K	PARTICIPANT	\N	PRESENT	0
197330	192772	14231L	PARTICIPANT	\N	PRESENT	0
197333	197332	11043H	PARTICIPANT	\N	PRESENT	0
197334	197332	14235Q	PARTICIPANT	\N	PRESENT	0
197339	197338	11043H	PARTICIPANT	\N	PRESENT	0
202155	201055	04086Q	PARTICIPANT	\N	PRESENT	0
202156	201055	14083S	PARTICIPANT	\N	PRESENT	0
202157	201055	01031L	PRESIDENT	0	PRESENT	0
202158	201055	11048N	PARTICIPANT	\N	PRESENT	0
202159	201055	11083R	PARTICIPANT	\N	PRESENT	0
202160	201055	08010L	PARTICIPANT	\N	PRESENT	0
202161	201055	89017R	PARTICIPANT	\N	PRESENT	0
202162	201055	14225N	PARTICIPANT	\N	PRESENT	0
202163	201055	01013J	PARTICIPANT	\N	PRESENT	0
202164	201055	14173T	PARTICIPANT	\N	PRESENT	0
202165	201055	11012A	PARTICIPANT	\N	EXCUSE	0
202166	201055	98053W	PARTICIPANT	\N	EXCUSE	0
202167	200372	98035U	PARTICIPANT	\N	PRESENT	0
202168	200372	14111D	PARTICIPANT	\N	PRESENT	0
202169	200372	11026G	PARTICIPANT	\N	PRESENT	0
202170	200372	19253P	PARTICIPANT	\N	PRESENT	0
202171	200372	19251M	PARTICIPANT	\N	PRESENT	0
202172	200372	01024M	PARTICIPANT	\N	PRESENT	0
202173	200372	04044E	PARTICIPANT	\N	PRESENT	0
202174	200372	04047H	PARTICIPANT	\N	PRESENT	0
202175	200372	95063L	PARTICIPANT	\N	PRESENT	0
202176	200372	04074L	PARTICIPANT	\N	PRESENT	0
202177	200372	04056J	PARTICIPANT	\N	PRESENT	0
202178	200372	14041T	PARTICIPANT	\N	PRESENT	0
202179	200372	08044W	PARTICIPANT	\N	PRESENT	0
202180	200372	14147R	PARTICIPANT	\N	PRESENT	0
202181	200372	14215L	PARTICIPANT	\N	PRESENT	0
202182	200372	14259Y	PARTICIPANT	\N	PRESENT	0
202183	200372	95049N	PARTICIPANT	\N	PRESENT	0
202184	200372	11056N	PARTICIPANT	\N	EXCUSE	0
202185	200372	08018U	PARTICIPANT	\N	EXCUSE	0
202186	201055	08061X	PARTICIPANT	\N	PRESENT	0
202187	201055	11088W	PARTICIPANT	\N	PRESENT	0
202188	201055	08034U	PARTICIPANT	\N	PRESENT	0
202189	201055	01016M	PARTICIPANT	\N	PRESENT	0
202190	201055	14159V	PARTICIPANT	\N	PRESENT	0
202191	201055	11057P	PARTICIPANT	\N	PRESENT	0
202192	200633	14151M	PARTICIPANT	\N	PRESENT	0
202193	200372	14069U	PARTICIPANT	\N	PRESENT	0
202252	201055	11068S	PARTICIPANT	\N	PRESENT	0
202272	200633	14227Q	PARTICIPANT	\N	PRESENT	0
202273	200633	14269B	PARTICIPANT	\N	PRESENT	0
202274	200633	14281W	PARTICIPANT	\N	PRESENT	0
202275	200633	01011G	PARTICIPANT	\N	PRESENT	0
202276	200633	04081K	PARTICIPANT	\N	PRESENT	0
202292	201055	08011M	PARTICIPANT	\N	PRESENT	0
202293	201055	11070L	PARTICIPANT	\N	PRESENT	0
202312	201055	11053K	PARTICIPANT	\N	PRESENT	0
202313	201055	14199E	PARTICIPANT	\N	PRESENT	0
202372	200633	11093T	PARTICIPANT	\N	EXCUSE	0
202373	200633	11112D	PARTICIPANT	\N	EXCUSE	0
202412	190801	08055A	PARTICIPANT	\N	PRESENT	0
202432	190801	01059Y	PARTICIPANT	\N	PRESENT	0
202433	190801	14227Q	PARTICIPANT	\N	PRESENT	0
202434	190801	11077T	PARTICIPANT	\N	PRESENT	0
202435	190801	08060W	PARTICIPANT	\N	PRESENT	0
202436	190801	11109J	PARTICIPANT	\N	PRESENT	0
202437	190801	11095V	PARTICIPANT	\N	PRESENT	0
202438	190801	08052W	PARTICIPANT	\N	PRESENT	0
202439	190801	04092N	PARTICIPANT	\N	PRESENT	0
205977	205738	04085P	PARTICIPANT	\N	PRESENT	0
205978	205738	08055A	PARTICIPANT	\N	PRESENT	0
205979	205738	14093U	PARTICIPANT	\N	PRESENT	0
205980	205738	19549D	PARTICIPANT	\N	PRESENT	0
205982	205738	08060W	PARTICIPANT	\N	PRESENT	0
205983	205738	19733B	PARTICIPANT	\N	PRESENT	0
205984	205738	19383Y	PARTICIPANT	\N	PRESENT	0
205985	205738	08024S	PARTICIPANT	\N	PRESENT	0
205987	205738	18083K	PARTICIPANT	\N	PRESENT	0
205989	205738	19681G	PARTICIPANT	\N	PRESENT	0
205990	205738	98023Q	PARTICIPANT	\N	PRESENT	0
205991	205738	19525U	PARTICIPANT	\N	PRESENT	0
205992	205738	11065P	PARTICIPANT	\N	PRESENT	0
205993	205738	19659J	PARTICIPANT	\N	PRESENT	0
205994	205738	19599P	PARTICIPANT	\N	PRESENT	0
205995	205738	02002K	PARTICIPANT	\N	PRESENT	0
205996	205738	15447F	PARTICIPANT	\N	PRESENT	0
205997	205738	19387D	PARTICIPANT	\N	PRESENT	0
205998	205738	19347U	PARTICIPANT	\N	PRESENT	0
206425	205738	19701S	PARTICIPANT	\N	PRESENT	0
206001	205738	19333N	PARTICIPANT	\N	PRESENT	0
206002	205738	04097T	PARTICIPANT	\N	PRESENT	0
206003	205738	19551W	PARTICIPANT	\N	PRESENT	0
206004	205738	14029X	PARTICIPANT	\N	PRESENT	0
206005	205738	19677L	PARTICIPANT	\N	PRESENT	0
210155	210154	08034U	PARTICIPANT	\N	PRESENT	0
206007	205738	14219Q	PARTICIPANT	\N	PRESENT	0
206008	205738	14103D	PARTICIPANT	\N	PRESENT	0
206009	205738	80027E	PRESIDENT	0	PRESENT	0
206010	205738	14031R	PARTICIPANT	\N	PRESENT	0
206011	205738	19637C	PARTICIPANT	\N	PRESENT	0
206012	205738	08009T	PRESIDENT	1	PRESENT	0
206013	205738	14221J	PARTICIPANT	\N	PRESENT	0
206014	205738	14169X	PARTICIPANT	\N	PRESENT	0
210812	210098	04042C	PRESIDENT	0	PRESENT	0
206016	205738	14237S	PARTICIPANT	\N	PRESENT	0
206017	205738	17637T	PARTICIPANT	\N	PRESENT	0
206018	205738	05012A	PARTICIPANT	\N	PRESENT	0
206019	205738	19503N	PARTICIPANT	\N	PRESENT	0
206020	205738	17583W	PARTICIPANT	\N	PRESENT	0
206021	205738	95062K	PARTICIPANT	\N	PRESENT	0
206022	205738	19713W	PARTICIPANT	\N	PRESENT	0
206023	205738	14051J	PARTICIPANT	\N	PRESENT	0
206024	205738	14157T	PARTICIPANT	\N	PRESENT	0
206025	205738	19737F	PARTICIPANT	\N	PRESENT	0
210813	210098	11054L	PARTICIPANT	\N	PRESENT	0
210814	210098	11066Q	PARTICIPANT	\N	PRESENT	0
210815	210098	08056B	PARTICIPANT	\N	PRESENT	0
210816	210098	19421M	PARTICIPANT	\N	PRESENT	0
210817	210098	19709B	PARTICIPANT	\N	PRESENT	0
210818	210098	14193X	PARTICIPANT	\N	PRESENT	0
210819	210098	97011G	PARTICIPANT	\N	PRESENT	0
210820	210098	08047A	PARTICIPANT	\N	PRESENT	0
210821	210098	98029W	PARTICIPANT	\N	PRESENT	0
210822	210098	14097Y	PARTICIPANT	\N	PRESENT	0
210823	210098	19647E	PARTICIPANT	\N	PRESENT	0
210824	210098	01062T	PARTICIPANT	\N	PRESENT	0
210825	210098	11041F	PARTICIPANT	\N	PRESENT	0
210826	210098	14235Q	PARTICIPANT	\N	PRESENT	0
210827	210098	08058D	PARTICIPANT	\N	PRESENT	0
210828	210098	14028W	PARTICIPANT	\N	PRESENT	0
210829	210098	19319Q	PARTICIPANT	\N	PRESENT	0
210830	210098	98022P	PARTICIPANT	\N	PRESENT	0
210831	210098	14267Y	PARTICIPANT	\N	PRESENT	0
210832	210098	98050T	PARTICIPANT	\N	PRESENT	0
210833	210098	14255U	PARTICIPANT	\N	PRESENT	0
210834	210098	08053X	PARTICIPANT	\N	PRESENT	0
210835	210098	19251M	PARTICIPANT	\N	PRESENT	0
210836	207686	19253P	PARTICIPANT	\N	PRESENT	0
210837	207686	14147R	PARTICIPANT	\N	PRESENT	0
210838	207686	18083K	PARTICIPANT	\N	PRESENT	0
210839	207686	14061L	PARTICIPANT	\N	PRESENT	0
210840	207686	14201E	PARTICIPANT	\N	PRESENT	0
210841	210098	95037J	PARTICIPANT	\N	PRESENT	0
210842	210098	01058X	PARTICIPANT	\N	PRESENT	0
210843	207686	14073Q	PARTICIPANT	\N	PRESENT	0
210844	207686	19575F	PARTICIPANT	\N	PRESENT	0
210845	210098	08061X	PARTICIPANT	\N	PRESENT	0
210846	210098	95067Q	PARTICIPANT	\N	PRESENT	0
210847	207686	14031R	PARTICIPANT	\N	PRESENT	0
210848	207686	04057K	PARTICIPANT	\N	PRESENT	0
210849	210098	04035D	PARTICIPANT	\N	PRESENT	0
210982	210182	19383Y	PARTICIPANT	\N	PRESENT	0
210983	210182	01043Q	PARTICIPANT	\N	PRESENT	0
210984	210182	14357A	PARTICIPANT	\N	PRESENT	0
210985	210182	19441R	PARTICIPANT	\N	PRESENT	0
210986	210182	19413M	PARTICIPANT	\N	PRESENT	0
210987	210182	80013X	PARTICIPANT	\N	PRESENT	0
210988	210182	19631V	PARTICIPANT	\N	PRESENT	0
210989	210182	11099A	PARTICIPANT	\N	PRESENT	0
210990	210182	08068F	PARTICIPANT	\N	PRESENT	0
210991	210182	04049K	PRESIDENT	1	PRESENT	0
210992	210182	19705W	PARTICIPANT	\N	PRESENT	0
210993	210182	19707Y	PARTICIPANT	\N	PRESENT	0
210994	210182	08015R	PARTICIPANT	\N	PRESENT	0
210995	210182	08019V	PARTICIPANT	\N	PRESENT	0
210996	210182	14197C	PARTICIPANT	\N	PRESENT	0
210997	210182	19369B	PARTICIPANT	\N	PRESENT	0
210998	210182	19511N	PARTICIPANT	\N	PRESENT	0
210999	210182	08028W	PARTICIPANT	\N	PRESENT	0
211000	210182	19563B	PARTICIPANT	\N	PRESENT	0
211001	210182	14265W	PARTICIPANT	\N	PRESENT	0
211002	210182	14329V	PARTICIPANT	\N	PRESENT	0
211003	210182	19591F	PARTICIPANT	\N	PRESENT	0
211004	210182	14135M	PARTICIPANT	\N	PRESENT	0
211005	210182	19467C	PARTICIPANT	\N	PRESENT	0
211006	210182	08038Y	PARTICIPANT	\N	PRESENT	0
211007	210182	08062Y	PARTICIPANT	\N	PRESENT	0
211008	210182	19695N	PARTICIPANT	\N	PRESENT	0
211009	210182	19301E	PARTICIPANT	\N	PRESENT	0
211010	210182	14033T	PARTICIPANT	\N	PRESENT	0
211011	210182	11090Q	PRESIDENT	0	PRESENT	0
211012	210182	01025N	PARTICIPANT	\N	PRESENT	0
211013	210182	19269X	PARTICIPANT	\N	PRESENT	0
211014	210182	14205J	PARTICIPANT	\N	PRESENT	0
211015	210182	04088S	PARTICIPANT	\N	PRESENT	0
211016	210182	14115H	PARTICIPANT	\N	PRESENT	0
211017	210182	11101A	PARTICIPANT	\N	PRESENT	0
211018	210182	19507S	PARTICIPANT	\N	PRESENT	0
211019	210182	14207L	PARTICIPANT	\N	PRESENT	0
211020	210182	19619A	PARTICIPANT	\N	PRESENT	0
211021	210182	14257W	PARTICIPANT	\N	PRESENT	0
211022	210182	14081Q	PARTICIPANT	\N	EXCUSE	0
211023	210182	04043D	PARTICIPANT	\N	EXCUSE	0
211024	210182	04089T	PARTICIPANT	\N	EXCUSE	0
211025	210182	14187A	PARTICIPANT	\N	EXCUSE	0
211026	210145	11048N	PARTICIPANT	\N	PRESENT	0
167493	167492	14033T	PARTICIPANT	\N	PRESENT	0
167495	167494	14033T	PARTICIPANT	\N	PRESENT	0
167497	167496	14033T	PARTICIPANT	\N	PRESENT	0
167513	167512	14033T	PARTICIPANT	\N	PRESENT	0
167533	167532	08055A	PARTICIPANT	\N	PRESENT	0
167534	167532	14207L	PARTICIPANT	\N	PRESENT	0
167535	167532	90003B	PARTICIPANT	\N	PRESENT	0
167536	167532	14038Y	PARTICIPANT	\N	PRESENT	0
167537	167532	88008L	PARTICIPANT	\N	PRESENT	0
167538	167532	11027H	PARTICIPANT	\N	PRESENT	0
167539	167532	80013X	PARTICIPANT	\N	PRESENT	0
167540	167532	87003B	PARTICIPANT	\N	PRESENT	0
167541	167532	95037J	PARTICIPANT	\N	PRESENT	0
167542	167532	14061L	PARTICIPANT	\N	PRESENT	0
167543	167532	04049K	PARTICIPANT	\N	PRESENT	0
167544	167532	08015R	PARTICIPANT	\N	PRESENT	0
167545	167532	08010L	PARTICIPANT	\N	PRESENT	0
167546	167532	80027E	PARTICIPANT	\N	PRESENT	0
167547	167532	08053X	PARTICIPANT	\N	PRESENT	0
167548	167532	04092N	PARTICIPANT	\N	PRESENT	0
167549	167532	14109K	PARTICIPANT	\N	PRESENT	0
167550	167532	14257W	PARTICIPANT	\N	PRESENT	0
167551	167532	05012A	PARTICIPANT	\N	PRESENT	0
167552	167532	11097X	PARTICIPANT	\N	PRESENT	0
167553	167532	11094U	PARTICIPANT	\N	PRESENT	0
167555	167554	14193X	PARTICIPANT	\N	PRESENT	0
167556	167554	04088S	PARTICIPANT	\N	PRESENT	0
167557	167554	11046L	PARTICIPANT	\N	PRESENT	0
167558	167554	01058X	PARTICIPANT	\N	PRESENT	0
173950	173949	14219Q	PRESIDENT	0	PRESENT	0
173951	173949	11065P	PARTICIPANT	\N	PRESENT	0
173952	173949	01008M	PARTICIPANT	\N	PRESENT	0
173953	173949	80013X	PARTICIPANT	\N	PRESENT	0
173954	173949	92045V	PARTICIPANT	\N	PRESENT	0
173955	173949	14093U	PARTICIPANT	\N	PRESENT	0
173956	173949	08049C	PARTICIPANT	\N	EXCUSE	0
173957	173949	09001P	PARTICIPANT	\N	EXCUSE	0
173974	173973	14219Q	PRESIDENT	0	PRESENT	0
173975	173973	11065P	PARTICIPANT	\N	PRESENT	0
173976	173973	01008M	PARTICIPANT	\N	PRESENT	0
173977	173973	92045V	PARTICIPANT	\N	EXCUSE	0
173978	173973	08049C	PARTICIPANT	\N	EXCUSE	0
173979	173973	09001P	PARTICIPANT	\N	EXCUSE	0
174073	174072	14219Q	PRESIDENT	0	PRESENT	0
173984	173981	11065P	PARTICIPANT	\N	PRESENT	0
174033	173981	14093U	PARTICIPANT	\N	PRESENT	0
174034	173973	01015L	PARTICIPANT	\N	EXCUSE	0
174052	173973	14093U	PARTICIPANT	\N	PRESENT	0
174074	174072	11065P	PARTICIPANT	\N	PRESENT	0
174075	174072	14093U	PARTICIPANT	\N	PRESENT	0
174076	174072	01015L	PARTICIPANT	\N	EXCUSE	0
174077	174072	08049C	PARTICIPANT	\N	EXCUSE	0
174078	174072	92045V	PARTICIPANT	\N	EXCUSE	0
177518	177517	95015C	PARTICIPANT	\N	PRESENT	0
178252	178235	14065Q	PARTICIPANT	\N	PRESENT	0
178253	178235	11029K	PARTICIPANT	\N	PRESENT	0
178254	178235	14281W	PARTICIPANT	\N	PRESENT	0
178255	178235	11061K	PARTICIPANT	\N	PRESENT	0
178256	178235	14135M	PARTICIPANT	\N	PRESENT	0
178257	178235	14229S	PARTICIPANT	\N	PRESENT	0
178258	178235	04050C	PARTICIPANT	\N	PRESENT	0
178332	178235	14089Y	PARTICIPANT	\N	EXCUSE	0
178333	178235	14207L	PARTICIPANT	\N	PRESENT	0
178334	178235	11014C	PARTICIPANT	\N	EXCUSE	0
178633	178632	14239U	PARTICIPANT	\N	PRESENT	0
178634	178632	11055M	PARTICIPANT	\N	EXCUSE	0
179433	179432	14133K	PARTICIPANT	\N	PRESENT	0
178636	178632	08043V	PARTICIPANT	\N	PRESENT	0
178637	178632	08024S	PARTICIPANT	\N	PRESENT	0
179434	179432	04040A	PARTICIPANT	\N	PRESENT	0
178639	178632	11031D	PARTICIPANT	\N	PRESENT	0
178640	178632	08052W	PARTICIPANT	\N	PRESENT	0
178641	178632	14041T	PARTICIPANT	\N	PRESENT	0
179435	179432	08058D	PARTICIPANT	\N	PRESENT	0
178643	178632	87003B	PARTICIPANT	\N	PRESENT	0
178644	178632	11061K	PARTICIPANT	\N	PRESENT	0
179436	179432	04042C	PRESIDENT	0	PRESENT	0
179437	179432	77002U	PARTICIPANT	\N	PRESENT	0
179438	179432	98029W	PARTICIPANT	\N	PRESENT	0
179439	179432	98018T	PARTICIPANT	\N	PRESENT	0
178649	178632	14223L	PARTICIPANT	\N	PRESENT	0
178650	178632	04092N	PRESIDENT	0	PRESENT	0
178651	178632	14265W	PARTICIPANT	\N	PRESENT	0
178652	178632	14028W	PARTICIPANT	\N	PRESENT	0
178653	178632	14235Q	PARTICIPANT	\N	PRESENT	0
178654	178632	14331P	PARTICIPANT	\N	PRESENT	0
178655	178632	14271U	PARTICIPANT	\N	EXCUSE	0
178656	178632	11097X	PARTICIPANT	\N	PRESENT	0
179440	179432	92020L	PARTICIPANT	\N	PRESENT	0
178658	178632	11094U	PARTICIPANT	\N	PRESENT	0
179441	179432	95030B	PARTICIPANT	\N	PRESENT	0
179442	179432	97011G	PARTICIPANT	\N	PRESENT	0
179443	179432	08065C	PARTICIPANT	\N	PRESENT	0
179444	179432	04035D	PARTICIPANT	\N	PRESENT	0
179445	179432	14014Q	PARTICIPANT	\N	PRESENT	0
179446	179432	07004J	PARTICIPANT	\N	EXCUSE	0
179447	179432	95035G	PARTICIPANT	\N	PRESENT	0
179448	179432	98022P	PARTICIPANT	\N	PRESENT	0
179449	179432	11064N	PARTICIPANT	\N	PRESENT	0
179450	179432	95037J	PARTICIPANT	\N	PRESENT	0
179451	179432	04078Q	PARTICIPANT	\N	PRESENT	0
179452	179432	14097Y	PARTICIPANT	\N	PRESENT	0
179453	179432	95041E	PARTICIPANT	\N	PRESENT	0
179454	179432	04036E	PARTICIPANT	\N	PRESENT	0
179455	179432	92031P	PARTICIPANT	\N	PRESENT	0
179456	179432	14251Q	PARTICIPANT	\N	PRESENT	0
179457	179432	11082Q	PARTICIPANT	\N	PRESENT	0
179458	179432	11105E	PARTICIPANT	\N	EXCUSE	0
179459	179432	14253S	PARTICIPANT	\N	PRESENT	0
179460	179432	08047A	PARTICIPANT	\N	PRESENT	0
179461	179432	14028W	PARTICIPANT	\N	PRESENT	0
179462	179432	14193X	PARTICIPANT	\N	PRESENT	0
179463	179432	98021N	PARTICIPANT	\N	EXCUSE	0
179464	179432	04080J	PARTICIPANT	\N	PRESENT	0
179465	179432	95059Q	PARTICIPANT	\N	EXCUSE	0
179466	179432	86044G	PARTICIPANT	\N	EXCUSE	0
179467	179432	01014K	PARTICIPANT	\N	PRESENT	0
179468	179432	11054L	PARTICIPANT	\N	PRESENT	0
179469	179432	08049C	PARTICIPANT	\N	EXCUSE	0
181055	181052	11029K	PARTICIPANT	\N	PRESENT	0
181056	181052	14014Q	PARTICIPANT	\N	PRESENT	0
181057	181052	07026Q	PARTICIPANT	\N	PRESENT	0
181058	181052	09001P	PRESIDENT	0	PRESENT	0
181059	181052	14031R	PARTICIPANT	\N	PRESENT	0
181060	181052	11067R	PARTICIPANT	\N	PRESENT	0
181061	181052	11014C	PARTICIPANT	\N	PRESENT	0
181062	181052	14109K	PARTICIPANT	\N	PRESENT	0
181093	181092	14219Q	PRESIDENT	0	PRESENT	0
181094	181092	11065P	PARTICIPANT	\N	PRESENT	0
181095	181092	14093U	PARTICIPANT	\N	PRESENT	0
181096	181092	80013X	PARTICIPANT	\N	PRESENT	0
181097	181092	14033T	PARTICIPANT	\N	PRESENT	0
181098	181092	05012A	PARTICIPANT	\N	PRESENT	0
181099	181092	01008M	PARTICIPANT	\N	PRESENT	0
181053	181052	08043V	PARTICIPANT	\N	PRESENT	0
181054	181052	08060W	PARTICIPANT	\N	EXCUSE	0
181100	181092	11035H	PARTICIPANT	\N	EXCUSE	0
181101	181092	09001P	PARTICIPANT	\N	EXCUSE	0
181102	181092	01015L	PARTICIPANT	\N	EXCUSE	0
181103	181092	92045V	PARTICIPANT	\N	PRESENT	0
181434	176295	08016S	PARTICIPANT	\N	EXCUSE	0
181572	176294	08016S	PARTICIPANT	\N	EXCUSE	0
182193	182192	08060W	PARTICIPANT	\N	PRESENT	0
182194	182192	14107H	PARTICIPANT	\N	PRESENT	0
182195	182192	11107G	PARTICIPANT	\N	PRESENT	0
182196	182192	95062K	PARTICIPANT	\N	PRESENT	0
182197	182192	08009T	PARTICIPANT	\N	PRESENT	0
182597	182580	08049C	PARTICIPANT	\N	PRESENT	0
182598	182580	01056V	PARTICIPANT	\N	EXCUSE	0
182599	182580	92045V	PARTICIPANT	\N	PRESENT	0
182600	182580	01015L	PARTICIPANT	\N	EXCUSE	0
182602	182580	14033T	PARTICIPANT	\N	EXCUSE	0
182603	182580	09001P	PARTICIPANT	\N	EXCUSE	0
182633	182632	05008E	PARTICIPANT	\N	PRESENT	0
182634	182632	14065Q	PARTICIPANT	\N	PRESENT	0
182636	182635	05008E	PARTICIPANT	\N	PRESENT	0
182637	182635	14065Q	PARTICIPANT	\N	PRESENT	0
182713	182712	14133K	PARTICIPANT	\N	PRESENT	0
182714	182712	08024S	PARTICIPANT	\N	PRESENT	0
182824	182823	08011M	PARTICIPANT	\N	PRESENT	0
183377	183375	05008E	PARTICIPANT	\N	PRESENT	0
183383	183382	05008E	PARTICIPANT	\N	PRESENT	0
183385	183384	05008E	PARTICIPANT	\N	PRESENT	0
183533	183532	98042T	PARTICIPANT	\N	PRESENT	0
183534	183532	01019Q	PARTICIPANT	\N	PRESENT	0
187013	187012	01034P	PARTICIPANT	\N	PRESENT	0
197456	190784	04038G	PARTICIPANT	\N	PRESENT	0
197461	190784	11091R	PARTICIPANT	\N	PRESENT	0
197464	190784	11026G	PARTICIPANT	\N	PRESENT	0
197492	190784	01031L	PARTICIPANT	\N	PRESENT	0
198132	190786	01016M	PARTICIPANT	\N	PRESENT	0
198792	192732	14135M	PARTICIPANT	\N	PRESENT	0
198793	192732	14239U	PARTICIPANT	\N	PRESENT	0
198794	192732	11083R	PARTICIPANT	\N	PRESENT	0
198795	192732	14030Q	PARTICIPANT	\N	PRESENT	0
198796	192732	95062K	PARTICIPANT	\N	PRESENT	0
198797	192732	14363X	PARTICIPANT	\N	PRESENT	0
198812	196738	08056B	PARTICIPANT	\N	EXCUSE	0
199193	199192	11027H	PARTICIPANT	\N	PRESENT	0
199194	199192	04036E	PARTICIPANT	\N	PRESENT	0
199195	199192	04070G	PARTICIPANT	\N	PRESENT	0
197454	190784	95035G	PARTICIPANT	\N	PRESENT	0
197455	190784	04036E	PARTICIPANT	\N	PRESENT	0
199196	199192	04088S	PARTICIPANT	\N	PRESENT	0
199197	199192	95067Q	PARTICIPANT	\N	PRESENT	0
199198	199192	04077P	PARTICIPANT	\N	PRESENT	0
199352	195879	14030Q	PARTICIPANT	\N	PRESENT	0
199353	195879	08060W	PARTICIPANT	\N	PRESENT	0
199354	195879	08043V	PARTICIPANT	\N	PRESENT	0
199355	195879	11029K	PARTICIPANT	\N	PRESENT	0
199356	195879	14038Y	PARTICIPANT	\N	EXCUSE	0
199357	195879	11031D	PARTICIPANT	\N	PRESENT	0
199358	195879	11027H	PARTICIPANT	\N	PRESENT	0
199359	195879	80013X	PARTICIPANT	\N	PRESENT	0
199372	195879	12042Y	PARTICIPANT	\N	PRESENT	0
199373	195879	14187A	PARTICIPANT	\N	PRESENT	0
199374	195879	04035D	PARTICIPANT	\N	PRESENT	0
199375	195879	11061K	PARTICIPANT	\N	EXCUSE	0
199376	195879	95035G	PARTICIPANT	\N	PRESENT	0
199377	195879	04036E	PARTICIPANT	\N	PRESENT	0
199378	195879	08031R	PARTICIPANT	\N	PRESENT	0
199379	195879	08017T	PARTICIPANT	\N	PRESENT	0
199380	195879	14031R	PARTICIPANT	\N	EXCUSE	0
199381	195879	11067R	PARTICIPANT	\N	PRESENT	0
199382	195879	14265W	PARTICIPANT	\N	EXCUSE	0
199383	195879	11045K	PARTICIPANT	\N	PRESENT	0
199384	195879	14109K	PARTICIPANT	\N	PRESENT	0
199499	190791	01056V	PARTICIPANT	\N	PRESENT	0
199500	190791	01027Q	PARTICIPANT	\N	PRESENT	0
199501	190791	04097T	PARTICIPANT	\N	PRESENT	0
199502	190791	77002U	PARTICIPANT	\N	PRESENT	0
199503	190791	04041B	PARTICIPANT	\N	PRESENT	0
199504	190791	14123H	PARTICIPANT	\N	PRESENT	0
199505	190791	11080N	PARTICIPANT	\N	PRESENT	0
199506	190791	14111D	PARTICIPANT	\N	PRESENT	0
199507	190791	14363X	PARTICIPANT	\N	PRESENT	0
199508	190791	92031P	PARTICIPANT	\N	PRESENT	0
199509	190791	11100Y	PARTICIPANT	\N	PRESENT	0
199510	190791	05012A	PARTICIPANT	\N	PRESENT	0
199511	190791	14331P	PARTICIPANT	\N	PRESENT	0
199512	190791	04074L	PARTICIPANT	\N	PRESENT	0
199513	190791	11088W	PARTICIPANT	\N	PRESENT	0
199514	190791	95062K	PARTICIPANT	\N	PRESENT	0
199515	190791	14193X	PARTICIPANT	\N	PRESENT	0
199516	190791	14053L	PARTICIPANT	\N	PRESENT	0
199517	190791	08042U	PARTICIPANT	\N	PRESENT	0
199518	190791	98018T	PARTICIPANT	\N	PRESENT	0
199519	190791	95041E	PARTICIPANT	\N	PRESENT	0
199520	190791	14195A	PARTICIPANT	\N	PRESENT	0
199521	190791	07029T	PARTICIPANT	\N	PRESENT	0
199522	190791	11048N	PARTICIPANT	\N	PRESENT	0
199523	190791	14038Y	PARTICIPANT	\N	PRESENT	0
199524	190791	98024R	PARTICIPANT	\N	PRESENT	0
199525	190791	04035D	PARTICIPANT	\N	PRESENT	0
199526	190791	04086Q	PARTICIPANT	\N	PRESENT	0
199527	190791	14059S	PARTICIPANT	\N	PRESENT	0
199528	190791	14026U	PARTICIPANT	\N	PRESENT	0
199529	190791	11097X	PARTICIPANT	\N	PRESENT	0
199530	190791	14071N	PARTICIPANT	\N	PRESENT	0
199531	190791	01008M	PARTICIPANT	\N	PRESENT	0
199532	190791	14217N	PARTICIPANT	\N	PRESENT	0
199533	190791	14187A	PARTICIPANT	\N	PRESENT	0
199534	190791	99004R	PARTICIPANT	\N	PRESENT	0
199535	190791	08015R	PARTICIPANT	\N	PRESENT	0
199536	190791	08034U	PARTICIPANT	\N	PRESENT	0
199537	190791	14259Y	PARTICIPANT	\N	PRESENT	0
199538	190791	08069G	PARTICIPANT	\N	PRESENT	0
199539	190791	14249W	PARTICIPANT	\N	PRESENT	0
199540	190791	14079W	PARTICIPANT	\N	PRESENT	0
199541	190791	98005N	PARTICIPANT	\N	PRESENT	0
199542	190791	98050T	PARTICIPANT	\N	PRESENT	0
199543	190791	14031R	PARTICIPANT	\N	PRESENT	0
199544	190791	04042C	PARTICIPANT	\N	PRESENT	0
199552	190791	04049K	PARTICIPANT	\N	PRESENT	0
199553	190791	08062Y	PARTICIPANT	\N	PRESENT	0
199554	190791	05008E	PARTICIPANT	\N	PRESENT	0
199555	190791	14069U	PARTICIPANT	\N	PRESENT	0
199556	190791	04081K	PARTICIPANT	\N	PRESENT	0
199557	190791	14033T	PARTICIPANT	\N	PRESENT	0
199558	190791	14135M	PARTICIPANT	\N	PRESENT	0
199559	190791	11091R	PARTICIPANT	\N	PRESENT	0
199560	190791	08010L	PARTICIPANT	\N	PRESENT	0
199561	190791	08039A	PARTICIPANT	\N	PRESENT	0
199562	190791	04057K	PARTICIPANT	\N	PRESENT	0
199563	190791	14041T	PARTICIPANT	\N	PRESENT	0
199564	190791	08018U	PARTICIPANT	\N	PRESENT	0
199572	190791	04088S	PARTICIPANT	\N	PRESENT	0
199573	190791	14357A	PARTICIPANT	\N	PRESENT	0
199574	190791	08019V	PARTICIPANT	\N	PRESENT	0
199575	190791	14157T	PARTICIPANT	\N	PRESENT	0
199576	190791	04092N	PARTICIPANT	\N	PRESENT	0
199577	190791	14119M	PARTICIPANT	\N	PRESENT	0
199578	190791	04043D	PARTICIPANT	\N	PRESENT	0
199579	190791	11090Q	PARTICIPANT	\N	PRESENT	0
199580	190791	95035G	PARTICIPANT	\N	PRESENT	0
199592	190791	04085P	PARTICIPANT	\N	PRESENT	0
199593	190791	98053W	PARTICIPANT	\N	PRESENT	0
199594	190791	01013J	PARTICIPANT	\N	PRESENT	0
199595	190791	07026Q	PARTICIPANT	\N	PRESENT	0
199596	190791	12041X	PARTICIPANT	\N	PRESENT	0
199597	190791	11031D	PARTICIPANT	\N	PRESENT	0
199598	190791	01015L	PARTICIPANT	\N	PRESENT	0
199599	190791	11034G	PARTICIPANT	\N	PRESENT	0
199600	190791	11098Y	PARTICIPANT	\N	PRESENT	0
199601	190791	08011M	PARTICIPANT	\N	PRESENT	0
199602	190791	01048V	PARTICIPANT	\N	PRESENT	0
199603	190791	08016S	PARTICIPANT	\N	PRESENT	0
199604	190791	11039M	PARTICIPANT	\N	PRESENT	0
199605	190791	01016M	PARTICIPANT	\N	PRESENT	0
199606	190791	11076S	PARTICIPANT	\N	PRESENT	0
199607	190791	04056J	PARTICIPANT	\N	PRESENT	0
199608	190791	14030Q	PARTICIPANT	\N	PRESENT	0
199609	190791	08053X	PARTICIPANT	\N	PRESENT	0
199610	190791	04040A	PARTICIPANT	\N	PRESENT	0
199611	190791	04059M	PARTICIPANT	\N	PRESENT	0
199612	190791	98046X	PARTICIPANT	\N	PRESENT	0
199613	190791	08052W	PARTICIPANT	\N	PRESENT	0
199614	190791	14255U	PARTICIPANT	\N	PRESENT	0
199615	190791	14083S	PARTICIPANT	\N	PRESENT	0
199616	190791	08055A	PARTICIPANT	\N	PRESENT	0
199617	190791	11027H	PARTICIPANT	\N	PRESENT	0
199618	190791	11053K	PARTICIPANT	\N	PRESENT	0
199619	190791	13002U	PARTICIPANT	\N	PRESENT	0
199620	190791	01011G	PARTICIPANT	\N	PRESENT	0
199621	190791	11070L	PARTICIPANT	\N	PRESENT	0
199622	190791	14159V	PARTICIPANT	\N	PRESENT	0
199623	190791	14327T	PARTICIPANT	\N	PRESENT	0
199624	190791	08060W	PARTICIPANT	\N	PRESENT	0
199625	190791	04061F	PARTICIPANT	\N	PRESENT	0
199626	190791	80013X	PARTICIPANT	\N	PRESENT	0
199627	190791	01022K	PARTICIPANT	\N	PRESENT	0
199628	190791	08068F	PARTICIPANT	\N	PRESENT	0
199629	190791	11105E	PARTICIPANT	\N	PRESENT	0
199630	190791	11089X	PARTICIPANT	\N	PRESENT	0
199631	190791	83047W	PARTICIPANT	\N	PRESENT	0
199632	190791	14034U	PARTICIPANT	\N	PRESENT	0
199633	190791	08058D	PARTICIPANT	\N	PRESENT	0
199634	190791	14231L	PARTICIPANT	\N	PRESENT	0
199635	190791	14085U	PARTICIPANT	\N	PRESENT	0
199636	190791	08056B	PARTICIPANT	\N	PRESENT	0
199637	190791	08017T	PARTICIPANT	\N	PRESENT	0
199638	190791	11077T	PARTICIPANT	\N	PRESENT	0
199639	190791	04079R	PARTICIPANT	\N	PRESENT	0
199640	190791	14073Q	PARTICIPANT	\N	PRESENT	0
199641	190791	14205J	PARTICIPANT	\N	PRESENT	0
199642	190791	14207L	PARTICIPANT	\N	PRESENT	0
199643	190791	14219Q	PARTICIPANT	\N	PRESENT	0
199644	190791	11085T	PARTICIPANT	\N	PRESENT	0
199645	190791	14225N	PARTICIPANT	\N	PRESENT	0
199646	190791	08014Q	PARTICIPANT	\N	PRESENT	0
199647	190791	04070G	PARTICIPANT	\N	PRESENT	0
199648	190791	11059R	PARTICIPANT	\N	PRESENT	0
167417	166235	14157T	PARTICIPANT	\N	PRESENT	0
172880	172879	14133K	PARTICIPANT	\N	PRESENT	0
172881	172879	96004D	PRESIDENT	0	PRESENT	0
172882	172879	04040A	PARTICIPANT	\N	PRESENT	0
172883	172879	04042C	PARTICIPANT	\N	PRESENT	0
172884	172879	11083R	PARTICIPANT	\N	PRESENT	0
172885	172879	14014Q	PARTICIPANT	\N	PRESENT	0
172886	172879	14097Y	PARTICIPANT	\N	PRESENT	0
172887	172879	04061F	PARTICIPANT	\N	PRESENT	0
172888	172879	14001X	PARTICIPANT	\N	PRESENT	0
172889	172879	04057K	PARTICIPANT	\N	EXCUSE	0
172890	172879	95059Q	PRESIDENT	1	PRESENT	0
172891	172879	04034C	PARTICIPANT	\N	PRESENT	0
172893	172892	96004D	PARTICIPANT	\N	PRESENT	0
172894	172892	04040A	PARTICIPANT	\N	PRESENT	0
172895	172892	04042C	PARTICIPANT	\N	PRESENT	0
172899	172892	04061F	PARTICIPANT	\N	PRESENT	0
172897	172892	14014Q	PARTICIPANT	\N	PRESENT	0
172898	172892	14097Y	PARTICIPANT	\N	PRESENT	0
172900	172892	14001X	PARTICIPANT	\N	PRESENT	0
172901	172892	04057K	PARTICIPANT	\N	EXCUSE	0
172902	172892	95059Q	PRESIDENT	0	PRESENT	0
172903	172892	04034C	PARTICIPANT	\N	PRESENT	0
198892	197512	14159V	PARTICIPANT	\N	PRESENT	0
199232	198532	04040A	PRESIDENT	0	PRESENT	0
179473	179470	04059M	PARTICIPANT	\N	PRESENT	0
179474	179470	11039M	PARTICIPANT	\N	PRESENT	0
179475	179470	01044R	PARTICIPANT	\N	PRESENT	0
179476	179470	08043V	PARTICIPANT	\N	PRESENT	0
179477	179470	14089Y	PARTICIPANT	\N	PRESENT	0
179478	179470	14105F	PARTICIPANT	\N	PRESENT	0
179479	179470	11029K	PARTICIPANT	\N	PRESENT	0
199242	198532	04049K	PARTICIPANT	\N	PRESENT	0
179481	179470	92015P	PARTICIPANT	\N	EXCUSE	0
179482	179470	08024S	PARTICIPANT	\N	PRESENT	0
199252	198532	05012A	PARTICIPANT	\N	PRESENT	0
199253	198532	08068F	PARTICIPANT	\N	PRESENT	0
199254	198532	04053F	PARTICIPANT	\N	PRESENT	0
179486	179470	14079W	PARTICIPANT	\N	PRESENT	0
179487	179470	11091R	PARTICIPANT	\N	PRESENT	0
179488	179470	87003B	PARTICIPANT	\N	PRESENT	0
199255	198532	14034U	PARTICIPANT	\N	PRESENT	0
179490	179470	14249W	PARTICIPANT	\N	PRESENT	0
179491	179470	01041N	PARTICIPANT	\N	PRESENT	0
199256	198532	11037K	PARTICIPANT	\N	PRESENT	0
199257	198532	11112D	PARTICIPANT	\N	PRESENT	0
199258	198532	14051J	PARTICIPANT	\N	PRESENT	0
179495	179470	11089X	PARTICIPANT	\N	PRESENT	0
179496	179470	07026Q	PARTICIPANT	\N	PRESENT	0
179497	179470	14123H	PARTICIPANT	\N	PRESENT	0
179498	179470	14179A	PARTICIPANT	\N	PRESENT	0
199259	198532	14151M	PARTICIPANT	\N	PRESENT	0
179500	179470	14241N	PARTICIPANT	\N	PRESENT	0
179501	179470	14061L	PARTICIPANT	\N	PRESENT	0
179502	179470	14073Q	PARTICIPANT	\N	PRESENT	0
179503	179470	08031R	PARTICIPANT	\N	PRESENT	0
199260	198532	19253P	PARTICIPANT	\N	PRESENT	0
179505	179470	08039A	PARTICIPANT	\N	PRESENT	0
179506	179470	08017T	PARTICIPANT	\N	PRESENT	0
179507	179470	14059S	PARTICIPANT	\N	PRESENT	0
179508	179470	08012N	PARTICIPANT	\N	PRESENT	0
179509	179470	14103D	PARTICIPANT	\N	PRESENT	0
179510	179470	11104D	PARTICIPANT	\N	PRESENT	0
179511	179470	14063N	PARTICIPANT	\N	PRESENT	0
179512	179470	04057K	PARTICIPANT	\N	PRESENT	0
179513	179470	11014C	PARTICIPANT	\N	PRESENT	0
179514	179470	14109K	PARTICIPANT	\N	PRESENT	0
179515	179470	04070G	PRESIDENT	0	PRESENT	0
199261	198532	14157T	PARTICIPANT	\N	PRESENT	0
199262	198532	14039A	PARTICIPANT	\N	PRESENT	0
179518	179470	83047W	PARTICIPANT	\N	PRESENT	0
179519	179470	14235Q	PARTICIPANT	\N	PRESENT	0
199264	198532	14205J	PARTICIPANT	\N	PRESENT	0
199266	198532	14030Q	PARTICIPANT	\N	PRESENT	0
179522	179470	14361V	PARTICIPANT	\N	PRESENT	0
179523	179470	14229S	PARTICIPANT	\N	PRESENT	0
179524	179470	14363X	PARTICIPANT	\N	PRESENT	0
179525	179470	11043H	PARTICIPANT	\N	PRESENT	0
199272	198532	14041T	PARTICIPANT	\N	PRESENT	0
199326	198532	04044E	PARTICIPANT	\N	PRESENT	0
200032	199802	08062Y	PARTICIPANT	\N	PRESENT	0
199335	198532	08010L	PARTICIPANT	\N	PRESENT	0
199336	198532	04086Q	PARTICIPANT	\N	PRESENT	0
199337	198532	14231L	PARTICIPANT	\N	PRESENT	0
199338	198532	14083S	PARTICIPANT	\N	PRESENT	0
199339	198532	14069U	PARTICIPANT	\N	PRESENT	0
199350	198532	14071N	PARTICIPANT	\N	PRESENT	0
202440	190801	08031R	PARTICIPANT	\N	PRESENT	0
199805	199802	14093U	PARTICIPANT	\N	PRESENT	0
199806	199802	14030Q	PARTICIPANT	\N	PRESENT	0
199807	199802	96004D	PARTICIPANT	\N	PRESENT	0
199808	199802	08060W	PARTICIPANT	\N	PRESENT	0
202441	190801	11098Y	PARTICIPANT	\N	PRESENT	0
199810	199802	14038Y	PARTICIPANT	\N	PRESENT	0
202492	190801	19251M	PARTICIPANT	\N	PRESENT	0
202493	190801	14039A	PARTICIPANT	\N	PRESENT	0
199813	199802	11065P	PARTICIPANT	\N	PRESENT	0
199814	199802	01015L	PARTICIPANT	\N	PRESENT	0
199815	199802	11107G	PARTICIPANT	\N	PRESENT	0
202494	190801	11100Y	PARTICIPANT	\N	PRESENT	0
199817	199802	02002K	PARTICIPANT	\N	EXCUSE	0
199818	199802	01022K	PARTICIPANT	\N	PRESENT	0
202495	190801	14033T	PARTICIPANT	\N	PRESENT	0
202496	190801	14103D	PARTICIPANT	\N	PRESENT	0
199821	199802	09001P	PARTICIPANT	\N	PRESENT	0
199822	199802	11059R	PARTICIPANT	\N	PRESENT	0
199823	199802	14219Q	PARTICIPANT	\N	PRESENT	0
202497	190801	14073Q	PARTICIPANT	\N	PRESENT	0
202498	190801	11089X	PARTICIPANT	\N	PRESENT	0
199826	199802	08009T	PRESIDENT	0	PRESENT	0
202499	190801	04059M	PARTICIPANT	\N	PRESENT	0
202500	190801	14193X	PARTICIPANT	\N	PRESENT	0
202501	190801	14265W	PARTICIPANT	\N	PRESENT	0
199830	199802	08042U	PARTICIPANT	\N	PRESENT	0
199831	199802	14169X	PARTICIPANT	\N	PRESENT	0
202502	190801	14217N	PARTICIPANT	\N	PRESENT	0
199833	199802	13002U	PARTICIPANT	\N	PRESENT	0
199834	199802	05012A	PARTICIPANT	\N	PRESENT	0
202503	190801	11104D	PARTICIPANT	\N	PRESENT	0
199836	199802	14135M	PARTICIPANT	\N	PRESENT	0
199837	199802	14331P	PARTICIPANT	\N	PRESENT	0
199838	199802	95062K	PARTICIPANT	\N	PRESENT	0
202504	190801	14059S	PARTICIPANT	\N	PRESENT	0
202505	190801	14179A	PARTICIPANT	\N	PRESENT	0
199841	199802	14157T	PARTICIPANT	\N	PRESENT	0
202506	190801	08041T	PARTICIPANT	\N	PRESENT	0
202507	190801	98053W	PARTICIPANT	\N	PRESENT	0
202508	190801	11031D	PARTICIPANT	\N	PRESENT	0
202509	190801	11063M	PARTICIPANT	\N	PRESENT	0
202510	190801	14361V	PARTICIPANT	\N	PRESENT	0
202511	190801	12042Y	PARTICIPANT	\N	PRESENT	0
202512	190801	08043V	PARTICIPANT	\N	PRESENT	0
202513	190801	19253P	PARTICIPANT	\N	PRESENT	0
202514	190801	14034U	PARTICIPANT	\N	PRESENT	0
202515	190801	14026U	PARTICIPANT	\N	PRESENT	0
202516	190801	83047W	PARTICIPANT	\N	PRESENT	0
202517	190801	11061K	PARTICIPANT	\N	PRESENT	0
202518	190801	04053F	PARTICIPANT	\N	PRESENT	0
202519	190801	98024R	PARTICIPANT	\N	PRESENT	0
202520	190801	04045F	PARTICIPANT	\N	PRESENT	0
202521	190801	14269B	PARTICIPANT	\N	PRESENT	0
202522	190801	14281W	PARTICIPANT	\N	PRESENT	0
202523	190801	14097Y	PARTICIPANT	\N	PRESENT	0
202524	190801	14271U	PARTICIPANT	\N	PRESENT	0
202525	190801	97011G	PARTICIPANT	\N	PRESENT	0
202526	190801	01008M	PARTICIPANT	\N	PRESENT	0
202528	190801	14030Q	PARTICIPANT	\N	PRESENT	0
202529	190801	14261S	PARTICIPANT	\N	PRESENT	0
202530	190801	14255U	PARTICIPANT	\N	PRESENT	0
202531	190801	14055N	PARTICIPANT	\N	PRESENT	0
202532	190801	14041T	PARTICIPANT	\N	PRESENT	0
202533	190801	14151M	PARTICIPANT	\N	PRESENT	0
202534	190801	04067M	PARTICIPANT	\N	PRESENT	0
202535	190801	08068F	PARTICIPANT	\N	PRESENT	0
202536	190801	08069G	PARTICIPANT	\N	PRESENT	0
202537	190801	14093U	PARTICIPANT	\N	PRESENT	0
202538	190801	14331P	PARTICIPANT	\N	PRESENT	0
202539	190801	11048N	PARTICIPANT	\N	PRESENT	0
202540	190801	11034G	PARTICIPANT	\N	PRESENT	0
202541	190801	04033B	PARTICIPANT	\N	PRESENT	0
202542	190801	04044E	PARTICIPANT	\N	PRESENT	0
202543	190801	14215L	PARTICIPANT	\N	PRESENT	0
202544	190801	04081K	PARTICIPANT	\N	PRESENT	0
202552	190801	08062Y	PARTICIPANT	\N	PRESENT	0
202553	190801	04047H	PARTICIPANT	\N	PRESENT	0
202554	190801	11066Q	PARTICIPANT	\N	PRESENT	0
202555	190801	01024M	PARTICIPANT	\N	PRESENT	0
202556	190801	04056J	PARTICIPANT	\N	PRESENT	0
202557	190801	14357A	PARTICIPANT	\N	PRESENT	0
209724	209616	04070G	PRESIDENT	0	PRESENT	0
209725	209616	19699S	PARTICIPANT	\N	PRESENT	0
209726	209616	12041X	PARTICIPANT	\N	PRESENT	0
209727	209616	19533U	PARTICIPANT	\N	PRESENT	0
209728	209616	04033B	PARTICIPANT	\N	PRESENT	0
209729	209616	14229S	PARTICIPANT	\N	PRESENT	0
209730	209616	14241N	PARTICIPANT	\N	PRESENT	0
209731	209616	19573D	PARTICIPANT	\N	PRESENT	0
209732	209616	14039A	PARTICIPANT	\N	PRESENT	0
209733	209616	14107H	PARTICIPANT	\N	PRESENT	0
209734	209616	08017T	PARTICIPANT	\N	PRESENT	0
209735	209616	08012N	PARTICIPANT	\N	PRESENT	0
209736	209616	14249W	PARTICIPANT	\N	PRESENT	0
209737	209616	08039A	PRESIDENT	1	PRESENT	0
209738	209616	08031R	PARTICIPANT	\N	PRESENT	0
209739	209616	19593H	PARTICIPANT	\N	PRESENT	0
209740	209616	14059S	PARTICIPANT	\N	PRESENT	0
209741	209616	19643A	PARTICIPANT	\N	PRESENT	0
209742	209616	14061L	PARTICIPANT	\N	PRESENT	0
209743	209616	04057K	PARTICIPANT	\N	PRESENT	0
209744	209616	14073Q	PARTICIPANT	\N	PRESENT	0
209745	209616	19611R	PARTICIPANT	\N	PRESENT	0
209746	209616	08035V	PARTICIPANT	\N	PRESENT	0
209747	209616	08043V	PARTICIPANT	\N	PRESENT	0
209748	209616	19693L	PARTICIPANT	\N	PRESENT	0
209749	209616	87003B	PARTICIPANT	\N	PRESENT	0
209750	209616	14030Q	PARTICIPANT	\N	PRESENT	0
209751	209616	19731Y	PARTICIPANT	\N	PRESENT	0
209752	209616	14251Q	PARTICIPANT	\N	PRESENT	0
209753	209616	08020N	PARTICIPANT	\N	PRESENT	0
209754	209616	04059M	PARTICIPANT	\N	PRESENT	0
209755	209616	19735D	PARTICIPANT	\N	PRESENT	0
209756	209616	11109J	PARTICIPANT	\N	PRESENT	0
209757	209616	14063N	PARTICIPANT	\N	PRESENT	0
209758	209616	14109K	PARTICIPANT	\N	PRESENT	0
209759	209616	11083R	PARTICIPANT	\N	PRESENT	0
209760	209616	14123H	PARTICIPANT	\N	PRESENT	0
209761	209616	11104D	PARTICIPANT	\N	PRESENT	0
209762	209616	04018C	PARTICIPANT	\N	PRESENT	0
209763	209616	19621T	PARTICIPANT	\N	PRESENT	0
209766	208065	19543W	PARTICIPANT	\N	PRESENT	0
209767	208065	19581D	PARTICIPANT	\N	PRESENT	0
209768	208065	04044E	PARTICIPANT	\N	PRESENT	0
209769	208065	04047H	PARTICIPANT	\N	PRESENT	0
209770	208065	19673G	PARTICIPANT	\N	PRESENT	0
209771	208065	01028R	PARTICIPANT	\N	PRESENT	0
209772	208065	19447X	PARTICIPANT	\N	PRESENT	0
209773	208065	05008E	PRESIDENT	0	PRESENT	0
209774	208065	14231L	PARTICIPANT	\N	PRESENT	0
209775	208065	14215L	PARTICIPANT	\N	PRESENT	0
209776	208065	08018U	PARTICIPANT	\N	PRESENT	0
209777	208065	19483C	PARTICIPANT	\N	PRESENT	0
209778	208065	11072N	PARTICIPANT	\N	PRESENT	0
209779	208065	14065Q	PARTICIPANT	\N	PRESENT	0
209780	208065	19649G	PARTICIPANT	\N	PRESENT	0
209781	208065	08045X	PARTICIPANT	\N	PRESENT	0
209782	208065	19253P	PARTICIPANT	\N	PRESENT	0
209783	208065	01024M	PARTICIPANT	\N	PRESENT	0
209784	208065	04038G	PARTICIPANT	\N	PRESENT	0
209785	208065	11033F	PARTICIPANT	\N	PRESENT	0
209786	208065	19725B	PARTICIPANT	\N	PRESENT	0
209787	208065	19729F	PARTICIPANT	\N	PRESENT	0
209788	208065	95063L	PARTICIPANT	\N	PRESENT	0
209789	208065	19629C	PARTICIPANT	\N	PRESENT	0
209790	208065	08044W	PARTICIPANT	\N	PRESENT	0
209791	208065	11049P	PARTICIPANT	\N	PRESENT	0
209792	208065	14021P	PARTICIPANT	\N	PRESENT	0
209793	208065	98035U	PARTICIPANT	\N	PRESENT	0
209794	208065	14111D	PARTICIPANT	\N	PRESENT	0
209795	208065	11010L	PARTICIPANT	\N	PRESENT	0
209796	208065	11026G	PARTICIPANT	\N	PRESENT	0
209797	208065	07034Q	PARTICIPANT	\N	PRESENT	0
209798	208065	01060R	PARTICIPANT	\N	PRESENT	0
209799	208065	19585H	PARTICIPANT	\N	PRESENT	0
209800	208065	19719D	PARTICIPANT	\N	PRESENT	0
209801	208065	14089Y	PARTICIPANT	\N	PRESENT	0
209802	208065	19489J	PARTICIPANT	\N	PRESENT	0
209803	208065	14179A	PARTICIPANT	\N	PRESENT	0
209804	208065	14147R	PARTICIPANT	\N	PRESENT	0
209805	208065	14069U	PARTICIPANT	\N	PRESENT	0
209806	208065	14151M	PARTICIPANT	\N	PRESENT	0
209807	208065	04008A	PARTICIPANT	\N	PRESENT	0
209808	208065	14259Y	PARTICIPANT	\N	PRESENT	0
209809	208065	14053L	PARTICIPANT	\N	EXCUSE	0
209810	208065	14275Y	PARTICIPANT	\N	EXCUSE	0
209811	207683	01043Q	PARTICIPANT	\N	PRESENT	0
209812	207683	19619A	PARTICIPANT	\N	PRESENT	0
209813	207683	11066Q	PARTICIPANT	\N	PRESENT	0
209814	207683	14219Q	PARTICIPANT	\N	PRESENT	0
209815	207683	19591F	PARTICIPANT	\N	PRESENT	0
209816	207683	19629C	PARTICIPANT	\N	PRESENT	0
209817	207683	19671E	PARTICIPANT	\N	PRESENT	0
209818	207683	14079W	PARTICIPANT	\N	PRESENT	0
209819	207683	17583W	PARTICIPANT	\N	PRESENT	0
209820	207683	07034Q	PARTICIPANT	\N	PRESENT	0
209821	207683	04018C	PARTICIPANT	\N	PRESENT	0
209822	207683	19701S	PARTICIPANT	\N	PRESENT	0
209823	207683	19731Y	PARTICIPANT	\N	PRESENT	0
209824	207683	07033P	PARTICIPANT	\N	PRESENT	0
209825	207683	14063N	PARTICIPANT	\N	PRESENT	0
209826	207683	19707Y	PARTICIPANT	\N	PRESENT	0
209827	207683	19705W	PARTICIPANT	\N	PRESENT	0
209828	207683	11049P	PARTICIPANT	\N	PRESENT	0
209829	207683	19575F	PARTICIPANT	\N	PRESENT	0
209830	207683	04088S	PARTICIPANT	\N	PRESENT	0
209831	207683	18083K	PARTICIPANT	\N	PRESENT	0
209832	207683	19673G	PARTICIPANT	\N	PRESENT	0
209833	207683	19677L	PARTICIPANT	\N	PRESENT	0
209834	207683	19447X	PARTICIPANT	\N	PRESENT	0
209835	207683	14173T	PARTICIPANT	\N	PRESENT	0
209836	207683	19543W	PARTICIPANT	\N	PRESENT	0
209837	207683	07004J	PARTICIPANT	\N	PRESENT	0
209838	207683	01024M	PARTICIPANT	\N	PRESENT	0
209839	207683	19441R	PARTICIPANT	\N	PRESENT	0
209840	207683	19479G	PARTICIPANT	\N	PRESENT	0
209841	207683	08014Q	PARTICIPANT	\N	PRESENT	0
209842	207683	14026U	PARTICIPANT	\N	PRESENT	0
209843	207683	14085U	PARTICIPANT	\N	PRESENT	0
209844	207683	19593H	PARTICIPANT	\N	PRESENT	0
209845	207683	14267Y	PARTICIPANT	\N	PRESENT	0
209846	207683	19503N	PARTICIPANT	\N	PRESENT	0
209847	207683	14223L	PARTICIPANT	\N	PRESENT	0
209848	207683	11080N	PARTICIPANT	\N	PRESENT	0
209849	207683	11048N	PARTICIPANT	\N	PRESENT	0
209850	207683	19687N	PARTICIPANT	\N	PRESENT	0
209851	207683	14031R	PARTICIPANT	\N	PRESENT	0
209852	207683	14059S	PARTICIPANT	\N	PRESENT	0
209853	207683	19709B	PARTICIPANT	\N	PRESENT	0
209854	207683	08034U	PARTICIPANT	\N	PRESENT	0
209855	207683	19413M	PARTICIPANT	\N	PRESENT	0
209856	207683	08015R	PARTICIPANT	\N	PRESENT	0
209857	207683	19689Q	PARTICIPANT	\N	PRESENT	0
209858	207683	99004R	PARTICIPANT	\N	PRESENT	0
209859	207683	19531S	PARTICIPANT	\N	PRESENT	0
209860	207683	11067R	PARTICIPANT	\N	PRESENT	0
209861	207683	19551W	PARTICIPANT	\N	PRESENT	0
209862	207683	14135M	PARTICIPANT	\N	PRESENT	0
209863	207683	19631V	PARTICIPANT	\N	PRESENT	0
209864	207683	95062K	PARTICIPANT	\N	PRESENT	0
209865	207683	04033B	PARTICIPANT	\N	PRESENT	0
209866	207683	14187A	PARTICIPANT	\N	PRESENT	0
209867	207683	05008E	PARTICIPANT	\N	PRESENT	0
209868	207683	07029T	PARTICIPANT	\N	PRESENT	0
209869	207683	04059M	PARTICIPANT	\N	PRESENT	0
209870	207683	14229S	PARTICIPANT	\N	PRESENT	0
209871	207683	11045K	PARTICIPANT	\N	PRESENT	0
209872	207683	19679N	PARTICIPANT	\N	PRESENT	0
209873	207683	14021P	PARTICIPANT	\N	PRESENT	0
209874	207683	19599P	PARTICIPANT	\N	PRESENT	0
209875	207683	19349W	PARTICIPANT	\N	PRESENT	0
209876	207683	19507S	PARTICIPANT	\N	PRESENT	0
209877	207683	95063L	PARTICIPANT	\N	PRESENT	0
209878	207683	19703U	PARTICIPANT	\N	PRESENT	0
209879	207683	19545Y	PARTICIPANT	\N	PRESENT	0
209880	207683	11064N	PARTICIPANT	\N	PRESENT	0
209881	207683	14123H	PARTICIPANT	\N	PRESENT	0
209882	207683	19563B	PARTICIPANT	\N	PRESENT	0
209883	207683	19253P	PARTICIPANT	\N	PRESENT	0
209884	207683	14034U	PARTICIPANT	\N	PRESENT	0
209885	207683	14231L	PARTICIPANT	\N	PRESENT	0
209886	207683	14033T	PARTICIPANT	\N	PRESENT	0
209887	207683	04089T	PARTICIPANT	\N	PRESENT	0
209888	207683	19573D	PARTICIPANT	\N	PRESENT	0
209889	207683	12016W	PARTICIPANT	\N	PRESENT	0
209890	207683	04085P	PARTICIPANT	\N	PRESENT	0
209891	207683	14237S	PARTICIPANT	\N	PRESENT	0
209892	207683	14193X	PARTICIPANT	\N	PRESENT	0
209893	207683	11070L	PARTICIPANT	\N	PRESENT	0
209894	207683	14030Q	PARTICIPANT	\N	PRESENT	0
165893	165892	14239U	PARTICIPANT	\N	PRESENT	0
167413	167412	14219Q	PARTICIPANT	\N	PRESENT	0
165895	165892	01046T	PARTICIPANT	\N	PRESENT	0
165896	165892	04053F	PARTICIPANT	\N	PRESENT	0
165897	165892	14255U	PARTICIPANT	\N	PRESENT	0
165898	165892	04066L	PARTICIPANT	\N	PRESENT	0
165899	165892	00003C	PARTICIPANT	\N	EXCUSE	0
165900	165892	14053L	PARTICIPANT	\N	PRESENT	0
165901	165892	11103C	PARTICIPANT	\N	PRESENT	0
167414	167412	14169X	PARTICIPANT	\N	PRESENT	0
165903	165892	14195A	PARTICIPANT	\N	PRESENT	0
165904	165892	14267Y	PARTICIPANT	\N	PRESENT	0
167415	167412	14157T	PARTICIPANT	\N	PRESENT	0
165906	165892	11031D	PARTICIPANT	\N	PRESENT	0
165907	165892	08052W	PARTICIPANT	\N	PRESENT	0
165908	165892	01059Y	PARTICIPANT	\N	PRESENT	0
165909	165892	04081K	PARTICIPANT	\N	PRESENT	0
165910	165892	98024R	PARTICIPANT	\N	PRESENT	0
165911	165892	10006L	PARTICIPANT	\N	PRESENT	0
167416	167412	14237S	PARTICIPANT	\N	PRESENT	0
165913	165892	14217N	PARTICIPANT	\N	PRESENT	0
165914	165892	14042U	PARTICIPANT	\N	PRESENT	0
165915	165892	14151M	PARTICIPANT	\N	PRESENT	0
165916	165892	12042Y	PARTICIPANT	\N	PRESENT	0
165917	165892	14281W	PARTICIPANT	\N	PRESENT	0
165918	165892	14087W	PARTICIPANT	\N	PRESENT	0
165919	165892	01003G	PARTICIPANT	\N	EXCUSE	0
167432	167412	14031R	PARTICIPANT	\N	PRESENT	0
165921	165892	14231L	PARTICIPANT	\N	PRESENT	0
165922	165892	11061K	PARTICIPANT	\N	PRESENT	0
165923	165892	14355X	PARTICIPANT	\N	PRESENT	0
167433	167412	08009T	PARTICIPANT	\N	PRESENT	0
165925	165892	08041T	PARTICIPANT	\N	PRESENT	0
165926	165892	01011G	PARTICIPANT	\N	PRESENT	0
165927	165892	14026U	PARTICIPANT	\N	EXCUSE	0
165928	165892	14213J	PARTICIPANT	\N	PRESENT	0
165929	165892	14121F	PARTICIPANT	\N	PRESENT	0
165930	165892	11112D	PARTICIPANT	\N	PRESENT	0
165931	165892	14037X	PARTICIPANT	\N	PRESENT	0
165932	165892	14018U	PARTICIPANT	\N	PRESENT	0
165933	165892	11067R	PARTICIPANT	\N	PRESENT	0
165934	165892	14223L	PARTICIPANT	\N	PRESENT	0
165935	165892	04092N	PARTICIPANT	\N	PRESENT	0
165936	165892	14265W	PARTICIPANT	\N	PRESENT	0
165937	165892	14119M	PARTICIPANT	\N	PRESENT	0
165938	165892	14071N	PARTICIPANT	\N	PRESENT	0
165939	165892	04043D	PARTICIPANT	\N	PRESENT	0
165940	165892	14271U	PARTICIPANT	\N	PRESENT	0
167434	167412	95062K	PARTICIPANT	\N	PRESENT	0
165942	165892	11093T	PARTICIPANT	\N	PRESENT	0
165943	165892	11097X	PARTICIPANT	\N	PRESENT	0
165944	165892	04045F	PARTICIPANT	\N	PRESENT	0
165945	165892	14227Q	PARTICIPANT	\N	PRESENT	0
165946	165892	01034P	PARTICIPANT	\N	PRESENT	0
165947	165892	11025F	PARTICIPANT	\N	PRESENT	0
165948	165892	11063M	PARTICIPANT	\N	PRESENT	0
169171	169170	14263U	PARTICIPANT	\N	PRESENT	0
169172	169170	11109J	PARTICIPANT	\N	PRESENT	0
169173	169170	04059M	PARTICIPANT	\N	PRESENT	0
173932	173931	14053L	PARTICIPANT	\N	PRESENT	0
169175	169170	01044R	PARTICIPANT	\N	PRESENT	0
169176	169170	08043V	PARTICIPANT	\N	PRESENT	0
169177	169170	14089Y	PARTICIPANT	\N	PRESENT	0
169178	169170	14105F	PARTICIPANT	\N	PRESENT	0
169179	169170	11029K	PARTICIPANT	\N	PRESENT	0
169180	169170	95015C	PARTICIPANT	\N	PRESENT	0
169181	169170	92015P	PARTICIPANT	\N	PRESENT	0
169182	169170	08024S	PARTICIPANT	\N	PRESENT	0
169183	169170	14201E	PARTICIPANT	\N	PRESENT	0
169184	169170	14329V	PARTICIPANT	\N	PRESENT	0
169185	169170	14209N	PARTICIPANT	\N	PRESENT	0
169186	169170	14079W	PARTICIPANT	\N	PRESENT	0
169187	169170	11091R	PARTICIPANT	\N	EXCUSE	0
169188	169170	87003B	PARTICIPANT	\N	PRESENT	0
173933	173931	11097X	PARTICIPANT	\N	PRESENT	0
169190	169170	14249W	PARTICIPANT	\N	PRESENT	0
173934	173931	12042Y	PARTICIPANT	\N	PRESENT	0
169192	169170	01025N	PARTICIPANT	\N	PRESENT	0
173936	173935	14053L	PARTICIPANT	\N	PRESENT	0
173937	173935	12042Y	PARTICIPANT	\N	PRESENT	0
169195	169170	11089X	PARTICIPANT	\N	PRESENT	0
169196	169170	07026Q	PARTICIPANT	\N	PRESENT	0
169197	169170	14123H	PARTICIPANT	\N	PRESENT	0
169198	169170	14179A	PARTICIPANT	\N	PRESENT	0
169199	169170	04041B	PARTICIPANT	\N	EXCUSE	0
169200	169170	14241N	PARTICIPANT	\N	PRESENT	0
169201	169170	14061L	PARTICIPANT	\N	PRESENT	0
169202	169170	14073Q	PARTICIPANT	\N	PRESENT	0
169203	169170	08031R	PARTICIPANT	\N	PRESENT	0
173938	173935	11097X	PARTICIPANT	\N	PRESENT	0
169205	169170	08039A	PARTICIPANT	\N	PRESENT	0
169206	169170	08017T	PARTICIPANT	\N	PRESENT	0
169207	169170	14059S	PARTICIPANT	\N	PRESENT	0
169208	169170	08012N	PARTICIPANT	\N	PRESENT	0
169209	169170	14103D	PARTICIPANT	\N	PRESENT	0
169210	169170	11104D	PARTICIPANT	\N	PRESENT	0
169211	169170	14063N	PARTICIPANT	\N	PRESENT	0
169212	169170	04057K	PARTICIPANT	\N	PRESENT	0
169213	169170	11014C	PARTICIPANT	\N	EXCUSE	0
169214	169170	14109K	PARTICIPANT	\N	PRESENT	0
169215	169170	04070G	PRESIDENT	0	PRESENT	0
184314	184313	14089Y	PARTICIPANT	\N	EXCUSE	0
184315	184313	11035H	PARTICIPANT	\N	EXCUSE	0
169218	169170	83047W	PARTICIPANT	\N	PRESENT	0
169219	169170	14235Q	PARTICIPANT	\N	PRESENT	0
184316	184313	14249W	PARTICIPANT	\N	EXCUSE	0
184317	184313	08018U	PARTICIPANT	\N	EXCUSE	0
169222	169170	14361V	PARTICIPANT	\N	PRESENT	0
169223	169170	14229S	PARTICIPANT	\N	PRESENT	0
169224	169170	14363X	PARTICIPANT	\N	PRESENT	0
169225	169170	11043H	PARTICIPANT	\N	PRESENT	0
169226	169170	11071M	PARTICIPANT	\N	PRESENT	0
184318	184313	14073Q	PARTICIPANT	\N	EXCUSE	0
184319	184313	11026G	PARTICIPANT	\N	EXCUSE	0
184320	184313	14097Y	PARTICIPANT	\N	PRESENT	0
184321	184313	11083R	PARTICIPANT	\N	PRESENT	0
184322	184313	14079W	PARTICIPANT	\N	PRESENT	0
184323	184313	96004D	PRESIDENT	0	PRESENT	0
184324	184313	04080J	PARTICIPANT	\N	EXCUSE	0
184325	184313	04057K	PARTICIPANT	\N	PRESENT	0
184326	184313	14135M	PARTICIPANT	\N	PRESENT	0
184327	184313	92045V	PARTICIPANT	\N	EXCUSE	0
184328	184313	98035U	PARTICIPANT	\N	EXCUSE	0
184329	184313	14133K	PARTICIPANT	\N	PRESENT	0
184330	184313	11012A	PARTICIPANT	\N	EXCUSE	0
184653	184652	98046X	PARTICIPANT	\N	PRESENT	0
184754	184752	14085U	PARTICIPANT	\N	PRESENT	0
184656	184654	98046X	PARTICIPANT	\N	PRESENT	0
184753	184752	14175V	PARTICIPANT	\N	PRESENT	0
184755	184752	11042G	PARTICIPANT	\N	PRESENT	0
184756	184752	11070L	PARTICIPANT	\N	PRESENT	0
184757	184752	11083R	PARTICIPANT	\N	PRESENT	0
184758	184752	14159V	PARTICIPANT	\N	PRESENT	0
184760	184759	14175V	PARTICIPANT	\N	PRESENT	0
184761	184759	14085U	PARTICIPANT	\N	PRESENT	0
184762	184759	11083R	PARTICIPANT	\N	PRESENT	0
184763	184759	14159V	PARTICIPANT	\N	PRESENT	0
184765	184764	14175V	PARTICIPANT	\N	PRESENT	0
184766	184764	14085U	PARTICIPANT	\N	PRESENT	0
184768	184767	08011M	PARTICIPANT	\N	PRESENT	0
184769	184767	04086Q	PARTICIPANT	\N	PRESENT	0
184770	184767	11083R	PARTICIPANT	\N	PRESENT	0
184771	184767	14159V	PARTICIPANT	\N	PRESENT	0
184773	184772	04086Q	PARTICIPANT	\N	PRESENT	0
184774	184772	11083R	PARTICIPANT	\N	PRESENT	0
184775	184772	14159V	PARTICIPANT	\N	PRESENT	0
184777	184776	14159V	PARTICIPANT	\N	PRESENT	0
184873	184872	11039M	PARTICIPANT	\N	PRESENT	0
184874	184872	98042T	PARTICIPANT	\N	PRESENT	0
184875	184872	01019Q	PARTICIPANT	\N	PRESENT	0
185233	185232	11031D	PARTICIPANT	\N	PRESENT	0
185234	185232	11061K	PARTICIPANT	\N	PRESENT	0
185235	185232	11097X	PARTICIPANT	\N	PRESENT	0
185392	185152	98035U	PARTICIPANT	\N	PRESENT	0
185393	185152	14065Q	PARTICIPANT	\N	PRESENT	0
185394	185152	95067Q	PARTICIPANT	\N	PRESENT	0
185395	185152	07034Q	PARTICIPANT	\N	PRESENT	0
185396	185152	14273W	PARTICIPANT	\N	PRESENT	0
185397	185152	01024M	PARTICIPANT	\N	PRESENT	0
185398	185152	04047H	PRESIDENT	0	PRESENT	0
185399	185152	01028R	PARTICIPANT	\N	PRESENT	0
185400	185152	05008E	PARTICIPANT	\N	PRESENT	0
185401	185152	11035H	PARTICIPANT	\N	PRESENT	0
185402	185152	11056N	PARTICIPANT	\N	PRESENT	0
185403	185152	04074L	PARTICIPANT	\N	PRESENT	0
185404	185152	11037K	PARTICIPANT	\N	PRESENT	0
185405	185152	14041T	PARTICIPANT	\N	PRESENT	0
185406	185152	14147R	PARTICIPANT	\N	PRESENT	0
185407	185152	08010L	PARTICIPANT	\N	PRESENT	0
180914	174352	14069U	PARTICIPANT	\N	PRESENT	0
180915	174352	11101A	PARTICIPANT	\N	PRESENT	0
180916	174352	11044J	PARTICIPANT	\N	PRESENT	0
180918	174352	14327T	PARTICIPANT	\N	PRESENT	0
180919	174352	14231L	PARTICIPANT	\N	PRESENT	0
180920	174352	01057W	PARTICIPANT	\N	PRESENT	0
180921	174352	11112D	PARTICIPANT	\N	PRESENT	0
180922	174352	08034U	PARTICIPANT	\N	PRESENT	0
180923	174352	14028W	PARTICIPANT	\N	PRESENT	0
180924	174352	95063L	PARTICIPANT	\N	PRESENT	0
180925	174352	05012A	PARTICIPANT	\N	PRESENT	0
180926	174352	11037K	PARTICIPANT	\N	PRESENT	0
181073	181072	95015C	PARTICIPANT	\N	PRESENT	0
181632	164996	14257W	PARTICIPANT	\N	PRESENT	0
182653	182652	04034C	PARTICIPANT	\N	PRESENT	0
182654	182652	98042T	PARTICIPANT	\N	PRESENT	0
199716	190791	01007L	PARTICIPANT	\N	PRESENT	0
199652	190791	14227Q	PARTICIPANT	\N	PRESENT	0
199653	190791	14269B	PARTICIPANT	\N	PRESENT	0
199654	190791	11054L	PARTICIPANT	\N	PRESENT	0
199715	190791	01034P	PARTICIPANT	\N	PRESENT	0
199656	190791	18127E	PARTICIPANT	\N	PRESENT	0
199657	190791	11026G	PARTICIPANT	\N	PRESENT	0
199658	190791	11074Q	PARTICIPANT	\N	PRESENT	0
199659	190791	14121F	PARTICIPANT	\N	PRESENT	0
199660	190791	14063N	PARTICIPANT	\N	PRESENT	0
199712	190791	04080J	PARTICIPANT	\N	PRESENT	0
199662	190791	11112D	PARTICIPANT	\N	PRESENT	0
199663	190791	14257W	PARTICIPANT	\N	PRESENT	0
199664	190791	11037K	PARTICIPANT	\N	PRESENT	0
199665	190791	11067R	PARTICIPANT	\N	PRESENT	0
199666	190791	11066Q	PARTICIPANT	\N	PRESENT	0
199667	190791	08035V	PARTICIPANT	\N	PRESENT	0
199668	190791	11061K	PARTICIPANT	\N	PRESENT	0
199669	190791	08024S	PARTICIPANT	\N	PRESENT	0
199670	190791	08061X	PARTICIPANT	\N	PRESENT	0
199671	190791	04077P	PARTICIPANT	\N	PRESENT	0
199672	190791	04053F	PARTICIPANT	\N	PRESENT	0
199673	190791	11068S	PARTICIPANT	\N	PRESENT	0
199674	190791	95063L	PARTICIPANT	\N	PRESENT	0
199675	190791	11036J	PARTICIPANT	\N	PRESENT	0
199676	190791	98029W	PARTICIPANT	\N	PRESENT	0
199692	190791	11083R	PARTICIPANT	\N	PRESENT	0
199693	190791	95037J	PARTICIPANT	\N	PRESENT	0
199694	190791	04034C	PARTICIPANT	\N	PRESENT	0
199695	190791	11107G	PARTICIPANT	\N	PRESENT	0
199696	190791	11023D	PARTICIPANT	\N	PRESENT	0
199697	190791	14039A	PARTICIPANT	\N	PRESENT	0
199698	190791	11114F	PARTICIPANT	\N	PRESENT	0
199699	190791	11055M	PARTICIPANT	\N	PRESENT	0
199700	190791	11029K	PARTICIPANT	\N	PRESENT	0
199701	190791	14261S	PARTICIPANT	\N	PRESENT	0
199702	190791	88008L	PARTICIPANT	\N	PRESENT	0
199703	190791	11081P	PARTICIPANT	\N	PRESENT	0
199704	190791	08031R	PARTICIPANT	\N	PRESENT	0
199705	190791	19253P	PARTICIPANT	\N	PRESENT	0
199706	190791	14201E	PARTICIPANT	\N	PRESENT	0
199707	190791	14241N	PARTICIPANT	\N	PRESENT	0
199708	190791	98022P	PARTICIPANT	\N	PRESENT	0
199709	190791	14093U	PARTICIPANT	\N	PRESENT	0
199710	190791	14089Y	PARTICIPANT	\N	PRESENT	0
199713	190791	11082Q	PARTICIPANT	\N	PRESENT	0
199714	190791	11093T	PARTICIPANT	\N	PRESENT	0
199732	190791	14169X	PARTICIPANT	\N	PRESENT	0
199733	190791	04071H	PARTICIPANT	\N	PRESENT	0
199734	190791	11065P	PARTICIPANT	\N	PRESENT	0
199735	190791	89017R	PARTICIPANT	\N	PRESENT	0
199752	190791	11033F	PARTICIPANT	\N	PRESENT	0
199773	199772	04045F	PARTICIPANT	\N	PRESENT	0
199774	199772	14089Y	PARTICIPANT	\N	PRESENT	0
199775	199772	14135M	PARTICIPANT	\N	PRESENT	0
199776	199772	01016M	PARTICIPANT	\N	PRESENT	0
199777	199772	14079W	PARTICIPANT	\N	PRESENT	0
199778	199772	90003B	PARTICIPANT	\N	EXCUSE	0
199782	199772	04049K	PARTICIPANT	\N	PRESENT	0
199780	199772	14073Q	PARTICIPANT	\N	EXCUSE	0
199781	199772	11012A	PARTICIPANT	\N	EXCUSE	0
199783	199772	96004D	PRESIDENT	0	PRESENT	0
199784	199772	14026U	PARTICIPANT	\N	PRESENT	0
199785	199772	95037J	PARTICIPANT	\N	PRESENT	0
199786	199772	14033T	PARTICIPANT	\N	PRESENT	0
199787	199772	14257W	PARTICIPANT	\N	PRESENT	0
199788	199772	11036J	PARTICIPANT	\N	PRESENT	0
199789	199772	11066Q	PARTICIPANT	\N	PRESENT	0
199790	199772	08068F	PARTICIPANT	\N	PRESENT	0
199791	199772	08019V	PARTICIPANT	\N	PRESENT	0
199792	199772	98050T	PARTICIPANT	\N	PRESENT	0
199793	199772	04088S	PARTICIPANT	\N	PRESENT	0
199794	199772	11081P	PARTICIPANT	\N	PRESENT	0
199795	199772	14207L	PARTICIPANT	\N	PRESENT	0
199796	199772	80013X	PARTICIPANT	\N	PRESENT	0
199797	199772	01008M	PARTICIPANT	\N	PRESENT	0
199798	199772	14205J	PARTICIPANT	\N	PRESENT	0
199799	199772	14357A	PARTICIPANT	\N	PRESENT	0
199800	199772	11090Q	PARTICIPANT	\N	PRESENT	0
199801	199772	14187A	PARTICIPANT	\N	PRESENT	0
200292	197404	14069U	PARTICIPANT	\N	PRESENT	0
200293	197404	14071N	PARTICIPANT	\N	PRESENT	0
200294	197404	08034U	PARTICIPANT	\N	PRESENT	0
200295	197404	08010L	PARTICIPANT	\N	PRESENT	0
200296	197404	04086Q	PARTICIPANT	\N	PRESENT	0
200297	197404	14034U	PARTICIPANT	\N	PRESENT	0
200298	197404	14231L	PARTICIPANT	\N	PRESENT	0
200299	197404	11037K	PARTICIPANT	\N	PRESENT	0
200300	197404	11112D	PARTICIPANT	\N	PRESENT	0
200301	197404	19253P	PARTICIPANT	\N	PRESENT	0
200302	197404	14063N	PARTICIPANT	\N	PRESENT	0
200303	197404	11034G	PARTICIPANT	\N	PRESENT	0
200304	197404	14327T	PARTICIPANT	\N	PRESENT	0
200305	197404	04040A	PRESIDENT	0	PRESENT	0
200306	197404	11098Y	PARTICIPANT	\N	PRESENT	0
200312	198532	04045F	PARTICIPANT	\N	EXCUSE	0
197999	191734	14030Q	PARTICIPANT	\N	PRESENT	0
198000	191734	08068F	PARTICIPANT	\N	PRESENT	0
198001	191734	04053F	PARTICIPANT	\N	PRESENT	0
198002	191734	14207L	PARTICIPANT	\N	PRESENT	0
198003	191734	14255U	PARTICIPANT	\N	PRESENT	0
198004	191734	14079W	PARTICIPANT	\N	PRESENT	0
198005	191734	14151M	PARTICIPANT	\N	PRESENT	0
198006	191734	14039A	PARTICIPANT	\N	PRESENT	0
198007	191734	14061L	PARTICIPANT	\N	PRESENT	0
198008	191734	04049K	PARTICIPANT	\N	PRESENT	0
198009	191734	14265W	PARTICIPANT	\N	PRESENT	0
198010	191734	14253S	PARTICIPANT	\N	PRESENT	0
198011	191734	11090Q	PARTICIPANT	\N	PRESENT	0
198012	191734	10015M	PARTICIPANT	\N	PRESENT	0
198013	191734	14157T	PARTICIPANT	\N	PRESENT	0
202558	190801	07029T	PARTICIPANT	\N	PRESENT	0
202559	190801	01022K	PARTICIPANT	\N	PRESENT	0
202560	190801	14253S	PARTICIPANT	\N	PRESENT	0
202561	190801	14267Y	PARTICIPANT	\N	PRESENT	0
202562	190801	14061L	PARTICIPANT	\N	PRESENT	0
202563	190801	04088S	PARTICIPANT	\N	PRESENT	0
202564	190801	08039A	PARTICIPANT	\N	PRESENT	0
202565	190801	14071N	PARTICIPANT	\N	PRESENT	0
202566	190801	14069U	PARTICIPANT	\N	PRESENT	0
202567	190801	08015R	PARTICIPANT	\N	PRESENT	0
202568	190801	14119M	PARTICIPANT	\N	PRESENT	0
202569	190801	14079W	PARTICIPANT	\N	PRESENT	0
202572	190801	13002U	PARTICIPANT	\N	PRESENT	0
202573	190801	14249W	PARTICIPANT	\N	PRESENT	0
202575	190801	14135M	PARTICIPANT	\N	PRESENT	0
202576	190801	18127E	PARTICIPANT	\N	PRESENT	0
202592	190801	11091R	PARTICIPANT	\N	PRESENT	0
202612	190801	01015L	PARTICIPANT	\N	PRESENT	0
202613	190801	01013J	PARTICIPANT	\N	PRESENT	0
202614	190801	11036J	PARTICIPANT	\N	PRESENT	0
202615	190801	11023D	PARTICIPANT	\N	PRESENT	0
202616	190801	14081Q	PARTICIPANT	\N	PRESENT	0
202617	190801	14207L	PARTICIPANT	\N	PRESENT	0
202632	190801	14231L	PARTICIPANT	\N	PRESENT	0
202633	190801	14209N	PARTICIPANT	\N	PRESENT	0
202634	190801	10006L	PARTICIPANT	\N	PRESENT	0
202635	190801	11029K	PARTICIPANT	\N	PRESENT	0
202636	190801	11065P	PARTICIPANT	\N	PRESENT	0
202637	190801	95030B	PARTICIPANT	\N	PRESENT	0
202652	190801	08061X	PARTICIPANT	\N	PRESENT	0
202672	190801	80013X	PARTICIPANT	\N	PRESENT	0
202673	190801	80027E	PARTICIPANT	\N	PRESENT	0
202732	190801	14111D	PARTICIPANT	\N	PRESENT	0
202733	190801	14133K	PARTICIPANT	\N	PRESENT	0
202734	190801	14173T	PARTICIPANT	\N	PRESENT	0
202735	190801	11097X	PARTICIPANT	\N	PRESENT	0
202736	190801	04049K	PARTICIPANT	\N	PRESENT	0
202737	190801	04057K	PARTICIPANT	\N	PRESENT	0
202738	190801	14363X	PARTICIPANT	\N	PRESENT	0
202739	190801	08048B	PARTICIPANT	\N	PRESENT	0
202752	190801	11067R	PARTICIPANT	\N	PRESENT	0
202753	190801	01034P	PARTICIPANT	\N	PRESENT	0
202754	190801	14355X	PARTICIPANT	\N	PRESENT	0
202772	190801	95063L	PARTICIPANT	\N	PRESENT	0
202773	190801	14159V	PARTICIPANT	\N	PRESENT	0
202774	190801	08010L	PARTICIPANT	\N	PRESENT	0
202775	190801	14053L	PARTICIPANT	\N	PRESENT	0
202776	190801	14169X	PARTICIPANT	\N	PRESENT	0
202777	190801	14259Y	PARTICIPANT	\N	PRESENT	0
202778	190801	08034U	PARTICIPANT	\N	PRESENT	0
202779	190801	05012A	PARTICIPANT	\N	PRESENT	0
202792	190801	04043D	PARTICIPANT	\N	PRESENT	0
202793	190801	04061F	PARTICIPANT	\N	PRESENT	0
202794	190801	01031L	PARTICIPANT	\N	PRESENT	0
202795	190801	11080N	PARTICIPANT	\N	PRESENT	0
202796	190801	04034C	PARTICIPANT	\N	PRESENT	0
202797	190801	08017T	PARTICIPANT	\N	PRESENT	0
202813	202812	11039M	PARTICIPANT	\N	PRESENT	0
202814	202812	98042T	PARTICIPANT	\N	PRESENT	0
202815	202812	01019Q	PARTICIPANT	\N	PRESENT	0
202832	202527	14059S	PARTICIPANT	\N	PRESENT	0
202833	202527	04070G	PRESIDENT	0	PRESENT	0
202834	202527	14061L	PARTICIPANT	\N	PRESENT	0
202835	202527	14103D	PARTICIPANT	\N	PRESENT	0
202836	202527	12041X	PARTICIPANT	\N	PRESENT	0
202837	202527	04057K	PARTICIPANT	\N	PRESENT	0
202838	202527	14073Q	PARTICIPANT	\N	PRESENT	0
202839	202527	04033B	PARTICIPANT	\N	PRESENT	0
202840	202527	11091R	PARTICIPANT	\N	PRESENT	0
202841	202527	11029K	PARTICIPANT	\N	PRESENT	0
202842	202527	01041N	PARTICIPANT	\N	PRESENT	0
202843	202527	14241N	PARTICIPANT	\N	PRESENT	0
202844	202527	14055N	PARTICIPANT	\N	PRESENT	0
202845	202527	14363X	PARTICIPANT	\N	PRESENT	0
202846	202527	14179A	PARTICIPANT	\N	PRESENT	0
202847	202527	11104D	PARTICIPANT	\N	PRESENT	0
202848	202527	08039A	PARTICIPANT	\N	PRESENT	0
202849	202527	08031R	PARTICIPANT	\N	PRESENT	0
202850	202527	14063N	PARTICIPANT	\N	EXCUSE	0
202851	202527	14209N	PARTICIPANT	\N	EXCUSE	0
202852	190801	14089Y	PARTICIPANT	\N	PRESENT	0
202872	190801	11064N	PARTICIPANT	\N	PRESENT	0
202873	190801	14195A	PARTICIPANT	\N	PRESENT	0
202874	190801	92031P	PARTICIPANT	\N	PRESENT	0
202892	190801	14083S	PARTICIPANT	\N	PRESENT	0
202912	202527	14249W	PARTICIPANT	\N	PRESENT	0
202932	190801	99004R	PARTICIPANT	\N	PRESENT	0
202952	190801	98046X	PARTICIPANT	\N	PRESENT	0
202953	190801	14257W	PARTICIPANT	\N	PRESENT	0
202954	190801	01041N	PARTICIPANT	\N	PRESENT	0
202972	190801	14327T	PARTICIPANT	\N	PRESENT	0
203112	190802	04066L	PARTICIPANT	\N	PRESENT	0
203113	190802	04092N	PARTICIPANT	\N	PRESENT	0
203114	190802	98024R	PARTICIPANT	\N	PRESENT	0
203115	190802	11031D	PARTICIPANT	\N	PRESENT	0
203116	190802	12041X	PARTICIPANT	\N	PRESENT	0
203117	190802	11063M	PARTICIPANT	\N	PRESENT	0
203118	190802	14227Q	PARTICIPANT	\N	PRESENT	0
203119	190802	08052W	PARTICIPANT	\N	PRESENT	0
203120	190802	11104D	PARTICIPANT	\N	PRESENT	0
203121	190802	14269B	PARTICIPANT	\N	PRESENT	0
203122	190802	08068F	PARTICIPANT	\N	PRESENT	0
203123	190802	19251M	PARTICIPANT	\N	PRESENT	0
203124	190802	14097Y	PARTICIPANT	\N	PRESENT	0
203125	190802	11061K	PARTICIPANT	\N	PRESENT	0
203126	190802	14271U	PARTICIPANT	\N	PRESENT	0
203127	190802	11029K	PARTICIPANT	\N	PRESENT	0
203132	190802	14261S	PARTICIPANT	\N	PRESENT	0
203133	190802	14255U	PARTICIPANT	\N	PRESENT	0
203134	190802	04049K	PARTICIPANT	\N	PRESENT	0
203135	190802	07029T	PARTICIPANT	\N	PRESENT	0
203136	190802	14215L	PARTICIPANT	\N	PRESENT	0
203137	190802	11067R	PARTICIPANT	\N	PRESENT	0
203138	190802	11089X	PARTICIPANT	\N	PRESENT	0
203139	190802	11109J	PARTICIPANT	\N	PRESENT	0
203140	190802	10006L	PARTICIPANT	\N	PRESENT	0
203141	190802	04047H	PARTICIPANT	\N	PRESENT	0
203152	190802	11026G	PARTICIPANT	\N	PRESENT	0
203153	190802	04053F	PARTICIPANT	\N	PRESENT	0
203154	190802	04085P	PARTICIPANT	\N	PRESENT	0
203155	190802	12042Y	PARTICIPANT	\N	PRESENT	0
203172	190802	01059Y	PARTICIPANT	\N	PRESENT	0
203173	190802	14081Q	PARTICIPANT	\N	PRESENT	0
203174	190802	04059M	PARTICIPANT	\N	PRESENT	0
203175	190802	14157T	PARTICIPANT	\N	PRESENT	0
203176	190802	14281W	PARTICIPANT	\N	PRESENT	0
203177	190802	11036J	PARTICIPANT	\N	PRESENT	0
203192	190802	80013X	PARTICIPANT	\N	PRESENT	0
203212	190802	14034U	PARTICIPANT	\N	PRESENT	0
203213	190802	04067M	PARTICIPANT	\N	PRESENT	0
203232	190802	14363X	PARTICIPANT	\N	PRESENT	0
203233	190802	14059S	PARTICIPANT	\N	PRESENT	0
203252	190802	14195A	PARTICIPANT	\N	PRESENT	0
203253	190802	14033T	PARTICIPANT	\N	PRESENT	0
203254	190802	14265W	PARTICIPANT	\N	PRESENT	0
203255	190802	14061L	PARTICIPANT	\N	PRESENT	0
203256	190802	14053L	PARTICIPANT	\N	PRESENT	0
203257	190802	14071N	PARTICIPANT	\N	PRESENT	0
203258	190802	14231L	PARTICIPANT	\N	PRESENT	0
203259	190802	14079W	PARTICIPANT	\N	PRESENT	0
203260	190802	14357A	PARTICIPANT	\N	PRESENT	0
203261	190802	04088S	PARTICIPANT	\N	PRESENT	0
203262	190802	11097X	PARTICIPANT	\N	PRESENT	0
203263	190802	14257W	PARTICIPANT	\N	PRESENT	0
203264	190802	11077T	PARTICIPANT	\N	PRESENT	0
203272	190802	11064N	PARTICIPANT	\N	PRESENT	0
203273	190802	14217N	PARTICIPANT	\N	PRESENT	0
203274	190802	08031R	PARTICIPANT	\N	PRESENT	0
203292	190802	04045F	PARTICIPANT	\N	PRESENT	0
203312	190802	98053W	PARTICIPANT	\N	PRESENT	0
203313	190802	04033B	PARTICIPANT	\N	PRESENT	0
203314	190802	04040A	PARTICIPANT	\N	PRESENT	0
203315	190802	14179A	PARTICIPANT	\N	PRESENT	0
203437	203436	96004D	PRESIDENT	0	PRESENT	0
183005	183004	11074Q	PARTICIPANT	\N	PRESENT	0
183006	183004	04056J	PARTICIPANT	\N	PRESENT	0
186673	186672	96004D	PARTICIPANT	\N	PRESENT	0
186674	186672	04045F	PARTICIPANT	\N	PRESENT	0
186675	186672	92045V	PARTICIPANT	\N	PRESENT	0
187773	187772	14133K	PARTICIPANT	\N	PRESENT	0
187774	187772	04040A	PARTICIPANT	\N	PRESENT	0
187775	187772	08058D	PARTICIPANT	\N	PRESENT	0
187776	187772	04042C	PARTICIPANT	\N	PRESENT	0
187777	187772	77002U	PARTICIPANT	\N	PRESENT	0
187778	187772	98029W	PARTICIPANT	\N	PRESENT	0
187779	187772	11027H	PARTICIPANT	\N	PRESENT	0
187780	187772	98018T	PARTICIPANT	\N	PRESENT	0
187781	187772	95030B	PARTICIPANT	\N	PRESENT	0
187782	187772	04035D	PARTICIPANT	\N	PRESENT	0
187783	187772	14014Q	PARTICIPANT	\N	EXCUSE	0
187784	187772	07004J	PARTICIPANT	\N	EXCUSE	0
187785	187772	14211G	PARTICIPANT	\N	EXCUSE	0
187786	187772	95037J	PARTICIPANT	\N	PRESENT	0
187787	187772	04078Q	PARTICIPANT	\N	EXCUSE	0
187788	187772	04036E	PARTICIPANT	\N	PRESENT	0
187789	187772	98005N	PARTICIPANT	\N	PRESENT	0
187790	187772	92031P	PARTICIPANT	\N	PRESENT	0
187791	187772	11106F	PARTICIPANT	\N	PRESENT	0
187792	187772	14251Q	PARTICIPANT	\N	PRESENT	0
187793	187772	83042R	PARTICIPANT	\N	PRESENT	0
187794	187772	14253S	PARTICIPANT	\N	EXCUSE	0
187795	187772	08047A	PARTICIPANT	\N	PRESENT	0
187796	187772	14028W	PARTICIPANT	\N	EXCUSE	0
187797	187772	14193X	PARTICIPANT	\N	PRESENT	0
187798	187772	98021N	PARTICIPANT	\N	PRESENT	0
187799	187772	95059Q	PRESIDENT	0	PRESENT	0
187800	187772	01014K	PARTICIPANT	\N	PRESENT	0
187801	187772	11054L	PARTICIPANT	\N	PRESENT	0
187802	187772	01056V	PARTICIPANT	\N	PRESENT	0
187803	187772	08049C	PARTICIPANT	\N	PRESENT	0
189303	188953	14327T	PARTICIPANT	\N	PRESENT	0
189304	188953	01031L	PRESIDENT	0	PRESENT	0
189305	188953	01057W	PARTICIPANT	\N	PRESENT	0
189306	188953	01016M	PARTICIPANT	\N	PRESENT	0
189307	188953	11074Q	PARTICIPANT	\N	PRESENT	0
189308	188953	89017R	PARTICIPANT	\N	PRESENT	0
189309	188953	08011M	PARTICIPANT	\N	PRESENT	0
189310	188953	14159V	PARTICIPANT	\N	PRESENT	0
189311	188953	11088W	PARTICIPANT	\N	PRESENT	0
189312	188953	11040E	PARTICIPANT	\N	PRESENT	0
189313	188953	04086Q	PARTICIPANT	\N	PRESENT	0
189314	188953	98046X	PARTICIPANT	\N	PRESENT	0
189315	188953	11083R	PARTICIPANT	\N	PRESENT	0
189316	188953	08010L	PARTICIPANT	\N	PRESENT	0
189317	188953	11042G	PARTICIPANT	\N	PRESENT	0
189318	188953	14083S	PARTICIPANT	\N	PRESENT	0
189319	188953	07029T	PARTICIPANT	\N	EXCUSE	0
189320	188953	11012A	PARTICIPANT	\N	EXCUSE	0
189321	188953	04034C	PARTICIPANT	\N	EXCUSE	0
189322	188953	98053W	PARTICIPANT	\N	EXCUSE	0
189323	188953	01027Q	PARTICIPANT	\N	EXCUSE	0
189652	189492	14327T	PARTICIPANT	\N	PRESENT	0
189653	189492	11067R	PARTICIPANT	\N	PRESENT	0
189654	189492	95062K	PARTICIPANT	\N	PRESENT	0
189655	189492	11099A	PARTICIPANT	\N	PRESENT	0
189656	189492	92045V	PARTICIPANT	\N	PRESENT	0
189657	189492	14041T	PARTICIPANT	\N	PRESENT	0
189658	189492	14042U	PARTICIPANT	\N	PRESENT	0
189659	189492	14147R	PARTICIPANT	\N	PRESENT	0
189660	189492	14151M	PARTICIPANT	\N	PRESENT	0
189661	189492	14157T	PARTICIPANT	\N	PRESENT	0
189662	189492	11106F	PARTICIPANT	\N	PRESENT	0
189663	189492	98023Q	PARTICIPANT	\N	PRESENT	0
189664	189492	14038Y	PARTICIPANT	\N	PRESENT	0
189665	189492	14061L	PARTICIPANT	\N	PRESENT	0
189666	189492	95067Q	PARTICIPANT	\N	PRESENT	0
189667	189492	14065Q	PARTICIPANT	\N	PRESENT	0
189668	189492	14187A	PARTICIPANT	\N	PRESENT	0
189669	189492	01014K	PARTICIPANT	\N	PRESENT	0
189670	189492	12042Y	PARTICIPANT	\N	PRESENT	0
189671	189492	11093T	PARTICIPANT	\N	PRESENT	0
189672	189492	01027Q	PARTICIPANT	\N	PRESENT	0
189673	189492	87003B	PARTICIPANT	\N	PRESENT	0
189674	189492	11014C	PARTICIPANT	\N	PRESENT	0
189675	189492	01008M	PARTICIPANT	\N	PRESENT	0
189676	189492	01011G	PARTICIPANT	\N	PRESENT	0
189677	189492	11036J	PARTICIPANT	\N	PRESENT	0
210461	210459	11053K	PARTICIPANT	\N	PRESENT	0
189679	189492	99004R	PARTICIPANT	\N	PRESENT	0
189680	189492	95049N	PARTICIPANT	\N	PRESENT	0
189681	189492	14211G	PARTICIPANT	\N	PRESENT	0
189682	189492	11061K	PARTICIPANT	\N	PRESENT	0
189683	189492	04034C	PARTICIPANT	\N	PRESENT	0
189684	189492	14361V	PARTICIPANT	\N	PRESENT	0
189685	189492	14001X	PARTICIPANT	\N	PRESENT	0
189686	189492	04044E	PARTICIPANT	\N	PRESENT	0
189687	189492	04045F	PARTICIPANT	\N	PRESENT	0
189688	189492	04047H	PARTICIPANT	\N	PRESENT	0
189689	189492	05008E	PRESIDENT	0	PRESENT	0
189690	189492	14231L	PARTICIPANT	\N	PRESENT	0
189691	189492	05012A	PARTICIPANT	\N	PRESENT	0
189692	189492	95037J	PARTICIPANT	\N	PRESENT	0
189693	189492	14281W	PARTICIPANT	\N	PRESENT	0
189694	189492	08015R	PARTICIPANT	\N	PRESENT	0
189695	189492	08017T	PARTICIPANT	\N	PRESENT	0
189696	189492	14179A	PARTICIPANT	\N	PRESENT	0
189697	189492	08019V	PARTICIPANT	\N	PRESENT	0
189698	189492	08010L	PARTICIPANT	\N	PRESENT	0
189699	189492	14215L	PARTICIPANT	\N	PRESENT	0
189700	189492	08012N	PARTICIPANT	\N	PRESENT	0
189701	189492	14259Y	PARTICIPANT	\N	PRESENT	0
189702	189492	14265W	PARTICIPANT	\N	PRESENT	0
189703	189492	08031R	PARTICIPANT	\N	PRESENT	0
189704	189492	14135M	PARTICIPANT	\N	PRESENT	0
189705	189492	01031L	PARTICIPANT	\N	PRESENT	0
189706	189492	08034U	PARTICIPANT	\N	PRESENT	0
189707	189492	07034Q	PARTICIPANT	\N	PRESENT	0
189708	189492	04085P	PARTICIPANT	\N	PRESENT	0
189709	189492	04086Q	PARTICIPANT	\N	PRESENT	0
189710	189492	95063L	PARTICIPANT	\N	PRESENT	0
189711	189492	04074L	PARTICIPANT	\N	PRESENT	0
189712	189492	04056J	PARTICIPANT	\N	PRESENT	0
189713	189492	08009T	PARTICIPANT	\N	PRESENT	0
189714	189492	04097T	PARTICIPANT	\N	PRESENT	0
189715	189492	04043D	PARTICIPANT	\N	PRESENT	0
189716	189492	01047U	PARTICIPANT	\N	PRESENT	0
189717	189492	01057W	PARTICIPANT	\N	PRESENT	0
189718	189492	01061S	PARTICIPANT	\N	PRESENT	0
189719	189492	01028R	PARTICIPANT	\N	PRESENT	0
189720	189492	08060W	PARTICIPANT	\N	PRESENT	0
189721	189492	08025T	PARTICIPANT	\N	PRESENT	0
189722	189492	08049C	PARTICIPANT	\N	PRESENT	0
189723	189492	08053X	PARTICIPANT	\N	PRESENT	0
189724	189492	08018U	PARTICIPANT	\N	PRESENT	0
189725	189492	04035D	PARTICIPANT	\N	PRESENT	0
189726	189492	04057K	PARTICIPANT	\N	PRESENT	0
189727	189492	08052W	PARTICIPANT	\N	PRESENT	0
189728	189492	08058D	PARTICIPANT	\N	PRESENT	0
189729	189492	04038G	PARTICIPANT	\N	PRESENT	0
189730	189492	08055A	PARTICIPANT	\N	PRESENT	0
189731	189492	11033F	PARTICIPANT	\N	PRESENT	0
189732	189492	14030Q	PARTICIPANT	\N	PRESENT	0
189733	189492	14093U	PARTICIPANT	\N	PRESENT	0
189734	189492	14119M	PARTICIPANT	\N	PRESENT	0
189735	189492	14251Q	PARTICIPANT	\N	PRESENT	0
189736	189492	14063N	PARTICIPANT	\N	PRESENT	0
189737	189492	14069U	PARTICIPANT	\N	PRESENT	0
189738	189492	14355X	PARTICIPANT	\N	PRESENT	0
189739	189492	14357A	PARTICIPANT	\N	PRESENT	0
189740	189492	14079W	PARTICIPANT	\N	PRESENT	0
189741	189492	14026U	PARTICIPANT	\N	PRESENT	0
189742	189492	14269B	PARTICIPANT	\N	PRESENT	0
189743	189492	11063M	PARTICIPANT	\N	PRESENT	0
189744	189492	11035H	PARTICIPANT	\N	PRESENT	0
189745	189492	14087W	PARTICIPANT	\N	PRESENT	0
189746	189492	14107H	PARTICIPANT	\N	PRESENT	0
189747	189492	14195A	PARTICIPANT	\N	PRESENT	0
189748	189492	14111D	PARTICIPANT	\N	PRESENT	0
189749	189492	14031R	PARTICIPANT	\N	PRESENT	0
189750	189492	11026G	PARTICIPANT	\N	PRESENT	0
189751	189492	14028W	PARTICIPANT	\N	PRESENT	0
189752	189492	14033T	PARTICIPANT	\N	PRESENT	0
189753	189492	14159V	PARTICIPANT	\N	PRESENT	0
189754	189492	14173T	PARTICIPANT	\N	PRESENT	0
189755	189492	11037K	PARTICIPANT	\N	PRESENT	0
189756	189492	11085T	PARTICIPANT	\N	PRESENT	0
210456	210455	11053K	PARTICIPANT	\N	PRESENT	0
210457	210455	14159V	PARTICIPANT	\N	PRESENT	0
210458	210455	05012A	PARTICIPANT	\N	PRESENT	0
210462	210459	14159V	PARTICIPANT	\N	PRESENT	0
210463	210459	05012A	PARTICIPANT	\N	PRESENT	0
210766	207686	04044E	PARTICIPANT	\N	PRESENT	0
210767	207686	05008E	PARTICIPANT	\N	PRESENT	0
165954	165953	14239U	PARTICIPANT	\N	PRESENT	0
185408	185152	14215L	PARTICIPANT	\N	PRESENT	0
165956	165953	01046T	PARTICIPANT	\N	PRESENT	0
165957	165953	04053F	PARTICIPANT	\N	PRESENT	0
165958	165953	14255U	PARTICIPANT	\N	PRESENT	0
165959	165953	04066L	PARTICIPANT	\N	PRESENT	0
165960	165953	00003C	PARTICIPANT	\N	EXCUSE	0
165961	165953	14053L	PARTICIPANT	\N	PRESENT	0
165962	165953	11103C	PARTICIPANT	\N	PRESENT	0
169834	169832	11036J	PARTICIPANT	\N	PRESENT	0
165964	165953	14195A	PARTICIPANT	\N	PRESENT	0
165965	165953	14267Y	PARTICIPANT	\N	PRESENT	0
169835	169832	14013P	PARTICIPANT	\N	PRESENT	0
165967	165953	11031D	PARTICIPANT	\N	PRESENT	0
165968	165953	08052W	PARTICIPANT	\N	PRESENT	0
165969	165953	01059Y	PARTICIPANT	\N	PRESENT	0
165970	165953	04081K	PARTICIPANT	\N	PRESENT	0
165971	165953	98024R	PARTICIPANT	\N	PRESENT	0
165972	165953	10006L	PARTICIPANT	\N	PRESENT	0
185409	185152	08051V	PARTICIPANT	\N	PRESENT	0
165974	165953	14217N	PARTICIPANT	\N	PRESENT	0
165975	165953	14042U	PARTICIPANT	\N	PRESENT	0
165976	165953	14151M	PARTICIPANT	\N	PRESENT	0
165977	165953	12042Y	PARTICIPANT	\N	PRESENT	0
165978	165953	14281W	PARTICIPANT	\N	PRESENT	0
165979	165953	14087W	PARTICIPANT	\N	PRESENT	0
165980	165953	01003G	PARTICIPANT	\N	EXCUSE	0
185410	185152	14111D	PARTICIPANT	\N	PRESENT	0
165982	165953	14231L	PARTICIPANT	\N	PRESENT	0
165983	165953	11061K	PARTICIPANT	\N	PRESENT	0
165984	165953	14355X	PARTICIPANT	\N	PRESENT	0
169838	169832	04089T	PARTICIPANT	\N	PRESENT	0
165986	165953	08041T	PARTICIPANT	\N	PRESENT	0
165987	165953	01011G	PARTICIPANT	\N	PRESENT	0
165988	165953	14026U	PARTICIPANT	\N	EXCUSE	0
165989	165953	14213J	PARTICIPANT	\N	PRESENT	0
165990	165953	14121F	PARTICIPANT	\N	PRESENT	0
165991	165953	11112D	PARTICIPANT	\N	PRESENT	0
165992	165953	14037X	PARTICIPANT	\N	PRESENT	0
165993	165953	14018U	PARTICIPANT	\N	PRESENT	0
165994	165953	11067R	PARTICIPANT	\N	PRESENT	0
165995	165953	14223L	PARTICIPANT	\N	PRESENT	0
165996	165953	04092N	PRESIDENT	0	PRESENT	0
165997	165953	14265W	PARTICIPANT	\N	PRESENT	0
165998	165953	14119M	PARTICIPANT	\N	PRESENT	0
165999	165953	14071N	PARTICIPANT	\N	PRESENT	0
166000	165953	04043D	PARTICIPANT	\N	PRESENT	0
166001	165953	14271U	PARTICIPANT	\N	PRESENT	0
185411	185152	04056J	PARTICIPANT	\N	PRESENT	0
166003	165953	11093T	PARTICIPANT	\N	PRESENT	0
166004	165953	11097X	PARTICIPANT	\N	PRESENT	0
166005	165953	04045F	PARTICIPANT	\N	PRESENT	0
166006	165953	14227Q	PARTICIPANT	\N	PRESENT	0
166007	165953	01034P	PARTICIPANT	\N	PRESENT	0
166008	165953	11025F	PARTICIPANT	\N	PRESENT	0
166009	165953	11063M	PARTICIPANT	\N	PRESENT	0
185412	185152	08018U	PARTICIPANT	\N	PRESENT	0
185413	185152	11084S	PARTICIPANT	\N	EXCUSE	0
169841	169832	08015R	PARTICIPANT	\N	PRESENT	0
169842	169832	11100Y	PARTICIPANT	\N	PRESENT	0
185414	185152	04038G	PARTICIPANT	\N	EXCUSE	0
169844	169832	14257W	PARTICIPANT	\N	PRESENT	0
169845	169832	98050T	PARTICIPANT	\N	PRESENT	0
185574	185572	14133K	PARTICIPANT	\N	PRESENT	0
185415	185152	95049N	PARTICIPANT	\N	EXCUSE	0
185416	185152	11033F	PARTICIPANT	\N	EXCUSE	0
185573	185572	08024S	PARTICIPANT	\N	PRESENT	0
185575	185572	14265W	PARTICIPANT	\N	PRESENT	0
185577	185576	14133K	PARTICIPANT	\N	PRESENT	0
185578	185576	14265W	PARTICIPANT	\N	PRESENT	0
185813	185812	96004D	PARTICIPANT	\N	PRESENT	0
185832	185796	01013J	PARTICIPANT	\N	EXCUSE	0
185833	185796	11083R	PARTICIPANT	\N	EXCUSE	0
185834	185796	01057W	PARTICIPANT	\N	EXCUSE	0
185835	185796	92039X	PARTICIPANT	\N	EXCUSE	0
185836	185796	14225N	PARTICIPANT	\N	EXCUSE	0
185837	185796	11012A	PARTICIPANT	\N	EXCUSE	0
185838	185796	14157T	PARTICIPANT	\N	EXCUSE	0
186113	186112	08034U	PARTICIPANT	\N	PRESENT	0
186133	186132	08034U	PARTICIPANT	\N	PRESENT	0
186479	186478	14207L	PARTICIPANT	\N	PRESENT	0
186480	186478	14089Y	PARTICIPANT	\N	PRESENT	0
186481	186478	14229S	PARTICIPANT	\N	PRESENT	0
186492	186172	89017R	PARTICIPANT	\N	PRESENT	0
186913	186912	08052W	PARTICIPANT	\N	PRESENT	0
186914	186912	11097X	PARTICIPANT	\N	PRESENT	0
186933	186932	08010L	PARTICIPANT	\N	PRESENT	0
186953	186952	89017R	PARTICIPANT	\N	PRESENT	0
186972	186954	11048N	PARTICIPANT	\N	PRESENT	0
186974	186973	11074Q	PARTICIPANT	\N	PRESENT	0
186975	186973	11083R	PARTICIPANT	\N	PRESENT	0
186977	186976	11074Q	PARTICIPANT	\N	PRESENT	0
186978	186976	11083R	PARTICIPANT	\N	PRESENT	0
186980	186979	11074Q	PARTICIPANT	\N	PRESENT	0
186981	186979	11083R	PARTICIPANT	\N	PRESENT	0
186993	186992	11074Q	PARTICIPANT	\N	PRESENT	0
186994	186992	11083R	PARTICIPANT	\N	PRESENT	0
187037	187036	11083R	PARTICIPANT	\N	PRESENT	0
186997	186995	11083R	PARTICIPANT	\N	PRESENT	0
187053	187052	11083R	PARTICIPANT	\N	PRESENT	0
187000	186998	11083R	PARTICIPANT	\N	PRESENT	0
187378	187377	89017R	PARTICIPANT	\N	PRESENT	0
187003	187001	11083R	PARTICIPANT	\N	PRESENT	0
187033	187032	08011M	PARTICIPANT	\N	PRESENT	0
187035	187034	04034C	PARTICIPANT	\N	PRESENT	0
187380	187379	89017R	PARTICIPANT	\N	PRESENT	0
188013	188012	04034C	PARTICIPANT	\N	PRESENT	0
188193	188192	14263U	PARTICIPANT	\N	PRESENT	0
188194	188192	04059M	PARTICIPANT	\N	PRESENT	0
188195	188192	14241N	PARTICIPANT	\N	PRESENT	0
188196	188192	08039A	PARTICIPANT	\N	PRESENT	0
188197	188192	04057K	PARTICIPANT	\N	PRESENT	0
188198	188192	04070G	PARTICIPANT	\N	PRESENT	0
188253	188252	09001P	PARTICIPANT	\N	PRESENT	0
188254	188252	14030Q	PARTICIPANT	\N	EXCUSE	0
188255	188252	08043V	PARTICIPANT	\N	EXCUSE	0
188256	188252	11029K	PARTICIPANT	\N	EXCUSE	0
188257	188252	14041T	PARTICIPANT	\N	EXCUSE	0
188258	188252	11061K	PARTICIPANT	\N	EXCUSE	0
188259	188252	07026Q	PARTICIPANT	\N	EXCUSE	0
188260	188252	04036E	PARTICIPANT	\N	EXCUSE	0
188261	188252	07029T	PARTICIPANT	\N	EXCUSE	0
188262	188252	08017T	PARTICIPANT	\N	EXCUSE	0
188263	188252	14031R	PARTICIPANT	\N	EXCUSE	0
188264	188252	11014C	PARTICIPANT	\N	EXCUSE	0
188265	188252	14109K	PARTICIPANT	\N	EXCUSE	0
188266	188252	14265W	PARTICIPANT	\N	EXCUSE	0
188373	188372	08009T	PARTICIPANT	\N	PRESENT	0
188407	188392	98046X	PARTICIPANT	\N	PRESENT	0
188408	188392	11083R	PARTICIPANT	\N	PRESENT	0
188409	188392	04045F	PARTICIPANT	\N	PRESENT	0
188410	188392	98035U	PARTICIPANT	\N	PRESENT	0
188411	188392	04034C	PARTICIPANT	\N	PRESENT	0
188412	188392	14135M	PARTICIPANT	\N	PRESENT	0
188434	188432	11036J	PARTICIPANT	\N	PRESENT	0
188437	188432	08068F	PARTICIPANT	\N	PRESENT	0
188438	188432	14207L	PARTICIPANT	\N	PRESENT	0
188441	188432	08028W	PARTICIPANT	\N	EXCUSE	0
188443	188432	14357A	PARTICIPANT	\N	EXCUSE	0
188444	188432	08038Y	PARTICIPANT	\N	PRESENT	0
188446	188432	14197C	PARTICIPANT	\N	PRESENT	0
188449	188432	14033T	PARTICIPANT	\N	PRESENT	0
188451	188432	11099A	PARTICIPANT	\N	EXCUSE	0
188452	188432	04049K	PARTICIPANT	\N	PRESENT	0
188455	188432	08015R	PARTICIPANT	\N	EXCUSE	0
188456	188432	11100Y	PRESIDENT	0	PRESENT	0
188457	188432	01061S	PARTICIPANT	\N	EXCUSE	0
188462	188432	08019V	PARTICIPANT	\N	PRESENT	0
188463	188432	14257W	PARTICIPANT	\N	PRESENT	0
200354	190794	04081K	PARTICIPANT	\N	PRESENT	0
200355	190794	14083S	PARTICIPANT	\N	PRESENT	0
200356	190794	07029T	PARTICIPANT	\N	PRESENT	0
200357	190794	14261S	PARTICIPANT	\N	PRESENT	0
200358	190794	04034C	PARTICIPANT	\N	PRESENT	0
200359	190794	04086Q	PARTICIPANT	\N	PRESENT	0
200360	190794	01027Q	PARTICIPANT	\N	PRESENT	0
200361	190794	98053W	PARTICIPANT	\N	PRESENT	0
200553	200552	11026G	PARTICIPANT	\N	PRESENT	0
200554	200552	10015M	PARTICIPANT	\N	PRESENT	0
200593	200592	86044G	PARTICIPANT	\N	PRESENT	0
200594	200592	11027H	PARTICIPANT	\N	PRESENT	0
200596	200595	08039A	PARTICIPANT	\N	EXCUSE	0
200597	200595	14235Q	PARTICIPANT	\N	EXCUSE	0
200598	200595	11082Q	PARTICIPANT	\N	EXCUSE	0
201015	200613	08041T	PARTICIPANT	\N	PRESENT	0
201016	200613	11093T	PARTICIPANT	\N	EXCUSE	0
201017	190796	14119M	PARTICIPANT	\N	PRESENT	0
201018	190796	14209N	PARTICIPANT	\N	PRESENT	0
201019	190796	11034G	PARTICIPANT	\N	PRESENT	0
201020	190796	11109J	PARTICIPANT	\N	PRESENT	0
201021	190796	11111C	PARTICIPANT	\N	PRESENT	0
201022	190796	11031D	PARTICIPANT	\N	PRESENT	0
201023	200613	01034P	PARTICIPANT	\N	PRESENT	0
201024	190796	14105F	PARTICIPANT	\N	PRESENT	0
201216	200614	14042U	PARTICIPANT	\N	PRESENT	0
201217	200614	10006L	PARTICIPANT	\N	PRESENT	0
201218	200614	08052W	PARTICIPANT	\N	PRESENT	0
201219	200614	11023D	PARTICIPANT	\N	PRESENT	0
201220	200614	11103C	PARTICIPANT	\N	PRESENT	0
201221	200614	04043D	PARTICIPANT	\N	PRESENT	0
201222	200614	00003C	PARTICIPANT	\N	EXCUSE	0
201223	190797	12041X	PARTICIPANT	\N	PRESENT	0
201224	190797	08052W	PARTICIPANT	\N	PRESENT	0
201225	190797	14121F	PARTICIPANT	\N	PRESENT	0
201226	190797	01016M	PARTICIPANT	\N	PRESENT	0
201227	190797	98046X	PARTICIPANT	\N	PRESENT	0
201164	201041	08061X	PARTICIPANT	\N	EXCUSE	0
201165	200614	14355X	PARTICIPANT	\N	PRESENT	0
201166	200614	04092N	PARTICIPANT	\N	PRESENT	0
201167	200614	11097X	PARTICIPANT	\N	PRESENT	0
201168	200614	14034U	PARTICIPANT	\N	PRESENT	0
201169	200614	14227Q	PARTICIPANT	\N	PRESENT	0
201170	200614	14269B	PARTICIPANT	\N	PRESENT	0
201171	200614	11112D	PARTICIPANT	\N	PRESENT	0
201172	200614	04081K	PARTICIPANT	\N	PRESENT	0
201173	200614	11063M	PARTICIPANT	\N	PRESENT	0
201174	200614	14231L	PARTICIPANT	\N	PRESENT	0
201175	200614	14119M	PARTICIPANT	\N	PRESENT	0
201176	200614	14281W	PARTICIPANT	\N	PRESENT	0
201177	200614	14087W	PARTICIPANT	\N	PRESENT	0
201178	200614	14267Y	PARTICIPANT	\N	PRESENT	0
201179	200614	14195A	PARTICIPANT	\N	PRESENT	0
201180	200614	14121F	PARTICIPANT	\N	PRESENT	0
201181	200614	14213J	PARTICIPANT	\N	PRESENT	0
201182	200614	14071N	PARTICIPANT	\N	PRESENT	0
201183	200614	14217N	PARTICIPANT	\N	PRESENT	0
201184	200614	98024R	PRESIDENT	0	PRESENT	0
201185	200614	14265W	PARTICIPANT	\N	PRESENT	0
201186	200614	04053F	PARTICIPANT	\N	PRESENT	0
201187	200614	14017T	PARTICIPANT	\N	EXCUSE	0
201188	200614	11061K	PARTICIPANT	\N	PRESENT	0
201189	200614	04045F	PARTICIPANT	\N	PRESENT	0
201190	200614	14026U	PARTICIPANT	\N	PRESENT	0
201191	200614	14151M	PARTICIPANT	\N	PRESENT	0
201192	200614	12042Y	PARTICIPANT	\N	PRESENT	0
201193	200614	08041T	PARTICIPANT	\N	PRESENT	0
201228	190797	14085U	PARTICIPANT	\N	PRESENT	0
201229	190797	14227Q	PARTICIPANT	\N	PRESENT	0
201230	190797	14063N	PARTICIPANT	\N	PRESENT	0
201231	190797	14097Y	PARTICIPANT	\N	PRESENT	0
201232	190797	04085P	PARTICIPANT	\N	PRESENT	0
201233	190797	01015L	PARTICIPANT	\N	PRESENT	0
201234	190797	04045F	PARTICIPANT	\N	PRESENT	0
201235	190797	08016S	PARTICIPANT	\N	PRESENT	0
201236	190797	11023D	PARTICIPANT	\N	PRESENT	0
201237	190797	08017T	PARTICIPANT	\N	PRESENT	0
201238	190797	01022K	PARTICIPANT	\N	PRESENT	0
201239	190797	01059Y	PARTICIPANT	\N	PRESENT	0
201240	190797	11063M	PARTICIPANT	\N	PRESENT	0
201241	190797	11031D	PARTICIPANT	\N	PRESENT	0
201242	190797	01013J	PARTICIPANT	\N	PRESENT	0
201243	190797	11034G	PARTICIPANT	\N	PRESENT	0
201244	190797	11054L	PARTICIPANT	\N	PRESENT	0
201245	190797	07026Q	PARTICIPANT	\N	PRESENT	0
201246	190797	14361V	PARTICIPANT	\N	PRESENT	0
201247	190797	11098Y	PARTICIPANT	\N	PRESENT	0
201248	190797	14151M	PARTICIPANT	\N	PRESENT	0
201249	190797	04059M	PARTICIPANT	\N	PRESENT	0
201250	190797	11061K	PARTICIPANT	\N	PRESENT	0
201251	190797	14239U	PARTICIPANT	\N	PRESENT	0
201252	190797	11057P	PARTICIPANT	\N	PRESENT	0
201253	190797	04053F	PARTICIPANT	\N	PRESENT	0
201255	190797	11107G	PARTICIPANT	\N	PRESENT	0
201256	190797	08011M	PARTICIPANT	\N	PRESENT	0
201257	190797	01031L	PARTICIPANT	\N	PRESENT	0
201258	190797	14261S	PARTICIPANT	\N	PRESENT	0
201259	190797	08043V	PARTICIPANT	\N	PRESENT	0
201260	190797	14241N	PARTICIPANT	\N	PRESENT	0
201261	190797	11029K	PARTICIPANT	\N	PRESENT	0
201262	190797	14103D	PARTICIPANT	\N	PRESENT	0
201263	190797	14042U	PARTICIPANT	\N	PRESENT	0
201264	190797	14267Y	PARTICIPANT	\N	PRESENT	0
201265	190797	14030Q	PARTICIPANT	\N	PRESENT	0
201266	190797	98024R	PARTICIPANT	\N	PRESENT	0
201267	190797	95030B	PARTICIPANT	\N	PRESENT	0
201268	190797	14026U	PARTICIPANT	\N	PRESENT	0
201269	190797	04047H	PARTICIPANT	\N	PRESENT	0
201270	190797	14269B	PARTICIPANT	\N	PRESENT	0
201271	190797	08055A	PARTICIPANT	\N	PRESENT	0
201272	190797	11045K	PARTICIPANT	\N	PRESENT	0
201273	190797	08068F	PARTICIPANT	\N	PRESENT	0
201274	190797	11089X	PARTICIPANT	\N	PRESENT	0
201275	190797	14197C	PARTICIPANT	\N	PRESENT	0
201276	190797	14235Q	PARTICIPANT	\N	PRESENT	0
201277	190797	14225N	PARTICIPANT	\N	PRESENT	0
201278	190797	11109J	PARTICIPANT	\N	PRESENT	0
201279	190797	14159V	PARTICIPANT	\N	PRESENT	0
201280	190797	11112D	PARTICIPANT	\N	PRESENT	0
201281	190797	11067R	PARTICIPANT	\N	PRESENT	0
201282	190797	11033F	PARTICIPANT	\N	PRESENT	0
201283	190797	11066Q	PARTICIPANT	\N	PRESENT	0
201284	190797	11104D	PARTICIPANT	\N	PRESENT	0
201285	190797	12042Y	PARTICIPANT	\N	PRESENT	0
201286	190797	08031R	PARTICIPANT	\N	PRESENT	0
201287	190797	08009T	PARTICIPANT	\N	PRESENT	0
201288	190797	14034U	PARTICIPANT	\N	PRESENT	0
201289	190797	14219Q	PARTICIPANT	\N	PRESENT	0
201290	190797	14221J	PARTICIPANT	\N	PRESENT	0
201291	190797	11036J	PARTICIPANT	\N	PRESENT	0
201292	190797	98022P	PARTICIPANT	\N	PRESENT	0
201305	190797	14249W	PARTICIPANT	\N	PRESENT	0
201306	190797	14217N	PARTICIPANT	\N	PRESENT	0
201307	190797	89017R	PARTICIPANT	\N	PRESENT	0
201308	190797	14281W	PARTICIPANT	\N	PRESENT	0
201309	190797	14207L	PARTICIPANT	\N	PRESENT	0
201310	190797	11077T	PARTICIPANT	\N	PRESENT	0
201311	190797	04044E	PARTICIPANT	\N	PRESENT	0
201312	190797	04035D	PARTICIPANT	\N	PRESENT	0
201313	190797	04033B	PARTICIPANT	\N	PRESENT	0
201314	190797	10006L	PARTICIPANT	\N	PRESENT	0
201315	190797	13002U	PARTICIPANT	\N	PRESENT	0
201316	190797	14069U	PARTICIPANT	\N	PRESENT	0
201317	190797	05012A	PARTICIPANT	\N	PRESENT	0
201318	190797	04057K	PARTICIPANT	\N	PRESENT	0
201319	190797	97011G	PARTICIPANT	\N	PRESENT	0
201320	190797	11103C	PARTICIPANT	\N	PRESENT	0
201321	190797	14363X	PARTICIPANT	\N	PRESENT	0
201322	190797	14331P	PARTICIPANT	\N	PRESENT	0
201323	190797	04061F	PARTICIPANT	\N	PRESENT	0
201324	190797	14187A	PARTICIPANT	\N	PRESENT	0
201325	190797	11090Q	PARTICIPANT	\N	PRESENT	0
201326	190797	14053L	PARTICIPANT	\N	PRESENT	0
201327	190797	01008M	PARTICIPANT	\N	PRESENT	0
201328	190797	01041N	PARTICIPANT	\N	PRESENT	0
201329	190797	14061L	PARTICIPANT	\N	PRESENT	0
201330	190797	14059S	PARTICIPANT	\N	PRESENT	0
201331	190797	14209N	PARTICIPANT	\N	PRESENT	0
201332	190797	99004R	PARTICIPANT	\N	PRESENT	0
201333	190797	01027Q	PARTICIPANT	\N	PRESENT	0
201334	190797	95015C	PARTICIPANT	\N	PRESENT	0
201335	190797	08039A	PARTICIPANT	\N	PRESENT	0
201336	190797	95067Q	PARTICIPANT	\N	PRESENT	0
201337	190797	08010L	PARTICIPANT	\N	PRESENT	0
201338	190797	08069G	PARTICIPANT	\N	PRESENT	0
201339	190797	11100Y	PARTICIPANT	\N	PRESENT	0
201340	190797	08041T	PARTICIPANT	\N	PRESENT	0
201341	190797	87003B	PARTICIPANT	\N	PRESENT	0
201342	190797	14259Y	PARTICIPANT	\N	PRESENT	0
174093	174092	89017R	PARTICIPANT	\N	PRESENT	0
174094	174092	11039M	PARTICIPANT	\N	PRESENT	0
174095	174092	08055A	PARTICIPANT	\N	PRESENT	0
174096	174092	11029K	PARTICIPANT	\N	PRESENT	0
174097	174092	04066L	PARTICIPANT	\N	PRESENT	0
174098	174092	04042C	PARTICIPANT	\N	PRESENT	0
174099	174092	08024S	PARTICIPANT	\N	PRESENT	0
174100	174092	04081K	PARTICIPANT	\N	PRESENT	0
174101	174092	98042T	PARTICIPANT	\N	PRESENT	0
174102	174092	11110B	PARTICIPANT	\N	PRESENT	0
174103	174092	98053W	PARTICIPANT	\N	PRESENT	0
174104	174092	08048B	PARTICIPANT	\N	PRESENT	0
174105	174092	01007L	PARTICIPANT	\N	PRESENT	0
174106	174092	95037J	PARTICIPANT	\N	PRESENT	0
174107	174092	86034E	PARTICIPANT	\N	PRESENT	0
174108	174092	04094Q	PARTICIPANT	\N	PRESENT	0
174109	174092	08039A	PARTICIPANT	\N	PRESENT	0
174110	174092	01043Q	PARTICIPANT	\N	PRESENT	0
174111	174092	11085T	PARTICIPANT	\N	PRESENT	0
174112	174092	04057K	PARTICIPANT	\N	PRESENT	0
174113	174092	92040Q	PARTICIPANT	\N	PRESENT	0
174114	174092	04088S	PARTICIPANT	\N	PRESENT	0
174115	174092	01019Q	PARTICIPANT	\N	PRESENT	0
174116	174092	04056J	PARTICIPANT	\N	PRESENT	0
192877	192876	98018T	PARTICIPANT	\N	PRESENT	0
192879	192878	14097Y	PARTICIPANT	\N	PRESENT	0
192912	190776	86034E	PARTICIPANT	\N	PRESENT	0
192913	190776	04059M	PARTICIPANT	\N	PRESENT	0
192914	190776	01028R	PARTICIPANT	\N	PRESENT	0
192915	190776	07034Q	PARTICIPANT	\N	PRESENT	0
192916	190776	14215L	PARTICIPANT	\N	PRESENT	0
192917	190776	00003C	PARTICIPANT	\N	PRESENT	0
192932	190776	07026Q	PARTICIPANT	\N	PRESENT	0
192933	190776	11054L	PARTICIPANT	\N	PRESENT	0
192934	190776	08043V	PARTICIPANT	\N	PRESENT	0
192935	190776	14269B	PARTICIPANT	\N	PRESENT	0
192936	190776	08011M	PARTICIPANT	\N	PRESENT	0
192937	190776	05008E	PARTICIPANT	\N	PRESENT	0
192938	190776	04056J	PARTICIPANT	\N	PRESENT	0
192939	190776	11026G	PARTICIPANT	\N	PRESENT	0
192940	190776	04053F	PARTICIPANT	\N	PRESENT	0
192941	190776	95063L	PARTICIPANT	\N	PRESENT	0
192942	190776	14159V	PARTICIPANT	\N	PRESENT	0
192943	190776	14107H	PARTICIPANT	\N	PRESENT	0
192944	190776	11037K	PARTICIPANT	\N	PRESENT	0
192945	190776	11109J	PARTICIPANT	\N	PRESENT	0
192946	190776	08073C	PARTICIPANT	\N	PRESENT	0
192947	190776	14039A	PARTICIPANT	\N	PRESENT	0
192948	190776	11029K	PARTICIPANT	\N	PRESENT	0
192949	190776	14219Q	PARTICIPANT	\N	PRESENT	0
192950	190776	11053K	PARTICIPANT	\N	PRESENT	0
192951	190776	01046T	PARTICIPANT	\N	PRESENT	0
192952	190776	14261S	PARTICIPANT	\N	PRESENT	0
192953	190776	04038G	PARTICIPANT	\N	PRESENT	0
192954	190776	08017T	PARTICIPANT	\N	PRESENT	0
192955	190776	08019V	PARTICIPANT	\N	PRESENT	0
192956	190776	14357A	PARTICIPANT	\N	PRESENT	0
192957	190776	07029T	PARTICIPANT	\N	PRESENT	0
192958	190776	01056V	PARTICIPANT	\N	PRESENT	0
192959	190776	98005N	PARTICIPANT	\N	PRESENT	0
192960	190776	11011M	PARTICIPANT	\N	PRESENT	0
192961	190776	11100Y	PARTICIPANT	\N	PRESENT	0
192962	190776	04043D	PARTICIPANT	\N	PRESENT	0
192963	190776	11080N	PARTICIPANT	\N	PRESENT	0
192964	190776	04066L	PARTICIPANT	\N	PRESENT	0
192965	190776	99004R	PARTICIPANT	\N	PRESENT	0
192966	190776	14041T	PARTICIPANT	\N	PRESENT	0
192967	190776	14111D	PARTICIPANT	\N	PRESENT	0
192968	190776	95062K	PARTICIPANT	\N	PRESENT	0
192969	190776	04085P	PARTICIPANT	\N	PRESENT	0
192970	190776	01027Q	PARTICIPANT	\N	PRESENT	0
192971	190776	14265W	PARTICIPANT	\N	PRESENT	0
192972	190776	04080J	PARTICIPANT	\N	PRESENT	0
192973	190776	02002K	PARTICIPANT	\N	PRESENT	0
192974	190776	08060W	PARTICIPANT	\N	PRESENT	0
192975	190776	14271U	PARTICIPANT	\N	PRESENT	0
192976	190776	11027H	PARTICIPANT	\N	PRESENT	0
192977	190776	11091R	PARTICIPANT	\N	PRESENT	0
192978	190776	14251Q	PARTICIPANT	\N	PRESENT	0
192992	190776	08016S	PARTICIPANT	\N	PRESENT	0
192993	190776	11089X	PARTICIPANT	\N	PRESENT	0
193012	190776	04042C	PARTICIPANT	\N	PRESENT	0
193013	190776	14275Y	PARTICIPANT	\N	PRESENT	0
193032	190776	14069U	PARTICIPANT	\N	PRESENT	0
193052	190776	04081K	PARTICIPANT	\N	PRESENT	0
193092	190776	14151M	PARTICIPANT	\N	PRESENT	0
193093	190776	14229S	PARTICIPANT	\N	PRESENT	0
196273	196272	11039M	PARTICIPANT	\N	PRESENT	0
196274	196272	98042T	PARTICIPANT	\N	PRESENT	0
196275	196272	01019Q	PARTICIPANT	\N	PRESENT	0
196813	196812	10015M	PARTICIPANT	\N	PRESENT	0
196537	196535	11055M	PARTICIPANT	\N	PRESENT	0
196814	196812	11026G	PARTICIPANT	\N	PRESENT	0
196539	196535	04053F	PARTICIPANT	\N	PRESENT	0
196540	196535	14255U	PARTICIPANT	\N	PRESENT	0
196541	196535	04066L	PARTICIPANT	\N	PRESENT	0
196542	196535	00003C	PARTICIPANT	\N	EXCUSE	0
196543	196535	14053L	PARTICIPANT	\N	PRESENT	0
196544	196535	11103C	PARTICIPANT	\N	PRESENT	0
197152	192772	04044E	PARTICIPANT	\N	EXCUSE	0
196546	196535	14195A	PARTICIPANT	\N	PRESENT	0
197155	192792	04071H	PARTICIPANT	\N	PRESENT	0
196548	196535	11023D	PARTICIPANT	\N	EXCUSE	0
196549	196535	11031D	PARTICIPANT	\N	PRESENT	0
196550	196535	08052W	PARTICIPANT	\N	PRESENT	0
196551	196535	01059Y	PARTICIPANT	\N	PRESENT	0
196552	196535	04081K	PARTICIPANT	\N	PRESENT	0
196553	196535	98024R	PARTICIPANT	\N	PRESENT	0
196554	196535	10006L	PARTICIPANT	\N	PRESENT	0
197156	192792	08069G	PARTICIPANT	\N	PRESENT	0
196556	196535	14217N	PARTICIPANT	\N	PRESENT	0
197270	197269	07026Q	PARTICIPANT	\N	PRESENT	0
196558	196535	14151M	PARTICIPANT	\N	EXCUSE	0
196559	196535	12042Y	PARTICIPANT	\N	PRESENT	0
196560	196535	14281W	PARTICIPANT	\N	PRESENT	0
196561	196535	14087W	PARTICIPANT	\N	PRESENT	0
196562	196535	14034U	PARTICIPANT	\N	PRESENT	0
196563	196535	14231L	PARTICIPANT	\N	PRESENT	0
196564	196535	11061K	PARTICIPANT	\N	PRESENT	0
197271	197269	14249W	PARTICIPANT	\N	PRESENT	0
197272	197269	08031R	PARTICIPANT	\N	PRESENT	0
196567	196535	08041T	PARTICIPANT	\N	PRESENT	0
196568	196535	01011G	PARTICIPANT	\N	PRESENT	0
197273	197269	08043V	PARTICIPANT	\N	PRESENT	0
196570	196535	14213J	PARTICIPANT	\N	PRESENT	0
196571	196535	14121F	PARTICIPANT	\N	PRESENT	0
196572	196535	11112D	PARTICIPANT	\N	PRESENT	0
201773	201772	08055A	PARTICIPANT	\N	PRESENT	0
201774	201772	14093U	PARTICIPANT	\N	PRESENT	0
196575	196535	11067R	PARTICIPANT	\N	PRESENT	0
196576	196535	14223L	PARTICIPANT	\N	PRESENT	0
196577	196535	04092N	PRESIDENT	0	PRESENT	0
196578	196535	14265W	PARTICIPANT	\N	PRESENT	0
196579	196535	14119M	PARTICIPANT	\N	PRESENT	0
196580	196535	14071N	PARTICIPANT	\N	PRESENT	0
196581	196535	04043D	PARTICIPANT	\N	PRESENT	0
196582	196535	14271U	PARTICIPANT	\N	PRESENT	0
201775	201772	14030Q	PARTICIPANT	\N	PRESENT	0
196584	196535	11093T	PARTICIPANT	\N	EXCUSE	0
196585	196535	11097X	PARTICIPANT	\N	PRESENT	0
196586	196535	04045F	PARTICIPANT	\N	PRESENT	0
196587	196535	14227Q	PARTICIPANT	\N	PRESENT	0
196588	196535	01034P	PARTICIPANT	\N	PRESENT	0
201776	201772	96004D	PARTICIPANT	\N	PRESENT	0
196590	196535	11063M	PARTICIPANT	\N	PRESENT	0
196591	196535	14269B	PARTICIPANT	\N	PRESENT	0
201777	201772	11095V	PARTICIPANT	\N	PRESENT	0
201778	201772	11065P	PARTICIPANT	\N	PRESENT	0
201779	201772	01015L	PARTICIPANT	\N	PRESENT	0
201780	201772	11107G	PARTICIPANT	\N	PRESENT	0
201781	201772	01022K	PARTICIPANT	\N	PRESENT	0
201782	201772	04097T	PARTICIPANT	\N	PRESENT	0
201783	201772	11059R	PARTICIPANT	\N	PRESENT	0
201784	201772	14219Q	PARTICIPANT	\N	PRESENT	0
201785	201772	80027E	PARTICIPANT	\N	PRESENT	0
201786	201772	14031R	PARTICIPANT	\N	PRESENT	0
201787	201772	08009T	PARTICIPANT	\N	PRESENT	0
201788	201772	14221J	PARTICIPANT	\N	PRESENT	0
201789	201772	92039X	PARTICIPANT	\N	PRESENT	0
201790	201772	14169X	PARTICIPANT	\N	PRESENT	0
201791	201772	13002U	PARTICIPANT	\N	PRESENT	0
201792	201772	05012A	PARTICIPANT	\N	PRESENT	0
201793	201772	14135M	PARTICIPANT	\N	PRESENT	0
201794	201772	95062K	PARTICIPANT	\N	PRESENT	0
201795	201772	14107H	PARTICIPANT	\N	PRESENT	0
201796	201772	14157T	PARTICIPANT	\N	PRESENT	0
201797	201772	08042U	PARTICIPANT	\N	PRESENT	0
185513	185512	11035H	PARTICIPANT	\N	EXCUSE	0
185514	185512	04061F	PARTICIPANT	\N	EXCUSE	0
185515	185512	92045V	PARTICIPANT	\N	EXCUSE	0
185516	185512	04034C	PARTICIPANT	\N	EXCUSE	0
185517	185512	11012A	PARTICIPANT	\N	EXCUSE	0
185518	185512	96004D	PRESIDENT	0	PRESENT	0
185519	185512	14089Y	PARTICIPANT	\N	PRESENT	0
185520	185512	95030B	PARTICIPANT	\N	PRESENT	0
185521	185512	11083R	PARTICIPANT	\N	PRESENT	0
185522	185512	14026U	PARTICIPANT	\N	PRESENT	0
185523	185512	14073Q	PARTICIPANT	\N	PRESENT	0
185524	185512	98046X	PARTICIPANT	\N	PRESENT	0
185525	185512	14001X	PARTICIPANT	\N	PRESENT	0
185526	185512	01016M	PARTICIPANT	\N	PRESENT	0
185527	185512	11100Y	PARTICIPANT	\N	PRESENT	0
185528	185512	08068F	PARTICIPANT	\N	PRESENT	0
185529	185512	11066Q	PARTICIPANT	\N	PRESENT	0
185530	185512	14207L	PARTICIPANT	\N	PRESENT	0
185531	185512	11098Y	PARTICIPANT	\N	PRESENT	0
185532	185512	14197C	PARTICIPANT	\N	PRESENT	0
185533	185512	11036J	PARTICIPANT	\N	PRESENT	0
185534	185512	11046L	PARTICIPANT	\N	PRESENT	0
185535	185512	14257W	PARTICIPANT	\N	PRESENT	0
185536	185512	14013P	PARTICIPANT	\N	PRESENT	0
185537	185512	14033T	PARTICIPANT	\N	PRESENT	0
185538	185512	98050T	PARTICIPANT	\N	PRESENT	0
185539	185512	01008M	PARTICIPANT	\N	PRESENT	0
185540	185512	14187A	PARTICIPANT	\N	PRESENT	0
185552	185512	04049K	PARTICIPANT	\N	PRESENT	0
185553	185512	14357A	PARTICIPANT	\N	PRESENT	0
205674	205673	14065Q	PARTICIPANT	\N	PRESENT	0
205675	205673	04047H	PARTICIPANT	\N	PRESENT	0
209765	209764	95067Q	PARTICIPANT	\N	PRESENT	0
210044	210043	19253P	PARTICIPANT	\N	EXCUSE	0
210106	210105	10006L	PARTICIPANT	\N	PRESENT	0
210480	207685	19731Y	PARTICIPANT	\N	PRESENT	0
210481	207685	19443T	PARTICIPANT	\N	PRESENT	0
210482	207685	08047A	PARTICIPANT	\N	PRESENT	0
210483	207685	14105F	PARTICIPANT	\N	PRESENT	0
210484	207685	19593H	PARTICIPANT	\N	PRESENT	0
210485	207685	14235Q	PARTICIPANT	\N	PRESENT	0
210486	207685	19347U	PARTICIPANT	\N	PRESENT	0
210478	207685	86034E	PARTICIPANT	\N	PRESENT	0
210479	207685	12016W	PARTICIPANT	\N	PRESENT	0
210487	207685	19413M	PARTICIPANT	\N	PRESENT	0
210488	207685	19251M	PARTICIPANT	\N	PRESENT	0
210489	207685	11054L	PARTICIPANT	\N	PRESENT	0
210490	207685	19683J	PARTICIPANT	\N	PRESENT	0
210491	207685	19695N	PARTICIPANT	\N	PRESENT	0
210492	207685	08058D	PARTICIPANT	\N	PRESENT	0
210493	207685	19333N	PARTICIPANT	\N	PRESENT	0
210494	207685	14028W	PARTICIPANT	\N	PRESENT	0
210495	207685	19715Y	PARTICIPANT	\N	PRESENT	0
210496	207685	11041F	PARTICIPANT	\N	PRESENT	0
210497	207685	11066Q	PARTICIPANT	\N	PRESENT	0
210498	207685	01062T	PARTICIPANT	\N	PRESENT	0
210499	207685	04042C	PARTICIPANT	\N	PRESENT	0
210500	207685	98029W	PARTICIPANT	\N	PRESENT	0
210501	207685	95037J	PARTICIPANT	\N	PRESENT	0
210502	207685	88008L	PARTICIPANT	\N	PRESENT	0
210503	207685	04034C	PARTICIPANT	\N	PRESENT	0
210504	207685	11027H	PARTICIPANT	\N	PRESENT	0
210505	207685	98022P	PARTICIPANT	\N	PRESENT	0
210506	207685	19387D	PARTICIPANT	\N	PRESENT	0
210507	207685	19585H	PARTICIPANT	\N	PRESENT	0
210508	207685	11064N	PARTICIPANT	\N	PRESENT	0
210509	207685	08049C	PARTICIPANT	\N	PRESENT	0
210510	207685	19629C	PARTICIPANT	\N	PRESENT	0
210511	207685	19319Q	PARTICIPANT	\N	PRESENT	0
210512	207685	19713W	PARTICIPANT	\N	PRESENT	0
210513	207685	19441R	PARTICIPANT	\N	PRESENT	0
210514	207685	16685X	PARTICIPANT	\N	PRESENT	0
210515	207685	14327T	PARTICIPANT	\N	PRESENT	0
210516	207685	19737F	PARTICIPANT	\N	PRESENT	0
210517	207685	08056B	PARTICIPANT	\N	PRESENT	0
210518	207685	14255U	PARTICIPANT	\N	PRESENT	0
210519	207685	14267Y	PARTICIPANT	\N	PRESENT	0
210520	207685	14237S	PARTICIPANT	\N	PRESENT	0
210521	207685	17583W	PARTICIPANT	\N	PRESENT	0
210522	207685	19581D	PARTICIPANT	\N	PRESENT	0
210523	207685	19421M	PARTICIPANT	\N	PRESENT	0
210524	207685	04044E	PARTICIPANT	\N	PRESENT	0
210525	207685	04047H	PARTICIPANT	\N	PRESENT	0
210526	207685	17637T	PARTICIPANT	\N	PRESENT	0
210527	207685	04008A	PARTICIPANT	\N	PRESENT	0
210528	207685	14193X	PARTICIPANT	\N	PRESENT	0
210529	207685	08010L	PARTICIPANT	\N	PRESENT	0
210530	207685	08020N	PARTICIPANT	\N	PRESENT	0
210531	207685	19679N	PARTICIPANT	\N	PRESENT	0
210850	210145	14327T	PARTICIPANT	\N	PRESENT	0
210851	210145	14331P	PARTICIPANT	\N	PRESENT	0
210852	210145	19545Y	PARTICIPANT	\N	PRESENT	0
210853	210145	01057W	PARTICIPANT	\N	PRESENT	0
210854	210145	14081Q	RAPPORTEUR_AVIS	\N	PRESENT	0
210855	210145	19667J	PARTICIPANT	\N	PRESENT	0
210856	210145	11074Q	PRESIDENT	0	PRESENT	0
210857	210145	89017R	PARTICIPANT	\N	PRESENT	0
210858	210145	19671E	PARTICIPANT	\N	PRESENT	0
210859	210145	88008L	PRESIDENT	1	PRESENT	0
210860	210145	11070L	PARTICIPANT	\N	PRESENT	0
210861	210145	11110B	PARTICIPANT	\N	PRESENT	0
210862	210145	07029T	PARTICIPANT	\N	PRESENT	0
210863	210145	14085U	PARTICIPANT	\N	PRESENT	0
210864	210145	19349W	PARTICIPANT	\N	PRESENT	0
210865	210145	08010L	PARTICIPANT	\N	PRESENT	0
210866	210145	19479G	PARTICIPANT	\N	PRESENT	0
210867	210145	19711U	PARTICIPANT	\N	PRESENT	0
210868	210145	19651A	PARTICIPANT	\N	PRESENT	0
210869	210145	19531S	PARTICIPANT	\N	PRESENT	0
210870	210145	08034U	PARTICIPANT	\N	PRESENT	0
210871	210145	14187A	RAPPORTEUR_AVIS	\N	PRESENT	0
210872	210145	19687N	PARTICIPANT	\N	PRESENT	0
210873	210145	19689Q	PARTICIPANT	\N	PRESENT	0
210874	210145	12016W	PARTICIPANT	\N	PRESENT	0
210875	210145	08011M	PARTICIPANT	\N	PRESENT	0
210876	210145	14034U	PARTICIPANT	\N	PRESENT	0
210877	210145	14169X	RAPPORTEUR_AVIS	\N	PRESENT	0
210878	210145	14173T	PARTICIPANT	\N	PRESENT	0
210879	210145	04086Q	PARTICIPANT	\N	PRESENT	0
210880	210145	11040E	PARTICIPANT	\N	PRESENT	0
210881	210145	14083S	PARTICIPANT	\N	PRESENT	0
210882	210145	14119M	RAPPORTEUR_AVIS	\N	PRESENT	0
210883	210145	11012A	PARTICIPANT	\N	PRESENT	0
210884	210145	14199E	PARTICIPANT	\N	PRESENT	0
210885	210145	14121F	PARTICIPANT	\N	PRESENT	0
210886	210145	99004R	PARTICIPANT	\N	PRESENT	0
210887	210145	04061F	PARTICIPANT	\N	PRESENT	0
210888	210145	19647E	PARTICIPANT	\N	PRESENT	0
210889	210145	07004J	PARTICIPANT	\N	PRESENT	0
210890	210145	08073C	PARTICIPANT	\N	EXCUSE	0
210891	207686	14231L	PARTICIPANT	\N	PRESENT	0
210892	207686	19669L	PARTICIPANT	\N	PRESENT	0
210893	207686	14275Y	PARTICIPANT	\N	PRESENT	0
210897	207686	19713W	PARTICIPANT	\N	PRESENT	0
210898	207686	14237S	PARTICIPANT	\N	PRESENT	0
210906	207686	19581D	PARTICIPANT	\N	PRESENT	0
210907	210098	19721W	PARTICIPANT	\N	PRESENT	0
210910	207686	11070L	PARTICIPANT	\N	PRESENT	0
210911	207686	19549D	PARTICIPANT	\N	PRESENT	0
211027	210098	88008L	PARTICIPANT	\N	PRESENT	0
211028	207687	11072N	PARTICIPANT	\N	PRESENT	0
211029	207687	05008E	PARTICIPANT	\N	PRESENT	0
211030	207687	14065Q	PARTICIPANT	\N	PRESENT	0
211031	207687	04047H	PARTICIPANT	\N	PRESENT	0
211032	207687	01028R	PARTICIPANT	\N	PRESENT	0
211033	207687	14021P	PARTICIPANT	\N	PRESENT	0
211034	207687	11033F	PARTICIPANT	\N	PRESENT	0
211035	207687	04085P	PARTICIPANT	\N	PRESENT	0
211036	207687	19593H	PARTICIPANT	\N	PRESENT	0
211037	207687	19349W	PARTICIPANT	\N	PRESENT	0
211038	207687	19447X	PARTICIPANT	\N	PRESENT	0
211039	207687	19467C	PARTICIPANT	\N	PRESENT	0
211040	207687	08010L	PARTICIPANT	\N	PRESENT	0
211041	207687	19443T	PARTICIPANT	\N	PRESENT	0
211042	207687	08020N	PARTICIPANT	\N	PRESENT	0
211043	207687	01025N	PARTICIPANT	\N	PRESENT	0
211044	207687	14215L	PARTICIPANT	\N	PRESENT	0
211045	207687	19621T	PARTICIPANT	\N	PRESENT	0
211046	207687	19713W	PARTICIPANT	\N	PRESENT	0
211047	207687	19737F	PARTICIPANT	\N	PRESENT	0
211048	207687	08044W	PARTICIPANT	\N	PRESENT	0
211049	207687	14103D	PARTICIPANT	\N	PRESENT	0
211050	207687	14147R	PARTICIPANT	\N	PRESENT	0
211051	207687	14053L	PARTICIPANT	\N	PRESENT	0
211052	207687	19649G	PARTICIPANT	\N	PRESENT	0
211053	207687	19483C	PARTICIPANT	\N	PRESENT	0
211054	207687	07029T	PARTICIPANT	\N	PRESENT	0
211055	207687	14151M	PARTICIPANT	\N	PRESENT	0
169918	169852	11082Q	PARTICIPANT	\N	EXCUSE	0
169854	169852	14133K	PARTICIPANT	\N	PRESENT	0
177792	174352	11099A	PARTICIPANT	\N	EXCUSE	0
169856	169852	04040A	PARTICIPANT	\N	PRESENT	0
169857	169852	08058D	PARTICIPANT	\N	PRESENT	0
169858	169852	04042C	PARTICIPANT	\N	PRESENT	0
177793	174352	04044E	PARTICIPANT	\N	EXCUSE	0
169860	169852	98029W	PARTICIPANT	\N	PRESENT	0
188466	188432	98050T	PARTICIPANT	\N	PRESENT	0
169862	169852	11027H	PARTICIPANT	\N	PRESENT	0
169863	169852	98018T	PARTICIPANT	\N	PRESENT	0
169864	169852	92018S	PARTICIPANT	\N	PRESENT	0
169865	169852	92020L	PARTICIPANT	\N	PRESENT	0
169866	169852	95030B	PARTICIPANT	\N	PRESENT	0
188677	188355	08024S	PARTICIPANT	\N	PRESENT	0
188468	188432	11046L	PARTICIPANT	\N	PRESENT	0
169869	169852	97011G	PARTICIPANT	\N	PRESENT	0
188469	188432	01058X	PARTICIPANT	\N	PRESENT	0
188470	188432	11094U	PARTICIPANT	\N	PRESENT	0
188471	188432	11066Q	PARTICIPANT	\N	PRESENT	0
169873	169852	14014Q	PARTICIPANT	\N	PRESENT	0
188675	188355	08043V	PARTICIPANT	\N	PRESENT	0
188676	188355	95015C	PARTICIPANT	\N	PRESENT	0
169876	169852	95035G	PARTICIPANT	\N	PRESENT	0
188678	188355	01025N	PARTICIPANT	\N	PRESENT	0
169878	169852	14211G	PARTICIPANT	\N	PRESENT	0
188679	188355	11089X	PARTICIPANT	\N	PRESENT	0
188680	188355	14123H	PARTICIPANT	\N	PRESENT	0
188681	188355	14179A	PARTICIPANT	\N	PRESENT	0
169882	169852	04078Q	PARTICIPANT	\N	PRESENT	0
169883	169852	14097Y	PARTICIPANT	\N	PRESENT	0
188682	188355	14241N	PARTICIPANT	\N	PRESENT	0
169885	169852	04036E	PARTICIPANT	\N	EXCUSE	0
188683	188355	04057K	PARTICIPANT	\N	PRESENT	0
188684	188355	04070G	PARTICIPANT	\N	PRESENT	0
188685	188355	83047W	PARTICIPANT	\N	PRESENT	0
188686	188355	14363X	PARTICIPANT	\N	PRESENT	0
169890	169852	11106F	PARTICIPANT	\N	PRESENT	0
169891	169852	14251Q	PARTICIPANT	\N	PRESENT	0
169892	169852	83042R	PARTICIPANT	\N	PRESENT	0
169893	169852	08053X	PARTICIPANT	\N	PRESENT	0
188687	188355	12041X	PARTICIPANT	\N	PRESENT	0
169895	169852	11105E	PARTICIPANT	\N	PRESENT	0
169896	169852	14253S	PARTICIPANT	\N	PRESENT	0
169897	169852	08047A	PARTICIPANT	\N	PRESENT	0
188688	188355	08039A	PARTICIPANT	\N	PRESENT	0
169899	169852	14193X	PARTICIPANT	\N	PRESENT	0
169900	169852	98021N	PARTICIPANT	\N	EXCUSE	0
169901	169852	04080J	PARTICIPANT	\N	PRESENT	0
169902	169852	95059Q	PRESIDENT	0	PRESENT	0
188689	188355	14059S	PARTICIPANT	\N	PRESENT	0
169904	169852	01014K	PARTICIPANT	\N	PRESENT	0
169905	169852	11054L	PARTICIPANT	\N	PRESENT	0
188697	188696	89017R	PARTICIPANT	\N	PRESENT	0
189333	189332	11039M	PARTICIPANT	\N	PRESENT	0
188977	188976	11074Q	PARTICIPANT	\N	PRESENT	0
169909	169852	04050C	PARTICIPANT	\N	PRESENT	0
189160	189159	04034C	PARTICIPANT	\N	PRESENT	0
189334	189332	98042T	PARTICIPANT	\N	PRESENT	0
189335	189332	01019Q	PARTICIPANT	\N	PRESENT	0
189473	189472	14089Y	PARTICIPANT	\N	PRESENT	0
189474	189472	14001X	PARTICIPANT	\N	PRESENT	0
189612	188952	14097Y	PARTICIPANT	\N	EXCUSE	0
189613	188952	04094Q	PARTICIPANT	\N	EXCUSE	0
189831	189773	77002U	PARTICIPANT	\N	PRESENT	0
189832	189773	14097Y	PARTICIPANT	\N	PRESENT	0
189833	189773	95059Q	PRESIDENT	0	PRESENT	0
189834	189773	01056V	PARTICIPANT	\N	PRESENT	0
189835	189773	11041F	PARTICIPANT	\N	PRESENT	0
189836	189773	01014K	PARTICIPANT	\N	PRESENT	0
189837	189773	04040A	PARTICIPANT	\N	PRESENT	0
189838	189773	11069T	PARTICIPANT	\N	PRESENT	0
189839	189773	08058D	PARTICIPANT	\N	PRESENT	0
189840	189773	11027H	PARTICIPANT	\N	PRESENT	0
189841	189773	14028W	PARTICIPANT	\N	PRESENT	0
189842	189773	04042C	PARTICIPANT	\N	PRESENT	0
189843	189773	11054L	PARTICIPANT	\N	PRESENT	0
189844	189773	95035G	PARTICIPANT	\N	PRESENT	0
189845	189773	04036E	PARTICIPANT	\N	PRESENT	0
189846	189773	95037J	PARTICIPANT	\N	PRESENT	0
189847	189773	14251Q	PARTICIPANT	\N	PRESENT	0
189848	189773	98018T	PARTICIPANT	\N	PRESENT	0
189849	189773	98021N	PARTICIPANT	\N	PRESENT	0
189850	189773	08053X	PARTICIPANT	\N	PRESENT	0
189851	189773	86044G	PARTICIPANT	\N	PRESENT	0
189852	189773	11106F	PARTICIPANT	\N	PRESENT	0
189853	189773	08047A	PARTICIPANT	\N	PRESENT	0
189854	189773	92031P	PARTICIPANT	\N	PRESENT	0
189855	189412	14327T	PARTICIPANT	\N	PRESENT	0
189856	189412	04034C	PARTICIPANT	\N	PRESENT	0
189857	189412	01057W	PARTICIPANT	\N	PRESENT	0
189858	189412	89017R	PARTICIPANT	\N	PRESENT	0
189859	189412	14225N	PARTICIPANT	\N	PRESENT	0
189860	189412	11070L	PRESIDENT	1	PRESENT	0
189861	189412	88008L	PARTICIPANT	\N	PRESENT	0
189862	189412	14085U	PARTICIPANT	\N	PRESENT	0
189863	189412	08010L	PARTICIPANT	\N	PRESENT	0
189864	189412	08061X	PARTICIPANT	\N	PRESENT	0
189865	189412	08016S	PARTICIPANT	\N	PRESENT	0
189866	189412	01031L	PRESIDENT	0	PRESENT	0
189867	189412	11048N	PARTICIPANT	\N	PRESENT	0
189868	189412	08034U	PARTICIPANT	\N	PRESENT	0
189869	189412	01016M	PARTICIPANT	\N	PRESENT	0
189870	189412	08011M	PARTICIPANT	\N	PRESENT	0
189871	189412	01027Q	PARTICIPANT	\N	PRESENT	0
189872	189412	14159V	PARTICIPANT	\N	PRESENT	0
189873	189412	14173T	PARTICIPANT	\N	PRESENT	0
189874	189412	04086Q	PARTICIPANT	\N	PRESENT	0
189875	189412	14083S	PARTICIPANT	\N	PRESENT	0
189876	189412	11057P	PARTICIPANT	\N	PRESENT	0
189877	189412	11012A	PARTICIPANT	\N	PRESENT	0
189878	189412	98046X	PARTICIPANT	\N	PRESENT	0
189879	189412	99004R	PARTICIPANT	\N	PRESENT	0
189880	189412	11042G	PARTICIPANT	\N	PRESENT	0
189881	189412	07029T	PARTICIPANT	\N	EXCUSE	0
189882	189412	98053W	PARTICIPANT	\N	EXCUSE	0
189883	189412	11085T	PARTICIPANT	\N	EXCUSE	0
189884	189412	01013J	PARTICIPANT	\N	EXCUSE	0
189885	189412	11088W	PARTICIPANT	\N	EXCUSE	0
189886	189773	04054G	PARTICIPANT	\N	PRESENT	0
189887	189773	95030B	PARTICIPANT	\N	PRESENT	0
189888	187942	14001X	PARTICIPANT	\N	PRESENT	0
189929	189773	04080J	PARTICIPANT	\N	PRESENT	0
190118	189824	04054G	PARTICIPANT	\N	PRESENT	0
190119	189824	14097Y	PARTICIPANT	\N	PRESENT	0
190120	189824	04077P	PARTICIPANT	\N	PRESENT	0
190121	189824	95030B	PARTICIPANT	\N	PRESENT	0
190122	189824	11080N	PARTICIPANT	\N	PRESENT	0
190123	189824	11027H	PARTICIPANT	\N	PRESENT	0
190124	189824	04078Q	PARTICIPANT	\N	PRESENT	0
190125	189824	95037J	PARTICIPANT	\N	PRESENT	0
190126	189824	92031P	PARTICIPANT	\N	PRESENT	0
190127	189824	86044G	PARTICIPANT	\N	PRESENT	0
190128	189824	08047A	PARTICIPANT	\N	PRESENT	0
190129	189824	11082Q	PARTICIPANT	\N	PRESENT	0
190130	189824	08053X	PARTICIPANT	\N	PRESENT	0
190131	189824	01014K	PARTICIPANT	\N	PRESENT	0
190132	189824	04042C	PRESIDENT	0	PRESENT	0
190133	189824	11054L	PARTICIPANT	\N	PRESENT	0
190134	189824	14251Q	PARTICIPANT	\N	PRESENT	0
190135	189824	11076S	PARTICIPANT	\N	PRESENT	0
190136	189824	04035D	PARTICIPANT	\N	PRESENT	0
190137	189824	04080J	PARTICIPANT	\N	PRESENT	0
190138	189824	01056V	PARTICIPANT	\N	PRESENT	0
190139	189824	04036E	PARTICIPANT	\N	PRESENT	0
190896	190756	92039X	PARTICIPANT	\N	PRESENT	0
190897	190756	11072N	PARTICIPANT	\N	PRESENT	0
190898	190756	11113E	PARTICIPANT	\N	PRESENT	0
190899	190756	04059M	PARTICIPANT	\N	PRESENT	0
190900	190756	11023D	PARTICIPANT	\N	PRESENT	0
190901	190756	11067R	PARTICIPANT	\N	PRESENT	0
190902	190756	14227Q	PARTICIPANT	\N	PRESENT	0
190903	190756	11077T	PARTICIPANT	\N	PRESENT	0
190904	190756	08043V	PARTICIPANT	\N	PRESENT	0
190905	190756	11041F	PARTICIPANT	\N	PRESENT	0
190906	190756	11014C	PARTICIPANT	\N	PRESENT	0
190907	190756	11110B	PARTICIPANT	\N	PRESENT	0
190908	190756	80027E	PARTICIPANT	\N	PRESENT	0
190909	190756	11027H	PARTICIPANT	\N	PRESENT	0
190910	190756	14085U	PARTICIPANT	\N	PRESENT	0
190911	190756	11106F	PARTICIPANT	\N	PRESENT	0
190912	190756	04085P	PARTICIPANT	\N	PRESENT	0
190913	190756	98053W	PARTICIPANT	\N	PRESENT	0
190914	190756	92018S	PARTICIPANT	\N	PRESENT	0
190915	190756	07026Q	PARTICIPANT	\N	PRESENT	0
190916	190756	04054G	PARTICIPANT	\N	PRESENT	0
190917	190756	12041X	PARTICIPANT	\N	PRESENT	0
190918	190756	01015L	PARTICIPANT	\N	PRESENT	0
190919	190756	11034G	PARTICIPANT	\N	PRESENT	0
182873	182872	14133K	PARTICIPANT	\N	PRESENT	0
182993	182992	14089Y	PARTICIPANT	\N	PRESENT	0
182994	182992	11029K	PARTICIPANT	\N	PRESENT	0
182995	182992	14207L	PRESIDENT	0	PRESENT	0
182996	182992	11023D	PARTICIPANT	\N	PRESENT	0
182997	182992	14229S	PARTICIPANT	\N	EXCUSE	0
182998	182992	04050C	PARTICIPANT	\N	PRESENT	0
182999	182992	11095V	PARTICIPANT	\N	EXCUSE	0
183000	182992	14053L	PARTICIPANT	\N	EXCUSE	0
183001	182992	04057K	PARTICIPANT	\N	EXCUSE	0
183002	182992	11014C	PARTICIPANT	\N	EXCUSE	0
183212	165001	11089X	PARTICIPANT	\N	PRESENT	0
183213	165001	14299H	PARTICIPANT	\N	PRESENT	0
183215	165001	01058X	PARTICIPANT	\N	PRESENT	0
183216	165001	04043D	PARTICIPANT	\N	PRESENT	0
183217	165001	11082Q	PARTICIPANT	\N	PRESENT	0
183218	165001	11036J	PARTICIPANT	\N	PRESENT	0
183219	165001	11068S	PARTICIPANT	\N	PRESENT	0
183220	165001	14263U	PARTICIPANT	\N	EXCUSE	0
183221	165001	01046T	PARTICIPANT	\N	EXCUSE	0
183222	165001	08039A	PARTICIPANT	\N	EXCUSE	0
183223	165001	14257W	PARTICIPANT	\N	EXCUSE	0
183253	183252	11074Q	PARTICIPANT	\N	PRESENT	0
183254	183252	04056J	PARTICIPANT	\N	PRESENT	0
183255	183252	07034Q	PARTICIPANT	\N	PRESENT	0
183341	183340	14239U	PARTICIPANT	\N	PRESENT	0
183342	183340	08043V	PARTICIPANT	\N	PRESENT	0
183343	183340	11061K	PARTICIPANT	\N	PRESENT	0
183344	183340	14147R	PARTICIPANT	\N	PRESENT	0
183345	183340	14271U	PARTICIPANT	\N	PRESENT	0
183353	183352	14239U	PARTICIPANT	\N	PRESENT	0
183354	183352	04092N	PARTICIPANT	\N	PRESENT	0
183392	165001	04061F	PARTICIPANT	\N	PRESENT	0
187559	187558	98053W	PARTICIPANT	\N	PRESENT	0
187561	187560	98053W	PARTICIPANT	\N	PRESENT	0
188733	188732	14081Q	PARTICIPANT	\N	PRESENT	0
188734	188732	01043Q	PARTICIPANT	\N	PRESENT	0
188753	188752	14081Q	PARTICIPANT	\N	PRESENT	0
188755	188754	14081Q	PARTICIPANT	\N	PRESENT	0
188756	188754	01043Q	PARTICIPANT	\N	PRESENT	0
188758	188757	01043Q	PARTICIPANT	\N	PRESENT	0
188759	188757	14081Q	PARTICIPANT	\N	PRESENT	0
188761	188760	14081Q	PARTICIPANT	\N	PRESENT	0
188762	188760	01043Q	PARTICIPANT	\N	PRESENT	0
188773	188772	04049K	PARTICIPANT	\N	PRESENT	0
188775	188774	04049K	PARTICIPANT	\N	PRESENT	0
188777	188776	08009T	PARTICIPANT	\N	PRESENT	0
188778	188776	08042U	PARTICIPANT	\N	PRESENT	0
188780	188779	08009T	PARTICIPANT	\N	PRESENT	0
188781	188779	08042U	PARTICIPANT	\N	PRESENT	0
188783	188782	08009T	PARTICIPANT	\N	PRESENT	0
188805	188804	14026U	PARTICIPANT	\N	PRESENT	0
188806	188804	95037J	PARTICIPANT	\N	PRESENT	0
188807	188804	11012A	PARTICIPANT	\N	PRESENT	0
188808	188804	14357A	PARTICIPANT	\N	PRESENT	0
188809	188804	14033T	PARTICIPANT	\N	PRESENT	0
188816	188814	14026U	PARTICIPANT	\N	PRESENT	0
188811	188804	14257W	PARTICIPANT	\N	PRESENT	0
188812	188804	11110B	PARTICIPANT	\N	PRESENT	0
188813	188804	14207L	PARTICIPANT	\N	PRESENT	0
188815	188814	96004D	PARTICIPANT	\N	PRESENT	0
188817	188814	95037J	PARTICIPANT	\N	PRESENT	0
188818	188814	11012A	PARTICIPANT	\N	PRESENT	0
188819	188814	14357A	PARTICIPANT	\N	PRESENT	0
188820	188814	14033T	PARTICIPANT	\N	PRESENT	0
188821	188814	14257W	PARTICIPANT	\N	PRESENT	0
188822	188814	14207L	PARTICIPANT	\N	PRESENT	0
188996	188995	01057W	PARTICIPANT	\N	PRESENT	0
188997	188995	14225N	PARTICIPANT	\N	PRESENT	0
200652	200612	04092N	PRESIDENT	0	PRESENT	0
200653	200612	14281W	PARTICIPANT	\N	PRESENT	0
200654	200612	11103C	PARTICIPANT	\N	PRESENT	0
200655	200612	08052W	PARTICIPANT	\N	PRESENT	0
200656	200612	12042Y	PARTICIPANT	\N	PRESENT	0
200657	200612	14121F	PARTICIPANT	\N	PRESENT	0
200658	200612	14071N	PARTICIPANT	\N	PRESENT	0
200659	200612	14227Q	PARTICIPANT	\N	PRESENT	0
200660	200612	14269B	PARTICIPANT	\N	PRESENT	0
200661	200612	14053L	PARTICIPANT	\N	EXCUSE	0
200662	200612	14017T	PARTICIPANT	\N	EXCUSE	0
200663	200612	00003C	PARTICIPANT	\N	EXCUSE	0
200664	200612	04045F	PARTICIPANT	\N	EXCUSE	0
200665	200612	14265W	PARTICIPANT	\N	PRESENT	0
200666	200612	11112D	PARTICIPANT	\N	EXCUSE	0
200670	190795	04092N	PARTICIPANT	\N	PRESENT	0
200671	190795	08011M	PARTICIPANT	\N	PRESENT	0
200669	190795	04081K	PARTICIPANT	\N	PRESENT	0
200672	200612	11097X	PARTICIPANT	\N	PRESENT	0
200673	200612	04081K	PARTICIPANT	\N	PRESENT	0
200674	200612	11063M	PARTICIPANT	\N	PRESENT	0
200675	200612	11031D	PARTICIPANT	\N	PRESENT	0
200676	200612	14151M	PARTICIPANT	\N	PRESENT	0
200677	200612	14217N	PARTICIPANT	\N	PRESENT	0
200678	200612	10006L	PARTICIPANT	\N	PRESENT	0
200679	200612	04053F	PARTICIPANT	\N	PRESENT	0
201343	190797	14031R	PARTICIPANT	\N	PRESENT	0
201344	190797	14111D	PARTICIPANT	\N	PRESENT	0
201345	190797	11048N	PARTICIPANT	\N	PRESENT	0
201346	190797	08034U	PARTICIPANT	\N	PRESENT	0
201347	190797	14119M	PARTICIPANT	\N	PRESENT	0
201348	190797	14147R	PARTICIPANT	\N	PRESENT	0
201349	190797	04049K	PARTICIPANT	\N	PRESENT	0
201350	190797	08047A	PARTICIPANT	\N	PRESENT	0
201351	190797	14195A	PARTICIPANT	\N	PRESENT	0
201352	190797	14033T	PARTICIPANT	\N	PRESENT	0
201353	190797	14038Y	PARTICIPANT	\N	PRESENT	0
201354	190797	08065C	PARTICIPANT	\N	PRESENT	0
201355	190797	14213J	PARTICIPANT	\N	PRESENT	0
201356	190797	08015R	PARTICIPANT	\N	PRESENT	0
201357	190797	16813M	PARTICIPANT	\N	PRESENT	0
201358	190797	14355X	PARTICIPANT	\N	PRESENT	0
201359	190797	07029T	PARTICIPANT	\N	PRESENT	0
201360	190797	04088S	PARTICIPANT	\N	PRESENT	0
201361	190797	14357A	PARTICIPANT	\N	PRESENT	0
201362	190797	08019V	PARTICIPANT	\N	PRESENT	0
201363	190797	14329V	PARTICIPANT	\N	PRESENT	0
201364	190797	14199E	PARTICIPANT	\N	PRESENT	0
201365	190797	19251M	PARTICIPANT	\N	PRESENT	0
201366	190797	11101A	PARTICIPANT	\N	PRESENT	0
201367	190797	08058D	PARTICIPANT	\N	PRESENT	0
201372	190797	08038Y	PARTICIPANT	\N	PRESENT	0
201373	201041	04086Q	PARTICIPANT	\N	PRESENT	0
201374	201041	14085U	PARTICIPANT	\N	PRESENT	0
201375	201041	01016M	PARTICIPANT	\N	PRESENT	0
201475	190797	14157T	PARTICIPANT	\N	PRESENT	0
201377	201041	08011M	PARTICIPANT	\N	PRESENT	0
201474	190797	14265W	PARTICIPANT	\N	PRESENT	0
201379	201041	14225N	PARTICIPANT	\N	PRESENT	0
201380	201041	14159V	PARTICIPANT	\N	PRESENT	0
201492	190797	01034P	PARTICIPANT	\N	PRESENT	0
201400	190797	80013X	PARTICIPANT	\N	PRESENT	0
201383	201041	14173T	PARTICIPANT	\N	PRESENT	0
201493	190797	14039A	PARTICIPANT	\N	PRESENT	0
201385	190797	98029W	PARTICIPANT	\N	PRESENT	0
201386	190797	04067M	PARTICIPANT	\N	PRESENT	0
201387	201041	01031L	PRESIDENT	0	PRESENT	0
201388	201041	08034U	PARTICIPANT	\N	PRESENT	0
201389	201041	08069G	PARTICIPANT	\N	PRESENT	0
201390	201041	11074Q	PARTICIPANT	\N	PRESENT	0
201391	201041	07029T	PARTICIPANT	\N	PRESENT	0
201392	201041	14083S	PARTICIPANT	\N	PRESENT	0
201393	201041	11057P	PARTICIPANT	\N	PRESENT	0
201394	201041	14199E	PARTICIPANT	\N	PRESENT	0
201395	201041	08010L	PARTICIPANT	\N	PRESENT	0
201396	201041	99004R	PARTICIPANT	\N	PRESENT	0
201397	201041	11085T	PARTICIPANT	\N	PRESENT	0
201398	201041	08016S	PARTICIPANT	\N	PRESENT	0
201399	201041	01013J	PARTICIPANT	\N	PRESENT	0
201494	190797	11059R	PARTICIPANT	\N	PRESENT	0
201495	190797	11014C	PARTICIPANT	\N	PRESENT	0
201512	190797	11095V	PARTICIPANT	\N	PRESENT	0
201513	190797	19269X	PARTICIPANT	\N	PRESENT	0
201514	190797	14065Q	PARTICIPANT	\N	PRESENT	0
201515	190797	14133K	PARTICIPANT	\N	PRESENT	0
201516	190797	11042G	PARTICIPANT	\N	PRESENT	0
201517	190797	08012N	PARTICIPANT	\N	PRESENT	0
201518	190797	14229S	PARTICIPANT	\N	PRESENT	0
201519	190797	11082Q	PARTICIPANT	\N	PRESENT	0
201520	190797	14271U	PARTICIPANT	\N	PRESENT	0
170933	170932	14215L	PARTICIPANT	\N	PRESENT	0
170954	170953	14219Q	PRESIDENT	0	PRESENT	0
170955	170953	01008M	PARTICIPANT	\N	PRESENT	0
170956	170953	11065P	PARTICIPANT	\N	PRESENT	0
170957	170953	14033T	PARTICIPANT	\N	EXCUSE	0
171020	170953	80013X	PARTICIPANT	\N	PRESENT	0
171073	170953	08049C	PARTICIPANT	\N	EXCUSE	0
171081	170953	01056V	PARTICIPANT	\N	PRESENT	0
171478	170953	14093U	PARTICIPANT	\N	PRESENT	0
189463	188952	95062K	PARTICIPANT	\N	EXCUSE	0
190374	190373	04034C	PARTICIPANT	\N	PRESENT	0
190376	190375	04034C	PARTICIPANT	\N	PRESENT	0
190653	190652	11097X	PARTICIPANT	\N	PRESENT	0
190654	190652	11031D	PARTICIPANT	\N	PRESENT	0
190655	190652	11061K	PARTICIPANT	\N	PRESENT	0
191813	191812	07029T	PARTICIPANT	\N	PRESENT	0
191815	191814	89017R	PARTICIPANT	\N	PRESENT	0
203440	203436	14249W	PARTICIPANT	\N	EXCUSE	0
203441	203436	14097Y	PARTICIPANT	\N	PRESENT	0
203442	203436	04061F	PARTICIPANT	\N	PRESENT	0
203443	203436	14073Q	PARTICIPANT	\N	PRESENT	0
203444	203436	11026G	PARTICIPANT	\N	PRESENT	0
203448	203436	04045F	PARTICIPANT	\N	PRESENT	0
203449	203436	98035U	PARTICIPANT	\N	PRESENT	0
203450	203436	11083R	PARTICIPANT	\N	PRESENT	0
203451	203436	14133K	PARTICIPANT	\N	PRESENT	0
203452	203436	10015M	PARTICIPANT	\N	EXCUSE	0
203453	203436	92045V	PARTICIPANT	\N	EXCUSE	0
203454	203436	11035H	PARTICIPANT	\N	EXCUSE	0
204973	204972	04040A	PRESIDENT	0	PRESENT	0
204974	204972	08010L	PARTICIPANT	\N	EXCUSE	0
204992	204972	14034U	PARTICIPANT	\N	EXCUSE	0
205454	205453	14265W	PARTICIPANT	\N	PRESENT	0
203438	203436	14089Y	PARTICIPANT	\N	PRESENT	0
203439	203436	14079W	PARTICIPANT	\N	PRESENT	0
205455	205453	04043D	PARTICIPANT	\N	PRESENT	0
205456	205453	14041T	PARTICIPANT	\N	PRESENT	0
205457	205453	10006L	PARTICIPANT	\N	PRESENT	0
205574	205212	80013X	PARTICIPANT	\N	EXCUSE	0
206811	206810	11026G	PARTICIPANT	\N	PRESENT	0
206813	206810	08031R	PARTICIPANT	\N	PRESENT	0
206814	206810	04070G	PARTICIPANT	\N	PRESENT	0
206816	206810	08015R	PARTICIPANT	\N	PRESENT	0
207107	206515	19367Y	PARTICIPANT	\N	PRESENT	0
207108	206515	19415P	PARTICIPANT	\N	PRESENT	0
207109	206515	19733B	PARTICIPANT	\N	PRESENT	0
207110	206515	14105F	PARTICIPANT	\N	PRESENT	0
207111	206515	19383Y	PARTICIPANT	\N	PRESENT	0
207112	206515	19621T	PARTICIPANT	\N	PRESENT	0
207113	206516	04086Q	PARTICIPANT	\N	PRESENT	0
207114	206516	02002K	PARTICIPANT	\N	PRESENT	0
207115	206516	19347U	PARTICIPANT	\N	PRESENT	0
207116	206516	08055A	PARTICIPANT	\N	PRESENT	0
207117	206516	14081Q	PARTICIPANT	\N	PRESENT	0
207118	206516	08060W	PARTICIPANT	\N	PRESENT	0
207119	206516	80013X	PARTICIPANT	\N	PRESENT	0
207120	206516	11104D	PARTICIPANT	\N	PRESENT	0
207121	206516	19503N	PARTICIPANT	\N	PRESENT	0
207122	206516	14051J	PARTICIPANT	\N	PRESENT	0
207123	206516	14207L	PARTICIPANT	\N	PRESENT	0
207124	206516	08009T	PARTICIPANT	\N	PRESENT	0
207125	206516	19369B	PARTICIPANT	\N	PRESENT	0
207126	206516	11065P	PARTICIPANT	\N	PRESENT	0
207127	206516	19387D	PARTICIPANT	\N	PRESENT	0
207128	206516	19301E	PARTICIPANT	\N	PRESENT	0
207129	206516	17589D	PARTICIPANT	\N	PRESENT	0
207130	206516	19713W	PARTICIPANT	\N	PRESENT	0
207131	206516	19447X	PARTICIPANT	\N	PRESENT	0
207132	206516	19735D	PARTICIPANT	\N	PRESENT	0
207133	206516	18083K	PARTICIPANT	\N	PRESENT	0
207134	206516	14089Y	PARTICIPANT	\N	PRESENT	0
207135	206516	98023Q	PARTICIPANT	\N	PRESENT	0
207136	206516	19671E	PARTICIPANT	\N	PRESENT	0
207137	206516	04089T	PARTICIPANT	\N	PRESENT	0
207138	206516	14205J	PARTICIPANT	\N	PRESENT	0
207139	206516	14265W	PARTICIPANT	\N	PRESENT	0
207140	206516	19421M	PARTICIPANT	\N	PRESENT	0
207141	206516	07029T	PARTICIPANT	\N	PRESENT	0
207142	206516	98050T	PARTICIPANT	\N	PRESENT	0
207143	206516	04088S	PARTICIPANT	\N	PRESENT	0
207144	206516	19467C	PARTICIPANT	\N	PRESENT	0
207145	206516	95062K	PARTICIPANT	\N	PRESENT	0
207146	206516	14147R	PARTICIPANT	\N	PRESENT	0
207147	206516	04085P	PARTICIPANT	\N	PRESENT	0
207148	206516	95063L	PARTICIPANT	\N	PRESENT	0
207149	206516	14041T	PARTICIPANT	\N	PRESENT	0
207150	206516	19719D	PARTICIPANT	\N	PRESENT	0
207151	206516	14069U	PARTICIPANT	\N	PRESENT	0
207152	206516	19533U	PARTICIPANT	\N	PRESENT	0
207153	206516	19549D	PARTICIPANT	\N	PRESENT	0
207154	206516	14093U	PARTICIPANT	\N	PRESENT	0
207155	206516	08024S	PARTICIPANT	\N	PRESENT	0
207156	206516	14111D	PARTICIPANT	\N	PRESENT	0
207157	206516	14135M	PARTICIPANT	\N	PRESENT	0
207158	206516	14031R	PARTICIPANT	\N	PRESENT	0
207159	206516	19329S	PARTICIPANT	\N	PRESENT	0
207160	206485	19697Q	PARTICIPANT	\N	PRESENT	0
207161	206485	11067R	PARTICIPANT	\N	PRESENT	0
207162	206485	14355X	PARTICIPANT	\N	PRESENT	0
207163	206485	19569H	PARTICIPANT	\N	PRESENT	0
207164	206485	11097X	PARTICIPANT	\N	PRESENT	0
207165	206485	14223L	PARTICIPANT	\N	PRESENT	0
207166	206485	04045F	PARTICIPANT	\N	PRESENT	0
207167	206485	14026U	PARTICIPANT	\N	PRESENT	0
207168	206485	14227Q	PARTICIPANT	\N	PRESENT	0
207169	206485	17779H	PARTICIPANT	\N	PRESENT	0
207170	206485	19553Y	PARTICIPANT	\N	PRESENT	0
207171	206485	19703U	PARTICIPANT	\N	PRESENT	0
207172	206485	14239U	PARTICIPANT	\N	PRESENT	0
207173	206485	14281W	PARTICIPANT	\N	PRESENT	0
207174	206485	14087W	PARTICIPANT	\N	PRESENT	0
207175	206485	19679N	PARTICIPANT	\N	PRESENT	0
207176	206485	14042U	PARTICIPANT	\N	PRESENT	0
207177	206485	19575F	PARTICIPANT	\N	PRESENT	0
207178	206485	08048B	PARTICIPANT	\N	PRESENT	0
207179	206485	14195A	PARTICIPANT	\N	PRESENT	0
207180	206485	19367Y	PARTICIPANT	\N	PRESENT	0
207181	206485	14213J	PARTICIPANT	\N	PRESENT	0
207182	206485	14261S	PARTICIPANT	\N	PRESENT	0
207183	206485	14217N	PARTICIPANT	\N	PRESENT	0
207184	206485	19335Q	PARTICIPANT	\N	PRESENT	0
207185	206485	10006L	PARTICIPANT	\N	PRESENT	0
207186	206485	19521Q	PARTICIPANT	\N	PRESENT	0
207187	206485	01034P	PARTICIPANT	\N	PRESENT	0
207188	206485	04092N	PRESIDENT	0	PRESENT	0
207189	206485	08052W	PARTICIPANT	\N	PRESENT	0
207190	206485	19663E	PARTICIPANT	\N	PRESENT	0
207191	206485	19717B	PARTICIPANT	\N	PRESENT	0
207192	206485	08041T	PARTICIPANT	\N	PRESENT	0
207193	206485	19723Y	PARTICIPANT	\N	PRESENT	0
207194	206485	19727D	PARTICIPANT	\N	PRESENT	0
207195	206485	14119M	PARTICIPANT	\N	PRESENT	0
207196	206485	11103C	PARTICIPANT	\N	PRESENT	0
207197	206485	19657G	PARTICIPANT	\N	PRESENT	0
207198	206485	19577H	PARTICIPANT	\N	PRESENT	0
207199	206485	19715Y	PARTICIPANT	\N	EXCUSE	0
207200	206516	19695N	PARTICIPANT	\N	PRESENT	0
207201	206516	01043Q	PARTICIPANT	\N	PRESENT	0
207202	206485	14071N	PARTICIPANT	\N	PRESENT	0
207203	206516	19689Q	PARTICIPANT	\N	PRESENT	0
207204	206516	19551W	PARTICIPANT	\N	PRESENT	0
207205	206516	19413M	PARTICIPANT	\N	PRESENT	0
207206	206516	14033T	PARTICIPANT	\N	PRESENT	0
207207	206516	11056N	PARTICIPANT	\N	PRESENT	0
207208	206516	14179A	PARTICIPANT	\N	PRESENT	0
207209	206516	14073Q	PARTICIPANT	\N	PRESENT	0
207210	206516	14030Q	PARTICIPANT	\N	PRESENT	0
207211	206516	14219Q	PARTICIPANT	\N	PRESENT	0
207212	206516	19441R	PARTICIPANT	\N	PRESENT	0
207213	206516	19349W	PARTICIPANT	\N	PRESENT	0
207214	206516	19725B	PARTICIPANT	\N	PRESENT	0
207215	206516	14231L	PARTICIPANT	\N	PRESENT	0
207216	206485	19527W	PARTICIPANT	\N	PRESENT	0
207217	206485	11045K	PARTICIPANT	\N	PRESENT	0
207218	206516	14237S	PARTICIPANT	\N	PRESENT	0
207219	206516	19629C	PARTICIPANT	\N	PRESENT	0
207220	206516	01048V	PARTICIPANT	\N	PRESENT	0
207221	206516	14241N	PARTICIPANT	\N	PRESENT	0
207222	206516	19543W	PARTICIPANT	\N	PRESENT	0
207223	206516	11012A	PARTICIPANT	\N	PRESENT	0
207224	206516	14221J	PARTICIPANT	\N	PRESENT	0
184353	184352	05008E	PARTICIPANT	\N	PRESENT	0
184354	184352	04047H	PARTICIPANT	\N	PRESENT	0
184356	184355	05008E	PARTICIPANT	\N	PRESENT	0
184358	184357	05008E	PARTICIPANT	\N	PRESENT	0
184393	184392	01034P	PARTICIPANT	\N	PRESENT	0
184395	184394	01034P	PARTICIPANT	\N	PRESENT	0
184397	184396	01034P	PARTICIPANT	\N	PRESENT	0
184533	184532	04055H	PARTICIPANT	\N	PRESENT	0
184553	184552	14085U	PARTICIPANT	\N	PRESENT	0
184554	184552	14175V	PARTICIPANT	\N	PRESENT	0
184557	184556	14083S	PARTICIPANT	\N	PRESENT	0
184562	184561	98021N	PARTICIPANT	\N	PRESENT	0
184563	184561	11106F	PARTICIPANT	\N	PRESENT	0
184564	184561	01056V	PARTICIPANT	\N	PRESENT	0
184565	184561	95037J	PARTICIPANT	\N	PRESENT	0
187213	187212	14249W	PARTICIPANT	\N	PRESENT	0
188353	188352	95015C	PARTICIPANT	\N	PRESENT	0
188354	188352	14241N	PARTICIPANT	\N	PRESENT	0
209895	207683	01025N	PARTICIPANT	\N	PRESENT	0
209896	207683	14205J	PARTICIPANT	\N	PRESENT	0
209897	207683	14083S	PARTICIPANT	\N	PRESENT	0
209898	207683	19569H	PARTICIPANT	\N	PRESENT	0
209899	207683	11072N	PARTICIPANT	\N	PRESENT	0
209900	207683	19651A	PARTICIPANT	\N	PRESENT	0
209901	207683	14051J	PARTICIPANT	\N	PRESENT	0
209902	207683	14028W	PARTICIPANT	\N	PRESENT	0
209903	207683	19647E	PARTICIPANT	\N	PRESENT	0
209904	207683	11101A	PARTICIPANT	\N	PRESENT	0
209905	207683	19483C	PARTICIPANT	\N	PRESENT	0
209906	207683	19383Y	PARTICIPANT	\N	PRESENT	0
209907	207683	14071N	PARTICIPANT	\N	PRESENT	0
209908	207683	14217N	PARTICIPANT	\N	PRESENT	0
209909	207683	19415P	PARTICIPANT	\N	PRESENT	0
209910	207683	97011G	PARTICIPANT	\N	PRESENT	0
209911	207683	14211G	PARTICIPANT	\N	PRESENT	0
209912	207683	17637T	PARTICIPANT	\N	PRESENT	0
209913	207683	19711U	PARTICIPANT	\N	PRESENT	0
209914	207683	19533U	PARTICIPANT	\N	PRESENT	0
209915	207683	14069U	PARTICIPANT	\N	PRESENT	0
209916	207683	04047H	PARTICIPANT	\N	PRESENT	0
209917	207683	19515S	PARTICIPANT	\N	PRESENT	0
209918	207683	19581D	PARTICIPANT	\N	PRESENT	0
209919	207683	14119M	PARTICIPANT	\N	PRESENT	0
209920	207683	19693L	PARTICIPANT	\N	PRESENT	0
209921	207683	11056N	PARTICIPANT	\N	PRESENT	0
209922	207683	14105F	PARTICIPANT	\N	PRESENT	0
209923	207683	08018U	PARTICIPANT	\N	PRESENT	0
209924	207683	14327T	PARTICIPANT	\N	PRESENT	0
209925	207683	19637C	PARTICIPANT	\N	PRESENT	0
209926	207683	14089Y	PARTICIPANT	\N	PRESENT	0
209927	207683	08055A	PARTICIPANT	\N	PRESENT	0
209928	207683	14357A	PARTICIPANT	\N	PRESENT	0
209929	207683	98022P	PARTICIPANT	\N	PRESENT	0
209930	207683	14029X	PARTICIPANT	\N	PRESENT	0
209931	207683	92040Q	PARTICIPANT	\N	PRESENT	0
209932	207683	19683J	PARTICIPANT	\N	PRESENT	0
209933	207683	11110B	PARTICIPANT	\N	PRESENT	0
209934	207683	80013X	PARTICIPANT	\N	PRESENT	0
209935	207683	19717B	PARTICIPANT	\N	PRESENT	0
209936	207683	04057K	PARTICIPANT	\N	PRESENT	0
209937	207683	14115H	PARTICIPANT	\N	PRESENT	0
209938	207683	19467C	PARTICIPANT	\N	PRESENT	0
209939	207683	08041T	PARTICIPANT	\N	PRESENT	0
209940	207683	19723Y	PARTICIPANT	\N	PRESENT	0
209941	207683	14087W	PARTICIPANT	\N	PRESENT	0
209942	207683	14257W	PARTICIPANT	\N	PRESENT	0
209943	207683	19621T	PARTICIPANT	\N	PRESENT	0
209944	207683	04040A	PARTICIPANT	\N	PRESENT	0
209945	207683	14225N	PARTICIPANT	\N	PRESENT	0
209946	207683	14227Q	PARTICIPANT	\N	PRESENT	0
209947	207683	01062T	PARTICIPANT	\N	PRESENT	0
209948	207683	11077T	PARTICIPANT	\N	PRESENT	0
209949	207683	14121F	PARTICIPANT	\N	PRESENT	0
209950	207683	19713W	PARTICIPANT	\N	PRESENT	0
209951	207683	14103D	PARTICIPANT	\N	PRESENT	0
209952	207683	14221J	PARTICIPANT	\N	PRESENT	0
209953	207683	19737F	PARTICIPANT	\N	PRESENT	0
209954	207683	19697Q	PARTICIPANT	\N	PRESENT	0
209955	207683	14065Q	PARTICIPANT	\N	PRESENT	0
209956	207683	11033F	PARTICIPANT	\N	PRESENT	0
209957	207683	14039A	PARTICIPANT	\N	PRESENT	0
209958	207683	08010L	PARTICIPANT	\N	PRESENT	0
209959	207683	19663E	PARTICIPANT	\N	PRESENT	0
209960	207683	14265W	PARTICIPANT	\N	PRESENT	0
209961	207683	14213J	PARTICIPANT	\N	PRESENT	0
209962	207683	14157T	PARTICIPANT	\N	PRESENT	0
209963	207683	01028R	PARTICIPANT	\N	PRESENT	0
209964	207683	80027E	PARTICIPANT	\N	PRESENT	0
209965	207683	08043V	PARTICIPANT	\N	PRESENT	0
209966	207683	08017T	PARTICIPANT	\N	PRESENT	0
209967	207683	19715Y	PARTICIPANT	\N	PRESENT	0
209968	207683	08019V	PARTICIPANT	\N	PRESENT	0
209969	207683	11012A	PARTICIPANT	\N	PRESENT	0
209970	207683	14241N	PARTICIPANT	\N	PRESENT	0
209971	207683	11026G	PARTICIPANT	\N	PRESENT	0
209972	207683	19565D	PARTICIPANT	\N	PRESENT	0
209973	207683	19367Y	PARTICIPANT	\N	PRESENT	0
209974	207683	08020N	PARTICIPANT	\N	PRESENT	0
209975	207683	04061F	PARTICIPANT	\N	PRESENT	0
209976	207683	14061L	PARTICIPANT	\N	PRESENT	0
209977	207683	08031R	PARTICIPANT	\N	PRESENT	0
209978	207683	11099A	PARTICIPANT	\N	PRESENT	0
209979	207683	14081Q	PARTICIPANT	\N	PRESENT	0
209980	207683	19725B	PARTICIPANT	\N	PRESENT	0
209981	207683	08016S	PARTICIPANT	\N	PRESENT	0
209982	207683	08024S	PARTICIPANT	\N	PRESENT	0
209983	207683	98029W	PARTICIPANT	\N	PRESENT	0
209984	207683	19295A	PARTICIPANT	\N	PRESENT	0
209985	207683	19729F	PARTICIPANT	\N	PRESENT	0
209986	208063	98005N	PARTICIPANT	\N	PRESENT	0
209987	208063	19443T	PARTICIPANT	\N	PRESENT	0
209988	208063	95030B	PARTICIPANT	\N	PRESENT	0
209989	208063	04034C	PARTICIPANT	\N	PRESENT	0
209990	208063	14079W	PARTICIPANT	\N	PRESENT	0
209991	208063	04040A	PARTICIPANT	\N	PRESENT	0
209992	208063	16685X	PARTICIPANT	\N	PRESENT	0
209993	208063	04042C	PRESIDENT	0	PRESENT	0
209994	208063	11054L	PARTICIPANT	\N	PRESENT	0
209995	208063	11066Q	PARTICIPANT	\N	PRESENT	0
209996	208063	08056B	PARTICIPANT	\N	PRESENT	0
209997	208063	95037J	PARTICIPANT	\N	PRESENT	0
209998	208063	14055N	PARTICIPANT	\N	PRESENT	0
209999	208063	19421M	PARTICIPANT	\N	PRESENT	0
210000	208063	19709B	PARTICIPANT	\N	PRESENT	0
210001	208063	14193X	PARTICIPANT	\N	PRESENT	0
210002	208063	97011G	PARTICIPANT	\N	PRESENT	0
210003	208063	08061X	PARTICIPANT	\N	PRESENT	0
210004	208063	08047A	PARTICIPANT	\N	PRESENT	0
210005	208063	04035D	PARTICIPANT	\N	PRESENT	0
210006	208063	95067Q	PARTICIPANT	\N	PRESENT	0
210007	208063	01062T	PARTICIPANT	\N	PRESENT	0
210008	208063	11041F	PARTICIPANT	\N	PRESENT	0
210009	208063	14235Q	PARTICIPANT	\N	PRESENT	0
210010	208063	19251M	PARTICIPANT	\N	PRESENT	0
210011	208063	14028W	PARTICIPANT	\N	PRESENT	0
210012	208063	14105F	PARTICIPANT	\N	PRESENT	0
210013	208063	98022P	PARTICIPANT	\N	PRESENT	0
210014	208063	14267Y	PARTICIPANT	\N	PRESENT	0
210015	208063	11064N	PARTICIPANT	\N	PRESENT	0
210016	208063	98050T	PARTICIPANT	\N	PRESENT	0
210017	208063	14211G	PARTICIPANT	\N	PRESENT	0
210018	208063	98053W	PARTICIPANT	\N	EXCUSE	0
210019	208063	19583F	PARTICIPANT	\N	EXCUSE	0
210020	207683	11109J	PARTICIPANT	\N	PRESENT	0
210021	207683	14207L	PARTICIPANT	\N	PRESENT	0
210022	207683	14111D	PARTICIPANT	\N	PRESENT	0
210023	207683	14151M	PARTICIPANT	\N	PRESENT	0
210024	207683	04044E	PARTICIPANT	\N	PRESENT	0
210025	207683	08045X	PARTICIPANT	\N	PRESENT	0
210026	207683	11083R	PARTICIPANT	\N	PRESENT	0
210027	207683	04086Q	PARTICIPANT	\N	PRESENT	0
210028	207683	19521Q	PARTICIPANT	\N	PRESENT	0
210029	207683	14042U	PARTICIPANT	\N	PRESENT	0
210036	207683	14215L	PARTICIPANT	\N	PRESENT	0
210149	210148	19531S	PARTICIPANT	\N	PRESENT	0
166355	166232	11040E	PARTICIPANT	\N	PRESENT	0
166356	166232	11054L	PARTICIPANT	\N	PRESENT	0
166357	166232	14159V	PARTICIPANT	\N	PRESENT	0
166358	166232	08053X	PARTICIPANT	\N	PRESENT	0
166533	166232	98022P	PARTICIPANT	\N	PRESENT	0
166535	166232	11067R	PARTICIPANT	\N	PRESENT	0
166534	166232	04040A	PARTICIPANT	\N	PRESENT	0
166536	166232	14241N	PARTICIPANT	\N	PRESENT	0
166367	166232	04042C	PARTICIPANT	\N	PRESENT	0
166368	166232	04080J	PARTICIPANT	\N	PRESENT	0
166537	166232	11105E	PARTICIPANT	\N	PRESENT	0
166538	166232	04043D	PARTICIPANT	\N	PRESENT	0
166539	166232	14109K	PARTICIPANT	\N	PRESENT	0
166540	166232	01031L	PARTICIPANT	\N	PRESENT	0
166373	166232	01056V	PARTICIPANT	\N	PRESENT	0
166374	166232	98005N	PARTICIPANT	\N	PRESENT	0
166375	166232	92031P	PARTICIPANT	\N	PRESENT	0
166376	166232	98021N	PARTICIPANT	\N	PRESENT	0
166552	166232	11083R	PARTICIPANT	\N	PRESENT	0
166378	166232	04035D	PARTICIPANT	\N	PRESENT	0
166379	166232	01027Q	PARTICIPANT	\N	PRESENT	0
166381	166232	14089Y	PARTICIPANT	\N	PRESENT	0
166384	166232	14361V	PARTICIPANT	\N	PRESENT	0
166386	166232	92015P	PARTICIPANT	\N	PRESENT	0
166572	166232	07034Q	PARTICIPANT	\N	PRESENT	0
166573	166232	14265W	PARTICIPANT	\N	PRESENT	0
166393	166233	08055A	PARTICIPANT	\N	PRESENT	0
166394	166233	04050C	PARTICIPANT	\N	PRESENT	0
166395	166233	11040E	PARTICIPANT	\N	PRESENT	0
166396	166233	11054L	PARTICIPANT	\N	PRESENT	0
166397	166233	14159V	PARTICIPANT	\N	PRESENT	0
166398	166233	08053X	PARTICIPANT	\N	PRESENT	0
166399	166233	11066Q	PARTICIPANT	\N	PRESENT	0
166345	166232	08055A	PARTICIPANT	\N	PRESENT	0
166354	166232	04050C	PARTICIPANT	\N	PRESENT	0
166400	166233	11029K	PARTICIPANT	\N	PRESENT	0
166401	166233	11083R	PARTICIPANT	\N	PRESENT	0
166402	166233	11076S	PARTICIPANT	\N	PRESENT	0
166403	166233	04042C	PARTICIPANT	\N	PRESENT	0
166404	166233	04080J	PARTICIPANT	\N	PRESENT	0
166405	166233	11053K	PARTICIPANT	\N	PRESENT	0
166406	166233	11011M	PARTICIPANT	\N	PRESENT	0
166407	166233	14175V	PARTICIPANT	\N	PRESENT	0
166408	166233	14105F	PARTICIPANT	\N	PRESENT	0
166409	166233	01056V	PARTICIPANT	\N	PRESENT	0
166410	166233	98005N	PARTICIPANT	\N	PRESENT	0
166411	166233	92031P	PARTICIPANT	\N	PRESENT	0
166412	166233	98021N	PARTICIPANT	\N	PRESENT	0
166413	166233	14079W	PARTICIPANT	\N	PRESENT	0
166414	166233	04035D	PARTICIPANT	\N	PRESENT	0
166415	166233	01027Q	PARTICIPANT	\N	PRESENT	0
166416	166233	14089Y	PARTICIPANT	\N	PRESENT	0
166417	166233	14361V	PARTICIPANT	\N	PRESENT	0
166418	166233	92015P	PARTICIPANT	\N	PRESENT	0
166419	166233	98022P	PARTICIPANT	\N	PRESENT	0
166420	166233	07034Q	PARTICIPANT	\N	PRESENT	0
166421	166233	14219Q	PARTICIPANT	\N	PRESENT	0
166427	166233	14014Q	PARTICIPANT	\N	PRESENT	0
166428	166233	14363X	PARTICIPANT	\N	PRESENT	0
166429	166233	04078Q	PARTICIPANT	\N	PRESENT	0
166430	166233	14237S	PARTICIPANT	\N	PRESENT	0
166431	166233	14193X	PARTICIPANT	\N	PRESENT	0
166433	166233	14103D	PARTICIPANT	\N	PRESENT	0
166434	166233	95067Q	PARTICIPANT	\N	PRESENT	0
166435	166233	11043H	PARTICIPANT	\N	PRESENT	0
166436	166233	14041T	PARTICIPANT	\N	PRESENT	0
166437	166233	08061X	PARTICIPANT	\N	PRESENT	0
166438	166233	14197C	PARTICIPANT	\N	PRESENT	0
166439	166233	08010L	PARTICIPANT	\N	PRESENT	0
166440	166233	14265W	PARTICIPANT	\N	PRESENT	0
166443	166233	12042Y	PARTICIPANT	\N	PRESENT	0
166446	166233	11067R	PARTICIPANT	\N	PRESENT	0
166449	166233	11104D	PARTICIPANT	\N	PRESENT	0
166453	166233	14069U	PARTICIPANT	\N	PRESENT	0
166456	166233	14033T	PARTICIPANT	\N	PRESENT	0
166487	166233	11105E	PARTICIPANT	\N	PRESENT	0
166489	166233	14217N	PARTICIPANT	\N	PRESENT	0
166490	166233	01047U	PARTICIPANT	\N	PRESENT	0
166491	166233	95035G	PARTICIPANT	\N	PRESENT	0
166492	166233	14357A	PARTICIPANT	\N	PRESENT	0
166512	166233	11036J	PARTICIPANT	\N	PRESENT	0
166513	166232	14014Q	PARTICIPANT	\N	PRESENT	0
166589	166232	04071H	PARTICIPANT	\N	PRESENT	0
166595	166232	14105F	PARTICIPANT	\N	PRESENT	0
166596	166232	01041N	PARTICIPANT	\N	PRESENT	0
166597	166232	14363X	PARTICIPANT	\N	PRESENT	0
166518	166232	14041T	PARTICIPANT	\N	PRESENT	0
166519	166232	08061X	PARTICIPANT	\N	PRESENT	0
166598	166232	14187A	PARTICIPANT	\N	PRESENT	0
166599	166232	11076S	PARTICIPANT	\N	PRESENT	0
166600	166232	14073Q	PARTICIPANT	\N	PRESENT	0
166523	166232	11104D	PARTICIPANT	\N	PRESENT	0
166524	166232	14069U	PARTICIPANT	\N	PRESENT	0
166601	166232	14211G	PARTICIPANT	\N	PRESENT	0
166642	166234	04050C	PARTICIPANT	\N	PRESENT	0
166527	166232	14217N	PARTICIPANT	\N	PRESENT	0
166643	166234	14361V	PARTICIPANT	\N	PRESENT	0
166644	166234	14109K	PARTICIPANT	\N	PRESENT	0
166645	166234	11036J	PARTICIPANT	\N	PRESENT	0
166531	166232	11036J	PARTICIPANT	\N	PRESENT	0
166532	166232	04078Q	PARTICIPANT	\N	PRESENT	0
166646	166234	14014Q	PARTICIPANT	\N	PRESENT	0
166647	166234	11067R	PARTICIPANT	\N	PRESENT	0
166648	166234	11083R	PARTICIPANT	\N	PRESENT	0
166649	166234	14241N	PARTICIPANT	\N	PRESENT	0
166650	166234	11053K	PARTICIPANT	\N	PRESENT	0
166651	166234	01041N	PARTICIPANT	\N	PRESENT	0
166652	166234	14363X	PARTICIPANT	\N	PRESENT	0
166653	166234	04043D	PARTICIPANT	\N	PRESENT	0
166654	166234	01056V	PARTICIPANT	\N	PRESENT	0
166655	166234	14041T	PARTICIPANT	\N	PRESENT	0
166656	166234	14105F	PARTICIPANT	\N	PRESENT	0
166657	166234	98005N	PARTICIPANT	\N	PRESENT	0
166658	166234	04071H	PARTICIPANT	\N	PRESENT	0
166659	166234	01027Q	PARTICIPANT	\N	PRESENT	0
166660	166234	01031L	PARTICIPANT	\N	PRESENT	0
166661	166234	88008L	PARTICIPANT	\N	PRESENT	0
166662	166234	98046X	PARTICIPANT	\N	PRESENT	0
166663	166234	13002U	PARTICIPANT	\N	PRESENT	0
166664	166234	14179A	PARTICIPANT	\N	PRESENT	0
166665	166234	14175V	PARTICIPANT	\N	PRESENT	0
166666	166234	14357A	PARTICIPANT	\N	PRESENT	0
166667	166234	14187A	PARTICIPANT	\N	PRESENT	0
166756	166235	11105E	PARTICIPANT	\N	PRESENT	0
166757	166235	80013X	PARTICIPANT	\N	PRESENT	0
166758	166235	01056V	PARTICIPANT	\N	PRESENT	0
166759	166235	88008L	PARTICIPANT	\N	PRESENT	0
166760	166235	04045F	PARTICIPANT	\N	PRESENT	0
166761	166235	14259Y	PARTICIPANT	\N	PRESENT	0
166762	166235	95030B	PARTICIPANT	\N	PRESENT	0
166763	166235	14227Q	PARTICIPANT	\N	PRESENT	0
166764	166235	14051J	PARTICIPANT	\N	PRESENT	0
166765	166235	08052W	PARTICIPANT	\N	PRESENT	0
166766	166235	95037J	PARTICIPANT	\N	PRESENT	0
166767	166235	08068F	PARTICIPANT	\N	PRESENT	0
166640	166234	08055A	PARTICIPANT	\N	PRESENT	0
166641	166234	11040E	PARTICIPANT	\N	PRESENT	0
166768	166235	04036E	PARTICIPANT	\N	PRESENT	0
166769	166235	11104D	PARTICIPANT	\N	PRESENT	0
166770	166235	14042U	PARTICIPANT	\N	PRESENT	0
166771	166235	11107G	PARTICIPANT	\N	PRESENT	0
166772	166235	08065C	PARTICIPANT	\N	PRESENT	0
166773	166235	11093T	PARTICIPANT	\N	PRESENT	0
166781	166235	13002U	PARTICIPANT	\N	PRESENT	0
166775	166235	14277B	PARTICIPANT	\N	PRESENT	0
166776	166235	14087W	PARTICIPANT	\N	PRESENT	0
166777	166235	04056J	PARTICIPANT	\N	PRESENT	0
166778	166235	14059S	PARTICIPANT	\N	PRESENT	0
166779	166235	14231L	PARTICIPANT	\N	PRESENT	0
166780	166235	08021P	PARTICIPANT	\N	PRESENT	0
166782	166235	14237S	PARTICIPANT	\N	PRESENT	0
166783	166235	98022P	PARTICIPANT	\N	PRESENT	0
166784	166235	04050C	PARTICIPANT	\N	PRESENT	0
166754	166235	86034E	PARTICIPANT	\N	PRESENT	0
166755	166235	14219Q	PARTICIPANT	\N	PRESENT	0
166785	166235	11046L	PARTICIPANT	\N	PRESENT	0
166786	166235	14169X	PARTICIPANT	\N	PRESENT	0
166787	166235	14107H	PARTICIPANT	\N	PRESENT	0
166788	166235	86044G	PARTICIPANT	\N	PRESENT	0
166789	166235	14159V	PARTICIPANT	\N	PRESENT	0
166790	166235	12042Y	PARTICIPANT	\N	PRESENT	0
166791	166235	11088W	PARTICIPANT	\N	PRESENT	0
166792	166235	04078Q	PARTICIPANT	\N	PRESENT	0
166793	166235	14211G	PARTICIPANT	\N	PRESENT	0
166794	166235	14327T	PARTICIPANT	\N	PRESENT	0
166795	166235	08062Y	PARTICIPANT	\N	PRESENT	0
166796	166235	99004R	PARTICIPANT	\N	PRESENT	0
166797	166235	04035D	PARTICIPANT	\N	PRESENT	0
189153	189152	14079W	PARTICIPANT	\N	PRESENT	0
189154	189152	14097Y	PARTICIPANT	\N	PRESENT	0
189156	189155	14026U	PARTICIPANT	\N	PRESENT	0
189157	189155	95037J	PARTICIPANT	\N	PRESENT	0
189158	189155	14257W	PARTICIPANT	\N	PRESENT	0
189164	189161	04070G	PARTICIPANT	\N	PRESENT	0
189166	189165	14249W	PARTICIPANT	\N	PRESENT	0
189167	189165	07026Q	PARTICIPANT	\N	PRESENT	0
189272	189192	04045F	PARTICIPANT	\N	EXCUSE	0
201532	201040	14357A	PARTICIPANT	\N	PRESENT	0
201533	201040	11100Y	PRESIDENT	0	PRESENT	0
201534	201040	11066Q	PARTICIPANT	\N	PRESENT	0
201535	201040	80013X	PARTICIPANT	\N	PRESENT	0
201536	201040	90003B	PARTICIPANT	\N	PRESENT	0
201537	201040	11099A	PARTICIPANT	\N	PRESENT	0
201538	201040	11094U	PARTICIPANT	\N	PRESENT	0
201539	201040	04049K	PARTICIPANT	\N	PRESENT	0
201540	201040	08015R	PARTICIPANT	\N	PRESENT	0
201541	201040	14179A	PARTICIPANT	\N	PRESENT	0
201542	201040	08019V	PARTICIPANT	\N	PRESENT	0
201543	201040	14197C	PARTICIPANT	\N	PRESENT	0
201544	201040	08028W	PARTICIPANT	\N	PRESENT	0
201545	201040	14187A	PARTICIPANT	\N	PRESENT	0
201546	201040	08038Y	PARTICIPANT	\N	PRESENT	0
201547	201040	11098Y	PARTICIPANT	\N	PRESENT	0
201548	201040	14033T	PARTICIPANT	\N	PRESENT	0
201549	201040	11090Q	PARTICIPANT	\N	PRESENT	0
201550	201040	01008M	PARTICIPANT	\N	PRESENT	0
201551	201040	14205J	PARTICIPANT	\N	PRESENT	0
201552	201040	04088S	PARTICIPANT	\N	PRESENT	0
201553	201040	11036J	PARTICIPANT	\N	PRESENT	0
201554	201040	04089T	PARTICIPANT	\N	PRESENT	0
201555	201040	14207L	PARTICIPANT	\N	PRESENT	0
201556	201040	14257W	PARTICIPANT	\N	PRESENT	0
201557	201040	08068F	PARTICIPANT	\N	EXCUSE	0
201558	201040	11111C	PARTICIPANT	\N	EXCUSE	0
201559	190797	98035U	PARTICIPANT	\N	PRESENT	0
201560	190797	04043D	PARTICIPANT	\N	PRESENT	0
201561	190797	04092N	PARTICIPANT	\N	PRESENT	0
201562	190797	01056V	PARTICIPANT	\N	PRESENT	0
201572	190797	04034C	PARTICIPANT	\N	PRESENT	0
201573	190797	11039M	PARTICIPANT	\N	PRESENT	0
201592	190797	11105E	PARTICIPANT	\N	PRESENT	0
201593	190797	14018U	PARTICIPANT	\N	PRESENT	0
201612	190797	01024M	PARTICIPANT	\N	PRESENT	0
201613	190797	01025N	PARTICIPANT	\N	PRESENT	0
201614	190797	11080N	PARTICIPANT	\N	PRESENT	0
201615	190797	14173T	PARTICIPANT	\N	PRESENT	0
201616	190797	01046T	PARTICIPANT	\N	PRESENT	0
201617	190797	11053K	PARTICIPANT	\N	PRESENT	0
201635	190797	08073C	PARTICIPANT	\N	PRESENT	0
201752	200632	01046T	PARTICIPANT	\N	PRESENT	0
201753	200632	14227Q	PARTICIPANT	\N	PRESENT	0
201754	200632	11112D	PARTICIPANT	\N	PRESENT	0
201755	200632	14042U	PARTICIPANT	\N	PRESENT	0
201756	200632	14195A	PARTICIPANT	\N	PRESENT	0
201757	200632	04043D	PARTICIPANT	\N	PRESENT	0
201758	200632	00003C	PARTICIPANT	\N	EXCUSE	0
203932	203912	14053L	PARTICIPANT	\N	PRESENT	0
202444	202442	08055A	PARTICIPANT	\N	PRESENT	0
202446	202442	14030Q	PARTICIPANT	\N	PRESENT	0
203933	203912	01046T	PARTICIPANT	\N	PRESENT	0
202449	202442	11095V	PARTICIPANT	\N	PRESENT	0
203934	203912	11103C	PARTICIPANT	\N	PRESENT	0
203935	203912	08052W	PARTICIPANT	\N	PRESENT	0
203936	203912	14195A	PARTICIPANT	\N	PRESENT	0
203937	203912	14026U	PARTICIPANT	\N	PRESENT	0
202454	202442	01015L	PARTICIPANT	\N	PRESENT	0
203938	203912	19269X	PARTICIPANT	\N	PRESENT	0
203939	203912	98024R	PRESIDENT	0	PRESENT	0
202457	202442	02002K	PARTICIPANT	\N	PRESENT	0
202458	202442	01022K	PARTICIPANT	\N	PRESENT	0
203940	203912	14355X	PARTICIPANT	\N	EXCUSE	0
202460	202442	04097T	PARTICIPANT	\N	PRESENT	0
202462	202442	11059R	PARTICIPANT	\N	PRESENT	0
202463	202442	14219Q	PARTICIPANT	\N	PRESENT	0
202464	202442	80027E	PARTICIPANT	\N	PRESENT	0
202465	202442	14031R	PARTICIPANT	\N	PRESENT	0
202466	202442	08009T	PRESIDENT	0	PRESENT	0
202467	202442	08062Y	PARTICIPANT	\N	EXCUSE	0
202468	202442	14221J	PARTICIPANT	\N	PRESENT	0
202469	202442	92039X	PARTICIPANT	\N	PRESENT	0
202470	202442	08042U	PARTICIPANT	\N	PRESENT	0
203941	203912	00003C	PARTICIPANT	\N	EXCUSE	0
202472	202442	14237S	PARTICIPANT	\N	PRESENT	0
202473	202442	13002U	PARTICIPANT	\N	PRESENT	0
202474	202442	05012A	PARTICIPANT	\N	PRESENT	0
203942	203912	14269B	PARTICIPANT	\N	PRESENT	0
203952	203912	11112D	PARTICIPANT	\N	PRESENT	0
202477	202442	14331P	PARTICIPANT	\N	PRESENT	0
203953	203912	14119M	PARTICIPANT	\N	PRESENT	0
202479	202442	14107H	PARTICIPANT	\N	PRESENT	0
203954	203912	14071N	PARTICIPANT	\N	PRESENT	0
202481	202442	14157T	PARTICIPANT	\N	PRESENT	0
203955	203912	14217N	PARTICIPANT	\N	PRESENT	0
203956	203912	11061K	PARTICIPANT	\N	PRESENT	0
203957	203912	14223L	PARTICIPANT	\N	PRESENT	0
203958	203912	04092N	PARTICIPANT	\N	EXCUSE	0
203959	203912	11097X	PARTICIPANT	\N	PRESENT	0
203960	203912	14231L	PARTICIPANT	\N	PRESENT	0
203961	203912	04043D	PARTICIPANT	\N	PRESENT	0
203962	203912	14255U	PARTICIPANT	\N	PRESENT	0
203963	203912	04053F	PARTICIPANT	\N	PRESENT	0
203964	203912	14265W	PARTICIPANT	\N	PRESENT	0
203965	203912	14034U	PARTICIPANT	\N	PRESENT	0
203972	203912	11031D	PARTICIPANT	\N	PRESENT	0
203992	203912	01034P	PARTICIPANT	\N	PRESENT	0
204063	190806	04047H	PARTICIPANT	\N	PRESENT	0
204064	190806	14053L	PARTICIPANT	\N	PRESENT	0
204065	190806	14079W	PARTICIPANT	\N	PRESENT	0
204066	190806	99004R	PARTICIPANT	\N	PRESENT	0
204067	190806	92040Q	PARTICIPANT	\N	PRESENT	0
204068	190806	14211G	PARTICIPANT	\N	PRESENT	0
204069	190806	95062K	PARTICIPANT	\N	PRESENT	0
204070	190806	04097T	PARTICIPANT	\N	PRESENT	0
204071	190806	14223L	PARTICIPANT	\N	PRESENT	0
204072	190806	02002K	PARTICIPANT	\N	PRESENT	0
204073	190806	98018T	PARTICIPANT	\N	PRESENT	0
204074	190806	98024R	PARTICIPANT	\N	PRESENT	0
204075	190806	04044E	PARTICIPANT	\N	PRESENT	0
204076	190806	04071H	PARTICIPANT	\N	PRESENT	0
204077	190806	08039A	PARTICIPANT	\N	PRESENT	0
204078	190806	11080N	PARTICIPANT	\N	PRESENT	0
204079	190806	04054G	PARTICIPANT	\N	PRESENT	0
204080	190806	08069G	PARTICIPANT	\N	PRESENT	0
204081	190806	11040E	PARTICIPANT	\N	PRESENT	0
204082	190806	14191V	PARTICIPANT	\N	PRESENT	0
204083	190806	87003B	PARTICIPANT	\N	PRESENT	0
204084	190806	14215L	PARTICIPANT	\N	PRESENT	0
204085	190806	95015C	PARTICIPANT	\N	PRESENT	0
204498	190807	14217N	PARTICIPANT	\N	PRESENT	0
204499	190807	14033T	PARTICIPANT	\N	PRESENT	0
204500	190807	08052W	PARTICIPANT	\N	PRESENT	0
204501	190807	99004R	PARTICIPANT	\N	PRESENT	0
204502	190807	04047H	PARTICIPANT	\N	PRESENT	0
204503	190807	14269B	PARTICIPANT	\N	PRESENT	0
204504	190807	14061L	PARTICIPANT	\N	PRESENT	0
204505	190807	04085P	PARTICIPANT	\N	PRESENT	0
204506	190807	11061K	PARTICIPANT	\N	PRESENT	0
204507	190807	08031R	PARTICIPANT	\N	PRESENT	0
204508	190807	11033F	PARTICIPANT	\N	PRESENT	0
204509	190807	01046T	PARTICIPANT	\N	PRESENT	0
204510	190807	14357A	PARTICIPANT	\N	PRESENT	0
204512	190807	16813M	PARTICIPANT	\N	PRESENT	0
204513	190807	04038G	PARTICIPANT	\N	PRESENT	0
204514	190807	14215L	PARTICIPANT	\N	PRESENT	0
204515	190807	14041T	PARTICIPANT	\N	PRESENT	0
204516	190807	95063L	PARTICIPANT	\N	PRESENT	0
204517	190807	04067M	PARTICIPANT	\N	PRESENT	0
204518	190807	05008E	PARTICIPANT	\N	PRESENT	0
168840	168839	95015C	PARTICIPANT	\N	PRESENT	0
168912	168848	11037K	PARTICIPANT	\N	PRESENT	0
168933	168848	14111D	PARTICIPANT	\N	PRESENT	0
168954	168848	11033F	PARTICIPANT	\N	PRESENT	0
168968	168848	01028R	PARTICIPANT	\N	PRESENT	0
168964	168848	11026G	PARTICIPANT	\N	PRESENT	0
168971	168848	11049P	PARTICIPANT	\N	PRESENT	0
168974	168848	14001X	PARTICIPANT	\N	PRESENT	0
168976	168848	04044E	PRESIDENT	1	PRESENT	0
168980	168848	11034G	PARTICIPANT	\N	PRESENT	0
168985	168848	11072N	PARTICIPANT	\N	PRESENT	0
168989	168848	98035U	PARTICIPANT	\N	PRESENT	0
168991	168848	01024M	PARTICIPANT	\N	PRESENT	0
168992	168848	14069U	PARTICIPANT	\N	PRESENT	0
168998	168848	01007L	PARTICIPANT	\N	PRESENT	0
189989	189988	14259Y	PARTICIPANT	\N	PRESENT	0
192096	190772	11076S	PARTICIPANT	\N	PRESENT	0
192258	190613	14097Y	PARTICIPANT	\N	PRESENT	0
192259	190613	95030B	PARTICIPANT	\N	PRESENT	0
192260	190613	01014K	PARTICIPANT	\N	PRESENT	0
192261	190613	04042C	PARTICIPANT	\N	PRESENT	0
192262	190613	11054L	PARTICIPANT	\N	PRESENT	0
192263	190613	95035G	PARTICIPANT	\N	PRESENT	0
192264	190613	95037J	PARTICIPANT	\N	PRESENT	0
192265	190613	92031P	PARTICIPANT	\N	PRESENT	0
192266	190613	98018T	PARTICIPANT	\N	PRESENT	0
192267	190613	08065C	PARTICIPANT	\N	PRESENT	0
192268	190613	98022P	PARTICIPANT	\N	PRESENT	0
192269	190613	14193X	PARTICIPANT	\N	PRESENT	0
192273	190613	04054G	PARTICIPANT	\N	PRESENT	0
192274	190613	14105F	PARTICIPANT	\N	PRESENT	0
207225	206516	08034U	PARTICIPANT	\N	PRESENT	0
207226	206516	14123H	PARTICIPANT	\N	PRESENT	0
207227	206516	88008L	PARTICIPANT	\N	PRESENT	0
207228	206516	19563B	PARTICIPANT	\N	PRESENT	0
207229	206516	19621T	PARTICIPANT	\N	PRESENT	0
207230	206516	14034U	PARTICIPANT	\N	PRESENT	0
207232	207231	11053K	PARTICIPANT	\N	PRESENT	0
207233	207231	14159V	PARTICIPANT	\N	PRESENT	0
207234	207231	05012A	PARTICIPANT	\N	PRESENT	0
207235	206516	14257W	PARTICIPANT	\N	PRESENT	0
207236	206516	14197C	PARTICIPANT	\N	PRESENT	0
207237	206516	14053L	PARTICIPANT	\N	PRESENT	0
207238	206516	11081P	PARTICIPANT	\N	PRESENT	0
207794	206654	11063M	PARTICIPANT	0	PRESENT	0
207795	206654	19727D	PARTICIPANT	0	PRESENT	0
207796	206654	19503N	PARTICIPANT	0	PRESENT	0
207797	206654	11067R	PARTICIPANT	0	PRESENT	0
207798	206654	08038Y	PARTICIPANT	0	PRESENT	0
207799	206654	11104D	PARTICIPANT	0	PRESENT	0
207800	206654	19525U	PARTICIPANT	0	PRESENT	0
207801	206654	19669L	PARTICIPANT	0	PRESENT	0
207802	206654	19593H	PARTICIPANT	0	PRESENT	0
207803	206654	14123H	PARTICIPANT	0	PRESENT	0
207804	206654	14227Q	PARTICIPANT	0	PRESENT	0
207805	206654	11097X	PARTICIPANT	0	PRESENT	0
207806	206654	14087W	PARTICIPANT	0	PRESENT	0
207807	206654	14083S	PARTICIPANT	0	PRESENT	0
207808	206654	14327T	PARTICIPANT	0	PRESENT	0
207809	206654	19447X	PARTICIPANT	0	PRESENT	0
207810	206654	19691J	PARTICIPANT	0	PRESENT	0
207811	206654	08034U	PARTICIPANT	0	PRESENT	0
207812	206654	19479G	PARTICIPANT	0	PRESENT	0
207813	206654	19335Q	PARTICIPANT	0	PRESENT	0
207814	206654	19333N	PARTICIPANT	0	PRESENT	0
207815	206654	14028W	PARTICIPANT	0	PRESENT	0
207816	206654	08024S	PARTICIPANT	0	PRESENT	0
207817	206654	17779H	PARTICIPANT	0	PRESENT	0
207818	206654	19683J	PARTICIPANT	0	PRESENT	0
207819	206654	19527W	PARTICIPANT	0	PRESENT	0
207820	206654	08014Q	PARTICIPANT	0	PRESENT	0
207821	206654	19599P	PARTICIPANT	0	PRESENT	0
207822	206654	19549D	PARTICIPANT	0	PRESENT	0
207823	206654	19697Q	PARTICIPANT	0	PRESENT	0
207824	206654	19349W	PARTICIPANT	0	PRESENT	0
207825	206654	19651A	PARTICIPANT	0	PRESENT	0
207826	206654	14239U	PARTICIPANT	0	PRESENT	0
207827	206654	04045F	PARTICIPANT	0	PRESENT	0
207828	206654	08061X	PARTICIPANT	0	PRESENT	0
207829	206654	14261S	PARTICIPANT	0	PRESENT	0
207830	206654	14179A	PARTICIPANT	0	PRESENT	0
207831	206654	08031R	PARTICIPANT	0	PRESENT	0
207832	206654	01034P	PARTICIPANT	0	PRESENT	0
207833	206654	14042U	PARTICIPANT	0	PRESENT	0
207834	206654	14219Q	PARTICIPANT	0	PRESENT	0
207835	206654	19713W	PARTICIPANT	0	PRESENT	0
207836	206654	14281W	PARTICIPANT	0	PRESENT	0
207837	206654	19553Y	PARTICIPANT	0	PRESENT	0
207838	206654	14195A	PARTICIPANT	0	PRESENT	0
207839	206654	19387D	PARTICIPANT	0	PRESENT	0
207840	206654	98022P	PARTICIPANT	0	PRESENT	0
207841	206654	14241N	PARTICIPANT	0	PRESENT	0
207842	206654	14121F	PARTICIPANT	0	PRESENT	0
207843	206654	14107H	PARTICIPANT	0	PRESENT	0
207844	206654	08052W	PARTICIPANT	0	PRESENT	0
207845	206654	04092N	PARTICIPANT	0	PRESENT	0
207846	206654	14213J	PARTICIPANT	0	PRESENT	0
207847	206654	98024R	PARTICIPANT	0	PRESENT	0
207848	206654	19421M	PARTICIPANT	0	PRESENT	0
207849	206654	14237S	PARTICIPANT	0	PRESENT	0
207850	206654	19581D	PARTICIPANT	0	PRESENT	0
207851	206654	19367Y	PARTICIPANT	0	PRESENT	0
207852	206654	19731Y	PARTICIPANT	0	PRESENT	0
207853	206654	14061L	PARTICIPANT	0	PRESENT	0
207854	206654	98050T	PARTICIPANT	0	PRESENT	0
207855	206654	14355X	PARTICIPANT	0	PRESENT	0
207856	206654	19657G	PARTICIPANT	0	PRESENT	0
207857	206654	07029T	PARTICIPANT	0	PRESENT	0
207858	206654	19693L	PARTICIPANT	0	PRESENT	0
207859	206654	11049P	PARTICIPANT	0	PRESENT	0
207860	206654	19575F	PARTICIPANT	0	PRESENT	0
207861	206654	14223L	PARTICIPANT	0	PRESENT	0
207862	206654	14267Y	PARTICIPANT	0	PRESENT	0
207863	206654	11110B	PARTICIPANT	0	PRESENT	0
207864	206654	14041T	PARTICIPANT	0	PRESENT	0
207865	206654	19663E	PARTICIPANT	0	PRESENT	0
207866	206654	14173T	PARTICIPANT	0	PRESENT	0
207867	206654	19703U	PARTICIPANT	0	PRESENT	0
207868	206654	14217N	PARTICIPANT	0	PRESENT	0
207869	206654	10006L	PARTICIPANT	0	PRESENT	0
207870	206654	14147R	PARTICIPANT	0	PRESENT	0
207871	206654	19533U	PARTICIPANT	0	PRESENT	0
207872	206654	19415P	PARTICIPANT	0	PRESENT	0
207873	206654	14111D	PARTICIPANT	0	PRESENT	0
207874	206654	19711U	PARTICIPANT	0	PRESENT	0
207875	206654	14069U	PARTICIPANT	0	PRESENT	0
207876	206654	19551W	PARTICIPANT	0	PRESENT	0
207877	206654	11045K	PARTICIPANT	0	PRESENT	0
207878	206654	04085P	PARTICIPANT	0	PRESENT	0
207879	206654	08018U	PARTICIPANT	0	PRESENT	0
207880	206654	01048V	PARTICIPANT	0	PRESENT	0
207881	206654	14038Y	PARTICIPANT	0	PRESENT	0
207882	206654	19521Q	PARTICIPANT	0	PRESENT	0
207883	206654	19709B	PARTICIPANT	0	PRESENT	0
207884	206654	18083K	PARTICIPANT	0	PRESENT	0
207885	206654	14030Q	PARTICIPANT	0	PRESENT	0
207886	206654	19629C	PARTICIPANT	0	PRESENT	0
207887	206654	08017T	PARTICIPANT	0	PRESENT	0
207888	206654	19483C	PARTICIPANT	0	PRESENT	0
207889	206654	19621T	PARTICIPANT	0	PRESENT	0
207890	206654	17637T	PARTICIPANT	0	PRESENT	0
207891	206654	14119M	PARTICIPANT	0	PRESENT	0
207892	206654	14157T	PARTICIPANT	0	PRESENT	0
207893	206654	19717B	PARTICIPANT	0	PRESENT	0
207894	206654	04088S	PARTICIPANT	0	PRESENT	0
207895	206654	14169X	PARTICIPANT	0	PRESENT	0
207896	206654	14071N	PARTICIPANT	0	PRESENT	0
207897	206654	14199E	PARTICIPANT	0	PRESENT	0
207898	206654	11054L	PARTICIPANT	0	PRESENT	0
207899	206654	10015M	PARTICIPANT	0	PRESENT	0
207900	206654	08015R	PARTICIPANT	0	PRESENT	0
207901	206654	14033T	PARTICIPANT	0	PRESENT	0
207902	206654	14257W	PARTICIPANT	0	PRESENT	0
207903	206654	14329V	PARTICIPANT	0	PRESENT	0
207904	206654	14357A	PARTICIPANT	0	PRESENT	0
207905	206654	14105F	PARTICIPANT	0	PRESENT	0
207906	206654	19443T	PARTICIPANT	0	PRESENT	0
207907	206654	08020N	PARTICIPANT	0	PRESENT	0
207908	206654	01025N	PARTICIPANT	0	PRESENT	0
208436	208435	14089Y	PARTICIPANT	\N	PRESENT	0
208438	208437	14089Y	PARTICIPANT	\N	PRESENT	0
208440	208439	14089Y	PARTICIPANT	\N	PRESENT	0
208442	208441	08058D	PARTICIPANT	\N	PRESENT	0
208445	208444	11053K	PARTICIPANT	\N	PRESENT	0
208446	208444	14159V	PARTICIPANT	\N	PRESENT	0
208447	208444	05012A	PARTICIPANT	\N	PRESENT	0
185853	185852	11039M	PARTICIPANT	\N	PRESENT	0
185854	185852	98042T	PARTICIPANT	\N	PRESENT	0
185855	185852	01019Q	PARTICIPANT	\N	PRESENT	0
186636	186635	01011G	PARTICIPANT	\N	PRESENT	0
186637	186635	14042U	PARTICIPANT	\N	PRESENT	0
188033	188032	96004D	PARTICIPANT	\N	PRESENT	0
188034	188032	14026U	PARTICIPANT	\N	PRESENT	0
188072	188032	14033T	PARTICIPANT	\N	PRESENT	0
188073	188032	14207L	PARTICIPANT	\N	PRESENT	0
188074	188032	14257W	PARTICIPANT	\N	PRESENT	0
188075	188032	14357A	PARTICIPANT	\N	PRESENT	0
188077	188076	96004D	PARTICIPANT	\N	PRESENT	0
188078	188076	14026U	PARTICIPANT	\N	PRESENT	0
188079	188076	11012A	PARTICIPANT	\N	PRESENT	0
188080	188076	14033T	PARTICIPANT	\N	PRESENT	0
188081	188076	14207L	PARTICIPANT	\N	PRESENT	0
188082	188076	14357A	PARTICIPANT	\N	PRESENT	0
189892	189412	04044E	RAPPORTEUR_AVIS	\N	PRESENT	0
189893	189412	04061F	PARTICIPANT	\N	PRESENT	0
189894	189493	11034G	PARTICIPANT	\N	PRESENT	0
189895	189493	14001X	PARTICIPANT	\N	PRESENT	0
189896	189493	01060R	PARTICIPANT	\N	PRESENT	0
189897	189493	01019Q	PARTICIPANT	\N	PRESENT	0
189898	189493	04044E	PARTICIPANT	\N	PRESENT	0
189899	189493	01028R	PARTICIPANT	\N	PRESENT	0
189900	189493	05008E	PRESIDENT	0	PRESENT	0
189901	189493	04079R	PARTICIPANT	\N	PRESENT	0
189902	189493	08025T	PARTICIPANT	\N	PRESENT	0
189903	189493	14041T	PARTICIPANT	\N	PRESENT	0
189904	189493	14215L	PARTICIPANT	\N	PRESENT	0
189905	189493	08018U	PARTICIPANT	\N	PRESENT	0
189906	189493	14259Y	PARTICIPANT	\N	PRESENT	0
189907	189493	98035U	PARTICIPANT	\N	PRESENT	0
189908	189493	14111D	PARTICIPANT	\N	PRESENT	0
189909	189493	95067Q	PARTICIPANT	\N	PRESENT	0
189910	189493	14065Q	PARTICIPANT	\N	PRESENT	0
189911	189493	11010L	PARTICIPANT	\N	PRESENT	0
189912	189493	10015M	PARTICIPANT	\N	PRESENT	0
189913	189493	11026G	PARTICIPANT	\N	PRESENT	0
189914	189493	01024M	PARTICIPANT	\N	PRESENT	0
189915	189493	19251M	PARTICIPANT	\N	PRESENT	0
189916	189493	04038G	PARTICIPANT	\N	PRESENT	0
189917	189493	11033F	PARTICIPANT	\N	PRESENT	0
189918	189493	04085P	PARTICIPANT	\N	PRESENT	0
189919	189493	11056N	PARTICIPANT	\N	PRESENT	0
189920	189493	95063L	PARTICIPANT	\N	PRESENT	0
189921	189493	04074L	PARTICIPANT	\N	PRESENT	0
189922	189493	11037K	PARTICIPANT	\N	PRESENT	0
189923	189493	04056J	PARTICIPANT	\N	PRESENT	0
189924	189493	14069U	PARTICIPANT	\N	PRESENT	0
189925	189493	11084S	PARTICIPANT	\N	PRESENT	0
189926	189493	95049N	PARTICIPANT	\N	PRESENT	0
189927	189493	07034Q	PARTICIPANT	\N	EXCUSE	0
189928	189493	04047H	PARTICIPANT	\N	EXCUSE	0
190109	189824	14133K	PARTICIPANT	\N	PRESENT	0
190110	189824	98018T	PARTICIPANT	\N	PRESENT	0
190111	189824	11041F	PARTICIPANT	\N	PRESENT	0
190112	189824	08058D	PARTICIPANT	\N	PRESENT	0
190246	190117	14073Q	PARTICIPANT	\N	PRESENT	0
190114	189824	14028W	PARTICIPANT	\N	PRESENT	0
190115	189824	95035G	PARTICIPANT	\N	PRESENT	0
190116	189824	11106F	PARTICIPANT	\N	PRESENT	0
190178	190117	01044R	PARTICIPANT	\N	PRESENT	0
190179	190117	04070G	PRESIDENT	0	PRESENT	0
190284	190117	11027H	PARTICIPANT	\N	PRESENT	0
190181	190117	12041X	PARTICIPANT	\N	PRESENT	0
190182	190117	14361V	PARTICIPANT	\N	PRESENT	0
190183	190117	95015C	PARTICIPANT	\N	PRESENT	0
190184	190117	11029K	PARTICIPANT	\N	PRESENT	0
190185	190117	01041N	PARTICIPANT	\N	PRESENT	0
190186	190117	14229S	PARTICIPANT	\N	PRESENT	0
190187	190117	11089X	PARTICIPANT	\N	PRESENT	0
190188	190117	14237S	PARTICIPANT	\N	PRESENT	0
190189	190117	05012A	PARTICIPANT	\N	PRESENT	0
190190	190117	08060W	PARTICIPANT	\N	PRESENT	0
190191	190117	04049K	PARTICIPANT	\N	PRESENT	0
190192	190117	08017T	PARTICIPANT	\N	PRESENT	0
190193	190117	08012N	PARTICIPANT	\N	PRESENT	0
190194	190117	08024S	PARTICIPANT	\N	PRESENT	0
190195	190117	14249W	PARTICIPANT	\N	PRESENT	0
190196	190117	08031R	PARTICIPANT	\N	PRESENT	0
190197	190117	07026Q	PARTICIPANT	\N	PRESENT	0
190198	190117	14038Y	PARTICIPANT	\N	PRESENT	0
190199	190117	14059S	PARTICIPANT	\N	PRESENT	0
190200	190117	14061L	PARTICIPANT	\N	PRESENT	0
190201	190117	04057K	PARTICIPANT	\N	PRESENT	0
190202	190117	11091R	PARTICIPANT	\N	PRESENT	0
190203	190117	08052W	PARTICIPANT	\N	PRESENT	0
190204	190117	08043V	PARTICIPANT	\N	PRESENT	0
190205	190117	01025N	PARTICIPANT	\N	PRESENT	0
190206	190117	87003B	PARTICIPANT	\N	PRESENT	0
190207	190117	11014C	PARTICIPANT	\N	PRESENT	0
190208	190117	04036E	PARTICIPANT	\N	PRESENT	0
190209	190117	14089Y	PARTICIPANT	\N	PRESENT	0
190210	190117	98042T	PARTICIPANT	\N	PRESENT	0
190211	190117	04088S	PARTICIPANT	\N	PRESENT	0
190212	190117	14093U	PARTICIPANT	\N	PRESENT	0
190213	190117	14105F	PARTICIPANT	\N	PRESENT	0
190214	190117	95063L	PARTICIPANT	\N	PRESENT	0
190215	190117	14363X	PARTICIPANT	\N	PRESENT	0
190216	190117	14109K	PARTICIPANT	\N	PRESENT	0
190217	190117	14063N	PARTICIPANT	\N	PRESENT	0
190218	190117	14123H	PARTICIPANT	\N	PRESENT	0
190219	190117	11104D	PARTICIPANT	\N	PRESENT	0
190220	190117	04055H	PARTICIPANT	\N	PRESENT	0
190221	190117	04061F	PARTICIPANT	\N	PRESENT	0
190225	190117	01057W	PARTICIPANT	\N	PRESENT	0
190226	190117	14083S	PARTICIPANT	\N	PRESENT	0
190227	190117	98046X	PARTICIPANT	\N	PRESENT	0
190228	190117	14329V	PARTICIPANT	\N	PRESENT	0
190229	190117	08034U	PARTICIPANT	\N	PRESENT	0
190230	190117	14173T	PARTICIPANT	\N	PRESENT	0
190247	190117	14187A	PARTICIPANT	\N	PRESENT	0
190248	190117	04056J	PARTICIPANT	\N	PRESENT	0
190270	190117	95030B	PARTICIPANT	\N	PRESENT	0
190271	190117	04035D	PARTICIPANT	\N	PRESENT	0
190272	190117	95067Q	PARTICIPANT	\N	PRESENT	0
190273	190117	14030Q	PARTICIPANT	\N	PRESENT	0
190274	190117	14219Q	PARTICIPANT	\N	PRESENT	0
190275	190117	04045F	PARTICIPANT	\N	PRESENT	0
190276	190117	11085T	PARTICIPANT	\N	PRESENT	0
190285	190117	11048N	PARTICIPANT	\N	PRESENT	0
190286	190117	08055A	PARTICIPANT	\N	PRESENT	0
190304	190117	11097X	PARTICIPANT	\N	PRESENT	0
190305	190117	14197C	PARTICIPANT	\N	PRESENT	0
190306	190117	14327T	PARTICIPANT	\N	PRESENT	0
190307	190117	14119M	PARTICIPANT	\N	PRESENT	0
210768	207686	14065Q	PARTICIPANT	\N	PRESENT	0
190309	190117	14217N	PARTICIPANT	\N	PRESENT	0
190310	190117	95035G	PARTICIPANT	\N	PRESENT	0
190311	190117	14031R	PARTICIPANT	\N	PRESENT	0
190312	190117	11067R	PARTICIPANT	\N	PRESENT	0
190313	190117	01024M	PARTICIPANT	\N	PRESENT	0
190314	190117	14227Q	PARTICIPANT	\N	PRESENT	0
190315	190117	14281W	PARTICIPANT	\N	PRESENT	0
190316	190117	14107H	PARTICIPANT	\N	PRESENT	0
190317	190117	14069U	PARTICIPANT	\N	PRESENT	0
190327	190117	14241N	PARTICIPANT	\N	EXCUSE	0
190328	190117	14103D	PARTICIPANT	\N	EXCUSE	0
190329	190117	11039M	PARTICIPANT	\N	EXCUSE	0
204673	204672	11039M	PARTICIPANT	\N	PRESENT	0
204674	204672	98042T	PARTICIPANT	\N	PRESENT	0
204675	204672	01019Q	PARTICIPANT	\N	PRESENT	0
210769	207686	04047H	PARTICIPANT	\N	PRESENT	0
210770	207686	04085P	PARTICIPANT	\N	PRESENT	0
210771	207686	19593H	PARTICIPANT	\N	PRESENT	0
210772	207686	14021P	PARTICIPANT	\N	PRESENT	0
210773	207686	19725B	PARTICIPANT	\N	PRESENT	0
210774	207686	11072N	PARTICIPANT	\N	PRESENT	0
210775	207686	19543W	PARTICIPANT	\N	PRESENT	0
210776	207686	19649G	PARTICIPANT	\N	PRESENT	0
210777	207686	11033F	PARTICIPANT	\N	PRESENT	0
210778	207686	08044W	PARTICIPANT	\N	PRESENT	0
210779	207686	01024M	PARTICIPANT	\N	PRESENT	0
210780	207686	19483C	PARTICIPANT	\N	PRESENT	0
210781	207686	19533U	PARTICIPANT	\N	PRESENT	0
210782	207686	14053L	PARTICIPANT	\N	PRESENT	0
210783	207686	14069U	PARTICIPANT	\N	PRESENT	0
210784	207686	14041T	PARTICIPANT	\N	PRESENT	0
210785	207686	14157T	PARTICIPANT	\N	PRESENT	0
210786	207686	19447X	PARTICIPANT	\N	PRESENT	0
210787	207686	19703U	PARTICIPANT	\N	PRESENT	0
210788	207686	14123H	PARTICIPANT	\N	PRESENT	0
210789	207686	14223L	PARTICIPANT	\N	PRESENT	0
210790	207686	08010L	PARTICIPANT	\N	PRESENT	0
210791	207686	19719D	PARTICIPANT	\N	PRESENT	0
210792	207686	19621T	PARTICIPANT	\N	PRESENT	0
210793	207686	19367Y	PARTICIPANT	\N	PRESENT	0
210794	207686	14079W	PARTICIPANT	\N	PRESENT	0
166798	166235	77002U	PARTICIPANT	\N	PRESENT	0
166826	166235	14257W	PARTICIPANT	\N	PRESENT	0
166800	166235	08018U	PARTICIPANT	\N	PRESENT	0
166801	166235	01058X	PARTICIPANT	\N	PRESENT	0
166802	166235	14329V	PARTICIPANT	\N	PRESENT	0
166803	166235	11110B	PARTICIPANT	\N	PRESENT	0
166804	166235	08010L	PARTICIPANT	\N	PRESENT	0
166805	166235	98035U	PARTICIPANT	\N	PRESENT	0
166806	166235	12041X	PARTICIPANT	\N	PRESENT	0
166807	166235	04085P	PARTICIPANT	\N	PRESENT	0
166808	166235	04054G	PARTICIPANT	\N	PRESENT	0
166809	166235	96004D	PARTICIPANT	\N	PRESENT	0
166810	166235	11040E	PARTICIPANT	\N	PRESENT	0
166811	166235	08053X	PARTICIPANT	\N	PRESENT	0
166812	166235	14229S	PARTICIPANT	\N	PRESENT	0
166813	166235	01015L	PARTICIPANT	\N	PRESENT	0
166815	166235	11015D	PARTICIPANT	\N	PRESENT	0
166816	166235	08016S	PARTICIPANT	\N	PRESENT	0
166817	166235	14173T	PARTICIPANT	\N	PRESENT	0
166818	166235	14109K	PARTICIPANT	\N	PRESENT	0
166819	166235	14175V	PARTICIPANT	\N	PRESENT	0
166820	166235	11011M	PARTICIPANT	\N	PRESENT	0
166821	166235	14271U	PARTICIPANT	\N	PRESENT	0
166822	166235	14053L	PARTICIPANT	\N	PRESENT	0
166823	166235	14121F	PARTICIPANT	\N	PRESENT	0
166824	166235	04092N	PARTICIPANT	\N	PRESENT	0
166825	166235	08012N	PARTICIPANT	\N	PRESENT	0
166827	166235	04049K	PARTICIPANT	\N	PRESENT	0
166828	166235	04077P	PARTICIPANT	\N	PRESENT	0
166829	166235	14187A	PARTICIPANT	\N	PRESENT	0
166830	166235	14331P	PARTICIPANT	\N	PRESENT	0
166831	166235	11035H	PARTICIPANT	\N	PRESENT	0
166832	166235	04047H	PARTICIPANT	\N	PRESENT	0
166833	166235	04053F	PARTICIPANT	\N	PRESENT	0
166834	166235	98023Q	PARTICIPANT	\N	PRESENT	0
166835	166235	14079W	PARTICIPANT	\N	PRESENT	0
166836	166235	08022Q	PARTICIPANT	\N	PRESENT	0
166837	166235	95035G	PARTICIPANT	\N	PRESENT	0
166838	166235	14217N	PARTICIPANT	\N	PRESENT	0
166839	166235	14031R	PARTICIPANT	\N	PRESENT	0
166840	166235	98053W	PARTICIPANT	\N	PRESENT	0
166841	166235	11036J	PARTICIPANT	\N	PRESENT	0
166842	166235	95062K	PARTICIPANT	\N	PRESENT	0
166843	166235	14028W	PARTICIPANT	\N	PRESENT	0
166844	166235	11067R	PARTICIPANT	\N	PRESENT	0
166845	166235	11080N	PARTICIPANT	\N	PRESENT	0
166846	166235	04066L	PARTICIPANT	\N	PRESENT	0
166847	166235	11084S	PARTICIPANT	\N	PRESENT	0
166848	166235	01057W	PARTICIPANT	\N	PRESENT	0
166849	166235	14001X	PARTICIPANT	\N	PRESENT	0
166850	166235	04081K	PARTICIPANT	\N	PRESENT	0
166851	166235	14071N	PARTICIPANT	\N	PRESENT	0
166852	166235	04074L	PARTICIPANT	\N	PRESENT	0
166853	166235	14135M	PARTICIPANT	\N	PRESENT	0
166854	166235	95059Q	PARTICIPANT	\N	PRESENT	0
166855	166235	05012A	PARTICIPANT	\N	PRESENT	0
166856	166235	04044E	PARTICIPANT	\N	PRESENT	0
166857	166235	04042C	PARTICIPANT	\N	PRESENT	0
166858	166235	04097T	PARTICIPANT	\N	PRESENT	0
166859	166235	01027Q	PARTICIPANT	\N	PRESENT	0
166860	166235	92031P	PARTICIPANT	\N	PRESENT	0
166861	166235	92045V	PARTICIPANT	\N	PRESENT	0
166862	166235	04057K	PARTICIPANT	\N	PRESENT	0
166863	166235	14191V	PARTICIPANT	\N	PRESENT	0
166864	166235	11103C	PARTICIPANT	\N	PRESENT	0
166865	166235	01013J	PARTICIPANT	\N	PRESENT	0
166866	166235	07026Q	PARTICIPANT	\N	PRESENT	0
166867	166235	11043H	PARTICIPANT	\N	PRESENT	0
166868	166235	11056N	PARTICIPANT	\N	PRESENT	0
166869	166235	11063M	PARTICIPANT	\N	PRESENT	0
166870	166235	14361V	PARTICIPANT	\N	PRESENT	0
166871	166235	11039M	PARTICIPANT	\N	PRESENT	0
166872	166235	01048V	PARTICIPANT	\N	PRESENT	0
166873	166235	92015P	PARTICIPANT	\N	PRESENT	0
166874	166235	98046X	PARTICIPANT	\N	PRESENT	0
166875	166235	08039A	PARTICIPANT	\N	PRESENT	0
166876	166235	08055A	PARTICIPANT	\N	PRESENT	0
166877	166235	11049P	PARTICIPANT	\N	PRESENT	0
166878	166235	10015M	PARTICIPANT	\N	PRESENT	0
166879	166235	11027H	PARTICIPANT	\N	PRESENT	0
166880	166235	14033T	PARTICIPANT	\N	PRESENT	0
166881	166235	80027E	PARTICIPANT	\N	PRESENT	0
166882	166235	95067Q	PARTICIPANT	\N	PRESENT	0
166883	166235	14041T	PARTICIPANT	\N	PRESENT	0
166884	166235	14167V	PARTICIPANT	\N	PRESENT	0
166885	166235	83047W	PARTICIPANT	\N	PRESENT	0
166886	166235	01011G	PARTICIPANT	\N	PRESENT	0
166887	166235	14038Y	PARTICIPANT	\N	PRESENT	0
166888	166235	01031L	PARTICIPANT	\N	PRESENT	0
166889	166235	14133K	PARTICIPANT	\N	PRESENT	0
166890	166235	11074Q	PARTICIPANT	\N	PRESENT	0
166891	166235	14199E	PARTICIPANT	\N	PRESENT	0
166892	166235	14061L	PARTICIPANT	\N	PRESENT	0
166893	166235	11066Q	PARTICIPANT	\N	PRESENT	0
166894	166235	14093U	PARTICIPANT	\N	PRESENT	0
166895	166235	14151M	PARTICIPANT	\N	PRESENT	0
166896	166235	98029W	PARTICIPANT	\N	PRESENT	0
166897	166235	14213J	PARTICIPANT	\N	PRESENT	0
166898	166235	14014Q	PARTICIPANT	\N	PRESENT	0
166935	166235	14030Q	PARTICIPANT	\N	PRESENT	0
166900	166235	04033B	PARTICIPANT	\N	PRESENT	0
166901	166235	11095V	PARTICIPANT	\N	PRESENT	0
166902	166235	95015C	PARTICIPANT	\N	PRESENT	0
166903	166235	11014C	PARTICIPANT	\N	PRESENT	0
166904	166235	14085U	PARTICIPANT	\N	PRESENT	0
166905	166235	11044J	PARTICIPANT	\N	PRESENT	0
166906	166235	05004A	PARTICIPANT	\N	PRESENT	0
166907	166235	11077T	PARTICIPANT	\N	PRESENT	0
166908	166235	07034Q	PARTICIPANT	\N	PRESENT	0
166909	166235	14249W	PARTICIPANT	\N	PRESENT	0
166910	166235	14069U	PARTICIPANT	\N	PRESENT	0
166911	166235	08038Y	PARTICIPANT	\N	PRESENT	0
166912	166235	14105F	PARTICIPANT	\N	PRESENT	0
166913	166235	01028R	PARTICIPANT	\N	PRESENT	0
166914	166235	01041N	PARTICIPANT	\N	PRESENT	0
166915	166235	08061X	PARTICIPANT	\N	PRESENT	0
166916	166235	14269B	PARTICIPANT	\N	PRESENT	0
166917	166235	05008E	PARTICIPANT	\N	PRESENT	0
166918	166235	11029K	PARTICIPANT	\N	PRESENT	0
166919	166235	11032E	PARTICIPANT	\N	PRESENT	0
166920	166235	04067M	PARTICIPANT	\N	PRESENT	0
166921	166235	11090Q	PARTICIPANT	\N	PRESENT	0
166922	166235	11031D	PARTICIPANT	\N	PRESENT	0
166923	166235	11061K	PARTICIPANT	\N	PRESENT	0
166924	166235	14065Q	PARTICIPANT	\N	PRESENT	0
166925	166235	08049C	PARTICIPANT	\N	PRESENT	0
166926	166235	11070L	PARTICIPANT	\N	PRESENT	0
166927	166235	11083R	PARTICIPANT	\N	PRESENT	0
166928	166235	11055M	PARTICIPANT	\N	PRESENT	0
166929	166235	14193X	PARTICIPANT	\N	PRESENT	0
166930	166235	98042T	PARTICIPANT	\N	PRESENT	0
166931	166235	04080J	PARTICIPANT	\N	PRESENT	0
166932	166235	14097Y	PARTICIPANT	\N	PRESENT	0
166933	166235	95063L	PARTICIPANT	\N	PRESENT	0
166934	166235	14255U	PARTICIPANT	\N	PRESENT	0
166936	166235	08051V	PARTICIPANT	\N	PRESENT	0
166937	166235	04040A	PARTICIPANT	\N	PRESENT	0
166938	166235	11082Q	PARTICIPANT	\N	PRESENT	0
166939	166235	01046T	PARTICIPANT	\N	PRESENT	0
166940	166235	11012A	PARTICIPANT	\N	PRESENT	0
166941	166235	08031R	PARTICIPANT	\N	PRESENT	0
166942	166235	04089T	PARTICIPANT	\N	PRESENT	0
166943	166235	01024M	PARTICIPANT	\N	PRESENT	0
166944	166235	04038G	PARTICIPANT	\N	PRESENT	0
166945	166235	01025N	PARTICIPANT	\N	PRESENT	0
166946	166235	14201E	PARTICIPANT	\N	PRESENT	0
166947	166235	04061F	PARTICIPANT	\N	PRESENT	0
166948	166235	08035V	PARTICIPANT	\N	PRESENT	0
166949	166235	08009T	PARTICIPANT	\N	PRESENT	0
166950	166235	11053K	PARTICIPANT	\N	PRESENT	0
166951	166235	01007L	PARTICIPANT	\N	PRESENT	0
166952	166235	89017R	PARTICIPANT	\N	PRESENT	0
166953	166235	01043Q	PARTICIPANT	\N	PRESENT	0
166954	166235	92044U	PARTICIPANT	\N	PRESENT	0
166955	166235	14055N	PARTICIPANT	\N	PRESENT	0
166956	166235	14103D	PARTICIPANT	\N	PRESENT	0
166957	166235	11094U	PARTICIPANT	\N	PRESENT	0
166958	166235	14363X	PARTICIPANT	\N	PRESENT	0
166959	166235	98005N	PARTICIPANT	\N	PRESENT	0
166960	166235	14073Q	PARTICIPANT	\N	PRESENT	0
166961	166235	95041E	PARTICIPANT	\N	PRESENT	0
166965	166235	14013P	PARTICIPANT	\N	PRESENT	0
166963	166235	11085T	PARTICIPANT	\N	PRESENT	0
166964	166235	14034U	PARTICIPANT	\N	PRESENT	0
166966	166235	08034U	PARTICIPANT	\N	PRESENT	0
166967	166235	14235Q	PARTICIPANT	\N	PRESENT	0
166968	166235	11034G	PARTICIPANT	\N	PRESENT	0
188035	187692	14327T	PARTICIPANT	\N	PRESENT	0
188036	187692	01031L	PRESIDENT	0	PRESENT	0
188037	187692	14175V	PARTICIPANT	\N	PRESENT	0
188038	187692	11048N	PARTICIPANT	\N	PRESENT	0
188039	187692	08034U	PARTICIPANT	\N	PRESENT	0
188040	187692	11053K	PARTICIPANT	\N	PRESENT	0
188041	187692	11074Q	PARTICIPANT	\N	PRESENT	0
188042	187692	08011M	PARTICIPANT	\N	PRESENT	0
188043	187692	88008L	PARTICIPANT	\N	PRESENT	0
188044	187692	14225N	PARTICIPANT	\N	PRESENT	0
188045	187692	11070L	PARTICIPANT	\N	PRESENT	0
188046	187692	11068S	PARTICIPANT	\N	PRESENT	0
188047	187692	11088W	PARTICIPANT	\N	PRESENT	0
188048	187692	11040E	PARTICIPANT	\N	PRESENT	0
188049	187692	07029T	PARTICIPANT	\N	PRESENT	0
188050	187692	14083S	PARTICIPANT	\N	PRESENT	0
188051	187692	11057P	PARTICIPANT	\N	PRESENT	0
188052	187692	11083R	PARTICIPANT	\N	PRESENT	0
188053	187692	08010L	PARTICIPANT	\N	PRESENT	0
188054	187692	08061X	PARTICIPANT	\N	PRESENT	0
188055	187692	99004R	PARTICIPANT	\N	PRESENT	0
188056	187692	04061F	PARTICIPANT	\N	PRESENT	0
188057	187692	11042G	PARTICIPANT	\N	PRESENT	0
188058	187692	01013J	PARTICIPANT	\N	PRESENT	0
188059	187692	04086Q	PARTICIPANT	\N	PRESENT	0
188060	187692	04071H	PARTICIPANT	\N	PRESENT	0
188061	187692	08069G	PARTICIPANT	\N	PRESENT	0
188062	187692	01027Q	PARTICIPANT	\N	PRESENT	0
188063	187692	14159V	PARTICIPANT	\N	PRESENT	0
188064	187692	11012A	PARTICIPANT	\N	EXCUSE	0
188065	187692	14085U	PARTICIPANT	\N	EXCUSE	0
188066	187692	98053W	PARTICIPANT	\N	EXCUSE	0
188067	187692	11085T	PARTICIPANT	\N	EXCUSE	0
188068	187692	89017R	PARTICIPANT	\N	EXCUSE	0
188069	187692	08014Q	PARTICIPANT	\N	EXCUSE	0
188070	187692	08016S	PARTICIPANT	\N	EXCUSE	0
188071	187692	14173T	PARTICIPANT	\N	EXCUSE	0
188092	187692	98046X	PARTICIPANT	\N	PRESENT	0
188172	187693	14175V	PARTICIPANT	\N	PRESENT	0
188173	187693	01031L	PRESIDENT	0	PRESENT	0
188174	187693	04071H	PARTICIPANT	\N	PRESENT	0
188175	187693	08034U	PARTICIPANT	\N	PRESENT	0
188176	187693	11053K	PARTICIPANT	\N	PRESENT	0
188177	187693	08011M	PARTICIPANT	\N	PRESENT	0
188178	187693	01027Q	PARTICIPANT	\N	PRESENT	0
188179	187693	11070L	PARTICIPANT	\N	PRESENT	0
188180	187693	14159V	PARTICIPANT	\N	PRESENT	0
188181	187693	14225N	PARTICIPANT	\N	PRESENT	0
188182	187693	04086Q	PARTICIPANT	\N	PRESENT	0
188183	187693	07029T	PARTICIPANT	\N	PRESENT	0
188184	187693	14083S	PARTICIPANT	\N	PRESENT	0
188185	187693	11012A	PARTICIPANT	\N	PRESENT	0
188186	187693	14085U	PARTICIPANT	\N	PRESENT	0
188187	187693	98046X	PARTICIPANT	\N	PRESENT	0
188188	187693	11083R	PARTICIPANT	\N	PRESENT	0
188189	187693	08010L	PARTICIPANT	\N	PRESENT	0
188492	188232	01031L	PRESIDENT	0	PRESENT	0
188493	188232	01048V	PARTICIPANT	\N	PRESENT	0
188494	188232	04034C	PARTICIPANT	\N	PRESENT	0
188495	188232	01057W	PARTICIPANT	\N	PRESENT	0
188496	188232	08011M	PARTICIPANT	\N	PRESENT	0
188497	188232	14225N	PARTICIPANT	\N	PRESENT	0
188498	188232	14159V	PARTICIPANT	\N	PRESENT	0
188499	188232	11070L	PARTICIPANT	\N	PRESENT	0
188500	188232	11040E	PARTICIPANT	\N	PRESENT	0
188501	188232	04086Q	PARTICIPANT	\N	PRESENT	0
188502	188232	14083S	PARTICIPANT	\N	PRESENT	0
188503	188232	11012A	PARTICIPANT	\N	PRESENT	0
188504	188232	14085U	PARTICIPANT	\N	PRESENT	0
188505	188232	96004D	PARTICIPANT	\N	PRESENT	0
188506	188232	98046X	PARTICIPANT	\N	PRESENT	0
188507	188232	08061X	PARTICIPANT	\N	PRESENT	0
188508	188232	11042G	PARTICIPANT	\N	PRESENT	0
188509	188232	14327T	PARTICIPANT	\N	EXCUSE	0
188510	188232	98053W	PARTICIPANT	\N	EXCUSE	0
188511	188232	11085T	PARTICIPANT	\N	EXCUSE	0
188512	188232	11088W	PARTICIPANT	\N	EXCUSE	0
188532	188232	01016M	PARTICIPANT	\N	PRESENT	0
188533	188232	88008L	PARTICIPANT	\N	PRESENT	0
188534	188232	11083R	PARTICIPANT	\N	PRESENT	0
188535	188232	04071H	PARTICIPANT	\N	PRESENT	0
188536	188232	11053K	PARTICIPANT	\N	PRESENT	0
188537	188232	99004R	PARTICIPANT	\N	PRESENT	0
188538	188232	01027Q	PARTICIPANT	\N	PRESENT	0
188539	188232	04055H	PARTICIPANT	\N	PRESENT	0
188540	188232	04061F	PARTICIPANT	\N	PRESENT	0
188541	188232	07029T	PARTICIPANT	\N	EXCUSE	0
188713	188712	14081Q	PARTICIPANT	\N	PRESENT	0
188714	188712	01043Q	PARTICIPANT	\N	PRESENT	0
202092	200633	11067R	PARTICIPANT	\N	PRESENT	0
202093	200633	11061K	PARTICIPANT	\N	PRESENT	0
202094	200633	14355X	PARTICIPANT	\N	PRESENT	0
202095	200633	11097X	PARTICIPANT	\N	PRESENT	0
202096	200633	08052W	PARTICIPANT	\N	PRESENT	0
202097	200633	04045F	PARTICIPANT	\N	PRESENT	0
202098	200633	11023D	PARTICIPANT	\N	PRESENT	0
202099	200633	11031D	PARTICIPANT	\N	PRESENT	0
202100	200633	11103C	PARTICIPANT	\N	PRESENT	0
202101	200633	14267Y	PARTICIPANT	\N	PRESENT	0
202102	200633	14195A	PARTICIPANT	\N	PRESENT	0
202103	200633	14213J	PARTICIPANT	\N	PRESENT	0
202104	200633	14217N	PARTICIPANT	\N	PRESENT	0
202105	200633	10006L	PARTICIPANT	\N	PRESENT	0
202106	200633	98024R	PRESIDENT	0	PRESENT	0
202107	200633	14265W	PARTICIPANT	\N	PRESENT	0
202108	200633	14053L	PARTICIPANT	\N	EXCUSE	0
202109	200633	14017T	PARTICIPANT	\N	EXCUSE	0
202110	200633	00003C	PARTICIPANT	\N	EXCUSE	0
202111	200633	08041T	PARTICIPANT	\N	PRESENT	0
202112	200633	14271U	PARTICIPANT	\N	PRESENT	0
202113	200633	14026U	PARTICIPANT	\N	PRESENT	0
202114	200633	01059Y	PARTICIPANT	\N	PRESENT	0
202115	200633	14119M	PARTICIPANT	\N	PRESENT	0
202132	200633	14071N	PARTICIPANT	\N	PRESENT	0
202133	200633	04092N	PRESIDENT	1	PRESENT	0
202134	200633	04043D	PARTICIPANT	\N	PRESENT	0
202135	200633	11025F	PARTICIPANT	\N	PRESENT	0
202136	200633	04053F	PARTICIPANT	\N	PRESENT	0
202137	200633	11063M	PARTICIPANT	\N	PRESENT	0
202152	200633	01034P	PARTICIPANT	\N	PRESENT	0
202153	200633	12042Y	PARTICIPANT	\N	PRESENT	0
202154	200633	14231L	PARTICIPANT	\N	PRESENT	0
202212	201055	04034C	PARTICIPANT	\N	PRESENT	0
202232	201055	07029T	PARTICIPANT	\N	PRESENT	0
202233	201055	14085U	PARTICIPANT	\N	PRESENT	0
202332	201055	04061F	PARTICIPANT	\N	PRESENT	0
202392	200633	01046T	PARTICIPANT	\N	EXCUSE	0
204088	190806	04085P	PARTICIPANT	\N	PRESENT	0
204089	190806	11034G	PARTICIPANT	\N	PRESENT	0
204086	190806	11031D	PARTICIPANT	\N	PRESENT	0
204087	190806	14111D	PARTICIPANT	\N	PRESENT	0
204093	190806	14361V	PARTICIPANT	\N	PRESENT	0
204091	190806	12041X	PARTICIPANT	\N	PRESENT	0
204092	190806	01019Q	PARTICIPANT	\N	PRESENT	0
204094	190806	08011M	PARTICIPANT	\N	PRESENT	0
204095	190806	11063M	PARTICIPANT	\N	PRESENT	0
204096	190806	11098Y	PARTICIPANT	\N	PRESENT	0
204097	190806	11061K	PARTICIPANT	\N	PRESENT	0
204098	190806	92031P	PARTICIPANT	\N	PRESENT	0
204099	190806	14269B	PARTICIPANT	\N	PRESENT	0
204100	190806	08010L	PARTICIPANT	\N	PRESENT	0
204101	190806	14001X	PARTICIPANT	\N	PRESENT	0
204102	190806	14237S	PARTICIPANT	\N	PRESENT	0
204103	190806	11054L	PARTICIPANT	\N	PRESENT	0
204104	190806	04057K	PARTICIPANT	\N	PRESENT	0
204105	190806	08068F	PARTICIPANT	\N	PRESENT	0
204106	190806	11105E	PARTICIPANT	\N	PRESENT	0
204107	190806	14031R	PARTICIPANT	\N	PRESENT	0
204108	190806	08016S	PARTICIPANT	\N	PRESENT	0
204109	190806	98035U	PARTICIPANT	\N	PRESENT	0
204110	190806	01016M	PARTICIPANT	\N	PRESENT	0
204111	190806	04056J	PARTICIPANT	\N	PRESENT	0
204112	190806	11039M	PARTICIPANT	\N	PRESENT	0
204113	190806	14251Q	PARTICIPANT	\N	PRESENT	0
204114	190806	08038Y	PARTICIPANT	\N	PRESENT	0
204115	190806	98046X	PARTICIPANT	\N	PRESENT	0
204116	190806	08034U	PARTICIPANT	\N	PRESENT	0
204117	190806	08052W	PARTICIPANT	\N	PRESENT	0
204118	190806	14051J	PARTICIPANT	\N	PRESENT	0
204119	190806	01027Q	PARTICIPANT	\N	PRESENT	0
204120	190806	14151M	PARTICIPANT	\N	PRESENT	0
204121	190806	04035D	PARTICIPANT	\N	PRESENT	0
204122	190806	11110B	PARTICIPANT	\N	PRESENT	0
204123	190806	11045K	PARTICIPANT	\N	PRESENT	0
204124	190806	01008M	PARTICIPANT	\N	PRESENT	0
204125	190806	11010L	PARTICIPANT	\N	PRESENT	0
204126	190806	11089X	PARTICIPANT	\N	PRESENT	0
204127	190806	14195A	PARTICIPANT	\N	PRESENT	0
204128	190806	04042C	PARTICIPANT	\N	PRESENT	0
166201	166178	04054G	PARTICIPANT	\N	PRESENT	0
166204	166178	04047H	PARTICIPANT	\N	PRESENT	0
166206	166178	14079W	PARTICIPANT	\N	PRESENT	0
166207	166178	14026U	PARTICIPANT	\N	PRESENT	0
166208	166178	14097Y	PARTICIPANT	\N	PRESENT	0
166209	166178	11026G	PARTICIPANT	\N	PRESENT	0
166210	166178	14001X	PARTICIPANT	\N	PRESENT	0
166211	166178	10015M	PARTICIPANT	\N	PRESENT	0
166212	166178	11012A	PARTICIPANT	\N	PRESENT	0
166213	166178	14227Q	PARTICIPANT	\N	PRESENT	0
166214	166178	11066Q	PARTICIPANT	\N	PRESENT	0
166215	166178	95067Q	PARTICIPANT	\N	PRESENT	0
171106	171105	92031P	PARTICIPANT	\N	PRESENT	0
171107	171105	14063N	PARTICIPANT	\N	PRESENT	0
170836	170832	14013P	PARTICIPANT	\N	PRESENT	0
170837	170832	08068F	PARTICIPANT	\N	PRESENT	0
170838	170832	14207L	PARTICIPANT	\N	PRESENT	0
171194	171193	01031L	PARTICIPANT	\N	PRESENT	0
174588	167278	01025N	PARTICIPANT	\N	PRESENT	0
174592	167278	14201E	PARTICIPANT	\N	PRESENT	0
166200	166178	14133K	PARTICIPANT	\N	PRESENT	0
170842	170832	80013X	PARTICIPANT	\N	PRESENT	0
170843	170832	14357A	PARTICIPANT	\N	EXCUSE	0
170844	170832	08038Y	PARTICIPANT	\N	PRESENT	0
174590	167278	14263U	PARTICIPANT	\N	PRESENT	0
174591	167278	13002U	PARTICIPANT	\N	PRESENT	0
174612	167278	95063L	PARTICIPANT	\N	PRESENT	0
170848	170832	14187A	PARTICIPANT	\N	PRESENT	0
170849	170832	14033T	PARTICIPANT	\N	PRESENT	0
174613	167278	07034Q	PARTICIPANT	\N	PRESENT	0
174614	167278	14073Q	PARTICIPANT	\N	PRESENT	0
174807	167279	01059Y	PARTICIPANT	\N	PRESENT	0
174808	167279	01013J	PARTICIPANT	\N	PRESENT	0
170854	170832	11111C	PARTICIPANT	\N	PRESENT	0
174809	167279	07026Q	PARTICIPANT	\N	PRESENT	0
170856	170832	11100Y	PRESIDENT	0	PRESENT	0
174810	167279	11034G	PARTICIPANT	\N	PRESENT	0
170858	170832	11098Y	PARTICIPANT	\N	PRESENT	0
174811	167279	04085P	PARTICIPANT	\N	PRESENT	0
174812	167279	04050C	PARTICIPANT	\N	PRESENT	0
174813	167279	11056N	PARTICIPANT	\N	PRESENT	0
170862	170832	08019V	PARTICIPANT	\N	PRESENT	0
174814	167279	04054G	PARTICIPANT	\N	PRESENT	0
174815	167279	14263U	PARTICIPANT	\N	PRESENT	0
170865	170832	04088S	PARTICIPANT	\N	PRESENT	0
170866	170832	98050T	PARTICIPANT	\N	PRESENT	0
170867	170832	11090Q	PARTICIPANT	\N	PRESENT	0
174816	167279	11040E	PARTICIPANT	\N	PRESENT	0
170869	170832	01058X	PARTICIPANT	\N	PRESENT	0
174817	167279	11063M	PARTICIPANT	\N	PRESENT	0
170871	170832	11066Q	PARTICIPANT	\N	PRESENT	0
174818	167279	05001W	PARTICIPANT	\N	PRESENT	0
174819	167279	01015L	PARTICIPANT	\N	PRESENT	0
174820	167279	14361V	PARTICIPANT	\N	PRESENT	0
174821	167279	01008M	PARTICIPANT	\N	PRESENT	0
174822	167279	92018S	PARTICIPANT	\N	PRESENT	0
174823	167279	14069U	PARTICIPANT	\N	PRESENT	0
174824	167279	14105F	PARTICIPANT	\N	PRESENT	0
174825	167279	11101A	PARTICIPANT	\N	PRESENT	0
174826	167279	11076S	PARTICIPANT	\N	PRESENT	0
174827	167279	11065P	PARTICIPANT	\N	PRESENT	0
174828	167279	11029K	PARTICIPANT	\N	PRESENT	0
174829	167279	11103C	PARTICIPANT	\N	PRESENT	0
174830	167279	13002U	PARTICIPANT	\N	PRESENT	0
174831	167279	04067M	PARTICIPANT	\N	PRESENT	0
174832	167279	11033F	PARTICIPANT	\N	PRESENT	0
174833	167279	14187A	PARTICIPANT	\N	PRESENT	0
174834	167279	95031C	PARTICIPANT	\N	PRESENT	0
174835	167279	14195A	PARTICIPANT	\N	PRESENT	0
174836	167279	08028W	PARTICIPANT	\N	PRESENT	0
174837	167279	04078Q	PARTICIPANT	\N	PRESENT	0
174838	167279	88008L	PARTICIPANT	\N	PRESENT	0
174839	167279	14041T	PARTICIPANT	\N	PRESENT	0
174840	167279	01046T	PARTICIPANT	\N	PRESENT	0
174841	167279	14217N	PARTICIPANT	\N	PRESENT	0
174842	167279	08049C	PARTICIPANT	\N	PRESENT	0
174843	167279	14215L	PARTICIPANT	\N	PRESENT	0
174844	167279	11081P	PARTICIPANT	\N	PRESENT	0
174845	167279	11012A	PARTICIPANT	\N	PRESENT	0
174846	167279	04038G	PARTICIPANT	\N	PRESENT	0
174847	167279	97011G	PARTICIPANT	\N	PRESENT	0
174848	167279	11096W	PARTICIPANT	\N	PRESENT	0
174849	167279	08065C	PARTICIPANT	\N	PRESENT	0
174850	167279	14201E	PARTICIPANT	\N	PRESENT	0
174851	167279	14211G	PARTICIPANT	\N	PRESENT	0
174852	167279	14261S	PARTICIPANT	\N	PRESENT	0
174853	167279	14033T	PARTICIPANT	\N	PRESENT	0
174854	167279	14355X	PARTICIPANT	\N	PRESENT	0
174855	167279	08048B	PARTICIPANT	\N	PRESENT	0
174856	167279	08041T	PARTICIPANT	\N	PRESENT	0
174857	167279	98022P	PARTICIPANT	\N	PRESENT	0
174858	167279	89029V	PARTICIPANT	\N	PRESENT	0
174859	167279	14213J	PARTICIPANT	\N	PRESENT	0
174860	167279	04061F	PARTICIPANT	\N	PRESENT	0
174861	167279	08016S	PARTICIPANT	\N	PRESENT	0
174862	167279	14061L	PARTICIPANT	\N	PRESENT	0
174863	167279	11039M	PARTICIPANT	\N	PRESENT	0
174864	167279	01016M	PARTICIPANT	\N	PRESENT	0
174865	167279	08015R	PARTICIPANT	\N	PRESENT	0
174866	167279	08010L	PARTICIPANT	\N	PRESENT	0
174867	167279	01044R	PARTICIPANT	\N	PRESENT	0
174868	167279	08039A	PARTICIPANT	\N	PRESENT	0
174869	167279	92015P	PARTICIPANT	\N	PRESENT	0
174870	167279	14037X	PARTICIPANT	\N	PRESENT	0
174871	167279	11100Y	PARTICIPANT	\N	PRESENT	0
174872	167279	01061S	PARTICIPANT	\N	PRESENT	0
174873	167279	98046X	PARTICIPANT	\N	PRESENT	0
174874	167279	08052W	PARTICIPANT	\N	PRESENT	0
174875	167279	08051V	PARTICIPANT	\N	PRESENT	0
174876	167279	01048V	PARTICIPANT	\N	PRESENT	0
174877	167279	14059S	PARTICIPANT	\N	PRESENT	0
174878	167279	11035H	PARTICIPANT	\N	PRESENT	0
174879	167279	08019V	PARTICIPANT	\N	PRESENT	0
174880	167279	08025T	PARTICIPANT	\N	PRESENT	0
174881	167279	14051J	PARTICIPANT	\N	PRESENT	0
174882	167279	14265W	PARTICIPANT	\N	PRESENT	0
174883	167279	14107H	PARTICIPANT	\N	PRESENT	0
174884	167279	04092N	PARTICIPANT	\N	PRESENT	0
174885	167279	14223L	PARTICIPANT	\N	PRESENT	0
174886	167279	11057P	PARTICIPANT	\N	PRESENT	0
174887	167279	14147R	PARTICIPANT	\N	PRESENT	0
174888	167279	04057K	PARTICIPANT	\N	PRESENT	0
174889	167279	01011G	PARTICIPANT	\N	PRESENT	0
174890	167279	08062Y	PARTICIPANT	\N	PRESENT	0
174891	167279	11027H	PARTICIPANT	\N	PRESENT	0
174892	167279	04066L	PARTICIPANT	\N	PRESENT	0
174893	167279	08055A	PARTICIPANT	\N	PRESENT	0
174894	167279	11084S	PARTICIPANT	\N	PRESENT	0
174895	167279	92020L	PARTICIPANT	\N	PRESENT	0
174896	167279	14157T	PARTICIPANT	\N	PRESENT	0
174897	167279	08060W	PARTICIPANT	\N	PRESENT	0
174898	167279	80013X	PARTICIPANT	\N	PRESENT	0
174740	167279	86034E	PARTICIPANT	\N	PRESENT	0
174741	174354	14327T	PARTICIPANT	\N	PRESENT	0
174742	174354	01057W	PARTICIPANT	\N	PRESENT	0
174743	174354	11053K	PARTICIPANT	\N	PRESENT	0
174744	174354	11074Q	PARTICIPANT	\N	PRESENT	0
174745	174354	14225N	PARTICIPANT	\N	PRESENT	0
174746	174354	88008L	PARTICIPANT	\N	PRESENT	0
174747	174354	11068S	PARTICIPANT	\N	PRESENT	0
174748	174354	11088W	PARTICIPANT	\N	PRESENT	0
174749	174354	07029T	PARTICIPANT	\N	PRESENT	0
174750	174354	08010L	PARTICIPANT	\N	PRESENT	0
174751	174354	08016S	PARTICIPANT	\N	PRESENT	0
174752	174354	14175V	PARTICIPANT	\N	PRESENT	0
174753	174354	11048N	PARTICIPANT	\N	PRESENT	0
174754	174354	08034U	PARTICIPANT	\N	PRESENT	0
174755	174354	01016M	PARTICIPANT	\N	PRESENT	0
174756	174354	08014Q	PARTICIPANT	\N	PRESENT	0
174757	174354	01027Q	PARTICIPANT	\N	PRESENT	0
174758	174354	14159V	PARTICIPANT	\N	PRESENT	0
174759	174354	14173T	PARTICIPANT	\N	PRESENT	0
174760	174354	04086Q	PARTICIPANT	\N	PRESENT	0
174761	174354	11040E	PARTICIPANT	\N	PRESENT	0
174762	174354	14083S	PARTICIPANT	\N	PRESENT	0
174763	174354	11057P	PARTICIPANT	\N	PRESENT	0
174764	174354	98046X	PARTICIPANT	\N	PRESENT	0
174765	174354	99004R	PARTICIPANT	\N	PRESENT	0
174766	174354	04061F	PRESIDENT	0	PRESENT	0
174767	174354	01013J	PARTICIPANT	\N	PRESENT	0
174768	174354	11042G	PARTICIPANT	\N	PRESENT	0
174769	174354	04071H	PARTICIPANT	\N	PRESENT	0
174770	174354	01031L	PARTICIPANT	\N	EXCUSE	0
174771	174354	11012A	PARTICIPANT	\N	EXCUSE	0
174772	174354	98053W	PARTICIPANT	\N	EXCUSE	0
174773	174354	08011M	PARTICIPANT	\N	EXCUSE	0
182293	182292	11068S	PARTICIPANT	\N	PRESENT	0
182295	182294	11068S	PARTICIPANT	\N	PRESENT	0
182297	182296	11053K	PARTICIPANT	\N	PRESENT	0
185953	185952	01057W	PARTICIPANT	\N	PRESENT	0
185954	185952	14225N	PARTICIPANT	\N	PRESENT	0
210034	210033	11049P	PARTICIPANT	\N	PRESENT	0
210039	208063	98018T	PARTICIPANT	\N	EXCUSE	0
210040	208063	19319Q	PARTICIPANT	\N	EXCUSE	0
210041	208063	08049C	PARTICIPANT	\N	EXCUSE	0
210192	210191	10006L	PARTICIPANT	\N	PRESENT	0
210193	210045	08041T	PARTICIPANT	\N	EXCUSE	0
211058	207687	19253P	PARTICIPANT	\N	PRESENT	0
211059	207687	14213J	PARTICIPANT	\N	PRESENT	0
211060	207687	14038Y	PARTICIPANT	\N	PRESENT	0
211061	207687	19507S	PARTICIPANT	\N	PRESENT	0
211062	207687	14119M	PARTICIPANT	\N	PRESENT	0
211063	207687	04044E	PARTICIPANT	\N	PRESENT	0
211064	207687	11026G	PARTICIPANT	\N	PRESENT	0
211065	207687	14083S	PARTICIPANT	\N	PRESENT	0
211066	207687	14211G	PARTICIPANT	\N	PRESENT	0
211067	207687	14231L	PARTICIPANT	\N	PRESENT	0
211068	207687	14275Y	PARTICIPANT	\N	PRESENT	0
211069	207687	14219Q	PARTICIPANT	\N	PRESENT	0
211070	207687	18083K	PARTICIPANT	\N	PRESENT	0
211071	207687	08049C	PARTICIPANT	\N	PRESENT	0
211075	207687	14059S	PARTICIPANT	\N	PRESENT	0
211073	207687	08019V	PARTICIPANT	\N	PRESENT	0
211074	207687	17583W	PARTICIPANT	\N	PRESENT	0
211076	207687	11085T	PARTICIPANT	\N	PRESENT	0
211077	207687	14265W	PARTICIPANT	\N	PRESENT	0
211078	207687	08015R	PARTICIPANT	\N	PRESENT	0
211079	207687	14026U	PARTICIPANT	\N	PRESENT	0
211080	207687	14071N	PARTICIPANT	\N	PRESENT	0
211081	207687	14034U	PARTICIPANT	\N	PRESENT	0
211082	207687	14179A	PARTICIPANT	\N	PRESENT	0
211152	208073	08052W	PARTICIPANT	\N	PRESENT	0
211153	208073	11063M	PARTICIPANT	\N	PRESENT	0
211056	207687	14069U	PARTICIPANT	\N	PRESENT	0
211057	207687	19629C	PARTICIPANT	\N	PRESENT	0
211154	208073	14026U	PARTICIPANT	\N	PRESENT	0
211155	208073	19691J	PARTICIPANT	\N	PRESENT	0
211156	208073	19521Q	PARTICIPANT	\N	PRESENT	0
211157	208073	11103C	PARTICIPANT	\N	PRESENT	0
211171	210043	14231L	PARTICIPANT	\N	EXCUSE	0
211338	210160	19681G	PARTICIPANT	\N	PRESENT	0
211339	210160	98023Q	PARTICIPANT	\N	PRESENT	0
211340	210160	19525U	PARTICIPANT	\N	PRESENT	0
211341	210160	11065P	PARTICIPANT	\N	PRESENT	0
211342	210160	19659J	PARTICIPANT	\N	PRESENT	0
211343	210160	19599P	PARTICIPANT	\N	PRESENT	0
211344	210160	02002K	PARTICIPANT	\N	PRESENT	0
211345	210160	15447F	PARTICIPANT	\N	PRESENT	0
211346	210160	19387D	PARTICIPANT	\N	PRESENT	0
211347	210160	19347U	PARTICIPANT	\N	PRESENT	0
211375	210099	11080N	PARTICIPANT	\N	PRESENT	0
211377	210151	89017R	PARTICIPANT	\N	PRESENT	0
211350	210160	19333N	PARTICIPANT	\N	PRESENT	0
211351	210160	04097T	PARTICIPANT	\N	PRESENT	0
211352	210160	19551W	PARTICIPANT	\N	PRESENT	0
211353	210160	14029X	PARTICIPANT	\N	PRESENT	0
211378	210151	19667J	PARTICIPANT	\N	PRESENT	0
211355	210160	19289C	PARTICIPANT	\N	PRESENT	0
211356	210160	14219Q	PARTICIPANT	\N	PRESENT	0
211357	210160	14103D	PARTICIPANT	\N	PRESENT	0
211358	210160	80027E	PARTICIPANT	\N	PRESENT	0
211359	210160	14031R	PARTICIPANT	\N	PRESENT	0
211360	210160	19637C	PARTICIPANT	\N	PRESENT	0
211361	210160	08009T	PRESIDENT	0	PRESENT	0
211362	210160	14221J	PARTICIPANT	\N	PRESENT	0
211363	210160	14169X	PARTICIPANT	\N	PRESENT	0
211364	210160	14191V	PARTICIPANT	\N	PRESENT	0
211365	210160	14237S	PARTICIPANT	\N	PRESENT	0
211366	210160	17637T	PARTICIPANT	\N	PRESENT	0
211367	210160	05012A	PARTICIPANT	\N	PRESENT	0
211368	210160	19503N	PARTICIPANT	\N	PRESENT	0
211369	210160	17583W	PARTICIPANT	\N	PRESENT	0
211370	210160	95062K	PARTICIPANT	\N	PRESENT	0
211371	210160	19713W	PARTICIPANT	\N	PRESENT	0
211372	210160	14051J	PARTICIPANT	\N	PRESENT	0
211373	210160	14157T	PARTICIPANT	\N	PRESENT	0
211374	210160	19737F	PARTICIPANT	\N	PRESENT	0
211376	210099	04035D	PARTICIPANT	\N	PRESENT	0
211379	210151	11040E	PARTICIPANT	\N	PRESENT	0
211380	210151	14083S	PARTICIPANT	\N	PRESENT	0
211381	210151	11053K	PARTICIPANT	\N	PRESENT	0
211382	210151	19545Y	PARTICIPANT	\N	PRESENT	0
211383	210151	14085U	PARTICIPANT	\N	PRESENT	0
211384	210151	88008L	PARTICIPANT	\N	PRESENT	0
211385	210151	04086Q	PARTICIPANT	\N	PRESENT	0
211386	210151	11070L	PARTICIPANT	\N	PRESENT	0
211387	210151	14327T	PARTICIPANT	\N	PRESENT	0
211388	210151	11074Q	PRESIDENT	0	PRESENT	0
211389	210151	11110B	PARTICIPANT	\N	PRESENT	0
211390	210151	19647E	PARTICIPANT	\N	PRESENT	0
211391	210151	14199E	PARTICIPANT	\N	PRESENT	0
211392	210151	07004J	PARTICIPANT	\N	PRESENT	0
211393	210151	01057W	PARTICIPANT	\N	PRESENT	0
211394	210151	11048N	PARTICIPANT	\N	PRESENT	0
211395	210151	14121F	PARTICIPANT	\N	PRESENT	0
211396	210151	04061F	PARTICIPANT	\N	PRESENT	0
211397	210151	14159V	PARTICIPANT	\N	PRESENT	0
211398	210151	07029T	PARTICIPANT	\N	PRESENT	0
211399	210151	14277B	PARTICIPANT	\N	PRESENT	0
211400	210151	19711U	PARTICIPANT	\N	PRESENT	0
211401	210151	08010L	PARTICIPANT	\N	PRESENT	0
211402	210151	01048V	PARTICIPANT	\N	PRESENT	0
211405	210043	14195A	PARTICIPANT	\N	EXCUSE	0
211404	210151	12016W	PARTICIPANT	\N	PRESENT	0
211406	210151	08011M	PARTICIPANT	\N	PRESENT	0
211407	210151	14253S	PARTICIPANT	\N	PRESENT	0
211408	210151	14331P	PARTICIPANT	\N	PRESENT	0
211409	210151	14225N	PARTICIPANT	\N	EXCUSE	0
211410	210151	19687N	PARTICIPANT	\N	PRESENT	0
211411	210151	19689Q	PARTICIPANT	\N	PRESENT	0
211412	210151	19479G	PARTICIPANT	\N	PRESENT	0
211413	210151	14173T	PARTICIPANT	\N	PRESENT	0
211414	210151	14179A	RAPPORTEUR_AVIS	\N	PRESENT	0
211415	210145	19551W	PARTICIPANT	\N	PRESENT	0
211417	211416	08039A	PARTICIPANT	\N	PRESENT	0
211418	210152	19545Y	PARTICIPANT	\N	PRESENT	0
211419	210152	11074Q	PRESIDENT	0	PRESENT	0
211420	210152	19667J	PARTICIPANT	\N	PRESENT	0
211421	210152	19671E	PARTICIPANT	\N	PRESENT	0
211422	210152	04047H	RAPPORTEUR_AVIS	\N	PRESENT	0
211423	210152	11110B	PARTICIPANT	\N	PRESENT	0
211424	210152	14277B	PARTICIPANT	\N	PRESENT	0
211425	210152	14085U	PARTICIPANT	\N	PRESENT	0
211426	210152	07004J	PARTICIPANT	\N	PRESENT	0
211427	210152	19349W	PARTICIPANT	\N	PRESENT	0
211428	210152	08010L	PARTICIPANT	\N	PRESENT	0
211429	210152	19479G	PARTICIPANT	\N	PRESENT	0
211430	210152	19647E	PARTICIPANT	\N	PRESENT	0
211431	210152	19711U	PARTICIPANT	\N	PRESENT	0
211432	210152	95067Q	RAPPORTEUR_AVIS	\N	PRESENT	0
211433	210152	19651A	PARTICIPANT	\N	PRESENT	0
211434	210152	12016W	PARTICIPANT	\N	PRESENT	0
211435	210152	14028W	RAPPORTEUR_AVIS	\N	PRESENT	0
211436	210152	14034U	PARTICIPANT	\N	PRESENT	0
211437	210152	14159V	PARTICIPANT	\N	PRESENT	0
211438	210152	14083S	PARTICIPANT	\N	PRESENT	0
211439	210152	11012A	PARTICIPANT	\N	PRESENT	0
211440	210152	04061F	PARTICIPANT	\N	PRESENT	0
211441	210152	14021P	RAPPORTEUR_AVIS	\N	PRESENT	0
211442	210152	14327T	PARTICIPANT	\N	PRESENT	0
211443	210152	14331P	PARTICIPANT	\N	PRESENT	0
211444	210152	04071H	PARTICIPANT	\N	PRESENT	0
211445	210152	11048N	PARTICIPANT	\N	PRESENT	0
211446	210152	95041E	PARTICIPANT	\N	PRESENT	0
211447	210152	01048V	PARTICIPANT	\N	PRESENT	0
211448	210152	08034U	PARTICIPANT	\N	PRESENT	0
211449	210152	08069G	PARTICIPANT	\N	PRESENT	0
211450	210152	19687N	PARTICIPANT	\N	PRESENT	0
211451	210152	01057W	PARTICIPANT	\N	PRESENT	0
211452	210152	19689Q	PARTICIPANT	\N	PRESENT	0
211453	210152	11053K	PARTICIPANT	\N	PRESENT	0
211454	210152	89017R	PARTICIPANT	\N	PRESENT	0
211455	210152	08011M	PARTICIPANT	\N	PRESENT	0
211456	210152	88008L	PARTICIPANT	\N	PRESENT	0
211457	210152	14173T	PARTICIPANT	\N	PRESENT	0
211458	210152	04086Q	PARTICIPANT	\N	PRESENT	0
211459	210152	11040E	PARTICIPANT	\N	PRESENT	0
211460	210152	07029T	PARTICIPANT	\N	PRESENT	0
211461	210152	14199E	PARTICIPANT	\N	PRESENT	0
211462	210152	14121F	PARTICIPANT	\N	PRESENT	0
211463	210152	99004R	PARTICIPANT	\N	PRESENT	0
211464	210152	14253S	PARTICIPANT	\N	PRESENT	0
211465	210045	04038G	PARTICIPANT	\N	PRESENT	0
211466	210099	19669L	PARTICIPANT	\N	PRESENT	0
166969	166235	14205J	PARTICIPANT	\N	PRESENT	0
166970	166235	11112D	PARTICIPANT	\N	PRESENT	0
166971	166235	04070G	PARTICIPANT	\N	PRESENT	0
166972	166235	11033F	PARTICIPANT	\N	PRESENT	0
166976	166235	11068S	PARTICIPANT	\N	PRESENT	0
166982	166235	99002P	PARTICIPANT	\N	PRESENT	0
166983	166235	14357A	PARTICIPANT	\N	PRESENT	0
166984	166235	14265W	PARTICIPANT	\N	PRESENT	0
166985	166235	09001P	PARTICIPANT	\N	PRESENT	0
166986	166235	04079R	PARTICIPANT	\N	PRESENT	0
166987	166235	04043D	PARTICIPANT	\N	PRESENT	0
166988	166235	01047U	PARTICIPANT	\N	PRESENT	0
166989	166235	11054L	PARTICIPANT	\N	PRESENT	0
166990	166235	14037X	PARTICIPANT	\N	PRESENT	0
166991	166235	04071H	PARTICIPANT	\N	PRESENT	0
166992	166235	11076S	PARTICIPANT	\N	PRESENT	0
166993	166235	14247U	PARTICIPANT	\N	PRESENT	0
166994	166235	01014K	PARTICIPANT	\N	PRESENT	0
166995	166235	14207L	PARTICIPANT	\N	PRESENT	0
166997	166235	14253S	PARTICIPANT	\N	PRESENT	0
166998	166235	14089Y	PARTICIPANT	\N	PRESENT	0
167005	166235	11026G	PARTICIPANT	\N	PRESENT	0
167273	166236	04066L	PARTICIPANT	\N	PRESENT	0
167274	166236	04074L	PARTICIPANT	\N	PRESENT	0
167275	166236	01057W	PARTICIPANT	\N	PRESENT	0
167296	166236	14103D	PARTICIPANT	\N	PRESENT	0
167297	166236	04067M	PARTICIPANT	\N	PRESENT	0
167298	166236	13002U	PARTICIPANT	\N	PRESENT	0
167299	166236	11061K	PARTICIPANT	\N	PRESENT	0
167300	166236	11077T	PARTICIPANT	\N	PRESENT	0
167301	166236	11066Q	PARTICIPANT	\N	PRESENT	0
167302	166236	14014Q	PARTICIPANT	\N	PRESENT	0
167303	166236	14201E	PARTICIPANT	\N	PRESENT	0
167304	166236	14055N	PARTICIPANT	\N	PRESENT	0
167305	166236	14191V	PARTICIPANT	\N	PRESENT	0
167307	166236	04057K	PARTICIPANT	\N	PRESENT	0
167308	166236	04080J	PARTICIPANT	\N	PRESENT	0
167309	166236	11034G	PARTICIPANT	\N	PRESENT	0
167333	166236	01031L	PARTICIPANT	\N	PRESENT	0
167335	166236	98005N	PARTICIPANT	\N	PRESENT	0
167341	166236	11012A	PARTICIPANT	\N	PRESENT	0
167343	166236	08051V	PARTICIPANT	\N	PRESENT	0
167344	166236	05008E	PARTICIPANT	\N	PRESENT	0
167355	166236	04036E	PARTICIPANT	\N	PRESENT	0
167356	166236	11084S	PARTICIPANT	\N	PRESENT	0
167357	166236	11095V	PARTICIPANT	\N	PRESENT	0
167358	166236	11083R	PARTICIPANT	\N	PRESENT	0
167359	166236	14205J	PARTICIPANT	\N	PRESENT	0
167360	166236	04043D	PARTICIPANT	\N	PRESENT	0
167361	166236	04071H	PARTICIPANT	\N	PRESENT	0
167372	166236	11056N	PARTICIPANT	\N	PRESENT	0
167373	166236	11011M	PARTICIPANT	\N	PRESENT	0
167374	166236	14363X	PARTICIPANT	\N	PRESENT	0
167418	166236	89017R	PARTICIPANT	\N	PRESENT	0
167732	167006	86034E	PARTICIPANT	\N	PRESENT	0
167752	167006	05008E	PARTICIPANT	\N	PRESENT	0
167753	167006	07034Q	PARTICIPANT	\N	PRESENT	0
167754	167006	08025T	PARTICIPANT	\N	PRESENT	0
167755	167006	11066Q	PARTICIPANT	\N	PRESENT	0
167756	167006	14065Q	PARTICIPANT	\N	PRESENT	0
167757	167006	08016S	PARTICIPANT	\N	PRESENT	0
167758	167006	14107H	PARTICIPANT	\N	PRESENT	0
167759	167006	01022K	PARTICIPANT	\N	PRESENT	0
167760	167006	14361V	PARTICIPANT	\N	PRESENT	0
167761	167006	11037K	PARTICIPANT	\N	PRESENT	0
167762	167006	11040E	PARTICIPANT	\N	PRESENT	0
167763	167006	08031R	PARTICIPANT	\N	PRESENT	0
167764	167006	01047U	PARTICIPANT	\N	PRESENT	0
167765	167006	14215L	PARTICIPANT	\N	PRESENT	0
167766	167006	01024M	PARTICIPANT	\N	PRESENT	0
167767	167006	11033F	PARTICIPANT	\N	PRESENT	0
167768	167006	11056N	PARTICIPANT	\N	PRESENT	0
167769	167006	14105F	PARTICIPANT	\N	PRESENT	0
167770	167006	08019V	PARTICIPANT	\N	PRESENT	0
167771	167006	14041T	PARTICIPANT	\N	PRESENT	0
167772	167006	04088S	PARTICIPANT	\N	PRESENT	0
167773	167006	07029T	PARTICIPANT	\N	PRESENT	0
167774	167006	14119M	PARTICIPANT	\N	PRESENT	0
167775	167006	14059S	PARTICIPANT	\N	PRESENT	0
167776	167006	14217N	PARTICIPANT	\N	PRESENT	0
167777	167006	14269B	PARTICIPANT	\N	PRESENT	0
167778	167006	14038Y	PARTICIPANT	\N	PRESENT	0
167779	167006	04033B	PARTICIPANT	\N	PRESENT	0
167780	167006	04081K	PARTICIPANT	\N	PRESENT	0
167781	167006	14223L	PARTICIPANT	\N	PRESENT	0
167782	167006	14042U	PARTICIPANT	\N	PRESENT	0
167783	167006	11067R	PARTICIPANT	\N	PRESENT	0
167784	167006	14103D	PARTICIPANT	\N	PRESENT	0
167785	167006	95049N	PARTICIPANT	\N	PRESENT	0
167786	167006	08051V	PARTICIPANT	\N	PRESENT	0
167787	167006	95063L	PARTICIPANT	\N	PRESENT	0
167788	167006	01028R	PARTICIPANT	\N	PRESENT	0
167789	167006	14187A	PARTICIPANT	\N	PRESENT	0
167790	167006	08034U	PARTICIPANT	\N	PRESENT	0
167791	167006	14363X	PARTICIPANT	\N	PRESENT	0
167792	167006	11103C	PARTICIPANT	\N	PRESENT	0
167793	167006	90003B	PARTICIPANT	\N	PRESENT	0
167794	167006	08062Y	PARTICIPANT	\N	PRESENT	0
167795	167006	14195A	PARTICIPANT	\N	PRESENT	0
167796	167006	80027E	PARTICIPANT	\N	PRESENT	0
167797	167006	04047H	PARTICIPANT	\N	PRESENT	0
167798	167006	14357A	PARTICIPANT	\N	PRESENT	0
167799	167006	08010L	PARTICIPANT	\N	PRESENT	0
167800	167006	08028W	PARTICIPANT	\N	PRESENT	0
167801	167006	04056J	PARTICIPANT	\N	PRESENT	0
167802	167006	14111D	PARTICIPANT	\N	PRESENT	0
167803	167006	14231L	PARTICIPANT	\N	PRESENT	0
167804	167006	11100Y	PARTICIPANT	\N	PRESENT	0
167805	167006	95035G	PARTICIPANT	\N	PRESENT	0
167806	167006	01027Q	PARTICIPANT	\N	PRESENT	0
167807	167006	14267Y	PARTICIPANT	\N	PRESENT	0
167808	167006	92045V	PARTICIPANT	\N	PRESENT	0
167809	167006	11049P	PARTICIPANT	\N	PRESENT	0
167810	167006	87003B	PARTICIPANT	\N	PRESENT	0
167812	167006	11057P	PARTICIPANT	\N	PRESENT	0
167813	167006	08058D	PARTICIPANT	\N	PRESENT	0
167814	167006	14063N	PARTICIPANT	\N	PRESENT	0
167815	167006	14225N	PARTICIPANT	\N	PRESENT	0
167816	167006	14205J	PARTICIPANT	\N	PRESENT	0
167817	167006	95067Q	PARTICIPANT	\N	PRESENT	0
167818	167006	95031C	PARTICIPANT	\N	PRESENT	0
167819	167006	04053F	PARTICIPANT	\N	PRESENT	0
167820	167006	14051J	PARTICIPANT	\N	PRESENT	0
167821	167006	11053K	PARTICIPANT	\N	PRESENT	0
167822	167006	14089Y	PARTICIPANT	\N	PRESENT	0
167823	167006	11011M	PARTICIPANT	\N	PRESENT	0
167824	167006	14135M	PARTICIPANT	\N	PRESENT	0
167825	167006	04049K	PARTICIPANT	\N	PRESENT	0
167826	167006	08015R	PARTICIPANT	\N	PRESENT	0
167827	167006	05012A	PARTICIPANT	\N	PRESENT	0
167828	167006	01041N	PARTICIPANT	\N	PRESENT	0
167829	167006	14157T	PARTICIPANT	\N	PRESENT	0
167830	167006	08024S	PARTICIPANT	\N	PRESENT	0
167831	167006	14147R	PARTICIPANT	\N	PRESENT	0
167833	167006	14265W	PARTICIPANT	\N	PRESENT	0
167834	167006	11097X	PARTICIPANT	\N	PRESENT	0
167835	167006	14237S	PARTICIPANT	\N	PRESENT	0
167836	167006	14013P	PARTICIPANT	\N	PRESENT	0
167837	167006	01048V	PARTICIPANT	\N	PRESENT	0
167838	167006	14061L	PARTICIPANT	\N	PRESENT	0
167841	167006	14197C	PARTICIPANT	\N	PRESENT	0
167842	167006	14257W	PARTICIPANT	\N	PRESENT	0
167843	167006	14331P	PARTICIPANT	\N	PRESENT	0
167844	167006	08048B	PARTICIPANT	\N	PRESENT	0
167845	167006	11071M	PARTICIPANT	\N	PRESENT	0
167846	167006	11048N	PARTICIPANT	\N	PRESENT	0
167847	167006	98050T	PARTICIPANT	\N	PRESENT	0
167848	167006	86044G	PARTICIPANT	\N	PRESENT	0
167849	167006	14028W	PARTICIPANT	\N	PRESENT	0
167850	167006	97011G	PARTICIPANT	\N	PRESENT	0
167851	167006	14173T	PARTICIPANT	\N	PRESENT	0
167852	167006	89029V	PARTICIPANT	\N	PRESENT	0
167853	167006	95030B	PARTICIPANT	\N	PRESENT	0
167872	167006	14121F	PARTICIPANT	\N	PRESENT	0
167876	167006	14221J	PARTICIPANT	\N	PRESENT	0
168305	167007	14085U	PARTICIPANT	\N	PRESENT	0
168306	167007	14053L	PARTICIPANT	\N	PRESENT	0
168307	167007	11106F	PARTICIPANT	\N	PRESENT	0
168308	167007	98021N	PARTICIPANT	\N	PRESENT	0
168309	167007	11085T	PARTICIPANT	\N	PRESENT	0
168310	167007	14081Q	PARTICIPANT	\N	PRESENT	0
168311	167007	14039A	PARTICIPANT	\N	PRESENT	0
168312	167007	14273W	PARTICIPANT	\N	PRESENT	0
168313	167007	04057K	PARTICIPANT	\N	PRESENT	0
168314	167007	11083R	PARTICIPANT	\N	PRESENT	0
168315	167007	11093T	PARTICIPANT	\N	PRESENT	0
168316	167007	11042G	PARTICIPANT	\N	PRESENT	0
168317	167007	01014K	PARTICIPANT	\N	PRESENT	0
183059	183058	14089Y	PARTICIPANT	\N	PRESENT	0
183060	183058	14207L	PARTICIPANT	\N	PRESENT	0
183061	183058	11029K	PARTICIPANT	\N	PRESENT	0
189553	189552	08043V	PARTICIPANT	\N	PRESENT	0
189554	189552	92020L	PARTICIPANT	\N	PRESENT	0
189592	188952	96004D	PARTICIPANT	\N	EXCUSE	0
189593	188952	05001W	PARTICIPANT	\N	EXCUSE	0
204131	190806	08042U	PARTICIPANT	\N	PRESENT	0
204132	190806	08043V	PARTICIPANT	\N	PRESENT	0
204133	190806	04043D	PARTICIPANT	\N	PRESENT	0
204134	190806	14107H	PARTICIPANT	\N	PRESENT	0
204135	190806	08047A	PARTICIPANT	\N	PRESENT	0
204136	190806	08017T	PARTICIPANT	\N	PRESENT	0
204137	190806	14225N	PARTICIPANT	\N	PRESENT	0
204138	190806	14331P	PARTICIPANT	\N	PRESENT	0
204139	190806	11066Q	PARTICIPANT	\N	PRESENT	0
204140	190806	05012A	PARTICIPANT	\N	PRESENT	0
204141	190806	14217N	PARTICIPANT	\N	PRESENT	0
204142	190806	04086Q	PARTICIPANT	\N	PRESENT	0
204143	190806	11091R	PARTICIPANT	\N	PRESENT	0
204144	190806	14363X	PARTICIPANT	\N	PRESENT	0
204145	190806	11037K	PARTICIPANT	\N	PRESENT	0
204146	190806	95030B	PARTICIPANT	\N	PRESENT	0
204147	190806	01014K	PARTICIPANT	\N	PRESENT	0
204148	190806	14187A	PARTICIPANT	\N	PRESENT	0
204149	190806	19285X	PARTICIPANT	\N	PRESENT	0
204150	190806	14135M	PARTICIPANT	\N	PRESENT	0
204129	190806	11097X	PARTICIPANT	\N	PRESENT	0
204130	190806	13002U	PARTICIPANT	\N	PRESENT	0
204151	190806	14063N	PARTICIPANT	\N	PRESENT	0
204152	190806	08024S	PARTICIPANT	\N	PRESENT	0
204153	190806	14033T	PARTICIPANT	\N	PRESENT	0
204154	190806	07029T	PARTICIPANT	\N	PRESENT	0
204155	190806	11083R	PARTICIPANT	\N	PRESENT	0
204156	190806	11036J	PARTICIPANT	\N	PRESENT	0
204157	190806	11048N	PARTICIPANT	\N	PRESENT	0
204158	190806	19269X	PARTICIPANT	\N	PRESENT	0
204159	190806	14167V	PARTICIPANT	\N	PRESENT	0
204160	190806	04053F	PARTICIPANT	\N	PRESENT	0
204161	190806	08061X	PARTICIPANT	\N	PRESENT	0
204162	190806	14041T	PARTICIPANT	\N	PRESENT	0
204163	190806	95063L	PARTICIPANT	\N	PRESENT	0
204164	190806	04034C	PARTICIPANT	\N	PRESENT	0
204165	190806	95067Q	PARTICIPANT	\N	PRESENT	0
204166	190806	11042G	PARTICIPANT	\N	PRESENT	0
204167	190806	11014C	PARTICIPANT	\N	PRESENT	0
204168	190806	97011G	PARTICIPANT	\N	PRESENT	0
204169	190806	14271U	PARTICIPANT	\N	PRESENT	0
204170	190806	04059M	PARTICIPANT	\N	PRESENT	0
204171	190806	14209N	PARTICIPANT	\N	PRESENT	0
204172	190806	11107G	PARTICIPANT	\N	PRESENT	0
204173	190806	08073C	PARTICIPANT	\N	PRESENT	0
204174	190806	14061L	PARTICIPANT	\N	PRESENT	0
204175	190806	14059S	PARTICIPANT	\N	PRESENT	0
204176	190806	01046T	PARTICIPANT	\N	PRESENT	0
204177	190806	11103C	PARTICIPANT	\N	PRESENT	0
204178	190806	08031R	PARTICIPANT	\N	PRESENT	0
204179	190806	08065C	PARTICIPANT	\N	PRESENT	0
204180	190806	14201E	PARTICIPANT	\N	PRESENT	0
204181	190806	19253P	PARTICIPANT	\N	PRESENT	0
204182	190806	04033B	PARTICIPANT	\N	PRESENT	0
204183	190806	14227Q	PARTICIPANT	\N	PRESENT	0
204184	190806	00003C	PARTICIPANT	\N	PRESENT	0
204185	190806	14207L	PARTICIPANT	\N	PRESENT	0
204186	190806	14105F	PARTICIPANT	\N	PRESENT	0
204187	190806	14357A	PARTICIPANT	\N	PRESENT	0
204188	190806	01011G	PARTICIPANT	\N	PRESENT	0
204189	190806	04074L	PARTICIPANT	\N	PRESENT	0
204190	190806	14042U	PARTICIPANT	\N	PRESENT	0
204191	190806	09001P	PARTICIPANT	\N	PRESENT	0
204192	190806	04080J	PARTICIPANT	\N	PRESENT	0
204193	190806	08015R	PARTICIPANT	\N	PRESENT	0
204194	190806	14205J	PARTICIPANT	\N	PRESENT	0
204195	190806	14034U	PARTICIPANT	\N	PRESENT	0
204196	190806	11053K	PARTICIPANT	\N	PRESENT	0
204197	190806	04088S	PARTICIPANT	\N	PRESENT	0
204198	190806	08019V	PARTICIPANT	\N	PRESENT	0
204199	190806	14249W	PARTICIPANT	\N	PRESENT	0
204200	190806	01025N	PARTICIPANT	\N	PRESENT	0
204201	190806	14231L	PARTICIPANT	\N	PRESENT	0
204202	190806	14133K	PARTICIPANT	\N	PRESENT	0
204203	190806	11077T	PARTICIPANT	\N	PRESENT	0
204204	190806	04040A	PARTICIPANT	\N	PRESENT	0
204205	190806	14083S	PARTICIPANT	\N	PRESENT	0
204206	190806	01047U	PARTICIPANT	\N	PRESENT	0
204207	190806	14038Y	PARTICIPANT	\N	PRESENT	0
204208	190806	95049N	PARTICIPANT	\N	PRESENT	0
204209	190806	01034P	PARTICIPANT	\N	PRESENT	0
204210	190806	14157T	PARTICIPANT	\N	PRESENT	0
204211	190806	14219Q	PARTICIPANT	\N	PRESENT	0
204212	190806	14103D	PARTICIPANT	\N	PRESENT	0
204213	190806	14030Q	PARTICIPANT	\N	PRESENT	0
204214	190806	01024M	PARTICIPANT	\N	PRESENT	0
204215	190806	04070G	PARTICIPANT	\N	PRESENT	0
204216	190806	14255U	PARTICIPANT	\N	PRESENT	0
204217	190806	14089Y	PARTICIPANT	\N	PRESENT	0
204218	190806	98021N	PARTICIPANT	\N	PRESENT	0
204219	190806	14073Q	PARTICIPANT	\N	PRESENT	0
204220	190806	11064N	PARTICIPANT	\N	PRESENT	0
204221	190806	98042T	PARTICIPANT	\N	PRESENT	0
204222	190806	14179A	PARTICIPANT	\N	PRESENT	0
204223	190806	14069U	PARTICIPANT	\N	PRESENT	0
204224	190806	11033F	PARTICIPANT	\N	PRESENT	0
204225	190806	11065P	PARTICIPANT	\N	PRESENT	0
204226	190806	89017R	PARTICIPANT	\N	PRESENT	0
204227	190806	14119M	PARTICIPANT	\N	PRESENT	0
204228	190806	04067M	PARTICIPANT	\N	PRESENT	0
204229	190806	14253S	PARTICIPANT	\N	PRESENT	0
204230	190806	11068S	PARTICIPANT	\N	PRESENT	0
204231	190806	14265W	PARTICIPANT	\N	PRESENT	0
204232	190806	14241N	PARTICIPANT	\N	PRESENT	0
204233	190806	98022P	PARTICIPANT	\N	PRESENT	0
204234	190806	14085U	PARTICIPANT	\N	PRESENT	0
204235	190806	83047W	PARTICIPANT	\N	PRESENT	0
204236	190806	18127E	PARTICIPANT	\N	PRESENT	0
204237	190806	11090Q	PARTICIPANT	\N	PRESENT	0
204254	190806	14026U	PARTICIPANT	\N	PRESENT	0
204252	190806	16813M	PARTICIPANT	\N	PRESENT	0
204253	190806	14123H	PARTICIPANT	\N	PRESENT	0
204255	190806	14018U	PARTICIPANT	\N	PRESENT	0
204256	190806	11111C	PARTICIPANT	\N	PRESENT	0
204272	190806	14329V	PARTICIPANT	\N	PRESENT	0
204273	190806	01041N	PARTICIPANT	\N	PRESENT	0
204274	190806	04038G	PARTICIPANT	\N	PRESENT	0
204275	190806	86034E	PARTICIPANT	\N	PRESENT	0
204292	190806	04049K	PARTICIPANT	\N	PRESENT	0
204293	190806	11026G	PARTICIPANT	\N	PRESENT	0
204312	190806	14071N	PARTICIPANT	\N	PRESENT	0
204519	190807	11089X	PARTICIPANT	\N	PRESENT	0
204520	190807	11107G	PARTICIPANT	\N	PRESENT	0
204521	190807	04056J	PARTICIPANT	\N	PRESENT	0
204522	190807	19251M	PARTICIPANT	\N	PRESENT	0
204523	190807	14227Q	PARTICIPANT	\N	PRESENT	0
204524	190807	14207L	PARTICIPANT	\N	PRESENT	0
204525	190807	08016S	PARTICIPANT	\N	PRESENT	0
204526	190807	14197C	PARTICIPANT	\N	PRESENT	0
204527	190807	04034C	PARTICIPANT	\N	PRESENT	0
204528	190807	00003C	PARTICIPANT	\N	PRESENT	0
204529	190807	11077T	PARTICIPANT	\N	PRESENT	0
204530	190807	08017T	PARTICIPANT	\N	PRESENT	0
204531	190807	98046X	PARTICIPANT	\N	PRESENT	0
204532	190807	01028R	PARTICIPANT	\N	PRESENT	0
204533	190807	11034G	PARTICIPANT	\N	PRESENT	0
204534	190807	11026G	PARTICIPANT	\N	PRESENT	0
204535	190807	01047U	PARTICIPANT	\N	PRESENT	0
204536	190807	14073Q	PARTICIPANT	\N	PRESENT	0
204537	190807	14259Y	PARTICIPANT	\N	PRESENT	0
204538	190807	98018T	PARTICIPANT	\N	PRESENT	0
204539	190807	04033B	PARTICIPANT	\N	PRESENT	0
204540	190807	14069U	PARTICIPANT	\N	PRESENT	0
204541	190807	14053L	PARTICIPANT	\N	PRESENT	0
204542	190807	14363X	PARTICIPANT	\N	PRESENT	0
204543	190807	01008M	PARTICIPANT	\N	PRESENT	0
204544	190807	14209N	PARTICIPANT	\N	PRESENT	0
204545	190807	14249W	PARTICIPANT	\N	PRESENT	0
204546	190807	14265W	PARTICIPANT	\N	PRESENT	0
204547	190807	11097X	PARTICIPANT	\N	PRESENT	0
204548	190807	08034U	PARTICIPANT	\N	PRESENT	0
204549	190807	07029T	PARTICIPANT	\N	PRESENT	0
204550	190807	14251Q	PARTICIPANT	\N	PRESENT	0
204551	190807	14135M	PARTICIPANT	\N	PRESENT	0
204552	190807	14329V	PARTICIPANT	\N	PRESENT	0
204553	190807	14038Y	PARTICIPANT	\N	PRESENT	0
204554	190807	14133K	PARTICIPANT	\N	PRESENT	0
204555	190807	04081K	PARTICIPANT	\N	PRESENT	0
204556	190807	95015C	PARTICIPANT	\N	PRESENT	0
204557	190807	08010L	PARTICIPANT	\N	PRESENT	0
204558	190807	11036J	PARTICIPANT	\N	PRESENT	0
174899	167279	14197C	PARTICIPANT	\N	PRESENT	0
174900	167279	11043H	PARTICIPANT	\N	PRESENT	0
174901	167279	01022K	PARTICIPANT	\N	PRESENT	0
174902	167279	11097X	PARTICIPANT	\N	PRESENT	0
174903	167279	14363X	PARTICIPANT	\N	PRESENT	0
174904	167279	80027E	PARTICIPANT	\N	PRESENT	0
174905	167279	95062K	PARTICIPANT	\N	PRESENT	0
174907	167279	08012N	PARTICIPANT	\N	PRESENT	0
174908	167279	14331P	PARTICIPANT	\N	PRESENT	0
174909	167279	86044G	PARTICIPANT	\N	PRESENT	0
174910	167279	11036J	PARTICIPANT	\N	PRESENT	0
174911	167279	04043D	PARTICIPANT	\N	PRESENT	0
174912	167279	11105E	PARTICIPANT	\N	PRESENT	0
174913	167279	98050T	PARTICIPANT	\N	PRESENT	0
174914	167279	08053X	PARTICIPANT	\N	PRESENT	0
174915	167279	05012A	PARTICIPANT	\N	PRESENT	0
174916	167279	04079R	PARTICIPANT	\N	PRESENT	0
174917	167279	04088S	PARTICIPANT	\N	PRESENT	0
174918	167279	08047A	PARTICIPANT	\N	PRESENT	0
174919	167279	08043V	PARTICIPANT	\N	PRESENT	0
174921	167279	11015D	PARTICIPANT	\N	PRESENT	0
174923	167279	83047W	PARTICIPANT	\N	PRESENT	0
174924	167279	98029W	PARTICIPANT	\N	PRESENT	0
174926	167279	04041B	PARTICIPANT	\N	PRESENT	0
174927	167279	14018U	PARTICIPANT	\N	PRESENT	0
174928	167279	01058X	PARTICIPANT	\N	PRESENT	0
174929	167279	11046L	PARTICIPANT	\N	PRESENT	0
174930	167279	04036E	PARTICIPANT	\N	PRESENT	0
174931	167279	01027Q	PARTICIPANT	\N	PRESENT	0
174932	167279	83042R	PARTICIPANT	\N	PRESENT	0
174933	167279	11059R	PARTICIPANT	\N	PRESENT	0
174934	167279	08017T	PARTICIPANT	\N	PRESENT	0
174935	167279	99004R	PARTICIPANT	\N	PRESENT	0
174936	167279	14241N	PARTICIPANT	\N	PRESENT	0
174937	167279	01019Q	PARTICIPANT	\N	PRESENT	0
174938	167279	08058D	PARTICIPANT	\N	PRESENT	0
174939	167279	02002K	PARTICIPANT	\N	PRESENT	0
174940	167279	95037J	PARTICIPANT	\N	PRESENT	0
174941	167279	04034C	PARTICIPANT	\N	PRESENT	0
174942	167279	14026U	PARTICIPANT	\N	PRESENT	0
174943	167279	14271U	PARTICIPANT	\N	PRESENT	0
174944	167279	11098Y	PARTICIPANT	\N	PRESENT	0
174945	167279	95041E	PARTICIPANT	\N	PRESENT	0
174946	167279	11054L	PARTICIPANT	\N	PRESENT	0
174947	167279	14071N	PARTICIPANT	\N	PRESENT	0
174948	167279	14167V	PARTICIPANT	\N	PRESENT	0
174949	167279	14227Q	PARTICIPANT	\N	PRESENT	0
174950	167279	14001X	PARTICIPANT	\N	PRESENT	0
174951	167279	08014Q	PARTICIPANT	\N	PRESENT	0
174952	167279	04033B	PARTICIPANT	\N	PRESENT	0
174953	167279	14109K	PARTICIPANT	\N	PRESENT	0
174954	167279	14014Q	PARTICIPANT	\N	PRESENT	0
174955	167279	14257W	PARTICIPANT	\N	PRESENT	0
174956	167279	05008E	PARTICIPANT	\N	PRESENT	0
174957	167279	14097Y	PARTICIPANT	\N	PRESENT	0
174958	167279	95063L	PARTICIPANT	\N	PRESENT	0
174959	167279	11112D	PARTICIPANT	\N	PRESENT	0
174961	167279	90003B	PARTICIPANT	\N	PRESENT	0
174962	167279	11074Q	PARTICIPANT	\N	PRESENT	0
174963	167279	14063N	PARTICIPANT	\N	PRESENT	0
174966	167279	14121F	PARTICIPANT	\N	PRESENT	0
174967	167279	11080N	PARTICIPANT	\N	PRESENT	0
174970	167279	14191V	PARTICIPANT	\N	PRESENT	0
174972	167279	14253S	PARTICIPANT	\N	PRESENT	0
175492	167288	01046T	PARTICIPANT	\N	PRESENT	0
175493	167288	04092N	PARTICIPANT	\N	PRESENT	0
175494	167288	11031D	PARTICIPANT	\N	PRESENT	0
175495	167288	14223L	PARTICIPANT	\N	PRESENT	0
175496	167288	14119M	PARTICIPANT	\N	PRESENT	0
175497	167288	14105F	PARTICIPANT	\N	PRESENT	0
175498	167288	08019V	PARTICIPANT	\N	PRESENT	0
175499	167288	14217N	PARTICIPANT	\N	PRESENT	0
175500	167288	14147R	PARTICIPANT	\N	PRESENT	0
175501	167288	14363X	PARTICIPANT	\N	PRESENT	0
175502	167288	14042U	PARTICIPANT	\N	PRESENT	0
175503	167288	07029T	PARTICIPANT	\N	PRESENT	0
175504	167288	11042G	PARTICIPANT	\N	PRESENT	0
175505	167288	14121F	PARTICIPANT	\N	PRESENT	0
175506	167288	11072N	PARTICIPANT	\N	PRESENT	0
175507	167288	14081Q	PARTICIPANT	\N	PRESENT	0
175508	167288	14159V	PARTICIPANT	\N	PRESENT	0
175509	167288	08024S	PARTICIPANT	\N	PRESENT	0
175510	167288	11066Q	PARTICIPANT	\N	PRESENT	0
175511	167288	13002U	PARTICIPANT	\N	PRESENT	0
175512	167288	11056N	PARTICIPANT	\N	PRESENT	0
175513	167288	11061K	PARTICIPANT	\N	PRESENT	0
175514	167288	14219Q	PARTICIPANT	\N	PRESENT	0
175515	167288	01025N	PARTICIPANT	\N	PRESENT	0
175516	167288	14241N	PARTICIPANT	\N	PRESENT	0
175517	167288	14261S	PARTICIPANT	\N	PRESENT	0
175518	167288	08049C	PARTICIPANT	\N	PRESENT	0
175519	167288	08031R	PARTICIPANT	\N	PRESENT	0
175520	167288	11012A	PARTICIPANT	\N	PRESENT	0
175521	167288	14109K	PARTICIPANT	\N	PRESENT	0
175522	167288	14014Q	PARTICIPANT	\N	PRESENT	0
175523	167288	14213J	PARTICIPANT	\N	PRESENT	0
175524	167288	14209N	PARTICIPANT	\N	PRESENT	0
175525	167288	14263U	PARTICIPANT	\N	PRESENT	0
175536	167288	11089X	PARTICIPANT	\N	PRESENT	0
175537	167288	14275Y	PARTICIPANT	\N	PRESENT	0
175538	167288	14191V	PARTICIPANT	\N	PRESENT	0
175539	167288	14123H	PARTICIPANT	\N	PRESENT	0
175540	167288	14357A	PARTICIPANT	\N	PRESENT	0
175541	167288	90003B	PARTICIPANT	\N	PRESENT	0
175542	167288	11036J	PARTICIPANT	\N	PRESENT	0
175582	167288	11082Q	PARTICIPANT	\N	PRESENT	0
175583	167288	08052W	PARTICIPANT	\N	PRESENT	0
175592	167288	14038Y	PARTICIPANT	\N	PRESENT	0
175593	167288	14215L	PARTICIPANT	\N	PRESENT	0
175594	167288	14026U	PARTICIPANT	\N	PRESENT	0
175595	167288	04088S	PARTICIPANT	\N	PRESENT	0
175596	167288	08056B	PARTICIPANT	\N	PRESENT	0
175597	167288	14157T	PARTICIPANT	\N	PRESENT	0
175598	167288	14259Y	PARTICIPANT	\N	PRESENT	0
175599	167288	04095R	PARTICIPANT	\N	PRESENT	0
175600	167288	11067R	PARTICIPANT	\N	PRESENT	0
175601	167288	97011G	PARTICIPANT	\N	PRESENT	0
175673	167291	05008E	PARTICIPANT	\N	PRESENT	0
175674	167291	80013X	PARTICIPANT	\N	PRESENT	0
175675	167291	05001W	PARTICIPANT	\N	PRESENT	0
175677	167291	11061K	PARTICIPANT	\N	PRESENT	0
175678	167291	04085P	PARTICIPANT	\N	PRESENT	0
175679	167291	11067R	PARTICIPANT	\N	PRESENT	0
175683	167291	13002U	PARTICIPANT	\N	PRESENT	0
175687	167291	04095R	PARTICIPANT	\N	PRESENT	0
175690	167291	11072N	PARTICIPANT	\N	PRESENT	0
175693	167291	14039A	PARTICIPANT	\N	PRESENT	0
175695	167291	04067M	PARTICIPANT	\N	PRESENT	0
175696	167291	14073Q	PARTICIPANT	\N	PRESENT	0
175697	167291	14042U	PARTICIPANT	\N	PRESENT	0
175698	167291	11082Q	PARTICIPANT	\N	PRESENT	0
175699	167291	14219Q	PARTICIPANT	\N	PRESENT	0
175700	167291	14275Y	PARTICIPANT	\N	PRESENT	0
175701	167291	01024M	PARTICIPANT	\N	PRESENT	0
175702	167291	14191V	PARTICIPANT	\N	PRESENT	0
175703	167291	08019V	PARTICIPANT	\N	PRESENT	0
175704	167291	14357A	PARTICIPANT	\N	PRESENT	0
175706	167291	04088S	PARTICIPANT	\N	PRESENT	0
175709	167291	14157T	PARTICIPANT	\N	PRESENT	0
175712	167291	14119M	PARTICIPANT	\N	PRESENT	0
175715	167291	08073C	PARTICIPANT	\N	PRESENT	0
175716	167291	11056N	PARTICIPANT	\N	PRESENT	0
175717	167291	01043Q	PARTICIPANT	\N	PRESENT	0
175718	167291	01046T	PARTICIPANT	\N	PRESENT	0
175719	167291	14261S	PARTICIPANT	\N	PRESENT	0
175720	167291	14217N	PARTICIPANT	\N	PRESENT	0
175721	167291	97011G	PARTICIPANT	\N	PRESENT	0
175722	167291	14223L	PARTICIPANT	\N	PRESENT	0
175723	167291	14147R	PARTICIPANT	\N	PRESENT	0
175724	167291	14265W	PARTICIPANT	\N	PRESENT	0
175652	167291	04081K	PARTICIPANT	\N	PRESENT	0
175672	167291	14259Y	PARTICIPANT	\N	PRESENT	0
175725	167291	14213J	PARTICIPANT	\N	PRESENT	0
175726	167291	01008M	PARTICIPANT	\N	PRESENT	0
175727	167291	14038Y	PARTICIPANT	\N	PRESENT	0
175728	167291	14361V	PARTICIPANT	\N	PRESENT	0
175729	167291	14237S	PARTICIPANT	\N	PRESENT	0
175730	167291	11109J	PARTICIPANT	\N	PRESENT	0
175731	167291	11097X	PARTICIPANT	\N	PRESENT	0
175732	167291	14249W	PARTICIPANT	\N	PRESENT	0
175733	167291	14205J	PARTICIPANT	\N	PRESENT	0
175734	167291	11114F	PARTICIPANT	\N	PRESENT	0
175772	167291	14199E	PARTICIPANT	\N	PRESENT	0
175773	167291	04049K	PARTICIPANT	\N	PRESENT	0
175774	167291	14026U	PARTICIPANT	\N	PRESENT	0
175775	167291	01025N	PARTICIPANT	\N	PRESENT	0
175792	167291	07029T	PARTICIPANT	\N	PRESENT	0
175793	167291	92018S	PARTICIPANT	\N	PRESENT	0
175794	167291	11103C	PARTICIPANT	\N	PRESENT	0
182515	182514	11039M	PARTICIPANT	\N	PRESENT	0
182516	182514	98042T	PARTICIPANT	\N	PRESENT	0
182517	182514	01019Q	PARTICIPANT	\N	PRESENT	0
182553	182552	14207L	PARTICIPANT	\N	PRESENT	0
182554	182552	14089Y	PARTICIPANT	\N	PRESENT	0
182593	182592	95067Q	PARTICIPANT	\N	PRESENT	0
182594	182592	97011G	PARTICIPANT	\N	PRESENT	0
182595	182592	04074L	PARTICIPANT	\N	PRESENT	0
182596	182592	04036E	PARTICIPANT	\N	PRESENT	0
182601	182592	04086Q	PARTICIPANT	\N	PRESENT	0
182613	182612	14209N	PARTICIPANT	\N	PRESENT	0
182614	182612	98035U	PARTICIPANT	\N	PRESENT	0
182639	182638	11048N	PARTICIPANT	\N	PRESENT	0
182640	182638	14063N	PARTICIPANT	\N	PRESENT	0
182641	182638	07034Q	PARTICIPANT	\N	PRESENT	0
210383	207684	14107H	PARTICIPANT	\N	PRESENT	0
210384	207684	19319Q	PARTICIPANT	\N	PRESENT	0
210385	207684	14327T	PARTICIPANT	\N	PRESENT	0
210386	207684	19533U	PARTICIPANT	\N	PRESENT	0
210387	207684	19707Y	PARTICIPANT	\N	PRESENT	0
210388	207684	19705W	PARTICIPANT	\N	PRESENT	0
210389	207684	14265W	PARTICIPANT	\N	PRESENT	0
210390	207684	19685L	PARTICIPANT	\N	PRESENT	0
210391	207684	19679N	PARTICIPANT	\N	PRESENT	0
210392	207684	19691J	PARTICIPANT	\N	PRESENT	0
210393	207684	19443T	PARTICIPANT	\N	PRESENT	0
210394	207684	14217N	PARTICIPANT	\N	PRESENT	0
210395	207684	14069U	PARTICIPANT	\N	PRESENT	0
210396	207684	19713W	PARTICIPANT	\N	PRESENT	0
210397	207684	19737F	PARTICIPANT	\N	PRESENT	0
210398	207684	19335Q	PARTICIPANT	\N	PRESENT	0
210399	210115	14111D	PARTICIPANT	\N	PRESENT	0
210400	210115	14065Q	PARTICIPANT	\N	PRESENT	0
210401	210115	11010L	PARTICIPANT	\N	PRESENT	0
210402	210115	07034Q	PARTICIPANT	\N	PRESENT	0
210403	210115	19543W	PARTICIPANT	\N	PRESENT	0
210404	210115	01024M	PARTICIPANT	\N	PRESENT	0
210405	210115	04044E	PARTICIPANT	\N	PRESENT	0
210406	210115	19585H	PARTICIPANT	\N	PRESENT	0
210407	210115	04047H	PARTICIPANT	\N	PRESENT	0
210408	210115	19673G	PARTICIPANT	\N	PRESENT	0
210409	210115	11033F	PARTICIPANT	\N	PRESENT	0
210410	210115	19447X	PARTICIPANT	\N	PRESENT	0
210411	210115	05008E	PARTICIPANT	\N	PRESENT	0
210412	210115	14231L	PARTICIPANT	\N	PRESENT	0
210413	210115	14089Y	PARTICIPANT	\N	PRESENT	0
210414	210115	19489J	PARTICIPANT	\N	PRESENT	0
210415	210115	19729F	PARTICIPANT	\N	PRESENT	0
210416	210115	19629C	PARTICIPANT	\N	PRESENT	0
210417	210115	14041T	PARTICIPANT	\N	PRESENT	0
210418	210115	08044W	PARTICIPANT	\N	PRESENT	0
210419	210115	14179A	PARTICIPANT	\N	PRESENT	0
210420	210115	19483C	PARTICIPANT	\N	PRESENT	0
210421	210115	11072N	PARTICIPANT	\N	PRESENT	0
210422	210115	19725B	PARTICIPANT	\N	PRESENT	0
210423	210115	98035U	PARTICIPANT	\N	PRESENT	0
210424	210115	08045X	PARTICIPANT	\N	PRESENT	0
210425	210115	11026G	PARTICIPANT	\N	PRESENT	0
210426	210115	19253P	PARTICIPANT	\N	PRESENT	0
210427	210115	14069U	PARTICIPANT	\N	PRESENT	0
210428	210115	14151M	PARTICIPANT	\N	PRESENT	0
210429	210115	14021P	PARTICIPANT	\N	PRESENT	0
210430	210115	14053L	PARTICIPANT	\N	EXCUSE	0
210431	210115	14275Y	PARTICIPANT	\N	EXCUSE	0
210432	207684	14028W	PARTICIPANT	\N	PRESENT	0
210433	207684	19727D	PARTICIPANT	\N	PRESENT	0
210434	207684	19441R	PARTICIPANT	\N	PRESENT	0
210435	207684	14205J	PARTICIPANT	\N	PRESENT	0
210436	207684	19253P	PARTICIPANT	\N	PRESENT	0
210437	207684	19733B	PARTICIPANT	\N	PRESENT	0
210438	207684	19573D	PARTICIPANT	\N	PRESENT	0
210439	207684	14169X	PARTICIPANT	\N	PRESENT	0
210440	207684	08010L	PARTICIPANT	\N	PRESENT	0
210441	207684	14223L	PARTICIPANT	\N	PRESENT	0
210442	207684	14193X	PARTICIPANT	\N	PRESENT	0
210443	207684	19671E	PARTICIPANT	\N	PRESENT	0
210444	207684	14097Y	PARTICIPANT	\N	PRESENT	0
210445	207684	14071N	PARTICIPANT	\N	PRESENT	0
210446	207684	19647E	PARTICIPANT	\N	PRESENT	0
210447	207684	19663E	PARTICIPANT	\N	PRESENT	0
210448	207684	19629C	PARTICIPANT	\N	PRESENT	0
210449	207684	08043V	PARTICIPANT	\N	PRESENT	0
210450	207684	14231L	PARTICIPANT	\N	PRESENT	0
210451	207684	14105F	PARTICIPANT	\N	PRESENT	0
210452	207684	19575F	PARTICIPANT	\N	PRESENT	0
210453	207684	04044E	PARTICIPANT	\N	PRESENT	0
210454	207684	14195A	PARTICIPANT	\N	PRESENT	0
210460	207684	11012A	PARTICIPANT	\N	PRESENT	0
210464	207684	08068F	PARTICIPANT	\N	PRESENT	0
210465	207684	11027H	PARTICIPANT	\N	PRESENT	0
210466	207684	14053L	PARTICIPANT	\N	PRESENT	0
210467	207684	14187A	PARTICIPANT	\N	PRESENT	0
210468	207684	80013X	PARTICIPANT	\N	PRESENT	0
210469	207684	14089Y	PARTICIPANT	\N	PRESENT	0
210470	207684	12041X	PARTICIPANT	\N	PRESENT	0
210532	207685	08028W	PARTICIPANT	\N	PRESENT	0
210533	207685	14119M	PARTICIPANT	\N	PRESENT	0
210534	207685	19575F	PARTICIPANT	\N	PRESENT	0
210535	207685	14147R	PARTICIPANT	\N	PRESENT	0
210536	207685	14115H	PARTICIPANT	\N	PRESENT	0
210537	207685	18083K	PARTICIPANT	\N	PRESENT	0
210538	207685	19447X	PARTICIPANT	\N	PRESENT	0
210539	207685	19467C	PARTICIPANT	\N	PRESENT	0
210540	207685	19709B	PARTICIPANT	\N	PRESENT	0
210541	207685	19663E	PARTICIPANT	\N	PRESENT	0
210542	207685	04088S	PARTICIPANT	\N	PRESENT	0
210543	207685	14033T	PARTICIPANT	\N	PRESENT	0
210544	207685	14265W	PARTICIPANT	\N	PRESENT	0
210545	207685	19729F	PARTICIPANT	\N	PRESENT	0
210546	207685	19705W	PARTICIPANT	\N	PRESENT	0
210547	207685	19725B	PARTICIPANT	\N	PRESENT	0
210548	207685	14079W	PARTICIPANT	\N	PRESENT	0
210549	207685	08062Y	PARTICIPANT	\N	PRESENT	0
210550	207685	98050T	PARTICIPANT	\N	PRESENT	0
210551	207685	14257W	PARTICIPANT	\N	PRESENT	0
210552	207685	19673G	PARTICIPANT	\N	PRESENT	0
210553	207685	14103D	PARTICIPANT	\N	PRESENT	0
210554	207685	19703U	PARTICIPANT	\N	PRESENT	0
210555	207685	14026U	PARTICIPANT	\N	PRESENT	0
210556	207685	97011G	PARTICIPANT	\N	PRESENT	0
210557	207685	08034U	PARTICIPANT	\N	PRESENT	0
210558	207685	08009T	PARTICIPANT	\N	PRESENT	0
210559	207685	01024M	PARTICIPANT	\N	PRESENT	0
210560	207685	95067Q	PARTICIPANT	\N	PRESENT	0
210561	207685	19515S	PARTICIPANT	\N	PRESENT	0
210562	207685	19691J	PARTICIPANT	\N	PRESENT	0
210563	207685	14087W	PARTICIPANT	\N	PRESENT	0
210564	207685	14219Q	PARTICIPANT	\N	PRESENT	0
210565	207685	14041T	PARTICIPANT	\N	PRESENT	0
210566	207685	14038Y	PARTICIPANT	\N	PRESENT	0
210567	207685	19367Y	PARTICIPANT	\N	PRESENT	0
210569	210568	04086Q	PARTICIPANT	\N	PRESENT	0
210570	207685	17589D	PARTICIPANT	\N	PRESENT	0
210571	207685	19253P	PARTICIPANT	\N	PRESENT	0
210572	207685	19591F	PARTICIPANT	\N	PRESENT	0
210573	207685	19329S	PARTICIPANT	\N	PRESENT	0
210574	207685	19671E	PARTICIPANT	\N	PRESENT	0
210575	207685	14331P	PARTICIPANT	\N	PRESENT	0
210576	207685	19549D	PARTICIPANT	\N	PRESENT	0
210577	207685	04040A	PARTICIPANT	\N	PRESENT	0
210578	207685	14059S	PARTICIPANT	\N	PRESENT	0
210579	207685	04018C	PARTICIPANT	\N	PRESENT	0
210580	207685	14231L	PARTICIPANT	\N	PRESENT	0
210581	207685	14121F	PARTICIPANT	\N	PRESENT	0
210582	207685	08061X	PARTICIPANT	\N	PRESENT	0
210583	207685	19631V	PARTICIPANT	\N	PRESENT	0
210584	207685	19543W	PARTICIPANT	\N	PRESENT	0
210585	207685	19621T	PARTICIPANT	\N	PRESENT	0
210586	207685	19533U	PARTICIPANT	\N	PRESENT	0
210587	207685	95062K	PARTICIPANT	\N	PRESENT	0
210588	207685	11104D	PARTICIPANT	\N	PRESENT	0
210589	207685	08068F	PARTICIPANT	\N	PRESENT	0
210590	207685	14031R	PARTICIPANT	\N	PRESENT	0
210591	207685	19479G	PARTICIPANT	\N	PRESENT	0
210592	207685	14097Y	PARTICIPANT	\N	PRESENT	0
210593	207685	19335Q	PARTICIPANT	\N	PRESENT	0
210594	207685	14221J	PARTICIPANT	\N	PRESENT	0
210595	207685	14357A	PARTICIPANT	\N	PRESENT	0
210596	207685	08015R	PARTICIPANT	\N	PRESENT	0
210597	207685	14034U	PARTICIPANT	\N	PRESENT	0
210598	207685	14197C	PARTICIPANT	\N	PRESENT	0
210599	207685	08053X	PARTICIPANT	\N	PRESENT	0
210600	207685	14111D	PARTICIPANT	\N	PRESENT	0
210601	207685	14107H	PARTICIPANT	\N	PRESENT	0
210602	207685	14123H	PARTICIPANT	\N	PRESENT	0
210603	207685	14071N	PARTICIPANT	\N	PRESENT	0
210381	207684	14034U	PARTICIPANT	\N	PRESENT	0
210382	207684	19715Y	PARTICIPANT	\N	PRESENT	0
210604	207685	14173T	PARTICIPANT	\N	PRESENT	0
168320	167007	14269B	PARTICIPANT	\N	PRESENT	0
168321	167007	08062Y	PARTICIPANT	\N	PRESENT	0
168322	167007	04071H	PARTICIPANT	\N	PRESENT	0
168323	167007	14249W	PARTICIPANT	\N	PRESENT	0
168324	167007	08035V	PARTICIPANT	\N	PRESENT	0
168325	167007	11072N	PARTICIPANT	\N	PRESENT	0
168326	167007	04089T	PARTICIPANT	\N	PRESENT	0
168327	167007	14037X	PARTICIPANT	\N	PRESENT	0
168328	167007	01048V	PARTICIPANT	\N	PRESENT	0
168329	167007	12041X	PARTICIPANT	\N	PRESENT	0
168330	167007	14119M	PARTICIPANT	\N	PRESENT	0
168331	167007	11031D	PARTICIPANT	\N	PRESENT	0
168332	167007	11101A	PARTICIPANT	\N	PRESENT	0
168333	167007	97011G	PARTICIPANT	\N	PRESENT	0
168334	167007	14195A	PARTICIPANT	\N	PRESENT	0
168335	167007	14034U	PARTICIPANT	\N	PRESENT	0
168336	167007	01025N	PARTICIPANT	\N	PRESENT	0
168337	167007	08047A	PARTICIPANT	\N	PRESENT	0
168338	167007	11111C	PARTICIPANT	\N	PRESENT	0
168339	167007	14277B	PARTICIPANT	\N	PRESENT	0
168340	167007	01043Q	PARTICIPANT	\N	PRESENT	0
168341	167007	14219Q	PARTICIPANT	\N	PRESENT	0
168342	167007	14221J	PARTICIPANT	\N	PRESENT	0
168343	167007	95049N	PARTICIPANT	\N	PRESENT	0
168394	167007	14327T	PARTICIPANT	\N	PRESENT	0
168395	167007	11064N	PARTICIPANT	\N	PRESENT	0
168396	167007	04070G	PARTICIPANT	\N	PRESENT	0
168397	167007	14259Y	PARTICIPANT	\N	PRESENT	0
168398	167007	14179A	PARTICIPANT	\N	PRESENT	0
168399	167007	92031P	PARTICIPANT	\N	PRESENT	0
168400	167007	11071M	PARTICIPANT	\N	PRESENT	0
168401	167007	14197C	PARTICIPANT	\N	PRESENT	0
168402	167007	14193X	PARTICIPANT	\N	PRESENT	0
168403	167007	99004R	PARTICIPANT	\N	PRESENT	0
168404	167007	14211G	PARTICIPANT	\N	PRESENT	0
168405	167007	01058X	PARTICIPANT	\N	PRESENT	0
168406	167007	95035G	PARTICIPANT	\N	PRESENT	0
168407	167007	04041B	PARTICIPANT	\N	PRESENT	0
168408	167007	04035D	PARTICIPANT	\N	PRESENT	0
168433	167007	01007L	PARTICIPANT	\N	PRESENT	0
168410	167007	11048N	PARTICIPANT	\N	PRESENT	0
168434	167007	14157T	PARTICIPANT	\N	PRESENT	0
168412	167007	14089Y	PARTICIPANT	\N	PRESENT	0
168413	167007	14133K	PARTICIPANT	\N	PRESENT	0
168414	167007	14093U	PARTICIPANT	\N	PRESENT	0
168415	167007	96004D	PARTICIPANT	\N	PRESENT	0
168416	167007	11044J	PARTICIPANT	\N	PRESENT	0
168417	167007	98023Q	PARTICIPANT	\N	PRESENT	0
168418	167007	14079W	PARTICIPANT	\N	PRESENT	0
168420	167007	98018T	PARTICIPANT	\N	PRESENT	0
168421	167007	98024R	PARTICIPANT	\N	PRESENT	0
168423	167007	05004A	PARTICIPANT	\N	PRESENT	0
168424	167007	14199E	PARTICIPANT	\N	PRESENT	0
168425	167007	01057W	PARTICIPANT	\N	PRESENT	0
168426	167007	04036E	PARTICIPANT	\N	PRESENT	0
168427	167007	95041E	PARTICIPANT	\N	PRESENT	0
168428	167007	01061S	PARTICIPANT	\N	PRESENT	0
168429	167007	08019V	PARTICIPANT	\N	PRESENT	0
168430	167007	14251Q	PARTICIPANT	\N	PRESENT	0
168431	167007	14031R	PARTICIPANT	\N	PRESENT	0
168432	167007	04080J	PARTICIPANT	\N	PRESENT	0
168435	167007	92045V	PARTICIPANT	\N	PRESENT	0
168436	167007	95067Q	PARTICIPANT	\N	PRESENT	0
168437	167007	11043H	PARTICIPANT	\N	PRESENT	0
168438	167007	11090Q	PARTICIPANT	\N	PRESENT	0
168439	167007	11094U	PARTICIPANT	\N	PRESENT	0
168440	167007	09001P	PARTICIPANT	\N	PRESENT	0
170775	170772	04042C	PARTICIPANT	\N	PRESENT	0
168756	167008	08055A	PARTICIPANT	\N	PRESENT	0
168763	167008	95062K	PARTICIPANT	\N	PRESENT	0
168764	167008	07034Q	PARTICIPANT	\N	PRESENT	0
168765	167008	08025T	PARTICIPANT	\N	PRESENT	0
168766	167008	01028R	PARTICIPANT	\N	PRESENT	0
168767	167008	01008M	PARTICIPANT	\N	PRESENT	0
168768	167008	08019V	PARTICIPANT	\N	PRESENT	0
168769	167008	14041T	PARTICIPANT	\N	PRESENT	0
168770	167008	07029T	PARTICIPANT	\N	PRESENT	0
168771	167008	04043D	PARTICIPANT	\N	PRESENT	0
168772	167008	14223L	PARTICIPANT	\N	PRESENT	0
168773	167008	11056N	PARTICIPANT	\N	PRESENT	0
168774	167008	11067R	PARTICIPANT	\N	PRESENT	0
168775	167008	13002U	PARTICIPANT	\N	PRESENT	0
168776	167008	04067M	PARTICIPANT	\N	PRESENT	0
168777	167008	14121F	PARTICIPANT	\N	PRESENT	0
168778	167008	11084S	PARTICIPANT	\N	PRESENT	0
168779	167008	14159V	PARTICIPANT	\N	PRESENT	0
168318	167007	14103D	PARTICIPANT	\N	PRESENT	0
168319	167007	11107G	PARTICIPANT	\N	PRESENT	0
168780	167008	14269B	PARTICIPANT	\N	PRESENT	0
168781	167008	01024M	PARTICIPANT	\N	PRESENT	0
168782	167008	14219Q	PARTICIPANT	\N	PRESENT	0
168783	167008	09001P	PARTICIPANT	\N	PRESENT	0
168784	167008	11034G	PARTICIPANT	\N	PRESENT	0
168785	167008	11033F	PARTICIPANT	\N	PRESENT	0
168786	167008	14083S	PARTICIPANT	\N	PRESENT	0
168787	167008	01027Q	PARTICIPANT	\N	PRESENT	0
168788	167008	04036E	PARTICIPANT	\N	PRESENT	0
168789	167008	14119M	PARTICIPANT	\N	PRESENT	0
168790	167008	97011G	PARTICIPANT	\N	PRESENT	0
168791	167008	88008L	PARTICIPANT	\N	PRESENT	0
168792	167008	11012A	PARTICIPANT	\N	PRESENT	0
168793	167008	14271U	PARTICIPANT	\N	PRESENT	0
168794	167008	11104D	PARTICIPANT	\N	PRESENT	0
168795	167008	11061K	PARTICIPANT	\N	PRESENT	0
168796	167008	14195A	PARTICIPANT	\N	PRESENT	0
168800	167008	11071M	PARTICIPANT	\N	PRESENT	0
168801	167008	14241N	PARTICIPANT	\N	PRESENT	0
168802	167008	14069U	PARTICIPANT	\N	PRESENT	0
168803	167008	04047H	PARTICIPANT	\N	PRESENT	0
168805	167008	14211G	PARTICIPANT	\N	PRESENT	0
170773	170772	96004D	PARTICIPANT	\N	PRESENT	0
170774	170772	04040A	PARTICIPANT	\N	PRESENT	0
170776	170772	04035D	PARTICIPANT	\N	PRESENT	0
170777	170772	04061F	PARTICIPANT	\N	PRESENT	0
170778	170772	14001X	PARTICIPANT	\N	PRESENT	0
170779	170772	95059Q	PARTICIPANT	\N	PRESENT	0
170872	170812	14111D	PARTICIPANT	\N	EXCUSE	0
170873	170812	08044W	PARTICIPANT	\N	EXCUSE	0
170874	170812	04047H	PARTICIPANT	\N	PRESENT	0
170875	170812	14259Y	PARTICIPANT	\N	PRESENT	0
170876	170812	14041T	PARTICIPANT	\N	PRESENT	0
170877	170812	14215L	PARTICIPANT	\N	PRESENT	0
170878	170812	07034Q	PARTICIPANT	\N	PRESENT	0
170879	170812	11035H	PARTICIPANT	\N	PRESENT	0
170880	170812	11037K	PARTICIPANT	\N	PRESENT	0
170881	170812	04038G	PARTICIPANT	\N	PRESENT	0
170882	170812	01024M	PARTICIPANT	\N	PRESENT	0
170883	170812	01028R	PARTICIPANT	\N	PRESENT	0
170884	170812	11084S	PARTICIPANT	\N	PRESENT	0
170885	170812	95067Q	PARTICIPANT	\N	PRESENT	0
170886	170812	05008E	PRESIDENT	0	PRESENT	0
170888	170887	04044E	PARTICIPANT	\N	PRESENT	0
170889	170887	14259Y	PARTICIPANT	\N	PRESENT	0
170890	170887	08019V	PARTICIPANT	\N	PRESENT	0
170891	170887	14275Y	PARTICIPANT	\N	PRESENT	0
170892	170887	11072N	PARTICIPANT	\N	PRESENT	0
170893	170887	11023D	PARTICIPANT	\N	PRESENT	0
170894	170887	08073C	PARTICIPANT	\N	PRESENT	0
170895	170887	04094Q	PARTICIPANT	\N	PRESENT	0
172225	170598	04081K	PARTICIPANT	\N	PRESENT	0
172292	170598	07026Q	PARTICIPANT	\N	PRESENT	0
172372	170598	11040E	PARTICIPANT	\N	PRESENT	0
172373	170598	14361V	PARTICIPANT	\N	PRESENT	0
172374	170598	14257W	PARTICIPANT	\N	PRESENT	0
172375	170598	14107H	PARTICIPANT	\N	PRESENT	0
172376	170598	08055A	PARTICIPANT	\N	PRESENT	0
172377	170598	14261S	PARTICIPANT	\N	PRESENT	0
172378	170598	08051V	PARTICIPANT	\N	PRESENT	0
172379	170598	01025N	PARTICIPANT	\N	PRESENT	0
172380	170598	14191V	PARTICIPANT	\N	PRESENT	0
172381	170598	14247U	PARTICIPANT	\N	PRESENT	0
172382	170598	14179A	PARTICIPANT	\N	PRESENT	0
172384	170598	08016S	PARTICIPANT	\N	PRESENT	0
172386	170598	05008E	PARTICIPANT	\N	PRESENT	0
172401	170598	14327T	PARTICIPANT	\N	PRESENT	0
172399	170598	11083R	PARTICIPANT	\N	PRESENT	0
172400	170598	01022K	PARTICIPANT	\N	PRESENT	0
172402	170598	95063L	PARTICIPANT	\N	PRESENT	0
172403	170598	11070L	PARTICIPANT	\N	PRESENT	0
172404	170598	14201E	PARTICIPANT	\N	PRESENT	0
172405	170598	98053W	PARTICIPANT	\N	PRESENT	0
172406	170598	14073Q	PARTICIPANT	\N	PRESENT	0
172407	170598	14219Q	PARTICIPANT	\N	PRESENT	0
172408	170598	04056J	PARTICIPANT	\N	PRESENT	0
172409	170598	14223L	PARTICIPANT	\N	PRESENT	0
183693	183692	95059Q	PARTICIPANT	\N	PRESENT	0
183694	183692	01014K	PARTICIPANT	\N	PRESENT	0
183933	183932	11026G	PARTICIPANT	\N	PRESENT	0
183934	183932	10015M	PARTICIPANT	\N	PRESENT	0
183953	183952	05008E	PARTICIPANT	\N	PRESENT	0
183955	183954	05008E	PARTICIPANT	\N	PRESENT	0
185116	185115	14089Y	PARTICIPANT	\N	PRESENT	0
183974	183972	98035U	PARTICIPANT	\N	PRESENT	0
185113	185112	14207L	PARTICIPANT	\N	PRESENT	0
185114	185112	14089Y	PARTICIPANT	\N	PRESENT	0
187913	187912	89017R	PARTICIPANT	\N	PRESENT	0
187915	187914	11074Q	PARTICIPANT	\N	PRESENT	0
187916	187914	11083R	PARTICIPANT	\N	PRESENT	0
188973	188972	96004D	PARTICIPANT	\N	PRESENT	0
188975	188974	96004D	PARTICIPANT	\N	PRESENT	0
188993	188992	04080J	PARTICIPANT	\N	PRESENT	0
188994	188992	98035U	PARTICIPANT	\N	PRESENT	0
204559	190807	08061X	PARTICIPANT	\N	PRESENT	0
204560	190807	14089Y	PARTICIPANT	\N	PRESENT	0
204561	190807	01024M	PARTICIPANT	\N	PRESENT	0
204562	190807	04053F	PARTICIPANT	\N	PRESENT	0
204563	190807	11080N	PARTICIPANT	\N	PRESENT	0
204564	190807	08039A	PARTICIPANT	\N	PRESENT	0
204565	190807	04092N	PARTICIPANT	\N	PRESENT	0
204566	190807	14083S	PARTICIPANT	\N	PRESENT	0
204567	190807	08069G	PARTICIPANT	\N	PRESENT	0
204568	190807	04035D	PARTICIPANT	\N	PRESENT	0
204569	190807	04071H	PARTICIPANT	\N	PRESENT	0
204570	190807	04057K	PARTICIPANT	\N	PRESENT	0
204571	190807	14071N	PARTICIPANT	\N	PRESENT	0
204572	190807	14271U	PARTICIPANT	\N	PRESENT	0
204573	190807	11063M	PARTICIPANT	\N	PRESENT	0
204574	190807	11098Y	PARTICIPANT	\N	PRESENT	0
204575	190807	14255U	PARTICIPANT	\N	PRESENT	0
204576	190807	19285X	PARTICIPANT	\N	PRESENT	0
204592	190807	11083R	PARTICIPANT	\N	PRESENT	0
204953	204952	04034C	PARTICIPANT	\N	PRESENT	0
205013	205012	07034Q	PARTICIPANT	\N	PRESENT	0
205015	205014	07034Q	PARTICIPANT	\N	PRESENT	0
205053	205052	01031L	PARTICIPANT	\N	PRESENT	0
205092	204972	11037K	PARTICIPANT	\N	EXCUSE	0
205094	205093	07034Q	PARTICIPANT	\N	PRESENT	0
205096	205095	07034Q	PARTICIPANT	\N	PRESENT	0
205112	204972	95067Q	PARTICIPANT	\N	PRESENT	0
205113	204972	01057W	PARTICIPANT	\N	EXCUSE	0
205114	204972	19253P	PARTICIPANT	\N	EXCUSE	0
205353	205352	14065Q	PARTICIPANT	\N	PRESENT	0
205354	205352	04047H	PARTICIPANT	\N	PRESENT	0
205413	205412	11061K	PARTICIPANT	\N	PRESENT	0
205414	205412	08052W	PARTICIPANT	\N	PRESENT	0
205415	205412	14265W	PARTICIPANT	\N	PRESENT	0
205416	205412	14034U	PARTICIPANT	\N	PRESENT	0
205585	205584	14065Q	PARTICIPANT	\N	PRESENT	0
205522	205520	04047H	PARTICIPANT	\N	PRESENT	0
205588	205586	04047H	PARTICIPANT	\N	PRESENT	0
205525	205523	04047H	PARTICIPANT	\N	PRESENT	0
205587	205586	14065Q	PARTICIPANT	\N	PRESENT	0
205641	205640	04040A	PARTICIPANT	\N	PRESENT	0
205643	205642	04035D	PARTICIPANT	\N	PRESENT	0
205645	205644	01056V	PARTICIPANT	\N	PRESENT	0
205694	205622	14327T	PARTICIPANT	\N	PRESENT	0
205695	205622	04071H	PARTICIPANT	\N	PRESENT	0
205696	205622	95041E	PARTICIPANT	\N	PRESENT	0
205697	205622	01048V	PARTICIPANT	\N	PRESENT	0
205698	205622	19545Y	PARTICIPANT	\N	PRESENT	0
205699	205622	01057W	PARTICIPANT	\N	PRESENT	0
205700	205622	11053K	PARTICIPANT	\N	PRESENT	0
205701	205622	11074Q	PRESIDENT	1	PRESENT	0
205702	205622	19667J	PARTICIPANT	\N	PRESENT	0
205703	205622	89017R	PARTICIPANT	\N	PRESENT	0
205704	205622	19671E	PARTICIPANT	\N	PRESENT	0
205705	205622	11070L	PARTICIPANT	\N	PRESENT	0
205706	205622	88008L	PRESIDENT	0	PRESENT	0
205707	205622	14225N	PARTICIPANT	\N	PRESENT	0
205708	205622	11110B	PARTICIPANT	\N	PRESENT	0
205709	205622	07029T	PARTICIPANT	\N	PRESENT	0
205710	205622	14085U	PARTICIPANT	\N	PRESENT	0
205711	205622	07004J	PARTICIPANT	\N	PRESENT	0
205712	205622	19349W	PARTICIPANT	\N	PRESENT	0
205713	205622	08010L	PARTICIPANT	\N	PRESENT	0
205714	205622	19479G	PARTICIPANT	\N	PRESENT	0
205715	205622	19647E	PARTICIPANT	\N	PRESENT	0
205716	205622	11048N	PARTICIPANT	\N	PRESENT	0
205717	205622	19711U	PARTICIPANT	\N	PRESENT	0
205718	205622	08034U	PARTICIPANT	\N	PRESENT	0
205719	205622	19651A	PARTICIPANT	\N	PRESENT	0
205720	205622	19531S	PARTICIPANT	\N	PRESENT	0
205721	205622	19687N	PARTICIPANT	\N	PRESENT	0
205722	205622	19689Q	PARTICIPANT	\N	PRESENT	0
205723	205622	12016W	PARTICIPANT	\N	PRESENT	0
205724	205622	08011M	PARTICIPANT	\N	PRESENT	0
205725	205622	08014Q	PARTICIPANT	\N	PRESENT	0
205726	205622	14034U	PARTICIPANT	\N	PRESENT	0
205727	205622	14159V	PARTICIPANT	\N	PRESENT	0
205728	205622	14173T	PARTICIPANT	\N	PRESENT	0
205729	205622	11040E	PARTICIPANT	\N	PRESENT	0
205730	205622	04086Q	PARTICIPANT	\N	PRESENT	0
205731	205622	11012A	PARTICIPANT	\N	PRESENT	0
205732	205622	14199E	PARTICIPANT	\N	PRESENT	0
205733	205622	08073C	PARTICIPANT	\N	PRESENT	0
205734	205622	14121F	PARTICIPANT	\N	PRESENT	0
205735	205622	99004R	PARTICIPANT	\N	PRESENT	0
205736	205622	04061F	PARTICIPANT	\N	PRESENT	0
205805	205692	08028W	PARTICIPANT	\N	PRESENT	0
205740	205622	14331P	PARTICIPANT	\N	PRESENT	0
205787	205692	19515S	PARTICIPANT	\N	PRESENT	0
205742	205687	19543W	PARTICIPANT	\N	PRESENT	0
205743	205687	19581D	PARTICIPANT	\N	PRESENT	0
205744	205687	04044E	PARTICIPANT	\N	PRESENT	0
205745	205687	19585H	PARTICIPANT	\N	PRESENT	0
205746	205687	04047H	PARTICIPANT	\N	PRESENT	0
205747	205687	19673G	PARTICIPANT	\N	PRESENT	0
205748	205687	01028R	PARTICIPANT	\N	PRESENT	0
205749	205687	19447X	PARTICIPANT	\N	PRESENT	0
205750	205687	14231L	PARTICIPANT	\N	PRESENT	0
205751	205687	05008E	PRESIDENT	1	PRESENT	0
205752	205687	19489J	PARTICIPANT	\N	PRESENT	0
205753	205687	14275Y	PARTICIPANT	\N	PRESENT	0
205754	205687	14041T	PRESIDENT	0	PRESENT	0
205755	205687	14147R	PARTICIPANT	\N	PRESENT	0
205756	205687	14179A	PARTICIPANT	\N	PRESENT	0
205757	205687	14151M	PARTICIPANT	\N	PRESENT	0
205758	205687	14215L	PARTICIPANT	\N	PRESENT	0
205759	205687	08018U	PARTICIPANT	\N	PRESENT	0
205760	205687	19483C	PARTICIPANT	\N	PRESENT	0
205762	205687	14053L	PARTICIPANT	\N	PRESENT	0
205763	205687	98035U	PARTICIPANT	\N	PRESENT	0
205764	205687	19649G	PARTICIPANT	\N	PRESENT	0
205765	205687	14065Q	PARTICIPANT	\N	PRESENT	0
205766	205687	11010L	PARTICIPANT	\N	PRESENT	0
205767	205687	10015M	PARTICIPANT	\N	PRESENT	0
205768	205687	07034Q	PARTICIPANT	\N	PRESENT	0
205769	205687	08045X	PARTICIPANT	\N	PRESENT	0
205770	205687	11026G	PARTICIPANT	\N	PRESENT	0
205771	205687	19253P	PARTICIPANT	\N	PRESENT	0
205772	205687	01024M	PARTICIPANT	\N	PRESENT	0
205773	205687	04038G	PARTICIPANT	\N	PRESENT	0
205774	205687	19719D	PARTICIPANT	\N	PRESENT	0
205775	205687	11033F	PARTICIPANT	\N	PRESENT	0
205776	205687	19725B	PARTICIPANT	\N	PRESENT	0
205777	205687	14089Y	PARTICIPANT	\N	PRESENT	0
205778	205687	19729F	PARTICIPANT	\N	PRESENT	0
205779	205687	95063L	PARTICIPANT	\N	PRESENT	0
205780	205687	19629C	PARTICIPANT	\N	PRESENT	0
205781	205687	14069U	PARTICIPANT	\N	PRESENT	0
205782	205687	11085T	PARTICIPANT	\N	PRESENT	0
205783	205687	11049P	PARTICIPANT	\N	PRESENT	0
205784	205687	04008A	PARTICIPANT	\N	PRESENT	0
205785	205687	14021P	PARTICIPANT	\N	PRESENT	0
205786	205687	08044W	PARTICIPANT	\N	EXCUSE	0
205788	205692	19565D	PARTICIPANT	\N	PRESENT	0
205789	205692	01043Q	PARTICIPANT	\N	PRESENT	0
205790	205692	14357A	PARTICIPANT	\N	PRESENT	0
205791	205692	19441R	PARTICIPANT	\N	PRESENT	0
205792	205692	14081Q	PARTICIPANT	\N	PRESENT	0
205793	205692	19413M	PARTICIPANT	\N	PRESENT	0
205794	205692	19631V	PARTICIPANT	\N	PRESENT	0
205795	205692	11099A	PARTICIPANT	\N	PRESENT	0
205796	205692	08068F	PARTICIPANT	\N	PRESENT	0
205797	205692	04049K	PARTICIPANT	\N	PRESENT	0
205798	205692	19705W	PARTICIPANT	\N	PRESENT	0
205799	205692	19707Y	PARTICIPANT	\N	PRESENT	0
205800	205692	08015R	PARTICIPANT	\N	PRESENT	0
205801	205692	08019V	PARTICIPANT	\N	PRESENT	0
205802	205692	14197C	PARTICIPANT	\N	PRESENT	0
205803	205692	19369B	PARTICIPANT	\N	PRESENT	0
205804	205692	19511N	PARTICIPANT	\N	PRESENT	0
175795	167291	08047A	PARTICIPANT	\N	PRESENT	0
195309	195301	08065C	PARTICIPANT	\N	PRESENT	0
189992	189990	08055A	PARTICIPANT	\N	PRESENT	0
190054	190052	11055M	PARTICIPANT	\N	PRESENT	0
189994	189990	14030Q	PARTICIPANT	\N	PRESENT	0
189995	189990	96004D	PARTICIPANT	\N	EXCUSE	0
189996	189990	08060W	PARTICIPANT	\N	PRESENT	0
189997	189990	11095V	PARTICIPANT	\N	PRESENT	0
189998	189990	14038Y	PARTICIPANT	\N	PRESENT	0
195868	190779	08073C	PARTICIPANT	\N	PRESENT	0
190056	190052	04053F	PARTICIPANT	\N	PRESENT	0
190057	190052	14255U	PARTICIPANT	\N	PRESENT	0
190002	189990	01015L	PARTICIPANT	\N	PRESENT	0
190003	189990	11107G	PARTICIPANT	\N	PRESENT	0
195869	190779	11055M	PARTICIPANT	\N	PRESENT	0
190005	189990	02002K	PARTICIPANT	\N	PRESENT	0
190006	189990	01022K	PARTICIPANT	\N	PRESENT	0
190007	189990	05001W	PARTICIPANT	\N	EXCUSE	0
190059	190052	00003C	PARTICIPANT	\N	EXCUSE	0
190060	190052	14053L	PARTICIPANT	\N	PRESENT	0
190010	189990	11059R	PARTICIPANT	\N	PRESENT	0
190011	189990	14219Q	PARTICIPANT	\N	PRESENT	0
190012	189990	80027E	PARTICIPANT	\N	PRESENT	0
190013	189990	14031R	PARTICIPANT	\N	PRESENT	0
190014	189990	08009T	PRESIDENT	0	PRESENT	0
190015	189990	08062Y	PARTICIPANT	\N	EXCUSE	0
190061	190052	11103C	PARTICIPANT	\N	PRESENT	0
190017	189990	92039X	PARTICIPANT	\N	PRESENT	0
190018	189990	08042U	PARTICIPANT	\N	PRESENT	0
205193	205192	04070G	PARTICIPANT	\N	PRESENT	0
190020	189990	14237S	PARTICIPANT	\N	PRESENT	0
190021	189990	13002U	PARTICIPANT	\N	PRESENT	0
190022	189990	05012A	PARTICIPANT	\N	PRESENT	0
190063	190052	14195A	PARTICIPANT	\N	PRESENT	0
190024	189990	14135M	PARTICIPANT	\N	PRESENT	0
205195	205194	04070G	PARTICIPANT	\N	PRESENT	0
190026	189990	95062K	PARTICIPANT	\N	PRESENT	0
190027	189990	14107H	PARTICIPANT	\N	PRESENT	0
190028	189990	14051J	PARTICIPANT	\N	EXCUSE	0
190029	189990	14157T	PARTICIPANT	\N	PRESENT	0
190065	190052	11023D	PARTICIPANT	\N	PRESENT	0
190066	190052	11031D	PARTICIPANT	\N	PRESENT	0
190067	190052	08052W	PARTICIPANT	\N	PRESENT	0
190068	190052	01059Y	PARTICIPANT	\N	PRESENT	0
190069	190052	04081K	PARTICIPANT	\N	PRESENT	0
190070	190052	98024R	PARTICIPANT	\N	PRESENT	0
206533	206514	04086Q	PARTICIPANT	\N	PRESENT	0
206534	206514	19347U	PARTICIPANT	\N	PRESENT	0
190073	190052	14217N	PARTICIPANT	\N	PRESENT	0
190074	190052	14042U	PARTICIPANT	\N	PRESENT	0
190075	190052	14151M	PARTICIPANT	\N	PRESENT	0
190076	190052	12042Y	PARTICIPANT	\N	PRESENT	0
190077	190052	14281W	PARTICIPANT	\N	PRESENT	0
206535	206514	14235Q	PARTICIPANT	\N	PRESENT	0
190079	190052	14034U	PARTICIPANT	\N	PRESENT	0
190080	190052	14231L	PARTICIPANT	\N	PRESENT	0
190081	190052	11061K	PARTICIPANT	\N	PRESENT	0
206536	206514	19593H	PARTICIPANT	\N	PRESENT	0
206537	206514	19727D	PARTICIPANT	\N	PRESENT	0
190084	190052	08041T	PARTICIPANT	\N	EXCUSE	0
190085	190052	01011G	PARTICIPANT	\N	PRESENT	0
190086	190052	14026U	PARTICIPANT	\N	PRESENT	0
190087	190052	14213J	PARTICIPANT	\N	PRESENT	0
206538	206514	80027E	PARTICIPANT	\N	PRESENT	0
190089	190052	11112D	PARTICIPANT	\N	PRESENT	0
206539	206514	14121F	PARTICIPANT	\N	PRESENT	0
206540	206514	19551W	PARTICIPANT	\N	PRESENT	0
190092	190052	11067R	PARTICIPANT	\N	PRESENT	0
206541	206514	19503N	PARTICIPANT	\N	PRESENT	0
190094	190052	04092N	PRESIDENT	0	PRESENT	0
190095	190052	14265W	PARTICIPANT	\N	PRESENT	0
190096	190052	14119M	PARTICIPANT	\N	PRESENT	0
190097	190052	14071N	PARTICIPANT	\N	PRESENT	0
190098	190052	04043D	PARTICIPANT	\N	PRESENT	0
190099	190052	14271U	PARTICIPANT	\N	PRESENT	0
206542	206514	14001X	PARTICIPANT	\N	PRESENT	0
190101	190052	11093T	PARTICIPANT	\N	EXCUSE	0
190102	190052	11097X	PARTICIPANT	\N	PRESENT	0
190103	190052	04045F	PARTICIPANT	\N	PRESENT	0
190104	190052	14227Q	PARTICIPANT	\N	PRESENT	0
190105	190052	01034P	PARTICIPANT	\N	PRESENT	0
190106	190052	11025F	PARTICIPANT	\N	PRESENT	0
190107	190052	11063M	PARTICIPANT	\N	PRESENT	0
190108	190052	14269B	PARTICIPANT	\N	PRESENT	0
206543	206514	19725B	PARTICIPANT	\N	PRESENT	0
206544	206514	14197C	PARTICIPANT	\N	PRESENT	0
206545	206514	14225N	PARTICIPANT	\N	PRESENT	0
206546	206514	14051J	PARTICIPANT	\N	PRESENT	0
206547	206514	08055A	PARTICIPANT	\N	PRESENT	0
206548	206514	08009T	PARTICIPANT	\N	PRESENT	0
206549	206514	02002K	PARTICIPANT	\N	PRESENT	0
206550	206514	08024S	PARTICIPANT	\N	PRESENT	0
206552	206514	08060W	PARTICIPANT	\N	PRESENT	0
206553	206514	19599P	PARTICIPANT	\N	PRESENT	0
206554	206514	14081Q	PARTICIPANT	\N	PRESENT	0
206555	206514	14207L	PARTICIPANT	\N	PRESENT	0
206556	206514	19549D	PARTICIPANT	\N	PRESENT	0
206557	206514	19531S	PARTICIPANT	\N	PRESENT	0
206558	206514	95063L	PARTICIPANT	\N	PRESENT	0
206559	206514	98029W	PARTICIPANT	\N	PRESENT	0
206560	206514	19629C	PARTICIPANT	\N	PRESENT	0
206561	206514	19349W	PARTICIPANT	\N	PRESENT	0
206562	206514	11065P	PARTICIPANT	\N	PRESENT	0
206563	206514	19563B	PARTICIPANT	\N	PRESENT	0
206564	206514	14241N	PARTICIPANT	\N	PRESENT	0
206565	206514	98022P	PARTICIPANT	\N	PRESENT	0
206566	206514	19301E	PARTICIPANT	\N	PRESENT	0
206567	206514	19681G	PARTICIPANT	\N	PRESENT	0
206568	206514	04057K	PARTICIPANT	\N	PRESENT	0
206569	206514	19387D	PARTICIPANT	\N	PRESENT	0
206570	206514	19719D	PARTICIPANT	\N	PRESENT	0
206571	206514	11064N	PARTICIPANT	\N	PRESENT	0
206572	206514	19583F	PARTICIPANT	\N	PRESENT	0
206573	206514	14093U	PARTICIPANT	\N	PRESENT	0
206574	206514	14195A	PARTICIPANT	\N	PRESENT	0
206575	206514	19441R	PARTICIPANT	\N	PRESENT	0
206576	206514	19479G	PARTICIPANT	\N	PRESENT	0
206577	206514	14219Q	PARTICIPANT	\N	PRESENT	0
206579	206514	14089Y	PARTICIPANT	\N	PRESENT	0
206616	206514	19553Y	PARTICIPANT	\N	PRESENT	0
206630	206514	19717B	PARTICIPANT	\N	PRESENT	0
206631	206514	19569H	PARTICIPANT	\N	PRESENT	0
206632	206514	19369B	PARTICIPANT	\N	PRESENT	0
206633	206514	19253P	PARTICIPANT	\N	PRESENT	0
206634	206514	88008L	PARTICIPANT	\N	PRESENT	0
206635	206514	11012A	PARTICIPANT	\N	PRESENT	0
206636	206514	14034U	PARTICIPANT	\N	PRESENT	0
206637	206514	14221J	PARTICIPANT	\N	PRESENT	0
206638	206514	14103D	PARTICIPANT	\N	PRESENT	0
206639	206514	19713W	PARTICIPANT	\N	PRESENT	0
206640	206514	19335Q	PARTICIPANT	\N	PRESENT	0
206641	206514	14073Q	PARTICIPANT	\N	PRESENT	0
206642	206514	19367Y	PARTICIPANT	\N	PRESENT	0
206643	206514	19621T	PARTICIPANT	\N	PRESENT	0
206644	206514	19611R	PARTICIPANT	\N	PRESENT	0
206645	206514	17583W	PARTICIPANT	\N	PRESENT	0
206646	206514	14237S	PARTICIPANT	\N	PRESENT	0
206647	206514	04044E	PARTICIPANT	\N	PRESENT	0
206648	206514	98050T	PARTICIPANT	\N	PRESENT	0
206649	206514	19733B	PARTICIPANT	\N	PRESENT	0
206650	206514	19421M	PARTICIPANT	\N	PRESENT	0
206651	206514	14111D	PARTICIPANT	\N	PRESENT	0
206652	206514	19545Y	PARTICIPANT	\N	PRESENT	0
206653	206514	19585H	PARTICIPANT	\N	PRESENT	0
206655	206514	14357A	PARTICIPANT	\N	PRESENT	0
206657	206514	04018C	PARTICIPANT	\N	PRESENT	0
206658	206514	19699S	PARTICIPANT	\N	PRESENT	0
206659	206514	19483C	PARTICIPANT	\N	PRESENT	0
206661	206514	19533U	PARTICIPANT	\N	PRESENT	0
206662	206514	19707Y	PARTICIPANT	\N	PRESENT	0
206663	206514	19705W	PARTICIPANT	\N	PRESENT	0
206664	206514	08015R	PARTICIPANT	\N	PRESENT	0
206665	206514	19383Y	PARTICIPANT	\N	PRESENT	0
206666	206514	14265W	PARTICIPANT	\N	PRESENT	0
206667	206514	14147R	PARTICIPANT	\N	PRESENT	0
206668	206514	08045X	PARTICIPANT	\N	PRESENT	0
206669	206514	98023Q	PARTICIPANT	\N	PRESENT	0
206670	206514	18083K	PARTICIPANT	\N	PRESENT	0
206671	206514	19575F	PARTICIPANT	\N	PRESENT	0
206672	206514	07029T	PARTICIPANT	\N	PRESENT	0
206673	206514	08010L	PARTICIPANT	\N	PRESENT	0
206674	206514	04008A	PARTICIPANT	\N	PRESENT	0
206675	206514	19711U	PARTICIPANT	\N	PRESENT	0
206676	206514	17637T	PARTICIPANT	\N	PRESENT	0
206677	206514	19679N	PARTICIPANT	\N	PRESENT	0
206678	206514	95062K	PARTICIPANT	\N	PRESENT	0
206679	206514	04097T	PARTICIPANT	\N	PRESENT	0
206680	206514	14041T	PARTICIPANT	\N	PRESENT	0
206681	206514	04088S	PARTICIPANT	\N	PRESENT	0
182333	182332	04071H	PARTICIPANT	\N	PRESENT	0
182353	182352	01031L	PARTICIPANT	\N	PRESENT	0
182354	182352	08011M	PARTICIPANT	\N	PRESENT	0
183373	183372	01047U	PARTICIPANT	\N	PRESENT	0
183374	183372	04036E	PARTICIPANT	\N	PRESENT	0
183376	183372	04038G	PARTICIPANT	\N	PRESENT	0
183378	183372	08068F	PARTICIPANT	\N	PRESENT	0
183379	183372	11061K	PARTICIPANT	\N	PRESENT	0
183380	183372	04035D	PARTICIPANT	\N	PRESENT	0
183381	183372	08042U	PARTICIPANT	\N	PRESENT	0
183813	183812	04040A	PARTICIPANT	\N	PRESENT	0
183814	183812	11106F	PARTICIPANT	\N	PRESENT	0
183816	183815	98021N	PARTICIPANT	\N	PRESENT	0
183832	180412	89017R	PARTICIPANT	\N	PRESENT	0
183833	180412	14030Q	PARTICIPANT	\N	PRESENT	0
183834	180412	14255U	PARTICIPANT	\N	PRESENT	0
183835	180412	14083S	PARTICIPANT	\N	PRESENT	0
183836	180412	04055H	PARTICIPANT	\N	PRESENT	0
183837	180412	14151M	PARTICIPANT	\N	PRESENT	0
183838	180412	95030B	PARTICIPANT	\N	PRESENT	0
183839	180412	14034U	PARTICIPANT	\N	PRESENT	0
183840	180412	14231L	PARTICIPANT	\N	PRESENT	0
183841	180412	04061F	PARTICIPANT	\N	PRESENT	0
183842	180412	14061L	PARTICIPANT	\N	PRESENT	0
183843	180412	04049K	PARTICIPANT	\N	PRESENT	0
183844	180412	86034E	PARTICIPANT	\N	PRESENT	0
183845	180412	11100Y	PARTICIPANT	\N	PRESENT	0
183846	180412	14205J	PARTICIPANT	\N	PRESENT	0
183847	180412	08062Y	PARTICIPANT	\N	PRESENT	0
183848	180412	14147R	PARTICIPANT	\N	PRESENT	0
183849	180412	14265W	PARTICIPANT	\N	PRESENT	0
183850	180412	14253S	PARTICIPANT	\N	PRESENT	0
183851	180412	14227Q	PARTICIPANT	\N	PRESENT	0
183852	180412	14157T	PARTICIPANT	\N	PRESENT	0
183853	180412	95067Q	PARTICIPANT	\N	PRESENT	0
183854	180412	14042U	PARTICIPANT	\N	PRESENT	0
183855	180412	08053X	PARTICIPANT	\N	PRESENT	0
183856	180412	14038Y	PARTICIPANT	\N	PRESENT	0
183857	180412	08010L	PARTICIPANT	\N	PRESENT	0
183858	180412	04053F	PARTICIPANT	\N	PRESENT	0
183863	183860	14083S	PARTICIPANT	\N	PRESENT	0
183861	183860	89017R	PARTICIPANT	\N	PRESENT	0
183862	183860	14255U	PARTICIPANT	\N	PRESENT	0
183864	183860	14151M	PARTICIPANT	\N	PRESENT	0
183865	183860	95030B	PARTICIPANT	\N	PRESENT	0
183866	183860	14034U	PARTICIPANT	\N	PRESENT	0
183867	183860	14061L	PARTICIPANT	\N	PRESENT	0
183868	183860	04049K	PARTICIPANT	\N	PRESENT	0
183869	183860	14205J	PARTICIPANT	\N	PRESENT	0
183874	183860	14157T	PARTICIPANT	\N	PRESENT	0
183871	183860	14265W	PARTICIPANT	\N	PRESENT	0
183872	183860	14253S	PARTICIPANT	\N	PRESENT	0
183873	183860	14227Q	PARTICIPANT	\N	PRESENT	0
183875	183860	95067Q	PARTICIPANT	\N	PRESENT	0
183876	183860	14042U	PARTICIPANT	\N	PRESENT	0
183877	183860	08053X	PARTICIPANT	\N	PRESENT	0
183878	183860	04053F	PARTICIPANT	\N	PRESENT	0
184559	184558	11027H	PARTICIPANT	\N	PRESENT	0
184560	184558	14097Y	PARTICIPANT	\N	PRESENT	0
185313	185312	14239U	PARTICIPANT	\N	PRESENT	0
185314	185312	11055M	PARTICIPANT	\N	PRESENT	0
185315	185312	14065Q	PARTICIPANT	\N	PRESENT	0
185316	185312	08043V	PARTICIPANT	\N	PRESENT	0
185317	185312	08024S	PARTICIPANT	\N	PRESENT	0
185318	185312	14195A	PARTICIPANT	\N	PRESENT	0
185319	185312	11031D	PARTICIPANT	\N	PRESENT	0
185320	185312	08052W	PARTICIPANT	\N	PRESENT	0
185321	185312	11061K	PARTICIPANT	\N	PRESENT	0
185322	185312	14213J	PRESIDENT	1	PRESENT	0
185323	185312	14147R	PARTICIPANT	\N	PRESENT	0
185324	185312	14223L	PARTICIPANT	\N	PRESENT	0
185325	185312	04092N	PRESIDENT	0	PRESENT	0
185326	185312	14265W	PARTICIPANT	\N	PRESENT	0
185327	185312	11097X	PARTICIPANT	\N	PRESENT	0
185328	185312	04045F	PARTICIPANT	\N	PRESENT	0
185329	185312	87003B	PARTICIPANT	\N	EXCUSE	0
185330	185312	14235Q	PARTICIPANT	\N	EXCUSE	0
185331	185312	14028W	PARTICIPANT	\N	EXCUSE	0
185332	185312	11094U	PARTICIPANT	\N	EXCUSE	0
185333	185312	14271U	PARTICIPANT	\N	EXCUSE	0
185353	185352	04054G	PARTICIPANT	\N	EXCUSE	0
185354	185352	96004D	PRESIDENT	0	PRESENT	0
185355	185352	14089Y	PARTICIPANT	\N	PRESENT	0
185356	185352	11035H	PARTICIPANT	\N	EXCUSE	0
185357	185352	14249W	PARTICIPANT	\N	PRESENT	0
185358	185352	08018U	PARTICIPANT	\N	PRESENT	0
185359	185352	04035D	PARTICIPANT	\N	PRESENT	0
185360	185352	11083R	PARTICIPANT	\N	PRESENT	0
185361	185352	14026U	PARTICIPANT	\N	PRESENT	0
185362	185352	95037J	PARTICIPANT	\N	PRESENT	0
185363	185352	04061F	PARTICIPANT	\N	EXCUSE	0
185364	185352	14073Q	PARTICIPANT	\N	PRESENT	0
185365	185352	11026G	PARTICIPANT	\N	EXCUSE	0
185366	185352	98046X	PARTICIPANT	\N	PRESENT	0
185367	185352	04057K	PARTICIPANT	\N	PRESENT	0
185368	185352	08042U	PARTICIPANT	\N	PRESENT	0
185369	185352	11012A	PARTICIPANT	\N	EXCUSE	0
185370	185352	04045F	PARTICIPANT	\N	PRESENT	0
185371	185352	98035U	PARTICIPANT	\N	PRESENT	0
185372	185352	92045V	PARTICIPANT	\N	EXCUSE	0
185373	185352	04034C	PARTICIPANT	\N	EXCUSE	0
185633	185632	11061K	PARTICIPANT	\N	PRESENT	0
185634	185632	11031D	PARTICIPANT	\N	PRESENT	0
185635	185632	11097X	PARTICIPANT	\N	PRESENT	0
187293	187292	11033F	PARTICIPANT	\N	PRESENT	0
187313	187312	11033F	PARTICIPANT	\N	PRESENT	0
187314	187312	04044E	PARTICIPANT	\N	PRESENT	0
187653	187652	14135M	PARTICIPANT	\N	PRESENT	0
187654	187652	11083R	PARTICIPANT	\N	PRESENT	0
187656	187655	14135M	PARTICIPANT	\N	PRESENT	0
187657	187655	11083R	PARTICIPANT	\N	PRESENT	0
187695	187694	14030Q	PARTICIPANT	\N	PRESENT	0
187696	187694	08043V	PARTICIPANT	\N	PRESENT	0
187697	187694	11029K	PARTICIPANT	\N	PRESENT	0
187698	187694	11027H	PARTICIPANT	\N	PRESENT	0
187699	187694	07026Q	PARTICIPANT	\N	PRESENT	0
187700	187694	09001P	PRESIDENT	0	PRESENT	0
187701	187694	08031R	PARTICIPANT	\N	PRESENT	0
187702	187694	14038Y	PARTICIPANT	\N	EXCUSE	0
187703	187694	11031D	PARTICIPANT	\N	EXCUSE	0
187704	187694	80013X	PARTICIPANT	\N	EXCUSE	0
187705	187694	12042Y	PARTICIPANT	\N	EXCUSE	0
187706	187694	04036E	PARTICIPANT	\N	EXCUSE	0
187707	187694	14031R	PARTICIPANT	\N	EXCUSE	0
187708	187694	14265W	PARTICIPANT	\N	EXCUSE	0
187709	187694	14237S	PARTICIPANT	\N	EXCUSE	0
187710	187694	14042U	PARTICIPANT	\N	PRESENT	0
187711	187694	11100Y	PARTICIPANT	\N	PRESENT	0
187712	187694	11066Q	PARTICIPANT	\N	PRESENT	0
187713	187694	14018U	PARTICIPANT	\N	PRESENT	0
187714	187694	04043D	PARTICIPANT	\N	PRESENT	0
187771	187770	07026Q	PARTICIPANT	\N	PRESENT	0
187893	187892	89017R	PARTICIPANT	\N	PRESENT	0
187933	187932	04049K	PARTICIPANT	\N	PRESENT	0
187935	187934	04049K	PARTICIPANT	\N	PRESENT	0
187936	187934	04053F	PARTICIPANT	\N	PRESENT	0
187937	187934	14255U	PARTICIPANT	\N	PRESENT	0
187938	187934	14061L	PARTICIPANT	\N	PRESENT	0
187939	187934	14265W	PARTICIPANT	\N	PRESENT	0
210090	208069	14195A	PARTICIPANT	\N	PRESENT	0
205213	205212	14235Q	PARTICIPANT	\N	EXCUSE	0
187943	187942	14255U	PARTICIPANT	\N	PRESENT	0
187944	187942	14083S	PARTICIPANT	\N	PRESENT	0
187945	187942	14061L	PARTICIPANT	\N	PRESENT	0
210091	208069	08052W	PARTICIPANT	\N	PRESENT	0
187948	187942	14053L	PARTICIPANT	\N	PRESENT	0
210092	208069	14042U	PARTICIPANT	\N	PRESENT	0
210093	208069	11067R	PARTICIPANT	\N	PRESENT	0
210150	210045	02002K	PARTICIPANT	\N	PRESENT	0
210177	210176	11053K	PARTICIPANT	\N	PRESENT	0
210179	210178	19711U	PARTICIPANT	\N	PRESENT	0
210795	207686	07029T	PARTICIPANT	\N	PRESENT	0
210796	207686	95062K	PARTICIPANT	\N	PRESENT	0
210797	207686	14111D	PARTICIPANT	\N	PRESENT	0
210798	207686	14151M	PARTICIPANT	\N	PRESENT	0
210799	207686	19573D	PARTICIPANT	\N	PRESENT	0
210800	207686	14267Y	PARTICIPANT	\N	PRESENT	0
210801	207686	11045K	PARTICIPANT	\N	PRESENT	0
210802	207686	01028R	PARTICIPANT	\N	PRESENT	0
210803	207686	19585H	PARTICIPANT	\N	PRESENT	0
210804	207686	14219Q	PARTICIPANT	\N	PRESENT	0
210805	210098	19443T	PARTICIPANT	\N	PRESENT	0
210806	210098	95030B	PARTICIPANT	\N	PRESENT	0
210807	210098	04034C	PARTICIPANT	\N	PRESENT	0
210808	210098	14079W	PARTICIPANT	\N	PRESENT	0
210809	210098	04040A	PARTICIPANT	\N	PRESENT	0
210810	210098	11027H	PARTICIPANT	\N	PRESENT	0
210811	210098	16685X	PARTICIPANT	\N	PRESENT	0
166153	166152	96004D	PRESIDENT	0	PRESENT	0
166154	166152	04040A	PARTICIPANT	\N	PRESENT	0
166155	166152	04035D	PARTICIPANT	\N	PRESENT	0
166156	166152	11083R	PARTICIPANT	\N	PRESENT	0
166157	166152	14014Q	PARTICIPANT	\N	PRESENT	0
166158	166152	98022P	PARTICIPANT	\N	PRESENT	0
166159	166152	04061F	PARTICIPANT	\N	PRESENT	0
166160	166152	83042R	PARTICIPANT	\N	PRESENT	0
166161	166152	04057K	PARTICIPANT	\N	PRESENT	0
166162	166152	98021N	PRESIDENT	1	PRESENT	0
166163	166152	04080J	PARTICIPANT	\N	PRESENT	0
166164	166152	95059Q	PARTICIPANT	\N	EXCUSE	0
166165	166152	04034C	PARTICIPANT	\N	PRESENT	0
166167	166166	96004D	PARTICIPANT	\N	PRESENT	0
166168	166166	04040A	PARTICIPANT	\N	PRESENT	0
166169	166166	04035D	PARTICIPANT	\N	PRESENT	0
166170	166166	11083R	PARTICIPANT	\N	PRESENT	0
166171	166166	98022P	PARTICIPANT	\N	PRESENT	0
166172	166166	04061F	PARTICIPANT	\N	PRESENT	0
166173	166166	14073Q	PARTICIPANT	\N	PRESENT	0
166174	166166	83042R	PARTICIPANT	\N	PRESENT	0
166175	166166	98021N	PRESIDENT	0	PRESENT	0
166176	166166	04057K	PARTICIPANT	\N	PRESENT	0
166177	166166	95059Q	PARTICIPANT	\N	EXCUSE	0
166202	158217	08051V	PARTICIPANT	\N	PRESENT	0
166203	158217	14071N	PARTICIPANT	\N	PRESENT	0
166753	166752	04042C	PARTICIPANT	\N	PRESENT	0
172410	170598	04071H	PARTICIPANT	\N	PRESENT	0
172411	170598	01060R	PARTICIPANT	\N	PRESENT	0
172412	170598	14241N	PARTICIPANT	\N	PRESENT	0
172432	170598	14225N	PARTICIPANT	\N	PRESENT	0
172433	170598	08031R	PARTICIPANT	\N	PRESENT	0
172434	170598	04074L	PARTICIPANT	\N	PRESENT	0
172436	170598	14055N	PARTICIPANT	\N	PRESENT	0
172437	170598	14123H	PARTICIPANT	\N	PRESENT	0
172495	170598	14195A	PARTICIPANT	\N	PRESENT	0
172496	170598	14363X	PARTICIPANT	\N	PRESENT	0
172497	170598	14041T	PARTICIPANT	\N	PRESENT	0
172498	170598	14063N	PARTICIPANT	\N	PRESENT	0
172499	170598	08014Q	PARTICIPANT	\N	PRESENT	0
172500	170598	08049C	PARTICIPANT	\N	PRESENT	0
172501	170598	14059S	PARTICIPANT	\N	PRESENT	0
172502	170598	11061K	PARTICIPANT	\N	PRESENT	0
172503	170598	14267Y	PARTICIPANT	\N	PRESENT	0
172579	170598	08041T	PARTICIPANT	\N	PRESENT	0
172580	170598	11103C	PARTICIPANT	\N	PRESENT	0
172581	170598	01048V	PARTICIPANT	\N	PRESENT	0
172582	170598	14157T	PARTICIPANT	\N	PRESENT	0
172592	170598	14231L	PARTICIPANT	\N	PRESENT	0
172593	170598	11049P	PARTICIPANT	\N	PRESENT	0
172594	170598	95030B	PARTICIPANT	\N	PRESENT	0
172595	170598	14030Q	PARTICIPANT	\N	PRESENT	0
172597	170598	14355X	PARTICIPANT	\N	PRESENT	0
172598	170598	14087W	PARTICIPANT	\N	PRESENT	0
172599	170598	11054L	PARTICIPANT	\N	PRESENT	0
172600	170598	14105F	PARTICIPANT	\N	PRESENT	0
172601	170598	11025F	PARTICIPANT	\N	PRESENT	0
172602	170598	11114F	PARTICIPANT	\N	PRESENT	0
172612	170598	14031R	PARTICIPANT	\N	PRESENT	0
172613	170598	01057W	PARTICIPANT	\N	PRESENT	0
172614	170598	14199E	PARTICIPANT	\N	PRESENT	0
172615	170598	14173T	PARTICIPANT	\N	PRESENT	0
172616	170598	04044E	PARTICIPANT	\N	PRESENT	0
172617	170598	11104D	PARTICIPANT	\N	PRESENT	0
172618	170598	01046T	PARTICIPANT	\N	PRESENT	0
172619	170598	14069U	PARTICIPANT	\N	PRESENT	0
172620	170598	14119M	PARTICIPANT	\N	PRESENT	0
172621	170598	08039A	PARTICIPANT	\N	PRESENT	0
172622	170598	95062K	PARTICIPANT	\N	PRESENT	0
172623	170598	01027Q	PARTICIPANT	\N	PRESENT	0
172624	170598	08010L	PARTICIPANT	\N	PRESENT	0
172733	170599	14107H	PARTICIPANT	\N	PRESENT	0
172734	170599	11098Y	PARTICIPANT	\N	PRESENT	0
172735	170599	11036J	PARTICIPANT	\N	PRESENT	0
172736	170599	11066Q	PARTICIPANT	\N	PRESENT	0
172737	170599	08041T	PARTICIPANT	\N	PRESENT	0
172738	170599	14187A	PARTICIPANT	\N	PRESENT	0
172739	170599	14061L	PARTICIPANT	\N	PRESENT	0
172740	170599	14217N	PARTICIPANT	\N	PRESENT	0
172741	170599	97011G	PARTICIPANT	\N	PRESENT	0
172742	170599	14179A	PARTICIPANT	\N	PRESENT	0
172743	170599	01043Q	PARTICIPANT	\N	PRESENT	0
172744	170599	14231L	PARTICIPANT	\N	PRESENT	0
172745	170599	14205J	PARTICIPANT	\N	PRESENT	0
172746	170599	14033T	PARTICIPANT	\N	PRESENT	0
172747	170599	14081Q	PARTICIPANT	\N	PRESENT	0
172748	170599	04088S	PARTICIPANT	\N	PRESENT	0
172749	170599	01019Q	PARTICIPANT	\N	PRESENT	0
172750	170599	08038Y	PARTICIPANT	\N	PRESENT	0
172751	170599	08016S	PARTICIPANT	\N	PRESENT	0
172752	170599	11104D	PARTICIPANT	\N	PRESENT	0
172753	170599	08055A	PARTICIPANT	\N	PRESENT	0
172754	170599	86044G	PARTICIPANT	\N	PRESENT	0
172755	170599	14261S	PARTICIPANT	\N	PRESENT	0
172756	170599	11067R	PARTICIPANT	\N	PRESENT	0
172757	170599	14225N	PARTICIPANT	\N	PRESENT	0
172758	170599	14073Q	PARTICIPANT	\N	PRESENT	0
172759	170599	08019V	PARTICIPANT	\N	PRESENT	0
172760	170599	14159V	PARTICIPANT	\N	PRESENT	0
172761	170599	98050T	PARTICIPANT	\N	PRESENT	0
172762	170599	14363X	PARTICIPANT	\N	PRESENT	0
172763	170599	14223L	PARTICIPANT	\N	PRESENT	0
172764	170599	14103D	PARTICIPANT	\N	PRESENT	0
172765	170599	04067M	PARTICIPANT	\N	PRESENT	0
172772	170599	14257W	PARTICIPANT	\N	PRESENT	0
172773	170599	11043H	PARTICIPANT	\N	PRESENT	0
172774	170599	14030Q	PARTICIPANT	\N	PRESENT	0
172775	170599	14191V	PARTICIPANT	\N	PRESENT	0
172776	170599	08060W	PARTICIPANT	\N	PRESENT	0
172777	170599	08048B	PARTICIPANT	\N	PRESENT	0
172778	170599	14265W	PARTICIPANT	\N	PRESENT	0
172779	170599	80013X	PARTICIPANT	\N	PRESENT	0
172780	170599	08031R	PARTICIPANT	\N	PRESENT	0
172781	170599	01015L	PARTICIPANT	\N	PRESENT	0
172782	170599	95062K	PARTICIPANT	\N	PRESENT	0
172832	170599	14199E	PARTICIPANT	\N	PRESENT	0
172833	170599	01047U	PARTICIPANT	\N	PRESENT	0
172834	170599	08056B	PARTICIPANT	\N	PRESENT	0
172835	170599	11097X	PARTICIPANT	\N	PRESENT	0
172836	170599	08062Y	PARTICIPANT	\N	PRESENT	0
172837	170599	11093T	PARTICIPANT	\N	PRESENT	0
172838	170599	01031L	PARTICIPANT	\N	PRESENT	0
172839	170599	14271U	PARTICIPANT	\N	PRESENT	0
172840	170599	14105F	PARTICIPANT	\N	PRESENT	0
172932	167024	86034E	PARTICIPANT	\N	PRESENT	0
173025	167024	04097T	PARTICIPANT	\N	PRESENT	0
173027	167024	08039A	PARTICIPANT	\N	PRESENT	0
173028	167024	04086Q	PARTICIPANT	\N	PRESENT	0
173029	167024	08028W	PARTICIPANT	\N	PRESENT	0
173030	167024	01019Q	PARTICIPANT	\N	PRESENT	0
173031	167024	04035D	PARTICIPANT	\N	PRESENT	0
173032	167024	11080N	PARTICIPANT	\N	PRESENT	0
173033	167024	14191V	PARTICIPANT	\N	PRESENT	0
173034	167024	96004D	PARTICIPANT	\N	PRESENT	0
173035	167024	86044G	PARTICIPANT	\N	PRESENT	0
173036	167024	01058X	PARTICIPANT	\N	PRESENT	0
173037	167024	90003B	PARTICIPANT	\N	PRESENT	0
172718	170599	01007L	PARTICIPANT	\N	PRESENT	0
172732	170599	08068F	PARTICIPANT	\N	PRESENT	0
173038	167024	01027Q	PARTICIPANT	\N	PRESENT	0
173041	167024	14031R	PARTICIPANT	\N	PRESENT	0
173044	167024	14033T	PARTICIPANT	\N	PRESENT	0
173047	167024	92031P	PARTICIPANT	\N	PRESENT	0
173049	167024	14111D	PARTICIPANT	\N	PRESENT	0
173054	167024	14105F	PARTICIPANT	\N	PRESENT	0
173056	167024	14357A	PARTICIPANT	\N	PRESENT	0
173059	167024	14041T	PARTICIPANT	\N	PRESENT	0
173061	167024	14223L	PARTICIPANT	\N	PRESENT	0
173062	167024	08041T	PARTICIPANT	\N	PRESENT	0
173066	167024	01041N	PARTICIPANT	\N	PRESENT	0
173067	167024	99004R	PARTICIPANT	\N	PRESENT	0
173068	167024	04081K	PARTICIPANT	\N	PRESENT	0
173069	167024	04033B	PARTICIPANT	\N	PRESENT	0
173070	167024	01057W	PARTICIPANT	\N	PRESENT	0
173071	167024	14071N	PARTICIPANT	\N	PRESENT	0
173072	167024	11088W	PARTICIPANT	\N	PRESENT	0
173073	167024	04057K	PARTICIPANT	\N	PRESENT	0
173074	167024	04085P	PARTICIPANT	\N	PRESENT	0
173075	167024	14175V	PARTICIPANT	\N	PRESENT	0
173076	167024	07026Q	PARTICIPANT	\N	PRESENT	0
173077	167024	14361V	PARTICIPANT	\N	PRESENT	0
173078	167024	07029T	PARTICIPANT	\N	PRESENT	0
173079	167024	14087W	PARTICIPANT	\N	PRESENT	0
173080	167024	92045V	PARTICIPANT	\N	PRESENT	0
173081	167024	14187A	PARTICIPANT	\N	PRESENT	0
173082	167024	08010L	PARTICIPANT	\N	PRESENT	0
173083	167024	05012A	PARTICIPANT	\N	PRESENT	0
173084	167024	11063M	PARTICIPANT	\N	PRESENT	0
173085	167024	14079W	PARTICIPANT	\N	PRESENT	0
180740	180738	04036E	PARTICIPANT	\N	PRESENT	0
180742	180738	04070G	PARTICIPANT	\N	PRESENT	0
180807	178732	08031R	PARTICIPANT	\N	PRESENT	0
180808	178732	11076S	PARTICIPANT	\N	PRESENT	0
182853	182852	11065P	PARTICIPANT	\N	PRESENT	0
183433	183432	11091R	PARTICIPANT	\N	PRESENT	0
183434	183432	11026G	PARTICIPANT	\N	PRESENT	0
183435	183432	14281W	PARTICIPANT	\N	PRESENT	0
183453	183452	08034U	PARTICIPANT	\N	PRESENT	0
183454	183452	11026G	PARTICIPANT	\N	PRESENT	0
184132	184112	11040E	PARTICIPANT	\N	PRESENT	0
184133	184112	14255U	PARTICIPANT	\N	PRESENT	0
184134	184112	14093U	PARTICIPANT	\N	PRESENT	0
184135	184112	98042T	PARTICIPANT	\N	PRESENT	0
184136	184112	04036E	PARTICIPANT	\N	PRESENT	0
184137	184112	14147R	PARTICIPANT	\N	PRESENT	0
184138	184112	11076S	PARTICIPANT	\N	PRESENT	0
184139	184112	04034C	PARTICIPANT	\N	PRESENT	0
184140	184112	14169X	PARTICIPANT	\N	PRESENT	0
184141	184112	01057W	PARTICIPANT	\N	PRESENT	0
184142	184112	11098Y	PARTICIPANT	\N	PRESENT	0
184143	184112	14253S	PARTICIPANT	\N	PRESENT	0
184145	184144	11031D	PARTICIPANT	\N	PRESENT	0
184146	184144	11061K	PARTICIPANT	\N	PRESENT	0
184147	184144	11097X	PARTICIPANT	\N	PRESENT	0
184153	184152	11031D	PARTICIPANT	\N	PRESENT	0
184154	184152	11061K	PARTICIPANT	\N	PRESENT	0
184155	184152	11097X	PARTICIPANT	\N	PRESENT	0
184157	184156	11031D	PARTICIPANT	\N	PRESENT	0
184158	184156	11061K	PARTICIPANT	\N	PRESENT	0
184159	184156	11097X	PARTICIPANT	\N	PRESENT	0
184216	184215	11103C	PARTICIPANT	\N	PRESENT	0
184217	184215	08052W	PARTICIPANT	\N	PRESENT	0
184233	184232	11103C	PARTICIPANT	\N	PRESENT	0
184234	184232	08052W	PARTICIPANT	\N	PRESENT	0
184236	184235	11103C	PARTICIPANT	\N	PRESENT	0
184237	184235	08052W	PARTICIPANT	\N	PRESENT	0
184240	184239	11103C	PARTICIPANT	\N	PRESENT	0
184241	184239	08052W	PARTICIPANT	\N	PRESENT	0
184245	184243	11103C	PARTICIPANT	\N	PRESENT	0
184246	184243	08052W	PARTICIPANT	\N	PRESENT	0
184249	184247	12042Y	PARTICIPANT	\N	PRESENT	0
184250	184247	11093T	PARTICIPANT	\N	PRESENT	0
184252	184251	12042Y	PARTICIPANT	\N	PRESENT	0
184253	184251	11093T	PARTICIPANT	\N	PRESENT	0
184255	184254	12042Y	PARTICIPANT	\N	PRESENT	0
184256	184254	11093T	PARTICIPANT	\N	PRESENT	0
184956	184192	08010L	PARTICIPANT	\N	PRESENT	0
184957	184192	08034U	PARTICIPANT	\N	EXCUSE	0
184958	184192	11048N	PARTICIPANT	\N	EXCUSE	0
184972	184820	11083R	PARTICIPANT	\N	PRESENT	0
185873	185872	01041N	PARTICIPANT	\N	PRESENT	0
185893	185892	04044E	PARTICIPANT	\N	PRESENT	0
187993	187992	11039M	PARTICIPANT	\N	PRESENT	0
187994	187992	98042T	PARTICIPANT	\N	PRESENT	0
187995	187992	01019Q	PARTICIPANT	\N	PRESENT	0
203841	190802	14133K	PARTICIPANT	\N	PRESENT	0
205806	205692	11081P	PARTICIPANT	\N	PRESENT	0
205807	205692	14265W	PARTICIPANT	\N	PRESENT	0
205808	205692	14329V	PARTICIPANT	\N	PRESENT	0
205809	205692	19591F	PARTICIPANT	\N	PRESENT	0
205810	205692	14135M	PARTICIPANT	\N	PRESENT	0
205811	205692	19467C	PARTICIPANT	\N	PRESENT	0
205812	205692	14187A	PARTICIPANT	\N	PRESENT	0
205813	205692	08038Y	PARTICIPANT	\N	PRESENT	0
205814	205692	19695N	PARTICIPANT	\N	PRESENT	0
205815	205692	19301E	PARTICIPANT	\N	PRESENT	0
205816	205692	14033T	PARTICIPANT	\N	PRESENT	0
205817	205692	11090Q	PARTICIPANT	\N	PRESENT	0
205818	205692	01025N	PARTICIPANT	\N	PRESENT	0
205819	205692	19295A	PARTICIPANT	\N	PRESENT	0
205820	205692	19269X	PARTICIPANT	\N	PRESENT	0
205821	205692	14205J	PARTICIPANT	\N	PRESENT	0
205822	205692	04088S	PARTICIPANT	\N	PRESENT	0
205823	205692	11056N	PARTICIPANT	\N	PRESENT	0
205824	205692	04089T	PARTICIPANT	\N	PRESENT	0
205825	205692	14115H	PARTICIPANT	\N	PRESENT	0
205826	205692	11101A	PARTICIPANT	\N	PRESENT	0
205827	205692	19507S	PARTICIPANT	\N	PRESENT	0
205828	205692	14207L	PARTICIPANT	\N	PRESENT	0
205829	205692	04043D	PARTICIPANT	\N	PRESENT	0
205830	205692	17589D	PARTICIPANT	\N	PRESENT	0
205831	205692	19619A	PARTICIPANT	\N	PRESENT	0
205832	205692	14257W	PARTICIPANT	\N	PRESENT	0
205833	205693	04070G	PRESIDENT	1	PRESENT	0
205834	205693	19699S	PARTICIPANT	\N	PRESENT	0
205835	205693	12041X	PARTICIPANT	\N	PRESENT	0
205836	205693	19533U	PARTICIPANT	\N	PRESENT	0
205837	205693	95015C	PARTICIPANT	\N	PRESENT	0
205838	205693	04033B	PARTICIPANT	\N	PRESENT	0
205839	205693	14229S	PARTICIPANT	\N	PRESENT	0
205840	205693	14241N	PARTICIPANT	\N	PRESENT	0
205841	205693	19573D	PARTICIPANT	\N	PRESENT	0
205842	205693	14039A	PARTICIPANT	\N	PRESENT	0
205843	205693	14107H	PARTICIPANT	\N	PRESENT	0
205844	205693	08017T	PARTICIPANT	\N	PRESENT	0
205845	205693	92040Q	PARTICIPANT	\N	PRESENT	0
205846	205693	07033P	PARTICIPANT	\N	PRESENT	0
205847	205693	08012N	PARTICIPANT	\N	PRESENT	0
205848	205693	08016S	PARTICIPANT	\N	PRESENT	0
205849	205693	14249W	PARTICIPANT	\N	PRESENT	0
205850	205693	08039A	PARTICIPANT	\N	PRESENT	0
205851	205693	08031R	PARTICIPANT	\N	PRESENT	0
205852	205693	19593H	PARTICIPANT	\N	PRESENT	0
205853	205693	14059S	PARTICIPANT	\N	PRESENT	0
205854	205693	19643A	PARTICIPANT	\N	PRESENT	0
205855	205693	14061L	PARTICIPANT	\N	PRESENT	0
205856	205693	14073Q	PARTICIPANT	\N	PRESENT	0
205857	205693	19611R	PARTICIPANT	\N	PRESENT	0
205858	205693	08035V	PARTICIPANT	\N	PRESENT	0
205859	205693	08043V	PARTICIPANT	\N	PRESENT	0
205860	205693	19693L	PARTICIPANT	\N	PRESENT	0
205861	205693	19399H	PARTICIPANT	\N	PRESENT	0
205862	205693	87003B	PARTICIPANT	\N	PRESENT	0
205863	205693	14201E	PARTICIPANT	\N	PRESENT	0
205864	205693	14030Q	PARTICIPANT	\N	PRESENT	0
205865	205693	14251Q	PARTICIPANT	\N	PRESENT	0
205866	205693	08020N	PRESIDENT	0	PRESENT	0
205867	205693	04059M	PARTICIPANT	\N	PRESENT	0
205869	205693	11109J	PARTICIPANT	\N	PRESENT	0
205870	205693	11083R	PARTICIPANT	\N	PRESENT	0
205871	205693	14063N	PARTICIPANT	\N	PRESENT	0
205872	205693	14109K	PARTICIPANT	\N	PRESENT	0
205873	205693	14123H	PARTICIPANT	\N	PRESENT	0
205874	205693	11043H	PARTICIPANT	\N	PRESENT	0
205875	205693	11104D	PARTICIPANT	\N	PRESENT	0
205876	205693	04018C	PARTICIPANT	\N	PRESENT	0
205877	205693	19621T	PARTICIPANT	\N	PRESENT	0
205878	205672	11067R	PARTICIPANT	\N	PRESENT	0
205879	205672	11077T	PARTICIPANT	\N	PRESENT	0
205880	205672	11097X	PARTICIPANT	\N	PRESENT	0
205881	205672	19675J	PARTICIPANT	\N	PRESENT	0
205882	205672	19553Y	PARTICIPANT	\N	PRESENT	0
205883	205672	19679N	PARTICIPANT	\N	PRESENT	0
205884	205672	14042U	PARTICIPANT	\N	PRESENT	0
205885	205672	08048B	PARTICIPANT	\N	PRESENT	0
205886	205672	14261S	PARTICIPANT	\N	PRESENT	0
205887	205672	19335Q	PARTICIPANT	\N	PRESENT	0
205888	205672	19683J	PARTICIPANT	\N	PRESENT	0
205889	205672	10006L	PARTICIPANT	\N	PRESENT	0
205890	205672	98024R	PARTICIPANT	\N	PRESENT	0
205891	205672	19521Q	PARTICIPANT	\N	PRESENT	0
205892	205672	19527W	PARTICIPANT	\N	PRESENT	0
205893	205672	04092N	PRESIDENT	0	PRESENT	0
205894	205672	08052W	PARTICIPANT	\N	PRESENT	0
205895	205672	19663E	PARTICIPANT	\N	PRESENT	0
205896	205672	19691J	PARTICIPANT	\N	PRESENT	0
205897	205672	14119M	PARTICIPANT	\N	PRESENT	0
205898	205672	14071N	PARTICIPANT	\N	PRESENT	0
205899	205672	19697Q	PARTICIPANT	\N	PRESENT	0
205900	205672	14355X	PARTICIPANT	\N	PRESENT	0
205901	205672	19569H	PARTICIPANT	\N	PRESENT	0
205902	205672	19415P	PARTICIPANT	\N	PRESENT	0
205903	205672	14223L	PARTICIPANT	\N	PRESENT	0
205904	205672	04045F	PARTICIPANT	\N	PRESENT	0
205905	205672	14026U	PARTICIPANT	\N	PRESENT	0
205906	205672	14227Q	PARTICIPANT	\N	PRESENT	0
205907	205672	11063M	PARTICIPANT	\N	PRESENT	0
205908	205672	17779H	PARTICIPANT	\N	PRESENT	0
205909	205672	19703U	PARTICIPANT	\N	PRESENT	0
205910	205672	14239U	PARTICIPANT	\N	PRESENT	0
205911	205672	11031D	PARTICIPANT	\N	PRESENT	0
205912	205672	14087W	PARTICIPANT	\N	PRESENT	0
205913	205672	14281W	PARTICIPANT	\N	PRESENT	0
205914	205672	19575F	PARTICIPANT	\N	PRESENT	0
205915	205672	14195A	PARTICIPANT	\N	PRESENT	0
169043	168848	11084S	PARTICIPANT	\N	PRESENT	0
169095	169094	04040A	PRESIDENT	0	PRESENT	0
169488	169094	14051J	PARTICIPANT	\N	PRESENT	0
169499	169094	08010L	PARTICIPANT	\N	PRESENT	0
175753	175752	11039M	PARTICIPANT	\N	PRESENT	0
169702	169094	11037K	PARTICIPANT	\N	PRESENT	0
169761	169094	11101A	PARTICIPANT	\N	PRESENT	0
169821	169094	95063L	PARTICIPANT	\N	PRESENT	0
170555	170554	08012N	PARTICIPANT	\N	PRESENT	0
170556	170554	14073Q	PARTICIPANT	\N	PRESENT	0
170557	170554	11043H	PARTICIPANT	\N	PRESENT	0
170558	170554	14241N	PARTICIPANT	\N	PRESENT	0
170559	170554	87003B	PARTICIPANT	\N	PRESENT	0
170563	170562	11043H	PARTICIPANT	\N	PRESENT	0
170564	170562	14199E	PARTICIPANT	\N	PRESENT	0
170565	170562	14073Q	PARTICIPANT	\N	PRESENT	0
170566	170562	08012N	PARTICIPANT	\N	PRESENT	0
170568	170567	11029K	PARTICIPANT	\N	PRESENT	0
170569	170567	14038Y	PARTICIPANT	\N	PRESENT	0
170570	170567	14209N	PARTICIPANT	\N	PRESENT	0
170571	170567	14042U	PARTICIPANT	\N	PRESENT	0
170572	170567	11083R	PARTICIPANT	\N	PRESENT	0
170573	170567	14179A	PARTICIPANT	\N	PRESENT	0
170574	170567	04041B	PARTICIPANT	\N	PRESENT	0
170575	170567	14241N	PARTICIPANT	\N	PRESENT	0
170576	170567	11026G	PARTICIPANT	\N	PRESENT	0
170577	170567	08039A	PARTICIPANT	\N	PRESENT	0
170578	170567	04057K	PARTICIPANT	\N	PRESENT	0
170579	170567	04070G	PARTICIPANT	\N	PRESENT	0
179049	177614	14065Q	PARTICIPANT	\N	PRESENT	0
179050	177614	11026G	PARTICIPANT	\N	PRESENT	0
179051	177614	14001X	PARTICIPANT	\N	PRESENT	0
179052	177614	01024M	PARTICIPANT	\N	PRESENT	0
179053	177614	04038G	PARTICIPANT	\N	PRESENT	0
179054	177614	01028R	PARTICIPANT	\N	PRESENT	0
179055	177614	04085P	PARTICIPANT	\N	PRESENT	0
179056	177614	05008E	PRESIDENT	0	PRESENT	0
179057	177614	11056N	PARTICIPANT	\N	PRESENT	0
179058	177614	95063L	PARTICIPANT	\N	PRESENT	0
179059	177614	04074L	PARTICIPANT	\N	PRESENT	0
179060	177614	92045V	PARTICIPANT	\N	PRESENT	0
179061	177614	08025T	PARTICIPANT	\N	PRESENT	0
179062	177614	11037K	PARTICIPANT	\N	PRESENT	0
179063	177614	04056J	PARTICIPANT	\N	PRESENT	0
179064	177614	08044W	PARTICIPANT	\N	PRESENT	0
179065	177614	14147R	PARTICIPANT	\N	PRESENT	0
179066	177614	11084S	PARTICIPANT	\N	PRESENT	0
179067	177614	11049P	PARTICIPANT	\N	PRESENT	0
206682	206514	19663E	PARTICIPANT	\N	PRESENT	0
206683	206514	14033T	PARTICIPANT	\N	PRESENT	0
206684	206514	19467C	PARTICIPANT	\N	PRESENT	0
206685	206514	19507S	PARTICIPANT	\N	PRESENT	0
206686	206514	14038Y	PARTICIPANT	\N	PRESENT	0
206687	206514	19447X	PARTICIPANT	\N	PRESENT	0
206688	206514	19677L	PARTICIPANT	\N	PRESENT	0
206689	206514	19415P	PARTICIPANT	\N	PRESENT	0
206690	206514	14119M	PARTICIPANT	\N	PRESENT	0
175754	175752	98042T	PARTICIPANT	\N	PRESENT	0
175755	175752	01019Q	PARTICIPANT	\N	PRESENT	0
178992	176294	14327T	PARTICIPANT	\N	PRESENT	0
178993	176294	04071H	PARTICIPANT	\N	PRESENT	0
178994	176294	01048V	PARTICIPANT	\N	PRESENT	0
178995	176294	04034C	PARTICIPANT	\N	PRESENT	0
178996	176294	01057W	PARTICIPANT	\N	PRESENT	0
178997	176294	89017R	PARTICIPANT	\N	PRESENT	0
178998	176294	11068S	PARTICIPANT	\N	PRESENT	0
178999	176294	14085U	PARTICIPANT	\N	PRESENT	0
179000	176294	96004D	PARTICIPANT	\N	PRESENT	0
179001	176294	08061X	PARTICIPANT	\N	PRESENT	0
179002	176294	08022Q	PARTICIPANT	\N	PRESENT	0
179003	176294	01031L	PRESIDENT	0	PRESENT	0
179004	176294	14175V	PARTICIPANT	\N	PRESENT	0
179005	176294	11048N	PARTICIPANT	\N	PRESENT	0
179006	176294	08034U	PARTICIPANT	\N	PRESENT	0
179007	176294	01016M	PARTICIPANT	\N	PRESENT	0
179008	176294	08011M	PARTICIPANT	\N	PRESENT	0
179009	176294	14159V	PARTICIPANT	\N	PRESENT	0
179010	176294	14173T	PARTICIPANT	\N	PRESENT	0
179011	176294	04086Q	PARTICIPANT	\N	PRESENT	0
179012	176294	11040E	PARTICIPANT	\N	PRESENT	0
179013	176294	14083S	PARTICIPANT	\N	PRESENT	0
179014	176294	11057P	PARTICIPANT	\N	PRESENT	0
179015	176294	11012A	PARTICIPANT	\N	PRESENT	0
179016	176294	98046X	PARTICIPANT	\N	PRESENT	0
179017	176294	11083R	PARTICIPANT	\N	PRESENT	0
179018	176294	99004R	PARTICIPANT	\N	PRESENT	0
179019	176294	04055H	PARTICIPANT	\N	PRESENT	0
179020	176294	04061F	PARTICIPANT	\N	PRESENT	0
179021	176294	01013J	PARTICIPANT	\N	PRESENT	0
179022	176294	11042G	PARTICIPANT	\N	PRESENT	0
179023	176294	07029T	PARTICIPANT	\N	EXCUSE	0
179024	176294	08010L	PARTICIPANT	\N	EXCUSE	0
179025	176294	11085T	PARTICIPANT	\N	EXCUSE	0
179026	176294	01027Q	PARTICIPANT	\N	EXCUSE	0
206691	206514	14133K	PARTICIPANT	\N	PRESENT	0
206692	206514	14169X	PARTICIPANT	\N	PRESENT	0
206693	206514	14031R	PARTICIPANT	\N	PRESENT	0
206694	206514	19673G	PARTICIPANT	\N	PRESENT	0
206695	206514	19573D	PARTICIPANT	\N	PRESENT	0
206696	206514	14021P	PARTICIPANT	\N	PRESENT	0
206697	206514	19399H	PARTICIPANT	\N	PRESENT	0
206698	206514	14105F	PARTICIPANT	\N	PRESENT	0
206699	206514	19731Y	PARTICIPANT	\N	PRESENT	0
206700	206514	14079W	PARTICIPANT	\N	PRESENT	0
206701	206514	11101A	PARTICIPANT	\N	PRESENT	0
206702	206514	14257W	PARTICIPANT	\N	PRESENT	0
206703	206514	14187A	PARTICIPANT	\N	PRESENT	0
206704	206514	10006L	PARTICIPANT	\N	PRESENT	0
206705	206514	08068F	PARTICIPANT	\N	PRESENT	0
206706	206514	11067R	PARTICIPANT	\N	PRESENT	0
206707	206514	14327T	PARTICIPANT	\N	PRESENT	0
206708	206514	08062Y	PARTICIPANT	\N	PRESENT	0
206709	206514	19329S	PARTICIPANT	\N	PRESENT	0
206710	206514	87003B	PARTICIPANT	\N	PRESENT	0
206711	206514	14063N	PARTICIPANT	\N	PRESENT	0
206712	206514	19721W	PARTICIPANT	\N	PRESENT	0
206713	206514	19619A	PARTICIPANT	\N	PRESENT	0
206714	206514	14107H	PARTICIPANT	\N	PRESENT	0
206715	206514	19637C	PARTICIPANT	\N	PRESENT	0
206716	206514	14109K	PARTICIPANT	\N	PRESENT	0
206717	206514	19577H	PARTICIPANT	\N	PRESENT	0
206718	206514	08016S	PARTICIPANT	\N	PRESENT	0
206719	206514	04085P	PARTICIPANT	\N	PRESENT	0
206720	206514	14059S	PARTICIPANT	\N	PRESENT	0
206721	206514	08034U	PARTICIPANT	\N	PRESENT	0
206722	206514	08019V	PARTICIPANT	\N	PRESENT	0
206723	206514	14069U	PARTICIPANT	\N	PRESENT	0
206724	206514	14259Y	PARTICIPANT	\N	PRESENT	0
206725	206514	11033F	PARTICIPANT	\N	PRESENT	0
206726	206514	14179A	PARTICIPANT	\N	PRESENT	0
206728	206514	19525U	PARTICIPANT	\N	PRESENT	0
206731	206514	14029X	PARTICIPANT	\N	PRESENT	0
206733	206514	14115H	PARTICIPANT	\N	PRESENT	0
206734	206514	14123H	PARTICIPANT	\N	PRESENT	0
206735	206514	16685X	PARTICIPANT	\N	PRESENT	0
206736	206514	19511N	PARTICIPANT	\N	PRESENT	0
206737	206514	19581D	PARTICIPANT	\N	PRESENT	0
206738	206514	11066Q	PARTICIPANT	\N	PRESENT	0
206739	206514	11027H	PARTICIPANT	\N	PRESENT	0
206740	206514	08044W	PARTICIPANT	\N	PRESENT	0
206741	206514	04033B	PARTICIPANT	\N	PRESENT	0
206742	206514	14028W	PARTICIPANT	\N	PRESENT	0
206743	206514	19643A	PARTICIPANT	\N	PRESENT	0
206744	206514	14199E	PARTICIPANT	\N	PRESENT	0
206745	206514	14053L	PARTICIPANT	\N	PRESENT	0
206746	206514	14211G	PARTICIPANT	\N	PRESENT	0
208522	208520	04043D	PARTICIPANT	\N	PRESENT	0
208525	208524	14215L	PARTICIPANT	\N	PRESENT	0
208703	208061	08053X	PARTICIPANT	\N	PRESENT	0
208527	208524	14179A	PARTICIPANT	\N	PRESENT	0
208529	208528	14215L	PARTICIPANT	\N	PRESENT	0
208531	208528	95015C	PARTICIPANT	\N	PRESENT	0
208702	207682	04086Q	PARTICIPANT	\N	PRESENT	0
208704	207682	14213J	PARTICIPANT	\N	PRESENT	0
208705	207682	01060R	PARTICIPANT	\N	PRESENT	0
208706	207682	19685L	PARTICIPANT	\N	PRESENT	0
208707	207682	08019V	PARTICIPANT	\N	PRESENT	0
208709	208708	14231L	PARTICIPANT	\N	PRESENT	0
208710	208708	11081P	PARTICIPANT	\N	PRESENT	0
208711	207682	11026G	PARTICIPANT	\N	PRESENT	0
208712	207682	14042U	PARTICIPANT	\N	PRESENT	0
208713	207682	19731Y	PARTICIPANT	\N	PRESENT	0
208714	207682	14173T	PARTICIPANT	\N	PRESENT	0
208715	207682	80027E	PARTICIPANT	\N	PRESENT	0
208716	207682	11101A	PARTICIPANT	\N	PRESENT	0
208717	207682	14073Q	PARTICIPANT	\N	PRESENT	0
208718	207682	14069U	PARTICIPANT	\N	PRESENT	0
208719	207682	17583W	PARTICIPANT	\N	PRESENT	0
208720	207682	14055N	PARTICIPANT	\N	PRESENT	0
182373	182372	04061F	PARTICIPANT	\N	PRESENT	0
182374	182372	88008L	PARTICIPANT	\N	PRESENT	0
182393	182392	11088W	PARTICIPANT	\N	PRESENT	0
182395	182394	89017R	PARTICIPANT	\N	PRESENT	0
182397	182396	89017R	PARTICIPANT	\N	PRESENT	0
182399	182398	89017R	PARTICIPANT	\N	PRESENT	0
182401	182400	14175V	PARTICIPANT	\N	PRESENT	0
182402	182400	14085U	PARTICIPANT	\N	PRESENT	0
182404	182403	14175V	PARTICIPANT	\N	PRESENT	0
182405	182403	14085U	PARTICIPANT	\N	PRESENT	0
182413	182412	05008E	PARTICIPANT	\N	PRESENT	0
182414	182412	14065Q	PARTICIPANT	\N	PRESENT	0
182415	182412	01024M	PARTICIPANT	\N	PRESENT	0
182417	182416	05008E	PARTICIPANT	\N	PRESENT	0
182418	182416	14065Q	PARTICIPANT	\N	PRESENT	0
182419	182416	01024M	PARTICIPANT	\N	PRESENT	0
182420	170092	05008E	PARTICIPANT	\N	PRESENT	0
182473	182472	14071N	PARTICIPANT	\N	PRESENT	0
182673	182672	14089Y	PARTICIPANT	\N	PRESENT	0
182674	182672	14031R	PARTICIPANT	\N	PRESENT	0
182675	182672	14229S	PRESIDENT	0	PRESENT	0
182676	182672	04050C	PARTICIPANT	\N	PRESENT	0
182677	182672	14207L	PARTICIPANT	\N	EXCUSE	0
182678	182672	14087W	PARTICIPANT	\N	EXCUSE	0
182679	182672	11061K	PARTICIPANT	\N	EXCUSE	0
182680	182672	11029K	PARTICIPANT	\N	EXCUSE	0
182681	182672	11014C	PARTICIPANT	\N	EXCUSE	0
182693	182692	08011M	PARTICIPANT	\N	PRESENT	0
182694	182692	11070L	PARTICIPANT	\N	PRESENT	0
182695	182692	11083R	PARTICIPANT	\N	PRESENT	0
182696	182692	14159V	PARTICIPANT	\N	PRESENT	0
182698	182697	08011M	PARTICIPANT	\N	PRESENT	0
182699	182697	14159V	PARTICIPANT	\N	PRESENT	0
182701	182700	08011M	PARTICIPANT	\N	PRESENT	0
182702	182700	11048N	PARTICIPANT	\N	PRESENT	0
182893	182892	14133K	PARTICIPANT	\N	PRESENT	0
182894	182892	96004D	PRESIDENT	0	PRESENT	0
182895	182892	14089Y	PARTICIPANT	\N	PRESENT	0
182896	182892	14079W	PARTICIPANT	\N	PRESENT	0
182897	182892	95030B	PARTICIPANT	\N	PRESENT	0
182898	182892	04035D	PARTICIPANT	\N	EXCUSE	0
182899	182892	11083R	PARTICIPANT	\N	PRESENT	0
182900	182892	14026U	PARTICIPANT	\N	EXCUSE	0
182901	182892	14097Y	PARTICIPANT	\N	PRESENT	0
182902	182892	04061F	PARTICIPANT	\N	PRESENT	0
182903	182892	98046X	PARTICIPANT	\N	EXCUSE	0
182904	182892	14001X	PARTICIPANT	\N	EXCUSE	0
182905	182892	04057K	PARTICIPANT	\N	PRESENT	0
182906	182892	08042U	PARTICIPANT	\N	PRESENT	0
182907	182892	14135M	PARTICIPANT	\N	PRESENT	0
182908	182892	01016M	PARTICIPANT	\N	PRESENT	0
182909	182892	11012A	PARTICIPANT	\N	PRESENT	0
182910	182892	95063L	PARTICIPANT	\N	PRESENT	0
182911	182892	04045F	PARTICIPANT	\N	PRESENT	0
182912	182892	98035U	PARTICIPANT	\N	PRESENT	0
182913	182892	92045V	PARTICIPANT	\N	EXCUSE	0
182914	182892	04034C	PARTICIPANT	\N	PRESENT	0
182915	182892	95059Q	PARTICIPANT	\N	PRESENT	0
182916	182892	14175V	PARTICIPANT	\N	PRESENT	0
182917	182892	11036J	PARTICIPANT	\N	PRESENT	0
182918	182892	08052W	PARTICIPANT	\N	PRESENT	0
182919	182892	14357A	PARTICIPANT	\N	PRESENT	0
182920	182892	14209N	PARTICIPANT	\N	PRESENT	0
182951	182946	99004R	PARTICIPANT	\N	PRESENT	0
182952	182946	04038G	PARTICIPANT	\N	PRESENT	0
182953	182946	02002K	PARTICIPANT	\N	PRESENT	0
182954	182946	14179A	PARTICIPANT	\N	PRESENT	0
183033	183032	99004R	PARTICIPANT	\N	PRESENT	0
183233	183232	04080J	PARTICIPANT	\N	PRESENT	0
183235	183234	04080J	PARTICIPANT	\N	PRESENT	0
183593	183592	14133K	PARTICIPANT	\N	PRESENT	0
183594	183592	04054G	PARTICIPANT	\N	PRESENT	0
183595	183592	04047H	PARTICIPANT	\N	PRESENT	0
183596	183592	14097Y	PARTICIPANT	\N	PRESENT	0
183597	183592	11084S	PARTICIPANT	\N	PRESENT	0
183598	183592	14073Q	PARTICIPANT	\N	PRESENT	0
183599	183592	92031P	PARTICIPANT	\N	PRESENT	0
183600	183592	14001X	PARTICIPANT	\N	PRESENT	0
183601	183592	11012A	PARTICIPANT	\N	PRESENT	0
183602	183592	14227Q	PARTICIPANT	\N	PRESENT	0
183603	183592	11066Q	PARTICIPANT	\N	PRESENT	0
183604	183592	95067Q	PARTICIPANT	\N	PRESENT	0
183653	183652	14042U	PARTICIPANT	\N	PRESENT	0
183654	183652	01011G	PARTICIPANT	\N	PRESENT	0
183656	183655	14063N	PARTICIPANT	\N	PRESENT	0
183657	183655	08034U	PARTICIPANT	\N	PRESENT	0
183658	183655	14235Q	PARTICIPANT	\N	PRESENT	0
183659	183655	11043H	PARTICIPANT	\N	PRESENT	0
189353	189352	14215L	PARTICIPANT	\N	PRESENT	0
190392	190249	04045F	PARTICIPANT	\N	PRESENT	0
190393	188952	01027Q	PARTICIPANT	\N	PRESENT	0
190394	188952	11010L	PARTICIPANT	\N	EXCUSE	0
190395	188952	11025F	PARTICIPANT	\N	PRESENT	0
190396	188952	11054L	PARTICIPANT	\N	PRESENT	0
190397	188952	04043D	PARTICIPANT	\N	PRESENT	0
190398	188952	08019V	PRESIDENT	0	PRESENT	0
190399	188952	14059S	PARTICIPANT	\N	PRESENT	0
190400	188952	11023D	PARTICIPANT	\N	PRESENT	0
204392	202913	11034G	PARTICIPANT	\N	PRESENT	0
204393	202913	01047U	PARTICIPANT	\N	PRESENT	0
204394	202913	14001X	PARTICIPANT	\N	PRESENT	0
204395	202913	04044E	PARTICIPANT	\N	PRESENT	0
204396	202913	04047H	PARTICIPANT	\N	PRESENT	0
204397	202913	01028R	PARTICIPANT	\N	PRESENT	0
204398	202913	04079R	PARTICIPANT	\N	PRESENT	0
204399	202913	14041T	PARTICIPANT	\N	PRESENT	0
204400	202913	14215L	PARTICIPANT	\N	PRESENT	0
204401	202913	14259Y	PARTICIPANT	\N	PRESENT	0
204402	202913	98035U	PARTICIPANT	\N	PRESENT	0
204403	202913	14111D	PARTICIPANT	\N	PRESENT	0
204404	202913	95067Q	PARTICIPANT	\N	PRESENT	0
204405	202913	11010L	PARTICIPANT	\N	PRESENT	0
204406	202913	07034Q	PARTICIPANT	\N	PRESENT	0
204407	202913	11026G	PARTICIPANT	\N	PRESENT	0
204408	202913	19253P	PARTICIPANT	\N	PRESENT	0
204409	202913	01024M	PARTICIPANT	\N	PRESENT	0
204410	202913	19251M	PARTICIPANT	\N	PRESENT	0
204411	202913	04038G	PARTICIPANT	\N	PRESENT	0
204412	202913	16813M	PARTICIPANT	\N	PRESENT	0
204413	202913	11033F	PARTICIPANT	\N	PRESENT	0
204414	202913	04085P	PARTICIPANT	\N	PRESENT	0
204415	202913	14089Y	PARTICIPANT	\N	PRESENT	0
204416	202913	95063L	PARTICIPANT	\N	PRESENT	0
204417	202913	04074L	PARTICIPANT	\N	PRESENT	0
204418	202913	11037K	PARTICIPANT	\N	PRESENT	0
204419	202913	04056J	PARTICIPANT	\N	PRESENT	0
204420	202913	14069U	PARTICIPANT	\N	PRESENT	0
204421	202913	11084S	PARTICIPANT	\N	PRESENT	0
204422	202913	95049N	PARTICIPANT	\N	PRESENT	0
204423	202915	11034G	PARTICIPANT	\N	PRESENT	0
204424	202915	01047U	PARTICIPANT	\N	PRESENT	0
204425	202915	14001X	PARTICIPANT	\N	PRESENT	0
204426	202915	04044E	PARTICIPANT	\N	PRESENT	0
204427	202915	04047H	PARTICIPANT	\N	PRESENT	0
204428	202915	01028R	PARTICIPANT	\N	PRESENT	0
204429	202915	04079R	PARTICIPANT	\N	PRESENT	0
204430	202915	14041T	PARTICIPANT	\N	PRESENT	0
204431	202915	14215L	PARTICIPANT	\N	PRESENT	0
204432	202915	14259Y	PARTICIPANT	\N	PRESENT	0
204433	202915	98035U	PARTICIPANT	\N	PRESENT	0
204434	202915	14111D	PARTICIPANT	\N	PRESENT	0
204435	202915	95067Q	PARTICIPANT	\N	PRESENT	0
204436	202915	11010L	PARTICIPANT	\N	PRESENT	0
204437	202915	07034Q	PARTICIPANT	\N	PRESENT	0
204438	202915	11026G	PARTICIPANT	\N	PRESENT	0
204439	202915	19253P	PARTICIPANT	\N	PRESENT	0
204440	202915	01024M	PARTICIPANT	\N	PRESENT	0
204441	202915	19251M	PARTICIPANT	\N	PRESENT	0
204442	202915	04038G	PARTICIPANT	\N	PRESENT	0
204443	202915	16813M	PARTICIPANT	\N	PRESENT	0
204444	202915	11033F	PARTICIPANT	\N	PRESENT	0
204445	202915	04085P	PARTICIPANT	\N	PRESENT	0
204446	202915	14089Y	PARTICIPANT	\N	PRESENT	0
204447	202915	95063L	PARTICIPANT	\N	PRESENT	0
204448	202915	04074L	PARTICIPANT	\N	PRESENT	0
204449	202915	11037K	PARTICIPANT	\N	PRESENT	0
204450	202915	04056J	PARTICIPANT	\N	PRESENT	0
204451	202915	14069U	PARTICIPANT	\N	PRESENT	0
204452	202915	11084S	PARTICIPANT	\N	PRESENT	0
204453	202915	95049N	PARTICIPANT	\N	PRESENT	0
204454	202915	92045V	PARTICIPANT	\N	EXCUSE	0
204455	202913	92045V	PARTICIPANT	\N	EXCUSE	0
204472	190807	08024S	PARTICIPANT	\N	PRESENT	0
204492	190807	14219Q	PARTICIPANT	\N	PRESENT	0
204493	190807	19253P	PARTICIPANT	\N	PRESENT	0
204494	190807	18127E	PARTICIPANT	\N	PRESENT	0
204495	190807	11066Q	PARTICIPANT	\N	PRESENT	0
204496	190807	14157T	PARTICIPANT	\N	PRESENT	0
204497	190807	04088S	PARTICIPANT	\N	PRESENT	0
165793	165792	08025T	PARTICIPANT	\N	PRESENT	0
165794	165792	04085P	PARTICIPANT	\N	PRESENT	0
165735	165686	14235Q	PARTICIPANT	\N	PRESENT	0
165795	165792	05008E	PRESIDENT	0	PRESENT	0
165737	165686	04033B	PARTICIPANT	\N	PRESENT	0
165738	165686	14361V	PARTICIPANT	\N	PRESENT	0
165739	165686	14229S	PARTICIPANT	\N	PRESENT	0
165740	165686	14363X	PARTICIPANT	\N	PRESENT	0
165741	165686	11043H	PARTICIPANT	\N	EXCUSE	0
165796	165792	11030C	PARTICIPANT	\N	PRESENT	0
165743	165686	11011M	PARTICIPANT	\N	PRESENT	0
165797	165792	11033F	PARTICIPANT	\N	PRESENT	0
165798	165792	14065Q	PARTICIPANT	\N	PRESENT	0
165799	165792	14069U	PARTICIPANT	\N	PRESENT	0
165800	165792	04047H	PARTICIPANT	\N	PRESENT	0
165801	165792	11032E	PARTICIPANT	\N	PRESENT	0
165802	165792	04038G	PARTICIPANT	\N	PRESENT	0
165803	165792	11056N	PARTICIPANT	\N	PRESENT	0
165804	165792	14259Y	PARTICIPANT	\N	PRESENT	0
165805	165792	11035H	PARTICIPANT	\N	PRESENT	0
165806	165792	14041T	PARTICIPANT	\N	PRESENT	0
165807	165792	01024M	PARTICIPANT	\N	PRESENT	0
165808	165792	11034G	PARTICIPANT	\N	PRESENT	0
165809	165792	08018U	PARTICIPANT	\N	PRESENT	0
165810	165792	01007L	PARTICIPANT	\N	PRESENT	0
165811	165792	11049P	PARTICIPANT	\N	PRESENT	0
165812	165792	08044W	PARTICIPANT	\N	EXCUSE	0
165813	165792	11084S	PARTICIPANT	\N	EXCUSE	0
165814	165792	11026G	PARTICIPANT	\N	PRESENT	0
165815	165792	04079R	PARTICIPANT	\N	PRESENT	0
165816	165792	14111D	PARTICIPANT	\N	PRESENT	0
165817	165792	14001X	PARTICIPANT	\N	PRESENT	0
165818	165792	14147R	PARTICIPANT	\N	PRESENT	0
165819	165792	08051V	PARTICIPANT	\N	PRESENT	0
165820	165792	07034Q	PARTICIPANT	\N	PRESENT	0
165821	165792	04074L	PARTICIPANT	\N	PRESENT	0
165822	165792	10015M	PARTICIPANT	\N	PRESENT	0
165823	165792	95063L	PARTICIPANT	\N	PRESENT	0
165824	165792	01019Q	PARTICIPANT	\N	PRESENT	0
165825	165792	01028R	PARTICIPANT	\N	PRESENT	0
165826	165792	98035U	PARTICIPANT	\N	PRESENT	0
165827	165792	04056J	PARTICIPANT	\N	PRESENT	0
165828	165792	04044E	PRESIDENT	1	PRESENT	0
165829	165792	92045V	PARTICIPANT	\N	PRESENT	0
165830	165792	95067Q	PARTICIPANT	\N	PRESENT	0
165831	165792	01047U	PARTICIPANT	\N	PRESENT	0
170795	170792	14073Q	PARTICIPANT	\N	PRESENT	0
170796	170792	11026G	PARTICIPANT	\N	PRESENT	0
170797	170792	14079W	PARTICIPANT	\N	PRESENT	0
170798	170792	14267Y	PARTICIPANT	\N	PRESENT	0
173086	167024	08016S	PARTICIPANT	\N	PRESENT	0
173087	167024	14363X	PARTICIPANT	\N	PRESENT	0
173088	167024	11057P	PARTICIPANT	\N	PRESENT	0
173089	167024	14123H	PARTICIPANT	\N	PRESENT	0
173090	167024	14227Q	PARTICIPANT	\N	PRESENT	0
173091	167024	07034Q	PARTICIPANT	\N	PRESENT	0
173092	167024	01015L	PARTICIPANT	\N	PRESENT	0
173093	167024	08022Q	PARTICIPANT	\N	PRESENT	0
173094	167024	04034C	PARTICIPANT	\N	PRESENT	0
173095	167024	04055H	PARTICIPANT	\N	PRESENT	0
173096	167024	80027E	PARTICIPANT	\N	PRESENT	0
173097	167024	11043H	PARTICIPANT	\N	PRESENT	0
173098	167024	14028W	PARTICIPANT	\N	PRESENT	0
173099	167024	08053X	PARTICIPANT	\N	PRESENT	0
173100	167024	04049K	PARTICIPANT	\N	PRESENT	0
173101	167024	11074Q	PARTICIPANT	\N	PRESENT	0
173102	167024	95063L	PARTICIPANT	\N	PRESENT	0
173103	167024	08052W	PARTICIPANT	\N	PRESENT	0
173104	167024	01016M	PARTICIPANT	\N	PRESENT	0
173105	167024	98035U	PARTICIPANT	\N	PRESENT	0
173106	167024	14053L	PARTICIPANT	\N	PRESENT	0
173107	167024	98046X	PARTICIPANT	\N	PRESENT	0
173108	167024	14217N	PARTICIPANT	\N	PRESENT	0
173109	167024	11103C	PARTICIPANT	\N	PRESENT	0
173110	167024	98018T	PARTICIPANT	\N	PRESENT	0
173111	167024	14093U	PARTICIPANT	\N	PRESENT	0
173112	167024	14037X	PARTICIPANT	\N	PRESENT	0
173113	167024	11097X	PARTICIPANT	\N	PRESENT	0
173114	167024	08055A	PARTICIPANT	\N	PRESENT	0
173115	167024	04043D	PARTICIPANT	\N	PRESENT	0
173116	167024	92020L	PARTICIPANT	\N	PRESENT	0
173117	167024	08043V	PARTICIPANT	\N	PRESENT	0
173118	167024	11014C	PARTICIPANT	\N	PRESENT	0
173119	167024	14061L	PARTICIPANT	\N	PRESENT	0
173120	167024	08068F	PARTICIPANT	\N	PRESENT	0
173121	167024	08034U	PARTICIPANT	\N	PRESENT	0
173122	167024	08017T	PARTICIPANT	\N	PRESENT	0
173123	167024	04088S	PARTICIPANT	\N	PRESENT	0
173124	167024	14107H	PARTICIPANT	\N	PRESENT	0
173125	167024	04092N	PARTICIPANT	\N	PRESENT	0
173126	167024	14001X	PARTICIPANT	\N	PRESENT	0
173127	167024	01031L	PARTICIPANT	\N	PRESENT	0
173128	167024	14051J	PARTICIPANT	\N	PRESENT	0
173129	167024	08014Q	PARTICIPANT	\N	PRESENT	0
173130	167024	14249W	PARTICIPANT	\N	PRESENT	0
173131	167024	01008M	PARTICIPANT	\N	PRESENT	0
173132	167024	14281W	PARTICIPANT	\N	PRESENT	0
173133	167024	14133K	PARTICIPANT	\N	PRESENT	0
173134	167024	14329V	PARTICIPANT	\N	PRESENT	0
173135	167024	14209N	PARTICIPANT	\N	PRESENT	0
173136	167024	14097Y	PARTICIPANT	\N	PRESENT	0
173137	167024	14081Q	PARTICIPANT	\N	PRESENT	0
173138	167024	14355X	PARTICIPANT	\N	PRESENT	0
173139	167024	14265W	PARTICIPANT	\N	PRESENT	0
173140	167024	12042Y	PARTICIPANT	\N	PRESENT	0
173141	167024	11112D	PARTICIPANT	\N	PRESENT	0
173142	167024	14063N	PARTICIPANT	\N	PRESENT	0
173143	167024	11037K	PARTICIPANT	\N	PRESENT	0
173144	167024	14213J	PARTICIPANT	\N	PRESENT	0
173145	167024	04053F	PARTICIPANT	\N	PRESENT	0
170793	170792	11012A	PARTICIPANT	\N	PRESENT	0
170794	170792	04047H	PARTICIPANT	\N	PRESENT	0
173146	167024	04042C	PARTICIPANT	\N	PRESENT	0
173147	167024	11032E	PARTICIPANT	\N	PRESENT	0
173148	167024	01014K	PARTICIPANT	\N	PRESENT	0
173149	167024	11067R	PARTICIPANT	\N	PRESENT	0
173150	167024	14085U	PARTICIPANT	\N	PRESENT	0
173152	167024	11066Q	PARTICIPANT	\N	PRESENT	0
173156	167024	13002U	PARTICIPANT	\N	PRESENT	0
173157	167024	11029K	PARTICIPANT	\N	PRESENT	0
173158	167024	08024S	PARTICIPANT	\N	PRESENT	0
173159	167024	11083R	PARTICIPANT	\N	PRESENT	0
173160	167024	14225N	PARTICIPANT	\N	PRESENT	0
173161	167024	14159V	PARTICIPANT	\N	PRESENT	0
173162	167024	14269B	PARTICIPANT	\N	PRESENT	0
173163	167024	11023D	PARTICIPANT	\N	PRESENT	0
173164	167024	14239U	PARTICIPANT	\N	PRESENT	0
173165	167024	14205J	PARTICIPANT	\N	PRESENT	0
173166	167024	14103D	PARTICIPANT	\N	PRESENT	0
173167	167024	14267Y	PARTICIPANT	\N	PRESENT	0
173168	167024	14219Q	PARTICIPANT	\N	PRESENT	0
173169	167024	14201E	PARTICIPANT	\N	PRESENT	0
173170	167024	11070L	PARTICIPANT	\N	PRESENT	0
173171	167024	14089Y	PARTICIPANT	\N	PRESENT	0
173172	167024	04067M	PARTICIPANT	\N	PRESENT	0
173173	167024	14119M	PARTICIPANT	\N	PRESENT	0
173174	167024	11053K	PARTICIPANT	\N	PRESENT	0
173175	167024	01034P	PARTICIPANT	\N	PRESENT	0
173176	167024	14253S	PARTICIPANT	\N	PRESENT	0
173177	167024	11081P	PARTICIPANT	\N	PRESENT	0
173178	167024	11012A	PARTICIPANT	\N	PRESENT	0
182253	182252	08011M	PARTICIPANT	\N	PRESENT	0
182254	182252	14083S	PARTICIPANT	\N	PRESENT	0
182255	182252	14085U	PARTICIPANT	\N	PRESENT	0
182256	182252	11042G	PARTICIPANT	\N	PRESENT	0
182257	182252	04086Q	PARTICIPANT	\N	PRESENT	0
182259	182258	14175V	PARTICIPANT	\N	PRESENT	0
182260	182258	14083S	PARTICIPANT	\N	PRESENT	0
182261	182258	14085U	PARTICIPANT	\N	PRESENT	0
182262	182258	11042G	PARTICIPANT	\N	PRESENT	0
182263	182258	04086Q	PARTICIPANT	\N	PRESENT	0
182264	182258	11070L	PARTICIPANT	\N	PRESENT	0
182272	182258	01057W	PARTICIPANT	\N	PRESENT	0
182273	182258	14159V	PARTICIPANT	\N	PRESENT	0
182275	182274	14083S	PARTICIPANT	\N	PRESENT	0
182276	182274	14085U	PARTICIPANT	\N	PRESENT	0
182277	182274	11042G	PARTICIPANT	\N	PRESENT	0
182278	182274	04086Q	PARTICIPANT	\N	PRESENT	0
182279	182274	11070L	PARTICIPANT	\N	PRESENT	0
182280	182274	01057W	PARTICIPANT	\N	PRESENT	0
182281	182274	14159V	PARTICIPANT	\N	PRESENT	0
182283	182282	14083S	PARTICIPANT	\N	PRESENT	0
182284	182282	14085U	PARTICIPANT	\N	PRESENT	0
182285	182282	11042G	PARTICIPANT	\N	PRESENT	0
182286	182282	11070L	PARTICIPANT	\N	PRESENT	0
182287	182282	01057W	PARTICIPANT	\N	PRESENT	0
182288	182282	14159V	PARTICIPANT	\N	PRESENT	0
182519	182518	04047H	PARTICIPANT	\N	PRESENT	0
182520	182518	11012A	PARTICIPANT	\N	PRESENT	0
182521	182518	14073Q	PARTICIPANT	\N	PRESENT	0
182522	182518	14001X	PARTICIPANT	\N	PRESENT	0
182572	182492	08049C	PARTICIPANT	\N	EXCUSE	0
184635	184632	04040A	PARTICIPANT	\N	PRESENT	0
182574	182492	01015L	PARTICIPANT	\N	EXCUSE	0
182575	182492	09001P	PARTICIPANT	\N	EXCUSE	0
182577	182576	14219Q	PRESIDENT	0	PRESENT	0
182578	182576	11065P	PARTICIPANT	\N	PRESENT	0
182579	182576	01056V	PARTICIPANT	\N	PRESENT	0
182581	182580	14219Q	PRESIDENT	0	PRESENT	0
182582	182580	11065P	PARTICIPANT	\N	PRESENT	0
184633	184632	14193X	PARTICIPANT	\N	PRESENT	0
184634	184632	11054L	PARTICIPANT	\N	PRESENT	0
184792	184192	14327T	PARTICIPANT	\N	EXCUSE	0
185433	185432	01008M	PARTICIPANT	\N	PRESENT	0
185434	185432	11036J	PARTICIPANT	\N	PRESENT	0
185472	185432	14001X	PARTICIPANT	\N	PRESENT	0
185436	185432	14013P	PARTICIPANT	\N	PRESENT	0
185437	185432	08068F	PARTICIPANT	\N	PRESENT	0
185438	185432	14207L	PARTICIPANT	\N	PRESENT	0
185473	185432	98046X	PARTICIPANT	\N	PRESENT	0
185474	185432	01016M	PARTICIPANT	\N	PRESENT	0
185475	185432	95030B	PARTICIPANT	\N	PRESENT	0
185476	185432	11083R	PARTICIPANT	\N	PRESENT	0
185443	185432	14357A	PARTICIPANT	\N	PRESENT	0
185477	185432	14073Q	PARTICIPANT	\N	PRESENT	0
185478	185432	96004D	PARTICIPANT	\N	PRESENT	0
185446	185432	14197C	PARTICIPANT	\N	PRESENT	0
185479	185432	14089Y	PARTICIPANT	\N	PRESENT	0
185448	185432	14187A	PARTICIPANT	\N	PRESENT	0
185449	185432	14033T	PARTICIPANT	\N	PRESENT	0
185480	185432	14026U	PARTICIPANT	\N	PRESENT	0
188853	188852	14079W	PARTICIPANT	\N	PRESENT	0
185452	185432	04049K	PARTICIPANT	\N	PRESENT	0
188854	188852	14097Y	PARTICIPANT	\N	PRESENT	0
188855	188852	04045F	PARTICIPANT	\N	PRESENT	0
202914	202913	05008E	PRESIDENT	0	PRESENT	0
185456	185432	11100Y	PRESIDENT	0	PRESENT	0
202916	202915	05008E	PRESIDENT	0	PRESENT	0
185458	185432	11098Y	PARTICIPANT	\N	PRESENT	0
205073	205072	01031L	PARTICIPANT	\N	PRESENT	0
205074	205072	08011M	PARTICIPANT	\N	PRESENT	0
205075	205072	04086Q	PARTICIPANT	\N	PRESENT	0
205076	205072	14173T	PARTICIPANT	\N	PRESENT	0
185463	185432	14257W	PARTICIPANT	\N	PRESENT	0
205077	205072	14225N	PARTICIPANT	\N	PRESENT	0
205078	205072	11057P	PARTICIPANT	\N	PRESENT	0
185466	185432	98050T	PARTICIPANT	\N	PRESENT	0
205079	205072	01013J	PARTICIPANT	\N	PRESENT	0
185468	185432	11046L	PARTICIPANT	\N	PRESENT	0
205916	205672	19367Y	PARTICIPANT	\N	PRESENT	0
205917	205672	14213J	PARTICIPANT	\N	PRESENT	0
185471	185432	11066Q	PARTICIPANT	\N	PRESENT	0
205918	205672	14217N	PARTICIPANT	\N	PRESENT	0
205919	205672	01034P	PRESIDENT	1	PRESENT	0
205920	205672	11045K	PARTICIPANT	\N	PRESENT	0
205921	205672	19715Y	PARTICIPANT	\N	PRESENT	0
205922	205672	19723Y	PARTICIPANT	\N	PRESENT	0
205923	205672	19727D	PARTICIPANT	\N	PRESENT	0
205924	205672	11103C	PARTICIPANT	\N	PRESENT	0
205925	205672	19657G	PARTICIPANT	\N	PRESENT	0
205926	205672	19577H	PARTICIPANT	\N	PRESENT	0
205931	205621	98005N	PARTICIPANT	\N	PRESENT	0
205932	205621	19443T	PARTICIPANT	\N	PRESENT	0
205933	205621	95030B	PARTICIPANT	\N	PRESENT	0
205934	205621	11080N	PARTICIPANT	\N	PRESENT	0
205935	205621	04034C	PARTICIPANT	\N	PRESENT	0
205936	205621	01058X	PARTICIPANT	\N	PRESENT	0
205937	205621	14079W	PARTICIPANT	\N	PRESENT	0
205938	205621	04040A	PARTICIPANT	\N	PRESENT	0
205939	205621	16685X	PARTICIPANT	\N	PRESENT	0
205940	205621	11027H	PARTICIPANT	\N	PRESENT	0
205941	205621	04042C	PRESIDENT	1	PRESENT	0
205942	205621	11054L	PARTICIPANT	\N	PRESENT	0
205943	205621	11066Q	PARTICIPANT	\N	PRESENT	0
205944	205621	19669L	PARTICIPANT	\N	PRESENT	0
205945	205621	08056B	PARTICIPANT	\N	PRESENT	0
205946	205621	11115U	PARTICIPANT	\N	PRESENT	0
205947	205621	95037J	PARTICIPANT	\N	PRESENT	0
205948	205621	19709B	PARTICIPANT	\N	PRESENT	0
205949	205621	14193X	PARTICIPANT	\N	PRESENT	0
205950	205621	08049C	PARTICIPANT	\N	PRESENT	0
205951	205621	08053X	PARTICIPANT	\N	PRESENT	0
205952	205621	97011G	PARTICIPANT	\N	PRESENT	0
205953	205621	08061X	PARTICIPANT	\N	PRESENT	0
205954	205621	08047A	PARTICIPANT	\N	PRESENT	0
205955	205621	98029W	PRESIDENT	0	PRESENT	0
205956	205621	14097Y	PARTICIPANT	\N	PRESENT	0
205957	205621	95067Q	PARTICIPANT	\N	PRESENT	0
205958	205621	14133K	PARTICIPANT	\N	PRESENT	0
205959	205621	01062T	PARTICIPANT	\N	PRESENT	0
205960	205621	11041F	PARTICIPANT	\N	PRESENT	0
205961	205621	14235Q	PARTICIPANT	\N	PRESENT	0
205962	205621	08058D	PARTICIPANT	\N	PRESENT	0
205963	205621	14028W	PARTICIPANT	\N	PRESENT	0
205964	205621	19251M	PARTICIPANT	\N	PRESENT	0
205965	205621	19721W	PARTICIPANT	\N	PRESENT	0
205966	205621	19319Q	PARTICIPANT	\N	PRESENT	0
205967	205621	14105F	PARTICIPANT	\N	PRESENT	0
205968	205621	98018T	PARTICIPANT	\N	PRESENT	0
205969	205621	98022P	PARTICIPANT	\N	PRESENT	0
205970	205621	14267Y	PARTICIPANT	\N	PRESENT	0
205971	205621	11064N	PARTICIPANT	\N	PRESENT	0
205972	205621	98050T	PARTICIPANT	\N	PRESENT	0
205973	205621	98053W	PARTICIPANT	\N	PRESENT	0
205974	205621	14211G	PARTICIPANT	\N	PRESENT	0
205975	205621	19583F	PARTICIPANT	\N	PRESENT	0
205976	205621	14255U	PARTICIPANT	\N	PRESENT	0
206432	205930	14133K	PARTICIPANT	\N	PRESENT	0
206433	205930	14065Q	PARTICIPANT	\N	PRESENT	0
206434	205930	96004D	PARTICIPANT	\N	PRESENT	0
206435	205930	14089Y	PARTICIPANT	\N	PRESENT	0
206436	205930	08014Q	PARTICIPANT	\N	PRESENT	0
206437	205930	14079W	PARTICIPANT	\N	PRESENT	0
206438	205930	14249W	PARTICIPANT	\N	PRESENT	0
206441	205930	08018U	PARTICIPANT	\N	PRESENT	0
206442	205930	04035D	PARTICIPANT	\N	PRESENT	0
206443	205930	11083R	PARTICIPANT	\N	PRESENT	0
206444	205930	14033T	PARTICIPANT	\N	PRESENT	0
206445	205930	14026U	PARTICIPANT	\N	PRESENT	0
206446	205930	19553Y	PARTICIPANT	\N	PRESENT	0
206447	205930	19725B	PARTICIPANT	\N	PRESENT	0
206448	205930	95037J	PARTICIPANT	\N	PRESENT	0
168914	168848	07034Q	PARTICIPANT	\N	PRESENT	0
168915	168848	04047H	PARTICIPANT	\N	PRESENT	0
168916	168848	08025T	PARTICIPANT	\N	PRESENT	0
168953	168848	92045V	PARTICIPANT	\N	PRESENT	0
168956	168848	14065Q	PARTICIPANT	\N	PRESENT	0
168958	168848	01019Q	PARTICIPANT	\N	PRESENT	0
168961	168848	95067Q	PARTICIPANT	\N	PRESENT	0
168962	168848	95049N	PARTICIPANT	\N	PRESENT	0
172912	171199	14018U	PARTICIPANT	\N	PRESENT	0
172913	171199	11067R	PARTICIPANT	\N	PRESENT	0
172914	171199	14119M	PARTICIPANT	\N	PRESENT	0
172998	172972	11039M	PARTICIPANT	\N	PRESENT	0
172999	172972	98042T	PARTICIPANT	\N	PRESENT	0
173000	172972	01019Q	PARTICIPANT	\N	PRESENT	0
176226	176225	11076S	PARTICIPANT	\N	PRESENT	0
176227	176225	14133K	PARTICIPANT	\N	PRESENT	0
176228	176225	04054G	PARTICIPANT	\N	PRESENT	0
176229	176225	04040A	PARTICIPANT	\N	PRESENT	0
176230	176225	08058D	PARTICIPANT	\N	PRESENT	0
176231	176225	04042C	PARTICIPANT	\N	PRESENT	0
176232	176225	77002U	PARTICIPANT	\N	PRESENT	0
176233	176225	98029W	PARTICIPANT	\N	PRESENT	0
176234	176225	11080N	PARTICIPANT	\N	PRESENT	0
176235	176225	11027H	PARTICIPANT	\N	PRESENT	0
176367	176366	11076S	PARTICIPANT	\N	PRESENT	0
176237	176225	92018S	PARTICIPANT	\N	PRESENT	0
176238	176225	92020L	PARTICIPANT	\N	PRESENT	0
176239	176225	95030B	PARTICIPANT	\N	PRESENT	0
176240	176225	11096W	PARTICIPANT	\N	PRESENT	0
176368	176366	14133K	PARTICIPANT	\N	PRESENT	0
176242	176225	97011G	PARTICIPANT	\N	PRESENT	0
176243	176225	08065C	PARTICIPANT	\N	PRESENT	0
176244	176225	04035D	PARTICIPANT	\N	PRESENT	0
176245	176225	04095R	PARTICIPANT	\N	PRESENT	0
176246	176225	14014Q	PARTICIPANT	\N	PRESENT	0
176247	176225	11015D	PARTICIPANT	\N	PRESENT	0
176248	176225	07004J	PARTICIPANT	\N	PRESENT	0
176369	176366	04054G	PARTICIPANT	\N	PRESENT	0
176250	176225	08056B	PARTICIPANT	\N	PRESENT	0
176251	176225	14211G	PARTICIPANT	\N	PRESENT	0
176252	176225	98022P	PARTICIPANT	\N	PRESENT	0
176253	176225	11064N	PARTICIPANT	\N	PRESENT	0
176254	176225	95037J	PARTICIPANT	\N	PRESENT	0
176255	176225	04078Q	PARTICIPANT	\N	PRESENT	0
176256	176225	14097Y	PARTICIPANT	\N	PRESENT	0
176257	176225	95041E	PARTICIPANT	\N	PRESENT	0
176258	176225	04036E	PARTICIPANT	\N	PRESENT	0
176259	176225	14039A	PARTICIPANT	\N	PRESENT	0
176260	176225	04077P	PARTICIPANT	\N	PRESENT	0
176370	176366	04040A	PARTICIPANT	\N	PRESENT	0
176262	176225	92031P	PARTICIPANT	\N	PRESENT	0
176263	176225	11106F	PARTICIPANT	\N	PRESENT	0
176264	176225	14251Q	PARTICIPANT	\N	PRESENT	0
176265	176225	83042R	PARTICIPANT	\N	PRESENT	0
176371	176366	08058D	PARTICIPANT	\N	PRESENT	0
176267	176225	11082Q	PARTICIPANT	\N	PRESENT	0
176268	176225	11105E	PARTICIPANT	\N	PRESENT	0
176269	176225	14253S	PARTICIPANT	\N	PRESENT	0
176270	176225	08047A	PARTICIPANT	\N	PRESENT	0
176271	176225	14028W	PARTICIPANT	\N	EXCUSE	0
176272	176225	14193X	PARTICIPANT	\N	PRESENT	0
176273	176225	98021N	PARTICIPANT	\N	PRESENT	0
176372	176366	04042C	PARTICIPANT	\N	PRESENT	0
176275	176225	95059Q	PRESIDENT	0	PRESENT	0
176373	176366	77002U	PARTICIPANT	\N	PRESENT	0
176277	176225	01014K	PARTICIPANT	\N	PRESENT	0
176278	176225	11054L	PARTICIPANT	\N	PRESENT	0
176279	176225	01056V	PARTICIPANT	\N	PRESENT	0
176374	176366	98029W	PARTICIPANT	\N	PRESENT	0
176281	176225	08049C	PARTICIPANT	\N	PRESENT	0
178852	167342	04085P	PARTICIPANT	\N	PRESENT	0
176375	176366	11080N	PARTICIPANT	\N	PRESENT	0
176376	176366	11027H	PARTICIPANT	\N	PRESENT	0
176377	176366	98018T	PARTICIPANT	\N	PRESENT	0
176378	176366	92018S	PARTICIPANT	\N	PRESENT	0
176379	176366	92020L	PARTICIPANT	\N	PRESENT	0
176380	176366	95030B	PARTICIPANT	\N	PRESENT	0
176381	176366	11096W	PARTICIPANT	\N	PRESENT	0
178853	167342	14013P	PARTICIPANT	\N	PRESENT	0
176383	176366	97011G	PARTICIPANT	\N	PRESENT	0
176384	176366	08065C	PARTICIPANT	\N	PRESENT	0
176385	176366	04035D	PARTICIPANT	\N	PRESENT	0
176386	176366	04095R	PARTICIPANT	\N	PRESENT	0
176387	176366	14014Q	PARTICIPANT	\N	PRESENT	0
176388	176366	11015D	PARTICIPANT	\N	PRESENT	0
176389	176366	07004J	PARTICIPANT	\N	PRESENT	0
178854	167342	01059Y	PARTICIPANT	\N	PRESENT	0
176391	176366	08056B	PARTICIPANT	\N	PRESENT	0
176392	176366	14211G	PARTICIPANT	\N	PRESENT	0
176393	176366	98022P	PARTICIPANT	\N	PRESENT	0
176394	176366	11064N	PARTICIPANT	\N	PRESENT	0
176395	176366	95037J	PARTICIPANT	\N	PRESENT	0
176396	176366	04078Q	PARTICIPANT	\N	PRESENT	0
176397	176366	14097Y	PARTICIPANT	\N	PRESENT	0
176398	176366	95041E	PARTICIPANT	\N	PRESENT	0
176399	176366	04036E	PARTICIPANT	\N	PRESENT	0
176400	176366	14039A	PARTICIPANT	\N	PRESENT	0
176401	176366	04077P	PARTICIPANT	\N	PRESENT	0
178855	167342	11056N	PARTICIPANT	\N	PRESENT	0
176403	176366	92031P	PARTICIPANT	\N	PRESENT	0
176404	176366	11106F	PARTICIPANT	\N	PRESENT	0
176405	176366	14251Q	PARTICIPANT	\N	PRESENT	0
176406	176366	83042R	PARTICIPANT	\N	PRESENT	0
178856	167342	11098Y	PARTICIPANT	\N	PRESENT	0
176408	176366	11082Q	PARTICIPANT	\N	PRESENT	0
176409	176366	11105E	PARTICIPANT	\N	PRESENT	0
176410	176366	14253S	PARTICIPANT	\N	PRESENT	0
176411	176366	08047A	PARTICIPANT	\N	PRESENT	0
176412	176366	14028W	PARTICIPANT	\N	EXCUSE	0
176413	176366	14193X	PARTICIPANT	\N	PRESENT	0
176414	176366	98021N	PARTICIPANT	\N	PRESENT	0
178857	167342	14235Q	PARTICIPANT	\N	PRESENT	0
176416	176366	95059Q	PRESIDENT	0	PRESENT	0
178858	167342	11031D	PARTICIPANT	\N	PRESENT	0
176418	176366	01014K	PARTICIPANT	\N	PRESENT	0
176419	176366	11054L	PARTICIPANT	\N	PRESENT	0
176420	176366	01056V	PARTICIPANT	\N	PRESENT	0
178859	167342	14257W	PARTICIPANT	\N	PRESENT	0
176422	176366	08049C	PARTICIPANT	\N	PRESENT	0
178860	167342	11099A	PARTICIPANT	\N	PRESENT	0
178861	167342	14267Y	PARTICIPANT	\N	PRESENT	0
178862	167342	08051V	PARTICIPANT	\N	PRESENT	0
178863	167342	14327T	PARTICIPANT	\N	PRESENT	0
178864	167342	12042Y	PARTICIPANT	\N	PRESENT	0
178865	167342	14225N	PARTICIPANT	\N	PRESENT	0
178872	167342	11036J	PARTICIPANT	\N	PRESENT	0
178873	167342	14103D	PARTICIPANT	\N	PRESENT	0
178874	167342	98053W	PARTICIPANT	\N	PRESENT	0
178875	167342	14361V	PARTICIPANT	\N	PRESENT	0
178892	167342	14195A	PARTICIPANT	\N	PRESENT	0
178893	167342	14083S	PARTICIPANT	\N	PRESENT	0
178894	167342	11012A	PARTICIPANT	\N	PRESENT	0
178912	167342	07029T	PARTICIPANT	\N	PRESENT	0
178913	167342	14111D	PARTICIPANT	\N	PRESENT	0
178914	167342	11063M	PARTICIPANT	\N	PRESENT	0
178932	167342	97011G	PARTICIPANT	\N	PRESENT	0
178952	167342	04045F	PARTICIPANT	\N	PRESENT	0
178953	167342	14119M	PARTICIPANT	\N	PRESENT	0
178954	167342	14031R	PARTICIPANT	\N	PRESENT	0
178955	167342	14079W	PARTICIPANT	\N	PRESENT	0
178956	167342	14069U	PARTICIPANT	\N	PRESENT	0
179072	176294	11088W	PARTICIPANT	\N	PRESENT	0
179232	177614	04044E	PARTICIPANT	\N	PRESENT	0
218247	218243	19729F	PARTICIPANT	\N	PRESENT	0
219896	214617	04038G	PARTICIPANT	\N	PRESENT	0
219901	219900	14147R	PARTICIPANT	\N	PRESENT	0
219902	219900	19649G	PARTICIPANT	\N	PRESENT	0
219903	219900	19543W	PARTICIPANT	\N	PRESENT	0
219904	219900	11033F	PARTICIPANT	\N	PRESENT	0
219905	219900	14231L	PARTICIPANT	\N	PRESENT	0
220182	220181	04061F	PARTICIPANT	\N	PRESENT	0
220184	220183	04061F	PARTICIPANT	\N	PRESENT	0
220189	220188	96004D	PRESIDENT	0	PRESENT	0
220190	220188	14133K	PARTICIPANT	\N	EXCUSE	0
220191	220188	14065Q	PARTICIPANT	\N	EXCUSE	0
220192	220188	14089Y	PARTICIPANT	\N	EXCUSE	0
220193	220188	14357A	PARTICIPANT	\N	EXCUSE	0
220194	220188	14079W	PARTICIPANT	\N	PRESENT	0
220196	220188	11083R	PARTICIPANT	\N	PRESENT	0
220198	220188	19725B	PARTICIPANT	\N	PRESENT	0
220205	220188	04097T	PARTICIPANT	\N	PRESENT	0
220206	220188	04061F	PARTICIPANT	\N	PRESENT	0
220207	220188	14073Q	PARTICIPANT	\N	PRESENT	0
220208	220188	11026G	PARTICIPANT	\N	PRESENT	0
220209	220188	08039A	PARTICIPANT	\N	PRESENT	0
220210	220188	14221J	PARTICIPANT	\N	PRESENT	0
220211	220188	19563B	PARTICIPANT	\N	PRESENT	0
220212	220188	04057K	PARTICIPANT	\N	PRESENT	0
220213	220188	19593H	PARTICIPANT	\N	PRESENT	0
220214	220188	14237S	PARTICIPANT	\N	PRESENT	0
220215	220188	14225N	PARTICIPANT	\N	PRESENT	0
220216	220188	10015M	PARTICIPANT	\N	PRESENT	0
220217	220188	14229S	PARTICIPANT	\N	PRESENT	0
220218	220188	98035U	PARTICIPANT	\N	EXCUSE	0
220219	220188	14331P	PARTICIPANT	\N	PRESENT	0
220220	220188	14097Y	PARTICIPANT	\N	EXCUSE	0
220221	220188	19685L	PARTICIPANT	\N	EXCUSE	0
220222	220188	08018U	PARTICIPANT	\N	EXCUSE	0
220229	220228	14179A	PARTICIPANT	\N	PRESENT	0
220231	220230	14179A	PARTICIPANT	\N	PRESENT	0
222246	222245	08049C	PARTICIPANT	\N	PRESENT	0
222485	220048	11109J	PARTICIPANT	\N	PRESENT	0
222486	220048	14261S	PARTICIPANT	\N	PRESENT	0
222487	220048	19631V	PARTICIPANT	\N	PRESENT	0
222488	220048	11033F	PARTICIPANT	\N	PRESENT	0
222489	220048	14038Y	PARTICIPANT	\N	PRESENT	0
222490	220048	19295A	PARTICIPANT	\N	PRESENT	0
222491	220048	14259Y	PARTICIPANT	\N	PRESENT	0
222492	220048	19659J	PARTICIPANT	\N	PRESENT	0
222493	220048	19577H	PARTICIPANT	\N	PRESENT	0
222494	220048	14199E	PARTICIPANT	\N	PRESENT	0
222495	220048	19691J	PARTICIPANT	\N	PRESENT	0
222496	220048	19329S	PARTICIPANT	\N	PRESENT	0
222497	220048	19715Y	PARTICIPANT	\N	PRESENT	0
222498	220048	14097Y	PARTICIPANT	\N	PRESENT	0
222499	220048	19583F	PARTICIPANT	\N	PRESENT	0
222500	220048	14277B	PARTICIPANT	\N	PRESENT	0
222501	220048	19729F	PARTICIPANT	\N	PRESENT	0
222502	220048	14059S	PARTICIPANT	\N	PRESENT	0
222503	220048	12016W	PARTICIPANT	\N	PRESENT	0
222504	220048	08019V	PRESIDENT	0	PRESENT	0
222505	220048	19657G	PARTICIPANT	\N	PRESENT	0
222506	220048	11072N	PARTICIPANT	\N	PRESENT	0
222507	220048	08073C	PARTICIPANT	\N	PRESENT	0
222508	220048	19319Q	PARTICIPANT	\N	PRESENT	0
222509	220048	19703U	PARTICIPANT	\N	PRESENT	0
222510	220048	19301E	PARTICIPANT	\N	PRESENT	0
222511	220048	14275Y	PARTICIPANT	\N	PRESENT	0
222512	220048	14157T	PARTICIPANT	\N	PRESENT	0
223612	222532	14257W	PARTICIPANT	\N	EXCUSE	0
226745	226742	11083R	PARTICIPANT	\N	PRESENT	0
223614	222532	14103D	PARTICIPANT	\N	EXCUSE	0
226743	226742	11074Q	PARTICIPANT	\N	PRESENT	0
223624	223622	14071N	PARTICIPANT	\N	PRESENT	0
223626	223625	14071N	PARTICIPANT	\N	PRESENT	0
226744	226742	14041T	PARTICIPANT	\N	PRESENT	0
225430	224734	04092N	PARTICIPANT	\N	EXCUSE	0
225431	224734	14239U	PARTICIPANT	\N	PRESENT	0
225432	224734	19415P	PARTICIPANT	\N	PRESENT	0
225433	224734	11103C	PRESIDENT	1	PRESENT	0
225434	224734	14195A	PARTICIPANT	\N	PRESENT	0
225435	224734	08052W	PARTICIPANT	\N	PRESENT	0
225436	224734	98024R	PARTICIPANT	\N	PRESENT	0
225437	224734	10006L	PARTICIPANT	\N	PRESENT	0
225438	224734	14042U	PARTICIPANT	\N	EXCUSE	0
225439	224734	14026U	PARTICIPANT	\N	PRESENT	0
225440	224734	11067R	PARTICIPANT	\N	PRESENT	0
225441	224734	11097X	PARTICIPANT	\N	PRESENT	0
225442	224734	01034P	PRESIDENT	0	PRESENT	0
225443	224734	11063M	PARTICIPANT	\N	EXCUSE	0
226746	226742	14239U	PARTICIPANT	\N	PRESENT	0
226747	226742	11012A	PARTICIPANT	\N	PRESENT	0
228119	228118	14193X	PARTICIPANT	\N	PRESENT	0
228120	228118	14255U	PARTICIPANT	\N	PRESENT	0
228123	228122	08058D	PARTICIPANT	\N	PRESENT	0
228468	218469	04086Q	PARTICIPANT	\N	PRESENT	0
228469	218469	19593H	PARTICIPANT	\N	PRESENT	0
228470	218469	11109J	PARTICIPANT	\N	PRESENT	0
228471	218469	19689Q	PARTICIPANT	\N	PRESENT	0
228472	218469	04034C	PARTICIPANT	\N	PRESENT	0
228473	218469	14261S	PARTICIPANT	\N	PRESENT	0
228487	218469	11045K	PARTICIPANT	\N	PRESENT	0
228475	218469	19319Q	PARTICIPANT	\N	PRESENT	0
228476	218469	11053K	PARTICIPANT	\N	PRESENT	0
228477	218469	07004J	PARTICIPANT	\N	PRESENT	0
228478	218469	11070L	PARTICIPANT	\N	PRESENT	0
228479	218469	14173T	PARTICIPANT	\N	PRESENT	0
228480	218469	14041T	PARTICIPANT	\N	PRESENT	0
228481	218469	14033T	PARTICIPANT	\N	PRESENT	0
228482	218469	07029T	PARTICIPANT	\N	PRESENT	0
228483	218469	14157T	PARTICIPANT	\N	PRESENT	0
228484	218469	14329V	PARTICIPANT	\N	PRESENT	0
228485	218469	19711U	PARTICIPANT	\N	PRESENT	0
228486	218469	19629C	PARTICIPANT	\N	PRESENT	0
228488	218469	19697Q	PARTICIPANT	\N	PRESENT	0
228489	218469	19687N	PARTICIPANT	\N	PRESENT	0
228490	218469	19581D	PARTICIPANT	\N	PRESENT	0
228491	218469	08011M	PARTICIPANT	\N	PRESENT	0
228492	218469	95063L	PARTICIPANT	\N	PRESENT	0
228493	218469	11074Q	PARTICIPANT	\N	PRESENT	0
228494	218469	19301E	PARTICIPANT	\N	PRESENT	0
228495	218469	14357A	PARTICIPANT	\N	PRESENT	0
228496	218469	19713W	PARTICIPANT	\N	PRESENT	0
228497	218469	19719D	PARTICIPANT	\N	PRESENT	0
228498	218469	11072N	PARTICIPANT	\N	PRESENT	0
228499	218469	95037J	PARTICIPANT	\N	PRESENT	0
228500	218469	08019V	PARTICIPANT	\N	PRESENT	0
228501	218469	98005N	PARTICIPANT	\N	PRESENT	0
228502	218469	95041E	PARTICIPANT	\N	PRESENT	0
228503	218469	19399H	PARTICIPANT	\N	PRESENT	0
228504	218469	19647E	PARTICIPANT	\N	PRESENT	0
228505	218469	04071H	PARTICIPANT	\N	PRESENT	0
228506	218469	11064N	PARTICIPANT	\N	PRESENT	0
228507	218469	19545Y	PARTICIPANT	\N	PRESENT	0
228509	218469	11077T	PARTICIPANT	\N	PRESENT	0
228510	218469	04059M	PARTICIPANT	\N	PRESENT	0
228511	218469	11031D	PARTICIPANT	\N	PRESENT	0
228512	218469	99004R	PARTICIPANT	\N	PRESENT	0
228514	218469	19573D	PARTICIPANT	\N	PRESENT	0
228519	218468	11070L	PARTICIPANT	\N	PRESENT	0
228520	218468	07029T	PARTICIPANT	\N	PRESENT	0
228521	218468	11077T	PARTICIPANT	\N	PRESENT	0
228522	218468	11045K	PARTICIPANT	\N	PRESENT	0
228523	218468	11031D	PARTICIPANT	\N	PRESENT	0
228524	218468	19399H	PARTICIPANT	\N	PRESENT	0
228525	218468	11097X	PARTICIPANT	\N	PRESENT	0
228526	218468	14357A	PARTICIPANT	\N	PRESENT	0
228527	218468	07004J	PARTICIPANT	\N	PRESENT	0
228528	218468	08011M	PARTICIPANT	\N	PRESENT	0
228529	218468	19573D	PARTICIPANT	\N	PRESENT	0
228530	218468	19711U	PARTICIPANT	\N	PRESENT	0
228531	218468	19647E	PARTICIPANT	\N	PRESENT	0
228532	218468	19545Y	PARTICIPANT	\N	PRESENT	0
228533	218468	14041T	PARTICIPANT	\N	PRESENT	0
228534	218468	99004R	PARTICIPANT	\N	PRESENT	0
228535	218468	11103C	PARTICIPANT	\N	PRESENT	0
228536	218468	19719D	PARTICIPANT	\N	PRESENT	0
228538	218468	04086Q	PARTICIPANT	\N	PRESENT	0
228539	218468	19593H	PARTICIPANT	\N	PRESENT	0
228540	218468	19583F	PARTICIPANT	\N	PRESENT	0
228541	218468	19667J	PARTICIPANT	\N	PRESENT	0
228548	218468	08031R	PARTICIPANT	\N	PRESENT	0
228549	218468	11074Q	PARTICIPANT	\N	PRESENT	0
228553	218468	95037J	PARTICIPANT	\N	PRESENT	0
228554	218468	95041E	PARTICIPANT	\N	PRESENT	0
228555	218468	14157T	PARTICIPANT	\N	PRESENT	0
228559	218468	11026G	PARTICIPANT	\N	PRESENT	0
228561	218468	14265W	PARTICIPANT	\N	PRESENT	0
228562	218468	14173T	PARTICIPANT	\N	PRESENT	0
228563	218468	08052W	PARTICIPANT	\N	PRESENT	0
228564	218468	11049P	PARTICIPANT	\N	PRESENT	0
228565	218468	19581D	PARTICIPANT	\N	PRESENT	0
216477	216302	04086Q	PARTICIPANT	\N	PRESENT	0
216478	216302	11070L	PARTICIPANT	\N	PRESENT	0
216479	216302	14327T	PARTICIPANT	\N	PRESENT	0
216480	216302	04071H	PARTICIPANT	\N	PRESENT	0
216481	216302	11074Q	PRESIDENT	0	PRESENT	0
216482	216302	11110B	PARTICIPANT	\N	PRESENT	0
216483	216302	14034U	PARTICIPANT	\N	PRESENT	0
216484	216302	07004J	PARTICIPANT	\N	EXCUSE	0
216485	216302	95041E	PARTICIPANT	\N	PRESENT	0
216486	216302	19711U	PARTICIPANT	\N	PRESENT	0
216487	216302	08010L	PARTICIPANT	\N	PRESENT	0
216488	216302	08011M	PARTICIPANT	\N	PRESENT	0
216489	216302	19349W	PARTICIPANT	\N	PRESENT	0
216490	216302	14331P	PARTICIPANT	\N	PRESENT	0
216491	216302	19687N	PARTICIPANT	\N	PRESENT	0
216492	216302	19689Q	PARTICIPANT	\N	PRESENT	0
216493	216302	19479G	PARTICIPANT	\N	PRESENT	0
216822	216821	04047H	PARTICIPANT	\N	PRESENT	0
216824	216821	19673G	PARTICIPANT	\N	PRESENT	0
216825	216821	19581D	PARTICIPANT	\N	PRESENT	0
217180	217177	14147R	PARTICIPANT	\N	PRESENT	0
217182	217177	19649G	PARTICIPANT	\N	PRESENT	0
217184	217177	04047H	PARTICIPANT	\N	PRESENT	0
217185	217177	19629C	PARTICIPANT	\N	PRESENT	0
217186	217177	19585H	PARTICIPANT	\N	PRESENT	0
217187	217177	14231L	PARTICIPANT	\N	PRESENT	0
217188	217177	11033F	PARTICIPANT	\N	PRESENT	0
217303	217302	95067Q	PARTICIPANT	\N	PRESENT	0
217304	217302	14028W	PARTICIPANT	\N	PRESENT	0
217306	217305	95067Q	PARTICIPANT	\N	PRESENT	0
217307	217305	14028W	PARTICIPANT	\N	PRESENT	0
217480	217478	14079W	PARTICIPANT	\N	PRESENT	0
217481	217478	19725B	PARTICIPANT	\N	PRESENT	0
217483	217482	14079W	PARTICIPANT	\N	PRESENT	0
217485	217482	19725B	PARTICIPANT	\N	PRESENT	0
217493	217492	98035U	PARTICIPANT	\N	PRESENT	0
217494	215602	04044E	PARTICIPANT	\N	EXCUSE	0
217496	217495	98035U	PARTICIPANT	\N	PRESENT	0
217707	217581	14327T	PARTICIPANT	\N	PRESENT	0
217708	217581	19711U	PARTICIPANT	\N	PRESENT	0
217709	217581	95041E	PARTICIPANT	\N	PRESENT	0
217710	217581	19687N	PARTICIPANT	\N	PRESENT	0
217711	217581	11074Q	PRESIDENT	0	PRESENT	0
217712	217581	14225N	PARTICIPANT	\N	PRESENT	0
217713	217581	14159V	PARTICIPANT	\N	PRESENT	0
217714	217581	04086Q	PARTICIPANT	\N	PRESENT	0
217715	217581	11040E	PARTICIPANT	\N	PRESENT	0
217716	217581	14085U	PARTICIPANT	\N	PRESENT	0
217717	217581	14121F	PARTICIPANT	\N	PRESENT	0
217718	217581	08010L	PARTICIPANT	\N	PRESENT	0
217719	217581	99004R	PARTICIPANT	\N	PRESENT	0
217737	217571	19697Q	PARTICIPANT	\N	PRESENT	0
217738	217571	11067R	PARTICIPANT	\N	PRESENT	0
217739	217571	14355X	PARTICIPANT	\N	PRESENT	0
217740	217571	11097X	PARTICIPANT	\N	PRESENT	0
217741	217571	19415P	PARTICIPANT	\N	PRESENT	0
217742	217571	14223L	PARTICIPANT	\N	PRESENT	0
217743	217571	04045F	PARTICIPANT	\N	PRESENT	0
217744	217571	14026U	PARTICIPANT	\N	PRESENT	0
217745	217571	14227Q	PARTICIPANT	\N	PRESENT	0
217746	217571	17779H	PARTICIPANT	\N	PRESENT	0
217747	217571	11063M	PARTICIPANT	\N	PRESENT	0
217748	217571	19703U	PARTICIPANT	\N	PRESENT	0
217749	217571	14239U	PARTICIPANT	\N	PRESENT	0
217750	217571	19553Y	PARTICIPANT	\N	PRESENT	0
217751	217571	11031D	PARTICIPANT	\N	PRESENT	0
217752	217571	14087W	PARTICIPANT	\N	PRESENT	0
217753	217571	14281W	PARTICIPANT	\N	PRESENT	0
217754	217571	19679N	PARTICIPANT	\N	PRESENT	0
217755	217571	14042U	PARTICIPANT	\N	PRESENT	0
217756	217571	19575F	PARTICIPANT	\N	PRESENT	0
217757	217571	14195A	PARTICIPANT	\N	PRESENT	0
217758	217571	19367Y	PARTICIPANT	\N	PRESENT	0
217759	217571	14217N	PARTICIPANT	\N	PRESENT	0
217760	217571	19335Q	PARTICIPANT	\N	PRESENT	0
217761	217571	10006L	PARTICIPANT	\N	PRESENT	0
217762	217571	19683J	PARTICIPANT	\N	PRESENT	0
217763	217571	98024R	PARTICIPANT	\N	PRESENT	0
217764	217571	19521Q	PARTICIPANT	\N	PRESENT	0
217765	217571	19527W	PARTICIPANT	\N	PRESENT	0
217766	217571	01034P	PARTICIPANT	\N	PRESENT	0
217767	217571	04092N	PRESIDENT	0	PRESENT	0
217768	217571	11045K	PARTICIPANT	\N	PRESENT	0
217769	217571	08052W	PARTICIPANT	\N	PRESENT	0
217770	217571	19663E	PARTICIPANT	\N	PRESENT	0
217771	217571	19715Y	PARTICIPANT	\N	PRESENT	0
217772	217571	19691J	PARTICIPANT	\N	PRESENT	0
217773	217571	19717B	PARTICIPANT	\N	PRESENT	0
217774	217571	08041T	PARTICIPANT	\N	PRESENT	0
217775	217571	19723Y	PARTICIPANT	\N	PRESENT	0
217776	217571	19727D	PARTICIPANT	\N	PRESENT	0
217777	217571	14119M	PARTICIPANT	\N	PRESENT	0
217778	217571	11103C	PARTICIPANT	\N	PRESENT	0
217779	217571	14071N	PARTICIPANT	\N	PRESENT	0
217780	217571	19657G	PARTICIPANT	\N	PRESENT	0
217781	217571	19577H	PARTICIPANT	\N	PRESENT	0
217877	217571	08048B	PARTICIPANT	\N	EXCUSE	0
217895	207712	98050T	PARTICIPANT	\N	PRESENT	0
217896	207712	01048V	PARTICIPANT	\N	PRESENT	0
217897	207712	11056N	PARTICIPANT	\N	PRESENT	0
217898	207712	19421M	PARTICIPANT	\N	PRESENT	0
217899	207712	14097Y	PARTICIPANT	\N	PRESENT	0
217900	207712	08061X	PARTICIPANT	\N	PRESENT	0
217901	217572	19715Y	PARTICIPANT	\N	PRESENT	0
217902	207712	14135M	PARTICIPANT	\N	PRESENT	0
217903	207712	11040E	PARTICIPANT	\N	PRESENT	0
217904	207712	08045X	PARTICIPANT	\N	PRESENT	0
217905	207712	19725B	PARTICIPANT	\N	PRESENT	0
217906	207712	19671E	PARTICIPANT	\N	PRESENT	0
217907	207712	19621T	PARTICIPANT	\N	PRESENT	0
217908	207712	08062Y	PARTICIPANT	\N	PRESENT	0
217909	207712	14231L	PARTICIPANT	\N	PRESENT	0
217910	207712	19733B	PARTICIPANT	\N	PRESENT	0
217912	207712	19689Q	PARTICIPANT	\N	PRESENT	0
217914	207712	19531S	PARTICIPANT	\N	PRESENT	0
217915	207712	14105F	PARTICIPANT	\N	PRESENT	0
217916	207712	19599P	PARTICIPANT	\N	PRESENT	0
217924	207712	08020N	PARTICIPANT	\N	PRESENT	0
217918	207712	08017T	PARTICIPANT	\N	PRESENT	0
217921	207712	95030B	PARTICIPANT	\N	PRESENT	0
217925	207712	11066Q	PARTICIPANT	\N	PRESENT	0
217926	207712	04018C	PARTICIPANT	\N	PRESENT	0
217927	207712	80027E	PARTICIPANT	\N	PRESENT	0
217928	207712	19681G	PARTICIPANT	\N	PRESENT	0
217929	207712	14331P	PARTICIPANT	\N	PRESENT	0
217930	207712	08031R	PARTICIPANT	\N	PRESENT	0
217931	207712	11012A	PARTICIPANT	\N	PRESENT	0
217932	207712	17589D	PARTICIPANT	\N	PRESENT	0
217933	217572	14281W	PARTICIPANT	\N	PRESENT	0
217934	207712	08069G	PARTICIPANT	\N	PRESENT	0
217935	207712	14030Q	PARTICIPANT	\N	PRESENT	0
217940	207712	19693L	PARTICIPANT	\N	PRESENT	0
217941	207712	14063N	PARTICIPANT	\N	PRESENT	0
217942	207712	08043V	PARTICIPANT	\N	PRESENT	0
217943	207712	14029X	PARTICIPANT	\N	PRESENT	0
217944	207712	14229S	PARTICIPANT	\N	PRESENT	0
217945	207712	14111D	PARTICIPANT	\N	PRESENT	0
217946	207712	98023Q	PARTICIPANT	\N	PRESENT	0
217947	207712	19631V	PARTICIPANT	\N	PRESENT	0
217948	207712	19413M	PARTICIPANT	\N	PRESENT	0
217949	207712	14151M	PARTICIPANT	\N	PRESENT	0
217950	207712	08038Y	PARTICIPANT	\N	PRESENT	0
217951	207712	02002K	PARTICIPANT	\N	PRESENT	0
217952	207712	19253P	PARTICIPANT	\N	PRESENT	0
217953	207712	16685X	PARTICIPANT	\N	PRESENT	0
217954	207712	14089Y	PARTICIPANT	\N	PRESENT	0
217955	207712	08068F	PARTICIPANT	\N	PRESENT	0
217957	207712	80013X	PARTICIPANT	\N	PRESENT	0
217958	207712	19593H	PARTICIPANT	\N	PRESENT	0
217959	207712	19695N	PARTICIPANT	\N	PRESENT	0
217960	207712	11054L	PARTICIPANT	\N	PRESENT	0
217961	207712	14001X	PARTICIPANT	\N	PRESENT	0
217962	207712	17779H	PARTICIPANT	\N	PRESENT	0
217963	207712	04045F	PARTICIPANT	\N	PRESENT	0
217964	207712	17583W	PARTICIPANT	\N	PRESENT	0
217965	207713	86034E	PARTICIPANT	\N	PRESENT	0
217966	207713	04047H	PARTICIPANT	\N	PRESENT	0
217967	207713	11101A	PARTICIPANT	\N	PRESENT	0
217968	207713	08020N	PARTICIPANT	\N	PRESENT	0
217969	207713	19703U	PARTICIPANT	\N	PRESENT	0
217970	207713	04097T	PARTICIPANT	\N	PRESENT	0
217971	207713	17637T	PARTICIPANT	\N	PRESENT	0
217972	207713	08011M	PARTICIPANT	\N	PRESENT	0
217973	207713	14211G	PARTICIPANT	\N	PRESENT	0
217974	207713	19711U	PARTICIPANT	\N	PRESENT	0
217975	207713	19643A	PARTICIPANT	\N	PRESENT	0
217976	207713	15447F	PARTICIPANT	\N	PRESENT	0
217977	207713	14223L	PARTICIPANT	\N	PRESENT	0
217978	207713	14259Y	PARTICIPANT	\N	PRESENT	0
213118	213116	14001X	PARTICIPANT	\N	PRESENT	0
213119	213116	14281W	PARTICIPANT	\N	PRESENT	0
213133	213132	14215L	PARTICIPANT	\N	PRESENT	0
213135	213134	14215L	PARTICIPANT	\N	PRESENT	0
217472	217470	08011M	PARTICIPANT	\N	PRESENT	0
214485	207695	14261S	PARTICIPANT	\N	PRESENT	0
214486	207695	04059M	PARTICIPANT	\N	PRESENT	0
214533	214532	14001X	PARTICIPANT	\N	PRESENT	0
214534	214532	14237S	PARTICIPANT	\N	PRESENT	0
214536	214535	14071N	PARTICIPANT	\N	PRESENT	0
214538	214537	18083K	PARTICIPANT	\N	PRESENT	0
214540	214539	18083K	PARTICIPANT	\N	PRESENT	0
214542	214541	04089T	PARTICIPANT	\N	PRESENT	0
214544	214543	04089T	PARTICIPANT	\N	PRESENT	0
214546	214545	04089T	PARTICIPANT	\N	PRESENT	0
214548	214547	04089T	PARTICIPANT	\N	PRESENT	0
217415	217414	11097X	PARTICIPANT	\N	PRESENT	0
217471	217470	11074Q	PARTICIPANT	\N	PRESENT	0
218996	218995	11026G	PARTICIPANT	\N	PRESENT	0
219898	219897	98018T	PARTICIPANT	\N	PRESENT	0
219899	219897	11041F	PARTICIPANT	\N	PRESENT	0
219907	219906	98018T	PARTICIPANT	\N	PRESENT	0
219908	219906	11041F	PARTICIPANT	\N	PRESENT	0
219914	219911	95037J	PARTICIPANT	\N	PRESENT	0
220201	220048	14331P	PARTICIPANT	\N	EXCUSE	0
220204	220048	14135M	PARTICIPANT	\N	EXCUSE	0
221365	221364	19699S	PARTICIPANT	\N	PRESENT	0
221840	221839	11053K	PARTICIPANT	\N	PRESENT	0
221841	221839	14159V	PARTICIPANT	\N	PRESENT	0
221842	221839	05012A	PARTICIPANT	\N	PRESENT	0
221844	221843	11053K	PARTICIPANT	\N	PRESENT	0
221845	221843	14159V	PARTICIPANT	\N	PRESENT	0
221846	221843	05012A	PARTICIPANT	\N	PRESENT	0
228057	221543	11109J	PARTICIPANT	\N	PRESENT	0
228058	221543	19631V	PARTICIPANT	\N	PRESENT	0
228059	221543	19295A	PARTICIPANT	\N	PRESENT	0
228060	221543	19659J	PARTICIPANT	\N	PRESENT	0
228061	221543	19691J	PARTICIPANT	\N	PRESENT	0
228062	221543	14039A	PARTICIPANT	\N	PRESENT	0
228063	221543	98005N	PARTICIPANT	\N	PRESENT	0
228064	221543	19729F	PARTICIPANT	\N	PRESENT	0
228065	221543	14219Q	PARTICIPANT	\N	PRESENT	0
228066	221543	14059S	PARTICIPANT	\N	PRESENT	0
228067	221543	08019V	PRESIDENT	0	PRESENT	0
228068	221543	11072N	PARTICIPANT	\N	EXCUSE	0
228069	221543	04043D	PARTICIPANT	\N	PRESENT	0
228070	221543	14157T	PARTICIPANT	\N	PRESENT	0
228071	221543	14275Y	PARTICIPANT	\N	EXCUSE	0
228085	221543	19657G	PARTICIPANT	\N	PRESENT	0
228090	221543	14331P	PARTICIPANT	\N	PRESENT	0
228091	221543	19703U	PARTICIPANT	\N	PRESENT	0
228094	221543	19301E	PARTICIPANT	\N	PRESENT	0
228097	221543	14093U	PARTICIPANT	\N	PRESENT	0
230255	220060	08039A	PARTICIPANT	\N	PRESENT	0
230256	220060	19715Y	PARTICIPANT	\N	PRESENT	0
230257	220060	14079W	PARTICIPANT	\N	PRESENT	0
230258	220060	14021P	PARTICIPANT	\N	PRESENT	0
230259	220060	14225N	PARTICIPANT	\N	PRESENT	0
230260	220060	19673G	PARTICIPANT	\N	PRESENT	0
230261	220060	08045X	PARTICIPANT	\N	PRESENT	0
230262	220060	19667J	PARTICIPANT	\N	PRESENT	0
230263	220060	01062T	PARTICIPANT	\N	PRESENT	0
230264	220060	08060W	PARTICIPANT	\N	PRESENT	0
230265	220060	80013X	PARTICIPANT	\N	PRESENT	0
230266	220060	95062K	PARTICIPANT	\N	PRESENT	0
230267	220060	19649G	PARTICIPANT	\N	PRESENT	0
230268	220060	19447X	PARTICIPANT	\N	PRESENT	0
230269	220060	11033F	PARTICIPANT	\N	PRESENT	0
230270	220060	14071N	PARTICIPANT	\N	PRESENT	0
230271	220060	14109K	PARTICIPANT	\N	PRESENT	0
230272	220060	19631V	PARTICIPANT	\N	PRESENT	0
230273	220060	14119M	PARTICIPANT	\N	PRESENT	0
230274	220060	11104D	PARTICIPANT	\N	PRESENT	0
230275	220060	08043V	PARTICIPANT	\N	PRESENT	0
230276	220060	11066Q	PARTICIPANT	\N	PRESENT	0
230277	220060	11045K	PARTICIPANT	\N	PRESENT	0
230278	220060	14081Q	PARTICIPANT	\N	PRESENT	0
230279	220060	11110B	PARTICIPANT	\N	PRESENT	0
230280	220060	19729F	PARTICIPANT	\N	PRESENT	0
230281	220060	19525U	PARTICIPANT	\N	PRESENT	0
230282	220060	08017T	PARTICIPANT	\N	PRESENT	0
230283	220060	07034Q	PARTICIPANT	\N	PRESENT	0
230284	220060	14085U	PARTICIPANT	\N	PRESENT	0
230285	220060	14331P	PARTICIPANT	\N	PRESENT	0
230286	220060	14121F	PARTICIPANT	\N	PRESENT	0
230287	220060	14041T	PARTICIPANT	\N	PRESENT	0
230288	220060	17779H	PARTICIPANT	\N	PRESENT	0
230289	220060	14193X	PARTICIPANT	\N	PRESENT	0
230290	220060	19443T	PARTICIPANT	\N	PRESENT	0
230291	220060	19489J	PARTICIPANT	\N	PRESENT	0
230292	220060	08035V	PARTICIPANT	\N	PRESENT	0
230293	220060	19689Q	PARTICIPANT	\N	PRESENT	0
230294	220060	11054L	PARTICIPANT	\N	PRESENT	0
230295	220060	97011G	PARTICIPANT	\N	PRESENT	0
230296	220060	19683J	PARTICIPANT	\N	PRESENT	0
230297	220060	14227Q	PARTICIPANT	\N	PRESENT	0
230298	220060	14033T	PARTICIPANT	\N	PRESENT	0
230299	220060	19333N	PARTICIPANT	\N	PRESENT	0
230300	220060	14135M	PARTICIPANT	\N	PRESENT	0
230301	220060	08014Q	PARTICIPANT	\N	PRESENT	0
230302	220060	07029T	PARTICIPANT	\N	PRESENT	0
230303	220060	19725B	PARTICIPANT	\N	PRESENT	0
230304	220060	14207L	PARTICIPANT	\N	PRESENT	0
230305	220060	19599P	PARTICIPANT	\N	PRESENT	0
230306	220060	01057W	PARTICIPANT	\N	PRESENT	0
230307	220060	14257W	PARTICIPANT	\N	PRESENT	0
230308	220060	19415P	PARTICIPANT	\N	PRESENT	0
230309	220060	19687N	PARTICIPANT	\N	PRESENT	0
230310	220060	14063N	PARTICIPANT	\N	PRESENT	0
230311	220060	08024S	PARTICIPANT	\N	PRESENT	0
230320	220060	11031D	PARTICIPANT	\N	PRESENT	0
230313	220060	19527W	PARTICIPANT	\N	PRESENT	0
230315	220060	04018C	PARTICIPANT	\N	PRESENT	0
230316	220060	19551W	PARTICIPANT	\N	PRESENT	0
230317	220060	19591F	PARTICIPANT	\N	PRESENT	0
230318	220060	19367Y	PARTICIPANT	\N	PRESENT	0
230319	220060	19251M	PARTICIPANT	\N	PRESENT	0
230321	220060	08016S	PARTICIPANT	\N	PRESENT	0
230322	220060	14061L	PARTICIPANT	\N	PRESENT	0
230323	220060	08012N	PARTICIPANT	\N	PRESENT	0
230324	220060	19483C	PARTICIPANT	\N	PRESENT	0
230325	220060	14059S	PARTICIPANT	\N	PRESENT	0
230326	220060	08061X	PARTICIPANT	\N	PRESENT	0
230327	220060	95037J	PARTICIPANT	\N	PRESENT	0
230328	220060	98029W	PARTICIPANT	\N	PRESENT	0
230329	220060	04061F	PARTICIPANT	\N	PRESENT	0
230330	220060	11083R	PARTICIPANT	\N	PRESENT	0
230331	220060	18083K	PARTICIPANT	\N	PRESENT	0
230332	220060	19651A	PARTICIPANT	\N	PRESENT	0
230333	220060	19637C	PARTICIPANT	\N	PRESENT	0
230334	220060	19697Q	PARTICIPANT	\N	PRESENT	0
230335	220060	11103C	PARTICIPANT	\N	PRESENT	0
230336	220060	08021P	PARTICIPANT	\N	PRESENT	0
230337	220060	08018U	PARTICIPANT	\N	PRESENT	0
230338	220060	19269X	PARTICIPANT	\N	PRESENT	0
230339	220060	11072N	PARTICIPANT	\N	PRESENT	0
230340	220060	19301E	PARTICIPANT	\N	PRESENT	0
230341	220060	14329V	PARTICIPANT	\N	PRESENT	0
230342	220060	19399H	PARTICIPANT	\N	PRESENT	0
230343	220060	88008L	PARTICIPANT	\N	PRESENT	0
230344	220060	19253P	PARTICIPANT	\N	PRESENT	0
230345	220060	14034U	PARTICIPANT	\N	PRESENT	0
230346	220060	14261S	PARTICIPANT	\N	PRESENT	0
230347	220060	19563B	PARTICIPANT	\N	PRESENT	0
230348	220060	14201E	PARTICIPANT	\N	PRESENT	0
230349	220060	19693L	PARTICIPANT	\N	PRESENT	0
230350	220060	98022P	PARTICIPANT	\N	PRESENT	0
230351	220060	08062Y	PARTICIPANT	\N	PRESENT	0
230352	220060	14241N	PARTICIPANT	\N	PRESENT	0
230353	220060	19387D	PARTICIPANT	\N	PRESENT	0
230354	220060	14213J	PARTICIPANT	\N	PRESENT	0
230355	220060	19727D	PARTICIPANT	\N	PRESENT	0
230356	220060	19545Y	PARTICIPANT	\N	PRESENT	0
230357	220060	14111D	PARTICIPANT	\N	PRESENT	0
230358	220060	14093U	PARTICIPANT	\N	PRESENT	0
230359	220060	04057K	PARTICIPANT	\N	PRESENT	0
230360	220060	11064N	PARTICIPANT	\N	PRESENT	0
230361	220060	14195A	PARTICIPANT	\N	PRESENT	0
230362	220060	14053L	PARTICIPANT	\N	PRESENT	0
230363	220060	14251Q	PARTICIPANT	\N	PRESENT	0
230364	220060	19717B	PARTICIPANT	\N	PRESENT	0
230365	220060	19553Y	PARTICIPANT	\N	PRESENT	0
230366	220060	04092N	PARTICIPANT	\N	PRESENT	0
230367	220060	19369B	PARTICIPANT	\N	PRESENT	0
230368	220060	19691J	PARTICIPANT	\N	PRESENT	0
230369	220060	19511N	PARTICIPANT	\N	PRESENT	0
230370	220060	19611R	PARTICIPANT	\N	PRESENT	0
230371	220060	11053K	PARTICIPANT	\N	PRESENT	0
223819	218293	14191V	PARTICIPANT	\N	PRESENT	0
223821	218293	04044E	PARTICIPANT	\N	PRESENT	0
223822	218293	14329V	PARTICIPANT	\N	PRESENT	0
223823	218293	02002K	PARTICIPANT	\N	PRESENT	0
223825	218293	01028R	PARTICIPANT	\N	PRESENT	0
223826	218293	95041E	PARTICIPANT	\N	PRESENT	0
223827	218293	14087W	PARTICIPANT	\N	PRESENT	0
223828	218293	08061X	PARTICIPANT	\N	PRESENT	0
223829	218293	08014Q	PARTICIPANT	\N	PRESENT	0
223830	218293	11097X	PARTICIPANT	\N	PRESENT	0
223831	218293	14255U	PARTICIPANT	\N	PRESENT	0
223832	218293	19683J	PARTICIPANT	\N	PRESENT	0
223833	218293	04033B	PARTICIPANT	\N	PRESENT	0
223834	218293	14030Q	PARTICIPANT	\N	PRESENT	0
223926	218821	17637T	PARTICIPANT	\N	EXCUSE	0
223927	218821	11065P	PARTICIPANT	\N	EXCUSE	0
223928	218821	19421M	PARTICIPANT	\N	EXCUSE	0
223929	221543	14097Y	PARTICIPANT	\N	EXCUSE	0
223930	221543	14135M	PARTICIPANT	\N	EXCUSE	0
225090	222588	19383Y	PARTICIPANT	\N	PRESENT	0
225091	222588	19333N	PARTICIPANT	\N	PRESENT	0
225092	222588	17583W	PARTICIPANT	\N	PRESENT	0
225093	222588	95062K	PARTICIPANT	\N	PRESENT	0
225094	222588	19549D	PARTICIPANT	\N	PRESENT	0
225095	222588	19387D	PARTICIPANT	\N	PRESENT	0
225096	222588	14221J	PARTICIPANT	\N	PRESENT	0
225097	222588	19599P	PARTICIPANT	\N	PRESENT	0
225098	222588	19637C	PARTICIPANT	\N	PRESENT	0
225099	222588	18083K	PARTICIPANT	\N	PRESENT	0
225100	222588	19551W	PARTICIPANT	\N	PRESENT	0
225101	222588	80027E	PARTICIPANT	\N	PRESENT	0
225102	222588	19503N	PARTICIPANT	\N	PRESENT	0
225103	222588	19347U	PARTICIPANT	\N	PRESENT	0
225104	222588	14157T	PARTICIPANT	\N	PRESENT	0
225105	222588	19685L	PARTICIPANT	\N	PRESENT	0
225106	222588	19681G	PARTICIPANT	\N	PRESENT	0
225107	222588	08024S	PARTICIPANT	\N	PRESENT	0
225108	222588	11065P	PARTICIPANT	\N	PRESENT	0
225109	222588	17637T	PARTICIPANT	\N	PRESENT	0
225110	222588	19525U	PARTICIPANT	\N	PRESENT	0
225111	222588	14031R	PRESIDENT	0	PRESENT	0
225112	222588	19713W	PARTICIPANT	\N	PRESENT	0
225113	222588	14191V	PARTICIPANT	\N	PRESENT	0
225114	222588	15447F	PARTICIPANT	\N	PRESENT	0
225115	222588	14093U	PARTICIPANT	\N	PRESENT	0
225116	222588	14029X	PARTICIPANT	\N	PRESENT	0
225117	222588	19737F	PARTICIPANT	\N	PRESENT	0
225118	222588	19739H	PARTICIPANT	\N	PRESENT	0
225119	222588	04097T	PARTICIPANT	\N	PRESENT	0
225120	222588	19701S	PARTICIPANT	\N	EXCUSE	0
225121	218299	89017R	PARTICIPANT	\N	PRESENT	0
225122	218299	87003B	PARTICIPANT	\N	PRESENT	0
225123	218299	10015M	PARTICIPANT	\N	PRESENT	0
225124	218299	80013X	PARTICIPANT	\N	PRESENT	0
225125	218299	08012N	PARTICIPANT	\N	PRESENT	0
225150	218299	04059M	PARTICIPANT	\N	PRESENT	0
225201	218299	04033B	PARTICIPANT	\N	PRESENT	0
225202	218299	19673G	PARTICIPANT	\N	PRESENT	0
225203	218299	08017T	PARTICIPANT	\N	PRESENT	0
225204	218299	08043V	PARTICIPANT	\N	PRESENT	0
225205	218299	99004R	PARTICIPANT	\N	PRESENT	0
225207	218299	14041T	PARTICIPANT	\N	PRESENT	0
225208	218299	14215L	PARTICIPANT	\N	PRESENT	0
225209	218299	19549D	PARTICIPANT	\N	PRESENT	0
225210	218299	08018U	PARTICIPANT	\N	PRESENT	0
225211	218299	11053K	PARTICIPANT	\N	PRESENT	0
225212	218299	14199E	PARTICIPANT	\N	PRESENT	0
225213	218299	14331P	PARTICIPANT	\N	PRESENT	0
225214	218299	95030B	PARTICIPANT	\N	PRESENT	0
225215	218299	14147R	PARTICIPANT	\N	PRESENT	0
225216	218299	14031R	PARTICIPANT	\N	PRESENT	0
225217	218299	14275Y	PARTICIPANT	\N	PRESENT	0
225218	218299	14157T	PARTICIPANT	\N	PRESENT	0
225219	218299	19543W	PARTICIPANT	\N	PRESENT	0
225220	218299	11012A	PARTICIPANT	\N	PRESENT	0
225221	218299	19739H	PARTICIPANT	\N	PRESENT	0
225223	218299	14207L	PARTICIPANT	\N	PRESENT	0
225224	218299	19413M	PARTICIPANT	\N	PRESENT	0
225225	218299	19725B	PARTICIPANT	\N	PRESENT	0
225226	218299	14265W	PARTICIPANT	\N	PRESENT	0
225227	218299	19611R	PARTICIPANT	\N	PRESENT	0
225228	218299	01048V	PARTICIPANT	\N	PRESENT	0
225229	218299	14205J	PARTICIPANT	\N	PRESENT	0
225230	218299	19551W	PARTICIPANT	\N	PRESENT	0
225231	218299	19415P	PARTICIPANT	\N	PRESENT	0
225232	218299	14033T	PARTICIPANT	\N	PRESENT	0
225233	218299	19581D	PARTICIPANT	\N	PRESENT	0
225234	218299	19511N	PARTICIPANT	\N	PRESENT	0
225236	218299	14211G	PARTICIPANT	\N	PRESENT	0
225242	218300	11072N	PARTICIPANT	\N	PRESENT	0
225243	218300	11040E	PARTICIPANT	\N	PRESENT	0
225244	218300	14225N	PARTICIPANT	\N	PRESENT	0
225245	218300	01057W	PARTICIPANT	\N	PRESENT	0
225246	218300	14001X	PARTICIPANT	\N	PRESENT	0
225247	218300	19503N	PARTICIPANT	\N	PRESENT	0
225248	218300	19525U	PARTICIPANT	\N	PRESENT	0
225249	218300	14063N	PARTICIPANT	\N	PRESENT	0
225250	218300	04045F	PARTICIPANT	\N	PRESENT	0
225251	218300	19629C	PARTICIPANT	\N	PRESENT	0
225252	218300	19253P	PARTICIPANT	\N	PRESENT	0
225253	218300	08020N	PARTICIPANT	\N	PRESENT	0
225254	218300	19711U	PARTICIPANT	\N	PRESENT	0
225255	218300	14231L	PARTICIPANT	\N	PRESENT	0
225256	218300	14191V	PARTICIPANT	\N	PRESENT	0
225257	218300	19703U	PARTICIPANT	\N	PRESENT	0
225258	218300	14267Y	PARTICIPANT	\N	PRESENT	0
225259	218300	07029T	PARTICIPANT	\N	PRESENT	0
225260	218300	19441R	PARTICIPANT	\N	PRESENT	0
225261	218300	14119M	PARTICIPANT	\N	PRESENT	0
225269	218300	14327T	PARTICIPANT	\N	PRESENT	0
225263	218300	19507S	PARTICIPANT	\N	PRESENT	0
225264	218300	19731Y	PARTICIPANT	\N	PRESENT	0
225265	218300	14211G	PARTICIPANT	\N	PRESENT	0
225266	218300	19611R	PARTICIPANT	\N	PRESENT	0
225267	218300	19581D	PARTICIPANT	\N	PRESENT	0
225268	218300	14217N	PARTICIPANT	\N	PRESENT	0
225270	218300	14179A	PARTICIPANT	\N	PRESENT	0
225271	218300	11104D	PARTICIPANT	\N	PRESENT	0
225272	218300	19741B	PARTICIPANT	\N	PRESENT	0
225273	218300	19735D	PARTICIPANT	\N	PRESENT	0
225274	218300	19387D	PARTICIPANT	\N	PRESENT	0
225275	218300	08034U	PARTICIPANT	\N	PRESENT	0
225276	218300	14111D	PARTICIPANT	\N	PRESENT	0
225277	218300	19739H	PARTICIPANT	\N	PRESENT	0
225278	218300	14029X	PARTICIPANT	\N	PRESENT	0
225279	218300	08010L	PARTICIPANT	\N	PRESENT	0
225280	218300	11074Q	PARTICIPANT	\N	PRESENT	0
225281	218300	19713W	PARTICIPANT	\N	PRESENT	0
225282	218300	19415P	PARTICIPANT	\N	PRESENT	0
225283	218300	19651A	PARTICIPANT	\N	PRESENT	0
225284	218300	10015M	PARTICIPANT	\N	PRESENT	0
225285	218300	14235Q	PARTICIPANT	\N	PRESENT	0
225286	218300	14107H	PARTICIPANT	\N	PRESENT	0
225287	218300	19737F	PARTICIPANT	\N	PRESENT	0
225288	218300	14034U	PARTICIPANT	\N	PRESENT	0
225289	218300	19667J	PARTICIPANT	\N	PRESENT	0
225290	218300	19483C	PARTICIPANT	\N	PRESENT	0
225291	218300	18083K	PARTICIPANT	\N	PRESENT	0
225292	218300	14069U	PARTICIPANT	\N	PRESENT	0
225293	218300	11067R	PARTICIPANT	\N	PRESENT	0
225294	218300	19367Y	PARTICIPANT	\N	PRESENT	0
225295	218300	11064N	PARTICIPANT	\N	PRESENT	0
225296	218300	19545Y	PARTICIPANT	\N	PRESENT	0
225297	218300	19413M	PARTICIPANT	\N	PRESENT	0
225298	218300	19549D	PARTICIPANT	\N	PRESENT	0
225299	218300	19725B	PARTICIPANT	\N	PRESENT	0
225300	218300	98050T	PARTICIPANT	\N	PRESENT	0
225301	218300	04038G	PARTICIPANT	\N	PRESENT	0
225302	218300	08016S	PARTICIPANT	\N	PRESENT	0
225303	218300	14257W	PARTICIPANT	\N	PRESENT	0
225304	218300	19467C	PARTICIPANT	\N	PRESENT	0
225305	218300	19573D	PARTICIPANT	\N	PRESENT	0
225306	218300	08045X	PARTICIPANT	\N	PRESENT	0
225307	218300	14205J	PARTICIPANT	\N	PRESENT	0
225308	218300	19631V	PARTICIPANT	\N	PRESENT	0
225309	218300	11070L	PARTICIPANT	\N	PRESENT	0
225310	218300	95037J	PARTICIPANT	\N	PRESENT	0
225311	218300	14121F	PARTICIPANT	\N	PRESENT	0
225312	218300	07004J	PARTICIPANT	\N	PRESENT	0
225313	218300	14105F	PARTICIPANT	\N	PRESENT	0
225314	218300	19575F	PARTICIPANT	\N	PRESENT	0
225315	218300	14275Y	PARTICIPANT	\N	PRESENT	0
225316	218300	19599P	PARTICIPANT	\N	PRESENT	0
225317	218300	08024S	PARTICIPANT	\N	PRESENT	0
225318	218300	14259Y	PARTICIPANT	\N	PRESENT	0
225319	218300	08011M	PARTICIPANT	\N	PRESENT	0
225320	218300	04059M	PARTICIPANT	\N	PRESENT	0
225321	218300	19637C	PARTICIPANT	\N	PRESENT	0
225322	218300	04088S	PARTICIPANT	\N	PRESENT	0
225323	218300	19691J	PARTICIPANT	\N	PRESENT	0
225324	218300	11110B	PARTICIPANT	\N	PRESENT	0
216038	212116	19569H	PARTICIPANT	\N	PRESENT	0
216039	212116	19421M	PARTICIPANT	\N	PRESENT	0
217318	217317	11040E	PARTICIPANT	\N	PRESENT	0
217319	217317	19667J	PARTICIPANT	\N	PRESENT	0
217320	217317	14071N	PARTICIPANT	\N	PRESENT	0
217322	217321	11040E	PARTICIPANT	\N	PRESENT	0
217323	217321	19667J	PARTICIPANT	\N	PRESENT	0
217324	217321	14071N	PARTICIPANT	\N	PRESENT	0
217326	217325	19647E	PARTICIPANT	\N	PRESENT	0
217328	217327	11070L	PARTICIPANT	\N	PRESENT	0
217329	217327	19647E	PARTICIPANT	\N	PRESENT	0
217331	217330	19647E	PARTICIPANT	\N	PRESENT	0
217333	217332	14327T	PARTICIPANT	\N	PRESENT	0
217335	217334	11064N	PARTICIPANT	\N	PRESENT	0
217336	217334	11054L	PARTICIPANT	\N	PRESENT	0
217556	217555	08068F	PARTICIPANT	\N	PRESENT	0
217558	217557	08068F	PARTICIPANT	\N	PRESENT	0
217560	217559	08019V	PARTICIPANT	\N	PRESENT	0
217562	217561	08019V	PARTICIPANT	\N	PRESENT	0
217564	217563	08019V	PARTICIPANT	\N	PRESENT	0
225791	225151	14133K	PARTICIPANT	\N	PRESENT	0
225792	225151	14065Q	PARTICIPANT	\N	EXCUSE	0
225793	225151	96004D	PRESIDENT	0	PRESENT	0
225794	225151	14089Y	PARTICIPANT	\N	PRESENT	0
225795	225151	08014Q	PARTICIPANT	\N	PRESENT	0
225796	225151	14357A	PARTICIPANT	\N	PRESENT	0
225797	225151	11083R	PARTICIPANT	\N	PRESENT	0
225798	225151	14033T	PARTICIPANT	\N	PRESENT	0
225799	225151	19725B	PARTICIPANT	\N	PRESENT	0
225800	225151	95037J	PARTICIPANT	\N	PRESENT	0
225801	225151	19685L	PARTICIPANT	\N	EXCUSE	0
225802	225151	14097Y	PARTICIPANT	\N	PRESENT	0
225803	225151	04061F	PARTICIPANT	\N	PRESENT	0
225804	225151	14061L	PARTICIPANT	\N	PRESENT	0
225805	225151	14073Q	PARTICIPANT	\N	PRESENT	0
225806	225151	11026G	PARTICIPANT	\N	PRESENT	0
225807	225151	08039A	PARTICIPANT	\N	PRESENT	0
225808	225151	14205J	PARTICIPANT	\N	EXCUSE	0
225809	225151	14001X	PARTICIPANT	\N	PRESENT	0
225810	225151	14221J	PARTICIPANT	\N	PRESENT	0
225811	225151	04057K	PARTICIPANT	\N	PRESENT	0
225812	225151	19563B	PARTICIPANT	\N	PRESENT	0
225813	225151	19593H	PARTICIPANT	\N	PRESENT	0
225814	225151	14135M	PARTICIPANT	\N	EXCUSE	0
225815	225151	14331P	PARTICIPANT	\N	PRESENT	0
225816	225151	14225N	PARTICIPANT	\N	PRESENT	0
228567	218468	08073C	PARTICIPANT	\N	PRESENT	0
228568	218468	08016S	PARTICIPANT	\N	PRESENT	0
228569	218468	19689Q	PARTICIPANT	\N	PRESENT	0
228570	218468	14029X	PARTICIPANT	\N	PRESENT	0
228571	218468	14030Q	PARTICIPANT	\N	PRESENT	0
228572	218468	19629C	PARTICIPANT	\N	PRESENT	0
228573	218468	19713W	PARTICIPANT	\N	PRESENT	0
228579	218468	04049K	PARTICIPANT	\N	PRESENT	0
228580	218468	04071H	PARTICIPANT	\N	PRESENT	0
230146	230145	04047H	PRESIDENT	0	PRESENT	0
230147	230145	19545Y	PARTICIPANT	\N	EXCUSE	0
230148	230145	14085U	PARTICIPANT	\N	PRESENT	0
230149	230145	11080N	PARTICIPANT	\N	EXCUSE	0
230150	230145	11083R	PARTICIPANT	\N	PRESENT	0
230151	230145	01057W	PARTICIPANT	\N	PRESENT	0
230152	230145	14021P	PARTICIPANT	\N	PRESENT	0
230153	230145	14157T	PARTICIPANT	\N	PRESENT	0
230154	230145	08049C	PARTICIPANT	\N	EXCUSE	0
234776	233199	05012A	PARTICIPANT	\N	PRESENT	0
234777	233199	14051J	PARTICIPANT	\N	PRESENT	0
234778	233199	08060W	PARTICIPANT	\N	PRESENT	0
234779	233199	19347U	PARTICIPANT	\N	PRESENT	0
234780	233199	19503N	PARTICIPANT	\N	PRESENT	0
234781	233199	14157T	PARTICIPANT	\N	PRESENT	0
234782	233199	19685L	PARTICIPANT	\N	PRESENT	0
234783	233199	08024S	PARTICIPANT	\N	PRESENT	0
234784	233199	19681G	PARTICIPANT	\N	PRESENT	0
234785	233199	98023Q	PARTICIPANT	\N	PRESENT	0
234786	233199	17637T	PARTICIPANT	\N	PRESENT	0
234787	233199	14038Y	PARTICIPANT	\N	PRESENT	0
234788	233199	14103D	PARTICIPANT	\N	PRESENT	0
234789	233199	14031R	PARTICIPANT	\N	PRESENT	0
234790	233199	19713W	PARTICIPANT	\N	PRESENT	0
234791	233199	08055A	PARTICIPANT	\N	PRESENT	0
234792	233199	14169X	PARTICIPANT	\N	PRESENT	0
234793	233199	15447F	PARTICIPANT	\N	PRESENT	0
234794	233199	14093U	PARTICIPANT	\N	PRESENT	0
234795	233199	14029X	PARTICIPANT	\N	PRESENT	0
234796	233199	19733B	PARTICIPANT	\N	PRESENT	0
234797	233199	08009T	PRESIDENT	0	PRESENT	0
234798	233199	19737F	PARTICIPANT	\N	PRESENT	0
234799	233199	19739H	PARTICIPANT	\N	PRESENT	0
234800	233199	19745F	PARTICIPANT	\N	PRESENT	0
234801	233199	17583W	PARTICIPANT	\N	EXCUSE	0
234802	233199	19599P	PARTICIPANT	\N	EXCUSE	0
234803	233068	08018U	PARTICIPANT	\N	EXCUSE	0
234804	233068	19447X	PARTICIPANT	\N	EXCUSE	0
234805	233329	19593H	PARTICIPANT	\N	PRESENT	0
234806	232942	04059M	PARTICIPANT	\N	PRESENT	0
234809	232942	19515S	PARTICIPANT	\N	PRESENT	0
234810	232942	04038G	PARTICIPANT	\N	PRESENT	0
234811	232942	11040E	PARTICIPANT	\N	PRESENT	0
234812	232942	19349W	PARTICIPANT	\N	PRESENT	0
234813	232942	11066Q	PARTICIPANT	\N	PRESENT	0
234814	232942	19721W	PARTICIPANT	\N	PRESENT	0
234815	232942	14073Q	PARTICIPANT	\N	PRESENT	0
234816	232942	15447F	PARTICIPANT	\N	PRESENT	0
234817	232942	19399H	PARTICIPANT	\N	PRESENT	0
234818	232942	19511N	PARTICIPANT	\N	PRESENT	0
234819	232942	14257W	PARTICIPANT	\N	PRESENT	0
234820	232942	19387D	PARTICIPANT	\N	PRESENT	0
234821	232942	19503N	PARTICIPANT	\N	PRESENT	0
234822	232942	99004R	PARTICIPANT	\N	PRESENT	0
234823	232942	19565D	PARTICIPANT	\N	PRESENT	0
234824	232942	19593H	PARTICIPANT	\N	PRESENT	0
234825	232942	19687N	PARTICIPANT	\N	PRESENT	0
234826	232942	01028R	PARTICIPANT	\N	PRESENT	0
234827	232942	19467C	PARTICIPANT	\N	PRESENT	0
234828	232942	11097X	PARTICIPANT	\N	PRESENT	0
234829	232942	04088S	PARTICIPANT	\N	PRESENT	0
234830	232942	19251M	PARTICIPANT	\N	PRESENT	0
234831	232942	19443T	PARTICIPANT	\N	PRESENT	0
234832	232942	07029T	PARTICIPANT	\N	PRESENT	0
234833	232942	14255U	PARTICIPANT	\N	PRESENT	0
234834	232942	19729F	PARTICIPANT	\N	PRESENT	0
234835	232942	14069U	PARTICIPANT	\N	PRESENT	0
234836	232942	14055N	PARTICIPANT	\N	PRESENT	0
234837	232942	19479G	PARTICIPANT	\N	PRESENT	0
234838	232942	02002K	PARTICIPANT	\N	PRESENT	0
234839	232942	14103D	PARTICIPANT	\N	PRESENT	0
234840	232942	10006L	PARTICIPANT	\N	PRESENT	0
234841	232942	19563B	PARTICIPANT	\N	PRESENT	0
234847	232942	95062K	PARTICIPANT	\N	PRESENT	0
234857	232942	14026U	PARTICIPANT	\N	PRESENT	0
234858	232942	19689Q	PARTICIPANT	\N	PRESENT	0
234859	232942	11067R	PARTICIPANT	\N	PRESENT	0
234861	232942	19413M	PARTICIPANT	\N	PRESENT	0
234862	232942	19415P	PARTICIPANT	\N	PRESENT	0
234863	232942	18083K	PARTICIPANT	\N	PRESENT	0
234866	232942	08056B	PARTICIPANT	\N	PRESENT	0
234872	232942	11012A	PARTICIPANT	\N	PRESENT	0
234873	232942	98022P	PARTICIPANT	\N	PRESENT	0
234874	232942	19575F	PARTICIPANT	\N	PRESENT	0
234875	232942	08024S	PARTICIPANT	\N	PRESENT	0
234876	232942	08041T	PARTICIPANT	\N	PRESENT	0
234877	232942	01058X	PARTICIPANT	\N	PRESENT	0
234878	232942	01024M	PARTICIPANT	\N	PRESENT	0
234879	232942	14265W	PARTICIPANT	\N	PRESENT	0
234884	232942	08019V	PARTICIPANT	\N	PRESENT	0
234885	232942	14147R	PARTICIPANT	\N	PRESENT	0
234886	232942	19731Y	PARTICIPANT	\N	PRESENT	0
234887	232942	14173T	PARTICIPANT	\N	PRESENT	0
234888	232942	14034U	PARTICIPANT	\N	PRESENT	0
234889	233065	19533U	PARTICIPANT	\N	EXCUSE	0
234903	232942	98050T	PARTICIPANT	\N	PRESENT	0
234904	232942	14028W	PARTICIPANT	\N	PRESENT	0
234905	232942	14135M	PARTICIPANT	\N	PRESENT	0
234907	232942	19253P	PARTICIPANT	\N	PRESENT	0
234908	232942	95030B	PARTICIPANT	\N	PRESENT	0
234909	232942	08055A	PARTICIPANT	\N	PRESENT	0
234910	232942	14207L	PARTICIPANT	\N	PRESENT	0
234912	232942	14105F	PARTICIPANT	\N	PRESENT	0
234913	232942	14221J	PARTICIPANT	\N	PRESENT	0
234915	232942	19543W	PARTICIPANT	\N	PRESENT	0
234916	232942	19335Q	PARTICIPANT	\N	PRESENT	0
217979	207713	95067Q	PARTICIPANT	\N	PRESENT	0
217980	207713	04071H	PARTICIPANT	\N	PRESENT	0
217981	207713	99004R	PARTICIPANT	\N	PRESENT	0
217982	207713	95030B	PARTICIPANT	\N	PRESENT	0
217983	207713	19679N	PARTICIPANT	\N	PRESENT	0
217984	207713	08069G	PARTICIPANT	\N	PRESENT	0
217985	207713	95015C	PARTICIPANT	\N	PRESENT	0
217986	207713	08010L	PARTICIPANT	\N	PRESENT	0
217987	207713	01057W	PARTICIPANT	\N	PRESENT	0
217988	207713	87003B	PARTICIPANT	\N	PRESENT	0
217989	207713	04092N	PARTICIPANT	\N	PRESENT	0
217990	207713	08028W	PARTICIPANT	\N	PRESENT	0
217991	207713	01048V	PARTICIPANT	\N	PRESENT	0
217992	207713	04042C	PARTICIPANT	\N	PRESENT	0
217993	207713	04033B	PARTICIPANT	\N	PRESENT	0
217994	207713	14105F	PARTICIPANT	\N	PRESENT	0
217995	207713	14069U	PARTICIPANT	\N	PRESENT	0
217996	207713	14053L	PARTICIPANT	\N	PRESENT	0
217997	207713	08034U	PARTICIPANT	\N	PRESENT	0
217998	207713	97011G	PARTICIPANT	\N	PRESENT	0
217999	207713	14249W	PARTICIPANT	\N	PRESENT	0
218000	207713	07034Q	PARTICIPANT	\N	PRESENT	0
218001	207713	14237S	PARTICIPANT	\N	PRESENT	0
218002	207713	14193X	PARTICIPANT	\N	PRESENT	0
218003	207713	17583W	PARTICIPANT	\N	PRESENT	0
218004	207713	04018C	PARTICIPANT	\N	PRESENT	0
218005	207713	14265W	PARTICIPANT	\N	PRESENT	0
218006	207713	08039A	PARTICIPANT	\N	PRESENT	0
218007	207713	19729F	PARTICIPANT	\N	PRESENT	0
218008	207713	14215L	PARTICIPANT	\N	PRESENT	0
218009	207713	14235Q	PARTICIPANT	\N	PRESENT	0
218010	207713	11097X	PARTICIPANT	\N	PRESENT	0
218011	207713	11056N	PARTICIPANT	\N	PRESENT	0
218012	207713	19421M	PARTICIPANT	\N	PRESENT	0
218013	207713	98018T	PARTICIPANT	\N	PRESENT	0
218014	207713	04085P	PARTICIPANT	\N	PRESENT	0
218015	207713	19515S	PARTICIPANT	\N	PRESENT	0
218016	207713	04038G	PARTICIPANT	\N	PRESENT	0
218017	207713	11080N	PARTICIPANT	\N	PRESENT	0
218018	207713	19695N	PARTICIPANT	\N	PRESENT	0
218019	207713	19565D	PARTICIPANT	\N	PRESENT	0
218020	207713	11031D	PARTICIPANT	\N	PRESENT	0
218021	207713	14157T	PARTICIPANT	\N	PRESENT	0
218022	207713	11074Q	PARTICIPANT	\N	PRESENT	0
218023	207713	04059M	PARTICIPANT	\N	PRESENT	0
218024	207713	11077T	PARTICIPANT	\N	PRESENT	0
218025	207713	14159V	PARTICIPANT	\N	PRESENT	0
218026	207713	98035U	PARTICIPANT	\N	PRESENT	0
218027	207713	14229S	PARTICIPANT	\N	PRESENT	0
218028	207713	08055A	PARTICIPANT	\N	PRESENT	0
218029	207713	01028R	PARTICIPANT	\N	PRESENT	0
218030	207713	14026U	PARTICIPANT	\N	PRESENT	0
218031	207713	08052W	PARTICIPANT	\N	PRESENT	0
218032	207713	08068F	PARTICIPANT	\N	PRESENT	0
218033	207713	04043D	PARTICIPANT	\N	PRESENT	0
218034	207713	14051J	PARTICIPANT	\N	PRESENT	0
218035	207713	08016S	PARTICIPANT	\N	PRESENT	0
218036	207713	14107H	PARTICIPANT	\N	PRESENT	0
218037	207713	08045X	PARTICIPANT	\N	PRESENT	0
218038	207713	14031R	PARTICIPANT	\N	PRESENT	0
218039	207713	14225N	PARTICIPANT	\N	PRESENT	0
218040	207713	14021P	PARTICIPANT	\N	PRESENT	0
218041	207713	92040Q	PARTICIPANT	\N	PRESENT	0
218042	207713	19715Y	PARTICIPANT	\N	PRESENT	0
218043	207713	14151M	PARTICIPANT	\N	PRESENT	0
218044	207713	14087W	PARTICIPANT	\N	PRESENT	0
218045	207713	08038Y	PARTICIPANT	\N	PRESENT	0
218046	207713	08060W	PARTICIPANT	\N	PRESENT	0
218047	207713	98050T	PARTICIPANT	\N	PRESENT	0
218048	207713	80013X	PARTICIPANT	\N	PRESENT	0
218049	207713	14191V	PARTICIPANT	\N	PRESENT	0
218050	207713	01058X	PARTICIPANT	\N	PRESENT	0
218051	207713	14028W	PARTICIPANT	\N	PRESENT	0
218052	207713	08024S	PARTICIPANT	\N	PRESENT	0
218053	207713	14197C	PARTICIPANT	\N	PRESENT	0
218054	207713	11115U	PARTICIPANT	\N	PRESENT	0
218055	207713	19667J	PARTICIPANT	\N	PRESENT	0
218056	207713	19649G	PARTICIPANT	\N	PRESENT	0
218057	207713	19647E	PARTICIPANT	\N	PRESENT	0
218058	207713	14199E	PARTICIPANT	\N	PRESENT	0
218059	207713	14079W	PARTICIPANT	\N	PRESENT	0
218060	207713	11110B	PARTICIPANT	\N	PRESENT	0
218061	207713	11066Q	PARTICIPANT	\N	PRESENT	0
218062	207713	19687N	PARTICIPANT	\N	PRESENT	0
218063	207713	12041X	PARTICIPANT	\N	PRESENT	0
218064	207713	04044E	PARTICIPANT	\N	PRESENT	0
218065	207713	08043V	PARTICIPANT	\N	PRESENT	0
218066	207713	11104D	PARTICIPANT	\N	PRESENT	0
218067	207713	98023Q	PARTICIPANT	\N	PRESENT	0
218068	207713	11048N	PARTICIPANT	\N	PRESENT	0
218069	207713	14281W	PARTICIPANT	\N	PRESENT	0
218070	207713	08035V	PARTICIPANT	\N	PRESENT	0
218071	207713	10006L	PARTICIPANT	\N	PRESENT	0
218072	207713	96004D	PARTICIPANT	\N	PRESENT	0
218073	207713	11040E	PARTICIPANT	\N	PRESENT	0
218074	207713	14147R	PARTICIPANT	\N	PRESENT	0
218075	207713	08053X	PARTICIPANT	\N	PRESENT	0
218076	207713	04086Q	PARTICIPANT	\N	PRESENT	0
218077	207713	19727D	PARTICIPANT	\N	PRESENT	0
218078	207713	19531S	PARTICIPANT	\N	PRESENT	0
218079	207713	14187A	PARTICIPANT	\N	PRESENT	0
218080	207713	14081Q	PARTICIPANT	\N	PRESENT	0
218081	207713	10015M	PARTICIPANT	\N	PRESENT	0
218082	207713	14065Q	PARTICIPANT	\N	PRESENT	0
218083	207713	19549D	PARTICIPANT	\N	PRESENT	0
218084	207713	95062K	PARTICIPANT	\N	PRESENT	0
218085	207713	08012N	PARTICIPANT	\N	PRESENT	0
218086	207713	08017T	PARTICIPANT	\N	PRESENT	0
218087	207713	14357A	PARTICIPANT	\N	PRESENT	0
218088	207713	19525U	PARTICIPANT	\N	PRESENT	0
218089	207713	14329V	PARTICIPANT	\N	PRESENT	0
218090	207713	14085U	PARTICIPANT	\N	PRESENT	0
218091	207713	14121F	PARTICIPANT	\N	PRESENT	0
218092	207713	08058D	PARTICIPANT	\N	PRESENT	0
218093	207713	17779H	PARTICIPANT	\N	PRESENT	0
218094	207713	14061L	PARTICIPANT	\N	PRESENT	0
218095	207713	19489J	PARTICIPANT	\N	PRESENT	0
218096	207713	08047A	PARTICIPANT	\N	PRESENT	0
218097	207713	11041F	PARTICIPANT	\N	PRESENT	0
218098	207713	19599P	PARTICIPANT	\N	PRESENT	0
218099	207713	19725B	PARTICIPANT	\N	PRESENT	0
218100	207713	08014Q	PARTICIPANT	\N	PRESENT	0
218101	207713	14001X	PARTICIPANT	\N	PRESENT	0
218102	207713	14227Q	PARTICIPANT	\N	PRESENT	0
218103	207713	19683J	PARTICIPANT	\N	PRESENT	0
218104	207713	11103C	PARTICIPANT	\N	PRESENT	0
218105	207713	19295A	PARTICIPANT	\N	PRESENT	0
218106	207713	11054L	PARTICIPANT	\N	PRESENT	0
218107	207713	11045K	PARTICIPANT	\N	PRESENT	0
218108	207713	98024R	PARTICIPANT	\N	PRESENT	0
218109	207713	14257W	PARTICIPANT	\N	PRESENT	0
218110	207713	14097Y	PARTICIPANT	\N	PRESENT	0
218111	207713	19631V	PARTICIPANT	\N	PRESENT	0
218112	207713	14063N	PARTICIPANT	\N	PRESENT	0
218113	207713	11049P	PARTICIPANT	\N	PRESENT	0
218114	207713	19527W	PARTICIPANT	\N	PRESENT	0
218115	207713	11067R	PARTICIPANT	\N	PRESENT	0
218116	207713	07029T	PARTICIPANT	\N	PRESENT	0
218117	207713	14135M	PARTICIPANT	\N	PRESENT	0
218123	207713	19251M	PARTICIPANT	\N	PRESENT	0
218119	207713	19591F	PARTICIPANT	\N	PRESENT	0
218120	207713	14071N	PARTICIPANT	\N	PRESENT	0
218121	207713	19551W	PARTICIPANT	\N	PRESENT	0
218122	207713	05008E	PARTICIPANT	\N	PRESENT	0
218124	207713	04008A	PARTICIPANT	\N	PRESENT	0
218125	207713	11026G	PARTICIPANT	\N	PRESENT	0
218126	207713	19413M	PARTICIPANT	\N	PRESENT	0
218127	207713	19447X	PARTICIPANT	\N	PRESENT	0
218128	207713	08061X	PARTICIPANT	\N	PRESENT	0
218129	207713	95063L	PARTICIPANT	\N	PRESENT	0
218130	207713	14038Y	PARTICIPANT	\N	PRESENT	0
218131	207713	95037J	PARTICIPANT	\N	PRESENT	0
218132	207713	98029W	PARTICIPANT	\N	PRESENT	0
218133	207713	04045F	PARTICIPANT	\N	PRESENT	0
218134	207713	19673G	PARTICIPANT	\N	PRESENT	0
218135	207713	19651A	PARTICIPANT	\N	PRESENT	0
218136	207713	14239U	PARTICIPANT	\N	PRESENT	0
218137	207713	14041T	PARTICIPANT	\N	PRESENT	0
218138	207713	11083R	PARTICIPANT	\N	PRESENT	0
218139	207713	14033T	PARTICIPANT	\N	PRESENT	0
218140	207713	19349W	PARTICIPANT	\N	PRESENT	0
218141	207713	19543W	PARTICIPANT	\N	PRESENT	0
218142	207713	11090Q	PARTICIPANT	\N	PRESENT	0
218143	207713	19269X	PARTICIPANT	\N	PRESENT	0
218144	207713	19697Q	PARTICIPANT	\N	PRESENT	0
218145	207713	08021P	PARTICIPANT	\N	PRESENT	0
218146	207713	04034C	PARTICIPANT	\N	PRESENT	0
218147	207713	14039A	PARTICIPANT	\N	PRESENT	0
221537	220048	11010L	PARTICIPANT	\N	EXCUSE	0
220359	220358	14033T	PARTICIPANT	\N	PRESENT	0
220360	220356	14033T	PARTICIPANT	\N	PRESENT	0
220362	220361	19507S	PARTICIPANT	\N	PRESENT	0
220363	220361	14207L	PARTICIPANT	\N	PRESENT	0
222237	222236	19709B	PARTICIPANT	\N	PRESENT	0
222244	220241	14205J	PARTICIPANT	\N	PRESENT	0
224861	222384	16685X	PARTICIPANT	\N	PRESENT	0
224862	222384	14055N	PARTICIPANT	\N	PRESENT	0
224863	222384	08053X	PARTICIPANT	\N	PRESENT	0
224864	222384	14097Y	PARTICIPANT	\N	PRESENT	0
224865	222384	04035D	PARTICIPANT	\N	PRESENT	0
224866	222384	14028W	PARTICIPANT	\N	PRESENT	0
224867	222384	14105F	PARTICIPANT	\N	PRESENT	0
224868	222384	98022P	PARTICIPANT	\N	PRESENT	0
224869	222384	11064N	PARTICIPANT	\N	PRESENT	0
224914	222384	04040A	PARTICIPANT	\N	PRESENT	0
224915	222384	08061X	PARTICIPANT	\N	PRESENT	0
224916	222384	98029W	PARTICIPANT	\N	PRESENT	0
224917	222384	01062T	PARTICIPANT	\N	PRESENT	0
224918	222384	01058X	PARTICIPANT	\N	PRESENT	0
224919	223254	08019V	PARTICIPANT	\N	PRESENT	0
224920	222384	19669L	PARTICIPANT	\N	PRESENT	0
224921	222384	11115U	PARTICIPANT	\N	PRESENT	0
224922	218299	14034U	PARTICIPANT	\N	PRESENT	0
224924	224180	04070G	PRESIDENT	0	PRESENT	0
224925	224180	19699S	PARTICIPANT	\N	PRESENT	0
224926	224180	19533U	PARTICIPANT	\N	PRESENT	0
224927	224180	95015C	PARTICIPANT	\N	PRESENT	0
224928	224180	04033B	PARTICIPANT	\N	PRESENT	0
224929	224180	14229S	PARTICIPANT	\N	PRESENT	0
224930	224180	14241N	PARTICIPANT	\N	PRESENT	0
224931	224180	19573D	PARTICIPANT	\N	PRESENT	0
224932	224180	14039A	PARTICIPANT	\N	PRESENT	0
224933	224180	14107H	PARTICIPANT	\N	PRESENT	0
224934	224180	08017T	PARTICIPANT	\N	PRESENT	0
224935	224180	92040Q	PARTICIPANT	\N	PRESENT	0
224936	224180	07033P	PARTICIPANT	\N	PRESENT	0
224937	224180	08012N	PARTICIPANT	\N	PRESENT	0
224938	224180	14249W	PARTICIPANT	\N	PRESENT	0
224939	224180	08031R	PARTICIPANT	\N	PRESENT	0
224940	224180	19593H	PARTICIPANT	\N	PRESENT	0
224941	224180	19643A	PARTICIPANT	\N	PRESENT	0
224942	224180	14059S	PARTICIPANT	\N	PRESENT	0
224943	224180	14061L	PARTICIPANT	\N	PRESENT	0
224944	224180	04057K	PARTICIPANT	\N	PRESENT	0
224945	224180	19611R	PARTICIPANT	\N	PRESENT	0
224946	224180	08043V	PARTICIPANT	\N	PRESENT	0
224947	224180	19693L	PARTICIPANT	\N	PRESENT	0
224948	224180	19399H	PARTICIPANT	\N	PRESENT	0
224949	224180	87003B	PARTICIPANT	\N	PRESENT	0
224950	224180	14030Q	PARTICIPANT	\N	PRESENT	0
224951	224180	19731Y	PARTICIPANT	\N	PRESENT	0
224952	224180	08020N	PARTICIPANT	\N	PRESENT	0
224953	224180	14251Q	PARTICIPANT	\N	PRESENT	0
224954	224180	04059M	PARTICIPANT	\N	PRESENT	0
224955	224180	19735D	PARTICIPANT	\N	PRESENT	0
224956	224180	14063N	PARTICIPANT	\N	PRESENT	0
224957	224180	14109K	PARTICIPANT	\N	PRESENT	0
224958	224180	11083R	PARTICIPANT	\N	PRESENT	0
224959	224180	14123H	PARTICIPANT	\N	PRESENT	0
224960	224180	11104D	PARTICIPANT	\N	PRESENT	0
224961	224180	11043H	PARTICIPANT	\N	PRESENT	0
224962	224180	04018C	PARTICIPANT	\N	PRESENT	0
224963	224180	12041X	PARTICIPANT	\N	PRESENT	0
224964	224180	08035V	PARTICIPANT	\N	PRESENT	0
224965	224180	19329S	PARTICIPANT	\N	PRESENT	0
224966	223290	11077T	PARTICIPANT	\N	PRESENT	0
224967	223290	11031D	PARTICIPANT	\N	PRESENT	0
224968	223290	14042U	PARTICIPANT	\N	PRESENT	0
224969	223290	19335Q	PARTICIPANT	\N	PRESENT	0
225018	218299	01057W	PARTICIPANT	\N	PRESENT	0
225019	218299	14225N	PARTICIPANT	\N	PRESENT	0
225020	218299	11040E	PARTICIPANT	\N	PRESENT	0
225021	218299	04038G	PARTICIPANT	\N	PRESENT	0
225022	218299	14121F	PARTICIPANT	\N	PRESENT	0
225023	218299	19349W	PARTICIPANT	\N	PRESENT	0
225024	218299	19387D	PARTICIPANT	\N	PRESENT	0
225025	218299	14231L	PARTICIPANT	\N	PRESENT	0
225026	218299	14179A	PARTICIPANT	\N	PRESENT	0
225027	218299	14327T	PARTICIPANT	\N	PRESENT	0
225028	218299	07029T	PARTICIPANT	\N	PRESENT	0
225029	218299	19729F	PARTICIPANT	\N	PRESENT	0
225030	218299	04086Q	PARTICIPANT	\N	PRESENT	0
225031	218299	19711U	PARTICIPANT	\N	PRESENT	0
225032	218299	14173T	PARTICIPANT	\N	PRESENT	0
225033	218299	14083S	PARTICIPANT	\N	PRESENT	0
225034	218299	88008L	PARTICIPANT	\N	PRESENT	0
225035	218299	14001X	PARTICIPANT	\N	PRESENT	0
225036	218299	11074Q	PARTICIPANT	\N	PRESENT	0
225037	218299	19531S	PARTICIPANT	\N	PRESENT	0
225038	218299	19667J	PARTICIPANT	\N	PRESENT	0
220353	220352	04089T	PARTICIPANT	\N	PRESENT	0
220355	220354	04089T	PARTICIPANT	\N	PRESENT	0
225039	218299	14061L	PARTICIPANT	\N	PRESENT	0
225040	218299	19383Y	PARTICIPANT	\N	PRESENT	0
225041	218299	19681G	PARTICIPANT	\N	PRESENT	0
225042	218299	19479G	PARTICIPANT	\N	PRESENT	0
225043	218299	95063L	PARTICIPANT	\N	PRESENT	0
225044	218299	14191V	PARTICIPANT	\N	PRESENT	0
225045	218299	19545Y	PARTICIPANT	\N	PRESENT	0
225046	218299	08011M	PARTICIPANT	\N	PRESENT	0
225047	218299	19647E	PARTICIPANT	\N	PRESENT	0
225048	218299	14253S	PARTICIPANT	\N	PRESENT	0
225049	218299	11104D	PARTICIPANT	\N	PRESENT	0
225051	218299	08014Q	PARTICIPANT	\N	PRESENT	0
225052	218299	08034U	PARTICIPANT	\N	PRESENT	0
225053	218299	08010L	PARTICIPANT	\N	PRESENT	0
225054	218299	17583W	PARTICIPANT	\N	PRESENT	0
225055	218299	11070L	PARTICIPANT	\N	PRESENT	0
225056	218299	19621T	PARTICIPANT	\N	PRESENT	0
225057	218299	19671E	PARTICIPANT	\N	PRESENT	0
225058	218299	14085U	PARTICIPANT	\N	PRESENT	0
225071	224180	14073Q	PARTICIPANT	\N	PRESENT	0
225072	218299	08020N	PARTICIPANT	\N	PRESENT	0
225073	218299	14069U	PARTICIPANT	\N	PRESENT	0
225074	218299	19483C	PARTICIPANT	\N	PRESENT	0
225075	218299	19573D	PARTICIPANT	\N	PRESENT	0
225076	218299	19651A	PARTICIPANT	\N	PRESENT	0
225077	218299	95015C	PARTICIPANT	\N	PRESENT	0
225078	218299	19593H	PARTICIPANT	\N	PRESENT	0
225126	218299	19737F	PARTICIPANT	\N	PRESENT	0
225132	223266	08018U	PARTICIPANT	\N	PRESENT	0
225134	218299	14029X	PARTICIPANT	\N	PRESENT	0
225135	218299	11048N	PARTICIPANT	\N	PRESENT	0
225136	218299	14229S	PARTICIPANT	\N	PRESENT	0
225137	223290	04045F	PARTICIPANT	\N	PRESENT	0
225138	218299	19649G	PARTICIPANT	\N	PRESENT	0
225139	218299	19443T	PARTICIPANT	\N	PRESENT	0
225140	218299	07004J	PARTICIPANT	\N	PRESENT	0
225141	218299	01034P	PARTICIPANT	\N	PRESENT	0
225143	218299	14267Y	PARTICIPANT	\N	PRESENT	0
225144	218299	14105F	PARTICIPANT	\N	PRESENT	0
225468	223399	19697Q	PARTICIPANT	\N	PRESENT	0
225469	223399	14061L	PARTICIPANT	\N	PRESENT	0
225470	223399	95041E	PARTICIPANT	\N	PRESENT	0
225471	223399	14073Q	PARTICIPANT	\N	PRESENT	0
225472	223399	14028W	PARTICIPANT	\N	PRESENT	0
225473	223399	19695N	PARTICIPANT	\N	PRESENT	0
225474	223399	11090Q	PARTICIPANT	\N	PRESENT	0
225475	223399	19585H	PARTICIPANT	\N	PRESENT	0
225476	223399	19631V	PARTICIPANT	\N	PRESENT	0
225477	223399	08068F	PARTICIPANT	\N	PRESENT	0
225478	223399	08015R	PARTICIPANT	\N	PRESENT	0
225479	223399	19737F	PARTICIPANT	\N	PRESENT	0
225480	223399	19349W	PARTICIPANT	\N	PRESENT	0
225481	223399	19369B	PARTICIPANT	\N	PRESENT	0
225482	223399	11043H	PARTICIPANT	\N	PRESENT	0
225483	223399	08028W	PRESIDENT	0	PRESENT	0
225484	223399	19563B	PARTICIPANT	\N	PRESENT	0
225485	223399	04061F	PARTICIPANT	\N	PRESENT	0
225486	223399	14257W	PARTICIPANT	\N	PRESENT	0
225487	223399	14237S	PARTICIPANT	\N	EXCUSE	0
225488	223399	14065Q	PARTICIPANT	\N	EXCUSE	0
225489	223399	14193X	PARTICIPANT	\N	EXCUSE	0
225490	223399	14219Q	PARTICIPANT	\N	EXCUSE	0
225491	223399	19681G	PARTICIPANT	\N	EXCUSE	0
225492	218300	19699S	PARTICIPANT	\N	PRESENT	0
225509	218300	19543W	PARTICIPANT	\N	PRESENT	0
225510	218300	88008L	PARTICIPANT	\N	PRESENT	0
225511	218300	19333N	PARTICIPANT	\N	PRESENT	0
225325	218300	19335Q	PARTICIPANT	\N	PRESENT	0
225326	218300	14087W	PARTICIPANT	\N	PRESENT	0
225327	218300	14039A	PARTICIPANT	\N	PRESENT	0
225328	218300	14083S	PARTICIPANT	\N	PRESENT	0
225329	218300	80013X	PARTICIPANT	\N	PRESENT	0
225330	218300	04047H	PARTICIPANT	\N	PRESENT	0
225331	218300	08068F	PARTICIPANT	\N	PRESENT	0
225332	218300	98022P	PARTICIPANT	\N	PRESENT	0
225333	218300	14157T	PARTICIPANT	\N	PRESENT	0
225334	218300	19349W	PARTICIPANT	\N	PRESENT	0
225335	218300	19647E	PARTICIPANT	\N	PRESENT	0
225336	218300	14061L	PARTICIPANT	\N	PRESENT	0
225337	218300	04086Q	PARTICIPANT	\N	PRESENT	0
225338	218300	14159V	PARTICIPANT	\N	PRESENT	0
225339	218300	14229S	PARTICIPANT	\N	PRESENT	0
225340	218300	08073C	PARTICIPANT	\N	PRESENT	0
225341	218300	14031R	PARTICIPANT	\N	PRESENT	0
225342	218300	14253S	PARTICIPANT	\N	PRESENT	0
225343	218300	14331P	PARTICIPANT	\N	PRESENT	0
225344	218300	19347U	PARTICIPANT	\N	PRESENT	0
225345	218300	14221J	PARTICIPANT	\N	PRESENT	0
225346	218300	14195A	PARTICIPANT	\N	PRESENT	0
225347	218300	19673G	PARTICIPANT	\N	PRESENT	0
225348	218300	11097X	PARTICIPANT	\N	PRESENT	0
225349	218300	14065Q	PARTICIPANT	\N	PRESENT	0
225350	218300	14030Q	PARTICIPANT	\N	PRESENT	0
225351	218300	08019V	PARTICIPANT	\N	PRESENT	0
225352	218300	98029W	PARTICIPANT	\N	PRESENT	0
225353	218300	14223L	PARTICIPANT	\N	PRESENT	0
225357	218300	19723Y	PARTICIPANT	\N	PRESENT	0
225358	218300	19693L	PARTICIPANT	\N	PRESENT	0
225359	218300	14281W	PARTICIPANT	\N	PRESENT	0
225369	218300	14073Q	PARTICIPANT	\N	PRESENT	0
225370	218300	14109K	PARTICIPANT	\N	PRESENT	0
225371	218300	14042U	PARTICIPANT	\N	PRESENT	0
225372	218300	19531S	PARTICIPANT	\N	PRESENT	0
225375	218300	11012A	PARTICIPANT	\N	PRESENT	0
225377	218300	14053L	PARTICIPANT	\N	PRESENT	0
225378	218300	19563B	PARTICIPANT	\N	PRESENT	0
225386	218300	19443T	PARTICIPANT	\N	PRESENT	0
225387	218300	14227Q	PARTICIPANT	\N	PRESENT	0
225388	218300	11103C	PARTICIPANT	\N	PRESENT	0
225389	218300	01048V	PARTICIPANT	\N	PRESENT	0
225390	218300	14028W	PARTICIPANT	\N	PRESENT	0
225391	218300	19479G	PARTICIPANT	\N	PRESENT	0
225392	218300	87003B	PARTICIPANT	\N	PRESENT	0
225393	218300	19565D	PARTICIPANT	\N	PRESENT	0
225394	218300	19695N	PARTICIPANT	\N	PRESENT	0
225395	218300	19697Q	PARTICIPANT	\N	PRESENT	0
225396	218300	11043H	PARTICIPANT	\N	PRESENT	0
225397	218300	08039A	PARTICIPANT	\N	PRESENT	0
225398	218300	11049P	PARTICIPANT	\N	PRESENT	0
225399	218300	19585H	PARTICIPANT	\N	PRESENT	0
225400	218300	08061X	PARTICIPANT	\N	PRESENT	0
225401	218300	14038Y	PARTICIPANT	\N	PRESENT	0
225402	218300	19515S	PARTICIPANT	\N	PRESENT	0
225403	218300	14026U	PARTICIPANT	\N	PRESENT	0
225404	218300	14265W	PARTICIPANT	\N	PRESENT	0
225405	218300	14071N	PARTICIPANT	\N	PRESENT	0
225406	218300	16685X	PARTICIPANT	\N	PRESENT	0
225407	218300	19447X	PARTICIPANT	\N	PRESENT	0
225408	218300	19533U	PARTICIPANT	\N	PRESENT	0
225409	218300	95015C	PARTICIPANT	\N	PRESENT	0
225410	218300	19649G	PARTICIPANT	\N	PRESENT	0
225411	218300	08017T	PARTICIPANT	\N	PRESENT	0
225412	218300	14085U	PARTICIPANT	\N	PRESENT	0
225413	218300	08014Q	PARTICIPANT	\N	PRESENT	0
225414	218300	08052W	PARTICIPANT	\N	PRESENT	0
225415	218300	08031R	PARTICIPANT	\N	PRESENT	0
225416	218300	11026G	PARTICIPANT	\N	PRESENT	0
225417	218300	04018C	PARTICIPANT	\N	PRESENT	0
225418	218300	14215L	PARTICIPANT	\N	PRESENT	0
225419	218300	11048N	PARTICIPANT	\N	PRESENT	0
225420	218300	14041T	PARTICIPANT	\N	PRESENT	0
225421	218300	89017R	PARTICIPANT	\N	PRESENT	0
225423	218300	19551W	PARTICIPANT	\N	PRESENT	0
225424	218300	19621T	PARTICIPANT	\N	PRESENT	0
225425	218300	14249W	PARTICIPANT	\N	PRESENT	0
225426	218300	95041E	PARTICIPANT	\N	PRESENT	0
225427	218300	04043D	PARTICIPANT	\N	PRESENT	0
225463	218300	19593H	PARTICIPANT	\N	PRESENT	0
225464	218300	14147R	PARTICIPANT	\N	PRESENT	0
225465	218300	14213J	PARTICIPANT	\N	PRESENT	0
225467	218300	14251Q	PARTICIPANT	\N	PRESENT	0
225493	223622	05012A	PARTICIPANT	\N	PRESENT	0
225494	223622	04045F	PARTICIPANT	\N	PRESENT	0
225495	223622	14063N	PARTICIPANT	\N	PRESENT	0
225496	223622	19575F	PARTICIPANT	\N	PRESENT	0
225497	223622	08068F	PARTICIPANT	\N	PRESENT	0
225498	223622	11099A	PARTICIPANT	\N	PRESENT	0
225503	223625	04045F	PARTICIPANT	\N	PRESENT	0
225500	223622	14253S	PARTICIPANT	\N	PRESENT	0
225501	223625	14063N	PARTICIPANT	\N	PRESENT	0
225502	223625	05012A	PARTICIPANT	\N	PRESENT	0
225504	223625	19575F	PARTICIPANT	\N	PRESENT	0
225505	223625	08068F	PARTICIPANT	\N	PRESENT	0
225506	223625	11099A	PARTICIPANT	\N	PRESENT	0
225507	223625	04049K	PARTICIPANT	\N	PRESENT	0
225508	223625	14253S	PARTICIPANT	\N	PRESENT	0
225855	223805	80013X	PARTICIPANT	\N	PRESENT	0
225857	223805	19723Y	PARTICIPANT	\N	PRESENT	0
225859	223805	01048V	PRESIDENT	0	PRESENT	0
225860	223805	08053X	PARTICIPANT	\N	PRESENT	0
225863	223805	19533U	PARTICIPANT	\N	PRESENT	0
225864	223805	19503N	PARTICIPANT	\N	PRESENT	0
225866	223805	01058X	PARTICIPANT	\N	PRESENT	0
225867	223805	04043D	PARTICIPANT	\N	PRESENT	0
225870	223805	14299H	PARTICIPANT	\N	PRESENT	0
225934	218821	19737F	PARTICIPANT	\N	PRESENT	0
226046	218305	11077T	PARTICIPANT	\N	PRESENT	0
226047	218305	19663E	PARTICIPANT	\N	PRESENT	0
226048	218305	14041T	PARTICIPANT	\N	PRESENT	0
226049	218305	19657G	PARTICIPANT	\N	PRESENT	0
226050	218305	19577H	PARTICIPANT	\N	PRESENT	0
226051	218305	14087W	PARTICIPANT	\N	PRESENT	0
226052	218305	11097X	PARTICIPANT	\N	PRESENT	0
226053	218305	08052W	PARTICIPANT	\N	PRESENT	0
226054	218305	19683J	PARTICIPANT	\N	PRESENT	0
226055	218305	11031D	PARTICIPANT	\N	PRESENT	0
226056	218305	19711U	PARTICIPANT	\N	PRESENT	0
226057	218305	19697Q	PARTICIPANT	\N	PRESENT	0
226058	218305	01034P	PARTICIPANT	\N	PRESENT	0
226059	218305	88008L	PARTICIPANT	\N	PRESENT	0
226060	218305	11012A	PARTICIPANT	\N	PRESENT	0
226061	218305	19553Y	PARTICIPANT	\N	PRESENT	0
226063	218305	19737F	PARTICIPANT	\N	PRESENT	0
226064	218305	11063M	PARTICIPANT	\N	PRESENT	0
226065	218305	14169X	PARTICIPANT	\N	PRESENT	0
226066	218305	14033T	PARTICIPANT	\N	PRESENT	0
226067	218305	98050T	PARTICIPANT	\N	PRESENT	0
226068	218305	19689Q	PARTICIPANT	\N	PRESENT	0
226069	218305	19681G	PARTICIPANT	\N	PRESENT	0
226070	218305	11067R	PARTICIPANT	\N	PRESENT	0
226071	218305	19503N	PARTICIPANT	\N	PRESENT	0
226072	218305	04092N	PARTICIPANT	\N	PRESENT	0
226073	218305	98005N	PARTICIPANT	\N	PRESENT	0
226075	226074	04035D	PARTICIPANT	\N	PRESENT	0
226076	218305	11048N	PARTICIPANT	\N	PRESENT	0
226077	218305	80013X	PARTICIPANT	\N	PRESENT	0
226078	218305	14241N	PARTICIPANT	\N	PRESENT	0
226079	218305	08045X	PARTICIPANT	\N	PRESENT	0
226082	218305	14251Q	PARTICIPANT	\N	PRESENT	0
226083	218305	14083S	PARTICIPANT	\N	PRESENT	0
226084	218305	08010L	PARTICIPANT	\N	PRESENT	0
226086	226085	87003B	PARTICIPANT	\N	PRESENT	0
226087	226085	11104D	PARTICIPANT	\N	PRESENT	0
226088	218305	19415P	PARTICIPANT	\N	PRESENT	0
226098	218305	19347U	PARTICIPANT	\N	PRESENT	0
226102	218305	04059M	PARTICIPANT	\N	PRESENT	0
226104	218305	19591F	PARTICIPANT	\N	PRESENT	0
214489	214488	14001X	PARTICIPANT	\N	PRESENT	0
214490	214488	11026G	PARTICIPANT	\N	PRESENT	0
214491	214488	14281W	PARTICIPANT	\N	PRESENT	0
215503	214719	08012N	PARTICIPANT	\N	PRESENT	0
225238	225237	11053K	PARTICIPANT	\N	PRESENT	0
225239	225237	14159V	PARTICIPANT	\N	PRESENT	0
225240	225237	05012A	PARTICIPANT	\N	PRESENT	0
225919	225918	14133K	PARTICIPANT	\N	PRESENT	0
225920	225918	14097Y	PARTICIPANT	\N	PRESENT	0
225950	225949	19735D	PARTICIPANT	\N	PRESENT	0
227653	227651	19543W	PARTICIPANT	\N	PRESENT	0
225952	225935	19735D	PARTICIPANT	\N	PRESENT	0
225953	225935	14087W	PARTICIPANT	\N	PRESENT	0
227652	227651	14147R	PARTICIPANT	\N	PRESENT	0
227654	227651	14231L	PARTICIPANT	\N	PRESENT	0
227655	227651	11045K	PARTICIPANT	\N	PRESENT	0
227657	227656	14147R	PARTICIPANT	\N	PRESENT	0
227658	227656	11033F	PARTICIPANT	\N	PRESENT	0
227659	227656	19629C	PARTICIPANT	\N	PRESENT	0
227660	227656	04047H	PARTICIPANT	\N	PRESENT	0
227661	227656	11045K	PARTICIPANT	\N	PRESENT	0
228516	228515	11053K	PARTICIPANT	\N	PRESENT	0
228517	228515	14159V	PARTICIPANT	\N	PRESENT	0
228518	228515	05012A	PARTICIPANT	\N	PRESENT	0
229687	229183	14147R	PARTICIPANT	\N	PRESENT	0
229688	229183	04047H	PARTICIPANT	\N	PRESENT	0
229689	229183	19629C	PARTICIPANT	\N	PRESENT	0
230448	230446	14255U	PARTICIPANT	\N	PRESENT	0
230523	230521	14255U	PARTICIPANT	\N	PRESENT	0
230540	230538	14255U	PARTICIPANT	\N	PRESENT	0
230548	230544	14255U	PARTICIPANT	\N	PRESENT	0
230560	230556	14255U	PARTICIPANT	\N	PRESENT	0
230573	230572	14255U	PARTICIPANT	\N	PRESENT	0
232422	230024	98053W	PARTICIPANT	\N	EXCUSE	0
232499	232498	04047H	PARTICIPANT	\N	PRESENT	0
232500	232498	19673G	PARTICIPANT	\N	PRESENT	0
232501	232498	95063L	PARTICIPANT	\N	PRESENT	0
232503	232498	11026G	PARTICIPANT	\N	PRESENT	0
232506	232504	04047H	PARTICIPANT	\N	PRESENT	0
232507	232504	19673G	PARTICIPANT	\N	PRESENT	0
232508	232504	14021P	PARTICIPANT	\N	PRESENT	0
232510	232504	11026G	PARTICIPANT	\N	PRESENT	0
232511	232504	95063L	PARTICIPANT	\N	PRESENT	0
232513	232512	04047H	PARTICIPANT	\N	PRESENT	0
232514	232512	19673G	PARTICIPANT	\N	PRESENT	0
232515	232512	14021P	PARTICIPANT	\N	PRESENT	0
232516	232512	11026G	PARTICIPANT	\N	PRESENT	0
232518	232517	04047H	PARTICIPANT	\N	PRESENT	0
232519	232517	19673G	PARTICIPANT	\N	PRESENT	0
232520	232517	14021P	PARTICIPANT	\N	PRESENT	0
232521	232517	11026G	PARTICIPANT	\N	PRESENT	0
232524	232523	04047H	PARTICIPANT	\N	PRESENT	0
232526	232523	14021P	PARTICIPANT	\N	PRESENT	0
232527	232523	11026G	PARTICIPANT	\N	PRESENT	0
232529	232528	04047H	PARTICIPANT	\N	PRESENT	0
232530	232528	11026G	PARTICIPANT	\N	PRESENT	0
233301	233065	19553Y	PARTICIPANT	\N	EXCUSE	0
233302	233065	19511N	PARTICIPANT	\N	EXCUSE	0
233303	233065	19683J	PARTICIPANT	\N	EXCUSE	0
233304	233065	19709B	PARTICIPANT	\N	EXCUSE	0
233305	233065	04043D	PARTICIPANT	\N	EXCUSE	0
233306	233065	19593H	PARTICIPANT	\N	PRESENT	0
233307	233065	01048V	PRESIDENT	0	PRESENT	0
233325	233323	14030Q	PARTICIPANT	\N	PRESENT	0
233326	233323	08031R	PARTICIPANT	\N	PRESENT	0
233327	233324	19577H	PARTICIPANT	\N	PRESENT	0
233328	233324	08043V	PARTICIPANT	\N	PRESENT	0
234917	232942	14083S	PARTICIPANT	\N	PRESENT	0
234918	232942	19713W	PARTICIPANT	\N	PRESENT	0
234919	232942	14215L	PARTICIPANT	\N	PRESENT	0
234920	232942	19581D	PARTICIPANT	\N	PRESENT	0
234921	232942	08053X	PARTICIPANT	\N	PRESENT	0
234922	232942	19525U	PARTICIPANT	\N	PRESENT	0
234923	232942	14109K	PARTICIPANT	\N	PRESENT	0
234924	232942	19583F	PARTICIPANT	\N	PRESENT	0
234925	232942	14121F	PARTICIPANT	\N	PRESENT	0
234926	232942	19549D	PARTICIPANT	\N	PRESENT	0
234927	232942	14267Y	PARTICIPANT	\N	PRESENT	0
234928	232942	08020N	PARTICIPANT	\N	PRESENT	0
234929	232942	14038Y	PARTICIPANT	\N	PRESENT	0
234930	232942	19741B	PARTICIPANT	\N	PRESENT	0
234931	232942	14249W	PARTICIPANT	\N	PRESENT	0
234932	232942	19671E	PARTICIPANT	\N	PRESENT	0
234933	232942	80013X	PARTICIPANT	\N	PRESENT	0
234935	234934	14041T	PARTICIPANT	\N	PRESENT	0
234936	234934	01024M	PARTICIPANT	\N	PRESENT	0
234937	232942	14197C	PARTICIPANT	\N	PRESENT	0
234939	234938	01024M	PARTICIPANT	\N	PRESENT	0
234940	234938	14041T	PARTICIPANT	\N	PRESENT	0
234941	232942	16685X	PARTICIPANT	\N	PRESENT	0
234942	232942	14107H	PARTICIPANT	\N	PRESENT	0
234943	232942	11026G	PARTICIPANT	\N	PRESENT	0
234944	232942	14239U	PARTICIPANT	\N	PRESENT	0
235018	232943	80013X	PARTICIPANT	\N	PRESENT	0
235019	232943	14281W	PARTICIPANT	\N	PRESENT	0
235020	232943	14197C	PARTICIPANT	\N	PRESENT	0
235021	232943	19727D	PARTICIPANT	\N	PRESENT	0
235022	232943	14235Q	PARTICIPANT	\N	PRESENT	0
235023	232943	11033F	PARTICIPANT	\N	PRESENT	0
235024	232943	11026G	PARTICIPANT	\N	PRESENT	0
235025	232943	11045K	PARTICIPANT	\N	PRESENT	0
235026	232943	19697Q	PARTICIPANT	\N	PRESENT	0
235027	232943	14239U	PARTICIPANT	\N	PRESENT	0
235028	232943	95062K	PARTICIPANT	\N	PRESENT	0
235029	232943	14038Y	PARTICIPANT	\N	PRESENT	0
235030	232943	19515S	PARTICIPANT	\N	PRESENT	0
235031	232943	11063M	PARTICIPANT	\N	PRESENT	0
235032	232943	11067R	PARTICIPANT	\N	PRESENT	0
235033	232943	19503N	PARTICIPANT	\N	PRESENT	0
235034	232943	19715Y	PARTICIPANT	\N	PRESENT	0
235035	232943	19649G	PARTICIPANT	\N	PRESENT	0
235036	232943	14001X	PARTICIPANT	\N	PRESENT	0
235037	232943	14063N	PARTICIPANT	\N	PRESENT	0
235038	232943	14207L	PARTICIPANT	\N	PRESENT	0
235039	232943	19525U	PARTICIPANT	\N	PRESENT	0
235040	232943	08045X	PARTICIPANT	\N	PRESENT	0
235041	232943	11072N	PARTICIPANT	\N	PRESENT	0
235042	232943	19349W	PARTICIPANT	\N	PRESENT	0
235043	232943	19549D	PARTICIPANT	\N	PRESENT	0
235044	232943	19583F	PARTICIPANT	\N	PRESENT	0
235045	232943	14195A	PARTICIPANT	\N	PRESENT	0
235046	232943	19691J	PARTICIPANT	\N	PRESENT	0
235047	232943	19713W	PARTICIPANT	\N	PRESENT	0
235048	232943	14042U	PARTICIPANT	\N	PRESENT	0
235049	232943	19737F	PARTICIPANT	\N	PRESENT	0
235050	232943	19441R	PARTICIPANT	\N	PRESENT	0
235051	232943	14103D	PARTICIPANT	\N	PRESENT	0
235052	232943	14327T	PARTICIPANT	\N	PRESENT	0
235053	232943	19581D	PARTICIPANT	\N	PRESENT	0
235054	232943	19747H	PARTICIPANT	\N	PRESENT	0
235055	232943	14267Y	PARTICIPANT	\N	PRESENT	0
235056	232943	11031D	PARTICIPANT	\N	PRESENT	0
235057	232943	19577H	PARTICIPANT	\N	PRESENT	0
235058	232943	11097X	PARTICIPANT	\N	PRESENT	0
235059	232943	19671E	PARTICIPANT	\N	PRESENT	0
235060	232943	14055N	PARTICIPANT	\N	PRESENT	0
235061	232943	04097T	PARTICIPANT	\N	PRESENT	0
235062	232943	19703U	PARTICIPANT	\N	PRESENT	0
235063	232943	14031R	PARTICIPANT	\N	PRESENT	0
235064	232943	14157T	PARTICIPANT	\N	PRESENT	0
235065	232943	19415P	PARTICIPANT	\N	PRESENT	0
235066	232943	14119M	PARTICIPANT	\N	PRESENT	0
235067	232943	07029T	PARTICIPANT	\N	PRESENT	0
235068	232943	08019V	PARTICIPANT	\N	PRESENT	0
235069	232943	19663E	PARTICIPANT	\N	PRESENT	0
235070	232943	14033T	PARTICIPANT	\N	PRESENT	0
235071	232943	19657G	PARTICIPANT	\N	PRESENT	0
235072	232943	19693L	PARTICIPANT	\N	PRESENT	0
235073	232943	14105F	PARTICIPANT	\N	PRESENT	0
235074	232943	14213J	PARTICIPANT	\N	PRESENT	0
235075	232943	19387D	PARTICIPANT	\N	PRESENT	0
235076	232943	19629C	PARTICIPANT	\N	PRESENT	0
235077	232943	19253P	PARTICIPANT	\N	PRESENT	0
235078	232943	19421M	PARTICIPANT	\N	PRESENT	0
235079	232943	19695N	PARTICIPANT	\N	PRESENT	0
235080	232943	19631V	PARTICIPANT	\N	PRESENT	0
235081	232943	08055A	PARTICIPANT	\N	PRESENT	0
235082	232943	19347U	PARTICIPANT	\N	PRESENT	0
235083	232943	19565D	PARTICIPANT	\N	PRESENT	0
235084	232943	04085P	PARTICIPANT	\N	PRESENT	0
235085	232943	14121F	PARTICIPANT	\N	PRESENT	0
235086	232943	19483C	PARTICIPANT	\N	PRESENT	0
235089	232943	19369B	PARTICIPANT	\N	PRESENT	0
235015	232943	04059M	PARTICIPANT	\N	PRESENT	0
235016	233065	01058X	PARTICIPANT	\N	EXCUSE	0
235090	232943	04086Q	PARTICIPANT	\N	PRESENT	0
218148	207713	11033F	PARTICIPANT	\N	PRESENT	0
218149	207713	08062Y	PARTICIPANT	\N	PRESENT	0
218150	207713	08015R	PARTICIPANT	\N	PRESENT	0
218151	207713	19593H	PARTICIPANT	\N	PRESENT	0
218152	207713	08041T	PARTICIPANT	\N	PRESENT	0
218153	207713	11012A	PARTICIPANT	\N	PRESENT	0
218154	207713	88008L	PARTICIPANT	\N	PRESENT	0
218155	207713	08031R	PARTICIPANT	\N	PRESENT	0
218156	207713	19443T	PARTICIPANT	\N	PRESENT	0
218157	207713	19253P	PARTICIPANT	\N	PRESENT	0
218158	207713	14261S	PARTICIPANT	\N	PRESENT	0
218159	207713	19629C	PARTICIPANT	\N	PRESENT	0
218160	207713	14201E	PARTICIPANT	\N	PRESENT	0
218161	207713	19681G	PARTICIPANT	\N	PRESENT	0
218162	207713	19563B	PARTICIPANT	\N	PRESENT	0
218163	207713	04061F	PARTICIPANT	\N	PRESENT	0
218164	207713	14241N	PARTICIPANT	\N	PRESENT	0
218165	207713	98022P	PARTICIPANT	\N	PRESENT	0
218166	207713	11099A	PARTICIPANT	\N	PRESENT	0
218167	207713	19581D	PARTICIPANT	\N	PRESENT	0
218168	207713	19719D	PARTICIPANT	\N	PRESENT	0
218169	207713	19387D	PARTICIPANT	\N	PRESENT	0
218170	207713	14169X	PARTICIPANT	\N	PRESENT	0
218171	207713	14207L	PARTICIPANT	\N	PRESENT	0
218172	207713	07033P	PARTICIPANT	\N	PRESENT	0
218173	207713	19301E	PARTICIPANT	\N	PRESENT	0
218174	207713	04057K	PARTICIPANT	\N	PRESENT	0
218175	207713	02002K	PARTICIPANT	\N	PRESENT	0
218176	207713	14173T	PARTICIPANT	\N	PRESENT	0
218177	207713	19705W	PARTICIPANT	\N	PRESENT	0
218178	207713	19553Y	PARTICIPANT	\N	PRESENT	0
218179	207713	19483C	PARTICIPANT	\N	PRESENT	0
218180	207713	14355X	PARTICIPANT	\N	PRESENT	0
218181	207713	14251Q	PARTICIPANT	\N	PRESENT	0
218182	207713	17589D	PARTICIPANT	\N	PRESENT	0
218183	207713	95041E	PARTICIPANT	\N	PRESENT	0
218184	207713	14195A	PARTICIPANT	\N	PRESENT	0
218185	207713	14111D	PARTICIPANT	\N	PRESENT	0
218186	207713	19545Y	PARTICIPANT	\N	PRESENT	0
218187	207713	19399H	PARTICIPANT	\N	PRESENT	0
218188	207713	14179A	PARTICIPANT	\N	PRESENT	0
218189	207713	01034P	PARTICIPANT	\N	PRESENT	0
218190	207713	19369B	PARTICIPANT	\N	PRESENT	0
218191	207713	19691J	PARTICIPANT	\N	PRESENT	0
218192	207713	19693L	PARTICIPANT	\N	PRESENT	0
218193	207713	11053K	PARTICIPANT	\N	PRESENT	0
218194	207713	19611R	PARTICIPANT	\N	PRESENT	0
218195	207713	19511N	PARTICIPANT	\N	PRESENT	0
218196	207713	04088S	PARTICIPANT	\N	PRESENT	0
218197	207713	19737F	PARTICIPANT	\N	PRESENT	0
218198	207713	14205J	PARTICIPANT	\N	PRESENT	0
218199	207713	19671E	PARTICIPANT	\N	PRESENT	0
218200	207713	19721W	PARTICIPANT	\N	PRESENT	0
218201	207713	19619A	PARTICIPANT	\N	PRESENT	0
218202	207713	08019V	PARTICIPANT	\N	PRESENT	0
218203	207713	19569H	PARTICIPANT	\N	PRESENT	0
218204	207713	08056B	PARTICIPANT	\N	PRESENT	0
218205	207713	08073C	PARTICIPANT	\N	PRESENT	0
218206	207713	16685X	PARTICIPANT	\N	PRESENT	0
218207	207713	19699S	PARTICIPANT	\N	PRESENT	0
218208	207713	14119M	PARTICIPANT	\N	PRESENT	0
218209	207713	11109J	PARTICIPANT	\N	PRESENT	0
218210	207713	14042U	PARTICIPANT	\N	PRESENT	0
218211	207713	14219Q	PARTICIPANT	\N	PRESENT	0
218212	207713	19479G	PARTICIPANT	\N	PRESENT	0
218213	207713	19441R	PARTICIPANT	\N	PRESENT	0
218214	207713	19583F	PARTICIPANT	\N	PRESENT	0
218215	207713	19713W	PARTICIPANT	\N	PRESENT	0
218216	207713	19575F	PARTICIPANT	\N	PRESENT	0
218217	207713	01043Q	PARTICIPANT	\N	PRESENT	0
218218	207713	14030Q	PARTICIPANT	\N	PRESENT	0
218219	207713	14327T	PARTICIPANT	\N	PRESENT	0
218220	207713	01025N	PARTICIPANT	\N	PRESENT	0
218221	207713	01024M	PARTICIPANT	\N	PRESENT	0
218222	207713	14217N	PARTICIPANT	\N	PRESENT	0
218223	207713	04040A	PARTICIPANT	\N	PRESENT	0
218224	207713	11085T	PARTICIPANT	\N	PRESENT	0
218225	207713	19577H	PARTICIPANT	\N	PRESENT	0
218226	207713	04070G	PARTICIPANT	\N	PRESENT	0
218227	207713	19521Q	PARTICIPANT	\N	PRESENT	0
218228	207713	19621T	PARTICIPANT	\N	PRESENT	0
218229	207713	11070L	PARTICIPANT	\N	PRESENT	0
218230	207713	14089Y	PARTICIPANT	\N	PRESENT	0
218231	207713	14083S	PARTICIPANT	\N	PRESENT	0
218232	207713	14073Q	PARTICIPANT	\N	PRESENT	0
218233	207713	19735D	PARTICIPANT	\N	PRESENT	0
218234	207713	14103D	PARTICIPANT	\N	PRESENT	0
218235	207713	14221J	PARTICIPANT	\N	PRESENT	0
218236	207713	19739H	PARTICIPANT	\N	PRESENT	0
218237	207713	14231L	PARTICIPANT	\N	PRESENT	0
218238	207713	19367Y	PARTICIPANT	\N	PRESENT	0
218239	207713	19685L	PARTICIPANT	\N	PRESENT	0
218240	207713	14055N	PARTICIPANT	\N	PRESENT	0
218241	207713	19731Y	PARTICIPANT	\N	PRESENT	0
218242	207713	01060R	PARTICIPANT	\N	PRESENT	0
218256	207713	19335Q	PARTICIPANT	\N	PRESENT	0
218245	207713	04089T	PARTICIPANT	\N	PRESENT	0
218246	207713	19663E	PARTICIPANT	\N	PRESENT	0
218248	207713	19533U	PARTICIPANT	\N	PRESENT	0
218249	207713	19507S	PARTICIPANT	\N	PRESENT	0
218250	207713	19383Y	PARTICIPANT	\N	PRESENT	0
218251	207713	18083K	PARTICIPANT	\N	PRESENT	0
218252	207713	19467C	PARTICIPANT	\N	PRESENT	0
218253	207713	19415P	PARTICIPANT	\N	PRESENT	0
218254	207713	04049K	PARTICIPANT	\N	PRESENT	0
218255	207713	19701S	PARTICIPANT	\N	PRESENT	0
218257	207713	12016W	PARTICIPANT	\N	PRESENT	0
218258	207713	14115H	PARTICIPANT	\N	PRESENT	0
218259	207713	11063M	PARTICIPANT	\N	PRESENT	0
218260	207713	19573D	PARTICIPANT	\N	PRESENT	0
218261	207713	89017R	PARTICIPANT	\N	PRESENT	0
218262	207713	05012A	PARTICIPANT	\N	PRESENT	0
218263	207713	19677L	PARTICIPANT	\N	PRESENT	0
218264	207713	14029X	PARTICIPANT	\N	PRESENT	0
218265	207713	19723Y	PARTICIPANT	\N	PRESENT	0
218266	207713	14213J	PARTICIPANT	\N	PRESENT	0
218270	207713	19709B	PARTICIPANT	\N	PRESENT	0
218268	207713	19733B	PARTICIPANT	\N	PRESENT	0
218269	207713	01062T	PARTICIPANT	\N	PRESENT	0
218271	207713	14034U	PARTICIPANT	\N	PRESENT	0
218272	207713	19657G	PARTICIPANT	\N	PRESENT	0
218308	207714	14034U	PARTICIPANT	\N	PRESENT	0
218318	207714	11063M	PARTICIPANT	\N	PRESENT	0
218319	207714	12016W	PARTICIPANT	\N	PRESENT	0
218320	207714	19715Y	PARTICIPANT	\N	PRESENT	0
218321	207714	08017T	PARTICIPANT	\N	PRESENT	0
218322	207714	14097Y	PARTICIPANT	\N	PRESENT	0
218323	207714	19593H	PARTICIPANT	\N	PRESENT	0
218324	207714	11031D	PARTICIPANT	\N	PRESENT	0
218325	207714	14195A	PARTICIPANT	\N	PRESENT	0
218326	207714	19583F	PARTICIPANT	\N	PRESENT	0
218327	207714	19713W	PARTICIPANT	\N	PRESENT	0
218328	207714	14227Q	PARTICIPANT	\N	PRESENT	0
218329	207714	19727D	PARTICIPANT	\N	PRESENT	0
218330	207714	14281W	PARTICIPANT	\N	PRESENT	0
218331	207714	11067R	PARTICIPANT	\N	PRESENT	0
218332	207714	98022P	PARTICIPANT	\N	PRESENT	0
218333	207714	14261S	PARTICIPANT	\N	PRESENT	0
218334	207714	19681G	PARTICIPANT	\N	PRESENT	0
218335	207714	19737F	PARTICIPANT	\N	PRESENT	0
218336	207714	19335Q	PARTICIPANT	\N	PRESENT	0
218337	207714	19685L	PARTICIPANT	\N	PRESENT	0
218338	207714	08052W	PARTICIPANT	\N	PRESENT	0
218339	207714	14055N	PARTICIPANT	\N	PRESENT	0
218340	207714	19731Y	PARTICIPANT	\N	PRESENT	0
218341	207714	11103C	PARTICIPANT	\N	PRESENT	0
218342	207714	19663E	PARTICIPANT	\N	PRESENT	0
218343	207714	14223L	PARTICIPANT	\N	PRESENT	0
218344	207714	14239U	PARTICIPANT	\N	PRESENT	0
218345	207714	04045F	PARTICIPANT	\N	PRESENT	0
218346	207714	19697Q	PARTICIPANT	\N	PRESENT	0
218347	207714	14069U	PARTICIPANT	\N	PRESENT	0
218348	207714	88008L	PARTICIPANT	\N	PRESENT	0
218349	207714	14041T	PARTICIPANT	\N	PRESENT	0
218350	207714	19723Y	PARTICIPANT	\N	PRESENT	0
218351	207714	14030Q	PARTICIPANT	\N	PRESENT	0
218352	207714	04092N	PARTICIPANT	\N	PRESENT	0
218353	207714	01034P	PARTICIPANT	\N	PRESENT	0
218354	207714	19553Y	PARTICIPANT	\N	PRESENT	0
218355	207714	14031R	PARTICIPANT	\N	PRESENT	0
218356	207714	97011G	PARTICIPANT	\N	PRESENT	0
218357	207714	14217N	PARTICIPANT	\N	PRESENT	0
218358	207714	19533U	PARTICIPANT	\N	PRESENT	0
218359	207714	19483C	PARTICIPANT	\N	PRESENT	0
218360	207714	95062K	PARTICIPANT	\N	PRESENT	0
218361	207714	04097T	PARTICIPANT	\N	PRESENT	0
218362	207714	19577H	PARTICIPANT	\N	PRESENT	0
218363	207714	14081Q	PARTICIPANT	\N	PRESENT	0
220308	220307	07004J	PARTICIPANT	\N	PRESENT	0
220310	220309	07004J	PARTICIPANT	\N	PRESENT	0
220322	220311	07004J	PARTICIPANT	\N	PRESENT	0
225591	218301	01048V	PARTICIPANT	\N	PRESENT	0
225592	218301	11074Q	PARTICIPANT	\N	PRESENT	0
225593	218301	11104D	PARTICIPANT	\N	PRESENT	0
225594	218301	19447X	PARTICIPANT	\N	PRESENT	0
225595	218301	14039A	PARTICIPANT	\N	PRESENT	0
225596	218301	08019V	PARTICIPANT	\N	PRESENT	0
225597	218301	19697Q	PARTICIPANT	\N	PRESENT	0
225598	218301	07029T	PARTICIPANT	\N	PRESENT	0
225599	218301	08043V	PARTICIPANT	\N	PRESENT	0
225600	218301	19647E	PARTICIPANT	\N	PRESENT	0
225601	218301	14087W	PARTICIPANT	\N	PRESENT	0
225602	218301	19711U	PARTICIPANT	\N	PRESENT	0
225603	218301	04057K	PARTICIPANT	\N	PRESENT	0
225604	218301	14251Q	PARTICIPANT	\N	PRESENT	0
225616	218301	14147R	PARTICIPANT	\N	PRESENT	0
225606	218301	14073Q	PARTICIPANT	\N	PRESENT	0
225607	218301	10006L	PARTICIPANT	\N	PRESENT	0
225608	218301	04018C	PARTICIPANT	\N	PRESENT	0
225609	218301	19735D	PARTICIPANT	\N	PRESENT	0
225610	218301	14030Q	PARTICIPANT	\N	PRESENT	0
225611	218301	14235Q	PARTICIPANT	\N	PRESENT	0
225612	218301	08017T	PARTICIPANT	\N	PRESENT	0
225613	218301	19611R	PARTICIPANT	\N	PRESENT	0
225614	218301	14241N	PARTICIPANT	\N	PRESENT	0
225615	218301	11043H	PARTICIPANT	\N	PRESENT	0
225617	218301	14249W	PARTICIPANT	\N	PRESENT	0
225618	218301	19533U	PARTICIPANT	\N	PRESENT	0
225619	218301	19593H	PARTICIPANT	\N	PRESENT	0
225620	218301	19695N	PARTICIPANT	\N	PRESENT	0
225621	218301	17637T	PARTICIPANT	\N	PRESENT	0
225622	218301	14123H	PARTICIPANT	\N	PRESENT	0
225623	218301	08012N	PARTICIPANT	\N	PRESENT	0
225624	218301	19621T	PARTICIPANT	\N	PRESENT	0
225625	218301	19573D	PARTICIPANT	\N	PRESENT	0
225626	218301	19333N	PARTICIPANT	\N	PRESENT	0
225627	218301	95015C	PARTICIPANT	\N	PRESENT	0
225628	218301	14059S	PARTICIPANT	\N	PRESENT	0
225629	218301	14061L	PARTICIPANT	\N	PRESENT	0
225630	218301	08010L	PARTICIPANT	\N	PRESENT	0
225631	218301	08020N	PARTICIPANT	\N	PRESENT	0
225632	218301	95037J	PARTICIPANT	\N	PRESENT	0
225633	218301	11064N	PARTICIPANT	\N	PRESENT	0
225634	218301	14121F	PARTICIPANT	\N	PRESENT	0
225635	218301	08016S	PARTICIPANT	\N	PRESENT	0
225636	218301	14229S	PARTICIPANT	\N	PRESENT	0
225637	218301	14053L	PARTICIPANT	\N	PRESENT	0
225638	218301	14265W	PARTICIPANT	\N	PRESENT	0
225639	218301	14217N	PARTICIPANT	\N	PRESENT	0
225640	218301	14213J	PARTICIPANT	\N	PRESENT	0
225641	218301	14157T	PARTICIPANT	\N	PRESENT	0
225642	218301	19479G	PARTICIPANT	\N	PRESENT	0
225643	218301	19713W	PARTICIPANT	\N	PRESENT	0
225644	218301	14071N	PARTICIPANT	\N	PRESENT	0
225645	218301	11097X	PARTICIPANT	\N	PRESENT	0
225646	218301	11048N	PARTICIPANT	\N	PRESENT	0
225647	218301	14033T	PARTICIPANT	\N	PRESENT	0
225648	218301	14327T	PARTICIPANT	\N	PRESENT	0
225649	218301	14089Y	PARTICIPANT	\N	PRESENT	0
225650	218301	14231L	PARTICIPANT	\N	PRESENT	0
225651	218301	14083S	PARTICIPANT	\N	PRESENT	0
225652	218301	19543W	PARTICIPANT	\N	PRESENT	0
225653	218301	12041X	PARTICIPANT	\N	PRESENT	0
225654	218301	04085P	PARTICIPANT	\N	PRESENT	0
225655	218301	14042U	PARTICIPANT	\N	PRESENT	0
225656	218301	08015R	PARTICIPANT	\N	PRESENT	0
225657	218301	08039A	PARTICIPANT	\N	PRESENT	0
225658	218301	14069U	PARTICIPANT	\N	PRESENT	0
225659	218301	14225N	PARTICIPANT	\N	PRESENT	0
225660	218301	14197C	PARTICIPANT	\N	PRESENT	0
225589	218301	01043Q	PARTICIPANT	\N	PRESENT	0
225590	218301	04070G	PARTICIPANT	\N	PRESENT	0
225661	218301	19693L	PARTICIPANT	\N	PRESENT	0
225662	218301	14034U	PARTICIPANT	\N	PRESENT	0
225663	218301	19531S	PARTICIPANT	\N	PRESENT	0
225664	218301	14021P	PARTICIPANT	\N	PRESENT	0
225665	218301	08031R	PARTICIPANT	\N	PRESENT	0
225666	218301	11026G	PARTICIPANT	\N	PRESENT	0
225667	218301	18083K	PARTICIPANT	\N	PRESENT	0
225668	218301	14179A	PARTICIPANT	\N	PRESENT	0
225669	218301	19483C	PARTICIPANT	\N	PRESENT	0
226062	218821	19399H	PARTICIPANT	\N	PRESENT	0
226733	221543	95062K	PARTICIPANT	\N	EXCUSE	0
226756	226755	14123H	PARTICIPANT	\N	PRESENT	0
226758	226757	14123H	PARTICIPANT	\N	PRESENT	0
226759	226757	19611R	PARTICIPANT	\N	PRESENT	0
226761	226760	14123H	PARTICIPANT	\N	PRESENT	0
226762	226760	19611R	PARTICIPANT	\N	PRESENT	0
226764	226763	14123H	PARTICIPANT	\N	PRESENT	0
226765	226763	19533U	PARTICIPANT	\N	PRESENT	0
226934	226199	19697Q	PARTICIPANT	\N	PRESENT	0
226935	226199	11067R	PARTICIPANT	\N	PRESENT	0
226936	226199	14355X	PARTICIPANT	\N	PRESENT	0
226937	226199	11097X	PARTICIPANT	\N	PRESENT	0
226938	226199	19415P	PARTICIPANT	\N	PRESENT	0
226939	226199	14223L	PARTICIPANT	\N	PRESENT	0
226940	226199	04045F	PARTICIPANT	\N	PRESENT	0
226941	226199	14227Q	PARTICIPANT	\N	PRESENT	0
226942	226199	19675J	PARTICIPANT	\N	PRESENT	0
226943	226199	11063M	PARTICIPANT	\N	PRESENT	0
226944	226199	19553Y	PARTICIPANT	\N	PRESENT	0
226945	226199	14239U	PARTICIPANT	\N	PRESENT	0
226946	226199	19703U	PARTICIPANT	\N	PRESENT	0
226947	226199	14281W	PARTICIPANT	\N	PRESENT	0
226948	226199	19679N	PARTICIPANT	\N	PRESENT	0
226949	226199	14042U	PARTICIPANT	\N	PRESENT	0
226950	226199	14195A	PARTICIPANT	\N	PRESENT	0
226951	226199	19575F	PARTICIPANT	\N	PRESENT	0
226952	226199	19367Y	PARTICIPANT	\N	PRESENT	0
226953	226199	14217N	PARTICIPANT	\N	PRESENT	0
226954	226199	14261S	PARTICIPANT	\N	PRESENT	0
226955	226199	98024R	PRESIDENT	1	PRESENT	0
226956	226199	19527W	PARTICIPANT	\N	PRESENT	0
226957	226199	01034P	PARTICIPANT	\N	PRESENT	0
226958	226199	04092N	PRESIDENT	0	PRESENT	0
226959	226199	08052W	PARTICIPANT	\N	PRESENT	0
226960	226199	19723Y	PARTICIPANT	\N	PRESENT	0
226961	226199	14119M	PARTICIPANT	\N	PRESENT	0
226962	226199	11103C	PARTICIPANT	\N	PRESENT	0
226963	226199	19657G	PARTICIPANT	\N	PRESENT	0
226964	226199	14071N	PARTICIPANT	\N	PRESENT	0
226965	226199	08048B	PARTICIPANT	\N	EXCUSE	0
226966	226199	19715Y	PARTICIPANT	\N	EXCUSE	0
226967	226199	08041T	PARTICIPANT	\N	EXCUSE	0
227055	226103	14327T	PARTICIPANT	\N	PRESENT	0
227056	226103	14331P	PARTICIPANT	\N	PRESENT	0
227057	226103	01048V	PARTICIPANT	\N	PRESENT	0
227058	226103	19545Y	PARTICIPANT	\N	PRESENT	0
227059	226103	11074Q	PRESIDENT	0	PRESENT	0
227060	226103	89017R	PARTICIPANT	\N	PRESENT	0
227061	226103	14225N	PARTICIPANT	\N	PRESENT	0
227062	226103	11070L	PARTICIPANT	\N	PRESENT	0
227063	226103	19671E	PARTICIPANT	\N	PRESENT	0
227064	226103	07029T	PARTICIPANT	\N	PRESENT	0
227065	226103	14085U	PARTICIPANT	\N	PRESENT	0
227066	226103	07004J	PARTICIPANT	\N	PRESENT	0
227067	226103	19349W	PARTICIPANT	\N	PRESENT	0
227068	226103	14253S	PARTICIPANT	\N	PRESENT	0
227069	226103	11048N	PARTICIPANT	\N	PRESENT	0
227070	226103	19479G	PARTICIPANT	\N	PRESENT	0
227071	226103	19647E	PARTICIPANT	\N	PRESENT	0
227072	226103	19711U	PARTICIPANT	\N	PRESENT	0
227073	226103	19651A	PARTICIPANT	\N	PRESENT	0
227074	226103	19531S	PARTICIPANT	\N	PRESENT	0
227075	226103	08034U	PARTICIPANT	\N	PRESENT	0
227076	226103	08069G	PARTICIPANT	\N	PRESENT	0
227077	226103	19687N	PARTICIPANT	\N	PRESENT	0
227078	226103	12016W	PARTICIPANT	\N	PRESENT	0
227079	226103	08011M	PARTICIPANT	\N	PRESENT	0
227080	226103	08014Q	PARTICIPANT	\N	PRESENT	0
227081	226103	14159V	PARTICIPANT	\N	PRESENT	0
227082	226103	14173T	PARTICIPANT	\N	PRESENT	0
227083	226103	04086Q	PARTICIPANT	\N	PRESENT	0
227084	226103	11040E	PARTICIPANT	\N	PRESENT	0
227085	226103	14083S	PARTICIPANT	\N	PRESENT	0
227086	226103	14199E	PARTICIPANT	\N	PRESENT	0
227087	226103	11012A	PARTICIPANT	\N	PRESENT	0
227088	226103	08073C	PARTICIPANT	\N	PRESENT	0
227089	226103	99004R	PARTICIPANT	\N	PRESENT	0
227090	226103	04061F	PARTICIPANT	\N	PRESENT	0
227091	225773	11054L	PARTICIPANT	\N	PRESENT	0
227092	225773	08053X	PARTICIPANT	\N	PRESENT	0
227093	225773	08061X	PARTICIPANT	\N	PRESENT	0
227094	225773	19251M	PARTICIPANT	\N	PRESENT	0
227095	225773	14028W	PARTICIPANT	\N	PRESENT	0
227096	225773	19721W	PARTICIPANT	\N	PRESENT	0
227101	226199	14026U	PARTICIPANT	\N	PRESENT	0
226213	218316	08052W	PARTICIPANT	\N	PRESENT	0
226214	218316	14087W	PARTICIPANT	\N	PRESENT	0
226215	218316	19545Y	PARTICIPANT	\N	PRESENT	0
226216	218316	19527W	PARTICIPANT	\N	PRESENT	0
226217	218316	14223L	PARTICIPANT	\N	PRESENT	0
226218	218316	07004J	PARTICIPANT	\N	PRESENT	0
226219	218316	11063M	PARTICIPANT	\N	PRESENT	0
226220	218316	11074Q	PARTICIPANT	\N	PRESENT	0
226221	218316	19651A	PARTICIPANT	\N	PRESENT	0
226222	218316	19719D	PARTICIPANT	\N	PRESENT	0
226223	218316	08019V	PARTICIPANT	\N	PRESENT	0
226224	218316	14225N	PARTICIPANT	\N	PRESENT	0
226225	218316	19711U	PARTICIPANT	\N	PRESENT	0
226226	218316	01034P	PARTICIPANT	\N	PRESENT	0
226227	218316	14229S	PARTICIPANT	\N	PRESENT	0
226228	218316	98005N	PARTICIPANT	\N	PRESENT	0
226229	218316	19689Q	PARTICIPANT	\N	PRESENT	0
226230	218316	98050T	PARTICIPANT	\N	PRESENT	0
226231	218316	08010L	PARTICIPANT	\N	PRESENT	0
226232	218316	14281W	PARTICIPANT	\N	PRESENT	0
226233	218316	04045F	PARTICIPANT	\N	PRESENT	0
226157	218306	11070L	PARTICIPANT	\N	PRESENT	0
226212	218316	04086Q	PARTICIPANT	\N	PRESENT	0
226234	218316	19611R	PARTICIPANT	\N	PRESENT	0
226235	218316	19573D	PARTICIPANT	\N	PRESENT	0
226236	218316	14249W	PARTICIPANT	\N	PRESENT	0
226237	218316	95063L	PARTICIPANT	\N	PRESENT	0
226238	218316	11045K	PARTICIPANT	\N	PRESENT	0
226239	218316	04018C	PARTICIPANT	\N	PRESENT	0
226240	218316	14041T	PARTICIPANT	\N	PRESENT	0
226241	218316	14251Q	PARTICIPANT	\N	PRESENT	0
226242	218316	08043V	PARTICIPANT	\N	PRESENT	0
226243	218316	19593H	PARTICIPANT	\N	PRESENT	0
226244	218316	08031R	PARTICIPANT	\N	PRESENT	0
226245	218316	14109K	PARTICIPANT	\N	PRESENT	0
226246	218316	08016S	PARTICIPANT	\N	PRESENT	0
226247	218316	04057K	PARTICIPANT	\N	PRESENT	0
226248	218316	14105F	PARTICIPANT	\N	PRESENT	0
226249	218316	04043D	PARTICIPANT	\N	PRESENT	0
226250	218316	19591F	PARTICIPANT	\N	PRESENT	0
226251	218316	19699S	PARTICIPANT	\N	PRESENT	0
226293	218317	19689Q	PARTICIPANT	\N	PRESENT	0
226294	218317	19545Y	PARTICIPANT	\N	PRESENT	0
226295	218317	14087W	PARTICIPANT	\N	PRESENT	0
226296	218317	11074Q	PARTICIPANT	\N	PRESENT	0
226297	218317	08052W	PARTICIPANT	\N	PRESENT	0
226298	218317	08043V	PARTICIPANT	\N	PRESENT	0
226299	218317	14229S	PARTICIPANT	\N	PRESENT	0
226300	218317	19651A	PARTICIPANT	\N	PRESENT	0
226301	218317	04057K	PARTICIPANT	\N	PRESENT	0
226302	218317	19699S	PARTICIPANT	\N	PRESENT	0
226303	218317	19719D	PARTICIPANT	\N	PRESENT	0
226304	218317	98050T	PARTICIPANT	\N	PRESENT	0
226305	218317	98005N	PARTICIPANT	\N	PRESENT	0
226306	218317	14223L	PARTICIPANT	\N	PRESENT	0
226307	218317	19711U	PARTICIPANT	\N	PRESENT	0
226308	218317	14211G	PARTICIPANT	\N	PRESENT	0
226309	218317	19593H	PARTICIPANT	\N	PRESENT	0
226310	218317	11063M	PARTICIPANT	\N	PRESENT	0
226311	218317	14041T	PARTICIPANT	\N	PRESENT	0
226312	218317	19399H	PARTICIPANT	\N	PRESENT	0
226313	218317	19573D	PARTICIPANT	\N	PRESENT	0
226314	218317	19611R	PARTICIPANT	\N	PRESENT	0
226315	218317	19647E	PARTICIPANT	\N	PRESENT	0
226316	218317	08017T	PARTICIPANT	\N	PRESENT	0
226317	218317	11045K	PARTICIPANT	\N	PRESENT	0
226318	218317	14109K	PARTICIPANT	\N	PRESENT	0
226319	218317	04045F	PARTICIPANT	\N	PRESENT	0
226320	218317	08019V	PARTICIPANT	\N	PRESENT	0
226321	218317	19649G	PARTICIPANT	\N	PRESENT	0
226322	218317	04070G	PARTICIPANT	\N	PRESENT	0
226323	218317	08010L	PARTICIPANT	\N	PRESENT	0
226324	218317	14105F	PARTICIPANT	\N	PRESENT	0
226325	218317	04043D	PARTICIPANT	\N	PRESENT	0
226326	218317	19735D	PARTICIPANT	\N	PRESENT	0
226327	218317	08039A	PARTICIPANT	\N	PRESENT	0
226328	218317	04059M	PARTICIPANT	\N	PRESENT	0
226329	218317	92040Q	PARTICIPANT	\N	PRESENT	0
226291	218317	14281W	PARTICIPANT	\N	PRESENT	0
226292	218317	04018C	PARTICIPANT	\N	PRESENT	0
226330	218317	14251Q	PARTICIPANT	\N	PRESENT	0
226331	218317	14249W	PARTICIPANT	\N	PRESENT	0
226332	218317	19695N	PARTICIPANT	\N	PRESENT	0
226333	218317	11083R	PARTICIPANT	\N	PRESENT	0
226334	218317	11070L	PARTICIPANT	\N	PRESENT	0
226335	218317	98018T	PARTICIPANT	\N	PRESENT	0
226336	218317	14039A	PARTICIPANT	\N	PRESENT	0
226337	218317	14073Q	PARTICIPANT	\N	PRESENT	0
226338	218317	99004R	PARTICIPANT	\N	PRESENT	0
226339	218317	19693L	PARTICIPANT	\N	PRESENT	0
226340	218317	08031R	PARTICIPANT	\N	PRESENT	0
226341	218317	19643A	PARTICIPANT	\N	PRESENT	0
226342	218317	19683J	PARTICIPANT	\N	PRESENT	0
226346	218317	88008L	PARTICIPANT	\N	PRESENT	0
226347	218317	07033P	PARTICIPANT	\N	PRESENT	0
226348	218317	98022P	PARTICIPANT	\N	PRESENT	0
226350	218317	14225N	PARTICIPANT	\N	PRESENT	0
226351	218317	08016S	PARTICIPANT	\N	PRESENT	0
226353	218317	11110B	PARTICIPANT	\N	PRESENT	0
226354	218317	14241N	PARTICIPANT	\N	PRESENT	0
226355	218317	11012A	PARTICIPANT	\N	PRESENT	0
226356	218317	19531S	PARTICIPANT	\N	PRESENT	0
226357	218317	02002K	PARTICIPANT	\N	PRESENT	0
226358	218317	14159V	PARTICIPANT	\N	PRESENT	0
226361	218317	04035D	PARTICIPANT	\N	PRESENT	0
226362	218317	04042C	PARTICIPANT	\N	PRESENT	0
226363	218317	07004J	PARTICIPANT	\N	PRESENT	0
226364	218317	19543W	PARTICIPANT	\N	PRESENT	0
226365	218317	14028W	PARTICIPANT	\N	PRESENT	0
226366	218317	11054L	PARTICIPANT	\N	PRESENT	0
226367	218317	11041F	PARTICIPANT	\N	PRESENT	0
226372	218317	04047H	PARTICIPANT	\N	PRESENT	0
226373	218317	19251M	PARTICIPANT	\N	PRESENT	0
226374	218317	14235Q	PARTICIPANT	\N	PRESENT	0
226375	218317	11026G	PARTICIPANT	\N	PRESENT	0
226376	218317	04034C	PARTICIPANT	\N	PRESENT	0
226377	218317	04040A	PARTICIPANT	\N	PRESENT	0
226378	218317	14079W	PARTICIPANT	\N	PRESENT	0
226379	218317	95067Q	PARTICIPANT	\N	PRESENT	0
226380	218317	19669L	PARTICIPANT	\N	PRESENT	0
226381	218317	11027H	PARTICIPANT	\N	PRESENT	0
226385	218317	95037J	PARTICIPANT	\N	PRESENT	0
226383	218317	08061X	PARTICIPANT	\N	PRESENT	0
226397	218315	11077T	PARTICIPANT	\N	PRESENT	0
226386	226081	04071H	PARTICIPANT	\N	PRESENT	0
226387	226081	19647E	PARTICIPANT	\N	PRESENT	0
226388	226081	14199E	PARTICIPANT	\N	PRESENT	0
226389	226081	14085U	PARTICIPANT	\N	PRESENT	0
226390	226081	99004R	PARTICIPANT	\N	PRESENT	0
226391	226081	11074Q	PRESIDENT	0	PRESENT	0
226392	226081	11070L	PARTICIPANT	\N	PRESENT	0
226393	226081	14225N	PARTICIPANT	\N	PRESENT	0
226394	226081	14327T	PARTICIPANT	\N	EXCUSE	0
226395	226081	07029T	PARTICIPANT	\N	EXCUSE	0
226396	226081	19667J	PARTICIPANT	\N	EXCUSE	0
226398	218315	11074Q	PARTICIPANT	\N	PRESENT	0
226399	218315	19647E	PARTICIPANT	\N	PRESENT	0
226400	218315	04042C	PARTICIPANT	\N	PRESENT	0
226401	218315	14235Q	PARTICIPANT	\N	PRESENT	0
226402	218315	04070G	PARTICIPANT	\N	PRESENT	0
226403	218315	19251M	PARTICIPANT	\N	PRESENT	0
226404	218315	11027H	PARTICIPANT	\N	PRESENT	0
226405	218315	08017T	PARTICIPANT	\N	PRESENT	0
226406	218315	19669L	PARTICIPANT	\N	PRESENT	0
226407	218315	11026G	PARTICIPANT	\N	PRESENT	0
226408	218315	95037J	PARTICIPANT	\N	PRESENT	0
226409	218315	98029W	PARTICIPANT	\N	PRESENT	0
226410	218315	14073Q	PARTICIPANT	\N	PRESENT	0
226411	218315	14255U	PARTICIPANT	\N	PRESENT	0
226412	218315	14079W	PARTICIPANT	\N	PRESENT	0
226413	218315	14241N	PARTICIPANT	\N	PRESENT	0
226414	218315	14225N	PARTICIPANT	\N	PRESENT	0
226415	218315	98022P	PARTICIPANT	\N	PRESENT	0
226416	218315	19735D	PARTICIPANT	\N	PRESENT	0
226417	218315	14219Q	PARTICIPANT	\N	PRESENT	0
226418	218315	11064N	PARTICIPANT	\N	PRESENT	0
226419	218315	98050T	PARTICIPANT	\N	PRESENT	0
226420	218315	98018T	PARTICIPANT	\N	PRESENT	0
226421	218315	14085U	PARTICIPANT	\N	PRESENT	0
226422	218315	19707Y	PARTICIPANT	\N	PRESENT	0
226423	218315	19705W	PARTICIPANT	\N	PRESENT	0
226424	218315	04035D	PARTICIPANT	\N	PRESENT	0
226425	218315	04033B	PARTICIPANT	\N	PRESENT	0
226426	218315	04071H	PARTICIPANT	\N	PRESENT	0
226427	218315	14041T	PARTICIPANT	\N	PRESENT	0
226428	218315	19709B	PARTICIPANT	\N	PRESENT	0
226429	218315	11070L	PARTICIPANT	\N	PRESENT	0
226430	218315	08018U	PARTICIPANT	\N	PRESENT	0
226431	218315	14211G	PARTICIPANT	\N	PRESENT	0
215353	215352	14065Q	PARTICIPANT	\N	PRESENT	0
215354	215352	96004D	PRESIDENT	0	PRESENT	0
215355	215352	14089Y	PARTICIPANT	\N	PRESENT	0
215356	215352	08014Q	PARTICIPANT	\N	PRESENT	0
215357	215352	14249W	PARTICIPANT	\N	PRESENT	0
215358	215352	11083R	PARTICIPANT	\N	PRESENT	0
215359	215352	19725B	PARTICIPANT	\N	PRESENT	0
215360	215352	04097T	PARTICIPANT	\N	PRESENT	0
215361	215352	04061F	PARTICIPANT	\N	PRESENT	0
215362	215352	14061L	PARTICIPANT	\N	PRESENT	0
215363	215352	14205J	PARTICIPANT	\N	PRESENT	0
215364	215352	14001X	PARTICIPANT	\N	PRESENT	0
215365	215352	11026G	PARTICIPANT	\N	PRESENT	0
215366	215352	19563B	PARTICIPANT	\N	PRESENT	0
215367	215352	19593H	PARTICIPANT	\N	EXCUSE	0
215368	215352	14135M	PARTICIPANT	\N	PRESENT	0
215369	215352	14331P	PARTICIPANT	\N	PRESENT	0
215370	215352	14225N	PARTICIPANT	\N	PRESENT	0
215371	215352	11074Q	PARTICIPANT	\N	PRESENT	0
215372	215352	08011M	PARTICIPANT	\N	PRESENT	0
215373	215352	14229S	PARTICIPANT	\N	PRESENT	0
215374	215352	01057W	PARTICIPANT	\N	PRESENT	0
215375	215352	11012A	PARTICIPANT	\N	PRESENT	0
215376	215352	14173T	PARTICIPANT	\N	PRESENT	0
215377	215352	11053K	PARTICIPANT	\N	PRESENT	0
215378	215352	04086Q	PARTICIPANT	\N	PRESENT	0
215379	215352	07029T	PARTICIPANT	\N	PRESENT	0
215380	215352	08034U	PARTICIPANT	\N	PRESENT	0
215381	215352	19479G	PARTICIPANT	\N	PRESENT	0
215382	215352	14083S	PARTICIPANT	\N	PRESENT	0
215383	215352	12016W	PARTICIPANT	\N	PRESENT	0
215384	215352	19647E	PARTICIPANT	\N	PRESENT	0
215385	215352	19671E	PARTICIPANT	\N	PRESENT	0
215386	215352	19531S	PARTICIPANT	\N	PRESENT	0
215387	215352	08010L	PARTICIPANT	\N	PRESENT	0
215388	215352	19689Q	PARTICIPANT	\N	PRESENT	0
215389	215352	19545Y	PARTICIPANT	\N	PRESENT	0
215390	215352	14121F	PARTICIPANT	\N	PRESENT	0
215392	215352	14085U	PARTICIPANT	\N	PRESENT	0
215393	215352	19711U	PARTICIPANT	\N	PRESENT	0
215394	215352	19651A	PARTICIPANT	\N	PRESENT	0
215395	215352	19349W	PARTICIPANT	\N	PRESENT	0
215396	215352	01048V	PARTICIPANT	\N	PRESENT	0
220369	220368	10015M	PARTICIPANT	\N	PRESENT	0
221621	220240	19515S	PARTICIPANT	\N	PRESENT	0
221622	220240	19565D	PARTICIPANT	\N	PRESENT	0
221623	220240	01043Q	PARTICIPANT	\N	PRESENT	0
221624	220240	14357A	PARTICIPANT	\N	PRESENT	0
221625	220240	19441R	PARTICIPANT	\N	PRESENT	0
221626	220240	14081Q	PARTICIPANT	\N	PRESENT	0
221627	220240	19413M	PARTICIPANT	\N	PRESENT	0
221628	220240	80013X	PARTICIPANT	\N	PRESENT	0
221629	220240	19631V	PARTICIPANT	\N	PRESENT	0
221630	220240	08021P	PARTICIPANT	\N	PRESENT	0
221631	220240	11099A	PARTICIPANT	\N	PRESENT	0
221632	220240	08068F	PARTICIPANT	\N	PRESENT	0
221633	220240	04049K	PARTICIPANT	\N	PRESENT	0
221634	220240	19705W	PARTICIPANT	\N	PRESENT	0
221635	220240	08015R	PARTICIPANT	\N	PRESENT	0
221636	220240	08019V	PARTICIPANT	\N	PRESENT	0
221637	220240	14197C	PARTICIPANT	\N	PRESENT	0
221638	220240	19369B	PARTICIPANT	\N	PRESENT	0
221639	220240	19511N	PARTICIPANT	\N	PRESENT	0
221640	220240	11081P	PARTICIPANT	\N	PRESENT	0
221641	220240	19563B	PARTICIPANT	\N	PRESENT	0
221642	220240	08028W	PARTICIPANT	\N	PRESENT	0
221643	220240	14265W	PARTICIPANT	\N	PRESENT	0
221644	220240	14329V	PARTICIPANT	\N	PRESENT	0
221645	220240	19467C	PARTICIPANT	\N	PRESENT	0
221646	220240	14187A	PARTICIPANT	\N	PRESENT	0
221647	220240	12016W	PARTICIPANT	\N	PRESENT	0
221648	220240	19301E	PARTICIPANT	\N	PRESENT	0
221649	220240	08062Y	PARTICIPANT	\N	PRESENT	0
221650	220240	01025N	PARTICIPANT	\N	PRESENT	0
221651	220240	11090Q	PRESIDENT	0	PRESENT	0
221652	220240	14033T	PARTICIPANT	\N	PRESENT	0
221653	220240	04088S	PARTICIPANT	\N	PRESENT	0
221654	220240	04089T	PARTICIPANT	\N	PRESENT	0
221655	220240	14115H	PARTICIPANT	\N	PRESENT	0
221656	220240	19507S	PARTICIPANT	\N	PRESENT	0
221657	220240	11101A	PARTICIPANT	\N	PRESENT	0
221658	220240	14207L	PARTICIPANT	\N	PRESENT	0
221659	220240	04043D	PARTICIPANT	\N	PRESENT	0
221660	220240	17589D	PARTICIPANT	\N	PRESENT	0
221661	220240	14257W	PARTICIPANT	\N	PRESENT	0
221662	219746	19569H	PARTICIPANT	\N	PRESENT	0
221663	219746	14227Q	PARTICIPANT	\N	PRESENT	0
221664	219746	14026U	PARTICIPANT	\N	PRESENT	0
221665	219746	11031D	PARTICIPANT	\N	PRESENT	0
221666	221367	92040Q	PARTICIPANT	\N	PRESENT	0
221667	221367	14251Q	PARTICIPANT	\N	PRESENT	0
221668	221367	04059M	PARTICIPANT	\N	PRESENT	0
221669	219746	19679N	PARTICIPANT	\N	PRESENT	0
221670	220240	19695N	PARTICIPANT	\N	PRESENT	0
221671	220240	19269X	PARTICIPANT	\N	PRESENT	0
221672	219746	01034P	PARTICIPANT	\N	PRESENT	0
221673	221367	19329S	PARTICIPANT	\N	PRESENT	0
221674	221367	14123H	PARTICIPANT	\N	PRESENT	0
221675	221367	11043H	PARTICIPANT	\N	PRESENT	0
221676	221367	19611R	PARTICIPANT	\N	PRESENT	0
221677	221367	14109K	PARTICIPANT	\N	PRESENT	0
221678	220317	10015M	PARTICIPANT	\N	PRESENT	0
221679	220317	14021P	PARTICIPANT	\N	PRESENT	0
221680	220317	19543W	PARTICIPANT	\N	PRESENT	0
221681	221367	19573D	PARTICIPANT	\N	PRESENT	0
221682	219746	11045K	PARTICIPANT	\N	PRESENT	0
221683	219487	19443T	PARTICIPANT	\N	PRESENT	0
221684	219487	11080N	PARTICIPANT	\N	PRESENT	0
221685	219487	95030B	PARTICIPANT	\N	PRESENT	0
221686	219487	01058X	PARTICIPANT	\N	PRESENT	0
221687	219487	14079W	PARTICIPANT	\N	PRESENT	0
221688	219487	11027H	PARTICIPANT	\N	PRESENT	0
221689	219487	16685X	PARTICIPANT	\N	PRESENT	0
221690	219487	04042C	PRESIDENT	0	PRESENT	0
221691	219487	11054L	PARTICIPANT	\N	PRESENT	0
221692	219487	11066Q	PARTICIPANT	\N	PRESENT	0
221693	219487	19669L	PARTICIPANT	\N	PRESENT	0
221694	219487	08056B	PARTICIPANT	\N	PRESENT	0
221695	219487	95037J	PARTICIPANT	\N	PRESENT	0
221696	219487	11115U	PARTICIPANT	\N	PRESENT	0
221697	219487	19709B	PARTICIPANT	\N	PRESENT	0
221698	219487	14193X	PARTICIPANT	\N	PRESENT	0
221699	219487	08049C	PARTICIPANT	\N	PRESENT	0
221700	219487	08053X	PARTICIPANT	\N	PRESENT	0
221701	219487	08061X	PARTICIPANT	\N	PRESENT	0
221702	219487	97011G	PARTICIPANT	\N	PRESENT	0
221703	219487	08047A	PARTICIPANT	\N	PRESENT	0
221704	219487	98029W	PARTICIPANT	\N	PRESENT	0
221705	219487	01062T	PARTICIPANT	\N	PRESENT	0
221706	219487	11041F	PARTICIPANT	\N	PRESENT	0
221707	219487	14235Q	PARTICIPANT	\N	PRESENT	0
221708	219487	08058D	PARTICIPANT	\N	PRESENT	0
221709	219487	14028W	PARTICIPANT	\N	PRESENT	0
221710	219487	19251M	PARTICIPANT	\N	PRESENT	0
221711	219487	19721W	PARTICIPANT	\N	PRESENT	0
221712	219487	19319Q	PARTICIPANT	\N	PRESENT	0
221713	219487	14105F	PARTICIPANT	\N	PRESENT	0
221714	219487	98018T	PARTICIPANT	\N	PRESENT	0
221715	219487	14267Y	PARTICIPANT	\N	PRESENT	0
221716	219487	98050T	PARTICIPANT	\N	PRESENT	0
221717	219487	14211G	PARTICIPANT	\N	PRESENT	0
221718	219487	19583F	PARTICIPANT	\N	PRESENT	0
221719	219487	19421M	PARTICIPANT	\N	PRESENT	0
221720	219487	14097Y	PARTICIPANT	\N	PRESENT	0
221721	219487	04035D	PARTICIPANT	\N	PRESENT	0
221722	219487	14133K	PARTICIPANT	\N	PRESENT	0
221723	219746	17779H	PARTICIPANT	\N	PRESENT	0
221724	219487	04034C	PARTICIPANT	\N	PRESENT	0
221725	219487	98022P	PARTICIPANT	\N	PRESENT	0
221726	219487	11064N	PARTICIPANT	\N	PRESENT	0
221727	219487	04040A	PARTICIPANT	\N	PRESENT	0
221728	219487	14255U	PARTICIPANT	\N	PRESENT	0
221729	219917	14327T	PARTICIPANT	\N	PRESENT	0
221730	219917	04071H	PARTICIPANT	\N	PRESENT	0
221731	219917	95041E	PARTICIPANT	\N	PRESENT	0
221732	219917	01048V	PARTICIPANT	\N	PRESENT	0
221733	219917	19545Y	PARTICIPANT	\N	PRESENT	0
221734	219917	01057W	PARTICIPANT	\N	PRESENT	0
221735	219917	19667J	PARTICIPANT	\N	PRESENT	0
221736	219917	89017R	PARTICIPANT	\N	PRESENT	0
221737	219917	19671E	PARTICIPANT	\N	PRESENT	0
221738	219917	11070L	PARTICIPANT	\N	PRESENT	0
221739	219917	88008L	PARTICIPANT	\N	PRESENT	0
221740	219917	14225N	PARTICIPANT	\N	PRESENT	0
221741	219917	07029T	PARTICIPANT	\N	PRESENT	0
221742	219917	14277B	PARTICIPANT	\N	PRESENT	0
221743	219917	14085U	PARTICIPANT	\N	PRESENT	0
221744	219917	07004J	PARTICIPANT	\N	PRESENT	0
221745	219917	19349W	PARTICIPANT	\N	PRESENT	0
218364	207714	14157T	PARTICIPANT	\N	PRESENT	0
218365	207714	11070L	PARTICIPANT	\N	PRESENT	0
218366	207714	01043Q	PARTICIPANT	\N	PRESENT	0
218367	207714	14053L	PARTICIPANT	\N	PRESENT	0
218368	207714	14237S	PARTICIPANT	\N	PRESENT	0
218369	207714	11097X	PARTICIPANT	\N	PRESENT	0
218370	207714	14071N	PARTICIPANT	\N	PRESENT	0
218371	207714	14249W	PARTICIPANT	\N	PRESENT	0
218372	207714	98024R	PARTICIPANT	\N	PRESENT	0
218373	207714	19733B	PARTICIPANT	\N	PRESENT	0
218374	207714	14235Q	PARTICIPANT	\N	PRESENT	0
218375	207714	11077T	PARTICIPANT	\N	PRESENT	0
218376	207714	14201E	PARTICIPANT	\N	PRESENT	0
218377	207714	04057K	PARTICIPANT	\N	PRESENT	0
218477	217582	19479G	PARTICIPANT	\N	PRESENT	0
218478	217582	11048N	PARTICIPANT	\N	PRESENT	0
218479	217582	19711U	PARTICIPANT	\N	PRESENT	0
218480	217582	19651A	PARTICIPANT	\N	PRESENT	0
218481	217582	01048V	PARTICIPANT	\N	PRESENT	0
218482	217582	08034U	PARTICIPANT	\N	PRESENT	0
218483	217582	95015C	RAPPORTEUR_AVIS	\N	PRESENT	0
218484	217582	11074Q	PRESIDENT	0	PRESENT	0
218485	217582	19667J	PARTICIPANT	\N	PRESENT	0
218486	217582	08011M	PARTICIPANT	\N	PRESENT	0
218487	217582	89017R	PARTICIPANT	\N	PRESENT	0
218488	217582	08014Q	PARTICIPANT	\N	PRESENT	0
218489	217582	88008L	PARTICIPANT	\N	PRESENT	0
218490	217582	07029T	PARTICIPANT	\N	PRESENT	0
218491	217582	14083S	PARTICIPANT	\N	PRESENT	0
218492	217582	14085U	PARTICIPANT	\N	PRESENT	0
218493	217582	19349W	PARTICIPANT	\N	PRESENT	0
218494	217582	08010L	PARTICIPANT	\N	PRESENT	0
218495	217582	07004J	PARTICIPANT	\N	EXCUSE	0
218496	217469	01043Q	PARTICIPANT	\N	PRESENT	0
218497	217469	11101A	PARTICIPANT	\N	PRESENT	0
218498	217469	14257W	PARTICIPANT	\N	PRESENT	0
218500	207714	19739H	PARTICIPANT	\N	PRESENT	0
218502	217469	14197C	PARTICIPANT	\N	PRESENT	0
218503	217573	19697Q	PARTICIPANT	\N	PRESENT	0
218504	217573	11067R	PARTICIPANT	\N	PRESENT	0
218505	217573	11077T	PARTICIPANT	\N	PRESENT	0
218506	217573	14355X	PARTICIPANT	\N	PRESENT	0
218507	217573	11097X	PARTICIPANT	\N	PRESENT	0
218508	217573	19415P	PARTICIPANT	\N	PRESENT	0
218509	217573	04045F	PARTICIPANT	\N	PRESENT	0
218510	217573	14223L	PARTICIPANT	\N	PRESENT	0
218511	217573	14026U	PARTICIPANT	\N	PRESENT	0
218512	217573	14227Q	PARTICIPANT	\N	PRESENT	0
218513	217573	14239U	PARTICIPANT	\N	PRESENT	0
218514	217573	19703U	PARTICIPANT	\N	PRESENT	0
218515	217573	19553Y	PARTICIPANT	\N	PRESENT	0
218516	217573	14087W	PARTICIPANT	\N	PRESENT	0
218517	217573	14281W	PARTICIPANT	\N	PRESENT	0
218518	217573	14195A	PARTICIPANT	\N	PRESENT	0
218519	217573	14213J	PARTICIPANT	\N	PRESENT	0
218520	217573	19367Y	PARTICIPANT	\N	PRESENT	0
218521	217573	14217N	PARTICIPANT	\N	PRESENT	0
218522	217573	14261S	PARTICIPANT	\N	PRESENT	0
218523	217573	19335Q	PARTICIPANT	\N	PRESENT	0
218524	217573	98024R	PARTICIPANT	\N	PRESENT	0
218525	217573	19527W	PARTICIPANT	\N	PRESENT	0
218526	217573	01034P	PARTICIPANT	\N	PRESENT	0
218527	217573	04092N	PRESIDENT	0	PRESENT	0
218528	217573	08052W	PARTICIPANT	\N	PRESENT	0
218529	217573	19663E	PARTICIPANT	\N	PRESENT	0
218530	217573	19715Y	PARTICIPANT	\N	PRESENT	0
218531	217573	19723Y	PARTICIPANT	\N	PRESENT	0
218532	217573	19727D	PARTICIPANT	\N	PRESENT	0
218533	217573	14119M	PARTICIPANT	\N	PRESENT	0
218534	217573	11103C	PARTICIPANT	\N	PRESENT	0
218535	217573	19657G	PARTICIPANT	\N	PRESENT	0
218536	217573	14071N	PARTICIPANT	\N	PRESENT	0
218537	217573	19577H	PARTICIPANT	\N	PRESENT	0
219631	219630	14229S	PARTICIPANT	\N	PRESENT	0
219632	219630	19593H	PARTICIPANT	\N	PRESENT	0
219633	219630	08043V	PARTICIPANT	\N	PRESENT	0
219635	219634	95015C	PARTICIPANT	\N	PRESENT	0
219636	219634	19593H	PARTICIPANT	\N	PRESENT	0
219638	219637	14039A	PARTICIPANT	\N	PRESENT	0
219639	219637	19593H	PARTICIPANT	\N	PRESENT	0
219641	219640	19699S	PARTICIPANT	\N	PRESENT	0
219643	219642	19699S	PARTICIPANT	\N	PRESENT	0
219696	219695	08012N	PARTICIPANT	\N	PRESENT	0
219697	219695	87003B	PARTICIPANT	\N	PRESENT	0
219698	219695	14073Q	PARTICIPANT	\N	PRESENT	0
219699	219695	19611R	PARTICIPANT	\N	PRESENT	0
219701	219700	08012N	PARTICIPANT	\N	PRESENT	0
219703	219702	08012N	PARTICIPANT	\N	PRESENT	0
219705	219704	11104D	PARTICIPANT	\N	PRESENT	0
219707	219706	11104D	PARTICIPANT	\N	PRESENT	0
219709	219708	11104D	PARTICIPANT	\N	PRESENT	0
219711	219710	92040Q	PARTICIPANT	\N	PRESENT	0
219712	219710	19735D	PARTICIPANT	\N	PRESENT	0
219817	219816	04040A	PARTICIPANT	\N	PRESENT	0
219818	219816	14255U	PARTICIPANT	\N	PRESENT	0
219819	219816	98029W	PARTICIPANT	\N	PRESENT	0
219820	219816	11027H	PARTICIPANT	\N	PRESENT	0
219821	219816	14079W	PARTICIPANT	\N	PRESENT	0
219822	219816	98018T	PRESIDENT	0	PRESENT	0
219823	219816	19251M	PARTICIPANT	\N	PRESENT	0
219824	219816	19583F	PARTICIPANT	\N	PRESENT	0
219825	219816	19709B	PARTICIPANT	\N	PRESENT	0
219826	219816	16685X	PARTICIPANT	\N	PRESENT	0
219827	219816	98050T	PARTICIPANT	\N	PRESENT	0
219828	219816	14235Q	PARTICIPANT	\N	PRESENT	0
219829	219816	19443T	PARTICIPANT	\N	PRESENT	0
219830	219816	19421M	PARTICIPANT	\N	PRESENT	0
219831	219816	01058X	PARTICIPANT	\N	PRESENT	0
219832	219816	19669L	PARTICIPANT	\N	PRESENT	0
219833	219816	01062T	PARTICIPANT	\N	PRESENT	0
219834	219816	11041F	PARTICIPANT	\N	PRESENT	0
219835	219816	95067Q	PARTICIPANT	\N	PRESENT	0
219836	219816	96004D	PARTICIPANT	\N	PRESENT	0
219837	219816	08011M	PARTICIPANT	\N	PRESENT	0
219838	219816	11074Q	PARTICIPANT	\N	PRESENT	0
219839	219816	14073Q	PARTICIPANT	\N	PRESENT	0
219840	219816	14089Y	PARTICIPANT	\N	PRESENT	0
219841	219816	14205J	PARTICIPANT	\N	PRESENT	0
219842	219816	19593H	PARTICIPANT	\N	PRESENT	0
219843	219816	11026G	PARTICIPANT	\N	PRESENT	0
219844	219816	08073C	PARTICIPANT	\N	PRESENT	0
219845	219816	14357A	PARTICIPANT	\N	PRESENT	0
219846	219816	04097T	PARTICIPANT	\N	PRESENT	0
219847	219816	14026U	PARTICIPANT	\N	PRESENT	0
219848	219816	14033T	PARTICIPANT	\N	PRESENT	0
219849	219816	10015M	PARTICIPANT	\N	PRESENT	0
219850	219816	08039A	PARTICIPANT	\N	PRESENT	0
219861	219816	04057K	PARTICIPANT	\N	PRESENT	0
219864	219816	14331P	PARTICIPANT	\N	PRESENT	0
219866	219816	04061F	PARTICIPANT	\N	PRESENT	0
219867	219816	11083R	PARTICIPANT	\N	PRESENT	0
219872	219816	98053W	PARTICIPANT	\N	EXCUSE	0
219873	219816	04035D	PARTICIPANT	\N	EXCUSE	0
219875	219816	08056B	PARTICIPANT	\N	EXCUSE	0
219877	219816	14028W	PARTICIPANT	\N	EXCUSE	0
219879	219816	11054L	PARTICIPANT	\N	EXCUSE	0
219922	219816	04034C	PARTICIPANT	\N	PRESENT	0
220245	220244	08019V	PARTICIPANT	\N	PRESENT	0
220247	220246	14187A	PARTICIPANT	\N	PRESENT	0
220249	220248	14081Q	PARTICIPANT	\N	PRESENT	0
220250	220248	19591F	PARTICIPANT	\N	PRESENT	0
220257	220248	01043Q	PARTICIPANT	\N	PRESENT	0
220261	220260	14081Q	PARTICIPANT	\N	PRESENT	0
220262	220260	19591F	PARTICIPANT	\N	PRESENT	0
220264	220263	14081Q	PARTICIPANT	\N	PRESENT	0
220265	220263	19591F	PARTICIPANT	\N	PRESENT	0
220326	219964	19663E	PARTICIPANT	\N	EXCUSE	0
220330	220329	11074Q	PARTICIPANT	\N	PRESENT	0
220332	220331	14083S	PARTICIPANT	\N	PRESENT	0
220334	220333	01057W	PARTICIPANT	\N	PRESENT	0
220335	220333	14225N	PARTICIPANT	\N	PRESENT	0
220337	220336	14331P	PARTICIPANT	\N	PRESENT	0
220339	220338	14327T	PARTICIPANT	\N	PRESENT	0
222209	219921	19711U	PARTICIPANT	\N	PRESENT	0
222210	219921	95041E	PARTICIPANT	\N	PRESENT	0
222211	219921	19651A	PARTICIPANT	\N	PRESENT	0
222212	219921	19545Y	PARTICIPANT	\N	PRESENT	0
222214	219921	19687N	PARTICIPANT	\N	PRESENT	0
222215	219921	12016W	PARTICIPANT	\N	PRESENT	0
222216	219921	11074Q	PRESIDENT	0	PRESENT	0
222217	219921	19667J	PARTICIPANT	\N	PRESENT	0
222218	219921	14225N	PARTICIPANT	\N	PRESENT	0
222219	219921	04086Q	PARTICIPANT	\N	PRESENT	0
222220	219921	11040E	PARTICIPANT	\N	PRESENT	0
222221	219921	14083S	PARTICIPANT	\N	PRESENT	0
222222	219921	07029T	PARTICIPANT	\N	PRESENT	0
214487	213059	08011M	PARTICIPANT	\N	EXCUSE	0
214625	207252	14275Y	PARTICIPANT	\N	EXCUSE	0
214975	214974	11049P	PARTICIPANT	\N	PRESENT	0
214976	214974	19581D	PARTICIPANT	\N	PRESENT	0
217337	214584	07029T	PARTICIPANT	\N	PRESENT	0
217339	217338	89017R	PARTICIPANT	\N	PRESENT	0
217340	217338	14034U	PARTICIPANT	\N	PRESENT	0
217341	217338	14199E	PARTICIPANT	\N	PRESENT	0
217342	217338	14173T	PARTICIPANT	\N	PRESENT	0
217343	217338	11048N	PARTICIPANT	\N	PRESENT	0
217344	217338	14331P	PARTICIPANT	\N	PRESENT	0
217345	217338	11012A	PARTICIPANT	\N	PRESENT	0
217346	217338	04086Q	PARTICIPANT	\N	PRESENT	0
217347	217338	07029T	PARTICIPANT	\N	PRESENT	0
217348	217338	19647E	PARTICIPANT	\N	PRESENT	0
217349	217338	19671E	PARTICIPANT	\N	PRESENT	0
217350	217338	19479G	PARTICIPANT	\N	PRESENT	0
217353	217338	14327T	PARTICIPANT	\N	PRESENT	0
217354	217338	14225N	PARTICIPANT	\N	PRESENT	0
217355	217338	08010L	PARTICIPANT	\N	PRESENT	0
217356	217338	19545Y	PARTICIPANT	\N	PRESENT	0
217357	217338	19651A	PARTICIPANT	\N	PRESENT	0
217358	217338	11053K	PARTICIPANT	\N	PRESENT	0
217359	217338	19349W	PARTICIPANT	\N	PRESENT	0
217360	217338	19711U	PARTICIPANT	\N	PRESENT	0
217361	217338	14085U	PARTICIPANT	\N	PRESENT	0
217362	217338	11074Q	PRESIDENT	0	PRESENT	0
217363	217338	08011M	PARTICIPANT	\N	PRESENT	0
217364	217338	07004J	PARTICIPANT	\N	EXCUSE	0
217371	214584	14205J	PARTICIPANT	\N	PRESENT	0
217397	214584	14331P	PARTICIPANT	\N	PRESENT	0
217398	214584	14249W	PARTICIPANT	\N	PRESENT	0
217399	214584	14229S	PARTICIPANT	\N	PRESENT	0
224449	223695	08010L	PARTICIPANT	\N	PRESENT	0
227102	226199	11031D	PARTICIPANT	\N	PRESENT	0
227103	226199	14087W	PARTICIPANT	\N	PRESENT	0
227104	226199	14213J	PARTICIPANT	\N	PRESENT	0
227105	226199	19521Q	PARTICIPANT	\N	PRESENT	0
227106	226199	11045K	PARTICIPANT	\N	PRESENT	0
227107	226199	19663E	PARTICIPANT	\N	PRESENT	0
227143	225850	14357A	PARTICIPANT	\N	PRESENT	0
227144	225850	19441R	PARTICIPANT	\N	PRESENT	0
227145	225850	80013X	PARTICIPANT	\N	PRESENT	0
227146	225850	08038Y	PARTICIPANT	\N	PRESENT	0
227147	225850	14205J	PARTICIPANT	\N	PRESENT	0
227148	225773	08056B	PARTICIPANT	\N	PRESENT	0
227149	225774	98005N	PARTICIPANT	\N	PRESENT	0
227150	225774	19443T	PARTICIPANT	\N	PRESENT	0
227151	225774	11080N	PARTICIPANT	\N	PRESENT	0
227152	225774	95030B	PARTICIPANT	\N	PRESENT	0
227153	225774	04034C	PARTICIPANT	\N	PRESENT	0
227154	225774	14079W	PARTICIPANT	\N	PRESENT	0
227155	225774	01058X	PARTICIPANT	\N	PRESENT	0
227156	225774	04040A	PARTICIPANT	\N	PRESENT	0
227228	225774	95067Q	PARTICIPANT	\N	PRESENT	0
227158	225774	11066Q	PARTICIPANT	\N	PRESENT	0
227159	225774	19669L	PARTICIPANT	\N	PRESENT	0
227160	225774	08056B	PARTICIPANT	\N	PRESENT	0
227161	225774	95037J	PARTICIPANT	\N	PRESENT	0
227162	225774	14055N	PARTICIPANT	\N	PRESENT	0
227163	225774	19421M	PARTICIPANT	\N	PRESENT	0
227164	225774	19709B	PARTICIPANT	\N	PRESENT	0
227229	225774	04042C	PARTICIPANT	\N	EXCUSE	0
227166	225774	14193X	PARTICIPANT	\N	PRESENT	0
227167	225774	08053X	PARTICIPANT	\N	PRESENT	0
227168	225774	97011G	PARTICIPANT	\N	PRESENT	0
227230	225773	04042C	PARTICIPANT	\N	EXCUSE	0
227170	225774	08047A	PARTICIPANT	\N	PRESENT	0
227171	225774	04035D	PARTICIPANT	\N	PRESENT	0
227425	218447	14147R	PARTICIPANT	\N	PRESENT	0
227173	225774	11041F	PARTICIPANT	\N	PRESENT	0
227174	225774	14235Q	PARTICIPANT	\N	PRESENT	0
227175	225774	08058D	PARTICIPANT	\N	PRESENT	0
227176	225774	19251M	PARTICIPANT	\N	PRESENT	0
227177	225774	14028W	PARTICIPANT	\N	PRESENT	0
227178	225774	19721W	PARTICIPANT	\N	PRESENT	0
227179	225774	14105F	PARTICIPANT	\N	PRESENT	0
227180	225774	98018T	PRESIDENT	0	PRESENT	0
227181	225774	98022P	PARTICIPANT	\N	PRESENT	0
227182	225774	14267Y	PARTICIPANT	\N	PRESENT	0
227183	225774	11064N	PARTICIPANT	\N	PRESENT	0
227184	225774	98050T	PARTICIPANT	\N	PRESENT	0
227427	218447	11049P	PARTICIPANT	\N	PRESENT	0
227186	225976	04044E	PARTICIPANT	\N	PRESENT	0
227187	225976	19581D	PARTICIPANT	\N	PRESENT	0
227188	225976	19585H	PARTICIPANT	\N	PRESENT	0
227189	225976	04047H	PARTICIPANT	\N	PRESENT	0
227190	225976	19673G	PARTICIPANT	\N	PRESENT	0
227191	225976	01028R	PARTICIPANT	\N	PRESENT	0
227192	225976	14231L	PARTICIPANT	\N	PRESENT	0
227193	225976	05008E	PRESIDENT	0	PRESENT	0
227194	225976	19447X	PARTICIPANT	\N	PRESENT	0
227195	225976	19489J	PARTICIPANT	\N	PRESENT	0
227196	225976	14041T	PARTICIPANT	\N	PRESENT	0
227197	225976	14179A	PARTICIPANT	\N	PRESENT	0
227198	225976	14147R	PARTICIPANT	\N	PRESENT	0
227199	225976	14151M	PARTICIPANT	\N	PRESENT	0
227200	225976	14215L	PARTICIPANT	\N	PRESENT	0
227201	225976	19483C	PARTICIPANT	\N	PRESENT	0
227202	225976	08018U	PARTICIPANT	\N	PRESENT	0
227203	225976	14259Y	PARTICIPANT	\N	PRESENT	0
227204	225976	11072N	PARTICIPANT	\N	PRESENT	0
227205	225976	14053L	PARTICIPANT	\N	PRESENT	0
227206	225976	14111D	PARTICIPANT	\N	PRESENT	0
227207	225976	19649G	PARTICIPANT	\N	PRESENT	0
227208	225976	14065Q	PARTICIPANT	\N	PRESENT	0
227209	225976	10015M	PARTICIPANT	\N	PRESENT	0
227210	225976	08045X	PARTICIPANT	\N	PRESENT	0
227211	225976	07034Q	PRESIDENT	1	PRESENT	0
227212	225976	11026G	PARTICIPANT	\N	PRESENT	0
227213	225976	19253P	PARTICIPANT	\N	PRESENT	0
227214	225976	01024M	PARTICIPANT	\N	PRESENT	0
227215	225976	04038G	PARTICIPANT	\N	PRESENT	0
227216	225976	19719D	PARTICIPANT	\N	PRESENT	0
227217	225976	11033F	PARTICIPANT	\N	PRESENT	0
227218	225976	19725B	PARTICIPANT	\N	PRESENT	0
227219	225976	19729F	PARTICIPANT	\N	PRESENT	0
227220	225976	19629C	PARTICIPANT	\N	PRESENT	0
227221	225976	08044W	PARTICIPANT	\N	PRESENT	0
227222	225976	14069U	PARTICIPANT	\N	PRESENT	0
227223	225976	11049P	PARTICIPANT	\N	PRESENT	0
227224	225976	14021P	PARTICIPANT	\N	PRESENT	0
227225	225850	14115H	PARTICIPANT	\N	PRESENT	0
227226	225774	14255U	PARTICIPANT	\N	PRESENT	0
227227	226199	19569H	PARTICIPANT	\N	PRESENT	0
227438	218447	14231L	PARTICIPANT	\N	PRESENT	0
227439	218445	04044E	PARTICIPANT	\N	PRESENT	0
227440	218445	11056N	PARTICIPANT	\N	PRESENT	0
227441	218445	19695N	PARTICIPANT	\N	PRESENT	0
227442	218445	19527W	PARTICIPANT	\N	PRESENT	0
227443	218445	19333N	PARTICIPANT	\N	PRESENT	0
227444	218445	19591F	PARTICIPANT	\N	PRESENT	0
227445	218445	19349W	PARTICIPANT	\N	PRESENT	0
227446	218445	14195A	PARTICIPANT	\N	PRESENT	0
227447	218445	19671E	PARTICIPANT	\N	PRESENT	0
227448	218445	19413M	PARTICIPANT	\N	PRESENT	0
227456	218445	19503N	PARTICIPANT	\N	PRESENT	0
227457	218445	19725B	PARTICIPANT	\N	PRESENT	0
227458	218445	17589D	PARTICIPANT	\N	PRESENT	0
227459	218445	19629C	PARTICIPANT	\N	PRESENT	0
227460	218445	19637C	PARTICIPANT	\N	PRESENT	0
227461	218445	19651A	PARTICIPANT	\N	PRESENT	0
227462	218445	08061X	PARTICIPANT	\N	PRESENT	0
227463	218445	11066Q	PARTICIPANT	\N	PRESENT	0
227464	218445	14187A	PARTICIPANT	\N	PRESENT	0
227465	218445	14327T	PARTICIPANT	\N	PRESENT	0
227466	218445	04086Q	PARTICIPANT	\N	PRESENT	0
227467	218445	19467C	PARTICIPANT	\N	PRESENT	0
227469	218445	14169X	PARTICIPANT	\N	PRESENT	0
227470	218445	14115H	PARTICIPANT	\N	PRESENT	0
227471	218445	11090Q	PARTICIPANT	\N	PRESENT	0
227472	218445	01057W	PARTICIPANT	\N	PRESENT	0
227473	218445	11103C	PARTICIPANT	\N	PRESENT	0
227474	218445	14061L	PARTICIPANT	\N	PRESENT	0
227475	218445	19733B	PARTICIPANT	\N	PRESENT	0
227476	218445	14041T	PARTICIPANT	\N	PRESENT	0
227477	218445	19675J	PARTICIPANT	\N	PRESENT	0
227478	218445	14329V	PARTICIPANT	\N	PRESENT	0
227479	218445	14026U	PARTICIPANT	\N	PRESENT	0
227480	218445	14331P	PARTICIPANT	\N	PRESENT	0
227481	218445	14217N	PARTICIPANT	\N	PRESENT	0
227482	218445	08010L	PARTICIPANT	\N	PRESENT	0
227483	218445	14105F	PARTICIPANT	\N	PRESENT	0
227484	218445	12016W	PARTICIPANT	\N	PRESENT	0
227485	218445	19727D	PARTICIPANT	\N	PRESENT	0
227486	218445	08024S	PARTICIPANT	\N	PRESENT	0
227487	218445	19631V	PARTICIPANT	\N	PRESENT	0
227488	218445	14085U	PARTICIPANT	\N	PRESENT	0
226432	218315	88008L	PARTICIPANT	\N	PRESENT	0
226433	218315	11012A	PARTICIPANT	\N	PRESENT	0
226434	218315	11110B	PARTICIPANT	\N	PRESENT	0
226435	218315	14069U	PARTICIPANT	\N	PRESENT	0
226436	218315	14249W	PARTICIPANT	\N	PRESENT	0
226437	218315	08039A	PARTICIPANT	\N	PRESENT	0
226438	218315	04034C	PARTICIPANT	\N	PRESENT	0
226439	218315	95041E	PARTICIPANT	\N	PRESENT	0
226440	218315	11053K	PARTICIPANT	\N	PRESENT	0
226441	218315	11085T	PARTICIPANT	\N	PRESENT	0
226442	218315	19531S	PARTICIPANT	\N	PRESENT	0
226443	218315	14028W	PARTICIPANT	\N	PRESENT	0
226444	218315	08020N	PARTICIPANT	\N	PRESENT	0
226445	218315	08010L	PARTICIPANT	\N	PRESENT	0
226446	218315	14231L	PARTICIPANT	\N	PRESENT	0
226447	218315	07029T	PARTICIPANT	\N	PRESENT	0
226449	218443	04044E	PARTICIPANT	\N	PRESENT	0
226450	226099	14327T	PARTICIPANT	\N	PRESENT	0
226451	226099	04071H	PARTICIPANT	\N	PRESENT	0
226452	226099	95041E	PARTICIPANT	\N	PRESENT	0
226453	226099	01048V	PARTICIPANT	\N	PRESENT	0
226500	218443	14135M	PARTICIPANT	\N	PRESENT	0
226455	226099	01057W	PARTICIPANT	\N	PRESENT	0
226456	226099	11053K	PARTICIPANT	\N	PRESENT	0
226457	226099	11074Q	PRESIDENT	0	PRESENT	0
226458	226099	19667J	PARTICIPANT	\N	PRESENT	0
226459	226099	14225N	PARTICIPANT	\N	PRESENT	0
226460	226099	19671E	PARTICIPANT	\N	PRESENT	0
226461	226099	88008L	PARTICIPANT	\N	PRESENT	0
226462	226099	07029T	PARTICIPANT	\N	PRESENT	0
226463	226099	14085U	PARTICIPANT	\N	PRESENT	0
226464	226099	08010L	PARTICIPANT	\N	PRESENT	0
226465	226099	11048N	PARTICIPANT	\N	PRESENT	0
226466	226099	19647E	PARTICIPANT	\N	PRESENT	0
226467	226099	19711U	PARTICIPANT	\N	PRESENT	0
226502	218443	19735D	PARTICIPANT	\N	PRESENT	0
226469	226099	19531S	PARTICIPANT	\N	PRESENT	0
226470	226099	08069G	PARTICIPANT	\N	PRESENT	0
226471	226099	19687N	PARTICIPANT	\N	PRESENT	0
226503	218443	11066Q	PARTICIPANT	\N	PRESENT	0
226473	226099	12016W	PARTICIPANT	\N	PRESENT	0
226474	226099	08011M	PARTICIPANT	\N	PRESENT	0
226475	226099	14034U	PARTICIPANT	\N	PRESENT	0
226476	226099	08014Q	PARTICIPANT	\N	PRESENT	0
226477	226099	14159V	PARTICIPANT	\N	PRESENT	0
226478	226099	04086Q	PARTICIPANT	\N	PRESENT	0
226479	226099	11040E	PARTICIPANT	\N	PRESENT	0
226480	226099	14199E	PARTICIPANT	\N	PRESENT	0
226481	226099	14121F	PARTICIPANT	\N	PRESENT	0
226482	226099	99004R	PARTICIPANT	\N	PRESENT	0
226483	226099	89017R	PARTICIPANT	\N	PRESENT	0
226484	226099	14083S	PARTICIPANT	\N	PRESENT	0
226499	218443	19333N	PARTICIPANT	\N	PRESENT	0
226504	218443	04043D	PARTICIPANT	\N	PRESENT	0
226505	218443	19689Q	PARTICIPANT	\N	PRESENT	0
226506	218443	19489J	PARTICIPANT	\N	PRESENT	0
226507	226099	14331P	PARTICIPANT	\N	PRESENT	0
226721	218441	14169X	PARTICIPANT	\N	PRESENT	0
226722	218441	11026G	PARTICIPANT	\N	PRESENT	0
226723	218441	14051J	PARTICIPANT	\N	PRESENT	0
226724	218441	08062Y	PARTICIPANT	\N	PRESENT	0
226725	218441	08034U	PARTICIPANT	\N	PRESENT	0
226726	218441	14211G	PARTICIPANT	\N	PRESENT	0
226727	218441	19503N	PARTICIPANT	\N	PRESENT	0
226728	218441	14193X	PARTICIPANT	\N	PRESENT	0
226729	218441	19489J	PARTICIPANT	\N	PRESENT	0
226730	218441	19575F	PARTICIPANT	\N	PRESENT	0
226731	218441	14121F	PARTICIPANT	\N	PRESENT	0
226732	218441	14201E	PARTICIPANT	\N	PRESENT	0
226734	218441	14197C	PARTICIPANT	\N	PRESENT	0
226735	218441	04045F	PARTICIPANT	\N	PRESENT	0
226736	218441	19483C	PARTICIPANT	\N	PRESENT	0
226737	218441	14119M	PARTICIPANT	\N	PRESENT	0
226739	218441	19367Y	PARTICIPANT	\N	PRESENT	0
226748	218441	14147R	PARTICIPANT	\N	PRESENT	0
226750	218441	19685L	PARTICIPANT	\N	PRESENT	0
226751	218441	80027E	PARTICIPANT	\N	PRESENT	0
226752	218441	14029X	PARTICIPANT	\N	PRESENT	0
226753	218441	14199E	PARTICIPANT	\N	PRESENT	0
226754	218441	19591F	PARTICIPANT	\N	PRESENT	0
226766	218441	14042U	PARTICIPANT	\N	PRESENT	0
226767	218441	14223L	PARTICIPANT	\N	PRESENT	0
226768	218441	14026U	PARTICIPANT	\N	PRESENT	0
226769	218441	08038Y	PARTICIPANT	\N	PRESENT	0
226770	218441	19647E	PARTICIPANT	\N	PRESENT	0
226771	218441	80013X	PARTICIPANT	\N	PRESENT	0
226772	218441	18083K	PARTICIPANT	\N	PRESENT	0
226774	218441	11085T	PARTICIPANT	\N	PRESENT	0
226775	218441	14030Q	PARTICIPANT	\N	PRESENT	0
226776	218441	19253P	PARTICIPANT	\N	PRESENT	0
226777	218441	19549D	PARTICIPANT	\N	PRESENT	0
226778	218441	08014Q	PARTICIPANT	\N	PRESENT	0
226779	218441	19533U	PARTICIPANT	\N	PRESENT	0
226780	218441	08024S	PARTICIPANT	\N	PRESENT	0
226781	218441	08060W	PARTICIPANT	\N	PRESENT	0
226782	218441	14195A	PARTICIPANT	\N	PRESENT	0
226783	218441	19347U	PARTICIPANT	\N	PRESENT	0
226784	218441	96004D	PARTICIPANT	\N	PRESENT	0
226789	218441	11067R	PARTICIPANT	\N	PRESENT	0
226790	218441	04092N	PARTICIPANT	\N	PRESENT	0
226791	218441	14231L	PARTICIPANT	\N	PRESENT	0
226792	218441	08015R	PARTICIPANT	\N	PRESENT	0
226793	218441	14217N	PARTICIPANT	\N	PRESENT	0
226794	218441	14257W	PARTICIPANT	\N	PRESENT	0
226795	218441	19569H	PARTICIPANT	\N	PRESENT	0
226796	218441	02002K	PARTICIPANT	\N	PRESENT	0
226797	218441	14151M	PARTICIPANT	\N	PRESENT	0
226798	218441	19521Q	PARTICIPANT	\N	PRESENT	0
226799	218441	11064N	PARTICIPANT	\N	PRESENT	0
226800	218441	11097X	PARTICIPANT	\N	PRESENT	0
226801	218441	88008L	PARTICIPANT	\N	PRESENT	0
226802	218441	14187A	PARTICIPANT	\N	PRESENT	0
226803	218441	95062K	PARTICIPANT	\N	PRESENT	0
226804	218441	17583W	PARTICIPANT	\N	PRESENT	0
226805	218441	04038G	PARTICIPANT	\N	PRESENT	0
226806	218441	01057W	PARTICIPANT	\N	PRESENT	0
226807	218441	14327T	PARTICIPANT	\N	PRESENT	0
226808	218441	01043Q	PARTICIPANT	\N	PRESENT	0
226809	218441	19631V	PARTICIPANT	\N	PRESENT	0
226810	218441	08044W	PARTICIPANT	\N	PRESENT	0
226811	218441	11110B	PARTICIPANT	\N	PRESENT	0
226812	218441	11048N	PARTICIPANT	\N	PRESENT	0
226874	218442	08010L	PARTICIPANT	\N	PRESENT	0
226875	218442	01024M	PARTICIPANT	\N	PRESENT	0
226876	218442	11074Q	PARTICIPANT	\N	PRESENT	0
226877	218442	14065Q	PARTICIPANT	\N	PRESENT	0
226878	218442	19543W	PARTICIPANT	\N	PRESENT	0
226879	218442	19503N	PARTICIPANT	\N	PRESENT	0
226880	218442	19447X	PARTICIPANT	\N	PRESENT	0
226881	218442	19507S	PARTICIPANT	\N	PRESENT	0
226882	218442	19415P	PARTICIPANT	\N	PRESENT	0
226883	218442	14157T	PARTICIPANT	\N	PRESENT	0
226884	218442	19533U	PARTICIPANT	\N	PRESENT	0
226885	218442	14179A	PARTICIPANT	\N	PRESENT	0
226886	218442	17583W	PARTICIPANT	\N	PRESENT	0
226887	218442	08044W	PARTICIPANT	\N	PRESENT	0
226888	218442	14119M	PARTICIPANT	\N	PRESENT	0
226889	218442	14105F	PARTICIPANT	\N	PRESENT	0
226890	218442	14083S	PARTICIPANT	\N	PRESENT	0
226891	218442	14111D	PARTICIPANT	\N	PRESENT	0
226892	218442	17637T	PARTICIPANT	\N	PRESENT	0
226893	218442	19649G	PARTICIPANT	\N	PRESENT	0
226894	218442	04085P	PARTICIPANT	\N	PRESENT	0
226895	218442	01028R	PARTICIPANT	\N	PRESENT	0
226896	218442	04047H	PARTICIPANT	\N	PRESENT	0
226897	218442	05008E	PARTICIPANT	\N	PRESENT	0
226898	218442	19253P	PARTICIPANT	\N	PRESENT	0
226899	218442	18083K	PARTICIPANT	\N	PRESENT	0
226900	218442	19387D	PARTICIPANT	\N	PRESENT	0
226901	218442	19349W	PARTICIPANT	\N	PRESENT	0
226902	218442	08039A	PARTICIPANT	\N	PRESENT	0
226903	218442	19679N	PARTICIPANT	\N	PRESENT	0
226904	218442	19719D	PARTICIPANT	\N	PRESENT	0
226905	218442	19737F	PARTICIPANT	\N	PRESENT	0
226906	218442	19483C	PARTICIPANT	\N	PRESENT	0
226907	218442	14030Q	PARTICIPANT	\N	PRESENT	0
226908	218442	19647E	PARTICIPANT	\N	PRESENT	0
226909	218442	11064N	PARTICIPANT	\N	PRESENT	0
226910	218442	19629C	PARTICIPANT	\N	PRESENT	0
226911	218442	88008L	PARTICIPANT	\N	PRESENT	0
226912	218442	11012A	PARTICIPANT	\N	PRESENT	0
226913	218442	19569H	PARTICIPANT	\N	PRESENT	0
226914	218442	14261S	PARTICIPANT	\N	PRESENT	0
226915	218442	14231L	PARTICIPANT	\N	PRESENT	0
226916	218442	14069U	PARTICIPANT	\N	PRESENT	0
226917	218442	14331P	PARTICIPANT	\N	PRESENT	0
226918	218442	14033T	PARTICIPANT	\N	PRESENT	0
226919	218442	04088S	PARTICIPANT	\N	PRESENT	0
226920	218442	14187A	PARTICIPANT	\N	PRESENT	0
212051	210184	14031R	PARTICIPANT	\N	PRESENT	0
211988	210184	08055A	PARTICIPANT	\N	PRESENT	0
217352	217351	08010L	PARTICIPANT	\N	PRESENT	0
217366	217365	08010L	PARTICIPANT	\N	PRESENT	0
217368	217367	08010L	PARTICIPANT	\N	PRESENT	0
211992	210184	08060W	PARTICIPANT	\N	PRESENT	0
211993	210184	19733B	PARTICIPANT	\N	PRESENT	0
217411	217410	11072N	PARTICIPANT	\N	PRESENT	0
211995	210184	08024S	PARTICIPANT	\N	PRESENT	0
211996	210184	14038Y	PARTICIPANT	\N	PRESENT	0
211997	210184	18083K	PARTICIPANT	\N	PRESENT	0
211678	210088	11063M	PARTICIPANT	\N	PRESENT	0
211937	210183	19631V	PARTICIPANT	\N	PRESENT	0
217422	217420	11026G	PARTICIPANT	\N	PRESENT	0
211999	210184	19681G	PARTICIPANT	\N	PRESENT	0
212000	210184	98023Q	PARTICIPANT	\N	PRESENT	0
212001	210184	19525U	PARTICIPANT	\N	PRESENT	0
211942	210183	08068F	PARTICIPANT	\N	PRESENT	0
212002	210184	11065P	PARTICIPANT	\N	PRESENT	0
211944	210183	11101A	PARTICIPANT	\N	PRESENT	0
217427	217426	11026G	PARTICIPANT	\N	PRESENT	0
211946	210183	08028W	PARTICIPANT	\N	PRESENT	0
211947	210183	19467C	PARTICIPANT	\N	PRESENT	0
212004	210184	19599P	PARTICIPANT	\N	PRESENT	0
211949	210183	80013X	PARTICIPANT	\N	PRESENT	0
217432	217431	11026G	PARTICIPANT	\N	PRESENT	0
217434	217433	11026G	PARTICIPANT	\N	PRESENT	0
211952	210183	08038Y	PARTICIPANT	\N	PRESENT	0
217436	217435	11026G	PARTICIPANT	\N	PRESENT	0
211954	210183	04089T	PARTICIPANT	\N	PRESENT	0
212008	210184	19347U	PARTICIPANT	\N	PRESENT	0
211956	210183	14197C	PARTICIPANT	\N	PRESENT	0
211957	210183	14187A	PARTICIPANT	\N	PRESENT	0
221746	219917	08010L	PARTICIPANT	\N	PRESENT	0
221747	219917	14253S	PARTICIPANT	\N	PRESENT	0
211960	210183	19565D	PARTICIPANT	\N	PRESENT	0
211961	210183	14033T	PARTICIPANT	\N	PRESENT	0
212011	210184	19333N	PARTICIPANT	\N	PRESENT	0
211963	210183	19591F	PARTICIPANT	\N	PRESENT	0
212012	210184	04097T	PARTICIPANT	\N	PRESENT	0
221748	219917	11048N	PARTICIPANT	\N	PRESENT	0
212014	210184	14029X	PARTICIPANT	\N	PRESENT	0
211967	210183	08015R	PARTICIPANT	\N	PRESENT	0
221749	219917	19479G	PARTICIPANT	\N	PRESENT	0
211969	210183	14205J	PARTICIPANT	\N	PRESENT	0
211970	210183	19441R	PARTICIPANT	\N	PRESENT	0
211971	210183	08019V	PARTICIPANT	\N	PRESENT	0
211972	210183	08062Y	PARTICIPANT	\N	PRESENT	0
221750	219917	19711U	PARTICIPANT	\N	PRESENT	0
211974	210183	19369B	PARTICIPANT	\N	PRESENT	0
211975	210183	14257W	PARTICIPANT	\N	PRESENT	0
211976	210183	14265W	PARTICIPANT	\N	PRESENT	0
212017	210184	14219Q	PARTICIPANT	\N	PRESENT	0
212018	210184	14103D	PARTICIPANT	\N	PRESENT	0
211979	210183	11090Q	PRESIDENT	0	PRESENT	0
221751	219917	19531S	PARTICIPANT	\N	PRESENT	0
221752	219917	08034U	PARTICIPANT	\N	PRESENT	0
221753	219917	08069G	PARTICIPANT	\N	PRESENT	0
212022	210184	08009T	PRESIDENT	0	PRESENT	0
221754	219917	19687N	PARTICIPANT	\N	PRESENT	0
221755	219917	19689Q	PARTICIPANT	\N	PRESENT	0
211986	210183	19413M	PARTICIPANT	\N	PRESENT	0
212023	210184	14221J	PARTICIPANT	\N	PRESENT	0
212024	210184	14169X	PARTICIPANT	\N	PRESENT	0
212025	210184	14191V	PARTICIPANT	\N	PRESENT	0
221756	219917	12016W	PARTICIPANT	\N	PRESENT	0
221757	219917	08011M	PARTICIPANT	\N	PRESENT	0
221758	219917	08014Q	PARTICIPANT	\N	PRESENT	0
212029	210184	19503N	PARTICIPANT	\N	PRESENT	0
221759	219917	14159V	PARTICIPANT	\N	PRESENT	0
212031	210184	95062K	PARTICIPANT	\N	PRESENT	0
212032	210184	19713W	PARTICIPANT	\N	PRESENT	0
212033	210184	14051J	PARTICIPANT	\N	PRESENT	0
221760	219917	14173T	PARTICIPANT	\N	PRESENT	0
212035	210184	19737F	PARTICIPANT	\N	PRESENT	0
221761	219917	04086Q	PARTICIPANT	\N	PRESENT	0
221762	219917	11040E	PARTICIPANT	\N	PRESENT	0
221763	219917	14083S	PARTICIPANT	\N	PRESENT	0
221764	219917	14119M	RAPPORTEUR_AVIS	\N	PRESENT	0
221765	219917	11012A	PARTICIPANT	\N	PRESENT	0
221766	219917	14199E	PARTICIPANT	\N	PRESENT	0
221767	219917	14121F	PARTICIPANT	\N	PRESENT	0
221768	219917	99004R	PARTICIPANT	\N	PRESENT	0
221769	219917	08073C	PARTICIPANT	\N	PRESENT	0
221770	219917	11053K	PARTICIPANT	\N	PRESENT	0
221771	219917	11074Q	PRESIDENT	0	PRESENT	0
221772	219917	11110B	PARTICIPANT	\N	PRESENT	0
221773	219917	14331P	PARTICIPANT	\N	EXCUSE	0
221774	219917	04061F	PARTICIPANT	\N	PRESENT	0
221775	219746	11077T	PARTICIPANT	\N	PRESENT	0
221776	219746	19683J	PARTICIPANT	\N	PRESENT	0
221778	220317	14041T	PARTICIPANT	\N	PRESENT	0
221779	220317	08018U	PARTICIPANT	\N	PRESENT	0
221780	220317	11026G	PARTICIPANT	\N	PRESENT	0
221781	220317	95063L	PARTICIPANT	\N	PRESENT	0
221782	220317	08044W	PARTICIPANT	\N	PRESENT	0
221783	220317	14259Y	PARTICIPANT	\N	PRESENT	0
221785	219917	19647E	PARTICIPANT	\N	PRESENT	0
221786	220240	19707Y	PARTICIPANT	\N	PRESENT	0
221787	220240	14135M	PARTICIPANT	\N	PRESENT	0
221788	220240	08038Y	PARTICIPANT	\N	PRESENT	0
221789	220240	19295A	PARTICIPANT	\N	PRESENT	0
221790	220240	14205J	PARTICIPANT	\N	PRESENT	0
221791	220240	11056N	PARTICIPANT	\N	PRESENT	0
221792	220236	19333N	PARTICIPANT	\N	PRESENT	0
221793	220236	19383Y	PARTICIPANT	\N	PRESENT	0
221794	220236	17583W	PARTICIPANT	\N	PRESENT	0
221795	220236	19701S	PARTICIPANT	\N	PRESENT	0
221796	220236	19549D	PARTICIPANT	\N	PRESENT	0
221797	220236	19387D	PARTICIPANT	\N	PRESENT	0
221798	220236	14219Q	PARTICIPANT	\N	PRESENT	0
221799	220236	14221J	PARTICIPANT	\N	PRESENT	0
221800	220236	19599P	PARTICIPANT	\N	PRESENT	0
221801	220236	19637C	PARTICIPANT	\N	PRESENT	0
221802	220236	18083K	PARTICIPANT	\N	PRESENT	0
221803	220236	19551W	PARTICIPANT	\N	PRESENT	0
221804	220236	05012A	PARTICIPANT	\N	PRESENT	0
221805	220236	80027E	PARTICIPANT	\N	PRESENT	0
221806	220236	14051J	PARTICIPANT	\N	PRESENT	0
221807	220236	08060W	PARTICIPANT	\N	PRESENT	0
221808	220236	19503N	PARTICIPANT	\N	PRESENT	0
221809	220236	19347U	PARTICIPANT	\N	PRESENT	0
221810	220236	96004D	PARTICIPANT	\N	PRESENT	0
221811	220236	19685L	PARTICIPANT	\N	PRESENT	0
221812	220236	14157T	PARTICIPANT	\N	PRESENT	0
221813	220236	08024S	PARTICIPANT	\N	PRESENT	0
221814	220236	19681G	PARTICIPANT	\N	PRESENT	0
221815	220236	98023Q	PARTICIPANT	\N	PRESENT	0
221816	220236	11065P	PARTICIPANT	\N	PRESENT	0
221817	220236	17637T	PARTICIPANT	\N	PRESENT	0
221818	220236	19525U	PARTICIPANT	\N	PRESENT	0
221819	220236	14103D	PARTICIPANT	\N	PRESENT	0
221820	220236	14031R	PARTICIPANT	\N	PRESENT	0
221821	220236	19713W	PARTICIPANT	\N	PRESENT	0
221822	220236	08055A	PARTICIPANT	\N	PRESENT	0
221823	220236	14191V	PARTICIPANT	\N	PRESENT	0
221824	220236	14169X	PARTICIPANT	\N	PRESENT	0
221825	220236	04085P	PARTICIPANT	\N	PRESENT	0
221826	220236	15447F	PARTICIPANT	\N	PRESENT	0
221827	220236	14093U	PARTICIPANT	\N	PRESENT	0
221828	220236	14029X	PARTICIPANT	\N	PRESENT	0
221829	220236	19733B	PARTICIPANT	\N	PRESENT	0
221830	220236	08009T	PARTICIPANT	\N	PRESENT	0
221831	220236	19737F	PARTICIPANT	\N	PRESENT	0
221832	220236	19739H	PARTICIPANT	\N	PRESENT	0
221833	220236	04097T	PARTICIPANT	\N	PRESENT	0
221834	220236	19659J	PARTICIPANT	\N	PRESENT	0
221835	220236	14038Y	PARTICIPANT	\N	EXCUSE	0
221836	220236	95062K	PARTICIPANT	\N	EXCUSE	0
221837	220236	02002K	PARTICIPANT	\N	EXCUSE	0
221838	221367	11109J	PARTICIPANT	\N	PRESENT	0
222065	220241	19467C	PARTICIPANT	\N	PRESENT	0
222066	220241	19515S	PARTICIPANT	\N	PRESENT	0
222067	220241	19565D	PARTICIPANT	\N	PRESENT	0
222068	220241	14187A	PARTICIPANT	\N	PRESENT	0
222069	220241	14081Q	PARTICIPANT	\N	PRESENT	0
222070	220241	08062Y	PARTICIPANT	\N	PRESENT	0
222071	220241	19301E	PARTICIPANT	\N	PRESENT	0
222072	220241	11090Q	PRESIDENT	0	PRESENT	0
222073	220241	14033T	PARTICIPANT	\N	PRESENT	0
222074	220241	04086Q	PARTICIPANT	\N	PRESENT	0
222075	220241	04088S	PARTICIPANT	\N	PRESENT	0
222076	220241	08068F	PARTICIPANT	\N	PRESENT	0
222077	220241	14115H	PARTICIPANT	\N	PRESENT	0
222078	220241	19705W	PARTICIPANT	\N	PRESENT	0
222079	220241	08015R	PARTICIPANT	\N	PRESENT	0
222080	220241	19511N	PARTICIPANT	\N	PRESENT	0
222081	220241	08028W	PARTICIPANT	\N	PRESENT	0
222082	220241	19591F	PARTICIPANT	\N	PRESENT	0
222223	219921	14121F	PARTICIPANT	\N	PRESENT	0
222224	219921	99004R	PARTICIPANT	\N	PRESENT	0
222225	219921	14253S	PARTICIPANT	\N	PRESENT	0
222226	219921	04061F	PARTICIPANT	\N	PRESENT	0
222227	219921	01057W	PARTICIPANT	\N	PRESENT	0
222228	219921	89017R	PARTICIPANT	\N	PRESENT	0
222229	219921	11070L	PARTICIPANT	\N	PRESENT	0
222230	219921	08010L	PARTICIPANT	\N	PRESENT	0
222231	219921	11048N	PARTICIPANT	\N	PRESENT	0
222232	219921	19479G	PARTICIPANT	\N	PRESENT	0
222233	219921	19531S	PARTICIPANT	\N	PRESENT	0
222234	219921	19689Q	PARTICIPANT	\N	PRESENT	0
222235	219921	14159V	PARTICIPANT	\N	PRESENT	0
222242	219921	19671E	PARTICIPANT	\N	PRESENT	0
222243	219921	08034U	PARTICIPANT	\N	PRESENT	0
222278	218280	14225N	PARTICIPANT	\N	PRESENT	0
222279	218280	14121F	PARTICIPANT	\N	PRESENT	0
222280	218280	08016S	PARTICIPANT	\N	PRESENT	0
222281	218280	19697Q	PARTICIPANT	\N	PRESENT	0
222282	218280	14081Q	PARTICIPANT	\N	PRESENT	0
222283	218280	14021P	PARTICIPANT	\N	PRESENT	0
222284	218280	14159V	PARTICIPANT	\N	PRESENT	0
222285	218280	19651A	PARTICIPANT	\N	PRESENT	0
222286	218280	19349W	PARTICIPANT	\N	PRESENT	0
222287	218280	19637C	PARTICIPANT	\N	PRESENT	0
222288	218280	19545Y	PARTICIPANT	\N	PRESENT	0
222289	218280	08017T	PARTICIPANT	\N	PRESENT	0
222290	218280	19689Q	PARTICIPANT	\N	PRESENT	0
222291	218280	14085U	PARTICIPANT	\N	PRESENT	0
222292	218280	14235Q	PARTICIPANT	\N	PRESENT	0
222293	218280	11040E	PARTICIPANT	\N	PRESENT	0
222294	218280	19531S	PARTICIPANT	\N	PRESENT	0
222295	218280	19647E	PARTICIPANT	\N	PRESENT	0
222296	218280	08055A	PARTICIPANT	\N	PRESENT	0
222297	218280	19553Y	PARTICIPANT	\N	PRESENT	0
222298	218280	08061X	PARTICIPANT	\N	PRESENT	0
222299	218280	88008L	PARTICIPANT	\N	PRESENT	0
222300	218280	14083S	PARTICIPANT	\N	PRESENT	0
222301	218280	14219Q	PARTICIPANT	\N	PRESENT	0
222302	218280	19735D	PARTICIPANT	\N	PRESENT	0
222303	218280	14267Y	PARTICIPANT	\N	PRESENT	0
222304	218280	19611R	PARTICIPANT	\N	PRESENT	0
222276	218280	11072N	PARTICIPANT	\N	PRESENT	0
222277	218280	11074Q	PARTICIPANT	\N	PRESENT	0
222305	218280	19441R	PARTICIPANT	\N	PRESENT	0
222306	218280	14327T	PARTICIPANT	\N	PRESENT	0
222307	218280	11070L	PARTICIPANT	\N	PRESENT	0
222308	218280	07004J	PARTICIPANT	\N	PRESENT	0
222309	218280	19737F	PARTICIPANT	\N	PRESENT	0
222310	218280	14195A	PARTICIPANT	\N	PRESENT	0
222311	218280	19387D	PARTICIPANT	\N	PRESENT	0
222312	218280	04085P	PARTICIPANT	\N	PRESENT	0
222313	218280	89017R	PARTICIPANT	\N	PRESENT	0
222314	218280	19671E	PARTICIPANT	\N	PRESENT	0
222315	218280	19421M	PARTICIPANT	\N	PRESENT	0
222316	218280	95041E	PARTICIPANT	\N	PRESENT	0
222317	218280	19413M	PARTICIPANT	\N	PRESENT	0
222318	218280	19731Y	PARTICIPANT	\N	PRESENT	0
222319	218280	19383Y	PARTICIPANT	\N	PRESENT	0
222320	218280	14061L	PARTICIPANT	\N	PRESENT	0
222321	218280	08015R	PARTICIPANT	\N	PRESENT	0
222322	218280	07029T	PARTICIPANT	\N	PRESENT	0
222323	218280	14029X	PARTICIPANT	\N	PRESENT	0
222324	218280	97011G	PARTICIPANT	\N	PRESENT	0
222325	218280	04033B	PARTICIPANT	\N	PRESENT	0
222326	218280	04086Q	PARTICIPANT	\N	PRESENT	0
222327	218280	08034U	PARTICIPANT	\N	PRESENT	0
222328	218280	99004R	PARTICIPANT	\N	PRESENT	0
222329	218280	95030B	PARTICIPANT	\N	PRESENT	0
222330	218280	08028W	PARTICIPANT	\N	PRESENT	0
222331	218280	14223L	PARTICIPANT	\N	PRESENT	0
222332	218280	11048N	PARTICIPANT	\N	PRESENT	0
222333	218280	14265W	PARTICIPANT	\N	PRESENT	0
222334	218280	19693L	PARTICIPANT	\N	PRESENT	0
222335	218280	19733B	PARTICIPANT	\N	PRESENT	0
222336	218280	14115H	PARTICIPANT	\N	PRESENT	0
222337	218280	19575F	PARTICIPANT	\N	PRESENT	0
222338	218280	87003B	PARTICIPANT	\N	PRESENT	0
222339	218280	14041T	PARTICIPANT	\N	PRESENT	0
222340	218280	14119M	PARTICIPANT	\N	PRESENT	0
222341	218280	19667J	PARTICIPANT	\N	PRESENT	0
222342	218280	01057W	PARTICIPANT	\N	PRESENT	0
222343	218280	04071H	PARTICIPANT	\N	PRESENT	0
222344	218280	01048V	PARTICIPANT	\N	PRESENT	0
222345	218280	19683J	PARTICIPANT	\N	PRESENT	0
222346	218280	14281W	PARTICIPANT	\N	PRESENT	0
222347	218280	19591F	PARTICIPANT	\N	PRESENT	0
222349	218280	14109K	PARTICIPANT	\N	PRESENT	0
222350	218280	14257W	PARTICIPANT	\N	PRESENT	0
222351	218280	08068F	PARTICIPANT	\N	PRESENT	0
222352	218280	04057K	PARTICIPANT	\N	PRESENT	0
222353	218280	14251Q	PARTICIPANT	\N	PRESENT	0
222354	218280	19583F	PARTICIPANT	\N	PRESENT	0
222355	218280	19479G	PARTICIPANT	\N	PRESENT	0
222356	218280	19713W	PARTICIPANT	\N	PRESENT	0
222357	218280	19369B	PARTICIPANT	\N	PRESENT	0
222358	218280	14030Q	PARTICIPANT	\N	PRESENT	0
222359	218280	19685L	PARTICIPANT	\N	PRESENT	0
222360	218280	14079W	PARTICIPANT	\N	PRESENT	0
222361	218280	14055N	PARTICIPANT	\N	PRESENT	0
222362	218280	14187A	PARTICIPANT	\N	PRESENT	0
222364	218280	14123H	PARTICIPANT	\N	PRESENT	0
222367	218280	19643A	PARTICIPANT	\N	PRESENT	0
222368	218280	14191V	PARTICIPANT	\N	PRESENT	0
222370	218280	19515S	PARTICIPANT	\N	PRESENT	0
222371	218280	19443T	PARTICIPANT	\N	PRESENT	0
222372	218280	19447X	PARTICIPANT	\N	PRESENT	0
222373	218280	19467C	PARTICIPANT	\N	PRESENT	0
222374	218280	04088S	PARTICIPANT	\N	PRESENT	0
222375	218280	08018U	PARTICIPANT	\N	PRESENT	0
222376	218280	14105F	PARTICIPANT	\N	PRESENT	0
222377	218280	19729F	PARTICIPANT	\N	PRESENT	0
222378	218280	07033P	PARTICIPANT	\N	PRESENT	0
222379	218280	17583W	PARTICIPANT	\N	PRESENT	0
222381	218280	19695N	PARTICIPANT	\N	PRESENT	0
222382	218280	19687N	PARTICIPANT	\N	PRESENT	0
222383	218280	19621T	PARTICIPANT	\N	PRESENT	0
222385	218280	11066Q	PARTICIPANT	\N	PRESENT	0
222387	218280	14133K	PARTICIPANT	\N	PRESENT	0
222388	218280	14169X	PARTICIPANT	\N	PRESENT	0
222389	218280	98022P	PARTICIPANT	\N	PRESENT	0
222390	218280	11097X	PARTICIPANT	\N	PRESENT	0
222396	218280	08062Y	PARTICIPANT	\N	PRESENT	0
222400	218280	19725B	PARTICIPANT	\N	PRESENT	0
222402	218280	14111D	PARTICIPANT	\N	PRESENT	0
222403	218280	19585H	PARTICIPANT	\N	PRESENT	0
222427	218280	19483C	PARTICIPANT	\N	PRESENT	0
222428	218280	11103C	PARTICIPANT	\N	PRESENT	0
222429	218280	08044W	PARTICIPANT	\N	PRESENT	0
222430	218280	11081P	PARTICIPANT	\N	PRESENT	0
222436	218280	11031D	PARTICIPANT	\N	PRESENT	0
222437	218280	98018T	PARTICIPANT	\N	PRESENT	0
222438	218280	04092N	PARTICIPANT	\N	PRESENT	0
222443	218280	86034E	PARTICIPANT	\N	PRESENT	0
222448	218280	14103D	PARTICIPANT	\N	PRESENT	0
222457	218280	19253P	PARTICIPANT	\N	PRESENT	0
222458	218280	08010L	PARTICIPANT	\N	PRESENT	0
222459	218280	19569H	PARTICIPANT	\N	PRESENT	0
222460	218280	19503N	PARTICIPANT	\N	PRESENT	0
222461	218280	12016W	PARTICIPANT	\N	PRESENT	0
222462	218280	08073C	PARTICIPANT	\N	PRESENT	0
222476	218280	14031R	PARTICIPANT	\N	PRESENT	0
222480	218280	11012A	PARTICIPANT	\N	PRESENT	0
222481	218280	14213J	PARTICIPANT	\N	PRESENT	0
222482	218280	14034U	PARTICIPANT	\N	PRESENT	0
222483	218280	80027E	PARTICIPANT	\N	PRESENT	0
222484	218280	14065Q	PARTICIPANT	\N	PRESENT	0
222533	218283	11077T	PARTICIPANT	\N	PRESENT	0
222589	218283	04085P	PARTICIPANT	\N	PRESENT	0
222590	218283	11031D	PARTICIPANT	\N	PRESENT	0
222591	218283	04038G	PARTICIPANT	\N	PRESENT	0
222592	218283	12041X	PARTICIPANT	\N	PRESENT	0
222593	218283	11040E	PARTICIPANT	\N	PRESENT	0
222594	218283	19347U	PARTICIPANT	\N	PRESENT	0
222595	218283	14235Q	PARTICIPANT	\N	PRESENT	0
222596	218283	11101A	PARTICIPANT	\N	PRESENT	0
222597	218283	19593H	PARTICIPANT	\N	PRESENT	0
222598	218283	08039A	PARTICIPANT	\N	PRESENT	0
222599	218283	04097T	PARTICIPANT	\N	PRESENT	0
222600	218283	19695N	PARTICIPANT	\N	PRESENT	0
222601	218283	08010L	PARTICIPANT	\N	PRESENT	0
222602	218283	11063M	PARTICIPANT	\N	PRESENT	0
222603	218283	08020N	PARTICIPANT	\N	PRESENT	0
222604	218283	14239U	PARTICIPANT	\N	PRESENT	0
222605	218283	19651A	PARTICIPANT	\N	PRESENT	0
222606	218283	19643A	PARTICIPANT	\N	PRESENT	0
222607	218283	98029W	PARTICIPANT	\N	PRESENT	0
222608	218283	95015C	PARTICIPANT	\N	PRESENT	0
217121	217120	98018T	PARTICIPANT	\N	PRESENT	0
217122	217120	11041F	PARTICIPANT	\N	PRESENT	0
217128	217126	14133K	PARTICIPANT	\N	PRESENT	0
217129	217126	08058D	PARTICIPANT	\N	PRESENT	0
217145	217143	14133K	PARTICIPANT	\N	PRESENT	0
217146	217143	08058D	PARTICIPANT	\N	PRESENT	0
227294	227291	07004J	PARTICIPANT	\N	PRESENT	0
227303	227302	14065Q	PARTICIPANT	\N	PRESENT	0
227321	227311	14021P	PARTICIPANT	\N	PRESENT	0
227373	227372	89017R	PARTICIPANT	\N	PRESENT	0
227413	227412	11074Q	PARTICIPANT	\N	PRESENT	0
227417	227416	01048V	PARTICIPANT	\N	PRESENT	0
227489	218445	19295A	PARTICIPANT	\N	PRESENT	0
227490	218445	19687N	PARTICIPANT	\N	PRESENT	0
227491	218445	08068F	PARTICIPANT	\N	PRESENT	0
227492	218445	14119M	PARTICIPANT	\N	PRESENT	0
227493	218445	08056B	PARTICIPANT	\N	PRESENT	0
227494	218445	04089T	PARTICIPANT	\N	PRESENT	0
227495	218445	14083S	PARTICIPANT	\N	PRESENT	0
227496	218445	14267Y	PARTICIPANT	\N	PRESENT	0
227498	218445	19581D	PARTICIPANT	\N	PRESENT	0
227499	218445	19739H	PARTICIPANT	\N	PRESENT	0
227500	218445	19367Y	PARTICIPANT	\N	PRESENT	0
227501	218445	19253P	PARTICIPANT	\N	PRESENT	0
227502	218445	14261S	PARTICIPANT	\N	PRESENT	0
227503	218445	11012A	PARTICIPANT	\N	PRESENT	0
227504	218445	19735D	PARTICIPANT	\N	PRESENT	0
227505	218445	19569H	PARTICIPANT	\N	PRESENT	0
227506	218445	08009T	PARTICIPANT	\N	PRESENT	0
227507	218445	01043Q	PARTICIPANT	\N	PRESENT	0
227508	218445	97011G	PARTICIPANT	\N	PRESENT	0
227509	218445	19711U	PARTICIPANT	\N	PRESENT	0
227510	218445	18083K	PARTICIPANT	\N	PRESENT	0
227511	218445	14029X	PARTICIPANT	\N	PRESENT	0
227512	218445	14157T	PARTICIPANT	\N	PRESENT	0
227513	218445	11101A	PARTICIPANT	\N	PRESENT	0
227514	218445	19575F	PARTICIPANT	\N	PRESENT	0
227515	218445	14033T	PARTICIPANT	\N	PRESENT	0
227516	218445	04088S	PARTICIPANT	\N	PRESENT	0
227517	218445	19657G	PARTICIPANT	\N	PRESENT	0
227518	218445	19577H	PARTICIPANT	\N	PRESENT	0
227519	218445	14237S	PARTICIPANT	\N	PRESENT	0
227520	218445	11063M	PARTICIPANT	\N	PRESENT	0
227521	218445	11054L	PARTICIPANT	\N	PRESENT	0
227522	218445	04008A	PARTICIPANT	\N	PRESENT	0
227523	227031	19593H	PARTICIPANT	\N	PRESENT	0
227524	227031	04070G	PRESIDENT	0	PRESENT	0
227525	227031	14059S	PARTICIPANT	\N	PRESENT	0
227526	227031	14061L	PARTICIPANT	\N	PRESENT	0
227527	227031	14355X	PARTICIPANT	\N	PRESENT	0
227528	227031	19611R	PARTICIPANT	\N	PRESENT	0
227529	227031	08043V	PARTICIPANT	\N	PRESENT	0
227530	227031	87003B	PARTICIPANT	\N	PRESENT	0
227531	227031	14229S	PARTICIPANT	\N	PRESENT	0
227532	227031	19731Y	PARTICIPANT	\N	PRESENT	0
227533	227031	19573D	PARTICIPANT	\N	PRESENT	0
227534	227031	14107H	PARTICIPANT	\N	PRESENT	0
227535	227031	14109K	PARTICIPANT	\N	PRESENT	0
227536	227031	14123H	PARTICIPANT	\N	PRESENT	0
227537	227031	11104D	PARTICIPANT	\N	PRESENT	0
227538	227031	95015C	PARTICIPANT	\N	EXCUSE	0
227539	227031	08016S	PARTICIPANT	\N	EXCUSE	0
227540	227031	04018C	PARTICIPANT	\N	EXCUSE	0
227541	227031	14201E	PARTICIPANT	\N	EXCUSE	0
227542	218445	11074Q	PARTICIPANT	\N	PRESENT	0
227543	218445	11077T	PARTICIPANT	\N	PRESENT	0
227544	218445	95030B	PARTICIPANT	\N	PRESENT	0
227545	218445	19479G	PARTICIPANT	\N	PRESENT	0
227546	218445	17779H	PARTICIPANT	\N	PRESENT	0
227547	218445	19689Q	PARTICIPANT	\N	PRESENT	0
227548	218445	19369B	PARTICIPANT	\N	PRESENT	0
227549	218445	04033B	PARTICIPANT	\N	PRESENT	0
227550	218445	14249W	PARTICIPANT	\N	PRESENT	0
227551	218445	14227Q	PARTICIPANT	\N	PRESENT	0
227552	218445	08020N	PARTICIPANT	\N	PRESENT	0
227553	218445	14135M	PARTICIPANT	\N	PRESENT	0
227554	218445	08034U	PARTICIPANT	\N	PRESENT	0
227555	218445	08062Y	PARTICIPANT	\N	PRESENT	0
227556	218445	19549D	PARTICIPANT	\N	PRESENT	0
227557	218445	14215L	PARTICIPANT	\N	PRESENT	0
227558	218445	19545Y	PARTICIPANT	\N	PRESENT	0
227559	218445	19737F	PARTICIPANT	\N	PRESENT	0
227560	218445	19515S	PARTICIPANT	\N	PRESENT	0
227561	218445	08014Q	PARTICIPANT	\N	PRESENT	0
227562	218445	14235Q	PARTICIPANT	\N	PRESENT	0
227563	218445	19347U	PARTICIPANT	\N	PRESENT	0
227564	218445	08015R	PARTICIPANT	\N	PRESENT	0
227565	218445	19713W	PARTICIPANT	\N	PRESENT	0
227566	218445	14231L	PARTICIPANT	\N	PRESENT	0
227567	218445	14103D	PARTICIPANT	\N	PRESENT	0
227568	218445	19649G	PARTICIPANT	\N	PRESENT	0
227569	218445	01024M	PARTICIPANT	\N	PRESENT	0
227570	218445	19531S	PARTICIPANT	\N	PRESENT	0
227571	218445	19719D	PARTICIPANT	\N	PRESENT	0
227572	218445	98023Q	PARTICIPANT	\N	PRESENT	0
227573	218445	19387D	PARTICIPANT	\N	PRESENT	0
227574	218445	19563B	PARTICIPANT	\N	PRESENT	0
227575	218445	14207L	PARTICIPANT	\N	PRESENT	0
227576	218445	14121F	PARTICIPANT	\N	PRESENT	0
227577	218445	14257W	PARTICIPANT	\N	PRESENT	0
227578	218445	14281W	PARTICIPANT	\N	PRESENT	0
227579	218445	14259Y	PARTICIPANT	\N	PRESENT	0
227580	218445	19701S	PARTICIPANT	\N	PRESENT	0
227581	218445	14241N	PARTICIPANT	\N	PRESENT	0
227582	218445	95037J	PARTICIPANT	\N	PRESENT	0
227583	218445	19647E	PARTICIPANT	\N	PRESENT	0
227584	218445	14107H	PARTICIPANT	\N	PRESENT	0
227585	218445	14038Y	PARTICIPANT	\N	PRESENT	0
227587	218445	19679N	PARTICIPANT	\N	PRESENT	0
227588	218445	95062K	PARTICIPANT	\N	PRESENT	0
227589	218445	11049P	PARTICIPANT	\N	PRESENT	0
227590	218445	98050T	PARTICIPANT	\N	PRESENT	0
227591	218445	14173T	PARTICIPANT	\N	PRESENT	0
227592	218445	08039A	PARTICIPANT	\N	PRESENT	0
227593	218445	14253S	PARTICIPANT	\N	PRESENT	0
227594	218445	19691J	PARTICIPANT	\N	PRESENT	0
227595	218445	11067R	PARTICIPANT	\N	PRESENT	0
227596	218445	14021P	PARTICIPANT	\N	PRESENT	0
227597	218445	14213J	PARTICIPANT	\N	PRESENT	0
227598	218445	17637T	PARTICIPANT	\N	PRESENT	0
227599	218445	11031D	PARTICIPANT	\N	PRESENT	0
227600	218445	11104D	PARTICIPANT	\N	PRESENT	0
227601	218445	19729F	PARTICIPANT	\N	PRESENT	0
227602	218445	14219Q	PARTICIPANT	\N	PRESENT	0
227603	218445	19723Y	PARTICIPANT	\N	PRESENT	0
227604	218445	14073Q	PARTICIPANT	\N	PRESENT	0
227605	218445	14197C	PARTICIPANT	\N	PRESENT	0
227606	218445	14111D	PARTICIPANT	\N	PRESENT	0
227607	218445	14031R	PARTICIPANT	\N	PRESENT	0
227608	218445	11048N	PARTICIPANT	\N	PRESENT	0
227609	218445	14147R	PARTICIPANT	\N	PRESENT	0
227610	218445	14081Q	PARTICIPANT	\N	PRESENT	0
227611	218445	11097X	PARTICIPANT	\N	PRESENT	0
227614	218445	80013X	PARTICIPANT	\N	PRESENT	0
227615	218445	14225N	PARTICIPANT	\N	PRESENT	0
227616	218445	19551W	PARTICIPANT	\N	PRESENT	0
227622	218445	04085P	PARTICIPANT	\N	PRESENT	0
227618	218445	19611R	PARTICIPANT	\N	PRESENT	0
227619	218445	19731Y	PARTICIPANT	\N	PRESENT	0
227624	218445	08011M	PARTICIPANT	\N	PRESENT	0
227625	218445	11109J	PARTICIPANT	\N	PRESENT	0
227627	218445	19543W	PARTICIPANT	\N	PRESENT	0
227628	218445	14151M	PARTICIPANT	\N	PRESENT	0
227629	218445	07029T	PARTICIPANT	\N	PRESENT	0
227630	218445	19507S	PARTICIPANT	\N	PRESENT	0
227631	218445	89017R	PARTICIPANT	\N	PRESENT	0
227632	218445	19483C	PARTICIPANT	\N	PRESENT	0
227633	227031	04057K	PARTICIPANT	\N	PRESENT	0
227634	227031	08017T	PARTICIPANT	\N	PRESENT	0
227635	227031	11109J	PARTICIPANT	\N	PRESENT	0
227636	218445	19573D	PARTICIPANT	\N	PRESENT	0
227637	218445	14159V	PARTICIPANT	\N	PRESENT	0
227638	218445	04070G	PARTICIPANT	\N	PRESENT	0
227641	227640	14065Q	PARTICIPANT	\N	PRESENT	0
227642	227640	10015M	PARTICIPANT	\N	PRESENT	0
227644	227643	96004D	PARTICIPANT	\N	PRESENT	0
227645	227643	11083R	PARTICIPANT	\N	PRESENT	0
227646	227643	14221J	PARTICIPANT	\N	PRESENT	0
227647	227643	95030B	PARTICIPANT	\N	PRESENT	0
227648	218445	14179A	PARTICIPANT	\N	PRESENT	0
227649	218445	14042U	PARTICIPANT	\N	PRESENT	0
227650	218445	19441R	PARTICIPANT	\N	PRESENT	0
227664	218445	19301E	PARTICIPANT	\N	PRESENT	0
227665	218445	14265W	PARTICIPANT	\N	PRESENT	0
227666	218445	19447X	PARTICIPANT	\N	PRESENT	0
227667	218445	19703U	PARTICIPANT	\N	PRESENT	0
227668	218445	14191V	PARTICIPANT	\N	PRESENT	0
227669	218445	01058X	PARTICIPANT	\N	PRESENT	0
227670	218445	19553Y	PARTICIPANT	\N	PRESENT	0
226923	218442	11048N	PARTICIPANT	\N	PRESENT	0
226924	218442	04033B	PARTICIPANT	\N	PRESENT	0
226925	218442	14265W	PARTICIPANT	\N	PRESENT	0
226926	218442	07029T	PARTICIPANT	\N	PRESENT	0
226927	218442	14197C	PARTICIPANT	\N	PRESENT	0
226928	218442	19531S	PARTICIPANT	\N	PRESENT	0
226929	218442	14257W	PARTICIPANT	\N	PRESENT	0
226930	218442	19441R	PARTICIPANT	\N	PRESENT	0
226931	218442	14034U	PARTICIPANT	\N	PRESENT	0
226932	218442	05012A	PARTICIPANT	\N	PRESENT	0
226933	218442	14087W	PARTICIPANT	\N	PRESENT	0
227385	225844	19585H	PARTICIPANT	\N	PRESENT	0
227324	225844	19741B	PARTICIPANT	\N	PRESENT	0
227325	225844	08055A	PARTICIPANT	\N	EXCUSE	0
227326	225844	14093U	PARTICIPANT	\N	PRESENT	0
226921	218442	11097X	PARTICIPANT	\N	PRESENT	0
226922	218442	19621T	PARTICIPANT	\N	PRESENT	0
227327	225844	19549D	PARTICIPANT	\N	PRESENT	0
227387	225844	14331P	PARTICIPANT	\N	PRESENT	0
227329	225844	08060W	PARTICIPANT	\N	PRESENT	0
227330	225844	19733B	PARTICIPANT	\N	PRESENT	0
227388	225844	01043Q	PARTICIPANT	\N	PRESENT	0
227389	225844	19581D	PARTICIPANT	\N	PRESENT	0
227333	225844	14038Y	PARTICIPANT	\N	PRESENT	0
227334	225844	18083K	PARTICIPANT	\N	PRESENT	0
227335	225844	19701S	PARTICIPANT	\N	PRESENT	0
227336	225844	19681G	PARTICIPANT	\N	PRESENT	0
227337	225844	98023Q	PARTICIPANT	\N	PRESENT	0
227338	225844	19525U	PARTICIPANT	\N	PRESENT	0
227391	225844	08010L	PARTICIPANT	\N	PRESENT	0
227340	225844	19659J	PARTICIPANT	\N	PRESENT	0
227341	225844	19599P	PARTICIPANT	\N	PRESENT	0
227392	225844	11045K	PARTICIPANT	\N	PRESENT	0
227393	225844	14063N	PARTICIPANT	\N	PRESENT	0
227344	225844	19387D	PARTICIPANT	\N	PRESENT	0
227345	225844	19347U	PARTICIPANT	\N	PRESENT	0
227394	225844	04089T	PARTICIPANT	\N	PRESENT	0
227347	225844	19333N	PARTICIPANT	\N	PRESENT	0
227348	225844	04097T	PARTICIPANT	\N	EXCUSE	0
227349	225844	19551W	PARTICIPANT	\N	PRESENT	0
227395	225844	14021P	PARTICIPANT	\N	PRESENT	0
227396	225844	14061L	PARTICIPANT	\N	PRESENT	0
227352	225844	14219Q	PARTICIPANT	\N	PRESENT	0
227353	225844	14103D	PARTICIPANT	\N	PRESENT	0
227400	225844	19527W	PARTICIPANT	\N	PRESENT	0
227355	225844	14031R	PARTICIPANT	\N	PRESENT	0
227356	225844	19637C	PARTICIPANT	\N	PRESENT	0
227357	225844	08009T	PRESIDENT	0	PRESENT	0
227358	225844	14221J	PARTICIPANT	\N	PRESENT	0
227639	221543	14277B	PARTICIPANT	\N	EXCUSE	0
227796	226155	14327T	PARTICIPANT	\N	PRESENT	0
227361	225844	14237S	PARTICIPANT	\N	PRESENT	0
227797	226155	14331P	PARTICIPANT	\N	PRESENT	0
227363	225844	05012A	PARTICIPANT	\N	PRESENT	0
227364	225844	19503N	PARTICIPANT	\N	PRESENT	0
227365	225844	19739H	PARTICIPANT	\N	PRESENT	0
227366	225844	17583W	PARTICIPANT	\N	PRESENT	0
227367	225844	95062K	PARTICIPANT	\N	PRESENT	0
227368	225844	19713W	PARTICIPANT	\N	PRESENT	0
227369	225844	14051J	PARTICIPANT	\N	PRESENT	0
227370	225844	14157T	PARTICIPANT	\N	PRESENT	0
227371	225844	19737F	PARTICIPANT	\N	EXCUSE	0
227798	226155	04071H	PARTICIPANT	\N	PRESENT	0
227799	226155	19479G	PARTICIPANT	\N	PRESENT	0
227800	226155	19711U	PARTICIPANT	\N	PRESENT	0
227801	226155	19531S	PARTICIPANT	\N	PRESENT	0
227802	226155	08069G	PARTICIPANT	\N	PRESENT	0
227803	226155	19689Q	PARTICIPANT	\N	PRESENT	0
227804	226155	11074Q	PRESIDENT	0	PRESENT	0
227805	226155	89017R	PARTICIPANT	\N	PRESENT	0
227806	226155	08011M	PARTICIPANT	\N	PRESENT	0
227807	226155	08014Q	PARTICIPANT	\N	PRESENT	0
227808	226155	19671E	PARTICIPANT	\N	PRESENT	0
227809	226155	11110B	PARTICIPANT	\N	PRESENT	0
227810	226155	07029T	PARTICIPANT	\N	PRESENT	0
227811	226155	14083S	PARTICIPANT	\N	PRESENT	0
227812	226155	08073C	PARTICIPANT	\N	PRESENT	0
227813	226155	14085U	PARTICIPANT	\N	PRESENT	0
227814	226155	07004J	PARTICIPANT	\N	PRESENT	0
227815	226155	14121F	PARTICIPANT	\N	PRESENT	0
227816	226155	08010L	PARTICIPANT	\N	PRESENT	0
227817	226155	19667J	PARTICIPANT	\N	EXCUSE	0
227826	218448	04086Q	PARTICIPANT	\N	PRESENT	0
227829	218448	11074Q	PARTICIPANT	\N	PRESENT	0
227830	218448	08069G	PARTICIPANT	\N	PRESENT	0
227831	218448	08014Q	PARTICIPANT	\N	PRESENT	0
227832	218448	11056N	PARTICIPANT	\N	PRESENT	0
227833	218448	19531S	PARTICIPANT	\N	PRESENT	0
227834	218448	19503N	PARTICIPANT	\N	PRESENT	0
227835	218448	19413M	PARTICIPANT	\N	PRESENT	0
227836	218448	19333N	PARTICIPANT	\N	PRESENT	0
227837	218448	08061X	PARTICIPANT	\N	PRESENT	0
227838	218448	19349W	PARTICIPANT	\N	PRESENT	0
227839	218448	14207L	PARTICIPANT	\N	PRESENT	0
227840	218448	14225N	PARTICIPANT	\N	PRESENT	0
227841	218448	14197C	PARTICIPANT	\N	PRESENT	0
227842	218448	19713W	PARTICIPANT	\N	PRESENT	0
227843	218448	14219Q	PARTICIPANT	\N	PRESENT	0
227844	218448	17589D	PARTICIPANT	\N	PRESENT	0
227845	218448	19441R	PARTICIPANT	\N	PRESENT	0
227846	218448	19737F	PARTICIPANT	\N	PRESENT	0
227847	218448	14327T	PARTICIPANT	\N	PRESENT	0
227848	218448	14205J	PARTICIPANT	\N	PRESENT	0
227849	218448	04088S	PARTICIPANT	\N	PRESENT	0
227850	218448	14191V	PARTICIPANT	\N	PRESENT	0
227851	218448	01025N	PARTICIPANT	\N	PRESENT	0
227852	218448	14033T	PARTICIPANT	\N	PRESENT	0
227853	218448	07029T	PARTICIPANT	\N	PRESENT	0
227854	218448	14257W	PARTICIPANT	\N	PRESENT	0
227855	218448	19507S	PARTICIPANT	\N	PRESENT	0
227856	218448	19479G	PARTICIPANT	\N	PRESENT	0
227857	218448	14265W	PARTICIPANT	\N	PRESENT	0
227858	218448	19619A	PARTICIPANT	\N	PRESENT	0
227859	218448	14115H	PARTICIPANT	\N	PRESENT	0
227860	218448	19511N	PARTICIPANT	\N	PRESENT	0
227861	218448	08010L	PARTICIPANT	\N	PRESENT	0
227862	218448	14107H	PARTICIPANT	\N	PRESENT	0
227863	218448	19711U	PARTICIPANT	\N	PRESENT	0
227864	218448	19347U	PARTICIPANT	\N	PRESENT	0
227865	218448	95030B	PARTICIPANT	\N	PRESENT	0
227866	218448	19689Q	PARTICIPANT	\N	PRESENT	0
227867	218448	97011G	PARTICIPANT	\N	PRESENT	0
227868	218448	19563B	PARTICIPANT	\N	PRESENT	0
227869	218448	14357A	PARTICIPANT	\N	PRESENT	0
227870	218448	19383Y	PARTICIPANT	\N	PRESENT	0
227871	218448	04049K	PARTICIPANT	\N	PRESENT	0
227872	218448	19671E	PARTICIPANT	\N	PRESENT	0
227873	218448	14085U	PARTICIPANT	\N	PRESENT	0
227874	218448	11067R	PARTICIPANT	\N	PRESENT	0
227875	218448	11090Q	PARTICIPANT	\N	PRESENT	0
227876	218448	07004J	PARTICIPANT	\N	PRESENT	0
227877	218448	19575F	PARTICIPANT	\N	PRESENT	0
227878	218448	14083S	PARTICIPANT	\N	PRESENT	0
227879	218448	14119M	PARTICIPANT	\N	PRESENT	0
227880	218448	11097X	PARTICIPANT	\N	PRESENT	0
227881	218448	19387D	PARTICIPANT	\N	PRESENT	0
227882	218448	19369B	PARTICIPANT	\N	PRESENT	0
227883	218448	19483C	PARTICIPANT	\N	PRESENT	0
227884	218448	11066Q	PARTICIPANT	\N	PRESENT	0
227885	218448	08068F	PARTICIPANT	\N	PRESENT	0
227887	218448	14069U	PARTICIPANT	\N	PRESENT	0
227888	218448	11048N	PARTICIPANT	\N	PRESENT	0
227889	218448	14331P	PARTICIPANT	\N	PRESENT	0
227890	218448	05008E	PARTICIPANT	\N	PRESENT	0
227891	218448	19447X	PARTICIPANT	\N	PRESENT	0
227893	218448	19611R	PARTICIPANT	\N	PRESENT	0
227894	218448	11099A	PARTICIPANT	\N	PRESENT	0
227895	218448	19725B	PARTICIPANT	\N	PRESENT	0
227896	218448	80013X	PARTICIPANT	\N	PRESENT	0
227897	218448	14063N	PARTICIPANT	\N	PRESENT	0
227898	218448	19629C	PARTICIPANT	\N	PRESENT	0
227899	218448	19701S	PARTICIPANT	\N	PRESENT	0
227906	218448	19515S	PARTICIPANT	\N	PRESENT	0
227907	218448	08020N	PARTICIPANT	\N	PRESENT	0
227908	218448	14187A	PARTICIPANT	\N	PRESENT	0
227909	218448	14103D	PARTICIPANT	\N	PRESENT	0
227911	218448	14195A	PARTICIPANT	\N	PRESENT	0
227923	218448	10015M	PARTICIPANT	\N	PRESENT	0
227924	218448	14042U	PARTICIPANT	\N	PRESENT	0
227925	218448	19367Y	PARTICIPANT	\N	PRESENT	0
227926	218448	19269X	PARTICIPANT	\N	PRESENT	0
227927	218448	19631V	PARTICIPANT	\N	PRESENT	0
227928	218448	14217N	PARTICIPANT	\N	PRESENT	0
227929	218448	14215L	PARTICIPANT	\N	PRESENT	0
227930	218448	14030Q	PARTICIPANT	\N	PRESENT	0
227931	218448	14039A	PARTICIPANT	\N	PRESENT	0
227932	218448	14179A	PARTICIPANT	\N	PRESENT	0
227933	218448	19573D	PARTICIPANT	\N	PRESENT	0
227934	218448	14169X	PARTICIPANT	\N	PRESENT	0
215806	205652	14257W	PARTICIPANT	\N	PRESENT	0
220496	219909	14034U	PARTICIPANT	\N	EXCUSE	0
222083	220241	01043Q	PARTICIPANT	\N	PRESENT	0
222084	220241	19441R	PARTICIPANT	\N	PRESENT	0
222085	220241	19413M	PARTICIPANT	\N	PRESENT	0
222086	221368	14063N	PARTICIPANT	\N	EXCUSE	0
222087	218277	18083K	PARTICIPANT	\N	PRESENT	0
222088	218277	11048N	PARTICIPANT	\N	PRESENT	0
222089	218277	08020N	PARTICIPANT	\N	PRESENT	0
222090	218277	89017R	PARTICIPANT	\N	PRESENT	0
222091	218277	14061L	PARTICIPANT	\N	PRESENT	0
222092	218277	14281W	PARTICIPANT	\N	PRESENT	0
222093	218277	08060W	PARTICIPANT	\N	PRESENT	0
222094	218277	19583F	PARTICIPANT	\N	PRESENT	0
222095	218277	11064N	PARTICIPANT	\N	PRESENT	0
222096	218278	04059M	PARTICIPANT	\N	PRESENT	0
222100	218278	19565D	PARTICIPANT	\N	PRESENT	0
222098	218278	19489J	PARTICIPANT	\N	PRESENT	0
222099	218278	19687N	PARTICIPANT	\N	PRESENT	0
222101	218278	19333N	PARTICIPANT	\N	PRESENT	0
222102	218278	14257W	PARTICIPANT	\N	PRESENT	0
222103	218278	14281W	PARTICIPANT	\N	PRESENT	0
222104	218278	08060W	PARTICIPANT	\N	PRESENT	0
222105	218278	19349W	PARTICIPANT	\N	PRESENT	0
222106	218278	14159V	PARTICIPANT	\N	PRESENT	0
222107	218278	11064N	PARTICIPANT	\N	PRESENT	0
222108	218278	19583F	PARTICIPANT	\N	PRESENT	0
222109	218278	08034U	PARTICIPANT	\N	PRESENT	0
222110	218278	14133K	PARTICIPANT	\N	PRESENT	0
222111	218278	14173T	PARTICIPANT	\N	PRESENT	0
222112	218278	14069U	PARTICIPANT	\N	PRESENT	0
222113	218278	11099A	PARTICIPANT	\N	PRESENT	0
222114	218278	88008L	PARTICIPANT	\N	PRESENT	0
222115	218278	08049C	PARTICIPANT	\N	PRESENT	0
222116	218278	04040A	PARTICIPANT	\N	PRESENT	0
222117	218278	19421M	PARTICIPANT	\N	PRESENT	0
222118	218278	19387D	PARTICIPANT	\N	PRESENT	0
222119	218278	14065Q	PARTICIPANT	\N	PRESENT	0
222120	218278	14030Q	PARTICIPANT	\N	PRESENT	0
222121	218278	14229S	PARTICIPANT	\N	PRESENT	0
222122	218278	14267Y	PARTICIPANT	\N	PRESENT	0
222123	218278	14241N	PARTICIPANT	\N	PRESENT	0
222124	218278	08014Q	PARTICIPANT	\N	PRESENT	0
222125	218278	08052W	PARTICIPANT	\N	PRESENT	0
222126	218278	97011G	PARTICIPANT	\N	PRESENT	0
222127	218278	08020N	PARTICIPANT	\N	PRESENT	0
222128	218278	08031R	PARTICIPANT	\N	PRESENT	0
222129	218278	19543W	PARTICIPANT	\N	PRESENT	0
222130	218278	80027E	PARTICIPANT	\N	PRESENT	0
222131	218278	14063N	PARTICIPANT	\N	PRESENT	0
222132	218278	14207L	PARTICIPANT	\N	PRESENT	0
222133	218278	19383Y	PARTICIPANT	\N	PRESENT	0
222134	218278	19573D	PARTICIPANT	\N	PRESENT	0
222135	218278	14275Y	PARTICIPANT	\N	PRESENT	0
222136	218278	05012A	PARTICIPANT	\N	PRESENT	0
222137	218278	98022P	PARTICIPANT	\N	PRESENT	0
222138	218278	19631V	PARTICIPANT	\N	PRESENT	0
222139	218278	14225N	PARTICIPANT	\N	PRESENT	0
222140	218278	17637T	PARTICIPANT	\N	PRESENT	0
222141	218278	14157T	PARTICIPANT	\N	PRESENT	0
222142	218278	08038Y	PARTICIPANT	\N	PRESENT	0
222143	218278	14103D	PARTICIPANT	\N	PRESENT	0
222144	218278	80013X	PARTICIPANT	\N	PRESENT	0
222145	218278	14187A	PARTICIPANT	\N	PRESENT	0
222146	218278	19713W	PARTICIPANT	\N	PRESENT	0
222147	218278	08043V	PARTICIPANT	\N	PRESENT	0
223381	223380	98018T	PARTICIPANT	\N	PRESENT	0
223668	223667	14147R	PARTICIPANT	\N	PRESENT	0
223672	223667	19649G	PARTICIPANT	\N	PRESENT	0
223677	222532	04044E	PARTICIPANT	\N	EXCUSE	0
228593	228592	19545Y	PARTICIPANT	\N	PRESENT	0
228594	228592	04086Q	PARTICIPANT	\N	PRESENT	0
228595	228592	11070L	PARTICIPANT	\N	PRESENT	0
228596	228592	04071H	PARTICIPANT	\N	PRESENT	0
228597	228592	11074Q	PRESIDENT	0	PRESENT	0
228598	228592	07004J	PARTICIPANT	\N	PRESENT	0
228599	228592	08011M	PARTICIPANT	\N	PRESENT	0
228600	228592	08073C	PARTICIPANT	\N	PRESENT	0
228601	228592	19687N	PARTICIPANT	\N	PRESENT	0
228602	228592	19689Q	PARTICIPANT	\N	PRESENT	0
229178	227663	11103C	PRESIDENT	0	PRESENT	0
229188	227663	14239U	PARTICIPANT	\N	PRESENT	0
229189	227663	98024R	PARTICIPANT	\N	PRESENT	0
229190	227663	01034P	PARTICIPANT	\N	PRESENT	0
229316	227663	19415P	PARTICIPANT	\N	PRESENT	0
229317	227663	14195A	PARTICIPANT	\N	PRESENT	0
229318	227663	08052W	PARTICIPANT	\N	PRESENT	0
229319	227663	10006L	PARTICIPANT	\N	PRESENT	0
229320	227663	14042U	PARTICIPANT	\N	PRESENT	0
229321	227663	14281W	PARTICIPANT	\N	PRESENT	0
229322	227663	14026U	PARTICIPANT	\N	PRESENT	0
229323	227663	19553Y	PARTICIPANT	\N	PRESENT	0
229324	227663	11067R	PARTICIPANT	\N	PRESENT	0
229325	227663	04092N	PARTICIPANT	\N	EXCUSE	0
229326	227663	11097X	PARTICIPANT	\N	PRESENT	0
229327	227663	11063M	PARTICIPANT	\N	PRESENT	0
229328	227663	19727D	PARTICIPANT	\N	PRESENT	0
229329	227663	19715Y	PARTICIPANT	\N	PRESENT	0
229330	227663	14261S	PARTICIPANT	\N	PRESENT	0
229331	227663	14087W	PARTICIPANT	\N	PRESENT	0
229332	227663	14119M	PARTICIPANT	\N	PRESENT	0
229333	227663	19335Q	PARTICIPANT	\N	PRESENT	0
229334	227663	19703U	PARTICIPANT	\N	PRESENT	0
229335	227663	19575F	PARTICIPANT	\N	PRESENT	0
229483	229482	07004J	PARTICIPANT	\N	PRESENT	0
229484	229482	10015M	PARTICIPANT	\N	PRESENT	0
230128	230127	14030Q	PRESIDENT	0	PRESENT	0
230129	230127	19643A	PARTICIPANT	\N	PRESENT	0
230130	230127	08020N	PARTICIPANT	\N	PRESENT	0
230131	230127	08024S	PARTICIPANT	\N	PRESENT	0
230132	230127	18083K	PARTICIPANT	\N	PRESENT	0
230133	230127	80013X	PARTICIPANT	\N	PRESENT	0
230134	230127	14217N	PARTICIPANT	\N	PRESENT	0
230135	230127	19599P	PARTICIPANT	\N	PRESENT	0
230136	230127	04035D	PARTICIPANT	\N	PRESENT	0
230137	230127	19715Y	PARTICIPANT	\N	PRESENT	0
230138	230127	08031R	PARTICIPANT	\N	PRESENT	0
230139	230127	14109K	PARTICIPANT	\N	PRESENT	0
230140	230127	11045K	PARTICIPANT	\N	PRESENT	0
230141	230127	08043V	PARTICIPANT	\N	EXCUSE	0
230142	230127	19577H	PARTICIPANT	\N	EXCUSE	0
230143	230127	07029T	PARTICIPANT	\N	EXCUSE	0
230144	230127	19679N	PARTICIPANT	\N	EXCUSE	0
222609	218283	99004R	PARTICIPANT	\N	PRESENT	0
222610	218283	01058X	PARTICIPANT	\N	PRESENT	0
222611	218283	11083R	PARTICIPANT	\N	PRESENT	0
222612	218283	14157T	PARTICIPANT	\N	PRESENT	0
222613	218283	17637T	PARTICIPANT	\N	PRESENT	0
222614	218283	19687N	PARTICIPANT	\N	PRESENT	0
222615	218283	95037J	PARTICIPANT	\N	PRESENT	0
222616	218283	19711U	PARTICIPANT	\N	PRESENT	0
222617	218283	19697Q	PARTICIPANT	\N	PRESENT	0
222618	218283	19637C	PARTICIPANT	\N	PRESENT	0
222619	218283	14223L	PARTICIPANT	\N	PRESENT	0
222620	218283	11072N	PARTICIPANT	\N	PRESENT	0
222621	218283	08028W	PARTICIPANT	\N	PRESENT	0
222622	218283	04033B	PARTICIPANT	\N	PRESENT	0
222623	218283	08061X	PARTICIPANT	\N	PRESENT	0
222624	218283	19349W	PARTICIPANT	\N	PRESENT	0
222625	218283	14069U	PARTICIPANT	\N	PRESENT	0
222626	218283	04045F	PARTICIPANT	\N	PRESENT	0
222627	218283	19301E	PARTICIPANT	\N	PRESENT	0
222628	218283	04047H	PARTICIPANT	\N	PRESENT	0
222629	218283	95030B	PARTICIPANT	\N	PRESENT	0
222630	218283	96004D	PARTICIPANT	\N	PRESENT	0
222631	218283	19731Y	PARTICIPANT	\N	PRESENT	0
222632	218283	19685L	PARTICIPANT	\N	PRESENT	0
222633	218283	98018T	PARTICIPANT	\N	PRESENT	0
222634	218283	04044E	PARTICIPANT	\N	PRESENT	0
222635	218283	11012A	PARTICIPANT	\N	PRESENT	0
222636	218283	19253P	PARTICIPANT	\N	PRESENT	0
222637	218283	04086Q	PARTICIPANT	\N	PRESENT	0
222638	218283	88008L	PARTICIPANT	\N	PRESENT	0
222639	218283	08031R	PARTICIPANT	\N	PRESENT	0
222640	218283	04092N	PARTICIPANT	\N	PRESENT	0
222641	218283	19629C	PARTICIPANT	\N	PRESENT	0
222642	218283	08049C	PARTICIPANT	\N	PRESENT	0
222643	218283	14123H	PARTICIPANT	\N	PRESENT	0
222644	218283	11081P	PARTICIPANT	\N	PRESENT	0
222645	218283	14201E	PARTICIPANT	\N	PRESENT	0
222646	218283	10015M	PARTICIPANT	\N	PRESENT	0
222647	218283	11090Q	PARTICIPANT	\N	PRESENT	0
222648	218283	11033F	PARTICIPANT	\N	PRESENT	0
222649	218283	98022P	PARTICIPANT	\N	PRESENT	0
222650	218283	05008E	PARTICIPANT	\N	PRESENT	0
222651	218283	14261S	PARTICIPANT	\N	PRESENT	0
222652	218283	19421M	PARTICIPANT	\N	PRESENT	0
222653	218283	14241N	PARTICIPANT	\N	PRESENT	0
222654	218283	19553Y	PARTICIPANT	\N	PRESENT	0
222655	218283	11099A	PARTICIPANT	\N	PRESENT	0
222656	218283	14071N	PARTICIPANT	\N	PRESENT	0
222657	218283	19563B	PARTICIPANT	\N	PRESENT	0
222658	218283	11097X	PARTICIPANT	\N	PRESENT	0
222659	218283	14187A	PARTICIPANT	\N	PRESENT	0
222660	218283	14087W	PARTICIPANT	\N	PRESENT	0
222661	218283	14249W	PARTICIPANT	\N	PRESENT	0
222662	218283	14053L	PARTICIPANT	\N	PRESENT	0
222663	218283	98035U	PARTICIPANT	\N	PRESENT	0
222664	218283	14159V	PARTICIPANT	\N	PRESENT	0
222665	218283	11074Q	PARTICIPANT	\N	PRESENT	0
222666	218283	14193X	PARTICIPANT	\N	PRESENT	0
222667	218283	04059M	PARTICIPANT	\N	PRESENT	0
222668	218283	14051J	PARTICIPANT	\N	PRESENT	0
222669	218283	08068F	PARTICIPANT	\N	PRESENT	0
222670	218283	95067Q	PARTICIPANT	\N	PRESENT	0
222671	218283	01028R	PARTICIPANT	\N	PRESENT	0
222672	218283	11027H	PARTICIPANT	\N	PRESENT	0
222673	218283	05012A	PARTICIPANT	\N	PRESENT	0
222674	218283	08052W	PARTICIPANT	\N	PRESENT	0
222675	218283	14229S	PARTICIPANT	\N	PRESENT	0
222676	218283	07033P	PARTICIPANT	\N	PRESENT	0
222677	218283	08055A	PARTICIPANT	\N	PRESENT	0
222678	218283	19707Y	PARTICIPANT	\N	PRESENT	0
222679	218283	08016S	PARTICIPANT	\N	PRESENT	0
222680	218283	14081Q	PARTICIPANT	\N	PRESENT	0
222681	218283	08069G	PARTICIPANT	\N	PRESENT	0
222682	218283	14107H	PARTICIPANT	\N	PRESENT	0
222683	218283	19515S	PARTICIPANT	\N	PRESENT	0
222684	218283	08045X	PARTICIPANT	\N	PRESENT	0
222685	218283	14225N	PARTICIPANT	\N	PRESENT	0
222686	218283	14259Y	PARTICIPANT	\N	PRESENT	0
222687	218283	14021P	PARTICIPANT	\N	PRESENT	0
222688	218283	19715Y	PARTICIPANT	\N	PRESENT	0
222689	218283	01057W	PARTICIPANT	\N	PRESENT	0
222690	218283	12016W	PARTICIPANT	\N	PRESENT	0
222691	218283	17779H	PARTICIPANT	\N	PRESENT	0
222692	218283	14281W	PARTICIPANT	\N	PRESENT	0
222693	218283	10006L	PARTICIPANT	\N	PRESENT	0
222694	218283	19649G	PARTICIPANT	\N	PRESENT	0
222695	218283	07034Q	PARTICIPANT	\N	PRESENT	0
222696	218283	80013X	PARTICIPANT	\N	PRESENT	0
222697	218283	19671E	PARTICIPANT	\N	PRESENT	0
222698	218283	08060W	PARTICIPANT	\N	PRESENT	0
222699	218283	08038Y	PARTICIPANT	\N	PRESENT	0
222700	218283	04018C	PARTICIPANT	\N	PRESENT	0
222701	218283	01062T	PARTICIPANT	\N	PRESENT	0
222702	218283	98023Q	PARTICIPANT	\N	PRESENT	0
222703	218283	14065Q	PARTICIPANT	\N	PRESENT	0
222704	218283	11066Q	PARTICIPANT	\N	PRESENT	0
222705	218283	08043V	PARTICIPANT	\N	PRESENT	0
222706	218283	14079W	PARTICIPANT	\N	PRESENT	0
222707	218283	11104D	PARTICIPANT	\N	PRESENT	0
222708	218283	08034U	PARTICIPANT	\N	PRESENT	0
222709	218283	08058D	PARTICIPANT	\N	PRESENT	0
222710	218283	11048N	PARTICIPANT	\N	PRESENT	0
222711	218283	08012N	PARTICIPANT	\N	PRESENT	0
222712	218283	80027E	PARTICIPANT	\N	PRESENT	0
222713	218283	11103C	PARTICIPANT	\N	PRESENT	0
222714	218283	19727D	PARTICIPANT	\N	PRESENT	0
222715	218283	19531S	PARTICIPANT	\N	PRESENT	0
222716	218283	19483C	PARTICIPANT	\N	PRESENT	0
222717	218283	14097Y	PARTICIPANT	\N	PRESENT	0
222718	218283	19575F	PARTICIPANT	\N	PRESENT	0
222719	218283	19489J	PARTICIPANT	\N	PRESENT	0
222720	218283	95062K	PARTICIPANT	\N	PRESENT	0
222721	218283	14085U	PARTICIPANT	\N	PRESENT	0
222722	218283	01048V	PARTICIPANT	\N	PRESENT	0
222723	218283	08017T	PARTICIPANT	\N	PRESENT	0
222724	218283	08053X	PARTICIPANT	\N	PRESENT	0
222725	218283	14217N	PARTICIPANT	\N	PRESENT	0
222726	218283	19525U	PARTICIPANT	\N	PRESENT	0
222727	218283	14042U	PARTICIPANT	\N	PRESENT	0
222728	218283	11045K	PARTICIPANT	\N	PRESENT	0
222729	218283	14265W	PARTICIPANT	\N	PRESENT	0
222730	218283	11110B	PARTICIPANT	\N	PRESENT	0
222731	218283	14205J	PARTICIPANT	\N	PRESENT	0
222732	218283	11041F	PARTICIPANT	\N	PRESENT	0
222733	218283	14105F	PARTICIPANT	\N	PRESENT	0
222734	218283	14207L	PARTICIPANT	\N	PRESENT	0
222735	218283	14191V	PARTICIPANT	\N	PRESENT	0
222736	218283	11080N	PARTICIPANT	\N	PRESENT	0
222737	218283	08014Q	PARTICIPANT	\N	PRESENT	0
222738	218283	19703U	PARTICIPANT	\N	PRESENT	0
222739	218283	19691J	PARTICIPANT	\N	PRESENT	0
222740	218283	19333N	PARTICIPANT	\N	PRESENT	0
222741	218283	19725B	PARTICIPANT	\N	PRESENT	0
222742	218283	04008A	PARTICIPANT	\N	PRESENT	0
222743	218283	14001X	PARTICIPANT	\N	PRESENT	0
222744	218283	14063N	PARTICIPANT	\N	PRESENT	0
222745	218283	14227Q	PARTICIPANT	\N	PRESENT	0
222746	218283	19683J	PARTICIPANT	\N	PRESENT	0
222747	218283	14255U	PARTICIPANT	\N	PRESENT	0
222748	218283	14213J	PARTICIPANT	\N	PRESENT	0
222749	218283	11109J	PARTICIPANT	\N	PRESENT	0
222750	218283	14083S	PARTICIPANT	\N	PRESENT	0
222751	218283	19295A	PARTICIPANT	\N	PRESENT	0
222752	218283	07004J	PARTICIPANT	\N	PRESENT	0
222753	218283	19689Q	PARTICIPANT	\N	PRESENT	0
222754	218283	19647E	PARTICIPANT	\N	PRESENT	0
222755	218283	19251M	PARTICIPANT	\N	PRESENT	0
222756	218283	11085T	PARTICIPANT	\N	PRESENT	0
222757	218283	19591F	PARTICIPANT	\N	PRESENT	0
222758	218283	19503N	PARTICIPANT	\N	PRESENT	0
222759	218283	14173T	PARTICIPANT	\N	PRESENT	0
222760	218283	14257W	PARTICIPANT	\N	PRESENT	0
222761	218283	14031R	PARTICIPANT	\N	PRESENT	0
222762	218283	19527W	PARTICIPANT	\N	PRESENT	0
222763	218283	04057K	PARTICIPANT	\N	PRESENT	0
222764	218283	19631V	PARTICIPANT	\N	PRESENT	0
222765	218283	04042C	PARTICIPANT	\N	PRESENT	0
222766	218283	14109K	PARTICIPANT	\N	PRESENT	0
222767	218283	08019V	PARTICIPANT	\N	PRESENT	0
222768	218283	98050T	PARTICIPANT	\N	PRESENT	0
222769	218283	04088S	PARTICIPANT	\N	PRESENT	0
222770	218283	19565D	PARTICIPANT	\N	PRESENT	0
222771	218283	08015R	PARTICIPANT	\N	PRESENT	0
222772	218283	17583W	PARTICIPANT	\N	PRESENT	0
222773	218283	04070G	PARTICIPANT	\N	PRESENT	0
222774	218283	19585H	PARTICIPANT	\N	PRESENT	0
222775	218283	19545Y	PARTICIPANT	\N	PRESENT	0
222776	218283	14093U	PARTICIPANT	\N	PRESENT	0
217705	214616	04038G	PARTICIPANT	\N	PRESENT	0
222514	222513	14115H	PARTICIPANT	\N	PRESENT	0
222515	222513	14030Q	PRESIDENT	0	PRESENT	0
222516	222513	08043V	PARTICIPANT	\N	PRESENT	0
222517	222513	19643A	PARTICIPANT	\N	PRESENT	0
222518	222513	08020N	PARTICIPANT	\N	PRESENT	0
222519	222513	08024S	PARTICIPANT	\N	PRESENT	0
222520	222513	80013X	PARTICIPANT	\N	PRESENT	0
222521	222513	14217N	PARTICIPANT	\N	PRESENT	0
222522	222513	19577H	PARTICIPANT	\N	PRESENT	0
222523	222513	19685L	PARTICIPANT	\N	PRESENT	0
222524	222513	19715Y	PARTICIPANT	\N	PRESENT	0
222525	222513	08031R	PARTICIPANT	\N	PRESENT	0
222526	222513	08017T	PARTICIPANT	\N	PRESENT	0
222527	222513	19697Q	PARTICIPANT	\N	PRESENT	0
222528	222513	19657G	PARTICIPANT	\N	PRESENT	0
222529	222513	14235Q	PARTICIPANT	\N	PRESENT	0
222530	222513	19269X	PARTICIPANT	\N	PRESENT	0
222531	222513	11045K	PARTICIPANT	\N	PRESENT	0
223239	222513	18083K	PARTICIPANT	\N	EXCUSE	0
223240	222513	19693L	PARTICIPANT	\N	EXCUSE	0
223241	222513	19599P	PARTICIPANT	\N	EXCUSE	0
223242	222513	07029T	PARTICIPANT	\N	EXCUSE	0
223243	222513	01043Q	PARTICIPANT	\N	EXCUSE	0
223245	222513	11031D	PARTICIPANT	\N	PRESENT	0
227671	218445	14109K	PARTICIPANT	\N	PRESENT	0
227672	218445	11110B	PARTICIPANT	\N	PRESENT	0
227673	218445	08043V	PARTICIPANT	\N	PRESENT	0
227674	218445	14093U	PARTICIPANT	\N	PRESENT	0
227675	218445	04049K	PARTICIPANT	\N	PRESENT	0
227676	218445	19383Y	PARTICIPANT	\N	PRESENT	0
227677	218445	01025N	PARTICIPANT	\N	PRESENT	0
227678	218445	14199E	PARTICIPANT	\N	PRESENT	0
227679	218445	08019V	PARTICIPANT	\N	PRESENT	0
227704	218445	14059S	PARTICIPANT	\N	PRESENT	0
227705	218444	11070L	PARTICIPANT	\N	PRESENT	0
227706	218444	14253S	PARTICIPANT	\N	PRESENT	0
227707	218444	14085U	PARTICIPANT	\N	PRESENT	0
227708	218444	11074Q	PARTICIPANT	\N	PRESENT	0
227709	218444	19413M	PARTICIPANT	\N	PRESENT	0
227710	218444	14197C	PARTICIPANT	\N	PRESENT	0
227711	218444	08068F	PARTICIPANT	\N	PRESENT	0
227712	218444	11031D	PARTICIPANT	\N	PRESENT	0
227713	218444	19253P	PARTICIPANT	\N	PRESENT	0
227714	218444	19387D	PARTICIPANT	\N	PRESENT	0
227715	218444	19629C	PARTICIPANT	\N	PRESENT	0
227716	218444	19737F	PARTICIPANT	\N	PRESENT	0
227717	218444	19569H	PARTICIPANT	\N	PRESENT	0
227718	218444	07004J	PARTICIPANT	\N	PRESENT	0
227719	218444	14215L	PARTICIPANT	\N	PRESENT	0
227720	218444	11097X	PARTICIPANT	\N	PRESENT	0
227721	218444	14225N	PARTICIPANT	\N	PRESENT	0
227722	218444	19687N	PARTICIPANT	\N	PRESENT	0
227723	218444	95030B	PARTICIPANT	\N	PRESENT	0
227724	218444	14259Y	PARTICIPANT	\N	PRESENT	0
227725	218444	14217N	PARTICIPANT	\N	PRESENT	0
227726	218444	17637T	PARTICIPANT	\N	PRESENT	0
227727	218444	19711U	PARTICIPANT	\N	PRESENT	0
227728	218444	14211G	PARTICIPANT	\N	PRESENT	0
227729	218444	14191V	PARTICIPANT	\N	PRESENT	0
227730	218444	19573D	PARTICIPANT	\N	PRESENT	0
227731	218444	14041T	PARTICIPANT	\N	PRESENT	0
227732	218444	14059S	PARTICIPANT	\N	PRESENT	0
227733	218444	19713W	PARTICIPANT	\N	PRESENT	0
227734	218444	19479G	PARTICIPANT	\N	PRESENT	0
227735	218444	19349W	PARTICIPANT	\N	PRESENT	0
227736	218444	19727D	PARTICIPANT	\N	PRESENT	0
227737	218444	19691J	PARTICIPANT	\N	PRESENT	0
227738	218444	19483C	PARTICIPANT	\N	PRESENT	0
227739	218444	11090Q	PARTICIPANT	\N	PRESENT	0
227740	218444	14179A	PARTICIPANT	\N	PRESENT	0
227741	218444	08061X	PARTICIPANT	\N	PRESENT	0
227742	218444	14073Q	PARTICIPANT	\N	PRESENT	0
227743	218444	14249W	PARTICIPANT	\N	PRESENT	0
227744	218444	19369B	PARTICIPANT	\N	PRESENT	0
227745	218444	08010L	PARTICIPANT	\N	PRESENT	0
227746	218444	14251Q	PARTICIPANT	\N	PRESENT	0
227747	218444	19647E	PARTICIPANT	\N	PRESENT	0
227748	218444	11064N	PARTICIPANT	\N	PRESENT	0
227749	218444	14187A	PARTICIPANT	\N	PRESENT	0
227750	218444	14331P	PARTICIPANT	\N	PRESENT	0
227751	218444	14265W	PARTICIPANT	\N	PRESENT	0
227752	218444	14061L	PARTICIPANT	\N	PRESENT	0
227753	218444	14231L	PARTICIPANT	\N	PRESENT	0
227754	218444	14083S	PARTICIPANT	\N	PRESENT	0
227755	218444	14034U	PARTICIPANT	\N	PRESENT	0
227756	218444	04049K	PARTICIPANT	\N	PRESENT	0
227757	218444	19383Y	PARTICIPANT	\N	PRESENT	0
227758	218444	18083K	PARTICIPANT	\N	PRESENT	0
227759	218444	14169X	PARTICIPANT	\N	PRESENT	0
227760	218444	14069U	PARTICIPANT	\N	PRESENT	0
227761	218444	19507S	PARTICIPANT	\N	PRESENT	0
227762	218444	14033T	PARTICIPANT	\N	PRESENT	0
227763	218444	04088S	PARTICIPANT	\N	PRESENT	0
227764	218444	19447X	PARTICIPANT	\N	PRESENT	0
227765	218444	11048N	PARTICIPANT	\N	PRESENT	0
227766	218444	07029T	PARTICIPANT	\N	PRESENT	0
227767	218444	14030Q	PARTICIPANT	\N	PRESENT	0
227768	218444	19563B	PARTICIPANT	\N	PRESENT	0
227769	218444	12016W	PARTICIPANT	\N	PRESENT	0
228382	227827	19667J	PARTICIPANT	\N	EXCUSE	0
228393	227827	19651A	PARTICIPANT	\N	PRESENT	0
228395	227827	11115U	PARTICIPANT	\N	EXCUSE	0
228396	227827	11065P	PARTICIPANT	\N	PRESENT	0
228398	227827	04038G	PARTICIPANT	\N	EXCUSE	0
228400	228399	14147R	PARTICIPANT	\N	PRESENT	0
228403	227827	08041T	PARTICIPANT	\N	EXCUSE	0
228404	227827	19551W	PARTICIPANT	\N	PRESENT	0
228407	227827	14107H	PARTICIPANT	\N	EXCUSE	0
228408	227827	19479G	PARTICIPANT	\N	PRESENT	0
228413	227827	19467C	PARTICIPANT	\N	PRESENT	0
229049	227662	04045F	PARTICIPANT	\N	EXCUSE	0
229050	227662	08048B	PARTICIPANT	\N	EXCUSE	0
229051	227662	08041T	PARTICIPANT	\N	EXCUSE	0
229052	227662	04092N	PRESIDENT	0	PRESENT	0
229053	227662	19683J	PARTICIPANT	\N	PRESENT	0
229054	227662	11103C	PARTICIPANT	\N	PRESENT	0
229055	227662	19717B	PARTICIPANT	\N	PRESENT	0
229056	227662	98024R	PARTICIPANT	\N	PRESENT	0
229057	227662	19703U	PARTICIPANT	\N	PRESENT	0
229058	227662	14071N	PARTICIPANT	\N	PRESENT	0
229059	227662	14355X	PARTICIPANT	\N	PRESENT	0
229060	227662	14195A	PARTICIPANT	\N	PRESENT	0
229061	227662	19553Y	PARTICIPANT	\N	PRESENT	0
229062	227662	14227Q	PARTICIPANT	\N	PRESENT	0
229063	227662	11067R	PARTICIPANT	\N	PRESENT	0
229064	227662	14213J	PARTICIPANT	\N	PRESENT	0
229065	227662	19727D	PARTICIPANT	\N	PRESENT	0
229066	227662	19367Y	PARTICIPANT	\N	PRESENT	0
229067	227662	19675J	PARTICIPANT	\N	PRESENT	0
229068	227662	01034P	PARTICIPANT	\N	PRESENT	0
229069	227662	19679N	PARTICIPANT	\N	PRESENT	0
229070	227662	19657G	PARTICIPANT	\N	PRESENT	0
229071	227662	19335Q	PARTICIPANT	\N	PRESENT	0
229072	227662	19691J	PARTICIPANT	\N	PRESENT	0
229073	227662	14042U	PARTICIPANT	\N	PRESENT	0
229074	227662	14281W	PARTICIPANT	\N	PRESENT	0
229075	227662	14026U	PARTICIPANT	\N	PRESENT	0
229076	227662	11097X	PARTICIPANT	\N	PRESENT	0
229077	227662	19575F	PARTICIPANT	\N	PRESENT	0
229078	227662	17779H	PARTICIPANT	\N	PRESENT	0
229079	227662	08052W	PARTICIPANT	\N	PRESENT	0
229080	227662	14261S	PARTICIPANT	\N	PRESENT	0
229081	227662	14087W	PARTICIPANT	\N	PRESENT	0
229082	227662	19697Q	PARTICIPANT	\N	PRESENT	0
229083	227662	19663E	PARTICIPANT	\N	PRESENT	0
229084	227662	19723Y	PARTICIPANT	\N	PRESENT	0
229085	227662	19715Y	PARTICIPANT	\N	PRESENT	0
229086	227662	14217N	PARTICIPANT	\N	PRESENT	0
229087	227662	14223L	PARTICIPANT	\N	PRESENT	0
229088	227662	14119M	PARTICIPANT	\N	PRESENT	0
229089	227662	19521Q	PARTICIPANT	\N	PRESENT	0
229090	227662	19527W	PARTICIPANT	\N	PRESENT	0
229091	228463	14001X	PARTICIPANT	\N	PRESENT	0
229092	228463	19581D	PARTICIPANT	\N	PRESENT	0
229093	228463	19585H	PARTICIPANT	\N	PRESENT	0
229094	228463	01028R	PARTICIPANT	\N	PRESENT	0
229095	228463	19447X	PARTICIPANT	\N	PRESENT	0
229096	228463	14041T	PARTICIPANT	\N	PRESENT	0
229097	228463	14215L	PARTICIPANT	\N	PRESENT	0
229098	228463	14259Y	PARTICIPANT	\N	PRESENT	0
229099	228463	14053L	PARTICIPANT	\N	PRESENT	0
229100	228463	14111D	PARTICIPANT	\N	PRESENT	0
229101	228463	19649G	PARTICIPANT	\N	PRESENT	0
229102	228463	14065Q	PARTICIPANT	\N	PRESENT	0
229103	228463	11026G	PARTICIPANT	\N	PRESENT	0
229104	228463	08045X	PARTICIPANT	\N	PRESENT	0
229105	228463	19253P	PARTICIPANT	\N	PRESENT	0
229106	228463	04038G	PARTICIPANT	\N	PRESENT	0
227935	218448	14199E	PARTICIPANT	\N	PRESENT	0
227936	218448	14135M	PARTICIPANT	\N	PRESENT	0
227937	218448	19741B	PARTICIPANT	\N	PRESENT	0
227938	218448	14249W	PARTICIPANT	\N	PRESENT	0
227951	218448	19695N	PARTICIPANT	\N	PRESENT	0
227952	218448	14157T	PARTICIPANT	\N	PRESENT	0
228151	218449	14159V	PARTICIPANT	\N	PRESENT	0
228152	218449	19731Y	PARTICIPANT	\N	PRESENT	0
228153	218449	14041T	PARTICIPANT	\N	PRESENT	0
228154	218449	80013X	PARTICIPANT	\N	PRESENT	0
228155	218449	11110B	PARTICIPANT	\N	PRESENT	0
228156	218449	14235Q	PARTICIPANT	\N	PRESENT	0
228157	218449	04085P	PARTICIPANT	\N	PRESENT	0
228158	218449	14257W	PARTICIPANT	\N	PRESENT	0
228159	218449	14205J	PARTICIPANT	\N	PRESENT	0
228161	218449	19515S	PARTICIPANT	\N	PRESENT	0
228162	218449	14191V	PARTICIPANT	\N	PRESENT	0
228163	218449	11040E	PARTICIPANT	\N	PRESENT	0
228164	218449	19631V	PARTICIPANT	\N	PRESENT	0
228165	218449	19591F	PARTICIPANT	\N	PRESENT	0
228166	218449	19701S	PARTICIPANT	\N	PRESENT	0
228169	218449	19533U	PARTICIPANT	\N	PRESENT	0
228170	218449	04088S	PARTICIPANT	\N	PRESENT	0
228172	218449	08034U	PARTICIPANT	\N	PRESENT	0
228173	218449	19693L	PARTICIPANT	\N	PRESENT	0
228174	218449	19399H	PARTICIPANT	\N	PRESENT	0
228175	218449	19741B	PARTICIPANT	\N	PRESENT	0
228176	218449	17589D	PARTICIPANT	\N	PRESENT	0
228177	218449	11099A	PARTICIPANT	\N	PRESENT	0
228178	218449	04049K	PARTICIPANT	\N	PRESENT	0
228179	218449	97011G	PARTICIPANT	\N	PRESENT	0
228180	218449	19507S	PARTICIPANT	\N	PRESENT	0
228181	218449	19573D	PARTICIPANT	\N	PRESENT	0
228182	218449	19447X	PARTICIPANT	\N	PRESENT	0
228183	218449	19503N	PARTICIPANT	\N	PRESENT	0
228184	218449	19269X	PARTICIPANT	\N	PRESENT	0
228185	218449	14051J	PARTICIPANT	\N	PRESENT	0
228186	218449	19695N	PARTICIPANT	\N	PRESENT	0
228187	218449	19667J	PARTICIPANT	\N	PRESENT	0
228188	218449	14265W	PARTICIPANT	\N	PRESENT	0
228189	218449	19711U	PARTICIPANT	\N	PRESENT	0
228190	218449	19689Q	PARTICIPANT	\N	PRESENT	0
228191	218449	11054L	PARTICIPANT	\N	PRESENT	0
228192	218449	98005N	PARTICIPANT	\N	PRESENT	0
228193	218449	19717B	PARTICIPANT	\N	PRESENT	0
228194	218449	14115H	PARTICIPANT	\N	PRESENT	0
228195	218449	10015M	PARTICIPANT	\N	PRESENT	0
228196	218449	19611R	PARTICIPANT	\N	PRESENT	0
228197	218449	14157T	PARTICIPANT	\N	PRESENT	0
228198	218449	19549D	PARTICIPANT	\N	PRESENT	0
228199	218449	14225N	PARTICIPANT	\N	PRESENT	0
228200	218449	19413M	PARTICIPANT	\N	PRESENT	0
228201	218449	14085U	PARTICIPANT	\N	PRESENT	0
228202	218449	11074Q	PARTICIPANT	\N	PRESENT	0
228203	218449	19383Y	PARTICIPANT	\N	PRESENT	0
228204	218449	19253P	PARTICIPANT	\N	PRESENT	0
228205	218449	08068F	PARTICIPANT	\N	PRESENT	0
228206	218449	19301E	PARTICIPANT	\N	PRESENT	0
228207	218449	19593H	PARTICIPANT	\N	PRESENT	0
228208	218449	11090Q	PARTICIPANT	\N	PRESENT	0
228209	218449	19713W	PARTICIPANT	\N	PRESENT	0
228210	218449	19479G	PARTICIPANT	\N	PRESENT	0
228211	218449	14251Q	PARTICIPANT	\N	PRESENT	0
228212	218449	14083S	PARTICIPANT	\N	PRESENT	0
228213	218449	19531S	PARTICIPANT	\N	PRESENT	0
228214	218449	08018U	PARTICIPANT	\N	PRESENT	0
228215	218449	11097X	PARTICIPANT	\N	PRESENT	0
228216	218449	14207L	PARTICIPANT	\N	PRESENT	0
228217	218449	10006L	PARTICIPANT	\N	PRESENT	0
228218	218449	11045K	PARTICIPANT	\N	PRESENT	0
228219	218449	19387D	PARTICIPANT	\N	PRESENT	0
228220	218449	14219Q	PARTICIPANT	\N	PRESENT	0
228221	218449	19643A	PARTICIPANT	\N	PRESENT	0
228222	218449	14119M	PARTICIPANT	\N	PRESENT	0
228223	218449	14199E	PARTICIPANT	\N	PRESENT	0
228224	218449	08019V	PARTICIPANT	\N	PRESENT	0
228225	218449	14331P	PARTICIPANT	\N	PRESENT	0
228226	218449	14169X	PARTICIPANT	\N	PRESENT	0
228227	218449	14135M	PARTICIPANT	\N	PRESENT	0
228228	218449	17637T	PARTICIPANT	\N	PRESENT	0
228229	218449	04043D	PARTICIPANT	\N	PRESENT	0
228230	218449	19441R	PARTICIPANT	\N	PRESENT	0
228231	218449	14039A	PARTICIPANT	\N	PRESENT	0
228232	218449	19295A	PARTICIPANT	\N	PRESENT	0
228233	218449	01048V	PARTICIPANT	\N	PRESENT	0
228234	218449	14249W	PARTICIPANT	\N	PRESENT	0
228235	218449	99004R	PARTICIPANT	\N	PRESENT	0
228239	218449	08011M	PARTICIPANT	\N	PRESENT	0
228240	218449	11072N	PARTICIPANT	\N	PRESENT	0
228241	218449	14231L	PARTICIPANT	\N	PRESENT	0
228242	218449	89017R	PARTICIPANT	\N	PRESENT	0
228243	218449	11056N	PARTICIPANT	\N	PRESENT	0
228244	218449	14327T	PARTICIPANT	\N	PRESENT	0
228245	218449	08073C	PARTICIPANT	\N	PRESENT	0
228246	218449	04089T	PARTICIPANT	\N	PRESENT	0
228248	218449	19671E	PARTICIPANT	\N	PRESENT	0
228249	218449	12016W	PARTICIPANT	\N	PRESENT	0
228250	218449	14357A	PARTICIPANT	\N	PRESENT	0
228251	218449	19657G	PARTICIPANT	\N	PRESENT	0
228121	218449	01043Q	PARTICIPANT	\N	PRESENT	0
228147	218449	07004J	PARTICIPANT	\N	PRESENT	0
228252	218449	14261S	PARTICIPANT	\N	PRESENT	0
228253	218449	14093U	PARTICIPANT	\N	PRESENT	0
228254	218449	19577H	PARTICIPANT	\N	PRESENT	0
228255	218449	08043V	PARTICIPANT	\N	PRESENT	0
228256	218449	14034U	PARTICIPANT	\N	PRESENT	0
228257	218449	11048N	PARTICIPANT	\N	PRESENT	0
228258	218449	11109J	PARTICIPANT	\N	PRESENT	0
228322	226156	14085U	PARTICIPANT	\N	PRESENT	0
228323	226156	07029T	PARTICIPANT	\N	EXCUSE	0
228324	218450	14034U	PARTICIPANT	\N	PRESENT	0
228325	218450	11074Q	PARTICIPANT	\N	PRESENT	0
228326	218450	14331P	PARTICIPANT	\N	PRESENT	0
228327	218450	89017R	PARTICIPANT	\N	PRESENT	0
228328	218450	19697Q	PARTICIPANT	\N	PRESENT	0
228329	218450	19667J	PARTICIPANT	\N	PRESENT	0
228330	218450	19643A	PARTICIPANT	\N	PRESENT	0
228331	218450	04043D	PARTICIPANT	\N	PRESENT	0
228332	218450	19533U	PARTICIPANT	\N	PRESENT	0
228333	218450	19713W	PARTICIPANT	\N	PRESENT	0
228334	218450	14327T	PARTICIPANT	\N	PRESENT	0
228335	218450	14231L	PARTICIPANT	\N	PRESENT	0
228336	218450	19503N	PARTICIPANT	\N	PRESENT	0
228337	218450	14051J	PARTICIPANT	\N	PRESENT	0
228338	218450	08043V	PARTICIPANT	\N	PRESENT	0
228339	218450	14229S	PARTICIPANT	\N	PRESENT	0
228340	218450	19593H	PARTICIPANT	\N	PRESENT	0
228341	218450	19611R	PARTICIPANT	\N	PRESENT	0
228342	218450	04089T	PARTICIPANT	\N	PRESENT	0
228343	218450	19253P	PARTICIPANT	\N	PRESENT	0
228344	218450	19693L	PARTICIPANT	\N	PRESENT	0
228345	218450	14123H	PARTICIPANT	\N	PRESENT	0
228346	218450	11056N	PARTICIPANT	\N	PRESENT	0
228347	218450	14093U	PARTICIPANT	\N	PRESENT	0
228348	218450	04070G	PARTICIPANT	\N	PRESENT	0
228349	218450	19347U	PARTICIPANT	\N	PRESENT	0
228350	218450	11090Q	PARTICIPANT	\N	PRESENT	0
228351	218450	19621T	PARTICIPANT	\N	PRESENT	0
228352	218450	11048N	PARTICIPANT	\N	PRESENT	0
228353	218450	01057W	PARTICIPANT	\N	PRESENT	0
228354	218450	14083S	PARTICIPANT	\N	PRESENT	0
228355	218450	14225N	PARTICIPANT	\N	PRESENT	0
228447	228446	14259Y	PARTICIPANT	\N	PRESENT	0
228448	228446	19489J	PARTICIPANT	\N	PRESENT	0
228449	228446	14231L	PARTICIPANT	\N	PRESENT	0
228451	228450	14259Y	PARTICIPANT	\N	PRESENT	0
228892	228891	04042C	PARTICIPANT	\N	PRESENT	0
228893	228891	98029W	PARTICIPANT	\N	PRESENT	0
228894	228891	98018T	PARTICIPANT	\N	PRESENT	0
228895	228891	98022P	PARTICIPANT	\N	PRESENT	0
228896	228891	14028W	PARTICIPANT	\N	PRESENT	0
228897	228891	14193X	PARTICIPANT	\N	PRESENT	0
228898	228891	11054L	PARTICIPANT	\N	PRESENT	0
228899	228891	95067Q	PARTICIPANT	\N	PRESENT	0
228902	228901	95067Q	PARTICIPANT	\N	PRESENT	0
228903	228901	14028W	PARTICIPANT	\N	PRESENT	0
228310	226156	14327T	PARTICIPANT	\N	PRESENT	0
228311	226156	14331P	PARTICIPANT	\N	PRESENT	0
228312	226156	11048N	PARTICIPANT	\N	PRESENT	0
228313	226156	04071H	PARTICIPANT	\N	PRESENT	0
228314	226156	11074Q	PRESIDENT	0	PRESENT	0
228315	226156	19667J	PARTICIPANT	\N	PRESENT	0
228316	226156	08011M	PARTICIPANT	\N	PRESENT	0
228317	226156	89017R	PARTICIPANT	\N	PRESENT	0
228318	226156	14034U	PARTICIPANT	\N	PRESENT	0
228319	226156	14225N	PARTICIPANT	\N	PRESENT	0
228320	226156	14083S	PARTICIPANT	\N	PRESENT	0
228321	226156	08073C	PARTICIPANT	\N	PRESENT	0
214795	205652	04061F	PARTICIPANT	\N	EXCUSE	0
214796	205652	14093U	PARTICIPANT	\N	PRESENT	0
214797	205652	19663E	PARTICIPANT	\N	PRESENT	0
214798	205652	19593H	PARTICIPANT	\N	PRESENT	0
215019	214715	11109J	PARTICIPANT	\N	PRESENT	0
215020	214715	19593H	PARTICIPANT	\N	PRESENT	0
217569	217449	04043D	PARTICIPANT	\N	EXCUSE	0
220253	220252	14119M	PARTICIPANT	\N	PRESENT	0
220259	220258	14119M	PARTICIPANT	\N	PRESENT	0
230543	230542	19515S	PARTICIPANT	\N	PRESENT	0
230546	230542	14115H	PARTICIPANT	\N	PRESENT	0
230549	230542	14329V	PARTICIPANT	\N	PRESENT	0
230550	230542	14187A	PARTICIPANT	\N	PRESENT	0
230552	230542	19695N	PARTICIPANT	\N	PRESENT	0
230553	230542	19565D	PARTICIPANT	\N	PRESENT	0
230555	230542	14033T	PARTICIPANT	\N	PRESENT	0
230558	230542	19511N	PARTICIPANT	\N	PRESENT	0
230561	230542	19441R	PARTICIPANT	\N	PRESENT	0
230562	230542	14265W	PARTICIPANT	\N	PRESENT	0
230563	230542	11090Q	PARTICIPANT	\N	PRESENT	0
230565	230542	14135M	PARTICIPANT	\N	PRESENT	0
230567	230542	19269X	PARTICIPANT	\N	PRESENT	0
230568	230542	19619A	PARTICIPANT	\N	PRESENT	0
230570	230542	19413M	PARTICIPANT	\N	PRESENT	0
230575	230542	07033P	PARTICIPANT	\N	PRESENT	0
230646	228416	19479G	PARTICIPANT	\N	PRESENT	0
230647	228416	19651A	PARTICIPANT	\N	PRESENT	0
230648	228416	08034U	PARTICIPANT	\N	PRESENT	0
230649	228416	08014Q	PARTICIPANT	\N	PRESENT	0
230650	228416	11070L	PARTICIPANT	\N	PRESENT	0
230652	220063	04086Q	PARTICIPANT	\N	PRESENT	0
230653	220063	08011M	PARTICIPANT	\N	PRESENT	0
230654	220063	11074Q	PARTICIPANT	\N	PRESENT	0
230655	220063	19687N	PARTICIPANT	\N	PRESENT	0
230656	220063	14085U	PARTICIPANT	\N	PRESENT	0
230657	220063	19651A	PARTICIPANT	\N	PRESENT	0
230658	220063	11070L	PARTICIPANT	\N	PRESENT	0
230659	220063	14261S	PARTICIPANT	\N	PRESENT	0
230660	220063	19511N	PARTICIPANT	\N	PRESENT	0
230661	220063	07029T	PARTICIPANT	\N	PRESENT	0
230662	220063	14038Y	PARTICIPANT	\N	PRESENT	0
230663	220063	19711U	PARTICIPANT	\N	PRESENT	0
230664	220063	01057W	PARTICIPANT	\N	PRESENT	0
230665	220063	08034U	PARTICIPANT	\N	PRESENT	0
230666	220063	14253S	PARTICIPANT	\N	PRESENT	0
230667	220063	01058X	PARTICIPANT	\N	PRESENT	0
230668	220063	04071H	PARTICIPANT	\N	PRESENT	0
230669	220063	01048V	PARTICIPANT	\N	PRESENT	0
230670	220063	19545Y	PARTICIPANT	\N	PRESENT	0
230671	220063	11040E	PARTICIPANT	\N	PRESENT	0
230672	220063	11053K	PARTICIPANT	\N	PRESENT	0
230673	220063	14105F	PARTICIPANT	\N	PRESENT	0
230674	220063	08010L	PARTICIPANT	\N	PRESENT	0
230675	220063	19479G	PARTICIPANT	\N	PRESENT	0
230676	220063	11072N	PARTICIPANT	\N	PRESENT	0
230683	220063	19673G	PARTICIPANT	\N	PRESENT	0
230684	220063	19551W	PARTICIPANT	\N	PRESENT	0
230685	220063	08014Q	PARTICIPANT	\N	PRESENT	0
230686	220063	19549D	PARTICIPANT	\N	PRESENT	0
230700	220063	19717B	PARTICIPANT	\N	PRESENT	0
230701	220063	04059M	PARTICIPANT	\N	PRESENT	0
230702	220063	99004R	PARTICIPANT	\N	PRESENT	0
230703	220063	19647E	PARTICIPANT	\N	PRESENT	0
230704	220063	19643A	PARTICIPANT	\N	PRESENT	0
230741	220064	08011M	PARTICIPANT	\N	PRESENT	0
230742	220064	19511N	PARTICIPANT	\N	PRESENT	0
230743	220064	19551W	PARTICIPANT	\N	PRESENT	0
230744	220064	19651A	PARTICIPANT	\N	PRESENT	0
230745	220064	14085U	PARTICIPANT	\N	PRESENT	0
230746	220064	08034U	PARTICIPANT	\N	PRESENT	0
230747	220064	14261S	PARTICIPANT	\N	PRESENT	0
230748	220064	19693L	PARTICIPANT	\N	PRESENT	0
230749	220064	19647E	PARTICIPANT	\N	PRESENT	0
230750	220064	14038Y	PARTICIPANT	\N	PRESENT	0
230751	220064	07029T	PARTICIPANT	\N	PRESENT	0
230752	220064	19301E	PARTICIPANT	\N	PRESENT	0
230753	220064	19687N	PARTICIPANT	\N	PRESENT	0
230754	220064	01057W	PARTICIPANT	\N	PRESENT	0
230755	220064	19711U	PARTICIPANT	\N	PRESENT	0
230756	220064	08010L	PARTICIPANT	\N	PRESENT	0
230757	220064	19667J	PARTICIPANT	\N	PRESENT	0
230758	220064	11053K	PARTICIPANT	\N	PRESENT	0
230759	220064	14331P	PARTICIPANT	\N	PRESENT	0
230760	220064	14327T	PARTICIPANT	\N	PRESENT	0
230761	220064	19545Y	PARTICIPANT	\N	PRESENT	0
230762	220064	19717B	PARTICIPANT	\N	PRESENT	0
230763	220064	14215L	PARTICIPANT	\N	PRESENT	0
230764	220064	19289C	PARTICIPANT	\N	PRESENT	0
230765	220064	04086Q	PARTICIPANT	\N	PRESENT	0
230766	220064	19643A	PARTICIPANT	\N	PRESENT	0
230767	220064	11090Q	PARTICIPANT	\N	PRESENT	0
230768	220064	11040E	PARTICIPANT	\N	PRESENT	0
230771	220064	14253S	PARTICIPANT	\N	PRESENT	0
230772	220064	19689Q	PARTICIPANT	\N	PRESENT	0
230775	220064	11072N	PARTICIPANT	\N	PRESENT	0
230776	220064	19593H	PARTICIPANT	\N	PRESENT	0
230785	220064	04071H	PARTICIPANT	\N	PRESENT	0
230792	220064	14225N	PARTICIPANT	\N	PRESENT	0
230739	220064	11070L	PARTICIPANT	\N	PRESENT	0
230740	220064	11074Q	PARTICIPANT	\N	PRESENT	0
230793	220064	19671E	PARTICIPANT	\N	PRESENT	0
232320	232243	19553Y	PARTICIPANT	\N	PRESENT	0
232321	232243	11031D	PARTICIPANT	\N	PRESENT	0
232322	232243	10006L	PARTICIPANT	\N	PRESENT	0
232323	232243	19527W	PARTICIPANT	\N	PRESENT	0
232324	232243	19691J	PARTICIPANT	\N	PRESENT	0
232326	232325	19651A	PARTICIPANT	\N	PRESENT	0
232327	232325	08020N	PARTICIPANT	\N	PRESENT	0
232328	232325	04086Q	PARTICIPANT	\N	PRESENT	0
232329	232325	07033P	PARTICIPANT	\N	PRESENT	0
232330	232325	19551W	PARTICIPANT	\N	PRESENT	0
232331	232325	04049K	PARTICIPANT	\N	PRESENT	0
232332	232325	14059S	PARTICIPANT	\N	PRESENT	0
232333	232325	96004D	PARTICIPANT	\N	PRESENT	0
232755	232753	05008E	PARTICIPANT	\N	PRESENT	0
232758	232753	14215L	PARTICIPANT	\N	PRESENT	0
232737	232733	19733B	PARTICIPANT	\N	PRESENT	0
232738	232733	18083K	PARTICIPANT	\N	PRESENT	0
232756	232753	14259Y	PARTICIPANT	\N	PRESENT	0
232740	232733	11065P	PARTICIPANT	\N	PRESENT	0
232741	232733	02002K	PARTICIPANT	\N	PRESENT	0
232742	232733	19347U	PARTICIPANT	\N	PRESENT	0
232743	232733	19551W	PARTICIPANT	\N	PRESENT	0
232744	232733	14031R	PARTICIPANT	\N	PRESENT	0
232745	232733	19637C	PARTICIPANT	\N	PRESENT	0
232746	232733	08009T	PARTICIPANT	\N	PRESENT	0
232747	232733	14051J	PARTICIPANT	\N	PRESENT	0
232748	232733	14157T	PARTICIPANT	\N	PRESENT	0
232759	232753	14231L	PARTICIPANT	\N	PRESENT	0
232760	232753	19489J	PARTICIPANT	\N	PRESENT	0
232761	232753	14151M	PARTICIPANT	\N	PRESENT	0
232762	232753	95063L	PARTICIPANT	\N	PRESENT	0
232767	232766	14133K	PARTICIPANT	\N	PRESENT	0
232768	232766	14065Q	PARTICIPANT	\N	EXCUSE	0
232769	232766	96004D	PRESIDENT	0	PRESENT	0
232770	232766	14089Y	PARTICIPANT	\N	PRESENT	0
232771	232766	14357A	PARTICIPANT	\N	PRESENT	0
232772	232766	14079W	PARTICIPANT	\N	PRESENT	0
232773	232766	14249W	PARTICIPANT	\N	PRESENT	0
232774	232766	11083R	PARTICIPANT	\N	EXCUSE	0
232775	232766	19553Y	PARTICIPANT	\N	EXCUSE	0
232776	232766	08044W	PARTICIPANT	\N	EXCUSE	0
232777	232766	04061F	PARTICIPANT	\N	PRESENT	0
232778	232766	14061L	PARTICIPANT	\N	EXCUSE	0
232779	232766	14073Q	PARTICIPANT	\N	PRESENT	0
232780	232766	11026G	PARTICIPANT	\N	PRESENT	0
232781	232766	08039A	PARTICIPANT	\N	PRESENT	0
232782	232766	14221J	PARTICIPANT	\N	PRESENT	0
232783	232766	04057K	PARTICIPANT	\N	EXCUSE	0
232784	232766	19335Q	PARTICIPANT	\N	EXCUSE	0
232785	232766	19593H	PARTICIPANT	\N	PRESENT	0
232786	232766	14331P	PARTICIPANT	\N	EXCUSE	0
232787	232766	98035U	PARTICIPANT	\N	EXCUSE	0
232788	232539	19667J	PARTICIPANT	\N	EXCUSE	0
232789	232539	19651A	PARTICIPANT	\N	PRESENT	0
233008	233007	01028R	PARTICIPANT	\N	PRESENT	0
222777	218283	14038Y	PARTICIPANT	\N	PRESENT	0
222778	218283	17589D	PARTICIPANT	\N	PRESENT	0
222779	218283	11064N	PARTICIPANT	\N	PRESENT	0
222780	218283	19583F	PARTICIPANT	\N	PRESENT	0
222781	218283	19443T	PARTICIPANT	\N	PRESENT	0
222782	218283	14195A	PARTICIPANT	\N	PRESENT	0
222783	218283	14251Q	PARTICIPANT	\N	PRESENT	0
222784	218283	14111D	PARTICIPANT	\N	PRESENT	0
222785	218283	07029T	PARTICIPANT	\N	PRESENT	0
222786	218283	14030Q	PARTICIPANT	\N	PRESENT	0
222787	218283	08062Y	PARTICIPANT	\N	PRESENT	0
222788	218283	04040A	PARTICIPANT	\N	PRESENT	0
222789	218283	14327T	PARTICIPANT	\N	PRESENT	0
222790	218283	01024M	PARTICIPANT	\N	PRESENT	0
222791	218283	08044W	PARTICIPANT	\N	PRESENT	0
222792	218283	14329V	PARTICIPANT	\N	PRESENT	0
222793	218283	19511N	PARTICIPANT	\N	PRESENT	0
222794	218283	14061L	PARTICIPANT	\N	PRESENT	0
222795	218283	14357A	PARTICIPANT	\N	PRESENT	0
222796	218283	19693L	PARTICIPANT	\N	PRESENT	0
222797	218283	19399H	PARTICIPANT	\N	PRESENT	0
222798	218283	11053K	PARTICIPANT	\N	PRESENT	0
222799	218283	08018U	PARTICIPANT	\N	PRESENT	0
222800	218283	08009T	PARTICIPANT	\N	PRESENT	0
222801	218283	87003B	PARTICIPANT	\N	PRESENT	0
222802	218283	92040Q	PARTICIPANT	\N	PRESENT	0
222803	218283	19611R	PARTICIPANT	\N	PRESENT	0
222804	218283	14073Q	PARTICIPANT	\N	PRESENT	0
222805	218283	19619A	PARTICIPANT	\N	PRESENT	0
222806	218283	19699S	PARTICIPANT	\N	PRESENT	0
222807	218283	19737F	PARTICIPANT	\N	PRESENT	0
222808	218283	19479G	PARTICIPANT	\N	PRESENT	0
222809	218283	19319Q	PARTICIPANT	\N	PRESENT	0
222810	218283	14199E	PARTICIPANT	\N	PRESENT	0
222811	218283	19521Q	PARTICIPANT	\N	PRESENT	0
222812	218283	14103D	PARTICIPANT	\N	PRESENT	0
222813	218283	19569H	PARTICIPANT	\N	PRESENT	0
222814	218283	16685X	PARTICIPANT	\N	PRESENT	0
222815	218283	19735D	PARTICIPANT	\N	PRESENT	0
222816	218283	19447X	PARTICIPANT	\N	PRESENT	0
222817	218283	04089T	PARTICIPANT	\N	PRESENT	0
222818	218283	19739H	PARTICIPANT	\N	PRESENT	0
222819	218283	19335Q	PARTICIPANT	\N	PRESENT	0
222820	218283	14221J	PARTICIPANT	\N	PRESENT	0
222821	218283	19681G	PARTICIPANT	\N	PRESENT	0
222822	218283	14267Y	PARTICIPANT	\N	PRESENT	0
222823	218283	14219Q	PARTICIPANT	\N	PRESENT	0
222824	218283	14277B	PARTICIPANT	\N	PRESENT	0
222825	218283	14275Y	PARTICIPANT	\N	PRESENT	0
222826	218283	19621T	PARTICIPANT	\N	PRESENT	0
222827	218283	14055N	PARTICIPANT	\N	PRESENT	0
222828	218283	19383Y	PARTICIPANT	\N	PRESENT	0
222829	218283	19721W	PARTICIPANT	\N	PRESENT	0
222830	218283	19705W	PARTICIPANT	\N	PRESENT	0
222831	218283	19673G	PARTICIPANT	\N	PRESENT	0
222832	218283	18083K	PARTICIPANT	\N	PRESENT	0
222833	218283	19663E	PARTICIPANT	\N	PRESENT	0
222834	218283	19733B	PARTICIPANT	\N	PRESENT	0
222835	218283	04049K	PARTICIPANT	\N	PRESENT	0
222836	218283	14115H	PARTICIPANT	\N	PRESENT	0
222837	218283	19675J	PARTICIPANT	\N	PRESENT	0
222838	218283	14029X	PARTICIPANT	\N	PRESENT	0
222839	218283	14135M	PARTICIPANT	\N	PRESENT	0
222840	218283	19533U	PARTICIPANT	\N	PRESENT	0
222849	218283	19657G	PARTICIPANT	\N	PRESENT	0
222842	218283	14355X	PARTICIPANT	\N	PRESENT	0
222843	218283	14059S	PARTICIPANT	\N	PRESENT	0
222844	218283	14033T	PARTICIPANT	\N	PRESENT	0
222845	218283	11049P	PARTICIPANT	\N	PRESENT	0
222846	218283	19701S	PARTICIPANT	\N	PRESENT	0
222847	218283	97011G	PARTICIPANT	\N	PRESENT	0
222848	218283	11070L	PARTICIPANT	\N	PRESENT	0
222850	218283	19573D	PARTICIPANT	\N	PRESENT	0
222867	218283	19659J	PARTICIPANT	\N	PRESENT	0
222852	218283	14119M	PARTICIPANT	\N	PRESENT	0
222853	218283	19667J	PARTICIPANT	\N	PRESENT	0
222854	218283	14151M	PARTICIPANT	\N	PRESENT	0
222855	218283	19467C	PARTICIPANT	\N	PRESENT	0
222856	218283	14041T	PARTICIPANT	\N	PRESENT	0
222857	218283	11010L	PARTICIPANT	\N	PRESENT	0
222858	218283	19507S	PARTICIPANT	\N	PRESENT	0
222862	218283	14253S	PARTICIPANT	\N	PRESENT	0
222860	218283	19709B	PARTICIPANT	\N	PRESENT	0
222861	218283	14133K	PARTICIPANT	\N	PRESENT	0
222865	218283	04071H	PARTICIPANT	\N	PRESENT	0
222866	218283	04043D	PARTICIPANT	\N	PRESENT	0
222868	218283	04061F	PARTICIPANT	\N	PRESENT	0
222869	218283	19677L	PARTICIPANT	\N	PRESENT	0
222870	218283	19413M	PARTICIPANT	\N	PRESENT	0
222871	218283	95041E	PARTICIPANT	\N	PRESENT	0
222872	218283	19723Y	PARTICIPANT	\N	PRESENT	0
222873	218283	19551W	PARTICIPANT	\N	PRESENT	0
222874	218283	08073C	PARTICIPANT	\N	PRESENT	0
222876	218283	14034U	PARTICIPANT	\N	PRESENT	0
222877	218283	11065P	PARTICIPANT	\N	PRESENT	0
222878	218283	19729F	PARTICIPANT	\N	PRESENT	0
222879	218283	19577H	PARTICIPANT	\N	PRESENT	0
222884	218283	19369B	PARTICIPANT	\N	PRESENT	0
222885	218283	11026G	PARTICIPANT	\N	PRESENT	0
222886	218283	11115U	PARTICIPANT	\N	PRESENT	0
222887	218283	14179A	PARTICIPANT	\N	PRESENT	0
223179	218281	11077T	PARTICIPANT	\N	PRESENT	0
223180	218281	08011M	PARTICIPANT	\N	PRESENT	0
223181	218281	14225N	PARTICIPANT	\N	PRESENT	0
223182	218281	19651A	PARTICIPANT	\N	PRESENT	0
223183	218281	14085U	PARTICIPANT	\N	PRESENT	0
223184	218281	19689Q	PARTICIPANT	\N	PRESENT	0
223185	218281	14081Q	PARTICIPANT	\N	PRESENT	0
223186	218281	19545Y	PARTICIPANT	\N	PRESENT	0
223187	218281	14251Q	PARTICIPANT	\N	PRESENT	0
223188	218281	19631V	PARTICIPANT	\N	PRESENT	0
223189	218281	19593H	PARTICIPANT	\N	PRESENT	0
223190	218281	19349W	PARTICIPANT	\N	PRESENT	0
223191	218281	14179A	PARTICIPANT	\N	PRESENT	0
223192	218281	19737F	PARTICIPANT	\N	PRESENT	0
223193	218281	19479G	PARTICIPANT	\N	PRESENT	0
223194	218281	14205J	PARTICIPANT	\N	PRESENT	0
223195	218281	19711U	PARTICIPANT	\N	PRESENT	0
223196	218281	04097T	PARTICIPANT	\N	PRESENT	0
223197	218281	19443T	PARTICIPANT	\N	PRESENT	0
223198	218281	19515S	PARTICIPANT	\N	PRESENT	0
223199	218281	19447X	PARTICIPANT	\N	PRESENT	0
223200	218281	14157T	PARTICIPANT	\N	PRESENT	0
223201	218281	04088S	PARTICIPANT	\N	PRESENT	0
223202	218281	19673G	PARTICIPANT	\N	PRESENT	0
223203	218281	14041T	PARTICIPANT	\N	PRESENT	0
223204	218281	11040E	PARTICIPANT	\N	PRESENT	0
223205	218281	19413M	PARTICIPANT	\N	PRESENT	0
223206	218281	07029T	PARTICIPANT	\N	PRESENT	0
223207	218281	08019V	PARTICIPANT	\N	PRESENT	0
223208	218281	19399H	PARTICIPANT	\N	PRESENT	0
223209	218281	11048N	PARTICIPANT	\N	PRESENT	0
223210	218281	04049K	PARTICIPANT	\N	PRESENT	0
223211	218281	14213J	PARTICIPANT	\N	PRESENT	0
223212	218281	14187A	PARTICIPANT	\N	PRESENT	0
223213	218281	04086Q	PARTICIPANT	\N	PRESENT	0
223214	218281	04061F	PARTICIPANT	\N	PRESENT	0
223215	218281	04018C	PARTICIPANT	\N	PRESENT	0
223216	218281	14055N	PARTICIPANT	\N	PRESENT	0
223217	218281	19731Y	PARTICIPANT	\N	PRESENT	0
223218	218281	11074Q	PARTICIPANT	\N	PRESENT	0
223219	218281	11090Q	PARTICIPANT	\N	PRESENT	0
223220	218281	19531S	PARTICIPANT	\N	PRESENT	0
223221	218281	19715Y	PARTICIPANT	\N	PRESENT	0
223222	218281	14357A	PARTICIPANT	\N	PRESENT	0
223223	218281	11101A	PARTICIPANT	\N	PRESENT	0
223224	218281	14249W	PARTICIPANT	\N	PRESENT	0
223225	218281	19671E	PARTICIPANT	\N	PRESENT	0
223226	218281	08073C	PARTICIPANT	\N	PRESENT	0
223227	218281	19677L	PARTICIPANT	\N	PRESENT	0
223228	218281	14265W	PARTICIPANT	\N	PRESENT	0
223229	218281	19647E	PARTICIPANT	\N	PRESENT	0
223230	218281	19663E	PARTICIPANT	\N	PRESENT	0
223231	218281	14033T	PARTICIPANT	\N	PRESENT	0
223232	218281	04071H	PARTICIPANT	\N	PRESENT	0
223233	218281	08034U	PARTICIPANT	\N	PRESENT	0
223234	218281	19583F	PARTICIPANT	\N	PRESENT	0
223235	218281	19563B	PARTICIPANT	\N	PRESENT	0
223236	218281	14061L	PARTICIPANT	\N	PRESENT	0
223237	218281	19383Y	PARTICIPANT	\N	PRESENT	0
223238	218281	19703U	PARTICIPANT	\N	PRESENT	0
223244	218281	12016W	PARTICIPANT	\N	PRESENT	0
223246	218281	19729F	PARTICIPANT	\N	PRESENT	0
223247	218281	14083S	PARTICIPANT	\N	PRESENT	0
223248	218281	11070L	PARTICIPANT	\N	PRESENT	0
223249	218281	04033B	PARTICIPANT	\N	PRESENT	0
223250	218281	14191V	PARTICIPANT	\N	PRESENT	0
223251	218281	14073Q	PARTICIPANT	\N	PRESENT	0
215190	214549	19697Q	PARTICIPANT	\N	PRESENT	0
215191	214549	11067R	PARTICIPANT	\N	PRESENT	0
215192	214549	19569H	PARTICIPANT	\N	PRESENT	0
215193	214549	11097X	PARTICIPANT	\N	PRESENT	0
215194	214549	19415P	PARTICIPANT	\N	PRESENT	0
215195	214549	04045F	PARTICIPANT	\N	PRESENT	0
215196	214549	14223L	PARTICIPANT	\N	PRESENT	0
215197	214549	19675J	PARTICIPANT	\N	PRESENT	0
215198	214549	17779H	PARTICIPANT	\N	PRESENT	0
215199	214549	19703U	PARTICIPANT	\N	PRESENT	0
215200	214549	14281W	PARTICIPANT	\N	PRESENT	0
215201	214549	14042U	PARTICIPANT	\N	PRESENT	0
215202	214549	19575F	PARTICIPANT	\N	PRESENT	0
215203	214549	14195A	PARTICIPANT	\N	PRESENT	0
215204	214549	19367Y	PARTICIPANT	\N	PRESENT	0
215205	214549	14213J	PARTICIPANT	\N	PRESENT	0
215206	214549	10006L	PARTICIPANT	\N	PRESENT	0
215207	214549	98024R	PARTICIPANT	\N	PRESENT	0
215208	214549	19521Q	PARTICIPANT	\N	PRESENT	0
215209	214549	01034P	PARTICIPANT	\N	PRESENT	0
215210	214549	04092N	PRESIDENT	0	PRESENT	0
215211	214549	08052W	PARTICIPANT	\N	PRESENT	0
215212	214549	19691J	PARTICIPANT	\N	PRESENT	0
215213	214549	08041T	PARTICIPANT	\N	PRESENT	0
215214	214549	11103C	PARTICIPANT	\N	PRESENT	0
215215	214549	19715Y	PARTICIPANT	\N	PRESENT	0
215216	214549	11077T	PARTICIPANT	\N	PRESENT	0
215217	214549	14026U	PARTICIPANT	\N	PRESENT	0
215218	214549	14227Q	PARTICIPANT	\N	PRESENT	0
215219	214549	11063M	PARTICIPANT	\N	PRESENT	0
215220	214549	19553Y	PARTICIPANT	\N	PRESENT	0
215221	214549	19679N	PARTICIPANT	\N	PRESENT	0
215222	214549	08048B	PARTICIPANT	\N	PRESENT	0
215223	214549	14217N	PARTICIPANT	\N	PRESENT	0
215224	214549	19683J	PARTICIPANT	\N	PRESENT	0
215225	214549	19527W	PARTICIPANT	\N	PRESENT	0
215226	214549	19663E	PARTICIPANT	\N	PRESENT	0
215227	214549	19723Y	PARTICIPANT	\N	PRESENT	0
215228	214549	19727D	PARTICIPANT	\N	PRESENT	0
215229	214549	14119M	PARTICIPANT	\N	PRESENT	0
215230	214549	14071N	PARTICIPANT	\N	PRESENT	0
215231	214549	19657G	PARTICIPANT	\N	PRESENT	0
215232	214549	14239U	PARTICIPANT	\N	PRESENT	0
215233	214493	11066Q	PARTICIPANT	\N	PRESENT	0
215234	214493	19669L	PARTICIPANT	\N	PRESENT	0
215235	214493	19721W	PARTICIPANT	\N	PRESENT	0
215236	214493	08047A	PARTICIPANT	\N	PRESENT	0
215237	214587	14327T	PARTICIPANT	\N	PRESENT	0
215238	214587	14331P	PARTICIPANT	\N	PRESENT	0
215239	214587	04071H	PARTICIPANT	\N	PRESENT	0
215240	214587	01048V	PARTICIPANT	\N	PRESENT	0
215241	214587	19545Y	PARTICIPANT	\N	PRESENT	0
215242	214587	01057W	PARTICIPANT	\N	PRESENT	0
215243	214587	11053K	PARTICIPANT	\N	PRESENT	0
215244	214587	19667J	PARTICIPANT	\N	PRESENT	0
215245	214587	89017R	PARTICIPANT	\N	PRESENT	0
215246	214587	11074Q	PRESIDENT	0	PRESENT	0
215247	214587	19671E	PARTICIPANT	\N	PRESENT	0
215248	214587	14225N	PARTICIPANT	\N	PRESENT	0
215249	214587	11110B	PARTICIPANT	\N	PRESENT	0
215250	214587	07029T	PARTICIPANT	\N	PRESENT	0
215251	214587	14085U	PARTICIPANT	\N	PRESENT	0
215252	214587	19349W	PARTICIPANT	\N	PRESENT	0
215253	214587	08010L	PARTICIPANT	\N	PRESENT	0
215254	214587	14253S	PARTICIPANT	\N	PRESENT	0
215255	214587	19479G	PARTICIPANT	\N	PRESENT	0
215256	214587	11048N	PARTICIPANT	\N	PRESENT	0
215257	214587	19711U	PARTICIPANT	\N	PRESENT	0
215258	214587	08034U	PARTICIPANT	\N	PRESENT	0
215259	214587	19531S	PARTICIPANT	\N	PRESENT	0
215260	214587	19651A	PARTICIPANT	\N	PRESENT	0
215261	214587	08069G	PARTICIPANT	\N	PRESENT	0
215262	214587	19687N	PARTICIPANT	\N	PRESENT	0
215263	214587	12016W	PARTICIPANT	\N	PRESENT	0
215264	214587	08011M	PARTICIPANT	\N	PRESENT	0
215265	214587	08014Q	PARTICIPANT	\N	PRESENT	0
215266	214587	14159V	PARTICIPANT	\N	PRESENT	0
215267	214587	14173T	PARTICIPANT	\N	PRESENT	0
215268	214587	11040E	PARTICIPANT	\N	PRESENT	0
215269	214587	04086Q	PARTICIPANT	\N	PRESENT	0
215270	214587	11012A	PARTICIPANT	\N	PRESENT	0
215271	214587	14199E	PARTICIPANT	\N	PRESENT	0
215272	214587	14121F	PARTICIPANT	\N	PRESENT	0
215273	214587	88008L	PARTICIPANT	\N	PRESENT	0
215274	214587	14277B	PARTICIPANT	\N	EXCUSE	0
215275	214587	07004J	PARTICIPANT	\N	EXCUSE	0
215276	214493	19319Q	PARTICIPANT	\N	PRESENT	0
215277	214493	14105F	PARTICIPANT	\N	PRESENT	0
215278	214493	19443T	PARTICIPANT	\N	PRESENT	0
215279	214493	19421M	PARTICIPANT	\N	PRESENT	0
215280	214493	14235Q	PARTICIPANT	\N	PRESENT	0
215281	214493	08049C	PARTICIPANT	\N	PRESENT	0
215282	214493	16685X	PARTICIPANT	\N	PRESENT	0
215283	214493	14255U	PARTICIPANT	\N	PRESENT	0
215284	214549	14261S	PARTICIPANT	\N	PRESENT	0
215285	214549	11045K	PARTICIPANT	\N	PRESENT	0
215286	214549	19717B	PARTICIPANT	\N	PRESENT	0
215287	214493	11080N	PARTICIPANT	\N	PRESENT	0
215288	214493	95030B	PARTICIPANT	\N	PRESENT	0
215289	214493	04040A	PARTICIPANT	\N	PRESENT	0
215290	214493	01058X	PARTICIPANT	\N	PRESENT	0
215291	214493	11027H	PARTICIPANT	\N	PRESENT	0
215292	214493	04042C	PRESIDENT	0	PRESENT	0
215293	214493	95037J	PARTICIPANT	\N	PRESENT	0
215294	214493	14055N	PARTICIPANT	\N	PRESENT	0
215295	214493	19709B	PARTICIPANT	\N	PRESENT	0
215296	214493	14193X	PARTICIPANT	\N	PRESENT	0
215297	214493	08053X	PARTICIPANT	\N	PRESENT	0
215298	214493	97011G	PARTICIPANT	\N	PRESENT	0
215299	214493	14097Y	PARTICIPANT	\N	PRESENT	0
215300	214493	14133K	PARTICIPANT	\N	PRESENT	0
215301	214493	01062T	PARTICIPANT	\N	PRESENT	0
215302	214493	08058D	PARTICIPANT	\N	PRESENT	0
215303	214493	19251M	PARTICIPANT	\N	PRESENT	0
215304	214493	14028W	PARTICIPANT	\N	PRESENT	0
215305	214493	98018T	PARTICIPANT	\N	PRESENT	0
215306	214493	98022P	PARTICIPANT	\N	PRESENT	0
215307	214493	11064N	PARTICIPANT	\N	PRESENT	0
215308	214493	98050T	PARTICIPANT	\N	PRESENT	0
215309	214493	14211G	PARTICIPANT	\N	PRESENT	0
215310	214493	04034C	PARTICIPANT	\N	PRESENT	0
215311	214493	11054L	PARTICIPANT	\N	PRESENT	0
215312	214493	98029W	PARTICIPANT	\N	PRESENT	0
215313	214493	11041F	PARTICIPANT	\N	PRESENT	0
215314	214624	19515S	PARTICIPANT	\N	PRESENT	0
215315	214624	01043Q	PARTICIPANT	\N	PRESENT	0
215316	214624	19565D	PARTICIPANT	\N	PRESENT	0
215317	214624	19441R	PARTICIPANT	\N	PRESENT	0
215318	214624	19413M	PARTICIPANT	\N	PRESENT	0
215319	214624	80013X	PARTICIPANT	\N	PRESENT	0
215320	214624	19631V	PARTICIPANT	\N	PRESENT	0
215321	214624	08068F	PARTICIPANT	\N	PRESENT	0
215322	214624	08019V	PARTICIPANT	\N	PRESENT	0
215323	214624	14197C	PARTICIPANT	\N	PRESENT	0
215324	214624	19511N	PARTICIPANT	\N	PRESENT	0
215325	214624	19563B	PARTICIPANT	\N	PRESENT	0
215326	214624	14265W	PARTICIPANT	\N	PRESENT	0
215327	214624	19591F	PARTICIPANT	\N	PRESENT	0
215328	214624	14135M	PARTICIPANT	\N	PRESENT	0
215329	214624	19467C	PARTICIPANT	\N	PRESENT	0
215330	214624	14187A	PARTICIPANT	\N	PRESENT	0
215331	214624	08062Y	PARTICIPANT	\N	PRESENT	0
215332	214624	19301E	PARTICIPANT	\N	PRESENT	0
215333	214624	19695N	PARTICIPANT	\N	PRESENT	0
215334	214624	11090Q	PRESIDENT	0	PRESENT	0
215335	214624	14033T	PARTICIPANT	\N	PRESENT	0
215336	214624	19295A	PARTICIPANT	\N	PRESENT	0
215337	214624	11056N	PARTICIPANT	\N	PRESENT	0
215338	214624	04089T	PARTICIPANT	\N	PRESENT	0
215339	214624	14115H	PARTICIPANT	\N	PRESENT	0
215340	214624	11101A	PARTICIPANT	\N	PRESENT	0
215341	214624	14207L	PARTICIPANT	\N	PRESENT	0
215342	214624	14257W	PARTICIPANT	\N	PRESENT	0
215343	214624	08028W	PARTICIPANT	\N	PRESENT	0
215347	214624	04049K	PARTICIPANT	\N	PRESENT	0
215348	214624	08038Y	PARTICIPANT	\N	PRESENT	0
215349	214624	19269X	PARTICIPANT	\N	PRESENT	0
215350	214624	04088S	PARTICIPANT	\N	PRESENT	0
215351	214624	04043D	PARTICIPANT	\N	PRESENT	0
215391	214549	14087W	PARTICIPANT	\N	PRESENT	0
215397	214719	04070G	PRESIDENT	0	PRESENT	0
215398	214719	12041X	PARTICIPANT	\N	PRESENT	0
215399	214719	19533U	PARTICIPANT	\N	PRESENT	0
215400	214719	95015C	PARTICIPANT	\N	PRESENT	0
215401	214719	19329S	PARTICIPANT	\N	PRESENT	0
215402	214719	14229S	PARTICIPANT	\N	PRESENT	0
215403	214719	19573D	PARTICIPANT	\N	PRESENT	0
215404	214719	14039A	PARTICIPANT	\N	PRESENT	0
215405	214719	14107H	PARTICIPANT	\N	PRESENT	0
229107	228463	19719D	PARTICIPANT	\N	PRESENT	0
229108	228463	11033F	PARTICIPANT	\N	PRESENT	0
229109	228463	19725B	PARTICIPANT	\N	PRESENT	0
229110	228463	14089Y	PARTICIPANT	\N	PRESENT	0
229111	228463	19729F	PARTICIPANT	\N	PRESENT	0
229112	228463	95063L	PARTICIPANT	\N	PRESENT	0
229113	228463	19629C	PARTICIPANT	\N	PRESENT	0
229114	228463	08044W	PARTICIPANT	\N	PRESENT	0
229115	228463	14069U	PARTICIPANT	\N	PRESENT	0
229116	228463	14021P	PARTICIPANT	\N	PRESENT	0
229117	228463	14147R	PARTICIPANT	\N	PRESENT	0
229118	228463	19483C	PARTICIPANT	\N	PRESENT	0
229119	228463	19673G	PARTICIPANT	\N	EXCUSE	0
229120	228463	14231L	PARTICIPANT	\N	EXCUSE	0
229121	228463	10015M	PARTICIPANT	\N	PRESENT	0
229122	228463	05008E	PRESIDENT	0	PRESENT	0
229123	228463	14151M	PARTICIPANT	\N	PRESENT	0
229124	228463	01024M	PARTICIPANT	\N	PRESENT	0
229125	228463	11049P	PARTICIPANT	\N	PRESENT	0
229126	228463	19489J	PARTICIPANT	\N	PRESENT	0
229127	228463	07034Q	PRESIDENT	1	PRESENT	0
229128	228463	04008A	PARTICIPANT	\N	PRESENT	0
229129	227662	11063M	PARTICIPANT	\N	PRESENT	0
229130	228463	04047H	PARTICIPANT	\N	PRESENT	0
229131	228463	08018U	PARTICIPANT	\N	PRESENT	0
229132	228463	98035U	PARTICIPANT	\N	PRESENT	0
229133	227892	19383Y	PARTICIPANT	\N	PRESENT	0
229134	227892	19515S	PARTICIPANT	\N	PRESENT	0
229135	227892	19565D	PARTICIPANT	\N	PRESENT	0
229136	227892	01043Q	PARTICIPANT	\N	PRESENT	0
229137	227892	19441R	PARTICIPANT	\N	PRESENT	0
229138	227892	14081Q	PARTICIPANT	\N	PRESENT	0
229139	227892	19413M	PARTICIPANT	\N	PRESENT	0
229140	227892	80013X	PARTICIPANT	\N	PRESENT	0
229141	227892	19631V	PARTICIPANT	\N	PRESENT	0
229142	227892	11099A	PARTICIPANT	\N	PRESENT	0
229143	227892	04049K	PARTICIPANT	\N	PRESENT	0
229144	227892	19705W	PARTICIPANT	\N	PRESENT	0
229145	227892	19707Y	PARTICIPANT	\N	PRESENT	0
229146	227892	08015R	PARTICIPANT	\N	PRESENT	0
229147	227892	08019V	PARTICIPANT	\N	PRESENT	0
229148	227892	14197C	PARTICIPANT	\N	PRESENT	0
229149	227892	19369B	PARTICIPANT	\N	PRESENT	0
229150	227892	19511N	PARTICIPANT	\N	PRESENT	0
229151	227892	08028W	PARTICIPANT	\N	PRESENT	0
229152	227892	19563B	PARTICIPANT	\N	PRESENT	0
229153	227892	14265W	PARTICIPANT	\N	PRESENT	0
229154	227892	14329V	PARTICIPANT	\N	PRESENT	0
229155	227892	19591F	PARTICIPANT	\N	PRESENT	0
229156	227892	14135M	PARTICIPANT	\N	PRESENT	0
229157	227892	19467C	PARTICIPANT	\N	PRESENT	0
229158	227892	08062Y	PARTICIPANT	\N	PRESENT	0
229159	227892	19301E	PARTICIPANT	\N	PRESENT	0
229160	227892	19695N	PARTICIPANT	\N	PRESENT	0
229161	227892	11090Q	PRESIDENT	0	PRESENT	0
229162	227892	01025N	PARTICIPANT	\N	PRESENT	0
229163	227892	14033T	PARTICIPANT	\N	PRESENT	0
229164	227892	19269X	PARTICIPANT	\N	PRESENT	0
229165	227892	14205J	PARTICIPANT	\N	PRESENT	0
229166	227892	04088S	PARTICIPANT	\N	PRESENT	0
229167	227892	04089T	PARTICIPANT	\N	PRESENT	0
229168	227892	14115H	PARTICIPANT	\N	PRESENT	0
229169	227892	11101A	PARTICIPANT	\N	PRESENT	0
229170	227892	19507S	PARTICIPANT	\N	PRESENT	0
229171	227892	14207L	PARTICIPANT	\N	PRESENT	0
229172	227892	04043D	PARTICIPANT	\N	PRESENT	0
229173	227892	19619A	PARTICIPANT	\N	PRESENT	0
229174	227892	17589D	PARTICIPANT	\N	PRESENT	0
229175	227892	14257W	PARTICIPANT	\N	PRESENT	0
229176	227892	08068F	PARTICIPANT	\N	PRESENT	0
229177	228463	11085T	PARTICIPANT	\N	PRESENT	0
229184	228463	11072N	PARTICIPANT	\N	PRESENT	0
229185	228463	14275Y	PARTICIPANT	\N	PRESENT	0
229186	227662	10006L	PARTICIPANT	\N	PRESENT	0
229187	227662	19577H	PARTICIPANT	\N	EXCUSE	0
229338	227827	19711U	PARTICIPANT	\N	PRESENT	0
229446	228464	14231L	PARTICIPANT	\N	EXCUSE	0
229454	228464	14089Y	PARTICIPANT	\N	PRESENT	0
229516	229514	19533U	PARTICIPANT	\N	PRESENT	0
229513	229511	14123H	PARTICIPANT	\N	PRESENT	0
229515	229514	14123H	PARTICIPANT	\N	PRESENT	0
229518	229517	14123H	PARTICIPANT	\N	PRESENT	0
229519	229517	19533U	PARTICIPANT	\N	PRESENT	0
229520	229517	19399H	PARTICIPANT	\N	PRESENT	0
229522	229521	14123H	PARTICIPANT	\N	PRESENT	0
229523	229521	19533U	PARTICIPANT	\N	PRESENT	0
229606	229605	11104D	PARTICIPANT	\N	PRESENT	0
229608	229605	87003B	PARTICIPANT	\N	PRESENT	0
229664	229663	04059M	PARTICIPANT	\N	PRESENT	0
229665	229663	11040E	PARTICIPANT	\N	PRESENT	0
229666	229663	14053L	PARTICIPANT	\N	PRESENT	0
229667	229663	11053K	PARTICIPANT	\N	PRESENT	0
229668	229663	04086Q	PARTICIPANT	\N	PRESENT	0
229669	229663	08052W	PARTICIPANT	\N	PRESENT	0
229670	229663	11070L	PARTICIPANT	\N	PRESENT	0
229671	229663	10006L	PARTICIPANT	\N	PRESENT	0
229672	229663	14041T	PARTICIPANT	\N	PRESENT	0
229673	229663	04089T	PARTICIPANT	\N	PRESENT	0
229674	229663	14034U	PARTICIPANT	\N	PRESENT	0
229675	229663	11064N	PARTICIPANT	\N	PRESENT	0
229676	229663	14081Q	PARTICIPANT	\N	PRESENT	0
229677	229663	14241N	PARTICIPANT	\N	PRESENT	0
229678	229663	14061L	PARTICIPANT	\N	PRESENT	0
229679	229663	14159V	PARTICIPANT	\N	PRESENT	0
229680	229663	86034E	PARTICIPANT	\N	PRESENT	0
229681	229663	12016W	PARTICIPANT	\N	PRESENT	0
229682	229663	11072N	PARTICIPANT	\N	PRESENT	0
229683	229663	05012A	PARTICIPANT	\N	PRESENT	0
229684	229663	14135M	PARTICIPANT	\N	PRESENT	0
229685	229663	04044E	PARTICIPANT	\N	PRESENT	0
229751	218448	14121F	PARTICIPANT	\N	PRESENT	0
230028	230027	01048V	PARTICIPANT	\N	PRESENT	0
230029	230027	08018U	PARTICIPANT	\N	PRESENT	0
230030	230027	11026G	PARTICIPANT	\N	PRESENT	0
230031	230027	14079W	PARTICIPANT	\N	PRESENT	0
230032	230027	19573D	PARTICIPANT	\N	PRESENT	0
230035	230027	98035U	PARTICIPANT	\N	PRESENT	0
230036	230027	08052W	PARTICIPANT	\N	PRESENT	0
230038	230027	19521Q	PARTICIPANT	\N	PRESENT	0
230056	230055	08024S	PARTICIPANT	\N	PRESENT	0
230057	230055	02002K	PARTICIPANT	\N	PRESENT	0
230058	230055	19551W	PARTICIPANT	\N	PRESENT	0
230059	230055	19349W	PARTICIPANT	\N	PRESENT	0
230060	230055	19737F	PARTICIPANT	\N	PRESENT	0
230115	230114	11104D	PARTICIPANT	\N	PRESENT	0
230116	230114	87003B	PARTICIPANT	\N	PRESENT	0
230372	220060	04043D	PARTICIPANT	\N	PRESENT	0
230373	220060	19737F	PARTICIPANT	\N	PRESENT	0
230374	220060	14205J	PARTICIPANT	\N	PRESENT	0
230375	220060	19699S	PARTICIPANT	\N	PRESENT	0
230376	220060	19721W	PARTICIPANT	\N	PRESENT	0
230377	220060	16685X	PARTICIPANT	\N	PRESENT	0
230378	220060	19583F	PARTICIPANT	\N	PRESENT	0
230379	220060	19575F	PARTICIPANT	\N	PRESENT	0
230380	220060	19735D	PARTICIPANT	\N	PRESENT	0
230381	220060	19569H	PARTICIPANT	\N	PRESENT	0
230382	220060	14219Q	PARTICIPANT	\N	PRESENT	0
230383	220060	04089T	PARTICIPANT	\N	PRESENT	0
230384	220060	19479G	PARTICIPANT	\N	PRESENT	0
230385	220060	19441R	PARTICIPANT	\N	PRESENT	0
230386	220060	14275Y	PARTICIPANT	\N	PRESENT	0
230387	220060	19319Q	PARTICIPANT	\N	PRESENT	0
230388	220060	19383Y	PARTICIPANT	\N	PRESENT	0
230389	220060	19713W	PARTICIPANT	\N	PRESENT	0
230390	220060	01043Q	PARTICIPANT	\N	PRESENT	0
230391	220060	08056B	PARTICIPANT	\N	PRESENT	0
230392	220060	01025N	PARTICIPANT	\N	PRESENT	0
230393	220060	14327T	PARTICIPANT	\N	PRESENT	0
230394	220060	01024M	PARTICIPANT	\N	PRESENT	0
230395	220060	14073Q	PARTICIPANT	\N	PRESENT	0
230396	220060	14083S	PARTICIPANT	\N	PRESENT	0
230397	220060	08031R	PARTICIPANT	\N	PRESENT	0
230398	220060	19581D	PARTICIPANT	\N	PRESENT	0
230399	220060	14267Y	PARTICIPANT	\N	PRESENT	0
230400	220060	14237S	PARTICIPANT	\N	PRESENT	0
230401	220060	14103D	PARTICIPANT	\N	PRESENT	0
230402	220060	14221J	PARTICIPANT	\N	PRESENT	0
230403	220060	19663E	PARTICIPANT	\N	PRESENT	0
230404	220060	19739H	PARTICIPANT	\N	PRESENT	0
230405	220060	19467C	PARTICIPANT	\N	PRESENT	0
230406	220060	19643A	PARTICIPANT	\N	PRESENT	0
230407	220060	04044E	PARTICIPANT	\N	PRESENT	0
230408	220060	10015M	PARTICIPANT	\N	PRESENT	0
230409	220060	19549D	PARTICIPANT	\N	PRESENT	0
230410	220060	14249W	PARTICIPANT	\N	PRESENT	0
230411	220060	14087W	PARTICIPANT	\N	PRESENT	0
230412	220060	19657G	PARTICIPANT	\N	PRESENT	0
230413	220060	08073C	PARTICIPANT	\N	PRESENT	0
230414	220060	05012A	PARTICIPANT	\N	PRESENT	0
212118	212117	14133K	PARTICIPANT	\N	EXCUSE	0
212119	212117	96004D	PRESIDENT	0	PRESENT	0
212120	212117	14089Y	PARTICIPANT	\N	PRESENT	0
212121	212117	14079W	PARTICIPANT	\N	PRESENT	0
212122	212117	14249W	PARTICIPANT	\N	PRESENT	0
212123	212117	11083R	PARTICIPANT	\N	PRESENT	0
212124	212117	14357A	PARTICIPANT	\N	PRESENT	0
212125	212117	14033T	PARTICIPANT	\N	PRESENT	0
212126	212117	19553Y	PARTICIPANT	\N	PRESENT	0
212127	212117	19725B	PARTICIPANT	\N	PRESENT	0
212128	212117	95037J	PARTICIPANT	\N	PRESENT	0
212129	212117	08044W	PARTICIPANT	\N	PRESENT	0
212130	212117	14097Y	PARTICIPANT	\N	PRESENT	0
212131	212117	14073Q	PARTICIPANT	\N	PRESENT	0
212132	212117	11026G	PARTICIPANT	\N	PRESENT	0
212133	212117	08039A	PARTICIPANT	\N	PRESENT	0
212134	212117	14205J	PARTICIPANT	\N	PRESENT	0
212135	212117	14001X	PARTICIPANT	\N	PRESENT	0
212136	212117	14221J	PARTICIPANT	\N	PRESENT	0
212137	212117	04057K	PARTICIPANT	\N	PRESENT	0
212138	212117	19563B	PARTICIPANT	\N	PRESENT	0
212139	212117	19335Q	PARTICIPANT	\N	PRESENT	0
212140	212117	19593H	PARTICIPANT	\N	PRESENT	0
212141	212117	14229S	PARTICIPANT	\N	PRESENT	0
212142	212117	98035U	PARTICIPANT	\N	PRESENT	0
213408	213249	19543W	PARTICIPANT	\N	PRESENT	0
213409	213249	04044E	PARTICIPANT	\N	PRESENT	0
213410	213249	19585H	PARTICIPANT	\N	PRESENT	0
213411	213249	19447X	PARTICIPANT	\N	PRESENT	0
213412	213249	14147R	PARTICIPANT	\N	PRESENT	0
213413	213249	14179A	PARTICIPANT	\N	PRESENT	0
213414	213249	14215L	PARTICIPANT	\N	PRESENT	0
213415	213249	08018U	PARTICIPANT	\N	PRESENT	0
213416	213249	19483C	PARTICIPANT	\N	PRESENT	0
213417	213249	14053L	PARTICIPANT	\N	PRESENT	0
213418	213249	14111D	PARTICIPANT	\N	PRESENT	0
213419	213249	11010L	PARTICIPANT	\N	PRESENT	0
213420	213249	11026G	PARTICIPANT	\N	PRESENT	0
213421	213249	08045X	PARTICIPANT	\N	PRESENT	0
213422	213249	19253P	PARTICIPANT	\N	PRESENT	0
213423	213249	01024M	PARTICIPANT	\N	PRESENT	0
213424	213249	04038G	PARTICIPANT	\N	PRESENT	0
213425	213249	19729F	PARTICIPANT	\N	PRESENT	0
213426	213249	14069U	PARTICIPANT	\N	PRESENT	0
213427	213249	11049P	PARTICIPANT	\N	PRESENT	0
213428	213249	14065Q	PARTICIPANT	\N	EXCUSE	0
213429	213249	19673G	PARTICIPANT	\N	EXCUSE	0
213430	213249	19719D	PARTICIPANT	\N	EXCUSE	0
213431	213249	14021P	PARTICIPANT	\N	EXCUSE	0
213438	213049	14327T	PARTICIPANT	\N	PRESENT	0
213439	213049	14331P	PARTICIPANT	\N	PRESENT	0
213440	213049	95041E	PARTICIPANT	\N	PRESENT	0
213441	213049	01048V	PARTICIPANT	\N	PRESENT	0
213442	213049	19545Y	PARTICIPANT	\N	PRESENT	0
213443	213049	01057W	PARTICIPANT	\N	PRESENT	0
213444	213049	11074Q	PRESIDENT	0	PRESENT	0
213445	213049	19667J	PARTICIPANT	\N	PRESENT	0
213446	213049	19671E	PARTICIPANT	\N	PRESENT	0
213447	213049	88008L	PARTICIPANT	\N	PRESENT	0
213448	213049	11070L	PARTICIPANT	\N	PRESENT	0
213449	213049	07029T	PARTICIPANT	\N	PRESENT	0
213450	213049	14277B	PARTICIPANT	\N	PRESENT	0
213451	213049	07004J	PARTICIPANT	\N	PRESENT	0
213452	213049	19349W	PARTICIPANT	\N	PRESENT	0
213453	213049	08010L	PARTICIPANT	\N	PRESENT	0
213454	213049	14253S	PARTICIPANT	\N	PRESENT	0
213455	213049	11048N	PARTICIPANT	\N	PRESENT	0
213456	213049	19711U	PARTICIPANT	\N	PRESENT	0
213457	213049	19651A	PARTICIPANT	\N	PRESENT	0
213458	213049	08034U	PARTICIPANT	\N	PRESENT	0
213459	213049	19689Q	PARTICIPANT	\N	PRESENT	0
213460	213049	12016W	PARTICIPANT	\N	PRESENT	0
213461	213049	08011M	PARTICIPANT	\N	PRESENT	0
213462	213049	14034U	PARTICIPANT	\N	PRESENT	0
213463	213049	08014Q	PARTICIPANT	\N	PRESENT	0
213464	213049	14159V	PARTICIPANT	\N	PRESENT	0
213465	213049	14173T	PARTICIPANT	\N	PRESENT	0
213466	213049	04086Q	PARTICIPANT	\N	EXCUSE	0
213467	213049	14083S	PARTICIPANT	\N	PRESENT	0
213468	213049	14121F	PARTICIPANT	\N	PRESENT	0
213469	213049	99004R	PARTICIPANT	\N	PRESENT	0
213470	213049	04061F	PARTICIPANT	\N	EXCUSE	0
213471	213049	11040E	PARTICIPANT	\N	PRESENT	0
213472	213049	04071H	PARTICIPANT	\N	PRESENT	0
213473	213049	14199E	PARTICIPANT	\N	PRESENT	0
213474	213049	11012A	PARTICIPANT	\N	PRESENT	0
213475	213049	08069G	PARTICIPANT	\N	PRESENT	0
213478	213276	14355X	PARTICIPANT	\N	EXCUSE	0
213479	213276	14281W	PARTICIPANT	\N	EXCUSE	0
213480	213276	08041T	PARTICIPANT	\N	PRESENT	0
213490	207693	04044E	PARTICIPANT	\N	PRESENT	0
213491	207693	19507S	PARTICIPANT	\N	PRESENT	0
213492	207693	95015C	PARTICIPANT	\N	PRESENT	0
213493	207693	19525U	PARTICIPANT	\N	PRESENT	0
213494	207693	19467C	PARTICIPANT	\N	PRESENT	0
213495	207693	14215L	PARTICIPANT	\N	PRESENT	0
213496	207693	07034Q	PARTICIPANT	\N	PRESENT	0
213497	207693	14179A	PARTICIPANT	\N	PRESENT	0
213498	207693	19715Y	PARTICIPANT	\N	PRESENT	0
213499	207693	19399H	PARTICIPANT	\N	PRESENT	0
213500	207693	19387D	PARTICIPANT	\N	PRESENT	0
213501	207693	08028W	PARTICIPANT	\N	PRESENT	0
213502	207693	19515S	PARTICIPANT	\N	PRESENT	0
213503	207693	19575F	PARTICIPANT	\N	PRESENT	0
213504	207693	19447X	PARTICIPANT	\N	PRESENT	0
213505	207693	19709B	PARTICIPANT	\N	PRESENT	0
213506	207693	19503N	PARTICIPANT	\N	PRESENT	0
213507	207693	19585H	PARTICIPANT	\N	PRESENT	0
213508	207693	19699S	PARTICIPANT	\N	PRESENT	0
213509	207693	19599P	PARTICIPANT	\N	PRESENT	0
213510	207693	14211G	PARTICIPANT	\N	PRESENT	0
213511	207693	04088S	PARTICIPANT	\N	PRESENT	0
214073	207696	19715Y	PARTICIPANT	\N	PRESENT	0
214074	207696	08045X	PARTICIPANT	\N	PRESENT	0
214075	207696	14215L	PARTICIPANT	\N	PRESENT	0
214076	207696	19651A	PARTICIPANT	\N	PRESENT	0
214077	207696	04038G	PARTICIPANT	\N	PRESENT	0
214078	207696	19599P	PARTICIPANT	\N	PRESENT	0
214079	207696	19319Q	PARTICIPANT	\N	PRESENT	0
214080	207696	19713W	PARTICIPANT	\N	PRESENT	0
214081	207696	08031R	PARTICIPANT	\N	PRESENT	0
214082	207696	19691J	PARTICIPANT	\N	PRESENT	0
214083	207696	19737F	PARTICIPANT	\N	PRESENT	0
214084	207696	01024M	PARTICIPANT	\N	PRESENT	0
214085	207696	19543W	PARTICIPANT	\N	PRESENT	0
214086	207696	14221J	PARTICIPANT	\N	PRESENT	0
214087	207696	95015C	PARTICIPANT	\N	PRESENT	0
214088	207696	14187A	PARTICIPANT	\N	PRESENT	0
214089	207696	19399H	PARTICIPANT	\N	PRESENT	0
214090	207696	19289C	PARTICIPANT	\N	PRESENT	0
214091	207696	14237S	PARTICIPANT	\N	PRESENT	0
214092	207696	19581D	PARTICIPANT	\N	PRESENT	0
214093	207696	14069U	PARTICIPANT	\N	PRESENT	0
214094	207696	19443T	PARTICIPANT	\N	PRESENT	0
214095	207696	14251Q	PARTICIPANT	\N	PRESENT	0
214096	207696	14257W	PARTICIPANT	\N	PRESENT	0
214097	207696	19565D	PARTICIPANT	\N	PRESENT	0
214098	207696	19703U	PARTICIPANT	\N	PRESENT	0
214099	207696	04070G	PARTICIPANT	\N	PRESENT	0
214100	207696	11026G	PARTICIPANT	\N	PRESENT	0
214101	207696	19729F	PARTICIPANT	\N	PRESENT	0
214102	207696	19575F	PARTICIPANT	\N	PRESENT	0
214103	207696	14083S	PARTICIPANT	\N	PRESENT	0
214448	207696	11012A	PARTICIPANT	\N	PRESENT	0
214449	207696	14061L	PARTICIPANT	\N	PRESENT	0
214450	207696	17583W	PARTICIPANT	\N	PRESENT	0
214451	207696	14211G	PARTICIPANT	\N	PRESENT	0
214452	207696	19251M	PARTICIPANT	\N	PRESENT	0
214453	207696	14034U	PARTICIPANT	\N	PRESENT	0
214454	207696	19349W	PARTICIPANT	\N	PRESENT	0
214455	207696	19697Q	PARTICIPANT	\N	PRESENT	0
214456	207696	19629C	PARTICIPANT	\N	PRESENT	0
214071	207696	04044E	PARTICIPANT	\N	PRESENT	0
214457	207696	19421M	PARTICIPANT	\N	PRESENT	0
214458	207696	14073Q	PARTICIPANT	\N	PRESENT	0
214459	207696	04097T	PARTICIPANT	\N	PRESENT	0
214460	207696	07029T	PARTICIPANT	\N	PRESENT	0
214461	207696	19631V	PARTICIPANT	\N	PRESENT	0
214462	207696	19573D	PARTICIPANT	\N	PRESENT	0
214463	207696	14219Q	PARTICIPANT	\N	PRESENT	0
214464	207696	19483C	PARTICIPANT	\N	PRESENT	0
214465	207696	16685X	PARTICIPANT	\N	PRESENT	0
214466	207696	19735D	PARTICIPANT	\N	PRESENT	0
214467	207696	14231L	PARTICIPANT	\N	PRESENT	0
214468	207696	08061X	PARTICIPANT	\N	PRESENT	0
214469	207696	19593H	PARTICIPANT	\N	PRESENT	0
214470	207696	19709B	PARTICIPANT	\N	PRESENT	0
214471	207696	19663E	PARTICIPANT	\N	PRESENT	0
214072	207696	07034Q	PARTICIPANT	\N	PRESENT	0
223252	218281	01028R	PARTICIPANT	\N	PRESENT	0
223253	218281	96004D	PARTICIPANT	\N	PRESENT	0
223264	218281	11097X	PARTICIPANT	\N	PRESENT	0
223267	218281	19705W	PARTICIPANT	\N	PRESENT	0
223268	218281	07004J	PARTICIPANT	\N	PRESENT	0
223269	218281	11012A	PARTICIPANT	\N	PRESENT	0
223270	218281	14034U	PARTICIPANT	\N	PRESENT	0
223271	218281	19503N	PARTICIPANT	\N	PRESENT	0
223273	218281	19483C	PARTICIPANT	\N	PRESENT	0
223274	218281	14327T	PARTICIPANT	\N	PRESENT	0
223275	218281	14121F	PARTICIPANT	\N	PRESENT	0
223276	218281	14107H	PARTICIPANT	\N	PRESENT	0
223277	218281	98035U	PARTICIPANT	\N	PRESENT	0
223278	218281	08016S	PARTICIPANT	\N	PRESENT	0
223279	218281	11083R	PARTICIPANT	\N	PRESENT	0
223281	218281	01048V	PARTICIPANT	\N	PRESENT	0
223282	218281	04057K	PARTICIPANT	\N	PRESENT	0
223283	218281	08010L	PARTICIPANT	\N	PRESENT	0
223284	218281	14231L	PARTICIPANT	\N	PRESENT	0
223286	223285	08009T	PARTICIPANT	\N	PRESENT	0
223287	218283	14147R	PARTICIPANT	\N	PRESENT	0
223616	223615	10015M	PARTICIPANT	\N	PRESENT	0
223618	223617	10015M	PARTICIPANT	\N	PRESENT	0
223620	223619	10015M	PARTICIPANT	\N	PRESENT	0
223688	218821	19467C	PARTICIPANT	\N	EXCUSE	0
223835	223289	08048B	PARTICIPANT	\N	EXCUSE	0
223836	223289	04092N	PARTICIPANT	\N	PRESENT	0
223837	223289	11097X	PARTICIPANT	\N	PRESENT	0
223838	223289	08052W	PARTICIPANT	\N	PRESENT	0
223839	223289	19715Y	PARTICIPANT	\N	PRESENT	0
223840	223289	04045F	PARTICIPANT	\N	PRESENT	0
223841	223289	17779H	PARTICIPANT	\N	PRESENT	0
223842	223289	19727D	PARTICIPANT	\N	PRESENT	0
223843	223289	14119M	PARTICIPANT	\N	PRESENT	0
223844	223289	14087W	PARTICIPANT	\N	PRESENT	0
223845	223289	14281W	PARTICIPANT	\N	PRESENT	0
223846	223289	19575F	PARTICIPANT	\N	PRESENT	0
223847	223289	19367Y	PARTICIPANT	\N	PRESENT	0
223848	223289	19657G	PARTICIPANT	\N	PRESENT	0
223849	223289	14071N	PARTICIPANT	\N	PRESENT	0
223850	223289	19577H	PARTICIPANT	\N	PRESENT	0
223851	223289	19697Q	PARTICIPANT	\N	PRESENT	0
223852	223289	08041T	PARTICIPANT	\N	EXCUSE	0
223853	223289	11045K	PARTICIPANT	\N	PRESENT	0
223854	223289	14042U	PARTICIPANT	\N	PRESENT	0
223855	223289	14195A	PARTICIPANT	\N	PRESENT	0
223856	223289	19679N	PARTICIPANT	\N	PRESENT	0
223857	223289	14223L	PARTICIPANT	\N	PRESENT	0
223891	223890	08049C	PARTICIPANT	\N	PRESENT	0
224054	223980	14327T	PARTICIPANT	\N	PRESENT	0
224055	223980	14331P	PARTICIPANT	\N	PRESENT	0
224056	223980	19545Y	PARTICIPANT	\N	PRESENT	0
224057	223980	01057W	PARTICIPANT	\N	PRESENT	0
224058	223980	11074Q	PRESIDENT	0	PRESENT	0
224059	223980	19667J	PARTICIPANT	\N	PRESENT	0
224060	223980	14225N	PARTICIPANT	\N	PRESENT	0
224061	223980	19671E	PARTICIPANT	\N	PRESENT	0
224062	223980	07029T	PARTICIPANT	\N	PRESENT	0
224063	223980	14085U	PARTICIPANT	\N	PRESENT	0
224064	223980	19349W	PARTICIPANT	\N	PRESENT	0
224065	223980	19479G	PARTICIPANT	\N	PRESENT	0
224066	223980	19711U	PARTICIPANT	\N	PRESENT	0
224067	223980	19531S	PARTICIPANT	\N	PRESENT	0
224068	223980	19651A	PARTICIPANT	\N	PRESENT	0
224069	223980	08034U	PARTICIPANT	\N	PRESENT	0
224070	223980	19689Q	PARTICIPANT	\N	PRESENT	0
224071	223980	08011M	PARTICIPANT	\N	PRESENT	0
224072	223980	08014Q	PARTICIPANT	\N	PRESENT	0
224073	223980	04086Q	PARTICIPANT	\N	PRESENT	0
224074	223980	11040E	PARTICIPANT	\N	PRESENT	0
224075	223980	14083S	PARTICIPANT	\N	PRESENT	0
224076	223980	08073C	PARTICIPANT	\N	PRESENT	0
224077	223980	14121F	PARTICIPANT	\N	PRESENT	0
224078	223980	99004R	PARTICIPANT	\N	PRESENT	0
224079	223980	95041E	PARTICIPANT	\N	EXCUSE	0
224080	218295	19585H	PARTICIPANT	\N	PRESENT	0
224081	218295	95063L	PARTICIPANT	\N	PRESENT	0
224082	218295	14197C	PARTICIPANT	\N	PRESENT	0
224083	218295	11097X	PARTICIPANT	\N	PRESENT	0
224084	218295	04097T	PARTICIPANT	\N	PRESENT	0
224085	218295	11101A	PARTICIPANT	\N	PRESENT	0
224086	218295	19329S	PARTICIPANT	\N	PRESENT	0
224087	218295	19533U	PARTICIPANT	\N	PRESENT	0
224088	218295	19679N	PARTICIPANT	\N	PRESENT	0
224089	218295	08020N	PARTICIPANT	\N	PRESENT	0
224090	218295	19693L	PARTICIPANT	\N	PRESENT	0
224091	223980	89017R	PARTICIPANT	\N	PRESENT	0
224092	223980	11070L	PARTICIPANT	\N	PRESENT	0
224093	223980	14199E	PARTICIPANT	\N	PRESENT	0
224094	218295	14026U	PARTICIPANT	\N	PRESENT	0
224095	218295	14217N	PARTICIPANT	\N	PRESENT	0
224096	218295	04049K	PARTICIPANT	\N	PRESENT	0
224097	222532	08038Y	PARTICIPANT	\N	EXCUSE	0
224098	218295	14105F	PARTICIPANT	\N	PRESENT	0
224099	218295	04018C	PARTICIPANT	\N	PRESENT	0
224100	218295	01057W	PARTICIPANT	\N	PRESENT	0
224101	218295	14199E	PARTICIPANT	\N	PRESENT	0
224102	218295	19399H	PARTICIPANT	\N	PRESENT	0
224103	218295	11070L	PARTICIPANT	\N	PRESENT	0
224104	218295	14083S	PARTICIPANT	\N	PRESENT	0
224105	218295	14259Y	PARTICIPANT	\N	PRESENT	0
224106	218295	14031R	PARTICIPANT	\N	PRESENT	0
224107	218295	11110B	PARTICIPANT	\N	PRESENT	0
224108	218295	14001X	PARTICIPANT	\N	PRESENT	0
224109	218295	14030Q	PARTICIPANT	\N	PRESENT	0
224110	218295	19691J	PARTICIPANT	\N	PRESENT	0
224111	218295	11012A	PARTICIPANT	\N	PRESENT	0
224113	218295	04038G	PARTICIPANT	\N	PRESENT	0
224114	218295	14229S	PARTICIPANT	\N	PRESENT	0
224115	218295	14111D	PARTICIPANT	\N	PRESENT	0
224116	218295	19581D	PARTICIPANT	\N	PRESENT	0
224117	218295	17779H	PARTICIPANT	\N	PRESENT	0
224118	218295	19503N	PARTICIPANT	\N	PRESENT	0
224119	218295	08017T	PARTICIPANT	\N	PRESENT	0
224120	218295	08014Q	PARTICIPANT	\N	PRESENT	0
224121	218295	19549D	PARTICIPANT	\N	PRESENT	0
224122	218295	14251Q	PARTICIPANT	\N	PRESENT	0
224123	218295	08016S	PARTICIPANT	\N	PRESENT	0
224124	218295	11077T	PARTICIPANT	\N	PRESENT	0
224125	218295	11048N	PARTICIPANT	\N	PRESENT	0
224126	218295	10006L	PARTICIPANT	\N	PRESENT	0
224127	218295	19741B	PARTICIPANT	\N	PRESENT	0
224128	218295	01025N	PARTICIPANT	\N	PRESENT	0
224129	218295	88008L	PARTICIPANT	\N	PRESENT	0
224130	218295	19695N	PARTICIPANT	\N	PRESENT	0
224131	218295	89017R	PARTICIPANT	\N	PRESENT	0
224132	218295	98029W	PARTICIPANT	\N	PRESENT	0
224133	218295	14097Y	PARTICIPANT	\N	PRESENT	0
224134	218295	80013X	PARTICIPANT	\N	PRESENT	0
224135	218295	14207L	PARTICIPANT	\N	PRESENT	0
224136	218295	19699S	PARTICIPANT	\N	PRESENT	0
224137	218295	08043V	PARTICIPANT	\N	PRESENT	0
224138	218295	14034U	PARTICIPANT	\N	PRESENT	0
224139	218295	14213J	PARTICIPANT	\N	PRESENT	0
224140	218295	08024S	PARTICIPANT	\N	PRESENT	0
224141	218295	14093U	PARTICIPANT	\N	PRESENT	0
224142	218295	19527W	PARTICIPANT	\N	PRESENT	0
224143	218295	95067Q	PARTICIPANT	\N	PRESENT	0
224144	218295	19575F	PARTICIPANT	\N	PRESENT	0
224145	218295	14147R	PARTICIPANT	\N	PRESENT	0
224146	218295	08049C	PARTICIPANT	\N	PRESENT	0
224147	218295	19647E	PARTICIPANT	\N	PRESENT	0
224148	218295	11045K	PARTICIPANT	\N	PRESENT	0
224149	218295	08031R	PARTICIPANT	\N	PRESENT	0
224150	218295	14249W	PARTICIPANT	\N	PRESENT	0
224151	218295	11090Q	PARTICIPANT	\N	PRESENT	0
224152	218295	14021P	PARTICIPANT	\N	PRESENT	0
224153	218295	19543W	PARTICIPANT	\N	PRESENT	0
224154	218295	14063N	PARTICIPANT	\N	PRESENT	0
224155	218295	08015R	PARTICIPANT	\N	PRESENT	0
224156	218295	04047H	PARTICIPANT	\N	PRESENT	0
224157	218295	01028R	PARTICIPANT	\N	PRESENT	0
224158	218295	19733B	PARTICIPANT	\N	PRESENT	0
224159	218295	11026G	PARTICIPANT	\N	PRESENT	0
224160	218295	08045X	PARTICIPANT	\N	PRESENT	0
224161	218295	08073C	PARTICIPANT	\N	PRESENT	0
224162	218295	08021P	PARTICIPANT	\N	PRESENT	0
224163	218295	01048V	PARTICIPANT	\N	PRESENT	0
224164	218295	14028W	PARTICIPANT	\N	PRESENT	0
224165	218295	14055N	PARTICIPANT	\N	PRESENT	0
224166	218295	04092N	PARTICIPANT	\N	PRESENT	0
224167	218295	19563B	PARTICIPANT	\N	PRESENT	0
224168	218295	19611R	PARTICIPANT	\N	PRESENT	0
224169	218295	01058X	PARTICIPANT	\N	PRESENT	0
224170	218295	11104D	PARTICIPANT	\N	PRESENT	0
224171	218295	04085P	PARTICIPANT	\N	PRESENT	0
224172	218295	04034C	PARTICIPANT	\N	PRESENT	0
224173	218295	19715Y	PARTICIPANT	\N	PRESENT	0
224174	218295	19569H	PARTICIPANT	\N	PRESENT	0
214495	214494	11053K	PARTICIPANT	\N	PRESENT	0
214496	214494	14159V	PARTICIPANT	\N	PRESENT	0
214497	214494	05012A	PARTICIPANT	\N	PRESENT	0
214502	214501	14039A	PARTICIPANT	\N	PRESENT	0
214504	214503	14073Q	PARTICIPANT	\N	PRESENT	0
214505	214503	08017T	PARTICIPANT	\N	PRESENT	0
214507	214506	14229S	PARTICIPANT	\N	PRESENT	0
214509	214508	14229S	PARTICIPANT	\N	PRESENT	0
214511	214510	14123H	PARTICIPANT	\N	PRESENT	0
214513	214512	19693L	PARTICIPANT	\N	PRESENT	0
214515	214514	14087W	PARTICIPANT	\N	PRESENT	0
214517	214516	14087W	PARTICIPANT	\N	PRESENT	0
214519	214518	14087W	PARTICIPANT	\N	PRESENT	0
214521	214520	14087W	PARTICIPANT	\N	PRESENT	0
215406	214719	08017T	PARTICIPANT	\N	PRESENT	0
215407	214719	92040Q	PARTICIPANT	\N	PRESENT	0
215408	214719	07033P	PARTICIPANT	\N	PRESENT	0
215409	214719	08016S	PARTICIPANT	\N	PRESENT	0
215410	214719	14249W	PARTICIPANT	\N	PRESENT	0
215411	214719	19593H	PARTICIPANT	\N	PRESENT	0
215412	214719	19643A	PARTICIPANT	\N	PRESENT	0
215413	214719	14061L	PARTICIPANT	\N	PRESENT	0
215414	214719	14073Q	PARTICIPANT	\N	PRESENT	0
215415	214719	08035V	PARTICIPANT	\N	PRESENT	0
215416	214719	08043V	PARTICIPANT	\N	PRESENT	0
215417	214719	19693L	PARTICIPANT	\N	PRESENT	0
215418	214719	19399H	PARTICIPANT	\N	PRESENT	0
215419	214719	87003B	PARTICIPANT	\N	PRESENT	0
215420	214719	14201E	PARTICIPANT	\N	PRESENT	0
215421	214719	14030Q	PARTICIPANT	\N	PRESENT	0
215422	214719	19731Y	PARTICIPANT	\N	PRESENT	0
215423	214719	08020N	PARTICIPANT	\N	PRESENT	0
215424	214719	04059M	PARTICIPANT	\N	PRESENT	0
215425	214719	11109J	PARTICIPANT	\N	PRESENT	0
215426	214719	14063N	PARTICIPANT	\N	PRESENT	0
215427	214719	14109K	PARTICIPANT	\N	PRESENT	0
215428	214719	11083R	PARTICIPANT	\N	PRESENT	0
215429	214719	14123H	PARTICIPANT	\N	PRESENT	0
215430	214719	11104D	PARTICIPANT	\N	PRESENT	0
215431	214719	11043H	PARTICIPANT	\N	PRESENT	0
215432	214719	04018C	PARTICIPANT	\N	PRESENT	0
215433	214719	19621T	PARTICIPANT	\N	PRESENT	0
215434	214719	14241N	PARTICIPANT	\N	EXCUSE	0
215435	214719	08031R	PARTICIPANT	\N	EXCUSE	0
215437	214549	11031D	PARTICIPANT	\N	PRESENT	0
215442	214493	14079W	PARTICIPANT	\N	PRESENT	0
215443	214493	11115U	PARTICIPANT	\N	PRESENT	0
215444	214493	08061X	PARTICIPANT	\N	PRESENT	0
215445	214493	95067Q	PARTICIPANT	\N	PRESENT	0
215450	214724	04070G	PRESIDENT	0	PRESENT	0
215451	214724	12041X	PARTICIPANT	\N	PRESENT	0
215452	214724	19533U	PARTICIPANT	\N	PRESENT	0
215453	214724	95015C	PARTICIPANT	\N	PRESENT	0
215454	214724	04033B	PARTICIPANT	\N	PRESENT	0
215455	214724	19329S	PARTICIPANT	\N	PRESENT	0
215456	214724	14229S	PARTICIPANT	\N	PRESENT	0
215457	214724	19573D	PARTICIPANT	\N	PRESENT	0
215458	214724	14039A	PARTICIPANT	\N	PRESENT	0
215459	214724	14107H	PARTICIPANT	\N	PRESENT	0
215460	214724	08017T	PARTICIPANT	\N	PRESENT	0
215461	214724	92040Q	PARTICIPANT	\N	PRESENT	0
215462	214724	07033P	PARTICIPANT	\N	PRESENT	0
215463	214724	08012N	PARTICIPANT	\N	PRESENT	0
215464	214724	08016S	PARTICIPANT	\N	PRESENT	0
215465	214724	14249W	PARTICIPANT	\N	PRESENT	0
215466	214724	19593H	PARTICIPANT	\N	PRESENT	0
215467	214724	19643A	PARTICIPANT	\N	PRESENT	0
215468	214724	14061L	PARTICIPANT	\N	PRESENT	0
215469	214724	04057K	PARTICIPANT	\N	PRESENT	0
215470	214724	08035V	PARTICIPANT	\N	PRESENT	0
215471	214724	08043V	PARTICIPANT	\N	PRESENT	0
215472	214724	19693L	PARTICIPANT	\N	PRESENT	0
215473	214724	87003B	PARTICIPANT	\N	PRESENT	0
215474	214724	19399H	PARTICIPANT	\N	PRESENT	0
215475	214724	14030Q	PARTICIPANT	\N	PRESENT	0
215476	214724	19731Y	PARTICIPANT	\N	PRESENT	0
215477	214724	08020N	PARTICIPANT	\N	PRESENT	0
215478	214724	14251Q	PARTICIPANT	\N	PRESENT	0
215479	214724	04059M	PARTICIPANT	\N	PRESENT	0
215480	214724	19735D	PARTICIPANT	\N	PRESENT	0
215481	214724	11109J	PARTICIPANT	\N	PRESENT	0
215482	214724	14063N	PARTICIPANT	\N	PRESENT	0
215483	214724	14109K	PARTICIPANT	\N	PRESENT	0
215484	214724	11083R	PARTICIPANT	\N	PRESENT	0
215485	214724	14123H	PARTICIPANT	\N	PRESENT	0
215486	214724	11043H	PARTICIPANT	\N	PRESENT	0
215487	214724	11104D	PARTICIPANT	\N	PRESENT	0
215488	214724	04018C	PARTICIPANT	\N	PRESENT	0
215489	214724	19621T	PARTICIPANT	\N	PRESENT	0
215490	214724	14073Q	PARTICIPANT	\N	PRESENT	0
215491	214724	14241N	PARTICIPANT	\N	EXCUSE	0
215492	214724	08031R	PARTICIPANT	\N	EXCUSE	0
215570	215569	11053K	PARTICIPANT	\N	PRESENT	0
215571	215569	14159V	PARTICIPANT	\N	PRESENT	0
215572	215569	05012A	PARTICIPANT	\N	PRESENT	0
215710	207702	19599P	PARTICIPANT	\N	PRESENT	0
215711	207702	14207L	PARTICIPANT	\N	PRESENT	0
215712	207702	19301E	PARTICIPANT	\N	PRESENT	0
215713	207702	19695N	PARTICIPANT	\N	PRESENT	0
215714	207702	19585H	PARTICIPANT	\N	PRESENT	0
215715	207702	11099A	PARTICIPANT	\N	PRESENT	0
215716	207702	19717B	PARTICIPANT	\N	PRESENT	0
215717	207702	11065P	PARTICIPANT	\N	PRESENT	0
215718	207702	19387D	PARTICIPANT	\N	PRESENT	0
215719	207702	19631V	PARTICIPANT	\N	PRESENT	0
215720	207702	19619A	PARTICIPANT	\N	PRESENT	0
215721	207702	19713W	PARTICIPANT	\N	PRESENT	0
215722	207702	19441R	PARTICIPANT	\N	PRESENT	0
215723	207702	19569H	PARTICIPANT	\N	PRESENT	0
215724	207702	19735D	PARTICIPANT	\N	PRESENT	0
215725	207702	14103D	PARTICIPANT	\N	PRESENT	0
215726	207702	19739H	PARTICIPANT	\N	PRESENT	0
215727	207702	01025N	PARTICIPANT	\N	PRESENT	0
215728	207702	08060W	PARTICIPANT	\N	PRESENT	0
215729	207702	19551W	PARTICIPANT	\N	PRESENT	0
215730	207702	80013X	PARTICIPANT	\N	PRESENT	0
215731	207702	14087W	PARTICIPANT	\N	PRESENT	0
215732	207702	04088S	PARTICIPANT	\N	PRESENT	0
215733	207702	19467C	PARTICIPANT	\N	PRESENT	0
215734	207702	19573D	PARTICIPANT	\N	PRESENT	0
215735	207702	18083K	PARTICIPANT	\N	PRESENT	0
215736	207702	14329V	PARTICIPANT	\N	PRESENT	0
215737	207702	19701S	PARTICIPANT	\N	PRESENT	0
215738	207702	04018C	PARTICIPANT	\N	PRESENT	0
215739	207702	14187A	PARTICIPANT	\N	PRESENT	0
215740	207702	19511N	PARTICIPANT	\N	PRESENT	0
215741	207702	08020N	PARTICIPANT	\N	PRESENT	0
215742	207702	19679N	PARTICIPANT	\N	PRESENT	0
215743	207702	14028W	PARTICIPANT	\N	PRESENT	0
215744	207702	19637C	PARTICIPANT	\N	PRESENT	0
215745	207702	08068F	PARTICIPANT	\N	PRESENT	0
215746	207702	19681G	PARTICIPANT	\N	PRESENT	0
215747	207702	19709B	PARTICIPANT	\N	PRESENT	0
215748	207702	14115H	PARTICIPANT	\N	PRESENT	0
215749	207702	95030B	PARTICIPANT	\N	PRESENT	0
215750	207702	19421M	PARTICIPANT	\N	PRESENT	0
215751	207702	19731Y	PARTICIPANT	\N	PRESENT	0
215752	207702	19575F	PARTICIPANT	\N	PRESENT	0
215753	207702	08024S	PARTICIPANT	\N	PRESENT	0
215754	207702	14089Y	PARTICIPANT	\N	PRESENT	0
215755	207702	19531S	PARTICIPANT	\N	PRESENT	0
215756	207702	19269X	PARTICIPANT	\N	PRESENT	0
215759	207702	14191V	PARTICIPANT	\N	PRESENT	0
215760	207702	19415P	PARTICIPANT	\N	PRESENT	0
215761	207702	14123H	PARTICIPANT	\N	PRESENT	0
215762	207702	19549D	PARTICIPANT	\N	PRESENT	0
215765	207702	14029X	PARTICIPANT	\N	PRESENT	0
215766	207702	14069U	PARTICIPANT	\N	PRESENT	0
215767	207702	11066Q	PARTICIPANT	\N	PRESENT	0
215771	207702	14259Y	PARTICIPANT	\N	PRESENT	0
215772	207702	14033T	PARTICIPANT	\N	PRESENT	0
215773	207702	14039A	PARTICIPANT	\N	PRESENT	0
215774	207702	14147R	PARTICIPANT	\N	PRESENT	0
215824	214588	14331P	PARTICIPANT	\N	PRESENT	0
215825	214588	19545Y	PARTICIPANT	\N	PRESENT	0
215826	214588	01057W	PARTICIPANT	\N	PRESENT	0
215827	214588	19667J	PARTICIPANT	\N	PRESENT	0
215828	214588	11074Q	PRESIDENT	0	PRESENT	0
215829	214588	89017R	PARTICIPANT	\N	PRESENT	0
215830	214588	14225N	PARTICIPANT	\N	PRESENT	0
215831	214588	19671E	PARTICIPANT	\N	PRESENT	0
215832	214588	07029T	PARTICIPANT	\N	PRESENT	0
215833	214588	14085U	PARTICIPANT	\N	PRESENT	0
215834	214588	19349W	PARTICIPANT	\N	PRESENT	0
215835	214588	08010L	PARTICIPANT	\N	PRESENT	0
215836	214588	19479G	PARTICIPANT	\N	PRESENT	0
215837	214588	11048N	PARTICIPANT	\N	PRESENT	0
215839	214588	19647E	PARTICIPANT	\N	PRESENT	0
230415	220060	11077T	PARTICIPANT	\N	PRESENT	0
230416	220060	11056N	PARTICIPANT	\N	PRESENT	0
230417	220060	17589D	PARTICIPANT	\N	PRESENT	0
230423	220060	19671E	PARTICIPANT	\N	PRESENT	0
230419	220060	04088S	PARTICIPANT	\N	PRESENT	0
230420	220060	19669L	PARTICIPANT	\N	PRESENT	0
230421	220060	02002K	PARTICIPANT	\N	PRESENT	0
230422	220060	14255U	PARTICIPANT	\N	PRESENT	0
230424	220060	14029X	PARTICIPANT	\N	PRESENT	0
230425	220060	08009T	PARTICIPANT	\N	PRESENT	0
230426	220060	14115H	PARTICIPANT	\N	PRESENT	0
230427	220060	19707Y	PARTICIPANT	\N	PRESENT	0
230428	220060	19705W	PARTICIPANT	\N	PRESENT	0
230429	220060	19543W	PARTICIPANT	\N	PRESENT	0
230430	220060	11026G	PARTICIPANT	\N	PRESENT	0
230431	220060	11085T	PARTICIPANT	\N	PRESENT	0
230433	220060	11065P	PARTICIPANT	\N	PRESENT	0
230434	230432	89017R	PARTICIPANT	\N	PRESENT	0
230435	230432	19651A	PARTICIPANT	\N	PRESENT	0
230436	230432	19667J	PARTICIPANT	\N	PRESENT	0
230437	230432	11040E	PARTICIPANT	\N	PRESENT	0
230449	230432	11074Q	PRESIDENT	0	PRESENT	0
230439	230432	14083S	PARTICIPANT	\N	PRESENT	0
230440	230432	11053K	PARTICIPANT	\N	PRESENT	0
230441	230432	19545Y	PARTICIPANT	\N	PRESENT	0
230442	230432	14085U	PARTICIPANT	\N	PRESENT	0
230443	230432	88008L	PARTICIPANT	\N	PRESENT	0
230444	230432	04086Q	PARTICIPANT	\N	PRESENT	0
230445	230432	14327T	PARTICIPANT	\N	PRESENT	0
230447	230432	04071H	PARTICIPANT	\N	PRESENT	0
230450	230432	11110B	PARTICIPANT	\N	PRESENT	0
230451	230432	19647E	PARTICIPANT	\N	PRESENT	0
230452	230432	14034U	PARTICIPANT	\N	PRESENT	0
230453	230432	14199E	PARTICIPANT	\N	PRESENT	0
230454	230432	07004J	PARTICIPANT	\N	EXCUSE	0
230455	230432	01057W	PARTICIPANT	\N	PRESENT	0
230456	230432	08069G	PARTICIPANT	\N	PRESENT	0
230457	230432	11048N	PARTICIPANT	\N	PRESENT	0
230458	230432	14121F	PARTICIPANT	\N	PRESENT	0
230459	230432	19531S	PARTICIPANT	\N	PRESENT	0
230460	230432	95041E	PARTICIPANT	\N	PRESENT	0
230461	230432	99004R	PARTICIPANT	\N	PRESENT	0
230462	230432	04061F	PARTICIPANT	\N	PRESENT	0
230463	230432	14159V	PARTICIPANT	\N	PRESENT	0
230464	230432	07029T	PARTICIPANT	\N	PRESENT	0
230466	230432	19711U	PARTICIPANT	\N	PRESENT	0
230467	230432	08034U	PARTICIPANT	\N	EXCUSE	0
230468	230432	08010L	PARTICIPANT	\N	PRESENT	0
230520	220060	04042C	PARTICIPANT	\N	PRESENT	0
230519	230432	01048V	PARTICIPANT	\N	PRESENT	0
230522	220060	19741B	PARTICIPANT	\N	PRESENT	0
230524	230432	12016W	PARTICIPANT	\N	PRESENT	0
230525	230432	19671E	PARTICIPANT	\N	PRESENT	0
230526	230432	08011M	PARTICIPANT	\N	PRESENT	0
230527	230432	14253S	PARTICIPANT	\N	PRESENT	0
230528	230432	08073C	PARTICIPANT	\N	PRESENT	0
230529	230432	19349W	PARTICIPANT	\N	PRESENT	0
230530	230432	14331P	PARTICIPANT	\N	PRESENT	0
230531	230432	14225N	PARTICIPANT	\N	PRESENT	0
230532	230432	11012A	PARTICIPANT	\N	PRESENT	0
230533	230432	19687N	PARTICIPANT	\N	PRESENT	0
230534	230432	19689Q	PARTICIPANT	\N	PRESENT	0
230535	230432	19479G	PARTICIPANT	\N	PRESENT	0
230536	220060	19675J	PARTICIPANT	\N	PRESENT	0
230541	220060	14030Q	PARTICIPANT	\N	PRESENT	0
230539	220060	89017R	PARTICIPANT	\N	PRESENT	0
230564	220060	11067R	PARTICIPANT	\N	PRESENT	0
230547	220060	11063M	PARTICIPANT	\N	PRESENT	0
230551	220060	19681G	PARTICIPANT	\N	PRESENT	0
230554	220060	11109J	PARTICIPANT	\N	PRESENT	0
230557	220060	11027H	PARTICIPANT	\N	PRESENT	0
230559	220060	19585H	PARTICIPANT	\N	PRESENT	0
230566	220060	01028R	PARTICIPANT	\N	PRESENT	0
230569	220060	95067Q	PARTICIPANT	\N	PRESENT	0
230571	220060	05008E	PARTICIPANT	\N	PRESENT	0
230591	230590	11053K	PARTICIPANT	\N	PRESENT	0
230576	220060	19515S	PARTICIPANT	\N	PRESENT	0
230577	220060	14038Y	PARTICIPANT	\N	PRESENT	0
230583	220060	04071H	PARTICIPANT	\N	PRESENT	0
230584	220060	98018T	PARTICIPANT	\N	PRESENT	0
230592	230590	14159V	PARTICIPANT	\N	PRESENT	0
230593	230590	05012A	PARTICIPANT	\N	PRESENT	0
230596	220062	11077T	PARTICIPANT	\N	PRESENT	0
230597	220062	11072N	PARTICIPANT	\N	PRESENT	0
230598	220062	19651A	PARTICIPANT	\N	PRESENT	0
230599	220062	07029T	PARTICIPANT	\N	PRESENT	0
230600	220062	04086Q	PARTICIPANT	\N	PRESENT	0
230601	220062	04049K	PARTICIPANT	\N	PRESENT	0
230602	220062	19545Y	PARTICIPANT	\N	PRESENT	0
230603	220062	19711U	PARTICIPANT	\N	PRESENT	0
230604	220062	14085U	PARTICIPANT	\N	PRESENT	0
230605	220062	14225N	PARTICIPANT	\N	PRESENT	0
230606	220062	08011M	PARTICIPANT	\N	PRESENT	0
230607	220062	11074Q	PARTICIPANT	\N	PRESENT	0
230608	220062	14038Y	PARTICIPANT	\N	PRESENT	0
230609	220062	19671E	PARTICIPANT	\N	PRESENT	0
230610	220062	14327T	PARTICIPANT	\N	PRESENT	0
230611	220062	01057W	PARTICIPANT	\N	PRESENT	0
230629	220062	14105F	PARTICIPANT	\N	PRESENT	0
230613	220062	11053K	PARTICIPANT	\N	PRESENT	0
230614	220062	19479G	PARTICIPANT	\N	PRESENT	0
230615	220062	11040E	PARTICIPANT	\N	PRESENT	0
230616	220062	04085P	PARTICIPANT	\N	PRESENT	0
230617	220062	19687N	PARTICIPANT	\N	PRESENT	0
230618	220062	14083S	PARTICIPANT	\N	PRESENT	0
230619	220062	88008L	PARTICIPANT	\N	PRESENT	0
230620	220062	14237S	PARTICIPANT	\N	PRESENT	0
230621	220062	14053L	PARTICIPANT	\N	PRESENT	0
230622	220062	08034U	PARTICIPANT	\N	PRESENT	0
230623	220062	04071H	PARTICIPANT	\N	PRESENT	0
230624	220062	19643A	PARTICIPANT	\N	PRESENT	0
230625	220062	08014Q	PARTICIPANT	\N	PRESENT	0
230626	220062	14187A	PARTICIPANT	\N	PRESENT	0
230627	220062	14093U	PARTICIPANT	\N	PRESENT	0
230628	220062	19447X	PARTICIPANT	\N	PRESENT	0
230630	228416	14327T	PARTICIPANT	\N	PRESENT	0
230631	228416	19711U	PARTICIPANT	\N	PRESENT	0
230632	228416	01048V	PARTICIPANT	\N	PRESENT	0
230633	228416	19545Y	PARTICIPANT	\N	PRESENT	0
230634	228416	01057W	PARTICIPANT	\N	PRESENT	0
230635	228416	11053K	PARTICIPANT	\N	PRESENT	0
230636	228416	11074Q	PRESIDENT	0	PRESENT	0
230637	228416	04086Q	PARTICIPANT	\N	PRESENT	0
230638	228416	11040E	PARTICIPANT	\N	PRESENT	0
230639	228416	07029T	PARTICIPANT	\N	PRESENT	0
230640	228416	14085U	PARTICIPANT	\N	PRESENT	0
230641	228416	08010L	PARTICIPANT	\N	PRESENT	0
230642	228416	14253S	PARTICIPANT	\N	PRESENT	0
230643	228416	14331P	PARTICIPANT	\N	EXCUSE	0
230644	228416	07004J	PARTICIPANT	\N	EXCUSE	0
230645	228416	08011M	PARTICIPANT	\N	PRESENT	0
230651	228416	04071H	PARTICIPANT	\N	PRESENT	0
230678	230677	14187A	PARTICIPANT	\N	PRESENT	0
230679	230677	19369B	PARTICIPANT	\N	PRESENT	0
230681	230680	14187A	PARTICIPANT	\N	PRESENT	0
230687	230682	14207L	PARTICIPANT	\N	PRESENT	0
230688	230682	11056N	PARTICIPANT	\N	PRESENT	0
230689	230682	14357A	PARTICIPANT	\N	PRESENT	0
230690	230682	01025N	PARTICIPANT	\N	PRESENT	0
230691	230682	14033T	PARTICIPANT	\N	PRESENT	0
230692	230682	11099A	PARTICIPANT	\N	PRESENT	0
230693	230682	14205J	PARTICIPANT	\N	PRESENT	0
230694	230682	19441R	PARTICIPANT	\N	PRESENT	0
230695	230682	19563B	PARTICIPANT	\N	PRESENT	0
230696	230682	14257W	PARTICIPANT	\N	PRESENT	0
230697	230682	14265W	PARTICIPANT	\N	PRESENT	0
230698	230682	14135M	PARTICIPANT	\N	PRESENT	0
230699	230682	19619A	PARTICIPANT	\N	PRESENT	0
230910	230909	14147R	PARTICIPANT	\N	PRESENT	0
230918	230586	14331P	PARTICIPANT	\N	PRESENT	0
230919	230586	19711U	PARTICIPANT	\N	PRESENT	0
230920	230586	19651A	PARTICIPANT	\N	PRESENT	0
230921	230586	08069G	PARTICIPANT	\N	PRESENT	0
230922	230586	19687N	PARTICIPANT	\N	PRESENT	0
230923	230586	11053K	PARTICIPANT	\N	PRESENT	0
230924	230586	11074Q	PRESIDENT	0	PRESENT	0
230925	230586	08011M	PARTICIPANT	\N	PRESENT	0
230926	230586	14034U	PARTICIPANT	\N	PRESENT	0
230927	230586	14159V	PARTICIPANT	\N	PRESENT	0
230928	230586	14225N	PARTICIPANT	\N	PRESENT	0
230929	230586	11070L	PARTICIPANT	\N	PRESENT	0
230930	230586	04086Q	PARTICIPANT	\N	PRESENT	0
230931	230586	14085U	PARTICIPANT	\N	PRESENT	0
230932	230586	08010L	PARTICIPANT	\N	PRESENT	0
230933	230586	14121F	PARTICIPANT	\N	PRESENT	0
230934	230586	99004R	PARTICIPANT	\N	PRESENT	0
230935	230586	14253S	PARTICIPANT	\N	PRESENT	0
230936	230586	19689Q	PARTICIPANT	\N	PRESENT	0
230940	230595	19673G	PARTICIPANT	\N	PRESENT	0
212050	210187	11067R	PARTICIPANT	\N	PRESENT	0
212428	207689	99004R	PARTICIPANT	\N	PRESENT	0
212429	207689	04086Q	PARTICIPANT	\N	PRESENT	0
212430	207689	14223L	PARTICIPANT	\N	PRESENT	0
212431	207689	14053L	PARTICIPANT	\N	PRESENT	0
212432	207689	98023Q	PARTICIPANT	\N	PRESENT	0
212426	207689	15447F	PARTICIPANT	\N	PRESENT	0
212427	207689	19711U	PARTICIPANT	\N	PRESENT	0
212433	207689	14191V	PARTICIPANT	\N	PRESENT	0
212434	207689	11080N	PARTICIPANT	\N	PRESENT	0
212435	207689	08069G	PARTICIPANT	\N	PRESENT	0
212436	207689	14157T	PARTICIPANT	\N	PRESENT	0
212437	207689	14026U	PARTICIPANT	\N	PRESENT	0
212438	207689	87003B	PARTICIPANT	\N	PRESENT	0
212439	207689	14169X	PARTICIPANT	\N	PRESENT	0
212440	207689	14031R	PARTICIPANT	\N	PRESENT	0
212441	207689	11010L	PARTICIPANT	\N	PRESENT	0
212442	207689	04092N	PARTICIPANT	\N	PRESENT	0
212443	207689	11048N	PARTICIPANT	\N	PRESENT	0
212444	207689	08018U	PARTICIPANT	\N	PRESENT	0
212445	207689	92040Q	PARTICIPANT	\N	PRESENT	0
212446	207689	86034E	PARTICIPANT	\N	PRESENT	0
212447	207689	19515S	PARTICIPANT	\N	PRESENT	0
212448	207689	14187A	PARTICIPANT	\N	PRESENT	0
212449	207689	14069U	PARTICIPANT	\N	PRESENT	0
212450	207689	04085P	PARTICIPANT	\N	PRESENT	0
212451	207689	11040E	PARTICIPANT	\N	PRESENT	0
212452	207689	14249W	PARTICIPANT	\N	PRESENT	0
212453	207689	11031D	PARTICIPANT	\N	PRESENT	0
212454	207689	11033F	PARTICIPANT	\N	PRESENT	0
212455	207689	08020N	PARTICIPANT	\N	PRESENT	0
212456	207689	14235Q	PARTICIPANT	\N	PRESENT	0
212457	207689	19347U	PARTICIPANT	\N	PRESENT	0
212458	207689	19695N	PARTICIPANT	\N	PRESENT	0
212459	207689	10006L	PARTICIPANT	\N	PRESENT	0
212460	207689	19565D	PARTICIPANT	\N	PRESENT	0
212461	207689	12041X	PARTICIPANT	\N	PRESENT	0
212462	207689	19593H	PARTICIPANT	\N	PRESENT	0
212463	207689	19687N	PARTICIPANT	\N	PRESENT	0
212464	207689	14133K	PARTICIPANT	\N	PRESENT	0
212465	207689	19591F	PARTICIPANT	\N	PRESENT	0
212466	207689	14079W	PARTICIPANT	\N	PRESENT	0
212467	207689	98035U	PARTICIPANT	\N	PRESENT	0
212468	207689	19421M	PARTICIPANT	\N	PRESENT	0
212469	207689	04059M	PARTICIPANT	\N	PRESENT	0
212470	207689	14087W	PARTICIPANT	\N	PRESENT	0
212471	207689	14159V	PARTICIPANT	\N	PRESENT	0
212472	207689	11103C	PARTICIPANT	\N	PRESENT	0
212473	207689	11077T	PARTICIPANT	\N	PRESENT	0
212474	207689	11097X	PARTICIPANT	\N	PRESENT	0
212475	207689	08055A	PARTICIPANT	\N	PRESENT	0
212476	207689	08068F	PARTICIPANT	\N	PRESENT	0
212477	207689	14051J	PARTICIPANT	\N	PRESENT	0
212478	207689	04035D	PARTICIPANT	\N	PRESENT	0
212479	207689	01028R	PARTICIPANT	\N	PRESENT	0
212480	207689	11027H	PARTICIPANT	\N	PRESENT	0
212481	207689	08052W	PARTICIPANT	\N	PRESENT	0
212482	207689	14107H	PARTICIPANT	\N	PRESENT	0
212483	207689	19367Y	PARTICIPANT	\N	PRESENT	0
212484	207689	08045X	PARTICIPANT	\N	PRESENT	0
212485	207689	14121F	PARTICIPANT	\N	PRESENT	0
212486	207689	14021P	PARTICIPANT	\N	PRESENT	0
212487	207689	14151M	PARTICIPANT	\N	PRESENT	0
212488	207689	19649G	PARTICIPANT	\N	PRESENT	0
212489	207689	19671E	PARTICIPANT	\N	PRESENT	0
212490	207689	08024S	PARTICIPANT	\N	PRESENT	0
212491	207689	14028W	PARTICIPANT	\N	PRESENT	0
212492	207689	80013X	PARTICIPANT	\N	PRESENT	0
212493	207689	08038Y	PARTICIPANT	\N	PRESENT	0
212494	207689	11045K	PARTICIPANT	\N	PRESENT	0
212495	207689	04018C	PARTICIPANT	\N	PRESENT	0
212496	207689	11066Q	PARTICIPANT	\N	PRESENT	0
212497	207689	11110B	PARTICIPANT	\N	PRESENT	0
212498	207689	14331P	PARTICIPANT	\N	PRESENT	0
212499	207689	14281W	PARTICIPANT	\N	PRESENT	0
212500	207689	08043V	PARTICIPANT	\N	PRESENT	0
212501	207689	08034U	PARTICIPANT	\N	PRESENT	0
212502	207689	14227Q	PARTICIPANT	\N	PRESENT	0
212503	207689	95067Q	PARTICIPANT	\N	PRESENT	0
212504	207689	19693L	PARTICIPANT	\N	PRESENT	0
212505	207689	14229S	PARTICIPANT	\N	PRESENT	0
212506	207689	11090Q	PARTICIPANT	\N	PRESENT	0
212507	207689	19647E	PARTICIPANT	\N	PRESENT	0
212508	207689	04033B	PARTICIPANT	\N	PRESENT	0
212509	207689	19489J	PARTICIPANT	\N	PRESENT	0
212510	207689	17779H	PARTICIPANT	\N	PRESENT	0
212511	207689	14123H	PARTICIPANT	\N	PRESENT	0
212512	207689	14085U	PARTICIPANT	\N	PRESENT	0
212513	207689	04071H	PARTICIPANT	\N	PRESENT	0
212514	207689	08053X	PARTICIPANT	\N	PRESENT	0
212515	207689	14265W	PARTICIPANT	\N	PRESENT	0
212516	207689	19703U	PARTICIPANT	\N	PRESENT	0
212517	207689	19525U	PARTICIPANT	\N	PRESENT	0
212518	207689	14081Q	PARTICIPANT	\N	PRESENT	0
212519	207689	08058D	PARTICIPANT	\N	PRESENT	0
212520	207689	04042C	PARTICIPANT	\N	PRESENT	0
212521	207689	19631V	PARTICIPANT	\N	PRESENT	0
212522	207689	19715Y	PARTICIPANT	\N	PRESENT	0
212523	207689	08011M	PARTICIPANT	\N	PRESENT	0
212524	207689	19527W	PARTICIPANT	\N	PRESENT	0
212525	207689	14257W	PARTICIPANT	\N	PRESENT	0
212526	207689	11041F	PARTICIPANT	\N	PRESENT	0
212527	207689	97011G	PARTICIPANT	\N	PRESENT	0
212528	207689	19599P	PARTICIPANT	\N	PRESENT	0
212529	207689	14357A	PARTICIPANT	\N	PRESENT	0
212530	207689	19725B	PARTICIPANT	\N	PRESENT	0
212531	207689	19707Y	PARTICIPANT	\N	PRESENT	0
212532	207689	19333N	PARTICIPANT	\N	PRESENT	0
212533	207689	14001X	PARTICIPANT	\N	PRESENT	0
212534	207689	14063N	PARTICIPANT	\N	PRESENT	0
212535	207689	19683J	PARTICIPANT	\N	PRESENT	0
212536	207689	07033P	PARTICIPANT	\N	PRESENT	0
212537	207689	14207L	PARTICIPANT	\N	PRESENT	0
212538	207689	19689Q	PARTICIPANT	\N	PRESENT	0
212539	207689	19413M	PARTICIPANT	\N	PRESENT	0
212540	207689	08015R	PARTICIPANT	\N	PRESENT	0
212541	207689	19251M	PARTICIPANT	\N	PRESENT	0
212542	207689	19503N	PARTICIPANT	\N	PRESENT	0
212543	207689	11067R	PARTICIPANT	\N	PRESENT	0
212544	207689	11026G	PARTICIPANT	\N	PRESENT	0
212545	207689	11049P	PARTICIPANT	\N	PRESENT	0
212546	207689	14109K	PARTICIPANT	\N	PRESENT	0
212547	207689	14097Y	PARTICIPANT	\N	PRESENT	0
212548	207689	19669L	PARTICIPANT	\N	PRESENT	0
212549	207689	19679N	PARTICIPANT	\N	PRESENT	0
212550	207689	19549D	PARTICIPANT	\N	PRESENT	0
212551	207689	04061F	PARTICIPANT	\N	PRESENT	0
212552	207689	08019V	PARTICIPANT	\N	PRESENT	0
212553	207689	05012A	PARTICIPANT	\N	PRESENT	0
212554	207689	19651A	PARTICIPANT	\N	PRESENT	0
212555	207689	08061X	PARTICIPANT	\N	PRESENT	0
212556	207689	08048B	PARTICIPANT	\N	PRESENT	0
212557	207689	19543W	PARTICIPANT	\N	PRESENT	0
212558	207689	08010L	PARTICIPANT	\N	PRESENT	0
212559	207689	98029W	PARTICIPANT	\N	PRESENT	0
212560	207689	95063L	PARTICIPANT	\N	PRESENT	0
212561	207689	04045F	PARTICIPANT	\N	PRESENT	0
212562	207689	11083R	PARTICIPANT	\N	PRESENT	0
212563	207689	19329S	PARTICIPANT	\N	PRESENT	0
212564	207689	19447X	PARTICIPANT	\N	PRESENT	0
212565	207689	95037J	PARTICIPANT	\N	PRESENT	0
212566	207689	14038Y	PARTICIPANT	\N	PRESENT	0
212567	207689	19697Q	PARTICIPANT	\N	PRESENT	0
212568	207689	19637C	PARTICIPANT	\N	PRESENT	0
212569	207689	95015C	PARTICIPANT	\N	PRESENT	0
212570	207689	11072N	PARTICIPANT	\N	PRESENT	0
212571	207689	19349W	PARTICIPANT	\N	PRESENT	0
212572	207689	19483C	PARTICIPANT	\N	PRESENT	0
212573	207689	19301E	PARTICIPANT	\N	PRESENT	0
212574	207689	14135M	PARTICIPANT	\N	PRESENT	0
212575	207689	19443T	PARTICIPANT	\N	PRESENT	0
212576	207689	89017R	PARTICIPANT	\N	PRESENT	0
212577	207689	19731Y	PARTICIPANT	\N	PRESENT	0
212578	207689	19685L	PARTICIPANT	\N	PRESENT	0
212579	207689	01060R	PARTICIPANT	\N	PRESENT	0
212580	207689	14055N	PARTICIPANT	\N	PRESENT	0
212581	207689	14061L	PARTICIPANT	\N	PRESENT	0
212582	207689	14261S	PARTICIPANT	\N	PRESENT	0
212583	207689	19629C	PARTICIPANT	\N	PRESENT	0
212584	207689	14329V	PARTICIPANT	\N	PRESENT	0
212585	207689	11012A	PARTICIPANT	\N	PRESENT	0
212586	207689	08031R	PARTICIPANT	\N	PRESENT	0
212587	207689	19719D	PARTICIPANT	\N	PRESENT	0
212588	207689	88008L	PARTICIPANT	\N	PRESENT	0
212589	207689	14201E	PARTICIPANT	\N	PRESENT	0
212590	207689	01048V	PARTICIPANT	\N	PRESENT	0
212591	207689	08049C	PARTICIPANT	\N	PRESENT	0
212592	207689	19553Y	PARTICIPANT	\N	PRESENT	0
224177	218295	19619A	PARTICIPANT	\N	PRESENT	0
224178	218295	04035D	PARTICIPANT	\N	PRESENT	0
224179	218295	14231L	PARTICIPANT	\N	PRESENT	0
224181	218295	19333N	PARTICIPANT	\N	PRESENT	0
224182	218295	19727D	PARTICIPANT	\N	PRESENT	0
224183	218295	04057K	PARTICIPANT	\N	PRESENT	0
224184	218295	95037J	PARTICIPANT	\N	PRESENT	0
224185	218295	87003B	PARTICIPANT	\N	PRESENT	0
224186	218295	19369B	PARTICIPANT	\N	PRESENT	0
224187	218295	92040Q	PARTICIPANT	\N	PRESENT	0
224188	218295	11083R	PARTICIPANT	\N	PRESENT	0
224189	218295	98050T	PARTICIPANT	\N	PRESENT	0
224190	218295	08047A	PARTICIPANT	\N	PRESENT	0
224191	218295	14038Y	PARTICIPANT	\N	PRESENT	0
224192	218295	08053X	PARTICIPANT	\N	PRESENT	0
224420	223695	14327T	PARTICIPANT	\N	PRESENT	0
224421	223695	14331P	PARTICIPANT	\N	PRESENT	0
224422	223695	95041E	PARTICIPANT	\N	PRESENT	0
224423	223695	01048V	PARTICIPANT	\N	PRESENT	0
224424	223695	19545Y	PARTICIPANT	\N	PRESENT	0
224425	223695	01057W	PARTICIPANT	\N	PRESENT	0
224426	223695	19667J	PARTICIPANT	\N	PRESENT	0
224427	223695	11074Q	PRESIDENT	0	PRESENT	0
224428	223695	14225N	PARTICIPANT	\N	PRESENT	0
224429	223695	88008L	PARTICIPANT	\N	PRESENT	0
224430	223695	11070L	PARTICIPANT	\N	PRESENT	0
224431	223695	07029T	PARTICIPANT	\N	PRESENT	0
224432	223695	14085U	PARTICIPANT	\N	PRESENT	0
224433	223695	19349W	PARTICIPANT	\N	PRESENT	0
224434	223695	11048N	PARTICIPANT	\N	PRESENT	0
224435	223695	19647E	PARTICIPANT	\N	PRESENT	0
224436	223695	19711U	PARTICIPANT	\N	PRESENT	0
224437	223695	08034U	PARTICIPANT	\N	PRESENT	0
224438	223695	19651A	PARTICIPANT	\N	PRESENT	0
224439	223695	19689Q	PARTICIPANT	\N	PRESENT	0
224440	223695	08011M	PARTICIPANT	\N	PRESENT	0
224441	223695	14034U	PARTICIPANT	\N	PRESENT	0
224442	223695	04086Q	PARTICIPANT	\N	PRESENT	0
224443	223695	14083S	PARTICIPANT	\N	PRESENT	0
224444	223695	14199E	PARTICIPANT	\N	PRESENT	0
224445	223695	08073C	PARTICIPANT	\N	PRESENT	0
224446	223695	14121F	PARTICIPANT	\N	PRESENT	0
224447	223695	99004R	PARTICIPANT	\N	PRESENT	0
224452	218298	07034Q	PARTICIPANT	\N	PRESENT	0
224450	218298	95062K	PARTICIPANT	\N	PRESENT	0
224451	218298	04092N	PARTICIPANT	\N	PRESENT	0
224453	218298	14038Y	PARTICIPANT	\N	PRESENT	0
224454	218298	04035D	PARTICIPANT	\N	PRESENT	0
224455	218298	14215L	PARTICIPANT	\N	PRESENT	0
224456	218298	08018U	PARTICIPANT	\N	PRESENT	0
224457	218298	14031R	PARTICIPANT	\N	PRESENT	0
224458	218298	14157T	PARTICIPANT	\N	PRESENT	0
224459	218298	14105F	PARTICIPANT	\N	PRESENT	0
224460	218298	04049K	PARTICIPANT	\N	PRESENT	0
224461	218298	87003B	PARTICIPANT	\N	PRESENT	0
224175	218295	04061F	PARTICIPANT	\N	PRESENT	0
224176	218295	14039A	PARTICIPANT	\N	PRESENT	0
224462	218298	14053L	PARTICIPANT	\N	PRESENT	0
224463	218298	14217N	PARTICIPANT	\N	PRESENT	0
224464	218298	14026U	PARTICIPANT	\N	PRESENT	0
224465	218298	14133K	PARTICIPANT	\N	PRESENT	0
224466	218298	98050T	PARTICIPANT	\N	PRESENT	0
224467	218298	07033P	PARTICIPANT	\N	PRESENT	0
224468	218298	95030B	PARTICIPANT	\N	PRESENT	0
224469	218298	08028W	PARTICIPANT	\N	PRESENT	0
224470	218298	04008A	PARTICIPANT	\N	PRESENT	0
224471	218298	99004R	PARTICIPANT	\N	PRESENT	0
224472	218298	01048V	PARTICIPANT	\N	PRESENT	0
224473	218298	04097T	PARTICIPANT	\N	PRESENT	0
224474	218298	18083K	PARTICIPANT	\N	PRESENT	0
224475	218298	15447F	PARTICIPANT	\N	PRESENT	0
224476	218298	19703U	PARTICIPANT	\N	PRESENT	0
224477	218298	19679N	PARTICIPANT	\N	PRESENT	0
224478	218298	14211G	PARTICIPANT	\N	PRESENT	0
224479	218298	17637T	PARTICIPANT	\N	PRESENT	0
224480	218298	14123H	PARTICIPANT	\N	PRESENT	0
224481	218298	14223L	PARTICIPANT	\N	PRESENT	0
224482	218298	04086Q	PARTICIPANT	\N	PRESENT	0
224483	218298	11101A	PARTICIPANT	\N	PRESENT	0
224484	218298	01058X	PARTICIPANT	\N	PRESENT	0
224485	218298	04018C	PARTICIPANT	\N	PRESENT	0
224486	218298	11103C	PARTICIPANT	\N	PRESENT	0
224487	218298	95067Q	PARTICIPANT	\N	PRESENT	0
224488	218298	10015M	PARTICIPANT	\N	PRESENT	0
224489	218298	17583W	PARTICIPANT	\N	PRESENT	0
224490	218298	19643A	PARTICIPANT	\N	PRESENT	0
224491	218298	86034E	PARTICIPANT	\N	PRESENT	0
224492	218298	19671E	PARTICIPANT	\N	PRESENT	0
224493	218298	04085P	PARTICIPANT	\N	PRESENT	0
224494	218298	11049P	PARTICIPANT	\N	PRESENT	0
224495	218298	11033F	PARTICIPANT	\N	PRESENT	0
224496	218298	14191V	PARTICIPANT	\N	PRESENT	0
224497	218298	92040Q	PARTICIPANT	\N	PRESENT	0
224498	218298	11056N	PARTICIPANT	\N	PRESENT	0
224499	218298	07029T	PARTICIPANT	\N	PRESENT	0
224500	218298	12041X	PARTICIPANT	\N	PRESENT	0
224501	218298	04038G	PARTICIPANT	\N	PRESENT	0
224502	218298	19673G	PARTICIPANT	\N	PRESENT	0
224503	218298	14235Q	PARTICIPANT	\N	PRESENT	0
224504	218298	04033B	PARTICIPANT	\N	PRESENT	0
224505	218298	04061F	PARTICIPANT	\N	PRESENT	0
224506	218298	08020N	PARTICIPANT	\N	PRESENT	0
224507	218298	01057W	PARTICIPANT	\N	PRESENT	0
224508	218298	11031D	PARTICIPANT	\N	PRESENT	0
224509	218298	19667J	PARTICIPANT	\N	PRESENT	0
224510	218298	19695N	PARTICIPANT	\N	PRESENT	0
224511	218298	19687N	PARTICIPANT	\N	PRESENT	0
224512	218298	19399H	PARTICIPANT	\N	PRESENT	0
224513	218298	14259Y	PARTICIPANT	\N	PRESENT	0
224514	218298	19593H	PARTICIPANT	\N	PRESENT	0
224515	218298	11080N	PARTICIPANT	\N	PRESENT	0
224516	218298	19347U	PARTICIPANT	\N	PRESENT	0
224559	218298	19575F	PARTICIPANT	\N	PRESENT	0
224518	218298	08061X	PARTICIPANT	\N	PRESENT	0
224519	218298	11083R	PARTICIPANT	\N	PRESENT	0
224520	218298	14173T	PARTICIPANT	\N	PRESENT	0
224521	218298	95037J	PARTICIPANT	\N	PRESENT	0
224522	218298	04045F	PARTICIPANT	\N	PRESENT	0
224523	218298	04034C	PARTICIPANT	\N	PRESENT	0
224524	218298	98029W	PARTICIPANT	\N	PRESENT	0
224525	218298	14041T	PARTICIPANT	\N	PRESENT	0
224526	218298	19651A	PARTICIPANT	\N	PRESENT	0
224527	218298	14239U	PARTICIPANT	\N	PRESENT	0
224528	218298	19349W	PARTICIPANT	\N	PRESENT	0
224529	218298	08010L	PARTICIPANT	\N	PRESENT	0
224530	218298	19637C	PARTICIPANT	\N	PRESENT	0
224531	218298	19573D	PARTICIPANT	\N	PRESENT	0
224532	218298	19693L	PARTICIPANT	\N	PRESENT	0
224533	218298	11072N	PARTICIPANT	\N	PRESENT	0
224534	218298	08021P	PARTICIPANT	\N	PRESENT	0
224535	218298	11048N	PARTICIPANT	\N	PRESENT	0
224536	218298	19269X	PARTICIPANT	\N	PRESENT	0
224537	218298	19329S	PARTICIPANT	\N	PRESENT	0
224538	218298	14119M	PARTICIPANT	\N	PRESENT	0
224539	218298	14331P	PARTICIPANT	\N	PRESENT	0
224540	218298	14147R	PARTICIPANT	\N	PRESENT	0
224541	218298	14055N	PARTICIPANT	\N	PRESENT	0
224542	218298	19731Y	PARTICIPANT	\N	PRESENT	0
224543	218298	19685L	PARTICIPANT	\N	PRESENT	0
224544	218298	14061L	PARTICIPANT	\N	PRESENT	0
224545	218298	19543W	PARTICIPANT	\N	PRESENT	0
224546	218298	14265W	PARTICIPANT	\N	PRESENT	0
224547	218298	08031R	PARTICIPANT	\N	PRESENT	0
224548	218298	19711U	PARTICIPANT	\N	PRESENT	0
224549	218298	14034U	PARTICIPANT	\N	PRESENT	0
224550	218298	88008L	PARTICIPANT	\N	PRESENT	0
224551	218298	11012A	PARTICIPANT	\N	PRESENT	0
224552	218298	19253P	PARTICIPANT	\N	PRESENT	0
224553	218298	19629C	PARTICIPANT	\N	PRESENT	0
224554	218298	04047H	PARTICIPANT	\N	PRESENT	0
224555	218298	08049C	PARTICIPANT	\N	PRESENT	0
224556	218298	14213J	PARTICIPANT	\N	PRESENT	0
224557	218298	19681G	PARTICIPANT	\N	PRESENT	0
224558	218298	98022P	PARTICIPANT	\N	PRESENT	0
224560	218298	14241N	PARTICIPANT	\N	PRESENT	0
224561	218298	19563B	PARTICIPANT	\N	PRESENT	0
224562	218298	19719D	PARTICIPANT	\N	PRESENT	0
224563	218298	19387D	PARTICIPANT	\N	PRESENT	0
224564	218298	08062Y	PARTICIPANT	\N	PRESENT	0
224565	218298	19553Y	PARTICIPANT	\N	PRESENT	0
224566	218298	19515S	PARTICIPANT	\N	PRESENT	0
224567	218298	11065P	PARTICIPANT	\N	PRESENT	0
224568	218298	08015R	PARTICIPANT	\N	PRESENT	0
224569	218298	14251Q	PARTICIPANT	\N	PRESENT	0
224570	218298	14093U	PARTICIPANT	\N	PRESENT	0
224571	218298	19707Y	PARTICIPANT	\N	PRESENT	0
224572	218298	14195A	PARTICIPANT	\N	PRESENT	0
224573	218298	08047A	PARTICIPANT	\N	PRESENT	0
214499	214498	14255U	PARTICIPANT	\N	PRESENT	0
214500	214498	08053X	PARTICIPANT	\N	PRESENT	0
214525	210900	14071N	PARTICIPANT	\N	PRESENT	0
214526	210900	11067R	PARTICIPANT	\N	PRESENT	0
215840	214588	19711U	PARTICIPANT	\N	PRESENT	0
215841	214588	19651A	PARTICIPANT	\N	PRESENT	0
215842	214588	08034U	PARTICIPANT	\N	PRESENT	0
215843	214588	19531S	PARTICIPANT	\N	PRESENT	0
215844	214588	08069G	PARTICIPANT	\N	PRESENT	0
215845	214588	19689Q	PARTICIPANT	\N	PRESENT	0
215846	214588	12016W	PARTICIPANT	\N	PRESENT	0
215847	214588	08011M	PARTICIPANT	\N	PRESENT	0
215848	214588	08014Q	PARTICIPANT	\N	PRESENT	0
215849	214588	14034U	PARTICIPANT	\N	PRESENT	0
215850	214588	04086Q	PARTICIPANT	\N	PRESENT	0
215851	214588	14083S	PARTICIPANT	\N	PRESENT	0
215852	214588	11012A	PARTICIPANT	\N	PRESENT	0
215853	214588	19507S	PARTICIPANT	\N	PRESENT	0
215854	214588	14121F	PARTICIPANT	\N	PRESENT	0
215855	214588	01048V	PARTICIPANT	\N	PRESENT	0
215856	214588	14277B	PARTICIPANT	\N	EXCUSE	0
215857	214588	07004J	PARTICIPANT	\N	EXCUSE	0
215858	207702	19675J	PARTICIPANT	\N	PRESENT	0
215859	207702	08073C	PARTICIPANT	\N	PRESENT	0
215860	207702	08028W	PARTICIPANT	\N	PRESENT	0
215861	207702	08061X	PARTICIPANT	\N	PRESENT	0
215862	207702	87003B	PARTICIPANT	\N	PRESENT	0
215900	207702	14051J	PARTICIPANT	\N	PRESENT	0
215865	207702	08014Q	PARTICIPANT	\N	PRESENT	0
215866	207702	08009T	PARTICIPANT	\N	PRESENT	0
215867	207702	14073Q	PARTICIPANT	\N	PRESENT	0
215868	207702	14219Q	PARTICIPANT	\N	PRESENT	0
215869	207702	14221J	PARTICIPANT	\N	PRESENT	0
215870	214589	19479G	PARTICIPANT	\N	PRESENT	0
215871	214589	19711U	PARTICIPANT	\N	PRESENT	0
215872	214589	01048V	PARTICIPANT	\N	PRESENT	0
215873	214589	08034U	PARTICIPANT	\N	PRESENT	0
215874	214589	19651A	PARTICIPANT	\N	PRESENT	0
215875	214589	95015C	RAPPORTEUR_AVIS	\N	PRESENT	0
215876	214589	19545Y	PARTICIPANT	\N	PRESENT	0
215877	214589	19687N	PARTICIPANT	\N	PRESENT	0
215878	214589	01057W	PARTICIPANT	\N	PRESENT	0
215879	214589	19689Q	PARTICIPANT	\N	PRESENT	0
215880	214589	89017R	PARTICIPANT	\N	PRESENT	0
215881	214589	19667J	PARTICIPANT	\N	PRESENT	0
215882	214589	11074Q	PRESIDENT	0	PRESENT	0
215883	214589	19671E	PARTICIPANT	\N	PRESENT	0
215884	214589	14173T	PARTICIPANT	\N	PRESENT	0
215885	214589	14083S	PARTICIPANT	\N	PRESENT	0
215886	214589	14085U	PARTICIPANT	\N	PRESENT	0
215887	214589	19349W	PARTICIPANT	\N	PRESENT	0
215888	214589	08010L	PARTICIPANT	\N	PRESENT	0
215889	214589	07029T	PARTICIPANT	\N	PRESENT	0
215890	214589	14277B	PARTICIPANT	\N	EXCUSE	0
215891	214589	07004J	PARTICIPANT	\N	EXCUSE	0
215892	207702	08016S	PARTICIPANT	\N	PRESENT	0
215893	207702	11033F	PARTICIPANT	\N	PRESENT	0
215894	207702	19369B	PARTICIPANT	\N	PRESENT	0
215895	207702	19447X	PARTICIPANT	\N	PRESENT	0
215896	207702	14231L	PARTICIPANT	\N	PRESENT	0
215897	207702	01043Q	PARTICIPANT	\N	PRESENT	0
215899	207702	08015R	PARTICIPANT	\N	PRESENT	0
216126	216121	14030Q	PRESIDENT	0	PRESENT	0
216127	216121	08043V	PARTICIPANT	\N	PRESENT	0
216129	216121	19643A	PARTICIPANT	\N	PRESENT	0
216130	216121	19621T	PARTICIPANT	\N	PRESENT	0
216132	216121	08020N	PARTICIPANT	\N	PRESENT	0
216133	216121	08024S	PARTICIPANT	\N	PRESENT	0
216134	216121	19701S	PARTICIPANT	\N	PRESENT	0
216135	216121	11031D	PARTICIPANT	\N	PRESENT	0
216136	216121	19693L	PARTICIPANT	\N	EXCUSE	0
216137	216121	14217N	PARTICIPANT	\N	PRESENT	0
216138	216121	14249W	PARTICIPANT	\N	PRESENT	0
216139	216121	19673G	PARTICIPANT	\N	PRESENT	0
216141	216121	19599P	PARTICIPANT	\N	PRESENT	0
216142	216121	04035D	PARTICIPANT	\N	EXCUSE	0
216144	216121	19715Y	PARTICIPANT	\N	PRESENT	0
216146	216121	08031R	PARTICIPANT	\N	EXCUSE	0
216148	216121	07029T	PARTICIPANT	\N	PRESENT	0
216150	216121	08017T	PARTICIPANT	\N	PRESENT	0
216151	216121	01043Q	PARTICIPANT	\N	EXCUSE	0
216153	216121	19697Q	PARTICIPANT	\N	PRESENT	0
216154	216121	19657G	PARTICIPANT	\N	PRESENT	0
216155	216121	14109K	PARTICIPANT	\N	PRESENT	0
216157	216121	14235Q	PARTICIPANT	\N	PRESENT	0
216158	216121	19679N	PARTICIPANT	\N	PRESENT	0
216159	216121	19269X	PARTICIPANT	\N	PRESENT	0
216160	216121	11045K	PARTICIPANT	\N	PRESENT	0
217580	207709	86034E	PARTICIPANT	\N	PRESENT	0
217586	217570	19697Q	PARTICIPANT	\N	PRESENT	0
217587	217570	11067R	PARTICIPANT	\N	PRESENT	0
216497	214917	19549D	PARTICIPANT	\N	PRESENT	0
217588	217570	11097X	PARTICIPANT	\N	PRESENT	0
216499	214917	08060W	PARTICIPANT	\N	PRESENT	0
216500	214917	19733B	PARTICIPANT	\N	PRESENT	0
217589	217570	19415P	PARTICIPANT	\N	PRESENT	0
216502	214917	08024S	PARTICIPANT	\N	PRESENT	0
216503	214917	14038Y	PARTICIPANT	\N	PRESENT	0
216504	214917	18083K	PARTICIPANT	\N	EXCUSE	0
216505	214917	19701S	PARTICIPANT	\N	PRESENT	0
217590	217570	04045F	PARTICIPANT	\N	PRESENT	0
216507	214917	98023Q	PARTICIPANT	\N	PRESENT	0
217591	217570	14227Q	PARTICIPANT	\N	PRESENT	0
217592	217570	17779H	PARTICIPANT	\N	PRESENT	0
217593	217570	11063M	PARTICIPANT	\N	PRESENT	0
216511	214917	19599P	PARTICIPANT	\N	PRESENT	0
217594	217570	14239U	PARTICIPANT	\N	PRESENT	0
217595	217570	19553Y	PARTICIPANT	\N	PRESENT	0
217596	217570	11031D	PARTICIPANT	\N	PRESENT	0
216515	214917	19347U	PARTICIPANT	\N	PRESENT	0
217597	217570	14281W	PARTICIPANT	\N	PRESENT	0
217598	217570	19575F	PARTICIPANT	\N	PRESENT	0
216518	214917	04097T	PARTICIPANT	\N	EXCUSE	0
217599	217570	14195A	PARTICIPANT	\N	PRESENT	0
216520	214917	14029X	PARTICIPANT	\N	PRESENT	0
217600	217570	14213J	PARTICIPANT	\N	PRESENT	0
217601	217570	14217N	PARTICIPANT	\N	PRESENT	0
216523	214917	14219Q	PARTICIPANT	\N	PRESENT	0
216524	214917	14103D	PARTICIPANT	\N	PRESENT	0
217602	217570	19335Q	PARTICIPANT	\N	PRESENT	0
216526	214917	14031R	PARTICIPANT	\N	PRESENT	0
216527	214917	19637C	PARTICIPANT	\N	PRESENT	0
216528	214917	08009T	PRESIDENT	0	PRESENT	0
217603	217570	98024R	PARTICIPANT	\N	PRESENT	0
216530	214917	14169X	PARTICIPANT	\N	PRESENT	0
216531	214917	14191V	PARTICIPANT	\N	PRESENT	0
216532	214917	14237S	PARTICIPANT	\N	PRESENT	0
217604	217570	01034P	PARTICIPANT	\N	PRESENT	0
216534	214917	05012A	PARTICIPANT	\N	PRESENT	0
216535	214917	19503N	PARTICIPANT	\N	PRESENT	0
216536	214917	19739H	PARTICIPANT	\N	PRESENT	0
216537	214917	17583W	PARTICIPANT	\N	PRESENT	0
217605	217570	04092N	PRESIDENT	0	PRESENT	0
216539	214917	19713W	PARTICIPANT	\N	PRESENT	0
216540	214917	14051J	PARTICIPANT	\N	PRESENT	0
217606	217570	11045K	PARTICIPANT	\N	PRESENT	0
217607	217570	08052W	PARTICIPANT	\N	PRESENT	0
217608	217570	19715Y	PARTICIPANT	\N	PRESENT	0
217609	217570	19717B	PARTICIPANT	\N	PRESENT	0
217610	217570	19723Y	PARTICIPANT	\N	PRESENT	0
217611	217570	19727D	PARTICIPANT	\N	PRESENT	0
217612	217570	11103C	PARTICIPANT	\N	PRESENT	0
217613	217570	14071N	PARTICIPANT	\N	PRESENT	0
217614	217570	19657G	PARTICIPANT	\N	PRESENT	0
217615	207709	04092N	PARTICIPANT	\N	PRESENT	0
217616	207709	01034P	PARTICIPANT	\N	PRESENT	0
217617	207709	08052W	PARTICIPANT	\N	PRESENT	0
217618	207709	11045K	PARTICIPANT	\N	PRESENT	0
217619	207709	19553Y	PARTICIPANT	\N	PRESENT	0
217620	207709	14261S	PARTICIPANT	\N	PRESENT	0
217621	207709	14227Q	PARTICIPANT	\N	PRESENT	0
217622	207709	14195A	PARTICIPANT	\N	PRESENT	0
217623	207709	19577H	PARTICIPANT	\N	PRESENT	0
217624	207709	19727D	PARTICIPANT	\N	PRESENT	0
217625	207709	19683J	PARTICIPANT	\N	PRESENT	0
217626	207709	11067R	PARTICIPANT	\N	PRESENT	0
217627	207709	14281W	PARTICIPANT	\N	PRESENT	0
217628	207709	17779H	PARTICIPANT	\N	PRESENT	0
217629	207709	04085P	PARTICIPANT	\N	PRESENT	0
217630	207709	11074Q	PARTICIPANT	\N	PRESENT	0
217631	207709	11077T	PARTICIPANT	\N	PRESENT	0
217632	207709	19715Y	PARTICIPANT	\N	PRESENT	0
217633	207709	11031D	PARTICIPANT	\N	PRESENT	0
217634	207709	19695N	PARTICIPANT	\N	PRESENT	0
217635	207709	19593H	PARTICIPANT	\N	PRESENT	0
217636	207709	19687N	PARTICIPANT	\N	PRESENT	0
217637	207709	14251Q	PARTICIPANT	\N	PRESENT	0
217638	207709	14042U	PARTICIPANT	\N	PRESENT	0
217639	207709	14239U	PARTICIPANT	\N	PRESENT	0
230941	230595	14179A	PARTICIPANT	\N	EXCUSE	0
230942	230595	04044E	PARTICIPANT	\N	EXCUSE	0
230943	230595	19719D	PARTICIPANT	\N	EXCUSE	0
230944	230595	14089Y	PARTICIPANT	\N	PRESENT	0
230945	230595	19629C	PARTICIPANT	\N	PRESENT	0
230946	230595	11049P	PARTICIPANT	\N	PRESENT	0
230947	230595	14147R	PARTICIPANT	\N	PRESENT	0
230948	230595	19447X	PARTICIPANT	\N	PRESENT	0
230949	230595	07034Q	PARTICIPANT	\N	PRESENT	0
230950	230595	05008E	PRESIDENT	0	PRESENT	0
230951	230595	14111D	PARTICIPANT	\N	PRESENT	0
230952	230595	19253P	PARTICIPANT	\N	PRESENT	0
230953	220073	14034U	PARTICIPANT	\N	PRESENT	0
231232	230587	14327T	PARTICIPANT	\N	PRESENT	0
231233	230587	14331P	PARTICIPANT	\N	PRESENT	0
231234	230587	04071H	PARTICIPANT	\N	PRESENT	0
231235	230587	95041E	PARTICIPANT	\N	PRESENT	0
231236	230587	19545Y	PARTICIPANT	\N	PRESENT	0
231237	230587	01057W	PARTICIPANT	\N	PRESENT	0
231238	230587	19667J	PARTICIPANT	\N	PRESENT	0
231239	230587	11074Q	PRESIDENT	0	PRESENT	0
231240	230587	19671E	PARTICIPANT	\N	PRESENT	0
231241	230587	14225N	PARTICIPANT	\N	PRESENT	0
231242	230587	11070L	PARTICIPANT	\N	PRESENT	0
231243	230587	14085U	PARTICIPANT	\N	PRESENT	0
231244	230587	08010L	PARTICIPANT	\N	PRESENT	0
231245	230587	19647E	PARTICIPANT	\N	PRESENT	0
231246	230587	19479G	PARTICIPANT	\N	PRESENT	0
231247	230587	19711U	PARTICIPANT	\N	PRESENT	0
231248	230587	08034U	PARTICIPANT	\N	PRESENT	0
231249	230587	19651A	PARTICIPANT	\N	PRESENT	0
231250	230587	08069G	PARTICIPANT	\N	PRESENT	0
231251	230587	19689Q	PARTICIPANT	\N	PRESENT	0
231252	230587	08011M	PARTICIPANT	\N	PRESENT	0
231253	230587	14173T	PARTICIPANT	\N	PRESENT	0
231254	230587	04086Q	PARTICIPANT	\N	PRESENT	0
231255	230587	14083S	PARTICIPANT	\N	PRESENT	0
231256	230587	11012A	PARTICIPANT	\N	PRESENT	0
231257	230587	14199E	PARTICIPANT	\N	PRESENT	0
231258	230587	14121F	PARTICIPANT	\N	PRESENT	0
231259	230587	99004R	PARTICIPANT	\N	PRESENT	0
231260	230587	07029T	PARTICIPANT	\N	EXCUSE	0
231261	230587	11048N	PARTICIPANT	\N	EXCUSE	0
231262	220076	04097T	PARTICIPANT	\N	PRESENT	0
231263	220076	07029T	PARTICIPANT	\N	PRESENT	0
231264	220076	19711U	PARTICIPANT	\N	PRESENT	0
231265	220076	14031R	PARTICIPANT	\N	PRESENT	0
231266	220076	99004R	PARTICIPANT	\N	PRESENT	0
231267	220076	04086Q	PARTICIPANT	\N	PRESENT	0
231268	220076	98005N	PARTICIPANT	\N	PRESENT	0
231269	220076	14173T	PARTICIPANT	\N	PRESENT	0
231270	220076	15447F	PARTICIPANT	\N	PRESENT	0
231271	220076	14215L	PARTICIPANT	\N	PRESENT	0
231272	220076	14123H	PARTICIPANT	\N	PRESENT	0
231273	220076	14087W	PARTICIPANT	\N	PRESENT	0
231274	220076	14249W	PARTICIPANT	\N	PRESENT	0
231275	220076	14237S	PARTICIPANT	\N	PRESENT	0
231276	220076	19533U	PARTICIPANT	\N	PRESENT	0
231277	220076	14331P	PARTICIPANT	\N	PRESENT	0
231278	220076	17583W	PARTICIPANT	\N	PRESENT	0
231279	220076	17637T	PARTICIPANT	\N	PRESENT	0
231280	220076	87003B	PARTICIPANT	\N	PRESENT	0
231281	220076	01057W	PARTICIPANT	\N	PRESENT	0
231282	220076	98023Q	PARTICIPANT	\N	PRESENT	0
231283	220076	10006L	PARTICIPANT	\N	PRESENT	0
231284	220076	08011M	PARTICIPANT	\N	PRESENT	0
231285	220076	14133K	PARTICIPANT	\N	PRESENT	0
231286	220076	11043H	PARTICIPANT	\N	PRESENT	0
231287	220076	08069G	PARTICIPANT	\N	PRESENT	0
231288	220076	19399H	PARTICIPANT	\N	PRESENT	0
231289	220076	14169X	PARTICIPANT	\N	PRESENT	0
231290	220076	98024R	PARTICIPANT	\N	PRESENT	0
231291	220076	10015M	PARTICIPANT	\N	PRESENT	0
231292	220076	08010L	PARTICIPANT	\N	PRESENT	0
231293	220076	01058X	PARTICIPANT	\N	PRESENT	0
231294	220076	14157T	PARTICIPANT	\N	PRESENT	0
231295	220076	98018T	PARTICIPANT	\N	PRESENT	0
231296	220076	11077T	PARTICIPANT	\N	PRESENT	0
231297	220076	14229S	PARTICIPANT	\N	PRESENT	0
231298	220076	08052W	PARTICIPANT	\N	PRESENT	0
231299	220076	08068F	PARTICIPANT	\N	PRESENT	0
231300	220076	14071N	PARTICIPANT	\N	PRESENT	0
231301	220076	14051J	PARTICIPANT	\N	PRESENT	0
231302	220076	11033F	PARTICIPANT	\N	PRESENT	0
231303	220076	04038G	PARTICIPANT	\N	PRESENT	0
231304	220076	19347U	PARTICIPANT	\N	PRESENT	0
231305	220076	12041X	PARTICIPANT	\N	PRESENT	0
231306	220076	11056N	PARTICIPANT	\N	PRESENT	0
231307	220076	14235Q	PARTICIPANT	\N	PRESENT	0
231308	220076	11063M	PARTICIPANT	\N	PRESENT	0
231310	220076	19695N	PARTICIPANT	\N	PRESENT	0
231311	220076	19565D	PARTICIPANT	\N	PRESENT	0
231312	220076	19687N	PARTICIPANT	\N	PRESENT	0
231313	231309	14147R	PARTICIPANT	\N	PRESENT	0
231314	220076	19593H	PARTICIPANT	\N	PRESENT	0
231315	231309	04047H	PARTICIPANT	\N	PRESENT	0
231316	220076	14225N	PARTICIPANT	\N	PRESENT	0
231317	231309	19581D	PARTICIPANT	\N	PRESENT	0
231318	220076	08028W	PARTICIPANT	\N	PRESENT	0
231319	231309	19649G	PARTICIPANT	\N	PRESENT	0
231320	220076	19515S	PARTICIPANT	\N	PRESENT	0
231321	220076	95063L	PARTICIPANT	\N	PRESENT	0
231322	220076	19707Y	PARTICIPANT	\N	PRESENT	0
231323	231309	14030Q	PARTICIPANT	\N	PRESENT	0
231324	231309	11045K	PARTICIPANT	\N	PRESENT	0
231325	220076	95037J	PARTICIPANT	\N	PRESENT	0
231326	220076	08020N	PARTICIPANT	\N	PRESENT	0
231327	220076	98029W	PARTICIPANT	\N	PRESENT	0
231328	220076	04047H	PARTICIPANT	\N	PRESENT	0
231329	220076	04034C	PARTICIPANT	\N	PRESENT	0
231330	220076	19651A	PARTICIPANT	\N	PRESENT	0
231331	220076	14239U	PARTICIPANT	\N	PRESENT	0
231332	220076	19637C	PARTICIPANT	\N	PRESENT	0
231333	220076	19697Q	PARTICIPANT	\N	PRESENT	0
231334	220076	08021P	PARTICIPANT	\N	PRESENT	0
231335	220076	11072N	PARTICIPANT	\N	PRESENT	0
231336	220076	11031D	PARTICIPANT	\N	PRESENT	0
231337	220076	04042C	PARTICIPANT	\N	PRESENT	0
231338	220076	14021P	PARTICIPANT	\N	PRESENT	0
231339	220076	95041E	PARTICIPANT	\N	PRESENT	0
231340	220076	19731Y	PARTICIPANT	\N	PRESENT	0
231341	220076	19685L	PARTICIPANT	\N	PRESENT	0
231342	220076	14253S	PARTICIPANT	\N	PRESENT	0
231343	220076	14199E	PARTICIPANT	\N	PRESENT	0
231344	220076	11012A	PARTICIPANT	\N	PRESENT	0
231345	220076	08031R	PARTICIPANT	\N	PRESENT	0
231346	220076	14119M	PARTICIPANT	\N	PRESENT	0
231347	220076	19253P	PARTICIPANT	\N	PRESENT	0
231348	220076	14079W	PARTICIPANT	\N	PRESENT	0
231349	220076	11083R	PARTICIPANT	\N	PRESENT	0
231351	220076	19629C	PARTICIPANT	\N	PRESENT	0
231352	220076	08049C	PARTICIPANT	\N	PRESENT	0
231353	231350	14147R	PARTICIPANT	\N	PRESENT	0
231354	220076	08034U	PARTICIPANT	\N	PRESENT	0
231355	220076	11081P	PARTICIPANT	\N	PRESENT	0
231356	231350	14231L	PARTICIPANT	\N	PRESENT	0
231357	220076	19563B	PARTICIPANT	\N	PRESENT	0
231358	220076	98022P	PARTICIPANT	\N	PRESENT	0
231359	220076	14241N	PARTICIPANT	\N	PRESENT	0
231360	220076	19681G	PARTICIPANT	\N	PRESENT	0
231361	220076	01043Q	PARTICIPANT	\N	PRESENT	0
231362	220076	11099A	PARTICIPANT	\N	PRESENT	0
231363	220076	19367Y	PARTICIPANT	\N	PRESENT	0
231364	220076	19717B	PARTICIPANT	\N	PRESENT	0
231365	220076	14042U	PARTICIPANT	\N	PRESENT	0
231366	220076	11097X	PARTICIPANT	\N	PRESENT	0
231367	220076	19553Y	PARTICIPANT	\N	PRESENT	0
231368	220076	19719D	PARTICIPANT	\N	PRESENT	0
231369	220076	07034Q	PARTICIPANT	\N	PRESENT	0
231370	230911	14147R	PARTICIPANT	\N	PRESENT	0
231371	220076	14083S	PARTICIPANT	\N	PRESENT	0
231372	220076	14093U	PARTICIPANT	\N	PRESENT	0
231373	220076	14073Q	PARTICIPANT	\N	PRESENT	0
231374	220076	95030B	PARTICIPANT	\N	PRESENT	0
231375	220076	19545Y	PARTICIPANT	\N	PRESENT	0
231376	220076	14111D	PARTICIPANT	\N	PRESENT	0
231377	220076	19585H	PARTICIPANT	\N	PRESENT	0
231378	220076	17589D	PARTICIPANT	\N	PRESENT	0
231379	220076	08056B	PARTICIPANT	\N	PRESENT	0
231380	220076	11064N	PARTICIPANT	\N	PRESENT	0
231381	220076	19583F	PARTICIPANT	\N	PRESENT	0
231382	220076	14251Q	PARTICIPANT	\N	PRESENT	0
231383	220076	14195A	PARTICIPANT	\N	PRESENT	0
231384	220076	08044W	PARTICIPANT	\N	PRESENT	0
231385	220076	04057K	PARTICIPANT	\N	PRESENT	0
231386	220076	02002K	PARTICIPANT	\N	PRESENT	0
231387	220076	07004J	PARTICIPANT	\N	PRESENT	0
231388	220076	01060R	PARTICIPANT	\N	PRESENT	0
212593	207689	14059S	PARTICIPANT	\N	PRESENT	0
212594	207689	17589D	PARTICIPANT	\N	PRESENT	0
212595	207689	19705W	PARTICIPANT	\N	PRESENT	0
212596	207689	14034U	PARTICIPANT	\N	PRESENT	0
212597	207689	07029T	PARTICIPANT	\N	PRESENT	0
212598	207689	14241N	PARTICIPANT	\N	PRESENT	0
212599	207689	98022P	PARTICIPANT	\N	PRESENT	0
212600	207689	11099A	PARTICIPANT	\N	PRESENT	0
212601	207689	19387D	PARTICIPANT	\N	PRESENT	0
212602	207689	19563B	PARTICIPANT	\N	PRESENT	0
212603	207689	04057K	PARTICIPANT	\N	PRESENT	0
212604	207689	02002K	PARTICIPANT	\N	PRESENT	0
212605	207689	19545Y	PARTICIPANT	\N	PRESENT	0
212606	207689	11065P	PARTICIPANT	\N	PRESENT	0
212607	207689	19585H	PARTICIPANT	\N	PRESENT	0
212608	207689	14111D	PARTICIPANT	\N	PRESENT	0
212609	207689	14093U	PARTICIPANT	\N	PRESENT	0
212610	207689	19289C	PARTICIPANT	\N	PRESENT	0
212611	207689	14253S	PARTICIPANT	\N	PRESENT	0
212612	207689	14041T	PARTICIPANT	\N	PRESENT	0
212613	207689	14217N	PARTICIPANT	\N	PRESENT	0
212614	207689	19721W	PARTICIPANT	\N	PRESENT	0
212615	207689	07004J	PARTICIPANT	\N	PRESENT	0
212616	207689	08062Y	PARTICIPANT	\N	PRESENT	0
212617	207689	14030Q	PARTICIPANT	\N	PRESENT	0
212618	207689	04040A	PARTICIPANT	\N	PRESENT	0
212619	207689	14089Y	PARTICIPANT	\N	PRESENT	0
212620	207689	14073Q	PARTICIPANT	\N	PRESENT	0
212621	207689	14255U	PARTICIPANT	\N	PRESENT	0
212622	207689	14083S	PARTICIPANT	\N	PRESENT	0
212623	207689	11053K	PARTICIPANT	\N	PRESENT	0
212624	207689	01057W	PARTICIPANT	\N	PRESENT	0
212625	207689	14267Y	PARTICIPANT	\N	PRESENT	0
212626	207689	04049K	PARTICIPANT	\N	PRESENT	0
212627	207689	19713W	PARTICIPANT	\N	PRESENT	0
212628	207689	14327T	PARTICIPANT	\N	PRESENT	0
212629	207689	11070L	PARTICIPANT	\N	PRESENT	0
212630	207689	19643A	PARTICIPANT	\N	PRESENT	0
212631	207689	11085T	PARTICIPANT	\N	PRESENT	0
212632	207689	01024M	PARTICIPANT	\N	PRESENT	0
212633	207689	19369B	PARTICIPANT	\N	PRESENT	0
212634	207689	14042U	PARTICIPANT	\N	PRESENT	0
212635	207689	04089T	PARTICIPANT	\N	PRESENT	0
212636	207689	04070G	PARTICIPANT	\N	PRESENT	0
212637	207689	04088S	PARTICIPANT	\N	PRESENT	0
212638	207689	01043Q	PARTICIPANT	\N	PRESENT	0
212639	207689	19691J	PARTICIPANT	\N	PRESENT	0
212640	207689	14029X	PARTICIPANT	\N	PRESENT	0
212641	207689	19319Q	PARTICIPANT	\N	PRESENT	0
212642	207689	19521Q	PARTICIPANT	\N	PRESENT	0
212643	207689	14205J	PARTICIPANT	\N	PRESENT	0
212644	207689	19441R	PARTICIPANT	\N	PRESENT	0
212645	207689	08009T	PARTICIPANT	\N	PRESENT	0
212646	207689	08056B	PARTICIPANT	\N	PRESENT	0
212647	207689	19569H	PARTICIPANT	\N	PRESENT	0
212648	207689	19573D	PARTICIPANT	\N	PRESENT	0
212649	207689	19735D	PARTICIPANT	\N	PRESENT	0
212650	207689	19709B	PARTICIPANT	\N	PRESENT	0
212651	207689	19511N	PARTICIPANT	\N	PRESENT	0
212652	207689	14277B	PARTICIPANT	\N	PRESENT	0
212653	207689	14275Y	PARTICIPANT	\N	PRESENT	0
212654	207689	08044W	PARTICIPANT	\N	PRESENT	0
212655	207689	19611R	PARTICIPANT	\N	PRESENT	0
212656	207689	19663E	PARTICIPANT	\N	PRESENT	0
212657	207689	19699S	PARTICIPANT	\N	PRESENT	0
212658	207689	14219Q	PARTICIPANT	\N	PRESENT	0
212659	207689	05008E	PARTICIPANT	\N	PRESENT	0
212660	207689	14221J	PARTICIPANT	\N	PRESENT	0
212661	207689	14251Q	PARTICIPANT	\N	PRESENT	0
212662	207689	19723Y	PARTICIPANT	\N	PRESENT	0
212663	207689	11074Q	PARTICIPANT	\N	PRESENT	0
212664	207689	19507S	PARTICIPANT	\N	PRESENT	0
212665	207689	19335Q	PARTICIPANT	\N	PRESENT	0
212666	207689	19467C	PARTICIPANT	\N	PRESENT	0
212667	207689	19479G	PARTICIPANT	\N	PRESENT	0
212668	207689	19737F	PARTICIPANT	\N	PRESENT	0
212669	207689	18083K	PARTICIPANT	\N	PRESENT	0
212670	207689	19415P	PARTICIPANT	\N	PRESENT	0
212671	207689	14033T	PARTICIPANT	\N	PRESENT	0
212672	207689	14119M	PARTICIPANT	\N	PRESENT	0
212673	207689	19667J	PARTICIPANT	\N	PRESENT	0
212674	207689	19675J	PARTICIPANT	\N	PRESENT	0
212675	207689	19399H	PARTICIPANT	\N	PRESENT	0
212676	207689	19533U	PARTICIPANT	\N	PRESENT	0
212677	207689	14147R	PARTICIPANT	\N	PRESENT	0
212678	207689	19729F	PARTICIPANT	\N	PRESENT	0
212679	207689	14115H	PARTICIPANT	\N	PRESENT	0
212684	207689	19701S	PARTICIPANT	\N	PRESENT	0
212681	207689	19733B	PARTICIPANT	\N	PRESENT	0
212682	207689	19575F	PARTICIPANT	\N	PRESENT	0
212683	207689	14105F	PARTICIPANT	\N	PRESENT	0
212685	207689	17637T	PARTICIPANT	\N	PRESENT	0
212686	207689	11064N	PARTICIPANT	\N	PRESENT	0
212687	207689	16685X	PARTICIPANT	\N	PRESENT	0
212688	207689	80027E	PARTICIPANT	\N	PRESENT	0
212698	207689	19619A	PARTICIPANT	\N	PRESENT	0
212690	207689	12016W	PARTICIPANT	\N	PRESENT	0
212691	207689	01062T	PARTICIPANT	\N	PRESENT	0
212693	207689	19659J	PARTICIPANT	\N	PRESENT	0
212697	207689	95041E	PARTICIPANT	\N	PRESENT	0
212695	207689	14231L	PARTICIPANT	\N	PRESENT	0
212696	207689	01034P	PARTICIPANT	\N	PRESENT	0
212699	207689	08035V	PARTICIPANT	\N	PRESENT	0
212970	210032	11070L	PARTICIPANT	\N	PRESENT	0
212971	210974	11067R	PARTICIPANT	\N	PRESENT	0
212989	210032	19629C	PARTICIPANT	\N	PRESENT	0
212991	210032	19737F	PARTICIPANT	\N	PRESENT	0
212992	210032	14231L	PARTICIPANT	\N	PRESENT	0
212993	210032	14219Q	PARTICIPANT	\N	PRESENT	0
212994	210032	14073Q	PARTICIPANT	\N	PRESENT	0
212995	210032	19369B	PARTICIPANT	\N	PRESENT	0
212996	210032	19329S	PARTICIPANT	\N	PRESENT	0
212998	210032	19659J	PARTICIPANT	\N	PRESENT	0
213000	210032	19715Y	PARTICIPANT	\N	PRESENT	0
213001	210032	12016W	PARTICIPANT	\N	PRESENT	0
213002	210032	19599P	PARTICIPANT	\N	PRESENT	0
213003	210032	14051J	PARTICIPANT	\N	PRESENT	0
213004	210032	14121F	PARTICIPANT	\N	PRESENT	0
213005	210032	19591F	PARTICIPANT	\N	PRESENT	0
213008	210032	19367Y	PARTICIPANT	\N	PRESENT	0
213009	210032	14055N	PARTICIPANT	\N	PRESENT	0
213010	210032	04018C	PARTICIPANT	\N	PRESENT	0
213011	210032	14081Q	PARTICIPANT	\N	PRESENT	0
213012	210032	08015R	PARTICIPANT	\N	PRESENT	0
213013	210032	18083K	PARTICIPANT	\N	PRESENT	0
213015	210032	19507S	PARTICIPANT	\N	PRESENT	0
213017	210032	19713W	PARTICIPANT	\N	PRESENT	0
213018	210032	19319Q	PARTICIPANT	\N	PRESENT	0
213019	210032	14327T	PARTICIPANT	\N	PRESENT	0
213020	210032	19479G	PARTICIPANT	\N	PRESENT	0
213021	210032	19735D	PARTICIPANT	\N	PRESENT	0
213022	210032	11012A	PARTICIPANT	\N	PRESENT	0
213023	210032	19413M	PARTICIPANT	\N	PRESENT	0
213024	210032	19503N	PARTICIPANT	\N	PRESENT	0
213025	210032	19689Q	PARTICIPANT	\N	PRESENT	0
213026	210032	08055A	PARTICIPANT	\N	PRESENT	0
213027	210032	19687N	PARTICIPANT	\N	PRESENT	0
213028	210032	04085P	PARTICIPANT	\N	PRESENT	0
213029	210032	19697Q	PARTICIPANT	\N	PRESENT	0
213030	210032	14031R	PARTICIPANT	\N	PRESENT	0
213031	210032	19667J	PARTICIPANT	\N	PRESENT	0
213032	210032	14261S	PARTICIPANT	\N	PRESENT	0
213033	210032	11064N	PARTICIPANT	\N	PRESENT	0
213034	210032	08019V	PARTICIPANT	\N	PRESENT	0
213035	210032	19399H	PARTICIPANT	\N	PRESENT	0
213036	210032	19693L	PARTICIPANT	\N	PRESENT	0
213037	210032	19703U	PARTICIPANT	\N	PRESENT	0
213038	210032	19447X	PARTICIPANT	\N	PRESENT	0
213039	210032	19631V	PARTICIPANT	\N	PRESENT	0
213040	210032	08010L	PARTICIPANT	\N	PRESENT	0
213042	210032	16685X	PARTICIPANT	\N	PRESENT	0
213043	210032	19575F	PARTICIPANT	\N	PRESENT	0
213044	210032	19593H	PARTICIPANT	\N	PRESENT	0
213045	210032	19525U	PARTICIPANT	\N	PRESENT	0
213046	210032	19301E	PARTICIPANT	\N	PRESENT	0
213047	210032	14221J	PARTICIPANT	\N	PRESENT	0
213048	210032	01048V	PARTICIPANT	\N	PRESENT	0
213050	210032	14083S	PARTICIPANT	\N	PRESENT	0
213051	210032	14267Y	PARTICIPANT	\N	PRESENT	0
213052	210032	19711U	PARTICIPANT	\N	PRESENT	0
213053	210032	17637T	PARTICIPANT	\N	PRESENT	0
213054	210032	19695N	PARTICIPANT	\N	PRESENT	0
213055	210032	19573D	PARTICIPANT	\N	PRESENT	0
213056	210032	14257W	PARTICIPANT	\N	PRESENT	0
213057	210032	08024S	PARTICIPANT	\N	PRESENT	0
213058	210032	11077T	PARTICIPANT	\N	PRESENT	0
213060	210032	11099A	PARTICIPANT	\N	PRESENT	0
224576	218298	14187A	PARTICIPANT	\N	PRESENT	0
224577	218298	04057K	PARTICIPANT	\N	PRESENT	0
224578	218298	14111D	PARTICIPANT	\N	PRESENT	0
224579	218298	19545Y	PARTICIPANT	\N	PRESENT	0
224580	218298	19723Y	PARTICIPANT	\N	PRESENT	0
224581	218298	08073C	PARTICIPANT	\N	PRESENT	0
224582	218298	04042C	PARTICIPANT	\N	PRESENT	0
224754	222532	14259Y	PARTICIPANT	\N	EXCUSE	0
224584	218298	11077T	PARTICIPANT	\N	PRESENT	0
224585	218298	04059M	PARTICIPANT	\N	PRESENT	0
224586	218298	04043D	PARTICIPANT	\N	PRESENT	0
224587	218298	11074Q	PARTICIPANT	\N	PRESENT	0
224588	218298	19741B	PARTICIPANT	\N	PRESENT	0
224589	218298	08068F	PARTICIPANT	\N	PRESENT	0
224590	218298	08052W	PARTICIPANT	\N	PRESENT	0
224732	218298	14159V	PARTICIPANT	\N	PRESENT	0
224733	218298	08019V	PARTICIPANT	\N	PRESENT	0
224735	224734	14281W	PARTICIPANT	\N	EXCUSE	0
224736	224734	19553Y	PARTICIPANT	\N	EXCUSE	0
224737	218298	08011M	PARTICIPANT	\N	PRESENT	0
224738	218298	14249W	PARTICIPANT	\N	PRESENT	0
224739	218298	19657G	PARTICIPANT	\N	PRESENT	0
224740	218298	14069U	PARTICIPANT	\N	PRESENT	0
224749	218298	95041E	PARTICIPANT	\N	PRESENT	0
224747	218298	05008E	PARTICIPANT	\N	PRESENT	0
224743	218298	19733B	PARTICIPANT	\N	PRESENT	0
224744	218298	11090Q	PARTICIPANT	\N	PRESENT	0
224745	218298	19533U	PARTICIPANT	\N	PRESENT	0
224748	218298	14231L	PARTICIPANT	\N	PRESENT	0
224750	218298	11053K	PARTICIPANT	\N	PRESENT	0
224751	218298	89017R	PARTICIPANT	\N	PRESENT	0
224923	218821	19647E	PARTICIPANT	\N	EXCUSE	0
224753	218298	14229S	PARTICIPANT	\N	PRESENT	0
225050	222532	08049C	PARTICIPANT	\N	EXCUSE	0
225069	218821	11115U	PARTICIPANT	\N	EXCUSE	0
225070	218821	99004R	PRESIDENT	0	PRESENT	0
225127	218821	19711U	PARTICIPANT	\N	EXCUSE	0
225133	218821	19713W	PARTICIPANT	\N	PRESENT	0
225142	224180	14201E	PARTICIPANT	\N	EXCUSE	0
225235	218821	19629C	PARTICIPANT	\N	EXCUSE	0
225241	218821	14147R	PARTICIPANT	\N	PRESENT	0
225354	222532	19489J	PARTICIPANT	\N	EXCUSE	0
225355	223622	19489J	PARTICIPANT	\N	PRESENT	0
225356	223625	19489J	PARTICIPANT	\N	PRESENT	0
225380	222532	14195A	PARTICIPANT	\N	PRESENT	0
225385	222532	19735D	PARTICIPANT	\N	PRESENT	0
225445	225444	19709B	PARTICIPANT	\N	PRESENT	0
225466	218821	19369B	PARTICIPANT	\N	PRESENT	0
225670	223292	19697Q	PARTICIPANT	\N	PRESENT	0
225671	223292	11067R	PARTICIPANT	\N	PRESENT	0
225672	223292	01034P	PARTICIPANT	\N	PRESENT	0
225673	223292	11097X	PRESIDENT	0	PRESENT	0
225674	223292	08052W	PARTICIPANT	\N	PRESENT	0
225675	223292	19553Y	PARTICIPANT	\N	PRESENT	0
225676	223292	19727D	PARTICIPANT	\N	PRESENT	0
225677	223292	19703U	PARTICIPANT	\N	PRESENT	0
225678	223292	14239U	PARTICIPANT	\N	PRESENT	0
225679	223292	14281W	PARTICIPANT	\N	PRESENT	0
225680	223292	14087W	PARTICIPANT	\N	PRESENT	0
225681	223292	11103C	PARTICIPANT	\N	PRESENT	0
225682	223292	19575F	PARTICIPANT	\N	PRESENT	0
225683	223292	14213J	PARTICIPANT	\N	PRESENT	0
225684	223292	14217N	PARTICIPANT	\N	PRESENT	0
225685	223292	98024R	PARTICIPANT	\N	PRESENT	0
225686	223292	08048B	PARTICIPANT	\N	EXCUSE	0
225687	223292	08041T	PARTICIPANT	\N	EXCUSE	0
225688	223292	19663E	PARTICIPANT	\N	PRESENT	0
225689	223292	04045F	PARTICIPANT	\N	PRESENT	0
225690	223292	14195A	PARTICIPANT	\N	PRESENT	0
225691	223292	19657G	PARTICIPANT	\N	PRESENT	0
225692	223292	14042U	PARTICIPANT	\N	EXCUSE	0
225693	223292	19715Y	PARTICIPANT	\N	EXCUSE	0
225694	223292	14227Q	PARTICIPANT	\N	PRESENT	0
225695	223292	10006L	PARTICIPANT	\N	PRESENT	0
225696	218302	14034U	PARTICIPANT	\N	PRESENT	0
225697	223292	14071N	PARTICIPANT	\N	PRESENT	0
224574	218298	11064N	PARTICIPANT	\N	PRESENT	0
224575	218298	17589D	PARTICIPANT	\N	PRESENT	0
225716	218302	19349W	PARTICIPANT	\N	PRESENT	0
225717	218302	19711U	PARTICIPANT	\N	PRESENT	0
225718	218302	14327T	PARTICIPANT	\N	PRESENT	0
225719	218302	14225N	PARTICIPANT	\N	PRESENT	0
225720	218302	04085P	PARTICIPANT	\N	PRESENT	0
225721	218302	14021P	PARTICIPANT	\N	PRESENT	0
225722	218302	19413M	PARTICIPANT	\N	PRESENT	0
225723	218302	11067R	PARTICIPANT	\N	PRESENT	0
225724	218302	14151M	PARTICIPANT	\N	PRESENT	0
225725	218302	11026G	PARTICIPANT	\N	PRESENT	0
225726	218302	19525U	PARTICIPANT	\N	PRESENT	0
225727	218302	14227Q	PARTICIPANT	\N	PRESENT	0
225728	218302	14121F	PARTICIPANT	\N	PRESENT	0
225729	218302	04034C	PARTICIPANT	\N	PRESENT	0
225730	218302	95037J	PARTICIPANT	\N	PRESENT	0
225731	218302	88008L	PARTICIPANT	\N	PRESENT	0
225732	218302	19553Y	PARTICIPANT	\N	PRESENT	0
225733	218302	14219Q	PARTICIPANT	\N	PRESENT	0
225734	218302	19737F	PARTICIPANT	\N	PRESENT	0
225735	218302	14255U	PARTICIPANT	\N	PRESENT	0
225736	218302	07004J	PARTICIPANT	\N	PRESENT	0
225737	218302	19421M	PARTICIPANT	\N	PRESENT	0
225738	218302	19731Y	PARTICIPANT	\N	PRESENT	0
225739	218302	11103C	PARTICIPANT	\N	PRESENT	0
225740	218302	14217N	PARTICIPANT	\N	PRESENT	0
225741	218302	08010L	PARTICIPANT	\N	PRESENT	0
225742	218302	19657G	PARTICIPANT	\N	PRESENT	0
225743	218302	14157T	PARTICIPANT	\N	PRESENT	0
225744	218302	18083K	PARTICIPANT	\N	PRESENT	0
225745	218302	19467C	PARTICIPANT	\N	PRESENT	0
225746	218302	19447X	PARTICIPANT	\N	PRESENT	0
225747	218302	01028R	PARTICIPANT	\N	PRESENT	0
225748	218302	14041T	PARTICIPANT	\N	PRESENT	0
225749	218302	08061X	PARTICIPANT	\N	PRESENT	0
225750	218302	14195A	PARTICIPANT	\N	PRESENT	0
225751	218302	14215L	PARTICIPANT	\N	PRESENT	0
225752	218302	14085U	PARTICIPANT	\N	PRESENT	0
225753	218302	19611R	PARTICIPANT	\N	PRESENT	0
225754	218302	08053X	PARTICIPANT	\N	PRESENT	0
225755	218302	19649G	PARTICIPANT	\N	PRESENT	0
225756	218302	19531S	PARTICIPANT	\N	PRESENT	0
225757	218302	19581D	PARTICIPANT	\N	PRESENT	0
225758	218302	19671E	PARTICIPANT	\N	PRESENT	0
225759	218302	14267Y	PARTICIPANT	\N	PRESENT	0
225760	218302	19689Q	PARTICIPANT	\N	PRESENT	0
225761	218302	19725B	PARTICIPANT	\N	PRESENT	0
225762	218302	19699S	PARTICIPANT	\N	PRESENT	0
225763	218302	10006L	PARTICIPANT	\N	PRESENT	0
225764	218302	11027H	PARTICIPANT	\N	PRESENT	0
225765	218302	19575F	PARTICIPANT	\N	PRESENT	0
225766	218302	19713W	PARTICIPANT	\N	PRESENT	0
225767	218302	19333N	PARTICIPANT	\N	PRESENT	0
225768	218302	14063N	PARTICIPANT	\N	PRESENT	0
225769	218302	14073Q	PARTICIPANT	\N	PRESENT	0
225770	218302	14281W	PARTICIPANT	\N	PRESENT	0
225771	218302	19479G	PARTICIPANT	\N	PRESENT	0
225772	218302	14331P	PARTICIPANT	\N	PRESENT	0
225775	218302	11070L	PARTICIPANT	\N	PRESENT	0
225776	218302	07029T	PARTICIPANT	\N	PRESENT	0
225777	218302	11097X	PARTICIPANT	\N	PRESENT	0
225778	218302	19443T	PARTICIPANT	\N	PRESENT	0
225779	218302	14001X	PARTICIPANT	\N	PRESENT	0
225780	218302	19591F	PARTICIPANT	\N	PRESENT	0
225781	218302	19673G	PARTICIPANT	\N	PRESENT	0
225782	218302	19549D	PARTICIPANT	\N	PRESENT	0
225783	218302	04057K	PARTICIPANT	\N	PRESENT	0
225784	218302	14213J	PARTICIPANT	\N	PRESENT	0
225785	218302	14357A	PARTICIPANT	\N	PRESENT	0
225786	218302	14061L	PARTICIPANT	\N	PRESENT	0
225787	218302	19683J	PARTICIPANT	\N	PRESENT	0
225788	218302	08016S	PARTICIPANT	\N	PRESENT	0
225789	218302	14042U	PARTICIPANT	\N	PRESENT	0
225790	218302	19637C	PARTICIPANT	\N	PRESENT	0
225817	218302	17779H	PARTICIPANT	\N	PRESENT	0
225818	218302	19387D	PARTICIPANT	\N	PRESENT	0
225819	218302	14239U	PARTICIPANT	\N	PRESENT	0
225820	218302	11031D	PARTICIPANT	\N	PRESENT	0
225825	218302	14147R	PARTICIPANT	\N	PRESENT	0
225822	218302	17637T	PARTICIPANT	\N	PRESENT	0
225823	218302	19251M	PARTICIPANT	\N	PRESENT	0
225824	218302	19741B	PARTICIPANT	\N	PRESENT	0
225826	218302	11040E	PARTICIPANT	\N	PRESENT	0
225827	218303	11072N	PARTICIPANT	\N	PRESENT	0
225828	218303	14042U	PARTICIPANT	\N	PRESENT	0
225829	218303	95041E	PARTICIPANT	\N	PRESENT	0
225831	218303	14213J	PARTICIPANT	\N	PRESENT	0
225832	218303	14227Q	PARTICIPANT	\N	PRESENT	0
225833	218303	14225N	PARTICIPANT	\N	PRESENT	0
225834	218303	19683J	PARTICIPANT	\N	PRESENT	0
225835	218303	19467C	PARTICIPANT	\N	PRESENT	0
225836	218303	19577H	PARTICIPANT	\N	PRESENT	0
213137	213136	19545Y	PARTICIPANT	\N	PRESENT	0
213138	213136	19689Q	PARTICIPANT	\N	PRESENT	0
213141	213140	19545Y	PARTICIPANT	\N	PRESENT	0
213142	213140	19689Q	PARTICIPANT	\N	PRESENT	0
213144	213143	01048V	PARTICIPANT	\N	PRESENT	0
213146	213145	11040E	PARTICIPANT	\N	PRESENT	0
213147	213145	19667J	PARTICIPANT	\N	PRESENT	0
213149	213148	11040E	PARTICIPANT	\N	PRESENT	0
213150	213148	19667J	PARTICIPANT	\N	PRESENT	0
213152	213151	11040E	PARTICIPANT	\N	PRESENT	0
213153	213151	19667J	PARTICIPANT	\N	PRESENT	0
213155	213154	89017R	PARTICIPANT	\N	PRESENT	0
215598	214493	14267Y	PARTICIPANT	\N	EXCUSE	0
215599	214493	08056B	PARTICIPANT	\N	EXCUSE	0
215600	214493	19583F	PARTICIPANT	\N	EXCUSE	0
215904	205652	19723Y	PARTICIPANT	\N	PRESENT	0
216175	214626	14133K	PARTICIPANT	\N	PRESENT	0
216176	214626	96004D	PRESIDENT	0	PRESENT	0
216177	214626	14089Y	PARTICIPANT	\N	PRESENT	0
216178	214626	08014Q	PARTICIPANT	\N	PRESENT	0
216180	214626	14357A	PARTICIPANT	\N	PRESENT	0
216181	214626	14079W	PARTICIPANT	\N	PRESENT	0
216182	214626	14249W	PARTICIPANT	\N	PRESENT	0
216183	214626	08018U	PARTICIPANT	\N	EXCUSE	0
216184	214626	11083R	PARTICIPANT	\N	PRESENT	0
216185	214626	14033T	PARTICIPANT	\N	PRESENT	0
216186	214626	19725B	PARTICIPANT	\N	PRESENT	0
216187	214626	95037J	PARTICIPANT	\N	PRESENT	0
216188	214626	19685L	PARTICIPANT	\N	EXCUSE	0
216189	214626	14097Y	PARTICIPANT	\N	PRESENT	0
216190	214626	14073Q	PARTICIPANT	\N	PRESENT	0
216191	214626	14001X	PARTICIPANT	\N	PRESENT	0
216192	214626	19563B	PARTICIPANT	\N	PRESENT	0
216193	214626	14237S	PARTICIPANT	\N	PRESENT	0
216194	214626	14331P	PARTICIPANT	\N	PRESENT	0
216195	214626	14229S	PARTICIPANT	\N	PRESENT	0
216196	214626	98035U	PARTICIPANT	\N	PRESENT	0
217640	207709	19697Q	PARTICIPANT	\N	PRESENT	0
217641	207709	04045F	PARTICIPANT	\N	PRESENT	0
217642	207709	19335Q	PARTICIPANT	\N	PRESENT	0
217643	207709	19367Y	PARTICIPANT	\N	PRESENT	0
217644	207709	19671E	PARTICIPANT	\N	PRESENT	0
217645	207709	11097X	PARTICIPANT	\N	PRESENT	0
217646	207709	95041E	PARTICIPANT	\N	PRESENT	0
217647	207709	14071N	PARTICIPANT	\N	PRESENT	0
217648	207709	04044E	PARTICIPANT	\N	PRESENT	0
217649	207709	11103C	PARTICIPANT	\N	PRESENT	0
217650	207709	04086Q	PARTICIPANT	\N	PRESENT	0
217651	207709	19583F	PARTICIPANT	\N	PRESENT	0
217652	207709	10006L	PARTICIPANT	\N	PRESENT	0
217653	207709	14217N	PARTICIPANT	\N	PRESENT	0
217654	207709	19723Y	PARTICIPANT	\N	PRESENT	0
217655	207709	19689Q	PARTICIPANT	\N	PRESENT	0
217656	207709	19467C	PARTICIPANT	\N	PRESENT	0
217657	207709	19649G	PARTICIPANT	\N	PRESENT	0
217658	207709	14041T	PARTICIPANT	\N	PRESENT	0
217659	207709	14213J	PARTICIPANT	\N	PRESENT	0
217660	207709	19657G	PARTICIPANT	\N	PRESENT	0
217663	207709	19693L	PARTICIPANT	\N	PRESENT	0
217665	207709	99004R	PARTICIPANT	\N	PRESENT	0
217664	207709	19575F	PARTICIPANT	\N	PRESENT	0
217666	207709	19711U	PARTICIPANT	\N	PRESENT	0
217667	207709	19415P	PARTICIPANT	\N	PRESENT	0
217668	207709	98024R	PARTICIPANT	\N	PRESENT	0
217669	207709	11063M	PARTICIPANT	\N	PRESENT	0
217670	207709	08016S	PARTICIPANT	\N	PRESENT	0
217671	207709	19301E	PARTICIPANT	\N	PRESENT	0
217684	207709	19621T	PARTICIPANT	\N	PRESENT	0
217699	207709	08019V	PARTICIPANT	\N	PRESENT	0
217700	207709	04061F	PARTICIPANT	\N	PRESENT	0
217701	207709	19663E	PARTICIPANT	\N	PRESENT	0
217702	207709	14231L	PARTICIPANT	\N	PRESENT	0
217703	207709	14157T	PARTICIPANT	\N	PRESENT	0
217704	207709	19725B	PARTICIPANT	\N	PRESENT	0
217706	207709	14223L	PARTICIPANT	\N	PRESENT	0
220464	220463	01024M	PARTICIPANT	\N	PRESENT	0
220466	220465	01024M	PARTICIPANT	\N	PRESENT	0
221507	220317	04044E	PARTICIPANT	\N	PRESENT	0
221508	219746	19527W	PARTICIPANT	\N	PRESENT	0
221509	219746	04092N	PRESIDENT	0	PRESENT	0
221510	219746	14355X	PARTICIPANT	\N	PRESENT	0
221511	219746	11097X	PARTICIPANT	\N	PRESENT	0
221512	219746	08052W	PARTICIPANT	\N	PRESENT	0
221513	219746	19415P	PARTICIPANT	\N	PRESENT	0
221514	219746	19691J	PARTICIPANT	\N	PRESENT	0
221515	219746	08041T	PARTICIPANT	\N	PRESENT	0
221516	219746	19675J	PARTICIPANT	\N	PRESENT	0
221517	219746	11103C	PARTICIPANT	\N	PRESENT	0
221518	219746	14195A	PARTICIPANT	\N	PRESENT	0
221519	219746	19367Y	PARTICIPANT	\N	PRESENT	0
221520	219746	14213J	PARTICIPANT	\N	PRESENT	0
221521	219746	14071N	PARTICIPANT	\N	PRESENT	0
221522	219746	14217N	PARTICIPANT	\N	PRESENT	0
221523	219746	98024R	PARTICIPANT	\N	PRESENT	0
221524	219746	19697Q	PARTICIPANT	\N	PRESENT	0
221525	219746	19727D	PARTICIPANT	\N	PRESENT	0
221526	219746	19577H	PARTICIPANT	\N	PRESENT	0
221527	219746	14223L	PARTICIPANT	\N	PRESENT	0
221528	219746	11063M	PARTICIPANT	\N	PRESENT	0
221529	219746	19703U	PARTICIPANT	\N	PRESENT	0
221530	219746	14239U	PARTICIPANT	\N	PRESENT	0
221531	219746	19575F	PARTICIPANT	\N	PRESENT	0
221532	219746	19715Y	PARTICIPANT	\N	PRESENT	0
221533	219746	14119M	PARTICIPANT	\N	PRESENT	0
221534	219746	19657G	PARTICIPANT	\N	PRESENT	0
221535	219746	14281W	PARTICIPANT	\N	PRESENT	0
221536	219746	10006L	PARTICIPANT	\N	PRESENT	0
221538	219746	19553Y	PARTICIPANT	\N	PRESENT	0
221539	219746	11067R	PARTICIPANT	\N	PRESENT	0
221540	219746	19521Q	PARTICIPANT	\N	PRESENT	0
221541	219746	19723Y	PARTICIPANT	\N	PRESENT	0
221542	219746	14261S	PARTICIPANT	\N	PRESENT	0
221544	219746	04045F	PARTICIPANT	\N	PRESENT	0
221545	219746	08048B	PARTICIPANT	\N	EXCUSE	0
221546	219746	14042U	PARTICIPANT	\N	PRESENT	0
221547	220317	14001X	PARTICIPANT	\N	PRESENT	0
221548	220317	04047H	PARTICIPANT	\N	PRESENT	0
221549	220317	19673G	PARTICIPANT	\N	PRESENT	0
221550	220317	01028R	PARTICIPANT	\N	PRESENT	0
221551	220317	19447X	PARTICIPANT	\N	PRESENT	0
221552	220317	05008E	PRESIDENT	0	PRESENT	0
221553	220317	19489J	PARTICIPANT	\N	PRESENT	0
221554	220317	14275Y	PARTICIPANT	\N	PRESENT	0
221555	220317	14179A	PARTICIPANT	\N	PRESENT	0
221556	220317	14147R	PARTICIPANT	\N	PRESENT	0
221557	220317	14151M	PARTICIPANT	\N	PRESENT	0
221558	220317	19483C	PARTICIPANT	\N	PRESENT	0
221559	220317	11072N	PARTICIPANT	\N	PRESENT	0
221560	220317	14053L	PARTICIPANT	\N	PRESENT	0
221561	220317	98035U	PARTICIPANT	\N	PRESENT	0
221562	220317	14111D	PARTICIPANT	\N	PRESENT	0
221563	220317	14065Q	PARTICIPANT	\N	PRESENT	0
221564	220317	11010L	PARTICIPANT	\N	PRESENT	0
221565	220317	07034Q	PARTICIPANT	\N	PRESENT	0
221566	220317	08045X	PARTICIPANT	\N	PRESENT	0
221567	220317	19253P	PARTICIPANT	\N	PRESENT	0
221568	220317	01024M	PARTICIPANT	\N	PRESENT	0
221569	220317	04038G	PARTICIPANT	\N	PRESENT	0
221570	220317	19719D	PARTICIPANT	\N	PRESENT	0
221571	220317	11033F	PARTICIPANT	\N	PRESENT	0
221572	220317	19725B	PARTICIPANT	\N	PRESENT	0
221573	220317	14089Y	PARTICIPANT	\N	PRESENT	0
221574	220317	19729F	PARTICIPANT	\N	PRESENT	0
221575	220317	19629C	PARTICIPANT	\N	PRESENT	0
221576	220317	11085T	PARTICIPANT	\N	PRESENT	0
221577	220317	04008A	PARTICIPANT	\N	PRESENT	0
221578	220317	19649G	PARTICIPANT	\N	PRESENT	0
221579	221367	04070G	PRESIDENT	0	PRESENT	0
221580	221367	19699S	PARTICIPANT	\N	PRESENT	0
221581	221367	12041X	PARTICIPANT	\N	PRESENT	0
221582	221367	19533U	PARTICIPANT	\N	PRESENT	0
221583	221367	95015C	PARTICIPANT	\N	PRESENT	0
221584	221367	04033B	PARTICIPANT	\N	PRESENT	0
221585	221367	14229S	PARTICIPANT	\N	PRESENT	0
221586	221367	14241N	PARTICIPANT	\N	PRESENT	0
221587	221367	14039A	PARTICIPANT	\N	PRESENT	0
221588	221367	14107H	PARTICIPANT	\N	PRESENT	0
221589	221367	08017T	PARTICIPANT	\N	PRESENT	0
221590	221367	07033P	PARTICIPANT	\N	PRESENT	0
221591	221367	08012N	PARTICIPANT	\N	PRESENT	0
221592	221367	08016S	PARTICIPANT	\N	PRESENT	0
221593	221367	14249W	PARTICIPANT	\N	PRESENT	0
221594	221367	08039A	PARTICIPANT	\N	PRESENT	0
221595	221367	08031R	PARTICIPANT	\N	PRESENT	0
221596	221367	19593H	PARTICIPANT	\N	PRESENT	0
221597	221367	14059S	PARTICIPANT	\N	PRESENT	0
221598	221367	14061L	PARTICIPANT	\N	PRESENT	0
231389	220076	11074Q	PARTICIPANT	\N	PRESENT	0
231390	220076	14159V	PARTICIPANT	\N	PRESENT	0
231391	220076	08009T	PARTICIPANT	\N	PRESENT	0
231392	220076	01028R	PARTICIPANT	\N	PRESENT	0
231393	220076	14001X	PARTICIPANT	\N	PRESENT	0
231394	220076	14063N	PARTICIPANT	\N	PRESENT	0
231395	220076	19727D	PARTICIPANT	\N	PRESENT	0
231396	220076	11085T	PARTICIPANT	\N	PRESENT	0
231397	220076	01024M	PARTICIPANT	\N	PRESENT	0
231398	220076	04033B	PARTICIPANT	\N	PRESENT	0
231399	220076	08016S	PARTICIPANT	\N	PRESENT	0
231400	220076	14107H	PARTICIPANT	\N	PRESENT	0
231401	220076	08039A	PARTICIPANT	\N	PRESENT	0
231402	220076	19577H	PARTICIPANT	\N	PRESENT	0
231403	220076	08045X	PARTICIPANT	\N	PRESENT	0
231404	220076	97011G	PARTICIPANT	\N	PRESENT	0
231417	220076	14205J	PARTICIPANT	\N	PRESENT	0
231406	220076	14187A	PARTICIPANT	\N	PRESENT	0
231407	220076	19647E	PARTICIPANT	\N	PRESENT	0
231408	220076	14197C	PARTICIPANT	\N	PRESENT	0
231590	220077	14034U	PARTICIPANT	\N	PRESENT	0
231410	220076	19543W	PARTICIPANT	\N	PRESENT	0
231411	220076	19749K	PARTICIPANT	\N	PRESENT	0
231412	220076	08017T	PARTICIPANT	\N	PRESENT	0
231413	220076	19649G	PARTICIPANT	\N	PRESENT	0
231414	220076	14030Q	PARTICIPANT	\N	PRESENT	0
231415	220076	80013X	PARTICIPANT	\N	PRESENT	0
231416	220076	08024S	PARTICIPANT	\N	PRESENT	0
231418	220076	14065Q	PARTICIPANT	\N	PRESENT	0
231419	220076	19549D	PARTICIPANT	\N	PRESENT	0
231420	220076	04088S	PARTICIPANT	\N	PRESENT	0
231421	220076	08043V	PARTICIPANT	\N	PRESENT	0
231422	220076	11066Q	PARTICIPANT	\N	PRESENT	0
231423	220076	14041T	PARTICIPANT	\N	PRESENT	0
231424	220076	11045K	PARTICIPANT	\N	PRESENT	0
231425	220076	11104D	PARTICIPANT	\N	PRESENT	0
231426	220076	11080N	PARTICIPANT	\N	PRESENT	0
231427	220076	80027E	PARTICIPANT	\N	PRESENT	0
231428	220076	08012N	PARTICIPANT	\N	PRESENT	0
231429	220076	19531S	PARTICIPANT	\N	PRESENT	0
231430	220076	19703U	PARTICIPANT	\N	PRESENT	0
231431	220076	19489J	PARTICIPANT	\N	PRESENT	0
231432	220076	95062K	PARTICIPANT	\N	PRESENT	0
231433	220076	08058D	PARTICIPANT	\N	PRESENT	0
231434	220076	14121F	PARTICIPANT	\N	PRESENT	0
231435	220076	14085U	PARTICIPANT	\N	PRESENT	0
231436	220076	14069U	PARTICIPANT	\N	PRESENT	0
231437	220076	19527W	PARTICIPANT	\N	PRESENT	0
231438	220076	19525U	PARTICIPANT	\N	PRESENT	0
231439	220076	11041F	PARTICIPANT	\N	PRESENT	0
231440	220076	19643A	PARTICIPANT	\N	PRESENT	0
231441	220076	19599P	PARTICIPANT	\N	PRESENT	0
231442	220076	04035D	PARTICIPANT	\N	PRESENT	0
231443	220076	19725B	PARTICIPANT	\N	PRESENT	0
231444	220076	19333N	PARTICIPANT	\N	PRESENT	0
231445	220076	04044E	PARTICIPANT	\N	PRESENT	0
231446	220076	89017R	PARTICIPANT	\N	PRESENT	0
231447	220076	14227Q	PARTICIPANT	\N	PRESENT	0
231448	220076	92040Q	PARTICIPANT	\N	PRESENT	0
231449	220076	11090Q	PARTICIPANT	\N	PRESENT	0
231450	220076	19683J	PARTICIPANT	\N	PRESENT	0
231451	220076	11054L	PARTICIPANT	\N	PRESENT	0
231452	220076	19251M	PARTICIPANT	\N	PRESENT	0
231453	220076	19383Y	PARTICIPANT	\N	PRESENT	0
231454	220076	19693L	PARTICIPANT	\N	PRESENT	0
231455	220076	11026G	PARTICIPANT	\N	PRESENT	0
231456	220076	19503N	PARTICIPANT	\N	PRESENT	0
231457	220076	04018C	PARTICIPANT	\N	PRESENT	0
231458	220076	19591F	PARTICIPANT	\N	PRESENT	0
231459	220076	11067R	PARTICIPANT	\N	PRESENT	0
231460	220076	19689Q	PARTICIPANT	\N	PRESENT	0
231461	220076	19551W	PARTICIPANT	\N	PRESENT	0
231462	220076	19483C	PARTICIPANT	\N	PRESENT	0
231463	220076	08015R	PARTICIPANT	\N	PRESENT	0
231464	220076	14257W	PARTICIPANT	\N	PRESENT	0
231465	220076	19631V	PARTICIPANT	\N	PRESENT	0
231557	220076	19679N	PARTICIPANT	\N	PRESENT	0
231467	220076	14207L	PARTICIPANT	\N	PRESENT	0
231576	220076	08041T	PARTICIPANT	\N	PRESENT	0
231469	220076	14231L	PARTICIPANT	\N	PRESENT	0
231471	220076	01034P	PARTICIPANT	\N	PRESENT	0
231560	220076	14193X	PARTICIPANT	\N	PRESENT	0
231473	220076	19369B	PARTICIPANT	\N	PRESENT	0
231474	220076	19691J	PARTICIPANT	\N	PRESENT	0
231551	220076	19415P	PARTICIPANT	\N	PRESENT	0
231476	220076	19569H	PARTICIPANT	\N	PRESENT	0
231477	220076	19611R	PARTICIPANT	\N	PRESENT	0
231478	220076	19511N	PARTICIPANT	\N	PRESENT	0
231479	220076	19619A	PARTICIPANT	\N	PRESENT	0
231534	220076	08035V	PARTICIPANT	\N	PRESENT	0
231481	220076	19721W	PARTICIPANT	\N	PRESENT	0
231482	220076	19699S	PARTICIPANT	\N	PRESENT	0
231483	220076	19737F	PARTICIPANT	\N	PRESENT	0
231484	220076	19735D	PARTICIPANT	\N	PRESENT	0
231550	220076	19741B	PARTICIPANT	\N	PRESENT	0
231486	220076	16685X	PARTICIPANT	\N	PRESENT	0
231487	220076	19441R	PARTICIPANT	\N	PRESENT	0
231564	220076	19729F	PARTICIPANT	\N	PRESENT	0
231489	220076	19479G	PARTICIPANT	\N	PRESENT	0
231567	220076	98050T	PARTICIPANT	\N	PRESENT	0
231491	220076	14219Q	PARTICIPANT	\N	PRESENT	0
231547	220076	18083K	PARTICIPANT	\N	PRESENT	0
231493	220076	19713W	PARTICIPANT	\N	PRESENT	0
231494	220076	19319Q	PARTICIPANT	\N	PRESENT	0
231495	220076	14089Y	PARTICIPANT	\N	PRESENT	0
231552	220076	19673G	PARTICIPANT	\N	PRESENT	0
231497	220076	14267Y	PARTICIPANT	\N	PRESENT	0
231555	220076	19573D	PARTICIPANT	\N	PRESENT	0
231499	220076	14221J	PARTICIPANT	\N	PRESENT	0
231562	220076	19705W	PARTICIPANT	\N	PRESENT	0
231501	220076	14103D	PARTICIPANT	\N	PRESENT	0
231565	220076	04071H	PARTICIPANT	\N	PRESENT	0
231589	220076	19747H	PARTICIPANT	\N	PRESENT	0
231504	220076	19335Q	PARTICIPANT	\N	PRESENT	0
231556	220076	05012A	PARTICIPANT	\N	PRESENT	0
231506	220076	11065P	PARTICIPANT	\N	PRESENT	0
231571	220076	08038Y	PARTICIPANT	\N	PRESENT	0
231508	220076	14255U	PARTICIPANT	\N	PRESENT	0
231553	220076	07033P	PARTICIPANT	\N	PRESENT	0
231510	220076	19521Q	PARTICIPANT	\N	PRESENT	0
231569	220076	19575F	PARTICIPANT	\N	PRESENT	0
231563	220076	19723Y	PARTICIPANT	\N	PRESENT	0
231586	220076	14265W	PARTICIPANT	\N	PRESENT	0
231514	220076	19413M	PARTICIPANT	\N	PRESENT	0
231568	220076	19667J	PARTICIPANT	\N	PRESENT	0
231516	220076	04040A	PARTICIPANT	\N	PRESENT	0
231517	220076	04070G	PARTICIPANT	\N	PRESENT	0
231518	220076	11070L	PARTICIPANT	\N	PRESENT	0
231519	220076	14327T	PARTICIPANT	\N	PRESENT	0
231520	220076	19739H	PARTICIPANT	\N	PRESENT	0
231521	220076	04085P	PARTICIPANT	\N	PRESENT	0
231522	220076	11049P	PARTICIPANT	\N	PRESENT	0
231587	220076	14213J	PARTICIPANT	\N	PRESENT	0
231524	220076	14059S	PARTICIPANT	\N	PRESENT	0
231525	220076	14061L	PARTICIPANT	\N	PRESENT	0
231584	220076	19581D	PARTICIPANT	\N	PRESENT	0
231527	220076	04045F	PARTICIPANT	\N	PRESENT	0
231528	220076	08018U	PARTICIPANT	\N	PRESENT	0
231581	220076	05008E	PARTICIPANT	\N	PRESENT	0
231580	220076	14026U	PARTICIPANT	\N	PRESENT	0
231588	220076	19447X	PARTICIPANT	\N	PRESENT	0
231532	220076	14105F	PARTICIPANT	\N	PRESENT	0
231533	220076	19709B	PARTICIPANT	\N	PRESENT	0
231585	220076	19671E	PARTICIPANT	\N	PRESENT	0
231536	220076	01062T	PARTICIPANT	\N	PRESENT	0
231549	220076	14038Y	PARTICIPANT	\N	PRESENT	0
231538	220076	19621T	PARTICIPANT	\N	PRESENT	0
231558	220076	14217N	PARTICIPANT	\N	PRESENT	0
231540	220076	95015C	PARTICIPANT	\N	PRESENT	0
231541	220076	19467C	PARTICIPANT	\N	PRESENT	0
231542	220076	04008A	PARTICIPANT	\N	PRESENT	0
231543	220076	14147R	PARTICIPANT	\N	PRESENT	0
231544	220076	11053K	PARTICIPANT	\N	PRESENT	0
231545	220076	08047A	PARTICIPANT	\N	PRESENT	0
231578	220076	19733B	PARTICIPANT	\N	PRESENT	0
231548	220076	19701S	PARTICIPANT	\N	PRESENT	0
231554	220076	14033T	PARTICIPANT	\N	PRESENT	0
231559	220076	19443T	PARTICIPANT	\N	PRESENT	0
231561	220076	14135M	PARTICIPANT	\N	PRESENT	0
231566	220076	19507S	PARTICIPANT	\N	PRESENT	0
231570	220076	14151M	PARTICIPANT	\N	PRESENT	0
231572	220076	14281W	PARTICIPANT	\N	PRESENT	0
231579	220076	08062Y	PARTICIPANT	\N	PRESENT	0
231574	220076	14053L	PARTICIPANT	\N	PRESENT	0
231575	220076	04049K	PARTICIPANT	\N	PRESENT	0
231582	220076	19421M	PARTICIPANT	\N	PRESENT	0
231583	220076	11115U	PARTICIPANT	\N	PRESENT	0
212039	212038	96004D	PARTICIPANT	\N	PRESENT	0
212043	212042	08009T	PARTICIPANT	\N	PRESENT	0
212044	212038	11083R	PARTICIPANT	\N	PRESENT	0
212045	212038	14221J	PARTICIPANT	\N	PRESENT	0
212046	212038	14331P	PARTICIPANT	\N	PRESENT	0
212048	212047	04042C	PARTICIPANT	\N	PRESENT	0
212049	212047	04040A	PARTICIPANT	\N	PRESENT	0
213061	210032	01043Q	PARTICIPANT	\N	PRESENT	0
213062	210032	14205J	PARTICIPANT	\N	PRESENT	0
213063	210032	19671E	PARTICIPANT	\N	PRESENT	0
213064	210032	19611R	PARTICIPANT	\N	PRESENT	0
213065	210032	14187A	PARTICIPANT	\N	PRESENT	0
213066	210032	19533U	PARTICIPANT	\N	PRESENT	0
213067	210032	11072N	PARTICIPANT	\N	PRESENT	0
213068	210032	04089T	PARTICIPANT	\N	PRESENT	0
213069	210032	14034U	PARTICIPANT	\N	PRESENT	0
213070	210032	19691J	PARTICIPANT	\N	PRESENT	0
213073	210032	19289C	PARTICIPANT	\N	PRESENT	0
213109	210032	11083R	PARTICIPANT	\N	PRESENT	0
213113	210032	19705W	PARTICIPANT	\N	PRESENT	0
213114	210032	19675J	PARTICIPANT	\N	PRESENT	0
213115	210032	04057K	PARTICIPANT	\N	PRESENT	0
213117	210032	04086Q	PARTICIPANT	\N	PRESENT	0
213120	210032	99004R	PARTICIPANT	\N	PRESENT	0
213121	210032	19347U	PARTICIPANT	\N	PRESENT	0
213139	210032	14265W	PARTICIPANT	\N	PRESENT	0
213156	210032	14069U	PARTICIPANT	\N	PRESENT	0
213204	207690	14221J	PARTICIPANT	\N	PRESENT	0
213205	207690	04085P	PARTICIPANT	\N	PRESENT	0
213206	207690	12016W	PARTICIPANT	\N	PRESENT	0
213207	207690	19715Y	PARTICIPANT	\N	PRESENT	0
213208	207690	08024S	PARTICIPANT	\N	PRESENT	0
213209	207690	19347U	PARTICIPANT	\N	PRESENT	0
213210	207690	14051J	PARTICIPANT	\N	PRESENT	0
213211	207690	19503N	PARTICIPANT	\N	PRESENT	0
213212	207690	19631V	PARTICIPANT	\N	PRESENT	0
213213	207690	04057K	PARTICIPANT	\N	PRESENT	0
213214	207690	04086Q	PARTICIPANT	\N	PRESENT	0
213215	207690	19637C	PARTICIPANT	\N	PRESENT	0
213216	207690	19289C	PARTICIPANT	\N	PRESENT	0
213217	207690	19707Y	PARTICIPANT	\N	PRESENT	0
213218	207690	11065P	PARTICIPANT	\N	PRESENT	0
213219	207690	19629C	PARTICIPANT	\N	PRESENT	0
213220	207690	19705W	PARTICIPANT	\N	PRESENT	0
213221	207690	14261S	PARTICIPANT	\N	PRESENT	0
213222	207690	16685X	PARTICIPANT	\N	PRESENT	0
213223	207690	19737F	PARTICIPANT	\N	PRESENT	0
213224	207690	14219Q	PARTICIPANT	\N	PRESENT	0
213225	207690	08019V	PARTICIPANT	\N	PRESENT	0
213226	207690	19399H	PARTICIPANT	\N	PRESENT	0
213227	207690	19693L	PARTICIPANT	\N	PRESENT	0
213228	207690	14265W	PARTICIPANT	\N	PRESENT	0
213229	207690	01048V	PARTICIPANT	\N	PRESENT	0
213230	207690	19675J	PARTICIPANT	\N	PRESENT	0
213238	207690	14083S	PARTICIPANT	\N	PRESENT	0
213232	207690	17637T	PARTICIPANT	\N	PRESENT	0
213233	207690	19447X	PARTICIPANT	\N	PRESENT	0
213234	207690	02002K	PARTICIPANT	\N	PRESENT	0
213235	207690	19713W	PARTICIPANT	\N	PRESENT	0
213236	207690	10006L	PARTICIPANT	\N	PRESENT	0
213237	207690	14327T	PARTICIPANT	\N	PRESENT	0
213239	207690	14069U	PARTICIPANT	\N	PRESENT	0
213240	207690	11099A	PARTICIPANT	\N	PRESENT	0
213241	207690	19573D	PARTICIPANT	\N	PRESENT	0
213242	207690	19301E	PARTICIPANT	\N	PRESENT	0
213243	207690	14089Y	PARTICIPANT	\N	PRESENT	0
213292	213290	04071H	PARTICIPANT	\N	PRESENT	0
213405	213249	07034Q	PRESIDENT	0	PRESENT	0
213406	213249	19581D	PARTICIPANT	\N	PRESENT	0
213407	213249	14231L	PARTICIPANT	\N	PRESENT	0
213203	207690	08009T	PARTICIPANT	\N	PRESENT	0
214109	207695	19717B	PARTICIPANT	\N	PRESENT	0
214110	207695	19631V	PARTICIPANT	\N	PRESENT	0
214114	207695	19707Y	PARTICIPANT	\N	PRESENT	0
214115	207695	19651A	PARTICIPANT	\N	PRESENT	0
213582	213276	19697Q	PARTICIPANT	\N	PRESENT	0
213583	213276	01034P	PARTICIPANT	\N	PRESENT	0
213584	213276	19679N	PARTICIPANT	\N	PRESENT	0
213585	213276	11103C	PARTICIPANT	\N	PRESENT	0
213586	213276	08052W	PARTICIPANT	\N	PRESENT	0
213587	213276	14195A	PARTICIPANT	\N	PRESENT	0
213588	213276	19367Y	PARTICIPANT	\N	PRESENT	0
213589	213276	19335Q	PARTICIPANT	\N	PRESENT	0
213590	213276	98024R	PARTICIPANT	\N	PRESENT	0
213591	213276	17779H	PARTICIPANT	\N	PRESENT	0
214117	207695	19667J	PARTICIPANT	\N	PRESENT	0
214118	207695	19543W	PARTICIPANT	\N	PRESENT	0
214119	207695	11033F	PARTICIPANT	\N	PRESENT	0
214121	207695	19575F	PARTICIPANT	\N	PRESENT	0
214124	207695	14093U	PARTICIPANT	\N	PRESENT	0
213600	213276	11077T	PARTICIPANT	\N	PRESENT	0
213601	213276	04092N	PRESIDENT	0	PRESENT	0
213602	213276	14223L	PARTICIPANT	\N	PRESENT	0
213603	213276	14227Q	PARTICIPANT	\N	PRESENT	0
213604	213276	19723Y	PARTICIPANT	\N	PRESENT	0
213605	213276	14119M	PARTICIPANT	\N	PRESENT	0
213606	213276	14087W	PARTICIPANT	\N	PRESENT	0
213607	213276	19575F	PARTICIPANT	\N	PRESENT	0
213608	213276	14261S	PARTICIPANT	\N	PRESENT	0
213610	213059	14331P	PARTICIPANT	\N	PRESENT	0
213611	213059	19711U	PARTICIPANT	\N	PRESENT	0
213612	213059	19545Y	PARTICIPANT	\N	PRESENT	0
213613	213059	01057W	PARTICIPANT	\N	PRESENT	0
213614	213059	11053K	PARTICIPANT	\N	PRESENT	0
213615	213059	12016W	PARTICIPANT	\N	PRESENT	0
213616	213059	11074Q	PRESIDENT	0	PRESENT	0
213617	213059	08014Q	PARTICIPANT	\N	PRESENT	0
213618	213059	14225N	PARTICIPANT	\N	PRESENT	0
213619	213059	14159V	PARTICIPANT	\N	PRESENT	0
213620	213059	19671E	PARTICIPANT	\N	PRESENT	0
213621	213059	07029T	PARTICIPANT	\N	PRESENT	0
213622	213059	14199E	PARTICIPANT	\N	PRESENT	0
213623	213059	07004J	PARTICIPANT	\N	PRESENT	0
213624	213059	14121F	PARTICIPANT	\N	PRESENT	0
213625	213059	99004R	PARTICIPANT	\N	PRESENT	0
213626	213059	95041E	PARTICIPANT	\N	PRESENT	0
213627	213059	19667J	PARTICIPANT	\N	PRESENT	0
213628	213059	14327T	PARTICIPANT	\N	EXCUSE	0
213629	213059	04086Q	PARTICIPANT	\N	EXCUSE	0
213630	213059	04061F	PARTICIPANT	\N	EXCUSE	0
213631	213276	19415P	PARTICIPANT	\N	PRESENT	0
213632	213276	14213J	PARTICIPANT	\N	PRESENT	0
213633	213276	14217N	PARTICIPANT	\N	PRESENT	0
213634	213276	19683J	PARTICIPANT	\N	PRESENT	0
213635	213276	19663E	PARTICIPANT	\N	PRESENT	0
213636	213276	14071N	PARTICIPANT	\N	PRESENT	0
213637	213276	14026U	PARTICIPANT	\N	PRESENT	0
214127	207695	14030Q	PARTICIPANT	\N	PRESENT	0
213644	213276	19553Y	PARTICIPANT	\N	PRESENT	0
214131	207695	11040E	PARTICIPANT	\N	PRESENT	0
213646	213276	11031D	PARTICIPANT	\N	PRESENT	0
213647	213276	19703U	PARTICIPANT	\N	PRESENT	0
214132	207695	19367Y	PARTICIPANT	\N	PRESENT	0
214133	207695	14069U	PARTICIPANT	\N	PRESENT	0
214134	207695	19415P	PARTICIPANT	\N	PRESENT	0
214137	207695	19733B	PARTICIPANT	\N	PRESENT	0
213654	213276	10006L	PARTICIPANT	\N	PRESENT	0
214139	207695	14105F	PARTICIPANT	\N	PRESENT	0
214140	207695	19643A	PARTICIPANT	\N	PRESENT	0
214143	207695	19383Y	PARTICIPANT	\N	PRESENT	0
214146	207695	04047H	PARTICIPANT	\N	PRESENT	0
214147	207695	14207L	PARTICIPANT	\N	PRESENT	0
214148	207695	14255U	PARTICIPANT	\N	PRESENT	0
214149	207695	11101A	PARTICIPANT	\N	PRESENT	0
225837	218303	19731Y	PARTICIPANT	\N	PRESENT	0
225838	218303	19703U	PARTICIPANT	\N	PRESENT	0
225839	218303	19553Y	PARTICIPANT	\N	PRESENT	0
225840	218303	19711U	PARTICIPANT	\N	PRESENT	0
225841	218303	11031D	PARTICIPANT	\N	PRESENT	0
225842	218303	11040E	PARTICIPANT	\N	PRESENT	0
225843	218303	19479G	PARTICIPANT	\N	PRESENT	0
225845	218303	19503N	PARTICIPANT	\N	PRESENT	0
225846	218303	19387D	PARTICIPANT	\N	PRESENT	0
225847	218303	11067R	PARTICIPANT	\N	PRESENT	0
225848	218303	14239U	PARTICIPANT	\N	PRESENT	0
225849	218303	14281W	PARTICIPANT	\N	PRESENT	0
225851	218303	14327T	PARTICIPANT	\N	PRESENT	0
225852	218303	88008L	PARTICIPANT	\N	PRESENT	0
225853	218303	14331P	PARTICIPANT	\N	PRESENT	0
225854	218303	14087W	PARTICIPANT	\N	PRESENT	0
225856	218303	08010L	PARTICIPANT	\N	PRESENT	0
225858	218303	19667J	PARTICIPANT	\N	PRESENT	0
225861	218303	19611R	PARTICIPANT	\N	PRESENT	0
225862	218303	14219Q	PARTICIPANT	\N	PRESENT	0
225865	218303	19693L	PARTICIPANT	\N	PRESENT	0
225872	218303	14041T	PARTICIPANT	\N	PRESENT	0
225873	218303	04043D	PARTICIPANT	\N	PRESENT	0
225874	218303	19637C	PARTICIPANT	\N	PRESENT	0
225875	218303	11097X	PARTICIPANT	\N	PRESENT	0
225876	218303	11074Q	PARTICIPANT	\N	PRESENT	0
225877	218303	08017T	PARTICIPANT	\N	PRESENT	0
225878	218303	19713W	PARTICIPANT	\N	PRESENT	0
225879	218303	19737F	PARTICIPANT	\N	PRESENT	0
225880	218303	04045F	PARTICIPANT	\N	PRESENT	0
225881	218303	19483C	PARTICIPANT	\N	PRESENT	0
225882	218303	14030Q	PARTICIPANT	\N	PRESENT	0
225883	218303	14147R	PARTICIPANT	\N	PRESENT	0
225884	218303	14121F	PARTICIPANT	\N	PRESENT	0
225885	218303	14038Y	PARTICIPANT	\N	PRESENT	0
225886	218303	19413M	PARTICIPANT	\N	PRESENT	0
225887	218303	11054L	PARTICIPANT	\N	PRESENT	0
225888	218303	19421M	PARTICIPANT	\N	PRESENT	0
225889	218303	19663E	PARTICIPANT	\N	PRESENT	0
225890	218303	19447X	PARTICIPANT	\N	PRESENT	0
225891	218303	19591F	PARTICIPANT	\N	PRESENT	0
225892	218303	08039A	PARTICIPANT	\N	PRESENT	0
225893	218303	08034U	PARTICIPANT	\N	PRESENT	0
225894	218303	19741B	PARTICIPANT	\N	PRESENT	0
225895	218303	19691J	PARTICIPANT	\N	PRESENT	0
225896	218303	11026G	PARTICIPANT	\N	PRESENT	0
225897	218303	99004R	PARTICIPANT	\N	PRESENT	0
225898	218303	04008A	PARTICIPANT	\N	PRESENT	0
225899	218303	19689Q	PARTICIPANT	\N	PRESENT	0
225900	218303	19727D	PARTICIPANT	\N	PRESENT	0
225901	218303	19549D	PARTICIPANT	\N	PRESENT	0
225902	218303	11064N	PARTICIPANT	\N	PRESENT	0
225903	218303	14267Y	PARTICIPANT	\N	PRESENT	0
225904	218303	19443T	PARTICIPANT	\N	PRESENT	0
225905	218303	08019V	PARTICIPANT	\N	PRESENT	0
225906	218303	19687N	PARTICIPANT	\N	PRESENT	0
225907	218303	14071N	PARTICIPANT	\N	PRESENT	0
225908	218303	11045K	PARTICIPANT	\N	PRESENT	0
225909	218303	80013X	PARTICIPANT	\N	PRESENT	0
225910	218303	19349W	PARTICIPANT	\N	PRESENT	0
225911	218303	19695N	PARTICIPANT	\N	PRESENT	0
225912	218303	04059M	PARTICIPANT	\N	PRESENT	0
225913	218303	19643A	PARTICIPANT	\N	PRESENT	0
225914	218303	19531S	PARTICIPANT	\N	PRESENT	0
225915	218303	14215L	PARTICIPANT	\N	PRESENT	0
225916	218303	19657G	PARTICIPANT	\N	PRESENT	0
225917	218303	19649G	PARTICIPANT	\N	PRESENT	0
225922	218303	95037J	PARTICIPANT	\N	PRESENT	0
225923	218303	19651A	PARTICIPANT	\N	PRESENT	0
225924	218303	11048N	PARTICIPANT	\N	PRESENT	0
225925	218303	14133K	PARTICIPANT	\N	PRESENT	0
225926	218303	11053K	PARTICIPANT	\N	PRESENT	0
225927	218303	19399H	PARTICIPANT	\N	PRESENT	0
225928	218303	17637T	PARTICIPANT	\N	PRESENT	0
225929	218303	01048V	PARTICIPANT	\N	PRESENT	0
225930	218303	11033F	PARTICIPANT	\N	PRESENT	0
225931	218303	11012A	PARTICIPANT	\N	PRESENT	0
225932	218303	19347U	PARTICIPANT	\N	PRESENT	0
225933	218303	08020N	PARTICIPANT	\N	PRESENT	0
225936	218303	14159V	PARTICIPANT	\N	PRESENT	0
225937	218303	08045X	PARTICIPANT	\N	PRESENT	0
225938	218303	14253S	PARTICIPANT	\N	PRESENT	0
225943	218303	14235Q	PARTICIPANT	\N	PRESENT	0
225946	218303	14034U	PARTICIPANT	\N	PRESENT	0
225947	218303	14083S	PARTICIPANT	\N	PRESENT	0
225975	218303	14157T	PARTICIPANT	\N	PRESENT	0
225977	218304	11072N	PARTICIPANT	\N	PRESENT	0
225997	218304	11031D	PARTICIPANT	\N	PRESENT	0
225998	218304	14235Q	PARTICIPANT	\N	PRESENT	0
225999	218304	11054L	PARTICIPANT	\N	PRESENT	0
226000	218304	08058D	PARTICIPANT	\N	PRESENT	0
226001	218304	80013X	PARTICIPANT	\N	PRESENT	0
226002	218304	19503N	PARTICIPANT	\N	PRESENT	0
226003	218304	19413M	PARTICIPANT	\N	PRESENT	0
226004	218304	08053X	PARTICIPANT	\N	PRESENT	0
226005	218304	08045X	PARTICIPANT	\N	PRESENT	0
226006	218304	95037J	PARTICIPANT	\N	PRESENT	0
226007	218304	88008L	PARTICIPANT	\N	PRESENT	0
226008	218304	04034C	PARTICIPANT	\N	PRESENT	0
226009	218304	11041F	PARTICIPANT	\N	PRESENT	0
226010	218304	11027H	PARTICIPANT	\N	PRESENT	0
226011	218304	11067R	PARTICIPANT	\N	PRESENT	0
226012	218304	19737F	PARTICIPANT	\N	PRESENT	0
226013	218304	14267Y	PARTICIPANT	\N	PRESENT	0
226014	218304	04040A	PARTICIPANT	\N	PRESENT	0
226016	218304	19421M	PARTICIPANT	\N	PRESENT	0
226018	218304	14083S	PARTICIPANT	\N	PRESENT	0
226019	218304	04042C	PARTICIPANT	\N	PRESENT	0
226020	218304	08034U	PARTICIPANT	\N	PRESENT	0
226021	218304	11074Q	PARTICIPANT	\N	PRESENT	0
226023	218304	14193X	PARTICIPANT	\N	PRESENT	0
226024	218304	19443T	PARTICIPANT	\N	PRESENT	0
226025	218304	14253S	PARTICIPANT	\N	PRESENT	0
226029	218304	08010L	PARTICIPANT	\N	PRESENT	0
226027	218304	19711U	PARTICIPANT	\N	PRESENT	0
226028	218304	11048N	PARTICIPANT	\N	PRESENT	0
226030	218304	14133K	PARTICIPANT	\N	PRESENT	0
226031	218304	14157T	PARTICIPANT	\N	PRESENT	0
226032	218304	19657G	PARTICIPANT	\N	PRESENT	0
226033	218304	14041T	PARTICIPANT	\N	PRESENT	0
226034	218304	19399H	PARTICIPANT	\N	PRESENT	0
226037	218304	19549D	PARTICIPANT	\N	PRESENT	0
226040	218304	19667J	PARTICIPANT	\N	PRESENT	0
226041	218304	11012A	PARTICIPANT	\N	PRESENT	0
226042	218304	11064N	PARTICIPANT	\N	PRESENT	0
226043	218304	08047A	PARTICIPANT	\N	PRESENT	0
226044	225935	14329V	PARTICIPANT	\N	PRESENT	0
226045	225949	14329V	PARTICIPANT	\N	PRESENT	0
226090	226089	05008E	PARTICIPANT	\N	PRESENT	0
226371	226370	96004D	PARTICIPANT	\N	PRESENT	0
226093	226092	05008E	PARTICIPANT	\N	PRESENT	0
226667	225954	19709B	PARTICIPANT	\N	PRESENT	0
226096	226095	05008E	PARTICIPANT	\N	PRESENT	0
226668	225954	19593H	PARTICIPANT	\N	PRESENT	0
228545	225949	14069U	PARTICIPANT	\N	PRESENT	0
226143	225935	11101A	PARTICIPANT	\N	PRESENT	0
226153	225935	14051J	PARTICIPANT	\N	PRESENT	0
226252	225935	14063N	PARTICIPANT	\N	PRESENT	0
226253	225949	14063N	PARTICIPANT	\N	PRESENT	0
226359	218821	08045X	PARTICIPANT	\N	EXCUSE	0
227428	225773	11115U	PARTICIPANT	\N	EXCUSE	0
227429	225773	98053W	PARTICIPANT	\N	EXCUSE	0
227430	225773	14097Y	PARTICIPANT	\N	EXCUSE	0
227431	225774	11115U	PARTICIPANT	\N	EXCUSE	0
227432	225774	98053W	PARTICIPANT	\N	EXCUSE	0
227433	225774	14097Y	PARTICIPANT	\N	EXCUSE	0
227586	226349	08049C	PARTICIPANT	\N	EXCUSE	0
227612	226349	14195A	PARTICIPANT	\N	PRESENT	0
227900	225935	08068F	PARTICIPANT	\N	PRESENT	0
227901	225935	19575F	PARTICIPANT	\N	PRESENT	0
227902	225935	14205J	PARTICIPANT	\N	PRESENT	0
227903	225935	05012A	PARTICIPANT	\N	PRESENT	0
227904	225935	14069U	PARTICIPANT	\N	PRESENT	0
227905	225935	19489J	PARTICIPANT	\N	PRESENT	0
227953	227827	08062Y	PARTICIPANT	\N	PRESENT	0
228513	228392	19553Y	PARTICIPANT	\N	PRESENT	0
228546	225949	05012A	PARTICIPANT	\N	PRESENT	0
228547	225949	19489J	PARTICIPANT	\N	PRESENT	0
228550	225949	08068F	PARTICIPANT	\N	PRESENT	0
228552	228551	05012A	PARTICIPANT	\N	PRESENT	0
228556	228551	08068F	PARTICIPANT	\N	PRESENT	0
228566	227827	19349W	PARTICIPANT	\N	EXCUSE	0
228575	228574	19629C	PARTICIPANT	\N	PRESENT	0
228576	228574	11033F	PARTICIPANT	\N	PRESENT	0
228577	228574	14147R	PARTICIPANT	\N	PRESENT	0
228578	228574	14030Q	PARTICIPANT	\N	PRESENT	0
228808	218472	97011G	PARTICIPANT	\N	PRESENT	0
228809	218472	11103C	PARTICIPANT	\N	PRESENT	0
228810	218472	14217N	PARTICIPANT	\N	PRESENT	0
213279	213278	04061F	PARTICIPANT	\N	PRESENT	0
213281	213280	11048N	PARTICIPANT	\N	PRESENT	0
213283	213282	04061F	PARTICIPANT	\N	PRESENT	0
213284	211416	11083R	PARTICIPANT	\N	PRESENT	0
213285	211416	04059M	PARTICIPANT	\N	PRESENT	0
213286	211416	14061L	PARTICIPANT	\N	PRESENT	0
213288	213287	08039A	PARTICIPANT	\N	PRESENT	0
213289	213287	11083R	PARTICIPANT	\N	PRESENT	0
213293	213291	19693L	PARTICIPANT	\N	PRESENT	0
213295	213294	19693L	PARTICIPANT	\N	PRESENT	0
213297	213296	19693L	PARTICIPANT	\N	PRESENT	0
213299	213298	19693L	PARTICIPANT	\N	PRESENT	0
213301	213300	14123H	PARTICIPANT	\N	PRESENT	0
213303	213302	95015C	PARTICIPANT	\N	PRESENT	0
213305	213304	95015C	PARTICIPANT	\N	PRESENT	0
213307	213306	95015C	PARTICIPANT	\N	PRESENT	0
213309	213308	14229S	PARTICIPANT	\N	PRESENT	0
213310	213308	19735D	PARTICIPANT	\N	PRESENT	0
213312	213311	14229S	PARTICIPANT	\N	PRESENT	0
213313	213311	08043V	PARTICIPANT	\N	PRESENT	0
213314	213311	19735D	PARTICIPANT	\N	PRESENT	0
213316	213315	14229S	PARTICIPANT	\N	PRESENT	0
213317	213315	08043V	PARTICIPANT	\N	PRESENT	0
213318	213315	19735D	PARTICIPANT	\N	PRESENT	0
215513	215512	01024M	PARTICIPANT	\N	PRESENT	0
215515	215514	01024M	PARTICIPANT	\N	PRESENT	0
215557	212116	99004R	PARTICIPANT	\N	PRESENT	0
215558	212116	19651A	PARTICIPANT	\N	PRESENT	0
215559	212116	04038G	PARTICIPANT	\N	PRESENT	0
215560	212116	11065P	PARTICIPANT	\N	PRESENT	0
215561	212116	02002K	PARTICIPANT	\N	PRESENT	0
215562	212116	04061F	PARTICIPANT	\N	PRESENT	0
215563	212116	08012N	PARTICIPANT	\N	PRESENT	0
215564	212116	08062Y	PARTICIPANT	\N	PRESENT	0
215565	212116	14147R	PARTICIPANT	\N	PRESENT	0
215566	212116	14107H	PARTICIPANT	\N	PRESENT	0
215567	212116	11097X	PARTICIPANT	\N	PRESENT	0
215568	212116	11066Q	PARTICIPANT	\N	PRESENT	0
216305	216304	86034E	PARTICIPANT	\N	PRESENT	0
216306	216304	04059M	PARTICIPANT	\N	PRESENT	0
216307	216304	11040E	PARTICIPANT	\N	PRESENT	0
216308	216304	14053L	PARTICIPANT	\N	PRESENT	0
216309	216304	11053K	PARTICIPANT	\N	PRESENT	0
216310	216304	04086Q	PARTICIPANT	\N	PRESENT	0
216311	216304	08052W	PARTICIPANT	\N	PRESENT	0
216312	216304	11070L	PARTICIPANT	\N	PRESENT	0
216313	216304	10006L	PARTICIPANT	\N	PRESENT	0
216314	216304	14041T	PARTICIPANT	\N	PRESENT	0
216315	216304	04089T	PARTICIPANT	\N	PRESENT	0
216316	216304	14034U	PARTICIPANT	\N	PRESENT	0
216317	216304	14231L	PARTICIPANT	\N	PRESENT	0
216318	216304	11064N	PARTICIPANT	\N	PRESENT	0
216319	216304	14081Q	PARTICIPANT	\N	PRESENT	0
216320	216304	14241N	PARTICIPANT	\N	PRESENT	0
216321	216304	14061L	PARTICIPANT	\N	PRESENT	0
216322	216304	14159V	PARTICIPANT	\N	PRESENT	0
216323	216304	08034U	PARTICIPANT	\N	PRESENT	0
216324	216304	01043Q	PARTICIPANT	\N	PRESENT	0
216325	216304	11077T	PARTICIPANT	\N	PRESENT	0
217419	217418	96004D	PARTICIPANT	\N	PRESENT	0
216327	216304	11072N	PARTICIPANT	\N	PRESENT	0
216328	216304	05012A	PARTICIPANT	\N	PRESENT	0
216329	216304	14135M	PARTICIPANT	\N	PRESENT	0
216330	216304	04044E	PARTICIPANT	\N	PRESENT	0
216332	216331	04059M	PARTICIPANT	\N	PRESENT	0
217424	217423	96004D	PARTICIPANT	\N	PRESENT	0
216334	216331	14053L	PARTICIPANT	\N	PRESENT	0
216335	216331	11053K	PARTICIPANT	\N	PRESENT	0
216336	216331	04086Q	PARTICIPANT	\N	PRESENT	0
216337	216331	08052W	PARTICIPANT	\N	PRESENT	0
216338	216331	11070L	PARTICIPANT	\N	PRESENT	0
216339	216331	10006L	PARTICIPANT	\N	PRESENT	0
216340	216331	14041T	PARTICIPANT	\N	PRESENT	0
216341	216331	04089T	PARTICIPANT	\N	PRESENT	0
216342	216331	14034U	PARTICIPANT	\N	PRESENT	0
217421	217418	19563B	PARTICIPANT	\N	PRESENT	0
216344	216331	11064N	PARTICIPANT	\N	PRESENT	0
216345	216331	14081Q	PARTICIPANT	\N	PRESENT	0
217425	217423	19563B	PARTICIPANT	\N	PRESENT	0
216347	216331	14061L	PARTICIPANT	\N	PRESENT	0
216348	216331	14159V	PARTICIPANT	\N	PRESENT	0
216349	216331	86034E	PARTICIPANT	\N	PRESENT	0
216350	216331	08034U	PARTICIPANT	\N	PRESENT	0
216351	216331	01043Q	PARTICIPANT	\N	PRESENT	0
216352	216331	11077T	PARTICIPANT	\N	PRESENT	0
216353	216331	12016W	PARTICIPANT	\N	PRESENT	0
216354	216331	11072N	PARTICIPANT	\N	PRESENT	0
216355	216331	05012A	PARTICIPANT	\N	PRESENT	0
216356	216331	14135M	PARTICIPANT	\N	PRESENT	0
216357	216331	04044E	PARTICIPANT	\N	PRESENT	0
217475	217474	14085U	PARTICIPANT	\N	PRESENT	0
217476	217474	14159V	PARTICIPANT	\N	PRESENT	0
219583	207718	11031D	PARTICIPANT	\N	PRESENT	0
219584	207718	19673G	PARTICIPANT	\N	PRESENT	0
219585	207718	11045K	PARTICIPANT	\N	PRESENT	0
219596	207718	04059M	PARTICIPANT	\N	PRESENT	0
219597	207718	11053K	PARTICIPANT	\N	PRESENT	0
219599	207718	11085T	PARTICIPANT	\N	PRESENT	0
219603	217443	19333N	PARTICIPANT	\N	PRESENT	0
219604	217443	19701S	PARTICIPANT	\N	PRESENT	0
219605	217443	95062K	PARTICIPANT	\N	PRESENT	0
219606	217443	19549D	PARTICIPANT	\N	PRESENT	0
219607	217443	14221J	PARTICIPANT	\N	PRESENT	0
219608	217443	19599P	PARTICIPANT	\N	PRESENT	0
219609	217443	18083K	PARTICIPANT	\N	PRESENT	0
219610	217443	14237S	PARTICIPANT	\N	PRESENT	0
219611	217443	05012A	PARTICIPANT	\N	PRESENT	0
219612	217443	14051J	PARTICIPANT	\N	PRESENT	0
219613	217443	19503N	PARTICIPANT	\N	PRESENT	0
219614	217443	19347U	PARTICIPANT	\N	PRESENT	0
219615	217443	14157T	PARTICIPANT	\N	PRESENT	0
219616	217443	19685L	PARTICIPANT	\N	PRESENT	0
219617	217443	08024S	PARTICIPANT	\N	PRESENT	0
219618	217443	19681G	PARTICIPANT	\N	PRESENT	0
219619	217443	98023Q	PARTICIPANT	\N	PRESENT	0
219620	217443	14038Y	PARTICIPANT	\N	PRESENT	0
219621	217443	14031R	PARTICIPANT	\N	PRESENT	0
219622	217443	19713W	PARTICIPANT	\N	PRESENT	0
219623	217443	08055A	PARTICIPANT	\N	PRESENT	0
219624	217443	14093U	PARTICIPANT	\N	PRESENT	0
219625	217443	08009T	PARTICIPANT	\N	PRESENT	0
219626	217443	19737F	PARTICIPANT	\N	PRESENT	0
219627	217443	04097T	PARTICIPANT	\N	PRESENT	0
219628	217443	19739H	PARTICIPANT	\N	PRESENT	0
219629	217443	02002K	PARTICIPANT	\N	EXCUSE	0
219759	207719	19503N	PARTICIPANT	\N	PRESENT	0
219748	207719	11070L	PARTICIPANT	\N	PRESENT	0
219758	207719	14227Q	PARTICIPANT	\N	PRESENT	0
219760	207719	08052W	PARTICIPANT	\N	PRESENT	0
219761	207719	11067R	PARTICIPANT	\N	PRESENT	0
219762	207719	14239U	PARTICIPANT	\N	PRESENT	0
219763	207719	19697Q	PARTICIPANT	\N	PRESENT	0
219764	207719	04092N	PARTICIPANT	\N	PRESENT	0
219765	207719	01034P	PARTICIPANT	\N	PRESENT	0
219766	207719	19553Y	PARTICIPANT	\N	PRESENT	0
219767	207719	14042U	PARTICIPANT	\N	PRESENT	0
219768	207719	19441R	PARTICIPANT	\N	PRESENT	0
219769	207719	14231L	PARTICIPANT	\N	PRESENT	0
219770	207719	19691J	PARTICIPANT	\N	PRESENT	0
219771	207719	19577H	PARTICIPANT	\N	PRESENT	0
219772	207719	19711U	PARTICIPANT	\N	PRESENT	0
219773	207719	14087W	PARTICIPANT	\N	PRESENT	0
219774	207719	11097X	PARTICIPANT	\N	PRESENT	0
219775	207719	19701S	PARTICIPANT	\N	PRESENT	0
219776	207719	04018C	PARTICIPANT	\N	PRESENT	0
219777	207719	14281W	PARTICIPANT	\N	PRESENT	0
219778	207719	11026G	PARTICIPANT	\N	PRESENT	0
219779	207719	14331P	PARTICIPANT	\N	PRESENT	0
219780	207719	19731Y	PARTICIPANT	\N	PRESENT	0
219781	207719	19583F	PARTICIPANT	\N	PRESENT	0
219782	207719	19415P	PARTICIPANT	\N	PRESENT	0
219783	207719	18083K	PARTICIPANT	\N	PRESENT	0
219784	207719	19657G	PARTICIPANT	\N	PRESENT	0
219785	207719	14265W	PARTICIPANT	\N	PRESENT	0
219786	207719	14026U	PARTICIPANT	\N	PRESENT	0
219787	207719	11103C	PARTICIPANT	\N	PRESENT	0
219788	207719	19399H	PARTICIPANT	\N	PRESENT	0
219789	207719	98024R	PARTICIPANT	\N	PRESENT	0
219790	207719	08061X	PARTICIPANT	\N	PRESENT	0
219791	207719	19591F	PARTICIPANT	\N	PRESENT	0
219792	207719	11031D	PARTICIPANT	\N	PRESENT	0
219793	207719	14119M	PARTICIPANT	\N	PRESENT	0
219794	207719	14219Q	PARTICIPANT	\N	PRESENT	0
219795	207719	14195A	PARTICIPANT	\N	PRESENT	0
219796	207719	14223L	PARTICIPANT	\N	PRESENT	0
219797	207719	19543W	PARTICIPANT	\N	PRESENT	0
219798	207719	19667J	PARTICIPANT	\N	PRESENT	0
219799	207719	04045F	PARTICIPANT	\N	PRESENT	0
231591	220077	04097T	PARTICIPANT	\N	PRESENT	0
231592	220077	07029T	PARTICIPANT	\N	PRESENT	0
231593	220077	19711U	PARTICIPANT	\N	PRESENT	0
231594	220077	14031R	PARTICIPANT	\N	PRESENT	0
231595	220077	99004R	PARTICIPANT	\N	PRESENT	0
231596	220077	04086Q	PARTICIPANT	\N	PRESENT	0
231597	220077	98005N	PARTICIPANT	\N	PRESENT	0
231598	220077	14173T	PARTICIPANT	\N	PRESENT	0
231599	220077	15447F	PARTICIPANT	\N	PRESENT	0
231600	220077	14215L	PARTICIPANT	\N	PRESENT	0
231601	220077	14123H	PARTICIPANT	\N	PRESENT	0
231602	220077	14087W	PARTICIPANT	\N	PRESENT	0
231603	220077	14249W	PARTICIPANT	\N	PRESENT	0
231604	220077	14237S	PARTICIPANT	\N	PRESENT	0
231605	220077	19533U	PARTICIPANT	\N	PRESENT	0
231606	220077	14331P	PARTICIPANT	\N	PRESENT	0
231607	220077	17583W	PARTICIPANT	\N	PRESENT	0
231608	220077	17637T	PARTICIPANT	\N	PRESENT	0
231609	220077	87003B	PARTICIPANT	\N	PRESENT	0
231610	220077	01057W	PARTICIPANT	\N	PRESENT	0
231611	220077	98023Q	PARTICIPANT	\N	PRESENT	0
231612	220077	10006L	PARTICIPANT	\N	PRESENT	0
231613	220077	08011M	PARTICIPANT	\N	PRESENT	0
231614	220077	14133K	PARTICIPANT	\N	PRESENT	0
231615	220077	11043H	PARTICIPANT	\N	PRESENT	0
231616	220077	08069G	PARTICIPANT	\N	PRESENT	0
231617	220077	19399H	PARTICIPANT	\N	PRESENT	0
231618	220077	14169X	PARTICIPANT	\N	PRESENT	0
231619	220077	98024R	PARTICIPANT	\N	PRESENT	0
231620	220077	10015M	PARTICIPANT	\N	PRESENT	0
231621	220077	08010L	PARTICIPANT	\N	PRESENT	0
231622	220077	01058X	PARTICIPANT	\N	PRESENT	0
231623	220077	14157T	PARTICIPANT	\N	PRESENT	0
231624	220077	98018T	PARTICIPANT	\N	PRESENT	0
231625	220077	11077T	PARTICIPANT	\N	PRESENT	0
231626	220077	14229S	PARTICIPANT	\N	PRESENT	0
231627	220077	08052W	PARTICIPANT	\N	PRESENT	0
231628	220077	08068F	PARTICIPANT	\N	PRESENT	0
231629	220077	14071N	PARTICIPANT	\N	PRESENT	0
231630	220077	14051J	PARTICIPANT	\N	PRESENT	0
231631	220077	11033F	PARTICIPANT	\N	PRESENT	0
231632	220077	04038G	PARTICIPANT	\N	PRESENT	0
231633	220077	19347U	PARTICIPANT	\N	PRESENT	0
231634	220077	12041X	PARTICIPANT	\N	PRESENT	0
231635	220077	11056N	PARTICIPANT	\N	PRESENT	0
231636	220077	14235Q	PARTICIPANT	\N	PRESENT	0
231637	220077	11063M	PARTICIPANT	\N	PRESENT	0
231638	220077	19695N	PARTICIPANT	\N	PRESENT	0
231639	220077	19565D	PARTICIPANT	\N	PRESENT	0
231640	220077	19687N	PARTICIPANT	\N	PRESENT	0
231641	220077	19593H	PARTICIPANT	\N	PRESENT	0
231642	220077	14225N	PARTICIPANT	\N	PRESENT	0
231643	220077	08028W	PARTICIPANT	\N	PRESENT	0
231644	220077	19515S	PARTICIPANT	\N	PRESENT	0
231645	220077	95063L	PARTICIPANT	\N	PRESENT	0
231646	220077	19707Y	PARTICIPANT	\N	PRESENT	0
231647	220077	95037J	PARTICIPANT	\N	PRESENT	0
231648	220077	08020N	PARTICIPANT	\N	PRESENT	0
231649	220077	98029W	PARTICIPANT	\N	PRESENT	0
231650	220077	04047H	PARTICIPANT	\N	PRESENT	0
231651	220077	04034C	PARTICIPANT	\N	PRESENT	0
231652	220077	19651A	PARTICIPANT	\N	PRESENT	0
231653	220077	14239U	PARTICIPANT	\N	PRESENT	0
231654	220077	19637C	PARTICIPANT	\N	PRESENT	0
231655	220077	19697Q	PARTICIPANT	\N	PRESENT	0
231656	220077	08021P	PARTICIPANT	\N	PRESENT	0
231657	220077	11072N	PARTICIPANT	\N	PRESENT	0
231658	220077	11031D	PARTICIPANT	\N	PRESENT	0
231659	220077	04042C	PARTICIPANT	\N	PRESENT	0
231660	220077	14021P	PARTICIPANT	\N	PRESENT	0
231661	220077	95041E	PARTICIPANT	\N	PRESENT	0
231662	220077	19731Y	PARTICIPANT	\N	PRESENT	0
231663	220077	19685L	PARTICIPANT	\N	PRESENT	0
231664	220077	14253S	PARTICIPANT	\N	PRESENT	0
231665	220077	14199E	PARTICIPANT	\N	PRESENT	0
231666	220077	11012A	PARTICIPANT	\N	PRESENT	0
231667	220077	08031R	PARTICIPANT	\N	PRESENT	0
231668	220077	14119M	PARTICIPANT	\N	PRESENT	0
231669	220077	19253P	PARTICIPANT	\N	PRESENT	0
231670	220077	14079W	PARTICIPANT	\N	PRESENT	0
231671	220077	11083R	PARTICIPANT	\N	PRESENT	0
231672	220077	19629C	PARTICIPANT	\N	PRESENT	0
231673	220077	08049C	PARTICIPANT	\N	PRESENT	0
231674	220077	08034U	PARTICIPANT	\N	PRESENT	0
231675	220077	11081P	PARTICIPANT	\N	PRESENT	0
231676	220077	19563B	PARTICIPANT	\N	PRESENT	0
231677	220077	98022P	PARTICIPANT	\N	PRESENT	0
231678	220077	14241N	PARTICIPANT	\N	PRESENT	0
231679	220077	19681G	PARTICIPANT	\N	PRESENT	0
231680	220077	01043Q	PARTICIPANT	\N	PRESENT	0
231681	220077	11099A	PARTICIPANT	\N	PRESENT	0
231682	220077	19367Y	PARTICIPANT	\N	PRESENT	0
231683	220077	19717B	PARTICIPANT	\N	PRESENT	0
231684	220077	14042U	PARTICIPANT	\N	PRESENT	0
231685	220077	11097X	PARTICIPANT	\N	PRESENT	0
231686	220077	19553Y	PARTICIPANT	\N	PRESENT	0
231687	220077	19719D	PARTICIPANT	\N	PRESENT	0
231688	220077	07034Q	PARTICIPANT	\N	PRESENT	0
231689	220077	14083S	PARTICIPANT	\N	PRESENT	0
231690	220077	14093U	PARTICIPANT	\N	PRESENT	0
231691	220077	14073Q	PARTICIPANT	\N	PRESENT	0
231692	220077	95030B	PARTICIPANT	\N	PRESENT	0
231693	220077	19545Y	PARTICIPANT	\N	PRESENT	0
231694	220077	14111D	PARTICIPANT	\N	PRESENT	0
231695	220077	19585H	PARTICIPANT	\N	PRESENT	0
231696	220077	17589D	PARTICIPANT	\N	PRESENT	0
231697	220077	08056B	PARTICIPANT	\N	PRESENT	0
231698	220077	11064N	PARTICIPANT	\N	PRESENT	0
231699	220077	19583F	PARTICIPANT	\N	PRESENT	0
231700	220077	14251Q	PARTICIPANT	\N	PRESENT	0
231701	220077	14195A	PARTICIPANT	\N	PRESENT	0
231702	220077	08044W	PARTICIPANT	\N	PRESENT	0
231703	220077	04057K	PARTICIPANT	\N	PRESENT	0
231704	220077	02002K	PARTICIPANT	\N	PRESENT	0
231705	220077	07004J	PARTICIPANT	\N	PRESENT	0
231706	220077	01060R	PARTICIPANT	\N	PRESENT	0
231707	220077	11074Q	PARTICIPANT	\N	PRESENT	0
231708	220077	14159V	PARTICIPANT	\N	PRESENT	0
231709	220077	08009T	PARTICIPANT	\N	PRESENT	0
231710	220077	01028R	PARTICIPANT	\N	PRESENT	0
231711	220077	14001X	PARTICIPANT	\N	PRESENT	0
231712	220077	14063N	PARTICIPANT	\N	PRESENT	0
231713	220077	19727D	PARTICIPANT	\N	PRESENT	0
231714	220077	11085T	PARTICIPANT	\N	PRESENT	0
231715	220077	01024M	PARTICIPANT	\N	PRESENT	0
231716	220077	04033B	PARTICIPANT	\N	PRESENT	0
231717	220077	08016S	PARTICIPANT	\N	PRESENT	0
231718	220077	14107H	PARTICIPANT	\N	PRESENT	0
231719	220077	08039A	PARTICIPANT	\N	PRESENT	0
231720	220077	19577H	PARTICIPANT	\N	PRESENT	0
231721	220077	08045X	PARTICIPANT	\N	PRESENT	0
231722	220077	97011G	PARTICIPANT	\N	PRESENT	0
231723	220077	14187A	PARTICIPANT	\N	PRESENT	0
231724	220077	19647E	PARTICIPANT	\N	PRESENT	0
231725	220077	14197C	PARTICIPANT	\N	PRESENT	0
231726	220077	19543W	PARTICIPANT	\N	PRESENT	0
231727	220077	19749K	PARTICIPANT	\N	PRESENT	0
231728	220077	08017T	PARTICIPANT	\N	PRESENT	0
231729	220077	19649G	PARTICIPANT	\N	PRESENT	0
231730	220077	14030Q	PARTICIPANT	\N	PRESENT	0
231731	220077	80013X	PARTICIPANT	\N	PRESENT	0
231732	220077	08024S	PARTICIPANT	\N	PRESENT	0
231733	220077	14205J	PARTICIPANT	\N	PRESENT	0
231734	220077	14065Q	PARTICIPANT	\N	PRESENT	0
231735	220077	19549D	PARTICIPANT	\N	PRESENT	0
231736	220077	04088S	PARTICIPANT	\N	PRESENT	0
231737	220077	08043V	PARTICIPANT	\N	PRESENT	0
231738	220077	11066Q	PARTICIPANT	\N	PRESENT	0
231739	220077	14041T	PARTICIPANT	\N	PRESENT	0
231740	220077	11045K	PARTICIPANT	\N	PRESENT	0
231741	220077	11104D	PARTICIPANT	\N	PRESENT	0
231742	220077	11080N	PARTICIPANT	\N	PRESENT	0
231743	220077	80027E	PARTICIPANT	\N	PRESENT	0
231744	220077	08012N	PARTICIPANT	\N	PRESENT	0
231745	220077	19531S	PARTICIPANT	\N	PRESENT	0
231746	220077	19703U	PARTICIPANT	\N	PRESENT	0
231747	220077	19489J	PARTICIPANT	\N	PRESENT	0
231748	220077	95062K	PARTICIPANT	\N	PRESENT	0
231749	220077	08058D	PARTICIPANT	\N	PRESENT	0
231750	220077	14121F	PARTICIPANT	\N	PRESENT	0
231751	220077	14085U	PARTICIPANT	\N	PRESENT	0
231752	220077	14069U	PARTICIPANT	\N	PRESENT	0
231753	220077	19527W	PARTICIPANT	\N	PRESENT	0
231754	220077	19525U	PARTICIPANT	\N	PRESENT	0
231755	220077	11041F	PARTICIPANT	\N	PRESENT	0
231756	220077	19643A	PARTICIPANT	\N	PRESENT	0
231757	220077	19599P	PARTICIPANT	\N	PRESENT	0
231758	220077	04035D	PARTICIPANT	\N	PRESENT	0
214597	214596	07004J	PARTICIPANT	\N	PRESENT	0
214152	207695	14083S	PARTICIPANT	\N	PRESENT	0
214153	207695	11053K	PARTICIPANT	\N	PRESENT	0
214154	207695	19545Y	PARTICIPANT	\N	PRESENT	0
213673	213276	11063M	PARTICIPANT	\N	PRESENT	0
214599	214598	07004J	PARTICIPANT	\N	PRESENT	0
214156	207695	11103C	PARTICIPANT	\N	PRESENT	0
214157	207695	95015C	PARTICIPANT	\N	PRESENT	0
214158	207695	19629C	PARTICIPANT	\N	PRESENT	0
214159	207695	08024S	PARTICIPANT	\N	PRESENT	0
214609	214607	14331P	PARTICIPANT	\N	PRESENT	0
214161	207695	19721W	PARTICIPANT	\N	PRESENT	0
214162	207695	98029W	PARTICIPANT	\N	PRESENT	0
214163	207695	14329V	PARTICIPANT	\N	PRESENT	0
214164	207695	14038Y	PARTICIPANT	\N	PRESENT	0
214165	207695	11080N	PARTICIPANT	\N	PRESENT	0
214166	207695	14195A	PARTICIPANT	\N	PRESENT	0
214069	207695	11074Q	PARTICIPANT	\N	PRESENT	0
214315	207695	19677L	PARTICIPANT	\N	PRESENT	0
214167	207695	08028W	PARTICIPANT	\N	PRESENT	0
214168	207695	19467C	PARTICIPANT	\N	PRESENT	0
214169	207695	18083K	PARTICIPANT	\N	PRESENT	0
214612	214611	14331P	PARTICIPANT	\N	PRESENT	0
214171	207695	14267Y	PARTICIPANT	\N	PRESENT	0
214172	207695	11031D	PARTICIPANT	\N	PRESENT	0
214173	207695	88008L	PARTICIPANT	\N	PRESENT	0
214174	207695	04038G	PARTICIPANT	\N	PRESENT	0
214614	214613	14331P	PARTICIPANT	\N	PRESENT	0
214176	207695	11027H	PARTICIPANT	\N	PRESENT	0
214619	214618	07004J	PARTICIPANT	\N	PRESENT	0
214178	207695	98023Q	PARTICIPANT	\N	PRESENT	0
214179	207695	19253P	PARTICIPANT	\N	PRESENT	0
214620	214615	14331P	PARTICIPANT	\N	PRESENT	0
214181	207695	11115U	PARTICIPANT	\N	PRESENT	0
214182	207695	11056N	PARTICIPANT	\N	PRESENT	0
214622	214621	11048N	PARTICIPANT	\N	PRESENT	0
214184	207695	19525U	PARTICIPANT	\N	PRESENT	0
214682	207699	04059M	PARTICIPANT	\N	PRESENT	0
214683	207699	14255U	PARTICIPANT	\N	PRESENT	0
214187	207695	11065P	PARTICIPANT	\N	PRESENT	0
214188	207695	19693L	PARTICIPANT	\N	PRESENT	0
214189	207695	14259Y	PARTICIPANT	\N	PRESENT	0
214190	207695	04008A	PARTICIPANT	\N	PRESENT	0
214191	207695	08052W	PARTICIPANT	\N	PRESENT	0
214684	207699	19319Q	PARTICIPANT	\N	PRESENT	0
214685	207699	11012A	PARTICIPANT	\N	PRESENT	0
214686	207699	08009T	PARTICIPANT	\N	PRESENT	0
214687	207699	14039A	PARTICIPANT	\N	PRESENT	0
214688	207699	19637C	PARTICIPANT	\N	PRESENT	0
214197	207695	19663E	PARTICIPANT	\N	PRESENT	0
214689	207699	08055A	PARTICIPANT	\N	PRESENT	0
214690	207699	80013X	PARTICIPANT	\N	PRESENT	0
214200	207695	98024R	PARTICIPANT	\N	PRESENT	0
214201	207695	10006L	PARTICIPANT	\N	PRESENT	0
214691	207699	14051J	PARTICIPANT	\N	PRESENT	0
214203	207695	14217N	PARTICIPANT	\N	PRESENT	0
214204	207695	01024M	PARTICIPANT	\N	PRESENT	0
214205	207695	19251M	PARTICIPANT	\N	PRESENT	0
214206	207695	14215L	PARTICIPANT	\N	PRESENT	0
214692	207699	19525U	PARTICIPANT	\N	PRESENT	0
214693	207699	14197C	PARTICIPANT	\N	PRESENT	0
214209	207695	04071H	PARTICIPANT	\N	PRESENT	0
214210	207695	04089T	PARTICIPANT	\N	PRESENT	0
214211	207695	87003B	PARTICIPANT	\N	PRESENT	0
214694	207699	80027E	PARTICIPANT	\N	PRESENT	0
214213	207695	19507S	PARTICIPANT	\N	PRESENT	0
214695	207699	19503N	PARTICIPANT	\N	PRESENT	0
214215	207695	14197C	PARTICIPANT	\N	PRESENT	0
214696	207699	19413M	PARTICIPANT	\N	PRESENT	0
214217	207695	95030B	PARTICIPANT	\N	PRESENT	0
214697	207699	19551W	PARTICIPANT	\N	PRESENT	0
214219	207695	14187A	PARTICIPANT	\N	PRESENT	0
214698	207699	14357A	PARTICIPANT	\N	PRESENT	0
214699	207699	19715Y	PARTICIPANT	\N	PRESENT	0
214700	207699	14235Q	PARTICIPANT	\N	PRESENT	0
214223	207695	14281W	PARTICIPANT	\N	PRESENT	0
214224	207695	08045X	PARTICIPANT	\N	PRESENT	0
214225	207695	19599P	PARTICIPANT	\N	PRESENT	0
214226	207695	14087W	PARTICIPANT	\N	PRESENT	0
214701	207699	11065P	PARTICIPANT	\N	PRESENT	0
214702	207699	11099A	PARTICIPANT	\N	PRESENT	0
214703	207699	04057K	PARTICIPANT	\N	PRESENT	0
214704	207699	14093U	PARTICIPANT	\N	PRESENT	0
214231	207695	08018U	PARTICIPANT	\N	PRESENT	0
214232	207695	11010L	PARTICIPANT	\N	PRESENT	0
214233	207695	14034U	PARTICIPANT	\N	PRESENT	0
214234	207695	04035D	PARTICIPANT	\N	PRESENT	0
214235	207695	14231L	PARTICIPANT	\N	PRESENT	0
214705	207699	19585H	PARTICIPANT	\N	PRESENT	0
214237	207695	19695N	PARTICIPANT	\N	PRESENT	0
214238	207695	14199E	PARTICIPANT	\N	PRESENT	0
214706	207699	19441R	PARTICIPANT	\N	PRESENT	0
214240	207695	08035V	PARTICIPANT	\N	PRESENT	0
214707	207699	08024S	PARTICIPANT	\N	PRESENT	0
214242	207695	15447F	PARTICIPANT	\N	PRESENT	0
214243	207695	08041T	PARTICIPANT	\N	PRESENT	0
214244	207695	19387D	PARTICIPANT	\N	PRESENT	0
214245	207695	19347U	PARTICIPANT	\N	PRESENT	0
214246	207695	19649G	PARTICIPANT	\N	PRESENT	0
214247	207695	07004J	PARTICIPANT	\N	PRESENT	0
214708	207699	89017R	PARTICIPANT	\N	PRESENT	0
214249	207695	08056B	PARTICIPANT	\N	PRESENT	0
214250	207695	14211G	PARTICIPANT	\N	PRESENT	0
214251	207695	19565D	PARTICIPANT	\N	PRESENT	0
214709	207699	19701S	PARTICIPANT	\N	PRESENT	0
214253	207695	14033T	PARTICIPANT	\N	PRESENT	0
214254	207695	11049P	PARTICIPANT	\N	PRESENT	0
214255	207695	14123H	PARTICIPANT	\N	PRESENT	0
214256	207695	14026U	PARTICIPANT	\N	PRESENT	0
214257	207695	01057W	PARTICIPANT	\N	PRESENT	0
214258	207695	98022P	PARTICIPANT	\N	PRESENT	0
214259	207695	11064N	PARTICIPANT	\N	PRESENT	0
214260	207695	19691J	PARTICIPANT	\N	PRESENT	0
214710	207699	19731Y	PARTICIPANT	\N	PRESENT	0
214711	207699	11056N	PARTICIPANT	\N	PRESENT	0
214263	207695	19553Y	PARTICIPANT	\N	PRESENT	0
214264	207695	19725B	PARTICIPANT	\N	PRESENT	0
214265	207695	19329S	PARTICIPANT	\N	PRESENT	0
214266	207695	95037J	PARTICIPANT	\N	PRESENT	0
214712	207699	14147R	PARTICIPANT	\N	PRESENT	0
214268	207695	14179A	PARTICIPANT	\N	PRESENT	0
214713	207699	19575F	PARTICIPANT	\N	PRESENT	0
214714	207699	14119M	PARTICIPANT	\N	PRESENT	0
214271	207695	08069G	PARTICIPANT	\N	PRESENT	0
214272	207695	19399H	PARTICIPANT	\N	PRESENT	0
214273	207695	04097T	PARTICIPANT	\N	PRESENT	0
214274	207695	11048N	PARTICIPANT	\N	PRESENT	0
214275	207695	19591F	PARTICIPANT	\N	PRESENT	0
214276	207695	14213J	PARTICIPANT	\N	PRESENT	0
214277	207695	19551W	PARTICIPANT	\N	PRESENT	0
214278	207695	19511N	PARTICIPANT	\N	PRESENT	0
214279	207695	19715Y	PARTICIPANT	\N	PRESENT	0
214280	207695	14121F	PARTICIPANT	\N	PRESENT	0
214716	207699	19387D	PARTICIPANT	\N	PRESENT	0
214717	207699	02002K	PARTICIPANT	\N	PRESENT	0
214283	207695	19683J	PARTICIPANT	\N	PRESENT	0
214718	207699	19549D	PARTICIPANT	\N	PRESENT	0
214285	207695	19447X	PARTICIPANT	\N	PRESENT	0
214720	207699	14033T	PARTICIPANT	\N	PRESENT	0
214721	207699	04088S	PARTICIPANT	\N	PRESENT	0
214288	207695	14021P	PARTICIPANT	\N	PRESENT	0
214289	207695	14039A	PARTICIPANT	\N	PRESENT	0
214290	207695	99004R	PARTICIPANT	\N	PRESENT	0
214722	207699	14157T	PARTICIPANT	\N	PRESENT	0
214723	207699	08028W	PARTICIPANT	\N	PRESENT	0
214293	207695	14061L	PARTICIPANT	\N	PRESENT	0
214294	207695	14073Q	PARTICIPANT	\N	PRESENT	0
214726	207699	19511N	PARTICIPANT	\N	PRESENT	0
214727	207699	19629C	PARTICIPANT	\N	PRESENT	0
214297	207695	08031R	PARTICIPANT	\N	PRESENT	0
214728	207699	15447F	PARTICIPANT	\N	PRESENT	0
214729	207699	19515S	PARTICIPANT	\N	PRESENT	0
214300	207695	14159V	PARTICIPANT	\N	PRESENT	0
214301	207695	07029T	PARTICIPANT	\N	PRESENT	0
214302	207695	04049K	PARTICIPANT	\N	PRESENT	0
214730	207699	19703U	PARTICIPANT	\N	PRESENT	0
214304	207695	86034E	PARTICIPANT	\N	PRESENT	0
214305	207695	19723Y	PARTICIPANT	\N	PRESENT	0
214731	207699	18083K	PARTICIPANT	\N	PRESENT	0
214307	207695	19699S	PARTICIPANT	\N	PRESENT	0
214308	207695	08015R	PARTICIPANT	\N	PRESENT	0
214732	207699	19631V	PARTICIPANT	\N	PRESENT	0
214310	207695	14277B	PARTICIPANT	\N	PRESENT	0
214311	207695	19711U	PARTICIPANT	\N	PRESENT	0
214312	207695	19709B	PARTICIPANT	\N	PRESENT	0
214313	207695	16685X	PARTICIPANT	\N	PRESENT	0
214314	207695	11026G	PARTICIPANT	\N	PRESENT	0
228811	218472	07033P	PARTICIPANT	\N	PRESENT	0
228812	218472	04061F	PARTICIPANT	\N	PRESENT	0
228813	218472	19581D	PARTICIPANT	\N	PRESENT	0
228814	218472	14199E	PARTICIPANT	\N	PRESENT	0
228815	218472	19521Q	PARTICIPANT	\N	PRESENT	0
228816	218472	19575F	PARTICIPANT	\N	PRESENT	0
228817	218472	19367Y	PARTICIPANT	\N	PRESENT	0
228818	218472	19621T	PARTICIPANT	\N	PRESENT	0
228819	218472	19701S	PARTICIPANT	\N	PRESENT	0
228820	218472	19483C	PARTICIPANT	\N	PRESENT	0
228821	218472	19675J	PARTICIPANT	\N	PRESENT	0
228822	218472	98050T	PARTICIPANT	\N	PRESENT	0
228823	218472	14061L	PARTICIPANT	\N	PRESENT	0
228824	218472	14059S	PARTICIPANT	\N	PRESENT	0
228825	218472	95015C	PARTICIPANT	\N	PRESENT	0
228872	218472	19543W	PARTICIPANT	\N	PRESENT	0
228870	218472	19733B	PARTICIPANT	\N	PRESENT	0
228828	218472	08069G	PARTICIPANT	\N	PRESENT	0
228829	218472	11080N	PARTICIPANT	\N	PRESENT	0
228830	218472	19421M	PARTICIPANT	\N	PRESENT	0
228831	218472	19703U	PARTICIPANT	\N	PRESENT	0
228832	218472	11097X	PARTICIPANT	\N	PRESENT	0
228833	218472	19673G	PARTICIPANT	\N	PRESENT	0
228834	218472	19667J	PARTICIPANT	\N	PRESENT	0
228835	218472	95067Q	PARTICIPANT	\N	PRESENT	0
228836	218472	14147R	PARTICIPANT	\N	PRESENT	0
228837	218472	04049K	PARTICIPANT	\N	PRESENT	0
228838	218472	14105F	PARTICIPANT	\N	PRESENT	0
228839	218472	17583W	PARTICIPANT	\N	PRESENT	0
228840	218472	08047A	PARTICIPANT	\N	PRESENT	0
228841	218472	14115H	PARTICIPANT	\N	PRESENT	0
228842	218472	14119M	PARTICIPANT	\N	PRESENT	0
228843	218472	14069U	PARTICIPANT	\N	PRESENT	0
228844	218472	92040Q	PARTICIPANT	\N	PRESENT	0
228845	218472	14029X	PARTICIPANT	\N	PRESENT	0
228846	218472	86034E	PARTICIPANT	\N	PRESENT	0
228847	218472	98005N	PARTICIPANT	\N	PRESENT	0
228848	218472	19447X	PARTICIPANT	\N	PRESENT	0
228849	218472	14038Y	PARTICIPANT	\N	PRESENT	0
228850	218472	19723Y	PARTICIPANT	\N	PRESENT	0
228851	218472	19507S	PARTICIPANT	\N	PRESENT	0
228852	218472	19467C	PARTICIPANT	\N	PRESENT	0
228853	218472	18083K	PARTICIPANT	\N	PRESENT	0
228854	218472	08019V	PARTICIPANT	\N	PRESENT	0
228855	218472	04086Q	PARTICIPANT	\N	PRESENT	0
228856	218472	19399H	PARTICIPANT	\N	PRESENT	0
228857	218472	19693L	PARTICIPANT	\N	PRESENT	0
228858	218472	14265W	PARTICIPANT	\N	PRESENT	0
228859	218472	14213J	PARTICIPANT	\N	PRESENT	0
228860	218472	19729F	PARTICIPANT	\N	PRESENT	0
228861	218472	19573D	PARTICIPANT	\N	PRESENT	0
228862	218472	08015R	PARTICIPANT	\N	PRESENT	0
228863	218472	08062Y	PARTICIPANT	\N	PRESENT	0
228864	218472	14355X	PARTICIPANT	\N	PRESENT	0
228865	218472	19443T	PARTICIPANT	\N	PRESENT	0
228866	218472	19657G	PARTICIPANT	\N	PRESENT	0
228867	218472	07029T	PARTICIPANT	\N	PRESENT	0
228868	218472	19663E	PARTICIPANT	\N	PRESENT	0
228869	218472	14123H	PARTICIPANT	\N	PRESENT	0
228871	218472	11049P	PARTICIPANT	\N	PRESENT	0
228873	218472	14031R	PARTICIPANT	\N	PRESENT	0
228874	218472	08020N	PARTICIPANT	\N	PRESENT	0
228875	218472	04047H	PARTICIPANT	\N	PRESENT	0
228876	218472	04042C	PARTICIPANT	\N	PRESENT	0
228877	218472	11048N	PARTICIPANT	\N	PRESENT	0
228878	218472	04008A	PARTICIPANT	\N	PRESENT	0
228879	218472	19511N	PARTICIPANT	\N	PRESENT	0
228900	218472	95063L	PARTICIPANT	\N	PRESENT	0
228881	218472	15447F	PARTICIPANT	\N	PRESENT	0
228882	218472	01043Q	PARTICIPANT	\N	PRESENT	0
228888	218472	11110B	PARTICIPANT	\N	PRESENT	0
228884	218472	98024R	PARTICIPANT	\N	PRESENT	0
228886	218472	05008E	PARTICIPANT	\N	PRESENT	0
228887	218472	17589D	PARTICIPANT	\N	PRESENT	0
228889	218472	19643A	PARTICIPANT	\N	PRESENT	0
228890	218472	17637T	PARTICIPANT	\N	PRESENT	0
228904	218472	19551W	PARTICIPANT	\N	PRESENT	0
228905	218472	01057W	PARTICIPANT	\N	PRESENT	0
228941	218472	11045K	PARTICIPANT	\N	PRESENT	0
228943	228942	14105F	PARTICIPANT	\N	PRESENT	0
228945	228942	14255U	PARTICIPANT	\N	PRESENT	0
228946	228942	04042C	PARTICIPANT	\N	PRESENT	0
228947	228942	19721W	PARTICIPANT	\N	PRESENT	0
228948	228942	98029W	PARTICIPANT	\N	PRESENT	0
228949	228942	14267Y	PARTICIPANT	\N	PRESENT	0
228950	228942	11027H	PARTICIPANT	\N	PRESENT	0
228951	228942	19251M	PARTICIPANT	\N	PRESENT	0
228952	228942	08056B	PARTICIPANT	\N	PRESENT	0
228953	228942	95037J	PARTICIPANT	\N	PRESENT	0
228954	228942	19583F	PARTICIPANT	\N	PRESENT	0
228955	228942	98005N	PARTICIPANT	\N	PRESENT	0
228956	228942	16685X	PARTICIPANT	\N	PRESENT	0
228957	228942	08047A	PARTICIPANT	\N	PRESENT	0
228958	228942	19319Q	PARTICIPANT	\N	PRESENT	0
228959	228942	14235Q	PARTICIPANT	\N	PRESENT	0
228960	228942	19443T	PARTICIPANT	\N	PRESENT	0
228961	228942	14055N	PARTICIPANT	\N	PRESENT	0
228962	218472	04034C	PARTICIPANT	\N	PRESENT	0
228963	218472	89017R	PARTICIPANT	\N	PRESENT	0
228964	218472	14207L	PARTICIPANT	\N	PRESENT	0
228965	218472	11077T	PARTICIPANT	\N	PRESENT	0
228966	218472	19689Q	PARTICIPANT	\N	PRESENT	0
228967	218472	04040A	PARTICIPANT	\N	PRESENT	0
228968	218472	14089Y	PARTICIPANT	\N	PRESENT	0
228969	218472	14255U	PARTICIPANT	\N	PRESENT	0
228970	218472	11053K	PARTICIPANT	\N	PRESENT	0
228971	218472	19699S	PARTICIPANT	\N	PRESENT	0
228972	218472	14221J	PARTICIPANT	\N	PRESENT	0
228973	218472	04070G	PARTICIPANT	\N	PRESENT	0
228974	218472	19479G	PARTICIPANT	\N	PRESENT	0
228975	218472	98023Q	PARTICIPANT	\N	PRESENT	0
228976	218472	14079W	PARTICIPANT	\N	PRESENT	0
228977	218472	08039A	PARTICIPANT	\N	PRESENT	0
228978	228942	19421M	PARTICIPANT	\N	PRESENT	0
228979	218472	14253S	PARTICIPANT	\N	PRESENT	0
228980	218472	14237S	PARTICIPANT	\N	PRESENT	0
228981	218472	19679N	PARTICIPANT	\N	PRESENT	0
228982	218472	11043H	PARTICIPANT	\N	PRESENT	0
228983	228942	01058X	PARTICIPANT	\N	PRESENT	0
228984	228942	01062T	PARTICIPANT	\N	PRESENT	0
228985	228942	11066Q	PARTICIPANT	\N	PRESENT	0
228986	228942	95067Q	PARTICIPANT	\N	PRESENT	0
228989	228675	11072N	PARTICIPANT	\N	PRESENT	0
228990	228675	98018T	PARTICIPANT	\N	PRESENT	0
228991	228675	14001X	PARTICIPANT	\N	PRESENT	0
228992	228675	14257W	PARTICIPANT	\N	PRESENT	0
228993	228675	19349W	PARTICIPANT	\N	PRESENT	0
228994	228675	04057K	PARTICIPANT	\N	PRESENT	0
228995	228675	19369B	PARTICIPANT	\N	PRESENT	0
228996	228675	14073Q	PARTICIPANT	\N	PRESENT	0
228997	228675	19737F	PARTICIPANT	\N	PRESENT	0
228998	228675	19483C	PARTICIPANT	\N	PRESENT	0
228999	228675	14357A	PARTICIPANT	\N	PRESENT	0
229000	228675	98050T	PARTICIPANT	\N	PRESENT	0
229001	228675	14157T	PARTICIPANT	\N	PRESENT	0
229002	228675	14033T	PARTICIPANT	\N	PRESENT	0
229003	228675	19467C	PARTICIPANT	\N	PRESENT	0
229004	228675	98035U	PARTICIPANT	\N	PRESENT	0
229005	228675	11083R	PARTICIPANT	\N	PRESENT	0
229006	228675	11066Q	PARTICIPANT	\N	PRESENT	0
229007	228675	19725B	PARTICIPANT	\N	PRESENT	0
229008	228675	19563B	PARTICIPANT	\N	PRESENT	0
229009	228675	14089Y	PARTICIPANT	\N	PRESENT	0
229010	228675	14119M	PARTICIPANT	\N	PRESENT	0
229011	228675	95062K	PARTICIPANT	\N	PRESENT	0
229012	228675	88008L	PARTICIPANT	\N	PRESENT	0
229013	228675	11012A	PARTICIPANT	\N	PRESENT	0
229014	228675	19549D	PARTICIPANT	\N	PRESENT	0
229015	228675	19593H	PARTICIPANT	\N	PRESENT	0
229016	228675	04061F	PARTICIPANT	\N	PRESENT	0
229017	228675	11097X	PARTICIPANT	\N	PRESENT	0
229018	228675	14237S	PARTICIPANT	\N	PRESENT	0
229019	228675	11026G	PARTICIPANT	\N	PRESENT	0
229020	228675	08020N	PARTICIPANT	\N	PRESENT	0
229021	228675	08056B	PARTICIPANT	\N	PRESENT	0
229022	228675	17583W	PARTICIPANT	\N	PRESENT	0
229023	228675	14197C	PARTICIPANT	\N	PRESENT	0
229024	228675	19441R	PARTICIPANT	\N	PRESENT	0
229025	228675	19333N	PARTICIPANT	\N	PRESENT	0
229026	228675	14147R	PARTICIPANT	\N	PRESENT	0
229027	228675	14265W	PARTICIPANT	\N	PRESENT	0
229028	228675	14029X	PARTICIPANT	\N	PRESENT	0
229029	228675	19479G	PARTICIPANT	\N	PRESENT	0
229030	228675	14103D	PARTICIPANT	\N	PRESENT	0
229031	228675	19679N	PARTICIPANT	\N	PRESENT	0
229032	228675	14105F	PARTICIPANT	\N	PRESENT	0
229033	228675	19543W	PARTICIPANT	\N	PRESENT	0
219802	207719	19521Q	PARTICIPANT	\N	PRESENT	0
219803	207719	19703U	PARTICIPANT	\N	PRESENT	0
219804	207719	19687N	PARTICIPANT	\N	PRESENT	0
219805	207719	14157T	PARTICIPANT	\N	PRESENT	0
219806	207719	11045K	PARTICIPANT	\N	PRESENT	0
219807	207719	14217N	PARTICIPANT	\N	PRESENT	0
219809	207719	19575F	PARTICIPANT	\N	PRESENT	0
219811	207719	14121F	PARTICIPANT	\N	PRESENT	0
219800	207719	11063M	PARTICIPANT	\N	PRESENT	0
219801	207719	14213J	PARTICIPANT	\N	PRESENT	0
219812	207719	19727D	PARTICIPANT	\N	PRESENT	0
219813	207719	14031R	PARTICIPANT	\N	PRESENT	0
219814	207719	10006L	PARTICIPANT	\N	PRESENT	0
219815	207719	19715Y	PARTICIPANT	\N	PRESENT	0
219854	207719	14055N	PARTICIPANT	\N	PRESENT	0
219857	207719	14079W	PARTICIPANT	\N	PRESENT	0
219862	207719	14073Q	PARTICIPANT	\N	PRESENT	0
219868	207719	19663E	PARTICIPANT	\N	PRESENT	0
219869	207719	14033T	PARTICIPANT	\N	PRESENT	0
219870	207719	19527W	PARTICIPANT	\N	PRESENT	0
219871	207719	14259Y	PARTICIPANT	\N	PRESENT	0
219888	207719	19335Q	PARTICIPANT	\N	PRESENT	0
219889	207719	98029W	PARTICIPANT	\N	PRESENT	0
219890	207719	19447X	PARTICIPANT	\N	PRESENT	0
219891	207719	19723Y	PARTICIPANT	\N	PRESENT	0
219892	207719	19673G	PARTICIPANT	\N	PRESENT	0
219893	207719	14257W	PARTICIPANT	\N	PRESENT	0
219894	207719	17779H	PARTICIPANT	\N	PRESENT	0
219895	207719	19483C	PARTICIPANT	\N	PRESENT	0
219912	207719	14071N	PARTICIPANT	\N	PRESENT	0
219913	207719	04043D	PARTICIPANT	\N	PRESENT	0
219915	207719	14249W	PARTICIPANT	\N	PRESENT	0
219919	207719	07004J	PARTICIPANT	\N	PRESENT	0
219924	207719	14083S	PARTICIPANT	\N	PRESENT	0
219925	207719	04085P	PARTICIPANT	\N	PRESENT	0
219926	207719	08019V	PARTICIPANT	\N	PRESENT	0
219927	207719	19693L	PARTICIPANT	\N	PRESENT	0
219931	207719	19649G	PARTICIPANT	\N	PRESENT	0
219936	207719	08010L	PARTICIPANT	\N	PRESENT	0
219937	207719	11054L	PARTICIPANT	\N	PRESENT	0
219939	207719	16685X	PARTICIPANT	\N	PRESENT	0
219946	207719	19689Q	PARTICIPANT	\N	PRESENT	0
219947	207719	04057K	PARTICIPANT	\N	PRESENT	0
219948	207719	11109J	PARTICIPANT	\N	PRESENT	0
219949	207719	19683J	PARTICIPANT	\N	PRESENT	0
219950	207719	19253P	PARTICIPANT	\N	PRESENT	0
219951	207719	14261S	PARTICIPANT	\N	PRESENT	0
219965	207719	19671E	PARTICIPANT	\N	PRESENT	0
219994	207719	14199E	PARTICIPANT	\N	PRESENT	0
220021	207719	11033F	PARTICIPANT	\N	PRESENT	0
220022	207719	19695N	PARTICIPANT	\N	PRESENT	0
220023	217448	14038Y	PARTICIPANT	\N	PRESENT	0
220024	217448	19333N	PARTICIPANT	\N	PRESENT	0
220025	217448	19701S	PARTICIPANT	\N	PRESENT	0
220026	217448	14031R	PARTICIPANT	\N	PRESENT	0
220027	217448	19713W	PARTICIPANT	\N	PRESENT	0
220028	217448	14219Q	PARTICIPANT	\N	PRESENT	0
220029	217448	08055A	PARTICIPANT	\N	PRESENT	0
220030	217448	19599P	PARTICIPANT	\N	PRESENT	0
220031	217448	19289C	PARTICIPANT	\N	PRESENT	0
220032	217448	14169X	PARTICIPANT	\N	PRESENT	0
220033	217448	18083K	PARTICIPANT	\N	PRESENT	0
220034	217448	04086Q	PARTICIPANT	\N	PRESENT	0
220035	217448	05012A	PARTICIPANT	\N	PRESENT	0
220036	217448	14051J	PARTICIPANT	\N	PRESENT	0
220037	217448	08009T	PRESIDENT	0	PRESENT	0
220038	217448	19347U	PARTICIPANT	\N	PRESENT	0
220039	217448	19503N	PARTICIPANT	\N	PRESENT	0
220040	217448	04097T	PARTICIPANT	\N	PRESENT	0
220041	217448	19739H	PARTICIPANT	\N	PRESENT	0
220042	217448	14157T	PARTICIPANT	\N	PRESENT	0
220043	217448	08024S	PARTICIPANT	\N	PRESENT	0
220044	217448	98023Q	PARTICIPANT	\N	PRESENT	0
220045	217448	02002K	PARTICIPANT	\N	EXCUSE	0
220046	207719	14034U	PARTICIPANT	\N	PRESENT	0
220047	207719	08035V	PARTICIPANT	\N	PRESENT	0
220049	207719	14179A	PARTICIPANT	\N	PRESENT	0
220053	207719	08016S	PARTICIPANT	\N	PRESENT	0
220054	207719	19301E	PARTICIPANT	\N	PRESENT	0
220080	207719	11085T	PARTICIPANT	\N	PRESENT	0
220089	207720	04086Q	PARTICIPANT	\N	PRESENT	0
220128	207720	14071N	PARTICIPANT	\N	PRESENT	0
220091	207720	19695N	PARTICIPANT	\N	PRESENT	0
220092	207720	19727D	PARTICIPANT	\N	PRESENT	0
220093	207720	17779H	PARTICIPANT	\N	PRESENT	0
220094	207720	11109J	PARTICIPANT	\N	PRESENT	0
220095	207720	19683J	PARTICIPANT	\N	PRESENT	0
220096	207720	14227Q	PARTICIPANT	\N	PRESENT	0
220097	207720	19503N	PARTICIPANT	\N	PRESENT	0
220098	207720	14281W	PARTICIPANT	\N	PRESENT	0
220099	207720	08052W	PARTICIPANT	\N	PRESENT	0
220100	207720	14239U	PARTICIPANT	\N	PRESENT	0
220101	207720	19697Q	PARTICIPANT	\N	PRESENT	0
220102	207720	04045F	PARTICIPANT	\N	PRESENT	0
220103	207720	10006L	PARTICIPANT	\N	PRESENT	0
220104	207720	11097X	PARTICIPANT	\N	PRESENT	0
220105	207720	11067R	PARTICIPANT	\N	PRESENT	0
220106	207720	19553Y	PARTICIPANT	\N	PRESENT	0
220107	207720	14195A	PARTICIPANT	\N	PRESENT	0
220108	207720	01034P	PARTICIPANT	\N	PRESENT	0
220109	207720	14261S	PARTICIPANT	\N	PRESENT	0
220110	207720	19543W	PARTICIPANT	\N	PRESENT	0
220111	207720	04018C	PARTICIPANT	\N	PRESENT	0
220112	207720	08034U	PARTICIPANT	\N	PRESENT	0
220113	207720	19711U	PARTICIPANT	\N	PRESENT	0
220114	207720	14157T	PARTICIPANT	\N	PRESENT	0
220115	207720	08019V	PARTICIPANT	\N	PRESENT	0
220116	207720	19415P	PARTICIPANT	\N	PRESENT	0
220117	207720	19663E	PARTICIPANT	\N	PRESENT	0
220118	207720	19521Q	PARTICIPANT	\N	PRESENT	0
220119	207720	19447X	PARTICIPANT	\N	PRESENT	0
220120	207720	14119M	PARTICIPANT	\N	PRESENT	0
220121	207720	19671E	PARTICIPANT	\N	PRESENT	0
220122	207720	04092N	PARTICIPANT	\N	PRESENT	0
220123	207720	19703U	PARTICIPANT	\N	PRESENT	0
220124	207720	19575F	PARTICIPANT	\N	PRESENT	0
220125	207720	11033F	PARTICIPANT	\N	PRESENT	0
220126	207720	11031D	PARTICIPANT	\N	PRESENT	0
220127	207720	11063M	PARTICIPANT	\N	PRESENT	0
220129	207720	08069G	PARTICIPANT	\N	PRESENT	0
220130	207720	14217N	PARTICIPANT	\N	PRESENT	0
220131	207720	14213J	PARTICIPANT	\N	PRESENT	0
220132	207720	14265W	PARTICIPANT	\N	PRESENT	0
220133	207720	14042U	PARTICIPANT	\N	PRESENT	0
220134	207720	11077T	PARTICIPANT	\N	PRESENT	0
220135	207720	19301E	PARTICIPANT	\N	PRESENT	0
220136	207720	08035V	PARTICIPANT	\N	PRESENT	0
220137	207720	14179A	PARTICIPANT	\N	PRESENT	0
221599	221367	04057K	PARTICIPANT	\N	PRESENT	0
221600	221367	14073Q	PARTICIPANT	\N	PRESENT	0
221601	221367	08035V	PARTICIPANT	\N	PRESENT	0
221602	221367	08043V	PARTICIPANT	\N	PRESENT	0
221603	221367	19693L	PARTICIPANT	\N	PRESENT	0
221604	221367	19399H	PARTICIPANT	\N	PRESENT	0
221605	221367	87003B	PARTICIPANT	\N	PRESENT	0
221606	221367	14201E	PARTICIPANT	\N	PRESENT	0
221607	221367	14030Q	PARTICIPANT	\N	PRESENT	0
221608	221367	19731Y	PARTICIPANT	\N	PRESENT	0
221609	221367	08020N	PARTICIPANT	\N	PRESENT	0
221610	221367	19735D	PARTICIPANT	\N	PRESENT	0
221611	221367	14063N	PARTICIPANT	\N	PRESENT	0
221612	221367	11083R	PARTICIPANT	\N	PRESENT	0
221613	221367	11104D	PARTICIPANT	\N	PRESENT	0
221614	221367	04018C	PARTICIPANT	\N	PRESENT	0
221615	221367	19643A	PARTICIPANT	\N	EXCUSE	0
221616	220317	14069U	PARTICIPANT	\N	PRESENT	0
221617	219746	14087W	PARTICIPANT	\N	PRESENT	0
221618	219746	19663E	PARTICIPANT	\N	PRESENT	0
221619	220317	19581D	PARTICIPANT	\N	PRESENT	0
221620	220317	11049P	PARTICIPANT	\N	PRESENT	0
221777	219487	95067Q	PARTICIPANT	\N	PRESENT	0
221848	218276	04059M	PARTICIPANT	\N	PRESENT	0
221864	218276	04038G	PARTICIPANT	\N	PRESENT	0
221865	218276	19349W	PARTICIPANT	\N	PRESENT	0
221866	218276	19525U	PARTICIPANT	\N	PRESENT	0
221867	218276	19631V	PARTICIPANT	\N	PRESENT	0
221868	218276	19549D	PARTICIPANT	\N	PRESENT	0
221869	218276	19503N	PARTICIPANT	\N	PRESENT	0
221870	218276	14053L	PARTICIPANT	\N	PRESENT	0
221871	218276	19383Y	PARTICIPANT	\N	PRESENT	0
221872	218276	14191V	PARTICIPANT	\N	PRESENT	0
221873	218276	11081P	PARTICIPANT	\N	PRESENT	0
221874	218276	88008L	PARTICIPANT	\N	PRESENT	0
221875	218276	19511N	PARTICIPANT	\N	PRESENT	0
221876	218276	14231L	PARTICIPANT	\N	PRESENT	0
221877	218276	14235Q	PARTICIPANT	\N	PRESENT	0
221878	218276	19413M	PARTICIPANT	\N	PRESENT	0
221879	218276	14063N	PARTICIPANT	\N	PRESENT	0
221880	218276	11066Q	PARTICIPANT	\N	PRESENT	0
231759	220077	19725B	PARTICIPANT	\N	PRESENT	0
231760	220077	19333N	PARTICIPANT	\N	PRESENT	0
231761	220077	04044E	PARTICIPANT	\N	PRESENT	0
231762	220077	89017R	PARTICIPANT	\N	PRESENT	0
231763	220077	14227Q	PARTICIPANT	\N	PRESENT	0
231764	220077	92040Q	PARTICIPANT	\N	PRESENT	0
231765	220077	11090Q	PARTICIPANT	\N	PRESENT	0
231766	220077	19683J	PARTICIPANT	\N	PRESENT	0
231767	220077	11054L	PARTICIPANT	\N	PRESENT	0
231768	220077	19251M	PARTICIPANT	\N	PRESENT	0
231769	220077	19383Y	PARTICIPANT	\N	PRESENT	0
231770	220077	19693L	PARTICIPANT	\N	PRESENT	0
231771	220077	11026G	PARTICIPANT	\N	PRESENT	0
231772	220077	19503N	PARTICIPANT	\N	PRESENT	0
231773	220077	04018C	PARTICIPANT	\N	PRESENT	0
231774	220077	19591F	PARTICIPANT	\N	PRESENT	0
231775	220077	11067R	PARTICIPANT	\N	PRESENT	0
231776	220077	19689Q	PARTICIPANT	\N	PRESENT	0
231777	220077	19551W	PARTICIPANT	\N	PRESENT	0
231778	220077	19483C	PARTICIPANT	\N	PRESENT	0
231779	220077	08015R	PARTICIPANT	\N	PRESENT	0
231780	220077	14257W	PARTICIPANT	\N	PRESENT	0
231781	220077	19631V	PARTICIPANT	\N	PRESENT	0
231782	220077	14207L	PARTICIPANT	\N	PRESENT	0
231783	220077	14231L	PARTICIPANT	\N	PRESENT	0
231784	220077	14029X	PARTICIPANT	\N	PRESENT	0
231785	220077	01034P	PARTICIPANT	\N	PRESENT	0
231786	220077	19369B	PARTICIPANT	\N	PRESENT	0
231787	220077	19691J	PARTICIPANT	\N	PRESENT	0
231788	220077	19569H	PARTICIPANT	\N	PRESENT	0
231789	220077	19611R	PARTICIPANT	\N	PRESENT	0
231790	220077	19511N	PARTICIPANT	\N	PRESENT	0
231791	220077	19619A	PARTICIPANT	\N	PRESENT	0
231792	220077	19721W	PARTICIPANT	\N	PRESENT	0
231793	220077	19699S	PARTICIPANT	\N	PRESENT	0
231794	220077	19737F	PARTICIPANT	\N	PRESENT	0
231795	220077	19735D	PARTICIPANT	\N	PRESENT	0
231796	220077	16685X	PARTICIPANT	\N	PRESENT	0
231797	220077	19441R	PARTICIPANT	\N	PRESENT	0
231798	220077	19479G	PARTICIPANT	\N	PRESENT	0
231799	220077	14219Q	PARTICIPANT	\N	PRESENT	0
231800	220077	19713W	PARTICIPANT	\N	PRESENT	0
231801	220077	19319Q	PARTICIPANT	\N	PRESENT	0
231802	220077	14089Y	PARTICIPANT	\N	PRESENT	0
231803	220077	14267Y	PARTICIPANT	\N	PRESENT	0
231804	220077	14221J	PARTICIPANT	\N	PRESENT	0
231805	220077	14103D	PARTICIPANT	\N	PRESENT	0
231806	220077	19335Q	PARTICIPANT	\N	PRESENT	0
231807	220077	11065P	PARTICIPANT	\N	PRESENT	0
231808	220077	14255U	PARTICIPANT	\N	PRESENT	0
231809	220077	19521Q	PARTICIPANT	\N	PRESENT	0
231810	220077	19413M	PARTICIPANT	\N	PRESENT	0
231811	220077	04040A	PARTICIPANT	\N	PRESENT	0
231812	220077	04070G	PARTICIPANT	\N	PRESENT	0
231813	220077	11070L	PARTICIPANT	\N	PRESENT	0
231814	220077	14327T	PARTICIPANT	\N	PRESENT	0
231815	220077	19739H	PARTICIPANT	\N	PRESENT	0
231816	220077	04085P	PARTICIPANT	\N	PRESENT	0
231817	220077	11049P	PARTICIPANT	\N	PRESENT	0
231818	220077	14059S	PARTICIPANT	\N	PRESENT	0
231819	220077	14061L	PARTICIPANT	\N	PRESENT	0
231820	220077	04045F	PARTICIPANT	\N	PRESENT	0
231821	220077	08018U	PARTICIPANT	\N	PRESENT	0
231822	220077	14105F	PARTICIPANT	\N	PRESENT	0
231823	220077	19709B	PARTICIPANT	\N	PRESENT	0
231824	220077	08035V	PARTICIPANT	\N	PRESENT	0
231825	220077	01062T	PARTICIPANT	\N	PRESENT	0
231826	220077	19621T	PARTICIPANT	\N	PRESENT	0
231827	220077	95015C	PARTICIPANT	\N	PRESENT	0
231828	220077	19467C	PARTICIPANT	\N	PRESENT	0
231829	220077	04008A	PARTICIPANT	\N	PRESENT	0
231830	220077	14147R	PARTICIPANT	\N	PRESENT	0
231831	220077	11053K	PARTICIPANT	\N	PRESENT	0
231832	220077	08047A	PARTICIPANT	\N	PRESENT	0
231833	220077	18083K	PARTICIPANT	\N	PRESENT	0
231834	220077	19701S	PARTICIPANT	\N	PRESENT	0
231835	220077	14038Y	PARTICIPANT	\N	PRESENT	0
231836	220077	19741B	PARTICIPANT	\N	PRESENT	0
231837	220077	19415P	PARTICIPANT	\N	PRESENT	0
231838	220077	19673G	PARTICIPANT	\N	PRESENT	0
231839	220077	07033P	PARTICIPANT	\N	PRESENT	0
231840	220077	14033T	PARTICIPANT	\N	PRESENT	0
231841	220077	19573D	PARTICIPANT	\N	PRESENT	0
231842	220077	05012A	PARTICIPANT	\N	PRESENT	0
231843	220077	19679N	PARTICIPANT	\N	PRESENT	0
231844	220077	14217N	PARTICIPANT	\N	PRESENT	0
231845	220077	19443T	PARTICIPANT	\N	PRESENT	0
231846	220077	14193X	PARTICIPANT	\N	PRESENT	0
231847	220077	14135M	PARTICIPANT	\N	PRESENT	0
231848	220077	19705W	PARTICIPANT	\N	PRESENT	0
231849	220077	19723Y	PARTICIPANT	\N	PRESENT	0
231850	220077	19729F	PARTICIPANT	\N	PRESENT	0
231851	220077	04071H	PARTICIPANT	\N	PRESENT	0
231852	220077	19507S	PARTICIPANT	\N	PRESENT	0
231853	220077	98050T	PARTICIPANT	\N	PRESENT	0
231854	220077	19667J	PARTICIPANT	\N	PRESENT	0
231855	220077	19575F	PARTICIPANT	\N	PRESENT	0
231856	220077	14151M	PARTICIPANT	\N	PRESENT	0
231857	220077	08038Y	PARTICIPANT	\N	PRESENT	0
231858	220077	14281W	PARTICIPANT	\N	PRESENT	0
231859	220077	14053L	PARTICIPANT	\N	PRESENT	0
231860	220077	04049K	PARTICIPANT	\N	PRESENT	0
231861	220077	08041T	PARTICIPANT	\N	PRESENT	0
231862	220077	19733B	PARTICIPANT	\N	PRESENT	0
231863	220077	08062Y	PARTICIPANT	\N	PRESENT	0
231864	220077	14026U	PARTICIPANT	\N	PRESENT	0
231865	220077	05008E	PARTICIPANT	\N	PRESENT	0
231866	220077	19421M	PARTICIPANT	\N	PRESENT	0
231867	220077	11115U	PARTICIPANT	\N	PRESENT	0
231868	220077	19581D	PARTICIPANT	\N	PRESENT	0
231869	220077	19671E	PARTICIPANT	\N	PRESENT	0
231870	220077	14265W	PARTICIPANT	\N	PRESENT	0
231871	220077	14213J	PARTICIPANT	\N	PRESENT	0
231872	220077	19447X	PARTICIPANT	\N	PRESENT	0
231873	220077	19747H	PARTICIPANT	\N	PRESENT	0
232159	220074	14034U	PARTICIPANT	\N	PRESENT	0
232160	232158	10006L	PARTICIPANT	\N	PRESENT	0
232161	232158	14217N	PARTICIPANT	\N	PRESENT	0
232162	232158	14026U	PARTICIPANT	\N	PRESENT	0
232163	232158	11026G	PARTICIPANT	\N	PRESENT	0
232164	232158	14265W	PARTICIPANT	\N	PRESENT	0
232165	220074	19585H	PARTICIPANT	\N	PRESENT	0
232172	220074	19737F	PARTICIPANT	\N	PRESENT	0
232177	220074	14089Y	PARTICIPANT	\N	PRESENT	0
232178	220074	97011G	PARTICIPANT	\N	PRESENT	0
232184	220074	19723Y	PARTICIPANT	\N	PRESENT	0
232185	220074	19447X	PARTICIPANT	\N	PRESENT	0
232187	220074	19581D	PARTICIPANT	\N	PRESENT	0
232189	220074	19575F	PARTICIPANT	\N	PRESENT	0
232190	220074	19703U	PARTICIPANT	\N	PRESENT	0
232193	220074	19725B	PARTICIPANT	\N	PRESENT	0
232194	220074	11012A	PARTICIPANT	\N	PRESENT	0
232195	220074	19387D	PARTICIPANT	\N	PRESENT	0
232197	220074	08020N	PARTICIPANT	\N	PRESENT	0
232198	220074	08044W	PARTICIPANT	\N	PRESENT	0
232199	220074	19629C	PARTICIPANT	\N	PRESENT	0
232200	220074	95062K	PARTICIPANT	\N	PRESENT	0
232201	220074	04018C	PARTICIPANT	\N	PRESENT	0
232204	220074	19565D	PARTICIPANT	\N	PRESENT	0
232205	220074	11072N	PARTICIPANT	\N	PRESENT	0
232207	220074	95030B	PARTICIPANT	\N	PRESENT	0
232209	232208	14083S	PARTICIPANT	\N	PRESENT	0
232210	232208	14187A	PARTICIPANT	\N	PRESENT	0
232211	232208	04049K	PARTICIPANT	\N	PRESENT	0
232212	232208	14205J	PARTICIPANT	\N	PRESENT	0
212041	212040	11041F	PARTICIPANT	\N	PRESENT	0
214379	207695	14237S	PARTICIPANT	\N	PRESENT	0
214380	207695	17637T	PARTICIPANT	\N	PRESENT	0
214733	207699	19591F	PARTICIPANT	\N	PRESENT	0
214734	207699	19565D	PARTICIPANT	\N	PRESENT	0
214383	207695	19533U	PARTICIPANT	\N	PRESENT	0
214384	207695	04088S	PARTICIPANT	\N	PRESENT	0
214385	207695	07034Q	PARTICIPANT	\N	PRESENT	0
214386	207695	19319Q	PARTICIPANT	\N	PRESENT	0
214387	207695	05012A	PARTICIPANT	\N	PRESENT	0
214388	207695	98050T	PARTICIPANT	\N	PRESENT	0
214389	207695	19503N	PARTICIPANT	\N	PRESENT	0
214390	207695	11090Q	PARTICIPANT	\N	PRESENT	0
214391	207695	17583W	PARTICIPANT	\N	PRESENT	0
214392	207695	04043D	PARTICIPANT	\N	PRESENT	0
214393	207695	19735D	PARTICIPANT	\N	PRESENT	0
214735	207699	19347U	PARTICIPANT	\N	PRESENT	0
214395	207695	19679N	PARTICIPANT	\N	PRESENT	0
214396	207695	19443T	PARTICIPANT	\N	PRESENT	0
214397	207695	14135M	PARTICIPANT	\N	PRESENT	0
214398	207695	19349W	PARTICIPANT	\N	PRESENT	0
214399	207695	14331P	PARTICIPANT	\N	PRESENT	0
214736	207699	04085P	PARTICIPANT	\N	PRESENT	0
214401	207695	14055N	PARTICIPANT	\N	PRESENT	0
214402	207695	14225N	PARTICIPANT	\N	PRESENT	0
214737	207699	19695N	PARTICIPANT	\N	PRESENT	0
214404	207695	19705W	PARTICIPANT	\N	PRESENT	0
214405	207695	11012A	PARTICIPANT	\N	PRESENT	0
214406	207695	04033B	PARTICIPANT	\N	PRESENT	0
214738	207699	08038Y	PARTICIPANT	\N	PRESENT	0
214739	207699	11090Q	PARTICIPANT	\N	PRESENT	0
214409	207695	14229S	PARTICIPANT	\N	PRESENT	0
214410	207695	11054L	PARTICIPANT	\N	PRESENT	0
214740	207699	19383Y	PARTICIPANT	\N	PRESENT	0
214412	207695	14107H	PARTICIPANT	\N	PRESENT	0
214741	207699	04049K	PARTICIPANT	\N	PRESENT	0
214414	207695	19421M	PARTICIPANT	\N	PRESENT	0
214742	207699	08060W	PARTICIPANT	\N	PRESENT	0
214416	207695	11043H	PARTICIPANT	\N	PRESENT	0
214473	207696	14179A	PARTICIPANT	\N	PRESENT	0
214743	207699	14207L	PARTICIPANT	\N	PRESENT	0
214419	207695	04018C	PARTICIPANT	\N	PRESENT	0
214420	207695	01058X	PARTICIPANT	\N	PRESENT	0
214421	207695	19703U	PARTICIPANT	\N	PRESENT	0
214422	207695	19713W	PARTICIPANT	\N	PRESENT	0
214423	207695	01028R	PARTICIPANT	\N	PRESENT	0
214744	207699	19599P	PARTICIPANT	\N	PRESENT	0
214425	207695	19689Q	PARTICIPANT	\N	PRESENT	0
214426	207695	19669L	PARTICIPANT	\N	PRESENT	0
214427	207695	14275Y	PARTICIPANT	\N	PRESENT	0
214428	207695	19301E	PARTICIPANT	\N	PRESENT	0
214429	207695	19675J	PARTICIPANT	\N	PRESENT	0
214430	207695	19413M	PARTICIPANT	\N	PRESENT	0
214431	207695	14051J	PARTICIPANT	\N	PRESENT	0
214745	207699	19269X	PARTICIPANT	\N	PRESENT	0
214433	207695	14227Q	PARTICIPANT	\N	PRESENT	0
214434	207695	04044E	PARTICIPANT	\N	PRESENT	0
214746	207699	14063N	PARTICIPANT	\N	PRESENT	0
214747	207699	98050T	PARTICIPANT	\N	PRESENT	0
214748	207699	08073C	PARTICIPANT	\N	PRESENT	0
214749	207699	19329S	PARTICIPANT	\N	PRESENT	0
214750	207699	19683J	PARTICIPANT	\N	PRESENT	0
214440	207695	11066Q	PARTICIPANT	\N	PRESENT	0
214751	207699	97011G	PARTICIPANT	\N	PRESENT	0
214752	207699	14038Y	PARTICIPANT	\N	PRESENT	0
214443	207695	14173T	PARTICIPANT	\N	PRESENT	0
214444	207695	19737F	PARTICIPANT	\N	PRESENT	0
214445	207695	11063M	PARTICIPANT	\N	PRESENT	0
214446	207695	19585H	PARTICIPANT	\N	PRESENT	0
214026	213639	14331P	PARTICIPANT	\N	PRESENT	0
214753	207699	19723Y	PARTICIPANT	\N	PRESENT	0
214472	207696	19441R	PARTICIPANT	\N	PRESENT	0
214316	207695	08010L	PARTICIPANT	\N	PRESENT	0
214474	207696	19301E	PARTICIPANT	\N	PRESENT	0
214475	207696	19387D	PARTICIPANT	\N	PRESENT	0
214476	207696	11085T	PARTICIPANT	\N	PRESENT	0
214027	213639	04071H	PARTICIPANT	\N	PRESENT	0
214028	213639	01048V	PARTICIPANT	\N	PRESENT	0
214029	213639	19545Y	PARTICIPANT	\N	PRESENT	0
214030	213639	01057W	PARTICIPANT	\N	PRESENT	0
214031	213639	11027H	RAPPORTEUR_AVIS	\N	PRESENT	0
214032	213639	11054L	RAPPORTEUR_AVIS	\N	PRESENT	0
214033	213639	89017R	PARTICIPANT	\N	PRESENT	0
214034	213639	11074Q	PRESIDENT	0	PRESENT	0
214035	213639	19667J	PARTICIPANT	\N	PRESENT	0
214036	213639	14225N	PARTICIPANT	\N	PRESENT	0
214037	213639	19671E	PARTICIPANT	\N	PRESENT	0
214038	213639	07029T	PARTICIPANT	\N	PRESENT	0
214039	213639	19349W	PARTICIPANT	\N	PRESENT	0
214040	213639	08010L	PARTICIPANT	\N	PRESENT	0
214041	213639	19711U	PARTICIPANT	\N	PRESENT	0
214042	213639	19651A	PARTICIPANT	\N	PRESENT	0
214043	213639	08034U	PARTICIPANT	\N	PRESENT	0
214044	213639	08069G	PARTICIPANT	\N	PRESENT	0
214045	213639	19689Q	PARTICIPANT	\N	PRESENT	0
214046	213639	12016W	PARTICIPANT	\N	PRESENT	0
214047	213639	08011M	PARTICIPANT	\N	PRESENT	0
214048	213639	08014Q	PARTICIPANT	\N	PRESENT	0
214049	213639	11040E	PARTICIPANT	\N	PRESENT	0
214050	213639	14121F	PARTICIPANT	\N	PRESENT	0
214051	213639	99004R	PARTICIPANT	\N	PRESENT	0
214477	207696	01058X	PARTICIPANT	\N	PRESENT	0
214053	213639	04086Q	PARTICIPANT	\N	EXCUSE	0
214054	213639	14327T	PARTICIPANT	\N	EXCUSE	0
214055	213639	04061F	PARTICIPANT	\N	EXCUSE	0
214478	207696	14261S	PARTICIPANT	\N	PRESENT	0
214754	207699	19507S	PARTICIPANT	\N	PRESENT	0
214317	207695	08034U	PARTICIPANT	\N	PRESENT	0
214318	207695	08039A	PARTICIPANT	\N	PRESENT	0
214319	207695	19289C	PARTICIPANT	\N	PRESENT	0
214320	207695	08017T	PARTICIPANT	\N	PRESENT	0
214321	207695	19483C	PARTICIPANT	\N	PRESENT	0
214322	207695	19729F	PARTICIPANT	\N	PRESENT	0
214755	207699	19467C	PARTICIPANT	\N	PRESENT	0
214324	207695	19697Q	PARTICIPANT	\N	PRESENT	0
214325	207695	19581D	PARTICIPANT	\N	PRESENT	0
214326	207695	11077T	PARTICIPANT	\N	PRESENT	0
214327	207695	14205J	PARTICIPANT	\N	PRESENT	0
214328	207695	14219Q	PARTICIPANT	\N	PRESENT	0
214329	207695	01048V	PARTICIPANT	\N	PRESENT	0
214330	207695	14059S	PARTICIPANT	\N	PRESENT	0
214331	207695	19441R	PARTICIPANT	\N	PRESENT	0
214332	207695	08012N	PARTICIPANT	\N	PRESENT	0
214333	207695	17779H	PARTICIPANT	\N	PRESENT	0
214756	207699	11103C	PARTICIPANT	\N	PRESENT	0
214335	207695	12016W	PARTICIPANT	\N	PRESENT	0
214757	207699	14133K	PARTICIPANT	\N	PRESENT	0
214758	207699	08015R	PARTICIPANT	\N	PRESENT	0
214759	207699	14115H	PARTICIPANT	\N	PRESENT	0
214760	207699	87003B	PARTICIPANT	\N	PRESENT	0
214340	207695	14251Q	PARTICIPANT	\N	PRESENT	0
214341	207695	14063N	PARTICIPANT	\N	PRESENT	0
214342	207695	14031R	PARTICIPANT	\N	PRESENT	0
214343	207695	14111D	PARTICIPANT	\N	PRESENT	0
214344	207695	19637C	PARTICIPANT	\N	PRESENT	0
214345	207695	14001X	PARTICIPANT	\N	PRESENT	0
214346	207695	11085T	PARTICIPANT	\N	PRESENT	0
214347	207695	01060R	PARTICIPANT	\N	PRESENT	0
214761	207699	08020N	PARTICIPANT	\N	PRESENT	0
214762	207699	04097T	PARTICIPANT	\N	PRESENT	0
214350	207695	08053X	PARTICIPANT	\N	PRESENT	0
214351	207695	14221J	PARTICIPANT	\N	PRESENT	0
214763	207699	04008A	PARTICIPANT	\N	PRESENT	0
214764	207699	17637T	PARTICIPANT	\N	PRESENT	0
214354	207695	14147R	PARTICIPANT	\N	PRESENT	0
214765	207699	19713W	PARTICIPANT	\N	PRESENT	0
214356	207695	19671E	PARTICIPANT	\N	PRESENT	0
214357	207695	14223L	PARTICIPANT	\N	PRESENT	0
214358	207695	04092N	PARTICIPANT	\N	PRESENT	0
214359	207695	19335Q	PARTICIPANT	\N	PRESENT	0
214360	207695	19369B	PARTICIPANT	\N	PRESENT	0
214766	207699	19573D	PARTICIPANT	\N	PRESENT	0
214362	207695	14109K	PARTICIPANT	\N	PRESENT	0
214363	207695	14257W	PARTICIPANT	\N	PRESENT	0
214364	207695	08011M	PARTICIPANT	\N	PRESENT	0
214365	207695	14265W	PARTICIPANT	\N	PRESENT	0
214366	207695	04070G	PARTICIPANT	\N	PRESENT	0
214367	207695	14119M	PARTICIPANT	\N	PRESENT	0
214368	207695	14071N	PARTICIPANT	\N	PRESENT	0
214369	207695	92040Q	PARTICIPANT	\N	PRESENT	0
214767	207699	01025N	PARTICIPANT	\N	PRESENT	0
214768	207699	19421M	PARTICIPANT	\N	PRESENT	0
214372	207695	14253S	PARTICIPANT	\N	PRESENT	0
214373	207695	19593H	PARTICIPANT	\N	PRESENT	0
214374	207695	19573D	PARTICIPANT	\N	PRESENT	0
214769	207699	14079W	PARTICIPANT	\N	PRESENT	0
214377	207695	08061X	PARTICIPANT	\N	PRESENT	0
214378	207695	08047A	PARTICIPANT	\N	PRESENT	0
229034	228675	19713W	PARTICIPANT	\N	PRESENT	0
229035	228675	11048N	PARTICIPANT	\N	PRESENT	0
229036	228675	14249W	PARTICIPANT	\N	PRESENT	0
229037	228675	14223L	PARTICIPANT	\N	PRESENT	0
229038	228675	19507S	PARTICIPANT	\N	PRESENT	0
229039	228675	14179A	PARTICIPANT	\N	PRESENT	0
229040	228675	14030Q	PARTICIPANT	\N	PRESENT	0
229041	228675	14042U	PARTICIPANT	\N	PRESENT	0
229042	228675	08049C	PARTICIPANT	\N	PRESENT	0
229043	228675	08011M	PARTICIPANT	\N	PRESENT	0
229044	228675	07029T	PARTICIPANT	\N	PRESENT	0
229045	228675	19545Y	PARTICIPANT	\N	PRESENT	0
229046	228675	19565D	PARTICIPANT	\N	PRESENT	0
229047	228675	14034U	PARTICIPANT	\N	PRESENT	0
229048	228675	18083K	PARTICIPANT	\N	PRESENT	0
229191	228415	14327T	PARTICIPANT	\N	PRESENT	0
229192	228415	04071H	PARTICIPANT	\N	PRESENT	0
229193	228415	01048V	PARTICIPANT	\N	PRESENT	0
229194	228415	19545Y	PARTICIPANT	\N	PRESENT	0
229195	228415	01057W	PARTICIPANT	\N	PRESENT	0
229196	228415	11074Q	PRESIDENT	0	PRESENT	0
229198	228415	19667J	PARTICIPANT	\N	PRESENT	0
229200	228415	14225N	PARTICIPANT	\N	PRESENT	0
229202	228415	88008L	PARTICIPANT	\N	PRESENT	0
229205	228415	11110B	PARTICIPANT	\N	PRESENT	0
229206	228415	07029T	PARTICIPANT	\N	PRESENT	0
229209	228415	14085U	PARTICIPANT	\N	PRESENT	0
229211	228415	19349W	PARTICIPANT	\N	PRESENT	0
229212	228415	19479G	PARTICIPANT	\N	PRESENT	0
229214	228415	11048N	PARTICIPANT	\N	PRESENT	0
229216	228415	19647E	PARTICIPANT	\N	PRESENT	0
229217	228415	19711U	PARTICIPANT	\N	PRESENT	0
229219	228415	19651A	PARTICIPANT	\N	PRESENT	0
229220	228415	08069G	PARTICIPANT	\N	PRESENT	0
229221	228415	19687N	PARTICIPANT	\N	PRESENT	0
229223	228415	14159V	PARTICIPANT	\N	PRESENT	0
229226	228415	04086Q	PARTICIPANT	\N	PRESENT	0
229229	228415	11040E	PARTICIPANT	\N	PRESENT	0
229233	228415	14083S	PARTICIPANT	\N	PRESENT	0
229236	228415	11012A	PARTICIPANT	\N	PRESENT	0
229238	228415	14121F	PARTICIPANT	\N	PRESENT	0
229240	228415	04061F	PARTICIPANT	\N	PRESENT	0
229242	228415	14331P	PARTICIPANT	\N	PRESENT	0
229244	228415	95041E	PARTICIPANT	\N	PRESENT	0
229245	228415	19531S	PARTICIPANT	\N	PRESENT	0
229246	228415	19689Q	PARTICIPANT	\N	PRESENT	0
229247	228415	11053K	PARTICIPANT	\N	PRESENT	0
229249	228415	12016W	PARTICIPANT	\N	PRESENT	0
229250	228415	89017R	PARTICIPANT	\N	PRESENT	0
229252	228415	08011M	PARTICIPANT	\N	PRESENT	0
229254	228415	14034U	PARTICIPANT	\N	PRESENT	0
229256	228415	19671E	PARTICIPANT	\N	PRESENT	0
229258	228415	14199E	PARTICIPANT	\N	PRESENT	0
229261	228415	08073C	PARTICIPANT	\N	PRESENT	0
229264	228415	08010L	PARTICIPANT	\N	PRESENT	0
229266	228415	99004R	PARTICIPANT	\N	PRESENT	0
229268	228415	14253S	PARTICIPANT	\N	PRESENT	0
229270	228415	08034U	PARTICIPANT	\N	EXCUSE	0
229273	228415	07004J	PARTICIPANT	\N	EXCUSE	0
229279	228072	19333N	PARTICIPANT	\N	PRESENT	0
229280	228072	17583W	PARTICIPANT	\N	PRESENT	0
229281	228072	19701S	PARTICIPANT	\N	PRESENT	0
229282	228072	95062K	PARTICIPANT	\N	PRESENT	0
229283	228072	19549D	PARTICIPANT	\N	PRESENT	0
229284	228072	19387D	PARTICIPANT	\N	PRESENT	0
229285	228072	14219Q	PARTICIPANT	\N	PRESENT	0
229286	228072	14221J	PARTICIPANT	\N	PRESENT	0
229287	228072	19599P	PARTICIPANT	\N	PRESENT	0
229288	228072	19637C	PARTICIPANT	\N	PRESENT	0
229289	228072	18083K	PARTICIPANT	\N	PRESENT	0
229290	228072	14237S	PARTICIPANT	\N	PRESENT	0
229291	228072	19551W	PARTICIPANT	\N	PRESENT	0
229292	228072	05012A	PARTICIPANT	\N	PRESENT	0
229293	228072	80027E	PARTICIPANT	\N	PRESENT	0
229294	228072	14051J	PARTICIPANT	\N	PRESENT	0
229295	228072	08060W	PARTICIPANT	\N	PRESENT	0
229296	228072	19503N	PARTICIPANT	\N	PRESENT	0
229297	228072	14157T	PARTICIPANT	\N	PRESENT	0
229298	228072	19685L	PARTICIPANT	\N	PRESENT	0
229299	228072	08024S	PARTICIPANT	\N	PRESENT	0
229300	228072	19681G	PARTICIPANT	\N	PRESENT	0
229301	228072	98023Q	PARTICIPANT	\N	PRESENT	0
229302	228072	17637T	PARTICIPANT	\N	PRESENT	0
229303	228072	19525U	PARTICIPANT	\N	PRESENT	0
229304	228072	14038Y	PARTICIPANT	\N	PRESENT	0
229305	228072	14103D	PARTICIPANT	\N	PRESENT	0
229306	228072	14031R	PARTICIPANT	\N	PRESENT	0
229307	228072	19713W	PARTICIPANT	\N	PRESENT	0
229308	228072	15447F	PARTICIPANT	\N	PRESENT	0
229309	228072	14093U	PARTICIPANT	\N	PRESENT	0
229310	228072	14029X	PARTICIPANT	\N	PRESENT	0
229311	228072	08009T	PRESIDENT	0	PRESENT	0
229312	228072	19739H	PARTICIPANT	\N	PRESENT	0
229313	228072	19741B	PARTICIPANT	\N	PRESENT	0
229314	228072	19733B	PARTICIPANT	\N	EXCUSE	0
229315	228072	02002K	PARTICIPANT	\N	EXCUSE	0
229336	228463	04044E	PARTICIPANT	\N	PRESENT	0
229337	228463	01060R	PARTICIPANT	\N	PRESENT	0
229339	228988	04070G	PRESIDENT	0	PRESENT	0
229340	228988	19699S	PARTICIPANT	\N	PRESENT	0
229341	228988	19533U	PARTICIPANT	\N	PRESENT	0
229342	228988	95015C	PARTICIPANT	\N	PRESENT	0
229343	228988	14241N	PARTICIPANT	\N	PRESENT	0
229344	228988	19573D	PARTICIPANT	\N	PRESENT	0
229345	228988	14107H	PARTICIPANT	\N	PRESENT	0
229346	228988	08016S	PARTICIPANT	\N	PRESENT	0
229347	228988	14249W	PARTICIPANT	\N	PRESENT	0
229348	228988	08039A	PARTICIPANT	\N	PRESENT	0
229349	228988	14059S	PARTICIPANT	\N	PRESENT	0
229350	228988	14061L	PARTICIPANT	\N	PRESENT	0
229351	228988	14073Q	PARTICIPANT	\N	PRESENT	0
229352	228988	19611R	PARTICIPANT	\N	PRESENT	0
229353	228988	19693L	PARTICIPANT	\N	PRESENT	0
229354	228988	19399H	PARTICIPANT	\N	PRESENT	0
229355	228988	14030Q	PARTICIPANT	\N	PRESENT	0
229356	228988	08020N	PARTICIPANT	\N	PRESENT	0
229357	228988	04059M	PARTICIPANT	\N	PRESENT	0
229358	228988	19735D	PARTICIPANT	\N	PRESENT	0
229359	228988	11109J	PARTICIPANT	\N	PRESENT	0
229360	228988	14109K	PARTICIPANT	\N	PRESENT	0
229361	228988	14063N	PARTICIPANT	\N	PRESENT	0
229362	228988	14123H	PARTICIPANT	\N	PRESENT	0
229363	228988	11104D	PARTICIPANT	\N	PRESENT	0
229364	228988	11043H	PARTICIPANT	\N	PRESENT	0
229365	228988	04018C	PARTICIPANT	\N	PRESENT	0
229366	228988	19621T	PARTICIPANT	\N	PRESENT	0
229367	228988	19643A	PARTICIPANT	\N	EXCUSE	0
229368	228988	12041X	PARTICIPANT	\N	EXCUSE	0
229369	228988	19731Y	PARTICIPANT	\N	EXCUSE	0
229370	228988	14251Q	PARTICIPANT	\N	EXCUSE	0
229371	228988	08043V	PARTICIPANT	\N	EXCUSE	0
229372	228988	87003B	PARTICIPANT	\N	EXCUSE	0
229373	228988	08031R	PARTICIPANT	\N	EXCUSE	0
229374	228988	19593H	PARTICIPANT	\N	EXCUSE	0
229375	228463	14179A	PARTICIPANT	\N	PRESENT	0
229376	228464	19725B	PARTICIPANT	\N	PRESENT	0
229377	228464	14065Q	PARTICIPANT	\N	PRESENT	0
229378	228464	04044E	PARTICIPANT	\N	PRESENT	0
229379	228464	04038G	PARTICIPANT	\N	PRESENT	0
229380	228464	19483C	PARTICIPANT	\N	PRESENT	0
229381	228464	14259Y	PARTICIPANT	\N	PRESENT	0
229382	228464	01028R	PARTICIPANT	\N	PRESENT	0
229383	228464	05008E	PRESIDENT	0	PRESENT	0
229384	228464	19447X	PARTICIPANT	\N	PRESENT	0
229385	228464	11072N	PARTICIPANT	\N	PRESENT	0
229386	228464	14053L	PARTICIPANT	\N	PRESENT	0
229387	228464	14275Y	PARTICIPANT	\N	PRESENT	0
229389	220055	01043Q	PARTICIPANT	\N	PRESENT	0
229390	220055	14021P	PARTICIPANT	\N	PRESENT	0
229391	220055	12041X	PARTICIPANT	\N	PRESENT	0
229392	220055	04085P	PARTICIPANT	\N	PRESENT	0
229393	220055	11049P	PARTICIPANT	\N	PRESENT	0
229394	220055	19631V	PARTICIPANT	\N	PRESENT	0
229395	220055	19713W	PARTICIPANT	\N	PRESENT	0
229396	220055	17583W	PARTICIPANT	\N	PRESENT	0
229397	220055	11067R	PARTICIPANT	\N	PRESENT	0
229398	220055	19367Y	PARTICIPANT	\N	PRESENT	0
229399	220055	19701S	PARTICIPANT	\N	PRESENT	0
229400	220055	14089Y	PARTICIPANT	\N	PRESENT	0
229401	220055	15447F	PARTICIPANT	\N	PRESENT	0
229402	220055	14073Q	PARTICIPANT	\N	PRESENT	0
229403	220055	08068F	PARTICIPANT	\N	PRESENT	0
229404	220055	14063N	PARTICIPANT	\N	PRESENT	0
229405	220055	11033F	PARTICIPANT	\N	PRESENT	0
229406	220055	19695N	PARTICIPANT	\N	PRESENT	0
229407	220055	19593H	PARTICIPANT	\N	PRESENT	0
229408	220055	19719D	PARTICIPANT	\N	PRESENT	0
229409	220055	11031D	PARTICIPANT	\N	PRESENT	0
229410	220055	19729F	PARTICIPANT	\N	PRESENT	0
211793	210045	04061F	PARTICIPANT	\N	EXCUSE	0
212413	212411	19349W	PARTICIPANT	\N	PRESENT	0
213076	210129	14115H	PARTICIPANT	\N	PRESENT	0
213077	210129	14030Q	PRESIDENT	0	PRESENT	0
213078	210129	08043V	PARTICIPANT	\N	PRESENT	0
213079	210129	19367Y	PARTICIPANT	\N	PRESENT	0
213080	210129	19643A	PARTICIPANT	\N	PRESENT	0
213081	210129	19621T	PARTICIPANT	\N	EXCUSE	0
213082	210129	08020N	PARTICIPANT	\N	PRESENT	0
213083	210129	08024S	PARTICIPANT	\N	PRESENT	0
213084	210129	18083K	PARTICIPANT	\N	PRESENT	0
213085	210129	19701S	PARTICIPANT	\N	PRESENT	0
213086	210129	11031D	PARTICIPANT	\N	PRESENT	0
213087	210129	80013X	PARTICIPANT	\N	EXCUSE	0
213088	210129	19693L	PARTICIPANT	\N	PRESENT	0
213089	210129	14217N	PARTICIPANT	\N	PRESENT	0
213090	210129	19577H	PARTICIPANT	\N	EXCUSE	0
213091	210129	14042U	PARTICIPANT	\N	EXCUSE	0
213092	210129	14249W	PARTICIPANT	\N	PRESENT	0
213093	210129	19673G	PARTICIPANT	\N	EXCUSE	0
213094	210129	19599P	PARTICIPANT	\N	PRESENT	0
213095	210129	04035D	PARTICIPANT	\N	PRESENT	0
213096	210129	14179A	PARTICIPANT	\N	EXCUSE	0
213097	210129	19685L	PARTICIPANT	\N	EXCUSE	0
213098	210129	19715Y	PARTICIPANT	\N	PRESENT	0
213099	210129	08031R	PARTICIPANT	\N	PRESENT	0
213100	210129	07029T	PARTICIPANT	\N	PRESENT	0
213101	210129	08017T	PARTICIPANT	\N	EXCUSE	0
213102	210129	01043Q	PARTICIPANT	\N	EXCUSE	0
213103	210129	19697Q	PARTICIPANT	\N	PRESENT	0
213104	210129	19657G	PARTICIPANT	\N	EXCUSE	0
213105	210129	19269X	PARTICIPANT	\N	EXCUSE	0
213106	210129	11045K	PARTICIPANT	\N	PRESENT	0
213107	210129	14251Q	PARTICIPANT	\N	PRESENT	0
213108	210129	19563B	PARTICIPANT	\N	PRESENT	0
213110	210129	14109K	PARTICIPANT	\N	PRESENT	0
213111	210129	14235Q	PARTICIPANT	\N	PRESENT	0
213112	210129	19679N	PARTICIPANT	\N	PRESENT	0
214970	214969	08048B	PARTICIPANT	\N	PRESENT	0
216851	216850	04043D	PARTICIPANT	\N	PRESENT	0
219192	217449	14093U	PARTICIPANT	\N	EXCUSE	0
219193	217449	19503N	PARTICIPANT	\N	EXCUSE	0
219194	217449	01048V	PRESIDENT	0	PRESENT	0
221881	218276	19697Q	PARTICIPANT	\N	PRESENT	0
221882	218276	19387D	PARTICIPANT	\N	PRESENT	0
221883	218276	19735D	PARTICIPANT	\N	PRESENT	0
221884	218276	19467C	PARTICIPANT	\N	PRESENT	0
221885	218276	04045F	PARTICIPANT	\N	PRESENT	0
221886	218276	19489J	PARTICIPANT	\N	PRESENT	0
221887	218276	11056N	PARTICIPANT	\N	PRESENT	0
221888	218276	14257W	PARTICIPANT	\N	PRESENT	0
221889	218276	19701S	PARTICIPANT	\N	PRESENT	0
221890	218276	10006L	PARTICIPANT	\N	PRESENT	0
221891	218276	14259Y	PARTICIPANT	\N	PRESENT	0
221892	218276	01058X	PARTICIPANT	\N	PRESENT	0
221893	218276	08028W	PARTICIPANT	\N	PRESENT	0
221894	218276	19703U	PARTICIPANT	\N	PRESENT	0
221895	218276	14105F	PARTICIPANT	\N	PRESENT	0
221896	218276	14111D	PARTICIPANT	\N	PRESENT	0
221897	218276	08031R	PARTICIPANT	\N	PRESENT	0
221898	218276	19533U	PARTICIPANT	\N	PRESENT	0
221899	218276	08041T	PARTICIPANT	\N	PRESENT	0
221900	218276	11012A	PARTICIPANT	\N	PRESENT	0
221901	218276	14083S	PARTICIPANT	\N	PRESENT	0
221902	218276	14219Q	PARTICIPANT	\N	PRESENT	0
221903	218276	19681G	PARTICIPANT	\N	PRESENT	0
221904	218276	19415P	PARTICIPANT	\N	PRESENT	0
221905	218276	19347U	PARTICIPANT	\N	PRESENT	0
221906	218276	14071N	PARTICIPANT	\N	PRESENT	0
221907	218276	14026U	PARTICIPANT	\N	PRESENT	0
221908	218276	14265W	PARTICIPANT	\N	PRESENT	0
221909	218276	19573D	PARTICIPANT	\N	PRESENT	0
221910	218276	14199E	PARTICIPANT	\N	PRESENT	0
221911	218276	19507S	PARTICIPANT	\N	PRESENT	0
221912	218276	14135M	PARTICIPANT	\N	PRESENT	0
221913	218276	14223L	PARTICIPANT	\N	PRESENT	0
221914	218276	19335Q	PARTICIPANT	\N	PRESENT	0
221915	218276	19739H	PARTICIPANT	\N	PRESENT	0
221916	218276	95015C	PARTICIPANT	\N	PRESENT	0
221917	218276	11049P	PARTICIPANT	\N	PRESENT	0
221918	218276	14147R	PARTICIPANT	\N	PRESENT	0
221919	218276	14211G	PARTICIPANT	\N	PRESENT	0
221920	218276	14187A	PARTICIPANT	\N	PRESENT	0
221921	218276	11065P	PARTICIPANT	\N	PRESENT	0
221922	218276	19715Y	PARTICIPANT	\N	PRESENT	0
221923	218276	11067R	PARTICIPANT	\N	PRESENT	0
221924	218276	19483C	PARTICIPANT	\N	PRESENT	0
221925	218276	14357A	PARTICIPANT	\N	PRESENT	0
221926	218276	14169X	PARTICIPANT	\N	PRESENT	0
221927	218276	14173T	PARTICIPANT	\N	PRESENT	0
221928	218276	19729F	PARTICIPANT	\N	PRESENT	0
221929	218276	97011G	PARTICIPANT	\N	PRESENT	0
221930	218276	14267Y	PARTICIPANT	\N	PRESENT	0
221931	218276	14097Y	PARTICIPANT	\N	PRESENT	0
221932	218276	19333N	PARTICIPANT	\N	PRESENT	0
221933	218276	19727D	PARTICIPANT	\N	PRESENT	0
221934	218276	80013X	PARTICIPANT	\N	PRESENT	0
221935	218276	95030B	PARTICIPANT	\N	PRESENT	0
221936	218276	14205J	PARTICIPANT	\N	PRESENT	0
221937	218276	19441R	PARTICIPANT	\N	PRESENT	0
221938	218276	14033T	PARTICIPANT	\N	PRESENT	0
221939	218276	04088S	PARTICIPANT	\N	PRESENT	0
221940	218276	19737F	PARTICIPANT	\N	PRESENT	0
221941	218276	05008E	PARTICIPANT	\N	PRESENT	0
221942	218276	14207L	PARTICIPANT	\N	PRESENT	0
221943	218276	19253P	PARTICIPANT	\N	PRESENT	0
221944	221368	04070G	PRESIDENT	0	PRESENT	0
221945	221368	19699S	PARTICIPANT	\N	PRESENT	0
211791	210045	11115U	PARTICIPANT	\N	EXCUSE	0
211792	210045	08069G	PARTICIPANT	\N	EXCUSE	0
221946	221368	12041X	PARTICIPANT	\N	PRESENT	0
221947	221368	95015C	PARTICIPANT	\N	PRESENT	0
221948	221368	14229S	PARTICIPANT	\N	PRESENT	0
221949	221368	14241N	PARTICIPANT	\N	PRESENT	0
221950	221368	19573D	PARTICIPANT	\N	PRESENT	0
221951	221368	14039A	PARTICIPANT	\N	PRESENT	0
221952	221368	14107H	PARTICIPANT	\N	PRESENT	0
221953	221368	08017T	PARTICIPANT	\N	PRESENT	0
221954	221368	92040Q	PARTICIPANT	\N	PRESENT	0
221955	221368	08039A	PARTICIPANT	\N	PRESENT	0
221956	221368	08031R	PARTICIPANT	\N	PRESENT	0
221957	221368	19593H	PARTICIPANT	\N	PRESENT	0
221958	221368	19643A	PARTICIPANT	\N	PRESENT	0
221959	221368	14059S	PARTICIPANT	\N	PRESENT	0
221960	221368	04057K	PARTICIPANT	\N	PRESENT	0
221961	221368	19611R	PARTICIPANT	\N	PRESENT	0
221962	221368	08043V	PARTICIPANT	\N	PRESENT	0
221963	221368	19693L	PARTICIPANT	\N	PRESENT	0
221964	221368	19399H	PARTICIPANT	\N	PRESENT	0
221965	221368	14030Q	PARTICIPANT	\N	PRESENT	0
221966	221368	19731Y	PARTICIPANT	\N	PRESENT	0
221967	221368	08020N	PARTICIPANT	\N	PRESENT	0
221968	221368	19735D	PARTICIPANT	\N	PRESENT	0
221969	221368	14109K	PARTICIPANT	\N	PRESENT	0
221970	221368	14123H	PARTICIPANT	\N	PRESENT	0
221971	221368	04018C	PARTICIPANT	\N	PRESENT	0
221972	218276	18083K	PARTICIPANT	\N	PRESENT	0
221973	218276	19659J	PARTICIPANT	\N	PRESENT	0
221974	218276	19577H	PARTICIPANT	\N	PRESENT	0
221975	218276	19637C	PARTICIPANT	\N	PRESENT	0
221976	218276	19713W	PARTICIPANT	\N	PRESENT	0
221977	218276	19725B	PARTICIPANT	\N	PRESENT	0
221978	218276	14197C	PARTICIPANT	\N	PRESENT	0
221979	221368	11083R	PARTICIPANT	\N	PRESENT	0
221980	218276	14069U	PARTICIPANT	\N	PRESENT	0
221981	221368	87003B	PARTICIPANT	\N	PRESENT	0
221982	218277	04059M	PARTICIPANT	\N	PRESENT	0
221983	219918	11048N	PARTICIPANT	\N	PRESENT	0
221984	219918	19479G	PARTICIPANT	\N	PRESENT	0
221985	219918	19711U	PARTICIPANT	\N	PRESENT	0
221986	219918	95041E	PARTICIPANT	\N	PRESENT	0
221987	219918	08034U	PARTICIPANT	\N	PRESENT	0
221988	219918	01057W	PARTICIPANT	\N	PRESENT	0
221989	219918	19689Q	PARTICIPANT	\N	PRESENT	0
221990	219918	11053K	PARTICIPANT	\N	PRESENT	0
221991	219918	11074Q	PRESIDENT	0	PRESENT	0
221992	219918	14034U	PARTICIPANT	\N	PRESENT	0
221993	219918	14159V	PARTICIPANT	\N	PRESENT	0
221994	219918	19671E	PARTICIPANT	\N	PRESENT	0
221995	219918	14225N	PARTICIPANT	\N	PRESENT	0
221996	219918	07029T	PARTICIPANT	\N	PRESENT	0
221997	219918	14083S	PARTICIPANT	\N	PRESENT	0
221998	219918	14085U	PARTICIPANT	\N	PRESENT	0
221999	219918	14121F	PARTICIPANT	\N	PRESENT	0
222000	219918	08010L	PARTICIPANT	\N	PRESENT	0
222001	219918	99004R	PARTICIPANT	\N	PRESENT	0
222002	219918	04061F	PARTICIPANT	\N	PRESENT	0
222003	219918	04086Q	PARTICIPANT	\N	PRESENT	0
222004	219918	04071H	PARTICIPANT	\N	PRESENT	0
232213	232208	19671E	PARTICIPANT	\N	PRESENT	0
232214	232208	14265W	PARTICIPANT	\N	PRESENT	0
232234	220074	19335Q	PARTICIPANT	\N	PRESENT	0
232216	220074	19441R	PARTICIPANT	\N	PRESENT	0
232217	220074	19733B	PARTICIPANT	\N	PRESENT	0
232218	220074	11049P	PARTICIPANT	\N	PRESENT	0
232219	220074	19741B	PARTICIPANT	\N	PRESENT	0
232236	220074	05008E	PARTICIPANT	\N	PRESENT	0
232221	220074	19671E	PARTICIPANT	\N	PRESENT	0
232222	220074	14079W	PARTICIPANT	\N	PRESENT	0
232223	220074	11056N	PARTICIPANT	\N	PRESENT	0
232235	220074	14105F	PARTICIPANT	\N	PRESENT	0
232237	220074	87003B	PARTICIPANT	\N	PRESENT	0
232238	220074	95063L	PARTICIPANT	\N	PRESENT	0
232239	220074	14327T	PARTICIPANT	\N	PRESENT	0
232228	220074	14157T	PARTICIPANT	\N	PRESENT	0
232229	220074	19621T	PARTICIPANT	\N	PRESENT	0
232230	220076	19387D	PARTICIPANT	\N	PRESENT	0
232231	220074	04085P	PARTICIPANT	\N	PRESENT	0
232232	220074	11033F	PARTICIPANT	\N	PRESENT	0
232233	220074	19713W	PARTICIPANT	\N	PRESENT	0
232240	220074	98018T	PARTICIPANT	\N	PRESENT	0
232241	220074	18083K	PARTICIPANT	\N	PRESENT	0
232242	220074	08049C	PARTICIPANT	\N	PRESENT	0
232335	232334	14235Q	PARTICIPANT	\N	PRESENT	0
232410	232409	04059M	PARTICIPANT	\N	PRESENT	0
232411	232409	14069U	PARTICIPANT	\N	PRESENT	0
232412	232409	14089Y	PARTICIPANT	\N	PRESENT	0
232413	232409	14105F	PARTICIPANT	\N	PRESENT	0
232414	232409	18083K	PARTICIPANT	\N	PRESENT	0
232415	232409	14187A	PARTICIPANT	\N	PRESENT	0
232416	232409	19347U	PARTICIPANT	\N	PRESENT	0
232417	232409	98022P	PARTICIPANT	\N	PRESENT	0
232418	232409	04049K	PARTICIPANT	\N	PRESENT	0
232419	232409	19637C	PARTICIPANT	\N	PRESENT	0
232420	232409	14193X	PARTICIPANT	\N	PRESENT	0
232421	232409	19671E	PARTICIPANT	\N	PRESENT	0
232717	232716	96004D	PARTICIPANT	\N	PRESENT	0
232731	232729	19593H	PARTICIPANT	\N	PRESENT	0
232719	232716	14001X	PARTICIPANT	\N	PRESENT	0
232720	232716	11083R	PARTICIPANT	\N	PRESENT	0
232721	232716	95030B	PARTICIPANT	\N	PRESENT	0
232722	232716	08053X	PARTICIPANT	\N	PRESENT	0
232723	232716	19467C	PARTICIPANT	\N	PRESENT	0
232725	232724	14255U	PARTICIPANT	\N	PRESENT	0
232727	232726	10015M	PARTICIPANT	\N	PRESENT	0
232728	232716	14205J	PARTICIPANT	\N	PRESENT	0
232730	232729	14123H	PARTICIPANT	\N	PRESENT	0
232734	232732	14123H	PARTICIPANT	\N	PRESENT	0
232750	232749	87003B	PARTICIPANT	\N	PRESENT	0
232751	232749	11104D	PARTICIPANT	\N	PRESENT	0
232754	232752	87003B	PARTICIPANT	\N	PRESENT	0
232757	232752	11104D	PARTICIPANT	\N	PRESENT	0
232764	232763	87003B	PARTICIPANT	\N	PRESENT	0
232765	232763	11104D	PARTICIPANT	\N	PRESENT	0
232854	232853	07034Q	PARTICIPANT	\N	PRESENT	0
232855	232853	14255U	PARTICIPANT	\N	PRESENT	0
232859	232853	14059S	PARTICIPANT	\N	PRESENT	0
232857	232853	11083R	PARTICIPANT	\N	PRESENT	0
232858	232853	11048N	PARTICIPANT	\N	PRESENT	0
232860	232853	14063N	PARTICIPANT	\N	PRESENT	0
232862	232861	14169X	PARTICIPANT	\N	PRESENT	0
232880	232878	11081P	PARTICIPANT	\N	PRESENT	0
232881	232878	14215L	PARTICIPANT	\N	PRESENT	0
232882	232878	14327T	PARTICIPANT	\N	PRESENT	0
232883	232878	14199E	PARTICIPANT	\N	PRESENT	0
232884	232878	95041E	PARTICIPANT	\N	PRESENT	0
232885	232878	19671E	PARTICIPANT	\N	PRESENT	0
232886	232878	19647E	PARTICIPANT	\N	PRESENT	0
232887	232878	04092N	PARTICIPANT	\N	PRESENT	0
232888	232878	14195A	PARTICIPANT	\N	PRESENT	0
232889	232878	14111D	PARTICIPANT	\N	PRESENT	0
232890	232878	04034C	PARTICIPANT	\N	PRESENT	0
232891	232878	14217N	PARTICIPANT	\N	PRESENT	0
232892	232878	11072N	PARTICIPANT	\N	PRESENT	0
232893	232878	14213J	PARTICIPANT	\N	PRESENT	0
232894	232878	14235Q	PARTICIPANT	\N	PRESENT	0
232895	232878	14197C	PARTICIPANT	\N	PRESENT	0
232896	232878	14085U	PARTICIPANT	\N	PRESENT	0
232897	232878	11067R	PARTICIPANT	\N	PRESENT	0
232898	232878	19349W	PARTICIPANT	\N	PRESENT	0
232899	232878	19709B	PARTICIPANT	\N	PRESENT	0
232900	232878	04088S	PARTICIPANT	\N	PRESENT	0
232901	232878	19731Y	PARTICIPANT	\N	PRESENT	0
232902	232878	19479G	PARTICIPANT	\N	PRESENT	0
232903	232878	19415P	PARTICIPANT	\N	PRESENT	0
232904	232878	19651A	PARTICIPANT	\N	PRESENT	0
232905	232878	14225N	PARTICIPANT	\N	PRESENT	0
232906	232878	08011M	PARTICIPANT	\N	PRESENT	0
232907	232878	19711U	PARTICIPANT	\N	PRESENT	0
232908	232878	11012A	PARTICIPANT	\N	PRESENT	0
232909	232878	19629C	PARTICIPANT	\N	PRESENT	0
232910	232878	97011G	PARTICIPANT	\N	PRESENT	0
232911	232878	19581D	PARTICIPANT	\N	PRESENT	0
232912	232878	14253S	PARTICIPANT	\N	PRESENT	0
232913	232878	14083S	PARTICIPANT	\N	PRESENT	0
232914	232878	95062K	PARTICIPANT	\N	PRESENT	0
232915	232878	19441R	PARTICIPANT	\N	PRESENT	0
232916	232878	14105F	PARTICIPANT	\N	PRESENT	0
232917	232878	01057W	PARTICIPANT	\N	PRESENT	0
232918	232878	11097X	PARTICIPANT	\N	PRESENT	0
232919	232878	19545Y	PARTICIPANT	\N	PRESENT	0
232920	232878	19525U	PARTICIPANT	\N	PRESENT	0
232921	232878	04071H	PARTICIPANT	\N	PRESENT	0
232922	232878	14031R	PARTICIPANT	\N	PRESENT	0
232923	232878	19565D	PARTICIPANT	\N	PRESENT	0
232924	232878	14121F	PARTICIPANT	\N	PRESENT	0
232925	232878	19387D	PARTICIPANT	\N	PRESENT	0
232926	232878	14063N	PARTICIPANT	\N	PRESENT	0
232927	232878	14331P	PARTICIPANT	\N	PRESENT	0
232928	232878	14069U	PARTICIPANT	\N	PRESENT	0
232929	232878	14073Q	PARTICIPANT	\N	PRESENT	0
232930	232878	14038Y	PARTICIPANT	\N	PRESENT	0
232931	232878	19447X	PARTICIPANT	\N	PRESENT	0
232932	232878	14219Q	PARTICIPANT	\N	PRESENT	0
232933	232878	14071N	PARTICIPANT	\N	PRESENT	0
232934	232878	19575F	PARTICIPANT	\N	PRESENT	0
232935	232878	08056B	PARTICIPANT	\N	PRESENT	0
232936	232878	19507S	PARTICIPANT	\N	PRESENT	0
232937	232878	19553Y	PARTICIPANT	\N	PRESENT	0
232993	232992	11053K	PARTICIPANT	\N	PRESENT	0
232994	232992	14159V	PARTICIPANT	\N	PRESENT	0
232995	232992	05012A	PARTICIPANT	\N	PRESENT	0
233000	232999	01028R	PARTICIPANT	\N	PRESENT	0
233003	233002	14331P	PARTICIPANT	\N	PRESENT	0
233004	233002	14225N	PARTICIPANT	\N	PRESENT	0
233021	233020	04047H	PARTICIPANT	\N	PRESENT	0
233022	233020	11026G	PARTICIPANT	\N	PRESENT	0
233024	233023	04047H	PARTICIPANT	\N	PRESENT	0
233025	233023	11026G	PARTICIPANT	\N	PRESENT	0
233027	233026	04047H	PARTICIPANT	\N	PRESENT	0
233028	233026	14021P	PARTICIPANT	\N	PRESENT	0
233029	233026	11026G	PARTICIPANT	\N	PRESENT	0
233040	233039	19421M	PARTICIPANT	\N	PRESENT	0
233054	233052	14275Y	PARTICIPANT	\N	EXCUSE	0
233056	233055	14133K	PARTICIPANT	\N	PRESENT	0
233057	233055	14097Y	PARTICIPANT	\N	PRESENT	0
233169	233168	12016W	PARTICIPANT	\N	EXCUSE	0
233172	233010	14051J	PARTICIPANT	\N	PRESENT	0
233173	233010	14329V	PARTICIPANT	\N	PRESENT	0
233198	232997	14071N	PARTICIPANT	\N	EXCUSE	0
233187	233010	19489J	PARTICIPANT	\N	PRESENT	0
233188	232539	08012N	PARTICIPANT	\N	EXCUSE	0
233202	233200	11101A	PARTICIPANT	\N	PRESENT	0
233204	233203	14187A	PARTICIPANT	\N	PRESENT	0
233207	232998	19687N	PARTICIPANT	\N	EXCUSE	0
233232	233010	19575F	PARTICIPANT	\N	PRESENT	0
233233	232998	08010L	PARTICIPANT	\N	PRESENT	0
233234	232998	14257W	PARTICIPANT	\N	PRESENT	0
233236	232998	14071N	PARTICIPANT	\N	EXCUSE	0
233239	232998	01057W	PARTICIPANT	\N	PRESENT	0
233244	232998	14231L	PARTICIPANT	\N	PRESENT	0
233245	232998	14063N	PARTICIPANT	\N	PRESENT	0
233246	232998	19735D	PARTICIPANT	\N	PRESENT	0
233257	232998	08049C	PARTICIPANT	\N	EXCUSE	0
233278	232997	04086Q	PARTICIPANT	\N	PRESENT	0
233279	232997	19253P	PARTICIPANT	\N	PRESENT	0
233281	232997	14028W	PARTICIPANT	\N	PRESENT	0
233283	233282	14021P	PARTICIPANT	\N	PRESENT	0
233284	233282	19585H	PARTICIPANT	\N	PRESENT	0
233285	232997	14069U	PARTICIPANT	\N	PRESENT	0
233286	232997	19489J	PARTICIPANT	\N	PRESENT	0
213333	213332	07004J	PARTICIPANT	\N	PRESENT	0
213340	213339	11074Q	PARTICIPANT	\N	PRESENT	0
213342	213341	95041E	PARTICIPANT	\N	PRESENT	0
213344	213343	95041E	PARTICIPANT	\N	PRESENT	0
213346	213345	11070L	PARTICIPANT	\N	PRESENT	0
213347	213345	19647E	PARTICIPANT	\N	PRESENT	0
213349	213348	11070L	PARTICIPANT	\N	PRESENT	0
213350	213348	19647E	PARTICIPANT	\N	PRESENT	0
214479	207696	11077T	PARTICIPANT	\N	PRESENT	0
214480	207696	08035V	PARTICIPANT	\N	PRESENT	0
214772	207699	19717B	PARTICIPANT	\N	PRESENT	0
214770	207699	19621T	PARTICIPANT	\N	PRESENT	0
214771	207699	14223L	PARTICIPANT	\N	PRESENT	0
214773	207699	14259Y	PARTICIPANT	\N	PRESENT	0
214774	207699	14265W	PARTICIPANT	\N	PRESENT	0
214775	207699	14103D	PARTICIPANT	\N	PRESENT	0
214776	207699	19681G	PARTICIPANT	\N	PRESENT	0
214777	207699	19335Q	PARTICIPANT	\N	PRESENT	0
214778	207699	19443T	PARTICIPANT	\N	PRESENT	0
214779	207699	14187A	PARTICIPANT	\N	PRESENT	0
214781	207699	14257W	PARTICIPANT	\N	PRESENT	0
214782	207699	08045X	PARTICIPANT	\N	PRESENT	0
214783	207699	14215L	PARTICIPANT	\N	PRESENT	0
214784	207699	08044W	PARTICIPANT	\N	PRESENT	0
214785	207699	14029X	PARTICIPANT	\N	PRESENT	0
214786	207699	19733B	PARTICIPANT	\N	PRESENT	0
214787	207699	19447X	PARTICIPANT	\N	PRESENT	0
214788	207699	01060R	PARTICIPANT	\N	PRESENT	0
214789	207699	14031R	PARTICIPANT	\N	PRESENT	0
214790	207699	14042U	PARTICIPANT	\N	PRESENT	0
214791	207699	14219Q	PARTICIPANT	\N	PRESENT	0
214792	207699	11067R	PARTICIPANT	\N	PRESENT	0
214793	207699	14123H	PARTICIPANT	\N	PRESENT	0
214794	207699	95030B	PARTICIPANT	\N	PRESENT	0
214799	207699	11104D	PARTICIPANT	\N	PRESENT	0
214800	207699	08062Y	PARTICIPANT	\N	PRESENT	0
214801	207699	11066Q	PARTICIPANT	\N	PRESENT	0
214802	207699	98022P	PARTICIPANT	\N	PRESENT	0
214803	207699	14107H	PARTICIPANT	\N	PRESENT	0
214804	207699	14053L	PARTICIPANT	\N	PRESENT	0
214805	207699	08061X	PARTICIPANT	\N	PRESENT	0
214806	207699	11033F	PARTICIPANT	\N	PRESENT	0
214807	207699	01048V	PARTICIPANT	\N	PRESENT	0
214808	207699	99004R	PARTICIPANT	\N	PRESENT	0
214809	207699	14231L	PARTICIPANT	\N	PRESENT	0
214810	207699	08068F	PARTICIPANT	\N	PRESENT	0
214811	207699	11041F	PARTICIPANT	\N	PRESENT	0
214812	207699	14001X	PARTICIPANT	\N	PRESENT	0
214814	207699	16685X	PARTICIPANT	\N	PRESENT	0
214815	207699	19369B	PARTICIPANT	\N	PRESENT	0
214816	207699	19301E	PARTICIPANT	\N	PRESENT	0
214817	207699	19679N	PARTICIPANT	\N	PRESENT	0
214818	207699	11097X	PARTICIPANT	\N	PRESENT	0
214819	207699	19533U	PARTICIPANT	\N	PRESENT	0
214820	207699	14105F	PARTICIPANT	\N	PRESENT	0
214821	207699	14061L	PARTICIPANT	\N	PRESENT	0
214822	207699	14030Q	PARTICIPANT	\N	PRESENT	0
214823	207699	19483C	PARTICIPANT	\N	PRESENT	0
214824	207699	14221J	PARTICIPANT	\N	PRESENT	0
214825	207699	19367Y	PARTICIPANT	\N	PRESENT	0
214826	207699	08053X	PARTICIPANT	\N	PRESENT	0
214827	207699	19685L	PARTICIPANT	\N	PRESENT	0
214828	207699	14073Q	PARTICIPANT	\N	PRESENT	0
214829	207699	08041T	PARTICIPANT	\N	PRESENT	0
214830	207699	14151M	PARTICIPANT	\N	PRESENT	0
214831	207699	14237S	PARTICIPANT	\N	PRESENT	0
214832	207699	19673G	PARTICIPANT	\N	PRESENT	0
214833	214492	19443T	PARTICIPANT	\N	PRESENT	0
214834	214492	11080N	PARTICIPANT	\N	PRESENT	0
214835	214492	95030B	PARTICIPANT	\N	PRESENT	0
214836	214492	04034C	PARTICIPANT	\N	PRESENT	0
214837	214492	04040A	PARTICIPANT	\N	PRESENT	0
214838	214492	14079W	PARTICIPANT	\N	PRESENT	0
214839	214492	16685X	PARTICIPANT	\N	PRESENT	0
214840	214492	11027H	PARTICIPANT	\N	PRESENT	0
214841	214492	04042C	PRESIDENT	0	PRESENT	0
214842	214492	11054L	PARTICIPANT	\N	PRESENT	0
214843	214492	11066Q	PARTICIPANT	\N	PRESENT	0
214844	214492	95037J	PARTICIPANT	\N	PRESENT	0
214845	214492	14055N	PARTICIPANT	\N	PRESENT	0
214846	214492	19421M	PARTICIPANT	\N	PRESENT	0
214847	214492	19709B	PARTICIPANT	\N	PRESENT	0
214848	214492	08049C	PARTICIPANT	\N	PRESENT	0
214849	214492	14193X	PARTICIPANT	\N	PRESENT	0
214850	214492	08053X	PARTICIPANT	\N	PRESENT	0
214851	214492	97011G	PARTICIPANT	\N	PRESENT	0
214852	214492	08047A	PARTICIPANT	\N	PRESENT	0
214853	214492	98029W	PARTICIPANT	\N	PRESENT	0
214854	214492	14097Y	PARTICIPANT	\N	PRESENT	0
214855	214492	95067Q	PARTICIPANT	\N	PRESENT	0
214856	214492	01062T	PARTICIPANT	\N	PRESENT	0
214857	214492	14133K	PARTICIPANT	\N	PRESENT	0
214858	214492	11041F	PARTICIPANT	\N	PRESENT	0
214859	214492	14235Q	PARTICIPANT	\N	PRESENT	0
214860	214492	08058D	PARTICIPANT	\N	PRESENT	0
214861	214492	14028W	PARTICIPANT	\N	PRESENT	0
214862	214492	19721W	PARTICIPANT	\N	PRESENT	0
214863	214492	19319Q	PARTICIPANT	\N	PRESENT	0
214864	214492	14105F	PARTICIPANT	\N	PRESENT	0
214865	214492	98018T	PARTICIPANT	\N	PRESENT	0
214866	214492	98022P	PARTICIPANT	\N	PRESENT	0
214867	214492	11064N	PARTICIPANT	\N	PRESENT	0
214868	214492	14211G	PARTICIPANT	\N	PRESENT	0
214869	214492	14255U	PARTICIPANT	\N	PRESENT	0
214870	214492	01058X	PARTICIPANT	\N	PRESENT	0
214873	214492	08061X	PARTICIPANT	\N	PRESENT	0
214874	207699	14217N	PARTICIPANT	\N	PRESENT	0
214875	207699	04043D	PARTICIPANT	\N	PRESENT	0
214878	207699	14205J	PARTICIPANT	\N	PRESENT	0
214879	207699	19729F	PARTICIPANT	\N	PRESENT	0
214885	214715	04070G	PRESIDENT	0	PRESENT	0
214886	214715	14331P	PARTICIPANT	\N	PRESENT	0
214887	214715	19533U	PARTICIPANT	\N	PRESENT	0
214888	214715	89017R	PARTICIPANT	\N	PRESENT	0
214889	214715	14229S	PARTICIPANT	\N	PRESENT	0
214890	214715	19573D	PARTICIPANT	\N	PRESENT	0
214891	214715	08017T	PARTICIPANT	\N	PRESENT	0
214893	214715	14249W	PARTICIPANT	\N	PRESENT	0
214894	214715	19643A	PARTICIPANT	\N	PRESENT	0
214895	214715	14061L	PARTICIPANT	\N	PRESENT	0
214896	214715	04057K	PARTICIPANT	\N	PRESENT	0
214897	214715	14073Q	PARTICIPANT	\N	PRESENT	0
214898	214715	19611R	PARTICIPANT	\N	PRESENT	0
214899	214715	19693L	PARTICIPANT	\N	PRESENT	0
214900	214715	87003B	PARTICIPANT	\N	PRESENT	0
214901	214715	14201E	PARTICIPANT	\N	PRESENT	0
214902	214715	14030Q	PARTICIPANT	\N	PRESENT	0
214903	214715	19731Y	PARTICIPANT	\N	PRESENT	0
214904	214715	14251Q	PARTICIPANT	\N	PRESENT	0
214905	214715	19735D	PARTICIPANT	\N	PRESENT	0
214906	214715	14063N	PARTICIPANT	\N	PRESENT	0
214907	214715	11083R	PARTICIPANT	\N	PRESENT	0
214908	214715	14109K	PARTICIPANT	\N	PRESENT	0
214909	214715	14123H	PARTICIPANT	\N	PRESENT	0
214910	214715	11104D	PARTICIPANT	\N	PRESENT	0
214911	214715	11043H	PARTICIPANT	\N	PRESENT	0
214912	214715	14241N	PARTICIPANT	\N	EXCUSE	0
214913	214715	08043V	PARTICIPANT	\N	EXCUSE	0
214914	214715	08031R	PARTICIPANT	\N	EXCUSE	0
214918	207699	08039A	PARTICIPANT	\N	PRESENT	0
214920	214919	14065Q	PARTICIPANT	\N	PRESENT	0
214921	214919	10015M	PARTICIPANT	\N	PRESENT	0
214922	207699	19593H	PARTICIPANT	\N	PRESENT	0
214923	207699	14329V	PARTICIPANT	\N	PRESENT	0
214924	207699	95062K	PARTICIPANT	\N	PRESENT	0
214925	214583	14327T	PRESIDENT	1	PRESENT	0
214926	214583	19479G	PARTICIPANT	\N	PRESENT	0
214927	214583	19651A	PARTICIPANT	\N	PRESENT	0
214928	214583	19545Y	PARTICIPANT	\N	PRESENT	0
214929	214583	19689Q	PARTICIPANT	\N	PRESENT	0
214930	214583	12016W	PARTICIPANT	\N	PRESENT	0
214931	214583	11074Q	PRESIDENT	0	PRESENT	0
214932	214583	08011M	PARTICIPANT	\N	PRESENT	0
214933	214583	19671E	PARTICIPANT	\N	PRESENT	0
214934	214583	14173T	PARTICIPANT	\N	PRESENT	0
214935	214583	07029T	PARTICIPANT	\N	PRESENT	0
214936	214583	14083S	PARTICIPANT	\N	PRESENT	0
214937	214583	14085U	PARTICIPANT	\N	PRESENT	0
214938	214583	19349W	PARTICIPANT	\N	PRESENT	0
214939	214583	08010L	PARTICIPANT	\N	PRESENT	0
214940	214583	14121F	PARTICIPANT	\N	PRESENT	0
214941	214583	14331P	PARTICIPANT	\N	PRESENT	0
214942	214583	04071H	PARTICIPANT	\N	PRESENT	0
214943	214583	11048N	PARTICIPANT	\N	PRESENT	0
214944	214583	19647E	PARTICIPANT	\N	PRESENT	0
214945	214583	95041E	PARTICIPANT	\N	PRESENT	0
214946	214583	01048V	PARTICIPANT	\N	PRESENT	0
214947	214583	08034U	PARTICIPANT	\N	PRESENT	0
229411	220055	19739H	PARTICIPANT	\N	PRESENT	0
229412	220055	14207L	PARTICIPANT	\N	PRESENT	0
229413	220055	19581D	PARTICIPANT	\N	PRESENT	0
229414	220055	18083K	PARTICIPANT	\N	PRESENT	0
229415	220055	19503N	PARTICIPANT	\N	PRESENT	0
229416	220055	19671E	PARTICIPANT	\N	PRESENT	0
229417	220055	14179A	PARTICIPANT	\N	PRESENT	0
229418	220055	08062Y	PARTICIPANT	\N	PRESENT	0
229419	220055	19727D	PARTICIPANT	\N	PRESENT	0
229420	220055	04088S	PARTICIPANT	\N	PRESENT	0
229421	220055	14107H	PARTICIPANT	\N	PRESENT	0
229422	220055	14061L	PARTICIPANT	\N	PRESENT	0
229423	220055	19687N	PARTICIPANT	\N	PRESENT	0
229424	220055	19479G	PARTICIPANT	\N	PRESENT	0
229425	220055	04038G	PARTICIPANT	\N	PRESENT	0
229426	220055	11103C	PARTICIPANT	\N	PRESENT	0
229427	220055	19565D	PARTICIPANT	\N	PRESENT	0
229428	220055	01028R	PARTICIPANT	\N	PRESENT	0
229429	220055	14065Q	PARTICIPANT	\N	PRESENT	0
229430	220055	14121F	PARTICIPANT	\N	PRESENT	0
229431	220055	19691J	PARTICIPANT	\N	PRESENT	0
229432	220055	97011G	PARTICIPANT	\N	PRESENT	0
229433	220055	19467C	PARTICIPANT	\N	PRESENT	0
229434	220055	14087W	PARTICIPANT	\N	PRESENT	0
229435	220055	19441R	PARTICIPANT	\N	PRESENT	0
229436	220055	19525U	PARTICIPANT	\N	PRESENT	0
229437	220055	14083S	PARTICIPANT	\N	PRESENT	0
229438	220055	14197C	PARTICIPANT	\N	PRESENT	0
229439	220055	14111D	PARTICIPANT	\N	PRESENT	0
229440	220055	19699S	PARTICIPANT	\N	PRESENT	0
229441	220055	11063M	PARTICIPANT	\N	PRESENT	0
229442	220055	19725B	PARTICIPANT	\N	PRESENT	0
229443	220055	14028W	PARTICIPANT	\N	PRESENT	0
229444	220055	08028W	PARTICIPANT	\N	PRESENT	0
229445	220055	19349W	PARTICIPANT	\N	PRESENT	0
229447	220055	01024M	PARTICIPANT	\N	PRESENT	0
229448	220055	19347U	PARTICIPANT	\N	PRESENT	0
229449	220055	05008E	PARTICIPANT	\N	PRESENT	0
229450	220055	14109K	PARTICIPANT	\N	PRESENT	0
229451	220055	19253P	PARTICIPANT	\N	PRESENT	0
229452	220055	08039A	PARTICIPANT	\N	PRESENT	0
229453	220055	14031R	PARTICIPANT	\N	PRESENT	0
229455	220055	19679N	PARTICIPANT	\N	PRESENT	0
229456	220055	19573D	PARTICIPANT	\N	PRESENT	0
229457	220055	19543W	PARTICIPANT	\N	PRESENT	0
229458	220055	14215L	PARTICIPANT	\N	PRESENT	0
229459	220055	19447X	PARTICIPANT	\N	PRESENT	0
229460	220055	14217N	PARTICIPANT	\N	PRESENT	0
229461	220055	14265W	PARTICIPANT	\N	PRESENT	0
229462	220055	14103D	PARTICIPANT	\N	PRESENT	0
229463	220055	19563B	PARTICIPANT	\N	PRESENT	0
229464	220055	19715Y	PARTICIPANT	\N	PRESENT	0
229465	220055	14257W	PARTICIPANT	\N	PRESENT	0
229466	220055	19383Y	PARTICIPANT	\N	PRESENT	0
229467	220055	14219Q	PARTICIPANT	\N	PRESENT	0
229468	220055	14223L	PARTICIPANT	\N	PRESENT	0
229469	220055	14069U	PARTICIPANT	\N	PRESENT	0
229470	220055	19483C	PARTICIPANT	\N	PRESENT	0
229471	220055	04018C	PARTICIPANT	\N	PRESENT	0
229472	220055	08015R	PARTICIPANT	\N	PRESENT	0
229473	220055	14119M	PARTICIPANT	\N	PRESENT	0
229474	220055	14059S	PARTICIPANT	\N	PRESENT	0
229475	220055	01048V	PARTICIPANT	\N	PRESENT	0
229476	220055	08061X	PARTICIPANT	\N	PRESENT	0
229477	220055	19489J	PARTICIPANT	\N	PRESENT	0
229478	220055	14030Q	PARTICIPANT	\N	PRESENT	0
229479	220055	19683J	PARTICIPANT	\N	PRESENT	0
229485	220055	01025N	PARTICIPANT	\N	PRESENT	0
229487	220055	19415P	PARTICIPANT	\N	PRESENT	0
229488	220055	08020N	PARTICIPANT	\N	PRESENT	0
229489	220055	19531S	PARTICIPANT	\N	PRESENT	0
229490	220055	19387D	PARTICIPANT	\N	PRESENT	0
229491	220055	19723Y	PARTICIPANT	\N	PRESENT	0
229492	220055	19741B	PARTICIPANT	\N	PRESENT	0
229493	220055	95063L	PARTICIPANT	\N	PRESENT	0
229494	220055	08045X	PARTICIPANT	\N	PRESENT	0
229495	220055	01057W	PARTICIPANT	\N	PRESENT	0
229496	220055	14115H	PARTICIPANT	\N	PRESENT	0
229497	220055	11101A	PARTICIPANT	\N	PRESENT	0
229498	220055	19413M	PARTICIPANT	\N	PRESENT	0
229499	220055	14026U	PARTICIPANT	\N	PRESENT	0
229500	220055	14029X	PARTICIPANT	\N	PRESENT	0
229501	220055	07029T	PARTICIPANT	\N	PRESENT	0
229502	220055	14157T	PARTICIPANT	\N	PRESENT	0
229503	220055	98023Q	PARTICIPANT	\N	PRESENT	0
229504	220055	14237S	PARTICIPANT	\N	PRESENT	0
229505	220055	08031R	PARTICIPANT	\N	PRESENT	0
229506	220055	19515S	PARTICIPANT	\N	PRESENT	0
229507	220055	14093U	PARTICIPANT	\N	PRESENT	0
229508	220055	19549D	PARTICIPANT	\N	PRESENT	0
229509	220055	14051J	PARTICIPANT	\N	PRESENT	0
229510	220055	80013X	PARTICIPANT	\N	PRESENT	0
229600	220056	01043Q	PARTICIPANT	\N	PRESENT	0
229601	220056	19715Y	PARTICIPANT	\N	PRESENT	0
229602	220056	11031D	PARTICIPANT	\N	PRESENT	0
229603	220056	12041X	PARTICIPANT	\N	PRESENT	0
229604	220056	11063M	PARTICIPANT	\N	PRESENT	0
229607	220056	04085P	PARTICIPANT	\N	PRESENT	0
229609	220056	19565D	PARTICIPANT	\N	PRESENT	0
229610	220056	19593H	PARTICIPANT	\N	PRESENT	0
229611	220056	19695N	PARTICIPANT	\N	PRESENT	0
229612	220056	19347U	PARTICIPANT	\N	PRESENT	0
229613	220056	19549D	PARTICIPANT	\N	PRESENT	0
229614	220056	19725B	PARTICIPANT	\N	PRESENT	0
229615	220056	14107H	PARTICIPANT	\N	PRESENT	0
229616	220056	14121F	PARTICIPANT	\N	PRESENT	0
229617	220056	80013X	PARTICIPANT	\N	PRESENT	0
229618	220056	14051J	PARTICIPANT	\N	PRESENT	0
229619	220056	14021P	PARTICIPANT	\N	PRESENT	0
229620	220056	19387D	PARTICIPANT	\N	PRESENT	0
229621	220056	19349W	PARTICIPANT	\N	PRESENT	0
229622	220056	14063N	PARTICIPANT	\N	PRESENT	0
229623	220056	14093U	PARTICIPANT	\N	PRESENT	0
229624	220056	14073Q	PARTICIPANT	\N	PRESENT	0
229625	220056	14083S	PARTICIPANT	\N	PRESENT	0
229627	220056	08031R	PARTICIPANT	\N	PRESENT	0
229628	220056	19581D	PARTICIPANT	\N	PRESENT	0
229629	220056	19367Y	PARTICIPANT	\N	PRESENT	0
229630	220056	14087W	PARTICIPANT	\N	PRESENT	0
229631	220056	14237S	PARTICIPANT	\N	PRESENT	0
229632	220056	07029T	PARTICIPANT	\N	PRESENT	0
229633	220056	18083K	PARTICIPANT	\N	PRESENT	0
229634	220056	04088S	PARTICIPANT	\N	PRESENT	0
229635	220056	11101A	PARTICIPANT	\N	PRESENT	0
229636	220056	14029X	PARTICIPANT	\N	PRESENT	0
229637	220056	19723Y	PARTICIPANT	\N	PRESENT	0
229638	220056	19515S	PARTICIPANT	\N	PRESENT	0
229639	220056	01057W	PARTICIPANT	\N	PRESENT	0
229640	220056	19679N	PARTICIPANT	\N	PRESENT	0
229641	220056	14219Q	PARTICIPANT	\N	PRESENT	0
229642	220056	17583W	PARTICIPANT	\N	PRESENT	0
229643	220056	08049C	PARTICIPANT	\N	PRESENT	0
229644	220056	14030Q	PARTICIPANT	\N	PRESENT	0
229645	220056	14223L	PARTICIPANT	\N	PRESENT	0
229646	220056	19413M	PARTICIPANT	\N	PRESENT	0
229647	220056	19503N	PARTICIPANT	\N	PRESENT	0
229648	220056	98023Q	PARTICIPANT	\N	PRESENT	0
229649	220056	19727D	PARTICIPANT	\N	PRESENT	0
229650	220056	14179A	PARTICIPANT	\N	PRESENT	0
229651	220056	19629C	PARTICIPANT	\N	PRESENT	0
229662	220056	14205J	PARTICIPANT	\N	PRESENT	0
229653	220056	11104D	PARTICIPANT	\N	PRESENT	0
229654	220056	14211G	PARTICIPANT	\N	PRESENT	0
229655	220056	11012A	PARTICIPANT	\N	PRESENT	0
229656	220056	19333N	PARTICIPANT	\N	PRESENT	0
229657	220056	97011G	PARTICIPANT	\N	PRESENT	0
229658	220056	14103D	PARTICIPANT	\N	PRESENT	0
229659	220056	19533U	PARTICIPANT	\N	PRESENT	0
229660	220056	19531S	PARTICIPANT	\N	PRESENT	0
229661	220056	87003B	PARTICIPANT	\N	PRESENT	0
229686	220056	19553Y	PARTICIPANT	\N	PRESENT	0
229690	220056	10006L	PARTICIPANT	\N	PRESENT	0
229691	220056	14069U	PARTICIPANT	\N	PRESENT	0
229692	220056	08015R	PARTICIPANT	\N	PRESENT	0
229693	220056	19713W	PARTICIPANT	\N	PRESENT	0
229694	220056	19383Y	PARTICIPANT	\N	PRESENT	0
229703	220056	11056N	PARTICIPANT	\N	PRESENT	0
229696	220056	14249W	PARTICIPANT	\N	PRESENT	0
229697	220056	19441R	PARTICIPANT	\N	PRESENT	0
229698	220056	14031R	PARTICIPANT	\N	PRESENT	0
229699	220056	14033T	PARTICIPANT	\N	PRESENT	0
229700	220056	19467C	PARTICIPANT	\N	PRESENT	0
229701	220056	19483C	PARTICIPANT	\N	PRESENT	0
229702	220056	19711U	PARTICIPANT	\N	PRESENT	0
212148	212147	14042U	PARTICIPANT	\N	PRESENT	0
212149	212147	14227Q	PARTICIPANT	\N	PRESENT	0
212151	212150	19251M	PARTICIPANT	\N	PRESENT	0
212152	210153	14261S	PARTICIPANT	\N	EXCUSE	0
212153	210153	19545Y	PARTICIPANT	\N	EXCUSE	0
213356	213355	14081Q	PARTICIPANT	\N	PRESENT	0
213358	213357	14187A	PARTICIPANT	\N	PRESENT	0
213359	213357	19591F	PARTICIPANT	\N	PRESENT	0
213360	213357	08062Y	PARTICIPANT	\N	PRESENT	0
213361	213357	04089T	PARTICIPANT	\N	PRESENT	0
213362	213357	01043Q	PARTICIPANT	\N	PRESENT	0
213364	213363	14187A	PARTICIPANT	\N	PRESENT	0
213366	213365	04049K	PARTICIPANT	\N	PRESENT	0
213368	213367	08019V	PARTICIPANT	\N	PRESENT	0
216218	216217	14073Q	PARTICIPANT	\N	PRESENT	0
216219	216217	08017T	PARTICIPANT	\N	PRESENT	0
216220	216217	04018C	PARTICIPANT	\N	PRESENT	0
216224	216223	95015C	PARTICIPANT	\N	PRESENT	0
216230	216229	19699S	PARTICIPANT	\N	PRESENT	0
216233	216232	08012N	PARTICIPANT	\N	PRESENT	0
216234	216232	14073Q	PARTICIPANT	\N	PRESENT	0
216235	216232	11043H	PARTICIPANT	\N	PRESENT	0
216237	216236	08012N	PARTICIPANT	\N	PRESENT	0
216238	216236	14073Q	PARTICIPANT	\N	PRESENT	0
216239	216236	11043H	PARTICIPANT	\N	PRESENT	0
216241	216240	08012N	PARTICIPANT	\N	PRESENT	0
220365	220364	11053K	PARTICIPANT	\N	PRESENT	0
220367	220366	04071H	PARTICIPANT	\N	PRESENT	0
222005	219918	19531S	PARTICIPANT	\N	PRESENT	0
222006	219918	01048V	PARTICIPANT	\N	PRESENT	0
222007	219918	19667J	PARTICIPANT	\N	PRESENT	0
222008	219918	14253S	PARTICIPANT	\N	PRESENT	0
222009	219918	11070L	PARTICIPANT	\N	PRESENT	0
222010	219918	19681G	RAPPORTEUR_AVIS	\N	PRESENT	0
222011	219918	14173T	PARTICIPANT	\N	PRESENT	0
222012	219918	14331P	PARTICIPANT	\N	EXCUSE	0
222013	219918	11110B	PARTICIPANT	\N	EXCUSE	0
222014	218277	19715Y	PARTICIPANT	\N	PRESENT	0
222015	218277	11065P	PARTICIPANT	\N	PRESENT	0
222016	218277	80013X	PARTICIPANT	\N	PRESENT	0
222017	218277	19333N	PARTICIPANT	\N	PRESENT	0
222018	218277	19413M	PARTICIPANT	\N	PRESENT	0
222019	218277	19659J	PARTICIPANT	\N	PRESENT	0
222020	218277	19387D	PARTICIPANT	\N	PRESENT	0
222021	218277	19713W	PARTICIPANT	\N	PRESENT	0
222022	218277	14197C	PARTICIPANT	\N	PRESENT	0
222023	218277	19619A	PARTICIPANT	\N	PRESENT	0
222024	218277	19553Y	PARTICIPANT	\N	PRESENT	0
222025	218277	88008L	PARTICIPANT	\N	PRESENT	0
222026	218277	19629C	PARTICIPANT	\N	PRESENT	0
222027	218277	08049C	PARTICIPANT	\N	PRESENT	0
222028	218277	19737F	PARTICIPANT	\N	PRESENT	0
222029	218277	19739H	PARTICIPANT	\N	PRESENT	0
222030	218277	19577H	PARTICIPANT	\N	PRESENT	0
222031	218277	19421M	PARTICIPANT	\N	PRESENT	0
222032	218277	17583W	PARTICIPANT	\N	PRESENT	0
222033	218277	14357A	PARTICIPANT	\N	PRESENT	0
222034	218277	14069U	PARTICIPANT	\N	PRESENT	0
222035	218277	19733B	PARTICIPANT	\N	PRESENT	0
222036	218277	14223L	PARTICIPANT	\N	PRESENT	0
222037	218277	14071N	PARTICIPANT	\N	PRESENT	0
222038	218277	19695N	PARTICIPANT	\N	PRESENT	0
222039	218277	19347U	PARTICIPANT	\N	PRESENT	0
222040	218277	19651A	PARTICIPANT	\N	PRESENT	0
222041	218277	19349W	PARTICIPANT	\N	PRESENT	0
222042	218277	19503N	PARTICIPANT	\N	PRESENT	0
222043	218277	08024S	PARTICIPANT	\N	PRESENT	0
222044	218277	14093U	PARTICIPANT	\N	PRESENT	0
222045	218277	11012A	PARTICIPANT	\N	PRESENT	0
222046	218277	19383Y	PARTICIPANT	\N	PRESENT	0
222047	218277	14033T	PARTICIPANT	\N	PRESENT	0
222048	218277	19507S	PARTICIPANT	\N	PRESENT	0
222049	218277	14029X	PARTICIPANT	\N	PRESENT	0
222050	218277	14257W	PARTICIPANT	\N	PRESENT	0
222051	218277	19467C	PARTICIPANT	\N	PRESENT	0
222052	218277	04088S	PARTICIPANT	\N	PRESENT	0
222053	218277	14135M	PARTICIPANT	\N	PRESENT	0
222054	218277	98050T	PARTICIPANT	\N	PRESENT	0
222055	218277	14026U	PARTICIPANT	\N	PRESENT	0
222056	218277	19441R	PARTICIPANT	\N	PRESENT	0
222057	218277	19549D	PARTICIPANT	\N	PRESENT	0
222058	218277	14217N	PARTICIPANT	\N	PRESENT	0
222059	218277	01048V	PARTICIPANT	\N	PRESENT	0
222060	218277	14201E	PARTICIPANT	\N	PRESENT	0
222061	218277	11081P	PARTICIPANT	\N	PRESENT	0
222063	218277	19677L	PARTICIPANT	\N	PRESENT	0
222064	218277	14147R	PARTICIPANT	\N	PRESENT	0
222148	220241	80013X	PARTICIPANT	\N	PRESENT	0
222149	220241	19631V	PARTICIPANT	\N	PRESENT	0
222150	220241	11099A	PARTICIPANT	\N	PRESENT	0
222151	220241	11081P	PARTICIPANT	\N	PRESENT	0
222152	220241	19563B	PARTICIPANT	\N	PRESENT	0
222153	220241	14135M	PARTICIPANT	\N	PRESENT	0
222154	220241	08038Y	PARTICIPANT	\N	PRESENT	0
222155	220241	19695N	PARTICIPANT	\N	PRESENT	0
222156	220241	19269X	PARTICIPANT	\N	PRESENT	0
222157	220241	11056N	PARTICIPANT	\N	PRESENT	0
222158	220241	19507S	PARTICIPANT	\N	PRESENT	0
222159	220241	04043D	PARTICIPANT	\N	PRESENT	0
222160	220241	14257W	PARTICIPANT	\N	PRESENT	0
222161	220241	19619A	PARTICIPANT	\N	EXCUSE	0
222162	218278	19335Q	PARTICIPANT	\N	PRESENT	0
222163	218278	19591F	PARTICIPANT	\N	PRESENT	0
222164	218278	04085P	PARTICIPANT	\N	PRESENT	0
222165	218278	19695N	PARTICIPANT	\N	PRESENT	0
222166	218278	17583W	PARTICIPANT	\N	PRESENT	0
222167	218278	19701S	PARTICIPANT	\N	PRESENT	0
222168	218278	14083S	PARTICIPANT	\N	PRESENT	0
222169	218278	14147R	PARTICIPANT	\N	PRESENT	0
222170	218278	14061L	PARTICIPANT	\N	PRESENT	0
222171	218278	14217N	PARTICIPANT	\N	PRESENT	0
222172	218278	18083K	PARTICIPANT	\N	PRESENT	0
222173	218279	14034U	PARTICIPANT	\N	PRESENT	0
222174	218279	19695N	PARTICIPANT	\N	PRESENT	0
222175	218279	04085P	PARTICIPANT	\N	PRESENT	0
222176	218279	19565D	PARTICIPANT	\N	PRESENT	0
222177	218279	19701S	PARTICIPANT	\N	PRESENT	0
222178	218279	19253P	PARTICIPANT	\N	PRESENT	0
222179	218279	14281W	PARTICIPANT	\N	PRESENT	0
222180	218279	19483C	PARTICIPANT	\N	PRESENT	0
222181	218279	17583W	PARTICIPANT	\N	PRESENT	0
222182	218279	05008E	PARTICIPANT	\N	PRESENT	0
222183	218279	14001X	PARTICIPANT	\N	PRESENT	0
222184	218279	19489J	PARTICIPANT	\N	PRESENT	0
222185	218279	01028R	PARTICIPANT	\N	PRESENT	0
222186	218279	19447X	PARTICIPANT	\N	PRESENT	0
222187	218279	19349W	PARTICIPANT	\N	PRESENT	0
222188	218279	19543W	PARTICIPANT	\N	PRESENT	0
222189	218279	18083K	PARTICIPANT	\N	PRESENT	0
222200	218279	08034U	PARTICIPANT	\N	PRESENT	0
222191	218279	19715Y	PARTICIPANT	\N	PRESENT	0
222192	218279	14065Q	PARTICIPANT	\N	PRESENT	0
222193	218279	01058X	PARTICIPANT	\N	PRESENT	0
222194	218279	14211G	PARTICIPANT	\N	PRESENT	0
222195	218279	14111D	PARTICIPANT	\N	PRESENT	0
222196	218279	14089Y	PARTICIPANT	\N	PRESENT	0
222197	218279	14033T	PARTICIPANT	\N	PRESENT	0
222198	218279	11049P	PARTICIPANT	\N	PRESENT	0
222199	218279	14147R	PARTICIPANT	\N	PRESENT	0
222201	218279	19713W	PARTICIPANT	\N	PRESENT	0
222202	218279	95030B	PARTICIPANT	\N	PRESENT	0
222203	218279	11064N	PARTICIPANT	\N	PRESENT	0
222204	218279	14237S	PARTICIPANT	\N	PRESENT	0
222205	218279	14069U	PARTICIPANT	\N	PRESENT	0
222206	218279	14219Q	PARTICIPANT	\N	PRESENT	0
222207	220048	08016S	PARTICIPANT	\N	PRESENT	0
222208	220048	95062K	PARTICIPANT	\N	EXCUSE	0
222363	219964	01058X	PARTICIPANT	\N	PRESENT	0
222365	219964	19709B	PARTICIPANT	\N	PRESENT	0
222366	219964	19723Y	PARTICIPANT	\N	PRESENT	0
222369	219964	14093U	PARTICIPANT	\N	PRESENT	0
223686	223685	05008E	PARTICIPANT	\N	PRESENT	0
223692	218292	95063L	PARTICIPANT	\N	PRESENT	0
223693	218292	11110B	PARTICIPANT	\N	PRESENT	0
233297	232998	14281W	PARTICIPANT	\N	PRESENT	0
233299	232998	04086Q	PARTICIPANT	\N	PRESENT	0
233314	233313	14030Q	PARTICIPANT	\N	PRESENT	0
233315	233313	04035D	PARTICIPANT	\N	PRESENT	0
233316	233313	08017T	PARTICIPANT	\N	PRESENT	0
233317	233313	19657G	PARTICIPANT	\N	PRESENT	0
233319	233318	14030Q	PARTICIPANT	\N	PRESENT	0
233320	233318	08043V	PARTICIPANT	\N	PRESENT	0
233321	233318	19701S	PARTICIPANT	\N	PRESENT	0
233322	233318	04035D	PARTICIPANT	\N	PRESENT	0
233358	233357	01048V	PARTICIPANT	\N	PRESENT	0
233372	232998	19565D	PARTICIPANT	\N	PRESENT	0
233410	233010	19735D	PARTICIPANT	\N	PRESENT	0
233540	232997	04044E	PARTICIPANT	\N	PRESENT	0
233552	232998	08038Y	PARTICIPANT	\N	EXCUSE	0
233905	233010	04045F	PARTICIPANT	\N	PRESENT	0
234019	234017	14255U	PARTICIPANT	\N	PRESENT	0
234417	234416	08049C	PARTICIPANT	\N	PRESENT	0
234418	234416	14028W	PARTICIPANT	\N	PRESENT	0
234419	234416	08045X	PARTICIPANT	\N	PRESENT	0
234420	234416	14265W	PARTICIPANT	\N	PRESENT	0
234422	234421	14249W	PARTICIPANT	\N	PRESENT	0
234423	234421	98029W	PARTICIPANT	\N	PRESENT	0
234424	234421	19569H	PARTICIPANT	\N	PRESENT	0
234425	234421	19637C	PARTICIPANT	\N	PRESENT	0
234426	234421	08053X	PARTICIPANT	\N	PRESENT	0
234439	232997	11101A	PARTICIPANT	\N	EXCUSE	0
234440	232998	11101A	PARTICIPANT	\N	EXCUSE	0
234466	233048	98005N	PARTICIPANT	\N	PRESENT	0
234467	233048	19443T	PARTICIPANT	\N	PRESENT	0
234468	233048	11080N	PARTICIPANT	\N	PRESENT	0
234469	233048	95030B	PARTICIPANT	\N	PRESENT	0
234470	233048	04034C	PARTICIPANT	\N	PRESENT	0
234471	233048	14079W	PARTICIPANT	\N	PRESENT	0
234472	233048	01058X	PARTICIPANT	\N	PRESENT	0
234473	233048	04040A	PARTICIPANT	\N	PRESENT	0
234474	233048	16685X	PARTICIPANT	\N	PRESENT	0
234475	233048	04042C	PRESIDENT	0	PRESENT	0
234476	233048	19669L	PARTICIPANT	\N	PRESENT	0
234477	233048	11066Q	PARTICIPANT	\N	PRESENT	0
234478	233048	08056B	PARTICIPANT	\N	PRESENT	0
234479	233048	95037J	PARTICIPANT	\N	PRESENT	0
234480	233048	19421M	PARTICIPANT	\N	PRESENT	0
234481	233048	19709B	PARTICIPANT	\N	PRESENT	0
234482	233048	97011G	PARTICIPANT	\N	PRESENT	0
234483	233048	08061X	PARTICIPANT	\N	PRESENT	0
234484	233048	08047A	PARTICIPANT	\N	PRESENT	0
234485	233048	98029W	PARTICIPANT	\N	PRESENT	0
234486	233048	04035D	PARTICIPANT	\N	PRESENT	0
234487	233048	95067Q	PARTICIPANT	\N	PRESENT	0
234488	233048	11041F	PARTICIPANT	\N	PRESENT	0
234489	233048	14235Q	PARTICIPANT	\N	PRESENT	0
234490	233048	08058D	PARTICIPANT	\N	PRESENT	0
234491	233048	14028W	PARTICIPANT	\N	PRESENT	0
234492	233048	19251M	PARTICIPANT	\N	PRESENT	0
234493	233048	19319Q	PARTICIPANT	\N	PRESENT	0
234494	233048	14105F	PARTICIPANT	\N	PRESENT	0
234495	233048	98018T	PARTICIPANT	\N	PRESENT	0
234496	233048	98022P	PARTICIPANT	\N	PRESENT	0
234497	233048	14267Y	PARTICIPANT	\N	PRESENT	0
234498	233048	98050T	PARTICIPANT	\N	PRESENT	0
234499	233048	14211G	PARTICIPANT	\N	PRESENT	0
234500	233048	19583F	PARTICIPANT	\N	PRESENT	0
234501	233048	14255U	PARTICIPANT	\N	PRESENT	0
234502	233048	01062T	PARTICIPANT	\N	PRESENT	0
234503	233048	08053X	PARTICIPANT	\N	PRESENT	0
234504	233048	14055N	PARTICIPANT	\N	PRESENT	0
234505	233048	11064N	PARTICIPANT	\N	PRESENT	0
234506	233048	19721W	PARTICIPANT	\N	PRESENT	0
234507	233329	04070G	PARTICIPANT	\N	PRESENT	0
234508	233329	19699S	PARTICIPANT	\N	PRESENT	0
234509	233329	12041X	PARTICIPANT	\N	PRESENT	0
234510	233329	19565D	PARTICIPANT	\N	PRESENT	0
234511	233329	19533U	PARTICIPANT	\N	PRESENT	0
234512	233329	95015C	PARTICIPANT	\N	PRESENT	0
234513	233329	14357A	PARTICIPANT	\N	PRESENT	0
234514	233329	14229S	PARTICIPANT	\N	PRESENT	0
234515	233329	19447X	PARTICIPANT	\N	PRESENT	0
234516	233329	14241N	PARTICIPANT	\N	PRESENT	0
234517	233329	19573D	PARTICIPANT	\N	PRESENT	0
234518	233329	14039A	PARTICIPANT	\N	PRESENT	0
234519	233329	14107H	PARTICIPANT	\N	PRESENT	0
234520	233329	07033P	PARTICIPANT	\N	PRESENT	0
234521	233329	08012N	PARTICIPANT	\N	PRESENT	0
234522	233329	14249W	PARTICIPANT	\N	PRESENT	0
234523	233329	08039A	PARTICIPANT	\N	PRESENT	0
234524	233329	08031R	PARTICIPANT	\N	PRESENT	0
234525	233329	14059S	PARTICIPANT	\N	PRESENT	0
234526	233329	19643A	PARTICIPANT	\N	PRESENT	0
234527	233329	14061L	PARTICIPANT	\N	PRESENT	0
234528	233329	04057K	PARTICIPANT	\N	PRESENT	0
234529	233329	14073Q	PARTICIPANT	\N	PRESENT	0
234530	233329	19611R	PARTICIPANT	\N	PRESENT	0
234531	233329	08035V	PARTICIPANT	\N	PRESENT	0
234532	233329	19695N	PARTICIPANT	\N	PRESENT	0
234533	233329	08043V	PARTICIPANT	\N	PRESENT	0
234534	233329	19693L	PARTICIPANT	\N	PRESENT	0
234535	233329	87003B	PARTICIPANT	\N	PRESENT	0
234536	233329	19399H	PARTICIPANT	\N	PRESENT	0
234537	233329	14030Q	PARTICIPANT	\N	PRESENT	0
234538	233329	19731Y	PARTICIPANT	\N	PRESENT	0
234539	233329	08020N	PARTICIPANT	\N	PRESENT	0
234540	233329	19735D	PARTICIPANT	\N	PRESENT	0
234541	233329	11109J	PARTICIPANT	\N	PRESENT	0
234542	233329	11083R	PARTICIPANT	\N	PRESENT	0
234543	233329	14109K	PARTICIPANT	\N	PRESENT	0
234544	233329	14123H	PARTICIPANT	\N	PRESENT	0
234545	233329	11104D	PARTICIPANT	\N	PRESENT	0
234546	233329	11043H	PARTICIPANT	\N	PRESENT	0
234547	233329	04018C	PARTICIPANT	\N	PRESENT	0
234548	233329	19619A	PARTICIPANT	\N	PRESENT	0
234549	233329	19621T	PARTICIPANT	\N	PRESENT	0
234550	233329	08019V	PARTICIPANT	\N	PRESENT	0
234551	233329	19749K	PARTICIPANT	\N	EXCUSE	0
234552	233048	11027H	PARTICIPANT	\N	PRESENT	0
234553	233048	14097Y	PARTICIPANT	\N	PRESENT	0
234554	233048	14133K	PARTICIPANT	\N	PRESENT	0
234555	233048	11115U	PARTICIPANT	\N	PRESENT	0
234556	233049	98005N	PARTICIPANT	\N	PRESENT	0
234557	233049	19443T	PARTICIPANT	\N	PRESENT	0
234558	233049	11080N	PARTICIPANT	\N	PRESENT	0
234559	233049	95030B	PARTICIPANT	\N	PRESENT	0
234560	233049	04034C	PARTICIPANT	\N	PRESENT	0
234561	233049	14079W	PARTICIPANT	\N	PRESENT	0
234562	233049	01058X	PARTICIPANT	\N	PRESENT	0
234563	233049	04040A	PARTICIPANT	\N	PRESENT	0
234564	233049	16685X	PARTICIPANT	\N	PRESENT	0
234565	233049	11027H	PARTICIPANT	\N	PRESENT	0
234566	233049	04042C	PRESIDENT	0	PRESENT	0
234567	233049	19669L	PARTICIPANT	\N	PRESENT	0
234568	233049	11066Q	PARTICIPANT	\N	PRESENT	0
234569	233049	08056B	PARTICIPANT	\N	PRESENT	0
234570	233049	95037J	PARTICIPANT	\N	PRESENT	0
234571	233049	11115U	PARTICIPANT	\N	PRESENT	0
234572	233049	14055N	PARTICIPANT	\N	PRESENT	0
234573	233049	19421M	PARTICIPANT	\N	PRESENT	0
234574	233049	19709B	PARTICIPANT	\N	PRESENT	0
234575	233049	08053X	PARTICIPANT	\N	PRESENT	0
234576	233049	97011G	PARTICIPANT	\N	PRESENT	0
234577	233049	08061X	PARTICIPANT	\N	PRESENT	0
234578	233049	08047A	PARTICIPANT	\N	PRESENT	0
234579	233049	98029W	PARTICIPANT	\N	PRESENT	0
234580	233049	14097Y	PARTICIPANT	\N	PRESENT	0
234581	233049	04035D	PARTICIPANT	\N	PRESENT	0
234582	233049	95067Q	PARTICIPANT	\N	PRESENT	0
234583	233049	01062T	PARTICIPANT	\N	PRESENT	0
234584	233049	14133K	PARTICIPANT	\N	PRESENT	0
234585	233049	11041F	PARTICIPANT	\N	PRESENT	0
234586	233049	14235Q	PARTICIPANT	\N	PRESENT	0
234587	233049	08058D	PARTICIPANT	\N	PRESENT	0
234588	233049	14028W	PARTICIPANT	\N	PRESENT	0
234589	233049	19251M	PARTICIPANT	\N	PRESENT	0
234590	233049	19721W	PARTICIPANT	\N	PRESENT	0
234591	233049	19319Q	PARTICIPANT	\N	PRESENT	0
234592	233049	14105F	PARTICIPANT	\N	PRESENT	0
234593	233049	98018T	PARTICIPANT	\N	PRESENT	0
234594	233049	98022P	PARTICIPANT	\N	PRESENT	0
213248	213247	98050T	PARTICIPANT	\N	PRESENT	0
213257	213252	04040A	PARTICIPANT	\N	PRESENT	0
213258	213252	14235Q	PARTICIPANT	\N	PRESENT	0
213260	213259	04035D	PARTICIPANT	\N	PRESENT	0
213261	213259	08049C	PARTICIPANT	\N	PRESENT	0
213263	213262	04035D	PARTICIPANT	\N	PRESENT	0
214576	207695	89017R	PARTICIPANT	\N	PRESENT	0
214948	214583	19531S	PARTICIPANT	\N	PRESENT	0
214949	214583	19687N	PARTICIPANT	\N	PRESENT	0
214950	214583	01057W	PARTICIPANT	\N	PRESENT	0
214951	214583	19667J	PARTICIPANT	\N	PRESENT	0
214952	214583	08014Q	PARTICIPANT	\N	PRESENT	0
214953	214583	14034U	PARTICIPANT	\N	PRESENT	0
214954	214583	11070L	PARTICIPANT	\N	PRESENT	0
214955	214583	14225N	PARTICIPANT	\N	PRESENT	0
214956	214583	11040E	PARTICIPANT	\N	PRESENT	0
214957	214583	04086Q	PARTICIPANT	\N	PRESENT	0
214958	214583	14199E	PARTICIPANT	\N	PRESENT	0
214959	214583	99004R	PARTICIPANT	\N	PRESENT	0
214960	214583	04061F	PARTICIPANT	\N	PRESENT	0
214961	214583	07004J	PARTICIPANT	\N	EXCUSE	0
214962	207699	14173T	PARTICIPANT	\N	PRESENT	0
214963	207699	19671E	PARTICIPANT	\N	PRESENT	0
214964	207699	11085T	PARTICIPANT	\N	PRESENT	0
214965	207699	19725B	PARTICIPANT	\N	PRESENT	0
214966	214492	98050T	PARTICIPANT	\N	PRESENT	0
214971	207699	19719D	PARTICIPANT	\N	PRESENT	0
214972	207699	11101A	PARTICIPANT	\N	PRESENT	0
214973	207699	14199E	PARTICIPANT	\N	PRESENT	0
214977	207699	19643A	PARTICIPANT	\N	PRESENT	0
214979	214584	14001X	PARTICIPANT	\N	PRESENT	0
214980	214584	11074Q	PRESIDENT	0	PRESENT	0
214981	214584	19671E	PARTICIPANT	\N	PRESENT	0
214982	214584	14225N	PARTICIPANT	\N	PRESENT	0
214984	214584	96004D	PARTICIPANT	\N	PRESENT	0
214985	214584	19349W	PARTICIPANT	\N	PRESENT	0
214986	214584	19563B	PARTICIPANT	\N	PRESENT	0
214987	214584	14135M	PARTICIPANT	\N	PRESENT	0
214988	214584	19479G	PARTICIPANT	\N	PRESENT	0
214989	214584	14061L	PARTICIPANT	\N	PRESENT	0
214990	214584	19711U	PARTICIPANT	\N	PRESENT	0
214991	214584	14065Q	PARTICIPANT	\N	PRESENT	0
214992	214584	19531S	PARTICIPANT	\N	PRESENT	0
214993	214584	19651A	PARTICIPANT	\N	PRESENT	0
214994	214584	11026G	PARTICIPANT	\N	PRESENT	0
214995	214584	19689Q	PARTICIPANT	\N	PRESENT	0
214996	214584	12016W	PARTICIPANT	\N	PRESENT	0
214997	214584	08011M	PARTICIPANT	\N	PRESENT	0
214998	214584	14173T	PARTICIPANT	\N	PRESENT	0
214999	214584	04086Q	PARTICIPANT	\N	PRESENT	0
215000	214584	14089Y	PARTICIPANT	\N	PRESENT	0
215001	214584	19725B	PARTICIPANT	\N	PRESENT	0
215002	214584	14083S	PARTICIPANT	\N	PRESENT	0
215003	214584	11083R	PARTICIPANT	\N	PRESENT	0
215004	214584	04097T	PARTICIPANT	\N	PRESENT	0
215005	214584	14121F	PARTICIPANT	\N	PRESENT	0
215006	214584	04061F	PARTICIPANT	\N	PRESENT	0
215007	207699	11053K	PARTICIPANT	\N	PRESENT	0
215008	207699	19569H	PARTICIPANT	\N	PRESENT	0
215013	207699	14026U	PARTICIPANT	\N	PRESENT	0
215014	207699	14109K	PARTICIPANT	\N	PRESENT	0
215015	207699	01043Q	PARTICIPANT	\N	PRESENT	0
215016	207699	14111D	PARTICIPANT	\N	PRESENT	0
215017	207699	14089Y	PARTICIPANT	\N	PRESENT	0
215018	207699	19709B	PARTICIPANT	\N	PRESENT	0
215021	207699	14193X	PARTICIPANT	\N	PRESENT	0
215022	207699	19693L	PARTICIPANT	\N	PRESENT	0
215023	207699	14229S	PARTICIPANT	\N	PRESENT	0
215024	207699	17583W	PARTICIPANT	\N	PRESENT	0
215025	207699	14028W	PARTICIPANT	\N	PRESENT	0
215026	207699	19563B	PARTICIPANT	\N	PRESENT	0
215027	207699	11027H	PARTICIPANT	\N	PRESENT	0
215028	207699	14251Q	PARTICIPANT	\N	PRESENT	0
215029	207699	08016S	PARTICIPANT	\N	PRESENT	0
215030	207699	19543W	PARTICIPANT	\N	PRESENT	0
215119	207700	19383Y	PARTICIPANT	\N	PRESENT	0
215120	207700	11090Q	PARTICIPANT	\N	PRESENT	0
215121	207700	19631V	PARTICIPANT	\N	PRESENT	0
215122	207700	80013X	PARTICIPANT	\N	PRESENT	0
215123	207700	08055A	PARTICIPANT	\N	PRESENT	0
215124	207700	14051J	PARTICIPANT	\N	PRESENT	0
215125	207700	19503N	PARTICIPANT	\N	PRESENT	0
215126	207700	08024S	PARTICIPANT	\N	PRESENT	0
215127	207700	19525U	PARTICIPANT	\N	PRESENT	0
215128	207700	19549D	PARTICIPANT	\N	PRESENT	0
215129	207700	14039A	PARTICIPANT	\N	PRESENT	0
215130	207700	19349W	PARTICIPANT	\N	PRESENT	0
215131	207700	19269X	PARTICIPANT	\N	PRESENT	0
215132	207700	11065P	PARTICIPANT	\N	PRESENT	0
215133	207700	11099A	PARTICIPANT	\N	PRESENT	0
215134	207700	01025N	PARTICIPANT	\N	PRESENT	0
215135	207700	14215L	PARTICIPANT	\N	PRESENT	0
215136	207700	19701S	PARTICIPANT	\N	PRESENT	0
215137	207700	19483C	PARTICIPANT	\N	PRESENT	0
215138	207700	14357A	PARTICIPANT	\N	PRESENT	0
215139	207700	14329V	PARTICIPANT	\N	PRESENT	0
215140	207700	95030B	PARTICIPANT	\N	PRESENT	0
215141	207700	14223L	PARTICIPANT	\N	PRESENT	0
215142	207700	14115H	PARTICIPANT	\N	PRESENT	0
215143	207700	14029X	PARTICIPANT	\N	PRESENT	0
215144	207700	19467C	PARTICIPANT	\N	PRESENT	0
215145	207700	19703U	PARTICIPANT	\N	PRESENT	0
215146	207700	19543W	PARTICIPANT	\N	PRESENT	0
215147	207700	08068F	PARTICIPANT	\N	PRESENT	0
215148	207700	19347U	PARTICIPANT	\N	PRESENT	0
215149	207700	19621T	PARTICIPANT	\N	PRESENT	0
215150	207700	08020N	PARTICIPANT	\N	PRESENT	0
215151	207700	19695N	PARTICIPANT	\N	PRESENT	0
215152	207700	19443T	PARTICIPANT	\N	PRESENT	0
215153	207700	14259Y	PARTICIPANT	\N	PRESENT	0
215154	207700	08038Y	PARTICIPANT	\N	PRESENT	0
215155	207700	19733B	PARTICIPANT	\N	PRESENT	0
215156	207700	19447X	PARTICIPANT	\N	PRESENT	0
215157	207700	18083K	PARTICIPANT	\N	PRESENT	0
215158	207700	19565D	PARTICIPANT	\N	PRESENT	0
215159	207700	11056N	PARTICIPANT	\N	PRESENT	0
215160	207700	19507S	PARTICIPANT	\N	PRESENT	0
215161	207700	14237S	PARTICIPANT	\N	PRESENT	0
215162	207700	11048N	PARTICIPANT	\N	PRESENT	0
215163	207700	14038Y	PARTICIPANT	\N	PRESENT	0
215164	207700	14147R	PARTICIPANT	\N	PRESENT	0
215165	207700	08009T	PARTICIPANT	\N	PRESENT	0
215166	207700	19551W	PARTICIPANT	\N	PRESENT	0
215167	207700	11049P	PARTICIPANT	\N	PRESENT	0
215168	207700	14053L	PARTICIPANT	\N	PRESENT	0
215169	207700	14123H	PARTICIPANT	\N	PRESENT	0
215170	207700	14061L	PARTICIPANT	\N	PRESENT	0
215171	207700	14265W	PARTICIPANT	\N	PRESENT	0
215172	207700	14257W	PARTICIPANT	\N	PRESENT	0
215173	207700	14187A	PARTICIPANT	\N	PRESENT	0
215174	207700	14071N	PARTICIPANT	\N	PRESENT	0
215175	207700	07029T	PARTICIPANT	\N	PRESENT	0
215176	207700	11097X	PARTICIPANT	\N	PRESENT	0
215177	207700	14069U	PARTICIPANT	\N	PRESENT	0
215178	207700	14119M	PARTICIPANT	\N	PRESENT	0
215179	207700	14033T	PARTICIPANT	\N	PRESENT	0
215180	207700	14026U	PARTICIPANT	\N	PRESENT	0
215181	207700	14213J	PARTICIPANT	\N	PRESENT	0
215182	207700	08015R	PARTICIPANT	\N	PRESENT	0
215183	207700	04033B	PARTICIPANT	\N	PRESENT	0
215184	207700	08049C	PARTICIPANT	\N	PRESENT	0
215185	207700	14093U	PARTICIPANT	\N	PRESENT	0
215186	207700	19713W	PARTICIPANT	\N	PRESENT	0
215187	207700	19441R	PARTICIPANT	\N	PRESENT	0
215188	207700	08010L	PARTICIPANT	\N	PRESENT	0
215189	207700	14083S	PARTICIPANT	\N	PRESENT	0
215505	214624	14205J	PARTICIPANT	\N	PRESENT	0
215506	214624	17589D	PARTICIPANT	\N	PRESENT	0
215510	215509	14001X	PARTICIPANT	\N	PRESENT	0
215511	215509	14281W	PARTICIPANT	\N	PRESENT	0
215516	214524	14001X	PARTICIPANT	\N	PRESENT	0
215517	214524	19581D	PARTICIPANT	\N	PRESENT	0
215518	214524	04044E	PARTICIPANT	\N	PRESENT	0
215519	214524	19585H	PARTICIPANT	\N	PRESENT	0
215520	214524	04047H	PARTICIPANT	\N	PRESENT	0
215521	214524	19673G	PARTICIPANT	\N	PRESENT	0
215522	214524	01028R	PARTICIPANT	\N	PRESENT	0
215523	214524	19447X	PARTICIPANT	\N	PRESENT	0
215524	214524	05008E	PRESIDENT	0	PRESENT	0
215525	214524	14231L	PARTICIPANT	\N	PRESENT	0
215526	214524	19489J	PARTICIPANT	\N	PRESENT	0
215117	207700	14034U	PARTICIPANT	\N	PRESENT	0
215118	207700	04049K	PARTICIPANT	\N	PRESENT	0
215527	214524	14147R	PARTICIPANT	\N	PRESENT	0
215528	214524	14151M	PARTICIPANT	\N	PRESENT	0
215529	214524	14215L	PARTICIPANT	\N	PRESENT	0
215530	214524	19483C	PARTICIPANT	\N	PRESENT	0
215531	214524	14259Y	PARTICIPANT	\N	PRESENT	0
229777	220058	19697Q	PARTICIPANT	\N	PRESENT	0
229778	220058	19637C	PARTICIPANT	\N	PRESENT	0
229779	220058	08052W	PARTICIPANT	\N	PRESENT	0
229780	220058	19525U	PARTICIPANT	\N	PRESENT	0
229781	220058	11045K	PARTICIPANT	\N	PRESENT	0
229782	220058	19649G	PARTICIPANT	\N	PRESENT	0
229783	220058	19713W	PARTICIPANT	\N	PRESENT	0
229784	220058	19737F	PARTICIPANT	\N	PRESENT	0
229785	220058	14267Y	PARTICIPANT	\N	PRESENT	0
229786	220058	01024M	PARTICIPANT	\N	PRESENT	0
229787	220058	08056B	PARTICIPANT	\N	PRESENT	0
229788	220058	08015R	PARTICIPANT	\N	PRESENT	0
229789	220058	19467C	PARTICIPANT	\N	PRESENT	0
229790	220058	99004R	PARTICIPANT	\N	PRESENT	0
229791	220058	19447X	PARTICIPANT	\N	PRESENT	0
229792	220058	19383Y	PARTICIPANT	\N	PRESENT	0
229793	220058	98029W	PARTICIPANT	\N	PRESENT	0
229794	220058	19367Y	PARTICIPANT	\N	PRESENT	0
229795	220058	19671E	PARTICIPANT	\N	PRESENT	0
229796	220058	19729F	PARTICIPANT	\N	PRESENT	0
229797	220058	19533U	PARTICIPANT	\N	PRESENT	0
229798	220058	11033F	PARTICIPANT	\N	PRESENT	0
229799	220058	01057W	PARTICIPANT	\N	PRESENT	0
229800	220058	19483C	PARTICIPANT	\N	PRESENT	0
229801	220058	14051J	PARTICIPANT	\N	PRESENT	0
229802	220058	11072N	PARTICIPANT	\N	PRESENT	0
229803	220058	95063L	PARTICIPANT	\N	PRESENT	0
229804	220058	04044E	PARTICIPANT	\N	PRESENT	0
229805	220058	08020N	PARTICIPANT	\N	PRESENT	0
229806	220058	19739H	PARTICIPANT	\N	PRESENT	0
229807	220058	19503N	PARTICIPANT	\N	PRESENT	0
229808	220058	04045F	PARTICIPANT	\N	PRESENT	0
229809	220058	14249W	PARTICIPANT	\N	PRESENT	0
229810	220058	08061X	PARTICIPANT	\N	PRESENT	0
229811	220058	11083R	PARTICIPANT	\N	PRESENT	0
229812	220058	14083S	PARTICIPANT	\N	PRESENT	0
229813	220058	19723Y	PARTICIPANT	\N	PRESENT	0
229814	220058	19347U	PARTICIPANT	\N	PRESENT	0
229815	220058	98023Q	PARTICIPANT	\N	PRESENT	0
229816	220058	04097T	PARTICIPANT	\N	PRESENT	0
229817	220058	19715Y	PARTICIPANT	\N	PRESENT	0
229818	220058	14103D	PARTICIPANT	\N	PRESENT	0
229750	220058	04086Q	PARTICIPANT	\N	PRESENT	0
229752	229388	14061L	PARTICIPANT	\N	PRESENT	0
229753	229388	95041E	PARTICIPANT	\N	PRESENT	0
229754	229388	14065Q	PARTICIPANT	\N	PRESENT	0
229755	229388	14073Q	PARTICIPANT	\N	PRESENT	0
229756	229388	14079W	PARTICIPANT	\N	PRESENT	0
229757	229388	14219Q	PARTICIPANT	\N	PRESENT	0
229758	229388	19695N	PARTICIPANT	\N	PRESENT	0
229759	229388	11090Q	PARTICIPANT	\N	PRESENT	0
229760	229388	19585H	PARTICIPANT	\N	PRESENT	0
229761	229388	19631V	PARTICIPANT	\N	PRESENT	0
229762	229388	14237S	PARTICIPANT	\N	PRESENT	0
229763	229388	08068F	PARTICIPANT	\N	PRESENT	0
229764	229388	08015R	PARTICIPANT	\N	PRESENT	0
229765	229388	19369B	PARTICIPANT	\N	PRESENT	0
229766	229388	14207L	PARTICIPANT	\N	PRESENT	0
229767	229388	19681G	PARTICIPANT	\N	PRESENT	0
229768	229388	08028W	PRESIDENT	0	PRESENT	0
229769	229388	19563B	PARTICIPANT	\N	PRESENT	0
229770	229388	14257W	PARTICIPANT	\N	PRESENT	0
229771	229388	14133K	PARTICIPANT	\N	EXCUSE	0
229772	229388	14193X	PARTICIPANT	\N	EXCUSE	0
229773	229388	19737F	PARTICIPANT	\N	EXCUSE	0
229774	229388	14028W	PARTICIPANT	\N	EXCUSE	0
229775	229388	11043H	PARTICIPANT	\N	EXCUSE	0
229776	229388	04061F	PARTICIPANT	\N	EXCUSE	0
229819	220058	19369B	PARTICIPANT	\N	PRESENT	0
229820	220058	19333N	PARTICIPANT	\N	PRESENT	0
229821	220058	19549D	PARTICIPANT	\N	PRESENT	0
229822	220058	11064N	PARTICIPANT	\N	PRESENT	0
229823	220058	18083K	PARTICIPANT	\N	PRESENT	0
229824	220058	17637T	PARTICIPANT	\N	PRESENT	0
229825	220058	14033T	PARTICIPANT	\N	PRESENT	0
229826	220058	19479G	PARTICIPANT	\N	PRESENT	0
229879	220057	19549D	PARTICIPANT	\N	PRESENT	0
229880	220057	14051J	PARTICIPANT	\N	PRESENT	0
229881	220057	98029W	PARTICIPANT	\N	PRESENT	0
229882	220057	08061X	PARTICIPANT	\N	PRESENT	0
229883	220057	19333N	PARTICIPANT	\N	PRESENT	0
229884	220057	11065P	PARTICIPANT	\N	PRESENT	0
229885	220057	19713W	PARTICIPANT	\N	PRESENT	0
229886	220057	19479G	PARTICIPANT	\N	PRESENT	0
229887	220057	14267Y	PARTICIPANT	\N	PRESENT	0
229888	220057	19369B	PARTICIPANT	\N	PRESENT	0
229889	220057	19737F	PARTICIPANT	\N	PRESENT	0
229890	220057	04097T	PARTICIPANT	\N	PRESENT	0
229891	220057	14033T	PARTICIPANT	\N	PRESENT	0
229892	220057	18083K	PARTICIPANT	\N	PRESENT	0
229893	220057	98023Q	PARTICIPANT	\N	PRESENT	0
229894	220057	19483C	PARTICIPANT	\N	PRESENT	0
229895	220057	04061F	PARTICIPANT	\N	PRESENT	0
229896	220057	19533U	PARTICIPANT	\N	PRESENT	0
229897	220057	14249W	PARTICIPANT	\N	PRESENT	0
229898	220057	19671E	PARTICIPANT	\N	PRESENT	0
229899	220057	19637C	PARTICIPANT	\N	PRESENT	0
229900	220057	19347U	PARTICIPANT	\N	PRESENT	0
229901	220057	19695N	PARTICIPANT	\N	PRESENT	0
229902	220057	08020N	PARTICIPANT	\N	PRESENT	0
229903	220057	17637T	PARTICIPANT	\N	PRESENT	0
229904	220057	01024M	PARTICIPANT	\N	PRESENT	0
229905	220057	11083R	PARTICIPANT	\N	PRESENT	0
229906	220057	11099A	PARTICIPANT	\N	PRESENT	0
229907	220057	14031R	PARTICIPANT	\N	PRESENT	0
229908	220057	14073Q	PARTICIPANT	\N	PRESENT	0
229909	220057	14221J	PARTICIPANT	\N	PRESENT	0
229910	220057	14275Y	PARTICIPANT	\N	PRESENT	0
229911	220057	11064N	PARTICIPANT	\N	PRESENT	0
229912	220057	08010L	PARTICIPANT	\N	PRESENT	0
229913	220057	14265W	PARTICIPANT	\N	PRESENT	0
229914	220057	14219Q	PARTICIPANT	\N	PRESENT	0
229915	220057	14083S	PARTICIPANT	\N	PRESENT	0
229916	220057	19681G	PARTICIPANT	\N	PRESENT	0
229917	220057	19563B	PARTICIPANT	\N	PRESENT	0
229918	220057	19387D	PARTICIPANT	\N	PRESENT	0
229919	220057	14241N	PARTICIPANT	\N	PRESENT	0
229920	220057	19629C	PARTICIPANT	\N	PRESENT	0
229921	220057	19553Y	PARTICIPANT	\N	PRESENT	0
229922	220057	14034U	PARTICIPANT	\N	PRESENT	0
229923	220057	88008L	PARTICIPANT	\N	PRESENT	0
229924	220057	11012A	PARTICIPANT	\N	PRESENT	0
229930	229927	14357A	PARTICIPANT	\N	PRESENT	0
229928	229927	14065Q	PARTICIPANT	\N	EXCUSE	0
229929	229927	96004D	PARTICIPANT	\N	EXCUSE	0
229931	229927	14079W	PARTICIPANT	\N	PRESENT	0
229877	220057	04086Q	PARTICIPANT	\N	PRESENT	0
229878	220057	19503N	PARTICIPANT	\N	PRESENT	0
229932	229927	08018U	PARTICIPANT	\N	EXCUSE	0
229933	229927	11083R	PARTICIPANT	\N	EXCUSE	0
229934	229927	14133K	PARTICIPANT	\N	EXCUSE	0
229935	229927	19725B	PARTICIPANT	\N	PRESENT	0
229936	229927	95037J	PARTICIPANT	\N	PRESENT	0
229937	229927	04097T	PARTICIPANT	\N	PRESENT	0
229938	229927	04061F	PARTICIPANT	\N	PRESENT	0
229939	220059	04085P	PARTICIPANT	\N	PRESENT	0
229940	229927	14061L	PARTICIPANT	\N	PRESENT	0
229941	229927	14073Q	PARTICIPANT	\N	PRESENT	0
229942	220059	19593H	PARTICIPANT	\N	PRESENT	0
229943	229927	14097Y	PARTICIPANT	\N	EXCUSE	0
229944	220059	07034Q	PARTICIPANT	\N	PRESENT	0
229945	229927	11026G	PARTICIPANT	\N	PRESENT	0
229946	220059	05008E	PARTICIPANT	\N	PRESENT	0
229947	229927	08039A	PARTICIPANT	\N	PRESENT	0
229948	229927	14221J	PARTICIPANT	\N	PRESENT	0
229949	220059	11026G	PARTICIPANT	\N	PRESENT	0
229950	229927	04057K	PARTICIPANT	\N	EXCUSE	0
229951	229927	19563B	PARTICIPANT	\N	PRESENT	0
229952	220059	19525U	PARTICIPANT	\N	PRESENT	0
229953	229927	19593H	PARTICIPANT	\N	PRESENT	0
229954	229927	14237S	PARTICIPANT	\N	PRESENT	0
229955	229927	14135M	PARTICIPANT	\N	PRESENT	0
229956	220059	19585H	PARTICIPANT	\N	PRESENT	0
229957	229927	10015M	PRESIDENT	0	PRESENT	0
229958	229927	98035U	PARTICIPANT	\N	PRESENT	0
229959	220059	19717B	PARTICIPANT	\N	PRESENT	0
229960	220059	19699S	PARTICIPANT	\N	PRESENT	0
229961	229927	14331P	PARTICIPANT	\N	EXCUSE	0
229962	220059	19629C	PARTICIPANT	\N	PRESENT	0
229963	220059	19611R	PARTICIPANT	\N	PRESENT	0
229964	220059	19737F	PARTICIPANT	\N	PRESENT	0
229965	220059	19569H	PARTICIPANT	\N	PRESENT	0
229966	220059	14073Q	PARTICIPANT	\N	PRESENT	0
229967	220059	11085T	PARTICIPANT	\N	PRESENT	0
229968	220059	11104D	PARTICIPANT	\N	PRESENT	0
229969	220059	14221J	PARTICIPANT	\N	PRESENT	0
229970	220059	14087W	PARTICIPANT	\N	PRESENT	0
229971	220059	19383Y	PARTICIPANT	\N	PRESENT	0
229972	220059	11103C	PARTICIPANT	\N	PRESENT	0
211511	210152	14225N	PARTICIPANT	\N	EXCUSE	0
213433	213432	14119M	PARTICIPANT	\N	PRESENT	0
213435	213434	14119M	PARTICIPANT	\N	PRESENT	0
213437	213436	14119M	PARTICIPANT	\N	PRESENT	0
213477	213476	04044E	PARTICIPANT	\N	PRESENT	0
219952	217449	18003S	PARTICIPANT	\N	PRESENT	0
215439	214584	08014Q	PARTICIPANT	\N	PRESENT	0
215440	214584	11053K	PARTICIPANT	\N	PRESENT	0
215441	214584	19545Y	PARTICIPANT	\N	PRESENT	0
215446	214584	14085U	PARTICIPANT	\N	PRESENT	0
215652	214876	04061F	PARTICIPANT	\N	PRESENT	0
215493	214584	19647E	PARTICIPANT	\N	PRESENT	0
215495	214584	01057W	PARTICIPANT	\N	PRESENT	0
219958	217449	19709B	PARTICIPANT	\N	PRESENT	0
215498	214584	08010L	PARTICIPANT	\N	PRESENT	0
215499	214584	08034U	PARTICIPANT	\N	PRESENT	0
215500	214584	01048V	PARTICIPANT	\N	PRESENT	0
215501	214584	11012A	PARTICIPANT	\N	PRESENT	0
215502	214584	07004J	PARTICIPANT	\N	EXCUSE	0
219959	217449	19533U	PARTICIPANT	\N	PRESENT	0
215603	214876	04085P	PARTICIPANT	\N	PRESENT	0
215604	214876	08055A	PARTICIPANT	\N	PRESENT	0
215605	214876	14093U	PARTICIPANT	\N	PRESENT	0
215606	214876	19549D	PARTICIPANT	\N	PRESENT	0
215607	214876	96004D	PARTICIPANT	\N	PRESENT	0
215608	214876	08060W	PARTICIPANT	\N	PRESENT	0
215609	214876	19733B	PARTICIPANT	\N	PRESENT	0
215610	214876	19383Y	PARTICIPANT	\N	PRESENT	0
215611	214876	08024S	PARTICIPANT	\N	PRESENT	0
215612	214876	14038Y	PARTICIPANT	\N	PRESENT	0
215613	214876	18083K	PARTICIPANT	\N	PRESENT	0
215614	214876	19701S	PARTICIPANT	\N	PRESENT	0
215615	214876	19681G	PARTICIPANT	\N	PRESENT	0
215616	214876	98023Q	PARTICIPANT	\N	PRESENT	0
215617	214876	19525U	PARTICIPANT	\N	PRESENT	0
215618	214876	11065P	PARTICIPANT	\N	PRESENT	0
215985	215984	04086Q	PARTICIPANT	\N	PRESENT	0
215620	214876	19599P	PARTICIPANT	\N	PRESENT	0
215621	214876	02002K	PARTICIPANT	\N	PRESENT	0
215622	214876	15447F	PARTICIPANT	\N	PRESENT	0
215623	214876	19387D	PARTICIPANT	\N	PRESENT	0
215624	214876	19347U	PARTICIPANT	\N	PRESENT	0
215625	214876	19685L	PARTICIPANT	\N	PRESENT	0
215987	215986	04086Q	PARTICIPANT	\N	PRESENT	0
215627	214876	04097T	PARTICIPANT	\N	PRESENT	0
215628	214876	19551W	PARTICIPANT	\N	PRESENT	0
215629	214876	14029X	PARTICIPANT	\N	PRESENT	0
215630	214876	19677L	PARTICIPANT	\N	PRESENT	0
215631	214876	19289C	PARTICIPANT	\N	PRESENT	0
215632	214876	14219Q	PARTICIPANT	\N	PRESENT	0
215633	214876	14103D	PARTICIPANT	\N	PRESENT	0
215634	214876	80027E	PARTICIPANT	\N	PRESENT	0
215635	214876	14031R	PARTICIPANT	\N	PRESENT	0
215636	214876	19637C	PARTICIPANT	\N	PRESENT	0
215637	214876	08009T	PRESIDENT	0	PRESENT	0
215638	214876	14221J	PARTICIPANT	\N	PRESENT	0
215639	214876	14169X	PARTICIPANT	\N	PRESENT	0
215640	214876	14191V	PARTICIPANT	\N	PRESENT	0
215641	214876	14237S	PARTICIPANT	\N	PRESENT	0
215642	214876	17637T	PARTICIPANT	\N	PRESENT	0
215643	214876	05012A	PARTICIPANT	\N	PRESENT	0
215644	214876	19503N	PARTICIPANT	\N	PRESENT	0
215645	214876	19739H	PARTICIPANT	\N	PRESENT	0
215989	215988	14034U	PARTICIPANT	\N	PRESENT	0
215647	214876	95062K	PARTICIPANT	\N	PRESENT	0
215648	214876	19713W	PARTICIPANT	\N	PRESENT	0
215649	214876	14051J	PARTICIPANT	\N	PRESENT	0
215650	214876	14157T	PARTICIPANT	\N	PRESENT	0
215651	214876	19737F	PARTICIPANT	\N	EXCUSE	0
221784	219964	80013X	PARTICIPANT	\N	PRESENT	0
219998	219964	01048V	PARTICIPANT	\N	PRESENT	0
223294	219923	11040E	PARTICIPANT	\N	PRESENT	0
223295	219923	19545Y	PARTICIPANT	\N	PRESENT	0
223296	219923	11070L	PARTICIPANT	\N	PRESENT	0
223297	219923	14327T	PARTICIPANT	\N	PRESENT	0
223298	219923	04071H	PARTICIPANT	\N	PRESENT	0
223299	219923	11074Q	PARTICIPANT	\N	PRESENT	0
223300	219923	19647E	PARTICIPANT	\N	PRESENT	0
223301	219923	07004J	PARTICIPANT	\N	PRESENT	0
223302	219923	11048N	PARTICIPANT	\N	PRESENT	0
223303	219923	14121F	PARTICIPANT	\N	PRESENT	0
223304	219923	95041E	PARTICIPANT	\N	PRESENT	0
223305	219923	99004R	PARTICIPANT	\N	PRESENT	0
223306	219923	14159V	PARTICIPANT	\N	PRESENT	0
223307	219923	07029T	PARTICIPANT	\N	PRESENT	0
223308	219923	19711U	PARTICIPANT	\N	PRESENT	0
223309	219923	08010L	PARTICIPANT	\N	PRESENT	0
223310	219923	08034U	PARTICIPANT	\N	PRESENT	0
223311	219923	01048V	PARTICIPANT	\N	PRESENT	0
223312	219923	08011M	PARTICIPANT	\N	PRESENT	0
223313	219923	08073C	PARTICIPANT	\N	PRESENT	0
223314	219923	19349W	PARTICIPANT	\N	PRESENT	0
223315	219923	14225N	PARTICIPANT	\N	PRESENT	0
223316	219923	19687N	PARTICIPANT	\N	PRESENT	0
223317	219923	19689Q	PARTICIPANT	\N	PRESENT	0
223749	218293	11074Q	PARTICIPANT	\N	PRESENT	0
223750	218293	19687N	PARTICIPANT	\N	PRESENT	0
223751	218293	14331P	PARTICIPANT	\N	PRESENT	0
223752	218293	14041T	PARTICIPANT	\N	PRESENT	0
223753	218293	19651A	PARTICIPANT	\N	PRESENT	0
223754	218293	11040E	PARTICIPANT	\N	PRESENT	0
223755	218293	19593H	PARTICIPANT	\N	PRESENT	0
223756	218293	14275Y	PARTICIPANT	\N	PRESENT	0
223757	218293	11012A	PARTICIPANT	\N	PRESENT	0
223758	218293	19619A	PARTICIPANT	\N	PRESENT	0
223759	218293	19581D	PARTICIPANT	\N	PRESENT	0
223760	218293	07029T	PARTICIPANT	\N	PRESENT	0
223761	218293	04086Q	PARTICIPANT	\N	PRESENT	0
223762	218293	99004R	PARTICIPANT	\N	PRESENT	0
223763	218293	19711U	PARTICIPANT	\N	PRESENT	0
223764	218293	08034U	PARTICIPANT	\N	PRESENT	0
223765	218293	19575F	PARTICIPANT	\N	PRESENT	0
223766	218293	19443T	PARTICIPANT	\N	PRESENT	0
223767	218293	19667J	PARTICIPANT	\N	PRESENT	0
223768	218293	19467C	PARTICIPANT	\N	PRESENT	0
223769	218293	18083K	PARTICIPANT	\N	PRESENT	0
223770	218293	14215L	PARTICIPANT	\N	PRESENT	0
223771	218293	07004J	PARTICIPANT	\N	PRESENT	0
223772	218293	04061F	PARTICIPANT	\N	PRESENT	0
223773	218293	14111D	PARTICIPANT	\N	PRESENT	0
223774	218293	14225N	PARTICIPANT	\N	PRESENT	0
223775	218293	04057K	PARTICIPANT	\N	PRESENT	0
223776	218293	14107H	PARTICIPANT	\N	PRESENT	0
223777	218293	19573D	PARTICIPANT	\N	PRESENT	0
223778	218293	19503N	PARTICIPANT	\N	PRESENT	0
223779	218293	04043D	PARTICIPANT	\N	PRESENT	0
223780	218293	19689Q	PARTICIPANT	\N	PRESENT	0
223781	218293	08020N	PARTICIPANT	\N	PRESENT	0
223782	218293	14159V	PARTICIPANT	\N	PRESENT	0
223783	218293	07033P	PARTICIPANT	\N	PRESENT	0
223784	218293	04059M	PARTICIPANT	\N	PRESENT	0
223785	218293	11045K	PARTICIPANT	\N	PRESENT	0
223786	218293	14081Q	PARTICIPANT	\N	PRESENT	0
223787	218293	19649G	PARTICIPANT	\N	PRESENT	0
223788	218293	19591F	PARTICIPANT	\N	PRESENT	0
223747	218293	11070L	PARTICIPANT	\N	PRESENT	0
223748	218293	08011M	PARTICIPANT	\N	PRESENT	0
223789	218293	19631V	PARTICIPANT	\N	PRESENT	0
223790	218293	14121F	PARTICIPANT	\N	PRESENT	0
223791	218293	08016S	PARTICIPANT	\N	PRESENT	0
223792	218293	11048N	PARTICIPANT	\N	PRESENT	0
223793	218293	11090Q	PARTICIPANT	\N	PRESENT	0
223794	218293	11110B	PARTICIPANT	\N	PRESENT	0
223795	218293	19697Q	PARTICIPANT	\N	PRESENT	0
223796	218293	19577H	PARTICIPANT	\N	PRESENT	0
223797	218293	14083S	PARTICIPANT	\N	PRESENT	0
223801	218293	19733B	PARTICIPANT	\N	PRESENT	0
223802	218293	14157T	PARTICIPANT	\N	PRESENT	0
223803	218293	19399H	PARTICIPANT	\N	PRESENT	0
223804	218293	04042C	PARTICIPANT	\N	PRESENT	0
223808	218293	11072N	PARTICIPANT	\N	PRESENT	0
223809	218293	14029X	PARTICIPANT	\N	PRESENT	0
223810	218293	19693L	PARTICIPANT	\N	PRESENT	0
223811	218293	08019V	PARTICIPANT	\N	PRESENT	0
223812	218293	19349W	PARTICIPANT	\N	PRESENT	0
223813	218293	19657G	PARTICIPANT	\N	PRESENT	0
223814	218293	04085P	PARTICIPANT	\N	PRESENT	0
223815	218293	14251Q	PARTICIPANT	\N	PRESENT	0
223816	222532	19253P	PARTICIPANT	\N	EXCUSE	0
223817	218293	19647E	PARTICIPANT	\N	PRESENT	0
223818	218293	04049K	PARTICIPANT	\N	PRESENT	0
234595	233049	14267Y	PARTICIPANT	\N	PRESENT	0
234596	233049	11064N	PARTICIPANT	\N	PRESENT	0
234597	233049	98050T	PARTICIPANT	\N	PRESENT	0
234598	233049	14211G	PARTICIPANT	\N	PRESENT	0
234599	233049	19583F	PARTICIPANT	\N	PRESENT	0
234600	233049	14255U	PARTICIPANT	\N	PRESENT	0
234602	233030	14327T	PARTICIPANT	\N	PRESENT	0
234603	233030	14331P	PARTICIPANT	\N	PRESENT	0
234604	233030	04071H	PARTICIPANT	\N	PRESENT	0
234605	233030	95041E	PARTICIPANT	\N	PRESENT	0
234606	233030	01048V	PARTICIPANT	\N	PRESENT	0
234607	233030	01057W	PARTICIPANT	\N	PRESENT	0
234608	233030	11053K	PARTICIPANT	\N	PRESENT	0
234609	233030	11074Q	PRESIDENT	0	PRESENT	0
234610	233030	19667J	PARTICIPANT	\N	PRESENT	0
234611	233030	89017R	PARTICIPANT	\N	PRESENT	0
234612	233030	19671E	PARTICIPANT	\N	PRESENT	0
234613	233030	14225N	PARTICIPANT	\N	PRESENT	0
234614	233030	07029T	PARTICIPANT	\N	PRESENT	0
234615	233030	14085U	PARTICIPANT	\N	PRESENT	0
234616	233030	19349W	PARTICIPANT	\N	PRESENT	0
234617	233030	08010L	PARTICIPANT	\N	PRESENT	0
234618	233030	14253S	PARTICIPANT	\N	PRESENT	0
234619	233030	19647E	PARTICIPANT	\N	PRESENT	0
234620	233030	19479G	PARTICIPANT	\N	PRESENT	0
234621	233030	19651A	PARTICIPANT	\N	PRESENT	0
234622	233030	19531S	PARTICIPANT	\N	PRESENT	0
234623	233030	08034U	PARTICIPANT	\N	PRESENT	0
234624	233030	08069G	PARTICIPANT	\N	PRESENT	0
234625	233030	19687N	PARTICIPANT	\N	PRESENT	0
234626	233030	19689Q	PARTICIPANT	\N	PRESENT	0
234627	233030	14034U	PARTICIPANT	\N	PRESENT	0
234628	233030	14173T	PARTICIPANT	\N	PRESENT	0
234629	233030	11040E	PARTICIPANT	\N	PRESENT	0
234630	233030	04086Q	PARTICIPANT	\N	PRESENT	0
234631	233030	14083S	PARTICIPANT	\N	PRESENT	0
234632	233030	11012A	PARTICIPANT	\N	PRESENT	0
234633	233030	14199E	PARTICIPANT	\N	PRESENT	0
234634	233030	08073C	PARTICIPANT	\N	PRESENT	0
234635	233030	14121F	PARTICIPANT	\N	PRESENT	0
234636	233030	19741B	PARTICIPANT	\N	PRESENT	0
234637	233030	99004R	PARTICIPANT	\N	PRESENT	0
234638	233030	88008L	PARTICIPANT	\N	PRESENT	0
234639	233030	11110B	PARTICIPANT	\N	PRESENT	0
234640	233030	11048N	PARTICIPANT	\N	EXCUSE	0
234641	233030	19711U	PARTICIPANT	\N	EXCUSE	0
234642	233030	08011M	PARTICIPANT	\N	EXCUSE	0
234644	233062	11067R	PARTICIPANT	\N	PRESENT	0
234645	233062	11077T	PARTICIPANT	\N	PRESENT	0
234646	233062	11097X	PARTICIPANT	\N	PRESENT	0
234647	233062	14223L	PARTICIPANT	\N	PRESENT	0
234648	233062	04045F	PARTICIPANT	\N	PRESENT	0
234649	233062	14227Q	PARTICIPANT	\N	PRESENT	0
234650	233062	19675J	PARTICIPANT	\N	PRESENT	0
234651	233062	17779H	PARTICIPANT	\N	PRESENT	0
234652	233062	11063M	PARTICIPANT	\N	PRESENT	0
234653	233062	19703U	PARTICIPANT	\N	PRESENT	0
234654	233062	11031D	PARTICIPANT	\N	PRESENT	0
234655	233062	14239U	PARTICIPANT	\N	PRESENT	0
234656	233062	14281W	PARTICIPANT	\N	PRESENT	0
234657	233062	14087W	PARTICIPANT	\N	PRESENT	0
234658	233062	14042U	PARTICIPANT	\N	PRESENT	0
234659	233062	19575F	PARTICIPANT	\N	PRESENT	0
234660	233062	14195A	PARTICIPANT	\N	PRESENT	0
234661	233062	14213J	PARTICIPANT	\N	PRESENT	0
234662	233062	19367Y	PARTICIPANT	\N	PRESENT	0
234663	233062	14261S	PARTICIPANT	\N	PRESENT	0
234664	233062	19335Q	PARTICIPANT	\N	PRESENT	0
234665	233062	19683J	PARTICIPANT	\N	PRESENT	0
234666	233062	10006L	PARTICIPANT	\N	PRESENT	0
234667	233062	19521Q	PARTICIPANT	\N	PRESENT	0
234668	233062	98024R	PARTICIPANT	\N	PRESENT	0
234669	233062	01034P	PARTICIPANT	\N	PRESENT	0
234670	233062	04092N	PRESIDENT	0	PRESENT	0
234671	233062	11045K	PARTICIPANT	\N	PRESENT	0
234672	233062	08052W	PARTICIPANT	\N	PRESENT	0
234673	233062	19691J	PARTICIPANT	\N	PRESENT	0
234674	233062	08041T	PARTICIPANT	\N	PRESENT	0
234675	233062	19723Y	PARTICIPANT	\N	PRESENT	0
234676	233062	19727D	PARTICIPANT	\N	PRESENT	0
234677	233062	14119M	PARTICIPANT	\N	PRESENT	0
234678	233062	11103C	PARTICIPANT	\N	PRESENT	0
234679	233062	14071N	PARTICIPANT	\N	PRESENT	0
234680	233062	19657G	PARTICIPANT	\N	PRESENT	0
234681	233062	19527W	PARTICIPANT	\N	EXCUSE	0
234682	233062	14355X	PARTICIPANT	\N	EXCUSE	0
234683	233062	08048B	PARTICIPANT	\N	EXCUSE	0
234684	233062	19569H	PARTICIPANT	\N	PRESENT	0
234685	233062	14026U	PARTICIPANT	\N	PRESENT	0
234686	233062	19663E	PARTICIPANT	\N	PRESENT	0
234687	233049	08049C	PARTICIPANT	\N	PRESENT	0
234688	233062	19415P	PARTICIPANT	\N	PRESENT	0
234689	233062	19577H	PARTICIPANT	\N	PRESENT	0
234690	233062	19697Q	PARTICIPANT	\N	PRESENT	0
234692	234691	11027H	PARTICIPANT	\N	PRESENT	0
234694	234693	11109J	PARTICIPANT	\N	PRESENT	0
234695	234693	11040E	PARTICIPANT	\N	PRESENT	0
234696	234693	08024S	PARTICIPANT	\N	PRESENT	0
234697	234693	19295A	PARTICIPANT	\N	PRESENT	0
234698	234693	11027H	PARTICIPANT	\N	PRESENT	0
234699	234693	11056N	PARTICIPANT	\N	PRESENT	0
234700	233063	19697Q	PARTICIPANT	\N	PRESENT	0
234701	233063	11067R	PARTICIPANT	\N	PRESENT	0
234702	233063	11077T	PARTICIPANT	\N	PRESENT	0
234703	233063	19569H	PARTICIPANT	\N	PRESENT	0
234704	233063	11097X	PARTICIPANT	\N	PRESENT	0
234705	233063	19415P	PARTICIPANT	\N	PRESENT	0
234706	233063	14223L	PARTICIPANT	\N	PRESENT	0
234707	233063	04045F	PARTICIPANT	\N	PRESENT	0
234708	233063	14026U	PARTICIPANT	\N	PRESENT	0
234709	233063	14227Q	PARTICIPANT	\N	PRESENT	0
234710	233063	19675J	PARTICIPANT	\N	PRESENT	0
234711	233063	17779H	PARTICIPANT	\N	PRESENT	0
234712	233063	11063M	PARTICIPANT	\N	PRESENT	0
234713	233063	19703U	PARTICIPANT	\N	PRESENT	0
234714	233063	11031D	PARTICIPANT	\N	PRESENT	0
234715	233063	14239U	PARTICIPANT	\N	PRESENT	0
234716	233063	14281W	PARTICIPANT	\N	PRESENT	0
234717	233063	14087W	PARTICIPANT	\N	PRESENT	0
234718	233063	14042U	PARTICIPANT	\N	PRESENT	0
234719	233063	19575F	PARTICIPANT	\N	PRESENT	0
234720	233063	14195A	PARTICIPANT	\N	PRESENT	0
234721	233063	14213J	PARTICIPANT	\N	PRESENT	0
234722	233063	19367Y	PARTICIPANT	\N	PRESENT	0
234723	233063	14261S	PARTICIPANT	\N	PRESENT	0
234724	233063	19335Q	PARTICIPANT	\N	PRESENT	0
234725	233063	19683J	PARTICIPANT	\N	PRESENT	0
234726	233063	10006L	PARTICIPANT	\N	PRESENT	0
234727	233063	19521Q	PARTICIPANT	\N	PRESENT	0
234728	233063	98024R	PARTICIPANT	\N	PRESENT	0
234729	233063	01034P	PARTICIPANT	\N	PRESENT	0
234730	233063	04092N	PRESIDENT	0	PRESENT	0
234731	233063	08052W	PARTICIPANT	\N	PRESENT	0
234732	233063	19663E	PARTICIPANT	\N	PRESENT	0
234733	233063	19691J	PARTICIPANT	\N	PRESENT	0
234734	233063	08041T	PARTICIPANT	\N	PRESENT	0
234735	233063	19723Y	PARTICIPANT	\N	PRESENT	0
234736	233063	19727D	PARTICIPANT	\N	PRESENT	0
234737	233063	14119M	PARTICIPANT	\N	PRESENT	0
234738	233063	11103C	PARTICIPANT	\N	PRESENT	0
234739	233063	14071N	PARTICIPANT	\N	PRESENT	0
234740	233063	19657G	PARTICIPANT	\N	PRESENT	0
234741	233063	19577H	PARTICIPANT	\N	PRESENT	0
234742	233063	19527W	PARTICIPANT	\N	EXCUSE	0
234743	233063	14355X	PARTICIPANT	\N	EXCUSE	0
234744	233063	08048B	PARTICIPANT	\N	EXCUSE	0
234745	234693	19695N	PARTICIPANT	\N	PRESENT	0
234746	234693	19441R	PARTICIPANT	\N	PRESENT	0
234747	234693	08019V	PARTICIPANT	\N	PRESENT	0
234748	234693	19301E	PARTICIPANT	\N	PRESENT	0
234749	234693	01062T	PARTICIPANT	\N	PRESENT	0
234758	233063	11045K	PARTICIPANT	\N	PRESENT	0
234759	233329	08017T	PARTICIPANT	\N	PRESENT	0
234760	233329	19685L	PARTICIPANT	\N	PRESENT	0
234761	233329	04059M	PARTICIPANT	\N	PRESENT	0
234762	233329	19747H	PARTICIPANT	\N	PRESENT	0
234763	233199	19383Y	PARTICIPANT	\N	PRESENT	0
234764	233199	19333N	PARTICIPANT	\N	PRESENT	0
234765	233199	19549D	PARTICIPANT	\N	PRESENT	0
234766	233199	95062K	PARTICIPANT	\N	PRESENT	0
234767	233199	19387D	PARTICIPANT	\N	PRESENT	0
234768	233199	14219Q	PARTICIPANT	\N	PRESENT	0
234769	233199	14221J	PARTICIPANT	\N	PRESENT	0
234770	233199	19637C	PARTICIPANT	\N	PRESENT	0
234771	233199	02002K	PARTICIPANT	\N	PRESENT	0
234772	233199	18083K	PARTICIPANT	\N	PRESENT	0
234773	233199	19551W	PARTICIPANT	\N	PRESENT	0
234774	233199	14237S	PARTICIPANT	\N	PRESENT	0
234775	233199	80027E	PARTICIPANT	\N	PRESENT	0
214968	214967	14021P	PARTICIPANT	\N	PRESENT	0
215532	214524	14053L	PARTICIPANT	\N	PRESENT	0
215533	214524	14111D	PARTICIPANT	\N	PRESENT	0
215534	214524	01024M	PARTICIPANT	\N	PRESENT	0
215535	214524	04038G	PARTICIPANT	\N	PRESENT	0
215536	214524	19719D	PARTICIPANT	\N	PRESENT	0
215537	214524	14089Y	PARTICIPANT	\N	PRESENT	0
215538	214524	19729F	PARTICIPANT	\N	PRESENT	0
215539	214524	19629C	PARTICIPANT	\N	PRESENT	0
215540	214524	08044W	PARTICIPANT	\N	PRESENT	0
215541	214524	14069U	PARTICIPANT	\N	PRESENT	0
215542	214524	11049P	PARTICIPANT	\N	PRESENT	0
215543	214524	98035U	PARTICIPANT	\N	PRESENT	0
215544	214524	19649G	PARTICIPANT	\N	PRESENT	0
215545	214524	07034Q	PARTICIPANT	\N	PRESENT	0
215546	214524	08045X	PARTICIPANT	\N	PRESENT	0
215547	214524	01060R	PARTICIPANT	\N	PRESENT	0
215548	214524	11033F	PARTICIPANT	\N	PRESENT	0
215549	214524	19725B	PARTICIPANT	\N	PRESENT	0
215550	214524	95063L	PARTICIPANT	\N	PRESENT	0
215551	214524	11085T	PARTICIPANT	\N	PRESENT	0
215552	214524	08018U	PARTICIPANT	\N	PRESENT	0
215553	214524	04008A	PARTICIPANT	\N	PRESENT	0
215554	214524	11072N	PARTICIPANT	\N	PRESENT	0
215555	214524	14021P	PARTICIPANT	\N	PRESENT	0
215556	214524	14065Q	PARTICIPANT	\N	EXCUSE	0
215590	214587	11070L	PARTICIPANT	\N	PRESENT	0
215591	214587	08019V	RAPPORTEUR_AVIS	\N	PRESENT	0
215592	214587	19689Q	PARTICIPANT	\N	PRESENT	0
215593	214587	08073C	PARTICIPANT	\N	PRESENT	0
215594	214587	19647E	PARTICIPANT	\N	PRESENT	0
215595	214587	14083S	PARTICIPANT	\N	PRESENT	0
215596	214587	04061F	PARTICIPANT	\N	PRESENT	0
215597	214587	14034U	PARTICIPANT	\N	EXCUSE	0
215601	207702	04059M	PARTICIPANT	\N	PRESENT	0
215653	207702	19383Y	PARTICIPANT	\N	PRESENT	0
215654	207702	04049K	PARTICIPANT	\N	PRESENT	0
215655	207702	11090Q	PARTICIPANT	\N	PRESENT	0
215705	207702	19347U	PARTICIPANT	\N	PRESENT	0
215706	207702	19503N	PARTICIPANT	\N	PRESENT	0
215707	207702	08055A	PARTICIPANT	\N	PRESENT	0
215708	207702	14197C	PARTICIPANT	\N	PRESENT	0
215709	207702	19525U	PARTICIPANT	\N	PRESENT	0
215777	207702	14097Y	PARTICIPANT	\N	PRESENT	0
215778	207702	14257W	PARTICIPANT	\N	PRESENT	0
215779	207702	04043D	PARTICIPANT	\N	PRESENT	0
215780	207702	01048V	PARTICIPANT	\N	PRESENT	0
215781	207702	19443T	PARTICIPANT	\N	PRESENT	0
215782	207702	95062K	PARTICIPANT	\N	PRESENT	0
215783	207702	14265W	PARTICIPANT	\N	PRESENT	0
215784	207702	14157T	PARTICIPANT	\N	PRESENT	0
215785	207702	11101A	PARTICIPANT	\N	PRESENT	0
215786	207702	17589D	PARTICIPANT	\N	PRESENT	0
215787	207702	14093U	PARTICIPANT	\N	PRESENT	0
215788	207702	97011G	PARTICIPANT	\N	PRESENT	0
215789	207702	19483C	PARTICIPANT	\N	PRESENT	0
215790	207702	11072N	PARTICIPANT	\N	PRESENT	0
215791	207702	19663E	PARTICIPANT	\N	PRESENT	0
215792	207702	08062Y	PARTICIPANT	\N	PRESENT	0
215793	207702	14026U	PARTICIPANT	\N	PRESENT	0
215794	207702	14357A	PARTICIPANT	\N	PRESENT	0
215795	207702	19581D	PARTICIPANT	\N	PRESENT	0
215796	207702	11070L	PARTICIPANT	\N	PRESENT	0
215797	207702	14173T	PARTICIPANT	\N	PRESENT	0
215798	207702	19673G	PARTICIPANT	\N	PRESENT	0
215799	207702	19693L	PARTICIPANT	\N	PRESENT	0
215800	207702	14105F	PARTICIPANT	\N	PRESENT	0
215801	207702	19697Q	PARTICIPANT	\N	PRESENT	0
215802	207702	04045F	PARTICIPANT	\N	PRESENT	0
215803	207702	14261S	PARTICIPANT	\N	PRESENT	0
215804	207702	14053L	PARTICIPANT	\N	PRESENT	0
215805	207702	11056N	PARTICIPANT	\N	PRESENT	0
215807	207702	04061F	PARTICIPANT	\N	PRESENT	0
215808	207702	19621T	PARTICIPANT	\N	PRESENT	0
215809	207702	19733B	PARTICIPANT	\N	PRESENT	0
215810	207702	08041T	PARTICIPANT	\N	PRESENT	0
215811	207702	19591F	PARTICIPANT	\N	PRESENT	0
215812	207702	14061L	PARTICIPANT	\N	PRESENT	0
215813	207702	19565D	PARTICIPANT	\N	PRESENT	0
215814	207702	11104D	PARTICIPANT	\N	PRESENT	0
215815	207702	14107H	PARTICIPANT	\N	PRESENT	0
215816	207702	04085P	PARTICIPANT	\N	PRESENT	0
215817	207702	14169X	PARTICIPANT	\N	PRESENT	0
215818	207702	96004D	PARTICIPANT	\N	PRESENT	0
215819	207702	95015C	PARTICIPANT	\N	PRESENT	0
215820	207702	14223L	PARTICIPANT	\N	PRESENT	0
215821	207702	11097X	PARTICIPANT	\N	PRESENT	0
215822	207702	14217N	PARTICIPANT	\N	PRESENT	0
215823	207702	19515S	PARTICIPANT	\N	PRESENT	0
215838	207702	14331P	PARTICIPANT	\N	PRESENT	0
215901	207702	19593H	PARTICIPANT	\N	PRESENT	0
215902	207702	14083S	PARTICIPANT	\N	PRESENT	0
215903	207702	14211G	PARTICIPANT	\N	PRESENT	0
215905	214589	14331P	PARTICIPANT	\N	PRESENT	0
215906	214589	14225N	PARTICIPANT	\N	PRESENT	0
215907	214589	11070L	PARTICIPANT	\N	PRESENT	0
215908	214589	11110B	PARTICIPANT	\N	PRESENT	0
215909	214589	11048N	PARTICIPANT	\N	PRESENT	0
215910	214589	08011M	PARTICIPANT	\N	PRESENT	0
215911	214589	14159V	PARTICIPANT	\N	PRESENT	0
215912	214589	14121F	PARTICIPANT	\N	EXCUSE	0
215913	214589	14034U	PARTICIPANT	\N	EXCUSE	0
215936	214725	04070G	PRESIDENT	0	PRESENT	0
215937	214725	19699S	PARTICIPANT	\N	PRESENT	0
215938	214725	12041X	PARTICIPANT	\N	PRESENT	0
215939	214725	19329S	PARTICIPANT	\N	PRESENT	0
215940	214725	14229S	PARTICIPANT	\N	PRESENT	0
215941	214725	19573D	PARTICIPANT	\N	PRESENT	0
215942	214725	14107H	PARTICIPANT	\N	PRESENT	0
215943	214725	08017T	PARTICIPANT	\N	PRESENT	0
215944	214725	08012N	PARTICIPANT	\N	PRESENT	0
215945	214725	08016S	PARTICIPANT	\N	PRESENT	0
215946	214725	14249W	PARTICIPANT	\N	PRESENT	0
215947	214725	19643A	PARTICIPANT	\N	PRESENT	0
215948	214725	14061L	PARTICIPANT	\N	PRESENT	0
215949	214725	04057K	PARTICIPANT	\N	PRESENT	0
215950	214725	14073Q	PARTICIPANT	\N	PRESENT	0
215951	214725	19611R	PARTICIPANT	\N	PRESENT	0
215952	214725	08035V	PARTICIPANT	\N	PRESENT	0
215953	214725	08043V	PARTICIPANT	\N	PRESENT	0
215954	214725	19693L	PARTICIPANT	\N	PRESENT	0
215955	214725	87003B	PARTICIPANT	\N	PRESENT	0
215956	214725	19399H	PARTICIPANT	\N	PRESENT	0
215957	214725	19731Y	PARTICIPANT	\N	PRESENT	0
215958	214725	08020N	PARTICIPANT	\N	PRESENT	0
215959	214725	19735D	PARTICIPANT	\N	PRESENT	0
215960	214725	11109J	PARTICIPANT	\N	PRESENT	0
215961	214725	14109K	PARTICIPANT	\N	PRESENT	0
215962	214725	14063N	PARTICIPANT	\N	PRESENT	0
215963	214725	11083R	PARTICIPANT	\N	PRESENT	0
215964	214725	14121F	PARTICIPANT	\N	PRESENT	0
215965	214725	14123H	PARTICIPANT	\N	PRESENT	0
215966	214725	11043H	PARTICIPANT	\N	PRESENT	0
215967	214725	11104D	PARTICIPANT	\N	PRESENT	0
215968	214725	04018C	PARTICIPANT	\N	PRESENT	0
215969	214725	14241N	PARTICIPANT	\N	EXCUSE	0
215970	214725	08031R	PARTICIPANT	\N	EXCUSE	0
215982	207702	19707Y	PARTICIPANT	\N	PRESENT	0
215983	207702	19705W	PARTICIPANT	\N	PRESENT	0
216471	216302	19651A	PARTICIPANT	\N	PRESENT	0
216472	216302	19667J	PARTICIPANT	\N	PRESENT	0
216473	216302	14083S	PARTICIPANT	\N	PRESENT	0
216474	216302	11053K	PARTICIPANT	\N	PRESENT	0
216475	216302	19545Y	PARTICIPANT	\N	PRESENT	0
216476	216302	14085U	PARTICIPANT	\N	PRESENT	0
229973	220059	14223L	PARTICIPANT	\N	PRESENT	0
229974	220059	11090Q	PARTICIPANT	\N	PRESENT	0
229975	220059	14105F	PARTICIPANT	\N	PRESENT	0
229976	220059	19549D	PARTICIPANT	\N	PRESENT	0
229977	220059	19551W	PARTICIPANT	\N	PRESENT	0
229978	220059	08016S	PARTICIPANT	\N	PRESENT	0
229979	220059	19301E	PARTICIPANT	\N	PRESENT	0
229980	220059	19575F	PARTICIPANT	\N	PRESENT	0
229981	220059	87003B	PARTICIPANT	\N	PRESENT	0
229982	220059	19657G	PARTICIPANT	\N	PRESENT	0
229983	220059	19443T	PARTICIPANT	\N	PRESENT	0
229984	220059	18083K	PARTICIPANT	\N	PRESENT	0
229985	220059	19415P	PARTICIPANT	\N	PRESENT	0
229986	220059	19467C	PARTICIPANT	\N	PRESENT	0
229987	220059	15447F	PARTICIPANT	\N	PRESENT	0
229988	220059	19739H	PARTICIPANT	\N	PRESENT	0
229989	220059	19729F	PARTICIPANT	\N	PRESENT	0
229990	220059	04086Q	PARTICIPANT	\N	PRESENT	0
229991	220059	04044E	PARTICIPANT	\N	PRESENT	0
229992	220059	11097X	PARTICIPANT	\N	PRESENT	0
229993	220059	11065P	PARTICIPANT	\N	PRESENT	0
229994	220059	19703U	PARTICIPANT	\N	PRESENT	0
229995	220059	11072N	PARTICIPANT	\N	PRESENT	0
229996	220059	01043Q	PARTICIPANT	\N	PRESENT	0
229997	220059	19667J	PARTICIPANT	\N	PRESENT	0
229998	220059	14187A	PARTICIPANT	\N	PRESENT	0
229999	220059	19741B	PARTICIPANT	\N	PRESENT	0
230000	220059	11031D	PARTICIPANT	\N	PRESENT	0
230001	220059	14026U	PARTICIPANT	\N	PRESENT	0
230011	220059	19515S	PARTICIPANT	\N	PRESENT	0
230013	220059	14257W	PARTICIPANT	\N	PRESENT	0
230016	220059	19421M	PARTICIPANT	\N	PRESENT	0
230022	220059	14159V	PARTICIPANT	\N	PRESENT	0
230034	220059	04033B	PARTICIPANT	\N	PRESENT	0
230037	220059	19695N	PARTICIPANT	\N	PRESENT	0
230039	220059	19483C	PARTICIPANT	\N	PRESENT	0
230040	220059	14219Q	PARTICIPANT	\N	PRESENT	0
230041	220059	19387D	PARTICIPANT	\N	PRESENT	0
230043	220059	08039A	PARTICIPANT	\N	PRESENT	0
230044	220059	14267Y	PARTICIPANT	\N	PRESENT	0
230045	220059	19591F	PARTICIPANT	\N	PRESENT	0
230046	220059	19447X	PARTICIPANT	\N	PRESENT	0
230047	220059	19713W	PARTICIPANT	\N	PRESENT	0
230048	220059	19511N	PARTICIPANT	\N	PRESENT	0
230049	220059	19725B	PARTICIPANT	\N	PRESENT	0
230050	220059	08014Q	PARTICIPANT	\N	PRESENT	0
230051	220059	14061L	PARTICIPANT	\N	PRESENT	0
230052	220059	88008L	PARTICIPANT	\N	PRESENT	0
230053	220059	98018T	PARTICIPANT	\N	PRESENT	0
230054	220059	19441R	PARTICIPANT	\N	PRESENT	0
230061	220059	80013X	PARTICIPANT	\N	PRESENT	0
230062	220059	19735D	PARTICIPANT	\N	PRESENT	0
230063	220059	19683J	PARTICIPANT	\N	PRESENT	0
230065	230064	14105F	PARTICIPANT	\N	PRESENT	0
230066	230064	08060W	PARTICIPANT	\N	PRESENT	0
230067	230064	14053L	PARTICIPANT	\N	PRESENT	0
230068	230064	14255U	PARTICIPANT	\N	PRESENT	0
230069	220059	89017R	PARTICIPANT	\N	PRESENT	0
230070	220059	19631V	PARTICIPANT	\N	PRESENT	0
230071	230064	14026U	PARTICIPANT	\N	PRESENT	0
230072	230064	14061L	PARTICIPANT	\N	PRESENT	0
230073	230064	04049K	PRESIDENT	0	PRESENT	0
230074	230064	19575F	PARTICIPANT	\N	PRESENT	0
230075	230064	89017R	PARTICIPANT	\N	PRESENT	0
230076	230064	14034U	PARTICIPANT	\N	PRESENT	0
230077	220059	19563B	PARTICIPANT	\N	PRESENT	0
230078	230064	14253S	PARTICIPANT	\N	PRESENT	0
230079	230064	08015R	PARTICIPANT	\N	PRESENT	0
230080	230064	16685X	PARTICIPANT	\N	PRESENT	0
230081	230064	14157T	PARTICIPANT	\N	PRESENT	0
230082	230064	04034C	PARTICIPANT	\N	PRESENT	0
230083	230064	08047A	PARTICIPANT	\N	PRESENT	0
230084	230064	04088S	PARTICIPANT	\N	PRESENT	0
230085	230064	14051J	PARTICIPANT	\N	PRESENT	0
230087	230064	14261S	PARTICIPANT	\N	EXCUSE	0
230089	230064	14030Q	PARTICIPANT	\N	EXCUSE	0
230090	230064	08068F	PARTICIPANT	\N	EXCUSE	0
230091	230064	14083S	PARTICIPANT	\N	EXCUSE	0
230092	230064	19545Y	PARTICIPANT	\N	EXCUSE	0
230093	230064	11031D	PARTICIPANT	\N	EXCUSE	0
230094	230064	14079W	PARTICIPANT	\N	EXCUSE	0
230095	230064	14041T	PARTICIPANT	\N	EXCUSE	0
230096	230064	14151M	PARTICIPANT	\N	EXCUSE	0
230097	230064	19521Q	PARTICIPANT	\N	EXCUSE	0
230098	230064	19591F	PARTICIPANT	\N	EXCUSE	0
230099	230064	11099A	PARTICIPANT	\N	EXCUSE	0
230100	230064	14205J	PARTICIPANT	\N	EXCUSE	0
230101	230064	19671E	PARTICIPANT	\N	EXCUSE	0
230105	230064	14329V	PARTICIPANT	\N	EXCUSE	0
230107	230064	14187A	PARTICIPANT	\N	EXCUSE	0
230111	230064	19695N	PARTICIPANT	\N	EXCUSE	0
230112	230064	14265W	PARTICIPANT	\N	EXCUSE	0
230113	220059	14029X	PARTICIPANT	\N	PRESENT	0
230117	220059	19681G	PARTICIPANT	\N	PRESENT	0
230118	220059	14103D	PARTICIPANT	\N	PRESENT	0
230119	220059	01057W	PARTICIPANT	\N	PRESENT	0
230120	220059	14079W	PARTICIPANT	\N	PRESENT	0
230121	220059	98005N	PARTICIPANT	\N	PRESENT	0
230122	220059	98035U	PARTICIPANT	\N	PRESENT	0
230123	220059	14241N	PARTICIPANT	\N	PRESENT	0
230124	220059	14157T	PARTICIPANT	\N	PRESENT	0
230125	220059	04088S	PARTICIPANT	\N	PRESENT	0
230126	220059	19715Y	PARTICIPANT	\N	PRESENT	0
230155	220059	01024M	PARTICIPANT	\N	PRESENT	0
230156	220059	19369B	PARTICIPANT	\N	PRESENT	0
230157	220059	11101A	PARTICIPANT	\N	PRESENT	0
230158	220059	14265W	PARTICIPANT	\N	PRESENT	0
230159	220059	19693L	PARTICIPANT	\N	PRESENT	0
230160	220059	14033T	PARTICIPANT	\N	PRESENT	0
230161	220059	10015M	PARTICIPANT	\N	PRESENT	0
230162	220059	04047H	PARTICIPANT	\N	PRESENT	0
230163	220059	19253P	PARTICIPANT	\N	PRESENT	0
230164	220059	14059S	PARTICIPANT	\N	PRESENT	0
230165	220059	11067R	PARTICIPANT	\N	PRESENT	0
230166	220059	01028R	PARTICIPANT	\N	PRESENT	0
230167	220059	19413M	PARTICIPANT	\N	PRESENT	0
230168	220059	19479G	PARTICIPANT	\N	PRESENT	0
230203	220060	17637T	PARTICIPANT	\N	PRESENT	0
230204	220060	99004R	PARTICIPANT	\N	PRESENT	0
230205	220060	19711U	PARTICIPANT	\N	PRESENT	0
230206	220060	11101A	PARTICIPANT	\N	PRESENT	0
230207	220060	04047H	PARTICIPANT	\N	PRESENT	0
230208	220060	95030B	PARTICIPANT	\N	PRESENT	0
230209	220060	92040Q	PARTICIPANT	\N	PRESENT	0
230210	220060	15447F	PARTICIPANT	\N	PRESENT	0
230211	220060	95015C	PARTICIPANT	\N	PRESENT	0
230212	220060	14223L	PARTICIPANT	\N	PRESENT	0
230213	220060	04035D	PARTICIPANT	\N	PRESENT	0
230214	220060	11097X	PARTICIPANT	\N	PRESENT	0
230215	220060	19421M	PARTICIPANT	\N	PRESENT	0
230216	220060	11080N	PARTICIPANT	\N	PRESENT	0
230217	220060	04097T	PARTICIPANT	\N	PRESENT	0
230218	220060	14157T	PARTICIPANT	\N	PRESENT	0
230219	220060	14105F	PARTICIPANT	\N	PRESENT	0
230220	220060	01058X	PARTICIPANT	\N	PRESENT	0
230221	220060	98023Q	PARTICIPANT	\N	PRESENT	0
230222	220060	04008A	PARTICIPANT	\N	PRESENT	0
230223	220060	04086Q	PARTICIPANT	\N	PRESENT	0
230224	220060	98024R	PARTICIPANT	\N	PRESENT	0
230225	220060	14031R	PARTICIPANT	\N	PRESENT	0
230226	220060	10006L	PARTICIPANT	\N	PRESENT	0
230227	220060	08034U	PARTICIPANT	\N	PRESENT	0
230228	220060	07033P	PARTICIPANT	\N	PRESENT	0
230229	220060	14357A	PARTICIPANT	\N	PRESENT	0
230230	220060	14265W	PARTICIPANT	\N	PRESENT	0
230231	220060	14026U	PARTICIPANT	\N	PRESENT	0
230232	220060	87003B	PARTICIPANT	\N	PRESENT	0
230233	220060	04049K	PARTICIPANT	\N	PRESENT	0
230234	220060	14187A	PARTICIPANT	\N	PRESENT	0
230235	220060	98005N	PARTICIPANT	\N	PRESENT	0
230236	220060	04033B	PARTICIPANT	\N	PRESENT	0
230237	220060	08020N	PARTICIPANT	\N	PRESENT	0
230238	220060	04085P	PARTICIPANT	\N	PRESENT	0
230239	220060	12041X	PARTICIPANT	\N	PRESENT	0
230240	220060	11040E	PARTICIPANT	\N	PRESENT	0
230241	220060	19347U	PARTICIPANT	\N	PRESENT	0
230242	220060	19565D	PARTICIPANT	\N	PRESENT	0
230243	220060	08015R	PARTICIPANT	\N	PRESENT	0
230244	220060	19695N	PARTICIPANT	\N	PRESENT	0
230245	220060	19593H	PARTICIPANT	\N	PRESENT	0
230246	220060	11090Q	PARTICIPANT	\N	PRESENT	0
230247	220060	14069U	PARTICIPANT	\N	PRESENT	0
230248	220060	04059M	PARTICIPANT	\N	PRESENT	0
230249	220060	14159V	PARTICIPANT	\N	PRESENT	0
230250	220060	14229S	PARTICIPANT	\N	PRESENT	0
230251	220060	14253S	PARTICIPANT	\N	PRESENT	0
230252	220060	14199E	PARTICIPANT	\N	PRESENT	0
230253	220060	08052W	PARTICIPANT	\N	PRESENT	0
230254	220060	14051J	PARTICIPANT	\N	PRESENT	0
223469	218286	07029T	PARTICIPANT	\N	PRESENT	0
223470	218286	14041T	PARTICIPANT	\N	PRESENT	0
223471	218286	08019V	PARTICIPANT	\N	PRESENT	0
223472	218286	19711U	PARTICIPANT	\N	PRESENT	0
223473	218286	19591F	PARTICIPANT	\N	PRESENT	0
223474	218286	14085U	PARTICIPANT	\N	PRESENT	0
223475	218286	08073C	PARTICIPANT	\N	PRESENT	0
223476	218286	14121F	PARTICIPANT	\N	PRESENT	0
223477	218286	11012A	PARTICIPANT	\N	PRESENT	0
223478	218286	19515S	PARTICIPANT	\N	PRESENT	0
223479	218286	19647E	PARTICIPANT	\N	PRESENT	0
223480	218286	96004D	PARTICIPANT	\N	PRESENT	0
223481	218286	19483C	PARTICIPANT	\N	PRESENT	0
223482	218286	08010L	PARTICIPANT	\N	PRESENT	0
223483	218286	99004R	PARTICIPANT	\N	PRESENT	0
223484	218286	14026U	PARTICIPANT	\N	PRESENT	0
223485	218286	19687N	PARTICIPANT	\N	PRESENT	0
223486	218286	95063L	PARTICIPANT	\N	PRESENT	0
223487	218286	14107H	PARTICIPANT	\N	PRESENT	0
223488	218286	14069U	PARTICIPANT	\N	PRESENT	0
223489	218286	08016S	PARTICIPANT	\N	PRESENT	0
223490	218286	14159V	PARTICIPANT	\N	PRESENT	0
223491	218286	01048V	PARTICIPANT	\N	PRESENT	0
223492	218286	14327T	PARTICIPANT	\N	PRESENT	0
223493	218286	11053K	PARTICIPANT	\N	PRESENT	0
223494	218286	19441R	PARTICIPANT	\N	PRESENT	0
223543	218287	14085U	PARTICIPANT	\N	PRESENT	0
223544	218287	19689Q	PARTICIPANT	\N	PRESENT	0
223545	218287	14159V	PARTICIPANT	\N	PRESENT	0
223546	218287	14225N	PARTICIPANT	\N	PRESENT	0
223547	218287	14121F	PARTICIPANT	\N	PRESENT	0
223548	218287	08073C	PARTICIPANT	\N	PRESENT	0
223549	218287	19651A	PARTICIPANT	\N	PRESENT	0
223550	218287	11053K	PARTICIPANT	\N	PRESENT	0
223551	218287	14179A	PARTICIPANT	\N	PRESENT	0
223552	218287	19577H	PARTICIPANT	\N	PRESENT	0
223553	218287	07004J	PARTICIPANT	\N	PRESENT	0
223554	218287	19545Y	PARTICIPANT	\N	PRESENT	0
223555	218287	11074Q	PARTICIPANT	\N	PRESENT	0
223556	218287	08011M	PARTICIPANT	\N	PRESENT	0
223557	218287	19515S	PARTICIPANT	\N	PRESENT	0
223558	218287	19399H	PARTICIPANT	\N	PRESENT	0
223559	218287	07029T	PARTICIPANT	\N	PRESENT	0
223560	218287	19693L	PARTICIPANT	\N	PRESENT	0
223561	218287	04043D	PARTICIPANT	\N	PRESENT	0
223562	218287	19657G	PARTICIPANT	\N	PRESENT	0
223563	218287	14026U	PARTICIPANT	\N	PRESENT	0
223564	218287	11048N	PARTICIPANT	\N	PRESENT	0
223565	218287	19711U	PARTICIPANT	\N	PRESENT	0
223566	218287	08034U	PARTICIPANT	\N	PRESENT	0
223567	218287	04086Q	PARTICIPANT	\N	PRESENT	0
223568	218287	11077T	PARTICIPANT	\N	PRESENT	0
223569	218287	19593H	PARTICIPANT	\N	PRESENT	0
223570	218287	19687N	PARTICIPANT	\N	PRESENT	0
223571	218287	14083S	PARTICIPANT	\N	PRESENT	0
223572	218287	11012A	PARTICIPANT	\N	PRESENT	0
223573	218287	99004R	PARTICIPANT	\N	PRESENT	0
223574	218287	01057W	PARTICIPANT	\N	PRESENT	0
223575	218287	14331P	PARTICIPANT	\N	PRESENT	0
223576	218287	95063L	PARTICIPANT	\N	PRESENT	0
223577	218287	04018C	PARTICIPANT	\N	PRESENT	0
223578	218287	11026G	PARTICIPANT	\N	PRESENT	0
223579	218287	08010L	PARTICIPANT	\N	PRESENT	0
223580	218287	11090Q	PARTICIPANT	\N	PRESENT	0
223581	218287	17637T	PARTICIPANT	\N	PRESENT	0
223582	218287	11070L	PARTICIPANT	\N	PRESENT	0
223583	218287	19483C	PARTICIPANT	\N	PRESENT	0
223584	218287	14069U	PARTICIPANT	\N	PRESENT	0
223585	218287	14041T	PARTICIPANT	\N	PRESENT	0
223586	218287	19643A	PARTICIPANT	\N	PRESENT	0
223587	218287	96004D	PARTICIPANT	\N	PRESENT	0
223588	218287	08019V	PARTICIPANT	\N	PRESENT	0
223541	218287	01043Q	PARTICIPANT	\N	PRESENT	0
223542	218287	11040E	PARTICIPANT	\N	PRESENT	0
223589	218287	04042C	PARTICIPANT	\N	PRESENT	0
223590	218287	19647E	PARTICIPANT	\N	PRESENT	0
223591	218287	08017T	PARTICIPANT	\N	PRESENT	0
223592	218287	01048V	PARTICIPANT	\N	PRESENT	0
223593	218287	11072N	PARTICIPANT	\N	PRESENT	0
223594	218287	19671E	PARTICIPANT	\N	PRESENT	0
223595	218287	01028R	PARTICIPANT	\N	PRESENT	0
223621	218292	04044E	PARTICIPANT	\N	PRESENT	0
223628	218292	08011M	PARTICIPANT	\N	PRESENT	0
223629	218292	11040E	PARTICIPANT	\N	PRESENT	0
223630	218292	11026G	PARTICIPANT	\N	PRESENT	0
223631	218292	14225N	PARTICIPANT	\N	PRESENT	0
223632	218292	19651A	PARTICIPANT	\N	PRESENT	0
223633	218292	19687N	PARTICIPANT	\N	PRESENT	0
223634	218292	07004J	PARTICIPANT	\N	PRESENT	0
223635	218292	19643A	PARTICIPANT	\N	PRESENT	0
223636	218292	19573D	PARTICIPANT	\N	PRESENT	0
223637	218292	14041T	PARTICIPANT	\N	PRESENT	0
223638	218292	07029T	PARTICIPANT	\N	PRESENT	0
223639	218292	14107H	PARTICIPANT	\N	PRESENT	0
223640	218292	14329V	PARTICIPANT	\N	PRESENT	0
223641	218292	08034U	PARTICIPANT	\N	PRESENT	0
223642	218292	19671E	PARTICIPANT	\N	PRESENT	0
223643	218292	14331P	PARTICIPANT	\N	PRESENT	0
223644	218292	19575F	PARTICIPANT	\N	PRESENT	0
223645	218292	19443T	PARTICIPANT	\N	PRESENT	0
223646	218292	19619A	PARTICIPANT	\N	PRESENT	0
223647	218292	04086Q	PARTICIPANT	\N	PRESENT	0
223648	218292	19711U	PARTICIPANT	\N	PRESENT	0
223649	218292	99004R	PARTICIPANT	\N	PRESENT	0
223650	218292	14121F	PARTICIPANT	\N	PRESENT	0
223651	218292	14081Q	PARTICIPANT	\N	PRESENT	0
223652	218292	19667J	PARTICIPANT	\N	PRESENT	0
223653	218292	11090Q	PARTICIPANT	\N	PRESENT	0
223654	218292	19693L	PARTICIPANT	\N	PRESENT	0
223655	218292	04061F	PARTICIPANT	\N	PRESENT	0
223680	218292	19593H	PARTICIPANT	\N	PRESENT	0
223657	218292	14215L	PARTICIPANT	\N	PRESENT	0
223658	218292	04035D	PARTICIPANT	\N	PRESENT	0
223659	218292	14039A	PARTICIPANT	\N	PRESENT	0
223660	218292	11074Q	PARTICIPANT	\N	PRESENT	0
223661	218292	14159V	PARTICIPANT	\N	PRESENT	0
223662	218292	14205J	PARTICIPANT	\N	PRESENT	0
223663	218292	08073C	PARTICIPANT	\N	PRESENT	0
223664	218292	19467C	PARTICIPANT	\N	PRESENT	0
223665	218292	19545Y	PARTICIPANT	\N	PRESENT	0
223666	218292	08019V	PARTICIPANT	\N	PRESENT	0
223673	218292	18083K	PARTICIPANT	\N	PRESENT	0
223674	218292	08018U	PARTICIPANT	\N	PRESENT	0
223675	218292	19631V	PARTICIPANT	\N	PRESENT	0
223676	218292	19689Q	PARTICIPANT	\N	PRESENT	0
223681	218292	19683J	PARTICIPANT	\N	PRESENT	0
223689	218292	14275Y	PARTICIPANT	\N	PRESENT	0
223690	218292	14087W	PARTICIPANT	\N	PRESENT	0
223691	218292	14251Q	PARTICIPANT	\N	PRESENT	0
224755	223290	19697Q	PARTICIPANT	\N	PRESENT	0
224756	223290	11067R	PARTICIPANT	\N	PRESENT	0
224757	223290	19569H	PARTICIPANT	\N	PRESENT	0
224758	223290	11097X	PARTICIPANT	\N	PRESENT	0
224759	223290	19415P	PARTICIPANT	\N	PRESENT	0
224760	223290	14223L	PARTICIPANT	\N	PRESENT	0
224761	223290	19675J	PARTICIPANT	\N	PRESENT	0
224762	223290	11063M	PARTICIPANT	\N	PRESENT	0
224763	223290	14239U	PARTICIPANT	\N	PRESENT	0
224764	223290	19703U	PARTICIPANT	\N	PRESENT	0
224765	223290	19553Y	PARTICIPANT	\N	PRESENT	0
224766	223290	14087W	PARTICIPANT	\N	PRESENT	0
224767	223290	14281W	PARTICIPANT	\N	PRESENT	0
224768	223290	14195A	PARTICIPANT	\N	PRESENT	0
224769	223290	19367Y	PARTICIPANT	\N	PRESENT	0
224770	223290	14213J	PARTICIPANT	\N	PRESENT	0
224771	223290	19683J	PARTICIPANT	\N	PRESENT	0
224772	223290	98024R	PARTICIPANT	\N	PRESENT	0
224773	223290	19521Q	PARTICIPANT	\N	PRESENT	0
224774	223290	19527W	PARTICIPANT	\N	PRESENT	0
224775	223290	01034P	PARTICIPANT	\N	PRESENT	0
224776	223290	04092N	PRESIDENT	0	PRESENT	0
224777	223290	08052W	PARTICIPANT	\N	PRESENT	0
224778	223290	19691J	PARTICIPANT	\N	PRESENT	0
224779	223290	19715Y	PARTICIPANT	\N	PRESENT	0
224780	223290	19723Y	PARTICIPANT	\N	PRESENT	0
224781	223290	19727D	PARTICIPANT	\N	PRESENT	0
224782	223290	14119M	PARTICIPANT	\N	PRESENT	0
224783	223290	19657G	PARTICIPANT	\N	PRESENT	0
224784	223290	14071N	PARTICIPANT	\N	PRESENT	0
224785	223290	08048B	PARTICIPANT	\N	EXCUSE	0
224786	223290	08041T	PARTICIPANT	\N	EXCUSE	0
224787	223290	14026U	PARTICIPANT	\N	PRESENT	0
224788	223290	14227Q	PARTICIPANT	\N	PRESENT	0
224789	223290	17779H	PARTICIPANT	\N	PRESENT	0
224790	223290	19679N	PARTICIPANT	\N	PRESENT	0
224791	223290	19575F	PARTICIPANT	\N	PRESENT	0
224792	223290	10006L	PARTICIPANT	\N	PRESENT	0
224793	223290	19663E	PARTICIPANT	\N	PRESENT	0
213319	205652	80013X	PRESIDENT	0	PRESENT	0
213482	213481	98023Q	PARTICIPANT	\N	PRESENT	0
213483	213481	19681G	PARTICIPANT	\N	PRESENT	0
213485	213484	98023Q	PARTICIPANT	\N	PRESENT	0
213487	213486	18083K	PARTICIPANT	\N	PRESENT	0
213489	213488	18083K	PARTICIPANT	\N	PRESENT	0
215344	214492	14267Y	PARTICIPANT	\N	EXCUSE	0
215345	214492	08056B	PARTICIPANT	\N	EXCUSE	0
215346	214492	19583F	PARTICIPANT	\N	EXCUSE	0
215991	215990	01024M	PARTICIPANT	\N	PRESENT	0
215993	215992	14021P	PARTICIPANT	\N	PRESENT	0
216035	207252	11072N	PARTICIPANT	\N	PRESENT	0
216036	207252	08019V	PRESIDENT	0	PRESENT	0
235533	235531	14073Q	PARTICIPANT	\N	PRESENT	0
235535	235534	14073Q	PARTICIPANT	\N	PRESENT	0
235536	235534	08012N	PARTICIPANT	\N	PRESENT	0
235538	235537	14073Q	PARTICIPANT	\N	PRESENT	0
237481	237480	19621T	PARTICIPANT	\N	PRESENT	0
237482	237480	19721W	PARTICIPANT	\N	PRESENT	0
237483	237480	19525U	PARTICIPANT	\N	PRESENT	0
237484	237480	19693L	PARTICIPANT	\N	PRESENT	0
237485	237480	07033P	PARTICIPANT	\N	PRESENT	0
237486	237480	11110B	PARTICIPANT	\N	PRESENT	0
237487	237480	14187A	PARTICIPANT	\N	PRESENT	0
237488	237480	14281W	PARTICIPANT	\N	PRESENT	0
237489	237480	04035D	PARTICIPANT	\N	PRESENT	0
237490	237480	98022P	PARTICIPANT	\N	PRESENT	0
237491	237480	99004R	PARTICIPANT	\N	PRESENT	0
237492	237480	19583F	PARTICIPANT	\N	PRESENT	0
237493	237480	19699S	PARTICIPANT	\N	PRESENT	0
237494	237480	11026G	PARTICIPANT	\N	PRESENT	0
237495	237480	11085T	PARTICIPANT	\N	PRESENT	0
237496	237480	19671E	PARTICIPANT	\N	PRESENT	0
237497	237480	04070G	PARTICIPANT	\N	PRESENT	0
237498	237480	04088S	PARTICIPANT	\N	PRESENT	0
237499	237480	14229S	PARTICIPANT	\N	PRESENT	0
237500	237480	11054L	PARTICIPANT	\N	PRESENT	0
237501	237480	04018C	PARTICIPANT	\N	PRESENT	0
237502	237480	98035U	PARTICIPANT	\N	PRESENT	0
237503	237480	95067Q	PARTICIPANT	\N	PRESENT	0
237691	235429	98053W	PARTICIPANT	\N	EXCUSE	0
237695	235429	08056B	PARTICIPANT	\N	EXCUSE	0
237867	237866	04038G	PARTICIPANT	\N	PRESENT	0
237868	237866	19253P	PARTICIPANT	\N	PRESENT	0
237869	237866	19719D	PARTICIPANT	\N	PRESENT	0
237870	237866	01024M	PARTICIPANT	\N	PRESENT	0
237871	237866	14151M	PARTICIPANT	\N	PRESENT	0
237872	237866	14187A	PARTICIPANT	\N	PRESENT	0
237873	237866	14087W	PRESIDENT	0	PRESENT	0
237874	237866	14026U	PARTICIPANT	\N	PRESENT	0
237875	237866	11048N	PRESIDENT	1	PRESENT	0
237876	237866	04049K	PARTICIPANT	\N	PRESENT	0
237877	237866	19711U	PARTICIPANT	\N	PRESENT	0
237878	237866	19441R	PARTICIPANT	\N	PRESENT	0
237879	237866	14103D	PARTICIPANT	\N	PRESENT	0
237880	237866	14031R	PARTICIPANT	\N	PRESENT	0
237881	237866	08053X	PARTICIPANT	\N	PRESENT	0
237882	237866	11067R	PARTICIPANT	\N	PRESENT	0
237883	237866	19503N	PARTICIPANT	\N	PRESENT	0
237884	237866	19689Q	PARTICIPANT	\N	PRESENT	0
237885	237866	19749K	PARTICIPANT	\N	PRESENT	0
237886	237866	19479G	PARTICIPANT	\N	PRESENT	0
237887	237866	14173T	PARTICIPANT	\N	PRESENT	0
237888	237866	19651A	PARTICIPANT	\N	EXCUSE	0
237889	237866	11040E	PARTICIPANT	\N	EXCUSE	0
237890	237866	19545Y	PARTICIPANT	\N	EXCUSE	0
237891	237866	19399H	PARTICIPANT	\N	EXCUSE	0
237892	237866	95063L	PARTICIPANT	\N	EXCUSE	0
237999	237998	14030Q	PARTICIPANT	\N	PRESENT	0
238000	237998	19533U	PARTICIPANT	\N	PRESENT	0
238001	237998	08039A	PARTICIPANT	\N	PRESENT	0
238002	237998	19749K	PARTICIPANT	\N	PRESENT	0
238768	238767	19651A	PARTICIPANT	\N	PRESENT	0
238769	238767	19295A	PARTICIPANT	\N	PRESENT	0
238770	238767	19347U	PARTICIPANT	\N	PRESENT	0
238771	238767	14039A	PARTICIPANT	\N	PRESENT	0
238772	238767	14169X	PARTICIPANT	\N	PRESENT	0
238773	238767	08073C	PARTICIPANT	\N	PRESENT	0
238774	238767	11031D	PARTICIPANT	\N	PRESENT	0
238920	238871	19333N	PARTICIPANT	\N	PRESENT	0
238921	238871	19383Y	PARTICIPANT	\N	PRESENT	0
238922	238871	17583W	PARTICIPANT	\N	PRESENT	0
238923	238871	19701S	PARTICIPANT	\N	PRESENT	0
238924	238871	19549D	PARTICIPANT	\N	PRESENT	0
238925	238871	95062K	PARTICIPANT	\N	PRESENT	0
238926	238871	19387D	PARTICIPANT	\N	PRESENT	0
238927	238871	19637C	PARTICIPANT	\N	PRESENT	0
238928	238871	14237S	PARTICIPANT	\N	PRESENT	0
238929	238871	18083K	PARTICIPANT	\N	PRESENT	0
238930	238871	14051J	PARTICIPANT	\N	PRESENT	0
238931	238871	08060W	PARTICIPANT	\N	PRESENT	0
238932	238871	19503N	PARTICIPANT	\N	PRESENT	0
238933	238871	19347U	PARTICIPANT	\N	PRESENT	0
238934	238871	96004D	PARTICIPANT	\N	PRESENT	0
238935	238871	14157T	PARTICIPANT	\N	PRESENT	0
238936	238871	08024S	PARTICIPANT	\N	PRESENT	0
238937	238871	98023Q	PARTICIPANT	\N	PRESENT	0
238938	238871	17637T	PARTICIPANT	\N	PRESENT	0
238939	238871	11065P	PARTICIPANT	\N	PRESENT	0
238940	238871	14038Y	PARTICIPANT	\N	PRESENT	0
238941	238871	14103D	PARTICIPANT	\N	PRESENT	0
238942	238871	14031R	PARTICIPANT	\N	PRESENT	0
238943	238871	08055A	PARTICIPANT	\N	PRESENT	0
238944	238871	19289C	PARTICIPANT	\N	PRESENT	0
238945	238871	14169X	PARTICIPANT	\N	PRESENT	0
238946	238871	15447F	PARTICIPANT	\N	PRESENT	0
238947	238871	14093U	PARTICIPANT	\N	PRESENT	0
238948	238871	19733B	PARTICIPANT	\N	PRESENT	0
238949	238871	08009T	PRESIDENT	0	PRESENT	0
238950	238871	04097T	PARTICIPANT	\N	PRESENT	0
238951	238871	19685L	PARTICIPANT	\N	EXCUSE	0
238974	238871	19551W	PARTICIPANT	\N	EXCUSE	0
239008	238880	04086Q	PARTICIPANT	\N	PRESENT	0
239009	238880	15447F	PRESIDENT	0	PRESENT	0
239010	238880	19729F	PARTICIPANT	\N	PRESENT	0
239011	238880	19443T	PARTICIPANT	\N	PRESENT	0
239012	238880	08035V	PARTICIPANT	\N	PRESENT	0
239013	238880	08058D	PRESIDENT	1	PRESENT	0
239014	238880	11053K	PARTICIPANT	\N	PRESENT	0
239015	238880	11049P	PARTICIPANT	\N	PRESENT	0
239016	238880	19719D	PARTICIPANT	\N	PRESENT	0
239017	238880	19721W	PARTICIPANT	\N	PRESENT	0
239018	238880	14021P	PARTICIPANT	\N	EXCUSE	0
239019	238880	04071H	PARTICIPANT	\N	PRESENT	0
239020	238880	10015M	PARTICIPANT	\N	PRESENT	0
239021	238880	19251M	PARTICIPANT	\N	PRESENT	0
239022	238880	19581D	PARTICIPANT	\N	PRESENT	0
239023	238880	19703U	PARTICIPANT	\N	PRESENT	0
239024	238880	14097Y	PARTICIPANT	\N	PRESENT	0
239025	238880	04085P	PARTICIPANT	\N	PRESENT	0
239026	238880	14111D	PARTICIPANT	\N	PRESENT	0
239027	238880	19543W	PARTICIPANT	\N	PRESENT	0
239028	238878	01043Q	PARTICIPANT	\N	PRESENT	0
239029	238878	14157T	PARTICIPANT	\N	PRESENT	0
239030	238878	14031R	PARTICIPANT	\N	PRESENT	0
239031	238878	14331P	PARTICIPANT	\N	PRESENT	0
239032	238878	04008A	PARTICIPANT	\N	PRESENT	0
239033	238878	05008E	PARTICIPANT	\N	PRESENT	0
239034	238878	11066Q	PARTICIPANT	\N	PRESENT	0
239092	238968	04070G	PRESIDENT	0	PRESENT	0
239093	238968	19699S	PARTICIPANT	\N	PRESENT	0
239094	238968	12041X	PARTICIPANT	\N	PRESENT	0
239095	238968	19533U	PARTICIPANT	\N	PRESENT	0
239096	238968	95015C	PARTICIPANT	\N	PRESENT	0
239097	238968	14229S	PARTICIPANT	\N	PRESENT	0
239098	238968	14241N	PARTICIPANT	\N	PRESENT	0
239099	238968	19573D	PARTICIPANT	\N	PRESENT	0
239100	238968	14107H	PARTICIPANT	\N	PRESENT	0
239101	238968	14249W	PARTICIPANT	\N	PRESENT	0
239102	238968	08039A	PARTICIPANT	\N	PRESENT	0
239103	238968	14059S	PARTICIPANT	\N	PRESENT	0
239104	238968	19643A	PARTICIPANT	\N	PRESENT	0
239105	238968	04057K	PARTICIPANT	\N	PRESENT	0
239106	238968	14073Q	PARTICIPANT	\N	PRESENT	0
239107	238968	19693L	PARTICIPANT	\N	PRESENT	0
239108	238968	19399H	PARTICIPANT	\N	PRESENT	0
239109	238968	87003B	PARTICIPANT	\N	PRESENT	0
239110	238968	19731Y	PARTICIPANT	\N	PRESENT	0
239111	238968	08020N	PARTICIPANT	\N	PRESENT	0
239112	238968	14251Q	PARTICIPANT	\N	PRESENT	0
239113	238968	04059M	PARTICIPANT	\N	PRESENT	0
239114	238968	19735D	PARTICIPANT	\N	PRESENT	0
239115	238968	11109J	PARTICIPANT	\N	PRESENT	0
239116	238968	14063N	PARTICIPANT	\N	PRESENT	0
239117	238968	11104D	PARTICIPANT	\N	PRESENT	0
239118	238968	11043H	PARTICIPANT	\N	PRESENT	0
239119	238968	04018C	PARTICIPANT	\N	PRESENT	0
239120	238968	19593H	PARTICIPANT	\N	PRESENT	0
239121	238968	19611R	PARTICIPANT	\N	PRESENT	0
226369	226368	95067Q	PARTICIPANT	\N	PRESENT	0
228465	228450	19489J	PARTICIPANT	\N	PRESENT	0
228466	228450	19629C	PARTICIPANT	\N	PRESENT	0
235091	232943	11049P	PARTICIPANT	\N	PRESENT	0
235092	232943	19467C	PARTICIPANT	\N	PRESENT	0
235093	232943	11103C	PARTICIPANT	\N	PRESENT	0
235094	232943	14073Q	PARTICIPANT	\N	PRESENT	0
235095	232943	14217N	PARTICIPANT	\N	PRESENT	0
235096	232943	04088S	PARTICIPANT	\N	PRESENT	0
235121	232943	14097Y	PARTICIPANT	\N	PRESENT	0
236155	235526	08048B	PARTICIPANT	\N	EXCUSE	0
236156	235526	19663E	PARTICIPANT	\N	EXCUSE	0
236157	235526	14281W	PARTICIPANT	\N	EXCUSE	0
236158	235526	08041T	PARTICIPANT	\N	EXCUSE	0
236298	232944	14001X	PARTICIPANT	\N	PRESENT	0
236299	232944	19689Q	PARTICIPANT	\N	PRESENT	0
236300	232944	14026U	PARTICIPANT	\N	PRESENT	0
236301	232944	14147R	PARTICIPANT	\N	PRESENT	0
236302	232944	11040E	PARTICIPANT	\N	PRESENT	0
236304	232944	11045K	PARTICIPANT	\N	PRESENT	0
236305	236303	19643A	PARTICIPANT	\N	PRESENT	0
236306	236303	95015C	PARTICIPANT	\N	PRESENT	0
236307	236303	19251M	PARTICIPANT	\N	PRESENT	0
236308	236303	87003B	PARTICIPANT	\N	PRESENT	0
236309	232944	19651A	PARTICIPANT	\N	PRESENT	0
236310	236303	19399H	PARTICIPANT	\N	PRESENT	0
236311	236303	19683J	PARTICIPANT	\N	PRESENT	0
236312	236303	14241N	PARTICIPANT	\N	PRESENT	0
236313	236303	14039A	PARTICIPANT	\N	PRESENT	0
236314	236303	19611R	PARTICIPANT	\N	PRESENT	0
236315	236303	19711U	PARTICIPANT	\N	PRESENT	0
236316	236303	08012N	PARTICIPANT	\N	PRESENT	0
236317	236303	14063N	PARTICIPANT	\N	PRESENT	0
236318	236303	19533U	PARTICIPANT	\N	PRESENT	0
236319	236303	14107H	PARTICIPANT	\N	PRESENT	0
236320	236303	11043H	PARTICIPANT	\N	PRESENT	0
236321	232944	19387D	PARTICIPANT	\N	PRESENT	0
236322	232944	14031R	PARTICIPANT	\N	PRESENT	0
236323	232944	01028R	PARTICIPANT	\N	PRESENT	0
236324	232944	19441R	PARTICIPANT	\N	PRESENT	0
236325	232944	11012A	PARTICIPANT	\N	PRESENT	0
236326	232944	18083K	PARTICIPANT	\N	PRESENT	0
236327	232944	19747H	PARTICIPANT	\N	PRESENT	0
236328	232944	19719D	PARTICIPANT	\N	PRESENT	0
236329	232944	14109K	PARTICIPANT	\N	PRESENT	0
236330	232944	08012N	PARTICIPANT	\N	PRESENT	0
236331	232944	11104D	PARTICIPANT	\N	PRESENT	0
236332	232944	14173T	PARTICIPANT	\N	PRESENT	0
236333	232944	95030B	PARTICIPANT	\N	PRESENT	0
236334	232944	19565D	PARTICIPANT	\N	PRESENT	0
236335	232944	14151M	PARTICIPANT	\N	PRESENT	0
236336	232944	14063N	PARTICIPANT	\N	PRESENT	0
236337	232944	14261S	PARTICIPANT	\N	PRESENT	0
236338	232944	14251Q	PARTICIPANT	\N	PRESENT	0
236339	232944	80013X	PARTICIPANT	\N	PRESENT	0
236340	232944	19503N	PARTICIPANT	\N	PRESENT	0
236341	232944	14327T	PARTICIPANT	\N	PRESENT	0
236342	232944	14069U	PARTICIPANT	\N	PRESENT	0
236343	232944	19511N	PARTICIPANT	\N	PRESENT	0
236344	232944	19533U	PARTICIPANT	\N	PRESENT	0
236346	232944	08019V	PARTICIPANT	\N	PRESENT	0
236347	232944	04061F	PARTICIPANT	\N	PRESENT	0
236348	232944	19685L	PARTICIPANT	\N	PRESENT	0
236349	232944	01058X	PARTICIPANT	\N	PRESENT	0
236353	232944	17583W	PARTICIPANT	\N	PRESENT	0
236355	232944	19581D	PARTICIPANT	\N	PRESENT	0
236364	232944	19527W	PARTICIPANT	\N	PRESENT	0
236365	232944	08024S	PARTICIPANT	\N	PRESENT	0
236366	232944	14083S	PARTICIPANT	\N	PRESENT	0
236367	232944	19731Y	PARTICIPANT	\N	PRESENT	0
236368	232944	14107H	PARTICIPANT	\N	PRESENT	0
236369	232944	11033F	PARTICIPANT	\N	PRESENT	0
236370	232944	88008L	PARTICIPANT	\N	PRESENT	0
236371	232944	08062Y	PARTICIPANT	\N	PRESENT	0
236372	232944	19479G	PARTICIPANT	\N	PRESENT	0
236373	232944	04049K	PARTICIPANT	\N	PRESENT	0
236374	232944	95062K	PARTICIPANT	\N	PRESENT	0
236375	232944	11043H	PARTICIPANT	\N	PRESENT	0
236376	232944	08010L	PARTICIPANT	\N	PRESENT	0
236377	232944	19621T	PARTICIPANT	\N	PRESENT	0
236378	232944	14201E	PARTICIPANT	\N	PRESENT	0
236379	232944	14355X	PARTICIPANT	\N	PRESENT	0
236380	232944	08069G	PARTICIPANT	\N	PRESENT	0
236381	232944	19699S	PARTICIPANT	\N	PRESENT	0
236382	232944	14105F	PARTICIPANT	\N	PRESENT	0
236383	232944	19447X	PARTICIPANT	\N	PRESENT	0
236386	232944	14199E	PARTICIPANT	\N	PRESENT	0
236387	232944	14207L	PARTICIPANT	\N	PRESENT	0
236388	232944	98022P	PARTICIPANT	\N	PRESENT	0
236389	232944	14179A	PARTICIPANT	\N	PRESENT	0
236390	232944	95015C	PARTICIPANT	\N	PRESENT	0
236391	232944	19695N	PARTICIPANT	\N	PRESENT	0
236392	232944	95041E	PARTICIPANT	\N	PRESENT	0
236393	232944	05008E	PARTICIPANT	\N	PRESENT	0
236394	232944	19367Y	PARTICIPANT	\N	PRESENT	0
236395	232944	19349W	PARTICIPANT	\N	PRESENT	0
236396	232944	19585H	PARTICIPANT	\N	PRESENT	0
236397	232944	14039A	PARTICIPANT	\N	PRESENT	0
236398	232944	14237S	PARTICIPANT	\N	PRESENT	0
236541	232945	95062K	PARTICIPANT	\N	PRESENT	0
236542	232945	99004R	PARTICIPANT	\N	PRESENT	0
236543	232945	08010L	PARTICIPANT	\N	PRESENT	0
236544	232945	04086Q	PARTICIPANT	\N	PRESENT	0
236545	232945	14038Y	PARTICIPANT	\N	PRESENT	0
236546	232945	14031R	PARTICIPANT	\N	PRESENT	0
236547	232945	08069G	PARTICIPANT	\N	PRESENT	0
236548	232945	18083K	PARTICIPANT	\N	PRESENT	0
236549	232945	19447X	PARTICIPANT	\N	PRESENT	0
236550	232945	04097T	PARTICIPANT	\N	PRESENT	0
236551	232945	87003B	PARTICIPANT	\N	PRESENT	0
236552	232945	19703U	PARTICIPANT	\N	PRESENT	0
236553	232945	19507S	PARTICIPANT	\N	PRESENT	0
236554	232945	08019V	PARTICIPANT	\N	PRESENT	0
236555	232945	92040Q	PARTICIPANT	\N	PRESENT	0
236556	232945	14133K	PARTICIPANT	\N	PRESENT	0
236557	232945	19467C	PARTICIPANT	\N	PRESENT	0
236558	232945	01058X	PARTICIPANT	\N	PRESENT	0
236559	232945	08034U	PARTICIPANT	\N	PRESENT	0
236560	232945	14069U	PARTICIPANT	\N	PRESENT	0
236561	232945	19707Y	PARTICIPANT	\N	PRESENT	0
236562	232945	19705W	PARTICIPANT	\N	PRESENT	0
236563	232945	04088S	PARTICIPANT	\N	PRESENT	0
236564	232945	04049K	PARTICIPANT	\N	PRESENT	0
236565	232945	14041T	PARTICIPANT	\N	PRESENT	0
236566	232945	14265W	PARTICIPANT	\N	PRESENT	0
236567	232945	19679N	PARTICIPANT	\N	PRESENT	0
236568	232945	14355X	PARTICIPANT	\N	PRESENT	0
236569	232945	14217N	PARTICIPANT	\N	PRESENT	0
236570	232945	98024R	PARTICIPANT	\N	PRESENT	0
236571	232945	17637T	PARTICIPANT	\N	PRESENT	0
236572	232945	19711U	PARTICIPANT	\N	PRESENT	0
236573	232945	95030B	PARTICIPANT	\N	PRESENT	0
236574	232945	04092N	PARTICIPANT	\N	PRESENT	0
236575	232945	19673G	PARTICIPANT	\N	PRESENT	0
236576	232945	14026U	PARTICIPANT	\N	PRESENT	0
236580	232945	11048N	PARTICIPANT	\N	PRESENT	0
236583	232945	07029T	PARTICIPANT	\N	PRESENT	0
236585	232945	14135M	PARTICIPANT	\N	PRESENT	0
236586	232945	14331P	PARTICIPANT	\N	PRESENT	0
236587	232945	19415P	PARTICIPANT	\N	PRESENT	0
236590	232945	14029X	PARTICIPANT	\N	PRESENT	0
236591	232945	19709B	PARTICIPANT	\N	PRESENT	0
236593	232945	19663E	PARTICIPANT	\N	PRESENT	0
236595	232945	08018U	PARTICIPANT	\N	PRESENT	0
236597	232945	95015C	PARTICIPANT	\N	PRESENT	0
236600	232945	14173T	PARTICIPANT	\N	PRESENT	0
236601	232945	19573D	PARTICIPANT	\N	PRESENT	0
236602	232945	98005N	PARTICIPANT	\N	PRESENT	0
236603	232945	14119M	PARTICIPANT	\N	PRESENT	0
236604	232945	11010L	PARTICIPANT	\N	PRESENT	0
236605	232945	19667J	PARTICIPANT	\N	PRESENT	0
236606	232945	19515S	PARTICIPANT	\N	PRESENT	0
236607	232945	14191V	PARTICIPANT	\N	PRESENT	0
236608	232945	11080N	PARTICIPANT	\N	PRESENT	0
236609	232945	04033B	PARTICIPANT	\N	PRESENT	0
236610	232945	19643A	PARTICIPANT	\N	PRESENT	0
236611	232945	10015M	PARTICIPANT	\N	PRESENT	0
236612	232945	08028W	PARTICIPANT	\N	PRESENT	0
236613	232945	01057W	PARTICIPANT	\N	PRESENT	0
236614	232945	08015R	PARTICIPANT	\N	PRESENT	0
236615	232945	08062Y	PARTICIPANT	\N	PRESENT	0
236616	232945	14147R	PARTICIPANT	\N	PRESENT	0
236617	232945	19671E	PARTICIPANT	\N	PRESENT	0
236618	232945	19399H	PARTICIPANT	\N	PRESENT	0
236619	232945	19729F	PARTICIPANT	\N	PRESENT	0
236620	232945	14213J	PARTICIPANT	\N	PRESENT	0
236621	236072	19503N	PARTICIPANT	\N	PRESENT	0
236622	232945	14187A	PARTICIPANT	\N	PRESENT	0
236623	232945	08047A	PARTICIPANT	\N	PRESENT	0
213131	213130	14173T	PARTICIPANT	\N	PRESENT	0
214552	214551	04049K	PARTICIPANT	\N	PRESENT	0
214554	214553	99004R	PARTICIPANT	\N	PRESENT	0
214556	214555	99004R	PARTICIPANT	\N	PRESENT	0
214573	214572	19647E	PARTICIPANT	\N	PRESENT	0
214578	214577	19647E	PARTICIPANT	\N	PRESENT	0
214580	214579	19647E	PARTICIPANT	\N	PRESENT	0
214582	214581	08010L	PARTICIPANT	\N	PRESENT	0
215864	205652	19709B	PARTICIPANT	\N	PRESENT	0
216231	215602	08034U	PARTICIPANT	\N	EXCUSE	0
216248	215602	14071N	PARTICIPANT	\N	PRESENT	0
216294	215602	04040A	PRESIDENT	0	PRESENT	0
217407	217406	04086Q	PARTICIPANT	\N	PRESENT	0
217409	217408	89017R	PARTICIPANT	\N	PRESENT	0
217413	217412	12016W	PARTICIPANT	\N	PRESENT	0
217417	217416	12016W	PARTICIPANT	\N	PRESENT	0
217430	217429	07029T	PARTICIPANT	\N	PRESENT	0
217442	217439	11048N	PARTICIPANT	\N	PRESENT	0
217445	217444	11048N	PARTICIPANT	\N	PRESENT	0
223858	223289	19663E	PARTICIPANT	\N	PRESENT	0
223859	223289	14213J	PARTICIPANT	\N	PRESENT	0
223860	223694	14331P	PARTICIPANT	\N	PRESENT	0
223861	223694	11048N	PARTICIPANT	\N	PRESENT	0
223862	223694	19647E	PARTICIPANT	\N	PRESENT	0
223863	223694	19711U	PARTICIPANT	\N	PRESENT	0
223864	223694	08034U	PARTICIPANT	\N	PRESENT	0
223865	223694	19651A	PARTICIPANT	\N	PRESENT	0
223866	223694	08011M	PARTICIPANT	\N	PRESENT	0
223867	223694	11074Q	PRESIDENT	0	PRESENT	0
223868	223694	08014Q	PARTICIPANT	\N	PRESENT	0
223869	223694	19671E	PARTICIPANT	\N	PRESENT	0
223870	223694	14225N	PARTICIPANT	\N	PRESENT	0
223871	223694	88008L	PARTICIPANT	\N	PRESENT	0
223872	223694	14173T	PARTICIPANT	\N	PRESENT	0
223873	223694	04086Q	PARTICIPANT	\N	PRESENT	0
223874	223694	11040E	PARTICIPANT	\N	PRESENT	0
223875	223694	07029T	PARTICIPANT	\N	PRESENT	0
223876	223694	14083S	PARTICIPANT	\N	PRESENT	0
223877	223694	14199E	PARTICIPANT	\N	PRESENT	0
223878	223694	11012A	PARTICIPANT	\N	PRESENT	0
223879	223694	14085U	PARTICIPANT	\N	PRESENT	0
223880	223694	14277B	PARTICIPANT	\N	PRESENT	0
223881	223694	08073C	PARTICIPANT	\N	PRESENT	0
223882	223694	19349W	PARTICIPANT	\N	PRESENT	0
223883	223694	99004R	PARTICIPANT	\N	PRESENT	0
223884	223694	14327T	PARTICIPANT	\N	EXCUSE	0
223885	223694	95041E	PARTICIPANT	\N	EXCUSE	0
223886	223289	19415P	PARTICIPANT	\N	PRESENT	0
223887	223289	19527W	PARTICIPANT	\N	PRESENT	0
223888	223289	14026U	PARTICIPANT	\N	PRESENT	0
223889	223289	01034P	PARTICIPANT	\N	PRESENT	0
223892	223694	01057W	PARTICIPANT	\N	PRESENT	0
223893	223694	11053K	PARTICIPANT	\N	PRESENT	0
223894	223694	19479G	PARTICIPANT	\N	PRESENT	0
223895	223694	14034U	PARTICIPANT	\N	PRESENT	0
223896	223265	19581D	PARTICIPANT	\N	PRESENT	0
223897	223265	04044E	PARTICIPANT	\N	PRESENT	0
223898	223265	19585H	PARTICIPANT	\N	PRESENT	0
223899	223265	04047H	PARTICIPANT	\N	PRESENT	0
223900	223265	19673G	PARTICIPANT	\N	PRESENT	0
223901	223265	01028R	PARTICIPANT	\N	PRESENT	0
223902	223265	19447X	PARTICIPANT	\N	PRESENT	0
223903	223265	05008E	PRESIDENT	0	PRESENT	0
223904	223265	14231L	PARTICIPANT	\N	PRESENT	0
223905	223265	19489J	PARTICIPANT	\N	PRESENT	0
223906	223265	14275Y	PARTICIPANT	\N	PRESENT	0
223907	223265	14147R	PARTICIPANT	\N	PRESENT	0
223908	223265	14179A	PARTICIPANT	\N	PRESENT	0
223909	223265	08010L	PARTICIPANT	\N	PRESENT	0
223910	223265	14151M	PARTICIPANT	\N	PRESENT	0
223911	223265	14215L	PARTICIPANT	\N	PRESENT	0
223912	223265	14259Y	PARTICIPANT	\N	PRESENT	0
223913	223265	11072N	PARTICIPANT	\N	PRESENT	0
223914	223265	14053L	PARTICIPANT	\N	PRESENT	0
223915	223265	19649G	PARTICIPANT	\N	PRESENT	0
223916	223265	14065Q	PARTICIPANT	\N	PRESENT	0
223917	223265	14111D	PARTICIPANT	\N	PRESENT	0
223918	223265	07034Q	PARTICIPANT	\N	PRESENT	0
223919	223265	08045X	PARTICIPANT	\N	PRESENT	0
223920	223265	11026G	PARTICIPANT	\N	PRESENT	0
223921	223265	19253P	PARTICIPANT	\N	PRESENT	0
223922	223265	01024M	PARTICIPANT	\N	PRESENT	0
223923	223265	19719D	PARTICIPANT	\N	PRESENT	0
223924	223265	19725B	PARTICIPANT	\N	PRESENT	0
223925	223265	14041T	PARTICIPANT	\N	PRESENT	0
223931	218295	04059M	PARTICIPANT	\N	PRESENT	0
223932	218295	11074Q	PARTICIPANT	\N	PRESENT	0
223933	218295	08011M	PARTICIPANT	\N	PRESENT	0
223934	218295	11040E	PARTICIPANT	\N	PRESENT	0
223935	218295	19687N	PARTICIPANT	\N	PRESENT	0
223936	218295	14235Q	PARTICIPANT	\N	PRESENT	0
223937	218295	19593H	PARTICIPANT	\N	PRESENT	0
223938	218295	14121F	PARTICIPANT	\N	PRESENT	0
223939	218295	14085U	PARTICIPANT	\N	PRESENT	0
223940	218295	11067R	PARTICIPANT	\N	PRESENT	0
223941	218295	19631V	PARTICIPANT	\N	PRESENT	0
223942	218295	19725B	PARTICIPANT	\N	PRESENT	0
223943	218295	19489J	PARTICIPANT	\N	PRESENT	0
223944	218295	19347U	PARTICIPANT	\N	PRESENT	0
223945	218295	14225N	PARTICIPANT	\N	PRESENT	0
223946	218295	11027H	PARTICIPANT	\N	PRESENT	0
223947	218295	08052W	PARTICIPANT	\N	PRESENT	0
223948	218295	01062T	PARTICIPANT	\N	PRESENT	0
223949	218295	08038Y	PARTICIPANT	\N	PRESENT	0
223950	218295	19525U	PARTICIPANT	\N	PRESENT	0
223951	218295	19651A	PARTICIPANT	\N	PRESENT	0
223952	218295	19349W	PARTICIPANT	\N	PRESENT	0
223953	218295	95041E	PARTICIPANT	\N	PRESENT	0
223954	218295	19253P	PARTICIPANT	\N	PRESENT	0
223955	218295	19629C	PARTICIPANT	\N	PRESENT	0
223956	218295	19479G	PARTICIPANT	\N	PRESENT	0
223957	218295	19545Y	PARTICIPANT	\N	PRESENT	0
223958	218295	19681G	PARTICIPANT	\N	PRESENT	0
223959	218295	08012N	PARTICIPANT	\N	PRESENT	0
223960	218295	19531S	PARTICIPANT	\N	PRESENT	0
223961	218295	19591F	PARTICIPANT	\N	PRESENT	0
223962	218295	19553Y	PARTICIPANT	\N	PRESENT	0
223963	218295	14241N	PARTICIPANT	\N	PRESENT	0
223964	218295	19737F	PARTICIPANT	\N	PRESENT	0
223965	218295	14103D	PARTICIPANT	\N	PRESENT	0
223966	218295	14327T	PARTICIPANT	\N	PRESENT	0
223967	218295	14215L	PARTICIPANT	\N	PRESENT	0
223968	218295	04044E	PARTICIPANT	\N	PRESENT	0
223969	218295	17637T	PARTICIPANT	\N	PRESENT	0
223970	218295	19711U	PARTICIPANT	\N	PRESENT	0
223971	218295	99004R	PARTICIPANT	\N	PRESENT	0
223972	218295	14157T	PARTICIPANT	\N	PRESENT	0
223973	218295	14123H	PARTICIPANT	\N	PRESENT	0
223974	218295	04043D	PARTICIPANT	\N	PRESENT	0
223975	218295	07034Q	PARTICIPANT	\N	PRESENT	0
223976	218295	19731Y	PARTICIPANT	\N	PRESENT	0
223977	218295	14059S	PARTICIPANT	\N	PRESENT	0
223978	218295	14061L	PARTICIPANT	\N	PRESENT	0
223979	218295	14357A	PARTICIPANT	\N	PRESENT	0
223981	218295	15447F	PARTICIPANT	\N	PRESENT	0
223982	218295	14191V	PARTICIPANT	\N	PRESENT	0
223983	218295	19667J	PARTICIPANT	\N	PRESENT	0
223984	218295	19703U	PARTICIPANT	\N	PRESENT	0
223985	218295	19673G	PARTICIPANT	\N	PRESENT	0
223986	218295	19447X	PARTICIPANT	\N	PRESENT	0
223987	218295	19467C	PARTICIPANT	\N	PRESENT	0
223988	218295	14033T	PARTICIPANT	\N	PRESENT	0
223989	218295	04088S	PARTICIPANT	\N	PRESENT	0
223990	218295	19643A	PARTICIPANT	\N	PRESENT	0
223991	218295	14029X	PARTICIPANT	\N	PRESENT	0
223992	218295	19443T	PARTICIPANT	\N	PRESENT	0
223993	218295	07029T	PARTICIPANT	\N	PRESENT	0
223994	218295	04086Q	PARTICIPANT	\N	PRESENT	0
223995	218295	01043Q	PARTICIPANT	\N	PRESENT	0
223996	218295	07004J	PARTICIPANT	\N	PRESENT	0
223997	218295	14275Y	PARTICIPANT	\N	PRESENT	0
223998	218295	14267Y	PARTICIPANT	\N	PRESENT	0
223999	218295	98022P	PARTICIPANT	\N	PRESENT	0
224000	218295	19599P	PARTICIPANT	\N	PRESENT	0
224001	218295	14107H	PARTICIPANT	\N	PRESENT	0
224002	218295	14065Q	PARTICIPANT	\N	PRESENT	0
224003	218295	14081Q	PARTICIPANT	\N	PRESENT	0
224004	218295	80027E	PARTICIPANT	\N	PRESENT	0
224005	218295	11054L	PARTICIPANT	\N	PRESENT	0
224006	218295	19683J	PARTICIPANT	\N	PRESENT	0
224007	218295	14257W	PARTICIPANT	\N	PRESENT	0
224008	218295	11065P	PARTICIPANT	\N	PRESENT	0
224009	218295	19713W	PARTICIPANT	\N	PRESENT	0
224010	218295	19441R	PARTICIPANT	\N	PRESENT	0
224011	218295	11064N	PARTICIPANT	\N	PRESENT	0
224012	218295	19387D	PARTICIPANT	\N	PRESENT	0
224013	218295	19719D	PARTICIPANT	\N	PRESENT	0
224015	218295	08068F	PARTICIPANT	\N	PRESENT	0
224016	218295	19671E	PARTICIPANT	\N	PRESENT	0
225361	225360	19553Y	PARTICIPANT	\N	PRESENT	0
225362	225360	01048V	PARTICIPANT	\N	PRESENT	0
225363	225360	14221J	PARTICIPANT	\N	PRESENT	0
225364	225360	01058X	PARTICIPANT	\N	PRESENT	0
225376	225373	19663E	PARTICIPANT	\N	PRESENT	0
225383	225373	04043D	PARTICIPANT	\N	PRESENT	0
225381	225373	14221J	PARTICIPANT	\N	PRESENT	0
225382	225373	19533U	PARTICIPANT	\N	PRESENT	0
225384	225373	01058X	PARTICIPANT	\N	PRESENT	0
225985	223667	11033F	PARTICIPANT	\N	PRESENT	0
225986	223667	19629C	PARTICIPANT	\N	PRESENT	0
225987	223667	19543W	PARTICIPANT	\N	PRESENT	0
225988	223667	11045K	PARTICIPANT	\N	PRESENT	0
225990	225989	19585H	PARTICIPANT	\N	PRESENT	0
225991	225989	19629C	PARTICIPANT	\N	PRESENT	0
225992	225989	14147R	PARTICIPANT	\N	PRESENT	0
225993	225989	19649G	PARTICIPANT	\N	PRESENT	0
225994	225989	14215L	PARTICIPANT	\N	PRESENT	0
225995	225989	19581D	PARTICIPANT	\N	PRESENT	0
226017	226015	11049P	PARTICIPANT	\N	PRESENT	0
226022	226015	04085P	PARTICIPANT	\N	PRESENT	0
226036	226035	14089Y	PARTICIPANT	\N	PRESENT	0
226039	226038	14089Y	PARTICIPANT	\N	PRESENT	0
226145	226144	14034U	PARTICIPANT	\N	PRESENT	0
226147	226146	14034U	PARTICIPANT	\N	PRESENT	0
226149	226148	19647E	PARTICIPANT	\N	PRESENT	0
226150	226148	11070L	PARTICIPANT	\N	PRESENT	0
226152	226151	04086Q	PARTICIPANT	\N	PRESENT	0
226524	226080	19651A	PARTICIPANT	\N	PRESENT	0
226525	226080	04086Q	PARTICIPANT	\N	PRESENT	0
226526	226080	11070L	PARTICIPANT	\N	PRESENT	0
226527	226080	11074Q	PRESIDENT	0	PRESENT	0
226528	226080	99004R	PARTICIPANT	\N	PRESENT	0
226529	226080	19711U	PARTICIPANT	\N	PRESENT	0
226530	226080	08010L	PARTICIPANT	\N	PRESENT	0
226531	226080	14225N	PARTICIPANT	\N	PRESENT	0
226532	226080	19689Q	PARTICIPANT	\N	PRESENT	0
226533	226080	19667J	PARTICIPANT	\N	EXCUSE	0
226534	226080	14327T	PARTICIPANT	\N	EXCUSE	0
226628	218821	11056N	PARTICIPANT	\N	PRESENT	0
226536	221543	14038Y	PARTICIPANT	\N	EXCUSE	0
226537	221543	19583F	PARTICIPANT	\N	EXCUSE	0
226538	221543	11010L	PARTICIPANT	\N	EXCUSE	0
226539	226080	07029T	PARTICIPANT	\N	EXCUSE	0
226661	218821	19651A	PARTICIPANT	\N	PRESENT	0
226664	218441	19415P	PARTICIPANT	\N	PRESENT	0
226665	218441	14267Y	PARTICIPANT	\N	PRESENT	0
226666	218441	08058D	PARTICIPANT	\N	PRESENT	0
226669	218441	14179A	PARTICIPANT	\N	PRESENT	0
226670	225222	04061F	PARTICIPANT	\N	EXCUSE	0
226671	218441	14237S	PARTICIPANT	\N	PRESENT	0
226672	218441	14105F	PARTICIPANT	\N	PRESENT	0
226673	218441	08010L	PARTICIPANT	\N	PRESENT	0
226674	218441	19269X	PARTICIPANT	\N	PRESENT	0
226675	218441	14073Q	PARTICIPANT	\N	PRESENT	0
226717	218441	11104D	PARTICIPANT	\N	PRESENT	0
226677	218441	98022P	PARTICIPANT	\N	PRESENT	0
226678	218441	14039A	PARTICIPANT	\N	PRESENT	0
226679	218441	19421M	PARTICIPANT	\N	PRESENT	0
226680	218441	01024M	PARTICIPANT	\N	PRESENT	0
226681	218441	19741B	PARTICIPANT	\N	PRESENT	0
226682	218441	08017T	PARTICIPANT	\N	PRESENT	0
226683	218441	19531S	PARTICIPANT	\N	PRESENT	0
226684	226198	11097X	PARTICIPANT	\N	PRESENT	0
226685	226198	19527W	PARTICIPANT	\N	PRESENT	0
226686	226198	19657G	PARTICIPANT	\N	PRESENT	0
226687	226198	19577H	PARTICIPANT	\N	PRESENT	0
226688	218441	19511N	PARTICIPANT	\N	PRESENT	0
226692	218441	95030B	PARTICIPANT	\N	PRESENT	0
226690	226198	19569H	PARTICIPANT	\N	PRESENT	0
226691	218441	08047A	PARTICIPANT	\N	PRESENT	0
226693	218441	19739H	PARTICIPANT	\N	PRESENT	0
226694	218441	14329V	PARTICIPANT	\N	PRESENT	0
226695	218441	98050T	PARTICIPANT	\N	PRESENT	0
226696	218441	14085U	PARTICIPANT	\N	PRESENT	0
226697	218441	14225N	PARTICIPANT	\N	PRESENT	0
226698	218441	11049P	PARTICIPANT	\N	PRESENT	0
226699	218441	19725B	PARTICIPANT	\N	PRESENT	0
226700	218441	08016S	PARTICIPANT	\N	PRESENT	0
226701	218441	08020N	PARTICIPANT	\N	PRESENT	0
226702	218441	19515S	PARTICIPANT	\N	PRESENT	0
226703	218441	19563B	PARTICIPANT	\N	PRESENT	0
226704	218441	14103D	PARTICIPANT	\N	PRESENT	0
226705	218441	14241N	PARTICIPANT	\N	PRESENT	0
226706	218441	14135M	PARTICIPANT	\N	PRESENT	0
226707	218441	19689Q	PARTICIPANT	\N	PRESENT	0
226708	218441	14031R	PARTICIPANT	\N	PRESENT	0
226709	218441	14205J	PARTICIPANT	\N	PRESENT	0
226710	218441	19413M	PARTICIPANT	\N	PRESENT	0
226711	218441	19467C	PARTICIPANT	\N	PRESENT	0
226712	218441	14157T	PARTICIPANT	\N	PRESENT	0
226713	218441	11070L	PARTICIPANT	\N	PRESENT	0
226714	218441	14083S	PARTICIPANT	\N	PRESENT	0
226715	218441	19387D	PARTICIPANT	\N	PRESENT	0
226716	218441	08068F	PARTICIPANT	\N	PRESENT	0
226718	218441	14207L	PARTICIPANT	\N	PRESENT	0
226719	218441	19525U	PARTICIPANT	\N	PRESENT	0
226720	218441	19551W	PARTICIPANT	\N	PRESENT	0
226740	225222	19663E	PARTICIPANT	\N	PRESENT	0
226741	225222	04043D	PARTICIPANT	\N	PRESENT	0
227497	218821	08069G	PARTICIPANT	\N	PRESENT	0
227613	221543	14259Y	PARTICIPANT	\N	EXCUSE	0
227620	225954	80013X	PARTICIPANT	\N	PRESENT	0
227621	225954	08053X	PARTICIPANT	\N	PRESENT	0
227784	227783	95037J	PARTICIPANT	\N	PRESENT	0
227785	227783	14221J	PARTICIPANT	\N	PRESENT	0
227910	226349	19489J	PARTICIPANT	\N	PRESENT	0
227912	226349	14063N	PARTICIPANT	\N	PRESENT	0
227913	226349	19565D	PARTICIPANT	\N	PRESENT	0
227914	226349	14259Y	PARTICIPANT	\N	PRESENT	0
227915	226349	19735D	PARTICIPANT	\N	PRESENT	0
227916	226349	14103D	PARTICIPANT	\N	PRESENT	0
227917	226349	14069U	PARTICIPANT	\N	PRESENT	0
227918	227827	19515S	PARTICIPANT	\N	EXCUSE	0
227919	227827	11097X	PARTICIPANT	\N	EXCUSE	0
227920	227827	14147R	PARTICIPANT	\N	EXCUSE	0
227921	227827	08012N	PARTICIPANT	\N	PRESENT	0
227922	227827	99004R	PRESIDENT	0	PRESENT	0
227940	227939	11083R	PARTICIPANT	\N	PRESENT	0
227941	227939	95030B	PARTICIPANT	\N	PRESENT	0
227942	227939	96004D	PARTICIPANT	\N	PRESENT	0
227943	227939	14237S	PARTICIPANT	\N	PRESENT	0
227944	227939	14221J	PARTICIPANT	\N	PRESENT	0
227946	227945	10006L	PARTICIPANT	\N	PRESENT	0
227947	227945	08031R	PARTICIPANT	\N	PRESENT	0
227948	227945	04070G	PARTICIPANT	\N	PRESENT	0
227949	227945	80027E	PARTICIPANT	\N	PRESENT	0
227950	227945	14255U	PARTICIPANT	\N	PRESENT	0
228104	228101	14089Y	PARTICIPANT	\N	PRESENT	0
228308	228307	11074Q	PARTICIPANT	\N	PRESENT	0
228309	228307	08011M	PARTICIPANT	\N	PRESENT	0
228907	228906	04042C	PARTICIPANT	\N	PRESENT	0
228908	228906	14193X	PARTICIPANT	\N	PRESENT	0
228909	228906	08056B	PARTICIPANT	\N	PRESENT	0
228910	228906	14267Y	PARTICIPANT	\N	PRESENT	0
228911	228906	14133K	PARTICIPANT	\N	PRESENT	0
228912	228906	08047A	PARTICIPANT	\N	PRESENT	0
228913	228906	98029W	PARTICIPANT	\N	PRESENT	0
228914	228906	98022P	PARTICIPANT	\N	PRESENT	0
228915	228906	19669L	PARTICIPANT	\N	PRESENT	0
228916	228906	11054L	PARTICIPANT	\N	PRESENT	0
228917	228906	11027H	PARTICIPANT	\N	PRESENT	0
228918	228906	11064N	PARTICIPANT	\N	PRESENT	0
228919	228906	98018T	PARTICIPANT	\N	PRESENT	0
228921	228920	04042C	PARTICIPANT	\N	PRESENT	0
228922	228920	14133K	PARTICIPANT	\N	PRESENT	0
228923	228920	98029W	PARTICIPANT	\N	PRESENT	0
228924	228920	14267Y	PARTICIPANT	\N	PRESENT	0
228925	228920	11027H	PARTICIPANT	\N	PRESENT	0
228926	228920	04035D	PARTICIPANT	\N	PRESENT	0
228927	228920	08056B	PARTICIPANT	\N	PRESENT	0
228928	228920	98022P	PARTICIPANT	\N	PRESENT	0
228929	228920	11064N	PARTICIPANT	\N	PRESENT	0
228930	228920	08047A	PARTICIPANT	\N	PRESENT	0
228931	228920	14193X	PARTICIPANT	\N	PRESENT	0
228932	228920	11054L	PARTICIPANT	\N	PRESENT	0
228934	228933	04042C	PARTICIPANT	\N	PRESENT	0
212052	210153	89017R	PARTICIPANT	\N	PRESENT	0
212053	210153	19575F	PARTICIPANT	\N	PRESENT	0
212054	210153	14030Q	PARTICIPANT	\N	PRESENT	0
212055	210153	08060W	PARTICIPANT	\N	EXCUSE	0
212056	210153	14105F	PARTICIPANT	\N	PRESENT	0
212057	210153	08068F	PARTICIPANT	\N	PRESENT	0
212058	210153	14255U	PARTICIPANT	\N	PRESENT	0
212059	210153	14053L	PARTICIPANT	\N	EXCUSE	0
212060	210153	14083S	PARTICIPANT	\N	PRESENT	0
212061	210153	14329V	PARTICIPANT	\N	PRESENT	0
212062	210153	11031D	PARTICIPANT	\N	PRESENT	0
212063	210153	14079W	PARTICIPANT	\N	PRESENT	0
212064	210153	14041T	PARTICIPANT	\N	EXCUSE	0
212065	210153	14151M	PARTICIPANT	\N	EXCUSE	0
212066	210153	14187A	PARTICIPANT	\N	PRESENT	0
212067	210153	14087W	PARTICIPANT	\N	PRESENT	0
212068	210153	19521Q	PARTICIPANT	\N	PRESENT	0
212069	210153	14034U	PARTICIPANT	\N	EXCUSE	0
212070	210153	19695N	PARTICIPANT	\N	PRESENT	0
212071	210153	14026U	PARTICIPANT	\N	PRESENT	0
212072	210153	19591F	PARTICIPANT	\N	PRESENT	0
212073	210153	14121F	PARTICIPANT	\N	PRESENT	0
212074	210153	14039A	PARTICIPANT	\N	EXCUSE	0
212075	210153	14061L	PARTICIPANT	\N	EXCUSE	0
212077	210153	11099A	PARTICIPANT	\N	PRESENT	0
212079	210153	04049K	PRESIDENT	0	PRESENT	0
212081	210153	08015R	PARTICIPANT	\N	PRESENT	0
212086	210153	16685X	PARTICIPANT	\N	PRESENT	0
212088	210153	14205J	PARTICIPANT	\N	PRESENT	0
212090	210153	19671E	PARTICIPANT	\N	PRESENT	0
212093	210153	14265W	PARTICIPANT	\N	PRESENT	0
212095	210153	14253S	PARTICIPANT	\N	PRESENT	0
212098	210153	08047A	PARTICIPANT	\N	EXCUSE	0
212100	210153	04088S	PARTICIPANT	\N	EXCUSE	0
212101	210153	19669L	PARTICIPANT	\N	EXCUSE	0
212102	210153	14051J	PARTICIPANT	\N	PRESENT	0
212103	210153	14227Q	PARTICIPANT	\N	PRESENT	0
212107	210153	19527W	PARTICIPANT	\N	EXCUSE	0
212110	210153	14157T	PARTICIPANT	\N	EXCUSE	0
212112	210153	04034C	PARTICIPANT	\N	PRESENT	0
212115	212114	95067Q	PARTICIPANT	\N	PRESENT	0
212143	212117	14065Q	PARTICIPANT	\N	EXCUSE	0
212144	212117	14061L	PARTICIPANT	\N	EXCUSE	0
212145	212117	14135M	PARTICIPANT	\N	EXCUSE	0
213264	205652	04043D	PARTICIPANT	\N	PRESENT	0
213265	205652	19533U	PARTICIPANT	\N	PRESENT	0
222238	218821	11097X	PARTICIPANT	\N	PRESENT	0
223679	223678	14033T	PARTICIPANT	\N	PRESENT	0
223683	223682	11083R	PARTICIPANT	\N	PRESENT	0
223684	223682	14042U	PARTICIPANT	\N	PRESENT	0
238874	238873	04089T	PARTICIPANT	\N	PRESENT	0
238875	238873	14187A	PARTICIPANT	\N	PRESENT	0
238877	238876	14187A	PARTICIPANT	\N	PRESENT	0
239122	238968	08043V	PARTICIPANT	\N	PRESENT	0
239123	238968	19749K	PARTICIPANT	\N	PRESENT	0
239124	238968	14030Q	PARTICIPANT	\N	PRESENT	0
239125	238968	08031R	PARTICIPANT	\N	PRESENT	0
240206	240203	14069U	PARTICIPANT	\N	PRESENT	0
240207	240203	04038G	PARTICIPANT	\N	PRESENT	0
240208	240203	11027H	PARTICIPANT	\N	PRESENT	0
240209	240203	14357A	PARTICIPANT	\N	PRESENT	0
240210	240203	19525U	PARTICIPANT	\N	PRESENT	0
240211	240203	11065P	PARTICIPANT	\N	PRESENT	0
240212	240203	14281W	PARTICIPANT	\N	PRESENT	0
240213	240203	19731Y	PARTICIPANT	\N	PRESENT	0
240215	240203	08017T	PARTICIPANT	\N	PRESENT	0
240216	240203	08009T	PARTICIPANT	\N	PRESENT	0
240217	240214	04092N	PARTICIPANT	\N	PRESENT	0
240218	240214	14071N	PARTICIPANT	\N	PRESENT	0
240219	240214	19521Q	PARTICIPANT	\N	PRESENT	0
240220	240214	14227Q	PARTICIPANT	\N	PRESENT	0
240221	240214	19727D	PARTICIPANT	\N	PRESENT	0
240222	240214	04045F	PARTICIPANT	\N	PRESENT	0
240223	240214	19717B	PARTICIPANT	\N	PRESENT	0
240224	240214	14026U	PARTICIPANT	\N	PRESENT	0
240225	240203	19415P	PARTICIPANT	\N	PRESENT	0
240226	240203	19347U	PARTICIPANT	\N	PRESENT	0
240273	239668	17583W	PARTICIPANT	\N	PRESENT	0
240274	239668	14213J	PARTICIPANT	\N	PRESENT	0
240275	239668	08039A	PARTICIPANT	\N	PRESENT	0
240308	239668	19713W	PARTICIPANT	\N	PRESENT	0
240311	239668	19483C	PARTICIPANT	\N	PRESENT	0
240312	239668	14026U	PARTICIPANT	\N	PRESENT	0
240314	239668	11064N	PARTICIPANT	\N	PRESENT	0
240333	239668	18083K	PARTICIPANT	\N	PRESENT	0
240334	239668	19507S	PARTICIPANT	\N	PRESENT	0
240335	239668	19383Y	PARTICIPANT	\N	PRESENT	0
240336	239668	14231L	PARTICIPANT	\N	PRESENT	0
240338	239668	08034U	PARTICIPANT	\N	PRESENT	0
240340	240339	19515S	PARTICIPANT	\N	PRESENT	0
240341	240339	19747H	PARTICIPANT	\N	PRESENT	0
240342	240339	18083K	PARTICIPANT	\N	PRESENT	0
240343	240339	14087W	PARTICIPANT	\N	PRESENT	0
240344	240339	08016S	PARTICIPANT	\N	PRESENT	0
240345	240339	14159V	PARTICIPANT	\N	PRESENT	0
240346	240339	16685X	PARTICIPANT	\N	PRESENT	0
240347	240339	17637T	PARTICIPANT	\N	PRESENT	0
240348	240339	14225N	PARTICIPANT	\N	PRESENT	0
240349	240339	14051J	PARTICIPANT	\N	PRESENT	0
240350	240339	14053L	PARTICIPANT	\N	PRESENT	0
240351	240339	08038Y	PARTICIPANT	\N	PRESENT	0
240352	240339	14151M	PARTICIPANT	\N	PRESENT	0
240353	240339	14231L	PARTICIPANT	\N	PRESENT	0
240354	240339	14081Q	PARTICIPANT	\N	PRESENT	0
240355	240339	12041X	PARTICIPANT	\N	PRESENT	0
240356	240339	08009T	PARTICIPANT	\N	PRESENT	0
240357	240339	14107H	PARTICIPANT	\N	PRESENT	0
240359	240358	19543W	PARTICIPANT	\N	PRESENT	0
240370	239669	04059M	PARTICIPANT	\N	PRESENT	0
240361	240358	14079W	PARTICIPANT	\N	PRESENT	0
240362	240358	14249W	PARTICIPANT	\N	PRESENT	0
240363	240358	97011G	PARTICIPANT	\N	PRESENT	0
240372	232547	08045X	PARTICIPANT	\N	PRESENT	0
240371	232547	08024S	PARTICIPANT	\N	PRESENT	0
240366	240358	19503N	PARTICIPANT	\N	PRESENT	0
240367	240358	11090Q	PARTICIPANT	\N	PRESENT	0
240368	240358	01058X	PARTICIPANT	\N	PRESENT	0
240369	240358	95067Q	PARTICIPANT	\N	PRESENT	0
240373	232547	19551W	PARTICIPANT	\N	PRESENT	0
240374	232547	19711U	PARTICIPANT	\N	PRESENT	0
240375	232547	19479G	PARTICIPANT	\N	PRESENT	0
240376	232875	19737F	PARTICIPANT	\N	PRESENT	0
240377	232875	19551W	PARTICIPANT	\N	PRESENT	0
240378	232875	08024S	PARTICIPANT	\N	PRESENT	0
240379	232875	19349W	PARTICIPANT	\N	PRESENT	0
240380	239669	04038G	PARTICIPANT	\N	PRESENT	0
240381	239669	14081Q	PARTICIPANT	\N	PRESENT	0
240382	239669	88008L	PARTICIPANT	\N	PRESENT	0
240383	239669	19441R	PARTICIPANT	\N	PRESENT	0
240384	239669	14219Q	PARTICIPANT	\N	PRESENT	0
240385	239669	08010L	PARTICIPANT	\N	PRESENT	0
240386	239669	11049P	PARTICIPANT	\N	PRESENT	0
240387	239669	19447X	PARTICIPANT	\N	PRESENT	0
240388	239669	19515S	PARTICIPANT	\N	PRESENT	0
240389	239669	14249W	PARTICIPANT	\N	PRESENT	0
240390	239669	04018C	PARTICIPANT	\N	PRESENT	0
240391	239669	07034Q	PARTICIPANT	\N	PRESENT	0
240392	239669	17583W	PARTICIPANT	\N	PRESENT	0
240393	239669	19629C	PARTICIPANT	\N	PRESENT	0
240394	239669	14261S	PARTICIPANT	\N	PRESENT	0
240395	239669	19387D	PARTICIPANT	\N	PRESENT	0
240396	239669	19543W	PARTICIPANT	\N	PRESENT	0
240397	239669	08068F	PARTICIPANT	\N	PRESENT	0
240398	239669	14065Q	PARTICIPANT	\N	PRESENT	0
240399	239669	14063N	PARTICIPANT	\N	PRESENT	0
240400	239669	14205J	PARTICIPANT	\N	PRESENT	0
240401	239669	14267Y	PARTICIPANT	\N	PRESENT	0
240402	239669	19415P	PARTICIPANT	\N	PRESENT	0
240403	239669	14069U	PARTICIPANT	\N	PRESENT	0
240404	239669	19565D	PARTICIPANT	\N	PRESENT	0
240405	239669	14265W	PARTICIPANT	\N	PRESENT	0
240406	239669	19711U	PARTICIPANT	\N	PRESENT	0
240407	239669	19747H	PARTICIPANT	\N	PRESENT	0
240408	239669	19507S	PARTICIPANT	\N	PRESENT	0
240409	239669	19741B	PARTICIPANT	\N	PRESENT	0
240410	239669	19731Y	PARTICIPANT	\N	PRESENT	0
240411	239669	14151M	PARTICIPANT	\N	PRESENT	0
240412	239669	14111D	PARTICIPANT	\N	PRESENT	0
240413	239669	19679N	PARTICIPANT	\N	PRESENT	0
240414	239669	14061L	PARTICIPANT	\N	PRESENT	0
240415	239669	14033T	PARTICIPANT	\N	PRESENT	0
240416	238562	14069U	PARTICIPANT	\N	PRESENT	0
240417	238562	19525U	PARTICIPANT	\N	PRESENT	0
240418	238562	04086Q	PARTICIPANT	\N	PRESENT	0
240419	238562	14259Y	PARTICIPANT	\N	PRESENT	0
240420	238562	14281W	PARTICIPANT	\N	PRESENT	0
236627	232945	04085P	PARTICIPANT	\N	PRESENT	0
236628	232945	11033F	PARTICIPANT	\N	PRESENT	0
236629	232945	11090Q	PARTICIPANT	\N	PRESENT	0
236630	232945	11031D	PARTICIPANT	\N	PRESENT	0
236631	232945	11040E	PARTICIPANT	\N	PRESENT	0
236632	232945	08020N	PARTICIPANT	\N	PRESENT	0
236633	232945	14157T	PARTICIPANT	\N	PRESENT	0
236634	232945	08039A	PARTICIPANT	\N	PRESENT	0
236635	232945	96004D	PARTICIPANT	\N	PRESENT	0
236636	232945	04038G	PARTICIPANT	\N	PRESENT	0
236637	232945	19695N	PARTICIPANT	\N	PRESENT	0
236638	232945	19347U	PARTICIPANT	\N	PRESENT	0
236639	232945	19565D	PARTICIPANT	\N	PRESENT	0
236640	232945	12041X	PARTICIPANT	\N	PRESENT	0
236641	232945	11063M	PARTICIPANT	\N	PRESENT	0
236642	232945	11043H	PARTICIPANT	\N	PRESENT	0
236643	232945	04008A	PARTICIPANT	\N	PRESENT	0
236644	232945	14211G	PARTICIPANT	\N	PRESENT	0
236645	232945	19687N	PARTICIPANT	\N	PRESENT	0
236646	232945	19593H	PARTICIPANT	\N	PRESENT	0
236647	232945	14235Q	PARTICIPANT	\N	PRESENT	0
236648	232945	07034Q	PARTICIPANT	\N	PRESENT	0
236649	232945	14239U	PARTICIPANT	\N	PRESENT	0
236650	232945	19651A	PARTICIPANT	\N	PRESENT	0
236652	232945	19543W	PARTICIPANT	\N	PRESENT	0
236653	232945	19659J	PARTICIPANT	\N	PRESENT	0
236654	232945	98050T	PARTICIPANT	\N	PRESENT	0
236655	232945	14061L	PARTICIPANT	\N	PRESENT	0
236656	232945	14059S	PARTICIPANT	\N	PRESENT	0
236658	232945	14055N	PARTICIPANT	\N	PRESENT	0
236659	232945	95037J	PARTICIPANT	\N	PRESENT	0
236660	232945	19731Y	PARTICIPANT	\N	PRESENT	0
236661	232945	14039A	PARTICIPANT	\N	PRESENT	0
236662	232945	19697Q	PARTICIPANT	\N	PRESENT	0
236663	232945	14329V	PARTICIPANT	\N	PRESENT	0
236664	232945	19637C	PARTICIPANT	\N	PRESENT	0
236665	232945	14357A	PARTICIPANT	\N	PRESENT	0
236666	232945	11072N	PARTICIPANT	\N	PRESENT	0
236667	232945	08021P	PARTICIPANT	\N	PRESENT	0
236668	232945	19733B	PARTICIPANT	\N	PRESENT	0
236669	232945	08073C	PARTICIPANT	\N	PRESENT	0
236670	232945	19383Y	PARTICIPANT	\N	PRESENT	0
236671	232945	19483C	PARTICIPANT	\N	PRESENT	0
236672	232945	08061X	PARTICIPANT	\N	PRESENT	0
236673	232945	19349W	PARTICIPANT	\N	PRESENT	0
236674	232945	19269X	PARTICIPANT	\N	PRESENT	0
236675	232945	11103C	PARTICIPANT	\N	PRESENT	0
236676	232945	04045F	PARTICIPANT	\N	PRESENT	0
236677	232945	89017R	PARTICIPANT	\N	PRESENT	0
236678	232945	19685L	PARTICIPANT	\N	PRESENT	0
236679	232945	01060R	PARTICIPANT	\N	PRESENT	0
236680	232945	07033P	PARTICIPANT	\N	PRESENT	0
236681	232945	14261S	PARTICIPANT	\N	PRESENT	0
236682	232945	10006L	PARTICIPANT	\N	PRESENT	0
236683	232945	19717B	PARTICIPANT	\N	PRESENT	0
236684	232945	19533U	PARTICIPANT	\N	PRESENT	0
236685	232945	88008L	PARTICIPANT	\N	PRESENT	0
236686	232945	14034U	PARTICIPANT	\N	PRESENT	0
236687	232945	11012A	PARTICIPANT	\N	PRESENT	0
236688	232945	08049C	PARTICIPANT	\N	PRESENT	0
236689	232945	14053L	PARTICIPANT	\N	PRESENT	0
236690	232945	19629C	PARTICIPANT	\N	PRESENT	0
236691	232945	14071N	PARTICIPANT	\N	PRESENT	0
236692	232945	19563B	PARTICIPANT	\N	PRESENT	0
236693	232945	05008E	PARTICIPANT	\N	PRESENT	0
236694	232945	98022P	PARTICIPANT	\N	PRESENT	0
236695	232945	14241N	PARTICIPANT	\N	PRESENT	0
236696	232945	11097X	PARTICIPANT	\N	PRESENT	0
236697	232945	14201E	PARTICIPANT	\N	PRESENT	0
236698	232945	19421M	PARTICIPANT	\N	PRESENT	0
236624	232945	14033T	PARTICIPANT	\N	PRESENT	0
236625	232945	14253S	PARTICIPANT	\N	PRESENT	0
236699	232945	19387D	PARTICIPANT	\N	PRESENT	0
236700	232945	19719D	PARTICIPANT	\N	PRESENT	0
236701	232945	19681G	PARTICIPANT	\N	PRESENT	0
236702	232945	04070G	PARTICIPANT	\N	PRESENT	0
236703	232945	11099A	PARTICIPANT	\N	PRESENT	0
236704	232945	04040A	PARTICIPANT	\N	PRESENT	0
236705	232945	11065P	PARTICIPANT	\N	PRESENT	0
236706	232945	19577H	PARTICIPANT	\N	PRESENT	0
236707	232945	14215L	PARTICIPANT	\N	PRESENT	0
236708	232945	19253P	PARTICIPANT	\N	PRESENT	0
236709	232945	19553Y	PARTICIPANT	\N	PRESENT	0
236710	232945	14087W	PARTICIPANT	\N	PRESENT	0
236711	232945	08031R	PARTICIPANT	\N	PRESENT	0
236712	232945	14237S	PARTICIPANT	\N	PRESENT	0
236713	232945	17583W	PARTICIPANT	\N	PRESENT	0
236714	232945	19289C	PARTICIPANT	\N	PRESENT	0
236715	232945	19581D	PARTICIPANT	\N	PRESENT	0
236716	232945	19747H	PARTICIPANT	\N	PRESENT	0
236717	232945	19367Y	PARTICIPANT	\N	PRESENT	0
236718	232945	19621T	PARTICIPANT	\N	PRESENT	0
236719	232945	19545Y	PARTICIPANT	\N	PRESENT	0
236720	232945	14195A	PARTICIPANT	\N	PRESENT	0
236721	232945	17589D	PARTICIPANT	\N	PRESENT	0
236722	232945	04018C	PARTICIPANT	\N	PRESENT	0
236723	232945	02002K	PARTICIPANT	\N	PRESENT	0
236724	232945	19585H	PARTICIPANT	\N	PRESENT	0
236725	232945	04057K	PARTICIPANT	\N	PRESENT	0
236726	232945	14251Q	PARTICIPANT	\N	PRESENT	0
236727	232945	14111D	PARTICIPANT	\N	PRESENT	0
236728	232945	19583F	PARTICIPANT	\N	PRESENT	0
236729	232945	11064N	PARTICIPANT	\N	PRESENT	0
236730	232945	11074Q	PARTICIPANT	\N	PRESENT	0
236731	232945	04059M	PARTICIPANT	\N	PRESENT	0
236732	232945	11077T	PARTICIPANT	\N	PRESENT	0
236733	232945	98035U	PARTICIPANT	\N	PRESENT	0
236734	232945	08055A	PARTICIPANT	\N	PRESENT	0
236735	232945	14229S	PARTICIPANT	\N	PRESENT	0
236736	232945	08052W	PARTICIPANT	\N	PRESENT	0
236737	232945	14193X	PARTICIPANT	\N	PRESENT	0
236738	232945	01028R	PARTICIPANT	\N	PRESENT	0
236739	232945	11027H	PARTICIPANT	\N	PRESENT	0
236740	232945	14051J	PARTICIPANT	\N	PRESENT	0
236741	232945	19715Y	PARTICIPANT	\N	PRESENT	0
236742	232945	04042C	PARTICIPANT	\N	PRESENT	0
236743	232945	14151M	PARTICIPANT	\N	PRESENT	0
236744	232945	14021P	PARTICIPANT	\N	PRESENT	0
236745	232945	14225N	PARTICIPANT	\N	PRESENT	0
236746	232945	98018T	PARTICIPANT	\N	PRESENT	0
236747	232945	08045X	PARTICIPANT	\N	PRESENT	0
236748	232945	04044E	PARTICIPANT	\N	PRESENT	0
236749	232945	08016S	PARTICIPANT	\N	PRESENT	0
236750	232945	14107H	PARTICIPANT	\N	PRESENT	0
236751	232945	95041E	PARTICIPANT	\N	PRESENT	0
236752	232945	01062T	PARTICIPANT	\N	PRESENT	0
236753	232945	08060W	PARTICIPANT	\N	PRESENT	0
236754	232945	01024M	PARTICIPANT	\N	PRESENT	0
236755	232945	01025N	PARTICIPANT	\N	PRESENT	0
236756	232945	08038Y	PARTICIPANT	\N	PRESENT	0
236757	232945	80013X	PARTICIPANT	\N	PRESENT	0
236758	232945	14028W	PARTICIPANT	\N	PRESENT	0
236759	232945	04047H	PARTICIPANT	\N	PRESENT	0
236760	232945	08024S	PARTICIPANT	\N	PRESENT	0
236761	232945	14197C	PARTICIPANT	\N	PRESENT	0
236762	232945	19649G	PARTICIPANT	\N	PRESENT	0
236763	232945	19575F	PARTICIPANT	\N	PRESENT	0
236764	232945	19647E	PARTICIPANT	\N	PRESENT	0
236765	232945	14327T	PARTICIPANT	\N	PRESENT	0
236766	232945	19727D	PARTICIPANT	\N	PRESENT	0
236767	232945	14030Q	PARTICIPANT	\N	PRESENT	0
236768	232945	80027E	PARTICIPANT	\N	PRESENT	0
236769	232945	08012N	PARTICIPANT	\N	PRESENT	0
236770	232945	04043D	PARTICIPANT	\N	PRESENT	0
236771	232945	04035D	PARTICIPANT	\N	PRESENT	0
236772	232945	01043Q	PARTICIPANT	\N	PRESENT	0
236773	232945	08035V	PARTICIPANT	\N	PRESENT	0
236774	232945	14121F	PARTICIPANT	\N	PRESENT	0
236775	232945	08058D	PARTICIPANT	\N	PRESENT	0
236776	232945	17779H	PARTICIPANT	\N	PRESENT	0
236777	232945	19489J	PARTICIPANT	\N	PRESENT	0
236778	232945	11054L	PARTICIPANT	\N	PRESENT	0
236779	232945	19295A	PARTICIPANT	\N	PRESENT	0
236780	232945	11109J	PARTICIPANT	\N	PRESENT	0
236781	232945	19683J	PARTICIPANT	\N	PRESENT	0
236782	232945	19723Y	PARTICIPANT	\N	PRESENT	0
236783	232945	14227Q	PARTICIPANT	\N	PRESENT	0
236784	232945	11067R	PARTICIPANT	\N	PRESENT	0
236785	232945	19503N	PARTICIPANT	\N	PRESENT	0
236786	232945	19741B	PARTICIPANT	\N	PRESENT	0
236787	232945	19591F	PARTICIPANT	\N	PRESENT	0
236788	232945	19551W	PARTICIPANT	\N	PRESENT	0
236789	232945	19333N	PARTICIPANT	\N	PRESENT	0
236790	232945	19725B	PARTICIPANT	\N	PRESENT	0
236791	232945	19689Q	PARTICIPANT	\N	PRESENT	0
236792	232945	14115H	PARTICIPANT	\N	PRESENT	0
214586	214585	11048N	PARTICIPANT	\N	PRESENT	0
214592	214591	19545Y	PARTICIPANT	\N	PRESENT	0
214593	214591	19689Q	PARTICIPANT	\N	PRESENT	0
214595	214594	19689Q	PARTICIPANT	\N	PRESENT	0
214601	214600	14159V	PARTICIPANT	\N	PRESENT	0
214603	214602	11074Q	PARTICIPANT	\N	PRESENT	0
214605	214604	11040E	PARTICIPANT	\N	PRESENT	0
214606	214604	19667J	PARTICIPANT	\N	PRESENT	0
216042	216041	04047H	PARTICIPANT	\N	PRESENT	0
216043	216041	19581D	PARTICIPANT	\N	PRESENT	0
216044	216041	19673G	PARTICIPANT	\N	PRESENT	0
216046	216045	04047H	PARTICIPANT	\N	PRESENT	0
216048	216047	19253P	PARTICIPANT	\N	PRESENT	0
216050	216049	19253P	PARTICIPANT	\N	PRESENT	0
219920	207715	08010L	PARTICIPANT	\N	PRESENT	0
219934	219933	08058D	PARTICIPANT	\N	PRESENT	0
219943	219942	14193X	PARTICIPANT	\N	PRESENT	0
219969	219967	14065Q	PARTICIPANT	\N	EXCUSE	0
219945	219942	08058D	PARTICIPANT	\N	PRESENT	0
219968	219967	14133K	PARTICIPANT	\N	EXCUSE	0
219970	219967	96004D	PRESIDENT	0	PRESENT	0
219971	219967	14089Y	PARTICIPANT	\N	PRESENT	0
219972	219967	14357A	PARTICIPANT	\N	PRESENT	0
219973	219967	14079W	PARTICIPANT	\N	PRESENT	0
219974	219967	08018U	PARTICIPANT	\N	EXCUSE	0
219975	219967	04035D	PARTICIPANT	\N	EXCUSE	0
219976	219967	11083R	PARTICIPANT	\N	PRESENT	0
219977	219967	14026U	PARTICIPANT	\N	PRESENT	0
219978	219967	14033T	PARTICIPANT	\N	PRESENT	0
219979	219967	19685L	PARTICIPANT	\N	EXCUSE	0
219980	219967	04097T	PARTICIPANT	\N	PRESENT	0
219981	219967	08044W	PARTICIPANT	\N	EXCUSE	0
219982	219967	14097Y	PARTICIPANT	\N	EXCUSE	0
219983	219967	04061F	PARTICIPANT	\N	PRESENT	0
219984	219967	14073Q	PARTICIPANT	\N	PRESENT	0
219985	219967	11026G	PARTICIPANT	\N	PRESENT	0
219986	219967	08039A	PARTICIPANT	\N	PRESENT	0
219987	219967	14205J	PARTICIPANT	\N	PRESENT	0
219989	219967	14001X	PARTICIPANT	\N	EXCUSE	0
219990	219967	04057K	PARTICIPANT	\N	PRESENT	0
219992	219967	19593H	PARTICIPANT	\N	PRESENT	0
219993	219967	08073C	PARTICIPANT	\N	PRESENT	0
219995	219967	14331P	PARTICIPANT	\N	PRESENT	0
219996	219967	98035U	PARTICIPANT	\N	EXCUSE	0
219997	219967	10015M	PARTICIPANT	\N	PRESENT	0
219999	219967	14221J	PARTICIPANT	\N	EXCUSE	0
224017	218295	17583W	PARTICIPANT	\N	PRESENT	0
224018	218295	19577H	PARTICIPANT	\N	PRESENT	0
224019	218295	11041F	PARTICIPANT	\N	PRESENT	0
224020	218295	08061X	PARTICIPANT	\N	PRESENT	0
224021	218295	19707Y	PARTICIPANT	\N	PRESENT	0
224022	218295	19705W	PARTICIPANT	\N	PRESENT	0
224023	218295	19483C	PARTICIPANT	\N	PRESENT	0
224024	218295	14331P	PARTICIPANT	\N	PRESENT	0
224025	218295	19675J	PARTICIPANT	\N	PRESENT	0
224026	218295	14329V	PARTICIPANT	\N	PRESENT	0
224027	218295	08034U	PARTICIPANT	\N	PRESENT	0
224028	218295	14069U	PARTICIPANT	\N	PRESENT	0
224029	218295	14187A	PARTICIPANT	\N	PRESENT	0
224030	218295	04033B	PARTICIPANT	\N	PRESENT	0
224031	218295	19689Q	PARTICIPANT	\N	PRESENT	0
224032	218295	19413M	PARTICIPANT	\N	PRESENT	0
224033	218295	11085T	PARTICIPANT	\N	PRESENT	0
224034	218295	08028W	PARTICIPANT	\N	PRESENT	0
224035	218295	14223L	PARTICIPANT	\N	PRESENT	0
224036	218295	19515S	PARTICIPANT	\N	PRESENT	0
224037	218295	19573D	PARTICIPANT	\N	PRESENT	0
224038	218295	19507S	PARTICIPANT	\N	PRESENT	0
224039	218295	19663E	PARTICIPANT	\N	PRESENT	0
224040	218295	18083K	PARTICIPANT	\N	PRESENT	0
224041	218295	19415P	PARTICIPANT	\N	PRESENT	0
224042	218295	19729F	PARTICIPANT	\N	PRESENT	0
224043	218295	95030B	PARTICIPANT	\N	PRESENT	0
224044	218295	19421M	PARTICIPANT	\N	PRESENT	0
224045	218295	19367Y	PARTICIPANT	\N	PRESENT	0
224046	218295	19335Q	PARTICIPANT	\N	PRESENT	0
224048	218295	11072N	PARTICIPANT	\N	PRESENT	0
224049	218295	11056N	PARTICIPANT	\N	PRESENT	0
224050	218295	19723Y	PARTICIPANT	\N	PRESENT	0
224051	218295	08019V	PARTICIPANT	\N	PRESENT	0
224052	218295	14115H	PARTICIPANT	\N	PRESENT	0
224053	218295	14265W	PARTICIPANT	\N	PRESENT	0
224591	218298	11027H	PARTICIPANT	\N	PRESENT	0
224592	218298	01028R	PARTICIPANT	\N	PRESENT	0
224593	218298	11097X	PARTICIPANT	\N	PRESENT	0
224594	218298	08016S	PARTICIPANT	\N	PRESENT	0
224595	218298	14107H	PARTICIPANT	\N	PRESENT	0
224596	218298	08045X	PARTICIPANT	\N	PRESENT	0
224597	218298	19421M	PARTICIPANT	\N	PRESENT	0
224598	218298	14225N	PARTICIPANT	\N	PRESENT	0
224599	218298	11099A	PARTICIPANT	\N	PRESENT	0
224600	218298	14151M	PARTICIPANT	\N	PRESENT	0
224601	218298	14357A	PARTICIPANT	\N	PRESENT	0
224602	218298	19715Y	PARTICIPANT	\N	PRESENT	0
224603	218298	14021P	PARTICIPANT	\N	PRESENT	0
224604	218298	19647E	PARTICIPANT	\N	PRESENT	0
224605	218298	19649G	PARTICIPANT	\N	PRESENT	0
224606	218298	14197C	PARTICIPANT	\N	PRESENT	0
224607	218298	19675J	PARTICIPANT	\N	PRESENT	0
224608	218298	08024S	PARTICIPANT	\N	PRESENT	0
224609	218298	14028W	PARTICIPANT	\N	PRESENT	0
224610	218298	19383Y	PARTICIPANT	\N	PRESENT	0
224611	218298	80013X	PARTICIPANT	\N	PRESENT	0
224612	218298	08038Y	PARTICIPANT	\N	PRESENT	0
224613	218298	01062T	PARTICIPANT	\N	PRESENT	0
224614	218298	14065Q	PARTICIPANT	\N	PRESENT	0
224615	218298	19549D	PARTICIPANT	\N	PRESENT	0
224616	218298	11066Q	PARTICIPANT	\N	PRESENT	0
224617	218298	19507S	PARTICIPANT	\N	PRESENT	0
224618	218298	08043V	PARTICIPANT	\N	PRESENT	0
224619	218298	11104D	PARTICIPANT	\N	PRESENT	0
224620	218298	19729F	PARTICIPANT	\N	PRESENT	0
224621	218298	14281W	PARTICIPANT	\N	PRESENT	0
224622	218298	08035V	PARTICIPANT	\N	PRESENT	0
224623	218298	08012N	PARTICIPANT	\N	PRESENT	0
224624	218298	80027E	PARTICIPANT	\N	PRESENT	0
224625	218298	19581D	PARTICIPANT	\N	PRESENT	0
224626	218298	19727D	PARTICIPANT	\N	PRESENT	0
224627	218298	19531S	PARTICIPANT	\N	PRESENT	0
224628	218298	14059S	PARTICIPANT	\N	PRESENT	0
224629	218298	17779H	PARTICIPANT	\N	PRESENT	0
224630	218298	14329V	PARTICIPANT	\N	PRESENT	0
224631	218298	19489J	PARTICIPANT	\N	PRESENT	0
224632	218298	08058D	PARTICIPANT	\N	PRESENT	0
224633	218298	14121F	PARTICIPANT	\N	PRESENT	0
224634	218298	19705W	PARTICIPANT	\N	PRESENT	0
224635	218298	14085U	PARTICIPANT	\N	PRESENT	0
224636	218298	08017T	PARTICIPANT	\N	PRESENT	0
224637	218298	08053X	PARTICIPANT	\N	PRESENT	0
224638	218298	19443T	PARTICIPANT	\N	PRESENT	0
224639	218298	19525U	PARTICIPANT	\N	PRESENT	0
224640	218298	11045K	PARTICIPANT	\N	PRESENT	0
224641	218298	11110B	PARTICIPANT	\N	PRESENT	0
224642	218298	14081Q	PARTICIPANT	\N	PRESENT	0
224643	218298	08034U	PARTICIPANT	\N	PRESENT	0
224644	218298	14207L	PARTICIPANT	\N	PRESENT	0
224645	218298	08039A	PARTICIPANT	\N	PRESENT	0
224646	218298	11041F	PARTICIPANT	\N	PRESENT	0
224647	218298	14199E	PARTICIPANT	\N	PRESENT	0
224648	218298	19599P	PARTICIPANT	\N	PRESENT	0
224649	218298	19725B	PARTICIPANT	\N	PRESENT	0
224650	218298	08014Q	PARTICIPANT	\N	PRESENT	0
224651	218298	19333N	PARTICIPANT	\N	PRESENT	0
224652	218298	14001X	PARTICIPANT	\N	PRESENT	0
224653	218298	14227Q	PARTICIPANT	\N	PRESENT	0
224654	218298	19415P	PARTICIPANT	\N	PRESENT	0
224655	218298	19683J	PARTICIPANT	\N	PRESENT	0
224656	218298	19689Q	PARTICIPANT	\N	PRESENT	0
224657	218298	19413M	PARTICIPANT	\N	PRESENT	0
224658	218298	19251M	PARTICIPANT	\N	PRESENT	0
224659	218298	11054L	PARTICIPANT	\N	PRESENT	0
224660	218298	19591F	PARTICIPANT	\N	PRESENT	0
224661	218298	19503N	PARTICIPANT	\N	PRESENT	0
224662	218298	14042U	PARTICIPANT	\N	PRESENT	0
224663	218298	11067R	PARTICIPANT	\N	PRESENT	0
224664	218298	19585H	PARTICIPANT	\N	PRESENT	0
224665	218298	01025N	PARTICIPANT	\N	PRESENT	0
224666	218298	19551W	PARTICIPANT	\N	PRESENT	0
224667	218298	04070G	PARTICIPANT	\N	PRESENT	0
224668	218298	19527W	PARTICIPANT	\N	PRESENT	0
224669	218298	14030Q	PARTICIPANT	\N	PRESENT	0
224670	218298	14063N	PARTICIPANT	\N	PRESENT	0
224671	218298	19631V	PARTICIPANT	\N	PRESENT	0
224672	218298	14097Y	PARTICIPANT	\N	PRESENT	0
224673	218298	19483C	PARTICIPANT	\N	PRESENT	0
224674	218298	14109K	PARTICIPANT	\N	PRESENT	0
224675	218298	19669L	PARTICIPANT	\N	PRESENT	0
224676	218298	14257W	PARTICIPANT	\N	PRESENT	0
228125	228124	04059M	PARTICIPANT	\N	PRESENT	0
228126	228124	11040E	PARTICIPANT	\N	PRESENT	0
228127	228124	14053L	PARTICIPANT	\N	PRESENT	0
228128	228124	11053K	PARTICIPANT	\N	PRESENT	0
228129	228124	08052W	PARTICIPANT	\N	PRESENT	0
228130	228124	11070L	PARTICIPANT	\N	PRESENT	0
228131	228124	10006L	PARTICIPANT	\N	PRESENT	0
228132	228124	14041T	PARTICIPANT	\N	PRESENT	0
228133	228124	04089T	PARTICIPANT	\N	PRESENT	0
228134	228124	14034U	PARTICIPANT	\N	PRESENT	0
228135	228124	14231L	PARTICIPANT	\N	PRESENT	0
228136	228124	11064N	PARTICIPANT	\N	PRESENT	0
228140	228124	14159V	PARTICIPANT	\N	PRESENT	0
228138	228124	14241N	PARTICIPANT	\N	PRESENT	0
228139	228124	14061L	PARTICIPANT	\N	PRESENT	0
228141	228124	86034E	PARTICIPANT	\N	PRESENT	0
228142	228124	08034U	PARTICIPANT	\N	PRESENT	0
228143	228124	01043Q	PARTICIPANT	\N	PRESENT	0
228144	228124	11077T	PARTICIPANT	\N	PRESENT	0
228145	228124	12016W	PARTICIPANT	\N	PRESENT	0
228146	228124	11072N	PARTICIPANT	\N	PRESENT	0
228148	228124	05012A	PARTICIPANT	\N	PRESENT	0
228149	228124	14135M	PARTICIPANT	\N	PRESENT	0
228150	228124	04044E	PARTICIPANT	\N	PRESENT	0
228238	228236	14028W	PARTICIPANT	\N	PRESENT	0
228171	225222	14093U	PARTICIPANT	\N	EXCUSE	0
228237	228236	95067Q	PARTICIPANT	\N	PRESENT	0
228935	228933	14267Y	PARTICIPANT	\N	PRESENT	0
228936	228933	11027H	PARTICIPANT	\N	PRESENT	0
228937	228933	98029W	PARTICIPANT	\N	PRESENT	0
228938	228933	08056B	PARTICIPANT	\N	PRESENT	0
228939	228933	11064N	PARTICIPANT	\N	PRESENT	0
228940	228933	98018T	PARTICIPANT	\N	PRESENT	0
229180	229179	14147R	PARTICIPANT	\N	PRESENT	0
229181	229179	19629C	PARTICIPANT	\N	PRESENT	0
229182	229179	04047H	PARTICIPANT	\N	PRESENT	0
229480	227892	11081P	PARTICIPANT	\N	EXCUSE	0
229481	227892	08021P	PARTICIPANT	\N	EXCUSE	0
230003	230002	11074Q	PARTICIPANT	\N	PRESENT	0
230004	230002	08011M	PARTICIPANT	\N	PRESENT	0
230005	230002	19711U	PARTICIPANT	\N	PRESENT	0
230006	230002	04071H	PARTICIPANT	\N	PRESENT	0
230007	230002	14327T	PARTICIPANT	\N	PRESENT	0
230008	230002	14225N	PARTICIPANT	\N	PRESENT	0
230009	230002	19651A	PARTICIPANT	\N	PRESENT	0
230010	230002	19647E	PARTICIPANT	\N	PRESENT	0
230012	230002	19671E	PARTICIPANT	\N	PRESENT	0
230015	230014	11074Q	PARTICIPANT	\N	PRESENT	0
230017	230014	08011M	PARTICIPANT	\N	PRESENT	0
230018	230014	11048N	PARTICIPANT	\N	PRESENT	0
230019	230014	04071H	PARTICIPANT	\N	PRESENT	0
230020	230014	11070L	PARTICIPANT	\N	PRESENT	0
230021	230014	14225N	PARTICIPANT	\N	PRESENT	0
230171	230169	10006L	PARTICIPANT	\N	PRESENT	0
230025	230014	19647E	PARTICIPANT	\N	PRESENT	0
230026	230014	19671E	PARTICIPANT	\N	PRESENT	0
230170	230169	04086Q	PARTICIPANT	\N	PRESENT	0
230172	230169	14223L	PARTICIPANT	\N	PRESENT	0
230173	230169	19711U	PARTICIPANT	\N	PRESENT	0
230174	230169	19705W	PARTICIPANT	\N	PRESENT	0
230175	230169	19611R	PARTICIPANT	\N	PRESENT	0
230176	230169	14225N	PARTICIPANT	\N	PRESENT	0
230177	230169	19251M	PARTICIPANT	\N	PRESENT	0
230178	230169	98035U	PARTICIPANT	\N	PRESENT	0
230179	230169	99004R	PARTICIPANT	\N	PRESENT	0
230180	230169	19707Y	PARTICIPANT	\N	PRESENT	0
230181	230169	14159V	PARTICIPANT	\N	PRESENT	0
230182	230169	19591F	PARTICIPANT	\N	PRESENT	0
230183	230169	08009T	PARTICIPANT	\N	PRESENT	0
230184	230169	11085T	PARTICIPANT	\N	PRESENT	0
230192	228392	18003S	PARTICIPANT	\N	PRESENT	0
230195	228392	14299H	PARTICIPANT	\N	PRESENT	0
230198	228392	19723Y	PARTICIPANT	\N	PRESENT	0
230199	228392	01048V	PARTICIPANT	\N	PRESENT	0
230200	228392	19533U	PARTICIPANT	\N	PRESENT	0
230201	228392	14093U	PARTICIPANT	\N	EXCUSE	0
230202	228392	19663E	PARTICIPANT	\N	EXCUSE	0
230770	230769	88008L	PARTICIPANT	\N	PRESENT	0
230812	207523	11074Q	PARTICIPANT	\N	PRESENT	0
230821	220069	11077T	PARTICIPANT	\N	PRESENT	0
230822	220069	19591F	PARTICIPANT	\N	PRESENT	0
230823	220069	19593H	PARTICIPANT	\N	PRESENT	0
230824	220069	19651A	PARTICIPANT	\N	PRESENT	0
230825	220069	11085T	PARTICIPANT	\N	PRESENT	0
230826	220069	01025N	PARTICIPANT	\N	PRESENT	0
230827	220069	19467C	PARTICIPANT	\N	PRESENT	0
230828	220069	19503N	PARTICIPANT	\N	PRESENT	0
230829	220069	05008E	PARTICIPANT	\N	PRESENT	0
230830	220069	19383Y	PARTICIPANT	\N	PRESENT	0
230831	220069	14093U	PARTICIPANT	\N	PRESENT	0
230832	220069	19671E	PARTICIPANT	\N	PRESENT	0
230833	220069	19701S	PARTICIPANT	\N	PRESENT	0
230834	220069	19637C	PARTICIPANT	\N	PRESENT	0
230835	220069	19707Y	PARTICIPANT	\N	PRESENT	0
230836	220069	80013X	PARTICIPANT	\N	PRESENT	0
230837	220069	19717B	PARTICIPANT	\N	PRESENT	0
230838	220069	04071H	PARTICIPANT	\N	PRESENT	0
230839	220069	04086Q	PARTICIPANT	\N	PRESENT	0
230840	220069	19629C	PARTICIPANT	\N	PRESENT	0
230841	220069	19695N	PARTICIPANT	\N	PRESENT	0
230842	220070	11077T	PARTICIPANT	\N	PRESENT	0
230843	220070	19591F	PARTICIPANT	\N	PRESENT	0
230844	220070	19593H	PARTICIPANT	\N	PRESENT	0
230845	220070	19651A	PARTICIPANT	\N	PRESENT	0
230846	220070	11085T	PARTICIPANT	\N	PRESENT	0
230847	220070	01025N	PARTICIPANT	\N	PRESENT	0
230848	220070	19467C	PARTICIPANT	\N	PRESENT	0
230849	220070	19503N	PARTICIPANT	\N	PRESENT	0
230850	220070	05008E	PARTICIPANT	\N	PRESENT	0
230851	220070	19383Y	PARTICIPANT	\N	PRESENT	0
230852	220070	14093U	PARTICIPANT	\N	PRESENT	0
230853	220070	19671E	PARTICIPANT	\N	PRESENT	0
230854	220070	19701S	PARTICIPANT	\N	PRESENT	0
230855	220070	19637C	PARTICIPANT	\N	PRESENT	0
230856	220070	19707Y	PARTICIPANT	\N	PRESENT	0
230857	220070	80013X	PARTICIPANT	\N	PRESENT	0
230858	220070	19717B	PARTICIPANT	\N	PRESENT	0
230859	220070	04071H	PARTICIPANT	\N	PRESENT	0
230860	220070	04086Q	PARTICIPANT	\N	PRESENT	0
230861	220070	19629C	PARTICIPANT	\N	PRESENT	0
230862	220070	19695N	PARTICIPANT	\N	PRESENT	0
230863	220070	11090Q	PARTICIPANT	\N	PRESENT	0
230864	220070	19705W	PARTICIPANT	\N	PRESENT	0
230865	220070	08068F	PARTICIPANT	\N	PRESENT	0
230866	220070	11065P	PARTICIPANT	\N	PRESENT	0
230867	220070	11099A	PARTICIPANT	\N	PRESENT	0
230868	220070	19583F	PARTICIPANT	\N	PRESENT	0
230869	220070	04049K	PARTICIPANT	\N	PRESENT	0
230870	220070	14357A	PARTICIPANT	\N	PRESENT	0
230871	220070	04043D	PARTICIPANT	\N	PRESENT	0
230872	220070	99004R	PARTICIPANT	\N	PRESENT	0
230873	220070	11072N	PARTICIPANT	\N	PRESENT	0
230874	220072	11077T	PARTICIPANT	\N	PRESENT	0
230875	220072	80013X	PARTICIPANT	\N	PRESENT	0
230876	220072	14093U	PARTICIPANT	\N	PRESENT	0
230899	220072	19467C	PARTICIPANT	\N	PRESENT	0
230878	230594	19489J	PARTICIPANT	\N	PRESENT	0
230879	230594	19629C	PARTICIPANT	\N	PRESENT	0
230880	230594	04038G	PARTICIPANT	\N	PRESENT	0
230881	230594	08018U	PARTICIPANT	\N	PRESENT	0
230882	230594	19483C	PARTICIPANT	\N	PRESENT	0
230883	230594	14259Y	PARTICIPANT	\N	PRESENT	0
230884	230594	14231L	PARTICIPANT	\N	PRESENT	0
230885	230594	05008E	PRESIDENT	0	PRESENT	0
230887	230594	07034Q	PARTICIPANT	\N	EXCUSE	0
230888	230594	04044E	PARTICIPANT	\N	EXCUSE	0
230890	220072	14231L	PARTICIPANT	\N	PRESENT	0
230891	220072	19629C	PARTICIPANT	\N	PRESENT	0
230892	220072	04038G	PARTICIPANT	\N	PRESENT	0
230893	220072	14079W	PARTICIPANT	\N	PRESENT	0
230894	220072	19489J	PARTICIPANT	\N	PRESENT	0
230895	220072	19503N	PARTICIPANT	\N	PRESENT	0
230896	220072	19543W	PARTICIPANT	\N	PRESENT	0
230897	220072	14259Y	PARTICIPANT	\N	PRESENT	0
230898	220072	19251M	PARTICIPANT	\N	PRESENT	0
230900	220072	19483C	PARTICIPANT	\N	PRESENT	0
230901	220072	19383Y	PARTICIPANT	\N	PRESENT	0
230902	220072	19717B	PARTICIPANT	\N	PRESENT	0
230903	220072	14357A	PARTICIPANT	\N	PRESENT	0
235437	233300	14030Q	PRESIDENT	0	PRESENT	0
235438	233300	08043V	PARTICIPANT	\N	PRESENT	0
235439	233300	19367Y	PARTICIPANT	\N	PRESENT	0
235440	233300	19643A	PARTICIPANT	\N	PRESENT	0
235441	233300	19701S	PARTICIPANT	\N	PRESENT	0
235442	233300	11031D	PARTICIPANT	\N	PRESENT	0
235443	233300	80013X	PARTICIPANT	\N	PRESENT	0
235444	233300	19693L	PARTICIPANT	\N	PRESENT	0
235445	233300	14217N	PARTICIPANT	\N	PRESENT	0
235446	233300	19673G	PARTICIPANT	\N	PRESENT	0
235447	233300	04035D	PARTICIPANT	\N	PRESENT	0
235448	233300	19715Y	PARTICIPANT	\N	PRESENT	0
235449	233300	07029T	PARTICIPANT	\N	PRESENT	0
235450	233300	08017T	PARTICIPANT	\N	PRESENT	0
235451	233300	14109K	PARTICIPANT	\N	PRESENT	0
235452	233300	14235Q	PARTICIPANT	\N	PRESENT	0
235453	233300	11045K	PARTICIPANT	\N	PRESENT	0
235454	233300	18083K	PARTICIPANT	\N	EXCUSE	0
235455	233300	01043Q	PARTICIPANT	\N	EXCUSE	0
235456	233300	08031R	PARTICIPANT	\N	EXCUSE	0
235457	233300	19269X	PARTICIPANT	\N	EXCUSE	0
235458	233300	19697Q	PARTICIPANT	\N	EXCUSE	0
235459	233300	19629C	PARTICIPANT	\N	PRESENT	0
235460	233300	14147R	PARTICIPANT	\N	PRESENT	0
239267	238871	02002K	PARTICIPANT	\N	EXCUSE	0
239327	238562	14327T	PARTICIPANT	\N	EXCUSE	0
239600	238562	19253P	PARTICIPANT	\N	EXCUSE	0
239629	238562	08049C	PARTICIPANT	\N	EXCUSE	0
239664	238562	04044E	PARTICIPANT	\N	EXCUSE	0
240421	238562	14231L	PARTICIPANT	\N	PRESENT	0
240422	238562	19565D	PARTICIPANT	\N	PRESENT	0
240423	238562	11049P	PARTICIPANT	\N	PRESENT	0
240424	238562	01057W	PARTICIPANT	\N	PRESENT	0
240425	238562	11048N	PARTICIPANT	\N	PRESENT	0
240426	238562	14063N	PARTICIPANT	\N	PRESENT	0
240427	238562	14028W	PARTICIPANT	\N	PRESENT	0
240428	238562	19735D	PARTICIPANT	\N	PRESENT	0
240429	238562	05012A	PARTICIPANT	\N	PRESENT	0
240430	238562	04045F	PARTICIPANT	\N	PRESENT	0
240431	239669	14257W	PARTICIPANT	\N	PRESENT	0
240432	239669	14026U	PARTICIPANT	\N	PRESENT	0
240433	239669	19713W	PARTICIPANT	\N	PRESENT	0
240434	238562	08010L	PARTICIPANT	\N	PRESENT	0
240435	238562	14103D	PARTICIPANT	\N	PRESENT	0
240436	239669	14073Q	PARTICIPANT	\N	PRESENT	0
240437	239669	14123H	PARTICIPANT	\N	PRESENT	0
240438	239669	14089Y	PARTICIPANT	\N	PRESENT	0
240439	239669	80013X	PARTICIPANT	\N	PRESENT	0
240440	239669	14221J	PARTICIPANT	\N	PRESENT	0
240441	238782	08068F	PARTICIPANT	\N	PRESENT	0
240442	238782	08015R	PARTICIPANT	\N	PRESENT	0
240443	238782	19737F	PARTICIPANT	\N	PRESENT	0
240444	238782	14028W	PARTICIPANT	\N	PRESENT	0
240445	238782	14219Q	PARTICIPANT	\N	PRESENT	0
240446	238782	19695N	PARTICIPANT	\N	PRESENT	0
240447	238782	08028W	PRESIDENT	0	PRESENT	0
240448	238782	19631V	PARTICIPANT	\N	PRESENT	0
240449	238782	14257W	PARTICIPANT	\N	PRESENT	0
240450	238782	95041E	PARTICIPANT	\N	EXCUSE	0
240451	238782	19637C	PARTICIPANT	\N	EXCUSE	0
240452	239669	14103D	PARTICIPANT	\N	PRESENT	0
240453	239669	19591F	PARTICIPANT	\N	PRESENT	0
240454	239669	19573D	PARTICIPANT	\N	PRESENT	0
240455	238782	14061L	PARTICIPANT	\N	PRESENT	0
240456	239669	08062Y	PARTICIPANT	\N	PRESENT	0
240457	238782	19251M	PARTICIPANT	\N	PRESENT	0
240458	239669	89017R	PARTICIPANT	\N	PRESENT	0
240459	239669	95062K	PARTICIPANT	\N	PRESENT	0
240460	239669	18083K	PARTICIPANT	\N	PRESENT	0
240461	239669	19467C	PARTICIPANT	\N	PRESENT	0
240462	239669	14179A	PARTICIPANT	\N	PRESENT	0
240463	239669	14109K	PARTICIPANT	\N	PRESENT	0
240464	239669	19719D	PARTICIPANT	\N	PRESENT	0
240465	239669	19383Y	PARTICIPANT	\N	PRESENT	0
240466	239669	11012A	PARTICIPANT	\N	PRESENT	0
240467	239669	14213J	PARTICIPANT	\N	PRESENT	0
240468	239669	19717B	PARTICIPANT	\N	PRESENT	0
240469	239669	19657G	PARTICIPANT	\N	PRESENT	0
240470	239669	11040E	PARTICIPANT	\N	PRESENT	0
240471	239669	98005N	PARTICIPANT	\N	PRESENT	0
240530	238782	14079W	PARTICIPANT	\N	PRESENT	0
240532	240531	14133K	PARTICIPANT	\N	PRESENT	0
240533	240531	14065Q	PARTICIPANT	\N	PRESENT	0
240534	240531	96004D	PRESIDENT	0	PRESENT	0
240535	240531	14089Y	PARTICIPANT	\N	PRESENT	0
240536	240531	08014Q	PARTICIPANT	\N	PRESENT	0
240537	240531	14357A	PARTICIPANT	\N	EXCUSE	0
240538	240531	14079W	PARTICIPANT	\N	PRESENT	0
240539	240531	14249W	PARTICIPANT	\N	PRESENT	0
240540	240531	08018U	PARTICIPANT	\N	EXCUSE	0
240541	240531	11083R	PARTICIPANT	\N	PRESENT	0
240542	240531	14033T	PARTICIPANT	\N	EXCUSE	0
240543	240531	14026U	PARTICIPANT	\N	PRESENT	0
240544	240531	95037J	PARTICIPANT	\N	PRESENT	0
240545	240531	04097T	PARTICIPANT	\N	EXCUSE	0
240546	240531	14097Y	PARTICIPANT	\N	EXCUSE	0
240547	240531	04061F	PARTICIPANT	\N	PRESENT	0
240548	240531	14061L	PARTICIPANT	\N	PRESENT	0
240549	240531	14073Q	PARTICIPANT	\N	PRESENT	0
240550	240531	11026G	PARTICIPANT	\N	EXCUSE	0
240551	240531	14001X	PARTICIPANT	\N	PRESENT	0
240552	240531	04057K	PARTICIPANT	\N	PRESENT	0
240553	240531	19563B	PARTICIPANT	\N	PRESENT	0
240554	240531	19593H	PARTICIPANT	\N	PRESENT	0
240555	240531	14331P	PARTICIPANT	\N	PRESENT	0
240556	240531	14225N	PARTICIPANT	\N	PRESENT	0
240557	240531	10015M	PARTICIPANT	\N	PRESENT	0
240558	240531	98035U	PARTICIPANT	\N	PRESENT	0
240559	238782	14065Q	PARTICIPANT	\N	PRESENT	0
240560	239004	14275Y	PARTICIPANT	\N	PRESENT	0
240561	239004	95062K	PARTICIPANT	\N	PRESENT	0
240563	239004	08019V	PRESIDENT	0	PRESENT	0
226738	225954	19663E	PARTICIPANT	\N	PRESENT	0
236795	232945	14063N	PARTICIPANT	\N	PRESENT	0
236796	232945	14109K	PARTICIPANT	\N	PRESENT	0
236797	232945	19631V	PARTICIPANT	\N	PRESENT	0
236793	232945	19527W	PARTICIPANT	\N	PRESENT	0
236794	232945	14105F	PARTICIPANT	\N	PRESENT	0
236798	232945	14257W	PARTICIPANT	\N	PRESENT	0
236799	232945	14097Y	PARTICIPANT	\N	PRESENT	0
236800	232945	19669L	PARTICIPANT	\N	PRESENT	0
236801	232945	11045K	PARTICIPANT	\N	PRESENT	0
236802	232945	14207L	PARTICIPANT	\N	PRESENT	0
236803	232945	08014Q	PARTICIPANT	\N	PRESENT	0
236804	232945	14001X	PARTICIPANT	\N	PRESENT	0
236805	232945	08017T	PARTICIPANT	\N	PRESENT	0
236806	232945	08053X	PARTICIPANT	\N	PRESENT	0
236807	232945	19525U	PARTICIPANT	\N	PRESENT	0
236808	232945	08068F	PARTICIPANT	\N	PRESENT	0
236809	232945	14081Q	PARTICIPANT	\N	PRESENT	0
236810	232945	11066Q	PARTICIPANT	\N	PRESENT	0
236868	232945	14093U	PARTICIPANT	\N	PRESENT	0
236812	232945	14065Q	PARTICIPANT	\N	PRESENT	0
236813	232945	19549D	PARTICIPANT	\N	PRESENT	0
236814	232945	14199E	PARTICIPANT	\N	PRESENT	0
236815	232945	14281W	PARTICIPANT	\N	PRESENT	0
236816	232945	11104D	PARTICIPANT	\N	PRESENT	0
236818	232945	14231L	PARTICIPANT	\N	PRESENT	0
236819	232945	08044W	PARTICIPANT	\N	PRESENT	0
236820	232945	14179A	PARTICIPANT	\N	PRESENT	0
236821	232945	01034P	PARTICIPANT	\N	PRESENT	0
236822	232945	86034E	PARTICIPANT	\N	PRESENT	0
236823	232945	19737F	PARTICIPANT	\N	PRESENT	0
236824	232945	95063L	PARTICIPANT	\N	PRESENT	0
236855	232945	19329S	PARTICIPANT	\N	PRESENT	0
236826	232945	14205J	PARTICIPANT	\N	PRESENT	0
236827	232945	19569H	PARTICIPANT	\N	PRESENT	0
236828	232945	14042U	PARTICIPANT	\N	PRESENT	0
236829	232945	19713W	PARTICIPANT	\N	PRESENT	0
236830	232945	14219Q	PARTICIPANT	\N	PRESENT	0
236831	232945	19479G	PARTICIPANT	\N	PRESENT	0
236832	232945	19441R	PARTICIPANT	\N	PRESENT	0
236833	232945	16685X	PARTICIPANT	\N	PRESENT	0
236834	232945	19319Q	PARTICIPANT	\N	PRESENT	0
236835	232945	04089T	PARTICIPANT	\N	PRESENT	0
236836	232945	19369B	PARTICIPANT	\N	PRESENT	0
236837	232945	19691J	PARTICIPANT	\N	PRESENT	0
236838	232945	07004J	PARTICIPANT	\N	PRESENT	0
236839	232945	08009T	PARTICIPANT	\N	PRESENT	0
236840	232945	19511N	PARTICIPANT	\N	PRESENT	0
236841	232945	19611R	PARTICIPANT	\N	PRESENT	0
236842	232945	19619A	PARTICIPANT	\N	PRESENT	0
236843	232945	19739H	PARTICIPANT	\N	PRESENT	0
236844	232945	19699S	PARTICIPANT	\N	PRESENT	0
236845	232945	14221J	PARTICIPANT	\N	PRESENT	0
236846	232945	14073Q	PARTICIPANT	\N	PRESENT	0
236847	232945	14267Y	PARTICIPANT	\N	PRESENT	0
236848	232945	14083S	PARTICIPANT	\N	PRESENT	0
236849	232945	19521Q	PARTICIPANT	\N	PRESENT	0
236850	232945	14123H	PARTICIPANT	\N	PRESENT	0
236851	232945	19749K	PARTICIPANT	\N	PRESENT	0
236852	232945	11085T	PARTICIPANT	\N	PRESENT	0
236853	232945	14103D	PARTICIPANT	\N	PRESENT	0
236854	232945	04071H	PARTICIPANT	\N	PRESENT	0
236856	232945	19721W	PARTICIPANT	\N	PRESENT	0
236857	232945	14169X	PARTICIPANT	\N	PRESENT	0
236858	232945	04061F	PARTICIPANT	\N	PRESENT	0
236859	232945	05012A	PARTICIPANT	\N	PRESENT	0
236860	232945	14159V	PARTICIPANT	\N	PRESENT	0
236861	232945	11026G	PARTICIPANT	\N	PRESENT	0
236862	232945	19675J	PARTICIPANT	\N	PRESENT	0
236863	232945	95067Q	PARTICIPANT	\N	PRESENT	0
236864	232945	14259Y	PARTICIPANT	\N	PRESENT	0
236865	232945	14089Y	PARTICIPANT	\N	PRESENT	0
236866	232945	19657G	PARTICIPANT	\N	PRESENT	0
236867	232945	11053K	PARTICIPANT	\N	PRESENT	0
236869	232945	14085U	PARTICIPANT	\N	PRESENT	0
237179	232946	04059M	PARTICIPANT	\N	PRESENT	0
237181	237180	11053K	PARTICIPANT	\N	PRESENT	0
237182	237180	14159V	PARTICIPANT	\N	PRESENT	0
237183	237180	05012A	PARTICIPANT	\N	PRESENT	0
237279	232946	19527W	PARTICIPANT	\N	PRESENT	0
237430	235532	14026U	PARTICIPANT	\N	PRESENT	0
237431	235532	17779H	PARTICIPANT	\N	PRESENT	0
237432	235532	11031D	PARTICIPANT	\N	PRESENT	0
237433	235532	19553Y	PARTICIPANT	\N	PRESENT	0
237434	235532	19679N	PARTICIPANT	\N	PRESENT	0
237435	235532	19575F	PARTICIPANT	\N	PRESENT	0
237436	235532	19335Q	PARTICIPANT	\N	PRESENT	0
237437	235532	10006L	PARTICIPANT	\N	PRESENT	0
237438	235532	19521Q	PARTICIPANT	\N	PRESENT	0
237439	235532	01034P	PARTICIPANT	\N	PRESENT	0
237440	235532	19663E	PARTICIPANT	\N	PRESENT	0
237441	235532	19715Y	PARTICIPANT	\N	PRESENT	0
237442	235532	19723Y	PARTICIPANT	\N	PRESENT	0
237443	235532	19577H	PARTICIPANT	\N	PRESENT	0
237444	235532	08048B	PARTICIPANT	\N	EXCUSE	0
237445	235429	19319Q	PARTICIPANT	\N	PRESENT	0
237446	235429	14105F	PARTICIPANT	\N	PRESENT	0
237447	235429	19443T	PARTICIPANT	\N	PRESENT	0
237448	235429	98018T	PARTICIPANT	\N	PRESENT	0
237449	235429	19421M	PARTICIPANT	\N	PRESENT	0
237450	235429	14235Q	PARTICIPANT	\N	PRESENT	0
237451	235429	98050T	PARTICIPANT	\N	PRESENT	0
237452	235429	04042C	PRESIDENT	0	PRESENT	0
237453	235429	11066Q	PARTICIPANT	\N	PRESENT	0
237454	235429	14211G	PARTICIPANT	\N	PRESENT	0
237455	235429	14097Y	PARTICIPANT	\N	PRESENT	0
237456	235429	95067Q	PARTICIPANT	\N	PRESENT	0
237457	235429	01058X	PARTICIPANT	\N	PRESENT	0
237458	235429	14028W	PARTICIPANT	\N	PRESENT	0
237459	235429	95037J	PARTICIPANT	\N	PRESENT	0
237460	235429	08053X	PARTICIPANT	\N	PRESENT	0
237461	235429	14255U	PARTICIPANT	\N	PRESENT	0
237462	235429	04035D	PARTICIPANT	\N	PRESENT	0
237463	235429	08047A	PARTICIPANT	\N	PRESENT	0
237464	235429	04040A	PARTICIPANT	\N	PRESENT	0
237465	235429	16685X	PARTICIPANT	\N	PRESENT	0
237466	235429	11054L	PARTICIPANT	\N	PRESENT	0
237467	235429	14193X	PARTICIPANT	\N	PRESENT	0
237468	235429	08061X	PARTICIPANT	\N	PRESENT	0
237469	235429	01062T	PARTICIPANT	\N	PRESENT	0
237470	235429	08058D	PARTICIPANT	\N	PRESENT	0
237471	235429	19721W	PARTICIPANT	\N	PRESENT	0
237472	235429	98022P	PARTICIPANT	\N	PRESENT	0
237473	235429	11064N	PARTICIPANT	\N	PRESENT	0
237474	235429	14267Y	PARTICIPANT	\N	PRESENT	0
237475	235429	19583F	PARTICIPANT	\N	PRESENT	0
237476	235429	19251M	PARTICIPANT	\N	PRESENT	0
237477	235429	14133K	PARTICIPANT	\N	PRESENT	0
237478	235429	11027H	PARTICIPANT	\N	PRESENT	0
237479	235429	11115U	PARTICIPANT	\N	PRESENT	0
237504	235613	19515S	PARTICIPANT	\N	PRESENT	0
237505	235613	01043Q	PARTICIPANT	\N	PRESENT	0
237506	235613	19565D	PARTICIPANT	\N	PRESENT	0
237507	235613	19441R	PARTICIPANT	\N	PRESENT	0
237508	235613	14081Q	PARTICIPANT	\N	PRESENT	0
237509	235613	19413M	PARTICIPANT	\N	PRESENT	0
237510	235613	80013X	PARTICIPANT	\N	PRESENT	0
237511	235613	19631V	PARTICIPANT	\N	PRESENT	0
237512	235613	11099A	PARTICIPANT	\N	PRESENT	0
237513	235613	08068F	PARTICIPANT	\N	PRESENT	0
237514	235613	04049K	PARTICIPANT	\N	PRESENT	0
237515	235613	19707Y	PARTICIPANT	\N	PRESENT	0
237516	235613	08015R	PARTICIPANT	\N	PRESENT	0
237517	235613	08019V	PARTICIPANT	\N	PRESENT	0
237518	235613	14197C	PARTICIPANT	\N	PRESENT	0
237519	235613	19369B	PARTICIPANT	\N	PRESENT	0
237520	235613	19511N	PARTICIPANT	\N	PRESENT	0
237521	235613	08028W	PARTICIPANT	\N	PRESENT	0
237522	235613	19563B	PARTICIPANT	\N	PRESENT	0
237523	235613	14265W	PARTICIPANT	\N	PRESENT	0
237524	235613	19467C	PARTICIPANT	\N	PRESENT	0
237525	235613	14187A	PARTICIPANT	\N	PRESENT	0
237526	235613	08038Y	PARTICIPANT	\N	PRESENT	0
237527	235613	19695N	PARTICIPANT	\N	PRESENT	0
237528	235613	14033T	PARTICIPANT	\N	PRESENT	0
237529	235613	11090Q	PRESIDENT	0	PRESENT	0
237530	235613	01025N	PARTICIPANT	\N	PRESENT	0
237531	235613	19269X	PARTICIPANT	\N	PRESENT	0
237532	235613	14205J	PARTICIPANT	\N	PRESENT	0
237533	235613	04088S	PARTICIPANT	\N	PRESENT	0
237534	235613	19507S	PARTICIPANT	\N	PRESENT	0
237535	235613	19747H	PARTICIPANT	\N	PRESENT	0
237536	235613	14207L	PARTICIPANT	\N	PRESENT	0
237537	235613	19619A	PARTICIPANT	\N	PRESENT	0
237538	235613	17589D	PARTICIPANT	\N	PRESENT	0
237539	235613	14257W	PARTICIPANT	\N	PRESENT	0
237540	235613	18083K	PARTICIPANT	\N	PRESENT	0
237541	235613	14042U	PARTICIPANT	\N	PRESENT	0
211777	211679	01048V	PARTICIPANT	\N	PRESENT	0
217937	217936	04086Q	PARTICIPANT	\N	PRESENT	0
217939	217938	04086Q	PARTICIPANT	\N	PRESENT	0
218499	217582	14121F	PARTICIPANT	\N	PRESENT	0
218501	217582	14034U	PARTICIPANT	\N	EXCUSE	0
220081	210194	11109J	PARTICIPANT	\N	PRESENT	0
220082	210194	14261S	PARTICIPANT	\N	PRESENT	0
220083	210194	14030Q	PARTICIPANT	\N	PRESENT	0
220084	210194	19673G	PARTICIPANT	\N	PRESENT	0
220085	210194	11083R	PARTICIPANT	\N	PRESENT	0
220086	210194	14219Q	PARTICIPANT	\N	PRESENT	0
220087	210194	14265W	PARTICIPANT	\N	PRESENT	0
220088	210194	14135M	PARTICIPANT	\N	PRESENT	0
224677	218298	19511N	PARTICIPANT	\N	PRESENT	0
224678	218298	14255U	PARTICIPANT	\N	PRESENT	0
224699	218298	14205J	PARTICIPANT	\N	PRESENT	0
224680	218298	11070L	PARTICIPANT	\N	PRESENT	0
224681	218298	14327T	PARTICIPANT	\N	PRESENT	0
224682	218298	19447X	PARTICIPANT	\N	PRESENT	0
224683	218298	04089T	PARTICIPANT	\N	PRESENT	0
224684	218298	14179A	PARTICIPANT	\N	PRESENT	0
224697	218298	01043Q	PARTICIPANT	\N	PRESENT	0
224727	218298	14087W	PARTICIPANT	\N	PRESENT	0
224687	218298	01034P	PARTICIPANT	\N	PRESENT	0
224688	218298	07004J	PARTICIPANT	\N	PRESENT	0
224689	218298	14033T	PARTICIPANT	\N	PRESENT	0
224724	218298	11085T	PARTICIPANT	\N	PRESENT	0
224691	218298	19611R	PARTICIPANT	\N	PRESENT	0
224692	218298	11026G	PARTICIPANT	\N	PRESENT	0
224693	218298	10006L	PARTICIPANT	\N	PRESENT	0
224694	218298	19619A	PARTICIPANT	\N	PRESENT	0
224695	218298	19735D	PARTICIPANT	\N	PRESENT	0
224696	218298	19691J	PARTICIPANT	\N	PRESENT	0
224698	218298	19479G	PARTICIPANT	\N	PRESENT	0
224723	218298	16685X	PARTICIPANT	\N	PRESENT	0
224701	218298	14029X	PARTICIPANT	\N	PRESENT	0
224702	218298	14277B	PARTICIPANT	\N	PRESENT	0
224703	218298	14275Y	PARTICIPANT	\N	PRESENT	0
224722	218298	19737F	PARTICIPANT	\N	PRESENT	0
224705	218298	19569H	PARTICIPANT	\N	PRESENT	0
224706	218298	14267Y	PARTICIPANT	\N	PRESENT	0
224707	218298	19699S	PARTICIPANT	\N	PRESENT	0
224708	218298	14083S	PARTICIPANT	\N	PRESENT	0
224709	218298	19709B	PARTICIPANT	\N	PRESENT	0
224710	218298	19335Q	PARTICIPANT	\N	PRESENT	0
224711	218298	04088S	PARTICIPANT	\N	PRESENT	0
224712	218298	19739H	PARTICIPANT	\N	PRESENT	0
224713	218298	14221J	PARTICIPANT	\N	PRESENT	0
224714	218298	14103D	PARTICIPANT	\N	PRESENT	0
224715	218298	19713W	PARTICIPANT	\N	PRESENT	0
224716	218298	19441R	PARTICIPANT	\N	PRESENT	0
224717	218298	14253S	PARTICIPANT	\N	PRESENT	0
224718	218298	19663E	PARTICIPANT	\N	PRESENT	0
224719	218298	14039A	PARTICIPANT	\N	PRESENT	0
224720	218298	19367Y	PARTICIPANT	\N	PRESENT	0
224721	218298	19521Q	PARTICIPANT	\N	PRESENT	0
224725	218298	14135M	PARTICIPANT	\N	PRESENT	0
224726	218298	19369B	PARTICIPANT	\N	PRESENT	0
224728	218298	04044E	PARTICIPANT	\N	PRESENT	0
224729	218298	14115H	PARTICIPANT	\N	PRESENT	0
224730	218298	19467C	PARTICIPANT	\N	PRESENT	0
224731	218298	05012A	PARTICIPANT	\N	PRESENT	0
224970	223696	89017R	PARTICIPANT	\N	PRESENT	0
225701	222532	14069U	PARTICIPANT	\N	PRESENT	0
224972	223696	19667J	PARTICIPANT	\N	PRESENT	0
224973	223696	11040E	PARTICIPANT	\N	PRESENT	0
224974	223696	08014Q	PARTICIPANT	\N	PRESENT	0
224975	223696	14083S	PARTICIPANT	\N	PRESENT	0
225702	222532	19525U	PARTICIPANT	\N	PRESENT	0
224977	223696	19545Y	PARTICIPANT	\N	PRESENT	0
224978	223696	14085U	PARTICIPANT	\N	PRESENT	0
224979	223696	88008L	PARTICIPANT	\N	PRESENT	0
224980	223696	04086Q	PARTICIPANT	\N	PRESENT	0
224981	223696	11070L	PARTICIPANT	\N	PRESENT	0
224982	223696	14327T	PARTICIPANT	\N	PRESENT	0
225703	222532	04086Q	PARTICIPANT	\N	PRESENT	0
224984	223696	11074Q	PRESIDENT	0	PRESENT	0
224985	223696	11110B	PARTICIPANT	\N	PRESENT	0
224986	223696	19647E	PARTICIPANT	\N	PRESENT	0
224987	223696	14034U	PARTICIPANT	\N	PRESENT	0
224988	223696	14199E	PARTICIPANT	\N	PRESENT	0
224989	223696	07004J	PARTICIPANT	\N	PRESENT	0
224990	223696	01057W	PARTICIPANT	\N	PRESENT	0
224991	223696	08069G	PARTICIPANT	\N	EXCUSE	0
225704	222532	19565D	PARTICIPANT	\N	PRESENT	0
224993	223696	14121F	PARTICIPANT	\N	PRESENT	0
224994	223696	19531S	PARTICIPANT	\N	PRESENT	0
224995	223696	95041E	PARTICIPANT	\N	PRESENT	0
224996	223696	99004R	PARTICIPANT	\N	PRESENT	0
224997	223696	04061F	PARTICIPANT	\N	PRESENT	0
224998	223696	14159V	PARTICIPANT	\N	PRESENT	0
224999	223696	07029T	PARTICIPANT	\N	PRESENT	0
225000	223696	14277B	PARTICIPANT	\N	PRESENT	0
225001	223696	19711U	PARTICIPANT	\N	PRESENT	0
225002	223696	08010L	PARTICIPANT	\N	PRESENT	0
225003	223696	08034U	PARTICIPANT	\N	PRESENT	0
225004	223696	01048V	PARTICIPANT	\N	PRESENT	0
225705	222532	14063N	PARTICIPANT	\N	PRESENT	0
225006	223696	19671E	PARTICIPANT	\N	PRESENT	0
225007	223696	08011M	PARTICIPANT	\N	PRESENT	0
225008	223696	14253S	PARTICIPANT	\N	PRESENT	0
225009	223696	08073C	PARTICIPANT	\N	PRESENT	0
225010	223696	19349W	PARTICIPANT	\N	PRESENT	0
225011	223696	14331P	PARTICIPANT	\N	PRESENT	0
225012	223696	14225N	PARTICIPANT	\N	PRESENT	0
225013	223696	11012A	PARTICIPANT	\N	PRESENT	0
225706	222532	14028W	PARTICIPANT	\N	PRESENT	0
225015	223696	19689Q	PARTICIPANT	\N	PRESENT	0
225016	223696	19479G	PARTICIPANT	\N	PRESENT	0
225017	223696	14173T	PARTICIPANT	\N	PRESENT	0
225707	222532	19687N	PARTICIPANT	\N	PRESENT	0
225708	222532	04045F	PARTICIPANT	\N	PRESENT	0
225709	222532	08034U	PARTICIPANT	\N	PRESENT	0
225710	222532	08010L	PARTICIPANT	\N	PRESENT	0
225711	222532	11048N	PARTICIPANT	\N	PRESENT	0
225712	222532	11049P	PARTICIPANT	\N	PRESENT	0
225713	222532	14327T	PARTICIPANT	\N	PRESENT	0
225714	222532	11043H	PARTICIPANT	\N	PRESENT	0
225715	222532	14281W	PARTICIPANT	\N	PRESENT	0
226158	225830	19711U	PARTICIPANT	\N	PRESENT	0
226159	225830	08034U	PARTICIPANT	\N	PRESENT	0
226160	225830	19689Q	PARTICIPANT	\N	PRESENT	0
226161	225830	11053K	PARTICIPANT	\N	PRESENT	0
226162	225830	99004R	PARTICIPANT	\N	PRESENT	0
226163	225830	08011M	PARTICIPANT	\N	PRESENT	0
226164	225830	11074Q	PRESIDENT	0	PRESENT	0
226165	225830	04061F	PARTICIPANT	\N	PRESENT	0
226166	225830	14327T	PARTICIPANT	\N	EXCUSE	0
226167	225830	07029T	PARTICIPANT	\N	EXCUSE	0
226168	225830	14083S	PARTICIPANT	\N	EXCUSE	0
226169	225830	19667J	PARTICIPANT	\N	EXCUSE	0
226170	218306	14033T	PARTICIPANT	\N	PRESENT	0
226485	218443	14001X	PARTICIPANT	\N	PRESENT	0
226486	218443	14030Q	PARTICIPANT	\N	PRESENT	0
226487	218443	19347U	PARTICIPANT	\N	PRESENT	0
226488	218443	14219Q	PARTICIPANT	\N	PRESENT	0
226489	218443	19441R	PARTICIPANT	\N	PRESENT	0
226490	218443	19713W	PARTICIPANT	\N	PRESENT	0
226491	218443	19443T	PARTICIPANT	\N	PRESENT	0
226492	218443	19415P	PARTICIPANT	\N	PRESENT	0
226493	226099	14173T	PARTICIPANT	\N	PRESENT	0
226494	218443	19565D	PARTICIPANT	\N	PRESENT	0
226495	218443	19733B	PARTICIPANT	\N	PRESENT	0
226496	218443	11063M	PARTICIPANT	\N	PRESENT	0
226497	218443	18083K	PARTICIPANT	\N	PRESENT	0
226498	218443	19447X	PARTICIPANT	\N	PRESENT	0
226508	218443	14241N	PARTICIPANT	\N	PRESENT	0
226509	218443	19701S	PARTICIPANT	\N	PRESENT	0
226510	218443	80013X	PARTICIPANT	\N	PRESENT	0
226511	218443	19693L	PARTICIPANT	\N	PRESENT	0
226512	218443	19593H	PARTICIPANT	\N	PRESENT	0
226513	218443	19687N	PARTICIPANT	\N	PRESENT	0
226514	218443	19479G	PARTICIPANT	\N	PRESENT	0
226515	218443	19699S	PARTICIPANT	\N	PRESENT	0
226516	218443	19543W	PARTICIPANT	\N	PRESENT	0
226517	218443	19581D	PARTICIPANT	\N	PRESENT	0
226518	218443	11027H	PARTICIPANT	\N	PRESENT	0
226519	218443	14179A	PARTICIPANT	\N	PRESENT	0
226520	218443	95041E	PARTICIPANT	\N	PRESENT	0
226521	218443	19667J	PARTICIPANT	\N	PRESENT	0
226522	218443	01060R	PARTICIPANT	\N	PRESENT	0
226523	218443	14111D	PARTICIPANT	\N	PRESENT	0
226540	218443	14053L	PARTICIPANT	\N	PRESENT	0
226541	218443	19573D	PARTICIPANT	\N	PRESENT	0
226542	218443	14225N	PARTICIPANT	\N	PRESENT	0
226543	218443	17637T	PARTICIPANT	\N	PRESENT	0
226544	218443	14083S	PARTICIPANT	\N	PRESENT	0
226545	218443	07033P	PARTICIPANT	\N	PRESENT	0
227623	225954	14221J	PARTICIPANT	\N	PRESENT	0
230787	230786	95067Q	PARTICIPANT	\N	PRESENT	0
230788	230786	14028W	PARTICIPANT	\N	PRESENT	0
230904	220072	05008E	PARTICIPANT	\N	PRESENT	0
230905	220072	08015R	PARTICIPANT	\N	PRESENT	0
230906	220072	11012A	PARTICIPANT	\N	PRESENT	0
230907	220072	08016S	PARTICIPANT	\N	PRESENT	0
230908	220072	14199E	PARTICIPANT	\N	PRESENT	0
230912	220072	14069U	PARTICIPANT	\N	PRESENT	0
230913	220072	19715Y	PARTICIPANT	\N	PRESENT	0
230914	220072	14061L	PARTICIPANT	\N	PRESENT	0
230979	230978	08020N	PARTICIPANT	\N	PRESENT	0
230980	230978	14195A	PARTICIPANT	\N	PRESENT	0
230982	230978	11064N	PARTICIPANT	\N	PRESENT	0
230983	230978	19583F	PARTICIPANT	\N	PRESENT	0
230984	230978	04057K	PARTICIPANT	\N	PRESENT	0
230985	230978	14265W	PARTICIPANT	\N	PRESENT	0
230987	230978	04088S	PARTICIPANT	\N	PRESENT	0
230988	230978	19585H	PARTICIPANT	\N	PRESENT	0
231108	231107	14255U	PARTICIPANT	\N	PRESENT	0
232708	230033	98053W	PARTICIPANT	\N	EXCUSE	0
232709	230033	98022P	PARTICIPANT	\N	EXCUSE	0
232710	230033	19583F	PARTICIPANT	\N	EXCUSE	0
233006	233005	19563B	PARTICIPANT	\N	PRESENT	0
233019	232539	19551W	PARTICIPANT	\N	PRESENT	0
233047	233046	14123H	PARTICIPANT	\N	PRESENT	0
233197	232539	08045X	PARTICIPANT	\N	EXCUSE	0
233209	233208	96004D	PARTICIPANT	\N	PRESENT	0
233210	233208	14089Y	PARTICIPANT	\N	PRESENT	0
233211	233208	11083R	PARTICIPANT	\N	PRESENT	0
233212	233208	14097Y	PARTICIPANT	\N	PRESENT	0
233213	233208	04061F	PARTICIPANT	\N	PRESENT	0
233214	233208	14221J	PARTICIPANT	\N	PRESENT	0
233334	232938	11072N	PARTICIPANT	\N	PRESENT	0
233336	232938	19737F	PARTICIPANT	\N	PRESENT	0
233337	232938	14187A	PARTICIPANT	\N	PRESENT	0
233338	232938	19631V	PARTICIPANT	\N	PRESENT	0
233339	232938	01062T	PARTICIPANT	\N	PRESENT	0
233340	232938	19443T	PARTICIPANT	\N	PRESENT	0
233341	232938	10015M	PARTICIPANT	\N	PRESENT	0
233342	232938	19591F	PARTICIPANT	\N	PRESENT	0
233343	232938	19527W	PARTICIPANT	\N	PRESENT	0
233344	232938	19301E	PARTICIPANT	\N	PRESENT	0
233345	232938	11031D	PARTICIPANT	\N	PRESENT	0
233346	232938	19441R	PARTICIPANT	\N	PRESENT	0
233347	232938	08020N	PARTICIPANT	\N	PRESENT	0
233353	232938	19735D	PARTICIPANT	\N	PRESENT	0
233351	232938	14207L	PARTICIPANT	\N	PRESENT	0
233352	232938	19415P	PARTICIPANT	\N	PRESENT	0
233354	232938	97011G	PARTICIPANT	\N	PRESENT	0
233355	232938	08010L	PARTICIPANT	\N	PRESENT	0
233356	232938	19713W	PARTICIPANT	\N	PRESENT	0
233359	232938	19507S	PARTICIPANT	\N	PRESENT	0
233360	232938	11054L	PARTICIPANT	\N	PRESENT	0
233361	232938	04040A	PARTICIPANT	\N	PRESENT	0
233362	232938	19573D	PARTICIPANT	\N	PRESENT	0
233363	232938	14265W	PARTICIPANT	\N	PRESENT	0
233364	232938	14193X	PARTICIPANT	\N	PRESENT	0
233365	232938	14197C	PARTICIPANT	\N	PRESENT	0
233366	232938	98050T	PARTICIPANT	\N	PRESENT	0
233367	232938	18083K	PARTICIPANT	\N	PRESENT	0
233368	232938	08045X	PARTICIPANT	\N	PRESENT	0
233369	232938	19695N	PARTICIPANT	\N	PRESENT	0
233370	232938	95067Q	PARTICIPANT	\N	PRESENT	0
233371	232938	19531S	PARTICIPANT	\N	PRESENT	0
233373	232938	19691J	PARTICIPANT	\N	PRESENT	0
233374	232938	04034C	PARTICIPANT	\N	PRESENT	0
233375	232938	19253P	PARTICIPANT	\N	PRESENT	0
233376	232938	14133K	PARTICIPANT	\N	PRESENT	0
233377	232874	19651A	PARTICIPANT	\N	PRESENT	0
233378	232874	19713W	PARTICIPANT	\N	PRESENT	0
233379	232539	19647E	PARTICIPANT	\N	PRESENT	0
233389	232539	19711U	PARTICIPANT	\N	EXCUSE	0
233390	232939	01043Q	PARTICIPANT	\N	PRESENT	0
233391	232939	19347U	PARTICIPANT	\N	PRESENT	0
233392	232939	80027E	PARTICIPANT	\N	PRESENT	0
233393	232939	19503N	PARTICIPANT	\N	PRESENT	0
233394	232939	19333N	PARTICIPANT	\N	PRESENT	0
233395	232939	08055A	PARTICIPANT	\N	PRESENT	0
233387	232539	19629C	PARTICIPANT	\N	EXCUSE	0
233388	232539	08024S	PARTICIPANT	\N	PRESENT	0
233396	232939	19737F	PARTICIPANT	\N	PRESENT	0
233397	232939	19749K	PARTICIPANT	\N	PRESENT	0
233398	232939	18083K	PARTICIPANT	\N	PRESENT	0
233399	232939	14033T	PARTICIPANT	\N	PRESENT	0
233400	232939	19741B	PARTICIPANT	\N	PRESENT	0
233401	232939	19443T	PARTICIPANT	\N	PRESENT	0
233402	232939	19549D	PARTICIPANT	\N	PRESENT	0
233403	232939	11040E	PARTICIPANT	\N	PRESENT	0
233404	232939	99004R	PARTICIPANT	\N	PRESENT	0
233405	232939	08015R	PARTICIPANT	\N	PRESENT	0
233406	232939	95067Q	PARTICIPANT	\N	PRESENT	0
233407	232939	19637C	PARTICIPANT	\N	PRESENT	0
233408	232939	19701S	PARTICIPANT	\N	PRESENT	0
233409	232939	14069U	PARTICIPANT	\N	PRESENT	0
233411	232939	14249W	PARTICIPANT	\N	PRESENT	0
233412	232939	19387D	PARTICIPANT	\N	PRESENT	0
233413	232939	19543W	PARTICIPANT	\N	PRESENT	0
233414	232939	19681G	PARTICIPANT	\N	PRESENT	0
233415	232939	14219Q	PARTICIPANT	\N	PRESENT	0
233416	232939	08056B	PARTICIPANT	\N	PRESENT	0
233417	232939	14103D	PARTICIPANT	\N	PRESENT	0
233418	232939	19739H	PARTICIPANT	\N	PRESENT	0
233419	232939	19575F	PARTICIPANT	\N	PRESENT	0
233420	232939	01024M	PARTICIPANT	\N	PRESENT	0
233421	232939	19551W	PARTICIPANT	\N	PRESENT	0
233422	232939	19747H	PARTICIPANT	\N	PRESENT	0
233423	232939	01058X	PARTICIPANT	\N	PRESENT	0
233424	232939	19563B	PARTICIPANT	\N	PRESENT	0
233425	232939	95015C	PARTICIPANT	\N	PRESENT	0
233426	232939	19289C	PARTICIPANT	\N	PRESENT	0
233427	232939	19651A	PARTICIPANT	\N	PRESENT	0
233428	232939	14237S	PARTICIPANT	\N	PRESENT	0
233429	232939	11056N	PARTICIPANT	\N	PRESENT	0
233430	232939	02002K	PARTICIPANT	\N	PRESENT	0
233431	232939	19629C	PARTICIPANT	\N	PRESENT	0
233432	232939	14089Y	PARTICIPANT	\N	PRESENT	0
233433	232939	04061F	PARTICIPANT	\N	PRESENT	0
233434	232939	14071N	PARTICIPANT	\N	PRESENT	0
233435	232939	14193X	PARTICIPANT	\N	PRESENT	0
233436	232939	14121F	PARTICIPANT	\N	PRESENT	0
233437	232939	11031D	PARTICIPANT	\N	PRESENT	0
233438	232939	08058D	PARTICIPANT	\N	PRESENT	0
233439	232939	19693L	PARTICIPANT	\N	PRESENT	0
233440	232939	98050T	PARTICIPANT	\N	PRESENT	0
233441	232939	19383Y	PARTICIPANT	\N	PRESENT	0
233442	232939	19531S	PARTICIPANT	\N	PRESENT	0
233443	232939	19583F	PARTICIPANT	\N	PRESENT	0
233444	232939	19479G	PARTICIPANT	\N	PRESENT	0
233445	232939	14257W	PARTICIPANT	\N	PRESENT	0
233446	232939	14051J	PARTICIPANT	\N	PRESENT	0
233447	232939	19619A	PARTICIPANT	\N	PRESENT	0
233448	232939	87003B	PARTICIPANT	\N	PRESENT	0
233449	233061	19527W	PARTICIPANT	\N	PRESENT	0
233450	233061	11067R	PARTICIPANT	\N	PRESENT	0
233451	233061	04092N	PRESIDENT	0	PRESENT	0
233452	233061	11097X	PARTICIPANT	\N	PRESENT	0
233453	233061	04045F	PARTICIPANT	\N	PRESENT	0
233454	233061	19723Y	PARTICIPANT	\N	PRESENT	0
233455	233061	14239U	PARTICIPANT	\N	PRESENT	0
233456	233061	19703U	PARTICIPANT	\N	PRESENT	0
233457	233061	14087W	PARTICIPANT	\N	PRESENT	0
233458	233061	14042U	PARTICIPANT	\N	PRESENT	0
233459	233061	19575F	PARTICIPANT	\N	PRESENT	0
233460	233061	19367Y	PARTICIPANT	\N	PRESENT	0
233461	233061	14071N	PARTICIPANT	\N	PRESENT	0
233462	233061	19335Q	PARTICIPANT	\N	PRESENT	0
233463	233061	19683J	PARTICIPANT	\N	PRESENT	0
233464	233061	19569H	PARTICIPANT	\N	PRESENT	0
233465	233061	14195A	PARTICIPANT	\N	PRESENT	0
233466	232939	17583W	PARTICIPANT	\N	PRESENT	0
233467	232939	04085P	PARTICIPANT	\N	PRESENT	0
233468	232939	14267Y	PARTICIPANT	\N	PRESENT	0
233469	232939	95062K	PARTICIPANT	\N	PRESENT	0
233470	232939	14211G	PARTICIPANT	\N	PRESENT	0
233471	233061	19663E	PARTICIPANT	\N	PRESENT	0
233472	233061	17779H	PARTICIPANT	\N	PRESENT	0
233473	233061	14119M	PARTICIPANT	\N	PRESENT	0
233474	233061	14213J	PARTICIPANT	\N	PRESENT	0
233475	232939	19253P	PARTICIPANT	\N	PRESENT	0
233476	232939	08060W	PARTICIPANT	\N	PRESENT	0
233477	232939	14147R	PARTICIPANT	\N	PRESENT	0
233478	232939	14215L	PARTICIPANT	\N	PRESENT	0
233479	232939	14038Y	PARTICIPANT	\N	PRESENT	0
233480	232939	14235Q	PARTICIPANT	\N	PRESENT	0
233481	232939	19349W	PARTICIPANT	\N	PRESENT	0
233482	232939	11012A	PARTICIPANT	\N	PRESENT	0
233483	232939	14053L	PARTICIPANT	\N	PRESENT	0
233484	232939	19713W	PARTICIPANT	\N	PRESENT	0
211917	210045	19515S	PARTICIPANT	\N	PRESENT	0
211918	210045	19651A	PARTICIPANT	\N	PRESENT	0
211919	210045	19629C	PARTICIPANT	\N	PRESENT	0
211920	210045	08024S	PARTICIPANT	\N	PRESENT	0
211921	210045	19467C	PARTICIPANT	\N	PRESENT	0
211922	210045	19399H	PARTICIPANT	\N	PRESENT	0
211923	210045	19551W	PARTICIPANT	\N	PRESENT	0
211924	210045	99004R	PRESIDENT	0	PRESENT	0
211925	210045	19711U	PARTICIPANT	\N	PRESENT	0
211926	210045	08012N	PARTICIPANT	\N	PRESENT	0
211927	210045	08062Y	PARTICIPANT	\N	PRESENT	0
211928	210045	17637T	PARTICIPANT	\N	PRESENT	0
211929	210045	14147R	PARTICIPANT	\N	PRESENT	0
211930	210045	14107H	PARTICIPANT	\N	PRESENT	0
211931	210045	19421M	PARTICIPANT	\N	PRESENT	0
211932	210045	11097X	PARTICIPANT	\N	PRESENT	0
211933	210045	01028R	PARTICIPANT	\N	PRESENT	0
211934	210045	11066Q	PARTICIPANT	\N	PRESENT	0
211935	210045	19479G	PARTICIPANT	\N	PRESENT	0
211936	210045	19737F	PARTICIPANT	\N	PRESENT	0
213246	213148	11074Q	PARTICIPANT	\N	PRESENT	0
213267	213266	11074Q	PARTICIPANT	\N	PRESENT	0
213277	212976	04086Q	PARTICIPANT	\N	PRESENT	0
215995	214550	14239U	PARTICIPANT	\N	PRESENT	0
215996	214550	14261S	PARTICIPANT	\N	PRESENT	0
215997	214550	19575F	PARTICIPANT	\N	PRESENT	0
215998	214550	19367Y	PARTICIPANT	\N	PRESENT	0
215999	214550	19415P	PARTICIPANT	\N	PRESENT	0
216000	214550	11103C	PARTICIPANT	\N	PRESENT	0
216001	214550	14195A	PARTICIPANT	\N	PRESENT	0
216002	214550	08052W	PARTICIPANT	\N	PRESENT	0
216003	214550	19663E	PARTICIPANT	\N	PRESENT	0
216004	214550	98024R	PARTICIPANT	\N	PRESENT	0
216005	214550	10006L	PARTICIPANT	\N	PRESENT	0
216006	214550	14217N	PARTICIPANT	\N	PRESENT	0
216007	214550	14042U	PARTICIPANT	\N	PRESENT	0
216008	214550	14281W	PARTICIPANT	\N	PRESENT	0
216009	214550	19521Q	PARTICIPANT	\N	PRESENT	0
216010	214550	08048B	PARTICIPANT	\N	PRESENT	0
216011	214550	19727D	PARTICIPANT	\N	PRESENT	0
216012	214550	14026U	PARTICIPANT	\N	PRESENT	0
216013	214550	19691J	PARTICIPANT	\N	PRESENT	0
216014	214550	19715Y	PARTICIPANT	\N	PRESENT	0
216015	214550	19723Y	PARTICIPANT	\N	PRESENT	0
216016	214550	17779H	PARTICIPANT	\N	PRESENT	0
216017	214550	19657G	PARTICIPANT	\N	PRESENT	0
216018	214550	11067R	PARTICIPANT	\N	PRESENT	0
216019	214550	14223L	PARTICIPANT	\N	PRESENT	0
216020	214550	04092N	PRESIDENT	0	PRESENT	0
216021	214550	14119M	PARTICIPANT	\N	PRESENT	0
216022	214550	14071N	PARTICIPANT	\N	EXCUSE	0
216023	214550	19679N	PARTICIPANT	\N	PRESENT	0
216024	214550	11097X	PARTICIPANT	\N	PRESENT	0
216025	214550	04045F	PARTICIPANT	\N	PRESENT	0
216026	214550	19703U	PARTICIPANT	\N	PRESENT	0
216027	214550	19675J	PARTICIPANT	\N	PRESENT	0
216028	214550	14227Q	PARTICIPANT	\N	PRESENT	0
216029	214550	19527W	PARTICIPANT	\N	PRESENT	0
216030	214550	01034P	PARTICIPANT	\N	PRESENT	0
216031	214550	19697Q	PARTICIPANT	\N	PRESENT	0
216032	214550	07029T	PARTICIPANT	\N	PRESENT	0
220000	219967	95067Q	PARTICIPANT	\N	PRESENT	0
220001	219967	01058X	PARTICIPANT	\N	PRESENT	0
220002	219967	19669L	PARTICIPANT	\N	PRESENT	0
220003	219967	19251M	PARTICIPANT	\N	PRESENT	0
220004	219967	11027H	PARTICIPANT	\N	PRESENT	0
220005	219967	11041F	PARTICIPANT	\N	PRESENT	0
220006	219967	01062T	PARTICIPANT	\N	PRESENT	0
220007	219967	14235Q	PARTICIPANT	\N	PRESENT	0
220008	219967	14255U	PARTICIPANT	\N	PRESENT	0
220009	219967	98029W	PARTICIPANT	\N	PRESENT	0
220010	219967	11074Q	PARTICIPANT	\N	PRESENT	0
220011	219967	08011M	PARTICIPANT	\N	PRESENT	0
220012	219967	19443T	PARTICIPANT	\N	PRESENT	0
220013	219967	19421M	PARTICIPANT	\N	PRESENT	0
220014	219967	19709B	PARTICIPANT	\N	PRESENT	0
220015	219967	98050T	PARTICIPANT	\N	PRESENT	0
220016	219967	19583F	PARTICIPANT	\N	PRESENT	0
220017	219967	16685X	PARTICIPANT	\N	PRESENT	0
220018	219967	04040A	PARTICIPANT	\N	PRESENT	0
220019	219967	04034C	PARTICIPANT	\N	PRESENT	0
220020	219967	98018T	PARTICIPANT	\N	PRESENT	0
220052	219964	14221J	PARTICIPANT	\N	EXCUSE	0
225145	222384	14079W	PARTICIPANT	\N	EXCUSE	0
225146	222384	98053W	PARTICIPANT	\N	EXCUSE	0
225147	222384	97011G	PARTICIPANT	\N	EXCUSE	0
225148	222384	08056B	PARTICIPANT	\N	EXCUSE	0
225149	222384	19583F	PARTICIPANT	\N	EXCUSE	0
225206	222386	19583F	PARTICIPANT	\N	EXCUSE	0
225153	222386	04040A	PARTICIPANT	\N	PRESENT	0
225154	222386	14105F	PARTICIPANT	\N	PRESENT	0
225155	222386	08058D	PARTICIPANT	\N	PRESENT	0
225156	222386	14255U	PARTICIPANT	\N	PRESENT	0
225157	222386	04042C	PRESIDENT	0	PRESENT	0
225158	222386	19721W	PARTICIPANT	\N	PRESENT	0
225159	222386	98029W	PARTICIPANT	\N	PRESENT	0
225160	222386	11080N	PARTICIPANT	\N	PRESENT	0
225161	222386	14267Y	PARTICIPANT	\N	PRESENT	0
225162	222386	11027H	PARTICIPANT	\N	PRESENT	0
225163	222386	11115U	PARTICIPANT	\N	PRESENT	0
225164	222386	14079W	PARTICIPANT	\N	EXCUSE	0
227787	227786	05008E	PARTICIPANT	\N	PRESENT	0
225166	222386	19251M	PARTICIPANT	\N	PRESENT	0
225167	222386	95030B	PARTICIPANT	\N	PRESENT	0
225168	222386	98053W	PARTICIPANT	\N	EXCUSE	0
225169	222386	97011G	PARTICIPANT	\N	EXCUSE	0
225170	222386	04035D	PARTICIPANT	\N	PRESENT	0
225171	222386	08056B	PARTICIPANT	\N	EXCUSE	0
225172	222386	14211G	PARTICIPANT	\N	PRESENT	0
225173	222386	98022P	PARTICIPANT	\N	PRESENT	0
225174	222386	11064N	PARTICIPANT	\N	PRESENT	0
225175	222386	95037J	PARTICIPANT	\N	PRESENT	0
225176	222386	14097Y	PARTICIPANT	\N	PRESENT	0
227788	227786	14259Y	PARTICIPANT	\N	PRESENT	0
227789	227786	11085T	PARTICIPANT	\N	PRESENT	0
225179	222386	19709B	PARTICIPANT	\N	PRESENT	0
225180	222386	16685X	PARTICIPANT	\N	PRESENT	0
225181	222386	08053X	PARTICIPANT	\N	PRESENT	0
225182	222386	08061X	PARTICIPANT	\N	PRESENT	0
225183	222386	08047A	PARTICIPANT	\N	PRESENT	0
225184	222386	14028W	PARTICIPANT	\N	PRESENT	0
227790	227786	19649G	PARTICIPANT	\N	PRESENT	0
227791	227786	19591F	PARTICIPANT	\N	PRESENT	0
225187	222386	98050T	PARTICIPANT	\N	PRESENT	0
225188	222386	14235Q	PARTICIPANT	\N	PRESENT	0
225189	222386	19443T	PARTICIPANT	\N	PRESENT	0
225190	222386	14055N	PARTICIPANT	\N	PRESENT	0
225191	222386	11054L	PARTICIPANT	\N	PRESENT	0
225192	222386	19421M	PARTICIPANT	\N	PRESENT	0
225193	222386	01058X	PARTICIPANT	\N	PRESENT	0
225194	222386	19669L	PARTICIPANT	\N	PRESENT	0
225195	222386	01062T	PARTICIPANT	\N	PRESENT	0
225196	222386	11041F	PARTICIPANT	\N	PRESENT	0
225197	222386	08049C	PARTICIPANT	\N	PRESENT	0
225198	222386	11066Q	PARTICIPANT	\N	PRESENT	0
225199	222386	95067Q	PARTICIPANT	\N	PRESENT	0
225200	222386	04034C	PARTICIPANT	\N	PRESENT	0
227792	227786	19651A	PARTICIPANT	\N	PRESENT	0
227793	227786	14041T	PARTICIPANT	\N	PRESENT	0
227794	227786	19593H	PARTICIPANT	\N	PRESENT	0
227795	227786	01028R	PARTICIPANT	\N	PRESENT	0
227818	218821	19515S	PARTICIPANT	\N	PRESENT	0
227819	218821	08024S	PARTICIPANT	\N	PRESENT	0
227820	218821	04038G	PARTICIPANT	\N	PRESENT	0
227821	218821	08012N	PARTICIPANT	\N	PRESENT	0
227822	218821	19349W	PARTICIPANT	\N	PRESENT	0
227823	218821	14107H	PARTICIPANT	\N	PRESENT	0
227824	218821	01028R	PARTICIPANT	\N	PRESENT	0
227825	218821	11066Q	PARTICIPANT	\N	PRESENT	0
227828	227827	11056N	PARTICIPANT	\N	EXCUSE	0
227886	227827	11066Q	PARTICIPANT	\N	PRESENT	0
228247	227827	08024S	PARTICIPANT	\N	PRESENT	0
239003	232954	19349W	PARTICIPANT	\N	PRESENT	0
239035	238878	08009T	PARTICIPANT	\N	PRESENT	0
239036	238878	14053L	PARTICIPANT	\N	PRESENT	0
239037	238878	96004D	PARTICIPANT	\N	PRESENT	0
239038	238878	14103D	PARTICIPANT	\N	PRESENT	0
239039	238878	88008L	PARTICIPANT	\N	PRESENT	0
239040	238878	17583W	PARTICIPANT	\N	PRESENT	0
239041	238878	14021P	PARTICIPANT	\N	PRESENT	0
239042	238878	14111D	PARTICIPANT	\N	PRESENT	0
239043	238878	19621T	PARTICIPANT	\N	PRESENT	0
239044	238878	19503N	PARTICIPANT	\N	PRESENT	0
239045	238878	19563B	PARTICIPANT	\N	PRESENT	0
239046	238878	19387D	PARTICIPANT	\N	PRESENT	0
239047	238878	14030Q	PARTICIPANT	\N	PRESENT	0
239048	238878	14051J	PARTICIPANT	\N	PRESENT	0
239049	238878	14033T	PARTICIPANT	\N	PRESENT	0
239050	238878	19383Y	PARTICIPANT	\N	PRESENT	0
234843	234842	14073Q	PARTICIPANT	\N	PRESENT	0
234844	234842	11043H	PARTICIPANT	\N	PRESENT	0
234845	234842	08012N	PARTICIPANT	\N	PRESENT	0
234846	234842	19699S	PARTICIPANT	\N	PRESENT	0
234849	234848	14073Q	PARTICIPANT	\N	PRESENT	0
234850	234848	11043H	PARTICIPANT	\N	PRESENT	0
234851	234848	08012N	PARTICIPANT	\N	PRESENT	0
234853	234852	14073Q	PARTICIPANT	\N	PRESENT	0
234854	234852	11043H	PARTICIPANT	\N	PRESENT	0
234855	234852	08012N	PARTICIPANT	\N	PRESENT	0
234856	234852	14059S	PARTICIPANT	\N	PRESENT	0
234864	234860	14123H	PARTICIPANT	\N	PRESENT	0
234865	234860	08031R	PARTICIPANT	\N	PRESENT	0
234868	234867	11104D	PARTICIPANT	\N	PRESENT	0
234869	234867	87003B	PARTICIPANT	\N	PRESENT	0
234871	234870	14030Q	PARTICIPANT	\N	PRESENT	0
234881	234880	14030Q	PARTICIPANT	\N	PRESENT	0
234883	234882	14030Q	PARTICIPANT	\N	PRESENT	0
237544	235613	04043D	PARTICIPANT	\N	PRESENT	0
237545	235532	19697Q	PARTICIPANT	\N	PRESENT	0
237546	235532	11067R	PARTICIPANT	\N	PRESENT	0
237547	235532	14087W	PARTICIPANT	\N	PRESENT	0
237548	235532	14195A	PARTICIPANT	\N	PRESENT	0
237549	235532	19527W	PARTICIPANT	\N	PRESENT	0
237550	235532	19727D	PARTICIPANT	\N	PRESENT	0
237564	235429	19709B	PARTICIPANT	\N	PRESENT	0
237579	235488	19333N	PARTICIPANT	\N	PRESENT	0
237580	235488	17583W	PARTICIPANT	\N	PRESENT	0
237581	235488	19549D	PARTICIPANT	\N	PRESENT	0
237582	235488	95062K	PARTICIPANT	\N	PRESENT	0
237583	235488	19673G	PARTICIPANT	\N	PRESENT	0
237584	235488	01028R	PARTICIPANT	\N	PRESENT	0
237585	235488	02002K	PARTICIPANT	\N	PRESENT	0
237586	235488	19551W	PARTICIPANT	\N	PRESENT	0
237587	235488	80027E	PARTICIPANT	\N	PRESENT	0
237588	235488	08060W	PARTICIPANT	\N	PRESENT	0
237589	235488	14041T	PARTICIPANT	\N	PRESENT	0
237590	235488	19347U	PARTICIPANT	\N	PRESENT	0
237591	235488	14147R	PARTICIPANT	\N	PRESENT	0
237592	235488	14151M	PARTICIPANT	\N	PRESENT	0
237593	235488	19685L	PARTICIPANT	\N	PRESENT	0
237594	235488	14157T	PARTICIPANT	\N	PRESENT	0
237595	235488	19681G	PARTICIPANT	\N	PRESENT	0
237596	235488	11065P	PARTICIPANT	\N	PRESENT	0
237597	235488	19525U	PARTICIPANT	\N	PRESENT	0
237598	235488	14038Y	PARTICIPANT	\N	PRESENT	0
237599	235488	14065Q	PARTICIPANT	\N	PRESENT	0
237600	235488	19649G	PARTICIPANT	\N	PRESENT	0
237601	235488	01024M	PARTICIPANT	\N	PRESENT	0
237602	235488	08055A	PARTICIPANT	\N	PRESENT	0
237603	235488	14191V	PARTICIPANT	\N	PRESENT	0
237604	235488	14069U	PARTICIPANT	\N	PRESENT	0
237605	235488	19383Y	PARTICIPANT	\N	PRESENT	0
237606	235488	19701S	PARTICIPANT	\N	PRESENT	0
237607	235488	19387D	PARTICIPANT	\N	PRESENT	0
237608	235488	14001X	PARTICIPANT	\N	PRESENT	0
237609	235488	19581D	PARTICIPANT	\N	PRESENT	0
237610	235488	04044E	PARTICIPANT	\N	PRESENT	0
237611	235488	19585H	PARTICIPANT	\N	PRESENT	0
237612	235488	04047H	PARTICIPANT	\N	PRESENT	0
237613	235488	05008E	PRESIDENT	0	PRESENT	0
237614	235488	14231L	PARTICIPANT	\N	PRESENT	0
237615	235488	18083K	PARTICIPANT	\N	PRESENT	0
237616	235488	05012A	PARTICIPANT	\N	PRESENT	0
237617	235488	14051J	PARTICIPANT	\N	PRESENT	0
237618	235488	19503N	PARTICIPANT	\N	PRESENT	0
237619	235488	14215L	PARTICIPANT	\N	PRESENT	0
237620	235488	19483C	PARTICIPANT	\N	PRESENT	0
237621	235488	17637T	PARTICIPANT	\N	PRESENT	0
237622	235488	11072N	PARTICIPANT	\N	PRESENT	0
237623	235488	14053L	PARTICIPANT	\N	PRESENT	0
237624	235488	14135M	PARTICIPANT	\N	PRESENT	0
237625	235488	14103D	PARTICIPANT	\N	PRESENT	0
237626	235488	14111D	PARTICIPANT	\N	PRESENT	0
237627	235488	14031R	PARTICIPANT	\N	PRESENT	0
237628	235488	19713W	PARTICIPANT	\N	PRESENT	0
237629	235488	07034Q	PARTICIPANT	\N	PRESENT	0
237630	235488	08045X	PARTICIPANT	\N	PRESENT	0
237631	235488	11026G	PARTICIPANT	\N	PRESENT	0
237632	235488	19719D	PARTICIPANT	\N	PRESENT	0
237633	235488	19725B	PARTICIPANT	\N	PRESENT	0
237634	235488	15447F	PARTICIPANT	\N	PRESENT	0
237635	235488	19729F	PARTICIPANT	\N	PRESENT	0
237636	235488	95063L	PARTICIPANT	\N	PRESENT	0
237637	235488	19733B	PARTICIPANT	\N	PRESENT	0
237638	235488	08009T	PARTICIPANT	\N	PRESENT	0
237639	235488	19739H	PARTICIPANT	\N	PRESENT	0
237640	235488	04097T	PARTICIPANT	\N	PRESENT	0
237645	235489	14001X	PARTICIPANT	\N	PRESENT	0
237646	235489	19581D	PARTICIPANT	\N	PRESENT	0
237647	235489	04044E	PARTICIPANT	\N	PRESENT	0
237648	235489	19673G	PARTICIPANT	\N	PRESENT	0
237649	235489	01028R	PARTICIPANT	\N	PRESENT	0
237650	235489	19447X	PARTICIPANT	\N	PRESENT	0
237651	235489	05008E	PRESIDENT	0	PRESENT	0
237652	235489	14231L	PARTICIPANT	\N	PRESENT	0
237653	235489	19489J	PARTICIPANT	\N	PRESENT	0
237654	235489	14041T	PARTICIPANT	\N	PRESENT	0
237655	235489	14147R	PARTICIPANT	\N	PRESENT	0
237656	235489	14179A	PARTICIPANT	\N	PRESENT	0
237657	235489	14151M	PARTICIPANT	\N	PRESENT	0
237658	235489	14215L	PRESIDENT	1	PRESENT	0
237659	235489	19483C	PARTICIPANT	\N	PRESENT	0
237660	235489	08018U	PARTICIPANT	\N	PRESENT	0
237661	235489	14259Y	PARTICIPANT	\N	PRESENT	0
237662	235489	11072N	PARTICIPANT	\N	PRESENT	0
237663	235489	98035U	PARTICIPANT	\N	PRESENT	0
237664	235489	14053L	PARTICIPANT	\N	PRESENT	0
237665	235489	14065Q	PARTICIPANT	\N	PRESENT	0
237666	235489	19649G	PARTICIPANT	\N	PRESENT	0
237667	235489	11010L	PARTICIPANT	\N	PRESENT	0
237668	235489	10015M	PARTICIPANT	\N	PRESENT	0
237669	235489	07034Q	PARTICIPANT	\N	PRESENT	0
237670	235489	08045X	PARTICIPANT	\N	PRESENT	0
237671	235489	11026G	PARTICIPANT	\N	PRESENT	0
237672	235489	19253P	PARTICIPANT	\N	PRESENT	0
237673	235489	01024M	PARTICIPANT	\N	PRESENT	0
237674	235489	04038G	PARTICIPANT	\N	PRESENT	0
237675	235489	19725B	PARTICIPANT	\N	PRESENT	0
237676	235489	19729F	PARTICIPANT	\N	PRESENT	0
237677	235489	95063L	PARTICIPANT	\N	PRESENT	0
237678	235489	08044W	PARTICIPANT	\N	PRESENT	0
237679	235489	14069U	PARTICIPANT	\N	PRESENT	0
237680	235489	11049P	PARTICIPANT	\N	PRESENT	0
237681	235489	14111D	PARTICIPANT	\N	PRESENT	0
237682	235489	19629C	PARTICIPANT	\N	PRESENT	0
237683	235489	01060R	PARTICIPANT	\N	PRESENT	0
237684	235489	11085T	PARTICIPANT	\N	PRESENT	0
237685	235489	19585H	PARTICIPANT	\N	PRESENT	0
237686	235489	04008A	PARTICIPANT	\N	PRESENT	0
237687	235489	04047H	PARTICIPANT	\N	PRESENT	0
237688	235489	19719D	PARTICIPANT	\N	PRESENT	0
237689	235489	11033F	PARTICIPANT	\N	PRESENT	0
237690	235489	14021P	PARTICIPANT	\N	PRESENT	0
237698	237429	04070G	PRESIDENT	0	PRESENT	0
237699	237429	19699S	PARTICIPANT	\N	PRESENT	0
237700	237429	12041X	PARTICIPANT	\N	PRESENT	0
237701	237429	14355X	PARTICIPANT	\N	PRESENT	0
237702	237429	19533U	PARTICIPANT	\N	PRESENT	0
237703	237429	95015C	PARTICIPANT	\N	PRESENT	0
237704	237429	19329S	PARTICIPANT	\N	PRESENT	0
237705	237429	14229S	PARTICIPANT	\N	PRESENT	0
237706	237429	14241N	PARTICIPANT	\N	PRESENT	0
237707	237429	19573D	PARTICIPANT	\N	PRESENT	0
237708	237429	14039A	PARTICIPANT	\N	PRESENT	0
237709	237429	14107H	PARTICIPANT	\N	PRESENT	0
237710	237429	08017T	PARTICIPANT	\N	PRESENT	0
237711	237429	07033P	PARTICIPANT	\N	PRESENT	0
237712	237429	08039A	PARTICIPANT	\N	PRESENT	0
237713	237429	08031R	PARTICIPANT	\N	PRESENT	0
237714	237429	19593H	PARTICIPANT	\N	PRESENT	0
237715	237429	19643A	PARTICIPANT	\N	PRESENT	0
237716	237429	14059S	PARTICIPANT	\N	PRESENT	0
237717	237429	04057K	PARTICIPANT	\N	PRESENT	0
237718	237429	19611R	PARTICIPANT	\N	PRESENT	0
237719	237429	19693L	PARTICIPANT	\N	PRESENT	0
237720	237429	87003B	PARTICIPANT	\N	PRESENT	0
237721	237429	19399H	PARTICIPANT	\N	PRESENT	0
237722	237429	14201E	PARTICIPANT	\N	PRESENT	0
237723	237429	14030Q	PARTICIPANT	\N	PRESENT	0
237724	237429	19731Y	PARTICIPANT	\N	PRESENT	0
237725	237429	08020N	PARTICIPANT	\N	PRESENT	0
237726	237429	04059M	PARTICIPANT	\N	PRESENT	0
237727	237429	19735D	PARTICIPANT	\N	PRESENT	0
237728	237429	11109J	PARTICIPANT	\N	PRESENT	0
237729	237429	14063N	PARTICIPANT	\N	PRESENT	0
237730	237429	14109K	PARTICIPANT	\N	PRESENT	0
237731	237429	14123H	PARTICIPANT	\N	PRESENT	0
211571	210098	14133K	PARTICIPANT	\N	EXCUSE	0
211572	210098	19583F	PARTICIPANT	\N	EXCUSE	0
211661	210099	14133K	PARTICIPANT	\N	EXCUSE	0
211663	210099	11115U	PARTICIPANT	\N	EXCUSE	0
211664	210099	19583F	PARTICIPANT	\N	EXCUSE	0
211665	210099	98005N	PARTICIPANT	\N	EXCUSE	0
211666	210099	14235Q	PARTICIPANT	\N	EXCUSE	0
211669	210100	14133K	PARTICIPANT	\N	EXCUSE	0
211671	210100	11115U	PARTICIPANT	\N	EXCUSE	0
211672	210100	19583F	PARTICIPANT	\N	EXCUSE	0
211673	210100	98005N	PARTICIPANT	\N	EXCUSE	0
211680	211679	19709B	PARTICIPANT	\N	PRESENT	0
211681	211679	19533U	PARTICIPANT	\N	PRESENT	0
211696	210045	11065P	PARTICIPANT	\N	PRESENT	0
211748	210045	89017R	PARTICIPANT	\N	EXCUSE	0
212146	211158	19727D	PARTICIPANT	\N	PRESENT	0
213321	213320	08010L	PARTICIPANT	\N	PRESENT	0
213323	213322	08010L	PARTICIPANT	\N	PRESENT	0
213375	213374	08047A	PARTICIPANT	\N	PRESENT	0
213376	213374	11066Q	PARTICIPANT	\N	PRESENT	0
213378	213377	95067Q	PARTICIPANT	\N	PRESENT	0
213379	213377	14028W	PARTICIPANT	\N	PRESENT	0
213384	213383	99004R	PARTICIPANT	\N	PRESENT	0
213386	213385	04071H	PARTICIPANT	\N	PRESENT	0
213388	213387	08009T	PARTICIPANT	\N	PRESENT	0
214872	214871	04070G	PARTICIPANT	\N	PRESENT	0
214880	214877	14255U	PARTICIPANT	\N	PRESENT	0
214881	214877	14237S	PARTICIPANT	\N	PRESENT	0
214882	214877	95067Q	PARTICIPANT	\N	PRESENT	0
214884	214877	04045F	PARTICIPANT	\N	PRESENT	0
214915	214877	14193X	PARTICIPANT	\N	PRESENT	0
214916	214877	14079W	PARTICIPANT	\N	PRESENT	0
217455	217454	14205J	PARTICIPANT	\N	PRESENT	0
217457	217456	14205J	PARTICIPANT	\N	PRESENT	0
217459	217458	14205J	PARTICIPANT	\N	PRESENT	0
217466	217465	08028W	PARTICIPANT	\N	PRESENT	0
217673	217672	14221J	PARTICIPANT	\N	PRESENT	0
217675	217674	14169X	PARTICIPANT	\N	PRESENT	0
217677	217676	18083K	PARTICIPANT	\N	PRESENT	0
217679	217678	18083K	PARTICIPANT	\N	PRESENT	0
217681	217680	14103D	PARTICIPANT	\N	PRESENT	0
217683	217682	19681G	PARTICIPANT	\N	PRESENT	0
217686	217685	14103D	PARTICIPANT	\N	PRESENT	0
217688	217687	14051J	PARTICIPANT	\N	PRESENT	0
217690	217689	14051J	PARTICIPANT	\N	PRESENT	0
217692	217691	14051J	PARTICIPANT	\N	PRESENT	0
217694	217693	08060W	PARTICIPANT	\N	PRESENT	0
217696	217695	08060W	PARTICIPANT	\N	PRESENT	0
217698	217697	08060W	PARTICIPANT	\N	PRESENT	0
219292	217449	19663E	PARTICIPANT	\N	EXCUSE	0
223280	220500	14179A	PARTICIPANT	\N	PRESENT	0
223369	223368	04042C	PARTICIPANT	\N	PRESENT	0
223371	223370	04042C	PARTICIPANT	\N	PRESENT	0
223372	223370	98018T	PARTICIPANT	\N	PRESENT	0
223373	223370	11027H	PARTICIPANT	\N	PRESENT	0
223374	223370	04040A	PARTICIPANT	\N	PRESENT	0
223375	223370	07004J	PARTICIPANT	\N	PRESENT	0
223377	223376	14133K	PARTICIPANT	\N	PRESENT	0
226556	218441	19671E	PARTICIPANT	\N	PRESENT	0
226557	218441	07029T	PARTICIPANT	\N	PRESENT	0
226558	218441	19701S	PARTICIPANT	\N	PRESENT	0
226559	218441	19637C	PARTICIPANT	\N	PRESENT	0
226560	218441	11066Q	PARTICIPANT	\N	PRESENT	0
226561	218441	14173T	PARTICIPANT	\N	PRESENT	0
226554	218441	04059M	PARTICIPANT	\N	PRESENT	0
226555	218441	19731Y	PARTICIPANT	\N	PRESENT	0
226562	218441	14034U	PARTICIPANT	\N	PRESENT	0
226563	218441	04071H	PARTICIPANT	\N	PRESENT	0
226564	218441	19585H	PARTICIPANT	\N	PRESENT	0
226565	218441	11074Q	PARTICIPANT	\N	PRESENT	0
226566	218441	19349W	PARTICIPANT	\N	PRESENT	0
226567	218441	04088S	PARTICIPANT	\N	PRESENT	0
226568	218441	04086Q	PARTICIPANT	\N	PRESENT	0
226569	218441	11033F	PARTICIPANT	\N	PRESENT	0
226570	218441	19729F	PARTICIPANT	\N	PRESENT	0
226571	218441	04044E	PARTICIPANT	\N	PRESENT	0
226572	218441	14069U	PARTICIPANT	\N	PRESENT	0
226573	218441	14215L	PARTICIPANT	\N	PRESENT	0
226574	218441	19711U	PARTICIPANT	\N	PRESENT	0
226575	218441	14033T	PARTICIPANT	\N	PRESENT	0
226576	218441	11080N	PARTICIPANT	\N	PRESENT	0
226578	218441	19649G	PARTICIPANT	\N	PRESENT	0
226579	218441	19667J	PARTICIPANT	\N	PRESENT	0
226580	218441	08056B	PARTICIPANT	\N	PRESENT	0
226581	218441	19441R	PARTICIPANT	\N	PRESENT	0
226582	218441	19507S	PARTICIPANT	\N	PRESENT	0
226583	218441	19703U	PARTICIPANT	\N	PRESENT	0
226584	218441	11027H	PARTICIPANT	\N	PRESENT	0
226585	218441	19737F	PARTICIPANT	\N	PRESENT	0
226586	218441	14055N	PARTICIPANT	\N	PRESENT	0
226587	218441	98018T	PARTICIPANT	\N	PRESENT	0
226588	218441	07004J	PARTICIPANT	\N	PRESENT	0
226589	218441	14041T	PARTICIPANT	\N	PRESENT	0
226590	218441	14089Y	PARTICIPANT	\N	PRESENT	0
226591	226198	14042U	PARTICIPANT	\N	EXCUSE	0
226592	226198	08048B	PARTICIPANT	\N	EXCUSE	0
226593	226198	19715Y	PARTICIPANT	\N	EXCUSE	0
226594	226198	08041T	PARTICIPANT	\N	EXCUSE	0
226595	218441	19651A	PARTICIPANT	\N	PRESENT	0
226596	218441	19447X	PARTICIPANT	\N	PRESENT	0
226597	218441	19673G	PARTICIPANT	\N	PRESENT	0
226598	218441	19679N	PARTICIPANT	\N	PRESENT	0
226599	218441	04047H	PARTICIPANT	\N	PRESENT	0
226600	218441	01028R	PARTICIPANT	\N	PRESENT	0
226601	218441	11040E	PARTICIPANT	\N	PRESENT	0
226602	218441	87003B	PARTICIPANT	\N	PRESENT	0
226604	218441	08045X	PARTICIPANT	\N	PRESENT	0
226605	218441	14331P	PARTICIPANT	\N	PRESENT	0
226606	218441	14249W	PARTICIPANT	\N	PRESENT	0
226607	218441	05008E	PARTICIPANT	\N	PRESENT	0
226608	218441	19643A	PARTICIPANT	\N	PRESENT	0
226610	218441	19479G	PARTICIPANT	\N	PRESENT	0
226611	218441	14079W	PARTICIPANT	\N	PRESENT	0
226612	218441	19581D	PARTICIPANT	\N	PRESENT	0
226613	218441	04085P	PARTICIPANT	\N	PRESENT	0
226614	218441	14219Q	PARTICIPANT	\N	PRESENT	0
226615	218441	08031R	PARTICIPANT	\N	PRESENT	0
226616	218441	11012A	PARTICIPANT	\N	PRESENT	0
226617	218441	19573D	PARTICIPANT	\N	PRESENT	0
226618	218441	19443T	PARTICIPANT	\N	PRESENT	0
226619	218441	11081P	PARTICIPANT	\N	PRESENT	0
226620	218441	14265W	PARTICIPANT	\N	PRESENT	0
226621	218441	19629C	PARTICIPANT	\N	PRESENT	0
226622	218441	19369B	PARTICIPANT	\N	PRESENT	0
226623	218441	19713W	PARTICIPANT	\N	PRESENT	0
226624	218441	19565D	PARTICIPANT	\N	PRESENT	0
226625	218441	04035D	PARTICIPANT	\N	PRESENT	0
226626	218441	14111D	PARTICIPANT	\N	PRESENT	0
226627	218441	14038Y	PARTICIPANT	\N	PRESENT	0
226629	226198	19697Q	PARTICIPANT	\N	PRESENT	0
226630	226198	11067R	PARTICIPANT	\N	PRESENT	0
226631	226198	14355X	PARTICIPANT	\N	PRESENT	0
226632	226198	04045F	PARTICIPANT	\N	PRESENT	0
226633	226198	14223L	PARTICIPANT	\N	PRESENT	0
226634	226198	14026U	PARTICIPANT	\N	PRESENT	0
226635	226198	11063M	PARTICIPANT	\N	PRESENT	0
226636	226198	17779H	PARTICIPANT	\N	PRESENT	0
226637	226198	19703U	PARTICIPANT	\N	PRESENT	0
226638	226198	14239U	PARTICIPANT	\N	PRESENT	0
226639	226198	11031D	PARTICIPANT	\N	PRESENT	0
226640	226198	14281W	PARTICIPANT	\N	PRESENT	0
226641	226198	14087W	PARTICIPANT	\N	PRESENT	0
226642	226198	19679N	PARTICIPANT	\N	PRESENT	0
226643	226198	14195A	PARTICIPANT	\N	PRESENT	0
226644	226198	19575F	PARTICIPANT	\N	PRESENT	0
226645	226198	19367Y	PARTICIPANT	\N	PRESENT	0
226646	226198	14213J	PARTICIPANT	\N	PRESENT	0
226647	226198	14217N	PARTICIPANT	\N	PRESENT	0
226648	226198	19335Q	PARTICIPANT	\N	PRESENT	0
226649	226198	19683J	PARTICIPANT	\N	PRESENT	0
226650	226198	98024R	PARTICIPANT	\N	PRESENT	0
226651	226198	19521Q	PARTICIPANT	\N	PRESENT	0
226652	226198	01034P	PARTICIPANT	\N	PRESENT	0
226653	226198	04092N	PRESIDENT	0	PRESENT	0
226654	226198	08052W	PARTICIPANT	\N	PRESENT	0
226655	226198	19663E	PARTICIPANT	\N	PRESENT	0
226656	226198	19727D	PARTICIPANT	\N	PRESENT	0
226657	226198	14119M	PARTICIPANT	\N	PRESENT	0
226658	226198	14071N	PARTICIPANT	\N	PRESENT	0
226659	218441	14063N	PARTICIPANT	\N	PRESENT	0
226660	218441	14061L	PARTICIPANT	\N	PRESENT	0
226662	218441	97011G	PARTICIPANT	\N	PRESENT	0
226663	218441	14261S	PARTICIPANT	\N	PRESENT	0
225422	223254	11081P	PARTICIPANT	\N	EXCUSE	0
225447	225446	05008E	PARTICIPANT	\N	PRESENT	0
233486	232939	08010L	PARTICIPANT	\N	PRESENT	0
233487	232939	14225N	PARTICIPANT	\N	PRESENT	0
233488	232939	14109K	PARTICIPANT	\N	PRESENT	0
233491	232939	04086Q	PARTICIPANT	\N	PRESENT	0
233492	232939	08024S	PARTICIPANT	\N	PRESENT	0
233493	232939	11054L	PARTICIPANT	\N	PRESENT	0
233494	232939	04059M	PARTICIPANT	\N	PRESENT	0
225456	225452	05008E	PARTICIPANT	\N	PRESENT	0
225458	225457	05008E	PARTICIPANT	\N	PRESENT	0
233495	232939	14265W	PARTICIPANT	\N	PRESENT	0
233497	232939	98023Q	PARTICIPANT	\N	PRESENT	0
233498	232939	14111D	PARTICIPANT	\N	PRESENT	0
233499	232939	08009T	PARTICIPANT	\N	PRESENT	0
233500	232939	14030Q	PARTICIPANT	\N	PRESENT	0
233510	232939	14281W	PARTICIPANT	\N	PRESENT	0
233511	232939	80013X	PARTICIPANT	\N	PRESENT	0
233522	233061	11045K	PARTICIPANT	\N	PRESENT	0
233523	233061	08052W	PARTICIPANT	\N	PRESENT	0
233524	233061	14026U	PARTICIPANT	\N	PRESENT	0
233525	233061	14355X	PARTICIPANT	\N	EXCUSE	0
233532	232939	19703U	PARTICIPANT	\N	PRESENT	0
233533	232939	19467C	PARTICIPANT	\N	PRESENT	0
233534	232939	14169X	PARTICIPANT	\N	PRESENT	0
233535	232939	04088S	PARTICIPANT	\N	PRESENT	0
233536	232939	19415P	PARTICIPANT	\N	PRESENT	0
233537	232939	14105F	PARTICIPANT	\N	PRESENT	0
233538	232939	14042U	PARTICIPANT	\N	PRESENT	0
233539	232939	95030B	PARTICIPANT	\N	PRESENT	0
233541	232939	98022P	PARTICIPANT	\N	PRESENT	0
233542	232939	11066Q	PARTICIPANT	\N	PRESENT	0
233543	232939	16685X	PARTICIPANT	\N	PRESENT	0
233544	232939	01057W	PARTICIPANT	\N	PRESENT	0
233545	232939	19507S	PARTICIPANT	\N	PRESENT	0
233546	232939	08028W	PARTICIPANT	\N	PRESENT	0
233547	232939	14157T	PARTICIPANT	\N	PRESENT	0
233548	232939	11101A	PARTICIPANT	\N	PRESENT	0
233549	232939	01025N	PARTICIPANT	\N	PRESENT	0
233550	232939	17589D	PARTICIPANT	\N	PRESENT	0
233551	232939	14221J	PARTICIPANT	\N	PRESENT	0
233554	232939	19483C	PARTICIPANT	\N	PRESENT	0
233665	232940	14211G	PARTICIPANT	\N	PRESENT	0
233666	232940	14259Y	PARTICIPANT	\N	PRESENT	0
233667	232940	14157T	PARTICIPANT	\N	PRESENT	0
233668	232940	99004R	PARTICIPANT	\N	PRESENT	0
233669	232940	04097T	PARTICIPANT	\N	PRESENT	0
233670	232940	87003B	PARTICIPANT	\N	PRESENT	0
233671	232940	92040Q	PARTICIPANT	\N	PRESENT	0
233672	232940	14031R	PARTICIPANT	\N	PRESENT	0
233673	232940	08019V	PARTICIPANT	\N	PRESENT	0
233674	232940	08069G	PARTICIPANT	\N	PRESENT	0
233675	232940	04086Q	PARTICIPANT	\N	PRESENT	0
233677	232940	14173T	PARTICIPANT	\N	PRESENT	0
233788	232940	04033B	PARTICIPANT	\N	PRESENT	0
233680	232940	08055A	PARTICIPANT	\N	PRESENT	0
233681	232940	01028R	PARTICIPANT	\N	PRESENT	0
233682	232940	19289C	PARTICIPANT	\N	PRESENT	0
233683	232940	19741B	PARTICIPANT	\N	PRESENT	0
233684	232940	08012N	PARTICIPANT	\N	PRESENT	0
233685	232940	14223L	PARTICIPANT	\N	PRESENT	0
233686	232940	01048V	PARTICIPANT	\N	PRESENT	0
233688	232940	19577H	PARTICIPANT	\N	PRESENT	0
233689	232940	14053L	PARTICIPANT	\N	PRESENT	0
233690	232940	14073Q	PARTICIPANT	\N	PRESENT	0
233692	232940	04018C	PARTICIPANT	\N	PRESENT	0
233693	232940	19701S	PARTICIPANT	\N	PRESENT	0
233694	232940	01025N	PARTICIPANT	\N	PRESENT	0
233695	232940	14267Y	PARTICIPANT	\N	PRESENT	0
233696	232940	01057W	PARTICIPANT	\N	PRESENT	0
233697	232940	19703U	PARTICIPANT	\N	PRESENT	0
233698	232940	19507S	PARTICIPANT	\N	PRESENT	0
233699	232940	19467C	PARTICIPANT	\N	PRESENT	0
233700	232940	19667J	PARTICIPANT	\N	PRESENT	0
233701	232940	17637T	PARTICIPANT	\N	PRESENT	0
233702	232940	08047A	PARTICIPANT	\N	PRESENT	0
233703	232940	01024M	PARTICIPANT	\N	PRESENT	0
233704	232940	08056B	PARTICIPANT	\N	PRESENT	0
233705	232940	19673G	PARTICIPANT	\N	PRESENT	0
233706	232940	98005N	PARTICIPANT	\N	PRESENT	0
233707	232940	11043H	PARTICIPANT	\N	PRESENT	0
233708	232940	08010L	PARTICIPANT	\N	PRESENT	0
233709	232940	01043Q	PARTICIPANT	\N	PRESENT	0
233710	232940	08039A	PARTICIPANT	\N	PRESENT	0
233711	232940	11070L	PARTICIPANT	\N	PRESENT	0
233712	232940	11049P	PARTICIPANT	\N	PRESENT	0
233713	232940	14119M	PARTICIPANT	\N	PRESENT	0
233714	232940	11031D	PARTICIPANT	\N	PRESENT	0
233716	232940	01058X	PARTICIPANT	\N	PRESENT	0
233718	232940	98023Q	PARTICIPANT	\N	PRESENT	0
233719	232940	04008A	PARTICIPANT	\N	PRESENT	0
233720	232940	11040E	PARTICIPANT	\N	PRESENT	0
233721	232940	11101A	PARTICIPANT	\N	PRESENT	0
233722	232940	11063M	PARTICIPANT	\N	PRESENT	0
233723	232940	14042U	PARTICIPANT	\N	PRESENT	0
233724	232940	14235Q	PARTICIPANT	\N	PRESENT	0
233725	232940	07004J	PARTICIPANT	\N	PRESENT	0
233726	232940	19593H	PARTICIPANT	\N	PRESENT	0
233727	232940	15447F	PARTICIPANT	\N	PRESENT	0
233728	232940	19695N	PARTICIPANT	\N	PRESENT	0
233729	232940	04070G	PARTICIPANT	\N	PRESENT	0
233730	232940	19347U	PARTICIPANT	\N	PRESENT	0
233732	232940	11085T	PARTICIPANT	\N	PRESENT	0
233733	232940	19687N	PARTICIPANT	\N	PRESENT	0
233735	232940	08020N	PARTICIPANT	\N	PRESENT	0
233736	232940	12041X	PARTICIPANT	\N	PRESENT	0
233737	232940	11074Q	PARTICIPANT	\N	PRESENT	0
233738	232940	04059M	PARTICIPANT	\N	PRESENT	0
233739	232940	96004D	PARTICIPANT	\N	PRESENT	0
233740	232940	98024R	PARTICIPANT	\N	PRESENT	0
233741	232940	08061X	PARTICIPANT	\N	PRESENT	0
233742	232940	04045F	PARTICIPANT	\N	PRESENT	0
233743	232940	04047H	PARTICIPANT	\N	PRESENT	0
233744	232940	19651A	PARTICIPANT	\N	PRESENT	0
233745	232940	14239U	PARTICIPANT	\N	PRESENT	0
233746	232940	19349W	PARTICIPANT	\N	PRESENT	0
233747	232940	19637C	PARTICIPANT	\N	PRESENT	0
233748	232940	14026U	PARTICIPANT	\N	PRESENT	0
233749	232940	19543W	PARTICIPANT	\N	PRESENT	0
233750	232940	04034C	PARTICIPANT	\N	PRESENT	0
233751	232940	19697Q	PARTICIPANT	\N	PRESENT	0
233752	232940	08021P	PARTICIPANT	\N	PRESENT	0
233753	232940	98018T	PARTICIPANT	\N	PRESENT	0
233754	232940	04044E	PARTICIPANT	\N	PRESENT	0
233755	232940	95037J	PARTICIPANT	\N	PRESENT	0
233756	232940	14039A	PARTICIPANT	\N	PRESENT	0
233757	232940	08073C	PARTICIPANT	\N	PRESENT	0
233758	232940	11072N	PARTICIPANT	\N	PRESENT	0
233759	232940	19301E	PARTICIPANT	\N	PRESENT	0
233760	232940	95030B	PARTICIPANT	\N	PRESENT	0
233761	232940	11077T	PARTICIPANT	\N	PRESENT	0
233762	232940	14021P	PARTICIPANT	\N	PRESENT	0
233763	232940	01060R	PARTICIPANT	\N	PRESENT	0
233764	232940	19731Y	PARTICIPANT	\N	PRESENT	0
233765	232940	19685L	PARTICIPANT	\N	PRESENT	0
233766	232940	89017R	PARTICIPANT	\N	PRESENT	0
233767	232940	04092N	PARTICIPANT	\N	PRESENT	0
233768	232940	14055N	PARTICIPANT	\N	PRESENT	0
233769	232940	11027H	PARTICIPANT	\N	PRESENT	0
233770	232940	95041E	PARTICIPANT	\N	PRESENT	0
233771	232940	14249W	PARTICIPANT	\N	PRESENT	0
233772	232940	19565D	PARTICIPANT	\N	PRESENT	0
233773	232940	11097X	PARTICIPANT	\N	PRESENT	0
233774	232940	11012A	PARTICIPANT	\N	PRESENT	0
233775	232940	08031R	PARTICIPANT	\N	PRESENT	0
233776	232940	14034U	PARTICIPANT	\N	PRESENT	0
233777	232940	19253P	PARTICIPANT	\N	PRESENT	0
233778	232940	14261S	PARTICIPANT	\N	PRESENT	0
233779	232940	98029W	PARTICIPANT	\N	PRESENT	0
233663	232940	14133K	PARTICIPANT	\N	PRESENT	0
233664	232940	95062K	PARTICIPANT	\N	PRESENT	0
233780	232940	19629C	PARTICIPANT	\N	PRESENT	0
233781	232940	08049C	PARTICIPANT	\N	PRESENT	0
233782	232940	14201E	PARTICIPANT	\N	PRESENT	0
233783	232940	19563B	PARTICIPANT	\N	PRESENT	0
233784	232940	98022P	PARTICIPANT	\N	PRESENT	0
233785	232940	14241N	PARTICIPANT	\N	PRESENT	0
233786	232940	19719D	PARTICIPANT	\N	PRESENT	0
233787	232940	19387D	PARTICIPANT	\N	PRESENT	0
233789	232940	14187A	PARTICIPANT	\N	PRESENT	0
233790	232940	11065P	PARTICIPANT	\N	PRESENT	0
233791	232940	11099A	PARTICIPANT	\N	PRESENT	0
233792	232940	19745F	PARTICIPANT	\N	PRESENT	0
233793	232940	19269X	PARTICIPANT	\N	PRESENT	0
233794	232940	04049K	PARTICIPANT	\N	PRESENT	0
233795	232940	14087W	PARTICIPANT	\N	PRESENT	0
233797	232940	01062T	PARTICIPANT	\N	PRESENT	0
233798	232940	07034Q	PARTICIPANT	\N	PRESENT	0
217565	217504	08009T	PARTICIPANT	\N	PRESENT	0
217566	217504	19503N	PARTICIPANT	\N	PRESENT	0
217567	217504	14093U	PARTICIPANT	\N	PRESENT	0
217568	217504	19347U	PARTICIPANT	\N	PRESENT	0
217577	217576	14087W	PARTICIPANT	\N	PRESENT	0
217579	217578	14213J	PARTICIPANT	\N	PRESENT	0
228606	227827	19421M	PARTICIPANT	\N	EXCUSE	0
228777	227827	17637T	PARTICIPANT	\N	EXCUSE	0
233069	233068	05008E	PRESIDENT	0	PRESENT	0
233070	233068	19543W	PARTICIPANT	\N	PRESENT	0
237542	236577	14147R	PARTICIPANT	\N	PRESENT	0
233072	233068	14065Q	PARTICIPANT	\N	PRESENT	0
233073	233068	14069U	PARTICIPANT	\N	PRESENT	0
233074	233068	14089Y	PARTICIPANT	\N	PRESENT	0
233075	233068	04047H	PARTICIPANT	\N	PRESENT	0
233076	233068	14053L	PARTICIPANT	\N	PRESENT	0
233077	233068	19629C	PARTICIPANT	\N	PRESENT	0
233078	233068	04038G	PARTICIPANT	\N	PRESENT	0
233079	233068	19253P	PARTICIPANT	\N	PRESENT	0
233080	233068	14259Y	PARTICIPANT	\N	PRESENT	0
233081	233068	04008A	PARTICIPANT	\N	PRESENT	0
233082	233068	19719D	PARTICIPANT	\N	PRESENT	0
237558	237543	14237S	PARTICIPANT	\N	PRESENT	0
233084	233068	01024M	PARTICIPANT	\N	PRESENT	0
233085	233068	14215L	PARTICIPANT	\N	PRESENT	0
237559	237543	14097Y	PARTICIPANT	\N	PRESENT	0
233087	233068	19673G	PARTICIPANT	\N	PRESENT	0
233088	233068	08045X	PARTICIPANT	\N	PRESENT	0
237560	237543	14071N	PARTICIPANT	\N	PRESENT	0
237561	237543	08020N	PARTICIPANT	\N	PRESENT	0
233091	233068	14231L	PARTICIPANT	\N	PRESENT	0
233092	233068	19649G	PARTICIPANT	\N	PRESENT	0
233093	233068	11049P	PARTICIPANT	\N	PRESENT	0
233094	233068	19725B	PARTICIPANT	\N	PRESENT	0
233095	233068	14179A	PARTICIPANT	\N	PRESENT	0
237562	237543	19637C	PARTICIPANT	\N	PRESENT	0
237563	237543	14215L	PARTICIPANT	\N	PRESENT	0
233098	233068	14021P	PARTICIPANT	\N	PRESENT	0
233099	233068	19489J	PARTICIPANT	\N	PRESENT	0
233100	233068	11026G	PARTICIPANT	\N	PRESENT	0
233101	233068	19483C	PARTICIPANT	\N	PRESENT	0
233102	233068	19729F	PARTICIPANT	\N	PRESENT	0
233103	233068	19581D	PARTICIPANT	\N	PRESENT	0
233104	233068	14111D	PARTICIPANT	\N	PRESENT	0
233105	233068	14001X	PARTICIPANT	\N	PRESENT	0
233106	233068	11085T	PARTICIPANT	\N	PRESENT	0
233107	233068	01060R	PARTICIPANT	\N	PRESENT	0
233108	233068	14147R	PARTICIPANT	\N	PRESENT	0
233109	233068	11072N	PARTICIPANT	\N	PRESENT	0
233110	233068	07034Q	PARTICIPANT	\N	PRESENT	0
233111	233068	10015M	PARTICIPANT	\N	PRESENT	0
233112	233068	95063L	PARTICIPANT	\N	PRESENT	0
233113	233068	01028R	PARTICIPANT	\N	PRESENT	0
233114	233068	98035U	PARTICIPANT	\N	PRESENT	0
237747	237746	11040E	PARTICIPANT	\N	PRESENT	0
233116	233068	04044E	PARTICIPANT	\N	PRESENT	0
233117	233068	19585H	PARTICIPANT	\N	PRESENT	0
237748	237746	14069U	PARTICIPANT	\N	PRESENT	0
237749	237746	04035D	PARTICIPANT	\N	PRESENT	0
237750	237746	14255U	PARTICIPANT	\N	PRESENT	0
237751	237746	14147R	PARTICIPANT	\N	PRESENT	0
237752	237746	19643A	PARTICIPANT	\N	PRESENT	0
237753	237746	92040Q	PARTICIPANT	\N	PRESENT	0
237754	237746	14331P	PARTICIPANT	\N	PRESENT	0
239051	238878	08014Q	PARTICIPANT	\N	PRESENT	0
239052	238878	08024S	PARTICIPANT	\N	PRESENT	0
239053	238878	14207L	PARTICIPANT	\N	PRESENT	0
239054	238878	19347U	PARTICIPANT	\N	PRESENT	0
239055	238878	14093U	PARTICIPANT	\N	PRESENT	0
239056	238878	19729F	PARTICIPANT	\N	PRESENT	0
239057	238878	19703U	PARTICIPANT	\N	PRESENT	0
239058	238878	18083K	PARTICIPANT	\N	PRESENT	0
239059	238878	14265W	PARTICIPANT	\N	PRESENT	0
239060	238878	08015R	PARTICIPANT	\N	PRESENT	0
239061	238878	19701S	PARTICIPANT	\N	PRESENT	0
239062	238878	19629C	PARTICIPANT	\N	PRESENT	0
239063	238878	19447X	PARTICIPANT	\N	PRESENT	0
233139	233118	08018U	PARTICIPANT	\N	EXCUSE	0
239064	238878	19741B	PARTICIPANT	\N	PRESENT	0
239065	238878	08045X	PARTICIPANT	\N	PRESENT	0
239066	238878	19637C	PARTICIPANT	\N	PRESENT	0
239067	238878	07004J	PARTICIPANT	\N	PRESENT	0
239068	238878	95062K	PARTICIPANT	\N	PRESENT	0
239069	238878	14211G	PARTICIPANT	\N	PRESENT	0
239070	238878	14038Y	PARTICIPANT	\N	PRESENT	0
239071	238878	19591F	PARTICIPANT	\N	PRESENT	0
239072	238878	14151M	PARTICIPANT	\N	PRESENT	0
239073	238878	11099A	PARTICIPANT	\N	PRESENT	0
239074	238878	08043V	PARTICIPANT	\N	PRESENT	0
239075	238878	14237S	PARTICIPANT	\N	PRESENT	0
239076	238878	19719D	PARTICIPANT	\N	PRESENT	0
239077	238878	16685X	PARTICIPANT	\N	PRESENT	0
239078	238878	14231L	PARTICIPANT	\N	PRESENT	0
239081	238878	19253P	PARTICIPANT	\N	PRESENT	0
239082	238878	08055A	PARTICIPANT	\N	PRESENT	0
239083	238878	04088S	PARTICIPANT	\N	PRESENT	0
239084	238878	04033B	PARTICIPANT	\N	PRESENT	0
239085	238878	14187A	PARTICIPANT	\N	PRESENT	0
239090	238878	14105F	PARTICIPANT	\N	PRESENT	0
239091	238878	19733B	PARTICIPANT	\N	PRESENT	0
239126	238878	14249W	PARTICIPANT	\N	PRESENT	0
239127	238878	08020N	PARTICIPANT	\N	PRESENT	0
239128	238878	11109J	PARTICIPANT	\N	PRESENT	0
239129	238878	14059S	PARTICIPANT	\N	PRESENT	0
239130	238878	14063N	PARTICIPANT	\N	PRESENT	0
239131	238878	14083S	PARTICIPANT	\N	PRESENT	0
239132	238878	19507S	PARTICIPANT	\N	PRESENT	0
239133	238878	19533U	PARTICIPANT	\N	PRESENT	0
239134	238878	14073Q	PARTICIPANT	\N	PRESENT	0
239135	238878	01048V	PARTICIPANT	\N	PRESENT	0
239136	238878	98050T	PARTICIPANT	\N	PRESENT	0
239137	238878	11049P	PARTICIPANT	\N	PRESENT	0
239138	238878	14135M	PARTICIPANT	\N	PRESENT	0
239139	238878	14107H	PARTICIPANT	\N	PRESENT	0
239140	238878	14169X	PARTICIPANT	\N	PRESENT	0
239141	238878	19565D	PARTICIPANT	\N	PRESENT	0
239142	238878	11065P	PARTICIPANT	\N	PRESENT	0
239143	238878	19549D	PARTICIPANT	\N	PRESENT	0
239144	238878	19527W	PARTICIPANT	\N	PRESENT	0
239145	238878	14147R	PARTICIPANT	\N	PRESENT	0
239146	238878	08069G	PARTICIPANT	\N	PRESENT	0
239147	238878	19515S	PARTICIPANT	\N	PRESENT	0
239149	238878	87003B	PARTICIPANT	\N	PRESENT	0
239150	238878	11104D	PARTICIPANT	\N	PRESENT	0
239151	238878	80027E	PARTICIPANT	\N	PRESENT	0
239152	238878	08056B	PARTICIPANT	\N	PRESENT	0
239153	238878	08039A	PARTICIPANT	\N	PRESENT	0
239154	238878	14255U	PARTICIPANT	\N	PRESENT	0
239155	238878	08041T	PARTICIPANT	\N	PRESENT	0
239156	238878	19611R	PARTICIPANT	\N	PRESENT	0
239157	238878	01024M	PARTICIPANT	\N	PRESENT	0
239158	238878	14193X	PARTICIPANT	\N	PRESENT	0
239159	238878	19333N	PARTICIPANT	\N	PRESENT	0
239160	238878	80013X	PARTICIPANT	\N	PRESENT	0
239161	238878	19695N	PARTICIPANT	\N	PRESENT	0
239162	238878	19593H	PARTICIPANT	\N	PRESENT	0
239163	238878	14042U	PARTICIPANT	\N	PRESENT	0
239164	238878	19329S	PARTICIPANT	\N	PRESENT	0
239165	238878	19731Y	PARTICIPANT	\N	PRESENT	0
239166	238878	08060W	PARTICIPANT	\N	PRESENT	0
239167	238878	19713W	PARTICIPANT	\N	PRESENT	0
239172	238878	10006L	PARTICIPANT	\N	PRESENT	0
239173	238878	19415P	PARTICIPANT	\N	PRESENT	0
239174	238878	14121F	PARTICIPANT	\N	PRESENT	0
239175	238878	11085T	PARTICIPANT	\N	PRESENT	0
239177	238878	14069U	PARTICIPANT	\N	PRESENT	0
239178	238878	98023Q	PARTICIPANT	\N	PRESENT	0
239179	238878	97011G	PARTICIPANT	\N	PRESENT	0
239180	238878	14205J	PARTICIPANT	\N	PRESENT	0
239181	238878	19575F	PARTICIPANT	\N	PRESENT	0
239182	238878	89017R	PARTICIPANT	\N	PRESENT	0
239183	238878	14201E	PARTICIPANT	\N	PRESENT	0
239184	238878	14267Y	PARTICIPANT	\N	PRESENT	0
239185	238878	14173T	PARTICIPANT	\N	PRESENT	0
239187	238878	14119M	PARTICIPANT	\N	PRESENT	0
239189	238878	11067R	PARTICIPANT	\N	PRESENT	0
239190	238878	19543W	PARTICIPANT	\N	PRESENT	0
239191	238878	19573D	PARTICIPANT	\N	PRESENT	0
239192	238878	14087W	PARTICIPANT	\N	PRESENT	0
239193	238878	19683J	PARTICIPANT	\N	PRESENT	0
239194	238878	14213J	PARTICIPANT	\N	PRESENT	0
239207	238878	14179A	PARTICIPANT	\N	PRESENT	0
239212	238878	14257W	PARTICIPANT	\N	PRESENT	0
239215	238878	11043H	PARTICIPANT	\N	PRESENT	0
239216	238878	14217N	PARTICIPANT	\N	PRESENT	0
239217	238878	11103C	PARTICIPANT	\N	PRESENT	0
239218	238878	11048N	PARTICIPANT	\N	PRESENT	0
239219	238878	11083R	PARTICIPANT	\N	PRESENT	0
236357	236356	04047H	PARTICIPANT	\N	PRESENT	0
236358	236356	19329S	PARTICIPANT	\N	PRESENT	0
236359	236356	11026G	PARTICIPANT	\N	PRESENT	0
236360	236356	08012N	PARTICIPANT	\N	PRESENT	0
236361	236356	14147R	PARTICIPANT	\N	PRESENT	0
236362	236356	04043D	PARTICIPANT	\N	PRESENT	0
236363	236356	98005N	PARTICIPANT	\N	PRESENT	0
237861	237860	95067Q	PARTICIPANT	\N	PRESENT	0
237862	237860	14079W	PARTICIPANT	\N	PRESENT	0
237863	237860	08058D	PARTICIPANT	\N	PRESENT	0
237864	237860	19647E	PARTICIPANT	\N	PRESENT	0
237865	237860	14055N	PARTICIPANT	\N	PRESENT	0
237893	235434	14097Y	PARTICIPANT	\N	PRESENT	0
237894	235434	19443T	PARTICIPANT	\N	PRESENT	0
237895	235434	01062T	PARTICIPANT	\N	PRESENT	0
237896	235434	01058X	PARTICIPANT	\N	PRESENT	0
237897	235434	08058D	PARTICIPANT	\N	PRESENT	0
237898	235434	16685X	PARTICIPANT	\N	PRESENT	0
237899	235434	11066Q	PARTICIPANT	\N	PRESENT	0
237900	235434	14105F	PARTICIPANT	\N	PRESENT	0
237901	235434	98018T	PRESIDENT	0	PRESENT	0
237902	235434	19709B	PARTICIPANT	\N	PRESENT	0
237903	235434	08061X	PARTICIPANT	\N	PRESENT	0
237904	235434	19583F	PARTICIPANT	\N	PRESENT	0
237905	235434	14255U	PARTICIPANT	\N	PRESENT	0
237906	235434	98050T	PARTICIPANT	\N	PRESENT	0
237907	235434	04040A	PARTICIPANT	\N	PRESENT	0
237908	235434	19251M	PARTICIPANT	\N	PRESENT	0
237909	235434	14357A	PARTICIPANT	\N	PRESENT	0
237910	235434	14225N	PARTICIPANT	\N	PRESENT	0
237911	235434	14237S	PARTICIPANT	\N	PRESENT	0
237912	235434	96004D	PARTICIPANT	\N	PRESENT	0
237913	235434	19563B	PARTICIPANT	\N	PRESENT	0
237914	235434	14135M	PARTICIPANT	\N	PRESENT	0
237915	235434	04057K	PARTICIPANT	\N	PRESENT	0
237916	235434	11026G	PARTICIPANT	\N	PRESENT	0
237917	235434	08014Q	PARTICIPANT	\N	PRESENT	0
237918	235434	14089Y	PARTICIPANT	\N	PRESENT	0
237919	235434	19725B	PARTICIPANT	\N	PRESENT	0
237920	235434	04061F	PARTICIPANT	\N	PRESENT	0
237921	235434	14331P	PARTICIPANT	\N	PRESENT	0
237923	237922	04085P	PARTICIPANT	\N	PRESENT	0
237924	237922	08055A	PARTICIPANT	\N	PRESENT	0
237925	237922	14093U	PARTICIPANT	\N	PRESENT	0
237926	237922	19549D	PARTICIPANT	\N	PRESENT	0
237927	237922	96004D	PARTICIPANT	\N	PRESENT	0
237928	237922	08060W	PARTICIPANT	\N	PRESENT	0
237929	237922	19733B	PARTICIPANT	\N	PRESENT	0
237930	237922	19383Y	PARTICIPANT	\N	PRESENT	0
237931	237922	08024S	PARTICIPANT	\N	PRESENT	0
237932	237922	14038Y	PARTICIPANT	\N	PRESENT	0
237933	237922	18083K	PARTICIPANT	\N	PRESENT	0
237934	237922	19701S	PARTICIPANT	\N	PRESENT	0
237935	237922	19681G	PARTICIPANT	\N	PRESENT	0
237972	235434	19669L	PARTICIPANT	\N	PRESENT	0
237937	237922	19525U	PARTICIPANT	\N	PRESENT	0
237938	237922	11065P	PARTICIPANT	\N	PRESENT	0
237939	237922	19659J	PARTICIPANT	\N	PRESENT	0
237940	237922	19599P	PARTICIPANT	\N	EXCUSE	0
237941	237922	02002K	PARTICIPANT	\N	PRESENT	0
237942	237922	15447F	PARTICIPANT	\N	PRESENT	0
237943	237922	19387D	PARTICIPANT	\N	PRESENT	0
237944	237922	19347U	PARTICIPANT	\N	PRESENT	0
237945	237922	19685L	PARTICIPANT	\N	PRESENT	0
237946	237922	19333N	PARTICIPANT	\N	PRESENT	0
237947	237922	04097T	PARTICIPANT	\N	PRESENT	0
237948	237922	19551W	PARTICIPANT	\N	PRESENT	0
237949	237922	14029X	PARTICIPANT	\N	PRESENT	0
237973	235434	08053X	PARTICIPANT	\N	PRESENT	0
237951	237922	14219Q	PARTICIPANT	\N	PRESENT	0
237952	237922	14103D	PARTICIPANT	\N	PRESENT	0
237953	237922	80027E	PARTICIPANT	\N	PRESENT	0
237954	237922	14031R	PARTICIPANT	\N	PRESENT	0
237732	237429	11104D	PARTICIPANT	\N	PRESENT	0
237733	237429	19749K	PARTICIPANT	\N	PRESENT	0
237734	237429	04018C	PARTICIPANT	\N	PRESENT	0
237735	237429	19621T	PARTICIPANT	\N	PRESENT	0
237736	237429	14061L	PARTICIPANT	\N	PRESENT	0
237737	237429	14251Q	PARTICIPANT	\N	PRESENT	0
237738	237429	08035V	PARTICIPANT	\N	PRESENT	0
237739	237429	04033B	PARTICIPANT	\N	PRESENT	0
237740	237429	92040Q	PARTICIPANT	\N	PRESENT	0
237741	237429	11043H	PARTICIPANT	\N	PRESENT	0
237742	237429	08016S	PARTICIPANT	\N	PRESENT	0
237743	237429	14073Q	PARTICIPANT	\N	EXCUSE	0
237744	237429	08043V	PARTICIPANT	\N	EXCUSE	0
237745	237429	14249W	PARTICIPANT	\N	EXCUSE	0
237797	235609	19333N	PARTICIPANT	\N	PRESENT	0
237798	235609	95062K	PARTICIPANT	\N	PRESENT	0
237799	235609	19549D	PARTICIPANT	\N	PRESENT	0
237800	235609	19673G	PARTICIPANT	\N	PRESENT	0
237801	235609	01028R	PARTICIPANT	\N	PRESENT	0
237802	235609	02002K	PARTICIPANT	\N	PRESENT	0
237803	235609	19551W	PARTICIPANT	\N	PRESENT	0
237804	235609	80027E	PARTICIPANT	\N	PRESENT	0
237805	235609	08060W	PARTICIPANT	\N	PRESENT	0
237806	235609	14041T	PARTICIPANT	\N	PRESENT	0
237807	235609	19347U	PARTICIPANT	\N	PRESENT	0
237808	235609	14147R	PARTICIPANT	\N	PRESENT	0
237809	235609	14151M	PARTICIPANT	\N	PRESENT	0
237810	235609	14157T	PARTICIPANT	\N	PRESENT	0
237811	235609	19685L	PARTICIPANT	\N	PRESENT	0
237812	235609	19681G	PARTICIPANT	\N	PRESENT	0
237813	235609	11065P	PARTICIPANT	\N	PRESENT	0
237814	235609	19525U	PARTICIPANT	\N	PRESENT	0
237815	235609	14038Y	PARTICIPANT	\N	PRESENT	0
237816	235609	14065Q	PARTICIPANT	\N	PRESENT	0
237817	235609	19649G	PARTICIPANT	\N	PRESENT	0
237818	235609	01024M	PARTICIPANT	\N	PRESENT	0
237819	235609	08055A	PARTICIPANT	\N	PRESENT	0
237820	235609	14191V	PARTICIPANT	\N	PRESENT	0
237821	235609	19383Y	PARTICIPANT	\N	PRESENT	0
237822	235609	19701S	PARTICIPANT	\N	PRESENT	0
237823	235609	19387D	PARTICIPANT	\N	PRESENT	0
237824	235609	14001X	PARTICIPANT	\N	PRESENT	0
237825	235609	19581D	PARTICIPANT	\N	PRESENT	0
237826	235609	04044E	PARTICIPANT	\N	PRESENT	0
237827	235609	19585H	PARTICIPANT	\N	PRESENT	0
237828	235609	04047H	PARTICIPANT	\N	PRESENT	0
237829	235609	05008E	PARTICIPANT	\N	PRESENT	0
237830	235609	14231L	PARTICIPANT	\N	PRESENT	0
237831	235609	18083K	PARTICIPANT	\N	PRESENT	0
237832	235609	05012A	PARTICIPANT	\N	PRESENT	0
237833	235609	14051J	PARTICIPANT	\N	PRESENT	0
237834	235609	19503N	PARTICIPANT	\N	PRESENT	0
237835	235609	14215L	PARTICIPANT	\N	PRESENT	0
237836	235609	19483C	PARTICIPANT	\N	PRESENT	0
237837	235609	17637T	PARTICIPANT	\N	PRESENT	0
237838	235609	11072N	PARTICIPANT	\N	PRESENT	0
237839	235609	14053L	PARTICIPANT	\N	PRESENT	0
237840	235609	14135M	PARTICIPANT	\N	PRESENT	0
237841	235609	14103D	PARTICIPANT	\N	PRESENT	0
237842	235609	14111D	PARTICIPANT	\N	PRESENT	0
237843	235609	14031R	PARTICIPANT	\N	PRESENT	0
237844	235609	19713W	PARTICIPANT	\N	PRESENT	0
237845	235609	07034Q	PARTICIPANT	\N	PRESENT	0
237846	235609	11026G	PARTICIPANT	\N	PRESENT	0
237847	235609	08045X	PARTICIPANT	\N	PRESENT	0
237848	235609	19719D	PARTICIPANT	\N	PRESENT	0
237849	235609	15447F	PARTICIPANT	\N	PRESENT	0
237850	235609	19725B	PARTICIPANT	\N	PRESENT	0
237851	235609	19729F	PARTICIPANT	\N	PRESENT	0
237852	235609	95063L	PARTICIPANT	\N	PRESENT	0
237853	235609	19733B	PARTICIPANT	\N	PRESENT	0
237854	235609	08009T	PRESIDENT	0	PRESENT	0
237855	235609	04097T	PARTICIPANT	\N	PRESENT	0
237856	235609	19739H	PARTICIPANT	\N	PRESENT	0
237857	235609	19659J	PARTICIPANT	\N	PRESENT	0
237858	235609	17583W	PARTICIPANT	\N	PRESENT	0
237859	235609	19599P	PARTICIPANT	\N	EXCUSE	0
237955	237922	19637C	PARTICIPANT	\N	PRESENT	0
237956	237922	08009T	PRESIDENT	0	PRESENT	0
237957	237922	14221J	PARTICIPANT	\N	PRESENT	0
237958	237922	14169X	PARTICIPANT	\N	PRESENT	0
237959	237922	14191V	PARTICIPANT	\N	PRESENT	0
237960	237922	14237S	PARTICIPANT	\N	PRESENT	0
237961	237922	17637T	PARTICIPANT	\N	PRESENT	0
237962	237922	19745F	PARTICIPANT	\N	EXCUSE	0
237963	237922	05012A	PARTICIPANT	\N	PRESENT	0
237964	237922	19503N	PARTICIPANT	\N	PRESENT	0
237965	237922	19739H	PARTICIPANT	\N	PRESENT	0
237966	237922	17583W	PARTICIPANT	\N	PRESENT	0
237967	237922	95062K	PARTICIPANT	\N	PRESENT	0
237968	237922	19713W	PARTICIPANT	\N	PRESENT	0
237969	237922	14051J	PARTICIPANT	\N	PRESENT	0
237970	237922	14157T	PARTICIPANT	\N	PRESENT	0
237971	237922	19737F	PARTICIPANT	\N	PRESENT	0
237974	235434	04042C	PARTICIPANT	0	PRESENT	0
213269	213268	11074Q	PARTICIPANT	\N	PRESENT	0
213270	213268	19651A	PARTICIPANT	\N	PRESENT	0
213272	213271	11074Q	PARTICIPANT	\N	PRESENT	0
213273	213271	19651A	PARTICIPANT	\N	PRESENT	0
213337	213336	14085U	PARTICIPANT	\N	PRESENT	0
213338	213336	14253S	PARTICIPANT	\N	PRESENT	0
213370	213369	08034U	PARTICIPANT	\N	PRESENT	0
213372	213371	11074Q	PARTICIPANT	\N	PRESENT	0
213373	213371	08011M	PARTICIPANT	\N	PRESENT	0
216040	207703	04044E	PARTICIPANT	\N	PRESENT	0
216051	207703	01034P	PARTICIPANT	\N	PRESENT	0
216052	207703	11074Q	PARTICIPANT	\N	PRESENT	0
216053	207703	08011M	PARTICIPANT	\N	PRESENT	0
216054	207703	14235Q	PARTICIPANT	\N	PRESENT	0
216055	207703	95037J	PARTICIPANT	\N	PRESENT	0
216056	207703	14063N	PARTICIPANT	\N	PRESENT	0
216057	207703	14085U	PARTICIPANT	\N	PRESENT	0
216058	207703	11066Q	PARTICIPANT	\N	PRESENT	0
216059	207703	11067R	PARTICIPANT	\N	PRESENT	0
216060	207703	19349W	PARTICIPANT	\N	PRESENT	0
216061	207703	19687N	PARTICIPANT	\N	PRESENT	0
216361	207703	95063L	PARTICIPANT	\N	PRESENT	0
216063	207703	19713W	PARTICIPANT	\N	PRESENT	0
216064	207703	19479G	PARTICIPANT	\N	PRESENT	0
216065	207703	19441R	PARTICIPANT	\N	PRESENT	0
216066	207703	14103D	PARTICIPANT	\N	PRESENT	0
216067	207703	11070L	PARTICIPANT	\N	PRESENT	0
216070	207703	19545Y	PARTICIPANT	\N	PRESENT	0
216072	207703	04034C	PARTICIPANT	\N	PRESENT	0
216075	207703	19689Q	PARTICIPANT	\N	PRESENT	0
216076	207703	04071H	PARTICIPANT	\N	PRESENT	0
216077	207703	19447X	PARTICIPANT	\N	PRESENT	0
216080	207703	19467C	PARTICIPANT	\N	PRESENT	0
216081	207703	04088S	PARTICIPANT	\N	PRESENT	0
216082	207703	19573D	PARTICIPANT	\N	PRESENT	0
216083	207703	07029T	PARTICIPANT	\N	PRESENT	0
216085	207703	19705W	PARTICIPANT	\N	PRESENT	0
216088	207703	14105F	PARTICIPANT	\N	PRESENT	0
216090	207703	19575F	PARTICIPANT	\N	PRESENT	0
216091	207703	97011G	PARTICIPANT	\N	PRESENT	0
216095	207703	19443T	PARTICIPANT	\N	PRESENT	0
216096	207703	04092N	PARTICIPANT	\N	PRESENT	0
216099	207703	04086Q	PARTICIPANT	\N	PRESENT	0
216101	207703	14249W	PARTICIPANT	\N	PRESENT	0
216103	207703	14331P	PARTICIPANT	\N	PRESENT	0
216104	207703	19731Y	PARTICIPANT	\N	PRESENT	0
216106	207703	14187A	PARTICIPANT	\N	PRESENT	0
216107	207703	14133K	PARTICIPANT	\N	PRESENT	0
216108	207703	19667J	PARTICIPANT	\N	PRESENT	0
216112	207703	19367Y	PARTICIPANT	\N	PRESENT	0
216114	207703	14073Q	PARTICIPANT	\N	PRESENT	0
216115	207703	14089Y	PARTICIPANT	\N	PRESENT	0
216117	207703	14079W	PARTICIPANT	\N	PRESENT	0
216118	207703	14237S	PARTICIPANT	\N	PRESENT	0
216122	207703	19673G	PARTICIPANT	\N	PRESENT	0
216123	207703	11097X	PARTICIPANT	\N	PRESENT	0
216124	207703	19421M	PARTICIPANT	\N	PRESENT	0
216125	207703	14083S	PARTICIPANT	\N	PRESENT	0
216128	207703	98029W	PARTICIPANT	\N	PRESENT	0
216131	207703	14081Q	PARTICIPANT	\N	PRESENT	0
216140	207703	98018T	PARTICIPANT	\N	PRESENT	0
216143	207703	14281W	PARTICIPANT	\N	PRESENT	0
216145	207703	08052W	PARTICIPANT	\N	PRESENT	0
216147	207703	19695N	PARTICIPANT	\N	PRESENT	0
216149	207703	19565D	PARTICIPANT	\N	PRESENT	0
216152	207703	19711U	PARTICIPANT	\N	PRESENT	0
216156	207703	14327T	PARTICIPANT	\N	PRESENT	0
216161	207703	17637T	PARTICIPANT	\N	PRESENT	0
216162	207703	19483C	PARTICIPANT	\N	PRESENT	0
216163	207703	19525U	PARTICIPANT	\N	PRESENT	0
216164	207703	19683J	PARTICIPANT	\N	PRESENT	0
216243	207703	14033T	PARTICIPANT	\N	PRESENT	0
216166	207703	19415P	PARTICIPANT	\N	PRESENT	0
216167	207703	08061X	PARTICIPANT	\N	PRESENT	0
216168	207703	14034U	PARTICIPANT	\N	PRESENT	0
216169	207703	04059M	PARTICIPANT	\N	PRESENT	0
216170	207703	08068F	PARTICIPANT	\N	PRESENT	0
216171	207703	14055N	PARTICIPANT	\N	PRESENT	0
216172	207703	11053K	PARTICIPANT	\N	PRESENT	0
216173	207703	04057K	PARTICIPANT	\N	PRESENT	0
216174	207703	80013X	PARTICIPANT	\N	PRESENT	0
216179	207703	14041T	PARTICIPANT	\N	PRESENT	0
216197	207703	11110B	PARTICIPANT	\N	PRESENT	0
216198	207703	14201E	PARTICIPANT	\N	PRESENT	0
216199	207703	14061L	PARTICIPANT	\N	PRESENT	0
216200	207703	19251M	PARTICIPANT	\N	PRESENT	0
216202	207703	08028W	PARTICIPANT	\N	PRESENT	0
216203	207703	95015C	PARTICIPANT	\N	PRESENT	0
216204	207703	14053L	PARTICIPANT	\N	PRESENT	0
216205	207703	95041E	PARTICIPANT	\N	PRESENT	0
216206	207703	11048N	PARTICIPANT	\N	PRESENT	0
216207	207703	14223L	PARTICIPANT	\N	PRESENT	0
216208	207703	12016W	PARTICIPANT	\N	PRESENT	0
216209	207703	14069U	PARTICIPANT	\N	PRESENT	0
216210	207703	19521Q	PARTICIPANT	\N	PRESENT	0
216211	207703	14071N	PARTICIPANT	\N	PRESENT	0
216213	207703	08010L	PARTICIPANT	\N	PRESENT	0
216221	207703	19269X	PARTICIPANT	\N	PRESENT	0
216222	207703	14251Q	PARTICIPANT	\N	PRESENT	0
216242	207703	19581D	PARTICIPANT	\N	PRESENT	0
216244	207703	14157T	PARTICIPANT	\N	PRESENT	0
216245	207703	14030Q	PARTICIPANT	\N	PRESENT	0
216287	207703	14211G	PARTICIPANT	\N	PRESENT	0
216288	207703	08015R	PARTICIPANT	\N	PRESENT	0
216289	207703	08034U	PARTICIPANT	\N	PRESENT	0
216290	207703	01043Q	PARTICIPANT	\N	PRESENT	0
216291	207703	08020N	PARTICIPANT	\N	PRESENT	0
216292	207703	07033P	PARTICIPANT	\N	PRESENT	0
216293	207703	08016S	PARTICIPANT	\N	PRESENT	0
216295	207703	14121F	PARTICIPANT	\N	PRESENT	0
216297	207703	14265W	PARTICIPANT	\N	PRESENT	0
216298	207703	19729F	PARTICIPANT	\N	PRESENT	0
216299	207703	19719D	PARTICIPANT	\N	PRESENT	0
216300	207703	19671E	PARTICIPANT	\N	PRESENT	0
216303	207703	11099A	PARTICIPANT	\N	PRESENT	0
216358	207703	01057W	PARTICIPANT	\N	PRESENT	0
216359	207703	19651A	PARTICIPANT	\N	PRESENT	0
216360	207703	19707Y	PARTICIPANT	\N	PRESENT	0
216547	207704	86034E	PARTICIPANT	\N	PRESENT	0
216551	214590	14327T	PARTICIPANT	\N	PRESENT	0
216552	214590	14331P	PARTICIPANT	\N	PRESENT	0
216553	214590	11048N	PARTICIPANT	\N	PRESENT	0
216554	214590	19479G	PARTICIPANT	\N	PRESENT	0
216555	214590	19711U	PARTICIPANT	\N	PRESENT	0
216556	214590	95041E	PARTICIPANT	\N	PRESENT	0
216557	214590	08034U	PARTICIPANT	\N	PRESENT	0
216558	214590	19651A	PARTICIPANT	\N	PRESENT	0
216559	214590	08069G	PARTICIPANT	\N	PRESENT	0
216560	214590	01057W	PARTICIPANT	\N	PRESENT	0
216561	214590	08011M	PARTICIPANT	\N	PRESENT	0
216562	214590	11074Q	PRESIDENT	0	PRESENT	0
216563	214590	19667J	PARTICIPANT	\N	PRESENT	0
216564	214590	14034U	PARTICIPANT	\N	PRESENT	0
216565	214590	04086Q	PARTICIPANT	\N	PRESENT	0
216566	214590	07029T	PARTICIPANT	\N	PRESENT	0
216567	214590	14083S	PARTICIPANT	\N	PRESENT	0
216568	214590	14199E	PARTICIPANT	\N	PRESENT	0
216569	214590	14121F	PARTICIPANT	\N	PRESENT	0
216570	214590	07004J	PARTICIPANT	\N	EXCUSE	0
216571	207704	95062K	PARTICIPANT	\N	PRESENT	0
216572	207704	04097T	PARTICIPANT	\N	PRESENT	0
216573	207704	04092N	PARTICIPANT	\N	PRESENT	0
216574	207704	19643A	PARTICIPANT	\N	PRESENT	0
216575	207704	11080N	PARTICIPANT	\N	PRESENT	0
216576	207704	14211G	PARTICIPANT	\N	PRESENT	0
216577	207704	19711U	PARTICIPANT	\N	PRESENT	0
216578	207704	04008A	PARTICIPANT	\N	PRESENT	0
216579	207704	95041E	PARTICIPANT	\N	PRESENT	0
216580	207704	08028W	PARTICIPANT	\N	PRESENT	0
216581	207704	14199E	PARTICIPANT	\N	PRESENT	0
216582	207704	14259Y	PARTICIPANT	\N	PRESENT	0
216583	207704	14187A	PARTICIPANT	\N	PRESENT	0
216584	207704	14053L	PARTICIPANT	\N	PRESENT	0
216585	207704	95067Q	PARTICIPANT	\N	PRESENT	0
216586	207704	04086Q	PARTICIPANT	\N	PRESENT	0
216587	207704	14079W	PARTICIPANT	\N	PRESENT	0
216588	207704	19671E	PARTICIPANT	\N	PRESENT	0
216589	207704	08020N	PARTICIPANT	\N	PRESENT	0
216590	207704	98024R	PARTICIPANT	\N	PRESENT	0
216591	207704	98018T	PARTICIPANT	\N	PRESENT	0
216592	207704	04085P	PARTICIPANT	\N	PRESENT	0
216593	207704	19565D	PARTICIPANT	\N	PRESENT	0
216594	207704	14193X	PARTICIPANT	\N	PRESENT	0
216595	207704	19593H	PARTICIPANT	\N	PRESENT	0
216596	207704	19695N	PARTICIPANT	\N	PRESENT	0
216597	207704	07034Q	PARTICIPANT	\N	PRESENT	0
216598	207704	14223L	PARTICIPANT	\N	PRESENT	0
216599	207704	11063M	PARTICIPANT	\N	PRESENT	0
216600	207704	19347U	PARTICIPANT	\N	PRESENT	0
225429	225428	14028W	PARTICIPANT	\N	PRESENT	0
225460	218273	08010L	PARTICIPANT	\N	PRESENT	0
225461	218295	08010L	PARTICIPANT	\N	PRESENT	0
225956	225955	14030Q	PRESIDENT	0	PRESENT	0
225957	225955	08043V	PARTICIPANT	\N	PRESENT	0
225958	225955	19643A	PARTICIPANT	\N	PRESENT	0
225959	225955	18083K	PARTICIPANT	\N	EXCUSE	0
225960	225955	11031D	PARTICIPANT	\N	PRESENT	0
225961	225955	80013X	PARTICIPANT	\N	PRESENT	0
225962	225955	19693L	PARTICIPANT	\N	PRESENT	0
225963	225955	14217N	PARTICIPANT	\N	EXCUSE	0
225965	225955	19599P	PARTICIPANT	\N	EXCUSE	0
225966	225955	14179A	PARTICIPANT	\N	PRESENT	0
225967	225955	19715Y	PARTICIPANT	\N	EXCUSE	0
225968	225955	08031R	PARTICIPANT	\N	PRESENT	0
225969	225955	07029T	PARTICIPANT	\N	PRESENT	0
225970	225955	08017T	PARTICIPANT	\N	PRESENT	0
225971	225955	19697Q	PARTICIPANT	\N	EXCUSE	0
225972	225955	14109K	PARTICIPANT	\N	PRESENT	0
225973	225955	14235Q	PARTICIPANT	\N	EXCUSE	0
225974	225955	19269X	PARTICIPANT	\N	EXCUSE	0
226992	226991	14239U	PARTICIPANT	\N	PRESENT	0
227016	227015	14239U	PARTICIPANT	\N	PRESENT	0
226994	226991	08052W	PARTICIPANT	\N	PRESENT	0
232996	232539	08062Y	PARTICIPANT	\N	EXCUSE	0
226996	226991	14217N	PARTICIPANT	\N	PRESENT	0
227018	227015	08052W	PARTICIPANT	\N	PRESENT	0
233514	233513	08020N	PARTICIPANT	\N	PRESENT	0
226999	226991	14213J	PARTICIPANT	\N	PRESENT	0
233515	233513	08024S	PARTICIPANT	\N	PRESENT	0
227001	226991	11067R	PARTICIPANT	\N	PRESENT	0
227002	226991	04092N	PARTICIPANT	\N	PRESENT	0
233516	233513	14199E	PARTICIPANT	\N	PRESENT	0
227004	226991	14227Q	PARTICIPANT	\N	PRESENT	0
227005	226991	01034P	PARTICIPANT	\N	PRESENT	0
227020	227015	14217N	PARTICIPANT	\N	PRESENT	0
233517	233513	11064N	PARTICIPANT	\N	PRESENT	0
233518	233513	14061L	PARTICIPANT	\N	PRESENT	0
227023	227015	14213J	PARTICIPANT	\N	PRESENT	0
233519	233513	98005N	PARTICIPANT	\N	PRESENT	0
227025	227015	11067R	PARTICIPANT	\N	PRESENT	0
227026	227015	04092N	PARTICIPANT	\N	PRESENT	0
233520	233513	14219Q	PARTICIPANT	\N	PRESENT	0
227028	227015	14227Q	PARTICIPANT	\N	PRESENT	0
227029	227015	01034P	PARTICIPANT	\N	PRESENT	0
233521	233513	14059S	PARTICIPANT	\N	PRESENT	0
233526	233513	14001X	PARTICIPANT	\N	PRESENT	0
233527	233513	08053X	PARTICIPANT	\N	PRESENT	0
233528	233513	11072N	PARTICIPANT	\N	PRESENT	0
233529	233513	07034Q	PARTICIPANT	\N	PRESENT	0
233530	233513	19319Q	PARTICIPANT	\N	PRESENT	0
233531	233513	04043D	PARTICIPANT	\N	PRESENT	0
233799	232940	19553Y	PARTICIPANT	\N	PRESENT	0
233800	232940	08034U	PARTICIPANT	\N	PRESENT	0
233801	232940	19533U	PARTICIPANT	\N	PRESENT	0
233802	232940	88008L	PARTICIPANT	\N	PRESENT	0
233803	232940	14093U	PARTICIPANT	\N	PRESENT	0
233804	232940	14195A	PARTICIPANT	\N	PRESENT	0
233805	232940	04043D	PARTICIPANT	\N	PRESENT	0
233806	232940	14205J	PARTICIPANT	\N	PRESENT	0
233807	232940	02002K	PARTICIPANT	\N	PRESENT	0
233808	232940	19545Y	PARTICIPANT	\N	PRESENT	0
233809	232940	04057K	PARTICIPANT	\N	PRESENT	0
233810	232940	97011G	PARTICIPANT	\N	PRESENT	0
233811	232940	19585H	PARTICIPANT	\N	PRESENT	0
233813	232940	14111D	PARTICIPANT	\N	PRESENT	0
233814	232940	14251Q	PARTICIPANT	\N	PRESENT	0
233815	232940	08041T	PARTICIPANT	\N	PRESENT	0
233817	232940	19583F	PARTICIPANT	\N	PRESENT	0
233818	232940	11064N	PARTICIPANT	\N	PRESENT	0
233819	232940	14123H	PARTICIPANT	\N	PRESENT	0
233820	232940	14147R	PARTICIPANT	\N	PRESENT	0
233821	232940	98035U	PARTICIPANT	\N	PRESENT	0
233822	232940	07033P	PARTICIPANT	\N	PRESENT	0
233823	232940	04085P	PARTICIPANT	\N	PRESENT	0
233824	232940	14357A	PARTICIPANT	\N	PRESENT	0
233825	232940	14329V	PARTICIPANT	\N	PRESENT	0
233826	232940	04042C	PARTICIPANT	\N	PRESENT	0
233827	232940	14051J	PARTICIPANT	\N	PRESENT	0
233828	232940	19691J	PARTICIPANT	\N	PRESENT	0
233829	232940	08052W	PARTICIPANT	\N	PRESENT	0
233830	232940	14169X	PARTICIPANT	\N	PRESENT	0
233831	232940	14083S	PARTICIPANT	\N	PRESENT	0
233832	232940	08016S	PARTICIPANT	\N	PRESENT	0
233833	232940	14107H	PARTICIPANT	\N	PRESENT	0
233834	232940	08045X	PARTICIPANT	\N	PRESENT	0
233835	232940	14225N	PARTICIPANT	\N	PRESENT	0
233836	232940	19643A	PARTICIPANT	\N	PRESENT	0
233838	232940	19647E	PARTICIPANT	\N	PRESENT	0
233839	232940	19649G	PARTICIPANT	\N	PRESENT	0
233841	232940	10006L	PARTICIPANT	\N	PRESENT	0
233842	232940	14197C	PARTICIPANT	\N	PRESENT	0
233843	232940	04061F	PARTICIPANT	\N	PRESENT	0
233844	232940	14028W	PARTICIPANT	\N	PRESENT	0
233845	232940	07029T	PARTICIPANT	\N	PRESENT	0
233846	232940	80013X	PARTICIPANT	\N	PRESENT	0
233847	232940	08038Y	PARTICIPANT	\N	PRESENT	0
233848	232940	86034E	PARTICIPANT	\N	PRESENT	0
233849	232940	19723Y	PARTICIPANT	\N	PRESENT	0
233850	232940	14065Q	PARTICIPANT	\N	PRESENT	0
233851	232940	19549D	PARTICIPANT	\N	PRESENT	0
233852	232940	08043V	PARTICIPANT	\N	PRESENT	0
233853	232940	11066Q	PARTICIPANT	\N	PRESENT	0
233854	232940	11104D	PARTICIPANT	\N	PRESENT	0
233855	232940	14281W	PARTICIPANT	\N	PRESENT	0
233856	232940	08035V	PARTICIPANT	\N	PRESENT	0
233857	232940	11115U	PARTICIPANT	\N	PRESENT	0
233858	232940	14033T	PARTICIPANT	\N	PRESENT	0
233859	232940	14199E	PARTICIPANT	\N	PRESENT	0
233860	232940	19489J	PARTICIPANT	\N	PRESENT	0
233861	232940	17779H	PARTICIPANT	\N	PRESENT	0
233862	232940	19735D	PARTICIPANT	\N	PRESENT	0
233863	232940	08058D	PARTICIPANT	\N	PRESENT	0
233864	232940	14121F	PARTICIPANT	\N	PRESENT	0
233866	232940	14085U	PARTICIPANT	\N	PRESENT	0
233867	232940	08017T	PARTICIPANT	\N	PRESENT	0
233868	232940	11045K	PARTICIPANT	\N	PRESENT	0
233869	232940	11041F	PARTICIPANT	\N	PRESENT	0
233870	232940	14207L	PARTICIPANT	\N	PRESENT	0
233871	232940	19725B	PARTICIPANT	\N	PRESENT	0
233872	232940	19333N	PARTICIPANT	\N	PRESENT	0
233873	232940	14001X	PARTICIPANT	\N	PRESENT	0
233875	232940	14227Q	PARTICIPANT	\N	PRESENT	0
233876	232940	19683J	PARTICIPANT	\N	PRESENT	0
233878	232940	11109J	PARTICIPANT	\N	PRESENT	0
233879	232940	19295A	PARTICIPANT	\N	PRESENT	0
233880	232940	11054L	PARTICIPANT	\N	PRESENT	0
233881	232940	19689Q	PARTICIPANT	\N	PRESENT	0
233882	232940	19675J	PARTICIPANT	\N	PRESENT	0
233883	232940	19413M	PARTICIPANT	\N	PRESENT	0
233885	232940	19251M	PARTICIPANT	\N	PRESENT	0
233886	232940	19591F	PARTICIPANT	\N	PRESENT	0
233888	232940	19503N	PARTICIPANT	\N	PRESENT	0
233892	232940	14109K	PARTICIPANT	\N	PRESENT	0
233890	232940	19551W	PARTICIPANT	\N	PRESENT	0
233891	232940	11067R	PARTICIPANT	\N	PRESENT	0
233896	232940	14063N	PARTICIPANT	\N	PRESENT	0
233898	232940	14097Y	PARTICIPANT	\N	PRESENT	0
233899	232940	14257W	PARTICIPANT	\N	PRESENT	0
233900	232940	19669L	PARTICIPANT	\N	PRESENT	0
233901	232940	11056N	PARTICIPANT	\N	PRESENT	0
233904	232940	14231L	PARTICIPANT	\N	PRESENT	0
233907	232940	14179A	PARTICIPANT	\N	PRESENT	0
233909	232940	19369B	PARTICIPANT	\N	PRESENT	0
233910	232940	08009T	PARTICIPANT	\N	PRESENT	0
233911	232940	19611R	PARTICIPANT	\N	PRESENT	0
233912	232940	19511N	PARTICIPANT	\N	PRESENT	0
233915	232940	19737F	PARTICIPANT	\N	PRESENT	0
233916	232940	19699S	PARTICIPANT	\N	PRESENT	0
233918	232940	19619A	PARTICIPANT	\N	PRESENT	0
233919	232940	16685X	PARTICIPANT	\N	PRESENT	0
214608	205652	14239U	PARTICIPANT	\N	PRESENT	0
214610	205652	01058X	PARTICIPANT	\N	EXCUSE	0
224014	218821	19551W	PARTICIPANT	\N	PRESENT	0
224047	218821	19479G	PARTICIPANT	\N	PRESENT	0
227681	227680	14065Q	PARTICIPANT	\N	PRESENT	0
227682	227680	96004D	PRESIDENT	0	PRESENT	0
227683	227680	14089Y	PARTICIPANT	\N	PRESENT	0
227684	227680	08014Q	PARTICIPANT	\N	PRESENT	0
227685	227680	14079W	PARTICIPANT	\N	PRESENT	0
227686	227680	14249W	PARTICIPANT	\N	PRESENT	0
227687	227680	11083R	PARTICIPANT	\N	PRESENT	0
227688	227680	19725B	PARTICIPANT	\N	PRESENT	0
227689	227680	95037J	PARTICIPANT	\N	PRESENT	0
227690	227680	19685L	PARTICIPANT	\N	EXCUSE	0
227691	227680	08044W	PARTICIPANT	\N	EXCUSE	0
227692	227680	14073Q	PARTICIPANT	\N	PRESENT	0
227693	227680	14205J	PARTICIPANT	\N	PRESENT	0
227694	227680	04057K	PARTICIPANT	\N	PRESENT	0
227695	227680	19335Q	PARTICIPANT	\N	EXCUSE	0
227696	227680	19593H	PARTICIPANT	\N	EXCUSE	0
227697	227680	14237S	PARTICIPANT	\N	PRESENT	0
227698	227680	14331P	PARTICIPANT	\N	PRESENT	0
227699	227680	14225N	PARTICIPANT	\N	PRESENT	0
227700	227680	10015M	PARTICIPANT	\N	PRESENT	0
227701	227680	19563B	PARTICIPANT	\N	PRESENT	0
227702	227680	08039A	PARTICIPANT	\N	PRESENT	0
227703	227680	14135M	PARTICIPANT	\N	PRESENT	0
235350	232998	04045F	PARTICIPANT	\N	PRESENT	0
235351	232998	95067Q	PARTICIPANT	\N	PRESENT	0
235352	232998	05012A	PARTICIPANT	\N	PRESENT	0
235353	232998	14069U	PARTICIPANT	\N	PRESENT	0
235354	232998	14259Y	PARTICIPANT	\N	PRESENT	0
235355	232998	19667J	PARTICIPANT	\N	PRESENT	0
239220	238878	19723Y	PARTICIPANT	\N	PRESENT	0
239221	238878	95030B	PARTICIPANT	\N	PRESENT	0
239222	238878	14219Q	PARTICIPANT	\N	PRESENT	0
239223	238878	19709B	PARTICIPANT	\N	PRESENT	0
239224	238878	19711U	PARTICIPANT	\N	PRESENT	0
239225	238869	19515S	PARTICIPANT	\N	PRESENT	0
239226	238869	19565D	PARTICIPANT	\N	PRESENT	0
239227	238869	14357A	PARTICIPANT	\N	PRESENT	0
239228	238869	19441R	PARTICIPANT	\N	PRESENT	0
239229	238869	19413M	PARTICIPANT	\N	PRESENT	0
239230	238869	80013X	PARTICIPANT	\N	PRESENT	0
239231	238869	19631V	PARTICIPANT	\N	PRESENT	0
239232	238869	04049K	PARTICIPANT	\N	PRESENT	0
239233	238869	19705W	PARTICIPANT	\N	PRESENT	0
239234	238869	19707Y	PARTICIPANT	\N	PRESENT	0
239235	238869	14179A	PARTICIPANT	\N	PRESENT	0
239236	238869	19369B	PARTICIPANT	\N	PRESENT	0
239237	238869	19511N	PARTICIPANT	\N	PRESENT	0
239238	238869	14265W	PARTICIPANT	\N	PRESENT	0
239239	238869	14329V	PARTICIPANT	\N	PRESENT	0
239240	238869	19591F	PARTICIPANT	\N	PRESENT	0
239241	238869	19467C	PARTICIPANT	\N	PRESENT	0
239242	238869	14073Q	PARTICIPANT	\N	PRESENT	0
239243	238869	14187A	PARTICIPANT	\N	PRESENT	0
239244	238869	19611R	PARTICIPANT	\N	PRESENT	0
239245	238869	08038Y	PARTICIPANT	\N	PRESENT	0
239246	238869	08062Y	PARTICIPANT	\N	PRESENT	0
239247	238869	19695N	PARTICIPANT	\N	PRESENT	0
239248	238869	14033T	PARTICIPANT	\N	PRESENT	0
239249	238869	11090Q	PRESIDENT	0	PRESENT	0
239250	238869	19693L	PARTICIPANT	\N	PRESENT	0
239251	238869	14205J	PARTICIPANT	\N	PRESENT	0
239252	238869	11056N	PARTICIPANT	\N	PRESENT	0
239253	238869	14115H	PARTICIPANT	\N	PRESENT	0
239254	238869	19731Y	PARTICIPANT	\N	PRESENT	0
239255	238869	11083R	PARTICIPANT	\N	PRESENT	0
239256	238869	19747H	PARTICIPANT	\N	PRESENT	0
239257	238869	14207L	PARTICIPANT	\N	PRESENT	0
239258	238869	04043D	PARTICIPANT	\N	PRESENT	0
239259	238869	14257W	PARTICIPANT	\N	PRESENT	0
239260	238878	19479G	PARTICIPANT	\N	PRESENT	0
239261	238878	19413M	PARTICIPANT	\N	PRESENT	0
239262	238878	19525U	PARTICIPANT	\N	PRESENT	0
239263	238878	11010L	PARTICIPANT	\N	PRESENT	0
239264	238878	14133K	PARTICIPANT	\N	PRESENT	0
239265	238878	14215L	PARTICIPANT	\N	PRESENT	0
239266	238878	19369B	PARTICIPANT	\N	PRESENT	0
239268	238878	14357A	PARTICIPANT	\N	PRESENT	0
239269	238878	19551W	PARTICIPANT	\N	PRESENT	0
239270	238878	19483C	PARTICIPANT	\N	PRESENT	0
239271	238878	19693L	PARTICIPANT	\N	PRESENT	0
239272	238878	08010L	PARTICIPANT	\N	PRESENT	0
239273	238878	19441R	PARTICIPANT	\N	PRESENT	0
239274	238878	19349W	PARTICIPANT	\N	PRESENT	0
239279	238878	19467C	PARTICIPANT	\N	PRESENT	0
239280	238878	19737F	PARTICIPANT	\N	PRESENT	0
239281	238878	14199E	PARTICIPANT	\N	PRESENT	0
239284	238878	14079W	PARTICIPANT	\N	PRESENT	0
239307	238878	19747H	PARTICIPANT	\N	PRESENT	0
239342	238605	95030B	PARTICIPANT	\N	PRESENT	0
239311	238878	04049K	PARTICIPANT	\N	PRESENT	0
239343	238605	14079W	PARTICIPANT	\N	PRESENT	0
239344	238605	97011G	PARTICIPANT	\N	PRESENT	0
239345	238605	98022P	PARTICIPANT	\N	PRESENT	0
239346	238605	98005N	PARTICIPANT	\N	PRESENT	0
239347	238605	16685X	PARTICIPANT	\N	PRESENT	0
239348	238605	98029W	PARTICIPANT	\N	PRESENT	0
239349	238605	11064N	PARTICIPANT	\N	PRESENT	0
239350	238605	95067Q	PARTICIPANT	\N	PRESENT	0
239351	238605	11041F	PARTICIPANT	\N	PRESENT	0
239352	238605	08058D	PARTICIPANT	\N	PRESENT	0
239353	238605	11066Q	PARTICIPANT	\N	PRESENT	0
239354	238605	11027H	PARTICIPANT	\N	PRESENT	0
239355	238605	08056B	PARTICIPANT	\N	PRESENT	0
239356	238605	19251M	PARTICIPANT	\N	PRESENT	0
239357	238605	14028W	PARTICIPANT	\N	PRESENT	0
239358	238605	08053X	PARTICIPANT	\N	PRESENT	0
239359	238605	19721W	PARTICIPANT	\N	PRESENT	0
239360	238605	11054L	PARTICIPANT	\N	PRESENT	0
239361	238605	14097Y	PARTICIPANT	\N	PRESENT	0
239362	238605	01058X	PARTICIPANT	\N	PRESENT	0
239363	238630	19697Q	PARTICIPANT	\N	PRESENT	0
239364	238630	11067R	PARTICIPANT	\N	PRESENT	0
239365	238630	11077T	PARTICIPANT	\N	PRESENT	0
239366	238630	14355X	PARTICIPANT	\N	PRESENT	0
239367	238630	11097X	PARTICIPANT	\N	PRESENT	0
239368	238630	19415P	PARTICIPANT	\N	PRESENT	0
239369	238630	04045F	PARTICIPANT	\N	PRESENT	0
239370	238630	14227Q	PARTICIPANT	\N	PRESENT	0
239371	238630	19675J	PARTICIPANT	\N	PRESENT	0
239372	238630	11063M	PARTICIPANT	\N	PRESENT	0
239373	238630	17779H	PARTICIPANT	\N	PRESENT	0
239374	238630	19703U	PARTICIPANT	\N	PRESENT	0
239375	238630	14239U	PARTICIPANT	\N	PRESENT	0
239376	238630	14281W	PARTICIPANT	\N	PRESENT	0
239377	238630	14087W	PARTICIPANT	\N	PRESENT	0
239378	238630	19679N	PARTICIPANT	\N	PRESENT	0
239379	238630	14195A	PARTICIPANT	\N	PRESENT	0
239380	238630	19575F	PARTICIPANT	\N	PRESENT	0
239381	238630	14213J	PARTICIPANT	\N	PRESENT	0
239382	238630	14217N	PARTICIPANT	\N	PRESENT	0
239383	238630	19335Q	PARTICIPANT	\N	PRESENT	0
239384	238630	14261S	PARTICIPANT	\N	PRESENT	0
239385	238630	10006L	PARTICIPANT	\N	PRESENT	0
239386	238630	19683J	PARTICIPANT	\N	PRESENT	0
239387	238630	98024R	PARTICIPANT	\N	PRESENT	0
239388	238630	19521Q	PARTICIPANT	\N	PRESENT	0
239389	238630	19527W	PARTICIPANT	\N	PRESENT	0
239390	238630	01034P	PARTICIPANT	\N	PRESENT	0
239391	238630	04092N	PRESIDENT	0	PRESENT	0
239392	238630	08052W	PARTICIPANT	\N	PRESENT	0
239393	238630	19691J	PARTICIPANT	\N	PRESENT	0
239394	238630	19717B	PARTICIPANT	\N	PRESENT	0
239395	238630	08041T	PARTICIPANT	\N	PRESENT	0
239396	238630	19723Y	PARTICIPANT	\N	PRESENT	0
239397	238630	19727D	PARTICIPANT	\N	PRESENT	0
239398	238630	14119M	PARTICIPANT	\N	PRESENT	0
239399	238630	11103C	PARTICIPANT	\N	PRESENT	0
239400	238630	19657G	PARTICIPANT	\N	PRESENT	0
239401	238630	14071N	PARTICIPANT	\N	PRESENT	0
239402	238630	19577H	PARTICIPANT	\N	PRESENT	0
239403	238630	19553Y	PARTICIPANT	\N	EXCUSE	0
239404	238630	08048B	PARTICIPANT	\N	EXCUSE	0
239405	238630	19715Y	PARTICIPANT	\N	EXCUSE	0
239406	238630	19569H	PARTICIPANT	\N	PRESENT	0
239407	238630	14042U	PARTICIPANT	\N	PRESENT	0
239408	238605	14133K	PARTICIPANT	\N	PRESENT	0
239409	238605	14255U	PARTICIPANT	\N	PRESENT	0
239419	238606	14001X	PARTICIPANT	\N	PRESENT	0
239420	238606	19543W	PARTICIPANT	\N	PRESENT	0
239421	238606	19585H	PARTICIPANT	\N	PRESENT	0
239422	238606	19673G	PARTICIPANT	\N	PRESENT	0
239423	238606	01028R	PARTICIPANT	\N	PRESENT	0
239424	238606	14231L	PARTICIPANT	\N	PRESENT	0
239425	238606	19447X	PARTICIPANT	\N	PRESENT	0
239426	238606	05008E	PRESIDENT	0	PRESENT	0
233679	233676	19683J	PARTICIPANT	\N	PRESENT	0
233691	233687	19683J	PARTICIPANT	\N	PRESENT	0
233717	233715	19683J	PARTICIPANT	\N	PRESENT	0
233734	233731	19683J	PARTICIPANT	\N	PRESENT	0
233840	233812	19683J	PARTICIPANT	\N	PRESENT	0
233992	233979	14123H	PARTICIPANT	\N	PRESENT	0
234001	233999	14123H	PARTICIPANT	\N	PRESENT	0
234009	234008	14123H	PARTICIPANT	\N	PRESENT	0
234010	234008	19533U	PARTICIPANT	\N	PRESENT	0
234011	234008	19611R	PARTICIPANT	\N	PRESENT	0
234016	234008	08031R	PARTICIPANT	\N	PRESENT	0
234032	234031	87003B	PARTICIPANT	\N	PRESENT	0
234033	234031	11104D	PARTICIPANT	\N	PRESENT	0
235394	232998	19253P	PARTICIPANT	\N	PRESENT	0
238520	238457	14133K	PARTICIPANT	\N	PRESENT	0
238521	238457	04040A	PARTICIPANT	\N	PRESENT	0
238522	238457	14105F	PARTICIPANT	\N	PRESENT	0
238523	238457	08058D	PARTICIPANT	\N	PRESENT	0
238524	238457	14255U	PARTICIPANT	\N	PRESENT	0
238525	238457	04042C	PRESIDENT	0	PRESENT	0
238526	238457	14267Y	PARTICIPANT	\N	PRESENT	0
238527	238457	98018T	PARTICIPANT	\N	PRESENT	0
237995	235434	04097T	PARTICIPANT	\N	PRESENT	0
238528	238457	19251M	PARTICIPANT	\N	PRESENT	0
238529	238457	04035D	PARTICIPANT	\N	PRESENT	0
238530	238457	11064N	PARTICIPANT	\N	PRESENT	0
238165	232949	11063M	PARTICIPANT	\N	PRESENT	0
238166	232949	19715Y	PARTICIPANT	\N	PRESENT	0
238167	232949	11067R	PARTICIPANT	\N	PRESENT	0
238168	232949	04085P	PARTICIPANT	\N	PRESENT	0
238169	232949	19333N	PARTICIPANT	\N	PRESENT	0
238170	232949	14281W	PARTICIPANT	\N	PRESENT	0
238171	232949	80013X	PARTICIPANT	\N	PRESENT	0
238172	232949	19727D	PARTICIPANT	\N	PRESENT	0
238173	232949	08060W	PARTICIPANT	\N	PRESENT	0
238174	232949	14227Q	PARTICIPANT	\N	PRESENT	0
238175	232949	04045F	PARTICIPANT	\N	PRESENT	0
238176	232949	19697Q	PARTICIPANT	\N	PRESENT	0
238177	232949	04092N	PARTICIPANT	\N	PRESENT	0
238178	232949	14034U	PARTICIPANT	\N	PRESENT	0
238179	232949	14231L	PARTICIPANT	\N	PRESENT	0
238180	232949	19747H	PARTICIPANT	\N	PRESENT	0
238181	232949	14061L	PARTICIPANT	\N	PRESENT	0
238182	232949	08015R	PARTICIPANT	\N	PRESENT	0
238183	232949	14213J	PARTICIPANT	\N	PRESENT	0
238184	232949	14026U	PARTICIPANT	\N	PRESENT	0
238185	232949	14217N	PARTICIPANT	\N	PRESENT	0
238186	232949	14331P	PARTICIPANT	\N	PRESENT	0
238187	232949	14053L	PARTICIPANT	\N	PRESENT	0
238188	232949	14071N	PARTICIPANT	\N	PRESENT	0
238189	232949	14187A	PARTICIPANT	\N	PRESENT	0
238190	232949	19521Q	PARTICIPANT	\N	PRESENT	0
238191	232949	14195A	PARTICIPANT	\N	PRESENT	0
238192	232949	08052W	PARTICIPANT	\N	PRESENT	0
238193	232949	14197C	PARTICIPANT	\N	PRESENT	0
238194	232949	19695N	PARTICIPANT	\N	PRESENT	0
238195	232949	14219Q	PARTICIPANT	\N	PRESENT	0
238196	232949	19737F	PARTICIPANT	\N	PRESENT	0
238197	232949	14083S	PARTICIPANT	\N	PRESENT	0
238198	232949	19703U	PARTICIPANT	\N	PRESENT	0
238199	232949	14327T	PARTICIPANT	\N	PRESENT	0
238200	232949	19553Y	PARTICIPANT	\N	PRESENT	0
238201	232949	07029T	PARTICIPANT	\N	PRESENT	0
238202	232949	10006L	PARTICIPANT	\N	PRESENT	0
238203	232949	11012A	PARTICIPANT	\N	PRESENT	0
238204	232949	14261S	PARTICIPANT	\N	PRESENT	0
238205	232949	19447X	PARTICIPANT	\N	PRESENT	0
238206	232949	04047H	PARTICIPANT	\N	PRESENT	0
238293	238292	98035U	PARTICIPANT	\N	PRESENT	0
238294	238292	11012A	PARTICIPANT	\N	PRESENT	0
238295	238292	08055A	PARTICIPANT	\N	PRESENT	0
238296	238292	04038G	PARTICIPANT	\N	PRESENT	0
238297	238292	08012N	PARTICIPANT	\N	PRESENT	0
238298	238292	14083S	PARTICIPANT	\N	PRESENT	0
238299	238292	19549D	PARTICIPANT	\N	PRESENT	0
238300	238292	19575F	PARTICIPANT	\N	PRESENT	0
238311	238310	14255U	PARTICIPANT	\N	PRESENT	0
238316	233052	11109J	PARTICIPANT	\N	PRESENT	0
238317	233052	19631V	PARTICIPANT	\N	PRESENT	0
238318	233052	14038Y	PARTICIPANT	\N	PRESENT	0
238319	233052	19295A	PARTICIPANT	\N	PRESENT	0
238320	233052	19659J	PARTICIPANT	\N	EXCUSE	0
238321	233052	19577H	PARTICIPANT	\N	PRESENT	0
238322	233052	19691J	PARTICIPANT	\N	PRESENT	0
238323	233052	19329S	PARTICIPANT	\N	PRESENT	0
238324	233052	19715Y	PARTICIPANT	\N	PRESENT	0
238325	233052	98005N	PARTICIPANT	\N	PRESENT	0
238326	233052	14097Y	PARTICIPANT	\N	PRESENT	0
238327	233052	14039A	PARTICIPANT	\N	PRESENT	0
238124	238123	08055A	PARTICIPANT	\N	PRESENT	0
238125	238123	08014Q	PARTICIPANT	\N	PRESENT	0
238126	238123	19467C	PARTICIPANT	\N	PRESENT	0
238127	238123	14042U	PARTICIPANT	\N	PRESENT	0
238128	238123	14197C	PARTICIPANT	\N	PRESENT	0
238129	238123	19725B	PARTICIPANT	\N	PRESENT	0
238130	238123	19551W	PARTICIPANT	\N	PRESENT	0
238131	238123	14097Y	PARTICIPANT	\N	PRESENT	0
238132	238123	19723Y	PARTICIPANT	\N	PRESENT	0
238133	238123	19483C	PARTICIPANT	\N	PRESENT	0
238134	238123	14205J	PARTICIPANT	\N	PRESENT	0
238135	238123	19563B	PARTICIPANT	\N	PRESENT	0
238136	238123	14265W	PARTICIPANT	\N	PRESENT	0
238137	238123	19533U	PARTICIPANT	\N	PRESENT	0
238138	238123	04088S	PARTICIPANT	\N	PRESENT	0
238139	238123	98050T	PARTICIPANT	\N	PRESENT	0
238386	238385	96004D	PARTICIPANT	\N	PRESENT	0
238387	238385	14089Y	PARTICIPANT	\N	PRESENT	0
238388	238385	19563B	PARTICIPANT	\N	PRESENT	0
238389	238385	19593H	PARTICIPANT	\N	PRESENT	0
238390	238385	10015M	PARTICIPANT	\N	PRESENT	0
238391	238385	98035U	PARTICIPANT	\N	PRESENT	0
238163	232949	04044E	PARTICIPANT	\N	PRESENT	0
238392	238385	14065Q	PARTICIPANT	\N	EXCUSE	0
238393	238385	19725B	PARTICIPANT	\N	EXCUSE	0
238164	232949	11031D	PARTICIPANT	\N	PRESENT	0
238394	238385	11083R	PARTICIPANT	\N	EXCUSE	0
238395	238385	04061F	PARTICIPANT	\N	EXCUSE	0
238396	238385	14061L	PARTICIPANT	\N	EXCUSE	0
238397	238385	14073Q	PARTICIPANT	\N	EXCUSE	0
238398	238385	08039A	PARTICIPANT	\N	EXCUSE	0
238399	238385	04057K	PARTICIPANT	\N	EXCUSE	0
238400	238385	14229S	PARTICIPANT	\N	PRESENT	0
238401	238385	14331P	PARTICIPANT	\N	PRESENT	0
238402	238385	08018U	PARTICIPANT	\N	EXCUSE	0
238444	233052	19729F	PARTICIPANT	\N	PRESENT	0
238445	233052	14219Q	PARTICIPANT	\N	PRESENT	0
238446	233052	14059S	PARTICIPANT	\N	PRESENT	0
238447	233052	08019V	PRESIDENT	0	PRESENT	0
238448	233052	19657G	PARTICIPANT	\N	PRESENT	0
238449	233052	11072N	PARTICIPANT	\N	PRESENT	0
238450	233052	08073C	PARTICIPANT	\N	PRESENT	0
238451	233052	19319Q	PARTICIPANT	\N	PRESENT	0
238452	233052	14331P	PARTICIPANT	\N	PRESENT	0
238453	233052	19703U	PARTICIPANT	\N	PRESENT	0
238454	233052	14030Q	PARTICIPANT	\N	PRESENT	0
238515	238514	07004J	PARTICIPANT	\N	PRESENT	0
238516	238514	10015M	PARTICIPANT	\N	PRESENT	0
238517	238514	14079W	PARTICIPANT	\N	PRESENT	0
238531	238457	95037J	PARTICIPANT	\N	PRESENT	0
238532	238457	14097Y	PARTICIPANT	\N	PRESENT	0
238533	238457	19583F	PARTICIPANT	\N	PRESENT	0
238534	238457	19709B	PARTICIPANT	\N	PRESENT	0
238535	238457	16685X	PARTICIPANT	\N	PRESENT	0
238536	238457	08053X	PARTICIPANT	\N	PRESENT	0
238537	238457	08061X	PARTICIPANT	\N	PRESENT	0
238538	238457	08047A	PARTICIPANT	\N	PRESENT	0
238539	238457	14193X	PARTICIPANT	\N	PRESENT	0
238540	238457	98050T	PARTICIPANT	\N	PRESENT	0
238541	238457	14235Q	PARTICIPANT	\N	PRESENT	0
238542	238457	19443T	PARTICIPANT	\N	PRESENT	0
238543	238457	14055N	PARTICIPANT	\N	PRESENT	0
238544	238457	11054L	PARTICIPANT	\N	PRESENT	0
238545	238457	19421M	PARTICIPANT	\N	PRESENT	0
238546	238457	01058X	PARTICIPANT	\N	PRESENT	0
238547	238457	19669L	PARTICIPANT	\N	PRESENT	0
238548	238457	01062T	PARTICIPANT	\N	PRESENT	0
238549	238457	11066Q	PARTICIPANT	\N	PRESENT	0
238550	238457	95067Q	PARTICIPANT	\N	PRESENT	0
216603	207704	04033B	PARTICIPANT	\N	PRESENT	0
216604	207704	98035U	PARTICIPANT	\N	PRESENT	0
216605	207704	11077T	PARTICIPANT	\N	PRESENT	0
216606	207704	04059M	PARTICIPANT	\N	PRESENT	0
216607	207704	14123H	PARTICIPANT	\N	PRESENT	0
216608	207704	08068F	PARTICIPANT	\N	PRESENT	0
216609	207704	11090Q	PARTICIPANT	\N	PRESENT	0
216610	207704	11027H	PARTICIPANT	\N	PRESENT	0
216611	207704	19421M	PARTICIPANT	\N	PRESENT	0
216612	207704	01028R	PARTICIPANT	\N	PRESENT	0
216613	207704	11097X	PARTICIPANT	\N	PRESENT	0
216614	207704	14331P	PARTICIPANT	\N	PRESENT	0
216615	207704	05012A	PARTICIPANT	\N	PRESENT	0
216616	207704	08034U	PARTICIPANT	\N	PRESENT	0
216617	207704	14159V	PARTICIPANT	\N	PRESENT	0
216618	207704	11074Q	PARTICIPANT	\N	PRESENT	0
216619	207704	01048V	PARTICIPANT	\N	PRESENT	0
216620	207704	08052W	PARTICIPANT	\N	PRESENT	0
216621	207704	08055A	PARTICIPANT	\N	PRESENT	0
216622	207704	04034C	PARTICIPANT	\N	PRESENT	0
216623	207704	08024S	PARTICIPANT	\N	PRESENT	0
216664	207704	08014Q	PARTICIPANT	\N	PRESENT	0
216625	207704	14021P	PARTICIPANT	\N	PRESENT	0
216626	207704	19715Y	PARTICIPANT	\N	PRESENT	0
216627	207704	07033P	PARTICIPANT	\N	PRESENT	0
216628	207704	12016W	PARTICIPANT	\N	PRESENT	0
216629	207704	97011G	PARTICIPANT	\N	PRESENT	0
216630	207704	19649G	PARTICIPANT	\N	PRESENT	0
216631	207704	14028W	PARTICIPANT	\N	PRESENT	0
216632	207704	80013X	PARTICIPANT	\N	PRESENT	0
216633	207704	08038Y	PARTICIPANT	\N	PRESENT	0
216634	207704	08060W	PARTICIPANT	\N	PRESENT	0
216635	207704	01062T	PARTICIPANT	\N	PRESENT	0
216636	207704	11031D	PARTICIPANT	\N	PRESENT	0
216637	207704	11045K	PARTICIPANT	\N	PRESENT	0
216638	207704	11066Q	PARTICIPANT	\N	PRESENT	0
216639	207704	96004D	PARTICIPANT	\N	PRESENT	0
216640	207704	08043V	PARTICIPANT	\N	PRESENT	0
216641	207704	14281W	PARTICIPANT	\N	PRESENT	0
216642	207704	11104D	PARTICIPANT	\N	PRESENT	0
216643	207704	08012N	PARTICIPANT	\N	PRESENT	0
216644	207704	14157T	PARTICIPANT	\N	PRESENT	0
216645	207704	19489J	PARTICIPANT	\N	PRESENT	0
216646	207704	17779H	PARTICIPANT	\N	PRESENT	0
216647	207704	08058D	PARTICIPANT	\N	PRESENT	0
216648	207704	14121F	PARTICIPANT	\N	PRESENT	0
216649	207704	14191V	PARTICIPANT	\N	PRESENT	0
216650	207704	14085U	PARTICIPANT	\N	PRESENT	0
216651	207704	14229S	PARTICIPANT	\N	PRESENT	0
216652	207704	01057W	PARTICIPANT	\N	PRESENT	0
216653	207704	08017T	PARTICIPANT	\N	PRESENT	0
216654	207704	14081Q	PARTICIPANT	\N	PRESENT	0
216655	207704	19703U	PARTICIPANT	\N	PRESENT	0
216656	207704	11033F	PARTICIPANT	\N	PRESENT	0
216657	207704	11041F	PARTICIPANT	\N	PRESENT	0
216658	207704	14031R	PARTICIPANT	\N	PRESENT	0
216659	207704	19599P	PARTICIPANT	\N	PRESENT	0
216660	207704	95015C	PARTICIPANT	\N	PRESENT	0
216661	207704	14207L	PARTICIPANT	\N	PRESENT	0
216601	207704	08010L	PARTICIPANT	\N	PRESENT	0
216602	207704	08069G	PARTICIPANT	\N	PRESENT	0
216662	207704	19725B	PARTICIPANT	\N	PRESENT	0
216663	207704	11103C	PARTICIPANT	\N	PRESENT	0
216665	207704	14001X	PARTICIPANT	\N	PRESENT	0
216666	207704	14227Q	PARTICIPANT	\N	PRESENT	0
216667	207704	17637T	PARTICIPANT	\N	PRESENT	0
216668	207704	19683J	PARTICIPANT	\N	PRESENT	0
216669	207704	14087W	PARTICIPANT	\N	PRESENT	0
216670	207704	14039A	PARTICIPANT	\N	PRESENT	0
216671	207704	19295A	PARTICIPANT	\N	PRESENT	0
216672	207704	11054L	PARTICIPANT	\N	PRESENT	0
216673	207704	19689Q	PARTICIPANT	\N	PRESENT	0
216674	207704	19687N	PARTICIPANT	\N	PRESENT	0
216675	207704	14105F	PARTICIPANT	\N	PRESENT	0
216676	207704	14147R	PARTICIPANT	\N	PRESENT	0
216677	207704	14169X	PARTICIPANT	\N	PRESENT	0
216678	207704	19251M	PARTICIPANT	\N	PRESENT	0
216679	207704	04042C	PARTICIPANT	\N	PRESENT	0
216680	207704	19591F	PARTICIPANT	\N	PRESENT	0
216681	207704	19503N	PARTICIPANT	\N	PRESENT	0
216682	207704	11067R	PARTICIPANT	\N	PRESENT	0
216683	207704	11026G	PARTICIPANT	\N	PRESENT	0
216684	207704	14061L	PARTICIPANT	\N	PRESENT	0
216685	207704	14265W	PARTICIPANT	\N	PRESENT	0
216686	207704	19729F	PARTICIPANT	\N	PRESENT	0
216687	207704	19527W	PARTICIPANT	\N	PRESENT	0
216688	207704	11049P	PARTICIPANT	\N	PRESENT	0
216689	207704	04061F	PARTICIPANT	\N	PRESENT	0
216690	207704	14063N	PARTICIPANT	\N	PRESENT	0
216691	207704	19631V	PARTICIPANT	\N	PRESENT	0
216692	207704	14097Y	PARTICIPANT	\N	PRESENT	0
216693	207704	98023Q	PARTICIPANT	\N	PRESENT	0
216694	207704	14257W	PARTICIPANT	\N	PRESENT	0
216695	207704	14107H	PARTICIPANT	\N	PRESENT	0
216696	207704	11048N	PARTICIPANT	\N	PRESENT	0
216697	207704	19549D	PARTICIPANT	\N	PRESENT	0
216698	207704	08061X	PARTICIPANT	\N	PRESENT	0
216699	207704	95063L	PARTICIPANT	\N	PRESENT	0
216700	207704	19483C	PARTICIPANT	\N	PRESENT	0
216701	207704	95037J	PARTICIPANT	\N	PRESENT	0
216702	207704	14069U	PARTICIPANT	\N	PRESENT	0
216703	207704	04045F	PARTICIPANT	\N	PRESENT	0
216704	207704	98029W	PARTICIPANT	\N	PRESENT	0
216705	207704	04049K	PARTICIPANT	\N	PRESENT	0
216706	207704	19651A	PARTICIPANT	\N	PRESENT	0
216707	207704	14239U	PARTICIPANT	\N	PRESENT	0
216708	207704	11083R	PARTICIPANT	\N	PRESENT	0
216709	207704	14133K	PARTICIPANT	\N	PRESENT	0
216710	207704	19349W	PARTICIPANT	\N	PRESENT	0
216711	207704	19515S	PARTICIPANT	\N	PRESENT	0
216712	207704	19637C	PARTICIPANT	\N	PRESENT	0
216713	207704	19543W	PARTICIPANT	\N	PRESENT	0
216714	207704	04018C	PARTICIPANT	\N	PRESENT	0
216715	207704	19697Q	PARTICIPANT	\N	PRESENT	0
216716	207704	08021P	PARTICIPANT	\N	PRESENT	0
216717	207704	07029T	PARTICIPANT	\N	PRESENT	0
216718	207704	19329S	PARTICIPANT	\N	PRESENT	0
216719	207704	08019V	PARTICIPANT	\N	PRESENT	0
216720	207704	11072N	PARTICIPANT	\N	PRESENT	0
216721	207704	05008E	PARTICIPANT	\N	PRESENT	0
216722	207704	19301E	PARTICIPANT	\N	PRESENT	0
216723	207704	01060R	PARTICIPANT	\N	PRESENT	0
216724	207704	14055N	PARTICIPANT	\N	PRESENT	0
216725	207704	19731Y	PARTICIPANT	\N	PRESENT	0
216726	207704	14033T	PARTICIPANT	\N	PRESENT	0
216732	207704	14261S	PARTICIPANT	\N	PRESENT	0
216729	207704	14135M	PARTICIPANT	\N	PRESENT	0
216730	207704	19443T	PARTICIPANT	\N	PRESENT	0
216733	207704	19253P	PARTICIPANT	\N	PRESENT	0
216734	207704	08015R	PARTICIPANT	\N	PRESENT	0
216735	207704	19629C	PARTICIPANT	\N	PRESENT	0
216736	207704	08049C	PARTICIPANT	\N	PRESENT	0
216737	207704	19691J	PARTICIPANT	\N	PRESENT	0
216738	207704	14249W	PARTICIPANT	\N	PRESENT	0
216739	207704	14201E	PARTICIPANT	\N	PRESENT	0
216740	207704	19563B	PARTICIPANT	\N	PRESENT	0
216741	207704	19511N	PARTICIPANT	\N	PRESENT	0
216742	207704	04043D	PARTICIPANT	\N	PRESENT	0
216743	207704	98022P	PARTICIPANT	\N	PRESENT	0
216744	207704	19719D	PARTICIPANT	\N	PRESENT	0
216745	207704	11099A	PARTICIPANT	\N	PRESENT	0
216746	207704	19289C	PARTICIPANT	\N	PRESENT	0
216747	207704	19733B	PARTICIPANT	\N	PRESENT	0
216748	207704	14029X	PARTICIPANT	\N	PRESENT	0
216749	207704	14093U	PARTICIPANT	\N	PRESENT	0
216750	207704	19545Y	PARTICIPANT	\N	PRESENT	0
216751	207704	14195A	PARTICIPANT	\N	PRESENT	0
216752	207704	02002K	PARTICIPANT	\N	PRESENT	0
216753	207704	11064N	PARTICIPANT	\N	PRESENT	0
216754	207704	19585H	PARTICIPANT	\N	PRESENT	0
216755	207704	04057K	PARTICIPANT	\N	PRESENT	0
216756	207704	19467C	PARTICIPANT	\N	PRESENT	0
216757	207704	14111D	PARTICIPANT	\N	PRESENT	0
216758	207704	14251Q	PARTICIPANT	\N	PRESENT	0
216759	207704	19367Y	PARTICIPANT	\N	PRESENT	0
216760	207704	19269X	PARTICIPANT	\N	PRESENT	0
216761	207704	14030Q	PARTICIPANT	\N	PRESENT	0
216762	207704	01043Q	PARTICIPANT	\N	PRESENT	0
216764	207704	14327T	PARTICIPANT	\N	PRESENT	0
216765	207704	01025N	PARTICIPANT	\N	PRESENT	0
216766	207704	08044W	PARTICIPANT	\N	PRESENT	0
216767	207704	01034P	PARTICIPANT	\N	PRESENT	0
216768	207704	19369B	PARTICIPANT	\N	PRESENT	0
216769	207704	11085T	PARTICIPANT	\N	PRESENT	0
216770	207704	08009T	PARTICIPANT	\N	PRESENT	0
216771	207704	04040A	PARTICIPANT	\N	PRESENT	0
216774	207704	11053K	PARTICIPANT	\N	PRESENT	0
233921	232940	19569H	PARTICIPANT	\N	PRESENT	0
233922	232940	14219Q	PARTICIPANT	\N	PRESENT	0
233923	232940	19479G	PARTICIPANT	\N	PRESENT	0
234005	232940	14059S	PARTICIPANT	\N	PRESENT	0
233925	232940	19441R	PARTICIPANT	\N	PRESENT	0
233926	232940	14089Y	PARTICIPANT	\N	PRESENT	0
233927	232940	19713W	PARTICIPANT	\N	PRESENT	0
233928	232940	19319Q	PARTICIPANT	\N	PRESENT	0
233983	232940	18083K	PARTICIPANT	\N	PRESENT	0
233930	232940	14030Q	PARTICIPANT	\N	PRESENT	0
233931	232940	14255U	PARTICIPANT	\N	PRESENT	0
233985	232940	19663E	PARTICIPANT	\N	PRESENT	0
234003	232940	19729F	PARTICIPANT	\N	PRESENT	0
234020	232940	19573D	PARTICIPANT	\N	PRESENT	0
233935	232940	14103D	PARTICIPANT	\N	PRESENT	0
233936	232940	14221J	PARTICIPANT	\N	PRESENT	0
233937	232940	19335Q	PARTICIPANT	\N	PRESENT	0
233938	232940	19739H	PARTICIPANT	\N	PRESENT	0
234750	230886	19673G	PARTICIPANT	\N	PRESENT	0
233940	232940	19749K	PARTICIPANT	\N	PRESENT	0
234024	232940	05012A	PARTICIPANT	\N	PRESENT	0
233942	232940	04038G	PARTICIPANT	\N	PRESENT	0
234013	232940	19705W	PARTICIPANT	\N	PRESENT	0
233972	232940	19415P	PARTICIPANT	\N	PRESENT	0
234014	232940	10015M	PARTICIPANT	\N	PRESENT	0
233946	232940	08060W	PARTICIPANT	\N	PRESENT	0
234000	232940	19483C	PARTICIPANT	\N	PRESENT	0
234028	232940	08024S	PARTICIPANT	\N	PRESENT	0
233949	232940	14081Q	PARTICIPANT	\N	PRESENT	0
234006	232940	19657G	PARTICIPANT	\N	PRESENT	0
233993	232940	14213J	PARTICIPANT	\N	PRESENT	0
233952	232940	19681G	PARTICIPANT	\N	PRESENT	0
233953	232940	17589D	PARTICIPANT	\N	PRESENT	0
233973	232940	14215L	PARTICIPANT	\N	PRESENT	0
233955	232940	19631V	PARTICIPANT	\N	PRESENT	0
233956	232940	11026G	PARTICIPANT	\N	PRESENT	0
233957	232940	80027E	PARTICIPANT	\N	PRESENT	0
234007	232940	08062Y	PARTICIPANT	\N	PRESENT	0
234002	232940	95067Q	PARTICIPANT	\N	PRESENT	0
233991	232940	17583W	PARTICIPANT	\N	PRESENT	0
233989	232940	04035D	PARTICIPANT	\N	PRESENT	0
233963	232940	19367Y	PARTICIPANT	\N	PRESENT	0
233964	232940	14069U	PARTICIPANT	\N	PRESENT	0
234022	232940	14193X	PARTICIPANT	\N	PRESENT	0
233966	232940	19733B	PARTICIPANT	\N	PRESENT	0
234023	232940	04088S	PARTICIPANT	\N	PRESENT	0
233968	232940	19747H	PARTICIPANT	\N	PRESENT	0
233969	232940	19621T	PARTICIPANT	\N	PRESENT	0
233970	232940	19707Y	PARTICIPANT	\N	PRESENT	0
233971	232940	19575F	PARTICIPANT	\N	PRESENT	0
233974	232940	11103C	PARTICIPANT	\N	PRESENT	0
234034	232940	08068F	PARTICIPANT	\N	PRESENT	0
234025	232940	98050T	PARTICIPANT	\N	PRESENT	0
233977	232940	14038Y	PARTICIPANT	\N	PRESENT	0
233978	232940	19383Y	PARTICIPANT	\N	PRESENT	0
233980	232940	11080N	PARTICIPANT	\N	PRESENT	0
233981	232940	08028W	PARTICIPANT	\N	PRESENT	0
233982	232940	19671E	PARTICIPANT	\N	PRESENT	0
233984	232940	14079W	PARTICIPANT	\N	PRESENT	0
233986	232940	14071N	PARTICIPANT	\N	PRESENT	0
233988	232940	04071H	PARTICIPANT	\N	PRESENT	0
233990	232940	19399H	PARTICIPANT	\N	PRESENT	0
233994	232940	19447X	PARTICIPANT	\N	PRESENT	0
233995	232940	14061L	PARTICIPANT	\N	PRESENT	0
233997	232940	14029X	PARTICIPANT	\N	PRESENT	0
233998	232940	08015R	PARTICIPANT	\N	PRESENT	0
234004	232940	19709B	PARTICIPANT	\N	PRESENT	0
234012	232940	19421M	PARTICIPANT	\N	PRESENT	0
234015	232940	14135M	PARTICIPANT	\N	PRESENT	0
234018	232940	14265W	PARTICIPANT	\N	PRESENT	0
234021	232940	14237S	PARTICIPANT	\N	PRESENT	0
234026	232940	11090Q	PARTICIPANT	\N	PRESENT	0
234029	232940	11083R	PARTICIPANT	\N	PRESENT	0
234030	232940	04040A	PARTICIPANT	\N	PRESENT	0
234038	232940	14229S	PARTICIPANT	\N	PRESENT	0
234039	232940	19727D	PARTICIPANT	\N	PRESENT	0
234040	232940	19527W	PARTICIPANT	\N	PRESENT	0
234041	232940	14105F	PARTICIPANT	\N	PRESENT	0
234042	232940	19581D	PARTICIPANT	\N	PRESENT	0
234043	232940	08053X	PARTICIPANT	\N	PRESENT	0
234044	232940	11110B	PARTICIPANT	\N	PRESENT	0
234045	232940	19531S	PARTICIPANT	\N	PRESENT	0
234046	232940	14159V	PARTICIPANT	\N	PRESENT	0
234355	232941	01043Q	PARTICIPANT	\N	PRESENT	0
234356	232941	80013X	PARTICIPANT	\N	PRESENT	0
234357	232941	11031D	PARTICIPANT	\N	PRESENT	0
234358	232941	14187A	PARTICIPANT	\N	PRESENT	0
234359	232941	14223L	PARTICIPANT	\N	PRESENT	0
234360	232941	19575F	PARTICIPANT	\N	PRESENT	0
234361	232941	19667J	PARTICIPANT	\N	PRESENT	0
234362	232941	19289C	PARTICIPANT	\N	PRESENT	0
234363	232941	19301E	PARTICIPANT	\N	PRESENT	0
234364	232941	14225N	PARTICIPANT	\N	PRESENT	0
234365	232941	11054L	PARTICIPANT	\N	PRESENT	0
234366	232941	04085P	PARTICIPANT	\N	PRESENT	0
234367	232941	19695N	PARTICIPANT	\N	PRESENT	0
234368	232941	19593H	PARTICIPANT	\N	PRESENT	0
234369	232941	19565D	PARTICIPANT	\N	PRESENT	0
234370	232941	19347U	PARTICIPANT	\N	PRESENT	0
234371	232941	19689Q	PARTICIPANT	\N	PRESENT	0
234372	232941	19647E	PARTICIPANT	\N	PRESENT	0
234373	232941	19551W	PARTICIPANT	\N	PRESENT	0
234374	232941	19631V	PARTICIPANT	\N	PRESENT	0
234375	232941	19725B	PARTICIPANT	\N	PRESENT	0
234376	232941	19681G	PARTICIPANT	\N	PRESENT	0
234377	232941	04057K	PARTICIPANT	\N	PRESENT	0
234378	232941	19387D	PARTICIPANT	\N	PRESENT	0
234379	232941	19543W	PARTICIPANT	\N	PRESENT	0
234380	232941	19611R	PARTICIPANT	\N	PRESENT	0
234381	232941	19699S	PARTICIPANT	\N	PRESENT	0
234382	232941	14083S	PARTICIPANT	\N	PRESENT	0
234383	232941	14147R	PARTICIPANT	\N	PRESENT	0
234384	232941	07029T	PARTICIPANT	\N	PRESENT	0
234385	232941	14069U	PARTICIPANT	\N	PRESENT	0
234386	232941	04086Q	PARTICIPANT	\N	PRESENT	0
234387	232941	14119M	PARTICIPANT	\N	PRESENT	0
234388	232941	04071H	PARTICIPANT	\N	PRESENT	0
234389	232941	19483C	PARTICIPANT	\N	PRESENT	0
234390	232941	14249W	PARTICIPANT	\N	PRESENT	0
234391	232941	17637T	PARTICIPANT	\N	PRESENT	0
234392	232941	12041X	PARTICIPANT	\N	PRESENT	0
234393	232941	99004R	PARTICIPANT	\N	PRESENT	0
234394	232941	11074Q	PARTICIPANT	\N	PRESENT	0
234395	232941	18083K	PARTICIPANT	\N	PRESENT	0
234396	232941	08009T	PARTICIPANT	\N	PRESENT	0
234397	232941	14033T	PARTICIPANT	\N	PRESENT	0
234398	232941	14157T	PARTICIPANT	\N	PRESENT	0
234399	232941	19643A	PARTICIPANT	\N	PRESENT	0
234400	232941	11043H	PARTICIPANT	\N	PRESENT	0
234401	232941	14031R	PARTICIPANT	\N	PRESENT	0
234402	232941	19383Y	PARTICIPANT	\N	PRESENT	0
234403	232941	95030B	PARTICIPANT	\N	PRESENT	0
234404	232941	14265W	PARTICIPANT	\N	PRESENT	0
234405	232941	14357A	PARTICIPANT	\N	PRESENT	0
234406	232941	14329V	PARTICIPANT	\N	PRESENT	0
234407	232941	14109K	PARTICIPANT	\N	PRESENT	0
234408	232941	11012A	PARTICIPANT	\N	PRESENT	0
234409	232941	14042U	PARTICIPANT	\N	PRESENT	0
234410	232941	97011G	PARTICIPANT	\N	PRESENT	0
234411	232941	14195A	PARTICIPANT	\N	PRESENT	0
234412	232941	19415P	PARTICIPANT	\N	PRESENT	0
234414	232941	17589D	PARTICIPANT	\N	PRESENT	0
234415	232941	08056B	PARTICIPANT	\N	PRESENT	0
234751	230886	14265W	PARTICIPANT	\N	PRESENT	0
234752	230886	14135M	PARTICIPANT	\N	PRESENT	0
234753	230886	11109J	PARTICIPANT	\N	PRESENT	0
234754	230886	19647E	PARTICIPANT	\N	PRESENT	0
234755	230886	19725B	PARTICIPANT	\N	PRESENT	0
234756	230886	01028R	PARTICIPANT	\N	PRESENT	0
234757	230886	14261S	PARTICIPANT	\N	PRESENT	0
235098	235097	11070L	PARTICIPANT	\N	PRESENT	0
235099	235097	14159V	PARTICIPANT	\N	PRESENT	0
235100	235097	08034U	PARTICIPANT	\N	PRESENT	0
235101	235097	11072N	PARTICIPANT	\N	PRESENT	0
235102	235097	14241N	PARTICIPANT	\N	PRESENT	0
235103	235097	11064N	PARTICIPANT	\N	PRESENT	0
235104	233295	14030Q	PRESIDENT	0	PRESENT	0
235105	233295	19367Y	PARTICIPANT	\N	PRESENT	0
235106	233295	19643A	PARTICIPANT	\N	PRESENT	0
235107	233295	19701S	PARTICIPANT	\N	EXCUSE	0
235108	233295	11031D	PARTICIPANT	\N	PRESENT	0
235109	233295	80013X	PARTICIPANT	\N	PRESENT	0
235110	233295	19693L	PARTICIPANT	\N	PRESENT	0
235111	233295	19599P	PARTICIPANT	\N	EXCUSE	0
235112	233295	19715Y	PARTICIPANT	\N	PRESENT	0
235113	233295	08031R	PARTICIPANT	\N	EXCUSE	0
235114	233295	07029T	PARTICIPANT	\N	PRESENT	0
235115	233295	08017T	PARTICIPANT	\N	PRESENT	0
235116	233295	01043Q	PARTICIPANT	\N	EXCUSE	0
212973	212972	04086Q	PARTICIPANT	\N	PRESENT	0
212975	212974	04086Q	PARTICIPANT	\N	PRESENT	0
212978	212977	04086Q	PARTICIPANT	\N	PRESENT	0
212980	212979	04086Q	PARTICIPANT	\N	PRESENT	0
212982	212981	04086Q	PARTICIPANT	\N	PRESENT	0
212984	212983	04086Q	PARTICIPANT	\N	PRESENT	0
213007	213006	19711U	PARTICIPANT	\N	PRESENT	0
212988	212987	19711U	PARTICIPANT	\N	PRESENT	0
212990	212985	19711U	PARTICIPANT	\N	PRESENT	0
212999	212997	19711U	PARTICIPANT	\N	PRESENT	0
213016	213014	19711U	PARTICIPANT	\N	PRESENT	0
213072	213071	19349W	PARTICIPANT	\N	PRESENT	0
213075	213074	08011M	PARTICIPANT	\N	PRESENT	0
213123	213122	04071H	PARTICIPANT	\N	PRESENT	0
213125	213124	04071H	PARTICIPANT	\N	PRESENT	0
213127	213126	04071H	PARTICIPANT	\N	PRESENT	0
213129	213128	04071H	PARTICIPANT	\N	PRESENT	0
216731	216728	14179A	PARTICIPANT	\N	PRESENT	0
216772	216763	14179A	PARTICIPANT	\N	PRESENT	0
217375	217374	14187A	PARTICIPANT	\N	PRESENT	0
217386	217385	14187A	PARTICIPANT	\N	PRESENT	0
217387	217385	04089T	PARTICIPANT	\N	PRESENT	0
217391	217390	14187A	PARTICIPANT	\N	PRESENT	0
217393	217392	14187A	PARTICIPANT	\N	PRESENT	0
217396	217374	01043Q	PARTICIPANT	\N	PRESENT	0
218684	217574	19727D	PARTICIPANT	\N	PRESENT	0
218685	217574	19553Y	PARTICIPANT	\N	PRESENT	0
218686	217574	11067R	PARTICIPANT	\N	PRESENT	0
218687	217574	14281W	PARTICIPANT	\N	PRESENT	0
218688	217574	08052W	PARTICIPANT	\N	PRESENT	0
218689	217574	14195A	PARTICIPANT	\N	PRESENT	0
218690	217574	19415P	PARTICIPANT	\N	PRESENT	0
218691	217574	19715Y	PARTICIPANT	\N	PRESENT	0
218692	217574	19717B	PARTICIPANT	\N	PRESENT	0
218693	217574	19683J	PARTICIPANT	\N	PRESENT	0
218694	217574	14355X	PARTICIPANT	\N	PRESENT	0
218695	217574	11097X	PARTICIPANT	\N	PRESENT	0
218696	217574	14223L	PARTICIPANT	\N	PRESENT	0
218697	217574	19675J	PARTICIPANT	\N	PRESENT	0
218698	217574	19703U	PARTICIPANT	\N	PRESENT	0
218699	217574	19575F	PARTICIPANT	\N	PRESENT	0
218700	217574	19367Y	PARTICIPANT	\N	PRESENT	0
218701	217574	14213J	PARTICIPANT	\N	PRESENT	0
218702	217574	10006L	PARTICIPANT	\N	PRESENT	0
218703	217574	98024R	PARTICIPANT	\N	PRESENT	0
218704	217574	04092N	PRESIDENT	0	PRESENT	0
218705	217574	19663E	PARTICIPANT	\N	PRESENT	0
218706	217574	08041T	PARTICIPANT	\N	PRESENT	0
218707	217574	14119M	PARTICIPANT	\N	PRESENT	0
218708	217574	11103C	PARTICIPANT	\N	PRESENT	0
218709	217574	19657G	PARTICIPANT	\N	PRESENT	0
218710	217574	14071N	PARTICIPANT	\N	PRESENT	0
218711	217574	04045F	PARTICIPANT	\N	PRESENT	0
218712	217574	19335Q	PARTICIPANT	\N	PRESENT	0
218713	217574	19521Q	PARTICIPANT	\N	PRESENT	0
218714	217574	01034P	PARTICIPANT	\N	PRESENT	0
218715	217574	19691J	PARTICIPANT	\N	PRESENT	0
218716	217574	19577H	PARTICIPANT	\N	PRESENT	0
218717	217574	11063M	PARTICIPANT	\N	PRESENT	0
218718	217574	19697Q	PARTICIPANT	\N	PRESENT	0
218719	217574	14239U	PARTICIPANT	\N	PRESENT	0
218720	217574	19723Y	PARTICIPANT	\N	PRESENT	0
218721	217574	19679N	PARTICIPANT	\N	PRESENT	0
218722	217574	14227Q	PARTICIPANT	\N	PRESENT	0
218723	217574	14217N	PARTICIPANT	\N	PRESENT	0
218724	217574	19569H	PARTICIPANT	\N	PRESENT	0
218725	217574	11077T	PARTICIPANT	\N	PRESENT	0
218726	217574	17779H	PARTICIPANT	\N	PRESENT	0
218727	217574	11045K	PARTICIPANT	\N	PRESENT	0
218728	217574	14042U	PARTICIPANT	\N	PRESENT	0
218729	217574	14261S	PARTICIPANT	\N	PRESENT	0
218730	216548	19443T	PARTICIPANT	\N	PRESENT	0
218731	216548	11080N	PARTICIPANT	\N	PRESENT	0
218732	216548	95030B	PARTICIPANT	\N	PRESENT	0
218733	216548	04034C	PARTICIPANT	\N	PRESENT	0
218734	216548	14079W	PARTICIPANT	\N	PRESENT	0
218735	216548	04040A	PARTICIPANT	\N	PRESENT	0
218736	216548	01058X	PARTICIPANT	\N	PRESENT	0
218737	216548	11027H	PARTICIPANT	\N	PRESENT	0
218738	216548	16685X	PARTICIPANT	\N	PRESENT	0
218739	216548	04042C	PRESIDENT	0	PRESENT	0
218740	216548	11054L	PARTICIPANT	\N	PRESENT	0
218741	216548	11066Q	PARTICIPANT	\N	PRESENT	0
218742	216548	08056B	PARTICIPANT	\N	PRESENT	0
218743	216548	11115U	PARTICIPANT	\N	PRESENT	0
218744	216548	95037J	PARTICIPANT	\N	PRESENT	0
218745	216548	14055N	PARTICIPANT	\N	PRESENT	0
218746	216548	19421M	PARTICIPANT	\N	PRESENT	0
218747	216548	19709B	PARTICIPANT	\N	PRESENT	0
218748	216548	14193X	PARTICIPANT	\N	PRESENT	0
218749	216548	08053X	PARTICIPANT	\N	PRESENT	0
218750	216548	97011G	PARTICIPANT	\N	PRESENT	0
218751	216548	08061X	PARTICIPANT	\N	PRESENT	0
218752	216548	08047A	PARTICIPANT	\N	PRESENT	0
218753	216548	98029W	PARTICIPANT	\N	PRESENT	0
218754	216548	14097Y	PARTICIPANT	\N	PRESENT	0
218755	216548	95067Q	PARTICIPANT	\N	PRESENT	0
218756	216548	01062T	PARTICIPANT	\N	PRESENT	0
218757	216548	14133K	PARTICIPANT	\N	PRESENT	0
218758	216548	11041F	PARTICIPANT	\N	PRESENT	0
218759	216548	14235Q	PARTICIPANT	\N	PRESENT	0
218760	216548	08058D	PARTICIPANT	\N	PRESENT	0
218761	216548	19251M	PARTICIPANT	\N	PRESENT	0
218762	216548	14028W	PARTICIPANT	\N	PRESENT	0
218763	216548	19721W	PARTICIPANT	\N	PRESENT	0
218764	216548	14105F	PARTICIPANT	\N	PRESENT	0
218765	216548	98018T	PARTICIPANT	\N	PRESENT	0
218766	216548	98022P	PARTICIPANT	\N	PRESENT	0
218767	216548	11064N	PARTICIPANT	\N	PRESENT	0
218768	216548	98050T	PARTICIPANT	\N	PRESENT	0
218769	216548	14211G	PARTICIPANT	\N	PRESENT	0
218770	216548	19583F	PARTICIPANT	\N	PRESENT	0
218771	216548	14255U	PARTICIPANT	\N	PRESENT	0
218772	217574	14087W	PARTICIPANT	\N	PRESENT	0
218773	217574	14026U	PARTICIPANT	\N	PRESENT	0
218774	217473	19515S	PARTICIPANT	\N	PRESENT	0
218775	217473	19565D	PARTICIPANT	\N	PRESENT	0
218776	217473	01043Q	PARTICIPANT	\N	PRESENT	0
218777	217473	14357A	PARTICIPANT	\N	PRESENT	0
218778	217473	19441R	PARTICIPANT	\N	PRESENT	0
218779	217473	14081Q	PARTICIPANT	\N	PRESENT	0
218780	217473	19413M	PARTICIPANT	\N	PRESENT	0
218781	217473	80013X	PARTICIPANT	\N	PRESENT	0
218782	217473	19631V	PARTICIPANT	\N	PRESENT	0
218783	217473	08021P	PARTICIPANT	\N	PRESENT	0
218784	217473	11099A	PARTICIPANT	\N	PRESENT	0
218785	217473	08068F	PARTICIPANT	\N	PRESENT	0
218786	217473	04049K	PARTICIPANT	\N	PRESENT	0
218787	217473	19705W	PARTICIPANT	\N	PRESENT	0
218788	217473	08015R	PARTICIPANT	\N	PRESENT	0
218789	217473	08019V	PARTICIPANT	\N	PRESENT	0
218790	217473	14197C	PARTICIPANT	\N	PRESENT	0
218791	217473	19369B	PARTICIPANT	\N	PRESENT	0
218792	217473	19511N	PARTICIPANT	\N	PRESENT	0
218793	217473	08028W	PARTICIPANT	\N	PRESENT	0
218794	217473	19563B	PARTICIPANT	\N	PRESENT	0
218795	217473	14265W	PARTICIPANT	\N	PRESENT	0
218796	217473	14329V	PARTICIPANT	\N	PRESENT	0
218797	217473	19591F	PARTICIPANT	\N	PRESENT	0
218798	217473	14135M	PARTICIPANT	\N	PRESENT	0
218799	217473	19467C	PARTICIPANT	\N	PRESENT	0
218800	217473	14187A	PARTICIPANT	\N	PRESENT	0
218801	217473	08038Y	PARTICIPANT	\N	PRESENT	0
218802	217473	08062Y	PARTICIPANT	\N	PRESENT	0
218803	217473	19301E	PARTICIPANT	\N	PRESENT	0
218804	217473	19695N	PARTICIPANT	\N	PRESENT	0
218805	217473	14033T	PARTICIPANT	\N	PRESENT	0
218806	217473	11090Q	PRESIDENT	0	PRESENT	0
218807	217473	01025N	PARTICIPANT	\N	PRESENT	0
218808	217473	19295A	PARTICIPANT	\N	PRESENT	0
218809	217473	19269X	PARTICIPANT	\N	PRESENT	0
218810	217473	14205J	PARTICIPANT	\N	PRESENT	0
218811	217473	04088S	PARTICIPANT	\N	PRESENT	0
218812	217473	14115H	PARTICIPANT	\N	PRESENT	0
218813	217473	11101A	PARTICIPANT	\N	PRESENT	0
218814	217473	19507S	PARTICIPANT	\N	PRESENT	0
218815	217473	14207L	PARTICIPANT	\N	PRESENT	0
218816	217473	04043D	PARTICIPANT	\N	PRESENT	0
218817	217473	19619A	PARTICIPANT	\N	PRESENT	0
218818	217473	17589D	PARTICIPANT	\N	PRESENT	0
218819	217473	14257W	PARTICIPANT	\N	PRESENT	0
218820	217574	19527W	PARTICIPANT	\N	PRESENT	0
218822	217473	11056N	PARTICIPANT	\N	PRESENT	0
218866	217782	04070G	PRESIDENT	0	PRESENT	0
218867	217782	19699S	PARTICIPANT	\N	PRESENT	0
218868	217782	12041X	PARTICIPANT	\N	PRESENT	0
218869	217782	19533U	PARTICIPANT	\N	PRESENT	0
218870	217782	95015C	PRESIDENT	1	PRESENT	0
218871	217782	04033B	PARTICIPANT	\N	PRESENT	0
228603	228392	04061F	PARTICIPANT	\N	EXCUSE	0
228604	228392	08053X	PARTICIPANT	\N	EXCUSE	0
228605	228392	19593H	PARTICIPANT	\N	EXCUSE	0
233190	233189	04047H	PARTICIPANT	\N	PRESENT	0
233191	233189	14089Y	PARTICIPANT	\N	PRESENT	0
233192	233189	19673G	PARTICIPANT	\N	PRESENT	0
234891	234890	19415P	PARTICIPANT	\N	PRESENT	0
233194	233189	11026G	PARTICIPANT	\N	PRESENT	0
234892	234890	11103C	PRESIDENT	0	PRESENT	0
233196	233189	19581D	PARTICIPANT	\N	PRESENT	0
234808	234807	07033P	PARTICIPANT	\N	PRESENT	0
234893	234890	14195A	PARTICIPANT	\N	PRESENT	0
234894	234890	08052W	PARTICIPANT	\N	PRESENT	0
234895	234890	14281W	PARTICIPANT	\N	PRESENT	0
234896	234890	11067R	PARTICIPANT	\N	PRESENT	0
234897	234890	11097X	PARTICIPANT	\N	PRESENT	0
234898	234890	01034P	PARTICIPANT	\N	PRESENT	0
234899	234890	19703U	PARTICIPANT	\N	PRESENT	0
234900	234890	14119M	PARTICIPANT	\N	PRESENT	0
234901	234890	19715Y	PARTICIPANT	\N	PRESENT	0
234902	234890	14026U	PARTICIPANT	\N	PRESENT	0
234906	234890	19723Y	PARTICIPANT	\N	PRESENT	0
234911	234890	14213J	PARTICIPANT	\N	PRESENT	0
234914	234890	19657G	PARTICIPANT	\N	PRESENT	0
235088	235087	10015M	PARTICIPANT	\N	PRESENT	0
235405	235404	18083K	PARTICIPANT	\N	PRESENT	0
235406	235404	19695N	PARTICIPANT	\N	PRESENT	0
235407	235404	04049K	PARTICIPANT	\N	PRESENT	0
235408	235404	14265W	PARTICIPANT	\N	PRESENT	0
235409	235404	05012A	PARTICIPANT	\N	PRESENT	0
235427	235426	10015M	PARTICIPANT	\N	PRESENT	0
235428	235426	14151M	PARTICIPANT	\N	PRESENT	0
238551	238457	10006L	PARTICIPANT	\N	PRESENT	0
238552	238457	14041T	PARTICIPANT	\N	PRESENT	0
238553	238457	14217N	PARTICIPANT	\N	PRESENT	0
238554	238457	19647E	PARTICIPANT	\N	PRESENT	0
238555	238457	14179A	PARTICIPANT	\N	PRESENT	0
238556	238457	08015R	PARTICIPANT	\N	PRESENT	0
238557	238457	08034U	PARTICIPANT	\N	PRESENT	0
238558	238457	14147R	PARTICIPANT	\N	PRESENT	0
238559	238457	07034Q	PARTICIPANT	\N	PRESENT	0
238560	238457	95062K	PARTICIPANT	\N	PRESENT	0
238561	238457	04018C	PARTICIPANT	\N	PRESENT	0
238563	238562	04040A	PRESIDENT	0	PRESENT	0
238564	238562	08048B	PARTICIPANT	\N	EXCUSE	0
238591	238562	08034U	PARTICIPANT	\N	EXCUSE	0
238602	232547	19667J	PARTICIPANT	\N	EXCUSE	0
238603	232547	19647E	PARTICIPANT	\N	EXCUSE	0
238608	238607	19447X	PARTICIPANT	\N	PRESENT	0
238609	238607	19649G	PARTICIPANT	\N	PRESENT	0
238612	232547	19369B	PARTICIPANT	\N	PRESENT	0
238613	232547	14147R	PARTICIPANT	\N	EXCUSE	0
238614	232547	19399H	PARTICIPANT	\N	PRESENT	0
238616	238615	14239U	PARTICIPANT	\N	PRESENT	0
238617	238615	19251M	PARTICIPANT	\N	PRESENT	0
238618	238615	14087W	PARTICIPANT	\N	PRESENT	0
238619	238615	98022P	PARTICIPANT	\N	PRESENT	0
238620	238615	14179A	PARTICIPANT	\N	PRESENT	0
238621	238615	11085T	PARTICIPANT	\N	PRESENT	0
238622	238615	08053X	PARTICIPANT	\N	PRESENT	0
238623	238615	19593H	PARTICIPANT	\N	PRESENT	0
238624	238615	17637T	PARTICIPANT	\N	PRESENT	0
238625	238615	19705W	PARTICIPANT	\N	PRESENT	0
238691	238690	10006L	PARTICIPANT	\N	PRESENT	0
238692	238690	19553Y	PARTICIPANT	\N	PRESENT	0
238693	238690	08052W	PARTICIPANT	\N	PRESENT	0
238777	238776	19479G	PARTICIPANT	\N	PRESENT	0
238779	238778	19479G	PARTICIPANT	\N	PRESENT	0
238787	238740	04044E	PARTICIPANT	\N	PRESENT	0
238788	238740	14026U	PARTICIPANT	\N	PRESENT	0
238789	238740	19511N	PARTICIPANT	\N	PRESENT	0
239089	239086	19731Y	PARTICIPANT	\N	PRESENT	0
238798	232948	11070L	PARTICIPANT	0	PRESENT	0
238799	232948	14227Q	PARTICIPANT	0	PRESENT	0
238800	232948	14191V	PARTICIPANT	0	PRESENT	0
238801	232948	11063M	PARTICIPANT	0	PRESENT	0
238802	232948	11031D	PARTICIPANT	0	PRESENT	0
238803	232948	19697Q	PARTICIPANT	0	PRESENT	0
238804	232948	04092N	PARTICIPANT	0	PRESENT	0
238805	232948	14213J	PARTICIPANT	0	PRESENT	0
238806	232948	04045F	PARTICIPANT	0	PRESENT	0
238807	232948	11045K	PARTICIPANT	0	PRESENT	0
238808	232948	14195A	PARTICIPANT	0	PRESENT	0
238809	232948	19387D	PARTICIPANT	0	PRESENT	0
238810	232948	14217N	PARTICIPANT	0	PRESENT	0
238811	232948	19747H	PARTICIPANT	0	PRESENT	0
238812	232948	11067R	PARTICIPANT	0	PRESENT	0
238813	232948	14061L	PARTICIPANT	0	PRESENT	0
238814	232948	08060W	PARTICIPANT	0	PRESENT	0
238815	232948	14219Q	PARTICIPANT	0	PRESENT	0
238816	232948	98024R	PARTICIPANT	0	PRESENT	0
238817	232948	14121F	PARTICIPANT	0	PRESENT	0
238818	232948	14147R	PARTICIPANT	0	PRESENT	0
238819	232948	19687N	PARTICIPANT	0	PRESENT	0
238820	232948	14026U	PARTICIPANT	0	PRESENT	0
238821	232948	14071N	PARTICIPANT	0	PRESENT	0
238822	232948	14215L	PARTICIPANT	0	PRESENT	0
238823	232948	11012A	PARTICIPANT	0	PRESENT	0
238824	232948	01048V	PARTICIPANT	0	PRESENT	0
238825	232948	14083S	PARTICIPANT	0	PRESENT	0
238826	232948	19651A	PARTICIPANT	0	PRESENT	0
238827	232948	11077T	PARTICIPANT	0	PRESENT	0
238828	232948	08031R	PARTICIPANT	0	PRESENT	0
238829	232948	14205J	PARTICIPANT	0	PRESENT	0
238830	232948	19413M	PARTICIPANT	0	PRESENT	0
238831	232948	11081P	PARTICIPANT	0	PRESENT	0
238832	232948	14225N	PARTICIPANT	0	PRESENT	0
238833	232948	19483C	PARTICIPANT	0	PRESENT	0
238834	232948	19503N	PARTICIPANT	0	PRESENT	0
238835	232948	08055A	PARTICIPANT	0	PRESENT	0
238836	232948	19549D	PARTICIPANT	0	PRESENT	0
238837	232948	14042U	PARTICIPANT	0	PRESENT	0
238838	232948	14053L	PARTICIPANT	0	PRESENT	0
238839	232948	14079W	PARTICIPANT	0	PRESENT	0
238840	232948	04047H	PARTICIPANT	0	PRESENT	0
238841	232948	01057W	PARTICIPANT	0	PRESENT	0
238842	232948	14331P	PARTICIPANT	0	PRESENT	0
238843	232948	10006L	PARTICIPANT	0	PRESENT	0
238844	232948	19553Y	PARTICIPANT	0	PRESENT	0
238845	232948	19629C	PARTICIPANT	0	PRESENT	0
238846	232948	19729F	PARTICIPANT	0	PRESENT	0
238847	232948	19521Q	PARTICIPANT	0	PRESENT	0
238848	232948	14231L	PARTICIPANT	0	PRESENT	0
238849	232948	14034U	PARTICIPANT	0	PRESENT	0
238850	232948	14157T	PARTICIPANT	0	PRESENT	0
238851	232948	14038Y	PARTICIPANT	0	PRESENT	0
238852	232948	14235Q	PARTICIPANT	0	PRESENT	0
238853	232948	08015R	PARTICIPANT	0	PRESENT	0
238854	232948	08034U	PARTICIPANT	0	PRESENT	0
238855	232948	19737F	PARTICIPANT	0	PRESENT	0
238856	232948	98050T	PARTICIPANT	0	PRESENT	0
238857	232948	19695N	PARTICIPANT	0	PRESENT	0
238858	232948	04085P	PARTICIPANT	0	PRESENT	0
238859	232948	19703U	PARTICIPANT	0	PRESENT	0
238860	232948	19631V	PARTICIPANT	0	PRESENT	0
238861	232948	14179A	PARTICIPANT	0	PRESENT	0
238862	232948	19727D	PARTICIPANT	0	PRESENT	0
238863	232948	14281W	PARTICIPANT	0	PRESENT	0
238864	232948	19563B	PARTICIPANT	0	PRESENT	0
238865	232948	19441R	PARTICIPANT	0	PRESENT	0
238866	232948	14187A	PARTICIPANT	0	PRESENT	0
238867	232948	14097Y	PARTICIPANT	0	PRESENT	0
238868	232948	14327T	PARTICIPANT	0	PRESENT	0
239087	239086	14073Q	PARTICIPANT	\N	PRESENT	0
239088	239086	19585H	PARTICIPANT	\N	PRESENT	0
239195	232547	19467C	PARTICIPANT	\N	PRESENT	0
239196	232547	11066Q	PARTICIPANT	\N	PRESENT	0
239198	239197	89017R	PARTICIPANT	\N	PRESENT	0
239199	239197	14061L	PARTICIPANT	\N	PRESENT	0
239200	239197	01058X	PARTICIPANT	\N	PRESENT	0
239201	239197	08056B	PARTICIPANT	\N	PRESENT	0
239202	239197	04049K	PARTICIPANT	\N	PRESENT	0
239203	239197	04045F	PARTICIPANT	\N	PRESENT	0
239204	239197	08015R	PARTICIPANT	\N	PRESENT	0
239205	239197	08017T	PARTICIPANT	\N	PRESENT	0
239206	239197	14255U	PARTICIPANT	\N	PRESENT	0
239209	239208	11053K	PARTICIPANT	\N	PRESENT	0
239210	239208	14159V	PARTICIPANT	\N	PRESENT	0
239211	239208	05012A	PARTICIPANT	\N	PRESENT	0
239213	232547	11056N	PARTICIPANT	\N	EXCUSE	0
239214	232547	19349W	PARTICIPANT	\N	PRESENT	0
239275	232547	08062Y	PARTICIPANT	\N	PRESENT	0
239276	232547	04038G	PARTICIPANT	\N	PRESENT	0
239277	232547	19713W	PARTICIPANT	\N	PRESENT	0
239278	232547	99004R	PRESIDENT	0	PRESENT	0
239283	239282	19563B	PARTICIPANT	\N	PRESENT	0
239312	233171	14261S	PARTICIPANT	\N	PRESENT	0
214575	214574	19415P	PARTICIPANT	\N	PRESENT	0
216214	216212	19507S	PARTICIPANT	\N	PRESENT	0
216215	216212	14207L	PARTICIPANT	\N	PRESENT	0
216216	216212	01025N	PARTICIPANT	\N	PRESENT	0
216226	216225	14207L	PARTICIPANT	\N	PRESENT	0
216227	216225	19507S	PARTICIPANT	\N	PRESENT	0
216228	216225	01025N	PARTICIPANT	\N	PRESENT	0
216247	216246	95062K	PARTICIPANT	\N	PRESENT	0
216286	216285	95062K	PARTICIPANT	\N	PRESENT	0
216544	216543	14193X	PARTICIPANT	\N	PRESENT	0
216545	216543	11027H	PARTICIPANT	\N	PRESENT	0
216546	216543	08058D	PARTICIPANT	\N	PRESENT	0
216775	207704	19611R	PARTICIPANT	\N	PRESENT	0
216776	207704	19581D	PARTICIPANT	\N	PRESENT	0
216777	207704	19619A	PARTICIPANT	\N	PRESENT	0
216778	207704	19721W	PARTICIPANT	\N	PRESENT	0
216779	207704	16685X	PARTICIPANT	\N	PRESENT	0
216780	207704	19569H	PARTICIPANT	\N	PRESENT	0
216781	207704	19441R	PARTICIPANT	\N	PRESENT	0
216782	207704	19479G	PARTICIPANT	\N	PRESENT	0
216783	207704	14219Q	PARTICIPANT	\N	PRESENT	0
216784	207704	19621T	PARTICIPANT	\N	PRESENT	0
216785	207704	14042U	PARTICIPANT	\N	PRESENT	0
216786	207704	19685L	PARTICIPANT	\N	PRESENT	0
216787	207704	14231L	PARTICIPANT	\N	PRESENT	0
216788	207704	19319Q	PARTICIPANT	\N	PRESENT	0
216789	207704	19713W	PARTICIPANT	\N	PRESENT	0
216790	207704	14103D	PARTICIPANT	\N	PRESENT	0
216791	207704	14073Q	PARTICIPANT	\N	PRESENT	0
216792	207704	08011M	PARTICIPANT	\N	PRESENT	0
216793	207704	14221J	PARTICIPANT	\N	PRESENT	0
216794	207704	19739H	PARTICIPANT	\N	PRESENT	0
216795	207704	19335Q	PARTICIPANT	\N	PRESENT	0
216796	207704	14089Y	PARTICIPANT	\N	PRESENT	0
216797	207704	14255U	PARTICIPANT	\N	PRESENT	0
216798	207704	14083S	PARTICIPANT	\N	PRESENT	0
216799	207704	19707Y	PARTICIPANT	\N	PRESENT	0
216800	207704	11070L	PARTICIPANT	\N	PRESENT	0
216801	207704	11110B	PARTICIPANT	\N	PRESENT	0
216802	207704	19705W	PARTICIPANT	\N	PRESENT	0
216803	207704	19521Q	PARTICIPANT	\N	PRESENT	0
216804	207704	17583W	PARTICIPANT	\N	PRESENT	0
216805	207704	14041T	PARTICIPANT	\N	PRESENT	0
216806	207704	14217N	PARTICIPANT	\N	PRESENT	0
216807	207704	14329V	PARTICIPANT	\N	PRESENT	0
216808	207704	14038Y	PARTICIPANT	\N	PRESENT	0
216809	207704	04047H	PARTICIPANT	\N	PRESENT	0
216810	207704	19701S	PARTICIPANT	\N	PRESENT	0
216811	207704	11115U	PARTICIPANT	\N	PRESENT	0
216812	207704	18083K	PARTICIPANT	\N	PRESENT	0
216813	207704	14357A	PARTICIPANT	\N	PRESENT	0
216814	207704	19693L	PARTICIPANT	\N	PRESENT	0
216815	207704	19663E	PARTICIPANT	\N	PRESENT	0
216816	207704	19675J	PARTICIPANT	\N	PRESENT	0
216817	207704	19507S	PARTICIPANT	\N	PRESENT	0
216818	207704	19573D	PARTICIPANT	\N	PRESENT	0
216819	207704	19673G	PARTICIPANT	\N	PRESENT	0
216820	207704	19709B	PARTICIPANT	\N	PRESENT	0
216823	207704	04088S	PARTICIPANT	\N	PRESENT	0
216826	207704	19657G	PARTICIPANT	\N	PRESENT	0
216827	207704	19399H	PARTICIPANT	\N	PRESENT	0
216829	207704	19447X	PARTICIPANT	\N	PRESENT	0
216830	207704	19723Y	PARTICIPANT	\N	PRESENT	0
216831	207704	19677L	PARTICIPANT	\N	PRESENT	0
216832	207704	19415P	PARTICIPANT	\N	PRESENT	0
216833	207704	08062Y	PARTICIPANT	\N	PRESENT	0
216834	207704	14119M	PARTICIPANT	\N	PRESENT	0
216836	207704	19667J	PARTICIPANT	\N	PRESENT	0
216837	207704	14115H	PARTICIPANT	\N	PRESENT	0
216838	207704	14253S	PARTICIPANT	\N	PRESENT	0
216839	207704	19679N	PARTICIPANT	\N	PRESENT	0
216840	207704	14071N	PARTICIPANT	\N	PRESENT	0
216841	207704	19533U	PARTICIPANT	\N	PRESENT	0
216842	207704	04071H	PARTICIPANT	\N	PRESENT	0
216843	207704	19727D	PARTICIPANT	\N	PRESENT	0
216844	207704	14034U	PARTICIPANT	\N	PRESENT	0
216845	207704	11109J	PARTICIPANT	\N	PRESENT	0
216846	207704	14151M	PARTICIPANT	\N	PRESENT	0
216847	207704	08016S	PARTICIPANT	\N	PRESENT	0
216848	207704	89017R	PARTICIPANT	\N	PRESENT	0
216849	207704	17589D	PARTICIPANT	\N	PRESENT	0
217257	207706	04086Q	PARTICIPANT	\N	PRESENT	0
217258	207706	08011M	PARTICIPANT	\N	PRESENT	0
217259	207706	14034U	PARTICIPANT	\N	PRESENT	0
217260	207706	19651A	PARTICIPANT	\N	PRESENT	0
217261	207706	19687N	PARTICIPANT	\N	PRESENT	0
217262	207706	14327T	PARTICIPANT	\N	PRESENT	0
217263	207706	14225N	PARTICIPANT	\N	PRESENT	0
217264	207706	19545Y	PARTICIPANT	\N	PRESENT	0
217265	207706	04071H	PARTICIPANT	\N	PRESENT	0
217266	207706	11048N	PARTICIPANT	\N	PRESENT	0
217267	207706	19663E	PARTICIPANT	\N	PRESENT	0
217268	207706	07029T	PARTICIPANT	\N	PRESENT	0
217269	207706	08019V	PARTICIPANT	\N	PRESENT	0
217270	207706	19711U	PARTICIPANT	\N	PRESENT	0
217271	207706	19693L	PARTICIPANT	\N	PRESENT	0
217272	207706	08034U	PARTICIPANT	\N	PRESENT	0
217273	207706	19689Q	PARTICIPANT	\N	PRESENT	0
217274	207706	19647E	PARTICIPANT	\N	PRESENT	0
217275	207706	14159V	PARTICIPANT	\N	PRESENT	0
217276	207706	11027H	PARTICIPANT	\N	PRESENT	0
217277	207706	19671E	PARTICIPANT	\N	PRESENT	0
217278	207706	14085U	PARTICIPANT	\N	PRESENT	0
217279	207706	19447X	PARTICIPANT	\N	PRESENT	0
217280	207706	04061F	PARTICIPANT	\N	PRESENT	0
217281	207706	11074Q	PARTICIPANT	\N	PRESENT	0
217282	207706	14083S	PARTICIPANT	\N	PRESENT	0
217283	207706	19667J	PARTICIPANT	\N	PRESENT	0
217284	207706	14069U	PARTICIPANT	\N	PRESENT	0
217285	207706	14081Q	PARTICIPANT	\N	PRESENT	0
217286	207706	08010L	PARTICIPANT	\N	PRESENT	0
217289	207706	14259Y	PARTICIPANT	\N	PRESENT	0
217290	207706	01048V	PARTICIPANT	\N	PRESENT	0
217291	207706	11077T	PARTICIPANT	\N	PRESENT	0
217292	207706	14105F	PARTICIPANT	\N	PRESENT	0
217379	217378	14281W	PARTICIPANT	\N	PRESENT	0
217380	217378	11026G	PARTICIPANT	\N	PRESENT	0
217381	217378	04057K	PARTICIPANT	\N	PRESENT	0
217382	217378	08034U	PARTICIPANT	\N	PRESENT	0
218455	207713	80027E	PARTICIPANT	\N	PRESENT	0
218457	207713	14331P	PARTICIPANT	\N	PRESENT	0
218823	216835	01060R	PARTICIPANT	\N	PRESENT	0
218824	216835	14001X	PARTICIPANT	\N	PRESENT	0
218825	216835	19543W	PARTICIPANT	\N	PRESENT	0
218826	216835	19581D	PARTICIPANT	\N	PRESENT	0
218827	216835	04044E	PARTICIPANT	\N	PRESENT	0
218828	216835	19585H	PARTICIPANT	\N	PRESENT	0
218829	216835	19673G	PARTICIPANT	\N	PRESENT	0
218830	216835	01028R	PARTICIPANT	\N	PRESENT	0
218831	216835	19447X	PARTICIPANT	\N	PRESENT	0
218832	216835	14231L	PARTICIPANT	\N	PRESENT	0
218833	216835	05008E	PRESIDENT	0	PRESENT	0
218834	216835	19489J	PARTICIPANT	\N	PRESENT	0
218835	216835	14041T	PARTICIPANT	\N	PRESENT	0
218836	216835	14147R	PARTICIPANT	\N	PRESENT	0
218837	216835	14151M	PARTICIPANT	\N	PRESENT	0
218838	216835	14215L	PARTICIPANT	\N	PRESENT	0
218839	216835	19483C	PARTICIPANT	\N	PRESENT	0
218840	216835	14053L	PARTICIPANT	\N	PRESENT	0
218841	216835	98035U	PARTICIPANT	\N	PRESENT	0
218842	216835	14111D	PARTICIPANT	\N	PRESENT	0
218843	216835	14065Q	PARTICIPANT	\N	PRESENT	0
218844	216835	19649G	PARTICIPANT	\N	PRESENT	0
218845	216835	07034Q	PARTICIPANT	\N	PRESENT	0
218846	216835	10015M	PARTICIPANT	\N	PRESENT	0
218847	216835	11026G	PARTICIPANT	\N	PRESENT	0
218848	216835	08045X	PARTICIPANT	\N	PRESENT	0
218849	216835	19253P	PARTICIPANT	\N	PRESENT	0
218850	216835	01024M	PARTICIPANT	\N	PRESENT	0
218851	216835	19719D	PARTICIPANT	\N	PRESENT	0
218852	216835	11033F	PARTICIPANT	\N	PRESENT	0
218853	216835	19725B	PARTICIPANT	\N	PRESENT	0
218854	216835	14089Y	PARTICIPANT	\N	PRESENT	0
218855	216835	19729F	PARTICIPANT	\N	PRESENT	0
218856	216835	95063L	PARTICIPANT	\N	PRESENT	0
217221	217220	92040Q	PARTICIPANT	\N	PRESENT	0
217222	217220	14109K	PARTICIPANT	\N	PRESENT	0
217224	217223	92040Q	PARTICIPANT	\N	PRESENT	0
217225	217223	14109K	PARTICIPANT	\N	PRESENT	0
218857	216835	19629C	PARTICIPANT	\N	PRESENT	0
218858	216835	11049P	PARTICIPANT	\N	PRESENT	0
217229	217228	92040Q	PARTICIPANT	\N	PRESENT	0
217230	217228	14109K	PARTICIPANT	\N	PRESENT	0
217231	217228	19593H	PARTICIPANT	\N	PRESENT	0
217232	217228	04018C	PARTICIPANT	\N	PRESENT	0
217234	217233	14109K	PARTICIPANT	\N	PRESENT	0
217235	217233	19593H	PARTICIPANT	\N	PRESENT	0
217236	217233	92040Q	PARTICIPANT	\N	PRESENT	0
232863	232539	19421M	PARTICIPANT	\N	PRESENT	0
232865	232864	19651A	PARTICIPANT	\N	PRESENT	0
232866	232864	04061F	PARTICIPANT	\N	PRESENT	0
232867	232864	19713W	PARTICIPANT	\N	PRESENT	0
232869	232868	19737F	PARTICIPANT	\N	PRESENT	0
232870	232868	19349W	PARTICIPANT	\N	PRESENT	0
232871	232868	08024S	PARTICIPANT	\N	PRESENT	0
232872	232868	19551W	PARTICIPANT	\N	PRESENT	0
235118	233295	14109K	PARTICIPANT	\N	PRESENT	0
235119	233295	14235Q	PARTICIPANT	\N	EXCUSE	0
235120	233295	19269X	PARTICIPANT	\N	EXCUSE	0
235122	233295	11045K	PARTICIPANT	\N	EXCUSE	0
235123	233295	14147R	PARTICIPANT	\N	PRESENT	0
235170	235169	08015R	PARTICIPANT	\N	PRESENT	0
235172	235169	14225N	PARTICIPANT	\N	PRESENT	0
235173	235169	19467C	PARTICIPANT	\N	PRESENT	0
235174	235169	14197C	PARTICIPANT	\N	PRESENT	0
235175	235169	04049K	PARTICIPANT	\N	PRESENT	0
235176	235169	11026G	PARTICIPANT	\N	PRESENT	0
235177	235169	01043Q	PARTICIPANT	\N	PRESENT	0
235178	235169	14001X	PARTICIPANT	\N	PRESENT	0
235179	235169	19335Q	PARTICIPANT	\N	PRESENT	0
235180	235169	19735D	PARTICIPANT	\N	PRESENT	0
235181	235169	19737F	PARTICIPANT	\N	PRESENT	0
235182	235169	19657G	PARTICIPANT	\N	PRESENT	0
235189	233010	11099A	PARTICIPANT	\N	PRESENT	0
235190	233010	14069U	PARTICIPANT	\N	PRESENT	0
235191	233010	05012A	PARTICIPANT	\N	PRESENT	0
235192	233010	08068F	PARTICIPANT	\N	PRESENT	0
235195	235194	08053X	PARTICIPANT	\N	PRESENT	0
235196	235194	14079W	PARTICIPANT	\N	PRESENT	0
235197	235194	19725B	PARTICIPANT	\N	PRESENT	0
235267	232997	14259Y	PARTICIPANT	\N	PRESENT	0
235268	232997	19735D	PARTICIPANT	\N	PRESENT	0
235269	232997	14231L	PARTICIPANT	\N	PRESENT	0
235270	232997	14103D	PARTICIPANT	\N	PRESENT	0
235271	232997	11049P	PARTICIPANT	\N	PRESENT	0
235272	232997	05012A	PARTICIPANT	\N	PRESENT	0
235273	232997	01057W	PARTICIPANT	\N	PRESENT	0
235274	232997	08010L	PARTICIPANT	\N	PRESENT	0
235275	232997	14327T	PARTICIPANT	\N	PRESENT	0
235276	232997	14257W	PARTICIPANT	\N	PRESENT	0
235277	232997	14281W	PARTICIPANT	\N	PRESENT	0
235278	232997	04045F	PARTICIPANT	\N	PRESENT	0
235279	232997	14063N	PARTICIPANT	\N	PRESENT	0
235280	232997	19565D	PARTICIPANT	\N	PRESENT	0
235281	232997	19525U	PARTICIPANT	\N	PRESENT	0
235286	235285	19575F	PARTICIPANT	\N	PRESENT	0
235287	235285	95015C	PARTICIPANT	\N	PRESENT	0
235288	235285	19467C	PARTICIPANT	\N	PRESENT	0
235289	235285	19251M	PARTICIPANT	\N	PRESENT	0
235290	235285	14151M	PARTICIPANT	\N	PRESENT	0
235291	235285	08056B	PARTICIPANT	\N	PRESENT	0
235292	235285	19709B	PARTICIPANT	\N	PRESENT	0
235293	235285	14193X	PARTICIPANT	\N	PRESENT	0
235294	235285	14237S	PARTICIPANT	\N	PRESENT	0
235295	235285	04045F	PARTICIPANT	\N	PRESENT	0
235296	235285	95067Q	PARTICIPANT	\N	PRESENT	0
235401	235400	04089T	PARTICIPANT	\N	PRESENT	0
235402	235400	01043Q	PARTICIPANT	\N	PRESENT	0
235436	232539	14107H	PARTICIPANT	\N	PRESENT	0
235462	235461	14079W	PARTICIPANT	\N	PRESENT	0
235463	235461	08056B	PARTICIPANT	\N	PRESENT	0
235464	235461	11064N	PARTICIPANT	\N	PRESENT	0
235465	235461	19569H	PARTICIPANT	\N	PRESENT	0
235466	235461	14179A	PARTICIPANT	\N	PRESENT	0
235467	235461	08069G	PARTICIPANT	\N	PRESENT	0
235468	235461	19699S	PARTICIPANT	\N	PRESENT	0
235469	235461	11026G	PARTICIPANT	\N	PRESENT	0
235470	235461	08034U	PARTICIPANT	\N	PRESENT	0
235471	235461	19697Q	PARTICIPANT	\N	PRESENT	0
235472	235461	14169X	PARTICIPANT	\N	PRESENT	0
235475	235474	07004J	PARTICIPANT	\N	PRESENT	0
235476	235474	14281W	PARTICIPANT	\N	PRESENT	0
235477	235474	04043D	PARTICIPANT	\N	PRESENT	0
235478	235474	04040A	PARTICIPANT	\N	PRESENT	0
235479	235474	14083S	PARTICIPANT	\N	PRESENT	0
235480	235474	14085U	PARTICIPANT	\N	PRESENT	0
235481	235474	14079W	PARTICIPANT	\N	PRESENT	0
235482	235474	19739H	PARTICIPANT	\N	PRESENT	0
235483	235474	10015M	PARTICIPANT	\N	PRESENT	0
235484	235474	11041F	PARTICIPANT	\N	PRESENT	0
235486	235485	01028R	PARTICIPANT	\N	PRESENT	0
235565	235564	95067Q	PARTICIPANT	\N	PRESENT	0
235566	235564	14028W	PARTICIPANT	\N	PRESENT	0
235570	235568	95067Q	PARTICIPANT	\N	PRESENT	0
235579	235568	14028W	PARTICIPANT	\N	PRESENT	0
235935	235567	14089Y	PARTICIPANT	\N	PRESENT	0
235936	235567	08014Q	PARTICIPANT	\N	PRESENT	0
235937	235567	14065Q	PARTICIPANT	\N	EXCUSE	0
235938	235567	14357A	PARTICIPANT	\N	PRESENT	0
235939	235567	14249W	PARTICIPANT	\N	EXCUSE	0
235940	235567	08018U	PARTICIPANT	\N	EXCUSE	0
235941	235567	11083R	PARTICIPANT	\N	PRESENT	0
235942	235567	14033T	PARTICIPANT	\N	EXCUSE	0
235943	235567	19725B	PARTICIPANT	\N	PRESENT	0
235944	235567	04097T	PARTICIPANT	\N	PRESENT	0
235945	235567	14097Y	PARTICIPANT	\N	PRESENT	0
235946	235567	14061L	PARTICIPANT	\N	EXCUSE	0
235947	235567	14073Q	PARTICIPANT	\N	EXCUSE	0
235948	235567	11026G	PARTICIPANT	\N	PRESENT	0
235949	235567	08039A	PARTICIPANT	\N	EXCUSE	0
235950	235567	14221J	PARTICIPANT	\N	PRESENT	0
235951	235567	04057K	PARTICIPANT	\N	EXCUSE	0
235952	235567	19563B	PARTICIPANT	\N	PRESENT	0
235953	235567	19593H	PARTICIPANT	\N	EXCUSE	0
235954	235567	14237S	PARTICIPANT	\N	PRESENT	0
235955	235567	14135M	PARTICIPANT	\N	PRESENT	0
235956	235567	14331P	PARTICIPANT	\N	EXCUSE	0
235957	235567	14225N	PARTICIPANT	\N	PRESENT	0
235958	235567	10015M	PARTICIPANT	\N	PRESENT	0
235959	235567	98035U	PARTICIPANT	\N	PRESENT	0
235960	235567	14053L	PARTICIPANT	\N	PRESENT	0
235961	235567	16685X	PARTICIPANT	\N	PRESENT	0
235962	235567	19483C	PARTICIPANT	\N	PRESENT	0
235963	235567	19251M	PARTICIPANT	\N	PRESENT	0
235964	235567	19421M	PARTICIPANT	\N	PRESENT	0
235965	235567	11041F	PARTICIPANT	\N	PRESENT	0
235966	235567	98018T	PARTICIPANT	\N	PRESENT	0
235967	235567	97011G	PARTICIPANT	\N	PRESENT	0
235968	235567	11066Q	PARTICIPANT	\N	PRESENT	0
235969	235567	11027H	PARTICIPANT	\N	PRESENT	0
235970	235567	11072N	PARTICIPANT	\N	PRESENT	0
235971	235567	04042C	PARTICIPANT	\N	PRESENT	0
235972	235567	01028R	PARTICIPANT	\N	PRESENT	0
235973	235567	19443T	PARTICIPANT	\N	PRESENT	0
235974	235567	98050T	PARTICIPANT	\N	PRESENT	0
235975	235567	95067Q	PARTICIPANT	\N	PRESENT	0
235976	235567	08058D	PARTICIPANT	\N	PRESENT	0
236004	235589	95067Q	PARTICIPANT	\N	PRESENT	0
236005	235589	14028W	PARTICIPANT	\N	PRESENT	0
236007	236006	19447X	PARTICIPANT	\N	PRESENT	0
236008	236006	19649G	PARTICIPANT	\N	PRESENT	0
236013	236011	14021P	PARTICIPANT	\N	PRESENT	0
236012	236011	19447X	PARTICIPANT	\N	PRESENT	0
236014	236011	14073Q	PARTICIPANT	\N	PRESENT	0
236016	236015	19447X	PARTICIPANT	\N	PRESENT	0
236017	236015	19649G	PARTICIPANT	\N	PRESENT	0
236018	236015	14021P	PARTICIPANT	\N	PRESENT	0
236024	236023	19447X	PARTICIPANT	\N	PRESENT	0
236029	236028	19447X	PARTICIPANT	\N	PRESENT	0
236034	236033	19447X	PARTICIPANT	\N	PRESENT	0
236043	236042	19447X	PARTICIPANT	\N	PRESENT	0
236048	236047	19447X	PARTICIPANT	\N	PRESENT	0
236051	236047	19649G	PARTICIPANT	\N	PRESENT	0
236053	236052	19447X	PARTICIPANT	\N	PRESENT	0
235117	233295	19697Q	PARTICIPANT	\N	EXCUSE	0
235934	235567	96004D	PRESIDENT	0	PRESENT	0
211716	211714	14105F	PARTICIPANT	\N	PRESENT	0
218872	217782	14229S	PARTICIPANT	\N	PRESENT	0
218873	217782	14241N	PARTICIPANT	\N	PRESENT	0
218874	217782	19573D	PARTICIPANT	\N	PRESENT	0
218875	217782	14039A	PARTICIPANT	\N	PRESENT	0
218876	217782	14107H	PARTICIPANT	\N	PRESENT	0
218877	217782	08017T	PARTICIPANT	\N	PRESENT	0
218878	217782	92040Q	PARTICIPANT	\N	PRESENT	0
218879	217782	07033P	PARTICIPANT	\N	PRESENT	0
218880	217782	08016S	PARTICIPANT	\N	PRESENT	0
218881	217782	14249W	PARTICIPANT	\N	PRESENT	0
218882	217782	08039A	PARTICIPANT	\N	PRESENT	0
218883	217782	08031R	PARTICIPANT	\N	PRESENT	0
218884	217782	19593H	PARTICIPANT	\N	PRESENT	0
218885	217782	19643A	PARTICIPANT	\N	PRESENT	0
218886	217782	14061L	PARTICIPANT	\N	PRESENT	0
218887	217782	04057K	PARTICIPANT	\N	PRESENT	0
218888	217782	14073Q	PARTICIPANT	\N	PRESENT	0
218889	217782	08035V	PARTICIPANT	\N	PRESENT	0
218890	217782	19611R	PARTICIPANT	\N	PRESENT	0
218891	217782	19693L	PARTICIPANT	\N	PRESENT	0
218892	217782	19399H	PARTICIPANT	\N	PRESENT	0
218893	217782	87003B	PARTICIPANT	\N	PRESENT	0
218894	217782	14201E	PARTICIPANT	\N	PRESENT	0
218895	217782	14030Q	PARTICIPANT	\N	PRESENT	0
218896	217782	19731Y	PARTICIPANT	\N	PRESENT	0
218897	217782	14251Q	PARTICIPANT	\N	PRESENT	0
218898	217782	04059M	PARTICIPANT	\N	PRESENT	0
218899	217782	19735D	PARTICIPANT	\N	PRESENT	0
218900	217782	11109J	PARTICIPANT	\N	PRESENT	0
218901	217782	14063N	PARTICIPANT	\N	PRESENT	0
218902	217782	11083R	PARTICIPANT	\N	PRESENT	0
218903	217782	14123H	PARTICIPANT	\N	PRESENT	0
218904	217782	11104D	PARTICIPANT	\N	PRESENT	0
218905	217782	04018C	PARTICIPANT	\N	PRESENT	0
218906	217782	19621T	PARTICIPANT	\N	PRESENT	0
218907	217782	08043V	PARTICIPANT	\N	EXCUSE	0
218908	217782	11043H	PARTICIPANT	\N	EXCUSE	0
218909	217574	11031D	PARTICIPANT	\N	PRESENT	0
218953	216549	19443T	PARTICIPANT	\N	PRESENT	0
218954	216549	04034C	PARTICIPANT	\N	PRESENT	0
218955	216549	14079W	PARTICIPANT	\N	PRESENT	0
218956	216549	04040A	PARTICIPANT	\N	PRESENT	0
218957	216549	11027H	PARTICIPANT	\N	PRESENT	0
218958	216549	16685X	PARTICIPANT	\N	PRESENT	0
218959	216549	04042C	PRESIDENT	0	PRESENT	0
218960	216549	11054L	PARTICIPANT	\N	PRESENT	0
218961	216549	11066Q	PARTICIPANT	\N	PRESENT	0
218962	216549	08056B	PARTICIPANT	\N	PRESENT	0
218963	216549	95037J	PARTICIPANT	\N	PRESENT	0
218964	216549	14055N	PARTICIPANT	\N	PRESENT	0
218965	216549	19421M	PARTICIPANT	\N	PRESENT	0
218966	216549	19709B	PARTICIPANT	\N	PRESENT	0
218967	216549	14193X	PRESIDENT	1	PRESENT	0
218968	216549	08053X	PARTICIPANT	\N	PRESENT	0
218969	216549	97011G	PARTICIPANT	\N	PRESENT	0
218970	216549	08047A	PARTICIPANT	\N	PRESENT	0
218971	216549	98029W	PARTICIPANT	\N	PRESENT	0
218972	216549	14097Y	PARTICIPANT	\N	PRESENT	0
218973	216549	95067Q	PARTICIPANT	\N	PRESENT	0
218974	216549	01062T	PARTICIPANT	\N	PRESENT	0
218975	216549	11041F	PARTICIPANT	\N	PRESENT	0
218976	216549	14235Q	PARTICIPANT	\N	PRESENT	0
218977	216549	08058D	PARTICIPANT	\N	PRESENT	0
218978	216549	19251M	PARTICIPANT	\N	PRESENT	0
218979	216549	14028W	PARTICIPANT	\N	PRESENT	0
218980	216549	19721W	PARTICIPANT	\N	PRESENT	0
218981	216549	14105F	PARTICIPANT	\N	PRESENT	0
218982	216549	98018T	PARTICIPANT	\N	PRESENT	0
218983	216549	98022P	PARTICIPANT	\N	PRESENT	0
218984	216549	14211G	PARTICIPANT	\N	PRESENT	0
218985	216549	19583F	PARTICIPANT	\N	PRESENT	0
218986	216549	14255U	PARTICIPANT	\N	PRESENT	0
219233	207716	11109J	PARTICIPANT	\N	PRESENT	0
219234	207716	14063N	PARTICIPANT	\N	PRESENT	0
219235	207716	08045X	PARTICIPANT	\N	PRESENT	0
218990	216549	95030B	PARTICIPANT	\N	PRESENT	0
219236	207716	19383Y	PARTICIPANT	\N	PRESENT	0
219237	218456	07033P	PARTICIPANT	\N	PRESENT	0
218993	216549	98050T	PARTICIPANT	\N	PRESENT	0
219238	218456	08012N	PARTICIPANT	\N	PRESENT	0
219197	218456	04070G	PRESIDENT	0	PRESENT	0
219198	218456	19699S	PARTICIPANT	\N	PRESENT	0
219199	218456	12041X	PARTICIPANT	\N	PRESENT	0
219200	218456	19533U	PARTICIPANT	\N	PRESENT	0
219201	218456	01048V	PARTICIPANT	\N	PRESENT	0
219202	218456	95015C	PARTICIPANT	\N	PRESENT	0
219203	218456	14229S	PARTICIPANT	\N	PRESENT	0
219204	218456	14241N	PARTICIPANT	\N	PRESENT	0
219205	218456	19573D	PARTICIPANT	\N	PRESENT	0
219206	218456	14039A	PARTICIPANT	\N	PRESENT	0
219207	218456	14107H	PARTICIPANT	\N	PRESENT	0
219208	218456	08017T	PARTICIPANT	\N	PRESENT	0
219209	218456	08016S	PARTICIPANT	\N	PRESENT	0
219210	218456	14249W	PARTICIPANT	\N	PRESENT	0
219211	218456	08031R	PARTICIPANT	\N	PRESENT	0
219212	218456	19593H	PARTICIPANT	\N	PRESENT	0
219213	218456	19643A	PARTICIPANT	\N	PRESENT	0
219214	218456	14061L	PARTICIPANT	\N	PRESENT	0
219215	218456	04057K	PARTICIPANT	\N	PRESENT	0
219216	218456	14073Q	PARTICIPANT	\N	PRESENT	0
219217	218456	08035V	PARTICIPANT	\N	PRESENT	0
219218	218456	19611R	PARTICIPANT	\N	PRESENT	0
219219	218456	08043V	PARTICIPANT	\N	PRESENT	0
219220	218456	19693L	PARTICIPANT	\N	PRESENT	0
219221	218456	19399H	PARTICIPANT	\N	PRESENT	0
219222	218456	14030Q	PARTICIPANT	\N	PRESENT	0
219223	218456	19731Y	PARTICIPANT	\N	PRESENT	0
219224	218456	08020N	PARTICIPANT	\N	PRESENT	0
219225	218456	04059M	PARTICIPANT	\N	PRESENT	0
219226	218456	19735D	PARTICIPANT	\N	PRESENT	0
219227	218456	14123H	PARTICIPANT	\N	PRESENT	0
219228	218456	11104D	PARTICIPANT	\N	PRESENT	0
219229	218456	04018C	PARTICIPANT	\N	PRESENT	0
219230	218456	19621T	PARTICIPANT	\N	PRESENT	0
219231	218456	14059S	PARTICIPANT	\N	EXCUSE	0
219232	218456	11043H	PARTICIPANT	\N	EXCUSE	0
219239	218456	11083R	PARTICIPANT	\N	PRESENT	0
219240	207716	11054L	PARTICIPANT	\N	PRESENT	0
219241	207716	14257W	PARTICIPANT	\N	PRESENT	0
219242	207716	14069U	PARTICIPANT	\N	PRESENT	0
219243	207716	14087W	PARTICIPANT	\N	PRESENT	0
219244	207716	08073C	PARTICIPANT	\N	PRESENT	0
219245	207716	19577H	PARTICIPANT	\N	PRESENT	0
219246	217584	14331P	PARTICIPANT	\N	PRESENT	0
219247	217584	04071H	PARTICIPANT	\N	PRESENT	0
219248	217584	19647E	PARTICIPANT	\N	PRESENT	0
219249	217584	11048N	PARTICIPANT	\N	PRESENT	0
219250	217584	19711U	PARTICIPANT	\N	PRESENT	0
219251	217584	08034U	PARTICIPANT	\N	PRESENT	0
219252	217584	01057W	PARTICIPANT	\N	PRESENT	0
219253	217584	19689Q	PARTICIPANT	\N	PRESENT	0
219254	217584	11074Q	PARTICIPANT	\N	PRESENT	0
219255	217584	19667J	PARTICIPANT	\N	PRESENT	0
219256	217584	08011M	PARTICIPANT	\N	PRESENT	0
219257	217584	14034U	PARTICIPANT	\N	PRESENT	0
219258	217584	14173T	PARTICIPANT	\N	PRESENT	0
219259	217584	04086Q	PARTICIPANT	\N	PRESENT	0
219260	217584	07029T	PARTICIPANT	\N	PRESENT	0
219261	217584	14083S	PARTICIPANT	\N	PRESENT	0
219262	217584	14085U	PARTICIPANT	\N	PRESENT	0
219263	217584	14121F	PARTICIPANT	\N	PRESENT	0
219264	217584	14327T	PARTICIPANT	\N	PRESENT	0
219265	217584	19479G	PARTICIPANT	\N	PRESENT	0
219266	217584	19531S	PARTICIPANT	\N	PRESENT	0
219267	217584	11053K	PARTICIPANT	\N	PRESENT	0
219268	217584	12016W	PARTICIPANT	\N	PRESENT	0
219269	217584	08014Q	PARTICIPANT	\N	PRESENT	0
219270	217584	88008L	PARTICIPANT	\N	PRESENT	0
219271	217584	14159V	PARTICIPANT	\N	PRESENT	0
219272	217584	11040E	PARTICIPANT	\N	PRESENT	0
219273	217584	11012A	PARTICIPANT	\N	PRESENT	0
219274	217584	14199E	PARTICIPANT	\N	PRESENT	0
219275	217584	08073C	PARTICIPANT	\N	PRESENT	0
219276	217584	08010L	PARTICIPANT	\N	PRESENT	0
219277	217584	99004R	PARTICIPANT	\N	PRESENT	0
219278	217584	04061F	PARTICIPANT	\N	PRESENT	0
219296	207716	14089Y	PARTICIPANT	\N	PRESENT	0
219297	207716	08024S	PARTICIPANT	\N	PRESENT	0
219298	207716	19725B	PARTICIPANT	\N	PRESENT	0
219299	207716	08034U	PARTICIPANT	\N	PRESENT	0
219300	207716	14199E	PARTICIPANT	\N	PRESENT	0
219301	207716	19563B	PARTICIPANT	\N	PRESENT	0
219302	207716	08043V	PARTICIPANT	\N	PRESENT	0
219303	207716	14241N	PARTICIPANT	\N	PRESENT	0
219304	207716	14159V	PARTICIPANT	\N	PRESENT	0
219305	207716	11099A	PARTICIPANT	\N	PRESENT	0
227426	226103	19667J	PARTICIPANT	\N	EXCUSE	0
232972	232539	19515S	PARTICIPANT	\N	PRESENT	0
232973	232539	19713W	PARTICIPANT	\N	PRESENT	0
238275	235473	14030Q	PRESIDENT	0	PRESENT	0
238276	235473	19643A	PARTICIPANT	\N	PRESENT	0
238277	235473	80013X	PARTICIPANT	\N	PRESENT	0
238278	235473	19693L	PARTICIPANT	\N	PRESENT	0
238279	235473	14179A	PARTICIPANT	\N	PRESENT	0
238280	235473	19715Y	PARTICIPANT	\N	PRESENT	0
238281	235473	14235Q	PARTICIPANT	\N	PRESENT	0
238282	235473	08043V	PARTICIPANT	\N	EXCUSE	0
238283	235473	08020N	PARTICIPANT	\N	EXCUSE	0
238284	235473	19599P	PARTICIPANT	\N	EXCUSE	0
238285	235473	01043Q	PARTICIPANT	\N	EXCUSE	0
238286	235473	19697Q	PARTICIPANT	\N	EXCUSE	0
238287	235473	11045K	PARTICIPANT	\N	EXCUSE	0
238291	235473	07029T	PARTICIPANT	\N	PRESENT	0
238302	238301	14133K	PARTICIPANT	\N	PRESENT	0
239313	233171	19717B	PARTICIPANT	\N	PRESENT	0
239314	233171	19631V	PARTICIPANT	\N	PRESENT	0
239315	233171	14259Y	PARTICIPANT	\N	PRESENT	0
239316	233171	19577H	PARTICIPANT	\N	PRESENT	0
239317	233171	11010L	PARTICIPANT	\N	PRESENT	0
239318	233171	19691J	PARTICIPANT	\N	PRESENT	0
239319	233171	19729F	PARTICIPANT	\N	PRESENT	0
239320	233171	04043D	PARTICIPANT	\N	PRESENT	0
239321	233171	11072N	PARTICIPANT	\N	PRESENT	0
239322	233171	08019V	PRESIDENT	0	PRESENT	0
239323	233171	14275Y	PARTICIPANT	\N	PRESENT	0
239324	233171	11054L	PARTICIPANT	\N	PRESENT	0
239325	233171	12016W	PARTICIPANT	\N	PRESENT	0
239326	233171	19657G	PARTICIPANT	\N	PRESENT	0
239328	238605	95037J	PARTICIPANT	\N	PRESENT	0
239329	238605	14105F	PARTICIPANT	\N	PRESENT	0
239330	238605	19443T	PARTICIPANT	\N	PRESENT	0
239331	238605	98018T	PRESIDENT	0	PRESENT	0
239332	238605	04034C	PARTICIPANT	\N	PRESENT	0
239333	238605	19421M	PARTICIPANT	\N	PRESENT	0
239334	238605	14193X	PARTICIPANT	\N	PRESENT	0
239335	238605	14267Y	PARTICIPANT	\N	PRESENT	0
239336	238605	19709B	PARTICIPANT	\N	PRESENT	0
239337	238605	98050T	PARTICIPANT	\N	PRESENT	0
239338	238605	08047A	PARTICIPANT	\N	PRESENT	0
239339	238605	04040A	PARTICIPANT	\N	PRESENT	0
239340	238605	14211G	PARTICIPANT	\N	PRESENT	0
239341	238605	08061X	PARTICIPANT	\N	PRESENT	0
239411	238630	11031D	PARTICIPANT	\N	PRESENT	0
239418	232547	14107H	PARTICIPANT	\N	PRESENT	0
239427	238606	19489J	PARTICIPANT	\N	PRESENT	0
239428	238606	14275Y	PARTICIPANT	\N	PRESENT	0
239429	238606	14041T	PARTICIPANT	\N	PRESENT	0
239430	238606	14147R	PARTICIPANT	\N	PRESENT	0
239431	238606	14151M	PARTICIPANT	\N	PRESENT	0
239432	238606	14215L	PARTICIPANT	\N	PRESENT	0
239433	238606	14259Y	PARTICIPANT	\N	PRESENT	0
239434	238606	17637T	PARTICIPANT	\N	PRESENT	0
239435	238606	11072N	PARTICIPANT	\N	PRESENT	0
239436	238606	14053L	PARTICIPANT	\N	PRESENT	0
239437	238606	98035U	PARTICIPANT	\N	PRESENT	0
239438	238606	14111D	PARTICIPANT	\N	PRESENT	0
239439	238606	19649G	PARTICIPANT	\N	PRESENT	0
239440	238606	14065Q	PARTICIPANT	\N	PRESENT	0
239441	238606	14073Q	PARTICIPANT	\N	PRESENT	0
239442	238606	07034Q	PARTICIPANT	\N	PRESENT	0
239443	238606	10015M	PARTICIPANT	\N	PRESENT	0
239444	238606	08045X	PARTICIPANT	\N	PRESENT	0
239445	238606	01024M	PARTICIPANT	\N	PRESENT	0
239446	238606	04038G	PARTICIPANT	\N	PRESENT	0
239447	238606	11090Q	PARTICIPANT	\N	PRESENT	0
239448	238606	19719D	PARTICIPANT	\N	PRESENT	0
239449	238606	11033F	PARTICIPANT	\N	PRESENT	0
239450	238606	19729F	PARTICIPANT	\N	PRESENT	0
239451	238606	95063L	PARTICIPANT	\N	PRESENT	0
239452	238606	19629C	PARTICIPANT	\N	PRESENT	0
239453	238606	14069U	PARTICIPANT	\N	PRESENT	0
239454	238606	11085T	PARTICIPANT	\N	PRESENT	0
239455	238606	11049P	PARTICIPANT	\N	PRESENT	0
239456	238606	11010L	PARTICIPANT	\N	PRESENT	0
239457	238606	19253P	PARTICIPANT	\N	PRESENT	0
239458	238606	14179A	PARTICIPANT	\N	PRESENT	0
239459	238606	01060R	PARTICIPANT	\N	PRESENT	0
239460	238606	19581D	PARTICIPANT	\N	PRESENT	0
239461	238606	19483C	PARTICIPANT	\N	PRESENT	0
239462	238870	19515S	PARTICIPANT	\N	PRESENT	0
239463	238870	19565D	PARTICIPANT	\N	PRESENT	0
239464	238870	01043Q	PARTICIPANT	\N	PRESENT	0
239465	238870	14357A	PARTICIPANT	\N	PRESENT	0
239466	238870	19441R	PARTICIPANT	\N	PRESENT	0
239467	238870	14081Q	PARTICIPANT	\N	PRESENT	0
239468	238870	19413M	PARTICIPANT	\N	PRESENT	0
239469	238870	80013X	PARTICIPANT	\N	PRESENT	0
239470	238870	19631V	PARTICIPANT	\N	PRESENT	0
239471	238870	08068F	PARTICIPANT	\N	PRESENT	0
239472	238870	04049K	PARTICIPANT	\N	PRESENT	0
239473	238870	19705W	PARTICIPANT	\N	PRESENT	0
239474	238870	19707Y	PARTICIPANT	\N	PRESENT	0
239475	238870	08015R	PARTICIPANT	\N	PRESENT	0
239476	238870	08019V	PARTICIPANT	\N	PRESENT	0
239477	238870	14197C	PARTICIPANT	\N	PRESENT	0
239478	238870	19369B	PARTICIPANT	\N	PRESENT	0
239479	238870	19511N	PARTICIPANT	\N	PRESENT	0
239480	238870	08028W	PRESIDENT	1	PRESENT	0
239481	238870	19563B	PARTICIPANT	\N	PRESENT	0
239482	238870	14265W	PARTICIPANT	\N	PRESENT	0
239483	238870	14135M	PARTICIPANT	\N	PRESENT	0
239484	238870	19467C	PARTICIPANT	\N	PRESENT	0
239485	238870	14187A	PARTICIPANT	\N	PRESENT	0
239486	238870	08038Y	PARTICIPANT	\N	PRESENT	0
239487	238870	08062Y	PARTICIPANT	\N	PRESENT	0
239488	238870	19695N	PARTICIPANT	\N	PRESENT	0
239489	238870	14033T	PARTICIPANT	\N	PRESENT	0
239490	238870	11090Q	PRESIDENT	0	PRESENT	0
239491	238870	19269X	PARTICIPANT	\N	PRESENT	0
239492	238870	14205J	PARTICIPANT	\N	PRESENT	0
239493	238870	04088S	PARTICIPANT	\N	PRESENT	0
239494	238870	14115H	PARTICIPANT	\N	PRESENT	0
239495	238870	19507S	PARTICIPANT	\N	PRESENT	0
239496	238870	19747H	PARTICIPANT	\N	PRESENT	0
239497	238870	14207L	PARTICIPANT	\N	PRESENT	0
239498	238870	04043D	PARTICIPANT	\N	PRESENT	0
239499	238870	17589D	PARTICIPANT	\N	PRESENT	0
239500	238870	14257W	PARTICIPANT	\N	PRESENT	0
239501	238870	11101A	PARTICIPANT	\N	EXCUSE	0
239502	232547	19629C	PARTICIPANT	\N	EXCUSE	0
239503	238605	11080N	PARTICIPANT	\N	PRESENT	0
239504	238605	14055N	PARTICIPANT	\N	PRESENT	0
239505	238605	04042C	PARTICIPANT	\N	EXCUSE	0
239506	238870	19619A	PARTICIPANT	\N	EXCUSE	0
239507	238870	11081P	PARTICIPANT	\N	EXCUSE	0
239508	238870	08021P	PARTICIPANT	\N	EXCUSE	0
239509	238630	19663E	PARTICIPANT	\N	EXCUSE	0
239510	238630	11045K	PARTICIPANT	\N	EXCUSE	0
239511	238631	19697Q	PARTICIPANT	\N	PRESENT	0
239512	238631	11067R	PARTICIPANT	\N	PRESENT	0
239513	238631	11077T	PARTICIPANT	\N	PRESENT	0
239514	238631	14355X	PARTICIPANT	\N	PRESENT	0
239515	238631	19569H	PARTICIPANT	\N	PRESENT	0
239516	238631	11097X	PARTICIPANT	\N	PRESENT	0
239517	238631	19415P	PARTICIPANT	\N	PRESENT	0
239518	238631	04045F	PARTICIPANT	\N	PRESENT	0
239519	238631	14227Q	PARTICIPANT	\N	PRESENT	0
239520	238631	19675J	PARTICIPANT	\N	PRESENT	0
239521	238631	11063M	PARTICIPANT	\N	PRESENT	0
239522	238631	17779H	PARTICIPANT	\N	PRESENT	0
239523	238631	19703U	PARTICIPANT	\N	PRESENT	0
239524	238631	14239U	PARTICIPANT	\N	PRESENT	0
239525	238631	11031D	PARTICIPANT	\N	PRESENT	0
239526	238631	14281W	PARTICIPANT	\N	PRESENT	0
239527	238631	14087W	PARTICIPANT	\N	PRESENT	0
239528	238631	19679N	PARTICIPANT	\N	PRESENT	0
239529	238631	14042U	PARTICIPANT	\N	PRESENT	0
239530	238631	14195A	PARTICIPANT	\N	PRESENT	0
239531	238631	19575F	PARTICIPANT	\N	PRESENT	0
239532	238631	14213J	PARTICIPANT	\N	PRESENT	0
239533	238631	14217N	PARTICIPANT	\N	PRESENT	0
239534	238631	19335Q	PARTICIPANT	\N	PRESENT	0
239535	238631	14261S	PARTICIPANT	\N	PRESENT	0
239536	238631	10006L	PARTICIPANT	\N	PRESENT	0
239537	238631	19683J	PARTICIPANT	\N	PRESENT	0
239538	238631	98024R	PARTICIPANT	\N	PRESENT	0
239539	238631	19521Q	PARTICIPANT	\N	PRESENT	0
239540	238631	19527W	PARTICIPANT	\N	PRESENT	0
239541	238631	01034P	PARTICIPANT	\N	PRESENT	0
239542	238631	04092N	PRESIDENT	0	PRESENT	0
239543	238631	08052W	PARTICIPANT	\N	PRESENT	0
239544	238631	19691J	PARTICIPANT	\N	PRESENT	0
239545	238631	19717B	PARTICIPANT	\N	PRESENT	0
239546	238631	08041T	PARTICIPANT	\N	PRESENT	0
239547	238631	19723Y	PARTICIPANT	\N	PRESENT	0
217238	217237	14229S	PARTICIPANT	\N	PRESENT	0
217239	217237	08043V	PARTICIPANT	\N	PRESENT	0
217241	217240	95015C	PARTICIPANT	\N	PRESENT	0
218910	217583	14327T	PARTICIPANT	\N	PRESENT	0
218911	217583	14331P	PARTICIPANT	\N	PRESENT	0
218912	217583	04071H	PARTICIPANT	\N	PRESENT	0
218913	217583	01048V	PARTICIPANT	\N	PRESENT	0
218914	217583	19545Y	PARTICIPANT	\N	PRESENT	0
218859	216835	14021P	PARTICIPANT	\N	PRESENT	0
218860	216835	04038G	PARTICIPANT	\N	EXCUSE	0
218861	216835	08018U	PARTICIPANT	\N	EXCUSE	0
218862	216835	04047H	PARTICIPANT	\N	PRESENT	0
218863	216835	14179A	PARTICIPANT	\N	PRESENT	0
218864	216835	14069U	PARTICIPANT	\N	PRESENT	0
218865	216835	11085T	PARTICIPANT	\N	PRESENT	0
218915	217583	01057W	PARTICIPANT	\N	PRESENT	0
218916	217583	11074Q	PRESIDENT	0	PRESENT	0
218917	217583	89017R	PARTICIPANT	\N	PRESENT	0
218918	217583	19667J	PARTICIPANT	\N	PRESENT	0
218919	217583	14225N	PARTICIPANT	\N	PRESENT	0
218920	217583	19671E	PARTICIPANT	\N	PRESENT	0
218921	217583	11070L	PARTICIPANT	\N	PRESENT	0
218922	217583	88008L	PARTICIPANT	\N	PRESENT	0
218923	217583	07029T	PARTICIPANT	\N	PRESENT	0
218924	217583	14085U	PARTICIPANT	\N	PRESENT	0
218925	217583	07004J	PARTICIPANT	\N	PRESENT	0
218926	217583	19349W	PARTICIPANT	\N	PRESENT	0
218927	217583	08010L	PARTICIPANT	\N	PRESENT	0
218928	217583	19479G	PARTICIPANT	\N	PRESENT	0
218929	217583	11048N	PARTICIPANT	\N	PRESENT	0
218930	217583	19647E	PARTICIPANT	\N	PRESENT	0
218931	217583	19711U	PARTICIPANT	\N	PRESENT	0
218932	217583	08034U	PARTICIPANT	\N	PRESENT	0
218933	217583	19651A	PARTICIPANT	\N	PRESENT	0
218934	217583	08069G	PARTICIPANT	\N	PRESENT	0
218935	217583	19689Q	PARTICIPANT	\N	PRESENT	0
218936	217583	08011M	PARTICIPANT	\N	PRESENT	0
218937	217583	08014Q	PARTICIPANT	\N	PRESENT	0
218938	217583	14159V	PARTICIPANT	\N	PRESENT	0
218939	217583	14173T	PARTICIPANT	\N	PRESENT	0
218940	217583	11040E	PARTICIPANT	\N	PRESENT	0
218941	217583	04086Q	PARTICIPANT	\N	PRESENT	0
218942	217583	14083S	PARTICIPANT	\N	PRESENT	0
218943	217583	11012A	PARTICIPANT	\N	PRESENT	0
218944	217583	14199E	PARTICIPANT	\N	PRESENT	0
218945	217583	08073C	PARTICIPANT	\N	PRESENT	0
218946	217583	14121F	PARTICIPANT	\N	PRESENT	0
218947	217583	99004R	PARTICIPANT	\N	PRESENT	0
218948	217583	04061F	PARTICIPANT	\N	PRESENT	0
218949	217583	95041E	PARTICIPANT	\N	PRESENT	0
218950	217583	19531S	PARTICIPANT	\N	PRESENT	0
218951	217583	19687N	PARTICIPANT	\N	PRESENT	0
218952	217583	11053K	PARTICIPANT	\N	PRESENT	0
218997	216549	01058X	PARTICIPANT	\N	PRESENT	0
219000	207716	11077T	PARTICIPANT	\N	PRESENT	0
219001	207716	14227Q	PARTICIPANT	\N	PRESENT	0
219074	207716	19703U	PARTICIPANT	\N	PRESENT	0
219072	207716	04092N	PARTICIPANT	\N	PRESENT	0
219004	207716	14033T	PARTICIPANT	\N	PRESENT	0
219005	207716	14265W	PARTICIPANT	\N	PRESENT	0
219006	207716	14119M	PARTICIPANT	\N	PRESENT	0
219007	207716	14195A	PARTICIPANT	\N	PRESENT	0
219008	207716	04045F	PARTICIPANT	\N	PRESENT	0
219009	207716	14055N	PARTICIPANT	\N	PRESENT	0
219010	207716	11063M	PARTICIPANT	\N	PRESENT	0
219011	217437	19383Y	PARTICIPANT	\N	PRESENT	0
219012	217437	19333N	PARTICIPANT	\N	PRESENT	0
219013	217437	17583W	PARTICIPANT	\N	PRESENT	0
219014	217437	19701S	PARTICIPANT	\N	PRESENT	0
219015	217437	95062K	PARTICIPANT	\N	PRESENT	0
219016	217437	19549D	PARTICIPANT	\N	PRESENT	0
219017	217437	19387D	PARTICIPANT	\N	PRESENT	0
219018	217437	14219Q	PARTICIPANT	\N	PRESENT	0
219019	217437	14221J	PARTICIPANT	\N	PRESENT	0
219020	217437	19599P	PARTICIPANT	\N	PRESENT	0
219021	217437	18083K	PARTICIPANT	\N	PRESENT	0
219022	217437	14237S	PARTICIPANT	\N	PRESENT	0
219023	217437	19551W	PARTICIPANT	\N	PRESENT	0
219024	217437	05012A	PARTICIPANT	\N	PRESENT	0
219025	217437	80027E	PARTICIPANT	\N	PRESENT	0
219026	217437	14051J	PARTICIPANT	\N	PRESENT	0
219027	217437	19677L	PARTICIPANT	\N	PRESENT	0
219028	217437	08060W	PARTICIPANT	\N	PRESENT	0
219029	217437	96004D	PARTICIPANT	\N	PRESENT	0
219030	217437	19347U	PARTICIPANT	\N	PRESENT	0
219031	217437	14157T	PARTICIPANT	\N	PRESENT	0
219032	217437	19685L	PARTICIPANT	\N	PRESENT	0
219033	217437	08024S	PARTICIPANT	\N	PRESENT	0
219034	217437	19681G	PARTICIPANT	\N	PRESENT	0
219035	217437	98023Q	PARTICIPANT	\N	PRESENT	0
219036	217437	17637T	PARTICIPANT	\N	PRESENT	0
219037	217437	19525U	PARTICIPANT	\N	PRESENT	0
219038	217437	14103D	PARTICIPANT	\N	PRESENT	0
219039	217437	14031R	PARTICIPANT	\N	PRESENT	0
219040	217437	19713W	PARTICIPANT	\N	PRESENT	0
219041	217437	08055A	PARTICIPANT	\N	PRESENT	0
219042	217437	14191V	PARTICIPANT	\N	PRESENT	0
219043	217437	14169X	PARTICIPANT	\N	PRESENT	0
219044	217437	04085P	PARTICIPANT	\N	PRESENT	0
219045	217437	15447F	PARTICIPANT	\N	PRESENT	0
219046	217437	14093U	PARTICIPANT	\N	PRESENT	0
219047	217437	14029X	PARTICIPANT	\N	PRESENT	0
219048	217437	19733B	PARTICIPANT	\N	PRESENT	0
219049	217437	08009T	PRESIDENT	0	PRESENT	0
219050	217437	19737F	PARTICIPANT	\N	PRESENT	0
219051	217437	19739H	PARTICIPANT	\N	PRESENT	0
219052	217437	04097T	PARTICIPANT	\N	PRESENT	0
219053	217437	19503N	PARTICIPANT	\N	EXCUSE	0
219054	217437	02002K	PARTICIPANT	\N	EXCUSE	0
219055	207716	11067R	PARTICIPANT	\N	PRESENT	0
219056	207716	19669L	PARTICIPANT	\N	PRESENT	0
219057	207716	14239U	PARTICIPANT	\N	PRESENT	0
219058	207716	19697Q	PARTICIPANT	\N	PRESENT	0
219059	207716	08041T	PARTICIPANT	\N	PRESENT	0
219060	207716	19731Y	PARTICIPANT	\N	PRESENT	0
219061	207716	95062K	PARTICIPANT	\N	PRESENT	0
219062	207716	11097X	PARTICIPANT	\N	PRESENT	0
219063	207716	14207L	PARTICIPANT	\N	PRESENT	0
219064	207716	08052W	PARTICIPANT	\N	PRESENT	0
219065	207716	19715Y	PARTICIPANT	\N	PRESENT	0
219066	207716	11031D	PARTICIPANT	\N	PRESENT	0
219067	207716	11103C	PARTICIPANT	\N	PRESENT	0
219068	207716	19533U	PARTICIPANT	\N	PRESENT	0
219069	207716	14217N	PARTICIPANT	\N	PRESENT	0
219070	207716	14281W	PARTICIPANT	\N	PRESENT	0
219071	207716	01034P	PARTICIPANT	\N	PRESENT	0
219073	207716	04018C	PARTICIPANT	\N	PRESENT	0
219075	207716	14039A	PARTICIPANT	\N	PRESENT	0
219077	207716	14261S	PARTICIPANT	\N	PRESENT	0
219078	207716	14111D	PARTICIPANT	\N	PRESENT	0
219080	207716	11110B	PARTICIPANT	\N	PRESENT	0
219081	207716	98024R	PARTICIPANT	\N	PRESENT	0
219082	207716	14041T	PARTICIPANT	\N	PRESENT	0
219083	207716	04088S	PARTICIPANT	\N	PRESENT	0
219084	207716	19447X	PARTICIPANT	\N	PRESENT	0
219085	207716	19693L	PARTICIPANT	\N	PRESENT	0
219086	207716	19575F	PARTICIPANT	\N	PRESENT	0
219087	207716	14231L	PARTICIPANT	\N	PRESENT	0
219088	207716	14028W	PARTICIPANT	\N	PRESENT	0
219089	207716	19727D	PARTICIPANT	\N	PRESENT	0
219090	207716	19689Q	PARTICIPANT	\N	PRESENT	0
219091	207716	19663E	PARTICIPANT	\N	PRESENT	0
219092	207716	19723Y	PARTICIPANT	\N	PRESENT	0
219093	207716	14105F	PARTICIPANT	\N	PRESENT	0
219094	207716	08015R	PARTICIPANT	\N	PRESENT	0
219095	207716	14223L	PARTICIPANT	\N	PRESENT	0
219096	207716	19573D	PARTICIPANT	\N	PRESENT	0
219097	207716	19691J	PARTICIPANT	\N	PRESENT	0
219098	207716	19735D	PARTICIPANT	\N	PRESENT	0
219099	207716	19441R	PARTICIPANT	\N	PRESENT	0
219100	207716	14251Q	PARTICIPANT	\N	PRESENT	0
219101	207716	14103D	PARTICIPANT	\N	PRESENT	0
219102	207716	07004J	PARTICIPANT	\N	PRESENT	0
219103	207716	14215L	PARTICIPANT	\N	PRESENT	0
219104	207716	11045K	PARTICIPANT	\N	PRESENT	0
219105	207716	14191V	PARTICIPANT	\N	PRESENT	0
219106	207716	19413M	PARTICIPANT	\N	PRESENT	0
219107	207716	19367Y	PARTICIPANT	\N	PRESENT	0
219108	207716	19679N	PARTICIPANT	\N	PRESENT	0
219109	207716	14205J	PARTICIPANT	\N	PRESENT	0
219110	207716	19483C	PARTICIPANT	\N	PRESENT	0
219111	207716	19701S	PARTICIPANT	\N	PRESENT	0
219112	207716	07034Q	PARTICIPANT	\N	PRESENT	0
219113	207716	17779H	PARTICIPANT	\N	PRESENT	0
219114	207716	19467C	PARTICIPANT	\N	PRESENT	0
219115	207716	19675J	PARTICIPANT	\N	PRESENT	0
219116	207716	19295A	PARTICIPANT	\N	PRESENT	0
219117	207716	14135M	PARTICIPANT	\N	PRESENT	0
219118	207716	10006L	PARTICIPANT	\N	PRESENT	0
225964	225954	19533U	PARTICIPANT	\N	PRESENT	0
235185	232539	11056N	PARTICIPANT	\N	EXCUSE	0
235186	232539	14147R	PARTICIPANT	\N	PRESENT	0
235187	232539	89017R	PARTICIPANT	\N	EXCUSE	0
235188	232539	04061F	PARTICIPANT	\N	PRESENT	0
236197	232944	04059M	PARTICIPANT	\N	PRESENT	0
236056	236055	19447X	PARTICIPANT	\N	PRESENT	0
236198	232944	14191V	PARTICIPANT	\N	PRESENT	0
236059	236058	19447X	PARTICIPANT	\N	PRESENT	0
236350	236345	19577H	PARTICIPANT	\N	PRESENT	0
236074	236073	14089Y	PARTICIPANT	\N	PRESENT	0
236075	236073	14079W	PARTICIPANT	\N	PRESENT	0
236076	236073	11026G	PARTICIPANT	\N	PRESENT	0
236077	236073	19697Q	PARTICIPANT	\N	PRESENT	0
236078	236073	98050T	PARTICIPANT	\N	PRESENT	0
236079	236073	11063M	PARTICIPANT	\N	PRESENT	0
236080	236073	14097Y	PARTICIPANT	\N	PRESENT	0
236082	236081	11054L	PARTICIPANT	\N	PRESENT	0
236083	236081	11033F	PARTICIPANT	\N	PRESENT	0
236084	236081	14179A	PARTICIPANT	\N	PRESENT	0
236085	236081	14281W	PARTICIPANT	\N	PRESENT	0
236086	236081	14097Y	PARTICIPANT	\N	PRESENT	0
236087	236081	14235Q	PARTICIPANT	\N	PRESENT	0
236113	235526	04045F	PARTICIPANT	\N	PRESENT	0
236114	235526	19727D	PARTICIPANT	\N	PRESENT	0
236115	235526	19553Y	PARTICIPANT	\N	PRESENT	0
236116	235526	14195A	PARTICIPANT	\N	PRESENT	0
236117	235526	19521Q	PARTICIPANT	\N	PRESENT	0
236118	235526	19575F	PARTICIPANT	\N	PRESENT	0
236119	235526	19657G	PARTICIPANT	\N	PRESENT	0
236120	235526	14217N	PARTICIPANT	\N	PRESENT	0
236121	235526	19415P	PARTICIPANT	\N	PRESENT	0
236187	233496	19551W	PARTICIPANT	\N	PRESENT	0
236188	233496	19737F	PARTICIPANT	\N	PRESENT	0
236189	233496	19349W	PARTICIPANT	\N	PRESENT	0
236190	233496	08024S	PARTICIPANT	\N	PRESENT	0
236351	236345	04085P	PARTICIPANT	\N	PRESENT	0
236352	236345	11065P	PARTICIPANT	\N	PRESENT	0
236354	236345	01043Q	PARTICIPANT	\N	PRESENT	0
236385	236384	19721W	PARTICIPANT	\N	PRESENT	0
236578	236577	14041T	PARTICIPANT	\N	PRESENT	0
236579	236577	98035U	PARTICIPANT	\N	PRESENT	0
236581	236577	14151M	PARTICIPANT	\N	PRESENT	0
236582	236577	19333N	PARTICIPANT	\N	PRESENT	0
236584	236577	14215L	PARTICIPANT	\N	PRESENT	0
236588	236577	04035D	PARTICIPANT	\N	PRESENT	0
236589	236577	08069G	PARTICIPANT	\N	PRESENT	0
236592	236577	04049K	PARTICIPANT	\N	PRESENT	0
236594	236577	19647E	PARTICIPANT	\N	PRESENT	0
236596	236577	19731Y	PARTICIPANT	\N	PRESENT	0
236598	236577	19483C	PARTICIPANT	\N	PRESENT	0
236599	236577	14059S	PARTICIPANT	\N	PRESENT	0
237221	232946	04092N	PARTICIPANT	\N	PRESENT	0
237184	235612	19515S	PARTICIPANT	\N	PRESENT	0
237185	235612	19565D	PARTICIPANT	\N	PRESENT	0
237186	235612	14357A	PARTICIPANT	\N	PRESENT	0
235017	232939	14107H	PARTICIPANT	\N	PRESENT	0
235184	232539	17637T	PARTICIPANT	\N	EXCUSE	0
237187	235612	19441R	PARTICIPANT	\N	PRESENT	0
237188	235612	14081Q	PARTICIPANT	\N	PRESENT	0
237189	235612	80013X	PARTICIPANT	\N	PRESENT	0
237190	235612	19631V	PARTICIPANT	\N	PRESENT	0
237191	235612	18083K	PARTICIPANT	\N	PRESENT	0
237192	235612	11099A	PARTICIPANT	\N	PRESENT	0
237193	235612	08068F	PARTICIPANT	\N	PRESENT	0
237194	235612	04049K	PARTICIPANT	\N	PRESENT	0
237195	235612	19707Y	PARTICIPANT	\N	PRESENT	0
237196	235612	08015R	PARTICIPANT	\N	PRESENT	0
237197	235612	14042U	PARTICIPANT	\N	PRESENT	0
237198	235612	08019V	PARTICIPANT	\N	PRESENT	0
237199	235612	14197C	PARTICIPANT	\N	PRESENT	0
237200	235612	19511N	PARTICIPANT	\N	PRESENT	0
237201	235612	19563B	PARTICIPANT	\N	PRESENT	0
237202	235612	14265W	PARTICIPANT	\N	PRESENT	0
237203	235612	14329V	PARTICIPANT	\N	PRESENT	0
237204	235612	14135M	PARTICIPANT	\N	PRESENT	0
237205	235612	19467C	PARTICIPANT	\N	PRESENT	0
237206	235612	08038Y	PARTICIPANT	\N	PRESENT	0
237207	235612	19695N	PARTICIPANT	\N	PRESENT	0
237208	235612	11090Q	PRESIDENT	0	PRESENT	0
237209	235612	19295A	PARTICIPANT	\N	PRESENT	0
237210	235612	19269X	PARTICIPANT	\N	PRESENT	0
237211	235612	04088S	PARTICIPANT	\N	PRESENT	0
237212	235612	19507S	PARTICIPANT	\N	PRESENT	0
237213	235612	19747H	PARTICIPANT	\N	PRESENT	0
237214	235612	14207L	PARTICIPANT	\N	PRESENT	0
237215	235612	04043D	PARTICIPANT	\N	PRESENT	0
237216	235612	14257W	PARTICIPANT	\N	PRESENT	0
237217	235612	11101A	PARTICIPANT	\N	EXCUSE	0
237218	235612	08062Y	PARTICIPANT	\N	EXCUSE	0
237219	235612	19369B	PARTICIPANT	\N	EXCUSE	0
237220	235612	08021P	PARTICIPANT	\N	EXCUSE	0
237222	232946	98024R	PARTICIPANT	\N	PRESENT	0
237223	232946	11063M	PARTICIPANT	\N	PRESENT	0
237224	232946	11031D	PARTICIPANT	\N	PRESENT	0
237225	232946	19687N	PARTICIPANT	\N	PRESENT	0
237226	232946	12041X	PARTICIPANT	\N	PRESENT	0
237227	232946	17779H	PARTICIPANT	\N	PRESENT	0
237228	232946	19689Q	PARTICIPANT	\N	PRESENT	0
237232	232946	14281W	PARTICIPANT	\N	PRESENT	0
237230	232946	19715Y	PARTICIPANT	\N	PRESENT	0
237231	232946	11067R	PARTICIPANT	\N	PRESENT	0
237233	232946	14065Q	PARTICIPANT	\N	PRESENT	0
237234	232946	14227Q	PARTICIPANT	\N	PRESENT	0
237235	232946	19545Y	PARTICIPANT	\N	PRESENT	0
237236	232946	17589D	PARTICIPANT	\N	PRESENT	0
237237	232946	04045F	PARTICIPANT	\N	PRESENT	0
237238	232946	19697Q	PARTICIPANT	\N	PRESENT	0
237239	232946	14201E	PARTICIPANT	\N	PRESENT	0
237240	232946	14195A	PARTICIPANT	\N	PRESENT	0
237241	232946	14179A	PARTICIPANT	\N	PRESENT	0
237242	232946	19521Q	PARTICIPANT	\N	PRESENT	0
237243	232946	11012A	PARTICIPANT	\N	PRESENT	0
237244	232946	19253P	PARTICIPANT	\N	PRESENT	0
237245	232946	04018C	PARTICIPANT	\N	PRESENT	0
237246	232946	19383Y	PARTICIPANT	\N	PRESENT	0
237247	232946	14026U	PARTICIPANT	\N	PRESENT	0
237248	232946	11103C	PARTICIPANT	\N	PRESENT	0
237249	232946	10006L	PARTICIPANT	\N	PRESENT	0
237250	232946	14071N	PARTICIPANT	\N	PRESENT	0
237251	232946	14237S	PARTICIPANT	\N	PRESENT	0
237252	235612	19619A	PARTICIPANT	\N	PRESENT	0
237253	232946	14069U	PARTICIPANT	\N	PRESENT	0
237254	232946	14147R	PARTICIPANT	\N	PRESENT	0
237255	232946	14213J	PARTICIPANT	\N	PRESENT	0
237256	232946	14157T	PARTICIPANT	\N	PRESENT	0
237257	232946	14119M	PARTICIPANT	\N	PRESENT	0
237258	232946	19711U	PARTICIPANT	\N	PRESENT	0
237259	232946	14191V	PARTICIPANT	\N	PRESENT	0
237260	232946	14029X	PARTICIPANT	\N	PRESENT	0
237261	232946	95062K	PARTICIPANT	\N	PRESENT	0
237262	232946	98022P	PARTICIPANT	\N	PRESENT	0
237263	232946	14111D	PARTICIPANT	\N	PRESENT	0
237264	232946	11072N	PARTICIPANT	\N	PRESENT	0
237265	232946	14215L	PARTICIPANT	\N	PRESENT	0
237266	232946	19387D	PARTICIPANT	\N	PRESENT	0
237267	232946	14239U	PARTICIPANT	\N	PRESENT	0
237268	232946	14073Q	PARTICIPANT	\N	PRESENT	0
237269	232946	19347U	PARTICIPANT	\N	PRESENT	0
237270	232946	19593H	PARTICIPANT	\N	PRESENT	0
237271	232946	19681G	PARTICIPANT	\N	PRESENT	0
237272	232946	14231L	PARTICIPANT	\N	PRESENT	0
237273	232946	08052W	PARTICIPANT	\N	PRESENT	0
237274	232946	19727D	PARTICIPANT	\N	PRESENT	0
237275	232946	14261S	PARTICIPANT	\N	PRESENT	0
237276	232946	14083S	PARTICIPANT	\N	PRESENT	0
237277	232946	11048N	PARTICIPANT	\N	PRESENT	0
237278	232946	80013X	PARTICIPANT	\N	PRESENT	0
237280	235612	08028W	PARTICIPANT	\N	PRESENT	0
237281	232946	01025N	PARTICIPANT	\N	PRESENT	0
237282	232946	14105F	PARTICIPANT	\N	PRESENT	0
219397	207717	01034P	PARTICIPANT	\N	PRESENT	0
219398	207717	11063M	PARTICIPANT	\N	PRESENT	0
219399	207717	11031D	PARTICIPANT	\N	PRESENT	0
219400	207717	19347U	PARTICIPANT	\N	PRESENT	0
219401	207717	08052W	PARTICIPANT	\N	PRESENT	0
219402	207717	11067R	PARTICIPANT	\N	PRESENT	0
219403	207717	11104D	PARTICIPANT	\N	PRESENT	0
219404	207717	14281W	PARTICIPANT	\N	PRESENT	0
219405	207717	14151M	PARTICIPANT	\N	PRESENT	0
219406	207717	14257W	PARTICIPANT	\N	PRESENT	0
219407	207717	19413M	PARTICIPANT	\N	PRESENT	0
219408	207717	19683J	PARTICIPANT	\N	PRESENT	0
219409	207717	19727D	PARTICIPANT	\N	PRESENT	0
219410	207717	19349W	PARTICIPANT	\N	PRESENT	0
219411	207717	19543W	PARTICIPANT	\N	PRESENT	0
219412	207717	19697Q	PARTICIPANT	\N	PRESENT	0
219413	207717	14239U	PARTICIPANT	\N	PRESENT	0
219414	207717	14241N	PARTICIPANT	\N	PRESENT	0
219415	207717	04045F	PARTICIPANT	\N	PRESENT	0
219416	207717	17779H	PARTICIPANT	\N	PRESENT	0
219417	207717	08061X	PARTICIPANT	\N	PRESENT	0
219418	207717	14042U	PARTICIPANT	\N	PRESENT	0
219419	207717	19679N	PARTICIPANT	\N	PRESENT	0
219420	207717	14231L	PARTICIPANT	\N	PRESENT	0
219421	207717	19739H	PARTICIPANT	\N	PRESENT	0
219422	207717	19703U	PARTICIPANT	\N	PRESENT	0
219423	207717	19483C	PARTICIPANT	\N	PRESENT	0
219424	207717	19447X	PARTICIPANT	\N	PRESENT	0
219425	207717	19533U	PARTICIPANT	\N	PRESENT	0
219426	207717	98024R	PARTICIPANT	\N	PRESENT	0
219430	207717	14355X	PARTICIPANT	\N	PRESENT	0
219428	207717	18083K	PARTICIPANT	\N	PRESENT	0
219429	207717	19723Y	PARTICIPANT	\N	PRESENT	0
219431	207717	19575F	PARTICIPANT	\N	PRESENT	0
219432	207717	11103C	PARTICIPANT	\N	PRESENT	0
219433	207717	14235Q	PARTICIPANT	\N	PRESENT	0
219434	207717	14071N	PARTICIPANT	\N	PRESENT	0
219435	207717	19713W	PARTICIPANT	\N	PRESENT	0
219436	207717	14119M	PARTICIPANT	\N	PRESENT	0
219437	207717	14197C	PARTICIPANT	\N	PRESENT	0
219438	207717	14227Q	PARTICIPANT	\N	PRESENT	0
219439	207717	19715Y	PARTICIPANT	\N	PRESENT	0
219440	207717	14195A	PARTICIPANT	\N	PRESENT	0
219441	207717	19441R	PARTICIPANT	\N	PRESENT	0
219442	207717	19553Y	PARTICIPANT	\N	PRESENT	0
219443	207717	19573D	PARTICIPANT	\N	PRESENT	0
219444	207717	14055N	PARTICIPANT	\N	PRESENT	0
219445	207717	11048N	PARTICIPANT	\N	PRESENT	0
219446	207717	14261S	PARTICIPANT	\N	PRESENT	0
219447	207717	14265W	PARTICIPANT	\N	PRESENT	0
219448	207717	19335Q	PARTICIPANT	\N	PRESENT	0
219449	207717	14159V	PARTICIPANT	\N	PRESENT	0
219450	207717	14061L	PARTICIPANT	\N	PRESENT	0
219451	207717	14033T	PARTICIPANT	\N	PRESENT	0
219452	207717	04088S	PARTICIPANT	\N	PRESENT	0
219453	207717	14223L	PARTICIPANT	\N	PRESENT	0
219454	207717	14026U	PARTICIPANT	\N	PRESENT	0
219455	207717	14217N	PARTICIPANT	\N	PRESENT	0
219456	207717	10006L	PARTICIPANT	\N	PRESENT	0
219457	207717	14083S	PARTICIPANT	\N	PRESENT	0
219458	207717	14357A	PARTICIPANT	\N	PRESENT	0
219459	207717	11045K	PARTICIPANT	\N	PRESENT	0
219460	207717	14213J	PARTICIPANT	\N	PRESENT	0
219461	207717	11097X	PARTICIPANT	\N	PRESENT	0
219462	207717	19701S	PARTICIPANT	\N	PRESENT	0
219463	207717	14135M	PARTICIPANT	\N	PRESENT	0
219464	207717	14221J	PARTICIPANT	\N	PRESENT	0
219465	207717	19443T	PARTICIPANT	\N	PRESENT	0
219466	207717	19657G	PARTICIPANT	\N	PRESENT	0
219467	207717	19577H	PARTICIPANT	\N	PRESENT	0
219468	207717	08055A	PARTICIPANT	\N	PRESENT	0
219469	207717	11077T	PARTICIPANT	\N	PRESENT	0
219470	207717	04040A	PARTICIPANT	\N	PRESENT	0
219471	207717	14069U	PARTICIPANT	\N	PRESENT	0
219472	207717	14249W	PARTICIPANT	\N	PRESENT	0
219473	207717	04033B	PARTICIPANT	\N	PRESENT	0
219474	207717	11099A	PARTICIPANT	\N	PRESENT	0
219475	207717	08019V	PARTICIPANT	\N	PRESENT	0
219476	207717	19737F	PARTICIPANT	\N	PRESENT	0
219477	207717	17637T	PARTICIPANT	\N	PRESENT	0
219478	207717	14087W	PARTICIPANT	\N	PRESENT	0
219479	207717	14073Q	PARTICIPANT	\N	PRESENT	0
219480	207717	07029T	PARTICIPANT	\N	PRESENT	0
219481	207717	14089Y	PARTICIPANT	\N	PRESENT	0
219485	207717	14034U	PARTICIPANT	\N	PRESENT	0
219483	207717	11012A	PARTICIPANT	\N	PRESENT	0
219484	207717	19387D	PARTICIPANT	\N	PRESENT	0
219395	207717	04059M	PARTICIPANT	\N	PRESENT	0
219396	207717	04092N	PARTICIPANT	\N	PRESENT	0
219486	207718	04044E	PARTICIPANT	\N	PRESENT	0
219488	207718	11063M	PARTICIPANT	\N	PRESENT	0
219489	207718	19683J	PARTICIPANT	\N	PRESENT	0
219490	207718	19715Y	PARTICIPANT	\N	PRESENT	0
219491	207718	11109J	PARTICIPANT	\N	PRESENT	0
219492	207718	14227Q	PARTICIPANT	\N	PRESENT	0
219493	207718	08068F	PARTICIPANT	\N	PRESENT	0
219494	207718	19527W	PARTICIPANT	\N	PRESENT	0
219495	207718	14021P	PARTICIPANT	\N	PRESENT	0
219496	207718	11067R	PARTICIPANT	\N	PRESENT	0
219497	207718	08052W	PARTICIPANT	\N	PRESENT	0
219498	207718	14281W	PARTICIPANT	\N	PRESENT	0
219499	207718	04092N	PARTICIPANT	\N	PRESENT	0
219500	207718	01034P	PARTICIPANT	\N	PRESENT	0
219501	207718	19413M	PARTICIPANT	\N	PRESENT	0
219502	207718	19503N	PARTICIPANT	\N	PRESENT	0
219503	207718	08055A	PARTICIPANT	\N	PRESENT	0
219504	207718	08061X	PARTICIPANT	\N	PRESENT	0
219505	207718	14239U	PARTICIPANT	\N	PRESENT	0
219506	207718	19697Q	PARTICIPANT	\N	PRESENT	0
219507	207718	04045F	PARTICIPANT	\N	PRESENT	0
219508	207718	19553Y	PARTICIPANT	\N	PRESENT	0
219509	207718	14195A	PARTICIPANT	\N	PRESENT	0
219510	207718	19441R	PARTICIPANT	\N	PRESENT	0
219511	207718	14042U	PARTICIPANT	\N	PRESENT	0
219512	207718	14221J	PARTICIPANT	\N	PRESENT	0
219513	207718	14073Q	PARTICIPANT	\N	PRESENT	0
219514	207718	14231L	PARTICIPANT	\N	PRESENT	0
219579	207718	19693L	PARTICIPANT	\N	PRESENT	0
219516	207718	08056B	PARTICIPANT	\N	PRESENT	0
219517	207718	19737F	PARTICIPANT	\N	PRESENT	0
219518	207718	11012A	PARTICIPANT	\N	PRESENT	0
219519	207718	19713W	PARTICIPANT	\N	PRESENT	0
219520	207718	11097X	PARTICIPANT	\N	PRESENT	0
219521	207718	10006L	PARTICIPANT	\N	PRESENT	0
219522	207718	14055N	PARTICIPANT	\N	PRESENT	0
219523	207718	14357A	PARTICIPANT	\N	PRESENT	0
219524	207718	11103C	PARTICIPANT	\N	PRESENT	0
219525	207718	14071N	PARTICIPANT	\N	PRESENT	0
219526	207718	14257W	PARTICIPANT	\N	PRESENT	0
219527	207718	98024R	PARTICIPANT	\N	PRESENT	0
219528	207718	14213J	PARTICIPANT	\N	PRESENT	0
219529	207718	14265W	PARTICIPANT	\N	PRESENT	0
219530	207718	14355X	PARTICIPANT	\N	PRESENT	0
219531	207718	19575F	PARTICIPANT	\N	PRESENT	0
219532	207718	19443T	PARTICIPANT	\N	PRESENT	0
219533	207718	04088S	PARTICIPANT	\N	PRESENT	0
219534	207718	19663E	PARTICIPANT	\N	PRESENT	0
219535	207718	18083K	PARTICIPANT	\N	PRESENT	0
219536	207718	19415P	PARTICIPANT	\N	PRESENT	0
219537	207718	14031R	PARTICIPANT	\N	PRESENT	0
219538	207718	14157T	PARTICIPANT	\N	PRESENT	0
219539	207718	14207L	PARTICIPANT	\N	PRESENT	0
219540	207718	14223L	PARTICIPANT	\N	PRESENT	0
219541	207718	19703U	PARTICIPANT	\N	PRESENT	0
219542	207718	19447X	PARTICIPANT	\N	PRESENT	0
219543	207718	14038Y	PARTICIPANT	\N	PRESENT	0
219544	207718	14217N	PARTICIPANT	\N	PRESENT	0
219545	207718	19301E	PARTICIPANT	\N	PRESENT	0
219546	207718	19727D	PARTICIPANT	\N	PRESENT	0
219547	207718	08019V	PARTICIPANT	\N	PRESENT	0
219548	207718	17779H	PARTICIPANT	\N	PRESENT	0
219549	207718	19679N	PARTICIPANT	\N	PRESENT	0
219550	207718	04043D	PARTICIPANT	\N	PRESENT	0
219551	207718	14089Y	PARTICIPANT	\N	PRESENT	0
219553	207718	19731Y	PARTICIPANT	\N	PRESENT	0
219554	207718	19253P	PARTICIPANT	\N	PRESENT	0
219568	207718	14205J	PARTICIPANT	\N	PRESENT	0
219573	207718	14087W	PARTICIPANT	\N	PRESENT	0
219574	207718	14259Y	PARTICIPANT	\N	PRESENT	0
219575	207718	19657G	PARTICIPANT	\N	PRESENT	0
219576	207718	14119M	PARTICIPANT	\N	PRESENT	0
219577	207718	19591F	PARTICIPANT	\N	PRESENT	0
219578	207718	19691J	PARTICIPANT	\N	PRESENT	0
219580	207718	14026U	PARTICIPANT	\N	PRESENT	0
219581	207718	19421M	PARTICIPANT	\N	PRESENT	0
219582	207718	14261S	PARTICIPANT	\N	PRESENT	0
219586	207718	14197C	PARTICIPANT	\N	PRESENT	0
219587	207718	19725B	PARTICIPANT	\N	PRESENT	0
228440	227827	89017R	PARTICIPANT	\N	EXCUSE	0
227772	227770	19253P	PARTICIPANT	\N	PRESENT	0
227773	227770	14259Y	PARTICIPANT	\N	PRESENT	0
227774	227770	04040A	PARTICIPANT	\N	PRESENT	0
228452	227827	19629C	PARTICIPANT	\N	EXCUSE	0
227776	227770	14231L	PARTICIPANT	\N	PRESENT	0
227777	227770	19565D	PARTICIPANT	\N	PRESENT	0
227778	227770	19489J	PARTICIPANT	\N	PRESENT	0
227779	227770	08010L	PARTICIPANT	\N	PRESENT	0
228508	227827	19369B	PARTICIPANT	\N	PRESENT	0
227781	227770	95063L	PARTICIPANT	\N	PRESENT	0
227782	226349	14028W	PARTICIPANT	\N	EXCUSE	0
228537	227827	19399H	PARTICIPANT	\N	PRESENT	0
228542	227827	19647E	PARTICIPANT	\N	EXCUSE	0
228543	227827	08045X	PARTICIPANT	\N	PRESENT	0
228544	227827	02002K	PARTICIPANT	\N	PRESENT	0
228557	227827	19713W	PARTICIPANT	\N	PRESENT	0
228558	227827	01028R	PARTICIPANT	\N	EXCUSE	0
228560	227827	19737F	PARTICIPANT	\N	PRESENT	0
228607	218472	11072N	PARTICIPANT	\N	PRESENT	0
228608	218472	14227Q	PARTICIPANT	\N	PRESENT	0
228609	218472	19683J	PARTICIPANT	\N	PRESENT	0
228610	218472	14085U	PARTICIPANT	\N	PRESENT	0
228611	218472	08073C	PARTICIPANT	\N	PRESENT	0
228612	218472	19583F	PARTICIPANT	\N	PRESENT	0
228613	218472	11040E	PARTICIPANT	\N	PRESENT	0
228614	218472	07004J	PARTICIPANT	\N	PRESENT	0
228615	218472	04089T	PARTICIPANT	\N	PRESENT	0
228616	218472	04088S	PARTICIPANT	\N	PRESENT	0
228617	218472	14021P	PARTICIPANT	\N	PRESENT	0
228618	218472	19349W	PARTICIPANT	\N	PRESENT	0
228619	218472	14201E	PARTICIPANT	\N	PRESENT	0
228620	218472	11067R	PARTICIPANT	\N	PRESENT	0
228621	218472	14179A	PARTICIPANT	\N	PRESENT	0
228622	218472	08052W	PARTICIPANT	\N	PRESENT	0
228623	218472	19387D	PARTICIPANT	\N	PRESENT	0
228624	218472	01025N	PARTICIPANT	\N	PRESENT	0
228625	218472	19593H	PARTICIPANT	\N	PRESENT	0
228626	218472	01028R	PARTICIPANT	\N	PRESENT	0
228627	218472	04085P	PARTICIPANT	\N	PRESENT	0
228628	218472	19637C	PARTICIPANT	\N	PRESENT	0
228629	218472	19585H	PARTICIPANT	\N	PRESENT	0
228630	218472	14111D	PARTICIPANT	\N	PRESENT	0
228631	218472	19651A	PARTICIPANT	\N	PRESENT	0
228632	218472	11066Q	PARTICIPANT	\N	PRESENT	0
228633	218472	11027H	PARTICIPANT	\N	PRESENT	0
228634	218472	14051J	PARTICIPANT	\N	PRESENT	0
228635	218472	19319Q	PARTICIPANT	\N	PRESENT	0
228636	218472	19721W	PARTICIPANT	\N	PRESENT	0
228637	218472	19737F	PARTICIPANT	\N	PRESENT	0
228638	218472	14001X	PARTICIPANT	\N	PRESENT	0
228639	218472	19649G	PARTICIPANT	\N	PRESENT	0
228640	218472	11031D	PARTICIPANT	\N	PRESENT	0
228641	218472	11033F	PARTICIPANT	\N	PRESENT	0
228642	218472	14235Q	PARTICIPANT	\N	PRESENT	0
228643	218472	19687N	PARTICIPANT	\N	PRESENT	0
228644	218472	19565D	PARTICIPANT	\N	PRESENT	0
228645	218472	19347U	PARTICIPANT	\N	PRESENT	0
228646	218472	14239U	PARTICIPANT	\N	PRESENT	0
228648	218472	19697Q	PARTICIPANT	\N	PRESENT	0
228649	218472	08021P	PARTICIPANT	\N	PRESENT	0
228650	218472	14039A	PARTICIPANT	\N	PRESENT	0
228651	218472	19301E	PARTICIPANT	\N	PRESENT	0
228652	218472	14229S	PARTICIPANT	\N	PRESENT	0
228653	218472	19531S	PARTICIPANT	\N	PRESENT	0
228654	218472	12041X	PARTICIPANT	\N	PRESENT	0
228655	218472	08058D	PARTICIPANT	\N	PRESENT	0
228656	218472	14121F	PARTICIPANT	\N	PRESENT	0
228657	218472	19715Y	PARTICIPANT	\N	PRESENT	0
228658	218472	12016W	PARTICIPANT	\N	PRESENT	0
228659	218472	14151M	PARTICIPANT	\N	PRESENT	0
228660	218472	14107H	PARTICIPANT	\N	PRESENT	0
228661	218472	14063N	PARTICIPANT	\N	PRESENT	0
228662	218472	08016S	PARTICIPANT	\N	PRESENT	0
228663	218472	80013X	PARTICIPANT	\N	PRESENT	0
228664	218472	80027E	PARTICIPANT	\N	PRESENT	0
228665	218472	14281W	PARTICIPANT	\N	PRESENT	0
228666	218472	08060W	PARTICIPANT	\N	PRESENT	0
228667	218472	08053X	PARTICIPANT	\N	PRESENT	0
228668	218472	11104D	PARTICIPANT	\N	PRESENT	0
228669	218472	04059M	PARTICIPANT	\N	PRESENT	0
228670	218472	19647E	PARTICIPANT	\N	PRESENT	0
228671	218472	19333N	PARTICIPANT	\N	PRESENT	0
228672	218472	19599P	PARTICIPANT	\N	PRESENT	0
228673	218472	08024S	PARTICIPANT	\N	PRESENT	0
228674	218472	04045F	PARTICIPANT	\N	PRESENT	0
228676	218472	19631V	PARTICIPANT	\N	PRESENT	0
228677	218472	17779H	PARTICIPANT	\N	PRESENT	0
228678	218472	14109K	PARTICIPANT	\N	PRESENT	0
228679	218472	14257W	PARTICIPANT	\N	PRESENT	0
228680	218472	19489J	PARTICIPANT	\N	PRESENT	0
228681	218472	19251M	PARTICIPANT	\N	PRESENT	0
228682	218472	95037J	PARTICIPANT	\N	PRESENT	0
228683	218472	14261S	PARTICIPANT	\N	PRESENT	0
228684	218472	19563B	PARTICIPANT	\N	PRESENT	0
228685	218472	08049C	PARTICIPANT	\N	PRESENT	0
228686	218472	19719D	PARTICIPANT	\N	PRESENT	0
228687	218472	19681G	PARTICIPANT	\N	PRESENT	0
228688	218472	14093U	PARTICIPANT	\N	PRESENT	0
228689	218472	14251Q	PARTICIPANT	\N	PRESENT	0
228690	218472	19527W	PARTICIPANT	\N	PRESENT	0
228691	218472	19727D	PARTICIPANT	\N	PRESENT	0
228692	218472	19545Y	PARTICIPANT	\N	PRESENT	0
228693	218472	19413M	PARTICIPANT	\N	PRESENT	0
228694	218472	14197C	PARTICIPANT	\N	PRESENT	0
228695	218472	11074Q	PARTICIPANT	\N	PRESENT	0
228696	218472	14028W	PARTICIPANT	\N	PRESENT	0
228697	218472	14225N	PARTICIPANT	\N	PRESENT	0
228698	218472	08011M	PARTICIPANT	\N	PRESENT	0
228699	218472	98035U	PARTICIPANT	\N	PRESENT	0
228700	218472	08061X	PARTICIPANT	\N	PRESENT	0
228701	218472	19695N	PARTICIPANT	\N	PRESENT	0
228702	218472	04038G	PARTICIPANT	\N	PRESENT	0
228703	218472	19253P	PARTICIPANT	\N	PRESENT	0
228704	218472	08031R	PARTICIPANT	\N	PRESENT	0
228705	218472	14034U	PARTICIPANT	\N	PRESENT	0
228706	218472	08043V	PARTICIPANT	\N	PRESENT	0
228707	218472	19629C	PARTICIPANT	\N	PRESENT	0
228708	218472	04057K	PARTICIPANT	\N	PRESENT	0
228709	218472	14195A	PARTICIPANT	\N	PRESENT	0
228710	218472	11064N	PARTICIPANT	\N	PRESENT	0
228711	218472	11109J	PARTICIPANT	\N	PRESENT	0
228712	218472	19549D	PARTICIPANT	\N	PRESENT	0
228713	218472	14030Q	PARTICIPANT	\N	PRESENT	0
228714	218472	08044W	PARTICIPANT	\N	PRESENT	0
228715	218472	01034P	PARTICIPANT	\N	PRESENT	0
228716	218472	19369B	PARTICIPANT	\N	PRESENT	0
228717	218472	19691J	PARTICIPANT	\N	PRESENT	0
228718	218472	88008L	PARTICIPANT	\N	PRESENT	0
228719	218472	14205J	PARTICIPANT	\N	PRESENT	0
228720	218472	19611R	PARTICIPANT	\N	PRESENT	0
228721	218472	19619A	PARTICIPANT	\N	PRESENT	0
228722	218472	01062T	PARTICIPANT	\N	PRESENT	0
228723	218472	19525U	PARTICIPANT	\N	PRESENT	0
228724	218472	19717B	PARTICIPANT	\N	PRESENT	0
228725	218472	08068F	PARTICIPANT	\N	PRESENT	0
228726	218472	14267Y	PARTICIPANT	\N	PRESENT	0
228727	218472	08056B	PARTICIPANT	\N	PRESENT	0
228728	218472	14219Q	PARTICIPANT	\N	PRESENT	0
228729	218472	19735D	PARTICIPANT	\N	PRESENT	0
228730	218472	16685X	PARTICIPANT	\N	PRESENT	0
228731	218472	14042U	PARTICIPANT	\N	PRESENT	0
228732	218472	19441R	PARTICIPANT	\N	PRESENT	0
228733	218472	19713W	PARTICIPANT	\N	PRESENT	0
228734	218472	14103D	PARTICIPANT	\N	PRESENT	0
228735	218472	14327T	PARTICIPANT	\N	PRESENT	0
228736	218472	11085T	PARTICIPANT	\N	PRESENT	0
228737	218472	11070L	PARTICIPANT	\N	PRESENT	0
228738	218472	14073Q	PARTICIPANT	\N	PRESENT	0
228739	218472	14083S	PARTICIPANT	\N	PRESENT	0
228740	218472	19739H	PARTICIPANT	\N	PRESENT	0
228741	218472	19335Q	PARTICIPANT	\N	PRESENT	0
228742	218472	19685L	PARTICIPANT	\N	PRESENT	0
228743	218472	01060R	PARTICIPANT	\N	PRESENT	0
228744	218472	14055N	PARTICIPANT	\N	PRESENT	0
228745	218472	14241N	PARTICIPANT	\N	PRESENT	0
228746	218472	11083R	PARTICIPANT	\N	PRESENT	0
228747	218472	11056N	PARTICIPANT	\N	PRESENT	0
228748	218472	02002K	PARTICIPANT	\N	PRESENT	0
228749	218472	11099A	PARTICIPANT	\N	PRESENT	0
228750	218472	11012A	PARTICIPANT	\N	PRESENT	0
228751	218472	19591F	PARTICIPANT	\N	PRESENT	0
228752	218472	08035V	PARTICIPANT	\N	PRESENT	0
228753	218472	14173T	PARTICIPANT	\N	PRESENT	0
228754	218472	11026G	PARTICIPANT	\N	PRESENT	0
228755	218472	08017T	PARTICIPANT	\N	PRESENT	0
228756	218472	14357A	PARTICIPANT	\N	PRESENT	0
228757	218472	14329V	PARTICIPANT	\N	PRESENT	0
228758	218472	11101A	PARTICIPANT	\N	PRESENT	0
215507	205652	14221J	PARTICIPANT	\N	PRESENT	0
215508	205652	19511N	PARTICIPANT	\N	PRESENT	0
217377	217376	04089T	PARTICIPANT	\N	PRESENT	0
217384	217383	04089T	PARTICIPANT	\N	PRESENT	0
217389	217388	04089T	PARTICIPANT	\N	PRESENT	0
217395	217394	04089T	PARTICIPANT	\N	PRESENT	0
217401	217400	04089T	PARTICIPANT	\N	PRESENT	0
219123	207716	14053L	PARTICIPANT	\N	PRESENT	0
219124	207716	18083K	PARTICIPANT	\N	PRESENT	0
219126	207716	19695N	PARTICIPANT	\N	PRESENT	0
219130	207716	08056B	PARTICIPANT	\N	PRESENT	0
219131	207716	19269X	PARTICIPANT	\N	PRESENT	0
219132	207716	08068F	PARTICIPANT	\N	PRESENT	0
219133	207716	19583F	PARTICIPANT	\N	PRESENT	0
219134	207716	19399H	PARTICIPANT	\N	PRESENT	0
217370	217369	04089T	PARTICIPANT	\N	PRESENT	0
217373	217372	04089T	PARTICIPANT	\N	PRESENT	0
219135	207716	04085P	PARTICIPANT	\N	PRESENT	0
219136	207716	14107H	PARTICIPANT	\N	PRESENT	0
219137	207716	95041E	PARTICIPANT	\N	PRESENT	0
219138	207716	08061X	PARTICIPANT	\N	PRESENT	0
219139	207716	98050T	PARTICIPANT	\N	PRESENT	0
219140	207716	19511N	PARTICIPANT	\N	PRESENT	0
219141	207716	14123H	PARTICIPANT	\N	PRESENT	0
219142	207716	14029X	PARTICIPANT	\N	PRESENT	0
219143	207716	08019V	PARTICIPANT	\N	PRESENT	0
219144	207716	14061L	PARTICIPANT	\N	PRESENT	0
219145	207716	14187A	PARTICIPANT	\N	PRESENT	0
219146	207716	19733B	PARTICIPANT	\N	PRESENT	0
219147	207716	19737F	PARTICIPANT	\N	PRESENT	0
219148	207716	19527W	PARTICIPANT	\N	PRESENT	0
219149	207716	89017R	PARTICIPANT	\N	PRESENT	0
219150	207716	19347U	PARTICIPANT	\N	PRESENT	0
219151	207716	14031R	PARTICIPANT	\N	PRESENT	0
219152	207716	04059M	PARTICIPANT	\N	PRESENT	0
219153	207716	19301E	PARTICIPANT	\N	PRESENT	0
219154	207716	19335Q	PARTICIPANT	\N	PRESENT	0
219155	207716	19553Y	PARTICIPANT	\N	PRESENT	0
219156	207716	14042U	PARTICIPANT	\N	PRESENT	0
219157	207716	19713W	PARTICIPANT	\N	PRESENT	0
219158	207716	14197C	PARTICIPANT	\N	PRESENT	0
219159	207716	95015C	PARTICIPANT	\N	PRESENT	0
219160	207716	19515S	PARTICIPANT	\N	PRESENT	0
219161	207716	11070L	PARTICIPANT	\N	PRESENT	0
219162	207716	01043Q	PARTICIPANT	\N	PRESENT	0
219163	207716	14026U	PARTICIPANT	\N	PRESENT	0
219164	207716	11012A	PARTICIPANT	\N	PRESENT	0
219165	207716	08055A	PARTICIPANT	\N	PRESENT	0
219166	207716	19525U	PARTICIPANT	\N	PRESENT	0
219167	207716	14115H	PARTICIPANT	\N	PRESENT	0
219168	207716	14355X	PARTICIPANT	\N	PRESENT	0
219169	207716	14071N	PARTICIPANT	\N	PRESENT	0
219170	207716	19699S	PARTICIPANT	\N	PRESENT	0
219171	207716	97011G	PARTICIPANT	\N	PRESENT	0
219172	207716	19687N	PARTICIPANT	\N	PRESENT	0
219173	207716	14249W	PARTICIPANT	\N	PRESENT	0
219174	207716	14157T	PARTICIPANT	\N	PRESENT	0
219175	207716	14021P	PARTICIPANT	\N	PRESENT	0
219176	207716	14221J	PARTICIPANT	\N	PRESENT	0
219177	207716	19739H	PARTICIPANT	\N	PRESENT	0
219178	207716	04047H	PARTICIPANT	\N	PRESENT	0
219179	207716	19657G	PARTICIPANT	\N	PRESENT	0
219180	207716	11026G	PARTICIPANT	\N	PRESENT	0
219181	207716	88008L	PARTICIPANT	\N	PRESENT	0
219182	207716	14213J	PARTICIPANT	\N	PRESENT	0
219183	207716	19591F	PARTICIPANT	\N	PRESENT	0
219186	207716	19673G	PARTICIPANT	\N	PRESENT	0
219189	207716	95030B	PARTICIPANT	\N	PRESENT	0
219190	207716	19507S	PARTICIPANT	\N	PRESENT	0
219191	207716	19521Q	PARTICIPANT	\N	PRESENT	0
219195	207716	98029W	PARTICIPANT	\N	PRESENT	0
219196	207716	19683J	PARTICIPANT	\N	PRESENT	0
219279	217584	89017R	PARTICIPANT	\N	PRESENT	0
219280	207716	14331P	PARTICIPANT	\N	PRESENT	0
219281	207716	14073Q	PARTICIPANT	\N	PRESENT	0
219282	207716	01048V	PARTICIPANT	\N	PRESENT	0
219283	207716	19565D	PARTICIPANT	\N	PRESENT	0
219284	207716	14083S	PARTICIPANT	\N	PRESENT	0
219285	207716	14237S	PARTICIPANT	\N	PRESENT	0
219286	207716	19349W	PARTICIPANT	\N	PRESENT	0
219288	207716	07029T	PARTICIPANT	\N	PRESENT	0
219289	207716	08035V	PARTICIPANT	\N	PRESENT	0
219290	207716	19543W	PARTICIPANT	\N	PRESENT	0
219291	207716	19549D	PARTICIPANT	\N	PRESENT	0
219293	207716	11048N	PARTICIPANT	\N	PRESENT	0
219294	207716	14357A	PARTICIPANT	\N	PRESENT	0
219295	218456	14063N	PARTICIPANT	\N	EXCUSE	0
219555	215602	19735D	PARTICIPANT	\N	PRESENT	0
219557	215602	04045F	PARTICIPANT	\N	PRESENT	0
219558	215602	14231L	PARTICIPANT	\N	PRESENT	0
219559	215602	04086Q	PARTICIPANT	\N	PRESENT	0
219560	215602	08010L	PARTICIPANT	\N	PRESENT	0
219561	215602	05012A	PARTICIPANT	\N	PRESENT	0
219562	215602	01057W	PARTICIPANT	\N	PRESENT	0
219563	215602	11048N	PARTICIPANT	\N	PRESENT	0
219564	215602	14259Y	PARTICIPANT	\N	PRESENT	0
219565	215602	19565D	PARTICIPANT	\N	PRESENT	0
219566	215602	19687N	PARTICIPANT	\N	PRESENT	0
219567	215602	14281W	PARTICIPANT	\N	PRESENT	0
219569	215602	14063N	PARTICIPANT	\N	PRESENT	0
219570	215602	19489J	PARTICIPANT	\N	PRESENT	0
219571	215602	14257W	PARTICIPANT	\N	PRESENT	0
219572	215602	19253P	PARTICIPANT	\N	PRESENT	0
220144	207721	04059M	PARTICIPANT	\N	PRESENT	0
220152	207721	11063M	PARTICIPANT	\N	PRESENT	0
220153	207721	11031D	PARTICIPANT	\N	PRESENT	0
220154	207721	19593H	PARTICIPANT	\N	PRESENT	0
220155	207721	14227Q	PARTICIPANT	\N	PRESENT	0
220156	207721	11109J	PARTICIPANT	\N	PRESENT	0
220157	207721	14225N	PARTICIPANT	\N	PRESENT	0
220158	207721	14281W	PARTICIPANT	\N	PRESENT	0
220159	207721	11067R	PARTICIPANT	\N	PRESENT	0
220160	207721	08052W	PARTICIPANT	\N	PRESENT	0
220161	207721	04045F	PARTICIPANT	\N	PRESENT	0
220162	207721	14239U	PARTICIPANT	\N	PRESENT	0
220163	207721	19697Q	PARTICIPANT	\N	PRESENT	0
220164	207721	14195A	PARTICIPANT	\N	PRESENT	0
220165	207721	14042U	PARTICIPANT	\N	PRESENT	0
220166	207721	01034P	PARTICIPANT	\N	PRESENT	0
220167	207721	14261S	PARTICIPANT	\N	PRESENT	0
220168	207721	19577H	PARTICIPANT	\N	PRESENT	0
220169	207721	07004J	PARTICIPANT	\N	PRESENT	0
220170	207721	04018C	PARTICIPANT	\N	PRESENT	0
220171	207721	14157T	PARTICIPANT	\N	PRESENT	0
220172	207721	19663E	PARTICIPANT	\N	PRESENT	0
220173	207721	19415P	PARTICIPANT	\N	PRESENT	0
220174	207721	19703U	PARTICIPANT	\N	PRESENT	0
220175	207721	19711U	PARTICIPANT	\N	PRESENT	0
220176	207721	04092N	PARTICIPANT	\N	PRESENT	0
220177	207721	10006L	PARTICIPANT	\N	PRESENT	0
220178	207721	11097X	PARTICIPANT	\N	PRESENT	0
220179	207721	98024R	PARTICIPANT	\N	PRESENT	0
220180	207721	19727D	PARTICIPANT	\N	PRESENT	0
220186	207721	14071N	PARTICIPANT	\N	PRESENT	0
220187	207721	14179A	PARTICIPANT	\N	PRESENT	0
220195	207721	17779H	PARTICIPANT	\N	PRESENT	0
220197	207721	19575F	PARTICIPANT	\N	PRESENT	0
220199	207721	19657G	PARTICIPANT	\N	PRESENT	0
220200	207721	14119M	PARTICIPANT	\N	PRESENT	0
220202	207721	14265W	PARTICIPANT	\N	PRESENT	0
220225	207721	14039A	PARTICIPANT	\N	PRESENT	0
220223	207721	19693L	PARTICIPANT	\N	PRESENT	0
220224	207721	19591F	PARTICIPANT	\N	PRESENT	0
220226	207721	19521Q	PARTICIPANT	\N	PRESENT	0
220227	207721	19689Q	PARTICIPANT	\N	PRESENT	0
220232	207721	11077T	PARTICIPANT	\N	PRESENT	0
220233	207721	08069G	PARTICIPANT	\N	PRESENT	0
220234	207721	19649G	PARTICIPANT	\N	PRESENT	0
220235	207721	11045K	PARTICIPANT	\N	PRESENT	0
220237	207721	19553Y	PARTICIPANT	\N	PRESENT	0
220239	207721	19683J	PARTICIPANT	\N	PRESENT	0
220242	207721	99004R	PARTICIPANT	\N	PRESENT	0
220243	207721	19583F	PARTICIPANT	\N	PRESENT	0
220266	207721	08019V	PARTICIPANT	\N	PRESENT	0
220267	207721	19295A	PARTICIPANT	\N	PRESENT	0
220268	207721	19669L	PARTICIPANT	\N	PRESENT	0
220269	207721	19643A	PARTICIPANT	\N	PRESENT	0
220270	207721	04071H	PARTICIPANT	\N	PRESENT	0
220271	207722	04086Q	PARTICIPANT	\N	PRESENT	0
220272	207722	04092N	PARTICIPANT	\N	PRESENT	0
220273	207722	10006L	PARTICIPANT	\N	PRESENT	0
220274	207722	11031D	PARTICIPANT	\N	PRESENT	0
220275	207722	14227Q	PARTICIPANT	\N	PRESENT	0
220276	207722	11067R	PARTICIPANT	\N	PRESENT	0
220277	207722	14042U	PARTICIPANT	\N	PRESENT	0
220278	207722	01034P	PARTICIPANT	\N	PRESENT	0
220279	207722	07004J	PARTICIPANT	\N	PRESENT	0
220280	207722	19697Q	PARTICIPANT	\N	PRESENT	0
236091	236090	07033P	PARTICIPANT	\N	PRESENT	0
236092	236090	14059S	PARTICIPANT	\N	PRESENT	0
236094	236093	07033P	PARTICIPANT	\N	PRESENT	0
236095	236093	19731Y	PARTICIPANT	\N	PRESENT	0
236096	236093	19611R	PARTICIPANT	\N	PRESENT	0
236097	236093	14059S	PARTICIPANT	\N	PRESENT	0
236098	236093	04070G	PARTICIPANT	\N	PRESENT	0
236099	236093	92040Q	PARTICIPANT	\N	PRESENT	0
236100	236093	14229S	PARTICIPANT	\N	PRESENT	0
236101	236093	04018C	PARTICIPANT	\N	PRESENT	0
236102	236093	04049K	PARTICIPANT	\N	PRESENT	0
237343	232947	11031D	PARTICIPANT	\N	PRESENT	0
237344	232947	12041X	PARTICIPANT	\N	PRESENT	0
237345	232947	14197C	PARTICIPANT	\N	PRESENT	0
237346	232947	11063M	PARTICIPANT	\N	PRESENT	0
237347	232947	11067R	PARTICIPANT	\N	PRESENT	0
237348	232947	19527W	PARTICIPANT	\N	PRESENT	0
237349	232947	19727D	PARTICIPANT	\N	PRESENT	0
237350	232947	19689Q	PARTICIPANT	\N	PRESENT	0
237351	232947	14227Q	PARTICIPANT	\N	PRESENT	0
237352	232947	04045F	PARTICIPANT	\N	PRESENT	0
237353	232947	19697Q	PARTICIPANT	\N	PRESENT	0
237354	232947	98024R	PARTICIPANT	\N	PRESENT	0
237355	232947	19629C	PARTICIPANT	\N	PRESENT	0
237356	232947	08049C	PARTICIPANT	\N	PRESENT	0
237357	232947	14231L	PARTICIPANT	\N	PRESENT	0
237358	232947	19737F	PARTICIPANT	\N	PRESENT	0
237359	232947	19479G	PARTICIPANT	\N	PRESENT	0
237360	232947	19713W	PARTICIPANT	\N	PRESENT	0
237361	232947	14087W	PARTICIPANT	\N	PRESENT	0
237362	232947	14030Q	PARTICIPANT	\N	PRESENT	0
237363	232947	04018C	PARTICIPANT	\N	PRESENT	0
237364	232947	14061L	PARTICIPANT	\N	PRESENT	0
237365	232947	19383Y	PARTICIPANT	\N	PRESENT	0
237366	232947	14265W	PARTICIPANT	\N	PRESENT	0
237367	232947	10006L	PARTICIPANT	\N	PRESENT	0
237368	232947	19515S	PARTICIPANT	\N	PRESENT	0
237369	232947	19703U	PARTICIPANT	\N	PRESENT	0
237370	232947	19447X	PARTICIPANT	\N	PRESENT	0
237371	232947	14029X	PARTICIPANT	\N	PRESENT	0
237372	232947	04088S	PARTICIPANT	\N	PRESENT	0
237373	232947	19415P	PARTICIPANT	\N	PRESENT	0
237374	232947	08019V	PARTICIPANT	\N	PRESENT	0
237375	232947	19347U	PARTICIPANT	\N	PRESENT	0
237376	232947	14213J	PARTICIPANT	\N	PRESENT	0
237377	232947	19575F	PARTICIPANT	\N	PRESENT	0
237378	232947	19387D	PARTICIPANT	\N	PRESENT	0
237379	232947	19695N	PARTICIPANT	\N	PRESENT	0
237380	232947	14195A	PARTICIPANT	\N	PRESENT	0
237381	232947	14026U	PARTICIPANT	\N	PRESENT	0
237382	232947	14215L	PARTICIPANT	\N	PRESENT	0
237383	232947	11097X	PARTICIPANT	\N	PRESENT	0
237384	232947	04049K	PARTICIPANT	\N	PRESENT	0
237385	232947	17779H	PARTICIPANT	\N	PRESENT	0
237386	232947	14217N	PARTICIPANT	\N	PRESENT	0
237387	232947	14255U	PARTICIPANT	\N	PRESENT	0
237388	232947	19521Q	PARTICIPANT	\N	PRESENT	0
237389	232947	08010L	PARTICIPANT	\N	PRESENT	0
237390	232947	14147R	PARTICIPANT	\N	PRESENT	0
237391	232947	80013X	PARTICIPANT	\N	PRESENT	0
237392	232947	08061X	PARTICIPANT	\N	PRESENT	0
237341	232947	14034U	PARTICIPANT	\N	PRESENT	0
237342	232947	04092N	PARTICIPANT	\N	PRESENT	0
237393	232947	14119M	PARTICIPANT	\N	PRESENT	0
237394	232947	08020N	PARTICIPANT	\N	PRESENT	0
237395	232947	14235Q	PARTICIPANT	\N	PRESENT	0
237396	232947	08031R	PARTICIPANT	\N	PRESENT	0
237397	232947	08068F	PARTICIPANT	\N	PRESENT	0
237398	232947	14219Q	PARTICIPANT	\N	PRESENT	0
237399	232947	14042U	PARTICIPANT	\N	PRESENT	0
237400	232947	11012A	PARTICIPANT	\N	PRESENT	0
237401	232947	14083S	PARTICIPANT	\N	PRESENT	0
237402	232947	18083K	PARTICIPANT	\N	PRESENT	0
237403	232947	11077T	PARTICIPANT	\N	PRESENT	0
237404	235532	14355X	PARTICIPANT	\N	PRESENT	0
237405	235532	11097X	PARTICIPANT	\N	PRESENT	0
237406	235532	19415P	PARTICIPANT	\N	PRESENT	0
237407	235532	04045F	PARTICIPANT	\N	PRESENT	0
237408	235532	14227Q	PARTICIPANT	\N	PRESENT	0
237409	235532	11063M	PARTICIPANT	\N	PRESENT	0
237410	235532	14239U	PARTICIPANT	\N	PRESENT	0
237411	235532	19703U	PARTICIPANT	\N	PRESENT	0
237412	235532	14281W	PARTICIPANT	\N	PRESENT	0
237413	235532	14042U	PARTICIPANT	\N	PRESENT	0
237414	235532	19367Y	PARTICIPANT	\N	PRESENT	0
237415	235532	14213J	PARTICIPANT	\N	PRESENT	0
237416	235532	14261S	PARTICIPANT	\N	PRESENT	0
237417	235532	14217N	PARTICIPANT	\N	PRESENT	0
237418	235532	19683J	PARTICIPANT	\N	PRESENT	0
237419	235532	98024R	PRESIDENT	1	PRESENT	0
237420	235532	04092N	PRESIDENT	0	PRESENT	0
237421	235532	11045K	PARTICIPANT	\N	PRESENT	0
237422	235532	08052W	PARTICIPANT	\N	PRESENT	0
237423	235532	19691J	PARTICIPANT	\N	PRESENT	0
237424	235532	19717B	PARTICIPANT	\N	PRESENT	0
237425	235532	14119M	PARTICIPANT	\N	PRESENT	0
237426	235532	11103C	PARTICIPANT	\N	PRESENT	0
237427	235532	14071N	PARTICIPANT	\N	PRESENT	0
237428	235532	19657G	PARTICIPANT	\N	PRESENT	0
237572	237571	14255U	PARTICIPANT	\N	PRESENT	0
237573	237571	19711U	PARTICIPANT	\N	PRESENT	0
237574	237571	08034U	PARTICIPANT	\N	PRESENT	0
237575	237571	19697Q	PARTICIPANT	\N	PRESENT	0
237576	237571	14169X	PARTICIPANT	\N	PRESENT	0
237577	237571	14237S	PARTICIPANT	\N	PRESENT	0
237578	237571	95067Q	PARTICIPANT	\N	PRESENT	0
237641	235532	08041T	PARTICIPANT	\N	EXCUSE	0
237643	237642	14255U	PARTICIPANT	\N	PRESENT	0
237644	237642	16685X	PARTICIPANT	\N	PRESENT	0
237692	235613	11101A	PARTICIPANT	\N	EXCUSE	0
237693	235613	08062Y	PARTICIPANT	\N	EXCUSE	0
237694	235613	08021P	PARTICIPANT	\N	EXCUSE	0
237696	235612	11056N	PARTICIPANT	\N	EXCUSE	0
237697	235613	11056N	PARTICIPANT	\N	EXCUSE	0
238004	238003	01028R	PARTICIPANT	\N	PRESENT	0
238088	238081	08018U	PARTICIPANT	\N	PRESENT	0
238090	238081	14211G	PARTICIPANT	\N	PRESENT	0
238092	238081	19683J	PARTICIPANT	\N	PRESENT	0
238085	238081	04040A	PARTICIPANT	\N	PRESENT	0
238086	238081	18083K	PARTICIPANT	\N	PRESENT	0
238095	238081	98005N	PARTICIPANT	\N	PRESENT	0
238096	238081	14219Q	PARTICIPANT	\N	PRESENT	0
238101	238081	11045K	PARTICIPANT	\N	PRESENT	0
238102	238081	19669L	PARTICIPANT	\N	PRESENT	0
238149	238148	14267Y	PARTICIPANT	\N	PRESENT	0
238150	238148	14193X	PARTICIPANT	\N	PRESENT	0
238151	238148	14255U	PARTICIPANT	\N	PRESENT	0
238154	238153	08009T	PARTICIPANT	\N	PRESENT	0
238155	238153	01025N	PARTICIPANT	\N	PRESENT	0
238156	238153	11026G	PARTICIPANT	\N	PRESENT	0
238157	238153	14219Q	PARTICIPANT	\N	PRESENT	0
238158	238153	14221J	PARTICIPANT	\N	PRESENT	0
238159	238153	14237S	PARTICIPANT	\N	PRESENT	0
238160	238153	19739H	PARTICIPANT	\N	PRESENT	0
238161	238153	95062K	PARTICIPANT	\N	PRESENT	0
238162	238153	19737F	PARTICIPANT	\N	PRESENT	0
238211	232951	11072N	PARTICIPANT	\N	PRESENT	0
238212	232951	19543W	PARTICIPANT	\N	PRESENT	0
238213	232951	14235Q	PARTICIPANT	\N	PRESENT	0
238214	232951	14219Q	PARTICIPANT	\N	PRESENT	0
238215	238210	14065Q	PARTICIPANT	\N	EXCUSE	0
238216	232951	14083S	PARTICIPANT	\N	PRESENT	0
212036	208076	11097X	PARTICIPANT	\N	PRESENT	0
212037	208076	11063M	PARTICIPANT	\N	PRESENT	0
214529	210904	11067R	PARTICIPANT	\N	PRESENT	0
214527	210902	11067R	PARTICIPANT	\N	PRESENT	0
214528	210904	14195A	PARTICIPANT	\N	PRESENT	0
214530	210904	11063M	PARTICIPANT	\N	PRESENT	0
214531	210908	11067R	PARTICIPANT	\N	PRESENT	0
215573	205652	18003S	PARTICIPANT	\N	PRESENT	0
215583	205652	14299H	PARTICIPANT	\N	EXCUSE	0
219552	215602	14327T	PARTICIPANT	\N	EXCUSE	0
219588	207718	19723Y	PARTICIPANT	\N	PRESENT	0
219589	207718	19695N	PARTICIPANT	\N	PRESENT	0
219590	207718	19643A	PARTICIPANT	\N	PRESENT	0
219591	207718	19335Q	PARTICIPANT	\N	PRESENT	0
219592	207718	19583F	PARTICIPANT	\N	PRESENT	0
219593	207718	14215L	PARTICIPANT	\N	PRESENT	0
219594	207718	04057K	PARTICIPANT	\N	PRESENT	0
219595	207718	19669L	PARTICIPANT	\N	PRESENT	0
219600	219598	11099A	PARTICIPANT	\N	PRESENT	0
219602	219601	04061F	PARTICIPANT	\N	PRESENT	0
219713	217585	14327T	PARTICIPANT	\N	PRESENT	0
219714	217585	14331P	PARTICIPANT	\N	PRESENT	0
219715	217585	01057W	PRESIDENT	1	PRESENT	0
219716	217585	11053K	PARTICIPANT	\N	PRESENT	0
219717	217585	11074Q	PRESIDENT	0	PRESENT	0
219718	217585	19667J	PARTICIPANT	\N	PRESENT	0
219719	217585	19671E	PARTICIPANT	\N	PRESENT	0
219720	217585	14225N	PARTICIPANT	\N	PRESENT	0
219721	217585	11070L	PARTICIPANT	\N	PRESENT	0
219722	217585	11110B	PARTICIPANT	\N	PRESENT	0
219723	217585	07029T	PARTICIPANT	\N	PRESENT	0
219724	217585	14085U	PARTICIPANT	\N	PRESENT	0
219725	217585	07004J	PARTICIPANT	\N	PRESENT	0
219726	217585	08010L	PARTICIPANT	\N	PRESENT	0
219727	217585	08031R	RAPPORTEUR_AVIS	\N	PRESENT	0
219728	217585	19647E	PARTICIPANT	\N	PRESENT	0
219729	217585	11048N	PARTICIPANT	\N	PRESENT	0
219730	217585	19711U	PARTICIPANT	\N	PRESENT	0
219731	217585	08034U	PARTICIPANT	\N	PRESENT	0
219732	217585	14073Q	RAPPORTEUR_AVIS	\N	PRESENT	0
219733	217585	19687N	PARTICIPANT	\N	PRESENT	0
219734	217585	19689Q	PARTICIPANT	\N	PRESENT	0
219735	217585	08011M	PARTICIPANT	\N	PRESENT	0
219736	217585	14034U	PARTICIPANT	\N	PRESENT	0
219737	217585	14159V	PARTICIPANT	\N	PRESENT	0
219738	217585	11040E	PARTICIPANT	\N	PRESENT	0
219739	217585	04086Q	PARTICIPANT	\N	PRESENT	0
219740	217585	14083S	PARTICIPANT	\N	PRESENT	0
219741	217585	98050T	RAPPORTEUR_AVIS	\N	PRESENT	0
219742	217585	14121F	PARTICIPANT	\N	PRESENT	0
219743	217585	99004R	PARTICIPANT	\N	PRESENT	0
219752	217575	14087W	PARTICIPANT	\N	PRESENT	0
219749	217575	14026U	PARTICIPANT	\N	PRESENT	0
219750	217575	98024R	PRESIDENT	0	PRESENT	0
219751	217575	11097X	PARTICIPANT	\N	PRESENT	0
219753	217575	14119M	PARTICIPANT	\N	PRESENT	0
219754	217575	08052W	PARTICIPANT	\N	PRESENT	0
219755	217575	19657G	PARTICIPANT	\N	PRESENT	0
219756	217575	14195A	PARTICIPANT	\N	PRESENT	0
219757	217575	14227Q	PARTICIPANT	\N	PRESENT	0
219929	219928	04061F	PARTICIPANT	\N	PRESENT	0
219932	219930	11048N	PARTICIPANT	\N	PRESENT	0
219938	219935	11048N	PARTICIPANT	\N	PRESENT	0
219941	219940	11048N	PARTICIPANT	\N	PRESENT	0
219966	207719	08034U	PARTICIPANT	\N	PRESENT	0
219988	207719	11110B	PARTICIPANT	\N	PRESENT	0
219991	207719	19713W	PARTICIPANT	\N	PRESENT	0
220139	220138	11053K	PARTICIPANT	\N	PRESENT	0
220141	220140	11053K	PARTICIPANT	\N	PRESENT	0
220143	220142	07029T	PARTICIPANT	\N	PRESENT	0
220146	220145	14085U	PARTICIPANT	\N	PRESENT	0
220148	220147	04086Q	PARTICIPANT	\N	PRESENT	0
220150	220149	04086Q	PARTICIPANT	\N	PRESENT	0
220185	220151	08011M	PARTICIPANT	\N	PRESENT	0
220378	220313	07034Q	PARTICIPANT	\N	PRESENT	0
220379	220313	14231L	PARTICIPANT	\N	PRESENT	0
220380	218273	11072N	PARTICIPANT	\N	PRESENT	0
220381	220313	14111D	PARTICIPANT	\N	PRESENT	0
220382	220313	08045X	PARTICIPANT	\N	PRESENT	0
220383	220313	11026G	PARTICIPANT	\N	PRESENT	0
220384	220313	01024M	PARTICIPANT	\N	PRESENT	0
220385	220313	19585H	PARTICIPANT	\N	PRESENT	0
220386	220313	19673G	PARTICIPANT	\N	PRESENT	0
220387	220313	19719D	PARTICIPANT	\N	PRESENT	0
220388	220313	01028R	PARTICIPANT	\N	PRESENT	0
220389	220313	05008E	PRESIDENT	0	PRESENT	0
220390	220313	19447X	PARTICIPANT	\N	PRESENT	0
220391	220313	19489J	PARTICIPANT	\N	PRESENT	0
220392	220313	14275Y	PARTICIPANT	\N	PRESENT	0
220393	220313	14041T	PARTICIPANT	\N	PRESENT	0
220394	220313	14147R	PARTICIPANT	\N	PRESENT	0
220395	220313	14151M	PARTICIPANT	\N	PRESENT	0
220396	220313	14215L	PARTICIPANT	\N	PRESENT	0
220397	220313	14021P	PARTICIPANT	\N	PRESENT	0
220398	220313	11072N	PARTICIPANT	\N	PRESENT	0
220399	220313	98035U	PARTICIPANT	\N	PRESENT	0
220400	220313	14179A	PARTICIPANT	\N	PRESENT	0
220401	219909	11074Q	PRESIDENT	0	PRESENT	0
220402	218273	19413M	PARTICIPANT	\N	PRESENT	0
220403	218273	19715Y	PARTICIPANT	\N	PRESENT	0
220404	218273	08014Q	PARTICIPANT	\N	PRESENT	0
220405	218273	19333N	PARTICIPANT	\N	PRESENT	0
220406	218273	19349W	PARTICIPANT	\N	PRESENT	0
220407	218273	14039A	PARTICIPANT	\N	PRESENT	0
220408	218273	19737F	PARTICIPANT	\N	PRESENT	0
220409	218273	19253P	PARTICIPANT	\N	PRESENT	0
220410	218273	14031R	PARTICIPANT	\N	PRESENT	0
220411	218273	19399H	PARTICIPANT	\N	PRESENT	0
220412	218273	14187A	PARTICIPANT	\N	PRESENT	0
220413	218273	19441R	PARTICIPANT	\N	PRESENT	0
220414	218273	19713W	PARTICIPANT	\N	PRESENT	0
220415	218273	14191V	PARTICIPANT	\N	PRESENT	0
220416	218273	19383Y	PARTICIPANT	\N	PRESENT	0
220417	218273	19301E	PARTICIPANT	\N	PRESENT	0
220418	218273	19565D	PARTICIPANT	\N	PRESENT	0
220419	218273	14105F	PARTICIPANT	\N	PRESENT	0
220420	218273	19611R	PARTICIPANT	\N	PRESENT	0
220421	218273	10006L	PARTICIPANT	\N	PRESENT	0
220422	218273	19415P	PARTICIPANT	\N	PRESENT	0
220423	218273	11083R	PARTICIPANT	\N	PRESENT	0
220424	218273	08060W	PARTICIPANT	\N	PRESENT	0
220425	218273	14001X	PARTICIPANT	\N	PRESENT	0
220426	218273	80027E	PARTICIPANT	\N	PRESENT	0
220427	218273	98035U	PARTICIPANT	\N	PRESENT	0
220428	218273	14061L	PARTICIPANT	\N	PRESENT	0
220429	218273	19573D	PARTICIPANT	\N	PRESENT	0
220430	218273	11110B	PARTICIPANT	\N	PRESENT	0
220431	218273	19319Q	PARTICIPANT	\N	PRESENT	0
220432	218273	08056B	PARTICIPANT	\N	PRESENT	0
220433	218273	19515S	PARTICIPANT	\N	PRESENT	0
220449	220313	14065Q	PARTICIPANT	\N	PRESENT	0
220450	220313	04047H	PARTICIPANT	\N	PRESENT	0
220451	220313	14089Y	PARTICIPANT	\N	PRESENT	0
220452	220313	14069U	PARTICIPANT	\N	PRESENT	0
220453	220313	19483C	PARTICIPANT	\N	PRESENT	0
220454	220313	19543W	PARTICIPANT	\N	PRESENT	0
220455	218273	18083K	PARTICIPANT	\N	PRESENT	0
220456	218273	14147R	PARTICIPANT	\N	PRESENT	0
220457	218273	14205J	PARTICIPANT	\N	PRESENT	0
220458	218273	19577H	PARTICIPANT	\N	PRESENT	0
220459	218273	19735D	PARTICIPANT	\N	PRESENT	0
220460	218273	14109K	PARTICIPANT	\N	PRESENT	0
220461	218273	04085P	PARTICIPANT	\N	PRESENT	0
220462	218273	14069U	PARTICIPANT	\N	PRESENT	0
220467	218273	14179A	PARTICIPANT	\N	PRESENT	0
220468	218273	08009T	PARTICIPANT	\N	PRESENT	0
220469	218273	14219Q	PARTICIPANT	\N	PRESENT	0
220470	219909	14331P	PARTICIPANT	\N	PRESENT	0
220471	219909	19479G	PARTICIPANT	\N	PRESENT	0
220472	219909	19711U	PARTICIPANT	\N	PRESENT	0
220473	219909	19531S	PARTICIPANT	\N	PRESENT	0
220474	219909	08034U	PARTICIPANT	\N	PRESENT	0
220475	219909	01048V	PARTICIPANT	\N	PRESENT	0
228759	218472	04035D	PARTICIPANT	\N	PRESENT	0
228760	218472	14081Q	PARTICIPANT	\N	PRESENT	0
228761	218472	14033T	PARTICIPANT	\N	PRESENT	0
228762	218472	01058X	PARTICIPANT	\N	PRESENT	0
228763	218472	99004R	PARTICIPANT	\N	PRESENT	0
228764	218472	04018C	PARTICIPANT	\N	PRESENT	0
228765	218472	14331P	PARTICIPANT	\N	PRESENT	0
228766	218472	14135M	PARTICIPANT	\N	PRESENT	0
228767	218472	19415P	PARTICIPANT	\N	PRESENT	0
228768	218472	08018U	PARTICIPANT	\N	PRESENT	0
228769	218472	14041T	PARTICIPANT	\N	PRESENT	0
228770	218472	19709B	PARTICIPANT	\N	PRESENT	0
228771	218472	19741B	PARTICIPANT	\N	PRESENT	0
228772	218472	14157T	PARTICIPANT	\N	PRESENT	0
228773	218472	04097T	PARTICIPANT	\N	PRESENT	0
228774	218472	19515S	PARTICIPANT	\N	PRESENT	0
228775	218472	19705W	PARTICIPANT	\N	PRESENT	0
228776	218472	14191V	PARTICIPANT	\N	PRESENT	0
228778	218472	14159V	PARTICIPANT	\N	PRESENT	0
228779	218472	14169X	PARTICIPANT	\N	PRESENT	0
228780	218472	04071H	PARTICIPANT	\N	PRESENT	0
228781	218472	08010L	PARTICIPANT	\N	PRESENT	0
228782	218472	10015M	PARTICIPANT	\N	PRESENT	0
228783	218472	14223L	PARTICIPANT	\N	PRESENT	0
228784	218472	08028W	PARTICIPANT	\N	PRESENT	0
228785	218472	11090Q	PARTICIPANT	\N	PRESENT	0
228786	218472	14259Y	PARTICIPANT	\N	PRESENT	0
228787	218472	87003B	PARTICIPANT	\N	PRESENT	0
228788	218472	14026U	PARTICIPANT	\N	PRESENT	0
228789	218472	95030B	PARTICIPANT	\N	PRESENT	0
228790	218472	01024M	PARTICIPANT	\N	PRESENT	0
228791	218472	04044E	PARTICIPANT	\N	PRESENT	0
228792	218472	04092N	PARTICIPANT	\N	PRESENT	0
228793	218472	14211G	PARTICIPANT	\N	PRESENT	0
228794	218472	98018T	PARTICIPANT	\N	PRESENT	0
228795	218472	14071N	PARTICIPANT	\N	PRESENT	0
228796	218472	14187A	PARTICIPANT	\N	PRESENT	0
228797	218472	95062K	PARTICIPANT	\N	PRESENT	0
228798	218472	04033B	PARTICIPANT	\N	PRESENT	0
228799	218472	04043D	PARTICIPANT	\N	PRESENT	0
228800	218472	14249W	PARTICIPANT	\N	PRESENT	0
228801	218472	14053L	PARTICIPANT	\N	PRESENT	0
228802	218472	14275Y	PARTICIPANT	\N	PRESENT	0
228803	218472	14087W	PARTICIPANT	\N	PRESENT	0
228804	218472	14215L	PARTICIPANT	\N	PRESENT	0
228805	218472	07034Q	PARTICIPANT	\N	PRESENT	0
228806	218472	19533U	PARTICIPANT	\N	PRESENT	0
228807	218472	05012A	PARTICIPANT	\N	PRESENT	0
232541	232539	99004R	PRESIDENT	0	PRESENT	0
232542	232539	19737F	PARTICIPANT	\N	PRESENT	0
232543	232539	01028R	PARTICIPANT	\N	EXCUSE	0
232544	232539	11097X	PARTICIPANT	\N	PRESENT	0
232801	232800	11053K	PARTICIPANT	\N	PRESENT	0
232641	232539	11066Q	PARTICIPANT	\N	PRESENT	0
232797	232796	11053K	PARTICIPANT	\N	PRESENT	0
232798	232796	14159V	PARTICIPANT	\N	PRESENT	0
232799	232796	05012A	PARTICIPANT	\N	PRESENT	0
232802	232800	14159V	PARTICIPANT	\N	PRESENT	0
232803	232800	05012A	PARTICIPANT	\N	PRESENT	0
232805	232804	04040A	PARTICIPANT	\N	PRESENT	0
232806	232804	01062T	PARTICIPANT	\N	PRESENT	0
235199	233118	14089Y	PARTICIPANT	\N	PRESENT	0
235200	233118	14053L	PARTICIPANT	\N	PRESENT	0
235201	233118	19725B	PARTICIPANT	\N	PRESENT	0
235202	233118	11026G	PARTICIPANT	\N	PRESENT	0
235203	233118	19483C	PARTICIPANT	\N	PRESENT	0
235204	233118	11072N	PARTICIPANT	\N	PRESENT	0
235205	233118	10015M	PARTICIPANT	\N	PRESENT	0
235206	233118	01028R	PRESIDENT	0	PRESENT	0
235208	233118	98035U	PARTICIPANT	\N	PRESENT	0
235224	233118	96004D	PARTICIPANT	\N	PRESENT	0
235226	233118	08014Q	PARTICIPANT	\N	PRESENT	0
235227	233118	08058D	PARTICIPANT	\N	PRESENT	0
235228	233118	04042C	PARTICIPANT	\N	PRESENT	0
235229	233118	11027H	PARTICIPANT	\N	PRESENT	0
235230	233118	14357A	PARTICIPANT	\N	PRESENT	0
235232	233118	98018T	PARTICIPANT	\N	PRESENT	0
235233	233118	19251M	PARTICIPANT	\N	PRESENT	0
235236	233118	97011G	PARTICIPANT	\N	PRESENT	0
235237	233118	11083R	PARTICIPANT	\N	PRESENT	0
235241	233118	04097T	PARTICIPANT	\N	PRESENT	0
235243	233118	14097Y	PARTICIPANT	\N	PRESENT	0
235246	233118	16685X	PARTICIPANT	\N	PRESENT	0
235249	233118	14221J	PARTICIPANT	\N	PRESENT	0
235250	233118	19563B	PARTICIPANT	\N	PRESENT	0
235252	233118	14237S	PARTICIPANT	\N	PRESENT	0
235253	233118	98050T	PARTICIPANT	\N	PRESENT	0
235254	233118	19443T	PARTICIPANT	\N	PRESENT	0
235255	233118	14135M	PARTICIPANT	\N	PRESENT	0
235256	233118	14225N	PARTICIPANT	\N	PRESENT	0
235257	233118	19421M	PARTICIPANT	\N	PRESENT	0
235259	233118	11041F	PARTICIPANT	\N	PRESENT	0
235260	233118	11066Q	PARTICIPANT	\N	PRESENT	0
235261	233118	95067Q	PARTICIPANT	\N	PRESENT	0
238634	238633	04059M	PARTICIPANT	\N	PRESENT	0
238635	238633	11040E	PARTICIPANT	\N	PRESENT	0
238636	238633	14053L	PARTICIPANT	\N	PRESENT	0
238637	238633	11053K	PARTICIPANT	\N	PRESENT	0
238638	238633	04086Q	PARTICIPANT	\N	PRESENT	0
238639	238633	08052W	PARTICIPANT	\N	PRESENT	0
238640	238633	11070L	PARTICIPANT	\N	PRESENT	0
238641	238633	10006L	PARTICIPANT	\N	PRESENT	0
238642	238633	14041T	PARTICIPANT	\N	PRESENT	0
238643	238633	14034U	PARTICIPANT	\N	PRESENT	0
238644	238633	14231L	PARTICIPANT	\N	PRESENT	0
238645	238633	11064N	PARTICIPANT	\N	PRESENT	0
238646	238633	14081Q	PARTICIPANT	\N	PRESENT	0
238647	238633	14241N	PARTICIPANT	\N	PRESENT	0
238648	238633	14061L	PARTICIPANT	\N	PRESENT	0
238649	238633	14159V	PARTICIPANT	\N	PRESENT	0
238650	238633	86034E	PARTICIPANT	\N	PRESENT	0
238651	238633	08034U	PARTICIPANT	\N	PRESENT	0
238652	238633	01043Q	PARTICIPANT	\N	PRESENT	0
238653	238633	11077T	PARTICIPANT	\N	PRESENT	0
238654	238633	11072N	PARTICIPANT	\N	PRESENT	0
238655	238633	05012A	PARTICIPANT	\N	PRESENT	0
238656	238633	14135M	PARTICIPANT	\N	PRESENT	0
238657	238633	04044E	PARTICIPANT	\N	PRESENT	0
238702	238701	01058X	PARTICIPANT	\N	PRESENT	0
238703	238701	19251M	PARTICIPANT	\N	PRESENT	0
238704	238701	95037J	PARTICIPANT	\N	PRESENT	0
238705	238701	14133K	PARTICIPANT	\N	PRESENT	0
238706	238701	04040A	PARTICIPANT	\N	PRESENT	0
238707	238701	08047A	PARTICIPANT	\N	PRESENT	0
238708	238701	19443T	PARTICIPANT	\N	PRESENT	0
238709	238701	14079W	PARTICIPANT	\N	PRESENT	0
238710	238701	14105F	PARTICIPANT	\N	PRESENT	0
238711	238701	14267Y	PARTICIPANT	\N	PRESENT	0
238712	238701	04042C	PARTICIPANT	\N	PRESENT	0
238713	238701	19421M	PARTICIPANT	\N	PRESENT	0
238714	238701	19319Q	PARTICIPANT	\N	PRESENT	0
238715	238701	19709B	PARTICIPANT	\N	PRESENT	0
238716	238701	98005N	PARTICIPANT	\N	PRESENT	0
238717	238701	14097Y	PARTICIPANT	\N	PRESENT	0
238718	238701	14055N	PARTICIPANT	\N	PRESENT	0
238719	238701	98022P	PARTICIPANT	\N	PRESENT	0
238720	238701	14193X	PARTICIPANT	\N	PRESENT	0
238721	238701	14255U	PARTICIPANT	\N	PRESENT	0
238723	238722	08028W	PARTICIPANT	\N	PRESENT	0
238724	238722	08068F	PARTICIPANT	\N	PRESENT	0
238725	238722	19695N	PARTICIPANT	\N	PRESENT	0
238726	238722	19349W	PARTICIPANT	\N	PRESENT	0
238727	238722	19251M	PARTICIPANT	\N	PRESENT	0
238728	238722	14257W	PARTICIPANT	\N	PRESENT	0
238729	238722	19737F	PARTICIPANT	\N	PRESENT	0
238730	238722	04061F	PARTICIPANT	\N	PRESENT	0
238731	238722	19637C	PARTICIPANT	\N	PRESENT	0
238733	238732	08028W	PARTICIPANT	\N	PRESENT	0
238734	238732	08068F	PARTICIPANT	\N	PRESENT	0
238735	238732	19695N	PARTICIPANT	\N	PRESENT	0
238736	238732	19737F	PARTICIPANT	\N	PRESENT	0
238737	238732	08015R	PARTICIPANT	\N	PRESENT	0
238738	238732	14257W	PARTICIPANT	\N	PRESENT	0
238739	238732	14237S	PARTICIPANT	\N	PRESENT	0
239548	238631	19727D	PARTICIPANT	\N	PRESENT	0
239549	238631	14119M	PARTICIPANT	\N	PRESENT	0
239550	238631	11103C	PARTICIPANT	\N	PRESENT	0
239551	238631	19657G	PARTICIPANT	\N	PRESENT	0
239552	238631	14071N	PARTICIPANT	\N	PRESENT	0
239553	238631	19577H	PARTICIPANT	\N	PRESENT	0
239554	238631	19553Y	PARTICIPANT	\N	EXCUSE	0
239555	238631	08048B	PARTICIPANT	\N	EXCUSE	0
239556	238631	19663E	PARTICIPANT	\N	EXCUSE	0
239557	238631	19367Y	PARTICIPANT	\N	EXCUSE	0
239558	238631	19715Y	PARTICIPANT	\N	EXCUSE	0
239559	238631	11045K	PARTICIPANT	\N	PRESENT	0
239560	238631	14223L	PARTICIPANT	\N	EXCUSE	0
239561	238631	14026U	PARTICIPANT	\N	PRESENT	0
239562	238872	19383Y	PARTICIPANT	\N	PRESENT	0
214058	214057	08048B	PARTICIPANT	\N	PRESENT	0
219120	219119	11053K	PARTICIPANT	\N	PRESENT	0
219121	219119	14159V	PARTICIPANT	\N	PRESENT	0
219122	219119	05012A	PARTICIPANT	\N	PRESENT	0
219127	219125	11053K	PARTICIPANT	\N	PRESENT	0
219128	219125	14159V	PARTICIPANT	\N	PRESENT	0
219129	219125	05012A	PARTICIPANT	\N	PRESENT	0
219287	217584	08047A	RAPPORTEUR_AVIS	\N	PRESENT	0
220281	207722	19703U	PARTICIPANT	\N	PRESENT	0
220282	207722	08069G	PARTICIPANT	\N	PRESENT	0
220283	207722	14119M	PARTICIPANT	\N	PRESENT	0
220284	207722	19415P	PARTICIPANT	\N	PRESENT	0
220285	207722	19711U	PARTICIPANT	\N	PRESENT	0
220286	207722	04043D	PARTICIPANT	\N	PRESENT	0
220287	207722	11063M	PARTICIPANT	\N	PRESENT	0
220288	207722	14239U	PARTICIPANT	\N	PRESENT	0
220289	207722	98024R	PARTICIPANT	\N	PRESENT	0
220290	207722	11097X	PARTICIPANT	\N	PRESENT	0
220291	207722	08052W	PARTICIPANT	\N	PRESENT	0
220292	207722	11045K	PARTICIPANT	\N	PRESENT	0
220293	207722	04018C	PARTICIPANT	\N	PRESENT	0
220294	207722	14195A	PARTICIPANT	\N	PRESENT	0
220295	207722	04057K	PARTICIPANT	\N	PRESENT	0
220296	207722	14071N	PARTICIPANT	\N	PRESENT	0
220297	207722	14281W	PARTICIPANT	\N	PRESENT	0
220298	207722	19583F	PARTICIPANT	\N	PRESENT	0
220299	207722	14255U	PARTICIPANT	\N	PRESENT	0
220300	207722	19663E	PARTICIPANT	\N	PRESENT	0
220301	207722	19683J	PARTICIPANT	\N	PRESENT	0
220302	207722	19591F	PARTICIPANT	\N	PRESENT	0
220303	207722	19727D	PARTICIPANT	\N	PRESENT	0
220304	207722	19695N	PARTICIPANT	\N	PRESENT	0
220315	207722	19643A	PARTICIPANT	\N	PRESENT	0
220306	207722	19701S	PARTICIPANT	\N	PRESENT	0
220312	207722	19659J	PARTICIPANT	\N	PRESENT	0
220316	207722	08019V	PARTICIPANT	\N	PRESENT	0
220321	207722	19693L	PARTICIPANT	\N	PRESENT	0
220323	207722	11077T	PARTICIPANT	\N	PRESENT	0
220324	207722	19295A	PARTICIPANT	\N	PRESENT	0
220325	207722	14179A	PARTICIPANT	\N	PRESENT	0
220327	207722	14261S	PARTICIPANT	\N	PRESENT	0
220328	207722	14039A	PARTICIPANT	\N	PRESENT	0
220533	220500	19333N	PARTICIPANT	\N	PRESENT	0
220531	220500	08052W	PARTICIPANT	\N	PRESENT	0
220532	220500	19525U	PARTICIPANT	\N	PRESENT	0
220534	220500	19583F	PARTICIPANT	\N	PRESENT	0
220535	220500	14195A	PARTICIPANT	\N	PRESENT	0
220536	220500	19553Y	PARTICIPANT	\N	PRESENT	0
220537	220500	19569H	PARTICIPANT	\N	PRESENT	0
220538	220500	19659J	PARTICIPANT	\N	PRESENT	0
220539	220500	19683J	PARTICIPANT	\N	PRESENT	0
220540	220500	14227Q	PARTICIPANT	\N	PRESENT	0
220541	220500	14085U	PARTICIPANT	\N	PRESENT	0
220542	220500	11031D	PARTICIPANT	\N	PRESENT	0
220543	220500	11054L	PARTICIPANT	\N	PRESENT	0
220544	220500	17779H	PARTICIPANT	\N	PRESENT	0
220545	220500	19691J	PARTICIPANT	\N	PRESENT	0
220546	220500	14277B	PARTICIPANT	\N	PRESENT	0
220547	220500	14219Q	PARTICIPANT	\N	PRESENT	0
220548	220500	95041E	PARTICIPANT	\N	PRESENT	0
220549	220500	19731Y	PARTICIPANT	\N	PRESENT	0
220550	220500	14331P	PARTICIPANT	\N	PRESENT	0
220551	220500	19515S	PARTICIPANT	\N	PRESENT	0
220552	220500	10006L	PARTICIPANT	\N	PRESENT	0
220553	220500	14041T	PARTICIPANT	\N	PRESENT	0
220554	220500	19693L	PARTICIPANT	\N	PRESENT	0
220555	220500	14173T	PARTICIPANT	\N	PRESENT	0
220556	220500	14026U	PARTICIPANT	\N	PRESENT	0
220557	220500	07029T	PARTICIPANT	\N	PRESENT	0
220558	220500	88008L	PARTICIPANT	\N	PRESENT	0
220559	220500	19253P	PARTICIPANT	\N	PRESENT	0
220560	220500	98018T	PARTICIPANT	\N	PRESENT	0
220561	220500	04092N	PARTICIPANT	\N	PRESENT	0
220562	220500	18083K	PARTICIPANT	\N	PRESENT	0
220563	220500	19527W	PARTICIPANT	\N	PRESENT	0
220564	220500	08024S	PARTICIPANT	\N	PRESENT	0
220565	220500	98035U	PARTICIPANT	\N	PRESENT	0
220566	220500	19719D	PARTICIPANT	\N	PRESENT	0
220567	220500	17589D	PARTICIPANT	\N	PRESENT	0
220568	220500	19737F	PARTICIPANT	\N	PRESENT	0
220569	220500	14201E	PARTICIPANT	\N	PRESENT	0
220570	220500	19721W	PARTICIPANT	\N	PRESENT	0
220571	220500	14281W	PARTICIPANT	\N	PRESENT	0
220572	220500	19631V	PARTICIPANT	\N	PRESENT	0
220573	220500	15447F	PARTICIPANT	\N	PRESENT	0
220574	220500	01028R	PARTICIPANT	\N	PRESENT	0
220575	220500	14223L	PARTICIPANT	\N	PRESENT	0
220576	220500	19593H	PARTICIPANT	\N	PRESENT	0
220577	220500	01058X	PARTICIPANT	\N	PRESENT	0
220578	220500	99004R	PARTICIPANT	\N	PRESENT	0
220579	220500	04085P	PARTICIPANT	\N	PRESENT	0
220580	220500	14235Q	PARTICIPANT	\N	PRESENT	0
220581	220500	04086Q	PARTICIPANT	\N	PRESENT	0
220582	220500	04008A	PARTICIPANT	\N	PRESENT	0
220583	220500	08053X	PARTICIPANT	\N	PRESENT	0
220584	220500	11066Q	PARTICIPANT	\N	PRESENT	0
220585	220500	08060W	PARTICIPANT	\N	PRESENT	0
220586	220500	07034Q	PARTICIPANT	\N	PRESENT	0
220587	220500	19671E	PARTICIPANT	\N	PRESENT	0
220588	220500	14261S	PARTICIPANT	\N	PRESENT	0
220589	220500	11012A	PARTICIPANT	\N	PRESENT	0
220590	220500	08031R	PARTICIPANT	\N	PRESENT	0
220591	220500	11101A	PARTICIPANT	\N	PRESENT	0
220592	220500	04097T	PARTICIPANT	\N	PRESENT	0
220593	220500	19711U	PARTICIPANT	\N	PRESENT	0
220594	220500	07033P	PARTICIPANT	\N	PRESENT	0
220595	220500	01048V	PARTICIPANT	\N	PRESENT	0
220596	220500	04018C	PARTICIPANT	\N	PRESENT	0
220597	220500	19715Y	PARTICIPANT	\N	PRESENT	0
220598	220500	11080N	PARTICIPANT	\N	PRESENT	0
220599	220500	08041T	PARTICIPANT	\N	PRESENT	0
220600	220500	11067R	PARTICIPANT	\N	PRESENT	0
220601	220500	14193X	PARTICIPANT	\N	PRESENT	0
220602	220500	14039A	PARTICIPANT	\N	PRESENT	0
220603	220500	08061X	PARTICIPANT	\N	PRESENT	0
220604	220500	14059S	PARTICIPANT	\N	PRESENT	0
220605	220500	14093U	PARTICIPANT	\N	PRESENT	0
220606	220500	01057W	PARTICIPANT	\N	PRESENT	0
220607	220500	14069U	PARTICIPANT	\N	PRESENT	0
220608	220500	14042U	PARTICIPANT	\N	PRESENT	0
220609	220500	11103C	PARTICIPANT	\N	PRESENT	0
220610	220500	11083R	PARTICIPANT	\N	PRESENT	0
220611	220500	08016S	PARTICIPANT	\N	PRESENT	0
220612	220500	14087W	PARTICIPANT	\N	PRESENT	0
220613	220500	97011G	PARTICIPANT	\N	PRESENT	0
220614	220500	19503N	PARTICIPANT	\N	PRESENT	0
220615	220500	19689Q	PARTICIPANT	\N	PRESENT	0
220616	220500	08039A	PARTICIPANT	\N	PRESENT	0
220617	220500	19531S	PARTICIPANT	\N	PRESENT	0
220618	220500	14071N	PARTICIPANT	\N	PRESENT	0
220619	220500	08058D	PARTICIPANT	\N	PRESENT	0
220620	220500	08010L	PARTICIPANT	\N	PRESENT	0
220621	220500	14105F	PARTICIPANT	\N	PRESENT	0
220622	220500	14225N	PARTICIPANT	\N	PRESENT	0
220623	220500	14265W	PARTICIPANT	\N	PRESENT	0
220624	220500	87003B	PARTICIPANT	\N	PRESENT	0
220625	220500	10015M	PARTICIPANT	\N	PRESENT	0
220626	220500	11072N	PARTICIPANT	\N	PRESENT	0
220627	220500	14053L	PARTICIPANT	\N	PRESENT	0
220628	220500	19545Y	PARTICIPANT	\N	PRESENT	0
220629	220500	19387D	PARTICIPANT	\N	PRESENT	0
220630	220500	14157T	PARTICIPANT	\N	PRESENT	0
220631	220500	08055A	PARTICIPANT	\N	PRESENT	0
220632	220500	14217N	PARTICIPANT	\N	PRESENT	0
220633	220500	14249W	PARTICIPANT	\N	PRESENT	0
220634	220500	19413M	PARTICIPANT	\N	PRESENT	0
220635	220500	11097X	PARTICIPANT	\N	PRESENT	0
220636	220500	14259Y	PARTICIPANT	\N	PRESENT	0
220637	220500	14147R	PARTICIPANT	\N	PRESENT	0
220638	220500	98050T	PARTICIPANT	\N	PRESENT	0
220639	220500	08028W	PARTICIPANT	\N	PRESENT	0
220640	220500	14357A	PARTICIPANT	\N	PRESENT	0
220641	220500	14079W	PARTICIPANT	\N	PRESENT	0
220642	220500	11090Q	PARTICIPANT	\N	PRESENT	0
220643	220500	12041X	PARTICIPANT	\N	PRESENT	0
220644	220500	19347U	PARTICIPANT	\N	PRESENT	0
220645	220500	19703U	PARTICIPANT	\N	PRESENT	0
220646	220500	14191V	PARTICIPANT	\N	PRESENT	0
220647	220500	08034U	PARTICIPANT	\N	PRESENT	0
220648	220500	08015R	PARTICIPANT	\N	PRESENT	0
220649	220500	19687N	PARTICIPANT	\N	PRESENT	0
220650	220500	19695N	PARTICIPANT	\N	PRESENT	0
220651	220500	14213J	PARTICIPANT	\N	PRESENT	0
220652	220500	04044E	PARTICIPANT	\N	PRESENT	0
220653	220500	19563B	PARTICIPANT	\N	PRESENT	0
220654	220500	08011M	PARTICIPANT	\N	PRESENT	0
220655	220500	08019V	PARTICIPANT	\N	PRESENT	0
220656	220500	19727D	PARTICIPANT	\N	PRESENT	0
224794	223290	11103C	PARTICIPANT	\N	PRESENT	0
224795	223290	19577H	PARTICIPANT	\N	PRESENT	0
224796	223290	14355X	PARTICIPANT	\N	EXCUSE	0
224797	223266	14001X	PARTICIPANT	\N	PRESENT	0
224798	223266	19543W	PARTICIPANT	\N	PRESENT	0
224799	223266	19581D	PARTICIPANT	\N	PRESENT	0
224800	223266	04047H	PARTICIPANT	\N	PRESENT	0
224801	223266	19673G	PARTICIPANT	\N	PRESENT	0
224802	223266	01028R	PARTICIPANT	\N	PRESENT	0
224803	223266	19447X	PARTICIPANT	\N	PRESENT	0
224804	223266	05008E	PRESIDENT	0	PRESENT	0
224805	223266	14231L	PARTICIPANT	\N	PRESENT	0
224806	223266	19489J	PARTICIPANT	\N	PRESENT	0
224807	223266	14275Y	PARTICIPANT	\N	PRESENT	0
224808	223266	14041T	PARTICIPANT	\N	PRESENT	0
224809	223266	14147R	PARTICIPANT	\N	PRESENT	0
224810	223266	14151M	PARTICIPANT	\N	PRESENT	0
224811	223266	14215L	PARTICIPANT	\N	PRESENT	0
224812	223266	19483C	PARTICIPANT	\N	PRESENT	0
224813	223266	14259Y	PARTICIPANT	\N	PRESENT	0
224814	223266	11072N	PARTICIPANT	\N	PRESENT	0
224815	223266	14053L	PARTICIPANT	\N	PRESENT	0
224816	223266	14111D	PARTICIPANT	\N	PRESENT	0
224817	223266	19649G	PARTICIPANT	\N	PRESENT	0
224818	223266	14065Q	PARTICIPANT	\N	PRESENT	0
224819	223266	10015M	PARTICIPANT	\N	PRESENT	0
224820	223266	11026G	PARTICIPANT	\N	PRESENT	0
224821	223266	08045X	PARTICIPANT	\N	PRESENT	0
224822	223266	07034Q	PARTICIPANT	\N	PRESENT	0
224823	223266	19253P	PARTICIPANT	\N	PRESENT	0
224824	223266	01024M	PARTICIPANT	\N	PRESENT	0
224825	223266	04038G	PARTICIPANT	\N	PRESENT	0
224826	223266	19719D	PARTICIPANT	\N	PRESENT	0
224827	223266	11033F	PARTICIPANT	\N	PRESENT	0
224828	223266	19725B	PARTICIPANT	\N	PRESENT	0
224829	223266	19729F	PARTICIPANT	\N	PRESENT	0
224830	223266	95063L	PARTICIPANT	\N	PRESENT	0
224831	223266	19629C	PARTICIPANT	\N	PRESENT	0
224832	223266	11085T	PARTICIPANT	\N	PRESENT	0
224833	223266	11049P	PARTICIPANT	\N	PRESENT	0
224834	223266	04008A	PARTICIPANT	\N	PRESENT	0
224835	223266	14021P	PARTICIPANT	\N	PRESENT	0
224836	223266	98035U	PARTICIPANT	\N	PRESENT	0
224837	223266	04044E	PARTICIPANT	\N	EXCUSE	0
224838	222384	19443T	PARTICIPANT	\N	PRESENT	0
224839	222384	95067Q	PARTICIPANT	\N	PRESENT	0
224840	222384	11080N	PARTICIPANT	\N	PRESENT	0
224841	222384	95030B	PARTICIPANT	\N	PRESENT	0
224842	222384	11041F	PARTICIPANT	\N	PRESENT	0
224843	222384	04034C	PARTICIPANT	\N	PRESENT	0
224844	222384	14235Q	PARTICIPANT	\N	PRESENT	0
224845	222384	11027H	PARTICIPANT	\N	PRESENT	0
224846	222384	08058D	PARTICIPANT	\N	PRESENT	0
224847	222384	04042C	PRESIDENT	0	PRESENT	0
224848	222384	11054L	PARTICIPANT	\N	PRESENT	0
224849	222384	19251M	PARTICIPANT	\N	PRESENT	0
224850	222384	11066Q	PARTICIPANT	\N	PRESENT	0
224851	222384	19721W	PARTICIPANT	\N	PRESENT	0
224852	222384	95037J	PARTICIPANT	\N	PRESENT	0
224853	222384	19421M	PARTICIPANT	\N	PRESENT	0
224854	222384	19709B	PARTICIPANT	\N	PRESENT	0
224855	222384	14267Y	PARTICIPANT	\N	PRESENT	0
224856	222384	08049C	PARTICIPANT	\N	PRESENT	0
224857	222384	98050T	PARTICIPANT	\N	PRESENT	0
224858	222384	14211G	PARTICIPANT	\N	PRESENT	0
224859	222384	08047A	PARTICIPANT	\N	PRESENT	0
224860	222384	14255U	PARTICIPANT	\N	PRESENT	0
224870	223254	19515S	PARTICIPANT	\N	PRESENT	0
224871	223254	19565D	PARTICIPANT	\N	PRESENT	0
224872	223254	14357A	PARTICIPANT	\N	PRESENT	0
224873	223254	19441R	PARTICIPANT	\N	PRESENT	0
224874	223254	14081Q	PARTICIPANT	\N	PRESENT	0
224875	223254	80013X	PARTICIPANT	\N	PRESENT	0
224876	223254	19631V	PARTICIPANT	\N	PRESENT	0
224877	223254	08021P	PARTICIPANT	\N	PRESENT	0
224878	223254	11099A	PARTICIPANT	\N	PRESENT	0
224879	223254	08068F	PARTICIPANT	\N	PRESENT	0
224880	223254	04049K	PARTICIPANT	\N	PRESENT	0
224881	223254	19705W	PARTICIPANT	\N	PRESENT	0
224882	223254	19707Y	PARTICIPANT	\N	PRESENT	0
224883	223254	08015R	PARTICIPANT	\N	PRESENT	0
224884	223254	14197C	PARTICIPANT	\N	PRESENT	0
224885	223254	19369B	PARTICIPANT	\N	PRESENT	0
224886	223254	19511N	PARTICIPANT	\N	PRESENT	0
224887	223254	08028W	PARTICIPANT	\N	PRESENT	0
224888	223254	19563B	PARTICIPANT	\N	PRESENT	0
224889	223254	14265W	PARTICIPANT	\N	PRESENT	0
224890	223254	14329V	PARTICIPANT	\N	PRESENT	0
224891	223254	19591F	PARTICIPANT	\N	PRESENT	0
224892	223254	14135M	PARTICIPANT	\N	PRESENT	0
224893	223254	19467C	PARTICIPANT	\N	PRESENT	0
224894	223254	14187A	PARTICIPANT	\N	PRESENT	0
224895	223254	08038Y	PARTICIPANT	\N	PRESENT	0
224896	223254	08062Y	PARTICIPANT	\N	PRESENT	0
224897	223254	19695N	PARTICIPANT	\N	PRESENT	0
224898	223254	14033T	PARTICIPANT	\N	PRESENT	0
224899	223254	11090Q	PRESIDENT	0	PRESENT	0
224900	223254	01025N	PARTICIPANT	\N	PRESENT	0
224901	223254	19269X	PARTICIPANT	\N	PRESENT	0
224902	223254	14205J	PARTICIPANT	\N	PRESENT	0
224903	223254	04088S	PARTICIPANT	\N	PRESENT	0
224904	223254	04089T	PARTICIPANT	\N	PRESENT	0
224905	223254	14115H	PARTICIPANT	\N	PRESENT	0
224906	223254	19507S	PARTICIPANT	\N	PRESENT	0
224907	223254	11101A	PARTICIPANT	\N	PRESENT	0
224908	223254	14207L	PARTICIPANT	\N	PRESENT	0
224909	223254	04043D	PARTICIPANT	\N	PRESENT	0
224910	223254	19619A	PARTICIPANT	\N	PRESENT	0
224911	223254	17589D	PARTICIPANT	\N	PRESENT	0
224912	223254	14257W	PARTICIPANT	\N	PRESENT	0
224913	223254	11056N	PARTICIPANT	\N	EXCUSE	0
225059	223254	14331P	PARTICIPANT	\N	PRESENT	0
225060	223254	89017R	PARTICIPANT	\N	PRESENT	0
225061	223254	11048N	PARTICIPANT	\N	PRESENT	0
225062	223254	01043Q	PARTICIPANT	\N	PRESENT	0
225063	223254	19413M	PARTICIPANT	\N	PRESENT	0
225064	218299	04061F	PARTICIPANT	\N	PRESENT	0
225065	218299	19629C	PARTICIPANT	\N	PRESENT	0
225066	218299	14249W	PARTICIPANT	\N	PRESENT	0
225067	218299	11115U	PARTICIPANT	\N	PRESENT	0
225068	218299	14111D	PARTICIPANT	\N	PRESENT	0
225079	218299	14241N	PARTICIPANT	\N	PRESENT	0
225080	218299	08031R	PARTICIPANT	\N	PRESENT	0
225081	218299	19685L	PARTICIPANT	\N	PRESENT	0
225082	218299	18083K	PARTICIPANT	\N	PRESENT	0
225083	223266	14089Y	PARTICIPANT	\N	PRESENT	0
225084	223266	19585H	PARTICIPANT	\N	PRESENT	0
225085	223266	14179A	PARTICIPANT	\N	PRESENT	0
225086	218299	14109K	PARTICIPANT	\N	PRESENT	0
225087	218299	08073C	PARTICIPANT	\N	PRESENT	0
225088	218299	19713W	PARTICIPANT	\N	PRESENT	0
225089	218299	14073Q	PARTICIPANT	\N	PRESENT	0
237782	237781	08020N	PARTICIPANT	\N	PRESENT	0
237783	237781	08024S	PARTICIPANT	\N	PRESENT	0
237784	237781	10006L	PARTICIPANT	\N	PRESENT	0
237785	237781	11010L	PARTICIPANT	\N	PRESENT	0
237786	237781	14199E	PARTICIPANT	\N	PRESENT	0
237787	237781	11064N	PARTICIPANT	\N	PRESENT	0
237788	237781	98005N	PARTICIPANT	\N	PRESENT	0
237789	237781	01043Q	PARTICIPANT	\N	PRESENT	0
237790	237781	14219Q	PARTICIPANT	\N	PRESENT	0
237791	237781	14001X	PARTICIPANT	\N	PRESENT	0
237792	237781	08053X	PARTICIPANT	\N	PRESENT	0
237793	237781	07034Q	PARTICIPANT	\N	PRESENT	0
237794	237781	04043D	PARTICIPANT	\N	PRESENT	0
237795	237781	01058X	PARTICIPANT	\N	PRESENT	0
237796	237781	14173T	PARTICIPANT	\N	PRESENT	0
238217	238210	96004D	PRESIDENT	0	PRESENT	0
238218	238210	14089Y	PARTICIPANT	\N	PRESENT	0
238219	232951	19717B	PARTICIPANT	\N	PRESENT	0
238220	238210	08014Q	PARTICIPANT	\N	PRESENT	0
238221	238210	14357A	PARTICIPANT	\N	PRESENT	0
238222	232951	14261S	PARTICIPANT	\N	PRESENT	0
238223	238210	08018U	PARTICIPANT	\N	EXCUSE	0
238224	238210	19725B	PARTICIPANT	\N	PRESENT	0
238225	232951	19629C	PARTICIPANT	\N	PRESENT	0
238226	238210	04097T	PARTICIPANT	\N	PRESENT	0
238227	238210	14097Y	PARTICIPANT	\N	PRESENT	0
238228	232951	19253P	PARTICIPANT	\N	PRESENT	0
238229	238210	04061F	PARTICIPANT	\N	PRESENT	0
238230	232951	14121F	PARTICIPANT	\N	PRESENT	0
238231	232951	11027H	PARTICIPANT	\N	PRESENT	0
238232	238210	14061L	PARTICIPANT	\N	EXCUSE	0
238233	238210	14073Q	PARTICIPANT	\N	EXCUSE	0
238234	232951	19583F	PARTICIPANT	\N	PRESENT	0
238235	232951	19585H	PARTICIPANT	\N	PRESENT	0
238236	238210	11026G	PARTICIPANT	\N	PRESENT	0
238237	232951	07029T	PARTICIPANT	\N	PRESENT	0
238238	238210	04057K	PARTICIPANT	\N	PRESENT	0
213352	213351	11053K	PARTICIPANT	\N	PRESENT	0
213353	213351	14159V	PARTICIPANT	\N	PRESENT	0
213354	213351	05012A	PARTICIPANT	\N	PRESENT	0
213381	213380	04040A	PARTICIPANT	\N	PRESENT	0
213382	213380	08058D	PARTICIPANT	\N	PRESENT	0
214483	214482	11049P	PARTICIPANT	\N	PRESENT	0
220476	219909	08069G	PARTICIPANT	\N	PRESENT	0
220477	219909	19689Q	PARTICIPANT	\N	PRESENT	0
220478	219909	19667J	PARTICIPANT	\N	PRESENT	0
220479	219909	89017R	PARTICIPANT	\N	PRESENT	0
220480	219909	08011M	PARTICIPANT	\N	PRESENT	0
220481	219909	19693L	RAPPORTEUR_AVIS	\N	PRESENT	0
220482	219909	19671E	PARTICIPANT	\N	PRESENT	0
220483	219909	11040E	PRESIDENT	1	PRESENT	0
220484	219909	04086Q	PARTICIPANT	\N	PRESENT	0
220485	219909	07029T	PARTICIPANT	\N	PRESENT	0
220486	219909	14083S	PARTICIPANT	\N	PRESENT	0
220487	219909	14051J	RAPPORTEUR_AVIS	\N	PRESENT	0
220488	219909	14199E	PARTICIPANT	\N	PRESENT	0
220489	219909	14277B	PARTICIPANT	\N	PRESENT	0
220490	219909	14121F	PARTICIPANT	\N	PRESENT	0
220491	219909	08010L	PARTICIPANT	\N	PRESENT	0
220492	219909	99004R	PARTICIPANT	\N	PRESENT	0
220493	219909	14123H	RAPPORTEUR_AVIS	\N	PRESENT	0
220494	219909	11048N	PARTICIPANT	\N	PRESENT	0
220495	219909	14327T	PARTICIPANT	\N	EXCUSE	0
220497	218273	19695N	PARTICIPANT	\N	PRESENT	0
220498	218273	14229S	PARTICIPANT	\N	PRESENT	0
220499	218273	14281W	PARTICIPANT	\N	PRESENT	0
220502	218273	11031D	PARTICIPANT	\N	PRESENT	0
220503	219910	14331P	PARTICIPANT	\N	PRESENT	0
220504	219910	07029T	PARTICIPANT	\N	PRESENT	0
220505	219910	95041E	PARTICIPANT	\N	PRESENT	0
220506	219910	19711U	PARTICIPANT	\N	PRESENT	0
220507	219910	19531S	PARTICIPANT	\N	PRESENT	0
220508	219910	11097X	RAPPORTEUR_AVIS	\N	PRESENT	0
220509	219910	14213J	RAPPORTEUR_AVIS	\N	PRESENT	0
220510	219910	19667J	PARTICIPANT	\N	PRESENT	0
220511	219910	08014Q	PARTICIPANT	\N	PRESENT	0
220512	219910	14327T	PARTICIPANT	\N	EXCUSE	0
220513	219910	19689Q	PARTICIPANT	\N	PRESENT	0
220514	219910	11074Q	PRESIDENT	0	PRESENT	0
220524	220500	86034E	PARTICIPANT	\N	PRESENT	0
220516	219910	14173T	PARTICIPANT	\N	PRESENT	0
220517	219910	19479G	PARTICIPANT	\N	PRESENT	0
220518	219910	19671E	PARTICIPANT	\N	PRESENT	0
220519	219910	08010L	PARTICIPANT	\N	PRESENT	0
220529	219910	04086Q	PARTICIPANT	\N	PRESENT	0
220530	219910	01057W	PARTICIPANT	\N	PRESENT	0
220688	220500	04043D	PARTICIPANT	\N	PRESENT	0
220689	220500	04034C	PARTICIPANT	\N	PRESENT	0
220525	219910	11048N	PARTICIPANT	\N	PRESENT	0
220526	219910	08034U	PARTICIPANT	\N	PRESENT	0
220527	219910	08011M	PARTICIPANT	\N	PRESENT	0
220528	219910	14085U	PARTICIPANT	\N	PRESENT	0
220690	220500	19421M	PARTICIPANT	\N	PRESENT	0
220691	220500	08069G	PARTICIPANT	\N	PRESENT	0
220692	220500	14097Y	PARTICIPANT	\N	PRESENT	0
220693	220500	11041F	PARTICIPANT	\N	PRESENT	0
220694	220500	11048N	PARTICIPANT	\N	PRESENT	0
220695	220500	14051J	PARTICIPANT	\N	PRESENT	0
220696	220500	14061L	PARTICIPANT	\N	PRESENT	0
220697	220500	14329V	PARTICIPANT	\N	PRESENT	0
220698	220500	19521Q	PARTICIPANT	\N	PRESENT	0
220699	220500	14038Y	PARTICIPANT	\N	PRESENT	0
220700	220500	19443T	PARTICIPANT	\N	PRESENT	0
220701	220500	14207L	PARTICIPANT	\N	PRESENT	0
220702	220500	08035V	PARTICIPANT	\N	PRESENT	0
220703	220500	05008E	PARTICIPANT	\N	PRESENT	0
220704	220500	14355X	PARTICIPANT	\N	PRESENT	0
220705	220500	11033F	PARTICIPANT	\N	PRESENT	0
220706	220500	14028W	PARTICIPANT	\N	PRESENT	0
220707	220500	19621T	PARTICIPANT	\N	PRESENT	0
220708	220500	19489J	PARTICIPANT	\N	PRESENT	0
220709	220500	19701S	PARTICIPANT	\N	PRESENT	0
220710	220500	14121F	PARTICIPANT	\N	PRESENT	0
220711	220500	92040Q	PARTICIPANT	\N	PRESENT	0
220712	220500	11056N	PARTICIPANT	\N	PRESENT	0
220713	220500	14199E	PARTICIPANT	\N	PRESENT	0
220714	220500	19599P	PARTICIPANT	\N	PRESENT	0
220715	220500	19483C	PARTICIPANT	\N	PRESENT	0
220716	220500	19725B	PARTICIPANT	\N	PRESENT	0
220717	220500	19383Y	PARTICIPANT	\N	PRESENT	0
220718	220500	14001X	PARTICIPANT	\N	PRESENT	0
220719	220500	08012N	PARTICIPANT	\N	PRESENT	0
220720	220500	08043V	PARTICIPANT	\N	PRESENT	0
220721	220500	19675J	PARTICIPANT	\N	PRESENT	0
220722	220500	80027E	PARTICIPANT	\N	PRESENT	0
220723	220500	08017T	PARTICIPANT	\N	PRESENT	0
220724	220500	14063N	PARTICIPANT	\N	PRESENT	0
220725	220500	11104D	PARTICIPANT	\N	PRESENT	0
220726	220500	11049P	PARTICIPANT	\N	PRESENT	0
220727	220500	19549D	PARTICIPANT	\N	PRESENT	0
220728	220500	14109K	PARTICIPANT	\N	PRESENT	0
220729	220500	19649G	PARTICIPANT	\N	PRESENT	0
220730	220500	14115H	PARTICIPANT	\N	PRESENT	0
220731	220500	98029W	PARTICIPANT	\N	PRESENT	0
220732	220500	04061F	PARTICIPANT	\N	PRESENT	0
220733	220500	19349W	PARTICIPANT	\N	PRESENT	0
220734	220500	19679N	PARTICIPANT	\N	PRESENT	0
220735	220500	19637C	PARTICIPANT	\N	PRESENT	0
220736	220500	08021P	PARTICIPANT	\N	PRESENT	0
220737	220500	19697Q	PARTICIPANT	\N	PRESENT	0
220738	220500	95037J	PARTICIPANT	\N	PRESENT	0
220739	220500	19733B	PARTICIPANT	\N	PRESENT	0
220740	220500	19329S	PARTICIPANT	\N	PRESENT	0
220741	220500	01062T	PARTICIPANT	\N	PRESENT	0
220742	220500	19629C	PARTICIPANT	\N	PRESENT	0
220743	220500	17583W	PARTICIPANT	\N	PRESENT	0
220744	220500	19681G	PARTICIPANT	\N	PRESENT	0
220745	220500	98022P	PARTICIPANT	\N	PRESENT	0
220746	220500	19581D	PARTICIPANT	\N	PRESENT	0
220747	220500	08049C	PARTICIPANT	\N	PRESENT	0
220748	220500	04035D	PARTICIPANT	\N	PRESENT	0
220749	220500	19585H	PARTICIPANT	\N	PRESENT	0
220750	220500	98024R	PARTICIPANT	\N	PRESENT	0
220751	220500	14030Q	PARTICIPANT	\N	PRESENT	0
220752	220500	04040A	PARTICIPANT	\N	PRESENT	0
220753	220500	04033B	PARTICIPANT	\N	PRESENT	0
220754	220500	11045K	PARTICIPANT	\N	PRESENT	0
220755	220500	98023Q	PARTICIPANT	\N	PRESENT	0
220756	220500	14255U	PARTICIPANT	\N	PRESENT	0
220757	220500	08044W	PARTICIPANT	\N	PRESENT	0
220758	220500	01034P	PARTICIPANT	\N	PRESENT	0
220759	220500	19573D	PARTICIPANT	\N	PRESENT	0
220760	220500	11070L	PARTICIPANT	\N	PRESENT	0
220761	220500	19611R	PARTICIPANT	\N	PRESENT	0
220762	220500	14029X	PARTICIPANT	\N	PRESENT	0
220763	220500	19511N	PARTICIPANT	\N	PRESENT	0
220764	220500	19709B	PARTICIPANT	\N	PRESENT	0
220765	220500	11085T	PARTICIPANT	\N	PRESENT	0
220766	220500	19663E	PARTICIPANT	\N	PRESENT	0
220767	220500	04088S	PARTICIPANT	\N	PRESENT	0
220768	220500	19619A	PARTICIPANT	\N	PRESENT	0
220769	220500	19713W	PARTICIPANT	\N	PRESENT	0
220770	220500	19723Y	PARTICIPANT	\N	PRESENT	0
220771	220500	19507S	PARTICIPANT	\N	PRESENT	0
220772	220500	11081P	PARTICIPANT	\N	PRESENT	0
220773	220500	19467C	PARTICIPANT	\N	PRESENT	0
220774	220500	19415P	PARTICIPANT	\N	PRESENT	0
220775	220500	04071H	PARTICIPANT	\N	PRESENT	0
220776	220500	16685X	PARTICIPANT	\N	PRESENT	0
220777	220500	14135M	PARTICIPANT	\N	PRESENT	0
220778	220500	05012A	PARTICIPANT	\N	PRESENT	0
220779	220500	01025N	PARTICIPANT	\N	PRESENT	0
220780	220500	11010L	PARTICIPANT	\N	PRESENT	0
220781	220500	11053K	PARTICIPANT	\N	PRESENT	0
220782	220500	14133K	PARTICIPANT	\N	PRESENT	0
220783	220500	14034U	PARTICIPANT	\N	PRESENT	0
220784	220500	14159V	PARTICIPANT	\N	PRESENT	0
220785	220500	19479G	PARTICIPANT	\N	PRESENT	0
220786	220500	19441R	PARTICIPANT	\N	PRESENT	0
220787	220500	14275Y	PARTICIPANT	\N	PRESENT	0
220788	220500	19319Q	PARTICIPANT	\N	PRESENT	0
220789	220500	14267Y	PARTICIPANT	\N	PRESENT	0
220790	220500	14103D	PARTICIPANT	\N	PRESENT	0
220791	220500	14221J	PARTICIPANT	\N	PRESENT	0
220792	220500	19739H	PARTICIPANT	\N	PRESENT	0
220793	220500	19667J	PARTICIPANT	\N	PRESENT	0
220794	220500	19335Q	PARTICIPANT	\N	PRESENT	0
220795	220500	19575F	PARTICIPANT	\N	PRESENT	0
220796	220500	04070G	PARTICIPANT	\N	PRESENT	0
220797	220500	07004J	PARTICIPANT	\N	PRESENT	0
220798	220500	19577H	PARTICIPANT	\N	PRESENT	0
220799	220500	01024M	PARTICIPANT	\N	PRESENT	0
220800	220500	01043Q	PARTICIPANT	\N	PRESENT	0
220801	220500	19657G	PARTICIPANT	\N	PRESENT	0
220802	220500	96004D	PARTICIPANT	\N	PRESENT	0
220803	220500	08056B	PARTICIPANT	\N	PRESENT	0
220806	220500	19399H	PARTICIPANT	\N	PRESENT	0
220805	220500	08018U	PARTICIPANT	\N	PRESENT	0
226344	226343	19591F	PARTICIPANT	\N	PRESENT	0
226345	226343	11054L	PARTICIPANT	\N	PRESENT	0
226352	226349	04040A	PRESIDENT	0	PRESENT	0
226360	226349	14071N	PARTICIPANT	\N	EXCUSE	0
226786	226785	11053K	PARTICIPANT	\N	PRESENT	0
226787	226785	14159V	PARTICIPANT	\N	PRESENT	0
226788	226785	05012A	PARTICIPANT	\N	PRESENT	0
226968	225850	19467C	PARTICIPANT	\N	PRESENT	0
226969	225850	19515S	PARTICIPANT	\N	PRESENT	0
226970	225850	19565D	PARTICIPANT	\N	PRESENT	0
226971	225850	19413M	PARTICIPANT	\N	PRESENT	0
226972	225850	08062Y	PARTICIPANT	\N	PRESENT	0
226973	225850	14033T	PARTICIPANT	\N	PRESENT	0
226974	225850	11090Q	PRESIDENT	0	PRESENT	0
226975	225850	19631V	PARTICIPANT	\N	PRESENT	0
226976	225850	19269X	PARTICIPANT	\N	PRESENT	0
226977	225850	04088S	PARTICIPANT	\N	PRESENT	0
226978	225850	08068F	PARTICIPANT	\N	PRESENT	0
226979	225850	19705W	PARTICIPANT	\N	PRESENT	0
226980	225850	19507S	PARTICIPANT	\N	PRESENT	0
226981	225850	08015R	PARTICIPANT	\N	PRESENT	0
226982	225850	14197C	PARTICIPANT	\N	PRESENT	0
226983	225850	14207L	PARTICIPANT	\N	PRESENT	0
226984	225850	19511N	PARTICIPANT	\N	PRESENT	0
226985	225850	08028W	PARTICIPANT	\N	PRESENT	0
226986	225850	19563B	PARTICIPANT	\N	PRESENT	0
226987	225850	14265W	PARTICIPANT	\N	PRESENT	0
226988	225850	19619A	PARTICIPANT	\N	PRESENT	0
226989	225850	14329V	PARTICIPANT	\N	PRESENT	0
226990	225850	14257W	PARTICIPANT	\N	PRESENT	0
227006	225850	19383Y	PARTICIPANT	\N	PRESENT	0
227007	225850	19707Y	PARTICIPANT	\N	PRESENT	0
227008	225850	14135M	PARTICIPANT	\N	PRESENT	0
227009	225850	14187A	PARTICIPANT	\N	PRESENT	0
227010	225850	11101A	PARTICIPANT	\N	PRESENT	0
227011	225850	11056N	PARTICIPANT	\N	EXCUSE	0
227012	225850	01025N	PARTICIPANT	\N	EXCUSE	0
227013	225850	11081P	PARTICIPANT	\N	EXCUSE	0
227014	225850	08021P	PARTICIPANT	\N	EXCUSE	0
227032	225773	19443T	PARTICIPANT	\N	PRESENT	0
227033	225773	11080N	PARTICIPANT	\N	PRESENT	0
227034	225773	04034C	PARTICIPANT	\N	PRESENT	0
227035	225773	11041F	PARTICIPANT	\N	PRESENT	0
227036	225773	14235Q	PARTICIPANT	\N	PRESENT	0
227037	225773	14079W	PARTICIPANT	\N	PRESENT	0
227038	225773	08058D	PARTICIPANT	\N	PRESENT	0
227039	225773	11066Q	PARTICIPANT	\N	PRESENT	0
227040	225773	14105F	PARTICIPANT	\N	PRESENT	0
227041	225773	95037J	PARTICIPANT	\N	PRESENT	0
227042	225773	14055N	PARTICIPANT	\N	PRESENT	0
227043	225773	98018T	PRESIDENT	0	PRESENT	0
227044	225773	98022P	PARTICIPANT	\N	PRESENT	0
227045	225773	19709B	PARTICIPANT	\N	PRESENT	0
227046	225773	08049C	PARTICIPANT	\N	PRESENT	0
227047	225773	14193X	PARTICIPANT	\N	PRESENT	0
227048	225773	14267Y	PARTICIPANT	\N	PRESENT	0
227049	225773	97011G	PARTICIPANT	\N	PRESENT	0
227050	225773	14211G	PARTICIPANT	\N	PRESENT	0
227051	225773	08047A	PARTICIPANT	\N	PRESENT	0
227052	225773	95030B	PARTICIPANT	\N	PRESENT	0
227053	225773	01058X	PARTICIPANT	\N	PRESENT	0
227054	225773	04040A	PARTICIPANT	\N	PRESENT	0
227097	225773	19669L	PARTICIPANT	\N	PRESENT	0
227098	225773	98050T	PARTICIPANT	\N	PRESENT	0
227099	225773	19421M	PARTICIPANT	\N	PRESENT	0
227100	225773	98005N	PARTICIPANT	\N	PRESENT	0
227108	225773	04035D	PARTICIPANT	\N	PRESENT	0
227109	225773	01062T	PARTICIPANT	\N	PRESENT	0
227110	225773	11064N	PARTICIPANT	\N	PRESENT	0
227111	227030	04070G	PRESIDENT	0	PRESENT	0
227112	227030	19699S	PARTICIPANT	\N	PRESENT	0
227113	227030	19533U	PARTICIPANT	\N	PRESENT	0
227114	227030	14229S	PARTICIPANT	\N	PRESENT	0
227115	227030	14241N	PARTICIPANT	\N	PRESENT	0
227116	227030	14039A	PARTICIPANT	\N	PRESENT	0
227117	227030	14107H	PARTICIPANT	\N	PRESENT	0
227118	227030	08017T	PARTICIPANT	\N	PRESENT	0
227119	227030	07033P	PARTICIPANT	\N	PRESENT	0
227120	227030	08031R	PARTICIPANT	\N	PRESENT	0
227121	227030	19593H	PARTICIPANT	\N	PRESENT	0
227122	227030	14059S	PARTICIPANT	\N	PRESENT	0
227123	227030	19643A	PARTICIPANT	\N	PRESENT	0
227124	227030	14061L	PARTICIPANT	\N	PRESENT	0
227125	227030	04057K	PARTICIPANT	\N	PRESENT	0
227126	227030	14073Q	PARTICIPANT	\N	PRESENT	0
227127	227030	19611R	PARTICIPANT	\N	PRESENT	0
227128	227030	08043V	PARTICIPANT	\N	PRESENT	0
227129	227030	19693L	PARTICIPANT	\N	PRESENT	0
227130	227030	87003B	PARTICIPANT	\N	PRESENT	0
227131	227030	14030Q	PARTICIPANT	\N	PRESENT	0
227132	227030	19731Y	PARTICIPANT	\N	PRESENT	0
227133	227030	08020N	PARTICIPANT	\N	PRESENT	0
227134	227030	11109J	PARTICIPANT	\N	PRESENT	0
227135	227030	11083R	PARTICIPANT	\N	PRESENT	0
227136	227030	14109K	PARTICIPANT	\N	PRESENT	0
227137	227030	14123H	PARTICIPANT	\N	PRESENT	0
227138	227030	11104D	PARTICIPANT	\N	PRESENT	0
227139	227030	04018C	PARTICIPANT	\N	PRESENT	0
227140	227030	95015C	PARTICIPANT	\N	EXCUSE	0
227141	227030	08016S	PARTICIPANT	\N	EXCUSE	0
227142	227030	14201E	PARTICIPANT	\N	EXCUSE	0
227231	218447	01043Q	PARTICIPANT	\N	PRESENT	0
227232	218447	07029T	PARTICIPANT	\N	PRESENT	0
227233	218447	04092N	PARTICIPANT	\N	PRESENT	0
227234	218447	11074Q	PARTICIPANT	\N	PRESENT	0
227235	218447	14281W	PARTICIPANT	\N	PRESENT	0
227236	218447	14225N	PARTICIPANT	\N	PRESENT	0
227237	218447	14121F	PARTICIPANT	\N	PRESENT	0
227238	218447	04045F	PARTICIPANT	\N	PRESENT	0
227239	218447	19563B	PARTICIPANT	\N	PRESENT	0
227240	218447	19651A	PARTICIPANT	\N	PRESENT	0
227241	218447	12016W	PARTICIPANT	\N	PRESENT	0
227242	218447	17779H	PARTICIPANT	\N	PRESENT	0
227243	218447	80013X	PARTICIPANT	\N	PRESENT	0
227244	218447	11064N	PARTICIPANT	\N	PRESENT	0
227245	218447	19691J	PARTICIPANT	\N	PRESENT	0
227246	218447	19369B	PARTICIPANT	\N	PRESENT	0
227247	218447	19695N	PARTICIPANT	\N	PRESENT	0
227248	218447	14179A	PARTICIPANT	\N	PRESENT	0
227249	218447	19713W	PARTICIPANT	\N	PRESENT	0
227250	218447	14103D	PARTICIPANT	\N	PRESENT	0
227251	218447	19671E	PARTICIPANT	\N	PRESENT	0
227252	218447	11056N	PARTICIPANT	\N	PRESENT	0
227253	218447	19565D	PARTICIPANT	\N	PRESENT	0
227254	218447	11097X	PARTICIPANT	\N	PRESENT	0
227255	218447	14253S	PARTICIPANT	\N	PRESENT	0
227256	218447	19729F	PARTICIPANT	\N	PRESENT	0
227257	218447	14223L	PARTICIPANT	\N	PRESENT	0
227258	218447	19711U	PARTICIPANT	\N	PRESENT	0
227259	218447	01057W	PARTICIPANT	\N	PRESENT	0
227260	218447	14119M	PARTICIPANT	\N	PRESENT	0
227261	218447	08019V	PARTICIPANT	\N	PRESENT	0
227262	218447	19667J	PARTICIPANT	\N	PRESENT	0
227263	218447	04088S	PARTICIPANT	\N	PRESENT	0
227264	218447	14029X	PARTICIPANT	\N	PRESENT	0
227265	218447	14197C	PARTICIPANT	\N	PRESENT	0
227266	218447	14207L	PARTICIPANT	\N	PRESENT	0
227267	218447	14265W	PARTICIPANT	\N	PRESENT	0
227268	218447	14357A	PARTICIPANT	\N	PRESENT	0
227269	218447	19349W	PARTICIPANT	\N	PRESENT	0
227270	218447	19657G	PARTICIPANT	\N	PRESENT	0
227271	218447	11070L	PARTICIPANT	\N	PRESENT	0
227272	218447	01062T	PARTICIPANT	\N	PRESENT	0
227273	218447	14219Q	PARTICIPANT	\N	PRESENT	0
227274	218447	08010L	PARTICIPANT	\N	PRESENT	0
227275	218447	11048N	PARTICIPANT	\N	PRESENT	0
227276	218447	19701S	PARTICIPANT	\N	PRESENT	0
227277	218447	11063M	PARTICIPANT	\N	PRESENT	0
227278	218447	14061L	PARTICIPANT	\N	PRESENT	0
227279	218447	19647E	PARTICIPANT	\N	PRESENT	0
227280	218447	19739H	PARTICIPANT	\N	PRESENT	0
227281	218447	14331P	PARTICIPANT	\N	PRESENT	0
227282	218447	19553Y	PARTICIPANT	\N	PRESENT	0
227284	218447	19669L	PARTICIPANT	\N	PRESENT	0
227285	218447	11053K	PARTICIPANT	\N	PRESENT	0
227286	218447	08061X	PARTICIPANT	\N	PRESENT	0
227287	218447	14239U	PARTICIPANT	\N	PRESENT	0
227288	218447	19721W	PARTICIPANT	\N	PRESENT	0
227289	218447	11067R	PARTICIPANT	\N	PRESENT	0
227290	218447	08034U	PARTICIPANT	\N	PRESENT	0
227292	218447	14083S	PARTICIPANT	\N	PRESENT	0
227293	218447	19569H	PARTICIPANT	\N	PRESENT	0
227295	218447	11103C	PARTICIPANT	\N	PRESENT	0
227296	218447	19415P	PARTICIPANT	\N	PRESENT	0
227297	218447	14033T	PARTICIPANT	\N	PRESENT	0
227298	218447	08069G	PARTICIPANT	\N	PRESENT	0
227299	218447	14073Q	PARTICIPANT	\N	PRESENT	0
227300	218447	11045K	PARTICIPANT	\N	PRESENT	0
219076	216548	04035D	PARTICIPANT	\N	EXCUSE	0
219079	216549	04035D	PARTICIPANT	\N	EXCUSE	0
220657	220500	08045X	PARTICIPANT	\N	PRESENT	0
222392	222380	89017R	PARTICIPANT	\N	EXCUSE	0
220319	220317	14231L	PARTICIPANT	\N	EXCUSE	0
220320	220313	04044E	PARTICIPANT	\N	PRESENT	0
220658	220500	08014Q	PARTICIPANT	\N	PRESENT	0
220659	220500	04045F	PARTICIPANT	\N	PRESENT	0
220660	220500	19673G	PARTICIPANT	\N	PRESENT	0
220661	220500	14187A	PARTICIPANT	\N	PRESENT	0
220662	220500	11099A	PARTICIPANT	\N	PRESENT	0
220663	220500	04049K	PARTICIPANT	\N	PRESENT	0
220664	220500	08020N	PARTICIPANT	\N	PRESENT	0
220665	220500	14111D	PARTICIPANT	\N	PRESENT	0
220666	220500	04057K	PARTICIPANT	\N	PRESENT	0
220667	220500	08062Y	PARTICIPANT	\N	PRESENT	0
220668	220500	19301E	PARTICIPANT	\N	PRESENT	0
220669	220500	14119M	PARTICIPANT	\N	PRESENT	0
220670	220500	14253S	PARTICIPANT	\N	PRESENT	0
220671	220500	19705W	PARTICIPANT	\N	PRESENT	0
220672	220500	11063M	PARTICIPANT	\N	PRESENT	0
220673	220500	14215L	PARTICIPANT	\N	PRESENT	0
220674	220500	19565D	PARTICIPANT	\N	PRESENT	0
220675	220500	11040E	PARTICIPANT	\N	PRESENT	0
220676	220500	04038G	PARTICIPANT	\N	PRESENT	0
220677	220500	11077T	PARTICIPANT	\N	PRESENT	0
220678	220500	08047A	PARTICIPANT	\N	PRESENT	0
220679	220500	11074Q	PARTICIPANT	\N	PRESENT	0
220680	220500	14021P	PARTICIPANT	\N	PRESENT	0
220681	220500	14211G	PARTICIPANT	\N	PRESENT	0
220682	220500	19295A	PARTICIPANT	\N	PRESENT	0
220683	220500	14083S	PARTICIPANT	\N	PRESENT	0
220684	220500	19367Y	PARTICIPANT	\N	PRESENT	0
220685	220500	11026G	PARTICIPANT	\N	PRESENT	0
220686	220500	14169X	PARTICIPANT	\N	PRESENT	0
220687	220500	11109J	PARTICIPANT	\N	PRESENT	0
220832	220500	08068F	PARTICIPANT	\N	PRESENT	0
220833	220500	14257W	PARTICIPANT	\N	PRESENT	0
220834	220500	19729F	PARTICIPANT	\N	PRESENT	0
220835	220500	11027H	PARTICIPANT	\N	PRESENT	0
220836	220500	04047H	PARTICIPANT	\N	PRESENT	0
220840	220500	14065Q	PARTICIPANT	\N	PRESENT	0
220838	220500	95067Q	PARTICIPANT	\N	PRESENT	0
220839	220500	14205J	PARTICIPANT	\N	PRESENT	0
220841	220500	14081Q	PARTICIPANT	\N	PRESENT	0
220842	220500	08038Y	PARTICIPANT	\N	PRESENT	0
220843	220500	19643A	PARTICIPANT	\N	PRESENT	0
220844	220500	17637T	PARTICIPANT	\N	PRESENT	0
220845	220500	19289C	PARTICIPANT	\N	PRESENT	0
220846	220500	12016W	PARTICIPANT	\N	PRESENT	0
220847	220500	19543W	PARTICIPANT	\N	PRESENT	0
220848	220500	19269X	PARTICIPANT	\N	PRESENT	0
220849	220500	14327T	PARTICIPANT	\N	PRESENT	0
220850	219916	14327T	PARTICIPANT	\N	PRESENT	0
220851	219916	11048N	PARTICIPANT	\N	PRESENT	0
220852	219916	19711U	PARTICIPANT	\N	PRESENT	0
220853	219916	95041E	PARTICIPANT	\N	PRESENT	0
220854	219916	08034U	PARTICIPANT	\N	PRESENT	0
220855	219916	19531S	PARTICIPANT	\N	PRESENT	0
220856	219916	01057W	PARTICIPANT	\N	PRESENT	0
220857	219916	19687N	PARTICIPANT	\N	PRESENT	0
220858	219916	19667J	PARTICIPANT	\N	PRESENT	0
220859	219916	11074Q	PRESIDENT	0	PRESENT	0
220860	219916	08011M	PARTICIPANT	\N	PRESENT	0
220861	219916	19671E	PARTICIPANT	\N	PRESENT	0
220862	219916	14225N	PARTICIPANT	\N	PRESENT	0
220863	219916	88008L	PARTICIPANT	\N	PRESENT	0
220864	219916	14173T	PARTICIPANT	\N	PRESENT	0
220865	219916	14083S	PARTICIPANT	\N	PRESENT	0
220866	219916	07004J	PARTICIPANT	\N	PRESENT	0
220867	219916	19349W	PARTICIPANT	\N	PRESENT	0
220868	219916	08010L	PARTICIPANT	\N	PRESENT	0
220869	219916	99004R	PARTICIPANT	\N	PRESENT	0
220870	220500	14033T	PARTICIPANT	\N	PRESENT	0
220872	219916	14085U	PARTICIPANT	\N	PRESENT	0
220873	220500	95015C	PARTICIPANT	\N	PRESENT	0
221194	218274	01043Q	PARTICIPANT	\N	PRESENT	0
221195	218274	04070G	PARTICIPANT	\N	PRESENT	0
221196	218274	04042C	PARTICIPANT	\N	PRESENT	0
221197	218274	01028R	PARTICIPANT	\N	PRESENT	0
221198	218274	04034C	PARTICIPANT	\N	PRESENT	0
221199	218274	08039A	PARTICIPANT	\N	PRESENT	0
221200	218274	11027H	PARTICIPANT	\N	PRESENT	0
221201	218274	14235Q	PARTICIPANT	\N	PRESENT	0
221202	218274	08020N	PARTICIPANT	\N	PRESENT	0
221203	218274	19347U	PARTICIPANT	\N	PRESENT	0
221204	218274	19533U	PARTICIPANT	\N	PRESENT	0
221205	218274	11054L	PARTICIPANT	\N	PRESENT	0
221206	218274	19251M	PARTICIPANT	\N	PRESENT	0
221207	218274	95015C	PARTICIPANT	\N	PRESENT	0
221208	218274	14063N	PARTICIPANT	\N	PRESENT	0
221209	218274	04035D	PARTICIPANT	\N	PRESENT	0
221210	218274	14028W	PARTICIPANT	\N	PRESENT	0
221211	218274	08058D	PARTICIPANT	\N	PRESENT	0
221480	218275	14223L	PARTICIPANT	\N	PRESENT	0
221213	218274	08017T	PARTICIPANT	\N	PRESENT	0
221214	218274	14051J	PARTICIPANT	\N	PRESENT	0
221478	218275	19657G	PARTICIPANT	\N	PRESENT	0
221216	218274	14097Y	PARTICIPANT	\N	PRESENT	0
221217	218274	14031R	PARTICIPANT	\N	PRESENT	0
221218	218274	11041F	PARTICIPANT	\N	PRESENT	0
221219	218274	19693L	PARTICIPANT	\N	PRESENT	0
221220	218274	11026G	PARTICIPANT	\N	PRESENT	0
221239	218274	19713W	PARTICIPANT	\N	PRESENT	0
221222	218274	14038Y	PARTICIPANT	\N	PRESENT	0
221223	218274	19467C	PARTICIPANT	\N	PRESENT	0
221224	218274	11083R	PARTICIPANT	\N	PRESENT	0
221225	218274	95037J	PARTICIPANT	\N	PRESENT	0
221226	218274	19573D	PARTICIPANT	\N	PRESENT	0
221227	218274	04057K	PARTICIPANT	\N	PRESENT	0
221228	218274	19443T	PARTICIPANT	\N	PRESENT	0
221229	218274	19545Y	PARTICIPANT	\N	PRESENT	0
221230	218274	95030B	PARTICIPANT	\N	PRESENT	0
221237	218274	19319Q	PARTICIPANT	\N	PRESENT	0
221232	218274	19731Y	PARTICIPANT	\N	PRESENT	0
221233	218274	19681G	PARTICIPANT	\N	PRESENT	0
221234	218274	19583F	PARTICIPANT	\N	PRESENT	0
221235	218274	14109K	PARTICIPANT	\N	PRESENT	0
221236	218274	19705W	PARTICIPANT	\N	PRESENT	0
221238	218274	19399H	PARTICIPANT	\N	PRESENT	0
221240	218274	14042U	PARTICIPANT	\N	PRESENT	0
221241	218274	19643A	PARTICIPANT	\N	PRESENT	0
221242	218274	14219Q	PARTICIPANT	\N	PRESENT	0
221243	218274	16685X	PARTICIPANT	\N	PRESENT	0
221244	218274	19737F	PARTICIPANT	\N	PRESENT	0
221245	219916	11070L	PARTICIPANT	\N	PRESENT	0
221246	219916	07029T	PARTICIPANT	\N	PRESENT	0
221247	219916	19689Q	PARTICIPANT	\N	PRESENT	0
221248	219916	08014Q	PARTICIPANT	\N	PRESENT	0
221249	219916	04086Q	PARTICIPANT	\N	PRESENT	0
221250	219916	14121F	PARTICIPANT	\N	PRESENT	0
221251	219916	04061F	PARTICIPANT	\N	PRESENT	0
221252	218274	19691J	PARTICIPANT	\N	PRESENT	0
221253	218274	08031R	PARTICIPANT	\N	PRESENT	0
221254	218274	14030Q	PARTICIPANT	\N	PRESENT	0
221255	218274	14255U	PARTICIPANT	\N	PRESENT	0
221256	218274	14073Q	PARTICIPANT	\N	PRESENT	0
221257	218274	19735D	PARTICIPANT	\N	PRESENT	0
221258	218274	19581D	PARTICIPANT	\N	PRESENT	0
221479	218275	19515S	PARTICIPANT	\N	PRESENT	0
221481	218275	04061F	PARTICIPANT	\N	PRESENT	0
221482	218275	14257W	PARTICIPANT	\N	PRESENT	0
221483	218275	14081Q	PARTICIPANT	\N	PRESENT	0
221484	218275	19637C	PARTICIPANT	\N	PRESENT	0
221485	218275	19689Q	PARTICIPANT	\N	PRESENT	0
221486	218275	95030B	PARTICIPANT	\N	PRESENT	0
221487	218275	19543W	PARTICIPANT	\N	PRESENT	0
221488	218275	19695N	PARTICIPANT	\N	PRESENT	0
221489	218275	19687N	PARTICIPANT	\N	PRESENT	0
221490	218275	19737F	PARTICIPANT	\N	PRESENT	0
221491	218275	11099A	PARTICIPANT	\N	PRESENT	0
221492	218275	01043Q	PARTICIPANT	\N	PRESENT	0
221493	218275	11048N	PARTICIPANT	\N	PRESENT	0
221494	218275	14069U	PARTICIPANT	\N	PRESENT	0
221495	218275	14241N	PARTICIPANT	\N	PRESENT	0
221496	218275	88008L	PARTICIPANT	\N	PRESENT	0
221497	218275	11056N	PARTICIPANT	\N	PRESENT	0
221498	218275	19467C	PARTICIPANT	\N	PRESENT	0
221499	218275	19565D	PARTICIPANT	\N	PRESENT	0
221500	218275	11090Q	PARTICIPANT	\N	PRESENT	0
221501	218275	14033T	PARTICIPANT	\N	PRESENT	0
221502	218275	14217N	PARTICIPANT	\N	PRESENT	0
221503	218275	14083S	PARTICIPANT	\N	PRESENT	0
221504	218275	01025N	PARTICIPANT	\N	PRESENT	0
221505	218275	19415P	PARTICIPANT	\N	PRESENT	0
221506	218275	04008A	PARTICIPANT	\N	PRESENT	0
222391	222380	04049K	PRESIDENT	0	PRESENT	0
222393	222380	14261S	PARTICIPANT	\N	EXCUSE	0
222394	222380	19575F	PARTICIPANT	\N	PRESENT	0
211468	210100	19443T	PARTICIPANT	\N	PRESENT	0
211469	210100	95030B	PARTICIPANT	\N	PRESENT	0
211470	210100	11080N	PARTICIPANT	\N	PRESENT	0
211471	210100	04034C	PARTICIPANT	\N	PRESENT	0
211472	210100	04040A	PARTICIPANT	\N	PRESENT	0
211473	210100	01058X	PARTICIPANT	\N	PRESENT	0
211474	210100	14079W	PARTICIPANT	\N	PRESENT	0
211475	210100	11027H	PARTICIPANT	\N	PRESENT	0
211476	210100	16685X	PARTICIPANT	\N	PRESENT	0
211477	210100	04042C	PRESIDENT	0	PRESENT	0
211478	210100	11054L	PARTICIPANT	\N	PRESENT	0
211479	210100	11066Q	PARTICIPANT	\N	PRESENT	0
211480	210100	19669L	PARTICIPANT	\N	PRESENT	0
211481	210100	08056B	PARTICIPANT	\N	PRESENT	0
211482	210100	95037J	PARTICIPANT	\N	PRESENT	0
211483	210100	14055N	PARTICIPANT	\N	PRESENT	0
211484	210100	19421M	PARTICIPANT	\N	PRESENT	0
211485	210100	19709B	PARTICIPANT	\N	PRESENT	0
211486	210100	14193X	PRESIDENT	1	PRESENT	0
211487	210100	08049C	PARTICIPANT	\N	PRESENT	0
211488	210100	08053X	PARTICIPANT	\N	PRESENT	0
211489	210100	97011G	PARTICIPANT	\N	PRESENT	0
211490	210100	08061X	PARTICIPANT	\N	PRESENT	0
211491	210100	08047A	PARTICIPANT	\N	PRESENT	0
211492	210100	98029W	PARTICIPANT	\N	PRESENT	0
211493	210100	14097Y	PARTICIPANT	\N	PRESENT	0
211494	210100	04035D	PARTICIPANT	\N	PRESENT	0
211495	210100	95067Q	PARTICIPANT	\N	PRESENT	0
211496	210100	01062T	PARTICIPANT	\N	PRESENT	0
211497	210100	11041F	PARTICIPANT	\N	PRESENT	0
211498	210100	14235Q	PARTICIPANT	\N	PRESENT	0
211499	210100	08058D	PARTICIPANT	\N	PRESENT	0
211500	210100	19251M	PARTICIPANT	\N	PRESENT	0
211501	210100	14028W	PARTICIPANT	\N	PRESENT	0
211502	210100	19721W	PARTICIPANT	\N	PRESENT	0
211503	210100	19319Q	PARTICIPANT	\N	PRESENT	0
211504	210100	14105F	PARTICIPANT	\N	PRESENT	0
211505	210100	98022P	PARTICIPANT	\N	PRESENT	0
211506	210100	11064N	PARTICIPANT	\N	PRESENT	0
211507	210100	14267Y	PARTICIPANT	\N	PRESENT	0
211508	210100	98050T	PARTICIPANT	\N	PRESENT	0
211509	210100	14211G	PARTICIPANT	\N	PRESENT	0
211510	210100	14255U	PARTICIPANT	\N	PRESENT	0
238241	238210	19593H	PARTICIPANT	\N	EXCUSE	0
238242	238210	14237S	PARTICIPANT	\N	PRESENT	0
238243	232951	19575F	PARTICIPANT	\N	PRESENT	0
238244	238210	14135M	PARTICIPANT	\N	PRESENT	0
238245	238210	14331P	PARTICIPANT	\N	PRESENT	0
238246	232951	10015M	PARTICIPANT	\N	PRESENT	0
238247	238210	14225N	PARTICIPANT	\N	PRESENT	0
238248	232951	04018C	PARTICIPANT	\N	PRESENT	0
238249	232951	11026G	PARTICIPANT	\N	PRESENT	0
238250	232951	04047H	PARTICIPANT	\N	PRESENT	0
238251	232951	07004J	PARTICIPANT	\N	PRESENT	0
238252	238210	98018T	PARTICIPANT	\N	PRESENT	0
238253	232951	19747H	PARTICIPANT	\N	PRESENT	0
238254	238210	11066Q	PARTICIPANT	\N	PRESENT	0
238255	232951	19581D	PARTICIPANT	\N	PRESENT	0
238256	238210	08058D	PARTICIPANT	\N	PRESENT	0
238257	238210	08061X	PARTICIPANT	\N	PRESENT	0
238258	232951	14111D	PARTICIPANT	\N	PRESENT	0
238259	238210	01062T	PARTICIPANT	\N	PRESENT	0
238260	232951	19667J	PARTICIPANT	\N	PRESENT	0
238261	238210	19583F	PARTICIPANT	\N	PRESENT	0
238262	238210	19251M	PARTICIPANT	\N	PRESENT	0
238239	238210	19563B	PARTICIPANT	\N	PRESENT	0
238240	232951	19711U	PARTICIPANT	\N	PRESENT	0
238263	238210	04040A	PARTICIPANT	\N	PRESENT	0
238264	238210	14255U	PARTICIPANT	\N	PRESENT	0
238265	238210	16685X	PARTICIPANT	\N	PRESENT	0
238266	238210	01058X	PARTICIPANT	\N	PRESENT	0
238267	238210	19443T	PARTICIPANT	\N	PRESENT	0
238268	238210	14105F	PARTICIPANT	\N	PRESENT	0
238269	238210	98050T	PARTICIPANT	\N	PRESENT	0
238270	238210	19709B	PARTICIPANT	\N	PRESENT	0
238271	232951	11033F	PARTICIPANT	\N	PRESENT	0
238272	232951	01024M	PARTICIPANT	\N	PRESENT	0
238273	232951	19683J	PARTICIPANT	\N	PRESENT	0
238274	232951	19563B	PARTICIPANT	\N	PRESENT	0
238288	232951	19731Y	PARTICIPANT	\N	PRESENT	0
238289	232951	19447X	PARTICIPANT	\N	PRESENT	0
238290	232951	19673G	PARTICIPANT	\N	PRESENT	0
238303	232951	19549D	PARTICIPANT	\N	PRESENT	0
238304	232951	14157T	PARTICIPANT	\N	PRESENT	0
238305	232951	08019V	PARTICIPANT	\N	PRESENT	0
238306	232951	14215L	PARTICIPANT	\N	PRESENT	0
238307	232951	11012A	PARTICIPANT	\N	PRESENT	0
238308	232951	14089Y	PARTICIPANT	\N	PRESENT	0
238309	232951	14229S	PARTICIPANT	\N	PRESENT	0
238312	232951	19651A	PARTICIPANT	\N	PRESENT	0
238313	232951	98050T	PARTICIPANT	\N	PRESENT	0
238314	232951	04085P	PARTICIPANT	\N	PRESENT	0
238315	232951	19649G	PARTICIPANT	\N	PRESENT	0
238328	232951	01028R	PARTICIPANT	\N	PRESENT	0
238329	232951	14069U	PARTICIPANT	\N	PRESENT	0
238330	232951	19695N	PARTICIPANT	\N	PRESENT	0
238331	233553	19737F	PARTICIPANT	\N	PRESENT	0
238332	233553	08024S	PARTICIPANT	\N	PRESENT	0
238333	232951	14213J	PARTICIPANT	\N	PRESENT	0
238334	232951	14030Q	PARTICIPANT	\N	PRESENT	0
238335	232951	11067R	PARTICIPANT	\N	PRESENT	0
238336	232951	19703U	PARTICIPANT	\N	PRESENT	0
238337	232951	19269X	PARTICIPANT	\N	PRESENT	0
238567	232952	14213J	PARTICIPANT	\N	PRESENT	0
238568	232952	11054L	PARTICIPANT	\N	PRESENT	0
238569	232952	19593H	PARTICIPANT	\N	PRESENT	0
238570	232952	10006L	PARTICIPANT	\N	PRESENT	0
238571	232952	08052W	PARTICIPANT	\N	PRESENT	0
238572	232952	19483C	PARTICIPANT	\N	PRESENT	0
238573	232952	19697Q	PARTICIPANT	\N	PRESENT	0
238574	232952	19553Y	PARTICIPANT	\N	PRESENT	0
238575	232952	19691J	PARTICIPANT	\N	PRESENT	0
238576	232952	11031D	PARTICIPANT	\N	PRESENT	0
238581	238577	19511N	PARTICIPANT	\N	PRESENT	0
238579	238577	08012N	PARTICIPANT	\N	PRESENT	0
238580	238577	08055A	PARTICIPANT	\N	PRESENT	0
238582	238577	19525U	PARTICIPANT	\N	PRESENT	0
238583	238577	92040Q	PARTICIPANT	\N	PRESENT	0
238584	232952	04086Q	PARTICIPANT	\N	PRESENT	0
238585	232952	14083S	PARTICIPANT	\N	PRESENT	0
238587	232952	11064N	PARTICIPANT	\N	PRESENT	0
238590	238589	08031R	PARTICIPANT	\N	PRESENT	0
238592	238589	14261S	PARTICIPANT	\N	PRESENT	0
238593	238589	11040E	PARTICIPANT	\N	PRESENT	0
238594	238589	14255U	PARTICIPANT	\N	PRESENT	0
238595	238589	19629C	PARTICIPANT	\N	PRESENT	0
238596	238589	19681G	PARTICIPANT	\N	PRESENT	0
238430	238428	14028W	PARTICIPANT	\N	PRESENT	0
238431	238428	95067Q	PARTICIPANT	\N	PRESENT	0
238433	238432	14028W	PARTICIPANT	\N	PRESENT	0
238434	238432	95067Q	PARTICIPANT	\N	PRESENT	0
238436	238435	14028W	PARTICIPANT	\N	PRESENT	0
238437	238435	95067Q	PARTICIPANT	\N	PRESENT	0
238597	238589	02002K	PARTICIPANT	\N	PRESENT	0
238598	238589	14081Q	PARTICIPANT	\N	PRESENT	0
238599	238589	95037J	PARTICIPANT	\N	PRESENT	0
238600	238589	19569H	PARTICIPANT	\N	PRESENT	0
238601	238589	80027E	PARTICIPANT	\N	PRESENT	0
238604	232952	19657G	PARTICIPANT	\N	PRESENT	0
238611	238610	19663E	PARTICIPANT	\N	PRESENT	0
238628	232547	19569H	PARTICIPANT	\N	EXCUSE	0
238629	232547	11097X	PARTICIPANT	\N	PRESENT	0
238659	238658	14133K	PARTICIPANT	\N	PRESENT	0
238565	232952	04044E	PARTICIPANT	\N	PRESENT	0
238566	232952	19711U	PARTICIPANT	\N	PRESENT	0
238660	238658	98022P	PARTICIPANT	\N	PRESENT	0
238661	232547	08012N	PARTICIPANT	\N	EXCUSE	0
238663	238662	04008A	PARTICIPANT	\N	PRESENT	0
238664	238662	14089Y	PARTICIPANT	\N	PRESENT	0
238665	238662	19253P	PARTICIPANT	\N	PRESENT	0
238666	238662	19649G	PARTICIPANT	\N	PRESENT	0
238667	238662	11049P	PARTICIPANT	\N	PRESENT	0
238669	238662	19585H	PARTICIPANT	\N	PRESENT	0
238670	238662	05008E	PARTICIPANT	\N	PRESENT	0
218998	217573	08048B	PARTICIPANT	\N	EXCUSE	0
217913	217911	14071N	PARTICIPANT	\N	PRESENT	0
220807	220500	19533U	PARTICIPANT	\N	PRESENT	0
220808	220500	14089Y	PARTICIPANT	\N	PRESENT	0
220809	220500	14251Q	PARTICIPANT	\N	PRESENT	0
220810	220500	14239U	PARTICIPANT	\N	PRESENT	0
220811	220500	14229S	PARTICIPANT	\N	PRESENT	0
220812	220500	14151M	PARTICIPANT	\N	PRESENT	0
220813	220500	14241N	PARTICIPANT	\N	PRESENT	0
220814	220500	19699S	PARTICIPANT	\N	PRESENT	0
220815	220500	14237S	PARTICIPANT	\N	PRESENT	0
220816	220500	04059M	PARTICIPANT	\N	PRESENT	0
220817	220500	14123H	PARTICIPANT	\N	PRESENT	0
220818	220500	14197C	PARTICIPANT	\N	PRESENT	0
220822	220500	08009T	PARTICIPANT	\N	PRESENT	0
220820	220500	14031R	PARTICIPANT	\N	PRESENT	0
220821	220500	11065P	PARTICIPANT	\N	PRESENT	0
220823	220500	19735D	PARTICIPANT	\N	PRESENT	0
220824	220500	11115U	PARTICIPANT	\N	PRESENT	0
220825	220500	19447X	PARTICIPANT	\N	PRESENT	0
220826	220500	19677L	PARTICIPANT	\N	PRESENT	0
220827	220500	19591F	PARTICIPANT	\N	PRESENT	0
220828	220500	89017R	PARTICIPANT	\N	PRESENT	0
220829	220500	19369B	PARTICIPANT	\N	PRESENT	0
220830	220500	04042C	PARTICIPANT	\N	PRESENT	0
220831	220500	04089T	PARTICIPANT	\N	PRESENT	0
221259	220238	19515S	PARTICIPANT	\N	PRESENT	0
221260	220238	19565D	PARTICIPANT	\N	PRESENT	0
221261	220238	14357A	PARTICIPANT	\N	PRESENT	0
221262	220238	19441R	PARTICIPANT	\N	PRESENT	0
221263	220238	19631V	PARTICIPANT	\N	PRESENT	0
221264	220238	08021P	PARTICIPANT	\N	PRESENT	0
221265	220238	11099A	PARTICIPANT	\N	PRESENT	0
221266	220238	04049K	PARTICIPANT	\N	PRESENT	0
221267	220238	08015R	PARTICIPANT	\N	PRESENT	0
221268	220238	14197C	PARTICIPANT	\N	PRESENT	0
221269	220238	19369B	PARTICIPANT	\N	PRESENT	0
221270	220238	19511N	PARTICIPANT	\N	PRESENT	0
221271	220238	08028W	PARTICIPANT	\N	PRESENT	0
221272	220238	11081P	PARTICIPANT	\N	PRESENT	0
221273	220238	19563B	PARTICIPANT	\N	PRESENT	0
221274	220238	14265W	PARTICIPANT	\N	PRESENT	0
221275	220238	14329V	PARTICIPANT	\N	PRESENT	0
221276	220238	08062Y	PARTICIPANT	\N	PRESENT	0
221277	220238	19695N	PARTICIPANT	\N	PRESENT	0
221278	220238	14033T	PARTICIPANT	\N	PRESENT	0
221279	220238	11090Q	PRESIDENT	0	PRESENT	0
221280	220238	01025N	PARTICIPANT	\N	PRESENT	0
221281	220238	04088S	PARTICIPANT	\N	PRESENT	0
221282	220238	11056N	PARTICIPANT	\N	PRESENT	0
221283	220238	14115H	PARTICIPANT	\N	PRESENT	0
221284	220238	19507S	PARTICIPANT	\N	PRESENT	0
221285	220238	14207L	PARTICIPANT	\N	PRESENT	0
221286	220238	17589D	PARTICIPANT	\N	PRESENT	0
221287	220238	14257W	PARTICIPANT	\N	PRESENT	0
221288	218274	98018T	PARTICIPANT	\N	PRESENT	0
221289	218274	19447X	PARTICIPANT	\N	PRESENT	0
221290	218274	19553Y	PARTICIPANT	\N	PRESENT	0
221291	219745	19527W	PARTICIPANT	\N	PRESENT	0
221292	219745	19697Q	PARTICIPANT	\N	PRESENT	0
221293	219745	11067R	PARTICIPANT	\N	PRESENT	0
221294	219745	04092N	PRESIDENT	0	PRESENT	0
221295	219745	14355X	PARTICIPANT	\N	PRESENT	0
221296	219745	19569H	PARTICIPANT	\N	PRESENT	0
221297	219745	11097X	PRESIDENT	1	PRESENT	0
221298	219745	08052W	PARTICIPANT	\N	PRESENT	0
221299	219745	19663E	PARTICIPANT	\N	PRESENT	0
221300	219745	19715Y	PARTICIPANT	\N	PRESENT	0
221301	219745	04045F	PARTICIPANT	\N	PRESENT	0
221302	219745	14223L	PARTICIPANT	\N	PRESENT	0
221303	219745	19703U	PARTICIPANT	\N	PRESENT	0
221304	219745	19727D	PARTICIPANT	\N	PRESENT	0
221305	219745	14281W	PARTICIPANT	\N	PRESENT	0
221306	219745	14195A	PARTICIPANT	\N	PRESENT	0
221307	219745	14213J	PARTICIPANT	\N	PRESENT	0
221308	219745	19657G	PARTICIPANT	\N	PRESENT	0
221309	219745	14217N	PARTICIPANT	\N	PRESENT	0
221310	219745	10006L	PARTICIPANT	\N	PRESENT	0
221311	218274	19593H	PARTICIPANT	\N	PRESENT	0
221312	218274	04018C	PARTICIPANT	\N	PRESENT	0
221313	218274	14041T	PARTICIPANT	\N	PRESENT	0
221314	219745	19679N	PARTICIPANT	\N	PRESENT	0
221315	219745	14071N	PARTICIPANT	\N	PRESENT	0
221316	218274	14249W	PARTICIPANT	\N	PRESENT	0
221317	219745	14087W	PARTICIPANT	\N	PRESENT	0
221318	219745	08048B	PARTICIPANT	\N	EXCUSE	0
221319	219745	19575F	PARTICIPANT	\N	PRESENT	0
221320	219745	19521Q	PARTICIPANT	\N	PRESENT	0
221321	219916	14034U	PARTICIPANT	\N	PRESENT	0
221322	218274	04097T	PARTICIPANT	\N	PRESENT	0
221323	218274	08016S	PARTICIPANT	\N	PRESENT	0
221324	218274	11104D	PARTICIPANT	\N	PRESENT	0
221325	218274	11110B	PARTICIPANT	\N	PRESENT	0
221328	218274	98022P	PARTICIPANT	\N	PRESENT	0
221329	218274	19335Q	PARTICIPANT	\N	PRESENT	0
221330	218274	11049P	PARTICIPANT	\N	PRESENT	0
221331	218274	14061L	PARTICIPANT	\N	PRESENT	0
221332	218274	14079W	PARTICIPANT	\N	PRESENT	0
221333	219745	19415P	PARTICIPANT	\N	PRESENT	0
221334	219745	14026U	PARTICIPANT	\N	PRESENT	0
221335	219745	19553Y	PARTICIPANT	\N	PRESENT	0
221336	219745	14042U	PARTICIPANT	\N	PRESENT	0
221337	219745	11045K	PARTICIPANT	\N	PRESENT	0
221338	219745	08041T	PARTICIPANT	\N	PRESENT	0
221339	219745	19723Y	PARTICIPANT	\N	PRESENT	0
221340	218274	97011G	PARTICIPANT	\N	PRESENT	0
221341	218274	19611R	PARTICIPANT	\N	PRESENT	0
221342	220238	19413M	PARTICIPANT	\N	PRESENT	0
221343	220238	18083K	PARTICIPANT	\N	PRESENT	0
221344	220238	08068F	PARTICIPANT	\N	PRESENT	0
221345	220238	14039A	PARTICIPANT	\N	PRESENT	0
221346	220238	14135M	PARTICIPANT	\N	PRESENT	0
221347	220238	19467C	PARTICIPANT	\N	PRESENT	0
221348	220238	19269X	PARTICIPANT	\N	PRESENT	0
221349	220238	14205J	PARTICIPANT	\N	PRESENT	0
221350	220238	04089T	PARTICIPANT	\N	PRESENT	0
221351	220238	19619A	PARTICIPANT	\N	PRESENT	0
221352	220238	08038Y	PARTICIPANT	\N	PRESENT	0
221355	218274	19709B	PARTICIPANT	\N	PRESENT	0
221356	218274	14223L	PARTICIPANT	\N	PRESENT	0
221357	220238	19383Y	PARTICIPANT	\N	PRESENT	0
221358	218274	19707Y	PARTICIPANT	\N	PRESENT	0
221359	218274	17637T	PARTICIPANT	\N	PRESENT	0
221360	219916	19545Y	PARTICIPANT	\N	PRESENT	0
221361	219916	14199E	PARTICIPANT	\N	PRESENT	0
221362	218274	17583W	PARTICIPANT	\N	PRESENT	0
221363	218274	14241N	PARTICIPANT	\N	PRESENT	0
221366	218274	19585H	PARTICIPANT	\N	PRESENT	0
221369	218274	19367Y	PARTICIPANT	\N	PRESENT	0
221370	218274	04089T	PARTICIPANT	\N	PRESENT	0
221371	218274	19591F	PARTICIPANT	\N	PRESENT	0
221372	218274	14147R	PARTICIPANT	\N	PRESENT	0
221373	218274	11066Q	PARTICIPANT	\N	PRESENT	0
221374	218274	19695N	PARTICIPANT	\N	PRESENT	0
221375	218274	19515S	PARTICIPANT	\N	PRESENT	0
221376	218274	14265W	PARTICIPANT	\N	PRESENT	0
221377	218274	11099A	PARTICIPANT	\N	PRESENT	0
221378	218274	04086Q	PARTICIPANT	\N	PRESENT	0
500868	500279	14179A	PARTICIPANT	\N	PRESENT	0
500869	500279	19573D	PARTICIPANT	\N	PRESENT	0
500874	500279	19719D	PARTICIPANT	\N	PRESENT	0
500877	500279	19347U	PARTICIPANT	\N	PRESENT	0
500878	500279	19575F	PARTICIPANT	\N	PRESENT	0
500879	500279	14109K	PARTICIPANT	\N	PRESENT	0
226171	225830	11048N	PARTICIPANT	\N	PRESENT	0
226172	218306	19503N	PARTICIPANT	\N	PRESENT	0
226173	218306	19737F	PARTICIPANT	\N	PRESENT	0
226174	218306	08009T	PARTICIPANT	\N	PRESENT	0
226175	218306	19711U	PARTICIPANT	\N	PRESENT	0
226176	218306	14031R	PARTICIPANT	\N	PRESENT	0
226177	218306	19549D	PARTICIPANT	\N	PRESENT	0
226178	218306	19637C	PARTICIPANT	\N	PRESENT	0
226179	218306	04061F	PARTICIPANT	\N	PRESENT	0
226180	218306	19681G	PARTICIPANT	\N	PRESENT	0
226181	218306	04018C	PARTICIPANT	\N	PRESENT	0
226182	218306	11053K	PARTICIPANT	\N	PRESENT	0
226183	218306	11048N	PARTICIPANT	\N	PRESENT	0
226184	218306	04085P	PARTICIPANT	\N	PRESENT	0
226185	218306	19347U	PARTICIPANT	\N	PRESENT	0
226186	218306	11074Q	PARTICIPANT	\N	PRESENT	0
226187	218306	19689Q	PARTICIPANT	\N	PRESENT	0
226188	218306	80013X	PARTICIPANT	\N	PRESENT	0
226189	218306	14221J	PARTICIPANT	\N	PRESENT	0
226190	218306	14241N	PARTICIPANT	\N	PRESENT	0
226191	218306	11097X	PARTICIPANT	\N	PRESENT	0
226192	218306	14157T	PARTICIPANT	\N	PRESENT	0
226193	218306	11090Q	PARTICIPANT	\N	PRESENT	0
226194	218306	98023Q	PARTICIPANT	\N	PRESENT	0
226195	218306	14093U	PARTICIPANT	\N	PRESENT	0
226196	218306	11065P	PARTICIPANT	\N	PRESENT	0
226197	218306	14041T	PARTICIPANT	\N	PRESENT	0
226200	218306	04043D	PARTICIPANT	\N	PRESENT	0
226201	218306	14357A	PARTICIPANT	\N	PRESENT	0
226202	218306	98050T	PARTICIPANT	\N	PRESENT	0
226203	218306	08034U	PARTICIPANT	\N	PRESENT	0
226204	218306	18083K	PARTICIPANT	\N	PRESENT	0
226205	218306	08024S	PARTICIPANT	\N	PRESENT	0
226206	218306	19543W	PARTICIPANT	\N	PRESENT	0
226207	218306	19695N	PARTICIPANT	\N	PRESENT	0
226208	218306	88008L	PARTICIPANT	\N	PRESENT	0
226209	218306	19649G	PARTICIPANT	\N	PRESENT	0
226210	218306	14253S	PARTICIPANT	\N	PRESENT	0
227301	218447	14071N	PARTICIPANT	\N	PRESENT	0
227304	218447	14063N	PARTICIPANT	\N	PRESENT	0
227305	218447	18083K	PARTICIPANT	\N	PRESENT	0
227306	218447	14213J	PARTICIPANT	\N	PRESENT	0
227307	218447	19685L	PARTICIPANT	\N	PRESENT	0
227308	218447	19335Q	PARTICIPANT	\N	PRESENT	0
227309	218447	19687N	PARTICIPANT	\N	PRESENT	0
227310	218447	14205J	PARTICIPANT	\N	PRESENT	0
227312	218447	19367Y	PARTICIPANT	\N	PRESENT	0
227313	218447	19733B	PARTICIPANT	\N	PRESENT	0
227314	218447	11109J	PARTICIPANT	\N	PRESENT	0
227315	218447	14042U	PARTICIPANT	\N	PRESENT	0
227316	218447	08056B	PARTICIPANT	\N	PRESENT	0
227317	218447	19545Y	PARTICIPANT	\N	PRESENT	0
227318	218447	01034P	PARTICIPANT	\N	PRESENT	0
227319	227030	14249W	PARTICIPANT	\N	PRESENT	0
227320	227030	04059M	PARTICIPANT	\N	PRESENT	0
227322	218447	14085U	PARTICIPANT	\N	PRESENT	0
227374	218447	14026U	PARTICIPANT	\N	PRESENT	0
227375	218447	19679N	PARTICIPANT	\N	PRESENT	0
227376	218447	19515S	PARTICIPANT	\N	PRESENT	0
227377	218447	19681G	PARTICIPANT	\N	PRESENT	0
227378	218447	04059M	PARTICIPANT	\N	PRESENT	0
227379	218447	14241N	PARTICIPANT	\N	PRESENT	0
227380	218447	14261S	PARTICIPANT	\N	PRESENT	0
227381	218447	19387D	PARTICIPANT	\N	PRESENT	0
227382	218447	11012A	PARTICIPANT	\N	PRESENT	0
227383	218447	19441R	PARTICIPANT	\N	PRESENT	0
227384	218447	19479G	PARTICIPANT	\N	PRESENT	0
227386	218447	14059S	PARTICIPANT	\N	PRESENT	0
227390	218447	19533U	PARTICIPANT	\N	PRESENT	0
227397	218447	08044W	PARTICIPANT	\N	PRESENT	0
227398	218447	14135M	PARTICIPANT	\N	PRESENT	0
227399	218447	14031R	PARTICIPANT	\N	PRESENT	0
227401	218447	08015R	PARTICIPANT	\N	PRESENT	0
227402	218447	14195A	PARTICIPANT	\N	PRESENT	0
227403	218447	14038Y	PARTICIPANT	\N	PRESENT	0
227404	218447	08038Y	PARTICIPANT	\N	PRESENT	0
227405	218447	19413M	PARTICIPANT	\N	PRESENT	0
227406	218447	04086Q	PARTICIPANT	\N	PRESENT	0
227407	218447	14109K	PARTICIPANT	\N	PRESENT	0
227408	218447	08068F	PARTICIPANT	\N	PRESENT	0
227409	218447	95062K	PARTICIPANT	\N	PRESENT	0
227410	218447	14211G	PARTICIPANT	\N	PRESENT	0
227411	218447	14257W	PARTICIPANT	\N	PRESENT	0
227414	218447	19703U	PARTICIPANT	\N	PRESENT	0
227415	218447	89017R	PARTICIPANT	\N	PRESENT	0
227418	218447	10006L	PARTICIPANT	\N	PRESENT	0
227419	218447	17589D	PARTICIPANT	\N	PRESENT	0
227420	218447	01048V	PARTICIPANT	\N	PRESENT	0
227421	225976	11085T	PARTICIPANT	\N	PRESENT	0
227422	225976	14089Y	PARTICIPANT	\N	PRESENT	0
227423	225976	04008A	PARTICIPANT	\N	PRESENT	0
227424	218447	19521Q	PARTICIPANT	\N	PRESENT	0
229925	227827	04061F	PARTICIPANT	\N	PRESENT	0
233288	233287	14255U	PARTICIPANT	\N	PRESENT	0
235124	232943	19383Y	PARTICIPANT	\N	PRESENT	0
235125	232943	14147R	PARTICIPANT	\N	PRESENT	0
235126	232943	14265W	PARTICIPANT	\N	PRESENT	0
235127	232943	19667J	PARTICIPANT	\N	PRESENT	0
235128	232943	19443T	PARTICIPANT	\N	PRESENT	0
235129	232943	01024M	PARTICIPANT	\N	PRESENT	0
235130	232943	14179A	PARTICIPANT	\N	PRESENT	0
235131	232943	14069U	PARTICIPANT	\N	PRESENT	0
235132	232943	19531S	PARTICIPANT	\N	PRESENT	0
235133	232943	08012N	PARTICIPANT	\N	PRESENT	0
235134	233330	04070G	PRESIDENT	0	PRESENT	0
235135	233330	19699S	PARTICIPANT	\N	PRESENT	0
235136	233330	12041X	PARTICIPANT	\N	PRESENT	0
235137	233330	19533U	PARTICIPANT	\N	PRESENT	0
235138	233330	95015C	PARTICIPANT	\N	PRESENT	0
235139	233330	14229S	PARTICIPANT	\N	PRESENT	0
235140	233330	19573D	PARTICIPANT	\N	PRESENT	0
235141	233330	14039A	PARTICIPANT	\N	PRESENT	0
235142	233330	14107H	PARTICIPANT	\N	PRESENT	0
235143	233330	08017T	PARTICIPANT	\N	PRESENT	0
235144	233330	14249W	PARTICIPANT	\N	PRESENT	0
235145	233330	08039A	PARTICIPANT	\N	PRESENT	0
235146	233330	08031R	PARTICIPANT	\N	PRESENT	0
235147	233330	19593H	PARTICIPANT	\N	PRESENT	0
235148	233330	14061L	PARTICIPANT	\N	PRESENT	0
235149	233330	04057K	PARTICIPANT	\N	PRESENT	0
235150	233330	19611R	PARTICIPANT	\N	PRESENT	0
235151	233330	08043V	PARTICIPANT	\N	PRESENT	0
235152	233330	14030Q	PARTICIPANT	\N	PRESENT	0
235153	233330	19731Y	PARTICIPANT	\N	PRESENT	0
235154	233330	11109J	PARTICIPANT	\N	PRESENT	0
235155	233330	14109K	PARTICIPANT	\N	PRESENT	0
235156	233330	14123H	PARTICIPANT	\N	PRESENT	0
235157	233330	11043H	PARTICIPANT	\N	PRESENT	0
235158	233330	11104D	PARTICIPANT	\N	PRESENT	0
235159	233330	19749K	PARTICIPANT	\N	PRESENT	0
235160	233330	04018C	PARTICIPANT	\N	PRESENT	0
235161	233330	14241N	PARTICIPANT	\N	EXCUSE	0
235162	233330	19693L	PARTICIPANT	\N	EXCUSE	0
235163	232943	08028W	PARTICIPANT	\N	PRESENT	0
235164	232943	19731Y	PARTICIPANT	\N	PRESENT	0
235165	232943	16685X	PARTICIPANT	\N	PRESENT	0
235166	232943	14030Q	PARTICIPANT	\N	PRESENT	0
235167	232943	14061L	PARTICIPANT	\N	PRESENT	0
235168	232943	97011G	PARTICIPANT	\N	PRESENT	0
235171	232943	19575F	PARTICIPANT	\N	PRESENT	0
235183	232943	19511N	PARTICIPANT	\N	PRESENT	0
237566	237565	10006L	PARTICIPANT	\N	PRESENT	0
237567	237565	19553Y	PARTICIPANT	\N	PRESENT	0
237568	237565	14063N	PARTICIPANT	\N	PRESENT	0
237569	237565	11048N	PARTICIPANT	\N	PRESENT	0
237570	237565	14059S	PARTICIPANT	\N	PRESENT	0
239563	238872	19333N	PARTICIPANT	\N	PRESENT	0
239564	238872	17583W	PARTICIPANT	\N	PRESENT	0
239565	238872	19549D	PARTICIPANT	\N	PRESENT	0
239566	238872	95062K	PARTICIPANT	\N	PRESENT	0
239567	238872	19387D	PARTICIPANT	\N	PRESENT	0
239568	238872	14219Q	PARTICIPANT	\N	PRESENT	0
239569	238872	14221J	PARTICIPANT	\N	PRESENT	0
239570	238872	19637C	PARTICIPANT	\N	PRESENT	0
239571	238872	18083K	PARTICIPANT	\N	PRESENT	0
239572	238872	14237S	PARTICIPANT	\N	PRESENT	0
239573	238872	19551W	PARTICIPANT	\N	PRESENT	0
239574	238872	80027E	PARTICIPANT	\N	PRESENT	0
239575	238872	05012A	PARTICIPANT	\N	PRESENT	0
239576	238872	14051J	PARTICIPANT	\N	PRESENT	0
239577	238872	08060W	PARTICIPANT	\N	PRESENT	0
239578	238872	19503N	PARTICIPANT	\N	PRESENT	0
239579	238872	19347U	PARTICIPANT	\N	PRESENT	0
239580	238872	14157T	PARTICIPANT	\N	PRESENT	0
239581	238872	19685L	PARTICIPANT	\N	PRESENT	0
239582	238872	08024S	PARTICIPANT	\N	PRESENT	0
239583	238872	98023Q	PARTICIPANT	\N	PRESENT	0
239584	238872	19525U	PARTICIPANT	\N	PRESENT	0
239585	238872	14038Y	PARTICIPANT	\N	PRESENT	0
211828	207688	04038G	PARTICIPANT	\N	PRESENT	0
211829	207688	19347U	PARTICIPANT	\N	PRESENT	0
211795	210622	04070G	PRESIDENT	0	PRESENT	0
211796	210622	19699S	PARTICIPANT	\N	PRESENT	0
211797	210622	12041X	PARTICIPANT	\N	PRESENT	0
211798	210622	19533U	PARTICIPANT	\N	PRESENT	0
211799	210622	95015C	PARTICIPANT	\N	PRESENT	0
211800	210622	14229S	PARTICIPANT	\N	PRESENT	0
211801	210622	14241N	PARTICIPANT	\N	PRESENT	0
211802	210622	19573D	PARTICIPANT	\N	PRESENT	0
211803	210622	14107H	PARTICIPANT	\N	PRESENT	0
211804	210622	08012N	PARTICIPANT	\N	PRESENT	0
211805	210622	14249W	PARTICIPANT	\N	PRESENT	0
211806	210622	08039A	PARTICIPANT	\N	PRESENT	0
211807	210622	08031R	PARTICIPANT	\N	PRESENT	0
211808	210622	19643A	PARTICIPANT	\N	PRESENT	0
211809	210622	14059S	PARTICIPANT	\N	PRESENT	0
211810	210622	14061L	PARTICIPANT	\N	PRESENT	0
211811	210622	04057K	PARTICIPANT	\N	PRESENT	0
211812	210622	14073Q	PARTICIPANT	\N	PRESENT	0
211813	210622	19611R	PARTICIPANT	\N	PRESENT	0
211814	210622	08043V	PARTICIPANT	\N	PRESENT	0
211815	210622	87003B	PARTICIPANT	\N	PRESENT	0
211816	210622	14030Q	PARTICIPANT	\N	PRESENT	0
211817	210622	19731Y	PARTICIPANT	\N	PRESENT	0
211818	210622	08020N	PARTICIPANT	\N	PRESENT	0
211819	210622	04059M	PARTICIPANT	\N	PRESENT	0
211820	210622	19735D	PARTICIPANT	\N	PRESENT	0
211821	210622	11083R	PARTICIPANT	\N	PRESENT	0
211822	210622	14063N	PARTICIPANT	\N	PRESENT	0
211823	210622	14123H	PARTICIPANT	\N	PRESENT	0
211824	210622	04018C	PARTICIPANT	\N	PRESENT	0
211825	210622	19621T	PARTICIPANT	\N	PRESENT	0
211826	210622	19693L	PARTICIPANT	\N	EXCUSE	0
211827	207688	14034U	PARTICIPANT	\N	PRESENT	0
211830	207688	14169X	PARTICIPANT	\N	PRESENT	0
211831	207688	08009T	PARTICIPANT	\N	PRESENT	0
211832	207688	14051J	PARTICIPANT	\N	PRESENT	0
211833	207688	19503N	PARTICIPANT	\N	PRESENT	0
211834	207688	19333N	PARTICIPANT	\N	PRESENT	0
211835	207688	08024S	PARTICIPANT	\N	PRESENT	0
211836	207688	08055A	PARTICIPANT	\N	PRESENT	0
211837	207688	19525U	PARTICIPANT	\N	PRESENT	0
211838	207688	80027E	PARTICIPANT	\N	PRESENT	0
211839	207688	14097Y	PARTICIPANT	\N	PRESENT	0
211840	207688	19599P	PARTICIPANT	\N	PRESENT	0
211841	207688	19637C	PARTICIPANT	\N	PRESENT	0
211842	207688	19349W	PARTICIPANT	\N	PRESENT	0
211843	207688	19551W	PARTICIPANT	\N	PRESENT	0
211844	207688	19659J	PARTICIPANT	\N	PRESENT	0
211845	207688	98022P	PARTICIPANT	\N	PRESENT	0
211861	207688	19367Y	PARTICIPANT	\N	PRESENT	0
211847	207688	19387D	PARTICIPANT	\N	PRESENT	0
211848	207688	02002K	PARTICIPANT	\N	PRESENT	0
211849	207688	19681G	PARTICIPANT	\N	PRESENT	0
211850	207688	08049C	PARTICIPANT	\N	PRESENT	0
211851	207688	19737F	PARTICIPANT	\N	PRESENT	0
211852	207688	19441R	PARTICIPANT	\N	PRESENT	0
211853	207688	14103D	PARTICIPANT	\N	PRESENT	0
211854	207688	14221J	PARTICIPANT	\N	PRESENT	0
211855	207688	14107H	PARTICIPANT	\N	PRESENT	0
211856	207688	14121F	PARTICIPANT	\N	PRESENT	0
211857	207688	14111D	PARTICIPANT	\N	PRESENT	0
211858	207688	14028W	PARTICIPANT	\N	PRESENT	0
211859	207688	14231L	PARTICIPANT	\N	PRESENT	0
211860	207688	19629C	PARTICIPANT	\N	PRESENT	0
211862	207688	14219Q	PARTICIPANT	\N	PRESENT	0
211863	207688	14083S	PARTICIPANT	\N	PRESENT	0
211864	207688	99004R	PARTICIPANT	\N	PRESENT	0
211865	207688	14187A	PARTICIPANT	\N	PRESENT	0
211866	207688	14053L	PARTICIPANT	\N	PRESENT	0
211867	207688	05012A	PARTICIPANT	\N	PRESENT	0
211868	207688	97011G	PARTICIPANT	\N	PRESENT	0
211869	207688	14357A	PARTICIPANT	\N	PRESENT	0
211870	207688	19733B	PARTICIPANT	\N	PRESENT	0
211871	207688	08020N	PARTICIPANT	\N	PRESENT	0
211872	207688	11048N	PARTICIPANT	\N	PRESENT	0
211873	207688	14147R	PARTICIPANT	\N	PRESENT	0
211874	207688	14105F	PARTICIPANT	\N	PRESENT	0
211875	207688	14265W	PARTICIPANT	\N	PRESENT	0
211876	207688	08062Y	PARTICIPANT	\N	PRESENT	0
211877	207688	19483C	PARTICIPANT	\N	PRESENT	0
211878	207688	95062K	PARTICIPANT	\N	PRESENT	0
211879	207688	17637T	PARTICIPANT	\N	PRESENT	0
211880	207688	19679N	PARTICIPANT	\N	PRESENT	0
211881	207688	08043V	PARTICIPANT	\N	PRESENT	0
211882	207688	15447F	PARTICIPANT	\N	PRESENT	0
211883	207688	01057W	PARTICIPANT	\N	PRESENT	0
211884	207688	14119M	PARTICIPANT	\N	PRESENT	0
211885	207688	14031R	PARTICIPANT	\N	PRESENT	0
211886	207688	18083K	PARTICIPANT	\N	PRESENT	0
211887	207688	14033T	PARTICIPANT	\N	PRESENT	0
211888	207688	19415P	PARTICIPANT	\N	PRESENT	0
211889	207688	14029X	PARTICIPANT	\N	PRESENT	0
211890	207688	19573D	PARTICIPANT	\N	PRESENT	0
211891	207688	19447X	PARTICIPANT	\N	PRESENT	0
211892	207688	14191V	PARTICIPANT	\N	PRESENT	0
211893	207688	14261S	PARTICIPANT	\N	PRESENT	0
211894	207688	11012A	PARTICIPANT	\N	PRESENT	0
211895	207688	08039A	PARTICIPANT	\N	PRESENT	0
211896	207688	14229S	PARTICIPANT	\N	PRESENT	0
211897	207688	11097X	PARTICIPANT	\N	PRESENT	0
211898	207688	14030Q	PARTICIPANT	\N	PRESENT	0
211899	207688	01058X	PARTICIPANT	\N	PRESENT	0
211900	207688	01048V	PARTICIPANT	\N	PRESENT	0
211901	207688	04085P	PARTICIPANT	\N	PRESENT	0
211902	207688	14235Q	PARTICIPANT	\N	PRESENT	0
211903	207688	11101A	PARTICIPANT	\N	PRESENT	0
211904	207688	01043Q	PARTICIPANT	\N	PRESENT	0
211905	207688	14195A	PARTICIPANT	\N	PRESENT	0
211906	207688	14241N	PARTICIPANT	\N	PRESENT	0
211907	207688	19725B	PARTICIPANT	\N	PRESENT	0
211908	207688	19709B	PARTICIPANT	\N	PRESENT	0
211909	207688	14059S	PARTICIPANT	\N	PRESENT	0
211910	207688	14223L	PARTICIPANT	\N	PRESENT	0
211911	207688	14026U	PARTICIPANT	\N	PRESENT	0
211912	207688	19713W	PARTICIPANT	\N	PRESENT	0
211913	207688	08061X	PARTICIPANT	\N	PRESENT	0
211914	207688	14327T	PARTICIPANT	\N	PRESENT	0
211915	207688	19631V	PARTICIPANT	\N	PRESENT	0
211916	207688	88008L	PARTICIPANT	\N	PRESENT	0
214780	213291	19593H	PARTICIPANT	\N	PRESENT	0
217451	217450	19577H	PARTICIPANT	\N	PRESENT	0
217453	217452	14071N	PARTICIPANT	\N	PRESENT	0
217720	217581	01048V	PARTICIPANT	\N	PRESENT	0
217463	217462	04061F	PARTICIPANT	\N	PRESENT	0
217464	217460	04061F	PARTICIPANT	\N	PRESENT	0
217468	217467	11053K	PARTICIPANT	\N	PRESENT	0
217721	217581	19531S	PARTICIPANT	\N	PRESENT	0
217722	217581	11053K	PARTICIPANT	\N	PRESENT	0
217723	217581	19667J	PARTICIPANT	\N	PRESENT	0
217724	217581	08011M	PARTICIPANT	\N	PRESENT	0
217725	217581	14034U	PARTICIPANT	\N	PRESENT	0
217726	217581	07029T	PARTICIPANT	\N	PRESENT	0
217727	217581	08069G	PARTICIPANT	\N	PRESENT	0
217728	217581	07004J	PARTICIPANT	\N	EXCUSE	0
217731	217581	14331P	PARTICIPANT	\N	PRESENT	0
217732	217581	08034U	PARTICIPANT	\N	PRESENT	0
217733	217581	14083S	PARTICIPANT	\N	PRESENT	0
217734	217581	19349W	PARTICIPANT	\N	PRESENT	0
217735	217581	14071N	RAPPORTEUR_AVIS	\N	PRESENT	0
217736	217581	11048N	PARTICIPANT	\N	PRESENT	0
217785	217572	19697Q	PARTICIPANT	\N	PRESENT	0
217786	217572	11067R	PARTICIPANT	\N	PRESENT	0
217787	217572	14355X	PARTICIPANT	\N	PRESENT	0
217788	217572	11097X	PARTICIPANT	\N	PRESENT	0
217789	217572	19415P	PARTICIPANT	\N	PRESENT	0
217790	217572	04045F	PARTICIPANT	\N	PRESENT	0
217791	217572	14223L	PARTICIPANT	\N	PRESENT	0
217792	217572	14227Q	PARTICIPANT	\N	PRESENT	0
217793	217572	17779H	PARTICIPANT	\N	PRESENT	0
217794	217572	19703U	PARTICIPANT	\N	PRESENT	0
217795	217572	19553Y	PARTICIPANT	\N	PRESENT	0
217796	217572	14239U	PARTICIPANT	\N	PRESENT	0
217797	217572	14042U	PARTICIPANT	\N	PRESENT	0
217798	217572	14195A	PARTICIPANT	\N	PRESENT	0
217799	217572	19367Y	PARTICIPANT	\N	PRESENT	0
217800	217572	14213J	PARTICIPANT	\N	PRESENT	0
217801	217572	14261S	PARTICIPANT	\N	PRESENT	0
217802	217572	14217N	PARTICIPANT	\N	PRESENT	0
217803	217572	19683J	PARTICIPANT	\N	PRESENT	0
217804	217572	98024R	PARTICIPANT	\N	PRESENT	0
217805	217572	01034P	PARTICIPANT	\N	PRESENT	0
217806	217572	04092N	PRESIDENT	0	PRESENT	0
217807	217572	08052W	PARTICIPANT	\N	PRESENT	0
217808	217572	19663E	PARTICIPANT	\N	PRESENT	0
217809	217572	08041T	PARTICIPANT	\N	PRESENT	0
217810	217572	19727D	PARTICIPANT	\N	PRESENT	0
230190	230189	98018T	PARTICIPANT	\N	PRESENT	0
230191	230189	14267Y	PARTICIPANT	\N	PRESENT	0
235324	233205	14038Y	PARTICIPANT	\N	PRESENT	0
235325	233205	19713W	PARTICIPANT	\N	PRESENT	0
235326	233205	14031R	PARTICIPANT	\N	PRESENT	0
235327	233205	19549D	PARTICIPANT	\N	PRESENT	0
235328	233205	14219Q	PARTICIPANT	\N	PRESENT	0
235329	233205	14221J	PARTICIPANT	\N	PRESENT	0
235330	233205	14169X	PARTICIPANT	\N	PRESENT	0
235331	233205	19637C	PARTICIPANT	\N	PRESENT	0
235332	233205	18083K	PARTICIPANT	\N	PRESENT	0
235333	233205	14237S	PARTICIPANT	\N	PRESENT	0
235334	233205	19551W	PARTICIPANT	\N	PRESENT	0
235335	233205	05012A	PARTICIPANT	\N	PRESENT	0
235336	233205	14093U	PARTICIPANT	\N	PRESENT	0
235337	233205	14051J	PARTICIPANT	\N	PRESENT	0
235338	233205	08060W	PARTICIPANT	\N	PRESENT	0
235339	233205	08009T	PRESIDENT	0	PRESENT	0
235340	233205	19347U	PARTICIPANT	\N	PRESENT	0
235341	233205	19503N	PARTICIPANT	\N	PRESENT	0
235342	233205	19737F	PARTICIPANT	\N	PRESENT	0
235343	233205	04097T	PARTICIPANT	\N	PRESENT	0
235344	233205	19739H	PARTICIPANT	\N	PRESENT	0
235345	233205	14157T	PARTICIPANT	\N	PRESENT	0
235346	233205	08024S	PARTICIPANT	\N	PRESENT	0
235347	233205	17637T	PARTICIPANT	\N	PRESENT	0
235348	233205	17583W	PARTICIPANT	\N	EXCUSE	0
235349	233205	19599P	PARTICIPANT	\N	EXCUSE	0
238695	238694	04008A	PARTICIPANT	\N	PRESENT	0
238696	238694	14089Y	PARTICIPANT	\N	PRESENT	0
238697	238694	19253P	PARTICIPANT	\N	PRESENT	0
238698	238694	19649G	PARTICIPANT	\N	PRESENT	0
238699	238694	11049P	PARTICIPANT	\N	PRESENT	0
238700	238694	19585H	PARTICIPANT	\N	PRESENT	0
238741	238740	04040A	PARTICIPANT	\N	PRESENT	0
238742	238740	08010L	PARTICIPANT	\N	PRESENT	0
238743	238740	08017T	PARTICIPANT	\N	PRESENT	0
238744	238740	04057K	PARTICIPANT	\N	PRESENT	0
238745	238740	92040Q	PARTICIPANT	\N	PRESENT	0
238746	238740	19565D	PARTICIPANT	\N	PRESENT	0
238747	238740	19709B	PARTICIPANT	\N	PRESENT	0
238748	238740	19503N	PARTICIPANT	\N	PRESENT	0
238749	238740	19515S	PARTICIPANT	\N	PRESENT	0
238750	238740	19575F	PARTICIPANT	\N	PRESENT	0
238751	238740	14065Q	PARTICIPANT	\N	PRESENT	0
238752	238740	14105F	PARTICIPANT	\N	PRESENT	0
238753	238740	14179A	PARTICIPANT	\N	PRESENT	0
238754	238740	04097T	PARTICIPANT	\N	PRESENT	0
238755	238740	19533U	PARTICIPANT	\N	PRESENT	0
238756	238740	95067Q	PARTICIPANT	\N	PRESENT	0
238757	238740	14061L	PARTICIPANT	\N	PRESENT	0
238758	232547	19515S	PARTICIPANT	\N	EXCUSE	0
238766	232547	01028R	PARTICIPANT	\N	EXCUSE	0
238785	238784	14193X	PARTICIPANT	\N	PRESENT	0
238786	238784	95067Q	PARTICIPANT	\N	PRESENT	0
238792	238791	08024S	PARTICIPANT	\N	PRESENT	0
238793	238791	14038Y	PARTICIPANT	\N	PRESENT	0
238794	238791	19295A	PARTICIPANT	\N	PRESENT	0
238795	238791	11027H	PARTICIPANT	\N	PRESENT	0
238796	238791	19695N	PARTICIPANT	\N	PRESENT	0
238797	238791	19441R	PARTICIPANT	\N	PRESENT	0
238883	238881	14083S	PARTICIPANT	\N	PRESENT	0
238884	238881	14199E	PARTICIPANT	\N	PRESENT	0
238885	238881	19565D	PARTICIPANT	\N	PRESENT	0
238886	238881	19511N	PARTICIPANT	\N	PRESENT	0
238887	238881	19611R	PARTICIPANT	\N	PRESENT	0
238888	238881	08034U	PARTICIPANT	\N	PRESENT	0
238889	238881	19729F	PARTICIPANT	\N	PRESENT	0
238890	238881	92040Q	PARTICIPANT	\N	PRESENT	0
238891	238881	14169X	PARTICIPANT	\N	PRESENT	0
238892	238881	04018C	PARTICIPANT	\N	PRESENT	0
238893	238881	19415P	PARTICIPANT	\N	PRESENT	0
238894	232954	19551W	PARTICIPANT	\N	PRESENT	0
239414	239412	19563B	PARTICIPANT	\N	PRESENT	0
239415	239412	19387D	PARTICIPANT	\N	PRESENT	0
239416	239412	08043V	PARTICIPANT	\N	PRESENT	0
239417	239412	98022P	PARTICIPANT	\N	PRESENT	0
239656	238605	98053W	PARTICIPANT	\N	EXCUSE	0
239657	238605	19583F	PARTICIPANT	\N	EXCUSE	0
239658	238605	08049C	PARTICIPANT	\N	EXCUSE	0
239659	238869	01043Q	PARTICIPANT	\N	EXCUSE	0
239660	238869	14135M	PARTICIPANT	\N	EXCUSE	0
239661	238869	08021P	PARTICIPANT	\N	EXCUSE	0
239662	238869	19619A	PARTICIPANT	\N	EXCUSE	0
239663	238869	11081P	PARTICIPANT	\N	EXCUSE	0
239665	238869	11101A	PARTICIPANT	\N	EXCUSE	0
239740	232547	19651A	PARTICIPANT	\N	EXCUSE	0
239741	232547	08069G	PARTICIPANT	\N	EXCUSE	0
239743	239742	14255U	PARTICIPANT	\N	PRESENT	0
239744	239742	19701S	PARTICIPANT	\N	PRESENT	0
239745	239742	14281W	PARTICIPANT	\N	PRESENT	0
239746	239742	11049P	PARTICIPANT	\N	PRESENT	0
239747	239742	07034Q	PARTICIPANT	\N	PRESENT	0
239754	232547	11065P	PARTICIPANT	\N	EXCUSE	0
239767	238562	14195A	PARTICIPANT	\N	EXCUSE	0
240019	232547	11115U	PARTICIPANT	\N	EXCUSE	0
240030	238780	89017R	PARTICIPANT	\N	PRESENT	0
240031	238780	19651A	PARTICIPANT	\N	PRESENT	0
240032	238780	19741B	PARTICIPANT	\N	PRESENT	0
240033	238780	11040E	PARTICIPANT	\N	PRESENT	0
240034	238780	08014Q	PARTICIPANT	\N	PRESENT	0
240035	238780	14083S	PARTICIPANT	\N	PRESENT	0
240036	238780	11053K	PARTICIPANT	\N	PRESENT	0
240037	238780	19545Y	PARTICIPANT	\N	PRESENT	0
240038	238780	14085U	PARTICIPANT	\N	PRESENT	0
240039	238780	88008L	PARTICIPANT	\N	PRESENT	0
240040	238780	04086Q	PARTICIPANT	\N	PRESENT	0
240041	238780	04071H	PARTICIPANT	\N	PRESENT	0
240043	238780	11074Q	PRESIDENT	0	PRESENT	0
240044	238780	19647E	PARTICIPANT	\N	PRESENT	0
240045	238780	14034U	PARTICIPANT	\N	PRESENT	0
240046	238780	11110B	PARTICIPANT	\N	PRESENT	0
240047	238780	14199E	PARTICIPANT	\N	PRESENT	0
240048	238780	07004J	PARTICIPANT	\N	PRESENT	0
240049	238780	01057W	PARTICIPANT	\N	PRESENT	0
240050	238780	11048N	PARTICIPANT	\N	PRESENT	0
240051	238780	14121F	PARTICIPANT	\N	PRESENT	0
240052	238780	99004R	PARTICIPANT	\N	PRESENT	0
240053	238780	04061F	PARTICIPANT	\N	PRESENT	0
240054	238780	14159V	PARTICIPANT	\N	PRESENT	0
240055	238780	07029T	PARTICIPANT	\N	PRESENT	0
240057	238780	14277B	PARTICIPANT	\N	PRESENT	0
240058	238780	19711U	PARTICIPANT	\N	PRESENT	0
240059	238780	08010L	PARTICIPANT	\N	PRESENT	0
240060	238780	08034U	PARTICIPANT	\N	PRESENT	0
240061	238780	01048V	PARTICIPANT	\N	PRESENT	0
240062	238780	08011M	PARTICIPANT	\N	PRESENT	0
240185	240184	10015M	PARTICIPANT	\N	PRESENT	0
240186	240184	01028R	PARTICIPANT	\N	PRESENT	0
240187	240184	19483C	PARTICIPANT	\N	PRESENT	0
240188	240184	19581D	PARTICIPANT	\N	PRESENT	0
240189	240184	14147R	PARTICIPANT	\N	PRESENT	0
240190	240184	05008E	PARTICIPANT	\N	PRESENT	0
240191	240184	04047H	PARTICIPANT	\N	PRESENT	0
240192	240184	14215L	PARTICIPANT	\N	PRESENT	0
240193	240184	01024M	PARTICIPANT	\N	PRESENT	0
240194	240184	14041T	PARTICIPANT	\N	PRESENT	0
240195	240184	19649G	PARTICIPANT	\N	PRESENT	0
240197	240196	05008E	PARTICIPANT	\N	PRESENT	0
240198	240196	04047H	PARTICIPANT	\N	PRESENT	0
240199	240196	01024M	PARTICIPANT	\N	PRESENT	0
240200	240196	14215L	PARTICIPANT	\N	PRESENT	0
240201	240196	19581D	PARTICIPANT	\N	PRESENT	0
240202	240196	19483C	PARTICIPANT	\N	PRESENT	0
240204	240196	10015M	PARTICIPANT	\N	PRESENT	0
240205	240196	01028R	PARTICIPANT	\N	PRESENT	0
240182	238781	04071H	PARTICIPANT	\N	PRESENT	0
240256	239668	08020N	PARTICIPANT	\N	PRESENT	0
240257	239668	14059S	PARTICIPANT	\N	PRESENT	0
240258	239668	19747H	PARTICIPANT	\N	PRESENT	0
240259	239668	14261S	PARTICIPANT	\N	PRESENT	0
240260	239668	14119M	PARTICIPANT	\N	PRESENT	0
240264	239668	11043H	PARTICIPANT	\N	PRESENT	0
240262	239668	19621T	PARTICIPANT	\N	PRESENT	0
240263	239668	14265W	PARTICIPANT	\N	PRESENT	0
240265	239668	07029T	PARTICIPANT	\N	PRESENT	0
240266	239668	04033B	PARTICIPANT	\N	PRESENT	0
240267	239668	08010L	PARTICIPANT	\N	PRESENT	0
240268	239668	05012A	PARTICIPANT	\N	PRESENT	0
240269	239668	14030Q	PARTICIPANT	\N	PRESENT	0
240270	239668	19369B	PARTICIPANT	\N	PRESENT	0
240271	239668	14135M	PARTICIPANT	\N	PRESENT	0
240272	239668	11072N	PARTICIPANT	\N	PRESENT	0
213325	213324	04042C	PARTICIPANT	\N	PRESENT	0
213326	213324	11027H	PARTICIPANT	\N	PRESENT	0
213327	213324	08056B	PARTICIPANT	\N	PRESENT	0
213328	213324	14133K	PARTICIPANT	\N	PRESENT	0
213330	213329	04042C	PARTICIPANT	\N	PRESENT	0
213331	213329	04040A	PARTICIPANT	\N	PRESENT	0
213335	213334	14211G	PARTICIPANT	\N	PRESENT	0
217440	217438	14085U	PARTICIPANT	\N	PRESENT	0
217441	217438	14159V	PARTICIPANT	\N	PRESENT	0
217447	217446	14159V	PARTICIPANT	\N	PRESENT	0
217503	217449	19723Y	PARTICIPANT	\N	PRESENT	0
218999	217574	08048B	PARTICIPANT	\N	EXCUSE	0
220374	219964	04043D	PARTICIPANT	\N	EXCUSE	0
220435	220434	08055A	PARTICIPANT	\N	PRESENT	0
220436	220434	08068F	PARTICIPANT	\N	PRESENT	0
220437	220434	19383Y	PARTICIPANT	\N	PRESENT	0
220438	220434	14329V	PARTICIPANT	\N	PRESENT	0
221464	218275	04086Q	PARTICIPANT	\N	PRESENT	0
220440	220434	14357A	PARTICIPANT	\N	PRESENT	0
220441	220434	01025N	PARTICIPANT	\N	PRESENT	0
220442	220434	19695N	PARTICIPANT	\N	PRESENT	0
220443	220434	14033T	PARTICIPANT	\N	PRESENT	0
220444	220434	11099A	PARTICIPANT	\N	PRESENT	0
220445	220434	04049K	PARTICIPANT	\N	PRESENT	0
220446	220434	11090Q	PRESIDENT	0	PRESENT	0
220447	220434	19269X	PARTICIPANT	\N	PRESENT	0
220448	220434	19619A	PARTICIPANT	\N	PRESENT	0
221466	218275	19681G	PARTICIPANT	\N	PRESENT	0
221467	218275	17637T	PARTICIPANT	\N	PRESENT	0
221468	218275	14235Q	PARTICIPANT	\N	PRESENT	0
221469	218275	14021P	PARTICIPANT	\N	PRESENT	0
221470	218275	98022P	PARTICIPANT	\N	PRESENT	0
221471	218275	04089T	PARTICIPANT	\N	PRESENT	0
221472	218275	17583W	PARTICIPANT	\N	PRESENT	0
221473	218275	19591F	PARTICIPANT	\N	PRESENT	0
221474	218275	19593H	PARTICIPANT	\N	PRESENT	0
221475	218275	14061L	PARTICIPANT	\N	PRESENT	0
221476	218275	11097X	PARTICIPANT	\N	PRESENT	0
221477	218275	07029T	PARTICIPANT	\N	PRESENT	0
222274	219921	08011M	PARTICIPANT	\N	EXCUSE	0
222275	219921	14331P	PARTICIPANT	\N	EXCUSE	0
222440	222439	14065Q	PARTICIPANT	\N	PRESENT	0
222441	222439	96004D	PRESIDENT	0	PRESENT	0
222442	222439	14089Y	PARTICIPANT	\N	EXCUSE	0
222444	222439	08014Q	PARTICIPANT	\N	PRESENT	0
222445	222439	14357A	PARTICIPANT	\N	PRESENT	0
222446	222439	14079W	PARTICIPANT	\N	PRESENT	0
222447	222439	14249W	PARTICIPANT	\N	PRESENT	0
222449	222439	08018U	PARTICIPANT	\N	PRESENT	0
222450	222439	04035D	PARTICIPANT	\N	EXCUSE	0
222451	222439	11083R	PARTICIPANT	\N	PRESENT	0
222452	222439	14033T	PARTICIPANT	\N	PRESENT	0
222453	222439	14026U	PARTICIPANT	\N	PRESENT	0
222454	222439	19725B	PARTICIPANT	\N	PRESENT	0
222455	222439	19685L	PARTICIPANT	\N	EXCUSE	0
222456	222439	04097T	PARTICIPANT	\N	PRESENT	0
222463	222439	08044W	PARTICIPANT	\N	PRESENT	0
222464	222439	14097Y	PARTICIPANT	\N	PRESENT	0
222465	222439	14061L	PARTICIPANT	\N	EXCUSE	0
222466	222439	14073Q	PARTICIPANT	\N	PRESENT	0
222467	222439	11026G	PARTICIPANT	\N	PRESENT	0
222468	222439	08039A	PARTICIPANT	\N	PRESENT	0
222469	222439	14205J	PARTICIPANT	\N	EXCUSE	0
222470	222439	14001X	PARTICIPANT	\N	PRESENT	0
222471	222439	14221J	PARTICIPANT	\N	PRESENT	0
222472	222439	04057K	PARTICIPANT	\N	PRESENT	0
222473	222439	19563B	PARTICIPANT	\N	PRESENT	0
222474	222439	14135M	PARTICIPANT	\N	PRESENT	0
222475	222439	14331P	PARTICIPANT	\N	EXCUSE	0
222477	222439	10015M	PARTICIPANT	\N	PRESENT	0
222478	222439	14229S	PARTICIPANT	\N	PRESENT	0
222479	222439	98035U	PARTICIPANT	\N	PRESENT	0
223799	223798	95062K	PARTICIPANT	\N	PRESENT	0
223800	223798	14157T	PARTICIPANT	\N	PRESENT	0
223806	223805	14239U	PARTICIPANT	\N	EXCUSE	0
223807	223805	19683J	PARTICIPANT	\N	PRESENT	0
223820	221543	11054L	PARTICIPANT	\N	EXCUSE	0
223824	221543	96004D	PARTICIPANT	\N	EXCUSE	0
226553	225954	01048V	PARTICIPANT	\N	PRESENT	0
226603	225222	19593H	PARTICIPANT	\N	EXCUSE	0
227434	226103	88008L	PARTICIPANT	\N	PRESENT	0
227435	226103	01057W	PARTICIPANT	\N	PRESENT	0
227436	226103	14121F	PARTICIPANT	\N	PRESENT	0
221465	218275	19585H	PARTICIPANT	\N	PRESENT	0
227437	226103	08010L	PARTICIPANT	\N	PRESENT	0
227450	227449	11070L	PARTICIPANT	\N	PRESENT	0
227451	227449	14159V	PARTICIPANT	\N	PRESENT	0
227452	227449	08034U	PARTICIPANT	\N	PRESENT	0
227453	227449	11072N	PARTICIPANT	\N	PRESENT	0
227454	227449	14241N	PARTICIPANT	\N	PRESENT	0
227455	227449	11040E	PARTICIPANT	\N	PRESENT	0
228074	228073	14030Q	PRESIDENT	0	PRESENT	0
228075	228073	19643A	PARTICIPANT	\N	PRESENT	0
228076	228073	08020N	PARTICIPANT	\N	PRESENT	0
228077	228073	19701S	PARTICIPANT	\N	PRESENT	0
228078	228073	11031D	PARTICIPANT	\N	PRESENT	0
228079	228073	80013X	PARTICIPANT	\N	PRESENT	0
228080	228073	19693L	PARTICIPANT	\N	PRESENT	0
228081	228073	14217N	PARTICIPANT	\N	PRESENT	0
228082	228073	14249W	PARTICIPANT	\N	PRESENT	0
228083	228073	19599P	PARTICIPANT	\N	PRESENT	0
228084	228073	08031R	PARTICIPANT	\N	PRESENT	0
228086	228073	14109K	PARTICIPANT	\N	PRESENT	0
228087	228073	14235Q	PARTICIPANT	\N	PRESENT	0
228088	228073	19269X	PARTICIPANT	\N	PRESENT	0
228089	228073	11045K	PARTICIPANT	\N	PRESENT	0
228092	228073	08043V	PARTICIPANT	\N	EXCUSE	0
228093	228073	18083K	PARTICIPANT	\N	EXCUSE	0
228095	228073	07029T	PARTICIPANT	\N	EXCUSE	0
228096	228073	19697Q	PARTICIPANT	\N	PRESENT	0
228099	228098	14030Q	PRESIDENT	0	PRESENT	0
228100	228098	19643A	PARTICIPANT	\N	PRESENT	0
228102	228098	08024S	PARTICIPANT	\N	PRESENT	0
228103	228098	19701S	PARTICIPANT	\N	PRESENT	0
228105	228098	11031D	PARTICIPANT	\N	PRESENT	0
228106	228098	80013X	PARTICIPANT	\N	PRESENT	0
228107	228098	19693L	PARTICIPANT	\N	PRESENT	0
228108	228098	14217N	PARTICIPANT	\N	PRESENT	0
228109	228098	19599P	PARTICIPANT	\N	PRESENT	0
228110	228098	19697Q	PARTICIPANT	\N	PRESENT	0
228111	228098	14109K	PARTICIPANT	\N	PRESENT	0
228112	228098	14235Q	PARTICIPANT	\N	PRESENT	0
228113	228098	19269X	PARTICIPANT	\N	PRESENT	0
228114	228098	11045K	PARTICIPANT	\N	PRESENT	0
228115	228098	08043V	PARTICIPANT	\N	EXCUSE	0
228116	228098	18083K	PARTICIPANT	\N	EXCUSE	0
228117	228098	08031R	PARTICIPANT	\N	EXCUSE	0
228582	228581	96004D	PARTICIPANT	\N	PRESENT	0
228583	228581	11083R	PARTICIPANT	\N	PRESENT	0
228584	228581	04061F	PARTICIPANT	\N	PRESENT	0
228585	228581	14001X	PARTICIPANT	\N	PRESENT	0
228586	228581	14237S	PARTICIPANT	\N	PRESENT	0
228587	228581	10015M	PARTICIPANT	\N	PRESENT	0
228588	228581	14331P	PARTICIPANT	\N	PRESENT	0
228589	228581	04057K	PARTICIPANT	\N	PRESENT	0
228590	228581	04097T	PARTICIPANT	\N	PRESENT	0
228591	228581	14221J	PARTICIPANT	\N	PRESENT	0
230042	230014	19651A	PARTICIPANT	\N	PRESENT	0
230088	230086	04092N	PARTICIPANT	\N	PRESENT	0
230102	230086	19703U	PARTICIPANT	\N	PRESENT	0
230103	230086	19697Q	PARTICIPANT	\N	PRESENT	0
230106	230104	04092N	PARTICIPANT	\N	PRESENT	0
230108	230104	19703U	PARTICIPANT	\N	PRESENT	0
230109	230104	19697Q	PARTICIPANT	\N	PRESENT	0
230110	230104	11067R	PARTICIPANT	\N	PRESENT	0
230186	230185	11053K	PARTICIPANT	\N	PRESENT	0
230187	230185	14159V	PARTICIPANT	\N	PRESENT	0
230188	230185	05012A	PARTICIPANT	\N	PRESENT	0
232975	232974	04033B	PARTICIPANT	\N	PRESENT	0
232976	232974	08058D	PARTICIPANT	\N	PRESENT	0
232977	232974	08034U	PARTICIPANT	\N	PRESENT	0
232978	232974	16685X	PARTICIPANT	\N	PRESENT	0
233011	233010	14087W	PARTICIPANT	\N	PRESENT	0
233012	232997	08034U	PARTICIPANT	\N	EXCUSE	0
233013	232998	08034U	PARTICIPANT	\N	PRESENT	0
233014	232998	04040A	PRESIDENT	0	PRESENT	0
233015	232997	04040A	PRESIDENT	0	PRESENT	0
233016	233010	14071N	PARTICIPANT	\N	PRESENT	0
233017	232997	08048B	PARTICIPANT	\N	EXCUSE	0
233018	232998	08048B	PARTICIPANT	\N	EXCUSE	0
233033	232539	19479G	PARTICIPANT	\N	EXCUSE	0
233034	232539	04038G	PARTICIPANT	\N	PRESENT	0
233035	232539	19467C	PARTICIPANT	\N	PRESENT	0
233036	232539	08069G	PARTICIPANT	\N	EXCUSE	0
233037	232539	02002K	PARTICIPANT	\N	EXCUSE	0
233038	232998	14195A	PARTICIPANT	\N	PRESENT	0
233044	232998	11049P	PARTICIPANT	\N	PRESENT	0
233045	232539	19369B	PARTICIPANT	\N	EXCUSE	0
233051	232539	19349W	PARTICIPANT	\N	PRESENT	0
226448	226349	11101A	PARTICIPANT	\N	EXCUSE	0
226501	226349	04045F	PARTICIPANT	\N	EXCUSE	0
226609	226349	04044E	PARTICIPANT	\N	EXCUSE	0
226773	226349	01057W	PARTICIPANT	\N	EXCUSE	0
228359	218454	11056N	PARTICIPANT	\N	PRESENT	0
228357	218454	08011M	PARTICIPANT	\N	PRESENT	0
228358	218454	04059M	PARTICIPANT	\N	PRESENT	0
228360	218454	08017T	PARTICIPANT	\N	PRESENT	0
228361	218454	14225N	PARTICIPANT	\N	PRESENT	0
228362	218454	08073C	PARTICIPANT	\N	PRESENT	0
228363	218454	04034C	PARTICIPANT	\N	PRESENT	0
228364	218454	19719D	PARTICIPANT	\N	PRESENT	0
228365	218454	95037J	PARTICIPANT	\N	PRESENT	0
228366	218454	14231L	PARTICIPANT	\N	PRESENT	0
228367	218454	07004J	PARTICIPANT	\N	PRESENT	0
228368	218454	11070L	PARTICIPANT	\N	PRESENT	0
228369	218454	14327T	PARTICIPANT	\N	PRESENT	0
228370	218454	04086Q	PARTICIPANT	\N	PRESENT	0
228371	218454	19711U	PARTICIPANT	\N	PRESENT	0
228372	218454	14191V	PARTICIPANT	\N	PRESENT	0
228373	218454	01057W	PARTICIPANT	\N	PRESENT	0
228374	218454	08019V	PARTICIPANT	\N	PRESENT	0
228375	218454	11040E	PARTICIPANT	\N	PRESENT	0
228376	218454	19687N	PARTICIPANT	\N	PRESENT	0
228377	218454	19689Q	PARTICIPANT	\N	PRESENT	0
228378	218454	19543W	PARTICIPANT	\N	PRESENT	0
228379	218454	19671E	PARTICIPANT	\N	PRESENT	0
228380	218454	19507S	PARTICIPANT	\N	PRESENT	0
228381	218454	14083S	PARTICIPANT	\N	PRESENT	0
228383	218454	11045K	PARTICIPANT	\N	PRESENT	0
228384	218454	19713W	PARTICIPANT	\N	PRESENT	0
228385	218454	14034U	PARTICIPANT	\N	PRESENT	0
228386	218454	98005N	PARTICIPANT	\N	PRESENT	0
228387	218454	11109J	PARTICIPANT	\N	PRESENT	0
228388	218454	19593H	PARTICIPANT	\N	PRESENT	0
228389	218454	11077T	PARTICIPANT	\N	PRESENT	0
228390	218454	14085U	PARTICIPANT	\N	PRESENT	0
228391	218454	19545Y	PARTICIPANT	\N	PRESENT	0
228394	218454	19383Y	PARTICIPANT	\N	PRESENT	0
228397	218454	19253P	PARTICIPANT	\N	PRESENT	0
228401	218454	11053K	PARTICIPANT	\N	PRESENT	0
228402	218454	19683J	PARTICIPANT	\N	PRESENT	0
228410	218454	19301E	PARTICIPANT	\N	PRESENT	0
228406	218454	11072N	PARTICIPANT	\N	PRESENT	0
228409	218454	19651A	PARTICIPANT	\N	PRESENT	0
228411	218454	08034U	PARTICIPANT	\N	PRESENT	0
228412	218454	04071H	PARTICIPANT	\N	PRESENT	0
228414	218458	14034U	PARTICIPANT	\N	PRESENT	0
228417	218458	08011M	PARTICIPANT	\N	PRESENT	0
228418	218458	11040E	PARTICIPANT	\N	PRESENT	0
228419	218458	11045K	PARTICIPANT	\N	PRESENT	0
228420	218458	19545Y	PARTICIPANT	\N	PRESENT	0
228421	218458	14191V	PARTICIPANT	\N	PRESENT	0
228422	218458	19667J	PARTICIPANT	\N	PRESENT	0
228423	218458	14033T	PARTICIPANT	\N	PRESENT	0
228424	218458	19507S	PARTICIPANT	\N	PRESENT	0
228425	218458	14041T	PARTICIPANT	\N	PRESENT	0
228426	218458	07029T	PARTICIPANT	\N	PRESENT	0
228427	218458	07033P	PARTICIPANT	\N	PRESENT	0
228428	218458	04018C	PARTICIPANT	\N	PRESENT	0
228429	218458	08034U	PARTICIPANT	\N	PRESENT	0
228430	218458	19711U	PARTICIPANT	\N	PRESENT	0
228431	218458	14327T	PARTICIPANT	\N	PRESENT	0
228432	218458	07004J	PARTICIPANT	\N	PRESENT	0
228433	218458	19253P	PARTICIPANT	\N	PRESENT	0
228434	218458	04086Q	PARTICIPANT	\N	PRESENT	0
228435	218458	14169X	PARTICIPANT	\N	PRESENT	0
228436	218458	19651A	PARTICIPANT	\N	PRESENT	0
228437	218458	19689Q	PARTICIPANT	\N	PRESENT	0
228438	218458	14085U	PARTICIPANT	\N	PRESENT	0
228439	218458	19719D	PARTICIPANT	\N	PRESENT	0
228441	218458	04043D	PARTICIPANT	\N	PRESENT	0
228442	218458	11077T	PARTICIPANT	\N	PRESENT	0
228443	218458	19649G	PARTICIPANT	\N	PRESENT	0
228444	218458	11085T	PARTICIPANT	\N	PRESENT	0
228445	218458	04071H	PARTICIPANT	\N	PRESENT	0
228453	218458	99004R	PARTICIPANT	\N	PRESENT	0
228454	218458	08019V	PARTICIPANT	\N	PRESENT	0
228455	218458	14225N	PARTICIPANT	\N	PRESENT	0
228456	218458	08073C	PARTICIPANT	\N	PRESENT	0
228457	218458	19593H	PARTICIPANT	\N	PRESENT	0
228458	218458	14261S	PARTICIPANT	\N	PRESENT	0
228459	218458	14157T	PARTICIPANT	\N	PRESENT	0
228460	218458	14357A	PARTICIPANT	\N	PRESENT	0
228461	218458	19647E	PARTICIPANT	\N	PRESENT	0
228462	218458	11074Q	PARTICIPANT	\N	PRESENT	0
228467	218458	11072N	PARTICIPANT	\N	PRESENT	0
235540	235539	14133K	PARTICIPANT	\N	PRESENT	0
235541	235539	96004D	PRESIDENT	0	PRESENT	0
235542	235539	14089Y	PARTICIPANT	\N	PRESENT	0
235543	235539	08014Q	PARTICIPANT	\N	PRESENT	0
235544	235539	14079W	PARTICIPANT	\N	PRESENT	0
235545	235539	19725B	PARTICIPANT	\N	PRESENT	0
235546	235539	04097T	PARTICIPANT	\N	PRESENT	0
235547	235539	14097Y	PARTICIPANT	\N	PRESENT	0
235548	235539	11026G	PARTICIPANT	\N	PRESENT	0
235549	235539	14001X	PARTICIPANT	\N	PRESENT	0
235550	235539	14237S	PARTICIPANT	\N	PRESENT	0
235551	235539	14135M	PARTICIPANT	\N	PRESENT	0
235552	235539	10015M	PARTICIPANT	\N	PRESENT	0
235553	235539	98035U	PARTICIPANT	\N	PRESENT	0
235554	235539	14065Q	PARTICIPANT	\N	EXCUSE	0
235555	235539	14249W	PARTICIPANT	\N	EXCUSE	0
235556	235539	08018U	PARTICIPANT	\N	EXCUSE	0
235557	235539	11083R	PARTICIPANT	\N	EXCUSE	0
235558	235539	14061L	PARTICIPANT	\N	EXCUSE	0
235559	235539	14073Q	PARTICIPANT	\N	EXCUSE	0
235560	235539	08039A	PARTICIPANT	\N	EXCUSE	0
235561	235539	04057K	PARTICIPANT	\N	EXCUSE	0
235562	235539	19593H	PARTICIPANT	\N	EXCUSE	0
235563	235539	14331P	PARTICIPANT	\N	EXCUSE	0
235980	235977	14026U	PARTICIPANT	\N	PRESENT	0
235981	235977	14033T	PARTICIPANT	\N	PRESENT	0
235982	235977	08014Q	PARTICIPANT	\N	PRESENT	0
235983	235977	14357A	PARTICIPANT	\N	PRESENT	0
235984	235977	19441R	PARTICIPANT	\N	PRESENT	0
235985	235977	14207L	PARTICIPANT	\N	PRESENT	0
235986	235977	11099A	PARTICIPANT	\N	PRESENT	0
235987	235977	14257W	PARTICIPANT	\N	PRESENT	0
237552	237551	14069U	PARTICIPANT	\N	PRESENT	0
237553	237551	08058D	PARTICIPANT	\N	PRESENT	0
237554	237551	98018T	PARTICIPANT	\N	PRESENT	0
237555	237551	92040Q	PARTICIPANT	\N	PRESENT	0
237556	237551	14157T	PARTICIPANT	\N	PRESENT	0
237557	237551	14331P	PARTICIPANT	\N	PRESENT	0
238007	238005	08010L	PARTICIPANT	\N	PRESENT	0
238008	238005	19693L	PARTICIPANT	\N	PRESENT	0
238009	238005	19467C	PARTICIPANT	\N	PRESENT	0
238010	238005	19573D	PARTICIPANT	\N	PRESENT	0
238011	238005	17637T	PARTICIPANT	\N	PRESENT	0
238012	238005	14069U	PARTICIPANT	\N	PRESENT	0
238013	238005	04043D	PARTICIPANT	\N	PRESENT	0
238014	238005	19347U	PARTICIPANT	\N	PRESENT	0
238015	238005	14255U	PARTICIPANT	\N	PRESENT	0
238016	238005	14021P	PARTICIPANT	\N	PRESENT	0
238017	238005	11026G	PARTICIPANT	\N	PRESENT	0
238018	238005	19649G	PARTICIPANT	\N	PRESENT	0
235978	235977	96004D	PARTICIPANT	\N	PRESENT	0
235979	235977	95037J	PARTICIPANT	\N	PRESENT	0
238019	238005	08052W	PARTICIPANT	\N	PRESENT	0
238020	238005	14179A	PARTICIPANT	\N	PRESENT	0
238021	238005	14235Q	PARTICIPANT	\N	PRESENT	0
238022	238005	04057K	PARTICIPANT	\N	PRESENT	0
238077	238076	10015M	PARTICIPANT	\N	PRESENT	0
238078	238076	19549D	PARTICIPANT	\N	PRESENT	0
238079	238076	04040A	PARTICIPANT	\N	PRESENT	0
238080	238076	14255U	PARTICIPANT	\N	PRESENT	0
238082	238076	18083K	PARTICIPANT	\N	PRESENT	0
238083	238076	11027H	PARTICIPANT	\N	PRESENT	0
238084	238076	14034U	PARTICIPANT	\N	PRESENT	0
238087	238076	04035D	PARTICIPANT	\N	PRESENT	0
238089	238076	19347U	PARTICIPANT	\N	PRESENT	0
238091	238076	07004J	PARTICIPANT	\N	PRESENT	0
238093	238076	19727D	PARTICIPANT	\N	PRESENT	0
238094	238076	19591F	PARTICIPANT	\N	PRESENT	0
238097	238076	19531S	PARTICIPANT	\N	PRESENT	0
238098	238076	19683J	PARTICIPANT	\N	PRESENT	0
238099	238076	14061L	PARTICIPANT	\N	PRESENT	0
238100	238076	11099A	PARTICIPANT	\N	PRESENT	0
238103	238076	11026G	PARTICIPANT	\N	PRESENT	0
238104	238076	08017T	PARTICIPANT	\N	PRESENT	0
238105	238076	14031R	PARTICIPANT	\N	PRESENT	0
238106	238076	14071N	PARTICIPANT	\N	PRESENT	0
238108	238076	95062K	PARTICIPANT	\N	PRESENT	0
238109	238076	19687N	PARTICIPANT	\N	PRESENT	0
238110	238076	19737F	PARTICIPANT	\N	PRESENT	0
239176	232547	17637T	PARTICIPANT	\N	EXCUSE	0
239586	238872	14103D	PARTICIPANT	\N	PRESENT	0
239587	238872	14031R	PARTICIPANT	\N	PRESENT	0
212078	210043	04040A	PRESIDENT	0	PRESENT	0
212080	210043	14069U	PARTICIPANT	\N	PRESENT	0
212082	210043	11101A	PARTICIPANT	\N	PRESENT	0
212083	210043	14259Y	PARTICIPANT	\N	PRESENT	0
212084	210043	08038Y	PARTICIPANT	\N	PRESENT	0
212085	210043	14327T	PARTICIPANT	\N	PRESENT	0
212087	210043	14281W	PARTICIPANT	\N	PRESENT	0
212089	210043	08048B	PARTICIPANT	\N	PRESENT	0
212091	210043	11049P	PARTICIPANT	\N	PRESENT	0
212092	210043	01057W	PARTICIPANT	\N	PRESENT	0
212094	210043	11048N	PARTICIPANT	\N	PRESENT	0
212096	210043	19489J	PARTICIPANT	\N	PRESENT	0
212097	210043	08010L	PARTICIPANT	\N	PRESENT	0
212099	210043	14063N	PARTICIPANT	\N	PRESENT	0
212104	210043	14257W	PARTICIPANT	\N	PRESENT	0
212105	210043	14028W	PARTICIPANT	\N	PRESENT	0
212106	210043	19735D	PARTICIPANT	\N	PRESENT	0
212108	210043	95063L	PARTICIPANT	\N	PRESENT	0
212109	210043	19687N	PARTICIPANT	\N	PRESENT	0
212111	210043	04045F	PARTICIPANT	\N	PRESENT	0
212113	210043	08049C	PARTICIPANT	\N	PRESENT	0
215915	207252	96004D	PARTICIPANT	\N	EXCUSE	0
215916	207252	14059S	PARTICIPANT	\N	EXCUSE	0
215917	207252	14225N	PARTICIPANT	\N	EXCUSE	0
215918	207252	98005N	PARTICIPANT	\N	EXCUSE	0
215919	207252	11054L	PARTICIPANT	\N	PRESENT	0
215920	207252	14331P	PARTICIPANT	\N	EXCUSE	0
215921	207252	14038Y	PARTICIPANT	\N	PRESENT	0
215922	207252	19583F	PARTICIPANT	\N	EXCUSE	0
217202	217201	08016S	PARTICIPANT	\N	PRESENT	0
217203	217201	19719D	PARTICIPANT	\N	PRESENT	0
217204	217201	14151M	PARTICIPANT	\N	PRESENT	0
217205	217201	14087W	PARTICIPANT	\N	PRESENT	0
217206	217201	17637T	PARTICIPANT	\N	PRESENT	0
217207	217201	14107H	PARTICIPANT	\N	PRESENT	0
217208	217201	04034C	PARTICIPANT	\N	PRESENT	0
217209	217201	14193X	PARTICIPANT	\N	PRESENT	0
217479	217477	96004D	PARTICIPANT	\N	PRESENT	0
217488	217477	14001X	PARTICIPANT	\N	PRESENT	0
217486	217477	14073Q	PARTICIPANT	\N	PRESENT	0
217487	217477	14097Y	PARTICIPANT	\N	PRESENT	0
217489	217477	14221J	PARTICIPANT	\N	PRESENT	0
217490	217477	04057K	PARTICIPANT	\N	PRESENT	0
212076	210043	19525U	PARTICIPANT	\N	EXCUSE	0
217491	217477	98035U	PARTICIPANT	\N	PRESENT	0
217497	217477	04042C	PARTICIPANT	\N	PRESENT	0
217498	217477	14255U	PARTICIPANT	\N	PRESENT	0
217499	217477	19709B	PARTICIPANT	\N	PRESENT	0
217500	217477	04034C	PARTICIPANT	\N	PRESENT	0
217501	217477	01062T	PARTICIPANT	\N	PRESENT	0
217502	217477	19251M	PARTICIPANT	\N	PRESENT	0
217811	217572	14119M	PARTICIPANT	\N	PRESENT	0
217812	217572	14071N	PARTICIPANT	\N	PRESENT	0
217813	217572	14026U	PARTICIPANT	\N	PRESENT	0
217814	217572	19679N	PARTICIPANT	\N	PRESENT	0
217815	217572	10006L	PARTICIPANT	\N	PRESENT	0
217816	217572	19657G	PARTICIPANT	\N	PRESENT	0
217817	207712	14034U	PARTICIPANT	\N	PRESENT	0
217818	207712	19651A	PARTICIPANT	\N	PRESENT	0
217819	207712	88008L	PARTICIPANT	\N	PRESENT	0
217820	207712	19349W	PARTICIPANT	\N	PRESENT	0
217821	207712	19629C	PARTICIPANT	\N	PRESENT	0
217822	207712	19583F	PARTICIPANT	\N	PRESENT	0
217823	207712	19737F	PARTICIPANT	\N	PRESENT	0
217824	207712	08011M	PARTICIPANT	\N	PRESENT	0
217825	207712	19731Y	PARTICIPANT	\N	PRESENT	0
217826	207712	19545Y	PARTICIPANT	\N	PRESENT	0
217827	207712	19387D	PARTICIPANT	\N	PRESENT	0
217828	207712	19687N	PARTICIPANT	\N	PRESENT	0
217829	207712	07029T	PARTICIPANT	\N	PRESENT	0
217830	207712	19729F	PARTICIPANT	\N	PRESENT	0
217831	207712	11048N	PARTICIPANT	\N	PRESENT	0
217832	207712	14265W	PARTICIPANT	\N	PRESENT	0
217833	207712	04088S	PARTICIPANT	\N	PRESENT	0
217834	207712	19507S	PARTICIPANT	\N	PRESENT	0
217835	207712	19447X	PARTICIPANT	\N	PRESENT	0
217836	207712	19479G	PARTICIPANT	\N	PRESENT	0
217837	207712	14327T	PARTICIPANT	\N	PRESENT	0
217838	207712	15447F	PARTICIPANT	\N	PRESENT	0
217839	207712	19713W	PARTICIPANT	\N	PRESENT	0
217840	207712	19441R	PARTICIPANT	\N	PRESENT	0
217841	207712	99004R	PARTICIPANT	\N	PRESENT	0
217842	207712	14073Q	PARTICIPANT	\N	PRESENT	0
217843	207712	19585H	PARTICIPANT	\N	PRESENT	0
217844	207712	19543W	PARTICIPANT	\N	PRESENT	0
217845	207712	19525U	PARTICIPANT	\N	PRESENT	0
217846	207712	19647E	PARTICIPANT	\N	PRESENT	0
217847	207712	12016W	PARTICIPANT	\N	PRESENT	0
217848	207712	14225N	PARTICIPANT	\N	PRESENT	0
217849	207712	14085U	PARTICIPANT	\N	PRESENT	0
217850	207712	11070L	PARTICIPANT	\N	PRESENT	0
217851	207712	14241N	PARTICIPANT	\N	PRESENT	0
217852	207712	97011G	PARTICIPANT	\N	PRESENT	0
217853	207712	19667J	PARTICIPANT	\N	PRESENT	0
217854	207712	19443T	PARTICIPANT	\N	PRESENT	0
217855	207712	98024R	PARTICIPANT	\N	PRESENT	0
217856	207712	08016S	PARTICIPANT	\N	PRESENT	0
217857	207712	14081Q	PARTICIPANT	\N	PRESENT	0
217858	207712	19333N	PARTICIPANT	\N	PRESENT	0
217859	207712	04071H	PARTICIPANT	\N	PRESENT	0
217860	207712	08028W	PARTICIPANT	\N	PRESENT	0
217861	207712	11074Q	PARTICIPANT	\N	PRESENT	0
217862	207712	14038Y	PARTICIPANT	\N	PRESENT	0
217863	207712	14215L	PARTICIPANT	\N	PRESENT	0
217864	217572	19575F	PARTICIPANT	\N	PRESENT	0
217865	217572	19335Q	PARTICIPANT	\N	PRESENT	0
217866	217572	19521Q	PARTICIPANT	\N	PRESENT	0
217867	217572	11045K	PARTICIPANT	\N	PRESENT	0
217868	217572	19691J	PARTICIPANT	\N	PRESENT	0
217869	217572	19723Y	PARTICIPANT	\N	PRESENT	0
217870	217572	19577H	PARTICIPANT	\N	PRESENT	0
217871	217572	08048B	PARTICIPANT	\N	EXCUSE	0
217872	207712	19533U	PARTICIPANT	\N	PRESENT	0
217873	207712	14083S	PARTICIPANT	\N	PRESENT	0
217874	207712	19715Y	PARTICIPANT	\N	PRESENT	0
217875	207712	14219Q	PARTICIPANT	\N	PRESENT	0
217876	207712	19711U	PARTICIPANT	\N	PRESENT	0
217878	207712	04008A	PARTICIPANT	\N	PRESENT	0
217879	207712	04086Q	PARTICIPANT	\N	PRESENT	0
217880	207712	19467C	PARTICIPANT	\N	PRESENT	0
217881	207712	18083K	PARTICIPANT	\N	PRESENT	0
217882	207712	01057W	PARTICIPANT	\N	PRESENT	0
217883	207712	14121F	PARTICIPANT	\N	PRESENT	0
217884	207712	14197C	PARTICIPANT	\N	PRESENT	0
217885	207712	19551W	PARTICIPANT	\N	PRESENT	0
217886	207712	14157T	PARTICIPANT	\N	PRESENT	0
217887	207712	08024S	PARTICIPANT	\N	PRESENT	0
217888	207712	04033B	PARTICIPANT	\N	PRESENT	0
217889	207712	08015R	PARTICIPANT	\N	PRESENT	0
217890	207712	14041T	PARTICIPANT	\N	PRESENT	0
217891	207712	19565D	PARTICIPANT	\N	PRESENT	0
217892	207712	19301E	PARTICIPANT	\N	PRESENT	0
217893	207712	14061L	PARTICIPANT	\N	PRESENT	0
217894	207712	14069U	PARTICIPANT	\N	PRESENT	0
218378	207714	14028W	PARTICIPANT	\N	PRESENT	0
218379	207714	14026U	PARTICIPANT	\N	PRESENT	0
218380	207714	14061L	PARTICIPANT	\N	PRESENT	0
218381	207714	19399H	PARTICIPANT	\N	PRESENT	0
218382	207714	11109J	PARTICIPANT	\N	PRESENT	0
218383	217469	19515S	PARTICIPANT	\N	PRESENT	0
218384	217469	19565D	PARTICIPANT	\N	PRESENT	0
218385	217469	19441R	PARTICIPANT	\N	PRESENT	0
218386	217469	19413M	PARTICIPANT	\N	PRESENT	0
218387	217469	80013X	PARTICIPANT	\N	PRESENT	0
218388	217469	19631V	PARTICIPANT	\N	PRESENT	0
218389	217469	08021P	PARTICIPANT	\N	PRESENT	0
218390	217469	08068F	PARTICIPANT	\N	PRESENT	0
218391	217469	04049K	PARTICIPANT	\N	PRESENT	0
218392	217469	19705W	PARTICIPANT	\N	PRESENT	0
218393	217469	08015R	PARTICIPANT	\N	PRESENT	0
218394	217469	08019V	PARTICIPANT	\N	PRESENT	0
218395	217469	19369B	PARTICIPANT	\N	PRESENT	0
218396	217469	19511N	PARTICIPANT	\N	PRESENT	0
218397	217469	08028W	PARTICIPANT	\N	PRESENT	0
218398	217469	19563B	PARTICIPANT	\N	PRESENT	0
218399	217469	14265W	PARTICIPANT	\N	PRESENT	0
218400	217469	14329V	PARTICIPANT	\N	PRESENT	0
218401	217469	19591F	PARTICIPANT	\N	PRESENT	0
218402	217469	14135M	PARTICIPANT	\N	PRESENT	0
218403	217469	19467C	PARTICIPANT	\N	PRESENT	0
218404	217469	14187A	PARTICIPANT	\N	PRESENT	0
218405	217469	08038Y	PARTICIPANT	\N	PRESENT	0
218406	217469	08062Y	PARTICIPANT	\N	PRESENT	0
218407	217469	19301E	PARTICIPANT	\N	PRESENT	0
218408	217469	19695N	PARTICIPANT	\N	PRESENT	0
218409	217469	14033T	PARTICIPANT	\N	PRESENT	0
218410	217469	11090Q	PRESIDENT	0	PRESENT	0
218411	217469	01025N	PARTICIPANT	\N	PRESENT	0
218412	217469	19295A	PARTICIPANT	\N	PRESENT	0
230915	230586	14327T	PARTICIPANT	\N	EXCUSE	0
230916	230586	07029T	PARTICIPANT	\N	EXCUSE	0
230917	230586	11048N	PARTICIPANT	\N	EXCUSE	0
230954	230595	14053L	PARTICIPANT	\N	PRESENT	0
230955	230595	19585H	PARTICIPANT	\N	PRESENT	0
230956	230595	19725B	PARTICIPANT	\N	PRESENT	0
230957	230595	95063L	PARTICIPANT	\N	PRESENT	0
230958	230595	19483C	PARTICIPANT	\N	PRESENT	0
230959	230595	11072N	PARTICIPANT	\N	PRESENT	0
230960	230595	14021P	PARTICIPANT	\N	PRESENT	0
230961	220073	14085U	PARTICIPANT	\N	PRESENT	0
230962	220073	11074Q	PARTICIPANT	\N	PRESENT	0
230963	220073	19651A	PARTICIPANT	\N	PRESENT	0
230964	220073	19681G	PARTICIPANT	\N	PRESENT	0
230965	220073	19689Q	PARTICIPANT	\N	PRESENT	0
230966	220073	19525U	PARTICIPANT	\N	PRESENT	0
230967	220073	14073Q	PARTICIPANT	\N	PRESENT	0
230968	220073	19731Y	PARTICIPANT	\N	PRESENT	0
230969	220073	19703U	PARTICIPANT	\N	PRESENT	0
230970	220073	19667J	PARTICIPANT	\N	PRESENT	0
230971	220073	14265W	PARTICIPANT	\N	PRESENT	0
230974	220073	19591F	PARTICIPANT	\N	PRESENT	0
230975	220073	07004J	PARTICIPANT	\N	PRESENT	0
230976	220073	04086Q	PARTICIPANT	\N	PRESENT	0
230977	220073	08011M	PARTICIPANT	\N	PRESENT	0
230981	220073	19333N	PARTICIPANT	\N	PRESENT	0
230986	220073	11067R	PARTICIPANT	\N	PRESENT	0
230989	220073	19545Y	PARTICIPANT	\N	PRESENT	0
230990	220073	14111D	PARTICIPANT	\N	PRESENT	0
230991	220073	95063L	PARTICIPANT	\N	PRESENT	0
230992	220073	14327T	PARTICIPANT	\N	PRESENT	0
230993	220073	14267Y	PARTICIPANT	\N	PRESENT	0
230994	220073	11070L	PARTICIPANT	\N	PRESENT	0
230995	220073	19575F	PARTICIPANT	\N	PRESENT	0
230996	220073	19415P	PARTICIPANT	\N	PRESENT	0
230997	220073	14041T	PARTICIPANT	\N	PRESENT	0
230998	220073	04088S	PARTICIPANT	\N	PRESENT	0
230999	220073	19583F	PARTICIPANT	\N	PRESENT	0
231000	220073	19553Y	PARTICIPANT	\N	PRESENT	0
231001	220073	01057W	PARTICIPANT	\N	PRESENT	0
231002	220073	19711U	PARTICIPANT	\N	PRESENT	0
231003	220073	19515S	PARTICIPANT	\N	PRESENT	0
231004	220073	14119M	PARTICIPANT	\N	PRESENT	0
231005	220073	19483C	PARTICIPANT	\N	PRESENT	0
231006	220073	14061L	PARTICIPANT	\N	PRESENT	0
231007	220073	10006L	PARTICIPANT	\N	PRESENT	0
231008	220073	19387D	PARTICIPANT	\N	PRESENT	0
231009	220073	17583W	PARTICIPANT	\N	PRESENT	0
231010	220073	19671E	PARTICIPANT	\N	PRESENT	0
231011	220073	08056B	PARTICIPANT	\N	PRESENT	0
231012	220073	19413M	PARTICIPANT	\N	PRESENT	0
231013	220073	14121F	PARTICIPANT	\N	PRESENT	0
231014	220073	19699S	PARTICIPANT	\N	PRESENT	0
231015	220073	14069U	PARTICIPANT	\N	PRESENT	0
231016	220073	19367Y	PARTICIPANT	\N	PRESENT	0
231017	220073	14033T	PARTICIPANT	\N	PRESENT	0
231018	220073	19383Y	PARTICIPANT	\N	PRESENT	0
231019	220073	18083K	PARTICIPANT	\N	PRESENT	0
231020	220073	14105F	PARTICIPANT	\N	PRESENT	0
231021	220073	19739H	PARTICIPANT	\N	PRESENT	0
231022	220073	01060R	PARTICIPANT	\N	PRESENT	0
231023	220073	04045F	PARTICIPANT	\N	PRESENT	0
231024	220073	19693L	PARTICIPANT	\N	PRESENT	0
231025	220073	11097X	PARTICIPANT	\N	PRESENT	0
231026	220073	19687N	PARTICIPANT	\N	PRESENT	0
231027	220073	19565D	PARTICIPANT	\N	PRESENT	0
231028	220073	04085P	PARTICIPANT	\N	PRESENT	0
231029	220073	19503N	PARTICIPANT	\N	PRESENT	0
231030	220073	97011G	PARTICIPANT	\N	PRESENT	0
231031	220073	14195A	PARTICIPANT	\N	PRESENT	0
231032	220073	14135M	PARTICIPANT	\N	PRESENT	0
231033	220073	19573D	PARTICIPANT	\N	PRESENT	0
231034	220073	19725B	PARTICIPANT	\N	PRESENT	0
231035	220073	98018T	PARTICIPANT	\N	PRESENT	0
231036	220073	19441R	PARTICIPANT	\N	PRESENT	0
231037	220073	19727D	PARTICIPANT	\N	PRESENT	0
231038	220073	88008L	PARTICIPANT	\N	PRESENT	0
231039	220073	14063N	PARTICIPANT	\N	PRESENT	0
231040	220073	04097T	PARTICIPANT	\N	PRESENT	0
231041	220073	19467C	PARTICIPANT	\N	PRESENT	0
231042	220073	19447X	PARTICIPANT	\N	PRESENT	0
231043	220073	19253P	PARTICIPANT	\N	PRESENT	0
231044	220073	19443T	PARTICIPANT	\N	PRESENT	0
231045	220073	14021P	PARTICIPANT	\N	PRESENT	0
231046	220073	14225N	PARTICIPANT	\N	PRESENT	0
231047	220073	19629C	PARTICIPANT	\N	PRESENT	0
231048	220073	08039A	PARTICIPANT	\N	PRESENT	0
231049	220073	19507S	PARTICIPANT	\N	PRESENT	0
231050	220073	14031R	PARTICIPANT	\N	PRESENT	0
231051	220073	14089Y	PARTICIPANT	\N	PRESENT	0
231052	220073	19549D	PARTICIPANT	\N	PRESENT	0
231053	220073	19741B	PARTICIPANT	\N	PRESENT	0
231054	220073	14157T	PARTICIPANT	\N	PRESENT	0
231055	220073	11056N	PARTICIPANT	\N	PRESENT	0
231056	220073	04034C	PARTICIPANT	\N	PRESENT	0
231057	220073	19533U	PARTICIPANT	\N	PRESENT	0
231058	220073	14331P	PARTICIPANT	\N	PRESENT	0
231059	220073	19369B	PARTICIPANT	\N	PRESENT	0
231060	220073	14042U	PARTICIPANT	\N	PRESENT	0
231061	220073	04071H	PARTICIPANT	\N	PRESENT	0
231062	220073	08012N	PARTICIPANT	\N	PRESENT	0
231063	220073	11054L	PARTICIPANT	\N	PRESENT	0
231064	220073	08044W	PARTICIPANT	\N	PRESENT	0
231065	220073	08028W	PARTICIPANT	\N	PRESENT	0
231066	220073	01024M	PARTICIPANT	\N	PRESENT	0
231067	220073	99004R	PARTICIPANT	\N	PRESENT	0
231068	220073	14083S	PARTICIPANT	\N	PRESENT	0
231069	220073	01043Q	PARTICIPANT	\N	PRESENT	0
231071	220073	14107H	PARTICIPANT	\N	PRESENT	0
231081	220073	95041E	PARTICIPANT	\N	PRESENT	0
231082	220073	14237S	PARTICIPANT	\N	PRESENT	0
231083	220073	14087W	PARTICIPANT	\N	PRESENT	0
231084	220073	19691J	PARTICIPANT	\N	PRESENT	0
231085	220073	19611R	PARTICIPANT	\N	PRESENT	0
231086	220073	19531S	PARTICIPANT	\N	PRESENT	0
231087	220073	08069G	PARTICIPANT	\N	PRESENT	0
231088	220073	95030B	PARTICIPANT	\N	PRESENT	0
231089	220073	19593H	PARTICIPANT	\N	PRESENT	0
231090	220073	14038Y	PARTICIPANT	\N	PRESENT	0
231092	220073	19319Q	PARTICIPANT	\N	PRESENT	0
231093	220073	19631V	PARTICIPANT	\N	PRESENT	0
231094	220073	19647E	PARTICIPANT	\N	PRESENT	0
231095	220073	19723Y	PARTICIPANT	\N	PRESENT	0
231096	220073	14199E	PARTICIPANT	\N	PRESENT	0
231097	220073	16685X	PARTICIPANT	\N	PRESENT	0
231098	220073	14103D	PARTICIPANT	\N	PRESENT	0
231099	220073	19335Q	PARTICIPANT	\N	PRESENT	0
231100	220073	19621T	PARTICIPANT	\N	PRESENT	0
231101	220073	19479G	PARTICIPANT	\N	PRESENT	0
231102	220073	08010L	PARTICIPANT	\N	PRESENT	0
231103	220073	08034U	PARTICIPANT	\N	PRESENT	0
231104	220073	08045X	PARTICIPANT	\N	PRESENT	0
231105	220073	11066Q	PARTICIPANT	\N	PRESENT	0
231106	220073	14221J	PARTICIPANT	\N	PRESENT	0
231109	220073	08016S	PARTICIPANT	\N	PRESENT	0
231110	220073	19585H	PARTICIPANT	\N	PRESENT	0
231111	220073	19673G	PARTICIPANT	\N	PRESENT	0
231112	220073	98029W	PARTICIPANT	\N	PRESENT	0
231113	220073	11072N	PARTICIPANT	\N	PRESENT	0
231114	220073	04057K	PARTICIPANT	\N	PRESENT	0
231115	220073	19717B	PARTICIPANT	\N	PRESENT	0
231116	220073	19735D	PARTICIPANT	\N	PRESENT	0
231117	220073	08024S	PARTICIPANT	\N	PRESENT	0
231118	220073	08062Y	PARTICIPANT	\N	PRESENT	0
216250	216249	14261S	PARTICIPANT	\N	PRESENT	0
216251	216249	19575F	PARTICIPANT	\N	PRESENT	0
216252	216249	08060W	PARTICIPANT	\N	PRESENT	0
216253	216249	14105F	PARTICIPANT	\N	PRESENT	0
216254	216249	14255U	PARTICIPANT	\N	PRESENT	0
216255	216249	14083S	PARTICIPANT	\N	PRESENT	0
216256	216249	19545Y	PARTICIPANT	\N	PRESENT	0
216257	216249	14151M	PARTICIPANT	\N	PRESENT	0
216258	216249	14187A	PARTICIPANT	\N	PRESENT	0
216259	216249	14087W	PARTICIPANT	\N	PRESENT	0
216260	216249	19521Q	PARTICIPANT	\N	PRESENT	0
216261	216249	19591F	PARTICIPANT	\N	PRESENT	0
216262	216249	14039A	PARTICIPANT	\N	PRESENT	0
216263	216249	04049K	PRESIDENT	0	PRESENT	0
216264	216249	16685X	PARTICIPANT	\N	PRESENT	0
216265	216249	19671E	PARTICIPANT	\N	PRESENT	0
216266	216249	14265W	PARTICIPANT	\N	PRESENT	0
216267	216249	14253S	PARTICIPANT	\N	PRESENT	0
216268	216249	04088S	PARTICIPANT	\N	PRESENT	0
216269	216249	14157T	PARTICIPANT	\N	PRESENT	0
216270	216249	14329V	PARTICIPANT	\N	PRESENT	0
216271	216249	08015R	PARTICIPANT	\N	PRESENT	0
216272	216249	89017R	PARTICIPANT	\N	EXCUSE	0
216273	216249	14030Q	PARTICIPANT	\N	EXCUSE	0
216274	216249	14053L	PARTICIPANT	\N	EXCUSE	0
216275	216249	11031D	PARTICIPANT	\N	EXCUSE	0
216276	216249	14041T	PARTICIPANT	\N	EXCUSE	0
216277	216249	14034U	PARTICIPANT	\N	EXCUSE	0
216278	216249	14026U	PARTICIPANT	\N	EXCUSE	0
216279	216249	14061L	PARTICIPANT	\N	EXCUSE	0
216280	216249	14205J	PARTICIPANT	\N	EXCUSE	0
216281	216249	08047A	PARTICIPANT	\N	EXCUSE	0
216282	216249	14051J	PARTICIPANT	\N	EXCUSE	0
216283	216249	19527W	PARTICIPANT	\N	EXCUSE	0
216284	216249	04034C	PARTICIPANT	\N	EXCUSE	0
216296	216249	14079W	PARTICIPANT	\N	EXCUSE	0
219185	219184	04047H	PARTICIPANT	\N	PRESENT	0
219187	219184	19729F	PARTICIPANT	\N	PRESENT	0
219188	219184	19673G	PARTICIPANT	\N	PRESENT	0
229486	228464	19673G	PARTICIPANT	\N	EXCUSE	0
230790	230789	04042C	PARTICIPANT	\N	PRESENT	0
230791	230789	98018T	PARTICIPANT	\N	PRESENT	0
232452	232450	14357A	PARTICIPANT	\N	PRESENT	0
232453	232450	19709B	PARTICIPANT	\N	PRESENT	0
232455	232450	19735D	PARTICIPANT	\N	PRESENT	0
232456	232450	08015R	PARTICIPANT	\N	PRESENT	0
232457	232450	14030Q	PARTICIPANT	\N	PRESENT	0
232458	232450	08031R	PARTICIPANT	\N	PRESENT	0
233043	233041	14225N	PARTICIPANT	\N	PRESENT	0
232460	232450	04070G	PARTICIPANT	\N	PRESENT	0
232461	232450	14249W	PARTICIPANT	\N	PRESENT	0
232462	232450	11026G	PARTICIPANT	\N	PRESENT	0
232464	232450	11064N	PARTICIPANT	\N	PRESENT	0
232466	232450	14073Q	PARTICIPANT	\N	PRESENT	0
233042	233041	14331P	PARTICIPANT	\N	PRESENT	0
233066	232539	11115U	PARTICIPANT	\N	EXCUSE	0
233067	232539	19569H	PARTICIPANT	\N	EXCUSE	0
233237	232539	19399H	PARTICIPANT	\N	PRESENT	0
233241	233240	08052W	PARTICIPANT	\N	PRESENT	0
233243	233242	08052W	PARTICIPANT	\N	PRESENT	0
233249	233248	19447X	PARTICIPANT	\N	PRESENT	0
233250	233248	14021P	PARTICIPANT	\N	PRESENT	0
233251	233248	19649G	PARTICIPANT	\N	PRESENT	0
233253	233252	19447X	PARTICIPANT	\N	PRESENT	0
233254	233252	14021P	PARTICIPANT	\N	PRESENT	0
233256	233255	19447X	PARTICIPANT	\N	PRESENT	0
233260	233259	19447X	PARTICIPANT	\N	PRESENT	0
233261	233259	19649G	PARTICIPANT	\N	PRESENT	0
233263	233262	19447X	PARTICIPANT	\N	PRESENT	0
233265	233264	19447X	PARTICIPANT	\N	PRESENT	0
233266	233264	14021P	PARTICIPANT	\N	PRESENT	0
233268	233267	19447X	PARTICIPANT	\N	PRESENT	0
233269	233267	14021P	PARTICIPANT	\N	PRESENT	0
233270	233267	19649G	PARTICIPANT	\N	PRESENT	0
233272	233271	19447X	PARTICIPANT	\N	PRESENT	0
233273	233271	14021P	PARTICIPANT	\N	PRESENT	0
233275	233274	19447X	PARTICIPANT	\N	PRESENT	0
233277	233276	19447X	PARTICIPANT	\N	PRESENT	0
233290	233289	19447X	PARTICIPANT	\N	PRESENT	0
233292	233291	11053K	PARTICIPANT	\N	PRESENT	0
233294	233293	17637T	PARTICIPANT	\N	PRESENT	0
234441	232852	14239U	PARTICIPANT	\N	PRESENT	0
235193	232997	14195A	PARTICIPANT	\N	EXCUSE	0
235211	235198	11027H	PARTICIPANT	\N	PRESENT	0
234444	232852	19575F	PARTICIPANT	\N	PRESENT	0
235209	235198	08058D	PARTICIPANT	\N	PRESENT	0
234446	232852	14195A	PARTICIPANT	\N	PRESENT	0
235210	235198	04042C	PRESIDENT	0	PRESENT	0
234448	232852	08052W	PARTICIPANT	\N	PRESENT	0
235212	235198	98018T	PARTICIPANT	\N	PRESENT	0
234450	232852	98024R	PARTICIPANT	\N	PRESENT	0
234451	232852	10006L	PARTICIPANT	\N	PRESENT	0
234452	232852	14041T	PARTICIPANT	\N	PRESENT	0
235213	235198	19251M	PARTICIPANT	\N	PRESENT	0
235214	235198	97011G	PARTICIPANT	\N	PRESENT	0
234455	232852	19565D	PARTICIPANT	\N	PRESENT	0
234456	232852	19553Y	PARTICIPANT	\N	PRESENT	0
234457	232852	19723Y	PARTICIPANT	\N	PRESENT	0
234458	232852	11067R	PARTICIPANT	\N	PRESENT	0
235215	235198	14097Y	PARTICIPANT	\N	PRESENT	0
234460	232852	04092N	PARTICIPANT	\N	PRESENT	0
234461	232852	04088S	PARTICIPANT	\N	PRESENT	0
234462	232852	14135M	PARTICIPANT	\N	PRESENT	0
235216	235198	16685X	PARTICIPANT	\N	PRESENT	0
235217	235198	98050T	PARTICIPANT	\N	PRESENT	0
235218	235198	14235Q	PARTICIPANT	\N	EXCUSE	0
235219	235198	19443T	PARTICIPANT	\N	PRESENT	0
235220	235198	19421M	PARTICIPANT	\N	PRESENT	0
235221	235198	11041F	PARTICIPANT	\N	PRESENT	0
235222	235198	11066Q	PARTICIPANT	\N	PRESENT	0
235223	235198	95067Q	PARTICIPANT	\N	PRESENT	0
235225	235198	14089Y	PARTICIPANT	\N	PRESENT	0
235231	235198	19725B	PARTICIPANT	\N	PRESENT	0
235234	235198	11026G	PARTICIPANT	\N	PRESENT	0
235235	235198	11072N	PARTICIPANT	\N	PRESENT	0
235238	235198	10015M	PARTICIPANT	\N	PRESENT	0
235239	235198	01028R	PARTICIPANT	\N	PRESENT	0
235240	235198	98035U	PARTICIPANT	\N	PRESENT	0
235242	235198	19483C	PARTICIPANT	\N	PRESENT	0
235244	235198	14053L	PARTICIPANT	\N	PRESENT	0
235245	235198	96004D	PARTICIPANT	\N	PRESENT	0
235247	235198	08014Q	PARTICIPANT	\N	PRESENT	0
235248	235198	14357A	PARTICIPANT	\N	PRESENT	0
235251	235198	04097T	PARTICIPANT	\N	PRESENT	0
235258	235198	19563B	PARTICIPANT	\N	PRESENT	0
235262	235198	14237S	PARTICIPANT	\N	PRESENT	0
235263	235198	14135M	PARTICIPANT	\N	PRESENT	0
235264	235198	14225N	PARTICIPANT	\N	PRESENT	0
235265	235198	14221J	PARTICIPANT	\N	PRESENT	0
235266	235198	11083R	PARTICIPANT	\N	PRESENT	0
235282	235198	04040A	PARTICIPANT	\N	EXCUSE	0
235283	235198	08061X	PARTICIPANT	\N	EXCUSE	0
235284	235198	08047A	PARTICIPANT	\N	EXCUSE	0
235297	233031	14133K	PRESIDENT	0	PRESENT	0
235298	233031	19631V	PARTICIPANT	\N	PRESENT	0
235357	235356	14261S	PARTICIPANT	\N	PRESENT	0
235300	233031	08068F	PARTICIPANT	\N	PRESENT	0
235301	233031	08028W	PARTICIPANT	\N	EXCUSE	0
235358	235356	19575F	PARTICIPANT	\N	PRESENT	0
235303	233031	14079W	PARTICIPANT	\N	PRESENT	0
235304	233031	19251M	PARTICIPANT	\N	PRESENT	0
235305	233031	19695N	PARTICIPANT	\N	PRESENT	0
235359	235356	14105F	PARTICIPANT	\N	PRESENT	0
235360	235356	08068F	PARTICIPANT	\N	PRESENT	0
235308	233031	14061L	PARTICIPANT	\N	PRESENT	0
235361	235356	14053L	PARTICIPANT	\N	PRESENT	0
235362	235356	14083S	PARTICIPANT	\N	PRESENT	0
235311	233031	14219Q	PARTICIPANT	\N	PRESENT	0
235312	233031	19637C	PARTICIPANT	\N	PRESENT	0
235313	233031	19563B	PARTICIPANT	\N	PRESENT	0
235314	233031	19369B	PARTICIPANT	\N	PRESENT	0
235315	233031	14257W	PARTICIPANT	\N	PRESENT	0
235363	235356	19521Q	PARTICIPANT	\N	PRESENT	0
235317	233031	14028W	PARTICIPANT	\N	PRESENT	0
235364	235356	14121F	PARTICIPANT	\N	PRESENT	0
235365	235356	14039A	PARTICIPANT	\N	PRESENT	0
235320	233031	19349W	PARTICIPANT	\N	PRESENT	0
235321	233031	11043H	PARTICIPANT	\N	EXCUSE	0
235322	233031	19737F	PARTICIPANT	\N	PRESENT	0
235323	233031	19585H	PARTICIPANT	\N	PRESENT	0
235366	235356	04049K	PRESIDENT	0	PRESENT	0
235367	235356	16685X	PARTICIPANT	\N	PRESENT	0
235368	235356	14205J	PARTICIPANT	\N	PRESENT	0
235369	235356	14265W	PARTICIPANT	\N	PRESENT	0
235370	235356	14253S	PARTICIPANT	\N	PRESENT	0
235371	235356	04088S	PARTICIPANT	\N	PRESENT	0
235372	235356	14051J	PARTICIPANT	\N	PRESENT	0
235373	235356	14157T	PARTICIPANT	\N	PRESENT	0
235374	235356	04034C	PARTICIPANT	\N	PRESENT	0
232791	232790	10006L	PARTICIPANT	\N	PRESENT	0
232792	232790	19569H	PARTICIPANT	\N	PRESENT	0
232793	232790	16685X	PARTICIPANT	\N	PRESENT	0
232794	232790	14221J	PARTICIPANT	\N	PRESENT	0
232808	232807	14355X	PARTICIPANT	\N	PRESENT	0
232810	232809	14355X	PARTICIPANT	\N	PRESENT	0
232812	232811	14355X	PARTICIPANT	\N	PRESENT	0
232814	232813	14123H	PARTICIPANT	\N	PRESENT	0
232816	232815	14085U	PARTICIPANT	\N	PRESENT	0
232817	232815	07033P	PARTICIPANT	\N	PRESENT	0
232818	232815	14034U	PARTICIPANT	\N	PRESENT	0
232819	232815	14073Q	PARTICIPANT	\N	PRESENT	0
232820	232815	19711U	PARTICIPANT	\N	PRESENT	0
232821	232815	19709B	PARTICIPANT	\N	PRESENT	0
232822	232815	14235Q	PARTICIPANT	\N	PRESENT	0
232823	232815	14229S	PARTICIPANT	\N	PRESENT	0
232824	232815	01028R	PARTICIPANT	\N	PRESENT	0
232825	232815	04034C	PARTICIPANT	\N	PRESENT	0
232827	232826	96004D	PARTICIPANT	\N	PRESENT	0
232828	232826	98029W	PARTICIPANT	\N	PRESENT	0
232829	232826	11027H	PARTICIPANT	\N	PRESENT	0
232830	232826	19507S	PARTICIPANT	\N	PRESENT	0
232831	232826	98022P	PARTICIPANT	\N	PRESENT	0
232832	232826	19583F	PARTICIPANT	\N	PRESENT	0
232833	232826	08015R	PARTICIPANT	\N	PRESENT	0
232834	232826	19591F	PARTICIPANT	\N	PRESENT	0
232835	232826	10015M	PARTICIPANT	\N	PRESENT	0
232836	232826	04040A	PARTICIPANT	\N	PRESENT	0
239628	239186	14073Q	PARTICIPANT	\N	PRESENT	0
239588	238872	19713W	PARTICIPANT	\N	PRESENT	0
239589	238872	08055A	PARTICIPANT	\N	PRESENT	0
239590	238872	19289C	PARTICIPANT	\N	PRESENT	0
239591	238872	14169X	PARTICIPANT	\N	PRESENT	0
239592	238872	15447F	PARTICIPANT	\N	PRESENT	0
239593	238872	14093U	PARTICIPANT	\N	PRESENT	0
239594	238872	08009T	PRESIDENT	0	PRESENT	0
239595	238872	19737F	PARTICIPANT	\N	PRESENT	0
239596	238872	19733B	PARTICIPANT	\N	EXCUSE	0
239597	238872	04097T	PARTICIPANT	\N	EXCUSE	0
239598	238872	19745F	PARTICIPANT	\N	EXCUSE	0
239599	238872	19599P	PARTICIPANT	\N	EXCUSE	0
239601	239186	04070G	PRESIDENT	0	PRESENT	0
239602	239186	19699S	PARTICIPANT	\N	PRESENT	0
239603	239186	14229S	PARTICIPANT	\N	PRESENT	0
239604	239186	14241N	PARTICIPANT	\N	PRESENT	0
239605	239186	19573D	PARTICIPANT	\N	PRESENT	0
239606	239186	14249W	PARTICIPANT	\N	PRESENT	0
239607	239186	08031R	PARTICIPANT	\N	PRESENT	0
239608	239186	14059S	PARTICIPANT	\N	PRESENT	0
239609	239186	14061L	PARTICIPANT	\N	PRESENT	0
239610	239186	04057K	PARTICIPANT	\N	PRESENT	0
239611	239186	08043V	PARTICIPANT	\N	PRESENT	0
239612	239186	19693L	PARTICIPANT	\N	PRESENT	0
239613	239186	87003B	PARTICIPANT	\N	PRESENT	0
239614	239186	14030Q	PARTICIPANT	\N	PRESENT	0
239615	239186	19731Y	PARTICIPANT	\N	PRESENT	0
239616	239186	08020N	PARTICIPANT	\N	PRESENT	0
239617	239186	04059M	PARTICIPANT	\N	PRESENT	0
239618	239186	19735D	PARTICIPANT	\N	PRESENT	0
239619	239186	11109J	PARTICIPANT	\N	PRESENT	0
239620	239186	14063N	PARTICIPANT	\N	PRESENT	0
239621	239186	14109K	PARTICIPANT	\N	PRESENT	0
239622	239186	11083R	PARTICIPANT	\N	PRESENT	0
239623	239186	11104D	PARTICIPANT	\N	PRESENT	0
239624	239186	11043H	PARTICIPANT	\N	PRESENT	0
239625	239186	19749K	PARTICIPANT	\N	PRESENT	0
239626	239186	04018C	PARTICIPANT	\N	PRESENT	0
239627	239186	19621T	PARTICIPANT	\N	PRESENT	0
239631	239630	04070G	PARTICIPANT	\N	PRESENT	0
239632	239630	11109J	PARTICIPANT	\N	PRESENT	0
239633	239630	19621T	PARTICIPANT	\N	PRESENT	0
239634	239630	08020N	PARTICIPANT	\N	PRESENT	0
239635	239630	87003B	PARTICIPANT	\N	PRESENT	0
239636	239630	11083R	PARTICIPANT	\N	PRESENT	0
239637	239630	19731Y	PARTICIPANT	\N	PRESENT	0
239638	239630	14061L	PARTICIPANT	\N	PRESENT	0
239639	239630	08031R	PARTICIPANT	\N	PRESENT	0
239640	239630	08039A	PARTICIPANT	\N	PRESENT	0
239641	239630	11104D	PARTICIPANT	\N	PRESENT	0
239642	239630	14063N	PARTICIPANT	\N	PRESENT	0
239643	239630	04057K	PARTICIPANT	\N	PRESENT	0
239644	239630	14109K	PARTICIPANT	\N	PRESENT	0
239645	239630	92040Q	PARTICIPANT	\N	PRESENT	0
239646	239630	19593H	PARTICIPANT	\N	PRESENT	0
239647	239630	19533U	PARTICIPANT	\N	PRESENT	0
239648	239630	19735D	PARTICIPANT	\N	PRESENT	0
239649	239630	14229S	PARTICIPANT	\N	PRESENT	0
239650	239630	14107H	PARTICIPANT	\N	PRESENT	0
239651	239630	11043H	PARTICIPANT	\N	PRESENT	0
239652	239630	04018C	PARTICIPANT	\N	PRESENT	0
239653	239630	19749K	PARTICIPANT	\N	PRESENT	0
239654	239630	19573D	PARTICIPANT	\N	PRESENT	0
239655	239630	12041X	PARTICIPANT	\N	PRESENT	0
239673	239666	11077T	PARTICIPANT	\N	PRESENT	0
239674	239666	17589D	PARTICIPANT	\N	PRESENT	0
239675	239666	14221J	PARTICIPANT	\N	PRESENT	0
239676	239666	14105F	PARTICIPANT	\N	PRESENT	0
239677	239666	19691J	PARTICIPANT	\N	PRESENT	0
239678	239666	04045F	PARTICIPANT	\N	PRESENT	0
239679	239666	11063M	PARTICIPANT	\N	PRESENT	0
239680	239666	19701S	PARTICIPANT	\N	PRESENT	0
239681	239666	88008L	PARTICIPANT	\N	PRESENT	0
239682	239666	11045K	PARTICIPANT	\N	PRESENT	0
239683	239666	14261S	PARTICIPANT	\N	PRESENT	0
239684	239666	19415P	PARTICIPANT	\N	PRESENT	0
239685	239666	19577H	PARTICIPANT	\N	PRESENT	0
239686	239666	19727D	PARTICIPANT	\N	PRESENT	0
239687	239666	14195A	PARTICIPANT	\N	PRESENT	0
239688	239666	14071N	PARTICIPANT	\N	PRESENT	0
239689	239666	14281W	PARTICIPANT	\N	PRESENT	0
239690	239666	14237S	PARTICIPANT	\N	PRESENT	0
239691	239666	14119M	PARTICIPANT	\N	PRESENT	0
239692	239666	19717B	PARTICIPANT	\N	PRESENT	0
239693	239666	19679N	PARTICIPANT	\N	PRESENT	0
239696	239666	14227Q	PARTICIPANT	\N	PRESENT	0
239698	239666	19629C	PARTICIPANT	\N	PRESENT	0
239699	239666	19737F	PARTICIPANT	\N	PRESENT	0
239700	239666	08052W	PARTICIPANT	\N	PRESENT	0
239702	239666	04092N	PARTICIPANT	\N	PRESENT	0
239703	239666	14147R	PARTICIPANT	\N	PRESENT	0
239704	239666	11049P	PARTICIPANT	\N	PRESENT	0
239705	239666	04088S	PARTICIPANT	\N	PRESENT	0
239706	239666	10006L	PARTICIPANT	\N	PRESENT	0
239707	239666	19467C	PARTICIPANT	\N	PRESENT	0
239708	239666	19581D	PARTICIPANT	\N	PRESENT	0
239709	239666	14038Y	PARTICIPANT	\N	PRESENT	0
239710	239666	95030B	PARTICIPANT	\N	PRESENT	0
239711	239666	04061F	PARTICIPANT	\N	PRESENT	0
239712	239666	19543W	PARTICIPANT	\N	PRESENT	0
239713	239666	14031R	PARTICIPANT	\N	PRESENT	0
239714	239666	14157T	PARTICIPANT	\N	PRESENT	0
239715	239666	17779H	PARTICIPANT	\N	PRESENT	0
239716	239666	14207L	PARTICIPANT	\N	PRESENT	0
239717	239666	14055N	PARTICIPANT	\N	PRESENT	0
239718	239666	14267Y	PARTICIPANT	\N	PRESENT	0
239719	239666	14042U	PARTICIPANT	\N	PRESENT	0
239720	239666	11109J	PARTICIPANT	\N	PRESENT	0
239721	239666	19657G	PARTICIPANT	\N	PRESENT	0
239722	239666	14033T	PARTICIPANT	\N	PRESENT	0
239723	239666	01043Q	PARTICIPANT	\N	PRESENT	0
239724	239666	19383Y	PARTICIPANT	\N	PRESENT	0
239725	239666	14179A	PARTICIPANT	\N	PRESENT	0
239726	239666	19553Y	PARTICIPANT	\N	PRESENT	0
239727	239666	08019V	PARTICIPANT	\N	PRESENT	0
239728	239666	14028W	PARTICIPANT	\N	PRESENT	0
239729	239666	19441R	PARTICIPANT	\N	PRESENT	0
239730	239666	19387D	PARTICIPANT	\N	PRESENT	0
239731	239666	14213J	PARTICIPANT	\N	PRESENT	0
239732	239666	19349W	PARTICIPANT	\N	PRESENT	0
239733	239666	19713W	PARTICIPANT	\N	PRESENT	0
239734	239666	19335Q	PARTICIPANT	\N	PRESENT	0
239735	239666	19673G	PARTICIPANT	\N	PRESENT	0
239736	239666	19253P	PARTICIPANT	\N	PRESENT	0
239737	239666	14135M	PARTICIPANT	\N	PRESENT	0
239738	239666	14265W	PARTICIPANT	\N	PRESENT	0
239739	239666	97011G	PARTICIPANT	\N	PRESENT	0
239748	239666	14069U	PARTICIPANT	\N	PRESENT	0
239749	239666	19565D	PARTICIPANT	\N	PRESENT	0
239750	239666	14219Q	PARTICIPANT	\N	PRESENT	0
239752	239751	19651A	PARTICIPANT	\N	PRESENT	0
239753	239751	19545Y	PARTICIPANT	\N	PRESENT	0
239755	239666	18083K	PARTICIPANT	\N	PRESENT	0
239757	239666	01024M	PARTICIPANT	\N	PRESENT	0
239758	239666	19503N	PARTICIPANT	\N	PRESENT	0
239759	239666	11067R	PARTICIPANT	\N	PRESENT	0
239760	239666	19413M	PARTICIPANT	\N	PRESENT	0
239761	239666	19685L	PARTICIPANT	\N	PRESENT	0
239762	239666	11085T	PARTICIPANT	\N	PRESENT	0
239763	239666	19525U	PARTICIPANT	\N	PRESENT	0
214628	214627	14215L	PARTICIPANT	\N	PRESENT	0
214630	214629	14215L	PARTICIPANT	\N	PRESENT	0
214681	214623	19383Y	PARTICIPANT	\N	PRESENT	0
214632	214623	19515S	PARTICIPANT	\N	PRESENT	0
214813	205652	19563B	PARTICIPANT	\N	EXCUSE	0
217248	217247	14331P	PARTICIPANT	\N	PRESENT	0
217250	217249	14331P	PARTICIPANT	\N	PRESENT	0
214636	214623	08068F	PARTICIPANT	\N	PRESENT	0
217252	217251	89017R	PARTICIPANT	\N	PRESENT	0
214639	214623	14329V	PARTICIPANT	\N	PRESENT	0
214640	214623	08028W	PARTICIPANT	\N	EXCUSE	0
217256	217255	89017R	PARTICIPANT	\N	PRESENT	0
217287	211160	11040E	PARTICIPANT	\N	PRESENT	0
214643	214623	80013X	PARTICIPANT	\N	PRESENT	0
217288	211160	19667J	PARTICIPANT	\N	PRESENT	0
214645	214623	14357A	PARTICIPANT	\N	PRESENT	0
214646	214623	08038Y	PARTICIPANT	\N	PRESENT	0
217294	217293	98050T	PARTICIPANT	\N	PRESENT	0
217295	217293	98029W	PARTICIPANT	\N	PRESENT	0
217297	217296	14235Q	PARTICIPANT	\N	PRESENT	0
217298	217296	04040A	PARTICIPANT	\N	PRESENT	0
214651	214623	14187A	PARTICIPANT	\N	PRESENT	0
217300	217299	14235Q	PARTICIPANT	\N	PRESENT	0
214653	214623	19695N	PARTICIPANT	\N	PRESENT	0
214654	214623	19565D	PARTICIPANT	\N	PRESENT	0
214655	214623	14033T	PARTICIPANT	\N	PRESENT	0
214656	214623	14081Q	PARTICIPANT	\N	EXCUSE	0
214657	214623	19591F	PARTICIPANT	\N	PRESENT	0
214658	214623	19511N	PARTICIPANT	\N	PRESENT	0
214659	214623	11099A	PARTICIPANT	\N	PRESENT	0
214660	214623	04049K	PARTICIPANT	\N	PRESENT	0
214661	214623	08015R	PARTICIPANT	\N	PRESENT	0
217301	217299	04040A	PARTICIPANT	\N	PRESENT	0
217309	217308	19651A	PARTICIPANT	\N	PRESENT	0
214664	214623	19441R	PARTICIPANT	\N	PRESENT	0
217310	217308	11053K	PARTICIPANT	\N	PRESENT	0
217311	217308	14085U	PARTICIPANT	\N	PRESENT	0
214667	214623	19563B	PARTICIPANT	\N	PRESENT	0
214668	214623	19369B	PARTICIPANT	\N	PRESENT	0
214669	214623	14257W	PARTICIPANT	\N	PRESENT	0
214670	214623	14265W	PARTICIPANT	\N	PRESENT	0
217312	217308	04071H	PARTICIPANT	\N	PRESENT	0
214672	214623	04088S	PARTICIPANT	\N	PRESENT	0
214673	214623	11090Q	PRESIDENT	0	PRESENT	0
214674	214623	04043D	PARTICIPANT	\N	PRESENT	0
214675	214623	14135M	PARTICIPANT	\N	PRESENT	0
214676	214623	19269X	PARTICIPANT	\N	PRESENT	0
217313	217308	11074Q	PARTICIPANT	\N	PRESENT	0
217314	217308	11048N	PARTICIPANT	\N	PRESENT	0
214679	214623	19301E	PARTICIPANT	\N	PRESENT	0
214680	214623	19413M	PARTICIPANT	\N	PRESENT	0
217315	217308	08011M	PARTICIPANT	\N	PRESENT	0
217316	217308	14225N	PARTICIPANT	\N	PRESENT	0
217784	215602	14028W	PARTICIPANT	\N	EXCUSE	0
218421	207714	14051J	PARTICIPANT	\N	PRESENT	0
218422	207714	14355X	PARTICIPANT	\N	PRESENT	0
218423	207714	19657G	PARTICIPANT	\N	PRESENT	0
218424	207714	14119M	PARTICIPANT	\N	PRESENT	0
218425	207714	14001X	PARTICIPANT	\N	PRESENT	0
218426	207714	19367Y	PARTICIPANT	\N	PRESENT	0
218427	207714	14079W	PARTICIPANT	\N	PRESENT	0
218428	207714	14087W	PARTICIPANT	\N	PRESENT	0
218429	207714	95041E	PARTICIPANT	\N	PRESENT	0
218430	207714	19703U	PARTICIPANT	\N	PRESENT	0
218431	207714	19507S	PARTICIPANT	\N	PRESENT	0
218432	207714	14213J	PARTICIPANT	\N	PRESENT	0
218433	207714	14191V	PARTICIPANT	\N	PRESENT	0
218434	207714	19527W	PARTICIPANT	\N	PRESENT	0
218435	207714	14042U	PARTICIPANT	\N	PRESENT	0
218436	207714	14219Q	PARTICIPANT	\N	PRESENT	0
218437	207714	08061X	PARTICIPANT	\N	PRESENT	0
218438	207714	19415P	PARTICIPANT	\N	PRESENT	0
218439	207714	98050T	PARTICIPANT	\N	PRESENT	0
218463	207714	19735D	PARTICIPANT	\N	PRESENT	0
218446	207714	19333N	PARTICIPANT	\N	PRESENT	0
218453	207714	14033T	PARTICIPANT	\N	PRESENT	0
218464	207714	14327T	PARTICIPANT	\N	PRESENT	0
218467	207714	10006L	PARTICIPANT	\N	PRESENT	0
218473	207714	80013X	PARTICIPANT	\N	PRESENT	0
218474	207714	14229S	PARTICIPANT	\N	PRESENT	0
218475	207714	08020N	PARTICIPANT	\N	PRESENT	0
218476	207714	11012A	PARTICIPANT	\N	PRESENT	0
218538	216828	04071H	PARTICIPANT	\N	PRESENT	0
218539	216828	01057W	PARTICIPANT	\N	PRESENT	0
218540	216828	14001X	PARTICIPANT	\N	PRESENT	0
218541	216828	04044E	PARTICIPANT	\N	PRESENT	0
218542	216828	04047H	PARTICIPANT	\N	PRESENT	0
218543	216828	14225N	PARTICIPANT	\N	PRESENT	0
218544	216828	19671E	PARTICIPANT	\N	PRESENT	0
218545	216828	05008E	PRESIDENT	0	PRESENT	0
218546	216828	19447X	PARTICIPANT	\N	PRESENT	0
218547	216828	14179A	PARTICIPANT	\N	PRESENT	0
218548	216828	14147R	PARTICIPANT	\N	PRESENT	0
218549	216828	14215L	PARTICIPANT	\N	PRESENT	0
218550	216828	14259Y	PARTICIPANT	\N	PRESENT	0
218551	216828	19649G	PARTICIPANT	\N	PRESENT	0
218552	216828	07034Q	PARTICIPANT	\N	PRESENT	0
218553	216828	08045X	PARTICIPANT	\N	PRESENT	0
218554	216828	01024M	PARTICIPANT	\N	PRESENT	0
218555	216828	04038G	PARTICIPANT	\N	PRESENT	0
218556	216828	14173T	PARTICIPANT	\N	PRESENT	0
218557	216828	19725B	PARTICIPANT	\N	PRESENT	0
218558	216828	14089Y	PARTICIPANT	\N	PRESENT	0
218413	217469	19269X	PARTICIPANT	\N	PRESENT	0
218414	217469	14205J	PARTICIPANT	\N	PRESENT	0
218415	217469	04088S	PARTICIPANT	\N	PRESENT	0
218416	217469	11056N	PARTICIPANT	\N	PRESENT	0
218417	217469	14115H	PARTICIPANT	\N	PRESENT	0
218418	217469	14207L	PARTICIPANT	\N	PRESENT	0
218419	217469	04043D	PARTICIPANT	\N	PRESENT	0
218420	217469	17589D	PARTICIPANT	\N	PRESENT	0
218559	216828	19729F	PARTICIPANT	\N	PRESENT	0
218560	216828	14199E	PARTICIPANT	\N	PRESENT	0
218561	216828	14069U	PARTICIPANT	\N	PRESENT	0
218562	216828	11049P	PARTICIPANT	\N	PRESENT	0
218563	216828	14111D	PARTICIPANT	\N	PRESENT	0
218564	216828	14065Q	PARTICIPANT	\N	PRESENT	0
218565	216828	95063L	PARTICIPANT	\N	PRESENT	0
218566	216828	11026G	PARTICIPANT	\N	PRESENT	0
218567	216828	19543W	PARTICIPANT	\N	PRESENT	0
218568	216828	19581D	PARTICIPANT	\N	PRESENT	0
218569	216828	19585H	PARTICIPANT	\N	PRESENT	0
218570	216828	04008A	PARTICIPANT	\N	PRESENT	0
218571	216828	19673G	PARTICIPANT	\N	PRESENT	0
218572	216828	01028R	PARTICIPANT	\N	PRESENT	0
218573	216828	14231L	PARTICIPANT	\N	PRESENT	0
218574	216828	08018U	PARTICIPANT	\N	EXCUSE	0
218575	217573	14042U	PARTICIPANT	\N	PRESENT	0
218576	217573	10006L	PARTICIPANT	\N	PRESENT	0
218577	217573	19521Q	PARTICIPANT	\N	PRESENT	0
218578	207715	01043Q	PARTICIPANT	\N	PRESENT	0
218579	207715	11063M	PARTICIPANT	\N	PRESENT	0
218580	207715	11031D	PARTICIPANT	\N	PRESENT	0
218581	207715	19593H	PARTICIPANT	\N	PRESENT	0
218582	207715	14235Q	PARTICIPANT	\N	PRESENT	0
218583	207715	19565D	PARTICIPANT	\N	PRESENT	0
218584	207715	19715Y	PARTICIPANT	\N	PRESENT	0
218585	207715	19727D	PARTICIPANT	\N	PRESENT	0
218586	207715	17779H	PARTICIPANT	\N	PRESENT	0
218587	207715	19591F	PARTICIPANT	\N	PRESENT	0
218588	207715	19413M	PARTICIPANT	\N	PRESENT	0
218589	207715	14001X	PARTICIPANT	\N	PRESENT	0
218590	207715	08073C	PARTICIPANT	\N	PRESENT	0
218591	207715	08017T	PARTICIPANT	\N	PRESENT	0
218592	207715	19295A	PARTICIPANT	\N	PRESENT	0
218593	207715	14081Q	PARTICIPANT	\N	PRESENT	0
218594	207715	14281W	PARTICIPANT	\N	PRESENT	0
218595	207715	11067R	PARTICIPANT	\N	PRESENT	0
218596	207715	08052W	PARTICIPANT	\N	PRESENT	0
218597	207715	14229S	PARTICIPANT	\N	PRESENT	0
218598	207715	14239U	PARTICIPANT	\N	PRESENT	0
218599	207715	19697Q	PARTICIPANT	\N	PRESENT	0
218600	207715	19681G	PARTICIPANT	\N	PRESENT	0
218601	207715	04045F	PARTICIPANT	\N	PRESENT	0
218602	207715	14261S	PARTICIPANT	\N	PRESENT	0
218603	207715	17589D	PARTICIPANT	\N	PRESENT	0
218604	207715	14195A	PARTICIPANT	\N	PRESENT	0
218605	207715	19479G	PARTICIPANT	\N	PRESENT	0
218606	207715	19713W	PARTICIPANT	\N	PRESENT	0
218607	207715	19737F	PARTICIPANT	\N	PRESENT	0
218608	207715	14042U	PARTICIPANT	\N	PRESENT	0
218609	207715	19739H	PARTICIPANT	\N	PRESENT	0
218610	207715	19335Q	PARTICIPANT	\N	PRESENT	0
218611	207715	04092N	PARTICIPANT	\N	PRESENT	0
218612	207715	01034P	PARTICIPANT	\N	PRESENT	0
218613	207715	19521Q	PARTICIPANT	\N	PRESENT	0
218614	207715	19569H	PARTICIPANT	\N	PRESENT	0
218615	207715	01025N	PARTICIPANT	\N	PRESENT	0
232273	230024	19443T	PARTICIPANT	\N	PRESENT	0
232274	230024	04034C	PARTICIPANT	\N	PRESENT	0
232275	230024	01058X	PARTICIPANT	\N	PRESENT	0
232276	230024	16685X	PARTICIPANT	\N	PRESENT	0
232277	230024	04042C	PRESIDENT	0	PRESENT	0
232278	230024	11054L	PARTICIPANT	\N	PRESENT	0
232279	230024	11066Q	PARTICIPANT	\N	PRESENT	0
232280	230024	95037J	PARTICIPANT	\N	PRESENT	0
232281	230024	19421M	PARTICIPANT	\N	PRESENT	0
232282	230024	19709B	PARTICIPANT	\N	PRESENT	0
232283	230024	14193X	PARTICIPANT	\N	PRESENT	0
232284	230024	08049C	PARTICIPANT	\N	PRESENT	0
232285	230024	97011G	PARTICIPANT	\N	PRESENT	0
232286	230024	08047A	PARTICIPANT	\N	PRESENT	0
232287	230024	98029W	PARTICIPANT	\N	PRESENT	0
232288	230024	14133K	PRESIDENT	1	PRESENT	0
232289	230024	14235Q	PARTICIPANT	\N	PRESENT	0
232290	230024	08058D	PARTICIPANT	\N	PRESENT	0
232291	230024	19251M	PARTICIPANT	\N	PRESENT	0
232292	230024	19721W	PARTICIPANT	\N	PRESENT	0
232293	230024	19319Q	PARTICIPANT	\N	PRESENT	0
232294	230024	14105F	PARTICIPANT	\N	PRESENT	0
232295	230024	98018T	PARTICIPANT	\N	PRESENT	0
232296	230024	98022P	PARTICIPANT	\N	PRESENT	0
232297	230024	98050T	PARTICIPANT	\N	PRESENT	0
232298	230024	19583F	PARTICIPANT	\N	PRESENT	0
232299	230024	04040A	PARTICIPANT	\N	PRESENT	0
232300	230024	08056B	PARTICIPANT	\N	PRESENT	0
232301	232243	14217N	PARTICIPANT	\N	PRESENT	0
232302	232243	19663E	PARTICIPANT	\N	EXCUSE	0
232303	232243	04045F	PARTICIPANT	\N	PRESENT	0
232304	232243	14223L	PARTICIPANT	\N	EXCUSE	0
232305	230024	08061X	PARTICIPANT	\N	PRESENT	0
232306	232243	19679N	PARTICIPANT	\N	PRESENT	0
232307	232243	14119M	PARTICIPANT	\N	PRESENT	0
232308	232243	14355X	PARTICIPANT	\N	EXCUSE	0
232309	230024	14255U	PARTICIPANT	\N	PRESENT	0
232310	230024	95030B	PARTICIPANT	\N	PRESENT	0
232311	230024	14079W	PARTICIPANT	\N	PRESENT	0
232312	230024	01062T	PARTICIPANT	\N	PRESENT	0
232313	230024	11041F	PARTICIPANT	\N	PRESENT	0
232314	230024	11027H	PARTICIPANT	\N	PRESENT	0
232315	230024	11064N	PARTICIPANT	\N	PRESENT	0
232316	230024	14267Y	PARTICIPANT	\N	PRESENT	0
232336	230588	14331P	PARTICIPANT	\N	PRESENT	0
232337	230588	04071H	PARTICIPANT	\N	PRESENT	0
232338	230588	95041E	PARTICIPANT	\N	PRESENT	0
232339	230588	19545Y	PARTICIPANT	\N	PRESENT	0
232340	230588	01057W	PARTICIPANT	\N	PRESENT	0
232341	230588	11053K	PARTICIPANT	\N	PRESENT	0
232342	230588	19667J	PARTICIPANT	\N	PRESENT	0
232343	230588	89017R	PARTICIPANT	\N	PRESENT	0
232344	230588	11074Q	PRESIDENT	0	PRESENT	0
232345	230588	11070L	PARTICIPANT	\N	PRESENT	0
232346	230588	14225N	PARTICIPANT	\N	PRESENT	0
232347	230588	19671E	PARTICIPANT	\N	PRESENT	0
232348	230588	14085U	PARTICIPANT	\N	PRESENT	0
232349	230588	08010L	PARTICIPANT	\N	PRESENT	0
232350	230588	14253S	PARTICIPANT	\N	PRESENT	0
232351	230588	19479G	PARTICIPANT	\N	PRESENT	0
232352	230588	19647E	PARTICIPANT	\N	PRESENT	0
232353	230588	19711U	PARTICIPANT	\N	PRESENT	0
232354	230588	08034U	PARTICIPANT	\N	PRESENT	0
232355	230588	19651A	PARTICIPANT	\N	PRESENT	0
232356	230588	19531S	PARTICIPANT	\N	PRESENT	0
232357	230588	08069G	PARTICIPANT	\N	PRESENT	0
232358	230588	19689Q	PARTICIPANT	\N	PRESENT	0
232359	230588	08011M	PARTICIPANT	\N	PRESENT	0
232360	230588	14034U	PARTICIPANT	\N	PRESENT	0
232361	230588	14159V	PARTICIPANT	\N	PRESENT	0
232362	230588	04086Q	PARTICIPANT	\N	PRESENT	0
232363	230588	14083S	PARTICIPANT	\N	PRESENT	0
232364	230588	14199E	PARTICIPANT	\N	PRESENT	0
232365	230588	11012A	PARTICIPANT	\N	PRESENT	0
232366	230588	14121F	PARTICIPANT	\N	PRESENT	0
232367	230588	99004R	PARTICIPANT	\N	PRESENT	0
232368	230588	04061F	PARTICIPANT	\N	PRESENT	0
232369	230588	07029T	PARTICIPANT	\N	EXCUSE	0
232370	230588	11048N	PARTICIPANT	\N	EXCUSE	0
232371	231091	04070G	PRESIDENT	0	PRESENT	0
232372	231091	19699S	PARTICIPANT	\N	PRESENT	0
232373	231091	12041X	PARTICIPANT	\N	PRESENT	0
232374	231091	19533U	PARTICIPANT	\N	PRESENT	0
232375	231091	14229S	PARTICIPANT	\N	PRESENT	0
232376	231091	14241N	PARTICIPANT	\N	PRESENT	0
232377	231091	19573D	PARTICIPANT	\N	PRESENT	0
232378	231091	08017T	PARTICIPANT	\N	PRESENT	0
231231	220076	14034U	PARTICIPANT	\N	PRESENT	0
232244	232243	19697Q	PARTICIPANT	\N	PRESENT	0
232245	232243	11067R	PARTICIPANT	\N	PRESENT	0
232246	232243	11097X	PARTICIPANT	\N	PRESENT	0
232247	232243	19415P	PARTICIPANT	\N	PRESENT	0
232248	232243	14026U	PARTICIPANT	\N	PRESENT	0
232249	232243	14227Q	PARTICIPANT	\N	PRESENT	0
232250	232243	19675J	PARTICIPANT	\N	PRESENT	0
232251	232243	11063M	PARTICIPANT	\N	PRESENT	0
232252	232243	14239U	PARTICIPANT	\N	PRESENT	0
232253	232243	19703U	PARTICIPANT	\N	PRESENT	0
232254	232243	14281W	PARTICIPANT	\N	PRESENT	0
232255	232243	14087W	PARTICIPANT	\N	PRESENT	0
232256	232243	14042U	PARTICIPANT	\N	PRESENT	0
232257	232243	19575F	PARTICIPANT	\N	PRESENT	0
232258	232243	14195A	PARTICIPANT	\N	PRESENT	0
232259	232243	19367Y	PARTICIPANT	\N	PRESENT	0
232260	232243	19683J	PARTICIPANT	\N	PRESENT	0
232261	232243	98024R	PRESIDENT	0	PRESENT	0
232262	232243	19521Q	PARTICIPANT	\N	PRESENT	0
232263	232243	04092N	PARTICIPANT	\N	PRESENT	0
232264	232243	11045K	PARTICIPANT	\N	PRESENT	0
232265	232243	08052W	PARTICIPANT	\N	PRESENT	0
232266	232243	19715Y	PARTICIPANT	\N	PRESENT	0
232267	232243	19717B	PARTICIPANT	\N	PRESENT	0
232268	232243	19723Y	PARTICIPANT	\N	PRESENT	0
232269	232243	19727D	PARTICIPANT	\N	PRESENT	0
232270	232243	14071N	PARTICIPANT	\N	PRESENT	0
232271	232243	08048B	PARTICIPANT	\N	EXCUSE	0
232272	232243	08041T	PARTICIPANT	\N	EXCUSE	0
232379	231091	07033P	PARTICIPANT	\N	PRESENT	0
232380	231091	14249W	PARTICIPANT	\N	PRESENT	0
232381	231091	08039A	PARTICIPANT	\N	PRESENT	0
232382	231091	08031R	PARTICIPANT	\N	PRESENT	0
232383	231091	19593H	PARTICIPANT	\N	PRESENT	0
232384	231091	14059S	PARTICIPANT	\N	PRESENT	0
232385	231091	14061L	PARTICIPANT	\N	PRESENT	0
232386	231091	04057K	PARTICIPANT	\N	PRESENT	0
232387	231091	14073Q	PARTICIPANT	\N	PRESENT	0
232388	231091	19611R	PARTICIPANT	\N	PRESENT	0
232389	231091	08035V	PARTICIPANT	\N	PRESENT	0
232390	231091	08043V	PARTICIPANT	\N	PRESENT	0
232391	231091	19693L	PARTICIPANT	\N	PRESENT	0
232392	231091	19399H	PARTICIPANT	\N	PRESENT	0
232393	231091	87003B	PARTICIPANT	\N	PRESENT	0
232394	231091	14030Q	PARTICIPANT	\N	PRESENT	0
232395	231091	19731Y	PARTICIPANT	\N	PRESENT	0
232396	231091	08020N	PARTICIPANT	\N	PRESENT	0
232397	231091	04059M	PARTICIPANT	\N	PRESENT	0
232398	231091	19735D	PARTICIPANT	\N	PRESENT	0
232399	231091	11083R	PARTICIPANT	\N	PRESENT	0
232400	231091	14063N	PARTICIPANT	\N	PRESENT	0
232401	231091	14123H	PARTICIPANT	\N	PRESENT	0
232402	231091	11104D	PARTICIPANT	\N	PRESENT	0
232403	231091	11043H	PARTICIPANT	\N	PRESENT	0
232404	231091	04018C	PARTICIPANT	\N	PRESENT	0
232405	231091	19621T	PARTICIPANT	\N	PRESENT	0
232406	231091	19643A	PARTICIPANT	\N	EXCUSE	0
232407	231091	14107H	PARTICIPANT	\N	EXCUSE	0
232408	232243	19335Q	PARTICIPANT	\N	PRESENT	0
232423	232317	11072N	PARTICIPANT	\N	PRESENT	0
232424	232317	04034C	PARTICIPANT	\N	PRESENT	0
232425	232317	19349W	PARTICIPANT	\N	PRESENT	0
232426	232317	14085U	PARTICIPANT	\N	PRESENT	0
232427	232317	14197C	PARTICIPANT	\N	PRESENT	0
232428	232317	14235Q	PARTICIPANT	\N	PRESENT	0
232429	232317	19479G	PARTICIPANT	\N	PRESENT	0
232430	232317	19731Y	PARTICIPANT	\N	PRESENT	0
232431	232317	04088S	PARTICIPANT	\N	PRESENT	0
232432	232317	19709B	PARTICIPANT	\N	PRESENT	0
232433	232317	08011M	PARTICIPANT	\N	PRESENT	0
232434	232317	14225N	PARTICIPANT	\N	PRESENT	0
232435	232317	19651A	PARTICIPANT	\N	PRESENT	0
232436	232317	19415P	PARTICIPANT	\N	PRESENT	0
232437	232317	97011G	PARTICIPANT	\N	PRESENT	0
232438	232317	19629C	PARTICIPANT	\N	PRESENT	0
232439	232317	11012A	PARTICIPANT	\N	PRESENT	0
232440	232317	19711U	PARTICIPANT	\N	PRESENT	0
232441	232317	95062K	PARTICIPANT	\N	PRESENT	0
232442	232317	14083S	PARTICIPANT	\N	PRESENT	0
232443	232317	14253S	PARTICIPANT	\N	PRESENT	0
232444	232317	19581D	PARTICIPANT	\N	PRESENT	0
215656	214883	04085P	PARTICIPANT	\N	PRESENT	0
215657	214883	08055A	PARTICIPANT	\N	PRESENT	0
215658	214883	14093U	PARTICIPANT	\N	PRESENT	0
215659	214883	19549D	PARTICIPANT	\N	PRESENT	0
215660	214883	96004D	PARTICIPANT	\N	PRESENT	0
215661	214883	08060W	PARTICIPANT	\N	PRESENT	0
215662	214883	19733B	PARTICIPANT	\N	PRESENT	0
215663	214883	19383Y	PARTICIPANT	\N	PRESENT	0
215664	214883	08024S	PARTICIPANT	\N	PRESENT	0
215665	214883	14038Y	PARTICIPANT	\N	PRESENT	0
215666	214883	18083K	PARTICIPANT	\N	PRESENT	0
215667	214883	19701S	PARTICIPANT	\N	PRESENT	0
215668	214883	19681G	PARTICIPANT	\N	PRESENT	0
215669	214883	98023Q	PARTICIPANT	\N	PRESENT	0
215670	214883	19525U	PARTICIPANT	\N	PRESENT	0
215671	214883	11065P	PARTICIPANT	\N	PRESENT	0
216033	214589	08014Q	PARTICIPANT	\N	PRESENT	0
215673	214883	19599P	PARTICIPANT	\N	PRESENT	0
215674	214883	02002K	PARTICIPANT	\N	PRESENT	0
215675	214883	15447F	PARTICIPANT	\N	PRESENT	0
215676	214883	19387D	PARTICIPANT	\N	PRESENT	0
215677	214883	19347U	PARTICIPANT	\N	PRESENT	0
215678	214883	19685L	PARTICIPANT	\N	PRESENT	0
216034	214589	04061F	PARTICIPANT	\N	PRESENT	0
215680	214883	04097T	PARTICIPANT	\N	PRESENT	0
215681	214883	19551W	PARTICIPANT	\N	PRESENT	0
215682	214883	14029X	PARTICIPANT	\N	PRESENT	0
215683	214883	19677L	PARTICIPANT	\N	PRESENT	0
215684	214883	19289C	PARTICIPANT	\N	PRESENT	0
215685	214883	14219Q	PARTICIPANT	\N	PRESENT	0
215686	214883	14103D	PARTICIPANT	\N	PRESENT	0
215687	214883	80027E	PARTICIPANT	\N	PRESENT	0
215688	214883	14031R	PARTICIPANT	\N	PRESENT	0
215689	214883	19637C	PARTICIPANT	\N	PRESENT	0
215690	214883	08009T	PRESIDENT	0	PRESENT	0
215691	214883	14221J	PARTICIPANT	\N	PRESENT	0
215692	214883	14169X	PARTICIPANT	\N	PRESENT	0
215693	214883	14191V	PARTICIPANT	\N	PRESENT	0
215694	214883	14237S	PARTICIPANT	\N	PRESENT	0
215695	214883	17637T	PARTICIPANT	\N	PRESENT	0
215696	214883	05012A	PARTICIPANT	\N	PRESENT	0
215697	214883	19503N	PARTICIPANT	\N	PRESENT	0
215698	214883	19739H	PARTICIPANT	\N	PRESENT	0
216037	214589	08073C	PARTICIPANT	\N	PRESENT	0
215700	214883	95062K	PARTICIPANT	\N	PRESENT	0
215701	214883	19713W	PARTICIPANT	\N	PRESENT	0
215702	214883	14051J	PARTICIPANT	\N	PRESENT	0
215703	214883	14157T	PARTICIPANT	\N	PRESENT	0
215704	214883	19737F	PARTICIPANT	\N	EXCUSE	0
220050	220048	96004D	PARTICIPANT	\N	EXCUSE	0
220051	220048	11054L	PARTICIPANT	\N	EXCUSE	0
223385	223384	14133K	PARTICIPANT	\N	PRESENT	0
223386	223384	14097Y	PARTICIPANT	\N	PRESENT	0
223387	223384	98022P	PARTICIPANT	\N	PRESENT	0
226749	225954	01058X	PARTICIPANT	\N	PRESENT	0
231072	231070	19741B	PARTICIPANT	\N	PRESENT	0
231073	231070	19695N	PARTICIPANT	\N	PRESENT	0
231074	231070	19691J	PARTICIPANT	\N	PRESENT	0
231075	231070	95037J	PARTICIPANT	\N	PRESENT	0
231076	231070	01043Q	PARTICIPANT	\N	PRESENT	0
231077	231070	19369B	PARTICIPANT	\N	PRESENT	0
231078	231070	01034P	PARTICIPANT	\N	PRESENT	0
231079	231070	14033T	PARTICIPANT	\N	PRESENT	0
231080	231070	08053X	PARTICIPANT	\N	PRESENT	0
235375	235356	14034U	PARTICIPANT	\N	PRESENT	0
235376	235356	89017R	PARTICIPANT	\N	EXCUSE	0
235377	235356	14030Q	PARTICIPANT	\N	EXCUSE	0
235378	235356	08060W	PARTICIPANT	\N	EXCUSE	0
235379	235356	14255U	PARTICIPANT	\N	EXCUSE	0
235380	235356	14329V	PARTICIPANT	\N	EXCUSE	0
235381	235356	11031D	PARTICIPANT	\N	EXCUSE	0
235382	235356	14079W	PARTICIPANT	\N	EXCUSE	0
235383	235356	14041T	PARTICIPANT	\N	EXCUSE	0
235384	235356	14187A	PARTICIPANT	\N	EXCUSE	0
235385	235356	14087W	PARTICIPANT	\N	EXCUSE	0
235386	235356	19695N	PARTICIPANT	\N	EXCUSE	0
235387	235356	14026U	PARTICIPANT	\N	EXCUSE	0
235388	235356	14061L	PARTICIPANT	\N	EXCUSE	0
235389	235356	08015R	PARTICIPANT	\N	EXCUSE	0
235390	235356	19671E	PARTICIPANT	\N	EXCUSE	0
235391	235356	08047A	PARTICIPANT	\N	EXCUSE	0
235392	235356	14227Q	PARTICIPANT	\N	EXCUSE	0
235393	235356	19527W	PARTICIPANT	\N	EXCUSE	0
235396	235395	14255U	PARTICIPANT	\N	PRESENT	0
235398	235397	14255U	PARTICIPANT	\N	PRESENT	0
235411	235410	14079W	PARTICIPANT	\N	PRESENT	0
235422	233065	19663E	PARTICIPANT	\N	PRESENT	0
235423	233065	08053X	PARTICIPANT	\N	PRESENT	0
235424	233065	19503N	PARTICIPANT	\N	PRESENT	0
235425	233065	80013X	PARTICIPANT	\N	EXCUSE	0
235508	235507	97011G	PARTICIPANT	\N	PRESENT	0
235509	235507	14255U	PARTICIPANT	\N	PRESENT	0
235510	235507	14195A	PARTICIPANT	\N	PRESENT	0
235511	235507	08056B	PARTICIPANT	\N	PRESENT	0
235512	235507	01057W	PARTICIPANT	\N	PRESENT	0
235513	235507	11026G	PARTICIPANT	\N	PRESENT	0
235514	235507	08010L	PARTICIPANT	\N	PRESENT	0
235515	235507	19729F	PARTICIPANT	\N	PRESENT	0
235516	235507	11012A	PARTICIPANT	\N	PRESENT	0
235517	235507	95062K	PARTICIPANT	\N	PRESENT	0
235600	235599	17637T	PARTICIPANT	\N	PRESENT	0
235602	235601	17637T	PARTICIPANT	\N	PRESENT	0
235604	235603	14157T	PARTICIPANT	\N	PRESENT	0
235605	235603	14031R	PARTICIPANT	\N	PRESENT	0
235607	235606	14157T	PARTICIPANT	\N	PRESENT	0
235608	235606	14031R	PARTICIPANT	\N	PRESENT	0
235989	235988	14121F	PARTICIPANT	\N	PRESENT	0
235991	235990	14085U	PARTICIPANT	\N	PRESENT	0
235992	235990	14253S	PARTICIPANT	\N	PRESENT	0
236103	235526	19703U	PARTICIPANT	\N	PRESENT	0
236104	235526	04092N	PRESIDENT	0	PRESENT	0
236105	235526	14355X	PARTICIPANT	\N	PRESENT	0
236106	235526	14087W	PARTICIPANT	\N	PRESENT	0
236107	235526	11103C	PARTICIPANT	\N	PRESENT	0
236108	235526	08052W	PARTICIPANT	\N	PRESENT	0
236109	235526	19367Y	PARTICIPANT	\N	PRESENT	0
236110	235526	19675J	PARTICIPANT	\N	PRESENT	0
236111	235526	19679N	PARTICIPANT	\N	PRESENT	0
236112	235526	98024R	PARTICIPANT	\N	PRESENT	0
236122	235526	17779H	PARTICIPANT	\N	PRESENT	0
236123	235526	14042U	PARTICIPANT	\N	PRESENT	0
236124	235526	19577H	PARTICIPANT	\N	PRESENT	0
236125	235526	19715Y	PARTICIPANT	\N	PRESENT	0
236126	235526	11031D	PARTICIPANT	\N	PRESENT	0
236127	235487	98035U	PARTICIPANT	\N	PRESENT	0
236128	235487	14111D	PARTICIPANT	\N	PRESENT	0
236129	235487	11010L	PARTICIPANT	\N	PRESENT	0
236130	235487	07034Q	PRESIDENT	0	PRESENT	0
236131	235487	08045X	PARTICIPANT	\N	PRESENT	0
236132	235487	04038G	PARTICIPANT	\N	PRESENT	0
236133	235487	04044E	PARTICIPANT	\N	PRESENT	0
236134	235487	19585H	PARTICIPANT	\N	PRESENT	0
236135	235487	19447X	PARTICIPANT	\N	PRESENT	0
236136	235487	05008E	PARTICIPANT	\N	PRESENT	0
236137	235487	14231L	PARTICIPANT	\N	PRESENT	0
236138	235487	14089Y	PARTICIPANT	\N	PRESENT	0
236139	235487	19729F	PARTICIPANT	\N	PRESENT	0
236140	235487	14147R	PARTICIPANT	\N	PRESENT	0
236141	235487	14151M	PARTICIPANT	\N	PRESENT	0
236142	235487	14069U	PARTICIPANT	\N	PRESENT	0
236143	235487	14215L	PARTICIPANT	\N	PRESENT	0
236144	235487	08018U	PARTICIPANT	\N	PRESENT	0
236145	235526	14026U	PARTICIPANT	\N	PRESENT	0
236146	235526	14213J	PARTICIPANT	\N	PRESENT	0
236147	235526	19527W	PARTICIPANT	\N	PRESENT	0
236148	235526	14071N	PARTICIPANT	\N	PRESENT	0
236149	235487	01024M	PARTICIPANT	\N	PRESENT	0
236150	235526	19723Y	PARTICIPANT	\N	PRESENT	0
236151	235526	14119M	PARTICIPANT	\N	PRESENT	0
236152	235526	11067R	PARTICIPANT	\N	PRESENT	0
236153	235526	01034P	PARTICIPANT	\N	PRESENT	0
236154	235526	10006L	PARTICIPANT	\N	PRESENT	0
236160	236159	19515S	PARTICIPANT	\N	PRESENT	0
236162	236159	19741B	PARTICIPANT	\N	PRESENT	0
238626	238562	11101A	PARTICIPANT	\N	EXCUSE	0
238627	238562	14071N	PARTICIPANT	\N	EXCUSE	0
239764	239666	19723Y	PARTICIPANT	\N	PRESENT	0
239765	239666	14059S	PARTICIPANT	\N	PRESENT	0
239766	239666	80013X	PARTICIPANT	\N	PRESENT	0
239768	239666	19563B	PARTICIPANT	\N	PRESENT	0
239769	239666	19521Q	PARTICIPANT	\N	PRESENT	0
239770	239666	17583W	PARTICIPANT	\N	PRESENT	0
239771	239666	95062K	PARTICIPANT	\N	PRESENT	0
239772	239666	08015R	PARTICIPANT	\N	PRESENT	0
239774	239773	08069G	PARTICIPANT	\N	PRESENT	0
239775	239666	11043H	PARTICIPANT	\N	PRESENT	0
239776	239773	04040A	PARTICIPANT	\N	PRESENT	0
239777	239773	04038G	PARTICIPANT	\N	PRESENT	0
239778	239773	14199E	PARTICIPANT	\N	PRESENT	0
239779	239773	07004J	PARTICIPANT	\N	PRESENT	0
239780	239773	14211G	PARTICIPANT	\N	PRESENT	0
239781	239773	04049K	PARTICIPANT	\N	PRESENT	0
239782	239773	10015M	PARTICIPANT	\N	PRESENT	0
239783	239666	14259Y	PARTICIPANT	\N	PRESENT	0
239784	239666	19507S	PARTICIPANT	\N	PRESENT	0
239785	239666	08024S	PARTICIPANT	\N	PRESENT	0
239786	239666	14079W	PARTICIPANT	\N	PRESENT	0
239787	239666	19729F	PARTICIPANT	\N	PRESENT	0
239788	239666	19675J	PARTICIPANT	\N	PRESENT	0
239789	239666	19709B	PARTICIPANT	\N	PRESENT	0
239790	239666	19549D	PARTICIPANT	\N	PRESENT	0
239791	239666	02002K	PARTICIPANT	\N	PRESENT	0
239792	239751	04038G	PARTICIPANT	\N	PRESENT	0
239793	239751	19719D	PARTICIPANT	\N	PRESENT	0
239794	239751	14151M	PARTICIPANT	\N	PRESENT	0
239795	239751	14087W	PARTICIPANT	\N	PRESENT	0
239796	239751	14026U	PARTICIPANT	\N	PRESENT	0
239797	239751	11048N	PRESIDENT	0	PRESENT	0
239798	239751	04049K	PARTICIPANT	\N	PRESENT	0
239799	239751	19711U	PARTICIPANT	\N	PRESENT	0
239800	239751	19441R	PARTICIPANT	\N	PRESENT	0
239801	239751	14103D	PARTICIPANT	\N	PRESENT	0
239802	239751	11067R	PARTICIPANT	\N	PRESENT	0
239803	239751	19503N	PARTICIPANT	\N	PRESENT	0
239804	239751	19749K	PARTICIPANT	\N	PRESENT	0
239805	239751	14173T	PARTICIPANT	\N	PRESENT	0
239900	239667	08052W	PARTICIPANT	\N	PRESENT	0
239901	239667	14281W	PARTICIPANT	\N	PRESENT	0
239902	239667	19349W	PARTICIPANT	\N	PRESENT	0
239903	239667	19637C	PARTICIPANT	\N	PRESENT	0
239904	239667	80013X	PARTICIPANT	\N	PRESENT	0
239905	239667	19503N	PARTICIPANT	\N	PRESENT	0
239907	239667	19727D	PARTICIPANT	\N	PRESENT	0
239908	239906	14030Q	PRESIDENT	0	PRESENT	0
239909	239906	80013X	PARTICIPANT	\N	PRESENT	0
239910	239667	19549D	PARTICIPANT	\N	PRESENT	0
239911	239906	14109K	PARTICIPANT	\N	PRESENT	0
239912	239906	08043V	PARTICIPANT	\N	EXCUSE	0
239913	239667	19563B	PARTICIPANT	\N	PRESENT	0
239914	239906	19701S	PARTICIPANT	\N	EXCUSE	0
239915	239906	19577H	PARTICIPANT	\N	EXCUSE	0
239916	239667	19387D	PARTICIPANT	\N	PRESENT	0
239917	239906	19715Y	PARTICIPANT	\N	EXCUSE	0
239918	239906	08031R	PARTICIPANT	\N	EXCUSE	0
239919	239667	19553Y	PARTICIPANT	\N	PRESENT	0
239920	239906	01043Q	PARTICIPANT	\N	EXCUSE	0
239921	239906	19657G	PARTICIPANT	\N	EXCUSE	0
239922	239667	02002K	PARTICIPANT	\N	PRESENT	0
239923	239667	14195A	PARTICIPANT	\N	PRESENT	0
239924	239667	19717B	PARTICIPANT	\N	PRESENT	0
239925	239667	19441R	PARTICIPANT	\N	PRESENT	0
239926	239667	14219Q	PARTICIPANT	\N	PRESENT	0
239927	239667	14042U	PARTICIPANT	\N	PRESENT	0
239928	239667	19713W	PARTICIPANT	\N	PRESENT	0
239929	239667	14267Y	PARTICIPANT	\N	PRESENT	0
239930	239667	19521Q	PARTICIPANT	\N	PRESENT	0
239931	239667	19581D	PARTICIPANT	\N	PRESENT	0
239932	239667	14079W	PARTICIPANT	\N	PRESENT	0
239933	239667	19335Q	PARTICIPANT	\N	PRESENT	0
239934	239667	19685L	PARTICIPANT	\N	PRESENT	0
239935	239667	04061F	PARTICIPANT	\N	PRESENT	0
239936	239906	14249W	PARTICIPANT	\N	PRESENT	0
239937	239667	17583W	PARTICIPANT	\N	PRESENT	0
239938	239667	19577H	PARTICIPANT	\N	PRESENT	0
239939	239667	08024S	PARTICIPANT	\N	PRESENT	0
239940	239667	19253P	PARTICIPANT	\N	PRESENT	0
239941	239667	01024M	PARTICIPANT	\N	PRESENT	0
239942	239667	14055N	PARTICIPANT	\N	PRESENT	0
239943	239667	19383Y	PARTICIPANT	\N	PRESENT	0
239944	239667	19729F	PARTICIPANT	\N	PRESENT	0
239945	239667	19399H	PARTICIPANT	\N	PRESENT	0
239946	239667	14157T	PARTICIPANT	\N	PRESENT	0
239947	239667	19657G	PARTICIPANT	\N	PRESENT	0
239948	239667	19413M	PARTICIPANT	\N	PRESENT	0
239949	239667	19507S	PARTICIPANT	\N	PRESENT	0
239950	239667	14033T	PARTICIPANT	\N	PRESENT	0
239951	239667	04088S	PARTICIPANT	\N	PRESENT	0
239952	239667	19723Y	PARTICIPANT	\N	PRESENT	0
239953	239667	08061X	PARTICIPANT	\N	PRESENT	0
239954	239667	14231L	PARTICIPANT	\N	PRESENT	0
239955	239667	19703U	PARTICIPANT	\N	PRESENT	0
239956	239667	11043H	PARTICIPANT	\N	PRESENT	0
239957	239667	99004R	PARTICIPANT	\N	PRESENT	0
239958	239667	14105F	PARTICIPANT	\N	PRESENT	0
239959	239667	14221J	PARTICIPANT	\N	PRESENT	0
239960	239188	04070G	PRESIDENT	0	PRESENT	0
239961	239188	19699S	PARTICIPANT	\N	PRESENT	0
239962	239188	19533U	PARTICIPANT	\N	PRESENT	0
239963	239188	95015C	PARTICIPANT	\N	PRESENT	0
239964	239188	14229S	PARTICIPANT	\N	PRESENT	0
239965	239188	14241N	PARTICIPANT	\N	PRESENT	0
239966	239188	19573D	PARTICIPANT	\N	PRESENT	0
239967	239188	14107H	PARTICIPANT	\N	PRESENT	0
239968	239188	08017T	PARTICIPANT	\N	PRESENT	0
239969	239188	14249W	PARTICIPANT	\N	PRESENT	0
239970	239188	08039A	PARTICIPANT	\N	PRESENT	0
239971	239188	19593H	PARTICIPANT	\N	PRESENT	0
239972	239188	19643A	PARTICIPANT	\N	PRESENT	0
239973	239188	14061L	PARTICIPANT	\N	PRESENT	0
239974	239188	04057K	PARTICIPANT	\N	PRESENT	0
239975	239188	14073Q	PARTICIPANT	\N	PRESENT	0
239976	239188	19611R	PARTICIPANT	\N	PRESENT	0
239977	239188	08043V	PARTICIPANT	\N	PRESENT	0
239978	239188	19693L	PARTICIPANT	\N	PRESENT	0
239979	239188	14030Q	PARTICIPANT	\N	PRESENT	0
239980	239188	19731Y	PARTICIPANT	\N	PRESENT	0
239981	239188	14251Q	PARTICIPANT	\N	PRESENT	0
239982	239188	19735D	PARTICIPANT	\N	PRESENT	0
239983	239188	14063N	PARTICIPANT	\N	PRESENT	0
239984	239188	14109K	PARTICIPANT	\N	PRESENT	0
239985	239188	14123H	PARTICIPANT	\N	PRESENT	0
239986	239188	11104D	PARTICIPANT	\N	PRESENT	0
239987	239188	19749K	PARTICIPANT	\N	PRESENT	0
239988	239188	19621T	PARTICIPANT	\N	PRESENT	0
239989	239667	14038Y	PARTICIPANT	\N	PRESENT	0
239990	239667	11099A	PARTICIPANT	\N	PRESENT	0
239991	239667	14026U	PARTICIPANT	\N	PRESENT	0
239992	239667	08009T	PARTICIPANT	\N	PRESENT	0
239898	239667	19565D	PARTICIPANT	\N	PRESENT	0
239899	239667	19737F	PARTICIPANT	\N	PRESENT	0
239993	239667	11066Q	PARTICIPANT	\N	PRESENT	0
239994	239667	04059M	PARTICIPANT	\N	PRESENT	0
239995	239667	18083K	PARTICIPANT	\N	PRESENT	0
239996	239667	14135M	PARTICIPANT	\N	PRESENT	0
239997	239667	14249W	PARTICIPANT	\N	PRESENT	0
239998	238606	14089Y	PARTICIPANT	\N	EXCUSE	0
239999	238606	04047H	PARTICIPANT	\N	EXCUSE	0
240000	238606	08018U	PARTICIPANT	\N	EXCUSE	0
240001	238606	19725B	PARTICIPANT	\N	EXCUSE	0
240002	239667	14107H	PARTICIPANT	\N	PRESENT	0
240003	239667	14001X	PARTICIPANT	\N	PRESENT	0
240004	239667	14207L	PARTICIPANT	\N	PRESENT	0
240005	239667	19551W	PARTICIPANT	\N	PRESENT	0
240006	239667	19749K	PARTICIPANT	\N	PRESENT	0
240007	239667	14073Q	PARTICIPANT	\N	PRESENT	0
240008	239667	14069U	PARTICIPANT	\N	PRESENT	0
240009	239667	19631V	PARTICIPANT	\N	PRESENT	0
240010	239667	11065P	PARTICIPANT	\N	PRESENT	0
240011	239667	08015R	PARTICIPANT	\N	PRESENT	0
240012	239667	19611R	PARTICIPANT	\N	PRESENT	0
240013	239667	19467C	PARTICIPANT	\N	PRESENT	0
240015	240014	08031R	PARTICIPANT	\N	PRESENT	0
240016	240014	19749K	PARTICIPANT	\N	PRESENT	0
240017	240014	87003B	PARTICIPANT	\N	PRESENT	0
240018	240014	08043V	PARTICIPANT	\N	PRESENT	0
240020	239667	97011G	PARTICIPANT	\N	PRESENT	0
240021	239667	14265W	PARTICIPANT	\N	PRESENT	0
240022	239667	19415P	PARTICIPANT	\N	PRESENT	0
240023	239667	01048V	PARTICIPANT	\N	PRESENT	0
240024	239667	14097Y	PARTICIPANT	\N	PRESENT	0
240025	239667	08031R	PARTICIPANT	\N	PRESENT	0
240026	239667	11012A	PARTICIPANT	\N	PRESENT	0
240027	239667	19369B	PARTICIPANT	\N	PRESENT	0
213245	213244	19729F	PARTICIPANT	\N	PRESENT	0
213275	213274	10006L	PARTICIPANT	\N	PRESENT	0
215010	215009	11053K	PARTICIPANT	\N	PRESENT	0
215011	215009	14159V	PARTICIPANT	\N	PRESENT	0
215012	215009	05012A	PARTICIPANT	\N	PRESENT	0
218616	207715	19421M	PARTICIPANT	\N	PRESENT	0
218617	207715	14087W	PARTICIPANT	\N	PRESENT	0
218618	207715	95041E	PARTICIPANT	\N	PRESENT	0
218619	207715	04047H	PARTICIPANT	\N	PRESENT	0
218620	207715	14257W	PARTICIPANT	\N	PRESENT	0
218621	207715	14187A	PARTICIPANT	\N	PRESENT	0
218622	207715	10006L	PARTICIPANT	\N	PRESENT	0
218623	207715	19483C	PARTICIPANT	\N	PRESENT	0
218624	207715	11103C	PARTICIPANT	\N	PRESENT	0
218625	207715	19733B	PARTICIPANT	\N	PRESENT	0
218626	207715	19383Y	PARTICIPANT	\N	PRESENT	0
218627	207715	08020N	PARTICIPANT	\N	PRESENT	0
218628	207715	14223L	PARTICIPANT	\N	PRESENT	0
218629	207715	14033T	PARTICIPANT	\N	PRESENT	0
218630	207715	19663E	PARTICIPANT	\N	PRESENT	0
218631	207715	19507S	PARTICIPANT	\N	PRESENT	0
218632	207715	19467C	PARTICIPANT	\N	PRESENT	0
218633	207715	19573D	PARTICIPANT	\N	PRESENT	0
218634	207715	19447X	PARTICIPANT	\N	PRESENT	0
218635	207715	19723Y	PARTICIPANT	\N	PRESENT	0
218636	207715	14255U	PARTICIPANT	\N	PRESENT	0
218637	207715	19367Y	PARTICIPANT	\N	PRESENT	0
218638	207715	19527W	PARTICIPANT	\N	PRESENT	0
218639	207715	14147R	PARTICIPANT	\N	PRESENT	0
218640	207715	17583W	PARTICIPANT	\N	PRESENT	0
218641	207715	19415P	PARTICIPANT	\N	PRESENT	0
218642	207715	80013X	PARTICIPANT	\N	PRESENT	0
218643	207715	19703U	PARTICIPANT	\N	PRESENT	0
218644	207715	11097X	PARTICIPANT	\N	PRESENT	0
218645	207715	14217N	PARTICIPANT	\N	PRESENT	0
218646	207715	14026U	PARTICIPANT	\N	PRESENT	0
218647	207715	14123H	PARTICIPANT	\N	PRESENT	0
218648	207715	14265W	PARTICIPANT	\N	PRESENT	0
218649	207715	14030Q	PARTICIPANT	\N	PRESENT	0
218650	207715	19369B	PARTICIPANT	\N	PRESENT	0
218651	207715	11109J	PARTICIPANT	\N	PRESENT	0
218652	207715	08062Y	PARTICIPANT	\N	PRESENT	0
218653	207715	14053L	PARTICIPANT	\N	PRESENT	0
218654	207715	04043D	PARTICIPANT	\N	PRESENT	0
218655	207715	14215L	PARTICIPANT	\N	PRESENT	0
218656	207715	04070G	PARTICIPANT	\N	PRESENT	0
218657	207715	14197C	PARTICIPANT	\N	PRESENT	0
218658	207715	14227Q	PARTICIPANT	\N	PRESENT	0
218659	207715	14055N	PARTICIPANT	\N	PRESENT	0
218660	207715	14135M	PARTICIPANT	\N	PRESENT	0
218661	207715	14071N	PARTICIPANT	\N	PRESENT	0
218662	207715	19709B	PARTICIPANT	\N	PRESENT	0
218663	207715	19577H	PARTICIPANT	\N	PRESENT	0
218664	207715	18083K	PARTICIPANT	\N	PRESENT	0
218665	207715	11077T	PARTICIPANT	\N	PRESENT	0
218666	207715	19349W	PARTICIPANT	\N	PRESENT	0
218667	207715	14105F	PARTICIPANT	\N	PRESENT	0
218668	207715	14213J	PARTICIPANT	\N	PRESENT	0
218669	207715	14355X	PARTICIPANT	\N	PRESENT	0
218670	207715	19657G	PARTICIPANT	\N	PRESENT	0
218671	207715	11026G	PARTICIPANT	\N	PRESENT	0
218672	207715	11012A	PARTICIPANT	\N	PRESENT	0
218673	207715	14231L	PARTICIPANT	\N	PRESENT	0
218674	207715	04049K	PARTICIPANT	\N	PRESENT	0
218675	207715	11056N	PARTICIPANT	\N	PRESENT	0
218676	207715	14219Q	PARTICIPANT	\N	PRESENT	0
218677	207715	19553Y	PARTICIPANT	\N	PRESENT	0
218678	207715	19719D	PARTICIPANT	\N	PRESENT	0
218679	207715	14083S	PARTICIPANT	\N	PRESENT	0
218680	207715	19563B	PARTICIPANT	\N	PRESENT	0
218681	207715	14119M	PARTICIPANT	\N	PRESENT	0
218682	207715	04097T	PARTICIPANT	\N	PRESENT	0
218683	207715	19679N	PARTICIPANT	\N	PRESENT	0
219852	219851	14030Q	PRESIDENT	0	PRESENT	0
219853	219851	08043V	PARTICIPANT	\N	PRESENT	0
219855	219851	19643A	PARTICIPANT	\N	PRESENT	0
219856	219851	08024S	PARTICIPANT	\N	PRESENT	0
219858	219851	18083K	PARTICIPANT	\N	PRESENT	0
219859	219851	19701S	PARTICIPANT	\N	PRESENT	0
219860	219851	11031D	PARTICIPANT	\N	PRESENT	0
219863	219851	19693L	PARTICIPANT	\N	PRESENT	0
219865	219851	14217N	PARTICIPANT	\N	PRESENT	0
219874	219851	14249W	PARTICIPANT	\N	PRESENT	0
219876	219851	19599P	PARTICIPANT	\N	PRESENT	0
219878	219851	04035D	PARTICIPANT	\N	EXCUSE	0
219880	219851	19685L	PARTICIPANT	\N	PRESENT	0
219881	219851	08031R	PARTICIPANT	\N	PRESENT	0
219882	219851	08017T	PARTICIPANT	\N	PRESENT	0
219883	219851	14251Q	PARTICIPANT	\N	PRESENT	0
219884	219851	14235Q	PARTICIPANT	\N	PRESENT	0
219885	219851	19679N	PARTICIPANT	\N	PRESENT	0
219886	219851	19269X	PARTICIPANT	\N	EXCUSE	0
219887	219851	11045K	PARTICIPANT	\N	PRESENT	0
221327	221326	14089Y	PARTICIPANT	\N	PRESENT	0
221354	221353	11049P	PARTICIPANT	\N	PRESENT	0
221850	221849	14239U	PARTICIPANT	\N	PRESENT	0
221851	221849	19415P	PARTICIPANT	\N	PRESENT	0
222395	222380	14030Q	PARTICIPANT	\N	EXCUSE	0
221853	221849	08052W	PARTICIPANT	\N	PRESENT	0
222397	222380	14105F	PARTICIPANT	\N	PRESENT	0
221855	221849	10006L	PARTICIPANT	\N	PRESENT	0
222398	222380	08068F	PARTICIPANT	\N	PRESENT	0
221857	221849	19553Y	PARTICIPANT	\N	PRESENT	0
221858	221849	19683J	PARTICIPANT	\N	PRESENT	0
222399	222380	14255U	PARTICIPANT	\N	PRESENT	0
221860	221849	11067R	PARTICIPANT	\N	PRESENT	0
221861	221849	04092N	PRESIDENT	0	PRESENT	0
221862	221849	11097X	PARTICIPANT	\N	PRESENT	0
221863	221849	01034P	PARTICIPANT	\N	PRESENT	0
222401	222380	14053L	PARTICIPANT	\N	PRESENT	0
222407	222380	14187A	PARTICIPANT	\N	PRESENT	0
222405	222380	19545Y	PARTICIPANT	\N	EXCUSE	0
222406	222380	14041T	PARTICIPANT	\N	PRESENT	0
222408	222380	14087W	PARTICIPANT	\N	PRESENT	0
222409	222380	19695N	PARTICIPANT	\N	PRESENT	0
222410	222380	14026U	PARTICIPANT	\N	PRESENT	0
222411	222380	19591F	PARTICIPANT	\N	PRESENT	0
222412	222380	14061L	PARTICIPANT	\N	EXCUSE	0
222413	222380	14039A	PARTICIPANT	\N	EXCUSE	0
222414	222380	11099A	PARTICIPANT	\N	PRESENT	0
222415	222380	08015R	PARTICIPANT	\N	PRESENT	0
222416	222380	14205J	PARTICIPANT	\N	PRESENT	0
222417	222380	19671E	PARTICIPANT	\N	PRESENT	0
222418	222380	14265W	PARTICIPANT	\N	PRESENT	0
222419	222380	14253S	PARTICIPANT	\N	EXCUSE	0
222420	222380	08047A	PARTICIPANT	\N	PRESENT	0
222421	222380	04088S	PARTICIPANT	\N	PRESENT	0
222422	222380	19669L	PARTICIPANT	\N	EXCUSE	0
222423	222380	14051J	PARTICIPANT	\N	PRESENT	0
222424	222380	14227Q	PARTICIPANT	\N	EXCUSE	0
222425	222380	14157T	PARTICIPANT	\N	PRESENT	0
222426	222380	04034C	PARTICIPANT	\N	EXCUSE	0
222431	222380	14329V	PARTICIPANT	\N	EXCUSE	0
222432	222380	11031D	PARTICIPANT	\N	EXCUSE	0
222433	222380	14079W	PARTICIPANT	\N	EXCUSE	0
222434	222380	19521Q	PARTICIPANT	\N	EXCUSE	0
222435	222380	16685X	PARTICIPANT	\N	EXCUSE	0
222535	222534	05008E	PRESIDENT	0	PRESENT	0
222536	222534	14231L	PARTICIPANT	\N	EXCUSE	0
222537	222534	19543W	PARTICIPANT	\N	PRESENT	0
222538	222534	11033F	PARTICIPANT	\N	PRESENT	0
222539	222534	14065Q	PARTICIPANT	\N	PRESENT	0
222540	222534	14069U	PARTICIPANT	\N	PRESENT	0
222541	222534	14089Y	PARTICIPANT	\N	PRESENT	0
222542	222534	04047H	PARTICIPANT	\N	PRESENT	0
222543	222534	14053L	PARTICIPANT	\N	PRESENT	0
222544	222534	19629C	PARTICIPANT	\N	PRESENT	0
222545	222534	04038G	PARTICIPANT	\N	PRESENT	0
222546	222534	19253P	PARTICIPANT	\N	PRESENT	0
222547	222534	14259Y	PARTICIPANT	\N	PRESENT	0
222548	222534	04008A	PARTICIPANT	\N	PRESENT	0
222549	222534	19719D	PARTICIPANT	\N	PRESENT	0
222550	222534	14041T	PARTICIPANT	\N	PRESENT	0
222551	222534	01024M	PARTICIPANT	\N	PRESENT	0
222553	222534	14151M	PARTICIPANT	\N	PRESENT	0
222554	222534	19673G	PARTICIPANT	\N	PRESENT	0
222555	222534	08045X	PARTICIPANT	\N	PRESENT	0
222556	222534	08018U	PARTICIPANT	\N	PRESENT	0
222557	222534	11010L	PARTICIPANT	\N	PRESENT	0
222558	222534	19649G	PARTICIPANT	\N	PRESENT	0
222559	222534	11049P	PARTICIPANT	\N	PRESENT	0
222560	222534	19725B	PARTICIPANT	\N	PRESENT	0
222561	222534	14179A	PARTICIPANT	\N	PRESENT	0
222562	222534	08044W	PARTICIPANT	\N	PRESENT	0
222563	222534	19447X	PARTICIPANT	\N	PRESENT	0
222564	222534	14021P	PARTICIPANT	\N	PRESENT	0
222565	222534	19489J	PARTICIPANT	\N	PRESENT	0
222566	222534	11026G	PARTICIPANT	\N	PRESENT	0
230939	230586	08034U	PARTICIPANT	\N	EXCUSE	0
232445	232317	11097X	PARTICIPANT	\N	PRESENT	0
232446	232317	01057W	PARTICIPANT	\N	PRESENT	0
232447	232317	14105F	PARTICIPANT	\N	PRESENT	0
232448	232317	19441R	PARTICIPANT	\N	PRESENT	0
232449	232317	19525U	PARTICIPANT	\N	PRESENT	0
232451	232317	19545Y	PARTICIPANT	\N	PRESENT	0
232454	232317	04071H	PARTICIPANT	\N	PRESENT	0
232463	232317	14031R	PARTICIPANT	\N	PRESENT	0
232465	232317	19387D	PARTICIPANT	\N	PRESENT	0
232467	232317	14121F	PARTICIPANT	\N	PRESENT	0
232468	232317	19565D	PARTICIPANT	\N	PRESENT	0
232469	232317	14073Q	PARTICIPANT	\N	PRESENT	0
232470	232317	14069U	PARTICIPANT	\N	PRESENT	0
232471	232317	14331P	PARTICIPANT	\N	PRESENT	0
232472	232317	14063N	PARTICIPANT	\N	PRESENT	0
232473	232317	14071N	PARTICIPANT	\N	PRESENT	0
232474	232317	14219Q	PARTICIPANT	\N	PRESENT	0
232475	232317	19447X	PARTICIPANT	\N	PRESENT	0
232476	232317	14038Y	PARTICIPANT	\N	PRESENT	0
232477	232317	08056B	PARTICIPANT	\N	PRESENT	0
232478	232317	19575F	PARTICIPANT	\N	PRESENT	0
232479	230033	19319Q	PARTICIPANT	\N	PRESENT	0
232480	230033	19443T	PARTICIPANT	\N	PRESENT	0
232481	230033	11080N	PARTICIPANT	\N	PRESENT	0
232482	230033	98018T	PARTICIPANT	\N	PRESENT	0
232483	230033	19421M	PARTICIPANT	\N	PRESENT	0
232484	230033	14267Y	PARTICIPANT	\N	PRESENT	0
232485	230033	14133K	PRESIDENT	0	PRESENT	0
232486	230033	11041F	PARTICIPANT	\N	PRESENT	0
232487	230033	04034C	PARTICIPANT	\N	PRESENT	0
232488	230033	14079W	PARTICIPANT	\N	PRESENT	0
232489	230033	11054L	PARTICIPANT	\N	PRESENT	0
232490	230033	11066Q	PARTICIPANT	\N	PRESENT	0
232491	230033	14105F	PARTICIPANT	\N	PRESENT	0
232492	230033	98050T	PARTICIPANT	\N	PRESENT	0
232493	230033	08061X	PARTICIPANT	\N	PRESENT	0
232494	230033	97011G	PARTICIPANT	\N	PRESENT	0
232495	230033	08047A	PARTICIPANT	\N	PRESENT	0
232496	230033	14255U	PARTICIPANT	\N	PRESENT	0
232497	230033	98029W	PARTICIPANT	\N	PRESENT	0
232502	230033	16685X	PARTICIPANT	\N	PRESENT	0
232505	232317	19507S	PARTICIPANT	\N	PRESENT	0
232509	232317	19553Y	PARTICIPANT	\N	PRESENT	0
232522	232317	11081P	PARTICIPANT	\N	PRESENT	0
232525	232317	14215L	PARTICIPANT	\N	PRESENT	0
232531	230033	14235Q	PARTICIPANT	\N	PRESENT	0
232532	230033	01058X	PARTICIPANT	\N	PRESENT	0
232533	230033	04040A	PARTICIPANT	\N	PRESENT	0
232534	230033	08058D	PARTICIPANT	\N	PRESENT	0
232535	232317	14199E	PARTICIPANT	\N	PRESENT	0
232536	232317	14327T	PARTICIPANT	\N	PRESENT	0
232537	232317	19647E	PARTICIPANT	\N	PRESENT	0
232538	232317	19671E	PARTICIPANT	\N	PRESENT	0
232540	232317	95041E	PARTICIPANT	\N	PRESENT	0
232545	232317	14111D	PARTICIPANT	\N	PRESENT	0
232546	232317	14195A	PARTICIPANT	\N	PRESENT	0
232548	232317	04092N	PARTICIPANT	\N	PRESENT	0
232549	232317	14213J	PARTICIPANT	\N	PRESENT	0
232550	230033	11027H	PARTICIPANT	\N	PRESENT	0
232551	230033	04042C	PARTICIPANT	\N	EXCUSE	0
232552	232317	14217N	PARTICIPANT	\N	PRESENT	0
232554	232317	11067R	PARTICIPANT	\N	PRESENT	0
232603	232318	19651A	PARTICIPANT	\N	PRESENT	0
232604	232318	95062K	PARTICIPANT	\N	PRESENT	0
232605	232318	19551W	PARTICIPANT	\N	PRESENT	0
232606	232318	11067R	PARTICIPANT	\N	PRESENT	0
232607	232318	19387D	PARTICIPANT	\N	PRESENT	0
232608	232318	01034P	PARTICIPANT	\N	PRESENT	0
232609	232318	14219Q	PARTICIPANT	\N	PRESENT	0
232610	232318	19479G	PARTICIPANT	\N	PRESENT	0
232614	232318	19483C	PARTICIPANT	\N	PRESENT	0
232612	232318	19553Y	PARTICIPANT	\N	PRESENT	0
232613	232318	19731Y	PARTICIPANT	\N	PRESENT	0
232615	232318	14217N	PARTICIPANT	\N	PRESENT	0
232616	232318	19301E	PARTICIPANT	\N	PRESENT	0
232617	232318	01048V	PARTICIPANT	\N	PRESENT	0
232618	232318	19575F	PARTICIPANT	\N	PRESENT	0
232619	232318	19667J	PARTICIPANT	\N	PRESENT	0
232620	232318	07029T	PARTICIPANT	\N	PRESENT	0
232621	232318	14199E	PARTICIPANT	\N	PRESENT	0
232622	232318	04088S	PARTICIPANT	\N	PRESENT	0
232623	232318	19507S	PARTICIPANT	\N	PRESENT	0
232624	232318	14038Y	PARTICIPANT	\N	PRESENT	0
232625	232318	19447X	PARTICIPANT	\N	PRESENT	0
232626	232318	19503N	PARTICIPANT	\N	PRESENT	0
232627	232318	19415P	PARTICIPANT	\N	PRESENT	0
232628	232318	11031D	PARTICIPANT	\N	PRESENT	0
232629	232318	08010L	PARTICIPANT	\N	PRESENT	0
232630	232318	95063L	PARTICIPANT	\N	PRESENT	0
232631	232318	14239U	PARTICIPANT	\N	PRESENT	0
232632	232318	14073Q	PARTICIPANT	\N	PRESENT	0
232633	232318	14213J	PARTICIPANT	\N	PRESENT	0
232634	232318	14225N	PARTICIPANT	\N	PRESENT	0
232635	232318	08052W	PARTICIPANT	\N	PRESENT	0
232636	232318	19629C	PARTICIPANT	\N	PRESENT	0
232637	232318	14111D	PARTICIPANT	\N	PRESENT	0
232638	232318	11064N	PARTICIPANT	\N	PRESENT	0
232639	232318	19573D	PARTICIPANT	\N	PRESENT	0
232640	232318	14267Y	PARTICIPANT	\N	PRESENT	0
232682	232319	14259Y	PARTICIPANT	\N	PRESENT	0
232683	232319	14073Q	PARTICIPANT	\N	PRESENT	0
232684	232319	14267Y	PARTICIPANT	\N	PRESENT	0
232685	232319	95063L	PARTICIPANT	\N	PRESENT	0
232686	232319	14231L	PARTICIPANT	\N	PRESENT	0
232687	232319	19479G	PARTICIPANT	\N	PRESENT	0
232688	232319	19441R	PARTICIPANT	\N	PRESENT	0
232689	232319	19731Y	PARTICIPANT	\N	PRESENT	0
232690	232319	19489J	PARTICIPANT	\N	PRESENT	0
232601	232318	11072N	PARTICIPANT	\N	PRESENT	0
232602	232318	04092N	PARTICIPANT	\N	PRESENT	0
232691	232319	04088S	PARTICIPANT	\N	PRESENT	0
232692	232319	14357A	PARTICIPANT	\N	PRESENT	0
232693	232319	97011G	PARTICIPANT	\N	PRESENT	0
232694	232319	07029T	PARTICIPANT	\N	PRESENT	0
232695	232319	01048V	PARTICIPANT	\N	PRESENT	0
232696	232319	19723Y	PARTICIPANT	\N	PRESENT	0
232697	232319	19629C	PARTICIPANT	\N	PRESENT	0
232698	232319	95030B	PARTICIPANT	\N	PRESENT	0
232699	232319	14213J	PARTICIPANT	\N	PRESENT	0
232700	232319	19483C	PARTICIPANT	\N	PRESENT	0
232701	232319	11031D	PARTICIPANT	\N	PRESENT	0
232702	232319	19521Q	PARTICIPANT	\N	PRESENT	0
232703	232319	19503N	PARTICIPANT	\N	PRESENT	0
232704	232319	14219Q	PARTICIPANT	\N	PRESENT	0
232705	232319	19447X	PARTICIPANT	\N	PRESENT	0
232706	232319	10015M	PARTICIPANT	\N	PRESENT	0
232707	232319	14151M	PARTICIPANT	\N	PRESENT	0
232711	232319	04059M	PARTICIPANT	\N	PRESENT	0
232712	232319	11064N	PARTICIPANT	\N	PRESENT	0
232713	232319	04057K	PARTICIPANT	\N	PRESENT	0
232714	232319	19333N	PARTICIPANT	\N	PRESENT	0
232715	232319	05008E	PARTICIPANT	\N	PRESENT	0
233502	233501	11110B	PARTICIPANT	\N	PRESENT	0
233503	233501	14069U	PARTICIPANT	\N	PRESENT	0
233504	233501	14195A	PARTICIPANT	\N	PRESENT	0
233505	233501	19663E	PARTICIPANT	\N	PRESENT	0
233506	233501	14026U	PARTICIPANT	\N	PRESENT	0
233507	233501	01057W	PARTICIPANT	\N	PRESENT	0
233508	233501	19511N	PARTICIPANT	\N	PRESENT	0
232680	232319	11072N	PARTICIPANT	\N	PRESENT	0
232681	232319	08052W	PARTICIPANT	\N	PRESENT	0
233509	233501	11067R	PARTICIPANT	\N	PRESENT	0
233512	233501	19527W	PARTICIPANT	\N	PRESENT	0
234035	234027	11053K	PARTICIPANT	\N	PRESENT	0
234036	234027	14159V	PARTICIPANT	\N	PRESENT	0
234037	234027	05012A	PARTICIPANT	\N	PRESENT	0
234413	232940	14217N	PARTICIPANT	\N	PRESENT	0
235491	235490	08055A	PARTICIPANT	\N	PRESENT	0
235492	235490	14069U	PARTICIPANT	\N	PRESENT	0
235493	235490	11103C	PARTICIPANT	\N	PRESENT	0
235494	235490	14329V	PARTICIPANT	\N	PRESENT	0
235495	235490	18083K	PARTICIPANT	\N	PRESENT	0
235496	235490	14357A	PARTICIPANT	\N	PRESENT	0
235497	235490	14187A	PARTICIPANT	\N	PRESENT	0
235498	235490	19723Y	PARTICIPANT	\N	PRESENT	0
235499	235490	14059S	PARTICIPANT	\N	PRESENT	0
235500	235490	14103D	PARTICIPANT	\N	PRESENT	0
235501	235490	08053X	PARTICIPANT	\N	PRESENT	0
235502	235490	19563B	PARTICIPANT	\N	PRESENT	0
235503	235490	14257W	PARTICIPANT	\N	PRESENT	0
235504	235490	98050T	PARTICIPANT	\N	PRESENT	0
235505	235490	19739H	PARTICIPANT	\N	PRESENT	0
235506	235490	19619A	PARTICIPANT	\N	PRESENT	0
235519	235518	14123H	PARTICIPANT	\N	PRESENT	0
235521	235520	14030Q	PARTICIPANT	\N	PRESENT	0
235524	235523	11104D	PARTICIPANT	\N	PRESENT	0
235525	235523	87003B	PARTICIPANT	\N	PRESENT	0
235528	235527	14030Q	PARTICIPANT	\N	PRESENT	0
216068	207252	11109J	PARTICIPANT	\N	PRESENT	0
216069	207252	14261S	PARTICIPANT	\N	PRESENT	0
216071	207252	19717B	PARTICIPANT	\N	PRESENT	0
216073	207252	19631V	PARTICIPANT	\N	PRESENT	0
216074	207252	11033F	PARTICIPANT	\N	PRESENT	0
216078	207252	19295A	PARTICIPANT	\N	PRESENT	0
216079	207252	14259Y	PARTICIPANT	\N	PRESENT	0
216084	207252	14199E	PARTICIPANT	\N	PRESENT	0
216086	207252	14033T	PARTICIPANT	\N	PRESENT	0
216087	207252	19691J	PARTICIPANT	\N	PRESENT	0
216089	207252	08016S	PARTICIPANT	\N	PRESENT	0
216092	207252	19329S	PARTICIPANT	\N	PRESENT	0
216093	207252	19715Y	PARTICIPANT	\N	PRESENT	0
216094	207252	14039A	PARTICIPANT	\N	PRESENT	0
216097	207252	19729F	PARTICIPANT	\N	PRESENT	0
216098	207252	14219Q	PARTICIPANT	\N	PRESENT	0
216100	207252	12016W	PARTICIPANT	\N	PRESENT	0
216102	207252	19657G	PARTICIPANT	\N	PRESENT	0
216105	207252	14097Y	PARTICIPANT	\N	PRESENT	0
216109	207252	19319Q	PARTICIPANT	\N	PRESENT	0
216110	207252	04043D	PARTICIPANT	\N	PRESENT	0
216111	207252	95062K	PRESIDENT	1	PRESENT	0
216113	207252	14135M	PARTICIPANT	\N	PRESENT	0
216116	207252	19703U	PARTICIPANT	\N	PRESENT	0
216119	207252	19301E	PARTICIPANT	\N	PRESENT	0
216120	207252	14157T	PARTICIPANT	\N	PRESENT	0
217403	217402	89017R	PARTICIPANT	\N	PRESENT	0
217405	217404	08010L	PARTICIPANT	\N	PRESENT	0
222586	222532	14071N	PARTICIPANT	\N	PRESENT	0
222587	222532	04040A	PRESIDENT	0	PRESENT	0
222864	222532	08048B	PARTICIPANT	\N	EXCUSE	0
222875	222532	11101A	PARTICIPANT	\N	EXCUSE	0
228047	225222	14239U	PARTICIPANT	\N	PRESENT	0
228048	225222	19683J	PARTICIPANT	\N	PRESENT	0
228049	225222	01048V	PRESIDENT	0	PRESENT	0
228050	225222	19533U	PARTICIPANT	\N	PRESENT	0
228051	225222	19503N	PARTICIPANT	\N	PRESENT	0
228052	225222	01058X	PARTICIPANT	\N	PRESENT	0
228056	225222	19553Y	PARTICIPANT	\N	PRESENT	0
228987	218441	14028W	PARTICIPANT	\N	PRESENT	0
230774	230773	14255U	PARTICIPANT	\N	PRESENT	0
236163	236159	19575F	PARTICIPANT	\N	PRESENT	0
236199	232944	19593H	PARTICIPANT	\N	PRESENT	0
236165	236159	14069U	PARTICIPANT	\N	PRESENT	0
236200	232944	14038Y	PARTICIPANT	\N	PRESENT	0
236167	236159	04042C	PARTICIPANT	\N	PRESENT	0
236201	235529	19697Q	PARTICIPANT	\N	PRESENT	0
236169	236159	04038G	PARTICIPANT	\N	PRESENT	0
236170	236159	19251M	PARTICIPANT	\N	PRESENT	0
236171	236159	14187A	PARTICIPANT	\N	PRESENT	0
236172	236159	19647E	PARTICIPANT	\N	PRESENT	0
236173	236159	19521Q	PARTICIPANT	\N	PRESENT	0
236174	236159	14179A	PARTICIPANT	\N	PRESENT	0
236175	236159	19591F	PARTICIPANT	\N	PRESENT	0
236176	236159	19511N	PARTICIPANT	\N	PRESENT	0
236177	236159	14031R	PARTICIPANT	\N	PRESENT	0
236202	235529	01034P	PARTICIPANT	\N	PRESENT	0
236203	235529	11067R	PARTICIPANT	\N	PRESENT	0
236180	236159	19443T	PARTICIPANT	\N	PRESENT	0
236181	236159	14135M	PARTICIPANT	\N	PRESENT	0
236182	236159	19687N	PARTICIPANT	\N	PRESENT	0
236204	235529	14355X	PARTICIPANT	\N	PRESENT	0
236184	236159	01062T	PARTICIPANT	\N	PRESENT	0
236185	236159	11041F	PARTICIPANT	\N	PRESENT	0
236186	236159	19749K	PARTICIPANT	\N	PRESENT	0
236205	235529	04092N	PARTICIPANT	\N	PRESENT	0
236206	235529	11097X	PARTICIPANT	\N	PRESENT	0
236207	235529	19663E	PARTICIPANT	\N	PRESENT	0
236208	235529	19715Y	PARTICIPANT	\N	PRESENT	0
236209	235529	04045F	PARTICIPANT	\N	PRESENT	0
236210	235529	14227Q	PARTICIPANT	\N	PRESENT	0
236211	235529	17779H	PARTICIPANT	\N	PRESENT	0
236212	235529	19723Y	PARTICIPANT	\N	PRESENT	0
236213	235529	19553Y	PARTICIPANT	\N	PRESENT	0
236214	235529	14119M	PARTICIPANT	\N	PRESENT	0
236215	235529	14087W	PARTICIPANT	\N	PRESENT	0
236216	235529	19679N	PARTICIPANT	\N	PRESENT	0
236217	235529	14195A	PARTICIPANT	\N	PRESENT	0
236218	235529	14213J	PARTICIPANT	\N	PRESENT	0
236219	235529	19367Y	PARTICIPANT	\N	PRESENT	0
236220	235529	19657G	PARTICIPANT	\N	PRESENT	0
236221	235529	14071N	PARTICIPANT	\N	PRESENT	0
236222	235529	14217N	PARTICIPANT	\N	PRESENT	0
236223	235529	98024R	PRESIDENT	0	PRESENT	0
236224	235529	19521Q	PARTICIPANT	\N	PRESENT	0
236225	232944	11031D	PARTICIPANT	\N	PRESENT	0
236226	232944	14227Q	PARTICIPANT	\N	PRESENT	0
236227	232944	17779H	PARTICIPANT	\N	PRESENT	0
236228	232944	14021P	PARTICIPANT	\N	PRESENT	0
236229	232944	04045F	PARTICIPANT	\N	PRESENT	0
236230	232944	19715Y	PARTICIPANT	\N	PRESENT	0
236231	232944	11067R	PARTICIPANT	\N	PRESENT	0
236232	232944	04085P	PARTICIPANT	\N	PRESENT	0
236233	232944	11066Q	PARTICIPANT	\N	PRESENT	0
236234	232944	12041X	PARTICIPANT	\N	PRESENT	0
236235	232944	11063M	PARTICIPANT	\N	PRESENT	0
236236	232944	19687N	PARTICIPANT	\N	PRESENT	0
236237	232944	19697Q	PARTICIPANT	\N	PRESENT	0
236238	232944	08060W	PARTICIPANT	\N	PRESENT	0
236239	232944	19727D	PARTICIPANT	\N	PRESENT	0
236240	232944	04092N	PARTICIPANT	\N	PRESENT	0
236241	232944	98024R	PARTICIPANT	\N	PRESENT	0
236242	232944	19521Q	PARTICIPANT	\N	PRESENT	0
236243	232944	14231L	PARTICIPANT	\N	PRESENT	0
236244	232944	01034P	PARTICIPANT	\N	PRESENT	0
236245	232944	11097X	PARTICIPANT	\N	PRESENT	0
236246	232944	87003B	PARTICIPANT	\N	PRESENT	0
236247	232944	19657G	PARTICIPANT	\N	PRESENT	0
236248	232944	14265W	PARTICIPANT	\N	PRESENT	0
236249	232944	14213J	PARTICIPANT	\N	PRESENT	0
236250	232944	14115H	PARTICIPANT	\N	PRESENT	0
236251	232944	14119M	PARTICIPANT	\N	PRESENT	0
236252	232944	19679N	PARTICIPANT	\N	PRESENT	0
236253	232944	19515S	PARTICIPANT	\N	PRESENT	0
236254	232944	19703U	PARTICIPANT	\N	PRESENT	0
236255	232944	19573D	PARTICIPANT	\N	PRESENT	0
236256	232944	14029X	PARTICIPANT	\N	PRESENT	0
236257	232944	19507S	PARTICIPANT	\N	PRESENT	0
236258	232944	04088S	PARTICIPANT	\N	PRESENT	0
236259	232944	14041T	PARTICIPANT	\N	PRESENT	0
236260	232944	19575F	PARTICIPANT	\N	PRESENT	0
236261	232944	19693L	PARTICIPANT	\N	PRESENT	0
236262	232944	04018C	PARTICIPANT	\N	PRESENT	0
236263	232944	14331P	PARTICIPANT	\N	PRESENT	0
236264	232944	14217N	PARTICIPANT	\N	PRESENT	0
236265	232944	04033B	PARTICIPANT	\N	PRESENT	0
236266	232944	14219Q	PARTICIPANT	\N	PRESENT	0
236267	232944	08052W	PARTICIPANT	\N	PRESENT	0
236268	232944	19647E	PARTICIPANT	\N	PRESENT	0
236269	232944	14195A	PARTICIPANT	\N	PRESENT	0
236270	232944	14215L	PARTICIPANT	\N	PRESENT	0
236271	232944	19671E	PARTICIPANT	\N	PRESENT	0
236272	232944	19583F	PARTICIPANT	\N	PRESENT	0
236273	232944	19611R	PARTICIPANT	\N	PRESENT	0
236274	232944	14121F	PARTICIPANT	\N	PRESENT	0
236275	232944	01025N	PARTICIPANT	\N	PRESENT	0
236276	232944	14087W	PARTICIPANT	\N	PRESENT	0
236277	232944	19467C	PARTICIPANT	\N	PRESENT	0
236278	232944	19415P	PARTICIPANT	\N	PRESENT	0
236279	232944	14281W	PARTICIPANT	\N	PRESENT	0
236280	232944	19683J	PARTICIPANT	\N	PRESENT	0
236281	232944	19659J	PARTICIPANT	\N	PRESENT	0
236282	232944	19289C	PARTICIPANT	\N	PRESENT	0
236283	232944	19629C	PARTICIPANT	\N	PRESENT	0
236284	232944	19563B	PARTICIPANT	\N	PRESENT	0
236285	232944	14103D	PARTICIPANT	\N	PRESENT	0
236286	232944	10006L	PARTICIPANT	\N	PRESENT	0
236287	232944	14071N	PARTICIPANT	\N	PRESENT	0
236288	232944	14033T	PARTICIPANT	\N	PRESENT	0
236289	232944	11103C	PARTICIPANT	\N	PRESENT	0
236290	232944	14239U	PARTICIPANT	\N	PRESENT	0
236291	232944	14267Y	PARTICIPANT	\N	PRESENT	0
236292	232944	19333N	PARTICIPANT	\N	PRESENT	0
236293	232944	19739H	PARTICIPANT	\N	PRESENT	0
236294	232944	08021P	PARTICIPANT	\N	PRESENT	0
236295	232944	08049C	PARTICIPANT	\N	PRESENT	0
236296	232944	19713W	PARTICIPANT	\N	PRESENT	0
236297	232944	14042U	PARTICIPANT	\N	PRESENT	0
225698	223292	04092N	PARTICIPANT	\N	EXCUSE	0
225130	225128	04049K	PARTICIPANT	\N	PRESENT	0
225131	225128	14255U	PARTICIPANT	\N	PRESENT	0
225699	221543	19715Y	PARTICIPANT	\N	EXCUSE	0
230816	230813	04086Q	PARTICIPANT	\N	PRESENT	0
230814	230813	11074Q	PARTICIPANT	\N	PRESENT	0
230815	230813	08011M	PARTICIPANT	\N	PRESENT	0
230817	230813	19711U	PARTICIPANT	\N	PRESENT	0
230818	230813	11053K	PARTICIPANT	\N	PRESENT	0
230819	230813	19689Q	PARTICIPANT	\N	PRESENT	0
230820	230813	19651A	PARTICIPANT	\N	PRESENT	0
233175	233174	19691J	PARTICIPANT	\N	PRESENT	0
233177	233176	11097X	PARTICIPANT	\N	PRESENT	0
233186	233185	19691J	PARTICIPANT	\N	PRESENT	0
236192	233052	96004D	PARTICIPANT	\N	EXCUSE	0
236193	233052	04043D	PARTICIPANT	\N	EXCUSE	0
236194	233052	14135M	PARTICIPANT	\N	EXCUSE	0
236195	233052	11054L	PARTICIPANT	\N	EXCUSE	0
236196	233052	95062K	PARTICIPANT	\N	EXCUSE	0
238760	238759	87003B	PARTICIPANT	\N	PRESENT	0
238761	238759	11104D	PARTICIPANT	\N	PRESENT	0
238763	238762	14030Q	PARTICIPANT	\N	PRESENT	0
238765	238764	14030Q	PARTICIPANT	\N	PRESENT	0
238895	233168	14261S	PARTICIPANT	\N	PRESENT	0
238896	233168	11109J	PARTICIPANT	\N	EXCUSE	0
238897	233168	19631V	PARTICIPANT	\N	EXCUSE	0
238898	233168	11033F	PARTICIPANT	\N	EXCUSE	0
238899	233168	96004D	PARTICIPANT	\N	EXCUSE	0
238900	233168	14038Y	PARTICIPANT	\N	EXCUSE	0
238901	233168	19295A	PARTICIPANT	\N	EXCUSE	0
238902	233168	14259Y	PARTICIPANT	\N	EXCUSE	0
238903	233168	19659J	PARTICIPANT	\N	EXCUSE	0
238904	233168	19577H	PARTICIPANT	\N	EXCUSE	0
238905	233168	11010L	PARTICIPANT	\N	EXCUSE	0
238906	233168	14199E	PARTICIPANT	\N	EXCUSE	0
238907	233168	14033T	PARTICIPANT	\N	EXCUSE	0
238908	233168	19691J	PARTICIPANT	\N	EXCUSE	0
238909	233168	08016S	PARTICIPANT	\N	EXCUSE	0
238910	233168	19329S	PARTICIPANT	\N	PRESENT	0
238911	233168	19715Y	PARTICIPANT	\N	EXCUSE	0
238912	233168	14097Y	PARTICIPANT	\N	EXCUSE	0
238913	233168	14039A	PARTICIPANT	\N	EXCUSE	0
238914	233168	19583F	PARTICIPANT	\N	EXCUSE	0
238915	233168	98005N	PARTICIPANT	\N	EXCUSE	0
238916	233168	14277B	PARTICIPANT	\N	EXCUSE	0
238917	233168	19729F	PARTICIPANT	\N	EXCUSE	0
238918	233168	14219Q	PARTICIPANT	\N	EXCUSE	0
238919	233168	14059S	PARTICIPANT	\N	EXCUSE	0
238952	233168	19657G	PARTICIPANT	\N	PRESENT	0
238953	233168	14157T	PARTICIPANT	\N	EXCUSE	0
238954	233168	19301E	PARTICIPANT	\N	EXCUSE	0
238955	233168	14275Y	PARTICIPANT	\N	EXCUSE	0
238956	233168	19703U	PARTICIPANT	\N	EXCUSE	0
238957	233168	11054L	PARTICIPANT	\N	EXCUSE	0
238958	233168	95062K	PARTICIPANT	\N	EXCUSE	0
238959	233168	14225N	PARTICIPANT	\N	EXCUSE	0
238960	233168	14331P	PARTICIPANT	\N	EXCUSE	0
238961	233168	14135M	PARTICIPANT	\N	EXCUSE	0
238962	233168	04043D	PARTICIPANT	\N	EXCUSE	0
238963	233168	19319Q	PARTICIPANT	\N	EXCUSE	0
238964	233168	08073C	PARTICIPANT	\N	EXCUSE	0
238965	233168	08019V	PRESIDENT	0	PRESENT	0
238966	233168	11072N	PARTICIPANT	\N	EXCUSE	0
238967	233168	19717B	PARTICIPANT	\N	EXCUSE	0
238969	233171	19319Q	PARTICIPANT	\N	EXCUSE	0
238970	233171	95062K	PARTICIPANT	\N	EXCUSE	0
238972	238971	95062K	PARTICIPANT	\N	EXCUSE	0
238973	238971	14261S	PARTICIPANT	\N	EXCUSE	0
238975	238971	19717B	PARTICIPANT	\N	EXCUSE	0
238976	238971	11033F	PARTICIPANT	\N	EXCUSE	0
238977	238971	96004D	PARTICIPANT	\N	EXCUSE	0
238978	238971	14038Y	PARTICIPANT	\N	EXCUSE	0
238979	238971	19659J	PARTICIPANT	\N	EXCUSE	0
238980	238971	19577H	PARTICIPANT	\N	EXCUSE	0
238981	238971	11010L	PARTICIPANT	\N	EXCUSE	0
238982	238971	14199E	PARTICIPANT	\N	EXCUSE	0
238983	238971	19691J	PARTICIPANT	\N	EXCUSE	0
238984	238971	08016S	PARTICIPANT	\N	EXCUSE	0
238985	238971	19715Y	PARTICIPANT	\N	EXCUSE	0
238986	238971	19583F	PARTICIPANT	\N	EXCUSE	0
238987	238971	98005N	PARTICIPANT	\N	EXCUSE	0
238988	238971	14277B	PARTICIPANT	\N	EXCUSE	0
238989	238971	19729F	PARTICIPANT	\N	EXCUSE	0
238990	238971	14219Q	PARTICIPANT	\N	EXCUSE	0
238991	238971	19319Q	PARTICIPANT	\N	EXCUSE	0
238992	238971	14135M	PARTICIPANT	\N	EXCUSE	0
238993	238971	14331P	PARTICIPANT	\N	EXCUSE	0
238994	238971	14225N	PARTICIPANT	\N	EXCUSE	0
238995	238971	11054L	PARTICIPANT	\N	EXCUSE	0
238996	238971	19703U	PARTICIPANT	\N	EXCUSE	0
238997	238971	19301E	PARTICIPANT	\N	EXCUSE	0
238998	238971	14157T	PARTICIPANT	\N	EXCUSE	0
238999	238971	14033T	PARTICIPANT	\N	EXCUSE	0
239000	233171	14038Y	PARTICIPANT	\N	EXCUSE	0
239001	233171	19583F	PARTICIPANT	\N	EXCUSE	0
239002	233171	14219Q	PARTICIPANT	\N	EXCUSE	0
239005	239004	04043D	PARTICIPANT	\N	EXCUSE	0
239006	239004	19583F	PARTICIPANT	\N	EXCUSE	0
239007	239004	14219Q	PARTICIPANT	\N	EXCUSE	0
240028	239667	14103D	PARTICIPANT	\N	PRESENT	0
240029	239667	19479G	PARTICIPANT	\N	PRESENT	0
240042	239667	14133K	PARTICIPANT	\N	PRESENT	0
240056	239667	95062K	PARTICIPANT	\N	PRESENT	0
240063	238780	14253S	PARTICIPANT	\N	PRESENT	0
240064	238780	08073C	PARTICIPANT	\N	PRESENT	0
240065	238780	14331P	PARTICIPANT	\N	PRESENT	0
240066	238780	14225N	PARTICIPANT	\N	PRESENT	0
240067	238780	11012A	PARTICIPANT	\N	PRESENT	0
240140	238780	19689Q	PARTICIPANT	\N	PRESENT	0
240148	238780	19479G	PARTICIPANT	\N	PRESENT	0
240149	238780	14173T	PARTICIPANT	\N	PRESENT	0
240150	238780	19349W	PARTICIPANT	\N	PRESENT	0
240151	238780	14327T	PARTICIPANT	\N	EXCUSE	0
240152	238780	19667J	PARTICIPANT	\N	EXCUSE	0
240153	238781	19741B	PARTICIPANT	\N	PRESENT	0
240154	238781	11040E	PARTICIPANT	\N	PRESENT	0
240155	238781	08014Q	PARTICIPANT	\N	PRESENT	0
240156	238781	14083S	PARTICIPANT	\N	PRESENT	0
240157	238781	11053K	PARTICIPANT	\N	PRESENT	0
240158	238781	19545Y	PARTICIPANT	\N	PRESENT	0
240159	238781	14085U	PARTICIPANT	\N	PRESENT	0
240160	238781	04086Q	PARTICIPANT	\N	PRESENT	0
240161	238781	11074Q	PRESIDENT	0	PRESENT	0
240162	238781	14034U	PARTICIPANT	\N	PRESENT	0
240163	238781	07004J	PARTICIPANT	\N	PRESENT	0
240164	238781	11048N	PARTICIPANT	\N	PRESENT	0
240165	238781	14121F	PARTICIPANT	\N	PRESENT	0
240166	238781	07029T	PARTICIPANT	\N	PRESENT	0
240167	238781	14277B	PARTICIPANT	\N	PRESENT	0
240168	238781	19711U	PARTICIPANT	\N	PRESENT	0
240230	240228	19489J	PARTICIPANT	\N	PRESENT	0
240170	238781	08034U	PARTICIPANT	\N	PRESENT	0
240171	238781	08011M	PARTICIPANT	\N	PRESENT	0
240172	238781	14253S	PARTICIPANT	\N	PRESENT	0
240173	238781	08073C	PARTICIPANT	\N	PRESENT	0
240174	238781	14331P	PARTICIPANT	\N	PRESENT	0
240175	238781	19689Q	PARTICIPANT	\N	PRESENT	0
240176	238781	19479G	PARTICIPANT	\N	PRESENT	0
240177	238781	14173T	PARTICIPANT	\N	PRESENT	0
240178	238781	19667J	PARTICIPANT	\N	EXCUSE	0
240179	238781	14327T	PARTICIPANT	\N	EXCUSE	0
240180	238781	88008L	PARTICIPANT	\N	PRESENT	0
240181	232547	19737F	PARTICIPANT	\N	PRESENT	0
240229	240228	14069U	PARTICIPANT	\N	PRESENT	0
240231	240228	05012A	PARTICIPANT	\N	PRESENT	0
240232	240228	11040E	PARTICIPANT	\N	PRESENT	0
240233	240228	14087W	PARTICIPANT	\N	PRESENT	0
240234	240228	14205J	PARTICIPANT	\N	PRESENT	0
240235	240228	08068F	PARTICIPANT	\N	PRESENT	0
240236	239668	04086Q	PARTICIPANT	\N	PRESENT	0
240237	239668	10015M	PARTICIPANT	\N	PRESENT	0
240238	239668	19347U	PARTICIPANT	\N	PRESENT	0
240239	239668	14151M	PARTICIPANT	\N	PRESENT	0
240240	239668	14065Q	PARTICIPANT	\N	PRESENT	0
240241	239668	19253P	PARTICIPANT	\N	PRESENT	0
240242	239668	19387D	PARTICIPANT	\N	PRESENT	0
240243	239668	19737F	PARTICIPANT	\N	PRESENT	0
240244	239668	19441R	PARTICIPANT	\N	PRESENT	0
240245	239668	14195A	PARTICIPANT	\N	PRESENT	0
240246	239668	19679N	PARTICIPANT	\N	PRESENT	0
240247	239668	19467C	PARTICIPANT	\N	PRESENT	0
240248	239668	04088S	PARTICIPANT	\N	PRESENT	0
240249	239668	19415P	PARTICIPANT	\N	PRESENT	0
240250	239668	14033T	PARTICIPANT	\N	PRESENT	0
240251	239668	14105F	PARTICIPANT	\N	PRESENT	0
240252	239668	14038Y	PARTICIPANT	\N	PRESENT	0
240253	239668	05008E	PARTICIPANT	\N	PRESENT	0
240254	239668	14179A	PARTICIPANT	\N	PRESENT	0
240255	239668	14249W	PARTICIPANT	\N	PRESENT	0
215764	215763	04047H	PARTICIPANT	\N	PRESENT	0
215769	215768	04047H	PARTICIPANT	\N	PRESENT	0
213254	213253	14111D	PARTICIPANT	\N	PRESENT	0
213256	213255	14111D	PARTICIPANT	\N	PRESENT	0
213393	213392	14207L	PARTICIPANT	\N	PRESENT	0
213394	213392	01025N	PARTICIPANT	\N	PRESENT	0
213395	213392	19507S	PARTICIPANT	\N	PRESENT	0
213397	213396	01025N	PARTICIPANT	\N	PRESENT	0
213398	213396	14207L	PARTICIPANT	\N	PRESENT	0
213400	213399	14207L	PARTICIPANT	\N	PRESENT	0
213401	213399	19507S	PARTICIPANT	\N	PRESENT	0
213402	213399	01025N	PARTICIPANT	\N	PRESENT	0
213404	213403	07004J	PARTICIPANT	\N	PRESENT	0
215758	215757	19253P	PARTICIPANT	\N	PRESENT	0
215770	215768	11026G	PARTICIPANT	\N	PRESENT	0
215776	215775	04047H	PARTICIPANT	\N	PRESENT	0
222584	218821	08062Y	PARTICIPANT	\N	EXCUSE	0
222881	222880	11053K	PARTICIPANT	\N	PRESENT	0
222883	222882	11053K	PARTICIPANT	\N	PRESENT	0
222888	219921	14173T	PARTICIPANT	\N	PRESENT	0
223256	223255	11054L	PARTICIPANT	\N	PRESENT	0
223318	218284	11070L	PARTICIPANT	\N	PRESENT	0
223319	218284	14225N	PARTICIPANT	\N	PRESENT	0
223320	218284	19715Y	PARTICIPANT	\N	PRESENT	0
223321	218284	11074Q	PARTICIPANT	\N	PRESENT	0
223322	218284	99004R	PARTICIPANT	\N	PRESENT	0
223323	218284	19711U	PARTICIPANT	\N	PRESENT	0
223324	218284	07004J	PARTICIPANT	\N	PRESENT	0
223325	218284	08011M	PARTICIPANT	\N	PRESENT	0
223326	218284	19413M	PARTICIPANT	\N	PRESENT	0
223327	218284	19545Y	PARTICIPANT	\N	PRESENT	0
223328	218284	14331P	PARTICIPANT	\N	PRESENT	0
223329	218284	19651A	PARTICIPANT	\N	PRESENT	0
223330	218284	19349W	PARTICIPANT	\N	PRESENT	0
223331	218284	14041T	PARTICIPANT	\N	PRESENT	0
223332	218284	07029T	PARTICIPANT	\N	PRESENT	0
223333	218284	11040E	PARTICIPANT	\N	PRESENT	0
223334	218284	04034C	PARTICIPANT	\N	PRESENT	0
223335	218284	14159V	PARTICIPANT	\N	PRESENT	0
223336	218284	01048V	PARTICIPANT	\N	PRESENT	0
223337	218284	14327T	PARTICIPANT	\N	PRESENT	0
223338	218284	08010L	PARTICIPANT	\N	PRESENT	0
223339	218284	08034U	PARTICIPANT	\N	PRESENT	0
223340	218284	04043D	PARTICIPANT	\N	PRESENT	0
223341	218284	11012A	PARTICIPANT	\N	PRESENT	0
223342	218284	04071H	PARTICIPANT	\N	PRESENT	0
223343	218284	19687N	PARTICIPANT	\N	PRESENT	0
223344	218284	14085U	PARTICIPANT	\N	PRESENT	0
223345	218284	04018C	PARTICIPANT	\N	PRESENT	0
223346	218284	14121F	PARTICIPANT	\N	PRESENT	0
223347	218284	19689Q	PARTICIPANT	\N	PRESENT	0
223348	218284	11065P	PARTICIPANT	\N	PRESENT	0
223349	218284	14249W	PARTICIPANT	\N	PRESENT	0
223350	218284	04047H	PARTICIPANT	\N	PRESENT	0
223351	218284	19583F	PARTICIPANT	\N	PRESENT	0
223352	218284	11048N	PARTICIPANT	\N	PRESENT	0
223353	218284	19649G	PARTICIPANT	\N	PRESENT	0
223354	218284	11090Q	PARTICIPANT	\N	PRESENT	0
223355	218284	19701S	PARTICIPANT	\N	PRESENT	0
223356	218284	14107H	PARTICIPANT	\N	PRESENT	0
223357	218284	11077T	PARTICIPANT	\N	PRESENT	0
223358	218284	08016S	PARTICIPANT	\N	PRESENT	0
223359	218284	19591F	PARTICIPANT	\N	PRESENT	0
223360	218284	19647E	PARTICIPANT	\N	PRESENT	0
223361	218284	19659J	PARTICIPANT	\N	PRESENT	0
223362	218284	08073C	PARTICIPANT	\N	PRESENT	0
223363	218284	19643A	PARTICIPANT	\N	PRESENT	0
223364	218284	19671E	PARTICIPANT	\N	PRESENT	0
223365	218284	98018T	PARTICIPANT	\N	PRESENT	0
223366	218284	95041E	PARTICIPANT	\N	PRESENT	0
223367	218284	04086Q	PARTICIPANT	\N	PRESENT	0
223378	218284	17637T	PARTICIPANT	\N	PRESENT	0
223379	218284	14231L	PARTICIPANT	\N	PRESENT	0
223382	218284	08019V	PARTICIPANT	\N	PRESENT	0
223383	218284	12016W	PARTICIPANT	\N	PRESENT	0
223388	218284	11080N	PARTICIPANT	\N	PRESENT	0
223389	218284	19593H	PARTICIPANT	\N	PRESENT	0
223390	218284	01043Q	PARTICIPANT	\N	PRESENT	0
223392	223391	14147R	PARTICIPANT	\N	PRESENT	0
223393	223391	19585H	PARTICIPANT	\N	PRESENT	0
223394	223391	04047H	PARTICIPANT	\N	PRESENT	0
223395	223391	19649G	PARTICIPANT	\N	PRESENT	0
223396	223391	11033F	PARTICIPANT	\N	PRESENT	0
223397	223391	19543W	PARTICIPANT	\N	PRESENT	0
223398	223391	11045K	PARTICIPANT	\N	PRESENT	0
223400	218284	14357A	PARTICIPANT	\N	PRESENT	0
223401	218284	02002K	PARTICIPANT	\N	PRESENT	0
223403	223402	01024M	PARTICIPANT	\N	PRESENT	0
223405	223404	01024M	PARTICIPANT	\N	PRESENT	0
223406	218285	11072N	PARTICIPANT	\N	PRESENT	0
223407	218285	19651A	PARTICIPANT	\N	PRESENT	0
223408	218285	14085U	PARTICIPANT	\N	PRESENT	0
223409	218285	19689Q	PARTICIPANT	\N	PRESENT	0
223410	218285	11040E	PARTICIPANT	\N	PRESENT	0
223411	218285	19545Y	PARTICIPANT	\N	PRESENT	0
223412	218285	08019V	PARTICIPANT	\N	PRESENT	0
223413	218285	11065P	PARTICIPANT	\N	PRESENT	0
223414	218285	11048N	PARTICIPANT	\N	PRESENT	0
223415	218285	08034U	PARTICIPANT	\N	PRESENT	0
223416	218285	04086Q	PARTICIPANT	\N	PRESENT	0
223417	218285	19711U	PARTICIPANT	\N	PRESENT	0
223418	218285	11074Q	PARTICIPANT	\N	PRESENT	0
223419	218285	08011M	PARTICIPANT	\N	PRESENT	0
223420	218285	07029T	PARTICIPANT	\N	PRESENT	0
223421	218285	14041T	PARTICIPANT	\N	PRESENT	0
223422	218285	19647E	PARTICIPANT	\N	PRESENT	0
223423	218285	19671E	PARTICIPANT	\N	PRESENT	0
223424	218285	14331P	PARTICIPANT	\N	PRESENT	0
223425	218285	19687N	PARTICIPANT	\N	PRESENT	0
223426	218285	19593H	PARTICIPANT	\N	PRESENT	0
223427	218285	02002K	PARTICIPANT	\N	PRESENT	0
223428	218285	01057W	PARTICIPANT	\N	PRESENT	0
223429	218285	14159V	PARTICIPANT	\N	PRESENT	0
223430	218285	14121F	PARTICIPANT	\N	PRESENT	0
223431	218285	14107H	PARTICIPANT	\N	PRESENT	0
223432	218285	19657G	PARTICIPANT	\N	PRESENT	0
223433	218285	14083S	PARTICIPANT	\N	PRESENT	0
223434	218285	08010L	PARTICIPANT	\N	PRESENT	0
223435	218285	14219Q	PARTICIPANT	\N	PRESENT	0
223436	218285	14231L	PARTICIPANT	\N	PRESENT	0
223437	218285	14026U	PARTICIPANT	\N	PRESENT	0
223438	218285	04071H	PARTICIPANT	\N	PRESENT	0
223439	218285	96004D	PARTICIPANT	\N	PRESENT	0
223440	218285	14089Y	PARTICIPANT	\N	PRESENT	0
223441	218285	11012A	PARTICIPANT	\N	PRESENT	0
223442	218285	14225N	PARTICIPANT	\N	PRESENT	0
223443	218285	11077T	PARTICIPANT	\N	PRESENT	0
223444	218285	14327T	PARTICIPANT	\N	PRESENT	0
223445	218285	19483C	PARTICIPANT	\N	PRESENT	0
223446	218285	14069U	PARTICIPANT	\N	PRESENT	0
223447	218285	14357A	PARTICIPANT	\N	PRESENT	0
223448	218285	14030Q	PARTICIPANT	\N	PRESENT	0
223449	218286	11070L	PARTICIPANT	\N	PRESENT	0
223450	218286	08011M	PARTICIPANT	\N	PRESENT	0
223451	218286	11074Q	PARTICIPANT	\N	PRESENT	0
223452	218286	11040E	PARTICIPANT	\N	PRESENT	0
223453	218286	19593H	PARTICIPANT	\N	PRESENT	0
223454	218286	19689Q	PARTICIPANT	\N	PRESENT	0
223455	218286	19651A	PARTICIPANT	\N	PRESENT	0
223456	218286	19545Y	PARTICIPANT	\N	PRESENT	0
223457	218286	14225N	PARTICIPANT	\N	PRESENT	0
223458	218286	07004J	PARTICIPANT	\N	PRESENT	0
223459	218286	14083S	PARTICIPANT	\N	PRESENT	0
223460	218286	14357A	PARTICIPANT	\N	PRESENT	0
223461	218286	14331P	PARTICIPANT	\N	PRESENT	0
223462	218286	19671E	PARTICIPANT	\N	PRESENT	0
223463	218286	08034U	PARTICIPANT	\N	PRESENT	0
223464	218286	04086Q	PARTICIPANT	\N	PRESENT	0
223465	218286	11048N	PARTICIPANT	\N	PRESENT	0
223466	218286	11090Q	PARTICIPANT	\N	PRESENT	0
223467	218286	01057W	PARTICIPANT	\N	PRESENT	0
223468	218286	19657G	PARTICIPANT	\N	PRESENT	0
221847	219487	98053W	PARTICIPANT	\N	EXCUSE	0
222567	222534	19483C	PARTICIPANT	\N	PRESENT	0
222568	222534	19729F	PARTICIPANT	\N	PRESENT	0
222569	222534	19581D	PARTICIPANT	\N	PRESENT	0
222570	222534	14111D	PARTICIPANT	\N	PRESENT	0
222571	222534	14001X	PARTICIPANT	\N	PRESENT	0
222572	222534	11085T	PARTICIPANT	\N	PRESENT	0
222574	222534	14147R	PARTICIPANT	\N	PRESENT	0
222575	222534	11072N	PARTICIPANT	\N	PRESENT	0
222576	222534	07034Q	PARTICIPANT	\N	PRESENT	0
222577	222534	10015M	PARTICIPANT	\N	PRESENT	0
222578	222534	95063L	PARTICIPANT	\N	PRESENT	0
222579	222534	01028R	PARTICIPANT	\N	PRESENT	0
222580	222534	98035U	PARTICIPANT	\N	PRESENT	0
222581	222534	14275Y	PARTICIPANT	\N	PRESENT	0
222582	222534	04044E	PARTICIPANT	\N	PRESENT	0
242873	242872	19575F	PARTICIPANT	\N	PRESENT	0
242874	242872	19415P	PARTICIPANT	\N	PRESENT	0
242875	242872	19467C	PARTICIPANT	\N	PRESENT	0
242876	242872	14041T	PARTICIPANT	\N	PRESENT	0
242877	242872	08018U	PARTICIPANT	\N	PRESENT	0
242878	242872	08041T	PARTICIPANT	\N	PRESENT	0
242879	242872	14147R	PARTICIPANT	\N	PRESENT	0
242880	242872	11012A	PARTICIPANT	\N	PRESENT	0
244131	244130	96004D	PARTICIPANT	\N	PRESENT	0
244132	244130	04097T	PARTICIPANT	\N	PRESENT	0
244133	244130	14073Q	PARTICIPANT	\N	PRESENT	0
244748	244151	14195A	PARTICIPANT	\N	PRESENT	0
244749	244151	19663E	PARTICIPANT	\N	PRESENT	0
244750	244151	98024R	PARTICIPANT	\N	PRESENT	0
244751	244151	19727D	PARTICIPANT	\N	PRESENT	0
244752	244151	19715Y	PARTICIPANT	\N	PRESENT	0
244753	244151	17779H	PARTICIPANT	\N	PRESENT	0
244754	244151	14223L	PARTICIPANT	\N	PRESENT	0
244755	244151	04092N	PARTICIPANT	\N	PRESENT	0
244756	244151	14119M	PARTICIPANT	\N	PRESENT	0
244757	244151	01034P	PARTICIPANT	\N	PRESENT	0
246244	242647	14042U	PARTICIPANT	\N	PRESENT	0
246245	242647	19367Y	PARTICIPANT	\N	PRESENT	0
246246	242647	19577H	PARTICIPANT	\N	PRESENT	0
246247	242647	19727D	PARTICIPANT	\N	PRESENT	0
246248	242647	19715Y	PARTICIPANT	\N	PRESENT	0
246249	242647	11097X	PARTICIPANT	\N	PRESENT	0
248845	246404	98053W	PARTICIPANT	\N	EXCUSE	0
248846	246404	14097Y	PARTICIPANT	\N	EXCUSE	0
248847	246404	14028W	PARTICIPANT	\N	EXCUSE	0
248848	246404	11054L	PARTICIPANT	\N	EXCUSE	0
248849	246404	04034C	PARTICIPANT	\N	EXCUSE	0
249814	249813	11053K	PARTICIPANT	\N	PRESENT	0
249815	249813	14159V	PARTICIPANT	\N	PRESENT	0
249816	249813	05012A	PARTICIPANT	\N	PRESENT	0
257791	255991	14103D	PARTICIPANT	\N	PRESENT	0
257767	255991	19599P	PARTICIPANT	\N	EXCUSE	0
257768	255991	14219Q	PARTICIPANT	\N	PRESENT	0
257769	255991	19745F	PARTICIPANT	\N	PRESENT	0
257770	255991	14221J	PARTICIPANT	\N	PRESENT	0
257772	255991	18083K	PARTICIPANT	\N	PRESENT	0
257773	255991	17583W	PARTICIPANT	\N	PRESENT	0
257774	255991	08024S	PARTICIPANT	\N	PRESENT	0
257775	255991	98023Q	PARTICIPANT	\N	PRESENT	0
257779	255991	19383Y	PARTICIPANT	\N	PRESENT	0
257780	255991	19333N	PARTICIPANT	\N	PRESENT	0
257781	255991	08055A	PARTICIPANT	\N	PRESENT	0
257782	255991	19637C	PARTICIPANT	\N	PRESENT	0
257783	255991	14169X	PARTICIPANT	\N	PRESENT	0
257784	255991	15447F	PARTICIPANT	\N	PRESENT	0
257785	255991	08060W	PARTICIPANT	\N	PRESENT	0
257786	255991	19503N	PARTICIPANT	\N	PRESENT	0
257787	255991	19659J	PARTICIPANT	\N	PRESENT	0
257789	255991	14038Y	PARTICIPANT	\N	PRESENT	0
257790	255991	08009T	PRESIDENT	0	PRESENT	0
257792	255991	19387D	PARTICIPANT	\N	PRESENT	0
257793	255991	19551W	PARTICIPANT	\N	PRESENT	0
257794	255991	05012A	PARTICIPANT	\N	PRESENT	0
257795	255991	19347U	PARTICIPANT	\N	PRESENT	0
257796	255991	19525U	PARTICIPANT	\N	PRESENT	0
257797	255991	14031R	PARTICIPANT	\N	PRESENT	0
257798	255991	14051J	PARTICIPANT	\N	PRESENT	0
257799	255991	19713W	PARTICIPANT	\N	PRESENT	0
257800	255991	14029X	PARTICIPANT	\N	PRESENT	0
257801	255991	19733B	PARTICIPANT	\N	PRESENT	0
257802	255991	19685L	PARTICIPANT	\N	PRESENT	0
257803	255991	19737F	PARTICIPANT	\N	PRESENT	0
257804	255774	14097Y	PARTICIPANT	\N	PRESENT	0
257805	255774	19443T	PARTICIPANT	\N	PRESENT	0
257806	255774	95067Q	PARTICIPANT	\N	PRESENT	0
257807	255774	95030B	PARTICIPANT	\N	PRESENT	0
257808	255774	14133K	PARTICIPANT	\N	PRESENT	0
257809	255774	01062T	PARTICIPANT	\N	PRESENT	0
257810	255774	01058X	PARTICIPANT	\N	PRESENT	0
257811	255774	04040A	PARTICIPANT	\N	PRESENT	0
257812	255774	08058D	PARTICIPANT	\N	PRESENT	0
257813	255774	04042C	PRESIDENT	0	PRESENT	0
257814	255774	14028W	PARTICIPANT	\N	PRESENT	0
257815	255774	11054L	PARTICIPANT	\N	PRESENT	0
257816	255774	11066Q	PARTICIPANT	\N	PRESENT	0
257817	255774	19721W	PARTICIPANT	\N	PRESENT	0
257818	255774	95037J	PARTICIPANT	\N	PRESENT	0
257819	255774	19709B	PARTICIPANT	\N	PRESENT	0
257820	255774	98022P	PARTICIPANT	\N	PRESENT	0
257821	255774	14267Y	PARTICIPANT	\N	PRESENT	0
257822	255774	14193X	PARTICIPANT	\N	PRESENT	0
257823	255774	98050T	PARTICIPANT	\N	PRESENT	0
257824	255774	08061X	PARTICIPANT	\N	PRESENT	0
257825	255774	97011G	PARTICIPANT	\N	PRESENT	0
257826	255774	14211G	PARTICIPANT	\N	PRESENT	0
257827	255774	19421M	PARTICIPANT	\N	EXCUSE	0
257828	255774	19251M	PARTICIPANT	\N	EXCUSE	0
257829	255774	08047A	PARTICIPANT	\N	EXCUSE	0
257830	255774	98029W	PARTICIPANT	\N	EXCUSE	0
257831	255774	16685X	PARTICIPANT	\N	PRESENT	0
257832	255991	04097T	PARTICIPANT	\N	PRESENT	0
257833	255991	95062K	PARTICIPANT	\N	PRESENT	0
257834	255991	17637T	PARTICIPANT	\N	PRESENT	0
257835	255774	98005N	PARTICIPANT	\N	PRESENT	0
257836	255774	11064N	PARTICIPANT	\N	PRESENT	0
257837	255774	19583F	PARTICIPANT	\N	PRESENT	0
257838	255724	19697Q	PARTICIPANT	\N	PRESENT	0
257839	255724	11067R	PARTICIPANT	\N	PRESENT	0
257840	255724	11097X	PARTICIPANT	\N	PRESENT	0
257841	255724	19415P	PARTICIPANT	\N	PRESENT	0
257842	255724	04045F	PARTICIPANT	\N	PRESENT	0
257843	255724	14223L	PARTICIPANT	\N	PRESENT	0
257844	255724	14227Q	PARTICIPANT	\N	PRESENT	0
257845	255724	17779H	PARTICIPANT	\N	PRESENT	0
257846	255724	19703U	PARTICIPANT	\N	PRESENT	0
257847	255724	14281W	PARTICIPANT	\N	PRESENT	0
257848	255724	14087W	PARTICIPANT	\N	PRESENT	0
257849	255724	14042U	PARTICIPANT	\N	PRESENT	0
257850	255724	14195A	PARTICIPANT	\N	PRESENT	0
257851	255724	19367Y	PARTICIPANT	\N	PRESENT	0
257852	255724	14213J	PARTICIPANT	\N	PRESENT	0
257853	255724	19335Q	PARTICIPANT	\N	PRESENT	0
257854	255724	14217N	PARTICIPANT	\N	PRESENT	0
257855	255724	19683J	PARTICIPANT	\N	PRESENT	0
257856	255724	19521Q	PARTICIPANT	\N	PRESENT	0
257857	255724	98024R	PARTICIPANT	\N	PRESENT	0
257858	255724	19527W	PARTICIPANT	\N	PRESENT	0
257859	255724	01034P	PARTICIPANT	\N	PRESENT	0
257860	255724	04092N	PRESIDENT	0	PRESENT	0
257861	255724	08052W	PARTICIPANT	\N	PRESENT	0
257862	255724	19663E	PARTICIPANT	\N	PRESENT	0
257863	255724	19691J	PARTICIPANT	\N	PRESENT	0
257864	255724	19717B	PARTICIPANT	\N	PRESENT	0
257865	255724	19723Y	PARTICIPANT	\N	PRESENT	0
257866	255724	19727D	PARTICIPANT	\N	PRESENT	0
257867	255724	11103C	PARTICIPANT	\N	PRESENT	0
257868	255724	14071N	PARTICIPANT	\N	PRESENT	0
257869	255724	08048B	PARTICIPANT	\N	EXCUSE	0
260436	260435	14239U	PARTICIPANT	\N	PRESENT	0
260437	260435	19647E	PARTICIPANT	\N	PRESENT	0
261095	261094	14030Q	PRESIDENT	0	PRESENT	0
261096	261094	08043V	PARTICIPANT	\N	PRESENT	0
261097	261094	19643A	PARTICIPANT	\N	PRESENT	0
261098	261094	08024S	PARTICIPANT	\N	PRESENT	0
261099	261094	14217N	PARTICIPANT	\N	PRESENT	0
261100	261094	19731Y	PARTICIPANT	\N	PRESENT	0
261101	261094	08031R	PARTICIPANT	\N	PRESENT	0
261102	261094	07029T	PARTICIPANT	\N	PRESENT	0
261103	261094	11045K	PARTICIPANT	\N	PRESENT	0
261104	261094	19749K	PARTICIPANT	\N	PRESENT	0
261105	261094	08020N	PARTICIPANT	\N	EXCUSE	0
261106	261094	19693L	PARTICIPANT	\N	EXCUSE	0
261107	261094	14249W	PARTICIPANT	\N	EXCUSE	0
261108	261094	04035D	PARTICIPANT	\N	EXCUSE	0
261109	261094	19715Y	PARTICIPANT	\N	EXCUSE	0
261110	261094	19697Q	PARTICIPANT	\N	EXCUSE	0
261175	258694	05012A	PARTICIPANT	\N	PRESENT	0
261176	258694	08068F	PARTICIPANT	\N	PRESENT	0
262435	262433	07033P	PARTICIPANT	\N	PRESENT	0
263103	260596	19415P	PARTICIPANT	\N	PRESENT	0
263104	260596	11103C	PARTICIPANT	\N	PRESENT	0
263105	260596	14195A	PARTICIPANT	\N	PRESENT	0
263106	260596	19663E	PARTICIPANT	\N	PRESENT	0
263108	260596	98024R	PARTICIPANT	\N	PRESENT	0
263109	260596	14217N	PARTICIPANT	\N	PRESENT	0
263110	260596	14087W	PARTICIPANT	\N	PRESENT	0
263111	260596	19521Q	PARTICIPANT	\N	PRESENT	0
263112	260596	19727D	PARTICIPANT	\N	PRESENT	0
263113	260596	14213J	PARTICIPANT	\N	PRESENT	0
263114	260596	19683J	PARTICIPANT	\N	PRESENT	0
263115	260596	19723Y	PARTICIPANT	\N	PRESENT	0
263116	260596	19657G	PARTICIPANT	\N	PRESENT	0
263117	260596	11067R	PARTICIPANT	\N	PRESENT	0
263118	260596	14223L	PARTICIPANT	\N	PRESENT	0
252380	240298	08014Q	PARTICIPANT	0	PRESENT	0
252381	240298	14225N	PARTICIPANT	0	PRESENT	0
252382	240298	14034U	PARTICIPANT	0	PRESENT	0
252383	240298	14193X	PARTICIPANT	0	PRESENT	0
252384	240298	14079W	PARTICIPANT	0	PRESENT	0
252385	240298	14251Q	PARTICIPANT	0	PRESENT	0
252386	240298	19739H	PARTICIPANT	0	PRESENT	0
252387	240298	80027E	PARTICIPANT	0	PRESENT	0
252388	240298	19521Q	PARTICIPANT	0	PRESENT	0
252389	240298	04059M	PARTICIPANT	0	PRESENT	0
252390	240298	19253P	PARTICIPANT	0	PRESENT	0
252391	240298	19483C	PARTICIPANT	0	PRESENT	0
252392	240298	08020N	PARTICIPANT	0	PRESENT	0
252393	240298	14038Y	PARTICIPANT	0	PRESENT	0
252394	240298	14033T	PARTICIPANT	0	PRESENT	0
252395	240298	08061X	PARTICIPANT	0	PRESENT	0
252396	240298	14061L	PARTICIPANT	0	PRESENT	0
252397	240298	19737F	PARTICIPANT	0	PRESENT	0
252398	240298	11054L	PARTICIPANT	0	PRESENT	0
252399	240298	04085P	PARTICIPANT	0	PRESENT	0
252400	240298	14275Y	PARTICIPANT	0	PRESENT	0
252401	240298	10015M	PARTICIPANT	0	PRESENT	0
252402	240298	08039A	PARTICIPANT	0	PRESENT	0
252403	240298	08015R	PARTICIPANT	0	PRESENT	0
252404	240298	14237S	PARTICIPANT	0	PRESENT	0
252405	240298	14081Q	PARTICIPANT	0	PRESENT	0
252406	240298	11077T	PARTICIPANT	0	PRESENT	0
252407	240298	04092N	PARTICIPANT	0	PRESENT	0
252408	240298	08018U	PARTICIPANT	0	PRESENT	0
252409	240298	11033F	PARTICIPANT	0	PRESENT	0
252410	240298	14065Q	PARTICIPANT	0	PRESENT	0
252411	240298	19399H	PARTICIPANT	0	PRESENT	0
252412	240298	11090Q	PARTICIPANT	0	PRESENT	0
252413	240298	19479G	PARTICIPANT	0	PRESENT	0
252414	240298	19441R	PARTICIPANT	0	PRESENT	0
252415	240298	19749K	PARTICIPANT	0	PRESENT	0
252416	240298	16685X	PARTICIPANT	0	PRESENT	0
252417	240298	19447X	PARTICIPANT	0	PRESENT	0
252418	240298	19643A	PARTICIPANT	0	PRESENT	0
252419	240298	04033B	PARTICIPANT	0	PRESENT	0
252420	240298	04088S	PARTICIPANT	0	PRESENT	0
252421	240298	19489J	PARTICIPANT	0	PRESENT	0
252422	240298	19741B	PARTICIPANT	0	PRESENT	0
252423	240298	14267Y	PARTICIPANT	0	PRESENT	0
252424	240298	08034U	PARTICIPANT	0	PRESENT	0
252425	240298	14135M	PARTICIPANT	0	PRESENT	0
252426	240298	80013X	PARTICIPANT	0	PRESENT	0
252427	240298	19727D	PARTICIPANT	0	PRESENT	0
252428	240298	14217N	PARTICIPANT	0	PRESENT	0
252429	240298	11056N	PARTICIPANT	0	PRESENT	0
252430	240298	14199E	PARTICIPANT	0	PRESENT	0
252431	240298	97011G	PARTICIPANT	0	PRESENT	0
252432	240298	19701S	PARTICIPANT	0	PRESENT	0
252433	240298	19251M	PARTICIPANT	0	PRESENT	0
252434	240298	14159V	PARTICIPANT	0	PRESENT	0
252435	240298	07029T	PARTICIPANT	0	PRESENT	0
252436	240298	19637C	PARTICIPANT	0	PRESENT	0
252437	240298	14205J	PARTICIPANT	0	PRESENT	0
252438	240298	19581D	PARTICIPANT	0	PRESENT	0
252439	240298	14357A	PARTICIPANT	0	PRESENT	0
252440	240298	98050T	PARTICIPANT	0	PRESENT	0
252441	240298	14089Y	PARTICIPANT	0	PRESENT	0
252458	251307	08015R	PARTICIPANT	\N	PRESENT	0
252462	251307	14065Q	PARTICIPANT	\N	EXCUSE	0
252464	251307	14061L	PARTICIPANT	\N	EXCUSE	0
252465	251307	11090Q	PARTICIPANT	\N	EXCUSE	0
252530	252529	14217N	PARTICIPANT	\N	PRESENT	0
252531	252529	11083R	PARTICIPANT	\N	PRESENT	0
252532	252529	14097Y	PARTICIPANT	\N	PRESENT	0
252533	252529	07034Q	PARTICIPANT	\N	PRESENT	0
252534	252529	17589D	PARTICIPANT	\N	PRESENT	0
252535	252529	10006L	PARTICIPANT	\N	PRESENT	0
252536	252529	19575F	PARTICIPANT	\N	PRESENT	0
253077	253076	14193X	PARTICIPANT	\N	PRESENT	0
253078	253076	14235Q	PARTICIPANT	\N	PRESENT	0
253079	253076	08053X	PARTICIPANT	\N	PRESENT	0
253080	253076	95067Q	PARTICIPANT	\N	PRESENT	0
253082	253081	04042C	PARTICIPANT	\N	PRESENT	0
253083	253081	11054L	PARTICIPANT	\N	PRESENT	0
253084	253081	14235Q	PARTICIPANT	\N	PRESENT	0
253085	253081	98029W	PARTICIPANT	\N	PRESENT	0
253086	253081	98018T	PARTICIPANT	\N	PRESENT	0
253087	253081	14133K	PARTICIPANT	\N	PRESENT	0
253089	253088	08047A	PARTICIPANT	\N	PRESENT	0
253090	253088	19421M	PARTICIPANT	\N	PRESENT	0
253091	253088	19251M	PARTICIPANT	\N	PRESENT	0
253093	253092	08068F	PARTICIPANT	\N	PRESENT	0
253094	253092	08028W	PARTICIPANT	\N	PRESENT	0
253095	253092	19737F	PARTICIPANT	\N	PRESENT	0
253681	253680	19651A	PARTICIPANT	\N	PRESENT	0
253682	253680	11074Q	PARTICIPANT	\N	PRESENT	0
254466	254465	14069U	PARTICIPANT	\N	PRESENT	0
254467	254465	19483C	PARTICIPANT	\N	PRESENT	0
254841	254840	11053K	PARTICIPANT	\N	PRESENT	0
254842	254840	14159V	PARTICIPANT	\N	PRESENT	0
254843	254840	05012A	PARTICIPANT	\N	PRESENT	0
254994	254993	14065Q	PARTICIPANT	\N	EXCUSE	0
254996	254993	14135M	PARTICIPANT	\N	EXCUSE	0
254995	254993	11026G	PARTICIPANT	\N	EXCUSE	0
254999	254998	19399H	PARTICIPANT	\N	PRESENT	0
255001	254998	04070G	PARTICIPANT	\N	PRESENT	0
255002	254998	19593H	PARTICIPANT	\N	PRESENT	0
255003	254998	14229S	PARTICIPANT	\N	PRESENT	0
255004	254998	19735D	PARTICIPANT	\N	PRESENT	0
255376	255374	98029W	PARTICIPANT	\N	PRESENT	0
255378	255374	08052W	PARTICIPANT	\N	PRESENT	0
255379	255374	14249W	PARTICIPANT	\N	PRESENT	0
255380	255374	19647E	PARTICIPANT	\N	PRESENT	0
255381	255374	19569H	PARTICIPANT	\N	PRESENT	0
255382	255374	14073Q	PARTICIPANT	\N	PRESENT	0
255383	255374	16685X	PARTICIPANT	\N	PRESENT	0
255384	255374	14001X	PARTICIPANT	\N	PRESENT	0
255385	255374	08053X	PARTICIPANT	\N	PRESENT	0
255386	255374	11041F	PARTICIPANT	\N	PRESENT	0
255387	255374	95067Q	PARTICIPANT	\N	PRESENT	0
255493	251151	19565D	PARTICIPANT	\N	PRESENT	0
255494	251151	14231L	PARTICIPANT	\N	PRESENT	0
255495	251151	19253P	PARTICIPANT	\N	PRESENT	0
255496	251151	14327T	PARTICIPANT	\N	PRESENT	0
255497	251151	14259Y	PARTICIPANT	\N	PRESENT	0
255498	251151	19489J	PARTICIPANT	\N	PRESENT	0
255499	251151	14069U	PARTICIPANT	\N	PRESENT	0
255573	255572	14065Q	PARTICIPANT	\N	PRESENT	0
255574	255572	07034Q	PARTICIPANT	\N	PRESENT	0
255732	255731	04040A	PARTICIPANT	\N	PRESENT	0
255733	255731	14069U	PARTICIPANT	\N	PRESENT	0
255734	255731	11027H	PARTICIPANT	\N	PRESENT	0
255735	255731	14079W	PARTICIPANT	\N	PRESENT	0
255736	255731	14073Q	PARTICIPANT	\N	PRESENT	0
255737	255731	04049K	PARTICIPANT	\N	PRESENT	0
255738	255731	19483C	PARTICIPANT	\N	PRESENT	0
255739	255731	95063L	PARTICIPANT	\N	PRESENT	0
255740	255731	04034C	PARTICIPANT	\N	PRESENT	0
255830	255829	11048N	PARTICIPANT	\N	PRESENT	0
255831	255829	14026U	PARTICIPANT	\N	PRESENT	0
255832	255829	14103D	PARTICIPANT	\N	PRESENT	0
255833	255829	11067R	PARTICIPANT	\N	PRESENT	0
255834	255829	04038G	PARTICIPANT	\N	PRESENT	0
255835	255829	14157T	PARTICIPANT	\N	PRESENT	0
255836	255829	19545Y	PARTICIPANT	\N	PRESENT	0
255837	255829	19503N	PARTICIPANT	\N	PRESENT	0
255838	255829	01024M	PARTICIPANT	\N	PRESENT	0
255839	255829	19711U	PARTICIPANT	\N	PRESENT	0
255840	255829	19719D	PARTICIPANT	\N	PRESENT	0
255841	255829	11040E	PARTICIPANT	\N	PRESENT	0
255842	255829	14151M	PARTICIPANT	\N	PRESENT	0
255844	255829	14071N	PARTICIPANT	\N	PRESENT	0
255845	255829	19651A	PARTICIPANT	\N	PRESENT	0
255846	255829	95063L	PARTICIPANT	\N	PRESENT	0
255857	255856	95063L	PARTICIPANT	\N	PRESENT	0
255871	255870	19545Y	PARTICIPANT	\N	PRESENT	0
255873	255872	08034U	PARTICIPANT	\N	PRESENT	0
255920	255919	04040A	PARTICIPANT	\N	PRESENT	0
255921	255919	01062T	PARTICIPANT	\N	PRESENT	0
255923	255922	04040A	PARTICIPANT	\N	PRESENT	0
255924	255922	01062T	PARTICIPANT	\N	PRESENT	0
255925	255918	88008L	PARTICIPANT	\N	PRESENT	0
255926	255918	11012A	PARTICIPANT	\N	PRESENT	0
255947	255946	08052W	PARTICIPANT	\N	PRESENT	0
255948	255946	10006L	PARTICIPANT	\N	PRESENT	0
255949	255946	19553Y	PARTICIPANT	\N	PRESENT	0
256015	256014	04040A	PARTICIPANT	\N	PRESENT	0
256164	256163	04040A	PARTICIPANT	\N	PRESENT	0
256165	256163	14259Y	PARTICIPANT	\N	PRESENT	0
256452	250133	11067R	PARTICIPANT	\N	PRESENT	0
256453	250133	19727D	PARTICIPANT	\N	PRESENT	0
256454	250133	14195A	PARTICIPANT	\N	PRESENT	0
240602	240599	14267Y	PARTICIPANT	\N	PRESENT	0
240603	240599	14231L	PARTICIPANT	\N	PRESENT	0
240604	240599	07034Q	PARTICIPANT	\N	PRESENT	0
240605	240599	14265W	PARTICIPANT	\N	PRESENT	0
240606	240599	11027H	PARTICIPANT	\N	PRESENT	0
240607	240599	04049K	PARTICIPANT	\N	PRESENT	0
240608	240599	08068F	PARTICIPANT	\N	PRESENT	0
240609	240599	08055A	PARTICIPANT	\N	PRESENT	0
240610	240599	04059M	PARTICIPANT	\N	PRESENT	0
240611	240599	04045F	PARTICIPANT	\N	PRESENT	0
240612	240599	08058D	PARTICIPANT	\N	PRESENT	0
240620	240599	04085P	PARTICIPANT	\N	PRESENT	0
240621	240599	11031D	PARTICIPANT	\N	PRESENT	0
240622	240599	19695N	PARTICIPANT	\N	PRESENT	0
240623	240599	19347U	PARTICIPANT	\N	PRESENT	0
240624	240599	19565D	PARTICIPANT	\N	PRESENT	0
240625	240599	19687N	PARTICIPANT	\N	PRESENT	0
240626	240599	11033F	PARTICIPANT	\N	PRESENT	0
240627	240599	95037J	PARTICIPANT	\N	PRESENT	0
240628	240599	04034C	PARTICIPANT	\N	PRESENT	0
240629	240599	17637T	PARTICIPANT	\N	PRESENT	0
240630	240599	19679N	PARTICIPANT	\N	PRESENT	0
240631	240599	95062K	PARTICIPANT	\N	PRESENT	0
240632	240599	98029W	PARTICIPANT	\N	PRESENT	0
240633	240599	19711U	PARTICIPANT	\N	PRESENT	0
240634	240599	19349W	PARTICIPANT	\N	PRESENT	0
240635	240599	19269X	PARTICIPANT	\N	PRESENT	0
240636	240599	01058X	PARTICIPANT	\N	PRESENT	0
240637	240599	08021P	PARTICIPANT	\N	PRESENT	0
240638	240599	99004R	PARTICIPANT	\N	PRESENT	0
240639	240599	04061F	PARTICIPANT	\N	PRESENT	0
240640	240599	14061L	PARTICIPANT	\N	PRESENT	0
240641	240599	14039A	PARTICIPANT	\N	PRESENT	0
240642	240599	11072N	PARTICIPANT	\N	PRESENT	0
240643	240599	08020N	PARTICIPANT	\N	PRESENT	0
240644	240599	19637C	PARTICIPANT	\N	PRESENT	0
240645	240599	95015C	PARTICIPANT	\N	PRESENT	0
240646	240599	14123H	PARTICIPANT	\N	PRESENT	0
240647	240599	88008L	PARTICIPANT	\N	PRESENT	0
240648	240599	08031R	PARTICIPANT	\N	PRESENT	0
240649	240599	11012A	PARTICIPANT	\N	PRESENT	0
240650	240599	19253P	PARTICIPANT	\N	PRESENT	0
240651	240599	14261S	PARTICIPANT	\N	PRESENT	0
240652	240599	15447F	PARTICIPANT	\N	PRESENT	0
240653	240599	19681G	PARTICIPANT	\N	PRESENT	0
240654	240599	19515S	PARTICIPANT	\N	PRESENT	0
240655	240599	14201E	PARTICIPANT	\N	PRESENT	0
240656	240599	04071H	PARTICIPANT	\N	PRESENT	0
240657	240599	19563B	PARTICIPANT	\N	PRESENT	0
240658	240599	19719D	PARTICIPANT	\N	PRESENT	0
240659	240599	19387D	PARTICIPANT	\N	PRESENT	0
240660	240599	19643A	PARTICIPANT	\N	PRESENT	0
240661	240599	19717B	PARTICIPANT	\N	PRESENT	0
240662	240599	96004D	PARTICIPANT	\N	PRESENT	0
240663	240599	19703U	PARTICIPANT	\N	PRESENT	0
240664	240599	19673G	PARTICIPANT	\N	PRESENT	0
240665	240599	19447X	PARTICIPANT	\N	PRESENT	0
240666	240599	19649G	PARTICIPANT	\N	PRESENT	0
240667	240599	19573D	PARTICIPANT	\N	PRESENT	0
240668	240599	11064N	PARTICIPANT	\N	PRESENT	0
240669	240599	14042U	PARTICIPANT	\N	PRESENT	0
240670	240599	14093U	PARTICIPANT	\N	PRESENT	0
240671	240599	98005N	PARTICIPANT	\N	PRESENT	0
240672	240599	19545Y	PARTICIPANT	\N	PRESENT	0
240673	240599	14133K	PARTICIPANT	\N	PRESENT	0
240674	240599	19707Y	PARTICIPANT	\N	PRESENT	0
240675	240599	14195A	PARTICIPANT	\N	PRESENT	0
240676	240599	19705W	PARTICIPANT	\N	PRESENT	0
240677	240599	14119M	PARTICIPANT	\N	PRESENT	0
240678	240599	14038Y	PARTICIPANT	\N	PRESENT	0
240679	240599	14251Q	PARTICIPANT	\N	PRESENT	0
240680	240599	14111D	PARTICIPANT	\N	PRESENT	0
240681	240599	19507S	PARTICIPANT	\N	PRESENT	0
240682	240599	04057K	PARTICIPANT	\N	PRESENT	0
240683	240599	14041T	PARTICIPANT	\N	PRESENT	0
240684	240599	19723Y	PARTICIPANT	\N	PRESENT	0
240685	240599	19685L	PARTICIPANT	\N	PRESENT	0
240686	240599	19731Y	PARTICIPANT	\N	PRESENT	0
240687	240599	14055N	PARTICIPANT	\N	PRESENT	0
240688	240599	19467C	PARTICIPANT	\N	PRESENT	0
240689	240599	08028W	PARTICIPANT	\N	PRESENT	0
240691	240599	98035U	PARTICIPANT	\N	PRESENT	0
240692	240599	14159V	PARTICIPANT	\N	PRESENT	0
240693	240599	11045K	PARTICIPANT	\N	PRESENT	0
240694	240599	11077T	PARTICIPANT	\N	PRESENT	0
240695	240599	98018T	PARTICIPANT	\N	PRESENT	0
240696	240599	08052W	PARTICIPANT	\N	PRESENT	0
240697	240599	18083K	PARTICIPANT	\N	PRESENT	0
240698	240599	11067R	PARTICIPANT	\N	PRESENT	0
240699	240599	19693L	PARTICIPANT	\N	PRESENT	0
240700	240599	19399H	PARTICIPANT	\N	PRESENT	0
240701	240599	19415P	PARTICIPANT	\N	PRESENT	0
240702	240599	14229S	PARTICIPANT	\N	PRESENT	0
240703	240599	14033T	PARTICIPANT	\N	PRESENT	0
240704	240599	19709B	PARTICIPANT	\N	PRESENT	0
240705	240599	14051J	PARTICIPANT	\N	PRESENT	0
240741	240599	14081Q	PARTICIPANT	\N	PRESENT	0
240707	240599	14107H	PARTICIPANT	\N	PRESENT	0
240708	240599	08016S	PARTICIPANT	\N	PRESENT	0
240709	240599	08045X	PARTICIPANT	\N	PRESENT	0
240710	240599	14135M	PARTICIPANT	\N	PRESENT	0
240711	240599	14281W	PARTICIPANT	\N	PRESENT	0
240712	240599	14225N	PARTICIPANT	\N	PRESENT	0
240713	240599	14331P	PARTICIPANT	\N	PRESENT	0
240714	240599	14021P	PARTICIPANT	\N	PRESENT	0
240715	240599	14151M	PARTICIPANT	\N	PRESENT	0
240716	240599	04088S	PARTICIPANT	\N	PRESENT	0
240717	240599	19647E	PARTICIPANT	\N	PRESENT	0
240718	240599	19443T	PARTICIPANT	\N	PRESENT	0
240719	240599	12016W	PARTICIPANT	\N	PRESENT	0
240720	240599	01025N	PARTICIPANT	\N	PRESENT	0
240721	240599	14028W	PARTICIPANT	\N	PRESENT	0
240722	240599	14073Q	PARTICIPANT	\N	PRESENT	0
240723	240599	80013X	PARTICIPANT	\N	PRESENT	0
240724	240599	14083S	PARTICIPANT	\N	PRESENT	0
240725	240599	08060W	PARTICIPANT	\N	PRESENT	0
240726	240599	08038Y	PARTICIPANT	\N	PRESENT	0
240727	240599	11066Q	PARTICIPANT	\N	PRESENT	0
240728	240599	11104D	PARTICIPANT	\N	PRESENT	0
240729	240599	19741B	PARTICIPANT	\N	PRESENT	0
240731	240599	19727D	PARTICIPANT	\N	PRESENT	0
240732	240599	14026U	PARTICIPANT	\N	PRESENT	0
240733	240599	80027E	PARTICIPANT	\N	PRESENT	0
240734	240599	19489J	PARTICIPANT	\N	PRESENT	0
240735	240599	04086Q	PARTICIPANT	\N	PRESENT	0
240736	240599	17779H	PARTICIPANT	\N	PRESENT	0
240737	240599	04092N	PARTICIPANT	\N	PRESENT	0
240738	240599	14121F	PARTICIPANT	\N	PRESENT	0
240739	240599	19525U	PARTICIPANT	\N	PRESENT	0
240740	240599	08019V	PARTICIPANT	\N	PRESENT	0
240742	240599	19421M	PARTICIPANT	\N	PRESENT	0
240743	240599	11041F	PARTICIPANT	\N	PRESENT	0
240744	240599	14207L	PARTICIPANT	\N	PRESENT	0
240745	240599	05008E	PARTICIPANT	\N	PRESENT	0
240746	240599	19725B	PARTICIPANT	\N	PRESENT	0
240747	240599	11097X	PARTICIPANT	\N	PRESENT	0
240748	240599	14001X	PARTICIPANT	\N	PRESENT	0
240749	240599	14071N	PARTICIPANT	\N	PRESENT	0
240750	240599	19683J	PARTICIPANT	\N	PRESENT	0
240751	240599	04033B	PARTICIPANT	\N	PRESENT	0
240752	240599	19295A	PARTICIPANT	\N	PRESENT	0
240753	240599	19543W	PARTICIPANT	\N	PRESENT	0
240754	240599	11054L	PARTICIPANT	\N	PRESENT	0
240755	240599	11043H	PARTICIPANT	\N	PRESENT	0
240756	240599	19251M	PARTICIPANT	\N	PRESENT	0
240757	240599	19591F	PARTICIPANT	\N	PRESENT	0
240758	240599	19503N	PARTICIPANT	\N	PRESENT	0
240759	240599	11010L	PARTICIPANT	\N	PRESENT	0
240760	240599	14063N	PARTICIPANT	\N	PRESENT	0
240761	240599	14249W	PARTICIPANT	\N	PRESENT	0
240762	240599	11090Q	PARTICIPANT	\N	PRESENT	0
240763	240599	19631V	PARTICIPANT	\N	PRESENT	0
240764	240599	95067Q	PARTICIPANT	\N	PRESENT	0
240765	240599	14109K	PARTICIPANT	\N	PRESENT	0
240766	240599	01057W	PARTICIPANT	\N	PRESENT	0
240767	240599	14097Y	PARTICIPANT	\N	PRESENT	0
240768	240599	14257W	PARTICIPANT	\N	PRESENT	0
240769	240599	08015R	PARTICIPANT	\N	PRESENT	0
240770	240599	17583W	PARTICIPANT	\N	PRESENT	0
240771	240599	19577H	PARTICIPANT	\N	PRESENT	0
240772	240599	14193X	PARTICIPANT	\N	PRESENT	0
240773	240599	10006L	PARTICIPANT	\N	PRESENT	0
240774	240599	14034U	PARTICIPANT	\N	PRESENT	0
240775	240599	08034U	PARTICIPANT	\N	PRESENT	0
240776	240599	10015M	PARTICIPANT	\N	PRESENT	0
240777	240599	11070L	PARTICIPANT	\N	PRESENT	0
250465	250453	07034Q	PARTICIPANT	\N	PRESENT	0
250597	250596	14225N	PARTICIPANT	\N	PRESENT	0
250598	250596	14151M	PARTICIPANT	\N	PRESENT	0
250599	250596	14051J	PARTICIPANT	\N	PRESENT	0
250600	250596	04040A	PARTICIPANT	\N	PRESENT	0
250601	250596	14081Q	PARTICIPANT	\N	PRESENT	0
250602	250596	14121F	PARTICIPANT	\N	PRESENT	0
250603	250596	14107H	PARTICIPANT	\N	PRESENT	0
250605	250223	19527W	PARTICIPANT	\N	PRESENT	0
250606	250223	19727D	PARTICIPANT	\N	PRESENT	0
250607	250223	14281W	PARTICIPANT	\N	PRESENT	0
250608	250223	08052W	PARTICIPANT	\N	PRESENT	0
250609	250223	19715Y	PARTICIPANT	\N	PRESENT	0
250610	250223	19683J	PARTICIPANT	\N	PRESENT	0
250611	250604	04070G	PRESIDENT	0	PRESENT	0
250612	250604	19699S	PARTICIPANT	\N	PRESENT	0
250613	250604	04044E	PARTICIPANT	\N	PRESENT	0
250614	250604	19673G	PARTICIPANT	\N	PRESENT	0
250615	250604	01028R	PARTICIPANT	\N	PRESENT	0
250616	250604	05008E	PARTICIPANT	\N	PRESENT	0
250617	250604	19447X	PARTICIPANT	\N	PRESENT	0
250618	250604	14039A	PARTICIPANT	\N	PRESENT	0
250619	250604	14147R	PARTICIPANT	\N	PRESENT	0
250620	250604	14151M	PARTICIPANT	\N	PRESENT	0
250621	250604	08018U	PARTICIPANT	\N	PRESENT	0
250622	250604	19483C	PARTICIPANT	\N	PRESENT	0
250623	250604	14249W	PARTICIPANT	\N	PRESENT	0
250624	250604	08031R	PARTICIPANT	\N	PRESENT	0
250625	250604	11072N	PARTICIPANT	\N	PRESENT	0
250626	250604	98035U	PARTICIPANT	\N	PRESENT	0
250627	250604	14053L	PARTICIPANT	\N	PRESENT	0
250628	250604	14059S	PARTICIPANT	\N	PRESENT	0
250629	250604	14111D	PARTICIPANT	\N	PRESENT	0
250630	250604	04057K	PARTICIPANT	\N	PRESENT	0
250631	250604	08035V	PARTICIPANT	\N	PRESENT	0
250632	250604	10015M	PARTICIPANT	\N	PRESENT	0
250633	250604	08045X	PARTICIPANT	\N	PRESENT	0
250634	250604	07034Q	PARTICIPANT	\N	PRESENT	0
250635	250604	19253P	PARTICIPANT	\N	PRESENT	0
250636	250604	08043V	PARTICIPANT	\N	PRESENT	0
250637	250604	04038G	PARTICIPANT	\N	PRESENT	0
250638	250604	19693L	PARTICIPANT	\N	PRESENT	0
250639	250604	19719D	PARTICIPANT	\N	PRESENT	0
250640	250604	14030Q	PARTICIPANT	\N	PRESENT	0
250641	250604	19725B	PARTICIPANT	\N	PRESENT	0
250642	250604	19729F	PARTICIPANT	\N	PRESENT	0
250643	250604	19731Y	PARTICIPANT	\N	PRESENT	0
250644	250604	14251Q	PARTICIPANT	\N	PRESENT	0
250645	250604	19629C	PARTICIPANT	\N	PRESENT	0
250646	250604	08020N	PARTICIPANT	\N	PRESENT	0
250647	250604	19735D	PARTICIPANT	\N	PRESENT	0
250648	250604	14063N	PARTICIPANT	\N	PRESENT	0
250649	250604	14069U	PARTICIPANT	\N	PRESENT	0
250650	250604	11085T	PARTICIPANT	\N	PRESENT	0
250651	250604	11049P	PARTICIPANT	\N	PRESENT	0
250652	250604	19749K	PARTICIPANT	\N	PRESENT	0
250653	250604	04018C	PARTICIPANT	\N	PRESENT	0
250654	250223	19697Q	PARTICIPANT	\N	PRESENT	0
250655	250223	11067R	PARTICIPANT	\N	PRESENT	0
250656	250223	11077T	PARTICIPANT	\N	PRESENT	0
250657	250223	14355X	PARTICIPANT	\N	PRESENT	0
250658	250223	11097X	PARTICIPANT	\N	PRESENT	0
250659	250223	19415P	PARTICIPANT	\N	PRESENT	0
250660	250223	14223L	PARTICIPANT	\N	PRESENT	0
250661	250223	04045F	PARTICIPANT	\N	PRESENT	0
250662	250223	19675J	PARTICIPANT	\N	PRESENT	0
250663	250223	11063M	PARTICIPANT	\N	PRESENT	0
250664	250223	17779H	PARTICIPANT	\N	PRESENT	0
250665	250223	19703U	PARTICIPANT	\N	PRESENT	0
250666	250223	14239U	PARTICIPANT	\N	PRESENT	0
250667	250223	14087W	PARTICIPANT	\N	PRESENT	0
250668	250223	19679N	PARTICIPANT	\N	PRESENT	0
250669	250223	14042U	PARTICIPANT	\N	PRESENT	0
250670	250223	19575F	PARTICIPANT	\N	PRESENT	0
250671	250223	14195A	PARTICIPANT	\N	PRESENT	0
250672	250223	14213J	PARTICIPANT	\N	PRESENT	0
250673	250223	19335Q	PARTICIPANT	\N	PRESENT	0
250674	250223	14217N	PARTICIPANT	\N	PRESENT	0
250675	250223	10006L	PARTICIPANT	\N	PRESENT	0
250676	250223	98024R	PARTICIPANT	\N	PRESENT	0
250677	250223	19521Q	PARTICIPANT	\N	PRESENT	0
250678	250223	01034P	PARTICIPANT	\N	PRESENT	0
250679	250223	04092N	PRESIDENT	0	PRESENT	0
250680	250223	11045K	PARTICIPANT	\N	PRESENT	0
250681	250223	19691J	PARTICIPANT	\N	PRESENT	0
250682	250223	19717B	PARTICIPANT	\N	PRESENT	0
250683	250223	11103C	PARTICIPANT	\N	PRESENT	0
250684	250223	19657G	PARTICIPANT	\N	PRESENT	0
250685	250223	14071N	PARTICIPANT	\N	PRESENT	0
250686	250223	08048B	PARTICIPANT	\N	EXCUSE	0
250793	250604	92040Q	PARTICIPANT	\N	PRESENT	0
250794	250604	19643A	PARTICIPANT	\N	EXCUSE	0
250795	250223	19569H	PARTICIPANT	\N	PRESENT	0
250796	250223	14026U	PARTICIPANT	\N	PRESENT	0
250797	250223	14227Q	PARTICIPANT	\N	PRESENT	0
250798	250223	11031D	PARTICIPANT	\N	PRESENT	0
250799	250223	19723Y	PARTICIPANT	\N	PRESENT	0
250800	250223	14119M	PARTICIPANT	\N	PRESENT	0
250809	250193	19575F	PARTICIPANT	\N	PRESENT	0
250810	250193	14089Y	PARTICIPANT	\N	PRESENT	0
250811	250193	98029W	PARTICIPANT	\N	PRESENT	0
250812	250193	11080N	PARTICIPANT	\N	PRESENT	0
250813	250193	11027H	PARTICIPANT	\N	PRESENT	0
250814	250193	19673G	PARTICIPANT	\N	PRESENT	0
250815	250193	08056B	PARTICIPANT	\N	PRESENT	0
250816	250193	19611R	PARTICIPANT	\N	PRESENT	0
250817	250193	14199E	PARTICIPANT	\N	PRESENT	0
250818	250193	98050T	PARTICIPANT	\N	PRESENT	0
250819	250193	19421M	PARTICIPANT	\N	PRESENT	0
250875	250194	19575F	PARTICIPANT	\N	PRESENT	0
250876	250194	14089Y	PARTICIPANT	\N	PRESENT	0
250877	250194	98029W	PARTICIPANT	\N	PRESENT	0
250878	250194	11080N	PARTICIPANT	\N	PRESENT	0
250879	250194	11027H	PARTICIPANT	\N	PRESENT	0
250880	250194	19673G	PARTICIPANT	\N	PRESENT	0
250881	250194	14199E	PARTICIPANT	\N	PRESENT	0
250882	250194	08056B	PARTICIPANT	\N	PRESENT	0
250883	250194	19611R	PARTICIPANT	\N	PRESENT	0
250884	250194	98050T	PARTICIPANT	\N	PRESENT	0
250885	250194	10015M	PARTICIPANT	\N	PRESENT	0
250886	250194	19421M	PARTICIPANT	\N	PRESENT	0
250893	250518	14259Y	PARTICIPANT	\N	PRESENT	0
250894	250560	04071H	PARTICIPANT	\N	PRESENT	0
250895	250560	11053K	PARTICIPANT	\N	PRESENT	0
250896	250560	11110B	PARTICIPANT	\N	PRESENT	0
250897	250560	19647E	PARTICIPANT	\N	PRESENT	0
250898	250560	08069G	PARTICIPANT	\N	PRESENT	0
250899	250560	19689Q	PARTICIPANT	\N	PRESENT	0
250900	250560	19741B	PARTICIPANT	\N	PRESENT	0
250976	250604	11109J	PARTICIPANT	\N	PRESENT	0
250977	250604	14259Y	PARTICIPANT	\N	PRESENT	0
250978	250604	14061L	PARTICIPANT	\N	EXCUSE	0
251576	251102	19333N	PARTICIPANT	\N	PRESENT	0
251577	251102	19701S	PARTICIPANT	\N	PRESENT	0
251578	251102	95062K	PARTICIPANT	\N	PRESENT	0
251579	251102	19549D	PARTICIPANT	\N	PRESENT	0
251580	251102	14219Q	PARTICIPANT	\N	PRESENT	0
251581	251102	14221J	PARTICIPANT	\N	PRESENT	0
251582	251102	19637C	PARTICIPANT	\N	PRESENT	0
251583	251102	19551W	PARTICIPANT	\N	PRESENT	0
251584	251102	18083K	PARTICIPANT	\N	PRESENT	0
251585	251102	05012A	PARTICIPANT	\N	PRESENT	0
251586	251102	14051J	PARTICIPANT	\N	PRESENT	0
251006	251001	11070L	PARTICIPANT	\N	PRESENT	0
251587	251102	08060W	PARTICIPANT	\N	PRESENT	0
251008	251001	14159V	PARTICIPANT	\N	PRESENT	0
251009	251001	08034U	PARTICIPANT	\N	PRESENT	0
251588	251102	19347U	PARTICIPANT	\N	PRESENT	0
251011	251001	11072N	PARTICIPANT	\N	PRESENT	0
251589	251102	19503N	PARTICIPANT	\N	PRESENT	0
251013	251001	14241N	PARTICIPANT	\N	PRESENT	0
251590	251102	08024S	PARTICIPANT	\N	PRESENT	0
251591	251102	98023Q	PARTICIPANT	\N	PRESENT	0
251592	251102	17637T	PARTICIPANT	\N	PRESENT	0
251593	251102	11065P	PARTICIPANT	\N	PRESENT	0
251594	251102	19525U	PARTICIPANT	\N	PRESENT	0
251595	251102	14038Y	PARTICIPANT	\N	PRESENT	0
251596	251102	14103D	PARTICIPANT	\N	PRESENT	0
251597	251102	14031R	PARTICIPANT	\N	PRESENT	0
251566	250196	08056B	PARTICIPANT	\N	PRESENT	0
251567	250196	19649G	PARTICIPANT	\N	PRESENT	0
251568	250196	19421M	PARTICIPANT	\N	PRESENT	0
251569	250196	10015M	PARTICIPANT	\N	PRESENT	0
251570	250196	11026G	PARTICIPANT	\N	PRESENT	0
251571	250196	19575F	PARTICIPANT	\N	PRESENT	0
251572	250196	98050T	PARTICIPANT	\N	PRESENT	0
251573	250196	08053X	PARTICIPANT	\N	PRESENT	0
251574	250196	98029W	PRESIDENT	0	PRESENT	0
240578	233555	08024S	PARTICIPANT	\N	PRESENT	0
240580	233555	19551W	PARTICIPANT	\N	PRESENT	0
240581	233555	19349W	PARTICIPANT	\N	PRESENT	0
242380	241235	19295A	PARTICIPANT	\N	EXCUSE	0
242381	241235	19583F	PARTICIPANT	\N	EXCUSE	0
242383	241235	04043D	PARTICIPANT	\N	EXCUSE	0
242384	241235	14219Q	PARTICIPANT	\N	EXCUSE	0
242388	241232	14135M	PARTICIPANT	\N	EXCUSE	0
242389	241232	95062K	PARTICIPANT	\N	EXCUSE	0
242390	241232	04043D	PARTICIPANT	\N	EXCUSE	0
242391	241232	19703U	PARTICIPANT	\N	EXCUSE	0
242392	241232	11033F	PARTICIPANT	\N	EXCUSE	0
243061	240896	17779H	PARTICIPANT	\N	PRESENT	0
243063	240896	19527W	PARTICIPANT	\N	PRESENT	0
243064	240896	11067R	PARTICIPANT	\N	PRESENT	0
243007	240896	11081P	PARTICIPANT	\N	EXCUSE	0
243225	239695	11083R	PARTICIPANT	\N	PRESENT	0
243009	240896	19747H	PARTICIPANT	\N	PRESENT	0
243010	240896	08068F	PARTICIPANT	\N	PRESENT	0
243011	240896	14207L	PARTICIPANT	\N	PRESENT	0
243012	240896	11101A	PARTICIPANT	\N	EXCUSE	0
243065	240896	19683J	PARTICIPANT	\N	PRESENT	0
243014	240896	08028W	PARTICIPANT	\N	PRESENT	0
243015	240896	19467C	PARTICIPANT	\N	PRESENT	0
243066	240896	08052W	PARTICIPANT	\N	PRESENT	0
243017	240896	80013X	PARTICIPANT	\N	PRESENT	0
243068	240896	11077T	PARTICIPANT	\N	PRESENT	0
243069	240896	19703U	PARTICIPANT	\N	PRESENT	0
243020	240896	08038Y	PARTICIPANT	\N	PRESENT	0
243021	240896	17589D	PARTICIPANT	\N	PRESENT	0
243070	240896	11063M	PARTICIPANT	\N	PRESENT	0
243023	240896	19507S	PARTICIPANT	\N	PRESENT	0
243024	240896	14197C	PARTICIPANT	\N	PRESENT	0
243025	240896	14187A	PARTICIPANT	\N	PRESENT	0
243026	240896	01025N	PARTICIPANT	\N	PRESENT	0
243071	240896	19415P	PARTICIPANT	\N	PRESENT	0
243028	240896	19565D	PARTICIPANT	\N	PRESENT	0
243029	240896	14033T	PARTICIPANT	\N	PRESENT	0
243030	240896	14081Q	PARTICIPANT	\N	PRESENT	0
243073	240896	08041T	PARTICIPANT	\N	PRESENT	0
243032	240896	19511N	PARTICIPANT	\N	PRESENT	0
243074	240896	04045F	PARTICIPANT	\N	PRESENT	0
243075	240896	19727D	PARTICIPANT	\N	PRESENT	0
243035	240896	08015R	PARTICIPANT	\N	PRESENT	0
243076	240896	14217N	PARTICIPANT	\N	PRESENT	0
243078	240896	19715Y	PARTICIPANT	\N	PRESENT	0
243038	240896	19441R	PARTICIPANT	\N	PRESENT	0
243079	240896	19697Q	PARTICIPANT	\N	PRESENT	0
243040	240896	08062Y	PARTICIPANT	\N	PRESENT	0
243080	240896	19679N	PARTICIPANT	\N	PRESENT	0
243081	240896	14071N	PARTICIPANT	\N	PRESENT	0
243043	240896	14257W	PARTICIPANT	\N	PRESENT	0
243044	240896	14265W	PARTICIPANT	\N	PRESENT	0
243082	240896	19575F	PARTICIPANT	\N	PRESENT	0
243046	240896	04088S	PARTICIPANT	\N	PRESENT	0
243047	240896	11090Q	PRESIDENT	0	PRESENT	0
243083	240896	14213J	PARTICIPANT	\N	PRESENT	0
243049	240896	14135M	PARTICIPANT	\N	PRESENT	0
243084	240896	11097X	PARTICIPANT	\N	PRESENT	0
243085	240896	98024R	PARTICIPANT	\N	PRESENT	0
243052	240896	19619A	PARTICIPANT	\N	PRESENT	0
243086	240896	14195A	PARTICIPANT	\N	PRESENT	0
243054	240896	19413M	PARTICIPANT	\N	PRESENT	0
243087	240896	11103C	PARTICIPANT	\N	PRESENT	0
243088	240896	14026U	PARTICIPANT	\N	PRESENT	0
243089	240896	14119M	PARTICIPANT	\N	PRESENT	0
243090	240896	01034P	PARTICIPANT	\N	PRESENT	0
243091	240896	19521Q	PARTICIPANT	\N	PRESENT	0
243092	240896	19691J	PARTICIPANT	\N	PRESENT	0
243093	240896	19723Y	PARTICIPANT	\N	PRESENT	0
243094	240896	04092N	PARTICIPANT	\N	PRESENT	0
243168	240897	19631V	PARTICIPANT	\N	PRESENT	0
243169	240897	19515S	PARTICIPANT	\N	PRESENT	0
243226	239695	19649G	PARTICIPANT	\N	PRESENT	0
243171	240897	11081P	PARTICIPANT	\N	EXCUSE	0
243232	239695	14133K	PARTICIPANT	\N	PRESENT	0
243173	240897	19747H	PARTICIPANT	\N	PRESENT	0
243174	240897	08068F	PARTICIPANT	\N	PRESENT	0
243233	239695	89017R	PARTICIPANT	\N	PRESENT	0
243176	240897	11101A	PARTICIPANT	\N	EXCUSE	0
243239	243237	14030Q	PARTICIPANT	\N	PRESENT	0
243178	240897	08028W	PARTICIPANT	\N	PRESENT	0
243179	240897	19467C	PARTICIPANT	\N	PRESENT	0
243240	243237	08043V	PARTICIPANT	\N	PRESENT	0
243181	240897	80013X	PARTICIPANT	\N	PRESENT	0
243241	243237	19621T	PARTICIPANT	\N	PRESENT	0
243242	243237	08020N	PARTICIPANT	\N	PRESENT	0
243184	240897	08038Y	PARTICIPANT	\N	PRESENT	0
243243	243237	95015C	PARTICIPANT	\N	PRESENT	0
243244	243237	14249W	PARTICIPANT	\N	PRESENT	0
243187	240897	19507S	PARTICIPANT	\N	PRESENT	0
243188	240897	14197C	PARTICIPANT	\N	PRESENT	0
243189	240897	14187A	PARTICIPANT	\N	PRESENT	0
243190	240897	01025N	PARTICIPANT	\N	PRESENT	0
243245	243237	14123H	PARTICIPANT	\N	PRESENT	0
243192	240897	19565D	PARTICIPANT	\N	PRESENT	0
243193	240897	14033T	PARTICIPANT	\N	PRESENT	0
243194	240897	14081Q	PARTICIPANT	\N	PRESENT	0
243246	243237	14061L	PARTICIPANT	\N	PRESENT	0
243247	243237	14073Q	PARTICIPANT	\N	PRESENT	0
243248	243237	19611R	PARTICIPANT	\N	PRESENT	0
243198	240897	04049K	PARTICIPANT	\N	PRESENT	0
243199	240897	08015R	PARTICIPANT	\N	PRESENT	0
243200	240897	01043Q	PARTICIPANT	\N	PRESENT	0
243201	240897	14205J	PARTICIPANT	\N	PRESENT	0
243202	240897	19441R	PARTICIPANT	\N	PRESENT	0
243249	243237	08031R	PARTICIPANT	\N	PRESENT	0
243204	240897	08062Y	PARTICIPANT	\N	PRESENT	0
243205	240897	19563B	PARTICIPANT	\N	PRESENT	0
243250	243237	14059S	PARTICIPANT	\N	PRESENT	0
243207	240897	14257W	PARTICIPANT	\N	PRESENT	0
243208	240897	14265W	PARTICIPANT	\N	PRESENT	0
243251	243237	04057K	PARTICIPANT	\N	PRESENT	0
243210	240897	04088S	PARTICIPANT	\N	PRESENT	0
243211	240897	11090Q	PRESIDENT	0	PRESENT	0
243252	243237	04070G	PRESIDENT	0	PRESENT	0
243253	243237	19593H	PARTICIPANT	\N	PRESENT	0
243254	243237	19735D	PARTICIPANT	\N	PRESENT	0
243215	240897	19705W	PARTICIPANT	\N	PRESENT	0
243255	243237	14229S	PARTICIPANT	\N	PRESENT	0
243256	243237	04018C	PARTICIPANT	\N	PRESENT	0
243218	240897	19413M	PARTICIPANT	\N	PRESENT	0
244112	244111	14103D	PARTICIPANT	\N	PRESENT	0
244114	244113	14103D	PARTICIPANT	\N	PRESENT	0
244116	244115	14103D	PARTICIPANT	\N	PRESENT	0
244118	244117	14103D	PARTICIPANT	\N	PRESENT	0
244119	244113	19515S	PARTICIPANT	\N	PRESENT	0
244120	244113	14151M	PARTICIPANT	\N	PRESENT	0
244122	244115	14069U	PARTICIPANT	\N	PRESENT	0
244123	244115	14151M	PARTICIPANT	\N	PRESENT	0
244137	243898	14199E	PARTICIPANT	\N	EXCUSE	0
244138	241232	19657G	PARTICIPANT	\N	EXCUSE	0
244139	241232	14199E	PARTICIPANT	\N	EXCUSE	0
244140	241232	19329S	PARTICIPANT	\N	PRESENT	0
244141	241232	19583F	PARTICIPANT	\N	EXCUSE	0
244142	241232	14277B	PARTICIPANT	\N	EXCUSE	0
246187	246177	08044W	PARTICIPANT	\N	PRESENT	0
246188	246177	14179A	PARTICIPANT	\N	PRESENT	0
246189	246177	19489J	PARTICIPANT	\N	PRESENT	0
246191	246170	08044W	PARTICIPANT	\N	PRESENT	0
249103	249102	14033T	PARTICIPANT	\N	PRESENT	0
249104	249102	18083K	PARTICIPANT	\N	PRESENT	0
249218	249217	04070G	PARTICIPANT	\N	PRESENT	0
256455	250133	19415P	PARTICIPANT	\N	PRESENT	0
256458	256449	14071N	PARTICIPANT	\N	PRESENT	0
256459	256449	14195A	PARTICIPANT	\N	PRESENT	0
256460	256449	04092N	PARTICIPANT	\N	PRESENT	0
256461	256449	19415P	PARTICIPANT	\N	PRESENT	0
256462	256449	19727D	PARTICIPANT	\N	PRESENT	0
256463	256449	11067R	PARTICIPANT	\N	PRESENT	0
256464	256449	19575F	PARTICIPANT	\N	PRESENT	0
256465	256449	14223L	PARTICIPANT	\N	PRESENT	0
256466	256449	19577H	PARTICIPANT	\N	PRESENT	0
257515	255990	19701S	PARTICIPANT	\N	PRESENT	0
257516	255990	19551W	PARTICIPANT	\N	PRESENT	0
257517	255990	19503N	PARTICIPANT	\N	PRESENT	0
257518	255990	17637T	PARTICIPANT	\N	PRESENT	0
257519	240325	14111D	PARTICIPANT	\N	PRESENT	0
257520	255990	14051J	PARTICIPANT	\N	PRESENT	0
257521	255990	19347U	PARTICIPANT	\N	PRESENT	0
257522	255990	19387D	PARTICIPANT	\N	PRESENT	0
257523	255990	14038Y	PARTICIPANT	\N	PRESENT	0
257524	240325	98035U	PARTICIPANT	\N	PRESENT	0
257525	240325	19733B	PARTICIPANT	\N	PRESENT	0
257526	240325	19663E	PARTICIPANT	\N	PRESENT	0
257527	240325	05008E	PARTICIPANT	\N	PRESENT	0
257528	240325	14195A	PARTICIPANT	\N	PRESENT	0
257529	240325	14261S	PARTICIPANT	\N	PRESENT	0
257530	255990	14221J	PARTICIPANT	\N	PRESENT	0
257531	255990	19289C	PARTICIPANT	\N	PRESENT	0
257532	255990	11065P	PARTICIPANT	\N	PRESENT	0
257619	240325	10006L	PARTICIPANT	\N	PRESENT	0
257620	240325	19521Q	PARTICIPANT	\N	PRESENT	0
257621	240325	19467C	PARTICIPANT	\N	PRESENT	0
257622	240325	11043H	PARTICIPANT	\N	PRESENT	0
257623	240325	11064N	PARTICIPANT	\N	PRESENT	0
257624	240325	14205J	PARTICIPANT	\N	PRESENT	0
257625	240325	18083K	PARTICIPANT	\N	PRESENT	0
257626	240325	19713W	PARTICIPANT	\N	PRESENT	0
257627	240325	14219Q	PARTICIPANT	\N	PRESENT	0
257628	240325	19399H	PARTICIPANT	\N	PRESENT	0
257629	240325	11097X	PARTICIPANT	\N	PRESENT	0
257630	240325	19701S	PARTICIPANT	\N	PRESENT	0
257631	240325	14042U	PARTICIPANT	\N	PRESENT	0
257632	240325	14071N	PARTICIPANT	\N	PRESENT	0
257633	240325	14031R	PARTICIPANT	\N	PRESENT	0
257634	240325	11049P	PARTICIPANT	\N	PRESENT	0
257635	240325	14157T	PARTICIPANT	\N	PRESENT	0
257636	240325	14073Q	PARTICIPANT	\N	PRESENT	0
257637	240325	19737F	PARTICIPANT	\N	PRESENT	0
257638	240325	14179A	PARTICIPANT	\N	PRESENT	0
257700	240326	01028R	PARTICIPANT	\N	PRESENT	0
257701	240326	14229S	PARTICIPANT	\N	PRESENT	0
257702	240326	14151M	PARTICIPANT	\N	PRESENT	0
257703	240326	19703U	PARTICIPANT	\N	PRESENT	0
257704	240326	14111D	PARTICIPANT	\N	PRESENT	0
257705	240326	07029T	PARTICIPANT	\N	PRESENT	0
257706	240326	19737F	PARTICIPANT	\N	PRESENT	0
257707	240326	14073Q	PARTICIPANT	\N	PRESENT	0
257708	240326	19663E	PARTICIPANT	\N	PRESENT	0
257709	240326	14030Q	PARTICIPANT	\N	PRESENT	0
257710	240326	14179A	PARTICIPANT	\N	PRESENT	0
257711	240326	14157T	PARTICIPANT	\N	PRESENT	0
257712	240326	19711U	PARTICIPANT	\N	PRESENT	0
257713	240326	19629C	PARTICIPANT	\N	PRESENT	0
257714	240326	14327T	PARTICIPANT	\N	PRESENT	0
257715	240326	04018C	PARTICIPANT	\N	PRESENT	0
257716	240326	19483C	PARTICIPANT	\N	PRESENT	0
257717	240326	11033F	PARTICIPANT	\N	PRESENT	0
257718	240326	19467C	PARTICIPANT	\N	PRESENT	0
257719	240326	19349W	PARTICIPANT	\N	PRESENT	0
257720	240326	19369B	PARTICIPANT	\N	PRESENT	0
257721	240326	14055N	PARTICIPANT	\N	PRESENT	0
257722	240326	19543W	PARTICIPANT	\N	PRESENT	0
257723	240326	17637T	PARTICIPANT	\N	PRESENT	0
257724	240326	04070G	PARTICIPANT	\N	PRESENT	0
257725	240326	19415P	PARTICIPANT	\N	PRESENT	0
257726	240326	98035U	PARTICIPANT	\N	PRESENT	0
257727	240326	19713W	PARTICIPANT	\N	PRESENT	0
257728	240326	19533U	PARTICIPANT	\N	PRESENT	0
257729	240326	14081Q	PARTICIPANT	\N	PRESENT	0
257730	240326	95030B	PARTICIPANT	\N	PRESENT	0
257731	240326	05008E	PARTICIPANT	\N	PRESENT	0
257732	240326	19545Y	PARTICIPANT	\N	PRESENT	0
257733	240326	14147R	PARTICIPANT	\N	PRESENT	0
257734	240326	04047H	PARTICIPANT	\N	PRESENT	0
257735	240326	19727D	PARTICIPANT	\N	PRESENT	0
257736	240326	14257W	PARTICIPANT	\N	PRESENT	0
257737	240326	19729F	PARTICIPANT	\N	PRESENT	0
257738	240326	14193X	PARTICIPANT	\N	PRESENT	0
257739	240326	14215L	PARTICIPANT	\N	PRESENT	0
257740	240326	11056N	PARTICIPANT	\N	PRESENT	0
257741	240326	08043V	PARTICIPANT	\N	PRESENT	0
257742	240326	19631V	PARTICIPANT	\N	PRESENT	0
257743	240326	11012A	PARTICIPANT	\N	PRESENT	0
257744	240326	11099A	PARTICIPANT	\N	PRESENT	0
257745	240326	19681G	PARTICIPANT	\N	PRESENT	0
257746	240326	19709B	PARTICIPANT	\N	PRESENT	0
257747	240326	14069U	PARTICIPANT	\N	PRESENT	0
257748	240326	14231L	PARTICIPANT	\N	PRESENT	0
257749	240326	19447X	PARTICIPANT	\N	PRESENT	0
257750	240326	11026G	PARTICIPANT	\N	PRESENT	0
257751	240326	08061X	PARTICIPANT	\N	PRESENT	0
257752	240326	19733B	PARTICIPANT	\N	PRESENT	0
257753	240326	19507S	PARTICIPANT	\N	PRESENT	0
257698	240326	14034U	PARTICIPANT	\N	PRESENT	0
257699	240326	08044W	PARTICIPANT	\N	PRESENT	0
257754	240326	14026U	PARTICIPANT	\N	PRESENT	0
257755	240326	14265W	PARTICIPANT	\N	PRESENT	0
257756	240326	14135M	PARTICIPANT	\N	PRESENT	0
257757	240326	14083S	PARTICIPANT	\N	PRESENT	0
257758	240326	14213J	PARTICIPANT	\N	PRESENT	0
257759	240326	19383Y	PARTICIPANT	\N	PRESENT	0
257760	240326	18083K	PARTICIPANT	\N	PRESENT	0
257761	240326	14042U	PARTICIPANT	\N	PRESENT	0
257762	240326	11048N	PARTICIPANT	\N	PRESENT	0
257763	240326	14133K	PARTICIPANT	\N	PRESENT	0
257764	240326	04033B	PARTICIPANT	\N	PRESENT	0
257765	240326	14033T	PARTICIPANT	\N	PRESENT	0
258134	255774	98053W	PARTICIPANT	\N	EXCUSE	0
258135	255774	08056B	PARTICIPANT	\N	EXCUSE	0
258136	255774	04034C	PARTICIPANT	\N	EXCUSE	0
258620	240330	11077T	PARTICIPANT	\N	PRESENT	0
258622	240330	11083R	PARTICIPANT	\N	PRESENT	0
258623	240330	14225N	PARTICIPANT	\N	PRESENT	0
258624	240330	19711U	PARTICIPANT	\N	PRESENT	0
258625	240330	04086Q	PARTICIPANT	\N	PRESENT	0
258626	240330	19741B	PARTICIPANT	\N	PRESENT	0
258627	240330	19629C	PARTICIPANT	\N	PRESENT	0
258628	240330	08058D	PARTICIPANT	\N	PRESENT	0
258629	240330	11012A	PARTICIPANT	\N	PRESENT	0
258630	240330	08011M	PARTICIPANT	\N	PRESENT	0
258631	240330	19695N	PARTICIPANT	\N	PRESENT	0
258633	240330	04085P	PARTICIPANT	\N	PRESENT	0
258639	240330	07004J	PARTICIPANT	\N	PRESENT	0
258640	240330	17589D	PARTICIPANT	\N	PRESENT	0
258641	240330	14085U	PARTICIPANT	\N	PRESENT	0
258644	240330	14083S	PARTICIPANT	\N	PRESENT	0
258645	240330	08061X	PARTICIPANT	\N	PRESENT	0
258646	240330	19673G	PARTICIPANT	\N	PRESENT	0
258647	240330	04018C	PARTICIPANT	\N	PRESENT	0
258648	240330	99004R	PARTICIPANT	\N	PRESENT	0
258649	240330	14267Y	PARTICIPANT	\N	PRESENT	0
258650	240330	11026G	PARTICIPANT	\N	PRESENT	0
258651	240330	14105F	PARTICIPANT	\N	PRESENT	0
258652	240330	98005N	PARTICIPANT	\N	PRESENT	0
258667	240330	14251Q	PARTICIPANT	\N	PRESENT	0
258668	240330	19693L	PARTICIPANT	\N	PRESENT	0
258669	240330	19657G	PARTICIPANT	\N	PRESENT	0
258670	240330	19399H	PARTICIPANT	\N	PRESENT	0
258671	240330	08019V	PARTICIPANT	\N	PRESENT	0
258672	240330	07029T	PARTICIPANT	\N	PRESENT	0
258673	240330	16685X	PARTICIPANT	\N	PRESENT	0
258681	240330	14031R	PARTICIPANT	\N	PRESENT	0
258682	258680	14053L	PARTICIPANT	\N	PRESENT	0
258683	240330	14221J	PARTICIPANT	\N	PRESENT	0
258691	258684	14053L	PARTICIPANT	\N	PRESENT	0
258693	258692	14053L	PARTICIPANT	\N	PRESENT	0
240585	238783	95041E	PARTICIPANT	\N	EXCUSE	0
240586	238783	08015R	PARTICIPANT	\N	EXCUSE	0
240587	238783	19637C	PARTICIPANT	\N	EXCUSE	0
240588	238783	08068F	PARTICIPANT	\N	PRESENT	0
240589	238783	19737F	PARTICIPANT	\N	PRESENT	0
240590	238783	14193X	PARTICIPANT	\N	PRESENT	0
240591	238783	19251M	PARTICIPANT	\N	PRESENT	0
240592	238783	19695N	PARTICIPANT	\N	PRESENT	0
240593	238783	11090Q	PARTICIPANT	\N	PRESENT	0
240594	238783	04061F	PARTICIPANT	\N	PRESENT	0
240595	238783	14028W	PARTICIPANT	\N	PRESENT	0
240596	238783	08028W	PRESIDENT	0	PRESENT	0
240597	238783	19349W	PARTICIPANT	\N	PRESENT	0
240598	238783	14073Q	PARTICIPANT	\N	PRESENT	0
240600	240599	86034E	PARTICIPANT	\N	PRESENT	0
240601	240599	14030Q	PARTICIPANT	\N	PRESENT	0
240778	240599	14179A	PARTICIPANT	\N	PRESENT	0
240779	240599	05012A	PARTICIPANT	\N	PRESENT	0
240780	240599	19369B	PARTICIPANT	\N	PRESENT	0
240781	240599	14259Y	PARTICIPANT	\N	PRESENT	0
240782	240599	19691J	PARTICIPANT	\N	PRESENT	0
240783	240599	11053K	PARTICIPANT	\N	PRESENT	0
240784	240599	98023Q	PARTICIPANT	\N	PRESENT	0
240785	240599	19611R	PARTICIPANT	\N	PRESENT	0
240786	240599	14253S	PARTICIPANT	\N	PRESENT	0
240787	240599	19737F	PARTICIPANT	\N	PRESENT	0
240788	240599	14199E	PARTICIPANT	\N	PRESENT	0
240852	240599	14205J	PARTICIPANT	\N	PRESENT	0
240790	240599	19699S	PARTICIPANT	\N	PRESENT	0
240791	240599	07004J	PARTICIPANT	\N	PRESENT	0
240792	240599	19721W	PARTICIPANT	\N	PRESENT	0
240793	240599	14255U	PARTICIPANT	\N	PRESENT	0
240794	240599	19619A	PARTICIPANT	\N	PRESENT	0
240795	240599	19581D	PARTICIPANT	\N	PRESENT	0
240796	240599	19735D	PARTICIPANT	\N	PRESENT	0
240797	240599	14103D	PARTICIPANT	\N	PRESENT	0
240798	240599	14065Q	PARTICIPANT	\N	PRESENT	0
240799	240599	19569H	PARTICIPANT	\N	PRESENT	0
240800	240599	16685X	PARTICIPANT	\N	PRESENT	0
240801	240599	19479G	PARTICIPANT	\N	PRESENT	0
240802	240599	19747H	PARTICIPANT	\N	PRESENT	0
240803	240599	19441R	PARTICIPANT	\N	PRESENT	0
240804	240599	14219Q	PARTICIPANT	\N	PRESENT	0
240805	240599	14275Y	PARTICIPANT	\N	PRESENT	0
240806	240599	14277B	PARTICIPANT	\N	PRESENT	0
240807	240599	14079W	PARTICIPANT	\N	PRESENT	0
240808	240599	19713W	PARTICIPANT	\N	PRESENT	0
240809	240599	01024M	PARTICIPANT	\N	PRESENT	0
240810	240599	07033P	PARTICIPANT	\N	PRESENT	0
240811	240599	04040A	PARTICIPANT	\N	PRESENT	0
240812	240599	14105F	PARTICIPANT	\N	PRESENT	0
240813	240599	14115H	PARTICIPANT	\N	PRESENT	0
240814	240599	11049P	PARTICIPANT	\N	PRESENT	0
240815	240599	14089Y	PARTICIPANT	\N	PRESENT	0
240816	240599	08024S	PARTICIPANT	\N	PRESENT	0
240817	240599	19749K	PARTICIPANT	\N	PRESENT	0
240833	240599	19329S	PARTICIPANT	\N	PRESENT	0
240819	240599	04089T	PARTICIPANT	\N	PRESENT	0
240820	240599	14221J	PARTICIPANT	\N	PRESENT	0
240821	240599	19335Q	PARTICIPANT	\N	PRESENT	0
240822	240599	89017R	PARTICIPANT	\N	PRESENT	0
240823	240599	14241N	PARTICIPANT	\N	PRESENT	0
240824	240599	19671E	PARTICIPANT	\N	PRESENT	0
240825	240599	08061X	PARTICIPANT	\N	PRESENT	0
240826	240599	95063L	PARTICIPANT	\N	PRESENT	0
240827	240599	04018C	PARTICIPANT	\N	PRESENT	0
240828	240599	11099A	PARTICIPANT	\N	PRESENT	0
240829	240599	19701S	PARTICIPANT	\N	PRESENT	0
240830	240599	11074Q	PARTICIPANT	\N	PRESENT	0
240831	240599	14357A	PARTICIPANT	\N	PRESENT	0
240832	240599	19651A	PARTICIPANT	\N	PRESENT	0
240834	240599	19483C	PARTICIPANT	\N	PRESENT	0
240835	240599	19675J	PARTICIPANT	\N	PRESENT	0
240836	240599	14329V	PARTICIPANT	\N	PRESENT	0
240837	240599	08043V	PARTICIPANT	\N	PRESENT	0
240838	240599	14213J	PARTICIPANT	\N	PRESENT	0
240839	240599	19729F	PARTICIPANT	\N	PRESENT	0
240840	240599	14227Q	PARTICIPANT	\N	PRESENT	0
240841	240599	19527W	PARTICIPANT	\N	PRESENT	0
240842	240599	07029T	PARTICIPANT	\N	PRESENT	0
240843	240599	19551W	PARTICIPANT	\N	PRESENT	0
240844	240599	19657G	PARTICIPANT	\N	PRESENT	0
240845	240599	11109J	PARTICIPANT	\N	PRESENT	0
240846	240599	08062Y	PARTICIPANT	\N	PRESENT	0
240847	240599	98050T	PARTICIPANT	\N	PRESENT	0
240848	240599	14059S	PARTICIPANT	\N	PRESENT	0
240849	240599	04008A	PARTICIPANT	\N	PRESENT	0
240850	240599	19689Q	PARTICIPANT	\N	PRESENT	0
240854	240599	11026G	PARTICIPANT	\N	PRESENT	0
240853	240599	14069U	PARTICIPANT	\N	PRESENT	0
240855	240599	14087W	PARTICIPANT	\N	PRESENT	0
240856	240599	11085T	PARTICIPANT	\N	PRESENT	0
240859	240599	11080N	PARTICIPANT	\N	PRESENT	0
240863	240599	08073C	PARTICIPANT	\N	PRESENT	0
240861	240599	11083R	PARTICIPANT	\N	PRESENT	0
240862	240599	04070G	PARTICIPANT	\N	PRESENT	0
241063	239672	98005N	PARTICIPANT	\N	PRESENT	0
241064	239672	14225N	PARTICIPANT	\N	PRESENT	0
241065	239672	19647E	PARTICIPANT	\N	PRESENT	0
241391	241370	05008E	PARTICIPANT	\N	PRESENT	0
241392	241370	14089Y	PARTICIPANT	\N	PRESENT	0
241068	239672	14081Q	PARTICIPANT	\N	PRESENT	0
241069	239672	08017T	PARTICIPANT	\N	PRESENT	0
241070	239672	11027H	PARTICIPANT	\N	PRESENT	0
241071	239672	04034C	PARTICIPANT	\N	PRESENT	0
241072	239672	11031D	PARTICIPANT	\N	PRESENT	0
241073	239672	19695N	PARTICIPANT	\N	PRESENT	0
241074	239672	19569H	PARTICIPANT	\N	PRESENT	0
241075	239672	14255U	PARTICIPANT	\N	PRESENT	0
241076	239672	14261S	PARTICIPANT	\N	PRESENT	0
241077	239672	11033F	PARTICIPANT	\N	PRESENT	0
241078	239672	19693L	PARTICIPANT	\N	PRESENT	0
241079	239672	19707Y	PARTICIPANT	\N	PRESENT	0
241080	239672	19705W	PARTICIPANT	\N	PRESENT	0
241081	239672	14041T	PARTICIPANT	\N	PRESENT	0
241082	239672	19671E	PARTICIPANT	\N	PRESENT	0
241083	239672	08052W	PARTICIPANT	\N	PRESENT	0
241084	239672	14251Q	PARTICIPANT	\N	PRESENT	0
241393	241370	08018U	PARTICIPANT	\N	PRESENT	0
241395	241370	19581D	PARTICIPANT	\N	PRESENT	0
241396	241370	95063L	PARTICIPANT	\N	PRESENT	0
244326	244325	08015R	PARTICIPANT	\N	PRESENT	0
244327	244325	14001X	PARTICIPANT	\N	PRESENT	0
244328	244325	19467C	PARTICIPANT	\N	PRESENT	0
244329	244325	14197C	PARTICIPANT	\N	PRESENT	0
244330	244325	08018U	PARTICIPANT	\N	PRESENT	0
244331	244325	01043Q	PARTICIPANT	\N	PRESENT	0
246179	232876	19629C	PARTICIPANT	\N	PRESENT	0
246180	232876	08024S	PARTICIPANT	\N	PRESENT	0
246181	232876	04038G	PARTICIPANT	\N	PRESENT	0
246182	232876	19711U	PARTICIPANT	\N	PRESENT	0
246184	232876	14107H	PARTICIPANT	\N	PRESENT	0
247287	247286	05008E	PARTICIPANT	\N	PRESENT	0
249467	247145	19563B	PARTICIPANT	\N	EXCUSE	0
247289	247286	08038Y	PARTICIPANT	\N	PRESENT	0
247290	247286	14215L	PARTICIPANT	\N	PRESENT	0
247291	247286	19649G	PARTICIPANT	\N	PRESENT	0
247292	247286	19447X	PARTICIPANT	\N	PRESENT	0
247293	247286	14073Q	PARTICIPANT	\N	PRESENT	0
247294	247286	12041X	PARTICIPANT	\N	PRESENT	0
247295	247286	08012N	PARTICIPANT	\N	PRESENT	0
249477	247146	19563B	PARTICIPANT	\N	EXCUSE	0
251284	251235	96004D	PARTICIPANT	\N	PRESENT	0
247298	247286	11090Q	PARTICIPANT	\N	PRESENT	0
251282	251235	04085P	PARTICIPANT	\N	PRESENT	0
247300	247286	19301E	PARTICIPANT	\N	PRESENT	0
251281	251235	89017R	PARTICIPANT	\N	PRESENT	0
251283	251235	05008E	PARTICIPANT	\N	PRESENT	0
251285	251235	04042C	PARTICIPANT	\N	PRESENT	0
251286	251235	08028W	PARTICIPANT	\N	PRESENT	0
251287	251235	04086Q	PARTICIPANT	\N	PRESENT	0
251288	251235	11074Q	PARTICIPANT	\N	PRESENT	0
251289	251235	14187A	PARTICIPANT	\N	PRESENT	0
251290	251235	14034U	PARTICIPANT	\N	PRESENT	0
251291	251235	11048N	PARTICIPANT	\N	PRESENT	0
251292	251235	14021P	PARTICIPANT	\N	PRESENT	0
251293	251235	14159V	PARTICIPANT	\N	PRESENT	0
251294	251235	01043Q	PARTICIPANT	\N	PRESENT	0
251295	251235	14251Q	PARTICIPANT	\N	PRESENT	0
251296	251235	11085T	PARTICIPANT	\N	PRESENT	0
251297	251235	08009T	PARTICIPANT	\N	PRESENT	0
241061	239672	11072N	PARTICIPANT	\N	PRESENT	0
241062	239672	19709B	PARTICIPANT	\N	PRESENT	0
251300	251235	04092N	PARTICIPANT	\N	PRESENT	0
251301	251235	08011M	PARTICIPANT	\N	PRESENT	0
251302	251235	04070G	PARTICIPANT	\N	PRESENT	0
251303	251235	08061X	PARTICIPANT	\N	PRESENT	0
251304	251235	11012A	PARTICIPANT	\N	PRESENT	0
251755	251753	11063M	PARTICIPANT	\N	PRESENT	0
251609	250562	07029T	PARTICIPANT	\N	EXCUSE	0
251610	250562	14331P	PARTICIPANT	\N	EXCUSE	0
251611	250562	08010L	PARTICIPANT	\N	EXCUSE	0
251612	250562	19667J	PARTICIPANT	\N	EXCUSE	0
251756	251753	11033F	PARTICIPANT	\N	PRESENT	0
251757	251753	04085P	PARTICIPANT	\N	PRESENT	0
251758	251753	11031D	PARTICIPANT	\N	PRESENT	0
251759	251753	12041X	PARTICIPANT	\N	PRESENT	0
251760	251753	14235Q	PARTICIPANT	\N	PRESENT	0
251761	251753	19565D	PARTICIPANT	\N	PRESENT	0
251762	251753	19347U	PARTICIPANT	\N	PRESENT	0
251763	251753	19695N	PARTICIPANT	\N	PRESENT	0
251764	251753	19593H	PARTICIPANT	\N	PRESENT	0
251765	251753	19687N	PARTICIPANT	\N	PRESENT	0
251766	251753	14085U	PARTICIPANT	\N	PRESENT	0
251767	251753	19727D	PARTICIPANT	\N	PRESENT	0
251768	251753	19647E	PARTICIPANT	\N	PRESENT	0
251769	251753	19349W	PARTICIPANT	\N	PRESENT	0
251770	251753	11099A	PARTICIPANT	\N	PRESENT	0
251771	251753	11064N	PARTICIPANT	\N	PRESENT	0
251772	251753	17589D	PARTICIPANT	\N	PRESENT	0
251773	251753	14195A	PARTICIPANT	\N	PRESENT	0
251774	251753	11012A	PARTICIPANT	\N	PRESENT	0
251775	251753	14034U	PARTICIPANT	\N	PRESENT	0
251776	251753	19719D	PARTICIPANT	\N	PRESENT	0
251777	251753	19737F	PARTICIPANT	\N	PRESENT	0
251778	251753	19479G	PARTICIPANT	\N	PRESENT	0
251779	251753	19713W	PARTICIPANT	\N	PRESENT	0
251780	251753	01024M	PARTICIPANT	\N	PRESENT	0
251781	251753	07004J	PARTICIPANT	\N	PRESENT	0
251782	251753	19701S	PARTICIPANT	\N	PRESENT	0
251783	251753	19533U	PARTICIPANT	\N	PRESENT	0
251784	251753	14147R	PARTICIPANT	\N	PRESENT	0
251785	251753	14105F	PARTICIPANT	\N	PRESENT	0
251786	251753	19575F	PARTICIPANT	\N	PRESENT	0
251787	251753	19711U	PARTICIPANT	\N	PRESENT	0
251788	251753	19447X	PARTICIPANT	\N	PRESENT	0
251789	251753	19387D	PARTICIPANT	\N	PRESENT	0
251790	251753	14191V	PARTICIPANT	\N	PRESENT	0
251791	251753	19723Y	PARTICIPANT	\N	PRESENT	0
251792	251753	18083K	PARTICIPANT	\N	PRESENT	0
251080	251079	19631V	PARTICIPANT	\N	PRESENT	0
251081	251079	14085U	PARTICIPANT	\N	PRESENT	0
251082	251079	19629C	PARTICIPANT	\N	PRESENT	0
251083	251079	08028W	PARTICIPANT	\N	PRESENT	0
251084	251079	14197C	PARTICIPANT	\N	PRESENT	0
251085	251079	14211G	PARTICIPANT	\N	PRESENT	0
251087	251079	14221J	PARTICIPANT	\N	PRESENT	0
251088	251079	14257W	PARTICIPANT	\N	PRESENT	0
251863	251862	14079W	PARTICIPANT	\N	PRESENT	0
251864	251862	97011G	PARTICIPANT	\N	PRESENT	0
251865	251862	08034U	PARTICIPANT	\N	PRESENT	0
251866	251862	95067Q	PARTICIPANT	\N	PRESENT	0
251867	251862	14169X	PARTICIPANT	\N	PRESENT	0
252188	252180	08055A	PARTICIPANT	\N	PRESENT	0
252196	252180	04047H	PARTICIPANT	\N	PRESENT	0
252205	252180	11080N	PARTICIPANT	\N	PRESENT	0
252209	252180	11083R	PARTICIPANT	\N	PRESENT	0
252213	252180	19611R	PARTICIPANT	\N	PRESENT	0
252217	252180	19687N	PARTICIPANT	\N	PRESENT	0
252221	252180	14157T	PARTICIPANT	\N	PRESENT	0
252448	252447	01025N	PARTICIPANT	\N	PRESENT	0
252449	252447	19515S	PARTICIPANT	\N	PRESENT	0
251110	251102	08009T	PRESIDENT	0	PRESENT	0
251111	251102	14237S	PARTICIPANT	\N	EXCUSE	0
251112	251102	80027E	PARTICIPANT	\N	EXCUSE	0
251113	251102	17583W	PARTICIPANT	\N	EXCUSE	0
251114	251102	19599P	PARTICIPANT	\N	EXCUSE	0
252450	252447	14187A	PARTICIPANT	\N	PRESENT	0
252451	252447	19269X	PARTICIPANT	\N	PRESENT	0
251117	251100	19719D	PARTICIPANT	\N	PRESENT	0
252453	252452	19515S	PARTICIPANT	\N	PRESENT	0
252454	252452	04089T	PARTICIPANT	\N	PRESENT	0
251123	251122	98035U	PARTICIPANT	\N	PRESENT	0
251124	251122	10015M	PARTICIPANT	\N	PRESENT	0
251125	251122	19593H	PARTICIPANT	\N	PRESENT	0
251126	251122	14133K	PARTICIPANT	\N	PRESENT	0
251127	251122	14097Y	PARTICIPANT	\N	PRESENT	0
251128	251122	96004D	PARTICIPANT	\N	PRESENT	0
251129	251122	04097T	PARTICIPANT	\N	PRESENT	0
251130	251122	11026G	PARTICIPANT	\N	PRESENT	0
251131	251122	98018T	PARTICIPANT	\N	PRESENT	0
251132	251122	98022P	PARTICIPANT	\N	PRESENT	0
251133	251122	04042C	PARTICIPANT	\N	PRESENT	0
251134	251122	98029W	PARTICIPANT	\N	PRESENT	0
252455	252452	14187A	PARTICIPANT	\N	PRESENT	0
252456	252452	01043Q	PARTICIPANT	\N	PRESENT	0
252457	252452	19441R	PARTICIPANT	\N	PRESENT	0
252460	252459	19515S	PARTICIPANT	\N	PRESENT	0
252461	252459	19747H	PARTICIPANT	\N	PRESENT	0
252463	252459	04089T	PARTICIPANT	\N	PRESENT	0
252471	252469	19747H	PARTICIPANT	\N	PRESENT	0
252472	252469	04089T	PARTICIPANT	\N	PRESENT	0
252473	252469	14187A	PARTICIPANT	\N	PRESENT	0
251146	250072	98018T	PARTICIPANT	\N	PRESENT	0
251147	250072	11041F	PARTICIPANT	\N	PRESENT	0
251148	250072	04034C	PARTICIPANT	\N	PRESENT	0
251149	250072	97011G	PARTICIPANT	\N	PRESENT	0
252474	252469	19515S	PARTICIPANT	\N	PRESENT	0
252476	252475	14030Q	PRESIDENT	0	PRESENT	0
252477	252475	19701S	PARTICIPANT	\N	PRESENT	0
251166	250072	14097Y	PARTICIPANT	\N	PRESENT	0
251167	250072	14133K	PARTICIPANT	\N	PRESENT	0
251168	250072	14235Q	PARTICIPANT	\N	PRESENT	0
251169	250072	14079W	PARTICIPANT	\N	PRESENT	0
251170	250072	04042C	PRESIDENT	0	PRESENT	0
251171	250072	11054L	PARTICIPANT	\N	PRESENT	0
251172	250072	95037J	PARTICIPANT	\N	PRESENT	0
251173	250072	14105F	PARTICIPANT	\N	PRESENT	0
251174	250072	14055N	PARTICIPANT	\N	PRESENT	0
251175	250072	19709B	PARTICIPANT	\N	PRESENT	0
251176	250072	14267Y	PARTICIPANT	\N	PRESENT	0
251177	250072	11064N	PARTICIPANT	\N	PRESENT	0
251178	250072	14255U	PARTICIPANT	\N	PRESENT	0
252478	252475	11031D	PARTICIPANT	\N	PRESENT	0
251180	250072	04035D	PARTICIPANT	\N	PRESENT	0
252479	252475	19679N	PARTICIPANT	\N	PRESENT	0
252480	252475	11045K	PARTICIPANT	\N	PRESENT	0
251183	250072	19251M	PARTICIPANT	\N	PRESENT	0
251184	250072	11066Q	PARTICIPANT	\N	PRESENT	0
251185	250072	98050T	PARTICIPANT	\N	PRESENT	0
251186	250072	19421M	PARTICIPANT	\N	PRESENT	0
251187	250072	08061X	PARTICIPANT	\N	PRESENT	0
252481	252475	19621T	PARTICIPANT	\N	PRESENT	0
252482	252475	19715Y	PARTICIPANT	\N	PRESENT	0
251598	251102	19713W	PARTICIPANT	\N	PRESENT	0
251599	251102	08055A	PARTICIPANT	\N	PRESENT	0
251600	251102	14191V	PARTICIPANT	\N	PRESENT	0
251601	251102	14169X	PARTICIPANT	\N	PRESENT	0
251602	251102	15447F	PARTICIPANT	\N	PRESENT	0
251603	251102	14093U	PARTICIPANT	\N	PRESENT	0
251604	251102	19733B	PARTICIPANT	\N	PRESENT	0
251605	251102	19739H	PARTICIPANT	\N	PRESENT	0
251606	251102	19745F	PARTICIPANT	\N	PRESENT	0
252483	252475	14249W	PARTICIPANT	\N	PRESENT	0
252484	252475	19731Y	PARTICIPANT	\N	PRESENT	0
252485	252475	08031R	PARTICIPANT	\N	PRESENT	0
252486	252475	08024S	PARTICIPANT	\N	PRESENT	0
252487	252475	19697Q	PARTICIPANT	\N	PRESENT	0
252488	252475	18083K	PARTICIPANT	\N	PRESENT	0
252489	252475	14179A	PARTICIPANT	\N	PRESENT	0
252490	252475	19269X	PARTICIPANT	\N	PRESENT	0
252491	252475	01043Q	PARTICIPANT	\N	PRESENT	0
252492	252475	19749K	PARTICIPANT	\N	PRESENT	0
252493	252475	08020N	PARTICIPANT	\N	PRESENT	0
252494	252475	14235Q	PARTICIPANT	\N	PRESENT	0
252495	252475	14109K	PARTICIPANT	\N	PRESENT	0
252496	252475	19673G	PARTICIPANT	\N	PRESENT	0
252497	252475	19599P	PARTICIPANT	\N	PRESENT	0
252498	252475	19643A	PARTICIPANT	\N	PRESENT	0
252499	252475	19693L	PARTICIPANT	\N	PRESENT	0
252500	252475	14217N	PARTICIPANT	\N	PRESENT	0
251754	251753	11070L	PARTICIPANT	\N	PRESENT	0
252501	252475	08017T	PARTICIPANT	\N	PRESENT	0
252502	252475	08043V	PARTICIPANT	\N	PRESENT	0
252503	252475	14115H	PARTICIPANT	\N	PRESENT	0
252504	252475	19367Y	PARTICIPANT	\N	PRESENT	0
252505	252475	07029T	PARTICIPANT	\N	PRESENT	0
252506	252475	19563B	PARTICIPANT	\N	PRESENT	0
252511	252508	14133K	PARTICIPANT	\N	PRESENT	0
252512	252508	19467C	PARTICIPANT	\N	PRESENT	0
252513	252508	18083K	PARTICIPANT	\N	PRESENT	0
252514	252508	19507S	PARTICIPANT	\N	PRESENT	0
252515	252508	14281W	PARTICIPANT	\N	PRESENT	0
252516	252508	19727D	PARTICIPANT	\N	PRESENT	0
244095	241232	08073C	PARTICIPANT	\N	EXCUSE	0
244096	241232	19295A	PARTICIPANT	\N	EXCUSE	0
244097	241232	11010L	PARTICIPANT	\N	EXCUSE	0
244098	241232	14157T	PARTICIPANT	\N	EXCUSE	0
244099	241232	19577H	PARTICIPANT	\N	EXCUSE	0
244100	241232	08016S	PARTICIPANT	\N	EXCUSE	0
244101	243898	19319Q	PARTICIPANT	\N	PRESENT	0
246362	241368	14195A	PARTICIPANT	\N	PRESENT	0
244103	243898	11010L	PARTICIPANT	\N	EXCUSE	0
244104	243898	19295A	PARTICIPANT	\N	EXCUSE	0
244105	243898	08016S	PARTICIPANT	\N	EXCUSE	0
244106	243898	11054L	PARTICIPANT	\N	EXCUSE	0
244126	243898	19583F	PARTICIPANT	\N	EXCUSE	0
244127	243898	04043D	PARTICIPANT	\N	PRESENT	0
244128	243898	19657G	PARTICIPANT	\N	EXCUSE	0
244129	243898	14033T	PARTICIPANT	\N	EXCUSE	0
244134	243898	14277B	PARTICIPANT	\N	EXCUSE	0
244135	243898	14219Q	PARTICIPANT	\N	EXCUSE	0
244136	243898	19703U	PARTICIPANT	\N	EXCUSE	0
246361	241368	14069U	PARTICIPANT	\N	PRESENT	0
246363	241368	19253P	PARTICIPANT	\N	PRESENT	0
246364	241368	04086Q	PARTICIPANT	\N	PRESENT	0
246365	241368	14259Y	PARTICIPANT	\N	PRESENT	0
246366	241368	08038Y	PARTICIPANT	\N	PRESENT	0
246367	241368	14281W	PARTICIPANT	\N	PRESENT	0
246368	241368	14231L	PARTICIPANT	\N	PRESENT	0
246369	241368	11049P	PARTICIPANT	\N	PRESENT	0
246370	241368	01057W	PARTICIPANT	\N	PRESENT	0
246371	241368	11048N	PARTICIPANT	\N	PRESENT	0
246372	241368	19489J	PARTICIPANT	\N	PRESENT	0
246373	241368	08010L	PARTICIPANT	\N	PRESENT	0
246374	241368	14103D	PARTICIPANT	\N	PRESENT	0
246375	241368	14063N	PARTICIPANT	\N	PRESENT	0
246376	241368	14257W	PARTICIPANT	\N	PRESENT	0
246377	241368	14028W	PARTICIPANT	\N	PRESENT	0
246378	241368	05012A	PARTICIPANT	\N	PRESENT	0
246379	241368	19735D	PARTICIPANT	\N	PRESENT	0
246380	241368	95063L	PARTICIPANT	\N	PRESENT	0
246381	241368	19687N	PARTICIPANT	\N	PRESENT	0
246382	241368	04045F	PARTICIPANT	\N	PRESENT	0
246412	246411	14255U	PARTICIPANT	\N	PRESENT	0
246414	246413	14193X	PARTICIPANT	\N	PRESENT	0
246415	246413	14235Q	PARTICIPANT	\N	PRESENT	0
246416	246413	95067Q	PARTICIPANT	\N	PRESENT	0
246429	246193	19631V	PARTICIPANT	\N	PRESENT	0
246430	246193	19575F	PARTICIPANT	\N	PRESENT	0
246431	246193	08020N	PARTICIPANT	\N	PRESENT	0
246432	246193	11027H	PARTICIPANT	\N	PRESENT	0
246433	246193	14357A	PARTICIPANT	\N	PRESENT	0
246434	246193	14079W	PARTICIPANT	\N	PRESENT	0
246435	246193	14041T	PARTICIPANT	\N	PRESENT	0
246436	246193	08018U	PARTICIPANT	\N	PRESENT	0
246437	246193	14059S	PARTICIPANT	\N	PRESENT	0
246438	246193	14147R	PARTICIPANT	\N	PRESENT	0
246439	246193	19421M	PARTICIPANT	\N	PRESENT	0
246440	246193	07034Q	PARTICIPANT	\N	PRESENT	0
250009	240301	08031R	PARTICIPANT	\N	PRESENT	0
250010	240301	19649G	PARTICIPANT	\N	PRESENT	0
250013	240301	19295A	PARTICIPANT	\N	PRESENT	0
250017	240301	14237S	PARTICIPANT	\N	PRESENT	0
250018	240301	19667J	PARTICIPANT	\N	PRESENT	0
250019	240301	04043D	PARTICIPANT	\N	PRESENT	0
250021	240301	80013X	PARTICIPANT	\N	PRESENT	0
250022	240301	11072N	PARTICIPANT	\N	PRESENT	0
250023	240301	19737F	PARTICIPANT	\N	PRESENT	0
250024	240301	07029T	PARTICIPANT	\N	PRESENT	0
250025	240301	19629C	PARTICIPANT	\N	PRESENT	0
250026	240301	19717B	PARTICIPANT	\N	PRESENT	0
250027	240301	11031D	PARTICIPANT	\N	PRESENT	0
250028	240301	17637T	PARTICIPANT	\N	PRESENT	0
250029	240301	05008E	PARTICIPANT	\N	PRESENT	0
250030	240301	14261S	PARTICIPANT	\N	PRESENT	0
250031	240301	19585H	PARTICIPANT	\N	PRESENT	0
250032	240301	04085P	PARTICIPANT	\N	PRESENT	0
250033	240301	19253P	PARTICIPANT	\N	PRESENT	0
250034	240301	19399H	PARTICIPANT	\N	PRESENT	0
250035	240301	19289C	PARTICIPANT	\N	PRESENT	0
250038	240301	11045K	PARTICIPANT	\N	PRESENT	0
250039	240301	14065Q	PARTICIPANT	\N	PRESENT	0
250040	240301	14179A	PARTICIPANT	\N	PRESENT	0
250041	240301	19711U	PARTICIPANT	\N	PRESENT	0
250042	240301	11109J	PARTICIPANT	\N	PRESENT	0
250043	240301	19593H	PARTICIPANT	\N	PRESENT	0
250044	240301	01028R	PARTICIPANT	\N	PRESENT	0
250046	240301	14109K	PARTICIPANT	\N	PRESENT	0
251383	250072	14028W	PARTICIPANT	\N	EXCUSE	0
250988	232877	19737F	PARTICIPANT	\N	EXCUSE	0
250994	250067	08024S	PARTICIPANT	\N	PRESENT	0
250996	250067	19551W	PARTICIPANT	\N	PRESENT	0
250998	250067	19349W	PARTICIPANT	\N	PRESENT	0
250999	250067	19737F	PARTICIPANT	\N	PRESENT	0
250007	240301	04059M	PARTICIPANT	\N	PRESENT	0
250008	240301	19581D	PARTICIPANT	\N	PRESENT	0
251379	250072	98053W	PARTICIPANT	\N	EXCUSE	0
251381	250072	08056B	PARTICIPANT	\N	EXCUSE	0
251532	250137	11097X	PARTICIPANT	\N	PRESENT	0
251533	250137	11067R	PARTICIPANT	\N	PRESENT	0
251538	251537	19553Y	PARTICIPANT	\N	PRESENT	0
251539	251537	10006L	PARTICIPANT	\N	PRESENT	0
251540	251537	08052W	PARTICIPANT	\N	PRESENT	0
251542	251541	08052W	PARTICIPANT	\N	PRESENT	0
251543	251541	10006L	PARTICIPANT	\N	PRESENT	0
251544	251541	19553Y	PARTICIPANT	\N	PRESENT	0
251561	251541	14239U	PARTICIPANT	\N	PRESENT	0
251562	251541	19667J	PARTICIPANT	\N	PRESENT	0
251563	251541	19565D	PARTICIPANT	\N	PRESENT	0
251564	251541	19723Y	PARTICIPANT	\N	PRESENT	0
251565	251541	14331P	PARTICIPANT	\N	PRESENT	0
251794	251793	08039A	PARTICIPANT	\N	PRESENT	0
251795	251793	14229S	PARTICIPANT	\N	PRESENT	0
251796	251793	11083R	PARTICIPANT	\N	PRESENT	0
251797	251793	04057K	PARTICIPANT	\N	PRESENT	0
251798	251793	08031R	PARTICIPANT	\N	PRESENT	0
261005	258758	19715Y	PARTICIPANT	\N	PRESENT	0
261006	258758	14059S	PARTICIPANT	\N	PRESENT	0
253074	253071	08053X	PARTICIPANT	\N	PRESENT	0
253075	253071	95067Q	PARTICIPANT	\N	PRESENT	0
256013	256012	95063L	PARTICIPANT	\N	PRESENT	0
261007	258758	19703U	PARTICIPANT	\N	EXCUSE	0
261008	258758	08073C	PARTICIPANT	\N	PRESENT	0
261009	258758	11054L	PARTICIPANT	\N	EXCUSE	0
261440	258758	08019V	PARTICIPANT	\N	PRESENT	0
262894	250210	14225N	PARTICIPANT	\N	EXCUSE	0
262896	262895	19701S	PARTICIPANT	\N	PRESENT	0
262897	262895	19667J	PARTICIPANT	\N	PRESENT	0
262904	262903	11048N	PRESIDENT	0	PRESENT	0
262905	262903	14026U	PARTICIPANT	\N	PRESENT	0
262906	262903	14103D	PARTICIPANT	\N	PRESENT	0
262907	262903	11067R	PARTICIPANT	\N	PRESENT	0
262908	262903	19503N	PARTICIPANT	\N	PRESENT	0
262909	262903	19651A	PARTICIPANT	\N	PRESENT	0
262910	262903	19719D	PARTICIPANT	\N	PRESENT	0
262911	258934	14299H	PARTICIPANT	\N	PRESENT	0
262912	258934	14093U	PARTICIPANT	\N	PRESENT	0
262949	262948	14133K	PARTICIPANT	\N	PRESENT	0
262950	262948	14065Q	PARTICIPANT	\N	PRESENT	0
262951	262948	96004D	PRESIDENT	0	PRESENT	0
262952	262948	14089Y	PARTICIPANT	\N	PRESENT	0
262953	262948	08014Q	PARTICIPANT	\N	PRESENT	0
262954	262948	14079W	PARTICIPANT	\N	PRESENT	0
262955	262948	08018U	PARTICIPANT	\N	EXCUSE	0
262956	262948	04035D	PARTICIPANT	\N	PRESENT	0
262957	262948	11083R	PARTICIPANT	\N	PRESENT	0
262958	262948	19725B	PARTICIPANT	\N	PRESENT	0
262959	262948	95037J	PARTICIPANT	\N	PRESENT	0
262960	262948	19569H	PARTICIPANT	\N	PRESENT	0
262961	262948	04097T	PARTICIPANT	\N	PRESENT	0
262962	262948	14001X	PARTICIPANT	\N	EXCUSE	0
262963	262948	04057K	PARTICIPANT	\N	PRESENT	0
262964	262948	98035U	PARTICIPANT	\N	PRESENT	0
262965	262948	14331P	PARTICIPANT	\N	PRESENT	0
263100	262993	14281W	PARTICIPANT	\N	EXCUSE	0
263119	260596	04092N	PRESIDENT	0	PRESENT	0
266784	263146	11043H	PARTICIPANT	\N	PRESENT	0
266785	263146	08034U	PARTICIPANT	\N	PRESENT	0
266791	263146	19583F	PARTICIPANT	\N	PRESENT	0
266792	263146	01048V	PARTICIPANT	\N	PRESENT	0
266793	263146	80013X	PARTICIPANT	\N	PRESENT	0
266794	263146	14121F	PARTICIPANT	\N	PRESENT	0
266798	262916	14219Q	PARTICIPANT	\N	PRESENT	0
266799	263146	14173T	PARTICIPANT	\N	PRESENT	0
266805	263146	14267Y	PARTICIPANT	\N	PRESENT	0
266782	263146	11026G	PARTICIPANT	\N	PRESENT	0
266783	263146	04085P	PARTICIPANT	\N	PRESENT	0
258774	258773	14193X	PARTICIPANT	\N	PRESENT	0
258775	258773	08053X	PARTICIPANT	\N	PRESENT	0
258776	258773	14235Q	PARTICIPANT	\N	PRESENT	0
258777	258773	95067Q	PARTICIPANT	\N	PRESENT	0
258779	258778	14193X	PARTICIPANT	\N	PRESENT	0
258780	258778	95067Q	PARTICIPANT	\N	PRESENT	0
258782	258781	14193X	PARTICIPANT	\N	PRESENT	0
258783	258781	95067Q	PARTICIPANT	\N	PRESENT	0
258785	258784	14193X	PARTICIPANT	\N	PRESENT	0
258786	258784	14235Q	PARTICIPANT	\N	PRESENT	0
258787	258784	95067Q	PARTICIPANT	\N	PRESENT	0
258789	258788	14193X	PARTICIPANT	\N	PRESENT	0
258790	258788	95067Q	PARTICIPANT	\N	PRESENT	0
258942	258748	19583F	PARTICIPANT	\N	EXCUSE	0
258946	258945	01028R	PARTICIPANT	\N	PRESENT	0
258995	253068	14221J	PARTICIPANT	\N	PRESENT	0
258997	253069	14221J	PARTICIPANT	\N	PRESENT	0
258999	253070	14221J	PARTICIPANT	\N	PRESENT	0
259065	258752	19657G	PARTICIPANT	\N	EXCUSE	0
259066	258752	98005N	PARTICIPANT	\N	EXCUSE	0
259067	258752	11010L	PARTICIPANT	\N	EXCUSE	0
260613	260612	14071N	PARTICIPANT	\N	PRESENT	0
260617	260615	14071N	PARTICIPANT	\N	PRESENT	0
260622	260621	14071N	PARTICIPANT	\N	PRESENT	0
260933	258674	05012A	PARTICIPANT	\N	PRESENT	0
260934	258674	08068F	PARTICIPANT	\N	PRESENT	0
260935	258674	19489J	PARTICIPANT	\N	PRESENT	0
260936	258674	11099A	PARTICIPANT	\N	PRESENT	0
260937	258674	14051J	PARTICIPANT	\N	PRESENT	0
261112	258875	04040A	PARTICIPANT	\N	PRESENT	0
261113	258875	14069U	PARTICIPANT	\N	PRESENT	0
261114	258875	19565D	PARTICIPANT	\N	PRESENT	0
261115	258875	08010L	PARTICIPANT	\N	PRESENT	0
261116	258875	19489J	PARTICIPANT	\N	PRESENT	0
261117	258875	14028W	PARTICIPANT	\N	PRESENT	0
261118	258875	14231L	PARTICIPANT	\N	PRESENT	0
261119	258875	01057W	PARTICIPANT	\N	PRESENT	0
261120	258875	95063L	PARTICIPANT	\N	PRESENT	0
261234	250210	14135M	PARTICIPANT	\N	EXCUSE	0
261302	261301	04070G	PARTICIPANT	\N	PRESENT	0
261303	261301	08039A	PARTICIPANT	\N	PRESENT	0
261304	261301	11083R	PARTICIPANT	\N	PRESENT	0
261305	261301	19749K	PARTICIPANT	\N	PRESENT	0
261306	261301	11109J	PARTICIPANT	\N	PRESENT	0
261307	261301	08031R	PARTICIPANT	\N	PRESENT	0
261308	261301	19399H	PARTICIPANT	\N	PRESENT	0
261309	261301	08043V	PARTICIPANT	\N	PRESENT	0
261312	261311	14229S	PARTICIPANT	\N	PRESENT	0
261313	261311	19611R	PARTICIPANT	\N	PRESENT	0
261315	261314	01028R	PARTICIPANT	\N	PRESENT	0
261317	261316	01028R	PARTICIPANT	\N	PRESENT	0
261393	261392	01057W	PARTICIPANT	\N	PRESENT	0
261395	261394	04043D	PARTICIPANT	\N	PRESENT	0
261409	261408	98029W	PARTICIPANT	\N	PRESENT	0
261414	261413	11083R	PARTICIPANT	\N	PRESENT	0
261435	261434	11070L	PARTICIPANT	\N	PRESENT	0
261436	261434	19647E	PARTICIPANT	\N	PRESENT	0
261438	261437	14085U	PARTICIPANT	\N	PRESENT	0
261439	261437	14253S	PARTICIPANT	\N	PRESENT	0
261488	261177	88008L	PARTICIPANT	\N	PRESENT	0
261495	258758	14199E	PARTICIPANT	\N	PRESENT	0
262552	262350	14021P	PARTICIPANT	\N	EXCUSE	0
262555	258758	14135M	PARTICIPANT	\N	EXCUSE	0
262748	262747	19621T	PARTICIPANT	\N	PRESENT	0
262749	262747	08031R	PARTICIPANT	\N	PRESENT	0
262752	262750	19621T	PARTICIPANT	\N	PRESENT	0
262753	262750	08031R	PARTICIPANT	\N	PRESENT	0
262762	262761	19621T	PARTICIPANT	\N	PRESENT	0
262763	262761	08031R	PARTICIPANT	\N	PRESENT	0
262766	262765	19621T	PARTICIPANT	\N	PRESENT	0
262767	262765	08031R	PARTICIPANT	\N	PRESENT	0
262772	261092	14255U	PARTICIPANT	\N	EXCUSE	0
262773	261092	04035D	PARTICIPANT	\N	EXCUSE	0
262774	261092	14028W	PARTICIPANT	\N	EXCUSE	0
262775	261092	19443T	PARTICIPANT	\N	EXCUSE	0
262776	261092	95067Q	PARTICIPANT	\N	EXCUSE	0
262781	262770	11053K	PARTICIPANT	\N	PRESENT	0
262783	262778	11053K	PARTICIPANT	\N	PRESENT	0
262792	258758	95062K	PARTICIPANT	\N	EXCUSE	0
262807	262806	01034P	PARTICIPANT	\N	PRESENT	0
262810	262809	01034P	PARTICIPANT	\N	PRESENT	0
262813	262812	11097X	PARTICIPANT	\N	PRESENT	0
262917	250210	11109J	PARTICIPANT	\N	PRESENT	0
262918	250210	14261S	PARTICIPANT	\N	PRESENT	0
262919	250210	14259Y	PARTICIPANT	\N	PRESENT	0
262920	250210	19691J	PARTICIPANT	\N	PRESENT	0
262921	250210	19715Y	PARTICIPANT	\N	PRESENT	0
262922	250210	19729F	PARTICIPANT	\N	PRESENT	0
262923	250210	14059S	PARTICIPANT	\N	PRESENT	0
262924	250210	08019V	PRESIDENT	0	PRESENT	0
262925	250210	19319Q	PARTICIPANT	\N	PRESENT	0
262926	250210	19703U	PARTICIPANT	\N	PRESENT	0
262927	250210	19301E	PARTICIPANT	\N	PRESENT	0
262928	261003	04040A	PRESIDENT	0	PRESENT	0
262929	261003	14069U	PARTICIPANT	\N	PRESENT	0
262930	261003	19525U	PARTICIPANT	\N	PRESENT	0
262931	261003	14327T	PARTICIPANT	\N	PRESENT	0
262932	261003	19565D	PARTICIPANT	\N	PRESENT	0
262933	261003	01057W	PARTICIPANT	\N	PRESENT	0
262934	261003	08034U	PARTICIPANT	\N	PRESENT	0
262935	261003	14103D	PARTICIPANT	\N	PRESENT	0
262936	261003	14257W	PARTICIPANT	\N	PRESENT	0
262937	261003	95063L	PARTICIPANT	\N	PRESENT	0
262938	261003	19687N	PARTICIPANT	\N	PRESENT	0
262939	261003	95067Q	PARTICIPANT	\N	PRESENT	0
262940	261003	11049P	PARTICIPANT	\N	PRESENT	0
262941	261003	08010L	PARTICIPANT	\N	PRESENT	0
262942	261003	14071N	PARTICIPANT	\N	PRESENT	0
262944	261003	04045F	PARTICIPANT	\N	PRESENT	0
262946	261003	05012A	PARTICIPANT	\N	PRESENT	0
263120	260596	14119M	PARTICIPANT	\N	PRESENT	0
263121	260596	14071N	PARTICIPANT	\N	PRESENT	0
263122	260596	11097X	PARTICIPANT	\N	PRESENT	0
263123	260596	04045F	PARTICIPANT	\N	PRESENT	0
263124	260596	19703U	PARTICIPANT	\N	PRESENT	0
263125	260596	19527W	PARTICIPANT	\N	PRESENT	0
263126	260596	01034P	PARTICIPANT	\N	PRESENT	0
263127	260596	08048B	PARTICIPANT	\N	EXCUSE	0
263128	260596	17779H	PARTICIPANT	\N	EXCUSE	0
263129	260596	19575F	PARTICIPANT	\N	EXCUSE	0
263130	260596	14281W	PARTICIPANT	\N	EXCUSE	0
263131	260596	14026U	PARTICIPANT	\N	EXCUSE	0
263132	260596	14239U	PARTICIPANT	\N	EXCUSE	0
263134	260596	19631V	PARTICIPANT	\N	PRESENT	0
263135	260596	19515S	PARTICIPANT	\N	PRESENT	0
263136	260596	14115H	PARTICIPANT	\N	PRESENT	0
263137	260596	19747H	PARTICIPANT	\N	PRESENT	0
263138	260596	08068F	PARTICIPANT	\N	PRESENT	0
263139	260596	14207L	PARTICIPANT	\N	PRESENT	0
263140	260596	19295A	PARTICIPANT	\N	PRESENT	0
263141	260596	80013X	PARTICIPANT	\N	PRESENT	0
263142	260596	11056N	PARTICIPANT	\N	PRESENT	0
263143	260596	08038Y	PARTICIPANT	\N	PRESENT	0
263144	260596	19507S	PARTICIPANT	\N	PRESENT	0
263145	260596	19695N	PARTICIPANT	\N	PRESENT	0
263147	260596	19565D	PARTICIPANT	\N	PRESENT	0
263148	260596	14033T	PARTICIPANT	\N	PRESENT	0
263149	260596	14081Q	PARTICIPANT	\N	PRESENT	0
263150	260596	19511N	PARTICIPANT	\N	PRESENT	0
263151	260596	08015R	PARTICIPANT	\N	PRESENT	0
263152	260596	14205J	PARTICIPANT	\N	PRESENT	0
263154	260596	08062Y	PARTICIPANT	\N	PRESENT	0
263155	260596	19369B	PARTICIPANT	\N	PRESENT	0
263156	260596	14257W	PARTICIPANT	\N	PRESENT	0
263157	260596	14265W	PARTICIPANT	\N	PRESENT	0
263158	260596	04088S	PARTICIPANT	\N	PRESENT	0
263159	260596	11090Q	PARTICIPANT	\N	PRESENT	0
263160	260596	14135M	PARTICIPANT	\N	PRESENT	0
263161	260596	19269X	PARTICIPANT	\N	PRESENT	0
263162	260596	19301E	PARTICIPANT	\N	PRESENT	0
263163	260596	19413M	PARTICIPANT	\N	PRESENT	0
263164	260596	18083K	PARTICIPANT	\N	PRESENT	0
241372	241371	19253P	PARTICIPANT	\N	PRESENT	0
246160	240289	14034U	PARTICIPANT	\N	PRESENT	0
246163	240289	14051J	PARTICIPANT	\N	PRESENT	0
246164	240289	14107H	PARTICIPANT	\N	PRESENT	0
246165	240289	19683J	PARTICIPANT	\N	PRESENT	0
246166	240289	19333N	PARTICIPANT	\N	PRESENT	0
246167	240289	19387D	PARTICIPANT	\N	PRESENT	0
246168	240289	04057K	PARTICIPANT	\N	PRESENT	0
246169	240289	11065P	PARTICIPANT	\N	PRESENT	0
246171	240289	04034C	PARTICIPANT	\N	PRESENT	0
246172	240289	19349W	PARTICIPANT	\N	PRESENT	0
246173	240289	08009T	PARTICIPANT	\N	PRESENT	0
246174	240289	18083K	PARTICIPANT	\N	PRESENT	0
246175	240289	19467C	PARTICIPANT	\N	PRESENT	0
246176	240289	19447X	PARTICIPANT	\N	PRESENT	0
246178	240289	19713W	PARTICIPANT	\N	PRESENT	0
246183	240289	14079W	PARTICIPANT	\N	PRESENT	0
246185	240289	19671E	PARTICIPANT	\N	PRESENT	0
246186	240289	19629C	PARTICIPANT	\N	PRESENT	0
246190	240289	04085P	PARTICIPANT	\N	PRESENT	0
246192	240289	14235Q	PARTICIPANT	\N	PRESENT	0
246194	240289	19583F	PARTICIPANT	\N	PRESENT	0
246195	240289	19413M	PARTICIPANT	\N	PRESENT	0
246196	240289	11040E	PARTICIPANT	\N	PRESENT	0
246197	240289	14029X	PARTICIPANT	\N	PRESENT	0
246198	240289	14119M	PARTICIPANT	\N	PRESENT	0
246199	240289	14223L	PARTICIPANT	\N	PRESENT	0
246200	240289	14105F	PARTICIPANT	\N	PRESENT	0
246201	240289	14267Y	PARTICIPANT	\N	PRESENT	0
246202	240289	14215L	PARTICIPANT	\N	PRESENT	0
246203	240289	97011G	PARTICIPANT	\N	PRESENT	0
246204	240289	19415P	PARTICIPANT	\N	PRESENT	0
246205	240289	98050T	PARTICIPANT	\N	PRESENT	0
246206	240289	11012A	PARTICIPANT	\N	PRESENT	0
246207	240289	11067R	PARTICIPANT	\N	PRESENT	0
246208	240289	19507S	PARTICIPANT	\N	PRESENT	0
246212	244314	08068F	PARTICIPANT	\N	PRESENT	0
246213	244314	14079W	PARTICIPANT	\N	PRESENT	0
246214	244314	19349W	PARTICIPANT	\N	PRESENT	0
246215	244314	14028W	PARTICIPANT	\N	PRESENT	0
246216	244314	19695N	PARTICIPANT	\N	PRESENT	0
246217	244314	19631V	PARTICIPANT	\N	PRESENT	0
246218	244314	19637C	PARTICIPANT	\N	PRESENT	0
246219	240289	14195A	PARTICIPANT	\N	PRESENT	0
246227	244314	19737F	PARTICIPANT	\N	PRESENT	0
246228	244314	04061F	PARTICIPANT	\N	PRESENT	0
246229	244314	08028W	PRESIDENT	0	PRESENT	0
246231	240289	14089Y	PARTICIPANT	\N	PRESENT	0
246232	244314	95041E	PARTICIPANT	\N	EXCUSE	0
246233	244314	14065Q	PARTICIPANT	\N	EXCUSE	0
246234	244314	19585H	PARTICIPANT	\N	EXCUSE	0
246235	240289	14031R	PARTICIPANT	\N	PRESENT	0
246236	240289	80013X	PARTICIPANT	\N	PRESENT	0
246240	240289	02002K	PARTICIPANT	\N	PRESENT	0
246243	240289	98022P	PARTICIPANT	\N	PRESENT	0
246250	240289	19573D	PARTICIPANT	\N	PRESENT	0
246251	240289	95063L	PARTICIPANT	\N	PRESENT	0
246252	244314	19251M	PARTICIPANT	\N	PRESENT	0
246253	240289	89017R	PARTICIPANT	\N	PRESENT	0
246254	240289	14157T	PARTICIPANT	\N	PRESENT	0
246255	240289	95062K	PARTICIPANT	\N	PRESENT	0
246256	240289	01025N	PARTICIPANT	\N	PRESENT	0
246257	244314	14061L	PARTICIPANT	\N	PRESENT	0
246258	240289	14147R	PARTICIPANT	\N	PRESENT	0
246259	240289	14073Q	PARTICIPANT	\N	PRESENT	0
246260	240289	14111D	PARTICIPANT	\N	PRESENT	0
246261	240289	14033T	PARTICIPANT	\N	PRESENT	0
246262	240289	14327T	PARTICIPANT	\N	PRESENT	0
246263	240289	14265W	PARTICIPANT	\N	PRESENT	0
246264	240289	14249W	PARTICIPANT	\N	PRESENT	0
246265	240289	19479G	PARTICIPANT	\N	PRESENT	0
246266	240289	14219Q	PARTICIPANT	\N	PRESENT	0
246267	240289	19383Y	PARTICIPANT	\N	PRESENT	0
246295	244314	14257W	PARTICIPANT	\N	PRESENT	0
246298	244314	14073Q	PARTICIPANT	\N	PRESENT	0
249732	240299	19591F	PARTICIPANT	\N	PRESENT	0
249733	240299	08068F	PARTICIPANT	\N	PRESENT	0
246398	244315	19695N	PARTICIPANT	\N	PRESENT	0
246399	244315	14219Q	PARTICIPANT	\N	PRESENT	0
249719	249718	11048N	PRESIDENT	0	PRESENT	0
249720	249718	11067R	PARTICIPANT	\N	PRESENT	0
249721	249718	14103D	PARTICIPANT	\N	PRESENT	0
249722	249718	19711U	PARTICIPANT	\N	PRESENT	0
249723	249718	14031R	PARTICIPANT	\N	PRESENT	0
249724	249718	19689Q	PARTICIPANT	\N	PRESENT	0
249725	249718	19441R	PARTICIPANT	\N	PRESENT	0
249726	249718	01024M	PARTICIPANT	\N	PRESENT	0
249727	249718	14026U	PARTICIPANT	\N	PRESENT	0
249728	249718	04049K	PARTICIPANT	\N	PRESENT	0
249729	249718	19503N	PARTICIPANT	\N	PRESENT	0
249730	249718	14071N	PARTICIPANT	\N	PRESENT	0
249731	249718	14207L	PARTICIPANT	\N	PRESENT	0
249734	240299	19413M	PARTICIPANT	\N	PRESENT	0
249735	240299	14207L	PARTICIPANT	\N	PRESENT	0
249736	240299	19631V	PARTICIPANT	\N	PRESENT	0
249737	240299	08014Q	PARTICIPANT	\N	PRESENT	0
249738	240299	11083R	PARTICIPANT	\N	PRESENT	0
249739	240299	96004D	PARTICIPANT	\N	PRESENT	0
249740	240299	11090Q	PARTICIPANT	\N	PRESENT	0
249741	240299	14115H	PARTICIPANT	\N	PRESENT	0
249742	240299	04057K	PARTICIPANT	\N	PRESENT	0
249743	240299	19441R	PARTICIPANT	\N	PRESENT	0
249744	240299	19713W	PARTICIPANT	\N	PRESENT	0
249745	240299	19737F	PARTICIPANT	\N	PRESENT	0
249746	240299	14267Y	PARTICIPANT	\N	PRESENT	0
249747	240299	14031R	PARTICIPANT	\N	PRESENT	0
249748	240299	08019V	PARTICIPANT	\N	PRESENT	0
249749	240299	14033T	PARTICIPANT	\N	PRESENT	0
249750	240299	19399H	PARTICIPANT	\N	PRESENT	0
249751	240299	14257W	PARTICIPANT	\N	PRESENT	0
249752	240299	04035D	PARTICIPANT	\N	PRESENT	0
249753	240299	14079W	PARTICIPANT	\N	PRESENT	0
249754	240299	14237S	PARTICIPANT	\N	PRESENT	0
249755	240299	14261S	PARTICIPANT	\N	PRESENT	0
249756	240299	19695N	PARTICIPANT	\N	PRESENT	0
249757	240299	11099A	PARTICIPANT	\N	PRESENT	0
249758	240299	14195A	PARTICIPANT	\N	PRESENT	0
249759	240299	19709B	PARTICIPANT	\N	PRESENT	0
249760	240299	19563B	PARTICIPANT	\N	PRESENT	0
249761	240299	14205J	PARTICIPANT	\N	PRESENT	0
249762	240299	19387D	PARTICIPANT	\N	PRESENT	0
249763	240299	14265W	PARTICIPANT	\N	PRESENT	0
249764	240299	14357A	PARTICIPANT	\N	PRESENT	0
249765	240299	05012A	PARTICIPANT	\N	PRESENT	0
249766	240299	19747H	PARTICIPANT	\N	PRESENT	0
249767	240299	14219Q	PARTICIPANT	\N	PRESENT	0
249768	240299	14071N	PARTICIPANT	\N	PRESENT	0
249769	240299	14241N	PARTICIPANT	\N	PRESENT	0
249770	240299	07029T	PARTICIPANT	\N	PRESENT	0
251305	251235	04044E	PARTICIPANT	\N	PRESENT	0
251306	251235	01034P	PARTICIPANT	\N	PRESENT	0
251314	251313	89017R	PARTICIPANT	\N	PRESENT	0
251317	251313	04059M	PARTICIPANT	\N	PRESENT	0
251319	251313	05008E	PARTICIPANT	\N	PRESENT	0
251321	251313	96004D	PARTICIPANT	\N	PRESENT	0
251323	251313	11031D	PARTICIPANT	\N	PRESENT	0
251324	251313	04086Q	PARTICIPANT	\N	PRESENT	0
251325	251313	98018T	PARTICIPANT	\N	PRESENT	0
251326	251313	11074Q	PARTICIPANT	\N	PRESENT	0
251327	251313	14034U	PARTICIPANT	\N	PRESENT	0
251333	251313	14021P	PARTICIPANT	\N	PRESENT	0
251335	251313	14159V	PARTICIPANT	\N	PRESENT	0
251336	251313	01043Q	PARTICIPANT	\N	PRESENT	0
251337	251313	14251Q	PARTICIPANT	\N	PRESENT	0
251338	251313	11085T	PARTICIPANT	\N	PRESENT	0
251340	251313	08009T	PARTICIPANT	\N	PRESENT	0
251341	251313	04092N	PARTICIPANT	\N	PRESENT	0
251342	251313	11072N	PARTICIPANT	\N	PRESENT	0
251344	251313	08011M	PARTICIPANT	\N	PRESENT	0
251346	251313	04070G	PARTICIPANT	\N	PRESENT	0
251347	251313	08061X	PARTICIPANT	\N	PRESENT	0
251348	251313	11090Q	PARTICIPANT	\N	PRESENT	0
251349	251313	11012A	PARTICIPANT	\N	PRESENT	0
251350	251313	04033B	PARTICIPANT	\N	PRESENT	0
251362	251360	89017R	PARTICIPANT	\N	PRESENT	0
251363	251360	04085P	PARTICIPANT	\N	PRESENT	0
251365	251360	04059M	PARTICIPANT	\N	PRESENT	0
251366	251360	05008E	PARTICIPANT	\N	PRESENT	0
251368	251360	14030Q	PARTICIPANT	\N	PRESENT	0
251369	251360	04040A	PARTICIPANT	\N	PRESENT	0
251370	251360	04086Q	PARTICIPANT	\N	PRESENT	0
251371	251360	11070L	PARTICIPANT	\N	PRESENT	0
251372	251360	98018T	PARTICIPANT	\N	PRESENT	0
251373	251360	98024R	PARTICIPANT	\N	PRESENT	0
251374	251360	11074Q	PARTICIPANT	\N	PRESENT	0
251376	251360	08045X	PARTICIPANT	\N	PRESENT	0
251377	251360	14034U	PARTICIPANT	\N	PRESENT	0
251378	251360	99004R	PARTICIPANT	\N	PRESENT	0
251380	251360	04049K	PARTICIPANT	\N	PRESENT	0
252519	252508	19483C	PARTICIPANT	\N	PRESENT	0
252520	252508	14103D	PARTICIPANT	\N	PRESENT	0
252521	252508	14265W	PARTICIPANT	\N	PRESENT	0
252522	252508	19735D	PARTICIPANT	\N	PRESENT	0
254557	240316	19479G	PARTICIPANT	\N	PRESENT	0
252524	252508	19269X	PARTICIPANT	\N	PRESENT	0
254780	254779	04061F	PARTICIPANT	\N	PRESENT	0
252526	252508	14173T	PARTICIPANT	\N	PRESENT	0
252896	251120	08055A	PARTICIPANT	\N	PRESENT	0
252888	250308	80027E	PARTICIPANT	\N	EXCUSE	0
252895	251120	08009T	PRESIDENT	0	PRESENT	0
252897	251120	14093U	PARTICIPANT	\N	PRESENT	0
252898	251120	19549D	PARTICIPANT	\N	PRESENT	0
252899	251120	08060W	PARTICIPANT	\N	PRESENT	0
252900	251120	19733B	PARTICIPANT	\N	PRESENT	0
252901	251120	19383Y	PARTICIPANT	\N	PRESENT	0
252902	251120	08024S	PARTICIPANT	\N	PRESENT	0
252903	251120	14038Y	PARTICIPANT	\N	PRESENT	0
252904	251120	18083K	PARTICIPANT	\N	PRESENT	0
252905	251120	19701S	PARTICIPANT	\N	PRESENT	0
252906	251120	98023Q	PARTICIPANT	\N	PRESENT	0
252907	251120	19525U	PARTICIPANT	\N	PRESENT	0
252908	251120	11065P	PARTICIPANT	\N	PRESENT	0
252909	251120	02002K	PARTICIPANT	\N	PRESENT	0
252910	251120	15447F	PARTICIPANT	\N	PRESENT	0
252911	251120	19347U	PARTICIPANT	\N	PRESENT	0
252912	251120	19333N	PARTICIPANT	\N	PRESENT	0
252913	251120	04097T	PARTICIPANT	\N	PRESENT	0
252517	252508	19511N	PARTICIPANT	\N	PRESENT	0
254778	254777	04061F	PARTICIPANT	\N	PRESENT	0
252914	251120	19551W	PARTICIPANT	\N	PRESENT	0
252915	251120	14219Q	PARTICIPANT	\N	PRESENT	0
252916	251120	14103D	PARTICIPANT	\N	PRESENT	0
252917	251120	14031R	PARTICIPANT	\N	PRESENT	0
252918	251120	19637C	PARTICIPANT	\N	PRESENT	0
252919	251120	14221J	PARTICIPANT	\N	PRESENT	0
252920	251120	14169X	PARTICIPANT	\N	PRESENT	0
252921	251120	17637T	PARTICIPANT	\N	PRESENT	0
252922	251120	19745F	PARTICIPANT	\N	PRESENT	0
252923	251120	05012A	PARTICIPANT	\N	PRESENT	0
252924	251120	19503N	PARTICIPANT	\N	PRESENT	0
252925	251120	19739H	PARTICIPANT	\N	PRESENT	0
252926	251120	95062K	PARTICIPANT	\N	PRESENT	0
252927	251120	19713W	PARTICIPANT	\N	PRESENT	0
252928	251120	14051J	PARTICIPANT	\N	PRESENT	0
252929	251120	14157T	PARTICIPANT	\N	PRESENT	0
252930	251120	19737F	PARTICIPANT	\N	PRESENT	0
252931	251120	19599P	PARTICIPANT	\N	EXCUSE	0
252932	251120	80027E	PARTICIPANT	\N	EXCUSE	0
252933	251120	14237S	PARTICIPANT	\N	EXCUSE	0
252934	251120	17583W	PARTICIPANT	\N	EXCUSE	0
253386	240307	11063M	PARTICIPANT	0	PRESENT	0
253387	240307	19527W	PARTICIPANT	0	PRESENT	0
253388	240307	14225N	PARTICIPANT	0	PRESENT	0
253389	240307	04049K	PARTICIPANT	0	PRESENT	0
253390	240307	19575F	PARTICIPANT	0	PRESENT	0
253391	240307	11064N	PARTICIPANT	0	PRESENT	0
253392	240307	14197C	PARTICIPANT	0	PRESENT	0
253393	240307	01043Q	PARTICIPANT	0	PRESENT	0
253394	240307	01028R	PARTICIPANT	0	PRESENT	0
253395	240307	19507S	PARTICIPANT	0	PRESENT	0
253396	240307	12016W	PARTICIPANT	0	PRESENT	0
253397	240307	19333N	PARTICIPANT	0	PRESENT	0
253398	240307	19689Q	PARTICIPANT	0	PRESENT	0
253399	240307	11109J	PARTICIPANT	0	PRESENT	0
253400	240307	14259Y	PARTICIPANT	0	PRESENT	0
253401	240307	19383Y	PARTICIPANT	0	PRESENT	0
253402	240307	19693L	PARTICIPANT	0	PRESENT	0
253403	240307	19725B	PARTICIPANT	0	PRESENT	0
253404	240307	19369B	PARTICIPANT	0	PRESENT	0
253405	240307	08060W	PARTICIPANT	0	PRESENT	0
253406	240307	18083K	PARTICIPANT	0	PRESENT	0
253407	240307	14235Q	PARTICIPANT	0	PRESENT	0
253408	240307	19553Y	PARTICIPANT	0	PRESENT	0
253409	240306	98022P	PARTICIPANT	0	PRESENT	0
253410	240306	07004J	PARTICIPANT	0	PRESENT	0
253411	240306	14265W	PARTICIPANT	0	PRESENT	0
253412	240306	08015R	PARTICIPANT	0	PRESENT	0
253413	240306	08020N	PARTICIPANT	0	PRESENT	0
253414	240306	19467C	PARTICIPANT	0	PRESENT	0
253415	240306	14179A	PARTICIPANT	0	PRESENT	0
253416	240306	14211G	PARTICIPANT	0	PRESENT	0
253417	240306	14033T	PARTICIPANT	0	PRESENT	0
253418	240306	14079W	PARTICIPANT	0	PRESENT	0
253419	240306	04040A	PARTICIPANT	0	PRESENT	0
253420	240306	19631V	PARTICIPANT	0	PRESENT	0
253421	240306	14193X	PARTICIPANT	0	PRESENT	0
253422	240306	19629C	PARTICIPANT	0	PRESENT	0
253423	240306	04088S	PARTICIPANT	0	PRESENT	0
253424	240306	14109K	PARTICIPANT	0	PRESENT	0
253425	240306	08031R	PARTICIPANT	0	PRESENT	0
253426	240306	11104D	PARTICIPANT	0	PRESENT	0
253427	240306	19563B	PARTICIPANT	0	PRESENT	0
253428	240306	97011G	PARTICIPANT	0	PRESENT	0
253429	240306	14115H	PARTICIPANT	0	PRESENT	0
253430	240306	19447X	PARTICIPANT	0	PRESENT	0
253431	240306	08045X	PARTICIPANT	0	PRESENT	0
253432	240306	14105F	PARTICIPANT	0	PRESENT	0
253433	240306	80013X	PARTICIPANT	0	PRESENT	0
253434	240306	14257W	PARTICIPANT	0	PRESENT	0
253435	240306	04018C	PARTICIPANT	0	PRESENT	0
253436	240306	08056B	PARTICIPANT	0	PRESENT	0
253437	240306	19507S	PARTICIPANT	0	PRESENT	0
253438	240306	14191V	PARTICIPANT	0	PRESENT	0
253439	240306	14053L	PARTICIPANT	0	PRESENT	0
253440	240306	14231L	PARTICIPANT	0	PRESENT	0
253441	240306	11099A	PARTICIPANT	0	PRESENT	0
253442	240306	14055N	PARTICIPANT	0	PRESENT	0
253443	240306	11012A	PARTICIPANT	0	PRESENT	0
253444	240306	14059S	PARTICIPANT	0	PRESENT	0
253445	240306	14034U	PARTICIPANT	0	PRESENT	0
253446	240306	04086Q	PARTICIPANT	0	PRESENT	0
253447	240306	05008E	PARTICIPANT	0	PRESENT	0
253448	240306	01028R	PARTICIPANT	0	PRESENT	0
253449	240306	04085P	PARTICIPANT	0	PRESENT	0
253450	240306	04038G	PARTICIPANT	0	PRESENT	0
253451	240306	19565D	PARTICIPANT	0	PRESENT	0
253452	240306	14159V	PARTICIPANT	0	PRESENT	0
253453	240306	19489J	PARTICIPANT	0	PRESENT	0
253454	240306	08038Y	PARTICIPANT	0	PRESENT	0
253455	240306	14151M	PARTICIPANT	0	PRESENT	0
253456	240306	19725B	PARTICIPANT	0	PRESENT	0
253457	240306	14063N	PARTICIPANT	0	PRESENT	0
253458	240306	14207L	PARTICIPANT	0	PRESENT	0
253459	240306	08068F	PARTICIPANT	0	PRESENT	0
253460	240306	14107H	PARTICIPANT	0	PRESENT	0
253461	240306	08043V	PARTICIPANT	0	PRESENT	0
253462	240306	14201E	PARTICIPANT	0	PRESENT	0
253463	240306	14241N	PARTICIPANT	0	PRESENT	0
253464	240306	14111D	PARTICIPANT	0	PRESENT	0
253465	240306	04057K	PARTICIPANT	0	PRESENT	0
253466	240306	08044W	PARTICIPANT	0	PRESENT	0
253467	240306	19253P	PARTICIPANT	0	PRESENT	0
253468	240306	19387D	PARTICIPANT	0	PRESENT	0
253469	240306	14089Y	PARTICIPANT	0	PRESENT	0
253470	240306	14073Q	PARTICIPANT	0	PRESENT	0
253471	240306	01024M	PARTICIPANT	0	PRESENT	0
253472	240306	14215L	PARTICIPANT	0	PRESENT	0
253473	240306	19747H	PARTICIPANT	0	PRESENT	0
253474	240306	19533U	PARTICIPANT	0	PRESENT	0
253475	240306	14069U	PARTICIPANT	0	PRESENT	0
253476	240306	14249W	PARTICIPANT	0	PRESENT	0
253477	240306	08028W	PARTICIPANT	0	PRESENT	0
253478	240306	14147R	PARTICIPANT	0	PRESENT	0
254781	254779	14001X	PARTICIPANT	\N	PRESENT	0
255777	254993	96004D	PRESIDENT	0	PRESENT	0
255485	254024	19467C	PARTICIPANT	\N	PRESENT	0
255554	253546	95062K	PARTICIPANT	\N	EXCUSE	0
255778	254993	14089Y	PARTICIPANT	\N	PRESENT	0
255780	254993	14357A	PARTICIPANT	\N	PRESENT	0
255781	254993	14079W	PARTICIPANT	\N	PRESENT	0
255782	254993	11083R	PARTICIPANT	\N	PRESENT	0
255783	254993	14026U	PARTICIPANT	\N	PRESENT	0
255784	254993	19725B	PARTICIPANT	\N	PRESENT	0
255785	254993	14097Y	PARTICIPANT	\N	PRESENT	0
255786	254993	14073Q	PARTICIPANT	\N	PRESENT	0
255787	254993	14221J	PARTICIPANT	\N	PRESENT	0
255788	254993	98035U	PARTICIPANT	\N	PRESENT	0
255789	254993	14229S	PARTICIPANT	\N	PRESENT	0
255790	254993	10015M	PARTICIPANT	\N	PRESENT	0
255791	254993	14331P	PARTICIPANT	\N	PRESENT	0
255792	254993	04057K	PARTICIPANT	\N	PRESENT	0
255793	254993	14001X	PARTICIPANT	\N	PRESENT	0
255851	255850	07033P	PARTICIPANT	\N	PRESENT	0
255852	255850	04043D	PARTICIPANT	\N	PRESENT	0
255853	255850	14179A	PARTICIPANT	\N	PRESENT	0
240961	240227	19709B	PARTICIPANT	\N	EXCUSE	0
240962	240227	19723Y	PARTICIPANT	\N	EXCUSE	0
243964	243960	19415P	PARTICIPANT	\N	PRESENT	0
243965	243960	19521Q	PARTICIPANT	\N	PRESENT	0
243966	243960	14213J	PARTICIPANT	\N	PRESENT	0
243967	243960	14195A	PARTICIPANT	\N	PRESENT	0
243968	243960	14119M	PARTICIPANT	\N	PRESENT	0
243969	243960	17779H	PARTICIPANT	\N	PRESENT	0
243970	243960	19679N	PARTICIPANT	\N	PRESENT	0
243971	243960	19727D	PARTICIPANT	\N	PRESENT	0
243972	243960	11097X	PARTICIPANT	\N	PRESENT	0
243973	243960	04092N	PARTICIPANT	\N	PRESENT	0
243987	243986	19253P	PARTICIPANT	\N	PRESENT	0
243988	243986	19647E	PARTICIPANT	\N	PRESENT	0
243989	243986	11049P	PARTICIPANT	\N	PRESENT	0
243990	243986	14081Q	PARTICIPANT	\N	PRESENT	0
243991	243986	11026G	PARTICIPANT	\N	PRESENT	0
243992	243986	80027E	PARTICIPANT	\N	PRESENT	0
243993	243986	98050T	PARTICIPANT	\N	PRESENT	0
243994	243986	04045F	PARTICIPANT	\N	PRESENT	0
243995	243986	95067Q	PARTICIPANT	\N	PRESENT	0
250094	244776	19663E	PARTICIPANT	\N	PRESENT	0
251156	251150	14255U	PARTICIPANT	\N	PRESENT	0
251157	251150	14195A	PARTICIPANT	\N	PRESENT	0
251158	251150	01057W	PARTICIPANT	\N	PRESENT	0
251159	251150	08056B	PARTICIPANT	\N	PRESENT	0
251160	251150	97011G	PARTICIPANT	\N	PRESENT	0
251161	251150	07033P	PARTICIPANT	\N	PRESENT	0
251162	251150	14249W	PARTICIPANT	\N	PRESENT	0
251163	251150	19729F	PARTICIPANT	\N	PRESENT	0
251164	251150	05012A	PARTICIPANT	\N	PRESENT	0
251165	251150	11026G	PARTICIPANT	\N	PRESENT	0
253582	253563	08014Q	PARTICIPANT	\N	PRESENT	0
253584	253563	08069G	PARTICIPANT	\N	PRESENT	0
255795	255794	08045X	PARTICIPANT	\N	PRESENT	0
255796	255794	14069U	PARTICIPANT	\N	PRESENT	0
255797	255794	14135M	PARTICIPANT	\N	PRESENT	0
255798	255794	19737F	PARTICIPANT	\N	PRESENT	0
255954	255953	19531S	PARTICIPANT	\N	PRESENT	0
255956	255955	19667J	PARTICIPANT	\N	PRESENT	0
255958	255957	11053K	PARTICIPANT	\N	PRESENT	0
255962	255961	19479G	PARTICIPANT	\N	PRESENT	0
255964	255963	19479G	PARTICIPANT	\N	PRESENT	0
255977	255976	14097Y	PARTICIPANT	\N	PRESENT	0
255979	255978	14097Y	PARTICIPANT	\N	PRESENT	0
255980	255978	98022P	PARTICIPANT	\N	PRESENT	0
255982	255981	14097Y	PARTICIPANT	\N	PRESENT	0
255983	255981	11115U	PARTICIPANT	\N	PRESENT	0
266688	260929	08053X	PARTICIPANT	\N	PRESENT	0
259020	259019	14219Q	PARTICIPANT	\N	PRESENT	0
259022	259021	14219Q	PARTICIPANT	\N	PRESENT	0
259024	259023	14219Q	PARTICIPANT	\N	PRESENT	0
259026	259025	08024S	PARTICIPANT	\N	PRESENT	0
259030	259029	08024S	PARTICIPANT	\N	PRESENT	0
259032	259031	08024S	PARTICIPANT	\N	PRESENT	0
263247	263235	14089Y	PARTICIPANT	\N	PRESENT	0
263258	263255	14089Y	PARTICIPANT	\N	PRESENT	0
266801	266685	14065Q	PARTICIPANT	\N	PRESENT	0
266802	266685	07034Q	PARTICIPANT	\N	PRESENT	0
266803	266800	14065Q	PARTICIPANT	\N	PRESENT	0
266804	266800	07034Q	PARTICIPANT	\N	PRESENT	0
266806	263146	07029T	PARTICIPANT	\N	PRESENT	0
266807	263146	19335Q	PARTICIPANT	\N	PRESENT	0
266809	263146	08061X	PARTICIPANT	\N	PRESENT	0
266810	263146	19479G	PARTICIPANT	\N	PRESENT	0
266811	263146	88008L	PARTICIPANT	\N	PRESENT	0
266836	262916	04071H	PARTICIPANT	\N	PRESENT	0
266813	262916	19701S	PARTICIPANT	\N	PRESENT	0
266837	262916	19683J	PARTICIPANT	\N	PRESENT	0
266838	262916	19643A	PARTICIPANT	\N	PRESENT	0
266839	262916	11048N	PARTICIPANT	\N	PRESENT	0
266817	262916	14179A	PARTICIPANT	\N	PRESENT	0
266835	263146	19573D	PARTICIPANT	\N	PRESENT	0
266840	262916	19647E	PARTICIPANT	\N	PRESENT	0
266841	262916	19649G	PARTICIPANT	\N	PRESENT	0
266842	262916	19689Q	PARTICIPANT	\N	PRESENT	0
266843	262916	04059M	PARTICIPANT	\N	PRESENT	0
266844	262916	99004R	PARTICIPANT	\N	PRESENT	0
266845	262916	19685L	PARTICIPANT	\N	EXCUSE	0
266846	262916	19681G	PARTICIPANT	\N	EXCUSE	0
266847	263146	19705W	PARTICIPANT	\N	PRESENT	0
266827	263146	11083R	PARTICIPANT	\N	PRESENT	0
266828	263146	14187A	PARTICIPANT	\N	PRESENT	0
266829	263146	14033T	PARTICIPANT	\N	PRESENT	0
266930	263146	04088S	PARTICIPANT	\N	PRESENT	0
266831	263146	14109K	PARTICIPANT	\N	PRESENT	0
266832	263146	19301E	PARTICIPANT	\N	PRESENT	0
266833	263146	19269X	PARTICIPANT	\N	PRESENT	0
266834	263146	19637C	PARTICIPANT	\N	PRESENT	0
266848	263146	14265W	PARTICIPANT	\N	PRESENT	0
266849	263146	95030B	PARTICIPANT	\N	PRESENT	0
266850	263146	19683J	PARTICIPANT	\N	PRESENT	0
266851	263146	11067R	PARTICIPANT	\N	PRESENT	0
266852	263146	19349W	PARTICIPANT	\N	PRESENT	0
266853	263146	04045F	PARTICIPANT	\N	PRESENT	0
266854	263146	04049K	PARTICIPANT	\N	PRESENT	0
266855	263146	19443T	PARTICIPANT	\N	PRESENT	0
266856	263146	14030Q	PARTICIPANT	\N	PRESENT	0
266857	263146	19629C	PARTICIPANT	\N	PRESENT	0
266858	263146	14197C	PARTICIPANT	\N	PRESENT	0
266859	263146	19695N	PARTICIPANT	\N	PRESENT	0
266860	263146	14257W	PARTICIPANT	\N	PRESENT	0
266862	263054	14223L	PARTICIPANT	\N	PRESENT	0
266864	263146	08015R	PARTICIPANT	\N	PRESENT	0
266865	263146	14034U	PARTICIPANT	\N	PRESENT	0
266866	263146	11012A	PARTICIPANT	\N	PRESENT	0
266867	263146	14071N	PARTICIPANT	\N	PRESENT	0
266869	263146	08031R	PARTICIPANT	\N	PRESENT	0
266876	263146	11109J	PARTICIPANT	\N	PRESENT	0
266877	263146	19569H	PARTICIPANT	\N	PRESENT	0
266878	263146	14069U	PARTICIPANT	\N	PRESENT	0
266879	259068	19683J	PARTICIPANT	\N	PRESENT	0
266880	263146	14223L	PARTICIPANT	\N	PRESENT	0
266893	263146	01058X	PARTICIPANT	\N	PRESENT	0
266894	263146	19383Y	PARTICIPANT	\N	PRESENT	0
266895	263146	14327T	PARTICIPANT	\N	PRESENT	0
266896	263146	14042U	PARTICIPANT	\N	PRESENT	0
266897	263146	14219Q	PARTICIPANT	\N	PRESENT	0
266898	263146	19737F	PARTICIPANT	\N	PRESENT	0
266899	263146	08056B	PARTICIPANT	\N	PRESENT	0
266900	263146	14157T	PARTICIPANT	\N	PRESENT	0
266901	263146	19447X	PARTICIPANT	\N	PRESENT	0
266902	263146	08010L	PARTICIPANT	\N	PRESENT	0
266903	263146	14031R	PARTICIPANT	\N	PRESENT	0
266905	263146	19387D	PARTICIPANT	\N	PRESENT	0
266906	266904	14239U	PARTICIPANT	\N	PRESENT	0
266907	263146	19333N	PARTICIPANT	\N	PRESENT	0
266908	266904	19549D	PARTICIPANT	\N	PRESENT	0
266909	266904	14065Q	PARTICIPANT	\N	PRESENT	0
266910	266904	19367Y	PARTICIPANT	\N	EXCUSE	0
266911	266904	14053L	PARTICIPANT	\N	PRESENT	0
266912	266904	14195A	PARTICIPANT	\N	PRESENT	0
266913	266904	19295A	PARTICIPANT	\N	PRESENT	0
266914	266904	14041T	PARTICIPANT	\N	PRESENT	0
266915	266904	14217N	PARTICIPANT	\N	PRESENT	0
266916	266904	14215L	PARTICIPANT	\N	PRESENT	0
266917	266904	19577H	PARTICIPANT	\N	PRESENT	0
266918	266904	08045X	PARTICIPANT	\N	PRESENT	0
266919	266904	14087W	PARTICIPANT	\N	PRESENT	0
266920	266904	14231L	PARTICIPANT	\N	PRESENT	0
266921	266904	19697Q	PARTICIPANT	\N	PRESENT	0
266922	266904	11067R	PARTICIPANT	\N	EXCUSE	0
266923	266904	14223L	PARTICIPANT	\N	PRESENT	0
266924	266904	11045K	PARTICIPANT	\N	PRESENT	0
266925	266904	04044E	PRESIDENT	0	PRESENT	0
266926	263146	19441R	PARTICIPANT	\N	PRESENT	0
266927	262916	08060W	PARTICIPANT	\N	EXCUSE	0
266928	263146	18083K	PARTICIPANT	\N	PRESENT	0
266929	263146	12016W	PARTICIPANT	\N	PRESENT	0
266932	266931	96004D	PARTICIPANT	\N	PRESENT	0
266933	266931	14133K	PARTICIPANT	\N	PRESENT	0
266934	266931	04035D	PARTICIPANT	\N	PRESENT	0
266935	266931	04097T	PARTICIPANT	\N	PRESENT	0
266936	266931	14097Y	PARTICIPANT	\N	PRESENT	0
266937	266931	04042C	PARTICIPANT	\N	PRESENT	0
266938	266931	19251M	PARTICIPANT	\N	PRESENT	0
266939	266931	04034C	PARTICIPANT	\N	PRESENT	0
266940	266931	98050T	PARTICIPANT	\N	PRESENT	0
266941	266931	01062T	PARTICIPANT	\N	PRESENT	0
266942	266931	14255U	PARTICIPANT	\N	PRESENT	0
266961	266954	08014Q	PARTICIPANT	\N	PRESENT	0
266962	266954	08069G	PARTICIPANT	\N	PRESENT	0
266963	266959	08014Q	PARTICIPANT	\N	PRESENT	0
266964	266959	08069G	PARTICIPANT	\N	PRESENT	0
266965	256023	19575F	PARTICIPANT	\N	PRESENT	0
266966	256023	98029W	PRESIDENT	0	PRESENT	0
266967	256023	08056B	PARTICIPANT	\N	PRESENT	0
266968	256023	98050T	PARTICIPANT	\N	PRESENT	0
263461	262993	14069U	PARTICIPANT	\N	PRESENT	0
263755	262993	14071N	PARTICIPANT	\N	EXCUSE	0
263761	263760	19629C	PARTICIPANT	\N	PRESENT	0
263762	263760	19719D	PARTICIPANT	\N	PRESENT	0
263763	263760	14026U	PARTICIPANT	\N	PRESENT	0
263860	263859	14053L	PARTICIPANT	\N	PRESENT	0
263861	263859	19719D	PARTICIPANT	\N	PRESENT	0
263862	263859	14026U	PARTICIPANT	\N	PRESENT	0
263863	263859	14281W	PARTICIPANT	\N	PRESENT	0
263865	256019	19575F	PARTICIPANT	\N	EXCUSE	0
263866	263850	14105F	PARTICIPANT	\N	PRESENT	0
263867	263850	08068F	PARTICIPANT	\N	PRESENT	0
263868	263850	14255U	PARTICIPANT	\N	PRESENT	0
263869	263850	14053L	PARTICIPANT	\N	PRESENT	0
263870	263850	14083S	PARTICIPANT	\N	PRESENT	0
263871	263850	14329V	PARTICIPANT	\N	PRESENT	0
263872	263850	14079W	PARTICIPANT	\N	EXCUSE	0
263873	263850	14041T	PARTICIPANT	\N	PRESENT	0
263874	263850	14187A	PARTICIPANT	\N	PRESENT	0
263875	263850	19521Q	PARTICIPANT	\N	PRESENT	0
263876	263850	14034U	PARTICIPANT	\N	PRESENT	0
263889	263850	89017R	PARTICIPANT	\N	EXCUSE	0
263890	263850	19575F	PARTICIPANT	\N	EXCUSE	0
263879	263850	11099A	PARTICIPANT	\N	PRESENT	0
263880	263850	08015R	PARTICIPANT	\N	PRESENT	0
263881	263850	16685X	PARTICIPANT	\N	PRESENT	0
263882	263850	19671E	PARTICIPANT	\N	PRESENT	0
263883	263850	14265W	PARTICIPANT	\N	PRESENT	0
263884	263850	04088S	PARTICIPANT	\N	PRESENT	0
263891	263850	11031D	PARTICIPANT	\N	EXCUSE	0
263886	263850	19527W	PARTICIPANT	\N	PRESENT	0
263887	263850	14157T	PARTICIPANT	\N	PRESENT	0
263892	263850	14087W	PARTICIPANT	\N	EXCUSE	0
263893	263850	14026U	PARTICIPANT	\N	EXCUSE	0
263894	263850	14061L	PARTICIPANT	\N	EXCUSE	0
263895	263850	14253S	PARTICIPANT	\N	EXCUSE	0
263896	263850	14051J	PARTICIPANT	\N	EXCUSE	0
263897	263850	04034C	PARTICIPANT	\N	EXCUSE	0
263905	263850	08047A	PARTICIPANT	\N	PRESENT	0
263908	263850	19695N	PARTICIPANT	\N	EXCUSE	0
263909	263850	14121F	PARTICIPANT	\N	EXCUSE	0
263910	263850	14227Q	PARTICIPANT	\N	EXCUSE	0
264049	258932	02002K	PARTICIPANT	\N	PRESENT	0
264050	256016	98029W	PARTICIPANT	\N	PRESENT	0
264051	256016	04008A	PARTICIPANT	\N	PRESENT	0
264052	256016	19673G	PARTICIPANT	\N	PRESENT	0
264053	256016	19649G	PARTICIPANT	\N	PRESENT	0
264054	256016	08056B	PARTICIPANT	\N	PRESENT	0
264055	256016	98022P	PARTICIPANT	\N	PRESENT	0
264056	256016	19611R	PARTICIPANT	\N	PRESENT	0
264057	256016	08010L	PARTICIPANT	\N	PRESENT	0
264058	256016	11026G	PARTICIPANT	\N	PRESENT	0
264059	256016	98050T	PARTICIPANT	\N	PRESENT	0
264060	256016	19421M	PARTICIPANT	\N	PRESENT	0
264062	264061	96004D	PARTICIPANT	\N	PRESENT	0
264063	264061	14331P	PARTICIPANT	\N	PRESENT	0
264064	264061	98035U	PARTICIPANT	\N	PRESENT	0
264065	264061	14133K	PARTICIPANT	\N	PRESENT	0
264066	262993	08048B	PARTICIPANT	\N	EXCUSE	0
264067	262998	08010L	PARTICIPANT	\N	PRESENT	0
264068	262993	08010L	PARTICIPANT	\N	PRESENT	0
264069	262993	11101A	PARTICIPANT	\N	EXCUSE	0
264070	262998	11101A	PARTICIPANT	\N	EXCUSE	0
264089	262998	19687N	PARTICIPANT	\N	PRESENT	0
264090	262993	19687N	PARTICIPANT	\N	PRESENT	0
264092	262993	14231L	PARTICIPANT	\N	EXCUSE	0
264115	264113	11027H	PARTICIPANT	\N	PRESENT	0
264116	264113	14193X	PARTICIPANT	\N	PRESENT	0
264121	264120	11027H	PARTICIPANT	\N	PRESENT	0
264122	264120	14193X	PARTICIPANT	\N	PRESENT	0
264124	264123	11027H	PARTICIPANT	\N	PRESENT	0
264125	264123	14193X	PARTICIPANT	\N	PRESENT	0
264127	264126	11027H	PARTICIPANT	\N	PRESENT	0
264128	264126	14193X	PARTICIPANT	\N	PRESENT	0
264131	262998	14121F	PARTICIPANT	\N	PRESENT	0
264206	258949	14299H	PARTICIPANT	\N	PRESENT	0
264207	258949	19709B	PARTICIPANT	\N	PRESENT	0
264208	258950	14299H	PARTICIPANT	\N	PRESENT	0
264209	258950	19709B	PARTICIPANT	\N	PRESENT	0
264210	258951	14299H	PARTICIPANT	\N	PRESENT	0
264211	258951	19709B	PARTICIPANT	\N	PRESENT	0
264213	264212	04040A	PARTICIPANT	\N	PRESENT	0
264239	262998	14257W	PARTICIPANT	\N	EXCUSE	0
264240	262998	14259Y	PARTICIPANT	\N	PRESENT	0
264241	262993	14259Y	PARTICIPANT	\N	PRESENT	0
264242	262993	04086Q	PARTICIPANT	\N	EXCUSE	0
264243	262998	04086Q	PARTICIPANT	\N	PRESENT	0
264288	264287	96004D	PARTICIPANT	\N	PRESENT	0
264289	264287	11074Q	PARTICIPANT	\N	PRESENT	0
264290	264287	08011M	PARTICIPANT	\N	PRESENT	0
265711	265710	08055A	PARTICIPANT	\N	PRESENT	0
265712	265710	14105F	PARTICIPANT	\N	PRESENT	0
265713	265710	11103C	PARTICIPANT	\N	PRESENT	0
265714	265710	19467C	PARTICIPANT	\N	PRESENT	0
265715	265710	18083K	PARTICIPANT	\N	PRESENT	0
265716	265710	17589D	PARTICIPANT	\N	PRESENT	0
265717	265710	14187A	PARTICIPANT	\N	PRESENT	0
265719	265710	08069G	PARTICIPANT	\N	PRESENT	0
265720	265710	14097Y	PARTICIPANT	\N	PRESENT	0
265721	265710	19723Y	PARTICIPANT	\N	PRESENT	0
265722	265710	16685X	PARTICIPANT	\N	PRESENT	0
265723	265710	14059S	PARTICIPANT	\N	PRESENT	0
265725	265710	17779H	PARTICIPANT	\N	PRESENT	0
265726	265710	14103D	PARTICIPANT	\N	PRESENT	0
265727	265710	08053X	PARTICIPANT	\N	PRESENT	0
265728	265710	14221J	PARTICIPANT	\N	PRESENT	0
265729	265710	14119M	PARTICIPANT	\N	PRESENT	0
265730	265710	98050T	PARTICIPANT	\N	PRESENT	0
265731	265710	19739H	PARTICIPANT	\N	PRESENT	0
265732	265710	17583W	PARTICIPANT	\N	PRESENT	0
265733	265710	19679N	PARTICIPANT	\N	PRESENT	0
265734	265710	14107H	PARTICIPANT	\N	PRESENT	0
265735	265710	14173T	PARTICIPANT	\N	PRESENT	0
265782	265781	11065P	PARTICIPANT	\N	PRESENT	0
265783	265781	19533U	PARTICIPANT	\N	PRESENT	0
265784	265781	08017T	PARTICIPANT	\N	PRESENT	0
265785	265781	14073Q	PARTICIPANT	\N	PRESENT	0
265856	265855	07033P	PARTICIPANT	\N	PRESENT	0
265857	265855	04070G	PARTICIPANT	\N	PRESENT	0
265858	265855	19671E	PARTICIPANT	\N	PRESENT	0
265859	265855	14059S	PARTICIPANT	\N	PRESENT	0
265860	265855	08039A	PARTICIPANT	\N	PRESENT	0
265861	265855	19479G	PARTICIPANT	\N	PRESENT	0
265862	265855	14219Q	PARTICIPANT	\N	PRESENT	0
265863	265855	19749K	PARTICIPANT	\N	PRESENT	0
265864	265855	14030Q	PARTICIPANT	\N	PRESENT	0
265865	265855	14229S	PARTICIPANT	\N	PRESENT	0
265866	265855	04018C	PARTICIPANT	\N	PRESENT	0
265868	265867	08039A	PARTICIPANT	\N	PRESENT	0
265869	265867	19399H	PARTICIPANT	\N	PRESENT	0
265870	265867	14229S	PARTICIPANT	\N	PRESENT	0
265871	265867	08043V	PARTICIPANT	\N	PRESENT	0
265873	265872	08039A	PARTICIPANT	\N	PRESENT	0
265874	265872	19399H	PARTICIPANT	\N	PRESENT	0
265915	258758	14225N	PARTICIPANT	\N	EXCUSE	0
265959	258758	14259Y	PARTICIPANT	\N	EXCUSE	0
266084	266083	04097T	PARTICIPANT	\N	PRESENT	0
266085	266083	96004D	PARTICIPANT	\N	PRESENT	0
266086	266083	98035U	PARTICIPANT	\N	PRESENT	0
266087	266083	14221J	PARTICIPANT	\N	PRESENT	0
266088	266083	04057K	PARTICIPANT	\N	PRESENT	0
266089	266083	14097Y	PARTICIPANT	\N	PRESENT	0
266090	266083	14061L	PARTICIPANT	\N	PRESENT	0
266091	266083	19709B	PARTICIPANT	\N	PRESENT	0
266092	266083	04042C	PARTICIPANT	\N	PRESENT	0
266093	266083	19251M	PARTICIPANT	\N	PRESENT	0
266094	266083	14255U	PARTICIPANT	\N	PRESENT	0
266095	266083	98050T	PARTICIPANT	\N	PRESENT	0
266096	266083	04034C	PARTICIPANT	\N	PRESENT	0
266871	256504	19515S	PARTICIPANT	\N	PRESENT	0
266872	256504	19467C	PARTICIPANT	\N	PRESENT	0
266873	256504	19551W	PARTICIPANT	\N	PRESENT	0
266874	256504	19369B	PARTICIPANT	\N	PRESENT	0
266875	256504	19713W	PARTICIPANT	\N	PRESENT	0
266944	266943	14239U	PARTICIPANT	\N	PRESENT	0
266945	266943	14041T	PARTICIPANT	\N	PRESENT	0
266946	266943	04044E	PARTICIPANT	\N	PRESENT	0
266947	266943	19697Q	PARTICIPANT	\N	PRESENT	0
266969	256023	10015M	PARTICIPANT	\N	PRESENT	0
266970	256023	19421M	PARTICIPANT	\N	PRESENT	0
266971	256023	19611R	PARTICIPANT	\N	EXCUSE	0
266972	258933	19575F	PARTICIPANT	\N	PRESENT	0
266973	258933	98029W	PRESIDENT	0	PRESENT	0
241243	241242	19651A	PARTICIPANT	\N	PRESENT	0
241244	241242	19721W	PARTICIPANT	\N	PRESENT	0
241245	241242	04088S	PARTICIPANT	\N	PRESENT	0
241246	241242	14051J	PARTICIPANT	\N	PRESENT	0
241270	240227	19593H	PARTICIPANT	\N	EXCUSE	0
242006	242005	19685L	PARTICIPANT	\N	PRESENT	0
242007	242005	11027H	PARTICIPANT	\N	PRESENT	0
242861	241490	98029W	PARTICIPANT	\N	EXCUSE	0
242862	241490	98053W	PARTICIPANT	\N	EXCUSE	0
242863	241490	08056B	PARTICIPANT	\N	EXCUSE	0
242864	241490	14028W	PARTICIPANT	\N	EXCUSE	0
242865	241490	14193X	PARTICIPANT	\N	EXCUSE	0
242866	241494	98029W	PARTICIPANT	\N	EXCUSE	0
242867	241494	98053W	PARTICIPANT	\N	EXCUSE	0
242868	241494	08056B	PARTICIPANT	\N	EXCUSE	0
242869	241494	14028W	PARTICIPANT	\N	EXCUSE	0
242870	241494	14193X	PARTICIPANT	\N	EXCUSE	0
242881	241494	19319Q	PARTICIPANT	\N	EXCUSE	0
242882	241490	19319Q	PARTICIPANT	\N	EXCUSE	0
243140	243139	04086Q	PARTICIPANT	\N	PRESENT	0
243141	243139	99004R	PARTICIPANT	\N	PRESENT	0
243142	243139	19731Y	PARTICIPANT	\N	PRESENT	0
243143	243139	04045F	PARTICIPANT	\N	PRESENT	0
243144	243139	98035U	PARTICIPANT	\N	PRESENT	0
243145	243139	04070G	PARTICIPANT	\N	PRESENT	0
243146	243139	11085T	PARTICIPANT	\N	PRESENT	0
243148	243139	08044W	PARTICIPANT	\N	PRESENT	0
243149	243139	04035D	PARTICIPANT	\N	PRESENT	0
243150	243139	19707Y	PARTICIPANT	\N	PRESENT	0
243151	243139	10006L	PARTICIPANT	\N	PRESENT	0
243152	243139	19647E	PARTICIPANT	\N	PRESENT	0
243153	243139	11049P	PARTICIPANT	\N	PRESENT	0
243154	243139	04049K	PARTICIPANT	\N	PRESENT	0
243155	243139	19711U	PARTICIPANT	\N	PRESENT	0
243156	243139	19709B	PARTICIPANT	\N	PRESENT	0
243157	243139	11026G	PARTICIPANT	\N	PRESENT	0
243158	243139	19573D	PARTICIPANT	\N	PRESENT	0
243159	243139	10015M	PARTICIPANT	\N	PRESENT	0
243160	243139	19705W	PARTICIPANT	\N	PRESENT	0
243161	243139	11043H	PARTICIPANT	\N	PRESENT	0
243163	243139	95067Q	PARTICIPANT	\N	PRESENT	0
243164	243139	19621T	PARTICIPANT	\N	PRESENT	0
245389	244125	14261S	PARTICIPANT	\N	PRESENT	0
245390	244125	19575F	PARTICIPANT	\N	PRESENT	0
245391	244125	19367Y	PARTICIPANT	\N	PRESENT	0
245392	244125	11103C	PARTICIPANT	\N	PRESENT	0
245396	244125	08052W	PARTICIPANT	\N	PRESENT	0
245394	244125	14195A	PARTICIPANT	\N	PRESENT	0
245395	244125	11031D	PARTICIPANT	\N	PRESENT	0
245397	244125	98024R	PARTICIPANT	\N	PRESENT	0
245398	244125	14217N	PARTICIPANT	\N	PRESENT	0
245399	244125	14042U	PARTICIPANT	\N	PRESENT	0
245400	244125	14281W	PARTICIPANT	\N	PRESENT	0
245401	244125	14087W	PARTICIPANT	\N	PRESENT	0
245441	244125	19521Q	PARTICIPANT	\N	PRESENT	0
245442	244125	14026U	PARTICIPANT	\N	PRESENT	0
245443	244125	19691J	PARTICIPANT	\N	PRESENT	0
245444	244125	19553Y	PARTICIPANT	\N	PRESENT	0
245445	244125	19569H	PARTICIPANT	\N	PRESENT	0
245446	244125	19715Y	PARTICIPANT	\N	PRESENT	0
245447	244125	19697Q	PARTICIPANT	\N	PRESENT	0
245448	244125	17779H	PARTICIPANT	\N	PRESENT	0
245449	244125	11067R	PARTICIPANT	\N	PRESENT	0
245450	244125	14223L	PARTICIPANT	\N	PRESENT	0
245451	244125	04092N	PARTICIPANT	\N	PRESENT	0
245452	244125	19335Q	PARTICIPANT	\N	PRESENT	0
245453	244125	14119M	PARTICIPANT	\N	PRESENT	0
245454	244125	14071N	PARTICIPANT	\N	PRESENT	0
245455	244125	19679N	PARTICIPANT	\N	PRESENT	0
245456	244125	11045K	PARTICIPANT	\N	PRESENT	0
245457	244125	04045F	PARTICIPANT	\N	PRESENT	0
245458	244125	19703U	PARTICIPANT	\N	PRESENT	0
245459	244125	19675J	PARTICIPANT	\N	PRESENT	0
245460	244125	14227Q	PARTICIPANT	\N	PRESENT	0
245461	244125	19527W	PARTICIPANT	\N	PRESENT	0
245502	244125	19683J	PARTICIPANT	\N	PRESENT	0
245503	244125	14213J	PARTICIPANT	\N	EXCUSE	0
245504	244125	08048B	PARTICIPANT	\N	EXCUSE	0
247234	247233	10015M	PARTICIPANT	\N	PRESENT	0
247235	247233	11072N	PARTICIPANT	\N	PRESENT	0
251382	251360	01043Q	PARTICIPANT	\N	PRESENT	0
251384	251360	11077T	PARTICIPANT	\N	PRESENT	0
251385	251360	01048V	PARTICIPANT	\N	PRESENT	0
251386	251360	08019V	PARTICIPANT	\N	PRESENT	0
251387	251360	14251Q	PARTICIPANT	\N	PRESENT	0
251388	251360	08009T	PARTICIPANT	\N	PRESENT	0
251389	251360	11072N	PARTICIPANT	\N	PRESENT	0
251392	251360	08011M	PARTICIPANT	\N	PRESENT	0
251393	251360	04070G	PARTICIPANT	\N	PRESENT	0
251424	251360	08061X	PARTICIPANT	\N	PRESENT	0
251425	251360	14237S	PARTICIPANT	\N	PRESENT	0
251426	251360	05012A	PARTICIPANT	\N	PRESENT	0
251427	251360	11090Q	PARTICIPANT	\N	PRESENT	0
251428	251360	11012A	PARTICIPANT	\N	PRESENT	0
251429	251360	04033B	PARTICIPANT	\N	PRESENT	0
251430	251360	04044E	PARTICIPANT	\N	PRESENT	0
251433	251432	89017R	PARTICIPANT	\N	PRESENT	0
251434	251432	04085P	PARTICIPANT	\N	PRESENT	0
251435	251432	05008E	PARTICIPANT	\N	PRESENT	0
251436	251432	96004D	PARTICIPANT	\N	PRESENT	0
251437	251432	04042C	PARTICIPANT	\N	PRESENT	0
251438	251432	04086Q	PARTICIPANT	\N	PRESENT	0
251439	251432	11070L	PARTICIPANT	\N	PRESENT	0
251440	251432	11074Q	PARTICIPANT	\N	PRESENT	0
251441	251432	14034U	PARTICIPANT	\N	PRESENT	0
251442	251432	14231L	PARTICIPANT	\N	PRESENT	0
251443	251432	08016S	PARTICIPANT	\N	PRESENT	0
251444	251432	01043Q	PARTICIPANT	\N	PRESENT	0
251445	251432	14251Q	PARTICIPANT	\N	PRESENT	0
251446	251432	08009T	PARTICIPANT	\N	PRESENT	0
251447	251432	04092N	PARTICIPANT	\N	PRESENT	0
251448	251432	11072N	PARTICIPANT	\N	PRESENT	0
251449	251432	04070G	PARTICIPANT	\N	PRESENT	0
251450	251432	08061X	PARTICIPANT	\N	PRESENT	0
251451	251432	05012A	PARTICIPANT	\N	PRESENT	0
251452	251432	11090Q	PARTICIPANT	\N	PRESENT	0
251453	251432	11012A	PARTICIPANT	\N	PRESENT	0
251454	251432	04033B	PARTICIPANT	\N	PRESENT	0
251455	251432	04044E	PARTICIPANT	\N	PRESENT	0
251456	251432	01034P	PARTICIPANT	\N	PRESENT	0
251460	251458	89017R	PARTICIPANT	\N	PRESENT	0
251461	251458	04085P	PARTICIPANT	\N	PRESENT	0
251462	251458	04059M	PARTICIPANT	\N	PRESENT	0
251463	251458	05008E	PARTICIPANT	\N	PRESENT	0
251464	251458	04086Q	PARTICIPANT	\N	PRESENT	0
251465	251458	11070L	PARTICIPANT	\N	PRESENT	0
251466	251458	11074Q	PARTICIPANT	\N	PRESENT	0
251467	251458	14187A	PARTICIPANT	\N	PRESENT	0
251468	251458	14034U	PARTICIPANT	\N	PRESENT	0
251469	251458	08016S	PARTICIPANT	\N	PRESENT	0
251470	251458	01043Q	PARTICIPANT	\N	PRESENT	0
251471	251458	14251Q	PARTICIPANT	\N	PRESENT	0
251484	251458	11085T	PARTICIPANT	\N	PRESENT	0
251485	251458	08009T	PARTICIPANT	\N	PRESENT	0
251486	251458	04092N	PARTICIPANT	\N	PRESENT	0
251487	251458	11072N	PARTICIPANT	\N	PRESENT	0
251488	251458	08011M	PARTICIPANT	\N	PRESENT	0
251489	251458	04070G	PARTICIPANT	\N	PRESENT	0
251491	251458	08061X	PARTICIPANT	\N	PRESENT	0
251492	251458	14193X	PARTICIPANT	\N	PRESENT	0
251496	251458	11090Q	PARTICIPANT	\N	PRESENT	0
251497	251458	11012A	PARTICIPANT	\N	PRESENT	0
251498	251458	01034P	PARTICIPANT	\N	PRESENT	0
251500	251499	89017R	PARTICIPANT	\N	PRESENT	0
251501	251499	04085P	PARTICIPANT	\N	PRESENT	0
251502	251499	04059M	PARTICIPANT	\N	PRESENT	0
251503	251499	05008E	PARTICIPANT	\N	PRESENT	0
251504	251499	96004D	PARTICIPANT	\N	PRESENT	0
251505	251499	04042C	PARTICIPANT	\N	PRESENT	0
251506	251499	11053K	PARTICIPANT	\N	PRESENT	0
251508	251499	04086Q	PARTICIPANT	\N	PRESENT	0
251509	251499	11070L	PARTICIPANT	\N	PRESENT	0
251510	251499	11074Q	PARTICIPANT	\N	PRESENT	0
251511	251499	14034U	PARTICIPANT	\N	PRESENT	0
251512	251499	08016S	PARTICIPANT	\N	PRESENT	0
251513	251499	01043Q	PARTICIPANT	\N	PRESENT	0
251514	251499	11077T	PARTICIPANT	\N	PRESENT	0
251515	251499	14251Q	PARTICIPANT	\N	PRESENT	0
251516	251499	11085T	PARTICIPANT	\N	PRESENT	0
251519	251499	04092N	PARTICIPANT	\N	PRESENT	0
251520	251499	08011M	PARTICIPANT	\N	PRESENT	0
251521	251499	04070G	PARTICIPANT	\N	PRESENT	0
251523	251499	08061X	PARTICIPANT	\N	PRESENT	0
251524	251499	11090Q	PARTICIPANT	\N	PRESENT	0
251525	251499	11012A	PARTICIPANT	\N	PRESENT	0
251527	251499	04033B	PARTICIPANT	\N	PRESENT	0
251528	251499	04044E	PARTICIPANT	\N	PRESENT	0
251529	251499	01034P	PARTICIPANT	\N	PRESENT	0
251530	251499	14157T	PARTICIPANT	\N	PRESENT	0
255854	255850	97011G	PARTICIPANT	\N	PRESENT	0
255861	255858	95067Q	PARTICIPANT	\N	PRESENT	0
255859	255858	14255U	PARTICIPANT	\N	PRESENT	0
255860	255858	14083S	PARTICIPANT	\N	PRESENT	0
255875	255874	11053K	PARTICIPANT	\N	PRESENT	0
255887	255886	86034E	PARTICIPANT	\N	PRESENT	0
255888	255886	04059M	PARTICIPANT	\N	PRESENT	0
255889	255886	11040E	PARTICIPANT	\N	PRESENT	0
255890	255886	14053L	PARTICIPANT	\N	PRESENT	0
255891	255886	11053K	PARTICIPANT	\N	PRESENT	0
255972	255971	14193X	PARTICIPANT	\N	PRESENT	0
255893	255886	08052W	PARTICIPANT	\N	PRESENT	0
255894	255886	11070L	PARTICIPANT	\N	PRESENT	0
255895	255886	10006L	PARTICIPANT	\N	PRESENT	0
255896	255886	14041T	PARTICIPANT	\N	PRESENT	0
255973	255971	08053X	PARTICIPANT	\N	PRESENT	0
255898	255886	14034U	PARTICIPANT	\N	PRESENT	0
255899	255886	14231L	PARTICIPANT	\N	PRESENT	0
255974	255971	95067Q	PARTICIPANT	\N	PRESENT	0
255901	255886	14081Q	PARTICIPANT	\N	PRESENT	0
255902	255886	14241N	PARTICIPANT	\N	PRESENT	0
255975	255971	14235Q	PARTICIPANT	\N	PRESENT	0
255904	255886	14159V	PARTICIPANT	\N	PRESENT	0
255905	255886	08034U	PARTICIPANT	\N	PRESENT	0
255906	255886	01043Q	PARTICIPANT	\N	PRESENT	0
255907	255886	11077T	PARTICIPANT	\N	PRESENT	0
255908	255886	12016W	PARTICIPANT	\N	PRESENT	0
255909	255886	11072N	PARTICIPANT	\N	PRESENT	0
255910	255886	05012A	PARTICIPANT	\N	PRESENT	0
255911	255886	14135M	PARTICIPANT	\N	PRESENT	0
255912	255886	04044E	PARTICIPANT	\N	PRESENT	0
255993	255992	08011M	PARTICIPANT	\N	PRESENT	0
256000	255999	08015R	PARTICIPANT	\N	PRESENT	0
256001	255999	01043Q	PARTICIPANT	\N	PRESENT	0
256002	255999	14001X	PARTICIPANT	\N	PRESENT	0
256004	256003	14121F	PARTICIPANT	\N	PRESENT	0
256006	256005	04043D	PARTICIPANT	\N	PRESENT	0
258233	240327	14089Y	PARTICIPANT	\N	PRESENT	0
258234	240327	19693L	PARTICIPANT	\N	PRESENT	0
258235	240327	99004R	PARTICIPANT	\N	PRESENT	0
258231	240327	19467C	PARTICIPANT	\N	PRESENT	0
258232	240327	19747H	PARTICIPANT	\N	PRESENT	0
258236	240327	19671E	PARTICIPANT	\N	PRESENT	0
258237	240327	14031R	PARTICIPANT	\N	PRESENT	0
258238	240327	14225N	PARTICIPANT	\N	PRESENT	0
258239	240327	14147R	PARTICIPANT	\N	PRESENT	0
258240	240327	08019V	PARTICIPANT	\N	PRESENT	0
258241	240327	19723Y	PARTICIPANT	\N	PRESENT	0
258242	240327	18083K	PARTICIPANT	\N	PRESENT	0
258243	240327	19387D	PARTICIPANT	\N	PRESENT	0
258244	240327	07029T	PARTICIPANT	\N	PRESENT	0
258245	240327	19415P	PARTICIPANT	\N	PRESENT	0
258246	240327	19681G	PARTICIPANT	\N	PRESENT	0
258247	240327	11104D	PARTICIPANT	\N	PRESENT	0
258249	240327	19533U	PARTICIPANT	\N	PRESENT	0
258250	240327	19663E	PARTICIPANT	\N	PRESENT	0
258251	240327	08010L	PARTICIPANT	\N	PRESENT	0
258252	240327	14083S	PARTICIPANT	\N	PRESENT	0
258253	240327	19711U	PARTICIPANT	\N	PRESENT	0
258254	240327	04057K	PARTICIPANT	\N	PRESENT	0
258255	240327	19695N	PARTICIPANT	\N	PRESENT	0
258256	240327	95063L	PARTICIPANT	\N	PRESENT	0
258257	240327	08020N	PARTICIPANT	\N	PRESENT	0
258258	240327	14267Y	PARTICIPANT	\N	PRESENT	0
258259	240327	19531S	PARTICIPANT	\N	PRESENT	0
258260	240327	14038Y	PARTICIPANT	\N	PRESENT	0
258261	240327	04035D	PARTICIPANT	\N	PRESENT	0
258262	240327	14021P	PARTICIPANT	\N	PRESENT	0
258263	240327	07004J	PARTICIPANT	\N	PRESENT	0
258264	240327	19689Q	PARTICIPANT	\N	PRESENT	0
258265	240327	14219Q	PARTICIPANT	\N	PRESENT	0
258266	240327	14179A	PARTICIPANT	\N	PRESENT	0
258267	240327	19483C	PARTICIPANT	\N	PRESENT	0
258268	240327	14357A	PARTICIPANT	\N	PRESENT	0
258269	240327	14331P	PARTICIPANT	\N	PRESENT	0
258270	240327	14257W	PARTICIPANT	\N	PRESENT	0
258271	240327	14030Q	PARTICIPANT	\N	PRESENT	0
258272	240327	14063N	PARTICIPANT	\N	PRESENT	0
258273	240327	19619A	PARTICIPANT	\N	PRESENT	0
258274	240327	19549D	PARTICIPANT	\N	PRESENT	0
258275	240327	11043H	PARTICIPANT	\N	PRESENT	0
258276	240327	19413M	PARTICIPANT	\N	PRESENT	0
258277	240327	19733B	PARTICIPANT	\N	PRESENT	0
258278	240327	11056N	PARTICIPANT	\N	PRESENT	0
258279	240327	08039A	PARTICIPANT	\N	PRESENT	0
258280	240327	01057W	PARTICIPANT	\N	PRESENT	0
258281	240327	14065Q	PARTICIPANT	\N	PRESENT	0
258282	240327	14109K	PARTICIPANT	\N	PRESENT	0
258283	240327	98050T	PARTICIPANT	\N	PRESENT	0
258285	258284	14205J	PARTICIPANT	\N	PRESENT	0
258286	258284	19703U	PARTICIPANT	\N	PRESENT	0
258287	258284	04071H	PARTICIPANT	\N	PRESENT	0
258288	258284	19443T	PARTICIPANT	\N	PRESENT	0
258289	258284	08034U	PARTICIPANT	\N	PRESENT	0
258290	258284	08058D	PRESIDENT	0	PRESENT	0
258291	258284	11049P	PARTICIPANT	\N	PRESENT	0
258292	258284	04085P	PARTICIPANT	\N	PRESENT	0
258293	258284	19729F	PARTICIPANT	\N	EXCUSE	0
258294	258284	19251M	PARTICIPANT	\N	EXCUSE	0
258295	240327	08011M	PARTICIPANT	\N	PRESENT	0
258296	240327	14111D	PARTICIPANT	\N	PRESENT	0
258297	240327	19729F	PARTICIPANT	\N	PRESENT	0
258298	240327	14069U	PARTICIPANT	\N	PRESENT	0
258299	240327	11027H	PARTICIPANT	\N	PRESENT	0
258300	240327	11054L	PARTICIPANT	\N	PRESENT	0
258301	240327	11067R	PARTICIPANT	\N	PRESENT	0
258302	240327	80013X	PARTICIPANT	\N	PRESENT	0
258303	240327	19697Q	PARTICIPANT	\N	PRESENT	0
258304	240327	14251Q	PARTICIPANT	\N	PRESENT	0
258305	240327	14121F	PARTICIPANT	\N	PRESENT	0
258306	240327	19631V	PARTICIPANT	\N	PRESENT	0
258307	240327	19253P	PARTICIPANT	\N	PRESENT	0
258316	240327	01048V	PARTICIPANT	\N	PRESENT	0
258317	240327	04070G	PARTICIPANT	\N	PRESENT	0
258334	240327	14231L	PARTICIPANT	\N	PRESENT	0
258335	240327	14327T	PARTICIPANT	\N	PRESENT	0
258336	240327	19553Y	PARTICIPANT	\N	PRESENT	0
258337	240327	04043D	PARTICIPANT	\N	PRESENT	0
258338	240327	14221J	PARTICIPANT	\N	PRESENT	0
258339	240327	14042U	PARTICIPANT	\N	PRESENT	0
258450	240328	04059M	PARTICIPANT	\N	PRESENT	0
258451	240328	14151M	PARTICIPANT	\N	PRESENT	0
258452	240328	07029T	PARTICIPANT	\N	PRESENT	0
258453	240328	07004J	PARTICIPANT	\N	PRESENT	0
258454	240328	14215L	PARTICIPANT	\N	PRESENT	0
258455	240328	04043D	PARTICIPANT	\N	PRESENT	0
258456	240328	04018C	PARTICIPANT	\N	PRESENT	0
258457	240328	08044W	PARTICIPANT	\N	PRESENT	0
258458	240328	14327T	PARTICIPANT	\N	PRESENT	0
258459	240328	14229S	PARTICIPANT	\N	PRESENT	0
258460	240328	11056N	PARTICIPANT	\N	PRESENT	0
258461	240328	19253P	PARTICIPANT	\N	PRESENT	0
258462	240328	19693L	PARTICIPANT	\N	PRESENT	0
258463	240328	08015R	PARTICIPANT	\N	PRESENT	0
258464	240328	19543W	PARTICIPANT	\N	PRESENT	0
258465	240328	19629C	PARTICIPANT	\N	PRESENT	0
258466	240328	14083S	PARTICIPANT	\N	PRESENT	0
258467	240328	05008E	PARTICIPANT	\N	PRESENT	0
258468	240328	11033F	PARTICIPANT	\N	PRESENT	0
258469	240328	14231L	PARTICIPANT	\N	PRESENT	0
258470	240328	14111D	PARTICIPANT	\N	PRESENT	0
258471	240328	19747H	PARTICIPANT	\N	PRESENT	0
258472	240328	11097X	PARTICIPANT	\N	PRESENT	0
258473	240328	04070G	PARTICIPANT	\N	PRESENT	0
258474	240328	19671E	PARTICIPANT	\N	PRESENT	0
258475	240328	17589D	PARTICIPANT	\N	PRESENT	0
258476	240328	19387D	PARTICIPANT	\N	PRESENT	0
258477	240328	19663E	PARTICIPANT	\N	PRESENT	0
258478	240328	19533U	PARTICIPANT	\N	PRESENT	0
258479	240328	08020N	PARTICIPANT	\N	PRESENT	0
258480	240328	19723Y	PARTICIPANT	\N	PRESENT	0
258481	240328	19447X	PARTICIPANT	\N	PRESENT	0
258482	240328	14179A	PARTICIPANT	\N	PRESENT	0
258483	240328	14069U	PARTICIPANT	\N	PRESENT	0
258484	240328	08043V	PARTICIPANT	\N	PRESENT	0
258485	240328	11012A	PARTICIPANT	\N	PRESENT	0
258486	240328	08034U	PARTICIPANT	\N	PRESENT	0
258487	240328	14219Q	PARTICIPANT	\N	PRESENT	0
258489	240328	11048N	PARTICIPANT	\N	PRESENT	0
258490	240328	14065Q	PARTICIPANT	\N	PRESENT	0
258491	240328	14147R	PARTICIPANT	\N	PRESENT	0
258492	258488	04070G	PARTICIPANT	\N	PRESENT	0
258493	258488	11109J	PARTICIPANT	\N	PRESENT	0
258494	258488	14030Q	PARTICIPANT	\N	PRESENT	0
258495	258488	08043V	PARTICIPANT	\N	PRESENT	0
258496	258488	19621T	PARTICIPANT	\N	PRESENT	0
258497	258488	87003B	PARTICIPANT	\N	PRESENT	0
258498	258488	14241N	PARTICIPANT	\N	PRESENT	0
258499	258488	14039A	PARTICIPANT	\N	PRESENT	0
241178	241177	19741B	PARTICIPANT	\N	PRESENT	0
241179	241177	14083S	PARTICIPANT	\N	PRESENT	0
241180	241177	14085U	PARTICIPANT	\N	PRESENT	0
241181	241177	04071H	PARTICIPANT	\N	PRESENT	0
241182	241177	11074Q	PARTICIPANT	\N	PRESENT	0
241183	241177	11048N	PARTICIPANT	\N	PRESENT	0
241184	241177	14121F	PARTICIPANT	\N	PRESENT	0
241185	241177	14159V	PARTICIPANT	\N	PRESENT	0
241186	241177	07029T	PARTICIPANT	\N	PRESENT	0
241187	241177	19711U	PARTICIPANT	\N	PRESENT	0
241188	241177	08010L	PARTICIPANT	\N	PRESENT	0
241189	241177	08034U	PARTICIPANT	\N	PRESENT	0
241190	241177	08011M	PARTICIPANT	\N	PRESENT	0
241191	241177	19671E	PARTICIPANT	\N	PRESENT	0
241192	241177	14253S	PARTICIPANT	\N	PRESENT	0
241193	241177	08073C	PARTICIPANT	\N	PRESENT	0
242459	241173	14053L	PARTICIPANT	\N	EXCUSE	0
242460	241367	04070G	PRESIDENT	0	PRESENT	0
242461	241367	19699S	PARTICIPANT	\N	PRESENT	0
242462	241367	19533U	PARTICIPANT	\N	PRESENT	0
242463	241367	95015C	PARTICIPANT	\N	PRESENT	0
242464	241367	19329S	PARTICIPANT	\N	PRESENT	0
242465	241367	04033B	PARTICIPANT	\N	PRESENT	0
242466	241367	14229S	PARTICIPANT	\N	PRESENT	0
242467	241367	14039A	PARTICIPANT	\N	PRESENT	0
242468	241367	14107H	PARTICIPANT	\N	PRESENT	0
242469	241367	08017T	PARTICIPANT	\N	PRESENT	0
242470	241367	08012N	PARTICIPANT	\N	PRESENT	0
242471	241367	08016S	PARTICIPANT	\N	PRESENT	0
242472	241367	08039A	PARTICIPANT	\N	PRESENT	0
242473	241367	08031R	PARTICIPANT	\N	PRESENT	0
242474	241367	19593H	PARTICIPANT	\N	PRESENT	0
242475	241367	14059S	PARTICIPANT	\N	PRESENT	0
242476	241367	19643A	PARTICIPANT	\N	PRESENT	0
242477	241367	14061L	PARTICIPANT	\N	PRESENT	0
242478	241367	04057K	PARTICIPANT	\N	PRESENT	0
242479	241367	08035V	PARTICIPANT	\N	PRESENT	0
242480	241367	19611R	PARTICIPANT	\N	PRESENT	0
242481	241367	19693L	PARTICIPANT	\N	PRESENT	0
242482	241367	19399H	PARTICIPANT	\N	PRESENT	0
242483	241367	87003B	PARTICIPANT	\N	PRESENT	0
242484	241367	14030Q	PARTICIPANT	\N	PRESENT	0
242485	241367	19731Y	PARTICIPANT	\N	PRESENT	0
242486	241367	14251Q	PARTICIPANT	\N	PRESENT	0
242487	241367	04059M	PARTICIPANT	\N	PRESENT	0
242488	241367	14063N	PARTICIPANT	\N	PRESENT	0
242489	241367	14109K	PARTICIPANT	\N	PRESENT	0
242490	241367	14123H	PARTICIPANT	\N	PRESENT	0
242491	241367	11104D	PARTICIPANT	\N	PRESENT	0
242492	241367	11043H	PARTICIPANT	\N	PRESENT	0
242493	241367	19749K	PARTICIPANT	\N	PRESENT	0
242494	241367	04018C	PARTICIPANT	\N	PRESENT	0
242495	241367	19621T	PARTICIPANT	\N	PRESENT	0
242496	241173	19673G	PARTICIPANT	\N	EXCUSE	0
242497	241173	14111D	PARTICIPANT	\N	PRESENT	0
242498	241173	14275Y	PARTICIPANT	\N	PRESENT	0
242499	241173	14069U	PARTICIPANT	\N	PRESENT	0
242500	241173	19543W	PARTICIPANT	\N	PRESENT	0
242501	241173	04044E	PARTICIPANT	\N	PRESENT	0
242502	241173	19447X	PARTICIPANT	\N	PRESENT	0
242503	241173	14231L	PARTICIPANT	\N	PRESENT	0
242504	241173	11010L	PARTICIPANT	\N	PRESENT	0
242505	241173	01024M	PARTICIPANT	\N	PRESENT	0
242506	241173	04038G	PARTICIPANT	\N	PRESENT	0
242507	241173	19585H	PARTICIPANT	\N	PRESENT	0
242508	241173	04047H	PARTICIPANT	\N	PRESENT	0
242509	241173	11033F	PARTICIPANT	\N	PRESENT	0
242510	241173	19729F	PARTICIPANT	\N	PRESENT	0
242511	241173	95063L	PARTICIPANT	\N	PRESENT	0
242512	241173	14041T	PARTICIPANT	\N	PRESENT	0
242513	241173	14147R	PARTICIPANT	\N	PRESENT	0
242514	241173	14215L	PARTICIPANT	\N	PRESENT	0
242515	241173	98035U	PARTICIPANT	\N	PRESENT	0
242516	241173	14001X	PARTICIPANT	\N	PRESENT	0
242517	241173	19581D	PARTICIPANT	\N	PRESENT	0
242518	241173	01028R	PARTICIPANT	\N	PRESENT	0
242519	241173	14151M	PARTICIPANT	\N	PRESENT	0
242520	241173	19483C	PARTICIPANT	\N	PRESENT	0
242521	241490	14097Y	PARTICIPANT	\N	PRESENT	0
242522	241490	95037J	PARTICIPANT	\N	PRESENT	0
242523	241490	19443T	PARTICIPANT	\N	PRESENT	0
242524	241490	19421M	PARTICIPANT	\N	PRESENT	0
242525	241490	14235Q	PARTICIPANT	\N	PRESENT	0
242526	241490	19709B	PARTICIPANT	\N	PRESENT	0
242527	241490	97011G	PARTICIPANT	\N	PRESENT	0
242528	241490	11066Q	PARTICIPANT	\N	PRESENT	0
242529	241367	12041X	PARTICIPANT	\N	PRESENT	0
242530	241367	92040Q	PARTICIPANT	\N	PRESENT	0
242531	241367	14249W	PARTICIPANT	\N	PRESENT	0
242532	241367	14073Q	PARTICIPANT	\N	PRESENT	0
242533	241367	08043V	PARTICIPANT	\N	PRESENT	0
242534	241367	08020N	PARTICIPANT	\N	PRESENT	0
242535	241367	19735D	PARTICIPANT	\N	PRESENT	0
242536	241367	11109J	PARTICIPANT	\N	PRESENT	0
242537	241367	11083R	PARTICIPANT	\N	PRESENT	0
242561	241490	11041F	PARTICIPANT	\N	PRESENT	0
242562	241490	14255U	PARTICIPANT	\N	PRESENT	0
242563	241173	01060R	PARTICIPANT	\N	PRESENT	0
242564	241173	05008E	PRESIDENT	0	PRESENT	0
242565	241173	19489J	PARTICIPANT	\N	PRESENT	0
242566	241173	14179A	PARTICIPANT	\N	PRESENT	0
242567	241173	19649G	PARTICIPANT	\N	PRESENT	0
242568	241173	14065Q	PARTICIPANT	\N	PRESENT	0
242569	241173	08045X	PARTICIPANT	\N	PRESENT	0
242570	241173	10015M	PARTICIPANT	\N	PRESENT	0
242571	241173	07034Q	PARTICIPANT	\N	PRESENT	0
242572	241173	19725B	PARTICIPANT	\N	PRESENT	0
242573	241173	14089Y	PARTICIPANT	\N	PRESENT	0
242574	241173	19319Q	PARTICIPANT	\N	PRESENT	0
242575	241173	08044W	PARTICIPANT	\N	PRESENT	0
242576	241173	11085T	PARTICIPANT	\N	PRESENT	0
242577	241173	11049P	PARTICIPANT	\N	PRESENT	0
242578	241173	04008A	PARTICIPANT	\N	PRESENT	0
242579	241173	14021P	PARTICIPANT	\N	PRESENT	0
242580	241490	04035D	PARTICIPANT	\N	PRESENT	0
242604	241173	08018U	PARTICIPANT	\N	PRESENT	0
242609	241490	19669L	PARTICIPANT	\N	PRESENT	0
242614	241269	14331P	PARTICIPANT	\N	PRESENT	0
242615	241269	19479G	PARTICIPANT	\N	PRESENT	0
242616	241269	11048N	PARTICIPANT	\N	PRESENT	0
242617	241269	19711U	PARTICIPANT	\N	PRESENT	0
242618	241269	19531S	PARTICIPANT	\N	PRESENT	0
242619	241269	08034U	PARTICIPANT	\N	PRESENT	0
242620	241269	01048V	PARTICIPANT	\N	PRESENT	0
242621	241269	01057W	PARTICIPANT	\N	PRESENT	0
242622	241269	11053K	PARTICIPANT	\N	PRESENT	0
242623	241269	08011M	PARTICIPANT	\N	PRESENT	0
242624	241269	89017R	PARTICIPANT	\N	PRESENT	0
242625	241269	11074Q	PRESIDENT	0	PRESENT	0
242626	241269	08014Q	PARTICIPANT	\N	PRESENT	0
242628	241269	14173T	PARTICIPANT	\N	PRESENT	0
242629	241269	04086Q	PARTICIPANT	\N	PRESENT	0
242630	241269	14083S	PARTICIPANT	\N	PRESENT	0
242631	241269	14085U	PARTICIPANT	\N	PRESENT	0
242632	241269	14277B	PARTICIPANT	\N	PRESENT	0
242633	241269	19349W	PARTICIPANT	\N	PRESENT	0
242634	241269	14121F	PARTICIPANT	\N	PRESENT	0
242635	241269	08010L	PARTICIPANT	\N	PRESENT	0
242636	241269	11040E	PARTICIPANT	\N	PRESENT	0
242637	241269	14327T	PARTICIPANT	\N	EXCUSE	0
242638	241269	07029T	PARTICIPANT	\N	EXCUSE	0
242639	241269	04071H	PARTICIPANT	\N	EXCUSE	0
242640	241269	95041E	PARTICIPANT	\N	EXCUSE	0
242641	241269	07004J	PARTICIPANT	\N	EXCUSE	0
242642	241490	16685X	PARTICIPANT	\N	PRESENT	0
242651	241490	11115U	PARTICIPANT	\N	PRESENT	0
242652	241269	19741B	PARTICIPANT	\N	PRESENT	0
242657	239410	19697Q	PARTICIPANT	\N	PRESENT	0
242658	239410	11067R	PARTICIPANT	\N	PRESENT	0
242659	239410	11077T	PARTICIPANT	\N	PRESENT	0
242660	239410	11097X	PARTICIPANT	\N	PRESENT	0
242661	239410	19415P	PARTICIPANT	\N	PRESENT	0
242662	239410	04045F	PARTICIPANT	\N	PRESENT	0
242663	239410	14026U	PARTICIPANT	\N	PRESENT	0
242664	239410	17779H	PARTICIPANT	\N	PRESENT	0
242665	239410	11063M	PARTICIPANT	\N	PRESENT	0
242666	239410	19703U	PARTICIPANT	\N	PRESENT	0
242667	239410	19679N	PARTICIPANT	\N	PRESENT	0
242668	239410	19575F	PARTICIPANT	\N	PRESENT	0
242669	239410	14195A	PARTICIPANT	\N	PRESENT	0
242670	239410	14213J	PARTICIPANT	\N	PRESENT	0
242671	239410	14217N	PARTICIPANT	\N	PRESENT	0
242672	239410	19683J	PARTICIPANT	\N	PRESENT	0
242673	239410	98024R	PARTICIPANT	\N	PRESENT	0
242674	239410	19521Q	PARTICIPANT	\N	PRESENT	0
242675	239410	19527W	PARTICIPANT	\N	PRESENT	0
242676	239410	01034P	PARTICIPANT	\N	PRESENT	0
242677	239410	04092N	PRESIDENT	0	PRESENT	0
266974	258933	11027H	PARTICIPANT	\N	PRESENT	0
267629	267402	14065Q	PARTICIPANT	\N	PRESENT	0
267630	267402	11026G	PARTICIPANT	\N	PRESENT	0
267631	267402	19253P	PARTICIPANT	\N	PRESENT	0
267632	267402	01024M	PARTICIPANT	\N	PRESENT	0
267633	267402	19585H	PARTICIPANT	\N	PRESENT	0
267634	267402	04047H	PARTICIPANT	\N	PRESENT	0
267635	267402	01028R	PARTICIPANT	\N	PRESENT	0
267636	267402	11033F	PARTICIPANT	\N	PRESENT	0
267637	267402	05008E	PRESIDENT	0	PRESENT	0
267638	267402	19447X	PARTICIPANT	\N	PRESENT	0
267639	267402	19489J	PARTICIPANT	\N	PRESENT	0
267640	267402	95063L	PARTICIPANT	\N	PRESENT	0
267641	267402	19629C	PARTICIPANT	\N	PRESENT	0
267642	267402	14041T	PARTICIPANT	\N	PRESENT	0
267643	267402	08044W	PARTICIPANT	\N	PRESENT	0
267644	267402	14147R	PARTICIPANT	\N	PRESENT	0
267645	267402	14151M	PARTICIPANT	\N	PRESENT	0
267646	267402	08018U	PARTICIPANT	\N	PRESENT	0
267647	267402	11049P	PARTICIPANT	\N	PRESENT	0
267648	267402	14089Y	PARTICIPANT	\N	PRESENT	0
267649	267402	07034Q	PARTICIPANT	\N	PRESENT	0
267650	267402	08045X	PARTICIPANT	\N	PRESENT	0
267651	267402	14179A	PARTICIPANT	\N	PRESENT	0
267652	267402	14069U	PARTICIPANT	\N	PRESENT	0
267653	267402	19543W	PARTICIPANT	\N	PRESENT	0
267654	267402	04044E	PARTICIPANT	\N	PRESENT	0
267655	267402	04038G	PARTICIPANT	\N	PRESENT	0
267665	263168	11072N	PARTICIPANT	\N	PRESENT	0
267679	263168	14219Q	PARTICIPANT	\N	PRESENT	0
267680	263168	19553Y	PARTICIPANT	\N	PRESENT	0
267681	263168	14069U	PARTICIPANT	\N	PRESENT	0
267682	263168	19731Y	PARTICIPANT	\N	PRESENT	0
267683	263168	08055A	PARTICIPANT	\N	PRESENT	0
267684	263168	04038G	PARTICIPANT	\N	PRESENT	0
267685	263168	19525U	PARTICIPANT	\N	PRESENT	0
267686	263168	07029T	PARTICIPANT	\N	PRESENT	0
267687	263168	19543W	PARTICIPANT	\N	PRESENT	0
267688	263168	14257W	PARTICIPANT	\N	PRESENT	0
267689	263168	19583F	PARTICIPANT	\N	PRESENT	0
267690	263168	19467C	PARTICIPANT	\N	PRESENT	0
267691	263168	14265W	PARTICIPANT	\N	PRESENT	0
267692	263168	19679N	PARTICIPANT	\N	PRESENT	0
267693	263168	19725B	PARTICIPANT	\N	PRESENT	0
267694	263168	19479G	PARTICIPANT	\N	PRESENT	0
267695	263168	19629C	PARTICIPANT	\N	PRESENT	0
267696	263168	19507S	PARTICIPANT	\N	PRESENT	0
267697	263168	14207L	PARTICIPANT	\N	PRESENT	0
267698	263168	19681G	PARTICIPANT	\N	PRESENT	0
267699	263168	19739H	PARTICIPANT	\N	PRESENT	0
267700	263168	11103C	PARTICIPANT	\N	PRESENT	0
267701	263168	19715Y	PARTICIPANT	\N	PRESENT	0
267702	263168	19347U	PARTICIPANT	\N	PRESENT	0
267703	263168	19399H	PARTICIPANT	\N	PRESENT	0
267704	263168	19631V	PARTICIPANT	\N	PRESENT	0
267705	263168	14107H	PARTICIPANT	\N	PRESENT	0
267706	263168	11066Q	PARTICIPANT	\N	PRESENT	0
267707	263168	19349W	PARTICIPANT	\N	PRESENT	0
267708	263168	19737F	PARTICIPANT	\N	PRESENT	0
267709	263168	08049C	PARTICIPANT	\N	PRESENT	0
267710	263168	01028R	PARTICIPANT	\N	PRESENT	0
267711	263168	19489J	PARTICIPANT	\N	PRESENT	0
267712	263168	11056N	PARTICIPANT	\N	PRESENT	0
267713	263168	14121F	PARTICIPANT	\N	PRESENT	0
267714	263168	01062T	PARTICIPANT	\N	PRESENT	0
267715	263168	19441R	PARTICIPANT	\N	PRESENT	0
267716	263168	19749K	PARTICIPANT	\N	PRESENT	0
267717	263168	19575F	PARTICIPANT	\N	PRESENT	0
267718	263168	14030Q	PARTICIPANT	\N	PRESENT	0
267719	263168	14327T	PARTICIPANT	\N	PRESENT	0
267720	263168	14259Y	PARTICIPANT	\N	PRESENT	0
267721	263168	14083S	PARTICIPANT	\N	PRESENT	0
267722	263168	08016S	PARTICIPANT	\N	PRESENT	0
267723	263168	14041T	PARTICIPANT	\N	PRESENT	0
267724	263168	04049K	PARTICIPANT	\N	PRESENT	0
267725	263168	14231L	PARTICIPANT	\N	PRESENT	0
267726	263168	08039A	PARTICIPANT	\N	PRESENT	0
267727	263168	08020N	PARTICIPANT	\N	PRESENT	0
267728	263168	11043H	PARTICIPANT	\N	PRESENT	0
267729	263168	14199E	PARTICIPANT	\N	PRESENT	0
267730	263168	18083K	PARTICIPANT	\N	PRESENT	0
267731	263168	19533U	PARTICIPANT	\N	PRESENT	0
267732	263168	19383Y	PARTICIPANT	\N	PRESENT	0
267733	263168	19701S	PARTICIPANT	\N	PRESENT	0
267734	263168	04018C	PARTICIPANT	\N	PRESENT	0
267735	263168	19367Y	PARTICIPANT	\N	PRESENT	0
267736	263168	19621T	PARTICIPANT	\N	PRESENT	0
267737	263168	14079W	PARTICIPANT	\N	PRESENT	0
267738	263168	19719D	PARTICIPANT	\N	PRESENT	0
267739	263168	19585H	PARTICIPANT	\N	PRESENT	0
267740	263168	14281W	PARTICIPANT	\N	PRESENT	0
267741	263168	80027E	PARTICIPANT	\N	PRESENT	0
267742	263168	19565D	PARTICIPANT	\N	PRESENT	0
267743	263168	19667J	PARTICIPANT	\N	PRESENT	0
267747	263168	11067R	PARTICIPANT	\N	PRESENT	0
267745	263168	95063L	PARTICIPANT	\N	PRESENT	0
267746	263168	11040E	PARTICIPANT	\N	PRESENT	0
267748	263168	14089Y	PARTICIPANT	\N	PRESENT	0
267749	263168	19573D	PARTICIPANT	\N	PRESENT	0
267750	263168	05008E	PARTICIPANT	\N	PRESENT	0
267751	263168	08010L	PARTICIPANT	\N	PRESENT	0
267752	263168	11048N	PARTICIPANT	\N	PRESENT	0
267753	263168	87003B	PARTICIPANT	\N	PRESENT	0
267754	263168	14034U	PARTICIPANT	\N	PRESENT	0
267755	263168	19387D	PARTICIPANT	\N	PRESENT	0
267756	263168	08014Q	PARTICIPANT	\N	PRESENT	0
267757	263168	14157T	PARTICIPANT	\N	PRESENT	0
267758	263168	14187A	PARTICIPANT	\N	PRESENT	0
267759	263168	19521Q	PARTICIPANT	\N	PRESENT	0
267760	263168	14267Y	PARTICIPANT	\N	PRESENT	0
267761	263168	08056B	PARTICIPANT	\N	PRESENT	0
267762	263168	01057W	PARTICIPANT	\N	PRESENT	0
267763	263168	19335Q	PARTICIPANT	\N	PRESENT	0
267764	263168	14001X	PARTICIPANT	\N	PRESENT	0
267765	263168	14179A	PARTICIPANT	\N	PRESENT	0
267766	263168	19727D	PARTICIPANT	\N	PRESENT	0
267767	263168	08053X	PARTICIPANT	\N	PRESENT	0
267768	263168	19581D	PARTICIPANT	\N	PRESENT	0
267769	263168	11110B	PARTICIPANT	\N	PRESENT	0
267770	263168	19713W	PARTICIPANT	\N	PRESENT	0
267771	263168	08044W	PARTICIPANT	\N	PRESENT	0
267772	263168	14087W	PARTICIPANT	\N	PRESENT	0
267773	263168	14235Q	PARTICIPANT	\N	PRESENT	0
267774	263168	01060R	PARTICIPANT	\N	PRESENT	0
267775	263168	95041E	PARTICIPANT	\N	PRESENT	0
267776	263168	19697Q	PARTICIPANT	\N	PRESENT	0
267777	263168	19643A	PARTICIPANT	\N	PRESENT	0
267778	263168	08017T	PARTICIPANT	\N	PRESENT	0
267779	263168	14053L	PARTICIPANT	\N	PRESENT	0
267780	263168	01024M	PARTICIPANT	\N	PRESENT	0
267781	263168	08045X	PARTICIPANT	\N	PRESENT	0
267782	263168	14109K	PARTICIPANT	\N	PRESENT	0
267783	263168	14065Q	PARTICIPANT	\N	PRESENT	0
267784	263168	11104D	PARTICIPANT	\N	PRESENT	0
267785	263168	14147R	PARTICIPANT	\N	PRESENT	0
267786	263168	14042U	PARTICIPANT	\N	PRESENT	0
267787	263168	19745F	PARTICIPANT	\N	PRESENT	0
267788	263168	14021P	PARTICIPANT	\N	PRESENT	0
267789	263168	14151M	PARTICIPANT	\N	PRESENT	0
267790	263168	19551W	PARTICIPANT	\N	PRESENT	0
267791	263168	19741B	PARTICIPANT	\N	PRESENT	0
267792	263168	14038Y	PARTICIPANT	\N	PRESENT	0
267793	263168	19289C	PARTICIPANT	\N	PRESENT	0
267794	263168	98022P	PARTICIPANT	\N	PRESENT	0
267795	263168	11064N	PARTICIPANT	\N	PRESENT	0
267796	263168	19721W	PARTICIPANT	\N	PRESENT	0
267797	263168	08061X	PARTICIPANT	\N	PRESENT	0
267798	263168	19527W	PARTICIPANT	\N	PRESENT	0
267800	263168	19723Y	PARTICIPANT	\N	PRESENT	0
267801	263168	19447X	PARTICIPANT	\N	PRESENT	0
267803	263168	19503N	PARTICIPANT	\N	PRESENT	0
267806	267024	08024S	PARTICIPANT	\N	EXCUSE	0
267807	267024	19599P	PARTICIPANT	\N	EXCUSE	0
267808	263168	14211G	PARTICIPANT	\N	PRESENT	0
267809	263168	95062K	PARTICIPANT	\N	PRESENT	0
267810	263168	04059M	PARTICIPANT	\N	PRESENT	0
267811	263168	14223L	PARTICIPANT	\N	PRESENT	0
267812	263168	14028W	PARTICIPANT	\N	PRESENT	0
267813	263168	14217N	PARTICIPANT	\N	PRESENT	0
267814	263168	11012A	PARTICIPANT	\N	PRESENT	0
267815	263168	04047H	PARTICIPANT	\N	PRESENT	0
267816	263168	10006L	PARTICIPANT	\N	PRESENT	0
267824	263168	17583W	PARTICIPANT	\N	PRESENT	0
267825	263168	08069G	PARTICIPANT	\N	PRESENT	0
267826	267024	18083K	PARTICIPANT	\N	PRESENT	0
267827	267024	14038Y	PARTICIPANT	\N	PRESENT	0
267828	267024	08060W	PARTICIPANT	\N	PRESENT	0
267829	267024	19701S	PARTICIPANT	\N	PRESENT	0
267830	267024	08009T	PRESIDENT	0	PRESENT	0
242538	241490	98005N	PARTICIPANT	\N	PRESENT	0
242539	241490	95030B	PARTICIPANT	\N	PRESENT	0
242540	241490	11080N	PARTICIPANT	\N	PRESENT	0
242541	241490	04034C	PARTICIPANT	\N	PRESENT	0
242542	241490	14079W	PARTICIPANT	\N	PRESENT	0
242543	241490	04040A	PARTICIPANT	\N	PRESENT	0
242544	241490	01058X	PARTICIPANT	\N	PRESENT	0
242545	241490	11027H	PARTICIPANT	\N	PRESENT	0
242546	241490	04042C	PRESIDENT	0	PRESENT	0
242547	241490	11054L	PARTICIPANT	\N	PRESENT	0
242548	241490	08053X	PARTICIPANT	\N	PRESENT	0
242549	241490	08061X	PARTICIPANT	\N	PRESENT	0
242550	241490	08047A	PARTICIPANT	\N	PRESENT	0
242551	241490	14133K	PARTICIPANT	\N	PRESENT	0
242552	241490	08058D	PARTICIPANT	\N	PRESENT	0
242553	241490	19251M	PARTICIPANT	\N	PRESENT	0
242554	241490	19721W	PARTICIPANT	\N	PRESENT	0
242555	241490	14105F	PARTICIPANT	\N	PRESENT	0
242556	241490	98018T	PARTICIPANT	\N	PRESENT	0
242557	241490	14267Y	PARTICIPANT	\N	PRESENT	0
242558	241490	11064N	PARTICIPANT	\N	PRESENT	0
242559	241490	98050T	PARTICIPANT	\N	PRESENT	0
242560	241490	14211G	PARTICIPANT	\N	PRESENT	0
242732	241494	98005N	PARTICIPANT	\N	PRESENT	0
242733	241494	19443T	PARTICIPANT	\N	PRESENT	0
242734	241494	95030B	PARTICIPANT	\N	PRESENT	0
242735	241494	11080N	PARTICIPANT	\N	PRESENT	0
242736	241494	04034C	PARTICIPANT	\N	PRESENT	0
242737	241494	14079W	PARTICIPANT	\N	PRESENT	0
242738	241494	04040A	PARTICIPANT	\N	PRESENT	0
242739	241494	01058X	PARTICIPANT	\N	PRESENT	0
242740	241494	11027H	PARTICIPANT	\N	PRESENT	0
242741	241494	16685X	PARTICIPANT	\N	PRESENT	0
242742	241494	04042C	PRESIDENT	0	PRESENT	0
242743	241494	11054L	PARTICIPANT	\N	PRESENT	0
242744	241494	11066Q	PARTICIPANT	\N	PRESENT	0
242745	241494	19669L	PARTICIPANT	\N	PRESENT	0
242746	241494	95037J	PARTICIPANT	\N	PRESENT	0
242747	241494	11115U	PARTICIPANT	\N	PRESENT	0
242748	241494	19421M	PARTICIPANT	\N	PRESENT	0
242749	241494	19709B	PARTICIPANT	\N	PRESENT	0
242750	241494	08053X	PARTICIPANT	\N	PRESENT	0
242751	241494	97011G	PARTICIPANT	\N	PRESENT	0
242752	241494	08061X	PARTICIPANT	\N	PRESENT	0
242753	241494	08047A	PARTICIPANT	\N	PRESENT	0
242754	241494	14097Y	PARTICIPANT	\N	PRESENT	0
242755	241494	04035D	PARTICIPANT	\N	PRESENT	0
242756	241494	14133K	PARTICIPANT	\N	PRESENT	0
242757	241494	11041F	PARTICIPANT	\N	PRESENT	0
242758	241494	14235Q	PARTICIPANT	\N	PRESENT	0
242759	241494	08058D	PARTICIPANT	\N	PRESENT	0
242760	241494	19251M	PARTICIPANT	\N	PRESENT	0
242761	241494	19721W	PARTICIPANT	\N	PRESENT	0
242762	241494	14105F	PARTICIPANT	\N	PRESENT	0
242763	241494	98018T	PARTICIPANT	\N	PRESENT	0
242764	241494	98022P	PARTICIPANT	\N	PRESENT	0
242765	241494	14267Y	PARTICIPANT	\N	PRESENT	0
242766	241494	11064N	PARTICIPANT	\N	PRESENT	0
242767	241494	98050T	PARTICIPANT	\N	PRESENT	0
242768	241494	14211G	PARTICIPANT	\N	PRESENT	0
242769	241494	14255U	PARTICIPANT	\N	PRESENT	0
242871	241267	19737F	PARTICIPANT	\N	PRESENT	0
247121	247119	19251M	PARTICIPANT	\N	PRESENT	0
247122	247119	08035V	PARTICIPANT	\N	PRESENT	0
242983	241276	11048N	PRESIDENT	0	PRESENT	0
242984	241276	14103D	PARTICIPANT	\N	PRESENT	0
242985	241276	11067R	PARTICIPANT	\N	PRESENT	0
242986	241276	19479G	PARTICIPANT	\N	PRESENT	0
242987	241276	19515S	PARTICIPANT	\N	PRESENT	0
242988	241276	19711U	PARTICIPANT	\N	PRESENT	0
242989	241276	14187A	PARTICIPANT	\N	PRESENT	0
242990	241276	14031R	PARTICIPANT	\N	PRESENT	0
242991	241276	19689Q	PARTICIPANT	\N	PRESENT	0
242992	241276	01024M	PARTICIPANT	\N	PRESENT	0
242993	241276	14026U	PARTICIPANT	\N	PRESENT	0
242994	241276	19573D	PARTICIPANT	\N	PRESENT	0
242995	241276	19503N	PARTICIPANT	\N	PRESENT	0
242996	241276	14069U	PARTICIPANT	\N	PRESENT	0
242997	241276	14151M	PARTICIPANT	\N	PRESENT	0
242998	241276	08053X	PARTICIPANT	\N	PRESENT	0
242999	241276	14157T	PARTICIPANT	\N	PRESENT	0
243000	241276	14207L	PARTICIPANT	\N	PRESENT	0
243001	241276	19749K	PARTICIPANT	\N	PRESENT	0
247123	247119	08034U	PARTICIPANT	\N	PRESENT	0
247124	247119	19443T	PARTICIPANT	\N	PRESENT	0
247125	247119	08058D	PRESIDENT	0	PRESENT	0
247126	247119	11049P	PARTICIPANT	\N	PRESENT	0
247128	247127	14030Q	PARTICIPANT	\N	PRESENT	0
247129	247127	19467C	PARTICIPANT	\N	PRESENT	0
247130	247127	08015R	PARTICIPANT	\N	PRESENT	0
247131	247127	01043Q	PARTICIPANT	\N	PRESENT	0
247132	247127	14225N	PARTICIPANT	\N	PRESENT	0
247133	247127	14001X	PARTICIPANT	\N	PRESENT	0
253527	253526	08044W	PARTICIPANT	\N	PRESENT	0
253538	253493	19479G	PARTICIPANT	\N	PRESENT	0
253539	253493	04049K	PARTICIPANT	\N	PRESENT	0
253727	240316	12041X	PARTICIPANT	\N	PRESENT	0
253728	240316	11063M	PARTICIPANT	\N	PRESENT	0
253729	240316	86034E	PARTICIPANT	\N	PRESENT	0
253730	240316	11040E	PARTICIPANT	\N	PRESENT	0
253731	240316	19515S	PARTICIPANT	\N	PRESENT	0
253732	240316	14235Q	PARTICIPANT	\N	PRESENT	0
253733	240316	19565D	PARTICIPANT	\N	PRESENT	0
253734	240316	14211G	PARTICIPANT	\N	PRESENT	0
253735	240316	17637T	PARTICIPANT	\N	PRESENT	0
253736	240316	04085P	PARTICIPANT	\N	PRESENT	0
253737	240316	11031D	PARTICIPANT	\N	PRESENT	0
253738	240316	19711U	PARTICIPANT	\N	PRESENT	0
253739	240316	04008A	PARTICIPANT	\N	PRESENT	0
253740	240316	08011M	PARTICIPANT	\N	PRESENT	0
253741	240316	19593H	PARTICIPANT	\N	PRESENT	0
253742	240316	95062K	PARTICIPANT	\N	PRESENT	0
253743	240316	19697Q	PARTICIPANT	\N	PRESENT	0
253571	253561	08014Q	PARTICIPANT	\N	PRESENT	0
253572	253561	08069G	PARTICIPANT	\N	PRESENT	0
253744	240316	04097T	PARTICIPANT	\N	PRESENT	0
253745	240316	95037J	PARTICIPANT	\N	PRESENT	0
253746	240316	01058X	PARTICIPANT	\N	PRESENT	0
253747	240316	04034C	PARTICIPANT	\N	PRESENT	0
253748	240316	08010L	PARTICIPANT	\N	PRESENT	0
253749	240316	04045F	PARTICIPANT	\N	PRESENT	0
253750	240316	19651A	PARTICIPANT	\N	PRESENT	0
253752	240316	96004D	PARTICIPANT	\N	PRESENT	0
253754	240316	19349W	PARTICIPANT	\N	PRESENT	0
253755	240316	19637C	PARTICIPANT	\N	PRESENT	0
253756	240316	19543W	PARTICIPANT	\N	PRESENT	0
253757	240316	99004R	PARTICIPANT	\N	PRESENT	0
253758	240316	08021P	PARTICIPANT	\N	PRESENT	0
253792	240316	14111D	PARTICIPANT	\N	PRESENT	0
243259	241276	14041T	PARTICIPANT	\N	PRESENT	0
243260	241276	19651A	PARTICIPANT	\N	EXCUSE	0
253793	240316	19545Y	PARTICIPANT	\N	PRESENT	0
253906	253897	08069G	PARTICIPANT	\N	PRESENT	0
253907	253897	08014Q	PARTICIPANT	\N	PRESENT	0
254025	254024	14205J	PARTICIPANT	\N	PRESENT	0
254026	254024	11083R	PARTICIPANT	\N	PRESENT	0
254027	254024	14001X	PARTICIPANT	\N	PRESENT	0
254028	254024	96004D	PARTICIPANT	\N	PRESENT	0
254029	254024	95030B	PARTICIPANT	\N	PRESENT	0
254030	254024	08053X	PARTICIPANT	\N	PRESENT	0
254031	254024	08049C	PARTICIPANT	\N	PRESENT	0
246410	246408	11066Q	PARTICIPANT	\N	PRESENT	0
247120	247119	04085P	PARTICIPANT	\N	PRESENT	0
254482	240317	80013X	PARTICIPANT	\N	PRESENT	0
254483	240317	12016W	PARTICIPANT	\N	PRESENT	0
254484	240317	19651A	PARTICIPANT	\N	PRESENT	0
254485	240317	19335Q	PARTICIPANT	\N	PRESENT	0
254486	240317	04018C	PARTICIPANT	\N	PRESENT	0
254487	253499	08056B	PARTICIPANT	\N	PRESENT	0
254488	253499	19421M	PARTICIPANT	\N	PRESENT	0
254489	253499	98022P	PARTICIPANT	\N	PRESENT	0
254490	253499	10015M	PARTICIPANT	\N	PRESENT	0
254491	253499	19575F	PARTICIPANT	\N	PRESENT	0
254492	253499	08010L	PARTICIPANT	\N	PRESENT	0
254493	253499	19673G	PARTICIPANT	\N	PRESENT	0
254494	253499	98029W	PRESIDENT	0	PRESENT	0
254495	253499	11080N	PARTICIPANT	\N	EXCUSE	0
254496	240317	14215L	PARTICIPANT	\N	PRESENT	0
254497	253496	11080N	PARTICIPANT	\N	EXCUSE	0
254498	240317	14031R	PARTICIPANT	\N	PRESENT	0
254499	240317	14147R	PARTICIPANT	\N	PRESENT	0
254500	240317	97011G	PARTICIPANT	\N	PRESENT	0
254501	240317	19533U	PARTICIPANT	\N	PRESENT	0
254502	240317	10006L	PARTICIPANT	\N	PRESENT	0
254503	240317	14331P	PARTICIPANT	\N	PRESENT	0
254504	240317	14097Y	PARTICIPANT	\N	PRESENT	0
254505	240317	19503N	PARTICIPANT	\N	PRESENT	0
254506	240317	11067R	PARTICIPANT	\N	PRESENT	0
254507	240317	04045F	PARTICIPANT	\N	PRESENT	0
258502	258488	19611R	PARTICIPANT	\N	PRESENT	0
258503	258488	14059S	PARTICIPANT	\N	PRESENT	0
258504	258488	08012N	PARTICIPANT	\N	PRESENT	0
258505	258488	14063N	PARTICIPANT	\N	PRESENT	0
258506	258488	14109K	PARTICIPANT	\N	PRESENT	0
258507	258488	19533U	PARTICIPANT	\N	PRESENT	0
258508	258488	19735D	PARTICIPANT	\N	PRESENT	0
258509	258488	14229S	PARTICIPANT	\N	PRESENT	0
258510	258488	11043H	PARTICIPANT	\N	PRESENT	0
258511	258488	04018C	PARTICIPANT	\N	PRESENT	0
258512	258488	19749K	PARTICIPANT	\N	PRESENT	0
258513	258488	19573D	PARTICIPANT	\N	PRESENT	0
258514	240328	14073Q	PARTICIPANT	\N	PRESENT	0
258523	240328	19749K	PARTICIPANT	\N	PRESENT	0
258524	240328	14193X	PARTICIPANT	\N	PRESENT	0
258525	240328	11072N	PARTICIPANT	\N	PRESENT	0
258526	240328	19741B	PARTICIPANT	\N	PRESENT	0
258527	258248	14133K	PARTICIPANT	\N	PRESENT	0
258528	258248	14065Q	PARTICIPANT	\N	PRESENT	0
258529	258248	96004D	PRESIDENT	0	PRESENT	0
258530	258248	14089Y	PARTICIPANT	\N	PRESENT	0
258531	258248	14079W	PARTICIPANT	\N	EXCUSE	0
258532	258248	08018U	PARTICIPANT	\N	EXCUSE	0
258533	258248	04035D	PARTICIPANT	\N	PRESENT	0
258534	258248	11083R	PARTICIPANT	\N	PRESENT	0
258535	258248	19553Y	PARTICIPANT	\N	PRESENT	0
258536	258248	04097T	PARTICIPANT	\N	PRESENT	0
258537	258248	14097Y	PARTICIPANT	\N	PRESENT	0
258538	258248	14061L	PARTICIPANT	\N	EXCUSE	0
258539	258248	14001X	PARTICIPANT	\N	PRESENT	0
258540	258248	14221J	PARTICIPANT	\N	PRESENT	0
258541	258248	04057K	PARTICIPANT	\N	PRESENT	0
258542	258248	19563B	PARTICIPANT	\N	EXCUSE	0
258543	258248	10015M	PARTICIPANT	\N	PRESENT	0
258544	258248	14073Q	PARTICIPANT	\N	PRESENT	0
258545	240328	14221J	PARTICIPANT	\N	PRESENT	0
258546	240328	14089Y	PARTICIPANT	\N	PRESENT	0
258547	240328	14053L	PARTICIPANT	\N	PRESENT	0
258548	240328	01028R	PARTICIPANT	\N	PRESENT	0
258549	240328	19593H	PARTICIPANT	\N	PRESENT	0
258550	240328	08031R	PARTICIPANT	\N	PRESENT	0
258551	240328	19631V	PARTICIPANT	\N	PRESENT	0
258552	240328	08061X	PARTICIPANT	\N	PRESENT	0
258590	240329	08044W	PARTICIPANT	\N	PRESENT	0
258591	240329	17589D	PARTICIPANT	\N	PRESENT	0
258592	240329	19593H	PARTICIPANT	\N	PRESENT	0
258593	240329	08031R	PARTICIPANT	\N	PRESENT	0
258594	240329	19629C	PARTICIPANT	\N	PRESENT	0
258595	240329	11012A	PARTICIPANT	\N	PRESENT	0
258596	240329	11033F	PARTICIPANT	\N	PRESENT	0
258597	240329	19749K	PARTICIPANT	\N	PRESENT	0
258598	240329	04070G	PARTICIPANT	\N	PRESENT	0
258599	240329	11097X	PARTICIPANT	\N	PRESENT	0
258600	240329	07029T	PARTICIPANT	\N	PRESENT	0
258601	240329	19693L	PARTICIPANT	\N	PRESENT	0
258602	240329	19631V	PARTICIPANT	\N	PRESENT	0
258603	240329	19671E	PARTICIPANT	\N	PRESENT	0
258604	240329	14229S	PARTICIPANT	\N	PRESENT	0
258605	240329	04018C	PARTICIPANT	\N	PRESENT	0
258500	258488	19731Y	PARTICIPANT	\N	PRESENT	0
258501	258488	08031R	PARTICIPANT	\N	PRESENT	0
258606	240329	14053L	PARTICIPANT	\N	PRESENT	0
258607	240329	11026G	PARTICIPANT	\N	PRESENT	0
258608	240329	14119M	PARTICIPANT	\N	PRESENT	0
258609	240329	19663E	PARTICIPANT	\N	PRESENT	0
258610	240329	14083S	PARTICIPANT	\N	PRESENT	0
258611	240329	14215L	PARTICIPANT	\N	PRESENT	0
258612	240329	19543W	PARTICIPANT	\N	PRESENT	0
258613	240329	14151M	PARTICIPANT	\N	PRESENT	0
258614	240329	14179A	PARTICIPANT	\N	PRESENT	0
258615	240329	08061X	PARTICIPANT	\N	PRESENT	0
258619	240329	19741B	PARTICIPANT	\N	PRESENT	0
258617	240329	11090Q	PARTICIPANT	\N	PRESENT	0
258618	240329	01028R	PARTICIPANT	\N	PRESENT	0
258634	258632	19667J	PARTICIPANT	\N	PRESENT	0
258635	258632	14255U	PARTICIPANT	\N	PRESENT	0
258636	258632	19701S	PARTICIPANT	\N	PRESENT	0
258637	258632	11049P	PARTICIPANT	\N	PRESENT	0
258638	258632	11026G	PARTICIPANT	\N	PRESENT	0
258749	258748	19295A	PARTICIPANT	\N	EXCUSE	0
258588	240329	11072N	PARTICIPANT	\N	PRESENT	0
258589	240329	05008E	PARTICIPANT	\N	PRESENT	0
258750	258748	19577H	PARTICIPANT	\N	EXCUSE	0
258751	258748	19631V	PARTICIPANT	\N	EXCUSE	0
258753	258752	19577H	PARTICIPANT	\N	EXCUSE	0
258754	258752	19295A	PARTICIPANT	\N	EXCUSE	0
258755	258752	19631V	PARTICIPANT	\N	EXCUSE	0
258772	251195	19503N	PARTICIPANT	\N	EXCUSE	0
258876	258745	11026G	PARTICIPANT	\N	PRESENT	0
258877	258745	17637T	PARTICIPANT	\N	PRESENT	0
258878	258745	19643A	PARTICIPANT	\N	PRESENT	0
258882	258881	08017T	PARTICIPANT	\N	PRESENT	0
258884	258883	11072N	PARTICIPANT	\N	PRESENT	0
258892	258891	14121F	PARTICIPANT	\N	PRESENT	0
258896	258895	95063L	PARTICIPANT	\N	PRESENT	0
258898	258897	95063L	PARTICIPANT	\N	PRESENT	0
258904	258903	11048N	PARTICIPANT	\N	PRESENT	0
258907	258340	04042C	PARTICIPANT	\N	PRESENT	0
258908	258340	98018T	PARTICIPANT	\N	PRESENT	0
258909	258340	14193X	PARTICIPANT	\N	PRESENT	0
258910	258340	98050T	PARTICIPANT	\N	PRESENT	0
258954	258953	04042C	PARTICIPANT	\N	PRESENT	0
258955	258953	07033P	PARTICIPANT	\N	PRESENT	0
258956	258953	14187A	PARTICIPANT	\N	PRESENT	0
258957	258953	14281W	PARTICIPANT	\N	PRESENT	0
258958	258953	11049P	PARTICIPANT	\N	PRESENT	0
258959	258953	98022P	PARTICIPANT	\N	PRESENT	0
258960	258953	99004R	PARTICIPANT	\N	PRESENT	0
258961	258953	19699S	PARTICIPANT	\N	PRESENT	0
258962	258953	04088S	PARTICIPANT	\N	PRESENT	0
258978	258977	14097Y	PARTICIPANT	\N	PRESENT	0
258979	258977	14133K	PARTICIPANT	\N	PRESENT	0
258980	258967	08052W	PARTICIPANT	\N	PRESENT	0
258981	258967	10006L	PARTICIPANT	\N	PRESENT	0
258982	258967	19553Y	PARTICIPANT	\N	PRESENT	0
258983	258968	08052W	PARTICIPANT	\N	PRESENT	0
258984	258968	10006L	PARTICIPANT	\N	PRESENT	0
258985	258968	19553Y	PARTICIPANT	\N	PRESENT	0
258986	258969	08052W	PARTICIPANT	\N	PRESENT	0
258987	258969	10006L	PARTICIPANT	\N	PRESENT	0
258990	258989	14071N	PARTICIPANT	\N	PRESENT	0
258992	258991	14071N	PARTICIPANT	\N	PRESENT	0
259051	258748	11109J	PARTICIPANT	\N	PRESENT	0
259054	258748	14097Y	PARTICIPANT	\N	PRESENT	0
259056	258748	98005N	PRESIDENT	1	PRESENT	0
259059	258748	08019V	PRESIDENT	0	PRESENT	0
259061	258748	19657G	PARTICIPANT	\N	PRESENT	0
259064	258748	14275Y	PARTICIPANT	\N	EXCUSE	0
259176	259175	08024S	PARTICIPANT	\N	PRESENT	0
259181	259180	08024S	PARTICIPANT	\N	PRESENT	0
259195	259193	19575F	PARTICIPANT	\N	PRESENT	0
259196	259193	19383Y	PARTICIPANT	\N	PRESENT	0
259197	259193	19621T	PARTICIPANT	\N	PRESENT	0
259198	259193	14195A	PARTICIPANT	\N	PRESENT	0
259199	259193	19347U	PARTICIPANT	\N	PRESENT	0
259200	259193	14103D	PARTICIPANT	\N	PRESENT	0
259201	259193	14265W	PARTICIPANT	\N	PRESENT	0
259202	259193	14237S	PARTICIPANT	\N	PRESENT	0
259203	259193	04088S	PARTICIPANT	\N	PRESENT	0
259204	259193	19679N	PARTICIPANT	\N	PRESENT	0
259205	259193	95067Q	PARTICIPANT	\N	PRESENT	0
259206	259193	14109K	PARTICIPANT	\N	PRESENT	0
259468	259466	14255U	PARTICIPANT	\N	PRESENT	0
259477	259476	14255U	PARTICIPANT	\N	PRESENT	0
259734	259733	96004D	PARTICIPANT	\N	PRESENT	0
259735	259733	04057K	PARTICIPANT	\N	PRESENT	0
259736	259733	14331P	PARTICIPANT	\N	PRESENT	0
259747	259746	96004D	PARTICIPANT	\N	PRESENT	0
259748	259746	04042C	PARTICIPANT	\N	PRESENT	0
260439	260438	19741B	PARTICIPANT	\N	PRESENT	0
260440	260438	04040A	PARTICIPANT	\N	PRESENT	0
260441	260438	19415P	PARTICIPANT	\N	PRESENT	0
260442	260438	88008L	PARTICIPANT	\N	PRESENT	0
260443	260438	19251M	PARTICIPANT	\N	PRESENT	0
260444	260438	19511N	PARTICIPANT	\N	PRESENT	0
260445	260438	19591F	PARTICIPANT	\N	PRESENT	0
260446	260438	08031R	PARTICIPANT	\N	PRESENT	0
260447	260438	14031R	PARTICIPANT	\N	PRESENT	0
260448	260438	11085T	PARTICIPANT	\N	PRESENT	0
260449	260438	14229S	PARTICIPANT	\N	PRESENT	0
260450	260438	01062T	PARTICIPANT	\N	PRESENT	0
242678	239410	08052W	PARTICIPANT	\N	PRESENT	0
242679	239410	19691J	PARTICIPANT	\N	PRESENT	0
242680	239410	19715Y	PARTICIPANT	\N	PRESENT	0
242681	239410	08041T	PARTICIPANT	\N	PRESENT	0
242682	239410	19723Y	PARTICIPANT	\N	PRESENT	0
242683	239410	19727D	PARTICIPANT	\N	PRESENT	0
242684	239410	14119M	PARTICIPANT	\N	PRESENT	0
242685	239410	11103C	PARTICIPANT	\N	PRESENT	0
242686	239410	14071N	PARTICIPANT	\N	PRESENT	0
242687	239410	14355X	PARTICIPANT	\N	EXCUSE	0
242688	239410	19569H	PARTICIPANT	\N	EXCUSE	0
242689	239410	08048B	PARTICIPANT	\N	EXCUSE	0
242690	239410	19663E	PARTICIPANT	\N	EXCUSE	0
242691	239410	19367Y	PARTICIPANT	\N	EXCUSE	0
242692	239410	14223L	PARTICIPANT	\N	EXCUSE	0
242694	241267	19383Y	PARTICIPANT	\N	PRESENT	0
242695	241267	19333N	PARTICIPANT	\N	PRESENT	0
242696	241267	17583W	PARTICIPANT	\N	PRESENT	0
242697	241267	95062K	PARTICIPANT	\N	PRESENT	0
242698	241267	19549D	PARTICIPANT	\N	PRESENT	0
242699	241267	19387D	PARTICIPANT	\N	PRESENT	0
242700	241267	14219Q	PARTICIPANT	\N	PRESENT	0
242701	241267	14221J	PARTICIPANT	\N	PRESENT	0
242702	241267	19637C	PARTICIPANT	\N	PRESENT	0
242703	241267	14237S	PARTICIPANT	\N	PRESENT	0
242704	241267	18083K	PARTICIPANT	\N	PRESENT	0
242705	241267	19551W	PARTICIPANT	\N	PRESENT	0
242706	241267	05012A	PARTICIPANT	\N	PRESENT	0
242707	241267	80027E	PARTICIPANT	\N	PRESENT	0
242708	241267	14051J	PARTICIPANT	\N	PRESENT	0
242709	241267	08060W	PARTICIPANT	\N	PRESENT	0
242710	241267	19503N	PARTICIPANT	\N	PRESENT	0
242711	241267	19347U	PARTICIPANT	\N	PRESENT	0
242712	241267	14157T	PARTICIPANT	\N	PRESENT	0
242713	241267	98023Q	PARTICIPANT	\N	PRESENT	0
242714	241267	14038Y	PARTICIPANT	\N	PRESENT	0
242715	241267	14103D	PARTICIPANT	\N	PRESENT	0
242716	241267	95067Q	PARTICIPANT	\N	PRESENT	0
242717	241267	14031R	PARTICIPANT	\N	PRESENT	0
242718	241267	19713W	PARTICIPANT	\N	PRESENT	0
242719	241267	08055A	PARTICIPANT	\N	PRESENT	0
242720	241267	14169X	PARTICIPANT	\N	PRESENT	0
242721	241267	15447F	PARTICIPANT	\N	PRESENT	0
242722	241267	14093U	PARTICIPANT	\N	PRESENT	0
242723	241267	08009T	PRESIDENT	0	PRESENT	0
242724	241267	04097T	PARTICIPANT	\N	PRESENT	0
242725	241267	08024S	PARTICIPANT	\N	EXCUSE	0
242726	241267	19681G	PARTICIPANT	\N	EXCUSE	0
242727	241267	19599P	PARTICIPANT	\N	EXCUSE	0
242728	241267	17637T	PARTICIPANT	\N	EXCUSE	0
242729	241173	14259Y	PARTICIPANT	\N	PRESENT	0
242730	241173	11026G	PARTICIPANT	\N	PRESENT	0
242731	241490	98022P	PARTICIPANT	\N	PRESENT	0
242771	239413	19697Q	PARTICIPANT	\N	PRESENT	0
242772	239413	11067R	PARTICIPANT	\N	PRESENT	0
242773	239413	11077T	PARTICIPANT	\N	PRESENT	0
242774	239413	11097X	PARTICIPANT	\N	PRESENT	0
242775	239413	19415P	PARTICIPANT	\N	PRESENT	0
242776	239413	04045F	PARTICIPANT	\N	PRESENT	0
242777	239413	14026U	PARTICIPANT	\N	PRESENT	0
242778	239413	14227Q	PARTICIPANT	\N	PRESENT	0
242779	239413	17779H	PARTICIPANT	\N	PRESENT	0
242780	239413	11063M	PARTICIPANT	\N	PRESENT	0
242781	239413	19703U	PARTICIPANT	\N	PRESENT	0
242782	239413	19553Y	PARTICIPANT	\N	PRESENT	0
242783	239413	14087W	PARTICIPANT	\N	PRESENT	0
242784	239413	19679N	PARTICIPANT	\N	PRESENT	0
242785	239413	19575F	PARTICIPANT	\N	PRESENT	0
242786	239413	14195A	PARTICIPANT	\N	PRESENT	0
242787	239413	14213J	PARTICIPANT	\N	PRESENT	0
242788	239413	14217N	PARTICIPANT	\N	PRESENT	0
242789	239413	19335Q	PARTICIPANT	\N	PRESENT	0
242790	239413	19683J	PARTICIPANT	\N	PRESENT	0
242791	239413	98024R	PARTICIPANT	\N	PRESENT	0
242792	239413	19521Q	PARTICIPANT	\N	PRESENT	0
242793	239413	19527W	PARTICIPANT	\N	PRESENT	0
242794	239413	01034P	PARTICIPANT	\N	PRESENT	0
242795	239413	04092N	PRESIDENT	0	PRESENT	0
242796	239413	08052W	PARTICIPANT	\N	PRESENT	0
242797	239413	19691J	PARTICIPANT	\N	PRESENT	0
242798	239413	19715Y	PARTICIPANT	\N	PRESENT	0
242799	239413	08041T	PARTICIPANT	\N	PRESENT	0
242800	239413	19723Y	PARTICIPANT	\N	PRESENT	0
242801	239413	19727D	PARTICIPANT	\N	PRESENT	0
242802	239413	14119M	PARTICIPANT	\N	PRESENT	0
242803	239413	11103C	PARTICIPANT	\N	PRESENT	0
242804	239413	14071N	PARTICIPANT	\N	PRESENT	0
242805	239413	14355X	PARTICIPANT	\N	PRESENT	0
242806	239413	19569H	PARTICIPANT	\N	EXCUSE	0
242807	239413	08048B	PARTICIPANT	\N	EXCUSE	0
242808	239413	19663E	PARTICIPANT	\N	EXCUSE	0
242809	239413	19367Y	PARTICIPANT	\N	EXCUSE	0
242810	239413	14223L	PARTICIPANT	\N	EXCUSE	0
242847	241176	19543W	PARTICIPANT	\N	PRESENT	0
242848	241176	04047H	PARTICIPANT	\N	PRESENT	0
242855	241269	14034U	PARTICIPANT	\N	PRESENT	0
242849	241176	19483C	PARTICIPANT	\N	PRESENT	0
242817	241269	99004R	PARTICIPANT	\N	PRESENT	0
242818	241176	14001X	PARTICIPANT	\N	PRESENT	0
242819	241176	04044E	PARTICIPANT	\N	PRESENT	0
242820	241176	19581D	PARTICIPANT	\N	PRESENT	0
242821	241176	01028R	PARTICIPANT	\N	PRESENT	0
242822	241176	05008E	PRESIDENT	0	PRESENT	0
242823	241176	19447X	PARTICIPANT	\N	PRESENT	0
242824	241176	14231L	PARTICIPANT	\N	PRESENT	0
242825	241176	19489J	PARTICIPANT	\N	PRESENT	0
242826	241176	14275Y	PARTICIPANT	\N	PRESENT	0
242827	241176	14041T	PARTICIPANT	\N	PRESENT	0
242828	241176	14147R	PARTICIPANT	\N	PRESENT	0
242829	241176	14151M	PARTICIPANT	\N	PRESENT	0
242830	241176	14215L	PARTICIPANT	\N	PRESENT	0
242831	241176	08018U	PARTICIPANT	\N	PRESENT	0
242832	241176	14111D	PARTICIPANT	\N	PRESENT	0
242833	241176	19649G	PARTICIPANT	\N	PRESENT	0
242834	241176	07034Q	PARTICIPANT	\N	PRESENT	0
242835	241176	11026G	PARTICIPANT	\N	PRESENT	0
242836	241176	01024M	PARTICIPANT	\N	PRESENT	0
242837	241176	04038G	PARTICIPANT	\N	PRESENT	0
242838	241176	11033F	PARTICIPANT	\N	PRESENT	0
242839	241176	19725B	PARTICIPANT	\N	PRESENT	0
242840	241176	19729F	PARTICIPANT	\N	PRESENT	0
242841	241176	08044W	PARTICIPANT	\N	PRESENT	0
242842	241176	11049P	PARTICIPANT	\N	PRESENT	0
242843	241176	04008A	PARTICIPANT	\N	PRESENT	0
242844	241176	14021P	PARTICIPANT	\N	PRESENT	0
242845	241269	14159V	PARTICIPANT	\N	PRESENT	0
242850	241176	14065Q	PARTICIPANT	\N	PRESENT	0
242851	241176	11010L	PARTICIPANT	\N	PRESENT	0
242852	241176	95063L	PARTICIPANT	\N	PRESENT	0
242853	241176	14053L	PARTICIPANT	\N	EXCUSE	0
242854	241176	19673G	PARTICIPANT	\N	EXCUSE	0
242856	241367	14241N	PARTICIPANT	\N	PRESENT	0
242857	241367	14201E	PARTICIPANT	\N	EXCUSE	0
242858	241494	95067Q	PARTICIPANT	\N	PRESENT	0
242859	241490	95067Q	PARTICIPANT	\N	PRESENT	0
242860	241269	19667J	PARTICIPANT	\N	EXCUSE	0
244408	244332	19253P	PARTICIPANT	\N	PRESENT	0
244409	244332	14021P	PARTICIPANT	\N	PRESENT	0
244410	244332	05008E	PRESIDENT	0	PRESENT	0
244411	244332	14151M	PARTICIPANT	\N	PRESENT	0
244412	244332	14065Q	PARTICIPANT	\N	PRESENT	0
244413	244332	01028R	PARTICIPANT	\N	PRESENT	0
244414	244332	11010L	PARTICIPANT	\N	PRESENT	0
244415	244332	19543W	PARTICIPANT	\N	PRESENT	0
244416	244332	14231L	PARTICIPANT	\N	PRESENT	0
244417	244332	14089Y	PARTICIPANT	\N	PRESENT	0
244418	244332	95063L	PARTICIPANT	\N	PRESENT	0
244419	244332	14069U	PARTICIPANT	\N	PRESENT	0
244398	244332	98035U	PARTICIPANT	\N	PRESENT	0
244399	244332	14111D	PARTICIPANT	\N	PRESENT	0
244400	244332	07034Q	PRESIDENT	1	PRESENT	0
244401	244332	14041T	PARTICIPANT	\N	PRESENT	0
244402	244332	14147R	PARTICIPANT	\N	PRESENT	0
244403	244332	01024M	PARTICIPANT	\N	PRESENT	0
244404	244332	04044E	PARTICIPANT	\N	PRESENT	0
244405	244332	04047H	PARTICIPANT	\N	PRESENT	0
244406	244332	19447X	PARTICIPANT	\N	PRESENT	0
244407	244332	19729F	PARTICIPANT	\N	EXCUSE	0
266975	258933	08056B	PARTICIPANT	\N	PRESENT	0
266976	258933	19611R	PARTICIPANT	\N	EXCUSE	0
266977	258933	08010L	PARTICIPANT	\N	PRESENT	0
266978	258933	10015M	PARTICIPANT	\N	PRESENT	0
266979	258933	19421M	PARTICIPANT	\N	PRESENT	0
267108	258759	11109J	PARTICIPANT	\N	PRESENT	0
267109	258759	14261S	PARTICIPANT	\N	PRESENT	0
267110	258759	14259Y	PARTICIPANT	\N	EXCUSE	0
267111	258759	19715Y	PARTICIPANT	\N	PRESENT	0
267113	258759	14059S	PARTICIPANT	\N	PRESENT	0
267115	258759	08019V	PRESIDENT	0	PRESENT	0
267117	258759	11072N	PARTICIPANT	\N	PRESENT	0
267118	258759	08073C	PARTICIPANT	\N	PRESENT	0
267119	258759	19657G	PARTICIPANT	\N	PRESENT	0
269611	263466	19415P	PARTICIPANT	\N	PRESENT	0
267206	256504	19399H	PARTICIPANT	\N	PRESENT	0
267207	256504	99004R	PARTICIPANT	\N	PRESENT	0
267274	267270	14135M	PARTICIPANT	\N	PRESENT	0
267275	267270	14265W	PARTICIPANT	\N	PRESENT	0
267277	267270	19515S	PARTICIPANT	\N	PRESENT	0
267278	267270	19369B	PARTICIPANT	\N	PRESENT	0
267279	267270	19705W	PARTICIPANT	\N	PRESENT	0
267281	267280	19631V	PARTICIPANT	\N	PRESENT	0
267282	267280	14265W	PARTICIPANT	\N	PRESENT	0
267283	267280	19515S	PARTICIPANT	\N	PRESENT	0
267284	267280	19705W	PARTICIPANT	\N	PRESENT	0
267285	267280	04049K	PARTICIPANT	\N	PRESENT	0
267287	267286	14265W	PARTICIPANT	\N	PRESENT	0
267288	267286	19515S	PARTICIPANT	\N	PRESENT	0
267289	267286	19705W	PARTICIPANT	\N	PRESENT	0
267290	267286	04049K	PARTICIPANT	\N	PRESENT	0
267291	267286	14135M	PARTICIPANT	\N	PRESENT	0
267293	267292	19631V	PARTICIPANT	\N	PRESENT	0
267294	267292	14135M	PARTICIPANT	\N	PRESENT	0
267295	267292	19515S	PARTICIPANT	\N	PRESENT	0
267296	267292	14265W	PARTICIPANT	\N	PRESENT	0
267302	267300	14135M	PARTICIPANT	\N	PRESENT	0
267303	267300	19631V	PARTICIPANT	\N	PRESENT	0
267305	267300	14265W	PARTICIPANT	\N	PRESENT	0
267309	267308	08028W	PARTICIPANT	\N	PRESENT	0
267310	267308	08068F	PARTICIPANT	\N	PRESENT	0
267311	267308	14219Q	PARTICIPANT	\N	PRESENT	0
267312	267308	19737F	PARTICIPANT	\N	PRESENT	0
267313	267308	14028W	PARTICIPANT	\N	PRESENT	0
267317	267316	08028W	PARTICIPANT	\N	PRESENT	0
267318	267316	08068F	PARTICIPANT	\N	PRESENT	0
267319	267316	14257W	PARTICIPANT	\N	PRESENT	0
267321	267316	19349W	PARTICIPANT	\N	PRESENT	0
267322	267316	19737F	PARTICIPANT	\N	PRESENT	0
267323	267316	14028W	PARTICIPANT	\N	PRESENT	0
267325	267324	08028W	PARTICIPANT	\N	PRESENT	0
267326	267324	08068F	PARTICIPANT	\N	PRESENT	0
267327	267324	14257W	PARTICIPANT	\N	PRESENT	0
267328	267324	14219Q	PARTICIPANT	\N	PRESENT	0
267330	267329	14051J	PARTICIPANT	\N	PRESENT	0
267331	267329	08024S	PARTICIPANT	\N	PRESENT	0
268041	263168	98050T	PARTICIPANT	\N	PRESENT	0
268042	263168	19709B	PARTICIPANT	\N	PRESENT	0
268043	263168	14123H	PARTICIPANT	\N	PRESENT	0
268044	263168	19333N	PARTICIPANT	\N	PRESENT	0
268045	263168	11053K	PARTICIPANT	\N	PRESENT	0
268046	263168	14237S	PARTICIPANT	\N	PRESENT	0
268047	263168	04045F	PARTICIPANT	\N	PRESENT	0
268489	268488	05008E	PRESIDENT	0	PRESENT	0
268490	268488	95063L	PARTICIPANT	\N	PRESENT	0
268491	268488	14069U	PARTICIPANT	\N	PRESENT	0
268492	268488	14215L	PARTICIPANT	\N	PRESENT	0
268494	268488	14089Y	PARTICIPANT	\N	PRESENT	0
268495	268488	11026G	PARTICIPANT	\N	PRESENT	0
268496	268488	14001X	PARTICIPANT	\N	PRESENT	0
268497	268488	19253P	PARTICIPANT	\N	PRESENT	0
268498	267403	14089Y	PARTICIPANT	\N	PRESENT	0
268499	267403	01024M	PARTICIPANT	\N	PRESENT	0
268609	268608	08031R	PARTICIPANT	\N	PRESENT	0
268610	268608	19637C	PARTICIPANT	\N	PRESENT	0
268611	268608	08020N	PARTICIPANT	\N	PRESENT	0
268613	268612	04033B	PARTICIPANT	\N	PRESENT	0
268614	268612	14079W	PARTICIPANT	\N	PRESENT	0
268615	268612	08034U	PARTICIPANT	\N	PRESENT	0
268616	268612	98029W	PARTICIPANT	\N	PRESENT	0
269609	263466	19467C	PARTICIPANT	\N	PRESENT	0
269610	263466	19289C	PARTICIPANT	\N	PRESENT	0
269612	263466	19543W	PARTICIPANT	\N	PRESENT	0
269613	263466	19507S	PARTICIPANT	\N	PRESENT	0
269614	263466	11072N	PARTICIPANT	\N	PRESENT	0
269615	263466	98035U	PARTICIPANT	\N	PRESENT	0
269616	263466	19399H	PARTICIPANT	\N	PRESENT	0
269617	263466	14159V	PARTICIPANT	\N	PRESENT	0
269618	263466	11077T	PARTICIPANT	\N	PRESENT	0
269619	263466	19443T	PARTICIPANT	\N	PRESENT	0
269620	263466	04059M	PARTICIPANT	\N	PRESENT	0
269621	263466	11074Q	PARTICIPANT	\N	PRESENT	0
269622	263466	19741B	PARTICIPANT	\N	PRESENT	0
269623	263466	01028R	PARTICIPANT	\N	PRESENT	0
269624	263466	11027H	PARTICIPANT	\N	PRESENT	0
269625	263466	08055A	PARTICIPANT	\N	PRESENT	0
269626	263466	08016S	PARTICIPANT	\N	PRESENT	0
269627	263466	08052W	PARTICIPANT	\N	PRESENT	0
269628	263466	14107H	PARTICIPANT	\N	PRESENT	0
269629	263466	14021P	PARTICIPANT	\N	PRESENT	0
269630	263466	19663E	PARTICIPANT	\N	PRESENT	0
269631	263466	14225N	PARTICIPANT	\N	PRESENT	0
269632	263466	19649G	PARTICIPANT	\N	PRESENT	0
269633	263466	04088S	PARTICIPANT	\N	PRESENT	0
269634	263466	14151M	PARTICIPANT	\N	PRESENT	0
269635	263466	14041T	PARTICIPANT	\N	PRESENT	0
269636	263466	19647E	PARTICIPANT	\N	PRESENT	0
269637	263466	08018U	PARTICIPANT	\N	PRESENT	0
269638	263466	01062T	PARTICIPANT	\N	PRESENT	0
269639	263466	11045K	PARTICIPANT	\N	PRESENT	0
269640	263466	07029T	PARTICIPANT	\N	PRESENT	0
269641	263466	86034E	PARTICIPANT	\N	PRESENT	0
269642	263466	08043V	PARTICIPANT	\N	PRESENT	0
269643	263466	19727D	PARTICIPANT	\N	PRESENT	0
269644	263466	19707Y	PARTICIPANT	\N	PRESENT	0
269645	263466	19695N	PARTICIPANT	\N	PRESENT	0
269646	263466	19705W	PARTICIPANT	\N	PRESENT	0
269647	263466	08015R	PARTICIPANT	\N	PRESENT	0
269648	263466	08058D	PARTICIPANT	\N	PRESENT	0
269649	263466	98050T	PARTICIPANT	\N	PRESENT	0
269650	263466	14121F	PARTICIPANT	\N	PRESENT	0
269651	263466	08017T	PARTICIPANT	\N	PRESENT	0
269652	263466	19733B	PARTICIPANT	\N	PRESENT	0
269653	263466	19525U	PARTICIPANT	\N	PRESENT	0
269654	263466	19725B	PARTICIPANT	\N	PRESENT	0
269655	263466	11041F	PARTICIPANT	\N	PRESENT	0
269656	263466	14059S	PARTICIPANT	\N	PRESENT	0
269657	263466	19333N	PARTICIPANT	\N	PRESENT	0
269658	263466	14001X	PARTICIPANT	\N	PRESENT	0
269659	263466	14329V	PARTICIPANT	\N	PRESENT	0
269660	263466	11054L	PARTICIPANT	\N	PRESENT	0
269661	263466	19689Q	PARTICIPANT	\N	PRESENT	0
269662	263466	14357A	PARTICIPANT	\N	PRESENT	0
269663	263466	14229S	PARTICIPANT	\N	PRESENT	0
269664	263466	19675J	PARTICIPANT	\N	PRESENT	0
269665	263466	11067R	PARTICIPANT	\N	PRESENT	0
269666	263466	19593H	PARTICIPANT	\N	PRESENT	0
269667	263466	19527W	PARTICIPANT	\N	PRESENT	0
269668	263466	19747H	PARTICIPANT	\N	PRESENT	0
269669	263466	14109K	PARTICIPANT	\N	PRESENT	0
269670	263466	19701S	PARTICIPANT	\N	PRESENT	0
269671	263466	14207L	PARTICIPANT	\N	PRESENT	0
269672	263466	14257W	PARTICIPANT	\N	PRESENT	0
269673	263466	19669L	PARTICIPANT	\N	PRESENT	0
269674	263466	19621T	PARTICIPANT	\N	PRESENT	0
269675	263466	11031D	PARTICIPANT	\N	PRESENT	0
269676	263466	19367Y	PARTICIPANT	\N	PRESENT	0
269677	263466	11109J	PARTICIPANT	\N	PRESENT	0
269678	263466	04049K	PARTICIPANT	\N	PRESENT	0
269679	263466	19643A	PARTICIPANT	\N	PRESENT	0
269680	263466	97011G	PARTICIPANT	\N	PRESENT	0
269681	263466	11103C	PARTICIPANT	\N	PRESENT	0
269682	263466	14331P	PARTICIPANT	\N	PRESENT	0
269683	263466	08031R	PARTICIPANT	\N	PRESENT	0
269684	263466	08034U	PARTICIPANT	\N	PRESENT	0
269685	263466	10006L	PARTICIPANT	\N	PRESENT	0
269686	263466	19735D	PARTICIPANT	\N	PRESENT	0
269687	263466	14237S	PARTICIPANT	\N	PRESENT	0
269688	263466	14231L	PARTICIPANT	\N	PRESENT	0
269689	263466	04043D	PARTICIPANT	\N	PRESENT	0
269690	263466	14069U	PARTICIPANT	\N	PRESENT	0
269691	263466	19511N	PARTICIPANT	\N	PRESENT	0
269692	263466	14205J	PARTICIPANT	\N	PRESENT	0
269693	263466	14053L	PARTICIPANT	\N	PRESENT	0
269694	263466	05008E	PARTICIPANT	\N	PRESENT	0
244027	241089	98024R	PARTICIPANT	\N	PRESENT	0
244028	241089	11097X	PARTICIPANT	\N	PRESENT	0
244029	241089	19575F	PARTICIPANT	\N	PRESENT	0
244033	244032	08052W	PARTICIPANT	\N	PRESENT	0
244035	244032	10006L	PARTICIPANT	\N	PRESENT	0
244038	244032	19553Y	PARTICIPANT	\N	PRESENT	0
245181	245180	19415P	PARTICIPANT	\N	PRESENT	0
245182	245180	04092N	PARTICIPANT	\N	PRESENT	0
245183	245180	19679N	PARTICIPANT	\N	PRESENT	0
245184	245180	19727D	PARTICIPANT	\N	PRESENT	0
245185	245180	11097X	PARTICIPANT	\N	PRESENT	0
247240	247239	08010L	PARTICIPANT	\N	PRESENT	0
247272	247243	11010L	PARTICIPANT	\N	EXCUSE	0
251155	251151	04040A	PARTICIPANT	\N	PRESENT	0
254510	240317	19479G	PARTICIPANT	\N	PRESENT	0
254511	240317	14073Q	PARTICIPANT	\N	PRESENT	0
254512	240317	07004J	PARTICIPANT	\N	PRESENT	0
254513	240317	14255U	PARTICIPANT	\N	PRESENT	0
254514	240317	19253P	PARTICIPANT	\N	PRESENT	0
254515	240317	19747H	PARTICIPANT	\N	PRESENT	0
254516	240317	19749K	PARTICIPANT	\N	PRESENT	0
254517	240317	19719D	PARTICIPANT	\N	PRESENT	0
254518	240317	01025N	PARTICIPANT	\N	PRESENT	0
254519	240317	14217N	PARTICIPANT	\N	PRESENT	0
254520	240317	04049K	PARTICIPANT	\N	PRESENT	0
254521	240317	14123H	PARTICIPANT	\N	PRESENT	0
254522	240317	14105F	PARTICIPANT	\N	PRESENT	0
254523	240317	14033T	PARTICIPANT	\N	PRESENT	0
254524	240317	19573D	PARTICIPANT	\N	PRESENT	0
254525	240317	14119M	PARTICIPANT	\N	PRESENT	0
254526	240317	19515S	PARTICIPANT	\N	PRESENT	0
254527	240317	11048N	PARTICIPANT	\N	PRESENT	0
254528	240317	14103D	PARTICIPANT	\N	PRESENT	0
254529	240317	14151M	PARTICIPANT	\N	PRESENT	0
254530	240317	19689Q	PARTICIPANT	\N	PRESENT	0
254531	240317	19441R	PARTICIPANT	\N	PRESENT	0
254532	240317	14281W	PARTICIPANT	\N	PRESENT	0
254533	240317	04088S	PARTICIPANT	\N	PRESENT	0
254534	240317	14253S	PARTICIPANT	\N	PRESENT	0
254535	240317	19631V	PARTICIPANT	\N	PRESENT	0
254536	240317	19679N	PARTICIPANT	\N	PRESENT	0
254537	240317	19673G	PARTICIPANT	\N	PRESENT	0
254538	240317	01024M	PARTICIPANT	\N	PRESENT	0
254540	240317	95030B	PARTICIPANT	\N	PRESENT	0
254541	240317	11103C	PARTICIPANT	\N	PRESENT	0
254542	240317	14213J	PARTICIPANT	\N	PRESENT	0
254543	240317	19629C	PARTICIPANT	\N	PRESENT	0
254544	240317	19675J	PARTICIPANT	\N	PRESENT	0
254545	240317	08061X	PARTICIPANT	\N	PRESENT	0
254549	240317	19415P	PARTICIPANT	\N	PRESENT	0
254547	240317	19347U	PARTICIPANT	\N	PRESENT	0
254548	240317	19507S	PARTICIPANT	\N	PRESENT	0
254550	240317	18083K	PARTICIPANT	\N	PRESENT	0
254551	240317	19467C	PARTICIPANT	\N	PRESENT	0
254552	240317	11012A	PARTICIPANT	\N	PRESENT	0
254553	240317	08031R	PARTICIPANT	\N	PRESENT	0
254555	240317	14029X	PARTICIPANT	\N	PRESENT	0
254556	240317	19521Q	PARTICIPANT	\N	PRESENT	0
254558	240317	08015R	PARTICIPANT	\N	PRESENT	0
254559	240317	14038Y	PARTICIPANT	\N	PRESENT	0
254560	240317	14237S	PARTICIPANT	\N	PRESENT	0
254561	240317	14079W	PARTICIPANT	\N	PRESENT	0
254562	240317	14041T	PARTICIPANT	\N	PRESENT	0
254563	240317	11027H	PARTICIPANT	\N	PRESENT	0
254564	240317	19545Y	PARTICIPANT	\N	PRESENT	0
254565	240317	04071H	PARTICIPANT	\N	PRESENT	0
254566	240317	14265W	PARTICIPANT	\N	PRESENT	0
254567	240317	19565D	PARTICIPANT	\N	PRESENT	0
254568	240317	14053L	PARTICIPANT	\N	PRESENT	0
254569	240317	11043H	PARTICIPANT	\N	PRESENT	0
254570	240317	14065Q	PARTICIPANT	\N	PRESENT	0
254571	240317	95062K	PARTICIPANT	\N	PRESENT	0
254572	240317	14135M	PARTICIPANT	\N	PRESENT	0
254573	240317	14087W	PARTICIPANT	\N	PRESENT	0
254574	240317	14195A	PARTICIPANT	\N	PRESENT	0
254575	240317	08056B	PARTICIPANT	\N	PRESENT	0
254576	240317	19563B	PARTICIPANT	\N	PRESENT	0
254577	240317	14071N	PARTICIPANT	\N	PRESENT	0
254578	240317	19583F	PARTICIPANT	\N	PRESENT	0
254579	240317	14042U	PARTICIPANT	\N	PRESENT	0
254580	240317	01034P	PARTICIPANT	\N	PRESENT	0
254581	240317	19551W	PARTICIPANT	\N	PRESENT	0
254783	254782	04085P	PARTICIPANT	\N	PRESENT	0
254784	254782	08058D	PRESIDENT	0	PRESENT	0
254785	254782	11053K	PARTICIPANT	\N	PRESENT	0
254786	254782	19721W	PARTICIPANT	\N	PRESENT	0
254787	254782	04086Q	PARTICIPANT	\N	PRESENT	0
254788	254782	04071H	PARTICIPANT	\N	PRESENT	0
254789	254782	08035V	PARTICIPANT	\N	PRESENT	0
254508	240317	19553Y	PARTICIPANT	\N	PRESENT	0
254509	240317	19691J	PARTICIPANT	\N	PRESENT	0
254790	254782	11049P	PARTICIPANT	\N	PRESENT	0
254791	254782	14021P	PARTICIPANT	\N	PRESENT	0
254792	254782	08034U	PARTICIPANT	\N	PRESENT	0
254793	254782	19443T	PARTICIPANT	\N	PRESENT	0
254794	254782	19703U	PARTICIPANT	\N	PRESENT	0
254795	254782	19729F	PARTICIPANT	\N	PRESENT	0
254838	254796	19651A	PARTICIPANT	\N	PRESENT	0
254839	254796	19545Y	PARTICIPANT	\N	PRESENT	0
254844	254796	19719D	PARTICIPANT	\N	PRESENT	0
254845	254796	19253P	PARTICIPANT	\N	PRESENT	0
254846	254796	14151M	PARTICIPANT	\N	PRESENT	0
254847	254796	14187A	PARTICIPANT	\N	PRESENT	0
254848	254796	14087W	PARTICIPANT	\N	PRESENT	0
254849	254796	14026U	PARTICIPANT	\N	PRESENT	0
254850	254796	19399H	PARTICIPANT	\N	PRESENT	0
254851	254796	11048N	PRESIDENT	0	PRESENT	0
254852	254796	04049K	PARTICIPANT	\N	PRESENT	0
254853	254796	19711U	PARTICIPANT	\N	PRESENT	0
254854	254796	19749K	PARTICIPANT	\N	PRESENT	0
254855	254796	14157T	PARTICIPANT	\N	PRESENT	0
254856	254796	19689Q	PARTICIPANT	\N	PRESENT	0
254857	254796	19503N	PARTICIPANT	\N	PRESENT	0
254858	254796	19533U	PARTICIPANT	\N	PRESENT	0
254859	254796	19573D	PARTICIPANT	\N	PRESENT	0
254860	254796	14071N	PARTICIPANT	\N	PRESENT	0
254861	254796	11067R	PARTICIPANT	\N	PRESENT	0
254862	254796	14031R	PARTICIPANT	\N	PRESENT	0
254863	254796	14103D	PARTICIPANT	\N	PRESENT	0
254864	254796	19441R	PARTICIPANT	\N	PRESENT	0
255093	254796	95063L	PARTICIPANT	\N	PRESENT	0
255307	255306	05008E	PRESIDENT	0	PRESENT	0
255308	255306	07034Q	PARTICIPANT	\N	PRESENT	0
255309	255306	19447X	PARTICIPANT	\N	PRESENT	0
255310	255306	14205J	PARTICIPANT	\N	PRESENT	0
255311	255306	14065Q	PARTICIPANT	\N	PRESENT	0
255312	255306	19649G	PARTICIPANT	\N	PRESENT	0
255313	255306	19543W	PARTICIPANT	\N	PRESENT	0
255314	255306	14147R	PARTICIPANT	\N	PRESENT	0
255507	253546	96004D	PARTICIPANT	\N	EXCUSE	0
255553	253546	08019V	PARTICIPANT	\N	EXCUSE	0
255741	255595	11077T	PARTICIPANT	\N	PRESENT	0
255742	255595	19447X	PARTICIPANT	\N	PRESENT	0
255743	255595	12041X	PARTICIPANT	\N	PRESENT	0
255744	255595	19649G	PARTICIPANT	\N	PRESENT	0
255745	255595	08012N	PARTICIPANT	\N	PRESENT	0
255746	255595	08016S	PARTICIPANT	\N	PRESENT	0
255747	255595	19301E	PARTICIPANT	\N	PRESENT	0
255748	255595	19699S	PARTICIPANT	\N	PRESENT	0
255749	255595	14089Y	PARTICIPANT	\N	PRESENT	0
255750	255595	14073Q	PARTICIPANT	\N	PRESENT	0
255751	255595	19693L	PARTICIPANT	\N	PRESENT	0
255752	255595	19671E	PARTICIPANT	\N	PRESENT	0
255753	255595	11045K	PARTICIPANT	\N	PRESENT	0
255754	255595	14021P	PARTICIPANT	\N	PRESENT	0
255755	255595	19747H	PARTICIPANT	\N	PRESENT	0
255756	255595	17637T	PARTICIPANT	\N	PRESENT	0
255757	255595	19575F	PARTICIPANT	\N	PRESENT	0
255758	255595	14157T	PARTICIPANT	\N	PRESENT	0
255759	255595	14357A	PARTICIPANT	\N	PRESENT	0
255760	255595	19479G	PARTICIPANT	\N	PRESENT	0
255761	255595	04070G	PARTICIPANT	\N	PRESENT	0
255762	255595	04018C	PARTICIPANT	\N	PRESENT	0
255763	255595	04057K	PARTICIPANT	\N	PRESENT	0
255764	255595	11083R	PARTICIPANT	\N	PRESENT	0
255765	255595	19749K	PARTICIPANT	\N	PRESENT	0
255766	255595	14241N	PARTICIPANT	\N	PRESENT	0
255767	255595	19399H	PARTICIPANT	\N	PRESENT	0
255768	255595	19703U	PARTICIPANT	\N	PRESENT	0
255769	255595	19413M	PARTICIPANT	\N	PRESENT	0
255770	255595	01024M	PARTICIPANT	\N	PRESENT	0
255771	255595	19543W	PARTICIPANT	\N	PRESENT	0
255772	255595	14251Q	PARTICIPANT	\N	PRESENT	0
255773	255595	11012A	PARTICIPANT	\N	PRESENT	0
255775	255595	14213J	PARTICIPANT	\N	PRESENT	0
255776	255595	19741B	PARTICIPANT	\N	PRESENT	0
260583	260582	19667J	PARTICIPANT	\N	PRESENT	0
260584	260582	19701S	PARTICIPANT	\N	PRESENT	0
260585	260582	11026G	PARTICIPANT	\N	PRESENT	0
260824	260823	19621T	PARTICIPANT	\N	PRESENT	0
260825	260823	08031R	PARTICIPANT	\N	PRESENT	0
260827	260826	19621T	PARTICIPANT	\N	PRESENT	0
260828	260826	08031R	PARTICIPANT	\N	PRESENT	0
260829	260826	19533U	PARTICIPANT	\N	PRESENT	0
260831	260830	19621T	PARTICIPANT	\N	PRESENT	0
260832	260830	08031R	PARTICIPANT	\N	PRESENT	0
260833	260830	11083R	PARTICIPANT	\N	PRESENT	0
260848	260846	19621T	PARTICIPANT	\N	PRESENT	0
260849	260846	08031R	PARTICIPANT	\N	PRESENT	0
260851	260850	19621T	PARTICIPANT	\N	PRESENT	0
260852	260850	08031R	PARTICIPANT	\N	PRESENT	0
260854	260853	19621T	PARTICIPANT	\N	PRESENT	0
260855	260853	08031R	PARTICIPANT	\N	PRESENT	0
260858	253032	19663E	PARTICIPANT	\N	PRESENT	0
260859	253032	19533U	PARTICIPANT	\N	PRESENT	0
260917	258973	14121F	PARTICIPANT	\N	PRESENT	0
261059	261058	11053K	PARTICIPANT	\N	PRESENT	0
261060	261058	14159V	PARTICIPANT	\N	PRESENT	0
261061	261058	05012A	PARTICIPANT	\N	PRESENT	0
261265	261264	14065Q	PARTICIPANT	\N	PRESENT	0
261266	261264	96004D	PRESIDENT	0	PRESENT	0
261267	261264	14089Y	PARTICIPANT	\N	PRESENT	0
260928	260927	98029W	PARTICIPANT	\N	PRESENT	0
260930	260929	98029W	PARTICIPANT	\N	PRESENT	0
261268	261264	14079W	PARTICIPANT	\N	PRESENT	0
261269	261264	11083R	PARTICIPANT	\N	PRESENT	0
261270	261264	19725B	PARTICIPANT	\N	PRESENT	0
261278	261264	14073Q	PARTICIPANT	\N	PRESENT	0
261279	261264	08039A	PARTICIPANT	\N	PRESENT	0
261280	261264	14001X	PARTICIPANT	\N	PRESENT	0
261281	261264	14221J	PARTICIPANT	\N	PRESENT	0
261282	261264	19563B	PARTICIPANT	\N	PRESENT	0
261283	261264	14135M	PARTICIPANT	\N	PRESENT	0
261284	261264	14229S	PARTICIPANT	\N	PRESENT	0
261286	261264	14331P	PARTICIPANT	\N	EXCUSE	0
261287	261264	04057K	PARTICIPANT	\N	EXCUSE	0
261288	261264	14097Y	PARTICIPANT	\N	EXCUSE	0
261291	261290	14133K	PARTICIPANT	\N	PRESENT	0
261292	261290	14097Y	PARTICIPANT	\N	PRESENT	0
261294	261293	14133K	PARTICIPANT	\N	PRESENT	0
261295	261293	14097Y	PARTICIPANT	\N	PRESENT	0
261296	261293	98022P	PARTICIPANT	\N	PRESENT	0
261298	261297	14133K	PARTICIPANT	\N	PRESENT	0
261299	261297	14097Y	PARTICIPANT	\N	PRESENT	0
261333	261332	11031D	PARTICIPANT	\N	PRESENT	0
261334	261332	04071H	PARTICIPANT	\N	PRESENT	0
261335	261332	14169X	PARTICIPANT	\N	PRESENT	0
261336	261332	08073C	PARTICIPANT	\N	PRESENT	0
261338	261337	96004D	PARTICIPANT	\N	PRESENT	0
261339	261337	14033T	PARTICIPANT	\N	PRESENT	0
261340	261337	14026U	PARTICIPANT	\N	PRESENT	0
261341	261337	08014Q	PARTICIPANT	\N	PRESENT	0
261342	261337	14073Q	PARTICIPANT	\N	PRESENT	0
261343	261337	04057K	PARTICIPANT	\N	PRESENT	0
261344	261337	14205J	PARTICIPANT	\N	PRESENT	0
261345	261337	14135M	PARTICIPANT	\N	PRESENT	0
261346	261337	19507S	PARTICIPANT	\N	PRESENT	0
261347	261337	19441R	PARTICIPANT	\N	PRESENT	0
261348	261337	14257W	PARTICIPANT	\N	PRESENT	0
261349	261337	11090Q	PARTICIPANT	\N	PRESENT	0
261387	261386	04044E	PARTICIPANT	\N	PRESENT	0
261410	258934	19553Y	PARTICIPANT	\N	EXCUSE	0
261411	258934	01058X	PARTICIPANT	\N	PRESENT	0
261412	258934	01048V	PRESIDENT	0	PRESENT	0
261425	258758	96004D	PARTICIPANT	\N	EXCUSE	0
261427	258934	19533U	PARTICIPANT	\N	PRESENT	0
261494	261493	89017R	PARTICIPANT	\N	PRESENT	0
261500	261003	04044E	PARTICIPANT	\N	EXCUSE	0
262224	261183	14327T	PARTICIPANT	\N	PRESENT	0
262225	261183	01057W	PARTICIPANT	\N	PRESENT	0
262226	261183	11053K	PARTICIPANT	\N	PRESENT	0
262227	261183	11074Q	PRESIDENT	0	PRESENT	0
262228	261183	14225N	PARTICIPANT	\N	PRESENT	0
262229	261183	19671E	PARTICIPANT	\N	PRESENT	0
262230	261183	88008L	PARTICIPANT	\N	PRESENT	0
262231	261183	07029T	PARTICIPANT	\N	PRESENT	0
262232	261183	14085U	PARTICIPANT	\N	PRESENT	0
262233	261183	07004J	PARTICIPANT	\N	PRESENT	0
262234	261183	14253S	PARTICIPANT	\N	PRESENT	0
262258	261183	08069G	PARTICIPANT	\N	PRESENT	0
262236	261183	19647E	PARTICIPANT	\N	PRESENT	0
262237	261183	19711U	PARTICIPANT	\N	PRESENT	0
262238	261183	19651A	PARTICIPANT	\N	PRESENT	0
262239	261183	19687N	PARTICIPANT	\N	PRESENT	0
262240	261183	19689Q	PARTICIPANT	\N	PRESENT	0
262241	261183	08011M	PARTICIPANT	\N	PRESENT	0
262242	261183	08014Q	PARTICIPANT	\N	PRESENT	0
262243	261183	14034U	PARTICIPANT	\N	PRESENT	0
262244	261183	04086Q	PARTICIPANT	\N	PRESENT	0
262245	261183	11040E	PARTICIPANT	\N	PRESENT	0
262246	261183	14083S	PARTICIPANT	\N	PRESENT	0
262247	261183	19741B	PARTICIPANT	\N	PRESENT	0
262248	261183	14121F	PARTICIPANT	\N	PRESENT	0
262249	261183	99004R	PARTICIPANT	\N	PRESENT	0
262250	261183	11070L	PARTICIPANT	\N	PRESENT	0
262251	261183	08010L	PARTICIPANT	\N	PRESENT	0
262252	261183	19531S	PARTICIPANT	\N	PRESENT	0
262253	261183	14159V	PARTICIPANT	\N	PRESENT	0
262254	261183	14199E	PARTICIPANT	\N	PRESENT	0
262255	261183	11048N	PARTICIPANT	\N	PRESENT	0
262256	261183	14187A	PARTICIPANT	\N	PRESENT	0
262257	261183	08073C	PARTICIPANT	\N	PRESENT	0
262259	261183	04071H	PARTICIPANT	\N	PRESENT	0
262260	261183	04061F	PARTICIPANT	\N	PRESENT	0
262266	262265	14079W	PARTICIPANT	\N	PRESENT	0
262267	262265	08056B	PARTICIPANT	\N	PRESENT	0
262268	262265	19503N	PARTICIPANT	\N	PRESENT	0
262269	262265	95067Q	PARTICIPANT	\N	PRESENT	0
262270	262265	97011G	PARTICIPANT	\N	PRESENT	0
262271	262265	14237S	PARTICIPANT	\N	PRESENT	0
262272	262265	04049K	PARTICIPANT	\N	PRESENT	0
262273	262265	08034U	PARTICIPANT	\N	PRESENT	0
262283	261751	19515S	PARTICIPANT	\N	PRESENT	0
262284	261751	19565D	PARTICIPANT	\N	PRESENT	0
262285	261751	19533U	PARTICIPANT	\N	PRESENT	0
262286	261751	14357A	PARTICIPANT	\N	PRESENT	0
262287	261751	19549D	PARTICIPANT	\N	PRESENT	0
262288	261751	19441R	PARTICIPANT	\N	PRESENT	0
262289	261751	14081Q	PARTICIPANT	\N	PRESENT	0
262290	261751	19413M	PARTICIPANT	\N	PRESENT	0
262291	261751	80013X	PARTICIPANT	\N	PRESENT	0
262292	261751	19631V	PARTICIPANT	\N	PRESENT	0
262293	261751	19551W	PARTICIPANT	\N	PRESENT	0
262294	261751	18083K	PARTICIPANT	\N	PRESENT	0
262295	261751	11099A	PARTICIPANT	\N	PRESENT	0
262296	261751	08068F	PARTICIPANT	\N	PRESENT	0
262297	261751	14051J	PARTICIPANT	\N	PRESENT	0
262298	261751	04049K	PARTICIPANT	\N	PRESENT	0
262299	261751	19705W	PARTICIPANT	\N	PRESENT	0
262300	261751	19707Y	PARTICIPANT	\N	PRESENT	0
262301	261751	08015R	PARTICIPANT	\N	PRESENT	0
262302	261751	19503N	PARTICIPANT	\N	PRESENT	0
262303	261751	08019V	PARTICIPANT	\N	PRESENT	0
262304	261751	14197C	PARTICIPANT	\N	PRESENT	0
262305	261751	19369B	PARTICIPANT	\N	PRESENT	0
262306	261751	19511N	PARTICIPANT	\N	PRESENT	0
262307	261751	19563B	PARTICIPANT	\N	PRESENT	0
262308	261751	14265W	PARTICIPANT	\N	PRESENT	0
262309	261751	14329V	PARTICIPANT	\N	PRESENT	0
262310	261751	19591F	PARTICIPANT	\N	PRESENT	0
262311	261751	14135M	PARTICIPANT	\N	PRESENT	0
262312	261751	19467C	PARTICIPANT	\N	PRESENT	0
262313	261751	08038Y	PARTICIPANT	\N	PRESENT	0
262314	261751	19301E	PARTICIPANT	\N	PRESENT	0
262315	261751	19695N	PARTICIPANT	\N	PRESENT	0
262316	261751	14033T	PARTICIPANT	\N	PRESENT	0
262317	261751	11090Q	PRESIDENT	0	PRESENT	0
262318	261751	01025N	PARTICIPANT	\N	PRESENT	0
262319	261751	14205J	PARTICIPANT	\N	PRESENT	0
262320	261751	04088S	PARTICIPANT	\N	PRESENT	0
262321	261751	14115H	PARTICIPANT	\N	PRESENT	0
262322	261751	19507S	PARTICIPANT	\N	PRESENT	0
262323	261751	19739H	PARTICIPANT	\N	PRESENT	0
262324	261751	04097T	PARTICIPANT	\N	PRESENT	0
262325	261751	19747H	PARTICIPANT	\N	PRESENT	0
262326	261751	14207L	PARTICIPANT	\N	PRESENT	0
262327	261751	04043D	PARTICIPANT	\N	PRESENT	0
262328	261751	19619A	PARTICIPANT	\N	PRESENT	0
262329	261751	17589D	PARTICIPANT	\N	PRESENT	0
262330	261751	14257W	PARTICIPANT	\N	PRESENT	0
247274	247273	08044W	PARTICIPANT	\N	PRESENT	0
247314	247284	86034E	PARTICIPANT	\N	PRESENT	0
247315	247284	14331P	PARTICIPANT	\N	PRESENT	0
247316	247284	14191V	PARTICIPANT	\N	PRESENT	0
247317	247284	19681G	PARTICIPANT	\N	PRESENT	0
247318	247284	10006L	PARTICIPANT	\N	PRESENT	0
247320	247284	08060W	PARTICIPANT	\N	PRESENT	0
247321	247284	11072N	PARTICIPANT	\N	PRESENT	0
247322	247284	14107H	PARTICIPANT	\N	PRESENT	0
247323	247284	08073C	PARTICIPANT	\N	PRESENT	0
247324	247284	14039A	PARTICIPANT	\N	PRESENT	0
247325	247284	17589D	PARTICIPANT	\N	PRESENT	0
247326	247284	14063N	PARTICIPANT	\N	PRESENT	0
247327	247284	14227Q	PARTICIPANT	\N	PRESENT	0
247328	247284	19583F	PARTICIPANT	\N	PRESENT	0
247329	247284	19387D	PARTICIPANT	\N	PRESENT	0
247330	247284	19319Q	PARTICIPANT	\N	PRESENT	0
247331	247284	19717B	PARTICIPANT	\N	PRESENT	0
247332	247284	19441R	PARTICIPANT	\N	PRESENT	0
247333	247284	19333N	PARTICIPANT	\N	PRESENT	0
247334	247284	19329S	PARTICIPANT	\N	PRESENT	0
247335	247284	12016W	PARTICIPANT	\N	PRESENT	0
244605	244151	14331P	PARTICIPANT	\N	PRESENT	0
244606	244151	04071H	PARTICIPANT	\N	PRESENT	0
244607	244151	19647E	PARTICIPANT	\N	PRESENT	0
244608	244151	19711U	PARTICIPANT	\N	PRESENT	0
244609	244151	19531S	PARTICIPANT	\N	PRESENT	0
244610	244151	08034U	PARTICIPANT	\N	PRESENT	0
244611	244151	11053K	PARTICIPANT	\N	PRESENT	0
244612	244151	89017R	PARTICIPANT	\N	PRESENT	0
244613	244151	19667J	PARTICIPANT	\N	PRESENT	0
244614	244151	11074Q	PRESIDENT	0	PRESENT	0
244615	244151	08011M	PARTICIPANT	\N	PRESENT	0
244616	244151	19671E	PARTICIPANT	\N	PRESENT	0
244617	244151	14225N	PARTICIPANT	\N	PRESENT	0
244618	244151	14173T	PARTICIPANT	\N	PRESENT	0
244619	244151	11040E	PARTICIPANT	\N	PRESENT	0
244620	244151	14083S	PARTICIPANT	\N	PRESENT	0
244621	244151	14085U	PARTICIPANT	\N	PRESENT	0
244622	244151	19349W	PARTICIPANT	\N	PRESENT	0
244623	244151	19741B	PARTICIPANT	\N	PRESENT	0
244624	244151	99004R	PARTICIPANT	\N	PRESENT	0
244625	244151	14253S	PARTICIPANT	\N	PRESENT	0
244626	244151	04061F	PARTICIPANT	\N	PRESENT	0
244627	244151	14327T	PARTICIPANT	\N	EXCUSE	0
244628	244151	07029T	PARTICIPANT	\N	EXCUSE	0
244629	244151	11048N	PARTICIPANT	\N	EXCUSE	0
244630	244151	11012A	PARTICIPANT	\N	EXCUSE	0
244631	244151	08010L	PARTICIPANT	\N	EXCUSE	0
244632	244151	14034U	PARTICIPANT	\N	EXCUSE	0
247336	247284	14277B	PARTICIPANT	\N	PRESENT	0
247337	247284	08053X	PARTICIPANT	\N	PRESENT	0
247338	247284	14073Q	PARTICIPANT	\N	PRESENT	0
247339	247284	14103D	PARTICIPANT	\N	PRESENT	0
247340	247284	14201E	PARTICIPANT	\N	PRESENT	0
247341	247284	19727D	PARTICIPANT	\N	PRESENT	0
247342	247284	19503N	PARTICIPANT	\N	PRESENT	0
243278	241241	15447F	PARTICIPANT	\N	PRESENT	0
243279	241241	19703U	PARTICIPANT	\N	PRESENT	0
243280	241241	14097Y	PARTICIPANT	\N	PRESENT	0
243281	241241	19729F	PARTICIPANT	\N	PRESENT	0
243282	241241	19443T	PARTICIPANT	\N	PRESENT	0
243283	241241	08035V	PARTICIPANT	\N	PRESENT	0
243284	241241	08058D	PRESIDENT	0	PRESENT	0
243285	241241	11053K	PARTICIPANT	\N	PRESENT	0
243286	241241	19581D	PARTICIPANT	\N	PRESENT	0
243287	241241	11049P	PARTICIPANT	\N	PRESENT	0
243288	241241	19721W	PARTICIPANT	\N	PRESENT	0
243289	241241	04085P	PARTICIPANT	\N	PRESENT	0
243290	241241	04086Q	PARTICIPANT	\N	EXCUSE	0
243291	241241	14021P	PARTICIPANT	\N	EXCUSE	0
247343	247284	08014Q	PARTICIPANT	\N	PRESENT	0
247344	247284	19715Y	PARTICIPANT	\N	PRESENT	0
247345	247284	14281W	PARTICIPANT	\N	PRESENT	0
247346	247284	14028W	PARTICIPANT	\N	PRESENT	0
247347	247284	19687N	PARTICIPANT	\N	PRESENT	0
247348	247284	19659J	PARTICIPANT	\N	PRESENT	0
247349	247284	08052W	PARTICIPANT	\N	PRESENT	0
247350	247284	14219Q	PARTICIPANT	\N	PRESENT	0
247351	247284	19629C	PARTICIPANT	\N	PRESENT	0
247352	247284	14197C	PARTICIPANT	\N	PRESENT	0
247353	247284	19549D	PARTICIPANT	\N	PRESENT	0
247354	247284	19631V	PARTICIPANT	\N	PRESENT	0
247355	247284	17779H	PARTICIPANT	\N	PRESENT	0
247356	247284	80027E	PARTICIPANT	\N	PRESENT	0
247357	247284	11066Q	PARTICIPANT	\N	PRESENT	0
247358	247284	19251M	PARTICIPANT	\N	PRESENT	0
247359	247284	14051J	PARTICIPANT	\N	PRESENT	0
247360	247284	80013X	PARTICIPANT	\N	PRESENT	0
247361	247284	11077T	PARTICIPANT	\N	PRESENT	0
247362	247284	19651A	PARTICIPANT	\N	PRESENT	0
247363	247284	11104D	PARTICIPANT	\N	PRESENT	0
247364	247284	19725B	PARTICIPANT	\N	PRESENT	0
247365	247284	14275Y	PARTICIPANT	\N	PRESENT	0
247366	247284	14229S	PARTICIPANT	\N	PRESENT	0
247367	247284	14207L	PARTICIPANT	\N	PRESENT	0
247368	247284	19731Y	PARTICIPANT	\N	PRESENT	0
247369	247284	14055N	PARTICIPANT	\N	PRESENT	0
247370	247284	19515S	PARTICIPANT	\N	PRESENT	0
247371	247284	19489J	PARTICIPANT	\N	PRESENT	0
247372	247284	05008E	PARTICIPANT	\N	PRESENT	0
247373	247284	19741B	PARTICIPANT	\N	PRESENT	0
247374	247284	08024S	PARTICIPANT	\N	PRESENT	0
247375	247284	19575F	PARTICIPANT	\N	PRESENT	0
247376	247284	08035V	PARTICIPANT	\N	PRESENT	0
247377	247284	19649G	PARTICIPANT	\N	PRESENT	0
247378	247284	04085P	PARTICIPANT	\N	PRESENT	0
247379	247284	19695N	PARTICIPANT	\N	PRESENT	0
247380	247284	04038G	PARTICIPANT	\N	PRESENT	0
247381	247284	01028R	PARTICIPANT	\N	PRESENT	0
247382	247284	11056N	PARTICIPANT	\N	PRESENT	0
247383	247284	08043V	PARTICIPANT	\N	PRESENT	0
247384	247284	14211G	PARTICIPANT	\N	PRESENT	0
247385	247284	95037J	PARTICIPANT	\N	PRESENT	0
247386	247284	14157T	PARTICIPANT	\N	PRESENT	0
247387	247284	19301E	PARTICIPANT	\N	PRESENT	0
247388	247284	19545Y	PARTICIPANT	\N	PRESENT	0
247389	247284	14195A	PARTICIPANT	\N	PRESENT	0
247390	247284	99004R	PARTICIPANT	\N	PRESENT	0
247391	247284	14251Q	PARTICIPANT	\N	PRESENT	0
247392	247284	01058X	PARTICIPANT	\N	PRESENT	0
247393	247284	98035U	PARTICIPANT	\N	PRESENT	0
247394	247284	08010L	PARTICIPANT	\N	PRESENT	0
247395	247284	08058D	PARTICIPANT	\N	PRESENT	0
247396	247284	08055A	PARTICIPANT	\N	PRESENT	0
247397	247284	11027H	PARTICIPANT	\N	PRESENT	0
247398	247284	14123H	PARTICIPANT	\N	PRESENT	0
247399	247284	04059M	PARTICIPANT	\N	PRESENT	0
247400	247284	14225N	PARTICIPANT	\N	PRESENT	0
247401	247284	14065Q	PARTICIPANT	\N	PRESENT	0
247402	247284	14021P	PARTICIPANT	\N	PRESENT	0
247403	247284	14151M	PARTICIPANT	\N	PRESENT	0
247404	247284	19643A	PARTICIPANT	\N	PRESENT	0
247405	247284	14223L	PARTICIPANT	\N	PRESENT	0
247406	247284	19647E	PARTICIPANT	\N	PRESENT	0
247407	247284	08020N	PARTICIPANT	\N	PRESENT	0
247408	247284	08038Y	PARTICIPANT	\N	PRESENT	0
247409	247284	19711U	PARTICIPANT	\N	PRESENT	0
247410	247284	08012N	PARTICIPANT	\N	PRESENT	0
247411	247284	11067R	PARTICIPANT	\N	PRESENT	0
247412	247284	19531S	PARTICIPANT	\N	PRESENT	0
247413	247284	17637T	PARTICIPANT	\N	PRESENT	0
247414	247284	19295A	PARTICIPANT	\N	PRESENT	0
247415	247284	95062K	PARTICIPANT	\N	PRESENT	0
247416	247284	14121F	PARTICIPANT	\N	PRESENT	0
247417	247284	14085U	PARTICIPANT	\N	PRESENT	0
247418	247284	19679N	PARTICIPANT	\N	PRESENT	0
247419	247284	19525U	PARTICIPANT	\N	PRESENT	0
247420	247284	14081Q	PARTICIPANT	\N	PRESENT	0
247421	247284	11041F	PARTICIPANT	\N	PRESENT	0
247422	247284	19683J	PARTICIPANT	\N	PRESENT	0
247423	247284	11109J	PARTICIPANT	\N	PRESENT	0
247424	247284	11080N	PARTICIPANT	\N	PRESENT	0
247425	247284	11054L	PARTICIPANT	\N	PRESENT	0
247426	247284	19689Q	PARTICIPANT	\N	PRESENT	0
247427	247284	01057W	PARTICIPANT	\N	PRESENT	0
247428	247284	19413M	PARTICIPANT	\N	PRESENT	0
247429	247284	87003B	PARTICIPANT	\N	PRESENT	0
247430	247284	19591F	PARTICIPANT	\N	PRESENT	0
247431	247284	01062T	PARTICIPANT	\N	PRESENT	0
247432	247284	11048N	PARTICIPANT	\N	PRESENT	0
247433	247284	08017T	PARTICIPANT	\N	PRESENT	0
247434	247284	19703U	PARTICIPANT	\N	PRESENT	0
247435	247284	08045X	PARTICIPANT	\N	PRESENT	0
247436	247284	19527W	PARTICIPANT	\N	PRESENT	0
247437	247284	14187A	PARTICIPANT	\N	PRESENT	0
247438	247284	14031R	PARTICIPANT	\N	PRESENT	0
266981	266980	11026G	PARTICIPANT	\N	PRESENT	0
266982	266980	14097Y	PARTICIPANT	\N	PRESENT	0
266983	266980	14133K	PARTICIPANT	\N	PRESENT	0
266984	266980	08015R	PARTICIPANT	\N	PRESENT	0
266985	266980	04088S	PARTICIPANT	\N	PRESENT	0
266986	266980	14079W	PARTICIPANT	\N	PRESENT	0
266987	266980	04097T	PARTICIPANT	\N	PRESENT	0
266988	266980	19573D	PARTICIPANT	\N	PRESENT	0
266989	266980	98050T	PARTICIPANT	\N	PRESENT	0
266990	266980	11040E	PARTICIPANT	\N	PRESENT	0
266991	266980	08056B	PARTICIPANT	\N	PRESENT	0
266992	266980	19521Q	PARTICIPANT	\N	PRESENT	0
266993	266980	04035D	PARTICIPANT	\N	PRESENT	0
267409	267408	19549D	PARTICIPANT	\N	PRESENT	0
267410	267408	08060W	PARTICIPANT	\N	PRESENT	0
267411	267408	04049K	PARTICIPANT	\N	PRESENT	0
267412	267408	14031R	PARTICIPANT	\N	PRESENT	0
267413	267408	14169X	PARTICIPANT	\N	PRESENT	0
268011	268010	96004D	PARTICIPANT	\N	PRESENT	0
268012	268010	14001X	PARTICIPANT	\N	PRESENT	0
268020	267356	11040E	PARTICIPANT	\N	PRESENT	0
268021	267356	19667J	PARTICIPANT	\N	PRESENT	0
268032	268031	11074Q	PARTICIPANT	\N	PRESENT	0
268033	268031	12016W	PARTICIPANT	\N	PRESENT	0
268484	267403	19447X	PARTICIPANT	\N	PRESENT	0
268486	267403	04047H	PARTICIPANT	\N	EXCUSE	0
268487	267403	19729F	PARTICIPANT	\N	EXCUSE	0
270213	270212	11054L	PARTICIPANT	\N	PRESENT	0
270267	270266	19569H	PARTICIPANT	\N	PRESENT	0
270268	270266	10015M	PARTICIPANT	\N	PRESENT	0
270269	270266	89017R	PARTICIPANT	\N	PRESENT	0
270270	270266	14079W	PARTICIPANT	\N	PRESENT	0
270271	270266	14255U	PARTICIPANT	\N	PRESENT	0
270272	270266	11026G	PARTICIPANT	\N	PRESENT	0
270314	270312	19673G	PARTICIPANT	\N	PRESENT	0
270315	270312	19649G	PARTICIPANT	\N	PRESENT	0
270316	270312	11026G	PARTICIPANT	\N	PRESENT	0
270319	270318	14193X	PARTICIPANT	\N	PRESENT	0
270320	270318	95067Q	PARTICIPANT	\N	PRESENT	0
270333	270332	11074Q	PARTICIPANT	\N	PRESENT	0
270334	270332	08011M	PARTICIPANT	\N	PRESENT	0
270335	270332	14327T	PARTICIPANT	\N	PRESENT	0
270336	270332	14225N	PARTICIPANT	\N	PRESENT	0
270337	270332	08073C	PARTICIPANT	\N	PRESENT	0
270338	270332	01057W	PARTICIPANT	\N	PRESENT	0
270340	270339	08015R	PARTICIPANT	\N	PRESENT	0
270341	270339	14225N	PARTICIPANT	\N	PRESENT	0
270342	270339	14001X	PARTICIPANT	\N	PRESENT	0
270344	270343	08015R	PARTICIPANT	\N	PRESENT	0
270345	270343	14225N	PARTICIPANT	\N	PRESENT	0
270346	270343	19735D	PARTICIPANT	\N	PRESENT	0
270347	270343	14001X	PARTICIPANT	\N	PRESENT	0
270348	270343	04049K	PARTICIPANT	\N	PRESENT	0
270349	270343	14030Q	PARTICIPANT	\N	PRESENT	0
270354	270353	19611R	PARTICIPANT	\N	PRESENT	0
270356	270355	19611R	PARTICIPANT	\N	PRESENT	0
270358	270357	11064N	PARTICIPANT	\N	PRESENT	0
270368	270367	19621T	PARTICIPANT	\N	PRESENT	0
270361	270360	11053K	PARTICIPANT	\N	PRESENT	0
270362	270360	05012A	PARTICIPANT	\N	PRESENT	0
270365	262765	14030Q	PARTICIPANT	\N	PRESENT	0
270366	262765	19731Y	PARTICIPANT	\N	PRESENT	0
270369	270367	08031R	PARTICIPANT	\N	PRESENT	0
270370	270367	19731Y	PARTICIPANT	\N	PRESENT	0
270381	270380	08034U	PARTICIPANT	\N	PRESENT	0
270387	270386	04092N	PARTICIPANT	\N	PRESENT	0
270388	270386	14239U	PARTICIPANT	\N	PRESENT	0
270389	270386	11031D	PARTICIPANT	\N	PRESENT	0
270390	270386	19691J	PARTICIPANT	\N	PRESENT	0
270391	270386	19683J	PARTICIPANT	\N	PRESENT	0
270392	270386	11097X	PARTICIPANT	\N	PRESENT	0
270394	270393	10006L	PARTICIPANT	\N	PRESENT	0
270398	263471	04086Q	PARTICIPANT	\N	PRESENT	0
270399	263471	19525U	PARTICIPANT	\N	PRESENT	0
270400	263471	96004D	PARTICIPANT	\N	PRESENT	0
270401	263471	19711U	PARTICIPANT	\N	PRESENT	0
270402	263471	99004R	PARTICIPANT	\N	PRESENT	0
270403	263471	19683J	PARTICIPANT	\N	PRESENT	0
270404	263471	19689Q	PARTICIPANT	\N	PRESENT	0
270405	263471	19569H	PARTICIPANT	\N	PRESENT	0
270406	263471	19593H	PARTICIPANT	\N	PRESENT	0
270407	263471	11072N	PARTICIPANT	\N	PRESENT	0
270408	263471	19663E	PARTICIPANT	\N	PRESENT	0
270409	263471	14225N	PARTICIPANT	\N	PRESENT	0
270410	263471	98022P	PARTICIPANT	\N	PRESENT	0
270411	263471	08010L	PARTICIPANT	\N	PRESENT	0
270412	263471	14147R	PARTICIPANT	\N	PRESENT	0
270413	263471	08034U	PARTICIPANT	\N	PRESENT	0
270414	263471	14179A	PARTICIPANT	\N	PRESENT	0
270415	263471	14237S	PARTICIPANT	\N	PRESENT	0
270170	270137	19483C	PARTICIPANT	\N	PRESENT	0
270171	270137	14265W	PARTICIPANT	\N	PRESENT	0
270416	263471	19697Q	PARTICIPANT	\N	PRESENT	0
270417	263471	19737F	PARTICIPANT	\N	PRESENT	0
270418	263471	19441R	PARTICIPANT	\N	PRESENT	0
270419	263471	14197C	PARTICIPANT	\N	PRESENT	0
270420	263471	19671E	PARTICIPANT	\N	PRESENT	0
270421	263471	19387D	PARTICIPANT	\N	PRESENT	0
270422	263471	11026G	PARTICIPANT	\N	PRESENT	0
270423	263471	11033F	PARTICIPANT	\N	PRESENT	0
270424	263471	04057K	PARTICIPANT	\N	PRESENT	0
270425	263471	19543W	PARTICIPANT	\N	PRESENT	0
270426	263471	95063L	PARTICIPANT	\N	PRESENT	0
270427	263471	14097Y	PARTICIPANT	\N	PRESENT	0
270428	263471	04033B	PARTICIPANT	\N	PRESENT	0
270429	263471	11090Q	PARTICIPANT	\N	PRESENT	0
270430	263471	01028R	PARTICIPANT	\N	PRESENT	0
270431	263471	19741B	PARTICIPANT	\N	PRESENT	0
270432	263471	11081P	PARTICIPANT	\N	PRESENT	0
270433	263471	14219Q	PARTICIPANT	\N	PRESENT	0
270434	263471	04061F	PARTICIPANT	\N	PRESENT	0
270435	263471	14089Y	PARTICIPANT	\N	PRESENT	0
270436	263471	14030Q	PARTICIPANT	\N	PRESENT	0
270437	263471	11083R	PARTICIPANT	\N	PRESENT	0
270438	263471	17637T	PARTICIPANT	\N	PRESENT	0
270442	263471	19533U	PARTICIPANT	\N	PRESENT	0
270443	263471	14111D	PARTICIPANT	\N	PRESENT	0
270444	263471	14229S	PARTICIPANT	\N	PRESENT	0
270445	263471	18083K	PARTICIPANT	\N	PRESENT	0
270446	263471	14157T	PARTICIPANT	\N	PRESENT	0
270447	263471	19399H	PARTICIPANT	\N	PRESENT	0
270448	263471	08061X	PARTICIPANT	\N	PRESENT	0
270449	263471	14251Q	PARTICIPANT	\N	PRESENT	0
270450	263471	14231L	PARTICIPANT	\N	PRESENT	0
270451	263471	14205J	PARTICIPANT	\N	PRESENT	0
270502	263472	19387D	PARTICIPANT	\N	PRESENT	0
270503	263472	19593H	PARTICIPANT	\N	PRESENT	0
270504	263472	14205J	PARTICIPANT	\N	PRESENT	0
270505	263472	14229S	PARTICIPANT	\N	PRESENT	0
270506	263472	04057K	PARTICIPANT	\N	PRESENT	0
270507	263472	11026G	PARTICIPANT	\N	PRESENT	0
270508	263472	19399H	PARTICIPANT	\N	PRESENT	0
270509	263472	19741B	PARTICIPANT	\N	PRESENT	0
270510	263472	18083K	PARTICIPANT	\N	PRESENT	0
270511	263472	14231L	PARTICIPANT	\N	PRESENT	0
270512	263472	19711U	PARTICIPANT	\N	PRESENT	0
270513	263472	19533U	PARTICIPANT	\N	PRESENT	0
270514	263472	14089Y	PARTICIPANT	\N	PRESENT	0
270515	263472	14179A	PARTICIPANT	\N	PRESENT	0
270516	263472	14219Q	PARTICIPANT	\N	PRESENT	0
270517	263472	11083R	PARTICIPANT	\N	PRESENT	0
270518	263472	14135M	PARTICIPANT	\N	PRESENT	0
270519	263472	14251Q	PARTICIPANT	\N	PRESENT	0
270520	263472	14111D	PARTICIPANT	\N	PRESENT	0
270521	263472	19737F	PARTICIPANT	\N	PRESENT	0
270522	263472	19441R	PARTICIPANT	\N	PRESENT	0
270524	270523	95067Q	PARTICIPANT	\N	PRESENT	0
270527	263472	19543W	PARTICIPANT	\N	PRESENT	0
270534	270532	14071N	PARTICIPANT	\N	PRESENT	0
270535	270533	14071N	PARTICIPANT	\N	PRESENT	0
270537	270536	10006L	PARTICIPANT	\N	PRESENT	0
270538	270536	08052W	PARTICIPANT	\N	PRESENT	0
270539	270536	19553Y	PARTICIPANT	\N	PRESENT	0
270541	270540	08052W	PARTICIPANT	\N	PRESENT	0
270542	270540	10006L	PARTICIPANT	\N	PRESENT	0
270543	270540	19553Y	PARTICIPANT	\N	PRESENT	0
270545	270544	98029W	PARTICIPANT	\N	PRESENT	0
270546	270544	08056B	PARTICIPANT	\N	PRESENT	0
270547	270544	08053X	PARTICIPANT	\N	PRESENT	0
270564	270562	14071N	PARTICIPANT	\N	PRESENT	0
270565	270563	10006L	PARTICIPANT	\N	PRESENT	0
270568	270567	96004D	PARTICIPANT	\N	PRESENT	0
270569	270567	14089Y	PARTICIPANT	\N	PRESENT	0
270570	270567	04061F	PARTICIPANT	\N	PRESENT	0
270571	268440	19663E	PARTICIPANT	\N	EXCUSE	0
270573	268443	19663E	PARTICIPANT	\N	EXCUSE	0
270500	263472	04086Q	PARTICIPANT	\N	PRESENT	0
270501	263472	98022P	PARTICIPANT	\N	PRESENT	0
248264	248263	98029W	PARTICIPANT	\N	PRESENT	0
248265	248263	08056B	PARTICIPANT	\N	PRESENT	0
248266	248263	11027H	PARTICIPANT	\N	PRESENT	0
248267	248263	11080N	PARTICIPANT	\N	PRESENT	0
248268	248263	11033F	PARTICIPANT	\N	PRESENT	0
248269	248263	98022P	PARTICIPANT	\N	PRESENT	0
248270	248263	19669L	PARTICIPANT	\N	PRESENT	0
248271	248263	04008A	PARTICIPANT	\N	EXCUSE	0
249279	249278	08055A	PARTICIPANT	\N	PRESENT	0
249280	249278	19575F	PARTICIPANT	\N	PRESENT	0
249281	249278	19383Y	PARTICIPANT	\N	PRESENT	0
249282	249278	11103C	PARTICIPANT	\N	PRESENT	0
249283	249278	11080N	PARTICIPANT	\N	PRESENT	0
249284	249278	14357A	PARTICIPANT	\N	PRESENT	0
249285	249278	17589D	PARTICIPANT	\N	PRESENT	0
249286	249278	04089T	PARTICIPANT	\N	PRESENT	0
249287	249278	19507S	PARTICIPANT	\N	PRESENT	0
249288	249278	14187A	PARTICIPANT	\N	PRESENT	0
249289	249278	08069G	PARTICIPANT	\N	PRESENT	0
249290	249278	19723Y	PARTICIPANT	\N	PRESENT	0
249291	249278	08034U	PARTICIPANT	\N	PRESENT	0
249292	249278	16685X	PARTICIPANT	\N	PRESENT	0
249293	249278	14103D	PARTICIPANT	\N	PRESENT	0
249294	249278	08053X	PARTICIPANT	\N	PRESENT	0
249295	249278	14119M	PARTICIPANT	\N	PRESENT	0
249299	249278	11090Q	PARTICIPANT	\N	PRESENT	0
249297	249278	04088S	PARTICIPANT	\N	PRESENT	0
249298	249278	98050T	PARTICIPANT	\N	PRESENT	0
249300	249278	19739H	PARTICIPANT	\N	PRESENT	0
249301	249278	17583W	PARTICIPANT	\N	PRESENT	0
249302	249278	19679N	PARTICIPANT	\N	PRESENT	0
249303	249278	14107H	PARTICIPANT	\N	PRESENT	0
249304	249278	14173T	PARTICIPANT	\N	PRESENT	0
250555	250554	14255U	PARTICIPANT	\N	PRESENT	0
250557	250556	14255U	PARTICIPANT	\N	PRESENT	0
255779	255595	19701S	PARTICIPANT	\N	PRESENT	0
255800	255595	95063L	PARTICIPANT	\N	PRESENT	0
255818	255595	19675J	PARTICIPANT	\N	PRESENT	0
255819	255595	08010L	PARTICIPANT	\N	PRESENT	0
255820	255595	19715Y	PARTICIPANT	\N	PRESENT	0
255821	255595	80013X	PARTICIPANT	\N	PRESENT	0
255822	255595	14033T	PARTICIPANT	\N	PRESENT	0
255847	255595	19253P	PARTICIPANT	\N	PRESENT	0
255848	255595	05008E	PARTICIPANT	\N	PRESENT	0
255849	255595	19553Y	PARTICIPANT	\N	PRESENT	0
255877	255876	14231L	PARTICIPANT	\N	PRESENT	0
255878	255876	01057W	PARTICIPANT	\N	PRESENT	0
255879	255876	96004D	PARTICIPANT	\N	PRESENT	0
255880	255876	97011G	PARTICIPANT	\N	PRESENT	0
255883	255882	96004D	PARTICIPANT	\N	PRESENT	0
255884	255882	97011G	PARTICIPANT	\N	PRESENT	0
255885	255882	01057W	PARTICIPANT	\N	PRESENT	0
255914	255913	14030Q	PARTICIPANT	\N	PRESENT	0
255915	255913	08043V	PARTICIPANT	\N	PRESENT	0
255916	255913	19701S	PARTICIPANT	\N	PRESENT	0
255965	255959	96004D	PARTICIPANT	\N	EXCUSE	0
255966	255960	96004D	PARTICIPANT	\N	EXCUSE	0
255967	255960	19715Y	PARTICIPANT	\N	EXCUSE	0
255968	255959	19715Y	PARTICIPANT	\N	EXCUSE	0
256130	255959	11010L	PARTICIPANT	\N	EXCUSE	0
256131	255959	19329S	PARTICIPANT	\N	EXCUSE	0
256133	255959	19583F	PARTICIPANT	\N	EXCUSE	0
256134	255959	19729F	PARTICIPANT	\N	EXCUSE	0
256136	255960	11010L	PARTICIPANT	\N	EXCUSE	0
256137	255960	19329S	PARTICIPANT	\N	EXCUSE	0
256138	255960	19583F	PARTICIPANT	\N	EXCUSE	0
256139	255960	19729F	PARTICIPANT	\N	EXCUSE	0
256140	255960	14331P	PARTICIPANT	\N	EXCUSE	0
256141	255960	14275Y	PARTICIPANT	\N	EXCUSE	0
257916	256024	04089T	PARTICIPANT	\N	EXCUSE	0
257917	256024	11101A	PARTICIPANT	\N	EXCUSE	0
257918	256024	08021P	PARTICIPANT	\N	EXCUSE	0
257919	256024	11081P	PARTICIPANT	\N	EXCUSE	0
257920	255991	02002K	PARTICIPANT	\N	PRESENT	0
257921	257788	01060R	PARTICIPANT	\N	PRESENT	0
257922	257788	14001X	PARTICIPANT	\N	PRESENT	0
257923	257788	19581D	PARTICIPANT	\N	PRESENT	0
257924	257788	04044E	PARTICIPANT	\N	PRESENT	0
257925	257788	19585H	PARTICIPANT	\N	PRESENT	0
257926	257788	04047H	PARTICIPANT	\N	PRESENT	0
257927	257788	01028R	PARTICIPANT	\N	PRESENT	0
257928	257788	19447X	PARTICIPANT	\N	PRESENT	0
257929	257788	14231L	PARTICIPANT	\N	PRESENT	0
257930	257788	05008E	PRESIDENT	0	PRESENT	0
257931	257788	19489J	PARTICIPANT	\N	PRESENT	0
257932	257788	14041T	PARTICIPANT	\N	PRESENT	0
257933	257788	14147R	PARTICIPANT	\N	PRESENT	0
257934	257788	14151M	PARTICIPANT	\N	PRESENT	0
257935	257788	14215L	PARTICIPANT	\N	PRESENT	0
257936	257788	19483C	PARTICIPANT	\N	PRESENT	0
257937	257788	11072N	PARTICIPANT	\N	PRESENT	0
257938	257788	98035U	PARTICIPANT	\N	PRESENT	0
257939	257788	14053L	PARTICIPANT	\N	PRESENT	0
257940	257788	19649G	PARTICIPANT	\N	PRESENT	0
257941	257788	14111D	PARTICIPANT	\N	PRESENT	0
257942	257788	14065Q	PARTICIPANT	\N	PRESENT	0
257943	257788	07034Q	PARTICIPANT	\N	PRESENT	0
257944	257788	08045X	PARTICIPANT	\N	PRESENT	0
257945	257788	11026G	PARTICIPANT	\N	PRESENT	0
257946	257788	10015M	PARTICIPANT	\N	PRESENT	0
257947	257788	19253P	PARTICIPANT	\N	PRESENT	0
257948	257788	04038G	PARTICIPANT	\N	PRESENT	0
257949	257788	19719D	PARTICIPANT	\N	PRESENT	0
257950	257788	11033F	PARTICIPANT	\N	PRESENT	0
257951	257788	19725B	PARTICIPANT	\N	PRESENT	0
257952	257788	19729F	PARTICIPANT	\N	PRESENT	0
257953	257788	19629C	PARTICIPANT	\N	PRESENT	0
257954	257788	08044W	PARTICIPANT	\N	PRESENT	0
257955	257788	14069U	PARTICIPANT	\N	PRESENT	0
257956	257788	11049P	PARTICIPANT	\N	PRESENT	0
257957	257788	04008A	PARTICIPANT	\N	PRESENT	0
257958	257788	14021P	PARTICIPANT	\N	PRESENT	0
257959	257788	11085T	PARTICIPANT	\N	EXCUSE	0
257960	257788	08018U	PARTICIPANT	\N	EXCUSE	0
257961	255991	11065P	PARTICIPANT	\N	PRESENT	0
257962	240326	89017R	PARTICIPANT	\N	PRESENT	0
257963	240326	14239U	PARTICIPANT	\N	PRESENT	0
257964	256024	04043D	PARTICIPANT	\N	PRESENT	0
258037	258034	14217N	PARTICIPANT	\N	PRESENT	0
258038	258034	10006L	PARTICIPANT	\N	PRESENT	0
258035	258034	07034Q	PARTICIPANT	\N	PRESENT	0
258036	258034	19575F	PARTICIPANT	\N	PRESENT	0
258040	258039	14239U	PARTICIPANT	\N	EXCUSE	0
258041	258039	14053L	PARTICIPANT	\N	EXCUSE	0
258042	258039	08045X	PARTICIPANT	\N	EXCUSE	0
258043	258039	19295A	PARTICIPANT	\N	EXCUSE	0
258044	257788	19673G	PARTICIPANT	\N	PRESENT	0
258014	255724	19657G	PARTICIPANT	\N	EXCUSE	0
258015	255724	14261S	PARTICIPANT	\N	EXCUSE	0
258016	255724	08041T	PARTICIPANT	\N	EXCUSE	0
258017	255724	19577H	PARTICIPANT	\N	EXCUSE	0
258045	257788	14179A	PARTICIPANT	\N	PRESENT	0
258046	257788	19543W	PARTICIPANT	\N	PRESENT	0
258047	257788	14089Y	PARTICIPANT	\N	PRESENT	0
258048	257788	14259Y	PARTICIPANT	\N	PRESENT	0
258049	255729	14327T	PARTICIPANT	\N	PRESENT	0
258050	255729	14331P	PARTICIPANT	\N	PRESENT	0
258051	255729	04071H	PARTICIPANT	\N	PRESENT	0
258052	255729	01048V	PARTICIPANT	\N	PRESENT	0
258053	255729	19545Y	PARTICIPANT	\N	PRESENT	0
258054	255729	01057W	PARTICIPANT	\N	PRESENT	0
258055	255729	11053K	PARTICIPANT	\N	PRESENT	0
258056	255729	19667J	PARTICIPANT	\N	PRESENT	0
258057	255729	11074Q	PRESIDENT	0	PRESENT	0
258058	255729	89017R	PARTICIPANT	\N	PRESENT	0
258059	255729	19671E	PARTICIPANT	\N	PRESENT	0
258060	255729	14225N	PARTICIPANT	\N	PRESENT	0
258061	255729	88008L	PARTICIPANT	\N	PRESENT	0
258062	255729	11110B	PARTICIPANT	\N	PRESENT	0
258063	255729	07029T	PARTICIPANT	\N	PRESENT	0
257997	255991	80027E	PARTICIPANT	\N	PRESENT	0
257998	255724	19569H	PARTICIPANT	\N	PRESENT	0
257999	255724	14026U	PARTICIPANT	\N	PRESENT	0
258000	255724	19679N	PARTICIPANT	\N	PRESENT	0
258001	255724	19575F	PARTICIPANT	\N	PRESENT	0
258002	255724	11045K	PARTICIPANT	\N	PRESENT	0
258003	255724	14239U	PARTICIPANT	\N	EXCUSE	0
258004	255724	19715Y	PARTICIPANT	\N	EXCUSE	0
258064	255729	14085U	PARTICIPANT	\N	PRESENT	0
258065	255729	14277B	PARTICIPANT	\N	PRESENT	0
258066	255729	07004J	PARTICIPANT	\N	PRESENT	0
258067	255729	19349W	PARTICIPANT	\N	PRESENT	0
258068	255729	08010L	PARTICIPANT	\N	PRESENT	0
258069	255729	14253S	PARTICIPANT	\N	PRESENT	0
258070	255729	11048N	PARTICIPANT	\N	PRESENT	0
258071	255729	19647E	PARTICIPANT	\N	PRESENT	0
258072	255729	19479G	PARTICIPANT	\N	PRESENT	0
258073	255729	19711U	PARTICIPANT	\N	PRESENT	0
258074	255729	08034U	PARTICIPANT	\N	PRESENT	0
262331	261183	01048V	PARTICIPANT	\N	PRESENT	0
262333	262332	19251M	PARTICIPANT	\N	PRESENT	0
262334	262332	98022P	PARTICIPANT	\N	PRESENT	0
262335	262332	19593H	PARTICIPANT	\N	PRESENT	0
262337	262336	14199E	PARTICIPANT	\N	PRESENT	0
262338	262336	08069G	PARTICIPANT	\N	PRESENT	0
262339	262336	10015M	PARTICIPANT	\N	PRESENT	0
262340	262336	14097Y	PARTICIPANT	\N	PRESENT	0
262346	261091	14255U	PARTICIPANT	\N	EXCUSE	0
262347	261091	04035D	PARTICIPANT	\N	EXCUSE	0
262348	261091	14028W	PARTICIPANT	\N	EXCUSE	0
262507	262350	14065Q	PARTICIPANT	\N	PRESENT	0
262508	262350	14111D	PARTICIPANT	\N	PRESENT	0
262509	262350	19581D	PARTICIPANT	\N	PRESENT	0
262510	262350	14069U	PARTICIPANT	\N	PRESENT	0
262511	262350	11085T	PARTICIPANT	\N	PRESENT	0
262512	262350	08018U	PARTICIPANT	\N	EXCUSE	0
262513	262350	19447X	PARTICIPANT	\N	EXCUSE	0
262529	261092	11027H	PARTICIPANT	\N	PRESENT	0
262530	261487	14215L	PARTICIPANT	\N	PRESENT	0
262531	261487	19533U	PARTICIPANT	\N	PRESENT	0
262532	261487	19581D	PARTICIPANT	\N	PRESENT	0
262533	261487	14121F	PARTICIPANT	\N	PRESENT	0
262534	261487	80013X	PARTICIPANT	\N	PRESENT	0
262535	261487	14257W	PARTICIPANT	\N	PRESENT	0
262536	261487	14225N	PARTICIPANT	\N	PRESENT	0
262537	261487	14111D	PARTICIPANT	\N	PRESENT	0
262538	261487	14089Y	PARTICIPANT	\N	PRESENT	0
262541	261487	04088S	PARTICIPANT	\N	PRESENT	0
262542	261487	14217N	PARTICIPANT	\N	PRESENT	0
262543	261487	19553Y	PARTICIPANT	\N	PRESENT	0
262544	261487	14021P	PARTICIPANT	\N	PRESENT	0
262545	261487	11109J	PARTICIPANT	\N	PRESENT	0
262546	261487	14147R	PARTICIPANT	\N	PRESENT	0
262547	261487	10006L	PARTICIPANT	\N	PRESENT	0
262548	261487	11072N	PARTICIPANT	\N	PRESENT	0
262549	261487	17583W	PARTICIPANT	\N	PRESENT	0
262550	261487	19713W	PARTICIPANT	\N	PRESENT	0
262551	261487	14033T	PARTICIPANT	\N	PRESENT	0
262553	261487	08038Y	PARTICIPANT	\N	PRESENT	0
262554	261487	14041T	PARTICIPANT	\N	PRESENT	0
262556	261487	14259Y	PARTICIPANT	\N	PRESENT	0
262557	261487	19295A	PARTICIPANT	\N	PRESENT	0
262675	261489	19295A	PARTICIPANT	\N	PRESENT	0
262708	261489	04045F	PARTICIPANT	\N	PRESENT	0
262677	261489	11109J	PARTICIPANT	\N	PRESENT	0
262678	261489	17779H	PARTICIPANT	\N	PRESENT	0
262679	261489	19715Y	PARTICIPANT	\N	PRESENT	0
262680	261489	12016W	PARTICIPANT	\N	PRESENT	0
262681	261489	80013X	PARTICIPANT	\N	PRESENT	0
262682	261489	19301E	PARTICIPANT	\N	PRESENT	0
262683	261489	14039A	PARTICIPANT	\N	PRESENT	0
262684	261489	11012A	PARTICIPANT	\N	PRESENT	0
262685	261489	14261S	PARTICIPANT	\N	PRESENT	0
262686	261489	19253P	PARTICIPANT	\N	PRESENT	0
262687	261489	14215L	PARTICIPANT	\N	PRESENT	0
262688	261489	19691J	PARTICIPANT	\N	PRESENT	0
262689	261489	14257W	PARTICIPANT	\N	PRESENT	0
262690	261489	17589D	PARTICIPANT	\N	PRESENT	0
262691	261489	04038G	PARTICIPANT	\N	PRESENT	0
262692	261489	19347U	PARTICIPANT	\N	PRESENT	0
262693	261489	14021P	PARTICIPANT	\N	PRESENT	0
262694	261489	01024M	PARTICIPANT	\N	PRESENT	0
262695	261489	14041T	PARTICIPANT	\N	PRESENT	0
262696	261489	95062K	PARTICIPANT	\N	PRESENT	0
262697	261489	14038Y	PARTICIPANT	\N	PRESENT	0
262698	261489	08019V	PARTICIPANT	\N	PRESENT	0
262699	261489	19629C	PARTICIPANT	\N	PRESENT	0
262700	261489	08056B	PARTICIPANT	\N	PRESENT	0
262701	261489	17583W	PARTICIPANT	\N	PRESENT	0
262702	261489	19399H	PARTICIPANT	\N	PRESENT	0
262703	261489	04088S	PARTICIPANT	\N	PRESENT	0
262704	261489	07029T	PARTICIPANT	\N	PRESENT	0
262705	261489	19551W	PARTICIPANT	\N	PRESENT	0
262706	261489	14223L	PARTICIPANT	\N	PRESENT	0
262707	261489	14217N	PARTICIPANT	\N	PRESENT	0
262709	261489	19747H	PARTICIPANT	\N	PRESENT	0
262710	261489	11056N	PARTICIPANT	\N	PRESENT	0
262711	261489	14205J	PARTICIPANT	\N	PRESENT	0
262712	261489	08015R	PARTICIPANT	\N	PRESENT	0
262713	261489	97011G	PARTICIPANT	\N	PRESENT	0
262714	261489	14111D	PARTICIPANT	\N	PRESENT	0
262715	261489	05008E	PARTICIPANT	\N	PRESENT	0
262716	261489	14033T	PARTICIPANT	\N	PRESENT	0
262717	261489	14331P	PARTICIPANT	\N	PRESENT	0
262718	261489	08062Y	PARTICIPANT	\N	PRESENT	0
262719	261489	08055A	PARTICIPANT	\N	PRESENT	0
262720	261489	14107H	PARTICIPANT	\N	PRESENT	0
262721	261489	14073Q	PARTICIPANT	\N	PRESENT	0
262722	261489	19507S	PARTICIPANT	\N	PRESENT	0
262723	261489	14121F	PARTICIPANT	\N	PRESENT	0
262725	262724	19515S	PARTICIPANT	\N	PRESENT	0
262726	262724	19667J	PARTICIPANT	\N	PRESENT	0
262727	262724	04040A	PARTICIPANT	\N	PRESENT	0
262728	262724	19747H	PARTICIPANT	\N	PRESENT	0
262729	262724	14053L	PARTICIPANT	\N	PRESENT	0
262730	262724	18083K	PARTICIPANT	\N	PRESENT	0
262731	262724	07033P	PARTICIPANT	\N	PRESENT	0
262732	262724	14197C	PARTICIPANT	\N	PRESENT	0
262733	262724	19647E	PARTICIPANT	\N	PRESENT	0
262734	262724	14081Q	PARTICIPANT	\N	PRESENT	0
262735	262724	04097T	PARTICIPANT	\N	PRESENT	0
262736	262724	11026G	PARTICIPANT	\N	PRESENT	0
262737	262724	16685X	PARTICIPANT	\N	PRESENT	0
262738	262724	08009T	PARTICIPANT	\N	PRESENT	0
262739	262724	14193X	PARTICIPANT	\N	PRESENT	0
262740	262724	14225N	PARTICIPANT	\N	PRESENT	0
262741	262724	14051J	PARTICIPANT	\N	PRESENT	0
262742	262724	14151M	PARTICIPANT	\N	PRESENT	0
262743	262724	12041X	PARTICIPANT	\N	PRESENT	0
262744	262724	19709B	PARTICIPANT	\N	PRESENT	0
262745	261489	18083K	PARTICIPANT	\N	PRESENT	0
262746	261489	14225N	PARTICIPANT	\N	PRESENT	0
262751	261489	04092N	PARTICIPANT	\N	PRESENT	0
262754	261489	14115H	PARTICIPANT	\N	PRESENT	0
262759	261489	17637T	PARTICIPANT	\N	PRESENT	0
262760	261489	14249W	PARTICIPANT	\N	PRESENT	0
262764	261489	14105F	PARTICIPANT	\N	PRESENT	0
262768	261489	11103C	PARTICIPANT	\N	PRESENT	0
262769	261489	19467C	PARTICIPANT	\N	PRESENT	0
262771	261489	11104D	PARTICIPANT	\N	PRESENT	0
262777	261489	14241N	PARTICIPANT	\N	PRESENT	0
262779	261489	11010L	PARTICIPANT	\N	PRESENT	0
262780	261489	14157T	PARTICIPANT	\N	PRESENT	0
262782	261489	14253S	PARTICIPANT	\N	PRESENT	0
262784	261489	14031R	PARTICIPANT	\N	PRESENT	0
262785	261489	04057K	PARTICIPANT	\N	PRESENT	0
262786	261489	88008L	PARTICIPANT	\N	PRESENT	0
262787	261489	08034U	PARTICIPANT	\N	PRESENT	0
262788	261489	04043D	PARTICIPANT	\N	PRESENT	0
262789	261489	14065Q	PARTICIPANT	\N	PRESENT	0
262790	261489	14147R	PARTICIPANT	\N	PRESENT	0
262793	261489	19415P	PARTICIPANT	\N	PRESENT	0
262794	261489	14109K	PARTICIPANT	\N	PRESENT	0
262796	262795	19515S	PARTICIPANT	\N	PRESENT	0
262797	262795	14030Q	PARTICIPANT	\N	PRESENT	0
262798	261489	95030B	PARTICIPANT	\N	PRESENT	0
262799	262795	14041T	PARTICIPANT	\N	PRESENT	0
262800	262795	97011G	PARTICIPANT	\N	PRESENT	0
262801	262795	14073Q	PARTICIPANT	\N	PRESENT	0
262802	262795	08017T	PARTICIPANT	\N	PRESENT	0
262803	262795	04018C	PARTICIPANT	\N	PRESENT	0
262808	261489	19333N	PARTICIPANT	\N	PRESENT	0
262811	261489	14211G	PARTICIPANT	\N	PRESENT	0
262815	262814	11048N	PARTICIPANT	\N	PRESENT	0
262816	261489	19383Y	PARTICIPANT	\N	PRESENT	0
262817	261489	14097Y	PARTICIPANT	\N	PRESENT	0
262818	261489	19631V	PARTICIPANT	\N	PRESENT	0
262819	261489	14265W	PARTICIPANT	\N	PRESENT	0
262820	261489	14135M	PARTICIPANT	\N	PRESENT	0
262669	261489	11077T	PARTICIPANT	\N	PRESENT	0
262674	261489	11072N	PARTICIPANT	\N	PRESENT	0
262821	261489	19483C	PARTICIPANT	\N	PRESENT	0
262826	261489	08038Y	PARTICIPANT	\N	PRESENT	0
262834	261489	14030Q	PARTICIPANT	\N	PRESENT	0
262838	261489	14193X	PARTICIPANT	\N	PRESENT	0
262839	261489	11043H	PARTICIPANT	\N	PRESENT	0
262840	261489	11099A	PARTICIPANT	\N	PRESENT	0
262842	261489	04033B	PARTICIPANT	\N	PRESENT	0
262884	256018	14089Y	PARTICIPANT	\N	PRESENT	0
262885	256018	08056B	PARTICIPANT	\N	PRESENT	0
262886	256018	19611R	PARTICIPANT	\N	PRESENT	0
262887	256018	19421M	PARTICIPANT	\N	PRESENT	0
262888	256018	98022P	PARTICIPANT	\N	PRESENT	0
262889	256018	11026G	PARTICIPANT	\N	PRESENT	0
262890	256018	10015M	PARTICIPANT	\N	PRESENT	0
262891	256018	08010L	PARTICIPANT	\N	PRESENT	0
262892	256018	19673G	PARTICIPANT	\N	PRESENT	0
262893	256018	98029W	PRESIDENT	0	PRESENT	0
243727	240227	01048V	PRESIDENT	0	PRESENT	0
243728	240227	19663E	PARTICIPANT	\N	PRESENT	0
243729	240227	19553Y	PARTICIPANT	\N	PRESENT	0
243730	240227	08053X	PARTICIPANT	\N	PRESENT	0
243731	240227	14221J	PARTICIPANT	\N	PRESENT	0
243732	240227	19533U	PARTICIPANT	\N	PRESENT	0
243733	240227	19503N	PARTICIPANT	\N	PRESENT	0
243734	240227	04043D	PARTICIPANT	\N	PRESENT	0
243735	240227	01058X	PARTICIPANT	\N	PRESENT	0
243747	243746	96004D	PRESIDENT	0	PRESENT	0
243748	243746	14089Y	PARTICIPANT	\N	PRESENT	0
243749	243746	08014Q	PARTICIPANT	\N	PRESENT	0
243750	243746	04035D	PARTICIPANT	\N	PRESENT	0
243751	243746	11083R	PARTICIPANT	\N	PRESENT	0
243752	243746	14026U	PARTICIPANT	\N	PRESENT	0
243753	243746	14033T	PARTICIPANT	\N	PRESENT	0
243754	243746	19725B	PARTICIPANT	\N	PRESENT	0
243755	243746	14097Y	PARTICIPANT	\N	PRESENT	0
243756	243746	04061F	PARTICIPANT	\N	PRESENT	0
243757	243746	14073Q	PARTICIPANT	\N	PRESENT	0
243758	243746	08039A	PARTICIPANT	\N	PRESENT	0
243760	243746	14001X	PARTICIPANT	\N	PRESENT	0
243761	243746	04057K	PARTICIPANT	\N	PRESENT	0
243762	243746	19563B	PARTICIPANT	\N	PRESENT	0
243763	243746	14237S	PARTICIPANT	\N	PRESENT	0
243764	243746	14135M	PARTICIPANT	\N	PRESENT	0
243765	243746	10015M	PARTICIPANT	\N	PRESENT	0
243766	243746	14249W	PARTICIPANT	\N	PRESENT	0
243767	243746	19593H	PARTICIPANT	\N	EXCUSE	0
243768	243746	14065Q	PARTICIPANT	\N	EXCUSE	0
243769	243746	19731Y	PARTICIPANT	\N	PRESENT	0
243772	243771	96004D	PRESIDENT	0	PRESENT	0
243773	243771	08014Q	PARTICIPANT	\N	PRESENT	0
243774	243771	14249W	PARTICIPANT	\N	PRESENT	0
243775	243771	08018U	PARTICIPANT	\N	PRESENT	0
243776	243771	11083R	PARTICIPANT	\N	PRESENT	0
243777	243771	14033T	PARTICIPANT	\N	PRESENT	0
243778	243771	19725B	PARTICIPANT	\N	PRESENT	0
243779	243771	04097T	PARTICIPANT	\N	PRESENT	0
243780	243771	14061L	PARTICIPANT	\N	PRESENT	0
243781	243771	14001X	PARTICIPANT	\N	PRESENT	0
243782	243771	14073Q	PARTICIPANT	\N	PRESENT	0
243783	243771	14221J	PARTICIPANT	\N	PRESENT	0
243784	243771	04057K	PARTICIPANT	\N	PRESENT	0
243785	243771	19563B	PARTICIPANT	\N	PRESENT	0
243786	243771	10015M	PARTICIPANT	\N	PRESENT	0
243787	243771	98035U	PARTICIPANT	\N	PRESENT	0
243788	243771	14065Q	PARTICIPANT	\N	EXCUSE	0
243789	243771	14097Y	PARTICIPANT	\N	EXCUSE	0
243790	243771	19593H	PARTICIPANT	\N	EXCUSE	0
243791	243771	14331P	PARTICIPANT	\N	EXCUSE	0
243792	243771	14135M	PARTICIPANT	\N	EXCUSE	0
243853	241235	11109J	PARTICIPANT	\N	PRESENT	0
243854	241235	19691J	PARTICIPANT	\N	PRESENT	0
243855	241235	19715Y	PARTICIPANT	\N	PRESENT	0
243856	241235	14097Y	PARTICIPANT	\N	PRESENT	0
243857	241235	98005N	PRESIDENT	0	PRESENT	0
243858	241235	19729F	PARTICIPANT	\N	PRESENT	0
243859	241235	14059S	PARTICIPANT	\N	PRESENT	0
243860	241235	12016W	PARTICIPANT	\N	PRESENT	0
243861	241235	19657G	PARTICIPANT	\N	PRESENT	0
243862	241235	19319Q	PARTICIPANT	\N	PRESENT	0
243863	241235	14275Y	PARTICIPANT	\N	PRESENT	0
243864	241235	19301E	PARTICIPANT	\N	PRESENT	0
243865	241235	95062K	PARTICIPANT	\N	PRESENT	0
243866	241235	19703U	PARTICIPANT	\N	PRESENT	0
243867	241235	14259Y	PARTICIPANT	\N	EXCUSE	0
243868	241232	19691J	PARTICIPANT	\N	EXCUSE	0
243869	241232	14275Y	PARTICIPANT	\N	EXCUSE	0
243870	241232	19319Q	PARTICIPANT	\N	EXCUSE	0
243871	241232	12016W	PARTICIPANT	\N	EXCUSE	0
243872	241232	14059S	PARTICIPANT	\N	EXCUSE	0
243873	241232	19715Y	PARTICIPANT	\N	EXCUSE	0
243874	241232	11109J	PARTICIPANT	\N	PRESENT	0
243875	241232	14261S	PARTICIPANT	\N	PRESENT	0
243876	241232	14259Y	PARTICIPANT	\N	PRESENT	0
243877	241232	19659J	PARTICIPANT	\N	PRESENT	0
243878	241232	14097Y	PARTICIPANT	\N	EXCUSE	0
243879	241232	19301E	PARTICIPANT	\N	PRESENT	0
243880	241232	14225N	PARTICIPANT	\N	EXCUSE	0
243881	241232	08019V	PRESIDENT	0	PRESENT	0
243882	241232	14038Y	PARTICIPANT	\N	EXCUSE	0
243902	243898	14261S	PARTICIPANT	\N	PRESENT	0
243903	243898	19631V	PARTICIPANT	\N	EXCUSE	0
243904	243898	11033F	PARTICIPANT	\N	EXCUSE	0
243905	243898	96004D	PARTICIPANT	\N	EXCUSE	0
243906	243898	14038Y	PARTICIPANT	\N	EXCUSE	0
243907	243898	14259Y	PARTICIPANT	\N	PRESENT	0
243912	243898	19659J	PARTICIPANT	\N	EXCUSE	0
243914	243898	19691J	PARTICIPANT	\N	EXCUSE	0
243915	243898	19577H	PARTICIPANT	\N	EXCUSE	0
243916	243898	14097Y	PARTICIPANT	\N	EXCUSE	0
243917	243898	19329S	PARTICIPANT	\N	EXCUSE	0
243918	243898	19715Y	PARTICIPANT	\N	PRESENT	0
243919	243898	14059S	PARTICIPANT	\N	PRESENT	0
243920	243898	19729F	PARTICIPANT	\N	EXCUSE	0
243921	243898	98005N	PARTICIPANT	\N	EXCUSE	0
243922	243898	12016W	PARTICIPANT	\N	EXCUSE	0
243923	243898	08019V	PRESIDENT	0	PRESENT	0
243924	243898	08073C	PARTICIPANT	\N	EXCUSE	0
243928	243898	14135M	PARTICIPANT	\N	EXCUSE	0
243929	243898	14225N	PARTICIPANT	\N	EXCUSE	0
243930	243898	95062K	PARTICIPANT	\N	EXCUSE	0
243931	243898	19301E	PARTICIPANT	\N	EXCUSE	0
243932	243898	14275Y	PARTICIPANT	\N	EXCUSE	0
243935	243898	14331P	PARTICIPANT	\N	EXCUSE	0
243950	241232	19631V	PARTICIPANT	\N	EXCUSE	0
243952	241232	19729F	PARTICIPANT	\N	EXCUSE	0
243954	241232	98005N	PARTICIPANT	\N	EXCUSE	0
244719	240283	11103C	PARTICIPANT	\N	PRESENT	0
244695	240283	11066Q	PARTICIPANT	\N	PRESENT	0
244696	240283	14257W	PARTICIPANT	\N	PRESENT	0
244697	240283	19731Y	PARTICIPANT	\N	PRESENT	0
244638	244121	19727D	PARTICIPANT	\N	PRESENT	0
244639	244121	01034P	PARTICIPANT	\N	PRESENT	0
244640	244121	14119M	PARTICIPANT	\N	PRESENT	0
244641	244121	04092N	PARTICIPANT	\N	PRESENT	0
244642	244121	19663E	PARTICIPANT	\N	PRESENT	0
244643	244121	14195A	PARTICIPANT	\N	PRESENT	0
244644	244121	19715Y	PARTICIPANT	\N	PRESENT	0
244645	244121	14223L	PARTICIPANT	\N	PRESENT	0
244646	244121	98024R	PRESIDENT	0	PRESENT	0
244647	244121	17779H	PARTICIPANT	\N	PRESENT	0
244648	244121	19703U	PARTICIPANT	\N	EXCUSE	0
244649	244121	08052W	PARTICIPANT	\N	EXCUSE	0
244650	244121	08048B	PARTICIPANT	\N	EXCUSE	0
244651	244121	14213J	PARTICIPANT	\N	EXCUSE	0
244698	240283	05008E	PARTICIPANT	\N	PRESENT	0
244699	240283	19593H	PARTICIPANT	\N	PRESENT	0
244700	240283	04085P	PARTICIPANT	\N	PRESENT	0
244692	240283	04044E	PARTICIPANT	\N	PRESENT	0
244693	240283	19717B	PARTICIPANT	\N	PRESENT	0
244701	240283	98005N	PARTICIPANT	\N	PRESENT	0
244702	240283	11010L	PARTICIPANT	\N	PRESENT	0
244703	240283	14063N	PARTICIPANT	\N	PRESENT	0
244704	240283	01028R	PARTICIPANT	\N	PRESENT	0
244705	240283	14223L	PARTICIPANT	\N	PRESENT	0
244706	240283	19515S	PARTICIPANT	\N	PRESENT	0
244707	240283	14327T	PARTICIPANT	\N	PRESENT	0
244708	240283	19611R	PARTICIPANT	\N	PRESENT	0
244709	240283	19319Q	PARTICIPANT	\N	PRESENT	0
244710	240283	14215L	PARTICIPANT	\N	PRESENT	0
244711	240283	19583F	PARTICIPANT	\N	PRESENT	0
244712	240283	14093U	PARTICIPANT	\N	PRESENT	0
244713	240283	14111D	PARTICIPANT	\N	PRESENT	0
244714	240283	18083K	PARTICIPANT	\N	PRESENT	0
244715	240283	14235Q	PARTICIPANT	\N	PRESENT	0
244716	240283	14033T	PARTICIPANT	\N	PRESENT	0
244717	240283	14065Q	PARTICIPANT	\N	PRESENT	0
244718	240283	19673G	PARTICIPANT	\N	PRESENT	0
244720	240283	19629C	PARTICIPANT	\N	PRESENT	0
244721	240283	08019V	PARTICIPANT	\N	PRESENT	0
244722	240283	14267Y	PARTICIPANT	\N	PRESENT	0
244723	240283	14187A	PARTICIPANT	\N	PRESENT	0
244725	240283	14261S	PARTICIPANT	\N	PRESENT	0
244726	240283	19747H	PARTICIPANT	\N	PRESENT	0
244727	240283	19749K	PARTICIPANT	\N	PRESENT	0
244728	240283	80027E	PARTICIPANT	\N	PRESENT	0
244729	240283	19735D	PARTICIPANT	\N	PRESENT	0
244730	240283	19447X	PARTICIPANT	\N	PRESENT	0
244731	240283	14265W	PARTICIPANT	\N	PRESENT	0
244732	240283	01025N	PARTICIPANT	\N	PRESENT	0
267087	262993	14028W	PARTICIPANT	\N	PRESENT	0
267088	262993	19525U	PARTICIPANT	\N	PRESENT	0
267089	262993	19489J	PARTICIPANT	\N	PRESENT	0
267090	262993	01028R	PARTICIPANT	\N	PRESENT	0
267091	262993	04040A	PRESIDENT	0	PRESENT	0
267092	262993	19565D	PARTICIPANT	\N	PRESENT	0
267093	262993	01057W	PARTICIPANT	\N	PRESENT	0
267094	262993	19253P	PARTICIPANT	\N	PRESENT	0
267667	267666	14089Y	PARTICIPANT	\N	PRESENT	0
267668	267666	14001X	PARTICIPANT	\N	PRESENT	0
267669	267666	19467C	PARTICIPANT	\N	PRESENT	0
267670	267666	14205J	PARTICIPANT	\N	PRESENT	0
267671	267666	08053X	PARTICIPANT	\N	PRESENT	0
267672	267666	08049C	PARTICIPANT	\N	PRESENT	0
267831	267024	19503N	PARTICIPANT	\N	PRESENT	0
267832	267024	19737F	PARTICIPANT	\N	PRESENT	0
267833	267024	14219Q	PARTICIPANT	\N	PRESENT	0
267834	267024	19745F	PARTICIPANT	\N	PRESENT	0
267835	267024	14265W	PARTICIPANT	\N	PRESENT	0
267836	263168	17779H	PARTICIPANT	\N	PRESENT	0
267838	263168	14253S	PARTICIPANT	\N	PRESENT	0
267839	267024	19551W	PARTICIPANT	\N	PRESENT	0
267841	263168	14205J	PARTICIPANT	\N	PRESENT	0
267842	263168	14119M	PARTICIPANT	\N	PRESENT	0
267843	267358	08056B	PARTICIPANT	\N	PRESENT	0
267844	267358	98022P	PARTICIPANT	\N	PRESENT	0
267845	267358	11026G	PARTICIPANT	\N	PRESENT	0
267846	267358	98050T	PARTICIPANT	\N	PRESENT	0
267847	267358	19673G	PARTICIPANT	\N	PRESENT	0
267848	267358	98029W	PRESIDENT	0	PRESENT	0
267849	267358	19611R	PARTICIPANT	\N	EXCUSE	0
267850	267358	04008A	PARTICIPANT	\N	EXCUSE	0
267851	267024	14187A	PARTICIPANT	\N	PRESENT	0
267852	267024	95062K	PARTICIPANT	\N	PRESENT	0
267853	267024	14237S	PARTICIPANT	\N	PRESENT	0
267854	267024	14051J	PARTICIPANT	\N	PRESENT	0
267855	263168	14241N	PARTICIPANT	\N	PRESENT	0
267856	263168	95037J	PARTICIPANT	\N	PRESENT	0
267857	263168	14215L	PARTICIPANT	\N	PRESENT	0
267858	267024	19347U	PARTICIPANT	\N	PRESENT	0
267859	263168	08034U	PARTICIPANT	\N	PRESENT	0
267860	263168	01058X	PARTICIPANT	\N	PRESENT	0
267861	267358	19575F	PARTICIPANT	\N	PRESENT	0
267862	267024	19383Y	PARTICIPANT	\N	PRESENT	0
267863	263168	19747H	PARTICIPANT	\N	PRESENT	0
267864	263168	14357A	PARTICIPANT	\N	PRESENT	0
267865	267024	17583W	PARTICIPANT	\N	PRESENT	0
267866	267024	19631V	PARTICIPANT	\N	PRESENT	0
267867	267024	98023Q	PARTICIPANT	\N	PRESENT	0
267868	263168	11010L	PARTICIPANT	\N	PRESENT	0
267869	263168	80013X	PARTICIPANT	\N	PRESENT	0
267870	263168	11099A	PARTICIPANT	\N	PRESENT	0
267871	263168	08031R	PARTICIPANT	\N	PRESENT	0
267872	263168	01025N	PARTICIPANT	\N	PRESENT	0
267873	263168	11097X	PARTICIPANT	\N	PRESENT	0
267875	263168	19663E	PARTICIPANT	\N	PRESENT	0
267878	263168	19651A	PARTICIPANT	\N	PRESENT	0
267879	263168	08019V	PARTICIPANT	\N	PRESENT	0
267880	263168	14195A	PARTICIPANT	\N	PRESENT	0
267888	267475	14135M	PARTICIPANT	\N	PRESENT	0
267889	267475	19467C	PARTICIPANT	\N	PRESENT	0
267890	267475	19515S	PARTICIPANT	\N	PRESENT	0
267891	267475	19565D	PARTICIPANT	\N	PRESENT	0
267892	267475	14357A	PARTICIPANT	\N	PRESENT	0
267893	267475	14187A	PARTICIPANT	\N	PRESENT	0
267894	267475	08038Y	PARTICIPANT	\N	PRESENT	0
267895	267475	11090Q	PRESIDENT	0	PRESENT	0
267896	267475	01025N	PARTICIPANT	\N	PRESENT	0
267897	267475	80013X	PARTICIPANT	\N	PRESENT	0
267898	267475	19631V	PARTICIPANT	\N	PRESENT	0
267899	267475	14205J	PARTICIPANT	\N	PRESENT	0
267900	267475	11099A	PARTICIPANT	\N	PRESENT	0
267901	267475	04049K	PARTICIPANT	\N	PRESENT	0
267902	267475	19705W	PARTICIPANT	\N	PRESENT	0
267903	267475	19707Y	PARTICIPANT	\N	PRESENT	0
267904	267475	08019V	PARTICIPANT	\N	PRESENT	0
267905	267475	19369B	PARTICIPANT	\N	PRESENT	0
267906	267475	19747H	PARTICIPANT	\N	PRESENT	0
267907	267475	14207L	PARTICIPANT	\N	PRESENT	0
267908	267475	04043D	PARTICIPANT	\N	PRESENT	0
267909	267475	19511N	PARTICIPANT	\N	PRESENT	0
267910	267475	14265W	PARTICIPANT	\N	PRESENT	0
267911	267475	17589D	PARTICIPANT	\N	PRESENT	0
267912	267475	11056N	PARTICIPANT	\N	EXCUSE	0
267913	267475	04089T	PARTICIPANT	\N	EXCUSE	0
267914	267475	11101A	PARTICIPANT	\N	EXCUSE	0
267915	267475	08015R	PARTICIPANT	\N	EXCUSE	0
267916	267475	14197C	PARTICIPANT	\N	EXCUSE	0
267917	267475	19695N	PARTICIPANT	\N	EXCUSE	0
267918	267475	14033T	PARTICIPANT	\N	EXCUSE	0
267919	267475	08021P	PARTICIPANT	\N	EXCUSE	0
267920	267475	08028W	PARTICIPANT	\N	EXCUSE	0
267921	267475	11081P	PARTICIPANT	\N	EXCUSE	0
267958	263168	14029X	PARTICIPANT	\N	PRESENT	0
267923	267664	14237S	PARTICIPANT	\N	PRESENT	0
267924	267664	14051J	PARTICIPANT	\N	PRESENT	0
267925	267664	08060W	PARTICIPANT	\N	PRESENT	0
267959	263168	14059S	PARTICIPANT	\N	PRESENT	0
267927	267664	08009T	PRESIDENT	0	PRESENT	0
267957	263168	19735D	PARTICIPANT	\N	PRESENT	0
267929	267664	19737F	PARTICIPANT	\N	PRESENT	0
267930	267664	19745F	PARTICIPANT	\N	PRESENT	0
267931	267664	14169X	PARTICIPANT	\N	PRESENT	0
267932	263168	01048V	PARTICIPANT	\N	PRESENT	0
267960	263168	19733B	PARTICIPANT	\N	PRESENT	0
267965	263168	19549D	PARTICIPANT	\N	PRESENT	0
267966	263168	07004J	PARTICIPANT	\N	PRESENT	0
267967	263168	14251Q	PARTICIPANT	\N	PRESENT	0
267977	267314	19443T	PARTICIPANT	\N	PRESENT	0
267978	267314	04034C	PARTICIPANT	\N	PRESENT	0
267979	267314	04040A	PARTICIPANT	\N	PRESENT	0
267980	267314	14079W	PARTICIPANT	\N	PRESENT	0
267981	267314	01058X	PARTICIPANT	\N	PRESENT	0
267982	267314	16685X	PARTICIPANT	\N	PRESENT	0
267983	267314	04042C	PRESIDENT	0	PRESENT	0
267984	267314	11054L	PARTICIPANT	\N	PRESENT	0
267985	267314	11066Q	PARTICIPANT	\N	PRESENT	0
267986	267314	08056B	PARTICIPANT	\N	PRESENT	0
267987	267314	95037J	PARTICIPANT	\N	PRESENT	0
267988	267314	19421M	PARTICIPANT	\N	PRESENT	0
267989	267314	19709B	PARTICIPANT	\N	PRESENT	0
267990	267314	08049C	PARTICIPANT	\N	PRESENT	0
267991	267314	08053X	PARTICIPANT	\N	PRESENT	0
267992	267314	08061X	PARTICIPANT	\N	PRESENT	0
267993	267314	08047A	PARTICIPANT	\N	PRESENT	0
267994	267314	98029W	PARTICIPANT	\N	PRESENT	0
267995	267314	14097Y	PARTICIPANT	\N	PRESENT	0
267996	267314	04035D	PARTICIPANT	\N	PRESENT	0
267997	267314	95067Q	PARTICIPANT	\N	PRESENT	0
267998	267314	14133K	PARTICIPANT	\N	PRESENT	0
267999	267314	11041F	PARTICIPANT	\N	PRESENT	0
268000	267314	08058D	PARTICIPANT	\N	PRESENT	0
268001	267314	19251M	PARTICIPANT	\N	PRESENT	0
268002	267314	14028W	PARTICIPANT	\N	PRESENT	0
268003	267314	19721W	PARTICIPANT	\N	PRESENT	0
268004	267314	98018T	PARTICIPANT	\N	PRESENT	0
268005	267314	98022P	PARTICIPANT	\N	PRESENT	0
268006	267314	14267Y	PARTICIPANT	\N	PRESENT	0
268007	267314	11064N	PARTICIPANT	\N	PRESENT	0
268008	267314	98050T	PARTICIPANT	\N	PRESENT	0
268009	267314	14255U	PARTICIPANT	\N	PRESENT	0
268013	267664	19713W	PARTICIPANT	\N	PRESENT	0
268014	267664	19551W	PARTICIPANT	\N	PRESENT	0
268015	267664	14179A	PARTICIPANT	\N	PRESENT	0
268016	263168	19673G	PARTICIPANT	\N	PRESENT	0
268017	263168	19703U	PARTICIPANT	\N	PRESENT	0
268019	263168	19511N	PARTICIPANT	\N	PRESENT	0
268034	263168	08012N	PARTICIPANT	\N	PRESENT	0
268035	263168	08043V	PARTICIPANT	\N	PRESENT	0
268036	263168	10015M	PARTICIPANT	\N	PRESENT	0
269089	266868	19663E	PARTICIPANT	\N	PRESENT	0
269090	266868	01048V	PARTICIPANT	\N	PRESENT	0
269152	269050	14229S	PARTICIPANT	\N	PRESENT	0
269155	269044	14229S	PARTICIPANT	\N	PRESENT	0
270173	270172	14357A	PARTICIPANT	\N	PRESENT	0
270175	270174	96004D	PARTICIPANT	\N	PRESENT	0
270176	270174	08014Q	PARTICIPANT	\N	PRESENT	0
270177	270174	95037J	PARTICIPANT	\N	PRESENT	0
270178	270174	11090Q	PARTICIPANT	\N	PRESENT	0
270179	270174	14357A	PARTICIPANT	\N	PRESENT	0
270180	270174	19441R	PARTICIPANT	\N	PRESENT	0
270181	270174	14207L	PARTICIPANT	\N	PRESENT	0
270182	270174	19507S	PARTICIPANT	\N	PRESENT	0
270183	270174	14257W	PARTICIPANT	\N	PRESENT	0
270376	268440	19723Y	PARTICIPANT	\N	EXCUSE	0
253528	253502	14261S	PARTICIPANT	\N	PRESENT	0
253529	253502	14038Y	PARTICIPANT	\N	PRESENT	0
253530	253502	14259Y	PARTICIPANT	\N	EXCUSE	0
253531	253502	19715Y	PARTICIPANT	\N	PRESENT	0
253532	253502	98005N	PARTICIPANT	\N	EXCUSE	0
253533	253502	14059S	PARTICIPANT	\N	PRESENT	0
253534	253502	08019V	PRESIDENT	0	PRESENT	0
253535	253502	14135M	PARTICIPANT	\N	EXCUSE	0
253536	253502	08016S	PARTICIPANT	\N	EXCUSE	0
253537	253502	19729F	PARTICIPANT	\N	EXCUSE	0
253541	253540	14135M	PARTICIPANT	\N	PRESENT	0
253542	253540	98005N	PARTICIPANT	\N	EXCUSE	0
253543	253540	19729F	PARTICIPANT	\N	EXCUSE	0
258091	255730	14327T	PARTICIPANT	\N	PRESENT	0
253545	253540	14259Y	PARTICIPANT	\N	EXCUSE	0
253547	253546	19729F	PARTICIPANT	\N	EXCUSE	0
253548	253546	08016S	PARTICIPANT	\N	EXCUSE	0
253549	253546	14038Y	PARTICIPANT	\N	EXCUSE	0
253550	253546	14135M	PARTICIPANT	\N	EXCUSE	0
253551	253546	98005N	PARTICIPANT	\N	EXCUSE	0
258075	255729	19531S	PARTICIPANT	\N	PRESENT	0
258076	255729	19687N	PARTICIPANT	\N	PRESENT	0
258077	255729	19689Q	PARTICIPANT	\N	PRESENT	0
258078	255729	08011M	PARTICIPANT	\N	PRESENT	0
258079	255729	08014Q	PARTICIPANT	\N	PRESENT	0
258080	255729	14159V	PARTICIPANT	\N	PRESENT	0
258081	255729	14173T	PARTICIPANT	\N	PRESENT	0
258082	255729	04086Q	PARTICIPANT	\N	PRESENT	0
258083	255729	11040E	PARTICIPANT	\N	PRESENT	0
258084	255729	14083S	PARTICIPANT	\N	PRESENT	0
258085	255729	11012A	PARTICIPANT	\N	PRESENT	0
258086	255729	19741B	PARTICIPANT	\N	PRESENT	0
258087	255729	14121F	PARTICIPANT	\N	PRESENT	0
258088	255729	99004R	PARTICIPANT	\N	PRESENT	0
258089	255729	14199E	PARTICIPANT	\N	EXCUSE	0
258090	255729	08069G	PARTICIPANT	\N	EXCUSE	0
258092	255730	14331P	PARTICIPANT	\N	PRESENT	0
258093	255730	04071H	PARTICIPANT	\N	PRESENT	0
258094	255730	01048V	PARTICIPANT	\N	PRESENT	0
258095	255730	19545Y	PARTICIPANT	\N	PRESENT	0
258096	255730	01057W	PARTICIPANT	\N	PRESENT	0
258097	255730	11053K	PARTICIPANT	\N	PRESENT	0
258098	255730	19667J	PARTICIPANT	\N	PRESENT	0
258099	255730	11074Q	PRESIDENT	0	PRESENT	0
258100	255730	89017R	PARTICIPANT	\N	PRESENT	0
258101	255730	19671E	PARTICIPANT	\N	PRESENT	0
258102	255730	14225N	PARTICIPANT	\N	PRESENT	0
258103	255730	88008L	PARTICIPANT	\N	PRESENT	0
258104	255730	11110B	PARTICIPANT	\N	PRESENT	0
258105	255730	07029T	PARTICIPANT	\N	PRESENT	0
258106	255730	14085U	PARTICIPANT	\N	PRESENT	0
258107	255730	14277B	PARTICIPANT	\N	PRESENT	0
258108	255730	07004J	PARTICIPANT	\N	PRESENT	0
258109	255730	19349W	PARTICIPANT	\N	PRESENT	0
258110	255730	08010L	PARTICIPANT	\N	PRESENT	0
258111	255730	14253S	PARTICIPANT	\N	PRESENT	0
258112	255730	11048N	PARTICIPANT	\N	PRESENT	0
258113	255730	19647E	PARTICIPANT	\N	PRESENT	0
258114	255730	19479G	PARTICIPANT	\N	PRESENT	0
258115	255730	19711U	PARTICIPANT	\N	PRESENT	0
258116	255730	08034U	PARTICIPANT	\N	PRESENT	0
258117	255730	19531S	PARTICIPANT	\N	PRESENT	0
258118	255730	19687N	PARTICIPANT	\N	PRESENT	0
258119	255730	19689Q	PARTICIPANT	\N	PRESENT	0
258120	255730	08011M	PARTICIPANT	\N	PRESENT	0
258121	255730	08014Q	PARTICIPANT	\N	PRESENT	0
258122	255730	14034U	PARTICIPANT	\N	PRESENT	0
258123	255730	14159V	PARTICIPANT	\N	PRESENT	0
258124	255730	14173T	PARTICIPANT	\N	PRESENT	0
258125	255730	04086Q	PARTICIPANT	\N	PRESENT	0
258126	255730	11040E	PARTICIPANT	\N	PRESENT	0
258127	255730	14083S	PARTICIPANT	\N	PRESENT	0
258128	255730	11012A	PARTICIPANT	\N	PRESENT	0
258129	255730	19741B	PARTICIPANT	\N	PRESENT	0
258130	255730	14121F	PARTICIPANT	\N	PRESENT	0
258131	255730	99004R	PARTICIPANT	\N	PRESENT	0
258132	255730	14199E	PARTICIPANT	\N	EXCUSE	0
258133	255730	08069G	PARTICIPANT	\N	EXCUSE	0
258137	256145	04070G	PRESIDENT	0	PRESENT	0
258138	256145	19699S	PARTICIPANT	\N	PRESENT	0
258139	256145	12041X	PARTICIPANT	\N	PRESENT	0
258140	256145	19533U	PARTICIPANT	\N	PRESENT	0
258141	256145	14229S	PARTICIPANT	\N	PRESENT	0
258142	256145	14241N	PARTICIPANT	\N	PRESENT	0
258143	256145	19573D	PARTICIPANT	\N	PRESENT	0
258144	256145	14107H	PARTICIPANT	\N	PRESENT	0
258145	256145	08012N	PARTICIPANT	\N	PRESENT	0
258146	256145	08039A	PARTICIPANT	\N	PRESENT	0
258147	256145	08031R	PARTICIPANT	\N	PRESENT	0
258148	256145	19593H	PARTICIPANT	\N	PRESENT	0
258149	256145	19643A	PARTICIPANT	\N	PRESENT	0
258150	256145	14059S	PARTICIPANT	\N	PRESENT	0
258151	256145	04057K	PARTICIPANT	\N	PRESENT	0
258152	256145	14073Q	PARTICIPANT	\N	PRESENT	0
258153	256145	19611R	PARTICIPANT	\N	PRESENT	0
258154	256145	08043V	PARTICIPANT	\N	PRESENT	0
258155	256145	19693L	PARTICIPANT	\N	PRESENT	0
258156	256145	87003B	PARTICIPANT	\N	PRESENT	0
258157	256145	14030Q	PARTICIPANT	\N	PRESENT	0
258158	256145	19731Y	PARTICIPANT	\N	PRESENT	0
258159	256145	14251Q	PARTICIPANT	\N	PRESENT	0
258160	256145	04059M	PARTICIPANT	\N	PRESENT	0
258161	256145	11109J	PARTICIPANT	\N	PRESENT	0
258162	256145	11083R	PARTICIPANT	\N	PRESENT	0
258163	256145	14063N	PARTICIPANT	\N	PRESENT	0
258164	256145	14109K	PARTICIPANT	\N	PRESENT	0
258165	256145	14123H	PARTICIPANT	\N	PRESENT	0
258166	256145	19749K	PARTICIPANT	\N	PRESENT	0
258167	256145	04018C	PARTICIPANT	\N	PRESENT	0
258168	256145	19621T	PARTICIPANT	\N	PRESENT	0
258169	256145	11043H	PARTICIPANT	\N	PRESENT	0
258170	256145	14061L	PARTICIPANT	\N	EXCUSE	0
258171	256145	14249W	PARTICIPANT	\N	EXCUSE	0
258172	240327	04059M	PARTICIPANT	\N	PRESENT	0
258173	240327	96004D	PARTICIPANT	\N	PRESENT	0
258174	240327	14079W	PARTICIPANT	\N	PRESENT	0
258175	258039	04085P	PARTICIPANT	\N	PRESENT	0
258176	258039	14065Q	PARTICIPANT	\N	PRESENT	0
258177	258039	19549D	PARTICIPANT	\N	PRESENT	0
258198	240327	19593H	PARTICIPANT	\N	PRESENT	0
258179	258039	14195A	PARTICIPANT	\N	PRESENT	0
258180	258039	19253P	PARTICIPANT	\N	PRESENT	0
258181	258039	14041T	PARTICIPANT	\N	PRESENT	0
258182	258039	14217N	PARTICIPANT	\N	PRESENT	0
258183	258039	14215L	PARTICIPANT	\N	PRESENT	0
258199	240327	14073Q	PARTICIPANT	\N	PRESENT	0
258185	258039	14087W	PRESIDENT	0	PRESENT	0
258186	258039	14231L	PARTICIPANT	\N	PRESENT	0
258187	258039	19691J	PARTICIPANT	\N	PRESENT	0
258188	258039	19553Y	PARTICIPANT	\N	PRESENT	0
258189	258039	14213J	PARTICIPANT	\N	PRESENT	0
258190	258039	19697Q	PARTICIPANT	\N	PRESENT	0
258191	258039	14031R	PARTICIPANT	\N	PRESENT	0
258192	258039	14147R	PARTICIPANT	\N	PRESENT	0
258193	258039	11067R	PARTICIPANT	\N	PRESENT	0
258194	258039	14223L	PARTICIPANT	\N	PRESENT	0
258200	240327	14223L	PARTICIPANT	\N	PRESENT	0
258196	258039	11045K	PARTICIPANT	\N	PRESENT	0
258197	258039	04044E	PRESIDENT	1	PRESENT	0
258201	240327	19709B	PARTICIPANT	\N	PRESENT	0
258202	240327	19507S	PARTICIPANT	\N	PRESENT	0
258203	240327	19525U	PARTICIPANT	\N	PRESENT	0
258204	240327	14055N	PARTICIPANT	\N	PRESENT	0
258205	240327	19725B	PARTICIPANT	\N	PRESENT	0
258206	240327	11083R	PARTICIPANT	\N	PRESENT	0
258207	240327	19563B	PARTICIPANT	\N	PRESENT	0
258208	240327	14213J	PARTICIPANT	\N	PRESENT	0
258209	240327	14133K	PARTICIPANT	\N	PRESENT	0
258210	240327	95030B	PARTICIPANT	\N	PRESENT	0
258211	240327	19629C	PARTICIPANT	\N	PRESENT	0
258212	240327	14229S	PARTICIPANT	\N	PRESENT	0
258213	240327	11026G	PARTICIPANT	\N	PRESENT	0
258214	240327	11074Q	PARTICIPANT	\N	PRESENT	0
258215	240327	04042C	PARTICIPANT	\N	PRESENT	0
258216	240327	98035U	PARTICIPANT	\N	PRESENT	0
258217	240327	14001X	PARTICIPANT	\N	PRESENT	0
258218	240327	14097Y	PARTICIPANT	\N	PRESENT	0
258219	240327	19503N	PARTICIPANT	\N	PRESENT	0
258220	240327	04061F	PARTICIPANT	\N	PRESENT	0
258221	240327	14105F	PARTICIPANT	\N	PRESENT	0
258222	240327	97011G	PARTICIPANT	\N	PRESENT	0
258223	240327	10015M	PARTICIPANT	\N	PRESENT	0
258224	240327	08043V	PARTICIPANT	\N	PRESENT	0
258225	240327	19673G	PARTICIPANT	\N	PRESENT	0
258226	240327	19441R	PARTICIPANT	\N	PRESENT	0
258227	240327	14255U	PARTICIPANT	\N	PRESENT	0
258228	240327	14235Q	PARTICIPANT	\N	PRESENT	0
258229	240327	04097T	PARTICIPANT	\N	PRESENT	0
258230	240327	14087W	PARTICIPANT	\N	PRESENT	0
262995	262994	19631V	PARTICIPANT	\N	PRESENT	0
262996	262994	19515S	PARTICIPANT	\N	PRESENT	0
262997	262994	11081P	PARTICIPANT	\N	EXCUSE	0
262999	262994	14115H	PARTICIPANT	\N	PRESENT	0
263001	262994	19747H	PARTICIPANT	\N	PRESENT	0
263002	262994	08068F	PARTICIPANT	\N	PRESENT	0
263003	262994	14207L	PARTICIPANT	\N	PRESENT	0
263004	262994	11101A	PARTICIPANT	\N	EXCUSE	0
263005	262994	19295A	PARTICIPANT	\N	PRESENT	0
263006	262994	80013X	PARTICIPANT	\N	PRESENT	0
263007	262994	11056N	PARTICIPANT	\N	PRESENT	0
263009	262994	14357A	PARTICIPANT	\N	EXCUSE	0
263010	262994	08038Y	PARTICIPANT	\N	PRESENT	0
263012	262994	04089T	PARTICIPANT	\N	EXCUSE	0
263013	262994	19507S	PARTICIPANT	\N	PRESENT	0
263014	262994	19695N	PARTICIPANT	\N	PRESENT	0
263015	262994	19565D	PARTICIPANT	\N	PRESENT	0
263016	262994	14033T	PARTICIPANT	\N	PRESENT	0
263017	262994	14081Q	PARTICIPANT	\N	PRESENT	0
263018	262994	19511N	PARTICIPANT	\N	PRESENT	0
263019	262994	11099A	PARTICIPANT	\N	EXCUSE	0
263020	262994	08015R	PARTICIPANT	\N	PRESENT	0
263021	262994	14205J	PARTICIPANT	\N	PRESENT	0
263022	262994	08062Y	PARTICIPANT	\N	PRESENT	0
263023	262994	19563B	PARTICIPANT	\N	EXCUSE	0
263024	262994	19369B	PARTICIPANT	\N	PRESENT	0
263025	262994	14257W	PARTICIPANT	\N	PRESENT	0
263026	262994	14265W	PARTICIPANT	\N	PRESENT	0
263027	262994	08021P	PARTICIPANT	\N	EXCUSE	0
263028	262994	04088S	PARTICIPANT	\N	PRESENT	0
263029	262994	11090Q	PRESIDENT	0	PRESENT	0
263030	262994	14135M	PARTICIPANT	\N	PRESENT	0
263031	262994	19269X	PARTICIPANT	\N	PRESENT	0
263032	262994	19301E	PARTICIPANT	\N	PRESENT	0
263033	262994	19413M	PARTICIPANT	\N	PRESENT	0
263034	262994	18083K	PARTICIPANT	\N	PRESENT	0
263036	262994	19415P	PARTICIPANT	\N	PRESENT	0
263037	262994	11103C	PARTICIPANT	\N	PRESENT	0
263039	262994	14195A	PARTICIPANT	\N	PRESENT	0
263040	262994	19663E	PARTICIPANT	\N	PRESENT	0
263041	262994	98024R	PARTICIPANT	\N	PRESENT	0
263042	262994	14217N	PARTICIPANT	\N	PRESENT	0
263043	262994	14087W	PARTICIPANT	\N	PRESENT	0
263045	262994	19521Q	PARTICIPANT	\N	PRESENT	0
263046	262994	19727D	PARTICIPANT	\N	PRESENT	0
263047	262994	14213J	PARTICIPANT	\N	PRESENT	0
263048	262994	19683J	PARTICIPANT	\N	PRESENT	0
263049	262994	19723Y	PARTICIPANT	\N	PRESENT	0
263050	262994	19657G	PARTICIPANT	\N	PRESENT	0
263052	262994	11067R	PARTICIPANT	\N	PRESENT	0
263056	262994	14223L	PARTICIPANT	\N	PRESENT	0
263057	262994	04092N	PARTICIPANT	\N	PRESENT	0
263058	262994	14119M	PARTICIPANT	\N	PRESENT	0
263059	262994	14071N	PARTICIPANT	\N	PRESENT	0
263060	262994	11097X	PARTICIPANT	\N	PRESENT	0
263061	262994	04045F	PARTICIPANT	\N	PRESENT	0
263062	262994	19703U	PARTICIPANT	\N	PRESENT	0
263063	262994	19527W	PARTICIPANT	\N	PRESENT	0
263064	262994	01034P	PARTICIPANT	\N	PRESENT	0
263346	261490	19443T	PARTICIPANT	\N	PRESENT	0
263347	261490	19741B	PARTICIPANT	\N	PRESENT	0
263348	261490	19663E	PARTICIPANT	\N	PRESENT	0
263349	261490	04088S	PARTICIPANT	\N	PRESENT	0
263350	261490	14041T	PARTICIPANT	\N	PRESENT	0
263351	261490	07029T	PARTICIPANT	\N	PRESENT	0
263352	261490	08062Y	PARTICIPANT	\N	PRESENT	0
263353	261490	19657G	PARTICIPANT	\N	PRESENT	0
263354	261490	08015R	PARTICIPANT	\N	PRESENT	0
263355	261490	98050T	PARTICIPANT	\N	PRESENT	0
263356	261490	19727D	PARTICIPANT	\N	PRESENT	0
263357	261490	14059S	PARTICIPANT	\N	PRESENT	0
263358	261490	14329V	PARTICIPANT	\N	PRESENT	0
263359	261490	17779H	PARTICIPANT	\N	PRESENT	0
263360	261490	14357A	PARTICIPANT	\N	PRESENT	0
263361	261490	14085U	PARTICIPANT	\N	PRESENT	0
263362	261490	08058D	PARTICIPANT	\N	PRESENT	0
263363	261490	19675J	PARTICIPANT	\N	PRESENT	0
263364	261490	19383Y	PARTICIPANT	\N	PRESENT	0
263368	261490	04018C	PARTICIPANT	\N	PRESENT	0
263366	261490	19483C	PARTICIPANT	\N	PRESENT	0
263367	261490	19701S	PARTICIPANT	\N	PRESENT	0
263369	261490	11110B	PARTICIPANT	\N	PRESENT	0
263370	261490	04033B	PARTICIPANT	\N	PRESENT	0
263371	261490	19367Y	PARTICIPANT	\N	PRESENT	0
263372	261490	08014Q	PARTICIPANT	\N	PRESENT	0
263373	261490	19725B	PARTICIPANT	\N	PRESENT	0
263374	261490	19549D	PARTICIPANT	\N	PRESENT	0
263375	261490	97011G	PARTICIPANT	\N	PRESENT	0
263377	261490	14229S	PARTICIPANT	\N	PRESENT	0
263378	261490	07033P	PARTICIPANT	\N	PRESENT	0
263379	261490	14217N	PARTICIPANT	\N	PRESENT	0
263380	261490	04061F	PARTICIPANT	\N	PRESENT	0
263381	261490	19545Y	PARTICIPANT	\N	PRESENT	0
263382	261490	14079W	PARTICIPANT	\N	PRESENT	0
263383	261490	19591F	PARTICIPANT	\N	PRESENT	0
263384	261490	19689Q	PARTICIPANT	\N	PRESENT	0
263385	261490	05012A	PARTICIPANT	\N	PRESENT	0
263386	261490	08053X	PARTICIPANT	\N	PRESENT	0
263387	261490	08034U	PARTICIPANT	\N	PRESENT	0
263388	261490	10006L	PARTICIPANT	\N	PRESENT	0
263389	261490	14257W	PARTICIPANT	\N	PRESENT	0
263390	261490	14193X	PARTICIPANT	\N	PRESENT	0
263391	261490	19553Y	PARTICIPANT	\N	PRESENT	0
263392	261490	04043D	PARTICIPANT	\N	PRESENT	0
263393	261490	08044W	PARTICIPANT	\N	PRESENT	0
263394	261490	14261S	PARTICIPANT	\N	PRESENT	0
263395	261490	14069U	PARTICIPANT	\N	PRESENT	0
263396	261490	14053L	PARTICIPANT	\N	PRESENT	0
263397	261490	14087W	PARTICIPANT	\N	PRESENT	0
263398	261490	19713W	PARTICIPANT	\N	PRESENT	0
263399	261490	19691J	PARTICIPANT	\N	PRESENT	0
263401	261490	14071N	PARTICIPANT	\N	PRESENT	0
263402	261490	19369B	PARTICIPANT	\N	PRESENT	0
263403	261490	19611R	PARTICIPANT	\N	PRESENT	0
263404	261490	19699S	PARTICIPANT	\N	PRESENT	0
263405	261490	05008E	PARTICIPANT	\N	PRESENT	0
263406	261490	14205J	PARTICIPANT	\N	PRESENT	0
263407	261490	19737F	PARTICIPANT	\N	PRESENT	0
263408	261490	11097X	PARTICIPANT	\N	PRESENT	0
263409	261490	19421M	PARTICIPANT	\N	PRESENT	0
263410	261490	16685X	PARTICIPANT	\N	PRESENT	0
263411	261490	19441R	PARTICIPANT	\N	PRESENT	0
263412	261490	19479G	PARTICIPANT	\N	PRESENT	0
263413	261490	04086Q	PARTICIPANT	\N	PRESENT	0
263414	261490	14089Y	PARTICIPANT	\N	PRESENT	0
263415	261490	98018T	PARTICIPANT	\N	PRESENT	0
263416	261490	19319Q	PARTICIPANT	\N	PRESENT	0
263417	261490	04044E	PARTICIPANT	\N	PRESENT	0
263418	261490	08009T	PARTICIPANT	\N	PRESENT	0
263419	261490	19335Q	PARTICIPANT	\N	PRESENT	0
263420	261490	14221J	PARTICIPANT	\N	PRESENT	0
263421	261490	04035D	PARTICIPANT	\N	PRESENT	0
263422	261490	14267Y	PARTICIPANT	\N	PRESENT	0
263423	261490	14083S	PARTICIPANT	\N	PRESENT	0
263424	261490	19749K	PARTICIPANT	\N	PRESENT	0
263425	261490	11070L	PARTICIPANT	\N	PRESENT	0
263426	261490	19521Q	PARTICIPANT	\N	PRESENT	0
263427	261490	07004J	PARTICIPANT	\N	PRESENT	0
263428	261490	08056B	PARTICIPANT	\N	PRESENT	0
263429	261490	04040A	PARTICIPANT	\N	PRESENT	0
263430	261490	01025N	PARTICIPANT	\N	PRESENT	0
263431	261490	11049P	PARTICIPANT	\N	PRESENT	0
263432	261490	14030Q	PARTICIPANT	\N	PRESENT	0
263433	261490	14327T	PARTICIPANT	\N	PRESENT	0
263434	261490	14115H	PARTICIPANT	\N	PRESENT	0
263435	261490	01043Q	PARTICIPANT	\N	PRESENT	0
263436	261490	14133K	PARTICIPANT	\N	PRESENT	0
263437	261490	11033F	PARTICIPANT	\N	PRESENT	0
263438	261490	11063M	PARTICIPANT	\N	PRESENT	0
263439	261490	08019V	PARTICIPANT	\N	PRESENT	0
263440	261490	19399H	PARTICIPANT	\N	PRESENT	0
263441	261490	19729F	PARTICIPANT	\N	PRESENT	0
263442	261490	14213J	PARTICIPANT	\N	PRESENT	0
263443	261490	01060R	PARTICIPANT	\N	PRESENT	0
263444	261490	19507S	PARTICIPANT	\N	PRESENT	0
263462	261490	14255U	PARTICIPANT	\N	PRESENT	0
263446	261490	19581D	PARTICIPANT	\N	PRESENT	0
263447	261490	08073C	PARTICIPANT	\N	PRESENT	0
263448	261490	11031D	PARTICIPANT	\N	PRESENT	0
263449	261490	01034P	PARTICIPANT	\N	PRESENT	0
263450	261490	80027E	PARTICIPANT	\N	PRESENT	0
263451	261490	14034U	PARTICIPANT	\N	PRESENT	0
263453	261490	01048V	PARTICIPANT	\N	PRESENT	0
263454	261490	19747H	PARTICIPANT	\N	PRESENT	0
263455	261490	11048N	PARTICIPANT	\N	PRESENT	0
263457	261490	19669L	PARTICIPANT	\N	PRESENT	0
263458	261490	19551W	PARTICIPANT	\N	PRESENT	0
263459	261490	11099A	PARTICIPANT	\N	PRESENT	0
263460	261490	11085T	PARTICIPANT	\N	PRESENT	0
241127	241126	14255U	PARTICIPANT	\N	PRESENT	0
241128	241126	88008L	PARTICIPANT	\N	PRESENT	0
241129	241126	14041T	PARTICIPANT	\N	PRESENT	0
241130	241126	01043Q	PARTICIPANT	\N	PRESENT	0
241131	241126	14059S	PARTICIPANT	\N	PRESENT	0
241132	241126	08009T	PARTICIPANT	\N	PRESENT	0
241133	241126	14237S	PARTICIPANT	\N	PRESENT	0
241134	241126	19421M	PARTICIPANT	\N	PRESENT	0
241135	241126	08015R	PARTICIPANT	\N	PRESENT	0
241136	241126	08045X	PARTICIPANT	\N	PRESENT	0
241195	241194	08073C	PARTICIPANT	\N	PRESENT	0
241196	241194	14277B	PARTICIPANT	\N	PRESENT	0
241198	241197	08073C	PARTICIPANT	\N	PRESENT	0
241199	241197	14277B	PARTICIPANT	\N	PRESENT	0
241206	241205	08009T	PARTICIPANT	\N	PRESENT	0
241207	241205	07004J	PARTICIPANT	\N	PRESENT	0
241208	241205	19713W	PARTICIPANT	\N	PRESENT	0
241209	241205	14133K	PARTICIPANT	\N	PRESENT	0
241211	241210	08009T	PARTICIPANT	\N	PRESENT	0
241212	241210	14179A	PARTICIPANT	\N	PRESENT	0
244733	240283	19253P	PARTICIPANT	\N	PRESENT	0
244734	240283	14241N	PARTICIPANT	\N	PRESENT	0
244735	240283	08060W	PARTICIPANT	\N	PRESENT	0
244736	240283	01024M	PARTICIPANT	\N	PRESENT	0
244737	240283	19691J	PARTICIPANT	\N	PRESENT	0
244738	240283	97011G	PARTICIPANT	\N	PRESENT	0
244739	240283	19387D	PARTICIPANT	\N	PRESENT	0
244740	240283	14121F	PARTICIPANT	\N	PRESENT	0
244741	240283	19663E	PARTICIPANT	\N	PRESENT	0
244742	240283	14105F	PARTICIPANT	\N	PRESENT	0
244743	240283	14028W	PARTICIPANT	\N	PRESENT	0
244746	240283	14069U	PARTICIPANT	\N	PRESENT	0
244747	240283	14021P	PARTICIPANT	\N	PRESENT	0
244758	240283	14030Q	PARTICIPANT	\N	PRESENT	0
244759	240283	14237S	PARTICIPANT	\N	PRESENT	0
244760	240283	11012A	PARTICIPANT	\N	PRESENT	0
244761	240283	14071N	PARTICIPANT	\N	PRESENT	0
244762	240283	14147R	PARTICIPANT	\N	PRESENT	0
244763	240283	08020N	PARTICIPANT	\N	PRESENT	0
244764	240283	16685X	PARTICIPANT	\N	PRESENT	0
244765	240283	11072N	PARTICIPANT	\N	PRESENT	0
244766	240283	08044W	PARTICIPANT	\N	PRESENT	0
244767	240283	14217N	PARTICIPANT	\N	PRESENT	0
244768	240283	14109K	PARTICIPANT	\N	PRESENT	0
244769	240283	14211G	PARTICIPANT	\N	PRESENT	0
244770	240283	19479G	PARTICIPANT	\N	PRESENT	0
244771	240283	04018C	PARTICIPANT	\N	PRESENT	0
244772	240283	08017T	PARTICIPANT	\N	PRESENT	0
244773	240283	19251M	PARTICIPANT	\N	PRESENT	0
244774	240283	11040E	PARTICIPANT	\N	PRESENT	0
244775	240283	19511N	PARTICIPANT	\N	PRESENT	0
244777	240283	19533U	PARTICIPANT	\N	PRESENT	0
244778	240283	10006L	PARTICIPANT	\N	PRESENT	0
244779	240283	14219Q	PARTICIPANT	\N	PRESENT	0
244780	240283	14179A	PARTICIPANT	\N	PRESENT	0
244781	240283	14042U	PARTICIPANT	\N	PRESENT	0
244783	240283	19369B	PARTICIPANT	\N	PRESENT	0
244785	240283	19573D	PARTICIPANT	\N	PRESENT	0
244786	240283	14221J	PARTICIPANT	\N	PRESENT	0
244788	240283	04088S	PARTICIPANT	\N	PRESENT	0
244794	240283	14107H	PARTICIPANT	\N	PRESENT	0
244795	240283	04059M	PARTICIPANT	\N	PRESENT	0
244796	240283	19649G	PARTICIPANT	\N	PRESENT	0
244797	240283	19415P	PARTICIPANT	\N	PRESENT	0
244798	240283	14357A	PARTICIPANT	\N	PRESENT	0
244800	240283	19575F	PARTICIPANT	\N	PRESENT	0
244801	240283	14041T	PARTICIPANT	\N	PRESENT	0
244802	240283	87003B	PARTICIPANT	\N	PRESENT	0
244803	240283	19441R	PARTICIPANT	\N	PRESENT	0
244804	240283	19591F	PARTICIPANT	\N	PRESENT	0
244805	240283	95067Q	PARTICIPANT	\N	PRESENT	0
244806	240283	95062K	PARTICIPANT	\N	PRESENT	0
244807	240283	14087W	PARTICIPANT	\N	PRESENT	0
244808	240283	01058X	PARTICIPANT	\N	PRESENT	0
244812	240283	88008L	PARTICIPANT	\N	PRESENT	0
244813	240283	14059S	PARTICIPANT	\N	PRESENT	0
244814	240283	08015R	PARTICIPANT	\N	PRESENT	0
244815	240283	04092N	PARTICIPANT	\N	PRESENT	0
244816	240283	14201E	PARTICIPANT	\N	PRESENT	0
244817	240283	19483C	PARTICIPANT	\N	PRESENT	0
244818	240283	14259Y	PARTICIPANT	\N	PRESENT	0
244820	240283	08010L	PARTICIPANT	\N	PRESENT	0
244821	240283	11097X	PARTICIPANT	\N	PRESENT	0
244822	240283	14255U	PARTICIPANT	\N	PRESENT	0
244823	240283	19631V	PARTICIPANT	\N	PRESENT	0
244824	240283	19741B	PARTICIPANT	\N	PRESENT	0
244825	240283	19725B	PARTICIPANT	\N	PRESENT	0
244826	240283	14053L	PARTICIPANT	\N	PRESENT	0
244827	240283	98050T	PARTICIPANT	\N	PRESENT	0
244828	244809	04071H	PARTICIPANT	\N	PRESENT	0
244829	244809	19443T	PARTICIPANT	\N	PRESENT	0
244830	244809	14111D	PARTICIPANT	\N	PRESENT	0
244831	244809	08034U	PARTICIPANT	\N	PRESENT	0
244832	244809	08035V	PARTICIPANT	\N	PRESENT	0
244833	244809	08058D	PRESIDENT	0	PRESENT	0
244834	244809	19251M	PARTICIPANT	\N	PRESENT	0
244835	244809	19581D	PARTICIPANT	\N	PRESENT	0
244836	244809	15447F	PARTICIPANT	\N	PRESENT	0
244837	244809	04086Q	PARTICIPANT	\N	PRESENT	0
244838	244809	19703U	PARTICIPANT	\N	PRESENT	0
244839	244809	19729F	PARTICIPANT	\N	PRESENT	0
244840	244809	11049P	PARTICIPANT	\N	PRESENT	0
244847	244809	14021P	PARTICIPANT	\N	PRESENT	0
244848	244809	19719D	PARTICIPANT	\N	PRESENT	0
244861	244316	19515S	PARTICIPANT	\N	PRESENT	0
244862	244316	14357A	PARTICIPANT	\N	PRESENT	0
244863	244316	11097X	PARTICIPANT	\N	PRESENT	0
244864	244316	19441R	PARTICIPANT	\N	PRESENT	0
244865	244316	80013X	PARTICIPANT	\N	PRESENT	0
244866	244316	14223L	PARTICIPANT	\N	PRESENT	0
244867	244316	19631V	PARTICIPANT	\N	PRESENT	0
244868	244316	17779H	PARTICIPANT	\N	PRESENT	0
244869	244316	11099A	PARTICIPANT	\N	PRESENT	0
244870	244316	04049K	PARTICIPANT	\N	PRESENT	0
244871	244316	14281W	PARTICIPANT	\N	PRESENT	0
244872	244316	08015R	PARTICIPANT	\N	PRESENT	0
244873	244316	14042U	PARTICIPANT	\N	PRESENT	0
244874	244316	08019V	PARTICIPANT	\N	PRESENT	0
244875	244316	19575F	PARTICIPANT	\N	PRESENT	0
244876	244316	14195A	PARTICIPANT	\N	PRESENT	0
244877	244316	19367Y	PARTICIPANT	\N	PRESENT	0
244878	244316	19369B	PARTICIPANT	\N	PRESENT	0
244879	244316	97011G	PARTICIPANT	\N	PRESENT	0
244880	244316	14217N	PARTICIPANT	\N	PRESENT	0
244881	244316	19511N	PARTICIPANT	\N	PRESENT	0
244882	244316	08028W	PARTICIPANT	\N	PRESENT	0
244883	244316	19563B	PARTICIPANT	\N	PRESENT	0
244884	244316	14265W	PARTICIPANT	\N	PRESENT	0
244885	244316	19527W	PARTICIPANT	\N	PRESENT	0
244886	244316	19467C	PARTICIPANT	\N	PRESENT	0
244887	244316	04092N	PARTICIPANT	\N	PRESENT	0
244888	244316	14187A	PARTICIPANT	\N	PRESENT	0
244889	244316	11045K	PARTICIPANT	\N	PRESENT	0
244890	244316	08038Y	PARTICIPANT	\N	PRESENT	0
244891	244316	08052W	PARTICIPANT	\N	PRESENT	0
244892	244316	19663E	PARTICIPANT	\N	PRESENT	0
244893	244316	08062Y	PARTICIPANT	\N	PRESENT	0
244894	244316	14033T	PARTICIPANT	\N	PRESENT	0
244895	244316	11090Q	PRESIDENT	0	PRESENT	0
244896	244316	01025N	PARTICIPANT	\N	PRESENT	0
244897	244316	19715Y	PARTICIPANT	\N	PRESENT	0
244898	244316	19269X	PARTICIPANT	\N	PRESENT	0
244899	244316	14205J	PARTICIPANT	\N	PRESENT	0
244900	244316	04088S	PARTICIPANT	\N	PRESENT	0
244901	244316	19727D	PARTICIPANT	\N	PRESENT	0
244902	244316	19507S	PARTICIPANT	\N	PRESENT	0
244903	244316	11103C	PARTICIPANT	\N	PRESENT	0
244904	244316	14071N	PARTICIPANT	\N	PRESENT	0
244905	244316	19747H	PARTICIPANT	\N	PRESENT	0
244906	244316	14207L	PARTICIPANT	\N	PRESENT	0
244907	244316	04043D	PARTICIPANT	\N	PRESENT	0
244908	244316	14257W	PARTICIPANT	\N	PRESENT	0
244910	244909	14123H	PARTICIPANT	\N	PRESENT	0
244911	244909	04070G	PARTICIPANT	\N	PRESENT	0
244912	244909	04059M	PARTICIPANT	\N	PRESENT	0
244913	244909	19347U	PARTICIPANT	\N	PRESENT	0
244914	244909	04085P	PARTICIPANT	\N	PRESENT	0
244915	244909	19593H	PARTICIPANT	\N	PRESENT	0
244916	244909	19695N	PARTICIPANT	\N	PRESENT	0
244917	244909	08043V	PARTICIPANT	\N	PRESENT	0
244918	244909	14229S	PARTICIPANT	\N	PRESENT	0
244919	244909	14109K	PARTICIPANT	\N	PRESENT	0
244920	244909	14021P	PARTICIPANT	\N	PRESENT	0
244921	244909	11104D	PARTICIPANT	\N	PRESENT	0
244922	244909	19631V	PARTICIPANT	\N	PRESENT	0
244923	244909	19727D	PARTICIPANT	\N	PRESENT	0
244924	244909	14097Y	PARTICIPANT	\N	PRESENT	0
244925	244909	19737F	PARTICIPANT	\N	PRESENT	0
266995	266994	89017R	PARTICIPANT	\N	PRESENT	0
266996	266994	04085P	PARTICIPANT	\N	PRESENT	0
266997	266994	04059M	PARTICIPANT	\N	PRESENT	0
266998	266994	05008E	PARTICIPANT	\N	PRESENT	0
266999	266994	96004D	PARTICIPANT	\N	PRESENT	0
267000	266994	04042C	PARTICIPANT	\N	PRESENT	0
267001	266994	11053K	PARTICIPANT	\N	PRESENT	0
267002	266994	04086Q	PARTICIPANT	\N	PRESENT	0
267003	266994	11074Q	PARTICIPANT	\N	PRESENT	0
267004	266994	14187A	PARTICIPANT	\N	PRESENT	0
267005	266994	14034U	PARTICIPANT	\N	PRESENT	0
267006	266994	14033T	PARTICIPANT	\N	PRESENT	0
267007	266994	11048N	PARTICIPANT	\N	PRESENT	0
267008	266994	14021P	PARTICIPANT	\N	PRESENT	0
267009	266994	01043Q	PARTICIPANT	\N	PRESENT	0
267010	266994	11077T	PARTICIPANT	\N	PRESENT	0
267011	266994	14251Q	PARTICIPANT	\N	PRESENT	0
267012	266994	11085T	PARTICIPANT	\N	PRESENT	0
267013	266994	08009T	PARTICIPANT	\N	PRESENT	0
267014	266994	04092N	PARTICIPANT	\N	PRESENT	0
267015	266994	11072N	PARTICIPANT	\N	PRESENT	0
267016	266994	08011M	PARTICIPANT	\N	PRESENT	0
267017	266994	04070G	PARTICIPANT	\N	PRESENT	0
267018	266994	08061X	PARTICIPANT	\N	PRESENT	0
267019	266994	11012A	PARTICIPANT	\N	PRESENT	0
267020	266994	04044E	PARTICIPANT	\N	PRESENT	0
267021	266994	01034P	PARTICIPANT	\N	PRESENT	0
267107	262998	04040A	PRESIDENT	0	PRESENT	0
267112	262998	05012A	PARTICIPANT	\N	PRESENT	0
267114	262998	19735D	PARTICIPANT	\N	PRESENT	0
267116	262998	04045F	PARTICIPANT	\N	PRESENT	0
267120	262998	19575F	PARTICIPANT	\N	PRESENT	0
267121	262998	14083S	PARTICIPANT	\N	PRESENT	0
267122	262998	14034U	PARTICIPANT	\N	PRESENT	0
267123	262998	14030Q	PARTICIPANT	\N	PRESENT	0
267124	262998	04049K	PARTICIPANT	\N	PRESENT	0
267125	262998	08068F	PARTICIPANT	\N	PRESENT	0
267126	262998	14157T	PARTICIPANT	\N	PRESENT	0
267127	262998	16685X	PARTICIPANT	\N	PRESENT	0
267128	262998	14265W	PARTICIPANT	\N	PRESENT	0
267132	259068	80013X	PARTICIPANT	\N	PRESENT	0
267130	262998	11099A	PARTICIPANT	\N	PRESENT	0
267131	262998	19671E	PARTICIPANT	\N	PRESENT	0
267133	259068	19663E	PARTICIPANT	\N	PRESENT	0
267134	259068	19709B	PARTICIPANT	\N	PRESENT	0
267135	259068	01048V	PARTICIPANT	\N	PRESENT	0
267136	259068	19503N	PARTICIPANT	\N	PRESENT	0
267137	259068	04043D	PARTICIPANT	\N	PRESENT	0
267138	259068	01058X	PARTICIPANT	\N	PRESENT	0
267140	259068	14299H	PARTICIPANT	\N	PRESENT	0
269122	263464	14085U	PARTICIPANT	\N	PRESENT	0
269123	263464	01058X	PARTICIPANT	\N	PRESENT	0
269124	263464	19671E	PARTICIPANT	\N	PRESENT	0
269125	263464	98022P	PARTICIPANT	\N	PRESENT	0
269126	263464	14249W	PARTICIPANT	\N	PRESENT	0
269127	263464	19747H	PARTICIPANT	\N	PRESENT	0
269128	263464	14073Q	PARTICIPANT	\N	PRESENT	0
269129	263464	14079W	PARTICIPANT	\N	PRESENT	0
269130	263464	14157T	PARTICIPANT	\N	PRESENT	0
269131	263464	19593H	PARTICIPANT	\N	PRESENT	0
269174	263464	14331P	PARTICIPANT	\N	PRESENT	0
269175	263464	19553Y	PARTICIPANT	\N	PRESENT	0
269176	258936	08056B	PARTICIPANT	\N	PRESENT	0
269177	258936	19649G	PARTICIPANT	\N	PRESENT	0
269178	258936	11080N	PARTICIPANT	\N	PRESENT	0
269179	258936	19421M	PARTICIPANT	\N	PRESENT	0
269180	258936	11026G	PARTICIPANT	\N	PRESENT	0
269181	258936	10015M	PARTICIPANT	\N	PRESENT	0
269182	258936	19575F	PARTICIPANT	\N	PRESENT	0
269183	258936	98050T	PARTICIPANT	\N	PRESENT	0
269184	258936	08010L	PARTICIPANT	\N	PRESENT	0
269185	258936	19673G	PARTICIPANT	\N	PRESENT	0
269186	258936	98029W	PRESIDENT	0	PRESENT	0
269187	258936	19611R	PARTICIPANT	\N	EXCUSE	0
269189	269188	14030Q	PRESIDENT	0	PRESENT	0
269190	269188	08043V	PARTICIPANT	0	PRESENT	0
269191	269188	19643A	PARTICIPANT	\N	PRESENT	0
269192	269188	19621T	PARTICIPANT	\N	PRESENT	0
269193	269188	18083K	PARTICIPANT	\N	PRESENT	0
269194	269188	19701S	PARTICIPANT	\N	PRESENT	0
269195	269188	80013X	PARTICIPANT	\N	PRESENT	0
269196	269188	19693L	PARTICIPANT	\N	PRESENT	0
269197	269188	14249W	PARTICIPANT	\N	PRESENT	0
269198	269188	04035D	PARTICIPANT	\N	PRESENT	0
269199	269188	19731Y	PARTICIPANT	\N	PRESENT	0
269200	269188	08031R	PARTICIPANT	\N	PRESENT	0
269201	269188	08017T	PARTICIPANT	\N	PRESENT	0
269202	269188	19697Q	PARTICIPANT	\N	PRESENT	0
269203	269188	14251Q	PARTICIPANT	\N	PRESENT	0
269204	269188	14109K	PARTICIPANT	\N	PRESENT	0
269205	269188	11045K	PARTICIPANT	\N	PRESENT	0
269206	269188	19749K	PARTICIPANT	\N	PRESENT	0
269207	269188	08020N	PARTICIPANT	\N	EXCUSE	0
269208	269188	08024S	PARTICIPANT	\N	EXCUSE	0
269209	269188	19599P	PARTICIPANT	\N	EXCUSE	0
269210	269188	19715Y	PARTICIPANT	\N	EXCUSE	0
269211	269188	07029T	PARTICIPANT	\N	EXCUSE	0
269212	269188	01043Q	PARTICIPANT	\N	EXCUSE	0
269214	269188	14235Q	PARTICIPANT	\N	EXCUSE	0
269215	269188	11109J	PARTICIPANT	\N	PRESENT	0
269216	269188	14073Q	PARTICIPANT	\N	PRESENT	0
269217	269188	19699S	PARTICIPANT	\N	PRESENT	0
269218	269188	08039A	PARTICIPANT	\N	PRESENT	0
269220	269188	11104D	PARTICIPANT	\N	PRESENT	0
269221	269188	04070G	PARTICIPANT	\N	PRESENT	0
269223	269188	19573D	PARTICIPANT	\N	PRESENT	0
269224	269188	19735D	PARTICIPANT	\N	PRESENT	0
269225	269188	14229S	PARTICIPANT	\N	PRESENT	0
269226	269188	04018C	PARTICIPANT	\N	PRESENT	0
269298	269290	14187A	PARTICIPANT	\N	PRESENT	0
269454	269453	07034Q	PRESIDENT	0	PRESENT	0
269455	269453	01024M	PARTICIPANT	\N	PRESENT	0
269456	269453	19585H	PARTICIPANT	\N	PRESENT	0
269457	269453	01028R	PARTICIPANT	\N	PRESENT	0
269458	269453	14231L	PARTICIPANT	\N	PRESENT	0
269459	269453	19447X	PARTICIPANT	\N	PRESENT	0
269460	269453	08044W	PARTICIPANT	\N	PRESENT	0
269461	269453	14147R	PARTICIPANT	\N	PRESENT	0
269462	269453	14069U	PARTICIPANT	\N	PRESENT	0
269463	269453	14151M	PARTICIPANT	\N	PRESENT	0
269464	269453	14215L	PARTICIPANT	\N	PRESENT	0
269465	269453	04047H	PARTICIPANT	\N	EXCUSE	0
269466	269453	19729F	PARTICIPANT	\N	EXCUSE	0
269494	263466	98022P	PARTICIPANT	\N	PRESENT	0
269495	263466	07034Q	PARTICIPANT	\N	PRESENT	0
269496	263466	19693L	PARTICIPANT	\N	PRESENT	0
269497	263466	14191V	PARTICIPANT	\N	PRESENT	0
269498	263466	19581D	PARTICIPANT	\N	PRESENT	0
269499	263466	14029X	PARTICIPANT	\N	PRESENT	0
269500	263466	08044W	PARTICIPANT	\N	PRESENT	0
269501	263466	11080N	PARTICIPANT	\N	PRESENT	0
269502	263466	19383Y	PARTICIPANT	\N	PRESENT	0
269503	263466	95062K	PARTICIPANT	\N	PRESENT	0
269504	263466	19731Y	PARTICIPANT	\N	PRESENT	0
269505	263466	19659J	PARTICIPANT	\N	PRESENT	0
269506	263466	19671E	PARTICIPANT	\N	PRESENT	0
269507	263466	14097Y	PARTICIPANT	\N	PRESENT	0
269508	263466	19709B	PARTICIPANT	\N	PRESENT	0
269509	263466	07033P	PARTICIPANT	\N	PRESENT	0
269510	263466	14030Q	PARTICIPANT	\N	PRESENT	0
269511	263466	19631V	PARTICIPANT	\N	PRESENT	0
269512	263466	11104D	PARTICIPANT	\N	PRESENT	0
269513	263466	14051J	PARTICIPANT	\N	PRESENT	0
269514	263466	19479G	PARTICIPANT	\N	PRESENT	0
269515	263466	08021P	PARTICIPANT	\N	PRESENT	0
269516	263466	08012N	PARTICIPANT	\N	PRESENT	0
269517	263466	14197C	PARTICIPANT	\N	PRESENT	0
269518	263466	19503N	PARTICIPANT	\N	PRESENT	0
269519	263466	04045F	PARTICIPANT	\N	PRESENT	0
269520	263466	19619A	PARTICIPANT	\N	PRESENT	0
269521	263466	19719D	PARTICIPANT	\N	PRESENT	0
269522	263466	11053K	PARTICIPANT	\N	PRESENT	0
269523	263466	19629C	PARTICIPANT	\N	PRESENT	0
269524	263466	19737F	PARTICIPANT	\N	PRESENT	0
269526	263466	80013X	PARTICIPANT	\N	PRESENT	0
269527	263466	19683J	PARTICIPANT	\N	PRESENT	0
269528	263466	08014Q	PARTICIPANT	\N	PRESENT	0
269529	263466	14281W	PARTICIPANT	\N	PRESENT	0
269530	263466	14201E	PARTICIPANT	\N	PRESENT	0
269531	263466	11040E	PARTICIPANT	\N	PRESENT	0
269532	263466	19545Y	PARTICIPANT	\N	PRESENT	0
269533	263466	19583F	PARTICIPANT	\N	PRESENT	0
269534	263466	14063N	PARTICIPANT	\N	PRESENT	0
269535	269525	05008E	PRESIDENT	0	PRESENT	0
269536	269453	14065Q	PARTICIPANT	\N	EXCUSE	0
269537	269525	14065Q	PARTICIPANT	\N	PRESENT	0
269538	269525	14089Y	PARTICIPANT	\N	PRESENT	0
269539	269525	14215L	PARTICIPANT	\N	PRESENT	0
245660	245659	14255U	PARTICIPANT	\N	PRESENT	0
245661	245659	18083K	PARTICIPANT	\N	PRESENT	0
245662	245659	08010L	PARTICIPANT	\N	PRESENT	0
246115	239694	04043D	PARTICIPANT	\N	PRESENT	0
245664	245659	14033T	PARTICIPANT	\N	PRESENT	0
245665	245659	08053X	PARTICIPANT	\N	PRESENT	0
246113	239669	04043D	PARTICIPANT	\N	PRESENT	0
246114	240599	04043D	PARTICIPANT	\N	PRESENT	0
246116	239697	04043D	PARTICIPANT	\N	PRESENT	0
246118	246117	11053K	PARTICIPANT	\N	PRESENT	0
246119	246117	14079W	PARTICIPANT	\N	PRESENT	0
246120	246117	08052W	PARTICIPANT	\N	PRESENT	0
246121	246117	95030B	PARTICIPANT	\N	PRESENT	0
246122	246117	15447F	PARTICIPANT	\N	PRESENT	0
246123	246117	04097T	PARTICIPANT	\N	PRESENT	0
246124	246117	04044E	PARTICIPANT	\N	PRESENT	0
246125	246117	19421M	PARTICIPANT	\N	PRESENT	0
246126	246117	98050T	PARTICIPANT	\N	PRESENT	0
246127	246117	04088S	PARTICIPANT	\N	PRESENT	0
246128	246117	19573D	PARTICIPANT	\N	PRESENT	0
246129	246117	01048V	PARTICIPANT	\N	PRESENT	0
246130	246117	11026G	PARTICIPANT	\N	PRESENT	0
246132	246131	01048V	PARTICIPANT	\N	PRESENT	0
249306	246405	98053W	PARTICIPANT	\N	EXCUSE	0
249307	246405	14133K	PARTICIPANT	\N	EXCUSE	0
249308	246405	14097Y	PARTICIPANT	\N	EXCUSE	0
249309	246405	14028W	PARTICIPANT	\N	EXCUSE	0
249310	246405	04034C	PARTICIPANT	\N	EXCUSE	0
249649	249648	14239U	PARTICIPANT	\N	PRESENT	0
249650	249648	04033B	PARTICIPANT	\N	PRESENT	0
249651	249648	19741B	PARTICIPANT	\N	PRESENT	0
249652	249648	95067Q	PARTICIPANT	\N	PRESENT	0
249653	249648	95030B	PARTICIPANT	\N	PRESENT	0
249654	249648	04088S	PARTICIPANT	\N	PRESENT	0
249655	249648	98022P	PARTICIPANT	\N	PRESENT	0
249656	249648	14217N	PARTICIPANT	\N	PRESENT	0
249657	249648	97011G	PARTICIPANT	\N	PRESENT	0
249658	249648	14097Y	PARTICIPANT	\N	PRESENT	0
249659	249648	04097T	PARTICIPANT	\N	PRESENT	0
249660	249648	04040A	PARTICIPANT	\N	PRESENT	0
249661	249648	04035D	PARTICIPANT	\N	PRESENT	0
250305	250304	14083S	PARTICIPANT	\N	PRESENT	0
249663	249648	16685X	PARTICIPANT	\N	PRESENT	0
249664	249648	19663E	PARTICIPANT	\N	PRESENT	0
249665	249648	19643A	PARTICIPANT	\N	PRESENT	0
249666	249648	19723Y	PARTICIPANT	\N	PRESENT	0
251901	250204	14261S	PARTICIPANT	\N	PRESENT	0
251902	250204	11109J	PARTICIPANT	\N	PRESENT	0
251903	250204	14259Y	PARTICIPANT	\N	PRESENT	0
251904	250204	08019V	PRESIDENT	0	PRESENT	0
251905	250204	19715Y	PARTICIPANT	\N	PRESENT	0
251906	250204	19301E	PARTICIPANT	\N	PRESENT	0
251907	250204	14275Y	PARTICIPANT	\N	PRESENT	0
251908	250204	04043D	PARTICIPANT	\N	EXCUSE	0
251909	250204	14225N	PARTICIPANT	\N	EXCUSE	0
253278	240307	11070L	PARTICIPANT	0	PRESENT	0
253279	240307	14055N	PARTICIPANT	0	PRESENT	0
253280	240307	04045F	PARTICIPANT	0	PRESENT	0
253281	240307	19697Q	PARTICIPANT	0	PRESENT	0
253282	240307	19593H	PARTICIPANT	0	PRESENT	0
253283	240307	80013X	PARTICIPANT	0	PRESENT	0
253284	240307	19387D	PARTICIPANT	0	PRESENT	0
253285	240307	19467C	PARTICIPANT	0	PRESENT	0
253286	240307	11097X	PARTICIPANT	0	PRESENT	0
253287	240307	04088S	PARTICIPANT	0	PRESENT	0
253288	240307	07004J	PARTICIPANT	0	PRESENT	0
253289	240307	19709B	PARTICIPANT	0	PRESENT	0
253290	240307	19729F	PARTICIPANT	0	PRESENT	0
253291	240307	14191V	PARTICIPANT	0	PRESENT	0
253292	240307	19737F	PARTICIPANT	0	PRESENT	0
253293	240307	14103D	PARTICIPANT	0	PRESENT	0
253294	240307	14357A	PARTICIPANT	0	PRESENT	0
253295	240307	14329V	PARTICIPANT	0	PRESENT	0
253296	240307	19679N	PARTICIPANT	0	PRESENT	0
253297	240307	14257W	PARTICIPANT	0	PRESENT	0
253298	240307	17779H	PARTICIPANT	0	PRESENT	0
253299	240307	19747H	PARTICIPANT	0	PRESENT	0
253300	240307	11056N	PARTICIPANT	0	PRESENT	0
253301	240307	11031D	PARTICIPANT	0	PRESENT	0
253302	240307	14265W	PARTICIPANT	0	PRESENT	0
253303	240307	14213J	PARTICIPANT	0	PRESENT	0
253304	240307	19703U	PARTICIPANT	0	PRESENT	0
253305	240307	19711U	PARTICIPANT	0	PRESENT	0
253306	240307	04085P	PARTICIPANT	0	PRESENT	0
253307	240307	11040E	PARTICIPANT	0	PRESENT	0
253308	240307	12041X	PARTICIPANT	0	PRESENT	0
253309	240307	19347U	PARTICIPANT	0	PRESENT	0
253310	240307	19695N	PARTICIPANT	0	PRESENT	0
253311	240307	11033F	PARTICIPANT	0	PRESENT	0
253312	240307	19683J	PARTICIPANT	0	PRESENT	0
253313	240307	19647E	PARTICIPANT	0	PRESENT	0
253314	240307	19503N	PARTICIPANT	0	PRESENT	0
253315	240307	19551W	PARTICIPANT	0	PRESENT	0
253316	240307	19715Y	PARTICIPANT	0	PRESENT	0
253317	240307	14281W	PARTICIPANT	0	PRESENT	0
253318	240307	19413M	PARTICIPANT	0	PRESENT	0
253319	240307	14207L	PARTICIPANT	0	PRESENT	0
253320	240307	14097Y	PARTICIPANT	0	PRESENT	0
253321	240307	19727D	PARTICIPANT	0	PRESENT	0
253322	240307	14051J	PARTICIPANT	0	PRESENT	0
253323	240307	19549D	PARTICIPANT	0	PRESENT	0
253324	240307	08055A	PARTICIPANT	0	PRESENT	0
253325	240307	19687N	PARTICIPANT	0	PRESENT	0
253326	240307	19349W	PARTICIPANT	0	PRESENT	0
253327	240307	14239U	PARTICIPANT	0	PRESENT	0
253328	240307	11012A	PARTICIPANT	0	PRESENT	0
253329	240307	19253P	PARTICIPANT	0	PRESENT	0
253330	240307	14241N	PARTICIPANT	0	PRESENT	0
253331	240307	19511N	PARTICIPANT	0	PRESENT	0
253332	240307	19619A	PARTICIPANT	0	PRESENT	0
253333	240307	17589D	PARTICIPANT	0	PRESENT	0
253334	240307	14195A	PARTICIPANT	0	PRESENT	0
253335	240307	14042U	PARTICIPANT	0	PRESENT	0
253336	240307	08056B	PARTICIPANT	0	PRESENT	0
253337	240307	19691J	PARTICIPANT	0	PRESENT	0
253338	240307	19719D	PARTICIPANT	0	PRESENT	0
253339	240307	08049C	PARTICIPANT	0	PRESENT	0
253340	240307	14085U	PARTICIPANT	0	PRESENT	0
253341	240307	14073Q	PARTICIPANT	0	PRESENT	0
253342	240307	01024M	PARTICIPANT	0	PRESENT	0
253343	240307	14034U	PARTICIPANT	0	PRESENT	0
253344	240307	08061X	PARTICIPANT	0	PRESENT	0
253345	240307	19577H	PARTICIPANT	0	PRESENT	0
253346	240307	19713W	PARTICIPANT	0	PRESENT	0
253347	240307	19367Y	PARTICIPANT	0	PRESENT	0
253348	240307	89017R	PARTICIPANT	0	PRESENT	0
253349	240307	19701S	PARTICIPANT	0	PRESENT	0
253350	240307	19483C	PARTICIPANT	0	PRESENT	0
253351	240307	14059S	PARTICIPANT	0	PRESENT	0
253352	240307	14217N	PARTICIPANT	0	PRESENT	0
253353	240307	05012A	PARTICIPANT	0	PRESENT	0
253354	240307	19533U	PARTICIPANT	0	PRESENT	0
253355	240307	10006L	PARTICIPANT	0	PRESENT	0
253356	240307	19335Q	PARTICIPANT	0	PRESENT	0
253357	240307	14069U	PARTICIPANT	0	PRESENT	0
253358	240307	14249W	PARTICIPANT	0	PRESENT	0
253359	240307	14053L	PARTICIPANT	0	PRESENT	0
253360	240307	14187A	PARTICIPANT	0	PRESENT	0
253361	240307	14327T	PARTICIPANT	0	PRESENT	0
253362	240307	98024R	PARTICIPANT	0	PRESENT	0
253363	240307	14223L	PARTICIPANT	0	PRESENT	0
253364	240307	19521Q	PARTICIPANT	0	PRESENT	0
253365	240307	08015R	PARTICIPANT	0	PRESENT	0
253366	240307	14147R	PARTICIPANT	0	PRESENT	0
253367	240307	11048N	PARTICIPANT	0	PRESENT	0
253368	240307	14105F	PARTICIPANT	0	PRESENT	0
253369	240307	14115H	PARTICIPANT	0	PRESENT	0
253370	240307	14157T	PARTICIPANT	0	PRESENT	0
253371	240307	14135M	PARTICIPANT	0	PRESENT	0
253372	240307	19657G	PARTICIPANT	0	PRESENT	0
253373	240307	14033T	PARTICIPANT	0	PRESENT	0
253374	240307	14119M	PARTICIPANT	0	PRESENT	0
253375	240307	14133K	PARTICIPANT	0	PRESENT	0
253376	240307	19447X	PARTICIPANT	0	PRESENT	0
253377	240307	14038Y	PARTICIPANT	0	PRESENT	0
253378	240307	19723Y	PARTICIPANT	0	PRESENT	0
253379	240307	08031R	PARTICIPANT	0	PRESENT	0
253380	240307	08020N	PARTICIPANT	0	PRESENT	0
253381	240307	19415P	PARTICIPANT	0	PRESENT	0
253382	240307	11099A	PARTICIPANT	0	PRESENT	0
253383	240307	04092N	PARTICIPANT	0	PRESENT	0
253384	240307	14031R	PARTICIPANT	0	PRESENT	0
253385	240307	14071N	PARTICIPANT	0	PRESENT	0
263467	261490	11026G	PARTICIPANT	\N	PRESENT	0
263468	261490	11045K	PARTICIPANT	\N	PRESENT	0
263757	261491	04044E	PARTICIPANT	\N	PRESENT	0
263776	261491	14053L	PARTICIPANT	\N	PRESENT	0
263777	261491	95063L	PARTICIPANT	\N	PRESENT	0
263778	261491	19651A	PARTICIPANT	\N	PRESENT	0
263779	261491	19329S	PARTICIPANT	\N	PRESENT	0
263781	261491	11056N	PARTICIPANT	\N	PRESENT	0
263782	261491	19593H	PARTICIPANT	\N	PRESENT	0
263783	261491	19719D	PARTICIPANT	\N	PRESENT	0
263784	261491	04038G	PARTICIPANT	\N	PRESENT	0
263785	261491	14261S	PARTICIPANT	\N	PRESENT	0
263786	261491	08044W	PARTICIPANT	\N	PRESENT	0
263787	261491	19737F	PARTICIPANT	\N	PRESENT	0
263788	261491	19691J	PARTICIPANT	\N	PRESENT	0
263789	261491	11012A	PARTICIPANT	\N	PRESENT	0
263790	261491	14157T	PARTICIPANT	\N	PRESENT	0
263791	261491	11043H	PARTICIPANT	\N	PRESENT	0
263792	261491	14259Y	PARTICIPANT	\N	PRESENT	0
263793	261491	19447X	PARTICIPANT	\N	PRESENT	0
263794	261491	19467C	PARTICIPANT	\N	PRESENT	0
263795	261491	19507S	PARTICIPANT	\N	PRESENT	0
263796	261491	19731Y	PARTICIPANT	\N	PRESENT	0
263797	261491	14055N	PARTICIPANT	\N	PRESENT	0
263798	261491	19701S	PARTICIPANT	\N	PRESENT	0
263799	261491	11067R	PARTICIPANT	\N	PRESENT	0
263800	261491	19695N	PARTICIPANT	\N	PRESENT	0
263801	261491	14065Q	PARTICIPANT	\N	PRESENT	0
263802	261491	08031R	PARTICIPANT	\N	PRESENT	0
263803	261491	19629C	PARTICIPANT	\N	PRESENT	0
263804	261491	19563B	PARTICIPANT	\N	PRESENT	0
263805	261491	14087W	PARTICIPANT	\N	PRESENT	0
263806	261491	14119M	PARTICIPANT	\N	PRESENT	0
263807	261491	10006L	PARTICIPANT	\N	PRESENT	0
263808	261491	19671E	PARTICIPANT	\N	PRESENT	0
263809	261491	01028R	PARTICIPANT	\N	PRESENT	0
263810	261491	11049P	PARTICIPANT	\N	PRESENT	0
263811	261491	04071H	PARTICIPANT	\N	PRESENT	0
263812	261491	19643A	PARTICIPANT	\N	PRESENT	0
263813	261491	19711U	PARTICIPANT	\N	PRESENT	0
263814	261491	08052W	PARTICIPANT	\N	PRESENT	0
263815	261491	19681G	PARTICIPANT	\N	PRESENT	0
263816	261491	14211G	PARTICIPANT	\N	PRESENT	0
263817	261491	19713W	PARTICIPANT	\N	PRESENT	0
263818	261491	19693L	PARTICIPANT	\N	PRESENT	0
263819	261491	19553Y	PARTICIPANT	\N	PRESENT	0
263820	261491	19399H	PARTICIPANT	\N	PRESENT	0
263821	261491	14241N	PARTICIPANT	\N	PRESENT	0
263822	261491	05008E	PARTICIPANT	\N	PRESENT	0
263823	261491	08053X	PARTICIPANT	\N	PRESENT	0
263824	261491	11066Q	PARTICIPANT	\N	PRESENT	0
263825	261491	19551W	PARTICIPANT	\N	PRESENT	0
263826	261491	19631V	PARTICIPANT	\N	PRESENT	0
263827	261491	19387D	PARTICIPANT	\N	PRESENT	0
263828	261491	08035V	PARTICIPANT	\N	PRESENT	0
263829	258758	14261S	PARTICIPANT	\N	PRESENT	0
263831	261491	19703U	PARTICIPANT	\N	PRESENT	0
263832	259068	19511N	PARTICIPANT	\N	EXCUSE	0
263833	259068	19723Y	PARTICIPANT	\N	EXCUSE	0
263834	259068	19533U	PARTICIPANT	\N	EXCUSE	0
263835	261490	14109K	PARTICIPANT	\N	PRESENT	0
263836	261490	14253S	PARTICIPANT	\N	PRESENT	0
263842	261491	19549D	PARTICIPANT	\N	PRESENT	0
263847	261491	14111D	PARTICIPANT	\N	PRESENT	0
263848	261491	14195A	PARTICIPANT	\N	PRESENT	0
263935	256021	08056B	PARTICIPANT	\N	PRESENT	0
263936	256021	19611R	PARTICIPANT	\N	PRESENT	0
263937	256021	19421M	PARTICIPANT	\N	PRESENT	0
263938	256021	11027H	PARTICIPANT	\N	PRESENT	0
263939	256021	98050T	PARTICIPANT	\N	PRESENT	0
263940	256021	08010L	PARTICIPANT	\N	PRESENT	0
263941	256021	98029W	PRESIDENT	0	PRESENT	0
263942	256021	19575F	PARTICIPANT	\N	EXCUSE	0
263945	261491	19573D	PARTICIPANT	\N	PRESENT	0
263946	261491	19657G	PARTICIPANT	\N	PRESENT	0
263947	261491	19333N	PARTICIPANT	\N	PRESENT	0
263948	261491	11031D	PARTICIPANT	\N	PRESENT	0
263949	261491	14109K	PARTICIPANT	\N	PRESENT	0
263950	261491	08049C	PARTICIPANT	\N	PRESENT	0
263951	261491	11099A	PARTICIPANT	\N	PRESENT	0
263952	261491	14123H	PARTICIPANT	\N	PRESENT	0
264017	261492	08035V	PARTICIPANT	\N	PRESENT	0
264018	261492	19333N	PARTICIPANT	\N	PRESENT	0
264019	261492	19593H	PARTICIPANT	\N	PRESENT	0
264020	261492	11031D	PARTICIPANT	\N	PRESENT	0
264021	261492	14109K	PARTICIPANT	\N	PRESENT	0
264048	261492	14179A	PARTICIPANT	\N	PRESENT	0
264023	261492	11064N	PARTICIPANT	\N	PRESENT	0
264024	261492	14039A	PARTICIPANT	\N	PRESENT	0
264025	261492	11099A	PARTICIPANT	\N	PRESENT	0
264026	261492	19681G	PARTICIPANT	\N	PRESENT	0
264027	261492	11012A	PARTICIPANT	\N	PRESENT	0
264028	261492	08031R	PARTICIPANT	\N	PRESENT	0
264029	261492	14261S	PARTICIPANT	\N	PRESENT	0
264030	261492	08009T	PARTICIPANT	\N	PRESENT	0
264031	261492	14327T	PARTICIPANT	\N	PRESENT	0
264032	261492	08056B	PARTICIPANT	\N	PRESENT	0
264033	261492	19335Q	PARTICIPANT	\N	PRESENT	0
264034	261492	14331P	PARTICIPANT	\N	PRESENT	0
264035	261492	14217N	PARTICIPANT	\N	PRESENT	0
264036	261492	10006L	PARTICIPANT	\N	PRESENT	0
264037	261492	14123H	PARTICIPANT	\N	PRESENT	0
264038	261492	19657G	PARTICIPANT	\N	PRESENT	0
264039	261492	19399H	PARTICIPANT	\N	PRESENT	0
264040	261492	19693L	PARTICIPANT	\N	PRESENT	0
264041	261492	14053L	PARTICIPANT	\N	PRESENT	0
264042	261492	19573D	PARTICIPANT	\N	PRESENT	0
264043	261492	17637T	PARTICIPANT	\N	PRESENT	0
264044	261492	19329S	PARTICIPANT	\N	PRESENT	0
264045	261492	11049P	PARTICIPANT	\N	PRESENT	0
264046	261492	14251Q	PARTICIPANT	\N	PRESENT	0
264047	261492	19553Y	PARTICIPANT	\N	PRESENT	0
264083	264079	08034U	PARTICIPANT	\N	PRESENT	0
264088	264086	08034U	PARTICIPANT	\N	PRESENT	0
264094	264091	08034U	PARTICIPANT	\N	PRESENT	0
264098	264097	05008E	PARTICIPANT	\N	PRESENT	0
264099	264097	08044W	PARTICIPANT	\N	PRESENT	0
264100	264097	14041T	PARTICIPANT	\N	PRESENT	0
264101	264097	19673G	PARTICIPANT	\N	PRESENT	0
264102	264097	11026G	PARTICIPANT	\N	PRESENT	0
264103	264097	19543W	PARTICIPANT	\N	PRESENT	0
264104	264097	19649G	PARTICIPANT	\N	PRESENT	0
264105	264097	14179A	PARTICIPANT	\N	PRESENT	0
264157	264156	14089Y	PARTICIPANT	\N	PRESENT	0
264161	262998	19565D	PARTICIPANT	\N	PRESENT	0
264178	262998	14028W	PARTICIPANT	\N	EXCUSE	0
264179	262998	08048B	PARTICIPANT	\N	EXCUSE	0
264180	262998	04044E	PARTICIPANT	\N	PRESENT	0
264181	262998	14231L	PARTICIPANT	\N	EXCUSE	0
264184	262998	14103D	PARTICIPANT	\N	EXCUSE	0
264205	264204	14121F	PARTICIPANT	\N	PRESENT	0
264251	262902	19713W	PARTICIPANT	\N	PRESENT	0
264252	262902	19711U	PARTICIPANT	\N	PRESENT	0
264253	262902	19681G	PARTICIPANT	\N	PRESENT	0
264254	262902	98023Q	PARTICIPANT	\N	PRESENT	0
264255	262902	04097T	PARTICIPANT	\N	PRESENT	0
264256	262902	19737F	PARTICIPANT	\N	PRESENT	0
264257	262902	11048N	PARTICIPANT	\N	PRESENT	0
264258	262902	14219Q	PARTICIPANT	\N	PRESENT	0
264303	263035	04086Q	PARTICIPANT	\N	PRESENT	0
264304	263035	95063L	PARTICIPANT	\N	PRESENT	0
264305	263035	14239U	PARTICIPANT	\N	PRESENT	0
264015	261492	04044E	PARTICIPANT	\N	PRESENT	0
264016	261492	08052W	PARTICIPANT	\N	PRESENT	0
264306	263035	19715Y	PARTICIPANT	\N	PRESENT	0
264307	263035	19583F	PARTICIPANT	\N	PRESENT	0
264308	263035	14215L	PARTICIPANT	\N	PRESENT	0
264309	263035	01060R	PARTICIPANT	\N	PRESENT	0
264310	263035	89017R	PARTICIPANT	\N	PRESENT	0
264311	263035	14223L	PARTICIPANT	\N	PRESENT	0
264312	263035	04044E	PARTICIPANT	\N	PRESENT	0
264313	263035	11067R	PARTICIPANT	\N	PRESENT	0
264314	263035	01062T	PARTICIPANT	\N	PRESENT	0
264315	263035	11066Q	PARTICIPANT	\N	PRESENT	0
264316	263035	19695N	PARTICIPANT	\N	PRESENT	0
264317	263035	19387D	PARTICIPANT	\N	PRESENT	0
264318	263035	19629C	PARTICIPANT	\N	PRESENT	0
264319	263035	11072N	PARTICIPANT	\N	PRESENT	0
264320	263035	14026U	PARTICIPANT	\N	PRESENT	0
264321	263035	14030Q	PARTICIPANT	\N	PRESENT	0
264322	263035	14231L	PARTICIPANT	\N	PRESENT	0
264323	263035	11012A	PARTICIPANT	\N	PRESENT	0
264324	263035	14059S	PARTICIPANT	\N	PRESENT	0
264325	263035	01024M	PARTICIPANT	\N	PRESENT	0
264326	263035	14267Y	PARTICIPANT	\N	PRESENT	0
264327	263035	19413M	PARTICIPANT	\N	PRESENT	0
264328	263035	01028R	PARTICIPANT	\N	PRESENT	0
241202	241201	14026U	PARTICIPANT	\N	PRESENT	0
241204	241203	14026U	PARTICIPANT	\N	PRESENT	0
241279	241163	98035U	PARTICIPANT	\N	PRESENT	0
241280	241163	14111D	PARTICIPANT	\N	PRESENT	0
241281	241163	07034Q	PRESIDENT	0	PRESENT	0
241282	241163	01024M	PARTICIPANT	\N	PRESENT	0
241283	241163	19585H	PARTICIPANT	\N	PRESENT	0
241284	241163	01028R	PARTICIPANT	\N	PRESENT	0
241285	241163	19447X	PARTICIPANT	\N	PRESENT	0
241286	241163	19725B	PARTICIPANT	\N	PRESENT	0
241287	241163	14089Y	PARTICIPANT	\N	PRESENT	0
241288	241163	19489J	PARTICIPANT	\N	PRESENT	0
241289	241163	95063L	PARTICIPANT	\N	PRESENT	0
241290	241163	14041T	PARTICIPANT	\N	PRESENT	0
241291	241163	14147R	PARTICIPANT	\N	PRESENT	0
241292	241163	14179A	PARTICIPANT	\N	PRESENT	0
241293	241163	14151M	PARTICIPANT	\N	PRESENT	0
241295	241163	08018U	PARTICIPANT	\N	PRESENT	0
241296	241163	19483C	PARTICIPANT	\N	PRESENT	0
241297	241163	14065Q	PARTICIPANT	\N	EXCUSE	0
241307	241278	19593H	PARTICIPANT	\N	PRESENT	0
241308	241278	14059S	PARTICIPANT	\N	PRESENT	0
241309	241278	04070G	PRESIDENT	0	PRESENT	0
241310	241278	19643A	PARTICIPANT	\N	PRESENT	0
241311	241278	19699S	PARTICIPANT	\N	PRESENT	0
241312	241278	04057K	PARTICIPANT	\N	PRESENT	0
241313	241278	12041X	PARTICIPANT	\N	PRESENT	0
241314	241278	19611R	PARTICIPANT	\N	PRESENT	0
241315	241278	08043V	PARTICIPANT	\N	PRESENT	0
241316	241278	14229S	PARTICIPANT	\N	PRESENT	0
241317	241278	14030Q	PARTICIPANT	\N	PRESENT	0
241318	241278	14241N	PARTICIPANT	\N	PRESENT	0
241319	241278	14251Q	PARTICIPANT	\N	PRESENT	0
241320	241278	19573D	PARTICIPANT	\N	PRESENT	0
241321	241278	14107H	PARTICIPANT	\N	PRESENT	0
241322	241278	19735D	PARTICIPANT	\N	PRESENT	0
241323	241278	11109J	PARTICIPANT	\N	PRESENT	0
241324	241278	14063N	PARTICIPANT	\N	PRESENT	0
241325	241278	08012N	PARTICIPANT	\N	PRESENT	0
241326	241278	19749K	PARTICIPANT	\N	PRESENT	0
241327	241278	08039A	PARTICIPANT	\N	PRESENT	0
241328	241278	08031R	PARTICIPANT	\N	PRESENT	0
241329	241278	19693L	PARTICIPANT	\N	EXCUSE	0
241330	241278	87003B	PARTICIPANT	\N	EXCUSE	0
241331	241278	04018C	PARTICIPANT	\N	EXCUSE	0
241335	241266	19701S	PARTICIPANT	\N	PRESENT	0
241336	241266	95062K	PARTICIPANT	\N	PRESENT	0
241337	241266	19387D	PARTICIPANT	\N	PRESENT	0
241338	241266	11053K	PARTICIPANT	\N	PRESENT	0
241339	241266	14219Q	PARTICIPANT	\N	PRESENT	0
241340	241266	19543W	PARTICIPANT	\N	PRESENT	0
241341	241266	19667J	PARTICIPANT	\N	PRESENT	0
241342	241266	19581D	PARTICIPANT	\N	PRESENT	0
241343	241266	19637C	PARTICIPANT	\N	PRESENT	0
241344	241266	02002K	PARTICIPANT	\N	PRESENT	0
241345	241266	18083K	PARTICIPANT	\N	PRESENT	0
241346	241266	14237S	PARTICIPANT	\N	PRESENT	0
241347	241266	08010L	PARTICIPANT	\N	PRESENT	0
241348	241266	98023Q	PARTICIPANT	\N	PRESENT	0
241349	241266	17637T	PARTICIPANT	\N	PRESENT	0
241350	241266	14038Y	PARTICIPANT	\N	PRESENT	0
241351	241266	19711U	PARTICIPANT	\N	PRESENT	0
241352	241266	19713W	PARTICIPANT	\N	PRESENT	0
241353	241266	19611R	PARTICIPANT	\N	PRESENT	0
241354	241266	15447F	PARTICIPANT	\N	PRESENT	0
241355	241266	04086Q	PARTICIPANT	\N	PRESENT	0
241356	241266	14093U	PARTICIPANT	\N	PRESENT	0
241357	241266	14029X	PARTICIPANT	\N	PRESENT	0
241358	241266	19733B	PARTICIPANT	\N	PRESENT	0
241359	241266	08009T	PRESIDENT	0	PRESENT	0
241360	241266	19737F	PARTICIPANT	\N	PRESENT	0
241361	241266	04097T	PARTICIPANT	\N	PRESENT	0
241362	241266	19741B	PARTICIPANT	\N	PRESENT	0
241363	241266	19659J	PARTICIPANT	\N	PRESENT	0
241364	241266	19745F	PARTICIPANT	\N	EXCUSE	0
241365	241266	08024S	PARTICIPANT	\N	EXCUSE	0
241366	241266	19599P	PARTICIPANT	\N	EXCUSE	0
241373	239694	04086Q	PARTICIPANT	\N	PRESENT	0
241375	239694	12041X	PARTICIPANT	\N	PRESENT	0
241376	239694	17637T	PARTICIPANT	\N	PRESENT	0
241377	239694	08028W	PARTICIPANT	\N	PRESENT	0
241378	239694	19731Y	PARTICIPANT	\N	PRESENT	0
241379	239694	19399H	PARTICIPANT	\N	PRESENT	0
241380	239694	14073Q	PARTICIPANT	\N	PRESENT	0
241381	239694	19447X	PARTICIPANT	\N	PRESENT	0
241446	239694	01025N	PARTICIPANT	\N	PRESENT	0
241383	239694	14241N	PARTICIPANT	\N	PRESENT	0
241384	239694	19301E	PARTICIPANT	\N	PRESENT	0
241385	239694	19649G	PARTICIPANT	\N	PRESENT	0
241386	239694	19585H	PARTICIPANT	\N	PRESENT	0
241387	239694	11043H	PARTICIPANT	\N	PRESENT	0
241388	239694	19349W	PARTICIPANT	\N	PRESENT	0
241389	239694	19533U	PARTICIPANT	\N	PRESENT	0
241390	239694	14038Y	PARTICIPANT	\N	PRESENT	0
241394	239694	19699S	PARTICIPANT	\N	PRESENT	0
241397	239694	11053K	PARTICIPANT	\N	PRESENT	0
241398	239694	08012N	PARTICIPANT	\N	PRESENT	0
241399	239694	04057K	PARTICIPANT	\N	PRESENT	0
241400	239694	07034Q	PARTICIPANT	\N	PRESENT	0
241401	239694	04070G	PARTICIPANT	\N	PRESENT	0
241402	239694	14087W	PARTICIPANT	\N	PRESENT	0
241403	239694	04018C	PARTICIPANT	\N	PRESENT	0
241404	239694	19629C	PARTICIPANT	\N	PRESENT	0
241405	239694	14021P	PARTICIPANT	\N	PRESENT	0
241406	239694	08016S	PARTICIPANT	\N	PRESENT	0
241407	239694	19333N	PARTICIPANT	\N	PRESENT	0
241408	239694	14107H	PARTICIPANT	\N	PRESENT	0
241409	239694	11066Q	PARTICIPANT	\N	PRESENT	0
241410	239694	19725B	PARTICIPANT	\N	PRESENT	0
241411	239694	08017T	PARTICIPANT	\N	PRESENT	0
241412	239694	19503N	PARTICIPANT	\N	PRESENT	0
241413	239694	14061L	PARTICIPANT	\N	PRESENT	0
241414	239694	19507S	PARTICIPANT	\N	PRESENT	0
241415	239694	19467C	PARTICIPANT	\N	PRESENT	0
241416	239694	19671E	PARTICIPANT	\N	PRESENT	0
241417	239694	14215L	PARTICIPANT	\N	PRESENT	0
241418	239694	14033T	PARTICIPANT	\N	PRESENT	0
241419	239694	19687N	PARTICIPANT	\N	PRESENT	0
241420	239694	19695N	PARTICIPANT	\N	PRESENT	0
241421	239694	08055A	PARTICIPANT	\N	PRESENT	0
241422	239694	08031R	PARTICIPANT	\N	PRESENT	0
241423	239694	08056B	PARTICIPANT	\N	PRESENT	0
241424	239694	19737F	PARTICIPANT	\N	PRESENT	0
241425	239694	19735D	PARTICIPANT	\N	PRESENT	0
241426	239694	14219Q	PARTICIPANT	\N	PRESENT	0
241427	239694	14195A	PARTICIPANT	\N	PRESENT	0
241428	239694	14031R	PARTICIPANT	\N	PRESENT	0
241429	239694	14237S	PARTICIPANT	\N	PRESENT	0
241430	239694	14059S	PARTICIPANT	\N	PRESENT	0
241431	239694	19631V	PARTICIPANT	\N	PRESENT	0
241432	239694	14063N	PARTICIPANT	\N	PRESENT	0
241433	239694	14197C	PARTICIPANT	\N	PRESENT	0
241434	239694	19387D	PARTICIPANT	\N	PRESENT	0
241435	239694	95015C	PARTICIPANT	\N	PRESENT	0
241436	239694	04047H	PARTICIPANT	\N	PRESENT	0
241437	239694	14030Q	PARTICIPANT	\N	PRESENT	0
241438	239694	14257W	PARTICIPANT	\N	PRESENT	0
241439	239694	08043V	PARTICIPANT	\N	PRESENT	0
241440	239694	14265W	PARTICIPANT	\N	PRESENT	0
241441	239694	14147R	PARTICIPANT	\N	PRESENT	0
241442	239694	19543W	PARTICIPANT	\N	PRESENT	0
241443	239694	19723Y	PARTICIPANT	\N	PRESENT	0
241444	239694	95062K	PARTICIPANT	\N	PRESENT	0
241445	239694	19711U	PARTICIPANT	\N	PRESENT	0
241447	239694	19611R	PARTICIPANT	\N	PRESENT	0
241448	239694	04059M	PARTICIPANT	\N	PRESENT	0
241449	239694	11104D	PARTICIPANT	\N	PRESENT	0
241450	239694	14041T	PARTICIPANT	\N	PRESENT	0
241451	239694	19715Y	PARTICIPANT	\N	PRESENT	0
241452	239694	87003B	PARTICIPANT	\N	PRESENT	0
241453	239694	14221J	PARTICIPANT	\N	PRESENT	0
241455	239694	14065Q	PARTICIPANT	\N	PRESENT	0
241456	239694	14135M	PARTICIPANT	\N	PRESENT	0
241457	239694	11056N	PARTICIPANT	\N	PRESENT	0
241458	239694	19479G	PARTICIPANT	\N	PRESENT	0
241459	239694	14229S	PARTICIPANT	\N	PRESENT	0
241460	239694	19329S	PARTICIPANT	\N	PRESENT	0
241461	239694	19253P	PARTICIPANT	\N	PRESENT	0
241462	239694	14034U	PARTICIPANT	\N	PRESENT	0
241463	239694	17583W	PARTICIPANT	\N	PRESENT	0
241464	239694	19575F	PARTICIPANT	\N	PRESENT	0
241465	239694	01024M	PARTICIPANT	\N	PRESENT	0
241466	239694	08045X	PARTICIPANT	\N	PRESENT	0
241467	239694	14083S	PARTICIPANT	\N	PRESENT	0
241468	239694	19441R	PARTICIPANT	\N	PRESENT	0
241469	239694	14249W	PARTICIPANT	\N	PRESENT	0
241470	239694	14053L	PARTICIPANT	\N	PRESENT	0
267298	267297	14133K	PARTICIPANT	\N	PRESENT	0
267299	267297	14097Y	PARTICIPANT	\N	PRESENT	0
267304	267301	14133K	PARTICIPANT	\N	PRESENT	0
267306	267301	14097Y	PARTICIPANT	\N	PRESENT	0
267307	267301	98022P	PARTICIPANT	\N	PRESENT	0
267618	259074	19593H	PARTICIPANT	\N	PRESENT	0
267619	259075	19593H	PARTICIPANT	\N	PRESENT	0
269338	269331	14133K	PARTICIPANT	\N	PRESENT	0
269339	269331	14065Q	PARTICIPANT	\N	EXCUSE	0
269340	269331	96004D	PARTICIPANT	\N	PRESENT	0
269341	269331	14089Y	PARTICIPANT	\N	PRESENT	0
269342	269331	14357A	PARTICIPANT	\N	PRESENT	0
269345	269331	14079W	PARTICIPANT	\N	PRESENT	0
269346	269331	14249W	PARTICIPANT	\N	PRESENT	0
269348	269331	11083R	PARTICIPANT	\N	EXCUSE	0
269349	269331	14026U	PARTICIPANT	\N	PRESENT	0
269350	269331	19725B	PARTICIPANT	\N	PRESENT	0
269351	269331	04097T	PARTICIPANT	\N	PRESENT	0
269352	269331	95037J	PARTICIPANT	\N	PRESENT	0
269353	269331	14097Y	PARTICIPANT	\N	PRESENT	0
269354	269331	14073Q	PARTICIPANT	\N	PRESENT	0
269356	269331	08039A	PARTICIPANT	\N	PRESENT	0
269358	269331	14001X	PARTICIPANT	\N	PRESENT	0
269359	269331	19563B	PARTICIPANT	\N	PRESENT	0
269360	269331	19593H	PARTICIPANT	\N	PRESENT	0
269364	269331	14331P	PARTICIPANT	\N	PRESENT	0
269362	269331	04057K	PARTICIPANT	\N	EXCUSE	0
269363	269331	14237S	PARTICIPANT	\N	PRESENT	0
269365	269331	14225N	PARTICIPANT	\N	PRESENT	0
269366	269331	10015M	PARTICIPANT	\N	PRESENT	0
269367	269331	98035U	PARTICIPANT	\N	PRESENT	0
269368	269331	14135M	PARTICIPANT	\N	EXCUSE	0
269373	269331	08018U	PARTICIPANT	\N	EXCUSE	0
269374	269331	14033T	PARTICIPANT	\N	EXCUSE	0
269377	269331	14221J	PARTICIPANT	\N	EXCUSE	0
270126	270125	11064N	PARTICIPANT	\N	PRESENT	0
270127	270125	11054L	PARTICIPANT	\N	PRESENT	0
270383	270382	11064N	PARTICIPANT	\N	PRESENT	0
270384	270382	11054L	PARTICIPANT	\N	PRESENT	0
270646	270644	19721W	PARTICIPANT	\N	PRESENT	0
270647	270644	11049P	PARTICIPANT	\N	PRESENT	0
270648	270644	14097Y	PARTICIPANT	\N	PRESENT	0
270649	270644	19581D	PARTICIPANT	\N	PRESENT	0
270650	270644	19703U	PARTICIPANT	\N	PRESENT	0
270576	270575	04034C	PARTICIPANT	\N	PRESENT	0
270645	270644	08058D	PARTICIPANT	\N	PRESENT	0
270651	270644	19729F	PARTICIPANT	\N	EXCUSE	0
270727	268440	08053X	PARTICIPANT	\N	EXCUSE	0
270729	268440	04043D	PARTICIPANT	\N	EXCUSE	0
270730	268440	19553Y	PARTICIPANT	\N	PRESENT	0
270732	268440	01058X	PARTICIPANT	\N	PRESENT	0
270914	263474	14205J	PARTICIPANT	\N	PRESENT	0
270915	263474	14157T	PARTICIPANT	\N	PRESENT	0
270916	263474	08069G	PARTICIPANT	\N	PRESENT	0
270917	263474	14083S	PARTICIPANT	\N	PRESENT	0
270918	263474	08028W	PARTICIPANT	\N	PRESENT	0
270919	263474	14123H	PARTICIPANT	\N	PRESENT	0
270920	263474	11040E	PARTICIPANT	\N	PRESENT	0
270921	263474	12041X	PARTICIPANT	\N	PRESENT	0
270922	263474	04085P	PARTICIPANT	\N	PRESENT	0
270923	263474	07034Q	PARTICIPANT	\N	PRESENT	0
270924	263474	08010L	PARTICIPANT	\N	PRESENT	0
270925	263474	08020N	PARTICIPANT	\N	PRESENT	0
270926	263474	08039A	PARTICIPANT	\N	PRESENT	0
270927	263474	19703U	PARTICIPANT	\N	PRESENT	0
270928	263474	19673G	PARTICIPANT	\N	PRESENT	0
270929	263474	14199E	PARTICIPANT	\N	PRESENT	0
270930	263474	19711U	PARTICIPANT	\N	PRESENT	0
270931	263474	04008A	PARTICIPANT	\N	PRESENT	0
270932	263474	01058X	PARTICIPANT	\N	PRESENT	0
270933	263474	19643A	PARTICIPANT	\N	PRESENT	0
270934	263474	14031R	PARTICIPANT	\N	PRESENT	0
270935	263474	19667J	PARTICIPANT	\N	PRESENT	0
270936	263474	92040Q	PARTICIPANT	\N	PRESENT	0
270937	263474	19573D	PARTICIPANT	\N	PRESENT	0
270938	263474	19447X	PARTICIPANT	\N	PRESENT	0
270939	263474	14331P	PARTICIPANT	\N	PRESENT	0
270940	263474	04018C	PARTICIPANT	\N	PRESENT	0
270941	263474	01057W	PARTICIPANT	\N	PRESENT	0
270942	263474	14235Q	PARTICIPANT	\N	PRESENT	0
270943	263474	87003B	PARTICIPANT	\N	PRESENT	0
270944	263474	11080N	PARTICIPANT	\N	PRESENT	0
270945	263474	11063M	PARTICIPANT	\N	PRESENT	0
270946	263474	11056N	PARTICIPANT	\N	PRESENT	0
270947	263474	19687N	PARTICIPANT	\N	PRESENT	0
270948	263474	04038G	PARTICIPANT	\N	PRESENT	0
270949	263474	14133K	PARTICIPANT	\N	PRESENT	0
270950	263474	14119M	PARTICIPANT	\N	PRESENT	0
270951	263474	08061X	PARTICIPANT	\N	PRESENT	0
270952	263474	95063L	PARTICIPANT	\N	PRESENT	0
270953	263474	95037J	PARTICIPANT	\N	PRESENT	0
270954	263474	98029W	PARTICIPANT	\N	PRESENT	0
270955	263474	04034C	PARTICIPANT	\N	PRESENT	0
270956	263474	19507S	PARTICIPANT	\N	PRESENT	0
270957	263474	19467C	PARTICIPANT	\N	PRESENT	0
270958	263474	04045F	PARTICIPANT	\N	PRESENT	0
270959	263474	18083K	PARTICIPANT	\N	PRESENT	0
270960	263474	19415P	PARTICIPANT	\N	PRESENT	0
270961	263474	14033T	PARTICIPANT	\N	PRESENT	0
270873	270872	01028R	PARTICIPANT	\N	PRESENT	0
270913	263474	14275Y	PARTICIPANT	\N	PRESENT	0
270962	263474	19651A	PARTICIPANT	\N	PRESENT	0
270963	263474	14135M	PARTICIPANT	\N	PRESENT	0
270964	263474	19443T	PARTICIPANT	\N	PRESENT	0
270965	263474	14239U	PARTICIPANT	\N	PRESENT	0
270966	263474	11083R	PARTICIPANT	\N	PRESENT	0
270967	263474	19741B	PARTICIPANT	\N	PRESENT	0
270968	263474	19637C	PARTICIPANT	\N	PRESENT	0
270969	263474	14029X	PARTICIPANT	\N	PRESENT	0
270970	263474	19269X	PARTICIPANT	\N	PRESENT	0
270971	263474	19709B	PARTICIPANT	\N	PRESENT	0
270972	263474	19543W	PARTICIPANT	\N	PRESENT	0
270973	263474	19663E	PARTICIPANT	\N	PRESENT	0
270974	263474	19659J	PARTICIPANT	\N	PRESENT	0
270975	263474	04088S	PARTICIPANT	\N	PRESENT	0
270976	263474	08021P	PARTICIPANT	\N	PRESENT	0
270977	263474	14041T	PARTICIPANT	\N	PRESENT	0
270978	263474	19697Q	PARTICIPANT	\N	PRESENT	0
270979	263474	08018U	PARTICIPANT	\N	PRESENT	0
270981	263474	08073C	PARTICIPANT	\N	PRESENT	0
270982	263474	14039A	PARTICIPANT	\N	PRESENT	0
270983	263474	07029T	PARTICIPANT	\N	PRESENT	0
270984	263474	19657G	PARTICIPANT	\N	PRESENT	0
270985	263474	01060R	PARTICIPANT	\N	PRESENT	0
270986	263474	89017R	PARTICIPANT	\N	PRESENT	0
270987	263474	14355X	PARTICIPANT	\N	PRESENT	0
270988	270980	14147R	PARTICIPANT	\N	PRESENT	0
270989	263474	19745F	PARTICIPANT	\N	PRESENT	0
270990	263474	08062Y	PARTICIPANT	\N	PRESENT	0
270992	263474	19731Y	PARTICIPANT	\N	PRESENT	0
270993	263474	08015R	PARTICIPANT	\N	PRESENT	0
270994	263474	19705W	PARTICIPANT	\N	PRESENT	0
270995	263474	11012A	PARTICIPANT	\N	PRESENT	0
270996	263474	08031R	PARTICIPANT	\N	PRESENT	0
270997	270980	11065P	PARTICIPANT	\N	EXCUSE	0
270998	263474	88008L	PARTICIPANT	\N	PRESENT	0
270999	263474	19707Y	PARTICIPANT	\N	PRESENT	0
271000	263474	14034U	PARTICIPANT	\N	PRESENT	0
271001	263474	98050T	PARTICIPANT	\N	PRESENT	0
271002	263474	19733B	PARTICIPANT	\N	PRESENT	0
271003	263474	14059S	PARTICIPANT	\N	PRESENT	0
271004	270980	19651A	PARTICIPANT	\N	PRESENT	0
271005	263474	08049C	PARTICIPANT	\N	PRESENT	0
271006	263474	19563B	PARTICIPANT	\N	PRESENT	0
271007	263474	14329V	PARTICIPANT	\N	PRESENT	0
271008	263474	14213J	PARTICIPANT	\N	PRESENT	0
271009	263474	11065P	PARTICIPANT	\N	PRESENT	0
271010	263474	19729F	PARTICIPANT	\N	PRESENT	0
271011	263474	11099A	PARTICIPANT	\N	PRESENT	0
271012	263474	14241N	PARTICIPANT	\N	PRESENT	0
271013	270980	89017R	PARTICIPANT	\N	EXCUSE	0
271014	263474	19399H	PARTICIPANT	\N	PRESENT	0
271015	263474	19719D	PARTICIPANT	\N	PRESENT	0
271016	270980	19421M	PARTICIPANT	\N	EXCUSE	0
271017	263474	19693L	PARTICIPANT	\N	PRESENT	0
271018	263474	19585H	PARTICIPANT	\N	PRESENT	0
271019	263474	04071H	PARTICIPANT	\N	PRESENT	0
271020	263474	17589D	PARTICIPANT	\N	PRESENT	0
271021	263474	14357A	PARTICIPANT	\N	PRESENT	0
271022	263474	14251Q	PARTICIPANT	\N	PRESENT	0
271023	263474	19383Y	PARTICIPANT	\N	PRESENT	0
271024	270980	19737F	PARTICIPANT	\N	EXCUSE	0
271025	263474	19367Y	PARTICIPANT	\N	PRESENT	0
271026	270980	11066Q	PARTICIPANT	\N	EXCUSE	0
271027	263474	14093U	PARTICIPANT	\N	PRESENT	0
271028	263474	19545Y	PARTICIPANT	\N	PRESENT	0
271029	263474	19621T	PARTICIPANT	\N	PRESENT	0
271030	263474	04057K	PARTICIPANT	\N	PRESENT	0
241165	241164	08038Y	PARTICIPANT	\N	PRESENT	0
241166	241164	19637C	PARTICIPANT	\N	PRESENT	0
241167	241164	19689Q	PARTICIPANT	\N	PRESENT	0
241168	241164	19591F	PARTICIPANT	\N	PRESENT	0
241200	241164	19413M	PARTICIPANT	\N	PRESENT	0
245388	232876	19399H	PARTICIPANT	\N	EXCUSE	0
245512	232876	08012N	PARTICIPANT	\N	PRESENT	0
245513	232876	19349W	PARTICIPANT	\N	PRESENT	0
245514	232876	08069G	PARTICIPANT	\N	EXCUSE	0
245515	232876	04061F	PARTICIPANT	\N	EXCUSE	0
246112	246111	14103D	PARTICIPANT	\N	PRESENT	0
250372	240303	19533U	PARTICIPANT	\N	PRESENT	0
250373	240303	19711U	PARTICIPANT	\N	PRESENT	0
250374	240303	14081Q	PARTICIPANT	\N	PRESENT	0
250375	240303	04018C	PARTICIPANT	\N	PRESENT	0
250376	240303	19349W	PARTICIPANT	\N	PRESENT	0
250377	240303	14033T	PARTICIPANT	\N	PRESENT	0
250378	240303	08009T	PARTICIPANT	\N	PRESENT	0
250379	240303	18083K	PARTICIPANT	\N	PRESENT	0
250380	240303	14031R	PARTICIPANT	\N	PRESENT	0
250381	240303	08062Y	PARTICIPANT	\N	PRESENT	0
250382	240303	19701S	PARTICIPANT	\N	PRESENT	0
250383	240303	19347U	PARTICIPANT	\N	PRESENT	0
250384	240303	08055A	PARTICIPANT	\N	PRESENT	0
250385	240303	14107H	PARTICIPANT	\N	PRESENT	0
250386	240303	14197C	PARTICIPANT	\N	PRESENT	0
250387	240303	19671E	PARTICIPANT	\N	PRESENT	0
250388	240303	19657G	PARTICIPANT	\N	PRESENT	0
250389	240303	19415P	PARTICIPANT	\N	PRESENT	0
250390	240303	14157T	PARTICIPANT	\N	PRESENT	0
250391	240303	08028W	PARTICIPANT	\N	PRESENT	0
250392	240303	14053L	PARTICIPANT	\N	PRESENT	0
250393	240303	19621T	PARTICIPANT	\N	PRESENT	0
250394	240303	19731Y	PARTICIPANT	\N	PRESENT	0
250395	240303	08024S	PARTICIPANT	\N	PRESENT	0
250396	240303	14051J	PARTICIPANT	\N	PRESENT	0
250397	240303	19525U	PARTICIPANT	\N	PRESENT	0
250398	240303	19333N	PARTICIPANT	\N	PRESENT	0
250399	240303	19531S	PARTICIPANT	\N	PRESENT	0
250400	240303	14097Y	PARTICIPANT	\N	PRESENT	0
250401	240303	14241N	PARTICIPANT	\N	PRESENT	0
250402	240303	19719D	PARTICIPANT	\N	PRESENT	0
250403	240303	19629C	PARTICIPANT	\N	PRESENT	0
250404	240303	19549D	PARTICIPANT	\N	PRESENT	0
250405	240303	19387D	PARTICIPANT	\N	PRESENT	0
250406	240303	19551W	PARTICIPANT	\N	PRESENT	0
250407	240303	12016W	PARTICIPANT	\N	PRESENT	0
250408	240303	19725B	PARTICIPANT	\N	PRESENT	0
250409	240303	14219Q	PARTICIPANT	\N	PRESENT	0
250410	240303	19479G	PARTICIPANT	\N	PRESENT	0
250411	240303	19713W	PARTICIPANT	\N	PRESENT	0
250412	240303	02002K	PARTICIPANT	\N	PRESENT	0
250369	240303	11072N	PARTICIPANT	\N	PRESENT	0
250371	240303	19733B	PARTICIPANT	\N	PRESENT	0
250413	240303	19747H	PARTICIPANT	\N	PRESENT	0
250414	240303	19581D	PARTICIPANT	\N	PRESENT	0
250415	240303	04033B	PARTICIPANT	\N	PRESENT	0
250416	240303	95030B	PARTICIPANT	\N	PRESENT	0
250417	240303	19575F	PARTICIPANT	\N	PRESENT	0
250418	240303	14147R	PARTICIPANT	\N	PRESENT	0
250419	240303	14265W	PARTICIPANT	\N	PRESENT	0
250420	240303	11103C	PARTICIPANT	\N	PRESENT	0
250421	240303	19489J	PARTICIPANT	\N	PRESENT	0
250422	240303	19447X	PARTICIPANT	\N	PRESENT	0
250423	240303	19443T	PARTICIPANT	\N	PRESENT	0
250424	240303	14038Y	PARTICIPANT	\N	PRESENT	0
250425	240303	19467C	PARTICIPANT	\N	PRESENT	0
250426	240303	01058X	PARTICIPANT	\N	PRESENT	0
250427	240303	01025N	PARTICIPANT	\N	PRESENT	0
250428	240303	19515S	PARTICIPANT	\N	PRESENT	0
250429	240303	19441R	PARTICIPANT	\N	PRESENT	0
250430	240303	11064N	PARTICIPANT	\N	PRESENT	0
250431	240303	14121F	PARTICIPANT	\N	PRESENT	0
250432	240303	19637C	PARTICIPANT	\N	PRESENT	0
250433	240303	11065P	PARTICIPANT	\N	PRESENT	0
250434	240303	19739H	PARTICIPANT	\N	PRESENT	0
250435	240303	14063N	PARTICIPANT	\N	PRESENT	0
250436	240303	04088S	PARTICIPANT	\N	PRESENT	0
250437	240303	19507S	PARTICIPANT	\N	PRESENT	0
250438	240303	14169X	PARTICIPANT	\N	PRESENT	0
250439	240303	19695N	PARTICIPANT	\N	PRESENT	0
250440	240303	19565D	PARTICIPANT	\N	PRESENT	0
250441	240303	08060W	PARTICIPANT	\N	PRESENT	0
250442	240303	14103D	PARTICIPANT	\N	PRESENT	0
250443	240303	97011G	PARTICIPANT	\N	PRESENT	0
250444	240303	14105F	PARTICIPANT	\N	PRESENT	0
250445	240303	04049K	PARTICIPANT	\N	PRESENT	0
250446	240303	14087W	PARTICIPANT	\N	PRESENT	0
250447	240303	14179A	PARTICIPANT	\N	PRESENT	0
250448	240303	11054L	PARTICIPANT	\N	PRESENT	0
250449	240303	08052W	PARTICIPANT	\N	PRESENT	0
250450	240303	19723Y	PARTICIPANT	\N	PRESENT	0
250451	240303	16685X	PARTICIPANT	\N	PRESENT	0
250452	240303	11097X	PARTICIPANT	\N	PRESENT	0
250466	240303	19383Y	PARTICIPANT	\N	PRESENT	0
250467	250308	19333N	PARTICIPANT	\N	PRESENT	0
250468	250308	19383Y	PARTICIPANT	\N	PRESENT	0
250469	250308	17583W	PARTICIPANT	\N	EXCUSE	0
250470	250308	19701S	PARTICIPANT	\N	PRESENT	0
250471	250308	14219Q	PARTICIPANT	\N	PRESENT	0
250472	250308	14221J	PARTICIPANT	\N	PRESENT	0
250473	250308	19637C	PARTICIPANT	\N	EXCUSE	0
250474	250308	02002K	PARTICIPANT	\N	PRESENT	0
250475	250308	19551W	PARTICIPANT	\N	PRESENT	0
250476	250308	14237S	PARTICIPANT	\N	EXCUSE	0
250477	250308	14051J	PARTICIPANT	\N	PRESENT	0
250478	250308	08060W	PARTICIPANT	\N	PRESENT	0
250479	250308	19347U	PARTICIPANT	\N	PRESENT	0
250480	250308	19503N	PARTICIPANT	\N	PRESENT	0
250481	250308	14157T	PARTICIPANT	\N	PRESENT	0
250482	250308	08024S	PARTICIPANT	\N	PRESENT	0
250483	250308	98023Q	PARTICIPANT	\N	PRESENT	0
250484	250308	11065P	PARTICIPANT	\N	PRESENT	0
250485	250308	19525U	PARTICIPANT	\N	PRESENT	0
250486	250308	14038Y	PRESIDENT	0	PRESENT	0
250487	250308	14103D	PARTICIPANT	\N	PRESENT	0
250488	250308	14031R	PARTICIPANT	\N	PRESENT	0
250489	250308	08055A	PARTICIPANT	\N	PRESENT	0
250490	250308	14169X	PARTICIPANT	\N	PRESENT	0
250491	250308	19733B	PARTICIPANT	\N	PRESENT	0
250492	250308	19745F	PARTICIPANT	\N	PRESENT	0
250493	250308	19599P	PARTICIPANT	\N	EXCUSE	0
250494	240303	14205J	PARTICIPANT	\N	PRESENT	0
250495	240303	19745F	PARTICIPANT	\N	PRESENT	0
250496	240303	19749K	PARTICIPANT	\N	PRESENT	0
250501	240303	14111D	PARTICIPANT	\N	PRESENT	0
250502	240303	08044W	PARTICIPANT	\N	PRESENT	0
250503	240303	14281W	PARTICIPANT	\N	PRESENT	0
250504	240303	17589D	PARTICIPANT	\N	PRESENT	0
250505	240303	80013X	PARTICIPANT	\N	PRESENT	0
250506	240303	10006L	PARTICIPANT	\N	PRESENT	0
250508	240303	14026U	PARTICIPANT	\N	PRESENT	0
250509	240303	14069U	PARTICIPANT	\N	PRESENT	0
250514	240303	14119M	PARTICIPANT	\N	PRESENT	0
250515	240303	19611R	PARTICIPANT	\N	PRESENT	0
250516	240303	11056N	PARTICIPANT	\N	PRESENT	0
250517	240303	08038Y	PARTICIPANT	\N	PRESENT	0
250519	240303	08020N	PARTICIPANT	\N	PRESENT	0
250520	240303	11066Q	PARTICIPANT	\N	PRESENT	0
250521	240303	14207L	PARTICIPANT	\N	PRESENT	0
250522	240303	19503N	PARTICIPANT	\N	PRESENT	0
250523	240303	14001X	PARTICIPANT	\N	PRESENT	0
250524	240303	19253P	PARTICIPANT	\N	PRESENT	0
250525	240303	19553Y	PARTICIPANT	\N	PRESENT	0
250526	240303	19521Q	PARTICIPANT	\N	PRESENT	0
250527	240303	11048N	PARTICIPANT	\N	PRESENT	0
250528	240303	14159V	PARTICIPANT	\N	PRESENT	0
250530	240303	08015R	PARTICIPANT	\N	PRESENT	0
250531	240303	19729F	PARTICIPANT	\N	PRESENT	0
250532	240303	14267Y	PARTICIPANT	\N	PRESENT	0
250534	240303	88008L	PARTICIPANT	\N	PRESENT	0
250535	240303	19413M	PARTICIPANT	\N	PRESENT	0
250536	240303	14355X	PARTICIPANT	\N	PRESENT	0
250537	240303	14123H	PARTICIPANT	\N	PRESENT	0
250538	240303	19741B	PARTICIPANT	\N	PRESENT	0
250539	240303	87003B	PARTICIPANT	\N	PRESENT	0
250540	240303	08049C	PARTICIPANT	\N	PRESENT	0
250541	240303	14211G	PARTICIPANT	\N	PRESENT	0
250563	250553	19543W	PARTICIPANT	\N	PRESENT	0
250564	250553	19581D	PARTICIPANT	\N	PRESENT	0
250565	250553	04044E	PARTICIPANT	\N	PRESENT	0
250566	250553	04047H	PARTICIPANT	\N	PRESENT	0
250567	250553	19673G	PARTICIPANT	\N	PRESENT	0
250568	250553	01028R	PARTICIPANT	\N	PRESENT	0
250569	250553	19447X	PARTICIPANT	\N	PRESENT	0
250570	250553	05008E	PRESIDENT	0	PRESENT	0
250571	250553	14147R	PARTICIPANT	\N	PRESENT	0
250572	250553	14179A	PARTICIPANT	\N	PRESENT	0
250573	250553	08018U	PARTICIPANT	\N	PRESENT	0
264331	263035	19631V	PARTICIPANT	\N	PRESENT	0
264332	263035	11110B	PARTICIPANT	\N	PRESENT	0
264333	263035	19747H	PARTICIPANT	\N	PRESENT	0
264334	263035	19577H	PARTICIPANT	\N	PRESENT	0
264335	263035	14195A	PARTICIPANT	\N	PRESENT	0
264336	263035	19701S	PARTICIPANT	\N	PRESENT	0
264337	263035	04018C	PARTICIPANT	\N	PRESENT	0
264338	263035	08019V	PARTICIPANT	\N	PRESENT	0
264339	263035	14157T	PARTICIPANT	\N	PRESENT	0
264340	263035	14191V	PARTICIPANT	\N	PRESENT	0
264341	263035	19711U	PARTICIPANT	\N	PRESENT	0
264342	263035	08020N	PARTICIPANT	\N	PRESENT	0
264343	263035	19447X	PARTICIPANT	\N	PRESENT	0
264344	263035	14029X	PARTICIPANT	\N	PRESENT	0
264345	263035	14105F	PARTICIPANT	\N	PRESENT	0
264346	263035	08047A	PARTICIPANT	\N	PRESENT	0
264347	263035	11103C	PARTICIPANT	\N	PRESENT	0
264348	263035	14053L	PARTICIPANT	\N	PRESENT	0
264349	263035	19667J	PARTICIPANT	\N	PRESENT	0
264350	263035	14261S	PARTICIPANT	\N	PRESENT	0
264351	263035	08043V	PARTICIPANT	\N	PRESENT	0
264352	263035	19599P	PARTICIPANT	\N	PRESENT	0
264353	263035	04035D	PARTICIPANT	\N	PRESENT	0
264354	263035	14063N	PARTICIPANT	\N	PRESENT	0
264355	263035	19415P	PARTICIPANT	\N	PRESENT	0
264356	263035	19301E	PARTICIPANT	\N	PRESENT	0
264357	263035	11056N	PARTICIPANT	\N	PRESENT	0
264358	263035	11054L	PARTICIPANT	\N	PRESENT	0
264359	263035	19679N	PARTICIPANT	\N	PRESENT	0
264360	263035	04088S	PARTICIPANT	\N	PRESENT	0
264361	263035	19521Q	PARTICIPANT	\N	PRESENT	0
264362	263035	14069U	PARTICIPANT	\N	PRESENT	0
264363	263035	14121F	PARTICIPANT	\N	PRESENT	0
264364	263035	14107H	PARTICIPANT	\N	PRESENT	0
264365	263035	14111D	PARTICIPANT	\N	PRESENT	0
264366	263035	14197C	PARTICIPANT	\N	PRESENT	0
264367	263035	12016W	PARTICIPANT	\N	PRESENT	0
264368	263035	16685X	PARTICIPANT	\N	PRESENT	0
264369	263035	17637T	PARTICIPANT	\N	PRESENT	0
264370	263035	14034U	PARTICIPANT	\N	PRESENT	0
264371	263035	14021P	PARTICIPANT	\N	PRESENT	0
264372	263035	19563B	PARTICIPANT	\N	PRESENT	0
264373	263035	19533U	PARTICIPANT	\N	PRESENT	0
264379	263035	19713W	PARTICIPANT	\N	PRESENT	0
264380	263035	11080N	PARTICIPANT	\N	PRESENT	0
264381	263035	99004R	PARTICIPANT	\N	PRESENT	0
264382	263035	14331P	PARTICIPANT	\N	PRESENT	0
264383	263035	95062K	PARTICIPANT	\N	PRESENT	0
264384	263035	98018T	PARTICIPANT	\N	PRESENT	0
264385	263035	19503N	PARTICIPANT	\N	PRESENT	0
264386	263035	11026G	PARTICIPANT	\N	PRESENT	0
264387	263035	19253P	PARTICIPANT	\N	PRESENT	0
264388	263035	18083K	PARTICIPANT	\N	PRESENT	0
264389	263035	97011G	PARTICIPANT	\N	PRESENT	0
264390	263035	19717B	PARTICIPANT	\N	PRESENT	0
264391	263035	19733B	PARTICIPANT	\N	PRESENT	0
264392	263035	11040E	PARTICIPANT	\N	PRESENT	0
264393	263035	19699S	PARTICIPANT	\N	PRESENT	0
264394	263035	19335Q	PARTICIPANT	\N	PRESENT	0
264395	263035	95030B	PARTICIPANT	\N	PRESENT	0
264396	263035	19573D	PARTICIPANT	\N	PRESENT	0
264399	263035	19681G	PARTICIPANT	\N	PRESENT	0
264404	263035	14031R	PARTICIPANT	\N	PRESENT	0
264405	263035	11048N	PARTICIPANT	\N	PRESENT	0
264406	263035	14179A	PARTICIPANT	\N	PRESENT	0
264407	263035	14257W	PARTICIPANT	\N	PRESENT	0
264503	263038	95062K	PARTICIPANT	\N	PRESENT	0
264504	263038	19679N	PARTICIPANT	\N	PRESENT	0
264505	263038	08020N	PARTICIPANT	\N	PRESENT	0
264506	263038	11080N	PARTICIPANT	\N	PRESENT	0
264507	263038	14031R	PARTICIPANT	\N	PRESENT	0
264508	263038	19573D	PARTICIPANT	\N	PRESENT	0
264509	263038	18083K	PARTICIPANT	\N	PRESENT	0
264510	263038	04088S	PARTICIPANT	\N	PRESENT	0
264511	263038	14029X	PARTICIPANT	\N	PRESENT	0
264512	263038	19447X	PARTICIPANT	\N	PRESENT	0
264513	263038	08019V	PARTICIPANT	\N	PRESENT	0
264514	263038	14157T	PARTICIPANT	\N	PRESENT	0
264515	263038	08047A	PARTICIPANT	\N	PRESENT	0
264516	263038	14147R	PARTICIPANT	\N	PRESENT	0
264517	263038	14026U	PARTICIPANT	\N	PRESENT	0
264518	263038	11048N	PARTICIPANT	\N	PRESENT	0
264519	263038	14223L	PARTICIPANT	\N	PRESENT	0
264520	263038	19711U	PARTICIPANT	\N	PRESENT	0
264521	263038	19733B	PARTICIPANT	\N	PRESENT	0
264522	263038	14059S	PARTICIPANT	\N	PRESENT	0
264523	263038	14191V	PARTICIPANT	\N	PRESENT	0
264524	263038	97011G	PARTICIPANT	\N	PRESENT	0
264525	263038	11103C	PARTICIPANT	\N	PRESENT	0
264526	263038	95030B	PARTICIPANT	\N	PRESENT	0
264527	263038	14331P	PARTICIPANT	\N	PRESENT	0
264528	263038	04018C	PARTICIPANT	\N	PRESENT	0
264529	263038	19335Q	PARTICIPANT	\N	PRESENT	0
264530	263038	19747H	PARTICIPANT	\N	PRESENT	0
264531	263038	19577H	PARTICIPANT	\N	PRESENT	0
264532	263038	14231L	PARTICIPANT	\N	PRESENT	0
264533	263038	14215L	PARTICIPANT	\N	PRESENT	0
264534	263038	01024M	PARTICIPANT	\N	PRESENT	0
264535	263038	19713W	PARTICIPANT	\N	PRESENT	0
264536	263038	19521Q	PARTICIPANT	\N	PRESENT	0
264537	263038	19583F	PARTICIPANT	\N	PRESENT	0
264538	263038	16685X	PARTICIPANT	\N	PRESENT	0
264539	263038	19253P	PARTICIPANT	\N	PRESENT	0
264329	263035	05008E	PARTICIPANT	\N	PRESENT	0
264330	263035	19543W	PARTICIPANT	\N	PRESENT	0
264540	263038	14261S	PARTICIPANT	\N	PRESENT	0
264541	263038	19563B	PARTICIPANT	\N	PRESENT	0
264542	263038	19387D	PARTICIPANT	\N	PRESENT	0
264543	263038	19629C	PARTICIPANT	\N	PRESENT	0
264544	263038	19681G	PARTICIPANT	\N	PRESENT	0
264545	263038	19717B	PARTICIPANT	\N	PRESENT	0
264546	263038	14034U	PARTICIPANT	\N	PRESENT	0
264547	263038	19543W	PARTICIPANT	\N	PRESENT	0
264548	263038	14179A	PARTICIPANT	\N	PRESENT	0
264549	263038	19301E	PARTICIPANT	\N	PRESENT	0
264550	263038	14257W	PARTICIPANT	\N	PRESENT	0
264551	263038	14207L	PARTICIPANT	\N	PRESENT	0
264552	263038	19631V	PARTICIPANT	\N	PRESENT	0
264553	263038	14063N	PARTICIPANT	\N	PRESENT	0
264554	263038	19599P	PARTICIPANT	\N	PRESENT	0
264555	263038	14107H	PARTICIPANT	\N	PRESENT	0
264556	263038	11066Q	PARTICIPANT	\N	PRESENT	0
264557	263038	11026G	PARTICIPANT	\N	PRESENT	0
264558	263038	04059M	PARTICIPANT	\N	PRESENT	0
264559	263038	01028R	PARTICIPANT	\N	PRESENT	0
264560	263038	80013X	PARTICIPANT	\N	PRESENT	0
264561	263038	14121F	PARTICIPANT	\N	PRESENT	0
264562	263038	14197C	PARTICIPANT	\N	PRESENT	0
264563	263038	12016W	PARTICIPANT	\N	PRESENT	0
264564	263038	19715Y	PARTICIPANT	\N	PRESENT	0
264565	263038	19503N	PARTICIPANT	\N	PRESENT	0
264566	263038	04085P	PARTICIPANT	\N	PRESENT	0
264567	263038	11040E	PARTICIPANT	\N	PRESENT	0
264568	263038	19745F	PARTICIPANT	\N	PRESENT	0
264569	263038	19441R	PARTICIPANT	\N	PRESENT	0
264570	263038	11067R	PARTICIPANT	\N	PRESENT	0
264571	263038	19533U	PARTICIPANT	\N	PRESENT	0
264572	263038	19467C	PARTICIPANT	\N	PRESENT	0
264573	263038	14105F	PARTICIPANT	\N	PRESENT	0
264574	263038	98018T	PARTICIPANT	\N	PRESENT	0
264575	263038	95063L	PARTICIPANT	\N	PRESENT	0
264576	263038	01060R	PARTICIPANT	\N	PRESENT	0
264577	263038	19621T	PARTICIPANT	\N	PRESENT	0
264578	263038	19329S	PARTICIPANT	\N	PRESENT	0
264579	263038	04035D	PARTICIPANT	\N	PRESENT	0
264580	263038	10006L	PARTICIPANT	\N	PRESENT	0
264581	263038	11110B	PARTICIPANT	\N	PRESENT	0
264582	263038	14251Q	PARTICIPANT	\N	PRESENT	0
264583	263038	19651A	PARTICIPANT	\N	PRESENT	0
264584	263038	11043H	PARTICIPANT	\N	PRESENT	0
264585	263038	08062Y	PARTICIPANT	\N	PRESENT	0
264586	263038	01057W	PARTICIPANT	\N	PRESENT	0
264587	263038	11056N	PARTICIPANT	\N	PRESENT	0
264588	263038	14115H	PARTICIPANT	\N	PRESENT	0
264589	263038	04044E	PARTICIPANT	\N	PRESENT	0
264590	263038	14069U	PARTICIPANT	\N	PRESENT	0
264591	263038	19695N	PARTICIPANT	\N	PRESENT	0
264592	263038	14038Y	PARTICIPANT	\N	PRESENT	0
264603	263038	14241N	PARTICIPANT	\N	PRESENT	0
264612	263038	14225N	PARTICIPANT	\N	PRESENT	0
264614	263038	14053L	PARTICIPANT	\N	PRESENT	0
264501	263038	04086Q	PARTICIPANT	\N	PRESENT	0
264502	263038	05008E	PARTICIPANT	\N	PRESENT	0
264621	263038	11083R	PARTICIPANT	\N	PRESENT	0
264622	263038	14201E	PARTICIPANT	\N	PRESENT	0
264623	263038	14187A	PARTICIPANT	\N	PRESENT	0
264624	263038	04038G	PARTICIPANT	\N	PRESENT	0
264625	263038	14357A	PARTICIPANT	\N	PRESENT	0
241471	239694	95030B	PARTICIPANT	\N	PRESENT	0
241472	239694	19525U	PARTICIPANT	\N	PRESENT	0
241473	239694	11045K	PARTICIPANT	\N	PRESENT	0
241518	239694	19713W	PARTICIPANT	\N	PRESENT	0
241482	239694	19415P	PARTICIPANT	\N	PRESENT	0
241485	239694	08039A	PARTICIPANT	\N	PRESENT	0
241487	239694	04097T	PARTICIPANT	\N	PRESENT	0
241488	239694	97011G	PARTICIPANT	\N	PRESENT	0
241489	239694	14331P	PARTICIPANT	\N	PRESENT	0
241491	239694	19511N	PARTICIPANT	\N	PRESENT	0
241492	239694	19531S	PARTICIPANT	\N	PRESENT	0
241493	239694	14235Q	PARTICIPANT	\N	PRESENT	0
241496	239694	08044W	PARTICIPANT	\N	PRESENT	0
241497	239694	14105F	PARTICIPANT	\N	PRESENT	0
241498	239694	14267Y	PARTICIPANT	\N	PRESENT	0
241499	239694	08015R	PARTICIPANT	\N	PRESENT	0
241500	239694	19675J	PARTICIPANT	\N	PRESENT	0
241501	239694	05008E	PARTICIPANT	\N	PRESENT	0
241502	239694	11040E	PARTICIPANT	\N	PRESENT	0
241504	239694	19749K	PARTICIPANT	\N	PRESENT	0
241516	239694	14231L	PARTICIPANT	\N	PRESENT	0
241517	239694	14207L	PARTICIPANT	\N	PRESENT	0
241519	239694	08038Y	PARTICIPANT	\N	PRESENT	0
241520	239694	08053X	PARTICIPANT	\N	PRESENT	0
241521	239694	19643A	PARTICIPANT	\N	PRESENT	0
241522	239694	11054L	PARTICIPANT	\N	PRESENT	0
241523	239694	01028R	PARTICIPANT	\N	PRESENT	0
241524	239694	04034C	PARTICIPANT	\N	PRESENT	0
241525	239694	80013X	PARTICIPANT	\N	PRESENT	0
241526	239694	14151M	PARTICIPANT	\N	PRESENT	0
241527	239694	14103D	PARTICIPANT	\N	PRESENT	0
241528	239694	19691J	PARTICIPANT	\N	PRESENT	0
241529	239694	19413M	PARTICIPANT	\N	PRESENT	0
241530	239694	80027E	PARTICIPANT	\N	PRESENT	0
241531	239694	19383Y	PARTICIPANT	\N	PRESENT	0
241532	239694	14329V	PARTICIPANT	\N	PRESENT	0
241533	239694	98050T	PARTICIPANT	\N	PRESENT	0
241534	239694	14051J	PARTICIPANT	\N	PRESENT	0
241535	239694	08041T	PARTICIPANT	\N	PRESENT	0
241536	239694	95063L	PARTICIPANT	\N	PRESENT	0
241537	239694	04088S	PARTICIPANT	\N	PRESENT	0
241538	239694	08062Y	PARTICIPANT	\N	PRESENT	0
241539	239694	19747H	PARTICIPANT	\N	PRESENT	0
241540	239694	19421M	PARTICIPANT	\N	PRESENT	0
241541	239694	88008L	PARTICIPANT	\N	PRESENT	0
241542	239694	89017R	PARTICIPANT	\N	PRESENT	0
241547	239694	11070L	PARTICIPANT	\N	PRESENT	0
241544	239694	11103C	PARTICIPANT	\N	PRESENT	0
241545	239694	14173T	PARTICIPANT	\N	PRESENT	0
241546	239694	14211G	PARTICIPANT	\N	PRESENT	0
241548	239694	19741B	PARTICIPANT	\N	PRESENT	0
241690	239695	14031R	PARTICIPANT	\N	PRESENT	0
241691	239695	14041T	PARTICIPANT	\N	PRESENT	0
241692	239695	86034E	PARTICIPANT	\N	PRESENT	0
241693	239695	14173T	PARTICIPANT	\N	PRESENT	0
241694	239695	08010L	PARTICIPANT	\N	PRESENT	0
241695	239695	08041T	PARTICIPANT	\N	PRESENT	0
241696	239695	04088S	PARTICIPANT	\N	PRESENT	0
241697	239695	14033T	PARTICIPANT	\N	PRESENT	0
241698	239695	08062Y	PARTICIPANT	\N	PRESENT	0
241699	239695	98050T	PARTICIPANT	\N	PRESENT	0
241700	239695	19383Y	PARTICIPANT	\N	PRESENT	0
241701	239695	14061L	PARTICIPANT	\N	PRESENT	0
241702	239695	19741B	PARTICIPANT	\N	PRESENT	0
241703	239695	14069U	PARTICIPANT	\N	PRESENT	0
241704	239695	01024M	PARTICIPANT	\N	PRESENT	0
241705	239695	19711U	PARTICIPANT	\N	PRESENT	0
241706	239695	17637T	PARTICIPANT	\N	PRESENT	0
241707	239695	95062K	PARTICIPANT	\N	PRESENT	0
241708	239695	19643A	PARTICIPANT	\N	PRESENT	0
241709	239695	14073Q	PARTICIPANT	\N	PRESENT	0
241710	239695	14331P	PARTICIPANT	\N	PRESENT	0
241711	239695	19703U	PARTICIPANT	\N	PRESENT	0
241712	239695	19447X	PARTICIPANT	\N	PRESENT	0
241713	239695	14215L	PARTICIPANT	\N	PRESENT	0
241714	239695	87003B	PARTICIPANT	\N	PRESENT	0
241715	239695	14265W	PARTICIPANT	\N	PRESENT	0
241716	239695	97011G	PARTICIPANT	\N	PRESENT	0
241717	239695	95041E	PARTICIPANT	\N	PRESENT	0
241718	239695	14030Q	PARTICIPANT	\N	PRESENT	0
241719	239695	04049K	PARTICIPANT	\N	PRESENT	0
241720	239695	98018T	PARTICIPANT	\N	PRESENT	0
241721	239695	11080N	PARTICIPANT	\N	PRESENT	0
241722	239695	08020N	PARTICIPANT	\N	PRESENT	0
241723	239695	01048V	PARTICIPANT	\N	PRESENT	0
241724	239695	11048N	PARTICIPANT	\N	PRESENT	0
241725	239695	98023Q	PARTICIPANT	\N	PRESENT	0
241726	239695	14259Y	PARTICIPANT	\N	PRESENT	0
241727	239695	04086Q	PARTICIPANT	\N	PRESENT	0
241728	239695	14053L	PARTICIPANT	\N	PRESENT	0
241729	239695	19747H	PARTICIPANT	\N	PRESENT	0
241730	239695	11097X	PARTICIPANT	\N	PRESENT	0
241731	239695	92040Q	PARTICIPANT	\N	PRESENT	0
241732	239695	19673G	PARTICIPANT	\N	PRESENT	0
241733	239695	98005N	PARTICIPANT	\N	PRESENT	0
241734	239695	11031D	PARTICIPANT	\N	PRESENT	0
241735	239695	19467C	PARTICIPANT	\N	PRESENT	0
241736	239695	12041X	PARTICIPANT	\N	PRESENT	0
241737	239695	19565D	PARTICIPANT	\N	PRESENT	0
241738	239695	14235Q	PARTICIPANT	\N	PRESENT	0
241739	239695	19443T	PARTICIPANT	\N	PRESENT	0
241740	239695	14029X	PARTICIPANT	\N	PRESENT	0
241741	239695	19709B	PARTICIPANT	\N	PRESENT	0
241742	239695	11063M	PARTICIPANT	\N	PRESENT	0
241743	239695	19593H	PARTICIPANT	\N	PRESENT	0
241744	239695	19507S	PARTICIPANT	\N	PRESENT	0
241745	239695	19695N	PARTICIPANT	\N	PRESENT	0
241746	239695	18083K	PARTICIPANT	\N	PRESENT	0
241747	239695	14038Y	PARTICIPANT	\N	PRESENT	0
241748	239695	07029T	PARTICIPANT	\N	PRESENT	0
241749	239695	15447F	PARTICIPANT	\N	PRESENT	0
241750	239695	19515S	PARTICIPANT	\N	PRESENT	0
241751	239695	01057W	PARTICIPANT	\N	PRESENT	0
241752	239695	11043H	PARTICIPANT	\N	PRESENT	0
241753	239695	08039A	PARTICIPANT	\N	PRESENT	0
241754	239695	04097T	PARTICIPANT	\N	PRESENT	0
241755	239695	19679N	PARTICIPANT	\N	PRESENT	0
241756	239695	08034U	PARTICIPANT	\N	PRESENT	0
241757	239695	95015C	PARTICIPANT	\N	PRESENT	0
241758	239695	04042C	PARTICIPANT	\N	PRESENT	0
241759	239695	12016W	PARTICIPANT	\N	PRESENT	0
241760	239695	19715Y	PARTICIPANT	\N	PRESENT	0
241761	239695	14199E	PARTICIPANT	\N	PRESENT	0
241762	239695	04038G	PARTICIPANT	\N	PRESENT	0
241763	239695	04085P	PARTICIPANT	\N	PRESENT	0
241764	239695	11040E	PARTICIPANT	\N	PRESENT	0
241765	239695	08018U	PARTICIPANT	\N	PRESENT	0
241766	239695	11056N	PARTICIPANT	\N	PRESENT	0
241767	239695	19667J	PARTICIPANT	\N	PRESENT	0
241768	239695	19687N	PARTICIPANT	\N	PRESENT	0
241769	239695	08061X	PARTICIPANT	\N	PRESENT	0
241770	239695	11090Q	PARTICIPANT	\N	PRESENT	0
241771	239695	95063L	PARTICIPANT	\N	PRESENT	0
241772	239695	95037J	PARTICIPANT	\N	PRESENT	0
241773	239695	95067Q	PARTICIPANT	\N	PRESENT	0
241774	239695	04034C	PARTICIPANT	\N	PRESENT	0
241775	239695	04045F	PARTICIPANT	\N	PRESENT	0
241776	239695	05012A	PARTICIPANT	\N	PRESENT	0
241777	239695	98029W	PARTICIPANT	\N	PRESENT	0
241778	239695	19533U	PARTICIPANT	\N	PRESENT	0
241779	239695	19651A	PARTICIPANT	\N	PRESENT	0
242400	241240	15447F	PARTICIPANT	\N	PRESENT	0
242401	241240	19703U	PARTICIPANT	\N	PRESENT	0
242402	241240	19729F	PARTICIPANT	\N	PRESENT	0
242403	241240	19443T	PARTICIPANT	\N	PRESENT	0
242404	241240	08035V	PARTICIPANT	\N	PRESENT	0
242405	241240	08058D	PRESIDENT	0	PRESENT	0
242406	241240	19251M	PARTICIPANT	\N	PRESENT	0
242407	241240	19581D	PARTICIPANT	\N	PRESENT	0
242408	241240	11049P	PARTICIPANT	\N	PRESENT	0
242409	241240	19719D	PARTICIPANT	\N	PRESENT	0
242410	241240	19721W	PARTICIPANT	\N	PRESENT	0
242411	241240	04085P	PARTICIPANT	\N	PRESENT	0
242412	241240	04086Q	PARTICIPANT	\N	EXCUSE	0
242414	239697	19681G	PARTICIPANT	\N	PRESENT	0
242415	239697	19629C	PARTICIPANT	\N	PRESENT	0
242416	239697	14329V	PARTICIPANT	\N	PRESENT	0
242417	239697	14109K	PARTICIPANT	\N	PRESENT	0
242418	239697	14111D	PARTICIPANT	\N	PRESENT	0
242419	239697	14205J	PARTICIPANT	\N	PRESENT	0
242420	239697	19713W	PARTICIPANT	\N	PRESENT	0
242421	239697	14219Q	PARTICIPANT	\N	PRESENT	0
242422	239697	08038Y	PARTICIPANT	\N	PRESENT	0
242423	239697	19737F	PARTICIPANT	\N	PRESENT	0
242424	239697	11048N	PARTICIPANT	\N	PRESENT	0
242425	239697	95030B	PARTICIPANT	\N	PRESENT	0
242426	239697	98018T	PARTICIPANT	\N	PRESENT	0
242427	239697	14123H	PARTICIPANT	\N	PRESENT	0
242428	239697	11067R	PARTICIPANT	\N	PRESENT	0
268349	268348	04043D	PARTICIPANT	\N	PRESENT	0
268503	268502	19507S	PARTICIPANT	\N	PRESENT	0
269132	269043	18083K	PARTICIPANT	\N	PRESENT	0
269133	269043	14061L	PARTICIPANT	\N	EXCUSE	0
269134	269043	95015C	PARTICIPANT	\N	EXCUSE	0
269135	269043	14039A	PARTICIPANT	\N	EXCUSE	0
269136	269043	19611R	PARTICIPANT	\N	EXCUSE	0
269137	269043	87003B	PARTICIPANT	\N	EXCUSE	0
269138	263464	18083K	PARTICIPANT	\N	PRESENT	0
269139	263464	98050T	PARTICIPANT	\N	PRESENT	0
269140	263464	08056B	PARTICIPANT	\N	PRESENT	0
269141	263464	14191V	PARTICIPANT	\N	PRESENT	0
269142	263464	19731Y	PARTICIPANT	\N	PRESENT	0
269143	263464	04018C	PARTICIPANT	\N	PRESENT	0
269144	263464	14225N	PARTICIPANT	\N	PRESENT	0
269145	263464	80013X	PARTICIPANT	\N	PRESENT	0
269146	263464	11104D	PARTICIPANT	\N	PRESENT	0
269147	263464	11067R	PARTICIPANT	\N	PRESENT	0
269148	263464	14030Q	PARTICIPANT	\N	PRESENT	0
269149	263464	19735D	PARTICIPANT	\N	PRESENT	0
269150	263464	14257W	PARTICIPANT	\N	PRESENT	0
269151	263464	19667J	PARTICIPANT	\N	PRESENT	0
269153	263464	19695N	PARTICIPANT	\N	PRESENT	0
269154	263464	95062K	PARTICIPANT	\N	PRESENT	0
269156	263464	14251Q	PARTICIPANT	\N	PRESENT	0
269157	263464	19699S	PARTICIPANT	\N	PRESENT	0
269158	263464	19673G	PARTICIPANT	\N	PRESENT	0
269159	263464	19663E	PARTICIPANT	\N	PRESENT	0
269160	263464	19741B	PARTICIPANT	\N	PRESENT	0
269161	263464	11070L	PARTICIPANT	\N	PRESENT	0
269162	263464	19447X	PARTICIPANT	\N	PRESENT	0
269163	263464	14031R	PARTICIPANT	\N	PRESENT	0
269164	263464	19479G	PARTICIPANT	\N	PRESENT	0
269165	263464	19335Q	PARTICIPANT	\N	PRESENT	0
269166	263464	19503N	PARTICIPANT	\N	PRESENT	0
269167	263464	14215L	PARTICIPANT	\N	PRESENT	0
269168	263464	08044W	PARTICIPANT	\N	PRESENT	0
269169	263464	19631V	PARTICIPANT	\N	PRESENT	0
269170	263464	19581D	PARTICIPANT	\N	PRESENT	0
269171	263464	19441R	PARTICIPANT	\N	PRESENT	0
269172	263464	17637T	PARTICIPANT	\N	PRESENT	0
269173	263464	14151M	PARTICIPANT	\N	PRESENT	0
269213	263464	14223L	PARTICIPANT	\N	PRESENT	0
269222	269219	08034U	PARTICIPANT	\N	PRESENT	0
269292	263465	14191V	PARTICIPANT	\N	PRESENT	0
269293	263465	19447X	PARTICIPANT	\N	PRESENT	0
269294	263465	19741B	PARTICIPANT	\N	PRESENT	0
269295	263465	19667J	PARTICIPANT	\N	PRESENT	0
269296	263465	19663E	PARTICIPANT	\N	PRESENT	0
269297	263465	19507S	PARTICIPANT	\N	PRESENT	0
269299	263465	18083K	PARTICIPANT	\N	PRESENT	0
269300	263465	07029T	PARTICIPANT	\N	PRESENT	0
269301	263465	14157T	PARTICIPANT	\N	PRESENT	0
269302	263465	14223L	PARTICIPANT	\N	PRESENT	0
269303	263465	98050T	PARTICIPANT	\N	PRESENT	0
269304	263465	19383Y	PARTICIPANT	\N	PRESENT	0
269305	263465	19731Y	PARTICIPANT	\N	PRESENT	0
269306	263465	19699S	PARTICIPANT	\N	PRESENT	0
269307	263465	08044W	PARTICIPANT	\N	PRESENT	0
269308	263465	14331P	PARTICIPANT	\N	PRESENT	0
269309	263465	05008E	PARTICIPANT	\N	PRESENT	0
269310	263465	19747H	PARTICIPANT	\N	PRESENT	0
269311	263465	19593H	PARTICIPANT	\N	PRESENT	0
269312	263465	19671E	PARTICIPANT	\N	PRESENT	0
269313	263465	14151M	PARTICIPANT	\N	PRESENT	0
269314	263465	80013X	PARTICIPANT	\N	PRESENT	0
269315	263465	19581D	PARTICIPANT	\N	PRESENT	0
269316	263465	14215L	PARTICIPANT	\N	PRESENT	0
269317	263465	19583F	PARTICIPANT	\N	PRESENT	0
269318	263465	14225N	PARTICIPANT	\N	PRESENT	0
269319	263465	19659J	PARTICIPANT	\N	PRESENT	0
269320	263465	14085U	PARTICIPANT	\N	PRESENT	0
269321	263465	19629C	PARTICIPANT	\N	PRESENT	0
269322	263465	19387D	PARTICIPANT	\N	PRESENT	0
269323	263465	19349W	PARTICIPANT	\N	PRESENT	0
269324	263465	19631V	PARTICIPANT	\N	PRESENT	0
269325	263465	14097Y	PARTICIPANT	\N	PRESENT	0
269326	263465	19725B	PARTICIPANT	\N	PRESENT	0
269327	263465	04018C	PARTICIPANT	\N	PRESENT	0
269328	263465	19553Y	PARTICIPANT	\N	PRESENT	0
269329	263465	14133K	PARTICIPANT	\N	PRESENT	0
269332	263465	98035U	PARTICIPANT	\N	PRESENT	0
269333	263465	11033F	PARTICIPANT	\N	PRESENT	0
269335	263465	97011G	PARTICIPANT	\N	PRESENT	0
269336	263465	17637T	PARTICIPANT	\N	PRESENT	0
269337	263465	14229S	PARTICIPANT	\N	PRESENT	0
269343	263465	19441R	PARTICIPANT	\N	PRESENT	0
269344	263465	19479G	PARTICIPANT	\N	PRESENT	0
269347	263465	19543W	PARTICIPANT	\N	PRESENT	0
269355	263465	19503N	PARTICIPANT	\N	PRESENT	0
269357	263465	19673G	PARTICIPANT	\N	PRESENT	0
269381	263465	08031R	PARTICIPANT	\N	PRESENT	0
269382	263465	11067R	PARTICIPANT	\N	PRESENT	0
269383	263465	14237S	PARTICIPANT	\N	PRESENT	0
269385	263465	19713W	PARTICIPANT	\N	PRESENT	0
269386	263465	14251Q	PARTICIPANT	\N	PRESENT	0
269387	263465	04070G	PARTICIPANT	\N	PRESENT	0
269388	263465	08043V	PARTICIPANT	\N	PRESENT	0
269389	263465	01028R	PARTICIPANT	\N	PRESENT	0
269390	263465	19749K	PARTICIPANT	\N	PRESENT	0
269391	263465	14205J	PARTICIPANT	\N	PRESENT	0
269392	263465	07034Q	PARTICIPANT	\N	PRESENT	0
269473	269467	08052W	PARTICIPANT	\N	PRESENT	0
269474	269467	11070L	PARTICIPANT	\N	PRESENT	0
269475	269467	10006L	PARTICIPANT	\N	PRESENT	0
269476	269467	14041T	PARTICIPANT	\N	PRESENT	0
269289	263465	11077T	PARTICIPANT	\N	PRESENT	0
269291	263465	95062K	PARTICIPANT	\N	PRESENT	0
269563	263466	19651A	PARTICIPANT	\N	PRESENT	0
269478	269467	14034U	PARTICIPANT	\N	PRESENT	0
269479	269467	14231L	PARTICIPANT	\N	PRESENT	0
269480	269467	11064N	PARTICIPANT	\N	PRESENT	0
269564	263466	14239U	PARTICIPANT	\N	PRESENT	0
269482	269467	14241N	PARTICIPANT	\N	PRESENT	0
269565	263466	19349W	PARTICIPANT	\N	PRESENT	0
269484	269467	14159V	PARTICIPANT	\N	PRESENT	0
269485	269467	86034E	PARTICIPANT	\N	PRESENT	0
269486	269467	08034U	PARTICIPANT	\N	PRESENT	0
269566	263466	08010L	PARTICIPANT	\N	PRESENT	0
269567	263466	19637C	PARTICIPANT	\N	PRESENT	0
269489	269467	12016W	PARTICIPANT	\N	PRESENT	0
269568	263466	19697Q	PARTICIPANT	\N	PRESENT	0
269491	269467	05012A	PARTICIPANT	\N	PRESENT	0
269569	263466	14169X	PARTICIPANT	\N	PRESENT	0
269493	269467	04044E	PARTICIPANT	\N	PRESENT	0
269570	263466	10015M	PARTICIPANT	\N	PRESENT	0
269571	263466	89017R	PARTICIPANT	\N	PRESENT	0
269572	263466	14223L	PARTICIPANT	\N	PRESENT	0
269573	263466	19685L	PARTICIPANT	\N	PRESENT	0
269574	263466	08028W	PARTICIPANT	\N	PRESENT	0
269575	263466	19515S	PARTICIPANT	\N	PRESENT	0
269576	263466	14034U	PARTICIPANT	\N	PRESENT	0
269577	263466	01057W	PARTICIPANT	\N	PRESENT	0
269578	263466	19553Y	PARTICIPANT	\N	PRESENT	0
269579	263466	14259Y	PARTICIPANT	\N	PRESENT	0
269580	263466	95067Q	PARTICIPANT	\N	PRESENT	0
269581	263466	11090Q	PARTICIPANT	\N	PRESENT	0
269582	263466	19703U	PARTICIPANT	\N	PRESENT	0
269583	263466	19699S	PARTICIPANT	\N	PRESENT	0
269584	263466	19713W	PARTICIPANT	\N	PRESENT	0
269585	263466	19673G	PARTICIPANT	\N	PRESENT	0
269586	263466	95063L	PARTICIPANT	\N	PRESENT	0
269587	263466	11010L	PARTICIPANT	\N	PRESENT	0
269588	263466	19667J	PARTICIPANT	\N	PRESENT	0
269589	263466	14241N	PARTICIPANT	\N	PRESENT	0
269590	263466	14199E	PARTICIPANT	\N	PRESENT	0
269591	263466	19575F	PARTICIPANT	\N	PRESENT	0
269592	263466	04085P	PARTICIPANT	\N	PRESENT	0
269593	263466	12041X	PARTICIPANT	\N	PRESENT	0
269594	263466	14253S	PARTICIPANT	\N	PRESENT	0
269595	263466	19573D	PARTICIPANT	\N	PRESENT	0
269596	263466	14119M	PARTICIPANT	\N	PRESENT	0
269597	263466	19387D	PARTICIPANT	\N	PRESENT	0
269598	263466	11099A	PARTICIPANT	\N	PRESENT	0
269599	263466	11049P	PARTICIPANT	\N	PRESENT	0
269600	263466	14105F	PARTICIPANT	\N	PRESENT	0
269601	263466	14093U	PARTICIPANT	\N	PRESENT	0
269602	263466	14147R	PARTICIPANT	\N	PRESENT	0
269603	263466	14195A	PARTICIPANT	\N	PRESENT	0
269604	263466	14251Q	PARTICIPANT	\N	PRESENT	0
269605	263466	14038Y	PARTICIPANT	\N	PRESENT	0
269606	263466	19585H	PARTICIPANT	\N	PRESENT	0
269607	263466	19723Y	PARTICIPANT	\N	PRESENT	0
269608	263466	02002K	PARTICIPANT	\N	PRESENT	0
269468	269467	04059M	PARTICIPANT	\N	PRESENT	0
269469	269467	11040E	PARTICIPANT	\N	PRESENT	0
269470	269467	14053L	PARTICIPANT	\N	PRESENT	0
269471	269467	11053K	PARTICIPANT	\N	PRESENT	0
269472	269467	04086Q	PARTICIPANT	\N	PRESENT	0
243356	241123	19503N	PARTICIPANT	\N	PRESENT	0
243357	241124	19503N	PARTICIPANT	\N	PRESENT	0
243359	243358	04059M	PARTICIPANT	\N	PRESENT	0
243360	243358	14255U	PARTICIPANT	\N	PRESENT	0
243361	243358	04042C	PARTICIPANT	\N	PRESENT	0
243362	243358	14053L	PARTICIPANT	\N	PRESENT	0
243363	243358	19721W	PARTICIPANT	\N	PRESENT	0
243364	243358	88008L	PARTICIPANT	\N	PRESENT	0
243365	243358	19525U	PARTICIPANT	\N	PRESENT	0
243366	243358	19663E	PARTICIPANT	\N	PRESENT	0
243367	243358	07033P	PARTICIPANT	\N	PRESENT	0
243368	243358	14187A	PARTICIPANT	\N	PRESENT	0
243369	243358	04035D	PARTICIPANT	\N	PRESENT	0
243370	243358	14211G	PARTICIPANT	\N	PRESENT	0
243371	243358	11049P	PARTICIPANT	\N	PRESENT	0
243372	243358	01057W	PARTICIPANT	\N	PRESENT	0
243373	243358	98022P	PARTICIPANT	\N	PRESENT	0
243374	243358	14081Q	PARTICIPANT	\N	PRESENT	0
243375	243358	14179A	PARTICIPANT	\N	PRESENT	0
243376	243358	99004R	PARTICIPANT	\N	PRESENT	0
243377	243358	11026G	PARTICIPANT	\N	PRESENT	0
243378	243358	08010L	PARTICIPANT	\N	PRESENT	0
243379	243358	08017T	PARTICIPANT	\N	PRESENT	0
243380	243358	08009T	PARTICIPANT	\N	PRESENT	0
243381	243358	19671E	PARTICIPANT	\N	PRESENT	0
243382	243358	04070G	PARTICIPANT	\N	PRESENT	0
243383	243358	04088S	PARTICIPANT	\N	PRESENT	0
243384	243358	19443T	PARTICIPANT	\N	PRESENT	0
243385	243358	14229S	PARTICIPANT	\N	PRESENT	0
243386	243358	04018C	PARTICIPANT	\N	PRESENT	0
243387	243358	95067Q	PARTICIPANT	\N	PRESENT	0
244023	244022	11064N	PARTICIPANT	\N	PRESENT	0
244034	244031	14227Q	PARTICIPANT	\N	PRESENT	0
244036	244031	07004J	PARTICIPANT	\N	PRESENT	0
244037	244031	11066Q	PARTICIPANT	\N	PRESENT	0
245229	243522	04042C	PARTICIPANT	\N	EXCUSE	0
245230	243522	14235Q	PARTICIPANT	\N	PRESENT	0
245232	243522	01058X	PARTICIPANT	\N	PRESENT	0
245234	243522	01062T	PARTICIPANT	\N	PRESENT	0
245235	243522	19709B	PARTICIPANT	\N	PRESENT	0
245236	243522	98029W	PARTICIPANT	\N	PRESENT	0
245237	244333	14001X	PARTICIPANT	\N	PRESENT	0
245238	244333	19543W	PARTICIPANT	\N	PRESENT	0
245239	244333	19581D	PARTICIPANT	\N	PRESENT	0
245240	244333	04044E	PARTICIPANT	\N	PRESENT	0
245241	244333	04047H	PARTICIPANT	\N	PRESENT	0
245242	244333	19673G	PARTICIPANT	\N	PRESENT	0
245243	244333	01028R	PARTICIPANT	\N	PRESENT	0
245244	244333	05008E	PRESIDENT	0	PRESENT	0
245245	244333	19447X	PARTICIPANT	\N	PRESENT	0
245246	244333	19489J	PARTICIPANT	\N	PRESENT	0
245247	244333	14147R	PARTICIPANT	\N	PRESENT	0
245248	244333	14179A	PARTICIPANT	\N	PRESENT	0
245249	244333	14151M	PARTICIPANT	\N	PRESENT	0
245250	244333	19483C	PARTICIPANT	\N	PRESENT	0
245251	244333	11072N	PARTICIPANT	\N	PRESENT	0
245252	244333	14111D	PARTICIPANT	\N	PRESENT	0
245253	244333	14065Q	PARTICIPANT	\N	PRESENT	0
245254	244333	19649G	PARTICIPANT	\N	PRESENT	0
245255	244333	07034Q	PARTICIPANT	\N	PRESENT	0
245256	244333	10015M	PARTICIPANT	\N	PRESENT	0
245257	244333	04038G	PARTICIPANT	\N	PRESENT	0
245258	244333	19719D	PARTICIPANT	\N	PRESENT	0
245259	244333	11033F	PARTICIPANT	\N	PRESENT	0
245260	244333	19729F	PARTICIPANT	\N	PRESENT	0
245261	244333	95063L	PARTICIPANT	\N	PRESENT	0
245262	244333	14069U	PARTICIPANT	\N	PRESENT	0
245263	244333	11049P	PARTICIPANT	\N	PRESENT	0
245268	243522	19421M	PARTICIPANT	\N	PRESENT	0
245269	243522	08056B	PARTICIPANT	\N	PRESENT	0
245270	243522	95037J	PARTICIPANT	\N	PRESENT	0
245271	243522	08061X	PARTICIPANT	\N	PRESENT	0
245272	243522	14097Y	PARTICIPANT	\N	PRESENT	0
245273	243522	08058D	PARTICIPANT	\N	PRESENT	0
245274	243522	08053X	PARTICIPANT	\N	PRESENT	0
245275	243522	98022P	PARTICIPANT	\N	PRESENT	0
245276	243522	11027H	PARTICIPANT	\N	PRESENT	0
245277	243522	14133K	PARTICIPANT	\N	PRESENT	0
245278	243522	14105F	PARTICIPANT	\N	PRESENT	0
245279	243522	14255U	PARTICIPANT	\N	PRESENT	0
245280	244333	14041T	PARTICIPANT	\N	PRESENT	0
245281	244333	14259Y	PARTICIPANT	\N	PRESENT	0
245282	244333	11010L	PARTICIPANT	\N	PRESENT	0
245283	244333	11026G	PARTICIPANT	\N	PRESENT	0
245284	244333	08045X	PARTICIPANT	\N	PRESENT	0
245285	244333	14089Y	PARTICIPANT	\N	PRESENT	0
245286	244333	19725B	PARTICIPANT	\N	PRESENT	0
245287	244333	08044W	PARTICIPANT	\N	PRESENT	0
245288	244333	04008A	PARTICIPANT	\N	PRESENT	0
245289	244333	14021P	PARTICIPANT	\N	PRESENT	0
245302	244333	11085T	PARTICIPANT	\N	PRESENT	0
245303	244333	01060R	PARTICIPANT	\N	PRESENT	0
245402	244149	14327T	PARTICIPANT	\N	PRESENT	0
245403	244149	14331P	PARTICIPANT	\N	PRESENT	0
245404	244149	04071H	PARTICIPANT	\N	PRESENT	0
245405	244149	01057W	PARTICIPANT	\N	PRESENT	0
245406	244149	11053K	PARTICIPANT	\N	PRESENT	0
245407	244149	89017R	PARTICIPANT	\N	PRESENT	0
245408	244149	11074Q	PRESIDENT	0	PRESENT	0
245409	244149	19667J	PARTICIPANT	\N	PRESENT	0
245410	244149	11070L	PARTICIPANT	\N	PRESENT	0
245411	244149	88008L	PARTICIPANT	\N	PRESENT	0
245412	244149	14225N	PARTICIPANT	\N	PRESENT	0
245413	244149	07029T	PARTICIPANT	\N	PRESENT	0
245414	244149	14085U	PARTICIPANT	\N	PRESENT	0
245415	244149	07004J	PARTICIPANT	\N	PRESENT	0
245416	244149	19349W	PARTICIPANT	\N	PRESENT	0
245417	244149	08010L	PARTICIPANT	\N	PRESENT	0
245418	244149	14253S	PARTICIPANT	\N	PRESENT	0
245419	244149	11048N	PARTICIPANT	\N	PRESENT	0
245420	244149	19479G	PARTICIPANT	\N	PRESENT	0
245421	244149	19647E	PARTICIPANT	\N	PRESENT	0
245422	244149	19711U	PARTICIPANT	\N	PRESENT	0
245423	244149	08034U	PARTICIPANT	\N	PRESENT	0
245424	244149	19651A	PARTICIPANT	\N	PRESENT	0
245425	244149	19687N	PARTICIPANT	\N	PRESENT	0
245426	244149	19689Q	PARTICIPANT	\N	PRESENT	0
245427	244149	08011M	PARTICIPANT	\N	PRESENT	0
245428	244149	08014Q	PARTICIPANT	\N	PRESENT	0
245429	244149	14034U	PARTICIPANT	\N	PRESENT	0
245430	244149	14159V	PARTICIPANT	\N	PRESENT	0
245431	244149	11040E	PARTICIPANT	\N	PRESENT	0
245432	244149	04086Q	PARTICIPANT	\N	PRESENT	0
245433	244149	14083S	PARTICIPANT	\N	PRESENT	0
245434	244149	11012A	PARTICIPANT	\N	PRESENT	0
245435	244149	14199E	PARTICIPANT	\N	PRESENT	0
245436	244149	19741B	PARTICIPANT	\N	PRESENT	0
245437	244149	14121F	PARTICIPANT	\N	PRESENT	0
245438	244149	99004R	PARTICIPANT	\N	PRESENT	0
245439	244149	04061F	PARTICIPANT	\N	PRESENT	0
245440	244149	08069G	PARTICIPANT	\N	PRESENT	0
245516	244323	19565D	PARTICIPANT	\N	EXCUSE	0
245517	244323	11101A	PARTICIPANT	\N	EXCUSE	0
245647	240285	14031R	PARTICIPANT	\N	PRESENT	0
245648	240285	14073Q	PARTICIPANT	\N	PRESENT	0
245649	240285	14219Q	PARTICIPANT	\N	PRESENT	0
245650	240285	11012A	PARTICIPANT	\N	PRESENT	0
245651	240285	19659J	PARTICIPANT	\N	PRESENT	0
245652	240285	08024S	PARTICIPANT	\N	PRESENT	0
245653	240285	19591F	PARTICIPANT	\N	PRESENT	0
245654	240285	14109K	PARTICIPANT	\N	PRESENT	0
245655	240285	14147R	PARTICIPANT	\N	PRESENT	0
245656	240285	14029X	PARTICIPANT	\N	PRESENT	0
245657	240285	08034U	PARTICIPANT	\N	PRESENT	0
245658	240285	95015C	PARTICIPANT	\N	PRESENT	0
245717	240285	11049P	PARTICIPANT	\N	PRESENT	0
245719	240285	19573D	PARTICIPANT	\N	PRESENT	0
245729	240285	19387D	PARTICIPANT	\N	PRESENT	0
245742	240285	11104D	PARTICIPANT	\N	PRESENT	0
245745	240285	08061X	PARTICIPANT	\N	PRESENT	0
245747	240285	14115H	PARTICIPANT	\N	PRESENT	0
245753	240285	98022P	PARTICIPANT	\N	PRESENT	0
245754	240285	14241N	PARTICIPANT	\N	PRESENT	0
245760	240285	14069U	PARTICIPANT	\N	PRESENT	0
245761	240285	19621T	PARTICIPANT	\N	PRESENT	0
245762	240285	19253P	PARTICIPANT	\N	PRESENT	0
245764	240285	14042U	PARTICIPANT	\N	PRESENT	0
245765	240285	04059M	PARTICIPANT	\N	PRESENT	0
245768	240285	14063N	PARTICIPANT	\N	PRESENT	0
245769	240285	95030B	PARTICIPANT	\N	PRESENT	0
245770	240285	98018T	PARTICIPANT	\N	PRESENT	0
245771	240285	19515S	PARTICIPANT	\N	PRESENT	0
245772	240285	19713W	PARTICIPANT	\N	PRESENT	0
245773	240285	80027E	PARTICIPANT	\N	PRESENT	0
245774	240285	08031R	PARTICIPANT	\N	PRESENT	0
245776	245644	11048N	PRESIDENT	0	PRESENT	0
245777	245644	11067R	PARTICIPANT	\N	PRESENT	0
245778	245644	14103D	PARTICIPANT	\N	PRESENT	0
245779	245644	19711U	PARTICIPANT	\N	PRESENT	0
264626	263038	14021P	PARTICIPANT	\N	PRESENT	0
264627	263038	87003B	PARTICIPANT	\N	PRESENT	0
264628	263038	19479G	PARTICIPANT	\N	PRESENT	0
264629	263038	14213J	PARTICIPANT	\N	PRESENT	0
264630	263038	08015R	PARTICIPANT	\N	PRESENT	0
264631	263038	14039A	PARTICIPANT	\N	PRESENT	0
264632	263038	95015C	PARTICIPANT	\N	PRESENT	0
264633	263038	01025N	PARTICIPANT	\N	PRESENT	0
264634	263038	19749K	PARTICIPANT	\N	PRESENT	0
264635	263038	19553Y	PARTICIPANT	\N	PRESENT	0
264636	263038	08055A	PARTICIPANT	\N	PRESENT	0
264641	263038	08056B	PARTICIPANT	\N	PRESENT	0
264642	263038	14089Y	PARTICIPANT	\N	PRESENT	0
264643	263038	14219Q	PARTICIPANT	\N	PRESENT	0
264644	263038	08053X	PARTICIPANT	\N	PRESENT	0
264645	263038	19731Y	PARTICIPANT	\N	PRESENT	0
264646	263038	19349W	PARTICIPANT	\N	PRESENT	0
264647	263038	08017T	PARTICIPANT	\N	PRESENT	0
264648	263038	19691J	PARTICIPANT	\N	PRESENT	0
264649	263038	19683J	PARTICIPANT	\N	PRESENT	0
264650	263038	19367Y	PARTICIPANT	\N	PRESENT	0
264651	263038	98022P	PARTICIPANT	\N	PRESENT	0
264652	263038	89017R	PARTICIPANT	\N	PRESENT	0
264653	263038	19483C	PARTICIPANT	\N	PRESENT	0
264654	263038	14227Q	PARTICIPANT	\N	PRESENT	0
264655	263038	11054L	PARTICIPANT	\N	PRESENT	0
264656	263038	14085U	PARTICIPANT	\N	PRESENT	0
264657	263038	14265W	PARTICIPANT	\N	PRESENT	0
264658	263038	11010L	PARTICIPANT	\N	PRESENT	0
264659	263038	19593H	PARTICIPANT	\N	PRESENT	0
264660	263038	19591F	PARTICIPANT	\N	PRESENT	0
264661	263038	11104D	PARTICIPANT	\N	PRESENT	0
264796	263044	11031D	PARTICIPANT	\N	PRESENT	0
264797	263044	11063M	PARTICIPANT	\N	PRESENT	0
264798	263044	14211G	PARTICIPANT	\N	PRESENT	0
264799	263044	11033F	PARTICIPANT	\N	PRESENT	0
264800	263044	04085P	PARTICIPANT	\N	PRESENT	0
264801	263044	17637T	PARTICIPANT	\N	PRESENT	0
264802	263044	11040E	PARTICIPANT	\N	PRESENT	0
264803	263044	95062K	PARTICIPANT	\N	PRESENT	0
264804	263044	19565D	PARTICIPANT	\N	PRESENT	0
264805	263044	19711U	PARTICIPANT	\N	PRESENT	0
264806	263044	19347U	PARTICIPANT	\N	PRESENT	0
264807	263044	04035D	PARTICIPANT	\N	PRESENT	0
264808	263044	14051J	PARTICIPANT	\N	PRESENT	0
264809	263044	19593H	PARTICIPANT	\N	PRESENT	0
264810	263044	98024R	PARTICIPANT	\N	PRESENT	0
264811	263044	19695N	PARTICIPANT	\N	PRESENT	0
264812	263044	08061X	PARTICIPANT	\N	PRESENT	0
264813	263044	95063L	PARTICIPANT	\N	PRESENT	0
264814	263044	14157T	PARTICIPANT	\N	PRESENT	0
264815	263044	98029W	PARTICIPANT	\N	PRESENT	0
264816	263044	19651A	PARTICIPANT	\N	PRESENT	0
264817	263044	01058X	PARTICIPANT	\N	PRESENT	0
264818	263044	11083R	PARTICIPANT	\N	PRESENT	0
264819	263044	99004R	PARTICIPANT	\N	PRESENT	0
264820	263044	19637C	PARTICIPANT	\N	PRESENT	0
264821	263044	19349W	PARTICIPANT	\N	PRESENT	0
264822	263044	04047H	PARTICIPANT	\N	PRESENT	0
264823	263044	08073C	PARTICIPANT	\N	PRESENT	0
264824	263044	14039A	PARTICIPANT	\N	PRESENT	0
264825	263044	08011M	PARTICIPANT	\N	PRESENT	0
264826	263044	04034C	PARTICIPANT	\N	PRESENT	0
264827	263044	08010L	PARTICIPANT	\N	PRESENT	0
264828	263044	95037J	PARTICIPANT	\N	PRESENT	0
264829	263044	19329S	PARTICIPANT	\N	PRESENT	0
264830	263044	04097T	PARTICIPANT	\N	PRESENT	0
264831	263044	11072N	PARTICIPANT	\N	PRESENT	0
264832	263044	19301E	PARTICIPANT	\N	PRESENT	0
264928	263044	14123H	PARTICIPANT	\N	PRESENT	0
264834	263044	19731Y	PARTICIPANT	\N	PRESENT	0
264835	263044	14055N	PARTICIPANT	\N	PRESENT	0
264836	263044	01060R	PARTICIPANT	\N	PRESENT	0
264931	263044	08012N	PARTICIPANT	\N	PRESENT	0
264838	263044	89017R	PARTICIPANT	\N	PRESENT	0
264839	263044	19745F	PARTICIPANT	\N	PRESENT	0
264840	263044	11012A	PARTICIPANT	\N	PRESENT	0
264841	263044	88008L	PARTICIPANT	\N	PRESENT	0
264842	263044	19679N	PARTICIPANT	\N	PRESENT	0
264843	263044	14034U	PARTICIPANT	\N	PRESENT	0
264844	263044	19253P	PARTICIPANT	\N	PRESENT	0
264845	263044	14261S	PARTICIPANT	\N	PRESENT	0
264846	263044	08020N	PARTICIPANT	\N	PRESENT	0
264847	263044	19629C	PARTICIPANT	\N	PRESENT	0
264848	263044	14201E	PARTICIPANT	\N	PRESENT	0
264849	263044	19563B	PARTICIPANT	\N	PRESENT	0
264850	263044	98022P	PARTICIPANT	\N	PRESENT	0
264851	263044	19643A	PARTICIPANT	\N	PRESENT	0
264852	263044	14241N	PARTICIPANT	\N	PRESENT	0
264853	263044	19553Y	PARTICIPANT	\N	PRESENT	0
264854	263044	04086Q	PARTICIPANT	\N	PRESENT	0
264855	263044	19681G	PARTICIPANT	\N	PRESENT	0
264856	263044	95015C	PARTICIPANT	\N	PRESENT	0
264857	263044	19717B	PARTICIPANT	\N	PRESENT	0
264858	263044	08028W	PARTICIPANT	\N	PRESENT	0
264859	263044	14195A	PARTICIPANT	\N	PRESENT	0
264860	263044	01048V	PARTICIPANT	\N	PRESENT	0
264861	263044	19545Y	PARTICIPANT	\N	PRESENT	0
264862	263044	02002K	PARTICIPANT	\N	PRESENT	0
264863	263044	19583F	PARTICIPANT	\N	PRESENT	0
264864	263044	10015M	PARTICIPANT	\N	PRESENT	0
264865	263044	17589D	PARTICIPANT	\N	PRESENT	0
264866	263044	14251Q	PARTICIPANT	\N	PRESENT	0
264867	263044	04042C	PARTICIPANT	\N	PRESENT	0
264868	263044	14111D	PARTICIPANT	\N	PRESENT	0
264869	263044	04057K	PARTICIPANT	\N	PRESENT	0
264870	263044	11043H	PARTICIPANT	\N	PRESENT	0
264871	263044	11064N	PARTICIPANT	\N	PRESENT	0
264872	263044	04033B	PARTICIPANT	\N	PRESENT	0
264873	263044	19543W	PARTICIPANT	\N	PRESENT	0
264874	263044	14259Y	PARTICIPANT	\N	PRESENT	0
264875	263044	01057W	PARTICIPANT	\N	PRESENT	0
264876	263044	14071N	PARTICIPANT	\N	PRESENT	0
264881	263044	11077T	PARTICIPANT	\N	PRESENT	0
264878	263044	19669L	PARTICIPANT	\N	PRESENT	0
264879	263044	98035U	PARTICIPANT	\N	PRESENT	0
264880	263044	19421M	PARTICIPANT	\N	PRESENT	0
264882	263044	04008A	PARTICIPANT	\N	PRESENT	0
264883	263044	04059M	PARTICIPANT	\N	PRESENT	0
264884	263044	11074Q	PARTICIPANT	\N	PRESENT	0
264885	263044	11080N	PARTICIPANT	\N	PRESENT	0
264886	263044	19515S	PARTICIPANT	\N	PRESENT	0
264887	263044	08068F	PARTICIPANT	\N	PRESENT	0
264888	263044	96004D	PARTICIPANT	\N	PRESENT	0
264889	263044	11027H	PARTICIPANT	\N	PRESENT	0
264890	263044	01028R	PARTICIPANT	\N	PRESENT	0
264891	263044	08052W	PARTICIPANT	\N	PRESENT	0
264892	263044	14229S	PARTICIPANT	\N	PRESENT	0
264893	263044	08055A	PARTICIPANT	\N	PRESENT	0
264894	263044	87003B	PARTICIPANT	\N	PRESENT	0
264895	263044	14239U	PARTICIPANT	\N	PRESENT	0
264896	263044	14223L	PARTICIPANT	\N	PRESENT	0
264897	263044	14107H	PARTICIPANT	\N	PRESENT	0
264898	263044	08024S	PARTICIPANT	\N	PRESENT	0
264899	263044	14187A	PARTICIPANT	\N	PRESENT	0
264900	263044	08045X	PARTICIPANT	\N	PRESENT	0
264901	263044	11090Q	PARTICIPANT	\N	PRESENT	0
264902	263044	14069U	PARTICIPANT	\N	PRESENT	0
264903	263044	14225N	PARTICIPANT	\N	PRESENT	0
264904	263044	14053L	PARTICIPANT	\N	PRESENT	0
264905	263044	14021P	PARTICIPANT	\N	PRESENT	0
264906	263044	12016W	PARTICIPANT	\N	PRESENT	0
264907	263044	14087W	PARTICIPANT	\N	PRESENT	0
264908	263044	19715Y	PARTICIPANT	\N	PRESENT	0
264909	263044	14215L	PARTICIPANT	\N	PRESENT	0
264910	263044	19719D	PARTICIPANT	\N	PRESENT	0
264911	263044	11099A	PARTICIPANT	\N	PRESENT	0
264912	263044	04071H	PARTICIPANT	\N	PRESENT	0
264913	263044	19647E	PARTICIPANT	\N	PRESENT	0
264914	263044	19649G	PARTICIPANT	\N	PRESENT	0
264915	263044	19673G	PARTICIPANT	\N	PRESENT	0
264916	263044	14028W	PARTICIPANT	\N	PRESENT	0
264917	263044	11010L	PARTICIPANT	\N	PRESENT	0
264918	263044	14197C	PARTICIPANT	\N	PRESENT	0
264919	263044	14031R	PARTICIPANT	\N	PRESENT	0
264920	263044	19667J	PARTICIPANT	\N	PRESENT	0
264921	263044	14199E	PARTICIPANT	\N	PRESENT	0
264922	263044	11066Q	PARTICIPANT	\N	PRESENT	0
264923	263044	01062T	PARTICIPANT	\N	PRESENT	0
264924	263044	19575F	PARTICIPANT	\N	PRESENT	0
264925	263044	08043V	PARTICIPANT	\N	PRESENT	0
264926	263044	98023Q	PARTICIPANT	\N	PRESENT	0
264927	263044	08053X	PARTICIPANT	\N	PRESENT	0
264929	263044	11104D	PARTICIPANT	\N	PRESENT	0
264794	263044	86034E	PARTICIPANT	\N	PRESENT	0
264795	263044	11056N	PARTICIPANT	\N	PRESENT	0
264930	263044	14026U	PARTICIPANT	\N	PRESENT	0
264932	263044	19727D	PARTICIPANT	\N	PRESENT	0
242431	239697	19533U	PARTICIPANT	\N	PRESENT	0
242432	239697	17583W	PARTICIPANT	\N	PRESENT	0
242433	239697	19551W	PARTICIPANT	\N	PRESENT	0
242434	239697	11012A	PARTICIPANT	\N	PRESENT	0
242435	239697	14105F	PARTICIPANT	\N	PRESENT	0
242436	239697	14199E	PARTICIPANT	\N	PRESENT	0
242437	239697	14069U	PARTICIPANT	\N	PRESENT	0
242438	239697	95062K	PARTICIPANT	\N	PRESENT	0
242439	239697	19575F	PARTICIPANT	\N	PRESENT	0
242440	239697	14179A	PARTICIPANT	\N	PRESENT	0
242441	239697	14033T	PARTICIPANT	\N	PRESENT	0
242442	239697	14357A	PARTICIPANT	\N	PRESENT	0
242443	239697	01025N	PARTICIPANT	\N	PRESENT	0
242444	239697	08056B	PARTICIPANT	\N	PRESENT	0
242445	239697	11070L	PARTICIPANT	\N	PRESENT	0
242446	239697	14265W	PARTICIPANT	\N	PRESENT	0
242447	239697	04097T	PARTICIPANT	\N	PRESENT	0
242448	239697	19467C	PARTICIPANT	\N	PRESENT	0
242449	239697	19563B	PARTICIPANT	\N	PRESENT	0
242450	239697	11099A	PARTICIPANT	\N	PRESENT	0
242451	239697	19383Y	PARTICIPANT	\N	PRESENT	0
242452	239697	14217N	PARTICIPANT	\N	PRESENT	0
242453	239697	11045K	PARTICIPANT	\N	PRESENT	0
242454	239697	14065Q	PARTICIPANT	\N	PRESENT	0
242429	239697	88008L	PARTICIPANT	\N	PRESENT	0
242430	239697	18083K	PARTICIPANT	\N	PRESENT	0
242455	239697	19709B	PARTICIPANT	\N	PRESENT	0
242456	239697	11097X	PARTICIPANT	\N	PRESENT	0
242457	239697	14213J	PARTICIPANT	\N	PRESENT	0
242458	239697	19679N	PARTICIPANT	\N	PRESENT	0
242611	242610	11063M	PARTICIPANT	\N	PRESENT	0
242613	242612	11063M	PARTICIPANT	\N	PRESENT	0
242644	242643	11063M	PARTICIPANT	\N	PRESENT	0
242646	242645	11063M	PARTICIPANT	\N	PRESENT	0
242648	242647	11063M	PARTICIPANT	\N	PRESENT	0
242656	242655	11063M	PARTICIPANT	\N	PRESENT	0
243389	243388	98022P	PARTICIPANT	\N	PRESENT	0
243390	243388	08012N	PARTICIPANT	\N	PRESENT	0
243391	243388	14221J	PARTICIPANT	\N	PRESENT	0
243392	243388	08061X	PARTICIPANT	\N	PRESENT	0
243393	243388	04088S	PARTICIPANT	\N	PRESENT	0
244153	244152	95015C	PARTICIPANT	\N	PRESENT	0
244154	244152	11083R	PARTICIPANT	\N	PRESENT	0
244319	244317	14073Q	PARTICIPANT	\N	PRESENT	0
244156	244152	19575F	PARTICIPANT	\N	PRESENT	0
244157	244152	97011G	PARTICIPANT	\N	PRESENT	0
244158	244152	19709B	PARTICIPANT	\N	PRESENT	0
244320	244317	08068F	PARTICIPANT	\N	PRESENT	0
244160	244152	08043V	PARTICIPANT	\N	PRESENT	0
244161	244152	08017T	PARTICIPANT	\N	PRESENT	0
244162	244152	11067R	PARTICIPANT	\N	PRESENT	0
244163	244152	14255U	PARTICIPANT	\N	PRESENT	0
244164	244152	14179A	PARTICIPANT	\N	PRESENT	0
244165	244152	19441R	PARTICIPANT	\N	PRESENT	0
244166	244152	04038G	PARTICIPANT	\N	PRESENT	0
244167	244152	19565D	PARTICIPANT	\N	PRESENT	0
244318	244317	19695N	PARTICIPANT	\N	PRESENT	0
244724	232876	19651A	PARTICIPANT	\N	EXCUSE	0
244841	240963	14239U	PARTICIPANT	\N	EXCUSE	0
244842	240963	19553Y	PARTICIPANT	\N	EXCUSE	0
244843	240963	19593H	PARTICIPANT	\N	EXCUSE	0
244844	240963	19511N	PARTICIPANT	\N	PRESENT	0
244845	240963	19533U	PARTICIPANT	\N	PRESENT	0
244846	240963	01058X	PARTICIPANT	\N	PRESENT	0
244926	244909	19611R	PARTICIPANT	\N	PRESENT	0
244927	244909	19329S	PARTICIPANT	\N	PRESENT	0
244928	244909	04057K	PARTICIPANT	\N	PRESENT	0
244929	244909	19573D	PARTICIPANT	\N	PRESENT	0
244930	244909	19621T	PARTICIPANT	\N	PRESENT	0
244931	244909	19747H	PARTICIPANT	\N	PRESENT	0
244932	244909	19749K	PARTICIPANT	\N	PRESENT	0
244933	244909	08031R	PARTICIPANT	\N	PRESENT	0
244934	244909	19533U	PARTICIPANT	\N	PRESENT	0
244935	244909	10015M	PARTICIPANT	\N	PRESENT	0
244936	244909	14355X	PARTICIPANT	\N	PRESENT	0
244937	244909	19735D	PARTICIPANT	\N	PRESENT	0
244938	244909	14039A	PARTICIPANT	\N	PRESENT	0
244939	244909	14187A	PARTICIPANT	\N	PRESENT	0
244940	244909	19629C	PARTICIPANT	\N	PRESENT	0
244941	244909	18083K	PARTICIPANT	\N	PRESENT	0
244942	244909	19713W	PARTICIPANT	\N	PRESENT	0
244943	244909	98005N	PARTICIPANT	\N	PRESENT	0
244944	244909	08052W	PARTICIPANT	\N	PRESENT	0
244945	244909	14267Y	PARTICIPANT	\N	PRESENT	0
244946	244909	14073Q	PARTICIPANT	\N	PRESENT	0
244947	244909	19369B	PARTICIPANT	\N	PRESENT	0
244948	244909	95015C	PARTICIPANT	\N	PRESENT	0
244949	244909	14105F	PARTICIPANT	\N	PRESENT	0
244950	244909	19521Q	PARTICIPANT	\N	PRESENT	0
244951	244909	14275Y	PARTICIPANT	\N	PRESENT	0
244952	244909	14249W	PARTICIPANT	\N	PRESENT	0
244953	244909	14231L	PARTICIPANT	\N	PRESENT	0
244954	244909	14030Q	PARTICIPANT	\N	PRESENT	0
244955	244909	14211G	PARTICIPANT	\N	PRESENT	0
244956	244909	08017T	PARTICIPANT	\N	PRESENT	0
244957	244909	14061L	PARTICIPANT	\N	PRESENT	0
244958	244909	14265W	PARTICIPANT	\N	PRESENT	0
244959	244909	14033T	PARTICIPANT	\N	PRESENT	0
244960	244909	19479G	PARTICIPANT	\N	PRESENT	0
244961	244909	19679N	PARTICIPANT	\N	PRESENT	0
244962	244909	14107H	PARTICIPANT	\N	PRESENT	0
244963	244909	07029T	PARTICIPANT	\N	PRESENT	0
244964	244909	11097X	PARTICIPANT	\N	PRESENT	0
244965	244909	14217N	PARTICIPANT	\N	PRESENT	0
244966	244909	11077T	PARTICIPANT	\N	PRESENT	0
244967	244909	01057W	PARTICIPANT	\N	PRESENT	0
244968	244909	11043H	PARTICIPANT	\N	PRESENT	0
244969	244909	14147R	PARTICIPANT	\N	PRESENT	0
244970	240277	11077T	PARTICIPANT	0	PRESENT	0
244971	240277	14109K	PARTICIPANT	0	PRESENT	0
244972	240277	19611R	PARTICIPANT	0	PRESENT	0
244973	240277	14219Q	PARTICIPANT	0	PRESENT	0
244974	240277	14039A	PARTICIPANT	0	PRESENT	0
244975	240277	19593H	PARTICIPANT	0	PRESENT	0
244976	240277	19631V	PARTICIPANT	0	PRESENT	0
244977	240277	14221J	PARTICIPANT	0	PRESENT	0
244978	240277	14229S	PARTICIPANT	0	PRESENT	0
244979	240277	14089Y	PARTICIPANT	0	PRESENT	0
244980	240277	04059M	PARTICIPANT	0	PRESENT	0
244981	240277	04070G	PARTICIPANT	0	PRESENT	0
244982	240277	14063N	PARTICIPANT	0	PRESENT	0
244983	240277	14235Q	PARTICIPANT	0	PRESENT	0
244984	240277	19695N	PARTICIPANT	0	PRESENT	0
244985	240277	08012N	PARTICIPANT	0	PRESENT	0
244986	240277	14021P	PARTICIPANT	0	PRESENT	0
244987	240277	08043V	PARTICIPANT	0	PRESENT	0
244988	240277	14231L	PARTICIPANT	0	PRESENT	0
244989	240277	19543W	PARTICIPANT	0	PRESENT	0
244990	240277	08020N	PARTICIPANT	0	PRESENT	0
244991	240277	01057W	PARTICIPANT	0	PRESENT	0
244992	240277	19347U	PARTICIPANT	0	PRESENT	0
244993	240277	11045K	PARTICIPANT	0	PRESENT	0
244994	240277	97011G	PARTICIPANT	0	PRESENT	0
244995	240277	08060W	PARTICIPANT	0	PRESENT	0
244996	240277	14249W	PARTICIPANT	0	PRESENT	0
244997	240277	14073Q	PARTICIPANT	0	PRESENT	0
244998	240277	04092N	PARTICIPANT	0	PRESENT	0
244999	240277	19349W	PARTICIPANT	0	PRESENT	0
245000	240277	14265W	PARTICIPANT	0	PRESENT	0
245001	240277	14199E	PARTICIPANT	0	PRESENT	0
245002	240277	14033T	PARTICIPANT	0	PRESENT	0
245003	240277	19483C	PARTICIPANT	0	PRESENT	0
245004	240277	14237S	PARTICIPANT	0	PRESENT	0
245005	240277	11031D	PARTICIPANT	0	PRESENT	0
245006	240277	14197C	PARTICIPANT	0	PRESENT	0
245007	240277	04088S	PARTICIPANT	0	PRESENT	0
245008	240277	11104D	PARTICIPANT	0	PRESENT	0
245009	240277	04034C	PARTICIPANT	0	PRESENT	0
245010	240277	11064N	PARTICIPANT	0	PRESENT	0
245011	240277	19737F	PARTICIPANT	0	PRESENT	0
245012	240277	14121F	PARTICIPANT	0	PRESENT	0
245013	240277	01048V	PARTICIPANT	0	PRESENT	0
245014	240277	08015R	PARTICIPANT	0	PRESENT	0
245015	240277	14213J	PARTICIPANT	0	PRESENT	0
245016	240277	08038Y	PARTICIPANT	0	PRESENT	0
245017	240277	19713W	PARTICIPANT	0	PRESENT	0
245018	240277	95062K	PARTICIPANT	0	PRESENT	0
245019	240277	19441R	PARTICIPANT	0	PRESENT	0
245020	240277	14031R	PARTICIPANT	0	PRESENT	0
245021	240277	98018T	PARTICIPANT	0	PRESENT	0
245022	240277	14187A	PARTICIPANT	0	PRESENT	0
245023	240277	01028R	PARTICIPANT	0	PRESENT	0
245024	240277	14069U	PARTICIPANT	0	PRESENT	0
245025	240277	19701S	PARTICIPANT	0	PRESENT	0
245026	240277	19741B	PARTICIPANT	0	PRESENT	0
245027	240277	19629C	PARTICIPANT	0	PRESENT	0
267204	267187	19511N	PARTICIPANT	\N	PRESENT	0
267234	267232	14255U	PARTICIPANT	\N	PRESENT	0
267236	267232	08053X	PARTICIPANT	\N	PRESENT	0
267251	267250	08058D	PARTICIPANT	\N	PRESENT	0
267252	267250	14133K	PARTICIPANT	\N	PRESENT	0
267264	267262	14255U	PARTICIPANT	\N	PRESENT	0
267265	267262	08053X	PARTICIPANT	\N	PRESENT	0
267267	267266	11043H	PARTICIPANT	\N	PRESENT	0
267268	267266	19349W	PARTICIPANT	\N	PRESENT	0
267269	267266	19711U	PARTICIPANT	\N	PRESENT	0
267271	267266	19575F	PARTICIPANT	\N	PRESENT	0
267272	267266	11048N	PARTICIPANT	\N	PRESENT	0
267273	267266	08012N	PARTICIPANT	\N	PRESENT	0
267276	267266	14063N	PARTICIPANT	\N	PRESENT	0
267320	267266	19643A	PARTICIPANT	\N	PRESENT	0
267389	267387	08011M	PARTICIPANT	\N	PRESENT	0
267391	267387	19711U	PARTICIPANT	\N	PRESENT	0
267392	267387	19349W	PARTICIPANT	\N	PRESENT	0
267396	267394	08011M	PARTICIPANT	\N	PRESENT	0
267397	267394	19711U	PARTICIPANT	\N	PRESENT	0
267398	267394	19349W	PARTICIPANT	\N	PRESENT	0
267399	267395	08011M	PARTICIPANT	\N	PRESENT	0
267400	267395	19711U	PARTICIPANT	\N	PRESENT	0
267401	267395	19349W	PARTICIPANT	\N	PRESENT	0
267415	267414	08011M	PARTICIPANT	\N	PRESENT	0
267417	267416	08011M	PARTICIPANT	\N	PRESENT	0
267418	267416	14083S	PARTICIPANT	\N	PRESENT	0
267876	267874	11070L	PARTICIPANT	\N	PRESENT	0
267877	267874	19647E	PARTICIPANT	\N	PRESENT	0
268584	268583	08058D	PRESIDENT	0	PRESENT	0
268585	268583	19721W	PARTICIPANT	\N	PRESENT	0
268586	268583	11053K	PARTICIPANT	\N	PRESENT	0
268587	268583	19251M	PARTICIPANT	\N	PRESENT	0
268588	268583	04071H	PARTICIPANT	\N	PRESENT	0
268589	268583	08035V	PARTICIPANT	\N	PRESENT	0
268590	268583	11049P	PARTICIPANT	\N	PRESENT	0
268591	268583	19581D	PARTICIPANT	\N	PRESENT	0
268592	268583	19443T	PARTICIPANT	\N	PRESENT	0
268593	268583	19703U	PARTICIPANT	\N	PRESENT	0
268594	268583	08034U	PARTICIPANT	\N	PRESENT	0
268595	268583	19729F	PARTICIPANT	\N	EXCUSE	0
268596	268583	04086Q	PARTICIPANT	\N	EXCUSE	0
269334	269330	14187A	PARTICIPANT	\N	PRESENT	0
269370	269369	14133K	PARTICIPANT	\N	PRESENT	0
269371	269369	96004D	PARTICIPANT	\N	PRESENT	0
269372	269369	04097T	PARTICIPANT	\N	PRESENT	0
269375	269369	14073Q	PARTICIPANT	\N	PRESENT	0
269376	269369	14001X	PARTICIPANT	\N	PRESENT	0
269378	269369	98050T	PARTICIPANT	\N	PRESENT	0
269379	269369	04034C	PARTICIPANT	\N	PRESENT	0
269380	269369	19709B	PARTICIPANT	\N	PRESENT	0
269540	269525	14151M	PARTICIPANT	\N	PRESENT	0
269541	269525	08018U	PARTICIPANT	\N	PRESENT	0
269542	269525	11049P	PARTICIPANT	\N	PRESENT	0
269543	269525	19447X	PARTICIPANT	\N	PRESENT	0
269544	269525	11072N	PARTICIPANT	\N	PRESENT	0
269545	269525	01028R	PARTICIPANT	\N	PRESENT	0
269546	263466	19591F	PARTICIPANT	\N	PRESENT	0
269547	263466	17779H	PARTICIPANT	\N	PRESENT	0
269548	263466	19347U	PARTICIPANT	\N	PRESENT	0
269549	263466	11063M	PARTICIPANT	\N	PRESENT	0
269550	263466	17637T	PARTICIPANT	\N	PRESENT	0
269551	263466	19489J	PARTICIPANT	\N	PRESENT	0
269552	263466	08011M	PARTICIPANT	\N	PRESENT	0
269553	263466	96004D	PARTICIPANT	\N	PRESENT	0
269554	263466	99004R	PARTICIPANT	\N	PRESENT	0
269555	263466	04097T	PARTICIPANT	\N	PRESENT	0
269556	263466	08061X	PARTICIPANT	\N	PRESENT	0
269557	263466	08039A	PARTICIPANT	\N	PRESENT	0
269558	263466	98029W	PARTICIPANT	\N	PRESENT	0
269559	263466	95037J	PARTICIPANT	\N	PRESENT	0
269560	263466	14123H	PARTICIPANT	\N	PRESENT	0
269561	263466	04034C	PARTICIPANT	\N	PRESENT	0
269562	263466	04042C	PARTICIPANT	\N	PRESENT	0
269695	263466	19369B	PARTICIPANT	\N	PRESENT	0
269696	263466	04033B	PARTICIPANT	\N	PRESENT	0
269697	263466	14187A	PARTICIPANT	\N	PRESENT	0
269698	263466	08056B	PARTICIPANT	\N	PRESENT	0
269699	263466	19421M	PARTICIPANT	\N	PRESENT	0
269700	263466	14042U	PARTICIPANT	\N	PRESENT	0
269701	263466	11097X	PARTICIPANT	\N	PRESENT	0
269702	263466	19521Q	PARTICIPANT	\N	PRESENT	0
269703	263466	19441R	PARTICIPANT	\N	PRESENT	0
269704	263466	14073Q	PARTICIPANT	\N	PRESENT	0
269705	263466	04086Q	PARTICIPANT	\N	PRESENT	0
269706	263466	14267Y	PARTICIPANT	\N	PRESENT	0
269707	263466	04092N	PARTICIPANT	\N	PRESENT	0
269708	263466	19739H	PARTICIPANT	\N	PRESENT	0
269709	263466	01060R	PARTICIPANT	\N	PRESENT	0
269710	263466	19335Q	PARTICIPANT	\N	PRESENT	0
269711	263466	98018T	PARTICIPANT	\N	PRESENT	0
269712	263466	04044E	PARTICIPANT	\N	PRESENT	0
269713	263466	14227Q	PARTICIPANT	\N	PRESENT	0
269714	263466	19551W	PARTICIPANT	\N	PRESENT	0
269715	263466	95041E	PARTICIPANT	\N	PRESENT	0
269716	263466	04070G	PARTICIPANT	\N	PRESENT	0
269717	263466	14089Y	PARTICIPANT	\N	PRESENT	0
269718	263466	19745F	PARTICIPANT	\N	PRESENT	0
269719	263466	11070L	PARTICIPANT	\N	PRESENT	0
269720	263466	19577H	PARTICIPANT	\N	PRESENT	0
269721	263466	04040A	PARTICIPANT	\N	PRESENT	0
269722	263466	04035D	PARTICIPANT	\N	PRESENT	0
269723	263466	19329S	PARTICIPANT	\N	PRESENT	0
269724	263466	11101A	PARTICIPANT	\N	PRESENT	0
269725	263466	01024M	PARTICIPANT	\N	PRESENT	0
269726	263466	04018C	PARTICIPANT	\N	PRESENT	0
269727	263466	01058X	PARTICIPANT	\N	PRESENT	0
269728	263466	14033T	PARTICIPANT	\N	PRESENT	0
269729	263466	14157T	PARTICIPANT	\N	PRESENT	0
269730	263466	14079W	PARTICIPANT	\N	PRESENT	0
269731	263466	11033F	PARTICIPANT	\N	PRESENT	0
269732	263466	19687N	PARTICIPANT	\N	PRESENT	0
269733	263466	12016W	PARTICIPANT	\N	PRESENT	0
269734	263466	14135M	PARTICIPANT	\N	PRESENT	0
269735	263466	11064N	PARTICIPANT	\N	PRESENT	0
269736	263466	18083K	PARTICIPANT	\N	PRESENT	0
269737	263466	14085U	PARTICIPANT	\N	PRESENT	0
269738	263466	98023Q	PARTICIPANT	\N	PRESENT	0
269739	263466	11026G	PARTICIPANT	\N	PRESENT	0
269740	263466	14215L	PARTICIPANT	\N	PRESENT	0
269741	263466	19749K	PARTICIPANT	\N	PRESENT	0
269742	263466	08068F	PARTICIPANT	\N	PRESENT	0
269759	263466	04071H	PARTICIPANT	\N	PRESENT	0
269756	263466	14031R	PARTICIPANT	\N	PRESENT	0
269763	263466	08053X	PARTICIPANT	\N	PRESENT	0
269758	263466	05012A	PARTICIPANT	\N	PRESENT	0
269761	263466	08045X	PARTICIPANT	\N	PRESENT	0
269764	263466	98024R	PARTICIPANT	\N	PRESENT	0
270008	267360	08056B	PARTICIPANT	\N	PRESENT	0
270009	267360	19421M	PARTICIPANT	\N	PRESENT	0
270010	267360	19575F	PARTICIPANT	\N	PRESENT	0
270011	267360	98050T	PARTICIPANT	\N	PRESENT	0
270012	267360	19673G	PARTICIPANT	\N	PRESENT	0
270013	267360	98029W	PRESIDENT	0	PRESENT	0
270014	267360	19611R	PARTICIPANT	\N	EXCUSE	0
270036	270033	14133K	PARTICIPANT	\N	PRESENT	0
270037	270033	08055A	PARTICIPANT	\N	PRESENT	0
270038	270033	19575F	PARTICIPANT	\N	PRESENT	0
270039	270033	19467C	PARTICIPANT	\N	PRESENT	0
270040	270033	14281W	PARTICIPANT	\N	PRESENT	0
270041	270033	19727D	PARTICIPANT	\N	PRESENT	0
270042	270033	19333N	PARTICIPANT	\N	PRESENT	0
270043	270033	07029T	PARTICIPANT	\N	PRESENT	0
270044	270033	08053X	PARTICIPANT	\N	PRESENT	0
270045	270033	19563B	PARTICIPANT	\N	PRESENT	0
270046	270033	14223L	PARTICIPANT	\N	PRESENT	0
270047	270033	14265W	PARTICIPANT	\N	PRESENT	0
270048	270033	19349W	PARTICIPANT	\N	PRESENT	0
270049	270033	95062K	PARTICIPANT	\N	PRESENT	0
241301	241300	14133K	PARTICIPANT	\N	PRESENT	0
241302	241300	14097Y	PARTICIPANT	\N	PRESENT	0
241303	241300	98022P	PARTICIPANT	\N	PRESENT	0
241305	241304	14133K	PARTICIPANT	\N	PRESENT	0
241306	241304	14097Y	PARTICIPANT	\N	PRESENT	0
244002	232876	19647E	PARTICIPANT	\N	EXCUSE	0
244003	232876	19713W	PARTICIPANT	\N	PRESENT	0
244073	244072	14030Q	PRESIDENT	0	PRESENT	0
244074	244072	08043V	PARTICIPANT	\N	PRESENT	0
244075	244072	19643A	PARTICIPANT	\N	PRESENT	0
244076	244072	19701S	PARTICIPANT	\N	PRESENT	0
244077	244072	11031D	PARTICIPANT	\N	PRESENT	0
244078	244072	19715Y	PARTICIPANT	\N	PRESENT	0
244079	244072	19731Y	PARTICIPANT	\N	PRESENT	0
244080	244072	07029T	PARTICIPANT	\N	PRESENT	0
244081	244072	14251Q	PARTICIPANT	\N	PRESENT	0
244082	244072	19679N	PARTICIPANT	\N	PRESENT	0
244083	244072	11045K	PARTICIPANT	\N	PRESENT	0
244084	244072	19697Q	PARTICIPANT	\N	EXCUSE	0
244085	244072	14249W	PARTICIPANT	\N	PRESENT	0
244086	244072	08020N	PARTICIPANT	\N	PRESENT	0
244087	244072	01043Q	PARTICIPANT	\N	EXCUSE	0
244088	244072	19577H	PARTICIPANT	\N	EXCUSE	0
244089	244072	19367Y	PARTICIPANT	\N	EXCUSE	0
244090	244072	19657G	PARTICIPANT	\N	EXCUSE	0
244091	244072	19693L	PARTICIPANT	\N	EXCUSE	0
244092	244072	08024S	PARTICIPANT	\N	EXCUSE	0
244093	244072	19673G	PARTICIPANT	\N	EXCUSE	0
245780	245644	19651A	PARTICIPANT	\N	PRESENT	0
245781	245644	14187A	PARTICIPANT	\N	PRESENT	0
245782	245644	14031R	PARTICIPANT	\N	PRESENT	0
245783	245644	19545Y	PARTICIPANT	\N	PRESENT	0
245784	245644	01024M	PARTICIPANT	\N	PRESENT	0
245785	245644	04038G	PARTICIPANT	\N	PRESENT	0
245786	245644	14026U	PARTICIPANT	\N	PRESENT	0
245787	245644	19399H	PARTICIPANT	\N	PRESENT	0
245788	245644	11040E	PARTICIPANT	\N	PRESENT	0
245789	245644	04049K	PARTICIPANT	\N	PRESENT	0
245790	245644	95063L	PARTICIPANT	\N	PRESENT	0
245791	245644	14087W	PARTICIPANT	\N	PRESENT	0
245792	245644	14041T	PARTICIPANT	\N	PRESENT	0
245793	245644	19503N	PARTICIPANT	\N	PRESENT	0
245794	245644	14151M	PARTICIPANT	\N	PRESENT	0
245795	245644	14071N	PARTICIPANT	\N	PRESENT	0
245796	245644	14157T	PARTICIPANT	\N	PRESENT	0
245797	245644	14207L	PARTICIPANT	\N	PRESENT	0
245798	245644	19749K	PARTICIPANT	\N	PRESENT	0
245799	245644	19533U	PARTICIPANT	\N	EXCUSE	0
245806	240285	08019V	PARTICIPANT	\N	PRESENT	0
245807	240285	80013X	PARTICIPANT	\N	PRESENT	0
245808	240285	14111D	PARTICIPANT	\N	PRESENT	0
245878	240286	80013X	PARTICIPANT	\N	PRESENT	0
245879	240286	19725B	PARTICIPANT	\N	PRESENT	0
245880	240286	14111D	PARTICIPANT	\N	PRESENT	0
245881	240286	19591F	PARTICIPANT	\N	PRESENT	0
245882	240286	14063N	PARTICIPANT	\N	PRESENT	0
245883	240286	14107H	PARTICIPANT	\N	PRESENT	0
245884	240286	80027E	PARTICIPANT	\N	PRESENT	0
245885	240286	11104D	PARTICIPANT	\N	PRESENT	0
245886	240286	19349W	PARTICIPANT	\N	PRESENT	0
245887	240286	08061X	PARTICIPANT	\N	PRESENT	0
245888	240286	98022P	PARTICIPANT	\N	PRESENT	0
245889	240286	14241N	PARTICIPANT	\N	PRESENT	0
245890	240286	19583F	PARTICIPANT	\N	PRESENT	0
245891	240286	14042U	PARTICIPANT	\N	PRESENT	0
245892	240286	14219Q	PARTICIPANT	\N	PRESENT	0
245893	240286	19737F	PARTICIPANT	\N	PRESENT	0
245894	240286	19253P	PARTICIPANT	\N	PRESENT	0
245895	240286	19629C	PARTICIPANT	\N	PRESENT	0
245896	240286	08031R	PARTICIPANT	\N	PRESENT	0
245898	240286	19691J	PARTICIPANT	\N	PRESENT	0
245900	240286	14267Y	PARTICIPANT	\N	PRESENT	0
245901	240286	19521Q	PARTICIPANT	\N	PRESENT	0
245903	240286	14215L	PARTICIPANT	\N	PRESENT	0
245906	240286	19731Y	PARTICIPANT	\N	PRESENT	0
245908	240286	14135M	PARTICIPANT	\N	PRESENT	0
245909	240286	08019V	PARTICIPANT	\N	PRESENT	0
245910	240286	14029X	PARTICIPANT	\N	PRESENT	0
245911	240286	19467C	PARTICIPANT	\N	PRESENT	0
245912	240286	19515S	PARTICIPANT	\N	PRESENT	0
245913	240286	14223L	PARTICIPANT	\N	PRESENT	0
245914	240286	14033T	PARTICIPANT	\N	PRESENT	0
245915	240286	19575F	PARTICIPANT	\N	PRESENT	0
245916	240286	14115H	PARTICIPANT	\N	PRESENT	0
245917	240286	14327T	PARTICIPANT	\N	PRESENT	0
245918	240286	95062K	PARTICIPANT	\N	PRESENT	0
245919	240286	14069U	PARTICIPANT	\N	PRESENT	0
245920	240286	14237S	PARTICIPANT	\N	PRESENT	0
245921	240286	08020N	PARTICIPANT	\N	PRESENT	0
245922	240286	19679N	PARTICIPANT	\N	PRESENT	0
245923	240286	19581D	PARTICIPANT	\N	PRESENT	0
245924	240286	08056B	PARTICIPANT	\N	PRESENT	0
245925	240286	14179A	PARTICIPANT	\N	PRESENT	0
245926	240286	19713W	PARTICIPANT	\N	PRESENT	0
245927	240286	14030Q	PARTICIPANT	\N	PRESENT	0
245928	240286	97011G	PARTICIPANT	\N	PRESENT	0
245929	240286	19525U	PARTICIPANT	\N	PRESENT	0
245930	240286	11033F	PARTICIPANT	\N	PRESENT	0
245931	240286	19553Y	PARTICIPANT	\N	PRESENT	0
245932	240286	18083K	PARTICIPANT	\N	PRESENT	0
245933	240286	01028R	PARTICIPANT	\N	PRESENT	0
245934	240286	08028W	PARTICIPANT	\N	PRESENT	0
245935	240286	04043D	PARTICIPANT	\N	PRESENT	0
245936	240286	19347U	PARTICIPANT	\N	PRESENT	0
245937	240286	95015C	PARTICIPANT	\N	PRESENT	0
245943	240286	11012A	PARTICIPANT	\N	PRESENT	0
245946	240286	08024S	PARTICIPANT	\N	PRESENT	0
245972	240286	14257W	PARTICIPANT	\N	PRESENT	0
245975	240286	19413M	PARTICIPANT	\N	PRESENT	0
245984	240286	08014Q	PARTICIPANT	\N	PRESENT	0
246014	240286	95063L	PARTICIPANT	\N	PRESENT	0
246015	240286	11054L	PARTICIPANT	\N	PRESENT	0
246016	240286	19483C	PARTICIPANT	\N	PRESENT	0
246017	240286	07029T	PARTICIPANT	\N	PRESENT	0
246018	240286	04088S	PARTICIPANT	\N	PRESENT	0
246019	240286	19543W	PARTICIPANT	\N	PRESENT	0
246020	240286	11010L	PARTICIPANT	\N	PRESENT	0
246021	240286	05008E	PARTICIPANT	\N	PRESENT	0
245876	240286	14034U	PARTICIPANT	\N	PRESENT	0
245877	240286	14089Y	PARTICIPANT	\N	PRESENT	0
246022	240286	14053L	PARTICIPANT	\N	PRESENT	0
246023	240286	19563B	PARTICIPANT	\N	PRESENT	0
246024	240286	08012N	PARTICIPANT	\N	PRESENT	0
246159	246158	01043Q	PARTICIPANT	\N	PRESENT	0
246162	246161	14121F	PARTICIPANT	\N	PRESENT	0
246297	246296	04086Q	PARTICIPANT	\N	PRESENT	0
247196	247195	14187A	PARTICIPANT	\N	PRESENT	0
247197	247195	04089T	PARTICIPANT	\N	PRESENT	0
247198	247195	01043Q	PARTICIPANT	\N	PRESENT	0
247200	247199	14187A	PARTICIPANT	\N	PRESENT	0
247201	247199	01025N	PARTICIPANT	\N	PRESENT	0
247203	247202	14187A	PARTICIPANT	\N	PRESENT	0
250205	250204	19295A	PARTICIPANT	\N	EXCUSE	0
250206	250204	11010L	PARTICIPANT	\N	EXCUSE	0
250207	250204	14097Y	PARTICIPANT	\N	EXCUSE	0
250208	250204	96004D	PARTICIPANT	\N	EXCUSE	0
250209	250204	19583F	PARTICIPANT	\N	EXCUSE	0
250211	250210	19295A	PARTICIPANT	\N	PRESENT	0
250212	250210	11010L	PARTICIPANT	\N	EXCUSE	0
250213	250210	14097Y	PARTICIPANT	\N	EXCUSE	0
250214	250210	96004D	PARTICIPANT	\N	EXCUSE	0
250215	250210	14219Q	PARTICIPANT	\N	EXCUSE	0
250216	250210	19583F	PARTICIPANT	\N	EXCUSE	0
250217	241232	14033T	PARTICIPANT	\N	EXCUSE	0
250218	241232	14039A	PARTICIPANT	\N	EXCUSE	0
250219	241232	11072N	PARTICIPANT	\N	EXCUSE	0
250220	241232	11054L	PARTICIPANT	\N	EXCUSE	0
250574	250553	19483C	PARTICIPANT	\N	PRESENT	0
250575	250553	11072N	PARTICIPANT	\N	PRESENT	0
250576	250553	14053L	PARTICIPANT	\N	PRESENT	0
250577	250553	98035U	PARTICIPANT	\N	PRESENT	0
250578	250553	14111D	PARTICIPANT	\N	PRESENT	0
250579	250553	10015M	PARTICIPANT	\N	PRESENT	0
250580	250553	08045X	PARTICIPANT	\N	PRESENT	0
250581	250553	07034Q	PARTICIPANT	\N	PRESENT	0
250582	250553	19253P	PARTICIPANT	\N	PRESENT	0
250583	250553	04038G	PARTICIPANT	\N	PRESENT	0
250584	250553	19719D	PARTICIPANT	\N	PRESENT	0
250585	250553	19725B	PARTICIPANT	\N	PRESENT	0
250586	250553	14089Y	PARTICIPANT	\N	PRESENT	0
250587	250553	19729F	PARTICIPANT	\N	PRESENT	0
250588	250553	95063L	PARTICIPANT	\N	PRESENT	0
250589	250553	19629C	PARTICIPANT	\N	PRESENT	0
250590	250553	08044W	PARTICIPANT	\N	PRESENT	0
250591	250553	14069U	PARTICIPANT	\N	PRESENT	0
250592	250553	11085T	PARTICIPANT	\N	PRESENT	0
250593	250553	11049P	PARTICIPANT	\N	PRESENT	0
250594	250553	14021P	PARTICIPANT	\N	PRESENT	0
250595	250553	14065Q	PARTICIPANT	\N	EXCUSE	0
264933	263044	19531S	PARTICIPANT	\N	PRESENT	0
264934	263044	10006L	PARTICIPANT	\N	PRESENT	0
264935	263044	19683J	PARTICIPANT	\N	PRESENT	0
264936	263044	19489J	PARTICIPANT	\N	PRESENT	0
264937	263044	07034Q	PARTICIPANT	\N	PRESENT	0
264938	263044	17779H	PARTICIPANT	\N	PRESENT	0
264939	263044	04043D	PARTICIPANT	\N	PRESENT	0
264940	263044	14121F	PARTICIPANT	\N	PRESENT	0
264941	263044	14085U	PARTICIPANT	\N	PRESENT	0
264942	263044	14079W	PARTICIPANT	\N	PRESENT	0
264943	263044	08017T	PARTICIPANT	\N	PRESENT	0
264944	263044	19525U	PARTICIPANT	\N	PRESENT	0
264945	263044	14331P	PARTICIPANT	\N	PRESENT	0
264946	263044	11045K	PARTICIPANT	\N	PRESENT	0
264947	263044	04045F	PARTICIPANT	\N	PRESENT	0
264948	263044	11041F	PARTICIPANT	\N	PRESENT	0
264950	263044	19599P	PARTICIPANT	\N	PRESENT	0
264951	263044	17583W	PARTICIPANT	\N	PRESENT	0
264952	263044	08058D	PARTICIPANT	\N	PRESENT	0
264953	263044	08035V	PARTICIPANT	\N	PRESENT	0
264954	263044	08047A	PARTICIPANT	\N	PRESENT	0
264955	263044	08031R	PARTICIPANT	\N	PRESENT	0
264956	263044	11049P	PARTICIPANT	\N	PRESENT	0
264957	263044	14173T	PARTICIPANT	\N	PRESENT	0
264958	263044	08014Q	PARTICIPANT	\N	PRESENT	0
264959	263044	19447X	PARTICIPANT	\N	PRESENT	0
264960	263044	19725B	PARTICIPANT	\N	PRESENT	0
264961	263044	19333N	PARTICIPANT	\N	PRESENT	0
264962	263044	19573D	PARTICIPANT	\N	PRESENT	0
264963	263044	80027E	PARTICIPANT	\N	PRESENT	0
264964	263044	11109J	PARTICIPANT	\N	PRESENT	0
264965	263044	19703U	PARTICIPANT	\N	PRESENT	0
264966	263044	19689Q	PARTICIPANT	\N	PRESENT	0
264967	263044	11054L	PARTICIPANT	\N	PRESENT	0
264968	263044	14133K	PARTICIPANT	\N	PRESENT	0
264970	263044	19251M	PARTICIPANT	\N	PRESENT	0
264971	263044	19707Y	PARTICIPANT	\N	PRESENT	0
264972	263044	92040Q	PARTICIPANT	\N	PRESENT	0
264973	263044	19591F	PARTICIPANT	\N	PRESENT	0
264974	263044	14119M	PARTICIPANT	\N	PRESENT	0
264975	263044	19551W	PARTICIPANT	\N	PRESENT	0
264976	263044	14227Q	PARTICIPANT	\N	PRESENT	0
264977	263044	11067R	PARTICIPANT	\N	PRESENT	0
264978	263044	14105F	PARTICIPANT	\N	PRESENT	0
264979	263044	19503N	PARTICIPANT	\N	PRESENT	0
264980	263044	19527W	PARTICIPANT	\N	PRESENT	0
264981	263044	14063N	PARTICIPANT	\N	PRESENT	0
264982	263044	19631V	PARTICIPANT	\N	PRESENT	0
264983	263044	19733B	PARTICIPANT	\N	PRESENT	0
264984	263044	14065Q	PARTICIPANT	\N	PRESENT	0
264985	263044	19549D	PARTICIPANT	\N	PRESENT	0
264986	263044	19747H	PARTICIPANT	\N	PRESENT	0
264987	263044	14109K	PARTICIPANT	\N	PRESENT	0
264988	263044	14097Y	PARTICIPANT	\N	PRESENT	0
264989	263044	14257W	PARTICIPANT	\N	PRESENT	0
264990	263044	95030B	PARTICIPANT	\N	PRESENT	0
264991	263044	04049K	PARTICIPANT	\N	PRESENT	0
264992	263044	14231L	PARTICIPANT	\N	PRESENT	0
264993	263044	14147R	PARTICIPANT	\N	PRESENT	0
264994	263044	08044W	PARTICIPANT	\N	PRESENT	0
264995	263044	14179A	PARTICIPANT	\N	PRESENT	0
264996	263044	97011G	PARTICIPANT	\N	PRESENT	0
264997	263044	19369B	PARTICIPANT	\N	PRESENT	0
264998	263044	19691J	PARTICIPANT	\N	PRESENT	0
264999	263044	11103C	PARTICIPANT	\N	PRESENT	0
265000	263044	11070L	PARTICIPANT	\N	PRESENT	0
265001	263044	07033P	PARTICIPANT	\N	PRESENT	0
265002	263044	19611R	PARTICIPANT	\N	PRESENT	0
265003	263044	95041E	PARTICIPANT	\N	PRESENT	0
265004	263044	19511N	PARTICIPANT	\N	PRESENT	0
265005	263044	14217N	PARTICIPANT	\N	PRESENT	0
265006	263044	19619A	PARTICIPANT	\N	PRESENT	0
265007	263044	19721W	PARTICIPANT	\N	PRESENT	0
265008	263044	19699S	PARTICIPANT	\N	PRESENT	0
265009	263044	14205J	PARTICIPANT	\N	PRESENT	0
265010	263044	19737F	PARTICIPANT	\N	PRESENT	0
265011	263044	19581D	PARTICIPANT	\N	PRESENT	0
265012	263044	19569H	PARTICIPANT	\N	PRESENT	0
265013	263044	08056B	PARTICIPANT	\N	PRESENT	0
265014	263044	19735D	PARTICIPANT	\N	PRESENT	0
265015	263044	16685X	PARTICIPANT	\N	PRESENT	0
265016	263044	98018T	PARTICIPANT	\N	PRESENT	0
265017	263044	19713W	PARTICIPANT	\N	PRESENT	0
265018	263044	14355X	PARTICIPANT	\N	PRESENT	0
265019	263044	19479G	PARTICIPANT	\N	PRESENT	0
265020	263044	14038Y	PARTICIPANT	\N	PRESENT	0
265021	263044	14219Q	PARTICIPANT	\N	PRESENT	0
265022	263044	19441R	PARTICIPANT	\N	PRESENT	0
265023	263044	19723Y	PARTICIPANT	\N	PRESENT	0
265024	263044	19507S	PARTICIPANT	\N	PRESENT	0
265025	263044	14207L	PARTICIPANT	\N	PRESENT	0
265026	263044	19467C	PARTICIPANT	\N	PRESENT	0
265027	263044	14267Y	PARTICIPANT	\N	PRESENT	0
265028	263044	18083K	PARTICIPANT	\N	PRESENT	0
265029	263044	14103D	PARTICIPANT	\N	PRESENT	0
265030	263044	14221J	PARTICIPANT	\N	PRESENT	0
265031	263044	19415P	PARTICIPANT	\N	PRESENT	0
265032	263044	19335Q	PARTICIPANT	\N	PRESENT	0
265033	263044	14033T	PARTICIPANT	\N	PRESENT	0
265034	263044	19739H	PARTICIPANT	\N	PRESENT	0
265035	263044	14135M	PARTICIPANT	\N	PRESENT	0
265036	263044	19749K	PARTICIPANT	\N	PRESENT	0
265037	263044	19705W	PARTICIPANT	\N	PRESENT	0
265038	263044	14083S	PARTICIPANT	\N	PRESENT	0
265039	263044	08019V	PARTICIPANT	\N	PRESENT	0
265040	263044	14089Y	PARTICIPANT	\N	PRESENT	0
265041	263044	19399H	PARTICIPANT	\N	PRESENT	0
265042	263044	14042U	PARTICIPANT	\N	PRESENT	0
265043	263044	19521Q	PARTICIPANT	\N	PRESENT	0
265044	263044	07004J	PARTICIPANT	\N	PRESENT	0
265045	263044	19693L	PARTICIPANT	\N	PRESENT	0
265046	263044	19729F	PARTICIPANT	\N	PRESENT	0
265047	263044	14255U	PARTICIPANT	\N	PRESENT	0
265048	263044	04070G	PARTICIPANT	\N	PRESENT	0
265049	263044	14265W	PARTICIPANT	\N	PRESENT	0
265050	263044	11085T	PARTICIPANT	\N	PRESENT	0
265051	263044	11115U	PARTICIPANT	\N	PRESENT	0
265052	263044	19577H	PARTICIPANT	\N	PRESENT	0
265053	263044	08009T	PARTICIPANT	\N	PRESENT	0
265054	263044	04040A	PARTICIPANT	\N	PRESENT	0
265055	263044	01025N	PARTICIPANT	\N	PRESENT	0
265056	263044	14213J	PARTICIPANT	\N	PRESENT	0
265057	263044	01024M	PARTICIPANT	\N	PRESENT	0
265058	263044	08039A	PARTICIPANT	\N	PRESENT	0
265059	263044	14327T	PARTICIPANT	\N	PRESENT	0
265060	263044	14030Q	PARTICIPANT	\N	PRESENT	0
265061	263044	98050T	PARTICIPANT	\N	PRESENT	0
265062	263044	14357A	PARTICIPANT	\N	PRESENT	0
265063	263044	19383Y	PARTICIPANT	\N	PRESENT	0
265064	263044	19483C	PARTICIPANT	\N	PRESENT	0
265065	263044	19533U	PARTICIPANT	\N	PRESENT	0
265066	263044	04018C	PARTICIPANT	\N	PRESENT	0
265067	263044	19701S	PARTICIPANT	\N	PRESENT	0
265068	263044	19621T	PARTICIPANT	\N	PRESENT	0
265069	263044	19367Y	PARTICIPANT	\N	PRESENT	0
265070	263044	08034U	PARTICIPANT	\N	PRESENT	0
265071	263044	19443T	PARTICIPANT	\N	PRESENT	0
265072	263044	19741B	PARTICIPANT	\N	PRESENT	0
265073	263044	04044E	PARTICIPANT	\N	PRESENT	0
265074	263044	14029X	PARTICIPANT	\N	PRESENT	0
265075	263044	04061F	PARTICIPANT	\N	PRESENT	0
265076	263044	19709B	PARTICIPANT	\N	PRESENT	0
265077	263044	19663E	PARTICIPANT	\N	PRESENT	0
265078	263044	04088S	PARTICIPANT	\N	PRESENT	0
265079	263044	14041T	PARTICIPANT	\N	PRESENT	0
265080	263044	08018U	PARTICIPANT	\N	PRESENT	0
265081	263044	14235Q	PARTICIPANT	\N	PRESENT	0
265082	263044	07029T	PARTICIPANT	\N	PRESENT	0
265083	263044	19687N	PARTICIPANT	\N	PRESENT	0
265084	263044	04038G	PARTICIPANT	\N	PRESENT	0
265085	263044	19657G	PARTICIPANT	\N	PRESENT	0
265086	263044	19697Q	PARTICIPANT	\N	PRESENT	0
265087	263044	08062Y	PARTICIPANT	\N	PRESENT	0
265088	263044	08015R	PARTICIPANT	\N	PRESENT	0
265089	263044	19269X	PARTICIPANT	\N	PRESENT	0
265090	263044	19387D	PARTICIPANT	\N	PRESENT	0
265091	263044	80013X	PARTICIPANT	\N	PRESENT	0
265092	263044	11026G	PARTICIPANT	\N	PRESENT	0
265093	263044	14115H	PARTICIPANT	\N	PRESENT	0
265094	263044	04092N	PARTICIPANT	\N	PRESENT	0
265095	263044	14059S	PARTICIPANT	\N	PRESENT	0
265096	263044	05008E	PARTICIPANT	\N	PRESENT	0
265097	263044	08069G	PARTICIPANT	\N	PRESENT	0
265098	263044	14191V	PARTICIPANT	\N	PRESENT	0
265099	263044	05012A	PARTICIPANT	\N	PRESENT	0
265100	263044	19675J	PARTICIPANT	\N	PRESENT	0
265101	263044	14159V	PARTICIPANT	\N	PRESENT	0
265102	263044	11110B	PARTICIPANT	\N	PRESENT	0
241298	241163	14231L	PARTICIPANT	\N	EXCUSE	0
241333	241332	14021P	PARTICIPANT	\N	PRESENT	0
242884	242883	11043H	PARTICIPANT	\N	PRESENT	0
242885	242883	19575F	PARTICIPANT	\N	PRESENT	0
242886	242883	14030Q	PARTICIPANT	\N	PRESENT	0
242887	242883	19721W	PARTICIPANT	\N	PRESENT	0
242888	242883	19251M	PARTICIPANT	\N	PRESENT	0
242889	242883	87003B	PARTICIPANT	\N	PRESENT	0
242890	242883	14249W	PARTICIPANT	\N	PRESENT	0
242891	242883	14081Q	PARTICIPANT	\N	PRESENT	0
242892	242883	19399H	PARTICIPANT	\N	PRESENT	0
242893	242883	14073Q	PARTICIPANT	\N	PRESENT	0
242894	242883	19699S	PARTICIPANT	\N	PRESENT	0
242895	242883	08012N	PARTICIPANT	\N	PRESENT	0
242896	242883	14063N	PARTICIPANT	\N	PRESENT	0
242897	242883	19533U	PARTICIPANT	\N	PRESENT	0
242898	242883	19643A	PARTICIPANT	\N	PRESENT	0
242899	242883	14039A	PARTICIPANT	\N	PRESENT	0
242900	242883	19711U	PARTICIPANT	\N	PRESENT	0
244110	244109	08011M	PARTICIPANT	\N	PRESENT	0
245028	240277	87003B	PARTICIPANT	0	PRESENT	0
245029	240277	14251Q	PARTICIPANT	0	PRESENT	0
245030	240277	11067R	PARTICIPANT	0	PRESENT	0
245031	240277	11027H	PARTICIPANT	0	PRESENT	0
245032	240277	12041X	PARTICIPANT	0	PRESENT	0
245033	240277	19399H	PARTICIPANT	0	PRESENT	0
245034	240277	19489J	PARTICIPANT	0	PRESENT	0
245035	240277	19575F	PARTICIPANT	0	PRESENT	0
245036	240277	08052W	PARTICIPANT	0	PRESENT	0
245037	240277	08035V	PARTICIPANT	0	PRESENT	0
245038	240277	04057K	PARTICIPANT	0	PRESENT	0
245039	240277	19329S	PARTICIPANT	0	PRESENT	0
245040	240277	14123H	PARTICIPANT	0	PRESENT	0
245041	240277	19697Q	PARTICIPANT	0	PRESENT	0
245042	240277	08031R	PARTICIPANT	0	PRESENT	0
245043	240277	19253P	PARTICIPANT	0	PRESENT	0
245044	240277	19699S	PARTICIPANT	0	PRESENT	0
245045	240277	19369B	PARTICIPANT	0	PRESENT	0
245046	240277	18083K	PARTICIPANT	0	PRESENT	0
245047	240277	19573D	PARTICIPANT	0	PRESENT	0
245048	240277	14061L	PARTICIPANT	0	PRESENT	0
245049	240277	19731Y	PARTICIPANT	0	PRESENT	0
245050	240277	19387D	PARTICIPANT	0	PRESENT	0
245051	240277	98005N	PARTICIPANT	0	PRESENT	0
245052	240277	19533U	PARTICIPANT	0	PRESENT	0
245053	240277	14071N	PARTICIPANT	0	PRESENT	0
245054	240277	04043D	PARTICIPANT	0	PRESENT	0
245055	240277	14217N	PARTICIPANT	0	PRESENT	0
245056	240277	04018C	PARTICIPANT	0	PRESENT	0
245057	240277	89017R	PARTICIPANT	0	PRESENT	0
245058	240277	19621T	PARTICIPANT	0	PRESENT	0
245059	240277	14267Y	PARTICIPANT	0	PRESENT	0
245060	240277	14211G	PARTICIPANT	0	PRESENT	0
245061	240277	95015C	PARTICIPANT	0	PRESENT	0
245062	240277	11043H	PARTICIPANT	0	PRESENT	0
245063	240277	14105F	PARTICIPANT	0	PRESENT	0
245064	240277	11097X	PARTICIPANT	0	PRESENT	0
245065	240277	14034U	PARTICIPANT	0	PRESENT	0
245066	240277	19735D	PARTICIPANT	0	PRESENT	0
245067	240277	19715Y	PARTICIPANT	0	PRESENT	0
245068	240277	19531S	PARTICIPANT	0	PRESENT	0
245069	240277	19725B	PARTICIPANT	0	PRESENT	0
245070	240277	08017T	PARTICIPANT	0	PRESENT	0
245071	240277	11063M	PARTICIPANT	0	PRESENT	0
245072	240277	14355X	PARTICIPANT	0	PRESENT	0
245073	240277	19691J	PARTICIPANT	0	PRESENT	0
245074	240277	19319Q	PARTICIPANT	0	PRESENT	0
245075	240277	95030B	PARTICIPANT	0	PRESENT	0
245076	240277	19727D	PARTICIPANT	0	PRESENT	0
245077	240277	11012A	PARTICIPANT	0	PRESENT	0
245078	240277	19707Y	PARTICIPANT	0	PRESENT	0
245079	240277	19705W	PARTICIPANT	0	PRESENT	0
245080	240277	17583W	PARTICIPANT	0	PRESENT	0
245081	240277	11085T	PARTICIPANT	0	PRESENT	0
245082	240277	19507S	PARTICIPANT	0	PRESENT	0
245083	240277	14275Y	PARTICIPANT	0	PRESENT	0
245084	240277	14030Q	PARTICIPANT	0	PRESENT	0
245085	240277	19447X	PARTICIPANT	0	PRESENT	0
245086	240277	04035D	PARTICIPANT	0	PRESENT	0
245087	240277	99004R	PARTICIPANT	0	PRESENT	0
245088	240277	19413M	PARTICIPANT	0	PRESENT	0
245089	240277	14107H	PARTICIPANT	0	PRESENT	0
245090	240277	19649G	PARTICIPANT	0	PRESENT	0
245091	240277	19647E	PARTICIPANT	0	PRESENT	0
245092	240277	14059S	PARTICIPANT	0	PRESENT	0
245093	240277	14147R	PARTICIPANT	0	PRESENT	0
245094	240277	04033B	PARTICIPANT	0	PRESENT	0
245095	240277	14119M	PARTICIPANT	0	PRESENT	0
245096	240277	08061X	PARTICIPANT	0	PRESENT	0
245097	240277	19421M	PARTICIPANT	0	PRESENT	0
245098	240277	88008L	PARTICIPANT	0	PRESENT	0
245099	240277	04085P	PARTICIPANT	0	PRESENT	0
245100	240277	17637T	PARTICIPANT	0	PRESENT	0
245101	240277	14157T	PARTICIPANT	0	PRESENT	0
245102	240277	14083S	PARTICIPANT	0	PRESENT	0
245103	240277	19749K	PARTICIPANT	0	PRESENT	0
245104	240277	14103D	PARTICIPANT	0	PRESENT	0
245105	240277	14042U	PARTICIPANT	0	PRESENT	0
245106	240277	14215L	PARTICIPANT	0	PRESENT	0
245107	240277	11048N	PARTICIPANT	0	PRESENT	0
245108	240277	01024M	PARTICIPANT	0	PRESENT	0
245109	240277	19747H	PARTICIPANT	0	PRESENT	0
245110	240277	19703U	PARTICIPANT	0	PRESENT	0
245111	240277	14026U	PARTICIPANT	0	PRESENT	0
245112	240277	19503N	PARTICIPANT	0	PRESENT	0
245113	240277	19479G	PARTICIPANT	0	PRESENT	0
245114	240277	08053X	PARTICIPANT	0	PRESENT	0
245115	240277	19563B	PARTICIPANT	0	PRESENT	0
245116	240282	11072N	PARTICIPANT	0	PRESENT	0
245117	240282	19685L	PARTICIPANT	0	PRESENT	0
245118	240282	19251M	PARTICIPANT	0	PRESENT	0
245119	240282	14111D	PARTICIPANT	0	PRESENT	0
245120	240282	19399H	PARTICIPANT	0	PRESENT	0
245121	240282	14041T	PARTICIPANT	0	PRESENT	0
245122	240282	04034C	PARTICIPANT	0	PRESENT	0
245123	240282	19687N	PARTICIPANT	0	PRESENT	0
245124	240282	19717B	PARTICIPANT	0	PRESENT	0
245125	240282	14327T	PARTICIPANT	0	PRESENT	0
245126	240282	98050T	PARTICIPANT	0	PRESENT	0
245127	240282	19443T	PARTICIPANT	0	PRESENT	0
245128	240282	14051J	PARTICIPANT	0	PRESENT	0
245129	240282	19441R	PARTICIPANT	0	PRESENT	0
245130	240282	19659J	PARTICIPANT	0	PRESENT	0
245131	240282	19301E	PARTICIPANT	0	PRESENT	0
245132	240282	19415P	PARTICIPANT	0	PRESENT	0
245133	240282	14038Y	PARTICIPANT	0	PRESENT	0
245134	240282	14031R	PARTICIPANT	0	PRESENT	0
245135	240282	08043V	PARTICIPANT	0	PRESENT	0
245136	240282	17583W	PARTICIPANT	0	PRESENT	0
245137	240282	19387D	PARTICIPANT	0	PRESENT	0
245138	240282	04008A	PARTICIPANT	0	PRESENT	0
245139	240282	19715Y	PARTICIPANT	0	PRESENT	0
245140	240282	14107H	PARTICIPANT	0	PRESENT	0
245141	240282	14147R	PARTICIPANT	0	PRESENT	0
245142	240282	11115U	PARTICIPANT	0	PRESENT	0
245143	240282	11045K	PARTICIPANT	0	PRESENT	0
245144	240282	19727D	PARTICIPANT	0	PRESENT	0
245145	240282	14033T	PARTICIPANT	0	PRESENT	0
245146	240282	14195A	PARTICIPANT	0	PRESENT	0
245147	240282	14133K	PARTICIPANT	0	PRESENT	0
245148	240282	19621T	PARTICIPANT	0	PRESENT	0
245149	240282	19349W	PARTICIPANT	0	PRESENT	0
245150	240282	14265W	PARTICIPANT	0	PRESENT	0
245151	240282	19741B	PARTICIPANT	0	PRESENT	0
245152	240282	04089T	PARTICIPANT	0	PRESENT	0
245153	240282	14267Y	PARTICIPANT	0	PRESENT	0
245154	240282	14097Y	PARTICIPANT	0	PRESENT	0
245155	240282	14259Y	PARTICIPANT	0	PRESENT	0
245156	240282	14241N	PARTICIPANT	0	PRESENT	0
245157	240282	19575F	PARTICIPANT	0	PRESENT	0
245158	240282	11070L	PARTICIPANT	0	PRESENT	0
245187	245186	14069U	PARTICIPANT	\N	PRESENT	0
245188	245186	14255U	PARTICIPANT	\N	PRESENT	0
245189	245186	14083S	PARTICIPANT	\N	PRESENT	0
245190	245186	19719D	PARTICIPANT	\N	PRESENT	0
245191	245186	14211G	PARTICIPANT	\N	PRESENT	0
245192	245186	19511N	PARTICIPANT	\N	PRESENT	0
245193	245186	11067R	PARTICIPANT	\N	PRESENT	0
245194	245186	04018C	PARTICIPANT	\N	PRESENT	0
245195	245186	01062T	PARTICIPANT	\N	PRESENT	0
245196	245186	19527W	PARTICIPANT	\N	PRESENT	0
246156	246155	14073Q	PARTICIPANT	\N	PRESENT	0
246157	246155	14225N	PARTICIPANT	\N	PRESENT	0
247103	247102	18083K	PARTICIPANT	\N	PRESENT	0
247104	247102	19673G	PARTICIPANT	\N	PRESENT	0
267419	258969	19703U	PARTICIPANT	\N	PRESENT	0
267452	267451	14229S	PARTICIPANT	\N	PRESENT	0
267453	267451	19611R	PARTICIPANT	\N	PRESENT	0
267455	267454	14229S	PARTICIPANT	\N	PRESENT	0
267456	267454	19611R	PARTICIPANT	\N	PRESENT	0
269045	269044	08043V	PARTICIPANT	\N	PRESENT	0
269046	269044	04018C	PARTICIPANT	\N	PRESENT	0
269047	269044	04057K	PARTICIPANT	\N	PRESENT	0
269048	269044	19643A	PARTICIPANT	\N	PRESENT	0
269049	269044	08039A	PARTICIPANT	\N	PRESENT	0
269051	269050	08043V	PARTICIPANT	\N	PRESENT	0
269052	269050	04018C	PARTICIPANT	\N	PRESENT	0
269053	269050	04057K	PARTICIPANT	\N	PRESENT	0
269054	269050	08039A	PARTICIPANT	\N	PRESENT	0
269056	269055	08043V	PARTICIPANT	\N	PRESENT	0
269057	269055	04018C	PARTICIPANT	\N	PRESENT	0
269058	269055	19749K	PARTICIPANT	\N	PRESENT	0
269059	269055	14109K	PARTICIPANT	\N	PRESENT	0
270138	270137	19515S	PARTICIPANT	\N	PRESENT	0
270139	270137	19575F	PARTICIPANT	\N	PRESENT	0
270140	270137	08014Q	PARTICIPANT	\N	PRESENT	0
270141	270137	19383Y	PARTICIPANT	\N	PRESENT	0
270142	270137	08020N	PARTICIPANT	\N	PRESENT	0
270143	270137	14207L	PARTICIPANT	\N	PRESENT	0
270144	270137	19693L	PARTICIPANT	\N	PRESENT	0
270145	270137	14217N	PARTICIPANT	\N	PRESENT	0
270146	270137	19507S	PARTICIPANT	\N	PRESENT	0
270147	270137	14197C	PARTICIPANT	\N	PRESENT	0
270148	270137	01025N	PARTICIPANT	\N	PRESENT	0
270149	270137	14199E	PARTICIPANT	\N	PRESENT	0
270150	270137	19347U	PARTICIPANT	\N	PRESENT	0
270151	270137	19727D	PARTICIPANT	\N	PRESENT	0
270152	270137	14033T	PARTICIPANT	\N	PRESENT	0
270153	270137	14026U	PARTICIPANT	\N	PRESENT	0
270154	270137	04097T	PARTICIPANT	\N	PRESENT	0
270155	270137	14213J	PARTICIPANT	\N	PRESENT	0
270156	270137	19511N	PARTICIPANT	\N	PRESENT	0
270157	270137	11099A	PARTICIPANT	\N	PRESENT	0
270158	270137	14159V	PARTICIPANT	\N	PRESENT	0
270159	270137	19563B	PARTICIPANT	\N	PRESENT	0
270160	270137	19369B	PARTICIPANT	\N	PRESENT	0
270161	270137	14109K	PARTICIPANT	\N	PRESENT	0
270162	270137	14257W	PARTICIPANT	\N	PRESENT	0
270303	270300	19421M	PARTICIPANT	\N	PRESENT	0
270164	270137	19745F	PARTICIPANT	\N	PRESENT	0
270165	270137	04088S	PARTICIPANT	\N	PRESENT	0
270166	270137	14135M	PARTICIPANT	\N	PRESENT	0
270167	270137	19269X	PARTICIPANT	\N	PRESENT	0
270168	270137	19619A	PARTICIPANT	\N	PRESENT	0
270169	270137	04045F	PARTICIPANT	\N	PRESENT	0
270301	270300	08056B	PARTICIPANT	\N	PRESENT	0
270302	270300	98029W	PARTICIPANT	\N	PRESENT	0
270372	270371	14089Y	PARTICIPANT	\N	PRESENT	0
270375	270373	08034U	PARTICIPANT	\N	PRESENT	0
270580	270439	14331P	PARTICIPANT	\N	PRESENT	0
270581	270439	95041E	PARTICIPANT	\N	PRESENT	0
270582	270439	12016W	PARTICIPANT	\N	PRESENT	0
270583	270439	19667J	PARTICIPANT	\N	PRESENT	0
270584	270439	11074Q	PRESIDENT	0	PRESENT	0
270585	270439	19671E	PARTICIPANT	\N	PRESENT	0
270586	270439	14159V	PARTICIPANT	\N	PRESENT	0
270587	270439	14173T	PARTICIPANT	\N	PRESENT	0
270588	270439	04086Q	PARTICIPANT	\N	PRESENT	0
270589	270439	11040E	PARTICIPANT	\N	PRESENT	0
270590	270439	07029T	PARTICIPANT	\N	PRESENT	0
270591	270439	07004J	PARTICIPANT	\N	PRESENT	0
270592	270439	19349W	PARTICIPANT	\N	PRESENT	0
270615	268440	19511N	PARTICIPANT	\N	EXCUSE	0
270617	270579	14089Y	PARTICIPANT	\N	PRESENT	0
270618	270579	14275Y	PARTICIPANT	\N	PRESENT	0
270619	270579	19629C	PARTICIPANT	\N	PRESENT	0
270620	270579	08045X	PARTICIPANT	\N	PRESENT	0
270621	270579	14041T	PARTICIPANT	\N	PRESENT	0
270622	270579	14179A	PARTICIPANT	\N	PRESENT	0
270623	270579	01024M	PARTICIPANT	\N	PRESENT	0
270624	270579	14151M	PARTICIPANT	\N	PRESENT	0
270625	270579	14215L	PARTICIPANT	\N	PRESENT	0
270626	270579	19585H	PARTICIPANT	\N	PRESENT	0
270627	270579	08018U	PARTICIPANT	\N	PRESENT	0
270628	270579	05008E	PRESIDENT	0	PRESENT	0
270629	270579	98035U	PARTICIPANT	\N	PRESENT	0
270630	270579	95063L	PARTICIPANT	\N	PRESENT	0
270631	270579	07034Q	PARTICIPANT	\N	PRESENT	0
270632	270579	11026G	PARTICIPANT	\N	PRESENT	0
270633	270579	19581D	PARTICIPANT	\N	PRESENT	0
270634	270579	01028R	PARTICIPANT	\N	PRESENT	0
270635	270579	19729F	PARTICIPANT	\N	EXCUSE	0
270636	270579	14065Q	PARTICIPANT	\N	EXCUSE	0
270637	270579	19253P	PARTICIPANT	\N	EXCUSE	0
270638	270579	14231L	PARTICIPANT	\N	EXCUSE	0
270639	270439	01057W	PARTICIPANT	\N	PRESENT	0
270640	270439	19687N	PARTICIPANT	\N	PRESENT	0
270641	270439	14034U	PARTICIPANT	\N	PRESENT	0
270642	270439	14083S	PARTICIPANT	\N	PRESENT	0
270659	263473	04086Q	PARTICIPANT	\N	PRESENT	0
270660	263473	87003B	PARTICIPANT	\N	PRESENT	0
270662	263473	19681G	PARTICIPANT	\N	PRESENT	0
270663	263473	15447F	PARTICIPANT	\N	PRESENT	0
270664	263473	04097T	PARTICIPANT	\N	PRESENT	0
270665	263473	19415P	PARTICIPANT	\N	PRESENT	0
270666	263473	11101A	PARTICIPANT	\N	PRESENT	0
270667	263473	19667J	PARTICIPANT	\N	PRESENT	0
270668	263473	14031R	PARTICIPANT	\N	PRESENT	0
270669	263473	14089Y	PARTICIPANT	\N	PRESENT	0
270670	263473	08056B	PARTICIPANT	\N	PRESENT	0
270671	263473	14257W	PARTICIPANT	\N	PRESENT	0
270672	263473	19333N	PARTICIPANT	\N	PRESENT	0
270674	263473	19715Y	PARTICIPANT	\N	PRESENT	0
270675	263473	14039A	PARTICIPANT	\N	PRESENT	0
270676	263473	19447X	PARTICIPANT	\N	PRESENT	0
270677	263473	14038Y	PARTICIPANT	\N	PRESENT	0
270678	263473	14179A	PARTICIPANT	\N	PRESENT	0
270679	263473	14103D	PARTICIPANT	\N	PRESENT	0
270680	263473	14073Q	PARTICIPANT	\N	PRESENT	0
270681	263473	19737F	PARTICIPANT	\N	PRESENT	0
270682	263473	04088S	PARTICIPANT	\N	PRESENT	0
270683	263473	19629C	PARTICIPANT	\N	PRESENT	0
270684	263473	01024M	PARTICIPANT	\N	PRESENT	0
270685	263473	04085P	PARTICIPANT	\N	PRESENT	0
270686	270440	14327T	PARTICIPANT	\N	PRESENT	0
270687	270440	14331P	PARTICIPANT	\N	PRESENT	0
270688	270440	11048N	PARTICIPANT	\N	PRESENT	0
270689	270440	04071H	PRESIDENT	0	PRESENT	0
270690	270440	19651A	PARTICIPANT	\N	PRESENT	0
270691	270440	08034U	PARTICIPANT	\N	PRESENT	0
270692	270440	19687N	PARTICIPANT	\N	PRESENT	0
270694	270440	08014Q	PARTICIPANT	\N	PRESENT	0
270695	270440	19671E	PARTICIPANT	\N	PRESENT	0
270696	270440	88008L	PARTICIPANT	\N	PRESENT	0
270697	270440	14173T	PARTICIPANT	\N	PRESENT	0
270698	270440	11040E	PARTICIPANT	\N	PRESENT	0
270699	270440	14083S	PARTICIPANT	\N	PRESENT	0
270700	270440	19349W	PARTICIPANT	\N	PRESENT	0
270701	270440	99004R	PARTICIPANT	\N	PRESENT	0
270702	270440	08011M	PARTICIPANT	\N	EXCUSE	0
270703	270440	11074Q	PARTICIPANT	\N	EXCUSE	0
270704	263473	14028W	PARTICIPANT	\N	PRESENT	0
270705	263473	95030B	PARTICIPANT	\N	PRESENT	0
270706	263473	14237S	PARTICIPANT	\N	PRESENT	0
270707	263473	19565D	PARTICIPANT	\N	PRESENT	0
270709	263473	14119M	PARTICIPANT	\N	PRESENT	0
270710	263473	14207L	PARTICIPANT	\N	PRESENT	0
270711	263473	11056N	PARTICIPANT	\N	PRESENT	0
270712	263473	08049C	PARTICIPANT	\N	PRESENT	0
270713	263473	14147R	PARTICIPANT	\N	PRESENT	0
270714	263473	14191V	PARTICIPANT	\N	PRESENT	0
270715	263473	19713W	PARTICIPANT	\N	PRESENT	0
270716	263473	14197C	PARTICIPANT	\N	PRESENT	0
270717	263473	19631V	PARTICIPANT	\N	PRESENT	0
270718	263473	19721W	PARTICIPANT	\N	PRESENT	0
270719	263473	19747H	PARTICIPANT	\N	PRESENT	0
270720	263473	08060W	PARTICIPANT	\N	PRESENT	0
270721	263473	01034P	PARTICIPANT	\N	PRESENT	0
270722	263473	19301E	PARTICIPANT	\N	PRESENT	0
270723	263473	19549D	PARTICIPANT	\N	PRESENT	0
270724	263473	01048V	PARTICIPANT	\N	PRESENT	0
270725	263473	19637C	PARTICIPANT	\N	PRESENT	0
270726	263473	19507S	PARTICIPANT	\N	PRESENT	0
270728	263473	14051J	PARTICIPANT	\N	PRESENT	0
270731	263473	19731Y	PARTICIPANT	\N	PRESENT	0
270733	263473	19413M	PARTICIPANT	\N	PRESENT	0
270734	263473	14042U	PARTICIPANT	\N	PRESENT	0
270735	263473	14157T	PARTICIPANT	\N	PRESENT	0
270736	263473	19695N	PARTICIPANT	\N	PRESENT	0
270737	263473	02002K	PARTICIPANT	\N	PRESENT	0
270738	263473	08039A	PARTICIPANT	\N	PRESENT	0
270739	263473	19383Y	PARTICIPANT	\N	PRESENT	0
240614	240613	14193X	PARTICIPANT	\N	PRESENT	0
240615	240613	08053X	PARTICIPANT	\N	PRESENT	0
240617	240616	14193X	PARTICIPANT	\N	PRESENT	0
240618	240616	08053X	PARTICIPANT	\N	PRESENT	0
240619	240616	95067Q	PARTICIPANT	\N	PRESENT	0
241369	241368	08048B	PARTICIPANT	\N	EXCUSE	0
241374	241368	04040A	PRESIDENT	0	PRESENT	0
241919	241368	11101A	PARTICIPANT	\N	EXCUSE	0
248920	246405	98050T	PARTICIPANT	\N	PRESENT	0
248927	248850	19663E	PARTICIPANT	\N	PRESENT	0
248929	246405	11027H	PARTICIPANT	\N	PRESENT	0
248930	246405	14255U	PARTICIPANT	\N	PRESENT	0
248931	247061	14331P	PARTICIPANT	\N	PRESENT	0
248932	247061	04071H	PARTICIPANT	\N	PRESENT	0
248933	247061	19545Y	PARTICIPANT	\N	PRESENT	0
248934	247061	01057W	PARTICIPANT	\N	PRESENT	0
248935	247061	19667J	PARTICIPANT	\N	PRESENT	0
248936	247061	11074Q	PRESIDENT	0	PRESENT	0
248937	247061	11070L	PARTICIPANT	\N	PRESENT	0
248938	247061	14225N	PARTICIPANT	\N	PRESENT	0
248939	247061	88008L	PARTICIPANT	\N	PRESENT	0
248940	247061	11110B	PARTICIPANT	\N	PRESENT	0
248941	247061	07029T	PARTICIPANT	\N	PRESENT	0
248942	247061	14085U	PARTICIPANT	\N	PRESENT	0
248943	247061	07004J	PARTICIPANT	\N	PRESENT	0
248944	247061	19349W	PARTICIPANT	\N	PRESENT	0
248945	247061	08010L	PARTICIPANT	\N	PRESENT	0
248946	247061	14253S	PARTICIPANT	\N	PRESENT	0
248947	247061	11048N	PARTICIPANT	\N	PRESENT	0
248948	247061	19479G	PARTICIPANT	\N	PRESENT	0
248949	247061	19711U	PARTICIPANT	\N	PRESENT	0
248950	247061	08034U	PARTICIPANT	\N	PRESENT	0
248951	247061	19531S	PARTICIPANT	\N	PRESENT	0
248952	247061	08069G	PARTICIPANT	\N	PRESENT	0
248953	247061	19687N	PARTICIPANT	\N	PRESENT	0
248954	247061	14159V	PARTICIPANT	\N	PRESENT	0
248955	247061	14173T	PARTICIPANT	\N	PRESENT	0
248956	247061	04086Q	PARTICIPANT	\N	PRESENT	0
248957	247061	11040E	PARTICIPANT	\N	PRESENT	0
248958	247061	14083S	PARTICIPANT	\N	PRESENT	0
248959	247061	11012A	PARTICIPANT	\N	PRESENT	0
248960	247061	19741B	PARTICIPANT	\N	PRESENT	0
248961	247061	14121F	PARTICIPANT	\N	PRESENT	0
248962	247061	99004R	PARTICIPANT	\N	PRESENT	0
248963	247145	19515S	PARTICIPANT	\N	PRESENT	0
248964	247145	01043Q	PARTICIPANT	\N	PRESENT	0
248965	247145	19565D	PARTICIPANT	\N	PRESENT	0
248966	247145	14357A	PARTICIPANT	\N	PRESENT	0
248967	247145	19441R	PARTICIPANT	\N	PRESENT	0
248968	247145	19413M	PARTICIPANT	\N	PRESENT	0
248969	247145	14081Q	PARTICIPANT	\N	PRESENT	0
248970	247145	80013X	PARTICIPANT	\N	PRESENT	0
248971	247145	19631V	PARTICIPANT	\N	PRESENT	0
248972	247145	11099A	PARTICIPANT	\N	PRESENT	0
248973	247145	08068F	PARTICIPANT	\N	PRESENT	0
248974	247145	04049K	PARTICIPANT	\N	PRESENT	0
248975	247145	19705W	PARTICIPANT	\N	PRESENT	0
248976	247145	19707Y	PARTICIPANT	\N	PRESENT	0
248977	247145	08015R	PARTICIPANT	\N	PRESENT	0
248978	247145	08019V	PARTICIPANT	\N	PRESENT	0
248979	247145	14197C	PARTICIPANT	\N	PRESENT	0
248980	247145	19369B	PARTICIPANT	\N	PRESENT	0
248981	247145	19511N	PARTICIPANT	\N	PRESENT	0
248982	247145	08028W	PARTICIPANT	\N	PRESENT	0
248983	247145	14265W	PARTICIPANT	\N	PRESENT	0
248984	247145	19591F	PARTICIPANT	\N	PRESENT	0
248985	247145	14135M	PARTICIPANT	\N	PRESENT	0
248986	247145	19467C	PARTICIPANT	\N	PRESENT	0
248987	247145	14187A	PARTICIPANT	\N	PRESENT	0
248988	247145	08038Y	PARTICIPANT	\N	PRESENT	0
248989	247145	08062Y	PARTICIPANT	\N	PRESENT	0
248990	247145	19301E	PARTICIPANT	\N	PRESENT	0
248991	247145	19695N	PARTICIPANT	\N	PRESENT	0
248992	247145	14033T	PARTICIPANT	\N	PRESENT	0
248993	247145	11090Q	PRESIDENT	0	PRESENT	0
248994	247145	01025N	PARTICIPANT	\N	PRESENT	0
248995	247145	19269X	PARTICIPANT	\N	PRESENT	0
248996	247145	14205J	PARTICIPANT	\N	PRESENT	0
248997	247145	04088S	PARTICIPANT	\N	PRESENT	0
248998	247145	11056N	PARTICIPANT	\N	PRESENT	0
248999	247145	04089T	PARTICIPANT	\N	PRESENT	0
249000	247145	14115H	PARTICIPANT	\N	PRESENT	0
249001	247145	19507S	PARTICIPANT	\N	PRESENT	0
249002	247145	19747H	PARTICIPANT	\N	PRESENT	0
249003	247145	14207L	PARTICIPANT	\N	PRESENT	0
249004	247145	04043D	PARTICIPANT	\N	PRESENT	0
249005	247145	19619A	PARTICIPANT	\N	PRESENT	0
249006	247145	17589D	PARTICIPANT	\N	PRESENT	0
249007	247145	14257W	PARTICIPANT	\N	PRESENT	0
249008	247145	11101A	PARTICIPANT	\N	EXCUSE	0
249009	247145	08021P	PARTICIPANT	\N	EXCUSE	0
249010	247145	11081P	PARTICIPANT	\N	EXCUSE	0
249011	248853	04070G	PRESIDENT	0	PRESENT	0
249012	248853	19699S	PARTICIPANT	\N	PRESENT	0
249013	248853	19533U	PARTICIPANT	\N	PRESENT	0
249014	248853	95015C	PARTICIPANT	\N	PRESENT	0
249015	248853	04033B	PARTICIPANT	\N	PRESENT	0
249016	248853	14229S	PARTICIPANT	\N	PRESENT	0
249017	248853	14241N	PARTICIPANT	\N	PRESENT	0
249018	248853	14039A	PARTICIPANT	\N	PRESENT	0
249019	248853	14107H	PARTICIPANT	\N	PRESENT	0
249020	248853	08017T	PARTICIPANT	\N	PRESENT	0
249022	248853	08012N	PARTICIPANT	\N	PRESENT	0
249023	248853	14249W	PARTICIPANT	\N	PRESENT	0
249024	248853	08039A	PARTICIPANT	\N	PRESENT	0
249025	248853	08031R	PARTICIPANT	\N	PRESENT	0
249026	248853	19593H	PARTICIPANT	\N	PRESENT	0
249027	248853	19643A	PARTICIPANT	\N	PRESENT	0
249028	248853	14059S	PARTICIPANT	\N	PRESENT	0
249029	248853	14061L	PARTICIPANT	\N	PRESENT	0
249030	248853	04057K	PARTICIPANT	\N	PRESENT	0
249031	248853	14073Q	PARTICIPANT	\N	PRESENT	0
249032	248853	19611R	PARTICIPANT	\N	PRESENT	0
249033	248853	08035V	PARTICIPANT	\N	PRESENT	0
249034	248853	08043V	PARTICIPANT	\N	PRESENT	0
249035	248853	19693L	PARTICIPANT	\N	PRESENT	0
249036	248853	87003B	PARTICIPANT	\N	PRESENT	0
249037	248853	19399H	PARTICIPANT	\N	PRESENT	0
249038	248853	14201E	PARTICIPANT	\N	PRESENT	0
249039	248853	14030Q	PARTICIPANT	\N	PRESENT	0
249040	248853	19731Y	PARTICIPANT	\N	PRESENT	0
249041	248853	14251Q	PARTICIPANT	\N	PRESENT	0
249042	248853	08020N	PARTICIPANT	\N	PRESENT	0
249043	248853	19735D	PARTICIPANT	\N	PRESENT	0
249044	248853	11109J	PARTICIPANT	\N	PRESENT	0
249045	248853	11083R	PARTICIPANT	\N	PRESENT	0
249046	248853	14109K	PARTICIPANT	\N	PRESENT	0
249047	248853	14063N	PARTICIPANT	\N	PRESENT	0
249048	248853	11104D	PARTICIPANT	\N	PRESENT	0
249049	248853	11043H	PARTICIPANT	\N	PRESENT	0
249050	248853	19749K	PARTICIPANT	\N	PRESENT	0
249051	248853	19621T	PARTICIPANT	\N	PRESENT	0
249052	248853	12041X	PARTICIPANT	\N	EXCUSE	0
249053	248852	04070G	PRESIDENT	0	PRESENT	0
249054	248852	19699S	PARTICIPANT	\N	PRESENT	0
249055	248852	19533U	PARTICIPANT	\N	PRESENT	0
249056	248852	95015C	PARTICIPANT	\N	PRESENT	0
249057	248852	04033B	PARTICIPANT	\N	PRESENT	0
249058	248852	19329S	PARTICIPANT	\N	PRESENT	0
249059	248852	14229S	PARTICIPANT	\N	PRESENT	0
249060	248852	14241N	PARTICIPANT	\N	PRESENT	0
249061	248852	14039A	PARTICIPANT	\N	PRESENT	0
249062	248852	14107H	PARTICIPANT	\N	PRESENT	0
249063	248852	08017T	PARTICIPANT	\N	PRESENT	0
249064	248852	92040Q	PARTICIPANT	\N	PRESENT	0
249065	248852	07033P	PARTICIPANT	\N	PRESENT	0
249066	248852	08012N	PARTICIPANT	\N	PRESENT	0
249067	248852	14249W	PARTICIPANT	\N	PRESENT	0
249068	248852	08039A	PARTICIPANT	\N	PRESENT	0
249069	248852	08031R	PARTICIPANT	\N	PRESENT	0
249070	248852	19593H	PARTICIPANT	\N	PRESENT	0
249071	248852	19643A	PARTICIPANT	\N	PRESENT	0
249072	248852	14059S	PARTICIPANT	\N	PRESENT	0
249073	248852	14061L	PARTICIPANT	\N	PRESENT	0
249074	248852	04057K	PARTICIPANT	\N	PRESENT	0
249075	248852	14073Q	PARTICIPANT	\N	PRESENT	0
249076	248852	19611R	PARTICIPANT	\N	PRESENT	0
249077	248852	08035V	PARTICIPANT	\N	PRESENT	0
249078	248852	08043V	PARTICIPANT	\N	PRESENT	0
249079	248852	19693L	PARTICIPANT	\N	PRESENT	0
249080	248852	87003B	PARTICIPANT	\N	PRESENT	0
249081	248852	19399H	PARTICIPANT	\N	PRESENT	0
249082	248852	14201E	PARTICIPANT	\N	PRESENT	0
249083	248852	14030Q	PARTICIPANT	\N	PRESENT	0
249084	248852	19731Y	PARTICIPANT	\N	PRESENT	0
249085	248852	14251Q	PARTICIPANT	\N	PRESENT	0
249086	248852	08020N	PARTICIPANT	\N	PRESENT	0
249087	248852	04059M	PARTICIPANT	\N	PRESENT	0
265639	263476	08060W	PARTICIPANT	\N	EXCUSE	0
265640	263476	19685L	PARTICIPANT	\N	EXCUSE	0
265641	263476	19599P	PARTICIPANT	\N	PRESENT	0
265642	263476	18083K	PARTICIPANT	\N	PRESENT	0
265643	263476	17583W	PARTICIPANT	\N	PRESENT	0
265644	263476	14051J	PARTICIPANT	\N	PRESENT	0
265645	263476	08009T	PRESIDENT	0	PRESENT	0
265646	263476	95062K	PARTICIPANT	\N	PRESENT	0
265647	263476	19739H	PARTICIPANT	\N	PRESENT	0
265648	263476	19745F	PARTICIPANT	\N	PRESENT	0
265649	263476	14221J	PARTICIPANT	\N	PRESENT	0
265650	263476	08055A	PARTICIPANT	\N	PRESENT	0
265651	263476	98023Q	PARTICIPANT	\N	PRESENT	0
265652	263476	14191V	PARTICIPANT	\N	PRESENT	0
265653	263476	19383Y	PARTICIPANT	\N	PRESENT	0
265654	263476	19333N	PARTICIPANT	\N	PRESENT	0
265655	263476	14219Q	PARTICIPANT	\N	PRESENT	0
265656	263476	19347U	PARTICIPANT	\N	PRESENT	0
265657	263476	19503N	PARTICIPANT	\N	PRESENT	0
265658	263476	19525U	PARTICIPANT	\N	PRESENT	0
265659	263476	14038Y	PARTICIPANT	\N	PRESENT	0
265660	263476	14157T	PARTICIPANT	\N	PRESENT	0
265661	263476	05012A	PARTICIPANT	\N	PRESENT	0
265662	263476	19637C	PARTICIPANT	\N	PRESENT	0
265663	263476	08024S	PARTICIPANT	\N	PRESENT	0
265664	263476	19713W	PARTICIPANT	\N	PRESENT	0
265665	263476	14031R	PARTICIPANT	\N	PRESENT	0
265666	263476	14029X	PARTICIPANT	\N	PRESENT	0
265667	263476	19733B	PARTICIPANT	\N	PRESENT	0
265668	263476	19737F	PARTICIPANT	\N	PRESENT	0
265669	263476	19701S	PARTICIPANT	\N	PRESENT	0
265670	263476	19681G	PARTICIPANT	\N	PRESENT	0
265672	263476	19549D	PARTICIPANT	\N	PRESENT	0
265673	263476	19551W	PARTICIPANT	\N	PRESENT	0
265674	263102	14327T	PARTICIPANT	\N	PRESENT	0
265675	263102	14331P	PARTICIPANT	\N	PRESENT	0
265676	263102	95041E	PARTICIPANT	\N	PRESENT	0
265677	263102	11074Q	PRESIDENT	0	PRESENT	0
265678	263102	89017R	PARTICIPANT	\N	PRESENT	0
265679	263102	88008L	PARTICIPANT	\N	PRESENT	0
265680	263102	19671E	PARTICIPANT	\N	PRESENT	0
265681	263102	11070L	PARTICIPANT	\N	PRESENT	0
265682	263102	14225N	PARTICIPANT	\N	PRESENT	0
265683	263102	07029T	PARTICIPANT	\N	PRESENT	0
265684	263102	14085U	PARTICIPANT	\N	PRESENT	0
265685	263102	07004J	PARTICIPANT	\N	PRESENT	0
265686	263102	19349W	PARTICIPANT	\N	PRESENT	0
265687	263102	08010L	PARTICIPANT	\N	PRESENT	0
265688	263102	19479G	PARTICIPANT	\N	PRESENT	0
265689	263102	11048N	PARTICIPANT	\N	PRESENT	0
265690	263102	19711U	PARTICIPANT	\N	PRESENT	0
265691	263102	19651A	PARTICIPANT	\N	PRESENT	0
265692	263102	08034U	PARTICIPANT	\N	PRESENT	0
265693	263102	08069G	PARTICIPANT	\N	PRESENT	0
265694	263102	19687N	PARTICIPANT	\N	PRESENT	0
265695	263102	12016W	PARTICIPANT	\N	PRESENT	0
265696	263102	08011M	PARTICIPANT	\N	PRESENT	0
265697	263102	08014Q	PARTICIPANT	\N	PRESENT	0
265698	263102	14159V	PARTICIPANT	\N	PRESENT	0
265699	263102	14173T	PARTICIPANT	\N	PRESENT	0
265700	263102	11040E	PARTICIPANT	\N	PRESENT	0
265701	263102	04086Q	PARTICIPANT	\N	PRESENT	0
265702	263102	14083S	PARTICIPANT	\N	PRESENT	0
265703	263102	14199E	PARTICIPANT	\N	PRESENT	0
265704	263102	11012A	PARTICIPANT	\N	PRESENT	0
265705	263102	08073C	PARTICIPANT	\N	PRESENT	0
265706	263102	14121F	PARTICIPANT	\N	PRESENT	0
265707	263102	19741B	PARTICIPANT	\N	PRESENT	0
265708	263102	99004R	PARTICIPANT	\N	PRESENT	0
265709	263102	14034U	PARTICIPANT	\N	EXCUSE	0
265718	263476	14169X	PARTICIPANT	\N	PRESENT	0
265724	263476	14103D	PARTICIPANT	\N	PRESENT	0
265736	263102	11053K	PARTICIPANT	\N	PRESENT	0
265737	263102	19647E	PARTICIPANT	\N	PRESENT	0
265738	263102	19689Q	PARTICIPANT	\N	PRESENT	0
265739	262943	19443T	PARTICIPANT	\N	PRESENT	0
265740	262943	95030B	PARTICIPANT	\N	PRESENT	0
265741	262943	11080N	PARTICIPANT	\N	PRESENT	0
265742	262943	04034C	PARTICIPANT	\N	PRESENT	0
265743	262943	04040A	PARTICIPANT	\N	PRESENT	0
265744	262943	14079W	PARTICIPANT	\N	PRESENT	0
265745	262943	01058X	PARTICIPANT	\N	PRESENT	0
265746	262943	11027H	PARTICIPANT	\N	PRESENT	0
265747	262943	16685X	PARTICIPANT	\N	PRESENT	0
265748	262943	04042C	PRESIDENT	0	PRESENT	0
265749	262943	11054L	PARTICIPANT	\N	PRESENT	0
265750	262943	11066Q	PARTICIPANT	\N	PRESENT	0
265751	262943	08056B	PARTICIPANT	\N	PRESENT	0
265752	262943	95037J	PARTICIPANT	\N	PRESENT	0
265753	262943	11115U	PARTICIPANT	\N	PRESENT	0
265754	262943	14055N	PARTICIPANT	\N	PRESENT	0
265755	262943	19421M	PARTICIPANT	\N	PRESENT	0
265756	262943	19709B	PARTICIPANT	\N	PRESENT	0
265757	262943	08053X	PARTICIPANT	\N	PRESENT	0
265758	262943	97011G	PARTICIPANT	\N	PRESENT	0
265759	262943	08061X	PARTICIPANT	\N	PRESENT	0
265760	262943	08047A	PARTICIPANT	\N	PRESENT	0
265761	262943	98029W	PARTICIPANT	\N	PRESENT	0
265762	262943	14097Y	PARTICIPANT	\N	PRESENT	0
265763	262943	04035D	PARTICIPANT	\N	PRESENT	0
265788	263102	04071H	PARTICIPANT	\N	PRESENT	0
265765	262943	01062T	PARTICIPANT	\N	PRESENT	0
265766	262943	11041F	PARTICIPANT	\N	PRESENT	0
265767	262943	14235Q	PARTICIPANT	\N	PRESENT	0
265768	262943	08058D	PARTICIPANT	\N	PRESENT	0
265769	262943	19251M	PARTICIPANT	\N	PRESENT	0
265770	262943	14028W	PARTICIPANT	\N	PRESENT	0
265771	262943	19721W	PARTICIPANT	\N	PRESENT	0
265772	262943	14105F	PARTICIPANT	\N	PRESENT	0
265773	262943	98018T	PARTICIPANT	\N	PRESENT	0
265774	262943	98022P	PARTICIPANT	\N	PRESENT	0
265775	262943	14267Y	PARTICIPANT	\N	PRESENT	0
265776	262943	11064N	PARTICIPANT	\N	PRESENT	0
265777	262943	98050T	PARTICIPANT	\N	PRESENT	0
265778	262943	14211G	PARTICIPANT	\N	PRESENT	0
265779	262943	19583F	PARTICIPANT	\N	PRESENT	0
265780	262943	14255U	PARTICIPANT	\N	PRESENT	0
265786	263476	02002K	PARTICIPANT	\N	PRESENT	0
265787	263476	19387D	PARTICIPANT	\N	PRESENT	0
265790	263102	01057W	PARTICIPANT	\N	PRESENT	0
265791	263102	19667J	PARTICIPANT	\N	PRESENT	0
265793	265789	19593H	PARTICIPANT	\N	PRESENT	0
265794	265789	04070G	PRESIDENT	0	PRESENT	0
265795	265789	19699S	PARTICIPANT	\N	PRESENT	0
265796	265789	19611R	PARTICIPANT	\N	PRESENT	0
265797	265789	19693L	PARTICIPANT	\N	PRESENT	0
265798	265789	87003B	PARTICIPANT	\N	PRESENT	0
265799	265789	14030Q	PARTICIPANT	\N	PRESENT	0
265800	265789	14241N	PARTICIPANT	\N	PRESENT	0
265801	265789	19731Y	PARTICIPANT	\N	PRESENT	0
265802	265789	11083R	PARTICIPANT	\N	PRESENT	0
265803	265789	07033P	PARTICIPANT	\N	PRESENT	0
265804	265789	14123H	PARTICIPANT	\N	PRESENT	0
265805	265789	19749K	PARTICIPANT	\N	PRESENT	0
265806	265789	04018C	PARTICIPANT	\N	PRESENT	0
265807	265789	08039A	PARTICIPANT	\N	PRESENT	0
265808	265789	14061L	PARTICIPANT	\N	EXCUSE	0
265809	265789	04057K	PARTICIPANT	\N	EXCUSE	0
265810	265789	14073Q	PARTICIPANT	\N	EXCUSE	0
265811	265789	08016S	PARTICIPANT	\N	EXCUSE	0
265812	265789	14249W	PARTICIPANT	\N	EXCUSE	0
265813	262945	19443T	PARTICIPANT	\N	PRESENT	0
265814	262945	95030B	PARTICIPANT	\N	PRESENT	0
265815	262945	11080N	PARTICIPANT	\N	PRESENT	0
265816	262945	04034C	PARTICIPANT	\N	PRESENT	0
265817	262945	04040A	PARTICIPANT	\N	PRESENT	0
265818	262945	14079W	PARTICIPANT	\N	PRESENT	0
265819	262945	01058X	PARTICIPANT	\N	PRESENT	0
265820	262945	11027H	PARTICIPANT	\N	PRESENT	0
265821	262945	16685X	PARTICIPANT	\N	PRESENT	0
265822	262945	04042C	PRESIDENT	0	PRESENT	0
265823	262945	11054L	PARTICIPANT	\N	PRESENT	0
265824	262945	11066Q	PARTICIPANT	\N	PRESENT	0
265825	262945	08056B	PARTICIPANT	\N	PRESENT	0
265826	262945	95037J	PARTICIPANT	\N	PRESENT	0
265827	262945	14055N	PARTICIPANT	\N	PRESENT	0
265828	262945	19421M	PARTICIPANT	\N	PRESENT	0
265829	262945	19709B	PARTICIPANT	\N	PRESENT	0
265830	262945	08053X	PARTICIPANT	\N	PRESENT	0
265831	262945	97011G	PARTICIPANT	\N	PRESENT	0
265832	262945	08061X	PARTICIPANT	\N	PRESENT	0
265833	262945	08047A	PARTICIPANT	\N	PRESENT	0
265834	262945	98029W	PARTICIPANT	\N	PRESENT	0
265835	262945	14097Y	PARTICIPANT	\N	PRESENT	0
265836	262945	04035D	PARTICIPANT	\N	PRESENT	0
265837	262945	01062T	PARTICIPANT	\N	PRESENT	0
265838	262945	11041F	PARTICIPANT	\N	PRESENT	0
265839	262945	14235Q	PARTICIPANT	\N	PRESENT	0
265840	262945	08058D	PARTICIPANT	\N	PRESENT	0
247105	247102	04049K	PARTICIPANT	\N	PRESENT	0
247439	247284	14257W	PARTICIPANT	\N	PRESENT	0
247440	247284	19669L	PARTICIPANT	\N	PRESENT	0
247441	247284	19667J	PARTICIPANT	\N	PRESENT	0
247442	247284	19565D	PARTICIPANT	\N	PRESENT	0
247443	247284	11033F	PARTICIPANT	\N	PRESENT	0
247444	247284	19593H	PARTICIPANT	\N	PRESENT	0
247445	247284	19447X	PARTICIPANT	\N	PRESENT	0
247446	247284	19563B	PARTICIPANT	\N	PRESENT	0
247447	247284	11040E	PARTICIPANT	\N	PRESENT	0
247448	247284	14133K	PARTICIPANT	\N	PRESENT	0
247449	247284	19637C	PARTICIPANT	\N	PRESENT	0
247450	247284	14119M	PARTICIPANT	\N	PRESENT	0
247451	247284	14241N	PARTICIPANT	\N	PRESENT	0
247452	247284	14261S	PARTICIPANT	\N	PRESENT	0
247453	247284	14038Y	PARTICIPANT	\N	PRESENT	0
247454	247284	88008L	PARTICIPANT	\N	PRESENT	0
247455	247284	19253P	PARTICIPANT	\N	PRESENT	0
247456	247284	11065P	PARTICIPANT	\N	PRESENT	0
247457	247284	19723Y	PARTICIPANT	\N	PRESENT	0
247458	247284	19507S	PARTICIPANT	\N	PRESENT	0
247459	247284	98022P	PARTICIPANT	\N	PRESENT	0
247460	247284	19553Y	PARTICIPANT	\N	PRESENT	0
247461	247284	19467C	PARTICIPANT	\N	PRESENT	0
247462	247284	11099A	PARTICIPANT	\N	PRESENT	0
247463	247284	18083K	PARTICIPANT	\N	PRESENT	0
247464	247284	08031R	PARTICIPANT	\N	PRESENT	0
247465	247284	19289C	PARTICIPANT	\N	PRESENT	0
247466	247284	11012A	PARTICIPANT	\N	PRESENT	0
247467	247284	08049C	PARTICIPANT	\N	PRESENT	0
247468	247284	19347U	PARTICIPANT	\N	PRESENT	0
247469	247284	14033T	PARTICIPANT	\N	PRESENT	0
247470	247284	04057K	PARTICIPANT	\N	PRESENT	0
247471	247284	14111D	PARTICIPANT	\N	PRESENT	0
247472	247284	19443T	PARTICIPANT	\N	PRESENT	0
247473	247284	11045K	PARTICIPANT	\N	PRESENT	0
247474	247284	14029X	PARTICIPANT	\N	PRESENT	0
247475	247284	19709B	PARTICIPANT	\N	PRESENT	0
247476	247284	19663E	PARTICIPANT	\N	PRESENT	0
247477	247284	08061X	PARTICIPANT	\N	PRESENT	0
247478	247284	01060R	PARTICIPANT	\N	PRESENT	0
247479	247284	04088S	PARTICIPANT	\N	PRESENT	0
247480	247284	14041T	PARTICIPANT	\N	PRESENT	0
247481	247284	92040Q	PARTICIPANT	\N	PRESENT	0
247482	247284	14071N	PARTICIPANT	\N	PRESENT	0
247483	247284	10015M	PARTICIPANT	\N	PRESENT	0
247484	247284	19745F	PARTICIPANT	\N	PRESENT	0
247486	247284	14231L	PARTICIPANT	\N	PRESENT	0
247487	247284	01034P	PARTICIPANT	\N	PRESENT	0
247488	247284	19369B	PARTICIPANT	\N	PRESENT	0
247489	247284	19511N	PARTICIPANT	\N	PRESENT	0
247490	247284	95067Q	PARTICIPANT	\N	PRESENT	0
247491	247284	19735D	PARTICIPANT	\N	PRESENT	0
247493	247284	11090Q	PARTICIPANT	\N	PRESENT	0
247494	247284	19737F	PARTICIPANT	\N	PRESENT	0
247496	247284	19721W	PARTICIPANT	\N	PRESENT	0
247497	247284	19569H	PARTICIPANT	\N	PRESENT	0
247498	247284	16685X	PARTICIPANT	\N	PRESENT	0
247500	247284	14083S	PARTICIPANT	\N	PRESENT	0
247501	247284	14253S	PARTICIPANT	\N	PRESENT	0
247502	247284	19713W	PARTICIPANT	\N	PRESENT	0
247504	247284	98023Q	PARTICIPANT	\N	PRESENT	0
247505	247284	19335Q	PARTICIPANT	\N	PRESENT	0
247506	247284	19739H	PARTICIPANT	\N	PRESENT	0
247507	247284	14221J	PARTICIPANT	\N	PRESENT	0
248015	247958	14083S	PARTICIPANT	\N	PRESENT	0
248792	247319	14205J	PARTICIPANT	\N	PRESENT	0
248793	247319	19703U	PARTICIPANT	\N	PRESENT	0
248794	247319	04071H	PARTICIPANT	\N	PRESENT	0
248795	247319	19729F	PARTICIPANT	\N	PRESENT	0
248796	247319	19443T	PARTICIPANT	\N	PRESENT	0
248797	247319	14111D	PARTICIPANT	\N	PRESENT	0
248798	247319	08035V	PARTICIPANT	\N	PRESENT	0
248799	247319	08058D	PRESIDENT	0	PRESENT	0
248800	247319	19251M	PARTICIPANT	\N	PRESENT	0
248801	247319	11049P	PARTICIPANT	\N	PRESENT	0
248802	247319	19721W	PARTICIPANT	\N	PRESENT	0
248803	247319	14097Y	PARTICIPANT	\N	EXCUSE	0
248804	240297	04086Q	PARTICIPANT	\N	PRESENT	0
248805	240297	04070G	PARTICIPANT	\N	PRESENT	0
248806	240297	12041X	PARTICIPANT	\N	PRESENT	0
248807	240297	19593H	PARTICIPANT	\N	PRESENT	0
248808	240297	08043V	PARTICIPANT	\N	PRESENT	0
248809	240297	12016W	PARTICIPANT	\N	PRESENT	0
248810	240297	14229S	PARTICIPANT	\N	PRESENT	0
248811	240297	19643A	PARTICIPANT	\N	PRESENT	0
248812	240297	14241N	PARTICIPANT	\N	PRESENT	0
248813	240297	19693L	PARTICIPANT	\N	PRESENT	0
248814	240297	11083R	PARTICIPANT	\N	PRESENT	0
248815	240297	04057K	PARTICIPANT	\N	PRESENT	0
248816	240297	19713W	PARTICIPANT	\N	PRESENT	0
248817	240297	01025N	PARTICIPANT	\N	PRESENT	0
248818	240297	19447X	PARTICIPANT	\N	PRESENT	0
248819	240297	19611R	PARTICIPANT	\N	PRESENT	0
248820	240297	19691J	PARTICIPANT	\N	PRESENT	0
248821	240297	19467C	PARTICIPANT	\N	PRESENT	0
248822	240297	19749K	PARTICIPANT	\N	PRESENT	0
248823	240297	19399H	PARTICIPANT	\N	PRESENT	0
248824	240297	08039A	PARTICIPANT	\N	PRESENT	0
248825	240297	99004R	PARTICIPANT	\N	PRESENT	0
248826	240297	04018C	PARTICIPANT	\N	PRESENT	0
248827	240297	19387D	PARTICIPANT	\N	PRESENT	0
248828	240297	04059M	PARTICIPANT	\N	PRESENT	0
248829	240297	08017T	PARTICIPANT	\N	PRESENT	0
248830	240297	19699S	PARTICIPANT	\N	PRESENT	0
248831	240297	19733B	PARTICIPANT	\N	PRESENT	0
248832	240297	14265W	PARTICIPANT	\N	PRESENT	0
248833	240297	04035D	PARTICIPANT	\N	PRESENT	0
248834	240297	11043H	PARTICIPANT	\N	PRESENT	0
248835	240297	95030B	PARTICIPANT	\N	PRESENT	0
248836	240297	14357A	PARTICIPANT	\N	PRESENT	0
248837	240297	08031R	PARTICIPANT	\N	PRESENT	0
248838	240297	19507S	PARTICIPANT	\N	PRESENT	0
248839	240297	19383Y	PARTICIPANT	\N	PRESENT	0
248840	240297	14034U	PARTICIPANT	\N	PRESENT	0
248841	240297	14033T	PARTICIPANT	\N	PRESENT	0
248842	240297	14059S	PARTICIPANT	\N	PRESENT	0
248843	240297	02002K	PARTICIPANT	\N	PRESENT	0
248844	240297	07029T	PARTICIPANT	\N	PRESENT	0
249159	249158	19631V	PARTICIPANT	\N	PRESENT	0
249160	249158	19515S	PARTICIPANT	\N	PRESENT	0
249161	249158	19747H	PARTICIPANT	\N	PRESENT	0
249162	249158	08028W	PARTICIPANT	\N	PRESENT	0
249163	249158	19467C	PARTICIPANT	\N	PRESENT	0
249164	249158	17589D	PARTICIPANT	\N	PRESENT	0
249206	249158	14197C	PARTICIPANT	\N	PRESENT	0
249207	249158	14187A	PARTICIPANT	\N	PRESENT	0
249208	249158	01025N	PARTICIPANT	\N	PRESENT	0
249209	249158	04049K	PARTICIPANT	\N	PRESENT	0
249210	249158	19441R	PARTICIPANT	\N	PRESENT	0
249211	249158	19369B	PARTICIPANT	\N	PRESENT	0
249212	249158	14265W	PARTICIPANT	\N	PRESENT	0
249213	249158	04088S	PARTICIPANT	\N	PRESENT	0
249214	249158	14135M	PARTICIPANT	\N	PRESENT	0
249215	249158	19269X	PARTICIPANT	\N	PRESENT	0
249216	249158	19705W	PARTICIPANT	\N	PRESENT	0
249311	247145	14329V	PARTICIPANT	\N	EXCUSE	0
249312	247146	11081P	PARTICIPANT	\N	EXCUSE	0
249313	247146	14329V	PARTICIPANT	\N	EXCUSE	0
249314	247146	11101A	PARTICIPANT	\N	EXCUSE	0
249315	247146	04092N	PARTICIPANT	\N	PRESENT	0
249364	247146	14261S	PARTICIPANT	\N	PRESENT	0
249365	247146	19717B	PARTICIPANT	\N	PRESENT	0
249366	247146	19575F	PARTICIPANT	\N	PRESENT	0
249367	247146	11103C	PARTICIPANT	\N	PRESENT	0
249368	247146	14195A	PARTICIPANT	\N	PRESENT	0
249369	247146	08052W	PARTICIPANT	\N	PRESENT	0
249370	247146	14217N	PARTICIPANT	\N	PRESENT	0
249371	247146	14042U	PARTICIPANT	\N	PRESENT	0
249372	247146	14281W	PARTICIPANT	\N	PRESENT	0
249374	247146	19727D	PARTICIPANT	\N	PRESENT	0
249375	247146	14213J	PARTICIPANT	\N	PRESENT	0
249377	247146	19715Y	PARTICIPANT	\N	PRESENT	0
249379	247146	19723Y	PARTICIPANT	\N	PRESENT	0
249381	247146	17779H	PARTICIPANT	\N	PRESENT	0
249382	247146	11067R	PARTICIPANT	\N	PRESENT	0
249385	247146	14223L	PARTICIPANT	\N	PRESENT	0
249388	247146	14119M	PARTICIPANT	\N	PRESENT	0
249389	247146	19679N	PARTICIPANT	\N	PRESENT	0
249390	247146	11045K	PARTICIPANT	\N	PRESENT	0
249391	247146	04045F	PARTICIPANT	\N	PRESENT	0
249393	247146	19703U	PARTICIPANT	\N	PRESENT	0
249449	248851	14261S	PARTICIPANT	\N	PRESENT	0
249397	247146	19527W	PARTICIPANT	\N	PRESENT	0
249448	248851	14239U	PARTICIPANT	\N	EXCUSE	0
249450	248851	19717B	PARTICIPANT	\N	PRESENT	0
249451	248851	19575F	PARTICIPANT	\N	PRESENT	0
249452	248851	19367Y	PARTICIPANT	\N	EXCUSE	0
249453	248851	11103C	PARTICIPANT	\N	PRESENT	0
267438	267437	19621T	PARTICIPANT	\N	PRESENT	0
267439	267437	08031R	PARTICIPANT	\N	PRESENT	0
267440	267437	19573D	PARTICIPANT	\N	PRESENT	0
267442	267441	19621T	PARTICIPANT	\N	PRESENT	0
267443	267441	08031R	PARTICIPANT	\N	PRESENT	0
267445	267444	04070G	PARTICIPANT	\N	PRESENT	0
267447	267446	04070G	PARTICIPANT	\N	PRESENT	0
267450	267449	04070G	PARTICIPANT	\N	PRESENT	0
267458	267457	04070G	PARTICIPANT	\N	PRESENT	0
267460	267459	04070G	PARTICIPANT	\N	PRESENT	0
267462	267461	04070G	PARTICIPANT	\N	PRESENT	0
267495	267494	86034E	PARTICIPANT	\N	PRESENT	0
267496	267494	19525U	PARTICIPANT	\N	PRESENT	0
267497	267494	04042C	PARTICIPANT	\N	PRESENT	0
267498	267494	19583F	PARTICIPANT	\N	PRESENT	0
267499	267494	14041T	PARTICIPANT	\N	PRESENT	0
267500	267494	19659J	PARTICIPANT	\N	PRESENT	0
267501	267494	12041X	PARTICIPANT	\N	PRESENT	0
267502	267494	19593H	PARTICIPANT	\N	PRESENT	0
267503	267494	19387D	PARTICIPANT	\N	PRESENT	0
267504	267494	04085P	PARTICIPANT	\N	PRESENT	0
267505	267494	07034Q	PARTICIPANT	\N	PRESENT	0
267506	267494	11097X	PARTICIPANT	\N	PRESENT	0
267507	267494	08049C	PARTICIPANT	\N	PRESENT	0
267508	267494	08028W	PARTICIPANT	\N	PRESENT	0
267509	267494	99004R	PARTICIPANT	\N	PRESENT	0
267510	267494	11080N	PARTICIPANT	\N	PRESENT	0
267511	267494	95041E	PARTICIPANT	\N	PRESENT	0
267512	267494	19441R	PARTICIPANT	\N	PRESENT	0
267513	267494	19707Y	PARTICIPANT	\N	PRESENT	0
267514	267494	19705W	PARTICIPANT	\N	PRESENT	0
267515	267494	19741B	PARTICIPANT	\N	PRESENT	0
267516	267494	14219Q	PARTICIPANT	\N	PRESENT	0
267517	267494	19349W	PARTICIPANT	\N	PRESENT	0
267518	267494	19637C	PARTICIPANT	\N	PRESENT	0
267519	267494	19621T	PARTICIPANT	\N	PRESENT	0
267520	267494	08052W	PARTICIPANT	\N	PRESENT	0
267521	267494	17589D	PARTICIPANT	\N	PRESENT	0
267522	267494	14085U	PARTICIPANT	\N	PRESENT	0
267523	267494	11109J	PARTICIPANT	\N	PRESENT	0
267524	267494	19295A	PARTICIPANT	\N	PRESENT	0
267525	267494	19489J	PARTICIPANT	\N	PRESENT	0
267526	267494	17779H	PARTICIPANT	\N	PRESENT	0
267527	267494	01048V	PARTICIPANT	\N	PRESENT	0
267528	267494	14265W	PARTICIPANT	\N	PRESENT	0
267529	267494	11110B	PARTICIPANT	\N	PRESENT	0
267530	267494	08016S	PARTICIPANT	\N	PRESENT	0
267531	267494	08045X	PARTICIPANT	\N	PRESENT	0
267532	267494	11033F	PARTICIPANT	\N	PRESENT	0
267533	267494	11040E	PARTICIPANT	\N	PRESENT	0
267534	267494	19687N	PARTICIPANT	\N	PRESENT	0
267535	267494	19695N	PARTICIPANT	\N	PRESENT	0
267536	267494	12016W	PARTICIPANT	\N	PRESENT	0
267537	267494	19649G	PARTICIPANT	\N	PRESENT	0
267538	267494	19683J	PARTICIPANT	\N	PRESENT	0
267539	267494	19591F	PARTICIPANT	\N	PRESENT	0
267540	267494	19689Q	PARTICIPANT	\N	PRESENT	0
267541	267494	08068F	PARTICIPANT	\N	PRESENT	0
267542	267494	01028R	PARTICIPANT	\N	PRESENT	0
267543	267494	04059M	PARTICIPANT	\N	PRESENT	0
267544	267494	11027H	PARTICIPANT	\N	PRESENT	0
267545	267494	14121F	PARTICIPANT	\N	PRESENT	0
267546	267494	11026G	PARTICIPANT	\N	PRESENT	0
267547	267494	19669L	PARTICIPANT	\N	PRESENT	0
267548	267494	08017T	PARTICIPANT	\N	PRESENT	0
267549	267494	19333N	PARTICIPANT	\N	PRESENT	0
267550	267494	14281W	PARTICIPANT	\N	PRESENT	0
267551	267494	14028W	PARTICIPANT	\N	PRESENT	0
267552	267494	19527W	PARTICIPANT	\N	PRESENT	0
267553	267494	14001X	PARTICIPANT	\N	PRESENT	0
267554	267494	14021P	PARTICIPANT	\N	PRESENT	0
267555	267494	14151M	PARTICIPANT	\N	PRESENT	0
267556	267494	11072N	PARTICIPANT	\N	PRESENT	0
267557	267494	19697Q	PARTICIPANT	\N	PRESENT	0
267558	267494	19651A	PARTICIPANT	\N	PRESENT	0
267559	267494	19543W	PARTICIPANT	\N	PRESENT	0
267560	267494	04034C	PARTICIPANT	\N	PRESENT	0
267561	267494	04045F	PARTICIPANT	\N	PRESENT	0
267562	267494	14055N	PARTICIPANT	\N	PRESENT	0
267563	267494	08061X	PARTICIPANT	\N	PRESENT	0
267564	267494	08073C	PARTICIPANT	\N	PRESENT	0
267565	267494	19289C	PARTICIPANT	\N	PRESENT	0
267566	267494	11099A	PARTICIPANT	\N	PRESENT	0
267567	267494	19647E	PARTICIPANT	\N	PRESENT	0
267568	267494	19301E	PARTICIPANT	\N	PRESENT	0
267569	267494	19253P	PARTICIPANT	\N	PRESENT	0
267570	267494	11012A	PARTICIPANT	\N	PRESENT	0
267571	267494	19717B	PARTICIPANT	\N	PRESENT	0
267572	267494	04057K	PARTICIPANT	\N	PRESENT	0
267573	267494	14093U	PARTICIPANT	\N	PRESENT	0
267574	267494	14251Q	PARTICIPANT	\N	PRESENT	0
267575	267494	11064N	PARTICIPANT	\N	PRESENT	0
267576	267494	11085T	PARTICIPANT	\N	PRESENT	0
267577	267494	11070L	PARTICIPANT	\N	PRESENT	0
267578	267494	11053K	PARTICIPANT	\N	PRESENT	0
267579	267494	19369B	PARTICIPANT	\N	PRESENT	0
267580	267494	19739H	PARTICIPANT	\N	PRESENT	0
267581	267494	08056B	PARTICIPANT	\N	PRESENT	0
267582	267494	19713W	PARTICIPANT	\N	PRESENT	0
267583	267494	19749K	PARTICIPANT	\N	PRESENT	0
267584	267494	04040A	PARTICIPANT	\N	PRESENT	0
267585	267494	07004J	PARTICIPANT	\N	PRESENT	0
267586	267494	98018T	PARTICIPANT	\N	PRESENT	0
267587	267494	19421M	PARTICIPANT	\N	PRESENT	0
267588	267494	01058X	PARTICIPANT	\N	PRESENT	0
267589	267494	19581D	PARTICIPANT	\N	PRESENT	0
267590	267494	14059S	PARTICIPANT	\N	PRESENT	0
267591	267494	14357A	PARTICIPANT	\N	PRESENT	0
267592	267494	98050T	PARTICIPANT	\N	PRESENT	0
267593	267494	98023Q	PARTICIPANT	\N	PRESENT	0
267594	267494	11103C	PARTICIPANT	\N	PRESENT	0
267595	267494	96004D	PARTICIPANT	\N	PRESENT	0
267596	267494	08069G	PARTICIPANT	\N	PRESENT	0
267597	267494	04033B	PARTICIPANT	\N	PRESENT	0
267598	267494	04071H	PARTICIPANT	\N	PRESENT	0
267599	267494	19643A	PARTICIPANT	\N	PRESENT	0
267600	267494	19515S	PARTICIPANT	\N	PRESENT	0
267601	267494	14033T	PARTICIPANT	\N	PRESENT	0
267602	267494	19399H	PARTICIPANT	\N	PRESENT	0
267603	267494	08019V	PARTICIPANT	\N	PRESENT	0
267604	267494	19663E	PARTICIPANT	\N	PRESENT	0
267605	267494	11049P	PARTICIPANT	\N	PRESENT	0
267606	267494	04035D	PARTICIPANT	\N	PRESENT	0
267610	267494	98029W	PARTICIPANT	\N	PRESENT	0
267608	267494	14211G	PARTICIPANT	\N	PRESENT	0
267609	267494	11074Q	PARTICIPANT	\N	PRESENT	0
267611	267494	14179A	PARTICIPANT	\N	PRESENT	0
267612	267494	95063L	PARTICIPANT	\N	PRESENT	0
267613	267494	11054L	PARTICIPANT	\N	PRESENT	0
267614	267494	04070G	PARTICIPANT	\N	PRESENT	0
267615	267494	19733B	PARTICIPANT	\N	PRESENT	0
267616	267494	11090Q	PARTICIPANT	\N	PRESENT	0
267617	267494	04043D	PARTICIPANT	\N	PRESENT	0
267620	267494	14107H	PARTICIPANT	\N	PRESENT	0
267621	267494	19629C	PARTICIPANT	\N	PRESENT	0
267622	267494	08060W	PARTICIPANT	\N	PRESENT	0
267623	267494	11045K	PARTICIPANT	\N	PRESENT	0
267624	267494	07033P	PARTICIPANT	\N	PRESENT	0
267627	267494	11048N	PARTICIPANT	\N	PRESENT	0
267628	267494	01024M	PARTICIPANT	\N	PRESENT	0
267881	263168	14026U	PARTICIPANT	\N	PRESENT	0
267882	263168	19301E	PARTICIPANT	\N	PRESENT	0
267883	263168	19563B	PARTICIPANT	\N	PRESENT	0
267884	263168	14201E	PARTICIPANT	\N	PRESENT	0
267885	263168	19253P	PARTICIPANT	\N	PRESENT	0
267886	263168	08052W	PARTICIPANT	\N	PRESENT	0
267887	267024	14169X	PARTICIPANT	\N	PRESENT	0
267933	263168	04044E	PARTICIPANT	\N	PRESENT	0
267939	267664	14038Y	PARTICIPANT	\N	PRESENT	0
267943	267664	19383Y	PARTICIPANT	\N	PRESENT	0
267944	267664	19701S	PARTICIPANT	\N	PRESENT	0
267945	267664	14187A	PARTICIPANT	\N	PRESENT	0
267953	267664	14357A	PARTICIPANT	\N	PRESENT	0
267954	267664	19347U	PARTICIPANT	\N	PRESENT	0
267955	267664	14207L	PARTICIPANT	\N	PRESENT	0
268022	263168	14105F	PARTICIPANT	\N	PRESENT	0
268023	263168	14073Q	PARTICIPANT	\N	PRESENT	0
268024	263168	14229S	PARTICIPANT	\N	PRESENT	0
268025	263168	19369B	PARTICIPANT	\N	PRESENT	0
268026	263168	14173T	PARTICIPANT	\N	PRESENT	0
268027	263168	11049P	PARTICIPANT	\N	PRESENT	0
268028	263168	08028W	PARTICIPANT	\N	PRESENT	0
268029	263168	14197C	PARTICIPANT	\N	PRESENT	0
268030	263168	14249W	PARTICIPANT	\N	PRESENT	0
268037	263168	14133K	PARTICIPANT	\N	PRESENT	0
268038	263168	19569H	PARTICIPANT	\N	PRESENT	0
268039	263168	19413M	PARTICIPANT	\N	PRESENT	0
268040	263168	95067Q	PARTICIPANT	\N	PRESENT	0
240942	240941	14065Q	PARTICIPANT	\N	PRESENT	0
240943	240941	10015M	PARTICIPANT	\N	PRESENT	0
240976	240939	14115H	PARTICIPANT	\N	PRESENT	0
240977	240939	14030Q	PRESIDENT	0	PRESENT	0
240978	240939	08043V	PARTICIPANT	\N	PRESENT	0
240979	240939	19643A	PARTICIPANT	\N	PRESENT	0
240980	240939	19621T	PARTICIPANT	\N	PRESENT	0
240982	240939	08020N	PARTICIPANT	\N	PRESENT	0
240983	240939	19701S	PARTICIPANT	\N	PRESENT	0
240984	240939	19693L	PARTICIPANT	\N	PRESENT	0
240985	240939	08031R	PARTICIPANT	\N	PRESENT	0
240986	240939	07029T	PARTICIPANT	\N	PRESENT	0
240987	240939	19697Q	PARTICIPANT	\N	PRESENT	0
240988	240939	14109K	PARTICIPANT	\N	PRESENT	0
240989	240939	19679N	PARTICIPANT	\N	PRESENT	0
240990	240939	19269X	PARTICIPANT	\N	PRESENT	0
240991	240939	11045K	PARTICIPANT	\N	PRESENT	0
240994	240939	19731Y	PARTICIPANT	\N	PRESENT	0
240996	240939	14217N	PARTICIPANT	\N	EXCUSE	0
240997	240939	19599P	PARTICIPANT	\N	EXCUSE	0
240998	240939	01043Q	PARTICIPANT	\N	EXCUSE	0
241334	241278	08020N	PARTICIPANT	\N	PRESENT	0
245567	245565	04097T	PARTICIPANT	\N	PRESENT	0
245566	245565	11083R	PARTICIPANT	\N	PRESENT	0
245568	245565	14097Y	PARTICIPANT	\N	PRESENT	0
245569	245565	04057K	PARTICIPANT	\N	PRESENT	0
245570	245565	14237S	PARTICIPANT	\N	PRESENT	0
245571	245565	14331P	PARTICIPANT	\N	PRESENT	0
245572	245565	14225N	PARTICIPANT	\N	PRESENT	0
248855	248850	19697Q	PARTICIPANT	\N	PRESENT	0
248856	248850	11067R	PARTICIPANT	\N	PRESENT	0
248857	248850	11077T	PARTICIPANT	\N	PRESENT	0
248858	248850	14355X	PARTICIPANT	\N	PRESENT	0
248859	248850	19569H	PARTICIPANT	\N	PRESENT	0
248860	248850	11097X	PARTICIPANT	\N	PRESENT	0
248861	248850	14223L	PARTICIPANT	\N	PRESENT	0
248862	248850	14026U	PARTICIPANT	\N	PRESENT	0
248863	248850	14227Q	PARTICIPANT	\N	PRESENT	0
248864	248850	11063M	PARTICIPANT	\N	PRESENT	0
248865	248850	17779H	PARTICIPANT	\N	PRESENT	0
248866	248850	19703U	PARTICIPANT	\N	PRESENT	0
248867	248850	14239U	PARTICIPANT	\N	PRESENT	0
248868	248850	19553Y	PARTICIPANT	\N	PRESENT	0
248869	248850	11031D	PARTICIPANT	\N	PRESENT	0
248870	248850	14087W	PARTICIPANT	\N	PRESENT	0
248871	248850	14281W	PARTICIPANT	\N	PRESENT	0
248872	248850	19679N	PARTICIPANT	\N	PRESENT	0
248873	248850	14042U	PARTICIPANT	\N	PRESENT	0
248874	248850	19575F	PARTICIPANT	\N	PRESENT	0
248875	248850	14195A	PARTICIPANT	\N	PRESENT	0
248876	248850	14213J	PARTICIPANT	\N	PRESENT	0
248877	248850	14217N	PARTICIPANT	\N	PRESENT	0
248878	248850	14261S	PARTICIPANT	\N	PRESENT	0
248879	248850	19335Q	PARTICIPANT	\N	PRESENT	0
248880	248850	10006L	PARTICIPANT	\N	PRESENT	0
248881	248850	98024R	PARTICIPANT	\N	PRESENT	0
248882	248850	19521Q	PARTICIPANT	\N	PRESENT	0
248883	248850	19527W	PARTICIPANT	\N	PRESENT	0
248884	248850	01034P	PARTICIPANT	\N	PRESENT	0
248885	248850	04092N	PARTICIPANT	\N	PRESENT	0
248886	248850	11045K	PARTICIPANT	\N	PRESENT	0
248887	248850	08052W	PARTICIPANT	\N	PRESENT	0
248888	248850	19691J	PARTICIPANT	\N	PRESENT	0
248889	248850	19717B	PARTICIPANT	\N	PRESENT	0
248890	248850	19723Y	PARTICIPANT	\N	PRESENT	0
248891	248850	19727D	PARTICIPANT	\N	PRESENT	0
248892	248850	14119M	PARTICIPANT	\N	PRESENT	0
248893	248850	19657G	PARTICIPANT	\N	PRESENT	0
248894	248850	19577H	PARTICIPANT	\N	PRESENT	0
248895	248850	08048B	PARTICIPANT	\N	EXCUSE	0
248896	248850	19367Y	PARTICIPANT	\N	EXCUSE	0
248898	248850	04045F	PARTICIPANT	\N	PRESENT	0
248899	248850	19715Y	PARTICIPANT	\N	EXCUSE	0
248900	246405	04035D	PARTICIPANT	\N	PRESENT	0
248901	246405	95067Q	PARTICIPANT	\N	PRESENT	0
248902	246405	19443T	PARTICIPANT	\N	PRESENT	0
248903	246405	95030B	PARTICIPANT	\N	PRESENT	0
248904	246405	11041F	PARTICIPANT	\N	PRESENT	0
248905	246405	04040A	PARTICIPANT	\N	PRESENT	0
248906	246405	14079W	PARTICIPANT	\N	PRESENT	0
248907	246405	08058D	PARTICIPANT	\N	PRESENT	0
248908	246405	04042C	PRESIDENT	0	PRESENT	0
248909	246405	19251M	PARTICIPANT	\N	PRESENT	0
248910	246405	11054L	PARTICIPANT	\N	PRESENT	0
248911	246405	11066Q	PARTICIPANT	\N	PRESENT	0
248912	246405	95037J	PARTICIPANT	\N	PRESENT	0
248913	246405	19709B	PARTICIPANT	\N	PRESENT	0
248914	246405	98022P	PARTICIPANT	\N	PRESENT	0
248915	246405	14193X	PARTICIPANT	\N	PRESENT	0
248916	246405	14267Y	PARTICIPANT	\N	PRESENT	0
248917	246405	97011G	PARTICIPANT	\N	PRESENT	0
248918	246405	08047A	PARTICIPANT	\N	PRESENT	0
248919	246405	98029W	PARTICIPANT	\N	PRESENT	0
248921	248850	11103C	PARTICIPANT	\N	PRESENT	0
248922	246405	08053X	PARTICIPANT	\N	PRESENT	0
248923	246405	19721W	PARTICIPANT	\N	PRESENT	0
248924	246405	01062T	PARTICIPANT	\N	PRESENT	0
248925	246405	11115U	PARTICIPANT	\N	PRESENT	0
248926	246405	16685X	PARTICIPANT	\N	PRESENT	0
249088	248852	19735D	PARTICIPANT	\N	PRESENT	0
249089	248852	11109J	PARTICIPANT	\N	PRESENT	0
249090	248852	11083R	PARTICIPANT	\N	PRESENT	0
249091	248852	14109K	PARTICIPANT	\N	PRESENT	0
249092	248852	14063N	PARTICIPANT	\N	PRESENT	0
249093	248852	14123H	PARTICIPANT	\N	PRESENT	0
249094	248852	11104D	PARTICIPANT	\N	PRESENT	0
249095	248852	11043H	PARTICIPANT	\N	PRESENT	0
249096	248852	19749K	PARTICIPANT	\N	PRESENT	0
249097	248852	04018C	PARTICIPANT	\N	PRESENT	0
249098	248852	19621T	PARTICIPANT	\N	PRESENT	0
249099	248852	12041X	PARTICIPANT	\N	EXCUSE	0
249100	248853	04018C	PARTICIPANT	\N	PRESENT	0
249101	247145	19295A	PARTICIPANT	\N	PRESENT	0
249117	247146	19515S	PARTICIPANT	\N	PRESENT	0
249118	247146	01043Q	PARTICIPANT	\N	PRESENT	0
249119	247146	19565D	PARTICIPANT	\N	PRESENT	0
249120	247146	14357A	PARTICIPANT	\N	PRESENT	0
249121	247146	19441R	PARTICIPANT	\N	PRESENT	0
249122	247146	14081Q	PARTICIPANT	\N	PRESENT	0
249123	247146	19413M	PARTICIPANT	\N	PRESENT	0
249124	247146	80013X	PARTICIPANT	\N	PRESENT	0
249125	247146	19631V	PARTICIPANT	\N	PRESENT	0
249126	247146	11099A	PARTICIPANT	\N	PRESENT	0
249127	247146	08068F	PARTICIPANT	\N	PRESENT	0
249128	247146	04049K	PARTICIPANT	\N	PRESENT	0
249129	247146	08015R	PARTICIPANT	\N	PRESENT	0
249130	247146	08019V	PARTICIPANT	\N	PRESENT	0
249131	247146	14197C	PARTICIPANT	\N	PRESENT	0
249132	247146	19369B	PARTICIPANT	\N	PRESENT	0
249133	247146	19511N	PARTICIPANT	\N	PRESENT	0
249134	247146	14265W	PARTICIPANT	\N	PRESENT	0
249135	247146	19591F	PARTICIPANT	\N	PRESENT	0
249136	247146	19467C	PARTICIPANT	\N	PRESENT	0
249137	247146	14187A	PARTICIPANT	\N	PRESENT	0
249138	247146	08038Y	PARTICIPANT	\N	PRESENT	0
249139	247146	08062Y	PARTICIPANT	\N	PRESENT	0
249140	247146	19695N	PARTICIPANT	\N	PRESENT	0
249141	247146	14033T	PARTICIPANT	\N	PRESENT	0
249142	247146	11090Q	PRESIDENT	0	PRESENT	0
249143	247146	01025N	PARTICIPANT	\N	PRESENT	0
249144	247146	19295A	PARTICIPANT	\N	PRESENT	0
249145	247146	14205J	PARTICIPANT	\N	PRESENT	0
249146	247146	04088S	PARTICIPANT	\N	PRESENT	0
249147	247146	11056N	PARTICIPANT	\N	PRESENT	0
249148	247146	14115H	PARTICIPANT	\N	PRESENT	0
249149	247146	19507S	PARTICIPANT	\N	PRESENT	0
249150	247146	14207L	PARTICIPANT	\N	PRESENT	0
249151	247146	19747H	PARTICIPANT	\N	PRESENT	0
249152	247146	04043D	PARTICIPANT	\N	PRESENT	0
249153	247146	17589D	PARTICIPANT	\N	PRESENT	0
249154	247146	19619A	PARTICIPANT	\N	PRESENT	0
249155	247146	14257W	PARTICIPANT	\N	PRESENT	0
249157	246405	19421M	PARTICIPANT	\N	PRESENT	0
249165	247080	19581D	PARTICIPANT	\N	PRESENT	0
249166	247080	04044E	PARTICIPANT	\N	PRESENT	0
249167	247080	04047H	PARTICIPANT	\N	PRESENT	0
249168	247080	19673G	PARTICIPANT	\N	PRESENT	0
249169	247080	01028R	PARTICIPANT	\N	PRESENT	0
249170	247080	19447X	PARTICIPANT	\N	PRESENT	0
249171	247080	05008E	PRESIDENT	0	PRESENT	0
249172	247080	14231L	PARTICIPANT	\N	PRESENT	0
249173	247080	19489J	PARTICIPANT	\N	PRESENT	0
249174	247080	14275Y	PARTICIPANT	\N	PRESENT	0
249175	247080	14041T	PARTICIPANT	\N	PRESENT	0
249176	247080	14147R	PARTICIPANT	\N	PRESENT	0
249177	247080	14151M	PARTICIPANT	\N	PRESENT	0
249178	247080	14215L	PARTICIPANT	\N	PRESENT	0
249179	247080	19483C	PARTICIPANT	\N	PRESENT	0
265841	262945	14028W	PARTICIPANT	\N	PRESENT	0
265842	262945	19251M	PARTICIPANT	\N	PRESENT	0
265843	262945	19721W	PARTICIPANT	\N	PRESENT	0
265844	262945	14105F	PARTICIPANT	\N	PRESENT	0
265845	262945	98018T	PARTICIPANT	\N	PRESENT	0
265846	262945	98022P	PARTICIPANT	\N	PRESENT	0
265847	262945	14267Y	PARTICIPANT	\N	PRESENT	0
265848	262945	11064N	PARTICIPANT	\N	PRESENT	0
265849	262945	98050T	PARTICIPANT	\N	PRESENT	0
265850	262945	14211G	PARTICIPANT	\N	PRESENT	0
265851	262945	19583F	PARTICIPANT	\N	PRESENT	0
265852	262945	14255U	PARTICIPANT	\N	PRESENT	0
265853	263476	80027E	PARTICIPANT	\N	PRESENT	0
265854	263102	11110B	PARTICIPANT	\N	PRESENT	0
265875	264132	19697Q	PARTICIPANT	\N	PRESENT	0
265876	264132	11067R	PARTICIPANT	\N	PRESENT	0
265877	264132	14355X	PARTICIPANT	\N	PRESENT	0
265878	264132	19569H	PARTICIPANT	\N	PRESENT	0
265879	264132	11097X	PARTICIPANT	\N	PRESENT	0
265880	264132	19415P	PARTICIPANT	\N	PRESENT	0
265881	264132	14223L	PARTICIPANT	\N	PRESENT	0
265882	264132	04045F	PARTICIPANT	\N	PRESENT	0
265883	264132	14026U	PARTICIPANT	\N	PRESENT	0
265884	264132	14227Q	PARTICIPANT	\N	PRESENT	0
265885	264132	17779H	PARTICIPANT	\N	PRESENT	0
265886	264132	11063M	PARTICIPANT	\N	PRESENT	0
265887	264132	19703U	PARTICIPANT	\N	PRESENT	0
265888	264132	19553Y	PARTICIPANT	\N	PRESENT	0
265889	264132	14087W	PARTICIPANT	\N	PRESENT	0
265890	264132	19679N	PARTICIPANT	\N	PRESENT	0
265891	264132	14042U	PARTICIPANT	\N	PRESENT	0
265892	264132	19575F	PARTICIPANT	\N	PRESENT	0
265893	264132	19367Y	PARTICIPANT	\N	PRESENT	0
265894	264132	14213J	PARTICIPANT	\N	PRESENT	0
265895	264132	14217N	PARTICIPANT	\N	PRESENT	0
265896	264132	19335Q	PARTICIPANT	\N	PRESENT	0
265897	264132	19683J	PARTICIPANT	\N	PRESENT	0
265898	264132	19521Q	PARTICIPANT	\N	PRESENT	0
265899	264132	98024R	PARTICIPANT	\N	PRESENT	0
265900	264132	19527W	PARTICIPANT	\N	PRESENT	0
265901	264132	04092N	PRESIDENT	0	PRESENT	0
265902	264132	11045K	PARTICIPANT	\N	PRESENT	0
265903	264132	08052W	PARTICIPANT	\N	PRESENT	0
265904	264132	19663E	PARTICIPANT	\N	PRESENT	0
265905	264132	19715Y	PARTICIPANT	\N	PRESENT	0
265906	264132	19691J	PARTICIPANT	\N	PRESENT	0
265907	264132	19723Y	PARTICIPANT	\N	PRESENT	0
265908	264132	19727D	PARTICIPANT	\N	PRESENT	0
265909	264132	14119M	PARTICIPANT	\N	PRESENT	0
265910	264132	11103C	PARTICIPANT	\N	PRESENT	0
265911	264132	19657G	PARTICIPANT	\N	PRESENT	0
265912	264132	14071N	PARTICIPANT	\N	PRESENT	0
265913	264132	19577H	PARTICIPANT	\N	PRESENT	0
265914	264132	08048B	PARTICIPANT	\N	EXCUSE	0
265916	263167	14327T	PARTICIPANT	\N	PRESENT	0
265917	263167	14331P	PARTICIPANT	\N	PRESENT	0
266007	262945	14133K	PARTICIPANT	\N	PRESENT	0
265919	263167	01057W	PARTICIPANT	\N	PRESENT	0
266008	263167	19545Y	PARTICIPANT	\N	PRESENT	0
265921	263167	11074Q	PRESIDENT	0	PRESENT	0
265922	263167	89017R	PARTICIPANT	\N	PRESENT	0
265923	263167	19667J	PARTICIPANT	\N	PRESENT	0
265924	263167	88008L	PARTICIPANT	\N	PRESENT	0
265925	263167	19671E	PARTICIPANT	\N	PRESENT	0
266010	265789	19533U	PARTICIPANT	\N	PRESENT	0
265927	263167	14225N	PARTICIPANT	\N	PRESENT	0
265928	263167	07029T	PARTICIPANT	\N	PRESENT	0
265929	263167	14085U	PARTICIPANT	\N	PRESENT	0
266011	265789	14229S	PARTICIPANT	\N	PRESENT	0
265931	263167	19349W	PARTICIPANT	\N	PRESENT	0
266012	265789	19573D	PARTICIPANT	\N	PRESENT	0
265933	263167	19479G	PARTICIPANT	\N	PRESENT	0
265934	263167	11048N	PARTICIPANT	\N	PRESENT	0
266013	265789	14039A	PARTICIPANT	\N	PRESENT	0
265936	263167	19711U	PARTICIPANT	\N	PRESENT	0
266014	265789	14107H	PARTICIPANT	\N	PRESENT	0
265938	263167	08034U	PARTICIPANT	\N	PRESENT	0
265939	263167	08069G	PARTICIPANT	\N	PRESENT	0
265940	263167	19687N	PARTICIPANT	\N	PRESENT	0
266015	265789	08031R	PARTICIPANT	\N	PRESENT	0
265942	263167	12016W	PARTICIPANT	\N	PRESENT	0
265943	263167	08011M	PARTICIPANT	\N	PRESENT	0
266016	265789	14059S	PARTICIPANT	\N	PRESENT	0
265945	263167	14159V	PARTICIPANT	\N	PRESENT	0
266017	265789	08035V	PARTICIPANT	\N	PRESENT	0
266018	265789	08043V	PARTICIPANT	\N	PRESENT	0
265948	263167	04086Q	PARTICIPANT	\N	PRESENT	0
265949	263167	14083S	PARTICIPANT	\N	PRESENT	0
266019	265789	08020N	PARTICIPANT	\N	PRESENT	0
265951	263167	08073C	PARTICIPANT	\N	PRESENT	0
265952	263167	14121F	PARTICIPANT	\N	PRESENT	0
265953	263167	19741B	PARTICIPANT	\N	PRESENT	0
266020	265789	14251Q	PARTICIPANT	\N	PRESENT	0
266021	265789	04059M	PARTICIPANT	\N	PRESENT	0
266022	265789	19735D	PARTICIPANT	\N	PRESENT	0
265957	263167	11110B	PARTICIPANT	\N	PRESENT	0
265958	263167	14034U	PARTICIPANT	\N	EXCUSE	0
265960	263167	19651A	PARTICIPANT	\N	PRESENT	0
265961	263167	08014Q	PARTICIPANT	\N	PRESENT	0
265962	264236	01060R	PARTICIPANT	\N	PRESENT	0
265963	264236	19543W	PARTICIPANT	\N	PRESENT	0
265964	264236	04044E	PARTICIPANT	\N	PRESENT	0
265965	264236	19581D	PARTICIPANT	\N	PRESENT	0
265966	264236	19585H	PARTICIPANT	\N	PRESENT	0
265967	264236	04047H	PARTICIPANT	\N	PRESENT	0
265968	264236	19673G	PARTICIPANT	\N	PRESENT	0
265969	264236	01028R	PARTICIPANT	\N	PRESENT	0
265970	264236	19447X	PARTICIPANT	\N	PRESENT	0
265971	264236	05008E	PRESIDENT	0	PRESENT	0
265972	264236	14231L	PARTICIPANT	\N	PRESENT	0
265973	264236	19489J	PARTICIPANT	\N	PRESENT	0
265974	264236	14041T	PARTICIPANT	\N	PRESENT	0
265975	264236	14179A	PARTICIPANT	\N	PRESENT	0
265976	264236	14147R	PARTICIPANT	\N	PRESENT	0
265977	264236	14215L	PARTICIPANT	\N	PRESENT	0
265978	264236	19483C	PARTICIPANT	\N	PRESENT	0
265979	264236	08018U	PARTICIPANT	\N	PRESENT	0
265980	264236	14259Y	PARTICIPANT	\N	PRESENT	0
265981	264236	11072N	PARTICIPANT	\N	PRESENT	0
265982	264236	14053L	PARTICIPANT	\N	PRESENT	0
265983	264236	98035U	PARTICIPANT	\N	PRESENT	0
265984	264236	14111D	PARTICIPANT	\N	PRESENT	0
265985	264236	19649G	PARTICIPANT	\N	PRESENT	0
265986	264236	14065Q	PARTICIPANT	\N	PRESENT	0
265987	264236	07034Q	PARTICIPANT	\N	PRESENT	0
265988	264236	10015M	PARTICIPANT	\N	PRESENT	0
265989	264236	11026G	PARTICIPANT	\N	PRESENT	0
265990	264236	08045X	PARTICIPANT	\N	PRESENT	0
265991	264236	19253P	PARTICIPANT	\N	PRESENT	0
265992	264236	01024M	PARTICIPANT	\N	PRESENT	0
265993	264236	04038G	PARTICIPANT	\N	PRESENT	0
265994	264236	19719D	PARTICIPANT	\N	PRESENT	0
265995	264236	11033F	PARTICIPANT	\N	PRESENT	0
265996	264236	19725B	PARTICIPANT	\N	PRESENT	0
265997	264236	14089Y	PARTICIPANT	\N	PRESENT	0
265998	264236	19729F	PARTICIPANT	\N	PRESENT	0
265999	264236	95063L	PARTICIPANT	\N	PRESENT	0
266000	264236	19629C	PARTICIPANT	\N	PRESENT	0
266001	264236	08044W	PARTICIPANT	\N	PRESENT	0
266002	264236	14069U	PARTICIPANT	\N	PRESENT	0
266003	264236	11085T	PARTICIPANT	\N	PRESENT	0
266004	264236	11049P	PARTICIPANT	\N	PRESENT	0
266005	264236	04008A	PARTICIPANT	\N	PRESENT	0
266006	264236	14021P	PARTICIPANT	\N	PRESENT	0
266023	265789	14063N	PARTICIPANT	\N	PRESENT	0
266024	265789	14109K	PARTICIPANT	\N	PRESENT	0
266025	265789	11043H	PARTICIPANT	\N	PRESENT	0
266026	265789	11104D	PARTICIPANT	\N	PRESENT	0
266027	263167	04061F	PARTICIPANT	\N	PRESENT	0
266033	266028	04061F	PARTICIPANT	\N	PRESENT	0
266035	266034	08034U	PARTICIPANT	\N	PRESENT	0
266036	264238	14111D	PARTICIPANT	\N	PRESENT	0
266037	264238	10015M	PARTICIPANT	\N	PRESENT	0
266038	264238	08045X	PARTICIPANT	\N	PRESENT	0
266039	264238	07034Q	PRESIDENT	1	PRESENT	0
266040	264238	01024M	PARTICIPANT	\N	PRESENT	0
266041	264238	04038G	PARTICIPANT	\N	PRESENT	0
266042	264238	19585H	PARTICIPANT	\N	PRESENT	0
266043	264238	19673G	PARTICIPANT	\N	PRESENT	0
266044	264238	19719D	PARTICIPANT	\N	PRESENT	0
266045	264238	01028R	PARTICIPANT	\N	PRESENT	0
266046	264238	05008E	PRESIDENT	0	PRESENT	0
266047	264238	19447X	PARTICIPANT	\N	PRESENT	0
266048	264238	19725B	PARTICIPANT	\N	PRESENT	0
266049	264238	19489J	PARTICIPANT	\N	PRESENT	0
266050	264238	14041T	PARTICIPANT	\N	PRESENT	0
266051	264238	14147R	PARTICIPANT	\N	PRESENT	0
266052	264238	14179A	PARTICIPANT	\N	PRESENT	0
266053	264238	14069U	PARTICIPANT	\N	PRESENT	0
242650	242649	14255U	PARTICIPANT	\N	PRESENT	0
244586	244585	19581D	PARTICIPANT	\N	PRESENT	0
244587	244585	08031R	PARTICIPANT	\N	PRESENT	0
244588	244585	19253P	PARTICIPANT	\N	PRESENT	0
244589	244585	19629C	PARTICIPANT	\N	PRESENT	0
244591	244590	19581D	PARTICIPANT	\N	PRESENT	0
244592	244590	19629C	PARTICIPANT	\N	PRESENT	0
244595	244594	19581D	PARTICIPANT	\N	PRESENT	0
249454	248851	14195A	PARTICIPANT	\N	PRESENT	0
249455	248851	08052W	PARTICIPANT	\N	PRESENT	0
249457	248851	14217N	PARTICIPANT	\N	PRESENT	0
249458	248851	14042U	PARTICIPANT	\N	PRESENT	0
249460	248851	14281W	PARTICIPANT	\N	PRESENT	0
249461	248851	08048B	PARTICIPANT	\N	EXCUSE	0
249462	248851	19727D	PARTICIPANT	\N	PRESENT	0
249463	248851	14213J	PARTICIPANT	\N	PRESENT	0
249464	248851	19715Y	PARTICIPANT	\N	PRESENT	0
249465	248851	19723Y	PARTICIPANT	\N	PRESENT	0
249466	248851	17779H	PARTICIPANT	\N	PRESENT	0
249468	248851	11067R	PARTICIPANT	\N	PRESENT	0
249469	248851	14223L	PARTICIPANT	\N	PRESENT	0
249470	248851	04092N	PRESIDENT	0	PRESENT	0
249471	248851	14119M	PARTICIPANT	\N	PRESENT	0
249472	248851	19679N	PARTICIPANT	\N	PRESENT	0
249473	248851	11045K	PARTICIPANT	\N	PRESENT	0
249474	248851	04045F	PARTICIPANT	\N	PRESENT	0
249475	248851	19703U	PARTICIPANT	\N	PRESENT	0
249476	248851	19527W	PARTICIPANT	\N	PRESENT	0
249494	248851	19631V	PARTICIPANT	\N	PRESENT	0
249496	248851	19515S	PARTICIPANT	\N	PRESENT	0
249497	248851	14115H	PARTICIPANT	\N	PRESENT	0
249498	248851	19747H	PARTICIPANT	\N	PRESENT	0
249499	248851	08068F	PARTICIPANT	\N	PRESENT	0
249500	248851	14207L	PARTICIPANT	\N	PRESENT	0
249502	248851	19467C	PARTICIPANT	\N	PRESENT	0
249503	248851	19295A	PARTICIPANT	\N	PRESENT	0
249504	248851	80013X	PARTICIPANT	\N	PRESENT	0
249505	248851	11056N	PARTICIPANT	\N	PRESENT	0
249506	248851	14357A	PARTICIPANT	\N	PRESENT	0
249507	248851	08038Y	PARTICIPANT	\N	PRESENT	0
249508	248851	19507S	PARTICIPANT	\N	PRESENT	0
249509	248851	14197C	PARTICIPANT	\N	PRESENT	0
249511	248851	17589D	PARTICIPANT	\N	PRESENT	0
249513	248851	14187A	PARTICIPANT	\N	PRESENT	0
249514	248851	01025N	PARTICIPANT	\N	PRESENT	0
249515	248851	19695N	PARTICIPANT	\N	PRESENT	0
249516	248851	19565D	PARTICIPANT	\N	PRESENT	0
249517	248851	14033T	PARTICIPANT	\N	PRESENT	0
249518	248851	14081Q	PARTICIPANT	\N	PRESENT	0
249519	248851	19591F	PARTICIPANT	\N	PRESENT	0
249520	248851	19511N	PARTICIPANT	\N	PRESENT	0
249521	248851	11099A	PARTICIPANT	\N	PRESENT	0
249522	248851	04049K	PARTICIPANT	\N	PRESENT	0
249523	248851	08015R	PARTICIPANT	\N	PRESENT	0
249524	248851	01043Q	PARTICIPANT	\N	PRESENT	0
249525	248851	14205J	PARTICIPANT	\N	PRESENT	0
249526	248851	19441R	PARTICIPANT	\N	PRESENT	0
249527	248851	08019V	PARTICIPANT	\N	PRESENT	0
249528	248851	08062Y	PARTICIPANT	\N	PRESENT	0
249529	248851	19369B	PARTICIPANT	\N	PRESENT	0
249531	248851	14257W	PARTICIPANT	\N	PRESENT	0
249532	248851	14265W	PARTICIPANT	\N	PRESENT	0
249533	248851	04088S	PARTICIPANT	\N	PRESENT	0
249534	248851	11090Q	PARTICIPANT	\N	PRESENT	0
249535	248851	04043D	PARTICIPANT	\N	PRESENT	0
249536	248851	19619A	PARTICIPANT	\N	PRESENT	0
249537	248851	19413M	PARTICIPANT	\N	PRESENT	0
249614	249612	10015M	PARTICIPANT	\N	PRESENT	0
249615	249612	11099A	PARTICIPANT	\N	PRESENT	0
249618	249612	04035D	PARTICIPANT	\N	PRESENT	0
249622	249612	19727D	PARTICIPANT	\N	PRESENT	0
249623	249612	19531S	PARTICIPANT	\N	PRESENT	0
249624	249612	11026G	PARTICIPANT	\N	PRESENT	0
249625	249612	14065Q	PARTICIPANT	\N	PRESENT	0
249626	249612	08053X	PARTICIPANT	\N	PRESENT	0
249627	249612	18083K	PARTICIPANT	\N	PRESENT	0
249628	249612	14061L	PARTICIPANT	\N	PRESENT	0
249835	244799	11048N	PRESIDENT	0	PRESENT	0
249836	244799	11067R	PARTICIPANT	\N	PRESENT	0
249837	244799	19479G	PARTICIPANT	\N	PRESENT	0
249838	244799	14103D	PARTICIPANT	\N	PRESENT	0
249839	244799	19515S	PARTICIPANT	\N	PRESENT	0
249840	244799	19711U	PARTICIPANT	\N	PRESENT	0
249841	244799	19689Q	PARTICIPANT	\N	PRESENT	0
249842	244799	19253P	PARTICIPANT	\N	PRESENT	0
249843	244799	01024M	PARTICIPANT	\N	PRESENT	0
249844	244799	04038G	PARTICIPANT	\N	PRESENT	0
249845	244799	19399H	PARTICIPANT	\N	PRESENT	0
249846	244799	14026U	PARTICIPANT	\N	PRESENT	0
249847	244799	11040E	PARTICIPANT	\N	PRESENT	0
249848	244799	04049K	PARTICIPANT	\N	PRESENT	0
249849	244799	14087W	PARTICIPANT	\N	PRESENT	0
249850	244799	14041T	PARTICIPANT	\N	PRESENT	0
249851	244799	19503N	PARTICIPANT	\N	PRESENT	0
249852	244799	14151M	PARTICIPANT	\N	PRESENT	0
249853	244799	14157T	PARTICIPANT	\N	PRESENT	0
249854	244799	19749K	PARTICIPANT	\N	PRESENT	0
249855	244799	14031R	PARTICIPANT	\N	PRESENT	0
249856	244799	14071N	PARTICIPANT	\N	EXCUSE	0
249862	249861	19575F	PARTICIPANT	\N	PRESENT	0
249863	249861	08060W	PARTICIPANT	\N	PRESENT	0
249864	249861	04049K	PARTICIPANT	\N	PRESENT	0
249865	249861	14031R	PARTICIPANT	\N	PRESENT	0
249866	249861	19549D	PARTICIPANT	\N	PRESENT	0
249984	249983	14193X	PARTICIPANT	\N	PRESENT	0
249985	249983	95067Q	PARTICIPANT	\N	PRESENT	0
249986	249983	14235Q	PARTICIPANT	\N	PRESENT	0
249988	249987	14193X	PARTICIPANT	\N	PRESENT	0
249989	249987	08053X	PARTICIPANT	\N	PRESENT	0
249990	249987	95067Q	PARTICIPANT	\N	PRESENT	0
250077	250073	14079W	PARTICIPANT	\N	PRESENT	0
250075	250073	08043V	PARTICIPANT	\N	PRESENT	0
250076	250073	19643A	PARTICIPANT	\N	PRESENT	0
250078	250073	08039A	PARTICIPANT	\N	PRESENT	0
250079	250073	04088S	PARTICIPANT	\N	PRESENT	0
250080	250073	98050T	PARTICIPANT	\N	PRESENT	0
250114	250112	14219Q	PARTICIPANT	\N	PRESENT	0
250082	250073	19679N	PARTICIPANT	\N	PRESENT	0
250113	250112	08020N	PARTICIPANT	\N	PRESENT	0
250115	250112	14059S	PARTICIPANT	\N	PRESENT	0
250116	250112	11072N	PARTICIPANT	\N	PRESENT	0
250117	250112	04043D	PARTICIPANT	\N	PRESENT	0
250124	250123	19415P	PARTICIPANT	\N	PRESENT	0
250138	250137	10006L	PARTICIPANT	\N	PRESENT	0
250139	250137	08052W	PARTICIPANT	\N	PRESENT	0
250140	250137	19553Y	PARTICIPANT	\N	PRESENT	0
250222	250221	89017R	PARTICIPANT	\N	PRESENT	0
250226	250225	08044W	PARTICIPANT	\N	PRESENT	0
250228	250227	08044W	PARTICIPANT	\N	PRESENT	0
250230	250229	08044W	PARTICIPANT	\N	PRESENT	0
250232	250231	08044W	PARTICIPANT	\N	PRESENT	0
250233	250231	14179A	PARTICIPANT	\N	PRESENT	0
250791	232877	19647E	PARTICIPANT	\N	PRESENT	0
250918	232877	19713W	PARTICIPANT	\N	PRESENT	0
250939	250938	08043V	PARTICIPANT	\N	PRESENT	0
250940	250938	14053L	PARTICIPANT	\N	PRESENT	0
250941	250938	14083S	PARTICIPANT	\N	PRESENT	0
250942	250938	08024S	PARTICIPANT	\N	PRESENT	0
250943	250938	08045X	PARTICIPANT	\N	PRESENT	0
250944	250938	19489J	PARTICIPANT	\N	PRESENT	0
250945	250938	08015R	PARTICIPANT	\N	PRESENT	0
250946	250938	14031R	PARTICIPANT	\N	PRESENT	0
250947	250938	95062K	PARTICIPANT	\N	PRESENT	0
250948	250938	14051J	PARTICIPANT	\N	PRESENT	0
250949	250938	14157T	PARTICIPANT	\N	PRESENT	0
250950	250938	19447X	PARTICIPANT	\N	PRESENT	0
250951	250938	14213J	PARTICIPANT	\N	PRESENT	0
250964	250963	14239U	PARTICIPANT	\N	PRESENT	0
250965	250963	04086Q	PARTICIPANT	\N	PRESENT	0
250966	250963	14259Y	PARTICIPANT	\N	PRESENT	0
250967	250963	19251M	PARTICIPANT	\N	PRESENT	0
250968	250963	19647E	PARTICIPANT	\N	PRESENT	0
250969	250963	14087W	PARTICIPANT	\N	PRESENT	0
250970	250963	97011G	PARTICIPANT	\N	PRESENT	0
250971	250963	98022P	PARTICIPANT	\N	PRESENT	0
250972	250963	08053X	PARTICIPANT	\N	PRESENT	0
250973	250963	19593H	PARTICIPANT	\N	PRESENT	0
250974	250963	95067Q	PARTICIPANT	\N	PRESENT	0
251928	251151	14195A	PARTICIPANT	\N	PRESENT	0
251431	232877	19421M	PARTICIPANT	\N	EXCUSE	0
251954	250533	14239U	PARTICIPANT	\N	PRESENT	0
251955	250533	14261S	PARTICIPANT	\N	PRESENT	0
251957	250533	19415P	PARTICIPANT	\N	PRESENT	0
251959	250533	11103C	PARTICIPANT	\N	PRESENT	0
251961	250533	14195A	PARTICIPANT	\N	PRESENT	0
251963	250533	08052W	PARTICIPANT	\N	PRESENT	0
251964	250533	19663E	PARTICIPANT	\N	PRESENT	0
251966	250533	14217N	PARTICIPANT	\N	PRESENT	0
268735	268167	11109J	PARTICIPANT	\N	PRESENT	0
268736	268167	14195A	PARTICIPANT	\N	PRESENT	0
268737	268167	14079W	PARTICIPANT	\N	PRESENT	0
268738	268167	14327T	PARTICIPANT	\N	PRESENT	0
268739	268167	08049C	PARTICIPANT	\N	PRESENT	0
268740	268167	04045F	PARTICIPANT	\N	PRESENT	0
268741	268167	98024R	PARTICIPANT	\N	PRESENT	0
268742	268167	10006L	PARTICIPANT	\N	PRESENT	0
268743	268167	08045X	PARTICIPANT	\N	PRESENT	0
268744	268167	19347U	PARTICIPANT	\N	PRESENT	0
268745	268167	95037J	PARTICIPANT	\N	PRESENT	0
268746	268167	14213J	PRESIDENT	0	PRESENT	0
268747	268167	19683J	PARTICIPANT	\N	PRESENT	0
268748	268167	11099A	PARTICIPANT	\N	PRESENT	0
268749	268167	04049K	PARTICIPANT	\N	PRESENT	0
268750	268167	08015R	PARTICIPANT	\N	PRESENT	0
268751	268167	08039A	PARTICIPANT	\N	PRESENT	0
268752	268167	08017T	PARTICIPANT	\N	PRESENT	0
268753	268167	19441R	PARTICIPANT	\N	PRESENT	0
268754	268167	04092N	PARTICIPANT	\N	PRESENT	0
268755	268167	19369B	PARTICIPANT	\N	PRESENT	0
268756	268167	14109K	PARTICIPANT	\N	PRESENT	0
268757	268167	14169X	PARTICIPANT	\N	PRESENT	0
268758	268167	19503N	PARTICIPANT	\N	PRESENT	0
268759	268167	04043D	PARTICIPANT	\N	PRESENT	0
268762	268761	08012N	PARTICIPANT	\N	PRESENT	0
268763	268761	92040Q	PARTICIPANT	\N	PRESENT	0
268764	268761	19511N	PARTICIPANT	\N	PRESENT	0
268766	268765	08012N	PARTICIPANT	\N	PRESENT	0
270054	263470	04044E	PARTICIPANT	\N	PRESENT	0
270055	263470	19593H	PARTICIPANT	\N	PRESENT	0
270056	263470	14215L	PARTICIPANT	\N	PRESENT	0
270057	263470	08044W	PARTICIPANT	\N	PRESENT	0
270058	263470	11033F	PARTICIPANT	\N	PRESENT	0
270059	263470	14151M	PARTICIPANT	\N	PRESENT	0
270060	263470	07029T	PARTICIPANT	\N	PRESENT	0
270061	263470	14093U	PARTICIPANT	\N	PRESENT	0
270062	263470	14119M	PARTICIPANT	\N	PRESENT	0
270063	263470	19667J	PARTICIPANT	\N	PRESENT	0
270064	263470	19673G	PARTICIPANT	\N	PRESENT	0
270081	263470	19399H	PARTICIPANT	\N	PRESENT	0
270066	263470	19507S	PARTICIPANT	\N	PRESENT	0
270067	263470	04086Q	PARTICIPANT	\N	PRESENT	0
270068	263470	97011G	PARTICIPANT	\N	PRESENT	0
270069	263470	19415P	PARTICIPANT	\N	PRESENT	0
270070	263470	19629C	PARTICIPANT	\N	PRESENT	0
270071	263470	19663E	PARTICIPANT	\N	PRESENT	0
270072	263470	19543W	PARTICIPANT	\N	PRESENT	0
270073	263470	05008E	PARTICIPANT	\N	PRESENT	0
270074	263470	19387D	PARTICIPANT	\N	PRESENT	0
270075	263470	14147R	PARTICIPANT	\N	PRESENT	0
270076	263470	14105F	PARTICIPANT	\N	PRESENT	0
270077	263470	98050T	PARTICIPANT	\N	PRESENT	0
270078	263470	19649G	PARTICIPANT	\N	PRESENT	0
270079	263470	19747H	PARTICIPANT	\N	PRESENT	0
270080	263470	14089Y	PARTICIPANT	\N	PRESENT	0
270082	263470	11067R	PARTICIPANT	\N	PRESENT	0
270083	263470	01028R	PARTICIPANT	\N	PRESENT	0
270084	263470	19631V	PARTICIPANT	\N	PRESENT	0
270092	270091	14053L	PARTICIPANT	\N	PRESENT	0
270093	270091	19719D	PARTICIPANT	\N	PRESENT	0
270094	270091	14026U	PARTICIPANT	\N	PRESENT	0
270098	270097	96004D	PRESIDENT	0	PRESENT	0
270099	270097	14357A	PARTICIPANT	\N	PRESENT	0
270100	270097	08014Q	PARTICIPANT	\N	PRESENT	0
270101	270097	04097T	PARTICIPANT	\N	PRESENT	0
270102	270097	14097Y	PARTICIPANT	\N	PRESENT	0
270103	270097	11026G	PARTICIPANT	\N	PRESENT	0
270104	270097	14001X	PARTICIPANT	\N	PRESENT	0
270105	270097	04057K	PARTICIPANT	\N	EXCUSE	0
270106	270097	98035U	PARTICIPANT	\N	PRESENT	0
270107	270097	14225N	PARTICIPANT	\N	PRESENT	0
270108	270097	14073Q	PARTICIPANT	\N	PRESENT	0
270109	270097	14079W	PARTICIPANT	\N	PRESENT	0
270110	270097	95037J	PARTICIPANT	\N	PRESENT	0
270117	270116	08034U	PARTICIPANT	\N	PRESENT	0
270119	270118	08034U	PARTICIPANT	\N	PRESENT	0
270121	270120	14121F	PARTICIPANT	\N	PRESENT	0
270123	270122	11070L	PARTICIPANT	\N	PRESENT	0
270124	270122	19647E	PARTICIPANT	\N	PRESENT	0
270132	270131	14331P	PARTICIPANT	\N	PRESENT	0
270134	270133	11053K	PARTICIPANT	\N	PRESENT	0
270136	270135	04049K	PARTICIPANT	\N	PRESENT	0
270199	270198	19721W	PARTICIPANT	\N	PRESENT	0
270200	270198	08058D	PARTICIPANT	\N	PRESENT	0
270201	270198	19719D	PARTICIPANT	\N	PRESENT	0
270202	270198	14097Y	PARTICIPANT	\N	PRESENT	0
270203	270198	11049P	PARTICIPANT	\N	PRESENT	0
270205	270204	14229S	PARTICIPANT	\N	PRESENT	0
270206	270204	08031R	PARTICIPANT	\N	PRESENT	0
270207	270204	08043V	PARTICIPANT	\N	PRESENT	0
270208	270204	19749K	PARTICIPANT	\N	PRESENT	0
270215	270214	11064N	PARTICIPANT	\N	PRESENT	0
270217	270216	11064N	PARTICIPANT	\N	PRESENT	0
270218	256147	19551W	PARTICIPANT	\N	PRESENT	0
270219	256147	08024S	PARTICIPANT	\N	PRESENT	0
270220	256143	19349W	PARTICIPANT	\N	PRESENT	0
270221	256166	19349W	PARTICIPANT	\N	PRESENT	0
270222	264173	19651A	PARTICIPANT	\N	PRESENT	0
270223	264173	19713W	PARTICIPANT	\N	PRESENT	0
270224	266870	19651A	PARTICIPANT	\N	PRESENT	0
270225	266870	19713W	PARTICIPANT	\N	PRESENT	0
270227	270226	11074Q	PARTICIPANT	\N	PRESENT	0
270228	270226	19741B	PARTICIPANT	\N	PRESENT	0
270229	270226	14121F	PARTICIPANT	\N	PRESENT	0
270230	270226	08011M	PARTICIPANT	\N	PRESENT	0
270231	270226	14331P	PARTICIPANT	\N	PRESENT	0
270232	270226	14225N	PARTICIPANT	\N	PRESENT	0
270233	270226	19349W	PARTICIPANT	\N	PRESENT	0
270234	270226	19479G	PARTICIPANT	\N	PRESENT	0
270235	270226	19671E	PARTICIPANT	\N	PRESENT	0
270237	270236	08028W	PARTICIPANT	\N	PRESENT	0
270238	270236	08068F	PARTICIPANT	\N	PRESENT	0
270240	270239	08028W	PARTICIPANT	\N	PRESENT	0
270241	270239	08068F	PARTICIPANT	\N	PRESENT	0
270242	270239	14237S	PARTICIPANT	\N	PRESENT	0
270244	270243	08028W	PARTICIPANT	\N	PRESENT	0
270245	270243	08068F	PARTICIPANT	\N	PRESENT	0
270246	270243	14237S	PARTICIPANT	\N	PRESENT	0
270247	270243	14219Q	PARTICIPANT	\N	PRESENT	0
270248	270243	19737F	PARTICIPANT	\N	PRESENT	0
270250	270249	08028W	PARTICIPANT	\N	PRESENT	0
270251	270249	08068F	PARTICIPANT	\N	PRESENT	0
270252	270249	19737F	PARTICIPANT	\N	PRESENT	0
270253	270249	14257W	PARTICIPANT	\N	PRESENT	0
270254	270249	19585H	PARTICIPANT	\N	PRESENT	0
270255	263174	14147R	PARTICIPANT	\N	PRESENT	0
270257	270256	19643A	PARTICIPANT	\N	PRESENT	0
270258	270256	18083K	PARTICIPANT	\N	PRESENT	0
270259	270256	14281W	PARTICIPANT	\N	PRESENT	0
270260	270256	19447X	PARTICIPANT	\N	PRESENT	0
270261	270256	14205J	PARTICIPANT	\N	PRESENT	0
270262	270256	05012A	PARTICIPANT	\N	PRESENT	0
270263	270256	19735D	PARTICIPANT	\N	PRESENT	0
270264	270256	04044E	PARTICIPANT	\N	PRESENT	0
270265	270256	14173T	PARTICIPANT	\N	PRESENT	0
270274	270273	14207L	PARTICIPANT	\N	PRESENT	0
270275	270273	19507S	PARTICIPANT	\N	PRESENT	0
270276	270273	19511N	PARTICIPANT	\N	PRESENT	0
270278	270277	19515S	PARTICIPANT	\N	PRESENT	0
270279	270277	19575F	PARTICIPANT	\N	PRESENT	0
270280	270277	08014Q	PARTICIPANT	\N	PRESENT	0
270281	270277	19383Y	PARTICIPANT	\N	PRESENT	0
270282	270277	14207L	PARTICIPANT	\N	PRESENT	0
270283	270277	19467C	PARTICIPANT	\N	PRESENT	0
270284	270277	17589D	PARTICIPANT	\N	PRESENT	0
270285	270277	14217N	PARTICIPANT	\N	PRESENT	0
270286	270277	19507S	PARTICIPANT	\N	PRESENT	0
270287	270277	19727D	PARTICIPANT	\N	PRESENT	0
270288	270277	14033T	PARTICIPANT	\N	PRESENT	0
270289	270277	04097T	PARTICIPANT	\N	PRESENT	0
270290	270277	11099A	PARTICIPANT	\N	PRESENT	0
270291	270277	04049K	PARTICIPANT	\N	PRESENT	0
270292	270277	08015R	PARTICIPANT	\N	PRESENT	0
270293	270277	14221J	PARTICIPANT	\N	PRESENT	0
270294	270277	19369B	PARTICIPANT	\N	PRESENT	0
270295	270277	19745F	PARTICIPANT	\N	PRESENT	0
270296	270277	19619A	PARTICIPANT	\N	PRESENT	0
270297	270277	19483C	PARTICIPANT	\N	PRESENT	0
270298	270277	19441R	PARTICIPANT	\N	PRESENT	0
270305	270304	95067Q	PARTICIPANT	\N	PRESENT	0
270307	270306	95067Q	PARTICIPANT	\N	PRESENT	0
270309	270308	04047H	PARTICIPANT	\N	PRESENT	0
270310	270308	19673G	PARTICIPANT	\N	PRESENT	0
270311	270308	19649G	PARTICIPANT	\N	PRESENT	0
270313	270312	04047H	PARTICIPANT	\N	PRESENT	0
249221	247147	19333N	PARTICIPANT	\N	PRESENT	0
249180	247080	08018U	PARTICIPANT	\N	PRESENT	0
249181	247080	11072N	PARTICIPANT	\N	PRESENT	0
249182	247080	14111D	PARTICIPANT	\N	PRESENT	0
249183	247080	19649G	PARTICIPANT	\N	PRESENT	0
249184	247080	14065Q	PARTICIPANT	\N	PRESENT	0
249185	247080	11010L	PARTICIPANT	\N	PRESENT	0
249186	247080	07034Q	PRESIDENT	1	PRESENT	0
249187	247080	08045X	PARTICIPANT	\N	PRESENT	0
249188	247080	10015M	PARTICIPANT	\N	PRESENT	0
249189	247080	19253P	PARTICIPANT	\N	PRESENT	0
249190	247080	01024M	PARTICIPANT	\N	PRESENT	0
249191	247080	04038G	PARTICIPANT	\N	PRESENT	0
249192	247080	11033F	PARTICIPANT	\N	PRESENT	0
249193	247080	14089Y	PARTICIPANT	\N	PRESENT	0
249194	247080	19725B	PARTICIPANT	\N	PRESENT	0
249195	247080	19729F	PARTICIPANT	\N	PRESENT	0
249196	247080	19629C	PARTICIPANT	\N	PRESENT	0
249197	247080	08044W	PARTICIPANT	\N	PRESENT	0
249198	247080	11085T	PARTICIPANT	\N	PRESENT	0
249199	247080	11049P	PARTICIPANT	\N	PRESENT	0
249200	247080	14021P	PARTICIPANT	\N	PRESENT	0
249201	247080	14053L	PARTICIPANT	\N	PRESENT	0
249202	247080	98035U	PARTICIPANT	\N	PRESENT	0
249203	247080	01060R	PARTICIPANT	\N	PRESENT	0
249204	247080	14259Y	PARTICIPANT	\N	PRESENT	0
249205	247080	04008A	PARTICIPANT	\N	PRESENT	0
249220	246405	08061X	PARTICIPANT	\N	PRESENT	0
249222	247147	19383Y	PARTICIPANT	\N	PRESENT	0
249223	247147	17583W	PARTICIPANT	\N	PRESENT	0
249224	247147	19701S	PARTICIPANT	\N	PRESENT	0
249225	247147	19549D	PARTICIPANT	\N	PRESENT	0
249226	247147	95062K	PARTICIPANT	\N	PRESENT	0
249227	247147	19387D	PARTICIPANT	\N	PRESENT	0
249228	247147	14219Q	PARTICIPANT	\N	PRESENT	0
249229	247147	14221J	PARTICIPANT	\N	PRESENT	0
249230	247147	19637C	PARTICIPANT	\N	PRESENT	0
249231	247147	02002K	PARTICIPANT	\N	PRESENT	0
249232	247147	19551W	PARTICIPANT	\N	PRESENT	0
249233	247147	14237S	PARTICIPANT	\N	PRESENT	0
249234	247147	18083K	PARTICIPANT	\N	PRESENT	0
249235	247147	80027E	PARTICIPANT	\N	PRESENT	0
249236	247147	05012A	PARTICIPANT	\N	PRESENT	0
249237	247147	14051J	PARTICIPANT	\N	PRESENT	0
249238	247147	08060W	PARTICIPANT	\N	PRESENT	0
249239	247147	19347U	PARTICIPANT	\N	PRESENT	0
249240	247147	19503N	PARTICIPANT	\N	PRESENT	0
249241	247147	19685L	PARTICIPANT	\N	PRESENT	0
249242	247147	14157T	PARTICIPANT	\N	PRESENT	0
249243	247147	08024S	PARTICIPANT	\N	PRESENT	0
249244	247147	98023Q	PARTICIPANT	\N	PRESENT	0
249245	247147	11065P	PARTICIPANT	\N	PRESENT	0
249246	247147	17637T	PARTICIPANT	\N	PRESENT	0
249247	247147	19525U	PARTICIPANT	\N	PRESENT	0
249248	247147	14038Y	PARTICIPANT	\N	PRESENT	0
249249	247147	14103D	PARTICIPANT	\N	PRESENT	0
249250	247147	14031R	PARTICIPANT	\N	PRESENT	0
249251	247147	19713W	PARTICIPANT	\N	PRESENT	0
249252	247147	08055A	PARTICIPANT	\N	PRESENT	0
249253	247147	14169X	PARTICIPANT	\N	PRESENT	0
249254	247147	14191V	PARTICIPANT	\N	PRESENT	0
249255	247147	14093U	PARTICIPANT	\N	PRESENT	0
249256	247147	14029X	PARTICIPANT	\N	PRESENT	0
249257	247147	19733B	PARTICIPANT	\N	PRESENT	0
249258	247147	08009T	PRESIDENT	0	PRESENT	0
249259	247147	19737F	PARTICIPANT	\N	PRESENT	0
249260	247147	04097T	PARTICIPANT	\N	PRESENT	0
249261	247147	19739H	PARTICIPANT	\N	PRESENT	0
249262	247147	19745F	PARTICIPANT	\N	PRESENT	0
249263	247147	19659J	PARTICIPANT	\N	PRESENT	0
249264	247147	19681G	PARTICIPANT	\N	EXCUSE	0
249265	247147	19599P	PARTICIPANT	\N	EXCUSE	0
249781	249780	19515S	PARTICIPANT	\N	PRESENT	0
249782	249780	19575F	PARTICIPANT	\N	PRESENT	0
249783	249780	19545Y	PARTICIPANT	\N	PRESENT	0
249784	249780	14249W	PARTICIPANT	\N	PRESENT	0
249785	249780	14187A	PARTICIPANT	\N	PRESENT	0
249786	249780	19647E	PARTICIPANT	\N	PRESENT	0
249787	249780	19521Q	PARTICIPANT	\N	PRESENT	0
249788	249780	19511N	PARTICIPANT	\N	PRESENT	0
249789	249780	08031R	PARTICIPANT	\N	PRESENT	0
249790	249780	19709B	PARTICIPANT	\N	PRESENT	0
249791	249780	80027E	PARTICIPANT	\N	PRESENT	0
249792	249780	14031R	PARTICIPANT	\N	PRESENT	0
249793	249780	11085T	PARTICIPANT	\N	PRESENT	0
249794	249780	14223L	PARTICIPANT	\N	PRESENT	0
249795	249780	19335Q	PARTICIPANT	\N	PRESENT	0
249796	249780	14265W	PARTICIPANT	\N	PRESENT	0
249797	249780	19443T	PARTICIPANT	\N	PRESENT	0
249798	249780	14229S	PARTICIPANT	\N	PRESENT	0
249799	249780	19687N	PARTICIPANT	\N	PRESENT	0
249800	249780	14051J	PARTICIPANT	\N	PRESENT	0
249801	249780	01062T	PARTICIPANT	\N	PRESENT	0
249802	249780	19749K	PARTICIPANT	\N	PRESENT	0
249818	249817	14069U	PARTICIPANT	\N	PRESENT	0
249819	249817	19467C	PARTICIPANT	\N	PRESENT	0
249820	249817	19507S	PARTICIPANT	\N	PRESENT	0
249821	249817	14281W	PARTICIPANT	\N	PRESENT	0
249822	249817	08045X	PARTICIPANT	\N	PRESENT	0
249823	249817	01043Q	PARTICIPANT	\N	PRESENT	0
249824	249817	14205J	PARTICIPANT	\N	PRESENT	0
249825	249817	14265W	PARTICIPANT	\N	PRESENT	0
249826	249817	19745F	PARTICIPANT	\N	PRESENT	0
249827	249817	04088S	PARTICIPANT	\N	PRESENT	0
249828	249817	05012A	PARTICIPANT	\N	PRESENT	0
249829	249817	19735D	PARTICIPANT	\N	PRESENT	0
249830	249817	14107H	PARTICIPANT	\N	PRESENT	0
249831	249817	14173T	PARTICIPANT	\N	PRESENT	0
249832	249817	19269X	PARTICIPANT	\N	PRESENT	0
249868	249867	14030Q	PRESIDENT	0	PRESENT	0
249869	249867	08043V	PARTICIPANT	\N	PRESENT	0
249870	249867	19643A	PARTICIPANT	\N	PRESENT	0
249871	249867	19621T	PARTICIPANT	\N	PRESENT	0
249872	249867	08024S	PARTICIPANT	\N	PRESENT	0
249873	249867	11031D	PARTICIPANT	\N	PRESENT	0
249874	249867	80013X	PARTICIPANT	\N	PRESENT	0
249875	249867	14217N	PARTICIPANT	\N	PRESENT	0
249876	249867	19731Y	PARTICIPANT	\N	PRESENT	0
249877	249867	08031R	PARTICIPANT	\N	PRESENT	0
249878	249867	19697Q	PARTICIPANT	\N	PRESENT	0
249879	249867	14109K	PARTICIPANT	\N	PRESENT	0
249880	249867	11045K	PARTICIPANT	\N	PRESENT	0
249881	249867	19749K	PARTICIPANT	\N	PRESENT	0
249882	249867	19693L	PARTICIPANT	\N	EXCUSE	0
249883	249867	19599P	PARTICIPANT	\N	EXCUSE	0
249884	249867	14235Q	PARTICIPANT	\N	EXCUSE	0
249892	244266	01048V	PARTICIPANT	\N	EXCUSE	0
249893	244266	01058X	PARTICIPANT	\N	EXCUSE	0
249894	244266	19511N	PARTICIPANT	\N	EXCUSE	0
249895	244266	19709B	PARTICIPANT	\N	EXCUSE	0
249896	244266	19663E	PARTICIPANT	\N	EXCUSE	0
249897	244266	19683J	PARTICIPANT	\N	PRESENT	0
249901	249867	07029T	PARTICIPANT	\N	EXCUSE	0
249910	249902	08068F	PARTICIPANT	\N	PRESENT	0
249912	249902	14237S	PARTICIPANT	\N	PRESENT	0
249913	249902	19737F	PARTICIPANT	\N	PRESENT	0
249914	249902	08015R	PARTICIPANT	\N	PRESENT	0
249919	249917	08068F	PARTICIPANT	\N	PRESENT	0
249920	249917	08015R	PARTICIPANT	\N	PRESENT	0
249997	244266	14093U	PARTICIPANT	\N	PRESENT	0
249998	244266	80013X	PARTICIPANT	\N	PRESENT	0
249999	244266	14221J	PARTICIPANT	\N	PRESENT	0
250000	244266	19593H	PARTICIPANT	\N	PRESENT	0
250001	244266	04043D	PARTICIPANT	\N	PRESENT	0
250003	249612	11045K	PARTICIPANT	\N	PRESENT	0
250004	249612	11027H	PARTICIPANT	\N	PRESENT	0
250005	249612	95062K	PARTICIPANT	\N	PRESENT	0
250006	249612	19737F	PARTICIPANT	\N	PRESENT	0
250071	250070	07029T	PARTICIPANT	\N	PRESENT	0
250321	250312	19531S	PARTICIPANT	\N	PRESENT	0
250322	250309	19531S	PARTICIPANT	\N	PRESENT	0
250370	250368	11070L	PARTICIPANT	\N	PRESENT	0
250454	250453	19575F	PARTICIPANT	\N	PRESENT	0
250455	250453	14255U	PARTICIPANT	\N	PRESENT	0
250456	250453	11083R	PARTICIPANT	\N	PRESENT	0
250457	250453	15447F	PARTICIPANT	\N	PRESENT	0
250458	250453	19553Y	PARTICIPANT	\N	PRESENT	0
250459	250453	11048N	PARTICIPANT	\N	PRESENT	0
250460	250453	19711U	PARTICIPANT	\N	PRESENT	0
250461	250453	14059S	PARTICIPANT	\N	PRESENT	0
250462	250453	14063N	PARTICIPANT	\N	PRESENT	0
250463	250453	04057K	PARTICIPANT	\N	PRESENT	0
250464	250453	14265W	PARTICIPANT	\N	PRESENT	0
266054	264238	14215L	PARTICIPANT	\N	PRESENT	0
266055	264238	19483C	PARTICIPANT	\N	PRESENT	0
266056	264238	14259Y	PARTICIPANT	\N	PRESENT	0
266057	264238	14053L	PARTICIPANT	\N	PRESENT	0
266058	264238	98035U	PARTICIPANT	\N	PRESENT	0
266059	264238	14065Q	PARTICIPANT	\N	PRESENT	0
266060	264238	19649G	PARTICIPANT	\N	PRESENT	0
266061	264238	11026G	PARTICIPANT	\N	PRESENT	0
266062	264238	01060R	PARTICIPANT	\N	PRESENT	0
266063	264238	19253P	PARTICIPANT	\N	PRESENT	0
266064	264238	19543W	PARTICIPANT	\N	PRESENT	0
266065	264238	04044E	PARTICIPANT	\N	PRESENT	0
266066	264238	19581D	PARTICIPANT	\N	PRESENT	0
266067	264238	04047H	PARTICIPANT	\N	PRESENT	0
266068	264238	11033F	PARTICIPANT	\N	PRESENT	0
266069	264238	14231L	PARTICIPANT	\N	PRESENT	0
266070	264238	14089Y	PARTICIPANT	\N	PRESENT	0
266071	264238	19729F	PARTICIPANT	\N	PRESENT	0
266072	264238	95063L	PARTICIPANT	\N	PRESENT	0
266073	264238	19629C	PARTICIPANT	\N	PRESENT	0
266074	264238	08044W	PARTICIPANT	\N	PRESENT	0
266075	264238	11085T	PARTICIPANT	\N	PRESENT	0
266076	264238	08018U	PARTICIPANT	\N	PRESENT	0
266077	264238	11049P	PARTICIPANT	\N	PRESENT	0
266078	264238	04008A	PARTICIPANT	\N	PRESENT	0
266079	264238	14021P	PARTICIPANT	\N	PRESENT	0
266080	264238	11072N	PARTICIPANT	\N	PRESENT	0
266100	262916	08009T	PRESIDENT	0	PRESENT	0
266106	263133	11077T	PARTICIPANT	\N	PRESENT	0
266414	263133	11043H	PARTICIPANT	\N	PRESENT	0
266492	266413	19741B	PARTICIPANT	\N	PRESENT	0
266493	266413	14030Q	PARTICIPANT	\N	PRESENT	0
266494	266413	04040A	PARTICIPANT	\N	PRESENT	0
266495	266413	19367Y	PARTICIPANT	\N	PRESENT	0
266496	266413	14089Y	PARTICIPANT	\N	PRESENT	0
266497	266413	19545Y	PARTICIPANT	\N	PRESENT	0
266498	266413	14357A	PARTICIPANT	\N	PRESENT	0
266499	266413	17589D	PARTICIPANT	\N	PRESENT	0
266500	266413	95030B	PARTICIPANT	\N	PRESENT	0
266501	266413	97011G	PARTICIPANT	\N	PRESENT	0
266502	266413	14123H	PARTICIPANT	\N	PRESENT	0
266503	266413	98022P	PARTICIPANT	\N	PRESENT	0
266504	266413	14179A	PARTICIPANT	\N	PRESENT	0
266505	266413	08015R	PARTICIPANT	\N	PRESENT	0
266506	266413	08034U	PARTICIPANT	\N	PRESENT	0
266507	266413	19581D	PARTICIPANT	\N	PRESENT	0
266508	266413	11085T	PARTICIPANT	\N	PRESENT	0
266509	266413	14147R	PARTICIPANT	\N	PRESENT	0
266510	266413	14223L	PARTICIPANT	\N	PRESENT	0
266511	266413	95062K	PARTICIPANT	\N	PRESENT	0
266512	266413	11041F	PARTICIPANT	\N	PRESENT	0
266513	266413	19737F	PARTICIPANT	\N	PRESENT	0
266514	266413	18083K	PARTICIPANT	\N	PRESENT	0
266626	263133	07034Q	PARTICIPANT	\N	PRESENT	0
266627	263133	19731Y	PARTICIPANT	\N	PRESENT	0
266628	263133	19467C	PARTICIPANT	\N	PRESENT	0
266629	263133	19575F	PARTICIPANT	\N	PRESENT	0
266630	263133	89017R	PARTICIPANT	\N	PRESENT	0
266631	263133	19715Y	PARTICIPANT	\N	PRESENT	0
266632	263133	11104D	PARTICIPANT	\N	PRESENT	0
266633	263133	19667J	PARTICIPANT	\N	PRESENT	0
266634	263133	19673G	PARTICIPANT	\N	PRESENT	0
266635	263133	19415P	PARTICIPANT	\N	PRESENT	0
266636	263133	11099A	PARTICIPANT	\N	PRESENT	0
266637	263133	19387D	PARTICIPANT	\N	PRESENT	0
266638	263133	14038Y	PARTICIPANT	\N	PRESENT	0
266639	263133	19629C	PARTICIPANT	\N	PRESENT	0
266641	263133	14059S	PARTICIPANT	\N	PRESENT	0
266642	266640	11070L	PARTICIPANT	\N	PRESENT	0
266643	266640	08034U	PARTICIPANT	\N	PRESENT	0
266644	266640	11072N	PARTICIPANT	\N	PRESENT	0
266645	263133	04038G	PARTICIPANT	\N	PRESENT	0
266646	266640	14241N	PARTICIPANT	\N	PRESENT	0
266647	263133	14065Q	PARTICIPANT	\N	PRESENT	0
266648	263133	14147R	PARTICIPANT	\N	PRESENT	0
266649	263133	14041T	PARTICIPANT	\N	PRESENT	0
266650	263133	19447X	PARTICIPANT	\N	PRESENT	0
266651	263133	08020N	PARTICIPANT	\N	PRESENT	0
266652	263133	14211G	PARTICIPANT	\N	PRESENT	0
266653	263133	19583F	PARTICIPANT	\N	PRESENT	0
266654	263133	05008E	PARTICIPANT	\N	PRESENT	0
266655	263133	19671E	PARTICIPANT	\N	PRESENT	0
266656	263133	04035D	PARTICIPANT	\N	PRESENT	0
266657	263133	19543W	PARTICIPANT	\N	PRESENT	0
266658	263133	14089Y	PARTICIPANT	\N	PRESENT	0
266659	263133	14105F	PARTICIPANT	\N	PRESENT	0
266660	263133	95062K	PARTICIPANT	\N	PRESENT	0
266661	263133	14063N	PARTICIPANT	\N	PRESENT	0
266662	263133	08068F	PARTICIPANT	\N	PRESENT	0
266663	263133	19507S	PARTICIPANT	\N	PRESENT	0
266664	263133	97011G	PARTICIPANT	\N	PRESENT	0
266665	263133	19253P	PARTICIPANT	\N	PRESENT	0
266666	263133	08044W	PARTICIPANT	\N	PRESENT	0
266667	263133	19747H	PARTICIPANT	\N	PRESENT	0
266668	263133	08034U	PARTICIPANT	\N	PRESENT	0
266669	263133	19301E	PARTICIPANT	\N	PRESENT	0
266670	263133	14215L	PARTICIPANT	\N	PRESENT	0
266671	263133	14111D	PARTICIPANT	\N	PRESENT	0
266672	262916	19333N	PARTICIPANT	\N	PRESENT	0
266673	262916	14031R	PARTICIPANT	\N	PRESENT	0
266674	262916	19387D	PARTICIPANT	\N	PRESENT	0
266675	262916	14169X	PARTICIPANT	\N	PRESENT	0
266676	262916	18083K	PARTICIPANT	\N	PRESENT	0
266677	262916	19551W	PARTICIPANT	\N	PRESENT	0
266678	262916	80027E	PARTICIPANT	\N	PRESENT	0
266679	262916	14051J	PARTICIPANT	\N	PRESENT	0
266680	262916	19503N	PARTICIPANT	\N	PRESENT	0
266681	262916	19347U	PARTICIPANT	\N	PRESENT	0
266682	262916	19739H	PARTICIPANT	\N	PRESENT	0
266683	262916	19745F	PARTICIPANT	\N	PRESENT	0
266684	262916	19525U	PARTICIPANT	\N	PRESENT	0
266686	262916	05012A	PARTICIPANT	\N	PRESENT	0
266687	262916	17637T	PARTICIPANT	\N	PRESENT	0
266689	262916	19383Y	PARTICIPANT	\N	PRESENT	0
266690	262916	19549D	PARTICIPANT	\N	PRESENT	0
266691	262916	19637C	PARTICIPANT	\N	PRESENT	0
266692	262916	02002K	PARTICIPANT	\N	PRESENT	0
266693	262916	08024S	PARTICIPANT	\N	PRESENT	0
266694	262916	11065P	PARTICIPANT	\N	PRESENT	0
266695	262916	14038Y	PARTICIPANT	\N	PRESENT	0
266697	262916	19737F	PARTICIPANT	\N	PRESENT	0
266698	262916	04097T	PARTICIPANT	\N	PRESENT	0
266700	263133	11064N	PARTICIPANT	\N	PRESENT	0
266701	263133	04057K	PARTICIPANT	\N	PRESENT	0
266746	263146	11077T	PARTICIPANT	\N	PRESENT	0
266747	263146	95063L	PARTICIPANT	\N	PRESENT	0
266748	263146	05008E	PARTICIPANT	\N	PRESENT	0
266750	263146	14063N	PARTICIPANT	\N	PRESENT	0
266751	263146	19715Y	PARTICIPANT	\N	PRESENT	0
266781	263146	14107H	PARTICIPANT	\N	PRESENT	0
266753	263146	01028R	PARTICIPANT	\N	PRESENT	0
266754	263146	04057K	PARTICIPANT	\N	PRESENT	0
266755	263146	11064N	PARTICIPANT	\N	PRESENT	0
266756	263146	19673G	PARTICIPANT	\N	PRESENT	0
266757	263146	19667J	PARTICIPANT	\N	PRESENT	0
266758	263146	19467C	PARTICIPANT	\N	PRESENT	0
266759	263146	19507S	PARTICIPANT	\N	PRESENT	0
266760	263146	14041T	PARTICIPANT	\N	PRESENT	0
266761	263146	95062K	PARTICIPANT	\N	PRESENT	0
266762	263146	14211G	PARTICIPANT	\N	PRESENT	0
266763	263146	11033F	PARTICIPANT	\N	PRESENT	0
266764	263146	19253P	PARTICIPANT	\N	PRESENT	0
266765	263146	08044W	PARTICIPANT	\N	PRESENT	0
266766	263146	14179A	PARTICIPANT	\N	PRESENT	0
266767	263146	19543W	PARTICIPANT	\N	PRESENT	0
266768	263146	14059S	PARTICIPANT	\N	PRESENT	0
266769	263146	19733B	PARTICIPANT	\N	PRESENT	0
266770	263146	19731Y	PARTICIPANT	\N	PRESENT	0
266771	263146	97011G	PARTICIPANT	\N	PRESENT	0
266772	263146	14026U	PARTICIPANT	\N	PRESENT	0
266773	263146	14331P	PARTICIPANT	\N	PRESENT	0
266774	263146	19621T	PARTICIPANT	\N	PRESENT	0
266775	263146	19533U	PARTICIPANT	\N	PRESENT	0
266776	263146	14089Y	PARTICIPANT	\N	PRESENT	0
266777	263146	14083S	PARTICIPANT	\N	PRESENT	0
266778	263146	19747H	PARTICIPANT	\N	PRESENT	0
266779	263146	14215L	PARTICIPANT	\N	PRESENT	0
244667	244121	19741B	PARTICIPANT	\N	PRESENT	0
244668	244121	19667J	PARTICIPANT	\N	PRESENT	0
244669	244121	11040E	PARTICIPANT	\N	PRESENT	0
244670	244121	14083S	PARTICIPANT	\N	PRESENT	0
244671	244121	11053K	PARTICIPANT	\N	PRESENT	0
244672	244121	14085U	PARTICIPANT	\N	PRESENT	0
244673	244121	04071H	PARTICIPANT	\N	PRESENT	0
244674	244121	11074Q	PARTICIPANT	\N	PRESENT	0
244675	244121	19647E	PARTICIPANT	\N	PRESENT	0
244676	244121	19531S	PARTICIPANT	\N	PRESENT	0
244677	244121	99004R	PARTICIPANT	\N	PRESENT	0
244678	244121	04061F	PARTICIPANT	\N	PRESENT	0
244679	244121	19711U	PARTICIPANT	\N	PRESENT	0
244680	244121	08034U	PARTICIPANT	\N	PRESENT	0
244666	244121	89017R	PARTICIPANT	\N	PRESENT	0
244681	244121	19671E	PARTICIPANT	\N	PRESENT	0
244682	244121	08011M	PARTICIPANT	\N	PRESENT	0
244683	244121	14253S	PARTICIPANT	\N	PRESENT	0
244684	244121	19349W	PARTICIPANT	\N	PRESENT	0
244685	244121	14331P	PARTICIPANT	\N	PRESENT	0
244686	244121	14225N	PARTICIPANT	\N	PRESENT	0
244687	244121	14173T	PARTICIPANT	\N	PRESENT	0
245264	244782	11048N	PARTICIPANT	\N	PRESENT	0
245265	244782	11067R	PARTICIPANT	\N	PRESENT	0
245266	244782	19749K	PARTICIPANT	\N	PRESENT	0
245267	244782	19479G	PARTICIPANT	\N	PRESENT	0
247276	247275	08045X	PARTICIPANT	\N	PRESENT	0
247277	247275	14135M	PARTICIPANT	\N	PRESENT	0
247278	247275	19737F	PARTICIPANT	\N	PRESENT	0
247279	247275	14173T	PARTICIPANT	\N	PRESENT	0
247280	247275	19667J	PARTICIPANT	\N	PRESENT	0
247281	247275	19383Y	PARTICIPANT	\N	PRESENT	0
247282	247275	19573D	PARTICIPANT	\N	PRESENT	0
247283	247275	02002K	PARTICIPANT	\N	PRESENT	0
247492	247485	14065Q	PARTICIPANT	\N	PRESENT	0
247495	247485	19549D	PARTICIPANT	\N	PRESENT	0
247513	247485	14079W	PARTICIPANT	\N	PRESENT	0
247503	247485	14089Y	PARTICIPANT	\N	PRESENT	0
247510	247485	14083S	PARTICIPANT	\N	PRESENT	0
247517	247485	19569H	PARTICIPANT	\N	PRESENT	0
247521	247485	17637T	PARTICIPANT	\N	PRESENT	0
247523	247485	10015M	PARTICIPANT	\N	PRESENT	0
249911	244790	19573D	PARTICIPANT	\N	EXCUSE	0
249915	249718	19573D	PARTICIPANT	\N	EXCUSE	0
249923	244799	19573D	PARTICIPANT	\N	EXCUSE	0
250952	250129	19703U	PARTICIPANT	\N	PRESENT	0
250953	250129	14213J	PARTICIPANT	\N	PRESENT	0
250954	250129	19415P	PARTICIPANT	\N	PRESENT	0
250955	250129	14223L	PARTICIPANT	\N	PRESENT	0
250956	250129	11067R	PARTICIPANT	\N	PRESENT	0
250957	250129	14119M	PARTICIPANT	\N	PRESENT	0
250959	250958	14071N	PARTICIPANT	\N	PRESENT	0
250961	250960	14071N	PARTICIPANT	\N	PRESENT	0
250962	250960	19723Y	PARTICIPANT	\N	PRESENT	0
251968	250533	14042U	PRESIDENT	1	PRESENT	0
251970	250533	14281W	PARTICIPANT	\N	PRESENT	0
251972	250533	14087W	PARTICIPANT	\N	PRESENT	0
251973	250533	14355X	PARTICIPANT	\N	PRESENT	0
251975	250533	08048B	PARTICIPANT	\N	EXCUSE	0
251977	250533	19727D	PARTICIPANT	\N	PRESENT	0
251978	250533	14213J	PARTICIPANT	\N	PRESENT	0
251979	250533	19723Y	PARTICIPANT	\N	PRESENT	0
251981	250533	17779H	PARTICIPANT	\N	PRESENT	0
251983	250533	11067R	PARTICIPANT	\N	PRESENT	0
251985	250533	14223L	PARTICIPANT	\N	PRESENT	0
251987	250533	04092N	PARTICIPANT	\N	EXCUSE	0
251989	250533	14119M	PARTICIPANT	\N	PRESENT	0
251990	250533	11097X	PRESIDENT	0	PRESENT	0
251992	250533	04045F	PARTICIPANT	\N	EXCUSE	0
251994	250533	19703U	PARTICIPANT	\N	PRESENT	0
251996	250533	19527W	PARTICIPANT	\N	EXCUSE	0
252285	240298	01043Q	PARTICIPANT	0	PRESENT	0
252286	240298	19515S	PARTICIPANT	0	PRESENT	0
252287	240298	19575F	PARTICIPANT	0	PRESENT	0
252288	240298	14223L	PARTICIPANT	0	PRESENT	0
252289	240298	19731Y	PARTICIPANT	0	PRESENT	0
252290	240298	19577H	PARTICIPANT	0	PRESENT	0
252291	240298	19735D	PARTICIPANT	0	PRESENT	0
252292	240298	14107H	PARTICIPANT	0	PRESENT	0
252293	240298	14227Q	PARTICIPANT	0	PRESENT	0
252294	240298	19593H	PARTICIPANT	0	PRESENT	0
252295	240298	08043V	PARTICIPANT	0	PRESENT	0
252296	240298	08024S	PARTICIPANT	0	PRESENT	0
252297	240298	01025N	PARTICIPANT	0	PRESENT	0
252298	240298	19673G	PARTICIPANT	0	PRESENT	0
252299	240298	19333N	PARTICIPANT	0	PRESENT	0
252300	240298	19525U	PARTICIPANT	0	PRESENT	0
252301	240298	14197C	PARTICIPANT	0	PRESENT	0
252302	240298	19621T	PARTICIPANT	0	PRESENT	0
252303	240298	19369B	PARTICIPANT	0	PRESENT	0
252304	240298	04057K	PARTICIPANT	0	PRESENT	0
252305	240298	14030Q	PARTICIPANT	0	PRESENT	0
252306	240298	14229S	PARTICIPANT	0	PRESENT	0
252307	240298	11027H	PARTICIPANT	0	PRESENT	0
252308	240298	14039A	PARTICIPANT	0	PRESENT	0
252309	240298	19507S	PARTICIPANT	0	PRESENT	0
252310	240298	18083K	PARTICIPANT	0	PRESENT	0
252311	240298	11104D	PARTICIPANT	0	PRESENT	0
252312	240298	19611R	PARTICIPANT	0	PRESENT	0
252313	240298	14231L	PARTICIPANT	0	PRESENT	0
252314	240298	19713W	PARTICIPANT	0	PRESENT	0
252315	240298	04070G	PARTICIPANT	0	PRESENT	0
252316	240298	19631V	PARTICIPANT	0	PRESENT	0
252317	240298	01034P	PARTICIPANT	0	PRESENT	0
252318	240298	19717B	PARTICIPANT	0	PRESENT	0
252319	240298	19387D	PARTICIPANT	0	PRESENT	0
252320	240298	11045K	PARTICIPANT	0	PRESENT	0
252321	240298	19413M	PARTICIPANT	0	PRESENT	0
252322	240298	19697Q	PARTICIPANT	0	PRESENT	0
252323	240298	19301E	PARTICIPANT	0	PRESENT	0
252324	240298	19269X	PARTICIPANT	0	PRESENT	0
252325	240298	19649G	PARTICIPANT	0	PRESENT	0
252326	240298	14021P	PARTICIPANT	0	PRESENT	0
252327	240298	19335Q	PARTICIPANT	0	PRESENT	0
252328	240298	14059S	PARTICIPANT	0	PRESENT	0
252329	240298	10006L	PARTICIPANT	0	PRESENT	0
252330	240298	08028W	PARTICIPANT	0	PRESENT	0
252331	240298	95015C	PARTICIPANT	0	PRESENT	0
252332	240298	19629C	PARTICIPANT	0	PRESENT	0
252333	240298	04018C	PARTICIPANT	0	PRESENT	0
252334	240298	14042U	PARTICIPANT	0	PRESENT	0
252335	240298	14073Q	PARTICIPANT	0	PRESENT	0
252336	240298	14327T	PARTICIPANT	0	PRESENT	0
252337	240298	11085T	PARTICIPANT	0	PRESENT	0
252338	240298	14147R	PARTICIPANT	0	PRESENT	0
252339	240298	19467C	PARTICIPANT	0	PRESENT	0
252340	240298	19295A	PARTICIPANT	0	PRESENT	0
252341	240298	19715Y	PARTICIPANT	0	PRESENT	0
252342	240298	08012N	PARTICIPANT	0	PRESENT	0
252343	240298	14083S	PARTICIPANT	0	PRESENT	0
252344	240298	19553Y	PARTICIPANT	0	PRESENT	0
252345	240298	14281W	PARTICIPANT	0	PRESENT	0
252346	240298	11053K	PARTICIPANT	0	PRESENT	0
252347	240298	14109K	PARTICIPANT	0	PRESENT	0
252348	240298	14111D	PARTICIPANT	0	PRESENT	0
252349	240298	08031R	PARTICIPANT	0	PRESENT	0
252350	240298	04043D	PARTICIPANT	0	PRESENT	0
252351	240298	19565D	PARTICIPANT	0	PRESENT	0
252352	240298	19683J	PARTICIPANT	0	PRESENT	0
252353	240298	08017T	PARTICIPANT	0	PRESENT	0
252354	240298	11070L	PARTICIPANT	0	PRESENT	0
252355	240298	14241N	PARTICIPANT	0	PRESENT	0
252356	240298	14121F	PARTICIPANT	0	PRESENT	0
252357	240298	19549D	PARTICIPANT	0	PRESENT	0
252358	240298	04061F	PARTICIPANT	0	PRESENT	0
252359	240298	14249W	PARTICIPANT	0	PRESENT	0
252360	240298	04086Q	PARTICIPANT	0	PRESENT	0
252361	240298	08010L	PARTICIPANT	0	PRESENT	0
252362	240298	19583F	PARTICIPANT	0	PRESENT	0
252363	240298	19703U	PARTICIPANT	0	PRESENT	0
252364	240298	11031D	PARTICIPANT	0	PRESENT	0
252365	240298	14215L	PARTICIPANT	0	PRESENT	0
252366	240298	14119M	PARTICIPANT	0	PRESENT	0
252367	240298	14265W	PARTICIPANT	0	PRESENT	0
252368	240298	14055N	PARTICIPANT	0	PRESENT	0
252369	240298	19747H	PARTICIPANT	0	PRESENT	0
252370	240298	19619A	PARTICIPANT	0	PRESENT	0
252371	240298	14063N	PARTICIPANT	0	PRESENT	0
252372	240298	14257W	PARTICIPANT	0	PRESENT	0
252373	240298	08035V	PARTICIPANT	0	PRESENT	0
252374	240298	11109J	PARTICIPANT	0	PRESENT	0
252375	240298	19691J	PARTICIPANT	0	PRESENT	0
252376	240298	14331P	PARTICIPANT	0	PRESENT	0
252377	240298	08055A	PARTICIPANT	0	PRESENT	0
252378	240298	14123H	PARTICIPANT	0	PRESENT	0
252379	240298	14219Q	PARTICIPANT	0	PRESENT	0
267188	267187	96004D	PRESIDENT	0	PRESENT	0
267189	267187	08014Q	PARTICIPANT	\N	PRESENT	0
267190	267187	11083R	PARTICIPANT	\N	PRESENT	0
267191	267187	19725B	PARTICIPANT	\N	PRESENT	0
267192	267187	19569H	PARTICIPANT	\N	PRESENT	0
267193	267187	14097Y	PARTICIPANT	\N	PRESENT	0
267194	267187	14001X	PARTICIPANT	\N	PRESENT	0
267195	267187	14221J	PARTICIPANT	\N	PRESENT	0
267196	267187	19593H	PARTICIPANT	\N	PRESENT	0
267197	267187	14229S	PARTICIPANT	\N	PRESENT	0
267198	267187	10015M	PARTICIPANT	\N	PRESENT	0
267199	267187	14331P	PARTICIPANT	\N	PRESENT	0
267200	267187	14135M	PARTICIPANT	\N	EXCUSE	0
267201	267187	08039A	PARTICIPANT	\N	EXCUSE	0
267202	267187	04097T	PARTICIPANT	\N	EXCUSE	0
267203	267187	14065Q	PARTICIPANT	\N	EXCUSE	0
269745	269744	14239U	PARTICIPANT	\N	PRESENT	0
269747	269744	19295A	PARTICIPANT	\N	EXCUSE	0
267407	256504	04038G	PARTICIPANT	\N	PRESENT	0
267421	267420	14089Y	PARTICIPANT	\N	PRESENT	0
269746	269744	14195A	PARTICIPANT	\N	PRESENT	0
269748	269744	14041T	PARTICIPANT	\N	PRESENT	0
269749	269744	14215L	PARTICIPANT	\N	PRESENT	0
269750	269744	19697Q	PARTICIPANT	\N	PRESENT	0
269751	269744	14031R	PARTICIPANT	\N	PRESENT	0
269752	269744	14147R	PARTICIPANT	\N	PRESENT	0
269753	269744	11067R	PARTICIPANT	\N	PRESENT	0
269754	269744	14223L	PARTICIPANT	\N	PRESENT	0
269755	269744	04044E	PRESIDENT	0	PRESENT	0
270086	270085	08058D	PARTICIPANT	\N	PRESENT	0
270087	270085	14133K	PARTICIPANT	\N	PRESENT	0
270089	270088	14255U	PARTICIPANT	\N	PRESENT	0
270090	270088	08053X	PARTICIPANT	\N	PRESENT	0
270185	270184	98029W	PARTICIPANT	\N	PRESENT	0
270186	270184	08056B	PARTICIPANT	\N	PRESENT	0
270187	270184	19421M	PARTICIPANT	\N	PRESENT	0
270188	270184	11026G	PARTICIPANT	\N	PRESENT	0
270189	270184	98050T	PARTICIPANT	\N	PRESENT	0
270192	270191	98029W	PARTICIPANT	\N	PRESENT	0
270193	270191	08056B	PARTICIPANT	\N	PRESENT	0
270194	270191	19611R	PARTICIPANT	\N	PRESENT	0
270195	270191	11026G	PARTICIPANT	\N	PRESENT	0
270196	270191	98050T	PARTICIPANT	\N	PRESENT	0
270197	270191	19421M	PARTICIPANT	\N	PRESENT	0
270378	268440	19533U	PARTICIPANT	\N	PRESENT	0
270577	270441	11074Q	PARTICIPANT	\N	PRESENT	0
270578	270441	08011M	PARTICIPANT	\N	PRESENT	0
270593	270439	11053K	PARTICIPANT	\N	PRESENT	0
270594	270439	14225N	PARTICIPANT	\N	PRESENT	0
270595	270439	11070L	PARTICIPANT	\N	PRESENT	0
270596	270439	14085U	PARTICIPANT	\N	PRESENT	0
270597	270439	08010L	PARTICIPANT	\N	PRESENT	0
270598	270439	14253S	PARTICIPANT	\N	PRESENT	0
270599	270439	11048N	PARTICIPANT	\N	PRESENT	0
270600	270439	19711U	PARTICIPANT	\N	PRESENT	0
270601	270439	19651A	PARTICIPANT	\N	PRESENT	0
270602	270439	19689Q	PARTICIPANT	\N	PRESENT	0
270603	270439	08011M	PARTICIPANT	\N	PRESENT	0
270604	270439	14199E	PARTICIPANT	\N	PRESENT	0
270605	270439	19741B	PARTICIPANT	\N	PRESENT	0
270606	270439	99004R	PARTICIPANT	\N	PRESENT	0
270607	270439	04061F	PARTICIPANT	\N	PRESENT	0
270608	270439	14327T	PARTICIPANT	\N	EXCUSE	0
270610	270439	04071H	PARTICIPANT	\N	PRESENT	0
270611	270439	11110B	PARTICIPANT	\N	PRESENT	0
270612	270439	19647E	PARTICIPANT	\N	PRESENT	0
270613	270439	89017R	PARTICIPANT	\N	PRESENT	0
270614	270439	19531S	PARTICIPANT	\N	PRESENT	0
270653	270652	08058D	PARTICIPANT	\N	PRESENT	0
270654	270652	04071H	PARTICIPANT	\N	PRESENT	0
270655	270652	19251M	PARTICIPANT	\N	PRESENT	0
270656	270652	11049P	PARTICIPANT	\N	PRESENT	0
270657	270652	14097Y	PARTICIPANT	\N	PRESENT	0
270658	270652	19703U	PARTICIPANT	\N	PRESENT	0
270661	270652	08035V	PARTICIPANT	\N	PRESENT	0
270673	270652	19729F	PARTICIPANT	\N	PRESENT	0
270708	270652	19443T	PARTICIPANT	\N	PRESENT	0
270740	263473	14259Y	PARTICIPANT	\N	PRESENT	0
270741	263473	14115H	PARTICIPANT	\N	PRESENT	0
270742	263473	08009T	PARTICIPANT	\N	PRESENT	0
270743	263473	14063N	PARTICIPANT	\N	PRESENT	0
270744	263473	14219Q	PARTICIPANT	\N	PRESENT	0
270745	263473	11104D	PARTICIPANT	\N	PRESENT	0
270746	263473	08015R	PARTICIPANT	\N	PRESENT	0
270747	263473	18083K	PARTICIPANT	\N	PRESENT	0
270748	263473	14215L	PARTICIPANT	\N	PRESENT	0
270749	263473	14109K	PARTICIPANT	\N	PRESENT	0
270750	263473	01025N	PARTICIPANT	\N	PRESENT	0
270751	263473	19335Q	PARTICIPANT	\N	PRESENT	0
270752	263473	19479G	PARTICIPANT	\N	PRESENT	0
270753	270440	19647E	PARTICIPANT	\N	PRESENT	0
270754	270440	19479G	PARTICIPANT	\N	PRESENT	0
270755	270440	19667J	PARTICIPANT	\N	PRESENT	0
270756	270440	14225N	PARTICIPANT	\N	PRESENT	0
270757	270440	07029T	PARTICIPANT	\N	PRESENT	0
270758	270440	14085U	PARTICIPANT	\N	PRESENT	0
270759	270440	19741B	PARTICIPANT	\N	PRESENT	0
270760	270440	14121F	PARTICIPANT	\N	PRESENT	0
270761	270440	08010L	PARTICIPANT	\N	PRESENT	0
270762	263473	11048N	PARTICIPANT	\N	PRESENT	0
270763	263473	19347U	PARTICIPANT	\N	PRESENT	0
270764	263473	14121F	PARTICIPANT	\N	PRESENT	0
270765	263473	14267Y	PARTICIPANT	\N	PRESENT	0
270766	263473	08028W	PARTICIPANT	\N	PRESENT	0
270767	263473	14135M	PARTICIPANT	\N	PRESENT	0
270768	263473	97011G	PARTICIPANT	\N	PRESENT	0
270769	263473	05012A	PARTICIPANT	\N	PRESENT	0
270770	263473	17583W	PARTICIPANT	\N	PRESENT	0
270771	263473	19515S	PARTICIPANT	\N	PRESENT	0
270772	263473	14173T	PARTICIPANT	\N	PRESENT	0
270773	263473	16685X	PARTICIPANT	\N	PRESENT	0
270774	263473	19349W	PARTICIPANT	\N	PRESENT	0
270775	263473	80013X	PARTICIPANT	\N	PRESENT	0
270776	263473	08038Y	PARTICIPANT	\N	PRESENT	0
270777	263473	14223L	PARTICIPANT	\N	PRESENT	0
270778	263473	19441R	PARTICIPANT	\N	PRESENT	0
270779	263473	14029X	PARTICIPANT	\N	PRESENT	0
270780	263473	98022P	PARTICIPANT	\N	PRESENT	0
270781	263473	07029T	PARTICIPANT	\N	PRESENT	0
270870	263474	86034E	PARTICIPANT	\N	PRESENT	0
270874	263474	19347U	PARTICIPANT	\N	PRESENT	0
270875	263474	19593H	PARTICIPANT	\N	PRESENT	0
270876	263474	19695N	PARTICIPANT	\N	PRESENT	0
270877	263474	14121F	PARTICIPANT	\N	PRESENT	0
270878	263474	14107H	PARTICIPANT	\N	PRESENT	0
270879	263474	14227Q	PARTICIPANT	\N	PRESENT	0
270880	263474	14197C	PARTICIPANT	\N	PRESENT	0
270881	263474	08012N	PARTICIPANT	\N	PRESENT	0
270882	263474	14051J	PARTICIPANT	\N	PRESENT	0
270883	263474	08052W	PARTICIPANT	\N	PRESENT	0
270884	263474	11077T	PARTICIPANT	\N	PRESENT	0
270885	263474	14201E	PARTICIPANT	\N	PRESENT	0
270886	263474	98022P	PARTICIPANT	\N	PRESENT	0
270887	263474	99004R	PARTICIPANT	\N	PRESENT	0
270888	263474	14038Y	PARTICIPANT	\N	PRESENT	0
270889	263474	95015C	PARTICIPANT	\N	PRESENT	0
270890	263474	19349W	PARTICIPANT	\N	PRESENT	0
270891	263474	19549D	PARTICIPANT	\N	PRESENT	0
270892	263474	08060W	PARTICIPANT	\N	PRESENT	0
270893	263474	11041F	PARTICIPANT	\N	PRESENT	0
270894	263474	15447F	PARTICIPANT	\N	PRESENT	0
270895	263474	19631V	PARTICIPANT	\N	PRESENT	0
270896	263474	19527W	PARTICIPANT	\N	PRESENT	0
270897	263474	04097T	PARTICIPANT	\N	PRESENT	0
270898	263474	19503N	PARTICIPANT	\N	PRESENT	0
270899	263474	14259Y	PARTICIPANT	\N	PRESENT	0
270900	263474	19629C	PARTICIPANT	\N	PRESENT	0
270901	263474	19253P	PARTICIPANT	\N	PRESENT	0
270902	263474	11115U	PARTICIPANT	\N	PRESENT	0
270903	263474	19679N	PARTICIPANT	\N	PRESENT	0
270904	263474	01048V	PARTICIPANT	\N	PRESENT	0
270905	263474	19691J	PARTICIPANT	\N	PRESENT	0
270906	263474	19721W	PARTICIPANT	\N	PRESENT	0
270907	263474	16685X	PARTICIPANT	\N	PRESENT	0
270908	263474	19515S	PARTICIPANT	\N	PRESENT	0
270909	263474	19441R	PARTICIPANT	\N	PRESENT	0
270910	263474	14219Q	PARTICIPANT	\N	PRESENT	0
270911	263474	14191V	PARTICIPANT	\N	PRESENT	0
270912	263474	14211G	PARTICIPANT	\N	PRESENT	0
255538	255500	19349W	PARTICIPANT	\N	PRESENT	0
255539	255500	19269X	PARTICIPANT	\N	PRESENT	0
255540	255500	08049C	PARTICIPANT	\N	PRESENT	0
255541	255500	19347U	PARTICIPANT	\N	PRESENT	0
255552	255500	19511N	PARTICIPANT	\N	PRESENT	0
256201	256121	19467C	PARTICIPANT	\N	PRESENT	0
256202	256121	14026U	PARTICIPANT	\N	PRESENT	0
256203	256121	14331P	PARTICIPANT	\N	PRESENT	0
256204	256121	14135M	PARTICIPANT	\N	PRESENT	0
256205	256121	19695N	PARTICIPANT	\N	PRESENT	0
256206	256121	19333N	PARTICIPANT	\N	PRESENT	0
256207	256121	14039A	PARTICIPANT	\N	PRESENT	0
256208	256121	19441R	PARTICIPANT	\N	PRESENT	0
256209	256121	14033T	PARTICIPANT	\N	PRESENT	0
256210	256121	19521Q	PARTICIPANT	\N	PRESENT	0
256211	256121	11040E	PARTICIPANT	\N	PRESENT	0
256212	256121	19507S	PARTICIPANT	\N	PRESENT	0
256213	256121	11056N	PARTICIPANT	\N	PRESENT	0
256214	256121	14267Y	PARTICIPANT	\N	PRESENT	0
256215	256121	14059S	PARTICIPANT	\N	PRESENT	0
256216	256121	92040Q	PARTICIPANT	\N	PRESENT	0
256217	256121	80013X	PARTICIPANT	\N	PRESENT	0
256218	256121	19673G	PARTICIPANT	\N	PRESENT	0
256219	256121	14093U	PARTICIPANT	\N	PRESENT	0
256220	256121	19563B	PARTICIPANT	\N	PRESENT	0
256221	256121	08052W	PARTICIPANT	\N	PRESENT	0
256222	256121	14221J	PARTICIPANT	\N	PRESENT	0
256223	256121	11085T	PARTICIPANT	\N	PRESENT	0
256224	256121	14085U	PARTICIPANT	\N	PRESENT	0
256225	256121	07033P	PARTICIPANT	\N	PRESENT	0
256226	256121	87003B	PARTICIPANT	\N	PRESENT	0
256227	256121	19681G	PARTICIPANT	\N	PRESENT	0
256228	256121	14265W	PARTICIPANT	\N	PRESENT	0
256229	256121	14051J	PARTICIPANT	\N	PRESENT	0
256230	256121	08049C	PARTICIPANT	\N	PRESENT	0
256231	256121	19707Y	PARTICIPANT	\N	PRESENT	0
256232	256121	19447X	PARTICIPANT	\N	PRESENT	0
256233	256121	95030B	PARTICIPANT	\N	PRESENT	0
256234	256121	08011M	PARTICIPANT	\N	PRESENT	0
256235	256121	98024R	PARTICIPANT	\N	PRESENT	0
256236	256121	14253S	PARTICIPANT	\N	PRESENT	0
256237	256121	04086Q	PARTICIPANT	\N	PRESENT	0
256238	256121	19705W	PARTICIPANT	\N	PRESENT	0
256239	256121	11080N	PARTICIPANT	\N	PRESENT	0
256240	256121	14211G	PARTICIPANT	\N	PRESENT	0
256241	256121	19347U	PARTICIPANT	\N	PRESENT	0
256242	256121	19679N	PARTICIPANT	\N	PRESENT	0
256243	256121	19687N	PARTICIPANT	\N	PRESENT	0
256244	256121	04035D	PARTICIPANT	\N	PRESENT	0
256245	256121	04059M	PARTICIPANT	\N	PRESENT	0
256246	256121	08028W	PARTICIPANT	\N	PRESENT	0
256247	256121	98035U	PARTICIPANT	\N	PRESENT	0
256248	256121	08055A	PARTICIPANT	\N	PRESENT	0
256249	256121	08045X	PARTICIPANT	\N	PRESENT	0
256250	256121	19575F	PARTICIPANT	\N	PRESENT	0
256251	256121	14151M	PARTICIPANT	\N	PRESENT	0
256252	256121	19593H	PARTICIPANT	\N	PRESENT	0
256253	256121	19667J	PARTICIPANT	\N	PRESENT	0
256254	256121	19703U	PARTICIPANT	\N	PRESENT	0
256255	256121	08060W	PARTICIPANT	\N	PRESENT	0
256256	256121	14173T	PARTICIPANT	\N	PRESENT	0
256257	256121	11104D	PARTICIPANT	\N	PRESENT	0
256258	256121	98005N	PARTICIPANT	\N	PRESENT	0
256259	256121	08016S	PARTICIPANT	\N	PRESENT	0
256260	256121	19727D	PARTICIPANT	\N	PRESENT	0
256261	256121	08012N	PARTICIPANT	\N	PRESENT	0
256262	256121	19443T	PARTICIPANT	\N	PRESENT	0
256263	256121	14107H	PARTICIPANT	\N	PRESENT	0
256264	256121	08024S	PARTICIPANT	\N	PRESENT	0
256265	256121	19489J	PARTICIPANT	\N	PRESENT	0
256266	256121	19415P	PARTICIPANT	\N	PRESENT	0
256267	256121	17779H	PARTICIPANT	\N	PRESENT	0
256268	256121	11110B	PARTICIPANT	\N	PRESENT	0
256269	256121	07029T	PARTICIPANT	\N	PRESENT	0
256270	256121	08062Y	PARTICIPANT	\N	PRESENT	0
256271	256121	08014Q	PARTICIPANT	\N	PRESENT	0
256272	256121	98050T	PARTICIPANT	\N	PRESENT	0
256273	256121	19725B	PARTICIPANT	\N	PRESENT	0
256274	256121	14028W	PARTICIPANT	\N	PRESENT	0
256275	256121	14281W	PARTICIPANT	\N	PRESENT	0
256276	256121	11103C	PARTICIPANT	\N	PRESENT	0
256277	256121	19527W	PARTICIPANT	\N	PRESENT	0
256278	256121	14001X	PARTICIPANT	\N	PRESENT	0
256279	256121	10006L	PARTICIPANT	\N	PRESENT	0
256280	256121	11067R	PARTICIPANT	\N	PRESENT	0
256281	256121	11048N	PARTICIPANT	\N	PRESENT	0
256282	256121	11054L	PARTICIPANT	\N	PRESENT	0
256283	256121	10015M	PARTICIPANT	\N	PRESENT	0
256284	256121	04038G	PARTICIPANT	\N	PRESENT	0
256285	256121	11031D	PARTICIPANT	\N	PRESENT	0
256286	256121	04044E	PARTICIPANT	\N	PRESENT	0
256287	256121	19675J	PARTICIPANT	\N	PRESENT	0
256288	256121	08061X	PARTICIPANT	\N	PRESENT	0
256289	256121	04045F	PARTICIPANT	\N	PRESENT	0
256290	256121	19349W	PARTICIPANT	\N	PRESENT	0
256291	256121	19723Y	PARTICIPANT	\N	PRESENT	0
256292	256121	19659J	PARTICIPANT	\N	PRESENT	0
256293	256121	19565D	PARTICIPANT	\N	PRESENT	0
256294	256121	19631V	PARTICIPANT	\N	PRESENT	0
256295	256121	19657G	PARTICIPANT	\N	PRESENT	0
256296	256121	19301E	PARTICIPANT	\N	PRESENT	0
256297	256121	11097X	PARTICIPANT	\N	PRESENT	0
256298	256121	14034U	PARTICIPANT	\N	PRESENT	0
256299	256121	11012A	PARTICIPANT	\N	PRESENT	0
256300	256121	19689Q	PARTICIPANT	\N	PRESENT	0
256301	256121	19383Y	PARTICIPANT	\N	PRESENT	0
256302	256121	14261S	PARTICIPANT	\N	PRESENT	0
256303	256121	14119M	PARTICIPANT	\N	PRESENT	0
256304	256121	14217N	PARTICIPANT	\N	PRESENT	0
256305	256121	19585H	PARTICIPANT	\N	PRESENT	0
256306	256121	19545Y	PARTICIPANT	\N	PRESENT	0
256307	256121	14187A	PARTICIPANT	\N	PRESENT	0
256308	256121	02002K	PARTICIPANT	\N	PRESENT	0
256309	256121	11064N	PARTICIPANT	\N	PRESENT	0
256310	256121	14195A	PARTICIPANT	\N	PRESENT	0
256311	256121	19671E	PARTICIPANT	\N	PRESENT	0
256312	256121	08043V	PARTICIPANT	\N	PRESENT	0
256313	256121	14109K	PARTICIPANT	\N	PRESENT	0
256314	256121	14277B	PARTICIPANT	\N	PRESENT	0
256315	256121	19367Y	PARTICIPANT	\N	PRESENT	0
256316	256121	19591F	PARTICIPANT	\N	PRESENT	0
256317	256121	11077T	PARTICIPANT	\N	PRESENT	0
256318	256121	11027H	PARTICIPANT	\N	PRESENT	0
256319	256121	14021P	PARTICIPANT	\N	PRESENT	0
256320	256121	19479G	PARTICIPANT	\N	PRESENT	0
256321	256121	01057W	PARTICIPANT	\N	PRESENT	0
256322	256121	19721W	PARTICIPANT	\N	PRESENT	0
256323	256121	19369B	PARTICIPANT	\N	PRESENT	0
256324	256121	19691J	PARTICIPANT	\N	PRESENT	0
256325	256121	14231L	PARTICIPANT	\N	PRESENT	0
256326	256121	14073Q	PARTICIPANT	\N	PRESENT	0
256327	256121	14083S	PARTICIPANT	\N	PRESENT	0
256328	256121	08035V	PARTICIPANT	\N	PRESENT	0
256329	256121	14097Y	PARTICIPANT	\N	PRESENT	0
256330	256121	14123H	PARTICIPANT	\N	PRESENT	0
256331	256121	01058X	PARTICIPANT	\N	PRESENT	0
256332	256121	14223L	PARTICIPANT	\N	PRESENT	0
256333	256121	08010L	PARTICIPANT	\N	PRESENT	0
256334	256121	14179A	PARTICIPANT	\N	PRESENT	0
256335	256121	01025N	PARTICIPANT	\N	PRESENT	0
256336	256121	14241N	PARTICIPANT	\N	PRESENT	0
256337	256121	14065Q	PARTICIPANT	\N	PRESENT	0
256338	256121	19637C	PARTICIPANT	\N	PRESENT	0
256339	256121	04043D	PARTICIPANT	\N	PRESENT	0
256340	256121	11045K	PARTICIPANT	\N	PRESENT	0
256341	256121	14255U	PARTICIPANT	\N	PRESENT	0
256342	256121	14259Y	PARTICIPANT	\N	PRESENT	0
256343	256121	11033F	PARTICIPANT	\N	PRESENT	0
256344	256121	14207L	PARTICIPANT	\N	PRESENT	0
256345	256121	01028R	PARTICIPANT	\N	PRESENT	0
256346	256121	11074Q	PARTICIPANT	\N	PRESENT	0
256347	256121	14115H	PARTICIPANT	\N	PRESENT	0
256348	256121	19549D	PARTICIPANT	\N	PRESENT	0
256349	256121	11099A	PARTICIPANT	\N	PRESENT	0
256350	256121	08058D	PARTICIPANT	\N	PRESENT	0
256351	256121	08019V	PARTICIPANT	\N	PRESENT	0
256352	256121	04097T	PARTICIPANT	\N	PRESENT	0
256353	256121	95041E	PARTICIPANT	\N	PRESENT	0
256354	256121	08031R	PARTICIPANT	\N	PRESENT	0
256355	256121	14042U	PARTICIPANT	\N	PRESENT	0
256356	256121	11043H	PARTICIPANT	\N	PRESENT	0
256357	256121	11109J	PARTICIPANT	\N	PRESENT	0
256358	256121	11072N	PARTICIPANT	\N	PRESENT	0
256359	256121	18083K	PARTICIPANT	\N	PRESENT	0
256360	256121	14251Q	PARTICIPANT	\N	PRESENT	0
256361	256121	04040A	PARTICIPANT	\N	PRESENT	0
256362	256121	14038Y	PARTICIPANT	\N	PRESENT	0
256363	256121	19749K	PARTICIPANT	\N	PRESENT	0
256364	256121	19533U	PARTICIPANT	\N	PRESENT	0
243112	239410	19747H	PARTICIPANT	\N	PRESENT	0
243113	239410	08068F	PARTICIPANT	\N	PRESENT	0
243114	239410	14207L	PARTICIPANT	\N	PRESENT	0
243115	239410	08028W	PARTICIPANT	\N	PRESENT	0
243116	239410	19467C	PARTICIPANT	\N	PRESENT	0
243117	239410	80013X	PARTICIPANT	\N	PRESENT	0
243118	239410	08038Y	PARTICIPANT	\N	PRESENT	0
243119	239410	19507S	PARTICIPANT	\N	PRESENT	0
243120	239410	14197C	PARTICIPANT	\N	PRESENT	0
243121	239410	17589D	PARTICIPANT	\N	PRESENT	0
243122	239410	14187A	PARTICIPANT	\N	PRESENT	0
243123	239410	01025N	PARTICIPANT	\N	PRESENT	0
243124	239410	19565D	PARTICIPANT	\N	PRESENT	0
243125	239410	14033T	PARTICIPANT	\N	PRESENT	0
243126	239410	14081Q	PARTICIPANT	\N	PRESENT	0
243127	239410	19511N	PARTICIPANT	\N	PRESENT	0
243128	239410	08015R	PARTICIPANT	\N	PRESENT	0
243129	239410	19441R	PARTICIPANT	\N	PRESENT	0
243130	239410	08062Y	PARTICIPANT	\N	PRESENT	0
243131	239410	14257W	PARTICIPANT	\N	PRESENT	0
243132	239410	14265W	PARTICIPANT	\N	PRESENT	0
243133	239410	04088S	PARTICIPANT	\N	PRESENT	0
243134	239410	11090Q	PARTICIPANT	\N	PRESENT	0
243135	239410	14135M	PARTICIPANT	\N	PRESENT	0
243136	239410	19619A	PARTICIPANT	\N	PRESENT	0
243137	239410	19413M	PARTICIPANT	\N	PRESENT	0
244307	244306	19253P	PARTICIPANT	\N	PRESENT	0
244309	244308	19253P	PARTICIPANT	\N	PRESENT	0
244311	244310	19253P	PARTICIPANT	\N	PRESENT	0
247253	247243	19729F	PARTICIPANT	\N	EXCUSE	0
249267	249266	19253P	PARTICIPANT	\N	PRESENT	0
249268	249266	04040A	PARTICIPANT	\N	PRESENT	0
249269	249266	19629C	PARTICIPANT	\N	PRESENT	0
249270	249266	14081Q	PARTICIPANT	\N	PRESENT	0
249271	249266	80027E	PARTICIPANT	\N	PRESENT	0
249272	249266	98050T	PARTICIPANT	\N	PRESENT	0
249273	249266	04045F	PARTICIPANT	\N	PRESENT	0
249274	249266	95067Q	PARTICIPANT	\N	PRESENT	0
249277	249276	04061F	PARTICIPANT	\N	PRESENT	0
249616	249613	11031D	PARTICIPANT	\N	PRESENT	0
249617	249613	04071H	PARTICIPANT	\N	PRESENT	0
249619	249613	14039A	PARTICIPANT	\N	PRESENT	0
249620	249613	14169X	PARTICIPANT	\N	PRESENT	0
268650	263174	19399H	PARTICIPANT	\N	PRESENT	0
268651	263174	95062K	PARTICIPANT	\N	PRESENT	0
268652	263174	19467C	PARTICIPANT	\N	PRESENT	0
268653	263174	19689Q	PARTICIPANT	\N	PRESENT	0
268654	263174	19573D	PARTICIPANT	\N	PRESENT	0
268655	263174	19479G	PARTICIPANT	\N	PRESENT	0
268656	263174	14331P	PARTICIPANT	\N	PRESENT	0
268657	263174	08034U	PARTICIPANT	\N	PRESENT	0
268658	263174	14215L	PARTICIPANT	\N	PRESENT	0
268659	263174	14237S	PARTICIPANT	\N	PRESENT	0
268660	263174	19709B	PARTICIPANT	\N	PRESENT	0
268661	263174	19667J	PARTICIPANT	\N	PRESENT	0
268662	263174	04035D	PARTICIPANT	\N	PRESENT	0
268663	263174	14097Y	PARTICIPANT	\N	PRESENT	0
268664	263174	19713W	PARTICIPANT	\N	PRESENT	0
268665	263174	19741B	PARTICIPANT	\N	PRESENT	0
268666	263174	14031R	PARTICIPANT	\N	PRESENT	0
268667	263174	10006L	PARTICIPANT	\N	PRESENT	0
268668	263174	19503N	PARTICIPANT	\N	PRESENT	0
268669	263174	14059S	PARTICIPANT	\N	PRESENT	0
268670	263174	14225N	PARTICIPANT	\N	PRESENT	0
268671	263174	19253P	PARTICIPANT	\N	PRESENT	0
268672	263174	08010L	PARTICIPANT	\N	PRESENT	0
268673	263174	97011G	PARTICIPANT	\N	PRESENT	0
268674	263174	11026G	PARTICIPANT	\N	PRESENT	0
268675	263174	98050T	PARTICIPANT	\N	PRESENT	0
268676	263174	04043D	PARTICIPANT	\N	PRESENT	0
268677	263174	14079W	PARTICIPANT	\N	PRESENT	0
268678	263174	08049C	PARTICIPANT	\N	PRESENT	0
268679	263174	14223L	PARTICIPANT	\N	PRESENT	0
268680	263174	19629C	PARTICIPANT	\N	PRESENT	0
268681	263174	14030Q	PARTICIPANT	\N	PRESENT	0
268682	263174	80013X	PARTICIPANT	\N	PRESENT	0
268683	263174	19543W	PARTICIPANT	\N	PRESENT	0
268684	263174	19697Q	PARTICIPANT	\N	PRESENT	0
268685	263174	05012A	PARTICIPANT	\N	PRESENT	0
268686	263174	01028R	PARTICIPANT	\N	PRESENT	0
268687	263174	11104D	PARTICIPANT	\N	PRESENT	0
268688	263174	19647E	PARTICIPANT	\N	PRESENT	0
268689	263174	19669L	PARTICIPANT	\N	PRESENT	0
268690	263174	14207L	PARTICIPANT	\N	PRESENT	0
268691	263174	19507S	PARTICIPANT	\N	PRESENT	0
268692	263174	14357A	PARTICIPANT	\N	PRESENT	0
268693	263174	19725B	PARTICIPANT	\N	PRESENT	0
268694	267103	14079W	PARTICIPANT	\N	PRESENT	0
268695	263174	14087W	PARTICIPANT	\N	PRESENT	0
268696	263174	14199E	PARTICIPANT	\N	PRESENT	0
268697	267103	14219Q	PARTICIPANT	\N	PRESENT	0
268698	267103	04061F	PARTICIPANT	\N	PRESENT	0
268699	267103	08028W	PRESIDENT	0	PRESENT	0
268700	263174	14265W	PARTICIPANT	\N	PRESENT	0
268701	263174	01057W	PARTICIPANT	\N	PRESENT	0
268702	263174	08053X	PARTICIPANT	\N	PRESENT	0
268703	263174	11012A	PARTICIPANT	\N	PRESENT	0
268704	263174	19693L	PARTICIPANT	\N	PRESENT	0
268705	263174	19621T	PARTICIPANT	\N	PRESENT	0
268706	263174	14034U	PARTICIPANT	\N	PRESENT	0
268707	263174	07029T	PARTICIPANT	\N	PRESENT	0
268708	263174	19701S	PARTICIPANT	\N	PRESENT	0
268709	263174	19695N	PARTICIPANT	\N	PRESENT	0
268732	263174	11090Q	PARTICIPANT	\N	PRESENT	0
268712	268710	19741B	PARTICIPANT	\N	PRESENT	0
268713	268710	08043V	PARTICIPANT	\N	PRESENT	0
268714	268710	19545Y	PARTICIPANT	\N	EXCUSE	0
268715	268710	14267Y	PARTICIPANT	\N	EXCUSE	0
268716	268710	04038G	PARTICIPANT	\N	PRESENT	0
268717	268710	19253P	PARTICIPANT	\N	EXCUSE	0
268718	268710	14357A	PARTICIPANT	\N	PRESENT	0
268719	268710	11070L	PRESIDENT	0	PRESENT	0
268733	263174	19631V	PARTICIPANT	\N	PRESENT	0
268721	268710	04097T	PARTICIPANT	\N	PRESENT	0
268734	263174	11045K	PARTICIPANT	\N	PRESENT	0
268723	268710	19711U	PARTICIPANT	\N	EXCUSE	0
268724	268710	12016W	PARTICIPANT	\N	PRESENT	0
268760	263174	14213J	PARTICIPANT	\N	PRESENT	0
268726	268710	08021P	PARTICIPANT	\N	EXCUSE	0
268727	268710	17637T	PARTICIPANT	\N	PRESENT	0
268728	268710	19533U	PARTICIPANT	\N	PRESENT	0
268729	268710	95062K	PARTICIPANT	\N	PRESENT	0
268730	268710	19689Q	PARTICIPANT	\N	PRESENT	0
268731	268710	11041F	PARTICIPANT	\N	PRESENT	0
268851	263191	11070L	PARTICIPANT	\N	PRESENT	0
268852	263191	14225N	PARTICIPANT	\N	PRESENT	0
268853	263191	14030Q	PARTICIPANT	\N	PRESENT	0
268854	263191	19713W	PARTICIPANT	\N	PRESENT	0
268855	263191	08052W	PARTICIPANT	\N	PRESENT	0
268856	263191	11074Q	PARTICIPANT	\N	PRESENT	0
268857	263191	08011M	PARTICIPANT	\N	PRESENT	0
268858	263191	14257W	PARTICIPANT	\N	PRESENT	0
268859	263191	19725B	PARTICIPANT	\N	PRESENT	0
268860	263191	19503N	PARTICIPANT	\N	PRESENT	0
268861	263191	11040E	PARTICIPANT	\N	PRESENT	0
268862	263191	19695N	PARTICIPANT	\N	PRESENT	0
268863	263191	19651A	PARTICIPANT	\N	PRESENT	0
268864	263191	19545Y	PARTICIPANT	\N	PRESENT	0
268865	263191	19441R	PARTICIPANT	\N	PRESENT	0
268866	263191	08056B	PARTICIPANT	\N	PRESENT	0
268867	263191	14327T	PARTICIPANT	\N	PRESENT	0
268868	263191	19347U	PARTICIPANT	\N	PRESENT	0
268869	263191	14085U	PARTICIPANT	\N	PRESENT	0
268870	263191	19747H	PARTICIPANT	\N	PRESENT	0
268871	263191	19739H	PARTICIPANT	\N	PRESENT	0
268872	263191	11097X	PARTICIPANT	\N	PRESENT	0
268873	263191	14071N	PARTICIPANT	\N	PRESENT	0
268874	263191	14331P	PARTICIPANT	\N	PRESENT	0
268875	263191	14026U	PARTICIPANT	\N	PRESENT	0
268876	263191	14157T	PARTICIPANT	\N	PRESENT	0
268877	263191	14213J	PARTICIPANT	\N	PRESENT	0
268878	263191	19703U	PARTICIPANT	\N	PRESENT	0
268879	263191	14223L	PARTICIPANT	\N	PRESENT	0
268880	263191	07029T	PARTICIPANT	\N	PRESENT	0
268881	263191	19709B	PARTICIPANT	\N	PRESENT	0
268882	263191	19447X	PARTICIPANT	\N	PRESENT	0
268883	263191	01057W	PARTICIPANT	\N	PRESENT	0
268884	263191	19741B	PARTICIPANT	\N	PRESENT	0
268885	263191	11077T	PARTICIPANT	\N	PRESENT	0
268886	263191	19689Q	PARTICIPANT	\N	PRESENT	0
268887	263191	14021P	PARTICIPANT	\N	PRESENT	0
268888	263191	14197C	PARTICIPANT	\N	PRESENT	0
268889	263191	95063L	PARTICIPANT	\N	PRESENT	0
268890	263191	14357A	PARTICIPANT	\N	PRESENT	0
268891	263191	19701S	PARTICIPANT	\N	PRESENT	0
268892	263191	14119M	PARTICIPANT	\N	PRESENT	0
268893	263191	01058X	PARTICIPANT	\N	PRESENT	0
268894	263191	11012A	PARTICIPANT	\N	PRESENT	0
268895	263191	01034P	PARTICIPANT	\N	PRESENT	0
246146	246133	14225N	PARTICIPANT	\N	EXCUSE	0
246147	246133	14135M	PARTICIPANT	\N	EXCUSE	0
246148	246133	11054L	PARTICIPANT	\N	EXCUSE	0
246149	246133	96004D	PARTICIPANT	\N	EXCUSE	0
246150	246133	14038Y	PARTICIPANT	\N	EXCUSE	0
246151	246133	19715Y	PARTICIPANT	\N	PRESENT	0
246152	246133	19729F	PARTICIPANT	\N	PRESENT	0
246153	246133	14261S	PARTICIPANT	\N	PRESENT	0
246154	246133	19301E	PARTICIPANT	\N	PRESENT	0
246209	246133	08031R	PARTICIPANT	\N	PRESENT	0
246210	246133	08017T	PARTICIPANT	\N	PRESENT	0
246211	246133	14235Q	PARTICIPANT	\N	PRESENT	0
246220	246133	80013X	PARTICIPANT	\N	PRESENT	0
246221	246133	08020N	PARTICIPANT	\N	PRESENT	0
246222	246133	19749K	PARTICIPANT	\N	PRESENT	0
246223	246133	19731Y	PARTICIPANT	\N	PRESENT	0
246224	246133	14217N	PARTICIPANT	\N	PRESENT	0
246225	246133	19643A	PARTICIPANT	\N	PRESENT	0
246226	246133	19701S	PARTICIPANT	\N	PRESENT	0
246230	246133	18083K	PARTICIPANT	\N	PRESENT	0
246299	246133	14030Q	PARTICIPANT	\N	PRESENT	0
246384	243898	11109J	PARTICIPANT	\N	EXCUSE	0
246385	243898	14157T	PARTICIPANT	\N	EXCUSE	0
249106	249105	14255U	PARTICIPANT	\N	PRESENT	0
249108	249107	14261S	PARTICIPANT	\N	PRESENT	0
249109	249107	19575F	PARTICIPANT	\N	PRESENT	0
249110	249107	14083S	PARTICIPANT	\N	PRESENT	0
249111	249107	04049K	PARTICIPANT	\N	PRESENT	0
249112	249107	19671E	PARTICIPANT	\N	PRESENT	0
249113	249107	14265W	PARTICIPANT	\N	PRESENT	0
249114	249107	04088S	PARTICIPANT	\N	PRESENT	0
249115	249107	95067Q	PARTICIPANT	\N	PRESENT	0
249275	248853	04059M	PARTICIPANT	\N	PRESENT	0
249305	247146	08021P	PARTICIPANT	\N	EXCUSE	0
249316	244580	19333N	PARTICIPANT	\N	PRESENT	0
249317	244580	19701S	PARTICIPANT	\N	PRESENT	0
249318	244580	19549D	PARTICIPANT	\N	PRESENT	0
249319	244580	19387D	PARTICIPANT	\N	PRESENT	0
249320	244580	19637C	PARTICIPANT	\N	PRESENT	0
249321	244580	18083K	PARTICIPANT	\N	PRESENT	0
249322	244580	19551W	PARTICIPANT	\N	PRESENT	0
249323	244580	08060W	PARTICIPANT	\N	PRESENT	0
249324	244580	19503N	PARTICIPANT	\N	PRESENT	0
249325	244580	14157T	PARTICIPANT	\N	PRESENT	0
249326	244580	08024S	PARTICIPANT	\N	PRESENT	0
249327	244580	98023Q	PARTICIPANT	\N	PRESENT	0
249328	244580	14038Y	PARTICIPANT	\N	PRESENT	0
249329	244580	14103D	PARTICIPANT	\N	PRESENT	0
249330	244580	19713W	PARTICIPANT	\N	PRESENT	0
249331	244580	14031R	PARTICIPANT	\N	PRESENT	0
249332	244580	08055A	PARTICIPANT	\N	PRESENT	0
249333	244580	14169X	PARTICIPANT	\N	PRESENT	0
249334	244580	04085P	PARTICIPANT	\N	PRESENT	0
249335	244580	14093U	PARTICIPANT	\N	PRESENT	0
249336	244580	14029X	PARTICIPANT	\N	PRESENT	0
249337	244580	19733B	PARTICIPANT	\N	PRESENT	0
249338	244580	08009T	PRESIDENT	0	PRESENT	0
249339	244580	19737F	PARTICIPANT	\N	PRESENT	0
249340	244580	19739H	PARTICIPANT	\N	PRESENT	0
249341	244580	04097T	PARTICIPANT	\N	PRESENT	0
249342	244580	19659J	PARTICIPANT	\N	PRESENT	0
249343	244580	19383Y	PARTICIPANT	\N	PRESENT	0
249344	244580	17583W	PARTICIPANT	\N	PRESENT	0
249345	244580	95062K	PARTICIPANT	\N	PRESENT	0
249346	244580	14219Q	PARTICIPANT	\N	PRESENT	0
249347	244580	14221J	PARTICIPANT	\N	PRESENT	0
249348	244580	02002K	PARTICIPANT	\N	PRESENT	0
249349	244580	14237S	PARTICIPANT	\N	PRESENT	0
249350	244580	80027E	PARTICIPANT	\N	PRESENT	0
249351	244580	14051J	PARTICIPANT	\N	PRESENT	0
249352	244580	19347U	PARTICIPANT	\N	PRESENT	0
249353	244580	19745F	PARTICIPANT	\N	PRESENT	0
249354	244580	19685L	PARTICIPANT	\N	PRESENT	0
249355	244580	19681G	PARTICIPANT	\N	PRESENT	0
249356	244580	11065P	PARTICIPANT	\N	PRESENT	0
249357	244580	19525U	PARTICIPANT	\N	PRESENT	0
249358	244580	19599P	PARTICIPANT	\N	EXCUSE	0
249359	244580	17637T	PARTICIPANT	\N	EXCUSE	0
249360	247061	11053K	PARTICIPANT	\N	PRESENT	0
249361	247061	14034U	PARTICIPANT	\N	PRESENT	0
249362	247061	08011M	PARTICIPANT	\N	EXCUSE	0
249678	240299	14034U	PARTICIPANT	\N	PRESENT	0
249679	244790	11067R	PARTICIPANT	\N	PRESENT	0
249680	244790	11048N	PRESIDENT	0	PRESENT	0
249681	244790	14103D	PARTICIPANT	\N	PRESENT	0
249682	244790	19479G	PARTICIPANT	\N	PRESENT	0
249683	244790	19711U	PARTICIPANT	\N	PRESENT	0
249684	244790	19441R	PARTICIPANT	\N	PRESENT	0
249685	244790	19689Q	PARTICIPANT	\N	PRESENT	0
249686	244790	12016W	PARTICIPANT	\N	PRESENT	0
249687	244790	19253P	PARTICIPANT	\N	PRESENT	0
249688	244790	01024M	PARTICIPANT	\N	PRESENT	0
249689	244790	04038G	PARTICIPANT	\N	PRESENT	0
249690	244790	14026U	PARTICIPANT	\N	PRESENT	0
249691	244790	04049K	PARTICIPANT	\N	PRESENT	0
249692	244790	14041T	PARTICIPANT	\N	PRESENT	0
249693	244790	19503N	PARTICIPANT	\N	PRESENT	0
249694	244790	14151M	PARTICIPANT	\N	PRESENT	0
249695	244790	14157T	PARTICIPANT	\N	PRESENT	0
249696	244790	14071N	PARTICIPANT	\N	PRESENT	0
249697	244790	14207L	PARTICIPANT	\N	PRESENT	0
249698	244790	19749K	PARTICIPANT	\N	PRESENT	0
249699	244790	11040E	PARTICIPANT	\N	PRESENT	0
249700	244790	19533U	PARTICIPANT	\N	PRESENT	0
249701	244790	14087W	PARTICIPANT	\N	PRESENT	0
249702	244790	14187A	PARTICIPANT	\N	PRESENT	0
249703	244790	19545Y	PARTICIPANT	\N	PRESENT	0
249704	244790	14031R	PARTICIPANT	\N	PRESENT	0
249705	244790	14173T	PARTICIPANT	\N	PRESENT	0
250143	232877	02002K	PARTICIPANT	\N	EXCUSE	0
250145	250144	04040A	PARTICIPANT	\N	PRESENT	0
250146	250144	14069U	PARTICIPANT	\N	PRESENT	0
250147	250144	19643A	PARTICIPANT	\N	PRESENT	0
250148	250144	92040Q	PARTICIPANT	\N	PRESENT	0
250149	250144	08058D	PARTICIPANT	\N	PRESENT	0
250150	250144	11115U	PARTICIPANT	\N	PRESENT	0
250151	250144	14259Y	PARTICIPANT	\N	PRESENT	0
250152	250144	98018T	PARTICIPANT	\N	PRESENT	0
250153	250144	14249W	PARTICIPANT	\N	PRESENT	0
250154	250144	19511N	PARTICIPANT	\N	PRESENT	0
250155	250144	19709B	PARTICIPANT	\N	PRESENT	0
250156	250144	04088S	PARTICIPANT	\N	PRESENT	0
250157	250144	14331P	PARTICIPANT	\N	PRESENT	0
250158	250144	04045F	PARTICIPANT	\N	PRESENT	0
250159	250144	04044E	PARTICIPANT	\N	PRESENT	0
250160	250144	14157T	PARTICIPANT	\N	PRESENT	0
250238	250237	14255U	PARTICIPANT	\N	PRESENT	0
250239	250237	19693L	PARTICIPANT	\N	PRESENT	0
250240	250237	14259Y	PARTICIPANT	\N	PRESENT	0
250241	250237	19565D	PARTICIPANT	\N	PRESENT	0
250242	250237	14026U	PARTICIPANT	\N	PRESENT	0
250243	250237	19551W	PARTICIPANT	\N	PRESENT	0
250244	250237	19581D	PARTICIPANT	\N	PRESENT	0
250245	250237	19697Q	PARTICIPANT	\N	PRESENT	0
250246	250237	19637C	PARTICIPANT	\N	PRESENT	0
250247	250237	19563B	PARTICIPANT	\N	PRESENT	0
250248	250237	19335Q	PARTICIPANT	\N	PRESENT	0
250249	250237	92040Q	PARTICIPANT	\N	PRESENT	0
250250	250237	01062T	PARTICIPANT	\N	PRESENT	0
250251	250237	14199E	PARTICIPANT	\N	PRESENT	0
250261	232877	19629C	PARTICIPANT	\N	EXCUSE	0
250276	232877	19369B	PARTICIPANT	\N	PRESENT	0
250313	232877	14147R	PARTICIPANT	\N	PRESENT	0
250314	232877	11056N	PARTICIPANT	\N	EXCUSE	0
250315	232877	19667J	PARTICIPANT	\N	EXCUSE	0
250316	232877	19479G	PARTICIPANT	\N	PRESENT	0
250317	232877	19569H	PARTICIPANT	\N	PRESENT	0
250318	232877	04038G	PARTICIPANT	\N	PRESENT	0
250320	232877	11065P	PARTICIPANT	\N	EXCUSE	0
250507	232877	04061F	PARTICIPANT	\N	EXCUSE	0
250510	232877	14107H	PARTICIPANT	\N	PRESENT	0
250511	250066	19737F	PARTICIPANT	\N	PRESENT	0
250512	250066	19349W	PARTICIPANT	\N	PRESENT	0
250513	250066	19551W	PARTICIPANT	\N	PRESENT	0
250552	232877	08069G	PARTICIPANT	\N	EXCUSE	0
251236	250141	05012A	PARTICIPANT	\N	PRESENT	0
251237	250141	08028W	PARTICIPANT	\N	PRESENT	0
251238	250141	14329V	PARTICIPANT	\N	PRESENT	0
251239	250141	14051J	PARTICIPANT	\N	PRESENT	0
251240	250141	08068F	PARTICIPANT	\N	PRESENT	0
251828	251823	19575F	PARTICIPANT	\N	PRESENT	0
251832	251823	14083S	PARTICIPANT	\N	PRESENT	0
251833	251823	11053K	PARTICIPANT	\N	PRESENT	0
251835	251823	14267Y	PARTICIPANT	\N	PRESENT	0
241250	241249	05008E	PARTICIPANT	\N	PRESENT	0
241251	241249	19543W	PARTICIPANT	\N	PRESENT	0
241252	241249	11033F	PARTICIPANT	\N	PRESENT	0
241253	241249	14041T	PARTICIPANT	\N	PRESENT	0
241254	241249	19581D	PARTICIPANT	\N	PRESENT	0
241255	241249	19483C	PARTICIPANT	\N	PRESENT	0
241256	241249	14111D	PARTICIPANT	\N	PRESENT	0
241257	241249	14147R	PARTICIPANT	\N	PRESENT	0
241258	241249	04044E	PARTICIPANT	\N	PRESENT	0
241260	241259	05008E	PARTICIPANT	\N	PRESENT	0
241261	241259	19483C	PARTICIPANT	\N	PRESENT	0
241262	241259	01024M	PARTICIPANT	\N	PRESENT	0
241263	241259	14041T	PARTICIPANT	\N	PRESENT	0
241264	241259	14065Q	PARTICIPANT	\N	PRESENT	0
241265	241259	10015M	PARTICIPANT	\N	PRESENT	0
244352	244351	04085P	PARTICIPANT	\N	PRESENT	0
244353	244351	11065P	PARTICIPANT	\N	PRESENT	0
244354	244351	19329S	PARTICIPANT	\N	PRESENT	0
244355	244351	19683J	PARTICIPANT	\N	PRESENT	0
244356	244351	19583F	PARTICIPANT	\N	PRESENT	0
244357	244351	14059S	PARTICIPANT	\N	PRESENT	0
244358	244351	19657G	PARTICIPANT	\N	PRESENT	0
244359	244351	14031R	PARTICIPANT	\N	PRESENT	0
244360	244351	19421M	PARTICIPANT	\N	PRESENT	0
244361	244351	14028W	PARTICIPANT	\N	PRESENT	0
244362	244351	11072N	PARTICIPANT	\N	PRESENT	0
244363	244351	19577H	PARTICIPANT	\N	PRESENT	0
244365	244364	08028W	PARTICIPANT	\N	PRESENT	0
244366	244364	19631V	PARTICIPANT	\N	PRESENT	0
244367	244364	14085U	PARTICIPANT	\N	PRESENT	0
244368	244364	19629C	PARTICIPANT	\N	PRESENT	0
244369	244364	14197C	PARTICIPANT	\N	PRESENT	0
244370	244364	14221J	PARTICIPANT	\N	PRESENT	0
244371	244364	14257W	PARTICIPANT	\N	PRESENT	0
244373	244372	19741B	PARTICIPANT	\N	PRESENT	0
244374	244372	19543W	PARTICIPANT	\N	PRESENT	0
244375	244372	04040A	PARTICIPANT	\N	PRESENT	0
244376	244372	14089Y	PARTICIPANT	\N	PRESENT	0
244377	244372	08020N	PARTICIPANT	\N	PRESENT	0
244378	244372	04042C	PARTICIPANT	\N	PRESENT	0
244379	244372	14357A	PARTICIPANT	\N	PRESENT	0
244380	244372	14079W	PARTICIPANT	\N	PRESENT	0
244381	244372	14041T	PARTICIPANT	\N	PRESENT	0
244382	244372	95030B	PARTICIPANT	\N	PRESENT	0
244383	244372	97011G	PARTICIPANT	\N	PRESENT	0
244384	244372	08018U	PARTICIPANT	\N	PRESENT	0
244385	244372	04035D	PARTICIPANT	\N	PRESENT	0
244386	244372	98022P	PARTICIPANT	\N	PRESENT	0
244387	244372	14179A	PARTICIPANT	\N	PRESENT	0
244388	244372	19511N	PARTICIPANT	\N	PRESENT	0
244389	244372	98005N	PARTICIPANT	\N	PRESENT	0
244390	244372	08015R	PARTICIPANT	\N	PRESENT	0
244391	244372	08034U	PARTICIPANT	\N	PRESENT	0
244392	244372	11085T	PARTICIPANT	\N	PRESENT	0
244393	244372	14147R	PARTICIPANT	\N	PRESENT	0
244394	244372	95062K	PARTICIPANT	\N	PRESENT	0
244395	244372	11041F	PARTICIPANT	\N	PRESENT	0
244396	244372	95067Q	PARTICIPANT	\N	PRESENT	0
244397	244372	19737F	PARTICIPANT	\N	PRESENT	0
245899	245897	14001X	PARTICIPANT	\N	PRESENT	0
245902	245897	08053X	PARTICIPANT	\N	PRESENT	0
245904	245897	04088S	PARTICIPANT	\N	PRESENT	0
245905	245897	11056N	PARTICIPANT	\N	PRESENT	0
245907	245897	01062T	PARTICIPANT	\N	PRESENT	0
245938	244125	19631V	PARTICIPANT	\N	PRESENT	0
245939	244125	19515S	PARTICIPANT	\N	PRESENT	0
245940	244125	19707Y	PARTICIPANT	\N	PRESENT	0
245941	244125	14115H	PARTICIPANT	\N	PRESENT	0
245942	244125	19747H	PARTICIPANT	\N	PRESENT	0
245944	244125	08068F	PARTICIPANT	\N	PRESENT	0
245945	244125	14207L	PARTICIPANT	\N	PRESENT	0
245947	244125	14329V	PARTICIPANT	\N	PRESENT	0
245948	244125	08028W	PARTICIPANT	\N	PRESENT	0
245949	244125	19467C	PARTICIPANT	\N	PRESENT	0
245950	244125	80013X	PARTICIPANT	\N	PRESENT	0
245951	244125	14357A	PARTICIPANT	\N	PRESENT	0
245952	244125	08038Y	PARTICIPANT	\N	PRESENT	0
245953	244125	04089T	PARTICIPANT	\N	PRESENT	0
245954	244125	19507S	PARTICIPANT	\N	PRESENT	0
245955	244125	17589D	PARTICIPANT	\N	PRESENT	0
245956	244125	14187A	PARTICIPANT	\N	PRESENT	0
245957	244125	19695N	PARTICIPANT	\N	PRESENT	0
245958	244125	14033T	PARTICIPANT	\N	PRESENT	0
245959	244125	19511N	PARTICIPANT	\N	PRESENT	0
245960	244125	11099A	PARTICIPANT	\N	PRESENT	0
245961	244125	04049K	PARTICIPANT	\N	PRESENT	0
245962	244125	08015R	PARTICIPANT	\N	PRESENT	0
245963	244125	01043Q	PARTICIPANT	\N	PRESENT	0
245964	244125	14205J	PARTICIPANT	\N	PRESENT	0
245965	244125	19441R	PARTICIPANT	\N	PRESENT	0
245966	244125	08019V	PARTICIPANT	\N	PRESENT	0
245967	244125	08062Y	PARTICIPANT	\N	PRESENT	0
245968	244125	19563B	PARTICIPANT	\N	PRESENT	0
245969	244125	19369B	PARTICIPANT	\N	PRESENT	0
245970	244125	14257W	PARTICIPANT	\N	PRESENT	0
245971	244125	14265W	PARTICIPANT	\N	PRESENT	0
245973	244125	08021P	PARTICIPANT	\N	PRESENT	0
245974	244125	04088S	PARTICIPANT	\N	PRESENT	0
245976	244125	11090Q	PARTICIPANT	\N	PRESENT	0
245977	244125	04043D	PARTICIPANT	\N	PRESENT	0
245978	244125	14135M	PARTICIPANT	\N	PRESENT	0
245979	244125	19269X	PARTICIPANT	\N	PRESENT	0
245980	244125	19705W	PARTICIPANT	\N	PRESENT	0
245981	244125	19619A	PARTICIPANT	\N	PRESENT	0
245982	244125	19301E	PARTICIPANT	\N	PRESENT	0
245983	244125	19413M	PARTICIPANT	\N	PRESENT	0
245985	244124	19631V	PARTICIPANT	\N	PRESENT	0
245986	244124	19515S	PARTICIPANT	\N	PRESENT	0
245987	244124	19747H	PARTICIPANT	\N	PRESENT	0
245988	244124	14207L	PARTICIPANT	\N	PRESENT	0
245989	244124	08028W	PARTICIPANT	\N	PRESENT	0
245990	244124	19467C	PARTICIPANT	\N	PRESENT	0
245991	244124	80013X	PARTICIPANT	\N	PRESENT	0
245992	244124	14357A	PARTICIPANT	\N	PRESENT	0
245993	244124	08038Y	PARTICIPANT	\N	PRESENT	0
245994	244124	19507S	PARTICIPANT	\N	PRESENT	0
245995	244124	14187A	PARTICIPANT	\N	PRESENT	0
245996	244124	01025N	PARTICIPANT	\N	PRESENT	0
245997	244124	14033T	PARTICIPANT	\N	PRESENT	0
245998	244124	19511N	PARTICIPANT	\N	PRESENT	0
245999	244124	11099A	PARTICIPANT	\N	PRESENT	0
246000	244124	04049K	PARTICIPANT	\N	PRESENT	0
246001	244124	08015R	PARTICIPANT	\N	PRESENT	0
246002	244124	14205J	PARTICIPANT	\N	PRESENT	0
246003	244124	19441R	PARTICIPANT	\N	PRESENT	0
246004	244124	08019V	PARTICIPANT	\N	PRESENT	0
246005	244124	08062Y	PARTICIPANT	\N	PRESENT	0
246006	244124	19563B	PARTICIPANT	\N	PRESENT	0
246007	244124	19369B	PARTICIPANT	\N	PRESENT	0
246008	244124	14257W	PARTICIPANT	\N	PRESENT	0
246009	244124	14265W	PARTICIPANT	\N	PRESENT	0
246010	244124	04088S	PARTICIPANT	\N	PRESENT	0
246011	244124	11090Q	PARTICIPANT	\N	PRESENT	0
246012	244124	04043D	PARTICIPANT	\N	PRESENT	0
246013	244124	19269X	PARTICIPANT	\N	PRESENT	0
246025	245801	14026U	PARTICIPANT	\N	PRESENT	0
246026	245801	14103D	PARTICIPANT	\N	PRESENT	0
246027	245801	19711U	PARTICIPANT	\N	PRESENT	0
246028	245801	04049K	PARTICIPANT	\N	PRESENT	0
246029	245801	19689Q	PARTICIPANT	\N	PRESENT	0
246030	245801	14069U	PARTICIPANT	\N	PRESENT	0
246031	245801	14157T	PARTICIPANT	\N	PRESENT	0
246032	245801	11048N	PARTICIPANT	\N	PRESENT	0
246033	245801	19479G	PARTICIPANT	\N	PRESENT	0
246049	246048	14103D	PARTICIPANT	\N	PRESENT	0
246050	246048	14069U	PARTICIPANT	\N	PRESENT	0
246051	246048	19719D	PARTICIPANT	\N	PRESENT	0
246052	245801	19503N	PARTICIPANT	\N	PRESENT	0
246053	245801	11067R	PARTICIPANT	\N	PRESENT	0
246054	245801	19749K	PARTICIPANT	\N	PRESENT	0
247245	241125	19663E	PARTICIPANT	\N	PRESENT	0
247247	241162	19663E	PARTICIPANT	\N	PRESENT	0
250263	250262	11097X	PARTICIPANT	\N	PRESENT	0
253500	252508	14107H	PARTICIPANT	\N	PRESENT	0
253607	253606	96004D	PRESIDENT	1	PRESENT	0
253609	253606	14097Y	PARTICIPANT	\N	PRESENT	0
253610	253606	14001X	PARTICIPANT	\N	PRESENT	0
253611	253606	04057K	PARTICIPANT	\N	PRESENT	0
253612	253606	98035U	PARTICIPANT	\N	PRESENT	0
253613	253606	14133K	PARTICIPANT	\N	PRESENT	0
253614	253606	04042C	PRESIDENT	0	PRESENT	0
253615	253606	04035D	PARTICIPANT	\N	PRESENT	0
253616	253606	98050T	PARTICIPANT	\N	PRESENT	0
253617	253606	04034C	PARTICIPANT	\N	PRESENT	0
255443	255439	14135M	PARTICIPANT	\N	PRESENT	0
256365	256121	14237S	PARTICIPANT	\N	PRESENT	0
256483	256482	11072N	PARTICIPANT	\N	PRESENT	0
256487	256486	11072N	PARTICIPANT	\N	PRESENT	0
256491	256490	11072N	PARTICIPANT	\N	PRESENT	0
256497	256496	11072N	PARTICIPANT	\N	PRESENT	0
256499	256498	11072N	PARTICIPANT	\N	PRESENT	0
256516	256144	11109J	PARTICIPANT	\N	PRESENT	0
258309	258308	11053K	PARTICIPANT	\N	PRESENT	0
256518	256144	14030Q	PARTICIPANT	\N	PRESENT	0
256519	256144	08043V	PARTICIPANT	\N	PRESENT	0
256520	256144	19643A	PARTICIPANT	\N	PRESENT	0
256521	256144	19621T	PARTICIPANT	\N	PRESENT	0
258310	258308	14159V	PARTICIPANT	\N	PRESENT	0
256523	256144	95015C	PARTICIPANT	\N	PRESENT	0
258311	258308	05012A	PARTICIPANT	\N	PRESENT	0
256525	256144	19693L	PARTICIPANT	\N	PRESENT	0
258313	258312	11053K	PARTICIPANT	\N	PRESENT	0
258314	258312	14159V	PARTICIPANT	\N	PRESENT	0
256528	256144	14249W	PARTICIPANT	\N	EXCUSE	0
256529	256144	11083R	PARTICIPANT	\N	PRESENT	0
256530	256144	08035V	PARTICIPANT	\N	PRESENT	0
258315	258312	05012A	PARTICIPANT	\N	PRESENT	0
258894	258893	11053K	PARTICIPANT	\N	PRESENT	0
258900	258899	19479G	PARTICIPANT	\N	PRESENT	0
256534	256144	19399H	PARTICIPANT	\N	PRESENT	0
256535	256144	14241N	PARTICIPANT	\N	PRESENT	0
258905	258902	88008L	PARTICIPANT	\N	PRESENT	0
256537	256144	19731Y	PARTICIPANT	\N	PRESENT	0
256538	256144	14061L	PARTICIPANT	\N	EXCUSE	0
256539	256144	14073Q	PARTICIPANT	\N	PRESENT	0
258906	258902	11012A	PARTICIPANT	\N	PRESENT	0
256541	256144	19611R	PARTICIPANT	\N	PRESENT	0
256542	256144	19699S	PARTICIPANT	\N	PRESENT	0
256543	256144	12041X	PARTICIPANT	\N	PRESENT	0
256544	256144	08039A	PARTICIPANT	\N	PRESENT	0
256545	256144	08017T	PARTICIPANT	\N	EXCUSE	0
258941	258674	14069U	PARTICIPANT	\N	PRESENT	0
259752	259751	14255U	PARTICIPANT	\N	PRESENT	0
259772	259095	08034U	PARTICIPANT	\N	PRESENT	0
256550	256144	14063N	PARTICIPANT	\N	PRESENT	0
256551	256144	04057K	PARTICIPANT	\N	EXCUSE	0
260242	258643	15447F	PARTICIPANT	\N	PRESENT	0
256553	256144	04070G	PRESIDENT	0	PRESENT	0
260243	258643	14093U	PARTICIPANT	\N	PRESENT	0
260244	258643	19733B	PARTICIPANT	\N	PRESENT	0
256556	256144	19573D	PARTICIPANT	\N	PRESENT	0
256557	256144	19533U	PARTICIPANT	\N	PRESENT	0
256558	256144	19735D	PARTICIPANT	\N	PRESENT	0
260245	258643	19745F	PARTICIPANT	\N	PRESENT	0
256560	256144	14229S	PARTICIPANT	\N	PRESENT	0
260246	258643	19659J	PARTICIPANT	\N	PRESENT	0
256562	256144	11043H	PARTICIPANT	\N	PRESENT	0
256563	256144	04018C	PARTICIPANT	\N	PRESENT	0
256564	256144	19749K	PARTICIPANT	\N	PRESENT	0
260247	258643	04085P	PARTICIPANT	\N	PRESENT	0
260248	258643	14157T	PARTICIPANT	\N	PRESENT	0
260249	258643	14029X	PARTICIPANT	\N	PRESENT	0
260250	258643	19549D	PARTICIPANT	\N	PRESENT	0
260251	258643	11065P	PARTICIPANT	\N	PRESENT	0
260252	258643	19685L	PARTICIPANT	\N	PRESENT	0
260253	258643	14038Y	PARTICIPANT	\N	PRESENT	0
260254	260214	04044E	PARTICIPANT	\N	PRESENT	0
260255	260214	04047H	PARTICIPANT	\N	PRESENT	0
260256	260214	19673G	PARTICIPANT	\N	PRESENT	0
260257	260214	01028R	PARTICIPANT	\N	PRESENT	0
260258	260214	05008E	PRESIDENT	0	PRESENT	0
260259	260214	19447X	PARTICIPANT	\N	PRESENT	0
260260	260214	19489J	PARTICIPANT	\N	PRESENT	0
260261	260214	14275Y	PARTICIPANT	\N	PRESENT	0
260262	260214	14147R	PARTICIPANT	\N	PRESENT	0
260263	260214	14179A	PARTICIPANT	\N	PRESENT	0
260264	260214	14151M	PARTICIPANT	\N	PRESENT	0
260265	260214	14215L	PARTICIPANT	\N	PRESENT	0
260266	260214	19483C	PARTICIPANT	\N	PRESENT	0
260267	260214	11072N	PARTICIPANT	\N	PRESENT	0
260268	260214	14053L	PARTICIPANT	\N	PRESENT	0
260269	260214	14111D	PARTICIPANT	\N	PRESENT	0
260270	260214	14065Q	PARTICIPANT	\N	PRESENT	0
260271	260214	07034Q	PARTICIPANT	\N	PRESENT	0
260272	260214	11026G	PARTICIPANT	\N	PRESENT	0
260273	260214	08045X	PARTICIPANT	\N	PRESENT	0
260274	260214	19253P	PARTICIPANT	\N	PRESENT	0
260275	260214	01024M	PARTICIPANT	\N	PRESENT	0
260276	260214	19719D	PARTICIPANT	\N	PRESENT	0
260277	260214	11033F	PARTICIPANT	\N	PRESENT	0
260278	260214	19725B	PARTICIPANT	\N	PRESENT	0
260279	260214	14089Y	PARTICIPANT	\N	PRESENT	0
260280	260214	19729F	PARTICIPANT	\N	PRESENT	0
260281	260214	04008A	PARTICIPANT	\N	PRESENT	0
260282	260214	95063L	PARTICIPANT	\N	PRESENT	0
260283	260214	10015M	PARTICIPANT	\N	PRESENT	0
260284	260214	14069U	PARTICIPANT	\N	PRESENT	0
260285	260214	14021P	PARTICIPANT	\N	PRESENT	0
260286	260214	14231L	PARTICIPANT	\N	PRESENT	0
260287	260214	11085T	PARTICIPANT	\N	PRESENT	0
260288	258643	19701S	PARTICIPANT	\N	PRESENT	0
260289	258952	19565D	PARTICIPANT	\N	PRESENT	0
260290	258952	14357A	PARTICIPANT	\N	PRESENT	0
260291	258952	19441R	PARTICIPANT	\N	PRESENT	0
260292	258952	19413M	PARTICIPANT	\N	PRESENT	0
260293	258952	19631V	PARTICIPANT	\N	PRESENT	0
260294	258952	11099A	PARTICIPANT	\N	PRESENT	0
260295	258952	08068F	PARTICIPANT	\N	PRESENT	0
260296	258952	04049K	PARTICIPANT	\N	PRESENT	0
260297	258952	19707Y	PARTICIPANT	\N	PRESENT	0
260298	258952	08015R	PARTICIPANT	\N	PRESENT	0
260299	258952	14197C	PARTICIPANT	\N	PRESENT	0
260300	258952	19369B	PARTICIPANT	\N	PRESENT	0
260301	258952	19511N	PARTICIPANT	\N	PRESENT	0
260302	258952	08028W	PARTICIPANT	\N	PRESENT	0
260303	258952	19563B	PARTICIPANT	\N	PRESENT	0
260304	258952	14265W	PARTICIPANT	\N	PRESENT	0
260305	258952	14135M	PARTICIPANT	\N	PRESENT	0
260306	258952	19467C	PARTICIPANT	\N	PRESENT	0
260307	258952	14187A	PARTICIPANT	\N	PRESENT	0
260308	258952	08062Y	PARTICIPANT	\N	PRESENT	0
260309	258952	19695N	PARTICIPANT	\N	PRESENT	0
260310	258952	14033T	PARTICIPANT	\N	PRESENT	0
260311	258952	11090Q	PARTICIPANT	\N	PRESENT	0
260312	258952	19269X	PARTICIPANT	\N	PRESENT	0
260313	258952	14205J	PARTICIPANT	\N	PRESENT	0
260314	258952	04088S	PARTICIPANT	\N	PRESENT	0
260315	258952	11056N	PARTICIPANT	\N	PRESENT	0
260316	258952	14115H	PARTICIPANT	\N	PRESENT	0
260317	258952	19507S	PARTICIPANT	\N	PRESENT	0
260318	258952	04043D	PARTICIPANT	\N	PRESENT	0
260319	258952	19619A	PARTICIPANT	\N	PRESENT	0
260320	258952	14257W	PARTICIPANT	\N	PRESENT	0
260321	258643	96004D	PARTICIPANT	\N	PRESENT	0
260322	258643	80027E	PARTICIPANT	\N	PRESENT	0
260323	258643	19551W	PARTICIPANT	\N	PRESENT	0
260324	258643	04097T	PARTICIPANT	\N	PRESENT	0
260325	258952	19747H	PARTICIPANT	\N	PRESENT	0
260326	260214	08018U	PARTICIPANT	\N	PRESENT	0
260327	260214	19581D	PARTICIPANT	\N	PRESENT	0
260328	260214	11049P	PARTICIPANT	\N	PRESENT	0
260329	258972	14327T	PARTICIPANT	\N	PRESENT	0
260330	258972	14331P	PARTICIPANT	\N	PRESENT	0
260331	258972	01048V	PARTICIPANT	\N	PRESENT	0
260332	258972	19545Y	PARTICIPANT	\N	PRESENT	0
260333	258972	01057W	PARTICIPANT	\N	PRESENT	0
260334	258972	11074Q	PRESIDENT	0	PRESENT	0
260335	258972	19667J	PARTICIPANT	\N	PRESENT	0
260336	258972	89017R	PARTICIPANT	\N	PRESENT	0
260337	258972	19671E	PARTICIPANT	\N	PRESENT	0
260338	258972	11070L	PARTICIPANT	\N	PRESENT	0
260339	258972	07029T	PARTICIPANT	\N	PRESENT	0
260340	258972	14085U	PARTICIPANT	\N	PRESENT	0
260341	258972	19349W	PARTICIPANT	\N	PRESENT	0
260342	258972	08010L	PARTICIPANT	\N	PRESENT	0
260343	258972	14253S	PARTICIPANT	\N	PRESENT	0
260344	258972	11048N	PARTICIPANT	\N	PRESENT	0
260345	258972	19479G	PARTICIPANT	\N	PRESENT	0
260346	258972	19711U	PARTICIPANT	\N	PRESENT	0
260347	258972	08034U	PARTICIPANT	\N	PRESENT	0
260348	258972	19531S	PARTICIPANT	\N	PRESENT	0
260349	258972	19689Q	PARTICIPANT	\N	PRESENT	0
260350	258972	08011M	PARTICIPANT	\N	PRESENT	0
260351	258972	08014Q	PARTICIPANT	\N	PRESENT	0
260352	258972	14034U	PARTICIPANT	\N	PRESENT	0
260353	258972	14159V	PARTICIPANT	\N	PRESENT	0
260354	258972	11040E	PARTICIPANT	\N	PRESENT	0
260355	258972	08073C	PARTICIPANT	\N	PRESENT	0
260356	258972	14121F	PARTICIPANT	\N	PRESENT	0
260357	258972	19741B	PARTICIPANT	\N	PRESENT	0
260358	258972	04061F	PARTICIPANT	\N	PRESENT	0
244169	244168	08055A	PARTICIPANT	\N	PRESENT	0
244170	244168	14105F	PARTICIPANT	\N	PRESENT	0
244171	244168	14207L	PARTICIPANT	\N	PRESENT	0
244172	244168	95037J	PARTICIPANT	\N	PRESENT	0
244173	244168	14213J	PARTICIPANT	\N	PRESENT	0
244174	244168	14097Y	PARTICIPANT	\N	PRESENT	0
244175	244168	08015R	PARTICIPANT	\N	PRESENT	0
244176	244168	08053X	PARTICIPANT	\N	PRESENT	0
244177	244168	14109K	PARTICIPANT	\N	PRESENT	0
244178	244168	14257W	PARTICIPANT	\N	PRESENT	0
244180	244179	19575F	PARTICIPANT	\N	PRESENT	0
244181	244179	19549D	PARTICIPANT	\N	PRESENT	0
244182	244179	14069U	PARTICIPANT	\N	PRESENT	0
244183	244179	08014Q	PARTICIPANT	\N	PRESENT	0
244184	244179	14105F	PARTICIPANT	\N	PRESENT	0
244185	244179	19383Y	PARTICIPANT	\N	PRESENT	0
244186	244179	14357A	PARTICIPANT	\N	PRESENT	0
244187	244179	19693L	PARTICIPANT	\N	PRESENT	0
244188	244179	14217N	PARTICIPANT	\N	PRESENT	0
244189	244179	01024M	PARTICIPANT	\N	PRESENT	0
244190	244179	19507S	PARTICIPANT	\N	PRESENT	0
244191	244179	01025N	PARTICIPANT	\N	PRESENT	0
244192	244179	14033T	PARTICIPANT	\N	PRESENT	0
244193	244179	04097T	PARTICIPANT	\N	PRESENT	0
244194	244179	11099A	PARTICIPANT	\N	PRESENT	0
244195	244179	04049K	PARTICIPANT	\N	PRESENT	0
244196	244179	16685X	PARTICIPANT	\N	PRESENT	0
244197	244179	19483C	PARTICIPANT	\N	PRESENT	0
244198	244179	19563B	PARTICIPANT	\N	PRESENT	0
244199	244179	19369B	PARTICIPANT	\N	PRESENT	0
244200	244179	14257W	PARTICIPANT	\N	PRESENT	0
244201	244179	14265W	PARTICIPANT	\N	PRESENT	0
244202	244179	92040Q	PARTICIPANT	\N	PRESENT	0
244203	244179	08061X	PARTICIPANT	\N	PRESENT	0
244204	244179	04088S	PARTICIPANT	\N	PRESENT	0
244205	244179	14135M	PARTICIPANT	\N	PRESENT	0
244206	244179	19269X	PARTICIPANT	\N	PRESENT	0
244207	244179	11012A	PARTICIPANT	\N	PRESENT	0
244208	244179	14107H	PARTICIPANT	\N	PRESENT	0
244209	244179	19619A	PARTICIPANT	\N	PRESENT	0
244210	244179	04045F	PARTICIPANT	\N	PRESENT	0
244211	244179	08049C	PARTICIPANT	\N	PRESENT	0
244213	244212	14033T	PARTICIPANT	\N	PRESENT	0
244214	244212	11099A	PARTICIPANT	\N	PRESENT	0
244215	244212	14257W	PARTICIPANT	\N	PRESENT	0
244216	244212	14265W	PARTICIPANT	\N	PRESENT	0
244218	244217	14187A	PARTICIPANT	\N	PRESENT	0
244219	244217	19747H	PARTICIPANT	\N	PRESENT	0
249952	249949	14221J	PARTICIPANT	\N	PRESENT	0
249953	249949	19593H	PARTICIPANT	\N	PRESENT	0
251801	251800	14261S	PARTICIPANT	\N	PRESENT	0
251802	251800	04085P	PARTICIPANT	\N	PRESENT	0
251803	251800	04059M	PARTICIPANT	\N	PRESENT	0
251804	251800	05008E	PARTICIPANT	\N	PRESENT	0
251805	251800	96004D	PARTICIPANT	\N	PRESENT	0
251806	251800	04042C	PARTICIPANT	\N	PRESENT	0
251807	251800	04086Q	PARTICIPANT	\N	PRESENT	0
251808	251800	11070L	PARTICIPANT	\N	PRESENT	0
251809	251800	98024R	PARTICIPANT	\N	PRESENT	0
251810	251800	11074Q	PARTICIPANT	\N	PRESENT	0
251811	251800	14034U	PARTICIPANT	\N	PRESENT	0
251812	251800	11048N	PARTICIPANT	\N	PRESENT	0
251813	251800	14021P	PARTICIPANT	\N	PRESENT	0
251814	251800	14159V	PARTICIPANT	\N	PRESENT	0
251815	251800	01043Q	PARTICIPANT	\N	PRESENT	0
251816	251800	11077T	PARTICIPANT	\N	PRESENT	0
251817	251800	14251Q	PARTICIPANT	\N	PRESENT	0
251818	251800	14031R	PARTICIPANT	\N	PRESENT	0
251819	251800	11085T	PARTICIPANT	\N	PRESENT	0
251820	251800	11072N	PARTICIPANT	\N	PRESENT	0
251821	251800	04070G	PARTICIPANT	\N	PRESENT	0
251822	251800	14071N	PARTICIPANT	\N	PRESENT	0
251824	251800	08061X	PARTICIPANT	\N	PRESENT	0
251825	251800	11090Q	PARTICIPANT	\N	PRESENT	0
251826	251800	04044E	PARTICIPANT	\N	PRESENT	0
263175	263171	11074Q	PARTICIPANT	\N	PRESENT	0
263181	263179	08011M	PARTICIPANT	\N	PRESENT	0
263943	262998	95063L	PARTICIPANT	\N	EXCUSE	0
263944	262993	95063L	PARTICIPANT	\N	EXCUSE	0
268898	263191	04033B	PARTICIPANT	\N	PRESENT	0
268899	263191	14087W	PARTICIPANT	\N	PRESENT	0
268900	263191	11053K	PARTICIPANT	\N	PRESENT	0
268901	263191	19467C	PARTICIPANT	\N	PRESENT	0
268902	263191	19507S	PARTICIPANT	\N	PRESENT	0
268903	263191	14187A	PARTICIPANT	\N	PRESENT	0
268904	263191	14199E	PARTICIPANT	\N	PRESENT	0
268905	263191	19349W	PARTICIPANT	\N	PRESENT	0
268906	263191	05012A	PARTICIPANT	\N	PRESENT	0
268907	263191	08018U	PARTICIPANT	\N	PRESENT	0
268908	263191	14231L	PARTICIPANT	\N	PRESENT	0
268909	263191	14073Q	PARTICIPANT	\N	PRESENT	0
268910	263191	14097Y	PARTICIPANT	\N	PRESENT	0
268911	263191	19693L	PARTICIPANT	\N	PRESENT	0
268912	263191	19553Y	PARTICIPANT	\N	PRESENT	0
268913	263191	14034U	PARTICIPANT	\N	PRESENT	0
268914	263191	18083K	PARTICIPANT	\N	PRESENT	0
268915	263191	14069U	PARTICIPANT	\N	PRESENT	0
268916	263191	19551W	PARTICIPANT	\N	PRESENT	0
268917	263191	08061X	PARTICIPANT	\N	PRESENT	0
268918	263191	19387D	PARTICIPANT	\N	PRESENT	0
268919	263191	11099A	PARTICIPANT	\N	PRESENT	0
268920	263191	11072N	PARTICIPANT	\N	PRESENT	0
268921	263191	14089Y	PARTICIPANT	\N	PRESENT	0
268922	263191	08069G	PARTICIPANT	\N	PRESENT	0
268994	263237	11070L	PARTICIPANT	\N	PRESENT	0
268995	263237	19347U	PARTICIPANT	\N	PRESENT	0
268996	263237	11040E	PARTICIPANT	\N	PRESENT	0
268997	263237	08018U	PARTICIPANT	\N	PRESENT	0
268998	263237	05008E	PARTICIPANT	\N	PRESENT	0
268999	263237	19709B	PARTICIPANT	\N	PRESENT	0
269000	263237	19507S	PARTICIPANT	\N	PRESENT	0
269001	263237	19467C	PARTICIPANT	\N	PRESENT	0
269002	263237	19447X	PARTICIPANT	\N	PRESENT	0
269003	263237	07029T	PARTICIPANT	\N	PRESENT	0
269004	263237	19693L	PARTICIPANT	\N	PRESENT	0
269005	263237	11049P	PARTICIPANT	\N	PRESENT	0
269006	263237	19551W	PARTICIPANT	\N	PRESENT	0
269007	263237	14151M	PARTICIPANT	\N	PRESENT	0
268896	263191	14265W	PARTICIPANT	\N	PRESENT	0
268897	263191	04061F	PARTICIPANT	\N	PRESENT	0
269008	263237	11026G	PARTICIPANT	\N	PRESENT	0
269009	263237	19689Q	PARTICIPANT	\N	PRESENT	0
269010	263237	19503N	PARTICIPANT	\N	PRESENT	0
269011	263237	11077T	PARTICIPANT	\N	PRESENT	0
269012	263237	14065Q	PARTICIPANT	\N	PRESENT	0
269013	263237	14225N	PARTICIPANT	\N	PRESENT	0
269014	263237	19349W	PARTICIPANT	\N	PRESENT	0
269015	263237	08061X	PARTICIPANT	\N	PRESENT	0
269016	263237	11072N	PARTICIPANT	\N	PRESENT	0
269017	263237	19387D	PARTICIPANT	\N	PRESENT	0
269018	263237	19545Y	PARTICIPANT	\N	PRESENT	0
269019	263237	14231L	PARTICIPANT	\N	PRESENT	0
269020	263237	14089Y	PARTICIPANT	\N	PRESENT	0
269021	263237	14034U	PARTICIPANT	\N	PRESENT	0
269022	263237	19747H	PARTICIPANT	\N	PRESENT	0
269023	263237	14215L	PARTICIPANT	\N	PRESENT	0
269024	263237	19621T	PARTICIPANT	\N	PRESENT	0
269025	263237	19701S	PARTICIPANT	\N	PRESENT	0
269026	263237	14357A	PARTICIPANT	\N	PRESENT	0
269027	263237	14331P	PARTICIPANT	\N	PRESENT	0
269028	263237	14213J	PARTICIPANT	\N	PRESENT	0
269029	263237	14069U	PARTICIPANT	\N	PRESENT	0
269030	263237	14187A	PARTICIPANT	\N	PRESENT	0
269031	263237	14223L	PARTICIPANT	\N	PRESENT	0
269032	263237	19553Y	PARTICIPANT	\N	PRESENT	0
269033	263237	11099A	PARTICIPANT	\N	PRESENT	0
269034	263237	08069G	PARTICIPANT	\N	PRESENT	0
269035	263237	19741B	PARTICIPANT	\N	PRESENT	0
269036	263237	19703U	PARTICIPANT	\N	PRESENT	0
269037	263237	19695N	PARTICIPANT	\N	PRESENT	0
269038	263237	14087W	PARTICIPANT	\N	PRESENT	0
269039	263237	14123H	PARTICIPANT	\N	PRESENT	0
269040	263237	14191V	PARTICIPANT	\N	PRESENT	0
269041	263237	14071N	PARTICIPANT	\N	PRESENT	0
269042	263237	18083K	PARTICIPANT	\N	PRESENT	0
269060	269043	04070G	PRESIDENT	0	PRESENT	0
269061	269043	19697Q	PARTICIPANT	\N	PRESENT	0
269062	269043	19699S	PARTICIPANT	\N	PRESENT	0
269063	269043	19701S	PARTICIPANT	\N	PRESENT	0
269064	269043	80013X	PARTICIPANT	\N	PRESENT	0
269065	269043	14229S	PARTICIPANT	\N	PRESENT	0
269066	269043	19573D	PARTICIPANT	\N	PRESENT	0
269067	269043	08017T	PARTICIPANT	\N	PRESENT	0
269068	269043	14249W	PARTICIPANT	\N	PRESENT	0
269069	269043	08039A	PARTICIPANT	\N	PRESENT	0
269070	269043	08031R	PARTICIPANT	\N	PRESENT	0
269071	269043	19643A	PARTICIPANT	\N	PRESENT	0
252814	240313	01043Q	PARTICIPANT	\N	PRESENT	0
252507	240310	19663E	PARTICIPANT	\N	PRESENT	0
252510	252509	08047A	PARTICIPANT	\N	PRESENT	0
252815	252527	04086Q	PARTICIPANT	\N	PRESENT	0
252816	252527	11049P	PARTICIPANT	\N	PRESENT	0
252820	240313	19697Q	PARTICIPANT	\N	PRESENT	0
252818	240313	19329S	PARTICIPANT	\N	PRESENT	0
252819	240313	10015M	PARTICIPANT	\N	PRESENT	0
252821	240313	11072N	PARTICIPANT	\N	PRESENT	0
252822	240313	19711U	PARTICIPANT	\N	PRESENT	0
252823	240313	04018C	PARTICIPANT	\N	PRESENT	0
252824	240313	04038G	PARTICIPANT	\N	PRESENT	0
252825	240313	19673G	PARTICIPANT	\N	PRESENT	0
252826	240313	01024M	PARTICIPANT	\N	PRESENT	0
252827	240313	19533U	PARTICIPANT	\N	PRESENT	0
252828	240313	19479G	PARTICIPANT	\N	PRESENT	0
252829	240313	14219Q	PARTICIPANT	\N	PRESENT	0
252830	240313	11012A	PARTICIPANT	\N	PRESENT	0
252831	252527	19721W	PARTICIPANT	\N	PRESENT	0
252832	252527	11053K	PARTICIPANT	\N	PRESENT	0
252833	240313	19637C	PARTICIPANT	\N	PRESENT	0
252834	240313	19507S	PARTICIPANT	\N	PRESENT	0
252835	240313	14261S	PARTICIPANT	\N	PRESENT	0
252836	240313	08061X	PARTICIPANT	\N	PRESENT	0
252837	240313	08019V	PARTICIPANT	\N	PRESENT	0
252838	240313	19301E	PARTICIPANT	\N	PRESENT	0
252839	240313	14267Y	PARTICIPANT	\N	PRESENT	0
252840	240313	14179A	PARTICIPANT	\N	PRESENT	0
252841	240313	04085P	PARTICIPANT	\N	PRESENT	0
252842	240313	14157T	PARTICIPANT	\N	PRESENT	0
252843	252527	19703U	PARTICIPANT	\N	PRESENT	0
252844	240313	19253P	PARTICIPANT	\N	PRESENT	0
252845	252527	04071H	PARTICIPANT	\N	PRESENT	0
252846	252527	08034U	PARTICIPANT	\N	PRESENT	0
252850	240313	19543W	PARTICIPANT	\N	PRESENT	0
252851	240313	11064N	PARTICIPANT	\N	PRESENT	0
252852	240313	19447X	PARTICIPANT	\N	PRESENT	0
252855	240313	01028R	PARTICIPANT	\N	PRESENT	0
252856	240313	14033T	PARTICIPANT	\N	PRESENT	0
252862	240313	19713W	PARTICIPANT	\N	PRESENT	0
252863	240313	88008L	PARTICIPANT	\N	PRESENT	0
252864	240313	11083R	PARTICIPANT	\N	PRESENT	0
252865	240313	19671E	PARTICIPANT	\N	PRESENT	0
252866	240313	14083S	PARTICIPANT	\N	PRESENT	0
252867	240313	19663E	PARTICIPANT	\N	PRESENT	0
252868	240313	19573D	PARTICIPANT	\N	PRESENT	0
252869	240313	95067Q	PARTICIPANT	\N	PRESENT	0
252870	240313	05008E	PARTICIPANT	\N	PRESENT	0
252871	240313	04034C	PARTICIPANT	\N	PRESENT	0
252872	240313	08056B	PARTICIPANT	\N	PRESENT	0
252873	240313	11110B	PARTICIPANT	\N	PRESENT	0
252880	252847	19593H	PARTICIPANT	\N	PRESENT	0
252883	252848	19593H	PARTICIPANT	\N	PRESENT	0
252884	252848	14221J	PARTICIPANT	\N	PRESENT	0
252885	250068	19551W	PARTICIPANT	\N	PRESENT	0
252886	250068	19737F	PARTICIPANT	\N	PRESENT	0
252890	252849	14221J	PARTICIPANT	\N	PRESENT	0
252891	252849	19593H	PARTICIPANT	\N	PRESENT	0
252892	250298	19551W	PARTICIPANT	\N	PRESENT	0
252893	250298	19349W	PARTICIPANT	\N	PRESENT	0
252894	250298	19737F	PARTICIPANT	\N	PRESENT	0
253035	253034	98029W	PARTICIPANT	\N	PRESENT	0
253096	240300	04059M	PARTICIPANT	0	PRESENT	0
253097	240300	19253P	PARTICIPANT	0	PRESENT	0
253098	240300	19629C	PARTICIPANT	0	PRESENT	0
253099	240300	19717B	PARTICIPANT	0	PRESENT	0
253100	240300	05008E	PARTICIPANT	0	PRESENT	0
253101	240300	19731Y	PARTICIPANT	0	PRESENT	0
253102	240300	19711U	PARTICIPANT	0	PRESENT	0
253103	240300	19683J	PARTICIPANT	0	PRESENT	0
253104	240300	07029T	PARTICIPANT	0	PRESENT	0
251841	251823	19333N	PARTICIPANT	\N	PRESENT	0
253105	240300	11072N	PARTICIPANT	0	PRESENT	0
253106	240300	04038G	PARTICIPANT	0	PRESENT	0
253107	240300	19387D	PARTICIPANT	0	PRESENT	0
251845	251823	19611R	PARTICIPANT	\N	PRESENT	0
253108	240300	14241N	PARTICIPANT	0	PRESENT	0
253109	240300	14179A	PARTICIPANT	0	PRESENT	0
251848	251823	14059S	PARTICIPANT	\N	PRESENT	0
253110	240300	14073Q	PARTICIPANT	0	PRESENT	0
251850	251823	19671E	PARTICIPANT	\N	PRESENT	0
251851	251823	14257W	PARTICIPANT	\N	PRESENT	0
253111	240300	14065Q	PARTICIPANT	0	PRESENT	0
251853	251823	19739H	PARTICIPANT	\N	PRESENT	0
253112	240300	19707Y	PARTICIPANT	0	PRESENT	0
251855	251823	19349W	PARTICIPANT	\N	PRESENT	0
253113	240300	19705W	PARTICIPANT	0	PRESENT	0
253114	240300	04018C	PARTICIPANT	0	PRESENT	0
253115	240300	19479G	PARTICIPANT	0	PRESENT	0
253116	240300	19737F	PARTICIPANT	0	PRESENT	0
253117	240300	19667J	PARTICIPANT	0	PRESENT	0
253118	240300	08031R	PARTICIPANT	0	PRESENT	0
253119	240300	11065P	PARTICIPANT	0	PRESENT	0
253120	240300	14033T	PARTICIPANT	0	PRESENT	0
253121	240300	14249W	PARTICIPANT	0	PRESENT	0
253122	240300	19289C	PARTICIPANT	0	PRESENT	0
253123	240300	11085T	PARTICIPANT	0	PRESENT	0
253124	240300	14215L	PARTICIPANT	0	PRESENT	0
253125	240300	14261S	PARTICIPANT	0	PRESENT	0
253126	240300	19713W	PARTICIPANT	0	PRESENT	0
253127	240300	14237S	PARTICIPANT	0	PRESENT	0
253128	240300	19673G	PARTICIPANT	0	PRESENT	0
253129	240300	14157T	PARTICIPANT	0	PRESENT	0
253130	240300	19399H	PARTICIPANT	0	PRESENT	0
253131	240300	11045K	PARTICIPANT	0	PRESENT	0
253132	240300	19747H	PARTICIPANT	0	PRESENT	0
253133	240300	19619A	PARTICIPANT	0	PRESENT	0
253134	240300	04035D	PARTICIPANT	0	PRESENT	0
253135	240300	19503N	PARTICIPANT	0	PRESENT	0
253136	240300	01024M	PARTICIPANT	0	PRESENT	0
253137	240300	19585H	PARTICIPANT	0	PRESENT	0
253138	240300	14251Q	PARTICIPANT	0	PRESENT	0
253139	240300	01028R	PARTICIPANT	0	PRESENT	0
253140	240300	19301E	PARTICIPANT	0	PRESENT	0
253141	240300	08034U	PARTICIPANT	0	PRESENT	0
253142	240300	19741B	PARTICIPANT	0	PRESENT	0
253143	240300	19581D	PARTICIPANT	0	PRESENT	0
253144	240300	19593H	PARTICIPANT	0	PRESENT	0
253145	240300	17637T	PARTICIPANT	0	PRESENT	0
253146	240300	14257W	PARTICIPANT	0	PRESENT	0
253147	240300	04085P	PARTICIPANT	0	PRESENT	0
253148	240300	19697Q	PARTICIPANT	0	PRESENT	0
253149	240300	80013X	PARTICIPANT	0	PRESENT	0
253150	240300	04043D	PARTICIPANT	0	PRESENT	0
253151	240300	11099A	PARTICIPANT	0	PRESENT	0
253152	240300	14034U	PARTICIPANT	0	PRESENT	0
253153	240300	14267Y	PARTICIPANT	0	PRESENT	0
253154	240300	14079W	PARTICIPANT	0	PRESENT	0
253155	240300	19295A	PARTICIPANT	0	PRESENT	0
253156	240300	19649G	PARTICIPANT	0	PRESENT	0
253157	240300	14083S	PARTICIPANT	0	PRESENT	0
253158	240305	04086Q	PARTICIPANT	0	PRESENT	0
253159	240305	04038G	PARTICIPANT	0	PRESENT	0
253160	240305	14103D	PARTICIPANT	0	PRESENT	0
253161	240305	19507S	PARTICIPANT	0	PRESENT	0
253162	240305	14235Q	PARTICIPANT	0	PRESENT	0
253163	240305	04085P	PARTICIPANT	0	PRESENT	0
253164	240305	14257W	PARTICIPANT	0	PRESENT	0
253165	240305	19489J	PARTICIPANT	0	PRESENT	0
253166	240305	11066Q	PARTICIPANT	0	PRESENT	0
253167	240305	19503N	PARTICIPANT	0	PRESENT	0
253168	240305	19565D	PARTICIPANT	0	PRESENT	0
253169	240305	19709B	PARTICIPANT	0	PRESENT	0
253170	240305	19683J	PARTICIPANT	0	PRESENT	0
253171	240305	19593H	PARTICIPANT	0	PRESENT	0
253172	240305	01028R	PARTICIPANT	0	PRESENT	0
253173	240305	08068F	PARTICIPANT	0	PRESENT	0
253174	240305	19413M	PARTICIPANT	0	PRESENT	0
253175	240305	14197C	PARTICIPANT	0	PRESENT	0
253176	240305	14207L	PARTICIPANT	0	PRESENT	0
253177	240305	19629C	PARTICIPANT	0	PRESENT	0
253178	240305	19253P	PARTICIPANT	0	PRESENT	0
253179	240305	19387D	PARTICIPANT	0	PRESENT	0
253180	240305	07004J	PARTICIPANT	0	PRESENT	0
253181	240305	05008E	PARTICIPANT	0	PRESENT	0
253182	240305	19711U	PARTICIPANT	0	PRESENT	0
253183	240305	11012A	PARTICIPANT	0	PRESENT	0
253184	240305	14147R	PARTICIPANT	0	PRESENT	0
253185	240305	19415P	PARTICIPANT	0	PRESENT	0
253186	240305	14033T	PARTICIPANT	0	PRESENT	0
253187	240305	14031R	PARTICIPANT	0	PRESENT	0
253188	240305	19447X	PARTICIPANT	0	PRESENT	0
253189	240305	19467C	PARTICIPANT	0	PRESENT	0
253190	240305	14105F	PARTICIPANT	0	PRESENT	0
253191	240305	14089Y	PARTICIPANT	0	PRESENT	0
244691	232876	19737F	PARTICIPANT	\N	PRESENT	0
244789	244782	14026U	PARTICIPANT	\N	PRESENT	0
244793	244792	14026U	PARTICIPANT	\N	PRESENT	0
255444	255439	19737F	PARTICIPANT	\N	PRESENT	0
255445	255439	14173T	PARTICIPANT	\N	PRESENT	0
255446	255439	14327T	PARTICIPANT	\N	PRESENT	0
255447	255439	04044E	PARTICIPANT	\N	PRESENT	0
255448	255439	19671E	PARTICIPANT	\N	PRESENT	0
255449	255439	02002K	PARTICIPANT	\N	PRESENT	0
255450	255439	19483C	PARTICIPANT	\N	PRESENT	0
255451	255439	19383Y	PARTICIPANT	\N	PRESENT	0
255469	255468	14135M	PARTICIPANT	\N	PRESENT	0
255471	255468	19737F	PARTICIPANT	\N	PRESENT	0
255472	255468	14034U	PARTICIPANT	\N	PRESENT	0
255473	255468	19383Y	PARTICIPANT	\N	PRESENT	0
255474	255468	19483C	PARTICIPANT	\N	PRESENT	0
255928	255927	19631V	PARTICIPANT	\N	PRESENT	0
255929	255927	19575F	PARTICIPANT	\N	PRESENT	0
255930	255927	19383Y	PARTICIPANT	\N	PRESENT	0
255931	255927	19629C	PARTICIPANT	\N	PRESENT	0
255932	255927	14195A	PARTICIPANT	\N	PRESENT	0
255936	255927	14187A	PARTICIPANT	\N	PRESENT	0
255934	255927	14327T	PARTICIPANT	\N	PRESENT	0
255935	255927	14197C	PARTICIPANT	\N	PRESENT	0
255937	255927	97011G	PARTICIPANT	\N	PRESENT	0
255938	255927	19347U	PARTICIPANT	\N	PRESENT	0
255939	255927	14179A	PARTICIPANT	\N	PRESENT	0
255940	255927	14265W	PARTICIPANT	\N	PRESENT	0
255941	255927	14237S	PARTICIPANT	\N	PRESENT	0
255942	255927	04088S	PARTICIPANT	\N	PRESENT	0
255943	255927	14107H	PARTICIPANT	\N	PRESENT	0
255944	255927	95067Q	PARTICIPANT	\N	PRESENT	0
255970	255969	19667J	PARTICIPANT	\N	PRESENT	0
262560	262558	11049P	PARTICIPANT	\N	PRESENT	0
262561	262558	19543W	PARTICIPANT	\N	PRESENT	0
262670	262558	19251M	PARTICIPANT	\N	PRESENT	0
262671	262558	19729F	PARTICIPANT	\N	PRESENT	0
262672	262558	19443T	PARTICIPANT	\N	PRESENT	0
262673	262558	19703U	PARTICIPANT	\N	PRESENT	0
262823	262822	04040A	PARTICIPANT	\N	PRESENT	0
262824	262822	19565D	PARTICIPANT	\N	PRESENT	0
262825	262822	08038Y	PARTICIPANT	\N	PRESENT	0
262827	262822	14259Y	PARTICIPANT	\N	PRESENT	0
262832	261179	05012A	PARTICIPANT	\N	PRESENT	0
262829	262822	08010L	PARTICIPANT	\N	PRESENT	0
262830	262822	14195A	PARTICIPANT	\N	PRESENT	0
262835	261179	19735D	PARTICIPANT	\N	PRESENT	0
262833	261179	14069U	PARTICIPANT	\N	PRESENT	0
262836	261179	04045F	PARTICIPANT	\N	PRESENT	0
262837	261179	08068F	PARTICIPANT	\N	PRESENT	0
262841	260590	14239U	PARTICIPANT	\N	EXCUSE	0
262843	260590	19415P	PARTICIPANT	\N	PRESENT	0
262844	260590	11103C	PARTICIPANT	\N	PRESENT	0
262845	260590	14195A	PARTICIPANT	\N	PRESENT	0
262846	260590	08052W	PARTICIPANT	\N	PRESENT	0
262847	260590	19663E	PARTICIPANT	\N	EXCUSE	0
262848	260590	10006L	PARTICIPANT	\N	PRESENT	0
262849	260590	14217N	PARTICIPANT	\N	PRESENT	0
262850	260590	14042U	PARTICIPANT	\N	PRESENT	0
262851	260590	14281W	PARTICIPANT	\N	EXCUSE	0
262852	260590	19521Q	PARTICIPANT	\N	PRESENT	0
262853	260590	14355X	PARTICIPANT	\N	EXCUSE	0
262854	260590	08048B	PARTICIPANT	\N	EXCUSE	0
262855	260590	08041T	PARTICIPANT	\N	EXCUSE	0
262856	260590	19727D	PARTICIPANT	\N	PRESENT	0
262857	260590	19569H	PARTICIPANT	\N	PRESENT	0
262858	260590	14213J	PARTICIPANT	\N	PRESENT	0
262859	260590	19715Y	PARTICIPANT	\N	PRESENT	0
262860	260590	19723Y	PARTICIPANT	\N	PRESENT	0
262861	260590	11067R	PARTICIPANT	\N	PRESENT	0
262862	260590	14223L	PARTICIPANT	\N	PRESENT	0
262863	260590	04092N	PRESIDENT	0	PRESENT	0
262864	260590	19679N	PARTICIPANT	\N	PRESENT	0
262865	260590	11045K	PARTICIPANT	\N	PRESENT	0
262866	260590	11097X	PARTICIPANT	\N	PRESENT	0
262867	260590	04045F	PARTICIPANT	\N	PRESENT	0
262868	260590	19703U	PARTICIPANT	\N	EXCUSE	0
262869	260590	19527W	PARTICIPANT	\N	PRESENT	0
262870	260590	01034P	PARTICIPANT	\N	PRESENT	0
262871	260590	17779H	PARTICIPANT	\N	EXCUSE	0
262872	260590	19575F	PARTICIPANT	\N	EXCUSE	0
262873	260590	14026U	PARTICIPANT	\N	EXCUSE	0
262874	261181	14069U	PARTICIPANT	\N	PRESENT	0
262875	261181	04045F	PARTICIPANT	\N	PRESENT	0
262876	261181	19735D	PARTICIPANT	\N	PRESENT	0
262877	261181	05012A	PARTICIPANT	\N	PRESENT	0
262878	261181	14253S	PARTICIPANT	\N	PRESENT	0
262879	261181	08068F	PARTICIPANT	\N	PRESENT	0
262880	261181	14329V	PARTICIPANT	\N	PRESENT	0
262881	261179	14329V	PARTICIPANT	\N	PRESENT	0
262882	261179	14253S	PARTICIPANT	\N	PRESENT	0
262883	261179	14051J	PARTICIPANT	\N	PRESENT	0
262967	262966	14065Q	PARTICIPANT	\N	PRESENT	0
262968	262966	96004D	PRESIDENT	0	PRESENT	0
262969	262966	14089Y	PARTICIPANT	\N	EXCUSE	0
262970	262966	08014Q	PARTICIPANT	\N	PRESENT	0
262971	262966	14249W	PARTICIPANT	\N	PRESENT	0
262972	262966	08018U	PARTICIPANT	\N	EXCUSE	0
262973	262966	04035D	PARTICIPANT	\N	PRESENT	0
262974	262966	11083R	PARTICIPANT	\N	PRESENT	0
262975	262966	14033T	PARTICIPANT	\N	PRESENT	0
262976	262966	19725B	PARTICIPANT	\N	PRESENT	0
262977	262966	95037J	PARTICIPANT	\N	PRESENT	0
262978	262966	04097T	PARTICIPANT	\N	PRESENT	0
262979	262966	04061F	PARTICIPANT	\N	PRESENT	0
262980	262966	14073Q	PARTICIPANT	\N	PRESENT	0
262981	262966	11026G	PARTICIPANT	\N	PRESENT	0
262982	262966	14001X	PARTICIPANT	\N	EXCUSE	0
262983	262966	14221J	PARTICIPANT	\N	PRESENT	0
262984	262966	04057K	PARTICIPANT	\N	PRESENT	0
262985	262966	19563B	PARTICIPANT	\N	PRESENT	0
262986	262966	19593H	PARTICIPANT	\N	PRESENT	0
262987	262966	14135M	PARTICIPANT	\N	PRESENT	0
263066	263065	14115H	PARTICIPANT	\N	PRESENT	0
262989	262966	14229S	PARTICIPANT	\N	PRESENT	0
262990	262966	10015M	PARTICIPANT	\N	PRESENT	0
262991	262966	98035U	PARTICIPANT	\N	PRESENT	0
262992	262966	14331P	PARTICIPANT	\N	PRESENT	0
263053	258934	80013X	PARTICIPANT	\N	PRESENT	0
263055	258934	19723Y	PARTICIPANT	\N	PRESENT	0
263067	263065	14030Q	PRESIDENT	0	PRESENT	0
263068	263065	19367Y	PARTICIPANT	\N	PRESENT	0
263069	263065	08020N	PARTICIPANT	\N	PRESENT	0
263070	263065	19701S	PARTICIPANT	\N	PRESENT	0
263071	263065	11031D	PARTICIPANT	\N	PRESENT	0
263072	263065	19693L	PARTICIPANT	\N	PRESENT	0
263073	263065	14249W	PARTICIPANT	\N	PRESENT	0
263074	263065	19599P	PARTICIPANT	\N	PRESENT	0
263075	263065	04035D	PARTICIPANT	\N	PRESENT	0
263076	263065	19715Y	PARTICIPANT	\N	PRESENT	0
263077	263065	19731Y	PARTICIPANT	\N	PRESENT	0
263078	263065	08031R	PARTICIPANT	\N	PRESENT	0
263079	263065	07029T	PARTICIPANT	\N	PRESENT	0
263080	263065	19563B	PARTICIPANT	\N	PRESENT	0
263081	263065	14109K	PARTICIPANT	\N	PRESENT	0
263082	263065	19679N	PARTICIPANT	\N	PRESENT	0
263083	263065	11045K	PARTICIPANT	\N	PRESENT	0
263084	263065	19749K	PARTICIPANT	\N	PRESENT	0
263085	263065	08043V	PARTICIPANT	\N	EXCUSE	0
263086	263065	08024S	PARTICIPANT	\N	EXCUSE	0
263087	263065	19577H	PARTICIPANT	\N	EXCUSE	0
263088	263065	01043Q	PARTICIPANT	\N	EXCUSE	0
263089	263065	19697Q	PARTICIPANT	\N	EXCUSE	0
263090	256019	08056B	PARTICIPANT	\N	PRESENT	0
263091	256019	19649G	PARTICIPANT	\N	PRESENT	0
263092	256019	19421M	PARTICIPANT	\N	PRESENT	0
263093	256019	11026G	PARTICIPANT	\N	PRESENT	0
263094	256019	10015M	PARTICIPANT	\N	PRESENT	0
263095	256019	98050T	PARTICIPANT	\N	PRESENT	0
263096	256019	08053X	PARTICIPANT	\N	PRESENT	0
263097	256019	19673G	PARTICIPANT	\N	PRESENT	0
263098	256019	02002K	PRESIDENT	0	PRESENT	0
263169	261490	86034E	PARTICIPANT	\N	PRESENT	0
263172	261490	19569H	PARTICIPANT	\N	PRESENT	0
263173	261490	19511N	PARTICIPANT	\N	PRESENT	0
263176	261490	14331P	PARTICIPANT	\N	PRESENT	0
263177	261490	19671E	PARTICIPANT	\N	PRESENT	0
263178	261490	19731Y	PARTICIPANT	\N	PRESENT	0
263180	261490	14157T	PARTICIPANT	\N	PRESENT	0
263182	261490	95030B	PARTICIPANT	\N	PRESENT	0
263183	261490	19629C	PARTICIPANT	\N	PRESENT	0
263184	261490	14105F	PARTICIPANT	\N	PRESENT	0
263185	261490	14195A	PARTICIPANT	\N	PRESENT	0
263186	261490	19413M	PARTICIPANT	\N	PRESENT	0
263187	261490	11109J	PARTICIPANT	\N	PRESENT	0
263188	261490	19295A	PARTICIPANT	\N	PRESENT	0
263189	261490	08024S	PARTICIPANT	\N	PRESENT	0
263190	261490	14219Q	PARTICIPANT	\N	PRESENT	0
263192	261490	98029W	PARTICIPANT	\N	PRESENT	0
258654	258653	14030Q	PARTICIPANT	\N	EXCUSE	0
258655	258653	08043V	PARTICIPANT	\N	PRESENT	0
258656	258653	19701S	PARTICIPANT	\N	PRESENT	0
258657	258653	11031D	PARTICIPANT	\N	PRESENT	0
258658	258653	19693L	PARTICIPANT	\N	PRESENT	0
258659	258653	14249W	PARTICIPANT	\N	EXCUSE	0
258660	258653	19599P	PARTICIPANT	\N	EXCUSE	0
258661	258653	08031R	PARTICIPANT	\N	PRESENT	0
258662	258653	07029T	PARTICIPANT	\N	PRESENT	0
258663	258653	19697Q	PARTICIPANT	\N	EXCUSE	0
258664	258653	14235Q	PARTICIPANT	\N	EXCUSE	0
258665	258653	19679N	PARTICIPANT	\N	EXCUSE	0
258666	258653	11045K	PARTICIPANT	\N	PRESENT	0
260359	258972	14083S	PARTICIPANT	\N	EXCUSE	0
260360	258972	95041E	PARTICIPANT	\N	EXCUSE	0
260361	258972	12016W	PARTICIPANT	\N	EXCUSE	0
260497	250092	04059M	PARTICIPANT	\N	PRESENT	0
260498	258973	14327T	PARTICIPANT	\N	PRESENT	0
260499	258973	14331P	PARTICIPANT	\N	PRESENT	0
260500	258973	04071H	PARTICIPANT	\N	PRESENT	0
260501	258973	19545Y	PARTICIPANT	\N	PRESENT	0
260502	258973	01057W	PARTICIPANT	\N	PRESENT	0
260503	258973	11053K	PARTICIPANT	\N	PRESENT	0
260504	258973	11074Q	PRESIDENT	0	PRESENT	0
260505	258973	89017R	PARTICIPANT	\N	PRESENT	0
260506	258973	19671E	PARTICIPANT	\N	PRESENT	0
260507	258973	11070L	PARTICIPANT	\N	PRESENT	0
260508	258973	07029T	PARTICIPANT	\N	PRESENT	0
260509	258973	14085U	PARTICIPANT	\N	PRESENT	0
260510	258973	07004J	PARTICIPANT	\N	PRESENT	0
260511	258973	19349W	PARTICIPANT	\N	PRESENT	0
260512	258973	08010L	PARTICIPANT	\N	PRESENT	0
260513	258973	14253S	PARTICIPANT	\N	PRESENT	0
260514	258973	19479G	PARTICIPANT	\N	PRESENT	0
260515	258973	19711U	PARTICIPANT	\N	PRESENT	0
260517	258973	19687N	PARTICIPANT	\N	PRESENT	0
260518	258973	19689Q	PARTICIPANT	\N	PRESENT	0
260519	258973	08011M	PARTICIPANT	\N	PRESENT	0
260552	250092	14107H	PARTICIPANT	\N	PRESENT	0
260521	258973	19741B	PARTICIPANT	\N	PRESENT	0
260522	258973	99004R	PARTICIPANT	\N	PRESENT	0
260523	258973	14083S	PARTICIPANT	\N	EXCUSE	0
260524	258973	01048V	PARTICIPANT	\N	EXCUSE	0
260525	258973	12016W	PARTICIPANT	\N	EXCUSE	0
260526	258973	14034U	PARTICIPANT	\N	EXCUSE	0
260527	250092	08034U	PARTICIPANT	\N	PRESENT	0
260537	250092	19467C	PARTICIPANT	\N	PRESENT	0
260529	250092	14063N	PARTICIPANT	\N	PRESENT	0
260530	250092	14073Q	PARTICIPANT	\N	PRESENT	0
260531	250092	08043V	PARTICIPANT	\N	PRESENT	0
260532	250092	14105F	PARTICIPANT	\N	PRESENT	0
260533	250092	19643A	PARTICIPANT	\N	PRESENT	0
260534	250092	19687N	PARTICIPANT	\N	PRESENT	0
260535	250092	14191V	PARTICIPANT	\N	PRESENT	0
260536	250092	08012N	PARTICIPANT	\N	PRESENT	0
260538	250092	14219Q	PARTICIPANT	\N	PRESENT	0
260539	250092	19329S	PARTICIPANT	\N	PRESENT	0
260540	250092	11043H	PARTICIPANT	\N	PRESENT	0
260541	250092	14197C	PARTICIPANT	\N	PRESENT	0
260542	250092	19681G	PARTICIPANT	\N	PRESENT	0
260543	250092	95062K	PARTICIPANT	\N	PRESENT	0
260544	250092	18083K	PARTICIPANT	\N	PRESENT	0
260545	250092	08047A	PARTICIPANT	\N	PRESENT	0
260546	250092	19399H	PARTICIPANT	\N	PRESENT	0
260547	250092	19521Q	PARTICIPANT	\N	PRESENT	0
260548	250092	19387D	PARTICIPANT	\N	PRESENT	0
260549	250092	14249W	PARTICIPANT	\N	PRESENT	0
260550	250092	19581D	PARTICIPANT	\N	PRESENT	0
260551	250092	14241N	PARTICIPANT	\N	PRESENT	0
260553	250092	19679N	PARTICIPANT	\N	PRESENT	0
260554	250092	14259Y	PARTICIPANT	\N	PRESENT	0
260555	250092	14195A	PARTICIPANT	\N	PRESENT	0
260556	250092	14135M	PARTICIPANT	\N	PRESENT	0
260557	250092	19507S	PARTICIPANT	\N	PRESENT	0
260558	250092	19699S	PARTICIPANT	\N	PRESENT	0
260559	250092	04057K	PARTICIPANT	\N	PRESENT	0
260560	250092	19729F	PARTICIPANT	\N	PRESENT	0
260561	250092	19413M	PARTICIPANT	\N	PRESENT	0
260562	250092	14026U	PARTICIPANT	\N	PRESENT	0
260563	250092	14147R	PARTICIPANT	\N	PRESENT	0
260564	250092	97011G	PARTICIPANT	\N	PRESENT	0
260565	250092	04070G	PARTICIPANT	\N	PRESENT	0
260566	250092	19723Y	PARTICIPANT	\N	PRESENT	0
260567	250092	14069U	PARTICIPANT	\N	PRESENT	0
260568	250092	14267Y	PARTICIPANT	\N	PRESENT	0
260569	250092	19383Y	PARTICIPANT	\N	PRESENT	0
260570	250092	14159V	PARTICIPANT	\N	PRESENT	0
260571	250092	14121F	PARTICIPANT	\N	PRESENT	0
260572	250092	14275Y	PARTICIPANT	\N	PRESENT	0
260573	250092	19733B	PARTICIPANT	\N	PRESENT	0
260574	250092	14251Q	PARTICIPANT	\N	PRESENT	0
260575	250092	14213J	PARTICIPANT	\N	PRESENT	0
260577	250092	19447X	PARTICIPANT	\N	PRESENT	0
260578	250092	19731Y	PARTICIPANT	\N	PRESENT	0
260579	250092	19503N	PARTICIPANT	\N	PRESENT	0
260580	250092	11110B	PARTICIPANT	\N	PRESENT	0
260586	250092	14053L	PARTICIPANT	\N	PRESENT	0
260587	250092	04088S	PARTICIPANT	\N	PRESENT	0
260588	250092	14033T	PARTICIPANT	\N	PRESENT	0
260589	250092	19533U	PARTICIPANT	\N	PRESENT	0
260591	250092	01024M	PARTICIPANT	\N	PRESENT	0
260592	250092	14257W	PARTICIPANT	\N	PRESENT	0
260593	250092	08010L	PARTICIPANT	\N	PRESENT	0
260594	250092	14028W	PARTICIPANT	\N	PRESENT	0
260595	250092	11056N	PARTICIPANT	\N	PRESENT	0
260597	250092	19739H	PARTICIPANT	\N	PRESENT	0
260598	250092	19565D	PARTICIPANT	\N	PRESENT	0
260599	250092	95030B	PARTICIPANT	\N	PRESENT	0
260600	250092	19619A	PARTICIPANT	\N	PRESENT	0
260601	250092	19525U	PARTICIPANT	\N	PRESENT	0
260602	250092	19349W	PARTICIPANT	\N	PRESENT	0
260603	250092	19511N	PARTICIPANT	\N	PRESENT	0
260605	250092	14179A	PARTICIPANT	\N	PRESENT	0
260606	250092	14042U	PARTICIPANT	\N	PRESENT	0
260607	250092	14187A	PARTICIPANT	\N	PRESENT	0
260608	250092	98023Q	PARTICIPANT	\N	PRESENT	0
260609	250092	14119M	PARTICIPANT	\N	PRESENT	0
260610	250092	14065Q	PARTICIPANT	\N	PRESENT	0
260611	250092	14021P	PARTICIPANT	\N	PRESENT	0
260616	250092	19671E	PARTICIPANT	\N	PRESENT	0
260623	250092	19691J	PARTICIPANT	\N	PRESENT	0
260704	250093	04059M	PARTICIPANT	\N	PRESENT	0
260705	250093	19565D	PARTICIPANT	\N	PRESENT	0
260706	250093	14021P	PARTICIPANT	\N	PRESENT	0
260707	250093	14028W	PARTICIPANT	\N	PRESENT	0
260708	250093	14065Q	PARTICIPANT	\N	PRESENT	0
260709	250093	14121F	PARTICIPANT	\N	PRESENT	0
260710	250093	19503N	PARTICIPANT	\N	PRESENT	0
260711	250093	14197C	PARTICIPANT	\N	PRESENT	0
260712	250093	19413M	PARTICIPANT	\N	PRESENT	0
260713	250093	14063N	PARTICIPANT	\N	PRESENT	0
260714	250093	19525U	PARTICIPANT	\N	PRESENT	0
260715	250093	11110B	PARTICIPANT	\N	PRESENT	0
260716	250093	19349W	PARTICIPANT	\N	PRESENT	0
260717	250093	19387D	PARTICIPANT	\N	PRESENT	0
260718	250093	04057K	PARTICIPANT	\N	PRESENT	0
260719	250093	14251Q	PARTICIPANT	\N	PRESENT	0
260720	250093	14195A	PARTICIPANT	\N	PRESENT	0
260721	250093	19691J	PARTICIPANT	\N	PRESENT	0
260722	250093	14042U	PARTICIPANT	\N	PRESENT	0
260723	250093	19637C	PARTICIPANT	\N	PRESENT	0
260724	250093	14219Q	PARTICIPANT	\N	PRESENT	0
260725	250093	08009T	PARTICIPANT	\N	PRESENT	0
260726	250093	01024M	PARTICIPANT	\N	PRESENT	0
260727	250093	14179A	PARTICIPANT	\N	PRESENT	0
260728	250093	19671E	PARTICIPANT	\N	PRESENT	0
260729	250093	14053L	PARTICIPANT	\N	PRESENT	0
260730	250093	14187A	PARTICIPANT	\N	PRESENT	0
260731	250093	19739H	PARTICIPANT	\N	PRESENT	0
260732	250093	89017R	PARTICIPANT	\N	PRESENT	0
260733	250093	19731Y	PARTICIPANT	\N	PRESENT	0
260734	250093	95030B	PARTICIPANT	\N	PRESENT	0
260735	250093	08010L	PARTICIPANT	\N	PRESENT	0
260736	250093	19733B	PARTICIPANT	\N	PRESENT	0
260737	250093	19383Y	PARTICIPANT	\N	PRESENT	0
260738	250093	97011G	PARTICIPANT	\N	PRESENT	0
260739	250093	14105F	PARTICIPANT	\N	PRESENT	0
260740	250093	08034U	PARTICIPANT	\N	PRESENT	0
260741	250093	14026U	PARTICIPANT	\N	PRESENT	0
260742	250093	08047A	PARTICIPANT	\N	PRESENT	0
260743	250093	14119M	PARTICIPANT	\N	PRESENT	0
260744	250093	14033T	PARTICIPANT	\N	PRESENT	0
260745	250093	19507S	PARTICIPANT	\N	PRESENT	0
260746	250093	19447X	PARTICIPANT	\N	PRESENT	0
260747	250093	04088S	PARTICIPANT	\N	PRESENT	0
260748	250093	18083K	PARTICIPANT	\N	PRESENT	0
260749	250093	19467C	PARTICIPANT	\N	PRESENT	0
260750	250093	19619A	PARTICIPANT	\N	PRESENT	0
241476	241475	14079W	PARTICIPANT	\N	PRESENT	0
241477	241475	04049K	PARTICIPANT	\N	PRESENT	0
241478	241475	08015R	PARTICIPANT	\N	PRESENT	0
241479	241475	19483C	PARTICIPANT	\N	PRESENT	0
241480	241475	14031R	PARTICIPANT	\N	PRESENT	0
241481	241475	14221J	PARTICIPANT	\N	PRESENT	0
241483	241475	14237S	PARTICIPANT	\N	PRESENT	0
241484	241475	95063L	PARTICIPANT	\N	PRESENT	0
241486	241475	04034C	PARTICIPANT	\N	PRESENT	0
241495	241475	14073Q	PARTICIPANT	\N	PRESENT	0
246417	240291	14331P	PARTICIPANT	\N	PRESENT	0
246402	244315	11090Q	PARTICIPANT	\N	PRESENT	0
241507	241503	11083R	PARTICIPANT	\N	PRESENT	0
241508	241503	04049K	PARTICIPANT	\N	PRESENT	0
241509	241503	14031R	PARTICIPANT	\N	PRESENT	0
246418	240291	19399H	PARTICIPANT	\N	PRESENT	0
241511	241503	14071N	PARTICIPANT	\N	PRESENT	0
241512	241503	14169X	PARTICIPANT	\N	PRESENT	0
241513	241503	14237S	PARTICIPANT	\N	PRESENT	0
241514	241503	14073Q	PARTICIPANT	\N	PRESENT	0
241515	241503	14069U	PARTICIPANT	\N	PRESENT	0
246387	244315	08068F	PARTICIPANT	\N	PRESENT	0
246388	244315	19737F	PARTICIPANT	\N	PRESENT	0
246419	240291	14115H	PARTICIPANT	\N	PRESENT	0
246420	240291	19693L	PARTICIPANT	\N	PRESENT	0
246391	244315	19585H	PARTICIPANT	\N	EXCUSE	0
246392	244315	08028W	PRESIDENT	0	PRESENT	0
246393	244315	19631V	PARTICIPANT	\N	PRESENT	0
246394	244315	95041E	PARTICIPANT	\N	EXCUSE	0
246395	244315	14065Q	PARTICIPANT	\N	EXCUSE	0
246421	240291	14061L	PARTICIPANT	\N	PRESENT	0
246422	240291	19731Y	PARTICIPANT	\N	PRESENT	0
246423	240291	19581D	PARTICIPANT	\N	PRESENT	0
246424	240291	14031R	PARTICIPANT	\N	PRESENT	0
246425	240291	14267Y	PARTICIPANT	\N	PRESENT	0
246426	240291	14033T	PARTICIPANT	\N	PRESENT	0
246427	240291	99004R	PARTICIPANT	\N	PRESENT	0
246428	240291	19741B	PARTICIPANT	\N	PRESENT	0
246441	240291	14253S	PARTICIPANT	\N	PRESENT	0
246442	240291	14329V	PARTICIPANT	\N	PRESENT	0
246443	240291	19415P	PARTICIPANT	\N	PRESENT	0
246444	240291	14135M	PARTICIPANT	\N	PRESENT	0
246445	240291	14041T	PARTICIPANT	\N	PRESENT	0
246446	240291	08018U	PARTICIPANT	\N	PRESENT	0
246447	240291	19711U	PARTICIPANT	\N	PRESENT	0
246448	240291	95030B	PARTICIPANT	\N	PRESENT	0
246449	240291	95015C	PARTICIPANT	\N	PRESENT	0
246450	240291	96004D	PARTICIPANT	\N	PRESENT	0
246451	240291	14147R	PARTICIPANT	\N	PRESENT	0
246452	240291	04092N	PARTICIPANT	\N	PRESENT	0
246454	240291	98024R	PARTICIPANT	\N	PRESENT	0
246455	240291	01058X	PARTICIPANT	\N	PRESENT	0
246456	240291	08010L	PARTICIPANT	\N	PRESENT	0
246457	240291	14133K	PARTICIPANT	\N	PRESENT	0
246458	240291	14223L	PARTICIPANT	\N	PRESENT	0
246459	240291	08034U	PARTICIPANT	\N	PRESENT	0
246460	240291	19747H	PARTICIPANT	\N	PRESENT	0
246461	240291	19745F	PARTICIPANT	\N	PRESENT	0
246462	240291	95062K	PARTICIPANT	\N	PRESENT	0
246463	240291	10006L	PARTICIPANT	\N	PRESENT	0
246464	240291	19705W	PARTICIPANT	\N	PRESENT	0
246465	240291	19707Y	PARTICIPANT	\N	PRESENT	0
246466	240291	04097T	PARTICIPANT	\N	PRESENT	0
246467	240291	19679N	PARTICIPANT	\N	PRESENT	0
246468	240291	01057W	PARTICIPANT	\N	PRESENT	0
246469	240291	14119M	PARTICIPANT	\N	PRESENT	0
246470	240291	11090Q	PARTICIPANT	\N	PRESENT	0
246472	240291	08028W	PARTICIPANT	\N	PRESENT	0
246473	240291	11010L	PARTICIPANT	\N	PRESENT	0
246474	240291	14187A	PARTICIPANT	\N	PRESENT	0
246475	240291	11048N	PARTICIPANT	\N	PRESENT	0
246476	240291	07034Q	PARTICIPANT	\N	PRESENT	0
246477	240291	05008E	PARTICIPANT	\N	PRESENT	0
246478	240291	11080N	PARTICIPANT	\N	PRESENT	0
246481	240291	04033B	PARTICIPANT	\N	PRESENT	0
246482	240291	14199E	PARTICIPANT	\N	PRESENT	0
246483	240291	19575F	PARTICIPANT	\N	PRESENT	0
246486	240291	14169X	PARTICIPANT	\N	PRESENT	0
246487	240291	15447F	PARTICIPANT	\N	PRESENT	0
246488	240291	19703U	PARTICIPANT	\N	PRESENT	0
246489	240291	19673G	PARTICIPANT	\N	PRESENT	0
246490	240291	17637T	PARTICIPANT	\N	PRESENT	0
246491	240291	08020N	PARTICIPANT	\N	PRESENT	0
246493	240291	11072N	PARTICIPANT	\N	PRESENT	0
246495	240291	95067Q	PARTICIPANT	\N	PRESENT	0
246500	240291	10015M	PARTICIPANT	\N	PRESENT	0
246501	240291	04085P	PARTICIPANT	\N	PRESENT	0
246503	240291	11040E	PARTICIPANT	\N	PRESENT	0
246505	240291	12041X	PARTICIPANT	\N	PRESENT	0
246506	240291	11063M	PARTICIPANT	\N	PRESENT	0
246508	240291	19347U	PARTICIPANT	\N	PRESENT	0
246510	240291	19593H	PARTICIPANT	\N	PRESENT	0
246511	240291	19687N	PARTICIPANT	\N	PRESENT	0
246513	240291	19695N	PARTICIPANT	\N	PRESENT	0
246516	240291	95037J	PARTICIPANT	\N	PRESENT	0
246518	240291	95063L	PARTICIPANT	\N	PRESENT	0
246519	240291	14083S	PARTICIPANT	\N	PRESENT	0
246521	240291	98029W	PARTICIPANT	\N	PRESENT	0
246522	240291	14073Q	PARTICIPANT	\N	PRESENT	0
246524	240291	19651A	PARTICIPANT	\N	PRESENT	0
246525	240291	19643A	PARTICIPANT	\N	PRESENT	0
246526	240291	14239U	PARTICIPANT	\N	PRESENT	0
246527	240291	08009T	PARTICIPANT	\N	PRESENT	0
246529	240291	19637C	PARTICIPANT	\N	PRESENT	0
246530	240291	14255U	PARTICIPANT	\N	PRESENT	0
246531	240291	19697Q	PARTICIPANT	\N	PRESENT	0
246532	240291	19515S	PARTICIPANT	\N	PRESENT	0
246533	240291	11083R	PARTICIPANT	\N	PRESENT	0
246534	240291	04034C	PARTICIPANT	\N	PRESENT	0
246535	240291	19301E	PARTICIPANT	\N	PRESENT	0
246536	240291	11070L	PARTICIPANT	\N	PRESENT	0
246537	240291	19349W	PARTICIPANT	\N	PRESENT	0
246538	240291	19667J	PARTICIPANT	\N	PRESENT	0
246539	240291	08061X	PARTICIPANT	\N	PRESENT	0
246540	240291	08073C	PARTICIPANT	\N	PRESENT	0
246541	240291	14103D	PARTICIPANT	\N	PRESENT	0
246542	240291	14039A	PARTICIPANT	\N	PRESENT	0
246543	240291	98023Q	PARTICIPANT	\N	PRESENT	0
246544	240291	04070G	PARTICIPANT	\N	PRESENT	0
246545	240291	14105F	PARTICIPANT	\N	PRESENT	0
246546	240291	19685L	PARTICIPANT	\N	PRESENT	0
246581	240291	04057K	PARTICIPANT	\N	PRESENT	0
246548	240291	14261S	PARTICIPANT	\N	PRESENT	0
246549	240291	19717B	PARTICIPANT	\N	PRESENT	0
246550	240291	11049P	PARTICIPANT	\N	PRESENT	0
246551	240291	19629C	PARTICIPANT	\N	PRESENT	0
246552	240291	08049C	PARTICIPANT	\N	PRESENT	0
246553	240291	14201E	PARTICIPANT	\N	PRESENT	0
246554	240291	19253P	PARTICIPANT	\N	PRESENT	0
246555	240291	19573D	PARTICIPANT	\N	PRESENT	0
246556	240291	19719D	PARTICIPANT	\N	PRESENT	0
246557	240291	19447X	PARTICIPANT	\N	PRESENT	0
246558	240291	98022P	PARTICIPANT	\N	PRESENT	0
246559	240291	14038Y	PARTICIPANT	\N	PRESENT	0
246560	240291	19553Y	PARTICIPANT	\N	PRESENT	0
246561	240291	19467C	PARTICIPANT	\N	PRESENT	0
246562	240291	19387D	PARTICIPANT	\N	PRESENT	0
246563	240291	19507S	PARTICIPANT	\N	PRESENT	0
246564	240291	08031R	PARTICIPANT	\N	PRESENT	0
246565	240291	19563B	PARTICIPANT	\N	PRESENT	0
246566	240291	11012A	PARTICIPANT	\N	PRESENT	0
246567	240291	18083K	PARTICIPANT	\N	PRESENT	0
246568	240291	19577H	PARTICIPANT	\N	PRESENT	0
246569	240291	14034U	PARTICIPANT	\N	PRESENT	0
246570	240291	07004J	PARTICIPANT	\N	PRESENT	0
246571	240291	19691J	PARTICIPANT	\N	PRESENT	0
246572	240291	08019V	PARTICIPANT	\N	PRESENT	0
246573	240291	14111D	PARTICIPANT	\N	PRESENT	0
246574	240291	19545Y	PARTICIPANT	\N	PRESENT	0
246575	240291	19583F	PARTICIPANT	\N	PRESENT	0
246576	240291	17589D	PARTICIPANT	\N	PRESENT	0
246577	240291	19657G	PARTICIPANT	\N	PRESENT	0
246578	240291	02002K	PARTICIPANT	\N	PRESENT	0
246579	240291	07029T	PARTICIPANT	\N	PRESENT	0
246580	240291	08044W	PARTICIPANT	\N	PRESENT	0
246582	240291	14159V	PARTICIPANT	\N	PRESENT	0
246583	240291	01025N	PARTICIPANT	\N	PRESENT	0
246584	240291	14030Q	PARTICIPANT	\N	PRESENT	0
246585	240291	04088S	PARTICIPANT	\N	PRESENT	0
246586	240291	14051J	PARTICIPANT	\N	PRESENT	0
246587	240291	08068F	PARTICIPANT	\N	PRESENT	0
246588	240291	11074Q	PARTICIPANT	\N	PRESENT	0
246589	240291	11115U	PARTICIPANT	\N	PRESENT	0
246590	240291	04059M	PARTICIPANT	\N	PRESENT	0
246591	240291	11077T	PARTICIPANT	\N	PRESENT	0
246592	240291	19663E	PARTICIPANT	\N	PRESENT	0
246593	240291	14042U	PARTICIPANT	\N	PRESENT	0
246594	240291	14229S	PARTICIPANT	\N	PRESENT	0
253241	240305	04018C	PARTICIPANT	0	PRESENT	0
253242	240305	01060R	PARTICIPANT	0	PRESENT	0
253243	240305	19747H	PARTICIPANT	0	PRESENT	0
253244	240305	14069U	PARTICIPANT	0	PRESENT	0
253245	240305	80013X	PARTICIPANT	0	PRESENT	0
253246	240305	11056N	PARTICIPANT	0	PRESENT	0
253247	240305	14107H	PARTICIPANT	0	PRESENT	0
253248	240305	08055A	PARTICIPANT	0	PRESENT	0
253249	240305	14267Y	PARTICIPANT	0	PRESENT	0
253250	240305	14231L	PARTICIPANT	0	PRESENT	0
253251	240305	11045K	PARTICIPANT	0	PRESENT	0
253252	240305	08060W	PARTICIPANT	0	PRESENT	0
253253	240305	14038Y	PARTICIPANT	0	PRESENT	0
253254	240305	19483C	PARTICIPANT	0	PRESENT	0
253255	240305	19479G	PARTICIPANT	0	PRESENT	0
253256	240305	14357A	PARTICIPANT	0	PRESENT	0
253257	240305	14201E	PARTICIPANT	0	PRESENT	0
253258	240305	19551W	PARTICIPANT	0	PRESENT	0
253259	240305	19631V	PARTICIPANT	0	PRESENT	0
253260	240305	19695N	PARTICIPANT	0	PRESENT	0
253261	240305	19733B	PARTICIPANT	0	PRESENT	0
253262	240305	11048N	PARTICIPANT	0	PRESENT	0
253263	240305	19347U	PARTICIPANT	0	PRESENT	0
253264	240305	01024M	PARTICIPANT	0	PRESENT	0
253265	240305	14195A	PARTICIPANT	0	PRESENT	0
253266	240305	14030Q	PARTICIPANT	0	PRESENT	0
253267	240305	12016W	PARTICIPANT	0	PRESENT	0
253268	240305	14217N	PARTICIPANT	0	PRESENT	0
253269	240305	14249W	PARTICIPANT	0	PRESENT	0
253270	240305	08044W	PARTICIPANT	0	PRESENT	0
253271	240305	08028W	PARTICIPANT	0	PRESENT	0
253272	240305	14063N	PARTICIPANT	0	PRESENT	0
253273	240305	14241N	PARTICIPANT	0	PRESENT	0
253275	253274	98029W	PARTICIPANT	\N	PRESENT	0
253277	253276	98029W	PARTICIPANT	\N	PRESENT	0
253660	253659	11040E	PARTICIPANT	\N	PRESENT	0
253661	253659	14069U	PARTICIPANT	\N	PRESENT	0
253662	253659	19643A	PARTICIPANT	\N	PRESENT	0
253663	253659	14255U	PARTICIPANT	\N	PRESENT	0
253664	253659	04086Q	PARTICIPANT	\N	PRESENT	0
253665	253659	19521Q	PARTICIPANT	\N	PRESENT	0
253666	253659	19735D	PARTICIPANT	\N	PRESENT	0
254321	240315	04059M	PARTICIPANT	0	PRESENT	0
253668	253659	04070G	PARTICIPANT	\N	PRESENT	0
253669	253659	92040Q	PARTICIPANT	\N	PRESENT	0
253670	253659	14253S	PARTICIPANT	\N	PRESENT	0
253671	253659	14147R	PARTICIPANT	\N	PRESENT	0
254322	240315	14026U	PARTICIPANT	0	PRESENT	0
254323	240315	11048N	PARTICIPANT	0	PRESENT	0
254324	240315	15447F	PARTICIPANT	0	PRESENT	0
254325	240315	08031R	PARTICIPANT	0	PRESENT	0
254326	240315	19629C	PARTICIPANT	0	PRESENT	0
254327	240315	19563B	PARTICIPANT	0	PRESENT	0
254328	240315	19443T	PARTICIPANT	0	PRESENT	0
254329	240315	19565D	PARTICIPANT	0	PRESENT	0
254330	240315	19503N	PARTICIPANT	0	PRESENT	0
254331	240315	11067R	PARTICIPANT	0	PRESENT	0
254332	240315	11040E	PARTICIPANT	0	PRESENT	0
254333	240315	14151M	PARTICIPANT	0	PRESENT	0
254334	240315	19651A	PARTICIPANT	0	PRESENT	0
254335	240315	19719D	PARTICIPANT	0	PRESENT	0
254336	240315	19695N	PARTICIPANT	0	PRESENT	0
254337	240315	19631V	PARTICIPANT	0	PRESENT	0
254338	240315	04018C	PARTICIPANT	0	PRESENT	0
254339	240315	19383Y	PARTICIPANT	0	PRESENT	0
254340	240315	19533U	PARTICIPANT	0	PRESENT	0
254341	240315	19711U	PARTICIPANT	0	PRESENT	0
254342	240315	19575F	PARTICIPANT	0	PRESENT	0
254343	240315	19333N	PARTICIPANT	0	PRESENT	0
254344	240315	11043H	PARTICIPANT	0	PRESENT	0
254345	240315	19515S	PARTICIPANT	0	PRESENT	0
254346	240315	14089Y	PARTICIPANT	0	PRESENT	0
254347	240315	19335Q	PARTICIPANT	0	PRESENT	0
254348	240315	19739H	PARTICIPANT	0	PRESENT	0
254349	240315	19545Y	PARTICIPANT	0	PRESENT	0
254350	240315	14103D	PARTICIPANT	0	PRESENT	0
254351	240315	19573D	PARTICIPANT	0	PRESENT	0
254352	240315	19447X	PARTICIPANT	0	PRESENT	0
254353	240315	14265W	PARTICIPANT	0	PRESENT	0
254354	240315	14213J	PARTICIPANT	0	PRESENT	0
254355	240315	14195A	PARTICIPANT	0	PRESENT	0
254356	240315	14083S	PARTICIPANT	0	PRESENT	0
254357	240315	19349W	PARTICIPANT	0	PRESENT	0
254358	240315	14029X	PARTICIPANT	0	PRESENT	0
254359	240315	01024M	PARTICIPANT	0	PRESENT	0
254360	240315	14331P	PARTICIPANT	0	PRESENT	0
254361	240315	14085U	PARTICIPANT	0	PRESENT	0
254362	240315	19727D	PARTICIPANT	0	PRESENT	0
254363	240315	14073Q	PARTICIPANT	0	PRESENT	0
254364	240315	14157T	PARTICIPANT	0	PRESENT	0
254365	240315	19689Q	PARTICIPANT	0	PRESENT	0
254366	240315	19507S	PARTICIPANT	0	PRESENT	0
254367	240315	14033T	PARTICIPANT	0	PRESENT	0
254368	240315	19415P	PARTICIPANT	0	PRESENT	0
254369	240315	14223L	PARTICIPANT	0	PRESENT	0
254370	240315	04049K	PARTICIPANT	0	PRESENT	0
254371	240315	14031R	PARTICIPANT	0	PRESENT	0
254372	240315	14041T	PARTICIPANT	0	PRESENT	0
254373	240315	04097T	PARTICIPANT	0	PRESENT	0
254374	240315	19747H	PARTICIPANT	0	PRESENT	0
254375	240315	19749K	PARTICIPANT	0	PRESENT	0
254376	240315	19671E	PARTICIPANT	0	PRESENT	0
254377	240315	14071N	PARTICIPANT	0	PRESENT	0
254378	240315	01043Q	PARTICIPANT	0	PRESENT	0
254379	240315	19387D	PARTICIPANT	0	PRESENT	0
254380	240315	04038G	PARTICIPANT	0	PRESENT	0
254381	240315	19701S	PARTICIPANT	0	PRESENT	0
254382	240315	14105F	PARTICIPANT	0	PRESENT	0
254383	240315	18083K	PARTICIPANT	0	PRESENT	0
254384	240315	14207L	PARTICIPANT	0	PRESENT	0
254385	240315	14021P	PARTICIPANT	0	PRESENT	0
254386	240315	04085P	PARTICIPANT	0	PRESENT	0
254387	240315	19729F	PARTICIPANT	0	PRESENT	0
254388	240315	97011G	PARTICIPANT	0	PRESENT	0
254389	240315	14119M	PARTICIPANT	0	PRESENT	0
253192	240305	18083K	PARTICIPANT	0	PRESENT	0
253193	240305	19663E	PARTICIPANT	0	PRESENT	0
253194	240305	19549D	PARTICIPANT	0	PRESENT	0
253195	240305	08038Y	PARTICIPANT	0	PRESENT	0
253196	240305	14211G	PARTICIPANT	0	PRESENT	0
253197	240305	19741B	PARTICIPANT	0	PRESENT	0
253198	240305	19671E	PARTICIPANT	0	PRESENT	0
253199	240305	14151M	PARTICIPANT	0	PRESENT	0
253200	240305	19443T	PARTICIPANT	0	PRESENT	0
253201	240305	14053L	PARTICIPANT	0	PRESENT	0
253202	240305	19715Y	PARTICIPANT	0	PRESENT	0
253203	240305	19533U	PARTICIPANT	0	PRESENT	0
253204	240305	95063L	PARTICIPANT	0	PRESENT	0
253205	240305	11110B	PARTICIPANT	0	PRESENT	0
253206	240305	14239U	PARTICIPANT	0	PRESENT	0
253207	240305	19725B	PARTICIPANT	0	PRESENT	0
253208	240305	19723Y	PARTICIPANT	0	PRESENT	0
253209	240305	08019V	PARTICIPANT	0	PRESENT	0
253210	240305	14021P	PARTICIPANT	0	PRESENT	0
253211	240305	08015R	PARTICIPANT	0	PRESENT	0
253212	240305	95030B	PARTICIPANT	0	PRESENT	0
253213	240305	14111D	PARTICIPANT	0	PRESENT	0
253214	240305	19441R	PARTICIPANT	0	PRESENT	0
253215	240305	14265W	PARTICIPANT	0	PRESENT	0
253216	240305	19731Y	PARTICIPANT	0	PRESENT	0
253217	240305	14119M	PARTICIPANT	0	PRESENT	0
253218	240305	19573D	PARTICIPANT	0	PRESENT	0
253219	240305	14159V	PARTICIPANT	0	PRESENT	0
253220	240305	19727D	PARTICIPANT	0	PRESENT	0
253221	240305	04049K	PARTICIPANT	0	PRESENT	0
253222	240305	97011G	PARTICIPANT	0	PRESENT	0
253223	240305	14121F	PARTICIPANT	0	PRESENT	0
253224	240305	14225N	PARTICIPANT	0	PRESENT	0
253225	240305	11067R	PARTICIPANT	0	PRESENT	0
253226	240305	19301E	PARTICIPANT	0	PRESENT	0
253227	240305	14109K	PARTICIPANT	0	PRESENT	0
253228	240305	14097Y	PARTICIPANT	0	PRESENT	0
253229	240305	19349W	PARTICIPANT	0	PRESENT	0
253230	240305	14081Q	PARTICIPANT	0	PRESENT	0
253231	240305	14073Q	PARTICIPANT	0	PRESENT	0
253232	240305	04059M	PARTICIPANT	0	PRESENT	0
253233	240305	14219Q	PARTICIPANT	0	PRESENT	0
253234	240305	16685X	PARTICIPANT	0	PRESENT	0
253235	240305	04092N	PARTICIPANT	0	PRESENT	0
253236	240305	19553Y	PARTICIPANT	0	PRESENT	0
253237	240305	14223L	PARTICIPANT	0	PRESENT	0
253238	240305	08034U	PARTICIPANT	0	PRESENT	0
253239	240305	19581D	PARTICIPANT	0	PRESENT	0
253240	240305	19527W	PARTICIPANT	0	PRESENT	0
243267	243266	11053K	PARTICIPANT	\N	PRESENT	0
243268	243266	14159V	PARTICIPANT	\N	PRESENT	0
243269	243266	05012A	PARTICIPANT	\N	PRESENT	0
244107	241368	14071N	PARTICIPANT	\N	PRESENT	0
244108	241368	14327T	PARTICIPANT	\N	PRESENT	0
244225	241368	95067Q	PARTICIPANT	\N	PRESENT	0
244272	244271	14026U	PARTICIPANT	\N	PRESENT	0
244274	244273	14026U	PARTICIPANT	\N	PRESENT	0
244275	244273	11067R	PARTICIPANT	\N	PRESENT	0
244277	244276	14026U	PARTICIPANT	\N	PRESENT	0
244278	244276	11048N	PARTICIPANT	\N	PRESENT	0
244280	244279	19515S	PARTICIPANT	\N	PRESENT	0
244281	244279	14026U	PARTICIPANT	\N	PRESENT	0
244282	244279	11067R	PARTICIPANT	\N	PRESENT	0
246407	246406	14133K	PARTICIPANT	\N	PRESENT	0
246409	246406	14097Y	PARTICIPANT	\N	PRESENT	0
249578	249577	07033P	PARTICIPANT	\N	PRESENT	0
249579	249577	19611R	PARTICIPANT	\N	PRESENT	0
249580	249577	14030Q	PARTICIPANT	\N	PRESENT	0
249581	249577	14229S	PARTICIPANT	\N	PRESENT	0
249582	249577	19749K	PARTICIPANT	\N	PRESENT	0
249583	249577	04018C	PARTICIPANT	\N	PRESENT	0
249584	249577	92040Q	PARTICIPANT	\N	PRESENT	0
249585	249577	14059S	PARTICIPANT	\N	PRESENT	0
250687	250560	14327T	PARTICIPANT	\N	PRESENT	0
250688	250560	01048V	PARTICIPANT	\N	PRESENT	0
250689	250560	01057W	PARTICIPANT	\N	PRESENT	0
250690	250560	19667J	PARTICIPANT	\N	PRESENT	0
250691	250560	11074Q	PRESIDENT	0	PRESENT	0
250692	250560	89017R	PARTICIPANT	\N	PRESENT	0
250693	250560	19671E	PARTICIPANT	\N	PRESENT	0
250694	250560	11070L	PARTICIPANT	\N	PRESENT	0
250695	250560	14225N	PARTICIPANT	\N	PRESENT	0
250696	250560	07029T	PARTICIPANT	\N	PRESENT	0
250697	250560	14085U	PARTICIPANT	\N	PRESENT	0
250698	250560	07004J	PARTICIPANT	\N	PRESENT	0
250699	250560	19349W	PARTICIPANT	\N	PRESENT	0
250700	250560	14253S	PARTICIPANT	\N	PRESENT	0
250701	250560	19479G	PARTICIPANT	\N	PRESENT	0
250702	250560	19711U	PARTICIPANT	\N	PRESENT	0
250703	250560	08034U	PARTICIPANT	\N	PRESENT	0
250704	250560	19531S	PARTICIPANT	\N	PRESENT	0
250705	250560	19651A	PARTICIPANT	\N	PRESENT	0
250706	250560	19687N	PARTICIPANT	\N	PRESENT	0
250707	250560	12016W	PARTICIPANT	\N	PRESENT	0
250708	250560	08011M	PARTICIPANT	\N	PRESENT	0
250709	250560	08014Q	PARTICIPANT	\N	PRESENT	0
250710	250560	14159V	PARTICIPANT	\N	PRESENT	0
250711	250560	14173T	PARTICIPANT	\N	PRESENT	0
250712	250560	11040E	PARTICIPANT	\N	PRESENT	0
250713	250560	04086Q	PARTICIPANT	\N	PRESENT	0
250714	250560	14083S	PARTICIPANT	\N	PRESENT	0
250715	250560	14199E	PARTICIPANT	\N	PRESENT	0
250716	250560	14121F	PARTICIPANT	\N	PRESENT	0
250717	250560	99004R	PARTICIPANT	\N	PRESENT	0
250718	250560	14331P	PARTICIPANT	\N	EXCUSE	0
250719	250560	11048N	PARTICIPANT	\N	EXCUSE	0
250720	250560	08010L	PARTICIPANT	\N	EXCUSE	0
250721	250604	19543W	PARTICIPANT	\N	PRESENT	0
250722	250604	19611R	PARTICIPANT	\N	PRESENT	0
250723	250604	01024M	PARTICIPANT	\N	PRESENT	0
250724	250604	14089Y	PARTICIPANT	\N	PRESENT	0
250725	250604	19581D	PARTICIPANT	\N	PRESENT	0
250726	250604	04047H	PARTICIPANT	\N	PRESENT	0
250727	250604	14229S	PARTICIPANT	\N	PRESENT	0
250728	250604	14241N	PARTICIPANT	\N	PRESENT	0
250729	250604	08012N	PARTICIPANT	\N	PRESENT	0
250730	250604	95063L	PARTICIPANT	\N	PRESENT	0
250731	250604	11083R	PARTICIPANT	\N	PRESENT	0
250732	250604	11104D	PARTICIPANT	\N	PRESENT	0
250733	250518	19543W	PARTICIPANT	\N	PRESENT	0
250734	250518	19673G	PARTICIPANT	\N	PRESENT	0
250735	250518	19447X	PARTICIPANT	\N	PRESENT	0
250736	250518	19573D	PARTICIPANT	\N	PRESENT	0
250737	250518	14039A	PARTICIPANT	\N	PRESENT	0
250738	250518	14147R	PARTICIPANT	\N	PRESENT	0
250739	250518	14151M	PARTICIPANT	\N	PRESENT	0
250740	250518	08018U	PARTICIPANT	\N	PRESENT	0
250741	250518	98035U	PARTICIPANT	\N	PRESENT	0
250742	250518	14059S	PARTICIPANT	\N	PRESENT	0
250743	250518	04057K	PARTICIPANT	\N	PRESENT	0
250744	250518	19611R	PARTICIPANT	\N	PRESENT	0
250745	250518	10015M	PARTICIPANT	\N	PRESENT	0
250747	250518	01024M	PARTICIPANT	\N	PRESENT	0
250748	250518	04038G	PARTICIPANT	\N	PRESENT	0
250749	250518	19693L	PARTICIPANT	\N	PRESENT	0
250750	250518	14030Q	PARTICIPANT	\N	PRESENT	0
250751	250518	14089Y	PARTICIPANT	\N	PRESENT	0
250752	250518	14251Q	PARTICIPANT	\N	PRESENT	0
250753	250518	14063N	PARTICIPANT	\N	PRESENT	0
250754	250518	14069U	PARTICIPANT	\N	PRESENT	0
250755	250518	14123H	PARTICIPANT	\N	PRESENT	0
250756	250518	11049P	PARTICIPANT	\N	PRESENT	0
250757	250518	04018C	PARTICIPANT	\N	PRESENT	0
250758	250518	04070G	PARTICIPANT	\N	PRESENT	0
250759	250518	19699S	PARTICIPANT	\N	PRESENT	0
250760	250518	04044E	PARTICIPANT	\N	PRESENT	0
250761	250518	19581D	PARTICIPANT	\N	PRESENT	0
250762	250518	04047H	PARTICIPANT	\N	PRESENT	0
250763	250518	14229S	PARTICIPANT	\N	PRESENT	0
250764	250518	05008E	PRESIDENT	0	PRESENT	0
250765	250518	14241N	PARTICIPANT	\N	PRESENT	0
250766	250518	08012N	PARTICIPANT	\N	PRESENT	0
250767	250518	19483C	PARTICIPANT	\N	PRESENT	0
250768	250518	14249W	PARTICIPANT	\N	PRESENT	0
250769	250518	11072N	PARTICIPANT	\N	PRESENT	0
250770	250518	08031R	PARTICIPANT	\N	PRESENT	0
250771	250518	14053L	PARTICIPANT	\N	PRESENT	0
250772	250518	14111D	PARTICIPANT	\N	PRESENT	0
250773	250518	08035V	PARTICIPANT	\N	PRESENT	0
250774	250518	07034Q	PARTICIPANT	\N	PRESENT	0
250775	250518	08045X	PARTICIPANT	\N	PRESENT	0
250776	250518	19253P	PARTICIPANT	\N	PRESENT	0
250777	250518	08043V	PARTICIPANT	\N	PRESENT	0
250778	250518	19719D	PARTICIPANT	\N	PRESENT	0
250779	250518	19725B	PARTICIPANT	\N	PRESENT	0
250780	250518	19729F	PARTICIPANT	\N	PRESENT	0
250781	250518	95063L	PARTICIPANT	\N	PRESENT	0
250782	250518	19731Y	PARTICIPANT	\N	PRESENT	0
250783	250518	19629C	PARTICIPANT	\N	PRESENT	0
250784	250518	08020N	PARTICIPANT	\N	PRESENT	0
250785	250518	19735D	PARTICIPANT	\N	PRESENT	0
250786	250518	11083R	PARTICIPANT	\N	PRESENT	0
250787	250518	11085T	PARTICIPANT	\N	PRESENT	0
250788	250518	19749K	PARTICIPANT	\N	PRESENT	0
250789	250518	14065Q	PARTICIPANT	\N	EXCUSE	0
250790	250604	14123H	PARTICIPANT	\N	PRESENT	0
250792	250518	92040Q	PARTICIPANT	\N	PRESENT	0
250802	250223	19663E	PARTICIPANT	\N	PRESENT	0
250803	250604	95015C	PARTICIPANT	\N	PRESENT	0
250804	250604	14073Q	PARTICIPANT	\N	PRESENT	0
250805	250604	87003B	PARTICIPANT	\N	PRESENT	0
250806	250604	04059M	PARTICIPANT	\N	PRESENT	0
250807	250604	14231L	PARTICIPANT	\N	PRESENT	0
250808	250604	08039A	PARTICIPANT	\N	PRESENT	0
250820	250224	19697Q	PARTICIPANT	\N	PRESENT	0
250821	250224	11067R	PARTICIPANT	\N	PRESENT	0
250822	250224	11077T	PARTICIPANT	\N	PRESENT	0
250823	250224	14355X	PARTICIPANT	\N	PRESENT	0
250824	250224	19569H	PARTICIPANT	\N	PRESENT	0
250825	250224	11097X	PARTICIPANT	\N	PRESENT	0
250826	250224	19415P	PARTICIPANT	\N	PRESENT	0
250827	250224	14223L	PARTICIPANT	\N	PRESENT	0
250828	250224	04045F	PARTICIPANT	\N	PRESENT	0
250829	250224	14026U	PARTICIPANT	\N	PRESENT	0
250830	250224	14227Q	PARTICIPANT	\N	PRESENT	0
250831	250224	19675J	PARTICIPANT	\N	PRESENT	0
250832	250224	11063M	PARTICIPANT	\N	PRESENT	0
250833	250224	17779H	PARTICIPANT	\N	PRESENT	0
250834	250224	19703U	PARTICIPANT	\N	PRESENT	0
250835	250224	14239U	PARTICIPANT	\N	PRESENT	0
250836	250224	11031D	PARTICIPANT	\N	PRESENT	0
250837	250224	14281W	PARTICIPANT	\N	PRESENT	0
250838	250224	14087W	PARTICIPANT	\N	PRESENT	0
250839	250224	19679N	PARTICIPANT	\N	PRESENT	0
250840	250224	14042U	PARTICIPANT	\N	PRESENT	0
250841	250224	19575F	PARTICIPANT	\N	PRESENT	0
250842	250224	14195A	PARTICIPANT	\N	PRESENT	0
250843	250224	14213J	PARTICIPANT	\N	PRESENT	0
250844	250224	19335Q	PARTICIPANT	\N	PRESENT	0
250845	250224	14217N	PARTICIPANT	\N	PRESENT	0
250846	250224	19683J	PARTICIPANT	\N	PRESENT	0
250847	250224	10006L	PARTICIPANT	\N	PRESENT	0
250848	250224	98024R	PRESIDENT	0	PRESENT	0
250849	250224	19521Q	PARTICIPANT	\N	PRESENT	0
250850	250224	19527W	PARTICIPANT	\N	PRESENT	0
250851	250224	01034P	PARTICIPANT	\N	PRESENT	0
250852	250224	04092N	PRESIDENT	1	PRESENT	0
260753	250093	11064N	PARTICIPANT	\N	PRESENT	0
260754	250093	14147R	PARTICIPANT	\N	PRESENT	0
260755	250093	98023Q	PARTICIPANT	\N	PRESENT	0
260756	250093	07029T	PARTICIPANT	\N	PRESENT	0
260764	250093	19737F	PARTICIPANT	\N	PRESENT	0
260765	250093	19621T	PARTICIPANT	\N	PRESENT	0
260766	250093	19673G	PARTICIPANT	\N	PRESENT	0
260767	250093	14169X	PARTICIPANT	\N	PRESENT	0
260768	250093	01043Q	PARTICIPANT	\N	PRESENT	0
260769	250093	19593H	PARTICIPANT	\N	PRESENT	0
260770	250093	04061F	PARTICIPANT	\N	PRESENT	0
260771	250093	19695N	PARTICIPANT	\N	PRESENT	0
260772	250093	19347U	PARTICIPANT	\N	PRESENT	0
260773	250093	14281W	PARTICIPANT	\N	PRESENT	0
260774	250093	08060W	PARTICIPANT	\N	PRESENT	0
260775	250093	14157T	PARTICIPANT	\N	PRESENT	0
260776	250093	11056N	PARTICIPANT	\N	PRESENT	0
260777	258621	14097Y	PARTICIPANT	\N	PRESENT	0
260778	258621	14133K	PARTICIPANT	\N	PRESENT	0
260779	258621	95030B	PARTICIPANT	\N	PRESENT	0
260780	258621	08034U	PARTICIPANT	\N	PRESENT	0
260781	258621	01062T	PARTICIPANT	\N	PRESENT	0
260782	258621	11041F	PARTICIPANT	\N	PRESENT	0
260783	258621	04034C	PARTICIPANT	\N	PRESENT	0
260784	258621	04040A	PARTICIPANT	\N	PRESENT	0
260785	258621	04042C	PRESIDENT	0	PRESENT	0
260786	258621	95037J	PARTICIPANT	\N	PRESENT	0
260787	258621	14105F	PARTICIPANT	\N	PRESENT	0
260788	258621	14267Y	PARTICIPANT	\N	PRESENT	0
260789	258621	98050T	PARTICIPANT	\N	PRESENT	0
260790	258621	97011G	PARTICIPANT	\N	PRESENT	0
260751	250093	19335Q	PARTICIPANT	\N	PRESENT	0
260752	250093	19723Y	PARTICIPANT	\N	PRESENT	0
260791	258621	98029W	PARTICIPANT	\N	PRESENT	0
260792	250093	19741B	PARTICIPANT	\N	PRESENT	0
260793	258621	19251M	PARTICIPANT	\N	PRESENT	0
260794	250093	19551W	PARTICIPANT	\N	PRESENT	0
260795	250093	08055A	PARTICIPANT	\N	PRESENT	0
260802	250093	08024S	PARTICIPANT	\N	PRESENT	0
260810	250093	08043V	PARTICIPANT	\N	PRESENT	0
260814	250093	08020N	PARTICIPANT	\N	PRESENT	0
260812	250093	19747H	PARTICIPANT	\N	PRESENT	0
260813	250093	19563B	PARTICIPANT	\N	PRESENT	0
260815	258621	16685X	PARTICIPANT	\N	PRESENT	0
260816	250093	19549D	PARTICIPANT	\N	PRESENT	0
260817	258621	08061X	PARTICIPANT	\N	PRESENT	0
260818	258621	08047A	PARTICIPANT	\N	PRESENT	0
260819	250093	11012A	PARTICIPANT	\N	PRESENT	0
260820	250093	14231L	PARTICIPANT	\N	PRESENT	0
260821	250093	11067R	PARTICIPANT	\N	PRESENT	0
260822	250093	19631V	PARTICIPANT	\N	PRESENT	0
260834	250093	11070L	PARTICIPANT	\N	PRESENT	0
260835	250093	05012A	PARTICIPANT	\N	PRESENT	0
260836	250093	08031R	PARTICIPANT	\N	PRESENT	0
260837	250093	14034U	PARTICIPANT	\N	PRESENT	0
260838	250093	19703U	PARTICIPANT	\N	PRESENT	0
260839	259089	19703U	PARTICIPANT	\N	PRESENT	0
260840	259089	08058D	PRESIDENT	0	PRESENT	0
260841	259089	11053K	PARTICIPANT	\N	PRESENT	0
260842	259089	19581D	PARTICIPANT	\N	PRESENT	0
260843	259089	11049P	PARTICIPANT	\N	PRESENT	0
260844	259089	19721W	PARTICIPANT	\N	PRESENT	0
260845	259089	19729F	PARTICIPANT	\N	EXCUSE	0
260847	250093	14073Q	PARTICIPANT	\N	PRESENT	0
260856	250093	14038Y	PARTICIPANT	\N	PRESENT	0
260857	250093	08015R	PARTICIPANT	\N	PRESENT	0
260860	250093	11043H	PARTICIPANT	\N	PRESENT	0
260861	250093	19483C	PARTICIPANT	\N	PRESENT	0
260862	250093	01048V	PARTICIPANT	\N	PRESENT	0
260939	260496	19565D	PARTICIPANT	\N	PRESENT	0
260940	260496	04085P	PARTICIPANT	\N	PRESENT	0
260941	260496	19347U	PARTICIPANT	\N	PRESENT	0
260942	260496	07029T	PARTICIPANT	\N	PRESENT	0
260943	260496	14219Q	PARTICIPANT	\N	PRESENT	0
260944	260496	08052W	PARTICIPANT	\N	PRESENT	0
260945	260496	08055A	PARTICIPANT	\N	PRESENT	0
260946	260496	98023Q	PARTICIPANT	\N	PRESENT	0
260947	260496	19533U	PARTICIPANT	\N	PRESENT	0
260948	260496	19551W	PARTICIPANT	\N	PRESENT	0
260949	260496	08060W	PARTICIPANT	\N	PRESENT	0
260950	260496	14051J	PARTICIPANT	\N	PRESENT	0
260951	260496	19549D	PARTICIPANT	\N	PRESENT	0
260952	260496	19637C	PARTICIPANT	\N	PRESENT	0
260953	260496	19349W	PARTICIPANT	\N	PRESENT	0
260954	260496	19387D	PARTICIPANT	\N	PRESENT	0
260955	260496	14030Q	PARTICIPANT	\N	PRESENT	0
260956	260496	19739H	PARTICIPANT	\N	PRESENT	0
260957	260496	19713W	PARTICIPANT	\N	PRESENT	0
260958	260496	19447X	PARTICIPANT	\N	PRESENT	0
260959	260496	19747H	PARTICIPANT	\N	PRESENT	0
260960	260496	19503N	PARTICIPANT	\N	PRESENT	0
260961	260496	05012A	PARTICIPANT	\N	PRESENT	0
260962	260496	19737F	PARTICIPANT	\N	PRESENT	0
260963	260496	95030B	PARTICIPANT	\N	PRESENT	0
260964	260496	19671E	PARTICIPANT	\N	PRESENT	0
260965	260496	14237S	PARTICIPANT	\N	PRESENT	0
260966	260496	04061F	PARTICIPANT	\N	PRESENT	0
260967	260496	19701S	PARTICIPANT	\N	PRESENT	0
260968	260496	19545Y	PARTICIPANT	\N	PRESENT	0
260969	260496	19695N	PARTICIPANT	\N	PRESENT	0
260970	260496	19521Q	PARTICIPANT	\N	PRESENT	0
260971	260496	19483C	PARTICIPANT	\N	PRESENT	0
260972	260496	19525U	PARTICIPANT	\N	PRESENT	0
260973	260496	08009T	PARTICIPANT	\N	PRESENT	0
260974	260496	14119M	PARTICIPANT	\N	PRESENT	0
260975	260496	19441R	PARTICIPANT	\N	PRESENT	0
260976	260496	19629C	PARTICIPANT	\N	PRESENT	0
260977	260496	14147R	PARTICIPANT	\N	PRESENT	0
260978	260496	14083S	PARTICIPANT	\N	PRESENT	0
260979	260496	08024S	PARTICIPANT	\N	PRESENT	0
260980	260496	14038Y	PARTICIPANT	\N	PRESENT	0
260981	260496	19725B	PARTICIPANT	\N	PRESENT	0
260982	260496	18083K	PARTICIPANT	\N	PRESENT	0
260983	260496	08010L	PARTICIPANT	\N	PRESENT	0
260984	260496	19709B	PARTICIPANT	\N	PRESENT	0
260985	260496	89017R	PARTICIPANT	\N	PRESENT	0
260986	260496	01057W	PARTICIPANT	\N	PRESENT	0
260987	260496	96004D	PARTICIPANT	\N	PRESENT	0
260988	260496	14053L	PARTICIPANT	\N	PRESENT	0
260989	260496	19631V	PARTICIPANT	\N	PRESENT	0
260990	260496	14021P	PARTICIPANT	\N	PRESENT	0
260991	260496	14169X	PARTICIPANT	\N	PRESENT	0
260992	260496	11064N	PARTICIPANT	\N	PRESENT	0
260926	258621	98018T	PARTICIPANT	\N	PRESENT	0
260938	260496	11077T	PARTICIPANT	\N	PRESENT	0
260993	260496	14221J	PARTICIPANT	\N	PRESENT	0
260994	260496	14249W	PARTICIPANT	\N	PRESENT	0
260995	260496	14034U	PARTICIPANT	\N	PRESENT	0
260996	260496	14073Q	PARTICIPANT	\N	PRESENT	0
260997	260496	14089Y	PARTICIPANT	\N	PRESENT	0
260998	260496	14033T	PARTICIPANT	\N	PRESENT	0
260999	260496	08068F	PARTICIPANT	\N	PRESENT	0
261004	261000	14034U	PARTICIPANT	\N	PRESENT	0
261026	261000	19347U	PARTICIPANT	\N	PRESENT	0
261027	261000	19551W	PARTICIPANT	\N	PRESENT	0
261028	261000	08060W	PARTICIPANT	\N	PRESENT	0
261029	261000	14038Y	PARTICIPANT	\N	PRESENT	0
261030	261000	19637C	PARTICIPANT	\N	PRESENT	0
261031	261000	19681G	PARTICIPANT	\N	PRESENT	0
261032	261000	04085P	PARTICIPANT	\N	PRESENT	0
261033	261000	14219Q	PARTICIPANT	\N	PRESENT	0
261034	261000	96004D	PARTICIPANT	\N	PRESENT	0
261035	261000	08009T	PARTICIPANT	\N	PRESENT	0
261036	261000	14051J	PARTICIPANT	\N	PRESENT	0
261037	261000	19671E	PARTICIPANT	\N	PRESENT	0
261038	261000	11012A	PARTICIPANT	\N	PRESENT	0
261039	261000	19387D	PARTICIPANT	\N	PRESENT	0
261040	261000	08019V	PARTICIPANT	\N	PRESENT	0
261041	261000	14093U	PARTICIPANT	\N	PRESENT	0
261042	261000	19711U	PARTICIPANT	\N	PRESENT	0
261043	261000	98023Q	PARTICIPANT	\N	PRESENT	0
261044	261000	19349W	PARTICIPANT	\N	PRESENT	0
261045	261000	08055A	PARTICIPANT	\N	PRESENT	0
261046	261000	19503N	PARTICIPANT	\N	PRESENT	0
261047	261000	19737F	PARTICIPANT	\N	PRESENT	0
261048	261000	19447X	PARTICIPANT	\N	PRESENT	0
261049	261000	19701S	PARTICIPANT	\N	PRESENT	0
261050	261000	18083K	PARTICIPANT	\N	PRESENT	0
261051	261000	14073Q	PARTICIPANT	\N	PRESENT	0
261052	261000	19749K	PARTICIPANT	\N	PRESENT	0
261053	261000	08039A	PARTICIPANT	\N	PRESENT	0
261054	261000	14121F	PARTICIPANT	\N	PRESENT	0
261055	261000	08024S	PARTICIPANT	\N	PRESENT	0
261056	261000	99004R	PARTICIPANT	\N	PRESENT	0
261057	261000	07029T	PARTICIPANT	\N	PRESENT	0
261062	261000	14147R	PARTICIPANT	\N	PRESENT	0
261063	261000	01024M	PARTICIPANT	\N	PRESENT	0
261064	261000	19731Y	PARTICIPANT	\N	PRESENT	0
261065	261000	19747H	PARTICIPANT	\N	PRESENT	0
247014	240294	11077T	PARTICIPANT	\N	PRESENT	0
246596	240291	08052W	PARTICIPANT	\N	PRESENT	0
246597	240291	04071H	PARTICIPANT	\N	PRESENT	0
246598	240291	01028R	PARTICIPANT	\N	PRESENT	0
246599	240291	19735D	PARTICIPANT	\N	PRESENT	0
246600	240291	11027H	PARTICIPANT	\N	PRESENT	0
246601	240291	14021P	PARTICIPANT	\N	PRESENT	0
246602	240291	08045X	PARTICIPANT	\N	PRESENT	0
246603	240291	14107H	PARTICIPANT	\N	PRESENT	0
246604	240291	14029X	PARTICIPANT	\N	PRESENT	0
246605	240291	11104D	PARTICIPANT	\N	PRESENT	0
246606	240291	01062T	PARTICIPANT	\N	PRESENT	0
246607	240291	08038Y	PARTICIPANT	\N	PRESENT	0
246608	240291	08060W	PARTICIPANT	\N	PRESENT	0
246609	240291	11066Q	PARTICIPANT	\N	PRESENT	0
246610	240291	14281W	PARTICIPANT	\N	PRESENT	0
246611	240291	19443T	PARTICIPANT	\N	PRESENT	0
246612	240291	08014Q	PARTICIPANT	\N	PRESENT	0
246613	240291	19727D	PARTICIPANT	\N	PRESENT	0
246614	240291	19531S	PARTICIPANT	\N	PRESENT	0
246615	240291	19683J	PARTICIPANT	\N	PRESENT	0
246616	240291	04047H	PARTICIPANT	\N	PRESENT	0
246617	240291	17779H	PARTICIPANT	\N	PRESENT	0
246618	240291	14026U	PARTICIPANT	\N	PRESENT	0
246619	240291	08058D	PARTICIPANT	\N	PRESENT	0
246620	240291	14121F	PARTICIPANT	\N	PRESENT	0
246621	240291	19329S	PARTICIPANT	\N	PRESENT	0
246622	240291	11099A	PARTICIPANT	\N	PRESENT	0
246623	240291	08017T	PARTICIPANT	\N	PRESENT	0
246624	240291	08053X	PARTICIPANT	\N	PRESENT	0
246625	240291	14179A	PARTICIPANT	\N	PRESENT	0
246626	240291	98018T	PARTICIPANT	\N	PRESENT	0
246627	240291	19525U	PARTICIPANT	\N	PRESENT	0
246628	240291	01024M	PARTICIPANT	\N	PRESENT	0
246629	240291	04044E	PARTICIPANT	\N	PRESENT	0
246630	240291	11045K	PARTICIPANT	\N	PRESENT	0
246631	240291	04045F	PARTICIPANT	\N	PRESENT	0
246632	240291	19725B	PARTICIPANT	\N	PRESENT	0
246633	240291	14207L	PARTICIPANT	\N	PRESENT	0
246634	240291	04040A	PARTICIPANT	\N	PRESENT	0
246635	240291	11097X	PARTICIPANT	\N	PRESENT	0
246636	240291	19333N	PARTICIPANT	\N	PRESENT	0
246637	240291	14001X	PARTICIPANT	\N	PRESENT	0
246638	240291	14227Q	PARTICIPANT	\N	PRESENT	0
246639	240291	19551W	PARTICIPANT	\N	PRESENT	0
246640	240291	14249W	PARTICIPANT	\N	PRESENT	0
246641	240291	19591F	PARTICIPANT	\N	PRESENT	0
246642	240291	11067R	PARTICIPANT	\N	PRESENT	0
246643	240291	19503N	PARTICIPANT	\N	PRESENT	0
246644	240291	19527W	PARTICIPANT	\N	PRESENT	0
246645	240291	19479G	PARTICIPANT	\N	PRESENT	0
246646	240291	14063N	PARTICIPANT	\N	PRESENT	0
246647	240291	14085U	PARTICIPANT	\N	PRESENT	0
246648	240291	19421M	PARTICIPANT	\N	PRESENT	0
246649	240291	19669L	PARTICIPANT	\N	PRESENT	0
246650	240291	04043D	PARTICIPANT	\N	PRESENT	0
246651	240291	14257W	PARTICIPANT	\N	PRESENT	0
246718	240291	04035D	PARTICIPANT	\N	PRESENT	0
246653	240291	19549D	PARTICIPANT	\N	PRESENT	0
246654	240291	14053L	PARTICIPANT	\N	PRESENT	0
246655	240291	19631V	PARTICIPANT	\N	PRESENT	0
246656	240291	19251M	PARTICIPANT	\N	PRESENT	0
246657	240291	19413M	PARTICIPANT	\N	PRESENT	0
246658	240291	14087W	PARTICIPANT	\N	PRESENT	0
246659	240291	19511N	PARTICIPANT	\N	PRESENT	0
246660	240291	19689Q	PARTICIPANT	\N	PRESENT	0
246661	240291	19489J	PARTICIPANT	\N	PRESENT	0
246662	240291	05012A	PARTICIPANT	\N	PRESENT	0
246663	240291	11053K	PARTICIPANT	\N	PRESENT	0
246664	240291	19533U	PARTICIPANT	\N	PRESENT	0
246665	240291	19649G	PARTICIPANT	\N	PRESENT	0
246666	240291	14193X	PARTICIPANT	\N	PRESENT	0
246667	240291	19521Q	PARTICIPANT	\N	PRESENT	0
246668	240291	19647E	PARTICIPANT	\N	PRESENT	0
246669	240291	19671E	PARTICIPANT	\N	PRESENT	0
246670	240291	19611R	PARTICIPANT	\N	PRESENT	0
246671	240291	08056B	PARTICIPANT	\N	PRESENT	0
246672	240291	19383Y	PARTICIPANT	\N	PRESENT	0
246673	240291	19319Q	PARTICIPANT	\N	PRESENT	0
246674	240291	19713W	PARTICIPANT	\N	PRESENT	0
246675	240291	01034P	PARTICIPANT	\N	PRESENT	0
246676	240291	97011G	PARTICIPANT	\N	PRESENT	0
246677	240291	11085T	PARTICIPANT	\N	PRESENT	0
246678	240291	14219Q	PARTICIPANT	\N	PRESENT	0
246679	240291	19569H	PARTICIPANT	\N	PRESENT	0
246680	240291	07033P	PARTICIPANT	\N	PRESENT	0
246681	240291	19737F	PARTICIPANT	\N	PRESENT	0
246682	240291	14205J	PARTICIPANT	\N	PRESENT	0
246683	240291	14217N	PARTICIPANT	\N	PRESENT	0
246684	240291	14327T	PARTICIPANT	\N	PRESENT	0
246685	240291	19699S	PARTICIPANT	\N	PRESENT	0
246698	240291	14357A	PARTICIPANT	\N	PRESENT	0
246687	240291	14231L	PARTICIPANT	\N	PRESENT	0
246688	240291	04061F	PARTICIPANT	\N	PRESENT	0
246689	240291	14079W	PARTICIPANT	\N	PRESENT	0
246690	240291	16685X	PARTICIPANT	\N	PRESENT	0
246691	240291	19369B	PARTICIPANT	\N	PRESENT	0
246692	240291	19335Q	PARTICIPANT	\N	PRESENT	0
246693	240291	01043Q	PARTICIPANT	\N	PRESENT	0
246694	240291	14265W	PARTICIPANT	\N	PRESENT	0
246695	240291	19749K	PARTICIPANT	\N	PRESENT	0
246696	240291	19619A	PARTICIPANT	\N	PRESENT	0
246697	240291	19441R	PARTICIPANT	\N	PRESENT	0
246699	240291	19715Y	PARTICIPANT	\N	PRESENT	0
246700	240291	19269X	PARTICIPANT	\N	PRESENT	0
246701	240291	08012N	PARTICIPANT	\N	PRESENT	0
246702	240291	14093U	PARTICIPANT	\N	PRESENT	0
246703	240291	11031D	PARTICIPANT	\N	PRESENT	0
246709	240291	19483C	PARTICIPANT	\N	PRESENT	0
246705	240291	08021P	PARTICIPANT	\N	PRESENT	0
246706	240291	19675J	PARTICIPANT	\N	PRESENT	0
246707	240291	04089T	PARTICIPANT	\N	PRESENT	0
246708	240291	19729F	PARTICIPANT	\N	PRESENT	0
246710	240291	86034E	PARTICIPANT	\N	PRESENT	0
246711	240291	19701S	PARTICIPANT	\N	PRESENT	0
246712	240291	11065P	PARTICIPANT	\N	PRESENT	0
246713	240291	89017R	PARTICIPANT	\N	PRESENT	0
246714	240291	98050T	PARTICIPANT	\N	PRESENT	0
246715	240291	14059S	PARTICIPANT	\N	PRESENT	0
246716	240291	14097Y	PARTICIPANT	\N	PRESENT	0
246717	240291	19367Y	PARTICIPANT	\N	PRESENT	0
246719	240291	04086Q	PARTICIPANT	\N	PRESENT	0
246720	240291	19733B	PARTICIPANT	\N	PRESENT	0
246721	240291	04049K	PARTICIPANT	\N	PRESENT	0
246722	240291	19709B	PARTICIPANT	\N	PRESENT	0
246723	240291	01048V	PARTICIPANT	\N	PRESENT	0
246724	240291	08011M	PARTICIPANT	\N	PRESENT	0
246725	240291	08035V	PARTICIPANT	\N	PRESENT	0
246726	240291	14123H	PARTICIPANT	\N	PRESENT	0
246731	240291	14089Y	PARTICIPANT	\N	PRESENT	0
246728	240291	80013X	PARTICIPANT	\N	PRESENT	0
246729	240291	14151M	PARTICIPANT	\N	PRESENT	0
246730	240291	14215L	PARTICIPANT	\N	PRESENT	0
246732	240291	14157T	PARTICIPANT	\N	PRESENT	0
247015	240294	14123H	PARTICIPANT	\N	PRESENT	0
247016	240294	04057K	PARTICIPANT	\N	PRESENT	0
247017	240294	08031R	PARTICIPANT	\N	PRESENT	0
247018	240294	04059M	PARTICIPANT	\N	PRESENT	0
247019	240294	14229S	PARTICIPANT	\N	PRESENT	0
247020	240294	08017T	PARTICIPANT	\N	PRESENT	0
247021	240294	14039A	PARTICIPANT	\N	PRESENT	0
247022	240294	19693L	PARTICIPANT	\N	PRESENT	0
247023	240294	07029T	PARTICIPANT	\N	PRESENT	0
247024	240294	08019V	PARTICIPANT	\N	PRESENT	0
247025	240294	19667J	PARTICIPANT	\N	PRESENT	0
247026	240294	19673G	PARTICIPANT	\N	PRESENT	0
247027	240294	14083S	PARTICIPANT	\N	PRESENT	0
247028	240294	19713W	PARTICIPANT	\N	PRESENT	0
247029	240294	14042U	PARTICIPANT	\N	PRESENT	0
247030	240294	19551W	PARTICIPANT	\N	PRESENT	0
247031	240294	19593H	PARTICIPANT	\N	PRESENT	0
247032	240294	04070G	PARTICIPANT	\N	PRESENT	0
247033	240294	14261S	PARTICIPANT	\N	PRESENT	0
247034	240294	19253P	PARTICIPANT	\N	PRESENT	0
247035	240294	19707Y	PARTICIPANT	\N	PRESENT	0
247036	240294	08020N	PARTICIPANT	\N	PRESENT	0
247037	240294	19643A	PARTICIPANT	\N	PRESENT	0
247038	240294	19573D	PARTICIPANT	\N	PRESENT	0
247039	240294	04043D	PARTICIPANT	\N	PRESENT	0
247040	240294	19533U	PARTICIPANT	\N	PRESENT	0
247041	240294	19699S	PARTICIPANT	\N	PRESENT	0
247042	240294	19583F	PARTICIPANT	\N	PRESENT	0
247043	240294	19705W	PARTICIPANT	\N	PRESENT	0
247044	240294	98050T	PARTICIPANT	\N	PRESENT	0
247045	240294	14199E	PARTICIPANT	\N	PRESENT	0
247046	240294	19415P	PARTICIPANT	\N	PRESENT	0
247047	240294	14033T	PARTICIPANT	\N	PRESENT	0
247048	240294	04088S	PARTICIPANT	\N	PRESENT	0
254390	240315	14219Q	PARTICIPANT	0	PRESENT	0
254391	240315	14327T	PARTICIPANT	0	PRESENT	0
254392	240315	14211G	PARTICIPANT	0	PRESENT	0
254393	240315	19577H	PARTICIPANT	0	PRESENT	0
254394	240315	14215L	PARTICIPANT	0	PRESENT	0
254395	240315	19301E	PARTICIPANT	0	PRESENT	0
254396	240315	08061X	PARTICIPANT	0	PRESENT	0
254397	240315	01060R	PARTICIPANT	0	PRESENT	0
254398	240315	19441R	PARTICIPANT	0	PRESENT	0
254399	240315	14217N	PARTICIPANT	0	PRESENT	0
254400	240315	08015R	PARTICIPANT	0	PRESENT	0
254401	240315	11012A	PARTICIPANT	0	PRESENT	0
254402	240315	19253P	PARTICIPANT	0	PRESENT	0
254403	240315	92040Q	PARTICIPANT	0	PRESENT	0
254404	240315	14147R	PARTICIPANT	0	PRESENT	0
254405	240315	19413M	PARTICIPANT	0	PRESENT	0
254406	240315	14261S	PARTICIPANT	0	PRESENT	0
254407	240315	11104D	PARTICIPANT	0	PRESENT	0
254408	240315	14109K	PARTICIPANT	0	PRESENT	0
254409	240315	19687N	PARTICIPANT	0	PRESENT	0
254410	240315	14028W	PARTICIPANT	0	PRESENT	0
254411	240315	08060W	PARTICIPANT	0	PRESENT	0
254412	240315	19347U	PARTICIPANT	0	PRESENT	0
254413	240315	17589D	PARTICIPANT	0	PRESENT	0
254414	240315	08021P	PARTICIPANT	0	PRESENT	0
254415	240315	08017T	PARTICIPANT	0	PRESENT	0
254416	240315	08019V	PARTICIPANT	0	PRESENT	0
254417	240315	14231L	PARTICIPANT	0	PRESENT	0
254418	240315	08020N	PARTICIPANT	0	PRESENT	0
254419	240315	19733B	PARTICIPANT	0	PRESENT	0
254420	240315	14051J	PARTICIPANT	0	PRESENT	0
254421	240315	14107H	PARTICIPANT	0	PRESENT	0
254422	240315	01028R	PARTICIPANT	0	PRESENT	0
254423	240315	19741B	PARTICIPANT	0	PRESENT	0
254424	240315	19723Y	PARTICIPANT	0	PRESENT	0
254425	240315	14281W	PARTICIPANT	0	PRESENT	0
254426	240315	08014Q	PARTICIPANT	0	PRESENT	0
254427	240315	19713W	PARTICIPANT	0	PRESENT	0
254428	240315	08044W	PARTICIPANT	0	PRESENT	0
254429	240315	14042U	PARTICIPANT	0	PRESENT	0
254430	240315	14063N	PARTICIPANT	0	PRESENT	0
254431	240315	19543W	PARTICIPANT	0	PRESENT	0
254432	240315	19647E	PARTICIPANT	0	PRESENT	0
254433	240315	12016W	PARTICIPANT	0	PRESENT	0
254434	240315	14201E	PARTICIPANT	0	PRESENT	0
254435	240315	87003B	PARTICIPANT	0	PRESENT	0
254436	240315	14135M	PARTICIPANT	0	PRESENT	0
254437	240315	04033B	PARTICIPANT	0	PRESENT	0
254438	240315	17583W	PARTICIPANT	0	PRESENT	0
254439	240315	14169X	PARTICIPANT	0	PRESENT	0
254440	240315	14123H	PARTICIPANT	0	PRESENT	0
254441	240315	99004R	PARTICIPANT	0	PRESENT	0
254442	240315	95030B	PARTICIPANT	0	PRESENT	0
254443	240315	14173T	PARTICIPANT	0	PRESENT	0
254444	240315	01025N	PARTICIPANT	0	PRESENT	0
254445	240315	19593H	PARTICIPANT	0	PRESENT	0
254446	240315	01057W	PARTICIPANT	0	PRESENT	0
254447	240315	14205J	PARTICIPANT	0	PRESENT	0
254448	240315	11033F	PARTICIPANT	0	PRESENT	0
254449	240315	14197C	PARTICIPANT	0	PRESENT	0
254450	240315	19737F	PARTICIPANT	0	PRESENT	0
254451	240315	19583F	PARTICIPANT	0	PRESENT	0
254452	240315	14111D	PARTICIPANT	0	PRESENT	0
254453	240315	08062Y	PARTICIPANT	0	PRESENT	0
254454	240315	19467C	PARTICIPANT	0	PRESENT	0
254455	240315	04045F	PARTICIPANT	0	PRESENT	0
254456	240315	08012N	PARTICIPANT	0	PRESENT	0
254457	240315	19681G	PARTICIPANT	0	PRESENT	0
254458	240315	19691J	PARTICIPANT	0	PRESENT	0
254459	240315	08068F	PARTICIPANT	0	PRESENT	0
254460	240315	08049C	PARTICIPANT	0	PRESENT	0
254461	240315	08028W	PARTICIPANT	0	PRESENT	0
254462	240315	10006L	PARTICIPANT	0	PRESENT	0
254774	251799	08009T	PRESIDENT	0	PRESENT	0
254775	251799	80027E	PARTICIPANT	\N	EXCUSE	0
254776	251799	19599P	PARTICIPANT	\N	EXCUSE	0
254954	251861	19697Q	PARTICIPANT	\N	PRESENT	0
254955	251861	19569H	PARTICIPANT	\N	PRESENT	0
254956	251861	11097X	PARTICIPANT	\N	PRESENT	0
254957	251861	19415P	PARTICIPANT	\N	PRESENT	0
254958	251861	14223L	PARTICIPANT	\N	PRESENT	0
254959	251861	04045F	PARTICIPANT	\N	PRESENT	0
254960	251861	14026U	PARTICIPANT	\N	PRESENT	0
254961	251861	14227Q	PARTICIPANT	\N	PRESENT	0
254962	251861	17779H	PARTICIPANT	\N	PRESENT	0
254963	251861	11063M	PARTICIPANT	\N	PRESENT	0
254964	251861	11031D	PARTICIPANT	\N	PRESENT	0
254965	251861	19703U	PARTICIPANT	\N	PRESENT	0
254966	251861	19553Y	PARTICIPANT	\N	PRESENT	0
254967	251861	14281W	PARTICIPANT	\N	PRESENT	0
254968	251861	14087W	PARTICIPANT	\N	PRESENT	0
254969	251861	19679N	PARTICIPANT	\N	PRESENT	0
254970	251861	14042U	PARTICIPANT	\N	PRESENT	0
254971	251861	14195A	PARTICIPANT	\N	PRESENT	0
254972	251861	19575F	PARTICIPANT	\N	PRESENT	0
254973	251861	19367Y	PARTICIPANT	\N	PRESENT	0
254974	251861	14213J	PARTICIPANT	\N	PRESENT	0
254975	251861	14217N	PARTICIPANT	\N	PRESENT	0
254976	251861	14261S	PARTICIPANT	\N	PRESENT	0
254977	251861	19683J	PARTICIPANT	\N	PRESENT	0
254978	251861	10006L	PARTICIPANT	\N	PRESENT	0
254979	251861	98024R	PARTICIPANT	\N	PRESENT	0
254980	251861	19521Q	PARTICIPANT	\N	PRESENT	0
254981	251861	19527W	PARTICIPANT	\N	PRESENT	0
254982	251861	01034P	PARTICIPANT	\N	PRESENT	0
254983	251861	04092N	PRESIDENT	0	PRESENT	0
254984	251861	08052W	PARTICIPANT	\N	PRESENT	0
254985	251861	19691J	PARTICIPANT	\N	PRESENT	0
254986	251861	19715Y	PARTICIPANT	\N	PRESENT	0
254987	251861	19723Y	PARTICIPANT	\N	PRESENT	0
254988	251861	19727D	PARTICIPANT	\N	PRESENT	0
254989	251861	14119M	PARTICIPANT	\N	PRESENT	0
254990	251861	11103C	PARTICIPANT	\N	PRESENT	0
254991	251861	14071N	PARTICIPANT	\N	PRESENT	0
254992	251861	08048B	PARTICIPANT	\N	EXCUSE	0
255048	254772	14001X	PARTICIPANT	\N	PRESENT	0
255049	254772	19543W	PARTICIPANT	\N	PRESENT	0
255050	254772	04044E	PARTICIPANT	\N	PRESENT	0
255051	254772	04047H	PARTICIPANT	\N	PRESENT	0
255052	254772	19673G	PARTICIPANT	\N	PRESENT	0
255053	254772	01028R	PARTICIPANT	\N	PRESENT	0
255054	254772	05008E	PRESIDENT	0	PRESENT	0
255055	254772	19447X	PARTICIPANT	\N	PRESENT	0
255056	254772	14231L	PARTICIPANT	\N	PRESENT	0
255057	254772	19489J	PARTICIPANT	\N	PRESENT	0
255058	254772	14041T	PARTICIPANT	\N	PRESENT	0
255059	254772	14147R	PARTICIPANT	\N	PRESENT	0
255060	254772	14179A	PARTICIPANT	\N	PRESENT	0
255061	254772	14151M	PARTICIPANT	\N	PRESENT	0
255062	254772	14215L	PARTICIPANT	\N	PRESENT	0
255063	254772	19483C	PARTICIPANT	\N	PRESENT	0
255064	254772	08018U	PARTICIPANT	\N	PRESENT	0
255065	254772	14259Y	PARTICIPANT	\N	PRESENT	0
255066	254772	14053L	PARTICIPANT	\N	PRESENT	0
255067	254772	98035U	PARTICIPANT	\N	PRESENT	0
255068	254772	14065Q	PARTICIPANT	\N	PRESENT	0
255069	254772	19649G	PARTICIPANT	\N	PRESENT	0
255070	254772	07034Q	PRESIDENT	1	PRESENT	0
255071	254772	08045X	PARTICIPANT	\N	PRESENT	0
255072	254772	10015M	PARTICIPANT	\N	PRESENT	0
255073	254772	19253P	PARTICIPANT	\N	PRESENT	0
255074	254772	01024M	PARTICIPANT	\N	PRESENT	0
255075	254772	04038G	PARTICIPANT	\N	PRESENT	0
255076	254772	19719D	PARTICIPANT	\N	PRESENT	0
255077	254772	11033F	PARTICIPANT	\N	PRESENT	0
255078	254772	19725B	PARTICIPANT	\N	PRESENT	0
255079	254772	95063L	PARTICIPANT	\N	PRESENT	0
255080	254772	19629C	PARTICIPANT	\N	PRESENT	0
255081	254772	08044W	PARTICIPANT	\N	PRESENT	0
255082	254772	14069U	PARTICIPANT	\N	PRESENT	0
255083	254772	11049P	PARTICIPANT	\N	PRESENT	0
255084	254772	14021P	PARTICIPANT	\N	PRESENT	0
255085	254772	14089Y	PARTICIPANT	\N	PRESENT	0
255086	254772	19729F	PARTICIPANT	\N	PRESENT	0
255087	254772	14111D	PARTICIPANT	\N	PRESENT	0
255088	254772	19581D	PARTICIPANT	\N	EXCUSE	0
255089	254772	11085T	PARTICIPANT	\N	EXCUSE	0
255094	251926	19443T	PARTICIPANT	\N	PRESENT	0
255095	251926	95030B	PARTICIPANT	\N	PRESENT	0
255096	251926	19533U	PARTICIPANT	\N	PRESENT	0
255097	251926	16685X	PARTICIPANT	\N	PRESENT	0
255098	251926	11027H	PARTICIPANT	\N	PRESENT	0
255099	251926	11054L	PARTICIPANT	\N	PRESENT	0
255100	251926	11066Q	PARTICIPANT	\N	PRESENT	0
255101	251926	08056B	PARTICIPANT	\N	PRESENT	0
255102	251926	11115U	PARTICIPANT	\N	PRESENT	0
255103	251926	19573D	PARTICIPANT	\N	PRESENT	0
245199	245198	19415P	PARTICIPANT	\N	PRESENT	0
245200	245198	11097X	PARTICIPANT	\N	PRESENT	0
245201	245198	19727D	PARTICIPANT	\N	PRESENT	0
245202	245198	14071N	PARTICIPANT	\N	PRESENT	0
245616	245613	19575F	PARTICIPANT	\N	PRESENT	0
245618	245613	14083S	PARTICIPANT	\N	PRESENT	0
245619	245613	14038Y	PARTICIPANT	\N	PRESENT	0
245620	245613	80013X	PARTICIPANT	\N	PRESENT	0
245621	245613	14357A	PARTICIPANT	\N	PRESENT	0
245622	245613	11065P	PARTICIPANT	\N	PRESENT	0
245623	245613	01024M	PARTICIPANT	\N	PRESENT	0
245624	245613	08018U	PARTICIPANT	\N	PRESENT	0
245625	245613	14033T	PARTICIPANT	\N	PRESENT	0
245626	245613	19333N	PARTICIPANT	\N	PRESENT	0
245627	245613	04097T	PARTICIPANT	\N	PRESENT	0
245628	245613	11048N	PARTICIPANT	\N	PRESENT	0
245629	245613	19551W	PARTICIPANT	\N	PRESENT	0
245630	245613	04049K	PARTICIPANT	\N	PRESENT	0
245631	245613	14219Q	PARTICIPANT	\N	PRESENT	0
245632	245613	14257W	PARTICIPANT	\N	PRESENT	0
245633	245613	92040Q	PARTICIPANT	\N	PRESENT	0
245634	245613	19533U	PARTICIPANT	\N	PRESENT	0
245635	245613	04088S	PARTICIPANT	\N	PRESENT	0
245636	245613	98050T	PARTICIPANT	\N	PRESENT	0
245637	245613	01058X	PARTICIPANT	\N	PRESENT	0
245638	245613	14051J	PARTICIPANT	\N	PRESENT	0
245639	245613	95067Q	PARTICIPANT	\N	PRESENT	0
250853	250224	11045K	PARTICIPANT	\N	PRESENT	0
250854	250224	08052W	PARTICIPANT	\N	PRESENT	0
250855	250224	19663E	PARTICIPANT	\N	PRESENT	0
250856	250224	19715Y	PARTICIPANT	\N	PRESENT	0
250857	250224	19691J	PARTICIPANT	\N	PRESENT	0
250858	250224	19717B	PARTICIPANT	\N	PRESENT	0
250859	250224	19723Y	PARTICIPANT	\N	PRESENT	0
250860	250224	19727D	PARTICIPANT	\N	PRESENT	0
250861	250224	14119M	PARTICIPANT	\N	PRESENT	0
250862	250224	11103C	PARTICIPANT	\N	PRESENT	0
250863	250224	19657G	PARTICIPANT	\N	PRESENT	0
250864	250224	14071N	PARTICIPANT	\N	PRESENT	0
250865	250224	08048B	PARTICIPANT	\N	EXCUSE	0
250866	250604	19573D	PARTICIPANT	\N	PRESENT	0
250868	250518	95015C	PARTICIPANT	\N	PRESENT	0
250869	250518	14073Q	PARTICIPANT	\N	PRESENT	0
250870	250518	87003B	PARTICIPANT	\N	PRESENT	0
250871	250518	04059M	PARTICIPANT	\N	PRESENT	0
250872	250518	14231L	PARTICIPANT	\N	PRESENT	0
250873	250518	08039A	PARTICIPANT	\N	PRESENT	0
250887	250604	14107H	PARTICIPANT	\N	PRESENT	0
250888	250604	11043H	PARTICIPANT	\N	PRESENT	0
250889	250518	11043H	PARTICIPANT	\N	PRESENT	0
250890	250518	11109J	PARTICIPANT	\N	PRESENT	0
251190	250072	95030B	PARTICIPANT	\N	PRESENT	0
262899	255917	02002K	PARTICIPANT	\N	PRESENT	0
258912	258911	89017R	PARTICIPANT	\N	PRESENT	0
262898	255917	08024S	PARTICIPANT	\N	PRESENT	0
251194	250072	16685X	PARTICIPANT	\N	PRESENT	0
251196	250072	04040A	PARTICIPANT	\N	PRESENT	0
262900	255917	19349W	PARTICIPANT	\N	EXCUSE	0
262901	255917	17637T	PARTICIPANT	\N	EXCUSE	0
263193	261490	95037J	PARTICIPANT	\N	PRESENT	0
251200	250529	19697Q	PARTICIPANT	\N	PRESENT	0
251201	250529	11067R	PARTICIPANT	\N	PRESENT	0
251202	250529	14355X	PARTICIPANT	\N	PRESENT	0
251203	250529	19569H	PARTICIPANT	\N	PRESENT	0
251204	250529	11097X	PARTICIPANT	\N	PRESENT	0
251205	250529	19415P	PARTICIPANT	\N	PRESENT	0
251206	250529	04045F	PARTICIPANT	\N	PRESENT	0
251207	250529	14223L	PARTICIPANT	\N	PRESENT	0
251208	250529	17779H	PARTICIPANT	\N	PRESENT	0
251209	250529	14239U	PARTICIPANT	\N	PRESENT	0
251210	250529	19553Y	PARTICIPANT	\N	PRESENT	0
251211	250529	11031D	PARTICIPANT	\N	PRESENT	0
251212	250529	19703U	PARTICIPANT	\N	PRESENT	0
251213	250529	14281W	PARTICIPANT	\N	PRESENT	0
251214	250529	19679N	PARTICIPANT	\N	PRESENT	0
251215	250529	14042U	PARTICIPANT	\N	PRESENT	0
251216	250529	14195A	PARTICIPANT	\N	PRESENT	0
251217	250529	19367Y	PARTICIPANT	\N	PRESENT	0
251218	250529	14213J	PARTICIPANT	\N	PRESENT	0
251219	250529	19335Q	PARTICIPANT	\N	PRESENT	0
251220	250529	14217N	PARTICIPANT	\N	PRESENT	0
251221	250529	19683J	PARTICIPANT	\N	PRESENT	0
251222	250529	10006L	PARTICIPANT	\N	PRESENT	0
251223	250529	19521Q	PARTICIPANT	\N	PRESENT	0
251224	250529	19527W	PARTICIPANT	\N	PRESENT	0
251225	250529	01034P	PARTICIPANT	\N	PRESENT	0
251226	250529	04092N	PRESIDENT	0	PRESENT	0
251227	250529	08052W	PARTICIPANT	\N	PRESENT	0
251228	250529	19723Y	PARTICIPANT	\N	PRESENT	0
251229	250529	19727D	PARTICIPANT	\N	PRESENT	0
251230	250529	14119M	PARTICIPANT	\N	PRESENT	0
251231	250529	11103C	PARTICIPANT	\N	PRESENT	0
251232	250529	19657G	PARTICIPANT	\N	PRESENT	0
251233	250529	19577H	PARTICIPANT	\N	PRESENT	0
251234	250529	08048B	PARTICIPANT	\N	EXCUSE	0
263194	261490	11066Q	PARTICIPANT	\N	PRESENT	0
263195	261490	14223L	PARTICIPANT	\N	PRESENT	0
263196	261490	11067R	PARTICIPANT	\N	PRESENT	0
263197	261490	19573D	PARTICIPANT	\N	PRESENT	0
263198	261490	14227Q	PARTICIPANT	\N	PRESENT	0
263199	261490	08052W	PARTICIPANT	\N	PRESENT	0
263200	261490	19631V	PARTICIPANT	\N	PRESENT	0
263201	261490	14097Y	PARTICIPANT	\N	PRESENT	0
263202	261490	11090Q	PARTICIPANT	\N	PRESENT	0
263203	261490	14073Q	PARTICIPANT	\N	PRESENT	0
263204	261490	19739H	PARTICIPANT	\N	PRESENT	0
263205	261490	14211G	PARTICIPANT	\N	PRESENT	0
263206	261490	14179A	PARTICIPANT	\N	PRESENT	0
263207	261490	14103D	PARTICIPANT	\N	PRESENT	0
263208	261490	17589D	PARTICIPANT	\N	PRESENT	0
263209	261490	19563B	PARTICIPANT	\N	PRESENT	0
263210	261490	19719D	PARTICIPANT	\N	PRESENT	0
263211	261490	14081Q	PARTICIPANT	\N	PRESENT	0
263212	261490	19599P	PARTICIPANT	\N	PRESENT	0
263213	261490	95041E	PARTICIPANT	\N	PRESENT	0
263214	261490	11041F	PARTICIPANT	\N	PRESENT	0
263221	261490	14039A	PARTICIPANT	\N	PRESENT	0
263216	261490	04045F	PARTICIPANT	\N	PRESENT	0
263217	261490	14169X	PARTICIPANT	\N	PRESENT	0
263222	261490	07034Q	PARTICIPANT	\N	PRESENT	0
263223	261490	19683J	PARTICIPANT	\N	PRESENT	0
263224	261490	17583W	PARTICIPANT	\N	PRESENT	0
263225	261490	19251M	PARTICIPANT	\N	PRESENT	0
263226	261490	19533U	PARTICIPANT	\N	PRESENT	0
263227	261490	11103C	PARTICIPANT	\N	PRESENT	0
263228	261490	14207L	PARTICIPANT	\N	PRESENT	0
263229	261490	19301E	PARTICIPANT	\N	PRESENT	0
263230	261490	14107H	PARTICIPANT	\N	PRESENT	0
263231	261490	14111D	PARTICIPANT	\N	PRESENT	0
263232	261490	11064N	PARTICIPANT	\N	PRESENT	0
263233	261490	04034C	PARTICIPANT	\N	PRESENT	0
263234	261490	08010L	PARTICIPANT	\N	PRESENT	0
263236	261490	04097T	PARTICIPANT	\N	PRESENT	0
263238	261490	14235Q	PARTICIPANT	\N	PRESENT	0
263239	261490	95062K	PARTICIPANT	\N	PRESENT	0
263240	261490	11056N	PARTICIPANT	\N	PRESENT	0
263241	261490	11080N	PARTICIPANT	\N	PRESENT	0
263242	261490	19515S	PARTICIPANT	\N	PRESENT	0
263243	261490	19593H	PARTICIPANT	\N	PRESENT	0
263244	261490	19503N	PARTICIPANT	\N	PRESENT	0
263245	261490	80013X	PARTICIPANT	\N	PRESENT	0
263246	261490	98024R	PARTICIPANT	\N	PRESENT	0
251390	250529	98024R	PARTICIPANT	\N	PRESENT	0
251391	250529	14071N	PARTICIPANT	\N	PRESENT	0
251394	250562	14327T	PARTICIPANT	\N	PRESENT	0
251395	250562	04071H	PARTICIPANT	\N	PRESENT	0
251396	250562	01057W	PARTICIPANT	\N	PRESENT	0
251397	250562	11074Q	PRESIDENT	0	PRESENT	0
251398	250562	89017R	PARTICIPANT	\N	PRESENT	0
251399	250562	11070L	PARTICIPANT	\N	PRESENT	0
251400	250562	14225N	PARTICIPANT	\N	PRESENT	0
251401	250562	19671E	PARTICIPANT	\N	PRESENT	0
263248	261490	19525U	PARTICIPANT	\N	PRESENT	0
251403	250562	19349W	PARTICIPANT	\N	PRESENT	0
251404	250562	19479G	PARTICIPANT	\N	PRESENT	0
251405	250562	11048N	PARTICIPANT	\N	PRESENT	0
251406	250562	19711U	PARTICIPANT	\N	PRESENT	0
251407	250562	19651A	PARTICIPANT	\N	PRESENT	0
251408	250562	19531S	PARTICIPANT	\N	PRESENT	0
251409	250562	19687N	PARTICIPANT	\N	PRESENT	0
251410	250562	19689Q	PARTICIPANT	\N	PRESENT	0
251411	250562	12016W	PARTICIPANT	\N	PRESENT	0
251412	250562	08011M	PARTICIPANT	\N	PRESENT	0
251413	250562	08014Q	PARTICIPANT	\N	PRESENT	0
251414	250562	14083S	PARTICIPANT	\N	PRESENT	0
251415	250562	14199E	PARTICIPANT	\N	PRESENT	0
251416	250562	19741B	PARTICIPANT	\N	PRESENT	0
251417	250562	14121F	PARTICIPANT	\N	PRESENT	0
251418	250562	99004R	PARTICIPANT	\N	PRESENT	0
261066	261000	14169X	PARTICIPANT	\N	PRESENT	0
261067	261000	14265W	PARTICIPANT	\N	PRESENT	0
261068	261000	14079W	PARTICIPANT	\N	PRESENT	0
261070	261000	19563B	PARTICIPANT	\N	PRESENT	0
261071	261000	19713W	PARTICIPANT	\N	PRESENT	0
261072	261000	19483C	PARTICIPANT	\N	PRESENT	0
261073	261000	95030B	PARTICIPANT	\N	PRESENT	0
261074	261000	11067R	PARTICIPANT	\N	PRESENT	0
261075	261000	11048N	PARTICIPANT	\N	PRESENT	0
261076	261000	04086Q	PARTICIPANT	\N	PRESENT	0
261078	261000	04043D	PARTICIPANT	\N	PRESENT	0
261079	261000	19565D	PARTICIPANT	\N	PRESENT	0
261080	261000	19543W	PARTICIPANT	\N	PRESENT	0
261089	261000	14089Y	PARTICIPANT	\N	PRESENT	0
261090	261000	11085T	PARTICIPANT	\N	PRESENT	0
261093	261000	98050T	PARTICIPANT	\N	PRESENT	0
261111	261000	19649G	PARTICIPANT	\N	PRESENT	0
261121	261000	08052W	PARTICIPANT	\N	PRESENT	0
261192	261001	19593H	PARTICIPANT	\N	PRESENT	0
261193	261001	19551W	PARTICIPANT	\N	PRESENT	0
261194	261001	08055A	PARTICIPANT	\N	PRESENT	0
261195	261001	14197C	PARTICIPANT	\N	PRESENT	0
261196	261001	19637C	PARTICIPANT	\N	PRESENT	0
261197	261001	14219Q	PARTICIPANT	\N	PRESENT	0
261198	261001	08009T	PARTICIPANT	\N	PRESENT	0
261199	261001	11012A	PARTICIPANT	\N	PRESENT	0
261200	261001	19671E	PARTICIPANT	\N	PRESENT	0
261201	261001	04018C	PARTICIPANT	\N	PRESENT	0
261202	261001	19701S	PARTICIPANT	\N	PRESENT	0
261203	261001	19731Y	PARTICIPANT	\N	PRESENT	0
261204	261001	98023Q	PARTICIPANT	\N	PRESENT	0
261205	261001	99004R	PARTICIPANT	\N	PRESENT	0
261206	261001	19711U	PARTICIPANT	\N	PRESENT	0
261207	261001	19399H	PARTICIPANT	\N	PRESENT	0
261208	261001	08019V	PARTICIPANT	\N	PRESENT	0
261209	261001	07029T	PARTICIPANT	\N	PRESENT	0
261210	261001	04088S	PARTICIPANT	\N	PRESENT	0
261211	261001	08034U	PARTICIPANT	\N	PRESENT	0
261212	261001	18083K	PARTICIPANT	\N	PRESENT	0
261213	261001	14038Y	PARTICIPANT	\N	PRESENT	0
261214	261001	08052W	PARTICIPANT	\N	PRESENT	0
261215	261001	14093U	PARTICIPANT	\N	PRESENT	0
261218	261001	19741B	PARTICIPANT	\N	PRESENT	0
261219	261001	19709B	PARTICIPANT	\N	PRESENT	0
261220	261001	98050T	PARTICIPANT	\N	PRESENT	0
261221	261001	95030B	PARTICIPANT	\N	PRESENT	0
261222	261001	19713W	PARTICIPANT	\N	PRESENT	0
261223	261001	19749K	PARTICIPANT	\N	PRESENT	0
261224	261001	19747H	PARTICIPANT	\N	PRESENT	0
261225	261001	11048N	PARTICIPANT	\N	PRESENT	0
261226	261001	19503N	PARTICIPANT	\N	PRESENT	0
261227	261001	08024S	PARTICIPANT	\N	PRESENT	0
261228	261001	19549D	PARTICIPANT	\N	PRESENT	0
261229	261001	14265W	PARTICIPANT	\N	PRESENT	0
261230	261001	19569H	PARTICIPANT	\N	PRESENT	0
261231	261001	19681G	PARTICIPANT	\N	PRESENT	0
261232	261001	14251Q	PARTICIPANT	\N	PRESENT	0
261233	261001	19691J	PARTICIPANT	\N	PRESENT	0
261235	261001	01048V	PARTICIPANT	\N	PRESENT	0
261236	261001	17637T	PARTICIPANT	\N	PRESENT	0
261241	261001	19697Q	PARTICIPANT	\N	PRESENT	0
261244	261001	11010L	PARTICIPANT	\N	PRESENT	0
261245	261001	14030Q	PARTICIPANT	\N	PRESENT	0
261246	261001	04059M	PARTICIPANT	\N	PRESENT	0
261285	261001	14179A	PARTICIPANT	\N	PRESENT	0
261289	261001	19611R	PARTICIPANT	\N	PRESENT	0
261300	261001	19483C	PARTICIPANT	\N	PRESENT	0
261310	261001	14083S	PARTICIPANT	\N	PRESENT	0
261351	258913	14299H	PARTICIPANT	\N	PRESENT	0
261352	258913	19709B	PARTICIPANT	\N	PRESENT	0
261178	261001	11070L	PARTICIPANT	\N	PRESENT	0
261191	261001	19347U	PARTICIPANT	\N	PRESENT	0
261354	258914	14299H	PARTICIPANT	\N	PRESENT	0
261355	258914	19709B	PARTICIPANT	\N	PRESENT	0
261357	258915	14299H	PARTICIPANT	\N	PRESENT	0
261358	258915	19709B	PARTICIPANT	\N	PRESENT	0
261359	258916	19709B	PARTICIPANT	\N	PRESENT	0
261361	258917	14299H	PARTICIPANT	\N	PRESENT	0
261363	258918	14299H	PARTICIPANT	\N	PRESENT	0
261442	261177	11048N	PARTICIPANT	\N	PRESENT	0
261443	261177	19479G	PARTICIPANT	\N	PRESENT	0
261444	261177	19647E	PARTICIPANT	\N	PRESENT	0
261445	261177	19711U	PARTICIPANT	\N	PRESENT	0
261446	261177	08034U	PARTICIPANT	\N	PRESENT	0
261447	261177	19651A	PARTICIPANT	\N	PRESENT	0
261448	261177	01057W	PARTICIPANT	\N	PRESENT	0
261449	261177	11053K	PARTICIPANT	\N	PRESENT	0
261450	261177	11074Q	PRESIDENT	0	PRESENT	0
261451	261177	08011M	PARTICIPANT	\N	PRESENT	0
261452	261177	14034U	PARTICIPANT	\N	PRESENT	0
261453	261177	19671E	PARTICIPANT	\N	PRESENT	0
261454	261177	14225N	PARTICIPANT	\N	PRESENT	0
261455	261177	14159V	PARTICIPANT	\N	PRESENT	0
261456	261177	11110B	PARTICIPANT	\N	PRESENT	0
261457	261177	14173T	PARTICIPANT	\N	PRESENT	0
261458	261177	04086Q	PARTICIPANT	\N	PRESENT	0
261459	261177	14089Y	RAPPORTEUR_AVIS	\N	PRESENT	0
261460	261177	14083S	PARTICIPANT	\N	PRESENT	0
261461	261177	08010L	PARTICIPANT	\N	PRESENT	0
261462	261177	19741B	PARTICIPANT	\N	PRESENT	0
261463	261177	14253S	PARTICIPANT	\N	PRESENT	0
261464	261177	04061F	PARTICIPANT	\N	PRESENT	0
261465	261177	14085U	PARTICIPANT	\N	PRESENT	0
261466	261177	99004R	PARTICIPANT	\N	PRESENT	0
261467	261177	11040E	PARTICIPANT	\N	EXCUSE	0
261468	261177	14327T	PARTICIPANT	\N	EXCUSE	0
261469	261177	07029T	PARTICIPANT	\N	EXCUSE	0
261470	261177	14121F	PARTICIPANT	\N	EXCUSE	0
261471	261177	89017R	PARTICIPANT	\N	EXCUSE	0
261473	261472	14255U	PARTICIPANT	\N	PRESENT	0
261474	261472	14281W	PARTICIPANT	\N	PRESENT	0
261475	261472	19521Q	PARTICIPANT	\N	PRESENT	0
261476	261472	19731Y	PARTICIPANT	\N	PRESENT	0
261477	261472	14073Q	PARTICIPANT	\N	PRESENT	0
261478	261472	08017T	PARTICIPANT	\N	PRESENT	0
261479	261472	19637C	PARTICIPANT	\N	PRESENT	0
261480	261472	19533U	PARTICIPANT	\N	PRESENT	0
261481	261472	04088S	PARTICIPANT	\N	PRESENT	0
261482	261472	11043H	PARTICIPANT	\N	PRESENT	0
261483	261472	01034P	PARTICIPANT	\N	PRESENT	0
262004	262003	01043Q	PARTICIPANT	\N	PRESENT	0
262097	261091	19443T	PARTICIPANT	\N	PRESENT	0
262098	261091	95030B	PARTICIPANT	\N	PRESENT	0
262099	261091	04034C	PARTICIPANT	\N	PRESENT	0
262100	261091	04040A	PARTICIPANT	\N	PRESENT	0
262101	261091	16685X	PARTICIPANT	\N	PRESENT	0
262102	261091	04042C	PRESIDENT	0	PRESENT	0
262103	261091	11054L	PARTICIPANT	\N	PRESENT	0
262104	261091	11066Q	PARTICIPANT	\N	PRESENT	0
262105	261091	08056B	PARTICIPANT	\N	PRESENT	0
262106	261091	95037J	PARTICIPANT	\N	PRESENT	0
262107	261091	14193X	PARTICIPANT	\N	PRESENT	0
262108	261091	97011G	PARTICIPANT	\N	PRESENT	0
262109	261091	08047A	PARTICIPANT	\N	PRESENT	0
262110	261091	14097Y	PARTICIPANT	\N	PRESENT	0
262111	261091	08034U	PARTICIPANT	\N	PRESENT	0
262112	261091	01062T	PARTICIPANT	\N	PRESENT	0
262113	261091	11041F	PARTICIPANT	\N	PRESENT	0
262114	261091	14235Q	PARTICIPANT	\N	PRESENT	0
262115	261091	08058D	PARTICIPANT	\N	PRESENT	0
262116	261091	19721W	PARTICIPANT	\N	PRESENT	0
262117	261091	19319Q	PARTICIPANT	\N	PRESENT	0
262118	261091	14105F	PARTICIPANT	\N	PRESENT	0
262119	261091	98018T	PARTICIPANT	\N	PRESENT	0
262120	261091	98022P	PARTICIPANT	\N	PRESENT	0
262121	261091	14267Y	PARTICIPANT	\N	PRESENT	0
262122	261091	11064N	PARTICIPANT	\N	PRESENT	0
262123	261091	98050T	PARTICIPANT	\N	PRESENT	0
262124	261091	14211G	PARTICIPANT	\N	PRESENT	0
262125	261091	08061X	PARTICIPANT	\N	PRESENT	0
262126	261091	19251M	PARTICIPANT	\N	PRESENT	0
262127	261091	19421M	PARTICIPANT	\N	PRESENT	0
262128	261091	14079W	PARTICIPANT	\N	PRESENT	0
262129	261091	98029W	PARTICIPANT	\N	PRESENT	0
262130	261091	11027H	PARTICIPANT	\N	PRESENT	0
262131	255917	19569H	PARTICIPANT	\N	PRESENT	0
262132	255917	19515S	PARTICIPANT	\N	PRESENT	0
262133	255917	19551W	PARTICIPANT	\N	PRESENT	0
262134	255917	19479G	PARTICIPANT	\N	PRESENT	0
262138	260576	11067R	PARTICIPANT	\N	PRESENT	0
262139	260576	19569H	PARTICIPANT	\N	PRESENT	0
244242	244241	14115H	PARTICIPANT	\N	PRESENT	0
244244	244243	14115H	PARTICIPANT	\N	PRESENT	0
244246	244245	08068F	PARTICIPANT	\N	PRESENT	0
244247	244245	19681G	PARTICIPANT	\N	PRESENT	0
244248	244245	08028W	PARTICIPANT	\N	PRESENT	0
244249	244245	01043Q	PARTICIPANT	\N	PRESENT	0
244251	244250	08028W	PARTICIPANT	\N	PRESENT	0
244252	244250	08068F	PARTICIPANT	\N	PRESENT	0
244253	244250	19681G	PARTICIPANT	\N	PRESENT	0
244254	244250	01043Q	PARTICIPANT	\N	PRESENT	0
244255	244250	14257W	PARTICIPANT	\N	PRESENT	0
244257	244256	14237S	PARTICIPANT	\N	PRESENT	0
244258	244256	19737F	PARTICIPANT	\N	PRESENT	0
244259	244256	14065Q	PARTICIPANT	\N	PRESENT	0
244260	244256	04061F	PARTICIPANT	\N	PRESENT	0
244261	244256	08068F	PARTICIPANT	\N	PRESENT	0
246269	246268	14030Q	PRESIDENT	0	PRESENT	0
246270	246268	19643A	PARTICIPANT	\N	PRESENT	0
246271	246268	08020N	PARTICIPANT	\N	PRESENT	0
246272	246268	18083K	PARTICIPANT	\N	PRESENT	0
246273	246268	19701S	PARTICIPANT	\N	PRESENT	0
246274	246268	80013X	PARTICIPANT	\N	PRESENT	0
246275	246268	14217N	PARTICIPANT	\N	PRESENT	0
246276	246268	19715Y	PARTICIPANT	\N	PRESENT	0
246277	246268	19731Y	PARTICIPANT	\N	PRESENT	0
246278	246268	08031R	PARTICIPANT	\N	PRESENT	0
246279	246268	08017T	PARTICIPANT	\N	PRESENT	0
246280	246268	19657G	PARTICIPANT	\N	PRESENT	0
246281	246268	14235Q	PARTICIPANT	\N	PRESENT	0
246282	246268	19749K	PARTICIPANT	\N	PRESENT	0
246283	246268	08043V	PARTICIPANT	\N	EXCUSE	0
246284	246268	19693L	PARTICIPANT	\N	EXCUSE	0
246285	246268	19599P	PARTICIPANT	\N	EXCUSE	0
246286	246268	07029T	PARTICIPANT	\N	EXCUSE	0
246287	246268	08019V	PARTICIPANT	\N	PRESENT	0
246288	246268	11072N	PARTICIPANT	\N	PRESENT	0
246289	246268	19301E	PARTICIPANT	\N	PRESENT	0
246290	246268	19729F	PARTICIPANT	\N	PRESENT	0
246291	246268	19319Q	PARTICIPANT	\N	PRESENT	0
246292	246268	14261S	PARTICIPANT	\N	PRESENT	0
246293	246268	14059S	PARTICIPANT	\N	PRESENT	0
246294	246268	95062K	PARTICIPANT	\N	PRESENT	0
247049	240294	19479G	PARTICIPANT	\N	PRESENT	0
247050	240294	19611R	PARTICIPANT	\N	PRESENT	0
247051	240294	19629C	PARTICIPANT	\N	PRESENT	0
247052	240294	19503N	PARTICIPANT	\N	PRESENT	0
247053	240294	08014Q	PARTICIPANT	\N	PRESENT	0
247054	240294	19631V	PARTICIPANT	\N	PRESENT	0
247055	240294	19711U	PARTICIPANT	\N	PRESENT	0
247056	240294	19507S	PARTICIPANT	\N	PRESENT	0
247057	240294	14034U	PARTICIPANT	\N	PRESENT	0
247058	240294	11012A	PARTICIPANT	\N	PRESENT	0
247059	240294	14030Q	PARTICIPANT	\N	PRESENT	0
247064	240294	14021P	PARTICIPANT	\N	PRESENT	0
247065	240294	14085U	PARTICIPANT	\N	PRESENT	0
247066	240294	08052W	PARTICIPANT	\N	PRESENT	0
247067	240294	01028R	PARTICIPANT	\N	PRESENT	0
247205	242655	11097X	PARTICIPANT	\N	PRESENT	0
247206	242645	19727D	PARTICIPANT	\N	PRESENT	0
247207	242645	11097X	PARTICIPANT	\N	PRESENT	0
247237	247236	04092N	PARTICIPANT	\N	PRESENT	0
247238	247236	14071N	PARTICIPANT	\N	PRESENT	0
247706	247639	14097Y	PARTICIPANT	\N	EXCUSE	0
247949	247639	14001X	PARTICIPANT	\N	EXCUSE	0
248687	247639	96004D	PRESIDENT	0	PRESENT	0
248688	247639	14089Y	PARTICIPANT	\N	PRESENT	0
248690	247639	14065Q	PARTICIPANT	\N	PRESENT	0
248691	247639	08014Q	PARTICIPANT	\N	PRESENT	0
248693	247639	14079W	PARTICIPANT	\N	PRESENT	0
248694	247639	14249W	PARTICIPANT	\N	PRESENT	0
248696	247639	11083R	PARTICIPANT	\N	PRESENT	0
248697	247639	14033T	PARTICIPANT	\N	PRESENT	0
248698	247639	19725B	PARTICIPANT	\N	PRESENT	0
248699	247639	04097T	PARTICIPANT	\N	PRESENT	0
248700	247639	08044W	PARTICIPANT	\N	PRESENT	0
248701	247639	14061L	PARTICIPANT	\N	PRESENT	0
248702	247639	14073Q	PARTICIPANT	\N	PRESENT	0
248703	247639	08039A	PARTICIPANT	\N	PRESENT	0
248704	247639	14221J	PARTICIPANT	\N	PRESENT	0
248705	247639	04057K	PARTICIPANT	\N	PRESENT	0
248706	247639	14237S	PARTICIPANT	\N	PRESENT	0
248707	247639	14135M	PARTICIPANT	\N	PRESENT	0
248708	247639	14331P	PARTICIPANT	\N	PRESENT	0
248709	247639	14225N	PARTICIPANT	\N	PRESENT	0
248710	247639	10015M	PARTICIPANT	\N	PRESENT	0
248711	247639	14229S	PARTICIPANT	\N	PRESENT	0
248712	247639	98035U	PARTICIPANT	\N	PRESENT	0
249804	249803	01062T	PARTICIPANT	\N	PRESENT	0
249805	249803	04040A	PARTICIPANT	\N	PRESENT	0
249806	249803	14097Y	PARTICIPANT	\N	PRESENT	0
249807	249803	19421M	PARTICIPANT	\N	PRESENT	0
249808	249803	04035D	PARTICIPANT	\N	PRESENT	0
249810	249809	01062T	PARTICIPANT	\N	PRESENT	0
249811	249809	04040A	PARTICIPANT	\N	PRESENT	0
249812	249809	19421M	PARTICIPANT	\N	PRESENT	0
250162	250161	11054L	PARTICIPANT	\N	PRESENT	0
250163	250161	14281W	PARTICIPANT	\N	PRESENT	0
250164	250161	19591F	PARTICIPANT	\N	PRESENT	0
251105	251104	14239U	PARTICIPANT	\N	PRESENT	0
251106	251104	19647E	PARTICIPANT	\N	PRESENT	0
251107	251104	07004J	PARTICIPANT	\N	PRESENT	0
253009	253008	14193X	PARTICIPANT	\N	PRESENT	0
253010	253008	08053X	PARTICIPANT	\N	PRESENT	0
253011	253008	95067Q	PARTICIPANT	\N	PRESENT	0
253012	253008	14235Q	PARTICIPANT	\N	PRESENT	0
261025	261003	14231L	PARTICIPANT	\N	EXCUSE	0
258826	258032	11109J	PARTICIPANT	\N	PRESENT	0
258827	258032	04059M	PARTICIPANT	\N	PRESENT	0
258828	258032	14030Q	PARTICIPANT	\N	PRESENT	0
258829	258032	08043V	PARTICIPANT	\N	PRESENT	0
258830	258032	19643A	PARTICIPANT	\N	PRESENT	0
258831	258032	19621T	PARTICIPANT	\N	PRESENT	0
261069	261003	11048N	PARTICIPANT	\N	EXCUSE	0
261077	261003	11101A	PARTICIPANT	\N	EXCUSE	0
258835	258032	19693L	PARTICIPANT	\N	PRESENT	0
258836	258032	87003B	PARTICIPANT	\N	PRESENT	0
261182	261181	14051J	PARTICIPANT	\N	PRESENT	0
261216	261003	14281W	PARTICIPANT	\N	EXCUSE	0
258839	258032	11083R	PARTICIPANT	\N	PRESENT	0
261365	261364	08014Q	PARTICIPANT	\N	PRESENT	0
258841	258032	14123H	PARTICIPANT	\N	PRESENT	0
261366	261364	08055A	PARTICIPANT	\N	PRESENT	0
261367	261364	19467C	PARTICIPANT	\N	PRESENT	0
258844	258032	19399H	PARTICIPANT	\N	PRESENT	0
258845	258032	14241N	PARTICIPANT	\N	PRESENT	0
258846	258032	14039A	PARTICIPANT	\N	PRESENT	0
258847	258032	19731Y	PARTICIPANT	\N	PRESENT	0
258848	258032	14061L	PARTICIPANT	\N	EXCUSE	0
258849	258032	14073Q	PARTICIPANT	\N	PRESENT	0
258850	258032	08031R	PARTICIPANT	\N	PRESENT	0
258851	258032	19611R	PARTICIPANT	\N	PRESENT	0
258852	258032	19699S	PARTICIPANT	\N	PRESENT	0
258853	258032	12041X	PARTICIPANT	\N	PRESENT	0
258854	258032	08039A	PARTICIPANT	\N	PRESENT	0
261368	261364	14042U	PARTICIPANT	\N	PRESENT	0
258856	258032	14059S	PARTICIPANT	\N	PRESENT	0
258857	258032	08012N	PARTICIPANT	\N	PRESENT	0
261369	261364	14197C	PARTICIPANT	\N	PRESENT	0
258859	258032	14251Q	PARTICIPANT	\N	PRESENT	0
258860	258032	14063N	PARTICIPANT	\N	PRESENT	0
258861	258032	04057K	PARTICIPANT	\N	PRESENT	0
258862	258032	14109K	PARTICIPANT	\N	PRESENT	0
258863	258032	04070G	PRESIDENT	0	PRESENT	0
261370	261364	19727D	PARTICIPANT	\N	PRESENT	0
258865	258032	19593H	PARTICIPANT	\N	PRESENT	0
258866	258032	19573D	PARTICIPANT	\N	PRESENT	0
258867	258032	19533U	PARTICIPANT	\N	PRESENT	0
261371	261364	14033T	PARTICIPANT	\N	PRESENT	0
261372	261364	16685X	PARTICIPANT	\N	PRESENT	0
258870	258032	14229S	PARTICIPANT	\N	PRESENT	0
258871	258032	14107H	PARTICIPANT	\N	PRESENT	0
258872	258032	11043H	PARTICIPANT	\N	PRESENT	0
258873	258032	04018C	PARTICIPANT	\N	PRESENT	0
258874	258032	19749K	PARTICIPANT	\N	PRESENT	0
261373	261364	14205J	PARTICIPANT	\N	PRESENT	0
261374	261364	19563B	PARTICIPANT	\N	PRESENT	0
261375	261364	14169X	PARTICIPANT	\N	PRESENT	0
261376	261364	19745F	PARTICIPANT	\N	PRESENT	0
261377	261364	19533U	PARTICIPANT	\N	PRESENT	0
261378	261364	98050T	PARTICIPANT	\N	PRESENT	0
261380	261379	14051J	PARTICIPANT	\N	PRESENT	0
261382	261381	14135M	PARTICIPANT	\N	PRESENT	0
261383	261381	19631V	PARTICIPANT	\N	PRESENT	0
261384	261381	14265W	PARTICIPANT	\N	PRESENT	0
261385	261381	14197C	PARTICIPANT	\N	PRESENT	0
263011	263008	14071N	PARTICIPANT	\N	PRESENT	0
255104	251926	19421M	PARTICIPANT	\N	PRESENT	0
255105	251926	08049C	PARTICIPANT	\N	PRESENT	0
255106	251926	08053X	PARTICIPANT	\N	PRESENT	0
255107	251926	97011G	PARTICIPANT	\N	PRESENT	0
255108	251926	08016S	PARTICIPANT	\N	PRESENT	0
255109	251926	08047A	PARTICIPANT	\N	PRESENT	0
255110	251926	98029W	PARTICIPANT	\N	PRESENT	0
255111	251926	14059S	PARTICIPANT	\N	PRESENT	0
255112	251926	19647E	PARTICIPANT	\N	PRESENT	0
255113	251926	04057K	PARTICIPANT	\N	PRESENT	0
255114	251926	14073Q	PARTICIPANT	\N	PRESENT	0
255115	251926	14235Q	PARTICIPANT	\N	PRESENT	0
255116	251926	08058D	PARTICIPANT	\N	PRESENT	0
255117	251926	19693L	PARTICIPANT	\N	PRESENT	0
255118	251926	14201E	PARTICIPANT	\N	PRESENT	0
255119	251926	14105F	PARTICIPANT	\N	PRESENT	0
255120	251926	98018T	PRESIDENT	0	PRESENT	0
255121	251926	14251Q	PARTICIPANT	\N	PRESENT	0
255122	251926	04059M	PARTICIPANT	\N	PRESENT	0
255123	251926	98022P	PARTICIPANT	\N	PRESENT	0
255124	251926	14109K	PARTICIPANT	\N	PRESENT	0
255125	251926	14123H	PARTICIPANT	\N	PRESENT	0
255126	251926	04018C	PARTICIPANT	\N	PRESENT	0
255127	251926	14255U	PARTICIPANT	\N	PRESENT	0
255128	251926	04070G	PARTICIPANT	\N	PRESENT	0
255129	251926	19699S	PARTICIPANT	\N	PRESENT	0
255130	251926	04034C	PARTICIPANT	\N	PRESENT	0
255131	251926	04040A	PARTICIPANT	\N	PRESENT	0
255132	251926	14229S	PARTICIPANT	\N	PRESENT	0
255133	251926	95037J	PARTICIPANT	\N	PRESENT	0
255134	251926	14055N	PARTICIPANT	\N	PRESENT	0
255135	251926	19709B	PARTICIPANT	\N	PRESENT	0
255136	251926	08017T	PARTICIPANT	\N	PRESENT	0
255137	251926	08031R	PARTICIPANT	\N	PRESENT	0
255138	251926	14097Y	PARTICIPANT	\N	PRESENT	0
255139	251926	01062T	PARTICIPANT	\N	PRESENT	0
255140	251926	19251M	PARTICIPANT	\N	PRESENT	0
255141	251926	14028W	PARTICIPANT	\N	PRESENT	0
255142	251926	08043V	PARTICIPANT	\N	PRESENT	0
255143	251926	08020N	PARTICIPANT	\N	PRESENT	0
255144	251926	11083R	PARTICIPANT	\N	PRESENT	0
255145	251926	11043H	PARTICIPANT	\N	PRESENT	0
255146	251926	19583F	PARTICIPANT	\N	PRESENT	0
255147	251926	19621T	PARTICIPANT	\N	PRESENT	0
255148	251926	14267Y	PARTICIPANT	\N	EXCUSE	0
255149	251926	98050T	PARTICIPANT	\N	EXCUSE	0
255150	251926	04042C	PARTICIPANT	\N	EXCUSE	0
255151	254997	19443T	PARTICIPANT	\N	PRESENT	0
255152	254997	19533U	PARTICIPANT	\N	PRESENT	0
255153	254997	95030B	PARTICIPANT	\N	PRESENT	0
255154	254997	11027H	PARTICIPANT	\N	PRESENT	0
255155	254997	16685X	PARTICIPANT	\N	PRESENT	0
255156	254997	11054L	PARTICIPANT	\N	PRESENT	0
255157	254997	11066Q	PARTICIPANT	\N	PRESENT	0
255158	254997	08056B	PARTICIPANT	\N	PRESENT	0
255159	254997	11115U	PARTICIPANT	\N	PRESENT	0
255160	254997	19573D	PARTICIPANT	\N	PRESENT	0
255161	254997	19421M	PARTICIPANT	\N	PRESENT	0
255162	254997	08049C	PARTICIPANT	\N	PRESENT	0
255163	254997	08053X	PARTICIPANT	\N	PRESENT	0
255164	254997	97011G	PARTICIPANT	\N	PRESENT	0
255165	254997	08016S	PARTICIPANT	\N	PRESENT	0
255166	254997	08047A	PARTICIPANT	\N	PRESENT	0
255167	254997	98029W	PARTICIPANT	\N	PRESENT	0
255168	254997	14059S	PARTICIPANT	\N	PRESENT	0
255169	254997	19647E	PARTICIPANT	\N	PRESENT	0
255170	254997	04057K	PARTICIPANT	\N	PRESENT	0
255171	254997	14073Q	PARTICIPANT	\N	PRESENT	0
255172	254997	14235Q	PARTICIPANT	\N	PRESENT	0
255173	254997	08058D	PARTICIPANT	\N	PRESENT	0
255174	254997	19693L	PARTICIPANT	\N	PRESENT	0
255175	254997	14201E	PARTICIPANT	\N	PRESENT	0
255176	254997	14105F	PARTICIPANT	\N	PRESENT	0
255177	254997	14251Q	PARTICIPANT	\N	PRESENT	0
255178	254997	98018T	PARTICIPANT	\N	PRESENT	0
255179	254997	04059M	PARTICIPANT	\N	PRESENT	0
255180	254997	98022P	PARTICIPANT	\N	PRESENT	0
255181	254997	14109K	PARTICIPANT	\N	PRESENT	0
255182	254997	14123H	PARTICIPANT	\N	PRESENT	0
255183	254997	04018C	PARTICIPANT	\N	PRESENT	0
255184	254997	14255U	PARTICIPANT	\N	PRESENT	0
255185	254997	04070G	PRESIDENT	0	PRESENT	0
255186	254997	19699S	PARTICIPANT	\N	PRESENT	0
255187	254997	04034C	PARTICIPANT	\N	PRESENT	0
255188	254997	04040A	PARTICIPANT	\N	PRESENT	0
255189	254997	14229S	PARTICIPANT	\N	PRESENT	0
255190	254997	95037J	PARTICIPANT	\N	PRESENT	0
255191	254997	14055N	PARTICIPANT	\N	PRESENT	0
255192	254997	19709B	PARTICIPANT	\N	PRESENT	0
255193	254997	08017T	PARTICIPANT	\N	PRESENT	0
255194	254997	08031R	PARTICIPANT	\N	PRESENT	0
255195	254997	14097Y	PARTICIPANT	\N	PRESENT	0
255196	254997	01062T	PARTICIPANT	\N	PRESENT	0
255197	254997	14028W	PARTICIPANT	\N	PRESENT	0
255198	254997	19251M	PARTICIPANT	\N	PRESENT	0
255199	254997	08043V	PARTICIPANT	\N	PRESENT	0
255200	254997	08020N	PARTICIPANT	\N	PRESENT	0
255201	254997	11083R	PARTICIPANT	\N	PRESENT	0
255202	254997	11043H	PARTICIPANT	\N	PRESENT	0
255203	254997	19583F	PARTICIPANT	\N	PRESENT	0
255204	254997	19621T	PARTICIPANT	\N	PRESENT	0
255205	254997	19611R	PARTICIPANT	\N	EXCUSE	0
255206	254997	14030Q	PARTICIPANT	\N	EXCUSE	0
255207	251926	14249W	PARTICIPANT	\N	PRESENT	0
255208	254997	14063N	PARTICIPANT	\N	PRESENT	0
255209	254997	14107H	PARTICIPANT	\N	PRESENT	0
255210	254997	08012N	PARTICIPANT	\N	PRESENT	0
255211	254997	14249W	PARTICIPANT	\N	PRESENT	0
255212	251926	14063N	PARTICIPANT	\N	PRESENT	0
255213	251926	14107H	PARTICIPANT	\N	PRESENT	0
255214	251926	08012N	PARTICIPANT	\N	PRESENT	0
255215	251926	19735D	PARTICIPANT	\N	PRESENT	0
255216	251926	08035V	PARTICIPANT	\N	PRESENT	0
255217	251799	14179A	PARTICIPANT	\N	PRESENT	0
255218	251926	19749K	PARTICIPANT	\N	PRESENT	0
255302	240319	04086Q	PARTICIPANT	\N	PRESENT	0
255303	240319	14026U	PARTICIPANT	\N	PRESENT	0
255304	240319	14331P	PARTICIPANT	\N	PRESENT	0
255305	240319	19525U	PARTICIPANT	\N	PRESENT	0
255315	240319	08017T	PARTICIPANT	\N	PRESENT	0
255316	240319	95062K	PARTICIPANT	\N	PRESENT	0
255317	240319	04038G	PARTICIPANT	\N	PRESENT	0
255318	240319	15447F	PARTICIPANT	\N	PRESENT	0
255319	240319	19533U	PARTICIPANT	\N	PRESENT	0
255320	240319	11067R	PARTICIPANT	\N	PRESENT	0
255321	240319	19503N	PARTICIPANT	\N	PRESENT	0
255322	240319	19515S	PARTICIPANT	\N	PRESENT	0
255323	240319	08028W	PARTICIPANT	\N	PRESENT	0
255324	240319	14103D	PARTICIPANT	\N	PRESENT	0
255325	240319	19711U	PARTICIPANT	\N	PRESENT	0
255326	240319	19749K	PARTICIPANT	\N	PRESENT	0
255327	240319	99004R	PARTICIPANT	\N	PRESENT	0
255328	240319	14235Q	PARTICIPANT	\N	PRESENT	0
255329	240319	04088S	PARTICIPANT	\N	PRESENT	0
255330	240319	14151M	PARTICIPANT	\N	PRESENT	0
255331	240319	19333N	PARTICIPANT	\N	PRESENT	0
255332	240319	11040E	PARTICIPANT	\N	PRESENT	0
255333	240319	01025N	PARTICIPANT	\N	PRESENT	0
255334	240319	19719D	PARTICIPANT	\N	PRESENT	0
255335	240319	19697Q	PARTICIPANT	\N	PRESENT	0
255336	240319	19651A	PARTICIPANT	\N	PRESENT	0
255337	240319	14029X	PARTICIPANT	\N	PRESENT	0
255338	240319	14033T	PARTICIPANT	\N	PRESENT	0
255339	240319	19467C	PARTICIPANT	\N	PRESENT	0
255340	240319	14053L	PARTICIPANT	\N	PRESENT	0
255341	240319	14223L	PARTICIPANT	\N	PRESENT	0
255342	240319	14031R	PARTICIPANT	\N	PRESENT	0
255343	240319	19545Y	PARTICIPANT	\N	PRESENT	0
255344	240319	14207L	PARTICIPANT	\N	PRESENT	0
255345	240319	14119M	PARTICIPANT	\N	PRESENT	0
255346	240319	19447X	PARTICIPANT	\N	PRESENT	0
255347	240319	19689Q	PARTICIPANT	\N	PRESENT	0
255348	240319	19695N	PARTICIPANT	\N	PRESENT	0
255349	240319	18083K	PARTICIPANT	\N	PRESENT	0
255350	240319	14105F	PARTICIPANT	\N	PRESENT	0
255351	240319	14041T	PARTICIPANT	\N	PRESENT	0
255352	240319	19387D	PARTICIPANT	\N	PRESENT	0
255353	240319	19573D	PARTICIPANT	\N	PRESENT	0
255354	240319	07029T	PARTICIPANT	\N	PRESENT	0
255355	240319	97011G	PARTICIPANT	\N	PRESENT	0
255356	240319	11048N	PARTICIPANT	\N	PRESENT	0
255357	240319	19413M	PARTICIPANT	\N	PRESENT	0
255358	240319	01024M	PARTICIPANT	\N	PRESENT	0
255359	253540	19715Y	PARTICIPANT	\N	PRESENT	0
255360	253540	19583F	PARTICIPANT	\N	PRESENT	0
255361	253540	19703U	PARTICIPANT	\N	EXCUSE	0
255362	253540	04043D	PARTICIPANT	\N	PRESENT	0
255363	253540	08019V	PRESIDENT	0	PRESENT	0
255364	240319	14213J	PARTICIPANT	\N	PRESENT	0
244009	244008	14051J	PARTICIPANT	\N	PRESENT	0
244010	244008	08053X	PARTICIPANT	\N	PRESENT	0
244012	244011	08020N	PARTICIPANT	\N	PRESENT	0
244013	244011	11083R	PARTICIPANT	\N	PRESENT	0
244014	244011	04057K	PARTICIPANT	\N	PRESENT	0
244015	244011	14073Q	PARTICIPANT	\N	PRESENT	0
244508	239671	11072N	PARTICIPANT	0	PRESENT	0
244509	239671	11031D	PARTICIPANT	0	PRESENT	0
244510	239671	80027E	PARTICIPANT	0	PRESENT	0
244511	239671	11109J	PARTICIPANT	0	PRESENT	0
244512	239671	19295A	PARTICIPANT	0	PRESENT	0
244513	239671	14207L	PARTICIPANT	0	PRESENT	0
244514	239671	14081Q	PARTICIPANT	0	PRESENT	0
244515	239671	08045X	PARTICIPANT	0	PRESENT	0
244516	239671	08052W	PARTICIPANT	0	PRESENT	0
244517	239671	08043V	PARTICIPANT	0	PRESENT	0
244518	239671	11066Q	PARTICIPANT	0	PRESENT	0
244519	239671	19387D	PARTICIPANT	0	PRESENT	0
244520	239671	14261S	PARTICIPANT	0	PRESENT	0
244521	239671	19749K	PARTICIPANT	0	PRESENT	0
244522	239671	19335Q	PARTICIPANT	0	PRESENT	0
244523	239671	19671E	PARTICIPANT	0	PRESENT	0
244524	239671	12016W	PARTICIPANT	0	PRESENT	0
244525	239671	98005N	PARTICIPANT	0	PRESENT	0
244526	239671	04088S	PARTICIPANT	0	PRESENT	0
244527	239671	19507S	PARTICIPANT	0	PRESENT	0
244528	239671	07029T	PARTICIPANT	0	PRESENT	0
244529	239671	17779H	PARTICIPANT	0	PRESENT	0
244530	239671	19683J	PARTICIPANT	0	PRESENT	0
244531	239671	08061X	PARTICIPANT	0	PRESENT	0
244532	239671	04045F	PARTICIPANT	0	PRESENT	0
244533	239671	14281W	PARTICIPANT	0	PRESENT	0
244534	239671	19697Q	PARTICIPANT	0	PRESENT	0
244535	239671	11067R	PARTICIPANT	0	PRESENT	0
244536	239671	19551W	PARTICIPANT	0	PRESENT	0
244537	239671	19415P	PARTICIPANT	0	PRESENT	0
244538	239671	10006L	PARTICIPANT	0	PRESENT	0
244539	239671	19527W	PARTICIPANT	0	PRESENT	0
244540	239671	14033T	PARTICIPANT	0	PRESENT	0
244541	239671	11026G	PARTICIPANT	0	PRESENT	0
244542	239671	11099A	PARTICIPANT	0	PRESENT	0
244543	239671	08019V	PARTICIPANT	0	PRESENT	0
244544	239671	19693L	PARTICIPANT	0	PRESENT	0
244545	239671	14135M	PARTICIPANT	0	PRESENT	0
244546	239671	11012A	PARTICIPANT	0	PRESENT	0
244547	239671	14219Q	PARTICIPANT	0	PRESENT	0
244548	239671	19565D	PARTICIPANT	0	PRESENT	0
244549	239671	19347U	PARTICIPANT	0	PRESENT	0
244550	239671	19689Q	PARTICIPANT	0	PRESENT	0
244551	239671	19569H	PARTICIPANT	0	PRESENT	0
244552	239671	11045K	PARTICIPANT	0	PRESENT	0
244553	239671	14103D	PARTICIPANT	0	PRESENT	0
244554	239671	08060W	PARTICIPANT	0	PRESENT	0
244555	239671	14251Q	PARTICIPANT	0	PRESENT	0
244556	239671	19631V	PARTICIPANT	0	PRESENT	0
244557	239671	19399H	PARTICIPANT	0	PRESENT	0
244558	239671	19709B	PARTICIPANT	0	PRESENT	0
244559	239671	19727D	PARTICIPANT	0	PRESENT	0
244560	239671	08055A	PARTICIPANT	0	PRESENT	0
244561	239671	19503N	PARTICIPANT	0	PRESENT	0
244562	239671	14034U	PARTICIPANT	0	PRESENT	0
244563	239671	11090Q	PARTICIPANT	0	PRESENT	0
244564	239671	14179A	PARTICIPANT	0	PRESENT	0
244565	239671	14021P	PARTICIPANT	0	PRESENT	0
244566	239671	04034C	PARTICIPANT	0	PRESENT	0
244567	239671	19647E	PARTICIPANT	0	PRESENT	0
244568	239671	19649G	PARTICIPANT	0	PRESENT	0
244569	239671	08017T	PARTICIPANT	0	PRESENT	0
244570	239671	14225N	PARTICIPANT	0	PRESENT	0
244571	239671	14089Y	PARTICIPANT	0	PRESENT	0
244572	239671	11033F	PARTICIPANT	0	PRESENT	0
244573	239671	14041T	PARTICIPANT	0	PRESENT	0
244850	244849	19545Y	PARTICIPANT	\N	PRESENT	0
244851	244849	14085U	PARTICIPANT	\N	PRESENT	0
244852	244849	11070L	PARTICIPANT	\N	PRESENT	0
244853	244849	14327T	PARTICIPANT	\N	PRESENT	0
244854	244849	14199E	PARTICIPANT	\N	PRESENT	0
244855	244849	01057W	PARTICIPANT	\N	PRESENT	0
244856	244849	11048N	PARTICIPANT	\N	PRESENT	0
244857	244849	08011M	PARTICIPANT	\N	PRESENT	0
244858	244849	14225N	PARTICIPANT	\N	PRESENT	0
244859	244849	19687N	PARTICIPANT	\N	PRESENT	0
244860	244849	14173T	PARTICIPANT	\N	PRESENT	0
251419	250562	11012A	PARTICIPANT	\N	PRESENT	0
251420	250562	08034U	PARTICIPANT	\N	PRESENT	0
251421	250562	11053K	PARTICIPANT	\N	PRESENT	0
251422	250562	11110B	PARTICIPANT	\N	PRESENT	0
255091	255090	01043Q	PARTICIPANT	\N	PRESENT	0
255802	255799	14030Q	PARTICIPANT	\N	EXCUSE	0
255804	255799	08043V	PARTICIPANT	\N	PRESENT	0
255806	255799	19643A	PARTICIPANT	\N	PRESENT	0
255808	255799	19621T	PARTICIPANT	\N	EXCUSE	0
251474	251100	19729F	PARTICIPANT	\N	PRESENT	0
251475	251100	19443T	PARTICIPANT	\N	PRESENT	0
251476	251100	08058D	PRESIDENT	0	PRESENT	0
251477	251100	19581D	PARTICIPANT	\N	PRESENT	0
251478	251100	11049P	PARTICIPANT	\N	PRESENT	0
251479	251100	19721W	PARTICIPANT	\N	PRESENT	0
251480	251100	15447F	PARTICIPANT	\N	PRESENT	0
251481	251100	19703U	PARTICIPANT	\N	PRESENT	0
251482	251100	04071H	PARTICIPANT	\N	PRESENT	0
251483	251100	11053K	PARTICIPANT	\N	PRESENT	0
255809	255799	08024S	PARTICIPANT	\N	EXCUSE	0
255810	255799	19701S	PARTICIPANT	\N	PRESENT	0
255811	255799	80013X	PARTICIPANT	\N	PRESENT	0
255812	255799	14217N	PARTICIPANT	\N	PRESENT	0
255813	255799	04035D	PARTICIPANT	\N	EXCUSE	0
251517	250529	11063M	PARTICIPANT	\N	PRESENT	0
251518	250529	19575F	PARTICIPANT	\N	PRESENT	0
255814	255799	08031R	PRESIDENT	0	PRESENT	0
255815	255799	07029T	PARTICIPANT	\N	EXCUSE	0
255816	255799	19269X	PARTICIPANT	\N	PRESENT	0
255817	255799	19749K	PARTICIPANT	\N	PRESENT	0
255823	253546	14261S	PARTICIPANT	\N	PRESENT	0
255824	253546	14259Y	PARTICIPANT	\N	EXCUSE	0
251545	250195	19649G	PARTICIPANT	\N	PRESENT	0
251546	250195	11080N	PARTICIPANT	\N	PRESENT	0
251547	250195	19611R	PARTICIPANT	\N	PRESENT	0
251548	250195	10015M	PARTICIPANT	\N	PRESENT	0
251549	250195	11026G	PARTICIPANT	\N	PRESENT	0
251550	250195	19673G	PARTICIPANT	\N	PRESENT	0
251551	250195	11033F	PARTICIPANT	\N	PRESENT	0
251552	250195	02002K	PARTICIPANT	\N	PRESENT	0
251553	250195	08056B	PARTICIPANT	\N	PRESENT	0
251554	250195	14089Y	PARTICIPANT	\N	PRESENT	0
251555	250195	14199E	PARTICIPANT	\N	PRESENT	0
251556	250195	19421M	PARTICIPANT	\N	PRESENT	0
251557	250195	98022P	PARTICIPANT	\N	PRESENT	0
251558	250195	98050T	PARTICIPANT	\N	PRESENT	0
251559	250195	19575F	PARTICIPANT	\N	PRESENT	0
251560	250195	98029W	PRESIDENT	0	PRESENT	0
251575	250196	19611R	PARTICIPANT	\N	PRESENT	0
255825	253546	19691J	PARTICIPANT	\N	PRESENT	0
255826	253546	19715Y	PARTICIPANT	\N	PRESENT	0
255827	253546	14059S	PRESIDENT	0	PRESENT	0
255828	253546	19703U	PARTICIPANT	\N	PRESENT	0
255843	253546	19583F	PARTICIPANT	\N	EXCUSE	0
260209	258643	08009T	PRESIDENT	0	PRESENT	0
260210	258643	19681G	PARTICIPANT	\N	EXCUSE	0
260211	258643	19599P	PARTICIPANT	\N	EXCUSE	0
260215	258643	14103D	PARTICIPANT	\N	PRESENT	0
260216	258643	95062K	PARTICIPANT	\N	PRESENT	0
260217	258643	19737F	PARTICIPANT	\N	PRESENT	0
260218	258643	19739H	PARTICIPANT	\N	PRESENT	0
260219	258643	14219Q	PARTICIPANT	\N	PRESENT	0
260220	258643	14191V	PARTICIPANT	\N	PRESENT	0
260221	258643	19333N	PARTICIPANT	\N	PRESENT	0
260222	258643	19383Y	PARTICIPANT	\N	PRESENT	0
260223	258643	17583W	PARTICIPANT	\N	PRESENT	0
260224	258643	19387D	PARTICIPANT	\N	PRESENT	0
260225	258643	14221J	PARTICIPANT	\N	PRESENT	0
260226	258643	19637C	PARTICIPANT	\N	PRESENT	0
260227	258643	18083K	PARTICIPANT	\N	PRESENT	0
260228	258643	14237S	PARTICIPANT	\N	PRESENT	0
260229	258643	05012A	PARTICIPANT	\N	PRESENT	0
260230	258643	14051J	PARTICIPANT	\N	PRESENT	0
260231	258643	08060W	PARTICIPANT	\N	PRESENT	0
260232	258643	19503N	PARTICIPANT	\N	PRESENT	0
260233	258643	19347U	PARTICIPANT	\N	PRESENT	0
260234	258643	08024S	PARTICIPANT	\N	PRESENT	0
260235	258643	98023Q	PARTICIPANT	\N	PRESENT	0
260236	258643	17637T	PARTICIPANT	\N	PRESENT	0
260237	258643	19525U	PARTICIPANT	\N	PRESENT	0
260238	258643	14031R	PARTICIPANT	\N	PRESENT	0
260239	258643	19713W	PARTICIPANT	\N	PRESENT	0
260240	258643	08055A	PARTICIPANT	\N	PRESENT	0
260241	258643	14169X	PARTICIPANT	\N	PRESENT	0
256480	256478	04044E	PARTICIPANT	\N	PRESENT	0
257639	256121	11026G	PARTICIPANT	\N	PRESENT	0
257640	256121	08056B	PARTICIPANT	\N	PRESENT	0
257641	256007	19647E	PARTICIPANT	\N	PRESENT	0
257642	256007	14103D	PARTICIPANT	\N	PRESENT	0
257643	256007	04070G	PARTICIPANT	\N	PRESENT	0
257870	255991	19701S	PARTICIPANT	\N	PRESENT	0
257871	255991	19681G	PARTICIPANT	\N	PRESENT	0
257872	255991	19289C	PARTICIPANT	\N	PRESENT	0
257873	255991	19549D	PARTICIPANT	\N	PRESENT	0
257874	255774	14079W	PARTICIPANT	\N	PRESENT	0
257875	255774	04035D	PARTICIPANT	\N	PRESENT	0
257876	255774	11041F	PARTICIPANT	\N	PRESENT	0
257877	255774	14255U	PARTICIPANT	\N	PRESENT	0
257878	255991	14093U	PARTICIPANT	\N	PRESENT	0
257879	255991	14237S	PARTICIPANT	\N	PRESENT	0
257880	255991	14157T	PARTICIPANT	\N	PRESENT	0
257881	256024	19515S	PARTICIPANT	\N	PRESENT	0
257882	256024	19565D	PARTICIPANT	\N	PRESENT	0
257883	256024	14357A	PARTICIPANT	\N	PRESENT	0
257884	256024	19441R	PARTICIPANT	\N	PRESENT	0
257885	256024	14081Q	PARTICIPANT	\N	PRESENT	0
257886	256024	19413M	PARTICIPANT	\N	PRESENT	0
257887	256024	80013X	PARTICIPANT	\N	PRESENT	0
257888	256024	19631V	PARTICIPANT	\N	PRESENT	0
257889	256024	11099A	PARTICIPANT	\N	PRESENT	0
257890	256024	08068F	PARTICIPANT	\N	PRESENT	0
257891	256024	08015R	PARTICIPANT	\N	PRESENT	0
257892	256024	08019V	PARTICIPANT	\N	PRESENT	0
257893	256024	14197C	PARTICIPANT	\N	PRESENT	0
257894	256024	19369B	PARTICIPANT	\N	PRESENT	0
257895	256024	19511N	PARTICIPANT	\N	PRESENT	0
257896	256024	08028W	PARTICIPANT	\N	PRESENT	0
257897	256024	19563B	PARTICIPANT	\N	PRESENT	0
257898	256024	14265W	PARTICIPANT	\N	PRESENT	0
257899	256024	14329V	PARTICIPANT	\N	PRESENT	0
257900	256024	14135M	PARTICIPANT	\N	PRESENT	0
257901	256024	19467C	PARTICIPANT	\N	PRESENT	0
257902	256024	08038Y	PARTICIPANT	\N	PRESENT	0
257903	256024	08062Y	PARTICIPANT	\N	PRESENT	0
257904	256024	19695N	PARTICIPANT	\N	PRESENT	0
257905	256024	14033T	PARTICIPANT	\N	PRESENT	0
257906	256024	11090Q	PRESIDENT	0	PRESENT	0
257907	256024	14205J	PARTICIPANT	\N	PRESENT	0
257908	256024	04088S	PARTICIPANT	\N	PRESENT	0
257909	256024	14115H	PARTICIPANT	\N	PRESENT	0
257910	256024	19507S	PARTICIPANT	\N	PRESENT	0
257911	256024	19747H	PARTICIPANT	\N	PRESENT	0
257912	256024	14207L	PARTICIPANT	\N	PRESENT	0
257913	256024	19619A	PARTICIPANT	\N	PRESENT	0
257914	256024	17589D	PARTICIPANT	\N	PRESENT	0
257915	256024	14257W	PARTICIPANT	\N	PRESENT	0
261010	258989	14195A	PARTICIPANT	\N	PRESENT	0
258031	255774	14235Q	PARTICIPANT	\N	PRESENT	0
258033	255774	11027H	PARTICIPANT	\N	PRESENT	0
261011	258989	19681G	PARTICIPANT	\N	PRESENT	0
258028	255724	14355X	PARTICIPANT	\N	EXCUSE	0
261012	258991	04092N	PARTICIPANT	\N	PRESENT	0
261013	258991	11067R	PARTICIPANT	\N	PRESENT	0
261015	261014	14071N	PARTICIPANT	\N	PRESENT	0
261016	261014	04092N	PARTICIPANT	\N	PRESENT	0
261017	261014	11067R	PARTICIPANT	\N	PRESENT	0
261018	261014	14195A	PARTICIPANT	\N	PRESENT	0
261020	261019	14071N	PARTICIPANT	\N	PRESENT	0
261021	261019	04092N	PARTICIPANT	\N	PRESENT	0
261022	261019	14195A	PARTICIPANT	\N	PRESENT	0
261024	261023	14071N	PARTICIPANT	\N	PRESENT	0
261081	258967	11097X	PARTICIPANT	\N	PRESENT	0
261082	258967	98024R	PARTICIPANT	\N	PRESENT	0
261084	261083	10006L	PARTICIPANT	\N	PRESENT	0
261085	261083	08052W	PARTICIPANT	\N	PRESENT	0
261086	261083	19553Y	PARTICIPANT	\N	PRESENT	0
261087	261083	11097X	PARTICIPANT	\N	PRESENT	0
261088	261083	98024R	PARTICIPANT	\N	PRESENT	0
262140	260576	11097X	PARTICIPANT	\N	PRESENT	0
262141	260576	19415P	PARTICIPANT	\N	PRESENT	0
262142	260576	04045F	PARTICIPANT	\N	PRESENT	0
262143	260576	14227Q	PARTICIPANT	\N	PRESENT	0
262144	260576	11063M	PARTICIPANT	\N	PRESENT	0
262145	260576	19703U	PARTICIPANT	\N	PRESENT	0
262146	260576	14281W	PARTICIPANT	\N	PRESENT	0
262147	260576	19679N	PARTICIPANT	\N	PRESENT	0
262148	260576	14042U	PARTICIPANT	\N	PRESENT	0
262149	260576	14195A	PARTICIPANT	\N	PRESENT	0
262150	260576	19367Y	PARTICIPANT	\N	PRESENT	0
262151	260576	14213J	PARTICIPANT	\N	PRESENT	0
262152	260576	14261S	PARTICIPANT	\N	PRESENT	0
262153	260576	14217N	PARTICIPANT	\N	PRESENT	0
262154	260576	19683J	PARTICIPANT	\N	PRESENT	0
262155	260576	98024R	PARTICIPANT	\N	PRESENT	0
262156	260576	19527W	PARTICIPANT	\N	PRESENT	0
262157	260576	01034P	PARTICIPANT	\N	PRESENT	0
262158	260576	04092N	PRESIDENT	0	PRESENT	0
262159	260576	08052W	PARTICIPANT	\N	PRESENT	0
262160	260576	19715Y	PARTICIPANT	\N	PRESENT	0
262161	260576	19691J	PARTICIPANT	\N	PRESENT	0
262162	260576	19727D	PARTICIPANT	\N	PRESENT	0
262163	260576	11103C	PARTICIPANT	\N	PRESENT	0
262164	260576	14071N	PARTICIPANT	\N	PRESENT	0
262165	260576	14239U	PARTICIPANT	\N	EXCUSE	0
262166	260576	14087W	PARTICIPANT	\N	EXCUSE	0
262167	260576	08048B	PARTICIPANT	\N	EXCUSE	0
262168	260576	19663E	PARTICIPANT	\N	PRESENT	0
262169	260576	19575F	PARTICIPANT	\N	EXCUSE	0
262170	260576	14026U	PARTICIPANT	\N	EXCUSE	0
262171	260576	19521Q	PARTICIPANT	\N	EXCUSE	0
262172	260576	17779H	PARTICIPANT	\N	EXCUSE	0
262173	261003	14063N	PARTICIPANT	\N	EXCUSE	0
262174	261091	95067Q	PARTICIPANT	\N	PRESENT	0
262175	256148	08024S	PARTICIPANT	\N	PRESENT	0
262176	256148	19551W	PARTICIPANT	\N	PRESENT	0
262177	261573	14001X	PARTICIPANT	\N	PRESENT	0
262178	261573	01060R	PARTICIPANT	\N	PRESENT	0
262179	261573	19543W	PARTICIPANT	\N	PRESENT	0
262180	261573	04044E	PARTICIPANT	\N	PRESENT	0
262181	261573	19581D	PARTICIPANT	\N	PRESENT	0
262182	261573	04047H	PARTICIPANT	\N	PRESENT	0
262183	261573	01028R	PARTICIPANT	\N	PRESENT	0
262184	261573	14231L	PARTICIPANT	\N	PRESENT	0
262185	261573	05008E	PRESIDENT	0	PRESENT	0
262186	261573	19489J	PARTICIPANT	\N	PRESENT	0
262187	261573	14041T	PARTICIPANT	\N	PRESENT	0
262188	261573	14147R	PARTICIPANT	\N	PRESENT	0
262189	261573	14151M	PARTICIPANT	\N	PRESENT	0
262190	261573	14215L	PARTICIPANT	\N	PRESENT	0
262191	261573	19483C	PARTICIPANT	\N	PRESENT	0
262192	261573	14259Y	PARTICIPANT	\N	PRESENT	0
262193	261573	11072N	PARTICIPANT	\N	PRESENT	0
262194	261573	98035U	PARTICIPANT	\N	PRESENT	0
262195	261573	14053L	PARTICIPANT	\N	PRESENT	0
262196	261573	14065Q	PARTICIPANT	\N	PRESENT	0
262197	261573	19649G	PARTICIPANT	\N	PRESENT	0
262198	261573	11010L	PARTICIPANT	\N	PRESENT	0
262199	261573	07034Q	PARTICIPANT	\N	PRESENT	0
262200	261573	10015M	PARTICIPANT	\N	PRESENT	0
262201	261573	11026G	PARTICIPANT	\N	PRESENT	0
262202	261573	19253P	PARTICIPANT	\N	PRESENT	0
262203	261573	01024M	PARTICIPANT	\N	PRESENT	0
262204	261573	04038G	PARTICIPANT	\N	PRESENT	0
262205	261573	19719D	PARTICIPANT	\N	PRESENT	0
262206	261573	11033F	PARTICIPANT	\N	PRESENT	0
262207	261573	14089Y	PARTICIPANT	\N	PRESENT	0
262208	261573	19729F	PARTICIPANT	\N	PRESENT	0
262209	261573	95063L	PARTICIPANT	\N	PRESENT	0
262210	261573	19629C	PARTICIPANT	\N	PRESENT	0
262211	261573	08044W	PARTICIPANT	\N	PRESENT	0
262212	261573	14069U	PARTICIPANT	\N	PRESENT	0
262213	261573	11085T	PARTICIPANT	\N	PRESENT	0
262214	261573	11049P	PARTICIPANT	\N	PRESENT	0
262215	261573	04008A	PARTICIPANT	\N	PRESENT	0
262216	261573	19725B	PARTICIPANT	\N	PRESENT	0
262217	261573	14111D	PARTICIPANT	\N	PRESENT	0
262218	261573	08045X	PARTICIPANT	\N	PRESENT	0
262219	261573	19673G	PARTICIPANT	\N	PRESENT	0
262220	261573	08018U	PARTICIPANT	\N	EXCUSE	0
262221	261573	19447X	PARTICIPANT	\N	EXCUSE	0
262222	261573	14021P	PARTICIPANT	\N	EXCUSE	0
262223	255917	19421M	PARTICIPANT	\N	EXCUSE	0
262261	260576	14223L	PARTICIPANT	\N	PRESENT	0
262262	260576	19723Y	PARTICIPANT	\N	PRESENT	0
262263	261183	89017R	PARTICIPANT	\N	PRESENT	0
262264	261183	19479G	PARTICIPANT	\N	PRESENT	0
262274	260576	14355X	PARTICIPANT	\N	EXCUSE	0
262275	260576	08041T	PARTICIPANT	\N	EXCUSE	0
262276	261183	12016W	PARTICIPANT	\N	PRESENT	0
262341	261751	11056N	PARTICIPANT	\N	PRESENT	0
262342	261751	04089T	PARTICIPANT	\N	EXCUSE	0
262343	261751	11101A	PARTICIPANT	\N	EXCUSE	0
262344	261751	14187A	PARTICIPANT	\N	EXCUSE	0
245203	244333	19253P	PARTICIPANT	\N	PRESENT	0
245204	244333	14231L	PARTICIPANT	\N	PRESENT	0
245205	244333	14053L	PARTICIPANT	\N	PRESENT	0
245206	244333	14215L	PARTICIPANT	\N	PRESENT	0
245207	244333	19629C	PARTICIPANT	\N	PRESENT	0
245208	244333	01024M	PARTICIPANT	\N	PRESENT	0
245209	244333	08018U	PARTICIPANT	\N	PRESENT	0
245210	243522	19443T	PARTICIPANT	\N	PRESENT	0
245211	243522	95067Q	PARTICIPANT	\N	PRESENT	0
245212	243522	95030B	PARTICIPANT	\N	PRESENT	0
245213	243522	04034C	PARTICIPANT	\N	PRESENT	0
245214	243522	11041F	PARTICIPANT	\N	PRESENT	0
245215	243522	04040A	PARTICIPANT	\N	PRESENT	0
245216	243522	16685X	PARTICIPANT	\N	PRESENT	0
245217	243522	14028W	PARTICIPANT	\N	PRESENT	0
245218	243522	11054L	PARTICIPANT	\N	PRESENT	0
245219	243522	19251M	PARTICIPANT	\N	PRESENT	0
245220	243522	11066Q	PARTICIPANT	\N	PRESENT	0
245221	243522	19319Q	PARTICIPANT	\N	PRESENT	0
245222	243522	98018T	PARTICIPANT	\N	PRESENT	0
245223	243522	14193X	PRESIDENT	0	PRESENT	0
245224	243522	14267Y	PARTICIPANT	\N	PRESENT	0
245225	243522	98050T	PARTICIPANT	\N	PRESENT	0
245226	243522	97011G	PARTICIPANT	\N	PRESENT	0
245227	243522	19583F	PARTICIPANT	\N	PRESENT	0
245228	243522	08047A	PARTICIPANT	\N	PRESENT	0
245231	243522	14211G	PARTICIPANT	\N	PRESENT	0
245305	245197	04070G	PRESIDENT	0	PRESENT	0
245306	245197	19699S	PARTICIPANT	\N	PRESENT	0
245307	245197	12041X	PARTICIPANT	\N	PRESENT	0
245308	245197	19533U	PARTICIPANT	\N	PRESENT	0
245309	245197	95015C	PARTICIPANT	\N	PRESENT	0
245310	245197	14241N	PARTICIPANT	\N	PRESENT	0
245311	245197	19573D	PARTICIPANT	\N	PRESENT	0
245312	245197	14107H	PARTICIPANT	\N	PRESENT	0
245313	245197	08017T	PARTICIPANT	\N	PRESENT	0
245314	245197	08012N	PARTICIPANT	\N	PRESENT	0
245315	245197	14249W	PARTICIPANT	\N	PRESENT	0
245316	245197	19643A	PARTICIPANT	\N	PRESENT	0
245317	245197	14059S	PARTICIPANT	\N	PRESENT	0
245318	245197	14061L	PARTICIPANT	\N	PRESENT	0
245319	245197	04057K	PARTICIPANT	\N	PRESENT	0
245320	245197	14073Q	PARTICIPANT	\N	PRESENT	0
245321	245197	19611R	PARTICIPANT	\N	PRESENT	0
245322	245197	08035V	PARTICIPANT	\N	PRESENT	0
245323	245197	19693L	PARTICIPANT	\N	PRESENT	0
245324	245197	14030Q	PARTICIPANT	\N	PRESENT	0
245325	245197	19731Y	PARTICIPANT	\N	PRESENT	0
245326	245197	08020N	PARTICIPANT	\N	PRESENT	0
245327	245197	04059M	PARTICIPANT	\N	PRESENT	0
245328	245197	19735D	PARTICIPANT	\N	PRESENT	0
245329	245197	14063N	PARTICIPANT	\N	PRESENT	0
245330	245197	14109K	PARTICIPANT	\N	PRESENT	0
245331	245197	11083R	PARTICIPANT	\N	PRESENT	0
245332	245197	19749K	PARTICIPANT	\N	PRESENT	0
245333	245197	04018C	PARTICIPANT	\N	PRESENT	0
245334	245197	08043V	PARTICIPANT	\N	EXCUSE	0
245335	245197	11104D	PARTICIPANT	\N	PRESENT	0
245336	245197	87003B	PARTICIPANT	\N	EXCUSE	0
245337	245197	08039A	PARTICIPANT	\N	EXCUSE	0
245338	245197	08031R	PARTICIPANT	\N	EXCUSE	0
245462	244323	19515S	PARTICIPANT	\N	PRESENT	0
245463	244323	01043Q	PARTICIPANT	\N	PRESENT	0
245464	244323	95030B	PARTICIPANT	\N	PRESENT	0
245465	244323	14357A	PARTICIPANT	\N	PRESENT	0
245466	244323	19441R	PARTICIPANT	\N	PRESENT	0
245467	244323	19413M	PARTICIPANT	\N	PRESENT	0
245468	244323	14001X	PARTICIPANT	\N	PRESENT	0
245469	244323	19631V	PARTICIPANT	\N	PRESENT	0
245470	244323	08021P	PARTICIPANT	\N	PRESENT	0
245471	244323	11099A	PARTICIPANT	\N	PRESENT	0
245472	244323	08068F	PARTICIPANT	\N	PRESENT	0
245473	244323	04049K	PARTICIPANT	\N	PRESENT	0
245474	244323	19705W	PARTICIPANT	\N	PRESENT	0
245475	244323	19707Y	PARTICIPANT	\N	PRESENT	0
245476	244323	08019V	PARTICIPANT	\N	PRESENT	0
245477	244323	19369B	PARTICIPANT	\N	PRESENT	0
245478	244323	19511N	PARTICIPANT	\N	PRESENT	0
245479	244323	08028W	PARTICIPANT	\N	PRESENT	0
245480	244323	19563B	PARTICIPANT	\N	PRESENT	0
245481	244323	14265W	PARTICIPANT	\N	PRESENT	0
245482	244323	14329V	PARTICIPANT	\N	PRESENT	0
245483	244323	14135M	PARTICIPANT	\N	PRESENT	0
245484	244323	19467C	PARTICIPANT	\N	PRESENT	0
245485	244323	14187A	PARTICIPANT	\N	PRESENT	0
245486	244323	08038Y	PARTICIPANT	\N	PRESENT	0
245487	244323	19301E	PARTICIPANT	\N	PRESENT	0
245488	244323	08062Y	PARTICIPANT	\N	PRESENT	0
245489	244323	19695N	PARTICIPANT	\N	PRESENT	0
245490	244323	14033T	PARTICIPANT	\N	PRESENT	0
245491	244323	11090Q	PRESIDENT	0	PRESENT	0
245492	244323	19269X	PARTICIPANT	\N	PRESENT	0
245493	244323	14205J	PARTICIPANT	\N	PRESENT	0
245494	244323	04088S	PARTICIPANT	\N	PRESENT	0
245495	244323	04089T	PARTICIPANT	\N	PRESENT	0
245496	244323	14115H	PARTICIPANT	\N	PRESENT	0
245497	244323	19507S	PARTICIPANT	\N	PRESENT	0
245498	244323	19747H	PARTICIPANT	\N	PRESENT	0
245499	244323	14207L	PARTICIPANT	\N	PRESENT	0
245500	244323	04043D	PARTICIPANT	\N	PRESENT	0
245501	244323	14257W	PARTICIPANT	\N	PRESENT	0
245520	244312	19333N	PARTICIPANT	\N	PRESENT	0
245521	244312	19383Y	PARTICIPANT	\N	PRESENT	0
245522	244312	17583W	PARTICIPANT	\N	PRESENT	0
245523	244312	19701S	PARTICIPANT	\N	PRESENT	0
245524	244312	19549D	PARTICIPANT	\N	PRESENT	0
245525	244312	95062K	PARTICIPANT	\N	PRESENT	0
245526	244312	19387D	PARTICIPANT	\N	PRESENT	0
245527	244312	14219Q	PARTICIPANT	\N	PRESENT	0
245528	244312	14221J	PARTICIPANT	\N	PRESENT	0
245529	244312	19637C	PARTICIPANT	\N	PRESENT	0
245530	244312	19551W	PARTICIPANT	\N	PRESENT	0
245531	244312	14237S	PARTICIPANT	\N	PRESENT	0
245532	244312	18083K	PARTICIPANT	\N	PRESENT	0
245533	244312	80027E	PARTICIPANT	\N	PRESENT	0
245534	244312	05012A	PARTICIPANT	\N	PRESENT	0
245535	244312	14051J	PARTICIPANT	\N	PRESENT	0
245536	244312	08060W	PARTICIPANT	\N	PRESENT	0
245537	244312	19347U	PARTICIPANT	\N	PRESENT	0
245538	244312	19503N	PARTICIPANT	\N	PRESENT	0
245539	244312	14157T	PARTICIPANT	\N	PRESENT	0
245540	244312	08024S	PARTICIPANT	\N	PRESENT	0
245541	244312	98023Q	PARTICIPANT	\N	PRESENT	0
245542	244312	11065P	PARTICIPANT	\N	PRESENT	0
245543	244312	17637T	PARTICIPANT	\N	PRESENT	0
245544	244312	19525U	PARTICIPANT	\N	PRESENT	0
245545	244312	14038Y	PARTICIPANT	\N	PRESENT	0
245546	244312	14103D	PARTICIPANT	\N	PRESENT	0
245547	244312	14031R	PARTICIPANT	\N	PRESENT	0
245548	244312	19289C	PARTICIPANT	\N	PRESENT	0
245549	244312	14169X	PARTICIPANT	\N	PRESENT	0
245550	244312	15447F	PARTICIPANT	\N	PRESENT	0
245551	244312	14093U	PARTICIPANT	\N	PRESENT	0
245552	244312	14029X	PARTICIPANT	\N	PRESENT	0
245553	244312	19733B	PARTICIPANT	\N	PRESENT	0
245554	244312	08009T	PRESIDENT	0	PRESENT	0
245555	244312	19737F	PARTICIPANT	\N	PRESENT	0
245556	244312	04097T	PARTICIPANT	\N	PRESENT	0
245557	244312	19745F	PARTICIPANT	\N	PRESENT	0
245558	244312	19659J	PARTICIPANT	\N	PRESENT	0
245559	244312	96004D	PARTICIPANT	\N	EXCUSE	0
245560	244312	19681G	PARTICIPANT	\N	EXCUSE	0
245561	244312	19599P	PARTICIPANT	\N	EXCUSE	0
245573	240285	14034U	PARTICIPANT	\N	PRESENT	0
245574	240285	14227Q	PARTICIPANT	\N	PRESENT	0
245575	240285	19349W	PARTICIPANT	\N	PRESENT	0
245576	240285	14195A	PARTICIPANT	\N	PRESENT	0
245577	240285	19583F	PARTICIPANT	\N	PRESENT	0
245578	240285	19521Q	PARTICIPANT	\N	PRESENT	0
245579	240285	04092N	PARTICIPANT	\N	PRESENT	0
245580	240285	19731Y	PARTICIPANT	\N	PRESENT	0
245581	240285	19443T	PARTICIPANT	\N	PRESENT	0
245582	240285	14105F	PARTICIPANT	\N	PRESENT	0
245583	240285	19575F	PARTICIPANT	\N	PRESENT	0
245584	240285	10006L	PARTICIPANT	\N	PRESENT	0
245585	240285	11063M	PARTICIPANT	\N	PRESENT	0
245586	240285	19679N	PARTICIPANT	\N	PRESENT	0
245587	240285	08020N	PARTICIPANT	\N	PRESENT	0
245588	240285	14089Y	PARTICIPANT	\N	PRESENT	0
245589	240285	19629C	PARTICIPANT	\N	PRESENT	0
245590	240285	14021P	PARTICIPANT	\N	PRESENT	0
245591	240285	99004R	PARTICIPANT	\N	PRESENT	0
245592	240285	19737F	PARTICIPANT	\N	PRESENT	0
245593	240285	11031D	PARTICIPANT	\N	PRESENT	0
245594	240285	14207L	PARTICIPANT	\N	PRESENT	0
245595	240285	14157T	PARTICIPANT	\N	PRESENT	0
245596	240285	14107H	PARTICIPANT	\N	PRESENT	0
245597	240285	19725B	PARTICIPANT	\N	PRESENT	0
245598	240285	04045F	PARTICIPANT	\N	PRESENT	0
255368	240319	14249W	PARTICIPANT	\N	PRESENT	0
255370	240319	14159V	PARTICIPANT	\N	PRESENT	0
255371	253540	14261S	PARTICIPANT	\N	PRESENT	0
255372	240319	14215L	PARTICIPANT	\N	PRESENT	0
255373	240319	19715Y	PARTICIPANT	\N	PRESENT	0
255375	240319	14109K	PARTICIPANT	\N	PRESENT	0
255377	240319	19683J	PARTICIPANT	\N	PRESENT	0
255388	240319	08055A	PARTICIPANT	\N	PRESENT	0
255389	240319	17583W	PARTICIPANT	\N	PRESENT	0
255390	240319	87003B	PARTICIPANT	\N	PRESENT	0
255391	240319	12016W	PARTICIPANT	\N	PRESENT	0
255392	240319	14157T	PARTICIPANT	\N	PRESENT	0
255394	255393	19631V	PARTICIPANT	\N	PRESENT	0
255395	255393	19741B	PARTICIPANT	\N	PRESENT	0
255396	255393	14093U	PARTICIPANT	\N	PRESENT	0
255397	255393	14083S	PARTICIPANT	\N	PRESENT	0
255398	255393	14038Y	PARTICIPANT	\N	PRESENT	0
255399	255393	19701S	PARTICIPANT	\N	PRESENT	0
255400	255393	14179A	PARTICIPANT	\N	PRESENT	0
255401	255393	19333N	PARTICIPANT	\N	PRESENT	0
255402	255393	04049K	PARTICIPANT	\N	PRESENT	0
255403	255393	19723Y	PARTICIPANT	\N	PRESENT	0
255404	255393	19711U	PARTICIPANT	\N	PRESENT	0
255405	255393	19709B	PARTICIPANT	\N	PRESENT	0
255406	255393	14031R	PARTICIPANT	\N	PRESENT	0
255365	253540	14059S	PARTICIPANT	\N	PRESENT	0
255366	240319	19415P	PARTICIPANT	\N	PRESENT	0
255407	255393	04057K	PARTICIPANT	\N	PRESENT	0
255408	255393	14265W	PARTICIPANT	\N	PRESENT	0
255409	255393	04070G	PARTICIPANT	\N	PRESENT	0
255410	255393	14169X	PARTICIPANT	\N	PRESENT	0
255411	255393	19349W	PARTICIPANT	\N	PRESENT	0
255412	255393	14107H	PARTICIPANT	\N	PRESENT	0
255413	240319	14229S	PARTICIPANT	\N	PRESENT	0
255414	240319	14073Q	PARTICIPANT	\N	PRESENT	0
255415	240319	19629C	PARTICIPANT	\N	PRESENT	0
255417	240319	19581D	PARTICIPANT	\N	PRESENT	0
255419	240319	19723Y	PARTICIPANT	\N	PRESENT	0
255420	240319	19739H	PARTICIPANT	\N	PRESENT	0
255421	240319	14257W	PARTICIPANT	\N	PRESENT	0
255422	240319	04043D	PARTICIPANT	\N	PRESENT	0
255423	240319	14042U	PARTICIPANT	\N	PRESENT	0
255424	240319	04045F	PARTICIPANT	\N	PRESENT	0
255425	240319	08043V	PARTICIPANT	\N	PRESENT	0
255426	240319	19713W	PARTICIPANT	\N	PRESENT	0
255427	240319	14217N	PARTICIPANT	\N	PRESENT	0
255428	240319	19507S	PARTICIPANT	\N	PRESENT	0
255429	240319	08020N	PARTICIPANT	\N	PRESENT	0
255430	240319	11043H	PARTICIPANT	\N	PRESENT	0
255431	240319	04049K	PARTICIPANT	\N	PRESENT	0
255432	240319	19671E	PARTICIPANT	\N	PRESENT	0
255433	240319	04033B	PARTICIPANT	\N	PRESENT	0
255434	240319	16685X	PARTICIPANT	\N	PRESENT	0
255470	240319	19553Y	PARTICIPANT	\N	PRESENT	0
255436	240319	14107H	PARTICIPANT	\N	PRESENT	0
255437	240319	04034C	PARTICIPANT	\N	PRESENT	0
255438	240319	19479G	PARTICIPANT	\N	PRESENT	0
255440	240319	14179A	PARTICIPANT	\N	PRESENT	0
255442	240319	14187A	PARTICIPANT	\N	PRESENT	0
255452	240319	19383Y	PARTICIPANT	\N	PRESENT	0
255453	240319	95030B	PARTICIPANT	\N	PRESENT	0
255454	240319	14034U	PARTICIPANT	\N	PRESENT	0
255455	240319	08031R	PARTICIPANT	\N	PRESENT	0
255456	240319	19563B	PARTICIPANT	\N	PRESENT	0
255457	240319	11027H	PARTICIPANT	\N	PRESENT	0
255458	240319	19483C	PARTICIPANT	\N	PRESENT	0
255459	240319	19733B	PARTICIPANT	\N	PRESENT	0
255460	240319	19667J	PARTICIPANT	\N	PRESENT	0
255461	240319	19543W	PARTICIPANT	\N	PRESENT	0
255462	240319	80013X	PARTICIPANT	\N	PRESENT	0
255463	240319	10006L	PARTICIPANT	\N	PRESENT	0
255464	240319	14123H	PARTICIPANT	\N	PRESENT	0
255465	240319	19631V	PARTICIPANT	\N	PRESENT	0
255466	240319	08015R	PARTICIPANT	\N	PRESENT	0
255467	240319	08061X	PARTICIPANT	\N	PRESENT	0
255475	240319	14071N	PARTICIPANT	\N	PRESENT	0
255476	240319	08009T	PARTICIPANT	\N	PRESENT	0
255477	240319	19593H	PARTICIPANT	\N	PRESENT	0
255478	240319	14281W	PARTICIPANT	\N	PRESENT	0
255479	240319	14079W	PARTICIPANT	\N	PRESENT	0
255480	240319	11012A	PARTICIPANT	\N	PRESENT	0
255481	240319	14089Y	PARTICIPANT	\N	PRESENT	0
255482	240319	14038Y	PARTICIPANT	\N	PRESENT	0
255483	240319	14051J	PARTICIPANT	\N	PRESENT	0
255484	240319	19583F	PARTICIPANT	\N	PRESENT	0
255486	240319	04057K	PARTICIPANT	\N	PRESENT	0
255487	240319	19673G	PARTICIPANT	\N	PRESENT	0
255488	240319	98022P	PARTICIPANT	\N	PRESENT	0
255489	240319	05008E	PARTICIPANT	\N	PRESENT	0
255490	240319	19725B	PARTICIPANT	\N	PRESENT	0
255491	240319	19687N	PARTICIPANT	\N	PRESENT	0
255492	240319	89017R	PARTICIPANT	\N	PRESENT	0
255508	240319	19649G	PARTICIPANT	\N	PRESENT	0
255509	240319	08010L	PARTICIPANT	\N	PRESENT	0
255510	240319	14169X	PARTICIPANT	\N	PRESENT	0
255520	253497	14089Y	PARTICIPANT	\N	PRESENT	0
255521	253497	08056B	PARTICIPANT	\N	PRESENT	0
255522	253497	11080N	PARTICIPANT	\N	PRESENT	0
255523	253497	19611R	PARTICIPANT	\N	PRESENT	0
255524	253497	19421M	PARTICIPANT	\N	PRESENT	0
255525	253497	98022P	PARTICIPANT	\N	PRESENT	0
255526	253497	10015M	PARTICIPANT	\N	PRESENT	0
255527	253497	08010L	PARTICIPANT	\N	PRESENT	0
255528	253497	19673G	PARTICIPANT	\N	PRESENT	0
255529	253497	11033F	PARTICIPANT	\N	PRESENT	0
255530	253497	98029W	PRESIDENT	0	PRESENT	0
255531	253497	98050T	PARTICIPANT	\N	EXCUSE	0
255532	253497	19575F	PARTICIPANT	\N	EXCUSE	0
255542	253498	08056B	PARTICIPANT	\N	PRESENT	0
255543	253498	19649G	PARTICIPANT	\N	PRESENT	0
255544	253498	19611R	PARTICIPANT	\N	PRESENT	0
255545	253498	19421M	PARTICIPANT	\N	PRESENT	0
255546	253498	98022P	PARTICIPANT	\N	PRESENT	0
255547	253498	10015M	PARTICIPANT	\N	PRESENT	0
255548	253498	19673G	PARTICIPANT	\N	PRESENT	0
255549	253498	98029W	PRESIDENT	0	PRESENT	0
255550	253498	98050T	PARTICIPANT	\N	EXCUSE	0
255551	253498	19575F	PARTICIPANT	\N	EXCUSE	0
255555	254993	08018U	PARTICIPANT	\N	EXCUSE	0
255556	240319	19549D	PARTICIPANT	\N	PRESENT	0
255557	240319	14197C	PARTICIPANT	\N	PRESENT	0
255558	240319	14357A	PARTICIPANT	\N	PRESENT	0
255559	240319	95063L	PARTICIPANT	\N	PRESENT	0
255560	240319	11033F	PARTICIPANT	\N	PRESENT	0
255575	255561	14205J	PARTICIPANT	\N	PRESENT	0
255576	255561	19703U	PARTICIPANT	\N	PRESENT	0
255577	255561	04071H	PARTICIPANT	\N	PRESENT	0
255578	255561	19729F	PARTICIPANT	\N	PRESENT	0
255579	255561	08034U	PARTICIPANT	\N	PRESENT	0
255580	255561	08035V	PARTICIPANT	\N	PRESENT	0
255581	255561	08058D	PRESIDENT	0	PRESENT	0
255582	255561	19581D	PARTICIPANT	\N	PRESENT	0
255583	255561	11049P	PARTICIPANT	\N	PRESENT	0
255584	240319	14231L	PARTICIPANT	\N	PRESENT	0
255585	240319	01057W	PARTICIPANT	\N	PRESENT	0
255586	240319	19693L	PARTICIPANT	\N	PRESENT	0
255587	240319	14205J	PARTICIPANT	\N	PRESENT	0
255588	240319	19531S	PARTICIPANT	\N	PRESENT	0
255589	240319	04085P	PARTICIPANT	\N	PRESENT	0
255590	240319	19347U	PARTICIPANT	\N	PRESENT	0
255591	240319	01043Q	PARTICIPANT	\N	PRESENT	0
255592	240319	19747H	PARTICIPANT	\N	PRESENT	0
255593	240319	11065P	PARTICIPANT	\N	PRESENT	0
255594	240319	14219Q	PARTICIPANT	\N	PRESENT	0
255596	240319	11110B	PARTICIPANT	\N	PRESENT	0
255597	240319	19727D	PARTICIPANT	\N	PRESENT	0
255598	240319	14083S	PARTICIPANT	\N	PRESENT	0
255599	240319	08056B	PARTICIPANT	\N	PRESENT	0
255600	240319	19575F	PARTICIPANT	\N	PRESENT	0
246496	246494	19575F	PARTICIPANT	\N	PRESENT	0
246497	246494	19467C	PARTICIPANT	\N	PRESENT	0
246498	246494	01024M	PARTICIPANT	\N	PRESENT	0
246499	246494	14281W	PARTICIPANT	\N	PRESENT	0
246502	246494	19727D	PARTICIPANT	\N	PRESENT	0
246504	246494	14026U	PARTICIPANT	\N	PRESENT	0
246507	246494	19691J	PARTICIPANT	\N	PRESENT	0
246509	246494	19333N	PARTICIPANT	\N	PRESENT	0
246512	246494	19657G	PARTICIPANT	\N	PRESENT	0
246514	246494	08053X	PARTICIPANT	\N	PRESENT	0
246515	246494	14223L	PARTICIPANT	\N	PRESENT	0
246517	246494	14265W	PARTICIPANT	\N	PRESENT	0
246520	246494	14119M	PARTICIPANT	\N	PRESENT	0
246523	246494	19679N	PARTICIPANT	\N	PRESENT	0
246528	246494	95062K	PARTICIPANT	\N	PRESENT	0
247108	247107	19415P	PARTICIPANT	\N	PRESENT	0
247109	247107	04092N	PARTICIPANT	\N	PRESENT	0
247110	247107	19703U	PARTICIPANT	\N	PRESENT	0
247111	247107	11063M	PARTICIPANT	\N	PRESENT	0
247112	247107	19717B	PARTICIPANT	\N	PRESENT	0
247113	247107	14239U	PARTICIPANT	\N	PRESENT	0
247114	247107	11067R	PARTICIPANT	\N	PRESENT	0
247115	247106	19415P	PARTICIPANT	\N	PRESENT	0
247116	247106	04092N	PARTICIPANT	\N	PRESENT	0
247117	247106	19717B	PARTICIPANT	\N	PRESENT	0
247118	247106	11067R	PARTICIPANT	\N	PRESENT	0
249549	249547	14041T	PARTICIPANT	\N	PRESENT	0
249550	249547	07033P	PARTICIPANT	\N	PRESENT	0
249551	249547	14255U	PARTICIPANT	\N	PRESENT	0
249552	249547	14071N	PARTICIPANT	\N	PRESENT	0
249553	249547	19483C	PARTICIPANT	\N	PRESENT	0
249554	249547	04049K	PARTICIPANT	\N	PRESENT	0
250902	250901	14105F	PARTICIPANT	\N	PRESENT	0
249556	249547	19731Y	PARTICIPANT	\N	PRESENT	0
249557	249547	04038G	PARTICIPANT	\N	PRESENT	0
249558	249547	04035D	PARTICIPANT	\N	PRESENT	0
249559	249547	98023Q	PARTICIPANT	\N	PRESENT	0
249560	249547	19333N	PARTICIPANT	\N	PRESENT	0
249561	249547	14215L	PARTICIPANT	\N	PRESENT	0
249562	249547	11083R	PARTICIPANT	\N	PRESENT	0
249563	249547	14265W	PARTICIPANT	\N	PRESENT	0
249564	249547	98035U	PARTICIPANT	\N	PRESENT	0
249565	249547	19709B	PARTICIPANT	\N	PRESENT	0
249566	249547	14059S	PARTICIPANT	\N	PRESENT	0
249567	249547	14135M	PARTICIPANT	\N	PRESENT	0
249568	249547	11033F	PARTICIPANT	\N	PRESENT	0
249569	249547	14147R	PARTICIPANT	\N	PRESENT	0
249570	249547	04047H	PARTICIPANT	\N	PRESENT	0
249574	249547	14151M	PARTICIPANT	\N	PRESENT	0
250903	250901	14255U	PARTICIPANT	\N	PRESENT	0
250904	250901	14267Y	PARTICIPANT	\N	PRESENT	0
250905	250901	11027H	PARTICIPANT	\N	PRESENT	0
250906	250901	11115U	PARTICIPANT	\N	PRESENT	0
250907	250901	14079W	PARTICIPANT	\N	PRESENT	0
250908	250901	14097Y	PARTICIPANT	\N	PRESENT	0
250909	250901	19709B	PARTICIPANT	\N	PRESENT	0
250910	250901	08053X	PARTICIPANT	\N	PRESENT	0
250911	250901	14193X	PARTICIPANT	\N	PRESENT	0
250912	250901	19443T	PARTICIPANT	\N	PRESENT	0
250913	250901	19421M	PARTICIPANT	\N	PRESENT	0
250914	250901	01058X	PARTICIPANT	\N	PRESENT	0
250915	250901	11066Q	PARTICIPANT	\N	PRESENT	0
250916	250901	95067Q	PARTICIPANT	\N	PRESENT	0
250917	250901	04034C	PARTICIPANT	\N	PRESENT	0
250920	250919	19631V	PARTICIPANT	\N	PRESENT	0
250921	250919	19515S	PARTICIPANT	\N	PRESENT	0
250922	250919	19747H	PARTICIPANT	\N	PRESENT	0
250923	250919	14207L	PARTICIPANT	\N	PRESENT	0
250924	250919	19467C	PARTICIPANT	\N	PRESENT	0
250925	250919	11056N	PARTICIPANT	\N	PRESENT	0
250926	250919	14197C	PARTICIPANT	\N	PRESENT	0
250927	250919	01025N	PARTICIPANT	\N	PRESENT	0
250928	250919	19695N	PARTICIPANT	\N	PRESENT	0
250929	250919	19565D	PARTICIPANT	\N	PRESENT	0
250930	250919	04049K	PARTICIPANT	\N	PRESENT	0
250931	250919	14205J	PARTICIPANT	\N	PRESENT	0
250932	250919	14357A	PARTICIPANT	\N	PRESENT	0
250933	250919	14265W	PARTICIPANT	\N	PRESENT	0
250934	250919	04088S	PARTICIPANT	\N	PRESENT	0
250935	250919	14135M	PARTICIPANT	\N	PRESENT	0
250936	250919	19619A	PARTICIPANT	\N	PRESENT	0
253503	253493	11048N	PRESIDENT	0	PRESENT	0
253504	253493	14103D	PARTICIPANT	\N	PRESENT	0
253505	253493	19711U	PARTICIPANT	\N	PRESENT	0
253506	253493	19533U	PARTICIPANT	\N	PRESENT	0
253507	253493	14031R	PARTICIPANT	\N	PRESENT	0
253508	253493	19253P	PARTICIPANT	\N	PRESENT	0
253509	253493	12016W	PARTICIPANT	\N	PRESENT	0
253510	253493	01024M	PARTICIPANT	\N	PRESENT	0
253511	253493	04038G	PARTICIPANT	\N	PRESENT	0
253512	253493	19399H	PARTICIPANT	\N	PRESENT	0
253513	253493	14026U	PARTICIPANT	\N	PRESENT	0
253514	253493	19719D	PARTICIPANT	\N	PRESENT	0
253515	253493	14173T	PARTICIPANT	\N	PRESENT	0
253516	253493	19573D	PARTICIPANT	\N	PRESENT	0
253517	253493	14087W	PARTICIPANT	\N	PRESENT	0
253518	253493	14041T	PARTICIPANT	\N	PRESENT	0
253519	253493	19503N	PARTICIPANT	\N	PRESENT	0
253520	253493	14151M	PARTICIPANT	\N	PRESENT	0
253521	253493	14071N	PARTICIPANT	\N	PRESENT	0
253522	253493	14157T	PARTICIPANT	\N	PRESENT	0
253523	253493	19749K	PARTICIPANT	\N	PRESENT	0
253524	253493	19441R	PARTICIPANT	\N	PRESENT	0
253525	253493	11067R	PARTICIPANT	\N	PRESENT	0
253760	240316	14039A	PARTICIPANT	\N	PRESENT	0
253761	240316	19659J	PARTICIPANT	\N	PRESENT	0
253762	240316	19301E	PARTICIPANT	\N	PRESENT	0
253763	240316	14157T	PARTICIPANT	\N	PRESENT	0
253764	240316	11083R	PARTICIPANT	\N	PRESENT	0
253765	240316	98029W	PARTICIPANT	\N	PRESENT	0
253766	240316	14123H	PARTICIPANT	\N	PRESENT	0
253767	240316	11012A	PARTICIPANT	\N	PRESENT	0
253768	240316	95015C	PARTICIPANT	\N	PRESENT	0
253769	240316	14034U	PARTICIPANT	\N	PRESENT	0
253770	240316	08031R	PARTICIPANT	\N	PRESENT	0
253771	240316	14223L	PARTICIPANT	\N	PRESENT	0
253772	240316	19629C	PARTICIPANT	\N	PRESENT	0
253773	240316	19253P	PARTICIPANT	\N	PRESENT	0
253774	240316	14261S	PARTICIPANT	\N	PRESENT	0
253775	240316	08049C	PARTICIPANT	\N	PRESENT	0
253777	240316	15447F	PARTICIPANT	\N	PRESENT	0
253778	240316	14201E	PARTICIPANT	\N	PRESENT	0
253779	240316	19563B	PARTICIPANT	\N	PRESENT	0
253780	240316	98022P	PARTICIPANT	\N	PRESENT	0
253781	240316	08028W	PARTICIPANT	\N	PRESENT	0
253782	240316	19719D	PARTICIPANT	\N	PRESENT	0
253783	240316	19387D	PARTICIPANT	\N	PRESENT	0
253784	240316	11099A	PARTICIPANT	\N	PRESENT	0
253785	240316	11056N	PARTICIPANT	\N	PRESENT	0
253786	240316	04038G	PARTICIPANT	\N	PRESENT	0
253787	240316	14169X	PARTICIPANT	\N	PRESENT	0
253788	240316	11043H	PARTICIPANT	\N	PRESENT	0
253789	240316	19681G	PARTICIPANT	\N	PRESENT	0
253790	240316	10015M	PARTICIPANT	\N	PRESENT	0
253791	240316	19553Y	PARTICIPANT	\N	PRESENT	0
253794	240316	19269X	PARTICIPANT	\N	PRESENT	0
253795	240316	14173T	PARTICIPANT	\N	PRESENT	0
253796	240316	17589D	PARTICIPANT	\N	PRESENT	0
253797	240316	14195A	PARTICIPANT	\N	PRESENT	0
253798	240316	04071H	PARTICIPANT	\N	PRESENT	0
253799	240316	11064N	PARTICIPANT	\N	PRESENT	0
253800	240316	19583F	PARTICIPANT	\N	PRESENT	0
253801	240316	08069G	PARTICIPANT	\N	PRESENT	0
253802	240316	02002K	PARTICIPANT	\N	PRESENT	0
253803	240316	01057W	PARTICIPANT	\N	PRESENT	0
253804	240316	87003B	PARTICIPANT	\N	PRESENT	0
253805	240316	11090Q	PARTICIPANT	\N	PRESENT	0
253806	240316	11074Q	PARTICIPANT	\N	PRESENT	0
253807	240316	04059M	PARTICIPANT	\N	PRESENT	0
253808	240316	08020N	PARTICIPANT	\N	PRESENT	0
253809	240316	14159V	PARTICIPANT	\N	PRESENT	0
253810	240316	11077T	PARTICIPANT	\N	PRESENT	0
253811	240316	19703U	PARTICIPANT	\N	PRESENT	0
253812	240316	08068F	PARTICIPANT	\N	PRESENT	0
253813	240316	08073C	PARTICIPANT	\N	PRESENT	0
253814	240316	19673G	PARTICIPANT	\N	PRESENT	0
253815	240316	14031R	PARTICIPANT	\N	PRESENT	0
253816	240316	11027H	PARTICIPANT	\N	PRESENT	0
253817	240316	19667J	PARTICIPANT	\N	PRESENT	0
253818	240316	08052W	PARTICIPANT	\N	PRESENT	0
253819	240316	14051J	PARTICIPANT	\N	PRESENT	0
253820	240316	01028R	PARTICIPANT	\N	PRESENT	0
253821	240316	14229S	PARTICIPANT	\N	PRESENT	0
253822	240316	98023Q	PARTICIPANT	\N	PRESENT	0
261496	261179	11099A	PARTICIPANT	\N	PRESENT	0
261497	261181	11099A	PARTICIPANT	\N	PRESENT	0
262345	261751	11081P	PARTICIPANT	\N	EXCUSE	0
262349	261003	19253P	PARTICIPANT	\N	EXCUSE	0
262351	261487	04059M	PARTICIPANT	\N	PRESENT	0
262352	261487	04086Q	PARTICIPANT	\N	PRESENT	0
262353	262350	19649G	PARTICIPANT	\N	PRESENT	0
262354	262350	10015M	PARTICIPANT	\N	PRESENT	0
262355	262350	11026G	PARTICIPANT	\N	PRESENT	0
262356	262350	19253P	PARTICIPANT	\N	PRESENT	0
262357	262350	04044E	PARTICIPANT	\N	PRESENT	0
262358	262350	04047H	PARTICIPANT	\N	PRESENT	0
262359	262350	19673G	PARTICIPANT	\N	PRESENT	0
262360	262350	19719D	PARTICIPANT	\N	PRESENT	0
262361	262350	01028R	PARTICIPANT	\N	PRESENT	0
262362	262350	05008E	PRESIDENT	0	PRESENT	0
262363	262350	14231L	PARTICIPANT	\N	PRESENT	0
262364	262350	14089Y	PARTICIPANT	\N	PRESENT	0
262365	262350	08044W	PARTICIPANT	\N	PRESENT	0
262366	262350	14041T	PARTICIPANT	\N	PRESENT	0
262367	262350	14147R	PARTICIPANT	\N	PRESENT	0
262368	262350	14215L	PARTICIPANT	\N	PRESENT	0
262369	262350	19483C	PARTICIPANT	\N	PRESENT	0
262370	262350	04008A	PARTICIPANT	\N	PRESENT	0
262371	262350	11072N	PARTICIPANT	\N	PRESENT	0
262372	262350	14053L	PARTICIPANT	\N	EXCUSE	0
262386	261487	11077T	PARTICIPANT	\N	PRESENT	0
262387	261487	11048N	PARTICIPANT	\N	PRESENT	0
262388	261487	19681G	PARTICIPANT	\N	PRESENT	0
262389	261487	11066Q	PARTICIPANT	\N	PRESENT	0
262390	261487	11040E	PARTICIPANT	\N	PRESENT	0
262391	261487	19489J	PARTICIPANT	\N	PRESENT	0
262392	261487	08068F	PARTICIPANT	\N	PRESENT	0
262393	261487	19413M	PARTICIPANT	\N	PRESENT	0
262394	261487	19565D	PARTICIPANT	\N	PRESENT	0
262395	261487	14197C	PARTICIPANT	\N	PRESENT	0
262396	261487	19715Y	PARTICIPANT	\N	PRESENT	0
262397	261487	08014Q	PARTICIPANT	\N	PRESENT	0
262398	261487	11065P	PARTICIPANT	\N	PRESENT	0
262399	261487	19301E	PARTICIPANT	\N	PRESENT	0
262400	261487	08024S	PARTICIPANT	\N	PRESENT	0
262401	261487	08009T	PARTICIPANT	\N	PRESENT	0
262402	261487	19503N	PARTICIPANT	\N	PRESENT	0
262403	261487	11012A	PARTICIPANT	\N	PRESENT	0
262404	261487	14227Q	PARTICIPANT	\N	PRESENT	0
262405	261487	08056B	PARTICIPANT	\N	PRESENT	0
262406	261487	11104D	PARTICIPANT	\N	PRESENT	0
262407	261487	14261S	PARTICIPANT	\N	PRESENT	0
262408	261487	11103C	PARTICIPANT	\N	PRESENT	0
262409	261487	14105F	PARTICIPANT	\N	PRESENT	0
262410	261487	14115H	PARTICIPANT	\N	PRESENT	0
262411	261487	19467C	PARTICIPANT	\N	PRESENT	0
262412	261487	19415P	PARTICIPANT	\N	PRESENT	0
262413	261487	95062K	PARTICIPANT	\N	PRESENT	0
262414	261487	99004R	PARTICIPANT	\N	PRESENT	0
262415	261487	07029T	PARTICIPANT	\N	PRESENT	0
262416	261487	14051J	PARTICIPANT	\N	PRESENT	0
262417	261487	80027E	PARTICIPANT	\N	PRESENT	0
262418	261487	08055A	PARTICIPANT	\N	PRESENT	0
262419	261487	19549D	PARTICIPANT	\N	PRESENT	0
262420	261487	14039A	PARTICIPANT	\N	PRESENT	0
262421	261487	11045K	PARTICIPANT	\N	PRESENT	0
262422	261487	19525U	PARTICIPANT	\N	PRESENT	0
262423	261487	19551W	PARTICIPANT	\N	PRESENT	0
262424	261487	08019V	PARTICIPANT	\N	PRESENT	0
262425	261487	14038Y	PARTICIPANT	\N	PRESENT	0
262426	261487	19747H	PARTICIPANT	\N	PRESENT	0
262427	261487	17779H	PARTICIPANT	\N	PRESENT	0
262428	261487	19739H	PARTICIPANT	\N	PRESENT	0
262429	261487	19441R	PARTICIPANT	\N	PRESENT	0
262430	261487	19333N	PARTICIPANT	\N	PRESENT	0
262431	261487	04085P	PARTICIPANT	\N	PRESENT	0
262432	261487	95030B	PARTICIPANT	\N	PRESENT	0
262434	261487	19695N	PARTICIPANT	\N	PRESENT	0
262436	261487	19563B	PARTICIPANT	\N	PRESENT	0
262437	261487	14267Y	PARTICIPANT	\N	PRESENT	0
262438	261487	97011G	PARTICIPANT	\N	PRESENT	0
262439	261487	19347U	PARTICIPANT	\N	PRESENT	0
262440	261487	14042U	PARTICIPANT	\N	PRESENT	0
262441	261487	19383Y	PARTICIPANT	\N	PRESENT	0
262442	261487	19631V	PARTICIPANT	\N	PRESENT	0
262443	261487	19527W	PARTICIPANT	\N	PRESENT	0
262444	261487	14031R	PARTICIPANT	\N	PRESENT	0
262445	261487	14219Q	PARTICIPANT	\N	PRESENT	0
262446	261487	14103D	PARTICIPANT	\N	PRESENT	0
262447	261487	14265W	PARTICIPANT	\N	PRESENT	0
262448	261487	19629C	PARTICIPANT	\N	PRESENT	0
262449	261487	19387D	PARTICIPANT	\N	PRESENT	0
262450	261487	11067R	PARTICIPANT	\N	PRESENT	0
262451	261487	19599P	PARTICIPANT	\N	PRESENT	0
262452	261487	19723Y	PARTICIPANT	\N	PRESENT	0
262453	261487	18083K	PARTICIPANT	\N	PRESENT	0
262454	261487	08010L	PARTICIPANT	\N	PRESENT	0
262455	261487	19727D	PARTICIPANT	\N	PRESENT	0
262456	261487	19593H	PARTICIPANT	\N	PRESENT	0
262457	261487	14331P	PARTICIPANT	\N	PRESENT	0
262458	261487	14093U	PARTICIPANT	\N	PRESENT	0
262459	261487	17589D	PARTICIPANT	\N	PRESENT	0
262460	261487	14327T	PARTICIPANT	\N	PRESENT	0
262461	261487	14107H	PARTICIPANT	\N	PRESENT	0
262462	261487	14223L	PARTICIPANT	\N	PRESENT	0
262463	261487	11056N	PARTICIPANT	\N	PRESENT	0
262466	261487	14083S	PARTICIPANT	\N	PRESENT	0
262473	261487	19399H	PARTICIPANT	\N	PRESENT	0
262474	261487	14187A	PARTICIPANT	\N	PRESENT	0
262475	261487	19507S	PARTICIPANT	\N	PRESENT	0
262476	261487	14205J	PARTICIPANT	\N	PRESENT	0
262477	261487	19679N	PARTICIPANT	\N	PRESENT	0
262479	261092	95030B	PARTICIPANT	\N	PRESENT	0
262480	261092	04034C	PARTICIPANT	\N	PRESENT	0
262481	261092	01058X	PARTICIPANT	\N	PRESENT	0
262482	261092	04040A	PARTICIPANT	\N	PRESENT	0
262483	261092	16685X	PARTICIPANT	\N	PRESENT	0
262484	261092	04042C	PRESIDENT	0	PRESENT	0
262485	261092	11054L	PARTICIPANT	\N	PRESENT	0
262486	261092	11066Q	PARTICIPANT	\N	PRESENT	0
262487	261092	95037J	PARTICIPANT	\N	PRESENT	0
262488	261092	19421M	PARTICIPANT	\N	PRESENT	0
262489	261092	14193X	PARTICIPANT	\N	PRESENT	0
262490	261092	97011G	PARTICIPANT	\N	PRESENT	0
262491	261092	08061X	PARTICIPANT	\N	PRESENT	0
262492	261092	08047A	PARTICIPANT	\N	PRESENT	0
262493	261092	98029W	PARTICIPANT	\N	PRESENT	0
262494	261092	14097Y	PARTICIPANT	\N	PRESENT	0
262495	261092	08034U	PARTICIPANT	\N	PRESENT	0
262496	261092	14133K	PARTICIPANT	\N	PRESENT	0
262497	261092	11041F	PARTICIPANT	\N	PRESENT	0
262498	261092	14235Q	PARTICIPANT	\N	PRESENT	0
262499	261092	14105F	PARTICIPANT	\N	PRESENT	0
262500	261092	98022P	PARTICIPANT	\N	PRESENT	0
262501	261092	11064N	PARTICIPANT	\N	PRESENT	0
262502	261092	14267Y	PARTICIPANT	\N	PRESENT	0
262503	261092	98050T	PARTICIPANT	\N	PRESENT	0
262504	261092	14211G	PARTICIPANT	\N	PRESENT	0
262505	261092	08056B	PARTICIPANT	\N	PRESENT	0
262506	261092	01062T	PARTICIPANT	\N	PRESENT	0
262539	261003	08048B	PARTICIPANT	\N	EXCUSE	0
262756	262755	11053K	PARTICIPANT	\N	PRESENT	0
262757	262755	14159V	PARTICIPANT	\N	PRESENT	0
262758	262755	05012A	PARTICIPANT	\N	PRESENT	0
262791	261003	14195A	PARTICIPANT	\N	EXCUSE	0
263249	261490	14121F	PARTICIPANT	\N	PRESENT	0
263250	261490	19693L	PARTICIPANT	\N	PRESENT	0
263251	261490	96004D	PARTICIPANT	\N	PRESENT	0
263252	261490	98035U	PARTICIPANT	\N	PRESENT	0
263253	261490	14259Y	PARTICIPANT	\N	PRESENT	0
263254	261490	19565D	PARTICIPANT	\N	PRESENT	0
263256	261490	14135M	PARTICIPANT	\N	PRESENT	0
263257	261490	98022P	PARTICIPANT	\N	PRESENT	0
263259	261490	19705W	PARTICIPANT	\N	PRESENT	0
263260	261490	19707Y	PARTICIPANT	\N	PRESENT	0
263261	261490	19329S	PARTICIPANT	\N	PRESENT	0
263262	261490	08016S	PARTICIPANT	\N	PRESENT	0
263263	261490	14151M	PARTICIPANT	\N	PRESENT	0
263264	261490	01058X	PARTICIPANT	\N	PRESENT	0
263265	261490	14159V	PARTICIPANT	\N	PRESENT	0
263266	261490	19703U	PARTICIPANT	\N	PRESENT	0
263267	261490	14251Q	PARTICIPANT	\N	PRESENT	0
263268	261490	04071H	PARTICIPANT	\N	PRESENT	0
263269	261490	19643A	PARTICIPANT	\N	PRESENT	0
263270	261490	19687N	PARTICIPANT	\N	PRESENT	0
263271	261490	19347U	PARTICIPANT	\N	PRESENT	0
263272	261490	19695N	PARTICIPANT	\N	PRESENT	0
263273	261490	08020N	PARTICIPANT	\N	PRESENT	0
263274	261490	11054L	PARTICIPANT	\N	PRESENT	0
263276	261490	19715Y	PARTICIPANT	\N	PRESENT	0
263277	261490	11104D	PARTICIPANT	\N	PRESENT	0
263278	261490	11027H	PARTICIPANT	\N	PRESENT	0
263279	261490	14249W	PARTICIPANT	\N	PRESENT	0
243975	243974	14065Q	PARTICIPANT	\N	PRESENT	0
243976	243974	14231L	PARTICIPANT	\N	PRESENT	0
243977	243974	11083R	PARTICIPANT	\N	PRESENT	0
243978	243974	19649G	PARTICIPANT	\N	PRESENT	0
243979	243974	14097Y	PARTICIPANT	\N	PRESENT	0
243980	243974	19723Y	PARTICIPANT	\N	PRESENT	0
243981	243974	14059S	PARTICIPANT	\N	PRESENT	0
243982	243974	19503N	PARTICIPANT	\N	PRESENT	0
243983	243974	04043D	PARTICIPANT	\N	PRESENT	0
243984	243974	19735D	PARTICIPANT	\N	PRESENT	0
243985	243974	95062K	PARTICIPANT	\N	PRESENT	0
244016	242610	11097X	PARTICIPANT	\N	PRESENT	0
244017	242612	14042U	PARTICIPANT	\N	PRESENT	0
244018	242612	19727D	PARTICIPANT	\N	PRESENT	0
244019	242643	14042U	PARTICIPANT	\N	PRESENT	0
244020	242643	19727D	PARTICIPANT	\N	PRESENT	0
245599	240285	14215L	PARTICIPANT	\N	PRESENT	0
245600	240285	14237S	PARTICIPANT	\N	PRESENT	0
245601	240285	19669L	PARTICIPANT	\N	PRESENT	0
245602	240285	18083K	PARTICIPANT	\N	PRESENT	0
245603	240285	19467C	PARTICIPANT	\N	PRESENT	0
245604	240285	08010L	PARTICIPANT	\N	PRESENT	0
245605	240285	14071N	PARTICIPANT	\N	PRESENT	0
245606	240285	14033T	PARTICIPANT	\N	PRESENT	0
245607	240285	19703U	PARTICIPANT	\N	PRESENT	0
245608	240285	19647E	PARTICIPANT	\N	PRESENT	0
245609	240285	14217N	PARTICIPANT	\N	PRESENT	0
245610	240285	97011G	PARTICIPANT	\N	PRESENT	0
245611	240285	14179A	PARTICIPANT	\N	PRESENT	0
245612	240285	11045K	PARTICIPANT	\N	PRESENT	0
245614	240285	19729F	PARTICIPANT	\N	PRESENT	0
245615	240285	19507S	PARTICIPANT	\N	PRESENT	0
245617	240285	14030Q	PARTICIPANT	\N	PRESENT	0
245640	240285	14028W	PARTICIPANT	\N	PRESENT	0
245641	240285	11066Q	PARTICIPANT	\N	PRESENT	0
245642	240285	95063L	PARTICIPANT	\N	PRESENT	0
245643	240285	14267Y	PARTICIPANT	\N	PRESENT	0
245645	240285	14223L	PARTICIPANT	\N	PRESENT	0
245646	240285	14249W	PARTICIPANT	\N	PRESENT	0
246035	246034	19741B	PARTICIPANT	\N	PRESENT	0
246036	246034	14065Q	PARTICIPANT	\N	PRESENT	0
246037	246034	14030Q	PARTICIPANT	\N	PRESENT	0
246038	246034	19691J	PARTICIPANT	\N	PRESENT	0
246039	246034	95037J	PARTICIPANT	\N	PRESENT	0
246040	246034	98005N	PARTICIPANT	\N	PRESENT	0
246041	246034	01043Q	PARTICIPANT	\N	PRESENT	0
246042	246034	08053X	PARTICIPANT	\N	PRESENT	0
246043	246034	19369B	PARTICIPANT	\N	PRESENT	0
246044	246034	04070G	PARTICIPANT	\N	PRESENT	0
246045	246034	01034P	PARTICIPANT	\N	PRESENT	0
246046	245644	19441R	PARTICIPANT	\N	PRESENT	0
246047	245644	19689Q	PARTICIPANT	\N	PRESENT	0
246072	244313	19333N	PARTICIPANT	\N	PRESENT	0
246073	244313	19383Y	PARTICIPANT	\N	PRESENT	0
246074	244313	19701S	PARTICIPANT	\N	PRESENT	0
246075	244313	95062K	PARTICIPANT	\N	PRESENT	0
246076	244313	19549D	PARTICIPANT	\N	PRESENT	0
246077	244313	14219Q	PARTICIPANT	\N	PRESENT	0
246078	244313	14221J	PARTICIPANT	\N	PRESENT	0
246079	244313	19637C	PARTICIPANT	\N	PRESENT	0
246080	244313	17779H	PARTICIPANT	\N	PRESENT	0
246081	244313	18083K	PARTICIPANT	\N	PRESENT	0
246082	244313	19551W	PARTICIPANT	\N	PRESENT	0
246083	244313	14237S	PARTICIPANT	\N	PRESENT	0
246084	244313	80027E	PARTICIPANT	\N	PRESENT	0
246085	244313	19553Y	PARTICIPANT	\N	PRESENT	0
246086	244313	14051J	PARTICIPANT	\N	PRESENT	0
246087	244313	08060W	PARTICIPANT	\N	PRESENT	0
246088	244313	19503N	PARTICIPANT	\N	PRESENT	0
246089	244313	19347U	PARTICIPANT	\N	PRESENT	0
246090	244313	14157T	PARTICIPANT	\N	PRESENT	0
246091	244313	08024S	PARTICIPANT	\N	PRESENT	0
246092	244313	17637T	PARTICIPANT	\N	PRESENT	0
246093	244313	11065P	PARTICIPANT	\N	PRESENT	0
246094	244313	19525U	PARTICIPANT	\N	PRESENT	0
246095	244313	14038Y	PARTICIPANT	\N	PRESENT	0
246096	244313	19713W	PARTICIPANT	\N	PRESENT	0
246097	244313	14031R	PARTICIPANT	\N	PRESENT	0
246098	244313	14169X	PARTICIPANT	\N	PRESENT	0
246099	244313	15447F	PARTICIPANT	\N	PRESENT	0
246100	244313	14029X	PARTICIPANT	\N	PRESENT	0
246101	244313	19733B	PARTICIPANT	\N	PRESENT	0
246102	244313	08009T	PRESIDENT	0	PRESENT	0
246103	244313	19737F	PARTICIPANT	\N	PRESENT	0
246104	244313	04097T	PARTICIPANT	\N	PRESENT	0
246105	244313	19745F	PARTICIPANT	\N	PRESENT	0
246106	244313	05012A	PARTICIPANT	\N	EXCUSE	0
246107	244313	96004D	PARTICIPANT	\N	EXCUSE	0
246108	244313	19681G	PARTICIPANT	\N	EXCUSE	0
246109	244313	19599P	PARTICIPANT	\N	EXCUSE	0
247636	247635	07004J	PARTICIPANT	\N	PRESENT	0
247637	247635	10015M	PARTICIPANT	\N	PRESENT	0
247638	247635	14079W	PARTICIPANT	\N	PRESENT	0
253016	253013	08052W	PARTICIPANT	\N	PRESENT	0
250130	250129	04092N	PARTICIPANT	\N	PRESENT	0
250131	250129	14071N	PARTICIPANT	\N	PRESENT	0
250134	250133	04092N	PARTICIPANT	\N	PRESENT	0
250135	250133	14071N	PARTICIPANT	\N	PRESENT	0
250300	250299	19421M	PARTICIPANT	\N	PRESENT	0
251310	251309	08039A	PARTICIPANT	\N	PRESENT	0
251311	251309	04057K	PARTICIPANT	\N	PRESENT	0
251312	251309	19399H	PARTICIPANT	\N	PRESENT	0
251316	251315	08039A	PARTICIPANT	\N	PRESENT	0
251318	251315	19399H	PARTICIPANT	\N	PRESENT	0
251320	251315	04057K	PARTICIPANT	\N	PRESENT	0
251322	251315	11083R	PARTICIPANT	\N	PRESENT	0
251329	251328	08039A	PARTICIPANT	\N	PRESENT	0
251330	251328	08031R	PARTICIPANT	\N	PRESENT	0
251331	251328	04057K	PARTICIPANT	\N	PRESENT	0
251332	251328	14229S	PARTICIPANT	\N	PRESENT	0
251353	251352	04070G	PARTICIPANT	\N	PRESENT	0
251357	251356	04070G	PARTICIPANT	\N	PRESENT	0
253014	253013	14042U	PARTICIPANT	\N	PRESENT	0
253015	253013	04045F	PARTICIPANT	\N	PRESENT	0
253017	253013	08053X	PARTICIPANT	\N	PRESENT	0
253018	253013	19593H	PARTICIPANT	\N	PRESENT	0
253019	253013	11026G	PARTICIPANT	\N	PRESENT	0
253020	253013	14255U	PARTICIPANT	\N	PRESENT	0
253021	253013	01043Q	PARTICIPANT	\N	PRESENT	0
253022	253013	11049P	PARTICIPANT	\N	PRESENT	0
253025	253024	14239U	PARTICIPANT	\N	PRESENT	0
253026	253024	04033B	PARTICIPANT	\N	PRESENT	0
269088	256504	19651A	PARTICIPANT	\N	PRESENT	0
269092	263464	19687N	PARTICIPANT	\N	PRESENT	0
269093	263464	14197C	PARTICIPANT	\N	PRESENT	0
269094	263464	08058D	PARTICIPANT	\N	PRESENT	0
269095	263464	14021P	PARTICIPANT	\N	PRESENT	0
269096	263464	11066Q	PARTICIPANT	\N	PRESENT	0
269097	263464	08014Q	PARTICIPANT	\N	PRESENT	0
269072	269043	04035D	PARTICIPANT	\N	PRESENT	0
269073	269043	14073Q	PARTICIPANT	\N	PRESENT	0
269074	269043	11045K	PARTICIPANT	\N	PRESENT	0
269075	269043	08043V	PARTICIPANT	\N	PRESENT	0
269076	269043	19693L	PARTICIPANT	\N	PRESENT	0
269077	269043	14030Q	PARTICIPANT	\N	PRESENT	0
269078	269043	19731Y	PARTICIPANT	\N	PRESENT	0
269079	269043	14251Q	PARTICIPANT	\N	PRESENT	0
269080	269043	19735D	PARTICIPANT	\N	PRESENT	0
269081	269043	11109J	PARTICIPANT	\N	PRESENT	0
269082	269043	14109K	PARTICIPANT	\N	PRESENT	0
269083	269043	11104D	PARTICIPANT	\N	PRESENT	0
269084	269043	19749K	PARTICIPANT	\N	PRESENT	0
269085	269043	04018C	PARTICIPANT	\N	PRESENT	0
269086	269043	19621T	PARTICIPANT	\N	PRESENT	0
269087	263464	11077T	PARTICIPANT	\N	PRESENT	0
269098	263464	11074Q	PARTICIPANT	\N	PRESENT	0
269099	263464	08011M	PARTICIPANT	\N	PRESENT	0
269100	263464	19349W	PARTICIPANT	\N	PRESENT	0
269101	263464	19659J	PARTICIPANT	\N	PRESENT	0
269102	263464	14107H	PARTICIPANT	\N	PRESENT	0
269103	263464	19545Y	PARTICIPANT	\N	PRESENT	0
269104	263464	19387D	PARTICIPANT	\N	PRESENT	0
269105	263464	19629C	PARTICIPANT	\N	PRESENT	0
269106	263464	19543W	PARTICIPANT	\N	PRESENT	0
269107	263464	04034C	PARTICIPANT	\N	PRESENT	0
269108	263464	19583F	PARTICIPANT	\N	PRESENT	0
269109	263464	11012A	PARTICIPANT	\N	PRESENT	0
269110	263464	14267Y	PARTICIPANT	\N	PRESENT	0
269111	263464	01048V	PARTICIPANT	\N	PRESENT	0
269112	263464	19443T	PARTICIPANT	\N	PRESENT	0
269113	263464	01057W	PARTICIPANT	\N	PRESENT	0
269114	263464	14119M	PARTICIPANT	\N	PRESENT	0
269115	263464	19415P	PARTICIPANT	\N	PRESENT	0
269116	263464	19507S	PARTICIPANT	\N	PRESENT	0
269117	263464	07029T	PARTICIPANT	\N	PRESENT	0
269118	263464	14105F	PARTICIPANT	\N	PRESENT	0
269119	263464	98018T	PARTICIPANT	\N	PRESENT	0
269120	263464	97011G	PARTICIPANT	\N	PRESENT	0
269121	263464	19383Y	PARTICIPANT	\N	PRESENT	0
255674	240320	14103D	PARTICIPANT	\N	PRESENT	0
255675	240320	04038G	PARTICIPANT	\N	PRESENT	0
255676	240320	19593H	PARTICIPANT	\N	PRESENT	0
255677	240320	19347U	PARTICIPANT	\N	PRESENT	0
255678	240320	80013X	PARTICIPANT	\N	PRESENT	0
255679	240320	14151M	PARTICIPANT	\N	PRESENT	0
255680	240320	19503N	PARTICIPANT	\N	PRESENT	0
255681	240320	11067R	PARTICIPANT	\N	PRESENT	0
255682	240320	14281W	PARTICIPANT	\N	PRESENT	0
255683	240320	19333N	PARTICIPANT	\N	PRESENT	0
255684	240320	19727D	PARTICIPANT	\N	PRESENT	0
255685	240320	19651A	PARTICIPANT	\N	PRESENT	0
255686	240320	19719D	PARTICIPANT	\N	PRESENT	0
255687	240320	11065P	PARTICIPANT	\N	PRESENT	0
255688	240320	14231L	PARTICIPANT	\N	PRESENT	0
255689	240320	19737F	PARTICIPANT	\N	PRESENT	0
255690	240320	19713W	PARTICIPANT	\N	PRESENT	0
255691	240320	01024M	PARTICIPANT	\N	PRESENT	0
255692	240320	19749K	PARTICIPANT	\N	PRESENT	0
255693	240320	08056B	PARTICIPANT	\N	PRESENT	0
255694	240320	14031R	PARTICIPANT	\N	PRESENT	0
255695	240320	14169X	PARTICIPANT	\N	PRESENT	0
255696	240320	14033T	PARTICIPANT	\N	PRESENT	0
255697	240320	14157T	PARTICIPANT	\N	PRESENT	0
255698	240320	19575F	PARTICIPANT	\N	PRESENT	0
255699	240320	19711U	PARTICIPANT	\N	PRESENT	0
255700	240320	04049K	PARTICIPANT	\N	PRESENT	0
255701	240320	14213J	PARTICIPANT	\N	PRESENT	0
255702	240320	14217N	PARTICIPANT	\N	PRESENT	0
255703	240320	14331P	PARTICIPANT	\N	PRESENT	0
255704	240320	14053L	PARTICIPANT	\N	PRESENT	0
255705	240320	14071N	PARTICIPANT	\N	PRESENT	0
255706	240320	19545Y	PARTICIPANT	\N	PRESENT	0
255707	240320	19387D	PARTICIPANT	\N	PRESENT	0
255708	240320	95063L	PARTICIPANT	\N	PRESENT	0
255709	240320	97011G	PARTICIPANT	\N	PRESENT	0
255710	240320	14357A	PARTICIPANT	\N	PRESENT	0
255711	240320	04033B	PARTICIPANT	\N	PRESENT	0
255712	240320	17583W	PARTICIPANT	\N	PRESENT	0
255713	240320	19747H	PARTICIPANT	\N	PRESENT	0
255714	240320	17637T	PARTICIPANT	\N	PRESENT	0
255715	240320	19687N	PARTICIPANT	\N	PRESENT	0
255716	240320	04085P	PARTICIPANT	\N	PRESENT	0
255717	240320	14089Y	PARTICIPANT	\N	PRESENT	0
255718	240320	14215L	PARTICIPANT	\N	PRESENT	0
255719	240320	14083S	PARTICIPANT	\N	PRESENT	0
255720	240320	19693L	PARTICIPANT	\N	PRESENT	0
255721	240320	19447X	PARTICIPANT	\N	PRESENT	0
255722	240320	10006L	PARTICIPANT	\N	PRESENT	0
255723	240320	14026U	PARTICIPANT	\N	PRESENT	0
255725	250069	08024S	PARTICIPANT	\N	PRESENT	0
255672	240320	14034U	PARTICIPANT	\N	PRESENT	0
255673	240320	11048N	PARTICIPANT	\N	PRESENT	0
255726	250069	19551W	PARTICIPANT	\N	PRESENT	0
255727	250069	19349W	PARTICIPANT	\N	PRESENT	0
255728	250069	19737F	PARTICIPANT	\N	PRESENT	0
255995	255994	11027H	PARTICIPANT	\N	PRESENT	0
256506	256505	96004D	PARTICIPANT	\N	PRESENT	0
256512	256509	96004D	PARTICIPANT	\N	PRESENT	0
256513	256509	14237S	PARTICIPANT	\N	PRESENT	0
256514	256509	14001X	PARTICIPANT	\N	PRESENT	0
256515	256509	10015M	PARTICIPANT	\N	PRESENT	0
256906	256007	19565D	PARTICIPANT	\N	PRESENT	0
256907	256007	14041T	PARTICIPANT	\N	PRESENT	0
256908	256007	19593H	PARTICIPANT	\N	PRESENT	0
256909	256007	14235Q	PARTICIPANT	\N	PRESENT	0
256910	256007	04085P	PARTICIPANT	\N	PRESENT	0
256911	256007	14033T	PARTICIPANT	\N	PRESENT	0
256912	256007	14133K	PARTICIPANT	\N	PRESENT	0
256913	256007	95063L	PARTICIPANT	\N	PRESENT	0
256914	256007	04045F	PARTICIPANT	\N	PRESENT	0
256915	256007	92040Q	PARTICIPANT	\N	PRESENT	0
256916	256007	19651A	PARTICIPANT	\N	PRESENT	0
256917	256007	11083R	PARTICIPANT	\N	PRESENT	0
256918	256007	19637C	PARTICIPANT	\N	PRESENT	0
256919	256007	19349W	PARTICIPANT	\N	PRESENT	0
256920	256007	19543W	PARTICIPANT	\N	PRESENT	0
256921	256007	19269X	PARTICIPANT	\N	PRESENT	0
256922	256007	14253S	PARTICIPANT	\N	PRESENT	0
256923	256007	19697Q	PARTICIPANT	\N	PRESENT	0
256924	256007	08021P	PARTICIPANT	\N	PRESENT	0
256925	256007	14039A	PARTICIPANT	\N	PRESENT	0
256926	256007	19659J	PARTICIPANT	\N	PRESENT	0
256927	256007	08069G	PARTICIPANT	\N	PRESENT	0
256928	256007	11072N	PARTICIPANT	\N	PRESENT	0
256929	256007	19301E	PARTICIPANT	\N	PRESENT	0
256930	256007	14259Y	PARTICIPANT	\N	PRESENT	0
256931	256007	19575F	PARTICIPANT	\N	PRESENT	0
256932	256007	11077T	PARTICIPANT	\N	PRESENT	0
256933	256007	04059M	PARTICIPANT	\N	PRESENT	0
256934	256007	08068F	PARTICIPANT	\N	PRESENT	0
256935	256007	15447F	PARTICIPANT	\N	PRESENT	0
256936	256007	14051J	PARTICIPANT	\N	PRESENT	0
256937	256007	11027H	PARTICIPANT	\N	PRESENT	0
256938	256007	01048V	PARTICIPANT	\N	PRESENT	0
256939	256007	14229S	PARTICIPANT	\N	PRESENT	0
256940	256007	01028R	PARTICIPANT	\N	PRESENT	0
256941	256007	08028W	PARTICIPANT	\N	PRESENT	0
256942	256007	08052W	PARTICIPANT	\N	PRESENT	0
256943	256007	04071H	PARTICIPANT	\N	PRESENT	0
256944	256007	11043H	PARTICIPANT	\N	PRESENT	0
256945	256007	08055A	PARTICIPANT	\N	PRESENT	0
256946	256007	08016S	PARTICIPANT	\N	PRESENT	0
256947	256007	14223L	PARTICIPANT	\N	PRESENT	0
256948	256007	14107H	PARTICIPANT	\N	PRESENT	0
256949	256007	08045X	PARTICIPANT	\N	PRESENT	0
256950	256007	87003B	PARTICIPANT	\N	PRESENT	0
256951	256007	11033F	PARTICIPANT	\N	PRESENT	0
256952	256007	14021P	PARTICIPANT	\N	PRESENT	0
256953	256007	19447X	PARTICIPANT	\N	PRESENT	0
256954	256007	14151M	PARTICIPANT	\N	PRESENT	0
256955	256007	14197C	PARTICIPANT	\N	PRESENT	0
256956	256007	98023Q	PARTICIPANT	\N	PRESENT	0
256957	256007	08024S	PARTICIPANT	\N	PRESENT	0
256958	256007	14028W	PARTICIPANT	\N	PRESENT	0
256959	256007	11048N	PARTICIPANT	\N	PRESENT	0
256960	256007	80013X	PARTICIPANT	\N	PRESENT	0
256961	256007	08038Y	PARTICIPANT	\N	PRESENT	0
256962	256007	08060W	PARTICIPANT	\N	PRESENT	0
256963	256007	14147R	PARTICIPANT	\N	PRESENT	0
256964	256007	01062T	PARTICIPANT	\N	PRESENT	0
256965	256007	14065Q	PARTICIPANT	\N	PRESENT	0
256966	256007	04049K	PARTICIPANT	\N	PRESENT	0
256967	256007	19549D	PARTICIPANT	\N	PRESENT	0
256968	256007	11066Q	PARTICIPANT	\N	PRESENT	0
256969	256007	14105F	PARTICIPANT	\N	PRESENT	0
256970	256007	08043V	PARTICIPANT	\N	PRESENT	0
256971	256007	11104D	PARTICIPANT	\N	PRESENT	0
256972	256007	14281W	PARTICIPANT	\N	PRESENT	0
256973	256007	08012N	PARTICIPANT	\N	PRESENT	0
256974	256007	80027E	PARTICIPANT	\N	PRESENT	0
256975	256007	14213J	PARTICIPANT	\N	PRESENT	0
256976	256007	19729F	PARTICIPANT	\N	PRESENT	0
256977	256007	19727D	PARTICIPANT	\N	PRESENT	0
256978	256007	19649G	PARTICIPANT	\N	PRESENT	0
256979	256007	19693L	PARTICIPANT	\N	PRESENT	0
256980	256007	19399H	PARTICIPANT	\N	PRESENT	0
256981	256007	08058D	PARTICIPANT	\N	PRESENT	0
256982	256007	08019V	PARTICIPANT	\N	PRESENT	0
256983	256007	17779H	PARTICIPANT	\N	PRESENT	0
256984	256007	14119M	PARTICIPANT	\N	PRESENT	0
256985	256007	14121F	PARTICIPANT	\N	PRESENT	0
256986	256007	14085U	PARTICIPANT	\N	PRESENT	0
256987	256007	11045K	PARTICIPANT	\N	PRESENT	0
256988	256007	07029T	PARTICIPANT	\N	PRESENT	0
256989	256007	19657G	PARTICIPANT	\N	PRESENT	0
256990	256007	19525U	PARTICIPANT	\N	PRESENT	0
256991	256007	08015R	PARTICIPANT	\N	PRESENT	0
256992	256007	11110B	PARTICIPANT	\N	PRESENT	0
256993	256007	14081Q	PARTICIPANT	\N	PRESENT	0
256994	256007	19707Y	PARTICIPANT	\N	PRESENT	0
256995	256007	11041F	PARTICIPANT	\N	PRESENT	0
256996	256007	14207L	PARTICIPANT	\N	PRESENT	0
256997	256007	19725B	PARTICIPANT	\N	PRESENT	0
256998	256007	98050T	PARTICIPANT	\N	PRESENT	0
256999	256007	08014Q	PARTICIPANT	\N	PRESENT	0
257000	256007	19333N	PARTICIPANT	\N	PRESENT	0
257001	256007	14059S	PARTICIPANT	\N	PRESENT	0
257002	256007	19531S	PARTICIPANT	\N	PRESENT	0
257003	256007	14001X	PARTICIPANT	\N	PRESENT	0
257004	256007	14227Q	PARTICIPANT	\N	PRESENT	0
257005	256007	19683J	PARTICIPANT	\N	PRESENT	0
257006	256007	11109J	PARTICIPANT	\N	PRESENT	0
257007	256007	14329V	PARTICIPANT	\N	PRESENT	0
257008	256007	14357A	PARTICIPANT	\N	PRESENT	0
257009	256007	11054L	PARTICIPANT	\N	PRESENT	0
257010	256007	19669L	PARTICIPANT	\N	PRESENT	0
257011	256007	19689Q	PARTICIPANT	\N	PRESENT	0
242693	241088	19367Y	PARTICIPANT	\N	EXCUSE	0
245159	244124	19575F	PARTICIPANT	\N	PRESENT	0
245160	244124	19367Y	PARTICIPANT	\N	PRESENT	0
245161	244124	11103C	PARTICIPANT	\N	PRESENT	0
245162	244124	14195A	PARTICIPANT	\N	PRESENT	0
245163	244124	08052W	PRESIDENT	1	PRESENT	0
245164	244124	14217N	PARTICIPANT	\N	PRESENT	0
245165	244124	14042U	PARTICIPANT	\N	PRESENT	0
245166	244124	14281W	PARTICIPANT	\N	PRESENT	0
245167	244124	19521Q	PARTICIPANT	\N	PRESENT	0
245168	244124	19727D	PARTICIPANT	\N	PRESENT	0
245169	244124	19715Y	PARTICIPANT	\N	PRESENT	0
245170	244124	17779H	PARTICIPANT	\N	PRESENT	0
245171	244124	14223L	PARTICIPANT	\N	PRESENT	0
245172	244124	04092N	PRESIDENT	0	PRESENT	0
245173	244124	14071N	PARTICIPANT	\N	PRESENT	0
245174	244124	11045K	PARTICIPANT	\N	PRESENT	0
245175	244124	11097X	PARTICIPANT	\N	PRESENT	0
245176	244124	19527W	PARTICIPANT	\N	PRESENT	0
245177	244124	08048B	PARTICIPANT	\N	EXCUSE	0
245178	244124	14213J	PARTICIPANT	\N	EXCUSE	0
245179	244124	19703U	PARTICIPANT	\N	EXCUSE	0
247301	244810	04085P	PARTICIPANT	\N	PRESENT	0
247302	244810	08058D	PRESIDENT	0	PRESENT	0
247303	244810	11053K	PARTICIPANT	\N	PRESENT	0
247304	244810	04086Q	PARTICIPANT	\N	PRESENT	0
247305	244810	04071H	PARTICIPANT	\N	PRESENT	0
247306	244810	08035V	PARTICIPANT	\N	PRESENT	0
247307	244810	11049P	PARTICIPANT	\N	PRESENT	0
247308	244810	14097Y	PARTICIPANT	\N	PRESENT	0
247309	244810	19729F	PARTICIPANT	\N	PRESENT	0
247310	244810	19581D	PARTICIPANT	\N	PRESENT	0
247311	244810	19443T	PARTICIPANT	\N	PRESENT	0
247312	244810	19703U	PARTICIPANT	\N	PRESENT	0
247313	244810	19251M	PARTICIPANT	\N	PRESENT	0
251868	251307	08068F	PARTICIPANT	\N	PRESENT	0
251869	251307	14133K	PARTICIPANT	\N	PRESENT	0
251870	251307	14079W	PARTICIPANT	\N	PRESENT	0
251871	251307	19349W	PARTICIPANT	\N	PRESENT	0
251872	251307	19695N	PARTICIPANT	\N	PRESENT	0
251873	251307	14219Q	PARTICIPANT	\N	PRESENT	0
251874	251307	19251M	PARTICIPANT	\N	PRESENT	0
253825	240316	08016S	PARTICIPANT	\N	PRESENT	0
251876	251307	08028W	PRESIDENT	0	PRESENT	0
251877	251307	19631V	PARTICIPANT	\N	PRESENT	0
251878	251307	01043Q	PARTICIPANT	\N	PRESENT	0
251910	251308	08068F	PARTICIPANT	\N	PRESENT	0
252042	252036	96004D	PRESIDENT	0	PRESENT	0
251912	251308	19737F	PARTICIPANT	\N	PRESENT	0
251913	251308	19349W	PARTICIPANT	\N	PRESENT	0
251914	251308	14219Q	PARTICIPANT	\N	PRESENT	0
251915	251308	19695N	PARTICIPANT	\N	PRESENT	0
251916	251308	19251M	PARTICIPANT	\N	PRESENT	0
252238	252036	14329V	PARTICIPANT	\N	PRESENT	0
252046	252036	14357A	PARTICIPANT	\N	PRESENT	0
251919	251308	08028W	PRESIDENT	0	PRESENT	0
251920	251308	19637C	PARTICIPANT	\N	PRESENT	0
252040	252036	14065Q	PARTICIPANT	\N	PRESENT	0
252048	252036	14079W	PARTICIPANT	\N	PRESENT	0
252051	252036	11083R	PARTICIPANT	\N	PRESENT	0
252053	252036	14033T	PARTICIPANT	\N	PRESENT	0
252058	252036	95037J	PARTICIPANT	\N	PRESENT	0
252060	252036	08044W	PARTICIPANT	\N	PRESENT	0
252065	252036	14097Y	PARTICIPANT	\N	PRESENT	0
252066	252036	14073Q	PARTICIPANT	\N	PRESENT	0
252068	252036	19563B	PARTICIPANT	\N	PRESENT	0
252070	252036	19593H	PARTICIPANT	\N	EXCUSE	0
252075	252036	14135M	PARTICIPANT	\N	PRESENT	0
252077	252036	14331P	PARTICIPANT	\N	PRESENT	0
252080	252036	10015M	PARTICIPANT	\N	PRESENT	0
252086	252036	98035U	PARTICIPANT	\N	PRESENT	0
252161	252036	14001X	PARTICIPANT	\N	EXCUSE	0
252165	252036	04049K	PARTICIPANT	\N	PRESENT	0
252175	252036	08047A	PARTICIPANT	\N	PRESENT	0
252211	252036	19725B	PARTICIPANT	\N	PRESENT	0
252240	252036	14265W	PARTICIPANT	\N	PRESENT	0
252242	252036	14051J	PARTICIPANT	\N	PRESENT	0
252246	252036	14187A	PARTICIPANT	\N	PRESENT	0
252251	252036	08015R	PARTICIPANT	\N	PRESENT	0
252253	252036	14261S	PARTICIPANT	\N	PRESENT	0
252257	252036	14121F	PARTICIPANT	\N	PRESENT	0
252259	252036	14083S	PARTICIPANT	\N	PRESENT	0
252262	252036	14157T	PARTICIPANT	\N	PRESENT	0
252268	252036	04088S	PARTICIPANT	\N	PRESENT	0
252274	252036	19521Q	PARTICIPANT	\N	PRESENT	0
252275	252036	19671E	PARTICIPANT	\N	PRESENT	0
252278	252036	19575F	PARTICIPANT	\N	PRESENT	0
252279	252036	14255U	PARTICIPANT	\N	PRESENT	0
253823	240316	08055A	PARTICIPANT	\N	PRESENT	0
253824	240316	11049P	PARTICIPANT	\N	PRESENT	0
253826	240316	08045X	PARTICIPANT	\N	PRESENT	0
253827	240316	14107H	PARTICIPANT	\N	PRESENT	0
253828	240316	14225N	PARTICIPANT	\N	PRESENT	0
253829	240316	12016W	PARTICIPANT	\N	PRESENT	0
253830	240316	14151M	PARTICIPANT	\N	PRESENT	0
253831	240316	14197C	PARTICIPANT	\N	PRESENT	0
253832	240316	14199E	PARTICIPANT	\N	PRESENT	0
253833	240316	19649G	PARTICIPANT	\N	PRESENT	0
253834	240316	14028W	PARTICIPANT	\N	PRESENT	0
253835	240316	14253S	PARTICIPANT	\N	PRESENT	0
253836	240316	08024S	PARTICIPANT	\N	PRESENT	0
253837	240316	19647E	PARTICIPANT	\N	PRESENT	0
253838	240316	19577H	PARTICIPANT	\N	PRESENT	0
253839	240316	08061X	PARTICIPANT	\N	PRESENT	0
253840	240316	80013X	PARTICIPANT	\N	PRESENT	0
253841	240316	14147R	PARTICIPANT	\N	PRESENT	0
253842	240316	07004J	PARTICIPANT	\N	PRESENT	0
253843	240316	08038Y	PARTICIPANT	\N	PRESENT	0
253844	240316	11070L	PARTICIPANT	\N	PRESENT	0
253845	240316	11048N	PARTICIPANT	\N	PRESENT	0
253846	240316	95067Q	PARTICIPANT	\N	PRESENT	0
253847	240316	08060W	PARTICIPANT	\N	PRESENT	0
253848	240316	01062T	PARTICIPANT	\N	PRESENT	0
253849	240316	14105F	PARTICIPANT	\N	PRESENT	0
253850	240316	08044W	PARTICIPANT	\N	PRESENT	0
253851	240316	19447X	PARTICIPANT	\N	PRESENT	0
253852	240316	19573D	PARTICIPANT	\N	PRESENT	0
253853	240316	14255U	PARTICIPANT	\N	PRESENT	0
253854	240316	14065Q	PARTICIPANT	\N	PRESENT	0
253855	240316	92040Q	PARTICIPANT	\N	PRESENT	0
253856	240316	11066Q	PARTICIPANT	\N	PRESENT	0
253857	240316	14119M	PARTICIPANT	\N	PRESENT	0
253858	240316	14251Q	PARTICIPANT	\N	PRESENT	0
253859	240316	19691J	PARTICIPANT	\N	PRESENT	0
253860	240316	08058D	PARTICIPANT	\N	PRESENT	0
253861	240316	08056B	PARTICIPANT	\N	PRESENT	0
253862	240316	08043V	PARTICIPANT	\N	PRESENT	0
253863	240316	11104D	PARTICIPANT	\N	PRESENT	0
253864	240316	14281W	PARTICIPANT	\N	PRESENT	0
253865	240316	04049K	PARTICIPANT	\N	PRESENT	0
253866	240316	01024M	PARTICIPANT	\N	PRESENT	0
253867	240316	14021P	PARTICIPANT	\N	PRESENT	0
253868	240316	11053K	PARTICIPANT	\N	PRESENT	0
253869	240316	14135M	PARTICIPANT	\N	PRESENT	0
253870	240316	01034P	PARTICIPANT	\N	PRESENT	0
253871	240316	08012N	PARTICIPANT	\N	PRESENT	0
253872	240316	14029X	PARTICIPANT	\N	PRESENT	0
253873	240316	08047A	PARTICIPANT	\N	PRESENT	0
253874	240316	19727D	PARTICIPANT	\N	PRESENT	0
253875	240316	19531S	PARTICIPANT	\N	PRESENT	0
253876	240316	19489J	PARTICIPANT	\N	PRESENT	0
253877	240316	19347U	PARTICIPANT	\N	PRESENT	0
253878	240316	17779H	PARTICIPANT	\N	PRESENT	0
253879	240316	19723Y	PARTICIPANT	\N	PRESENT	0
253880	240316	14121F	PARTICIPANT	\N	PRESENT	0
253881	240316	01025N	PARTICIPANT	\N	PRESENT	0
253882	240316	14085U	PARTICIPANT	\N	PRESENT	0
253883	240316	19507S	PARTICIPANT	\N	PRESENT	0
253884	240316	08035V	PARTICIPANT	\N	PRESENT	0
253885	240316	08053X	PARTICIPANT	\N	PRESENT	0
253886	240316	04033B	PARTICIPANT	\N	PRESENT	0
253887	240316	08017T	PARTICIPANT	\N	PRESENT	0
253888	240316	14083S	PARTICIPANT	\N	PRESENT	0
253889	240316	14071N	PARTICIPANT	\N	PRESENT	0
253890	240316	14073Q	PARTICIPANT	\N	PRESENT	0
253891	240316	19467C	PARTICIPANT	\N	PRESENT	0
253892	240316	19525U	PARTICIPANT	\N	PRESENT	0
253893	240316	19707Y	PARTICIPANT	\N	PRESENT	0
253894	240316	08009T	PARTICIPANT	\N	PRESENT	0
253895	240316	14081Q	PARTICIPANT	\N	PRESENT	0
253896	240316	18083K	PARTICIPANT	\N	PRESENT	0
253898	240316	19415P	PARTICIPANT	\N	PRESENT	0
253899	240316	11041F	PARTICIPANT	\N	PRESENT	0
253900	240316	14033T	PARTICIPANT	\N	PRESENT	0
253901	240316	14207L	PARTICIPANT	\N	PRESENT	0
253902	240316	08014Q	PARTICIPANT	\N	PRESENT	0
253903	240316	19333N	PARTICIPANT	\N	PRESENT	0
253904	240316	08019V	PARTICIPANT	\N	PRESENT	0
258920	258919	14255U	PARTICIPANT	\N	PRESENT	0
260195	258752	19717B	PARTICIPANT	\N	PRESENT	0
260196	258752	19715Y	PARTICIPANT	\N	EXCUSE	0
260197	258752	14097Y	PARTICIPANT	\N	PRESENT	0
260198	258752	14275Y	PARTICIPANT	\N	PRESENT	0
260199	258752	95062K	PARTICIPANT	\N	EXCUSE	0
260200	258752	14331P	PARTICIPANT	\N	PRESENT	0
260201	258752	04043D	PARTICIPANT	\N	PRESENT	0
260202	258752	08019V	PRESIDENT	0	PRESENT	0
261499	261498	14089Y	PARTICIPANT	\N	PRESENT	0
261567	261003	14028W	PARTICIPANT	\N	EXCUSE	0
261602	261003	19735D	PARTICIPANT	\N	EXCUSE	0
263280	261490	01062T	PARTICIPANT	\N	PRESENT	0
263281	261490	19527W	PARTICIPANT	\N	PRESENT	0
263282	261490	11040E	PARTICIPANT	\N	PRESENT	0
263283	261490	19647E	PARTICIPANT	\N	PRESENT	0
263284	261490	08035V	PARTICIPANT	\N	PRESENT	0
263285	261490	08012N	PARTICIPANT	\N	PRESENT	0
263286	261490	14021P	PARTICIPANT	\N	PRESENT	0
263287	261490	04085P	PARTICIPANT	\N	PRESENT	0
263288	261490	04038G	PARTICIPANT	\N	PRESENT	0
263289	261490	08061X	PARTICIPANT	\N	PRESENT	0
263290	261490	95063L	PARTICIPANT	\N	PRESENT	0
263291	261490	19651A	PARTICIPANT	\N	PRESENT	0
263292	261490	11083R	PARTICIPANT	\N	PRESENT	0
263293	258968	11097X	PARTICIPANT	\N	PRESENT	0
263294	261490	19269X	PARTICIPANT	\N	PRESENT	0
263295	258968	98024R	PARTICIPANT	\N	PRESENT	0
263296	261490	19543W	PARTICIPANT	\N	PRESENT	0
263297	258968	11067R	PARTICIPANT	\N	PRESENT	0
263298	261490	08021P	PARTICIPANT	\N	PRESENT	0
263299	261490	11072N	PARTICIPANT	\N	PRESENT	0
263300	261490	14055N	PARTICIPANT	\N	PRESENT	0
263301	261490	19745F	PARTICIPANT	\N	PRESENT	0
263302	261490	17637T	PARTICIPANT	\N	PRESENT	0
263303	261490	19711U	PARTICIPANT	\N	PRESENT	0
263304	261490	04008A	PARTICIPANT	\N	PRESENT	0
263305	261490	11012A	PARTICIPANT	\N	PRESENT	0
263306	261490	08031R	PARTICIPANT	\N	PRESENT	0
263307	261490	88008L	PARTICIPANT	\N	PRESENT	0
263308	261490	08011M	PARTICIPANT	\N	PRESENT	0
263309	261490	08049C	PARTICIPANT	\N	PRESENT	0
263310	261490	99004R	PARTICIPANT	\N	PRESENT	0
263311	261490	19679N	PARTICIPANT	\N	PRESENT	0
263312	261490	19387D	PARTICIPANT	\N	PRESENT	0
263313	261490	14123H	PARTICIPANT	\N	PRESENT	0
263314	261490	04042C	PARTICIPANT	\N	PRESENT	0
263315	261490	11065P	PARTICIPANT	\N	PRESENT	0
263316	261490	19681G	PARTICIPANT	\N	PRESENT	0
263317	261490	14241N	PARTICIPANT	\N	PRESENT	0
263318	261490	14093U	PARTICIPANT	\N	PRESENT	0
263319	261490	04057K	PARTICIPANT	\N	PRESENT	0
263320	261490	10015M	PARTICIPANT	\N	PRESENT	0
263321	261490	02002K	PARTICIPANT	\N	PRESENT	0
263322	261490	11043H	PARTICIPANT	\N	PRESENT	0
263323	261490	04059M	PARTICIPANT	\N	PRESENT	0
263324	261490	11077T	PARTICIPANT	\N	PRESENT	0
263325	261490	01057W	PARTICIPANT	\N	PRESENT	0
263326	261490	19673G	PARTICIPANT	\N	PRESENT	0
263327	261490	11074Q	PARTICIPANT	\N	PRESENT	0
263328	261490	08068F	PARTICIPANT	\N	PRESENT	0
263329	261490	11010L	PARTICIPANT	\N	PRESENT	0
263330	261490	01028R	PARTICIPANT	\N	PRESENT	0
263331	261490	14031R	PARTICIPANT	\N	PRESENT	0
263332	261490	08055A	PARTICIPANT	\N	PRESENT	0
263333	261490	19667J	PARTICIPANT	\N	PRESENT	0
263334	261490	19447X	PARTICIPANT	\N	PRESENT	0
263335	261490	14119M	PARTICIPANT	\N	PRESENT	0
263336	261490	19649G	PARTICIPANT	\N	PRESENT	0
263337	261490	92040Q	PARTICIPANT	\N	PRESENT	0
263338	261490	14038Y	PARTICIPANT	\N	PRESENT	0
263339	261490	19723Y	PARTICIPANT	\N	PRESENT	0
263340	261490	14065Q	PARTICIPANT	\N	PRESENT	0
263341	261490	19467C	PARTICIPANT	\N	PRESENT	0
263342	261490	18083K	PARTICIPANT	\N	PRESENT	0
263343	261490	19415P	PARTICIPANT	\N	PRESENT	0
263344	261490	08038Y	PARTICIPANT	\N	PRESENT	0
263345	261490	14033T	PARTICIPANT	\N	PRESENT	0
263838	263837	04042C	PARTICIPANT	\N	PRESENT	0
263839	263837	98018T	PARTICIPANT	\N	PRESENT	0
263840	263837	98029W	PARTICIPANT	\N	PRESENT	0
263841	263837	98022P	PARTICIPANT	\N	PRESENT	0
263843	263837	14097Y	PARTICIPANT	\N	PRESENT	0
263844	263837	08056B	PARTICIPANT	\N	PRESENT	0
263845	263837	11064N	PARTICIPANT	\N	PRESENT	0
263846	263837	14235Q	PARTICIPANT	\N	PRESENT	0
263857	261491	14033T	PARTICIPANT	\N	PRESENT	0
263851	263850	04049K	PRESIDENT	0	PRESENT	0
263852	263850	14030Q	PARTICIPANT	\N	PRESENT	0
263853	261491	14115H	PARTICIPANT	\N	PRESENT	0
263854	261491	19533U	PARTICIPANT	\N	PRESENT	0
263855	261491	19667J	PARTICIPANT	\N	PRESENT	0
263856	261491	14041T	PARTICIPANT	\N	PRESENT	0
263858	258758	19631V	PARTICIPANT	\N	PRESENT	0
263888	261491	19715Y	PARTICIPANT	\N	PRESENT	0
263898	261491	14217N	PARTICIPANT	\N	PRESENT	0
263899	261491	19335Q	PARTICIPANT	\N	PRESENT	0
263901	263900	14193X	PARTICIPANT	\N	PRESENT	0
263902	263900	14235Q	PARTICIPANT	\N	PRESENT	0
263904	263903	08058D	PARTICIPANT	\N	PRESENT	0
263906	261491	98022P	PARTICIPANT	\N	PRESENT	0
263907	261491	11064N	PARTICIPANT	\N	PRESENT	0
263912	263911	14255U	PARTICIPANT	\N	PRESENT	0
263913	263911	08053X	PARTICIPANT	\N	PRESENT	0
263914	263911	14079W	PARTICIPANT	\N	PRESENT	0
263915	263911	14089Y	PARTICIPANT	\N	PRESENT	0
263916	261491	08056B	PARTICIPANT	\N	PRESENT	0
263918	263917	04040A	PARTICIPANT	\N	PRESENT	0
263919	263917	01062T	PARTICIPANT	\N	PRESENT	0
263921	263920	04040A	PARTICIPANT	\N	PRESENT	0
263922	263920	01062T	PARTICIPANT	\N	PRESENT	0
263924	261491	08024S	PARTICIPANT	\N	PRESENT	0
263925	263923	04040A	PARTICIPANT	\N	PRESENT	0
263926	263923	01062T	PARTICIPANT	\N	PRESENT	0
263928	263927	11054L	PARTICIPANT	\N	PRESENT	0
263929	263927	11064N	PARTICIPANT	\N	PRESENT	0
263930	261491	14331P	PARTICIPANT	\N	PRESENT	0
263931	261491	17637T	PARTICIPANT	\N	PRESENT	0
263932	261491	14079W	PARTICIPANT	\N	PRESENT	0
263933	261491	07029T	PARTICIPANT	\N	PRESENT	0
263934	261491	19543W	PARTICIPANT	\N	PRESENT	0
264071	258757	19729F	PARTICIPANT	\N	EXCUSE	0
264072	258759	19729F	PARTICIPANT	\N	EXCUSE	0
264073	258758	19729F	PARTICIPANT	\N	EXCUSE	0
264106	258759	14038Y	PARTICIPANT	\N	EXCUSE	0
264107	258759	19329S	PARTICIPANT	\N	EXCUSE	0
264108	258759	14033T	PARTICIPANT	\N	EXCUSE	0
264109	258759	14039A	PARTICIPANT	\N	EXCUSE	0
264110	258757	14033T	PARTICIPANT	\N	EXCUSE	0
264111	258757	19329S	PARTICIPANT	\N	EXCUSE	0
264112	258757	14157T	PARTICIPANT	\N	EXCUSE	0
264114	260853	19533U	PARTICIPANT	\N	PRESENT	0
264118	264117	19621T	PARTICIPANT	\N	PRESENT	0
264119	264117	08031R	PARTICIPANT	\N	PRESENT	0
264130	264129	89017R	PARTICIPANT	\N	PRESENT	0
264137	264135	11070L	PARTICIPANT	\N	PRESENT	0
264138	264135	19647E	PARTICIPANT	\N	PRESENT	0
264139	264136	11070L	PARTICIPANT	\N	PRESENT	0
264140	264136	19647E	PARTICIPANT	\N	PRESENT	0
264141	264134	11070L	PARTICIPANT	\N	PRESENT	0
264142	264134	19647E	PARTICIPANT	\N	PRESENT	0
264145	264144	14085U	PARTICIPANT	\N	PRESENT	0
264146	264144	14253S	PARTICIPANT	\N	PRESENT	0
264147	264143	14085U	PARTICIPANT	\N	PRESENT	0
264148	264143	14253S	PARTICIPANT	\N	PRESENT	0
264152	258947	19663E	PARTICIPANT	\N	PRESENT	0
264154	258947	19683J	PARTICIPANT	\N	PRESENT	0
264158	258758	11109J	PARTICIPANT	\N	PRESENT	0
264159	264155	89017R	PARTICIPANT	\N	PRESENT	0
264162	258758	19691J	PARTICIPANT	\N	EXCUSE	0
264163	258758	19583F	PARTICIPANT	\N	EXCUSE	0
264164	258758	98005N	PARTICIPANT	\N	EXCUSE	0
264165	258758	19319Q	PARTICIPANT	\N	EXCUSE	0
264166	258758	14275Y	PARTICIPANT	\N	EXCUSE	0
264167	258759	19691J	PARTICIPANT	\N	EXCUSE	0
264168	258759	19583F	PARTICIPANT	\N	EXCUSE	0
264169	258759	98005N	PARTICIPANT	\N	EXCUSE	0
264170	258759	19319Q	PARTICIPANT	\N	EXCUSE	0
264171	258759	14275Y	PARTICIPANT	\N	EXCUSE	0
264172	258759	96004D	PARTICIPANT	\N	EXCUSE	0
264174	258759	14225N	PARTICIPANT	\N	EXCUSE	0
264176	258758	04043D	PARTICIPANT	\N	PRESENT	0
264190	264189	08011M	PARTICIPANT	\N	PRESENT	0
264191	264189	14159V	PARTICIPANT	\N	PRESENT	0
264192	264189	19711U	PARTICIPANT	\N	PRESENT	0
264193	264189	19667J	PARTICIPANT	\N	PRESENT	0
242413	240599	08010L	PARTICIPANT	\N	PRESENT	0
244263	244262	19479G	PARTICIPANT	\N	PRESENT	0
245506	245505	11053K	PARTICIPANT	\N	PRESENT	0
245507	245505	14159V	PARTICIPANT	\N	PRESENT	0
245508	245505	05012A	PARTICIPANT	\N	PRESENT	0
246070	244316	11081P	PARTICIPANT	\N	EXCUSE	0
246071	244316	11101A	PARTICIPANT	\N	EXCUSE	0
247211	247208	19575F	PARTICIPANT	\N	PRESENT	0
247212	247208	98029W	PARTICIPANT	\N	PRESENT	0
247213	247208	11080N	PARTICIPANT	\N	PRESENT	0
247214	247208	11027H	PARTICIPANT	\N	PRESENT	0
247215	247208	04008A	PARTICIPANT	\N	EXCUSE	0
247216	247208	19673G	PARTICIPANT	\N	PRESENT	0
247221	247208	08056B	PARTICIPANT	\N	PRESENT	0
247218	247208	14199E	PARTICIPANT	\N	PRESENT	0
247219	247208	19649G	PARTICIPANT	\N	PRESENT	0
247222	247208	98022P	PARTICIPANT	\N	PRESENT	0
247223	247208	19611R	PARTICIPANT	\N	PRESENT	0
247224	247208	11026G	PARTICIPANT	\N	PRESENT	0
247225	247208	08010L	PARTICIPANT	\N	PRESENT	0
247226	247208	08053X	PARTICIPANT	\N	PRESENT	0
247227	247208	98050T	PARTICIPANT	\N	PRESENT	0
247228	247208	10015M	PARTICIPANT	\N	PRESENT	0
247229	247208	19421M	PARTICIPANT	\N	PRESENT	0
247230	247208	19669L	PARTICIPANT	\N	PRESENT	0
256366	256121	14030Q	PARTICIPANT	\N	PRESENT	0
256367	256121	19697Q	PARTICIPANT	\N	PRESENT	0
256368	256121	14197C	PARTICIPANT	\N	PRESENT	0
256369	256121	19693L	PARTICIPANT	\N	PRESENT	0
256401	256121	98023Q	PARTICIPANT	\N	PRESENT	0
256371	256121	08015R	PARTICIPANT	\N	PRESENT	0
256372	256121	14257W	PARTICIPANT	\N	PRESENT	0
256373	256121	14029X	PARTICIPANT	\N	PRESENT	0
256374	256121	19573D	PARTICIPANT	\N	PRESENT	0
256484	256121	08039A	PARTICIPANT	\N	PRESENT	0
256376	256121	11083R	PARTICIPANT	\N	PRESENT	0
256377	256121	98018T	PARTICIPANT	\N	PRESENT	0
256378	256121	14063N	PARTICIPANT	\N	PRESENT	0
256379	256121	11065P	PARTICIPANT	\N	PRESENT	0
256380	256121	19413M	PARTICIPANT	\N	PRESENT	0
256381	256121	14157T	PARTICIPANT	\N	PRESENT	0
247209	247208	11033F	PARTICIPANT	\N	PRESENT	0
247210	247208	14089Y	PARTICIPANT	\N	EXCUSE	0
256402	256121	04061F	PARTICIPANT	\N	PRESENT	0
256383	256121	19709B	PARTICIPANT	\N	PRESENT	0
256384	256121	14133K	PARTICIPANT	\N	PRESENT	0
256385	256121	08068F	PARTICIPANT	\N	PRESENT	0
256386	256121	14055N	PARTICIPANT	\N	PRESENT	0
256387	256121	04071H	PARTICIPANT	\N	PRESENT	0
256388	256121	89017R	PARTICIPANT	\N	PRESENT	0
256389	256121	19731Y	PARTICIPANT	\N	PRESENT	0
256390	256121	01060R	PARTICIPANT	\N	PRESENT	0
256391	256121	05012A	PARTICIPANT	\N	PRESENT	0
256392	256121	19683J	PARTICIPANT	\N	PRESENT	0
256396	256121	19621T	PARTICIPANT	\N	PRESENT	0
256394	256121	19335Q	PARTICIPANT	\N	PRESENT	0
256395	256121	14147R	PARTICIPANT	\N	PRESENT	0
256397	256121	95062K	PARTICIPANT	\N	PRESENT	0
256398	256121	08053X	PARTICIPANT	\N	PRESENT	0
256411	256121	95067Q	PARTICIPANT	\N	PRESENT	0
256400	256121	19643A	PARTICIPANT	\N	PRESENT	0
256412	256121	19483C	PARTICIPANT	\N	PRESENT	0
256404	256121	19611R	PARTICIPANT	\N	PRESENT	0
256405	256121	19647E	PARTICIPANT	\N	PRESENT	0
256406	256121	19669L	PARTICIPANT	\N	PRESENT	0
256407	256121	14229S	PARTICIPANT	\N	PRESENT	0
256408	256121	04018C	PARTICIPANT	\N	PRESENT	0
256409	256121	14087W	PARTICIPANT	\N	PRESENT	0
256410	256121	19733B	PARTICIPANT	\N	PRESENT	0
256413	256121	04033B	PARTICIPANT	\N	PRESENT	0
256414	256121	01048V	PARTICIPANT	\N	PRESENT	0
256415	256121	14053L	PARTICIPANT	\N	PRESENT	0
256416	256121	17583W	PARTICIPANT	\N	PRESENT	0
256433	256121	08044W	PARTICIPANT	\N	PRESENT	0
256418	256121	14215L	PARTICIPANT	\N	PRESENT	0
256419	256121	14169X	PARTICIPANT	\N	PRESENT	0
256420	256121	04047H	PARTICIPANT	\N	PRESENT	0
256421	256121	19729F	PARTICIPANT	\N	PRESENT	0
256422	256121	19399H	PARTICIPANT	\N	PRESENT	0
256423	256121	14121F	PARTICIPANT	\N	PRESENT	0
256424	256121	04057K	PARTICIPANT	\N	PRESENT	0
256425	256121	14213J	PARTICIPANT	\N	PRESENT	0
256426	256121	19741B	PARTICIPANT	\N	PRESENT	0
256427	256121	04088S	PARTICIPANT	\N	PRESENT	0
256428	256121	97011G	PARTICIPANT	\N	PRESENT	0
256429	256121	14357A	PARTICIPANT	\N	PRESENT	0
256430	256121	14079W	PARTICIPANT	\N	PRESENT	0
256431	256121	11115U	PARTICIPANT	\N	PRESENT	0
256432	256121	19701S	PARTICIPANT	\N	PRESENT	0
256434	256121	08009T	PARTICIPANT	\N	PRESENT	0
256435	256121	95063L	PARTICIPANT	\N	PRESENT	0
256436	256121	08021P	PARTICIPANT	\N	PRESENT	0
256437	256121	12041X	PARTICIPANT	\N	PRESENT	0
256438	256121	11049P	PARTICIPANT	\N	PRESENT	0
256439	256121	14235Q	PARTICIPANT	\N	PRESENT	0
256440	256121	17637T	PARTICIPANT	\N	PRESENT	0
256441	256121	14327T	PARTICIPANT	\N	PRESENT	0
256442	256121	19685L	PARTICIPANT	\N	PRESENT	0
256443	256121	19747H	PARTICIPANT	\N	PRESENT	0
256444	256121	96004D	PARTICIPANT	\N	PRESENT	0
256445	256121	11090Q	PARTICIPANT	\N	PRESENT	0
256446	256121	19551W	PARTICIPANT	\N	PRESENT	0
256447	256121	17589D	PARTICIPANT	\N	PRESENT	0
256448	256121	04049K	PARTICIPANT	\N	PRESENT	0
256450	256121	19649G	PARTICIPANT	\N	PRESENT	0
256451	256121	05008E	PARTICIPANT	\N	PRESENT	0
256456	256121	11053K	PARTICIPANT	\N	PRESENT	0
256457	256121	14159V	PARTICIPANT	\N	PRESENT	0
256467	256121	01043Q	PARTICIPANT	\N	PRESENT	0
256468	256121	16685X	PARTICIPANT	\N	PRESENT	0
256469	256121	19531S	PARTICIPANT	\N	PRESENT	0
256472	256121	01062T	PARTICIPANT	\N	PRESENT	0
256475	256121	95015C	PARTICIPANT	\N	PRESENT	0
256476	256121	08069G	PARTICIPANT	\N	PRESENT	0
256477	256121	08034U	PARTICIPANT	\N	PRESENT	0
256479	256121	08038Y	PARTICIPANT	\N	PRESENT	0
256481	256121	19735D	PARTICIPANT	\N	PRESENT	0
256485	256121	19619A	PARTICIPANT	\N	PRESENT	0
256488	256121	04092N	PARTICIPANT	\N	PRESENT	0
256489	256121	19713W	PARTICIPANT	\N	PRESENT	0
256492	256121	19511N	PARTICIPANT	\N	PRESENT	0
256493	256121	19543W	PARTICIPANT	\N	PRESENT	0
256494	256121	14089Y	PARTICIPANT	\N	PRESENT	0
256495	256121	04070G	PARTICIPANT	\N	PRESENT	0
256500	256121	14193X	PARTICIPANT	\N	PRESENT	0
256501	256121	14069U	PARTICIPANT	\N	PRESENT	0
256502	256121	19269X	PARTICIPANT	\N	PRESENT	0
256503	256121	14031R	PARTICIPANT	\N	PRESENT	0
256507	256121	04008A	PARTICIPANT	\N	PRESENT	0
256863	256007	04008A	PARTICIPANT	\N	PRESENT	0
256864	256007	17637T	PARTICIPANT	\N	PRESENT	0
256865	256007	95062K	PARTICIPANT	\N	PRESENT	0
256866	256007	04047H	PARTICIPANT	\N	PRESENT	0
256867	256007	96004D	PARTICIPANT	\N	PRESENT	0
256868	256007	95030B	PARTICIPANT	\N	PRESENT	0
256870	256007	14026U	PARTICIPANT	\N	PRESENT	0
256872	256007	04092N	PARTICIPANT	\N	PRESENT	0
256873	256007	08039A	PARTICIPANT	\N	PRESENT	0
256875	256007	14123H	PARTICIPANT	\N	PRESENT	0
256877	256007	19515S	PARTICIPANT	\N	PRESENT	0
256878	256007	11080N	PARTICIPANT	\N	PRESENT	0
256879	256007	11115U	PARTICIPANT	\N	PRESENT	0
256880	256007	19703U	PARTICIPANT	\N	PRESENT	0
256881	256007	14031R	PARTICIPANT	\N	PRESENT	0
256882	256007	98005N	PARTICIPANT	\N	PRESENT	0
256883	256007	19573D	PARTICIPANT	\N	PRESENT	0
256884	256007	14173T	PARTICIPANT	\N	PRESENT	0
256885	256007	14038Y	PARTICIPANT	\N	PRESENT	0
256886	256007	19507S	PARTICIPANT	\N	PRESENT	0
256887	256007	19467C	PARTICIPANT	\N	PRESENT	0
256888	256007	18083K	PARTICIPANT	\N	PRESENT	0
256889	256007	19443T	PARTICIPANT	\N	PRESENT	0
256890	256007	14029X	PARTICIPANT	\N	PRESENT	0
256891	256007	12041X	PARTICIPANT	\N	PRESENT	0
256892	255990	08009T	PRESIDENT	0	PRESENT	0
256893	255990	05012A	PARTICIPANT	\N	PRESENT	0
256894	255990	19549D	PARTICIPANT	\N	EXCUSE	0
256895	255990	19739H	PARTICIPANT	\N	EXCUSE	0
256896	255990	19599P	PARTICIPANT	\N	EXCUSE	0
256897	255990	19637C	PARTICIPANT	\N	EXCUSE	0
256898	256007	11031D	PARTICIPANT	\N	PRESENT	0
256899	256007	04038G	PARTICIPANT	\N	PRESENT	0
256900	256007	19347U	PARTICIPANT	\N	PRESENT	0
256901	256007	19415P	PARTICIPANT	\N	PRESENT	0
256902	256007	19741B	PARTICIPANT	\N	PRESENT	0
256903	256007	19695N	PARTICIPANT	\N	PRESENT	0
256904	256007	11040E	PARTICIPANT	\N	PRESENT	0
256905	256007	04088S	PARTICIPANT	\N	PRESENT	0
257014	256007	08010L	PARTICIPANT	\N	PRESENT	0
257015	256007	19503N	PARTICIPANT	\N	PRESENT	0
257016	256007	19413M	PARTICIPANT	\N	PRESENT	0
257017	256007	11067R	PARTICIPANT	\N	PRESENT	0
257018	256007	19527W	PARTICIPANT	\N	PRESENT	0
257019	256007	14063N	PARTICIPANT	\N	PRESENT	0
257020	256007	11049P	PARTICIPANT	\N	PRESENT	0
257021	256007	19631V	PARTICIPANT	\N	PRESENT	0
257022	256007	14109K	PARTICIPANT	\N	PRESENT	0
257023	256007	19675J	PARTICIPANT	\N	PRESENT	0
257024	256007	14097Y	PARTICIPANT	\N	PRESENT	0
257025	256007	14257W	PARTICIPANT	\N	PRESENT	0
257026	256007	19383Y	PARTICIPANT	\N	PRESENT	0
257027	256007	19483C	PARTICIPANT	\N	PRESENT	0
257028	256007	11012A	PARTICIPANT	\N	PRESENT	0
257029	256007	88008L	PARTICIPANT	\N	PRESENT	0
257030	256007	19701S	PARTICIPANT	\N	PRESENT	0
257031	256007	04018C	PARTICIPANT	\N	PRESENT	0
257032	256007	08061X	PARTICIPANT	\N	PRESENT	0
257033	256007	97011G	PARTICIPANT	\N	PRESENT	0
257034	256007	14261S	PARTICIPANT	\N	PRESENT	0
257035	256007	19253P	PARTICIPANT	\N	PRESENT	0
257036	256007	11103C	PARTICIPANT	\N	PRESENT	0
257037	256007	08031R	PARTICIPANT	\N	PRESENT	0
257038	256007	07033P	PARTICIPANT	\N	PRESENT	0
257039	256007	19629C	PARTICIPANT	\N	PRESENT	0
257040	256007	08049C	PARTICIPANT	\N	PRESENT	0
257041	256007	14217N	PARTICIPANT	\N	PRESENT	0
257042	256007	19563B	PARTICIPANT	\N	PRESENT	0
257043	256007	98022P	PARTICIPANT	\N	PRESENT	0
257044	256007	14331P	PARTICIPANT	\N	PRESENT	0
257045	256007	14241N	PARTICIPANT	\N	PRESENT	0
257046	256007	10015M	PARTICIPANT	\N	PRESENT	0
257047	256007	19719D	PARTICIPANT	\N	PRESENT	0
257051	256007	08034U	PARTICIPANT	\N	PRESENT	0
257049	256007	19387D	PARTICIPANT	\N	PRESENT	0
257050	256007	11065P	PARTICIPANT	\N	PRESENT	0
257052	256007	19681G	PARTICIPANT	\N	PRESENT	0
257053	256007	19553Y	PARTICIPANT	\N	PRESENT	0
257054	256007	07034Q	PARTICIPANT	\N	PRESENT	0
257055	256007	10006L	PARTICIPANT	\N	PRESENT	0
257056	256007	19533U	PARTICIPANT	\N	PRESENT	0
257057	256007	14069U	PARTICIPANT	\N	PRESENT	0
257058	256007	19585H	PARTICIPANT	\N	PRESENT	0
257059	256007	19545Y	PARTICIPANT	\N	PRESENT	0
257060	256007	14053L	PARTICIPANT	\N	PRESENT	0
257061	256007	17589D	PARTICIPANT	\N	PRESENT	0
257062	256007	14111D	PARTICIPANT	\N	PRESENT	0
257063	256007	04033B	PARTICIPANT	\N	PRESENT	0
257064	256007	02002K	PARTICIPANT	\N	PRESENT	0
257065	256007	04057K	PARTICIPANT	\N	PRESENT	0
257066	256007	14187A	PARTICIPANT	\N	PRESENT	0
257067	256007	14251Q	PARTICIPANT	\N	PRESENT	0
257068	256007	14093U	PARTICIPANT	\N	PRESENT	0
257069	256007	11064N	PARTICIPANT	\N	PRESENT	0
257070	256007	19583F	PARTICIPANT	\N	PRESENT	0
257071	256007	11097X	PARTICIPANT	\N	PRESENT	0
257072	256007	14195A	PARTICIPANT	\N	PRESENT	0
257073	256007	05008E	PARTICIPANT	\N	PRESENT	0
257074	256007	14231L	PARTICIPANT	\N	PRESENT	0
257075	256007	14179A	PARTICIPANT	\N	PRESENT	0
257076	256007	14034U	PARTICIPANT	\N	PRESENT	0
257077	256007	04086Q	PARTICIPANT	\N	PRESENT	0
257078	256007	08044W	PARTICIPANT	\N	PRESENT	0
257079	256007	19691J	PARTICIPANT	\N	PRESENT	0
257080	256007	19369B	PARTICIPANT	\N	PRESENT	0
257081	256007	19611R	PARTICIPANT	\N	PRESENT	0
257082	256007	98018T	PARTICIPANT	\N	PRESENT	0
257083	256007	19511N	PARTICIPANT	\N	PRESENT	0
257084	256007	04044E	PARTICIPANT	\N	PRESENT	0
257085	256007	95041E	PARTICIPANT	\N	PRESENT	0
257086	256007	19721W	PARTICIPANT	\N	PRESENT	0
257087	256007	19619A	PARTICIPANT	\N	PRESENT	0
257088	256007	14205J	PARTICIPANT	\N	PRESENT	0
257089	256007	19699S	PARTICIPANT	\N	PRESENT	0
257090	256007	19737F	PARTICIPANT	\N	PRESENT	0
257091	256007	19735D	PARTICIPANT	\N	PRESENT	0
257092	256007	98024R	PARTICIPANT	\N	PRESENT	0
257093	256007	16685X	PARTICIPANT	\N	PRESENT	0
257094	256007	14042U	PARTICIPANT	\N	PRESENT	0
257095	256007	04035D	PARTICIPANT	\N	PRESENT	0
257096	256007	14219Q	PARTICIPANT	\N	PRESENT	0
257097	256007	19289C	PARTICIPANT	\N	PRESENT	0
257098	256007	04097T	PARTICIPANT	\N	PRESENT	0
257099	256007	14237S	PARTICIPANT	\N	PRESENT	0
257100	256007	19441R	PARTICIPANT	\N	PRESENT	0
257101	256007	14073Q	PARTICIPANT	\N	PRESENT	0
257102	256007	14277B	PARTICIPANT	\N	PRESENT	0
257103	256007	19713W	PARTICIPANT	\N	PRESENT	0
257104	256007	14087W	PARTICIPANT	\N	PRESENT	0
257105	256007	11074Q	PARTICIPANT	\N	PRESENT	0
257106	256007	14215L	PARTICIPANT	\N	PRESENT	0
257107	256007	14267Y	PARTICIPANT	\N	PRESENT	0
257108	256007	17583W	PARTICIPANT	\N	PRESENT	0
257109	256007	14221J	PARTICIPANT	\N	PRESENT	0
257110	256007	14083S	PARTICIPANT	\N	PRESENT	0
257111	256007	19521Q	PARTICIPANT	\N	PRESENT	0
257112	256007	19581D	PARTICIPANT	\N	PRESENT	0
257113	256007	19569H	PARTICIPANT	\N	PRESENT	0
257114	256007	19367Y	PARTICIPANT	\N	PRESENT	0
257115	256007	19749K	PARTICIPANT	\N	PRESENT	0
257116	256007	07004J	PARTICIPANT	\N	PRESENT	0
257117	256007	14255U	PARTICIPANT	\N	PRESENT	0
257118	256007	11085T	PARTICIPANT	\N	PRESENT	0
257119	256007	19577H	PARTICIPANT	\N	PRESENT	0
257120	256007	19551W	PARTICIPANT	\N	PRESENT	0
257121	256007	04040A	PARTICIPANT	\N	PRESENT	0
257122	256007	19671E	PARTICIPANT	\N	PRESENT	0
257123	256007	01025N	PARTICIPANT	\N	PRESENT	0
257124	256007	19621T	PARTICIPANT	\N	PRESENT	0
257125	256007	14030Q	PARTICIPANT	\N	PRESENT	0
257126	256007	14327T	PARTICIPANT	\N	PRESENT	0
257127	256007	01043Q	PARTICIPANT	\N	PRESENT	0
257128	256007	19643A	PARTICIPANT	\N	PRESENT	0
257129	256007	19335Q	PARTICIPANT	\N	PRESENT	0
257130	256007	19733B	PARTICIPANT	\N	PRESENT	0
257131	256007	89017R	PARTICIPANT	\N	PRESENT	0
257132	256007	19685L	PARTICIPANT	\N	PRESENT	0
257133	256007	01060R	PARTICIPANT	\N	PRESENT	0
257134	256007	14055N	PARTICIPANT	\N	PRESENT	0
257135	256007	19731Y	PARTICIPANT	\N	PRESENT	0
257136	256007	19745F	PARTICIPANT	\N	PRESENT	0
257137	256007	19663E	PARTICIPANT	\N	PRESENT	0
257138	256007	11099A	PARTICIPANT	\N	PRESENT	0
257139	256007	14115H	PARTICIPANT	\N	PRESENT	0
257156	256007	01058X	PARTICIPANT	\N	PRESENT	0
257141	256007	19479G	PARTICIPANT	\N	PRESENT	0
257142	256007	95067Q	PARTICIPANT	\N	PRESENT	0
257143	256007	19679N	PARTICIPANT	\N	PRESENT	0
257144	256007	14135M	PARTICIPANT	\N	PRESENT	0
257145	256007	04043D	PARTICIPANT	\N	PRESENT	0
257146	256007	14157T	PARTICIPANT	\N	PRESENT	0
257147	256007	14211G	PARTICIPANT	\N	PRESENT	0
257148	256007	99004R	PARTICIPANT	\N	PRESENT	0
257149	256007	86034E	PARTICIPANT	\N	PRESENT	0
257150	256007	19705W	PARTICIPANT	\N	PRESENT	0
257151	256007	08011M	PARTICIPANT	\N	PRESENT	0
257152	256007	14265W	PARTICIPANT	\N	PRESENT	0
257153	256007	08062Y	PARTICIPANT	\N	PRESENT	0
257154	256007	08053X	PARTICIPANT	\N	PRESENT	0
257155	256007	19747H	PARTICIPANT	\N	PRESENT	0
257157	256007	14193X	PARTICIPANT	\N	PRESENT	0
257158	256007	19687N	PARTICIPANT	\N	PRESENT	0
257159	256007	14079W	PARTICIPANT	\N	PRESENT	0
257160	256007	19711U	PARTICIPANT	\N	PRESENT	0
257161	256007	19489J	PARTICIPANT	\N	PRESENT	0
257162	256007	14159V	PARTICIPANT	\N	PRESENT	0
257163	256007	05012A	PARTICIPANT	\N	PRESENT	0
257164	256007	08009T	PARTICIPANT	\N	PRESENT	0
257165	256007	19723Y	PARTICIPANT	\N	PRESENT	0
257166	256007	11090Q	PARTICIPANT	\N	PRESENT	0
257167	256007	11053K	PARTICIPANT	\N	PRESENT	0
257012	256007	14169X	PARTICIPANT	\N	PRESENT	0
257013	256007	19591F	PARTICIPANT	\N	PRESENT	0
257168	256007	98035U	PARTICIPANT	\N	PRESENT	0
257169	256007	11026G	PARTICIPANT	\N	PRESENT	0
240964	238586	11074Q	PARTICIPANT	\N	PRESENT	0
240965	238586	08045X	PARTICIPANT	\N	PRESENT	0
240966	238586	14255U	PARTICIPANT	\N	PRESENT	0
240967	238586	11049P	PARTICIPANT	\N	PRESENT	0
240968	238588	11074Q	PARTICIPANT	\N	PRESENT	0
240969	238588	08045X	PARTICIPANT	\N	PRESENT	0
240970	238588	14255U	PARTICIPANT	\N	PRESENT	0
240971	238588	11083R	PARTICIPANT	\N	PRESENT	0
240972	238588	11049P	PARTICIPANT	\N	PRESENT	0
240973	238588	08015R	PARTICIPANT	\N	PRESENT	0
240974	238588	04034C	PARTICIPANT	\N	PRESENT	0
240975	238588	11027H	PARTICIPANT	\N	PRESENT	0
240981	240599	19383Y	PARTICIPANT	\N	PRESENT	0
241035	238775	08010L	PARTICIPANT	\N	PRESENT	0
241036	238775	05008E	PRESIDENT	0	PRESENT	0
241037	238775	19543W	PARTICIPANT	\N	PRESENT	0
241038	238775	11033F	PARTICIPANT	\N	PRESENT	0
241039	238775	14065Q	PARTICIPANT	\N	PRESENT	0
241040	238775	14069U	PARTICIPANT	\N	PRESENT	0
241041	238775	04047H	PARTICIPANT	\N	EXCUSE	0
241042	238775	19253P	PARTICIPANT	\N	PRESENT	0
241043	238775	14041T	PARTICIPANT	\N	PRESENT	0
241044	238775	01024M	PARTICIPANT	\N	PRESENT	0
241045	238775	19673G	PARTICIPANT	\N	PRESENT	0
241046	238775	08018U	PARTICIPANT	\N	EXCUSE	0
241047	238775	11010L	PARTICIPANT	\N	PRESENT	0
241048	238775	14231L	PARTICIPANT	\N	EXCUSE	0
241049	238775	19649G	PARTICIPANT	\N	PRESENT	0
241050	238775	19725B	PARTICIPANT	\N	PRESENT	0
241051	238775	14179A	PARTICIPANT	\N	PRESENT	0
241052	238775	19447X	PARTICIPANT	\N	PRESENT	0
241053	238775	19483C	PARTICIPANT	\N	PRESENT	0
241054	238775	19729F	PARTICIPANT	\N	PRESENT	0
241055	238775	19581D	PARTICIPANT	\N	PRESENT	0
241056	238775	14001X	PARTICIPANT	\N	EXCUSE	0
241057	238775	07034Q	PARTICIPANT	\N	PRESENT	0
241058	238775	10015M	PARTICIPANT	\N	PRESENT	0
241059	238775	01028R	PARTICIPANT	\N	EXCUSE	0
241060	238775	04044E	PARTICIPANT	\N	EXCUSE	0
246301	246300	14105F	PARTICIPANT	\N	PRESENT	0
246302	246300	14051J	PARTICIPANT	\N	PRESENT	0
246303	246300	14121F	PARTICIPANT	\N	PRESENT	0
246304	246300	14187A	PARTICIPANT	\N	PRESENT	0
246305	246300	19521Q	PARTICIPANT	\N	PRESENT	0
246306	246300	14079W	PARTICIPANT	\N	PRESENT	0
246307	246300	19591F	PARTICIPANT	\N	PRESENT	0
246308	246300	14151M	PARTICIPANT	\N	PRESENT	0
246309	246300	14026U	PARTICIPANT	\N	PRESENT	0
246310	246300	89017R	PARTICIPANT	\N	PRESENT	0
246311	246300	14087W	PARTICIPANT	\N	PRESENT	0
246312	246300	14053L	PARTICIPANT	\N	PRESENT	0
246313	246300	14265W	PARTICIPANT	\N	PRESENT	0
246314	246300	16685X	PARTICIPANT	\N	PRESENT	0
246315	246300	08068F	PARTICIPANT	\N	PRESENT	0
246316	246300	04049K	PRESIDENT	0	PRESENT	0
246317	246300	14253S	PARTICIPANT	\N	PRESENT	0
246318	246300	04088S	PARTICIPANT	\N	PRESENT	0
246319	246300	19527W	PARTICIPANT	\N	PRESENT	0
246320	246300	14261S	PARTICIPANT	\N	EXCUSE	0
246321	246300	19575F	PARTICIPANT	\N	PRESENT	0
246322	246300	14030Q	PARTICIPANT	\N	EXCUSE	0
246323	246300	08060W	PARTICIPANT	\N	EXCUSE	0
246324	246300	14255U	PARTICIPANT	\N	EXCUSE	0
246325	246300	14083S	PARTICIPANT	\N	EXCUSE	0
246326	246300	14329V	PARTICIPANT	\N	EXCUSE	0
246327	246300	11031D	PARTICIPANT	\N	EXCUSE	0
246328	246300	14041T	PARTICIPANT	\N	EXCUSE	0
246329	246300	14061L	PARTICIPANT	\N	EXCUSE	0
246330	246300	08015R	PARTICIPANT	\N	EXCUSE	0
246331	246300	19671E	PARTICIPANT	\N	EXCUSE	0
246332	246300	08047A	PARTICIPANT	\N	EXCUSE	0
246333	246300	14157T	PARTICIPANT	\N	PRESENT	0
246334	246300	14205J	PARTICIPANT	\N	EXCUSE	0
246336	246335	14255U	PARTICIPANT	\N	PRESENT	0
246339	246338	14255U	PARTICIPANT	\N	PRESENT	0
246340	246337	14255U	PARTICIPANT	\N	PRESENT	0
250549	250548	11053K	PARTICIPANT	\N	PRESENT	0
250550	250548	14159V	PARTICIPANT	\N	PRESENT	0
250551	250548	05012A	PARTICIPANT	\N	PRESENT	0
251003	250553	14259Y	PARTICIPANT	\N	PRESENT	0
251005	250553	14231L	PARTICIPANT	\N	PRESENT	0
251040	250553	01024M	PARTICIPANT	\N	PRESENT	0
251042	250553	14151M	PARTICIPANT	\N	PRESENT	0
251058	250518	11104D	PARTICIPANT	\N	PRESENT	0
251880	251879	96004D	PRESIDENT	0	PRESENT	0
251881	251879	14089Y	PARTICIPANT	\N	PRESENT	0
251882	251879	14357A	PARTICIPANT	\N	PRESENT	0
251883	251879	11083R	PARTICIPANT	\N	PRESENT	0
251884	251879	14033T	PARTICIPANT	\N	PRESENT	0
251885	251879	19725B	PARTICIPANT	\N	PRESENT	0
251886	251879	95037J	PARTICIPANT	\N	PRESENT	0
251887	251879	08044W	PARTICIPANT	\N	PRESENT	0
251888	251879	14097Y	PARTICIPANT	\N	PRESENT	0
251889	251879	14073Q	PARTICIPANT	\N	PRESENT	0
251890	251879	11026G	PARTICIPANT	\N	PRESENT	0
251891	251879	04057K	PARTICIPANT	\N	PRESENT	0
251892	251879	19563B	PARTICIPANT	\N	PRESENT	0
251893	251879	19593H	PARTICIPANT	\N	PRESENT	0
251894	251879	14135M	PARTICIPANT	\N	PRESENT	0
251895	251879	14331P	PARTICIPANT	\N	PRESENT	0
251896	251879	10015M	PARTICIPANT	\N	PRESENT	0
251897	251879	98035U	PARTICIPANT	\N	PRESENT	0
251898	251879	14225N	PARTICIPANT	\N	EXCUSE	0
251899	251879	14001X	PARTICIPANT	\N	EXCUSE	0
251900	251879	14061L	PARTICIPANT	\N	EXCUSE	0
253905	240316	14001X	PARTICIPANT	\N	PRESENT	0
253908	240316	14205J	PARTICIPANT	\N	PRESENT	0
253909	240316	14227Q	PARTICIPANT	\N	PRESENT	0
253910	240316	19733B	PARTICIPANT	\N	PRESENT	0
253911	240316	11054L	PARTICIPANT	\N	PRESENT	0
253912	240316	19683J	PARTICIPANT	\N	PRESENT	0
253913	240316	19737F	PARTICIPANT	\N	PRESENT	0
253914	240316	19251M	PARTICIPANT	\N	PRESENT	0
253915	240316	19503N	PARTICIPANT	\N	PRESENT	0
253916	240316	19689Q	PARTICIPANT	\N	PRESENT	0
253917	240316	14179A	PARTICIPANT	\N	PRESENT	0
253918	240316	19399H	PARTICIPANT	\N	PRESENT	0
253919	240316	19413M	PARTICIPANT	\N	PRESENT	0
253920	240316	05012A	PARTICIPANT	\N	PRESENT	0
253921	240316	19693L	PARTICIPANT	\N	PRESENT	0
253922	240316	19551W	PARTICIPANT	\N	PRESENT	0
253923	240316	19729F	PARTICIPANT	\N	PRESENT	0
253924	240316	14265W	PARTICIPANT	\N	PRESENT	0
253925	240316	19527W	PARTICIPANT	\N	PRESENT	0
253926	240316	14063N	PARTICIPANT	\N	PRESENT	0
253927	240316	14213J	PARTICIPANT	\N	PRESENT	0
253928	240316	19631V	PARTICIPANT	\N	PRESENT	0
253929	240316	19443T	PARTICIPANT	\N	PRESENT	0
253930	240316	14109K	PARTICIPANT	\N	PRESENT	0
253931	240316	14097Y	PARTICIPANT	\N	PRESENT	0
253932	240316	11045K	PARTICIPANT	\N	PRESENT	0
253933	240316	19741B	PARTICIPANT	\N	PRESENT	0
253934	240316	19669L	PARTICIPANT	\N	PRESENT	0
253935	240316	08034U	PARTICIPANT	\N	PRESENT	0
253936	240316	19709B	PARTICIPANT	\N	PRESENT	0
253937	240316	19549D	PARTICIPANT	\N	PRESENT	0
253938	240316	19483C	PARTICIPANT	\N	PRESENT	0
253939	240316	04088S	PARTICIPANT	\N	PRESENT	0
253940	240316	19735D	PARTICIPANT	\N	PRESENT	0
253941	240316	14041T	PARTICIPANT	\N	PRESENT	0
253942	240316	14231L	PARTICIPANT	\N	PRESENT	0
253943	240316	07029T	PARTICIPANT	\N	PRESENT	0
257776	257771	11053K	PARTICIPANT	\N	PRESENT	0
257777	257771	14159V	PARTICIPANT	\N	PRESENT	0
257778	257771	05012A	PARTICIPANT	\N	PRESENT	0
258516	258515	08043V	PARTICIPANT	\N	PRESENT	0
258517	258515	19399H	PARTICIPANT	\N	PRESENT	0
258518	258515	08031R	PARTICIPANT	\N	PRESENT	0
258519	258515	08039A	PARTICIPANT	\N	PRESENT	0
258520	258515	14109K	PARTICIPANT	\N	PRESENT	0
258521	258515	19749K	PARTICIPANT	\N	PRESENT	0
258522	258515	04018C	PARTICIPANT	\N	PRESENT	0
260604	258973	11040E	PARTICIPANT	\N	PRESENT	0
260624	260614	11026G	PARTICIPANT	\N	PRESENT	0
260625	260614	10015M	PARTICIPANT	\N	PRESENT	0
260797	260796	96004D	PARTICIPANT	\N	PRESENT	0
260798	260796	14097Y	PARTICIPANT	\N	PRESENT	0
260799	260796	14133K	PARTICIPANT	\N	PRESENT	0
260800	260796	04061F	PARTICIPANT	\N	PRESENT	0
260801	260796	04097T	PARTICIPANT	\N	PRESENT	0
260803	260796	04042C	PARTICIPANT	\N	PRESENT	0
260804	260796	14255U	PARTICIPANT	\N	PRESENT	0
260805	260796	04034C	PARTICIPANT	\N	PRESENT	0
260806	260796	98050T	PARTICIPANT	\N	PRESENT	0
260807	260796	01062T	PARTICIPANT	\N	PRESENT	0
260808	260796	19251M	PARTICIPANT	\N	PRESENT	0
260809	260796	14205J	PARTICIPANT	\N	PRESENT	0
261397	261396	08018U	PARTICIPANT	\N	PRESENT	0
261400	261399	08018U	PARTICIPANT	\N	PRESENT	0
261401	261398	08018U	PARTICIPANT	\N	PRESENT	0
261403	261402	08018U	PARTICIPANT	\N	PRESENT	0
261405	261404	08018U	PARTICIPANT	\N	PRESENT	0
261407	261406	08018U	PARTICIPANT	\N	PRESENT	0
262012	261486	04034C	PARTICIPANT	\N	PRESENT	0
262013	261956	04070G	PARTICIPANT	\N	PRESENT	0
262014	261956	19533U	PARTICIPANT	\N	PRESENT	0
262015	261956	14229S	PARTICIPANT	\N	PRESENT	0
262016	261956	05008E	PRESIDENT	0	PRESENT	0
262017	261956	19447X	PARTICIPANT	\N	PRESENT	0
262018	261956	14231L	PARTICIPANT	\N	PRESENT	0
262019	261956	19573D	PARTICIPANT	\N	PRESENT	0
262020	261956	14107H	PARTICIPANT	\N	PRESENT	0
262021	261956	08017T	PARTICIPANT	\N	PRESENT	0
262022	261956	14147R	PARTICIPANT	\N	PRESENT	0
262023	261956	14179A	PARTICIPANT	\N	PRESENT	0
262024	261956	14151M	PARTICIPANT	\N	PRESENT	0
262025	261956	14249W	PARTICIPANT	\N	PRESENT	0
262026	261956	08039A	PARTICIPANT	\N	PRESENT	0
262027	261956	11072N	PARTICIPANT	\N	PRESENT	0
262028	261956	14059S	PARTICIPANT	\N	PRESENT	0
262029	261956	04057K	PARTICIPANT	\N	PRESENT	0
262030	261956	14111D	PARTICIPANT	\N	PRESENT	0
262031	261956	14073Q	PARTICIPANT	\N	PRESENT	0
262032	261956	19611R	PARTICIPANT	\N	PRESENT	0
262033	261956	01024M	PARTICIPANT	\N	PRESENT	0
262034	261956	04038G	PARTICIPANT	\N	PRESENT	0
262035	261956	19693L	PARTICIPANT	\N	PRESENT	0
262036	261956	19399H	PARTICIPANT	\N	PRESENT	0
262037	261956	14030Q	PARTICIPANT	\N	PRESENT	0
262038	261956	19725B	PARTICIPANT	\N	PRESENT	0
262039	261956	19731Y	PARTICIPANT	\N	PRESENT	0
262040	261956	14251Q	PARTICIPANT	\N	PRESENT	0
262041	261956	19735D	PARTICIPANT	\N	PRESENT	0
262042	261956	11109J	PARTICIPANT	\N	PRESENT	0
262043	261956	14063N	PARTICIPANT	\N	PRESENT	0
262044	261956	11083R	PARTICIPANT	\N	PRESENT	0
262045	261956	14123H	PARTICIPANT	\N	PRESENT	0
262046	261956	11043H	PARTICIPANT	\N	PRESENT	0
262047	261956	19749K	PARTICIPANT	\N	PRESENT	0
262048	261956	08018U	PARTICIPANT	\N	EXCUSE	0
262049	261956	14021P	PARTICIPANT	\N	EXCUSE	0
262050	261486	14135M	PARTICIPANT	\N	PRESENT	0
262051	261486	19703U	PARTICIPANT	\N	PRESENT	0
262052	261486	19507S	PARTICIPANT	\N	PRESENT	0
262053	261486	05012A	PARTICIPANT	\N	PRESENT	0
262054	261486	14034U	PARTICIPANT	\N	PRESENT	0
262055	261486	07029T	PARTICIPANT	\N	PRESENT	0
262056	261572	04070G	PRESIDENT	0	PRESENT	0
262057	261572	01028R	PARTICIPANT	\N	PRESENT	0
262058	261572	08017T	PARTICIPANT	\N	PRESENT	0
262059	261572	14179A	PARTICIPANT	\N	PRESENT	0
262060	261572	14111D	PARTICIPANT	\N	PRESENT	0
262061	261572	11109J	PARTICIPANT	\N	PRESENT	0
262062	261572	11083R	PARTICIPANT	\N	PRESENT	0
262063	261486	19515S	PARTICIPANT	\N	PRESENT	0
262064	261486	19631V	PARTICIPANT	\N	PRESENT	0
262065	261486	14259Y	PARTICIPANT	\N	PRESENT	0
262066	261486	08014Q	PARTICIPANT	\N	PRESENT	0
262067	261486	19713W	PARTICIPANT	\N	PRESENT	0
262068	261486	19679N	PARTICIPANT	\N	PRESENT	0
262069	261486	14265W	PARTICIPANT	\N	PRESENT	0
262070	261486	19629C	PARTICIPANT	\N	PRESENT	0
262071	261486	19563B	PARTICIPANT	\N	PRESENT	0
262072	256017	08056B	PARTICIPANT	\N	PRESENT	0
262073	256017	19649G	PARTICIPANT	\N	PRESENT	0
262074	256017	19611R	PARTICIPANT	\N	PRESENT	0
262075	256017	19421M	PARTICIPANT	\N	PRESENT	0
262076	256017	98022P	PARTICIPANT	\N	PRESENT	0
262077	256017	11026G	PARTICIPANT	\N	PRESENT	0
262078	256017	98050T	PARTICIPANT	\N	PRESENT	0
262079	256017	08010L	PARTICIPANT	\N	PRESENT	0
262080	256017	04008A	PARTICIPANT	\N	PRESENT	0
262081	256017	19673G	PARTICIPANT	\N	PRESENT	0
262082	256017	98029W	PRESIDENT	0	PRESENT	0
262083	256017	19575F	PARTICIPANT	\N	EXCUSE	0
262084	258932	14089Y	PARTICIPANT	\N	PRESENT	0
262085	258932	08056B	PARTICIPANT	\N	PRESENT	0
262086	258932	19649G	PARTICIPANT	\N	PRESENT	0
262087	258932	19611R	PARTICIPANT	\N	PRESENT	0
262088	258932	19421M	PARTICIPANT	\N	PRESENT	0
262089	258932	98022P	PARTICIPANT	\N	PRESENT	0
262090	258932	11026G	PARTICIPANT	\N	PRESENT	0
262091	258932	98050T	PARTICIPANT	\N	PRESENT	0
262092	258932	08010L	PARTICIPANT	\N	PRESENT	0
262093	258932	19673G	PARTICIPANT	\N	PRESENT	0
262094	258932	98029W	PRESIDENT	0	PRESENT	0
262095	258932	19575F	PARTICIPANT	\N	EXCUSE	0
264194	264189	01057W	PARTICIPANT	\N	PRESENT	0
264195	264185	08011M	PARTICIPANT	\N	PRESENT	0
264218	264214	19511N	PARTICIPANT	\N	PRESENT	0
264217	264214	11083R	PARTICIPANT	\N	PRESENT	0
264198	264185	19667J	PARTICIPANT	\N	PRESENT	0
264219	264215	11083R	PARTICIPANT	\N	PRESENT	0
264220	264215	19511N	PARTICIPANT	\N	PRESENT	0
264221	264216	11083R	PARTICIPANT	\N	PRESENT	0
264222	264216	19511N	PARTICIPANT	\N	PRESENT	0
264224	264223	11074Q	PARTICIPANT	\N	PRESENT	0
264225	264223	88008L	PARTICIPANT	\N	PRESENT	0
264226	264223	11012A	PARTICIPANT	\N	PRESENT	0
264227	264223	04061F	PARTICIPANT	\N	PRESENT	0
264228	264223	14034U	PARTICIPANT	\N	PRESENT	0
264229	262902	19333N	PARTICIPANT	\N	EXCUSE	0
264230	262902	19551W	PARTICIPANT	\N	PRESENT	0
264231	262902	17583W	PARTICIPANT	\N	EXCUSE	0
264232	262902	08060W	PARTICIPANT	\N	EXCUSE	0
264233	262902	08024S	PARTICIPANT	\N	EXCUSE	0
264234	262902	19599P	PARTICIPANT	\N	EXCUSE	0
264244	262902	18083K	PARTICIPANT	\N	PRESENT	0
264245	262902	14038Y	PARTICIPANT	\N	PRESENT	0
264246	262902	08009T	PRESIDENT	0	PRESENT	0
264247	262902	19739H	PARTICIPANT	\N	PRESENT	0
264248	262902	19667J	PARTICIPANT	\N	PRESENT	0
264249	262902	19671E	PARTICIPANT	\N	PRESENT	0
264250	262902	17637T	PARTICIPANT	\N	PRESENT	0
264259	264235	98035U	PARTICIPANT	\N	PRESENT	0
264260	264235	14111D	PARTICIPANT	\N	PRESENT	0
264261	264235	11026G	PARTICIPANT	\N	PRESENT	0
264262	264235	07034Q	PARTICIPANT	\N	PRESENT	0
264263	264235	19253P	PARTICIPANT	\N	PRESENT	0
264264	264235	19543W	PARTICIPANT	\N	PRESENT	0
264265	264235	01024M	PARTICIPANT	\N	PRESENT	0
264266	264235	04038G	PARTICIPANT	\N	PRESENT	0
264267	264235	04044E	PARTICIPANT	\N	PRESENT	0
264268	264235	01028R	PARTICIPANT	\N	PRESENT	0
264269	264235	05008E	PRESIDENT	0	PRESENT	0
264270	264235	14089Y	PARTICIPANT	\N	PRESENT	0
264271	264235	19489J	PARTICIPANT	\N	PRESENT	0
264272	264235	95063L	PARTICIPANT	\N	PRESENT	0
264273	264235	14041T	PARTICIPANT	\N	PRESENT	0
264274	264235	14069U	PARTICIPANT	\N	PRESENT	0
264275	264235	11072N	PARTICIPANT	\N	PRESENT	0
264276	264235	14021P	PARTICIPANT	\N	PRESENT	0
264277	264235	14053L	PARTICIPANT	\N	EXCUSE	0
264278	264235	19729F	PARTICIPANT	\N	EXCUSE	0
264279	264235	19447X	PARTICIPANT	\N	EXCUSE	0
264280	262902	19503N	PARTICIPANT	\N	PRESENT	0
264281	256028	14221J	PARTICIPANT	\N	PRESENT	0
264282	256028	19593H	PARTICIPANT	\N	PRESENT	0
264283	256029	14221J	PARTICIPANT	\N	PRESENT	0
241170	241169	80013X	PARTICIPANT	\N	PRESENT	0
241172	241171	80013X	PARTICIPANT	\N	PRESENT	0
241175	241174	80013X	PARTICIPANT	\N	PRESENT	0
246733	244032	11097X	PARTICIPANT	\N	PRESENT	0
246734	244032	11067R	PARTICIPANT	\N	PRESENT	0
247508	247284	04043D	PARTICIPANT	\N	PRESENT	0
247509	247284	14069U	PARTICIPANT	\N	PRESENT	0
247511	247284	14089Y	PARTICIPANT	\N	PRESENT	0
247512	247284	04070G	PARTICIPANT	\N	PRESENT	0
247514	247284	19521Q	PARTICIPANT	\N	PRESENT	0
247515	247284	14249W	PARTICIPANT	\N	PRESENT	0
247516	247284	07004J	PARTICIPANT	\N	PRESENT	0
247518	247284	04033B	PARTICIPANT	\N	PRESENT	0
247519	247284	19577H	PARTICIPANT	\N	PRESENT	0
247520	247284	95030B	PARTICIPANT	\N	PRESENT	0
247522	247284	97011G	PARTICIPANT	\N	PRESENT	0
247524	247284	08018U	PARTICIPANT	\N	PRESENT	0
247525	247284	17583W	PARTICIPANT	\N	PRESENT	0
247526	247284	19729F	PARTICIPANT	\N	PRESENT	0
247527	247284	11085T	PARTICIPANT	\N	PRESENT	0
247528	247284	19747H	PARTICIPANT	\N	PRESENT	0
247529	247284	04040A	PARTICIPANT	\N	PRESENT	0
247530	247284	04035D	PARTICIPANT	\N	PRESENT	0
247531	247284	19585H	PARTICIPANT	\N	PRESENT	0
247532	247284	14159V	PARTICIPANT	\N	PRESENT	0
247533	247284	98024R	PARTICIPANT	\N	PRESENT	0
247534	247284	04092N	PARTICIPANT	\N	PRESENT	0
247535	247284	04089T	PARTICIPANT	\N	PRESENT	0
247536	247284	14059S	PARTICIPANT	\N	PRESENT	0
247537	247284	01025N	PARTICIPANT	\N	PRESENT	0
247538	247284	14061L	PARTICIPANT	\N	PRESENT	0
247539	247284	01024M	PARTICIPANT	\N	PRESENT	0
247540	247284	14327T	PARTICIPANT	\N	PRESENT	0
247541	247284	01043Q	PARTICIPANT	\N	PRESENT	0
247542	247284	04047H	PARTICIPANT	\N	PRESENT	0
247543	247284	14205J	PARTICIPANT	\N	PRESENT	0
247544	247284	19707Y	PARTICIPANT	\N	PRESENT	0
247545	247284	14030Q	PARTICIPANT	\N	PRESENT	0
247546	247284	19705W	PARTICIPANT	\N	PRESENT	0
247547	247284	14147R	PARTICIPANT	\N	PRESENT	0
247548	247284	14109K	PARTICIPANT	\N	PRESENT	0
247549	247284	08062Y	PARTICIPANT	\N	PRESENT	0
247550	247284	08015R	PARTICIPANT	\N	PRESENT	0
247551	247284	08019V	PARTICIPANT	\N	PRESENT	0
247552	247284	08068F	PARTICIPANT	\N	PRESENT	0
247553	247284	14217N	PARTICIPANT	\N	PRESENT	0
247554	247284	14239U	PARTICIPANT	\N	PRESENT	0
247555	247284	07034Q	PARTICIPANT	\N	PRESENT	0
247556	247284	04071H	PARTICIPANT	\N	PRESENT	0
247557	247284	19691J	PARTICIPANT	\N	PRESENT	0
247558	247284	11097X	PARTICIPANT	\N	PRESENT	0
247559	247284	19675J	PARTICIPANT	\N	PRESENT	0
247560	247284	14115H	PARTICIPANT	\N	PRESENT	0
247561	247284	08028W	PARTICIPANT	\N	PRESENT	0
247562	247284	19367Y	PARTICIPANT	\N	PRESENT	0
247563	247284	14259Y	PARTICIPANT	\N	PRESENT	0
247564	247284	14079W	PARTICIPANT	\N	PRESENT	0
247565	247284	04086Q	PARTICIPANT	\N	PRESENT	0
247566	247284	14357A	PARTICIPANT	\N	PRESENT	0
247567	247284	19693L	PARTICIPANT	\N	PRESENT	0
247568	247284	11070L	PARTICIPANT	\N	PRESENT	0
247569	247284	14034U	PARTICIPANT	\N	PRESENT	0
247570	247284	19733B	PARTICIPANT	\N	PRESENT	0
247571	247284	05012A	PARTICIPANT	\N	PRESENT	0
247572	247284	98050T	PARTICIPANT	\N	PRESENT	0
247573	247284	19383Y	PARTICIPANT	\N	PRESENT	0
247574	247284	11010L	PARTICIPANT	\N	PRESENT	0
247575	247284	08069G	PARTICIPANT	\N	PRESENT	0
247576	247284	19621T	PARTICIPANT	\N	PRESENT	0
247577	247284	19399H	PARTICIPANT	\N	PRESENT	0
247578	247284	14026U	PARTICIPANT	\N	PRESENT	0
247579	247284	04042C	PARTICIPANT	\N	PRESENT	0
247580	247284	04044E	PARTICIPANT	\N	PRESENT	0
247581	247284	11103C	PARTICIPANT	\N	PRESENT	0
247582	247284	14329V	PARTICIPANT	\N	PRESENT	0
247583	247284	19701S	PARTICIPANT	\N	PRESENT	0
247584	247284	08034U	PARTICIPANT	\N	PRESENT	0
247585	247284	19673G	PARTICIPANT	\N	PRESENT	0
247586	247284	14087W	PARTICIPANT	\N	PRESENT	0
247587	247284	14199E	PARTICIPANT	\N	PRESENT	0
247588	247284	14355X	PARTICIPANT	\N	PRESENT	0
247589	247284	14213J	PARTICIPANT	\N	PRESENT	0
247590	247284	19483C	PARTICIPANT	\N	PRESENT	0
247591	247284	19657G	PARTICIPANT	\N	PRESENT	0
247592	247284	14267Y	PARTICIPANT	\N	PRESENT	0
247593	247284	95041E	PARTICIPANT	\N	PRESENT	0
247604	247284	04018C	PARTICIPANT	\N	PRESENT	0
247595	247284	14265W	PARTICIPANT	\N	PRESENT	0
247596	247284	14193X	PARTICIPANT	\N	PRESENT	0
247597	247284	08047A	PARTICIPANT	\N	PRESENT	0
247598	247284	04049K	PARTICIPANT	\N	PRESENT	0
247599	247284	19533U	PARTICIPANT	\N	PRESENT	0
247600	247284	14237S	PARTICIPANT	\N	PRESENT	0
247605	247284	14235Q	PARTICIPANT	\N	PRESENT	0
247602	247284	14173T	PARTICIPANT	\N	PRESENT	0
247603	247284	14215L	PARTICIPANT	\N	PRESENT	0
247606	247284	02002K	PARTICIPANT	\N	PRESENT	0
247607	247284	19697Q	PARTICIPANT	\N	PRESENT	0
247608	247284	11053K	PARTICIPANT	\N	PRESENT	0
247609	247284	08056B	PARTICIPANT	\N	PRESENT	0
247610	247284	14093U	PARTICIPANT	\N	PRESENT	0
247611	247284	11031D	PARTICIPANT	\N	PRESENT	0
247612	247284	19619A	PARTICIPANT	\N	PRESENT	0
247613	247284	19551W	PARTICIPANT	\N	PRESENT	0
247614	247284	19699S	PARTICIPANT	\N	PRESENT	0
247615	247284	11063M	PARTICIPANT	\N	PRESENT	0
247616	247284	12041X	PARTICIPANT	\N	PRESENT	0
247617	247284	14255U	PARTICIPANT	\N	PRESENT	0
247618	247284	98029W	PARTICIPANT	\N	PRESENT	0
247619	247284	19479G	PARTICIPANT	\N	PRESENT	0
247620	247284	14169X	PARTICIPANT	\N	PRESENT	0
247621	247284	19421M	PARTICIPANT	\N	PRESENT	0
247622	247284	19685L	PARTICIPANT	\N	PRESENT	0
247623	247284	19581D	PARTICIPANT	\N	PRESENT	0
247624	247284	11043H	PARTICIPANT	\N	PRESENT	0
247625	247284	08044W	PARTICIPANT	\N	PRESENT	0
247626	247284	19611R	PARTICIPANT	\N	PRESENT	0
247627	247284	14135M	PARTICIPANT	\N	PRESENT	0
247628	247284	11049P	PARTICIPANT	\N	PRESENT	0
247629	247284	07029T	PARTICIPANT	\N	PRESENT	0
247630	247284	08021P	PARTICIPANT	\N	PRESENT	0
247631	247284	04097T	PARTICIPANT	\N	PRESENT	0
247632	247284	11110B	PARTICIPANT	\N	PRESENT	0
247633	247284	11115U	PARTICIPANT	\N	PRESENT	0
247634	247284	04008A	PARTICIPANT	\N	PRESENT	0
247950	240295	86034E	PARTICIPANT	\N	PRESENT	0
247951	240295	11031D	PARTICIPANT	\N	PRESENT	0
247952	240295	04085P	PARTICIPANT	\N	PRESENT	0
247953	240295	11040E	PARTICIPANT	\N	PRESENT	0
247954	240295	04038G	PARTICIPANT	\N	PRESENT	0
247955	240295	14235Q	PARTICIPANT	\N	PRESENT	0
247956	240295	11056N	PARTICIPANT	\N	PRESENT	0
247957	240295	11063M	PARTICIPANT	\N	PRESENT	0
247959	240295	19347U	PARTICIPANT	\N	PRESENT	0
247960	240295	19695N	PARTICIPANT	\N	PRESENT	0
247961	240295	19565D	PARTICIPANT	\N	PRESENT	0
247962	240295	19711U	PARTICIPANT	\N	PRESENT	0
247963	240295	19593H	PARTICIPANT	\N	PRESENT	0
247964	240295	04008A	PARTICIPANT	\N	PRESENT	0
247965	240295	14239U	PARTICIPANT	\N	PRESENT	0
247966	240295	04045F	PARTICIPANT	\N	PRESENT	0
247967	240295	08061X	PARTICIPANT	\N	PRESENT	0
247968	240295	14157T	PARTICIPANT	\N	PRESENT	0
247969	240295	19651A	PARTICIPANT	\N	PRESENT	0
247970	240295	11083R	PARTICIPANT	\N	PRESENT	0
247971	240295	19637C	PARTICIPANT	\N	PRESENT	0
247972	240295	96004D	PARTICIPANT	\N	PRESENT	0
247973	240295	19697Q	PARTICIPANT	\N	PRESENT	0
247974	240295	08073C	PARTICIPANT	\N	PRESENT	0
247975	240295	19679N	PARTICIPANT	\N	PRESENT	0
247976	240295	14039A	PARTICIPANT	\N	PRESENT	0
247977	240295	19659J	PARTICIPANT	\N	PRESENT	0
247978	240295	19329S	PARTICIPANT	\N	PRESENT	0
247979	240295	11072N	PARTICIPANT	\N	PRESENT	0
247980	240295	04097T	PARTICIPANT	\N	PRESENT	0
247981	240295	19301E	PARTICIPANT	\N	PRESENT	0
247982	240295	08039A	PARTICIPANT	\N	PRESENT	0
247983	240295	14261S	PARTICIPANT	\N	PRESENT	0
247984	240295	08020N	PARTICIPANT	\N	PRESENT	0
247985	240295	19629C	PARTICIPANT	\N	PRESENT	0
247986	240295	14123H	PARTICIPANT	\N	PRESENT	0
247987	240295	19687N	PARTICIPANT	\N	PRESENT	0
247988	240295	08010L	PARTICIPANT	\N	PRESENT	0
247989	240295	19563B	PARTICIPANT	\N	PRESENT	0
247990	240295	14201E	PARTICIPANT	\N	PRESENT	0
247991	240295	19643A	PARTICIPANT	\N	PRESENT	0
247992	240295	14241N	PARTICIPANT	\N	PRESENT	0
247993	240295	04071H	PARTICIPANT	\N	PRESENT	0
257465	240325	04086Q	PARTICIPANT	\N	PRESENT	0
257466	240325	14033T	PARTICIPANT	\N	PRESENT	0
257467	240325	19711U	PARTICIPANT	\N	PRESENT	0
257468	240325	04088S	PARTICIPANT	\N	PRESENT	0
257469	255990	19333N	PARTICIPANT	\N	PRESENT	0
257470	255990	15447F	PARTICIPANT	\N	PRESENT	0
257471	255990	14029X	PARTICIPANT	\N	PRESENT	0
257472	255990	08060W	PARTICIPANT	\N	PRESENT	0
257473	255990	14031R	PARTICIPANT	\N	PRESENT	0
257474	255990	14157T	PARTICIPANT	\N	PRESENT	0
257475	240325	19575F	PARTICIPANT	\N	PRESENT	0
257476	240325	14331P	PARTICIPANT	\N	PRESENT	0
257477	240325	19483C	PARTICIPANT	\N	PRESENT	0
257478	255990	14169X	PARTICIPANT	\N	PRESENT	0
257479	240325	14055N	PARTICIPANT	\N	PRESENT	0
257480	240325	19731Y	PARTICIPANT	\N	PRESENT	0
257481	240325	14215L	PARTICIPANT	\N	PRESENT	0
257482	240325	14087W	PARTICIPANT	\N	PRESENT	0
257483	255990	18083K	PARTICIPANT	\N	PRESENT	0
257484	255990	14237S	PARTICIPANT	\N	PRESENT	0
257485	255990	19737F	PARTICIPANT	\N	PRESENT	0
257486	255990	14219Q	PARTICIPANT	\N	PRESENT	0
257488	257487	08058D	PRESIDENT	0	PRESENT	0
257489	240325	07004J	PARTICIPANT	\N	PRESENT	0
257490	240325	08044W	PARTICIPANT	\N	PRESENT	0
257491	240325	11033F	PARTICIPANT	\N	PRESENT	0
257492	240325	19347U	PARTICIPANT	\N	PRESENT	0
257493	240325	14229S	PARTICIPANT	\N	PRESENT	0
257494	240325	14081Q	PARTICIPANT	\N	PRESENT	0
257495	240325	17589D	PARTICIPANT	\N	PRESENT	0
257496	240325	19479G	PARTICIPANT	\N	PRESENT	0
257497	240325	19629C	PARTICIPANT	\N	PRESENT	0
257498	240325	19383Y	PARTICIPANT	\N	PRESENT	0
257499	240325	11067R	PARTICIPANT	\N	PRESENT	0
257534	255990	19681G	PARTICIPANT	\N	PRESENT	0
257501	240325	19543W	PARTICIPANT	\N	PRESENT	0
257502	240325	19349W	PARTICIPANT	\N	PRESENT	0
257503	240325	04018C	PARTICIPANT	\N	PRESENT	0
257504	257487	14097Y	PARTICIPANT	\N	PRESENT	0
257505	257487	19729F	PARTICIPANT	\N	PRESENT	0
257506	257487	19443T	PARTICIPANT	\N	PRESENT	0
257507	257487	08034U	PARTICIPANT	\N	PRESENT	0
257508	257487	11049P	PARTICIPANT	\N	PRESENT	0
257509	257487	19721W	PARTICIPANT	\N	PRESENT	0
257510	240325	19253P	PARTICIPANT	\N	PRESENT	0
257511	257487	19581D	PARTICIPANT	\N	EXCUSE	0
257512	240325	14151M	PARTICIPANT	\N	PRESENT	0
257513	240325	14259Y	PARTICIPANT	\N	PRESENT	0
257535	257487	19703U	PARTICIPANT	\N	PRESENT	0
257533	240325	11040E	PARTICIPANT	\N	PRESENT	0
257536	257487	04071H	PARTICIPANT	\N	PRESENT	0
257537	240325	19569H	PARTICIPANT	\N	PRESENT	0
257538	240325	95030B	PARTICIPANT	\N	PRESENT	0
257539	240325	04070G	PARTICIPANT	\N	PRESENT	0
257540	240325	07029T	PARTICIPANT	\N	PRESENT	0
257541	240325	19507S	PARTICIPANT	\N	PRESENT	0
257542	240325	11027H	PARTICIPANT	\N	PRESENT	0
257544	240325	14281W	PARTICIPANT	\N	PRESENT	0
257545	257543	89017R	PARTICIPANT	\N	PRESENT	0
257546	240325	19611R	PARTICIPANT	\N	PRESENT	0
257547	257543	14133K	PARTICIPANT	\N	PRESENT	0
257548	257543	04085P	PARTICIPANT	\N	PRESENT	0
257549	257543	04059M	PARTICIPANT	\N	PRESENT	0
257550	257543	05008E	PARTICIPANT	\N	PRESENT	0
257551	255990	19713W	PARTICIPANT	\N	PRESENT	0
257552	257543	96004D	PARTICIPANT	\N	PRESENT	0
257553	257543	04040A	PARTICIPANT	\N	PRESENT	0
257554	257543	04086Q	PARTICIPANT	\N	PRESENT	0
257555	257543	08011M	PARTICIPANT	\N	PRESENT	0
257556	257543	14034U	PARTICIPANT	\N	PRESENT	0
257557	257543	14033T	PARTICIPANT	\N	PRESENT	0
257558	257543	11048N	PARTICIPANT	\N	PRESENT	0
257559	257543	14021P	PARTICIPANT	\N	PRESENT	0
257560	257543	14159V	PARTICIPANT	\N	PRESENT	0
257561	257543	08039A	PARTICIPANT	\N	PRESENT	0
257562	257543	01043Q	PARTICIPANT	\N	PRESENT	0
257563	257543	14251Q	PARTICIPANT	\N	PRESENT	0
257564	257543	04092N	PARTICIPANT	\N	PRESENT	0
257565	257543	11072N	PARTICIPANT	\N	PRESENT	0
257566	257543	08061X	PARTICIPANT	\N	PRESENT	0
257567	257543	11012A	PARTICIPANT	\N	PRESENT	0
257568	257543	04033B	PARTICIPANT	\N	PRESENT	0
257569	257543	01034P	PARTICIPANT	\N	PRESENT	0
257570	240325	19335Q	PARTICIPANT	\N	PRESENT	0
257572	240325	19747H	PARTICIPANT	\N	PRESENT	0
257573	255990	14103D	PARTICIPANT	\N	PRESENT	0
257574	240325	14327T	PARTICIPANT	\N	PRESENT	0
257575	257571	89017R	PARTICIPANT	\N	PRESENT	0
257576	257571	04085P	PARTICIPANT	\N	PRESENT	0
257577	257571	05008E	PARTICIPANT	\N	PRESENT	0
257578	257571	96004D	PARTICIPANT	\N	PRESENT	0
257579	257571	04040A	PARTICIPANT	\N	PRESENT	0
257580	257571	04086Q	PARTICIPANT	\N	PRESENT	0
257581	257571	11070L	PARTICIPANT	\N	PRESENT	0
257582	240325	14069U	PARTICIPANT	\N	PRESENT	0
257583	240325	87003B	PARTICIPANT	\N	PRESENT	0
257584	257571	11074Q	PARTICIPANT	\N	PRESENT	0
257585	240325	14147R	PARTICIPANT	\N	PRESENT	0
257586	257571	14034U	PARTICIPANT	\N	PRESENT	0
257587	257571	11048N	PARTICIPANT	\N	PRESENT	0
257588	257571	11077T	PARTICIPANT	\N	PRESENT	0
257589	257571	14251Q	PARTICIPANT	\N	PRESENT	0
257590	240325	19719D	PARTICIPANT	\N	PRESENT	0
257591	257571	08009T	PARTICIPANT	\N	PRESENT	0
257592	240325	19441R	PARTICIPANT	\N	PRESENT	0
257593	257571	04092N	PARTICIPANT	\N	PRESENT	0
257594	257571	08011M	PARTICIPANT	\N	PRESENT	0
257595	257571	04070G	PARTICIPANT	\N	PRESENT	0
257596	257571	08061X	PARTICIPANT	\N	PRESENT	0
257597	257571	98018T	PARTICIPANT	\N	PRESENT	0
257598	257571	11090Q	PARTICIPANT	\N	PRESENT	0
257599	257571	11012A	PARTICIPANT	\N	PRESENT	0
257600	257571	04033B	PARTICIPANT	\N	PRESENT	0
257601	257571	01028R	PARTICIPANT	\N	PRESENT	0
257602	257571	04044E	PARTICIPANT	\N	PRESENT	0
257603	257571	01034P	PARTICIPANT	\N	PRESENT	0
257604	255990	19383Y	PARTICIPANT	\N	PRESENT	0
257605	240325	19593H	PARTICIPANT	\N	PRESENT	0
257606	240325	19631V	PARTICIPANT	\N	PRESENT	0
257607	240325	19725B	PARTICIPANT	\N	PRESENT	0
257608	240325	14235Q	PARTICIPANT	\N	PRESENT	0
257609	240325	19695N	PARTICIPANT	\N	PRESENT	0
257610	240325	14083S	PARTICIPANT	\N	PRESENT	0
257611	240325	04033B	PARTICIPANT	\N	PRESENT	0
257612	255990	19733B	PARTICIPANT	\N	PRESENT	0
257613	240325	19447X	PARTICIPANT	\N	PRESENT	0
257614	240325	11048N	PARTICIPANT	\N	PRESENT	0
257615	240325	11012A	PARTICIPANT	\N	PRESENT	0
257616	240325	19563B	PARTICIPANT	\N	PRESENT	0
257617	240325	19553Y	PARTICIPANT	\N	PRESENT	0
257618	240325	14135M	PARTICIPANT	\N	PRESENT	0
258769	258748	96004D	PARTICIPANT	\N	EXCUSE	0
258770	258752	96004D	PARTICIPANT	\N	EXCUSE	0
258797	258796	80013X	PARTICIPANT	\N	PRESENT	0
258798	258796	14221J	PARTICIPANT	\N	PRESENT	0
258799	258796	04043D	PARTICIPANT	\N	PRESENT	0
258800	258796	14239U	PARTICIPANT	\N	EXCUSE	0
258801	258796	14093U	PARTICIPANT	\N	EXCUSE	0
258802	258796	19663E	PARTICIPANT	\N	EXCUSE	0
258803	258796	19553Y	PARTICIPANT	\N	EXCUSE	0
258804	258796	19511N	PARTICIPANT	\N	EXCUSE	0
258805	258796	04061F	PARTICIPANT	\N	EXCUSE	0
258806	258796	19723Y	PARTICIPANT	\N	EXCUSE	0
258807	258796	19709B	PARTICIPANT	\N	EXCUSE	0
258808	258796	01048V	PARTICIPANT	\N	EXCUSE	0
258809	258796	19593H	PARTICIPANT	\N	EXCUSE	0
258810	258796	19533U	PARTICIPANT	\N	EXCUSE	0
258811	258796	01058X	PARTICIPANT	\N	EXCUSE	0
258812	258796	19503N	PARTICIPANT	\N	EXCUSE	0
258824	258796	14299H	PARTICIPANT	\N	PRESENT	0
258879	258748	14038Y	PARTICIPANT	\N	EXCUSE	0
258880	258752	14038Y	PARTICIPANT	\N	EXCUSE	0
258943	258752	19583F	PARTICIPANT	\N	EXCUSE	0
258971	258970	14225N	PARTICIPANT	\N	PRESENT	0
259001	259000	14111D	PARTICIPANT	\N	PRESENT	0
241233	241232	96004D	PARTICIPANT	\N	EXCUSE	0
241234	241232	14331P	PARTICIPANT	\N	EXCUSE	0
241236	241235	96004D	PARTICIPANT	\N	EXCUSE	0
241237	241235	14135M	PARTICIPANT	\N	EXCUSE	0
241238	241235	19631V	PARTICIPANT	\N	EXCUSE	0
241239	241232	14219Q	PARTICIPANT	\N	EXCUSE	0
241780	239695	07034Q	PARTICIPANT	\N	PRESENT	0
241781	239695	19543W	PARTICIPANT	\N	PRESENT	0
241782	239695	14239U	PARTICIPANT	\N	PRESENT	0
241783	239695	14147R	PARTICIPANT	\N	PRESENT	0
241784	239695	19349W	PARTICIPANT	\N	PRESENT	0
241785	239695	19637C	PARTICIPANT	\N	PRESENT	0
241786	239695	19671E	PARTICIPANT	\N	PRESENT	0
241787	239695	19659J	PARTICIPANT	\N	PRESENT	0
241788	239695	14217N	PARTICIPANT	\N	PRESENT	0
241789	239695	19697Q	PARTICIPANT	\N	PRESENT	0
241790	239695	19675J	PARTICIPANT	\N	PRESENT	0
241791	239695	08073C	PARTICIPANT	\N	PRESENT	0
241792	239695	14357A	PARTICIPANT	\N	PRESENT	0
241793	239695	14039A	PARTICIPANT	\N	PRESENT	0
241794	239695	14329V	PARTICIPANT	\N	PRESENT	0
241795	239695	19483C	PARTICIPANT	\N	PRESENT	0
241796	239695	19329S	PARTICIPANT	\N	PRESENT	0
241797	239695	04018C	PARTICIPANT	\N	PRESENT	0
241798	239695	19301E	PARTICIPANT	\N	PRESENT	0
241799	239695	04033B	PARTICIPANT	\N	PRESENT	0
241878	239695	19685L	PARTICIPANT	\N	PRESENT	0
241879	239695	08043V	PARTICIPANT	\N	PRESENT	0
241880	239695	19731Y	PARTICIPANT	\N	PRESENT	0
241803	239695	01060R	PARTICIPANT	\N	PRESENT	0
241804	239695	11012A	PARTICIPANT	\N	PRESENT	0
241805	239695	88008L	PARTICIPANT	\N	PRESENT	0
241806	239695	19707Y	PARTICIPANT	\N	PRESENT	0
241807	239695	14034U	PARTICIPANT	\N	PRESENT	0
241808	239695	19705W	PARTICIPANT	\N	PRESENT	0
241809	239695	08015R	PARTICIPANT	\N	PRESENT	0
241810	239695	19253P	PARTICIPANT	\N	PRESENT	0
241811	239695	19693L	PARTICIPANT	\N	PRESENT	0
241812	239695	08049C	PARTICIPANT	\N	PRESENT	0
241813	239695	19629C	PARTICIPANT	\N	PRESENT	0
241814	239695	19563B	PARTICIPANT	\N	PRESENT	0
241815	239695	19729F	PARTICIPANT	\N	PRESENT	0
241816	239695	19289C	PARTICIPANT	\N	PRESENT	0
241817	239695	98022P	PARTICIPANT	\N	PRESENT	0
241818	239695	14241N	PARTICIPANT	\N	PRESENT	0
241819	239695	11099A	PARTICIPANT	\N	PRESENT	0
241820	239695	14105F	PARTICIPANT	\N	PRESENT	0
241821	239695	19387D	PARTICIPANT	\N	PRESENT	0
241822	239695	08047A	PARTICIPANT	\N	PRESENT	0
241823	239695	19719D	PARTICIPANT	\N	PRESENT	0
241824	239695	14115H	PARTICIPANT	\N	PRESENT	0
241825	239695	11049P	PARTICIPANT	\N	PRESENT	0
241826	239695	17589D	PARTICIPANT	\N	PRESENT	0
241827	239695	14111D	PARTICIPANT	\N	PRESENT	0
241828	239695	14253S	PARTICIPANT	\N	PRESENT	0
241830	239695	14251Q	PARTICIPANT	\N	PRESENT	0
241831	239695	04043D	PARTICIPANT	\N	PRESENT	0
241832	239695	11064N	PARTICIPANT	\N	PRESENT	0
241833	239695	14237S	PARTICIPANT	\N	PRESENT	0
241834	239695	14249W	PARTICIPANT	\N	PRESENT	0
241835	239695	19269X	PARTICIPANT	\N	PRESENT	0
241836	239695	19421M	PARTICIPANT	\N	PRESENT	0
241837	239695	19585H	PARTICIPANT	\N	PRESENT	0
241838	239695	98035U	PARTICIPANT	\N	PRESENT	0
241839	239695	14159V	PARTICIPANT	\N	PRESENT	0
241840	239695	11077T	PARTICIPANT	\N	PRESENT	0
241841	239695	08012N	PARTICIPANT	\N	PRESENT	0
241842	239695	04092N	PARTICIPANT	\N	PRESENT	0
241843	239695	04059M	PARTICIPANT	\N	PRESENT	0
241844	239695	10015M	PARTICIPANT	\N	PRESENT	0
241845	239695	11074Q	PARTICIPANT	\N	PRESENT	0
241846	239695	01028R	PARTICIPANT	\N	PRESENT	0
241847	239695	08028W	PARTICIPANT	\N	PRESENT	0
241848	239695	14051J	PARTICIPANT	\N	PRESENT	0
241849	239695	11027H	PARTICIPANT	\N	PRESENT	0
241850	239695	08052W	PARTICIPANT	\N	PRESENT	0
241851	239695	14229S	PARTICIPANT	\N	PRESENT	0
241852	239695	14169X	PARTICIPANT	\N	PRESENT	0
241853	239695	08055A	PARTICIPANT	\N	PRESENT	0
241854	239695	14123H	PARTICIPANT	\N	PRESENT	0
241855	239695	08016S	PARTICIPANT	\N	PRESENT	0
241856	239695	14026U	PARTICIPANT	\N	PRESENT	0
241857	239695	14107H	PARTICIPANT	\N	PRESENT	0
241858	239695	02002K	PARTICIPANT	\N	PRESENT	0
241859	239695	08069G	PARTICIPANT	\N	PRESENT	0
241860	239695	01058X	PARTICIPANT	\N	PRESENT	0
241861	239695	11109J	PARTICIPANT	\N	PRESENT	0
241862	239695	99004R	PARTICIPANT	\N	PRESENT	0
241863	239695	19549D	PARTICIPANT	\N	PRESENT	0
241864	239695	95030B	PARTICIPANT	\N	PRESENT	0
241865	239695	04047H	PARTICIPANT	\N	PRESENT	0
241866	239695	14021P	PARTICIPANT	\N	PRESENT	0
241867	239695	08045X	PARTICIPANT	\N	PRESENT	0
241869	239695	04035D	PARTICIPANT	\N	PRESENT	0
241870	239695	14151M	PARTICIPANT	\N	PRESENT	0
241871	239695	98024R	PARTICIPANT	\N	PRESENT	0
241873	239695	14197C	PARTICIPANT	\N	PRESENT	0
241874	239695	80013X	PARTICIPANT	\N	PRESENT	0
241875	239695	08060W	PARTICIPANT	\N	PRESENT	0
241877	239695	08038Y	PARTICIPANT	\N	PRESENT	0
241881	239695	11066Q	PARTICIPANT	\N	PRESENT	0
241882	239695	14065Q	PARTICIPANT	\N	PRESENT	0
241883	239695	04044E	PARTICIPANT	\N	PRESENT	0
241884	239695	11104D	PARTICIPANT	\N	PRESENT	0
241885	239695	05008E	PARTICIPANT	\N	PRESENT	0
241886	239695	08058D	PARTICIPANT	\N	PRESENT	0
241887	239695	08035V	PARTICIPANT	\N	PRESENT	0
241888	239695	14071N	PARTICIPANT	\N	PRESENT	0
241889	239695	19489J	PARTICIPANT	\N	PRESENT	0
241890	239695	14187A	PARTICIPANT	\N	PRESENT	0
241891	239695	19727D	PARTICIPANT	\N	PRESENT	0
241892	239695	17779H	PARTICIPANT	\N	PRESENT	0
241893	239695	14121F	PARTICIPANT	\N	PRESENT	0
241894	239695	14085U	PARTICIPANT	\N	PRESENT	0
241895	239695	08017T	PARTICIPANT	\N	PRESENT	0
241896	239695	08053X	PARTICIPANT	\N	PRESENT	0
241897	239695	96004D	PARTICIPANT	\N	PRESENT	0
241898	239695	19525U	PARTICIPANT	\N	PRESENT	0
241899	239695	11045K	PARTICIPANT	\N	PRESENT	0
241900	239695	14081Q	PARTICIPANT	\N	PRESENT	0
241901	239695	17583W	PARTICIPANT	\N	PRESENT	0
241902	239695	11041F	PARTICIPANT	\N	PRESENT	0
241903	239695	14207L	PARTICIPANT	\N	PRESENT	0
241904	239695	19725B	PARTICIPANT	\N	PRESENT	0
241905	239695	14119M	PARTICIPANT	\N	PRESENT	0
241906	239695	08014Q	PARTICIPANT	\N	PRESENT	0
241907	239695	14001X	PARTICIPANT	\N	PRESENT	0
241908	239695	19683J	PARTICIPANT	\N	PRESENT	0
241909	239695	80027E	PARTICIPANT	\N	PRESENT	0
241910	239695	11054L	PARTICIPANT	\N	PRESENT	0
241911	239695	19689Q	PARTICIPANT	\N	PRESENT	0
241912	239695	19669L	PARTICIPANT	\N	PRESENT	0
241913	239695	19413M	PARTICIPANT	\N	PRESENT	0
241914	239695	19503N	PARTICIPANT	\N	PRESENT	0
241915	239695	19399H	PARTICIPANT	\N	PRESENT	0
241916	239695	19251M	PARTICIPANT	\N	PRESENT	0
241917	239695	19591F	PARTICIPANT	\N	PRESENT	0
241918	239695	11026G	PARTICIPANT	\N	PRESENT	0
241920	239695	11067R	PARTICIPANT	\N	PRESENT	0
241921	239695	14227Q	PARTICIPANT	\N	PRESENT	0
241922	239695	19527W	PARTICIPANT	\N	PRESENT	0
241923	239695	14059S	PARTICIPANT	\N	PRESENT	0
241924	239695	14063N	PARTICIPANT	\N	PRESENT	0
241925	239695	14257W	PARTICIPANT	\N	PRESENT	0
241926	239695	19733B	PARTICIPANT	\N	PRESENT	0
241927	239695	19631V	PARTICIPANT	\N	PRESENT	0
241928	239695	14109K	PARTICIPANT	\N	PRESENT	0
241929	239695	14097Y	PARTICIPANT	\N	PRESENT	0
241930	239695	14195A	PARTICIPANT	\N	PRESENT	0
241931	239695	19415P	PARTICIPANT	\N	PRESENT	0
241932	239695	14213J	PARTICIPANT	\N	PRESENT	0
241933	239695	04057K	PARTICIPANT	\N	PRESENT	0
241934	239695	04008A	PARTICIPANT	\N	PRESENT	0
241935	239695	11103C	PARTICIPANT	\N	PRESENT	0
241936	239695	14231L	PARTICIPANT	\N	PRESENT	0
241937	239695	08044W	PARTICIPANT	\N	PRESENT	0
241938	239695	01034P	PARTICIPANT	\N	PRESENT	0
241939	239695	19369B	PARTICIPANT	\N	PRESENT	0
241940	239695	19691J	PARTICIPANT	\N	PRESENT	0
241941	239695	11053K	PARTICIPANT	\N	PRESENT	0
241942	239695	19611R	PARTICIPANT	\N	PRESENT	0
241943	239695	19511N	PARTICIPANT	\N	PRESENT	0
241944	239695	19619A	PARTICIPANT	\N	PRESENT	0
241945	239695	19721W	PARTICIPANT	\N	PRESENT	0
241946	239695	19699S	PARTICIPANT	\N	PRESENT	0
258886	258748	19729F	PARTICIPANT	\N	EXCUSE	0
258888	258748	14199E	PARTICIPANT	\N	EXCUSE	0
258889	258752	14199E	PARTICIPANT	\N	EXCUSE	0
259750	259749	11064N	PARTICIPANT	\N	PRESENT	0
261185	261184	14079W	PARTICIPANT	\N	PRESENT	0
261186	261184	97011G	PARTICIPANT	\N	PRESENT	0
261187	261184	11026G	PARTICIPANT	\N	PRESENT	0
261188	261184	19711U	PARTICIPANT	\N	PRESENT	0
261189	261184	08034U	PARTICIPANT	\N	PRESENT	0
261190	261184	14169X	PARTICIPANT	\N	PRESENT	0
264284	256029	19593H	PARTICIPANT	\N	PRESENT	0
264285	256030	14221J	PARTICIPANT	\N	PRESENT	0
264286	256030	19593H	PARTICIPANT	\N	PRESENT	0
264292	264200	11074Q	PARTICIPANT	\N	PRESENT	0
264293	264200	08011M	PARTICIPANT	\N	PRESENT	0
264294	264200	88008L	PARTICIPANT	\N	PRESENT	0
264295	264200	14327T	PARTICIPANT	\N	PRESENT	0
264296	264200	04061F	PARTICIPANT	\N	PRESENT	0
264297	264200	01057W	PARTICIPANT	\N	PRESENT	0
264298	264200	11048N	PARTICIPANT	\N	PRESENT	0
264299	264200	14085U	PARTICIPANT	\N	PRESENT	0
264300	264200	07004J	PARTICIPANT	\N	PRESENT	0
264301	264200	07029T	PARTICIPANT	\N	PRESENT	0
264375	264374	14135M	PARTICIPANT	\N	PRESENT	0
264376	264374	19631V	PARTICIPANT	\N	PRESENT	0
264377	264374	14265W	PARTICIPANT	\N	PRESENT	0
264378	264374	01025N	PARTICIPANT	\N	PRESENT	0
264398	264397	14135M	PARTICIPANT	\N	PRESENT	0
264400	264397	19631V	PARTICIPANT	\N	PRESENT	0
264401	264397	14265W	PARTICIPANT	\N	PRESENT	0
264402	264397	01025N	PARTICIPANT	\N	PRESENT	0
264403	264397	19515S	PARTICIPANT	\N	PRESENT	0
264594	264593	14135M	PARTICIPANT	\N	PRESENT	0
264595	264593	19631V	PARTICIPANT	\N	PRESENT	0
264596	264593	19515S	PARTICIPANT	\N	PRESENT	0
264598	264597	14135M	PARTICIPANT	\N	PRESENT	0
264599	264597	19631V	PARTICIPANT	\N	PRESENT	0
264600	264597	14265W	PARTICIPANT	\N	PRESENT	0
264601	264597	19515S	PARTICIPANT	\N	PRESENT	0
264604	264602	14135M	PARTICIPANT	\N	PRESENT	0
264605	264602	19631V	PARTICIPANT	\N	PRESENT	0
264606	264602	14265W	PARTICIPANT	\N	PRESENT	0
264607	264602	19705W	PARTICIPANT	\N	PRESENT	0
264608	264602	19369B	PARTICIPANT	\N	PRESENT	0
264610	264609	14265W	PARTICIPANT	\N	PRESENT	0
264611	264609	19631V	PARTICIPANT	\N	PRESENT	0
264615	264613	14265W	PARTICIPANT	\N	PRESENT	0
264616	264613	19631V	PARTICIPANT	\N	PRESENT	0
264618	264617	14135M	PARTICIPANT	\N	PRESENT	0
264619	264617	19631V	PARTICIPANT	\N	PRESENT	0
264620	264617	14265W	PARTICIPANT	\N	PRESENT	0
264638	264637	96004D	PARTICIPANT	\N	PRESENT	0
264639	264637	14221J	PARTICIPANT	\N	PRESENT	0
264640	264637	10015M	PARTICIPANT	\N	PRESENT	0
265103	264302	19703U	PARTICIPANT	\N	PRESENT	0
265104	264302	04071H	PARTICIPANT	\N	PRESENT	0
265105	264302	19729F	PARTICIPANT	\N	PRESENT	0
265106	264302	19443T	PARTICIPANT	\N	PRESENT	0
265107	264302	08034U	PARTICIPANT	\N	PRESENT	0
265108	264302	08035V	PARTICIPANT	\N	PRESENT	0
265109	264302	08058D	PRESIDENT	0	PRESENT	0
265110	264302	19251M	PARTICIPANT	\N	PRESENT	0
265111	264302	19581D	PARTICIPANT	\N	PRESENT	0
265112	264302	11049P	PARTICIPANT	\N	PRESENT	0
265113	264302	19719D	PARTICIPANT	\N	PRESENT	0
265114	264302	19721W	PARTICIPANT	\N	PRESENT	0
265115	264302	14097Y	PARTICIPANT	\N	EXCUSE	0
265116	263044	11053K	PARTICIPANT	\N	PRESENT	0
265118	265117	11053K	PARTICIPANT	\N	PRESENT	0
265119	265117	14159V	PARTICIPANT	\N	PRESENT	0
265120	265117	05012A	PARTICIPANT	\N	PRESENT	0
265121	263044	11065P	PARTICIPANT	\N	PRESENT	0
266788	258757	14225N	PARTICIPANT	\N	EXCUSE	0
266789	258757	96004D	PARTICIPANT	\N	EXCUSE	0
266790	258757	14038Y	PARTICIPANT	\N	EXCUSE	0
266795	258758	11010L	PARTICIPANT	\N	EXCUSE	0
266796	258759	11010L	PARTICIPANT	\N	EXCUSE	0
266797	258759	19295A	PARTICIPANT	\N	EXCUSE	0
266882	266881	08055A	PARTICIPANT	\N	PRESENT	0
266883	266881	04047H	PARTICIPANT	\N	PRESENT	0
266884	266881	19545Y	PARTICIPANT	\N	PRESENT	0
266885	266881	14085U	PARTICIPANT	\N	PRESENT	0
266886	266881	11080N	PARTICIPANT	\N	PRESENT	0
266887	266881	11083R	PARTICIPANT	\N	PRESENT	0
266888	266881	01057W	PARTICIPANT	\N	PRESENT	0
266889	266881	19611R	PARTICIPANT	\N	EXCUSE	0
266890	266881	19687N	PARTICIPANT	\N	PRESENT	0
266891	266881	08049C	PARTICIPANT	\N	EXCUSE	0
266892	266881	14157T	PARTICIPANT	\N	PRESENT	0
266948	258757	14261S	PARTICIPANT	\N	PRESENT	0
266949	258757	14259Y	PARTICIPANT	\N	PRESENT	0
266950	258757	19691J	PARTICIPANT	\N	PRESENT	0
266951	258757	19715Y	PARTICIPANT	\N	PRESENT	0
266952	258757	14039A	PARTICIPANT	\N	PRESENT	0
266953	258757	14059S	PRESIDENT	0	PRESENT	0
266955	258757	08019V	PARTICIPANT	\N	EXCUSE	0
266956	258757	19657G	PARTICIPANT	\N	PRESENT	0
266957	258757	04043D	PARTICIPANT	\N	PRESENT	0
266958	258757	14331P	PARTICIPANT	\N	PRESENT	0
266960	258757	19703U	PARTICIPANT	\N	EXCUSE	0
267025	266808	19631V	PARTICIPANT	\N	PRESENT	0
267026	266808	19515S	PARTICIPANT	\N	PRESENT	0
267027	266808	19707Y	PARTICIPANT	\N	PRESENT	0
267028	266808	11081P	PARTICIPANT	\N	EXCUSE	0
267029	266808	19747H	PARTICIPANT	\N	PRESENT	0
267030	266808	08068F	PARTICIPANT	\N	PRESENT	0
267031	266808	14207L	PARTICIPANT	\N	PRESENT	0
267032	266808	11101A	PARTICIPANT	\N	EXCUSE	0
267033	266808	14329V	PARTICIPANT	\N	EXCUSE	0
267034	266808	19467C	PARTICIPANT	\N	EXCUSE	0
267035	266808	80013X	PARTICIPANT	\N	PRESENT	0
267036	266808	14357A	PARTICIPANT	\N	PRESENT	0
267037	266808	04089T	PARTICIPANT	\N	EXCUSE	0
267038	266808	14197C	PARTICIPANT	\N	EXCUSE	0
267039	266808	14187A	PARTICIPANT	\N	PRESENT	0
267040	266808	19695N	PARTICIPANT	\N	PRESENT	0
267041	266808	19565D	PARTICIPANT	\N	EXCUSE	0
267042	266808	14033T	PARTICIPANT	\N	PRESENT	0
267043	266808	19591F	PARTICIPANT	\N	EXCUSE	0
267044	266808	19511N	PARTICIPANT	\N	PRESENT	0
267045	266808	11099A	PARTICIPANT	\N	PRESENT	0
267046	266808	04049K	PARTICIPANT	\N	PRESENT	0
267047	266808	08015R	PARTICIPANT	\N	EXCUSE	0
267048	266808	19441R	PARTICIPANT	\N	PRESENT	0
267049	266808	19369B	PARTICIPANT	\N	EXCUSE	0
267050	266808	14257W	PARTICIPANT	\N	PRESENT	0
267051	266808	14265W	PARTICIPANT	\N	PRESENT	0
267052	266808	08021P	PARTICIPANT	\N	EXCUSE	0
267053	266808	04088S	PARTICIPANT	\N	PRESENT	0
267054	266808	11090Q	PRESIDENT	0	PRESENT	0
267055	266808	19269X	PARTICIPANT	\N	PRESENT	0
267056	266808	19705W	PARTICIPANT	\N	PRESENT	0
267057	266808	19619A	PARTICIPANT	\N	PRESENT	0
267058	266808	19301E	PARTICIPANT	\N	PRESENT	0
267059	266808	19413M	PARTICIPANT	\N	PRESENT	0
267062	266808	96004D	PARTICIPANT	\N	PRESENT	0
267063	266808	14089Y	PARTICIPANT	\N	PRESENT	0
267064	266808	08014Q	PARTICIPANT	\N	PRESENT	0
267065	266808	11083R	PARTICIPANT	\N	PRESENT	0
267066	266808	14026U	PARTICIPANT	\N	PRESENT	0
267067	266808	19725B	PARTICIPANT	\N	PRESENT	0
267068	266808	19569H	PARTICIPANT	\N	PRESENT	0
267069	266808	14097Y	PARTICIPANT	\N	PRESENT	0
267070	266808	14001X	PARTICIPANT	\N	PRESENT	0
267071	266808	14221J	PARTICIPANT	\N	PRESENT	0
267072	266808	19593H	PARTICIPANT	\N	PRESENT	0
267073	266808	14331P	PARTICIPANT	\N	PRESENT	0
267074	266808	10015M	PARTICIPANT	\N	PRESENT	0
267076	267075	14030Q	PRESIDENT	0	PRESENT	0
266786	258757	11010L	PARTICIPANT	\N	EXCUSE	0
266787	258757	19295A	PARTICIPANT	\N	EXCUSE	0
267077	267075	08043V	PARTICIPANT	\N	PRESENT	0
267078	267075	11031D	PARTICIPANT	\N	PRESENT	0
267079	267075	80013X	PARTICIPANT	\N	PRESENT	0
267080	267075	19731Y	PARTICIPANT	\N	PRESENT	0
267081	267075	11045K	PARTICIPANT	\N	PRESENT	0
267082	267075	19749K	PARTICIPANT	\N	PRESENT	0
267083	267075	08017T	PARTICIPANT	\N	PRESENT	0
267084	267075	19701S	PARTICIPANT	\N	EXCUSE	0
267085	267075	19693L	PARTICIPANT	\N	EXCUSE	0
267086	267075	08031R	PARTICIPANT	\N	EXCUSE	0
267095	266808	08028W	PARTICIPANT	\N	EXCUSE	0
247164	247163	08014Q	PARTICIPANT	\N	PRESENT	0
247165	247163	14357A	PARTICIPANT	\N	PRESENT	0
247166	247163	14249W	PARTICIPANT	\N	PRESENT	0
247167	247163	11083R	PARTICIPANT	\N	PRESENT	0
247168	247163	14033T	PARTICIPANT	\N	PRESENT	0
247169	247163	19725B	PARTICIPANT	\N	PRESENT	0
247170	247163	95037J	PARTICIPANT	\N	PRESENT	0
247171	247163	14097Y	PARTICIPANT	\N	PRESENT	0
247172	247163	14061L	PARTICIPANT	\N	PRESENT	0
247173	247163	14073Q	PARTICIPANT	\N	PRESENT	0
247174	247163	14001X	PARTICIPANT	\N	PRESENT	0
247175	247163	14221J	PARTICIPANT	\N	PRESENT	0
247176	247163	19563B	PARTICIPANT	\N	PRESENT	0
247177	247163	14331P	PARTICIPANT	\N	PRESENT	0
247178	247163	10015M	PRESIDENT	0	PRESENT	0
247179	247163	14133K	PARTICIPANT	\N	EXCUSE	0
247180	247163	14065Q	PARTICIPANT	\N	EXCUSE	0
247181	247163	96004D	PARTICIPANT	\N	EXCUSE	0
247182	247163	14089Y	PARTICIPANT	\N	EXCUSE	0
247183	247163	04097T	PARTICIPANT	\N	EXCUSE	0
247184	247163	11026G	PARTICIPANT	\N	EXCUSE	0
247185	247163	14237S	PARTICIPANT	\N	EXCUSE	0
247186	247163	04057K	PARTICIPANT	\N	EXCUSE	0
247187	247163	14135M	PARTICIPANT	\N	EXCUSE	0
247188	247163	11027H	PARTICIPANT	\N	PRESENT	0
247189	247163	11054L	PARTICIPANT	\N	PRESENT	0
247191	247190	11083R	PARTICIPANT	\N	PRESENT	0
247192	247190	04057K	PARTICIPANT	\N	PRESENT	0
247994	240295	11099A	PARTICIPANT	\N	PRESENT	0
247995	240295	19289C	PARTICIPANT	\N	PRESENT	0
247996	240295	10015M	PARTICIPANT	\N	PRESENT	0
247997	240295	95037J	PARTICIPANT	\N	PRESENT	0
247998	240295	11012A	PARTICIPANT	\N	PRESENT	0
247999	240295	08031R	PARTICIPANT	\N	PRESENT	0
248000	240295	14223L	PARTICIPANT	\N	PRESENT	0
248001	240295	88008L	PARTICIPANT	\N	PRESENT	0
248002	240295	19253P	PARTICIPANT	\N	PRESENT	0
248003	240295	19515S	PARTICIPANT	\N	PRESENT	0
248004	240295	11065P	PARTICIPANT	\N	PRESENT	0
248005	240295	14191V	PARTICIPANT	\N	PRESENT	0
248006	240295	98022P	PARTICIPANT	\N	PRESENT	0
248007	240295	11080N	PARTICIPANT	\N	PRESENT	0
248008	240295	19387D	PARTICIPANT	\N	PRESENT	0
248009	240295	08069G	PARTICIPANT	\N	PRESENT	0
248010	240295	08049C	PARTICIPANT	\N	PRESENT	0
248011	240295	01057W	PARTICIPANT	\N	PRESENT	0
248012	240295	19717B	PARTICIPANT	\N	PRESENT	0
248013	240295	87003B	PARTICIPANT	\N	PRESENT	0
248014	240295	19681G	PARTICIPANT	\N	PRESENT	0
248016	240295	19703U	PARTICIPANT	\N	PRESENT	0
248017	240295	14031R	PARTICIPANT	\N	PRESENT	0
248018	240295	14195A	PARTICIPANT	\N	PRESENT	0
248019	240295	19583F	PARTICIPANT	\N	PRESENT	0
248020	240295	19667J	PARTICIPANT	\N	PRESENT	0
248021	240295	14111D	PARTICIPANT	\N	PRESENT	0
248022	240295	14251Q	PARTICIPANT	\N	PRESENT	0
248023	240295	11115U	PARTICIPANT	\N	PRESENT	0
248024	240295	17589D	PARTICIPANT	\N	PRESENT	0
248025	240295	04057K	PARTICIPANT	\N	PRESENT	0
248026	240295	19545Y	PARTICIPANT	\N	PRESENT	0
248027	240295	19585H	PARTICIPANT	\N	PRESENT	0
248028	240295	14038Y	PARTICIPANT	\N	PRESENT	0
248029	240295	14093U	PARTICIPANT	\N	PRESENT	0
248030	240295	19447X	PARTICIPANT	\N	PRESENT	0
248031	240295	98035U	PARTICIPANT	\N	PRESENT	0
248032	240295	14159V	PARTICIPANT	\N	PRESENT	0
248033	240295	19467C	PARTICIPANT	\N	PRESENT	0
248034	240295	04059M	PARTICIPANT	\N	PRESENT	0
248035	240295	19631V	PARTICIPANT	\N	PRESENT	0
248036	240295	19443T	PARTICIPANT	\N	PRESENT	0
248037	240295	08068F	PARTICIPANT	\N	PRESENT	0
248038	240295	14034U	PARTICIPANT	\N	PRESENT	0
248039	240295	19553Y	PARTICIPANT	\N	PRESENT	0
248040	240295	14029X	PARTICIPANT	\N	PRESENT	0
248041	240295	19709B	PARTICIPANT	\N	PRESENT	0
248042	240295	11027H	PARTICIPANT	\N	PRESENT	0
248043	240295	01028R	PARTICIPANT	\N	PRESENT	0
248044	240295	08052W	PARTICIPANT	\N	PRESENT	0
248045	240295	04088S	PARTICIPANT	\N	PRESENT	0
248046	240295	08055A	PARTICIPANT	\N	PRESENT	0
248047	240295	14107H	PARTICIPANT	\N	PRESENT	0
248048	240295	08018U	PARTICIPANT	\N	PRESENT	0
248049	240295	08045X	PARTICIPANT	\N	PRESENT	0
248050	240295	14225N	PARTICIPANT	\N	PRESENT	0
248051	240295	14021P	PARTICIPANT	\N	PRESENT	0
248052	240295	19715Y	PARTICIPANT	\N	PRESENT	0
248053	240295	92040Q	PARTICIPANT	\N	PRESENT	0
248054	240295	12016W	PARTICIPANT	\N	PRESENT	0
248055	240295	14151M	PARTICIPANT	\N	PRESENT	0
248056	240295	12041X	PARTICIPANT	\N	PRESENT	0
248057	240295	14087W	PARTICIPANT	\N	PRESENT	0
248058	240295	14197C	PARTICIPANT	\N	PRESENT	0
248059	240295	14033T	PARTICIPANT	\N	PRESENT	0
248060	240295	08024S	PARTICIPANT	\N	PRESENT	0
248061	240295	14135M	PARTICIPANT	\N	PRESENT	0
248062	240295	14028W	PARTICIPANT	\N	PRESENT	0
248063	240295	18083K	PARTICIPANT	\N	PRESENT	0
248064	240295	08012N	PARTICIPANT	\N	PRESENT	0
248065	240295	80027E	PARTICIPANT	\N	PRESENT	0
248066	240295	14121F	PARTICIPANT	\N	PRESENT	0
248067	240295	14085U	PARTICIPANT	\N	PRESENT	0
248068	240295	07029T	PARTICIPANT	\N	PRESENT	0
248069	240295	14355X	PARTICIPANT	\N	PRESENT	0
248070	240295	08035V	PARTICIPANT	\N	PRESENT	0
248071	240295	19531S	PARTICIPANT	\N	PRESENT	0
248072	240295	04086Q	PARTICIPANT	\N	PRESENT	0
248073	240295	14281W	PARTICIPANT	\N	PRESENT	0
248074	240295	04092N	PARTICIPANT	\N	PRESENT	0
248075	240295	11104D	PARTICIPANT	\N	PRESENT	0
248076	240295	11066Q	PARTICIPANT	\N	PRESENT	0
248077	240295	04044E	PARTICIPANT	\N	PRESENT	0
248078	240295	19649G	PARTICIPANT	\N	PRESENT	0
248079	240295	14065Q	PARTICIPANT	\N	PRESENT	0
248080	240295	19549D	PARTICIPANT	\N	PRESENT	0
248081	240295	05008E	PARTICIPANT	\N	PRESENT	0
248082	240295	08043V	PARTICIPANT	\N	PRESENT	0
248083	240295	11097X	PARTICIPANT	\N	PRESENT	0
248084	240295	14081Q	PARTICIPANT	\N	PRESENT	0
248085	240295	11110B	PARTICIPANT	\N	PRESENT	0
248086	240295	04047H	PARTICIPANT	\N	PRESENT	0
248087	240295	19727D	PARTICIPANT	\N	PRESENT	0
248088	240295	11045K	PARTICIPANT	\N	PRESENT	0
248089	240295	95030B	PARTICIPANT	\N	PRESENT	0
248090	240295	19525U	PARTICIPANT	\N	PRESENT	0
248091	240295	08017T	PARTICIPANT	\N	PRESENT	0
248092	240295	08058D	PARTICIPANT	\N	PRESENT	0
248093	240295	14069U	PARTICIPANT	\N	PRESENT	0
248094	240295	17779H	PARTICIPANT	\N	PRESENT	0
248095	240295	04033B	PARTICIPANT	\N	PRESENT	0
248096	240295	19489J	PARTICIPANT	\N	PRESENT	0
248097	240295	19689Q	PARTICIPANT	\N	PRESENT	0
248098	240295	14071N	PARTICIPANT	\N	PRESENT	0
248099	240295	11054L	PARTICIPANT	\N	PRESENT	0
248100	240295	19295A	PARTICIPANT	\N	PRESENT	0
248101	240295	19575F	PARTICIPANT	\N	PRESENT	0
248102	240295	19591F	PARTICIPANT	\N	PRESENT	0
248103	240295	19503N	PARTICIPANT	\N	PRESENT	0
248104	240295	11067R	PARTICIPANT	\N	PRESENT	0
248105	240295	14199E	PARTICIPANT	\N	PRESENT	0
248106	240295	08047A	PARTICIPANT	\N	PRESENT	0
248107	240295	19527W	PARTICIPANT	\N	PRESENT	0
248108	240295	14063N	PARTICIPANT	\N	PRESENT	0
248109	240295	14109K	PARTICIPANT	\N	PRESENT	0
248110	240295	14229S	PARTICIPANT	\N	PRESENT	0
248111	240295	19669L	PARTICIPANT	\N	PRESENT	0
248112	240295	14257W	PARTICIPANT	\N	PRESENT	0
248113	240295	11041F	PARTICIPANT	\N	PRESENT	0
248114	240295	19747H	PARTICIPANT	\N	PRESENT	0
248115	240295	10006L	PARTICIPANT	\N	PRESENT	0
248116	240295	08053X	PARTICIPANT	\N	PRESENT	0
248117	240295	14041T	PARTICIPANT	\N	PRESENT	0
248118	240295	01062T	PARTICIPANT	\N	PRESENT	0
248119	240295	14227Q	PARTICIPANT	\N	PRESENT	0
248120	240295	08034U	PARTICIPANT	\N	PRESENT	0
248121	240295	19413M	PARTICIPANT	\N	PRESENT	0
248122	240295	97011G	PARTICIPANT	\N	PRESENT	0
248123	240295	14051J	PARTICIPANT	\N	PRESENT	0
248124	240295	14213J	PARTICIPANT	\N	PRESENT	0
248125	240295	11048N	PARTICIPANT	\N	PRESENT	0
248126	240295	14207L	PARTICIPANT	\N	PRESENT	0
248127	240295	08014Q	PARTICIPANT	\N	PRESENT	0
248128	240295	19683J	PARTICIPANT	\N	PRESENT	0
248129	240295	19725B	PARTICIPANT	\N	PRESENT	0
248130	240295	19333N	PARTICIPANT	\N	PRESENT	0
248131	240295	14079W	PARTICIPANT	\N	PRESENT	0
248132	240295	19399H	PARTICIPANT	\N	PRESENT	0
248133	240295	11109J	PARTICIPANT	\N	PRESENT	0
248134	240295	80013X	PARTICIPANT	\N	PRESENT	0
248135	240295	11077T	PARTICIPANT	\N	PRESENT	0
256871	256869	14069U	PARTICIPANT	\N	PRESENT	0
259034	259033	08028W	PARTICIPANT	\N	PRESENT	0
259035	259033	08068F	PARTICIPANT	\N	PRESENT	0
259036	259033	19737F	PARTICIPANT	\N	PRESENT	0
259037	259033	14073Q	PARTICIPANT	\N	PRESENT	0
259039	259038	19575F	PARTICIPANT	\N	PRESENT	0
259040	259038	14083S	PARTICIPANT	\N	PRESENT	0
259041	259038	14038Y	PARTICIPANT	\N	PRESENT	0
259045	259038	17589D	PARTICIPANT	\N	PRESENT	0
259078	259070	19631V	PARTICIPANT	\N	PRESENT	0
259044	259038	14357A	PARTICIPANT	\N	PRESENT	0
259046	259038	01024M	PARTICIPANT	\N	PRESENT	0
259047	259038	14197C	PARTICIPANT	\N	PRESENT	0
259048	259038	14033T	PARTICIPANT	\N	PRESENT	0
259049	259038	19333N	PARTICIPANT	\N	PRESENT	0
259050	259038	04097T	PARTICIPANT	\N	PRESENT	0
259052	259038	14257W	PARTICIPANT	\N	PRESENT	0
259053	259038	19533U	PARTICIPANT	\N	PRESENT	0
259055	259038	04088S	PARTICIPANT	\N	PRESENT	0
259057	259038	19503N	PARTICIPANT	\N	PRESENT	0
259058	259038	19619A	PARTICIPANT	\N	PRESENT	0
259060	259038	01058X	PARTICIPANT	\N	PRESENT	0
259062	259038	14051J	PARTICIPANT	\N	PRESENT	0
259063	259038	95067Q	PARTICIPANT	\N	PRESENT	0
259077	259070	14135M	PARTICIPANT	\N	PRESENT	0
259079	259070	14265W	PARTICIPANT	\N	PRESENT	0
259082	259081	14051J	PARTICIPANT	\N	PRESENT	0
259084	259083	14051J	PARTICIPANT	\N	PRESENT	0
259085	259083	14237S	PARTICIPANT	\N	PRESENT	0
259087	259086	14051J	PARTICIPANT	\N	PRESENT	0
259091	259090	08028W	PARTICIPANT	\N	PRESENT	0
259092	259090	08068F	PARTICIPANT	\N	PRESENT	0
259093	259090	19737F	PARTICIPANT	\N	PRESENT	0
259094	250088	11072N	PARTICIPANT	\N	PRESENT	0
259096	259095	08058D	PRESIDENT	0	PRESENT	0
259097	259095	11049P	PARTICIPANT	\N	PRESENT	0
259098	259095	19721W	PARTICIPANT	\N	PRESENT	0
259099	259095	19443T	PARTICIPANT	\N	EXCUSE	0
259100	250088	07029T	PARTICIPANT	\N	PRESENT	0
259101	250088	19399H	PARTICIPANT	\N	PRESENT	0
259102	250088	04061F	PARTICIPANT	\N	PRESENT	0
259103	250088	14249W	PARTICIPANT	\N	PRESENT	0
259104	250088	14331P	PARTICIPANT	\N	PRESENT	0
259105	250088	14073Q	PARTICIPANT	\N	PRESENT	0
259106	250088	14231L	PARTICIPANT	\N	PRESENT	0
259107	250088	19629C	PARTICIPANT	\N	PRESENT	0
259108	250088	19387D	PARTICIPANT	\N	PRESENT	0
259109	250088	14147R	PARTICIPANT	\N	PRESENT	0
259110	250088	19349W	PARTICIPANT	\N	PRESENT	0
259111	250088	19585H	PARTICIPANT	\N	PRESENT	0
259112	250088	04018C	PARTICIPANT	\N	PRESENT	0
259113	250088	04047H	PARTICIPANT	\N	PRESENT	0
259114	250088	11033F	PARTICIPANT	\N	PRESENT	0
259115	250088	14197C	PARTICIPANT	\N	PRESENT	0
259116	250088	19649G	PARTICIPANT	\N	PRESENT	0
259117	250088	11067R	PARTICIPANT	\N	PRESENT	0
259118	250088	08045X	PARTICIPANT	\N	PRESENT	0
259119	250088	14191V	PARTICIPANT	\N	PRESENT	0
259152	250088	19591F	PARTICIPANT	\N	PRESENT	0
259121	250088	19447X	PARTICIPANT	\N	PRESENT	0
259122	250088	19467C	PARTICIPANT	\N	PRESENT	0
259123	250088	19693L	PARTICIPANT	\N	PRESENT	0
259124	250088	19701S	PARTICIPANT	\N	PRESENT	0
259125	250088	19383Y	PARTICIPANT	\N	PRESENT	0
259126	250088	14217N	PARTICIPANT	\N	PRESENT	0
259127	250088	11103C	PARTICIPANT	\N	PRESENT	0
259128	250088	07034Q	PARTICIPANT	\N	PRESENT	0
259129	250088	19711U	PARTICIPANT	\N	PRESENT	0
259130	250088	14265W	PARTICIPANT	\N	PRESENT	0
259131	250088	14030Q	PARTICIPANT	\N	PRESENT	0
259132	250088	19543W	PARTICIPANT	\N	PRESENT	0
259133	250088	11031D	PARTICIPANT	\N	PRESENT	0
259134	250088	11045K	PARTICIPANT	\N	PRESENT	0
259135	250088	19671E	PARTICIPANT	\N	PRESENT	0
259136	250088	19581D	PARTICIPANT	\N	PRESENT	0
259137	250088	14219Q	PARTICIPANT	\N	PRESENT	0
259138	250088	14021P	PARTICIPANT	\N	PRESENT	0
259139	250088	08068F	PARTICIPANT	\N	PRESENT	0
259140	250088	17583W	PARTICIPANT	\N	PRESENT	0
259141	250088	14083S	PARTICIPANT	\N	PRESENT	0
259142	250088	19719D	PARTICIPANT	\N	PRESENT	0
259143	250088	19689Q	PARTICIPANT	\N	PRESENT	0
259144	250088	19549D	PARTICIPANT	\N	PRESENT	0
259145	250088	14221J	PARTICIPANT	\N	PRESENT	0
259146	250088	11090Q	PARTICIPANT	\N	PRESENT	0
259147	250088	19679N	PARTICIPANT	\N	PRESENT	0
259148	250088	19643A	PARTICIPANT	\N	PRESENT	0
259149	250088	19253P	PARTICIPANT	\N	PRESENT	0
259150	250088	19515S	PARTICIPANT	\N	PRESENT	0
259151	250088	19415P	PARTICIPANT	\N	PRESENT	0
259153	250088	05008E	PARTICIPANT	\N	PRESENT	0
259154	250088	19731Y	PARTICIPANT	\N	PRESENT	0
259155	250088	19367Y	PARTICIPANT	\N	PRESENT	0
259156	250088	19483C	PARTICIPANT	\N	PRESENT	0
259157	250088	19533U	PARTICIPANT	\N	PRESENT	0
259158	250088	19503N	PARTICIPANT	\N	PRESENT	0
259159	250088	19553Y	PARTICIPANT	\N	PRESENT	0
259160	250088	99004R	PARTICIPANT	\N	PRESENT	0
259161	250088	08028W	PARTICIPANT	\N	PRESENT	0
259162	250088	14029X	PARTICIPANT	\N	PRESENT	0
259163	250088	08020N	PARTICIPANT	\N	PRESENT	0
259164	250088	14157T	PARTICIPANT	\N	PRESENT	0
259165	250088	11054L	PARTICIPANT	\N	PRESENT	0
259166	250088	19695N	PARTICIPANT	\N	PRESENT	0
259167	250088	19525U	PARTICIPANT	\N	PRESENT	0
259168	250088	19697Q	PARTICIPANT	\N	PRESENT	0
259169	250088	18083K	PARTICIPANT	\N	PRESENT	0
259170	250088	01028R	PARTICIPANT	\N	PRESENT	0
259171	250088	14065Q	PARTICIPANT	\N	PRESENT	0
259172	250088	19727D	PARTICIPANT	\N	PRESENT	0
259173	250088	11043H	PARTICIPANT	\N	PRESENT	0
259174	250088	14031R	PARTICIPANT	\N	PRESENT	0
259177	250088	14103D	PARTICIPANT	\N	PRESENT	0
259178	250088	08031R	PARTICIPANT	\N	PRESENT	0
259179	250088	14151M	PARTICIPANT	\N	PRESENT	0
259182	250088	01024M	PARTICIPANT	\N	PRESENT	0
259002	259000	19649G	PARTICIPANT	\N	PRESENT	0
259003	259000	07034Q	PARTICIPANT	\N	PRESENT	0
259004	259000	19253P	PARTICIPANT	\N	PRESENT	0
259005	259000	19543W	PARTICIPANT	\N	PRESENT	0
259006	259000	19585H	PARTICIPANT	\N	PRESENT	0
259007	259000	04047H	PARTICIPANT	\N	PRESENT	0
259008	259000	01028R	PARTICIPANT	\N	PRESENT	0
259009	259000	19447X	PARTICIPANT	\N	PRESENT	0
259010	259000	05008E	PRESIDENT	0	PRESENT	0
259011	259000	95063L	PARTICIPANT	\N	PRESENT	0
259012	259000	14147R	PARTICIPANT	\N	PRESENT	0
259013	259000	14151M	PARTICIPANT	\N	PRESENT	0
259014	259000	14069U	PARTICIPANT	\N	PRESENT	0
259015	259000	11049P	PARTICIPANT	\N	PRESENT	0
259016	259000	11072N	PARTICIPANT	\N	PRESENT	0
259017	259000	19729F	PARTICIPANT	\N	EXCUSE	0
259027	259000	14053L	PARTICIPANT	\N	PRESENT	0
259028	259000	14231L	PARTICIPANT	\N	PRESENT	0
259183	250088	14038Y	PARTICIPANT	\N	PRESENT	0
259184	250088	19631V	PARTICIPANT	\N	PRESENT	0
259185	250088	08060W	PARTICIPANT	\N	PRESENT	0
259186	250088	19747H	PARTICIPANT	\N	PRESENT	0
259187	250088	19479G	PARTICIPANT	\N	PRESENT	0
259188	250088	14257W	PARTICIPANT	\N	PRESENT	0
259189	250088	97011G	PARTICIPANT	\N	PRESENT	0
259190	250088	11066Q	PARTICIPANT	\N	PRESENT	0
259191	250088	14135M	PARTICIPANT	\N	PRESENT	0
259192	250088	14105F	PARTICIPANT	\N	PRESENT	0
259194	250088	95030B	PARTICIPANT	\N	PRESENT	0
259207	250088	14187A	PARTICIPANT	\N	PRESENT	0
259208	250088	14215L	PARTICIPANT	\N	PRESENT	0
259209	250088	11110B	PARTICIPANT	\N	PRESENT	0
259210	250088	80027E	PARTICIPANT	\N	PRESENT	0
259211	250088	14211G	PARTICIPANT	\N	PRESENT	0
259212	250088	14121F	PARTICIPANT	\N	PRESENT	0
259213	250088	11109J	PARTICIPANT	\N	PRESENT	0
259214	250088	19369B	PARTICIPANT	\N	PRESENT	0
259215	250088	19691J	PARTICIPANT	\N	PRESENT	0
259216	250088	14259Y	PARTICIPANT	\N	PRESENT	0
259217	250088	19659J	PARTICIPANT	\N	PRESENT	0
259218	250088	08024S	PARTICIPANT	\N	PRESENT	0
259219	250088	08017T	PARTICIPANT	\N	PRESENT	0
259220	250088	04049K	PARTICIPANT	\N	PRESENT	0
259221	250088	14229S	PARTICIPANT	\N	PRESENT	0
259222	250088	14107H	PARTICIPANT	\N	PRESENT	0
259223	250088	19739H	PARTICIPANT	\N	PRESENT	0
259224	250088	14028W	PARTICIPANT	\N	PRESENT	0
259225	250088	14063N	PARTICIPANT	\N	PRESENT	0
259226	250088	11048N	PARTICIPANT	\N	PRESENT	0
259227	250088	19681G	PARTICIPANT	\N	PRESENT	0
259228	250088	14281W	PARTICIPANT	\N	PRESENT	0
259229	250088	19441R	PARTICIPANT	\N	PRESENT	0
259230	250088	08069G	PARTICIPANT	\N	PRESENT	0
241947	239695	14205J	PARTICIPANT	\N	PRESENT	0
241948	239695	11115U	PARTICIPANT	\N	PRESENT	0
241949	239695	19737F	PARTICIPANT	\N	PRESENT	0
241950	239695	11070L	PARTICIPANT	\N	PRESENT	0
241998	239695	14135M	PARTICIPANT	\N	PRESENT	0
241952	239695	08009T	PARTICIPANT	\N	PRESENT	0
241953	239695	08056B	PARTICIPANT	\N	PRESENT	0
241954	239695	19735D	PARTICIPANT	\N	PRESENT	0
241955	239695	16685X	PARTICIPANT	\N	PRESENT	0
241956	239695	19441R	PARTICIPANT	\N	PRESENT	0
241957	239695	19479G	PARTICIPANT	\N	PRESENT	0
241958	239695	08068F	PARTICIPANT	\N	PRESENT	0
241959	239695	14219Q	PARTICIPANT	\N	PRESENT	0
241960	239695	14042U	PARTICIPANT	\N	PRESENT	0
241961	239695	19713W	PARTICIPANT	\N	PRESENT	0
241962	239695	19319Q	PARTICIPANT	\N	PRESENT	0
241963	239695	14277B	PARTICIPANT	\N	PRESENT	0
241964	239695	14275Y	PARTICIPANT	\N	PRESENT	0
241965	239695	14267Y	PARTICIPANT	\N	PRESENT	0
241966	239695	04089T	PARTICIPANT	\N	PRESENT	0
241967	239695	14221J	PARTICIPANT	\N	PRESENT	0
241968	239695	14103D	PARTICIPANT	\N	PRESENT	0
241969	239695	19335Q	PARTICIPANT	\N	PRESENT	0
241970	239695	14089Y	PARTICIPANT	\N	PRESENT	0
241971	239695	14083S	PARTICIPANT	\N	PRESENT	0
241972	239695	19749K	PARTICIPANT	\N	PRESENT	0
241973	239695	14179A	PARTICIPANT	\N	PRESENT	0
241974	239695	19521Q	PARTICIPANT	\N	PRESENT	0
241975	239695	07004J	PARTICIPANT	\N	PRESENT	0
241976	239695	14255U	PARTICIPANT	\N	PRESENT	0
241977	239695	11085T	PARTICIPANT	\N	PRESENT	0
241978	239695	04040A	PARTICIPANT	\N	PRESENT	0
241979	239695	04070G	PARTICIPANT	\N	PRESENT	0
241980	239695	01025N	PARTICIPANT	\N	PRESENT	0
241981	239695	19581D	PARTICIPANT	\N	PRESENT	0
241982	239695	14093U	PARTICIPANT	\N	PRESENT	0
241983	239695	19545Y	PARTICIPANT	\N	PRESENT	0
241984	239695	08031R	PARTICIPANT	\N	PRESENT	0
241985	239695	19663E	PARTICIPANT	\N	PRESENT	0
242000	239695	19575F	PARTICIPANT	\N	PRESENT	0
241987	239695	19681G	PARTICIPANT	\N	PRESENT	0
241997	239695	14211G	PARTICIPANT	\N	PRESENT	0
241989	239695	04061F	PARTICIPANT	\N	PRESENT	0
241990	239695	19701S	PARTICIPANT	\N	PRESENT	0
241991	239695	14087W	PARTICIPANT	\N	PRESENT	0
241992	239695	19621T	PARTICIPANT	\N	PRESENT	0
241993	239695	19723Y	PARTICIPANT	\N	PRESENT	0
241994	239695	01043Q	PARTICIPANT	\N	PRESENT	0
241996	239695	08011M	PARTICIPANT	\N	PRESENT	0
242002	239695	19333N	PARTICIPANT	\N	PRESENT	0
242001	239695	11010L	PARTICIPANT	\N	PRESENT	0
242003	239695	14079W	PARTICIPANT	\N	PRESENT	0
242004	239695	19531S	PARTICIPANT	\N	PRESENT	0
242317	239697	04086Q	PARTICIPANT	\N	PRESENT	0
242324	239697	07029T	PARTICIPANT	\N	PRESENT	0
242325	239697	17589D	PARTICIPANT	\N	PRESENT	0
242326	239697	14073Q	PARTICIPANT	\N	PRESENT	0
242327	239697	12041X	PARTICIPANT	\N	PRESENT	0
242328	239697	19683J	PARTICIPANT	\N	PRESENT	0
242329	239697	14197C	PARTICIPANT	\N	PRESENT	0
242330	239697	80013X	PARTICIPANT	\N	PRESENT	0
242331	239697	08012N	PARTICIPANT	\N	PRESENT	0
242332	239697	04059M	PARTICIPANT	\N	PRESENT	0
242333	239697	19651A	PARTICIPANT	\N	PRESENT	0
242334	239697	19349W	PARTICIPANT	\N	PRESENT	0
242335	239697	19649G	PARTICIPANT	\N	PRESENT	0
242336	239697	19725B	PARTICIPANT	\N	PRESENT	0
242337	239697	14107H	PARTICIPANT	\N	PRESENT	0
242338	239697	14081Q	PARTICIPANT	\N	PRESENT	0
242339	239697	04057K	PARTICIPANT	\N	PRESENT	0
242340	239697	98022P	PARTICIPANT	\N	PRESENT	0
242341	239697	19611R	PARTICIPANT	\N	PRESENT	0
242342	239697	19699S	PARTICIPANT	\N	PRESENT	0
242343	239697	14089Y	PARTICIPANT	\N	PRESENT	0
242344	239697	19479G	PARTICIPANT	\N	PRESENT	0
242345	239697	19749K	PARTICIPANT	\N	PRESENT	0
242346	239697	14083S	PARTICIPANT	\N	PRESENT	0
242347	239697	01024M	PARTICIPANT	\N	PRESENT	0
242348	239697	19581D	PARTICIPANT	\N	PRESENT	0
242349	239697	19671E	PARTICIPANT	\N	PRESENT	0
242350	239697	14147R	PARTICIPANT	\N	PRESENT	0
242351	239697	11043H	PARTICIPANT	\N	PRESENT	0
242352	239697	14087W	PARTICIPANT	\N	PRESENT	0
242353	239697	14215L	PARTICIPANT	\N	PRESENT	0
242354	239697	01060R	PARTICIPANT	\N	PRESENT	0
242355	239697	04018C	PARTICIPANT	\N	PRESENT	0
242356	239697	14249W	PARTICIPANT	\N	PRESENT	0
242357	239697	19333N	PARTICIPANT	\N	PRESENT	0
242358	239697	19447X	PARTICIPANT	\N	PRESENT	0
242359	239697	19301E	PARTICIPANT	\N	PRESENT	0
242360	239697	14241N	PARTICIPANT	\N	PRESENT	0
242361	239697	14021P	PARTICIPANT	\N	PRESENT	0
242362	239697	08031R	PARTICIPANT	\N	PRESENT	0
242363	239697	04088S	PARTICIPANT	\N	PRESENT	0
242364	239697	11103C	PARTICIPANT	\N	PRESENT	0
242365	239697	17637T	PARTICIPANT	\N	PRESENT	0
242366	239697	19711U	PARTICIPANT	\N	PRESENT	0
242367	239697	08010L	PARTICIPANT	\N	PRESENT	0
242368	239697	08020N	PARTICIPANT	\N	PRESENT	0
242369	239697	19399H	PARTICIPANT	\N	PRESENT	0
242370	239697	08062Y	PARTICIPANT	\N	PRESENT	0
242371	239697	14061L	PARTICIPANT	\N	PRESENT	0
242372	239697	11090Q	PARTICIPANT	\N	PRESENT	0
242373	239697	19421M	PARTICIPANT	\N	PRESENT	0
242374	239697	05008E	PARTICIPANT	\N	PRESENT	0
242375	239697	16685X	PARTICIPANT	\N	PRESENT	0
242376	239697	11053K	PARTICIPANT	\N	PRESENT	0
242377	239697	19621T	PARTICIPANT	\N	PRESENT	0
242378	239697	14235Q	PARTICIPANT	\N	PRESENT	0
242379	239697	19687N	PARTICIPANT	\N	PRESENT	0
242382	239697	19543W	PARTICIPANT	\N	PRESENT	0
242385	239697	19735D	PARTICIPANT	\N	PRESENT	0
242386	239697	04070G	PARTICIPANT	\N	PRESENT	0
242387	239697	19387D	PARTICIPANT	\N	PRESENT	0
242393	239697	87003B	PARTICIPANT	\N	PRESENT	0
242394	239697	14042U	PARTICIPANT	\N	PRESENT	0
242395	239697	19691J	PARTICIPANT	\N	PRESENT	0
242396	239697	14103D	PARTICIPANT	\N	PRESENT	0
242397	239697	14030Q	PARTICIPANT	\N	PRESENT	0
242398	239697	08039A	PARTICIPANT	\N	PRESENT	0
242399	239697	14229S	PARTICIPANT	\N	PRESENT	0
244435	243898	14039A	PARTICIPANT	\N	EXCUSE	0
244436	243898	11072N	PARTICIPANT	\N	EXCUSE	0
245291	245290	04040A	PARTICIPANT	\N	PRESENT	0
245292	245290	19467C	PARTICIPANT	\N	PRESENT	0
245293	245290	14151M	PARTICIPANT	\N	PRESENT	0
245294	245290	14179A	PARTICIPANT	\N	PRESENT	0
245295	245290	19709B	PARTICIPANT	\N	PRESENT	0
245296	245290	14031R	PARTICIPANT	\N	PRESENT	0
245297	245290	14237S	PARTICIPANT	\N	PRESENT	0
245298	245290	14193X	PARTICIPANT	\N	PRESENT	0
245299	245290	11012A	PARTICIPANT	\N	PRESENT	0
245300	245290	04045F	PARTICIPANT	\N	PRESENT	0
245301	245290	04044E	PARTICIPANT	\N	PRESENT	0
247160	247158	98018T	PARTICIPANT	\N	PRESENT	0
247162	247161	98018T	PARTICIPANT	\N	PRESENT	0
247159	247158	14097Y	PARTICIPANT	\N	PRESENT	0
250064	250063	19713W	PARTICIPANT	\N	PRESENT	0
250065	250063	19651A	PARTICIPANT	\N	PRESENT	0
251931	251929	19667J	PARTICIPANT	\N	PRESENT	0
251932	251929	11040E	PARTICIPANT	\N	PRESENT	0
251934	251307	95041E	PARTICIPANT	\N	EXCUSE	0
252076	252072	08052W	PARTICIPANT	\N	PRESENT	0
252078	252072	10006L	PARTICIPANT	\N	PRESENT	0
252081	252072	19553Y	PARTICIPANT	\N	PRESENT	0
253944	240316	14355X	PARTICIPANT	\N	PRESENT	0
253945	240316	14042U	PARTICIPANT	\N	PRESENT	0
253946	240316	19511N	PARTICIPANT	\N	PRESENT	0
253948	240316	19369B	PARTICIPANT	\N	PRESENT	0
253949	240316	08015R	PARTICIPANT	\N	PRESENT	0
253950	240316	04089T	PARTICIPANT	\N	PRESENT	0
253951	240316	19441R	PARTICIPANT	\N	PRESENT	0
253952	240316	19705W	PARTICIPANT	\N	PRESENT	0
253953	240316	19611R	PARTICIPANT	\N	PRESENT	0
253954	240316	98024R	PARTICIPANT	\N	PRESENT	0
253961	240316	19619A	PARTICIPANT	\N	PRESENT	0
253956	240316	95030B	PARTICIPANT	\N	PRESENT	0
253958	240316	04047H	PARTICIPANT	\N	PRESENT	0
253959	240316	14026U	PARTICIPANT	\N	PRESENT	0
253960	240316	04086Q	PARTICIPANT	\N	PRESENT	0
253962	240316	19721W	PARTICIPANT	\N	PRESENT	0
253963	240316	14331P	PARTICIPANT	\N	PRESENT	0
253964	240316	14103D	PARTICIPANT	\N	PRESENT	0
253965	240316	98018T	PARTICIPANT	\N	PRESENT	0
253966	240316	04044E	PARTICIPANT	\N	PRESENT	0
253967	240316	19699S	PARTICIPANT	\N	PRESENT	0
266515	263051	04044E	PARTICIPANT	0	PRESENT	0
258319	251195	04043D	PARTICIPANT	\N	PRESENT	0
258320	251195	14221J	PARTICIPANT	\N	PRESENT	0
258321	251195	80013X	PARTICIPANT	\N	PRESENT	0
258322	251195	19593H	PARTICIPANT	\N	EXCUSE	0
258323	251195	19553Y	PARTICIPANT	\N	EXCUSE	0
258324	251195	19511N	PARTICIPANT	\N	EXCUSE	0
258325	251195	01058X	PARTICIPANT	\N	EXCUSE	0
258326	251195	19663E	PARTICIPANT	\N	EXCUSE	0
258327	251195	19533U	PARTICIPANT	\N	EXCUSE	0
258328	251195	01048V	PARTICIPANT	\N	EXCUSE	0
258329	251195	14093U	PARTICIPANT	\N	EXCUSE	0
258330	251195	14239U	PARTICIPANT	\N	EXCUSE	0
258331	251195	19723Y	PARTICIPANT	\N	EXCUSE	0
258332	251195	04061F	PARTICIPANT	\N	EXCUSE	0
258333	251195	19709B	PARTICIPANT	\N	EXCUSE	0
258341	258340	19647E	PARTICIPANT	\N	PRESENT	0
258675	255959	98005N	PARTICIPANT	\N	PRESENT	0
258676	255959	19657G	PARTICIPANT	\N	PRESENT	0
258677	255959	08019V	PRESIDENT	0	PRESENT	0
258678	255959	11072N	PARTICIPANT	\N	EXCUSE	0
258679	255959	14097Y	PARTICIPANT	\N	PRESENT	0
258685	255960	11109J	PARTICIPANT	\N	PRESENT	0
258686	255960	19631V	PARTICIPANT	\N	PRESENT	0
258687	255960	14097Y	PARTICIPANT	\N	PRESENT	0
258688	255960	98005N	PARTICIPANT	\N	PRESENT	0
258689	255960	08019V	PRESIDENT	0	PRESENT	0
258690	255960	19657G	PARTICIPANT	\N	PRESENT	0
258724	258723	19569H	PARTICIPANT	\N	PRESENT	0
258725	258723	14065Q	PARTICIPANT	\N	PRESENT	0
258726	258723	19549D	PARTICIPANT	\N	PRESENT	0
258727	258723	14255U	PARTICIPANT	\N	PRESENT	0
258728	258723	14063N	PARTICIPANT	\N	PRESENT	0
258729	258723	11026G	PARTICIPANT	\N	PRESENT	0
258730	258723	10015M	PARTICIPANT	\N	PRESENT	0
258731	258723	95063L	PARTICIPANT	\N	PRESENT	0
258732	258723	14089Y	PARTICIPANT	\N	PRESENT	0
258733	258723	14079W	PARTICIPANT	\N	PRESENT	0
258746	258745	19549D	PARTICIPANT	\N	PRESENT	0
258738	258723	96004D	PARTICIPANT	\N	PRESENT	0
258740	258723	04070G	PARTICIPANT	\N	PRESENT	0
258741	258723	98018T	PARTICIPANT	\N	PRESENT	0
258743	258723	14001X	PARTICIPANT	\N	PRESENT	0
258744	258723	14237S	PARTICIPANT	\N	PRESENT	0
258747	258745	19569H	PARTICIPANT	\N	PRESENT	0
266516	263051	05008E	PARTICIPANT	0	PRESENT	0
266517	263051	95063L	PARTICIPANT	0	PRESENT	0
266518	263051	08019V	PARTICIPANT	0	PRESENT	0
266519	263051	14041T	PARTICIPANT	0	PRESENT	0
266520	263051	04088S	PARTICIPANT	0	PRESENT	0
266521	263051	19467C	PARTICIPANT	0	PRESENT	0
266522	263051	14029X	PARTICIPANT	0	PRESENT	0
266523	263051	97011G	PARTICIPANT	0	PRESENT	0
266524	263051	11103C	PARTICIPANT	0	PRESENT	0
266525	263051	14215L	PARTICIPANT	0	PRESENT	0
266526	263051	19367Y	PARTICIPANT	0	PRESENT	0
266527	263051	19581D	PARTICIPANT	0	PRESENT	0
266528	263051	14109K	PARTICIPANT	0	PRESENT	0
266529	263051	12016W	PARTICIPANT	0	PRESENT	0
266530	263051	19715Y	PARTICIPANT	0	PRESENT	0
266531	263051	11109J	PARTICIPANT	0	PRESENT	0
266532	263051	11026G	PARTICIPANT	0	PRESENT	0
266533	263051	04085P	PARTICIPANT	0	PRESENT	0
266534	263051	19593H	PARTICIPANT	0	PRESENT	0
266535	263051	17589D	PARTICIPANT	0	PRESENT	0
266536	263051	14261S	PARTICIPANT	0	PRESENT	0
265543	265542	19575F	PARTICIPANT	\N	PRESENT	0
265544	265542	98029W	PRESIDENT	0	PRESENT	0
265545	265542	19673G	PARTICIPANT	\N	PRESENT	0
265546	265542	08056B	PARTICIPANT	\N	PRESENT	0
265547	265542	19611R	PARTICIPANT	\N	PRESENT	0
265548	265542	08010L	PARTICIPANT	\N	PRESENT	0
265549	265542	98050T	PARTICIPANT	\N	PRESENT	0
265550	265542	10015M	PARTICIPANT	\N	PRESENT	0
265551	265542	19421M	PARTICIPANT	\N	PRESENT	0
265552	256022	19575F	PARTICIPANT	\N	PRESENT	0
265553	256022	98029W	PRESIDENT	0	PRESENT	0
265554	256022	11027H	PARTICIPANT	\N	PRESENT	0
265555	256022	19673G	PARTICIPANT	\N	PRESENT	0
265556	256022	08056B	PARTICIPANT	\N	PRESENT	0
265557	256022	19611R	PARTICIPANT	\N	PRESENT	0
265558	256022	08010L	PARTICIPANT	\N	PRESENT	0
265559	256022	98050T	PARTICIPANT	\N	PRESENT	0
265560	256022	10015M	PARTICIPANT	\N	PRESENT	0
265561	256022	19421M	PARTICIPANT	\N	PRESENT	0
266537	263051	14089Y	PARTICIPANT	0	PRESENT	0
266538	263051	14033T	PARTICIPANT	0	PRESENT	0
266415	263054	14034U	PARTICIPANT	\N	PRESENT	0
266416	263054	95063L	PARTICIPANT	\N	PRESENT	0
266417	263054	05008E	PARTICIPANT	\N	PRESENT	0
266418	263054	19253P	PARTICIPANT	\N	PRESENT	0
266419	263054	19629C	PARTICIPANT	\N	PRESENT	0
266420	263054	19749K	PARTICIPANT	\N	PRESENT	0
266421	263054	19695N	PARTICIPANT	\N	PRESENT	0
266422	263054	19731Y	PARTICIPANT	\N	PRESENT	0
266423	263054	04059M	PARTICIPANT	\N	PRESENT	0
266424	263054	19479G	PARTICIPANT	\N	PRESENT	0
266425	263054	01060R	PARTICIPANT	\N	PRESENT	0
266426	263054	11033F	PARTICIPANT	\N	PRESENT	0
266427	263054	11026G	PARTICIPANT	\N	PRESENT	0
266428	263054	11109J	PARTICIPANT	\N	PRESENT	0
266429	263054	14257W	PARTICIPANT	\N	PRESENT	0
266430	263054	19621T	PARTICIPANT	\N	PRESENT	0
266431	263054	08019V	PARTICIPANT	\N	PRESENT	0
266432	263054	11083R	PARTICIPANT	\N	PRESENT	0
266433	263054	04085P	PARTICIPANT	\N	PRESENT	0
266434	263054	14191V	PARTICIPANT	\N	PRESENT	0
266435	263054	08020N	PARTICIPANT	\N	PRESENT	0
266436	263054	19447X	PARTICIPANT	\N	PRESENT	0
266437	263054	19651A	PARTICIPANT	\N	PRESENT	0
266438	263054	19737F	PARTICIPANT	\N	PRESENT	0
266439	263054	01025N	PARTICIPANT	\N	PRESENT	0
266440	263054	12016W	PARTICIPANT	\N	PRESENT	0
266441	263054	14089Y	PARTICIPANT	\N	PRESENT	0
266442	263054	14147R	PARTICIPANT	\N	PRESENT	0
266443	263054	19533U	PARTICIPANT	\N	PRESENT	0
266444	263054	19347U	PARTICIPANT	\N	PRESENT	0
266445	263054	08031R	PARTICIPANT	\N	PRESENT	0
266446	263054	11077T	PARTICIPANT	\N	PRESENT	0
266447	263054	19483C	PARTICIPANT	\N	PRESENT	0
266448	263054	14069U	PARTICIPANT	\N	PRESENT	0
266449	263054	19467C	PARTICIPANT	\N	PRESENT	0
266450	263054	14261S	PARTICIPANT	\N	PRESENT	0
266451	263054	14215L	PARTICIPANT	\N	PRESENT	0
266452	263054	14187A	PARTICIPANT	\N	PRESENT	0
266453	263054	04033B	PARTICIPANT	\N	PRESENT	0
266454	263054	04035D	PARTICIPANT	\N	PRESENT	0
266455	263054	19713W	PARTICIPANT	\N	PRESENT	0
266456	263054	01024M	PARTICIPANT	\N	PRESENT	0
266457	263054	14053L	PARTICIPANT	\N	PRESENT	0
266458	263054	18083K	PARTICIPANT	\N	PRESENT	0
266459	263054	14059S	PARTICIPANT	\N	PRESENT	0
266460	263054	14041T	PARTICIPANT	\N	PRESENT	0
266461	263054	14231L	PARTICIPANT	\N	PRESENT	0
266462	263054	19545Y	PARTICIPANT	\N	PRESENT	0
266463	263054	14235Q	PARTICIPANT	\N	PRESENT	0
266464	263054	04047H	PARTICIPANT	\N	PRESENT	0
266465	263054	14331P	PARTICIPANT	\N	PRESENT	0
266466	263054	14157T	PARTICIPANT	\N	PRESENT	0
266467	263054	14265W	PARTICIPANT	\N	PRESENT	0
266468	263054	14211G	PARTICIPANT	\N	PRESENT	0
266469	263054	14026U	PARTICIPANT	\N	PRESENT	0
266470	263054	14030Q	PARTICIPANT	\N	PRESENT	0
266471	263054	14219Q	PARTICIPANT	\N	PRESENT	0
266472	263054	19747H	PARTICIPANT	\N	PRESENT	0
266473	263054	14031R	PARTICIPANT	\N	PRESENT	0
266474	263054	08015R	PARTICIPANT	\N	PRESENT	0
266475	263054	04088S	PARTICIPANT	\N	PRESENT	0
266476	263054	14083S	PARTICIPANT	\N	PRESENT	0
266477	263054	14133K	PARTICIPANT	\N	PRESENT	0
266478	263054	11048N	PARTICIPANT	\N	PRESENT	0
266479	263054	19733B	PARTICIPANT	\N	PRESENT	0
266480	263054	08039A	PARTICIPANT	\N	PRESENT	0
266481	263054	17583W	PARTICIPANT	\N	PRESENT	0
266482	263054	14105F	PARTICIPANT	\N	PRESENT	0
266483	263054	08010L	PARTICIPANT	\N	PRESENT	0
266484	263054	14033T	PARTICIPANT	\N	PRESENT	0
266485	263054	19507S	PARTICIPANT	\N	PRESENT	0
266486	263054	08056B	PARTICIPANT	\N	PRESENT	0
266487	263054	08069G	PARTICIPANT	\N	PRESENT	0
266488	263054	14087W	PARTICIPANT	\N	PRESENT	0
266489	263054	19563B	PARTICIPANT	\N	PRESENT	0
266490	263054	19383Y	PARTICIPANT	\N	PRESENT	0
266491	263054	14213J	PARTICIPANT	\N	PRESENT	0
242581	241088	14239U	PARTICIPANT	\N	PRESENT	0
242582	241088	19575F	PARTICIPANT	\N	PRESENT	0
244045	244044	04042C	PARTICIPANT	\N	PRESENT	0
242584	241088	14195A	PARTICIPANT	\N	PRESENT	0
242585	241088	11031D	PARTICIPANT	\N	PRESENT	0
242586	241088	08052W	PARTICIPANT	\N	PRESENT	0
242587	241088	19663E	PARTICIPANT	\N	PRESENT	0
242588	241088	08048B	PARTICIPANT	\N	EXCUSE	0
242589	241088	08041T	PARTICIPANT	\N	PRESENT	0
242590	241088	19727D	PARTICIPANT	\N	PRESENT	0
242591	241088	19715Y	PARTICIPANT	\N	PRESENT	0
242592	241088	14213J	PARTICIPANT	\N	PRESENT	0
242593	241088	17779H	PARTICIPANT	\N	PRESENT	0
242594	241088	11067R	PARTICIPANT	\N	PRESENT	0
242595	241088	14223L	PARTICIPANT	\N	EXCUSE	0
242596	241088	04092N	PRESIDENT	0	PRESENT	0
242597	241088	11063M	PARTICIPANT	\N	PRESENT	0
242598	241088	01034P	PARTICIPANT	\N	PRESENT	0
242599	241088	19527W	PARTICIPANT	\N	PRESENT	0
242600	241088	19703U	PARTICIPANT	\N	PRESENT	0
242601	241088	11097X	PARTICIPANT	\N	PRESENT	0
242602	241088	19679N	PARTICIPANT	\N	PRESENT	0
242603	241088	14119M	PARTICIPANT	\N	PRESENT	0
242605	241088	19569H	PARTICIPANT	\N	EXCUSE	0
242606	241088	10006L	PARTICIPANT	\N	EXCUSE	0
242607	241088	19415P	PARTICIPANT	\N	PRESENT	0
242608	241088	19723Y	PARTICIPANT	\N	PRESENT	0
244047	244046	98018T	PARTICIPANT	\N	PRESENT	0
244048	244046	14097Y	PARTICIPANT	\N	PRESENT	0
244050	244049	04042C	PARTICIPANT	\N	PRESENT	0
244051	244049	98018T	PARTICIPANT	\N	PRESENT	0
244052	244049	14097Y	PARTICIPANT	\N	PRESENT	0
244054	244053	04042C	PARTICIPANT	\N	PRESENT	0
244055	244053	98029W	PARTICIPANT	\N	PRESENT	0
244056	244053	98022P	PARTICIPANT	\N	PRESENT	0
244057	244053	11027H	PARTICIPANT	\N	PRESENT	0
244058	244053	14235Q	PARTICIPANT	\N	PRESENT	0
244061	244060	11054L	PARTICIPANT	\N	PRESENT	0
244062	244060	11027H	PARTICIPANT	\N	PRESENT	0
244063	244060	08047A	PARTICIPANT	\N	PRESENT	0
244064	244060	04035D	PARTICIPANT	\N	PRESENT	0
244065	244060	11064N	PARTICIPANT	\N	PRESENT	0
244066	244060	04042C	PARTICIPANT	\N	PRESENT	0
244068	244067	04042C	PARTICIPANT	\N	PRESENT	0
244069	244067	11027H	PARTICIPANT	\N	PRESENT	0
244070	244067	98050T	PARTICIPANT	\N	PRESENT	0
244071	244067	14255U	PARTICIPANT	\N	PRESENT	0
244350	244349	98029W	PARTICIPANT	\N	PRESENT	0
248136	240295	19729F	PARTICIPANT	\N	PRESENT	0
248137	240295	19693L	PARTICIPANT	\N	PRESENT	0
248138	240295	19269X	PARTICIPANT	\N	PRESENT	0
248139	240295	14265W	PARTICIPANT	\N	PRESENT	0
248140	240295	08060W	PARTICIPANT	\N	PRESENT	0
248141	240295	19251M	PARTICIPANT	\N	PRESENT	0
248142	240295	08038Y	PARTICIPANT	\N	PRESENT	0
248143	240295	19707Y	PARTICIPANT	\N	PRESENT	0
248144	240295	19551W	PARTICIPANT	\N	PRESENT	0
248145	240295	19705W	PARTICIPANT	\N	PRESENT	0
248146	240295	08015R	PARTICIPANT	\N	PRESENT	0
248147	240295	01060R	PARTICIPANT	\N	PRESENT	0
248148	240295	19685L	PARTICIPANT	\N	PRESENT	0
248149	240295	08062Y	PARTICIPANT	\N	PRESENT	0
248150	240295	19731Y	PARTICIPANT	\N	PRESENT	0
248151	240295	14055N	PARTICIPANT	\N	PRESENT	0
248152	240295	19745F	PARTICIPANT	\N	PRESENT	0
248153	240295	14231L	PARTICIPANT	\N	PRESENT	0
248154	240295	14119M	PARTICIPANT	\N	PRESENT	0
248155	240295	08044W	PARTICIPANT	\N	PRESENT	0
248156	240295	01034P	PARTICIPANT	\N	PRESENT	0
248157	240295	19369B	PARTICIPANT	\N	PRESENT	0
248158	240295	19611R	PARTICIPANT	\N	PRESENT	0
248159	240295	19511N	PARTICIPANT	\N	PRESENT	0
248160	240295	19619A	PARTICIPANT	\N	PRESENT	0
248161	240295	19721W	PARTICIPANT	\N	PRESENT	0
248162	240295	14205J	PARTICIPANT	\N	PRESENT	0
248163	240295	19699S	PARTICIPANT	\N	PRESENT	0
248164	240295	19737F	PARTICIPANT	\N	PRESENT	0
248165	240295	04089T	PARTICIPANT	\N	PRESENT	0
248166	240295	19569H	PARTICIPANT	\N	PRESENT	0
248167	240295	19735D	PARTICIPANT	\N	PRESENT	0
248168	240295	16685X	PARTICIPANT	\N	PRESENT	0
248169	240295	19441R	PARTICIPANT	\N	PRESENT	0
248170	240295	19479G	PARTICIPANT	\N	PRESENT	0
248171	240295	14219Q	PARTICIPANT	\N	PRESENT	0
248172	240295	04035D	PARTICIPANT	\N	PRESENT	0
248173	240295	14083S	PARTICIPANT	\N	PRESENT	0
248174	240295	19713W	PARTICIPANT	\N	PRESENT	0
248175	240295	19319Q	PARTICIPANT	\N	PRESENT	0
248176	240295	14277B	PARTICIPANT	\N	PRESENT	0
248177	240295	14275Y	PARTICIPANT	\N	PRESENT	0
248178	240295	98024R	PARTICIPANT	\N	PRESENT	0
248179	240295	14267Y	PARTICIPANT	\N	PRESENT	0
248180	240295	14103D	PARTICIPANT	\N	PRESENT	0
248181	240295	14221J	PARTICIPANT	\N	PRESENT	0
248182	240295	19739H	PARTICIPANT	\N	PRESENT	0
248183	240295	19335Q	PARTICIPANT	\N	PRESENT	0
248184	240295	14073Q	PARTICIPANT	\N	PRESENT	0
248185	240295	14089Y	PARTICIPANT	\N	PRESENT	0
248186	240295	19749K	PARTICIPANT	\N	PRESENT	0
248187	240295	14026U	PARTICIPANT	\N	PRESENT	0
248188	240295	11070L	PARTICIPANT	\N	PRESENT	0
248189	240295	19521Q	PARTICIPANT	\N	PRESENT	0
248190	240295	07004J	PARTICIPANT	\N	PRESENT	0
248191	240295	14255U	PARTICIPANT	\N	PRESENT	0
248192	240295	04040A	PARTICIPANT	\N	PRESENT	0
248193	240295	19691J	PARTICIPANT	\N	PRESENT	0
248194	240295	01025N	PARTICIPANT	\N	PRESENT	0
248195	240295	01024M	PARTICIPANT	\N	PRESENT	0
248196	240295	14030Q	PARTICIPANT	\N	PRESENT	0
248197	240295	14187A	PARTICIPANT	\N	PRESENT	0
248198	240295	14327T	PARTICIPANT	\N	PRESENT	0
248199	240295	11085T	PARTICIPANT	\N	PRESENT	0
248200	240295	19577H	PARTICIPANT	\N	PRESENT	0
248201	240295	01043Q	PARTICIPANT	\N	PRESENT	0
248202	240295	98029W	PARTICIPANT	\N	PRESENT	0
248203	240295	14215L	PARTICIPANT	\N	PRESENT	0
248204	240295	95041E	PARTICIPANT	\N	PRESENT	0
248205	240295	11053K	PARTICIPANT	\N	PRESENT	0
248206	240295	14249W	PARTICIPANT	\N	PRESENT	0
248207	240295	14211G	PARTICIPANT	\N	PRESENT	0
248208	240295	05012A	PARTICIPANT	\N	PRESENT	0
248209	240295	17637T	PARTICIPANT	\N	PRESENT	0
248210	240295	19533U	PARTICIPANT	\N	PRESENT	0
248211	240295	07034Q	PARTICIPANT	\N	PRESENT	0
248212	240295	95062K	PARTICIPANT	\N	PRESENT	0
248213	240295	14193X	PARTICIPANT	\N	PRESENT	0
248214	240295	14237S	PARTICIPANT	\N	PRESENT	0
248215	240295	14061L	PARTICIPANT	\N	PRESENT	0
248216	240295	17583W	PARTICIPANT	\N	PRESENT	0
248217	240295	04049K	PARTICIPANT	\N	PRESENT	0
248218	240295	19723Y	PARTICIPANT	\N	PRESENT	0
248219	240295	19483C	PARTICIPANT	\N	PRESENT	0
248220	240295	02002K	PARTICIPANT	\N	PRESENT	0
248221	240295	19581D	PARTICIPANT	\N	PRESENT	0
248222	240295	14059S	PARTICIPANT	\N	PRESENT	0
248223	240295	04042C	PARTICIPANT	\N	PRESENT	0
248224	240295	19657G	PARTICIPANT	\N	PRESENT	0
248225	240295	98050T	PARTICIPANT	\N	PRESENT	0
248226	240295	08019V	PARTICIPANT	\N	PRESENT	0
248227	240295	14331P	PARTICIPANT	\N	PRESENT	0
248228	240295	14147R	PARTICIPANT	\N	PRESENT	0
248229	240295	04018C	PARTICIPANT	\N	PRESENT	0
248230	240295	11090Q	PARTICIPANT	\N	PRESENT	0
248231	240295	19421M	PARTICIPANT	\N	PRESENT	0
248244	240295	19367Y	PARTICIPANT	\N	PRESENT	0
248233	240295	19675J	PARTICIPANT	\N	PRESENT	0
248234	240295	04070G	PARTICIPANT	\N	PRESENT	0
248235	240295	19383Y	PARTICIPANT	\N	PRESENT	0
248236	240295	14329V	PARTICIPANT	\N	PRESENT	0
248237	240295	14357A	PARTICIPANT	\N	PRESENT	0
248238	240295	07033P	PARTICIPANT	\N	PRESENT	0
248239	240295	11103C	PARTICIPANT	\N	PRESENT	0
248240	240295	19663E	PARTICIPANT	\N	PRESENT	0
248241	240295	14259Y	PARTICIPANT	\N	PRESENT	0
248242	240295	98023Q	PARTICIPANT	\N	PRESENT	0
248243	240295	19701S	PARTICIPANT	\N	PRESENT	0
248245	240295	19741B	PARTICIPANT	\N	PRESENT	0
248246	240295	14115H	PARTICIPANT	\N	PRESENT	0
248247	240295	14133K	PARTICIPANT	\N	PRESENT	0
248248	240295	19733B	PARTICIPANT	\N	PRESENT	0
248249	240295	19621T	PARTICIPANT	\N	PRESENT	0
248250	240295	08028W	PARTICIPANT	\N	PRESENT	0
248251	240295	19507S	PARTICIPANT	\N	PRESENT	0
248255	240295	14253S	PARTICIPANT	\N	PRESENT	0
248253	240295	11049P	PARTICIPANT	\N	PRESENT	0
248254	240295	14169X	PARTICIPANT	\N	PRESENT	0
248256	240295	19349W	PARTICIPANT	\N	PRESENT	0
248257	240295	11033F	PARTICIPANT	\N	PRESENT	0
248258	240295	19647E	PARTICIPANT	\N	PRESENT	0
258975	258974	04049K	PARTICIPANT	\N	PRESENT	0
258976	258974	14255U	PARTICIPANT	\N	PRESENT	0
259231	250088	19663E	PARTICIPANT	\N	PRESENT	0
259232	250088	08019V	PARTICIPANT	\N	PRESENT	0
259233	250088	01025N	PARTICIPANT	\N	PRESENT	0
259234	259095	15447F	PARTICIPANT	\N	PRESENT	0
259235	259095	19703U	PARTICIPANT	\N	PRESENT	0
259236	259095	19729F	PARTICIPANT	\N	PRESENT	0
259237	259095	04071H	PARTICIPANT	\N	PRESENT	0
259238	259095	08035V	PARTICIPANT	\N	PRESENT	0
259239	259095	19581D	PARTICIPANT	\N	PRESENT	0
259240	250088	19335Q	PARTICIPANT	\N	PRESENT	0
259241	250088	10006L	PARTICIPANT	\N	PRESENT	0
259242	250088	95063L	PARTICIPANT	\N	PRESENT	0
259243	250088	19507S	PARTICIPANT	\N	PRESENT	0
259244	250088	08061X	PARTICIPANT	\N	PRESENT	0
259245	250088	19413M	PARTICIPANT	\N	PRESENT	0
259246	250088	19737F	PARTICIPANT	\N	PRESENT	0
259247	250088	08043V	PARTICIPANT	\N	PRESENT	0
259248	250088	14042U	PARTICIPANT	\N	PRESENT	0
259249	250088	14329V	PARTICIPANT	\N	PRESENT	0
259250	250088	19725B	PARTICIPANT	\N	PRESENT	0
259251	250088	14327T	PARTICIPANT	\N	PRESENT	0
259252	250088	14267Y	PARTICIPANT	\N	PRESENT	0
259253	250088	19673G	PARTICIPANT	\N	PRESENT	0
259254	250088	19565D	PARTICIPANT	\N	PRESENT	0
259255	250088	14059S	PARTICIPANT	\N	PRESENT	0
259256	258642	08009T	PRESIDENT	0	PRESENT	0
259257	258642	96004D	PARTICIPANT	\N	EXCUSE	0
259258	258642	19599P	PARTICIPANT	\N	EXCUSE	0
259259	250088	19563B	PARTICIPANT	\N	PRESENT	0
259260	250088	14201E	PARTICIPANT	\N	PRESENT	0
259261	250088	14111D	PARTICIPANT	\N	PRESENT	0
259262	250088	14223L	PARTICIPANT	\N	PRESENT	0
259263	250088	19723Y	PARTICIPANT	\N	PRESENT	0
259264	250088	19573D	PARTICIPANT	\N	PRESENT	0
259265	250088	04088S	PARTICIPANT	\N	PRESENT	0
259266	250088	19657G	PARTICIPANT	\N	PRESENT	0
259267	250088	87003B	PARTICIPANT	\N	PRESENT	0
259268	250088	11104D	PARTICIPANT	\N	PRESENT	0
259269	250088	14179A	PARTICIPANT	\N	PRESENT	0
259270	250088	19749K	PARTICIPANT	\N	PRESENT	0
259271	250088	88008L	PARTICIPANT	\N	PRESENT	0
259272	250088	19683J	PARTICIPANT	\N	PRESENT	0
259273	250088	19699S	PARTICIPANT	\N	PRESENT	0
259274	250088	19707Y	PARTICIPANT	\N	PRESENT	0
259275	250088	19705W	PARTICIPANT	\N	PRESENT	0
259276	250088	19611R	PARTICIPANT	\N	PRESENT	0
259277	250088	11097X	PARTICIPANT	\N	PRESENT	0
259278	250088	14275Y	PARTICIPANT	\N	PRESENT	0
259279	250088	11056N	PARTICIPANT	\N	PRESENT	0
259280	250088	14173T	PARTICIPANT	\N	PRESENT	0
259281	250088	14033T	PARTICIPANT	\N	PRESENT	0
259282	250088	08062Y	PARTICIPANT	\N	PRESENT	0
259283	250088	11041F	PARTICIPANT	\N	PRESENT	0
259284	250088	17589D	PARTICIPANT	\N	PRESENT	0
259285	250088	19289C	PARTICIPANT	\N	PRESENT	0
259286	250088	19511N	PARTICIPANT	\N	PRESENT	0
259446	250089	86034E	PARTICIPANT	\N	PRESENT	0
259447	250089	95062K	PARTICIPANT	\N	PRESENT	0
259448	250089	99004R	PARTICIPANT	\N	PRESENT	0
259449	250089	11097X	PARTICIPANT	\N	PRESENT	0
259492	250089	04043D	PARTICIPANT	\N	PRESENT	0
259451	250089	14169X	PARTICIPANT	\N	PRESENT	0
259452	250089	08069G	PARTICIPANT	\N	PRESENT	0
259453	250089	19399H	PARTICIPANT	\N	PRESENT	0
259454	250089	19741B	PARTICIPANT	\N	PRESENT	0
259455	250089	08028W	PARTICIPANT	\N	PRESENT	0
259456	250089	87003B	PARTICIPANT	\N	PRESENT	0
259457	250089	14215L	PARTICIPANT	\N	PRESENT	0
259458	250089	08044W	PARTICIPANT	\N	PRESENT	0
259459	250089	05008E	PARTICIPANT	\N	PRESENT	0
259460	250089	14191V	PARTICIPANT	\N	PRESENT	0
259461	250089	19707Y	PARTICIPANT	\N	PRESENT	0
259462	250089	19705W	PARTICIPANT	\N	PRESENT	0
259463	250089	14329V	PARTICIPANT	\N	PRESENT	0
259464	250089	14031R	PARTICIPANT	\N	PRESENT	0
259465	250089	14133K	PARTICIPANT	\N	PRESENT	0
259467	258642	19637C	PARTICIPANT	\N	EXCUSE	0
259469	250089	04035D	PARTICIPANT	\N	PRESENT	0
259470	250089	14187A	PARTICIPANT	\N	PRESENT	0
259471	250089	19675J	PARTICIPANT	\N	PRESENT	0
259473	250089	95041E	PARTICIPANT	\N	PRESENT	0
259474	250089	98023Q	PARTICIPANT	\N	PRESENT	0
259478	250089	19515S	PARTICIPANT	\N	PRESENT	0
259479	250089	15447F	PARTICIPANT	\N	PRESENT	0
259480	250089	14223L	PARTICIPANT	\N	PRESENT	0
259481	250089	11103C	PARTICIPANT	\N	PRESENT	0
259482	250089	04086Q	PARTICIPANT	\N	PRESENT	0
259483	250089	14147R	PARTICIPANT	\N	PRESENT	0
259484	250089	08010L	PARTICIPANT	\N	PRESENT	0
259485	250089	95030B	PARTICIPANT	\N	PRESENT	0
259486	250089	14053L	PARTICIPANT	\N	PRESENT	0
259487	250089	01058X	PARTICIPANT	\N	PRESENT	0
259488	250089	07034Q	PARTICIPANT	\N	PRESENT	0
259489	250089	08055A	PARTICIPANT	\N	PRESENT	0
259490	250089	19679N	PARTICIPANT	\N	PRESENT	0
259491	250089	04047H	PARTICIPANT	\N	PRESENT	0
259493	250089	14135M	PARTICIPANT	\N	PRESENT	0
259494	250089	14033T	PARTICIPANT	\N	PRESENT	0
259495	250089	18083K	PARTICIPANT	\N	PRESENT	0
259496	250089	19673G	PARTICIPANT	\N	PRESENT	0
259497	250089	14029X	PARTICIPANT	\N	PRESENT	0
259498	250089	92040Q	PARTICIPANT	\N	PRESENT	0
259499	250089	07033P	PARTICIPANT	\N	PRESENT	0
259500	250089	04071H	PARTICIPANT	\N	PRESENT	0
259501	250089	08011M	PARTICIPANT	\N	PRESENT	0
259502	250089	14211G	PARTICIPANT	\N	PRESENT	0
259503	250089	98024R	PARTICIPANT	\N	PRESENT	0
259504	250089	95015C	PARTICIPANT	\N	PRESENT	0
259505	250089	01057W	PARTICIPANT	\N	PRESENT	0
259506	250089	11090Q	PARTICIPANT	\N	PRESENT	0
259507	250089	05012A	PARTICIPANT	\N	PRESENT	0
259508	250089	11048N	PARTICIPANT	\N	PRESENT	0
259509	250089	19447X	PARTICIPANT	\N	PRESENT	0
259510	250089	19643A	PARTICIPANT	\N	PRESENT	0
259511	250089	96004D	PARTICIPANT	\N	PRESENT	0
259512	250089	19723Y	PARTICIPANT	\N	PRESENT	0
259513	250089	10015M	PARTICIPANT	\N	PRESENT	0
259514	250089	11031D	PARTICIPANT	\N	PRESENT	0
259515	250089	08039A	PARTICIPANT	\N	PRESENT	0
259516	250089	11056N	PARTICIPANT	\N	PRESENT	0
259517	250089	11063M	PARTICIPANT	\N	PRESENT	0
259518	250089	04085P	PARTICIPANT	\N	PRESENT	0
259519	250089	14157T	PARTICIPANT	\N	PRESENT	0
259520	250089	19695N	PARTICIPANT	\N	PRESENT	0
259521	250089	19565D	PARTICIPANT	\N	PRESENT	0
259522	250089	19347U	PARTICIPANT	\N	PRESENT	0
259523	250089	14026U	PARTICIPANT	\N	PRESENT	0
259524	250089	19687N	PARTICIPANT	\N	PRESENT	0
259525	250089	11033F	PARTICIPANT	\N	PRESENT	0
259526	250089	08061X	PARTICIPANT	\N	PRESENT	0
259527	250089	19663E	PARTICIPANT	\N	PRESENT	0
259528	250089	95063L	PARTICIPANT	\N	PRESENT	0
259529	250089	95037J	PARTICIPANT	\N	PRESENT	0
259530	250089	04088S	PARTICIPANT	\N	PRESENT	0
259531	250089	04045F	PARTICIPANT	\N	PRESENT	0
259532	250089	98029W	PARTICIPANT	\N	PRESENT	0
259533	250089	19651A	PARTICIPANT	\N	PRESENT	0
259534	250089	11083R	PARTICIPANT	\N	PRESENT	0
259535	250089	08018U	PARTICIPANT	\N	PRESENT	0
259536	250089	19349W	PARTICIPANT	\N	PRESENT	0
259537	250089	07029T	PARTICIPANT	\N	PRESENT	0
259538	250089	19543W	PARTICIPANT	\N	PRESENT	0
259539	250089	19269X	PARTICIPANT	\N	PRESENT	0
259540	250089	19657G	PARTICIPANT	\N	PRESENT	0
259541	250089	19637C	PARTICIPANT	\N	PRESENT	0
259542	250089	08062Y	PARTICIPANT	\N	PRESENT	0
259543	250089	08015R	PARTICIPANT	\N	PRESENT	0
259544	250089	19697Q	PARTICIPANT	\N	PRESENT	0
259545	250089	08073C	PARTICIPANT	\N	PRESENT	0
259546	250089	19659J	PARTICIPANT	\N	PRESENT	0
259547	250089	11072N	PARTICIPANT	\N	PRESENT	0
259548	250089	19733B	PARTICIPANT	\N	PRESENT	0
259549	250089	19329S	PARTICIPANT	\N	PRESENT	0
259550	250089	14059S	PARTICIPANT	\N	PRESENT	0
259551	250089	11012A	PARTICIPANT	\N	PRESENT	0
259552	250089	19253P	PARTICIPANT	\N	PRESENT	0
259553	250089	14034U	PARTICIPANT	\N	PRESENT	0
259554	250089	14239U	PARTICIPANT	\N	PRESENT	0
259555	250089	04008A	PARTICIPANT	\N	PRESENT	0
259556	250089	88008L	PARTICIPANT	\N	PRESENT	0
259557	250089	08031R	PARTICIPANT	\N	PRESENT	0
259558	250089	08049C	PARTICIPANT	\N	PRESENT	0
259559	250089	19367Y	PARTICIPANT	\N	PRESENT	0
259560	250089	19629C	PARTICIPANT	\N	PRESENT	0
259561	250089	19621T	PARTICIPANT	\N	PRESENT	0
259562	250089	19563B	PARTICIPANT	\N	PRESENT	0
259563	250089	04018C	PARTICIPANT	\N	PRESENT	0
241119	241118	14193X	PARTICIPANT	\N	PRESENT	0
241120	241118	08058D	PARTICIPANT	\N	PRESENT	0
241121	241118	11064N	PARTICIPANT	\N	PRESENT	0
241122	241118	14133K	PARTICIPANT	\N	PRESENT	0
241137	238971	14259Y	PARTICIPANT	\N	EXCUSE	0
241138	238971	19329S	PARTICIPANT	\N	EXCUSE	0
241139	238971	12016W	PARTICIPANT	\N	EXCUSE	0
241140	238971	08073C	PARTICIPANT	\N	EXCUSE	0
241141	238971	11109J	PARTICIPANT	\N	PRESENT	0
241142	238971	19631V	PARTICIPANT	\N	PRESENT	0
241143	238971	19295A	PARTICIPANT	\N	PRESENT	0
241144	238971	14097Y	PARTICIPANT	\N	PRESENT	0
241145	238971	14039A	PARTICIPANT	\N	PRESENT	0
241146	238971	14059S	PARTICIPANT	\N	PRESENT	0
241147	238971	08019V	PRESIDENT	0	PRESENT	0
241148	238971	11072N	PARTICIPANT	\N	PRESENT	0
241149	238971	04043D	PARTICIPANT	\N	PRESENT	0
241150	238971	14275Y	PARTICIPANT	\N	PRESENT	0
241151	238971	19657G	PARTICIPANT	\N	PRESENT	0
246342	246341	08014Q	PARTICIPANT	\N	PRESENT	0
246343	246341	14042U	PARTICIPANT	\N	PRESENT	0
246344	246341	19727D	PARTICIPANT	\N	PRESENT	0
246345	246341	19725B	PARTICIPANT	\N	PRESENT	0
246346	246341	19551W	PARTICIPANT	\N	PRESENT	0
246347	246341	14097Y	PARTICIPANT	\N	PRESENT	0
246348	246341	16685X	PARTICIPANT	\N	PRESENT	0
246349	246341	19483C	PARTICIPANT	\N	PRESENT	0
246350	246341	14205J	PARTICIPANT	\N	PRESENT	0
246351	246341	17779H	PARTICIPANT	\N	PRESENT	0
246352	246341	14265W	PARTICIPANT	\N	PRESENT	0
246353	246341	14169X	PARTICIPANT	\N	PRESENT	0
246354	246341	19745F	PARTICIPANT	\N	PRESENT	0
246355	246341	04088S	PARTICIPANT	\N	PRESENT	0
246356	246341	98050T	PARTICIPANT	\N	PRESENT	0
246357	246341	11097X	PARTICIPANT	\N	PRESENT	0
246358	246341	11043H	PARTICIPANT	\N	PRESENT	0
246359	246341	95067Q	PARTICIPANT	\N	PRESENT	0
246360	246341	19563B	PARTICIPANT	\N	PRESENT	0
246479	246471	14041T	PARTICIPANT	\N	PRESENT	0
246480	246471	01024M	PARTICIPANT	\N	PRESENT	0
246484	246453	14041T	PARTICIPANT	\N	PRESENT	0
246485	246453	01024M	PARTICIPANT	\N	PRESENT	0
246736	246735	11074Q	PARTICIPANT	\N	PRESENT	0
246737	246735	04061F	PARTICIPANT	\N	PRESENT	0
249888	249885	04049K	PARTICIPANT	\N	PRESENT	0
249886	249885	18083K	PARTICIPANT	\N	PRESENT	0
249887	249885	14151M	PARTICIPANT	\N	PRESENT	0
249889	249885	08017T	PARTICIPANT	\N	PRESENT	0
249890	249885	14265W	PARTICIPANT	\N	PRESENT	0
249891	249885	05012A	PARTICIPANT	\N	PRESENT	0
253968	240316	04092N	PARTICIPANT	\N	PRESENT	0
253969	240316	16685X	PARTICIPANT	\N	PRESENT	0
253970	240316	19569H	PARTICIPANT	\N	PRESENT	0
253971	240316	14089Y	PARTICIPANT	\N	PRESENT	0
253972	240316	05008E	PARTICIPANT	\N	PRESENT	0
253973	240316	14219Q	PARTICIPANT	\N	PRESENT	0
253974	240316	19713W	PARTICIPANT	\N	PRESENT	0
253975	240316	19739H	PARTICIPANT	\N	PRESENT	0
253976	240316	08062Y	PARTICIPANT	\N	PRESENT	0
253977	240316	19335Q	PARTICIPANT	\N	PRESENT	0
253978	240316	14221J	PARTICIPANT	\N	PRESENT	0
253979	240316	07033P	PARTICIPANT	\N	PRESENT	0
253980	240316	19521Q	PARTICIPANT	\N	PRESENT	0
253981	240316	14069U	PARTICIPANT	\N	PRESENT	0
253982	240316	04057K	PARTICIPANT	\N	PRESENT	0
253983	240316	19421M	PARTICIPANT	\N	PRESENT	0
253984	240316	04043D	PARTICIPANT	\N	PRESENT	0
253985	240316	07034Q	PARTICIPANT	\N	PRESENT	0
253986	240316	04070G	PARTICIPANT	\N	PRESENT	0
253987	240316	10006L	PARTICIPANT	\N	PRESENT	0
253988	240316	04040A	PARTICIPANT	\N	PRESENT	0
253989	240316	19533U	PARTICIPANT	\N	PRESENT	0
253990	240316	14249W	PARTICIPANT	\N	PRESENT	0
253991	240316	14327T	PARTICIPANT	\N	PRESENT	0
253992	240316	01043Q	PARTICIPANT	\N	PRESENT	0
253993	240316	04061F	PARTICIPANT	\N	PRESENT	0
253994	240316	19749K	PARTICIPANT	\N	PRESENT	0
253995	240316	14237S	PARTICIPANT	\N	PRESENT	0
253996	240316	14053L	PARTICIPANT	\N	PRESENT	0
253997	240316	11103C	PARTICIPANT	\N	PRESENT	0
253998	240316	89017R	PARTICIPANT	\N	PRESENT	0
253999	240316	14215L	PARTICIPANT	\N	PRESENT	0
254000	240316	01060R	PARTICIPANT	\N	PRESENT	0
254001	240316	19745F	PARTICIPANT	\N	PRESENT	0
254002	240316	14079W	PARTICIPANT	\N	PRESENT	0
254003	240316	11033F	PARTICIPANT	\N	PRESENT	0
254004	240316	14193X	PARTICIPANT	\N	PRESENT	0
254005	240316	19695N	PARTICIPANT	\N	PRESENT	0
254006	240316	19687N	PARTICIPANT	\N	PRESENT	0
254007	240316	17583W	PARTICIPANT	\N	PRESENT	0
254008	240316	19747H	PARTICIPANT	\N	PRESENT	0
254009	240316	04018C	PARTICIPANT	\N	PRESENT	0
254010	240316	14059S	PARTICIPANT	\N	PRESENT	0
254011	240316	97011G	PARTICIPANT	\N	PRESENT	0
254012	240316	11067R	PARTICIPANT	\N	PRESENT	0
254013	240316	14217N	PARTICIPANT	\N	PRESENT	0
254014	240316	19701S	PARTICIPANT	\N	PRESENT	0
254015	240316	19679N	PARTICIPANT	\N	PRESENT	0
254016	240316	19621T	PARTICIPANT	\N	PRESENT	0
254017	240316	19675J	PARTICIPANT	\N	PRESENT	0
254018	240316	11065P	PARTICIPANT	\N	PRESENT	0
254019	240316	11026G	PARTICIPANT	\N	PRESENT	0
254020	240316	19383Y	PARTICIPANT	\N	PRESENT	0
254021	240316	19671E	PARTICIPANT	\N	PRESENT	0
254022	240316	14038Y	PARTICIPANT	\N	PRESENT	0
254023	240316	19715Y	PARTICIPANT	\N	PRESENT	0
254320	240317	04059M	PARTICIPANT	\N	PRESENT	0
254468	253496	14089Y	PARTICIPANT	\N	PRESENT	0
254469	253496	08056B	PARTICIPANT	\N	PRESENT	0
254470	253496	19611R	PARTICIPANT	\N	PRESENT	0
254471	253496	19421M	PARTICIPANT	\N	PRESENT	0
254472	253496	98022P	PARTICIPANT	\N	PRESENT	0
254473	253496	10015M	PARTICIPANT	\N	PRESENT	0
254474	253496	19575F	PARTICIPANT	\N	PRESENT	0
254475	253496	11027H	PARTICIPANT	\N	PRESENT	0
254476	253496	08010L	PARTICIPANT	\N	PRESENT	0
254477	253496	08053X	PARTICIPANT	\N	PRESENT	0
254478	253496	19673G	PARTICIPANT	\N	PRESENT	0
254479	253496	98029W	PRESIDENT	0	PRESENT	0
254480	240317	14026U	PARTICIPANT	\N	PRESENT	0
254481	240317	11040E	PARTICIPANT	\N	PRESENT	0
254582	253494	11048N	PRESIDENT	0	PRESENT	0
254583	253494	11067R	PARTICIPANT	\N	PRESENT	0
254584	253494	14103D	PARTICIPANT	\N	PRESENT	0
254585	253494	19651A	PARTICIPANT	\N	PRESENT	0
254586	253494	19533U	PARTICIPANT	\N	PRESENT	0
254587	253494	14031R	PARTICIPANT	\N	PRESENT	0
254588	253494	19545Y	PARTICIPANT	\N	PRESENT	0
254589	253494	14187A	PARTICIPANT	\N	PRESENT	0
254590	253494	19689Q	PARTICIPANT	\N	PRESENT	0
254591	253494	19441R	PARTICIPANT	\N	PRESENT	0
254592	253494	19253P	PARTICIPANT	\N	PRESENT	0
254593	253494	14026U	PARTICIPANT	\N	PRESENT	0
254594	253494	19399H	PARTICIPANT	\N	PRESENT	0
254595	253494	19719D	PARTICIPANT	\N	PRESENT	0
254596	253494	04049K	PARTICIPANT	\N	PRESENT	0
254597	253494	19573D	PARTICIPANT	\N	PRESENT	0
254598	253494	14087W	PARTICIPANT	\N	PRESENT	0
254599	253494	19503N	PARTICIPANT	\N	PRESENT	0
254600	253494	14151M	PARTICIPANT	\N	PRESENT	0
254601	253494	14157T	PARTICIPANT	\N	PRESENT	0
254602	253494	14071N	PARTICIPANT	\N	PRESENT	0
254603	253494	19749K	PARTICIPANT	\N	PRESENT	0
266539	263051	14105F	PARTICIPANT	0	PRESENT	0
266540	263051	19553Y	PARTICIPANT	0	PRESENT	0
266541	263051	19629C	PARTICIPANT	0	PRESENT	0
266542	263051	19253P	PARTICIPANT	0	PRESENT	0
266543	263051	14147R	PARTICIPANT	0	PRESENT	0
266544	263051	19711U	PARTICIPANT	0	PRESENT	0
266545	263051	19483C	PARTICIPANT	0	PRESENT	0
266546	263051	14055N	PARTICIPANT	0	PRESENT	0
266547	263051	19731Y	PARTICIPANT	0	PRESENT	0
266548	263051	04043D	PARTICIPANT	0	PRESENT	0
266549	263051	14157T	PARTICIPANT	0	PRESENT	0
266550	263051	11080N	PARTICIPANT	0	PRESENT	0
266551	263051	14191V	PARTICIPANT	0	PRESENT	0
266552	263051	19643A	PARTICIPANT	0	PRESENT	0
266553	263051	04035D	PARTICIPANT	0	PRESENT	0
266554	263051	01048V	PARTICIPANT	0	PRESENT	0
266555	263051	14119M	PARTICIPANT	0	PRESENT	0
266556	263051	14069U	PARTICIPANT	0	PRESENT	0
266557	263051	19657G	PARTICIPANT	0	PRESENT	0
266558	263051	01060R	PARTICIPANT	0	PRESENT	0
266559	263051	19335Q	PARTICIPANT	0	PRESENT	0
266560	263051	04057K	PARTICIPANT	0	PRESENT	0
266561	263051	19575F	PARTICIPANT	0	PRESENT	0
266562	263051	14187A	PARTICIPANT	0	PRESENT	0
266563	263051	19695N	PARTICIPANT	0	PRESENT	0
266564	263051	19489J	PARTICIPANT	0	PRESENT	0
266565	263051	11033F	PARTICIPANT	0	PRESENT	0
266566	263051	01025N	PARTICIPANT	0	PRESENT	0
266567	263051	14179A	PARTICIPANT	0	PRESENT	0
266568	263051	04059M	PARTICIPANT	0	PRESENT	0
266569	263051	19681G	PARTICIPANT	0	PRESENT	0
266570	263051	19507S	PARTICIPANT	0	PRESENT	0
266571	263051	14087W	PARTICIPANT	0	PRESENT	0
266572	263051	19577H	PARTICIPANT	0	PRESENT	0
266573	263051	19383Y	PARTICIPANT	0	PRESENT	0
266574	263051	14039A	PARTICIPANT	0	PRESENT	0
266575	263051	08056B	PARTICIPANT	0	PRESENT	0
266576	263051	08062Y	PARTICIPANT	0	PRESENT	0
266577	263051	19709B	PARTICIPANT	0	PRESENT	0
266578	263051	11049P	PARTICIPANT	0	PRESENT	0
266579	263051	14259Y	PARTICIPANT	0	PRESENT	0
266580	263051	14213J	PARTICIPANT	0	PRESENT	0
266581	263051	14331P	PARTICIPANT	0	PRESENT	0
266582	263051	19347U	PARTICIPANT	0	PRESENT	0
266583	263051	01024M	PARTICIPANT	0	PRESENT	0
266584	263051	04071H	PARTICIPANT	0	PRESENT	0
266585	263051	14211G	PARTICIPANT	0	PRESENT	0
266586	263051	19747H	PARTICIPANT	0	PRESENT	0
266587	263051	11083R	PARTICIPANT	0	PRESENT	0
266588	263051	11043H	PARTICIPANT	0	PRESENT	0
266589	263051	08020N	PARTICIPANT	0	PRESENT	0
266590	263051	11027H	PARTICIPANT	0	PRESENT	0
266591	263051	14251Q	PARTICIPANT	0	PRESENT	0
266592	263051	19733B	PARTICIPANT	0	PRESENT	0
266593	263051	04049K	PARTICIPANT	0	PRESENT	0
266594	263051	08061X	PARTICIPANT	0	PRESENT	0
266595	263051	19387D	PARTICIPANT	0	PRESENT	0
266596	263051	19563B	PARTICIPANT	0	PRESENT	0
266597	263051	08039A	PARTICIPANT	0	PRESENT	0
266598	263051	19399H	PARTICIPANT	0	PRESENT	0
266599	263051	14223L	PARTICIPANT	0	PRESENT	0
266600	263051	14221J	PARTICIPANT	0	PRESENT	0
266601	263051	11085T	PARTICIPANT	0	PRESENT	0
266602	263051	88008L	PARTICIPANT	0	PRESENT	0
266603	263051	08024S	PARTICIPANT	0	PRESENT	0
266604	263051	19349W	PARTICIPANT	0	PRESENT	0
266605	263051	19651A	PARTICIPANT	0	PRESENT	0
266606	263051	14199E	PARTICIPANT	0	PRESENT	0
266607	263051	14030Q	PARTICIPANT	0	PRESENT	0
266608	263051	14231L	PARTICIPANT	0	PRESENT	0
266609	263051	14265W	PARTICIPANT	0	PRESENT	0
266610	263051	14267Y	PARTICIPANT	0	PRESENT	0
266611	263051	11048N	PARTICIPANT	0	PRESENT	0
266612	263051	19447X	PARTICIPANT	0	PRESENT	0
266613	263051	80013X	PARTICIPANT	0	PRESENT	0
266614	263051	19565D	PARTICIPANT	0	PRESENT	0
266615	263051	14235Q	PARTICIPANT	0	PRESENT	0
266616	263051	14026U	PARTICIPANT	0	PRESENT	0
266617	263051	95030B	PARTICIPANT	0	PRESENT	0
266618	263051	19621T	PARTICIPANT	0	PRESENT	0
266619	263051	14357A	PARTICIPANT	0	PRESENT	0
266620	263051	19479G	PARTICIPANT	0	PRESENT	0
266621	263051	19737F	PARTICIPANT	0	PRESENT	0
266622	263051	08015R	PARTICIPANT	0	PRESENT	0
266623	263051	14217N	PARTICIPANT	0	PRESENT	0
266624	263051	95062K	PARTICIPANT	0	PRESENT	0
266625	263051	19725B	PARTICIPANT	0	PRESENT	0
267096	265122	08056B	PARTICIPANT	\N	PRESENT	0
267097	265122	19421M	PARTICIPANT	\N	PRESENT	0
267098	265122	10015M	PARTICIPANT	\N	PRESENT	0
267099	265122	98050T	PARTICIPANT	\N	PRESENT	0
267100	265122	19673G	PARTICIPANT	\N	PRESENT	0
267101	265122	98029W	PRESIDENT	0	PRESENT	0
267141	264160	04049K	PRESIDENT	0	PRESENT	0
267142	264160	89017R	PARTICIPANT	\N	EXCUSE	0
267143	264160	19575F	PARTICIPANT	\N	PRESENT	0
267144	264160	14030Q	PARTICIPANT	\N	PRESENT	0
267145	264160	08060W	PARTICIPANT	\N	EXCUSE	0
267146	264160	08068F	PARTICIPANT	\N	PRESENT	0
267147	264160	14255U	PARTICIPANT	\N	EXCUSE	0
267148	264160	14053L	PARTICIPANT	\N	EXCUSE	0
267149	264160	14083S	PARTICIPANT	\N	PRESENT	0
267150	264160	19545Y	PARTICIPANT	\N	EXCUSE	0
267151	264160	14329V	PARTICIPANT	\N	EXCUSE	0
267152	264160	14079W	PARTICIPANT	\N	EXCUSE	0
267153	264160	14041T	PARTICIPANT	\N	EXCUSE	0
267154	264160	14187A	PARTICIPANT	\N	EXCUSE	0
267155	264160	14087W	PARTICIPANT	\N	EXCUSE	0
267156	264160	19521Q	PARTICIPANT	\N	EXCUSE	0
267157	264160	14034U	PARTICIPANT	\N	PRESENT	0
267158	264160	19695N	PARTICIPANT	\N	EXCUSE	0
267159	264160	14026U	PARTICIPANT	\N	EXCUSE	0
267160	264160	19591F	PARTICIPANT	\N	EXCUSE	0
267161	264160	14121F	PARTICIPANT	\N	PRESENT	0
267162	264160	14061L	PARTICIPANT	\N	EXCUSE	0
267163	264160	11099A	PARTICIPANT	\N	PRESENT	0
267165	264160	08015R	PARTICIPANT	\N	EXCUSE	0
267166	264160	16685X	PARTICIPANT	\N	PRESENT	0
267167	264160	19671E	PARTICIPANT	\N	PRESENT	0
267168	264160	14265W	PARTICIPANT	\N	PRESENT	0
267169	264160	14253S	PARTICIPANT	\N	EXCUSE	0
267170	264160	04088S	PARTICIPANT	\N	EXCUSE	0
267171	264160	14051J	PARTICIPANT	\N	EXCUSE	0
267172	264160	19527W	PARTICIPANT	\N	EXCUSE	0
267173	264160	14157T	PARTICIPANT	\N	PRESENT	0
267174	264160	04044E	PARTICIPANT	\N	PRESENT	0
267175	264160	08010L	PARTICIPANT	\N	PRESENT	0
267176	264160	14259Y	PARTICIPANT	\N	PRESENT	0
267179	264160	19565D	PARTICIPANT	\N	PRESENT	0
267181	264160	19687N	PARTICIPANT	\N	PRESENT	0
267182	264160	04086Q	PARTICIPANT	\N	PRESENT	0
267183	264160	04045F	PARTICIPANT	\N	PRESENT	0
267184	264160	19735D	PARTICIPANT	\N	PRESENT	0
267185	264160	05012A	PARTICIPANT	\N	PRESENT	0
267186	264160	04040A	PARTICIPANT	\N	PRESENT	0
267209	267208	96004D	PRESIDENT	0	PRESENT	0
267210	267208	14089Y	PARTICIPANT	\N	PRESENT	0
267211	267208	08014Q	PARTICIPANT	\N	PRESENT	0
267212	267208	14357A	PARTICIPANT	\N	PRESENT	0
267213	267208	04035D	PARTICIPANT	\N	EXCUSE	0
267214	267208	11083R	PARTICIPANT	\N	PRESENT	0
267215	267208	14033T	PARTICIPANT	\N	PRESENT	0
267216	267208	14026U	PARTICIPANT	\N	PRESENT	0
267217	267208	19725B	PARTICIPANT	\N	PRESENT	0
267218	267208	95037J	PARTICIPANT	\N	EXCUSE	0
267220	267208	19569H	PARTICIPANT	\N	PRESENT	0
267221	267208	04097T	PARTICIPANT	\N	EXCUSE	0
267222	267219	08039A	PARTICIPANT	\N	PRESENT	0
267223	267219	08043V	PARTICIPANT	\N	PRESENT	0
267224	267219	19749K	PARTICIPANT	\N	PRESENT	0
267225	267219	19399H	PARTICIPANT	\N	PRESENT	0
267226	267208	14097Y	PARTICIPANT	\N	PRESENT	0
267227	267208	14001X	PARTICIPANT	\N	PRESENT	0
267228	267208	14221J	PARTICIPANT	\N	PRESENT	0
267229	267208	04057K	PARTICIPANT	\N	EXCUSE	0
267230	267208	19593H	PARTICIPANT	\N	PRESENT	0
267231	267208	14135M	PARTICIPANT	\N	EXCUSE	0
267233	267208	14331P	PARTICIPANT	\N	PRESENT	0
267235	267208	10015M	PARTICIPANT	\N	PRESENT	0
267237	267208	19695N	PARTICIPANT	\N	PRESENT	0
267238	267208	08068F	PARTICIPANT	\N	PRESENT	0
267239	267208	19413M	PARTICIPANT	\N	PRESENT	0
267240	267208	11099A	PARTICIPANT	\N	PRESENT	0
267241	267208	14207L	PARTICIPANT	\N	PRESENT	0
267242	267208	19269X	PARTICIPANT	\N	PRESENT	0
267243	267208	04088S	PARTICIPANT	\N	PRESENT	0
267244	267208	19631V	PARTICIPANT	\N	PRESENT	0
241086	238690	11067R	PARTICIPANT	\N	PRESENT	0
241087	238690	11097X	PARTICIPANT	\N	PRESENT	0
241090	241089	10006L	PARTICIPANT	\N	PRESENT	0
241091	241089	08052W	PARTICIPANT	\N	PRESENT	0
241092	241089	19553Y	PARTICIPANT	\N	PRESENT	0
245340	245339	19575F	PARTICIPANT	\N	PRESENT	0
245341	245339	14069U	PARTICIPANT	\N	PRESENT	0
245342	245339	08020N	PARTICIPANT	\N	PRESENT	0
245343	245339	14207L	PARTICIPANT	\N	PRESENT	0
245344	245339	11103C	PARTICIPANT	\N	PRESENT	0
245345	245339	14329V	PARTICIPANT	\N	PRESENT	0
245346	245339	11080N	PARTICIPANT	\N	PRESENT	0
245347	245339	18083K	PARTICIPANT	\N	PRESENT	0
245348	245339	14357A	PARTICIPANT	\N	PRESENT	0
245349	245339	17589D	PARTICIPANT	\N	PRESENT	0
245350	245339	19507S	PARTICIPANT	\N	PRESENT	0
245351	245339	14187A	PARTICIPANT	\N	PRESENT	0
245352	245339	08034U	PARTICIPANT	\N	PRESENT	0
245353	245339	16685X	PARTICIPANT	\N	PRESENT	0
245354	245339	08053X	PARTICIPANT	\N	PRESENT	0
245355	245339	14221J	PARTICIPANT	\N	PRESENT	0
245356	245339	04092N	PARTICIPANT	\N	PRESENT	0
245357	245339	14109K	PARTICIPANT	\N	PRESENT	0
245358	245339	14265W	PARTICIPANT	\N	PRESENT	0
245359	245339	14169X	PARTICIPANT	\N	PRESENT	0
245360	245339	08061X	PARTICIPANT	\N	PRESENT	0
245361	245339	04088S	PARTICIPANT	\N	PRESENT	0
245362	245339	07034Q	PARTICIPANT	\N	PRESENT	0
245363	245339	05012A	PARTICIPANT	\N	PRESENT	0
245364	245339	98050T	PARTICIPANT	\N	PRESENT	0
245365	245339	17583W	PARTICIPANT	\N	PRESENT	0
245366	245339	19679N	PARTICIPANT	\N	PRESENT	0
245367	245339	14331P	PARTICIPANT	\N	PRESENT	0
245368	245339	14107H	PARTICIPANT	\N	PRESENT	0
245369	245339	19619A	PARTICIPANT	\N	PRESENT	0
245370	245339	14173T	PARTICIPANT	\N	PRESENT	0
245371	245339	11063M	PARTICIPANT	\N	PRESENT	0
245372	245339	14225N	PARTICIPANT	\N	PRESENT	0
245510	245509	19689Q	PARTICIPANT	\N	PRESENT	0
245511	245509	19545Y	PARTICIPANT	\N	PRESENT	0
246237	244321	08068F	PARTICIPANT	\N	PRESENT	0
246238	244321	19631V	PARTICIPANT	\N	PRESENT	0
246239	244321	14065Q	PARTICIPANT	\N	PRESENT	0
246241	244321	19251M	PARTICIPANT	\N	PRESENT	0
246242	244321	08015R	PARTICIPANT	\N	PRESENT	0
248261	240295	11043H	PARTICIPANT	\N	PRESENT	0
248262	240295	95067Q	PARTICIPANT	\N	PRESENT	0
248581	240296	11070L	PARTICIPANT	\N	PRESENT	0
248259	240295	14217N	PARTICIPANT	\N	PRESENT	0
248260	240295	11010L	PARTICIPANT	\N	PRESENT	0
248582	240296	19747H	PARTICIPANT	\N	PRESENT	0
248583	240296	19731Y	PARTICIPANT	\N	PRESENT	0
248584	240296	95062K	PARTICIPANT	\N	PRESENT	0
248585	240296	14191V	PARTICIPANT	\N	PRESENT	0
248586	240296	14033T	PARTICIPANT	\N	PRESENT	0
248587	240296	07029T	PARTICIPANT	\N	PRESENT	0
248588	240296	19269X	PARTICIPANT	\N	PRESENT	0
248589	240296	11099A	PARTICIPANT	\N	PRESENT	0
248590	240296	19553Y	PARTICIPANT	\N	PRESENT	0
248591	240296	19387D	PARTICIPANT	\N	PRESENT	0
248592	240296	11031D	PARTICIPANT	\N	PRESENT	0
248593	240296	14121F	PARTICIPANT	\N	PRESENT	0
248594	240296	17779H	PARTICIPANT	\N	PRESENT	0
248595	240296	14030Q	PARTICIPANT	\N	PRESENT	0
248596	240296	19575F	PARTICIPANT	\N	PRESENT	0
248597	240296	14031R	PARTICIPANT	\N	PRESENT	0
248598	240296	19679N	PARTICIPANT	\N	PRESENT	0
248599	240296	19715Y	PARTICIPANT	\N	PRESENT	0
248600	240296	08024S	PARTICIPANT	\N	PRESENT	0
248601	240296	80013X	PARTICIPANT	\N	PRESENT	0
248602	240296	14281W	PARTICIPANT	\N	PRESENT	0
248603	240296	11067R	PARTICIPANT	\N	PRESENT	0
248604	240296	14109K	PARTICIPANT	\N	PRESENT	0
248605	240296	19295A	PARTICIPANT	\N	PRESENT	0
248606	240296	17589D	PARTICIPANT	\N	PRESENT	0
248607	240296	19563B	PARTICIPANT	\N	PRESENT	0
248608	240296	19441R	PARTICIPANT	\N	PRESENT	0
248609	246404	19319Q	PARTICIPANT	\N	PRESENT	0
248610	246404	95037J	PARTICIPANT	\N	PRESENT	0
248611	246404	95067Q	PARTICIPANT	\N	PRESENT	0
248612	246404	01062T	PARTICIPANT	\N	PRESENT	0
248613	246404	19709B	PARTICIPANT	\N	PRESENT	0
248614	246404	14193X	PARTICIPANT	\N	PRESENT	0
248615	246404	11027H	PARTICIPANT	\N	PRESENT	0
248616	246404	04042C	PRESIDENT	0	PRESENT	0
248617	240296	19691J	PARTICIPANT	\N	PRESENT	0
248618	240296	14261S	PARTICIPANT	\N	PRESENT	0
248619	240296	01024M	PARTICIPANT	\N	PRESENT	0
248620	240296	14073Q	PARTICIPANT	\N	PRESENT	0
248621	240296	04018C	PARTICIPANT	\N	PRESENT	0
248622	240296	97011G	PARTICIPANT	\N	PRESENT	0
248623	240296	14253S	PARTICIPANT	\N	PRESENT	0
248624	240296	19693L	PARTICIPANT	\N	PRESENT	0
248625	240296	14119M	PARTICIPANT	\N	PRESENT	0
248626	240296	19447X	PARTICIPANT	\N	PRESENT	0
248627	240296	19643A	PARTICIPANT	\N	PRESENT	0
248628	240296	14265W	PARTICIPANT	\N	PRESENT	0
248629	240296	14147R	PARTICIPANT	\N	PRESENT	0
248630	240296	01060R	PARTICIPANT	\N	PRESENT	0
248631	240296	17583W	PARTICIPANT	\N	PRESENT	0
248632	240296	19413M	PARTICIPANT	\N	PRESENT	0
248633	240296	19511N	PARTICIPANT	\N	PRESENT	0
248634	240296	19619A	PARTICIPANT	\N	PRESENT	0
248635	240296	19593H	PARTICIPANT	\N	PRESENT	0
248636	240296	95030B	PARTICIPANT	\N	PRESENT	0
248637	240296	14223L	PARTICIPANT	\N	PRESENT	0
248638	240296	11103C	PARTICIPANT	\N	PRESENT	0
248639	240296	19657G	PARTICIPANT	\N	PRESENT	0
248640	240296	19577H	PARTICIPANT	\N	PRESENT	0
248641	240296	11045K	PARTICIPANT	\N	PRESENT	0
248642	240296	11043H	PARTICIPANT	\N	PRESENT	0
248643	246404	04035D	PARTICIPANT	\N	PRESENT	0
248644	246404	14133K	PARTICIPANT	\N	PRESENT	0
248645	246404	11041F	PARTICIPANT	\N	PRESENT	0
248646	246404	04040A	PARTICIPANT	\N	PRESENT	0
248647	246404	16685X	PARTICIPANT	\N	PRESENT	0
248648	246404	19251M	PARTICIPANT	\N	PRESENT	0
248649	246404	11066Q	PARTICIPANT	\N	PRESENT	0
248650	246404	14083S	PARTICIPANT	\N	PRESENT	0
248651	246404	14267Y	PARTICIPANT	\N	PRESENT	0
248652	246404	98050T	PARTICIPANT	\N	PRESENT	0
248653	246404	08061X	PARTICIPANT	\N	PRESENT	0
248654	246404	14211G	PARTICIPANT	\N	PRESENT	0
248655	246404	14255U	PARTICIPANT	\N	PRESENT	0
248656	246404	08047A	PARTICIPANT	\N	PRESENT	0
248657	246404	98029W	PARTICIPANT	\N	PRESENT	0
248658	240296	19369B	PARTICIPANT	\N	PRESENT	0
248659	246404	19421M	PARTICIPANT	\N	PRESENT	0
248660	246404	08034U	PARTICIPANT	\N	PRESENT	0
248661	240296	18083K	PARTICIPANT	\N	PRESENT	0
248662	240296	14357A	PARTICIPANT	\N	PRESENT	0
248663	240296	14038Y	PARTICIPANT	\N	PRESENT	0
248664	240296	19621T	PARTICIPANT	\N	PRESENT	0
248665	240296	19367Y	PARTICIPANT	\N	PRESENT	0
248666	240296	19697Q	PARTICIPANT	\N	PRESENT	0
248667	240296	04088S	PARTICIPANT	\N	PRESENT	0
248668	240296	19507S	PARTICIPANT	\N	PRESENT	0
248669	246404	97011G	PARTICIPANT	\N	PRESENT	0
248670	240296	14219Q	PARTICIPANT	\N	PRESENT	0
248671	240296	08017T	PARTICIPANT	\N	PRESENT	0
248672	240296	08043V	PARTICIPANT	\N	PRESENT	0
248673	240296	19347U	PARTICIPANT	\N	PRESENT	0
248674	246404	95030B	PARTICIPANT	\N	PRESENT	0
248675	246404	01058X	PARTICIPANT	\N	PRESENT	0
248676	240296	19349W	PARTICIPANT	\N	PRESENT	0
248677	240296	01025N	PARTICIPANT	\N	PRESENT	0
248678	240296	14217N	PARTICIPANT	\N	PRESENT	0
248679	240296	08020N	PARTICIPANT	\N	PRESENT	0
248680	240296	19467C	PARTICIPANT	\N	PRESENT	0
248681	240296	19399H	PARTICIPANT	\N	PRESENT	0
248682	240296	08031R	PARTICIPANT	\N	PRESENT	0
248683	240296	11012A	PARTICIPANT	\N	PRESENT	0
248684	240296	19629C	PARTICIPANT	\N	PRESENT	0
248685	240296	14237S	PARTICIPANT	\N	PRESENT	0
248686	240296	11048N	PARTICIPANT	\N	PRESENT	0
248689	240296	19725B	PARTICIPANT	\N	PRESENT	0
248692	240296	01057W	PARTICIPANT	\N	PRESENT	0
248695	240296	11097X	PARTICIPANT	\N	PRESENT	0
258764	251195	14299H	PARTICIPANT	\N	PRESENT	0
259566	250089	98022P	PARTICIPANT	\N	PRESENT	0
259567	250089	19701S	PARTICIPANT	\N	PRESENT	0
259568	250089	11065P	PARTICIPANT	\N	PRESENT	0
259569	250089	19483C	PARTICIPANT	\N	PRESENT	0
259570	250089	11099A	PARTICIPANT	\N	PRESENT	0
259571	250089	19387D	PARTICIPANT	\N	PRESENT	0
259572	250089	19383Y	PARTICIPANT	\N	PRESENT	0
259573	250089	19553Y	PARTICIPANT	\N	PRESENT	0
259574	250089	19681G	PARTICIPANT	\N	PRESENT	0
259575	250089	19289C	PARTICIPANT	\N	PRESENT	0
259576	250089	14357A	PARTICIPANT	\N	PRESENT	0
259577	250089	14213J	PARTICIPANT	\N	PRESENT	0
259578	250089	11064N	PARTICIPANT	\N	PRESENT	0
259579	250089	17589D	PARTICIPANT	\N	PRESENT	0
259580	250089	14111D	PARTICIPANT	\N	PRESENT	0
259581	250089	02002K	PARTICIPANT	\N	PRESENT	0
259582	250089	14093U	PARTICIPANT	\N	PRESENT	0
259583	250089	14251Q	PARTICIPANT	\N	PRESENT	0
259584	250089	04057K	PARTICIPANT	\N	PRESENT	0
259585	250089	14265W	PARTICIPANT	\N	PRESENT	0
259586	250089	14195A	PARTICIPANT	\N	PRESENT	0
259587	250089	19729F	PARTICIPANT	\N	PRESENT	0
259588	250089	19693L	PARTICIPANT	\N	PRESENT	0
259589	250089	89017R	PARTICIPANT	\N	PRESENT	0
259590	250089	19685L	PARTICIPANT	\N	PRESENT	0
259591	250089	19731Y	PARTICIPANT	\N	PRESENT	0
259592	250089	14055N	PARTICIPANT	\N	PRESENT	0
259593	250089	19745F	PARTICIPANT	\N	PRESENT	0
259594	250089	08019V	PARTICIPANT	\N	PRESENT	0
259595	250089	19415P	PARTICIPANT	\N	PRESENT	0
259596	250089	19467C	PARTICIPANT	\N	PRESENT	0
259597	250089	19507S	PARTICIPANT	\N	PRESENT	0
259598	250089	19713W	PARTICIPANT	\N	PRESENT	0
259599	250089	14221J	PARTICIPANT	\N	PRESENT	0
259600	250089	14038Y	PARTICIPANT	\N	PRESENT	0
259601	250089	14275Y	PARTICIPANT	\N	PRESENT	0
259602	250089	14173T	PARTICIPANT	\N	PRESENT	0
259603	250089	19573D	PARTICIPANT	\N	PRESENT	0
259604	250089	14159V	PARTICIPANT	\N	PRESENT	0
259605	250089	11077T	PARTICIPANT	\N	PRESENT	0
259606	250089	11074Q	PARTICIPANT	\N	PRESENT	0
259607	250089	14051J	PARTICIPANT	\N	PRESENT	0
259608	250089	08068F	PARTICIPANT	\N	PRESENT	0
259609	250089	11049P	PARTICIPANT	\N	PRESENT	0
259610	250089	01028R	PARTICIPANT	\N	PRESENT	0
259611	250089	08052W	PARTICIPANT	\N	PRESENT	0
259612	250089	08047A	PARTICIPANT	\N	PRESENT	0
259613	250089	14229S	PARTICIPANT	\N	PRESENT	0
259564	250089	14201E	PARTICIPANT	\N	PRESENT	0
259565	250089	14241N	PARTICIPANT	\N	PRESENT	0
259614	250089	14105F	PARTICIPANT	\N	PRESENT	0
259615	250089	14107H	PARTICIPANT	\N	PRESENT	0
259616	250089	04049K	PARTICIPANT	\N	PRESENT	0
259617	250089	08045X	PARTICIPANT	\N	PRESENT	0
259618	250089	97011G	PARTICIPANT	\N	PRESENT	0
259619	250089	19669L	PARTICIPANT	\N	PRESENT	0
259620	250089	14021P	PARTICIPANT	\N	PRESENT	0
259621	250089	14331P	PARTICIPANT	\N	PRESENT	0
259622	250089	14151M	PARTICIPANT	\N	PRESENT	0
259623	250089	19647E	PARTICIPANT	\N	PRESENT	0
259624	250089	19649G	PARTICIPANT	\N	PRESENT	0
259625	250089	14197C	PARTICIPANT	\N	PRESENT	0
259626	250089	08024S	PARTICIPANT	\N	PRESENT	0
259627	250089	14028W	PARTICIPANT	\N	PRESENT	0
259628	250089	19581D	PARTICIPANT	\N	PRESENT	0
259629	250089	08060W	PARTICIPANT	\N	PRESENT	0
259630	250089	19671E	PARTICIPANT	\N	PRESENT	0
259631	250089	01062T	PARTICIPANT	\N	PRESENT	0
259632	250089	19549D	PARTICIPANT	\N	PRESENT	0
259633	250089	14065Q	PARTICIPANT	\N	PRESENT	0
259634	250089	11066Q	PARTICIPANT	\N	PRESENT	0
259635	250089	08043V	PARTICIPANT	\N	PRESENT	0
259636	250089	11104D	PARTICIPANT	\N	PRESENT	0
259637	250089	14281W	PARTICIPANT	\N	PRESENT	0
259638	250089	08035V	PARTICIPANT	\N	PRESENT	0
259639	250089	17583W	PARTICIPANT	\N	PRESENT	0
259640	250089	04061F	PARTICIPANT	\N	PRESENT	0
259641	250089	08012N	PARTICIPANT	\N	PRESENT	0
259642	250089	80027E	PARTICIPANT	\N	PRESENT	0
259643	250089	19727D	PARTICIPANT	\N	PRESENT	0
259644	250089	19531S	PARTICIPANT	\N	PRESENT	0
259645	250089	08058D	PARTICIPANT	\N	PRESENT	0
259646	250089	14121F	PARTICIPANT	\N	PRESENT	0
259647	250089	19533U	PARTICIPANT	\N	PRESENT	0
259648	250089	08034U	PARTICIPANT	\N	PRESENT	0
259649	250089	14085U	PARTICIPANT	\N	PRESENT	0
259650	250089	08017T	PARTICIPANT	\N	PRESENT	0
259651	250089	14227Q	PARTICIPANT	\N	PRESENT	0
259652	250089	19525U	PARTICIPANT	\N	PRESENT	0
259653	250089	11110B	PARTICIPANT	\N	PRESENT	0
259654	250089	14253S	PARTICIPANT	\N	PRESENT	0
259655	250089	14081Q	PARTICIPANT	\N	PRESENT	0
259656	250089	19575F	PARTICIPANT	\N	PRESENT	0
259657	250089	11041F	PARTICIPANT	\N	PRESENT	0
259658	250089	19725B	PARTICIPANT	\N	PRESENT	0
259659	250089	19703U	PARTICIPANT	\N	PRESENT	0
259660	250089	19333N	PARTICIPANT	\N	PRESENT	0
259661	250089	08014Q	PARTICIPANT	\N	PRESENT	0
259662	250089	19489J	PARTICIPANT	\N	PRESENT	0
259663	250089	19683J	PARTICIPANT	\N	PRESENT	0
259664	250089	11080N	PARTICIPANT	\N	PRESENT	0
259665	250089	11109J	PARTICIPANT	\N	PRESENT	0
259666	250089	11054L	PARTICIPANT	\N	PRESENT	0
259667	250089	14259Y	PARTICIPANT	\N	PRESENT	0
259668	250089	19689Q	PARTICIPANT	\N	PRESENT	0
259669	250089	19413M	PARTICIPANT	\N	PRESENT	0
259670	250089	19251M	PARTICIPANT	\N	PRESENT	0
259671	250089	11026G	PARTICIPANT	\N	PRESENT	0
259672	250089	19591F	PARTICIPANT	\N	PRESENT	0
259673	250089	19503N	PARTICIPANT	\N	PRESENT	0
259674	250089	11067R	PARTICIPANT	\N	PRESENT	0
259675	250089	14069U	PARTICIPANT	\N	PRESENT	0
259676	250089	19551W	PARTICIPANT	\N	PRESENT	0
259677	250089	19527W	PARTICIPANT	\N	PRESENT	0
259678	250089	14249W	PARTICIPANT	\N	PRESENT	0
259679	250089	14063N	PARTICIPANT	\N	PRESENT	0
259680	250089	14087W	PARTICIPANT	\N	PRESENT	0
259681	250089	19631V	PARTICIPANT	\N	PRESENT	0
259682	250089	14097Y	PARTICIPANT	\N	PRESENT	0
259683	250089	14257W	PARTICIPANT	\N	PRESENT	0
259684	250089	14231L	PARTICIPANT	\N	PRESENT	0
259685	250089	14179A	PARTICIPANT	\N	PRESENT	0
259686	250089	14073Q	PARTICIPANT	\N	PRESENT	0
259687	250089	01034P	PARTICIPANT	\N	PRESENT	0
259688	250089	19369B	PARTICIPANT	\N	PRESENT	0
259689	250089	19691J	PARTICIPANT	\N	PRESENT	0
259690	250089	14071N	PARTICIPANT	\N	PRESENT	0
259691	258674	19735D	PARTICIPANT	\N	PRESENT	0
259692	250089	19611R	PARTICIPANT	\N	PRESENT	0
259693	250089	08009T	PARTICIPANT	\N	PRESENT	0
259694	250089	11053K	PARTICIPANT	\N	PRESENT	0
259695	250089	04033B	PARTICIPANT	\N	PRESENT	0
259696	250089	19511N	PARTICIPANT	\N	PRESENT	0
259697	250089	11043H	PARTICIPANT	\N	PRESENT	0
259698	250089	19721W	PARTICIPANT	\N	PRESENT	0
259699	258694	19735D	PARTICIPANT	\N	PRESENT	0
259700	250089	19699S	PARTICIPANT	\N	PRESENT	0
259701	250089	14205J	PARTICIPANT	\N	PRESENT	0
259702	250089	19737F	PARTICIPANT	\N	PRESENT	0
259703	250089	08056B	PARTICIPANT	\N	PRESENT	0
259704	250089	19569H	PARTICIPANT	\N	PRESENT	0
259705	250089	19735D	PARTICIPANT	\N	PRESENT	0
259706	250089	16685X	PARTICIPANT	\N	PRESENT	0
259707	250089	19441R	PARTICIPANT	\N	PRESENT	0
259708	250089	19479G	PARTICIPANT	\N	PRESENT	0
259709	250089	14219Q	PARTICIPANT	\N	PRESENT	0
259710	250089	14042U	PARTICIPANT	\N	PRESENT	0
259711	250089	08020N	PARTICIPANT	\N	PRESENT	0
259712	250089	14123H	PARTICIPANT	\N	PRESENT	0
259713	250089	04042C	PARTICIPANT	\N	PRESENT	0
259714	250089	19335Q	PARTICIPANT	\N	PRESENT	0
259715	250089	19739H	PARTICIPANT	\N	PRESENT	0
259716	250089	14103D	PARTICIPANT	\N	PRESENT	0
259717	250089	14267Y	PARTICIPANT	\N	PRESENT	0
259718	250089	19749K	PARTICIPANT	\N	PRESENT	0
259719	250089	11070L	PARTICIPANT	\N	PRESENT	0
259720	250089	19521Q	PARTICIPANT	\N	PRESENT	0
259721	250089	07004J	PARTICIPANT	\N	PRESENT	0
259722	250089	17637T	PARTICIPANT	\N	PRESENT	0
259723	250089	14255U	PARTICIPANT	\N	PRESENT	0
259724	250089	11085T	PARTICIPANT	\N	PRESENT	0
241153	241152	14085U	PARTICIPANT	\N	PRESENT	0
241154	241152	04086Q	PARTICIPANT	\N	PRESENT	0
241155	241152	11074Q	PARTICIPANT	\N	PRESENT	0
241156	241152	14199E	PARTICIPANT	\N	PRESENT	0
241157	241152	01057W	PARTICIPANT	\N	PRESENT	0
241158	241152	08011M	PARTICIPANT	\N	PRESENT	0
241159	241152	14225N	PARTICIPANT	\N	PRESENT	0
241160	241152	11012A	PARTICIPANT	\N	PRESENT	0
244234	244232	14038Y	PARTICIPANT	\N	PRESENT	0
244235	244232	19701S	PARTICIPANT	\N	PRESENT	0
244237	244236	14038Y	PARTICIPANT	\N	PRESENT	0
244238	244236	19701S	PARTICIPANT	\N	PRESENT	0
244264	241271	19663E	PARTICIPANT	\N	PRESENT	0
244335	244334	08068F	PARTICIPANT	\N	PRESENT	0
244267	244266	14239U	PARTICIPANT	\N	EXCUSE	0
244268	244266	19553Y	PARTICIPANT	\N	PRESENT	0
244336	244334	14065Q	PARTICIPANT	\N	PRESENT	0
244337	244334	14079W	PARTICIPANT	\N	PRESENT	0
244338	244334	14219Q	PARTICIPANT	\N	PRESENT	0
244348	241368	19565D	PARTICIPANT	\N	EXCUSE	0
249900	249899	14255U	PARTICIPANT	\N	PRESENT	0
250011	247137	19575F	PARTICIPANT	\N	PRESENT	0
250012	247137	04049K	PARTICIPANT	\N	PRESENT	0
250014	247137	14087W	PARTICIPANT	\N	PRESENT	0
250015	247137	11040E	PARTICIPANT	\N	PRESENT	0
250016	247137	11099A	PARTICIPANT	\N	PRESENT	0
250048	250047	04040A	PARTICIPANT	\N	PRESENT	0
250049	250047	04042C	PARTICIPANT	\N	PRESENT	0
250050	250047	19721W	PARTICIPANT	\N	PRESENT	0
250051	250047	14267Y	PARTICIPANT	\N	PRESENT	0
250052	250047	11027H	PARTICIPANT	\N	PRESENT	0
250053	250047	14079W	PARTICIPANT	\N	PRESENT	0
250054	250047	95037J	PARTICIPANT	\N	PRESENT	0
250055	250047	19709B	PARTICIPANT	\N	PRESENT	0
250056	250047	16685X	PARTICIPANT	\N	PRESENT	0
250057	250047	95030B	PARTICIPANT	\N	PRESENT	0
250058	250047	14193X	PARTICIPANT	\N	PRESENT	0
250059	250047	98050T	PARTICIPANT	\N	PRESENT	0
250060	250047	19443T	PARTICIPANT	\N	PRESENT	0
250061	250047	19421M	PARTICIPANT	\N	PRESENT	0
250062	250047	01058X	PARTICIPANT	\N	PRESENT	0
250252	240302	80013X	PARTICIPANT	\N	PRESENT	0
250253	240302	19657G	PARTICIPANT	\N	PRESENT	0
250254	240302	11070L	PARTICIPANT	\N	PRESENT	0
250255	240302	19737F	PARTICIPANT	\N	PRESENT	0
250256	240302	19593H	PARTICIPANT	\N	PRESENT	0
250257	240302	19671E	PARTICIPANT	\N	PRESENT	0
250258	240302	19301E	PARTICIPANT	\N	PRESENT	0
244229	244228	14038Y	PARTICIPANT	\N	PRESENT	0
244230	244228	19701S	PARTICIPANT	\N	PRESENT	0
250259	240302	19647E	PARTICIPANT	\N	PRESENT	0
250260	240302	04044E	PARTICIPANT	\N	PRESENT	0
250264	240302	08012N	PARTICIPANT	\N	PRESENT	0
250265	240302	19715Y	PARTICIPANT	\N	PRESENT	0
250266	240302	14103D	PARTICIPANT	\N	PRESENT	0
250267	240302	19441R	PARTICIPANT	\N	PRESENT	0
250268	240302	04057K	PARTICIPANT	\N	PRESENT	0
250269	240302	19723Y	PARTICIPANT	\N	PRESENT	0
250277	240302	14069U	PARTICIPANT	\N	PRESENT	0
250278	240302	19749K	PARTICIPANT	\N	PRESENT	0
250279	240302	08014Q	PARTICIPANT	\N	PRESENT	0
250280	240302	08052W	PARTICIPANT	\N	PRESENT	0
250281	240302	14241N	PARTICIPANT	\N	PRESENT	0
250282	240302	05012A	PARTICIPANT	\N	PRESENT	0
250283	240302	14217N	PARTICIPANT	\N	PRESENT	0
250284	240302	19511N	PARTICIPANT	\N	PRESENT	0
250286	240302	19553Y	PARTICIPANT	\N	PRESENT	0
250287	240302	19575F	PARTICIPANT	\N	PRESENT	0
250288	240302	14105F	PARTICIPANT	\N	PRESENT	0
250289	240302	14147R	PARTICIPANT	\N	PRESENT	0
250290	240302	19507S	PARTICIPANT	\N	PRESENT	0
250291	240302	19747H	PARTICIPANT	\N	PRESENT	0
250292	240302	01025N	PARTICIPANT	\N	PRESENT	0
250293	240302	14219Q	PARTICIPANT	\N	PRESENT	0
250294	240302	14179A	PARTICIPANT	\N	PRESENT	0
250295	240302	19611R	PARTICIPANT	\N	PRESENT	0
250296	240302	14259Y	PARTICIPANT	\N	PRESENT	0
250297	240302	95067Q	PARTICIPANT	\N	PRESENT	0
250301	240302	08015R	PARTICIPANT	\N	PRESENT	0
250302	240302	01043Q	PARTICIPANT	\N	PRESENT	0
250303	240302	04092N	PARTICIPANT	\N	PRESENT	0
250306	240302	14151M	PARTICIPANT	\N	PRESENT	0
250307	240302	08009T	PARTICIPANT	\N	PRESENT	0
250319	240302	14115H	PARTICIPANT	\N	PRESENT	0
250542	240303	95063L	PARTICIPANT	\N	PRESENT	0
250543	240303	04059M	PARTICIPANT	\N	PRESENT	0
250544	240303	14193X	PARTICIPANT	\N	PRESENT	0
250545	240303	19593H	PARTICIPANT	\N	PRESENT	0
250546	240303	19651A	PARTICIPANT	\N	PRESENT	0
250547	240303	95062K	PARTICIPANT	\N	PRESENT	0
252528	252527	08058D	PRESIDENT	0	PRESENT	0
254694	240318	14235Q	PARTICIPANT	\N	PRESENT	0
254695	240318	14151M	PARTICIPANT	\N	PRESENT	0
254696	240318	19503N	PARTICIPANT	\N	PRESENT	0
254697	240318	19631V	PARTICIPANT	\N	PRESENT	0
254698	240318	04045F	PARTICIPANT	\N	PRESENT	0
254699	240318	19349W	PARTICIPANT	\N	PRESENT	0
254700	240318	11067R	PARTICIPANT	\N	PRESENT	0
254701	240318	19719D	PARTICIPANT	\N	PRESENT	0
254702	240318	11099A	PARTICIPANT	\N	PRESENT	0
254703	240318	16685X	PARTICIPANT	\N	PRESENT	0
254704	240318	19441R	PARTICIPANT	\N	PRESENT	0
254705	240318	19691J	PARTICIPANT	\N	PRESENT	0
254706	240318	19749K	PARTICIPANT	\N	PRESENT	0
254707	240318	14083S	PARTICIPANT	\N	PRESENT	0
254708	240318	19651A	PARTICIPANT	\N	PRESENT	0
254709	240318	19737F	PARTICIPANT	\N	PRESENT	0
254710	240318	01025N	PARTICIPANT	\N	PRESENT	0
254711	240318	19747H	PARTICIPANT	\N	PRESENT	0
254712	240318	04018C	PARTICIPANT	\N	PRESENT	0
254713	240318	14071N	PARTICIPANT	\N	PRESENT	0
254714	240318	04049K	PARTICIPANT	\N	PRESENT	0
254715	240318	19711U	PARTICIPANT	\N	PRESENT	0
254716	240318	14087W	PARTICIPANT	\N	PRESENT	0
254717	240318	14097Y	PARTICIPANT	\N	PRESENT	0
254718	240318	19689Q	PARTICIPANT	\N	PRESENT	0
254719	240318	11043H	PARTICIPANT	\N	PRESENT	0
254720	240318	19679N	PARTICIPANT	\N	PRESENT	0
254721	240318	04071H	PARTICIPANT	\N	PRESENT	0
254722	240318	14031R	PARTICIPANT	\N	PRESENT	0
254723	240318	19515S	PARTICIPANT	\N	PRESENT	0
254724	240318	14029X	PARTICIPANT	\N	PRESENT	0
254725	240318	04088S	PARTICIPANT	\N	PRESENT	0
254726	240318	14038Y	PARTICIPANT	\N	PRESENT	0
254727	240318	08010L	PARTICIPANT	\N	PRESENT	0
254728	240318	19415P	PARTICIPANT	\N	PRESENT	0
254729	240318	19563B	PARTICIPANT	\N	PRESENT	0
254730	240318	19629C	PARTICIPANT	\N	PRESENT	0
254731	240318	14219Q	PARTICIPANT	\N	PRESENT	0
254732	240318	11027H	PARTICIPANT	\N	PRESENT	0
254733	240318	14026U	PARTICIPANT	\N	PRESENT	0
254734	240318	14103D	PARTICIPANT	\N	PRESENT	0
254735	240318	14157T	PARTICIPANT	\N	PRESENT	0
254736	240318	08031R	PARTICIPANT	\N	PRESENT	0
254737	240318	14042U	PARTICIPANT	\N	PRESENT	0
254738	240318	08015R	PARTICIPANT	\N	PRESENT	0
254739	240318	14231L	PARTICIPANT	\N	PRESENT	0
254740	240318	95063L	PARTICIPANT	\N	PRESENT	0
254741	240318	14257W	PARTICIPANT	\N	PRESENT	0
254742	240318	19467C	PARTICIPANT	\N	PRESENT	0
254743	240318	19347U	PARTICIPANT	\N	PRESENT	0
254744	240318	14187A	PARTICIPANT	\N	PRESENT	0
254745	240318	14213J	PARTICIPANT	\N	PRESENT	0
254746	240318	19545Y	PARTICIPANT	\N	PRESENT	0
254747	240318	11048N	PARTICIPANT	\N	PRESENT	0
254748	240318	11012A	PARTICIPANT	\N	PRESENT	0
254749	240318	14034U	PARTICIPANT	\N	PRESENT	0
254750	240318	80013X	PARTICIPANT	\N	PRESENT	0
254751	240318	18083K	PARTICIPANT	\N	PRESENT	0
254752	240318	19533U	PARTICIPANT	\N	PRESENT	0
254753	240318	14253S	PARTICIPANT	\N	PRESENT	0
254754	240318	14119M	PARTICIPANT	\N	PRESENT	0
254755	240318	14065Q	PARTICIPANT	\N	PRESENT	0
254692	240318	01043Q	PARTICIPANT	\N	PRESENT	0
254693	240318	11040E	PARTICIPANT	\N	PRESENT	0
254756	240318	14331P	PARTICIPANT	\N	PRESENT	0
254757	240318	19447X	PARTICIPANT	\N	PRESENT	0
254758	240318	19483C	PARTICIPANT	\N	PRESENT	0
254759	240318	14069U	PARTICIPANT	\N	PRESENT	0
254760	240318	19507S	PARTICIPANT	\N	PRESENT	0
254761	240318	14033T	PARTICIPANT	\N	PRESENT	0
254762	240318	14265W	PARTICIPANT	\N	PRESENT	0
254763	240318	08061X	PARTICIPANT	\N	PRESENT	0
254764	240318	14215L	PARTICIPANT	\N	PRESENT	0
254765	240318	08056B	PARTICIPANT	\N	PRESENT	0
254766	240318	17583W	PARTICIPANT	\N	PRESENT	0
254767	240318	19383Y	PARTICIPANT	\N	PRESENT	0
254768	240318	19713W	PARTICIPANT	\N	PRESENT	0
254769	240318	19479G	PARTICIPANT	\N	PRESENT	0
258736	258735	19689Q	PARTICIPANT	\N	PRESENT	0
258737	258735	19545Y	PARTICIPANT	\N	PRESENT	0
258742	258739	08034U	PARTICIPANT	\N	PRESENT	0
267247	267208	80013X	PARTICIPANT	\N	PRESENT	0
267248	267208	19747H	PARTICIPANT	\N	PRESENT	0
267249	267208	19511N	PARTICIPANT	\N	PRESENT	0
267253	267208	19441R	PARTICIPANT	\N	PRESENT	0
267254	267208	19619A	PARTICIPANT	\N	PRESENT	0
267255	267208	19515S	PARTICIPANT	\N	PRESENT	0
267256	267208	14187A	PARTICIPANT	\N	PRESENT	0
267257	267208	04049K	PARTICIPANT	\N	PRESENT	0
267258	267208	19301E	PARTICIPANT	\N	PRESENT	0
267259	267208	19705W	PARTICIPANT	\N	PRESENT	0
267260	267208	19707Y	PARTICIPANT	\N	PRESENT	0
267261	267208	14265W	PARTICIPANT	\N	PRESENT	0
267263	267208	14065Q	PARTICIPANT	\N	EXCUSE	0
267332	258935	08056B	PARTICIPANT	\N	PRESENT	0
267333	258935	19649G	PARTICIPANT	\N	PRESENT	0
267334	258935	11080N	PARTICIPANT	\N	PRESENT	0
267335	258935	19611R	PARTICIPANT	\N	PRESENT	0
267336	258935	19421M	PARTICIPANT	\N	PRESENT	0
267337	258935	19575F	PARTICIPANT	\N	PRESENT	0
267338	258935	98050T	PARTICIPANT	\N	PRESENT	0
267339	258935	08010L	PARTICIPANT	\N	PRESENT	0
267340	258935	19673G	PARTICIPANT	\N	PRESENT	0
267341	258935	98029W	PRESIDENT	0	PRESENT	0
267342	265432	08056B	PARTICIPANT	\N	PRESENT	0
267343	265432	19649G	PARTICIPANT	\N	PRESENT	0
267344	265432	11080N	PARTICIPANT	\N	PRESENT	0
267345	265432	19611R	PARTICIPANT	\N	PRESENT	0
267346	265432	19421M	PARTICIPANT	\N	PRESENT	0
267347	265432	98050T	PARTICIPANT	\N	PRESENT	0
267348	265432	08010L	PARTICIPANT	\N	PRESENT	0
267349	265432	19673G	PARTICIPANT	\N	PRESENT	0
267350	265432	98029W	PRESIDENT	0	PRESENT	0
267245	267208	14257W	PARTICIPANT	\N	PRESENT	0
267246	267208	11090Q	PARTICIPANT	\N	PRESENT	0
267351	265122	19611R	PARTICIPANT	\N	EXCUSE	0
267354	267353	19479G	PARTICIPANT	\N	PRESENT	0
267355	267352	19479G	PARTICIPANT	\N	PRESENT	0
267368	267362	11070L	PARTICIPANT	\N	PRESENT	0
267369	267362	19647E	PARTICIPANT	\N	PRESENT	0
267370	267363	11070L	PARTICIPANT	\N	PRESENT	0
267371	267363	19647E	PARTICIPANT	\N	PRESENT	0
267433	259071	19593H	PARTICIPANT	\N	PRESENT	0
267435	259072	19593H	PARTICIPANT	\N	PRESENT	0
267436	259073	19593H	PARTICIPANT	\N	PRESENT	0
267466	267465	08034U	PARTICIPANT	\N	PRESENT	0
267467	265855	14147R	PARTICIPANT	\N	PRESENT	0
267469	267468	08034U	PARTICIPANT	\N	PRESENT	0
267471	267470	08034U	PARTICIPANT	\N	PRESENT	0
267473	267472	11074Q	PARTICIPANT	\N	PRESENT	0
267474	267472	08011M	PARTICIPANT	\N	PRESENT	0
267478	267477	19575F	PARTICIPANT	\N	PRESENT	0
267479	267477	11053K	PARTICIPANT	\N	PRESENT	0
267480	267477	14267Y	PARTICIPANT	\N	PRESENT	0
267481	267477	88008L	PARTICIPANT	\N	PRESENT	0
267482	267477	14179A	PARTICIPANT	\N	PRESENT	0
267483	267477	19333N	PARTICIPANT	\N	PRESENT	0
267484	267477	08031R	PARTICIPANT	\N	PRESENT	0
267485	267477	19611R	PARTICIPANT	\N	PRESENT	0
267486	267477	04049K	PARTICIPANT	\N	PRESENT	0
267487	267477	11077T	PARTICIPANT	\N	PRESENT	0
267488	267477	14059S	PARTICIPANT	\N	PRESENT	0
267489	267477	19671E	PARTICIPANT	\N	PRESENT	0
267490	267477	14257W	PARTICIPANT	\N	PRESENT	0
267491	267477	19735D	PARTICIPANT	\N	PRESENT	0
267626	267625	08019V	PARTICIPANT	\N	PRESENT	0
267656	267402	19729F	PARTICIPANT	\N	EXCUSE	0
267674	267673	08058D	PARTICIPANT	\N	PRESENT	0
267675	267673	11049P	PARTICIPANT	\N	PRESENT	0
267676	267673	14097Y	PARTICIPANT	\N	PRESENT	0
267677	267673	19703U	PARTICIPANT	\N	PRESENT	0
267678	267673	04071H	PARTICIPANT	\N	PRESENT	0
267820	267663	04092N	PARTICIPANT	\N	EXCUSE	0
267938	267663	11103C	PRESIDENT	0	PRESENT	0
267940	267663	08052W	PARTICIPANT	\N	PRESENT	0
267941	267663	14281W	PARTICIPANT	\N	PRESENT	0
267942	267663	11097X	PARTICIPANT	\N	PRESENT	0
267946	267663	19553Y	PARTICIPANT	\N	PRESENT	0
267947	267663	01034P	PARTICIPANT	\N	PRESENT	0
267948	267663	19569H	PARTICIPANT	\N	PRESENT	0
267949	267663	98024R	PARTICIPANT	\N	PRESENT	0
267950	267663	11067R	PARTICIPANT	\N	PRESENT	0
267951	267663	19727D	PARTICIPANT	\N	PRESENT	0
267952	267663	14119M	PARTICIPANT	\N	PRESENT	0
267956	267663	14026U	PARTICIPANT	\N	PRESENT	0
267961	267663	19521Q	PARTICIPANT	\N	PRESENT	0
267969	267968	19741B	PARTICIPANT	\N	PRESENT	0
267971	267970	19741B	PARTICIPANT	\N	PRESENT	0
267973	267972	19741B	PARTICIPANT	\N	PRESENT	0
267974	267663	10006L	PARTICIPANT	\N	PRESENT	0
267976	267975	19741B	PARTICIPANT	\N	PRESENT	0
268048	267060	08060W	PARTICIPANT	\N	EXCUSE	0
268049	267060	08024S	PARTICIPANT	\N	EXCUSE	0
268050	267060	14051J	PARTICIPANT	\N	PRESENT	0
268051	267060	07034Q	PARTICIPANT	\N	PRESENT	0
268052	267060	08045X	PARTICIPANT	\N	PRESENT	0
268053	267060	08009T	PRESIDENT	0	PRESENT	0
268054	267060	19737F	PARTICIPANT	\N	PRESENT	0
268055	267060	14219Q	PARTICIPANT	\N	PRESENT	0
268056	267060	19659J	PARTICIPANT	\N	PRESENT	0
268057	267060	19599P	PARTICIPANT	\N	PRESENT	0
268058	267060	05008E	PARTICIPANT	\N	PRESENT	0
268059	267060	19681G	PARTICIPANT	\N	PRESENT	0
268060	267060	19253P	PARTICIPANT	\N	PRESENT	0
268061	267060	19739H	PARTICIPANT	\N	PRESENT	0
268062	267060	98023Q	PARTICIPANT	\N	PRESENT	0
268063	267060	14191V	PARTICIPANT	\N	PRESENT	0
268064	267060	19503N	PARTICIPANT	\N	PRESENT	0
268065	267060	01024M	PARTICIPANT	\N	PRESENT	0
268066	267060	10015M	PARTICIPANT	\N	PRESENT	0
268067	267060	01028R	PARTICIPANT	\N	PRESENT	0
268068	267060	14001X	PARTICIPANT	\N	PRESENT	0
268069	267060	04044E	PARTICIPANT	\N	PRESENT	0
268070	267060	19673G	PARTICIPANT	\N	PRESENT	0
268071	267060	19489J	PARTICIPANT	\N	PRESENT	0
268072	267060	14147R	PARTICIPANT	\N	PRESENT	0
268073	267060	14151M	PARTICIPANT	\N	PRESENT	0
268074	267060	14215L	PARTICIPANT	\N	PRESENT	0
268075	267060	17637T	PARTICIPANT	\N	PRESENT	0
268076	267060	14135M	PARTICIPANT	\N	PRESENT	0
268077	267060	14097Y	PARTICIPANT	\N	PRESENT	0
268078	267060	14065Q	PARTICIPANT	\N	PRESENT	0
268079	267060	19719D	PARTICIPANT	\N	PRESENT	0
268080	267060	14041T	PARTICIPANT	\N	PRESENT	0
268081	267060	14231L	PARTICIPANT	\N	PRESENT	0
268082	267060	19745F	PARTICIPANT	\N	PRESENT	0
268083	267060	17583W	PARTICIPANT	\N	PRESENT	0
268084	267060	02002K	PARTICIPANT	\N	PRESENT	0
268085	267060	18083K	PARTICIPANT	\N	PRESENT	0
268086	267060	14237S	PARTICIPANT	\N	PRESENT	0
268087	267060	14157T	PARTICIPANT	\N	PRESENT	0
268088	267060	14053L	PARTICIPANT	\N	PRESENT	0
268089	267060	19551W	PARTICIPANT	\N	PRESENT	0
268090	267060	19289C	PARTICIPANT	\N	PRESENT	0
268091	267060	19581D	PARTICIPANT	\N	PRESENT	0
268092	267060	14069U	PARTICIPANT	\N	PRESENT	0
268093	267060	14031R	PARTICIPANT	\N	PRESENT	0
268094	267060	14029X	PARTICIPANT	\N	PRESENT	0
268095	267060	19383Y	PARTICIPANT	\N	PRESENT	0
268096	267060	19585H	PARTICIPANT	\N	PRESENT	0
268097	267060	08044W	PARTICIPANT	\N	PRESENT	0
268098	267060	05012A	PARTICIPANT	\N	PRESENT	0
268099	267060	19713W	PARTICIPANT	\N	PRESENT	0
268100	267060	19387D	PARTICIPANT	\N	PRESENT	0
268102	267060	11049P	PARTICIPANT	\N	PRESENT	0
268103	267060	19549D	PARTICIPANT	\N	PRESENT	0
268104	267022	14327T	PARTICIPANT	\N	PRESENT	0
268105	267022	14331P	PARTICIPANT	\N	PRESENT	0
268106	267022	04071H	PARTICIPANT	\N	PRESENT	0
268107	267022	01048V	PARTICIPANT	\N	PRESENT	0
268108	267022	01057W	PARTICIPANT	\N	PRESENT	0
268109	267022	11053K	PARTICIPANT	\N	PRESENT	0
268110	267022	19667J	PARTICIPANT	\N	PRESENT	0
268111	267022	11074Q	PRESIDENT	0	PRESENT	0
268112	267022	19671E	PARTICIPANT	\N	PRESENT	0
268113	267022	14225N	PARTICIPANT	\N	PRESENT	0
268114	267022	11070L	PARTICIPANT	\N	PRESENT	0
268115	267022	11110B	PARTICIPANT	\N	PRESENT	0
268116	267022	07029T	PARTICIPANT	\N	PRESENT	0
268117	267022	14085U	PARTICIPANT	\N	PRESENT	0
268118	267022	19349W	PARTICIPANT	\N	PRESENT	0
268119	267022	08010L	PARTICIPANT	\N	PRESENT	0
268120	267022	14253S	PARTICIPANT	\N	PRESENT	0
243227	241123	19663E	PARTICIPANT	\N	PRESENT	0
243229	241124	19663E	PARTICIPANT	\N	PRESENT	0
249773	249771	04097T	PARTICIPANT	\N	PRESENT	0
249774	249771	98050T	PARTICIPANT	\N	PRESENT	0
249775	249771	96004D	PARTICIPANT	\N	PRESENT	0
249776	249771	04042C	PARTICIPANT	\N	PRESENT	0
249777	249771	14255U	PARTICIPANT	\N	PRESENT	0
249778	249771	19251M	PARTICIPANT	\N	PRESENT	0
250121	232877	08045X	PARTICIPANT	\N	EXCUSE	0
250119	250118	11026G	PARTICIPANT	\N	PRESENT	0
250120	250118	10015M	PARTICIPANT	\N	PRESENT	0
250125	247236	19717B	PARTICIPANT	\N	PRESENT	0
250126	247236	14195A	PARTICIPANT	\N	PRESENT	0
250127	247236	14119M	PARTICIPANT	\N	PRESENT	0
250200	250199	96004D	PARTICIPANT	\N	PRESENT	0
250201	250199	04097T	PARTICIPANT	\N	PRESENT	0
250202	250199	14229S	PARTICIPANT	\N	PRESENT	0
250203	250199	98035U	PARTICIPANT	\N	PRESENT	0
250270	250234	14221J	PARTICIPANT	\N	PRESENT	0
250271	250234	19593H	PARTICIPANT	\N	PRESENT	0
250272	250235	14221J	PARTICIPANT	\N	PRESENT	0
250273	250235	19593H	PARTICIPANT	\N	PRESENT	0
250274	250236	14221J	PARTICIPANT	\N	PRESENT	0
250275	250236	19593H	PARTICIPANT	\N	PRESENT	0
250311	250310	11053K	PARTICIPANT	\N	PRESENT	0
250498	250497	14221J	PARTICIPANT	\N	PRESENT	0
250499	250497	19503N	PARTICIPANT	\N	PRESENT	0
250500	250497	19709B	PARTICIPANT	\N	PRESENT	0
250891	250193	08010L	PARTICIPANT	\N	EXCUSE	0
250892	250194	08010L	PARTICIPANT	\N	EXCUSE	0
250979	250975	14259Y	PARTICIPANT	\N	PRESENT	0
250980	250975	14199E	PARTICIPANT	\N	PRESENT	0
250981	250975	08069G	PARTICIPANT	\N	PRESENT	0
250982	250975	14097Y	PARTICIPANT	\N	PRESENT	0
250983	250975	04049K	PARTICIPANT	\N	PRESENT	0
250984	250975	19349W	PARTICIPANT	\N	PRESENT	0
251858	232877	19399H	PARTICIPANT	\N	PRESENT	0
251859	232877	19551W	PARTICIPANT	\N	PRESENT	0
251860	232877	08012N	PARTICIPANT	\N	PRESENT	0
251921	251308	14073Q	PARTICIPANT	\N	PRESENT	0
251922	251308	01043Q	PARTICIPANT	\N	PRESENT	0
251923	251308	19631V	PARTICIPANT	\N	PRESENT	0
251924	251308	19671E	PARTICIPANT	\N	PRESENT	0
251933	240310	01043Q	PARTICIPANT	\N	PRESENT	0
251935	240310	08024S	PARTICIPANT	\N	PRESENT	0
251936	240310	11027H	PARTICIPANT	\N	PRESENT	0
251937	240310	19721W	PARTICIPANT	\N	PRESENT	0
251938	240310	14227Q	PARTICIPANT	\N	PRESENT	0
251939	240310	11041F	PARTICIPANT	\N	PRESENT	0
251940	240310	08052W	PARTICIPANT	\N	PRESENT	0
251941	240310	11104D	PARTICIPANT	\N	PRESENT	0
251942	240310	08060W	PARTICIPANT	\N	PRESENT	0
251943	240310	14039A	PARTICIPANT	\N	PRESENT	0
251944	240310	19659J	PARTICIPANT	\N	PRESENT	0
251945	240310	19387D	PARTICIPANT	\N	PRESENT	0
251946	240310	98022P	PARTICIPANT	\N	PRESENT	0
251947	240310	19563B	PARTICIPANT	\N	PRESENT	0
251948	240310	16685X	PARTICIPANT	\N	PRESENT	0
251949	240310	14201E	PARTICIPANT	\N	PRESENT	0
251950	240310	04045F	PARTICIPANT	\N	PRESENT	0
251951	240310	19253P	PARTICIPANT	\N	PRESENT	0
251952	240310	14327T	PARTICIPANT	\N	PRESENT	0
251953	240310	19739H	PARTICIPANT	\N	PRESENT	0
251956	240310	19511N	PARTICIPANT	\N	PRESENT	0
251958	240310	14083S	PARTICIPANT	\N	PRESENT	0
251960	240310	14042U	PARTICIPANT	\N	PRESENT	0
251962	240310	19735D	PARTICIPANT	\N	PRESENT	0
251965	240310	14103D	PARTICIPANT	\N	PRESENT	0
251967	240310	08016S	PARTICIPANT	\N	PRESENT	0
251969	240310	01062T	PARTICIPANT	\N	PRESENT	0
251971	240310	14251Q	PARTICIPANT	\N	PRESENT	0
248897	248854	08034U	PARTICIPANT	\N	PRESENT	0
249772	249771	04035D	PARTICIPANT	\N	PRESENT	0
251974	240310	08055A	PARTICIPANT	\N	PRESENT	0
251976	240310	08012N	PARTICIPANT	\N	PRESENT	0
251980	240310	14111D	PARTICIPANT	\N	PRESENT	0
251982	240310	11072N	PARTICIPANT	\N	PRESENT	0
251984	240310	11074Q	PARTICIPANT	\N	PRESENT	0
251986	240310	98035U	PARTICIPANT	\N	PRESENT	0
251988	240310	11066Q	PARTICIPANT	\N	PRESENT	0
251991	240310	19611R	PARTICIPANT	\N	PRESENT	0
251993	240310	19691J	PARTICIPANT	\N	PRESENT	0
251995	240310	14089Y	PARTICIPANT	\N	PRESENT	0
251997	240310	11099A	PARTICIPANT	\N	PRESENT	0
251998	240310	19725B	PARTICIPANT	\N	PRESENT	0
251999	240310	08058D	PARTICIPANT	\N	PRESENT	0
252000	240310	19731Y	PARTICIPANT	\N	PRESENT	0
252001	240310	12041X	PARTICIPANT	\N	PRESENT	0
252002	240310	14231L	PARTICIPANT	\N	PRESENT	0
252003	240310	19669L	PARTICIPANT	\N	PRESENT	0
252004	240310	19591F	PARTICIPANT	\N	PRESENT	0
252005	240310	19333N	PARTICIPANT	\N	PRESENT	0
252006	240310	19489J	PARTICIPANT	\N	PRESENT	0
252007	240310	19503N	PARTICIPANT	\N	PRESENT	0
252008	251308	14133K	PARTICIPANT	\N	PRESENT	0
252009	251308	08015R	PARTICIPANT	\N	PRESENT	0
252010	251308	95041E	PARTICIPANT	\N	EXCUSE	0
252011	240310	11054L	PARTICIPANT	\N	PRESENT	0
252012	240310	98029W	PARTICIPANT	\N	PRESENT	0
252013	240310	19697Q	PARTICIPANT	\N	PRESENT	0
252014	240310	04085P	PARTICIPANT	\N	PRESENT	0
252015	240310	11040E	PARTICIPANT	\N	PRESENT	0
252016	240310	11033F	PARTICIPANT	\N	PRESENT	0
252017	240310	04034C	PARTICIPANT	\N	PRESENT	0
252018	240310	19565D	PARTICIPANT	\N	PRESENT	0
252019	240310	19687N	PARTICIPANT	\N	PRESENT	0
252020	240310	11083R	PARTICIPANT	\N	PRESENT	0
252021	240310	19347U	PARTICIPANT	\N	PRESENT	0
252022	240310	11031D	PARTICIPANT	\N	PRESENT	0
252023	240310	14225N	PARTICIPANT	\N	PRESENT	0
252024	240310	14121F	PARTICIPANT	\N	PRESENT	0
252025	240310	95037J	PARTICIPANT	\N	PRESENT	0
252026	240310	08061X	PARTICIPANT	\N	PRESENT	0
252027	240310	19543W	PARTICIPANT	\N	PRESENT	0
252028	240310	19349W	PARTICIPANT	\N	PRESENT	0
252029	240310	95062K	PARTICIPANT	\N	PRESENT	0
252030	240310	08021P	PARTICIPANT	\N	PRESENT	0
252032	240310	99004R	PARTICIPANT	\N	PRESENT	0
252033	240310	01058X	PARTICIPANT	\N	PRESENT	0
252034	240310	19329S	PARTICIPANT	\N	PRESENT	0
252035	240310	19301E	PARTICIPANT	\N	PRESENT	0
252037	240310	86034E	PARTICIPANT	\N	PRESENT	0
252038	240310	19651A	PARTICIPANT	\N	PRESENT	0
252039	240310	14055N	PARTICIPANT	\N	PRESENT	0
252041	240310	01060R	PARTICIPANT	\N	PRESENT	0
252043	240310	17637T	PARTICIPANT	\N	PRESENT	0
252045	240310	14159V	PARTICIPANT	\N	PRESENT	0
252047	240310	14034U	PARTICIPANT	\N	PRESENT	0
252049	240310	14157T	PARTICIPANT	\N	PRESENT	0
252050	240310	14261S	PARTICIPANT	\N	PRESENT	0
252052	240310	08031R	PARTICIPANT	\N	PRESENT	0
252054	240310	08049C	PARTICIPANT	\N	PRESENT	0
252055	240310	04042C	PARTICIPANT	\N	PRESENT	0
252056	240310	95067Q	PARTICIPANT	\N	PRESENT	0
252057	240310	14241N	PARTICIPANT	\N	PRESENT	0
252059	240310	19553Y	PARTICIPANT	\N	PRESENT	0
252061	240310	11065P	PARTICIPANT	\N	PRESENT	0
252062	240310	95015C	PARTICIPANT	\N	PRESENT	0
252063	240310	19717B	PARTICIPANT	\N	PRESENT	0
252064	240310	04097T	PARTICIPANT	\N	PRESENT	0
252067	240310	08020N	PARTICIPANT	\N	PRESENT	0
252069	240310	14235Q	PARTICIPANT	\N	PRESENT	0
252071	240310	15447F	PARTICIPANT	\N	PRESENT	0
252073	240310	14093U	PARTICIPANT	\N	PRESENT	0
252074	240310	04071H	PARTICIPANT	\N	PRESENT	0
252079	240310	10015M	PARTICIPANT	\N	PRESENT	0
252082	240310	14223L	PARTICIPANT	\N	PRESENT	0
252083	240310	14051J	PARTICIPANT	\N	PRESENT	0
252084	240310	08028W	PARTICIPANT	\N	PRESENT	0
252085	240310	01028R	PARTICIPANT	\N	PRESENT	0
252087	240310	08068F	PARTICIPANT	\N	PRESENT	0
252088	240310	14169X	PARTICIPANT	\N	PRESENT	0
252089	240310	14107H	PARTICIPANT	\N	PRESENT	0
252090	240310	19515S	PARTICIPANT	\N	PRESENT	0
252091	240310	11080N	PARTICIPANT	\N	PRESENT	0
252092	240310	14197C	PARTICIPANT	\N	PRESENT	0
252093	240310	14191V	PARTICIPANT	\N	PRESENT	0
252094	240310	14151M	PARTICIPANT	\N	PRESENT	0
252095	240310	14259Y	PARTICIPANT	\N	PRESENT	0
252096	240310	01057W	PARTICIPANT	\N	PRESENT	0
252097	240310	08053X	PARTICIPANT	\N	PRESENT	0
252098	240310	11064N	PARTICIPANT	\N	PRESENT	0
252099	240310	19703U	PARTICIPANT	\N	PRESENT	0
252100	240310	04057K	PARTICIPANT	\N	PRESENT	0
252101	240310	19673G	PARTICIPANT	\N	PRESENT	0
252102	240310	14031R	PARTICIPANT	\N	PRESENT	0
252103	240310	19637C	PARTICIPANT	\N	PRESENT	0
259725	250089	04040A	PARTICIPANT	\N	PRESENT	0
259726	250089	04070G	PARTICIPANT	\N	PRESENT	0
259727	250089	14030Q	PARTICIPANT	\N	PRESENT	0
259728	250089	01025N	PARTICIPANT	\N	PRESENT	0
259729	250089	01024M	PARTICIPANT	\N	PRESENT	0
259730	250089	14327T	PARTICIPANT	\N	PRESENT	0
259731	250089	01043Q	PARTICIPANT	\N	PRESENT	0
259732	250089	19719D	PARTICIPANT	\N	PRESENT	0
259737	250089	10006L	PARTICIPANT	\N	PRESENT	0
259738	250089	98050T	PARTICIPANT	\N	PRESENT	0
259739	250089	14119M	PARTICIPANT	\N	PRESENT	0
259740	250089	14217N	PARTICIPANT	\N	PRESENT	0
259741	250089	19747H	PARTICIPANT	\N	PRESENT	0
259742	250089	01060R	PARTICIPANT	\N	PRESENT	0
259743	250089	14115H	PARTICIPANT	\N	PRESENT	0
259744	250089	04059M	PARTICIPANT	\N	PRESENT	0
259745	250089	19593H	PARTICIPANT	\N	PRESENT	0
259753	250089	11045K	PARTICIPANT	\N	PRESENT	0
259754	252207	08056B	PARTICIPANT	\N	PRESENT	0
259755	252207	19421M	PARTICIPANT	\N	PRESENT	0
259756	252207	98022P	PARTICIPANT	\N	PRESENT	0
259757	252207	11026G	PARTICIPANT	\N	PRESENT	0
259758	252207	10015M	PARTICIPANT	\N	PRESENT	0
259759	252207	19575F	PARTICIPANT	\N	PRESENT	0
259760	252207	98050T	PARTICIPANT	\N	PRESENT	0
259761	252207	08010L	PARTICIPANT	\N	PRESENT	0
259762	252207	98029W	PRESIDENT	0	PRESENT	0
259763	255984	08056B	PARTICIPANT	\N	PRESENT	0
259764	255984	98022P	PARTICIPANT	\N	PRESENT	0
259765	255984	11026G	PARTICIPANT	\N	PRESENT	0
259766	255984	10015M	PARTICIPANT	\N	PRESENT	0
259767	255984	19575F	PARTICIPANT	\N	PRESENT	0
259768	255984	98050T	PARTICIPANT	\N	PRESENT	0
259769	255984	08010L	PARTICIPANT	\N	PRESENT	0
259770	255984	04008A	PARTICIPANT	\N	PRESENT	0
259771	255984	98029W	PRESIDENT	0	PRESENT	0
259774	259773	14085U	PARTICIPANT	\N	PRESENT	0
259775	259773	11070L	PARTICIPANT	\N	PRESENT	0
259776	259773	14327T	PARTICIPANT	\N	PRESENT	0
259777	259773	11074Q	PARTICIPANT	\N	PRESENT	0
259778	259773	01057W	PARTICIPANT	\N	PRESENT	0
259779	259773	11048N	PARTICIPANT	\N	PRESENT	0
259780	259773	08011M	PARTICIPANT	\N	PRESENT	0
259781	259773	11012A	PARTICIPANT	\N	PRESENT	0
259782	259773	19687N	PARTICIPANT	\N	PRESENT	0
260070	250090	11072N	PARTICIPANT	\N	PRESENT	0
260071	250090	11031D	PARTICIPANT	\N	PRESENT	0
260072	250090	19649G	PARTICIPANT	\N	PRESENT	0
260073	250090	11045K	PARTICIPANT	\N	PRESENT	0
260074	250090	11067R	PARTICIPANT	\N	PRESENT	0
260075	250090	14281W	PARTICIPANT	\N	PRESENT	0
260076	250090	08017T	PARTICIPANT	\N	PRESENT	0
260077	250090	11109J	PARTICIPANT	\N	PRESENT	0
260078	250090	08043V	PARTICIPANT	\N	PRESENT	0
260079	250090	14065Q	PARTICIPANT	\N	PRESENT	0
260080	250090	14229S	PARTICIPANT	\N	PRESENT	0
260081	250090	19289C	PARTICIPANT	\N	PRESENT	0
260082	250090	19719D	PARTICIPANT	\N	PRESENT	0
260083	250090	19725B	PARTICIPANT	\N	PRESENT	0
260084	250090	19543W	PARTICIPANT	\N	PRESENT	0
260085	250090	95063L	PARTICIPANT	\N	PRESENT	0
260086	250090	08061X	PARTICIPANT	\N	PRESENT	0
260087	250090	19253P	PARTICIPANT	\N	PRESENT	0
260088	250090	14111D	PARTICIPANT	\N	PRESENT	0
260089	250090	19479G	PARTICIPANT	\N	PRESENT	0
260090	250090	14042U	PARTICIPANT	\N	PRESENT	0
260091	250090	14231L	PARTICIPANT	\N	PRESENT	0
260092	250090	19747H	PARTICIPANT	\N	PRESENT	0
260093	250090	14215L	PARTICIPANT	\N	PRESENT	0
260094	250090	14030Q	PARTICIPANT	\N	PRESENT	0
260095	250090	04047H	PARTICIPANT	\N	PRESENT	0
260096	250090	95030B	PARTICIPANT	\N	PRESENT	0
260097	250090	19415P	PARTICIPANT	\N	PRESENT	0
260098	250090	07029T	PARTICIPANT	\N	PRESENT	0
260099	250090	19447X	PARTICIPANT	\N	PRESENT	0
260100	250090	19703U	PARTICIPANT	\N	PRESENT	0
260101	250090	19673G	PARTICIPANT	\N	PRESENT	0
260102	250090	14191V	PARTICIPANT	\N	PRESENT	0
260103	250090	08069G	PARTICIPANT	\N	PRESENT	0
260104	250090	14069U	PARTICIPANT	\N	PRESENT	0
260105	250090	19643A	PARTICIPANT	\N	PRESENT	0
260106	250090	97011G	PARTICIPANT	\N	PRESENT	0
260107	258642	19333N	PARTICIPANT	\N	PRESENT	0
260108	258642	17583W	PARTICIPANT	\N	PRESENT	0
260109	258642	19701S	PARTICIPANT	\N	PRESENT	0
260110	258642	95062K	PARTICIPANT	\N	PRESENT	0
260111	258642	19549D	PARTICIPANT	\N	PRESENT	0
260112	258642	19387D	PARTICIPANT	\N	PRESENT	0
260113	258642	14219Q	PARTICIPANT	\N	PRESENT	0
260114	258642	14221J	PARTICIPANT	\N	PRESENT	0
260115	258642	02002K	PARTICIPANT	\N	PRESENT	0
260116	258642	18083K	PARTICIPANT	\N	PRESENT	0
260117	258642	19551W	PARTICIPANT	\N	PRESENT	0
260118	258642	14051J	PARTICIPANT	\N	PRESENT	0
260119	258642	08060W	PARTICIPANT	\N	PRESENT	0
260120	258642	19503N	PARTICIPANT	\N	PRESENT	0
260121	258642	19347U	PARTICIPANT	\N	PRESENT	0
260122	258642	14157T	PARTICIPANT	\N	PRESENT	0
260123	258642	19685L	PARTICIPANT	\N	PRESENT	0
260124	258642	08024S	PARTICIPANT	\N	PRESENT	0
260125	258642	98023Q	PARTICIPANT	\N	PRESENT	0
260126	258642	11065P	PARTICIPANT	\N	PRESENT	0
260127	258642	19525U	PARTICIPANT	\N	PRESENT	0
260128	258642	14038Y	PARTICIPANT	\N	PRESENT	0
260129	258642	14031R	PARTICIPANT	\N	PRESENT	0
260130	258642	19713W	PARTICIPANT	\N	PRESENT	0
260131	258642	14169X	PARTICIPANT	\N	PRESENT	0
260132	258642	15447F	PARTICIPANT	\N	PRESENT	0
260133	258642	14093U	PARTICIPANT	\N	PRESENT	0
260134	258642	19733B	PARTICIPANT	\N	PRESENT	0
260135	258642	19739H	PARTICIPANT	\N	PRESENT	0
260136	250090	10006L	PARTICIPANT	\N	PRESENT	0
260137	250090	19533U	PARTICIPANT	\N	PRESENT	0
260138	250090	14187A	PARTICIPANT	\N	PRESENT	0
260139	250090	07034Q	PARTICIPANT	\N	PRESENT	0
260140	250090	19679N	PARTICIPANT	\N	PRESENT	0
260141	250090	19693L	PARTICIPANT	\N	PRESENT	0
260142	250090	08031R	PARTICIPANT	\N	PRESENT	0
260143	250090	19629C	PARTICIPANT	\N	PRESENT	0
260144	250090	19695N	PARTICIPANT	\N	PRESENT	0
260145	250090	05008E	PARTICIPANT	\N	PRESENT	0
260146	250090	14147R	PARTICIPANT	\N	PRESENT	0
260147	250090	04049K	PARTICIPANT	\N	PRESENT	0
260148	250090	14249W	PARTICIPANT	\N	PRESENT	0
260149	250090	14223L	PARTICIPANT	\N	PRESENT	0
260150	250090	14329V	PARTICIPANT	\N	PRESENT	0
260151	250090	11056N	PARTICIPANT	\N	PRESENT	0
260152	250090	19611R	PARTICIPANT	\N	PRESENT	0
260153	250090	19569H	PARTICIPANT	\N	PRESENT	0
260154	250090	19651A	PARTICIPANT	\N	PRESENT	0
260155	250090	11097X	PARTICIPANT	\N	PRESENT	0
260156	250090	14213J	PARTICIPANT	\N	PRESENT	0
260157	250090	14053L	PARTICIPANT	\N	PRESENT	0
260158	250090	14211G	PARTICIPANT	\N	PRESENT	0
260159	250090	19565D	PARTICIPANT	\N	PRESENT	0
260160	258642	05012A	PARTICIPANT	\N	PRESENT	0
260161	250090	14119M	PARTICIPANT	\N	PRESENT	0
260162	250090	87003B	PARTICIPANT	\N	PRESENT	0
260163	250090	19573D	PARTICIPANT	\N	PRESENT	0
260164	250090	11033F	PARTICIPANT	\N	PRESENT	0
260170	250090	19713W	PARTICIPANT	\N	PRESENT	0
260171	250090	14073Q	PARTICIPANT	\N	PRESENT	0
260172	250090	19553Y	PARTICIPANT	\N	PRESENT	0
260173	250090	11043H	PARTICIPANT	\N	PRESENT	0
260174	250090	19621T	PARTICIPANT	\N	PRESENT	0
260175	250090	04018C	PARTICIPANT	\N	PRESENT	0
260176	250090	14331P	PARTICIPANT	\N	PRESENT	0
260177	250090	14157T	PARTICIPANT	\N	PRESENT	0
260178	250090	19383Y	PARTICIPANT	\N	PRESENT	0
260179	250090	11048N	PARTICIPANT	\N	PRESENT	0
260180	250090	08039A	PARTICIPANT	\N	PRESENT	0
260181	250090	14071N	PARTICIPANT	\N	PRESENT	0
260182	250090	14179A	PARTICIPANT	\N	PRESENT	0
260183	250090	19733B	PARTICIPANT	\N	PRESENT	0
260184	250090	08020N	PARTICIPANT	\N	PRESENT	0
260185	250090	14275Y	PARTICIPANT	\N	PRESENT	0
260186	250090	19269X	PARTICIPANT	\N	PRESENT	0
260187	250090	01024M	PARTICIPANT	\N	PRESENT	0
260188	250090	14265W	PARTICIPANT	\N	PRESENT	0
260189	250090	14033T	PARTICIPANT	\N	PRESENT	0
260190	250090	04088S	PARTICIPANT	\N	PRESENT	0
260191	250090	14031R	PARTICIPANT	\N	PRESENT	0
260192	250090	14133K	PARTICIPANT	\N	PRESENT	0
260193	250090	14217N	PARTICIPANT	\N	PRESENT	0
260194	250090	14059S	PARTICIPANT	\N	PRESENT	0
260203	250090	19367Y	PARTICIPANT	\N	PRESENT	0
260204	250090	14135M	PARTICIPANT	\N	PRESENT	0
260205	250090	19727D	PARTICIPANT	\N	PRESENT	0
240564	239004	12016W	PARTICIPANT	\N	PRESENT	0
240565	239004	14059S	PARTICIPANT	\N	PRESENT	0
240566	239004	19657G	PARTICIPANT	\N	PRESENT	0
240567	239004	19703U	PARTICIPANT	\N	PRESENT	0
240568	239004	19729F	PARTICIPANT	\N	PRESENT	0
240569	239004	98005N	PARTICIPANT	\N	PRESENT	0
240570	239004	14097Y	PARTICIPANT	\N	PRESENT	0
240571	239004	19329S	PARTICIPANT	\N	EXCUSE	0
240572	239004	14033T	PARTICIPANT	\N	EXCUSE	0
240573	239004	14199E	PARTICIPANT	\N	PRESENT	0
240574	239004	19295A	PARTICIPANT	\N	EXCUSE	0
240575	239004	14038Y	PARTICIPANT	\N	PRESENT	0
240576	239004	11109J	PARTICIPANT	\N	PRESENT	0
240577	239004	19717B	PARTICIPANT	\N	PRESENT	0
240579	239004	19631V	PARTICIPANT	\N	PRESENT	0
240582	239004	19691J	PARTICIPANT	\N	PRESENT	0
240583	239004	19715Y	PARTICIPANT	\N	EXCUSE	0
240584	239004	19577H	PARTICIPANT	\N	PRESENT	0
243395	243394	95063L	PARTICIPANT	\N	PRESENT	0
247139	247137	19489J	PARTICIPANT	\N	PRESENT	0
247140	247137	05012A	PARTICIPANT	\N	PRESENT	0
247142	247137	08068F	PARTICIPANT	\N	PRESENT	0
247193	247137	14063N	PARTICIPANT	\N	PRESENT	0
253038	250198	11080N	PARTICIPANT	\N	PRESENT	0
253036	250198	14089Y	PARTICIPANT	\N	PRESENT	0
253037	250198	98029W	PARTICIPANT	\N	PRESENT	0
253039	250198	11027H	PARTICIPANT	\N	PRESENT	0
253040	250198	19673G	PARTICIPANT	\N	PRESENT	0
253041	250198	98022P	PARTICIPANT	\N	PRESENT	0
253042	250198	08056B	PARTICIPANT	\N	PRESENT	0
253043	250198	19611R	PARTICIPANT	\N	PRESENT	0
253044	250198	08053X	PARTICIPANT	\N	PRESENT	0
253045	250198	98050T	PARTICIPANT	\N	PRESENT	0
253046	250198	10015M	PARTICIPANT	\N	PRESENT	0
253047	250198	19421M	PARTICIPANT	\N	PRESENT	0
253048	250197	14089Y	PARTICIPANT	\N	PRESENT	0
253049	250197	98029W	PARTICIPANT	\N	PRESENT	0
253050	250197	11080N	PARTICIPANT	\N	PRESENT	0
253051	250197	11027H	PARTICIPANT	\N	PRESENT	0
253052	250197	19673G	PARTICIPANT	\N	PRESENT	0
253053	250197	98022P	PARTICIPANT	\N	PRESENT	0
253054	250197	08056B	PARTICIPANT	\N	PRESENT	0
253055	250197	19611R	PARTICIPANT	\N	PRESENT	0
253056	250197	08053X	PARTICIPANT	\N	PRESENT	0
253057	250197	98050T	PARTICIPANT	\N	PRESENT	0
253058	250197	10015M	PARTICIPANT	\N	PRESENT	0
253059	250197	19421M	PARTICIPANT	\N	PRESENT	0
253060	250192	19575F	PARTICIPANT	\N	PRESENT	0
253061	250192	98029W	PARTICIPANT	\N	PRESENT	0
253062	250192	08056B	PARTICIPANT	\N	PRESENT	0
253063	250192	98022P	PARTICIPANT	\N	PRESENT	0
253064	250192	19669L	PARTICIPANT	\N	PRESENT	0
253065	250192	19611R	PARTICIPANT	\N	PRESENT	0
254770	240318	14147R	PARTICIPANT	\N	PRESENT	0
254797	252853	14327T	PARTICIPANT	\N	PRESENT	0
254798	252853	14331P	PARTICIPANT	\N	PRESENT	0
254799	252853	95041E	PARTICIPANT	\N	PRESENT	0
254800	252853	19545Y	PARTICIPANT	\N	PRESENT	0
254801	252853	01057W	PARTICIPANT	\N	PRESENT	0
254802	252853	11053K	PARTICIPANT	\N	PRESENT	0
254803	252853	19667J	PARTICIPANT	\N	PRESENT	0
254804	252853	11074Q	PRESIDENT	0	PRESENT	0
254805	252853	89017R	PARTICIPANT	\N	PRESENT	0
254806	252853	88008L	PARTICIPANT	\N	PRESENT	0
254807	252853	19671E	PARTICIPANT	\N	PRESENT	0
254808	252853	07029T	PARTICIPANT	\N	PRESENT	0
254809	252853	14085U	PARTICIPANT	\N	PRESENT	0
254810	252853	19349W	PARTICIPANT	\N	PRESENT	0
254811	252853	08010L	PARTICIPANT	\N	PRESENT	0
254812	252853	14253S	PARTICIPANT	\N	PRESENT	0
254813	252853	11048N	PARTICIPANT	\N	PRESENT	0
254814	252853	19479G	PARTICIPANT	\N	PRESENT	0
254815	252853	19711U	PARTICIPANT	\N	PRESENT	0
254816	252853	08034U	PARTICIPANT	\N	PRESENT	0
254817	252853	19531S	PARTICIPANT	\N	PRESENT	0
254818	252853	19651A	PARTICIPANT	\N	PRESENT	0
254819	252853	08069G	PARTICIPANT	\N	PRESENT	0
254820	252853	19687N	PARTICIPANT	\N	PRESENT	0
254821	252853	19689Q	PARTICIPANT	\N	PRESENT	0
254822	252853	12016W	PARTICIPANT	\N	PRESENT	0
254823	252853	08011M	PARTICIPANT	\N	PRESENT	0
254824	252853	14034U	PARTICIPANT	\N	PRESENT	0
254825	252853	14159V	PARTICIPANT	\N	PRESENT	0
254826	252853	14173T	PARTICIPANT	\N	PRESENT	0
254827	252853	04086Q	PARTICIPANT	\N	PRESENT	0
254828	252853	11040E	PARTICIPANT	\N	PRESENT	0
254829	252853	14083S	PARTICIPANT	\N	PRESENT	0
254830	252853	14199E	PARTICIPANT	\N	PRESENT	0
254831	252853	11012A	PARTICIPANT	\N	PRESENT	0
254832	252853	08073C	PARTICIPANT	\N	PRESENT	0
254833	252853	14121F	PARTICIPANT	\N	PRESENT	0
254834	252853	19741B	PARTICIPANT	\N	PRESENT	0
254835	252853	99004R	PARTICIPANT	\N	PRESENT	0
254836	252853	04061F	PARTICIPANT	\N	PRESENT	0
254837	252853	07004J	PARTICIPANT	\N	EXCUSE	0
254868	251799	19333N	PARTICIPANT	\N	PRESENT	0
254869	251799	19383Y	PARTICIPANT	\N	PRESENT	0
254870	251799	17583W	PARTICIPANT	\N	PRESENT	0
254871	251799	19701S	PARTICIPANT	\N	PRESENT	0
254872	251799	95062K	PARTICIPANT	\N	PRESENT	0
254873	251799	19549D	PARTICIPANT	\N	PRESENT	0
254874	251799	19387D	PARTICIPANT	\N	PRESENT	0
254875	251799	14219Q	PARTICIPANT	\N	PRESENT	0
254876	251799	14221J	PARTICIPANT	\N	PRESENT	0
254877	251799	19637C	PARTICIPANT	\N	PRESENT	0
254878	251799	18083K	PARTICIPANT	\N	PRESENT	0
254879	251799	19551W	PARTICIPANT	\N	PRESENT	0
254880	251799	14237S	PARTICIPANT	\N	PRESENT	0
254881	251799	05012A	PARTICIPANT	\N	PRESENT	0
254882	251799	14051J	PARTICIPANT	\N	PRESENT	0
254883	251799	08060W	PARTICIPANT	\N	PRESENT	0
254884	251799	19503N	PARTICIPANT	\N	PRESENT	0
254885	251799	19347U	PARTICIPANT	\N	PRESENT	0
254886	251799	96004D	PARTICIPANT	\N	PRESENT	0
254887	251799	08024S	PARTICIPANT	\N	PRESENT	0
254888	251799	98023Q	PARTICIPANT	\N	PRESENT	0
254889	251799	19525U	PARTICIPANT	\N	PRESENT	0
254890	251799	14038Y	PARTICIPANT	\N	PRESENT	0
254891	251799	14031R	PARTICIPANT	\N	PRESENT	0
254892	251799	19713W	PARTICIPANT	\N	PRESENT	0
254893	251799	08055A	PARTICIPANT	\N	PRESENT	0
254894	251799	19289C	PARTICIPANT	\N	PRESENT	0
254895	251799	04085P	PARTICIPANT	\N	PRESENT	0
254896	251799	15447F	PARTICIPANT	\N	PRESENT	0
254897	251799	14093U	PARTICIPANT	\N	PRESENT	0
254898	251799	14029X	PARTICIPANT	\N	PRESENT	0
254899	251799	19733B	PARTICIPANT	\N	PRESENT	0
254900	251799	19737F	PARTICIPANT	\N	PRESENT	0
254901	251799	19739H	PARTICIPANT	\N	PRESENT	0
254902	251799	19745F	PARTICIPANT	\N	PRESENT	0
254904	251799	14157T	PARTICIPANT	\N	PRESENT	0
254905	251799	19681G	PARTICIPANT	\N	PRESENT	0
254906	251799	04097T	PARTICIPANT	\N	PRESENT	0
254907	251799	17637T	PARTICIPANT	\N	PRESENT	0
254908	251799	14103D	PARTICIPANT	\N	PRESENT	0
254909	253501	19515S	PARTICIPANT	\N	PRESENT	0
254910	253501	01043Q	PARTICIPANT	\N	PRESENT	0
254911	253501	19565D	PARTICIPANT	\N	PRESENT	0
254912	253501	14357A	PARTICIPANT	\N	PRESENT	0
254913	253501	19441R	PARTICIPANT	\N	PRESENT	0
254914	253501	14081Q	PARTICIPANT	\N	PRESENT	0
254915	253501	19413M	PARTICIPANT	\N	PRESENT	0
254916	253501	80013X	PARTICIPANT	\N	PRESENT	0
254917	253501	19631V	PARTICIPANT	\N	PRESENT	0
254918	253501	11099A	PARTICIPANT	\N	PRESENT	0
254919	253501	08068F	PARTICIPANT	\N	PRESENT	0
254920	253501	04049K	PARTICIPANT	\N	PRESENT	0
254921	253501	19705W	PARTICIPANT	\N	PRESENT	0
254922	253501	19707Y	PARTICIPANT	\N	PRESENT	0
254923	253501	08015R	PARTICIPANT	\N	PRESENT	0
254924	253501	14197C	PARTICIPANT	\N	PRESENT	0
254925	253501	19369B	PARTICIPANT	\N	PRESENT	0
254926	253501	19511N	PARTICIPANT	\N	PRESENT	0
254927	253501	08028W	PARTICIPANT	\N	PRESENT	0
254928	253501	19563B	PARTICIPANT	\N	PRESENT	0
254929	253501	14265W	PARTICIPANT	\N	PRESENT	0
254930	253501	14135M	PARTICIPANT	\N	PRESENT	0
254931	253501	19467C	PARTICIPANT	\N	PRESENT	0
254932	253501	14187A	PARTICIPANT	\N	PRESENT	0
254933	253501	08038Y	PARTICIPANT	\N	PRESENT	0
254934	253501	08062Y	PARTICIPANT	\N	PRESENT	0
254935	253501	19301E	PARTICIPANT	\N	PRESENT	0
254936	253501	19695N	PARTICIPANT	\N	PRESENT	0
254937	253501	14033T	PARTICIPANT	\N	PRESENT	0
254938	253501	11090Q	PARTICIPANT	\N	PRESENT	0
254939	253501	01025N	PARTICIPANT	\N	PRESENT	0
254940	253501	19295A	PARTICIPANT	\N	PRESENT	0
254941	253501	19269X	PARTICIPANT	\N	PRESENT	0
254942	253501	14205J	PARTICIPANT	\N	PRESENT	0
261720	261717	08055A	PARTICIPANT	\N	PRESENT	0
261722	261717	04047H	PARTICIPANT	0	PRESENT	0
261723	261717	19545Y	PARTICIPANT	\N	EXCUSE	0
261725	261717	14085U	PARTICIPANT	\N	PRESENT	0
261726	261717	11080N	PARTICIPANT	\N	EXCUSE	0
261728	261717	11083R	PARTICIPANT	\N	PRESENT	0
261730	261717	01057W	PARTICIPANT	\N	PRESENT	0
261731	261717	19611R	PARTICIPANT	\N	PRESENT	0
261732	261717	19687N	PARTICIPANT	\N	EXCUSE	0
261734	261717	08049C	PARTICIPANT	\N	EXCUSE	0
261736	261717	14157T	PARTICIPANT	\N	PRESENT	0
267819	267817	19667J	PARTICIPANT	\N	PRESENT	0
264075	258758	19657G	PARTICIPANT	\N	PRESENT	0
264076	258759	14135M	PARTICIPANT	\N	EXCUSE	0
264077	258757	14135M	PARTICIPANT	\N	EXCUSE	0
264078	258758	19295A	PARTICIPANT	\N	EXCUSE	0
264080	258758	19659J	PARTICIPANT	\N	EXCUSE	0
264081	258757	19659J	PARTICIPANT	\N	EXCUSE	0
264082	258759	19659J	PARTICIPANT	\N	EXCUSE	0
264084	258758	14033T	PARTICIPANT	\N	EXCUSE	0
264085	258758	14038Y	PARTICIPANT	\N	EXCUSE	0
264087	258758	14039A	PARTICIPANT	\N	EXCUSE	0
264093	258758	11072N	PARTICIPANT	\N	PRESENT	0
264095	258758	14157T	PARTICIPANT	\N	EXCUSE	0
264096	258758	19329S	PARTICIPANT	\N	EXCUSE	0
267818	267817	11040E	PARTICIPANT	\N	PRESENT	0
267822	267821	88008L	PARTICIPANT	\N	PRESENT	0
267823	267821	11012A	PARTICIPANT	\N	PRESENT	0
267840	267837	14121F	PARTICIPANT	\N	PRESENT	0
267936	267934	19711U	PARTICIPANT	\N	PRESENT	0
267937	267935	19711U	PARTICIPANT	\N	PRESENT	0
268121	267022	11048N	PARTICIPANT	\N	PRESENT	0
268122	267022	19479G	PARTICIPANT	\N	PRESENT	0
268123	267022	19647E	PARTICIPANT	\N	PRESENT	0
268124	267022	08034U	PARTICIPANT	\N	PRESENT	0
268125	267022	08069G	PARTICIPANT	\N	PRESENT	0
268126	267022	19687N	PARTICIPANT	\N	PRESENT	0
268127	267022	19689Q	PARTICIPANT	\N	PRESENT	0
268128	267022	08011M	PARTICIPANT	\N	PRESENT	0
268129	267022	08014Q	PARTICIPANT	\N	PRESENT	0
268130	267022	14173T	PARTICIPANT	\N	PRESENT	0
268131	267022	11040E	PARTICIPANT	\N	PRESENT	0
268132	267022	11012A	PARTICIPANT	\N	PRESENT	0
268133	267022	99004R	PARTICIPANT	\N	PRESENT	0
268134	267022	04061F	PARTICIPANT	\N	PRESENT	0
268135	267315	14097Y	PARTICIPANT	\N	PRESENT	0
268136	267315	04035D	PARTICIPANT	\N	PRESENT	0
268137	267315	19443T	PARTICIPANT	\N	PRESENT	0
268138	267315	19709B	PARTICIPANT	\N	PRESENT	0
268139	267315	14267Y	PARTICIPANT	\N	PRESENT	0
268140	267315	11064N	PARTICIPANT	\N	PRESENT	0
268141	267315	98050T	PARTICIPANT	\N	PRESENT	0
268142	267315	04042C	PRESIDENT	0	PRESENT	0
268143	267315	19251M	PARTICIPANT	\N	PRESENT	0
268144	267315	19583F	PARTICIPANT	\N	PRESENT	0
268145	267315	08047A	PARTICIPANT	\N	PRESENT	0
268146	267315	98029W	PARTICIPANT	\N	PRESENT	0
268147	267315	16685X	PARTICIPANT	\N	PRESENT	0
268148	267315	14105F	PARTICIPANT	\N	PRESENT	0
268149	267315	14133K	PARTICIPANT	\N	PRESENT	0
268150	267315	04034C	PARTICIPANT	\N	PRESENT	0
268151	267315	04040A	PARTICIPANT	\N	PRESENT	0
268152	267315	11027H	PARTICIPANT	\N	PRESENT	0
268153	267315	08058D	PARTICIPANT	\N	PRESENT	0
268154	267315	95037J	PARTICIPANT	\N	PRESENT	0
268155	267315	98018T	PARTICIPANT	\N	PRESENT	0
268156	267315	19421M	PARTICIPANT	\N	PRESENT	0
268157	267315	08053X	PARTICIPANT	\N	PRESENT	0
268158	267315	08061X	PARTICIPANT	\N	PRESENT	0
268159	267315	11041F	PARTICIPANT	\N	PRESENT	0
268160	267315	08056B	PARTICIPANT	\N	PRESENT	0
268161	267315	95067Q	PARTICIPANT	\N	PRESENT	0
268162	267315	14079W	PARTICIPANT	\N	PRESENT	0
268163	267315	01062T	PARTICIPANT	\N	PRESENT	0
268164	267315	98022P	PARTICIPANT	\N	PRESENT	0
268165	267315	11054L	PARTICIPANT	\N	PRESENT	0
268166	267315	11066Q	PARTICIPANT	\N	PRESENT	0
268168	268167	14221J	PARTICIPANT	\N	EXCUSE	0
268169	268167	14173T	PARTICIPANT	\N	EXCUSE	0
268170	267314	95030B	PARTICIPANT	\N	EXCUSE	0
268171	267314	97011G	PARTICIPANT	\N	EXCUSE	0
268172	267315	14255U	PARTICIPANT	\N	PRESENT	0
268173	267060	14089Y	PARTICIPANT	\N	PRESENT	0
268174	267060	14169X	PARTICIPANT	\N	PRESENT	0
268175	267315	19721W	PARTICIPANT	\N	PRESENT	0
268176	267403	17583W	PARTICIPANT	\N	PRESENT	0
268177	267403	19549D	PARTICIPANT	\N	PRESENT	0
268178	267403	19673G	PARTICIPANT	\N	PRESENT	0
268179	267403	01028R	PARTICIPANT	\N	PRESENT	0
268180	267403	02002K	PARTICIPANT	\N	PRESENT	0
268181	267403	19551W	PARTICIPANT	\N	PRESENT	0
268182	267403	14041T	PARTICIPANT	\N	PRESENT	0
268183	267403	14147R	PARTICIPANT	\N	PRESENT	0
268184	267403	14151M	PARTICIPANT	\N	PRESENT	0
268185	267403	14157T	PARTICIPANT	\N	PRESENT	0
268186	267403	19681G	PARTICIPANT	\N	PRESENT	0
268187	267403	98023Q	PARTICIPANT	\N	PRESENT	0
268188	267403	14065Q	PARTICIPANT	\N	PRESENT	0
268189	267403	10015M	PARTICIPANT	\N	PRESENT	0
268191	267403	19289C	PARTICIPANT	\N	PRESENT	0
268192	267403	14191V	PARTICIPANT	\N	PRESENT	0
268194	267403	08044W	PARTICIPANT	\N	PRESENT	0
268195	267403	14069U	PARTICIPANT	\N	PRESENT	0
268196	267403	11049P	PARTICIPANT	\N	PRESENT	0
268197	267403	19383Y	PARTICIPANT	\N	PRESENT	0
268198	267403	19387D	PARTICIPANT	\N	PRESENT	0
268199	267403	14001X	PARTICIPANT	\N	PRESENT	0
268200	267403	14219Q	PARTICIPANT	\N	PRESENT	0
268201	267403	04044E	PARTICIPANT	\N	PRESENT	0
268202	267403	19581D	PARTICIPANT	\N	PRESENT	0
268203	267403	19585H	PARTICIPANT	\N	PRESENT	0
268204	267403	19599P	PARTICIPANT	\N	PRESENT	0
268205	267403	05008E	PRESIDENT	0	PRESENT	0
268206	267403	14231L	PARTICIPANT	\N	PRESENT	0
268207	267403	18083K	PARTICIPANT	\N	PRESENT	0
268208	267403	14237S	PARTICIPANT	\N	PRESENT	0
268209	267403	05012A	PARTICIPANT	\N	PRESENT	0
268210	267403	14051J	PARTICIPANT	\N	PRESENT	0
268211	267403	19489J	PARTICIPANT	\N	PRESENT	0
268212	267403	19503N	PARTICIPANT	\N	PRESENT	0
268213	267403	14215L	PARTICIPANT	\N	PRESENT	0
268214	267403	17637T	PARTICIPANT	\N	PRESENT	0
268215	267403	14135M	PARTICIPANT	\N	PRESENT	0
268216	267403	14053L	PARTICIPANT	\N	PRESENT	0
268217	267403	14031R	PARTICIPANT	\N	PRESENT	0
268218	267403	19713W	PARTICIPANT	\N	PRESENT	0
268219	267403	07034Q	PARTICIPANT	\N	PRESENT	0
268220	267403	08045X	PARTICIPANT	\N	PRESENT	0
268221	267403	19253P	PARTICIPANT	\N	PRESENT	0
268222	267403	19719D	PARTICIPANT	\N	PRESENT	0
268223	267403	14169X	PARTICIPANT	\N	PRESENT	0
268224	267403	14029X	PARTICIPANT	\N	PRESENT	0
268225	267403	08009T	PARTICIPANT	\N	PRESENT	0
268226	267403	19737F	PARTICIPANT	\N	PRESENT	0
268227	267403	19739H	PARTICIPANT	\N	PRESENT	0
268228	267403	19745F	PARTICIPANT	\N	PRESENT	0
268229	267403	19659J	PARTICIPANT	\N	PRESENT	0
268230	267061	19383Y	PARTICIPANT	\N	PRESENT	0
268231	267061	19333N	PARTICIPANT	\N	PRESENT	0
268232	267061	19549D	PARTICIPANT	\N	PRESENT	0
268233	267061	19387D	PARTICIPANT	\N	PRESENT	0
268234	267061	14219Q	PARTICIPANT	\N	PRESENT	0
268235	267061	19599P	PARTICIPANT	\N	PRESENT	0
268236	267061	19551W	PARTICIPANT	\N	PRESENT	0
268237	267061	80027E	PARTICIPANT	\N	PRESENT	0
268238	267061	14051J	PARTICIPANT	\N	PRESENT	0
268239	267061	19347U	PARTICIPANT	\N	PRESENT	0
268240	267061	19503N	PARTICIPANT	\N	PRESENT	0
268241	267061	19685L	PARTICIPANT	\N	PRESENT	0
268242	267061	17637T	PARTICIPANT	\N	PRESENT	0
268243	267061	14038Y	PARTICIPANT	\N	PRESENT	0
268244	267061	19713W	PARTICIPANT	\N	PRESENT	0
268245	267061	14031R	PARTICIPANT	\N	PRESENT	0
268246	267061	08055A	PARTICIPANT	\N	PRESENT	0
268247	267061	19289C	PARTICIPANT	\N	PRESENT	0
268248	267061	14191V	PARTICIPANT	\N	PRESENT	0
268249	267061	14169X	PARTICIPANT	\N	PRESENT	0
268250	267061	04085P	PARTICIPANT	\N	PRESENT	0
268251	267061	14029X	PARTICIPANT	\N	PRESENT	0
268252	267061	19733B	PARTICIPANT	\N	PRESENT	0
268253	267061	08009T	PRESIDENT	0	PRESENT	0
268254	267061	19737F	PARTICIPANT	\N	PRESENT	0
268255	267061	19739H	PARTICIPANT	\N	PRESENT	0
268256	267061	04097T	PARTICIPANT	\N	PRESENT	0
268257	267061	19745F	PARTICIPANT	\N	PRESENT	0
268258	267061	08060W	PARTICIPANT	\N	EXCUSE	0
268259	267061	08024S	PARTICIPANT	\N	EXCUSE	0
247063	247062	14079W	PARTICIPANT	\N	PRESENT	0
247069	247068	08052W	PARTICIPANT	\N	PRESENT	0
247070	247068	19667J	PARTICIPANT	\N	PRESENT	0
247071	247068	14042U	PARTICIPANT	\N	PRESENT	0
247072	247068	11049P	PARTICIPANT	\N	PRESENT	0
247073	247068	19593H	PARTICIPANT	\N	PRESENT	0
247249	247248	14255U	PARTICIPANT	\N	PRESENT	0
247250	247248	11027H	PARTICIPANT	\N	PRESENT	0
247251	247248	16685X	PARTICIPANT	\N	PRESENT	0
247252	247248	95067Q	PARTICIPANT	\N	PRESENT	0
252106	240310	14199E	PARTICIPANT	\N	PRESENT	0
252107	240310	19575F	PARTICIPANT	\N	PRESENT	0
252108	240310	19631V	PARTICIPANT	\N	PRESENT	0
252109	240310	11048N	PARTICIPANT	\N	PRESENT	0
252110	240310	98023Q	PARTICIPANT	\N	PRESENT	0
252111	240310	14147R	PARTICIPANT	\N	PRESENT	0
252112	240310	04049K	PARTICIPANT	\N	PRESENT	0
252113	240310	04059M	PARTICIPANT	\N	PRESENT	0
252114	240310	14105F	PARTICIPANT	\N	PRESENT	0
252115	240310	11049P	PARTICIPANT	\N	PRESENT	0
252116	240310	08045X	PARTICIPANT	\N	PRESENT	0
252117	240310	92040Q	PARTICIPANT	\N	PRESENT	0
252118	240310	14133K	PARTICIPANT	\N	PRESENT	0
252119	240310	19573D	PARTICIPANT	\N	PRESENT	0
252120	240310	19649G	PARTICIPANT	\N	PRESENT	0
252121	240310	19447X	PARTICIPANT	\N	PRESENT	0
252122	240310	14038Y	PARTICIPANT	\N	PRESENT	0
252123	240310	96004D	PARTICIPANT	\N	PRESENT	0
252124	240310	08038Y	PARTICIPANT	\N	PRESENT	0
252125	240310	14229S	PARTICIPANT	\N	PRESENT	0
252126	240310	19723Y	PARTICIPANT	\N	PRESENT	0
252127	240310	19549D	PARTICIPANT	\N	PRESENT	0
252128	240310	14065Q	PARTICIPANT	\N	PRESENT	0
252129	240310	19507S	PARTICIPANT	\N	PRESENT	0
252130	240310	08043V	PARTICIPANT	\N	PRESENT	0
252131	240310	19467C	PARTICIPANT	\N	PRESENT	0
252104	240310	19667J	PARTICIPANT	\N	PRESENT	0
252105	240310	14257W	PARTICIPANT	\N	PRESENT	0
252132	240310	11045K	PARTICIPANT	\N	PRESENT	0
252133	240310	18083K	PARTICIPANT	\N	PRESENT	0
252134	240310	19415P	PARTICIPANT	\N	PRESENT	0
252135	240310	14281W	PARTICIPANT	\N	PRESENT	0
252136	240310	08035V	PARTICIPANT	\N	PRESENT	0
252137	240310	14033T	PARTICIPANT	\N	PRESENT	0
252138	240310	14135M	PARTICIPANT	\N	PRESENT	0
252139	240310	19531S	PARTICIPANT	\N	PRESENT	0
252140	240310	08019V	PARTICIPANT	\N	PRESENT	0
252141	240310	19683J	PARTICIPANT	\N	PRESENT	0
252142	240310	17779H	PARTICIPANT	\N	PRESENT	0
252143	240310	19399H	PARTICIPANT	\N	PRESENT	0
252144	240310	19647E	PARTICIPANT	\N	PRESENT	0
252145	240310	19693L	PARTICIPANT	\N	PRESENT	0
252146	240310	19729F	PARTICIPANT	\N	PRESENT	0
252147	240310	14265W	PARTICIPANT	\N	PRESENT	0
252148	240310	14213J	PARTICIPANT	\N	PRESENT	0
252149	240310	19727D	PARTICIPANT	\N	PRESENT	0
252150	240310	14109K	PARTICIPANT	\N	PRESENT	0
252151	240310	19707Y	PARTICIPANT	\N	PRESENT	0
252152	240310	19525U	PARTICIPANT	\N	PRESENT	0
252153	240310	19705W	PARTICIPANT	\N	PRESENT	0
252154	240310	11110B	PARTICIPANT	\N	PRESENT	0
252155	240310	08015R	PARTICIPANT	\N	PRESENT	0
252156	240310	14081Q	PARTICIPANT	\N	PRESENT	0
252157	240310	08062Y	PARTICIPANT	\N	PRESENT	0
252158	240310	14207L	PARTICIPANT	\N	PRESENT	0
252159	240310	14355X	PARTICIPANT	\N	PRESENT	0
252160	240310	08014Q	PARTICIPANT	\N	PRESENT	0
252162	240310	07029T	PARTICIPANT	\N	PRESENT	0
252163	240310	14001X	PARTICIPANT	\N	PRESENT	0
252164	240310	11109J	PARTICIPANT	\N	PRESENT	0
252166	240310	08018U	PARTICIPANT	\N	PRESENT	0
252167	240310	19689Q	PARTICIPANT	\N	PRESENT	0
252168	240310	19709B	PARTICIPANT	\N	PRESENT	0
252169	240310	19737F	PARTICIPANT	\N	PRESENT	0
252170	240310	04088S	PARTICIPANT	\N	PRESENT	0
252171	240310	19413M	PARTICIPANT	\N	PRESENT	0
252172	240310	19251M	PARTICIPANT	\N	PRESENT	0
252174	240310	19551W	PARTICIPANT	\N	PRESENT	0
252176	240310	14063N	PARTICIPANT	\N	PRESENT	0
252177	240310	04035D	PARTICIPANT	\N	PRESENT	0
252178	240310	19715Y	PARTICIPANT	\N	PRESENT	0
252179	240310	14097Y	PARTICIPANT	\N	PRESENT	0
252181	240310	04047H	PARTICIPANT	\N	PRESENT	0
252182	240310	98018T	PARTICIPANT	\N	PRESENT	0
252184	240310	04086Q	PARTICIPANT	\N	PRESENT	0
252186	240310	04038G	PARTICIPANT	\N	PRESENT	0
252187	240310	14357A	PARTICIPANT	\N	PRESENT	0
252190	240310	19593H	PARTICIPANT	\N	PRESENT	0
252191	240310	04033B	PARTICIPANT	\N	PRESENT	0
252192	240310	14030Q	PARTICIPANT	\N	PRESENT	0
252193	240310	14187A	PARTICIPANT	\N	PRESENT	0
252194	240310	01025N	PARTICIPANT	\N	PRESENT	0
252195	240310	05008E	PARTICIPANT	\N	PRESENT	0
252197	240310	11097X	PARTICIPANT	\N	PRESENT	0
252198	240310	19421M	PARTICIPANT	\N	PRESENT	0
252199	240310	08044W	PARTICIPANT	\N	PRESENT	0
252200	240310	19695N	PARTICIPANT	\N	PRESENT	0
252201	240310	14069U	PARTICIPANT	\N	PRESENT	0
252202	240310	11085T	PARTICIPANT	\N	PRESENT	0
252203	240310	14249W	PARTICIPANT	\N	PRESENT	0
252204	240310	19369B	PARTICIPANT	\N	PRESENT	0
252206	240310	14087W	PARTICIPANT	\N	PRESENT	0
252208	240310	14215L	PARTICIPANT	\N	PRESENT	0
252210	240310	14179A	PARTICIPANT	\N	PRESENT	0
252212	240310	14073Q	PARTICIPANT	\N	PRESENT	0
252214	240310	11053K	PARTICIPANT	\N	PRESENT	0
252215	240310	19619A	PARTICIPANT	\N	PRESENT	0
252216	240310	19713W	PARTICIPANT	\N	PRESENT	0
252218	240310	01024M	PARTICIPANT	\N	PRESENT	0
252219	240310	14267Y	PARTICIPANT	\N	PRESENT	0
252220	240310	14205J	PARTICIPANT	\N	PRESENT	0
252222	240310	19699S	PARTICIPANT	\N	PRESENT	0
252223	240310	10006L	PARTICIPANT	\N	PRESENT	0
252224	240310	19569H	PARTICIPANT	\N	PRESENT	0
252225	240310	08056B	PARTICIPANT	\N	PRESENT	0
252226	240310	07034Q	PARTICIPANT	\N	PRESENT	0
252227	240310	05012A	PARTICIPANT	\N	PRESENT	0
252228	240310	11026G	PARTICIPANT	\N	PRESENT	0
252229	240310	08034U	PARTICIPANT	\N	PRESENT	0
252230	240310	19441R	PARTICIPANT	\N	PRESENT	0
252231	240310	14219Q	PARTICIPANT	\N	PRESENT	0
252232	240310	19479G	PARTICIPANT	\N	PRESENT	0
252233	240310	07033P	PARTICIPANT	\N	PRESENT	0
252234	240310	17589D	PARTICIPANT	\N	PRESENT	0
252235	240310	19533U	PARTICIPANT	\N	PRESENT	0
252236	240310	04089T	PARTICIPANT	\N	PRESENT	0
252237	240310	19335Q	PARTICIPANT	\N	PRESENT	0
252239	240310	19521Q	PARTICIPANT	\N	PRESENT	0
252241	240310	07004J	PARTICIPANT	\N	PRESENT	0
252243	240310	14255U	PARTICIPANT	\N	PRESENT	0
252244	240310	04018C	PARTICIPANT	\N	PRESENT	0
252245	240310	19671E	PARTICIPANT	\N	PRESENT	0
252247	240310	19581D	PARTICIPANT	\N	PRESENT	0
252248	240310	19747H	PARTICIPANT	\N	PRESENT	0
252249	240310	19621T	PARTICIPANT	\N	PRESENT	0
252250	240310	19745F	PARTICIPANT	\N	PRESENT	0
252252	240310	19367Y	PARTICIPANT	\N	PRESENT	0
252254	240310	19741B	PARTICIPANT	\N	PRESENT	0
252255	240310	19643A	PARTICIPANT	\N	PRESENT	0
252256	240310	19383Y	PARTICIPANT	\N	PRESENT	0
252258	240310	97011G	PARTICIPANT	\N	PRESENT	0
252269	240310	11070L	PARTICIPANT	\N	PRESENT	0
252261	240310	14217N	PARTICIPANT	\N	PRESENT	0
252263	240310	14329V	PARTICIPANT	\N	PRESENT	0
252264	240310	14079W	PARTICIPANT	\N	PRESENT	0
252265	240310	19701S	PARTICIPANT	\N	PRESENT	0
252266	240310	11103C	PARTICIPANT	\N	PRESENT	0
252267	240310	19483C	PARTICIPANT	\N	PRESENT	0
252270	240310	19675J	PARTICIPANT	\N	PRESENT	0
252271	240310	19577H	PARTICIPANT	\N	PRESENT	0
252272	240310	19657G	PARTICIPANT	\N	PRESENT	0
252273	240310	98050T	PARTICIPANT	\N	PRESENT	0
252276	240310	19679N	PARTICIPANT	\N	PRESENT	0
252277	240310	14193X	PARTICIPANT	\N	PRESENT	0
252280	240310	98024R	PARTICIPANT	\N	PRESENT	0
252281	240310	19711U	PARTICIPANT	\N	PRESENT	0
252282	240310	19289C	PARTICIPANT	\N	PRESENT	0
252283	240310	95063L	PARTICIPANT	\N	PRESENT	0
252284	240310	89017R	PARTICIPANT	\N	PRESENT	0
252442	240310	11012A	PARTICIPANT	\N	PRESENT	0
252443	240310	19269X	PARTICIPANT	\N	PRESENT	0
252444	240310	14021P	PARTICIPANT	\N	PRESENT	0
252445	240310	12016W	PARTICIPANT	\N	PRESENT	0
252446	240310	14221J	PARTICIPANT	\N	PRESENT	0
252466	240310	14085U	PARTICIPANT	\N	PRESENT	0
252467	240310	88008L	PARTICIPANT	\N	PRESENT	0
252468	240310	14195A	PARTICIPANT	\N	PRESENT	0
260208	250090	19349W	PARTICIPANT	\N	PRESENT	0
260362	258937	14239U	PARTICIPANT	\N	PRESENT	0
260363	258937	19575F	PARTICIPANT	\N	PRESENT	0
260364	258937	11103C	PARTICIPANT	\N	PRESENT	0
260365	258937	08052W	PARTICIPANT	\N	PRESENT	0
260366	258937	14195A	PARTICIPANT	\N	PRESENT	0
260367	258937	11045K	PARTICIPANT	\N	PRESENT	0
260368	258937	14217N	PARTICIPANT	\N	PRESENT	0
260369	258937	14042U	PARTICIPANT	\N	PRESENT	0
260370	258937	14087W	PARTICIPANT	\N	PRESENT	0
260371	258937	19727D	PARTICIPANT	\N	PRESENT	0
260372	258937	19569H	PARTICIPANT	\N	PRESENT	0
260373	258937	14213J	PARTICIPANT	\N	PRESENT	0
260374	258937	19683J	PARTICIPANT	\N	PRESENT	0
260375	258937	19657G	PARTICIPANT	\N	PRESENT	0
260376	258937	14223L	PARTICIPANT	\N	PRESENT	0
260377	258937	19335Q	PARTICIPANT	\N	PRESENT	0
260378	258937	14119M	PARTICIPANT	\N	PRESENT	0
260379	258937	04092N	PRESIDENT	0	PRESENT	0
260380	258937	11067R	PARTICIPANT	\N	PRESENT	0
260381	258937	19723Y	PARTICIPANT	\N	PRESENT	0
260382	258937	17779H	PARTICIPANT	\N	EXCUSE	0
260383	258937	19679N	PARTICIPANT	\N	PRESENT	0
260384	258937	11097X	PARTICIPANT	\N	PRESENT	0
260385	258937	19715Y	PARTICIPANT	\N	EXCUSE	0
260386	258937	04045F	PARTICIPANT	\N	EXCUSE	0
260387	258952	19515S	PARTICIPANT	\N	EXCUSE	0
260388	258937	19367Y	PARTICIPANT	\N	PRESENT	0
260389	258952	11081P	PARTICIPANT	\N	EXCUSE	0
260390	258952	11101A	PARTICIPANT	\N	EXCUSE	0
260391	258952	04089T	PARTICIPANT	\N	EXCUSE	0
260392	258952	14207L	PARTICIPANT	\N	EXCUSE	0
260393	258937	08048B	PARTICIPANT	\N	EXCUSE	0
260394	258952	08021P	PARTICIPANT	\N	EXCUSE	0
260395	258937	14026U	PARTICIPANT	\N	PRESENT	0
260396	258952	01025N	PARTICIPANT	\N	EXCUSE	0
260397	258937	19527W	PARTICIPANT	\N	PRESENT	0
260398	258937	11063M	PARTICIPANT	\N	PRESENT	0
260399	258937	01034P	PARTICIPANT	\N	PRESENT	0
260400	258937	19703U	PARTICIPANT	\N	PRESENT	0
260401	258937	19675J	PARTICIPANT	\N	PRESENT	0
260402	258937	14227Q	PARTICIPANT	\N	PRESENT	0
260403	258937	19663E	PARTICIPANT	\N	EXCUSE	0
260404	258952	14239U	PARTICIPANT	\N	PRESENT	0
260405	258952	19575F	PARTICIPANT	\N	PRESENT	0
260406	258952	19367Y	PARTICIPANT	\N	PRESENT	0
260407	258952	11103C	PARTICIPANT	\N	PRESENT	0
260408	258952	14195A	PARTICIPANT	\N	PRESENT	0
260409	258952	08052W	PARTICIPANT	\N	PRESENT	0
260410	258952	14217N	PARTICIPANT	\N	PRESENT	0
260411	258952	14042U	PARTICIPANT	\N	PRESENT	0
260412	258952	14087W	PARTICIPANT	\N	PRESENT	0
260413	258952	19727D	PARTICIPANT	\N	PRESENT	0
260414	258952	14026U	PARTICIPANT	\N	PRESENT	0
260415	258952	19569H	PARTICIPANT	\N	PRESENT	0
260416	258952	14213J	PARTICIPANT	\N	PRESENT	0
260417	258952	19683J	PARTICIPANT	\N	PRESENT	0
260418	258952	19723Y	PARTICIPANT	\N	PRESENT	0
260419	258952	19657G	PARTICIPANT	\N	PRESENT	0
260420	258952	11067R	PARTICIPANT	\N	PRESENT	0
260421	258952	14223L	PARTICIPANT	\N	PRESENT	0
260422	258952	04092N	PARTICIPANT	\N	PRESENT	0
260423	258952	19335Q	PARTICIPANT	\N	PRESENT	0
260424	258952	14119M	PARTICIPANT	\N	PRESENT	0
260425	258952	19679N	PARTICIPANT	\N	PRESENT	0
260426	258952	11045K	PARTICIPANT	\N	PRESENT	0
260427	258952	11097X	PARTICIPANT	\N	PRESENT	0
260428	258952	19703U	PARTICIPANT	\N	PRESENT	0
260429	258952	19675J	PARTICIPANT	\N	PRESENT	0
260430	258952	14227Q	PARTICIPANT	\N	PRESENT	0
260431	258952	01034P	PARTICIPANT	\N	PRESENT	0
260432	258952	19527W	PARTICIPANT	\N	PRESENT	0
260433	258952	11063M	PARTICIPANT	\N	PRESENT	0
260451	258937	19631V	PARTICIPANT	\N	PRESENT	0
260452	258937	19707Y	PARTICIPANT	\N	PRESENT	0
260453	258937	14115H	PARTICIPANT	\N	PRESENT	0
260454	258937	19747H	PARTICIPANT	\N	PRESENT	0
260455	258937	08068F	PARTICIPANT	\N	PRESENT	0
260456	258937	08028W	PARTICIPANT	\N	PRESENT	0
260457	258937	19467C	PARTICIPANT	\N	PRESENT	0
260458	258937	11056N	PARTICIPANT	\N	PRESENT	0
260459	258937	14357A	PARTICIPANT	\N	PRESENT	0
260460	258937	19507S	PARTICIPANT	\N	PRESENT	0
260461	258937	14197C	PARTICIPANT	\N	PRESENT	0
260462	258937	14187A	PARTICIPANT	\N	PRESENT	0
260463	258937	19695N	PARTICIPANT	\N	PRESENT	0
260464	258937	19565D	PARTICIPANT	\N	PRESENT	0
260465	258937	14033T	PARTICIPANT	\N	PRESENT	0
260466	258937	19511N	PARTICIPANT	\N	PRESENT	0
260467	258937	11099A	PARTICIPANT	\N	PRESENT	0
260468	258937	04049K	PARTICIPANT	\N	PRESENT	0
260469	258937	08015R	PARTICIPANT	\N	PRESENT	0
260470	258937	14205J	PARTICIPANT	\N	PRESENT	0
260471	258937	19441R	PARTICIPANT	\N	PRESENT	0
260472	258937	08062Y	PARTICIPANT	\N	PRESENT	0
260473	258937	19563B	PARTICIPANT	\N	PRESENT	0
260474	258937	19369B	PARTICIPANT	\N	PRESENT	0
260475	258937	14257W	PARTICIPANT	\N	PRESENT	0
260476	258937	14265W	PARTICIPANT	\N	PRESENT	0
260477	258937	04088S	PARTICIPANT	\N	PRESENT	0
260478	258937	11090Q	PARTICIPANT	\N	PRESENT	0
260479	258937	04043D	PARTICIPANT	\N	PRESENT	0
260480	258937	14135M	PARTICIPANT	\N	PRESENT	0
260481	258937	19269X	PARTICIPANT	\N	PRESENT	0
260482	258937	19619A	PARTICIPANT	\N	PRESENT	0
260483	258937	19413M	PARTICIPANT	\N	PRESENT	0
260495	258972	99004R	PARTICIPANT	\N	EXCUSE	0
261237	255917	19711U	PARTICIPANT	\N	PRESENT	0
261238	255917	08062Y	PARTICIPANT	\N	PRESENT	0
261239	255917	11097X	PARTICIPANT	\N	PRESENT	0
261240	255917	19651A	PARTICIPANT	\N	EXCUSE	0
261243	254554	14221J	PARTICIPANT	\N	PRESENT	0
261248	261247	19515S	PARTICIPANT	\N	PRESENT	0
261249	261247	19383Y	PARTICIPANT	\N	PRESENT	0
261250	261247	14195A	PARTICIPANT	\N	PRESENT	0
261251	261247	19467C	PARTICIPANT	\N	PRESENT	0
261252	261247	14357A	PARTICIPANT	\N	PRESENT	0
261253	261247	14217N	PARTICIPANT	\N	PRESENT	0
261254	261247	01024M	PARTICIPANT	\N	PRESENT	0
261255	261247	19507S	PARTICIPANT	\N	PRESENT	0
261256	261247	19727D	PARTICIPANT	\N	PRESENT	0
261257	261247	14033T	PARTICIPANT	\N	PRESENT	0
261258	261247	19511N	PARTICIPANT	\N	PRESENT	0
261259	261247	19369B	PARTICIPANT	\N	PRESENT	0
261260	261247	14257W	PARTICIPANT	\N	PRESENT	0
261261	261247	04088S	PARTICIPANT	\N	PRESENT	0
261262	261247	19349W	PARTICIPANT	\N	PRESENT	0
261263	261247	08020N	PARTICIPANT	\N	PRESENT	0
261272	261271	19631V	PARTICIPANT	\N	PRESENT	0
261273	261271	14237S	PARTICIPANT	\N	PRESENT	0
261274	261271	19347U	PARTICIPANT	\N	PRESENT	0
261275	261271	14265W	PARTICIPANT	\N	PRESENT	0
261276	255917	19737F	PARTICIPANT	\N	PRESENT	0
261277	255917	19369B	PARTICIPANT	\N	PRESENT	0
261390	255917	11066Q	PARTICIPANT	\N	PRESENT	0
261391	255917	99004R	PRESIDENT	0	PRESENT	0
261501	255917	01028R	PARTICIPANT	\N	EXCUSE	0
261502	261484	04092N	PARTICIPANT	\N	PRESENT	0
261503	261484	19511N	PARTICIPANT	\N	PRESENT	0
261504	261484	19569H	PARTICIPANT	\N	PRESENT	0
261505	261484	14195A	PARTICIPANT	\N	PRESENT	0
261506	261484	19731Y	PARTICIPANT	\N	PRESENT	0
261507	261484	19289C	PARTICIPANT	\N	PRESENT	0
261508	261484	15447F	PARTICIPANT	\N	PRESENT	0
261509	261484	14265W	PARTICIPANT	\N	PRESENT	0
261510	261484	14041T	PARTICIPANT	\N	PRESENT	0
261511	261484	14073Q	PARTICIPANT	\N	PRESENT	0
261512	261484	19415P	PARTICIPANT	\N	PRESENT	0
261513	261484	04088S	PARTICIPANT	\N	PRESENT	0
261514	261484	19369B	PARTICIPANT	\N	PRESENT	0
261515	261484	19367Y	PARTICIPANT	\N	PRESENT	0
261516	261484	04045F	PARTICIPANT	\N	PRESENT	0
261517	261484	97011G	PARTICIPANT	\N	PRESENT	0
261518	261484	18083K	PARTICIPANT	\N	PRESENT	0
261519	261484	19693L	PARTICIPANT	\N	PRESENT	0
261520	261484	11063M	PARTICIPANT	\N	PRESENT	0
261521	261484	19565D	PARTICIPANT	\N	PRESENT	0
261522	261484	19581D	PARTICIPANT	\N	PRESENT	0
261523	261484	14211G	PARTICIPANT	\N	PRESENT	0
261524	261484	19689Q	PARTICIPANT	\N	PRESENT	0
261525	261484	14115H	PARTICIPANT	\N	PRESENT	0
261526	261484	19711U	PARTICIPANT	\N	PRESENT	0
260206	250090	14087W	PARTICIPANT	\N	PRESENT	0
260207	250090	14123H	PARTICIPANT	\N	PRESENT	0
261527	261484	11070L	PARTICIPANT	\N	PRESENT	0
261528	261484	19253P	PARTICIPANT	\N	PRESENT	0
261529	261484	14071N	PARTICIPANT	\N	PRESENT	0
261530	261484	14147R	PARTICIPANT	\N	PRESENT	0
244599	244598	07033P	PARTICIPANT	\N	PRESENT	0
247081	240963	18003S	PARTICIPANT	\N	EXCUSE	0
247084	240963	14299H	PARTICIPANT	\N	EXCUSE	0
247094	240963	19709B	PARTICIPANT	\N	PRESENT	0
247095	240963	01048V	PARTICIPANT	\N	PRESENT	0
247097	240963	19503N	PARTICIPANT	\N	PRESENT	0
247098	240963	04043D	PARTICIPANT	\N	PRESENT	0
247101	240963	19663E	PARTICIPANT	\N	EXCUSE	0
247135	247134	07029T	PARTICIPANT	\N	PRESENT	0
247141	247138	07029T	PARTICIPANT	\N	PRESENT	0
247144	247143	07029T	PARTICIPANT	\N	PRESENT	0
247150	247149	14133K	PARTICIPANT	\N	PRESENT	0
247151	247149	14097Y	PARTICIPANT	\N	PRESENT	0
247152	247149	98022P	PARTICIPANT	\N	PRESENT	0
247153	247149	11115U	PARTICIPANT	\N	PRESENT	0
247155	247154	14133K	PARTICIPANT	\N	PRESENT	0
247156	247154	14097Y	PARTICIPANT	\N	PRESENT	0
247157	247154	98022P	PARTICIPANT	\N	PRESENT	0
247220	247194	01028R	PARTICIPANT	\N	PRESENT	0
249706	247243	14261S	PARTICIPANT	\N	PRESENT	0
249707	247243	19717B	PARTICIPANT	\N	PRESENT	0
249708	247243	14038Y	PARTICIPANT	\N	PRESENT	0
249709	247243	14259Y	PARTICIPANT	\N	PRESENT	0
249710	247243	19659J	PARTICIPANT	\N	PRESENT	0
249711	247243	19715Y	PARTICIPANT	\N	PRESENT	0
249712	247243	14059S	PARTICIPANT	\N	PRESENT	0
249713	247243	08019V	PRESIDENT	0	PRESENT	0
249714	247243	11072N	PARTICIPANT	\N	PRESENT	0
249715	247243	12016W	PARTICIPANT	\N	EXCUSE	0
249716	247243	14331P	PARTICIPANT	\N	PRESENT	0
249717	247243	19703U	PARTICIPANT	\N	PRESENT	0
249833	232877	99004R	PRESIDENT	0	PRESENT	0
249834	232877	19651A	PARTICIPANT	\N	PRESENT	0
249857	232877	08062Y	PARTICIPANT	\N	PRESENT	0
249858	232877	11097X	PARTICIPANT	\N	PRESENT	0
249859	232877	11066Q	PARTICIPANT	\N	PRESENT	0
249898	232877	19515S	PARTICIPANT	\N	PRESENT	0
249943	232877	01028R	PARTICIPANT	\N	PRESENT	0
249967	232877	19711U	PARTICIPANT	\N	EXCUSE	0
250045	232877	19467C	PARTICIPANT	\N	PRESENT	0
252861	252860	08034U	PARTICIPANT	\N	PRESENT	0
252876	246403	19531S	PARTICIPANT	\N	PRESENT	0
252878	252877	19531S	PARTICIPANT	\N	PRESENT	0
252887	250562	14085U	PARTICIPANT	\N	PRESENT	0
252936	252935	14261S	PARTICIPANT	\N	PRESENT	0
252937	252935	19575F	PARTICIPANT	\N	PRESENT	0
252938	252935	14255U	PARTICIPANT	\N	PRESENT	0
252939	252935	14083S	PARTICIPANT	\N	PRESENT	0
252940	252935	14329V	PARTICIPANT	\N	PRESENT	0
252941	252935	14079W	PARTICIPANT	\N	PRESENT	0
252942	252935	14187A	PARTICIPANT	\N	PRESENT	0
252943	252935	19521Q	PARTICIPANT	\N	PRESENT	0
252944	252935	14121F	PARTICIPANT	\N	PRESENT	0
252945	252935	19671E	PARTICIPANT	\N	PRESENT	0
252946	252935	14265W	PARTICIPANT	\N	PRESENT	0
252947	252935	08015R	PARTICIPANT	\N	PRESENT	0
252948	252935	08047A	PARTICIPANT	\N	PRESENT	0
252949	252935	04088S	PARTICIPANT	\N	PRESENT	0
252950	252935	14051J	PARTICIPANT	\N	PRESENT	0
252951	252935	14157T	PARTICIPANT	\N	PRESENT	0
252952	252935	89017R	PARTICIPANT	\N	EXCUSE	0
252953	252935	14030Q	PARTICIPANT	\N	EXCUSE	0
252954	252935	14105F	PARTICIPANT	\N	EXCUSE	0
252955	252935	14053L	PARTICIPANT	\N	EXCUSE	0
252956	252935	19545Y	PARTICIPANT	\N	EXCUSE	0
252957	252935	11031D	PARTICIPANT	\N	EXCUSE	0
252958	252935	14041T	PARTICIPANT	\N	EXCUSE	0
252959	252935	14087W	PARTICIPANT	\N	EXCUSE	0
252960	252935	14026U	PARTICIPANT	\N	EXCUSE	0
252961	252935	14061L	PARTICIPANT	\N	EXCUSE	0
252962	252935	14253S	PARTICIPANT	\N	EXCUSE	0
252963	252935	04049K	PRESIDENT	0	PRESENT	0
252964	252935	14033T	PARTICIPANT	\N	PRESENT	0
252965	252935	19563B	PARTICIPANT	\N	PRESENT	0
252966	252935	14357A	PARTICIPANT	\N	PRESENT	0
252967	252935	14331P	PARTICIPANT	\N	PRESENT	0
252968	252935	10015M	PARTICIPANT	\N	PRESENT	0
252969	252935	19725B	PARTICIPANT	\N	PRESENT	0
252970	252935	14073Q	PARTICIPANT	\N	PRESENT	0
252971	252935	14065Q	PARTICIPANT	\N	PRESENT	0
252972	252935	14135M	PARTICIPANT	\N	PRESENT	0
252973	252935	14097Y	PARTICIPANT	\N	PRESENT	0
252974	252935	95037J	PARTICIPANT	\N	PRESENT	0
252975	252935	98035U	PARTICIPANT	\N	PRESENT	0
252976	252935	11083R	PARTICIPANT	\N	PRESENT	0
252977	252935	96004D	PARTICIPANT	\N	PRESENT	0
252978	252935	08044W	PARTICIPANT	\N	PRESENT	0
252980	252979	14261S	PARTICIPANT	\N	PRESENT	0
252981	252979	14030Q	PARTICIPANT	\N	EXCUSE	0
252982	252979	19575F	PARTICIPANT	\N	PRESENT	0
252983	252979	14255U	PARTICIPANT	\N	PRESENT	0
252984	252979	14083S	PARTICIPANT	\N	PRESENT	0
252985	252979	14329V	PARTICIPANT	\N	PRESENT	0
252986	252979	14079W	PARTICIPANT	\N	PRESENT	0
252987	252979	14187A	PARTICIPANT	\N	PRESENT	0
252988	252979	19521Q	PARTICIPANT	\N	PRESENT	0
252989	252979	14121F	PARTICIPANT	\N	PRESENT	0
252990	252979	04049K	PRESIDENT	0	PRESENT	0
252991	252979	08015R	PARTICIPANT	\N	PRESENT	0
252992	252979	19671E	PARTICIPANT	\N	PRESENT	0
252993	252979	14265W	PARTICIPANT	\N	PRESENT	0
252994	252979	08047A	PARTICIPANT	\N	PRESENT	0
252995	252979	04088S	PARTICIPANT	\N	PRESENT	0
252996	252979	14051J	PARTICIPANT	\N	PRESENT	0
252997	252979	14157T	PARTICIPANT	\N	PRESENT	0
252998	252979	89017R	PARTICIPANT	\N	EXCUSE	0
252999	252979	14105F	PARTICIPANT	\N	EXCUSE	0
253000	252979	14053L	PARTICIPANT	\N	EXCUSE	0
253001	252979	19545Y	PARTICIPANT	\N	EXCUSE	0
253002	252979	11031D	PARTICIPANT	\N	EXCUSE	0
253003	252979	14041T	PARTICIPANT	\N	EXCUSE	0
253004	252979	14087W	PARTICIPANT	\N	EXCUSE	0
253005	252979	14026U	PARTICIPANT	\N	EXCUSE	0
253006	252979	14061L	PARTICIPANT	\N	EXCUSE	0
253007	252979	14253S	PARTICIPANT	\N	EXCUSE	0
255000	252853	04071H	PARTICIPANT	\N	PRESENT	0
255005	251925	19443T	PARTICIPANT	\N	PRESENT	0
255006	251925	95030B	PARTICIPANT	\N	PRESENT	0
255007	251925	04034C	PARTICIPANT	\N	PRESENT	0
255008	251925	04040A	PARTICIPANT	\N	PRESENT	0
255009	251925	01058X	PARTICIPANT	\N	PRESENT	0
255010	251925	14079W	PARTICIPANT	\N	PRESENT	0
255011	251925	11027H	PARTICIPANT	\N	PRESENT	0
255012	251925	16685X	PARTICIPANT	\N	PRESENT	0
255013	251925	11054L	PARTICIPANT	\N	PRESENT	0
255014	251925	11066Q	PARTICIPANT	\N	PRESENT	0
255015	251925	08056B	PARTICIPANT	\N	PRESENT	0
255016	251925	95037J	PARTICIPANT	\N	PRESENT	0
255017	251925	11115U	PARTICIPANT	\N	PRESENT	0
255018	251925	14055N	PARTICIPANT	\N	PRESENT	0
255019	251925	19421M	PARTICIPANT	\N	PRESENT	0
255020	251925	19709B	PARTICIPANT	\N	PRESENT	0
255021	251925	08049C	PARTICIPANT	\N	PRESENT	0
255022	251925	08053X	PARTICIPANT	\N	PRESENT	0
255023	251925	97011G	PARTICIPANT	\N	PRESENT	0
255024	251925	08061X	PARTICIPANT	\N	PRESENT	0
255025	251925	08047A	PARTICIPANT	\N	PRESENT	0
255026	251925	98029W	PARTICIPANT	\N	PRESENT	0
255027	251925	14097Y	PARTICIPANT	\N	PRESENT	0
255028	251925	95067Q	PARTICIPANT	\N	PRESENT	0
255029	251925	01062T	PARTICIPANT	\N	PRESENT	0
255030	251925	14235Q	PARTICIPANT	\N	PRESENT	0
255031	251925	08058D	PARTICIPANT	\N	PRESENT	0
254943	253501	04088S	PARTICIPANT	\N	PRESENT	0
254944	253501	19507S	PARTICIPANT	\N	PRESENT	0
254945	253501	14207L	PARTICIPANT	\N	PRESENT	0
254946	253501	04043D	PARTICIPANT	\N	PRESENT	0
254947	253501	19619A	PARTICIPANT	\N	PRESENT	0
254948	253501	17589D	PARTICIPANT	\N	PRESENT	0
254949	253501	14257W	PARTICIPANT	\N	PRESENT	0
254950	253501	11056N	PARTICIPANT	\N	EXCUSE	0
254951	253501	04089T	PARTICIPANT	\N	EXCUSE	0
254952	253501	11101A	PARTICIPANT	\N	EXCUSE	0
254953	253501	11081P	PARTICIPANT	\N	EXCUSE	0
260757	260434	14239U	PARTICIPANT	\N	PRESENT	0
260758	260434	11074Q	PARTICIPANT	\N	PRESENT	0
260759	260434	08045X	PARTICIPANT	\N	PRESENT	0
260760	260434	11049P	PARTICIPANT	\N	PRESENT	0
260761	260434	08015R	PARTICIPANT	\N	PRESENT	0
260762	260434	07034Q	PARTICIPANT	\N	PRESENT	0
260763	260434	19745F	PARTICIPANT	\N	PRESENT	0
264202	264201	11053K	PARTICIPANT	\N	PRESENT	0
264203	264185	19647E	PARTICIPANT	\N	PRESENT	0
268260	267061	14237S	PARTICIPANT	\N	PRESENT	0
268261	267061	19659J	PARTICIPANT	\N	PRESENT	0
268262	267061	17583W	PARTICIPANT	\N	PRESENT	0
268263	267061	95062K	PARTICIPANT	\N	PRESENT	0
268264	267061	02002K	PARTICIPANT	\N	PRESENT	0
268265	267061	14157T	PARTICIPANT	\N	PRESENT	0
268266	267061	19701S	PARTICIPANT	\N	PRESENT	0
268267	267061	98023Q	PARTICIPANT	\N	PRESENT	0
268268	267061	19525U	PARTICIPANT	\N	PRESENT	0
268269	267061	19637C	PARTICIPANT	\N	PRESENT	0
268270	267022	14034U	PARTICIPANT	\N	PRESENT	0
268271	267022	14083S	PARTICIPANT	\N	PRESENT	0
268272	267022	08073C	PARTICIPANT	\N	EXCUSE	0
268273	267022	89017R	PARTICIPANT	\N	EXCUSE	0
268274	267061	18083K	PARTICIPANT	\N	PRESENT	0
268275	267061	19681G	PARTICIPANT	\N	PRESENT	0
268276	267061	14093U	PARTICIPANT	\N	PRESENT	0
268288	267662	19697Q	PARTICIPANT	\N	PRESENT	0
268289	267662	11067R	PARTICIPANT	\N	PRESENT	0
268290	267662	19569H	PARTICIPANT	\N	PRESENT	0
268291	267662	11097X	PARTICIPANT	\N	PRESENT	0
268292	267662	14223L	PARTICIPANT	\N	PRESENT	0
268293	267662	04045F	PARTICIPANT	\N	PRESENT	0
268294	267662	14026U	PARTICIPANT	\N	PRESENT	0
268295	267662	14227Q	PARTICIPANT	\N	PRESENT	0
268296	267662	17779H	PARTICIPANT	\N	PRESENT	0
268297	267662	11063M	PARTICIPANT	\N	PRESENT	0
268298	267662	19703U	PARTICIPANT	\N	PRESENT	0
268299	267662	11031D	PARTICIPANT	\N	PRESENT	0
268300	267662	14087W	PARTICIPANT	\N	PRESENT	0
268301	267662	14281W	PARTICIPANT	\N	PRESENT	0
268302	267662	19679N	PARTICIPANT	\N	PRESENT	0
268303	267662	14042U	PARTICIPANT	\N	PRESENT	0
268304	267662	19575F	PARTICIPANT	\N	PRESENT	0
268305	267662	14195A	PARTICIPANT	\N	PRESENT	0
268306	267662	19367Y	PARTICIPANT	\N	PRESENT	0
268307	267662	14217N	PARTICIPANT	\N	PRESENT	0
268308	267662	10006L	PARTICIPANT	\N	PRESENT	0
268309	267662	98024R	PARTICIPANT	\N	PRESENT	0
268310	267662	19521Q	PARTICIPANT	\N	PRESENT	0
268311	267662	19527W	PARTICIPANT	\N	PRESENT	0
268312	267662	04092N	PRESIDENT	0	PRESENT	0
268313	267662	11045K	PARTICIPANT	\N	PRESENT	0
268314	267662	08052W	PARTICIPANT	\N	PRESENT	0
268315	267662	19663E	PARTICIPANT	\N	PRESENT	0
268316	267662	19723Y	PARTICIPANT	\N	PRESENT	0
268317	267662	19727D	PARTICIPANT	\N	PRESENT	0
268318	267662	14119M	PARTICIPANT	\N	PRESENT	0
268319	267662	11103C	PARTICIPANT	\N	PRESENT	0
268320	267662	14071N	PARTICIPANT	\N	PRESENT	0
268321	267662	08048B	PARTICIPANT	\N	EXCUSE	0
268322	267662	19715Y	PARTICIPANT	\N	EXCUSE	0
268323	267023	14327T	PARTICIPANT	\N	PRESENT	0
268325	267023	19479G	PARTICIPANT	\N	PRESENT	0
268326	267023	11048N	PARTICIPANT	\N	PRESENT	0
268327	267023	01048V	PARTICIPANT	\N	PRESENT	0
268329	267023	01057W	PARTICIPANT	\N	PRESENT	0
268330	267023	11053K	PARTICIPANT	\N	PRESENT	0
268331	267023	19667J	PARTICIPANT	\N	PRESENT	0
268332	267023	08011M	PARTICIPANT	\N	PRESENT	0
268333	267023	11074Q	PRESIDENT	0	PRESENT	0
268334	267023	08014Q	PARTICIPANT	\N	PRESENT	0
268335	267023	14034U	PARTICIPANT	\N	PRESENT	0
268337	267023	11070L	PARTICIPANT	\N	PRESENT	0
268338	267023	14159V	PARTICIPANT	\N	PRESENT	0
268339	267023	07029T	PARTICIPANT	\N	PRESENT	0
268340	267023	14083S	PARTICIPANT	\N	PRESENT	0
268341	267023	11012A	PARTICIPANT	\N	PRESENT	0
268342	267023	14085U	PARTICIPANT	\N	PRESENT	0
268395	268393	04033B	PARTICIPANT	\N	PRESENT	0
268344	267023	14121F	PARTICIPANT	\N	PRESENT	0
268345	267023	14253S	PARTICIPANT	\N	PRESENT	0
268346	267023	04061F	PARTICIPANT	\N	PRESENT	0
268347	267023	89017R	PARTICIPANT	\N	EXCUSE	0
268350	267023	08073C	PARTICIPANT	\N	EXCUSE	0
268351	267404	04044E	PARTICIPANT	\N	PRESENT	0
268352	267404	19581D	PARTICIPANT	\N	PRESENT	0
268353	267404	19673G	PARTICIPANT	\N	PRESENT	0
268354	267404	01028R	PARTICIPANT	\N	PRESENT	0
268355	267404	05008E	PRESIDENT	0	PRESENT	0
268356	267404	19447X	PARTICIPANT	\N	PRESENT	0
268357	267404	19489J	PARTICIPANT	\N	PRESENT	0
268358	267404	14041T	PARTICIPANT	\N	PRESENT	0
268359	267404	14147R	PARTICIPANT	\N	PRESENT	0
268360	267404	14151M	PARTICIPANT	\N	PRESENT	0
268361	267404	14215L	PARTICIPANT	\N	PRESENT	0
268362	267404	08018U	PARTICIPANT	\N	PRESENT	0
268363	267404	14053L	PARTICIPANT	\N	PRESENT	0
268364	267404	19649G	PARTICIPANT	\N	PRESENT	0
268365	267404	10015M	PARTICIPANT	\N	PRESENT	0
268366	267404	11026G	PARTICIPANT	\N	PRESENT	0
268367	267404	07034Q	PARTICIPANT	\N	PRESENT	0
268368	267404	19253P	PARTICIPANT	\N	PRESENT	0
268369	267404	01024M	PARTICIPANT	\N	PRESENT	0
268370	267404	19719D	PARTICIPANT	\N	PRESENT	0
268371	267404	11033F	PARTICIPANT	\N	PRESENT	0
268372	267404	19725B	PARTICIPANT	\N	PRESENT	0
268373	267404	19629C	PARTICIPANT	\N	PRESENT	0
268374	267404	08044W	PARTICIPANT	\N	PRESENT	0
268375	267404	14021P	PARTICIPANT	\N	PRESENT	0
268376	267404	98035U	PARTICIPANT	\N	PRESENT	0
268377	267404	14065Q	PARTICIPANT	\N	PRESENT	0
268378	267404	08045X	PARTICIPANT	\N	PRESENT	0
268379	267404	01060R	PARTICIPANT	\N	PRESENT	0
268380	267404	14001X	PARTICIPANT	\N	PRESENT	0
268381	267404	04038G	PARTICIPANT	\N	PRESENT	0
268382	267404	19585H	PARTICIPANT	\N	PRESENT	0
268383	267404	14231L	PARTICIPANT	\N	PRESENT	0
268384	267404	14089Y	PARTICIPANT	\N	PRESENT	0
268385	267404	95063L	PARTICIPANT	\N	PRESENT	0
268386	267404	14069U	PARTICIPANT	\N	PRESENT	0
268387	267404	11049P	PARTICIPANT	\N	PRESENT	0
268388	267404	14259Y	PARTICIPANT	\N	PRESENT	0
268389	267404	11072N	PARTICIPANT	\N	PRESENT	0
268390	267404	19729F	PARTICIPANT	\N	EXCUSE	0
268391	267404	14111D	PARTICIPANT	\N	EXCUSE	0
268392	267404	04047H	PARTICIPANT	\N	EXCUSE	0
268394	268393	86034E	PARTICIPANT	\N	PRESENT	0
268396	268393	04042C	PARTICIPANT	\N	PRESENT	0
268397	268393	19671E	PARTICIPANT	\N	PRESENT	0
268398	268393	14041T	PARTICIPANT	\N	PRESENT	0
268399	268393	16685X	PARTICIPANT	\N	PRESENT	0
268400	268393	19447X	PARTICIPANT	\N	PRESENT	0
268401	268393	04040A	PARTICIPANT	\N	PRESENT	0
268402	268393	10006L	PARTICIPANT	\N	PRESENT	0
268403	268393	04044E	PARTICIPANT	\N	PRESENT	0
268404	267476	19515S	PARTICIPANT	\N	PRESENT	0
268405	267476	19565D	PARTICIPANT	\N	PRESENT	0
268406	267476	14357A	PARTICIPANT	\N	PRESENT	0
268407	267476	19441R	PARTICIPANT	\N	PRESENT	0
268408	267476	19413M	PARTICIPANT	\N	PRESENT	0
268409	267476	80013X	PARTICIPANT	\N	PRESENT	0
268410	267476	19631V	PARTICIPANT	\N	PRESENT	0
268411	267476	05012A	PARTICIPANT	\N	PRESENT	0
268412	267476	08068F	PARTICIPANT	\N	PRESENT	0
268413	267476	04049K	PARTICIPANT	\N	PRESENT	0
268414	267476	19705W	PARTICIPANT	\N	PRESENT	0
268415	267476	08015R	PARTICIPANT	\N	PRESENT	0
268416	267476	14197C	PARTICIPANT	\N	PRESENT	0
268417	267476	19369B	PARTICIPANT	\N	PRESENT	0
268418	267476	19511N	PARTICIPANT	\N	PRESENT	0
268419	267476	08028W	PARTICIPANT	\N	PRESENT	0
268420	267476	19563B	PARTICIPANT	\N	PRESENT	0
268421	267476	14265W	PARTICIPANT	\N	PRESENT	0
268422	267476	19591F	PARTICIPANT	\N	PRESENT	0
268423	267476	14135M	PARTICIPANT	\N	PRESENT	0
268424	267476	19467C	PARTICIPANT	\N	PRESENT	0
268425	267476	14187A	PARTICIPANT	\N	PRESENT	0
268426	267476	19695N	PARTICIPANT	\N	PRESENT	0
268427	267476	11090Q	PRESIDENT	0	PRESENT	0
268428	267476	14205J	PARTICIPANT	\N	PRESENT	0
268429	267476	11101A	PARTICIPANT	\N	PRESENT	0
268430	267476	19507S	PARTICIPANT	\N	PRESENT	0
268431	267476	14207L	PARTICIPANT	\N	PRESENT	0
268432	267476	19747H	PARTICIPANT	\N	PRESENT	0
268433	267476	04043D	PARTICIPANT	\N	PRESENT	0
268434	267476	19619A	PARTICIPANT	\N	PRESENT	0
242314	242313	19545Y	PARTICIPANT	\N	PRESENT	0
242315	242313	14085U	PARTICIPANT	\N	PRESENT	0
242316	242313	11070L	PARTICIPANT	\N	PRESENT	0
242318	242313	11074Q	PARTICIPANT	\N	PRESENT	0
242319	242313	14199E	PARTICIPANT	\N	PRESENT	0
242320	242313	01057W	PARTICIPANT	\N	PRESENT	0
242321	242313	11048N	PARTICIPANT	\N	PRESENT	0
242322	242313	08011M	PARTICIPANT	\N	PRESENT	0
242323	242313	14173T	PARTICIPANT	\N	PRESENT	0
242770	241235	11033F	PARTICIPANT	\N	EXCUSE	0
242811	241235	14331P	PARTICIPANT	\N	EXCUSE	0
242812	241235	08019V	PARTICIPANT	\N	EXCUSE	0
243396	240278	86034E	PARTICIPANT	\N	PRESENT	0
243397	240278	04092N	PARTICIPANT	\N	PRESENT	0
243398	240278	11074Q	PARTICIPANT	\N	PRESENT	0
243399	240278	14159V	PARTICIPANT	\N	PRESENT	0
243400	240278	08052W	PARTICIPANT	\N	PRESENT	0
243401	240278	11104D	PARTICIPANT	\N	PRESENT	0
243402	240278	14107H	PARTICIPANT	\N	PRESENT	0
243403	240278	19593H	PARTICIPANT	\N	PRESENT	0
243404	240278	04034C	PARTICIPANT	\N	PRESENT	0
243405	240278	17779H	PARTICIPANT	\N	PRESENT	0
243406	240278	14121F	PARTICIPANT	\N	PRESENT	0
243407	240278	11067R	PARTICIPANT	\N	PRESENT	0
243408	240278	19413M	PARTICIPANT	\N	PRESENT	0
243409	240278	14063N	PARTICIPANT	\N	PRESENT	0
243410	240278	19631V	PARTICIPANT	\N	PRESENT	0
243411	240278	08017T	PARTICIPANT	\N	PRESENT	0
243412	240278	19329S	PARTICIPANT	\N	PRESENT	0
243413	240278	14021P	PARTICIPANT	\N	PRESENT	0
243414	240278	14229S	PARTICIPANT	\N	PRESENT	0
243415	240278	01028R	PARTICIPANT	\N	PRESENT	0
243416	240278	04057K	PARTICIPANT	\N	PRESENT	0
243417	240278	14001X	PARTICIPANT	\N	PRESENT	0
243418	240278	19725B	PARTICIPANT	\N	PRESENT	0
243419	240278	14277B	PARTICIPANT	\N	PRESENT	0
243420	240278	19441R	PARTICIPANT	\N	PRESENT	0
243421	240278	19479G	PARTICIPANT	\N	PRESENT	0
243422	240278	19737F	PARTICIPANT	\N	PRESENT	0
243423	240278	08009T	PARTICIPANT	\N	PRESENT	0
243424	240278	19611R	PARTICIPANT	\N	PRESENT	0
243425	240278	19563B	PARTICIPANT	\N	PRESENT	0
243426	240278	11012A	PARTICIPANT	\N	PRESENT	0
243427	240278	14073Q	PARTICIPANT	\N	PRESENT	0
243428	240278	14083S	PARTICIPANT	\N	PRESENT	0
243429	240278	14255U	PARTICIPANT	\N	PRESENT	0
243430	240278	11070L	PARTICIPANT	\N	PRESENT	0
243431	240278	19421M	PARTICIPANT	\N	PRESENT	0
243432	240278	14215L	PARTICIPANT	\N	PRESENT	0
243433	240278	11097X	PARTICIPANT	\N	PRESENT	0
243434	240278	19369B	PARTICIPANT	\N	PRESENT	0
243435	240278	04018C	PARTICIPANT	\N	PRESENT	0
243436	240278	04045F	PARTICIPANT	\N	PRESENT	0
243437	240278	19629C	PARTICIPANT	\N	PRESENT	0
243438	240278	19387D	PARTICIPANT	\N	PRESENT	0
243439	240278	11083R	PARTICIPANT	\N	PRESENT	0
243440	240278	14081Q	PARTICIPANT	\N	PRESENT	0
243441	240278	19659J	PARTICIPANT	\N	PRESENT	0
243442	240278	08014Q	PARTICIPANT	\N	PRESENT	0
243443	240278	19591F	PARTICIPANT	\N	PRESENT	0
243444	240278	08038Y	PARTICIPANT	\N	PRESENT	0
243445	240278	11099A	PARTICIPANT	\N	PRESENT	0
243446	240278	19749K	PARTICIPANT	\N	PRESENT	0
243447	240278	19619A	PARTICIPANT	\N	PRESENT	0
243448	240278	04097T	PARTICIPANT	\N	PRESENT	0
243449	240278	95062K	PARTICIPANT	\N	PRESENT	0
243450	240278	19671E	PARTICIPANT	\N	PRESENT	0
243451	240278	19621T	PARTICIPANT	\N	PRESENT	0
243452	240278	19543W	PARTICIPANT	\N	PRESENT	0
243453	240278	08011M	PARTICIPANT	\N	PRESENT	0
243454	240278	19669L	PARTICIPANT	\N	PRESENT	0
243455	240278	19711U	PARTICIPANT	\N	PRESENT	0
243460	240278	01058X	PARTICIPANT	\N	PRESENT	0
243457	240278	08020N	PARTICIPANT	\N	PRESENT	0
243458	240278	19483C	PARTICIPANT	\N	PRESENT	0
243459	240278	19533U	PARTICIPANT	\N	PRESENT	0
243461	240278	14217N	PARTICIPANT	\N	PRESENT	0
243462	240278	97011G	PARTICIPANT	\N	PRESENT	0
243463	240278	19643A	PARTICIPANT	\N	PRESENT	0
243464	240278	05012A	PARTICIPANT	\N	PRESENT	0
243465	240278	19697Q	PARTICIPANT	\N	PRESENT	0
243466	240278	19515S	PARTICIPANT	\N	PRESENT	0
243467	240278	04086Q	PARTICIPANT	\N	PRESENT	0
243468	240278	19703U	PARTICIPANT	\N	PRESENT	0
243469	240278	07029T	PARTICIPANT	\N	PRESENT	0
243470	240278	98018T	PARTICIPANT	\N	PRESENT	0
243471	240278	14038Y	PARTICIPANT	\N	PRESENT	0
243472	240278	14249W	PARTICIPANT	\N	PRESENT	0
243473	240278	14135M	PARTICIPANT	\N	PRESENT	0
243474	240278	14033T	PARTICIPANT	\N	PRESENT	0
243475	240278	19663E	PARTICIPANT	\N	PRESENT	0
243476	240278	19741B	PARTICIPANT	\N	PRESENT	0
243477	240278	19447X	PARTICIPANT	\N	PRESENT	0
243478	240278	18083K	PARTICIPANT	\N	PRESENT	0
243479	240278	19667J	PARTICIPANT	\N	PRESENT	0
243480	240278	14031R	PARTICIPANT	\N	PRESENT	0
243481	240278	01057W	PARTICIPANT	\N	PRESENT	0
243482	240278	19573D	PARTICIPANT	\N	PRESENT	0
243483	240278	14251Q	PARTICIPANT	\N	PRESENT	0
243484	240278	14147R	PARTICIPANT	\N	PRESENT	0
243485	240278	14265W	PARTICIPANT	\N	PRESENT	0
243486	240278	19729F	PARTICIPANT	\N	PRESENT	0
243487	240278	14355X	PARTICIPANT	\N	PRESENT	0
243488	240278	11010L	PARTICIPANT	\N	PRESENT	0
243489	240278	19575F	PARTICIPANT	\N	PRESENT	0
243490	240278	10015M	PARTICIPANT	\N	PRESENT	0
243495	240278	14157T	PARTICIPANT	\N	PRESENT	0
243492	240278	04049K	PARTICIPANT	\N	PRESENT	0
243493	240278	01043Q	PARTICIPANT	\N	PRESENT	0
243494	240278	14109K	PARTICIPANT	\N	PRESENT	0
243496	240278	19695N	PARTICIPANT	\N	PRESENT	0
243497	240278	95015C	PARTICIPANT	\N	PRESENT	0
243498	240278	11053K	PARTICIPANT	\N	PRESENT	0
243499	240278	14123H	PARTICIPANT	\N	PRESENT	0
243500	240278	08034U	PARTICIPANT	\N	PRESENT	0
243501	240278	99004R	PARTICIPANT	\N	PRESENT	0
243502	240278	96004D	PARTICIPANT	\N	PRESENT	0
243503	240278	08018U	PARTICIPANT	\N	PRESENT	0
243504	240278	19525U	PARTICIPANT	\N	PRESENT	0
243505	240278	19399H	PARTICIPANT	\N	PRESENT	0
243506	240278	14034U	PARTICIPANT	\N	PRESENT	0
243507	240278	19683J	PARTICIPANT	\N	PRESENT	0
243508	240278	19647E	PARTICIPANT	\N	PRESENT	0
243509	240278	19521Q	PARTICIPANT	\N	PRESENT	0
243510	240278	08010L	PARTICIPANT	\N	PRESENT	0
243511	240278	11054L	PARTICIPANT	\N	PRESENT	0
243512	240278	89017R	PARTICIPANT	\N	PRESENT	0
243513	240278	04044E	PARTICIPANT	\N	PRESENT	0
243514	240278	14069U	PARTICIPANT	\N	PRESENT	0
243515	240278	11085T	PARTICIPANT	\N	PRESENT	0
243516	240278	14151M	PARTICIPANT	\N	PRESENT	0
243517	240278	04059M	PARTICIPANT	\N	PRESENT	0
243518	240278	14061L	PARTICIPANT	\N	PRESENT	0
243519	240278	19549D	PARTICIPANT	\N	PRESENT	0
243520	240278	98050T	PARTICIPANT	\N	PRESENT	0
243521	240278	14197C	PARTICIPANT	\N	PRESENT	0
243523	240278	07033P	PARTICIPANT	\N	PRESENT	0
243524	240278	19699S	PARTICIPANT	\N	PRESENT	0
243525	240278	19503N	PARTICIPANT	\N	PRESENT	0
243526	240278	04043D	PARTICIPANT	\N	PRESENT	0
243527	240278	19553Y	PARTICIPANT	\N	PRESENT	0
243528	240278	01048V	PARTICIPANT	\N	PRESENT	0
243529	240278	19651A	PARTICIPANT	\N	PRESENT	0
261531	261484	14030Q	PARTICIPANT	\N	PRESENT	0
261532	261484	14111D	PARTICIPANT	\N	PRESENT	0
261533	255917	08069G	PARTICIPANT	\N	EXCUSE	0
261534	261484	19329S	PARTICIPANT	\N	PRESENT	0
261535	261484	19681G	PARTICIPANT	\N	PRESENT	0
261536	261484	11031D	PARTICIPANT	\N	PRESENT	0
261537	261484	04061F	PARTICIPANT	\N	PRESENT	0
261538	261484	08056B	PARTICIPANT	\N	PRESENT	0
261539	261484	19629C	PARTICIPANT	\N	PRESENT	0
261540	261484	19747H	PARTICIPANT	\N	PRESENT	0
261541	261484	11097X	PARTICIPANT	\N	PRESENT	0
261542	261484	01025N	PARTICIPANT	\N	PRESENT	0
261543	261484	19679N	PARTICIPANT	\N	PRESENT	0
261544	261484	19387D	PARTICIPANT	\N	PRESENT	0
261545	261484	19593H	PARTICIPANT	\N	PRESENT	0
261546	261484	11048N	PARTICIPANT	\N	PRESENT	0
261550	261484	08019V	PARTICIPANT	\N	PRESENT	0
261548	261484	14213J	PARTICIPANT	\N	PRESENT	0
261549	261484	08015R	PARTICIPANT	\N	PRESENT	0
261551	261484	19399H	PARTICIPANT	\N	PRESENT	0
261552	261484	14327T	PARTICIPANT	\N	PRESENT	0
261553	261484	19727D	PARTICIPANT	\N	PRESENT	0
261554	261484	19553Y	PARTICIPANT	\N	PRESENT	0
261555	261484	14217N	PARTICIPANT	\N	PRESENT	0
261556	261484	19663E	PARTICIPANT	\N	PRESENT	0
261557	261484	11049P	PARTICIPANT	\N	PRESENT	0
261559	261484	19703U	PARTICIPANT	\N	PRESENT	0
261560	261484	14267Y	PARTICIPANT	\N	PRESENT	0
261561	261484	14038Y	PARTICIPANT	\N	PRESENT	0
261562	261484	17779H	PARTICIPANT	\N	PRESENT	0
261563	261484	19723Y	PARTICIPANT	\N	PRESENT	0
261564	261484	19479G	PARTICIPANT	\N	PRESENT	0
261565	261484	19749K	PARTICIPANT	\N	PRESENT	0
261566	261484	14219Q	PARTICIPANT	\N	PRESENT	0
261568	261484	14059S	PARTICIPANT	\N	PRESENT	0
261569	261484	11072N	PARTICIPANT	\N	PRESENT	0
261570	261484	19691J	PARTICIPANT	\N	PRESENT	0
261571	261484	11115U	PARTICIPANT	\N	PRESENT	0
261574	261484	14179A	PARTICIPANT	\N	PRESENT	0
261575	261484	14105F	PARTICIPANT	\N	PRESENT	0
261577	261484	19651A	PARTICIPANT	\N	PRESENT	0
261578	261484	19713W	PARTICIPANT	\N	PRESENT	0
261579	261484	14033T	PARTICIPANT	\N	PRESENT	0
261580	261484	11043H	PARTICIPANT	\N	PRESENT	0
261581	261484	19563B	PARTICIPANT	\N	PRESENT	0
261582	261484	19533U	PARTICIPANT	\N	PRESENT	0
261583	261484	19441R	PARTICIPANT	\N	PRESENT	0
261584	261484	19739H	PARTICIPANT	\N	PRESENT	0
261585	261484	17583W	PARTICIPANT	\N	PRESENT	0
261586	261484	11067R	PARTICIPANT	\N	PRESENT	0
261587	261484	01024M	PARTICIPANT	\N	PRESENT	0
261588	261484	19695N	PARTICIPANT	\N	PRESENT	0
261589	261484	19543W	PARTICIPANT	\N	PRESENT	0
261590	261484	14081Q	PARTICIPANT	\N	PRESENT	0
261591	261484	14173T	PARTICIPANT	\N	PRESENT	0
261592	261484	14031R	PARTICIPANT	\N	PRESENT	0
261593	261484	14259Y	PARTICIPANT	\N	PRESENT	0
261594	261484	14231L	PARTICIPANT	\N	PRESENT	0
261595	261484	04034C	PARTICIPANT	\N	PRESENT	0
261596	261484	14121F	PARTICIPANT	\N	PRESENT	0
261597	261484	19745F	PARTICIPANT	\N	PRESENT	0
261598	255917	19399H	PARTICIPANT	\N	PRESENT	0
261599	261484	14157T	PARTICIPANT	\N	PRESENT	0
261600	261484	19683J	PARTICIPANT	\N	PRESENT	0
261601	261484	95030B	PARTICIPANT	\N	PRESENT	0
261603	255917	19667J	PARTICIPANT	\N	EXCUSE	0
261604	255917	19647E	PARTICIPANT	\N	PRESENT	0
261605	261484	19741B	PARTICIPANT	\N	PRESENT	0
261606	261484	19521Q	PARTICIPANT	\N	PRESENT	0
261776	261485	98023Q	PARTICIPANT	\N	PRESENT	0
261608	261484	14034U	PARTICIPANT	\N	PRESENT	0
261609	255917	19467C	PARTICIPANT	\N	PRESENT	0
261610	255917	11056N	PARTICIPANT	\N	EXCUSE	0
261611	255917	14147R	PARTICIPANT	\N	PRESENT	0
261612	261484	80013X	PARTICIPANT	\N	PRESENT	0
261613	261484	14051J	PARTICIPANT	\N	PRESENT	0
261680	261485	11063M	PARTICIPANT	\N	PRESENT	0
261681	261485	11056N	PARTICIPANT	\N	PRESENT	0
261682	261485	19565D	PARTICIPANT	\N	PRESENT	0
261683	261485	17779H	PARTICIPANT	\N	PRESENT	0
261684	261485	14121F	PARTICIPANT	\N	PRESENT	0
261685	261485	14051J	PARTICIPANT	\N	PRESENT	0
261686	261485	80013X	PARTICIPANT	\N	PRESENT	0
261687	261485	19683J	PARTICIPANT	\N	PRESENT	0
261688	261485	14081Q	PARTICIPANT	\N	PRESENT	0
261689	261485	11072N	PARTICIPANT	\N	PRESENT	0
261690	261485	19329S	PARTICIPANT	\N	PRESENT	0
261691	261485	19289C	PARTICIPANT	\N	PRESENT	0
261692	261485	19387D	PARTICIPANT	\N	PRESENT	0
261693	261485	19563B	PARTICIPANT	\N	PRESENT	0
261694	261485	04057K	PARTICIPANT	\N	PRESENT	0
261695	261485	19553Y	PARTICIPANT	\N	PRESENT	0
261696	261485	19619A	PARTICIPANT	\N	PRESENT	0
261697	261485	08031R	PARTICIPANT	\N	PRESENT	0
261698	261485	19253P	PARTICIPANT	\N	PRESENT	0
261699	261485	19713W	PARTICIPANT	\N	PRESENT	0
261700	261485	19569H	PARTICIPANT	\N	PRESENT	0
261701	261485	14231L	PARTICIPANT	\N	PRESENT	0
261702	261485	14073Q	PARTICIPANT	\N	PRESENT	0
261703	261485	19521Q	PARTICIPANT	\N	PRESENT	0
261704	261485	08044W	PARTICIPANT	\N	PRESENT	0
261705	261485	01024M	PARTICIPANT	\N	PRESENT	0
261706	261485	19747H	PARTICIPANT	\N	PRESENT	0
261707	261485	19739H	PARTICIPANT	\N	PRESENT	0
261708	261485	04085P	PARTICIPANT	\N	PRESENT	0
261709	261485	19731Y	PARTICIPANT	\N	PRESENT	0
261710	261485	97011G	PARTICIPANT	\N	PRESENT	0
261711	261485	14147R	PARTICIPANT	\N	PRESENT	0
261712	261485	19711U	PARTICIPANT	\N	PRESENT	0
261713	261485	14115H	PARTICIPANT	\N	PRESENT	0
261714	261485	14041T	PARTICIPANT	\N	PRESENT	0
261715	261485	04088S	PARTICIPANT	\N	PRESENT	0
261716	261485	14033T	PARTICIPANT	\N	PRESENT	0
261718	261485	14157T	PARTICIPANT	\N	PRESENT	0
261719	261485	19703U	PARTICIPANT	\N	PRESENT	0
261721	261485	14038Y	PARTICIPANT	\N	PRESENT	0
261724	261485	17583W	PARTICIPANT	\N	PRESENT	0
261727	261485	14249W	PARTICIPANT	\N	PRESENT	0
261729	261485	14237S	PARTICIPANT	\N	PRESENT	0
261733	261485	95030B	PARTICIPANT	\N	PRESENT	0
261735	261485	17637T	PARTICIPANT	\N	PRESENT	0
261737	261485	11033F	PARTICIPANT	\N	PRESENT	0
261738	261485	19347U	PARTICIPANT	\N	PRESENT	0
261739	261485	19695N	PARTICIPANT	\N	PRESENT	0
261740	261485	14235Q	PARTICIPANT	\N	PRESENT	0
261741	261485	19593H	PARTICIPANT	\N	PRESENT	0
261742	261485	02002K	PARTICIPANT	\N	PRESENT	0
261743	255917	04038G	PARTICIPANT	\N	PRESENT	0
261744	261485	19745F	PARTICIPANT	\N	PRESENT	0
261745	255917	14107H	PARTICIPANT	\N	EXCUSE	0
261746	261485	19367Y	PARTICIPANT	\N	PRESENT	0
261747	261485	19679N	PARTICIPANT	\N	PRESENT	0
261748	261485	08039A	PARTICIPANT	\N	PRESENT	0
261749	261485	14105F	PARTICIPANT	\N	PRESENT	0
261750	255917	19713W	PARTICIPANT	\N	PRESENT	0
261752	261485	11067R	PARTICIPANT	\N	PRESENT	0
261753	261485	19503N	PARTICIPANT	\N	PRESENT	0
261754	261485	19413M	PARTICIPANT	\N	PRESENT	0
261755	261485	11103C	PARTICIPANT	\N	PRESENT	0
261756	261485	14207L	PARTICIPANT	\N	PRESENT	0
261678	261485	11070L	PARTICIPANT	\N	PRESENT	0
261679	261485	11031D	PARTICIPANT	\N	PRESENT	0
261757	261485	14197C	PARTICIPANT	\N	PRESENT	0
261758	261485	14151M	PARTICIPANT	\N	PRESENT	0
261759	261485	14053L	PARTICIPANT	\N	PRESENT	0
261760	261485	14217N	PARTICIPANT	\N	PRESENT	0
261761	261485	08020N	PARTICIPANT	\N	PRESENT	0
261762	261485	14071N	PARTICIPANT	\N	PRESENT	0
261764	261485	08055A	PARTICIPANT	\N	PRESENT	0
261765	261485	14109K	PARTICIPANT	\N	PRESENT	0
261766	261485	19479G	PARTICIPANT	\N	PRESENT	0
261767	261485	14265W	PARTICIPANT	\N	PRESENT	0
261768	261485	08019V	PARTICIPANT	\N	PRESENT	0
261769	261485	19525U	PARTICIPANT	\N	PRESENT	0
261770	261485	14211G	PARTICIPANT	\N	PRESENT	0
261771	261485	08052W	PARTICIPANT	\N	PRESENT	0
261772	261485	19715Y	PARTICIPANT	\N	PRESENT	0
261773	261485	95062K	PARTICIPANT	\N	PRESENT	0
261774	261485	11043H	PARTICIPANT	\N	PRESENT	0
261775	255917	08012N	PARTICIPANT	\N	EXCUSE	0
261777	261485	01058X	PARTICIPANT	\N	PRESENT	0
261778	261485	16685X	PARTICIPANT	\N	PRESENT	0
261779	261485	14267Y	PARTICIPANT	\N	PRESENT	0
261784	261485	14031R	PARTICIPANT	\N	PRESENT	0
261781	261485	04049K	PARTICIPANT	\N	PRESENT	0
261782	261485	08068F	PARTICIPANT	\N	PRESENT	0
261785	261485	14213J	PARTICIPANT	\N	PRESENT	0
261786	261783	14097Y	PARTICIPANT	\N	PRESENT	0
244292	244152	14069U	PARTICIPANT	\N	PRESENT	0
244293	244152	19693L	PARTICIPANT	\N	PRESENT	0
244294	232876	19421M	PARTICIPANT	\N	EXCUSE	0
244295	232876	19467C	PARTICIPANT	\N	PRESENT	0
244296	232876	08062Y	PARTICIPANT	\N	EXCUSE	0
244297	232876	11097X	PARTICIPANT	\N	PRESENT	0
244298	232876	19479G	PARTICIPANT	\N	PRESENT	0
244299	232876	19515S	PARTICIPANT	\N	PRESENT	0
244300	232876	19551W	PARTICIPANT	\N	PRESENT	0
244301	232876	19369B	PARTICIPANT	\N	EXCUSE	0
244302	232876	11066Q	PARTICIPANT	\N	PRESENT	0
244303	232876	01028R	PARTICIPANT	\N	EXCUSE	0
244304	232876	14147R	PARTICIPANT	\N	PRESENT	0
244305	232876	08045X	PARTICIPANT	\N	PRESENT	0
244346	232876	17637T	PARTICIPANT	\N	EXCUSE	0
244347	232876	99004R	PRESIDENT	0	PRESENT	0
246057	246055	11074Q	PRESIDENT	0	PRESENT	0
246058	246055	14237S	PARTICIPANT	\N	PRESENT	0
246059	246055	19531S	PARTICIPANT	\N	PRESENT	0
246060	246055	88008L	PARTICIPANT	\N	PRESENT	0
246061	246055	14085U	PARTICIPANT	\N	PRESENT	0
246062	246055	14327T	PARTICIPANT	\N	PRESENT	0
246063	246055	11083R	PARTICIPANT	\N	PRESENT	0
246064	246055	14097Y	PARTICIPANT	\N	PRESENT	0
246065	246055	01057W	PARTICIPANT	\N	PRESENT	0
246066	246055	04057K	PARTICIPANT	\N	PRESENT	0
246067	246055	14225N	PARTICIPANT	\N	PRESENT	0
246068	246055	14331P	PARTICIPANT	\N	PRESENT	0
246069	246055	04097T	PARTICIPANT	\N	PRESENT	0
255032	251925	14028W	PARTICIPANT	\N	PRESENT	0
255033	251925	19251M	PARTICIPANT	\N	PRESENT	0
255034	251925	19721W	PARTICIPANT	\N	PRESENT	0
255035	251925	14105F	PARTICIPANT	\N	PRESENT	0
255036	251925	98018T	PRESIDENT	0	PRESENT	0
255037	251925	98022P	PARTICIPANT	\N	PRESENT	0
255038	251925	11064N	PARTICIPANT	\N	PRESENT	0
255039	251925	19583F	PARTICIPANT	\N	PRESENT	0
255040	251925	14211G	PARTICIPANT	\N	PRESENT	0
255041	251925	14255U	PARTICIPANT	\N	PRESENT	0
255042	251925	14267Y	PARTICIPANT	\N	EXCUSE	0
255043	251925	98050T	PARTICIPANT	\N	EXCUSE	0
255044	251925	04042C	PARTICIPANT	\N	EXCUSE	0
255045	251799	11065P	PARTICIPANT	\N	PRESENT	0
255046	251861	11067R	PARTICIPANT	\N	PRESENT	0
255047	251861	19663E	PARTICIPANT	\N	EXCUSE	0
255219	254997	08035V	PARTICIPANT	\N	PRESENT	0
255220	254997	19735D	PARTICIPANT	\N	PRESENT	0
255221	254997	19749K	PARTICIPANT	\N	PRESENT	0
255222	254997	08039A	PARTICIPANT	\N	EXCUSE	0
255563	255562	14063N	PARTICIPANT	\N	PRESENT	0
255564	255562	05012A	PARTICIPANT	\N	PRESENT	0
255565	255562	19735D	PARTICIPANT	\N	PRESENT	0
255566	255562	08068F	PARTICIPANT	\N	PRESENT	0
255567	255562	19575F	PARTICIPANT	\N	PRESENT	0
255568	255562	14329V	PARTICIPANT	\N	PRESENT	0
255569	255562	14087W	PARTICIPANT	\N	PRESENT	0
255570	255562	11099A	PARTICIPANT	\N	PRESENT	0
255571	255562	14051J	PARTICIPANT	\N	PRESENT	0
255805	253030	19663E	PARTICIPANT	\N	PRESENT	0
255807	253030	19723Y	PARTICIPANT	\N	PRESENT	0
255863	255862	14331P	PARTICIPANT	\N	PRESENT	0
255868	255867	04061F	PARTICIPANT	\N	PRESENT	0
255869	255867	14001X	PARTICIPANT	\N	PRESENT	0
255986	255985	89017R	PARTICIPANT	\N	PRESENT	0
255988	255987	89017R	PARTICIPANT	\N	PRESENT	0
255997	255996	08047A	PARTICIPANT	\N	PRESENT	0
256079	240324	11066Q	PARTICIPANT	\N	PRESENT	0
256080	240324	19619A	PARTICIPANT	\N	PRESENT	0
256081	240324	14071N	PARTICIPANT	\N	PRESENT	0
256082	240324	14053L	PARTICIPANT	\N	PRESENT	0
256083	256031	98035U	PARTICIPANT	\N	PRESENT	0
256084	256031	14111D	PARTICIPANT	\N	PRESENT	0
256085	256031	07034Q	PARTICIPANT	\N	PRESENT	0
256086	256031	11026G	PARTICIPANT	\N	PRESENT	0
256087	256031	08045X	PARTICIPANT	\N	PRESENT	0
256088	256031	19543W	PARTICIPANT	\N	PRESENT	0
256089	256031	19585H	PARTICIPANT	\N	PRESENT	0
256090	256031	11033F	PARTICIPANT	\N	PRESENT	0
256091	256031	01028R	PARTICIPANT	\N	PRESENT	0
256092	256031	19447X	PARTICIPANT	\N	PRESENT	0
256093	256031	05008E	PRESIDENT	0	PRESENT	0
256094	256031	14231L	PARTICIPANT	\N	PRESENT	0
256095	256031	19629C	PARTICIPANT	\N	PRESENT	0
256096	256031	08044W	PARTICIPANT	\N	PRESENT	0
256097	256031	14041T	PARTICIPANT	\N	PRESENT	0
256098	256031	14179A	PARTICIPANT	\N	PRESENT	0
256099	256031	19483C	PARTICIPANT	\N	PRESENT	0
256100	256031	19729F	PARTICIPANT	\N	EXCUSE	0
256101	256031	14065Q	PARTICIPANT	\N	EXCUSE	0
256102	256031	08018U	PARTICIPANT	\N	EXCUSE	0
256103	240324	11043H	PARTICIPANT	\N	PRESENT	0
256104	240324	14237S	PARTICIPANT	\N	PRESENT	0
256105	240324	11045K	PARTICIPANT	\N	PRESENT	0
256106	240324	08028W	PARTICIPANT	\N	PRESENT	0
256107	240324	19301E	PARTICIPANT	\N	PRESENT	0
256108	240324	19383Y	PARTICIPANT	\N	PRESENT	0
256109	240324	08060W	PARTICIPANT	\N	PRESENT	0
256110	240324	19333N	PARTICIPANT	\N	PRESENT	0
256111	240324	96004D	PARTICIPANT	\N	PRESENT	0
256112	240324	18083K	PARTICIPANT	\N	PRESENT	0
256113	240324	14221J	PARTICIPANT	\N	PRESENT	0
256114	240324	11040E	PARTICIPANT	\N	PRESENT	0
256115	240324	14231L	PARTICIPANT	\N	PRESENT	0
256116	240324	19719D	PARTICIPANT	\N	PRESENT	0
256117	240324	14179A	PARTICIPANT	\N	PRESENT	0
256118	240324	04043D	PARTICIPANT	\N	PRESENT	0
256119	240324	19565D	PARTICIPANT	\N	PRESENT	0
256122	240324	14107H	PARTICIPANT	\N	PRESENT	0
256123	240324	19611R	PARTICIPANT	\N	PRESENT	0
256124	240324	14073Q	PARTICIPANT	\N	PRESENT	0
256125	240324	19659J	PARTICIPANT	\N	PRESENT	0
256077	240324	04044E	PARTICIPANT	\N	PRESENT	0
256078	240324	19681G	PARTICIPANT	\N	PRESENT	0
256126	240324	19507S	PARTICIPANT	\N	PRESENT	0
256127	240324	19511N	PARTICIPANT	\N	PRESENT	0
256128	240324	19443T	PARTICIPANT	\N	PRESENT	0
256129	240324	14105F	PARTICIPANT	\N	PRESENT	0
256132	240324	07033P	PARTICIPANT	\N	PRESENT	0
256135	240324	14028W	PARTICIPANT	\N	PRESENT	0
256142	240324	14223L	PARTICIPANT	\N	PRESENT	0
256146	240324	07029T	PARTICIPANT	\N	PRESENT	0
256149	240324	11026G	PARTICIPANT	\N	PRESENT	0
256151	253027	14221J	PARTICIPANT	\N	PRESENT	0
256152	253027	19593H	PARTICIPANT	\N	PRESENT	0
256153	240324	19583F	PARTICIPANT	\N	PRESENT	0
256155	253028	14221J	PARTICIPANT	\N	PRESENT	0
256156	253028	19593H	PARTICIPANT	\N	PRESENT	0
256158	253029	14221J	PARTICIPANT	\N	PRESENT	0
256159	240324	14253S	PARTICIPANT	\N	PRESENT	0
256160	240324	14042U	PARTICIPANT	\N	PRESENT	0
256161	240324	14039A	PARTICIPANT	\N	PRESENT	0
256162	240324	19573D	PARTICIPANT	\N	PRESENT	0
256172	256121	19525U	PARTICIPANT	\N	PRESENT	0
256173	256121	14219Q	PARTICIPANT	\N	PRESENT	0
256174	256121	88008L	PARTICIPANT	\N	PRESENT	0
256170	256121	86034E	PARTICIPANT	\N	PRESENT	0
256171	256121	80027E	PARTICIPANT	\N	PRESENT	0
256175	256121	19719D	PARTICIPANT	\N	PRESENT	0
256176	256121	19583F	PARTICIPANT	\N	PRESENT	0
256177	256121	19651A	PARTICIPANT	\N	PRESENT	0
256178	256121	11066Q	PARTICIPANT	\N	PRESENT	0
256179	256121	19253P	PARTICIPANT	\N	PRESENT	0
256180	256121	14227Q	PARTICIPANT	\N	PRESENT	0
256181	256121	14111D	PARTICIPANT	\N	PRESENT	0
256182	256121	14103D	PARTICIPANT	\N	PRESENT	0
256183	256121	14081Q	PARTICIPANT	\N	PRESENT	0
256184	256121	19387D	PARTICIPANT	\N	PRESENT	0
256185	256121	04085P	PARTICIPANT	\N	PRESENT	0
256186	256121	07004J	PARTICIPANT	\N	PRESENT	0
256187	256121	19629C	PARTICIPANT	\N	PRESENT	0
256188	256121	11041F	PARTICIPANT	\N	PRESENT	0
256189	256121	98022P	PARTICIPANT	\N	PRESENT	0
256190	256121	19553Y	PARTICIPANT	\N	PRESENT	0
256191	256121	19737F	PARTICIPANT	\N	PRESENT	0
256192	256121	19711U	PARTICIPANT	\N	PRESENT	0
256193	256121	14041T	PARTICIPANT	\N	PRESENT	0
256194	256121	15447F	PARTICIPANT	\N	PRESENT	0
256195	256121	14105F	PARTICIPANT	\N	PRESENT	0
256196	256121	19503N	PARTICIPANT	\N	PRESENT	0
256197	256121	19515S	PARTICIPANT	\N	PRESENT	0
256198	256121	07034Q	PARTICIPANT	\N	PRESENT	0
256199	256121	19745F	PARTICIPANT	\N	PRESENT	0
256200	256121	99004R	PARTICIPANT	\N	PRESENT	0
260166	260165	04047H	PARTICIPANT	\N	PRESENT	0
260167	260165	08012N	PARTICIPANT	\N	PRESENT	0
260168	260165	04043D	PARTICIPANT	\N	PRESENT	0
260169	260165	11026G	PARTICIPANT	\N	PRESENT	0
268435	267476	14257W	PARTICIPANT	\N	PRESENT	0
268436	267476	04089T	PARTICIPANT	\N	EXCUSE	0
268437	267476	14033T	PARTICIPANT	\N	EXCUSE	0
268438	267476	08021P	PARTICIPANT	\N	EXCUSE	0
268439	267476	11081P	PARTICIPANT	\N	EXCUSE	0
268445	268101	04070G	PRESIDENT	0	PRESENT	0
268446	268101	19699S	PARTICIPANT	\N	PRESENT	0
268447	268101	14229S	PARTICIPANT	\N	PRESENT	0
268448	268101	14241N	PARTICIPANT	\N	PRESENT	0
268449	268101	19573D	PARTICIPANT	\N	PRESENT	0
268450	268101	14107H	PARTICIPANT	\N	PRESENT	0
268451	268101	08017T	PARTICIPANT	\N	PRESENT	0
268452	268101	92040Q	PARTICIPANT	\N	PRESENT	0
268453	268101	07033P	PARTICIPANT	\N	PRESENT	0
268454	268101	08012N	PARTICIPANT	\N	PRESENT	0
268455	268101	14249W	PARTICIPANT	\N	PRESENT	0
268456	268101	08039A	PARTICIPANT	\N	PRESENT	0
268457	268101	08031R	PARTICIPANT	\N	PRESENT	0
268458	268101	19593H	PARTICIPANT	\N	PRESENT	0
268459	268101	19643A	PARTICIPANT	\N	PRESENT	0
268460	268101	14059S	PARTICIPANT	\N	PRESENT	0
268461	268101	14073Q	PARTICIPANT	\N	PRESENT	0
268462	268101	08043V	PARTICIPANT	\N	PRESENT	0
268463	268101	19693L	PARTICIPANT	\N	PRESENT	0
268464	268101	19399H	PARTICIPANT	\N	PRESENT	0
268465	268101	14030Q	PARTICIPANT	\N	PRESENT	0
268466	268101	19731Y	PARTICIPANT	\N	PRESENT	0
268467	268101	08020N	PARTICIPANT	\N	PRESENT	0
268468	268101	14251Q	PARTICIPANT	\N	PRESENT	0
268469	268101	19735D	PARTICIPANT	\N	PRESENT	0
268470	268101	14109K	PARTICIPANT	\N	PRESENT	0
268471	268101	14123H	PARTICIPANT	\N	PRESENT	0
268472	268101	11104D	PARTICIPANT	\N	PRESENT	0
268473	268101	11043H	PARTICIPANT	\N	PRESENT	0
268474	268101	19749K	PARTICIPANT	\N	PRESENT	0
268475	268101	04018C	PARTICIPANT	\N	PRESENT	0
268476	268101	14061L	PARTICIPANT	\N	EXCUSE	0
268477	268101	04057K	PARTICIPANT	\N	EXCUSE	0
268478	268101	95015C	PARTICIPANT	\N	EXCUSE	0
268479	268101	14039A	PARTICIPANT	\N	EXCUSE	0
268480	268101	19611R	PARTICIPANT	\N	EXCUSE	0
268481	267664	08024S	PARTICIPANT	\N	EXCUSE	0
268482	267664	19599P	PARTICIPANT	\N	EXCUSE	0
268483	268101	87003B	PARTICIPANT	\N	EXCUSE	0
268500	267315	97011G	PARTICIPANT	\N	EXCUSE	0
268501	267315	14028W	PARTICIPANT	\N	EXCUSE	0
268505	268504	08055A	PARTICIPANT	\N	PRESENT	0
268506	268504	04047H	PARTICIPANT	\N	PRESENT	0
268507	268504	14085U	PARTICIPANT	\N	PRESENT	0
268508	268504	11080N	PARTICIPANT	\N	PRESENT	0
268509	268504	11083R	PARTICIPANT	\N	EXCUSE	0
268510	268504	01057W	PARTICIPANT	\N	PRESENT	0
268511	268504	19611R	PARTICIPANT	\N	EXCUSE	0
268512	268504	08049C	PARTICIPANT	\N	PRESENT	0
268513	268504	14157T	PARTICIPANT	\N	PRESENT	0
268515	266032	11048N	PARTICIPANT	\N	PRESENT	0
268516	266032	19647E	PARTICIPANT	\N	PRESENT	0
268517	266032	19479G	PARTICIPANT	\N	PRESENT	0
268518	266032	19651A	PARTICIPANT	\N	PRESENT	0
268519	266032	08069G	PARTICIPANT	\N	PRESENT	0
268520	266032	01057W	PARTICIPANT	\N	PRESENT	0
268521	266032	12016W	PARTICIPANT	\N	PRESENT	0
268522	266032	11053K	PARTICIPANT	\N	PRESENT	0
268523	266032	11074Q	PRESIDENT	0	PRESENT	0
268524	266032	08011M	PARTICIPANT	\N	PRESENT	0
268525	266032	19671E	PARTICIPANT	\N	PRESENT	0
268526	266032	07029T	PARTICIPANT	\N	PRESENT	0
268527	266032	14085U	PARTICIPANT	\N	PRESENT	0
268528	266032	19349W	PARTICIPANT	\N	PRESENT	0
268529	266032	19741B	PARTICIPANT	\N	PRESENT	0
268530	266032	14121F	PARTICIPANT	\N	PRESENT	0
268531	266032	14327T	PARTICIPANT	\N	PRESENT	0
268532	266032	14083S	PARTICIPANT	\N	PRESENT	0
268533	266032	04071H	PARTICIPANT	\N	PRESENT	0
268534	266032	08034U	PARTICIPANT	\N	PRESENT	0
268535	266032	19687N	PARTICIPANT	\N	PRESENT	0
268536	266032	19689Q	PARTICIPANT	\N	PRESENT	0
268537	266032	08010L	PARTICIPANT	\N	PRESENT	0
268538	266032	99004R	PARTICIPANT	\N	PRESENT	0
268539	266032	19667J	PARTICIPANT	\N	PRESENT	0
268540	266032	08014Q	PARTICIPANT	\N	PRESENT	0
268541	266032	14225N	PARTICIPANT	\N	PRESENT	0
268542	266032	11070L	PARTICIPANT	\N	PRESENT	0
268543	266032	08073C	PARTICIPANT	\N	EXCUSE	0
268544	266032	89017R	PARTICIPANT	\N	EXCUSE	0
268546	268545	11053K	PARTICIPANT	\N	PRESENT	0
268547	268545	14159V	PARTICIPANT	\N	PRESENT	0
268548	268545	05012A	PARTICIPANT	\N	PRESENT	0
268550	268549	14239U	PARTICIPANT	0	PRESENT	0
268551	268549	19549D	PARTICIPANT	\N	PRESENT	0
268552	268549	19367Y	PARTICIPANT	\N	PRESENT	0
268553	268549	14195A	PARTICIPANT	\N	PRESENT	0
268554	268549	19295A	PARTICIPANT	\N	EXCUSE	0
268555	268549	19253P	PARTICIPANT	\N	PRESENT	0
268556	268549	14217N	PARTICIPANT	\N	PRESENT	0
268557	268549	14215L	PARTICIPANT	\N	PRESENT	0
268558	268549	19577H	PARTICIPANT	\N	PRESENT	0
268559	268549	08045X	PARTICIPANT	\N	PRESENT	0
268560	268549	14087W	PARTICIPANT	\N	PRESENT	0
268561	268549	19697Q	PARTICIPANT	\N	PRESENT	0
268562	268549	14031R	PARTICIPANT	\N	PRESENT	0
268563	268549	11067R	PARTICIPANT	\N	PRESENT	0
268564	268549	14223L	PARTICIPANT	\N	PRESENT	0
268565	268549	04044E	PRESIDENT	0	PRESENT	0
268566	266032	14199E	PARTICIPANT	\N	PRESENT	0
268567	267357	08056B	PARTICIPANT	\N	PRESENT	0
268568	267357	19421M	PARTICIPANT	\N	PRESENT	0
268569	267357	10015M	PARTICIPANT	\N	PRESENT	0
268570	267357	19575F	PARTICIPANT	\N	PRESENT	0
268571	267357	19673G	PARTICIPANT	\N	PRESENT	0
268572	267357	98029W	PRESIDENT	0	PRESENT	0
268573	267357	02002K	PARTICIPANT	\N	PRESENT	0
268574	267357	19611R	PARTICIPANT	\N	EXCUSE	0
268575	267359	08056B	PARTICIPANT	\N	PRESENT	0
268576	267359	19421M	PARTICIPANT	\N	PRESENT	0
268577	267359	10015M	PARTICIPANT	\N	PRESENT	0
268578	267359	19575F	PARTICIPANT	\N	PRESENT	0
268579	267359	19673G	PARTICIPANT	\N	PRESENT	0
268580	267359	98029W	PRESIDENT	0	PRESENT	0
268581	267359	02002K	PARTICIPANT	\N	PRESENT	0
268582	267359	19611R	PARTICIPANT	\N	EXCUSE	0
268597	267103	08068F	PARTICIPANT	\N	PRESENT	0
268598	267103	14073Q	PARTICIPANT	\N	PRESENT	0
268599	267103	19695N	PARTICIPANT	\N	PRESENT	0
268600	267103	19631V	PARTICIPANT	\N	PRESENT	0
268601	267103	14061L	PARTICIPANT	\N	EXCUSE	0
268602	267103	14193X	PARTICIPANT	\N	EXCUSE	0
268603	267103	14028W	PARTICIPANT	\N	EXCUSE	0
268604	267103	14065Q	PARTICIPANT	\N	PRESENT	0
268605	267103	11090Q	PARTICIPANT	\N	PRESENT	0
268606	267103	14257W	PARTICIPANT	\N	PRESENT	0
268607	267103	08015R	PARTICIPANT	\N	PRESENT	0
268617	263174	04059M	PARTICIPANT	\N	PRESENT	0
268618	263174	14191V	PARTICIPANT	\N	PRESENT	0
268619	263174	11040E	PARTICIPANT	\N	PRESENT	0
268620	263174	19593H	PARTICIPANT	\N	PRESENT	0
268621	263174	01024M	PARTICIPANT	\N	PRESENT	0
268622	263174	19673G	PARTICIPANT	\N	PRESENT	0
268623	263174	19447X	PARTICIPANT	\N	PRESENT	0
268624	263174	11072N	PARTICIPANT	\N	PRESENT	0
268625	263174	08018U	PARTICIPANT	\N	PRESENT	0
268626	263174	11067R	PARTICIPANT	\N	PRESENT	0
268627	263174	14151M	PARTICIPANT	\N	PRESENT	0
268628	263174	05008E	PARTICIPANT	\N	PRESENT	0
268629	263174	14267Y	PARTICIPANT	\N	PRESENT	0
268630	263174	08056B	PARTICIPANT	\N	PRESENT	0
268631	263174	19723Y	PARTICIPANT	\N	PRESENT	0
268632	263174	19565D	PARTICIPANT	\N	PRESENT	0
268633	263174	11099A	PARTICIPANT	\N	PRESENT	0
268634	263174	11103C	PARTICIPANT	\N	PRESENT	0
268635	263174	19747H	PARTICIPANT	\N	PRESENT	0
268636	263174	19737F	PARTICIPANT	\N	PRESENT	0
268637	263174	19649G	PARTICIPANT	\N	PRESENT	0
268638	263174	14065Q	PARTICIPANT	\N	PRESENT	0
268639	263174	19659J	PARTICIPANT	\N	PRESENT	0
268640	263174	14105F	PARTICIPANT	\N	PRESENT	0
268641	263174	11097X	PARTICIPANT	\N	PRESENT	0
268642	263174	14229S	PARTICIPANT	\N	PRESENT	0
268643	263174	11077T	PARTICIPANT	\N	PRESENT	0
268644	263174	14029X	PARTICIPANT	\N	PRESENT	0
268645	263174	19333N	PARTICIPANT	\N	PRESENT	0
268646	263174	14201E	PARTICIPANT	\N	PRESENT	0
268647	263174	19387D	PARTICIPANT	\N	PRESENT	0
268648	263174	14157T	PARTICIPANT	\N	PRESENT	0
268649	263174	18083K	PARTICIPANT	\N	PRESENT	0
241085	240227	14239U	PARTICIPANT	\N	EXCUSE	0
241248	241247	07004J	PARTICIPANT	\N	PRESENT	0
243663	240279	19651A	PARTICIPANT	\N	PRESENT	0
243664	240279	11083R	PARTICIPANT	\N	PRESENT	0
243665	240279	14229S	PARTICIPANT	\N	PRESENT	0
243666	240279	08017T	PARTICIPANT	\N	PRESENT	0
243667	240279	19593H	PARTICIPANT	\N	PRESENT	0
243668	240279	11054L	PARTICIPANT	\N	PRESENT	0
243669	240279	19591F	PARTICIPANT	\N	PRESENT	0
243670	240279	14121F	PARTICIPANT	\N	PRESENT	0
243671	240279	19329S	PARTICIPANT	\N	PRESENT	0
243672	240279	04057K	PARTICIPANT	\N	PRESENT	0
243673	240279	19697Q	PARTICIPANT	\N	PRESENT	0
243674	240279	19543W	PARTICIPANT	\N	PRESENT	0
243675	240279	19749K	PARTICIPANT	\N	PRESENT	0
243676	240279	19737F	PARTICIPANT	\N	PRESENT	0
243677	240279	19663E	PARTICIPANT	\N	PRESENT	0
243678	240279	19573D	PARTICIPANT	\N	PRESENT	0
243679	240279	14033T	PARTICIPANT	\N	PRESENT	0
243680	240279	18083K	PARTICIPANT	\N	PRESENT	0
243681	240279	19667J	PARTICIPANT	\N	PRESENT	0
243682	240279	07029T	PARTICIPANT	\N	PRESENT	0
243683	240279	19729F	PARTICIPANT	\N	PRESENT	0
243684	240279	19671E	PARTICIPANT	\N	PRESENT	0
243685	240279	97011G	PARTICIPANT	\N	PRESENT	0
243686	240279	14217N	PARTICIPANT	\N	PRESENT	0
243687	240279	08010L	PARTICIPANT	\N	PRESENT	0
243688	240279	19711U	PARTICIPANT	\N	PRESENT	0
243689	240279	11070L	PARTICIPANT	\N	PRESENT	0
243690	240279	14215L	PARTICIPANT	\N	PRESENT	0
243691	240279	19521Q	PARTICIPANT	\N	PRESENT	0
243692	240279	19369B	PARTICIPANT	\N	PRESENT	0
243693	240279	14083S	PARTICIPANT	\N	PRESENT	0
243694	240279	14109K	PARTICIPANT	\N	PRESENT	0
243695	240279	04070G	PARTICIPANT	\N	PRESENT	0
243696	240279	14061L	PARTICIPANT	\N	PRESENT	0
243697	240279	19533U	PARTICIPANT	\N	PRESENT	0
243698	240279	19399H	PARTICIPANT	\N	PRESENT	0
243699	240279	14355X	PARTICIPANT	\N	PRESENT	0
243700	240279	04018C	PARTICIPANT	\N	PRESENT	0
243701	240279	19621T	PARTICIPANT	\N	PRESENT	0
243702	240279	19699S	PARTICIPANT	\N	PRESENT	0
243703	240279	19387D	PARTICIPANT	\N	PRESENT	0
243704	240279	08031R	PARTICIPANT	\N	PRESENT	0
243705	240279	19695N	PARTICIPANT	\N	PRESENT	0
243706	240279	04043D	PARTICIPANT	\N	PRESENT	0
243707	240279	19447X	PARTICIPANT	\N	PRESENT	0
243708	240279	11027H	PARTICIPANT	\N	PRESENT	0
243709	240279	19483C	PARTICIPANT	\N	PRESENT	0
243710	240279	19441R	PARTICIPANT	\N	PRESENT	0
243711	240279	19741B	PARTICIPANT	\N	PRESENT	0
243712	240279	98050T	PARTICIPANT	\N	PRESENT	0
243713	240279	04092N	PARTICIPANT	\N	PRESENT	0
243714	240279	11097X	PARTICIPANT	\N	PRESENT	0
243717	240279	95015C	PARTICIPANT	\N	PRESENT	0
243720	240279	19735D	PARTICIPANT	\N	PRESENT	0
243722	240279	14157T	PARTICIPANT	\N	PRESENT	0
243723	240279	19575F	PARTICIPANT	\N	PRESENT	0
243724	240279	19479G	PARTICIPANT	\N	PRESENT	0
243725	240279	19503N	PARTICIPANT	\N	PRESENT	0
243737	240279	19731Y	PARTICIPANT	\N	PRESENT	0
243738	240279	98005N	PARTICIPANT	\N	PRESENT	0
243739	240279	19703U	PARTICIPANT	\N	PRESENT	0
243740	240279	19611R	PARTICIPANT	\N	PRESENT	0
243741	240279	19301E	PARTICIPANT	\N	PRESENT	0
243742	240279	14042U	PARTICIPANT	\N	PRESENT	0
243743	240279	10015M	PARTICIPANT	\N	PRESENT	0
243744	240279	14073Q	PARTICIPANT	\N	PRESENT	0
243745	240279	01028R	PARTICIPANT	\N	PRESENT	0
243759	240279	19253P	PARTICIPANT	\N	PRESENT	0
243770	240279	08043V	PARTICIPANT	\N	PRESENT	0
243883	240280	19593H	PARTICIPANT	\N	PRESENT	0
243884	240280	04070G	PARTICIPANT	\N	PRESENT	0
243885	240280	14123H	PARTICIPANT	\N	PRESENT	0
243886	240280	14229S	PARTICIPANT	\N	PRESENT	0
243887	240280	19611R	PARTICIPANT	\N	PRESENT	0
243888	240280	19319Q	PARTICIPANT	\N	PRESENT	0
243889	240280	19621T	PARTICIPANT	\N	PRESENT	0
243890	240280	14217N	PARTICIPANT	\N	PRESENT	0
243891	240280	14041T	PARTICIPANT	\N	PRESENT	0
243892	240280	19447X	PARTICIPANT	\N	PRESENT	0
243893	240280	19573D	PARTICIPANT	\N	PRESENT	0
243894	240280	19399H	PARTICIPANT	\N	PRESENT	0
243895	240280	19533U	PARTICIPANT	\N	PRESENT	0
243896	240280	19731Y	PARTICIPANT	\N	PRESENT	0
243897	240280	19701S	PARTICIPANT	\N	PRESENT	0
243899	240280	19711U	PARTICIPANT	\N	PRESENT	0
243901	240280	19503N	PARTICIPANT	\N	PRESENT	0
243925	240280	98005N	PARTICIPANT	\N	PRESENT	0
243926	240280	14073Q	PARTICIPANT	\N	PRESENT	0
243927	240280	19699S	PARTICIPANT	\N	PRESENT	0
243933	240280	14061L	PARTICIPANT	\N	PRESENT	0
243934	240280	04057K	PARTICIPANT	\N	PRESENT	0
243936	240280	14355X	PARTICIPANT	\N	PRESENT	0
243937	240280	07029T	PARTICIPANT	\N	PRESENT	0
243938	240280	19735D	PARTICIPANT	\N	PRESENT	0
243939	240280	08010L	PARTICIPANT	\N	PRESENT	0
243940	240280	08020N	PARTICIPANT	\N	PRESENT	0
243941	240280	11097X	PARTICIPANT	\N	PRESENT	0
243942	240280	14034U	PARTICIPANT	\N	PRESENT	0
243943	240280	08031R	PARTICIPANT	\N	PRESENT	0
243944	240280	19697Q	PARTICIPANT	\N	PRESENT	0
243945	240280	19543W	PARTICIPANT	\N	PRESENT	0
243946	240280	11083R	PARTICIPANT	\N	PRESENT	0
243947	240280	19329S	PARTICIPANT	\N	PRESENT	0
243948	240280	95015C	PARTICIPANT	\N	PRESENT	0
243949	240280	04034C	PARTICIPANT	\N	PRESENT	0
243661	240279	14034U	PARTICIPANT	\N	PRESENT	0
243662	240279	14123H	PARTICIPANT	\N	PRESENT	0
243951	240280	11054L	PARTICIPANT	\N	PRESENT	0
243955	240280	19483C	PARTICIPANT	\N	PRESENT	0
243956	240280	14083S	PARTICIPANT	\N	PRESENT	0
243961	240280	19713W	PARTICIPANT	\N	PRESENT	0
243958	240280	19715Y	PARTICIPANT	\N	PRESENT	0
243959	240280	19253P	PARTICIPANT	\N	PRESENT	0
243962	240280	14030Q	PARTICIPANT	\N	PRESENT	0
243963	240280	98050T	PARTICIPANT	\N	PRESENT	0
243996	240280	04059M	PARTICIPANT	\N	PRESENT	0
243997	240280	19727D	PARTICIPANT	\N	PRESENT	0
243998	240280	04043D	PARTICIPANT	\N	PRESENT	0
243999	240280	11010L	PARTICIPANT	\N	PRESENT	0
244000	240280	14157T	PARTICIPANT	\N	PRESENT	0
244001	240280	08039A	PARTICIPANT	\N	PRESENT	0
244004	240280	04085P	PARTICIPANT	\N	PRESENT	0
244005	240280	04018C	PARTICIPANT	\N	PRESENT	0
244006	240280	19575F	PARTICIPANT	\N	PRESENT	0
244007	240280	08017T	PARTICIPANT	\N	PRESENT	0
244021	240280	19531S	PARTICIPANT	\N	PRESENT	0
244024	240280	14021P	PARTICIPANT	\N	PRESENT	0
244025	240280	19695N	PARTICIPANT	\N	PRESENT	0
244026	240280	01048V	PARTICIPANT	\N	PRESENT	0
243851	240280	11070L	PARTICIPANT	\N	PRESENT	0
244030	240280	14103D	PARTICIPANT	\N	PRESENT	0
244043	240280	14097Y	PARTICIPANT	\N	PRESENT	0
244094	240280	89017R	PARTICIPANT	\N	PRESENT	0
244270	244269	11083R	PARTICIPANT	\N	PRESENT	0
244284	244283	08038Y	PARTICIPANT	\N	PRESENT	0
244285	244283	14105F	PARTICIPANT	\N	PRESENT	0
244286	244283	14255U	PARTICIPANT	\N	PRESENT	0
244287	244283	19251M	PARTICIPANT	\N	PRESENT	0
244288	244283	98005N	PARTICIPANT	\N	PRESENT	0
244289	244283	01043Q	PARTICIPANT	\N	PRESENT	0
244290	244283	04043D	PARTICIPANT	\N	PRESENT	0
244291	244283	11045K	PARTICIPANT	\N	PRESENT	0
244636	244332	14001X	PARTICIPANT	\N	PRESENT	0
245374	245373	04059M	PARTICIPANT	\N	PRESENT	0
245375	245373	95015C	PARTICIPANT	\N	PRESENT	0
245376	245373	19693L	PARTICIPANT	\N	PRESENT	0
246134	246133	95062K	PARTICIPANT	\N	PRESENT	0
246135	246133	08019V	PARTICIPANT	\N	PRESENT	0
245379	245373	14123H	PARTICIPANT	\N	PRESENT	0
245380	245373	14241N	PARTICIPANT	\N	PRESENT	0
245381	245373	14039A	PARTICIPANT	\N	PRESENT	0
245382	245373	19611R	PARTICIPANT	\N	PRESENT	0
245383	245373	04070G	PRESIDENT	0	PRESENT	0
245384	245373	19593H	PARTICIPANT	\N	PRESENT	0
245385	245373	19573D	PARTICIPANT	\N	PRESENT	0
245386	245373	19533U	PARTICIPANT	\N	PRESENT	0
245387	245373	14229S	PARTICIPANT	\N	PRESENT	0
246136	246133	19319Q	PARTICIPANT	\N	PRESENT	0
246137	246133	14059S	PARTICIPANT	\N	PRESENT	0
246138	246133	11072N	PARTICIPANT	\N	PRESENT	0
246139	246133	19657G	PARTICIPANT	\N	PRESENT	0
246140	246133	19659J	PARTICIPANT	\N	EXCUSE	0
246141	246133	08016S	PARTICIPANT	\N	EXCUSE	0
246142	246133	19583F	PARTICIPANT	\N	EXCUSE	0
246143	246133	19691J	PARTICIPANT	\N	EXCUSE	0
246144	246133	14275Y	PARTICIPANT	\N	EXCUSE	0
246145	246133	19703U	PARTICIPANT	\N	EXCUSE	0
261787	261783	04071H	PARTICIPANT	\N	PRESENT	0
261788	261783	19443T	PARTICIPANT	\N	PRESENT	0
261789	261783	14111D	PARTICIPANT	\N	PRESENT	0
261790	261783	08058D	PRESIDENT	0	PRESENT	0
261791	261783	19251M	PARTICIPANT	\N	PRESENT	0
261792	261783	19581D	PARTICIPANT	\N	PRESENT	0
261793	261783	19721W	PARTICIPANT	\N	PRESENT	0
261794	261783	04086Q	PARTICIPANT	\N	PRESENT	0
261795	261783	15447F	PARTICIPANT	\N	PRESENT	0
261796	261783	19703U	PARTICIPANT	\N	PRESENT	0
261797	261783	19729F	PARTICIPANT	\N	PRESENT	0
261798	261783	11049P	PARTICIPANT	\N	PRESENT	0
261799	261485	04045F	PARTICIPANT	\N	PRESENT	0
261800	261485	19651A	PARTICIPANT	\N	PRESENT	0
261801	261485	14069U	PARTICIPANT	\N	PRESENT	0
261802	261485	01057W	PARTICIPANT	\N	PRESENT	0
261803	261485	19637C	PARTICIPANT	\N	PRESENT	0
261804	261485	19447X	PARTICIPANT	\N	PRESENT	0
261805	261485	14089Y	PARTICIPANT	\N	PRESENT	0
261806	261485	19441R	PARTICIPANT	\N	PRESENT	0
261807	261485	08015R	PARTICIPANT	\N	PRESENT	0
261808	261485	04070G	PARTICIPANT	\N	PRESENT	0
261809	261485	08056B	PARTICIPANT	\N	PRESENT	0
261810	261485	14179A	PARTICIPANT	\N	PRESENT	0
261811	261485	14107H	PARTICIPANT	\N	PRESENT	0
261812	261485	14123H	PARTICIPANT	\N	PRESENT	0
261907	261486	14107H	PARTICIPANT	\N	PRESENT	0
261908	261486	14121F	PARTICIPANT	\N	PRESENT	0
261909	261486	19549D	PARTICIPANT	\N	PRESENT	0
261910	261486	14197C	PARTICIPANT	\N	PRESENT	0
261911	261486	14109K	PARTICIPANT	\N	PRESENT	0
261912	261486	19637C	PARTICIPANT	\N	PRESENT	0
261913	261486	04045F	PARTICIPANT	\N	PRESENT	0
261914	261486	19593H	PARTICIPANT	\N	PRESENT	0
261915	261486	02002K	PARTICIPANT	\N	PRESENT	0
262278	262277	14219Q	PARTICIPANT	\N	PRESENT	0
261917	261486	14231L	PARTICIPANT	\N	PRESENT	0
261918	261486	16685X	PARTICIPANT	\N	PRESENT	0
261919	261486	19479G	PARTICIPANT	\N	PRESENT	0
261920	261486	14089Y	PARTICIPANT	\N	PRESENT	0
261921	261486	14179A	PARTICIPANT	\N	PRESENT	0
261922	261486	14327T	PARTICIPANT	\N	PRESENT	0
261923	261486	19525U	PARTICIPANT	\N	PRESENT	0
261924	261486	95062K	PARTICIPANT	\N	PRESENT	0
261925	261486	08020N	PARTICIPANT	\N	PRESENT	0
261926	261486	14157T	PARTICIPANT	\N	PRESENT	0
261927	261486	11043H	PARTICIPANT	\N	PRESENT	0
261928	261486	19711U	PARTICIPANT	\N	PRESENT	0
261929	261486	14069U	PARTICIPANT	\N	PRESENT	0
261930	261486	01057W	PARTICIPANT	\N	PRESENT	0
261931	261486	14031R	PARTICIPANT	\N	PRESENT	0
261932	261486	14053L	PARTICIPANT	\N	PRESENT	0
261933	261486	19747H	PARTICIPANT	\N	PRESENT	0
261934	261486	19739H	PARTICIPANT	\N	PRESENT	0
261935	261486	19745F	PARTICIPANT	\N	PRESENT	0
261936	261486	14217N	PARTICIPANT	\N	PRESENT	0
261937	261486	08015R	PARTICIPANT	\N	PRESENT	0
261938	261486	95067Q	PARTICIPANT	\N	PRESENT	0
261939	261486	14105F	PARTICIPANT	\N	PRESENT	0
261940	261486	14213J	PARTICIPANT	\N	PRESENT	0
261941	261486	95030B	PARTICIPANT	\N	PRESENT	0
261942	261486	14033T	PARTICIPANT	\N	PRESENT	0
261943	261486	08034U	PARTICIPANT	\N	PRESENT	0
261944	261486	97011G	PARTICIPANT	\N	PRESENT	0
261945	261486	04049K	PARTICIPANT	\N	PRESENT	0
261946	261486	08038Y	PARTICIPANT	\N	PRESENT	0
261947	261486	19701S	PARTICIPANT	\N	PRESENT	0
261948	261486	01058X	PARTICIPANT	\N	PRESENT	0
261949	261486	19387D	PARTICIPANT	\N	PRESENT	0
261950	261486	19253P	PARTICIPANT	\N	PRESENT	0
261951	261486	08009T	PARTICIPANT	\N	PRESENT	0
261952	261486	08056B	PARTICIPANT	\N	PRESENT	0
261953	261486	14038Y	PARTICIPANT	\N	PRESENT	0
261954	255917	19629C	PARTICIPANT	\N	PRESENT	0
261955	261486	11097X	PARTICIPANT	\N	PRESENT	0
261957	261486	14083S	PARTICIPANT	\N	PRESENT	0
261958	261486	11056N	PARTICIPANT	\N	PRESENT	0
261959	261486	19347U	PARTICIPANT	\N	PRESENT	0
261960	261486	19565D	PARTICIPANT	\N	PRESENT	0
261961	261572	19533U	PARTICIPANT	\N	PRESENT	0
261962	261572	14229S	PARTICIPANT	\N	PRESENT	0
261963	261572	14231L	PARTICIPANT	\N	PRESENT	0
261964	261572	19447X	PARTICIPANT	\N	PRESENT	0
261965	261572	19573D	PARTICIPANT	\N	PRESENT	0
261966	261572	14107H	PARTICIPANT	\N	PRESENT	0
261967	261572	14147R	PARTICIPANT	\N	PRESENT	0
261968	261572	14249W	PARTICIPANT	\N	PRESENT	0
261969	261572	08039A	PARTICIPANT	\N	PRESENT	0
261970	261572	08031R	PARTICIPANT	\N	PRESENT	0
261971	261572	11072N	PARTICIPANT	\N	PRESENT	0
261972	261572	14059S	PARTICIPANT	\N	PRESENT	0
261973	261572	04057K	PARTICIPANT	\N	PRESENT	0
261974	261572	14073Q	PARTICIPANT	\N	PRESENT	0
261975	261572	19611R	PARTICIPANT	\N	PRESENT	0
261976	261572	01024M	PARTICIPANT	\N	PRESENT	0
261977	261572	19693L	PARTICIPANT	\N	PRESENT	0
261978	261572	19399H	PARTICIPANT	\N	PRESENT	0
261979	261572	14030Q	PARTICIPANT	\N	PRESENT	0
261980	261572	19725B	PARTICIPANT	\N	PRESENT	0
261981	261572	19731Y	PARTICIPANT	\N	PRESENT	0
261982	261572	14251Q	PARTICIPANT	\N	PRESENT	0
261983	261572	19735D	PARTICIPANT	\N	PRESENT	0
261984	261572	14063N	PARTICIPANT	\N	PRESENT	0
261985	261572	14123H	PARTICIPANT	\N	PRESENT	0
261986	261572	11043H	PARTICIPANT	\N	PRESENT	0
261987	261572	19749K	PARTICIPANT	\N	PRESENT	0
261988	261572	14061L	PARTICIPANT	\N	EXCUSE	0
261989	261572	19699S	PARTICIPANT	\N	EXCUSE	0
261990	261572	08043V	PARTICIPANT	\N	EXCUSE	0
261991	261572	87003B	PARTICIPANT	\N	EXCUSE	0
261992	261572	04018C	PARTICIPANT	\N	EXCUSE	0
261993	261486	08045X	PARTICIPANT	\N	PRESENT	0
261994	261486	04061F	PARTICIPANT	\N	PRESENT	0
261995	261486	19441R	PARTICIPANT	\N	PRESENT	0
261996	261486	11065P	PARTICIPANT	\N	PRESENT	0
261997	261486	14115H	PARTICIPANT	\N	PRESENT	0
261998	261486	18083K	PARTICIPANT	\N	PRESENT	0
261999	261486	19673G	PARTICIPANT	\N	PRESENT	0
261905	261486	11070L	PARTICIPANT	\N	PRESENT	0
261906	261486	14051J	PARTICIPANT	\N	PRESENT	0
262000	261572	14151M	PARTICIPANT	\N	PRESENT	0
262001	261572	04038G	PARTICIPANT	\N	PRESENT	0
262002	261486	11031D	PARTICIPANT	\N	PRESENT	0
262005	261486	19715Y	PARTICIPANT	\N	PRESENT	0
262006	261486	11067R	PARTICIPANT	\N	PRESENT	0
262007	261486	14257W	PARTICIPANT	\N	PRESENT	0
262008	261486	19599P	PARTICIPANT	\N	PRESENT	0
262009	261486	14147R	PARTICIPANT	\N	PRESENT	0
262010	261486	01025N	PARTICIPANT	\N	PRESENT	0
262011	261486	19483C	PARTICIPANT	\N	PRESENT	0
262096	261956	01028R	PARTICIPANT	\N	PRESENT	0
262279	262277	14059S	PARTICIPANT	\N	PRESENT	0
262280	262277	19319Q	PARTICIPANT	\N	PRESENT	0
262281	262277	04043D	PARTICIPANT	\N	PRESENT	0
262282	262277	01058X	PARTICIPANT	\N	PRESENT	0
262374	262373	14073Q	PARTICIPANT	\N	PRESENT	0
262375	262373	04049K	PARTICIPANT	\N	PRESENT	0
262376	262373	08015R	PARTICIPANT	\N	PRESENT	0
262377	262373	19483C	PARTICIPANT	\N	PRESENT	0
262378	262373	14237S	PARTICIPANT	\N	PRESENT	0
262379	262373	14225N	PARTICIPANT	\N	PRESENT	0
262380	262373	95063L	PARTICIPANT	\N	PRESENT	0
262381	262373	04034C	PARTICIPANT	\N	PRESENT	0
262383	262382	95063L	PARTICIPANT	\N	PRESENT	0
262384	262382	14225N	PARTICIPANT	\N	PRESENT	0
262385	262382	08015R	PARTICIPANT	\N	PRESENT	0
262465	262464	19631V	PARTICIPANT	\N	PRESENT	0
262467	262464	19347U	PARTICIPANT	\N	PRESENT	0
262468	262464	14179A	PARTICIPANT	\N	PRESENT	0
262469	262464	14237S	PARTICIPANT	\N	PRESENT	0
262470	262464	14265W	PARTICIPANT	\N	PRESENT	0
262471	262464	14107H	PARTICIPANT	\N	PRESENT	0
262472	262464	14109K	PARTICIPANT	\N	PRESENT	0
262514	262478	14069U	PARTICIPANT	\N	PRESENT	0
262559	262558	08058D	PARTICIPANT	\N	PRESENT	0
262516	262478	08020N	PARTICIPANT	\N	PRESENT	0
262517	262478	19467C	PARTICIPANT	\N	PRESENT	0
262518	262478	17589D	PARTICIPANT	\N	PRESENT	0
262519	262478	19507S	PARTICIPANT	\N	PRESENT	0
262520	262478	14033T	PARTICIPANT	\N	PRESENT	0
262521	262478	19511N	PARTICIPANT	\N	PRESENT	0
262522	262478	14205J	PARTICIPANT	\N	PRESENT	0
262523	262478	14265W	PARTICIPANT	\N	PRESENT	0
262524	262478	19745F	PARTICIPANT	\N	PRESENT	0
262525	262478	04088S	PARTICIPANT	\N	PRESENT	0
262526	262478	05012A	PARTICIPANT	\N	PRESENT	0
262527	262478	19735D	PARTICIPANT	\N	PRESENT	0
262528	262478	19619A	PARTICIPANT	\N	PRESENT	0
262540	255917	08045X	PARTICIPANT	\N	EXCUSE	0
240865	240864	19515S	PARTICIPANT	\N	PRESENT	0
240866	240864	08055A	PARTICIPANT	\N	PRESENT	0
240867	240864	14105F	PARTICIPANT	\N	PRESENT	0
240868	240864	08020N	PARTICIPANT	\N	PRESENT	0
240869	240864	14207L	PARTICIPANT	\N	PRESENT	0
240870	240864	14329V	PARTICIPANT	\N	PRESENT	0
240871	240864	19467C	PARTICIPANT	\N	PRESENT	0
240872	240864	11027H	PARTICIPANT	\N	PRESENT	0
240873	240864	80013X	PARTICIPANT	\N	PRESENT	0
240874	240864	19719D	PARTICIPANT	\N	PRESENT	0
240875	240864	01024M	PARTICIPANT	\N	PRESENT	0
240876	240864	01025N	PARTICIPANT	\N	PRESENT	0
240877	240864	14026U	PARTICIPANT	\N	PRESENT	0
240878	240864	19725B	PARTICIPANT	\N	PRESENT	0
240879	240864	95037J	PARTICIPANT	\N	PRESENT	0
240880	240864	14213J	PARTICIPANT	\N	PRESENT	0
240881	240864	14061L	PARTICIPANT	\N	PRESENT	0
240882	240864	19611R	PARTICIPANT	\N	PRESENT	0
240883	240864	04049K	PARTICIPANT	\N	PRESENT	0
240884	240864	19723Y	PARTICIPANT	\N	PRESENT	0
240885	240864	08015R	PARTICIPANT	\N	PRESENT	0
240886	240864	08010L	PARTICIPANT	\N	PRESENT	0
240887	240864	14205J	PARTICIPANT	\N	PRESENT	0
240888	240864	08053X	PARTICIPANT	\N	PRESENT	0
241095	241093	19563B	PARTICIPANT	\N	PRESENT	0
240890	240864	14109K	PARTICIPANT	\N	PRESENT	0
240891	240864	14257W	PARTICIPANT	\N	PRESENT	0
241094	241093	14193X	PARTICIPANT	\N	PRESENT	0
240893	240864	05012A	PARTICIPANT	\N	PRESENT	0
240894	240864	19443T	PARTICIPANT	\N	PRESENT	0
241096	241093	14257W	PARTICIPANT	\N	PRESENT	0
241097	241093	19695N	PARTICIPANT	\N	PRESENT	0
241098	241093	19585H	PARTICIPANT	\N	PRESENT	0
241099	241093	19251M	PARTICIPANT	\N	PRESENT	0
241100	241093	19349W	PARTICIPANT	\N	PRESENT	0
241101	241093	19737F	PARTICIPANT	\N	PRESENT	0
241102	241093	08028W	PARTICIPANT	\N	PRESENT	0
241103	241093	08068F	PARTICIPANT	\N	PRESENT	0
241105	241104	14237S	PARTICIPANT	\N	PRESENT	0
241106	241104	14073Q	PARTICIPANT	\N	PRESENT	0
241107	241104	19251M	PARTICIPANT	\N	PRESENT	0
241108	241104	14257W	PARTICIPANT	\N	PRESENT	0
241109	241104	19563B	PARTICIPANT	\N	PRESENT	0
241110	241104	19737F	PARTICIPANT	\N	PRESENT	0
241111	241104	08068F	PARTICIPANT	\N	PRESENT	0
241112	241104	08028W	PARTICIPANT	\N	PRESENT	0
241114	241113	08028W	PARTICIPANT	\N	PRESENT	0
241115	241113	08068F	PARTICIPANT	\N	PRESENT	0
241116	241113	19737F	PARTICIPANT	\N	PRESENT	0
241117	241113	14237S	PARTICIPANT	\N	PRESENT	0
244148	243898	19717B	PARTICIPANT	\N	EXCUSE	0
244150	241232	19717B	PARTICIPANT	\N	EXCUSE	0
244340	244339	14281W	PARTICIPANT	\N	PRESENT	0
244341	244339	14081Q	PARTICIPANT	\N	PRESENT	0
244342	244339	14097Y	PARTICIPANT	\N	PRESENT	0
244343	244339	08053X	PARTICIPANT	\N	PRESENT	0
244344	244339	14227Q	PARTICIPANT	\N	PRESENT	0
244345	244339	11066Q	PARTICIPANT	\N	PRESENT	0
245666	244322	19631V	PARTICIPANT	\N	PRESENT	0
245667	244322	19515S	PARTICIPANT	\N	PRESENT	0
245668	244322	19707Y	PARTICIPANT	\N	PRESENT	0
245669	244322	11081P	PARTICIPANT	\N	EXCUSE	0
245670	244322	14115H	PARTICIPANT	\N	PRESENT	0
245671	244322	19747H	PARTICIPANT	\N	PRESENT	0
245672	244322	08068F	PARTICIPANT	\N	PRESENT	0
245673	244322	14207L	PARTICIPANT	\N	PRESENT	0
245674	244322	11101A	PARTICIPANT	\N	EXCUSE	0
245675	244322	14329V	PARTICIPANT	\N	PRESENT	0
245676	244322	08028W	PARTICIPANT	\N	PRESENT	0
245677	244322	19467C	PARTICIPANT	\N	PRESENT	0
245718	244322	14261S	PARTICIPANT	\N	PRESENT	0
245679	244322	80013X	PARTICIPANT	\N	PRESENT	0
245680	244322	11056N	PARTICIPANT	\N	EXCUSE	0
245681	244322	14357A	PARTICIPANT	\N	PRESENT	0
245682	244322	08038Y	PARTICIPANT	\N	PRESENT	0
245683	244322	17589D	PARTICIPANT	\N	PRESENT	0
245684	244322	04089T	PARTICIPANT	\N	PRESENT	0
245685	244322	19507S	PARTICIPANT	\N	PRESENT	0
245720	244322	19575F	PARTICIPANT	\N	PRESENT	0
245687	244322	14187A	PARTICIPANT	\N	PRESENT	0
245721	244322	19367Y	PARTICIPANT	\N	PRESENT	0
245689	244322	19695N	PARTICIPANT	\N	PRESENT	0
245722	244322	11103C	PARTICIPANT	\N	PRESENT	0
245691	244322	14033T	PARTICIPANT	\N	PRESENT	0
245723	244322	14195A	PARTICIPANT	\N	PRESENT	0
245724	244322	08052W	PARTICIPANT	\N	PRESENT	0
245694	244322	19511N	PARTICIPANT	\N	PRESENT	0
245695	244322	11099A	PARTICIPANT	\N	PRESENT	0
245696	244322	04049K	PARTICIPANT	\N	PRESENT	0
245697	244322	08015R	PARTICIPANT	\N	PRESENT	0
245698	244322	01043Q	PARTICIPANT	\N	PRESENT	0
245699	244322	14205J	PARTICIPANT	\N	PRESENT	0
245700	244322	19441R	PARTICIPANT	\N	PRESENT	0
245701	244322	08019V	PARTICIPANT	\N	PRESENT	0
245702	244322	08062Y	PARTICIPANT	\N	PRESENT	0
245703	244322	19563B	PARTICIPANT	\N	PRESENT	0
245704	244322	19369B	PARTICIPANT	\N	PRESENT	0
245705	244322	14257W	PARTICIPANT	\N	PRESENT	0
245706	244322	14265W	PARTICIPANT	\N	PRESENT	0
245707	244322	08021P	PARTICIPANT	\N	PRESENT	0
245708	244322	04088S	PARTICIPANT	\N	PRESENT	0
245709	244322	11090Q	PRESIDENT	0	PRESENT	0
245710	244322	04043D	PARTICIPANT	\N	PRESENT	0
245711	244322	14135M	PARTICIPANT	\N	PRESENT	0
245712	244322	19269X	PARTICIPANT	\N	PRESENT	0
245713	244322	19705W	PARTICIPANT	\N	PRESENT	0
245714	244322	19619A	PARTICIPANT	\N	PRESENT	0
245715	244322	19301E	PARTICIPANT	\N	PRESENT	0
245716	244322	19413M	PARTICIPANT	\N	PRESENT	0
245725	244322	98024R	PARTICIPANT	\N	PRESENT	0
245726	244322	14217N	PARTICIPANT	\N	PRESENT	0
245727	244322	14042U	PARTICIPANT	\N	PRESENT	0
245728	244322	14281W	PARTICIPANT	\N	PRESENT	0
245730	244322	14087W	PARTICIPANT	\N	PRESENT	0
245731	244322	19521Q	PARTICIPANT	\N	PRESENT	0
245732	244322	19553Y	PARTICIPANT	\N	PRESENT	0
245733	244322	19715Y	PARTICIPANT	\N	PRESENT	0
245734	244322	19683J	PARTICIPANT	\N	PRESENT	0
245735	244322	19697Q	PARTICIPANT	\N	PRESENT	0
245736	244322	17779H	PARTICIPANT	\N	PRESENT	0
245737	244322	11067R	PARTICIPANT	\N	PRESENT	0
245738	244322	14223L	PARTICIPANT	\N	PRESENT	0
245739	244322	04092N	PARTICIPANT	\N	PRESENT	0
245740	244322	19335Q	PARTICIPANT	\N	PRESENT	0
245741	244322	14119M	PARTICIPANT	\N	PRESENT	0
245743	244322	14071N	PARTICIPANT	\N	PRESENT	0
245744	244322	19679N	PARTICIPANT	\N	PRESENT	0
245746	244322	11045K	PARTICIPANT	\N	PRESENT	0
245748	244322	04045F	PARTICIPANT	\N	PRESENT	0
245749	244322	19703U	PARTICIPANT	\N	PRESENT	0
245750	244322	14227Q	PARTICIPANT	\N	PRESENT	0
245751	244322	19527W	PARTICIPANT	\N	PRESENT	0
245752	244322	14026U	PARTICIPANT	\N	PRESENT	0
245755	244322	19569H	PARTICIPANT	\N	PRESENT	0
245756	244322	11031D	PARTICIPANT	\N	PRESENT	0
245757	244322	19675J	PARTICIPANT	\N	PRESENT	0
245758	244322	19691J	PARTICIPANT	\N	PRESENT	0
245759	244322	18083K	PARTICIPANT	\N	PRESENT	0
245763	244322	19565D	PARTICIPANT	\N	EXCUSE	0
245766	244323	11056N	PARTICIPANT	\N	EXCUSE	0
245767	244323	11081P	PARTICIPANT	\N	EXCUSE	0
245775	244323	80013X	PARTICIPANT	\N	PRESENT	0
245800	244323	17589D	PARTICIPANT	\N	PRESENT	0
245802	244323	19619A	PARTICIPANT	\N	PRESENT	0
245803	244323	08015R	PARTICIPANT	\N	PRESENT	0
250085	240297	14147R	PARTICIPANT	\N	PRESENT	0
255369	251926	11041F	PARTICIPANT	\N	EXCUSE	0
255416	251925	11041F	PARTICIPANT	\N	EXCUSE	0
255418	251926	11064N	PARTICIPANT	\N	PRESENT	0
255501	255500	19515S	PARTICIPANT	\N	PRESENT	0
255502	255500	08055A	PARTICIPANT	\N	PRESENT	0
255503	255500	08014Q	PARTICIPANT	\N	PRESENT	0
255504	255500	14105F	PARTICIPANT	\N	PRESENT	0
255505	255500	19383Y	PARTICIPANT	\N	PRESENT	0
255506	255500	14207L	PARTICIPANT	\N	PRESENT	0
255511	255500	08028W	PARTICIPANT	\N	PRESENT	0
255512	255500	19467C	PARTICIPANT	\N	PRESENT	0
255513	255500	14217N	PARTICIPANT	\N	PRESENT	0
255514	255500	19507S	PARTICIPANT	\N	PRESENT	0
255515	255500	01025N	PARTICIPANT	\N	PRESENT	0
255516	255500	19727D	PARTICIPANT	\N	PRESENT	0
255517	255500	14213J	PARTICIPANT	\N	PRESENT	0
255518	255500	08015R	PARTICIPANT	\N	PRESENT	0
255519	255500	19483C	PARTICIPANT	\N	PRESENT	0
255533	255500	19369B	PARTICIPANT	\N	PRESENT	0
255534	255500	14257W	PARTICIPANT	\N	PRESENT	0
255535	255500	14265W	PARTICIPANT	\N	PRESENT	0
255536	255500	19745F	PARTICIPANT	\N	PRESENT	0
255537	255500	14135M	PARTICIPANT	\N	PRESENT	0
271705	270566	19697Q	PARTICIPANT	\N	PRESENT	0
271706	270566	11067R	PARTICIPANT	\N	PRESENT	0
271707	270566	11097X	PARTICIPANT	\N	PRESENT	0
271708	270566	14223L	PARTICIPANT	\N	PRESENT	0
271709	270566	14026U	PARTICIPANT	\N	PRESENT	0
271710	270566	14227Q	PARTICIPANT	\N	PRESENT	0
271711	270566	11063M	PARTICIPANT	\N	PRESENT	0
271712	270566	17779H	PARTICIPANT	\N	PRESENT	0
271713	270566	19703U	PARTICIPANT	\N	PRESENT	0
271714	270566	11031D	PARTICIPANT	\N	PRESENT	0
271715	270566	14087W	PARTICIPANT	\N	PRESENT	0
271716	270566	14281W	PARTICIPANT	\N	PRESENT	0
271717	270566	19679N	PARTICIPANT	\N	PRESENT	0
271718	270566	14042U	PARTICIPANT	\N	PRESENT	0
271719	270566	14213J	PARTICIPANT	\N	PRESENT	0
271720	270566	14217N	PARTICIPANT	\N	PRESENT	0
271721	270566	19335Q	PARTICIPANT	\N	PRESENT	0
271722	270566	19683J	PARTICIPANT	\N	PRESENT	0
271723	270566	98024R	PARTICIPANT	\N	PRESENT	0
271724	270566	19521Q	PARTICIPANT	\N	PRESENT	0
271725	270566	01034P	PARTICIPANT	\N	PRESENT	0
271726	270566	04092N	PARTICIPANT	\N	PRESENT	0
271727	270566	08052W	PARTICIPANT	\N	PRESENT	0
271728	270566	19663E	PARTICIPANT	\N	PRESENT	0
271729	270566	19715Y	PARTICIPANT	\N	PRESENT	0
271730	270566	19691J	PARTICIPANT	\N	PRESENT	0
271731	270566	11103C	PARTICIPANT	\N	PRESENT	0
271732	270566	14071N	PARTICIPANT	\N	PRESENT	0
271733	270566	08048B	PARTICIPANT	\N	EXCUSE	0
271734	270395	17583W	PARTICIPANT	\N	PRESENT	0
271735	270395	14219Q	PARTICIPANT	\N	PRESENT	0
271736	270395	19637C	PARTICIPANT	\N	PRESENT	0
271737	270395	14191V	PARTICIPANT	\N	PRESENT	0
271738	270395	14169X	PARTICIPANT	\N	PRESENT	0
271739	270395	15447F	PARTICIPANT	\N	PRESENT	0
271740	270395	14093U	PARTICIPANT	\N	PRESENT	0
271741	270395	14029X	PARTICIPANT	\N	PRESENT	0
271742	270395	08009T	PRESIDENT	0	PRESENT	0
271743	270395	19737F	PARTICIPANT	\N	PRESENT	0
271744	270395	19739H	PARTICIPANT	\N	PRESENT	0
271745	270395	19745F	PARTICIPANT	\N	PRESENT	0
271746	270395	19713W	PARTICIPANT	\N	PRESENT	0
271747	270395	08060W	PARTICIPANT	\N	PRESENT	0
271748	270395	19347U	PARTICIPANT	\N	PRESENT	0
271749	270395	19659J	PARTICIPANT	\N	PRESENT	0
271750	270395	19525U	PARTICIPANT	\N	PRESENT	0
271751	270395	14031R	PARTICIPANT	\N	PRESENT	0
271752	270395	19383Y	PARTICIPANT	\N	PRESENT	0
271753	270395	08055A	PARTICIPANT	\N	PRESENT	0
271754	270525	04035D	PARTICIPANT	\N	PRESENT	0
271755	270395	19503N	PARTICIPANT	\N	PRESENT	0
271756	270395	98023Q	PARTICIPANT	\N	PRESENT	0
271757	270395	95062K	PARTICIPANT	\N	PRESENT	0
271758	270395	18083K	PARTICIPANT	\N	PRESENT	0
271759	270566	14119M	PARTICIPANT	\N	PRESENT	0
271760	270395	05012A	PARTICIPANT	\N	PRESENT	0
271761	270395	14157T	PARTICIPANT	\N	PRESENT	0
271762	270525	14105F	PARTICIPANT	\N	PRESENT	0
271763	270395	14103D	PARTICIPANT	\N	PRESENT	0
271764	270525	98050T	PARTICIPANT	\N	PRESENT	0
271765	270566	04045F	PARTICIPANT	\N	PRESENT	0
271766	270566	19527W	PARTICIPANT	\N	PRESENT	0
271767	270566	19723Y	PARTICIPANT	\N	PRESENT	0
271768	270525	14097Y	PARTICIPANT	\N	PRESENT	0
271769	270566	19575F	PARTICIPANT	\N	PRESENT	0
271770	270395	19333N	PARTICIPANT	\N	PRESENT	0
271771	270395	19549D	PARTICIPANT	\N	PRESENT	0
271772	270395	19551W	PARTICIPANT	\N	PRESENT	0
271773	270395	14051J	PARTICIPANT	\N	PRESENT	0
271774	270395	08024S	PARTICIPANT	\N	PRESENT	0
271775	270395	17637T	PARTICIPANT	\N	PRESENT	0
271776	270395	19733B	PARTICIPANT	\N	PRESENT	0
271777	270395	96004D	PARTICIPANT	\N	PRESENT	0
271778	270395	14038Y	PARTICIPANT	\N	PRESENT	0
271779	270525	11115U	PARTICIPANT	\N	PRESENT	0
271780	270566	14195A	PARTICIPANT	\N	PRESENT	0
271781	271641	04070G	PRESIDENT	0	PRESENT	0
271782	271641	19699S	PARTICIPANT	\N	PRESENT	0
271783	271641	14229S	PARTICIPANT	\N	PRESENT	0
271784	271641	14241N	PARTICIPANT	\N	PRESENT	0
271785	271641	14107H	PARTICIPANT	\N	PRESENT	0
271786	271641	08012N	PARTICIPANT	\N	PRESENT	0
271787	271641	08031R	PARTICIPANT	\N	PRESENT	0
271788	271641	19593H	PARTICIPANT	\N	PRESENT	0
271789	271641	14073Q	PARTICIPANT	\N	PRESENT	0
271790	271641	08035V	PARTICIPANT	\N	PRESENT	0
271791	271641	08043V	PARTICIPANT	\N	PRESENT	0
271792	271641	87003B	PARTICIPANT	\N	PRESENT	0
271793	271641	19399H	PARTICIPANT	\N	PRESENT	0
271794	271641	14030Q	PARTICIPANT	\N	PRESENT	0
271795	271641	19731Y	PARTICIPANT	\N	PRESENT	0
271796	271641	08020N	PARTICIPANT	\N	PRESENT	0
271797	271641	04059M	PARTICIPANT	\N	PRESENT	0
271798	271641	11109J	PARTICIPANT	\N	PRESENT	0
271799	271641	14063N	PARTICIPANT	\N	PRESENT	0
271800	271641	14109K	PARTICIPANT	\N	PRESENT	0
271801	271641	11083R	PARTICIPANT	\N	PRESENT	0
271802	271641	11104D	PARTICIPANT	\N	PRESENT	0
271803	271641	19749K	PARTICIPANT	\N	PRESENT	0
271804	271641	04018C	PARTICIPANT	\N	PRESENT	0
271805	271641	19621T	PARTICIPANT	\N	PRESENT	0
271806	271641	14061L	PARTICIPANT	\N	EXCUSE	0
271807	270395	02002K	PARTICIPANT	\N	PRESENT	0
271808	270525	95067Q	PARTICIPANT	\N	PRESENT	0
271809	270525	01058X	PARTICIPANT	\N	PRESENT	0
271810	270566	19569H	PARTICIPANT	\N	PRESENT	0
271811	271641	08017T	PARTICIPANT	\N	PRESENT	0
271812	271641	07033P	PARTICIPANT	\N	PRESENT	0
271813	271641	14059S	PARTICIPANT	\N	PRESENT	0
271814	271641	04057K	PARTICIPANT	\N	PRESENT	0
271815	271641	19735D	PARTICIPANT	\N	PRESENT	0
271816	271641	11043H	PARTICIPANT	\N	PRESENT	0
271817	270566	11077T	PARTICIPANT	\N	PRESENT	0
271818	271641	14039A	PARTICIPANT	\N	PRESENT	0
271819	271641	08016S	PARTICIPANT	\N	PRESENT	0
271820	271641	19693L	PARTICIPANT	\N	PRESENT	0
271821	270525	08056B	PARTICIPANT	\N	PRESENT	0
271822	270525	11041F	PARTICIPANT	\N	PRESENT	0
271823	271641	14123H	PARTICIPANT	\N	PRESENT	0
271824	270396	14103D	PARTICIPANT	\N	PRESENT	0
271825	270396	19713W	PARTICIPANT	\N	PRESENT	0
271826	270396	19549D	PARTICIPANT	\N	PRESENT	0
271827	270396	14219Q	PARTICIPANT	\N	PRESENT	0
271828	270396	08055A	PARTICIPANT	\N	PRESENT	0
271829	270396	19637C	PARTICIPANT	\N	PRESENT	0
271830	270396	02002K	PARTICIPANT	\N	PRESENT	0
271831	270396	14093U	PARTICIPANT	\N	PRESENT	0
271832	270396	14051J	PARTICIPANT	\N	PRESENT	0
271833	270396	08060W	PARTICIPANT	\N	PRESENT	0
271834	270396	19733B	PARTICIPANT	\N	PRESENT	0
271835	270396	08009T	PRESIDENT	0	PRESENT	0
271837	270396	19347U	PARTICIPANT	\N	PRESENT	0
271838	270396	19737F	PARTICIPANT	\N	PRESENT	0
271839	270396	19503N	PARTICIPANT	\N	PRESENT	0
271840	270396	19739H	PARTICIPANT	\N	PRESENT	0
271841	270396	19745F	PARTICIPANT	\N	PRESENT	0
271842	270396	14157T	PARTICIPANT	\N	PRESENT	0
271843	270396	19659J	PARTICIPANT	\N	PRESENT	0
271844	270396	19681G	PARTICIPANT	\N	PRESENT	0
271845	270396	08024S	PARTICIPANT	\N	PRESENT	0
271846	270396	11065P	PARTICIPANT	\N	PRESENT	0
271848	270396	19701S	PARTICIPANT	\N	EXCUSE	0
271849	270396	19685L	PARTICIPANT	\N	EXCUSE	0
271850	270396	19333N	PARTICIPANT	\N	PRESENT	0
271851	270396	19551W	PARTICIPANT	\N	PRESENT	0
271852	270396	80027E	PARTICIPANT	\N	EXCUSE	0
271853	270396	95062K	PARTICIPANT	\N	PRESENT	0
271854	270396	18083K	PARTICIPANT	\N	PRESENT	0
271855	270396	05012A	PARTICIPANT	\N	PRESENT	0
271856	270396	14031R	PARTICIPANT	\N	PRESENT	0
271857	270396	15447F	PARTICIPANT	\N	PRESENT	0
271858	270396	14029X	PARTICIPANT	\N	PRESENT	0
271875	270643	14041T	PARTICIPANT	\N	PRESENT	0
271860	270396	19383Y	PARTICIPANT	\N	PRESENT	0
271861	270396	14038Y	PARTICIPANT	\N	PRESENT	0
271862	270396	14191V	PARTICIPANT	\N	PRESENT	0
271863	270396	04097T	PARTICIPANT	\N	PRESENT	0
271865	270643	14001X	PARTICIPANT	\N	PRESENT	0
271866	270643	19581D	PARTICIPANT	\N	PRESENT	0
271867	270643	19585H	PARTICIPANT	\N	PRESENT	0
271868	270643	04047H	PARTICIPANT	\N	PRESENT	0
271869	270643	19673G	PARTICIPANT	\N	PRESENT	0
271870	270643	01028R	PARTICIPANT	\N	PRESENT	0
271871	270643	05008E	PRESIDENT	0	PRESENT	0
271872	270643	14231L	PARTICIPANT	\N	PRESENT	0
271873	270643	19447X	PARTICIPANT	\N	PRESENT	0
271874	270643	19489J	PARTICIPANT	\N	PRESENT	0
271911	271910	98029W	PARTICIPANT	\N	PRESENT	0
271912	271910	08056B	PARTICIPANT	\N	PRESENT	0
271913	271910	98022P	PARTICIPANT	\N	PRESENT	0
271914	271910	11026G	PARTICIPANT	\N	PRESENT	0
271915	271910	08010L	PARTICIPANT	\N	PRESENT	0
271917	271910	98050T	PARTICIPANT	\N	PRESENT	0
271918	271910	19421M	PARTICIPANT	\N	PRESENT	0
271919	271910	19575F	PARTICIPANT	\N	EXCUSE	0
271920	271910	19611R	PARTICIPANT	\N	EXCUSE	0
271921	271910	04008A	PARTICIPANT	\N	EXCUSE	0
275097	274412	14239U	PARTICIPANT	\N	PRESENT	0
275098	274412	14041T	PARTICIPANT	\N	PRESENT	0
275099	274412	14217N	PARTICIPANT	\N	PRESENT	0
275100	274412	19577H	PARTICIPANT	\N	PRESENT	0
279269	278438	19647E	PARTICIPANT	\N	EXCUSE	0
275102	274412	19697Q	PARTICIPANT	\N	PRESENT	0
275103	274412	14147R	PARTICIPANT	\N	PRESENT	0
275104	274412	04044E	PARTICIPANT	\N	PRESENT	0
275113	275112	89017R	PARTICIPANT	\N	PRESENT	0
275114	275112	04085P	PARTICIPANT	\N	PRESENT	0
275115	275112	05008E	PARTICIPANT	\N	PRESENT	0
275116	275112	96004D	PARTICIPANT	\N	PRESENT	0
275117	275112	11053K	PARTICIPANT	\N	PRESENT	0
275118	275112	04086Q	PARTICIPANT	\N	PRESENT	0
275119	275112	04071H	PARTICIPANT	\N	PRESENT	0
275120	275112	14034U	PARTICIPANT	\N	PRESENT	0
275121	275112	14021P	PARTICIPANT	\N	PRESENT	0
275122	275112	14251Q	PARTICIPANT	\N	PRESENT	0
275123	275112	11085T	PARTICIPANT	\N	PRESENT	0
275124	275112	08009T	PARTICIPANT	\N	PRESENT	0
275125	275112	04092N	PARTICIPANT	\N	PRESENT	0
275126	275112	11072N	PARTICIPANT	\N	PRESENT	0
275127	275112	04070G	PARTICIPANT	\N	PRESENT	0
275128	275112	14071N	PARTICIPANT	\N	PRESENT	0
275129	275112	08061X	PARTICIPANT	\N	PRESENT	0
275130	275112	98018T	PARTICIPANT	\N	PRESENT	0
275131	275112	11090Q	PARTICIPANT	\N	PRESENT	0
275132	275112	11012A	PARTICIPANT	\N	PRESENT	0
275133	275112	01034P	PARTICIPANT	\N	PRESENT	0
279249	278438	08062Y	PARTICIPANT	\N	PRESENT	0
284315	281722	19553Y	PARTICIPANT	\N	PRESENT	0
284316	281722	11103C	PARTICIPANT	\N	PRESENT	0
284317	281722	14195A	PARTICIPANT	\N	PRESENT	0
284318	281722	19367Y	PARTICIPANT	\N	PRESENT	0
284319	281722	14261S	PARTICIPANT	\N	PRESENT	0
284320	281722	10006L	PARTICIPANT	\N	PRESENT	0
284321	281722	19683J	PARTICIPANT	\N	PRESENT	0
284329	284080	04070G	PRESIDENT	0	PRESENT	0
284330	284080	19533U	PARTICIPANT	\N	PRESENT	0
284331	284080	95015C	PARTICIPANT	\N	PRESENT	0
284332	284080	14229S	PARTICIPANT	\N	PRESENT	0
284333	284080	14241N	PARTICIPANT	\N	PRESENT	0
284334	284080	19573D	PARTICIPANT	\N	PRESENT	0
284335	284080	14039A	PARTICIPANT	\N	PRESENT	0
284336	284080	14107H	PARTICIPANT	\N	PRESENT	0
284337	284080	07033P	PARTICIPANT	\N	PRESENT	0
284338	284080	08012N	PARTICIPANT	\N	PRESENT	0
284339	284080	14249W	PARTICIPANT	\N	PRESENT	0
284340	284080	08039A	PARTICIPANT	\N	PRESENT	0
284341	284080	08031R	PARTICIPANT	\N	PRESENT	0
284342	284080	19593H	PARTICIPANT	\N	PRESENT	0
284343	284080	19643A	PARTICIPANT	\N	PRESENT	0
284344	284080	14061L	PARTICIPANT	\N	PRESENT	0
284345	284080	04057K	PARTICIPANT	\N	PRESENT	0
284346	284080	14073Q	PARTICIPANT	\N	PRESENT	0
284347	284080	19611R	PARTICIPANT	\N	PRESENT	0
284348	284080	08035V	PARTICIPANT	\N	PRESENT	0
284349	284080	08043V	PARTICIPANT	\N	PRESENT	0
284350	284080	19693L	PARTICIPANT	\N	PRESENT	0
284351	284080	87003B	PARTICIPANT	\N	PRESENT	0
284352	284080	19399H	PARTICIPANT	\N	PRESENT	0
284353	284080	14030Q	PARTICIPANT	\N	PRESENT	0
284354	284080	19731Y	PARTICIPANT	\N	PRESENT	0
284355	284080	14251Q	PARTICIPANT	\N	PRESENT	0
284356	284080	04059M	PARTICIPANT	\N	PRESENT	0
284357	284080	19735D	PARTICIPANT	\N	PRESENT	0
284358	284080	14063N	PARTICIPANT	\N	PRESENT	0
284359	284080	14123H	PARTICIPANT	\N	PRESENT	0
284360	284080	11043H	PARTICIPANT	\N	PRESENT	0
284361	284080	11104D	PARTICIPANT	\N	PRESENT	0
284362	284080	19749K	PARTICIPANT	\N	PRESENT	0
284363	284080	04018C	PARTICIPANT	\N	PRESENT	0
284364	284080	19758L	PARTICIPANT	\N	PRESENT	0
284365	284080	14059S	PARTICIPANT	\N	EXCUSE	0
284366	284080	11083R	PARTICIPANT	\N	EXCUSE	0
284367	284080	08016S	PARTICIPANT	\N	EXCUSE	0
284368	281722	11067R	PARTICIPANT	\N	PRESENT	0
284369	281722	04045F	PARTICIPANT	\N	PRESENT	0
284370	281722	14227Q	PARTICIPANT	\N	PRESENT	0
284371	281722	19703U	PARTICIPANT	\N	PRESENT	0
284372	281722	14281W	PARTICIPANT	\N	PRESENT	0
284373	281722	98024R	PARTICIPANT	\N	PRESENT	0
284374	281722	19527W	PARTICIPANT	\N	PRESENT	0
284375	281722	08052W	PARTICIPANT	\N	PRESENT	0
284376	281722	19691J	PARTICIPANT	\N	PRESENT	0
284377	281722	14223L	PARTICIPANT	\N	PRESENT	0
284378	281722	14087W	PARTICIPANT	\N	PRESENT	0
284379	281722	19575F	PARTICIPANT	\N	PRESENT	0
284380	281722	14217N	PARTICIPANT	\N	PRESENT	0
284381	281722	19727D	PARTICIPANT	\N	PRESENT	0
284382	281722	14119M	PARTICIPANT	\N	PRESENT	0
284383	281722	19657G	PARTICIPANT	\N	PRESENT	0
284384	281722	14026U	PARTICIPANT	\N	PRESENT	0
284385	281722	19679N	PARTICIPANT	\N	PRESENT	0
284386	281722	19521Q	PARTICIPANT	\N	PRESENT	0
284387	281722	19723Y	PARTICIPANT	\N	PRESENT	0
284998	273898	19611R	PARTICIPANT	\N	PRESENT	0
285003	273898	19533U	PARTICIPANT	\N	PRESENT	0
285007	273898	05008E	PARTICIPANT	\N	PRESENT	0
290056	289756	14329V	PARTICIPANT	\N	PRESENT	0
290058	289756	19467C	PARTICIPANT	\N	PRESENT	0
290060	289756	18083K	PARTICIPANT	\N	PRESENT	0
290061	289756	19729F	PARTICIPANT	\N	PRESENT	0
290062	289756	14357A	PARTICIPANT	\N	PRESENT	0
290063	289756	04086Q	PARTICIPANT	\N	PRESENT	0
290064	289756	14259Y	PARTICIPANT	\N	PRESENT	0
290065	289756	04071H	PARTICIPANT	\N	PRESENT	0
290066	289756	14195A	PARTICIPANT	\N	PRESENT	0
290067	289756	14169X	PARTICIPANT	\N	PRESENT	0
290068	289756	19675J	PARTICIPANT	\N	PRESENT	0
290069	289756	14041T	PARTICIPANT	\N	PRESENT	0
290070	289756	19507S	PARTICIPANT	\N	PRESENT	0
290071	289756	14213J	PARTICIPANT	\N	PRESENT	0
290057	289756	14038Y	PARTICIPANT	\N	PRESENT	0
290072	289756	14265W	PARTICIPANT	\N	PRESENT	0
290073	289756	14063N	PARTICIPANT	\N	PRESENT	0
290074	289756	19399H	PARTICIPANT	\N	PRESENT	0
290075	289756	08019V	PARTICIPANT	\N	PRESENT	0
290076	289756	04008A	PARTICIPANT	\N	PRESENT	0
290077	289756	14033T	PARTICIPANT	\N	PRESENT	0
290078	289756	11109J	PARTICIPANT	\N	PRESENT	0
290079	289756	08018U	PARTICIPANT	\N	PRESENT	0
290080	289756	14355X	PARTICIPANT	\N	PRESENT	0
290081	289756	19723Y	PARTICIPANT	\N	PRESENT	0
290082	289756	08015R	PARTICIPANT	\N	PRESENT	0
290083	289756	08069G	PARTICIPANT	\N	PRESENT	0
290084	289756	14061L	PARTICIPANT	\N	PRESENT	0
290085	289756	07029T	PARTICIPANT	\N	PRESENT	0
290086	289756	19733B	PARTICIPANT	\N	PRESENT	0
290087	289756	14059S	PARTICIPANT	\N	PRESENT	0
290088	289756	12016W	PARTICIPANT	\N	PRESENT	0
290089	289756	04088S	PARTICIPANT	\N	PRESENT	0
290091	289756	01048V	PARTICIPANT	\N	PRESENT	0
290092	289756	19663E	PARTICIPANT	\N	PRESENT	0
290093	289756	14119M	PARTICIPANT	\N	PRESENT	0
290094	289756	14253S	PARTICIPANT	\N	PRESENT	0
290095	289756	05012A	PARTICIPANT	\N	PRESENT	0
290096	289756	98050T	PARTICIPANT	\N	PRESENT	0
290098	289756	08035V	PARTICIPANT	\N	PRESENT	0
290099	289756	04043D	PARTICIPANT	\N	PRESENT	0
290100	289756	19619A	PARTICIPANT	\N	PRESENT	0
290101	289756	14219Q	PARTICIPANT	\N	PRESENT	0
290102	289756	14135M	PARTICIPANT	\N	PRESENT	0
290103	289756	19705W	PARTICIPANT	\N	PRESENT	0
290104	289756	19421M	PARTICIPANT	\N	PRESENT	0
290105	289756	11043H	PARTICIPANT	\N	PRESENT	0
290106	289756	11090Q	PARTICIPANT	\N	PRESENT	0
290107	289756	19749K	PARTICIPANT	\N	PRESENT	0
290108	289756	01034P	PARTICIPANT	\N	PRESENT	0
290109	289756	19739H	PARTICIPANT	\N	PRESENT	0
290110	289756	14089Y	PARTICIPANT	\N	PRESENT	0
290111	289756	04034C	PARTICIPANT	\N	PRESENT	0
290112	289756	14083S	PARTICIPANT	\N	PRESENT	0
290113	289756	01025N	PARTICIPANT	\N	PRESENT	0
290114	289756	08011M	PARTICIPANT	\N	PRESENT	0
290115	289756	95067Q	PARTICIPANT	\N	PRESENT	0
290156	273523	19621T	PARTICIPANT	\N	PRESENT	0
290157	273523	08031R	PARTICIPANT	\N	PRESENT	0
290457	284976	19621T	PARTICIPANT	\N	PRESENT	0
290518	290517	19611R	PARTICIPANT	\N	PRESENT	0
290540	284980	19611R	PARTICIPANT	\N	PRESENT	0
290557	284988	19611R	PARTICIPANT	\N	PRESENT	0
293391	293125	04086Q	PARTICIPANT	\N	PRESENT	0
293392	293125	11090Q	PARTICIPANT	\N	PRESENT	0
293393	293125	14205J	PARTICIPANT	\N	PRESENT	0
293394	293125	19413M	PARTICIPANT	\N	PRESENT	0
293395	293125	08060W	PARTICIPANT	\N	PRESENT	0
293396	293125	14207L	PARTICIPANT	\N	PRESENT	0
293397	293125	14221J	PARTICIPANT	\N	PRESENT	0
293398	293125	08019V	PARTICIPANT	\N	PRESENT	0
293399	293125	19507S	PARTICIPANT	\N	PRESENT	0
293400	293125	98050T	PARTICIPANT	\N	PRESENT	0
293401	293125	19695N	PARTICIPANT	\N	PRESENT	0
293402	293125	14329V	PARTICIPANT	\N	PRESENT	0
293403	293125	07004J	PARTICIPANT	\N	PRESENT	0
293404	293125	01048V	PARTICIPANT	\N	PRESENT	0
293405	293125	11097X	PARTICIPANT	\N	PRESENT	0
293406	293125	04085P	PARTICIPANT	\N	PRESENT	0
293407	293125	11099A	PARTICIPANT	\N	PRESENT	0
293408	293125	19441R	PARTICIPANT	\N	PRESENT	0
293409	293125	14257W	PARTICIPANT	\N	PRESENT	0
293410	293125	14327T	PARTICIPANT	\N	PRESENT	0
293411	293125	19347U	PARTICIPANT	\N	PRESENT	0
293412	293125	14265W	PARTICIPANT	\N	PRESENT	0
293413	293125	19711U	PARTICIPANT	\N	PRESENT	0
293414	293125	14217N	PARTICIPANT	\N	PRESENT	0
293415	293125	19657G	PARTICIPANT	\N	PRESENT	0
293416	293125	14357A	PARTICIPANT	\N	PRESENT	0
293417	293125	04043D	PARTICIPANT	\N	PRESENT	0
293418	293125	04088S	PARTICIPANT	\N	PRESENT	0
293419	293125	19301E	PARTICIPANT	\N	PRESENT	0
293420	293125	14093U	PARTICIPANT	\N	PRESENT	0
293421	293125	08069G	PARTICIPANT	\N	PRESENT	0
293422	293125	11064N	PARTICIPANT	\N	PRESENT	0
293423	293125	14033T	PARTICIPANT	\N	PRESENT	0
293424	293125	08061X	PARTICIPANT	\N	PRESENT	0
293425	293125	19563B	PARTICIPANT	\N	PRESENT	0
293426	293125	14169X	PARTICIPANT	\N	PRESENT	0
293427	293125	14030Q	PARTICIPANT	\N	PRESENT	0
293428	293125	05008E	PARTICIPANT	\N	PRESENT	0
293429	293125	08016S	PARTICIPANT	\N	PRESENT	0
293430	293125	19253P	PARTICIPANT	\N	PRESENT	0
293431	293125	19699S	PARTICIPANT	\N	PRESENT	0
293432	293125	19693L	PARTICIPANT	\N	PRESENT	0
293433	293125	19593H	PARTICIPANT	\N	PRESENT	0
293434	293125	19719D	PARTICIPANT	\N	PRESENT	0
293435	293125	14251Q	PARTICIPANT	\N	PRESENT	0
293436	293125	14115H	PARTICIPANT	\N	PRESENT	0
293437	293125	19739H	PARTICIPANT	\N	PRESENT	0
293440	293125	19581D	PARTICIPANT	\N	PRESENT	0
293443	293125	19705W	PARTICIPANT	\N	PRESENT	0
293448	293125	19503N	PARTICIPANT	\N	PRESENT	0
293449	293125	08009T	PARTICIPANT	\N	PRESENT	0
293450	293125	14083S	PARTICIPANT	\N	PRESENT	0
293451	293125	11083R	PARTICIPANT	\N	PRESENT	0
293452	293125	11056N	PARTICIPANT	\N	PRESENT	0
293453	293125	19643A	PARTICIPANT	\N	PRESENT	0
293456	293125	19349W	PARTICIPANT	\N	PRESENT	0
293457	293125	19269X	PARTICIPANT	\N	PRESENT	0
293459	293125	19749K	PARTICIPANT	\N	PRESENT	0
293470	293125	14135M	PARTICIPANT	\N	PRESENT	0
293471	293125	14219Q	PARTICIPANT	\N	PRESENT	0
293472	293125	14021P	PARTICIPANT	\N	PRESENT	0
293473	293125	14157T	PARTICIPANT	\N	PRESENT	0
293474	293125	14147R	PARTICIPANT	\N	PRESENT	0
293530	293126	08060W	PARTICIPANT	\N	PRESENT	0
293531	293126	19413M	PARTICIPANT	\N	PRESENT	0
293532	293126	11090Q	PARTICIPANT	\N	PRESENT	0
293533	293126	19695N	PARTICIPANT	\N	PRESENT	0
293534	293126	11056N	PARTICIPANT	\N	PRESENT	0
293535	293126	19749K	PARTICIPANT	\N	PRESENT	0
293536	293126	14327T	PARTICIPANT	\N	PRESENT	0
293537	293126	14357A	PARTICIPANT	\N	PRESENT	0
293538	293126	19447X	PARTICIPANT	\N	PRESENT	0
293539	293126	19443T	PARTICIPANT	\N	PRESENT	0
293540	293126	19507S	PARTICIPANT	\N	PRESENT	0
293541	293126	14115H	PARTICIPANT	\N	PRESENT	0
293542	293126	19503N	PARTICIPANT	\N	PRESENT	0
293543	293126	11097X	PARTICIPANT	\N	PRESENT	0
293544	293126	14265W	PARTICIPANT	\N	PRESENT	0
293545	293126	11099A	PARTICIPANT	\N	PRESENT	0
293546	293126	07034Q	PARTICIPANT	\N	PRESENT	0
293547	293126	11083R	PARTICIPANT	\N	PRESENT	0
293548	293126	19711U	PARTICIPANT	\N	PRESENT	0
293549	293126	19563B	PARTICIPANT	\N	PRESENT	0
293550	293126	19269X	PARTICIPANT	\N	PRESENT	0
293551	293126	14033T	PARTICIPANT	\N	PRESENT	0
293552	293126	14205J	PARTICIPANT	\N	PRESENT	0
293553	293126	14135M	PARTICIPANT	\N	PRESENT	0
293554	293126	19593H	PARTICIPANT	\N	PRESENT	0
293555	293126	19347U	PARTICIPANT	\N	PRESENT	0
293556	293126	14329V	PARTICIPANT	\N	PRESENT	0
293557	293126	19441R	PARTICIPANT	\N	PRESENT	0
293558	293126	08069G	PARTICIPANT	\N	PRESENT	0
293559	293126	14059S	PARTICIPANT	\N	PRESENT	0
293560	293126	19643A	PARTICIPANT	\N	PRESENT	0
293561	293126	14257W	PARTICIPANT	\N	PRESENT	0
293562	293126	04088S	PARTICIPANT	\N	PRESENT	0
293563	293126	16685X	PARTICIPANT	\N	PRESENT	0
293564	293126	14030Q	PARTICIPANT	\N	PRESENT	0
293565	293126	19657G	PARTICIPANT	\N	PRESENT	0
293566	293126	19739H	PARTICIPANT	\N	PRESENT	0
293567	293126	04033B	PARTICIPANT	\N	PRESENT	0
293568	293126	14231L	PARTICIPANT	\N	PRESENT	0
293569	293126	11012A	PARTICIPANT	\N	PRESENT	0
293570	293126	14083S	PARTICIPANT	\N	PRESENT	0
293571	293126	14219Q	PARTICIPANT	\N	PRESENT	0
293572	293126	01048V	PARTICIPANT	\N	PRESENT	0
293573	293126	19349W	PARTICIPANT	\N	PRESENT	0
293574	293126	11064N	PARTICIPANT	\N	PRESENT	0
293575	293126	07029T	PARTICIPANT	\N	PRESENT	0
293576	293126	14111D	PARTICIPANT	\N	PRESENT	0
293577	293126	95041E	PARTICIPANT	\N	PRESENT	0
293578	293126	14221J	PARTICIPANT	\N	PRESENT	0
293579	293126	08016S	PARTICIPANT	\N	PRESENT	0
293580	293126	19369B	PARTICIPANT	\N	PRESENT	0
293581	293126	14073Q	PARTICIPANT	\N	PRESENT	0
293582	293126	14197C	PARTICIPANT	\N	PRESENT	0
293528	293126	11070L	PARTICIPANT	\N	PRESENT	0
293529	293126	14207L	PARTICIPANT	\N	PRESENT	0
294589	294307	14229S	PARTICIPANT	\N	PRESENT	0
294587	294307	16685X	PARTICIPANT	\N	PRESENT	0
294588	294307	19745F	PARTICIPANT	\N	PRESENT	0
294590	294307	08015R	PARTICIPANT	\N	PRESENT	0
271905	271641	19533U	PARTICIPANT	\N	PRESENT	0
271906	271641	19573D	PARTICIPANT	\N	PRESENT	0
271907	271641	19611R	PARTICIPANT	\N	PRESENT	0
271908	271641	19643A	PARTICIPANT	\N	PRESENT	0
271909	271641	08039A	PARTICIPANT	\N	PRESENT	0
271916	271641	14251Q	PARTICIPANT	\N	PRESENT	0
271922	270525	19669L	PARTICIPANT	\N	PRESENT	0
272843	270530	19295A	PARTICIPANT	\N	PRESENT	0
272844	270530	95062K	PARTICIPANT	\N	PRESENT	0
272845	270530	19563B	PARTICIPANT	\N	PRESENT	0
272846	270530	11012A	PARTICIPANT	\N	PRESENT	0
272847	270530	14195A	PARTICIPANT	\N	PRESENT	0
272848	270530	14251Q	PARTICIPANT	\N	PRESENT	0
272849	270530	98024R	PARTICIPANT	\N	PRESENT	0
272850	270530	19553Y	PARTICIPANT	\N	PRESENT	0
272851	270530	05008E	PARTICIPANT	\N	PRESENT	0
272852	270530	19511N	PARTICIPANT	\N	PRESENT	0
272853	270530	04033B	PARTICIPANT	\N	PRESENT	0
272854	270530	01034P	PARTICIPANT	\N	PRESENT	0
272855	270530	14042U	PARTICIPANT	\N	PRESENT	0
272856	270530	01058X	PARTICIPANT	\N	PRESENT	0
272857	270530	14231L	PARTICIPANT	\N	PRESENT	0
272858	270530	19713W	PARTICIPANT	\N	PRESENT	0
272859	270530	14219Q	PARTICIPANT	\N	PRESENT	0
272860	270530	16685X	PARTICIPANT	\N	PRESENT	0
272861	270530	01048V	PARTICIPANT	\N	PRESENT	0
272862	270530	14089Y	PARTICIPANT	\N	PRESENT	0
272863	270530	95067Q	PARTICIPANT	\N	PRESENT	0
272864	270530	19735D	PARTICIPANT	\N	PRESENT	0
272865	270530	14073Q	PARTICIPANT	\N	PRESENT	0
272866	270530	14221J	PARTICIPANT	\N	PRESENT	0
272867	270530	14327T	PARTICIPANT	\N	PRESENT	0
272868	270530	19747H	PARTICIPANT	\N	PRESENT	0
272869	270530	14083S	PARTICIPANT	\N	PRESENT	0
272870	270530	19515S	PARTICIPANT	\N	PRESENT	0
272871	270530	19691J	PARTICIPANT	\N	PRESENT	0
272872	270530	01024M	PARTICIPANT	\N	PRESENT	0
272873	270530	19421M	PARTICIPANT	\N	PRESENT	0
272874	270530	19703U	PARTICIPANT	\N	PRESENT	0
272875	270530	14041T	PARTICIPANT	\N	PRESENT	0
272876	270530	19741B	PARTICIPANT	\N	PRESENT	0
272877	270530	04088S	PARTICIPANT	\N	PRESENT	0
272878	270530	14119M	PARTICIPANT	\N	PRESENT	0
272879	270530	14033T	PARTICIPANT	\N	PRESENT	0
272880	270530	19447X	PARTICIPANT	\N	PRESENT	0
272881	270530	19575F	PARTICIPANT	\N	PRESENT	0
272882	270530	19507S	PARTICIPANT	\N	PRESENT	0
272883	270530	19399H	PARTICIPANT	\N	PRESENT	0
272884	270530	08015R	PARTICIPANT	\N	PRESENT	0
272885	270530	14135M	PARTICIPANT	\N	PRESENT	0
272887	270530	19383Y	PARTICIPANT	\N	PRESENT	0
272888	270530	05012A	PARTICIPANT	\N	PRESENT	0
272889	270530	14105F	PARTICIPANT	\N	PRESENT	0
272890	270530	14115H	PARTICIPANT	\N	PRESENT	0
272891	270530	10006L	PARTICIPANT	\N	PRESENT	0
272892	270530	19533U	PARTICIPANT	\N	PRESENT	0
272893	270530	14147R	PARTICIPANT	\N	PRESENT	0
272894	270530	14357A	PARTICIPANT	\N	PRESENT	0
272895	270530	14329V	PARTICIPANT	\N	PRESENT	0
272896	270530	96004D	PARTICIPANT	\N	PRESENT	0
272897	270530	14331P	PARTICIPANT	\N	PRESENT	0
272898	270530	14187A	PARTICIPANT	\N	PRESENT	0
272899	270530	98050T	PARTICIPANT	\N	PRESENT	0
272900	270530	14071N	PARTICIPANT	\N	PRESENT	0
272901	270530	14217N	PARTICIPANT	\N	PRESENT	0
272902	270530	89017R	PARTICIPANT	\N	PRESENT	0
272903	270530	08069G	PARTICIPANT	\N	PRESENT	0
272904	270530	14265W	PARTICIPANT	\N	PRESENT	0
272905	270530	19621T	PARTICIPANT	\N	PRESENT	0
272906	270530	19335Q	PARTICIPANT	\N	PRESENT	0
272907	270530	14157T	PARTICIPANT	\N	PRESENT	0
272908	270530	08060W	PARTICIPANT	\N	PRESENT	0
272909	270530	14193X	PARTICIPANT	\N	PRESENT	0
272910	270530	19693L	PARTICIPANT	\N	PRESENT	0
272911	270530	08055A	PARTICIPANT	\N	PRESENT	0
272912	270530	19573D	PARTICIPANT	\N	PRESENT	0
272913	270530	19657G	PARTICIPANT	\N	PRESENT	0
272914	270530	14239U	PARTICIPANT	\N	PRESENT	0
272915	270530	14034U	PARTICIPANT	\N	PRESENT	0
272916	270530	19441R	PARTICIPANT	\N	PRESENT	0
272917	270530	17583W	PARTICIPANT	\N	PRESENT	0
272918	270530	11097X	PARTICIPANT	\N	PRESENT	0
272932	270530	14281W	PARTICIPANT	\N	PRESENT	0
272933	270530	19679N	PARTICIPANT	\N	PRESENT	0
272934	270530	14087W	PARTICIPANT	\N	PRESENT	0
272935	270530	07029T	PARTICIPANT	\N	PRESENT	0
273057	272936	14034U	PARTICIPANT	\N	PRESENT	0
273058	272936	04092N	PARTICIPANT	\N	PRESENT	0
273059	272936	11063M	PARTICIPANT	\N	PRESENT	0
273060	272936	04085P	PARTICIPANT	\N	PRESENT	0
273061	272936	11056N	PARTICIPANT	\N	PRESENT	0
273062	272936	11033F	PARTICIPANT	\N	PRESENT	0
273063	272936	19565D	PARTICIPANT	\N	PRESENT	0
273064	272936	11031D	PARTICIPANT	\N	PRESENT	0
273065	272936	12041X	PARTICIPANT	\N	PRESENT	0
273066	272936	19695N	PARTICIPANT	\N	PRESENT	0
273067	272936	14235Q	PARTICIPANT	\N	PRESENT	0
273068	272936	19687N	PARTICIPANT	\N	PRESENT	0
273069	272936	19593H	PARTICIPANT	\N	PRESENT	0
273070	272936	19715Y	PARTICIPANT	\N	PRESENT	0
273071	272936	80013X	PARTICIPANT	\N	PRESENT	0
273072	272936	14021P	PARTICIPANT	\N	PRESENT	0
273073	272936	14281W	PARTICIPANT	\N	PRESENT	0
273074	272936	19727D	PARTICIPANT	\N	PRESENT	0
273075	272936	19413M	PARTICIPANT	\N	PRESENT	0
273076	272936	11067R	PARTICIPANT	\N	PRESENT	0
273077	272936	19295A	PARTICIPANT	\N	PRESENT	0
273078	272936	19489J	PARTICIPANT	\N	PRESENT	0
273079	272936	17779H	PARTICIPANT	\N	PRESENT	0
273080	272936	14257W	PARTICIPANT	\N	PRESENT	0
273081	272936	14207L	PARTICIPANT	\N	PRESENT	0
273082	272936	08060W	PARTICIPANT	\N	PRESENT	0
273083	272936	08055A	PARTICIPANT	\N	PRESENT	0
273084	272936	14159V	PARTICIPANT	\N	PRESENT	0
273085	272936	14097Y	PARTICIPANT	\N	PRESENT	0
273086	272936	14195A	PARTICIPANT	\N	PRESENT	0
273087	272936	14251Q	PARTICIPANT	\N	PRESENT	0
273088	272936	19713W	PARTICIPANT	\N	PRESENT	0
273089	272936	14089Y	PARTICIPANT	\N	PRESENT	0
273090	272936	14042U	PARTICIPANT	\N	PRESENT	0
273091	272936	19521Q	PARTICIPANT	\N	PRESENT	0
273092	272936	14083S	PARTICIPANT	\N	PRESENT	0
273093	272936	14215L	PARTICIPANT	\N	PRESENT	0
273094	272936	14087W	PARTICIPANT	\N	PRESENT	0
273095	272936	14231L	PARTICIPANT	\N	PRESENT	0
273096	272936	11097X	PARTICIPANT	\N	PRESENT	0
273097	272936	19621T	PARTICIPANT	\N	PRESENT	0
273098	272936	19253P	PARTICIPANT	\N	PRESENT	0
273099	272936	08031R	PARTICIPANT	\N	PRESENT	0
273100	272936	11012A	PARTICIPANT	\N	PRESENT	0
273101	272936	19563B	PARTICIPANT	\N	PRESENT	0
273102	272936	19553Y	PARTICIPANT	\N	PRESENT	0
273103	272936	01024M	PARTICIPANT	\N	PRESENT	0
273104	272936	14331P	PARTICIPANT	\N	PRESENT	0
273105	272936	19747H	PARTICIPANT	\N	PRESENT	0
273106	272936	19383Y	PARTICIPANT	\N	PRESENT	0
273107	272936	14357A	PARTICIPANT	\N	PRESENT	0
273108	272936	14329V	PARTICIPANT	\N	PRESENT	0
273109	272936	14213J	PARTICIPANT	\N	PRESENT	0
273110	272936	14217N	PARTICIPANT	\N	PRESENT	0
273111	272936	05012A	PARTICIPANT	\N	PRESENT	0
273112	272936	14187A	PARTICIPANT	\N	PRESENT	0
273113	272936	98024R	PARTICIPANT	\N	PRESENT	0
273114	272936	08015R	PARTICIPANT	\N	PRESENT	0
273115	272936	14265W	PARTICIPANT	\N	PRESENT	0
273116	272936	14105F	PARTICIPANT	\N	PRESENT	0
273117	272936	14135M	PARTICIPANT	\N	PRESENT	0
273118	272936	07029T	PARTICIPANT	\N	PRESENT	0
273119	272936	19507S	PARTICIPANT	\N	PRESENT	0
273120	272936	04088S	PARTICIPANT	\N	PRESENT	0
273121	272936	14033T	PARTICIPANT	\N	PRESENT	0
273122	272936	19703U	PARTICIPANT	\N	PRESENT	0
273123	272936	19515S	PARTICIPANT	\N	PRESENT	0
273124	272936	14115H	PARTICIPANT	\N	PRESENT	0
273125	272936	19575F	PARTICIPANT	\N	PRESENT	0
273126	272936	19693L	PARTICIPANT	\N	PRESENT	0
273127	272936	19511N	PARTICIPANT	\N	PRESENT	0
273128	272936	11109J	PARTICIPANT	\N	PRESENT	0
273129	272936	19531S	PARTICIPANT	\N	PRESENT	0
273130	272936	19679N	PARTICIPANT	\N	PRESENT	0
273131	272936	04097T	PARTICIPANT	\N	PRESENT	0
273132	272936	19697Q	PARTICIPANT	\N	PRESENT	0
273133	272936	14327T	PARTICIPANT	\N	PRESENT	0
273134	272936	95063L	PARTICIPANT	\N	PRESENT	0
273135	272936	19335Q	PARTICIPANT	\N	PRESENT	0
273136	272936	04049K	PARTICIPANT	\N	PRESENT	0
273137	272936	04045F	PARTICIPANT	\N	PRESENT	0
273138	272936	08061X	PARTICIPANT	\N	PRESENT	0
271876	270643	14147R	PARTICIPANT	\N	PRESENT	0
271877	270643	14179A	PARTICIPANT	\N	PRESENT	0
271878	270643	14151M	PARTICIPANT	\N	PRESENT	0
271879	270643	14215L	PARTICIPANT	\N	PRESENT	0
271880	270643	08018U	PARTICIPANT	\N	PRESENT	0
271881	270643	14259Y	PARTICIPANT	\N	PRESENT	0
271882	270643	11072N	PARTICIPANT	\N	PRESENT	0
271883	270643	14053L	PARTICIPANT	\N	PRESENT	0
271884	270643	98035U	PARTICIPANT	\N	PRESENT	0
271885	270643	14111D	PARTICIPANT	\N	PRESENT	0
271886	270643	19649G	PARTICIPANT	\N	PRESENT	0
271887	270643	07034Q	PARTICIPANT	\N	PRESENT	0
271888	270643	08045X	PARTICIPANT	\N	PRESENT	0
271889	270643	11026G	PARTICIPANT	\N	PRESENT	0
271890	270643	19253P	PARTICIPANT	\N	PRESENT	0
271891	270643	01024M	PARTICIPANT	\N	PRESENT	0
271892	270643	04038G	PARTICIPANT	\N	PRESENT	0
271893	270643	19719D	PARTICIPANT	\N	PRESENT	0
271894	270643	11033F	PARTICIPANT	\N	PRESENT	0
271895	270643	19725B	PARTICIPANT	\N	PRESENT	0
271896	270643	19729F	PARTICIPANT	\N	PRESENT	0
271897	270643	95063L	PARTICIPANT	\N	PRESENT	0
271898	270643	19629C	PARTICIPANT	\N	PRESENT	0
271899	270643	14069U	PARTICIPANT	\N	PRESENT	0
271900	270643	11085T	PARTICIPANT	\N	PRESENT	0
271901	270643	11049P	PARTICIPANT	\N	PRESENT	0
271902	270643	04008A	PARTICIPANT	\N	PRESENT	0
271903	270643	14021P	PARTICIPANT	\N	PRESENT	0
271904	270643	14065Q	PARTICIPANT	\N	EXCUSE	0
275730	275729	14239U	PARTICIPANT	\N	PRESENT	0
275731	275729	19253P	PARTICIPANT	\N	PRESENT	0
275732	275729	14041T	PARTICIPANT	\N	PRESENT	0
275733	275729	19697Q	PARTICIPANT	\N	PRESENT	0
275734	275729	14147R	PARTICIPANT	\N	PRESENT	0
275735	275729	11045K	PRESIDENT	0	PRESENT	0
275736	275729	04044E	PARTICIPANT	\N	EXCUSE	0
275738	275729	19691J	PARTICIPANT	\N	PRESENT	0
292346	292345	96004D	PARTICIPANT	\N	PRESENT	0
292347	292345	04042C	PARTICIPANT	\N	PRESENT	0
292348	292345	14255U	PARTICIPANT	\N	PRESENT	0
292349	292345	98050T	PARTICIPANT	\N	PRESENT	0
292350	292345	04034C	PARTICIPANT	\N	PRESENT	0
292351	292345	14097Y	PARTICIPANT	\N	PRESENT	0
292352	292345	04035D	PARTICIPANT	\N	PRESENT	0
292353	292345	04061F	PARTICIPANT	\N	EXCUSE	0
292355	292354	11026G	PARTICIPANT	\N	PRESENT	0
292356	292354	10015M	PARTICIPANT	\N	PRESENT	0
292357	287933	14327T	PARTICIPANT	\N	EXCUSE	0
292358	287933	08049C	PARTICIPANT	\N	EXCUSE	0
293110	293109	19329S	PARTICIPANT	\N	EXCUSE	0
293111	293109	14059S	PARTICIPANT	\N	EXCUSE	0
293119	293118	19673G	PARTICIPANT	\N	PRESENT	0
293120	293118	95063L	PARTICIPANT	\N	PRESENT	0
293121	293118	01028R	PARTICIPANT	\N	PRESENT	0
293123	293122	19673G	PARTICIPANT	\N	PRESENT	0
293124	293122	95063L	PARTICIPANT	\N	PRESENT	0
293130	293129	96004D	PARTICIPANT	\N	PRESENT	0
293131	293129	19725B	PARTICIPANT	\N	PRESENT	0
293133	293132	96004D	PARTICIPANT	\N	PRESENT	0
300599	300445	80013X	PARTICIPANT	\N	PRESENT	0
300601	300445	14357A	PARTICIPANT	\N	EXCUSE	0
300602	300445	08052W	PRESIDENT	0	PRESENT	0
300604	300445	17589D	PARTICIPANT	\N	PRESENT	0
300605	300445	98024R	PARTICIPANT	\N	PRESENT	0
300606	300445	19727D	PARTICIPANT	\N	PRESENT	0
300607	300445	19553Y	PARTICIPANT	\N	PRESENT	0
300608	300445	14237S	PARTICIPANT	\N	PRESENT	0
300609	300445	19735D	PARTICIPANT	\N	PRESENT	0
300610	300445	95062K	PARTICIPANT	\N	PRESENT	0
300611	300445	19421M	PARTICIPANT	\N	PRESENT	0
300636	297573	14205J	PARTICIPANT	\N	PRESENT	0
300638	297574	14205J	PARTICIPANT	\N	PRESENT	0
300639	297576	14205J	PARTICIPANT	\N	PRESENT	0
300800	300799	04057K	PARTICIPANT	\N	PRESENT	0
300801	300799	11083R	PARTICIPANT	\N	PRESENT	0
300822	300821	04057K	PARTICIPANT	\N	PRESENT	0
300823	300821	11083R	PARTICIPANT	\N	PRESENT	0
301853	301832	05008E	PRESIDENT	0	PRESENT	0
301854	301832	14053L	PARTICIPANT	\N	PRESENT	0
301855	301832	19543W	PARTICIPANT	\N	PRESENT	0
301856	301832	11085T	PARTICIPANT	\N	PRESENT	0
301857	301832	19729F	PARTICIPANT	\N	EXCUSE	0
301858	301832	14111D	PARTICIPANT	\N	EXCUSE	0
301859	301832	19253P	PARTICIPANT	\N	EXCUSE	0
301860	301832	14215L	PARTICIPANT	\N	EXCUSE	0
301861	301832	14231L	PARTICIPANT	\N	EXCUSE	0
301862	301832	19762G	PARTICIPANT	\N	EXCUSE	0
301863	301835	19591F	PARTICIPANT	\N	PRESENT	0
301864	301835	04034C	PARTICIPANT	\N	PRESENT	0
301865	301835	19651A	PARTICIPANT	\N	PRESENT	0
301866	301835	19637C	PARTICIPANT	\N	PRESENT	0
301867	301835	19543W	PARTICIPANT	\N	PRESENT	0
301868	301835	19563B	PARTICIPANT	\N	PRESENT	0
301869	301835	19695N	PARTICIPANT	\N	PRESENT	0
301870	301835	11070L	PARTICIPANT	\N	PRESENT	0
301871	301835	11085T	PARTICIPANT	\N	PRESENT	0
301872	301835	19671E	PARTICIPANT	\N	PRESENT	0
301873	301835	14357A	PARTICIPANT	\N	PRESENT	0
301874	301835	04088S	PARTICIPANT	\N	PRESENT	0
301875	301835	14157T	PARTICIPANT	\N	PRESENT	0
301876	301835	19667J	PARTICIPANT	\N	PRESENT	0
301877	301835	19643A	PARTICIPANT	\N	PRESENT	0
301878	301835	11090Q	PARTICIPANT	\N	PRESENT	0
301879	301835	14038Y	PARTICIPANT	\N	PRESENT	0
301880	301835	19741B	PARTICIPANT	\N	PRESENT	0
301881	301835	19705W	PARTICIPANT	\N	PRESENT	0
301882	301835	14053L	PARTICIPANT	\N	PRESENT	0
301883	301835	19421M	PARTICIPANT	\N	PRESENT	0
301884	301835	19573D	PARTICIPANT	\N	PRESENT	0
301885	301835	19663E	PARTICIPANT	\N	PRESENT	0
301886	301835	11054L	PARTICIPANT	\N	PRESENT	0
301887	301835	11099A	PARTICIPANT	\N	PRESENT	0
301888	301835	19383Y	PARTICIPANT	\N	PRESENT	0
301889	301835	08016S	PARTICIPANT	\N	PRESENT	0
301890	301835	04043D	PARTICIPANT	\N	PRESENT	0
301891	301835	14187A	PARTICIPANT	\N	PRESENT	0
301892	301835	14265W	PARTICIPANT	\N	PRESENT	0
301893	301835	02002K	PARTICIPANT	\N	PRESENT	0
301894	301835	19647E	PARTICIPANT	\N	PRESENT	0
301895	301835	14041T	PARTICIPANT	\N	PRESENT	0
301896	301835	19629C	PARTICIPANT	\N	PRESENT	0
301897	301835	08038Y	PARTICIPANT	\N	PRESENT	0
301898	301835	11033F	PARTICIPANT	\N	PRESENT	0
301900	301899	01028R	PARTICIPANT	\N	PRESENT	0
301901	301899	07034Q	PARTICIPANT	\N	PRESENT	0
301902	301899	19729F	PARTICIPANT	\N	PRESENT	0
301903	301899	11072N	PARTICIPANT	\N	PRESENT	0
301904	301899	04044E	PARTICIPANT	\N	PRESENT	0
301905	301899	11026G	PARTICIPANT	\N	PRESENT	0
301906	301835	19687N	PARTICIPANT	\N	PRESENT	0
301907	301835	19549D	PARTICIPANT	\N	PRESENT	0
301910	301835	19649G	PARTICIPANT	\N	PRESENT	0
301911	301835	99004R	PARTICIPANT	\N	PRESENT	0
301912	301835	11109J	PARTICIPANT	\N	PRESENT	0
301913	301835	08068F	PARTICIPANT	\N	PRESENT	0
301914	301835	19701S	PARTICIPANT	\N	PRESENT	0
301915	301835	11053K	PARTICIPANT	\N	PRESENT	0
301916	301835	01043Q	PARTICIPANT	\N	PRESENT	0
301917	301835	14217N	PARTICIPANT	\N	PRESENT	0
301969	301918	04059M	PARTICIPANT	\N	PRESENT	0
301970	301918	14147R	PARTICIPANT	\N	PRESENT	0
301971	301918	14265W	PARTICIPANT	\N	PRESENT	0
301972	301918	19383Y	PARTICIPANT	\N	PRESENT	0
301973	301918	19669L	PARTICIPANT	\N	PRESENT	0
301974	301918	11074Q	PARTICIPANT	\N	PRESENT	0
301975	301918	14227Q	PARTICIPANT	\N	PRESENT	0
301976	301918	14041T	PARTICIPANT	\N	PRESENT	0
301977	301918	14357A	PARTICIPANT	\N	PRESENT	0
301978	301918	99004R	PARTICIPANT	\N	PRESENT	0
301979	301918	04008A	PARTICIPANT	\N	PRESENT	0
301980	301918	14207L	PARTICIPANT	\N	PRESENT	0
301981	301918	14215L	PARTICIPANT	\N	PRESENT	0
301982	301918	19301E	PARTICIPANT	\N	PRESENT	0
301983	301918	19747H	PARTICIPANT	\N	PRESENT	0
301984	301918	14331P	PARTICIPANT	\N	PRESENT	0
301985	301918	19515S	PARTICIPANT	\N	PRESENT	0
301986	301918	11056N	PARTICIPANT	\N	PRESENT	0
301987	301918	19611R	PARTICIPANT	\N	PRESENT	0
301988	301918	11033F	PARTICIPANT	\N	PRESENT	0
301989	301918	08017T	PARTICIPANT	\N	PRESENT	0
301990	301918	11099A	PARTICIPANT	\N	PRESENT	0
301991	301918	19705W	PARTICIPANT	\N	PRESENT	0
301992	301918	08019V	PARTICIPANT	\N	PRESENT	0
301993	301918	19667J	PARTICIPANT	\N	PRESENT	0
301994	301918	19593H	PARTICIPANT	\N	PRESENT	0
301995	301918	04018C	PARTICIPANT	\N	PRESENT	0
301996	301918	14021P	PARTICIPANT	\N	PRESENT	0
301997	301918	19695N	PARTICIPANT	\N	PRESENT	0
301998	301918	19565D	PARTICIPANT	\N	PRESENT	0
285982	285981	19531S	PARTICIPANT	\N	PRESENT	0
285986	285985	19647E	PARTICIPANT	\N	PRESENT	0
285987	285985	11070L	PARTICIPANT	\N	PRESENT	0
290686	290672	04018C	PARTICIPANT	\N	PRESENT	0
290127	289578	08028W	PARTICIPANT	\N	EXCUSE	0
290675	290672	04070G	PARTICIPANT	\N	PRESENT	0
290688	290672	19693L	PARTICIPANT	\N	PRESENT	0
290690	290672	19699S	PARTICIPANT	\N	PRESENT	0
290693	290672	19643A	PARTICIPANT	\N	PRESENT	0
290694	290672	92040Q	PARTICIPANT	\N	PRESENT	0
290696	290672	95015C	PARTICIPANT	\N	PRESENT	0
290699	290672	19329S	PARTICIPANT	\N	PRESENT	0
290702	290672	19611R	PARTICIPANT	\N	PRESENT	0
291339	287619	19697Q	PARTICIPANT	\N	PRESENT	0
291340	287619	11067R	PARTICIPANT	\N	PRESENT	0
291341	287619	14355X	PARTICIPANT	\N	PRESENT	0
291342	287619	19569H	PARTICIPANT	\N	PRESENT	0
285979	285978	19647E	PARTICIPANT	\N	PRESENT	0
285980	285978	11070L	PARTICIPANT	\N	PRESENT	0
291343	287619	11097X	PARTICIPANT	\N	PRESENT	0
291344	287619	19415P	PARTICIPANT	\N	PRESENT	0
291345	287619	04045F	PARTICIPANT	\N	PRESENT	0
291346	287619	14227Q	PARTICIPANT	\N	PRESENT	0
291347	287619	19675J	PARTICIPANT	\N	PRESENT	0
291348	287619	11063M	PARTICIPANT	\N	PRESENT	0
291349	287619	17779H	PARTICIPANT	\N	PRESENT	0
291350	287619	19703U	PARTICIPANT	\N	PRESENT	0
291351	287619	14239U	PARTICIPANT	\N	PRESENT	0
291352	287619	19553Y	PARTICIPANT	\N	PRESENT	0
291353	287619	11031D	PARTICIPANT	\N	PRESENT	0
291354	287619	14087W	PARTICIPANT	\N	PRESENT	0
291355	287619	19679N	PARTICIPANT	\N	PRESENT	0
291356	287619	14042U	PARTICIPANT	\N	PRESENT	0
291357	287619	19575F	PARTICIPANT	\N	PRESENT	0
291358	287619	14195A	PARTICIPANT	\N	PRESENT	0
291359	287619	19367Y	PARTICIPANT	\N	PRESENT	0
291360	287619	14213J	PARTICIPANT	\N	PRESENT	0
291361	287619	14261S	PARTICIPANT	\N	PRESENT	0
291362	287619	14217N	PARTICIPANT	\N	PRESENT	0
291363	287619	19335Q	PARTICIPANT	\N	PRESENT	0
291364	287619	19683J	PARTICIPANT	\N	PRESENT	0
291365	287619	98024R	PARTICIPANT	\N	PRESENT	0
291366	287619	19521Q	PARTICIPANT	\N	PRESENT	0
291367	287619	19527W	PARTICIPANT	\N	PRESENT	0
291368	287619	01034P	PARTICIPANT	\N	PRESENT	0
291369	287619	04092N	PRESIDENT	0	PRESENT	0
291370	287619	08052W	PARTICIPANT	\N	PRESENT	0
291371	287619	19663E	PARTICIPANT	\N	PRESENT	0
291372	287619	19691J	PARTICIPANT	\N	PRESENT	0
291373	287619	19723Y	PARTICIPANT	\N	PRESENT	0
291374	287619	19727D	PARTICIPANT	\N	PRESENT	0
291375	287619	14119M	PARTICIPANT	\N	PRESENT	0
291376	287619	11103C	PARTICIPANT	\N	PRESENT	0
291377	287619	14071N	PARTICIPANT	\N	PRESENT	0
291378	287619	19577H	PARTICIPANT	\N	PRESENT	0
291379	287619	08041T	PARTICIPANT	\N	EXCUSE	0
291380	287619	14026U	PARTICIPANT	\N	PRESENT	0
291381	287619	14281W	PARTICIPANT	\N	PRESENT	0
291382	287619	19611R	PARTICIPANT	\N	PRESENT	0
291523	288052	11027H	PARTICIPANT	\N	PRESENT	0
291525	291386	19681G	PARTICIPANT	\N	PRESENT	0
291526	288052	19721W	PARTICIPANT	\N	PRESENT	0
291549	291185	19533U	PARTICIPANT	\N	PRESENT	0
291550	291185	19611R	PARTICIPANT	\N	PRESENT	0
291551	291185	11109J	PARTICIPANT	\N	PRESENT	0
291552	291185	11043H	PARTICIPANT	\N	PRESENT	0
291553	291185	11083R	PARTICIPANT	\N	EXCUSE	0
291554	291395	14231L	PARTICIPANT	\N	PRESENT	0
291555	291395	11010L	PARTICIPANT	\N	PRESENT	0
291556	291395	19253P	PARTICIPANT	\N	PRESENT	0
291557	291395	14021P	PARTICIPANT	\N	PRESENT	0
291558	289582	19515S	PARTICIPANT	\N	PRESENT	0
291559	289582	19565D	PARTICIPANT	\N	PRESENT	0
291560	289582	14357A	PARTICIPANT	\N	PRESENT	0
291561	289582	19441R	PARTICIPANT	\N	PRESENT	0
291562	289582	14081Q	PARTICIPANT	\N	PRESENT	0
291563	289582	19413M	PARTICIPANT	\N	PRESENT	0
291564	289582	80013X	PARTICIPANT	\N	PRESENT	0
291565	289582	19631V	PARTICIPANT	\N	PRESENT	0
291566	289582	11099A	PARTICIPANT	\N	PRESENT	0
291567	289582	08068F	PARTICIPANT	\N	PRESENT	0
291568	289582	04049K	PARTICIPANT	\N	PRESENT	0
291569	289582	19705W	PARTICIPANT	\N	PRESENT	0
291570	289582	19707Y	PARTICIPANT	\N	PRESENT	0
291571	289582	08015R	PARTICIPANT	\N	PRESENT	0
291572	289582	08019V	PARTICIPANT	\N	PRESENT	0
291573	289582	14197C	PARTICIPANT	\N	PRESENT	0
291574	289582	19369B	PARTICIPANT	\N	PRESENT	0
291575	289582	19511N	PARTICIPANT	\N	PRESENT	0
291576	289582	19563B	PARTICIPANT	\N	PRESENT	0
291577	289582	08028W	PARTICIPANT	\N	PRESENT	0
291578	289582	14265W	PARTICIPANT	\N	PRESENT	0
291579	289582	14329V	PARTICIPANT	\N	PRESENT	0
291580	289582	19591F	PARTICIPANT	\N	PRESENT	0
291581	289582	14135M	PARTICIPANT	\N	PRESENT	0
291582	289582	19467C	PARTICIPANT	\N	PRESENT	0
291583	289582	14187A	PARTICIPANT	\N	PRESENT	0
291584	289582	08038Y	PARTICIPANT	\N	PRESENT	0
291585	289582	08062Y	PARTICIPANT	\N	PRESENT	0
291586	289582	19301E	PARTICIPANT	\N	PRESENT	0
291587	289582	19695N	PARTICIPANT	\N	PRESENT	0
291588	289582	14033T	PARTICIPANT	\N	PRESENT	0
291589	289582	11090Q	PRESIDENT	0	PRESENT	0
291590	289582	19295A	PARTICIPANT	\N	PRESENT	0
291591	289582	19269X	PARTICIPANT	\N	PRESENT	0
291592	289582	14205J	PARTICIPANT	\N	PRESENT	0
291593	289582	04088S	PARTICIPANT	\N	PRESENT	0
291594	289582	11056N	PARTICIPANT	\N	PRESENT	0
291595	289582	04089T	PARTICIPANT	\N	PRESENT	0
291596	289582	14115H	PARTICIPANT	\N	PRESENT	0
291597	289582	11101A	PARTICIPANT	\N	PRESENT	0
291598	289582	19507S	PARTICIPANT	\N	PRESENT	0
291599	289582	19747H	PARTICIPANT	\N	PRESENT	0
291600	289582	14207L	PARTICIPANT	\N	PRESENT	0
291601	289582	04043D	PARTICIPANT	\N	PRESENT	0
291602	289582	19619A	PARTICIPANT	\N	PRESENT	0
291603	289582	17589D	PARTICIPANT	\N	PRESENT	0
291604	289582	14257W	PARTICIPANT	\N	PRESENT	0
291605	289582	08021P	PARTICIPANT	\N	EXCUSE	0
291606	289582	11081P	PARTICIPANT	\N	EXCUSE	0
291607	291395	01060R	PARTICIPANT	\N	PRESENT	0
291608	291395	19673G	PARTICIPANT	\N	EXCUSE	0
291609	291395	19719D	PARTICIPANT	\N	EXCUSE	0
291610	291395	19447X	PARTICIPANT	\N	EXCUSE	0
291612	291395	14065Q	PARTICIPANT	\N	PRESENT	0
291613	289196	14327T	PARTICIPANT	\N	PRESENT	0
291614	289196	14331P	PARTICIPANT	\N	PRESENT	0
291615	289196	04071H	PARTICIPANT	\N	PRESENT	0
291616	289196	01048V	PARTICIPANT	\N	PRESENT	0
291617	289196	19545Y	PARTICIPANT	\N	PRESENT	0
291618	289196	01057W	PARTICIPANT	\N	PRESENT	0
291619	289196	11053K	PARTICIPANT	\N	PRESENT	0
291620	289196	11074Q	PRESIDENT	0	PRESENT	0
291621	289196	89017R	PARTICIPANT	\N	PRESENT	0
291622	289196	19667J	PARTICIPANT	\N	PRESENT	0
291623	289196	19671E	PARTICIPANT	\N	PRESENT	0
291624	289196	11070L	PARTICIPANT	\N	PRESENT	0
291625	289196	88008L	PARTICIPANT	\N	PRESENT	0
291626	289196	14225N	PARTICIPANT	\N	PRESENT	0
291627	289196	07029T	PARTICIPANT	\N	PRESENT	0
291628	289196	14085U	PARTICIPANT	\N	PRESENT	0
291629	289196	07004J	PARTICIPANT	\N	PRESENT	0
291630	289196	19349W	PARTICIPANT	\N	PRESENT	0
291631	289196	08010L	PARTICIPANT	\N	PRESENT	0
291632	289196	14253S	PARTICIPANT	\N	PRESENT	0
291633	289196	11048N	PARTICIPANT	\N	PRESENT	0
291634	289196	19479G	PARTICIPANT	\N	PRESENT	0
291635	289196	19647E	PARTICIPANT	\N	PRESENT	0
291636	289196	19711U	PARTICIPANT	\N	PRESENT	0
291637	289196	08034U	PARTICIPANT	\N	PRESENT	0
291638	289196	08069G	PARTICIPANT	\N	PRESENT	0
291639	289196	19687N	PARTICIPANT	\N	PRESENT	0
291640	289196	19689Q	PARTICIPANT	\N	PRESENT	0
291641	289196	12016W	PARTICIPANT	\N	PRESENT	0
291642	289196	08011M	PARTICIPANT	\N	PRESENT	0
291643	289196	14034U	PARTICIPANT	\N	PRESENT	0
291644	289196	14159V	PARTICIPANT	\N	PRESENT	0
291645	289196	19719D	PARTICIPANT	\N	PRESENT	0
291646	289196	14173T	PARTICIPANT	\N	PRESENT	0
291647	289196	04086Q	PARTICIPANT	\N	PRESENT	0
291648	289196	11040E	PARTICIPANT	\N	PRESENT	0
291649	289196	11012A	PARTICIPANT	\N	PRESENT	0
291650	289196	14199E	PARTICIPANT	\N	PRESENT	0
291651	289196	08073C	PARTICIPANT	\N	PRESENT	0
291652	289196	19741B	PARTICIPANT	\N	PRESENT	0
291653	289196	14121F	PARTICIPANT	\N	PRESENT	0
291654	289196	99004R	PARTICIPANT	\N	PRESENT	0
291655	289196	08014Q	PARTICIPANT	\N	EXCUSE	0
291703	291186	04070G	PRESIDENT	0	PRESENT	0
281732	281726	14030Q	PRESIDENT	0	PRESENT	0
281733	281726	08043V	PARTICIPANT	\N	PRESENT	0
281734	281726	19643A	PARTICIPANT	\N	PRESENT	0
281735	281726	08020N	PARTICIPANT	\N	PRESENT	0
281736	281726	08024S	PARTICIPANT	\N	PRESENT	0
281737	281726	11031D	PARTICIPANT	\N	PRESENT	0
281738	281726	80013X	PARTICIPANT	\N	PRESENT	0
281739	281726	19715Y	PARTICIPANT	\N	PRESENT	0
281740	281726	19731Y	PARTICIPANT	\N	PRESENT	0
281741	281726	08017T	PARTICIPANT	\N	PRESENT	0
281742	281726	14109K	PARTICIPANT	\N	PRESENT	0
281743	281726	19269X	PARTICIPANT	\N	PRESENT	0
281744	281726	11045K	PARTICIPANT	\N	PRESENT	0
281745	281726	19749K	PARTICIPANT	\N	PRESENT	0
281746	281726	19367Y	PARTICIPANT	\N	EXCUSE	0
281747	281726	19701S	PARTICIPANT	\N	EXCUSE	0
281748	281726	19693L	PARTICIPANT	\N	EXCUSE	0
281749	281726	07029T	PARTICIPANT	\N	EXCUSE	0
281750	281726	01043Q	PARTICIPANT	\N	EXCUSE	0
289175	273918	01043Q	PARTICIPANT	\N	PRESENT	0
294591	294307	19673G	PARTICIPANT	\N	PRESENT	0
294592	294307	14219Q	PARTICIPANT	\N	PRESENT	0
294593	294307	19725B	PARTICIPANT	\N	PRESENT	0
294594	294307	19333N	PARTICIPANT	\N	PRESENT	0
294595	294307	08068F	PARTICIPANT	\N	PRESENT	0
294596	294307	19553Y	PARTICIPANT	\N	PRESENT	0
294597	294307	01048V	PARTICIPANT	\N	PRESENT	0
294598	294307	14213J	PARTICIPANT	\N	PRESENT	0
294599	294307	14034U	PARTICIPANT	\N	PRESENT	0
294600	294307	11064N	PARTICIPANT	\N	PRESENT	0
294601	294307	19479G	PARTICIPANT	\N	PRESENT	0
294602	294307	14251Q	PARTICIPANT	\N	PRESENT	0
294603	294307	04092N	PARTICIPANT	\N	PRESENT	0
294604	294307	19507S	PARTICIPANT	\N	PRESENT	0
294605	294307	14059S	PARTICIPANT	\N	PRESENT	0
294606	294307	19399H	PARTICIPANT	\N	PRESENT	0
294607	294307	14033T	PARTICIPANT	\N	PRESENT	0
294621	294307	04061F	PARTICIPANT	\N	PRESENT	0
294622	294307	08034U	PARTICIPANT	\N	PRESENT	0
294623	294307	14103D	PARTICIPANT	\N	PRESENT	0
294624	294307	19681G	PARTICIPANT	\N	PRESENT	0
294626	294625	19669L	PARTICIPANT	\N	PRESENT	0
294627	294625	19739H	PARTICIPANT	\N	PRESENT	0
294628	294208	07034Q	PARTICIPANT	\N	PRESENT	0
294629	294625	04040A	PARTICIPANT	\N	PRESENT	0
294630	294208	14179A	PARTICIPANT	\N	PRESENT	0
294631	294625	11026G	PARTICIPANT	\N	PRESENT	0
294632	294625	19713W	PARTICIPANT	\N	PRESENT	0
294633	294307	11043H	PARTICIPANT	\N	PRESENT	0
294634	294307	11026G	PARTICIPANT	\N	PRESENT	0
294635	294307	11010L	PARTICIPANT	\N	PRESENT	0
294636	294307	17583W	PARTICIPANT	\N	PRESENT	0
294637	294307	19443T	PARTICIPANT	\N	PRESENT	0
294638	294307	14121F	PARTICIPANT	\N	PRESENT	0
294639	294307	19611R	PARTICIPANT	\N	PRESENT	0
294643	294307	19679N	PARTICIPANT	\N	PRESENT	0
294644	294307	19421M	PARTICIPANT	\N	PRESENT	0
294645	294307	11054L	PARTICIPANT	\N	PRESENT	0
294646	294307	08038Y	PARTICIPANT	\N	PRESENT	0
294647	294307	19669L	PARTICIPANT	\N	PRESENT	0
294648	294307	98022P	PARTICIPANT	\N	PRESENT	0
294658	294307	08031R	PARTICIPANT	\N	PRESENT	0
294650	294307	01057W	PARTICIPANT	\N	PRESENT	0
294651	294307	08010L	PARTICIPANT	\N	PRESENT	0
294652	294307	14089Y	PARTICIPANT	\N	PRESENT	0
294653	294307	19643A	PARTICIPANT	\N	PRESENT	0
294654	294307	95062K	PARTICIPANT	\N	PRESENT	0
294655	294307	19741B	PARTICIPANT	\N	PRESENT	0
294656	294307	08039A	PARTICIPANT	\N	PRESENT	0
294657	294307	01058X	PARTICIPANT	\N	PRESENT	0
294659	294307	11012A	PARTICIPANT	\N	PRESENT	0
294660	294307	01028R	PARTICIPANT	\N	PRESENT	0
294661	294307	08069G	PARTICIPANT	\N	PRESENT	0
294800	289108	11077T	PARTICIPANT	\N	PRESENT	0
294801	289108	14147R	PARTICIPANT	\N	PRESENT	0
294802	289108	05008E	PARTICIPANT	\N	PRESENT	0
294803	289108	07034Q	PARTICIPANT	\N	PRESENT	0
294804	289108	19693L	PARTICIPANT	\N	PRESENT	0
294805	289108	11031D	PARTICIPANT	\N	PRESENT	0
294806	289108	19679N	PARTICIPANT	\N	PRESENT	0
294807	289108	19443T	PARTICIPANT	\N	PRESENT	0
294808	289108	19447X	PARTICIPANT	\N	PRESENT	0
294809	289108	14329V	PARTICIPANT	\N	PRESENT	0
294810	289108	19701S	PARTICIPANT	\N	PRESENT	0
294811	289108	04092N	PARTICIPANT	\N	PRESENT	0
294812	289108	19319Q	PARTICIPANT	\N	PRESENT	0
294813	289108	19737F	PARTICIPANT	\N	PRESENT	0
294814	289108	14030Q	PARTICIPANT	\N	PRESENT	0
294815	289108	08031R	PARTICIPANT	\N	PRESENT	0
294816	289108	14231L	PARTICIPANT	\N	PRESENT	0
294817	289108	19565D	PARTICIPANT	\N	PRESENT	0
294818	289108	19599P	PARTICIPANT	\N	PRESENT	0
294819	289108	14081Q	PARTICIPANT	\N	PRESENT	0
294820	289108	19723Y	PARTICIPANT	\N	PRESENT	0
294821	289108	14065Q	PARTICIPANT	\N	PRESENT	0
294822	289108	08043V	PARTICIPANT	\N	PRESENT	0
294823	289108	11045K	PARTICIPANT	\N	PRESENT	0
294824	289108	19649G	PARTICIPANT	\N	PRESENT	0
294825	289108	19715Y	PARTICIPANT	\N	PRESENT	0
294826	289108	11067R	PARTICIPANT	\N	PRESENT	0
294827	289108	11033F	PARTICIPANT	\N	PRESENT	0
294828	289108	19503N	PARTICIPANT	\N	PRESENT	0
294829	289108	14109K	PARTICIPANT	\N	PRESENT	0
294830	289108	10006L	PARTICIPANT	\N	PRESENT	0
294831	289108	19727D	PARTICIPANT	\N	PRESENT	0
294832	289108	04047H	PARTICIPANT	\N	PRESENT	0
294833	289108	08017T	PARTICIPANT	\N	PRESENT	0
294834	289108	14042U	PARTICIPANT	\N	PRESENT	0
294835	289108	19629C	PARTICIPANT	\N	PRESENT	0
294836	289108	19543W	PARTICIPANT	\N	PRESENT	0
294837	289108	19441R	PARTICIPANT	\N	PRESENT	0
294838	289108	19253P	PARTICIPANT	\N	PRESENT	0
294839	289108	19749K	PARTICIPANT	\N	PRESENT	0
294840	289108	14215L	PARTICIPANT	\N	PRESENT	0
294841	289108	14021P	PARTICIPANT	\N	PRESENT	0
294842	289108	19533U	PARTICIPANT	\N	PRESENT	0
294843	289108	19367Y	PARTICIPANT	\N	PRESENT	0
294844	289108	19621T	PARTICIPANT	\N	PRESENT	0
294845	289108	19643A	PARTICIPANT	\N	PRESENT	0
294846	289108	08061X	PARTICIPANT	\N	PRESENT	0
294847	289108	01024M	PARTICIPANT	\N	PRESENT	0
294848	289108	19585H	PARTICIPANT	\N	PRESENT	0
294849	289108	14105F	PARTICIPANT	\N	PRESENT	0
294850	289108	01028R	PARTICIPANT	\N	PRESENT	0
294851	289108	01057W	PARTICIPANT	\N	PRESENT	0
294852	289108	04040A	PARTICIPANT	\N	PRESENT	0
294853	289108	04044E	PARTICIPANT	\N	PRESENT	0
294854	289108	19551W	PARTICIPANT	\N	PRESENT	0
294855	289108	08069G	PARTICIPANT	\N	PRESENT	0
294856	289108	18083K	PARTICIPANT	\N	PRESENT	0
294857	289108	14331P	PARTICIPANT	\N	PRESENT	0
294858	289108	14187A	PARTICIPANT	\N	PRESENT	0
294859	289108	14033T	PARTICIPANT	\N	PRESENT	0
294860	289108	14157T	PARTICIPANT	\N	PRESENT	0
294861	289108	14223L	PARTICIPANT	\N	PRESENT	0
294862	289108	14213J	PARTICIPANT	\N	PRESENT	0
294863	289108	14219Q	PARTICIPANT	\N	PRESENT	0
294864	289108	19741B	PARTICIPANT	\N	PRESENT	0
294865	289108	19657G	PARTICIPANT	\N	PRESENT	0
294866	289108	19747H	PARTICIPANT	\N	PRESENT	0
294867	289108	14265W	PARTICIPANT	\N	PRESENT	0
294868	289108	14357A	PARTICIPANT	\N	PRESENT	0
294869	289108	14083S	PARTICIPANT	\N	PRESENT	0
294870	289108	14034U	PARTICIPANT	\N	PRESENT	0
294995	293670	19319Q	PARTICIPANT	\N	PRESENT	0
294996	281355	14030Q	PRESIDENT	0	PRESENT	0
294997	281355	08043V	PARTICIPANT	\N	PRESENT	0
294998	281355	19643A	PARTICIPANT	\N	EXCUSE	0
294999	281355	08020N	PARTICIPANT	\N	EXCUSE	0
295000	281355	08024S	PARTICIPANT	\N	EXCUSE	0
295001	281355	19693L	PARTICIPANT	\N	EXCUSE	0
295002	281355	19599P	PARTICIPANT	\N	PRESENT	0
295003	281355	19731Y	PARTICIPANT	\N	PRESENT	0
295004	281355	07029T	PARTICIPANT	\N	EXCUSE	0
295005	281355	08017T	PARTICIPANT	\N	PRESENT	0
295006	281355	14109K	PARTICIPANT	\N	PRESENT	0
295007	281355	19749K	PARTICIPANT	\N	PRESENT	0
295009	295008	14331P	PARTICIPANT	\N	PRESENT	0
295027	295026	14331P	PARTICIPANT	\N	PRESENT	0
295131	295130	19531S	PARTICIPANT	\N	PRESENT	0
295154	293464	19575F	PARTICIPANT	\N	PRESENT	0
295155	293464	08052W	PRESIDENT	0	PRESENT	0
295156	293464	19727D	PARTICIPANT	\N	PRESENT	0
295157	293464	14213J	PARTICIPANT	\N	PRESENT	0
295158	293464	14227Q	PARTICIPANT	\N	PRESENT	0
295159	293464	19713W	PARTICIPANT	\N	PRESENT	0
295160	293464	95062K	PARTICIPANT	\N	PRESENT	0
295161	293464	14237S	PARTICIPANT	\N	PRESENT	0
295162	293464	14223L	PARTICIPANT	\N	PRESENT	0
273141	272936	19441R	PARTICIPANT	\N	PRESENT	0
273142	272936	14221J	PARTICIPANT	\N	PRESENT	0
273143	272936	10006L	PARTICIPANT	\N	PRESENT	0
273144	272936	11080N	PARTICIPANT	\N	PRESENT	0
273145	272936	14085U	PARTICIPANT	\N	PRESENT	0
273237	270531	19489J	PARTICIPANT	\N	PRESENT	0
273238	270531	14231L	PARTICIPANT	\N	PRESENT	0
273239	270531	14159V	PARTICIPANT	\N	PRESENT	0
273240	270531	95063L	PARTICIPANT	\N	PRESENT	0
273241	270531	14251Q	PARTICIPANT	\N	PRESENT	0
273242	270531	11031D	PARTICIPANT	\N	PRESENT	0
273243	270531	11033F	PARTICIPANT	\N	PRESENT	0
273244	270531	19593H	PARTICIPANT	\N	PRESENT	0
273245	270531	17779H	PARTICIPANT	\N	PRESENT	0
273246	270531	19621T	PARTICIPANT	\N	PRESENT	0
273247	270531	19515S	PARTICIPANT	\N	PRESENT	0
273248	270531	11080N	PARTICIPANT	\N	PRESENT	0
273249	270531	19703U	PARTICIPANT	\N	PRESENT	0
273250	270531	07029T	PARTICIPANT	\N	PRESENT	0
273251	270531	14331P	PARTICIPANT	\N	PRESENT	0
273252	270531	14069U	PARTICIPANT	\N	PRESENT	0
273253	270531	04049K	PARTICIPANT	\N	PRESENT	0
273254	270531	14105F	PARTICIPANT	\N	PRESENT	0
273255	270531	19575F	PARTICIPANT	\N	PRESENT	0
273256	270531	19687N	PARTICIPANT	\N	PRESENT	0
273257	270531	14021P	PARTICIPANT	\N	PRESENT	0
273258	270531	19507S	PARTICIPANT	\N	PRESENT	0
273259	270531	14033T	PARTICIPANT	\N	PRESENT	0
273260	270531	19563B	PARTICIPANT	\N	PRESENT	0
273261	270531	19695N	PARTICIPANT	\N	PRESENT	0
273262	270531	14235Q	PARTICIPANT	\N	PRESENT	0
273263	270531	11056N	PARTICIPANT	\N	PRESENT	0
273264	270531	19747H	PARTICIPANT	\N	PRESENT	0
273265	270531	11012A	PARTICIPANT	\N	PRESENT	0
273266	270531	19399H	PARTICIPANT	\N	PRESENT	0
273267	270531	19713W	PARTICIPANT	\N	PRESENT	0
273315	273314	08028W	PARTICIPANT	\N	PRESENT	0
273316	273314	08068F	PARTICIPANT	\N	PRESENT	0
273139	272936	14030Q	PARTICIPANT	\N	PRESENT	0
273140	272936	19369B	PARTICIPANT	\N	PRESENT	0
273318	273317	08028W	PARTICIPANT	\N	PRESENT	0
273319	273317	08068F	PARTICIPANT	\N	PRESENT	0
273324	273322	08068F	PARTICIPANT	\N	PRESENT	0
273346	273329	19575F	PARTICIPANT	\N	PRESENT	0
273347	273329	19549D	PARTICIPANT	\N	PRESENT	0
273348	273329	19747H	PARTICIPANT	\N	PRESENT	0
273349	273329	14083S	PARTICIPANT	\N	PRESENT	0
273350	273329	14038Y	PARTICIPANT	\N	PRESENT	0
273351	273329	19681G	PARTICIPANT	\N	PRESENT	0
273352	273329	80013X	PARTICIPANT	\N	PRESENT	0
273353	273329	14357A	PARTICIPANT	\N	PRESENT	0
273355	273329	11065P	PARTICIPANT	\N	PRESENT	0
273357	273329	17589D	PARTICIPANT	\N	PRESENT	0
273358	273329	14033T	PARTICIPANT	\N	PRESENT	0
273361	273329	19333N	PARTICIPANT	\N	PRESENT	0
273364	273329	04097T	PARTICIPANT	\N	PRESENT	0
273366	273329	11048N	PARTICIPANT	\N	PRESENT	0
273375	273329	14219Q	PARTICIPANT	\N	PRESENT	0
273376	273329	14257W	PARTICIPANT	\N	PRESENT	0
273377	273329	19533U	PARTICIPANT	\N	PRESENT	0
273378	273329	04088S	PARTICIPANT	\N	PRESENT	0
273379	273329	98050T	PARTICIPANT	\N	PRESENT	0
273380	273329	19619A	PARTICIPANT	\N	PRESENT	0
273381	273329	01058X	PARTICIPANT	\N	PRESENT	0
273382	273329	14051J	PARTICIPANT	\N	PRESENT	0
273383	273329	95067Q	PARTICIPANT	\N	PRESENT	0
273385	273384	14133K	PARTICIPANT	\N	PRESENT	0
273386	273384	19643A	PARTICIPANT	\N	PRESENT	0
273387	273384	14281W	PARTICIPANT	\N	PRESENT	0
273388	273384	08045X	PARTICIPANT	\N	PRESENT	0
273389	273384	14026U	PARTICIPANT	\N	PRESENT	0
273390	273384	19447X	PARTICIPANT	\N	PRESENT	0
273391	273384	14205J	PARTICIPANT	\N	PRESENT	0
273392	273384	14173T	PARTICIPANT	\N	PRESENT	0
273393	273384	19735D	PARTICIPANT	\N	PRESENT	0
275070	273327	19569H	PARTICIPANT	\N	PRESENT	0
275071	273327	14357A	PARTICIPANT	\N	PRESENT	0
275072	273327	14079W	PARTICIPANT	\N	PRESENT	0
275073	273327	14001X	PARTICIPANT	\N	PRESENT	0
275074	273327	11074Q	PRESIDENT	0	PRESENT	0
275075	273327	14221J	PARTICIPANT	\N	PRESENT	0
275076	273327	14225N	PARTICIPANT	\N	PRESENT	0
275077	273327	14085U	PARTICIPANT	\N	PRESENT	0
275078	273327	19563B	PARTICIPANT	\N	PRESENT	0
275079	273327	11048N	PARTICIPANT	\N	PRESENT	0
275080	273327	19479G	PARTICIPANT	\N	PRESENT	0
275081	273327	19711U	PARTICIPANT	\N	PRESENT	0
275082	273327	04057K	PARTICIPANT	\N	PRESENT	0
275083	273327	19531S	PARTICIPANT	\N	PRESENT	0
275084	273327	19687N	PARTICIPANT	\N	PRESENT	0
275085	273327	11026G	PARTICIPANT	\N	PRESENT	0
275086	273327	10015M	PARTICIPANT	\N	PRESENT	0
275087	273327	19689Q	PARTICIPANT	\N	PRESENT	0
275088	273327	14033T	PARTICIPANT	\N	PRESENT	0
275089	273327	08011M	PARTICIPANT	\N	PRESENT	0
275090	273327	14089Y	PARTICIPANT	\N	PRESENT	0
273235	270531	14034U	PARTICIPANT	\N	PRESENT	0
273236	270531	04085P	PARTICIPANT	\N	PRESENT	0
275091	273327	19725B	PARTICIPANT	\N	PRESENT	0
275092	273327	14083S	PARTICIPANT	\N	PRESENT	0
275093	273327	11083R	PARTICIPANT	\N	PRESENT	0
275094	273327	14121F	PARTICIPANT	\N	PRESENT	0
275095	273327	19741B	PARTICIPANT	\N	PRESENT	0
275096	273327	04061F	PARTICIPANT	\N	PRESENT	0
275613	271933	14089Y	PARTICIPANT	\N	PRESENT	0
275614	271933	08056B	PARTICIPANT	\N	PRESENT	0
275615	271933	19611R	PARTICIPANT	\N	PRESENT	0
275616	271933	19421M	PARTICIPANT	\N	PRESENT	0
275617	271933	10015M	PARTICIPANT	\N	PRESENT	0
275618	271933	19575F	PARTICIPANT	\N	PRESENT	0
275619	271933	98050T	PARTICIPANT	\N	PRESENT	0
275620	271933	08010L	PARTICIPANT	\N	PRESENT	0
275621	271933	19673G	PARTICIPANT	\N	PRESENT	0
275622	271933	98029W	PRESIDENT	0	PRESENT	0
275623	271933	04008A	PARTICIPANT	\N	EXCUSE	0
275648	263766	11026G	PARTICIPANT	\N	PRESENT	0
275661	263766	19543W	PARTICIPANT	\N	PRESENT	0
275665	263766	11085T	PARTICIPANT	\N	PRESENT	0
275675	263766	08020N	PARTICIPANT	\N	PRESENT	0
276409	268443	18003S	PARTICIPANT	\N	PRESENT	0
276438	268443	14093U	PARTICIPANT	\N	PRESENT	0
276439	268443	19533U	PARTICIPANT	\N	PRESENT	0
276440	268443	19503N	PARTICIPANT	\N	PRESENT	0
276443	268443	04043D	PARTICIPANT	\N	PRESENT	0
276480	267658	14221J	PARTICIPANT	\N	PRESENT	0
276481	267658	19593H	PARTICIPANT	\N	PRESENT	0
276483	267659	14221J	PARTICIPANT	\N	PRESENT	0
276484	267659	19593H	PARTICIPANT	\N	PRESENT	0
276485	267660	14221J	PARTICIPANT	\N	PRESENT	0
278756	278438	08024S	PARTICIPANT	\N	EXCUSE	0
278757	278438	19569H	PARTICIPANT	\N	EXCUSE	0
278847	278438	01028R	PARTICIPANT	\N	EXCUSE	0
280315	279252	04086Q	PARTICIPANT	\N	PRESENT	0
280316	279252	14083S	PARTICIPANT	\N	PRESENT	0
280317	279252	99004R	PARTICIPANT	\N	PRESENT	0
280318	279252	14331P	PARTICIPANT	\N	EXCUSE	0
280319	279252	11012A	PARTICIPANT	\N	EXCUSE	0
280320	279252	19689Q	PARTICIPANT	\N	EXCUSE	0
280321	279252	14121F	PARTICIPANT	\N	EXCUSE	0
280322	279252	08014Q	PARTICIPANT	\N	EXCUSE	0
280323	279252	14034U	PARTICIPANT	\N	EXCUSE	0
280324	279252	88008L	PARTICIPANT	\N	EXCUSE	0
280396	278759	19713W	PARTICIPANT	\N	PRESENT	0
280397	278759	19549D	PARTICIPANT	\N	PRESENT	0
280398	278759	95062K	PARTICIPANT	\N	PRESENT	0
280400	278759	08055A	PARTICIPANT	\N	PRESENT	0
280401	278759	19599P	PARTICIPANT	\N	PRESENT	0
280402	278759	14191V	PARTICIPANT	\N	PRESENT	0
280404	278759	05012A	PARTICIPANT	\N	PRESENT	0
280405	278759	14051J	PARTICIPANT	\N	PRESENT	0
280406	278759	14029X	PARTICIPANT	\N	PRESENT	0
280407	278759	08060W	PARTICIPANT	\N	PRESENT	0
280408	278759	08009T	PRESIDENT	0	PRESENT	0
280409	278759	19503N	PARTICIPANT	\N	PRESENT	0
280410	278759	19737F	PARTICIPANT	\N	PRESENT	0
280411	278759	19347U	PARTICIPANT	\N	PRESENT	0
280412	278759	19739H	PARTICIPANT	\N	PRESENT	0
280413	278759	19745F	PARTICIPANT	\N	PRESENT	0
280415	278759	19701S	PARTICIPANT	\N	PRESENT	0
279271	279270	11074Q	PARTICIPANT	\N	PRESENT	0
279279	279278	14199E	PARTICIPANT	\N	PRESENT	0
279281	279280	19479G	PARTICIPANT	\N	PRESENT	0
285589	280907	14030Q	PRESIDENT	0	PRESENT	0
285590	280907	08043V	PARTICIPANT	\N	PRESENT	0
285591	280907	19621T	PARTICIPANT	\N	PRESENT	0
285592	280907	11031D	PARTICIPANT	\N	PRESENT	0
285593	280907	80013X	PARTICIPANT	\N	PRESENT	0
285595	280907	19693L	PARTICIPANT	\N	PRESENT	0
285596	280907	14217N	PARTICIPANT	\N	PRESENT	0
285597	280907	19599P	PARTICIPANT	\N	PRESENT	0
285598	280907	19731Y	PARTICIPANT	\N	PRESENT	0
285599	280907	08031R	PARTICIPANT	\N	PRESENT	0
285601	280907	07029T	PARTICIPANT	\N	PRESENT	0
285603	280907	11045K	PARTICIPANT	\N	PRESENT	0
285604	280907	19749K	PARTICIPANT	\N	PRESENT	0
285607	280907	01043Q	PARTICIPANT	\N	EXCUSE	0
298632	298326	11072N	PARTICIPANT	\N	PRESENT	0
298635	298326	19679N	PARTICIPANT	\N	PRESENT	0
298636	298326	19521Q	PARTICIPANT	\N	PRESENT	0
298637	298326	14119M	PARTICIPANT	\N	PRESENT	0
298638	298326	08052W	PARTICIPANT	\N	PRESENT	0
298639	298326	11067R	PARTICIPANT	\N	PRESENT	0
298640	298326	11045K	PARTICIPANT	\N	PRESENT	0
298641	298326	19739H	PARTICIPANT	\N	PRESENT	0
298642	298326	07004J	PARTICIPANT	\N	PRESENT	0
298643	298326	19697Q	PARTICIPANT	\N	PRESENT	0
298644	298326	04085P	PARTICIPANT	\N	PRESENT	0
298645	298326	14041T	PARTICIPANT	\N	PRESENT	0
298646	298326	19657G	PARTICIPANT	\N	PRESENT	0
298647	298326	19663E	PARTICIPANT	\N	PRESENT	0
298648	298326	11097X	PARTICIPANT	\N	PRESENT	0
298649	298326	14071N	PARTICIPANT	\N	PRESENT	0
298650	298326	98005N	PARTICIPANT	\N	PRESENT	0
298651	298326	19711U	PARTICIPANT	\N	PRESENT	0
298652	298326	04086Q	PARTICIPANT	\N	PRESENT	0
298653	298326	19741B	PARTICIPANT	\N	PRESENT	0
298654	298326	14021P	PARTICIPANT	\N	PRESENT	0
298655	298326	19553Y	PARTICIPANT	\N	PRESENT	0
298656	298326	95063L	PARTICIPANT	\N	PRESENT	0
298657	298326	14039A	PARTICIPANT	\N	PRESENT	0
298658	298326	19695N	PARTICIPANT	\N	PRESENT	0
298659	298326	14281W	PARTICIPANT	\N	PRESENT	0
298660	298326	14059S	PARTICIPANT	\N	PRESENT	0
298661	298326	19691J	PARTICIPANT	\N	PRESENT	0
298662	298326	19675J	PARTICIPANT	\N	PRESENT	0
298663	298326	19687N	PARTICIPANT	\N	PRESENT	0
298664	298326	19591F	PARTICIPANT	\N	PRESENT	0
298665	298326	19727D	PARTICIPANT	\N	PRESENT	0
298666	298326	19335Q	PARTICIPANT	\N	PRESENT	0
298667	298326	02002K	PARTICIPANT	\N	PRESENT	0
298668	298326	14265W	PARTICIPANT	\N	PRESENT	0
298669	298326	19715Y	PARTICIPANT	\N	PRESENT	0
298670	298326	04034C	PARTICIPANT	\N	PRESENT	0
298671	298326	19611R	PARTICIPANT	\N	PRESENT	0
298672	298326	19399H	PARTICIPANT	\N	PRESENT	0
298712	295638	08043V	PARTICIPANT	\N	PRESENT	0
298717	295638	19715Y	PARTICIPANT	\N	PRESENT	0
298714	295638	19593H	PARTICIPANT	\N	PRESENT	0
298715	295638	11056N	PARTICIPANT	\N	PRESENT	0
298716	295638	19695N	PARTICIPANT	\N	PRESENT	0
298718	295638	04057K	PARTICIPANT	\N	PRESENT	0
298719	295638	19651A	PARTICIPANT	\N	PRESENT	0
298720	295638	11083R	PARTICIPANT	\N	PRESENT	0
298721	295638	95063L	PARTICIPANT	\N	PRESENT	0
298722	295638	14251Q	PARTICIPANT	\N	PRESENT	0
298723	295638	19591F	PARTICIPANT	\N	PRESENT	0
298724	295638	11012A	PARTICIPANT	\N	PRESENT	0
298725	295638	19253P	PARTICIPANT	\N	PRESENT	0
298726	295638	19515S	PARTICIPANT	\N	PRESENT	0
298727	295638	14241N	PARTICIPANT	\N	PRESENT	0
298728	295638	19611R	PARTICIPANT	\N	PRESENT	0
298729	295638	19749K	PARTICIPANT	\N	PRESENT	0
298730	295638	08019V	PARTICIPANT	\N	PRESENT	0
298731	295638	19747H	PARTICIPANT	\N	PRESENT	0
298732	295638	14041T	PARTICIPANT	\N	PRESENT	0
298733	295638	19739H	PARTICIPANT	\N	PRESENT	0
298734	295638	04088S	PARTICIPANT	\N	PRESENT	0
298735	295638	01043Q	PARTICIPANT	\N	PRESENT	0
298736	295638	98005N	PARTICIPANT	\N	PRESENT	0
298737	295638	04018C	PARTICIPANT	\N	PRESENT	0
298738	295638	19533U	PARTICIPANT	\N	PRESENT	0
298739	295638	17637T	PARTICIPANT	\N	PRESENT	0
298740	295638	05012A	PARTICIPANT	\N	PRESENT	0
298741	295638	14265W	PARTICIPANT	\N	PRESENT	0
298742	295638	04086Q	PARTICIPANT	\N	PRESENT	0
298743	295638	11109J	PARTICIPANT	\N	PRESENT	0
298744	295638	99004R	PARTICIPANT	\N	PRESENT	0
298745	295638	19711U	PARTICIPANT	\N	PRESENT	0
298746	295638	19399H	PARTICIPANT	\N	PRESENT	0
298747	295638	11090Q	PARTICIPANT	\N	PRESENT	0
298748	295638	14038Y	PARTICIPANT	\N	PRESENT	0
298749	295638	19701S	PARTICIPANT	\N	PRESENT	0
298710	295638	11070L	PARTICIPANT	\N	PRESENT	0
298711	295638	08012N	PARTICIPANT	\N	PRESENT	0
298750	295638	04033B	PARTICIPANT	\N	PRESENT	0
298751	295638	04085P	PARTICIPANT	\N	PRESENT	0
298752	295638	08061X	PARTICIPANT	\N	PRESENT	0
298753	295638	14107H	PARTICIPANT	\N	PRESENT	0
298754	295638	19735D	PARTICIPANT	\N	PRESENT	0
298755	295638	08038Y	PARTICIPANT	\N	PRESENT	0
298756	295638	19573D	PARTICIPANT	\N	PRESENT	0
298757	295638	11099A	PARTICIPANT	\N	PRESENT	0
298758	295638	19543W	PARTICIPANT	\N	PRESENT	0
298759	295638	19565D	PARTICIPANT	\N	PRESENT	0
298760	295638	19289C	PARTICIPANT	\N	PRESENT	0
298761	295638	19631V	PARTICIPANT	\N	PRESENT	0
298762	295638	14087W	PARTICIPANT	\N	PRESENT	0
298763	295638	19727D	PARTICIPANT	\N	PRESENT	0
298764	295772	19593H	PARTICIPANT	\N	PRESENT	0
298765	295772	04057K	PARTICIPANT	\N	PRESENT	0
298766	295772	19533U	PARTICIPANT	\N	PRESENT	0
298767	295772	19611R	PARTICIPANT	\N	PRESENT	0
298768	295772	04033B	PARTICIPANT	\N	PRESENT	0
298769	295772	08043V	PARTICIPANT	\N	PRESENT	0
298770	295772	19399H	PARTICIPANT	\N	PRESENT	0
298771	295772	14241N	PARTICIPANT	\N	PRESENT	0
298772	295772	19573D	PARTICIPANT	\N	PRESENT	0
298773	295772	14251Q	PARTICIPANT	\N	PRESENT	0
298774	295772	14039A	PARTICIPANT	\N	PRESENT	0
298775	295772	11083R	PARTICIPANT	\N	PRESENT	0
298776	295772	14123H	PRESIDENT	0	PRESENT	0
298777	295772	08012N	PARTICIPANT	\N	PRESENT	0
298778	295772	19749K	PARTICIPANT	\N	PRESENT	0
298779	295772	04018C	PARTICIPANT	\N	PRESENT	0
298780	295772	19621T	PARTICIPANT	\N	PRESENT	0
298781	295772	19643A	PARTICIPANT	\N	EXCUSE	0
298782	295772	14061L	PARTICIPANT	\N	EXCUSE	0
298783	295772	11043H	PARTICIPANT	\N	EXCUSE	0
298784	295772	19693L	PARTICIPANT	\N	EXCUSE	0
298785	295772	14201E	PARTICIPANT	\N	EXCUSE	0
298786	295772	08039A	PARTICIPANT	\N	EXCUSE	0
298787	295772	08031R	PARTICIPANT	\N	EXCUSE	0
298788	295638	19687N	PARTICIPANT	\N	PRESENT	0
298790	295638	19741B	PARTICIPANT	\N	PRESENT	0
298791	295638	19657G	PARTICIPANT	\N	PRESENT	0
298795	295638	19693L	PARTICIPANT	\N	PRESENT	0
298796	295638	14021P	PARTICIPANT	\N	PRESENT	0
298797	295638	14281W	PARTICIPANT	\N	PRESENT	0
298798	295638	14071N	PARTICIPANT	\N	PRESENT	0
298799	295638	14039A	PARTICIPANT	\N	PRESENT	0
298801	295638	08017T	PARTICIPANT	\N	PRESENT	0
298802	295638	08062Y	PARTICIPANT	\N	PRESENT	0
298804	295638	19553Y	PARTICIPANT	\N	PRESENT	0
298805	295638	14093U	PARTICIPANT	\N	PRESENT	0
298806	295638	14059S	PARTICIPANT	\N	PRESENT	0
298807	295638	19679N	PARTICIPANT	\N	PRESENT	0
298808	295638	14257W	PARTICIPANT	\N	PRESENT	0
298809	295638	19521Q	PARTICIPANT	\N	PRESENT	0
298810	295638	19441R	PARTICIPANT	\N	PRESENT	0
298811	295638	19647E	PARTICIPANT	\N	PRESENT	0
298812	295638	11067R	PARTICIPANT	\N	PRESENT	0
298947	289189	11056N	PARTICIPANT	\N	PRESENT	0
298948	289189	19695N	PARTICIPANT	\N	PRESENT	0
298949	289189	19335Q	PARTICIPANT	\N	PRESENT	0
298950	289189	14069U	PARTICIPANT	\N	PRESENT	0
298952	289189	19611R	PARTICIPANT	\N	PRESENT	0
298955	289189	19289C	PARTICIPANT	\N	PRESENT	0
272886	268440	04061F	PARTICIPANT	\N	EXCUSE	0
273869	273868	14215L	PARTICIPANT	\N	PRESENT	0
273870	273868	14026U	PARTICIPANT	\N	PRESENT	0
273871	273868	14051J	PARTICIPANT	\N	PRESENT	0
273927	273926	11074Q	PARTICIPANT	\N	PRESENT	0
273938	273937	08017T	PARTICIPANT	\N	PRESENT	0
275803	275788	19347U	PARTICIPANT	\N	EXCUSE	0
275804	275788	14327T	PARTICIPANT	\N	EXCUSE	0
289493	289492	08034U	PARTICIPANT	\N	PRESENT	0
289511	289510	08011M	PARTICIPANT	\N	PRESENT	0
289512	289510	07004J	PARTICIPANT	\N	PRESENT	0
289517	289513	08011M	PARTICIPANT	\N	PRESENT	0
289522	289521	08011M	PARTICIPANT	\N	PRESENT	0
289533	289532	08011M	PARTICIPANT	\N	PRESENT	0
289613	289581	04085P	PARTICIPANT	\N	PRESENT	0
289614	289581	04059M	PARTICIPANT	\N	PRESENT	0
289615	289581	05008E	PARTICIPANT	\N	PRESENT	0
289616	289581	96004D	PARTICIPANT	\N	PRESENT	0
289617	289581	04042C	PARTICIPANT	\N	PRESENT	0
289618	289581	11053K	PARTICIPANT	\N	PRESENT	0
289619	289581	04086Q	PARTICIPANT	\N	PRESENT	0
289620	289581	11074Q	PARTICIPANT	\N	PRESENT	0
289621	289581	14187A	PARTICIPANT	\N	PRESENT	0
289622	289581	14034U	PARTICIPANT	\N	PRESENT	0
289623	289581	11048N	PARTICIPANT	\N	PRESENT	0
289624	289581	14021P	PARTICIPANT	\N	PRESENT	0
289625	289581	14073Q	PARTICIPANT	\N	PRESENT	0
289626	289581	11077T	PARTICIPANT	\N	PRESENT	0
289627	289581	14251Q	PARTICIPANT	\N	PRESENT	0
289628	289581	08009T	PARTICIPANT	\N	PRESENT	0
289629	289581	04092N	PARTICIPANT	\N	PRESENT	0
289630	289581	11072N	PARTICIPANT	\N	PRESENT	0
289631	289581	08011M	PARTICIPANT	\N	PRESENT	0
289632	289581	04070G	PARTICIPANT	\N	PRESENT	0
289633	289581	08061X	PARTICIPANT	\N	PRESENT	0
289634	289581	11090Q	PARTICIPANT	\N	PRESENT	0
289635	289581	11012A	PARTICIPANT	\N	PRESENT	0
289636	289581	04044E	PARTICIPANT	\N	PRESENT	0
289637	289581	01034P	PARTICIPANT	\N	PRESENT	0
291704	291186	19699S	PARTICIPANT	\N	PRESENT	0
291705	291186	19533U	PARTICIPANT	\N	PRESENT	0
291706	291186	95015C	PARTICIPANT	\N	PRESENT	0
291707	291186	04033B	PARTICIPANT	\N	PRESENT	0
291708	291186	19329S	PARTICIPANT	\N	PRESENT	0
291709	291186	14229S	PARTICIPANT	\N	PRESENT	0
291710	291186	14241N	PARTICIPANT	\N	PRESENT	0
291711	291186	14039A	PARTICIPANT	\N	PRESENT	0
291712	291186	14107H	PARTICIPANT	\N	PRESENT	0
291713	291186	08017T	PARTICIPANT	\N	PRESENT	0
291714	291186	08012N	PARTICIPANT	\N	PRESENT	0
291715	291186	08039A	PARTICIPANT	\N	PRESENT	0
291716	291186	08031R	PARTICIPANT	\N	PRESENT	0
291717	291186	19593H	PARTICIPANT	\N	PRESENT	0
291718	291186	19643A	PARTICIPANT	\N	PRESENT	0
291719	291186	14059S	PARTICIPANT	\N	PRESENT	0
291720	291186	14061L	PARTICIPANT	\N	PRESENT	0
291721	291186	04057K	PARTICIPANT	\N	PRESENT	0
291722	291186	19693L	PARTICIPANT	\N	PRESENT	0
291723	291186	87003B	PARTICIPANT	\N	PRESENT	0
291724	291186	19399H	PARTICIPANT	\N	PRESENT	0
291725	291186	14030Q	PARTICIPANT	\N	PRESENT	0
291726	291186	08020N	PARTICIPANT	\N	PRESENT	0
291727	291186	14251Q	PARTICIPANT	\N	PRESENT	0
291728	291186	04059M	PARTICIPANT	\N	PRESENT	0
291729	291186	11109J	PARTICIPANT	\N	PRESENT	0
291730	291186	14109K	PARTICIPANT	\N	PRESENT	0
291731	291186	14063N	PARTICIPANT	\N	PRESENT	0
291732	291186	11043H	PARTICIPANT	\N	PRESENT	0
291733	291186	11104D	PARTICIPANT	\N	PRESENT	0
291734	291186	19749K	PARTICIPANT	\N	PRESENT	0
291735	291186	19758L	PARTICIPANT	\N	PRESENT	0
291736	291186	19621T	PARTICIPANT	\N	PRESENT	0
291737	288052	14211G	PARTICIPANT	\N	PRESENT	0
291798	287620	14355X	PARTICIPANT	\N	PRESENT	0
291799	287620	04092N	PRESIDENT	1	PRESENT	0
291800	287620	08052W	PARTICIPANT	\N	PRESENT	0
291801	287620	14042U	PRESIDENT	0	PRESENT	0
291802	287620	14195A	PARTICIPANT	\N	PRESENT	0
291803	287620	19367Y	PARTICIPANT	\N	PRESENT	0
291804	287620	14071N	PARTICIPANT	\N	PRESENT	0
291805	287620	14227Q	PARTICIPANT	\N	PRESENT	0
291806	287620	19723Y	PARTICIPANT	\N	PRESENT	0
291807	287620	08048B	PARTICIPANT	\N	EXCUSE	0
291808	287620	08041T	PARTICIPANT	\N	EXCUSE	0
291809	287620	11067R	PARTICIPANT	\N	PRESENT	0
291810	287620	19415P	PARTICIPANT	\N	PRESENT	0
291811	287620	14223L	PARTICIPANT	\N	PRESENT	0
291812	287620	14087W	PARTICIPANT	\N	PRESENT	0
291813	287620	19679N	PARTICIPANT	\N	PRESENT	0
291815	287620	19697Q	PARTICIPANT	\N	PRESENT	0
291816	287620	19569H	PARTICIPANT	\N	PRESENT	0
291817	287620	14026U	PARTICIPANT	\N	PRESENT	0
291818	287620	11063M	PARTICIPANT	\N	PRESENT	0
291819	287620	19703U	PARTICIPANT	\N	PRESENT	0
291820	287620	14119M	PARTICIPANT	\N	PRESENT	0
291821	287620	14281W	PARTICIPANT	\N	PRESENT	0
291822	287620	14213J	PARTICIPANT	\N	PRESENT	0
291823	287620	14217N	PARTICIPANT	\N	PRESENT	0
291824	287620	19527W	PARTICIPANT	\N	PRESENT	0
291825	273924	11056N	PARTICIPANT	\N	PRESENT	0
291826	273924	19695N	PARTICIPANT	\N	PRESENT	0
291827	273924	19683J	PARTICIPANT	\N	PRESENT	0
291828	273924	08055A	PARTICIPANT	\N	PRESENT	0
291829	273924	14207L	PARTICIPANT	\N	PRESENT	0
291830	273924	14257W	PARTICIPANT	\N	PRESENT	0
291831	273924	19503N	PARTICIPANT	\N	PRESENT	0
291832	273924	08060W	PARTICIPANT	\N	PRESENT	0
291833	273924	17589D	PARTICIPANT	\N	PRESENT	0
291834	273924	14195A	PARTICIPANT	\N	PRESENT	0
291835	273924	19295A	PARTICIPANT	\N	PRESENT	0
291836	273924	14135M	PARTICIPANT	\N	PRESENT	0
291837	273924	08056B	PARTICIPANT	\N	PRESENT	0
291838	273924	88008L	PARTICIPANT	\N	PRESENT	0
291839	273924	14327T	PARTICIPANT	\N	PRESENT	0
291840	273924	19347U	PARTICIPANT	\N	PRESENT	0
291841	273924	11104D	PARTICIPANT	\N	PRESENT	0
291842	273924	14107H	PARTICIPANT	\N	PRESENT	0
291843	273924	19413M	PARTICIPANT	\N	PRESENT	0
291844	273924	19725B	PARTICIPANT	\N	PRESENT	0
291845	287620	19553Y	PARTICIPANT	\N	PRESENT	0
291846	287620	19335Q	PARTICIPANT	\N	PRESENT	0
291847	287620	19691J	PARTICIPANT	\N	PRESENT	0
291848	287620	19727D	PARTICIPANT	\N	PRESENT	0
291849	287620	19715Y	PARTICIPANT	\N	EXCUSE	0
291850	273924	08068F	PARTICIPANT	\N	PRESENT	0
291851	273924	08016S	PARTICIPANT	\N	PRESENT	0
291852	273924	19745F	PARTICIPANT	\N	PRESENT	0
291853	273924	14237S	PARTICIPANT	\N	PRESENT	0
291854	273924	14061L	PARTICIPANT	\N	PRESENT	0
291855	273924	14357A	PARTICIPANT	\N	PRESENT	0
291856	273924	11090Q	PARTICIPANT	\N	PRESENT	0
291857	273924	14205J	PARTICIPANT	\N	PRESENT	0
291858	273924	14021P	PARTICIPANT	\N	PRESENT	0
291859	273924	19599P	PARTICIPANT	\N	PRESENT	0
291860	273924	08010L	PARTICIPANT	\N	PRESENT	0
291861	273924	95030B	PARTICIPANT	\N	PRESENT	0
291862	273924	11099A	PARTICIPANT	\N	PRESENT	0
291863	273924	19515S	PARTICIPANT	\N	PRESENT	0
291864	273924	14033T	PARTICIPANT	\N	PRESENT	0
291865	273924	19507S	PARTICIPANT	\N	PRESENT	0
291866	273924	18083K	PARTICIPANT	\N	PRESENT	0
291867	273924	08015R	PARTICIPANT	\N	PRESENT	0
291868	273924	11103C	PARTICIPANT	\N	PRESENT	0
291869	273924	19269X	PARTICIPANT	\N	PRESENT	0
291960	273924	80013X	PARTICIPANT	\N	PRESENT	0
291961	273924	19415P	PARTICIPANT	\N	PRESENT	0
291962	273924	19667J	PARTICIPANT	\N	PRESENT	0
291963	273924	14217N	PARTICIPANT	\N	PRESENT	0
291964	273924	19383Y	PARTICIPANT	\N	PRESENT	0
291965	273924	19715Y	PARTICIPANT	\N	PRESENT	0
291966	273924	14042U	PARTICIPANT	\N	PRESENT	0
291967	273924	19749K	PARTICIPANT	\N	PRESENT	0
291968	273924	08031R	PARTICIPANT	\N	PRESENT	0
291969	273924	89017R	PARTICIPANT	\N	PRESENT	0
291970	273924	14026U	PARTICIPANT	\N	PRESENT	0
291971	273924	19621T	PARTICIPANT	\N	PRESENT	0
291972	273924	14241N	PARTICIPANT	\N	PRESENT	0
291973	273924	19553Y	PARTICIPANT	\N	PRESENT	0
291975	273924	05008E	PARTICIPANT	\N	PRESENT	0
291976	273924	14329V	PARTICIPANT	\N	PRESENT	0
291977	273924	19679N	PARTICIPANT	\N	PRESENT	0
291978	273924	19611R	PARTICIPANT	\N	PRESENT	0
291979	273924	11077T	PARTICIPANT	\N	PRESENT	0
291980	273924	19349W	PARTICIPANT	\N	PRESENT	0
291981	273924	19703U	PARTICIPANT	\N	PRESENT	0
291982	273924	19713W	PARTICIPANT	\N	PRESENT	0
291983	273924	14331P	PARTICIPANT	\N	PRESENT	0
291984	291974	07034Q	PARTICIPANT	\N	PRESENT	0
291985	291974	01028R	PARTICIPANT	\N	PRESENT	0
271241	270317	19713W	PARTICIPANT	\N	PRESENT	0
271244	270317	04061F	PARTICIPANT	\N	PRESENT	0
276035	273522	19621T	PARTICIPANT	\N	PRESENT	0
292394	275857	19663E	PARTICIPANT	\N	PRESENT	0
295317	295313	08058D	PARTICIPANT	\N	PRESENT	0
295318	295313	98029W	PARTICIPANT	\N	PRESENT	0
295319	295313	14267Y	PARTICIPANT	\N	PRESENT	0
295320	295313	14079W	PARTICIPANT	\N	PRESENT	0
295321	295313	19251M	PARTICIPANT	\N	PRESENT	0
295322	295313	04035D	PARTICIPANT	\N	PRESENT	0
295323	295313	19709B	PARTICIPANT	\N	PRESENT	0
295324	295313	16685X	PARTICIPANT	\N	PRESENT	0
295334	295313	08047A	PARTICIPANT	\N	PRESENT	0
295326	295313	14193X	PARTICIPANT	\N	PRESENT	0
295327	295313	19443T	PARTICIPANT	\N	PRESENT	0
295328	295313	01058X	PARTICIPANT	\N	PRESENT	0
295329	295313	19669L	PARTICIPANT	\N	PRESENT	0
295330	295313	11066Q	PARTICIPANT	\N	PRESENT	0
295331	295313	04034C	PARTICIPANT	\N	PRESENT	0
295341	292898	14147R	PARTICIPANT	\N	PRESENT	0
295340	292898	02002K	PARTICIPANT	\N	PRESENT	0
295343	292898	14107H	PARTICIPANT	\N	PRESENT	0
295348	293230	14034U	PARTICIPANT	\N	PRESENT	0
295351	295349	14299H	PARTICIPANT	\N	PRESENT	0
295352	295349	19709B	PARTICIPANT	\N	PRESENT	0
295353	295349	01048V	PARTICIPANT	\N	PRESENT	0
295356	295355	04070G	PARTICIPANT	\N	PRESENT	0
295357	295355	11043H	PARTICIPANT	\N	PRESENT	0
295359	295355	19643A	PARTICIPANT	\N	PRESENT	0
295360	295355	19533U	PARTICIPANT	\N	PRESENT	0
295361	295355	19573D	PARTICIPANT	\N	PRESENT	0
295362	295355	08012N	PARTICIPANT	\N	PRESENT	0
295363	295355	14063N	PARTICIPANT	\N	PRESENT	0
295364	295355	14107H	PARTICIPANT	\N	PRESENT	0
295365	295355	14249W	PARTICIPANT	\N	PRESENT	0
295366	295355	19611R	PARTICIPANT	\N	PRESENT	0
295585	295584	99004R	PARTICIPANT	\N	PRESENT	0
295629	293466	08052W	PRESIDENT	0	PRESENT	0
295630	293466	19575F	PARTICIPANT	\N	EXCUSE	0
295631	293466	95062K	PARTICIPANT	\N	EXCUSE	0
295632	293462	08052W	PARTICIPANT	\N	PRESENT	0
295634	295633	19647E	PARTICIPANT	\N	PRESENT	0
295635	295633	11070L	PARTICIPANT	\N	PRESENT	0
295647	295646	11053K	PARTICIPANT	\N	PRESENT	0
295315	295313	14133K	PARTICIPANT	\N	PRESENT	0
295316	295313	04040A	PARTICIPANT	\N	PRESENT	0
295648	295646	14083S	PARTICIPANT	\N	PRESENT	0
295649	295646	11097X	PARTICIPANT	\N	PRESENT	0
295650	295646	19611R	PARTICIPANT	\N	PRESENT	0
295651	295646	14081Q	PARTICIPANT	\N	PRESENT	0
295674	295673	11099A	PARTICIPANT	\N	PRESENT	0
295677	295676	11099A	PARTICIPANT	\N	PRESENT	0
295682	295679	04092N	PARTICIPANT	\N	PRESENT	0
295683	295679	01034P	PARTICIPANT	\N	PRESENT	0
295684	295680	04092N	PARTICIPANT	\N	PRESENT	0
295685	295680	01034P	PARTICIPANT	\N	PRESENT	0
295779	295778	05008E	PARTICIPANT	\N	PRESENT	0
295780	295778	14179A	PARTICIPANT	\N	PRESENT	0
295781	295778	19447X	PARTICIPANT	\N	PRESENT	0
295782	295778	11026G	PARTICIPANT	\N	PRESENT	0
295783	295778	14065Q	PARTICIPANT	\N	PRESENT	0
295784	295778	19719D	PARTICIPANT	\N	PRESENT	0
295785	295778	14053L	PARTICIPANT	\N	PRESENT	0
295787	295786	05008E	PARTICIPANT	\N	PRESENT	0
295788	295786	04047H	PARTICIPANT	\N	PRESENT	0
295789	295786	04085P	PARTICIPANT	\N	PRESENT	0
295790	295786	14065Q	PARTICIPANT	\N	PRESENT	0
295791	295786	14089Y	PARTICIPANT	\N	PRESENT	0
295792	295786	19253P	PARTICIPANT	\N	PRESENT	0
295793	295786	14215L	PARTICIPANT	\N	PRESENT	0
295802	295801	05008E	PARTICIPANT	\N	PRESENT	0
295803	295801	14065Q	PARTICIPANT	\N	PRESENT	0
295796	295786	14123H	PARTICIPANT	\N	PRESENT	0
295797	295786	14179A	PARTICIPANT	\N	PRESENT	0
295798	295786	19447X	PARTICIPANT	\N	PRESENT	0
295799	295786	11026G	PARTICIPANT	\N	PRESENT	0
297238	297237	19575F	PARTICIPANT	\N	PRESENT	0
295804	295801	14089Y	PARTICIPANT	\N	PRESENT	0
295805	295801	14053L	PARTICIPANT	\N	PRESENT	0
297239	297237	19549D	PARTICIPANT	\N	PRESENT	0
295807	295801	19719D	PARTICIPANT	\N	PRESENT	0
295808	295801	14215L	PARTICIPANT	\N	PRESENT	0
297240	297237	19747H	PARTICIPANT	\N	PRESENT	0
295810	295801	14179A	PARTICIPANT	\N	PRESENT	0
297241	297237	14083S	PARTICIPANT	\N	PRESENT	0
297242	297237	14038Y	PARTICIPANT	\N	PRESENT	0
295813	295801	11026G	PARTICIPANT	\N	PRESENT	0
295814	295801	11072N	PARTICIPANT	\N	PRESENT	0
295815	295801	04044E	PARTICIPANT	\N	PRESENT	0
297243	297237	14357A	PARTICIPANT	\N	PRESENT	0
297244	297237	14033T	PARTICIPANT	\N	PRESENT	0
297245	297237	19333N	PARTICIPANT	\N	PRESENT	0
297246	297237	04061F	PARTICIPANT	\N	PRESENT	0
297247	297237	14257W	PARTICIPANT	\N	PRESENT	0
297248	297237	14265W	PARTICIPANT	\N	PRESENT	0
297249	297237	04088S	PARTICIPANT	\N	PRESENT	0
297250	297237	19503N	PARTICIPANT	\N	PRESENT	0
297251	297237	19619A	PARTICIPANT	\N	PRESENT	0
297290	297289	14193X	PARTICIPANT	\N	PRESENT	0
297293	297291	19467C	PARTICIPANT	\N	PRESENT	0
297294	297291	88008L	PARTICIPANT	\N	PRESENT	0
297295	297291	14205J	PARTICIPANT	\N	PRESENT	0
297296	297291	04088S	PARTICIPANT	\N	PRESENT	0
297297	297291	98050T	PARTICIPANT	\N	PRESENT	0
297298	297291	14265W	PARTICIPANT	\N	PRESENT	0
297339	297338	11109J	PARTICIPANT	\N	EXCUSE	0
297340	297338	14079W	PARTICIPANT	\N	EXCUSE	0
297341	297338	10006L	PARTICIPANT	\N	PRESENT	0
297342	297338	08045X	PARTICIPANT	\N	PRESENT	0
297343	297338	19347U	PARTICIPANT	\N	PRESENT	0
297344	297338	14213J	PARTICIPANT	\N	EXCUSE	0
297345	297338	11099A	PARTICIPANT	\N	PRESENT	0
297346	297338	04049K	PARTICIPANT	\N	EXCUSE	0
297347	297338	19441R	PARTICIPANT	\N	PRESENT	0
297348	297338	14109K	PARTICIPANT	\N	PRESENT	0
297349	297338	14169X	PRESIDENT	0	PRESENT	0
297350	297338	19503N	PARTICIPANT	\N	PRESENT	0
297351	297338	04043D	PARTICIPANT	\N	PRESENT	0
297352	297338	04045F	PARTICIPANT	\N	PRESENT	0
297355	297354	14219Q	PARTICIPANT	\N	PRESENT	0
297357	297354	14135M	PARTICIPANT	\N	EXCUSE	0
297359	297358	14259Y	PARTICIPANT	\N	PRESENT	0
297360	297358	14059S	PARTICIPANT	\N	PRESENT	0
297377	294985	14255U	PARTICIPANT	\N	EXCUSE	0
297378	294985	04035D	PARTICIPANT	\N	EXCUSE	0
297379	294985	98022P	PARTICIPANT	\N	EXCUSE	0
297386	294986	14255U	PARTICIPANT	\N	EXCUSE	0
297387	294986	04035D	PARTICIPANT	\N	EXCUSE	0
297388	294986	98022P	PARTICIPANT	\N	EXCUSE	0
298592	298591	14115H	PARTICIPANT	\N	PRESENT	0
298593	298591	08060W	PARTICIPANT	\N	PRESENT	0
298594	298591	14207L	PARTICIPANT	\N	PRESENT	0
298618	298617	04047H	PARTICIPANT	\N	PRESENT	0
298596	298591	14357A	PARTICIPANT	\N	PRESENT	0
298597	298591	19507S	PARTICIPANT	\N	PRESENT	0
298598	298591	14033T	PARTICIPANT	\N	PRESENT	0
298599	298591	14205J	PARTICIPANT	\N	PRESENT	0
298619	298617	14065Q	PARTICIPANT	\N	PRESENT	0
298601	298591	19563B	PARTICIPANT	\N	PRESENT	0
298602	298591	14257W	PARTICIPANT	\N	PRESENT	0
298603	298591	11090Q	PARTICIPANT	\N	PRESENT	0
298620	298617	01024M	PARTICIPANT	\N	PRESENT	0
298813	295875	19349W	PARTICIPANT	\N	PRESENT	0
298814	296100	19349W	PARTICIPANT	\N	PRESENT	0
298815	297304	19349W	PARTICIPANT	\N	PRESENT	0
298957	298622	01043Q	PARTICIPANT	\N	PRESENT	0
298959	298958	19575F	PARTICIPANT	\N	PRESENT	0
299030	299029	01034P	PARTICIPANT	\N	PRESENT	0
298961	298958	08052W	PARTICIPANT	\N	PRESENT	0
299034	294210	19713W	PARTICIPANT	\N	PRESENT	0
298963	298958	14087W	PARTICIPANT	\N	PRESENT	0
298964	298958	19521Q	PARTICIPANT	\N	PRESENT	0
298965	298958	19553Y	PARTICIPANT	\N	PRESENT	0
298966	298958	19611R	PARTICIPANT	\N	PRESENT	0
298967	298958	19697Q	PARTICIPANT	\N	PRESENT	0
298968	298958	11067R	PARTICIPANT	\N	PRESENT	0
299036	294211	19713W	PARTICIPANT	\N	PRESENT	0
298970	298958	14071N	PARTICIPANT	\N	PRESENT	0
298971	298958	19679N	PARTICIPANT	\N	PRESENT	0
299051	299050	08009T	PARTICIPANT	\N	PRESENT	0
299771	298280	14327T	PARTICIPANT	\N	PRESENT	0
299772	298280	14331P	PARTICIPANT	\N	PRESENT	0
299773	298280	11053K	PARTICIPANT	\N	PRESENT	0
299774	298280	19667J	PARTICIPANT	\N	PRESENT	0
299775	298280	89017R	PARTICIPANT	\N	PRESENT	0
299776	298280	11074Q	PRESIDENT	0	PRESENT	0
272034	272033	11053K	PARTICIPANT	\N	PRESENT	0
272035	272033	14159V	PARTICIPANT	\N	PRESENT	0
272036	272033	05012A	PARTICIPANT	\N	PRESENT	0
272038	272037	08015R	PARTICIPANT	\N	PRESENT	0
272039	272037	14001X	PARTICIPANT	\N	PRESENT	0
272040	272037	19735D	PARTICIPANT	\N	PRESENT	0
272041	272037	88008L	PARTICIPANT	\N	PRESENT	0
272042	272037	89017R	PARTICIPANT	\N	PRESENT	0
272207	272206	95063L	PARTICIPANT	\N	PRESENT	0
275712	268444	14093U	PARTICIPANT	\N	EXCUSE	0
275820	275819	11083R	PARTICIPANT	\N	PRESENT	0
275821	275819	19583F	PARTICIPANT	\N	PRESENT	0
275822	275819	04057K	PARTICIPANT	\N	PRESENT	0
275823	275819	14265W	PARTICIPANT	\N	PRESENT	0
275824	275819	04088S	PARTICIPANT	\N	PRESENT	0
275825	275819	19585H	PARTICIPANT	\N	PRESENT	0
275827	275826	08058D	PARTICIPANT	\N	PRESENT	0
275828	275826	11049P	PARTICIPANT	\N	PRESENT	0
275829	275826	14097Y	PARTICIPANT	\N	PRESENT	0
275830	275826	19443T	PARTICIPANT	\N	PRESENT	0
275832	275831	14215L	PARTICIPANT	\N	PRESENT	0
278173	278171	89017R	PARTICIPANT	\N	PRESENT	0
278174	278171	10006L	PARTICIPANT	\N	PRESENT	0
278175	278171	11049P	PARTICIPANT	\N	PRESENT	0
278177	278171	19745F	PARTICIPANT	\N	PRESENT	0
278180	278171	11063M	PARTICIPANT	\N	PRESENT	0
278182	278171	19741B	PARTICIPANT	\N	PRESENT	0
278225	278171	88008L	PARTICIPANT	\N	PRESENT	0
278235	278234	10006L	PARTICIPANT	\N	PRESENT	0
278236	278234	19741B	PARTICIPANT	\N	PRESENT	0
278237	278234	14255U	PARTICIPANT	\N	PRESENT	0
278238	278234	11049P	PARTICIPANT	\N	PRESENT	0
278239	278234	14073Q	PARTICIPANT	\N	PRESENT	0
278240	278234	08031R	PARTICIPANT	\N	PRESENT	0
278241	278234	16685X	PARTICIPANT	\N	PRESENT	0
278242	278234	19687N	PARTICIPANT	\N	PRESENT	0
280416	278759	14219Q	PARTICIPANT	\N	PRESENT	0
280417	278759	18083K	PARTICIPANT	\N	PRESENT	0
280418	278759	14237S	PARTICIPANT	\N	PRESENT	0
280419	278759	19551W	PARTICIPANT	\N	PRESENT	0
280420	278759	96004D	PARTICIPANT	\N	PRESENT	0
280421	278759	98023Q	PARTICIPANT	\N	PRESENT	0
280422	278759	14031R	PARTICIPANT	\N	PRESENT	0
280423	278759	15447F	PARTICIPANT	\N	PRESENT	0
280424	278759	14093U	PARTICIPANT	\N	PRESENT	0
280425	278759	19563B	PARTICIPANT	\N	PRESENT	0
280426	278759	19383Y	PARTICIPANT	\N	PRESENT	0
280427	278759	17583W	PARTICIPANT	\N	PRESENT	0
280428	278759	19387D	PARTICIPANT	\N	PRESENT	0
280429	278759	08024S	PARTICIPANT	\N	PRESENT	0
280430	278759	14157T	PARTICIPANT	\N	PRESENT	0
280431	278759	04097T	PARTICIPANT	\N	PRESENT	0
280432	279288	19697Q	PARTICIPANT	\N	PRESENT	0
280433	279288	11067R	PARTICIPANT	\N	PRESENT	0
280434	279288	11077T	PARTICIPANT	\N	PRESENT	0
280435	279288	14355X	PARTICIPANT	\N	PRESENT	0
280436	279288	11097X	PARTICIPANT	\N	PRESENT	0
280437	279288	19415P	PARTICIPANT	\N	PRESENT	0
280438	279288	14223L	PARTICIPANT	\N	PRESENT	0
280439	279288	04045F	PARTICIPANT	\N	PRESENT	0
280440	279288	14026U	PARTICIPANT	\N	PRESENT	0
280441	279288	14227Q	PARTICIPANT	\N	PRESENT	0
280442	279288	19675J	PARTICIPANT	\N	PRESENT	0
280443	279288	17779H	PARTICIPANT	\N	PRESENT	0
280444	279288	19703U	PARTICIPANT	\N	PRESENT	0
280445	279288	14239U	PARTICIPANT	\N	PRESENT	0
280446	279288	19553Y	PARTICIPANT	\N	PRESENT	0
280447	279288	11031D	PARTICIPANT	\N	PRESENT	0
280448	279288	14087W	PARTICIPANT	\N	PRESENT	0
280449	279288	14281W	PARTICIPANT	\N	PRESENT	0
280450	279288	19679N	PARTICIPANT	\N	PRESENT	0
280451	279288	14042U	PARTICIPANT	\N	PRESENT	0
280452	279288	19575F	PARTICIPANT	\N	PRESENT	0
280453	279288	14195A	PARTICIPANT	\N	PRESENT	0
280454	279288	19367Y	PARTICIPANT	\N	PRESENT	0
280455	279288	14213J	PARTICIPANT	\N	PRESENT	0
280456	279288	14217N	PARTICIPANT	\N	PRESENT	0
280457	279288	19335Q	PARTICIPANT	\N	PRESENT	0
280458	279288	10006L	PARTICIPANT	\N	PRESENT	0
280459	279288	19521Q	PARTICIPANT	\N	PRESENT	0
280460	279288	98024R	PARTICIPANT	\N	PRESENT	0
280461	279288	19527W	PARTICIPANT	\N	PRESENT	0
280462	279288	01034P	PARTICIPANT	\N	PRESENT	0
280463	279288	04092N	PRESIDENT	0	PRESENT	0
280464	279288	08052W	PARTICIPANT	\N	PRESENT	0
280465	279288	19715Y	PARTICIPANT	\N	PRESENT	0
280466	279288	19691J	PARTICIPANT	\N	PRESENT	0
280467	279288	19727D	PARTICIPANT	\N	PRESENT	0
280468	279288	14119M	PARTICIPANT	\N	PRESENT	0
280469	279288	11103C	PARTICIPANT	\N	PRESENT	0
280470	279288	14071N	PARTICIPANT	\N	PRESENT	0
280471	279288	19657G	PARTICIPANT	\N	PRESENT	0
280472	279288	08048B	PARTICIPANT	\N	EXCUSE	0
280473	279288	08041T	PARTICIPANT	\N	EXCUSE	0
280474	280178	19643A	PARTICIPANT	\N	PRESENT	0
280475	280178	04070G	PRESIDENT	0	PRESENT	0
280476	280178	14061L	PARTICIPANT	\N	PRESENT	0
280477	280178	19699S	PARTICIPANT	\N	PRESENT	0
280478	280178	14073Q	PARTICIPANT	\N	PRESENT	0
280479	280178	19611R	PARTICIPANT	\N	PRESENT	0
280480	280178	08043V	PARTICIPANT	\N	PRESENT	0
280481	280178	87003B	PARTICIPANT	\N	PRESENT	0
280482	280178	14241N	PARTICIPANT	\N	PRESENT	0
280483	280178	19731Y	PARTICIPANT	\N	PRESENT	0
280484	280178	08020N	PARTICIPANT	\N	PRESENT	0
280485	280178	14251Q	PARTICIPANT	\N	PRESENT	0
280486	280178	14107H	PARTICIPANT	\N	PRESENT	0
280487	280178	08017T	PARTICIPANT	\N	PRESENT	0
280488	280178	14063N	PARTICIPANT	\N	PRESENT	0
280489	280178	11083R	PARTICIPANT	\N	PRESENT	0
280490	280178	14123H	PARTICIPANT	\N	PRESENT	0
280491	280178	08012N	PARTICIPANT	\N	PRESENT	0
280492	280178	04018C	PARTICIPANT	\N	PRESENT	0
280493	280178	19758L	PARTICIPANT	\N	PRESENT	0
280494	280178	08039A	PARTICIPANT	\N	PRESENT	0
280495	280178	08031R	PARTICIPANT	\N	PRESENT	0
280496	280178	14059S	PARTICIPANT	\N	EXCUSE	0
280497	280178	19735D	PARTICIPANT	\N	EXCUSE	0
280498	278438	19369B	PARTICIPANT	\N	EXCUSE	0
280502	279254	14083S	PARTICIPANT	\N	EXCUSE	0
280503	279254	11012A	PARTICIPANT	\N	EXCUSE	0
280504	279254	08014Q	PARTICIPANT	\N	EXCUSE	0
280505	279254	88008L	PARTICIPANT	\N	EXCUSE	0
280507	280499	19515S	PARTICIPANT	\N	PRESENT	0
280508	280499	19533U	PARTICIPANT	\N	PRESENT	0
280509	280499	14357A	PARTICIPANT	\N	PRESENT	0
280510	280499	19441R	PARTICIPANT	\N	PRESENT	0
280511	280499	14081Q	PARTICIPANT	\N	PRESENT	0
280512	280499	19413M	PARTICIPANT	\N	PRESENT	0
280513	280499	80013X	PARTICIPANT	\N	PRESENT	0
280514	280499	19631V	PARTICIPANT	\N	PRESENT	0
280515	280499	08021P	PARTICIPANT	\N	PRESENT	0
280516	280499	11099A	PARTICIPANT	\N	PRESENT	0
280517	280499	08068F	PARTICIPANT	\N	PRESENT	0
280518	280499	04049K	PARTICIPANT	\N	PRESENT	0
280519	280499	19705W	PARTICIPANT	\N	PRESENT	0
280520	280499	19707Y	PARTICIPANT	\N	PRESENT	0
280521	280499	08015R	PARTICIPANT	\N	PRESENT	0
280522	280499	08019V	PARTICIPANT	\N	PRESENT	0
280523	280499	19369B	PARTICIPANT	\N	PRESENT	0
280524	280499	19511N	PARTICIPANT	\N	PRESENT	0
280525	280499	08028W	PARTICIPANT	\N	PRESENT	0
280526	280499	14265W	PARTICIPANT	\N	PRESENT	0
280527	280499	14135M	PARTICIPANT	\N	PRESENT	0
280528	280499	19467C	PARTICIPANT	\N	PRESENT	0
280529	280499	11048N	PARTICIPANT	\N	PRESENT	0
280530	280499	14187A	PARTICIPANT	\N	PRESENT	0
280531	280499	08038Y	PARTICIPANT	\N	PRESENT	0
280532	280499	08062Y	PARTICIPANT	\N	PRESENT	0
280533	280499	19301E	PARTICIPANT	\N	PRESENT	0
280534	280499	19695N	PARTICIPANT	\N	PRESENT	0
280535	280499	14033T	PARTICIPANT	\N	PRESENT	0
280536	280499	11090Q	PRESIDENT	0	PRESENT	0
280537	280499	01025N	PARTICIPANT	\N	PRESENT	0
280538	280499	19295A	PARTICIPANT	\N	PRESENT	0
280539	280499	19269X	PARTICIPANT	\N	PRESENT	0
280540	280499	14205J	PARTICIPANT	\N	PRESENT	0
280541	280499	04088S	PARTICIPANT	\N	PRESENT	0
280542	280499	11056N	PARTICIPANT	\N	PRESENT	0
280543	280499	14115H	PARTICIPANT	\N	PRESENT	0
280544	280499	11101A	PARTICIPANT	\N	PRESENT	0
280545	280499	19507S	PARTICIPANT	\N	PRESENT	0
280546	280499	98050T	PARTICIPANT	\N	PRESENT	0
280547	280499	19747H	PARTICIPANT	\N	PRESENT	0
280548	280499	14207L	PARTICIPANT	\N	PRESENT	0
280549	280499	19619A	PARTICIPANT	\N	PRESENT	0
280550	280499	17589D	PARTICIPANT	\N	PRESENT	0
280551	280499	14257W	PARTICIPANT	\N	PRESENT	0
280552	280499	04089T	PARTICIPANT	\N	EXCUSE	0
286026	286025	14133K	PARTICIPANT	\N	PRESENT	0
286027	286025	14193X	PARTICIPANT	\N	PRESENT	0
286028	286025	08058D	PARTICIPANT	\N	PRESENT	0
287991	273917	14034U	PARTICIPANT	\N	PRESENT	0
287992	273917	08018U	PARTICIPANT	\N	PRESENT	0
287993	273917	14151M	PARTICIPANT	\N	PRESENT	0
287994	273917	19649G	PARTICIPANT	\N	PRESENT	0
287995	273917	19631V	PARTICIPANT	\N	PRESENT	0
287996	273917	95063L	PARTICIPANT	\N	PRESENT	0
287997	273917	11083R	PARTICIPANT	\N	PRESENT	0
287998	273917	11064N	PARTICIPANT	\N	PRESENT	0
287999	273917	14219Q	PARTICIPANT	\N	PRESENT	0
288000	273917	14089Y	PARTICIPANT	\N	PRESENT	0
288001	273917	08056B	PARTICIPANT	\N	PRESENT	0
288002	273917	14041T	PARTICIPANT	\N	PRESENT	0
288003	273917	14105F	PARTICIPANT	\N	PRESENT	0
288004	273917	14147R	PARTICIPANT	\N	PRESENT	0
288005	273917	14063N	PARTICIPANT	\N	PRESENT	0
288006	273917	14197C	PARTICIPANT	\N	PRESENT	0
288007	273917	11103C	PARTICIPANT	\N	PRESENT	0
288008	273917	19711U	PARTICIPANT	\N	PRESENT	0
288009	273917	19447X	PARTICIPANT	\N	PRESENT	0
288010	273917	14033T	PARTICIPANT	\N	PRESENT	0
288011	273917	19731Y	PARTICIPANT	\N	PRESENT	0
288012	273917	19701S	PARTICIPANT	\N	PRESENT	0
288013	273917	11012A	PARTICIPANT	\N	PRESENT	0
288014	273917	11026G	PARTICIPANT	\N	PRESENT	0
288015	273917	19729F	PARTICIPANT	\N	PRESENT	0
288016	273917	11040E	PARTICIPANT	\N	PRESENT	0
288017	273917	14021P	PARTICIPANT	\N	PRESENT	0
288018	273917	19669L	PARTICIPANT	\N	PRESENT	0
288019	273917	14121F	PARTICIPANT	\N	PRESENT	0
288020	273917	08010L	PARTICIPANT	\N	PRESENT	0
288021	273917	14223L	PARTICIPANT	\N	PRESENT	0
288022	273917	18083K	PARTICIPANT	\N	PRESENT	0
288023	273917	19741B	PARTICIPANT	\N	PRESENT	0
288024	273917	07029T	PARTICIPANT	\N	PRESENT	0
288025	273917	19387D	PARTICIPANT	\N	PRESENT	0
288026	273917	88008L	PARTICIPANT	\N	PRESENT	0
288027	273917	04018C	PARTICIPANT	\N	PRESENT	0
288028	273917	19599P	PARTICIPANT	\N	PRESENT	0
288029	273917	14107H	PARTICIPANT	\N	PRESENT	0
288030	273917	11045K	PARTICIPANT	\N	PRESENT	0
288031	273917	19415P	PARTICIPANT	\N	PRESENT	0
288032	273917	19581D	PARTICIPANT	\N	PRESENT	0
288033	273917	14073Q	PARTICIPANT	\N	PRESENT	0
288034	273917	19737F	PARTICIPANT	\N	PRESENT	0
288035	273917	14029X	PARTICIPANT	\N	PRESENT	0
288036	273917	01028R	PARTICIPANT	\N	PRESENT	0
288037	273917	14028W	PARTICIPANT	\N	PRESENT	0
288038	273917	05008E	PARTICIPANT	\N	PRESENT	0
288040	273917	19251M	PARTICIPANT	\N	PRESENT	0
288041	273917	14065Q	PARTICIPANT	\N	PRESENT	0
288042	273917	14030Q	PARTICIPANT	\N	PRESENT	0
288043	273917	08020N	PARTICIPANT	\N	PRESENT	0
288044	273917	19545Y	PARTICIPANT	\N	PRESENT	0
288046	273917	14229S	PARTICIPANT	\N	PRESENT	0
288047	273917	14267Y	PARTICIPANT	\N	PRESENT	0
288048	273917	19699S	PARTICIPANT	\N	PRESENT	0
288049	273917	19253P	PARTICIPANT	\N	PRESENT	0
288050	273917	19758L	PARTICIPANT	\N	PRESENT	0
288051	273917	07034Q	PARTICIPANT	\N	PRESENT	0
288054	273917	19629C	PARTICIPANT	\N	PRESENT	0
288055	273917	19683J	PARTICIPANT	\N	PRESENT	0
288058	273917	04059M	PARTICIPANT	\N	PRESENT	0
288059	273917	04047H	PARTICIPANT	\N	PRESENT	0
288060	273917	11048N	PARTICIPANT	\N	PRESENT	0
288065	273917	19399H	PARTICIPANT	\N	PRESENT	0
288066	273917	14251Q	PARTICIPANT	\N	PRESENT	0
288068	273917	11109J	PARTICIPANT	\N	PRESENT	0
288070	273917	14055N	PARTICIPANT	\N	PRESENT	0
288139	281196	05008E	PARTICIPANT	\N	PRESENT	0
288140	281196	19758L	PARTICIPANT	\N	PRESENT	0
288141	281196	11040E	PARTICIPANT	\N	PRESENT	0
288142	281196	14235Q	PARTICIPANT	\N	PRESENT	0
288143	281196	01028R	PARTICIPANT	\N	PRESENT	0
288144	281196	14021P	PARTICIPANT	\N	PRESENT	0
288145	281196	19599P	PARTICIPANT	\N	PRESENT	0
288146	281196	04059M	PARTICIPANT	\N	PRESENT	0
288147	281196	14065Q	PARTICIPANT	\N	PRESENT	0
288148	281196	11066Q	PARTICIPANT	\N	PRESENT	0
288149	281196	14229S	PARTICIPANT	\N	PRESENT	0
288150	281196	19669L	PARTICIPANT	\N	PRESENT	0
288151	281196	11045K	PARTICIPANT	\N	PRESENT	0
288152	281196	11026G	PARTICIPANT	\N	PRESENT	0
288153	281196	19251M	PARTICIPANT	\N	PRESENT	0
288154	281196	08017T	PARTICIPANT	\N	PRESENT	0
288155	281196	14107H	PARTICIPANT	\N	PRESENT	0
288156	281196	14151M	PARTICIPANT	\N	PRESENT	0
288157	281196	14028W	PARTICIPANT	\N	PRESENT	0
288158	281196	19683J	PARTICIPANT	\N	PRESENT	0
288159	281196	14121F	PARTICIPANT	\N	PRESENT	0
288160	281196	11109J	PARTICIPANT	\N	PRESENT	0
288161	281196	04057K	PARTICIPANT	\N	PRESENT	0
288162	281196	14251Q	PARTICIPANT	\N	PRESENT	0
288163	281196	19387D	PARTICIPANT	\N	PRESENT	0
288164	281196	14039A	PARTICIPANT	\N	PRESENT	0
288165	281196	95063L	PARTICIPANT	\N	PRESENT	0
288166	281196	19629C	PARTICIPANT	\N	PRESENT	0
288167	281196	19253P	PARTICIPANT	\N	PRESENT	0
288168	281196	08031R	PARTICIPANT	\N	PRESENT	0
288169	281196	14261S	PARTICIPANT	\N	PRESENT	0
288170	281196	19737F	PARTICIPANT	\N	PRESENT	0
288171	281196	19699S	PARTICIPANT	\N	PRESENT	0
288172	281196	11072N	PARTICIPANT	\N	PRESENT	0
288173	281196	19543W	PARTICIPANT	\N	PRESENT	0
288174	281196	19581D	PARTICIPANT	\N	PRESENT	0
288175	281196	04018C	PARTICIPANT	\N	PRESENT	0
288176	281196	19701S	PARTICIPANT	\N	PRESENT	0
288177	281196	19731Y	PARTICIPANT	\N	PRESENT	0
288178	281196	14055N	PARTICIPANT	\N	PRESENT	0
288179	281196	19533U	PARTICIPANT	\N	PRESENT	0
288180	281196	14217N	PARTICIPANT	\N	PRESENT	0
288181	281196	07029T	PARTICIPANT	\N	PRESENT	0
288182	281196	08018U	PARTICIPANT	\N	PRESENT	0
288183	281196	18083K	PARTICIPANT	\N	PRESENT	0
288184	281196	14029X	PARTICIPANT	\N	PRESENT	0
288185	281196	19447X	PARTICIPANT	\N	PRESENT	0
288186	281196	19673G	PARTICIPANT	\N	PRESENT	0
288187	281196	08020N	PARTICIPANT	\N	PRESENT	0
288188	281196	99004R	PARTICIPANT	\N	PRESENT	0
288189	281196	19711U	PARTICIPANT	\N	PRESENT	0
288190	281196	14223L	PARTICIPANT	\N	PRESENT	0
288191	281196	14249W	PARTICIPANT	\N	PRESENT	0
288192	281196	04044E	PARTICIPANT	\N	PRESENT	0
288193	281196	19329S	PARTICIPANT	\N	PRESENT	0
288194	281196	08010L	PARTICIPANT	\N	PRESENT	0
288195	281196	11033F	PARTICIPANT	\N	PRESENT	0
288196	281196	04085P	PARTICIPANT	\N	PRESENT	0
288197	281196	19347U	PARTICIPANT	\N	PRESENT	0
288198	281196	19551W	PARTICIPANT	\N	PRESENT	0
288199	281196	19649G	PARTICIPANT	\N	PRESENT	0
288200	281196	11027H	PARTICIPANT	\N	PRESENT	0
288201	281196	14001X	PARTICIPANT	\N	PRESENT	0
288202	281196	14105F	PARTICIPANT	\N	PRESENT	0
288203	281196	19693L	PARTICIPANT	\N	PRESENT	0
288204	281196	19399H	PARTICIPANT	\N	PRESENT	0
288137	281196	14034U	PARTICIPANT	\N	PRESENT	0
288138	281196	04047H	PARTICIPANT	\N	PRESENT	0
288205	281196	19729F	PARTICIPANT	\N	PRESENT	0
288206	281196	19591F	PARTICIPANT	\N	PRESENT	0
288207	281196	14073Q	PARTICIPANT	\N	PRESENT	0
288208	281196	08034U	PARTICIPANT	\N	PRESENT	0
288209	281196	14197C	PARTICIPANT	\N	PRESENT	0
288210	281196	14257W	PARTICIPANT	\N	PRESENT	0
288212	281196	14265W	PARTICIPANT	\N	PRESENT	0
288213	281196	19715Y	PARTICIPANT	\N	PRESENT	0
288214	281196	14053L	PARTICIPANT	\N	PRESENT	0
288215	281196	19503N	PARTICIPANT	\N	PRESENT	0
288216	281196	14123H	PARTICIPANT	\N	PRESENT	0
288217	281196	11056N	PARTICIPANT	\N	PRESENT	0
288218	281196	88008L	PARTICIPANT	\N	PRESENT	0
288219	281196	10006L	PARTICIPANT	\N	PRESENT	0
288220	281196	14193X	PARTICIPANT	\N	PRESENT	0
288221	281196	19467C	PARTICIPANT	\N	PRESENT	0
288222	281196	14033T	PARTICIPANT	\N	PRESENT	0
288223	281196	14119M	PARTICIPANT	\N	PRESENT	0
288224	281196	14213J	PARTICIPANT	\N	PRESENT	0
288225	281196	14157T	PARTICIPANT	\N	PRESENT	0
288226	281196	19549D	PARTICIPANT	\N	PRESENT	0
288227	281196	11048N	PARTICIPANT	\N	PRESENT	0
288228	281196	19631V	PARTICIPANT	\N	PRESENT	0
288229	281196	08061X	PARTICIPANT	\N	PRESENT	0
288230	281196	11012A	PARTICIPANT	\N	PRESENT	0
288231	281196	08016S	PARTICIPANT	\N	PRESENT	0
288232	281196	04086Q	PARTICIPANT	\N	PRESENT	0
288233	281196	04035D	PARTICIPANT	\N	PRESENT	0
288234	281196	19689Q	PARTICIPANT	\N	PRESENT	0
274813	268443	19709B	PARTICIPANT	\N	EXCUSE	0
275959	274820	19709B	PARTICIPANT	\N	PRESENT	0
275961	274852	19709B	PARTICIPANT	\N	PRESENT	0
275963	274853	19709B	PARTICIPANT	\N	PRESENT	0
275965	274855	19709B	PARTICIPANT	\N	PRESENT	0
275967	274856	19709B	PARTICIPANT	\N	PRESENT	0
283124	283118	11074Q	PARTICIPANT	\N	PRESENT	0
283126	283118	08011M	PARTICIPANT	\N	PRESENT	0
283432	283431	19647E	PARTICIPANT	\N	PRESENT	0
285386	285385	08024S	PARTICIPANT	\N	PRESENT	0
285387	285385	04043D	PARTICIPANT	\N	PRESENT	0
285388	285385	01058X	PARTICIPANT	\N	PRESENT	0
291986	291974	19729F	PARTICIPANT	\N	PRESENT	0
292017	288053	14235Q	PARTICIPANT	\N	PRESENT	0
292018	288053	11054L	PARTICIPANT	\N	PRESENT	0
292019	273924	14051J	PARTICIPANT	\N	PRESENT	0
292020	273924	19335Q	PARTICIPANT	\N	PRESENT	0
292021	288053	12041X	PARTICIPANT	\N	PRESENT	0
292024	273924	12016W	PARTICIPANT	\N	PRESENT	0
292025	273924	11064N	PARTICIPANT	\N	PRESENT	0
292031	289094	08009T	PRESIDENT	0	PRESENT	0
292032	289094	19685L	PARTICIPANT	\N	EXCUSE	0
292033	289094	19637C	PARTICIPANT	\N	EXCUSE	0
292038	273924	14213J	PARTICIPANT	\N	PRESENT	0
292039	273924	08061X	PARTICIPANT	\N	PRESENT	0
292040	273924	11012A	PARTICIPANT	\N	PRESENT	0
292041	273924	08038Y	PARTICIPANT	\N	PRESENT	0
292042	288053	11027H	PARTICIPANT	\N	PRESENT	0
292043	273924	19521Q	PARTICIPANT	\N	PRESENT	0
292044	289094	14031R	PARTICIPANT	\N	PRESENT	0
292069	289094	19745F	PARTICIPANT	\N	PRESENT	0
292046	289094	96004D	PARTICIPANT	\N	PRESENT	0
292047	289094	19503N	PARTICIPANT	\N	PRESENT	0
292048	289094	04097T	PARTICIPANT	\N	PRESENT	0
292049	289094	14169X	PARTICIPANT	\N	PRESENT	0
292050	273924	19693L	PARTICIPANT	\N	PRESENT	0
292051	273924	14089Y	PARTICIPANT	\N	PRESENT	0
292055	289094	18083K	PARTICIPANT	\N	PRESENT	0
292056	289094	15447F	PARTICIPANT	\N	PRESENT	0
292057	289094	14331P	PARTICIPANT	\N	PRESENT	0
292058	289094	14051J	PARTICIPANT	\N	PRESENT	0
292059	273924	19533U	PARTICIPANT	\N	PRESENT	0
292060	289094	19333N	PARTICIPANT	\N	PRESENT	0
292061	289094	11026G	PARTICIPANT	\N	PRESENT	0
292062	289094	14079W	PARTICIPANT	\N	PRESENT	0
292063	289094	14219Q	PARTICIPANT	\N	PRESENT	0
292064	289094	19599P	PARTICIPANT	\N	PRESENT	0
292065	289094	19725B	PARTICIPANT	\N	PRESENT	0
292066	289094	19739H	PARTICIPANT	\N	PRESENT	0
292070	273924	19733B	PARTICIPANT	\N	PRESENT	0
292071	273924	11109J	PARTICIPANT	\N	PRESENT	0
292072	273924	11067R	PARTICIPANT	\N	PRESENT	0
292073	273924	14229S	PARTICIPANT	\N	PRESENT	0
292074	273924	08034U	PARTICIPANT	\N	PRESENT	0
292075	273924	04057K	PARTICIPANT	\N	PRESENT	0
292079	289094	19551W	PARTICIPANT	\N	PRESENT	0
292080	289094	14237S	PARTICIPANT	\N	PRESENT	0
292090	273924	08024S	PARTICIPANT	\N	PRESENT	0
292091	273924	14281W	PARTICIPANT	\N	PRESENT	0
292096	289094	14089Y	PARTICIPANT	\N	PRESENT	0
292097	273924	95062K	PARTICIPANT	\N	PRESENT	0
292098	273924	14251Q	PARTICIPANT	\N	PRESENT	0
292105	273924	19691J	PARTICIPANT	\N	PRESENT	0
292106	273924	14071N	PARTICIPANT	\N	PRESENT	0
292130	273924	11048N	PARTICIPANT	\N	PRESENT	0
292131	273924	14087W	PARTICIPANT	\N	PRESENT	0
292144	273924	14231L	PARTICIPANT	\N	PRESENT	0
292146	273924	04044E	PARTICIPANT	\N	PRESENT	0
292147	273924	08069G	PARTICIPANT	\N	PRESENT	0
292148	273924	14235Q	PARTICIPANT	\N	PRESENT	0
292245	273925	04086Q	PARTICIPANT	\N	PRESENT	0
292246	273925	14135M	PARTICIPANT	\N	PRESENT	0
292247	273925	11090Q	PARTICIPANT	\N	PRESENT	0
292248	273925	11056N	PARTICIPANT	\N	PRESENT	0
292249	273925	80013X	PARTICIPANT	\N	PRESENT	0
292250	273925	19333N	PARTICIPANT	\N	PRESENT	0
292251	273925	19503N	PARTICIPANT	\N	PRESENT	0
292252	273925	08055A	PARTICIPANT	\N	PRESENT	0
292253	273925	14207L	PARTICIPANT	\N	PRESENT	0
292254	273925	08060W	PARTICIPANT	\N	PRESENT	0
292255	273925	14051J	PARTICIPANT	\N	PRESENT	0
292256	273925	19413M	PARTICIPANT	\N	PRESENT	0
292257	273925	14257W	PARTICIPANT	\N	PRESENT	0
292258	273925	04045F	PARTICIPANT	\N	PRESENT	0
292259	273925	14239U	PARTICIPANT	\N	PRESENT	0
292260	273925	14205J	PARTICIPANT	\N	PRESENT	0
292261	273925	19565D	PARTICIPANT	\N	PRESENT	0
292262	273925	14231L	PARTICIPANT	\N	PRESENT	0
292263	273925	19737F	PARTICIPANT	\N	PRESENT	0
292264	273925	01025N	PARTICIPANT	\N	PRESENT	0
292265	273925	14033T	PARTICIPANT	\N	PRESENT	0
292266	273925	19515S	PARTICIPANT	\N	PRESENT	0
292267	273925	19747H	PARTICIPANT	\N	PRESENT	0
292268	273925	19533U	PARTICIPANT	\N	PRESENT	0
292269	273925	11077T	PARTICIPANT	\N	PRESENT	0
292270	273925	19695N	PARTICIPANT	\N	PRESENT	0
292271	273925	19727D	PARTICIPANT	\N	PRESENT	0
292272	273925	19551W	PARTICIPANT	\N	PRESENT	0
292273	273925	14197C	PARTICIPANT	\N	PRESENT	0
292274	273925	14107H	PARTICIPANT	\N	PRESENT	0
292275	273925	19269X	PARTICIPANT	\N	PRESENT	0
292276	273925	11099A	PARTICIPANT	\N	PRESENT	0
292277	273925	19563B	PARTICIPANT	\N	PRESENT	0
292278	273925	08016S	PARTICIPANT	\N	PRESENT	0
292279	273925	19629C	PARTICIPANT	\N	PRESENT	0
292280	273925	08031R	PARTICIPANT	\N	PRESENT	0
292281	273925	17589D	PARTICIPANT	\N	PRESENT	0
292282	273925	11097X	PARTICIPANT	\N	PRESENT	0
292283	273925	10006L	PARTICIPANT	\N	PRESENT	0
292284	273925	19383Y	PARTICIPANT	\N	PRESENT	0
292285	273925	19507S	PARTICIPANT	\N	PRESENT	0
292286	273925	04088S	PARTICIPANT	\N	PRESENT	0
292287	273925	14157T	PARTICIPANT	\N	PRESENT	0
292288	273925	14115H	PARTICIPANT	\N	PRESENT	0
292289	273925	14357A	PARTICIPANT	\N	PRESENT	0
292290	273925	14329V	PARTICIPANT	\N	PRESENT	0
292291	273925	14061L	PARTICIPANT	\N	PRESENT	0
292292	273925	19713W	PARTICIPANT	\N	PRESENT	0
292293	273925	16685X	PARTICIPANT	\N	PRESENT	0
292294	273925	18083K	PARTICIPANT	\N	PRESENT	0
292295	273925	14038Y	PARTICIPANT	\N	PRESENT	0
292296	273925	14265W	PARTICIPANT	\N	PRESENT	0
292297	273925	19347U	PARTICIPANT	\N	PRESENT	0
292298	273925	19621T	PARTICIPANT	\N	PRESENT	0
292299	273925	14217N	PARTICIPANT	\N	PRESENT	0
292300	273925	19387D	PARTICIPANT	\N	PRESENT	0
292301	273925	14071N	PARTICIPANT	\N	PRESENT	0
292302	273925	19479G	PARTICIPANT	\N	PRESENT	0
292303	273925	14042U	PARTICIPANT	\N	PRESENT	0
292304	273925	08061X	PARTICIPANT	\N	PRESENT	0
292305	273925	14235Q	PARTICIPANT	\N	PRESENT	0
292306	273925	19549D	PARTICIPANT	\N	PRESENT	0
292307	273925	19521Q	PARTICIPANT	\N	PRESENT	0
292308	273925	08069G	PARTICIPANT	\N	PRESENT	0
292309	273925	14221J	PARTICIPANT	\N	PRESENT	0
292310	273925	14030Q	PARTICIPANT	\N	PRESENT	0
292311	273925	19691J	PARTICIPANT	\N	PRESENT	0
292312	273925	14219Q	PARTICIPANT	\N	PRESENT	0
292313	273925	19441R	PARTICIPANT	\N	PRESENT	0
292314	273925	19749K	PARTICIPANT	\N	PRESENT	0
292315	273925	14327T	PARTICIPANT	\N	PRESENT	0
292316	273925	11043H	PARTICIPANT	\N	PRESENT	0
292317	273925	14031R	PARTICIPANT	\N	PRESENT	0
292318	273925	96004D	PARTICIPANT	\N	PRESENT	0
292319	273925	19733B	PARTICIPANT	\N	PRESENT	0
292320	273925	19447X	PARTICIPANT	\N	PRESENT	0
292321	273925	08034U	PARTICIPANT	\N	PRESENT	0
292322	273925	14215L	PARTICIPANT	\N	PRESENT	0
292323	273925	19443T	PARTICIPANT	\N	PRESENT	0
292324	273925	04049K	PARTICIPANT	\N	PRESENT	0
292325	273925	04047H	PARTICIPANT	\N	PRESENT	0
292326	273925	19703U	PARTICIPANT	\N	PRESENT	0
292327	273925	08068F	PARTICIPANT	\N	PRESENT	0
292328	273925	14123H	PARTICIPANT	\N	PRESENT	0
292329	273925	11048N	PARTICIPANT	\N	PRESENT	0
292330	273925	14259Y	PARTICIPANT	\N	PRESENT	0
292331	273925	19643A	PARTICIPANT	\N	PRESENT	0
292332	273925	19741B	PARTICIPANT	\N	PRESENT	0
292333	273925	14083S	PARTICIPANT	\N	PRESENT	0
292334	273925	19701S	PARTICIPANT	\N	PRESENT	0
292335	273925	19673G	PARTICIPANT	\N	PRESENT	0
292336	273925	04033B	PARTICIPANT	\N	PRESENT	0
292337	273925	04035D	PARTICIPANT	\N	PRESENT	0
292339	292338	08015R	PARTICIPANT	\N	PRESENT	0
272577	272576	08055A	PARTICIPANT	\N	PRESENT	0
272578	272576	04047H	PARTICIPANT	\N	PRESENT	0
272579	272576	14085U	PARTICIPANT	\N	PRESENT	0
272580	272576	11080N	PARTICIPANT	\N	PRESENT	0
272582	272576	01057W	PARTICIPANT	\N	PRESENT	0
272583	272576	19611R	PARTICIPANT	\N	EXCUSE	0
272584	272576	19687N	PARTICIPANT	\N	PRESENT	0
272585	272576	08049C	PARTICIPANT	\N	PRESENT	0
272586	272576	14157T	PARTICIPANT	\N	PRESENT	0
272589	272588	08055A	PARTICIPANT	\N	PRESENT	0
272590	272588	04047H	PARTICIPANT	\N	PRESENT	0
272591	272588	19545Y	PARTICIPANT	\N	PRESENT	0
272592	272588	14085U	PARTICIPANT	\N	PRESENT	0
272593	272588	11080N	PARTICIPANT	\N	PRESENT	0
272594	272588	11083R	PARTICIPANT	\N	PRESENT	0
272595	272588	01057W	PARTICIPANT	\N	PRESENT	0
272596	272588	19611R	PARTICIPANT	\N	PRESENT	0
272598	272588	08049C	PARTICIPANT	\N	PRESENT	0
272632	272631	08055A	PARTICIPANT	\N	PRESENT	0
272633	272631	04047H	PARTICIPANT	\N	PRESENT	0
272634	272631	14085U	PARTICIPANT	\N	PRESENT	0
272635	272631	11080N	PARTICIPANT	\N	PRESENT	0
272636	272631	11083R	PARTICIPANT	\N	PRESENT	0
272637	272631	01057W	PARTICIPANT	\N	PRESENT	0
272638	272631	14157T	PARTICIPANT	\N	PRESENT	0
272639	272631	19687N	PARTICIPANT	\N	PRESENT	0
272644	272631	08049C	PARTICIPANT	\N	PRESENT	0
274497	270562	14195A	PARTICIPANT	\N	PRESENT	0
274498	270562	11067R	PARTICIPANT	\N	PRESENT	0
274499	270562	14223L	PARTICIPANT	\N	PRESENT	0
274500	270562	04092N	PARTICIPANT	\N	PRESENT	0
291383	287619	11077T	PARTICIPANT	\N	PRESENT	0
291384	287619	11045K	PARTICIPANT	\N	PRESENT	0
291385	287619	19715Y	PARTICIPANT	\N	PRESENT	0
291387	291386	14038Y	PARTICIPANT	\N	PRESENT	0
291388	291386	08009T	PRESIDENT	0	PRESENT	0
291389	291386	14219Q	PARTICIPANT	\N	PRESENT	0
291390	291386	19685L	PARTICIPANT	\N	EXCUSE	0
291391	291386	19637C	PARTICIPANT	\N	EXCUSE	0
291392	291386	14221J	PARTICIPANT	\N	PRESENT	0
291393	287619	14223L	PARTICIPANT	\N	PRESENT	0
291394	287619	10006L	PARTICIPANT	\N	PRESENT	0
291396	291185	04070G	PRESIDENT	0	PRESENT	0
291397	291185	19699S	PARTICIPANT	\N	PRESENT	0
291398	291185	95015C	PARTICIPANT	\N	PRESENT	0
291399	291185	19329S	PARTICIPANT	\N	PRESENT	0
291400	291185	04033B	PARTICIPANT	\N	PRESENT	0
291401	291185	14229S	PARTICIPANT	\N	PRESENT	0
291402	291185	14241N	PARTICIPANT	\N	PRESENT	0
291403	291185	14039A	PARTICIPANT	\N	PRESENT	0
291404	291185	14107H	PARTICIPANT	\N	PRESENT	0
291405	291185	08017T	PARTICIPANT	\N	PRESENT	0
291406	291185	92040Q	PARTICIPANT	\N	PRESENT	0
291407	291185	07033P	PARTICIPANT	\N	PRESENT	0
291408	291185	08012N	PARTICIPANT	\N	PRESENT	0
291409	291185	08016S	PARTICIPANT	\N	PRESENT	0
291410	291185	08039A	PARTICIPANT	\N	PRESENT	0
291411	291185	08031R	PARTICIPANT	\N	PRESENT	0
291412	291185	19593H	PARTICIPANT	\N	PRESENT	0
291413	291185	19643A	PARTICIPANT	\N	PRESENT	0
291414	291185	14059S	PARTICIPANT	\N	PRESENT	0
291415	291185	14061L	PARTICIPANT	\N	PRESENT	0
291416	291185	04057K	PARTICIPANT	\N	PRESENT	0
291417	291185	14073Q	PARTICIPANT	\N	PRESENT	0
291418	291185	08035V	PARTICIPANT	\N	PRESENT	0
291419	291185	19693L	PARTICIPANT	\N	PRESENT	0
291420	291185	87003B	PARTICIPANT	\N	PRESENT	0
291421	291185	19399H	PARTICIPANT	\N	PRESENT	0
291422	291185	14201E	PARTICIPANT	\N	PRESENT	0
291423	291185	14030Q	PARTICIPANT	\N	PRESENT	0
291424	291185	14251Q	PARTICIPANT	\N	PRESENT	0
291425	291185	08020N	PARTICIPANT	\N	PRESENT	0
291426	291185	04059M	PARTICIPANT	\N	PRESENT	0
291427	291185	14063N	PARTICIPANT	\N	PRESENT	0
291428	291185	14109K	PARTICIPANT	\N	PRESENT	0
291429	291185	14123H	PARTICIPANT	\N	PRESENT	0
291430	291185	11104D	PARTICIPANT	\N	PRESENT	0
291431	291185	19749K	PARTICIPANT	\N	PRESENT	0
291432	291185	19758L	PARTICIPANT	\N	PRESENT	0
291433	291185	19621T	PARTICIPANT	\N	PRESENT	0
291434	291386	19383Y	PARTICIPANT	\N	PRESENT	0
291435	291386	17583W	PARTICIPANT	\N	PRESENT	0
291436	291386	19387D	PARTICIPANT	\N	PRESENT	0
291437	291386	14157T	PARTICIPANT	\N	PRESENT	0
291438	291386	19745F	PARTICIPANT	\N	PRESENT	0
291439	291386	14169X	PARTICIPANT	\N	PRESENT	0
291440	291386	14031R	PARTICIPANT	\N	PRESENT	0
291441	291386	19549D	PARTICIPANT	\N	PRESENT	0
291442	291386	08055A	PARTICIPANT	\N	PRESENT	0
291443	291386	15447F	PARTICIPANT	\N	PRESENT	0
291444	291386	14237S	PARTICIPANT	\N	PRESENT	0
291445	291386	14051J	PARTICIPANT	\N	PRESENT	0
291446	291386	08060W	PARTICIPANT	\N	PRESENT	0
291447	291386	19503N	PARTICIPANT	\N	PRESENT	0
291448	291386	08024S	PARTICIPANT	\N	PRESENT	0
291449	291386	19739H	PARTICIPANT	\N	PRESENT	0
291450	288052	14097Y	PARTICIPANT	\N	PRESENT	0
291451	288052	19443T	PARTICIPANT	\N	PRESENT	0
291452	288052	12041X	PARTICIPANT	\N	PRESENT	0
291453	288052	95030B	PARTICIPANT	\N	PRESENT	0
291454	288052	14133K	PARTICIPANT	\N	PRESENT	0
291455	288052	04034C	PARTICIPANT	\N	PRESENT	0
291456	288052	14235Q	PARTICIPANT	\N	PRESENT	0
291457	288052	01058X	PARTICIPANT	\N	PRESENT	0
291458	288052	16685X	PARTICIPANT	\N	PRESENT	0
291459	288052	08058D	PARTICIPANT	\N	PRESENT	0
291460	288052	04042C	PRESIDENT	0	PRESENT	0
291461	288052	19251M	PARTICIPANT	\N	PRESENT	0
291462	288052	11066Q	PARTICIPANT	\N	PRESENT	0
291463	288052	08056B	PARTICIPANT	\N	PRESENT	0
291464	288052	14105F	PARTICIPANT	\N	PRESENT	0
291465	288052	98018T	PARTICIPANT	\N	PRESENT	0
291466	288052	14193X	PARTICIPANT	\N	PRESENT	0
291467	288052	11064N	PARTICIPANT	\N	PRESENT	0
291468	288052	98050T	PARTICIPANT	\N	PRESENT	0
291469	288052	08053X	PARTICIPANT	\N	PRESENT	0
291470	288052	14255U	PARTICIPANT	\N	PRESENT	0
291471	291386	19333N	PARTICIPANT	\N	PRESENT	0
291472	291386	19701S	PARTICIPANT	\N	PRESENT	0
291473	291386	19599P	PARTICIPANT	\N	PRESENT	0
291474	291386	98023Q	PARTICIPANT	\N	PRESENT	0
291475	291386	14093U	PARTICIPANT	\N	PRESENT	0
291476	291386	19659J	PARTICIPANT	\N	PRESENT	0
291477	288052	14079W	PARTICIPANT	\N	PRESENT	0
291478	288052	04040A	PARTICIPANT	\N	PRESENT	0
291479	288052	08061X	PARTICIPANT	\N	PRESENT	0
291480	288052	95067Q	PARTICIPANT	\N	PRESENT	0
291481	291386	18083K	PARTICIPANT	\N	PRESENT	0
291482	291386	05012A	PARTICIPANT	\N	PRESENT	0
291483	291386	96004D	PARTICIPANT	\N	PRESENT	0
291484	291386	19347U	PARTICIPANT	\N	PRESENT	0
291485	291386	19713W	PARTICIPANT	\N	PRESENT	0
291486	291386	14029X	PARTICIPANT	\N	PRESENT	0
291487	291386	19737F	PARTICIPANT	\N	PRESENT	0
291488	288052	98022P	PARTICIPANT	\N	PRESENT	0
291489	291386	19551W	PARTICIPANT	\N	PRESENT	0
291490	291386	14103D	PARTICIPANT	\N	PRESENT	0
291491	291386	04085P	PARTICIPANT	\N	PRESENT	0
291492	291386	04097T	PARTICIPANT	\N	PRESENT	0
291493	291395	14001X	PARTICIPANT	\N	PRESENT	0
291494	291395	19581D	PARTICIPANT	\N	PRESENT	0
291495	291395	04044E	PARTICIPANT	\N	PRESENT	0
291496	291395	04047H	PARTICIPANT	\N	PRESENT	0
291497	291395	01028R	PARTICIPANT	\N	PRESENT	0
291498	291395	19489J	PARTICIPANT	\N	PRESENT	0
291499	291395	14275Y	PARTICIPANT	\N	PRESENT	0
291500	291395	14041T	PARTICIPANT	\N	PRESENT	0
291501	291395	14215L	PARTICIPANT	\N	PRESENT	0
291502	291395	14259Y	PARTICIPANT	\N	PRESENT	0
291503	291395	11072N	PARTICIPANT	\N	PRESENT	0
291504	291395	14053L	PARTICIPANT	\N	PRESENT	0
291505	291395	19649G	PARTICIPANT	\N	PRESENT	0
291506	291395	14111D	PARTICIPANT	\N	PRESENT	0
291507	291395	07034Q	PRESIDENT	0	PRESENT	0
291508	291395	10015M	PARTICIPANT	\N	PRESENT	0
291509	291395	11026G	PARTICIPANT	\N	PRESENT	0
291510	291395	01024M	PARTICIPANT	\N	PRESENT	0
291511	291395	04038G	PARTICIPANT	\N	PRESENT	0
291512	291395	11033F	PARTICIPANT	\N	PRESENT	0
291513	291395	14089Y	PARTICIPANT	\N	PRESENT	0
291514	291395	19729F	PARTICIPANT	\N	PRESENT	0
291515	291395	95063L	PARTICIPANT	\N	PRESENT	0
291516	291395	19629C	PARTICIPANT	\N	PRESENT	0
291517	291395	14069U	PARTICIPANT	\N	PRESENT	0
291518	291395	11085T	PARTICIPANT	\N	PRESENT	0
291519	291395	11049P	PARTICIPANT	\N	PRESENT	0
291520	291395	04008A	PARTICIPANT	\N	PRESENT	0
291521	288052	11054L	PARTICIPANT	\N	PRESENT	0
291522	291386	19525U	PARTICIPANT	\N	PRESENT	0
273321	273320	04061F	PARTICIPANT	\N	PRESENT	0
273323	273320	14001X	PARTICIPANT	\N	PRESENT	0
273727	273295	08061X	PARTICIPANT	\N	PRESENT	0
273728	270532	14119M	PARTICIPANT	\N	PRESENT	0
273729	270532	08034U	PARTICIPANT	\N	PRESENT	0
273730	270533	08034U	PARTICIPANT	\N	PRESENT	0
273731	270533	14119M	PARTICIPANT	\N	PRESENT	0
273841	273295	14105F	PARTICIPANT	\N	PRESENT	0
275786	275785	08031R	PARTICIPANT	\N	PRESENT	0
275787	275785	08043V	PARTICIPANT	\N	PRESENT	0
275835	270351	19663E	PARTICIPANT	\N	PRESENT	0
275836	273867	19663E	PARTICIPANT	\N	PRESENT	0
275838	270352	19663E	PARTICIPANT	\N	PRESENT	0
275847	275845	14331P	PARTICIPANT	\N	PRESENT	0
275849	275848	14121F	PARTICIPANT	\N	PRESENT	0
275851	275850	14121F	PARTICIPANT	\N	PRESENT	0
275853	275852	19711U	PARTICIPANT	\N	PRESENT	0
275855	275854	14199E	PARTICIPANT	\N	PRESENT	0
275859	275858	08011M	PARTICIPANT	\N	PRESENT	0
275861	275860	01048V	PARTICIPANT	\N	PRESENT	0
275864	275862	19667J	PARTICIPANT	\N	PRESENT	0
275865	275863	19667J	PARTICIPANT	\N	PRESENT	0
275867	275866	19667J	PARTICIPANT	\N	PRESENT	0
275920	275913	19667J	PARTICIPANT	\N	PRESENT	0
280553	280499	11081P	PARTICIPANT	\N	EXCUSE	0
280554	278438	89017R	PARTICIPANT	\N	EXCUSE	0
280555	278438	11056N	PARTICIPANT	\N	EXCUSE	0
280556	278759	19681G	PARTICIPANT	\N	PRESENT	0
280557	278438	11065P	PARTICIPANT	\N	EXCUSE	0
280558	278438	19399H	PARTICIPANT	\N	EXCUSE	0
280559	278438	08045X	PARTICIPANT	\N	PRESENT	0
280560	278438	17637T	PARTICIPANT	\N	EXCUSE	0
280561	278759	11065P	PARTICIPANT	\N	PRESENT	0
280562	279254	14327T	PARTICIPANT	\N	PRESENT	0
280563	279254	14331P	PARTICIPANT	\N	PRESENT	0
280564	279254	01048V	PARTICIPANT	\N	PRESENT	0
280565	279254	19545Y	PARTICIPANT	\N	PRESENT	0
280566	279254	01057W	PARTICIPANT	\N	PRESENT	0
280567	279254	89017R	PARTICIPANT	\N	PRESENT	0
280568	279254	11074Q	PRESIDENT	0	PRESENT	0
280569	279254	11070L	PARTICIPANT	\N	PRESENT	0
280570	279254	14225N	PARTICIPANT	\N	PRESENT	0
280571	279254	07029T	PARTICIPANT	\N	PRESENT	0
280572	279254	14085U	PARTICIPANT	\N	PRESENT	0
280573	279254	07004J	PARTICIPANT	\N	PRESENT	0
280574	279254	19349W	PARTICIPANT	\N	PRESENT	0
280575	279254	14253S	PARTICIPANT	\N	PRESENT	0
280576	279254	19479G	PARTICIPANT	\N	PRESENT	0
280577	279254	19531S	PARTICIPANT	\N	PRESENT	0
280578	279254	08011M	PARTICIPANT	\N	PRESENT	0
280579	279254	14034U	PARTICIPANT	\N	PRESENT	0
280580	279254	14159V	PARTICIPANT	\N	PRESENT	0
280581	279254	14173T	PARTICIPANT	\N	PRESENT	0
280582	279254	11040E	PARTICIPANT	\N	PRESENT	0
280583	279254	04086Q	PARTICIPANT	\N	PRESENT	0
280584	279254	14199E	PARTICIPANT	\N	PRESENT	0
280585	279254	08073C	PARTICIPANT	\N	PRESENT	0
280586	279254	14121F	PARTICIPANT	\N	PRESENT	0
280587	279254	99004R	PARTICIPANT	\N	PRESENT	0
280588	279254	04061F	PARTICIPANT	\N	PRESENT	0
280592	278438	19479G	PARTICIPANT	\N	PRESENT	0
280593	278444	19713W	PARTICIPANT	\N	PRESENT	0
280638	279254	95041E	PARTICIPANT	\N	PRESENT	0
280639	279254	11053K	PARTICIPANT	\N	PRESENT	0
280640	279254	08034U	PARTICIPANT	\N	PRESENT	0
280641	279254	08069G	PARTICIPANT	\N	PRESENT	0
280642	279254	19741B	PARTICIPANT	\N	PRESENT	0
280706	280499	19591F	PARTICIPANT	\N	PRESENT	0
280707	279254	19667J	PARTICIPANT	\N	PRESENT	0
280708	279254	11048N	PARTICIPANT	\N	PRESENT	0
280709	278292	19663E	PARTICIPANT	\N	PRESENT	0
280710	278759	14169X	PARTICIPANT	\N	PRESENT	0
280711	280499	04043D	PARTICIPANT	\N	PRESENT	0
280712	280690	19515S	PARTICIPANT	\N	PRESENT	0
280713	280690	14081Q	PARTICIPANT	\N	PRESENT	0
280714	280690	19413M	PARTICIPANT	\N	PRESENT	0
280715	280690	19667J	PARTICIPANT	\N	PRESENT	0
280716	280690	80013X	PARTICIPANT	\N	PRESENT	0
280717	280690	19631V	PARTICIPANT	\N	PRESENT	0
280718	280690	08021P	PARTICIPANT	\N	PRESENT	0
280719	280690	08068F	PARTICIPANT	\N	PRESENT	0
280720	280690	04049K	PARTICIPANT	\N	PRESENT	0
280721	280690	19705W	PARTICIPANT	\N	PRESENT	0
280722	280690	19707Y	PARTICIPANT	\N	PRESENT	0
280723	280690	08015R	PARTICIPANT	\N	PRESENT	0
280724	280690	08019V	PARTICIPANT	\N	PRESENT	0
280725	280690	19369B	PARTICIPANT	\N	PRESENT	0
280726	280690	19511N	PARTICIPANT	\N	PRESENT	0
280727	280690	14265W	PARTICIPANT	\N	PRESENT	0
280728	280690	19591F	PARTICIPANT	\N	PRESENT	0
280729	280690	14135M	PARTICIPANT	\N	PRESENT	0
280730	280690	19467C	PARTICIPANT	\N	PRESENT	0
280731	280690	14187A	PARTICIPANT	\N	PRESENT	0
280732	280690	08038Y	PARTICIPANT	\N	PRESENT	0
280733	280690	08062Y	PARTICIPANT	\N	PRESENT	0
280734	280690	19301E	PARTICIPANT	\N	PRESENT	0
280735	280690	19695N	PARTICIPANT	\N	PRESENT	0
280736	280690	14033T	PARTICIPANT	\N	PRESENT	0
280737	280690	11090Q	PRESIDENT	0	PRESENT	0
280738	280690	01025N	PARTICIPANT	\N	PRESENT	0
280739	280690	19295A	PARTICIPANT	\N	PRESENT	0
280740	280690	14205J	PARTICIPANT	\N	PRESENT	0
280741	280690	04088S	PARTICIPANT	\N	PRESENT	0
280742	280690	11056N	PARTICIPANT	\N	PRESENT	0
280743	280690	14115H	PARTICIPANT	\N	PRESENT	0
280744	280690	11101A	PARTICIPANT	\N	PRESENT	0
280745	280690	19507S	PARTICIPANT	\N	PRESENT	0
280746	280690	19747H	PARTICIPANT	\N	PRESENT	0
280747	280690	14207L	PARTICIPANT	\N	PRESENT	0
280748	280690	04043D	PARTICIPANT	\N	PRESENT	0
280749	280690	19619A	PARTICIPANT	\N	PRESENT	0
280750	280690	17589D	PARTICIPANT	\N	PRESENT	0
280751	280690	14257W	PARTICIPANT	\N	PRESENT	0
280752	280690	04089T	PARTICIPANT	\N	EXCUSE	0
280753	280690	11081P	PARTICIPANT	\N	EXCUSE	0
280754	278759	14038Y	PARTICIPANT	\N	PRESENT	0
280755	278759	14221J	PARTICIPANT	\N	PRESENT	0
280756	278759	19637C	PARTICIPANT	\N	PRESENT	0
280852	279257	19667J	PARTICIPANT	\N	PRESENT	0
280859	280178	19593H	PARTICIPANT	\N	PRESENT	0
280860	280178	04057K	PARTICIPANT	\N	PRESENT	0
280861	280178	19533U	PARTICIPANT	\N	PRESENT	0
280862	280178	14030Q	PARTICIPANT	\N	PRESENT	0
280863	280178	14109K	PARTICIPANT	\N	PRESENT	0
280864	280178	11104D	PARTICIPANT	\N	PRESENT	0
280865	280178	19749K	PARTICIPANT	\N	PRESENT	0
280866	280178	19621T	PARTICIPANT	\N	PRESENT	0
280867	280178	19573D	PARTICIPANT	\N	PRESENT	0
280868	280178	04059M	PARTICIPANT	\N	PRESENT	0
280869	280178	11109J	PARTICIPANT	\N	PRESENT	0
280870	280178	07033P	PARTICIPANT	\N	PRESENT	0
280871	280178	11043H	PARTICIPANT	\N	PRESENT	0
280872	280178	14249W	PARTICIPANT	\N	PRESENT	0
280873	280178	19399H	PARTICIPANT	\N	EXCUSE	0
280875	278438	19711U	PARTICIPANT	\N	PRESENT	0
280878	278438	08012N	PARTICIPANT	\N	EXCUSE	0
280914	273877	19683J	PARTICIPANT	\N	PRESENT	0
280915	273877	19715Y	PARTICIPANT	\N	PRESENT	0
280916	273877	17779H	PARTICIPANT	\N	PRESENT	0
280917	273877	19415P	PARTICIPANT	\N	PRESENT	0
280918	273877	19681G	PARTICIPANT	\N	PRESENT	0
280919	273877	19629C	PARTICIPANT	\N	PRESENT	0
280920	273877	04045F	PARTICIPANT	\N	PRESENT	0
280921	273877	11097X	PARTICIPANT	\N	PRESENT	0
280922	273877	04092N	PARTICIPANT	\N	PRESENT	0
280923	273877	11066Q	PARTICIPANT	\N	PRESENT	0
280924	273877	11031D	PARTICIPANT	\N	PRESENT	0
280925	273877	16685X	PARTICIPANT	\N	PRESENT	0
280926	273877	14191V	PARTICIPANT	\N	PRESENT	0
280927	273877	14071N	PARTICIPANT	\N	PRESENT	0
280928	273877	14355X	PARTICIPANT	\N	PRESENT	0
280929	273877	19575F	PARTICIPANT	\N	PRESENT	0
280930	273877	08034U	PARTICIPANT	\N	PRESENT	0
280931	273877	19697Q	PARTICIPANT	\N	PRESENT	0
280932	273877	14119M	PARTICIPANT	\N	PRESENT	0
280933	273877	14227Q	PARTICIPANT	\N	PRESENT	0
280980	280946	19515S	PARTICIPANT	\N	PRESENT	0
280981	280946	19441R	PARTICIPANT	\N	PRESENT	0
280982	280946	80013X	PARTICIPANT	\N	PRESENT	0
280983	280946	11099A	PARTICIPANT	\N	PRESENT	0
280984	280946	19347U	PARTICIPANT	\N	PRESENT	0
280985	280946	14157T	PARTICIPANT	\N	PRESENT	0
280986	280946	14187A	PARTICIPANT	\N	PRESENT	0
273300	268440	80013X	PARTICIPANT	\N	PRESENT	0
273301	268440	19683J	PARTICIPANT	\N	PRESENT	0
273303	268440	19503N	PARTICIPANT	\N	PRESENT	0
273305	268440	14221J	PARTICIPANT	\N	PRESENT	0
273306	268440	19593H	PARTICIPANT	\N	PRESENT	0
273309	268440	01048V	PRESIDENT	0	PRESENT	0
274539	274333	05008E	PRESIDENT	0	PRESENT	0
274540	274333	19543W	PARTICIPANT	\N	PRESENT	0
281392	281391	14173T	PARTICIPANT	\N	PRESENT	0
274542	274333	14065Q	PARTICIPANT	\N	PRESENT	0
274543	274333	14069U	PARTICIPANT	\N	PRESENT	0
274544	274333	14089Y	PARTICIPANT	\N	PRESENT	0
274545	274333	04047H	PARTICIPANT	\N	PRESENT	0
274546	274333	14053L	PARTICIPANT	\N	PRESENT	0
274547	274333	19629C	PARTICIPANT	\N	PRESENT	0
274548	274333	04038G	PARTICIPANT	\N	PRESENT	0
274549	274333	19253P	PARTICIPANT	\N	PRESENT	0
274550	274333	14259Y	PARTICIPANT	\N	EXCUSE	0
274551	274333	04008A	PARTICIPANT	\N	PRESENT	0
274552	274333	19719D	PARTICIPANT	\N	EXCUSE	0
274553	274333	14041T	PARTICIPANT	\N	PRESENT	0
274554	274333	01024M	PARTICIPANT	\N	PRESENT	0
274555	274333	14215L	PARTICIPANT	\N	PRESENT	0
274556	274333	14151M	PARTICIPANT	\N	PRESENT	0
281393	281391	14026U	PARTICIPANT	\N	PRESENT	0
274558	274333	08045X	PARTICIPANT	\N	PRESENT	0
281394	281391	19447X	PARTICIPANT	\N	PRESENT	0
288235	281196	08068F	PARTICIPANT	\N	PRESENT	0
274561	274333	14231L	PARTICIPANT	\N	PRESENT	0
288236	286003	04086Q	PARTICIPANT	\N	PRESENT	0
274563	274333	11049P	PARTICIPANT	\N	PRESENT	0
274564	274333	19725B	PARTICIPANT	\N	PRESENT	0
288237	286003	07029T	PARTICIPANT	\N	PRESENT	0
274566	274333	08044W	PARTICIPANT	\N	PRESENT	0
274567	274333	19447X	PARTICIPANT	\N	PRESENT	0
288238	286003	19531S	PARTICIPANT	\N	PRESENT	0
274569	274333	19489J	PARTICIPANT	\N	PRESENT	0
288239	286003	08069G	PARTICIPANT	\N	PRESENT	0
274571	274333	19729F	PARTICIPANT	\N	PRESENT	0
274572	274333	19581D	PARTICIPANT	\N	PRESENT	0
274573	274333	14111D	PARTICIPANT	\N	PRESENT	0
274574	274333	14001X	PARTICIPANT	\N	PRESENT	0
288240	286003	11074Q	PRESIDENT	0	PRESENT	0
288241	286003	14207L	PARTICIPANT	\N	PRESENT	0
274577	274333	14147R	PARTICIPANT	\N	PRESENT	0
274578	274333	11072N	PARTICIPANT	\N	PRESENT	0
288242	286003	14225N	PARTICIPANT	\N	PRESENT	0
274580	274333	10015M	PARTICIPANT	\N	PRESENT	0
288243	286003	14327T	PARTICIPANT	\N	EXCUSE	0
274582	274333	01028R	PARTICIPANT	\N	EXCUSE	0
288244	286003	14083S	PARTICIPANT	\N	EXCUSE	0
288245	286003	14085U	PARTICIPANT	\N	EXCUSE	0
274585	274333	04044E	PARTICIPANT	\N	PRESENT	0
288246	286003	08014Q	PARTICIPANT	\N	EXCUSE	0
288247	286003	01057W	PARTICIPANT	\N	PRESENT	0
288248	286003	08010L	PARTICIPANT	\N	PRESENT	0
288347	273918	04097T	PARTICIPANT	\N	PRESENT	0
288348	273918	11056N	PARTICIPANT	\N	PRESENT	0
288349	273918	19711U	PARTICIPANT	\N	PRESENT	0
288350	273918	17637T	PARTICIPANT	\N	PRESENT	0
288351	273918	04085P	PARTICIPANT	\N	PRESENT	0
288352	273918	08010L	PARTICIPANT	\N	PRESENT	0
288353	273918	04038G	PARTICIPANT	\N	PRESENT	0
288354	273918	11040E	PARTICIPANT	\N	PRESENT	0
288355	273918	01058X	PARTICIPANT	\N	PRESENT	0
288356	273918	08020N	PARTICIPANT	\N	PRESENT	0
288357	273918	99004R	PARTICIPANT	\N	PRESENT	0
288358	273918	11101A	PARTICIPANT	\N	PRESENT	0
288359	273918	04035D	PARTICIPANT	\N	PRESENT	0
288360	273918	19565D	PARTICIPANT	\N	PRESENT	0
288361	273918	04092N	PARTICIPANT	\N	PRESENT	0
288362	273918	19758L	PARTICIPANT	\N	PRESENT	0
288363	273918	19347U	PARTICIPANT	\N	PRESENT	0
288364	273918	04044E	PARTICIPANT	\N	PRESENT	0
288365	273918	19695N	PARTICIPANT	\N	PRESENT	0
288366	273918	11031D	PARTICIPANT	\N	PRESENT	0
288367	273918	95015C	PARTICIPANT	\N	PRESENT	0
288368	273918	12041X	PARTICIPANT	\N	PRESENT	0
288369	273918	04047H	PARTICIPANT	\N	PRESENT	0
288370	273918	95030B	PARTICIPANT	\N	PRESENT	0
288371	273918	19593H	PARTICIPANT	\N	PRESENT	0
288372	273918	19687N	PARTICIPANT	\N	PRESENT	0
288373	273918	10015M	PARTICIPANT	\N	PRESENT	0
288374	273918	08061X	PARTICIPANT	\N	PRESENT	0
288375	273918	95037J	PARTICIPANT	\N	PRESENT	0
288376	273918	04034C	PARTICIPANT	\N	PRESENT	0
288377	273918	15447F	PARTICIPANT	\N	PRESENT	0
288378	273918	98029W	PARTICIPANT	\N	PRESENT	0
288379	273918	14239U	PARTICIPANT	\N	PRESENT	0
288380	273918	11083R	PARTICIPANT	\N	PRESENT	0
288381	273918	19515S	PARTICIPANT	\N	PRESENT	0
288382	273918	19269X	PARTICIPANT	\N	PRESENT	0
288383	273918	19543W	PARTICIPANT	\N	PRESENT	0
288384	273918	11080N	PARTICIPANT	\N	PRESENT	0
288385	273918	95063L	PARTICIPANT	\N	PRESENT	0
288386	273918	08073C	PARTICIPANT	\N	PRESENT	0
288387	273918	14039A	PARTICIPANT	\N	PRESENT	0
288388	273918	08011M	PARTICIPANT	\N	PRESENT	0
288389	273918	19659J	PARTICIPANT	\N	PRESENT	0
288390	273918	11072N	PARTICIPANT	\N	PRESENT	0
288391	273918	19301E	PARTICIPANT	\N	PRESENT	0
288392	273918	04086Q	PARTICIPANT	\N	PRESENT	0
288393	273918	19421M	PARTICIPANT	\N	PRESENT	0
288394	273918	14055N	PARTICIPANT	\N	PRESENT	0
288395	273918	11097X	PARTICIPANT	\N	PRESENT	0
288396	273918	19731Y	PARTICIPANT	\N	PRESENT	0
288397	273918	19685L	PARTICIPANT	\N	PRESENT	0
288398	273918	04033B	PARTICIPANT	\N	PRESENT	0
288399	273918	19745F	PARTICIPANT	\N	PRESENT	0
288400	273918	14071N	PARTICIPANT	\N	PRESENT	0
288401	273918	11012A	PARTICIPANT	\N	PRESENT	0
288402	273918	08031R	PARTICIPANT	\N	PRESENT	0
288403	273918	08016S	PARTICIPANT	\N	PRESENT	0
288404	273918	14261S	PARTICIPANT	\N	PRESENT	0
288405	273918	14187A	PARTICIPANT	\N	PRESENT	0
288406	273918	19253P	PARTICIPANT	\N	PRESENT	0
288407	273918	19629C	PARTICIPANT	\N	PRESENT	0
288408	273918	14223L	PARTICIPANT	\N	PRESENT	0
288409	273918	14201E	PARTICIPANT	\N	PRESENT	0
288410	273918	19643A	PARTICIPANT	\N	PRESENT	0
288411	273918	19563B	PARTICIPANT	\N	PRESENT	0
288412	273918	14241N	PARTICIPANT	\N	PRESENT	0
288413	273918	98022P	PARTICIPANT	\N	PRESENT	0
288414	273918	01057W	PARTICIPANT	\N	PRESENT	0
288415	273918	88008L	PARTICIPANT	\N	PRESENT	0
288416	273918	19717B	PARTICIPANT	\N	PRESENT	0
288417	273918	19681G	PARTICIPANT	\N	PRESENT	0
288418	273918	14069U	PARTICIPANT	\N	PRESENT	0
288419	273918	14053L	PARTICIPANT	\N	PRESENT	0
288420	273918	19697Q	PARTICIPANT	\N	PRESENT	0
288421	273918	19329S	PARTICIPANT	\N	PRESENT	0
288422	273918	14193X	PARTICIPANT	\N	PRESENT	0
288423	273918	14093U	PARTICIPANT	\N	PRESENT	0
288424	273918	19545Y	PARTICIPANT	\N	PRESENT	0
288425	273918	19585H	PARTICIPANT	\N	PRESENT	0
288426	273918	14251Q	PARTICIPANT	\N	PRESENT	0
288427	273918	11064N	PARTICIPANT	\N	PRESENT	0
288428	273918	14249W	PARTICIPANT	\N	PRESENT	0
288429	273918	04057K	PARTICIPANT	\N	PRESENT	0
288430	273918	14111D	PARTICIPANT	\N	PRESENT	0
288431	273918	04043D	PARTICIPANT	\N	PRESENT	0
288334	273918	86034E	PARTICIPANT	\N	PRESENT	0
288346	273918	14157T	PARTICIPANT	\N	PRESENT	0
288432	273918	14123H	PARTICIPANT	\N	PRESENT	0
288433	273918	14195A	PARTICIPANT	\N	PRESENT	0
288434	273918	04042C	PARTICIPANT	\N	PRESENT	0
288435	273918	04059M	PARTICIPANT	\N	PRESENT	0
288436	273918	11077T	PARTICIPANT	\N	PRESENT	0
288437	273918	11074Q	PARTICIPANT	\N	PRESENT	0
288438	273918	11048N	PARTICIPANT	\N	PRESENT	0
288439	273918	08055A	PARTICIPANT	\N	PRESENT	0
288440	273918	19533U	PARTICIPANT	\N	PRESENT	0
288441	273918	14229S	PARTICIPANT	\N	PRESENT	0
288442	273918	11027H	PARTICIPANT	\N	PRESENT	0
288443	273918	14051J	PARTICIPANT	\N	PRESENT	0
288444	273918	19581D	PARTICIPANT	\N	PRESENT	0
288445	273918	08068F	PARTICIPANT	\N	PRESENT	0
288446	273918	19651A	PARTICIPANT	\N	PRESENT	0
288447	273918	14079W	PARTICIPANT	\N	PRESENT	0
288448	273918	19671E	PARTICIPANT	\N	PRESENT	0
288449	273918	14151M	PARTICIPANT	\N	PRESENT	0
288450	273918	19715Y	PARTICIPANT	\N	PRESENT	0
288451	273918	04061F	PARTICIPANT	\N	PRESENT	0
288452	273918	19599P	PARTICIPANT	\N	PRESENT	0
288453	273918	14225N	PARTICIPANT	\N	PRESENT	0
275877	273325	08014Q	PARTICIPANT	\N	EXCUSE	0
279373	278438	19651A	PARTICIPANT	\N	PRESENT	0
279376	278438	08069G	PARTICIPANT	\N	EXCUSE	0
279390	278438	19629C	PARTICIPANT	\N	EXCUSE	0
288057	288056	14187A	PARTICIPANT	\N	PRESENT	0
288062	288061	14187A	PARTICIPANT	\N	PRESENT	0
288063	288061	04043D	PARTICIPANT	\N	PRESENT	0
288064	288061	19369B	PARTICIPANT	\N	PRESENT	0
288069	288067	14187A	PARTICIPANT	\N	PRESENT	0
288632	288631	14213J	PRESIDENT	0	PRESENT	0
288633	288631	11099A	PARTICIPANT	\N	PRESENT	0
288634	288631	98024R	PARTICIPANT	\N	PRESENT	0
288635	288631	14109K	PARTICIPANT	\N	PRESENT	0
288636	288631	19503N	PARTICIPANT	\N	PRESENT	0
288637	288631	10006L	PARTICIPANT	\N	PRESENT	0
288638	288631	14169X	PARTICIPANT	\N	PRESENT	0
288640	288631	04043D	PARTICIPANT	\N	PRESENT	0
288642	288631	19347U	PARTICIPANT	\N	PRESENT	0
288644	288631	04049K	PARTICIPANT	\N	EXCUSE	0
288646	288631	08049C	PARTICIPANT	\N	EXCUSE	0
288648	288631	14327T	PARTICIPANT	\N	EXCUSE	0
288650	288631	19369B	PARTICIPANT	\N	EXCUSE	0
288669	288668	14213J	PRESIDENT	0	PRESENT	0
288670	288668	11099A	PARTICIPANT	\N	PRESENT	0
288671	288668	14195A	PARTICIPANT	\N	PRESENT	0
288672	288668	08015R	PARTICIPANT	\N	PRESENT	0
288673	288668	98024R	PARTICIPANT	\N	PRESENT	0
288675	288668	14109K	PARTICIPANT	\N	PRESENT	0
288681	288668	19503N	PARTICIPANT	\N	PRESENT	0
288682	288668	14169X	PARTICIPANT	\N	PRESENT	0
288684	288668	08049C	PARTICIPANT	\N	EXCUSE	0
288686	288668	14327T	PARTICIPANT	\N	EXCUSE	0
288687	288668	04049K	PARTICIPANT	\N	EXCUSE	0
288691	288668	19369B	PARTICIPANT	\N	EXCUSE	0
288955	288954	14239U	PARTICIPANT	\N	PRESENT	0
288956	288954	19647E	PARTICIPANT	\N	PRESENT	0
288957	288954	19591F	PARTICIPANT	\N	PRESENT	0
288961	288954	08009T	PARTICIPANT	\N	PRESENT	0
288962	288954	10015M	PARTICIPANT	\N	PRESENT	0
288964	288963	14239U	PARTICIPANT	\N	PRESENT	0
288965	288963	19647E	PARTICIPANT	\N	PRESENT	0
288966	288963	19551W	PARTICIPANT	\N	PRESENT	0
288967	288963	08044W	PARTICIPANT	\N	PRESENT	0
292342	273925	14069U	PARTICIPANT	\N	PRESENT	0
292343	273925	19715Y	PARTICIPANT	\N	PRESENT	0
292340	292338	14225N	PARTICIPANT	\N	PRESENT	0
292341	292338	89017R	PARTICIPANT	\N	PRESENT	0
292344	273925	08019V	PARTICIPANT	\N	PRESENT	0
292616	292362	19593H	PARTICIPANT	\N	PRESENT	0
292617	292362	04070G	PRESIDENT	0	PRESENT	0
292618	292362	19699S	PARTICIPANT	\N	PRESENT	0
292619	292362	04057K	PARTICIPANT	\N	PRESENT	0
292620	292362	19533U	PARTICIPANT	\N	PRESENT	0
292621	292362	95015C	PARTICIPANT	\N	PRESENT	0
292622	292362	19611R	PARTICIPANT	\N	PRESENT	0
292623	292362	19693L	PARTICIPANT	\N	PRESENT	0
292624	292362	14229S	PARTICIPANT	\N	PRESENT	0
292625	292362	19573D	PARTICIPANT	\N	PRESENT	0
292626	292362	11109J	PARTICIPANT	\N	PRESENT	0
292627	292362	14063N	PARTICIPANT	\N	PRESENT	0
292628	292362	14123H	PARTICIPANT	\N	PRESENT	0
292629	292362	19749K	PARTICIPANT	\N	PRESENT	0
292630	292362	19758L	PARTICIPANT	\N	PRESENT	0
292631	292362	19621T	PARTICIPANT	\N	PRESENT	0
292632	292362	14241N	PARTICIPANT	\N	EXCUSE	0
292633	292362	14073Q	PARTICIPANT	\N	EXCUSE	0
292634	292362	08020N	PARTICIPANT	\N	EXCUSE	0
292635	292362	19735D	PARTICIPANT	\N	EXCUSE	0
292636	292362	11083R	PARTICIPANT	\N	EXCUSE	0
292637	292362	08043V	PARTICIPANT	\N	EXCUSE	0
292638	292362	19399H	PARTICIPANT	\N	EXCUSE	0
292639	292362	14249W	PARTICIPANT	\N	EXCUSE	0
292640	292362	04018C	PARTICIPANT	\N	EXCUSE	0
292641	292362	08039A	PARTICIPANT	\N	EXCUSE	0
292642	273930	19621T	PARTICIPANT	\N	PRESENT	0
292643	273930	14329V	PARTICIPANT	\N	PRESENT	0
292644	273930	04088S	PARTICIPANT	\N	PRESENT	0
292645	273930	11012A	PARTICIPANT	\N	PRESENT	0
292646	273930	04049K	PARTICIPANT	\N	PRESENT	0
292647	273930	11109J	PARTICIPANT	\N	PRESENT	0
292650	273930	19715Y	PARTICIPANT	\N	PRESENT	0
292651	273930	18083K	PARTICIPANT	\N	PRESENT	0
292652	273930	19553Y	PARTICIPANT	\N	PRESENT	0
292653	273930	11026G	PARTICIPANT	\N	PRESENT	0
292742	273967	14205J	PARTICIPANT	\N	PRESENT	0
292743	273967	14135M	PARTICIPANT	\N	PRESENT	0
292754	273967	11033F	PARTICIPANT	\N	PRESENT	0
292755	273967	19695N	PARTICIPANT	\N	PRESENT	0
292756	273967	19758L	PARTICIPANT	\N	PRESENT	0
292757	273967	19503N	PARTICIPANT	\N	PRESENT	0
292758	273967	19565D	PARTICIPANT	\N	PRESENT	0
292759	273967	19347U	PARTICIPANT	\N	PRESENT	0
292760	273967	19551W	PARTICIPANT	\N	PRESENT	0
292761	273967	08055A	PARTICIPANT	\N	PRESENT	0
292762	273967	14207L	PARTICIPANT	\N	PRESENT	0
292763	273967	08060W	PARTICIPANT	\N	PRESENT	0
292764	273967	14107H	PARTICIPANT	\N	PRESENT	0
292765	273967	14197C	PARTICIPANT	\N	PRESENT	0
292766	273967	19301E	PARTICIPANT	\N	PRESENT	0
292767	273967	19413M	PARTICIPANT	\N	PRESENT	0
292768	273967	14257W	PARTICIPANT	\N	PRESENT	0
292769	273967	11099A	PARTICIPANT	\N	PRESENT	0
292770	273967	19583F	PARTICIPANT	\N	PRESENT	0
292771	273967	19619A	PARTICIPANT	\N	PRESENT	0
292772	273967	19563B	PARTICIPANT	\N	PRESENT	0
292773	273967	08016S	PARTICIPANT	\N	PRESENT	0
292774	273967	19349W	PARTICIPANT	\N	PRESENT	0
292775	273967	19737F	PARTICIPANT	\N	PRESENT	0
292776	273967	11097X	PARTICIPANT	\N	PRESENT	0
292777	273967	19383Y	PARTICIPANT	\N	PRESENT	0
292778	273967	14329V	PARTICIPANT	\N	PRESENT	0
292779	273967	08034U	PARTICIPANT	\N	PRESENT	0
292780	273967	95030B	PARTICIPANT	\N	PRESENT	0
292781	273967	08010L	PARTICIPANT	\N	PRESENT	0
292782	273967	19711U	PARTICIPANT	\N	PRESENT	0
292783	273967	18083K	PARTICIPANT	\N	PRESENT	0
292784	273967	19507S	PARTICIPANT	\N	PRESENT	0
292785	273967	14033T	PARTICIPANT	\N	PRESENT	0
292786	273967	19667J	PARTICIPANT	\N	PRESENT	0
292787	273967	19447X	PARTICIPANT	\N	PRESENT	0
292788	273967	14038Y	PARTICIPANT	\N	PRESENT	0
292789	273967	14042U	PARTICIPANT	\N	PRESENT	0
292790	273967	19643A	PARTICIPANT	\N	PRESENT	0
292791	273967	19553Y	PARTICIPANT	\N	PRESENT	0
292792	273967	19715Y	PARTICIPANT	\N	PRESENT	0
292793	273967	19593H	PARTICIPANT	\N	PRESENT	0
292794	273967	14265W	PARTICIPANT	\N	PRESENT	0
292795	273967	14103D	PARTICIPANT	\N	PRESENT	0
292796	273967	14219Q	PARTICIPANT	\N	PRESENT	0
292797	273967	11048N	PARTICIPANT	\N	PRESENT	0
292798	273967	19441R	PARTICIPANT	\N	PRESENT	0
292805	273967	08061X	PARTICIPANT	\N	PRESENT	0
292807	273967	04085P	PARTICIPANT	\N	PRESENT	0
292808	273967	19479G	PARTICIPANT	\N	PRESENT	0
292811	273967	19701S	PARTICIPANT	\N	PRESENT	0
292812	273967	19663E	PARTICIPANT	\N	PRESENT	0
292813	273967	04045F	PARTICIPANT	\N	PRESENT	0
292738	273967	04044E	PARTICIPANT	\N	PRESENT	0
292741	273967	11090Q	PARTICIPANT	\N	PRESENT	0
292814	273967	19651A	PARTICIPANT	\N	PRESENT	0
292815	273967	11109J	PARTICIPANT	\N	PRESENT	0
292818	273967	07033P	PARTICIPANT	\N	PRESENT	0
292819	273967	04049K	PARTICIPANT	\N	PRESENT	0
292822	273967	14221J	PARTICIPANT	\N	PRESENT	0
292831	290503	19713W	PARTICIPANT	\N	PRESENT	0
292832	273967	14357A	PARTICIPANT	\N	PRESENT	0
292833	273967	19573D	PARTICIPANT	\N	PRESENT	0
292834	273967	19659J	PARTICIPANT	\N	PRESENT	0
292835	273967	19691J	PARTICIPANT	\N	PRESENT	0
292836	273967	14097Y	PARTICIPANT	\N	PRESENT	0
292837	273967	19689Q	PARTICIPANT	\N	PRESENT	0
292838	273967	19533U	PARTICIPANT	\N	PRESENT	0
292842	273967	19683J	PARTICIPANT	\N	PRESENT	0
292843	273967	14239U	PARTICIPANT	\N	PRESENT	0
292851	273967	08019V	PARTICIPANT	\N	PRESENT	0
292868	273967	14079W	PARTICIPANT	\N	PRESENT	0
292869	273967	11085T	PARTICIPANT	\N	PRESENT	0
292879	279374	01048V	PARTICIPANT	\N	PRESENT	0
292892	292891	07033P	PARTICIPANT	\N	PRESENT	0
292893	292891	95063L	PARTICIPANT	\N	PRESENT	0
275957	275956	96004D	PARTICIPANT	\N	PRESENT	0
275968	268444	04043D	PARTICIPANT	\N	EXCUSE	0
278422	278421	96004D	PARTICIPANT	\N	PRESENT	0
278423	278421	14331P	PARTICIPANT	\N	PRESENT	0
278424	278421	10015M	PARTICIPANT	\N	PRESENT	0
291659	287619	19657G	PARTICIPANT	\N	PRESENT	0
291660	287619	08048B	PARTICIPANT	\N	EXCUSE	0
291935	273924	14030Q	PARTICIPANT	\N	PRESENT	0
291936	273924	19739H	PARTICIPANT	\N	PRESENT	0
291745	289494	04071H	PARTICIPANT	\N	PRESENT	0
291937	273924	19549D	PARTICIPANT	\N	PRESENT	0
291747	289494	19545Y	PARTICIPANT	\N	PRESENT	0
291748	289494	01057W	PARTICIPANT	\N	PRESENT	0
291938	273924	17583W	PARTICIPANT	\N	PRESENT	0
291750	289494	11074Q	PRESIDENT	0	PRESENT	0
291751	289494	89017R	PARTICIPANT	\N	PRESENT	0
291752	289494	19667J	PARTICIPANT	\N	PRESENT	0
291939	273924	14169X	PARTICIPANT	\N	PRESENT	0
291940	289205	14034U	PARTICIPANT	\N	PRESENT	0
291755	289494	88008L	PARTICIPANT	\N	PRESENT	0
291756	289494	14225N	PARTICIPANT	\N	PRESENT	0
291757	289494	07029T	PARTICIPANT	\N	PRESENT	0
291758	289494	14085U	PARTICIPANT	\N	PRESENT	0
291759	289494	07004J	PARTICIPANT	\N	PRESENT	0
291760	289494	19349W	PARTICIPANT	\N	PRESENT	0
291761	289494	08010L	PARTICIPANT	\N	PRESENT	0
291762	289494	14253S	PARTICIPANT	\N	PRESENT	0
291763	289494	11048N	PARTICIPANT	\N	PRESENT	0
291764	289494	19479G	PARTICIPANT	\N	PRESENT	0
291765	289494	19647E	PARTICIPANT	\N	PRESENT	0
291766	289494	19711U	PARTICIPANT	\N	PRESENT	0
291767	289494	08034U	PARTICIPANT	\N	PRESENT	0
291768	289494	19651A	PARTICIPANT	\N	PRESENT	0
291769	289494	08069G	PARTICIPANT	\N	PRESENT	0
291941	273924	04049K	PARTICIPANT	\N	PRESENT	0
291942	273924	95015C	PARTICIPANT	\N	PRESENT	0
291772	289494	12016W	PARTICIPANT	\N	PRESENT	0
291773	289494	08011M	PARTICIPANT	\N	PRESENT	0
291774	289494	14034U	PARTICIPANT	\N	PRESENT	0
291775	289494	14159V	PARTICIPANT	\N	PRESENT	0
291776	289494	14173T	PARTICIPANT	\N	PRESENT	0
291777	289494	04086Q	PARTICIPANT	\N	PRESENT	0
291778	289494	11040E	PARTICIPANT	\N	PRESENT	0
291779	289494	11012A	PARTICIPANT	\N	PRESENT	0
291780	289494	14199E	PARTICIPANT	\N	PRESENT	0
291943	273924	11045K	PARTICIPANT	\N	PRESENT	0
291782	289494	19741B	PARTICIPANT	\N	PRESENT	0
291783	289494	14121F	PARTICIPANT	\N	PRESENT	0
291784	289494	99004R	PARTICIPANT	\N	PRESENT	0
291785	289494	08014Q	PARTICIPANT	\N	EXCUSE	0
291787	289196	19651A	PARTICIPANT	\N	PRESENT	0
291814	273924	04059M	PARTICIPANT	\N	PRESENT	0
291870	289205	14331P	PARTICIPANT	\N	PRESENT	0
291871	289205	11048N	PARTICIPANT	\N	PRESENT	0
291872	289205	01034P	PARTICIPANT	\N	PRESENT	0
291873	289205	19711U	PARTICIPANT	\N	PRESENT	0
291874	289205	19545Y	PARTICIPANT	\N	PRESENT	0
291875	289205	08011M	PARTICIPANT	\N	PRESENT	0
291876	289205	11074Q	PRESIDENT	0	PRESENT	0
291877	289205	11070L	PARTICIPANT	\N	PRESENT	0
291878	289205	07029T	PARTICIPANT	\N	PRESENT	0
291879	289205	14085U	PARTICIPANT	\N	PRESENT	0
291880	289205	19349W	PARTICIPANT	\N	PRESENT	0
291881	289205	14121F	PARTICIPANT	\N	PRESENT	0
291882	289205	19741B	PARTICIPANT	\N	PRESENT	0
291883	289205	08014Q	PARTICIPANT	\N	EXCUSE	0
291884	273924	14103D	PARTICIPANT	\N	PRESENT	0
291885	273924	14215L	PARTICIPANT	\N	PRESENT	0
291886	273924	14157T	PARTICIPANT	\N	PRESENT	0
291887	273924	14105F	PARTICIPANT	\N	PRESENT	0
291888	273924	04088S	PARTICIPANT	\N	PRESENT	0
291889	273924	19467C	PARTICIPANT	\N	PRESENT	0
291890	273924	19301E	PARTICIPANT	\N	PRESENT	0
291891	273924	19563B	PARTICIPANT	\N	PRESENT	0
291892	289205	01057W	PARTICIPANT	\N	PRESENT	0
291893	289205	14225N	PARTICIPANT	\N	PRESENT	0
291894	289205	99004R	PARTICIPANT	\N	PRESENT	0
291895	273924	19701S	PARTICIPANT	\N	PRESENT	0
296556	296555	11053K	PARTICIPANT	\N	PRESENT	0
291897	273924	14111D	PARTICIPANT	\N	PRESENT	0
291898	273924	14031R	PARTICIPANT	\N	PRESENT	0
291899	273924	14038Y	PARTICIPANT	\N	PRESENT	0
291900	273924	14115H	PARTICIPANT	\N	PRESENT	0
291901	273924	14063N	PARTICIPANT	\N	PRESENT	0
291902	273924	19333N	PARTICIPANT	\N	PRESENT	0
291903	273924	98050T	PARTICIPANT	\N	PRESENT	0
291904	273924	14029X	PARTICIPANT	\N	PRESENT	0
291905	273924	19543W	PARTICIPANT	\N	PRESENT	0
291906	273924	11097X	PARTICIPANT	\N	PRESENT	0
291907	273924	14069U	PARTICIPANT	\N	PRESENT	0
291908	273924	14221J	PARTICIPANT	\N	PRESENT	0
291909	273924	08019V	PARTICIPANT	\N	PRESENT	0
291910	289205	19651A	PARTICIPANT	\N	PRESENT	0
291911	289205	04086Q	PARTICIPANT	\N	EXCUSE	0
291912	273924	19758L	PARTICIPANT	\N	PRESENT	0
291913	273924	19629C	PARTICIPANT	\N	PRESENT	0
291914	273924	14265W	PARTICIPANT	\N	PRESENT	0
291944	273924	19643A	PARTICIPANT	\N	PRESENT	0
291916	273924	08053X	PARTICIPANT	\N	PRESENT	0
291917	287620	11097X	PARTICIPANT	\N	PRESENT	0
291918	287620	19663E	PARTICIPANT	\N	PRESENT	0
291919	273924	19399H	PARTICIPANT	\N	PRESENT	0
291920	273924	11043H	PARTICIPANT	\N	PRESENT	0
291921	273924	16685X	PARTICIPANT	\N	PRESENT	0
291922	273924	08062Y	PARTICIPANT	\N	PRESENT	0
291923	273924	14259Y	PARTICIPANT	\N	PRESENT	0
291924	287620	17779H	PARTICIPANT	\N	PRESENT	0
291925	273924	14197C	PARTICIPANT	\N	PRESENT	0
291926	273924	19551W	PARTICIPANT	\N	PRESENT	0
291927	273924	14219Q	PARTICIPANT	\N	PRESENT	0
291928	273924	19387D	PARTICIPANT	\N	PRESENT	0
291929	289205	19687N	PARTICIPANT	\N	PRESENT	0
291930	289205	12016W	PARTICIPANT	\N	PRESENT	0
291931	273924	19747H	PARTICIPANT	\N	PRESENT	0
291932	273924	19737F	PARTICIPANT	\N	PRESENT	0
291933	273924	19253P	PARTICIPANT	\N	PRESENT	0
291934	273924	14093U	PARTICIPANT	\N	PRESENT	0
291946	273924	19441R	PARTICIPANT	\N	PRESENT	0
291947	273924	19689Q	PARTICIPANT	\N	PRESENT	0
291948	273924	14109K	PARTICIPANT	\N	PRESENT	0
291949	287620	19521Q	PARTICIPANT	\N	PRESENT	0
291950	287620	11045K	PARTICIPANT	\N	PRESENT	0
291951	273924	01025N	PARTICIPANT	\N	PRESENT	0
291952	273924	04045F	PARTICIPANT	\N	PRESENT	0
291953	273924	01028R	PARTICIPANT	\N	PRESENT	0
291954	273924	11033F	PARTICIPANT	\N	PRESENT	0
291955	273924	08020N	PARTICIPANT	\N	PRESENT	0
291956	287620	01034P	PARTICIPANT	\N	EXCUSE	0
291957	289205	19479G	PARTICIPANT	\N	PRESENT	0
291958	273924	07034Q	PARTICIPANT	\N	PRESENT	0
291959	273924	14059S	PARTICIPANT	\N	PRESENT	0
291987	273924	19479G	PARTICIPANT	\N	PRESENT	0
291988	273924	19447X	PARTICIPANT	\N	PRESENT	0
291990	273924	14123H	PARTICIPANT	\N	PRESENT	0
291991	273924	14121F	PARTICIPANT	\N	PRESENT	0
291994	273924	04085P	PARTICIPANT	\N	PRESENT	0
291995	273924	14081Q	PARTICIPANT	\N	PRESENT	0
291996	288053	14097Y	PARTICIPANT	\N	PRESENT	0
291997	288053	04035D	PARTICIPANT	\N	PRESENT	0
291998	288053	19443T	PARTICIPANT	\N	PRESENT	0
291999	288053	95067Q	PARTICIPANT	\N	PRESENT	0
292000	288053	11080N	PARTICIPANT	\N	PRESENT	0
292001	288053	14133K	PARTICIPANT	\N	PRESENT	0
292002	288053	04034C	PARTICIPANT	\N	PRESENT	0
292003	288053	01058X	PARTICIPANT	\N	PRESENT	0
292004	288053	04040A	PARTICIPANT	\N	PRESENT	0
292005	288053	08058D	PARTICIPANT	\N	PRESENT	0
292006	288053	16685X	PARTICIPANT	\N	PRESENT	0
292007	288053	04042C	PRESIDENT	0	PRESENT	0
292008	288053	19251M	PARTICIPANT	\N	PRESENT	0
292009	288053	11066Q	PARTICIPANT	\N	PRESENT	0
292010	288053	19721W	PARTICIPANT	\N	PRESENT	0
292011	288053	98018T	PARTICIPANT	\N	PRESENT	0
292012	288053	19421M	PARTICIPANT	\N	PRESENT	0
292013	288053	98022P	PARTICIPANT	\N	PRESENT	0
292014	288053	11064N	PARTICIPANT	\N	PRESENT	0
292015	288053	98050T	PARTICIPANT	\N	PRESENT	0
292016	288053	14255U	PARTICIPANT	\N	PRESENT	0
292103	273924	14223L	PARTICIPANT	\N	PRESENT	0
292104	273924	01058X	PARTICIPANT	\N	PRESENT	0
296557	296555	14159V	PARTICIPANT	\N	PRESENT	0
296558	296555	05012A	PARTICIPANT	\N	PRESENT	0
296568	296567	14083S	PARTICIPANT	\N	PRESENT	0
296569	296567	14157T	PARTICIPANT	\N	PRESENT	0
296570	296567	08015R	PARTICIPANT	\N	PRESENT	0
296571	296567	19723Y	PARTICIPANT	\N	PRESENT	0
298408	298407	04047H	PARTICIPANT	\N	PRESENT	0
298409	298407	01024M	PARTICIPANT	\N	PRESENT	0
298411	298410	01024M	PARTICIPANT	\N	PRESENT	0
280987	280946	19695N	PARTICIPANT	\N	PRESENT	0
280988	280946	08062Y	PARTICIPANT	\N	PRESENT	0
280989	280946	01025N	PARTICIPANT	\N	PRESENT	0
280990	280946	11090Q	PRESIDENT	0	PRESENT	0
280991	280946	14207L	PARTICIPANT	\N	PRESENT	0
280992	280946	17589D	PARTICIPANT	\N	PRESENT	0
280993	280946	14257W	PARTICIPANT	\N	PRESENT	0
280994	280946	19383Y	PARTICIPANT	\N	PRESENT	0
280995	280946	19701S	PARTICIPANT	\N	PRESENT	0
280996	280946	14357A	PARTICIPANT	\N	PRESENT	0
280997	280946	19387D	PARTICIPANT	\N	PRESENT	0
280998	280946	19413M	PARTICIPANT	\N	PRESENT	0
280999	280946	14081Q	PARTICIPANT	\N	PRESENT	0
281000	280946	14221J	PARTICIPANT	\N	PRESENT	0
281001	280946	14237S	PARTICIPANT	\N	PRESENT	0
281002	280946	18083K	PARTICIPANT	\N	PRESENT	0
281003	280946	05012A	PARTICIPANT	\N	PRESENT	0
281004	280946	14051J	PARTICIPANT	\N	PRESENT	0
281005	280946	04049K	PARTICIPANT	\N	PRESENT	0
281006	280946	08015R	PARTICIPANT	\N	PRESENT	0
281007	280946	19503N	PARTICIPANT	\N	PRESENT	0
281008	280946	08019V	PARTICIPANT	\N	PRESENT	0
281009	280946	19369B	PARTICIPANT	\N	PRESENT	0
281010	280946	19511N	PARTICIPANT	\N	PRESENT	0
281011	280946	08024S	PARTICIPANT	\N	PRESENT	0
281012	280946	19563B	PARTICIPANT	\N	PRESENT	0
281013	280946	14265W	PARTICIPANT	\N	PRESENT	0
281014	280946	14329V	PARTICIPANT	\N	PRESENT	0
281015	280946	14135M	PARTICIPANT	\N	PRESENT	0
281016	280946	19467C	PARTICIPANT	\N	PRESENT	0
281017	280946	14103D	PARTICIPANT	\N	PRESENT	0
281018	280946	14031R	PARTICIPANT	\N	PRESENT	0
281019	280946	19713W	PARTICIPANT	\N	PRESENT	0
281020	280946	08038Y	PARTICIPANT	\N	PRESENT	0
281021	280946	14033T	PARTICIPANT	\N	PRESENT	0
281022	280946	19295A	PARTICIPANT	\N	PRESENT	0
281023	280946	19269X	PARTICIPANT	\N	PRESENT	0
281024	280946	14205J	PARTICIPANT	\N	PRESENT	0
281025	280946	11056N	PARTICIPANT	\N	PRESENT	0
281026	280946	04088S	PARTICIPANT	\N	PRESENT	0
281027	280946	14115H	PARTICIPANT	\N	PRESENT	0
281028	280946	11101A	PARTICIPANT	\N	PRESENT	0
281029	280946	19507S	PARTICIPANT	\N	PRESENT	0
281030	280946	19737F	PARTICIPANT	\N	PRESENT	0
281031	280946	19739H	PARTICIPANT	\N	PRESENT	0
281032	280946	19747H	PARTICIPANT	\N	PRESENT	0
281033	280946	19619A	PARTICIPANT	\N	PRESENT	0
281034	280946	04089T	PARTICIPANT	\N	EXCUSE	0
281035	280946	11081P	PARTICIPANT	\N	EXCUSE	0
281036	273877	14231L	PARTICIPANT	\N	PRESENT	0
281037	273877	97011G	PARTICIPANT	\N	PRESENT	0
281038	273877	14107H	PARTICIPANT	\N	PRESENT	0
281039	273877	11043H	PARTICIPANT	\N	PRESENT	0
281040	273877	19533U	PARTICIPANT	\N	PRESENT	0
281041	273877	95062K	PARTICIPANT	\N	PRESENT	0
281043	280946	19549D	PARTICIPANT	\N	PRESENT	0
281044	280946	19551W	PARTICIPANT	\N	PRESENT	0
281045	273877	19699S	PARTICIPANT	\N	PRESENT	0
281046	273877	01062T	PARTICIPANT	\N	PRESENT	0
281049	273877	14281W	PARTICIPANT	\N	PRESENT	0
281050	273877	19657G	PARTICIPANT	\N	PRESENT	0
281052	273877	08049C	PARTICIPANT	\N	PRESENT	0
281119	273878	14071N	PARTICIPANT	\N	PRESENT	0
281120	273878	04092N	PARTICIPANT	\N	PRESENT	0
281121	273878	11031D	PARTICIPANT	\N	PRESENT	0
281122	273878	19758L	PARTICIPANT	\N	PRESENT	0
281123	273878	19715Y	PARTICIPANT	\N	PRESENT	0
281124	273878	14281W	PARTICIPANT	\N	PRESENT	0
281125	273878	01062T	PARTICIPANT	\N	PRESENT	0
281126	273878	11066Q	PARTICIPANT	\N	PRESENT	0
281127	273878	14107H	PARTICIPANT	\N	PRESENT	0
281128	273878	11067R	PARTICIPANT	\N	PRESENT	0
281129	273878	19527W	PARTICIPANT	\N	PRESENT	0
281130	280937	14069U	PARTICIPANT	\N	PRESENT	0
281131	273878	14063N	PARTICIPANT	\N	PRESENT	0
281132	273878	14227Q	PARTICIPANT	\N	PRESENT	0
281135	273878	19697Q	PARTICIPANT	\N	PRESENT	0
281136	273878	04045F	PARTICIPANT	\N	PRESENT	0
281137	273878	98022P	PARTICIPANT	\N	PRESENT	0
281138	273878	19301E	PARTICIPANT	\N	PRESENT	0
281139	273878	19319Q	PARTICIPANT	\N	PRESENT	0
281140	273878	14219Q	PARTICIPANT	\N	PRESENT	0
281141	273878	16685X	PARTICIPANT	\N	PRESENT	0
281142	273878	19569H	PARTICIPANT	\N	PRESENT	0
281143	273878	19699S	PARTICIPANT	\N	PRESENT	0
281144	273878	14231L	PARTICIPANT	\N	PRESENT	0
281145	273878	14030Q	PARTICIPANT	\N	PRESENT	0
281146	273878	19335Q	PARTICIPANT	\N	PRESENT	0
281147	273878	19367Y	PARTICIPANT	\N	PRESENT	0
281148	273878	11056N	PARTICIPANT	\N	PRESENT	0
281149	273878	08049C	PARTICIPANT	\N	PRESENT	0
281150	273878	98050T	PARTICIPANT	\N	PRESENT	0
281151	273878	19675J	PARTICIPANT	\N	PRESENT	0
281152	273878	14026U	PARTICIPANT	\N	PRESENT	0
281153	273878	14213J	PARTICIPANT	\N	PRESENT	0
281154	273878	08034U	PARTICIPANT	\N	PRESENT	0
281155	273878	97011G	PARTICIPANT	\N	PRESENT	0
281156	273878	14217N	PARTICIPANT	\N	PRESENT	0
281157	273878	11103C	PARTICIPANT	\N	PRESENT	0
281158	273878	19575F	PARTICIPANT	\N	PRESENT	0
281159	273878	19657G	PARTICIPANT	\N	PRESENT	0
281160	273878	04088S	PARTICIPANT	\N	PRESENT	0
281161	273878	14029X	PARTICIPANT	\N	PRESENT	0
281162	273878	19415P	PARTICIPANT	\N	PRESENT	0
281163	273878	14119M	PARTICIPANT	\N	PRESENT	0
281164	273878	14191V	PARTICIPANT	\N	PRESENT	0
281165	273878	11043H	PARTICIPANT	\N	PRESENT	0
281166	273878	19691J	PARTICIPANT	\N	PRESENT	0
281167	273878	14123H	PARTICIPANT	\N	PRESENT	0
281168	273878	08020N	PARTICIPANT	\N	PRESENT	0
281169	273878	96004D	PARTICIPANT	\N	PRESENT	0
281170	273878	95030B	PARTICIPANT	\N	PRESENT	0
281171	273878	95062K	PARTICIPANT	\N	PRESENT	0
281172	273878	08038Y	PARTICIPANT	\N	PRESENT	0
281173	273878	08031R	PARTICIPANT	\N	PRESENT	0
281174	273878	19727D	PARTICIPANT	\N	PRESENT	0
281175	273878	19611R	PARTICIPANT	\N	PRESENT	0
281176	273878	14241N	PARTICIPANT	\N	PRESENT	0
281177	273878	19681G	PARTICIPANT	\N	PRESENT	0
281178	273878	14239U	PARTICIPANT	\N	PRESENT	0
281179	273878	10006L	PARTICIPANT	\N	PRESENT	0
281192	273878	19383Y	PARTICIPANT	\N	PRESENT	0
281193	273878	11064N	PARTICIPANT	\N	PRESENT	0
281195	273878	19467C	PARTICIPANT	\N	PRESENT	0
281198	273878	14042U	PARTICIPANT	\N	PRESENT	0
281116	280946	19565D	PARTICIPANT	\N	EXCUSE	0
281117	273878	11072N	PARTICIPANT	\N	PRESENT	0
281199	273878	15447F	PARTICIPANT	\N	PRESENT	0
281200	273878	18083K	PARTICIPANT	\N	PRESENT	0
281201	273878	14031R	PARTICIPANT	\N	PRESENT	0
281202	273878	14357A	PARTICIPANT	\N	PRESENT	0
281203	280937	19253P	PARTICIPANT	\N	PRESENT	0
281204	280937	14021P	PARTICIPANT	\N	PRESENT	0
281205	273878	14257W	PARTICIPANT	\N	PRESENT	0
281206	273878	14069U	PARTICIPANT	\N	PRESENT	0
281272	273879	11072N	PARTICIPANT	\N	PRESENT	0
281273	273879	19507S	PARTICIPANT	\N	PRESENT	0
281274	273879	04088S	PARTICIPANT	\N	PRESENT	0
281275	273879	19467C	PARTICIPANT	\N	PRESENT	0
281276	273879	14026U	PARTICIPANT	\N	PRESENT	0
281277	273879	14033T	PARTICIPANT	\N	PRESENT	0
281278	273879	95037J	PARTICIPANT	\N	PRESENT	0
281279	273879	11031D	PARTICIPANT	\N	PRESENT	0
281280	273879	19715Y	PARTICIPANT	\N	PRESENT	0
281281	273879	19727D	PARTICIPANT	\N	PRESENT	0
281282	273879	80013X	PARTICIPANT	\N	PRESENT	0
281283	273879	19295A	PARTICIPANT	\N	PRESENT	0
281284	273879	19413M	PARTICIPANT	\N	PRESENT	0
281285	273879	19551W	PARTICIPANT	\N	PRESENT	0
281286	273879	14107H	PARTICIPANT	\N	PRESENT	0
281287	273879	14207L	PARTICIPANT	\N	PRESENT	0
281288	273879	19387D	PARTICIPANT	\N	PRESENT	0
281289	273879	19681G	PARTICIPANT	\N	PRESENT	0
281290	273879	98022P	PARTICIPANT	\N	PRESENT	0
281291	273879	19511N	PARTICIPANT	\N	PRESENT	0
281292	273879	19301E	PARTICIPANT	\N	PRESENT	0
281293	273879	08049C	PARTICIPANT	\N	PRESENT	0
281294	273879	19611R	PARTICIPANT	\N	PRESENT	0
281295	273879	19619A	PARTICIPANT	\N	PRESENT	0
281296	273879	14063N	PARTICIPANT	\N	PRESENT	0
281297	273879	19441R	PARTICIPANT	\N	PRESENT	0
281298	273879	08031R	PARTICIPANT	\N	PRESENT	0
281299	273879	19563B	PARTICIPANT	\N	PRESENT	0
281300	273879	08055A	PARTICIPANT	\N	PRESENT	0
281301	273879	14030Q	PARTICIPANT	\N	PRESENT	0
281302	273879	01025N	PARTICIPANT	\N	PRESENT	0
281303	273879	11056N	PARTICIPANT	\N	PRESENT	0
281304	273879	19747H	PARTICIPANT	\N	PRESENT	0
281305	273879	19745F	PARTICIPANT	\N	PRESENT	0
279378	279377	08016S	PARTICIPANT	\N	EXCUSE	0
279379	279377	14275Y	PARTICIPANT	\N	EXCUSE	0
279380	279377	19659J	PARTICIPANT	\N	EXCUSE	0
279381	279377	11010L	PARTICIPANT	\N	EXCUSE	0
279382	279377	14059S	PARTICIPANT	\N	EXCUSE	0
279383	279377	19577H	PARTICIPANT	\N	EXCUSE	0
279384	279377	14135M	PARTICIPANT	\N	EXCUSE	0
279385	279377	96004D	PARTICIPANT	\N	EXCUSE	0
279392	274860	14299H	PARTICIPANT	\N	PRESENT	0
279394	274859	14299H	PARTICIPANT	\N	PRESENT	0
279395	274858	14299H	PARTICIPANT	\N	PRESENT	0
279397	274857	14299H	PARTICIPANT	\N	PRESENT	0
287932	282453	14331P	PARTICIPANT	\N	EXCUSE	0
288454	273918	14107H	PARTICIPANT	\N	PRESENT	0
288455	273918	01062T	PARTICIPANT	\N	PRESENT	0
288456	273918	08038Y	PARTICIPANT	\N	PRESENT	0
288457	273918	80013X	PARTICIPANT	\N	PRESENT	0
288458	273918	14197C	PARTICIPANT	\N	PRESENT	0
288459	273918	89017R	PARTICIPANT	\N	PRESENT	0
288460	273918	11090Q	PARTICIPANT	\N	PRESENT	0
288462	273918	14028W	PARTICIPANT	\N	PRESENT	0
288463	273918	08024S	PARTICIPANT	\N	PRESENT	0
288464	273918	19747H	PARTICIPANT	\N	PRESENT	0
288466	273918	19649G	PARTICIPANT	\N	PRESENT	0
288467	273918	19647E	PARTICIPANT	\N	PRESENT	0
288468	273918	19727D	PARTICIPANT	\N	PRESENT	0
288470	273918	14331P	PARTICIPANT	\N	PRESENT	0
288471	273918	19531S	PARTICIPANT	\N	PRESENT	0
288472	273918	08012N	PARTICIPANT	\N	PRESENT	0
288473	273918	11049P	PARTICIPANT	\N	PRESENT	0
288474	273918	14281W	PARTICIPANT	\N	PRESENT	0
288475	273918	11066Q	PARTICIPANT	\N	PRESENT	0
288482	273918	11045K	PARTICIPANT	\N	PRESENT	0
288477	273918	14065Q	PARTICIPANT	\N	PRESENT	0
288478	273918	19549D	PARTICIPANT	\N	PRESENT	0
288479	273918	19551W	PARTICIPANT	\N	PRESENT	0
288480	273918	14081Q	PARTICIPANT	\N	PRESENT	0
288481	273918	07034Q	PARTICIPANT	\N	PRESENT	0
288483	273918	14169X	PARTICIPANT	\N	PRESENT	0
288484	273918	19525U	PARTICIPANT	\N	PRESENT	0
288485	273918	08058D	PARTICIPANT	\N	PRESENT	0
288486	273918	14121F	PARTICIPANT	\N	PRESENT	0
288487	273918	19683J	PARTICIPANT	\N	PRESENT	0
288488	273918	14227Q	PARTICIPANT	\N	PRESENT	0
288489	273918	14001X	PARTICIPANT	\N	PRESENT	0
288490	273918	19333N	PARTICIPANT	\N	PRESENT	0
288491	273918	14038Y	PARTICIPANT	\N	PRESENT	0
288492	273918	14207L	PARTICIPANT	\N	PRESENT	0
288493	273918	19725B	PARTICIPANT	\N	PRESENT	0
288494	273918	19723Y	PARTICIPANT	\N	PRESENT	0
288495	273918	14257W	PARTICIPANT	\N	PRESENT	0
288496	273918	14097Y	PARTICIPANT	\N	PRESENT	0
288497	273918	04049K	PARTICIPANT	\N	PRESENT	0
288498	273918	14109K	PARTICIPANT	\N	PRESENT	0
288499	273918	14063N	PARTICIPANT	\N	PRESENT	0
288500	273918	19527W	PARTICIPANT	\N	PRESENT	0
288501	273918	14061L	PARTICIPANT	\N	PRESENT	0
288502	273918	11067R	PARTICIPANT	\N	PRESENT	0
288503	273918	19503N	PARTICIPANT	\N	PRESENT	0
288504	273918	07029T	PARTICIPANT	\N	PRESENT	0
288505	273918	19489J	PARTICIPANT	\N	PRESENT	0
288506	273918	19591F	PARTICIPANT	\N	PRESENT	0
288507	273918	08015R	PARTICIPANT	\N	PRESENT	0
288508	273918	19251M	PARTICIPANT	\N	PRESENT	0
288509	273918	19413M	PARTICIPANT	\N	PRESENT	0
288510	273918	14147R	PARTICIPANT	\N	PRESENT	0
288511	273918	01028R	PARTICIPANT	\N	PRESENT	0
288512	273918	19707Y	PARTICIPANT	\N	PRESENT	0
288513	273918	04089T	PARTICIPANT	\N	PRESENT	0
288514	273918	14231L	PARTICIPANT	\N	PRESENT	0
288515	273918	14034U	PARTICIPANT	\N	PRESENT	0
288516	273918	96004D	PARTICIPANT	\N	PRESENT	0
288517	273918	19691J	PARTICIPANT	\N	PRESENT	0
288518	273918	14033T	PARTICIPANT	\N	PRESENT	0
288519	273918	19369B	PARTICIPANT	\N	PRESENT	0
288520	273918	19611R	PARTICIPANT	\N	PRESENT	0
288521	273918	19511N	PARTICIPANT	\N	PRESENT	0
288522	273918	19399H	PARTICIPANT	\N	PRESENT	0
288523	273918	19737F	PARTICIPANT	\N	PRESENT	0
288524	273918	19699S	PARTICIPANT	\N	PRESENT	0
288525	273918	19619A	PARTICIPANT	\N	PRESENT	0
288526	273918	14133K	PARTICIPANT	\N	PRESENT	0
288527	273918	19415P	PARTICIPANT	\N	PRESENT	0
288528	273918	19689Q	PARTICIPANT	\N	PRESENT	0
288529	273918	98024R	PARTICIPANT	\N	PRESENT	0
288530	273918	14213J	PARTICIPANT	\N	PRESENT	0
288531	273918	19569H	PARTICIPANT	\N	PRESENT	0
288532	273918	16685X	PARTICIPANT	\N	PRESENT	0
288533	273918	08039A	PARTICIPANT	\N	PRESENT	0
288534	273918	08056B	PARTICIPANT	\N	PRESENT	0
288535	273918	14042U	PARTICIPANT	\N	PRESENT	0
288536	273918	14219Q	PARTICIPANT	\N	PRESENT	0
288537	273918	07033P	PARTICIPANT	\N	PRESENT	0
288538	273918	19441R	PARTICIPANT	\N	PRESENT	0
288539	273918	14021P	PARTICIPANT	\N	PRESENT	0
288540	273918	98023Q	PARTICIPANT	\N	PRESENT	0
288541	273918	98050T	PARTICIPANT	\N	PRESENT	0
288542	273918	14275Y	PARTICIPANT	\N	PRESENT	0
288543	273918	14277B	PARTICIPANT	\N	PRESENT	0
288544	273918	14265W	PARTICIPANT	\N	PRESENT	0
288545	273918	11033F	PARTICIPANT	\N	PRESENT	0
288546	273918	08048B	PARTICIPANT	\N	PRESENT	0
288547	273918	08017T	PARTICIPANT	\N	PRESENT	0
288548	273918	19713W	PARTICIPANT	\N	PRESENT	0
288549	273918	19705W	PARTICIPANT	\N	PRESENT	0
288550	273918	14267Y	PARTICIPANT	\N	PRESENT	0
288551	273918	14103D	PARTICIPANT	\N	PRESENT	0
288552	273918	14221J	PARTICIPANT	\N	PRESENT	0
288553	273918	11103C	PARTICIPANT	\N	PRESENT	0
288554	273918	19739H	PARTICIPANT	\N	PRESENT	0
288555	273918	19335Q	PARTICIPANT	\N	PRESENT	0
288556	273918	11053K	PARTICIPANT	\N	PRESENT	0
288557	273918	14073Q	PARTICIPANT	\N	PRESENT	0
288558	273918	14217N	PARTICIPANT	\N	PRESENT	0
288559	273918	11085T	PARTICIPANT	\N	PRESENT	0
288560	273918	11070L	PARTICIPANT	\N	PRESENT	0
288561	273918	19577H	PARTICIPANT	\N	PRESENT	0
288562	273918	04018C	PARTICIPANT	\N	PRESENT	0
288563	273918	01024M	PARTICIPANT	\N	PRESENT	0
288564	273918	04070G	PARTICIPANT	\N	PRESENT	0
288565	273918	14030Q	PARTICIPANT	\N	PRESENT	0
288566	273918	19575F	PARTICIPANT	\N	PRESENT	0
288567	273918	19669L	PARTICIPANT	\N	PRESENT	0
288568	273918	19521Q	PARTICIPANT	\N	PRESENT	0
288569	273918	05012A	PARTICIPANT	\N	PRESENT	0
288570	273918	14235Q	PARTICIPANT	\N	PRESENT	0
288571	273918	14253S	PARTICIPANT	\N	PRESENT	0
288572	273918	08062Y	PARTICIPANT	\N	PRESENT	0
288573	273918	14135M	PARTICIPANT	\N	PRESENT	0
288574	273918	19507S	PARTICIPANT	\N	PRESENT	0
288575	273918	19447X	PARTICIPANT	\N	PRESENT	0
288576	273918	11099A	PARTICIPANT	\N	PRESENT	0
288577	273918	14059S	PARTICIPANT	\N	PRESENT	0
288578	273918	04088S	PARTICIPANT	\N	PRESENT	0
288579	273918	08044W	PARTICIPANT	\N	PRESENT	0
288580	273918	14329V	PARTICIPANT	\N	PRESENT	0
288581	273918	19679N	PARTICIPANT	\N	PRESENT	0
288582	273918	14119M	PARTICIPANT	\N	PRESENT	0
288583	273918	19667J	PARTICIPANT	\N	PRESENT	0
288584	273918	14041T	PARTICIPANT	\N	PRESENT	0
288585	273918	18083K	PARTICIPANT	\N	PRESENT	0
288586	273918	19693L	PARTICIPANT	\N	PRESENT	0
288587	273918	19729F	PARTICIPANT	\N	PRESENT	0
288588	273918	19467C	PARTICIPANT	\N	PRESENT	0
288589	273918	11026G	PARTICIPANT	\N	PRESENT	0
288590	273918	14029X	PARTICIPANT	\N	PRESENT	0
288591	273918	19701S	PARTICIPANT	\N	PRESENT	0
288592	273918	05008E	PARTICIPANT	\N	PRESENT	0
288593	273918	19675J	PARTICIPANT	\N	PRESENT	0
288594	273918	11109J	PARTICIPANT	\N	PRESENT	0
288595	273918	08034U	PARTICIPANT	\N	PRESENT	0
288596	273918	19663E	PARTICIPANT	\N	PRESENT	0
288597	273918	19673G	PARTICIPANT	\N	PRESENT	0
288598	273918	19573D	PARTICIPANT	\N	PRESENT	0
288599	273918	19295A	PARTICIPANT	\N	PRESENT	0
288600	273918	80027E	PARTICIPANT	\N	PRESENT	0
288601	273918	19387D	PARTICIPANT	\N	PRESENT	0
288602	273918	14205J	PARTICIPANT	\N	PRESENT	0
288614	273918	14089Y	PARTICIPANT	\N	PRESENT	0
288604	273918	01048V	PARTICIPANT	\N	PRESENT	0
288605	273918	04071H	PARTICIPANT	\N	PRESENT	0
288693	273918	19749K	PARTICIPANT	\N	PRESENT	0
279400	279399	05008E	PARTICIPANT	\N	PRESENT	0
281181	281180	19721W	PARTICIPANT	\N	PRESENT	0
281182	281180	14079W	PARTICIPANT	\N	PRESENT	0
281183	281180	95030B	PARTICIPANT	\N	PRESENT	0
281184	281180	02002K	PARTICIPANT	\N	PRESENT	0
281185	281180	15447F	PARTICIPANT	\N	PRESENT	0
281186	281180	98022P	PARTICIPANT	\N	PRESENT	0
281187	281180	04097T	PARTICIPANT	\N	PRESENT	0
281188	281180	08015R	PARTICIPANT	\N	PRESENT	0
281189	281180	01048V	PARTICIPANT	\N	PRESENT	0
281190	281180	19503N	PARTICIPANT	\N	PRESENT	0
281191	281180	04044E	PARTICIPANT	\N	PRESENT	0
286355	273911	19683J	PARTICIPANT	\N	PRESENT	0
286356	273911	19693L	PARTICIPANT	\N	PRESENT	0
286357	273911	80027E	PARTICIPANT	\N	PRESENT	0
286358	273911	19253P	PARTICIPANT	\N	PRESENT	0
286359	273911	04059M	PARTICIPANT	\N	PRESENT	0
286360	273911	19695N	PARTICIPANT	\N	PRESENT	0
286361	273911	19713W	PARTICIPANT	\N	PRESENT	0
286362	273911	17589D	PARTICIPANT	\N	PRESENT	0
286363	273911	80013X	PARTICIPANT	\N	PRESENT	0
286364	273911	19329S	PARTICIPANT	\N	PRESENT	0
286365	285992	19545Y	PARTICIPANT	\N	PRESENT	0
286366	273911	19301E	PARTICIPANT	\N	PRESENT	0
286367	273911	11104D	PARTICIPANT	\N	PRESENT	0
286368	273911	11085T	PARTICIPANT	\N	PRESENT	0
286369	273911	19507S	PARTICIPANT	\N	PRESENT	0
286370	273911	11031D	PARTICIPANT	\N	PRESENT	0
286371	286328	14111D	PARTICIPANT	\N	PRESENT	0
286372	286328	07034Q	PARTICIPANT	\N	PRESENT	0
286373	286328	11026G	PARTICIPANT	\N	PRESENT	0
286374	286328	01024M	PARTICIPANT	\N	PRESENT	0
286710	273912	14033T	PARTICIPANT	\N	PRESENT	0
286376	286328	19581D	PARTICIPANT	\N	PRESENT	0
286377	286328	19585H	PARTICIPANT	\N	PRESENT	0
286378	286328	04047H	PARTICIPANT	\N	PRESENT	0
286379	286328	11033F	PARTICIPANT	\N	PRESENT	0
286380	286328	01028R	PARTICIPANT	\N	PRESENT	0
286381	286328	05008E	PRESIDENT	0	PRESENT	0
286382	286328	14231L	PARTICIPANT	\N	PRESENT	0
286383	286328	14089Y	PARTICIPANT	\N	PRESENT	0
286384	286328	95063L	PARTICIPANT	\N	PRESENT	0
286385	286328	14179A	PARTICIPANT	\N	PRESENT	0
286386	286328	14151M	PARTICIPANT	\N	PRESENT	0
286387	286328	14215L	PARTICIPANT	\N	PRESENT	0
286388	286328	11072N	PARTICIPANT	\N	PRESENT	0
286389	273911	08020N	PARTICIPANT	\N	PRESENT	0
286709	273912	14135M	PARTICIPANT	\N	PRESENT	0
286711	273912	11083R	PARTICIPANT	\N	PRESENT	0
286712	273912	08043V	PARTICIPANT	\N	PRESENT	0
286715	273912	14193X	PARTICIPANT	\N	PRESENT	0
286716	273912	14229S	PARTICIPANT	\N	PRESENT	0
286717	273912	98050T	PARTICIPANT	\N	PRESENT	0
286718	273912	19383Y	PARTICIPANT	\N	PRESENT	0
286719	273912	19719D	PARTICIPANT	\N	PRESENT	0
286720	273912	14197C	PARTICIPANT	\N	PRESENT	0
286721	273912	11043H	PARTICIPANT	\N	PRESENT	0
286722	273912	14267Y	PARTICIPANT	\N	PRESENT	0
286729	273912	14227Q	PARTICIPANT	\N	PRESENT	0
286730	273912	19565D	PARTICIPANT	\N	PRESENT	0
286731	273912	08034U	PARTICIPANT	\N	PRESENT	0
286732	273912	19687N	PARTICIPANT	\N	PRESENT	0
286733	273912	14133K	PARTICIPANT	\N	PRESENT	0
286734	273912	08015R	PARTICIPANT	\N	PRESENT	0
286735	273912	19621T	PARTICIPANT	\N	PRESENT	0
286736	273912	04044E	PARTICIPANT	\N	PRESENT	0
286737	273912	19369B	PARTICIPANT	\N	PRESENT	0
286765	273912	08047A	PARTICIPANT	\N	PRESENT	0
286766	273912	17583W	PARTICIPANT	\N	PRESENT	0
286767	273912	14199E	PARTICIPANT	\N	PRESENT	0
286774	273912	11049P	PARTICIPANT	\N	PRESENT	0
286775	273912	14251Q	PARTICIPANT	\N	PRESENT	0
286776	273912	11109J	PARTICIPANT	\N	PRESENT	0
286777	273912	95015C	PARTICIPANT	\N	PRESENT	0
286779	273912	19691J	PARTICIPANT	\N	PRESENT	0
286780	273912	14087W	PARTICIPANT	\N	PRESENT	0
286903	273913	11072N	PARTICIPANT	\N	PRESENT	0
286904	273913	04047H	PARTICIPANT	\N	PRESENT	0
286905	273913	11033F	PARTICIPANT	\N	PRESENT	0
286906	273913	11067R	PARTICIPANT	\N	PRESENT	0
286907	273913	19413M	PARTICIPANT	\N	PRESENT	0
286908	273913	19333N	PARTICIPANT	\N	PRESENT	0
286909	273913	14001X	PARTICIPANT	\N	PRESENT	0
286910	273913	14231L	PARTICIPANT	\N	PRESENT	0
286911	273913	14241N	PARTICIPANT	\N	PRESENT	0
286912	273913	14261S	PARTICIPANT	\N	PRESENT	0
286913	273913	19629C	PARTICIPANT	\N	PRESENT	0
286914	273913	19253P	PARTICIPANT	\N	PRESENT	0
286915	273913	19737F	PARTICIPANT	\N	PRESENT	0
286916	273913	19691J	PARTICIPANT	\N	PRESENT	0
286917	273913	14097Y	PARTICIPANT	\N	PRESENT	0
286918	273913	19725B	PARTICIPANT	\N	PRESENT	0
286919	273913	14281W	PARTICIPANT	\N	PRESENT	0
286920	273913	08043V	PARTICIPANT	\N	PRESENT	0
286921	273913	11026G	PARTICIPANT	\N	PRESENT	0
286922	273913	14051J	PARTICIPANT	\N	PRESENT	0
286923	273913	08060W	PARTICIPANT	\N	PRESENT	0
286924	273913	01028R	PARTICIPANT	\N	PRESENT	0
286925	273913	04034C	PARTICIPANT	\N	PRESENT	0
286926	273913	19687N	PARTICIPANT	\N	PRESENT	0
286927	273913	05008E	PARTICIPANT	\N	PRESENT	0
286928	273913	19671E	PARTICIPANT	\N	PRESENT	0
286929	273913	14265W	PARTICIPANT	\N	PRESENT	0
286930	273913	19573D	PARTICIPANT	\N	PRESENT	0
286931	273913	19447X	PARTICIPANT	\N	PRESENT	0
286932	273913	19443T	PARTICIPANT	\N	PRESENT	0
286933	273913	08020N	PARTICIPANT	\N	PRESENT	0
286934	273913	14215L	PARTICIPANT	\N	PRESENT	0
286935	273913	04085P	PARTICIPANT	\N	PRESENT	0
286936	273913	99004R	PARTICIPANT	\N	PRESENT	0
286937	273913	11043H	PARTICIPANT	\N	PRESENT	0
286938	273913	95030B	PARTICIPANT	\N	PRESENT	0
286939	273913	14119M	PARTICIPANT	\N	PRESENT	0
286940	273913	11109J	PARTICIPANT	\N	PRESENT	0
286941	273913	19631V	PARTICIPANT	\N	PRESENT	0
286942	273913	19591F	PARTICIPANT	\N	PRESENT	0
286943	273913	11045K	PARTICIPANT	\N	PRESENT	0
286944	273913	04059M	PARTICIPANT	\N	PRESENT	0
286945	273913	17589D	PARTICIPANT	\N	PRESENT	0
286946	273913	19549D	PARTICIPANT	\N	PRESENT	0
286947	273913	14257W	PARTICIPANT	\N	PRESENT	0
286948	273913	14207L	PARTICIPANT	\N	PRESENT	0
286949	273913	19531S	PARTICIPANT	\N	PRESENT	0
286950	273913	19565D	PARTICIPANT	\N	PRESENT	0
286951	273913	19649G	PARTICIPANT	\N	PRESENT	0
286952	273913	14089Y	PARTICIPANT	\N	PRESENT	0
286953	273913	14237S	PARTICIPANT	\N	PRESENT	0
286954	273913	14147R	PARTICIPANT	\N	PRESENT	0
286955	273913	14105F	PARTICIPANT	\N	PRESENT	0
286956	273913	19347U	PARTICIPANT	\N	PRESENT	0
286957	273913	08062Y	PARTICIPANT	\N	PRESENT	0
286958	273913	19723Y	PARTICIPANT	\N	PRESENT	0
286959	273913	14021P	PARTICIPANT	\N	PRESENT	0
286960	273913	14065Q	PARTICIPANT	\N	PRESENT	0
286961	273913	19727D	PARTICIPANT	\N	PRESENT	0
286962	273913	19551W	PARTICIPANT	\N	PRESENT	0
286963	273913	80013X	PARTICIPANT	\N	PRESENT	0
286964	273913	19349W	PARTICIPANT	\N	PRESENT	0
286965	273913	19387D	PARTICIPANT	\N	PRESENT	0
286966	273913	19533U	PARTICIPANT	\N	PRESENT	0
286967	273913	19673G	PARTICIPANT	\N	PRESENT	0
286968	273913	19575F	PARTICIPANT	\N	PRESENT	0
286969	273913	14038Y	PARTICIPANT	\N	PRESENT	0
286970	273913	04088S	PARTICIPANT	\N	PRESENT	0
286971	273913	14197C	PARTICIPANT	\N	PRESENT	0
286972	273913	19669L	PARTICIPANT	\N	PRESENT	0
286973	273913	14026U	PARTICIPANT	\N	PRESENT	0
286974	273913	14187A	PARTICIPANT	\N	PRESENT	0
286975	273913	08031R	PARTICIPANT	\N	PRESENT	0
286976	273913	19741B	PARTICIPANT	\N	PRESENT	0
286977	273913	01057W	PARTICIPANT	\N	PRESENT	0
286978	273913	14249W	PARTICIPANT	\N	PRESENT	0
286979	273913	11097X	PARTICIPANT	\N	PRESENT	0
286980	273913	14073Q	PARTICIPANT	\N	PRESENT	0
286981	273913	19713W	PARTICIPANT	\N	PRESENT	0
286982	273913	14213J	PARTICIPANT	\N	PRESENT	0
286983	273913	19729F	PARTICIPANT	\N	PRESENT	0
286984	273913	14069U	PARTICIPANT	\N	PRESENT	0
286985	273913	19383Y	PARTICIPANT	\N	PRESENT	0
286986	273913	08015R	PARTICIPANT	\N	PRESENT	0
286987	273913	14061L	PARTICIPANT	\N	PRESENT	0
286988	273913	19335Q	PARTICIPANT	\N	PRESENT	0
286989	273913	19715Y	PARTICIPANT	\N	PRESENT	0
286990	273913	95063L	PARTICIPANT	\N	PRESENT	0
286991	273913	19749K	PARTICIPANT	\N	PRESENT	0
286992	273913	14042U	PARTICIPANT	\N	PRESENT	0
286993	273913	10006L	PARTICIPANT	\N	PRESENT	0
286994	273913	14217N	PARTICIPANT	\N	PRESENT	0
278135	274815	14239U	PARTICIPANT	\N	PRESENT	0
278136	274815	19575F	PARTICIPANT	\N	PRESENT	0
278137	274815	19415P	PARTICIPANT	\N	PRESENT	0
278138	274815	11103C	PARTICIPANT	\N	PRESENT	0
278139	274815	14195A	PARTICIPANT	\N	PRESENT	0
278140	274815	08052W	PARTICIPANT	\N	PRESENT	0
278141	274815	19663E	PARTICIPANT	\N	PRESENT	0
278142	274815	10006L	PARTICIPANT	\N	PRESENT	0
278143	274815	14217N	PARTICIPANT	\N	PRESENT	0
278144	274815	14042U	PARTICIPANT	\N	PRESENT	0
278145	274815	14281W	PARTICIPANT	\N	PRESENT	0
278146	274815	14087W	PARTICIPANT	\N	PRESENT	0
278147	274815	19521Q	PARTICIPANT	\N	PRESENT	0
278148	274815	14355X	PARTICIPANT	\N	PRESENT	0
278149	274815	08048B	PARTICIPANT	\N	EXCUSE	0
278150	274815	19553Y	PARTICIPANT	\N	PRESENT	0
278151	274815	19569H	PARTICIPANT	\N	PRESENT	0
278152	274815	14213J	PARTICIPANT	\N	PRESENT	0
278153	274815	19715Y	PARTICIPANT	\N	PRESENT	0
278154	274815	19723Y	PARTICIPANT	\N	PRESENT	0
278155	274815	11067R	PARTICIPANT	\N	PRESENT	0
278156	274815	14223L	PARTICIPANT	\N	PRESENT	0
278157	274815	04092N	PRESIDENT	0	PRESENT	0
278158	274815	14119M	PARTICIPANT	\N	PRESENT	0
278161	274815	14071N	PARTICIPANT	\N	PRESENT	0
278162	274815	19679N	PARTICIPANT	\N	PRESENT	0
278163	274815	11097X	PARTICIPANT	\N	PRESENT	0
278164	274815	04045F	PARTICIPANT	\N	PRESENT	0
278165	274815	19703U	PARTICIPANT	\N	PRESENT	0
278166	274815	14227Q	PARTICIPANT	\N	PRESENT	0
278167	274815	19527W	PARTICIPANT	\N	PRESENT	0
287934	287933	14071N	PARTICIPANT	\N	EXCUSE	0
287974	287933	04086Q	PARTICIPANT	\N	EXCUSE	0
287975	287933	04040A	PRESIDENT	0	PRESENT	0
288045	287933	08034U	PARTICIPANT	\N	EXCUSE	0
288211	287933	08038Y	PARTICIPANT	\N	EXCUSE	0
288338	287933	19735D	PARTICIPANT	\N	EXCUSE	0
298413	298412	04047H	PARTICIPANT	\N	PRESENT	0
298414	298412	01024M	PARTICIPANT	\N	PRESENT	0
298455	289187	04086Q	PARTICIPANT	\N	PRESENT	0
298456	289187	04092N	PARTICIPANT	\N	PRESENT	0
298457	289187	14087W	PARTICIPANT	\N	PRESENT	0
298458	289187	11031D	PARTICIPANT	\N	PRESENT	0
298459	289187	17779H	PARTICIPANT	\N	PRESENT	0
298460	289187	14227Q	PARTICIPANT	\N	PRESENT	0
298461	289187	14281W	PARTICIPANT	\N	PRESENT	0
298462	289187	08052W	PARTICIPANT	\N	PRESENT	0
298463	289187	04045F	PARTICIPANT	\N	PRESENT	0
298464	289187	11012A	PARTICIPANT	\N	PRESENT	0
298465	289187	14267Y	PARTICIPANT	\N	PRESENT	0
298466	289187	19657G	PARTICIPANT	\N	PRESENT	0
298467	289187	14041T	PARTICIPANT	\N	PRESENT	0
298468	289187	98005N	PARTICIPANT	\N	PRESENT	0
298469	289187	19687N	PARTICIPANT	\N	PRESENT	0
298470	289187	19760E	PARTICIPANT	\N	PRESENT	0
298471	289187	19335Q	PARTICIPANT	\N	PRESENT	0
298472	289187	19521Q	PARTICIPANT	\N	PRESENT	0
298473	289187	19679N	PARTICIPANT	\N	PRESENT	0
298474	289187	11067R	PARTICIPANT	\N	PRESENT	0
298475	289187	19697Q	PARTICIPANT	\N	PRESENT	0
298476	289187	04057K	PARTICIPANT	\N	PRESENT	0
298477	289187	14059S	PARTICIPANT	\N	PRESENT	0
298478	289187	19553Y	PARTICIPANT	\N	PRESENT	0
298479	289187	14119M	PARTICIPANT	\N	PRESENT	0
298480	289187	11045K	PARTICIPANT	\N	PRESENT	0
298481	289187	19749K	PARTICIPANT	\N	PRESENT	0
298482	289187	19711U	PARTICIPANT	\N	PRESENT	0
298483	289187	19319Q	PARTICIPANT	\N	PRESENT	0
298484	289187	11097X	PARTICIPANT	\N	PRESENT	0
298485	289187	08019V	PARTICIPANT	\N	PRESENT	0
298486	289187	19701S	PARTICIPANT	\N	PRESENT	0
298487	289187	14083S	PARTICIPANT	\N	PRESENT	0
298488	289187	14071N	PARTICIPANT	\N	PRESENT	0
298489	289187	19715Y	PARTICIPANT	\N	PRESENT	0
298490	289187	19727D	PARTICIPANT	\N	PRESENT	0
298491	289187	19689Q	PARTICIPANT	\N	PRESENT	0
298492	289187	14219Q	PARTICIPANT	\N	PRESENT	0
298493	289187	11083R	PARTICIPANT	\N	PRESENT	0
298494	289187	19695N	PARTICIPANT	\N	PRESENT	0
298495	289187	19663E	PARTICIPANT	\N	PRESENT	0
298497	289187	14039A	PARTICIPANT	\N	PRESENT	0
298498	289187	14329V	PARTICIPANT	\N	PRESENT	0
298499	289187	08073C	PARTICIPANT	\N	PRESENT	0
298553	289188	14071N	PARTICIPANT	\N	PRESENT	0
298554	289188	19399H	PARTICIPANT	\N	PRESENT	0
298555	289188	11067R	PARTICIPANT	\N	PRESENT	0
298557	289188	19657G	PARTICIPANT	\N	PRESENT	0
298558	289188	14227Q	PARTICIPANT	\N	PRESENT	0
298559	289188	19553Y	PARTICIPANT	\N	PRESENT	0
298560	289188	04092N	PARTICIPANT	\N	PRESENT	0
298561	289188	19679N	PARTICIPANT	\N	PRESENT	0
298562	289188	19521Q	PARTICIPANT	\N	PRESENT	0
298563	289188	04045F	PARTICIPANT	\N	PRESENT	0
298564	289188	08052W	PARTICIPANT	\N	PRESENT	0
298565	289188	19695N	PARTICIPANT	\N	PRESENT	0
298566	289188	19711U	PARTICIPANT	\N	PRESENT	0
298567	289188	19697Q	PARTICIPANT	\N	PRESENT	0
298568	289188	17779H	PARTICIPANT	\N	PRESENT	0
298569	289188	19667J	PARTICIPANT	\N	PRESENT	0
298570	289188	14087W	PARTICIPANT	\N	PRESENT	0
298571	289188	14041T	PARTICIPANT	\N	PRESENT	0
298572	289188	19663E	PARTICIPANT	\N	PRESENT	0
298573	289188	14217N	PARTICIPANT	\N	PRESENT	0
298574	289188	19760E	PARTICIPANT	\N	PRESENT	0
298575	289188	19335Q	PARTICIPANT	\N	PRESENT	0
298576	289188	14329V	PARTICIPANT	\N	PRESENT	0
298577	289188	11031D	PARTICIPANT	\N	PRESENT	0
298584	289188	19687N	PARTICIPANT	\N	PRESENT	0
298586	289188	19611R	PARTICIPANT	\N	PRESENT	0
298587	289188	19689Q	PARTICIPANT	\N	PRESENT	0
298606	289188	14039A	PARTICIPANT	\N	PRESENT	0
298607	289188	98005N	PARTICIPANT	\N	PRESENT	0
298608	289188	08019V	PARTICIPANT	\N	PRESENT	0
298609	289188	14059S	PARTICIPANT	\N	PRESENT	0
298610	289188	11045K	PARTICIPANT	\N	PRESENT	0
298611	289188	11115U	PARTICIPANT	\N	PRESENT	0
298612	289188	14267Y	PARTICIPANT	\N	PRESENT	0
298613	289188	19715Y	PARTICIPANT	\N	PRESENT	0
298615	289188	14281W	PARTICIPANT	\N	PRESENT	0
298616	289188	11012A	PARTICIPANT	\N	PRESENT	0
298621	289188	19651A	PARTICIPANT	\N	PRESENT	0
299340	299339	08060W	PARTICIPANT	\N	PRESENT	0
299341	299339	14215L	PARTICIPANT	\N	PRESENT	0
299342	299339	12041X	PARTICIPANT	\N	PRESENT	0
299344	299339	08053X	PARTICIPANT	\N	PRESENT	0
299345	299339	19671E	PARTICIPANT	\N	PRESENT	0
299346	299339	98035U	PARTICIPANT	\N	PRESENT	0
298551	289188	11072N	PARTICIPANT	\N	PRESENT	0
298552	289188	19727D	PARTICIPANT	\N	PRESENT	0
299348	299339	14051J	PARTICIPANT	\N	PRESENT	0
299777	298280	11070L	PARTICIPANT	\N	PRESENT	0
299778	298280	14225N	PARTICIPANT	\N	PRESENT	0
299779	298280	11110B	PARTICIPANT	\N	PRESENT	0
299780	298280	14085U	PARTICIPANT	\N	PRESENT	0
299781	298280	19349W	PARTICIPANT	\N	PRESENT	0
299782	298280	19479G	PARTICIPANT	\N	PRESENT	0
299783	298280	11048N	PARTICIPANT	\N	PRESENT	0
299784	298280	19647E	PARTICIPANT	\N	PRESENT	0
299785	298280	19711U	PARTICIPANT	\N	PRESENT	0
299786	298280	08034U	PARTICIPANT	\N	PRESENT	0
299835	299357	19563B	PARTICIPANT	\N	PRESENT	0
299788	298280	19687N	PARTICIPANT	\N	PRESENT	0
299789	298280	19689Q	PARTICIPANT	\N	PRESENT	0
299790	298280	12016W	PARTICIPANT	\N	PRESENT	0
299791	298280	08011M	PARTICIPANT	\N	PRESENT	0
299792	298280	14159V	PARTICIPANT	\N	PRESENT	0
299793	298280	14173T	PARTICIPANT	\N	PRESENT	0
299794	298280	04086Q	PARTICIPANT	\N	PRESENT	0
299795	298280	14083S	PARTICIPANT	\N	PRESENT	0
299796	298280	11012A	PARTICIPANT	\N	PRESENT	0
299797	298280	19741B	PARTICIPANT	\N	PRESENT	0
299798	298280	14121F	PARTICIPANT	\N	PRESENT	0
299799	298280	99004R	PARTICIPANT	\N	PRESENT	0
299800	298280	07029T	PARTICIPANT	\N	EXCUSE	0
299801	298280	08014Q	PARTICIPANT	\N	EXCUSE	0
299802	297489	08048B	PARTICIPANT	\N	PRESENT	0
299803	297489	04045F	PARTICIPANT	\N	EXCUSE	0
299817	298280	14034U	PARTICIPANT	\N	PRESENT	0
299836	299357	14038Y	PARTICIPANT	\N	PRESENT	0
299837	299357	19467C	PARTICIPANT	\N	EXCUSE	0
299868	298800	19543W	PARTICIPANT	\N	PRESENT	0
299869	298800	19581D	PARTICIPANT	\N	PRESENT	0
299870	298800	04044E	PARTICIPANT	\N	PRESENT	0
299871	298800	19585H	PARTICIPANT	\N	PRESENT	0
299872	298800	01028R	PARTICIPANT	\N	PRESENT	0
299873	298800	19447X	PARTICIPANT	\N	PRESENT	0
299874	298800	05008E	PRESIDENT	0	PRESENT	0
299875	298800	14041T	PARTICIPANT	\N	PRESENT	0
299876	298800	14179A	PARTICIPANT	\N	PRESENT	0
281308	273879	11090Q	PARTICIPANT	\N	PRESENT	0
281309	273879	14265W	PARTICIPANT	\N	PRESENT	0
281310	273879	97011G	PARTICIPANT	\N	PRESENT	0
281311	273879	14357A	PARTICIPANT	\N	PRESENT	0
281312	273879	14329V	PARTICIPANT	\N	PRESENT	0
281313	273879	14213J	PARTICIPANT	\N	PRESENT	0
281314	273879	04049K	PARTICIPANT	\N	PRESENT	0
281315	273879	19575F	PARTICIPANT	\N	PRESENT	0
281316	273879	08015R	PARTICIPANT	\N	PRESENT	0
281317	273879	11099A	PARTICIPANT	\N	PRESENT	0
281318	273879	08062Y	PARTICIPANT	\N	PRESENT	0
281319	273879	19657G	PARTICIPANT	\N	PRESENT	0
281320	273879	14135M	PARTICIPANT	\N	PRESENT	0
281321	273879	11097X	PARTICIPANT	\N	PRESENT	0
281322	273879	14157T	PARTICIPANT	\N	PRESENT	0
281323	273879	19415P	PARTICIPANT	\N	PRESENT	0
281324	273879	18083K	PARTICIPANT	\N	PRESENT	0
281325	273879	14115H	PARTICIPANT	\N	PRESENT	0
281326	273879	08020N	PARTICIPANT	\N	PRESENT	0
281327	273879	14029X	PARTICIPANT	\N	PRESENT	0
281328	273879	19515S	PARTICIPANT	\N	PRESENT	0
281329	273879	15447F	PARTICIPANT	\N	PRESENT	0
281330	273879	19713W	PARTICIPANT	\N	PRESENT	0
281331	273879	08010L	PARTICIPANT	\N	PRESENT	0
281332	273879	19629C	PARTICIPANT	\N	PRESENT	0
281333	273879	14327T	PARTICIPANT	\N	PRESENT	0
281334	273879	14257W	PARTICIPANT	\N	PRESENT	0
281335	273879	14281W	PARTICIPANT	\N	PRESENT	0
281339	273879	11103C	PARTICIPANT	\N	PRESENT	0
281337	273879	19725B	PARTICIPANT	\N	PRESENT	0
281338	273879	19503N	PARTICIPANT	\N	PRESENT	0
281306	273879	95030B	PARTICIPANT	\N	PRESENT	0
281307	273879	96004D	PARTICIPANT	\N	PRESENT	0
281340	273879	17583W	PARTICIPANT	\N	PRESENT	0
281341	273879	19543W	PARTICIPANT	\N	PRESENT	0
281342	273879	19569H	PARTICIPANT	\N	PRESENT	0
281343	273879	14097Y	PARTICIPANT	\N	PRESENT	0
281344	273879	14205J	PARTICIPANT	\N	PRESENT	0
281345	273879	14191V	PARTICIPANT	\N	PRESENT	0
281346	273879	11043H	PARTICIPANT	\N	PRESENT	0
281347	273879	17589D	PARTICIPANT	\N	PRESENT	0
281348	280937	11049P	PARTICIPANT	\N	PRESENT	0
281349	280937	04008A	PARTICIPANT	\N	PRESENT	0
281350	273879	19383Y	PARTICIPANT	\N	PRESENT	0
281351	273879	19701S	PARTICIPANT	\N	PRESENT	0
281352	273879	01058X	PARTICIPANT	\N	PRESENT	0
281353	273879	01034P	PARTICIPANT	\N	PRESENT	0
281354	273879	19583F	PARTICIPANT	\N	PRESENT	0
281356	273879	14109K	PARTICIPANT	\N	PRESENT	0
281357	279256	14331P	PARTICIPANT	\N	PRESENT	0
281358	279256	04071H	PARTICIPANT	\N	PRESENT	0
281359	279256	01048V	PARTICIPANT	\N	PRESENT	0
281360	279256	01057W	PARTICIPANT	\N	PRESENT	0
281361	279256	11053K	PARTICIPANT	\N	PRESENT	0
281362	279256	19667J	PARTICIPANT	\N	PRESENT	0
281363	279256	11074Q	PRESIDENT	0	PRESENT	0
281364	279256	14225N	PARTICIPANT	\N	PRESENT	0
281365	279256	11070L	PARTICIPANT	\N	PRESENT	0
281366	279256	07029T	PARTICIPANT	\N	PRESENT	0
281367	279256	14085U	PARTICIPANT	\N	PRESENT	0
281368	279256	07004J	PARTICIPANT	\N	PRESENT	0
281369	279256	19349W	PARTICIPANT	\N	PRESENT	0
281370	279256	14253S	PARTICIPANT	\N	PRESENT	0
281371	279256	19479G	PARTICIPANT	\N	PRESENT	0
281372	279256	19711U	PARTICIPANT	\N	PRESENT	0
281373	279256	19689Q	PARTICIPANT	\N	PRESENT	0
281374	279256	08011M	PARTICIPANT	\N	PRESENT	0
281375	279256	14034U	PARTICIPANT	\N	PRESENT	0
281376	279256	19719D	PARTICIPANT	\N	PRESENT	0
281377	279256	11040E	PARTICIPANT	\N	PRESENT	0
281378	279256	04086Q	PARTICIPANT	\N	PRESENT	0
281379	279256	19741B	PARTICIPANT	\N	PRESENT	0
281381	279256	99004R	PARTICIPANT	\N	PRESENT	0
281382	279256	11048N	PARTICIPANT	\N	PRESENT	0
281383	279256	19531S	PARTICIPANT	\N	PRESENT	0
281384	279256	11012A	PARTICIPANT	\N	EXCUSE	0
281385	279256	08014Q	PARTICIPANT	\N	EXCUSE	0
281386	279256	88008L	PARTICIPANT	\N	EXCUSE	0
281387	273879	14119M	PARTICIPANT	\N	PRESENT	0
281388	273879	14121F	PARTICIPANT	\N	PRESENT	0
281389	273879	07029T	PARTICIPANT	\N	PRESENT	0
281390	273879	95062K	PARTICIPANT	\N	PRESENT	0
281396	273879	19739H	PARTICIPANT	\N	PRESENT	0
281397	273879	14073Q	PARTICIPANT	\N	PRESENT	0
281398	273879	08061X	PARTICIPANT	\N	PRESENT	0
281399	273879	19703U	PARTICIPANT	\N	PRESENT	0
281400	273879	19369B	PARTICIPANT	\N	PRESENT	0
281402	280937	19543W	PARTICIPANT	\N	PRESENT	0
281403	273879	19549D	PARTICIPANT	\N	PRESENT	0
281405	273879	04085P	PARTICIPANT	\N	PRESENT	0
281408	273879	19581D	PARTICIPANT	\N	PRESENT	0
281409	281395	14038Y	PARTICIPANT	\N	PRESENT	0
281411	281410	14038Y	PARTICIPANT	\N	PRESENT	0
281412	273879	14159V	PARTICIPANT	\N	PRESENT	0
281413	273879	14061L	PARTICIPANT	\N	PRESENT	0
281414	273879	14331P	PARTICIPANT	\N	PRESENT	0
281415	273879	08024S	PARTICIPANT	\N	PRESENT	0
281416	273879	14241N	PARTICIPANT	\N	PRESENT	0
281417	273879	14031R	PARTICIPANT	\N	PRESENT	0
281427	273879	19479G	PARTICIPANT	\N	PRESENT	0
281511	281510	08045X	PARTICIPANT	\N	PRESENT	0
281512	281510	19441R	PARTICIPANT	\N	PRESENT	0
281513	281510	04045F	PARTICIPANT	\N	PRESENT	0
281514	281510	14169X	PARTICIPANT	\N	PRESENT	0
281515	281510	11099A	PARTICIPANT	\N	PRESENT	0
281516	281510	04049K	PARTICIPANT	\N	PRESENT	0
281517	281510	08015R	PARTICIPANT	\N	PRESENT	0
281518	281510	11109J	PARTICIPANT	\N	PRESENT	0
281519	281510	19503N	PARTICIPANT	\N	PRESENT	0
281520	281510	08049C	PARTICIPANT	\N	PRESENT	0
281521	281510	19347U	PARTICIPANT	\N	PRESENT	0
281522	281510	14109K	PARTICIPANT	\N	PRESENT	0
281523	281510	14195A	PARTICIPANT	\N	PRESENT	0
281524	281510	14213J	PARTICIPANT	\N	PRESENT	0
281525	281510	19369B	PARTICIPANT	\N	PRESENT	0
281526	281510	98024R	PARTICIPANT	\N	PRESENT	0
281527	281510	08039A	PARTICIPANT	\N	PRESENT	0
281604	273881	04086Q	PARTICIPANT	\N	PRESENT	0
281605	273881	05008E	PARTICIPANT	\N	PRESENT	0
281606	273881	07034Q	PARTICIPANT	\N	PRESENT	0
281607	273881	19649G	PARTICIPANT	\N	PRESENT	0
281608	273881	19687N	PARTICIPANT	\N	PRESENT	0
281609	273881	04085P	PARTICIPANT	\N	PRESENT	0
281610	273881	14121F	PARTICIPANT	\N	PRESENT	0
281611	273881	14107H	PARTICIPANT	\N	PRESENT	0
281612	273881	19543W	PARTICIPANT	\N	PRESENT	0
281613	273881	19691J	PARTICIPANT	\N	PRESENT	0
281614	273881	19441R	PARTICIPANT	\N	PRESENT	0
281615	273881	14191V	PARTICIPANT	\N	PRESENT	0
281616	273881	08031R	PARTICIPANT	\N	PRESENT	0
281617	273881	19629C	PARTICIPANT	\N	PRESENT	0
281618	273881	19737F	PARTICIPANT	\N	PRESENT	0
281619	273881	96004D	PARTICIPANT	\N	PRESENT	0
281620	273881	08020N	PARTICIPANT	\N	PRESENT	0
281621	273881	04092N	PARTICIPANT	\N	PRESENT	0
281622	273881	14071N	PARTICIPANT	\N	PRESENT	0
281623	273881	14069U	PARTICIPANT	\N	PRESENT	0
281624	273881	14031R	PARTICIPANT	\N	PRESENT	0
281625	273881	14038Y	PARTICIPANT	\N	PRESENT	0
281626	273881	19335Q	PARTICIPANT	\N	PRESENT	0
281627	273881	19747H	PARTICIPANT	\N	PRESENT	0
281628	273881	14329V	PARTICIPANT	\N	PRESENT	0
281629	273881	95063L	PARTICIPANT	\N	PRESENT	0
281630	273881	14331P	PARTICIPANT	\N	PRESENT	0
281631	273881	08044W	PARTICIPANT	\N	PRESENT	0
281632	273881	17583W	PARTICIPANT	\N	PRESENT	0
281633	273881	14029X	PARTICIPANT	\N	PRESENT	0
281634	273881	04088S	PARTICIPANT	\N	PRESENT	0
281635	273881	19741B	PARTICIPANT	\N	PRESENT	0
281636	273881	19715Y	PARTICIPANT	\N	PRESENT	0
281637	273881	19679N	PARTICIPANT	\N	PRESENT	0
281638	273881	14147R	PARTICIPANT	\N	PRESENT	0
281639	273881	19521Q	PARTICIPANT	\N	PRESENT	0
281640	273881	14169X	PARTICIPANT	\N	PRESENT	0
281641	273881	11109J	PARTICIPANT	\N	PRESENT	0
281642	273881	14241N	PARTICIPANT	\N	PRESENT	0
281643	273881	14119M	PARTICIPANT	\N	PRESENT	0
281644	273881	19415P	PARTICIPANT	\N	PRESENT	0
281645	273881	19739H	PARTICIPANT	\N	PRESENT	0
281646	273881	19697Q	PARTICIPANT	\N	PRESENT	0
281647	273881	14111D	PARTICIPANT	\N	PRESENT	0
281648	273881	14197C	PARTICIPANT	\N	PRESENT	0
281649	273881	05012A	PARTICIPANT	\N	PRESENT	0
281650	273881	11072N	PARTICIPANT	\N	PRESENT	0
281651	273881	14265W	PARTICIPANT	\N	PRESENT	0
281652	273881	08019V	PARTICIPANT	\N	PRESENT	0
281653	273881	14193X	PARTICIPANT	\N	PRESENT	0
281654	273881	17637T	PARTICIPANT	\N	PRESENT	0
271235	271233	08043V	PARTICIPANT	\N	PRESENT	0
271236	271233	19643A	PARTICIPANT	\N	PRESENT	0
271237	271233	11083R	PARTICIPANT	\N	PRESENT	0
271238	271233	19611R	PARTICIPANT	\N	PRESENT	0
271239	271233	08039A	PARTICIPANT	\N	PRESENT	0
271240	271233	04057K	PARTICIPANT	\N	PRESENT	0
271242	271233	14109K	PARTICIPANT	\N	PRESENT	0
271243	271233	14229S	PARTICIPANT	\N	PRESENT	0
271245	271233	04018C	PARTICIPANT	\N	PRESENT	0
271246	271233	19749K	PARTICIPANT	\N	PRESENT	0
271558	270439	08014Q	PARTICIPANT	\N	EXCUSE	0
285389	273899	11070L	PARTICIPANT	\N	PRESENT	0
285390	273899	01028R	PARTICIPANT	\N	PRESENT	0
285391	273899	14259Y	PARTICIPANT	\N	PRESENT	0
285392	273899	14275Y	PARTICIPANT	\N	PRESENT	0
285393	273899	19651A	PARTICIPANT	\N	PRESENT	0
285394	273899	14257W	PARTICIPANT	\N	PRESENT	0
285395	273899	04088S	PARTICIPANT	\N	PRESENT	0
285396	273899	14083S	PARTICIPANT	\N	PRESENT	0
285397	273899	01025N	PARTICIPANT	\N	PRESENT	0
285398	273899	14038Y	PARTICIPANT	\N	PRESENT	0
285399	273899	19629C	PARTICIPANT	\N	PRESENT	0
285400	273899	14215L	PARTICIPANT	\N	PRESENT	0
285401	273899	19553Y	PARTICIPANT	\N	PRESENT	0
285402	273899	19515S	PARTICIPANT	\N	PRESENT	0
285403	273899	19533U	PARTICIPANT	\N	PRESENT	0
285404	273899	11056N	PARTICIPANT	\N	PRESENT	0
285405	273899	04038G	PARTICIPANT	\N	PRESENT	0
285406	273899	14089Y	PARTICIPANT	\N	PRESENT	0
285407	273899	11049P	PARTICIPANT	\N	PRESENT	0
285408	273899	01024M	PARTICIPANT	\N	PRESENT	0
285409	273899	14211G	PARTICIPANT	\N	PRESENT	0
285410	273899	07034Q	PARTICIPANT	\N	PRESENT	0
285411	273899	14105F	PARTICIPANT	\N	PRESENT	0
285412	273899	19489J	PARTICIPANT	\N	PRESENT	0
285413	273899	14221J	PARTICIPANT	\N	PRESENT	0
285414	273899	11043H	PARTICIPANT	\N	PRESENT	0
285415	273899	19747H	PARTICIPANT	\N	PRESENT	0
285416	273899	14001X	PARTICIPANT	\N	PRESENT	0
285417	273899	14329V	PARTICIPANT	\N	PRESENT	0
285418	273899	19667J	PARTICIPANT	\N	PRESENT	0
285419	273899	19583F	PARTICIPANT	\N	PRESENT	0
285420	273899	19543W	PARTICIPANT	\N	PRESENT	0
285421	273899	19725B	PARTICIPANT	\N	PRESENT	0
285422	273899	04057K	PARTICIPANT	\N	PRESENT	0
285423	273899	19447X	PARTICIPANT	\N	PRESENT	0
285424	273899	19421M	PARTICIPANT	\N	PRESENT	0
285425	273899	19551W	PARTICIPANT	\N	PRESENT	0
285426	273899	19333N	PARTICIPANT	\N	PRESENT	0
285427	273899	11012A	PARTICIPANT	\N	PRESENT	0
285428	273899	14327T	PARTICIPANT	\N	PRESENT	0
285429	273899	04049K	PARTICIPANT	\N	PRESENT	0
285430	273899	14187A	PARTICIPANT	\N	PRESENT	0
285431	273899	14097Y	PARTICIPANT	\N	PRESENT	0
285432	273899	19593H	PARTICIPANT	\N	PRESENT	0
285433	273899	07029T	PARTICIPANT	\N	PRESENT	0
285434	273899	14157T	PARTICIPANT	\N	PRESENT	0
285435	273899	19749K	PARTICIPANT	\N	PRESENT	0
285436	273899	14169X	PARTICIPANT	\N	PRESENT	0
285437	273899	14357A	PARTICIPANT	\N	PRESENT	0
285438	273899	19441R	PARTICIPANT	\N	PRESENT	0
285439	273899	19621T	PARTICIPANT	\N	PRESENT	0
285440	273899	14251Q	PARTICIPANT	\N	PRESENT	0
285441	273899	19399H	PARTICIPANT	\N	PRESENT	0
285442	273899	14109K	PARTICIPANT	\N	PRESENT	0
285443	273899	19503N	PARTICIPANT	\N	PRESENT	0
285444	273899	08031R	PARTICIPANT	\N	PRESENT	0
285445	273899	19739H	PARTICIPANT	\N	PRESENT	0
285446	273899	05008E	PARTICIPANT	\N	PRESENT	0
285447	273899	04086Q	PARTICIPANT	\N	PRESENT	0
285448	273899	19335Q	PARTICIPANT	\N	PRESENT	0
285449	273899	01057W	PARTICIPANT	\N	PRESENT	0
285450	273899	11097X	PARTICIPANT	\N	PRESENT	0
285451	273899	14053L	PARTICIPANT	\N	PRESENT	0
285452	273899	08068F	PARTICIPANT	\N	PRESENT	0
285453	273899	14265W	PARTICIPANT	\N	PRESENT	0
285454	273899	14069U	PARTICIPANT	\N	PRESENT	0
285455	273899	19691J	PARTICIPANT	\N	PRESENT	0
285456	273899	19575F	PARTICIPANT	\N	PRESENT	0
285457	273899	11048N	PARTICIPANT	\N	PRESENT	0
285458	273899	05012A	PARTICIPANT	\N	PRESENT	0
285459	273899	19599P	PARTICIPANT	\N	PRESENT	0
285460	273899	01058X	PARTICIPANT	\N	PRESENT	0
285461	273899	19349W	PARTICIPANT	\N	PRESENT	0
285462	273899	11067R	PARTICIPANT	\N	PRESENT	0
285463	273899	17589D	PARTICIPANT	\N	PRESENT	0
285464	273899	14195A	PARTICIPANT	\N	PRESENT	0
285465	273899	14217N	PARTICIPANT	\N	PRESENT	0
285466	273899	08010L	PARTICIPANT	\N	PRESENT	0
285467	273899	14231L	PARTICIPANT	\N	PRESENT	0
285468	273899	08038Y	PARTICIPANT	\N	PRESENT	0
285469	273899	14087W	PARTICIPANT	\N	PRESENT	0
285470	273899	14267Y	PARTICIPANT	\N	PRESENT	0
285471	273899	14034U	PARTICIPANT	\N	PRESENT	0
285472	273899	19565D	PARTICIPANT	\N	PRESENT	0
285473	273899	14147R	PARTICIPANT	\N	PRESENT	0
285474	273899	19413M	PARTICIPANT	\N	PRESENT	0
285475	273899	14179A	PARTICIPANT	\N	PRESENT	0
285476	273902	11077T	PARTICIPANT	\N	PRESENT	0
285506	273902	08009T	PARTICIPANT	\N	PRESENT	0
285508	273902	95063L	PARTICIPANT	\N	PRESENT	0
285509	273902	19651A	PARTICIPANT	\N	PRESENT	0
285510	273902	19697Q	PARTICIPANT	\N	PRESENT	0
285511	273902	19563B	PARTICIPANT	\N	PRESENT	0
285512	273902	19387D	PARTICIPANT	\N	PRESENT	0
285513	273902	19681G	PARTICIPANT	\N	PRESENT	0
285514	273902	98023Q	PARTICIPANT	\N	PRESENT	0
285515	273902	04057K	PARTICIPANT	\N	PRESENT	0
285516	273902	19583F	PARTICIPANT	\N	PRESENT	0
285517	273902	19713W	PARTICIPANT	\N	PRESENT	0
285518	273902	19441R	PARTICIPANT	\N	PRESENT	0
285519	273902	19525U	PARTICIPANT	\N	PRESENT	0
285520	273902	14051J	PARTICIPANT	\N	PRESENT	0
285521	273902	14063N	PARTICIPANT	\N	PRESENT	0
285522	273902	19527W	PARTICIPANT	\N	PRESENT	0
285523	273902	19503N	PARTICIPANT	\N	PRESENT	0
285524	273902	19295A	PARTICIPANT	\N	PRESENT	0
285525	273902	14227Q	PARTICIPANT	\N	PRESENT	0
285526	273902	19683J	PARTICIPANT	\N	PRESENT	0
285527	273902	04085P	PARTICIPANT	\N	PRESENT	0
285528	273902	14157T	PARTICIPANT	\N	PRESENT	0
285529	273902	14033T	PARTICIPANT	\N	PRESENT	0
285530	273902	04034C	PARTICIPANT	\N	PRESENT	0
285531	273902	19531S	PARTICIPANT	\N	PRESENT	0
285532	273902	95062K	PARTICIPANT	\N	PRESENT	0
285533	273902	14197C	PARTICIPANT	\N	PRESENT	0
285534	273902	11109J	PARTICIPANT	\N	PRESENT	0
285535	273902	19551W	PARTICIPANT	\N	PRESENT	0
285536	273902	08068F	PARTICIPANT	\N	PRESENT	0
285537	273902	08052W	PARTICIPANT	\N	PRESENT	0
285538	273902	07029T	PARTICIPANT	\N	PRESENT	0
285539	273902	19673G	PARTICIPANT	\N	PRESENT	0
285540	273902	19369B	PARTICIPANT	\N	PRESENT	0
285541	273902	08039A	PARTICIPANT	\N	PRESENT	0
285542	273902	14211G	PARTICIPANT	\N	PRESENT	0
285543	273902	17637T	PARTICIPANT	\N	PRESENT	0
285544	273902	19413M	PARTICIPANT	\N	PRESENT	0
285545	273902	01058X	PARTICIPANT	\N	PRESENT	0
285546	273902	19739H	PARTICIPANT	\N	PRESENT	0
285547	273902	19747H	PARTICIPANT	\N	PRESENT	0
285548	273902	98050T	PARTICIPANT	\N	PRESENT	0
285549	273902	01025N	PARTICIPANT	\N	PRESENT	0
285550	273902	14357A	PARTICIPANT	\N	PRESENT	0
285551	273902	14215L	PARTICIPANT	\N	PRESENT	0
285552	273902	19621T	PARTICIPANT	\N	PRESENT	0
285553	273902	14069U	PARTICIPANT	\N	PRESENT	0
285554	273902	19447X	PARTICIPANT	\N	PRESENT	0
285555	273902	05012A	PARTICIPANT	\N	PRESENT	0
285556	273902	19415P	PARTICIPANT	\N	PRESENT	0
285557	273902	14187A	PARTICIPANT	\N	PRESENT	0
285558	273902	19399H	PARTICIPANT	\N	PRESENT	0
285559	273902	07034Q	PARTICIPANT	\N	PRESENT	0
285560	273902	97011G	PARTICIPANT	\N	PRESENT	0
285561	273902	14249W	PARTICIPANT	\N	PRESENT	0
285562	273902	19695N	PARTICIPANT	\N	PRESENT	0
285563	273902	19687N	PARTICIPANT	\N	PRESENT	0
285567	273902	19711U	PARTICIPANT	\N	PRESENT	0
285568	273902	14041T	PARTICIPANT	\N	PRESENT	0
285569	273902	04049K	PARTICIPANT	\N	PRESENT	0
285570	273902	11083R	PARTICIPANT	\N	PRESENT	0
285571	273902	14173T	PARTICIPANT	\N	PRESENT	0
285572	273902	04088S	PARTICIPANT	\N	PRESENT	0
285573	273902	14151M	PARTICIPANT	\N	PRESENT	0
285577	273902	11041F	PARTICIPANT	\N	PRESENT	0
285578	273902	02002K	PARTICIPANT	\N	PRESENT	0
285579	273902	14259Y	PARTICIPANT	\N	PRESENT	0
285580	273902	19701S	PARTICIPANT	\N	PRESENT	0
285584	273902	19731Y	PARTICIPANT	\N	PRESENT	0
273290	273289	14239U	PARTICIPANT	\N	PRESENT	0
273291	273289	19295A	PARTICIPANT	\N	PRESENT	0
273292	273289	14217N	PARTICIPANT	\N	PRESENT	0
273293	273289	04044E	PARTICIPANT	\N	PRESENT	0
273294	273289	19691J	PARTICIPANT	\N	PRESENT	0
275955	268444	19723Y	PARTICIPANT	\N	PRESENT	0
285673	285672	89017R	PARTICIPANT	\N	PRESENT	0
286997	273913	08044W	PARTICIPANT	\N	PRESENT	0
286998	273913	14087W	PARTICIPANT	\N	PRESENT	0
286999	273913	08061X	PARTICIPANT	\N	PRESENT	0
287000	273913	04033B	PARTICIPANT	\N	PRESENT	0
287001	273913	08068F	PARTICIPANT	\N	PRESENT	0
287002	273913	19503N	PARTICIPANT	\N	PRESENT	0
287003	273913	14053L	PARTICIPANT	\N	PRESENT	0
287004	273913	18083K	PARTICIPANT	\N	PRESENT	0
287005	273913	19719D	PARTICIPANT	\N	PRESENT	0
287006	273913	19703U	PARTICIPANT	\N	PRESENT	0
287007	273913	19521Q	PARTICIPANT	\N	PRESENT	0
287008	273913	11056N	PARTICIPANT	\N	PRESENT	0
287009	273913	11077T	PARTICIPANT	\N	PRESENT	0
287010	273913	14151M	PARTICIPANT	\N	PRESENT	0
287011	273913	19647E	PARTICIPANT	\N	PRESENT	0
287345	286778	14030Q	PARTICIPANT	\N	PRESENT	0
287346	286778	08043V	PARTICIPANT	\N	PRESENT	0
287347	286778	11031D	PARTICIPANT	\N	PRESENT	0
287348	286778	19715Y	PARTICIPANT	\N	PRESENT	0
287349	286778	19731Y	PARTICIPANT	\N	PRESENT	0
287350	286778	08031R	PARTICIPANT	\N	PRESENT	0
287351	286778	11045K	PARTICIPANT	\N	PRESENT	0
287352	286778	01043Q	PARTICIPANT	\N	EXCUSE	0
287353	286778	04035D	PARTICIPANT	\N	EXCUSE	0
287355	286778	07029T	PARTICIPANT	\N	EXCUSE	0
287379	284611	19575F	PARTICIPANT	\N	PRESENT	0
287380	284611	11103C	PARTICIPANT	\N	PRESENT	0
287381	284611	14195A	PARTICIPANT	\N	PRESENT	0
287382	284611	11031D	PARTICIPANT	\N	PRESENT	0
287383	284611	08052W	PARTICIPANT	\N	PRESENT	0
286995	273913	14275Y	PARTICIPANT	\N	PRESENT	0
286996	273913	14030Q	PARTICIPANT	\N	PRESENT	0
287384	284611	19663E	PARTICIPANT	\N	EXCUSE	0
287385	284611	98024R	PARTICIPANT	\N	PRESENT	0
287386	284611	14217N	PARTICIPANT	\N	PRESENT	0
287387	284611	14042U	PARTICIPANT	\N	PRESENT	0
287388	284611	14281W	PARTICIPANT	\N	PRESENT	0
287389	284611	14087W	PARTICIPANT	\N	PRESENT	0
287390	284611	19521Q	PARTICIPANT	\N	PRESENT	0
287391	284611	14355X	PARTICIPANT	\N	EXCUSE	0
287392	284611	08048B	PARTICIPANT	\N	PRESENT	0
287393	284611	08041T	PARTICIPANT	\N	EXCUSE	0
287394	284611	19727D	PARTICIPANT	\N	PRESENT	0
287395	284611	14026U	PARTICIPANT	\N	PRESENT	0
287396	284611	19691J	PARTICIPANT	\N	PRESENT	0
287397	284611	19569H	PARTICIPANT	\N	PRESENT	0
287398	284611	14213J	PARTICIPANT	\N	PRESENT	0
287399	284611	19715Y	PARTICIPANT	\N	PRESENT	0
287400	284611	19683J	PARTICIPANT	\N	PRESENT	0
287401	284611	19723Y	PARTICIPANT	\N	PRESENT	0
287402	284611	19697Q	PARTICIPANT	\N	PRESENT	0
287403	284611	17779H	PARTICIPANT	\N	PRESENT	0
287404	284611	11067R	PARTICIPANT	\N	PRESENT	0
287405	284611	14223L	PARTICIPANT	\N	PRESENT	0
287406	284611	04092N	PRESIDENT	0	PRESENT	0
287407	284611	14119M	PARTICIPANT	\N	PRESENT	0
287408	284611	14071N	PARTICIPANT	\N	PRESENT	0
287409	284611	19679N	PARTICIPANT	\N	PRESENT	0
287410	284611	11045K	PARTICIPANT	\N	PRESENT	0
287411	284611	11097X	PARTICIPANT	\N	PRESENT	0
287412	284611	04045F	PARTICIPANT	\N	PRESENT	0
287413	284611	19703U	PARTICIPANT	\N	PRESENT	0
287414	284611	14227Q	PARTICIPANT	\N	PRESENT	0
287415	284611	01034P	PARTICIPANT	\N	PRESENT	0
287416	284611	19527W	PARTICIPANT	\N	PRESENT	0
287417	284611	11063M	PARTICIPANT	\N	PRESENT	0
287696	287695	08039A	PARTICIPANT	\N	PRESENT	0
288465	288461	04057K	PARTICIPANT	\N	PRESENT	0
288469	288461	04088S	PARTICIPANT	\N	PRESENT	0
288607	288606	14133K	PARTICIPANT	\N	PRESENT	0
288608	288606	14065Q	PARTICIPANT	\N	PRESENT	0
288609	288606	96004D	PRESIDENT	0	PRESENT	0
288610	288606	14089Y	PARTICIPANT	\N	PRESENT	0
288611	288606	14079W	PARTICIPANT	\N	PRESENT	0
288612	288606	11083R	PARTICIPANT	\N	PRESENT	0
288613	288606	14033T	PARTICIPANT	\N	PRESENT	0
288615	288606	19725B	PARTICIPANT	\N	PRESENT	0
288616	288606	95037J	PARTICIPANT	\N	PRESENT	0
288617	288606	19569H	PARTICIPANT	\N	PRESENT	0
288618	288606	04097T	PARTICIPANT	\N	PRESENT	0
288619	288606	14061L	PARTICIPANT	\N	PRESENT	0
288620	288606	14073Q	PARTICIPANT	\N	PRESENT	0
288621	288606	14001X	PARTICIPANT	\N	PRESENT	0
288622	288606	14221J	PARTICIPANT	\N	PRESENT	0
288623	288606	04057K	PARTICIPANT	\N	EXCUSE	0
288624	288606	19563B	PARTICIPANT	\N	PRESENT	0
288625	288606	08073C	PARTICIPANT	\N	PRESENT	0
288626	288606	14237S	PARTICIPANT	\N	PRESENT	0
288627	288606	14135M	PARTICIPANT	\N	PRESENT	0
288628	288606	10015M	PARTICIPANT	\N	PRESENT	0
288629	288606	14229S	PARTICIPANT	\N	PRESENT	0
288630	288606	14357A	PARTICIPANT	\N	EXCUSE	0
288647	288606	08009T	PARTICIPANT	\N	PRESENT	0
288652	288606	19551W	PARTICIPANT	\N	PRESENT	0
288653	288606	14051J	PARTICIPANT	\N	PRESENT	0
288656	288606	19739H	PARTICIPANT	\N	PRESENT	0
288659	288606	19503N	PARTICIPANT	\N	PRESENT	0
288660	288606	05012A	PARTICIPANT	\N	PRESENT	0
288661	288606	19745F	PARTICIPANT	\N	PRESENT	0
288662	288606	14169X	PARTICIPANT	\N	PRESENT	0
288665	288606	14103D	PARTICIPANT	\N	PRESENT	0
288667	288606	14219Q	PARTICIPANT	\N	PRESENT	0
288674	288606	19289C	PARTICIPANT	\N	PRESENT	0
288676	288606	19333N	PARTICIPANT	\N	PRESENT	0
288677	288606	19347U	PARTICIPANT	\N	PRESENT	0
288678	288606	19387D	PARTICIPANT	\N	PRESENT	0
288679	288606	15447F	PARTICIPANT	\N	PRESENT	0
288680	288606	19599P	PARTICIPANT	\N	PRESENT	0
288683	288606	18083K	PARTICIPANT	\N	PRESENT	0
288685	288606	08055A	PARTICIPANT	\N	PRESENT	0
288688	288606	14327T	PARTICIPANT	\N	PRESENT	0
288689	288606	19531S	PARTICIPANT	\N	PRESENT	0
288690	288606	14121F	PARTICIPANT	\N	PRESENT	0
288692	286125	14211G	PARTICIPANT	\N	PRESENT	0
289783	289755	08058D	PARTICIPANT	\N	PRESENT	0
289784	289755	11049P	PARTICIPANT	\N	PRESENT	0
289786	289785	08058D	PRESIDENT	0	PRESENT	0
289787	289785	04071H	PARTICIPANT	\N	PRESENT	0
289788	289785	11049P	PARTICIPANT	\N	PRESENT	0
292899	292898	08024S	PARTICIPANT	\N	EXCUSE	0
292900	292898	99004R	PRESIDENT	0	PRESENT	0
292901	292898	19737F	PARTICIPANT	\N	PRESENT	0
292902	292898	19711U	PARTICIPANT	\N	EXCUSE	0
292903	292898	08012N	PARTICIPANT	\N	PRESENT	0
292904	292898	19551W	PARTICIPANT	\N	EXCUSE	0
292905	292898	19479G	PARTICIPANT	\N	PRESENT	0
292906	292898	11097X	PARTICIPANT	\N	EXCUSE	0
292907	292898	19421M	PARTICIPANT	\N	EXCUSE	0
292908	292898	08062Y	PARTICIPANT	\N	EXCUSE	0
292909	292898	11066Q	PARTICIPANT	\N	PRESENT	0
292915	292914	19667J	PARTICIPANT	\N	PRESENT	0
292916	292914	11040E	PARTICIPANT	\N	PRESENT	0
292918	292917	08034U	PARTICIPANT	\N	PRESENT	0
292929	292920	04086Q	PARTICIPANT	\N	PRESENT	0
293065	292510	14259Y	PARTICIPANT	\N	EXCUSE	0
293254	292898	19651A	PARTICIPANT	\N	EXCUSE	0
293255	292898	04061F	PARTICIPANT	\N	EXCUSE	0
293256	292898	19713W	PARTICIPANT	\N	PRESENT	0
293258	293257	08034U	PARTICIPANT	\N	PRESENT	0
293260	293259	19545Y	PARTICIPANT	\N	PRESENT	0
293264	293263	14133K	PARTICIPANT	\N	PRESENT	0
293265	293263	19741B	PARTICIPANT	\N	PRESENT	0
293266	293263	08043V	PARTICIPANT	\N	EXCUSE	0
293267	293263	04038G	PARTICIPANT	\N	PRESENT	0
293268	293263	19253P	PARTICIPANT	\N	EXCUSE	0
293269	293263	14357A	PARTICIPANT	\N	EXCUSE	0
293270	293263	11070L	PRESIDENT	0	PRESENT	0
293271	293263	04097T	PARTICIPANT	\N	PRESENT	0
293272	293263	19711U	PARTICIPANT	\N	PRESENT	0
293273	293263	12016W	PARTICIPANT	\N	PRESENT	0
293274	293263	19533U	PARTICIPANT	\N	PRESENT	0
293275	293263	17637T	PARTICIPANT	\N	EXCUSE	0
293276	293263	08021P	PARTICIPANT	\N	EXCUSE	0
293277	293263	19531S	PARTICIPANT	\N	EXCUSE	0
293278	293263	14267Y	PARTICIPANT	\N	EXCUSE	0
293279	292937	14133K	PARTICIPANT	\N	PRESENT	0
293280	292937	04038G	PARTICIPANT	\N	PRESENT	0
293281	292937	19253P	PARTICIPANT	\N	PRESENT	0
293282	292937	14357A	PARTICIPANT	\N	EXCUSE	0
293283	292937	11070L	PARTICIPANT	\N	PRESENT	0
290121	289756	19643A	PARTICIPANT	\N	PRESENT	0
290118	289756	19693L	PARTICIPANT	\N	PRESENT	0
290124	289756	04018C	PARTICIPANT	\N	PRESENT	0
290126	289756	11063M	PARTICIPANT	\N	PRESENT	0
290122	289756	11115U	PARTICIPANT	\N	PRESENT	0
290125	289756	04035D	PARTICIPANT	\N	PRESENT	0
290128	289756	19735D	PARTICIPANT	\N	PRESENT	0
290129	289756	08073C	PARTICIPANT	\N	PRESENT	0
290130	289756	14053L	PARTICIPANT	\N	PRESENT	0
290131	289756	19621T	PARTICIPANT	\N	PRESENT	0
290132	289756	95030B	PARTICIPANT	\N	PRESENT	0
290133	289756	14251Q	PARTICIPANT	\N	PRESENT	0
290134	289756	19443T	PARTICIPANT	\N	PRESENT	0
290138	289756	11053K	PARTICIPANT	\N	PRESENT	0
290136	289756	04061F	PARTICIPANT	\N	PRESENT	0
290137	289756	14123H	PARTICIPANT	\N	PRESENT	0
290139	289756	19531S	PARTICIPANT	\N	PRESENT	0
290140	289756	14034U	PARTICIPANT	\N	PRESENT	0
290141	289756	14073Q	PARTICIPANT	\N	PRESENT	0
290142	289756	02002K	PARTICIPANT	\N	PRESENT	0
290143	289756	14327T	PARTICIPANT	\N	PRESENT	0
290144	289756	04097T	PARTICIPANT	\N	PRESENT	0
290146	289756	11031D	PARTICIPANT	\N	PRESENT	0
290148	289756	14179A	PARTICIPANT	\N	PRESENT	0
290149	289756	14071N	PARTICIPANT	\N	PRESENT	0
290150	289756	04089T	PARTICIPANT	\N	PRESENT	0
290151	289756	19713W	PARTICIPANT	\N	PRESENT	0
290152	289756	19593H	PARTICIPANT	\N	PRESENT	0
290153	289756	19251M	PARTICIPANT	\N	PRESENT	0
290154	289756	08009T	PARTICIPANT	\N	PRESENT	0
290155	289756	17589D	PARTICIPANT	\N	PRESENT	0
290458	273921	86034E	PARTICIPANT	\N	PRESENT	0
290459	273921	11033F	PARTICIPANT	\N	PRESENT	0
290460	273921	19347U	PARTICIPANT	\N	PRESENT	0
290461	273921	19758L	PARTICIPANT	\N	PRESENT	0
290462	273921	11040E	PARTICIPANT	\N	PRESENT	0
290463	273921	19593H	PARTICIPANT	\N	PRESENT	0
290464	273921	14235Q	PARTICIPANT	\N	PRESENT	0
290465	273921	14055N	PARTICIPANT	\N	PRESENT	0
290466	273921	19637C	PARTICIPANT	\N	PRESENT	0
290467	273921	19563B	PARTICIPANT	\N	PRESENT	0
290468	273921	19387D	PARTICIPANT	\N	PRESENT	0
290469	273921	19681G	PARTICIPANT	\N	PRESENT	0
290470	273921	19329S	PARTICIPANT	\N	PRESENT	0
290471	273921	19301E	PARTICIPANT	\N	PRESENT	0
290472	273921	19719D	PARTICIPANT	\N	PRESENT	0
290473	273921	19553Y	PARTICIPANT	\N	PRESENT	0
290474	273921	17589D	PARTICIPANT	\N	PRESENT	0
290475	273921	14195A	PARTICIPANT	\N	PRESENT	0
290476	273921	14093U	PARTICIPANT	\N	PRESENT	0
290477	273921	14197C	PARTICIPANT	\N	PRESENT	0
290478	273921	19599P	PARTICIPANT	\N	PRESENT	0
290479	273921	11109J	PARTICIPANT	\N	PRESENT	0
290480	273921	14121F	PARTICIPANT	\N	PRESENT	0
290481	273921	14227Q	PARTICIPANT	\N	PRESENT	0
290482	273921	19727D	PARTICIPANT	\N	PRESENT	0
290483	273921	11067R	PARTICIPANT	\N	PRESENT	0
290484	273921	19591F	PARTICIPANT	\N	PRESENT	0
290485	273921	19669L	PARTICIPANT	\N	PRESENT	0
293140	293139	04086Q	PARTICIPANT	\N	PRESENT	0
290487	273921	14281W	PARTICIPANT	\N	PRESENT	0
290488	273921	14229S	PARTICIPANT	\N	PRESENT	0
290489	273921	14081Q	PARTICIPANT	\N	PRESENT	0
290490	273921	14063N	PARTICIPANT	\N	PRESENT	0
290491	273921	17637T	PARTICIPANT	\N	PRESENT	0
290493	273921	19715Y	PARTICIPANT	\N	PRESENT	0
290494	273921	80013X	PARTICIPANT	\N	PRESENT	0
290495	273921	12016W	PARTICIPANT	\N	PRESENT	0
290496	273921	08052W	PARTICIPANT	\N	PRESENT	0
290497	273921	14051J	PARTICIPANT	\N	PRESENT	0
290498	273921	08060W	PARTICIPANT	\N	PRESENT	0
290499	273921	14109K	PARTICIPANT	\N	PRESENT	0
290500	273921	14097Y	PARTICIPANT	\N	PRESENT	0
290501	273921	19565D	PARTICIPANT	\N	PRESENT	0
290502	273921	19413M	PARTICIPANT	\N	PRESENT	0
290504	273921	19333N	PARTICIPANT	\N	PRESENT	0
290505	273921	19527W	PARTICIPANT	\N	PRESENT	0
290506	273921	14257W	PARTICIPANT	\N	PRESENT	0
290507	273921	19489J	PARTICIPANT	\N	PRESENT	0
290508	273921	19647E	PARTICIPANT	\N	PRESENT	0
290509	273921	19619A	PARTICIPANT	\N	PRESENT	0
290510	273921	19441R	PARTICIPANT	\N	PRESENT	0
290511	273921	19479G	PARTICIPANT	\N	PRESENT	0
290512	273921	14042U	PARTICIPANT	\N	PRESENT	0
290513	273921	14219Q	PARTICIPANT	\N	PRESENT	0
290514	273921	14275Y	PARTICIPANT	\N	PRESENT	0
290515	273921	19713W	PARTICIPANT	\N	PRESENT	0
290516	273921	14255U	PARTICIPANT	\N	PRESENT	0
290519	273921	96004D	PARTICIPANT	\N	PRESENT	0
290520	273921	04097T	PARTICIPANT	\N	PRESENT	0
290521	273921	08020N	PARTICIPANT	\N	PRESENT	0
290522	273921	08010L	PARTICIPANT	\N	PRESENT	0
290523	273921	95030B	PARTICIPANT	\N	PRESENT	0
290524	273921	11010L	PARTICIPANT	\N	PRESENT	0
290525	273921	19515S	PARTICIPANT	\N	PRESENT	0
290526	273921	19673G	PARTICIPANT	\N	PRESENT	0
290527	273921	14135M	PARTICIPANT	\N	PRESENT	0
290528	273921	99004R	PARTICIPANT	\N	PRESENT	0
290529	273921	08039A	PARTICIPANT	\N	PRESENT	0
290530	273921	19679N	PARTICIPANT	\N	PRESENT	0
290531	273921	18083K	PARTICIPANT	\N	PRESENT	0
290532	273921	11031D	PARTICIPANT	\N	PRESENT	0
290533	273921	04092N	PARTICIPANT	\N	PRESENT	0
290534	273921	04038G	PARTICIPANT	\N	PRESENT	0
290539	273921	04071H	PARTICIPANT	\N	PRESENT	0
290541	273921	15447F	PARTICIPANT	\N	PRESENT	0
290542	273921	01058X	PARTICIPANT	\N	PRESENT	0
290543	273921	12041X	PARTICIPANT	\N	PRESENT	0
290546	273921	08028W	PARTICIPANT	\N	PRESENT	0
290547	273921	10015M	PARTICIPANT	\N	PRESENT	0
290548	273921	11043H	PARTICIPANT	\N	PRESENT	0
290549	273921	01028R	PARTICIPANT	\N	PRESENT	0
290550	273921	08069G	PARTICIPANT	\N	PRESENT	0
290551	273921	04085P	PARTICIPANT	\N	PRESENT	0
290552	273921	14259Y	PARTICIPANT	\N	PRESENT	0
290553	273921	11056N	PARTICIPANT	\N	PRESENT	0
290554	273921	14123H	PARTICIPANT	\N	PRESENT	0
290555	273921	19695N	PARTICIPANT	\N	PRESENT	0
290556	273921	14223L	PARTICIPANT	\N	PRESENT	0
290558	273921	14191V	PARTICIPANT	\N	PRESENT	0
290559	273921	19703U	PARTICIPANT	\N	PRESENT	0
290560	273921	14239U	PARTICIPANT	\N	PRESENT	0
290561	273921	19651A	PARTICIPANT	\N	PRESENT	0
290562	273921	11115U	PARTICIPANT	\N	PRESENT	0
290563	273921	19349W	PARTICIPANT	\N	PRESENT	0
293135	293134	19673G	PARTICIPANT	\N	PRESENT	0
293138	293137	99004R	PARTICIPANT	\N	PRESENT	0
293142	293141	04086Q	PARTICIPANT	\N	PRESENT	0
299877	298800	14215L	PARTICIPANT	\N	PRESENT	0
299878	298800	08018U	PARTICIPANT	\N	PRESENT	0
299879	298800	11072N	PARTICIPANT	\N	PRESENT	0
299880	298800	14053L	PARTICIPANT	\N	PRESENT	0
299881	298800	14111D	PARTICIPANT	\N	PRESENT	0
299882	298800	10015M	PARTICIPANT	\N	PRESENT	0
299883	298800	19253P	PARTICIPANT	\N	PRESENT	0
299884	298800	01024M	PARTICIPANT	\N	PRESENT	0
299885	298800	19725B	PARTICIPANT	\N	PRESENT	0
299886	298800	14089Y	PARTICIPANT	\N	PRESENT	0
299887	298800	19729F	PARTICIPANT	\N	PRESENT	0
299888	298800	19629C	PARTICIPANT	\N	PRESENT	0
299889	298800	14069U	PARTICIPANT	\N	PRESENT	0
299890	298800	11085T	PARTICIPANT	\N	PRESENT	0
299891	298800	11049P	PARTICIPANT	\N	PRESENT	0
299892	298800	19762G	PARTICIPANT	\N	PRESENT	0
299893	298800	98035U	PARTICIPANT	\N	PRESENT	0
299894	298800	19489J	PARTICIPANT	\N	PRESENT	0
299895	298800	19649G	PARTICIPANT	\N	PRESENT	0
299896	298800	07034Q	PARTICIPANT	\N	PRESENT	0
299897	298800	08045X	PARTICIPANT	\N	PRESENT	0
299898	298800	14147R	PARTICIPANT	\N	PRESENT	0
299899	298800	14259Y	PARTICIPANT	\N	PRESENT	0
299900	298800	19673G	PARTICIPANT	\N	PRESENT	0
299901	298800	11033F	PARTICIPANT	\N	PRESENT	0
299902	298800	14021P	PARTICIPANT	\N	PRESENT	0
299903	298800	14231L	PARTICIPANT	\N	PRESENT	0
299904	298800	14065Q	PARTICIPANT	\N	EXCUSE	0
299905	298800	04047H	PARTICIPANT	\N	EXCUSE	0
299906	298800	04008A	PARTICIPANT	\N	EXCUSE	0
299911	299910	14249W	PARTICIPANT	\N	PRESENT	0
299912	299910	95067Q	PARTICIPANT	\N	PRESENT	0
299913	299910	14073Q	PARTICIPANT	\N	PRESENT	0
299914	299910	19647E	PARTICIPANT	\N	PRESENT	0
300033	300025	19647E	PARTICIPANT	\N	PRESENT	0
300034	300025	11070L	PARTICIPANT	\N	PRESENT	0
300105	297575	19503N	PARTICIPANT	\N	PRESENT	0
300106	298186	19503N	PARTICIPANT	\N	PRESENT	0
300107	298504	19503N	PARTICIPANT	\N	PRESENT	0
300108	295875	19551W	PARTICIPANT	\N	PRESENT	0
300109	295875	19737F	PARTICIPANT	\N	PRESENT	0
272044	270440	01057W	PARTICIPANT	\N	PRESENT	0
273458	271231	19735D	PARTICIPANT	\N	EXCUSE	0
274005	273667	19631V	PARTICIPANT	\N	EXCUSE	0
274006	273668	19631V	PARTICIPANT	\N	EXCUSE	0
278437	278102	14231L	PARTICIPANT	\N	EXCUSE	0
278442	268444	01058X	PARTICIPANT	\N	EXCUSE	0
279283	279282	14259Y	PARTICIPANT	\N	PRESENT	0
279284	279282	14001X	PARTICIPANT	\N	PRESENT	0
279286	279285	14259Y	PARTICIPANT	\N	PRESENT	0
279287	279285	14001X	PARTICIPANT	\N	PRESENT	0
281657	273881	19657G	PARTICIPANT	\N	PRESENT	0
281658	273881	04033B	PARTICIPANT	\N	PRESENT	0
281659	273881	14215L	PARTICIPANT	\N	PRESENT	0
281660	273881	08015R	PARTICIPANT	\N	PRESENT	0
281661	273881	14213J	PARTICIPANT	\N	PRESENT	0
281662	273881	14026U	PARTICIPANT	\N	PRESENT	0
281663	273881	14217N	PARTICIPANT	\N	PRESENT	0
281664	273881	14030Q	PARTICIPANT	\N	PRESENT	0
281665	273881	14073Q	PARTICIPANT	\N	PRESENT	0
281666	273881	14219Q	PARTICIPANT	\N	PRESENT	0
281667	273881	11097X	PARTICIPANT	\N	PRESENT	0
281668	273881	19369B	PARTICIPANT	\N	PRESENT	0
281669	273881	19447X	PARTICIPANT	\N	PRESENT	0
281670	273881	14061L	PARTICIPANT	\N	PRESENT	0
281671	273881	19387D	PARTICIPANT	\N	PRESENT	0
281672	273881	04049K	PARTICIPANT	\N	PRESENT	0
281673	273881	14249W	PARTICIPANT	\N	PRESENT	0
281674	273881	10006L	PARTICIPANT	\N	PRESENT	0
281675	273881	89017R	PARTICIPANT	\N	PRESENT	0
281676	273881	19479G	PARTICIPANT	\N	PRESENT	0
281677	273881	14187A	PARTICIPANT	\N	PRESENT	0
282026	282023	14193X	PARTICIPANT	\N	PRESENT	0
282028	282023	08053X	PARTICIPANT	\N	PRESENT	0
282031	282023	14235Q	PARTICIPANT	\N	PRESENT	0
281655	273881	01057W	PARTICIPANT	\N	PRESENT	0
281656	273881	07029T	PARTICIPANT	\N	PRESENT	0
282033	282023	95067Q	PARTICIPANT	\N	PRESENT	0
282042	282040	14193X	PARTICIPANT	\N	PRESENT	0
282044	282040	08053X	PARTICIPANT	\N	PRESENT	0
282046	282040	95067Q	PARTICIPANT	\N	PRESENT	0
282056	282053	14255U	PARTICIPANT	\N	PRESENT	0
282057	282053	08053X	PARTICIPANT	\N	PRESENT	0
282298	273985	04043D	PARTICIPANT	\N	PRESENT	0
282491	282490	19333N	PARTICIPANT	\N	PRESENT	0
282492	282490	14031R	PARTICIPANT	\N	PRESENT	0
282493	282490	19713W	PARTICIPANT	\N	PRESENT	0
282494	282490	14221J	PARTICIPANT	\N	PRESENT	0
282495	282490	14169X	PARTICIPANT	\N	PRESENT	0
282496	282490	18083K	PARTICIPANT	\N	PRESENT	0
282497	282490	14093U	PARTICIPANT	\N	PRESENT	0
282498	282490	14029X	PARTICIPANT	\N	PRESENT	0
282499	282490	14051J	PARTICIPANT	\N	PRESENT	0
282500	282490	08060W	PARTICIPANT	\N	PRESENT	0
282501	282490	19733B	PARTICIPANT	\N	PRESENT	0
282502	282490	08009T	PRESIDENT	0	PRESENT	0
282503	282490	96004D	PARTICIPANT	\N	PRESENT	0
282504	282490	19503N	PARTICIPANT	\N	PRESENT	0
282505	282490	19739H	PARTICIPANT	\N	PRESENT	0
282506	282490	98023Q	PARTICIPANT	\N	PRESENT	0
282507	282490	19525U	PARTICIPANT	\N	PRESENT	0
282509	282490	14237S	PARTICIPANT	\N	PRESENT	0
282510	282490	15447F	PARTICIPANT	\N	PRESENT	0
282511	282490	19549D	PARTICIPANT	\N	PRESENT	0
282512	282490	19637C	PARTICIPANT	\N	PRESENT	0
282513	282490	11065P	PARTICIPANT	\N	PRESENT	0
282514	282490	19681G	PARTICIPANT	\N	PRESENT	0
282515	282490	17637T	PARTICIPANT	\N	PRESENT	0
282516	282490	14038Y	PARTICIPANT	\N	PRESENT	0
282517	282490	19387D	PARTICIPANT	\N	PRESENT	0
282518	282490	14157T	PARTICIPANT	\N	PRESENT	0
282519	282490	95062K	PARTICIPANT	\N	PRESENT	0
282520	282490	08055A	PARTICIPANT	\N	PRESENT	0
282521	282490	02002K	PARTICIPANT	\N	PRESENT	0
282694	282657	19515S	PARTICIPANT	\N	PRESENT	0
282695	282657	19565D	PARTICIPANT	\N	PRESENT	0
282696	282657	14357A	PARTICIPANT	\N	PRESENT	0
282697	282657	19441R	PARTICIPANT	\N	PRESENT	0
282698	282657	14081Q	PARTICIPANT	\N	PRESENT	0
282699	282657	19413M	PARTICIPANT	\N	PRESENT	0
282700	282657	80013X	PARTICIPANT	\N	PRESENT	0
282701	282657	19631V	PARTICIPANT	\N	PRESENT	0
282702	282657	11099A	PARTICIPANT	\N	PRESENT	0
282703	282657	08068F	PARTICIPANT	\N	PRESENT	0
282704	282657	04049K	PARTICIPANT	\N	PRESENT	0
282705	282657	19705W	PARTICIPANT	\N	PRESENT	0
282706	282657	19707Y	PARTICIPANT	\N	PRESENT	0
282707	282657	08015R	PARTICIPANT	\N	PRESENT	0
282708	282657	14197C	PARTICIPANT	\N	PRESENT	0
282709	282657	19369B	PARTICIPANT	\N	PRESENT	0
282710	282657	19511N	PARTICIPANT	\N	PRESENT	0
282711	282657	08028W	PARTICIPANT	\N	PRESENT	0
282712	282657	19563B	PARTICIPANT	\N	PRESENT	0
282713	282657	14265W	PARTICIPANT	\N	PRESENT	0
282714	282657	14329V	PARTICIPANT	\N	PRESENT	0
282715	282657	19591F	PARTICIPANT	\N	PRESENT	0
282716	282657	14135M	PARTICIPANT	\N	PRESENT	0
282717	282657	19467C	PARTICIPANT	\N	PRESENT	0
282718	282657	14187A	PARTICIPANT	\N	PRESENT	0
282719	282657	08062Y	PARTICIPANT	\N	PRESENT	0
282720	282657	14033T	PARTICIPANT	\N	PRESENT	0
282721	282657	11090Q	PRESIDENT	0	PRESENT	0
282722	282657	01025N	PARTICIPANT	\N	PRESENT	0
282723	282657	19269X	PARTICIPANT	\N	PRESENT	0
282724	282657	14205J	PARTICIPANT	\N	PRESENT	0
282725	282657	04088S	PARTICIPANT	\N	PRESENT	0
282726	282657	11056N	PARTICIPANT	\N	PRESENT	0
282727	282657	14115H	PARTICIPANT	\N	PRESENT	0
282728	282657	19507S	PARTICIPANT	\N	PRESENT	0
282729	282657	14207L	PARTICIPANT	\N	PRESENT	0
282730	282657	19747H	PARTICIPANT	\N	PRESENT	0
282731	282657	04043D	PARTICIPANT	\N	PRESENT	0
282732	282657	17589D	PARTICIPANT	\N	PRESENT	0
282733	282657	14257W	PARTICIPANT	\N	PRESENT	0
282734	282657	04089T	PARTICIPANT	\N	EXCUSE	0
282735	282657	11081P	PARTICIPANT	\N	EXCUSE	0
282736	273890	95030B	PARTICIPANT	\N	PRESENT	0
282737	273890	11103C	PARTICIPANT	\N	PRESENT	0
282740	273890	14227Q	PARTICIPANT	\N	PRESENT	0
282741	273890	95062K	PARTICIPANT	\N	PRESENT	0
282742	273890	08069G	PARTICIPANT	\N	PRESENT	0
282743	273890	14237S	PARTICIPANT	\N	PRESENT	0
282744	273890	11083R	PARTICIPANT	\N	PRESENT	0
282745	273890	19549D	PARTICIPANT	\N	PRESENT	0
282746	273890	87003B	PARTICIPANT	\N	PRESENT	0
282747	273890	19673G	PARTICIPANT	\N	PRESENT	0
282748	273890	14026U	PARTICIPANT	\N	PRESENT	0
282749	273890	17637T	PARTICIPANT	\N	PRESENT	0
282750	273890	19573D	PARTICIPANT	\N	PRESENT	0
282751	273890	08017T	PARTICIPANT	\N	PRESENT	0
282852	273894	04044E	PARTICIPANT	\N	PRESENT	0
282853	273894	05008E	PARTICIPANT	\N	PRESENT	0
282854	273894	14169X	PARTICIPANT	\N	PRESENT	0
282855	273894	14259Y	PARTICIPANT	\N	PRESENT	0
282856	273894	04038G	PARTICIPANT	\N	PRESENT	0
282857	273894	19715Y	PARTICIPANT	\N	PRESENT	0
282858	273894	08045X	PARTICIPANT	\N	PRESENT	0
282859	273894	11066Q	PARTICIPANT	\N	PRESENT	0
282860	273894	11056N	PARTICIPANT	\N	PRESENT	0
282861	273894	19758L	PARTICIPANT	\N	PRESENT	0
282862	273894	11040E	PARTICIPANT	\N	PRESENT	0
282863	273894	14121F	PARTICIPANT	\N	PRESENT	0
282864	273894	14227Q	PARTICIPANT	\N	PRESENT	0
282865	273894	19503N	PARTICIPANT	\N	PRESENT	0
282866	273894	19251M	PARTICIPANT	\N	PRESENT	0
282867	273894	19489J	PARTICIPANT	\N	PRESENT	0
282868	273894	14001X	PARTICIPANT	\N	PRESENT	0
282869	273894	19549D	PARTICIPANT	\N	PRESENT	0
282870	273894	14107H	PARTICIPANT	\N	PRESENT	0
282871	273894	14225N	PARTICIPANT	\N	PRESENT	0
282872	273894	19329S	PARTICIPANT	\N	PRESENT	0
282873	273894	19349W	PARTICIPANT	\N	PRESENT	0
282874	273894	08016S	PARTICIPANT	\N	PRESENT	0
282875	273894	14241N	PARTICIPANT	\N	PRESENT	0
282876	273894	88008L	PARTICIPANT	\N	PRESENT	0
282877	273894	19387D	PARTICIPANT	\N	PRESENT	0
282878	273894	19545Y	PARTICIPANT	\N	PRESENT	0
282879	273894	19717B	PARTICIPANT	\N	PRESENT	0
282880	273894	08031R	PARTICIPANT	\N	PRESENT	0
282881	273894	19583F	PARTICIPANT	\N	PRESENT	0
282882	273894	14195A	PARTICIPANT	\N	PRESENT	0
282883	273894	19479G	PARTICIPANT	\N	PRESENT	0
282884	273894	14042U	PARTICIPANT	\N	PRESENT	0
282885	273894	14237S	PARTICIPANT	\N	PRESENT	0
282886	273894	14267Y	PARTICIPANT	\N	PRESENT	0
282887	273894	01024M	PARTICIPANT	\N	PRESENT	0
282888	273894	08056B	PARTICIPANT	\N	PRESENT	0
282889	273894	19253P	PARTICIPANT	\N	PRESENT	0
282890	273894	19629C	PARTICIPANT	\N	PRESENT	0
282891	273894	19671E	PARTICIPANT	\N	PRESENT	0
282295	282294	96004D	PARTICIPANT	\N	PRESENT	0
282296	282294	11026G	PARTICIPANT	\N	PRESENT	0
282297	282294	10015M	PARTICIPANT	\N	PRESENT	0
285585	273902	19575F	PARTICIPANT	\N	PRESENT	0
285586	273902	19735D	PARTICIPANT	\N	PRESENT	0
285587	273902	80013X	PARTICIPANT	\N	PRESENT	0
285588	273902	14081Q	PARTICIPANT	\N	PRESENT	0
285611	273902	11067R	PARTICIPANT	\N	PRESENT	0
285618	273902	19693L	PARTICIPANT	\N	PRESENT	0
285621	273902	19749K	PARTICIPANT	\N	PRESENT	0
285625	273902	19253P	PARTICIPANT	\N	PRESENT	0
285626	273902	98029W	PARTICIPANT	\N	PRESENT	0
285627	273902	99004R	PARTICIPANT	\N	PRESENT	0
285628	273902	14147R	PARTICIPANT	\N	PRESENT	0
285629	273902	14065Q	PARTICIPANT	\N	PRESENT	0
285633	273902	04071H	PARTICIPANT	\N	PRESENT	0
285636	273902	19643A	PARTICIPANT	\N	PRESENT	0
285648	273902	19667J	PARTICIPANT	\N	PRESENT	0
285654	273902	08010L	PARTICIPANT	\N	PRESENT	0
285655	273902	14042U	PARTICIPANT	\N	PRESENT	0
285660	273902	07004J	PARTICIPANT	\N	PRESENT	0
285661	273902	19637C	PARTICIPANT	\N	PRESENT	0
285662	273902	11054L	PARTICIPANT	\N	PRESENT	0
285663	273902	01057W	PARTICIPANT	\N	PRESENT	0
285664	273902	14327T	PARTICIPANT	\N	PRESENT	0
285665	273902	04086Q	PARTICIPANT	\N	PRESENT	0
285666	273902	19565D	PARTICIPANT	\N	PRESENT	0
285667	273902	19251M	PARTICIPANT	\N	PRESENT	0
285668	273902	19591F	PARTICIPANT	\N	PRESENT	0
285669	273902	14021P	PARTICIPANT	\N	PRESENT	0
285670	273902	19725B	PARTICIPANT	\N	PRESENT	0
285671	273902	14195A	PARTICIPANT	\N	PRESENT	0
285776	285674	19369B	PARTICIPANT	\N	PRESENT	0
285777	285674	08039A	PARTICIPANT	\N	PRESENT	0
285778	285674	19667J	PARTICIPANT	\N	PRESENT	0
285779	285674	01028R	PARTICIPANT	\N	PRESENT	0
285780	285674	08068F	PARTICIPANT	\N	PRESENT	0
285781	285674	19301E	PARTICIPANT	\N	PRESENT	0
285782	285674	19651A	PARTICIPANT	\N	PRESENT	0
285783	285674	19549D	PARTICIPANT	\N	PRESENT	0
285784	285674	80013X	PARTICIPANT	\N	PRESENT	0
285785	285674	19527W	PARTICIPANT	\N	PRESENT	0
285786	285674	19503N	PARTICIPANT	\N	PRESENT	0
285787	285674	19295A	PARTICIPANT	\N	PRESENT	0
285788	285674	11109J	PARTICIPANT	\N	PRESENT	0
285789	285674	11067R	PARTICIPANT	\N	PRESENT	0
285790	285674	19551W	PARTICIPANT	\N	PRESENT	0
285791	285674	19531S	PARTICIPANT	\N	PRESENT	0
285792	285674	04057K	PARTICIPANT	\N	PRESENT	0
285793	285674	14195A	PARTICIPANT	\N	PRESENT	0
285794	285674	02002K	PARTICIPANT	\N	PRESENT	0
285795	285674	19583F	PARTICIPANT	\N	PRESENT	0
285796	285674	11099A	PARTICIPANT	\N	PRESENT	0
285797	285674	19553Y	PARTICIPANT	\N	PRESENT	0
285798	285674	19387D	PARTICIPANT	\N	PRESENT	0
285799	285674	19713W	PARTICIPANT	\N	PRESENT	0
285800	285674	19749K	PARTICIPANT	\N	PRESENT	0
285801	285674	19739H	PARTICIPANT	\N	PRESENT	0
285802	285674	14327T	PARTICIPANT	\N	PRESENT	0
285803	285674	01025N	PARTICIPANT	\N	PRESENT	0
285804	285674	07004J	PARTICIPANT	\N	PRESENT	0
285805	285674	19747H	PARTICIPANT	\N	PRESENT	0
285806	285674	14215L	PARTICIPANT	\N	PRESENT	0
285807	285674	19621T	PARTICIPANT	\N	PRESENT	0
285808	285674	19731Y	PARTICIPANT	\N	PRESENT	0
285809	285674	19701S	PARTICIPANT	\N	PRESENT	0
285810	285674	07034Q	PARTICIPANT	\N	PRESENT	0
285811	285674	04086Q	PARTICIPANT	\N	PRESENT	0
285812	285674	19591F	PARTICIPANT	\N	PRESENT	0
285813	285674	19643A	PARTICIPANT	\N	PRESENT	0
285814	285674	01057W	PARTICIPANT	\N	PRESENT	0
285815	285674	14259Y	PARTICIPANT	\N	PRESENT	0
285816	285674	19693L	PARTICIPANT	\N	PRESENT	0
285817	285674	14157T	PARTICIPANT	\N	PRESENT	0
285818	285674	19447X	PARTICIPANT	\N	PRESENT	0
285819	285674	04088S	PARTICIPANT	\N	PRESENT	0
285820	285674	14041T	PARTICIPANT	\N	PRESENT	0
285821	285674	07029T	PARTICIPANT	\N	PRESENT	0
285822	285674	05012A	PARTICIPANT	\N	PRESENT	0
285823	285674	19711U	PARTICIPANT	\N	PRESENT	0
285824	285674	19575F	PARTICIPANT	\N	PRESENT	0
285825	285674	11090Q	PARTICIPANT	\N	PRESENT	0
285826	285674	04049K	PARTICIPANT	\N	PRESENT	0
285827	285674	14147R	PARTICIPANT	\N	PRESENT	0
285828	285674	04070G	PARTICIPANT	\N	PRESENT	0
285829	285674	19735D	PARTICIPANT	\N	PRESENT	0
285830	285674	19441R	PARTICIPANT	\N	PRESENT	0
285831	285674	11097X	PARTICIPANT	\N	PRESENT	0
285832	285674	14179A	PARTICIPANT	\N	PRESENT	0
285833	285674	01024M	PARTICIPANT	\N	PRESENT	0
285834	285674	14109K	PARTICIPANT	\N	PRESENT	0
285835	285674	11110B	PARTICIPANT	\N	PRESENT	0
285836	285674	08018U	PARTICIPANT	\N	PRESENT	0
285837	285674	14030Q	PARTICIPANT	\N	PRESENT	0
285909	273903	14065Q	PARTICIPANT	\N	PRESENT	0
285910	273903	14239U	PARTICIPANT	\N	PRESENT	0
285911	273903	19585H	PARTICIPANT	\N	PRESENT	0
285912	273903	19681G	PARTICIPANT	\N	PRESENT	0
285913	273903	11033F	PARTICIPANT	\N	PRESENT	0
285914	273903	19583F	PARTICIPANT	\N	PRESENT	0
285915	273903	19569H	PARTICIPANT	\N	PRESENT	0
285916	273903	19521Q	PARTICIPANT	\N	PRESENT	0
285917	273903	14121F	PARTICIPANT	\N	PRESENT	0
285918	273903	98050T	PARTICIPANT	\N	PRESENT	0
285919	273903	08031R	PARTICIPANT	\N	PRESENT	0
285920	273903	14249W	PARTICIPANT	\N	PRESENT	0
285921	273903	14041T	PARTICIPANT	\N	PRESENT	0
285922	273903	19673G	PARTICIPANT	\N	PRESENT	0
285923	273903	10015M	PARTICIPANT	\N	PRESENT	0
285924	273903	14030Q	PARTICIPANT	\N	PRESENT	0
285925	273903	14231L	PARTICIPANT	\N	PRESENT	0
285926	273903	19711U	PARTICIPANT	\N	PRESENT	0
285927	273903	19717B	PARTICIPANT	\N	PRESENT	0
285928	273903	19611R	PARTICIPANT	\N	PRESENT	0
285941	273903	19651A	PARTICIPANT	\N	PRESENT	0
285942	273903	19591F	PARTICIPANT	\N	PRESENT	0
285943	273903	01024M	PARTICIPANT	\N	PRESENT	0
285989	273903	19701S	PARTICIPANT	\N	PRESENT	0
285945	273903	14105F	PARTICIPANT	\N	PRESENT	0
285946	273903	19575F	PARTICIPANT	\N	PRESENT	0
285947	273903	08010L	PARTICIPANT	\N	PRESENT	0
285948	273903	07004J	PARTICIPANT	\N	PRESENT	0
285949	273903	11048N	PARTICIPANT	\N	PRESENT	0
285950	273903	05008E	PARTICIPANT	\N	PRESENT	0
285953	273903	14215L	PARTICIPANT	\N	PRESENT	0
285954	273903	11072N	PARTICIPANT	\N	PRESENT	0
285970	273903	14033T	PARTICIPANT	\N	PRESENT	0
285971	273903	04088S	PARTICIPANT	\N	PRESENT	0
285972	273903	19671E	PARTICIPANT	\N	PRESENT	0
285973	273903	19697Q	PARTICIPANT	\N	PRESENT	0
285974	273903	14034U	PARTICIPANT	\N	PRESENT	0
285774	285674	11077T	PARTICIPANT	\N	PRESENT	0
285775	285674	19565D	PARTICIPANT	\N	PRESENT	0
285975	273903	19657G	PARTICIPANT	\N	PRESENT	0
285976	273903	19399H	PARTICIPANT	\N	PRESENT	0
285977	273903	19667J	PARTICIPANT	\N	PRESENT	0
285988	273903	19713W	PARTICIPANT	\N	PRESENT	0
285990	273903	17637T	PARTICIPANT	\N	PRESENT	0
285991	273903	19447X	PARTICIPANT	\N	PRESENT	0
285993	273903	95062K	PARTICIPANT	\N	PRESENT	0
285995	273903	08034U	PARTICIPANT	\N	PRESENT	0
285996	273903	14357A	PARTICIPANT	\N	PRESENT	0
286000	273903	14147R	PARTICIPANT	\N	PRESENT	0
286019	273903	19643A	PARTICIPANT	\N	PRESENT	0
286023	273903	19749K	PARTICIPANT	\N	PRESENT	0
286029	273903	08018U	PARTICIPANT	\N	PRESENT	0
286030	273903	11012A	PARTICIPANT	\N	PRESENT	0
286031	273903	04086Q	PARTICIPANT	\N	PRESENT	0
286034	273903	19647E	PARTICIPANT	\N	PRESENT	0
286035	273903	07034Q	PARTICIPANT	\N	PRESENT	0
285905	273903	04044E	PARTICIPANT	\N	PRESENT	0
285908	273903	19593H	PARTICIPANT	\N	PRESENT	0
271925	271924	04040A	PARTICIPANT	\N	PRESENT	0
271926	271924	04038G	PARTICIPANT	\N	PRESENT	0
271927	271924	14199E	PARTICIPANT	\N	PRESENT	0
271928	271924	08056B	PARTICIPANT	\N	PRESENT	0
271929	271924	08069G	PARTICIPANT	\N	PRESENT	0
271930	271924	95041E	PARTICIPANT	\N	PRESENT	0
271931	271924	19349W	PARTICIPANT	\N	PRESENT	0
279798	279797	11109J	PARTICIPANT	\N	PRESENT	0
279799	279797	14195A	PARTICIPANT	\N	PRESENT	0
279800	279797	14079W	PARTICIPANT	\N	PRESENT	0
279801	279797	14327T	PARTICIPANT	\N	PRESENT	0
279802	279797	98024R	PARTICIPANT	\N	EXCUSE	0
279803	279797	08045X	PARTICIPANT	\N	PRESENT	0
279805	279797	19347U	PARTICIPANT	\N	PRESENT	0
279806	279797	95037J	PARTICIPANT	\N	PRESENT	0
279808	279797	14213J	PRESIDENT	0	PRESENT	0
279809	279797	11099A	PARTICIPANT	\N	PRESENT	0
279810	279797	04049K	PARTICIPANT	\N	EXCUSE	0
279811	279797	08015R	PARTICIPANT	\N	EXCUSE	0
279812	279797	19441R	PARTICIPANT	\N	PRESENT	0
279813	279797	19369B	PARTICIPANT	\N	PRESENT	0
279814	279797	14109K	PARTICIPANT	\N	PRESENT	0
279815	279797	14169X	PARTICIPANT	\N	PRESENT	0
279816	279797	08049C	PARTICIPANT	\N	PRESENT	0
284151	284150	11043H	PARTICIPANT	\N	PRESENT	0
284152	284150	87003B	PARTICIPANT	\N	PRESENT	0
284153	284150	19399H	PARTICIPANT	\N	PRESENT	0
284154	284150	14213J	PARTICIPANT	\N	PRESENT	0
284155	284150	14241N	PARTICIPANT	\N	PRESENT	0
284156	284150	14039A	PARTICIPANT	\N	PRESENT	0
284157	284150	19611R	PARTICIPANT	\N	PRESENT	0
284158	284150	19711U	PARTICIPANT	\N	PRESENT	0
284159	284150	08012N	PARTICIPANT	\N	PRESENT	0
284160	284150	14063N	PARTICIPANT	\N	PRESENT	0
284161	284150	19573D	PARTICIPANT	\N	PRESENT	0
284162	284150	14107H	PARTICIPANT	\N	PRESENT	0
284163	284150	19725B	PARTICIPANT	\N	PRESENT	0
284164	284150	14073Q	PARTICIPANT	\N	PRESENT	0
284166	284150	19349W	PARTICIPANT	\N	PRESENT	0
284167	284150	95015C	PARTICIPANT	\N	PRESENT	0
284168	284150	14081Q	PARTICIPANT	\N	PRESENT	0
284271	284270	14073Q	PARTICIPANT	\N	PRESENT	0
284272	284270	19731Y	PARTICIPANT	\N	PRESENT	0
284273	284270	01025N	PARTICIPANT	\N	PRESENT	0
284274	284270	14069U	PARTICIPANT	\N	PRESENT	0
284886	284822	19631V	PARTICIPANT	\N	PRESENT	0
284887	284822	19515S	PARTICIPANT	\N	PRESENT	0
284888	284822	19707Y	PARTICIPANT	\N	PRESENT	0
284945	276475	14281W	PARTICIPANT	\N	PRESENT	0
284890	284822	14115H	PARTICIPANT	\N	PRESENT	0
284891	284822	19747H	PARTICIPANT	\N	PRESENT	0
284948	276475	14087W	PARTICIPANT	\N	PRESENT	0
284893	284822	14207L	PARTICIPANT	\N	PRESENT	0
284951	276475	19521Q	PARTICIPANT	\N	PRESENT	0
285012	284991	19611R	PARTICIPANT	\N	PRESENT	0
285016	284973	19611R	PARTICIPANT	\N	PRESENT	0
284897	284822	19467C	PARTICIPANT	\N	PRESENT	0
293284	292937	04097T	PARTICIPANT	\N	PRESENT	0
284899	284822	80013X	PARTICIPANT	\N	PRESENT	0
293285	292937	19711U	PARTICIPANT	\N	PRESENT	0
284901	284822	14357A	PARTICIPANT	\N	PRESENT	0
293286	292937	17637T	PARTICIPANT	\N	PRESENT	0
284903	284822	17589D	PARTICIPANT	\N	PRESENT	0
284904	284822	04089T	PARTICIPANT	\N	EXCUSE	0
284905	284822	19507S	PARTICIPANT	\N	PRESENT	0
284906	284822	14197C	PARTICIPANT	\N	PRESENT	0
284907	284822	14187A	PARTICIPANT	\N	PRESENT	0
284908	284822	01025N	PARTICIPANT	\N	PRESENT	0
293287	292937	95062K	PARTICIPANT	\N	PRESENT	0
284910	284822	19565D	PARTICIPANT	\N	PRESENT	0
284911	284822	14033T	PARTICIPANT	\N	PRESENT	0
293288	292937	08043V	PARTICIPANT	\N	EXCUSE	0
293289	292937	19531S	PARTICIPANT	\N	EXCUSE	0
284914	284822	19511N	PARTICIPANT	\N	PRESENT	0
284915	284822	11099A	PARTICIPANT	\N	PRESENT	0
284916	284822	04049K	PARTICIPANT	\N	PRESENT	0
284917	284822	08015R	PARTICIPANT	\N	PRESENT	0
293461	293460	17589D	PARTICIPANT	\N	PRESENT	0
284919	284822	14205J	PARTICIPANT	\N	PRESENT	0
284920	284822	19441R	PARTICIPANT	\N	PRESENT	0
293463	293462	17589D	PARTICIPANT	\N	PRESENT	0
284922	284822	08062Y	PARTICIPANT	\N	PRESENT	0
284923	284822	19563B	PARTICIPANT	\N	PRESENT	0
284924	284822	19369B	PARTICIPANT	\N	PRESENT	0
284925	284822	14257W	PARTICIPANT	\N	PRESENT	0
284926	284822	14265W	PARTICIPANT	\N	PRESENT	0
293465	293464	17589D	PARTICIPANT	\N	PRESENT	0
284928	284822	04088S	PARTICIPANT	\N	PRESENT	0
284929	284822	11090Q	PRESIDENT	0	PRESENT	0
293467	293466	17589D	PARTICIPANT	0	PRESENT	0
284931	284822	14135M	PARTICIPANT	\N	PRESENT	0
293469	293468	17589D	PARTICIPANT	\N	PRESENT	0
284933	284822	19705W	PARTICIPANT	\N	PRESENT	0
284934	284822	19619A	PARTICIPANT	\N	PRESENT	0
293605	292510	14063N	PARTICIPANT	\N	EXCUSE	0
284936	284822	19413M	PARTICIPANT	\N	PRESENT	0
293606	292510	05012A	PARTICIPANT	\N	EXCUSE	0
293703	292510	04044E	PARTICIPANT	\N	EXCUSE	0
293843	293842	11053K	PARTICIPANT	\N	PRESENT	0
293844	293842	14159V	PARTICIPANT	\N	PRESENT	0
293845	293842	05012A	PARTICIPANT	\N	PRESENT	0
293994	293992	19593H	PARTICIPANT	\N	PRESENT	0
293995	293992	04070G	PRESIDENT	0	PRESENT	0
293996	293992	19699S	PARTICIPANT	\N	PRESENT	0
293997	293992	19533U	PARTICIPANT	\N	PRESENT	0
293998	293992	19611R	PARTICIPANT	\N	PRESENT	0
293999	293992	08043V	PARTICIPANT	\N	PRESENT	0
294000	293992	14030Q	PARTICIPANT	\N	PRESENT	0
294001	293992	19731Y	PARTICIPANT	\N	PRESENT	0
294002	293992	14107H	PARTICIPANT	\N	PRESENT	0
294003	293992	14063N	PARTICIPANT	\N	PRESENT	0
294004	293992	11083R	PARTICIPANT	\N	PRESENT	0
294005	293992	08012N	PARTICIPANT	\N	PRESENT	0
294006	293992	14123H	PARTICIPANT	\N	PRESENT	0
294007	293992	11104D	PARTICIPANT	\N	PRESENT	0
294008	293992	19621T	PARTICIPANT	\N	PRESENT	0
294012	293835	04092N	PRESIDENT	0	PRESENT	0
294013	293835	11103C	PARTICIPANT	\N	PRESENT	0
294014	293835	08052W	PARTICIPANT	\N	PRESENT	0
294015	293835	08048B	PARTICIPANT	\N	PRESENT	0
294016	293835	14213J	PARTICIPANT	\N	PRESENT	0
294017	293835	19657G	PARTICIPANT	\N	PRESENT	0
294018	293835	14223L	PARTICIPANT	\N	PRESENT	0
294019	293835	14227Q	PARTICIPANT	\N	PRESENT	0
294020	293835	98024R	PARTICIPANT	\N	PRESENT	0
294021	293835	17779H	PARTICIPANT	\N	PRESENT	0
294052	293442	14001X	PARTICIPANT	\N	PRESENT	0
294023	293835	14119M	PARTICIPANT	\N	PRESENT	0
294024	293835	19679N	PARTICIPANT	\N	PRESENT	0
294025	293835	19575F	PARTICIPANT	\N	PRESENT	0
294026	293835	19577H	PARTICIPANT	\N	PRESENT	0
294027	293835	19760E	PARTICIPANT	\N	PRESENT	0
294028	293835	14195A	PARTICIPANT	\N	PRESENT	0
294029	293835	01034P	PARTICIPANT	\N	PRESENT	0
294030	293835	11097X	PARTICIPANT	\N	PRESENT	0
294031	293835	19415P	PARTICIPANT	\N	PRESENT	0
294032	293835	14239U	PARTICIPANT	\N	PRESENT	0
294033	293835	19367Y	PARTICIPANT	\N	PRESENT	0
294034	293835	10006L	PARTICIPANT	\N	PRESENT	0
294035	293835	19521Q	PARTICIPANT	\N	PRESENT	0
294036	293835	19703U	PARTICIPANT	\N	EXCUSE	0
294037	293835	19727D	PARTICIPANT	\N	EXCUSE	0
294038	293835	14281W	PARTICIPANT	\N	EXCUSE	0
294039	293835	08041T	PARTICIPANT	\N	EXCUSE	0
294040	293835	11031D	PARTICIPANT	\N	PRESENT	0
294041	293835	04045F	PARTICIPANT	\N	PRESENT	0
294042	293835	14042U	PARTICIPANT	\N	PRESENT	0
294043	293835	14071N	PARTICIPANT	\N	PRESENT	0
294044	293835	19691J	PARTICIPANT	\N	PRESENT	0
294045	293835	14355X	PARTICIPANT	\N	PRESENT	0
294046	293835	19553Y	PARTICIPANT	\N	PRESENT	0
294047	293835	19335Q	PARTICIPANT	\N	PRESENT	0
294048	293835	11067R	PARTICIPANT	\N	PRESENT	0
294049	293835	11045K	PARTICIPANT	\N	PRESENT	0
294050	293835	14217N	PARTICIPANT	\N	PRESENT	0
294051	293835	19569H	PARTICIPANT	\N	PRESENT	0
294053	293442	19543W	PARTICIPANT	\N	PRESENT	0
294054	293442	04044E	PARTICIPANT	\N	PRESENT	0
294055	293442	19581D	PARTICIPANT	\N	PRESENT	0
294056	293442	19585H	PARTICIPANT	\N	PRESENT	0
294057	293442	04047H	PARTICIPANT	\N	PRESENT	0
294058	293442	19673G	PARTICIPANT	\N	PRESENT	0
294059	293442	19447X	PARTICIPANT	\N	PRESENT	0
294060	293442	05008E	PRESIDENT	2	PRESENT	0
294061	293442	19489J	PARTICIPANT	\N	PRESENT	0
294062	293442	14147R	PARTICIPANT	\N	PRESENT	0
294063	293442	14179A	PARTICIPANT	\N	PRESENT	0
294064	293442	14215L	PRESIDENT	1	PRESENT	0
294065	293442	11072N	PARTICIPANT	\N	PRESENT	0
271693	271231	11101A	PARTICIPANT	\N	EXCUSE	0
286410	286409	07034Q	PARTICIPANT	\N	PRESENT	0
286411	286409	14071N	PARTICIPANT	\N	PRESENT	0
287284	287283	14255U	PARTICIPANT	\N	PRESENT	0
291611	287543	11070L	PARTICIPANT	\N	PRESENT	0
287286	287283	14083S	PARTICIPANT	\N	PRESENT	0
287287	287283	08018U	PARTICIPANT	\N	PRESENT	0
287289	287283	14041T	PARTICIPANT	\N	PRESENT	0
287290	287283	04049K	PARTICIPANT	\N	PRESENT	0
287291	287283	95067Q	PARTICIPANT	\N	PRESENT	0
287292	287283	19551W	PARTICIPANT	\N	PRESENT	0
287294	287293	19631V	PARTICIPANT	\N	PRESENT	0
287295	287293	19515S	PARTICIPANT	\N	PRESENT	0
294253	273913	14133K	PARTICIPANT	\N	PRESENT	0
287297	287293	11081P	PARTICIPANT	\N	EXCUSE	0
287298	287293	14115H	PARTICIPANT	\N	PRESENT	0
287299	287293	19747H	PARTICIPANT	\N	PRESENT	0
287300	287293	08068F	PARTICIPANT	\N	PRESENT	0
287301	287293	14207L	PARTICIPANT	\N	PRESENT	0
287302	287293	11101A	PARTICIPANT	\N	PRESENT	0
287303	287293	14329V	PARTICIPANT	\N	PRESENT	0
287304	287293	08028W	PARTICIPANT	\N	PRESENT	0
287305	287293	19467C	PARTICIPANT	\N	PRESENT	0
287306	287293	19295A	PARTICIPANT	\N	PRESENT	0
287307	287293	80013X	PARTICIPANT	\N	PRESENT	0
295240	295234	19663E	PARTICIPANT	\N	PRESENT	0
287309	287293	14357A	PARTICIPANT	\N	EXCUSE	0
295342	295234	12041X	PARTICIPANT	\N	PRESENT	0
287311	287293	17589D	PARTICIPANT	\N	PRESENT	0
295344	295234	04088S	PARTICIPANT	\N	PRESENT	0
295345	295234	11012A	PARTICIPANT	\N	PRESENT	0
287314	287293	14197C	PARTICIPANT	\N	PRESENT	0
287315	287293	14187A	PARTICIPANT	\N	PRESENT	0
287316	287293	01025N	PARTICIPANT	\N	EXCUSE	0
287317	287293	19695N	PARTICIPANT	\N	PRESENT	0
287318	287293	19565D	PARTICIPANT	\N	PRESENT	0
287319	287293	14033T	PARTICIPANT	\N	PRESENT	0
287320	287293	14081Q	PARTICIPANT	\N	PRESENT	0
287321	287293	19591F	PARTICIPANT	\N	PRESENT	0
287322	287293	19511N	PARTICIPANT	\N	PRESENT	0
287323	287293	11099A	PARTICIPANT	\N	PRESENT	0
287324	287293	04049K	PARTICIPANT	\N	PRESENT	0
287325	287293	08015R	PARTICIPANT	\N	PRESENT	0
295346	295234	01062T	PARTICIPANT	\N	PRESENT	0
287327	287293	14205J	PARTICIPANT	\N	PRESENT	0
287328	287293	19441R	PARTICIPANT	\N	PRESENT	0
287329	287293	08019V	PARTICIPANT	\N	PRESENT	0
287330	287293	08062Y	PARTICIPANT	\N	PRESENT	0
287331	287293	19563B	PARTICIPANT	\N	PRESENT	0
287332	287293	19369B	PARTICIPANT	\N	PRESENT	0
287333	287293	14257W	PARTICIPANT	\N	PRESENT	0
287334	287293	14265W	PARTICIPANT	\N	PRESENT	0
287335	287293	08021P	PARTICIPANT	\N	EXCUSE	0
287336	287293	04088S	PARTICIPANT	\N	PRESENT	0
287337	287293	11090Q	PRESIDENT	0	PRESENT	0
295347	295234	14001X	PARTICIPANT	\N	PRESENT	0
287339	287293	14135M	PARTICIPANT	\N	PRESENT	0
295776	295775	04008A	PARTICIPANT	\N	PRESENT	0
299053	299052	11054L	PARTICIPANT	\N	PRESENT	0
287342	287293	19619A	PARTICIPANT	\N	PRESENT	0
299054	299052	11033F	PARTICIPANT	\N	PRESENT	0
287344	287293	19413M	PARTICIPANT	\N	PRESENT	0
299055	299052	97011G	PARTICIPANT	\N	PRESENT	0
299056	299052	95067Q	PARTICIPANT	\N	PRESENT	0
299057	299052	14235Q	PARTICIPANT	\N	PRESENT	0
299058	299052	19647E	PARTICIPANT	\N	PRESENT	0
299059	299052	19591F	PARTICIPANT	\N	PRESENT	0
299061	299060	14331P	PARTICIPANT	\N	PRESENT	0
299243	298973	01043Q	PARTICIPANT	\N	PRESENT	0
299244	298973	04008A	PARTICIPANT	\N	PRESENT	0
299248	298973	11081P	PARTICIPANT	\N	EXCUSE	0
299249	299062	04008A	PARTICIPANT	\N	PRESENT	0
299250	299062	11081P	PARTICIPANT	\N	EXCUSE	0
299313	292891	19551W	PARTICIPANT	\N	PRESENT	0
299372	299371	11053K	PARTICIPANT	\N	PRESENT	0
299373	299371	14159V	PARTICIPANT	\N	PRESENT	0
299374	299371	05012A	PARTICIPANT	\N	PRESENT	0
299380	294264	14030Q	PRESIDENT	0	PRESENT	0
299381	294264	08043V	PARTICIPANT	\N	PRESENT	0
299382	294264	19367Y	PARTICIPANT	\N	PRESENT	0
299383	294264	18083K	PARTICIPANT	\N	PRESENT	0
299384	294264	14249W	PARTICIPANT	\N	PRESENT	0
299385	294264	19599P	PARTICIPANT	\N	PRESENT	0
299386	294264	04035D	PARTICIPANT	\N	PRESENT	0
299387	294264	08017T	PARTICIPANT	\N	PRESENT	0
299388	294264	14109K	PARTICIPANT	\N	PRESENT	0
299389	294264	11031D	PARTICIPANT	\N	EXCUSE	0
299390	294264	08031R	PARTICIPANT	\N	EXCUSE	0
299391	294264	01043Q	PARTICIPANT	\N	EXCUSE	0
299392	294264	07029T	PARTICIPANT	\N	EXCUSE	0
299396	294264	19657G	PARTICIPANT	\N	EXCUSE	0
299397	294264	14115H	PARTICIPANT	\N	EXCUSE	0
299398	294264	19749K	PARTICIPANT	\N	EXCUSE	0
299399	294264	19621T	PARTICIPANT	\N	EXCUSE	0
299400	294264	14217N	PARTICIPANT	\N	EXCUSE	0
299401	294264	19673G	PARTICIPANT	\N	EXCUSE	0
299402	294264	08020N	PARTICIPANT	\N	EXCUSE	0
300110	296100	19551W	PARTICIPANT	\N	PRESENT	0
300111	296100	19737F	PARTICIPANT	\N	PRESENT	0
300112	297304	19551W	PARTICIPANT	\N	PRESENT	0
300113	297304	19737F	PARTICIPANT	\N	PRESENT	0
300117	300116	14093U	PARTICIPANT	\N	PRESENT	0
300119	300118	14093U	PARTICIPANT	\N	PRESENT	0
300124	300123	14093U	PARTICIPANT	\N	PRESENT	0
300128	300127	14239U	PARTICIPANT	\N	PRESENT	0
300129	300127	14065Q	PARTICIPANT	\N	EXCUSE	0
300130	300127	14217N	PARTICIPANT	\N	PRESENT	0
300131	300127	14031R	PARTICIPANT	\N	PRESENT	0
300132	300127	14119M	PARTICIPANT	\N	PRESENT	0
300133	300127	04044E	PRESIDENT	0	PRESENT	0
300136	300125	14093U	PARTICIPANT	\N	PRESENT	0
300137	300135	14093U	PARTICIPANT	\N	PRESENT	0
300138	300120	14093U	PARTICIPANT	\N	PRESENT	0
300459	289198	14034U	PARTICIPANT	\N	PRESENT	0
300460	289198	12041X	PARTICIPANT	\N	PRESENT	0
300461	289198	14235Q	PARTICIPANT	\N	PRESENT	0
300462	289198	19565D	PARTICIPANT	\N	PRESENT	0
300463	289198	19591F	PARTICIPANT	\N	PRESENT	0
300464	289198	19631V	PARTICIPANT	\N	PRESENT	0
300465	289198	14207L	PARTICIPANT	\N	PRESENT	0
300466	289198	04034C	PARTICIPANT	\N	PRESENT	0
300467	289198	08061X	PARTICIPANT	\N	PRESENT	0
300468	289198	19629C	PARTICIPANT	\N	PRESENT	0
300469	289198	19507S	PARTICIPANT	\N	PRESENT	0
300470	289198	19399H	PARTICIPANT	\N	PRESENT	0
300471	289198	14267Y	PARTICIPANT	\N	PRESENT	0
300472	289198	19369B	PARTICIPANT	\N	PRESENT	0
300473	289198	19747H	PARTICIPANT	\N	PRESENT	0
300474	289198	14329V	PARTICIPANT	\N	PRESENT	0
300475	289198	97011G	PARTICIPANT	\N	PRESENT	0
300476	289198	11103C	PARTICIPANT	\N	PRESENT	0
300477	289198	11012A	PARTICIPANT	\N	PRESENT	0
300478	289198	11067R	PARTICIPANT	\N	PRESENT	0
300479	289198	11109J	PARTICIPANT	\N	PRESENT	0
300480	295640	14034U	PARTICIPANT	\N	PRESENT	0
300481	295640	12041X	PARTICIPANT	\N	PRESENT	0
300482	295640	14235Q	PARTICIPANT	\N	PRESENT	0
300483	295640	19565D	PARTICIPANT	\N	PRESENT	0
300484	295640	19591F	PARTICIPANT	\N	PRESENT	0
300485	295640	19631V	PARTICIPANT	\N	PRESENT	0
300486	295640	14207L	PARTICIPANT	\N	PRESENT	0
300487	295640	04034C	PARTICIPANT	\N	PRESENT	0
300488	295640	08061X	PARTICIPANT	\N	PRESENT	0
300489	295640	19629C	PARTICIPANT	\N	PRESENT	0
300490	295640	19507S	PARTICIPANT	\N	PRESENT	0
300491	295640	19399H	PARTICIPANT	\N	PRESENT	0
300492	295640	14267Y	PARTICIPANT	\N	PRESENT	0
300493	295640	19369B	PARTICIPANT	\N	PRESENT	0
300494	295640	19747H	PARTICIPANT	\N	PRESENT	0
300495	295640	14329V	PARTICIPANT	\N	PRESENT	0
300496	295640	97011G	PARTICIPANT	\N	PRESENT	0
300497	295640	11103C	PARTICIPANT	\N	PRESENT	0
300498	295640	11012A	PARTICIPANT	\N	PRESENT	0
300499	295640	11067R	PARTICIPANT	\N	PRESENT	0
300500	295640	11109J	PARTICIPANT	\N	PRESENT	0
300501	295640	04057K	PARTICIPANT	\N	PRESENT	0
300502	295640	19681G	PARTICIPANT	\N	PRESENT	0
300503	295640	14187A	PARTICIPANT	\N	PRESENT	0
300504	295640	95063L	PARTICIPANT	\N	PRESENT	0
300505	295640	14219Q	PARTICIPANT	\N	PRESENT	0
300506	295640	19441R	PARTICIPANT	\N	PRESENT	0
300507	295640	19671E	PARTICIPANT	\N	PRESENT	0
300508	295640	19695N	PARTICIPANT	\N	PRESENT	0
300509	295640	19687N	PARTICIPANT	\N	PRESENT	0
300510	295640	95037J	PARTICIPANT	\N	PRESENT	0
300511	295640	08045X	PARTICIPANT	\N	PRESENT	0
300512	295640	19335Q	PARTICIPANT	\N	PRESENT	0
300513	295640	19711U	PARTICIPANT	\N	PRESENT	0
273519	273518	11085T	PARTICIPANT	\N	PRESENT	0
273520	273518	04042C	PARTICIPANT	\N	PRESENT	0
275764	268444	19663E	PARTICIPANT	\N	EXCUSE	0
276478	268443	01048V	PARTICIPANT	\N	EXCUSE	0
277637	263768	04061F	PARTICIPANT	\N	PRESENT	0
279502	279501	14215L	PARTICIPANT	\N	PRESENT	0
280854	280853	19585H	PARTICIPANT	\N	PRESENT	0
280856	280855	19585H	PARTICIPANT	\N	PRESENT	0
280858	280857	19585H	PARTICIPANT	\N	PRESENT	0
281717	281715	04086Q	PARTICIPANT	\N	PRESENT	0
281718	281716	04086Q	PARTICIPANT	\N	PRESENT	0
282894	273894	19581D	PARTICIPANT	\N	PRESENT	0
282895	273894	08009T	PARTICIPANT	\N	PRESENT	0
282896	273894	14061L	PARTICIPANT	\N	PRESENT	0
282897	273894	19733B	PARTICIPANT	\N	PRESENT	0
282898	273894	19383Y	PARTICIPANT	\N	PRESENT	0
282899	273894	14063N	PARTICIPANT	\N	PRESENT	0
282900	273894	11104D	PARTICIPANT	\N	PRESENT	0
282901	273894	10006L	PARTICIPANT	\N	PRESENT	0
282902	273894	19533U	PARTICIPANT	\N	PRESENT	0
282903	273894	11103C	PARTICIPANT	\N	PRESENT	0
282904	273894	04033B	PARTICIPANT	\N	PRESENT	0
282905	273894	14026U	PARTICIPANT	\N	PRESENT	0
282906	273894	14179A	PARTICIPANT	\N	PRESENT	0
282907	273894	19443T	PARTICIPANT	\N	PRESENT	0
282908	273894	14041T	PARTICIPANT	\N	PRESENT	0
282909	273894	14105F	PARTICIPANT	\N	PRESENT	0
282910	273894	19415P	PARTICIPANT	\N	PRESENT	0
282911	273894	14029X	PARTICIPANT	\N	PRESENT	0
282912	273894	19573D	PARTICIPANT	\N	PRESENT	0
282913	273894	19447X	PARTICIPANT	\N	PRESENT	0
282914	273894	19673G	PARTICIPANT	\N	PRESENT	0
282915	273894	11048N	PARTICIPANT	\N	PRESENT	0
282916	273894	14223L	PARTICIPANT	\N	PRESENT	0
282917	273894	87003B	PARTICIPANT	\N	PRESENT	0
282918	273894	01057W	PARTICIPANT	\N	PRESENT	0
282919	273894	08069G	PARTICIPANT	\N	PRESENT	0
282920	273894	19681G	PARTICIPANT	\N	PRESENT	0
282921	273894	01058X	PARTICIPANT	\N	PRESENT	0
282922	273894	08020N	PARTICIPANT	\N	PRESENT	0
282923	273894	95030B	PARTICIPANT	\N	PRESENT	0
282924	273894	19711U	PARTICIPANT	\N	PRESENT	0
282925	273894	17637T	PARTICIPANT	\N	PRESENT	0
282926	273894	14038Y	PARTICIPANT	\N	PRESENT	0
282927	273894	08021P	PARTICIPANT	\N	PRESENT	0
282928	273894	19575F	PARTICIPANT	\N	PRESENT	0
282929	273894	08049C	PARTICIPANT	\N	PRESENT	0
282930	273894	19585H	PARTICIPANT	\N	PRESENT	0
282931	273894	14221J	PARTICIPANT	\N	PRESENT	0
282932	273894	14157T	PARTICIPANT	\N	PRESENT	0
282933	273894	04092N	PARTICIPANT	\N	PRESENT	0
282934	273894	01028R	PARTICIPANT	\N	PRESENT	0
282935	273894	14231L	PARTICIPANT	\N	PRESENT	0
282936	273894	95062K	PARTICIPANT	\N	PRESENT	0
282937	273894	14327T	PARTICIPANT	\N	PRESENT	0
282938	273894	14217N	PARTICIPANT	\N	PRESENT	0
282939	273894	19553Y	PARTICIPANT	\N	PRESENT	0
282940	273894	98050T	PARTICIPANT	\N	PRESENT	0
282941	273894	02002K	PARTICIPANT	\N	PRESENT	0
282942	273894	19637C	PARTICIPANT	\N	PRESENT	0
282943	273894	19333N	PARTICIPANT	\N	PRESENT	0
282944	273894	14239U	PARTICIPANT	\N	PRESENT	0
282945	273894	19719D	PARTICIPANT	\N	PRESENT	0
282946	273894	08039A	PARTICIPANT	\N	PRESENT	0
282947	273894	04045F	PARTICIPANT	\N	PRESENT	0
282948	273894	98022P	PARTICIPANT	\N	PRESENT	0
282949	273894	14251Q	PARTICIPANT	\N	PRESENT	0
282950	273894	17583W	PARTICIPANT	\N	PRESENT	0
282951	273894	14031R	PARTICIPANT	\N	PRESENT	0
282952	273894	08034U	PARTICIPANT	\N	PRESENT	0
282959	273894	08061X	PARTICIPANT	\N	PRESENT	0
282892	273894	14215L	PARTICIPANT	\N	PRESENT	0
282893	273894	19543W	PARTICIPANT	\N	PRESENT	0
282954	273894	14083S	PARTICIPANT	\N	PRESENT	0
282955	273894	19347U	PARTICIPANT	\N	PRESENT	0
282956	273894	08024S	PARTICIPANT	\N	PRESENT	0
282957	273894	11054L	PARTICIPANT	\N	PRESENT	0
282958	273894	10015M	PARTICIPANT	\N	PRESENT	0
282960	273894	19731Y	PARTICIPANT	\N	PRESENT	0
282961	273894	18083K	PARTICIPANT	\N	PRESENT	0
282962	273894	14211G	PARTICIPANT	\N	PRESENT	0
282963	273894	07004J	PARTICIPANT	\N	PRESENT	0
282964	273894	14111D	PARTICIPANT	\N	PRESENT	0
282965	273894	14069U	PARTICIPANT	\N	PRESENT	0
282966	273894	19651A	PARTICIPANT	\N	PRESENT	0
282967	273894	11049P	PARTICIPANT	\N	PRESENT	0
282968	273894	19741B	PARTICIPANT	\N	PRESENT	0
282969	273894	19643A	PARTICIPANT	\N	PRESENT	0
282970	273894	14173T	PARTICIPANT	\N	PRESENT	0
282971	273894	14213J	PARTICIPANT	\N	PRESENT	0
282972	273894	19367Y	PARTICIPANT	\N	PRESENT	0
282973	273894	19713W	PARTICIPANT	\N	PRESENT	0
282974	273894	08055A	PARTICIPANT	\N	PRESENT	0
282975	273894	11064N	PARTICIPANT	\N	PRESENT	0
282976	273894	14123H	PARTICIPANT	\N	PRESENT	0
282977	273894	11041F	PARTICIPANT	\N	PRESENT	0
282978	273894	19685L	PARTICIPANT	\N	PRESENT	0
282979	273894	14051J	PARTICIPANT	\N	PRESENT	0
283107	273895	86034E	PARTICIPANT	\N	PRESENT	0
283108	273895	19347U	PARTICIPANT	\N	PRESENT	0
283109	273895	19683J	PARTICIPANT	\N	PRESENT	0
283110	273895	14121F	PARTICIPANT	\N	PRESENT	0
283111	273895	14227Q	PARTICIPANT	\N	PRESENT	0
283112	273895	19503N	PARTICIPANT	\N	PRESENT	0
283113	273895	11041F	PARTICIPANT	\N	PRESENT	0
283114	273895	08021P	PARTICIPANT	\N	PRESENT	0
283125	273895	01028R	PARTICIPANT	\N	PRESENT	0
283128	273895	14051J	PARTICIPANT	\N	PRESENT	0
283129	273895	19585H	PARTICIPANT	\N	PRESENT	0
283130	273895	04057K	PARTICIPANT	\N	PRESENT	0
283131	273895	19681G	PARTICIPANT	\N	PRESENT	0
283133	273895	14063N	PARTICIPANT	\N	PRESENT	0
283134	273895	98029W	PARTICIPANT	\N	PRESENT	0
283135	273895	17779H	PARTICIPANT	\N	PRESENT	0
283136	273895	08060W	PARTICIPANT	\N	PRESENT	0
283137	273895	14039A	PARTICIPANT	\N	PRESENT	0
283138	273895	80013X	PARTICIPANT	\N	PRESENT	0
283139	273895	14207L	PARTICIPANT	\N	PRESENT	0
283140	273895	12041X	PARTICIPANT	\N	PRESENT	0
283141	273895	19515S	PARTICIPANT	\N	PRESENT	0
283142	273895	17637T	PARTICIPANT	\N	PRESENT	0
283143	273895	19711U	PARTICIPANT	\N	PRESENT	0
283144	273895	14151M	PARTICIPANT	\N	PRESENT	0
283145	273895	19649G	PARTICIPANT	\N	PRESENT	0
283146	273895	04008A	PARTICIPANT	\N	PRESENT	0
283147	273895	19599P	PARTICIPANT	\N	PRESENT	0
283148	273895	14211G	PARTICIPANT	\N	PRESENT	0
283149	273895	95062K	PARTICIPANT	\N	PRESENT	0
283150	273895	04038G	PARTICIPANT	\N	PRESENT	0
283151	273895	11056N	PARTICIPANT	\N	PRESENT	0
283152	273895	08011M	PARTICIPANT	\N	PRESENT	0
283153	273895	11040E	PARTICIPANT	\N	PRESENT	0
283154	273895	01058X	PARTICIPANT	\N	PRESENT	0
283155	273895	19758L	PARTICIPANT	\N	PRESENT	0
283156	273895	99004R	PARTICIPANT	\N	PRESENT	0
283157	273895	14157T	PARTICIPANT	\N	PRESENT	0
283158	273895	19695N	PARTICIPANT	\N	PRESENT	0
283159	273895	19687N	PARTICIPANT	\N	PRESENT	0
283160	273895	19593H	PARTICIPANT	\N	PRESENT	0
283161	273895	08020N	PARTICIPANT	\N	PRESENT	0
283162	273895	04097T	PARTICIPANT	\N	PRESENT	0
283163	273895	08039A	PARTICIPANT	\N	PRESENT	0
283164	273895	08010L	PARTICIPANT	\N	PRESENT	0
283165	273895	04045F	PARTICIPANT	\N	PRESENT	0
283166	273895	14239U	PARTICIPANT	\N	PRESENT	0
283167	273895	14123H	PARTICIPANT	\N	PRESENT	0
283168	273895	19651A	PARTICIPANT	\N	PRESENT	0
283169	273895	95015C	PARTICIPANT	\N	PRESENT	0
283170	273895	19637C	PARTICIPANT	\N	PRESENT	0
283171	273895	19349W	PARTICIPANT	\N	PRESENT	0
283172	273895	15447F	PARTICIPANT	\N	PRESENT	0
283173	273895	04034C	PARTICIPANT	\N	PRESENT	0
283174	273895	19269X	PARTICIPANT	\N	PRESENT	0
283175	273895	19697Q	PARTICIPANT	\N	PRESENT	0
283176	273895	19643A	PARTICIPANT	\N	PRESENT	0
283177	273895	11083R	PARTICIPANT	\N	PRESENT	0
283178	273895	19329S	PARTICIPANT	\N	PRESENT	0
283179	273895	08073C	PARTICIPANT	\N	PRESENT	0
283180	273895	14169X	PARTICIPANT	\N	PRESENT	0
283181	273895	10015M	PARTICIPANT	\N	PRESENT	0
283182	273895	11043H	PARTICIPANT	\N	PRESENT	0
283183	273895	19731Y	PARTICIPANT	\N	PRESENT	0
283184	273895	19685L	PARTICIPANT	\N	PRESENT	0
283185	273895	89017R	PARTICIPANT	\N	PRESENT	0
283186	273895	14223L	PARTICIPANT	\N	PRESENT	0
271923	271231	14259Y	PARTICIPANT	\N	EXCUSE	0
271932	271231	04044E	PARTICIPANT	\N	EXCUSE	0
272400	272043	04086Q	PARTICIPANT	\N	EXCUSE	0
272402	272043	08048B	PARTICIPANT	\N	EXCUSE	0
272403	272043	08034U	PARTICIPANT	\N	EXCUSE	0
272587	272043	11101A	PARTICIPANT	\N	EXCUSE	0
273268	272043	04044E	PARTICIPANT	\N	EXCUSE	0
273270	273269	19515S	PARTICIPANT	\N	PRESENT	0
273271	273269	07033P	PARTICIPANT	\N	PRESENT	0
273272	273269	14087W	PARTICIPANT	\N	PRESENT	0
273273	273269	19649G	PARTICIPANT	\N	PRESENT	0
273274	273269	19725B	PARTICIPANT	\N	PRESENT	0
273275	273269	11026G	PARTICIPANT	\N	PRESENT	0
273276	273269	16685X	PARTICIPANT	\N	PRESENT	0
273277	273269	14225N	PARTICIPANT	\N	PRESENT	0
273278	273269	04034C	PARTICIPANT	\N	PRESENT	0
276042	273669	11109J	PARTICIPANT	\N	PRESENT	0
276043	273669	14261S	PARTICIPANT	\N	PRESENT	0
276044	273669	14259Y	PARTICIPANT	\N	EXCUSE	0
276045	273669	19659J	PARTICIPANT	\N	PRESENT	0
276046	273669	19691J	PARTICIPANT	\N	PRESENT	0
276047	273669	19329S	PARTICIPANT	\N	PRESENT	0
276048	273669	08019V	PRESIDENT	0	PRESENT	0
276049	273669	19715Y	PARTICIPANT	\N	EXCUSE	0
276050	273669	11072N	PARTICIPANT	\N	PRESENT	0
276051	273669	19319Q	PARTICIPANT	\N	PRESENT	0
286071	273905	08068F	PARTICIPANT	\N	PRESENT	0
286072	273905	07034Q	PARTICIPANT	\N	PRESENT	0
286073	273905	14357A	PARTICIPANT	\N	PRESENT	0
286074	273905	19693L	PARTICIPANT	\N	PRESENT	0
286075	273905	19657G	PARTICIPANT	\N	PRESENT	0
286076	273905	11099A	PARTICIPANT	\N	PRESENT	0
286077	273905	19697Q	PARTICIPANT	\N	PRESENT	0
286078	273905	19695N	PARTICIPANT	\N	PRESENT	0
286079	273905	05012A	PARTICIPANT	\N	PRESENT	0
286080	273905	04057K	PARTICIPANT	\N	PRESENT	0
286081	273905	11072N	PARTICIPANT	\N	PRESENT	0
286082	273905	19711U	PARTICIPANT	\N	PRESENT	0
286083	273905	19591F	PARTICIPANT	\N	PRESENT	0
286084	273905	19531S	PARTICIPANT	\N	PRESENT	0
286069	273905	04044E	PARTICIPANT	\N	PRESENT	0
286070	273905	08039A	PARTICIPANT	\N	PRESENT	0
286085	273905	02002K	PARTICIPANT	\N	PRESENT	0
286086	273905	14229S	PARTICIPANT	\N	PRESENT	0
286087	273905	19369B	PARTICIPANT	\N	PRESENT	0
286088	273905	14329V	PARTICIPANT	\N	PRESENT	0
286089	273905	04071H	PARTICIPANT	\N	PRESENT	0
286090	273905	19735D	PARTICIPANT	\N	PRESENT	0
286091	273905	19593H	PARTICIPANT	\N	PRESENT	0
286092	273905	19621T	PARTICIPANT	\N	PRESENT	0
286093	273905	11090Q	PARTICIPANT	\N	PRESENT	0
286094	273905	14157T	PARTICIPANT	\N	PRESENT	0
286095	273905	04086Q	PARTICIPANT	\N	PRESENT	0
286096	273905	19667J	PARTICIPANT	\N	PRESENT	0
286097	273905	14109K	PARTICIPANT	\N	PRESENT	0
286098	273905	07004J	PARTICIPANT	\N	PRESENT	0
286099	273905	19295A	PARTICIPANT	\N	PRESENT	0
286100	273905	19651A	PARTICIPANT	\N	PRESENT	0
286101	273905	11048N	PARTICIPANT	\N	PRESENT	0
286102	273905	04070G	PARTICIPANT	\N	PRESENT	0
286103	273905	19749K	PARTICIPANT	\N	PRESENT	0
286104	273905	14147R	PARTICIPANT	\N	PRESENT	0
286105	273905	11109J	PARTICIPANT	\N	PRESENT	0
286106	273905	01028R	PARTICIPANT	\N	PRESENT	0
286183	281194	19667J	PARTICIPANT	\N	PRESENT	0
286184	281194	19651A	PARTICIPANT	\N	PRESENT	0
286185	281194	08068F	PARTICIPANT	\N	PRESENT	0
286186	281194	19295A	PARTICIPANT	\N	PRESENT	0
286187	281194	19593H	PARTICIPANT	\N	PRESENT	0
286188	281194	19749K	PARTICIPANT	\N	PRESENT	0
286189	281194	07004J	PARTICIPANT	\N	PRESENT	0
286190	281194	19735D	PARTICIPANT	\N	PRESENT	0
286191	281194	19553Y	PARTICIPANT	\N	PRESENT	0
286192	281194	19693L	PARTICIPANT	\N	PRESENT	0
286193	281194	19591F	PARTICIPANT	\N	PRESENT	0
286194	281194	02002K	PARTICIPANT	\N	PRESENT	0
286195	281194	19711U	PARTICIPANT	\N	PRESENT	0
286196	281194	14329V	PARTICIPANT	\N	PRESENT	0
286197	281194	05012A	PARTICIPANT	\N	PRESENT	0
286198	281194	17637T	PARTICIPANT	\N	PRESENT	0
286199	281194	14261S	PARTICIPANT	\N	PRESENT	0
286200	281194	19531S	PARTICIPANT	\N	PRESENT	0
286201	281194	11109J	PARTICIPANT	\N	PRESENT	0
286202	281194	14357A	PARTICIPANT	\N	PRESENT	0
286203	281194	04086Q	PARTICIPANT	\N	PRESENT	0
286204	281194	08010L	PARTICIPANT	\N	PRESENT	0
286205	281194	08039A	PARTICIPANT	\N	PRESENT	0
286206	281194	19695N	PARTICIPANT	\N	PRESENT	0
286207	281194	11072N	PARTICIPANT	\N	PRESENT	0
286208	281194	04071H	PARTICIPANT	\N	PRESENT	0
289225	273920	11077T	PARTICIPANT	\N	PRESENT	0
289226	273920	04047H	PARTICIPANT	\N	PRESENT	0
289227	273920	19683J	PARTICIPANT	\N	PRESENT	0
289228	273920	04059M	PARTICIPANT	\N	PRESENT	0
289229	273920	11045K	PARTICIPANT	\N	PRESENT	0
289230	273920	19649G	PARTICIPANT	\N	PRESENT	0
289231	273920	19671E	PARTICIPANT	\N	PRESENT	0
289232	273920	19611R	PARTICIPANT	\N	PRESENT	0
289233	273920	04034C	PARTICIPANT	\N	PRESENT	0
289234	273920	19629C	PARTICIPANT	\N	PRESENT	0
289235	273920	19663E	PARTICIPANT	\N	PRESENT	0
286181	281194	19369B	PARTICIPANT	\N	PRESENT	0
286182	281194	11090Q	PARTICIPANT	\N	PRESENT	0
289236	273920	19701S	PARTICIPANT	\N	PRESENT	0
289237	273920	14215L	PARTICIPANT	\N	PRESENT	0
289238	273920	04044E	PARTICIPANT	\N	PRESENT	0
289239	273920	99004R	PARTICIPANT	\N	PRESENT	0
289240	273920	19693L	PARTICIPANT	\N	PRESENT	0
289241	273920	19647E	PARTICIPANT	\N	PRESENT	0
289242	273920	19689Q	PARTICIPANT	\N	PRESENT	0
289243	273920	11026G	PARTICIPANT	\N	PRESENT	0
289244	273920	19543W	PARTICIPANT	\N	PRESENT	0
289245	273920	14261S	PARTICIPANT	\N	PRESENT	0
289246	273920	19711U	PARTICIPANT	\N	PRESENT	0
289247	273920	19591F	PARTICIPANT	\N	PRESENT	0
289248	273920	14053L	PARTICIPANT	\N	PRESENT	0
289249	273920	14030Q	PARTICIPANT	\N	PRESENT	0
289250	273920	05008E	PARTICIPANT	\N	PRESENT	0
289251	273920	11033F	PARTICIPANT	\N	PRESENT	0
289252	273920	11031D	PARTICIPANT	\N	PRESENT	0
289253	273920	04085P	PARTICIPANT	\N	PRESENT	0
289254	273920	14001X	PARTICIPANT	\N	PRESENT	0
289255	273920	19593H	PARTICIPANT	\N	PRESENT	0
289256	273920	19695N	PARTICIPANT	\N	PRESENT	0
289257	273920	14151M	PARTICIPANT	\N	PRESENT	0
289258	273920	14229S	PARTICIPANT	\N	PRESENT	0
289259	273920	14042U	PARTICIPANT	\N	PRESENT	0
289260	273920	14235Q	PARTICIPANT	\N	PRESENT	0
289261	273920	14093U	PARTICIPANT	\N	PRESENT	0
289262	273920	04035D	PARTICIPANT	\N	PRESENT	0
289263	273920	14055N	PARTICIPANT	\N	PRESENT	0
289264	273920	95063L	PARTICIPANT	\N	PRESENT	0
289265	273920	01028R	PARTICIPANT	\N	PRESENT	0
289266	273920	04043D	PARTICIPANT	\N	PRESENT	0
289267	273920	19347U	PARTICIPANT	\N	PRESENT	0
289268	273920	19687N	PARTICIPANT	\N	PRESENT	0
289269	273920	17637T	PARTICIPANT	\N	PRESENT	0
289270	273920	14065Q	PARTICIPANT	\N	PRESENT	0
289271	273920	11109J	PARTICIPANT	\N	PRESENT	0
289272	273920	14021P	PARTICIPANT	\N	PRESENT	0
289273	273920	04040A	PARTICIPANT	\N	PRESENT	0
289274	273920	14071N	PARTICIPANT	\N	PRESENT	0
289280	289087	04059M	PARTICIPANT	\N	PRESENT	0
289281	289087	04085P	PARTICIPANT	\N	PRESENT	0
289282	289087	19593H	PARTICIPANT	\N	PRESENT	0
289283	289087	11031D	PARTICIPANT	\N	PRESENT	0
289284	289087	19683J	PARTICIPANT	\N	PRESENT	0
289285	289087	19649G	PARTICIPANT	\N	PRESENT	0
289286	289087	11026G	PARTICIPANT	\N	PRESENT	0
289287	289087	05008E	PARTICIPANT	\N	PRESENT	0
289288	289087	04047H	PARTICIPANT	\N	PRESENT	0
289289	289087	11072N	PARTICIPANT	\N	PRESENT	0
289290	289087	14039A	PARTICIPANT	\N	PRESENT	0
289291	289087	14042U	PARTICIPANT	\N	PRESENT	0
289292	289087	11070L	PARTICIPANT	\N	PRESENT	0
289293	289087	14030Q	PARTICIPANT	\N	PRESENT	0
289294	289087	04018C	PARTICIPANT	\N	PRESENT	0
289295	289087	19701S	PARTICIPANT	\N	PRESENT	0
289296	289087	19693L	PARTICIPANT	\N	PRESENT	0
289297	289087	08019V	PARTICIPANT	\N	PRESENT	0
289298	289087	14215L	PARTICIPANT	\N	PRESENT	0
289299	289087	19711U	PARTICIPANT	\N	PRESENT	0
289300	289087	14261S	PARTICIPANT	\N	PRESENT	0
289301	289087	19629C	PARTICIPANT	\N	PRESENT	0
289302	289087	19669L	PARTICIPANT	\N	PRESENT	0
289303	289087	17637T	PARTICIPANT	\N	PRESENT	0
289304	289087	11033F	PARTICIPANT	\N	PRESENT	0
289305	289087	04035D	PARTICIPANT	\N	PRESENT	0
289306	289087	19643A	PARTICIPANT	\N	PRESENT	0
275934	273669	19729F	PARTICIPANT	\N	EXCUSE	0
278244	278243	19621T	PARTICIPANT	\N	PRESENT	0
278245	278243	08031R	PARTICIPANT	\N	PRESENT	0
278767	278766	14065Q	PARTICIPANT	\N	PRESENT	0
278768	278766	96004D	PRESIDENT	0	PRESENT	0
278769	278766	14089Y	PARTICIPANT	\N	PRESENT	0
278770	278766	08014Q	PARTICIPANT	\N	EXCUSE	0
278771	278766	14357A	PARTICIPANT	\N	PRESENT	0
278772	278766	14079W	PARTICIPANT	\N	PRESENT	0
278773	278766	08018U	PARTICIPANT	\N	EXCUSE	0
278774	278766	11083R	PARTICIPANT	\N	PRESENT	0
278775	278766	19725B	PARTICIPANT	\N	PRESENT	0
278776	278766	04097T	PARTICIPANT	\N	EXCUSE	0
278777	278766	14097Y	PARTICIPANT	\N	PRESENT	0
278778	278766	04061F	PARTICIPANT	\N	PRESENT	0
278779	278766	14061L	PARTICIPANT	\N	EXCUSE	0
278780	278766	14073Q	PARTICIPANT	\N	PRESENT	0
278781	278766	14001X	PARTICIPANT	\N	PRESENT	0
278782	278766	14221J	PARTICIPANT	\N	PRESENT	0
278783	278766	04057K	PARTICIPANT	\N	PRESENT	0
278784	278766	19593H	PARTICIPANT	\N	PRESENT	0
278785	278766	08073C	PARTICIPANT	\N	PRESENT	0
278786	278766	14135M	PARTICIPANT	\N	EXCUSE	0
278787	278766	14331P	PARTICIPANT	\N	PRESENT	0
284525	284524	19563B	PARTICIPANT	\N	PRESENT	0
284526	284524	08043V	PARTICIPANT	\N	PRESENT	0
286390	273911	19723Y	PARTICIPANT	\N	PRESENT	0
286391	273911	14073Q	PARTICIPANT	\N	PRESENT	0
286392	273911	08028W	PARTICIPANT	\N	PRESENT	0
286393	273911	19575F	PARTICIPANT	\N	PRESENT	0
286394	273911	08073C	PARTICIPANT	\N	PRESENT	0
286395	273911	14213J	PARTICIPANT	\N	PRESENT	0
286396	285992	01048V	PARTICIPANT	\N	PRESENT	0
286397	285992	14034U	PARTICIPANT	\N	PRESENT	0
286398	273911	11063M	PARTICIPANT	\N	PRESENT	0
286399	273911	19685L	PARTICIPANT	\N	PRESENT	0
286400	273911	14033T	PARTICIPANT	\N	PRESENT	0
286401	273911	11110B	PARTICIPANT	\N	PRESENT	0
286402	273911	01024M	PARTICIPANT	\N	PRESENT	0
286403	273911	14241N	PARTICIPANT	\N	PRESENT	0
286404	273911	19621T	PARTICIPANT	\N	PRESENT	0
286405	273911	18083K	PARTICIPANT	\N	PRESENT	0
286406	273911	14265W	PARTICIPANT	\N	PRESENT	0
286407	273911	14193X	PARTICIPANT	\N	PRESENT	0
286408	273911	04049K	PARTICIPANT	\N	PRESENT	0
286422	273912	08060W	PARTICIPANT	\N	PRESENT	0
286423	273912	11066Q	PARTICIPANT	\N	PRESENT	0
286424	273912	19683J	PARTICIPANT	\N	PRESENT	0
286425	273912	14123H	PARTICIPANT	\N	PRESENT	0
286426	273912	11040E	PARTICIPANT	\N	PRESENT	0
286427	273912	14115H	PARTICIPANT	\N	PRESENT	0
286428	273912	19515S	PARTICIPANT	\N	PRESENT	0
286429	273912	19649G	PARTICIPANT	\N	PRESENT	0
286420	273912	86034E	PARTICIPANT	\N	PRESENT	0
286421	273912	14331P	PARTICIPANT	\N	PRESENT	0
286430	273912	14097Y	PARTICIPANT	\N	PRESENT	0
286431	273912	04047H	PARTICIPANT	\N	PRESENT	0
286432	273912	04034C	PARTICIPANT	\N	PRESENT	0
286433	273912	19503N	PARTICIPANT	\N	PRESENT	0
286434	273912	19413M	PARTICIPANT	\N	PRESENT	0
286435	273912	11026G	PARTICIPANT	\N	PRESENT	0
286436	273912	11103C	PARTICIPANT	\N	PRESENT	0
286437	273912	19673G	PARTICIPANT	\N	PRESENT	0
286438	273912	19333N	PARTICIPANT	\N	PRESENT	0
286439	273912	95062K	PARTICIPANT	\N	PRESENT	0
286440	273912	19669L	PARTICIPANT	\N	PRESENT	0
286441	273912	95063L	PARTICIPANT	\N	PRESENT	0
286442	273912	19421M	PARTICIPANT	\N	PRESENT	0
286443	273912	19671E	PARTICIPANT	\N	PRESENT	0
286444	273912	19525U	PARTICIPANT	\N	PRESENT	0
286445	273912	04085P	PARTICIPANT	\N	PRESENT	0
286446	273912	19695N	PARTICIPANT	\N	PRESENT	0
286447	273912	19251M	PARTICIPANT	\N	PRESENT	0
286448	273912	19689Q	PARTICIPANT	\N	PRESENT	0
286450	273912	14021P	PARTICIPANT	\N	PRESENT	0
286451	273912	11067R	PARTICIPANT	\N	PRESENT	0
286453	273912	19647E	PARTICIPANT	\N	PRESENT	0
286454	273912	19631V	PARTICIPANT	\N	PRESENT	0
286455	273912	19301E	PARTICIPANT	\N	PRESENT	0
286456	273912	04059M	PARTICIPANT	\N	PRESENT	0
286457	273912	14281W	PARTICIPANT	\N	PRESENT	0
286458	273912	01028R	PARTICIPANT	\N	PRESENT	0
286459	273912	14107H	PARTICIPANT	\N	PRESENT	0
286460	273912	19349W	PARTICIPANT	\N	PRESENT	0
286461	273912	19563B	PARTICIPANT	\N	PRESENT	0
286462	273912	19387D	PARTICIPANT	\N	PRESENT	0
286463	273912	14151M	PARTICIPANT	\N	PRESENT	0
286464	273912	11033F	PARTICIPANT	\N	PRESENT	0
286465	273912	19591F	PARTICIPANT	\N	PRESENT	0
286466	273912	19585H	PARTICIPANT	\N	PRESENT	0
286467	273912	19347U	PARTICIPANT	\N	PRESENT	0
286468	273912	19593H	PARTICIPANT	\N	PRESENT	0
286469	273912	19329S	PARTICIPANT	\N	PRESENT	0
286470	273912	19253P	PARTICIPANT	\N	PRESENT	0
286471	273912	19629C	PARTICIPANT	\N	PRESENT	0
286472	273912	08031R	PARTICIPANT	\N	PRESENT	0
286473	273912	19737F	PARTICIPANT	\N	PRESENT	0
286474	273912	14231L	PARTICIPANT	\N	PRESENT	0
286475	273912	19739H	PARTICIPANT	\N	PRESENT	0
286476	273912	19731Y	PARTICIPANT	\N	PRESENT	0
286477	273912	14261S	PARTICIPANT	\N	PRESENT	0
286478	273912	19533U	PARTICIPANT	\N	PRESENT	0
286479	273912	14187A	PARTICIPANT	\N	PRESENT	0
286480	273912	08028W	PARTICIPANT	\N	PRESENT	0
286481	273912	14223L	PARTICIPANT	\N	PRESENT	0
286482	273912	19575F	PARTICIPANT	\N	PRESENT	0
286483	273912	18083K	PARTICIPANT	\N	PRESENT	0
286484	273912	19729F	PARTICIPANT	\N	PRESENT	0
286485	273912	19507S	PARTICIPANT	\N	PRESENT	0
286486	273912	19415P	PARTICIPANT	\N	PRESENT	0
286487	273912	19467C	PARTICIPANT	\N	PRESENT	0
286488	273912	19723Y	PARTICIPANT	\N	PRESENT	0
286489	273912	19667J	PARTICIPANT	\N	PRESENT	0
286490	273912	11080N	PARTICIPANT	\N	PRESENT	0
286491	273912	19643A	PARTICIPANT	\N	PRESENT	0
286492	273912	14265W	PARTICIPANT	\N	PRESENT	0
286493	273912	17637T	PARTICIPANT	\N	PRESENT	0
286494	273912	99004R	PARTICIPANT	\N	PRESENT	0
286495	273912	08020N	PARTICIPANT	\N	PRESENT	0
286496	273912	04097T	PARTICIPANT	\N	PRESENT	0
286497	273912	01057W	PARTICIPANT	\N	PRESENT	0
286498	273912	19637C	PARTICIPANT	\N	PRESENT	0
286499	273912	14121F	PARTICIPANT	\N	PRESENT	0
286500	273912	14063N	PARTICIPANT	\N	PRESENT	0
286501	273912	08024S	PARTICIPANT	\N	PRESENT	0
286502	273912	11045K	PARTICIPANT	\N	PRESENT	0
286503	273912	19745F	PARTICIPANT	\N	PRESENT	0
286504	273912	14215L	PARTICIPANT	\N	PRESENT	0
286505	273912	14089Y	PARTICIPANT	\N	PRESENT	0
286506	273912	14207L	PARTICIPANT	\N	PRESENT	0
286508	273912	19577H	PARTICIPANT	\N	PRESENT	0
286515	273912	19711U	PARTICIPANT	\N	PRESENT	0
286516	273912	19581D	PARTICIPANT	\N	PRESENT	0
286517	273912	10006L	PARTICIPANT	\N	PRESENT	0
286519	273912	14257W	PARTICIPANT	\N	PRESENT	0
286520	273912	14038Y	PARTICIPANT	\N	PRESENT	0
286521	273912	19713W	PARTICIPANT	\N	PRESENT	0
286522	273912	08012N	PARTICIPANT	\N	PRESENT	0
286523	273912	14039A	PARTICIPANT	\N	PRESENT	0
286524	273912	11104D	PARTICIPANT	\N	PRESENT	0
286525	273912	14103D	PARTICIPANT	\N	PRESENT	0
286526	273912	08061X	PARTICIPANT	\N	PRESENT	0
286527	273912	19747H	PARTICIPANT	\N	PRESENT	0
286528	273912	14031R	PARTICIPANT	\N	PRESENT	0
286529	273912	08017T	PARTICIPANT	\N	PRESENT	0
286530	273912	14001X	PARTICIPANT	\N	PRESENT	0
286531	273912	11072N	PARTICIPANT	\N	PRESENT	0
286532	273912	14217N	PARTICIPANT	\N	PRESENT	0
286533	273912	04086Q	PARTICIPANT	\N	PRESENT	0
286534	273912	11031D	PARTICIPANT	\N	PRESENT	0
286535	273912	14213J	PARTICIPANT	\N	PRESENT	0
286536	273912	14026U	PARTICIPANT	\N	PRESENT	0
286537	273912	19715Y	PARTICIPANT	\N	PRESENT	0
286538	273912	14065Q	PARTICIPANT	\N	PRESENT	0
286540	273912	04057K	PARTICIPANT	\N	PRESENT	0
286541	273912	19693L	PARTICIPANT	\N	PRESENT	0
286556	273912	19685L	PARTICIPANT	\N	PRESENT	0
286558	273912	95030B	PARTICIPANT	\N	PRESENT	0
286559	273912	87003B	PARTICIPANT	\N	PRESENT	0
286560	273912	14249W	PARTICIPANT	\N	PRESENT	0
286561	273912	15447F	PARTICIPANT	\N	PRESENT	0
286562	273912	19295A	PARTICIPANT	\N	PRESENT	0
286563	273912	14205J	PARTICIPANT	\N	PRESENT	0
286564	273912	14259Y	PARTICIPANT	\N	PRESENT	0
286565	273912	05008E	PARTICIPANT	\N	PRESENT	0
286566	273912	08016S	PARTICIPANT	\N	PRESENT	0
286567	273912	19651A	PARTICIPANT	\N	PRESENT	0
286568	273912	14069U	PARTICIPANT	\N	PRESENT	0
286569	273912	19741B	PARTICIPANT	\N	PRESENT	0
272137	270395	04097T	PARTICIPANT	\N	PRESENT	0
273995	273666	14261S	PARTICIPANT	\N	EXCUSE	0
273996	273666	19691J	PARTICIPANT	\N	PRESENT	0
273997	273666	19329S	PARTICIPANT	\N	PRESENT	0
273998	273666	14097Y	PARTICIPANT	\N	PRESENT	0
273999	273666	19729F	PARTICIPANT	\N	EXCUSE	0
274000	273666	08019V	PRESIDENT	0	PRESENT	0
274001	273666	19657G	PARTICIPANT	\N	PRESENT	0
274002	273666	11072N	PARTICIPANT	\N	PRESENT	0
274003	273666	14135M	PARTICIPANT	\N	PRESENT	0
292026	291992	14179A	PARTICIPANT	\N	PRESENT	0
292027	291992	95063L	PARTICIPANT	\N	PRESENT	0
292028	291992	07034Q	PARTICIPANT	\N	PRESENT	0
292029	291992	01028R	PARTICIPANT	\N	PRESENT	0
292030	291992	19729F	PARTICIPANT	\N	PRESENT	0
292034	291993	95063L	PARTICIPANT	\N	PRESENT	0
292035	291993	07034Q	PARTICIPANT	\N	PRESENT	0
292036	291993	01028R	PARTICIPANT	\N	PRESENT	0
292037	291993	11033F	PARTICIPANT	\N	PRESENT	0
300515	295640	14033T	PARTICIPANT	\N	PRESENT	0
293672	293670	08024S	PARTICIPANT	\N	PRESENT	0
293673	293670	10006L	PARTICIPANT	\N	PRESENT	0
293674	293670	98005N	PARTICIPANT	\N	PRESENT	0
293675	293670	14059S	PARTICIPANT	\N	PRESENT	0
293676	293670	04043D	PARTICIPANT	\N	PRESENT	0
300514	295640	14105F	PARTICIPANT	\N	PRESENT	0
300516	295640	19415P	PARTICIPANT	\N	PRESENT	0
294872	294871	14147R	PARTICIPANT	\N	PRESENT	0
294873	292510	04045F	PARTICIPANT	\N	EXCUSE	0
294928	294927	14255U	PARTICIPANT	\N	PRESENT	0
294929	294927	11048N	PARTICIPANT	\N	PRESENT	0
294930	294927	19711U	PARTICIPANT	\N	PRESENT	0
294932	294927	04088S	PARTICIPANT	\N	PRESENT	0
294933	294927	14063N	PARTICIPANT	\N	PRESENT	0
294956	292510	19253P	PARTICIPANT	\N	PRESENT	0
294958	292510	14195A	PARTICIPANT	\N	PRESENT	0
294959	292510	04086Q	PARTICIPANT	\N	PRESENT	0
294960	292510	08038Y	PARTICIPANT	\N	PRESENT	0
294961	292510	14327T	PARTICIPANT	\N	EXCUSE	0
294962	292510	14069U	PARTICIPANT	\N	EXCUSE	0
294963	292510	14231L	PARTICIPANT	\N	PRESENT	0
294964	292510	19565D	PARTICIPANT	\N	PRESENT	0
294965	292510	19489J	PARTICIPANT	\N	PRESENT	0
294966	292510	11049P	PARTICIPANT	\N	PRESENT	0
294967	292510	08034U	PARTICIPANT	\N	PRESENT	0
294968	292510	08010L	PARTICIPANT	\N	PRESENT	0
294969	292510	14257W	PARTICIPANT	\N	PRESENT	0
294970	292510	14028W	PARTICIPANT	\N	PRESENT	0
294971	292510	95063L	PARTICIPANT	\N	PRESENT	0
294972	292510	01057W	PARTICIPANT	\N	PRESENT	0
300517	295640	98005N	PARTICIPANT	\N	PRESENT	0
300518	295640	14119M	PARTICIPANT	\N	PRESENT	0
300519	295640	19443T	PARTICIPANT	\N	PRESENT	0
300520	295640	14071N	PARTICIPANT	\N	PRESENT	0
292022	291989	07034Q	PARTICIPANT	\N	PRESENT	0
292023	291989	01028R	PARTICIPANT	\N	PRESENT	0
300521	295640	19703U	PARTICIPANT	\N	PRESENT	0
300522	295640	14038Y	PARTICIPANT	\N	PRESENT	0
300525	295640	19719D	PARTICIPANT	\N	PRESENT	0
300529	295640	11065P	PARTICIPANT	\N	PRESENT	0
300533	295640	14039A	PARTICIPANT	\N	PRESENT	0
300535	295640	19669L	PARTICIPANT	\N	PRESENT	0
300537	295640	19347U	PARTICIPANT	\N	PRESENT	0
300547	295640	14087W	PARTICIPANT	\N	PRESENT	0
300566	295640	14265W	PARTICIPANT	\N	PRESENT	0
300570	295640	04088S	PARTICIPANT	\N	PRESENT	0
300571	295640	14193X	PARTICIPANT	\N	PRESENT	0
300572	295640	08038Y	PARTICIPANT	\N	PRESENT	0
300573	295640	19699S	PARTICIPANT	\N	PRESENT	0
300574	295640	14331P	PARTICIPANT	\N	PRESENT	0
300575	295640	19489J	PARTICIPANT	\N	PRESENT	0
300576	295640	14229S	PARTICIPANT	\N	PRESENT	0
300577	295640	11099A	PARTICIPANT	\N	PRESENT	0
300578	295640	19563B	PARTICIPANT	\N	PRESENT	0
300579	295640	14107H	PARTICIPANT	\N	PRESENT	0
300580	295640	08016S	PARTICIPANT	\N	PRESENT	0
300581	295640	11056N	PARTICIPANT	\N	PRESENT	0
300582	295640	19745F	PARTICIPANT	\N	PRESENT	0
300583	295640	14029X	PARTICIPANT	\N	PRESENT	0
300584	295640	19543W	PARTICIPANT	\N	PRESENT	0
300585	295640	19749K	PARTICIPANT	\N	PRESENT	0
300586	295640	19739H	PARTICIPANT	\N	PRESENT	0
300587	295640	11066Q	PARTICIPANT	\N	PRESENT	0
300588	295640	17779H	PARTICIPANT	\N	PRESENT	0
300589	295640	11048N	PARTICIPANT	\N	PRESENT	0
300590	295640	19511N	PARTICIPANT	\N	PRESENT	0
300591	295640	19413M	PARTICIPANT	\N	PRESENT	0
300592	295640	19503N	PARTICIPANT	\N	PRESENT	0
300593	295640	08019V	PARTICIPANT	\N	PRESENT	0
300594	295640	19367Y	PARTICIPANT	\N	PRESENT	0
300595	295640	14069U	PARTICIPANT	\N	PRESENT	0
300596	295640	19533U	PARTICIPANT	\N	PRESENT	0
300597	295640	14041T	PARTICIPANT	\N	PRESENT	0
300598	295640	19447X	PARTICIPANT	\N	PRESENT	0
300600	295640	08034U	PARTICIPANT	\N	PRESENT	0
300603	295640	11090Q	PARTICIPANT	\N	PRESENT	0
300612	295640	19713W	PARTICIPANT	\N	PRESENT	0
300613	295640	19729F	PARTICIPANT	\N	PRESENT	0
300614	295640	18083K	PARTICIPANT	\N	PRESENT	0
300615	295640	14042U	PARTICIPANT	\N	PRESENT	0
300616	295640	19693L	PARTICIPANT	\N	PRESENT	0
300617	295640	11097X	PARTICIPANT	\N	PRESENT	0
300618	295640	04033B	PARTICIPANT	\N	PRESENT	0
300619	295640	08018U	PARTICIPANT	\N	PRESENT	0
300620	295640	04049K	PARTICIPANT	\N	PRESENT	0
300621	295640	14123H	PARTICIPANT	\N	PRESENT	0
300622	295640	14073Q	PARTICIPANT	\N	PRESENT	0
300623	295640	19295A	PARTICIPANT	\N	PRESENT	0
300624	295640	14157T	PARTICIPANT	\N	PRESENT	0
300625	295640	14217N	PARTICIPANT	\N	PRESENT	0
300626	295640	14195A	PARTICIPANT	\N	PRESENT	0
300627	295640	19515S	PARTICIPANT	\N	PRESENT	0
300628	295640	99004R	PARTICIPANT	\N	PRESENT	0
300629	295640	14357A	PARTICIPANT	\N	PRESENT	0
300630	295640	08015R	PARTICIPANT	\N	PRESENT	0
300631	295640	14215L	PARTICIPANT	\N	PRESENT	0
300632	295640	08010L	PARTICIPANT	\N	PRESENT	0
300633	295640	19643A	PARTICIPANT	\N	PRESENT	0
300634	295640	11085T	PARTICIPANT	\N	PRESENT	0
300635	295640	17637T	PARTICIPANT	\N	PRESENT	0
300637	295640	11101A	PARTICIPANT	\N	PRESENT	0
300640	295640	08068F	PARTICIPANT	\N	PRESENT	0
300641	295640	01058X	PARTICIPANT	\N	PRESENT	0
300642	295640	04044E	PARTICIPANT	\N	PRESENT	0
300643	295640	14249W	PARTICIPANT	\N	PRESENT	0
300644	295640	07029T	PARTICIPANT	\N	PRESENT	0
300648	295640	19683J	PARTICIPANT	\N	PRESENT	0
300649	295640	01043Q	PARTICIPANT	\N	PRESENT	0
300650	295640	14237S	PARTICIPANT	\N	PRESENT	0
300651	295640	14030Q	PARTICIPANT	\N	PRESENT	0
300652	295640	19479G	PARTICIPANT	\N	PRESENT	0
300653	295640	12016W	PARTICIPANT	\N	PRESENT	0
300654	295640	14327T	PARTICIPANT	\N	PRESENT	0
300655	295640	14241N	PARTICIPANT	\N	PRESENT	0
300656	295640	95062K	PARTICIPANT	\N	PRESENT	0
300657	295640	19581D	PARTICIPANT	\N	PRESENT	0
300658	295640	04018C	PARTICIPANT	\N	PRESENT	0
300659	295640	11053K	PARTICIPANT	\N	PRESENT	0
300802	289200	19679N	PARTICIPANT	\N	PRESENT	0
300803	289200	17637T	PARTICIPANT	\N	PRESENT	0
300804	289200	11101A	PARTICIPANT	\N	PRESENT	0
300805	289200	14053L	PARTICIPANT	\N	PRESENT	0
300808	289200	19581D	PARTICIPANT	\N	PRESENT	0
300810	289200	19693L	PARTICIPANT	\N	PRESENT	0
300811	289200	14033T	PARTICIPANT	\N	PRESENT	0
300812	289200	05012A	PARTICIPANT	\N	PRESENT	0
300813	289200	08034U	PARTICIPANT	\N	PRESENT	0
300814	289200	11103C	PARTICIPANT	\N	PRESENT	0
300815	289200	14217N	PARTICIPANT	\N	PRESENT	0
300816	289200	04097T	PARTICIPANT	\N	PRESENT	0
300817	289200	14357A	PARTICIPANT	\N	PRESENT	0
300818	289200	19703U	PARTICIPANT	\N	PRESENT	0
300819	289200	11048N	PARTICIPANT	\N	PRESENT	0
300820	289200	19421M	PARTICIPANT	\N	PRESENT	0
300824	289200	08015R	PARTICIPANT	\N	PRESENT	0
300825	289200	14157T	PARTICIPANT	\N	PRESENT	0
300826	289200	19515S	PARTICIPANT	\N	PRESENT	0
300827	289200	14031R	PARTICIPANT	\N	PRESENT	0
300828	289200	14105F	PARTICIPANT	\N	PRESENT	0
300829	289200	08039A	PARTICIPANT	\N	PRESENT	0
300830	289200	19711U	PARTICIPANT	\N	PRESENT	0
300831	289200	95062K	PARTICIPANT	\N	PRESENT	0
300832	289200	14087W	PARTICIPANT	\N	PRESENT	0
300833	289200	04086Q	PARTICIPANT	\N	PRESENT	0
300834	289200	04033B	PARTICIPANT	\N	PRESENT	0
300835	289200	08010L	PARTICIPANT	\N	PRESENT	0
300836	289200	14079W	PARTICIPANT	\N	PRESENT	0
300837	289200	04042C	PARTICIPANT	\N	PRESENT	0
300838	289200	04035D	PARTICIPANT	\N	PRESENT	0
272154	271621	14115H	PARTICIPANT	\N	PRESENT	0
272155	271621	14030Q	PRESIDENT	0	PRESENT	0
272156	271621	08043V	PARTICIPANT	\N	PRESENT	0
272157	271621	19643A	PARTICIPANT	\N	PRESENT	0
272158	271621	08020N	PARTICIPANT	\N	PRESENT	0
272159	271621	18083K	PARTICIPANT	\N	PRESENT	0
272160	271621	19701S	PARTICIPANT	\N	PRESENT	0
272161	271621	80013X	PARTICIPANT	\N	PRESENT	0
272163	271621	19673G	PARTICIPANT	\N	PRESENT	0
272164	271621	19599P	PARTICIPANT	\N	PRESENT	0
272165	271621	19715Y	PARTICIPANT	\N	PRESENT	0
272167	271621	19731Y	PARTICIPANT	\N	PRESENT	0
272168	271621	08031R	PARTICIPANT	\N	PRESENT	0
272169	271621	07029T	PARTICIPANT	\N	PRESENT	0
272170	271621	08017T	PARTICIPANT	\N	PRESENT	0
272172	271621	14109K	PARTICIPANT	\N	PRESENT	0
272173	271621	19749K	PARTICIPANT	\N	PRESENT	0
272174	271621	19577H	PARTICIPANT	\N	EXCUSE	0
272175	271621	01043Q	PARTICIPANT	\N	EXCUSE	0
272177	271621	19697Q	PARTICIPANT	\N	EXCUSE	0
272178	271621	14235Q	PARTICIPANT	\N	EXCUSE	0
272180	271621	19693L	PARTICIPANT	\N	EXCUSE	0
278178	276033	08039A	PARTICIPANT	\N	EXCUSE	0
278196	276033	11043H	PARTICIPANT	\N	EXCUSE	0
282413	282330	07034Q	PARTICIPANT	\N	PRESENT	0
282414	282331	07034Q	PARTICIPANT	\N	PRESENT	0
282415	282332	07034Q	PARTICIPANT	\N	PRESENT	0
282416	282333	07034Q	PARTICIPANT	\N	PRESENT	0
283189	273895	08031R	PARTICIPANT	\N	PRESENT	0
283190	273895	08016S	PARTICIPANT	\N	PRESENT	0
283191	273895	08069G	PARTICIPANT	\N	PRESENT	0
283192	273895	19253P	PARTICIPANT	\N	PRESENT	0
283193	273895	14261S	PARTICIPANT	\N	PRESENT	0
283194	273895	14259Y	PARTICIPANT	\N	PRESENT	0
283195	273895	19629C	PARTICIPANT	\N	PRESENT	0
283196	273895	08049C	PARTICIPANT	\N	PRESENT	0
283197	273895	01057W	PARTICIPANT	\N	PRESENT	0
283198	273895	11065P	PARTICIPANT	\N	PRESENT	0
283199	273895	19563B	PARTICIPANT	\N	PRESENT	0
283200	273895	87003B	PARTICIPANT	\N	PRESENT	0
283201	273895	14241N	PARTICIPANT	\N	PRESENT	0
283202	273895	98022P	PARTICIPANT	\N	PRESENT	0
283203	273895	19703U	PARTICIPANT	\N	PRESENT	0
283204	273895	19719D	PARTICIPANT	\N	PRESENT	0
283205	273895	19673G	PARTICIPANT	\N	PRESENT	0
283206	273895	11099A	PARTICIPANT	\N	PRESENT	0
283207	273895	88008L	PARTICIPANT	\N	PRESENT	0
283208	273895	14031R	PARTICIPANT	\N	PRESENT	0
283209	273895	19289C	PARTICIPANT	\N	PRESENT	0
283210	273895	19387D	PARTICIPANT	\N	PRESENT	0
283211	273895	19667J	PARTICIPANT	\N	PRESENT	0
283212	273895	14199E	PARTICIPANT	\N	PRESENT	0
283213	273895	19575F	PARTICIPANT	\N	PRESENT	0
283214	273895	19583F	PARTICIPANT	\N	PRESENT	0
283215	273895	11064N	PARTICIPANT	\N	PRESENT	0
283216	273895	98023Q	PARTICIPANT	\N	PRESENT	0
283217	273895	14111D	PARTICIPANT	\N	PRESENT	0
283218	273895	19545Y	PARTICIPANT	\N	PRESENT	0
283219	273895	04049K	PARTICIPANT	\N	PRESENT	0
283220	273895	14251Q	PARTICIPANT	\N	PRESENT	0
283221	273895	14093U	PARTICIPANT	\N	PRESENT	0
283222	273895	08047A	PARTICIPANT	\N	PRESENT	0
283223	273895	14195A	PARTICIPANT	\N	PRESENT	0
283224	273895	14105F	PARTICIPANT	\N	PRESENT	0
283225	273895	14115H	PARTICIPANT	\N	PRESENT	0
283226	273895	04059M	PARTICIPANT	\N	PRESENT	0
283227	273895	11049P	PARTICIPANT	\N	PRESENT	0
283228	273895	11077T	PARTICIPANT	\N	PRESENT	0
283229	273895	14119M	PARTICIPANT	\N	PRESENT	0
283230	273895	11074Q	PARTICIPANT	\N	PRESENT	0
283231	273895	08068F	PARTICIPANT	\N	PRESENT	0
283232	273895	19573D	PARTICIPANT	\N	PRESENT	0
283233	273895	14229S	PARTICIPANT	\N	PRESENT	0
283234	273895	08055A	PARTICIPANT	\N	PRESENT	0
283235	273895	19447X	PARTICIPANT	\N	PRESENT	0
283236	273895	14021P	PARTICIPANT	\N	PRESENT	0
283237	273895	14173T	PARTICIPANT	\N	PRESENT	0
283238	273895	08045X	PARTICIPANT	\N	PRESENT	0
283239	273895	14107H	PARTICIPANT	\N	PRESENT	0
283240	273895	19679N	PARTICIPANT	\N	PRESENT	0
283241	273895	19715Y	PARTICIPANT	\N	PRESENT	0
283242	273895	04071H	PARTICIPANT	\N	PRESENT	0
283243	273895	19647E	PARTICIPANT	\N	PRESENT	0
283244	273895	14038Y	PARTICIPANT	\N	PRESENT	0
283245	273895	14197C	PARTICIPANT	\N	PRESENT	0
283246	273895	19723Y	PARTICIPANT	\N	PRESENT	0
283247	273895	08024S	PARTICIPANT	\N	PRESENT	0
283248	273895	14028W	PARTICIPANT	\N	PRESENT	0
283187	273895	08028W	PARTICIPANT	\N	PRESENT	0
283188	273895	11012A	PARTICIPANT	\N	PRESENT	0
283249	273895	19507S	PARTICIPANT	\N	PRESENT	0
283250	273895	19467C	PARTICIPANT	\N	PRESENT	0
283251	273895	08038Y	PARTICIPANT	\N	PRESENT	0
283252	273895	14065Q	PARTICIPANT	\N	PRESENT	0
283253	273895	19415P	PARTICIPANT	\N	PRESENT	0
283254	273895	19549D	PARTICIPANT	\N	PRESENT	0
283255	273895	11066Q	PARTICIPANT	\N	PRESENT	0
283256	273895	08043V	PARTICIPANT	\N	PRESENT	0
283257	273895	11104D	PARTICIPANT	\N	PRESENT	0
283258	273895	14033T	PARTICIPANT	\N	PRESENT	0
283259	273895	14281W	PARTICIPANT	\N	PRESENT	0
283260	273895	08012N	PARTICIPANT	\N	PRESENT	0
283261	273895	19727D	PARTICIPANT	\N	PRESENT	0
283262	273895	14135M	PARTICIPANT	\N	PRESENT	0
283263	273895	19565D	PARTICIPANT	\N	PRESENT	0
283264	273895	18083K	PARTICIPANT	\N	PRESENT	0
283265	273895	19443T	PARTICIPANT	\N	PRESENT	0
283266	273895	19489J	PARTICIPANT	\N	PRESENT	0
283267	273895	19741B	PARTICIPANT	\N	PRESENT	0
283268	273895	08058D	PARTICIPANT	\N	PRESENT	0
283269	273895	14029X	PARTICIPANT	\N	PRESENT	0
283270	273895	08052W	PARTICIPANT	\N	PRESENT	0
283271	273895	19525U	PARTICIPANT	\N	PRESENT	0
283272	273895	19709B	PARTICIPANT	\N	PRESENT	0
283273	273895	04088S	PARTICIPANT	\N	PRESENT	0
283274	273895	14085U	PARTICIPANT	\N	PRESENT	0
283275	273895	08017T	PARTICIPANT	\N	PRESENT	0
283276	273895	08053X	PARTICIPANT	\N	PRESENT	0
283277	273895	14041T	PARTICIPANT	\N	PRESENT	0
283278	273895	11045K	PARTICIPANT	\N	PRESENT	0
283279	273895	11080N	PARTICIPANT	\N	PRESENT	0
283280	273895	14081Q	PARTICIPANT	\N	PRESENT	0
283281	273895	08018U	PARTICIPANT	\N	PRESENT	0
283282	273895	14159V	PARTICIPANT	\N	PRESENT	0
283283	273895	07029T	PARTICIPANT	\N	PRESENT	0
283284	273895	19657G	PARTICIPANT	\N	PRESENT	0
283285	273895	19333N	PARTICIPANT	\N	PRESENT	0
283286	273895	14001X	PARTICIPANT	\N	PRESENT	0
283287	273895	19725B	PARTICIPANT	\N	PRESENT	0
283288	273895	11054L	PARTICIPANT	\N	PRESENT	0
283289	273895	19689Q	PARTICIPANT	\N	PRESENT	0
283290	273895	19399H	PARTICIPANT	\N	PRESENT	0
283291	273895	19413M	PARTICIPANT	\N	PRESENT	0
283292	273895	19693L	PARTICIPANT	\N	PRESENT	0
283293	273895	19251M	PARTICIPANT	\N	PRESENT	0
283294	273895	19591F	PARTICIPANT	\N	PRESENT	0
283295	273895	19729F	PARTICIPANT	\N	PRESENT	0
283296	273895	11067R	PARTICIPANT	\N	PRESENT	0
283297	273895	14265W	PARTICIPANT	\N	PRESENT	0
283298	273895	19631V	PARTICIPANT	\N	PRESENT	0
283299	273895	14213J	PARTICIPANT	\N	PRESENT	0
283300	273895	19669L	PARTICIPANT	\N	PRESENT	0
283301	273895	92040Q	PARTICIPANT	\N	PRESENT	0
283302	273895	14097Y	PARTICIPANT	\N	PRESENT	0
283303	273895	14257W	PARTICIPANT	\N	PRESENT	0
283304	273895	08015R	PARTICIPANT	\N	PRESENT	0
283305	273895	11027H	PARTICIPANT	\N	PRESENT	0
283306	273895	01060R	PARTICIPANT	\N	PRESENT	0
283307	273895	14055N	PARTICIPANT	\N	PRESENT	0
283308	273895	14030Q	PARTICIPANT	\N	PRESENT	0
283309	273895	04089T	PARTICIPANT	\N	PRESENT	0
283310	273895	14231L	PARTICIPANT	\N	PRESENT	0
283311	273895	14179A	PARTICIPANT	\N	PRESENT	0
283312	273895	08062Y	PARTICIPANT	\N	PRESENT	0
283313	273895	19369B	PARTICIPANT	\N	PRESENT	0
283314	273895	19691J	PARTICIPANT	\N	PRESENT	0
283315	273895	19707Y	PARTICIPANT	\N	PRESENT	0
283316	273895	01034P	PARTICIPANT	\N	PRESENT	0
283317	273895	19705W	PARTICIPANT	\N	PRESENT	0
283318	273895	19511N	PARTICIPANT	\N	PRESENT	0
283319	273895	19619A	PARTICIPANT	\N	PRESENT	0
283320	273895	19721W	PARTICIPANT	\N	PRESENT	0
283321	273895	04035D	PARTICIPANT	\N	PRESENT	0
283322	273895	19569H	PARTICIPANT	\N	PRESENT	0
283323	273895	08056B	PARTICIPANT	\N	PRESENT	0
283324	273895	19611R	PARTICIPANT	\N	PRESENT	0
283325	273895	19735D	PARTICIPANT	\N	PRESENT	0
283326	273895	98024R	PARTICIPANT	\N	PRESENT	0
283327	273895	16685X	PARTICIPANT	\N	PRESENT	0
272666	272664	14093U	PARTICIPANT	\N	PRESENT	0
272667	272664	11026G	PARTICIPANT	\N	PRESENT	0
272668	272664	08009T	PARTICIPANT	\N	PRESENT	0
272669	272664	14169X	PARTICIPANT	\N	PRESENT	0
272679	272664	19739H	PARTICIPANT	\N	PRESENT	0
272680	272664	19713W	PARTICIPANT	\N	PRESENT	0
272681	272664	19737F	PARTICIPANT	\N	PRESENT	0
273398	263481	04059M	PARTICIPANT	\N	PRESENT	0
273403	263481	14227Q	PARTICIPANT	\N	PRESENT	0
273404	263481	19727D	PARTICIPANT	\N	PRESENT	0
273405	263481	04045F	PARTICIPANT	\N	PRESENT	0
273406	263481	04057K	PARTICIPANT	\N	PRESENT	0
273407	263481	19553Y	PARTICIPANT	\N	PRESENT	0
273408	263481	07029T	PARTICIPANT	\N	PRESENT	0
273409	263481	19515S	PARTICIPANT	\N	PRESENT	0
273410	263481	19671E	PARTICIPANT	\N	PRESENT	0
273411	263481	19581D	PARTICIPANT	\N	PRESENT	0
273412	263481	19711U	PARTICIPANT	\N	PRESENT	0
273413	263481	19441R	PARTICIPANT	\N	PRESENT	0
273414	263481	19715Y	PARTICIPANT	\N	PRESENT	0
273415	263481	95062K	PARTICIPANT	\N	PRESENT	0
273416	263481	99004R	PARTICIPANT	\N	PRESENT	0
273417	263481	14219Q	PARTICIPANT	\N	PRESENT	0
273418	263481	01034P	PARTICIPANT	\N	PRESENT	0
273419	263481	17637T	PARTICIPANT	\N	PRESENT	0
273420	263481	14042U	PARTICIPANT	\N	PRESENT	0
273428	263481	19697Q	PARTICIPANT	\N	PRESENT	0
273429	263481	18083K	PARTICIPANT	\N	PRESENT	0
273430	263481	14231L	PARTICIPANT	\N	PRESENT	0
273431	263481	11031D	PARTICIPANT	\N	PRESENT	0
273432	263481	14259Y	PARTICIPANT	\N	PRESENT	0
273433	263481	19611R	PARTICIPANT	\N	PRESENT	0
273437	263481	11083R	PARTICIPANT	\N	PRESENT	0
273438	263481	11097X	PARTICIPANT	\N	PRESENT	0
273439	263481	96004D	PARTICIPANT	\N	PRESENT	0
273440	263481	19507S	PARTICIPANT	\N	PRESENT	0
273441	263481	14135M	PARTICIPANT	\N	PRESENT	0
273451	263481	19695N	PARTICIPANT	\N	PRESENT	0
273452	263481	01024M	PARTICIPANT	\N	PRESENT	0
273453	263481	11115U	PARTICIPANT	\N	PRESENT	0
273454	263481	08017T	PARTICIPANT	\N	PRESENT	0
273459	263481	19741B	PARTICIPANT	\N	PRESENT	0
273463	263481	14239U	PARTICIPANT	\N	PRESENT	0
273464	263481	04034C	PARTICIPANT	\N	PRESENT	0
273465	263481	19683J	PARTICIPANT	\N	PRESENT	0
273493	263482	11083R	PARTICIPANT	\N	PRESENT	0
273498	263482	01048V	PARTICIPANT	\N	PRESENT	0
273499	263482	14219Q	PARTICIPANT	\N	PRESENT	0
273500	263482	96004D	PARTICIPANT	\N	PRESENT	0
273501	263482	07029T	PARTICIPANT	\N	PRESENT	0
273502	263482	19295A	PARTICIPANT	\N	PRESENT	0
273503	263482	04034C	PARTICIPANT	\N	PRESENT	0
273504	263482	01024M	PARTICIPANT	\N	PRESENT	0
273505	263482	19515S	PARTICIPANT	\N	PRESENT	0
273506	263482	14034U	PARTICIPANT	\N	PRESENT	0
273507	263482	08073C	PARTICIPANT	\N	PRESENT	0
273508	263482	19441R	PARTICIPANT	\N	PRESENT	0
273509	263482	04057K	PARTICIPANT	\N	PRESENT	0
273510	263482	19507S	PARTICIPANT	\N	PRESENT	0
273511	263482	19549D	PARTICIPANT	\N	PRESENT	0
273512	263482	19671E	PARTICIPANT	\N	PRESENT	0
273513	263482	19715Y	PARTICIPANT	\N	PRESENT	0
273526	263482	19691J	PARTICIPANT	\N	PRESENT	0
273527	263482	14083S	PARTICIPANT	\N	PRESENT	0
273528	263482	12016W	PARTICIPANT	\N	PRESENT	0
273529	263482	14079W	PARTICIPANT	\N	PRESENT	0
273489	263482	04059M	PARTICIPANT	\N	PRESENT	0
273492	263482	19695N	PARTICIPANT	\N	PRESENT	0
273530	263482	14225N	PARTICIPANT	\N	PRESENT	0
273531	263482	19253P	PARTICIPANT	\N	PRESENT	0
289309	289087	19689Q	PARTICIPANT	\N	PRESENT	0
289310	289087	19671E	PARTICIPANT	\N	PRESENT	0
289311	289087	14229S	PARTICIPANT	\N	PRESENT	0
289312	289087	04034C	PARTICIPANT	\N	PRESENT	0
289314	289087	19591F	PARTICIPANT	\N	PRESENT	0
289315	289087	11109J	PARTICIPANT	\N	PRESENT	0
289316	289087	14123H	PARTICIPANT	\N	PRESENT	0
289317	289087	04044E	PARTICIPANT	\N	PRESENT	0
289318	289087	95063L	PARTICIPANT	\N	PRESENT	0
289307	289087	99004R	PARTICIPANT	\N	PRESENT	0
289308	289087	19347U	PARTICIPANT	\N	PRESENT	0
289319	289087	14065Q	PARTICIPANT	\N	PRESENT	0
289320	289087	14001X	PARTICIPANT	\N	PRESENT	0
289321	289087	19699S	PARTICIPANT	\N	PRESENT	0
289322	289087	19691J	PARTICIPANT	\N	PRESENT	0
289327	289087	08018U	PARTICIPANT	\N	PRESENT	0
289328	289087	19707Y	PARTICIPANT	\N	PRESENT	0
289329	289087	19705W	PARTICIPANT	\N	PRESENT	0
289330	289087	11097X	PARTICIPANT	\N	PRESENT	0
289331	289087	11027H	PARTICIPANT	\N	PRESENT	0
289332	289087	14357A	PARTICIPANT	\N	PRESENT	0
289333	289087	19741B	PARTICIPANT	\N	PRESENT	0
289334	289087	04040A	PARTICIPANT	\N	PRESENT	0
289335	289087	19295A	PARTICIPANT	\N	PRESENT	0
289336	289087	19573D	PARTICIPANT	\N	PRESENT	0
289337	289087	19329S	PARTICIPANT	\N	PRESENT	0
289338	282453	11109J	PARTICIPANT	\N	PRESENT	0
289339	282453	11033F	PARTICIPANT	\N	EXCUSE	0
289340	282453	19295A	PARTICIPANT	\N	PRESENT	0
289341	282453	14097Y	PARTICIPANT	\N	PRESENT	0
289342	282453	14039A	PARTICIPANT	\N	PRESENT	0
289343	282453	19715Y	PARTICIPANT	\N	PRESENT	0
289344	282453	08019V	PRESIDENT	0	PRESENT	0
289345	282453	08073C	PARTICIPANT	\N	PRESENT	0
289346	282453	11072N	PARTICIPANT	\N	PRESENT	0
289347	282453	08016S	PARTICIPANT	\N	PRESENT	0
289348	282453	14059S	PARTICIPANT	\N	PRESENT	0
289349	282453	19703U	PARTICIPANT	\N	PRESENT	0
289350	282453	19301E	PARTICIPANT	\N	PRESENT	0
289351	289087	11053K	PARTICIPANT	\N	PRESENT	0
289352	289087	14331P	PARTICIPANT	\N	PRESENT	0
289415	289088	04047H	PARTICIPANT	\N	PRESENT	0
289417	289416	96004D	PARTICIPANT	\N	PRESENT	0
289419	289418	14133K	PARTICIPANT	\N	PRESENT	0
289420	289418	96004D	PARTICIPANT	\N	PRESENT	0
289421	289088	14030Q	PARTICIPANT	\N	PRESENT	0
289422	289088	11026G	PARTICIPANT	\N	PRESENT	0
289423	289088	19711U	PARTICIPANT	\N	PRESENT	0
289424	289088	11070L	PARTICIPANT	\N	PRESENT	0
289425	289088	19699S	PARTICIPANT	\N	PRESENT	0
289426	289088	19705W	PARTICIPANT	\N	PRESENT	0
289427	289088	19683J	PARTICIPANT	\N	PRESENT	0
289428	289088	19593H	PARTICIPANT	\N	PRESENT	0
289429	289088	14261S	PARTICIPANT	\N	PRESENT	0
289430	289088	19399H	PARTICIPANT	\N	PRESENT	0
289431	289088	11090Q	PARTICIPANT	\N	PRESENT	0
289432	289088	14331P	PARTICIPANT	\N	PRESENT	0
289433	289088	04059M	PARTICIPANT	\N	PRESENT	0
289434	289088	19649G	PARTICIPANT	\N	PRESENT	0
289435	289088	11097X	PARTICIPANT	\N	PRESENT	0
289436	289088	11033F	PARTICIPANT	\N	PRESENT	0
289437	289088	19689Q	PARTICIPANT	\N	PRESENT	0
289438	289088	14215L	PARTICIPANT	\N	PRESENT	0
289439	289088	19667J	PARTICIPANT	\N	PRESENT	0
289440	289088	19671E	PARTICIPANT	\N	PRESENT	0
289441	289088	19747H	PARTICIPANT	\N	PRESENT	0
289442	289088	19611R	PARTICIPANT	\N	PRESENT	0
289443	289088	01048V	PARTICIPANT	\N	PRESENT	0
289444	289088	11072N	PARTICIPANT	\N	PRESENT	0
289445	289088	14042U	PARTICIPANT	\N	PRESENT	0
289446	289088	19329S	PARTICIPANT	\N	PRESENT	0
289447	289088	19669L	PARTICIPANT	\N	PRESENT	0
289448	289088	99004R	PARTICIPANT	\N	PRESENT	0
289449	289088	14039A	PARTICIPANT	\N	PRESENT	0
289450	289088	19693L	PARTICIPANT	\N	PRESENT	0
289451	289088	11031D	PARTICIPANT	\N	PRESENT	0
289452	289088	11053K	PARTICIPANT	\N	PRESENT	0
289454	289088	14123H	PARTICIPANT	\N	PRESENT	0
289455	289088	14217N	PARTICIPANT	\N	PRESENT	0
289456	289088	19591F	PARTICIPANT	\N	PRESENT	0
289457	289088	19741B	PARTICIPANT	\N	PRESENT	0
289458	289088	19573D	PARTICIPANT	\N	PRESENT	0
289459	289088	14357A	PARTICIPANT	\N	PRESENT	0
289460	289088	95063L	PARTICIPANT	\N	PRESENT	0
289461	289088	19651A	PARTICIPANT	\N	PRESENT	0
289462	289088	01028R	PARTICIPANT	\N	PRESENT	0
289463	289088	08019V	PARTICIPANT	\N	PRESENT	0
289464	289088	19691J	PARTICIPANT	\N	PRESENT	0
289465	289088	19647E	PARTICIPANT	\N	PRESENT	0
289466	289088	04018C	PARTICIPANT	\N	PRESENT	0
289467	289088	19643A	PARTICIPANT	\N	PRESENT	0
289469	289088	14065Q	PARTICIPANT	\N	PRESENT	0
289470	289088	19295A	PARTICIPANT	\N	PRESENT	0
289472	289088	19707Y	PARTICIPANT	\N	PRESENT	0
289473	289088	14255U	PARTICIPANT	\N	PRESENT	0
289413	289088	04044E	PARTICIPANT	\N	PRESENT	0
289414	289088	05008E	PARTICIPANT	\N	PRESENT	0
289474	289088	19687N	PARTICIPANT	\N	PRESENT	0
278426	278425	96004D	PARTICIPANT	\N	PRESENT	0
278427	278425	14255U	PARTICIPANT	\N	PRESENT	0
278428	278425	04042C	PARTICIPANT	\N	EXCUSE	0
278429	278425	19251M	PARTICIPANT	\N	EXCUSE	0
278430	278425	04035D	PARTICIPANT	\N	PRESENT	0
278431	278425	04097T	PARTICIPANT	\N	EXCUSE	0
278432	278425	19709B	PARTICIPANT	\N	PRESENT	0
278433	278425	14001X	PARTICIPANT	\N	EXCUSE	0
278434	278425	98050T	PARTICIPANT	\N	PRESENT	0
278435	278425	01062T	PARTICIPANT	\N	PRESENT	0
278436	278425	04034C	PARTICIPANT	\N	PRESENT	0
281752	281751	14239U	PARTICIPANT	\N	PRESENT	0
281753	281751	19253P	PARTICIPANT	\N	PRESENT	0
281754	281751	14031R	PARTICIPANT	\N	PRESENT	0
281755	281751	11067R	PARTICIPANT	\N	PRESENT	0
281756	281751	14119M	PARTICIPANT	\N	PRESENT	0
281757	281751	19319Q	PARTICIPANT	\N	PRESENT	0
281758	281751	04044E	PRESIDENT	0	PRESENT	0
282441	282440	07004J	PARTICIPANT	\N	PRESENT	0
282442	282440	14219Q	PARTICIPANT	\N	PRESENT	0
282443	282440	19713W	PARTICIPANT	\N	PRESENT	0
282444	282440	19737F	PARTICIPANT	\N	PRESENT	0
284217	284216	14239U	PARTICIPANT	\N	PRESENT	0
284218	284216	19253P	PRESIDENT	0	PRESENT	0
284219	284216	14217N	PARTICIPANT	\N	PRESENT	0
284220	284216	14087W	PARTICIPANT	\N	EXCUSE	0
284221	284216	14031R	PARTICIPANT	\N	PRESENT	0
284222	284216	11067R	PARTICIPANT	\N	PRESENT	0
284223	284216	14223L	PARTICIPANT	\N	PRESENT	0
284224	284216	04044E	PARTICIPANT	\N	EXCUSE	0
286570	273912	08039A	PARTICIPANT	\N	PRESENT	0
286571	273912	08010L	PARTICIPANT	\N	PRESENT	0
286572	273912	88008L	PARTICIPANT	\N	PRESENT	0
286573	273912	19335Q	PARTICIPANT	\N	PRESENT	0
286574	273912	01024M	PARTICIPANT	\N	PRESENT	0
286575	273912	14119M	PARTICIPANT	\N	PRESENT	0
286576	273912	14061L	PARTICIPANT	\N	PRESENT	0
286577	273912	19543W	PARTICIPANT	\N	PRESENT	0
286578	273912	04071H	PARTICIPANT	\N	PRESENT	0
286579	273912	04061F	PARTICIPANT	\N	PRESENT	0
286580	273912	19749K	PARTICIPANT	\N	PRESENT	0
286581	273912	08062Y	PARTICIPANT	\N	PRESENT	0
286582	273912	14030Q	PARTICIPANT	\N	PRESENT	0
286583	273912	19511N	PARTICIPANT	\N	PRESENT	0
286584	273912	19549D	PARTICIPANT	\N	PRESENT	0
286585	273912	08053X	PARTICIPANT	\N	PRESENT	0
286586	273912	08069G	PARTICIPANT	\N	PRESENT	0
286587	273912	11012A	PARTICIPANT	\N	PRESENT	0
286588	273912	19447X	PARTICIPANT	\N	PRESENT	0
286591	273912	14085U	PARTICIPANT	\N	PRESENT	0
286593	273912	08073C	PARTICIPANT	\N	PRESENT	0
286594	273912	19663E	PARTICIPANT	\N	PRESENT	0
286595	273912	14179A	PARTICIPANT	\N	PRESENT	0
286596	273912	14221J	PARTICIPANT	\N	PRESENT	0
286597	273912	19703U	PARTICIPANT	\N	PRESENT	0
286598	273912	08019V	PARTICIPANT	\N	PRESENT	0
286599	273912	19521Q	PARTICIPANT	\N	PRESENT	0
286600	273912	19681G	PARTICIPANT	\N	PRESENT	0
286601	273912	14225N	PARTICIPANT	\N	PRESENT	0
286602	273912	14041T	PARTICIPANT	\N	PRESENT	0
286603	273912	19717B	PARTICIPANT	\N	PRESENT	0
286604	273912	14051J	PARTICIPANT	\N	PRESENT	0
286605	273912	14195A	PARTICIPANT	\N	PRESENT	0
286606	273912	01058X	PARTICIPANT	\N	PRESENT	0
286607	273912	08044W	PARTICIPANT	\N	PRESENT	0
286608	273912	11099A	PARTICIPANT	\N	PRESENT	0
286609	273912	14173T	PARTICIPANT	\N	PRESENT	0
286610	273912	16685X	PARTICIPANT	\N	PRESENT	0
286611	273912	19479G	PARTICIPANT	\N	PRESENT	0
286612	273912	19573D	PARTICIPANT	\N	PRESENT	0
286613	273912	11056N	PARTICIPANT	\N	PRESENT	0
286614	273912	19551W	PARTICIPANT	\N	PRESENT	0
286615	273912	11097X	PARTICIPANT	\N	PRESENT	0
286616	273912	14053L	PARTICIPANT	\N	PRESENT	0
286617	273912	14211G	PARTICIPANT	\N	PRESENT	0
286618	273912	14105F	PARTICIPANT	\N	PRESENT	0
286626	273912	19441R	PARTICIPANT	\N	PRESENT	0
286627	286589	04070G	PRESIDENT	0	PRESENT	0
286628	286589	19699S	PARTICIPANT	\N	PRESENT	0
286629	286589	19533U	PARTICIPANT	\N	PRESENT	0
286630	286589	19611R	PARTICIPANT	\N	PRESENT	0
286631	286589	08043V	PARTICIPANT	\N	PRESENT	0
286632	286589	87003B	PARTICIPANT	\N	PRESENT	0
286633	286589	19399H	PARTICIPANT	\N	PRESENT	0
286634	286589	14229S	PARTICIPANT	\N	PRESENT	0
286635	286589	14241N	PARTICIPANT	\N	PRESENT	0
286636	286589	19731Y	PARTICIPANT	\N	PRESENT	0
286637	286589	19573D	PARTICIPANT	\N	PRESENT	0
286638	286589	19735D	PARTICIPANT	\N	PRESENT	0
286639	286589	11083R	PARTICIPANT	\N	PRESENT	0
286640	286589	14063N	PARTICIPANT	\N	PRESENT	0
286641	286589	07033P	PARTICIPANT	\N	PRESENT	0
286642	286589	08012N	PARTICIPANT	\N	PRESENT	0
286643	286589	11104D	PARTICIPANT	\N	PRESENT	0
286644	286589	19749K	PARTICIPANT	\N	PRESENT	0
286645	286589	08016S	PARTICIPANT	\N	PRESENT	0
286646	286589	08039A	PARTICIPANT	\N	PRESENT	0
286647	286589	08031R	PARTICIPANT	\N	PRESENT	0
286649	273912	98029W	PARTICIPANT	\N	PRESENT	0
286658	273912	17589D	PARTICIPANT	\N	PRESENT	0
286659	273912	14111D	PARTICIPANT	\N	PRESENT	0
286660	273912	04043D	PARTICIPANT	\N	PRESENT	0
286661	273912	14201E	PARTICIPANT	\N	PRESENT	0
286662	273912	14029X	PARTICIPANT	\N	PRESENT	0
286663	273912	14147R	PARTICIPANT	\N	PRESENT	0
286664	273912	19697Q	PARTICIPANT	\N	PRESENT	0
286665	273912	12041X	PARTICIPANT	\N	PRESENT	0
286666	273912	04045F	PARTICIPANT	\N	PRESENT	0
286667	273912	14327T	PARTICIPANT	\N	PRESENT	0
286668	273912	19489J	PARTICIPANT	\N	PRESENT	0
286672	273912	04033B	PARTICIPANT	\N	PRESENT	0
286673	273912	11027H	PARTICIPANT	\N	PRESENT	0
286674	273912	14034U	PARTICIPANT	\N	PRESENT	0
286675	273912	10015M	PARTICIPANT	\N	PRESENT	0
286676	273912	14219Q	PARTICIPANT	\N	PRESENT	0
286677	273912	14079W	PARTICIPANT	\N	PRESENT	0
286678	273912	80013X	PARTICIPANT	\N	PRESENT	0
286694	286589	14107H	PARTICIPANT	\N	PRESENT	0
286695	286589	08018U	PARTICIPANT	\N	PRESENT	0
286696	286589	14249W	PARTICIPANT	\N	PRESENT	0
286697	286589	19643A	PARTICIPANT	\N	PRESENT	0
286698	286589	14073Q	PARTICIPANT	\N	PRESENT	0
286699	286589	19693L	PARTICIPANT	\N	PRESENT	0
286700	286589	14030Q	PARTICIPANT	\N	PRESENT	0
286701	286589	14251Q	PARTICIPANT	\N	PRESENT	0
286702	286589	19621T	PARTICIPANT	\N	PRESENT	0
286703	286589	14059S	PARTICIPANT	\N	EXCUSE	0
286704	286589	04059M	PARTICIPANT	\N	EXCUSE	0
286705	273912	14073Q	PARTICIPANT	\N	PRESENT	0
286706	273912	19611R	PARTICIPANT	\N	PRESENT	0
286707	273912	04088S	PARTICIPANT	\N	PRESENT	0
286708	273912	14042U	PARTICIPANT	\N	PRESENT	0
287013	286235	08009T	PRESIDENT	0	PRESENT	0
287014	286235	19685L	PARTICIPANT	\N	EXCUSE	0
287015	286235	19681G	PARTICIPANT	\N	EXCUSE	0
287016	286590	04070G	PRESIDENT	0	PRESENT	0
287017	286590	19699S	PARTICIPANT	\N	PRESENT	0
287018	286590	19533U	PARTICIPANT	\N	PRESENT	0
287019	286590	95015C	PARTICIPANT	\N	PRESENT	0
287020	286590	04033B	PARTICIPANT	\N	PRESENT	0
287021	286590	14241N	PARTICIPANT	\N	PRESENT	0
287022	286590	19573D	PARTICIPANT	\N	PRESENT	0
287023	286590	14039A	PARTICIPANT	\N	PRESENT	0
287024	286590	14107H	PARTICIPANT	\N	PRESENT	0
287025	286590	08017T	PARTICIPANT	\N	PRESENT	0
287026	286590	92040Q	PARTICIPANT	\N	PRESENT	0
287027	286590	08012N	PARTICIPANT	\N	PRESENT	0
287028	286590	14249W	PARTICIPANT	\N	PRESENT	0
287029	286590	08039A	PARTICIPANT	\N	PRESENT	0
287030	286590	08031R	PARTICIPANT	\N	PRESENT	0
287031	286590	14061L	PARTICIPANT	\N	PRESENT	0
287032	286590	04057K	PARTICIPANT	\N	PRESENT	0
287033	286590	14073Q	PARTICIPANT	\N	PRESENT	0
287034	286590	19611R	PARTICIPANT	\N	PRESENT	0
287035	286590	08035V	PARTICIPANT	\N	PRESENT	0
287036	286590	08043V	PARTICIPANT	\N	PRESENT	0
287037	286590	19399H	PARTICIPANT	\N	PRESENT	0
287038	286590	14201E	PARTICIPANT	\N	PRESENT	0
287039	286590	19731Y	PARTICIPANT	\N	PRESENT	0
287040	286590	08020N	PARTICIPANT	\N	PRESENT	0
287041	286590	14109K	PARTICIPANT	\N	PRESENT	0
287042	286590	11104D	PARTICIPANT	\N	PRESENT	0
287043	286590	04018C	PARTICIPANT	\N	PRESENT	0
287044	286590	19621T	PARTICIPANT	\N	PRESENT	0
287045	286590	14059S	PARTICIPANT	\N	PRESENT	0
287046	286590	14229S	PARTICIPANT	\N	EXCUSE	0
287047	286590	14030Q	PARTICIPANT	\N	PRESENT	0
287048	286590	07033P	PARTICIPANT	\N	PRESENT	0
287049	286590	87003B	PARTICIPANT	\N	PRESENT	0
272115	270525	19583F	PARTICIPANT	\N	EXCUSE	0
276027	276026	14041T	PARTICIPANT	\N	PRESENT	0
300841	289200	11080N	PARTICIPANT	\N	PRESENT	0
300842	289200	04085P	PARTICIPANT	\N	PRESENT	0
300843	289200	11056N	PARTICIPANT	\N	PRESENT	0
300844	289200	19667J	PARTICIPANT	\N	PRESENT	0
300845	289200	19447X	PARTICIPANT	\N	PRESENT	0
300846	289200	19399H	PARTICIPANT	\N	PRESENT	0
300847	289200	19760E	PARTICIPANT	\N	PRESENT	0
300848	289200	19695N	PARTICIPANT	\N	PRESENT	0
300849	289200	04034C	PARTICIPANT	\N	PRESENT	0
300850	289200	08061X	PARTICIPANT	\N	PRESENT	0
300851	289200	19651A	PARTICIPANT	\N	PRESENT	0
300852	289200	19697Q	PARTICIPANT	\N	PRESENT	0
300853	289200	14039A	PARTICIPANT	\N	PRESENT	0
300854	289200	08024S	PARTICIPANT	\N	PRESENT	0
300855	289200	19659J	PARTICIPANT	\N	PRESENT	0
300856	289200	19415P	PARTICIPANT	\N	PRESENT	0
300857	289200	95037J	PARTICIPANT	\N	PRESENT	0
300858	289200	19723Y	PARTICIPANT	\N	PRESENT	0
300859	289200	14111D	PARTICIPANT	\N	PRESENT	0
300860	289200	14038Y	PARTICIPANT	\N	PRESENT	0
300861	289200	14251Q	PARTICIPANT	\N	PRESENT	0
300862	289200	19585H	PARTICIPANT	\N	PRESENT	0
300863	289200	19507S	PARTICIPANT	\N	PRESENT	0
300864	289200	04008A	PARTICIPANT	\N	PRESENT	0
300865	289200	19593H	PARTICIPANT	\N	PRESENT	0
300866	289200	11012A	PARTICIPANT	\N	PRESENT	0
300867	289200	18083K	PARTICIPANT	\N	PRESENT	0
300868	289200	08016S	PARTICIPANT	\N	PRESENT	0
300869	289200	14034U	PARTICIPANT	\N	PRESENT	0
300880	289200	04071H	PARTICIPANT	\N	PRESENT	0
300871	289200	04088S	PARTICIPANT	\N	PRESENT	0
300872	289200	14241N	PARTICIPANT	\N	PRESENT	0
300873	289200	19563B	PARTICIPANT	\N	PRESENT	0
300874	289200	14041T	PARTICIPANT	\N	PRESENT	0
300971	289200	05008E	PARTICIPANT	\N	PRESENT	0
300876	289200	19719D	PARTICIPANT	\N	PRESENT	0
300877	289200	19681G	PARTICIPANT	\N	PRESENT	0
300878	289200	10015M	PARTICIPANT	\N	PRESENT	0
300879	289200	19657G	PARTICIPANT	\N	PRESENT	0
300881	289200	19745F	PARTICIPANT	\N	PRESENT	0
300882	289200	04059M	PARTICIPANT	\N	PRESENT	0
300883	289200	14123H	PARTICIPANT	\N	PRESENT	0
300884	289200	14159V	PARTICIPANT	\N	PRESENT	0
300885	289200	11074Q	PARTICIPANT	\N	PRESENT	0
300886	289200	14051J	PARTICIPANT	\N	PRESENT	0
300887	289200	19707Y	PARTICIPANT	\N	PRESENT	0
300888	289200	08068F	PARTICIPANT	\N	PRESENT	0
300889	289200	01028R	PARTICIPANT	\N	PRESENT	0
300890	289200	14229S	PARTICIPANT	\N	PRESENT	0
300891	289200	19729F	PARTICIPANT	\N	PRESENT	0
300892	289200	14021P	PARTICIPANT	\N	PRESENT	0
300893	289200	19669L	PARTICIPANT	\N	PRESENT	0
300894	289200	14331P	PARTICIPANT	\N	PRESENT	0
300895	289200	19599P	PARTICIPANT	\N	PRESENT	0
300896	289200	12016W	PARTICIPANT	\N	PRESENT	0
300897	289200	08019V	PARTICIPANT	\N	PRESENT	0
300898	289200	19649G	PARTICIPANT	\N	PRESENT	0
300899	289200	11045K	PARTICIPANT	\N	PRESENT	0
300900	289200	19647E	PARTICIPANT	\N	PRESENT	0
300901	289200	14265W	PARTICIPANT	\N	PRESENT	0
300902	289200	80013X	PARTICIPANT	\N	PRESENT	0
300903	289200	08060W	PARTICIPANT	\N	PRESENT	0
300904	289200	08038Y	PARTICIPANT	\N	PRESENT	0
300905	289200	11066Q	PARTICIPANT	\N	PRESENT	0
300906	289200	11090Q	PARTICIPANT	\N	PRESENT	0
300907	289200	19689Q	PARTICIPANT	\N	PRESENT	0
300908	289200	14069U	PARTICIPANT	\N	PRESENT	0
300909	289200	08012N	PARTICIPANT	\N	PRESENT	0
300910	289200	19565D	PARTICIPANT	\N	PRESENT	0
300911	289200	11041F	PARTICIPANT	\N	PRESENT	0
300912	289200	04049K	PARTICIPANT	\N	PRESENT	0
300913	289200	17779H	PARTICIPANT	\N	PRESENT	0
300914	289200	19489J	PARTICIPANT	\N	PRESENT	0
300915	289200	19741B	PARTICIPANT	\N	PRESENT	0
300916	289200	14085U	PARTICIPANT	\N	PRESENT	0
300917	289200	11026G	PARTICIPANT	\N	PRESENT	0
300918	289200	19525U	PARTICIPANT	\N	PRESENT	0
300919	289200	19549D	PARTICIPANT	\N	PRESENT	0
300920	289200	19443T	PARTICIPANT	\N	PRESENT	0
300921	289200	08058D	PARTICIPANT	\N	PRESENT	0
300922	289200	19683J	PARTICIPANT	\N	PRESENT	0
300923	289200	11054L	PARTICIPANT	\N	PRESENT	0
300924	289200	11067R	PARTICIPANT	\N	PRESENT	0
300925	289200	19551W	PARTICIPANT	\N	PRESENT	0
300926	289200	97011G	PARTICIPANT	\N	PRESENT	0
300927	289200	14207L	PARTICIPANT	\N	PRESENT	0
300928	289200	11077T	PARTICIPANT	\N	PRESENT	0
300929	289200	14257W	PARTICIPANT	\N	PRESENT	0
300930	289200	07033P	PARTICIPANT	\N	PRESENT	0
300839	289200	11033F	PARTICIPANT	\N	PRESENT	0
300840	289200	14235Q	PARTICIPANT	\N	PRESENT	0
300931	289200	14071N	PARTICIPANT	\N	PRESENT	0
300932	289200	04057K	PARTICIPANT	\N	PRESENT	0
300933	289200	14093U	PARTICIPANT	\N	PRESENT	0
300934	289200	14187A	PARTICIPANT	\N	PRESENT	0
300935	289200	19479G	PARTICIPANT	\N	PRESENT	0
300936	289200	14073Q	PARTICIPANT	\N	PRESENT	0
300937	289200	14267Y	PARTICIPANT	\N	PRESENT	0
300938	289200	14231L	PARTICIPANT	\N	PRESENT	0
300939	289200	01043Q	PARTICIPANT	\N	PRESENT	0
300940	289200	04047H	PARTICIPANT	\N	PRESENT	0
300941	289200	14030Q	PARTICIPANT	\N	PRESENT	0
300942	289200	01024M	PARTICIPANT	\N	PRESENT	0
300943	289200	14119M	PARTICIPANT	\N	PRESENT	0
300944	289200	11070L	PARTICIPANT	\N	PRESENT	0
300945	289200	14255U	PARTICIPANT	\N	PRESENT	0
300946	289200	19369B	PARTICIPANT	\N	PRESENT	0
300947	289200	19611R	PARTICIPANT	\N	PRESENT	0
300948	289200	19699S	PARTICIPANT	\N	PRESENT	0
300949	289200	98024R	PARTICIPANT	\N	PRESENT	0
300950	289200	19511N	PARTICIPANT	\N	PRESENT	0
300951	289200	19619A	PARTICIPANT	\N	PRESENT	0
300952	289200	14205J	PARTICIPANT	\N	PRESENT	0
300953	289200	11072N	PARTICIPANT	\N	PRESENT	0
300954	289200	19737F	PARTICIPANT	\N	PRESENT	0
300955	289200	04044E	PARTICIPANT	\N	PRESENT	0
300956	289200	16685X	PARTICIPANT	\N	PRESENT	0
300957	289200	19717B	PARTICIPANT	\N	PRESENT	0
300958	289200	11097X	PARTICIPANT	\N	PRESENT	0
300959	289200	19713W	PARTICIPANT	\N	PRESENT	0
300960	289200	14042U	PARTICIPANT	\N	PRESENT	0
300961	289200	14083S	PARTICIPANT	\N	PRESENT	0
300962	289200	14215L	PARTICIPANT	\N	PRESENT	0
300963	289200	19739H	PARTICIPANT	\N	PRESENT	0
300964	289200	19335Q	PARTICIPANT	\N	PRESENT	0
300965	289200	04061F	PARTICIPANT	\N	PRESENT	0
300966	289200	19687N	PARTICIPANT	\N	PRESENT	0
300967	289200	12041X	PARTICIPANT	\N	PRESENT	0
300968	289200	14193X	PARTICIPANT	\N	PRESENT	0
300969	289200	14219Q	PARTICIPANT	\N	PRESENT	0
300970	289200	11065P	PARTICIPANT	\N	PRESENT	0
300972	289200	19533U	PARTICIPANT	\N	PRESENT	0
300973	289200	19543W	PARTICIPANT	\N	PRESENT	0
300974	289200	19671E	PARTICIPANT	\N	PRESENT	0
300975	289200	95063L	PARTICIPANT	\N	PRESENT	0
300976	289200	19347U	PARTICIPANT	\N	PRESENT	0
300977	289200	19762G	PARTICIPANT	\N	PRESENT	0
300978	289200	19503N	PARTICIPANT	\N	PRESENT	0
300979	289200	14329V	PARTICIPANT	\N	PRESENT	0
300980	289200	19289C	PARTICIPANT	\N	PRESENT	0
300981	289200	19631V	PARTICIPANT	\N	PRESENT	0
300982	289200	19367Y	PARTICIPANT	\N	PRESENT	0
300983	289200	19413M	PARTICIPANT	\N	PRESENT	0
300984	289200	04018C	PARTICIPANT	\N	PRESENT	0
300985	289200	11099A	PARTICIPANT	\N	PRESENT	0
300986	289200	08017T	PARTICIPANT	\N	PRESENT	0
300987	289200	19295A	PARTICIPANT	\N	PRESENT	0
300988	289200	11109J	PARTICIPANT	\N	PRESENT	0
300989	289200	19301E	PARTICIPANT	\N	PRESENT	0
300990	289200	19553Y	PARTICIPANT	\N	PRESENT	0
300991	289200	19727D	PARTICIPANT	\N	PRESENT	0
300992	289200	98005N	PARTICIPANT	\N	PRESENT	0
300993	289200	86034E	PARTICIPANT	\N	PRESENT	0
300994	289200	19747H	PARTICIPANT	\N	PRESENT	0
300998	289200	19673G	PARTICIPANT	\N	PRESENT	0
300996	289200	01058X	PARTICIPANT	\N	PRESENT	0
300997	289200	99004R	PARTICIPANT	\N	PRESENT	0
300999	289200	04070G	PARTICIPANT	\N	PRESENT	0
301000	289200	11085T	PARTICIPANT	\N	PRESENT	0
301001	289200	19735D	PARTICIPANT	\N	PRESENT	0
301003	289200	19733B	PARTICIPANT	\N	PRESENT	0
301004	289200	19643A	PARTICIPANT	\N	PRESENT	0
301005	289200	11083R	PARTICIPANT	\N	PRESENT	0
301024	289200	14089Y	PARTICIPANT	\N	PRESENT	0
301013	289200	19253P	PARTICIPANT	\N	PRESENT	0
301016	289200	14107H	PARTICIPANT	\N	PRESENT	0
301023	289200	04043D	PARTICIPANT	\N	PRESENT	0
301027	289200	08052W	PARTICIPANT	\N	PRESENT	0
301034	289200	19591F	PARTICIPANT	\N	PRESENT	0
301035	289200	17589D	PARTICIPANT	\N	PRESENT	0
283328	273895	95030B	PARTICIPANT	\N	PRESENT	0
283329	273895	19441R	PARTICIPANT	\N	PRESENT	0
283330	273895	14205J	PARTICIPANT	\N	PRESENT	0
283331	273895	19479G	PARTICIPANT	\N	PRESENT	0
283332	273895	04047H	PARTICIPANT	\N	PRESENT	0
283333	273895	14042U	PARTICIPANT	\N	PRESENT	0
283334	273895	14026U	PARTICIPANT	\N	PRESENT	0
283335	273895	19553Y	PARTICIPANT	\N	PRESENT	0
283336	273895	17589D	PARTICIPANT	\N	PRESENT	0
283337	273895	04086Q	PARTICIPANT	\N	PRESENT	0
283338	273895	04042C	PARTICIPANT	\N	PRESENT	0
283339	273895	14255U	PARTICIPANT	\N	PRESENT	0
283340	273895	19713W	PARTICIPANT	\N	PRESENT	0
283341	273895	04092N	PARTICIPANT	\N	PRESENT	0
283342	273895	14275Y	PARTICIPANT	\N	PRESENT	0
283343	273895	14277B	PARTICIPANT	\N	PRESENT	0
283344	273895	98018T	PARTICIPANT	\N	PRESENT	0
283345	273895	04044E	PARTICIPANT	\N	PRESENT	0
283346	273895	14327T	PARTICIPANT	\N	PRESENT	0
283347	273895	96004D	PARTICIPANT	\N	PRESENT	0
283348	273895	08035V	PARTICIPANT	\N	PRESENT	0
283349	273895	19421M	PARTICIPANT	\N	PRESENT	0
283350	273895	01025N	PARTICIPANT	\N	PRESENT	0
283351	273895	01024M	PARTICIPANT	\N	PRESENT	0
283352	273895	11097X	PARTICIPANT	\N	PRESENT	0
283353	273895	11053K	PARTICIPANT	\N	PRESENT	0
283354	273895	05008E	PARTICIPANT	\N	PRESENT	0
283355	273895	14187A	PARTICIPANT	\N	PRESENT	0
283356	273895	04040A	PARTICIPANT	\N	PRESENT	0
283357	273895	04070G	PARTICIPANT	\N	PRESENT	0
283358	273895	04033B	PARTICIPANT	\N	PRESENT	0
283359	273895	08009T	PARTICIPANT	\N	PRESENT	0
283360	273895	04043D	PARTICIPANT	\N	PRESENT	0
283361	273895	11070L	PARTICIPANT	\N	PRESENT	0
283362	273895	07004J	PARTICIPANT	\N	PRESENT	0
283363	273895	14069U	PARTICIPANT	\N	PRESENT	0
283364	273895	19551W	PARTICIPANT	\N	PRESENT	0
283425	273895	14133K	PARTICIPANT	\N	PRESENT	0
283366	273895	19521Q	PARTICIPANT	\N	PRESENT	0
283367	273895	14083S	PARTICIPANT	\N	PRESENT	0
283368	273895	14249W	PARTICIPANT	\N	PRESENT	0
283369	273895	14073Q	PARTICIPANT	\N	PRESENT	0
283370	273895	14267Y	PARTICIPANT	\N	PRESENT	0
283371	273895	14053L	PARTICIPANT	\N	PRESENT	0
283372	273895	14221J	PARTICIPANT	\N	PRESENT	0
283373	273895	19739H	PARTICIPANT	\N	PRESENT	0
283374	273895	14087W	PARTICIPANT	\N	PRESENT	0
283375	273895	19335Q	PARTICIPANT	\N	PRESENT	0
283376	273895	14215L	PARTICIPANT	\N	PRESENT	0
283377	273895	14237S	PARTICIPANT	\N	PRESENT	0
283378	273895	17583W	PARTICIPANT	\N	PRESENT	0
283379	273895	14193X	PARTICIPANT	\N	PRESENT	0
283380	273895	07034Q	PARTICIPANT	\N	PRESENT	0
283381	273895	10006L	PARTICIPANT	\N	PRESENT	0
283382	273895	19533U	PARTICIPANT	\N	PRESENT	0
283383	273895	11031D	PARTICIPANT	\N	PRESENT	0
283384	273895	04085P	PARTICIPANT	\N	PRESENT	0
283385	273895	08034U	PARTICIPANT	\N	PRESENT	0
283386	273895	14147R	PARTICIPANT	\N	PRESENT	0
283387	273895	97011G	PARTICIPANT	\N	PRESENT	0
283388	273895	11103C	PARTICIPANT	\N	PRESENT	0
283389	273895	07033P	PARTICIPANT	\N	PRESENT	0
283390	273895	19543W	PARTICIPANT	\N	PRESENT	0
283391	273895	14217N	PARTICIPANT	\N	PRESENT	0
283392	273895	19671E	PARTICIPANT	\N	PRESENT	0
283393	273895	14079W	PARTICIPANT	\N	PRESENT	0
283394	273895	08061X	PARTICIPANT	\N	PRESENT	0
283395	273895	19581D	PARTICIPANT	\N	PRESENT	0
283396	273895	19747H	PARTICIPANT	\N	PRESENT	0
283397	273895	19367Y	PARTICIPANT	\N	PRESENT	0
283416	273895	11048N	PARTICIPANT	\N	PRESENT	0
283399	273895	04018C	PARTICIPANT	\N	PRESENT	0
283400	273895	19383Y	PARTICIPANT	\N	PRESENT	0
283422	273895	11115U	PARTICIPANT	\N	PRESENT	0
283402	273895	98005N	PARTICIPANT	\N	PRESENT	0
283403	273895	19675J	PARTICIPANT	\N	PRESENT	0
283404	273895	14357A	PARTICIPANT	\N	PRESENT	0
283417	273895	05012A	PARTICIPANT	\N	PRESENT	0
283406	273895	14329V	PARTICIPANT	\N	PRESENT	0
283407	273895	19531S	PARTICIPANT	\N	PRESENT	0
283408	273895	95067Q	PARTICIPANT	\N	PRESENT	0
283409	273895	11090Q	PARTICIPANT	\N	PRESENT	0
283410	273895	98050T	PARTICIPANT	\N	PRESENT	0
283411	273895	11026G	PARTICIPANT	\N	PRESENT	0
283412	273895	14061L	PARTICIPANT	\N	PRESENT	0
283413	273895	19733B	PARTICIPANT	\N	PRESENT	0
283427	273895	14225N	PARTICIPANT	\N	PRESENT	0
283415	273895	19701S	PARTICIPANT	\N	PRESENT	0
283424	273895	19749K	PARTICIPANT	\N	PRESENT	0
283426	273895	14034U	PARTICIPANT	\N	PRESENT	0
283428	273895	02002K	PARTICIPANT	\N	PRESENT	0
283429	273895	11110B	PARTICIPANT	\N	PRESENT	0
283430	273895	19621T	PARTICIPANT	\N	PRESENT	0
283734	273896	04044E	PARTICIPANT	\N	PRESENT	0
283873	279499	19649G	PARTICIPANT	\N	PRESENT	0
283874	279499	11080N	PARTICIPANT	\N	PRESENT	0
283875	279499	19611R	PARTICIPANT	\N	PRESENT	0
283876	279499	11026G	PARTICIPANT	\N	PRESENT	0
283877	279499	10015M	PARTICIPANT	\N	PRESENT	0
283878	279499	19673G	PARTICIPANT	\N	PRESENT	0
283879	279499	08056B	PARTICIPANT	\N	PRESENT	0
283880	279499	19421M	PARTICIPANT	\N	PRESENT	0
283881	279499	98022P	PARTICIPANT	\N	PRESENT	0
283882	279499	19575F	PARTICIPANT	\N	PRESENT	0
283883	279499	98050T	PARTICIPANT	\N	PRESENT	0
283884	279499	08010L	PARTICIPANT	\N	PRESENT	0
283885	279499	98029W	PRESIDENT	0	PRESENT	0
284527	282692	19301E	PARTICIPANT	\N	PRESENT	0
284528	282692	08038Y	PARTICIPANT	\N	PRESENT	0
284529	282692	19295A	PARTICIPANT	\N	PRESENT	0
284530	282692	08068F	PARTICIPANT	\N	PRESENT	0
284531	282692	19631V	PARTICIPANT	\N	PRESENT	0
284532	282692	11081P	PARTICIPANT	\N	EXCUSE	0
285900	285899	11070L	PARTICIPANT	\N	PRESENT	0
284534	282657	19695N	PARTICIPANT	\N	PRESENT	0
284535	282657	19619A	PARTICIPANT	\N	PRESENT	0
285170	284823	14087W	PARTICIPANT	\N	EXCUSE	0
285901	285899	19647E	PARTICIPANT	\N	PRESENT	0
285903	285902	19647E	PARTICIPANT	\N	PRESENT	0
285904	285902	11070L	PARTICIPANT	\N	PRESENT	0
286238	273988	19723Y	PARTICIPANT	\N	PRESENT	0
286247	286212	19725B	PARTICIPANT	\N	PRESENT	0
286248	286212	14221J	PARTICIPANT	\N	PRESENT	0
286250	286249	96004D	PARTICIPANT	\N	PRESENT	0
286251	286249	11083R	PARTICIPANT	\N	PRESENT	0
286252	286249	19725B	PARTICIPANT	\N	PRESENT	0
286253	286249	04097T	PARTICIPANT	\N	PRESENT	0
286254	286249	10015M	PARTICIPANT	\N	PRESENT	0
286255	286249	14079W	PARTICIPANT	\N	PRESENT	0
286256	286249	14097Y	PARTICIPANT	\N	PRESENT	0
286258	286257	14327T	PARTICIPANT	\N	PRESENT	0
286259	286257	19503N	PARTICIPANT	\N	PRESENT	0
286260	286257	10015M	PARTICIPANT	\N	PRESENT	0
286262	286261	14327T	PARTICIPANT	\N	PRESENT	0
286263	286261	19503N	PARTICIPANT	\N	PRESENT	0
286264	286261	19725B	PARTICIPANT	\N	PRESENT	0
286265	286261	08073C	PARTICIPANT	\N	PRESENT	0
286266	286261	10015M	PARTICIPANT	\N	PRESENT	0
286269	286268	04061F	PARTICIPANT	\N	PRESENT	0
286620	286619	08043V	PARTICIPANT	\N	PRESENT	0
286621	286619	04038G	PARTICIPANT	\N	PRESENT	0
286622	286619	17637T	PARTICIPANT	\N	PRESENT	0
286623	286619	11041F	PRESIDENT	0	PRESENT	0
286624	286619	95062K	PARTICIPANT	\N	PRESENT	0
286625	286619	11070L	PARTICIPANT	\N	EXCUSE	0
286648	286619	14357A	PARTICIPANT	\N	EXCUSE	0
286651	286650	14065Q	PARTICIPANT	\N	PRESENT	0
286652	286650	14030Q	PARTICIPANT	\N	PRESENT	0
286653	286650	95037J	PARTICIPANT	\N	PRESENT	0
286654	286650	19369B	PARTICIPANT	\N	PRESENT	0
286655	286650	01034P	PARTICIPANT	\N	PRESENT	0
286656	286650	08053X	PARTICIPANT	\N	PRESENT	0
286657	286650	14241N	PARTICIPANT	\N	PRESENT	0
286669	286619	19531S	PARTICIPANT	\N	EXCUSE	0
286680	286679	14133K	PARTICIPANT	\N	PRESENT	0
287354	286214	04040A	PARTICIPANT	\N	EXCUSE	0
286682	286679	04042C	PARTICIPANT	\N	PRESENT	0
286683	286679	14267Y	PARTICIPANT	\N	PRESENT	0
286684	286679	11027H	PARTICIPANT	\N	PRESENT	0
286685	286679	08034U	PARTICIPANT	\N	PRESENT	0
286686	286679	08047A	PARTICIPANT	\N	PRESENT	0
286687	286679	14193X	PRESIDENT	0	PRESENT	0
286688	286679	98050T	PARTICIPANT	\N	PRESENT	0
286689	286679	14235Q	PARTICIPANT	\N	PRESENT	0
286690	286679	01062T	PARTICIPANT	\N	PRESENT	0
287356	286214	98022P	PARTICIPANT	\N	EXCUSE	0
286692	286679	11066Q	PARTICIPANT	\N	PRESENT	0
286693	286679	04034C	PARTICIPANT	\N	PRESENT	0
287357	286214	14193X	PARTICIPANT	\N	EXCUSE	0
273683	263483	11072N	PARTICIPANT	\N	PRESENT	0
273684	263483	19749K	PARTICIPANT	\N	PRESENT	0
273685	263483	19349W	PARTICIPANT	\N	PRESENT	0
273686	263483	19533U	PARTICIPANT	\N	PRESENT	0
273687	263483	19575F	PARTICIPANT	\N	PRESENT	0
273688	263483	08031R	PARTICIPANT	\N	PRESENT	0
273689	263483	19581D	PARTICIPANT	\N	PRESENT	0
273690	263483	01060R	PARTICIPANT	\N	PRESENT	0
273691	263483	95015C	PARTICIPANT	\N	PRESENT	0
273692	263483	01028R	PARTICIPANT	\N	PRESENT	0
273695	263483	14030Q	PARTICIPANT	\N	PRESENT	0
273696	263483	14179A	PARTICIPANT	\N	PRESENT	0
273733	263484	11054L	PARTICIPANT	\N	PRESENT	0
273734	263484	08012N	PARTICIPANT	\N	PRESENT	0
273735	263484	14085U	PARTICIPANT	\N	PRESENT	0
273736	263484	08058D	PARTICIPANT	\N	PRESENT	0
273737	263484	01028R	PARTICIPANT	\N	PRESENT	0
273738	263484	08053X	PARTICIPANT	\N	PRESENT	0
273739	263484	11027H	PARTICIPANT	\N	PRESENT	0
273726	263484	86034E	PARTICIPANT	\N	PRESENT	0
273732	263484	14235Q	PARTICIPANT	\N	PRESENT	0
273740	263484	11066Q	PARTICIPANT	\N	PRESENT	0
273741	263484	14207L	PARTICIPANT	\N	PRESENT	0
273742	263484	14097Y	PARTICIPANT	\N	PRESENT	0
273743	263484	14257W	PARTICIPANT	\N	PRESENT	0
273744	263484	04034C	PARTICIPANT	\N	PRESENT	0
273745	263484	95063L	PARTICIPANT	\N	PRESENT	0
273746	263484	95037J	PARTICIPANT	\N	PRESENT	0
273747	263484	19681G	PARTICIPANT	\N	PRESENT	0
273748	263484	14241N	PARTICIPANT	\N	PRESENT	0
273749	263484	14093U	PARTICIPANT	\N	PRESENT	0
273750	263484	19583F	PARTICIPANT	\N	PRESENT	0
273751	263484	19479G	PARTICIPANT	\N	PRESENT	0
273752	263484	19253P	PARTICIPANT	\N	PRESENT	0
273753	263484	19629C	PARTICIPANT	\N	PRESENT	0
273754	263484	08031R	PARTICIPANT	\N	PRESENT	0
273755	263484	19737F	PARTICIPANT	\N	PRESENT	0
273756	263484	08034U	PARTICIPANT	\N	PRESENT	0
273757	263484	04042C	PARTICIPANT	\N	PRESENT	0
273758	263484	19319Q	PARTICIPANT	\N	PRESENT	0
273759	263484	08049C	PARTICIPANT	\N	PRESENT	0
273760	263484	19721W	PARTICIPANT	\N	PRESENT	0
273761	263484	04057K	PARTICIPANT	\N	PRESENT	0
273762	263484	04044E	PARTICIPANT	\N	PRESENT	0
273763	263484	01058X	PARTICIPANT	\N	PRESENT	0
273764	263484	98018T	PARTICIPANT	\N	PRESENT	0
273765	263484	98050T	PARTICIPANT	\N	PRESENT	0
273766	263484	01025N	PARTICIPANT	\N	PRESENT	0
273767	263484	04040A	PARTICIPANT	\N	PRESENT	0
273768	263484	19421M	PARTICIPANT	\N	PRESENT	0
273769	263484	14255U	PARTICIPANT	\N	PRESENT	0
273770	263484	14089Y	PARTICIPANT	\N	PRESENT	0
273771	263484	14267Y	PARTICIPANT	\N	PRESENT	0
273772	263484	19747H	PARTICIPANT	\N	PRESENT	0
273773	263484	19671E	PARTICIPANT	\N	PRESENT	0
273774	263484	97011G	PARTICIPANT	\N	PRESENT	0
273775	263484	11103C	PARTICIPANT	\N	PRESENT	0
273776	263484	19621T	PARTICIPANT	\N	PRESENT	0
273777	263484	04018C	PARTICIPANT	\N	PRESENT	0
273778	263484	19701S	PARTICIPANT	\N	PRESENT	0
273779	263484	19731Y	PARTICIPANT	\N	PRESENT	0
273780	263484	14331P	PARTICIPANT	\N	PRESENT	0
273781	263484	08028W	PARTICIPANT	\N	PRESENT	0
273782	263484	14105F	PARTICIPANT	\N	PRESENT	0
273783	263484	08047A	PARTICIPANT	\N	PRESENT	0
273784	263484	19333N	PARTICIPANT	\N	PRESENT	0
273785	263484	19729F	PARTICIPANT	\N	PRESENT	0
273786	263484	19657G	PARTICIPANT	\N	PRESENT	0
273787	263484	14063N	PARTICIPANT	\N	PRESENT	0
273788	263484	04088S	PARTICIPANT	\N	PRESENT	0
273789	263484	19709B	PARTICIPANT	\N	PRESENT	0
273790	263484	19443T	PARTICIPANT	\N	PRESENT	0
273791	263484	18083K	PARTICIPANT	\N	PRESENT	0
273792	263484	14033T	PARTICIPANT	\N	PRESENT	0
273793	263484	14031R	PARTICIPANT	\N	PRESENT	0
273794	263484	14157T	PARTICIPANT	\N	PRESENT	0
273795	263484	01057W	PARTICIPANT	\N	PRESENT	0
273796	263484	14133K	PARTICIPANT	\N	PRESENT	0
273797	263484	14193X	PARTICIPANT	\N	PRESENT	0
273798	263484	19251M	PARTICIPANT	\N	PRESENT	0
273799	263484	19563B	PARTICIPANT	\N	PRESENT	0
273800	263484	14231L	PARTICIPANT	\N	PRESENT	0
273801	263484	16685X	PARTICIPANT	\N	PRESENT	0
273802	263484	98029W	PARTICIPANT	\N	PRESENT	0
273803	263484	14028W	PARTICIPANT	\N	PRESENT	0
273804	263484	19503N	PARTICIPANT	\N	PRESENT	0
273805	263484	11056N	PARTICIPANT	\N	PRESENT	0
273806	263484	04035D	PARTICIPANT	\N	PRESENT	0
273807	263484	01062T	PARTICIPANT	\N	PRESENT	0
273808	263484	19591F	PARTICIPANT	\N	PRESENT	0
273809	263484	19715Y	PARTICIPANT	\N	PRESENT	0
273810	263484	19733B	PARTICIPANT	\N	PRESENT	0
273811	263484	14038Y	PARTICIPANT	\N	PRESENT	0
273812	263484	14211G	PARTICIPANT	\N	PRESENT	0
273813	263484	19713W	PARTICIPANT	\N	PRESENT	0
273814	263484	19447X	PARTICIPANT	\N	PRESENT	0
273815	263484	14265W	PARTICIPANT	\N	PRESENT	0
273816	263484	11097X	PARTICIPANT	\N	PRESENT	0
273817	263484	19387D	PARTICIPANT	\N	PRESENT	0
273818	263484	11110B	PARTICIPANT	\N	PRESENT	0
273819	263484	14219Q	PARTICIPANT	\N	PRESENT	0
273820	263484	08056B	PARTICIPANT	\N	PRESENT	0
273821	263484	19581D	PARTICIPANT	\N	PRESENT	0
273822	263484	11074Q	PARTICIPANT	\N	PRESENT	0
273823	263484	14055N	PARTICIPANT	\N	PRESENT	0
273824	263484	19575F	PARTICIPANT	\N	PRESENT	0
273825	263484	19367Y	PARTICIPANT	\N	PRESENT	0
273826	263484	14223L	PARTICIPANT	\N	PRESENT	0
273827	263484	14111D	PARTICIPANT	\N	PRESENT	0
273828	263484	14253S	PARTICIPANT	\N	PRESENT	0
273829	263484	11012A	PARTICIPANT	\N	PRESENT	0
273830	263484	14107H	PARTICIPANT	\N	PRESENT	0
273831	263484	14327T	PARTICIPANT	\N	PRESENT	0
273832	263484	14147R	PARTICIPANT	\N	PRESENT	0
273833	263484	14213J	PARTICIPANT	\N	PRESENT	0
273834	263484	19565D	PARTICIPANT	\N	PRESENT	0
273835	263484	04061F	PARTICIPANT	\N	PRESENT	0
273836	263484	19647E	PARTICIPANT	\N	PRESENT	0
273837	263484	95015C	PARTICIPANT	\N	PRESENT	0
273838	263484	19669L	PARTICIPANT	\N	PRESENT	0
273839	263484	19599P	PARTICIPANT	\N	PRESENT	0
273840	263484	08061X	PARTICIPANT	\N	PRESENT	0
273843	263484	19543W	PARTICIPANT	\N	PRESENT	0
273844	263484	11083R	PARTICIPANT	\N	PRESENT	0
273845	263484	11043H	PARTICIPANT	\N	PRESENT	0
273846	263484	11067R	PARTICIPANT	\N	PRESENT	0
273847	263484	19725B	PARTICIPANT	\N	PRESENT	0
273848	263484	14237S	PARTICIPANT	\N	PRESENT	0
273849	263484	95030B	PARTICIPANT	\N	PRESENT	0
273850	263484	08015R	PARTICIPANT	\N	PRESENT	0
273851	263484	11048N	PARTICIPANT	\N	PRESENT	0
273852	263484	19467C	PARTICIPANT	\N	PRESENT	0
273853	263484	19659J	PARTICIPANT	\N	PRESENT	0
273854	263484	14034U	PARTICIPANT	\N	PRESENT	0
273855	263484	14030Q	PARTICIPANT	\N	PRESENT	0
273856	263484	19687N	PARTICIPANT	\N	PRESENT	0
273858	263484	87003B	PARTICIPANT	\N	PRESENT	0
273859	263484	19441R	PARTICIPANT	\N	PRESENT	0
273860	263484	14021P	PARTICIPANT	\N	PRESENT	0
273861	263484	15447F	PARTICIPANT	\N	PRESENT	0
273862	263484	14029X	PARTICIPANT	\N	PRESENT	0
273864	263484	14121F	PARTICIPANT	\N	PRESENT	0
273873	263484	19415P	PARTICIPANT	\N	PRESENT	0
273874	263484	19399H	PARTICIPANT	\N	PRESENT	0
273875	263484	19683J	PARTICIPANT	\N	PRESENT	0
273876	263484	08010L	PARTICIPANT	\N	PRESENT	0
273880	263484	19611R	PARTICIPANT	\N	PRESENT	0
273882	263484	14123H	PARTICIPANT	\N	PRESENT	0
273892	263484	14041T	PARTICIPANT	\N	PRESENT	0
273904	263484	14151M	PARTICIPANT	\N	PRESENT	0
273916	263484	14217N	PARTICIPANT	\N	PRESENT	0
274251	273624	08009T	PRESIDENT	0	PRESENT	0
274252	273624	14031R	PARTICIPANT	\N	EXCUSE	0
274253	273624	14219Q	PARTICIPANT	\N	PRESENT	0
274254	273624	19745F	PARTICIPANT	\N	PRESENT	0
274255	273624	08055A	PARTICIPANT	\N	PRESENT	0
274256	273624	14221J	PARTICIPANT	\N	PRESENT	0
274257	273624	14103D	PARTICIPANT	\N	PRESENT	0
274258	273624	14051J	PARTICIPANT	\N	PRESENT	0
274263	273624	19549D	PARTICIPANT	\N	PRESENT	0
274264	273624	95062K	PARTICIPANT	\N	PRESENT	0
274265	273624	19387D	PARTICIPANT	\N	PRESENT	0
274266	273624	19637C	PARTICIPANT	\N	PRESENT	0
274267	273624	19551W	PARTICIPANT	\N	PRESENT	0
274268	273624	05012A	PARTICIPANT	\N	PRESENT	0
274269	273624	19503N	PARTICIPANT	\N	PRESENT	0
274270	273624	19347U	PARTICIPANT	\N	PRESENT	0
274271	273624	14157T	PARTICIPANT	\N	PRESENT	0
279830	279829	14147R	PARTICIPANT	\N	PRESENT	0
282357	282356	14187A	PARTICIPANT	\N	PRESENT	0
282359	282358	14187A	PARTICIPANT	\N	PRESENT	0
282364	282363	19515S	PARTICIPANT	\N	PRESENT	0
282365	282363	08055A	PARTICIPANT	\N	PRESENT	0
282366	282363	19575F	PARTICIPANT	\N	PRESENT	0
282367	282363	14105F	PARTICIPANT	\N	PRESENT	0
282368	282363	14207L	PARTICIPANT	\N	PRESENT	0
282369	282363	14329V	PARTICIPANT	\N	PRESENT	0
282370	282363	19467C	PARTICIPANT	\N	PRESENT	0
282371	282363	80013X	PARTICIPANT	\N	PRESENT	0
282372	282363	19719D	PARTICIPANT	\N	PRESENT	0
282373	282363	01024M	PARTICIPANT	\N	PRESENT	0
282374	282363	14026U	PARTICIPANT	\N	PRESENT	0
282375	282363	19725B	PARTICIPANT	\N	PRESENT	0
282376	282363	95037J	PARTICIPANT	\N	PRESENT	0
282377	282363	14213J	PARTICIPANT	\N	PRESENT	0
282378	282363	19611R	PARTICIPANT	\N	PRESENT	0
282379	282363	04049K	PARTICIPANT	\N	PRESENT	0
282380	282363	19723Y	PARTICIPANT	\N	PRESENT	0
282381	282363	08015R	PARTICIPANT	\N	PRESENT	0
282382	282363	08010L	PARTICIPANT	\N	PRESENT	0
282383	282363	14205J	PARTICIPANT	\N	PRESENT	0
282384	282363	14219Q	PARTICIPANT	\N	PRESENT	0
282385	282363	19441R	PARTICIPANT	\N	PRESENT	0
282386	282363	14109K	PARTICIPANT	\N	PRESENT	0
282387	282363	19745F	PARTICIPANT	\N	PRESENT	0
283116	283115	04049K	PARTICIPANT	\N	PRESENT	0
283117	283115	14051J	PARTICIPANT	\N	PRESENT	0
283119	283115	04088S	PARTICIPANT	\N	PRESENT	0
283120	283115	19671E	PARTICIPANT	\N	PRESENT	0
283121	283115	14041T	PARTICIPANT	\N	PRESENT	0
283122	283115	14053L	PARTICIPANT	\N	PRESENT	0
286108	286107	08043V	PARTICIPANT	\N	PRESENT	0
283127	283115	14083S	PARTICIPANT	\N	PRESENT	0
283132	283115	19758L	PARTICIPANT	\N	PRESENT	0
286109	286107	04038G	PARTICIPANT	\N	PRESENT	0
286110	286107	14357A	PARTICIPANT	\N	PRESENT	0
286111	286107	11070L	PRESIDENT	0	PRESENT	0
286112	286107	95062K	PARTICIPANT	\N	PRESENT	0
286113	286107	11041F	PARTICIPANT	\N	PRESENT	0
286114	286107	04097T	PARTICIPANT	\N	EXCUSE	0
286116	286115	08043V	PARTICIPANT	\N	PRESENT	0
286117	286115	04038G	PARTICIPANT	\N	PRESENT	0
286118	286115	14357A	PARTICIPANT	\N	PRESENT	0
286119	286115	11070L	PRESIDENT	0	PRESENT	0
286120	286115	04097T	PARTICIPANT	\N	EXCUSE	0
286121	286115	19531S	PARTICIPANT	\N	PRESENT	0
286122	286115	17637T	PARTICIPANT	\N	PRESENT	0
286123	286115	95062K	PARTICIPANT	\N	PRESENT	0
286124	286115	19689Q	PARTICIPANT	\N	PRESENT	0
286126	286125	14065Q	PARTICIPANT	\N	PRESENT	0
286127	286125	96004D	PRESIDENT	0	PRESENT	0
286128	286125	14357A	PARTICIPANT	\N	PRESENT	0
286129	286125	14249W	PARTICIPANT	\N	PRESENT	0
286130	286125	11083R	PARTICIPANT	\N	PRESENT	0
286131	286125	14033T	PARTICIPANT	\N	PRESENT	0
286132	286125	19725B	PARTICIPANT	\N	PRESENT	0
286133	286125	14097Y	PARTICIPANT	\N	PRESENT	0
286134	286125	14073Q	PARTICIPANT	\N	EXCUSE	0
286135	286125	11026G	PARTICIPANT	\N	PRESENT	0
286136	286125	14221J	PARTICIPANT	\N	PRESENT	0
286137	286125	04057K	PARTICIPANT	\N	PRESENT	0
286138	286125	19563B	PARTICIPANT	\N	PRESENT	0
286139	286125	14237S	PARTICIPANT	\N	EXCUSE	0
286140	286125	10015M	PARTICIPANT	\N	PRESENT	0
286141	286125	14229S	PARTICIPANT	\N	PRESENT	0
286142	286125	98035U	PARTICIPANT	\N	PRESENT	0
286143	286125	19593H	PARTICIPANT	\N	PRESENT	0
287050	286590	04059M	PARTICIPANT	\N	PRESENT	0
287051	286235	17583W	PARTICIPANT	\N	PRESENT	0
287052	286235	19737F	PARTICIPANT	\N	PRESENT	0
287053	286235	19739H	PARTICIPANT	\N	PRESENT	0
287054	286235	14219Q	PARTICIPANT	\N	PRESENT	0
287055	286235	19387D	PARTICIPANT	\N	PRESENT	0
287056	286235	14103D	PARTICIPANT	\N	PRESENT	0
287057	286235	14221J	PARTICIPANT	\N	PRESENT	0
287058	286235	19745F	PARTICIPANT	\N	PRESENT	0
287059	286235	19713W	PARTICIPANT	\N	PRESENT	0
287060	286235	14029X	PARTICIPANT	\N	PRESENT	0
287061	286235	98023Q	PARTICIPANT	\N	PRESENT	0
287062	286214	14097Y	PARTICIPANT	\N	PRESENT	0
287063	286214	04035D	PARTICIPANT	\N	PRESENT	0
287064	286214	19443T	PARTICIPANT	\N	PRESENT	0
287065	286214	12041X	PARTICIPANT	\N	PRESENT	0
287066	286214	01062T	PARTICIPANT	\N	PRESENT	0
287067	286214	04034C	PARTICIPANT	\N	PRESENT	0
287068	286214	11041F	PARTICIPANT	\N	PRESENT	0
287069	286214	14079W	PARTICIPANT	\N	PRESENT	0
287070	286214	04042C	PRESIDENT	0	PRESENT	0
287071	286214	11066Q	PARTICIPANT	\N	PRESENT	0
287072	286214	19721W	PARTICIPANT	\N	PRESENT	0
287073	286214	08056B	PARTICIPANT	\N	PRESENT	0
287074	286214	14105F	PARTICIPANT	\N	PRESENT	0
287075	286214	14267Y	PARTICIPANT	\N	PRESENT	0
287076	286214	98050T	PARTICIPANT	\N	PRESENT	0
287077	286214	14211G	PARTICIPANT	\N	PRESENT	0
287078	286214	08047A	PARTICIPANT	\N	PRESENT	0
287079	286235	19701S	PARTICIPANT	\N	PRESENT	0
287080	286235	14169X	PARTICIPANT	\N	PRESENT	0
287081	286235	19289C	PARTICIPANT	\N	PRESENT	0
287082	286235	19637C	PARTICIPANT	\N	PRESENT	0
287083	286235	15447F	PARTICIPANT	\N	PRESENT	0
287084	286214	01058X	PARTICIPANT	\N	PRESENT	0
287085	286214	14028W	PARTICIPANT	\N	PRESENT	0
287086	286214	08053X	PARTICIPANT	\N	PRESENT	0
287087	286214	95030B	PARTICIPANT	\N	PRESENT	0
287088	286214	14055N	PARTICIPANT	\N	PRESENT	0
287089	286235	19383Y	PARTICIPANT	\N	PRESENT	0
287090	286235	19333N	PARTICIPANT	\N	PRESENT	0
287091	286235	19549D	PARTICIPANT	\N	PRESENT	0
287092	286235	18083K	PARTICIPANT	\N	PRESENT	0
287093	286235	14051J	PARTICIPANT	\N	PRESENT	0
287094	286235	08060W	PARTICIPANT	\N	PRESENT	0
287095	286235	19503N	PARTICIPANT	\N	PRESENT	0
287096	286235	19525U	PARTICIPANT	\N	PRESENT	0
287097	286235	14031R	PARTICIPANT	\N	PRESENT	0
287098	286235	08055A	PARTICIPANT	\N	PRESENT	0
287099	286214	11080N	PARTICIPANT	\N	PRESENT	0
287100	286214	11027H	PARTICIPANT	\N	PRESENT	0
287101	286214	95037J	PARTICIPANT	\N	PRESENT	0
287102	286214	19421M	PARTICIPANT	\N	PRESENT	0
287103	286214	08061X	PARTICIPANT	\N	PRESENT	0
287104	286214	08058D	PARTICIPANT	\N	PRESENT	0
287105	286214	19251M	PARTICIPANT	\N	PRESENT	0
287106	286214	14255U	PARTICIPANT	\N	PRESENT	0
287107	285994	14327T	PARTICIPANT	\N	PRESENT	0
287108	285994	11048N	PARTICIPANT	\N	PRESENT	0
287109	285994	19479G	PARTICIPANT	\N	PRESENT	0
287110	285994	19711U	PARTICIPANT	\N	PRESENT	0
287111	285994	19687N	PARTICIPANT	\N	PRESENT	0
287112	285994	01057W	PARTICIPANT	\N	PRESENT	0
287113	285994	08011M	PARTICIPANT	\N	PRESENT	0
287114	285994	11074Q	PRESIDENT	0	PRESENT	0
287115	285994	88008L	PARTICIPANT	\N	PRESENT	0
287116	285994	14225N	PARTICIPANT	\N	PRESENT	0
287117	285994	14159V	PARTICIPANT	\N	PRESENT	0
287118	285994	14173T	PARTICIPANT	\N	PRESENT	0
287119	285994	11040E	PARTICIPANT	\N	PRESENT	0
287120	285994	04086Q	PARTICIPANT	\N	PRESENT	0
287121	285994	14085U	PARTICIPANT	\N	PRESENT	0
287122	285994	07004J	PARTICIPANT	\N	PRESENT	0
287123	285994	08010L	PARTICIPANT	\N	PRESENT	0
287124	285994	14253S	PARTICIPANT	\N	PRESENT	0
287125	285994	99004R	PARTICIPANT	\N	PRESENT	0
287126	286235	95062K	PARTICIPANT	\N	PRESENT	0
287127	286235	19599P	PARTICIPANT	\N	PRESENT	0
287128	286235	14237S	PARTICIPANT	\N	PRESENT	0
287129	286235	05012A	PARTICIPANT	\N	PRESENT	0
287130	286235	19347U	PARTICIPANT	\N	PRESENT	0
287131	286235	96004D	PARTICIPANT	\N	PRESENT	0
287132	286235	08024S	PARTICIPANT	\N	PRESENT	0
287133	286235	04097T	PARTICIPANT	\N	PRESENT	0
287134	286235	14069U	PARTICIPANT	\N	PRESENT	0
287135	287012	14001X	PARTICIPANT	\N	PRESENT	0
287136	287012	19581D	PARTICIPANT	\N	PRESENT	0
287137	287012	04044E	PARTICIPANT	\N	PRESENT	0
287138	287012	04047H	PARTICIPANT	\N	PRESENT	0
287139	287012	19673G	PARTICIPANT	\N	PRESENT	0
287140	287012	01028R	PARTICIPANT	\N	PRESENT	0
287141	287012	19447X	PARTICIPANT	\N	PRESENT	0
287142	287012	05008E	PRESIDENT	0	PRESENT	0
287143	287012	14231L	PARTICIPANT	\N	PRESENT	0
287144	287012	19489J	PARTICIPANT	\N	PRESENT	0
287145	287012	14275Y	PARTICIPANT	\N	PRESENT	0
287146	287012	14041T	PARTICIPANT	\N	PRESENT	0
287147	287012	14147R	PARTICIPANT	\N	PRESENT	0
287148	287012	14179A	PARTICIPANT	\N	PRESENT	0
287149	287012	14151M	PARTICIPANT	\N	PRESENT	0
271032	263474	11064N	PARTICIPANT	\N	PRESENT	0
271033	263474	11031D	PARTICIPANT	\N	PRESENT	0
271034	263474	14115H	PARTICIPANT	\N	PRESENT	0
271176	263474	11053K	PARTICIPANT	\N	PRESENT	0
271036	263474	08047A	PARTICIPANT	\N	PRESENT	0
271037	263474	04049K	PARTICIPANT	\N	PRESENT	0
271200	263474	19581D	PARTICIPANT	\N	PRESENT	0
271039	263474	98035U	PARTICIPANT	\N	PRESENT	0
271188	263474	14087W	PARTICIPANT	\N	PRESENT	0
271041	263474	04059M	PARTICIPANT	\N	PRESENT	0
271183	263474	04086Q	PARTICIPANT	\N	PRESENT	0
271043	263474	08068F	PARTICIPANT	\N	PRESENT	0
271044	263474	14217N	PARTICIPANT	\N	PRESENT	0
271045	263474	11027H	PARTICIPANT	\N	PRESENT	0
271046	263474	01028R	PARTICIPANT	\N	PRESENT	0
271205	263474	95041E	PARTICIPANT	\N	PRESENT	0
271048	263474	14229S	PARTICIPANT	\N	PRESENT	0
271185	263474	05008E	PARTICIPANT	\N	PRESENT	0
271050	263474	19681G	PARTICIPANT	\N	PRESENT	0
271051	263474	08055A	PARTICIPANT	\N	PRESENT	0
271052	263474	08038Y	PARTICIPANT	\N	PRESENT	0
271053	263474	08045X	PARTICIPANT	\N	PRESENT	0
271201	263474	14169X	PARTICIPANT	\N	PRESENT	0
271179	263474	11101A	PARTICIPANT	\N	PRESENT	0
271212	263474	05012A	PARTICIPANT	\N	PRESENT	0
271207	263474	14193X	PARTICIPANT	\N	PRESENT	0
271058	263474	14225N	PARTICIPANT	\N	PRESENT	0
271059	263474	14021P	PARTICIPANT	\N	PRESENT	0
271060	263474	19715Y	PARTICIPANT	\N	PRESENT	0
271203	263474	19723Y	PARTICIPANT	\N	PRESENT	0
271062	263474	12016W	PARTICIPANT	\N	PRESENT	0
271214	263474	14071N	PARTICIPANT	\N	PRESENT	0
271064	263474	19647E	PARTICIPANT	\N	PRESENT	0
271065	263474	14151M	PARTICIPANT	\N	PRESENT	0
271194	263474	98024R	PARTICIPANT	\N	PRESENT	0
271067	263474	19649G	PARTICIPANT	\N	PRESENT	0
271068	263474	08024S	PARTICIPANT	\N	PRESENT	0
271208	263474	11090Q	PARTICIPANT	\N	PRESENT	0
271210	263474	14253S	PARTICIPANT	\N	PRESENT	0
271071	263474	80013X	PARTICIPANT	\N	PRESENT	0
271218	263474	04033B	PARTICIPANT	\N	PRESENT	0
271073	263474	01062T	PARTICIPANT	\N	PRESENT	0
271074	263474	11066Q	PARTICIPANT	\N	PRESENT	0
271075	263474	08043V	PARTICIPANT	\N	PRESENT	0
271076	263474	14281W	PARTICIPANT	\N	PRESENT	0
271178	263474	19747H	PARTICIPANT	\N	PRESENT	0
271192	263474	14215L	PARTICIPANT	\N	PRESENT	0
271182	263474	11103C	PARTICIPANT	\N	PRESENT	0
271081	263474	19727D	PARTICIPANT	\N	PRESENT	0
271082	263474	19531S	PARTICIPANT	\N	PRESENT	0
271189	263474	14187A	PARTICIPANT	\N	PRESENT	0
271084	263474	19489J	PARTICIPANT	\N	PRESENT	0
271193	263474	10006L	PARTICIPANT	\N	PRESENT	0
271086	263474	17779H	PARTICIPANT	\N	PRESENT	0
271087	263474	08058D	PARTICIPANT	\N	PRESENT	0
271088	263474	19683J	PARTICIPANT	\N	PRESENT	0
271089	263474	14085U	PARTICIPANT	\N	PRESENT	0
271090	263474	11104D	PARTICIPANT	\N	PRESENT	0
271213	263474	19533U	PARTICIPANT	\N	PRESENT	0
271092	263474	19525U	PARTICIPANT	\N	PRESENT	0
271093	263474	11110B	PARTICIPANT	\N	PRESENT	0
271219	263474	19421M	PARTICIPANT	\N	PRESENT	0
271095	263474	19599P	PARTICIPANT	\N	PRESENT	0
271190	263474	95030B	PARTICIPANT	\N	PRESENT	0
271097	263474	14207L	PARTICIPANT	\N	PRESENT	0
271248	263474	19551W	PARTICIPANT	\N	PRESENT	0
271099	263474	14159V	PARTICIPANT	\N	PRESENT	0
271215	263474	95062K	PARTICIPANT	\N	PRESENT	0
271186	263474	04035D	PARTICIPANT	\N	PRESENT	0
271102	263474	19333N	PARTICIPANT	\N	PRESENT	0
271103	263474	08014Q	PARTICIPANT	\N	PRESENT	0
271222	263474	04044E	PARTICIPANT	\N	PRESENT	0
271105	263474	14001X	PARTICIPANT	\N	PRESENT	0
271220	263474	11097X	PARTICIPANT	\N	PRESENT	0
271107	263474	11109J	PARTICIPANT	\N	PRESENT	0
271184	263474	14079W	PARTICIPANT	\N	PRESENT	0
271109	263474	19295A	PARTICIPANT	\N	PRESENT	0
271198	263474	19671E	PARTICIPANT	\N	PRESENT	0
271111	263474	11054L	PARTICIPANT	\N	PRESENT	0
271196	263474	14223L	PARTICIPANT	\N	PRESENT	0
271113	263474	19689Q	PARTICIPANT	\N	PRESENT	0
271114	263474	19251M	PARTICIPANT	\N	PRESENT	0
271115	263474	19413M	PARTICIPANT	\N	PRESENT	0
271223	263474	14173T	PARTICIPANT	\N	PRESENT	0
271224	263474	19335Q	PARTICIPANT	\N	PRESENT	0
271118	263474	11067R	PARTICIPANT	\N	PRESENT	0
271119	263474	14063N	PARTICIPANT	\N	PRESENT	0
271191	263474	14249W	PARTICIPANT	\N	PRESENT	0
271121	263474	14109K	PARTICIPANT	\N	PRESENT	0
271122	263474	14026U	PARTICIPANT	\N	PRESENT	0
271123	263474	14097Y	PARTICIPANT	\N	PRESENT	0
271180	263474	04042C	PARTICIPANT	\N	PRESENT	0
271195	263474	98018T	PARTICIPANT	\N	PRESENT	0
271126	263474	14257W	PARTICIPANT	\N	PRESENT	0
271127	263474	19669L	PARTICIPANT	\N	PRESENT	0
271187	263474	97011G	PARTICIPANT	\N	PRESENT	0
271129	263474	08053X	PARTICIPANT	\N	PRESENT	0
271133	263474	19713W	PARTICIPANT	\N	PRESENT	0
271131	263474	14028W	PARTICIPANT	\N	PRESENT	0
271197	263474	04092N	PARTICIPANT	\N	PRESENT	0
271134	263474	14042U	PARTICIPANT	\N	PRESENT	0
271204	263474	04061F	PARTICIPANT	\N	PRESENT	0
271136	263474	14030Q	PARTICIPANT	\N	PRESENT	0
271137	263474	14231L	PARTICIPANT	\N	PRESENT	0
271138	263474	19577H	PARTICIPANT	\N	PRESENT	0
271139	263474	14327T	PARTICIPANT	\N	PRESENT	0
271181	263474	14053L	PARTICIPANT	\N	PRESENT	0
271141	263474	14179A	PARTICIPANT	\N	PRESENT	0
271142	263474	01024M	PARTICIPANT	\N	PRESENT	0
271143	263474	01025N	PARTICIPANT	\N	PRESENT	0
271144	263474	11070L	PARTICIPANT	\N	PRESENT	0
271145	263474	19369B	PARTICIPANT	\N	PRESENT	0
271146	263474	04070G	PARTICIPANT	\N	PRESENT	0
271147	263474	11085T	PARTICIPANT	\N	PRESENT	0
271148	263474	01034P	PARTICIPANT	\N	PRESENT	0
271149	263474	19611R	PARTICIPANT	\N	PRESENT	0
271150	263474	19511N	PARTICIPANT	\N	PRESENT	0
271151	263474	19619A	PARTICIPANT	\N	PRESENT	0
271217	263474	17583W	PARTICIPANT	\N	PRESENT	0
271153	263474	19737F	PARTICIPANT	\N	PRESENT	0
271154	263474	19699S	PARTICIPANT	\N	PRESENT	0
271155	263474	07004J	PARTICIPANT	\N	PRESENT	0
271156	263474	14255U	PARTICIPANT	\N	PRESENT	0
271157	263474	19521Q	PARTICIPANT	\N	PRESENT	0
271158	263474	08009T	PARTICIPANT	\N	PRESENT	0
271159	263474	19569H	PARTICIPANT	\N	PRESENT	0
271160	263474	08056B	PARTICIPANT	\N	PRESENT	0
271161	263474	19735D	PARTICIPANT	\N	PRESENT	0
271162	263474	19479G	PARTICIPANT	\N	PRESENT	0
271199	263474	14147R	PARTICIPANT	\N	PRESENT	0
271164	263474	14073Q	PARTICIPANT	\N	PRESENT	0
271165	263474	19749K	PARTICIPANT	\N	PRESENT	0
271166	263474	14089Y	PARTICIPANT	\N	PRESENT	0
271167	263474	14103D	PARTICIPANT	\N	PRESENT	0
271168	263474	14267Y	PARTICIPANT	\N	PRESENT	0
271169	263474	14221J	PARTICIPANT	\N	PRESENT	0
271206	263474	11048N	PARTICIPANT	\N	PRESENT	0
271171	263474	19739H	PARTICIPANT	\N	PRESENT	0
271172	263474	02002K	PARTICIPANT	\N	PRESENT	0
271173	263474	19565D	PARTICIPANT	\N	PRESENT	0
271174	263474	19301E	PARTICIPANT	\N	PRESENT	0
271175	263474	19553Y	PARTICIPANT	\N	PRESENT	0
271177	263474	14069U	PARTICIPANT	\N	PRESENT	0
271202	263474	08034U	PARTICIPANT	\N	PRESENT	0
271209	263474	14237S	PARTICIPANT	\N	PRESENT	0
271211	263474	04047H	PARTICIPANT	\N	PRESENT	0
271216	263474	17637T	PARTICIPANT	\N	PRESENT	0
271221	263474	95067Q	PARTICIPANT	\N	PRESENT	0
271225	263474	11026G	PARTICIPANT	\N	PRESENT	0
271226	263474	08017T	PARTICIPANT	\N	PRESENT	0
271228	263474	19725B	PARTICIPANT	\N	PRESENT	0
271229	263474	08035V	PARTICIPANT	\N	PRESENT	0
273281	268514	14030Q	PRESIDENT	0	PRESENT	0
273282	268514	08043V	PARTICIPANT	\N	PRESENT	0
273283	268514	19701S	PARTICIPANT	\N	PRESENT	0
273284	268514	08017T	PARTICIPANT	\N	PRESENT	0
273286	273285	14030Q	PARTICIPANT	\N	PRESENT	0
273287	273285	08043V	PARTICIPANT	\N	PRESENT	0
273288	273285	11031D	PARTICIPANT	\N	PRESENT	0
284616	284615	08069G	PARTICIPANT	\N	PRESENT	0
284617	284615	14199E	PARTICIPANT	\N	PRESENT	0
284618	284615	14097Y	PARTICIPANT	\N	PRESENT	0
284619	284615	04038G	PARTICIPANT	\N	PRESENT	0
284620	284615	11026G	PARTICIPANT	\N	PRESENT	0
284621	284615	08056B	PARTICIPANT	\N	PRESENT	0
284622	284615	10015M	PARTICIPANT	\N	PRESENT	0
287358	286214	14235Q	PARTICIPANT	\N	EXCUSE	0
287359	286214	11054L	PARTICIPANT	\N	EXCUSE	0
287360	286214	95067Q	PARTICIPANT	\N	EXCUSE	0
287361	286215	04040A	PARTICIPANT	\N	EXCUSE	0
287374	286215	98022P	PARTICIPANT	\N	EXCUSE	0
287375	286215	14193X	PARTICIPANT	\N	EXCUSE	0
287376	286215	14235Q	PARTICIPANT	\N	EXCUSE	0
287377	286215	11054L	PARTICIPANT	\N	EXCUSE	0
287378	286215	95067Q	PARTICIPANT	\N	EXCUSE	0
287536	286215	97011G	PARTICIPANT	\N	EXCUSE	0
287540	286214	97011G	PARTICIPANT	\N	EXCUSE	0
287544	287543	11072N	PARTICIPANT	\N	PRESENT	0
287545	287543	14159V	PARTICIPANT	\N	PRESENT	0
287546	287543	14241N	PARTICIPANT	\N	PRESENT	0
287672	287671	08039A	PARTICIPANT	\N	PRESENT	0
287673	287671	14229S	PARTICIPANT	\N	PRESENT	0
287674	287671	14039A	PARTICIPANT	\N	PRESENT	0
287675	287671	19735D	PARTICIPANT	\N	PRESENT	0
288335	273918	14105F	PARTICIPANT	\N	PRESENT	0
288336	273918	19703U	PARTICIPANT	\N	PRESENT	0
288337	286003	08011M	PARTICIPANT	\N	EXCUSE	0
288639	273988	80013X	PARTICIPANT	\N	PRESENT	0
288643	273988	19683J	PARTICIPANT	\N	PRESENT	0
288645	273988	19709B	PARTICIPANT	\N	PRESENT	0
288649	273988	01048V	PRESIDENT	0	PRESENT	0
288651	273988	19533U	PARTICIPANT	\N	EXCUSE	0
288655	273988	01058X	PARTICIPANT	\N	PRESENT	0
288658	273988	04043D	PARTICIPANT	\N	PRESENT	0
289048	273988	14221J	PARTICIPANT	\N	EXCUSE	0
289072	289070	14213J	PRESIDENT	0	PRESENT	0
289074	289070	11099A	PARTICIPANT	\N	PRESENT	0
289076	289070	14169X	PARTICIPANT	\N	PRESENT	0
289078	289070	19503N	PARTICIPANT	\N	PRESENT	0
289079	289070	19347U	PARTICIPANT	\N	PRESENT	0
289081	289070	08049C	PARTICIPANT	\N	EXCUSE	0
289082	289070	14327T	PARTICIPANT	\N	EXCUSE	0
289083	289070	19369B	PARTICIPANT	\N	EXCUSE	0
289085	289070	04049K	PARTICIPANT	\N	EXCUSE	0
289100	284818	14147R	PARTICIPANT	\N	PRESENT	0
289101	284818	14107H	PARTICIPANT	\N	PRESENT	0
289496	289495	14135M	PARTICIPANT	\N	PRESENT	0
289497	289495	14205J	PARTICIPANT	\N	PRESENT	0
289499	289498	14135M	PARTICIPANT	\N	PRESENT	0
289500	289498	14205J	PARTICIPANT	\N	PRESENT	0
289502	289501	14135M	PARTICIPANT	\N	PRESENT	0
289503	289501	14205J	PARTICIPANT	\N	PRESENT	0
289505	289504	14135M	PARTICIPANT	\N	PRESENT	0
289506	289504	14205J	PARTICIPANT	\N	PRESENT	0
289508	289507	14135M	PARTICIPANT	\N	PRESENT	0
289509	289507	14205J	PARTICIPANT	\N	PRESENT	0
289807	289806	14053L	PARTICIPANT	\N	PRESENT	0
289808	289806	19719D	PARTICIPANT	\N	PRESENT	0
289810	289809	14169X	PARTICIPANT	\N	PRESENT	0
289832	289578	11081P	PARTICIPANT	\N	EXCUSE	0
289853	279374	04043D	PARTICIPANT	\N	EXCUSE	0
289854	279374	19511N	PARTICIPANT	\N	EXCUSE	0
291528	291527	04085P	PARTICIPANT	\N	PRESENT	0
292823	292816	08052W	PRESIDENT	0	PRESENT	0
291530	291527	08058D	PRESIDENT	0	PRESENT	0
292824	292816	17589D	PARTICIPANT	\N	PRESENT	0
291532	291527	19721W	PARTICIPANT	\N	PRESENT	0
291533	291527	04086Q	PARTICIPANT	\N	PRESENT	0
291534	291527	19719D	PARTICIPANT	\N	PRESENT	0
291535	291527	19251M	PARTICIPANT	\N	PRESENT	0
291536	291527	04071H	PARTICIPANT	\N	PRESENT	0
291537	291527	08035V	PARTICIPANT	\N	PRESENT	0
291538	291527	15447F	PARTICIPANT	\N	PRESENT	0
291539	291527	11049P	PARTICIPANT	\N	PRESENT	0
291540	291527	14097Y	PARTICIPANT	\N	PRESENT	0
292825	292816	19727D	PARTICIPANT	\N	PRESENT	0
291542	291527	08034U	PARTICIPANT	\N	PRESENT	0
291543	291527	19729F	PARTICIPANT	\N	PRESENT	0
291544	291527	19581D	PARTICIPANT	\N	PRESENT	0
291545	291527	14205J	PARTICIPANT	\N	PRESENT	0
292826	292816	19683J	PARTICIPANT	\N	PRESENT	0
291547	291527	19443T	PARTICIPANT	\N	PRESENT	0
291548	291527	19703U	PARTICIPANT	\N	PRESENT	0
291945	279374	19663E	PARTICIPANT	\N	EXCUSE	0
292820	292816	11031D	PARTICIPANT	\N	PRESENT	0
292821	292816	14357A	PARTICIPANT	\N	PRESENT	0
292827	292816	95062K	PRESIDENT	1	PRESENT	0
292828	292816	04045F	PARTICIPANT	\N	PRESENT	0
292829	292816	19713W	PARTICIPANT	\N	PRESENT	0
292830	292816	14227Q	PARTICIPANT	\N	PRESENT	0
293237	293109	19729F	PARTICIPANT	\N	EXCUSE	0
293239	293238	11074Q	PARTICIPANT	\N	PRESENT	0
293246	289353	19691J	PARTICIPANT	\N	PRESENT	0
293247	289353	11072N	PARTICIPANT	\N	PRESENT	0
293248	289353	14275Y	PARTICIPANT	\N	PRESENT	0
293249	289353	19715Y	PARTICIPANT	\N	PRESENT	0
293250	289353	19717B	PARTICIPANT	\N	PRESENT	0
293251	289353	19577H	PARTICIPANT	\N	PRESENT	0
294494	292933	08014Q	PARTICIPANT	\N	EXCUSE	0
294608	294307	14123H	PARTICIPANT	\N	PRESENT	0
294609	294307	17779H	PARTICIPANT	\N	PRESENT	0
294610	294307	04070G	PARTICIPANT	\N	PRESENT	0
294611	294307	11097X	PARTICIPANT	\N	PRESENT	0
294612	294307	14135M	PARTICIPANT	\N	PRESENT	0
294613	294307	14179A	PARTICIPANT	\N	PRESENT	0
294614	294307	11077T	PARTICIPANT	\N	PRESENT	0
294615	294307	19713W	PARTICIPANT	\N	PRESENT	0
294616	294307	14157T	PARTICIPANT	\N	PRESENT	0
294617	294307	19691J	PARTICIPANT	\N	PRESENT	0
294618	294307	14028W	PARTICIPANT	\N	PRESENT	0
294619	294307	18083K	PARTICIPANT	\N	PRESENT	0
294620	294307	04088S	PARTICIPANT	\N	PRESENT	0
294640	292898	19467C	PARTICIPANT	\N	PRESENT	0
294641	292898	19515S	PARTICIPANT	\N	PRESENT	0
294642	292898	11056N	PARTICIPANT	\N	EXCUSE	0
295724	295722	14221J	PARTICIPANT	\N	PRESENT	0
295725	295722	19593H	PARTICIPANT	\N	PRESENT	0
295818	295817	08024S	PARTICIPANT	\N	PRESENT	0
295819	295817	14042U	PARTICIPANT	\N	PRESENT	0
295820	295817	11083R	PARTICIPANT	\N	PRESENT	0
295821	295817	19551W	PARTICIPANT	\N	PRESENT	0
295822	295817	14059S	PARTICIPANT	\N	PRESENT	0
295823	295817	19503N	PARTICIPANT	\N	PRESENT	0
295824	295817	95062K	PARTICIPANT	\N	PRESENT	0
295825	295817	04043D	PARTICIPANT	\N	PRESENT	0
296067	296066	08010L	PARTICIPANT	\N	PRESENT	0
296068	296066	04035D	PARTICIPANT	\N	PRESENT	0
296077	296074	14255U	PARTICIPANT	\N	PRESENT	0
296086	296085	08038Y	PARTICIPANT	\N	PRESENT	0
298179	295657	19533U	PARTICIPANT	\N	PRESENT	0
298180	295657	01058X	PARTICIPANT	\N	PRESENT	0
298181	295657	01048V	PARTICIPANT	\N	EXCUSE	0
298182	295657	19593H	PARTICIPANT	\N	EXCUSE	0
298793	298792	19621T	PARTICIPANT	\N	PRESENT	0
298794	298792	08031R	PARTICIPANT	\N	PRESENT	0
298954	298953	08069G	PARTICIPANT	\N	PRESENT	0
299105	299099	14239U	PARTICIPANT	\N	PRESENT	0
299108	299099	14065Q	PARTICIPANT	\N	EXCUSE	0
299109	299099	19549D	PARTICIPANT	\N	PRESENT	0
299111	299099	19367Y	PARTICIPANT	\N	PRESENT	0
299112	299099	14053L	PARTICIPANT	\N	EXCUSE	0
299113	299099	19629C	PARTICIPANT	\N	EXCUSE	0
299114	299099	14195A	PARTICIPANT	\N	PRESENT	0
299116	299099	19295A	PARTICIPANT	\N	EXCUSE	0
274272	273624	08024S	PARTICIPANT	\N	PRESENT	0
274273	273624	98023Q	PARTICIPANT	\N	PRESENT	0
274274	273624	19525U	PARTICIPANT	\N	PRESENT	0
274275	273624	14038Y	PARTICIPANT	\N	PRESENT	0
274276	273624	19713W	PARTICIPANT	\N	PRESENT	0
274277	273624	14191V	PARTICIPANT	\N	PRESENT	0
274278	273624	04085P	PARTICIPANT	\N	PRESENT	0
274279	273624	15447F	PARTICIPANT	\N	PRESENT	0
274280	273624	14093U	PARTICIPANT	\N	PRESENT	0
274281	273624	14029X	PARTICIPANT	\N	PRESENT	0
274282	273624	19737F	PARTICIPANT	\N	PRESENT	0
274283	273624	17583W	PARTICIPANT	\N	PRESENT	0
274284	273624	14237S	PARTICIPANT	\N	PRESENT	0
274285	273624	19659J	PARTICIPANT	\N	PRESENT	0
274286	273624	19733B	PARTICIPANT	\N	PRESENT	0
274287	273624	02002K	PARTICIPANT	\N	PRESENT	0
274288	273624	19701S	PARTICIPANT	\N	PRESENT	0
274289	273494	11067R	PARTICIPANT	\N	PRESENT	0
274290	273494	01034P	PARTICIPANT	\N	PRESENT	0
274291	273494	04092N	PRESIDENT	0	PRESENT	0
274292	273494	08052W	PARTICIPANT	\N	PRESENT	0
274293	273494	14223L	PARTICIPANT	\N	PRESENT	0
274294	273494	19717B	PARTICIPANT	\N	PRESENT	0
274295	273494	14227Q	PARTICIPANT	\N	PRESENT	0
274296	273494	11063M	PARTICIPANT	\N	PRESENT	0
274297	273494	14119M	PARTICIPANT	\N	PRESENT	0
274298	273494	14087W	PARTICIPANT	\N	PRESENT	0
274299	273494	19679N	PARTICIPANT	\N	PRESENT	0
274300	273494	11103C	PARTICIPANT	\N	PRESENT	0
274301	273494	19367Y	PARTICIPANT	\N	PRESENT	0
274302	273494	14213J	PARTICIPANT	\N	PRESENT	0
274303	273494	14071N	PARTICIPANT	\N	PRESENT	0
274304	273494	19335Q	PARTICIPANT	\N	PRESENT	0
274305	273494	14217N	PARTICIPANT	\N	PRESENT	0
274306	273494	98024R	PARTICIPANT	\N	PRESENT	0
274307	273494	19521Q	PARTICIPANT	\N	PRESENT	0
274308	273494	08048B	PARTICIPANT	\N	EXCUSE	0
274309	273494	19715Y	PARTICIPANT	\N	PRESENT	0
274310	273624	04097T	PARTICIPANT	\N	PRESENT	0
274393	273302	11027H	PARTICIPANT	\N	PRESENT	0
274394	273494	19697Q	PARTICIPANT	\N	PRESENT	0
274395	273494	19569H	PARTICIPANT	\N	PRESENT	0
274396	273494	11097X	PARTICIPANT	\N	PRESENT	0
274397	273494	14026U	PARTICIPANT	\N	PRESENT	0
274398	273494	17779H	PARTICIPANT	\N	PRESENT	0
274399	273494	19553Y	PARTICIPANT	\N	PRESENT	0
274400	273494	19703U	PARTICIPANT	\N	PRESENT	0
274401	273494	14042U	PARTICIPANT	\N	PRESENT	0
274402	273494	19575F	PARTICIPANT	\N	PRESENT	0
274403	273494	19683J	PARTICIPANT	\N	PRESENT	0
274404	273494	19691J	PARTICIPANT	\N	PRESENT	0
274405	273494	19657G	PARTICIPANT	\N	PRESENT	0
274406	273494	19727D	PARTICIPANT	\N	EXCUSE	0
274407	273494	14195A	PARTICIPANT	\N	EXCUSE	0
274408	273494	19663E	PARTICIPANT	\N	EXCUSE	0
274409	273302	14211G	PARTICIPANT	\N	PRESENT	0
274410	273302	14079W	PARTICIPANT	\N	PRESENT	0
274411	273302	08056B	PARTICIPANT	\N	PRESENT	0
274890	263758	19723Y	PARTICIPANT	\N	PRESENT	0
275175	272043	04040A	PRESIDENT	0	PRESENT	0
275178	272043	14069U	PARTICIPANT	\N	PRESENT	0
275179	272043	19253P	PARTICIPANT	\N	PRESENT	0
275181	272043	08038Y	PARTICIPANT	\N	PRESENT	0
275182	272043	14327T	PARTICIPANT	\N	PRESENT	0
275184	272043	14281W	PARTICIPANT	\N	PRESENT	0
275185	272043	19565D	PARTICIPANT	\N	PRESENT	0
275186	272043	01057W	PARTICIPANT	\N	PRESENT	0
275190	272043	14028W	PARTICIPANT	\N	PRESENT	0
275193	272043	95067Q	PARTICIPANT	\N	PRESENT	0
275194	272043	95063L	PARTICIPANT	\N	PRESENT	0
275195	272043	19489J	PARTICIPANT	\N	PRESENT	0
275196	272043	08010L	PARTICIPANT	\N	PRESENT	0
275197	272043	14071N	PARTICIPANT	\N	PRESENT	0
275198	272043	14063N	PARTICIPANT	\N	PRESENT	0
275199	272043	14030Q	PARTICIPANT	\N	PRESENT	0
275200	272043	08043V	PARTICIPANT	\N	PRESENT	0
275201	272043	19621T	PARTICIPANT	\N	PRESENT	0
275202	272043	08020N	PARTICIPANT	\N	PRESENT	0
275203	272043	11031D	PARTICIPANT	\N	PRESENT	0
275204	272043	19693L	PARTICIPANT	\N	PRESENT	0
275205	272043	19715Y	PARTICIPANT	\N	PRESENT	0
275206	272043	19731Y	PARTICIPANT	\N	PRESENT	0
275207	272043	08031R	PARTICIPANT	\N	PRESENT	0
275208	272043	14109K	PARTICIPANT	\N	PRESENT	0
275209	272043	19749K	PARTICIPANT	\N	PRESENT	0
276053	276036	08009T	PRESIDENT	0	PRESENT	0
276054	276036	98023Q	PARTICIPANT	\N	PRESENT	0
276055	276036	14093U	PARTICIPANT	\N	EXCUSE	0
276056	276036	18083K	PARTICIPANT	\N	PRESENT	0
276057	276036	14051J	PARTICIPANT	\N	PRESENT	0
276058	276036	08060W	PARTICIPANT	\N	PRESENT	0
276059	276036	14157T	PARTICIPANT	\N	PRESENT	0
276101	276036	19549D	PARTICIPANT	\N	PRESENT	0
276102	276036	02002K	PARTICIPANT	\N	PRESENT	0
276103	276036	19503N	PARTICIPANT	\N	PRESENT	0
276104	276036	19685L	PARTICIPANT	\N	PRESENT	0
276105	276036	14031R	PARTICIPANT	\N	PRESENT	0
276106	276036	19713W	PARTICIPANT	\N	PRESENT	0
276107	276036	19737F	PARTICIPANT	\N	PRESENT	0
276108	276036	04097T	PARTICIPANT	\N	PRESENT	0
276109	276036	19347U	PARTICIPANT	\N	PRESENT	0
276110	276028	19697Q	PARTICIPANT	\N	PRESENT	0
276111	276028	04045F	PARTICIPANT	\N	PRESENT	0
276112	276028	14026U	PARTICIPANT	\N	PRESENT	0
276113	276028	11063M	PARTICIPANT	\N	PRESENT	0
276114	276028	14239U	PARTICIPANT	\N	PRESENT	0
276115	276028	04049K	PARTICIPANT	\N	PRESENT	0
276116	276028	14042U	PARTICIPANT	\N	PRESENT	0
276117	276028	14195A	PARTICIPANT	\N	PRESENT	0
276118	276028	14213J	PARTICIPANT	\N	PRESENT	0
276119	276028	10006L	PARTICIPANT	\N	PRESENT	0
276120	276028	19521Q	PARTICIPANT	\N	PRESENT	0
276121	276028	11045K	PARTICIPANT	\N	PRESENT	0
276122	276028	19727D	PARTICIPANT	\N	PRESENT	0
276123	276028	11103C	PARTICIPANT	\N	PRESENT	0
276124	276028	19335Q	PARTICIPANT	\N	PRESENT	0
276125	276028	08028W	PARTICIPANT	\N	PRESENT	0
276126	276028	19527W	PARTICIPANT	\N	PRESENT	0
276127	276028	01034P	PARTICIPANT	\N	PRESENT	0
276341	276038	01025N	PARTICIPANT	\N	PRESENT	0
276342	276038	07004J	PARTICIPANT	\N	PRESENT	0
276343	276038	14255U	PARTICIPANT	\N	PRESENT	0
276344	276038	14267Y	PARTICIPANT	\N	PRESENT	0
276345	276038	19581D	PARTICIPANT	\N	PRESENT	0
276346	276038	19369B	PARTICIPANT	\N	PRESENT	0
276348	276038	19671E	PARTICIPANT	\N	PRESENT	0
276349	276038	14275Y	PARTICIPANT	\N	PRESENT	0
276350	276038	14079W	PARTICIPANT	\N	PRESENT	0
276351	276038	01034P	PARTICIPANT	\N	PRESENT	0
276352	276038	19735D	PARTICIPANT	\N	PRESENT	0
276353	276038	19747H	PARTICIPANT	\N	PRESENT	0
276354	276038	14042U	PARTICIPANT	\N	PRESENT	0
276355	276038	14219Q	PARTICIPANT	\N	PRESENT	0
276356	276038	14217N	PARTICIPANT	\N	PRESENT	0
276357	276038	16685X	PARTICIPANT	\N	PRESENT	0
276358	276038	07033P	PARTICIPANT	\N	PRESENT	0
276359	276038	14103D	PARTICIPANT	\N	PRESENT	0
276360	276038	97011G	PARTICIPANT	\N	PRESENT	0
276361	276038	08056B	PARTICIPANT	\N	PRESENT	0
276362	276038	19691J	PARTICIPANT	\N	PRESENT	0
276363	276038	19569H	PARTICIPANT	\N	PRESENT	0
276364	276038	11048N	PARTICIPANT	\N	PRESENT	0
276365	276038	04061F	PARTICIPANT	\N	PRESENT	0
276366	276038	04049K	PARTICIPANT	\N	PRESENT	0
276367	276038	14105F	PARTICIPANT	\N	PRESENT	0
276368	276038	19521Q	PARTICIPANT	\N	PRESENT	0
276369	276038	04070G	PARTICIPANT	\N	PRESENT	0
276370	276038	14115H	PARTICIPANT	\N	PRESENT	0
276371	276038	11049P	PARTICIPANT	\N	PRESENT	0
276372	276038	19619A	PARTICIPANT	\N	PRESENT	0
276373	276038	14119M	PARTICIPANT	\N	PRESENT	0
276374	276038	14083S	PARTICIPANT	\N	PRESENT	0
276375	276038	11053K	PARTICIPANT	\N	PRESENT	0
276382	276038	98005N	PARTICIPANT	\N	PRESENT	0
276377	276038	14327T	PARTICIPANT	\N	PRESENT	0
276378	276038	14030Q	PARTICIPANT	\N	PRESENT	0
276379	276038	01024M	PARTICIPANT	\N	PRESENT	0
276380	276038	11085T	PARTICIPANT	\N	PRESENT	0
276381	276038	14133K	PARTICIPANT	\N	PRESENT	0
276383	276038	08044W	PARTICIPANT	\N	PRESENT	0
276384	276038	14231L	PARTICIPANT	\N	PRESENT	0
276385	276038	14073Q	PARTICIPANT	\N	PRESENT	0
276386	276038	19699S	PARTICIPANT	\N	PRESENT	0
276387	276038	19447X	PARTICIPANT	\N	PRESENT	0
276388	276038	14089Y	PARTICIPANT	\N	PRESENT	0
276389	276038	19721W	PARTICIPANT	\N	PRESENT	0
276390	276038	19507S	PARTICIPANT	\N	PRESENT	0
276391	276038	19467C	PARTICIPANT	\N	PRESENT	0
276392	276038	19749K	PARTICIPANT	\N	PRESENT	0
275299	275298	14109K	PARTICIPANT	\N	PRESENT	0
275300	275298	04018C	PARTICIPANT	\N	PRESENT	0
275301	275298	19611R	PARTICIPANT	\N	PRESENT	0
275302	275298	08043V	PARTICIPANT	\N	PRESENT	0
275303	275298	19749K	PARTICIPANT	\N	PRESENT	0
275304	275298	08031R	PARTICIPANT	\N	PRESENT	0
275306	275305	08031R	PARTICIPANT	\N	PRESENT	0
275307	275305	19611R	PARTICIPANT	\N	PRESENT	0
275308	275305	04018C	PARTICIPANT	\N	PRESENT	0
275310	275305	08043V	PARTICIPANT	\N	PRESENT	0
275312	275305	19749K	PARTICIPANT	\N	PRESENT	0
275313	275305	14109K	PARTICIPANT	\N	PRESENT	0
275314	275305	04057K	PARTICIPANT	\N	PRESENT	0
275316	275315	04018C	PARTICIPANT	\N	PRESENT	0
275317	275315	08043V	PARTICIPANT	\N	PRESENT	0
275318	275315	08031R	PARTICIPANT	\N	PRESENT	0
275319	275315	04057K	PARTICIPANT	\N	PRESENT	0
275345	275342	14030Q	PARTICIPANT	\N	PRESENT	0
275354	275342	19515S	PARTICIPANT	\N	PRESENT	0
275356	275342	08024S	PARTICIPANT	\N	PRESENT	0
275357	275342	97011G	PARTICIPANT	\N	PRESENT	0
275360	275342	14241N	PARTICIPANT	\N	PRESENT	0
275361	275342	08017T	PARTICIPANT	\N	PRESENT	0
275362	275342	04018C	PARTICIPANT	\N	PRESENT	0
280691	279377	11109J	PARTICIPANT	\N	PRESENT	0
280692	279377	19631V	PARTICIPANT	\N	PRESENT	0
280693	279377	19295A	PARTICIPANT	\N	PRESENT	0
280694	279377	19715Y	PARTICIPANT	\N	PRESENT	0
280695	279377	14097Y	PARTICIPANT	\N	PRESENT	0
280696	279377	98005N	PARTICIPANT	\N	PRESENT	0
280697	279377	19729F	PARTICIPANT	\N	PRESENT	0
280699	279377	14219Q	PARTICIPANT	\N	PRESENT	0
280700	279377	19583F	PARTICIPANT	\N	PRESENT	0
280702	279377	08019V	PRESIDENT	0	PRESENT	0
280703	279377	19657G	PARTICIPANT	\N	PRESENT	0
280704	279377	11072N	PARTICIPANT	\N	PRESENT	0
280705	279377	19301E	PARTICIPANT	\N	PRESENT	0
281774	276025	14093U	PARTICIPANT	\N	PRESENT	0
281775	276025	80013X	PARTICIPANT	\N	PRESENT	0
281776	276025	19663E	PARTICIPANT	\N	PRESENT	0
281777	276025	19553Y	PARTICIPANT	\N	PRESENT	0
281778	276025	19511N	PARTICIPANT	\N	PRESENT	0
281779	276025	19683J	PARTICIPANT	\N	PRESENT	0
287177	286214	14133K	PARTICIPANT	\N	PRESENT	0
281781	276025	19723Y	PARTICIPANT	\N	PRESENT	0
281782	276025	01048V	PRESIDENT	0	PRESENT	0
281783	276025	19503N	PARTICIPANT	\N	PRESENT	0
281784	276025	01058X	PARTICIPANT	\N	PRESENT	0
287150	287012	14215L	PARTICIPANT	\N	PRESENT	0
287151	287012	08018U	PARTICIPANT	\N	PRESENT	0
287152	287012	11072N	PARTICIPANT	\N	PRESENT	0
287153	287012	14053L	PARTICIPANT	\N	PRESENT	0
287154	287012	14111D	PARTICIPANT	\N	PRESENT	0
287155	287012	19649G	PARTICIPANT	\N	PRESENT	0
287156	287012	07034Q	PARTICIPANT	\N	PRESENT	0
287157	287012	10015M	PARTICIPANT	\N	PRESENT	0
287450	285994	11053K	PARTICIPANT	\N	PRESENT	0
287159	287012	11026G	PARTICIPANT	\N	PRESENT	0
287160	287012	19253P	PARTICIPANT	\N	PRESENT	0
287161	287012	01024M	PARTICIPANT	\N	PRESENT	0
287162	287012	04038G	PARTICIPANT	\N	PRESENT	0
287451	285994	19667J	PARTICIPANT	\N	PRESENT	0
287164	287012	11033F	PARTICIPANT	\N	PRESENT	0
287452	285994	14034U	PARTICIPANT	\N	PRESENT	0
287166	287012	19725B	PARTICIPANT	\N	PRESENT	0
287167	287012	19729F	PARTICIPANT	\N	PRESENT	0
287168	287012	19629C	PARTICIPANT	\N	PRESENT	0
287169	287012	08044W	PARTICIPANT	\N	PRESENT	0
287170	287012	11049P	PARTICIPANT	\N	PRESENT	0
287171	287012	04008A	PARTICIPANT	\N	PRESENT	0
287172	287012	14021P	PARTICIPANT	\N	PRESENT	0
287173	287012	14089Y	PARTICIPANT	\N	PRESENT	0
287174	287012	14065Q	PARTICIPANT	\N	PRESENT	0
287175	287012	14069U	PARTICIPANT	\N	PRESENT	0
287176	287012	19719D	PARTICIPANT	\N	EXCUSE	0
287220	286215	11064N	PARTICIPANT	\N	PRESENT	0
287221	287012	98035U	PARTICIPANT	\N	PRESENT	0
287222	287012	11085T	PARTICIPANT	\N	PRESENT	0
287223	286235	17637T	PARTICIPANT	\N	PRESENT	0
287224	285994	19689Q	PARTICIPANT	\N	PRESENT	0
287225	285994	14083S	PARTICIPANT	\N	PRESENT	0
287226	285994	19741B	PARTICIPANT	\N	PRESENT	0
287227	287012	95063L	PARTICIPANT	\N	PRESENT	0
287228	286590	19329S	PARTICIPANT	\N	PRESENT	0
287229	286590	08016S	PARTICIPANT	\N	PRESENT	0
287230	286590	19593H	PARTICIPANT	\N	PRESENT	0
287231	286590	19643A	PARTICIPANT	\N	PRESENT	0
287232	286590	19693L	PARTICIPANT	\N	PRESENT	0
287233	286590	14251Q	PARTICIPANT	\N	PRESENT	0
287234	286590	19735D	PARTICIPANT	\N	PRESENT	0
287235	286590	11109J	PARTICIPANT	\N	PRESENT	0
287236	286590	14063N	PARTICIPANT	\N	PRESENT	0
287237	286590	11083R	PARTICIPANT	\N	PRESENT	0
287238	286590	14123H	PARTICIPANT	\N	PRESENT	0
287239	286590	11043H	PARTICIPANT	\N	PRESENT	0
287240	286590	19749K	PARTICIPANT	\N	PRESENT	0
287241	286590	19758L	PARTICIPANT	\N	EXCUSE	0
287242	286592	04070G	PRESIDENT	0	PRESENT	0
287243	286592	19699S	PARTICIPANT	\N	PRESENT	0
287244	286592	19533U	PARTICIPANT	\N	PRESENT	0
287245	286592	95015C	PARTICIPANT	\N	PRESENT	0
287246	286592	19329S	PARTICIPANT	\N	PRESENT	0
287247	286592	14241N	PARTICIPANT	\N	PRESENT	0
287248	286592	19573D	PARTICIPANT	\N	PRESENT	0
287249	286592	14039A	PARTICIPANT	\N	PRESENT	0
287250	286592	14107H	PARTICIPANT	\N	PRESENT	0
287251	286592	08017T	PARTICIPANT	\N	PRESENT	0
287252	286592	08012N	PARTICIPANT	\N	PRESENT	0
287253	286592	08016S	PARTICIPANT	\N	PRESENT	0
287254	286592	08039A	PARTICIPANT	\N	PRESENT	0
287255	286592	08031R	PARTICIPANT	\N	PRESENT	0
287256	286592	19593H	PARTICIPANT	\N	PRESENT	0
287257	286592	14059S	PARTICIPANT	\N	PRESENT	0
287258	286592	14061L	PARTICIPANT	\N	PRESENT	0
287259	286592	14073Q	PARTICIPANT	\N	PRESENT	0
287260	286592	19611R	PARTICIPANT	\N	PRESENT	0
287261	286592	08043V	PARTICIPANT	\N	PRESENT	0
287262	286592	19693L	PARTICIPANT	\N	PRESENT	0
287263	286592	19399H	PARTICIPANT	\N	PRESENT	0
287264	286592	87003B	PARTICIPANT	\N	PRESENT	0
287265	286592	14030Q	PARTICIPANT	\N	PRESENT	0
287266	286592	19731Y	PARTICIPANT	\N	PRESENT	0
287267	286592	14251Q	PARTICIPANT	\N	PRESENT	0
287268	286592	04059M	PARTICIPANT	\N	PRESENT	0
287269	286592	19735D	PARTICIPANT	\N	PRESENT	0
287270	286592	11109J	PARTICIPANT	\N	PRESENT	0
287271	286592	14063N	PARTICIPANT	\N	PRESENT	0
287272	286592	14123H	PARTICIPANT	\N	PRESENT	0
287273	286592	11104D	PARTICIPANT	\N	PRESENT	0
287274	286592	11043H	PARTICIPANT	\N	PRESENT	0
287275	286592	19749K	PARTICIPANT	\N	PRESENT	0
287276	286592	04018C	PARTICIPANT	\N	PRESENT	0
287277	286592	19621T	PARTICIPANT	\N	PRESENT	0
287278	286592	19758L	PARTICIPANT	\N	EXCUSE	0
287279	286592	14229S	PARTICIPANT	\N	EXCUSE	0
287280	286592	08020N	PARTICIPANT	\N	PRESENT	0
287281	286592	11083R	PARTICIPANT	\N	PRESENT	0
287362	287012	19543W	PARTICIPANT	0	PRESENT	0
287363	287012	14259Y	PARTICIPANT	\N	PRESENT	0
287453	285994	19719D	PARTICIPANT	\N	PRESENT	0
287597	273914	04018C	PARTICIPANT	\N	PRESENT	0
287598	273914	19631V	PARTICIPANT	\N	PRESENT	0
287599	273914	19421M	PARTICIPANT	\N	PRESENT	0
287600	273914	19599P	PARTICIPANT	\N	PRESENT	0
287602	273914	14033T	PARTICIPANT	\N	PRESENT	0
287607	273914	14179A	PARTICIPANT	\N	PRESENT	0
287608	273914	80013X	PARTICIPANT	\N	PRESENT	0
287609	273914	14241N	PARTICIPANT	\N	PRESENT	0
287610	273914	01057W	PARTICIPANT	\N	PRESENT	0
287611	273914	14275Y	PARTICIPANT	\N	PRESENT	0
287612	273914	14197C	PARTICIPANT	\N	PRESENT	0
287613	273914	19581D	PARTICIPANT	\N	PRESENT	0
287614	273914	01058X	PARTICIPANT	\N	PRESENT	0
287615	273914	01034P	PARTICIPANT	\N	PRESENT	0
287616	273914	18083K	PARTICIPANT	\N	PRESENT	0
287617	273914	08018U	PARTICIPANT	\N	PRESENT	0
287618	273914	14069U	PARTICIPANT	\N	PRESENT	0
287621	273914	14059S	PARTICIPANT	\N	PRESENT	0
287622	273914	19713W	PARTICIPANT	\N	PRESENT	0
287623	273914	11097X	PARTICIPANT	\N	PRESENT	0
287624	273914	19689Q	PARTICIPANT	\N	PRESENT	0
287625	273914	14121F	PARTICIPANT	\N	PRESENT	0
287626	273914	14107H	PARTICIPANT	\N	PRESENT	0
287627	273914	14199E	PARTICIPANT	\N	PRESENT	0
287628	273914	14073Q	PARTICIPANT	\N	PRESENT	0
287629	273914	11099A	PARTICIPANT	\N	PRESENT	0
271557	263475	04086Q	PARTICIPANT	\N	PRESENT	0
271566	263475	11040E	PARTICIPANT	\N	PRESENT	0
271567	263475	11026G	PARTICIPANT	\N	PRESENT	0
271572	263475	08018U	PARTICIPANT	\N	PRESENT	0
271573	263475	19707Y	PARTICIPANT	\N	PRESENT	0
271574	263475	19383Y	PARTICIPANT	\N	PRESENT	0
271575	263475	04018C	PARTICIPANT	\N	PRESENT	0
271576	263475	08014Q	PARTICIPANT	\N	PRESENT	0
271577	263475	98022P	PARTICIPANT	\N	PRESENT	0
271579	263475	04034C	PARTICIPANT	\N	PRESENT	0
271580	263475	19441R	PARTICIPANT	\N	PRESENT	0
271581	263475	14041T	PARTICIPANT	\N	PRESENT	0
271582	263475	07029T	PARTICIPANT	\N	PRESENT	0
271583	263475	19399H	PARTICIPANT	\N	PRESENT	0
271584	263475	19705W	PARTICIPANT	\N	PRESENT	0
271585	263475	08010L	PARTICIPANT	\N	PRESENT	0
271587	263475	97011G	PARTICIPANT	\N	PRESENT	0
271588	263475	11103C	PARTICIPANT	\N	PRESENT	0
271589	263475	19621T	PARTICIPANT	\N	PRESENT	0
271590	263475	14079W	PARTICIPANT	\N	PRESENT	0
271591	263475	19747H	PARTICIPANT	\N	PRESENT	0
271592	263475	14083S	PARTICIPANT	\N	PRESENT	0
271594	263475	08058D	PARTICIPANT	\N	PRESENT	0
271597	263475	08031R	PARTICIPANT	\N	PRESENT	0
271598	263475	04088S	PARTICIPANT	\N	PRESENT	0
271599	263475	19737F	PARTICIPANT	\N	PRESENT	0
271600	263475	14255U	PARTICIPANT	\N	PRESENT	0
271601	263475	19413M	PARTICIPANT	\N	PRESENT	0
271602	263475	14038Y	PARTICIPANT	\N	PRESENT	0
271603	263475	19709B	PARTICIPANT	\N	PRESENT	0
271604	263475	19681G	PARTICIPANT	\N	PRESENT	0
271605	263475	19573D	PARTICIPANT	\N	PRESENT	0
271606	263475	04035D	PARTICIPANT	\N	PRESENT	0
271607	263475	11012A	PARTICIPANT	\N	PRESENT	0
271608	263475	14237S	PARTICIPANT	\N	PRESENT	0
271609	263475	14030Q	PARTICIPANT	\N	PRESENT	0
271610	263475	19713W	PARTICIPANT	\N	PRESENT	0
271611	263475	14115H	PARTICIPANT	\N	PRESENT	0
271612	263475	08056B	PARTICIPANT	\N	PRESENT	0
271613	263475	14241N	PARTICIPANT	\N	PRESENT	0
271615	263475	14191V	PARTICIPANT	\N	PRESENT	0
271616	263475	01025N	PARTICIPANT	\N	PRESENT	0
271617	263475	11110B	PARTICIPANT	\N	PRESENT	0
271618	263475	14227Q	PARTICIPANT	\N	PRESENT	0
271619	263475	08017T	PARTICIPANT	\N	PRESENT	0
271620	263475	14123H	PARTICIPANT	\N	PRESENT	0
271622	263475	11064N	PARTICIPANT	\N	PRESENT	0
271623	263475	14069U	PARTICIPANT	\N	PRESENT	0
271624	263475	14073Q	PARTICIPANT	\N	PRESENT	0
271638	263475	14109K	PARTICIPANT	\N	PRESENT	0
271639	263475	14225N	PARTICIPANT	\N	PRESENT	0
271640	263475	14213J	PARTICIPANT	\N	PRESENT	0
271646	263475	08043V	PARTICIPANT	\N	PRESENT	0
271647	263475	14197C	PARTICIPANT	\N	PRESENT	0
271648	263475	14029X	PARTICIPANT	\N	PRESENT	0
271649	263475	19629C	PARTICIPANT	\N	PRESENT	0
271650	263475	95030B	PARTICIPANT	\N	PRESENT	0
271651	263475	08069G	PARTICIPANT	\N	PRESENT	0
271652	263475	10006L	PARTICIPANT	\N	PRESENT	0
271653	263475	08015R	PARTICIPANT	\N	PRESENT	0
271654	263475	19611R	PARTICIPANT	\N	PRESENT	0
271655	263475	14033T	PARTICIPANT	\N	PRESENT	0
271660	263475	14119M	PARTICIPANT	\N	PRESENT	0
277621	276029	14239U	PARTICIPANT	\N	EXCUSE	0
277930	275756	14327T	PARTICIPANT	\N	PRESENT	0
277931	275756	19479G	PARTICIPANT	\N	PRESENT	0
277932	275756	19711U	PARTICIPANT	\N	PRESENT	0
277933	275756	19651A	PARTICIPANT	\N	PRESENT	0
277934	275756	08069G	PARTICIPANT	\N	PRESENT	0
277935	275756	01057W	PARTICIPANT	\N	PRESENT	0
277936	275756	11074Q	PRESIDENT	0	PRESENT	0
277937	275756	14026U	RAPPORTEUR_AVIS	\N	PRESENT	0
277938	275756	04086Q	PARTICIPANT	\N	PRESENT	0
277939	275756	14083S	PARTICIPANT	\N	PRESENT	0
277940	275756	14277B	PARTICIPANT	\N	PRESENT	0
277941	275756	08073C	PARTICIPANT	\N	PRESENT	0
277942	275756	07004J	PARTICIPANT	\N	PRESENT	0
277943	275756	19349W	PARTICIPANT	\N	PRESENT	0
277944	275756	19741B	PARTICIPANT	\N	PRESENT	0
277945	275756	08010L	PARTICIPANT	\N	PRESENT	0
277946	275756	14253S	PARTICIPANT	\N	PRESENT	0
277947	275756	08011M	PARTICIPANT	\N	EXCUSE	0
277948	275756	08014Q	PARTICIPANT	\N	EXCUSE	0
277949	275756	01048V	PARTICIPANT	\N	PRESENT	0
277950	275756	89017R	PARTICIPANT	\N	PRESENT	0
277951	275756	14225N	PARTICIPANT	\N	PRESENT	0
277952	275756	88008L	PARTICIPANT	\N	PRESENT	0
277953	275756	11110B	PARTICIPANT	\N	PRESENT	0
277954	275756	07029T	PARTICIPANT	\N	PRESENT	0
277955	275756	14085U	PARTICIPANT	\N	PRESENT	0
277956	275756	14159V	PARTICIPANT	\N	PRESENT	0
277957	275756	14173T	PARTICIPANT	\N	PRESENT	0
277958	275756	11040E	PARTICIPANT	\N	PRESENT	0
277959	275756	14199E	PARTICIPANT	\N	PRESENT	0
277960	275756	11012A	PARTICIPANT	\N	PRESENT	0
277961	275756	14121F	PARTICIPANT	\N	PRESENT	0
277962	275756	99004R	PARTICIPANT	\N	PRESENT	0
277963	275756	04061F	PARTICIPANT	\N	PRESENT	0
277964	275756	14331P	PARTICIPANT	\N	PRESENT	0
277965	275756	19667J	PARTICIPANT	\N	PRESENT	0
277966	275756	19531S	PARTICIPANT	\N	PRESENT	0
277967	275756	08034U	PARTICIPANT	\N	PRESENT	0
277968	275756	14034U	PARTICIPANT	\N	PRESENT	0
277974	275134	19443T	PARTICIPANT	\N	PRESENT	0
277975	275134	95030B	PARTICIPANT	\N	PRESENT	0
277976	275134	04034C	PARTICIPANT	\N	PRESENT	0
277977	275134	01058X	PARTICIPANT	\N	PRESENT	0
277978	275134	04040A	PARTICIPANT	\N	PRESENT	0
277979	275134	16685X	PARTICIPANT	\N	PRESENT	0
277980	275134	04042C	PRESIDENT	0	PRESENT	0
277981	275134	11054L	PARTICIPANT	\N	PRESENT	0
277982	275134	11066Q	PARTICIPANT	\N	PRESENT	0
277983	275134	95037J	PARTICIPANT	\N	PRESENT	0
277984	275134	14055N	PARTICIPANT	\N	PRESENT	0
277985	275134	19421M	PARTICIPANT	\N	PRESENT	0
277986	275134	19709B	PARTICIPANT	\N	PRESENT	0
277987	275134	08047A	PARTICIPANT	\N	PRESENT	0
277988	275134	98029W	PARTICIPANT	\N	PRESENT	0
277989	275134	14097Y	PARTICIPANT	\N	PRESENT	0
277990	275134	95067Q	PARTICIPANT	\N	PRESENT	0
277991	275134	14133K	PARTICIPANT	\N	PRESENT	0
277992	275134	11041F	PARTICIPANT	\N	PRESENT	0
277993	275134	14235Q	PARTICIPANT	\N	PRESENT	0
277994	275134	08058D	PARTICIPANT	\N	PRESENT	0
277995	275134	14028W	PARTICIPANT	\N	PRESENT	0
277996	275134	19251M	PARTICIPANT	\N	PRESENT	0
277997	275134	19721W	PARTICIPANT	\N	PRESENT	0
277998	275134	19319Q	PARTICIPANT	\N	PRESENT	0
277999	275134	14105F	PARTICIPANT	\N	PRESENT	0
278000	275134	98018T	PARTICIPANT	\N	PRESENT	0
278001	275134	98022P	PARTICIPANT	\N	PRESENT	0
278002	275134	14267Y	PARTICIPANT	\N	PRESENT	0
278003	275134	11064N	PARTICIPANT	\N	PRESENT	0
278004	275134	98050T	PARTICIPANT	\N	PRESENT	0
278005	275134	14255U	PARTICIPANT	\N	PRESENT	0
278006	275134	97011G	PARTICIPANT	\N	PRESENT	0
278007	275134	08053X	PARTICIPANT	\N	PRESENT	0
278008	275134	08061X	PARTICIPANT	\N	PRESENT	0
278009	275134	01062T	PARTICIPANT	\N	PRESENT	0
278010	275842	14135M	PARTICIPANT	\N	PRESENT	0
278011	275842	19467C	PARTICIPANT	\N	PRESENT	0
278012	275842	19515S	PARTICIPANT	\N	PRESENT	0
278013	275842	14357A	PARTICIPANT	\N	PRESENT	0
278014	275842	14187A	PARTICIPANT	\N	PRESENT	0
278015	275842	08062Y	PARTICIPANT	\N	PRESENT	0
278016	275842	11090Q	PRESIDENT	0	PRESENT	0
278017	275842	04088S	PARTICIPANT	\N	PRESENT	0
278018	275842	14115H	PARTICIPANT	\N	PRESENT	0
278019	275842	04049K	PARTICIPANT	\N	PRESENT	0
278020	275842	19705W	PARTICIPANT	\N	PRESENT	0
278021	275842	19707Y	PARTICIPANT	\N	PRESENT	0
278022	275842	11101A	PARTICIPANT	\N	PRESENT	0
278023	275842	08015R	PARTICIPANT	\N	PRESENT	0
278024	275842	08019V	PARTICIPANT	\N	PRESENT	0
278025	275842	19747H	PARTICIPANT	\N	PRESENT	0
278026	275842	04043D	PARTICIPANT	\N	PRESENT	0
278027	275842	08028W	PARTICIPANT	\N	PRESENT	0
278028	275842	14265W	PARTICIPANT	\N	PRESENT	0
278029	275842	14329V	PARTICIPANT	\N	PRESENT	0
278030	276033	04070G	PRESIDENT	0	PRESENT	0
278031	276033	19699S	PARTICIPANT	\N	PRESENT	0
278032	276033	12041X	PARTICIPANT	\N	PRESENT	0
278033	276033	19533U	PARTICIPANT	\N	PRESENT	0
278034	276033	95015C	PARTICIPANT	\N	PRESENT	0
278035	276033	04033B	PARTICIPANT	\N	PRESENT	0
278036	276033	19329S	PARTICIPANT	\N	PRESENT	0
278037	276033	14229S	PARTICIPANT	\N	PRESENT	0
278038	276033	14241N	PARTICIPANT	\N	PRESENT	0
278039	276033	19573D	PARTICIPANT	\N	PRESENT	0
275806	275805	05008E	PARTICIPANT	\N	PRESENT	0
275808	275807	05008E	PARTICIPANT	\N	PRESENT	0
275810	275809	05008E	PARTICIPANT	\N	PRESENT	0
275812	275811	05008E	PARTICIPANT	\N	PRESENT	0
275814	275813	05008E	PARTICIPANT	\N	PRESENT	0
275816	275815	05008E	PARTICIPANT	\N	PRESENT	0
275818	275817	05008E	PARTICIPANT	\N	PRESENT	0
279323	279322	04047H	PARTICIPANT	\N	PRESENT	0
279324	279322	19673G	PARTICIPANT	\N	PRESENT	0
279325	279322	11026G	PARTICIPANT	\N	PRESENT	0
279334	279330	14042U	PARTICIPANT	\N	PRESENT	0
299122	299099	14217N	PARTICIPANT	\N	PRESENT	0
299123	299099	14215L	PARTICIPANT	\N	PRESENT	0
299126	299099	08045X	PARTICIPANT	\N	PRESENT	0
299128	299099	14087W	PARTICIPANT	\N	PRESENT	0
299129	299099	14231L	PARTICIPANT	\N	PRESENT	0
299130	299099	19691J	PARTICIPANT	\N	EXCUSE	0
299132	299099	19697Q	PARTICIPANT	\N	PRESENT	0
299133	299099	14031R	PARTICIPANT	\N	EXCUSE	0
299135	299099	14147R	PARTICIPANT	\N	PRESENT	0
299136	299099	11067R	PARTICIPANT	\N	PRESENT	0
299137	299099	14223L	PARTICIPANT	\N	PRESENT	0
299139	299099	14119M	PARTICIPANT	\N	PRESENT	0
299140	299099	11045K	PARTICIPANT	\N	EXCUSE	0
299141	299099	04044E	PRESIDENT	0	PRESENT	0
299358	297354	19295A	PARTICIPANT	\N	EXCUSE	0
299359	297354	11010L	PARTICIPANT	\N	EXCUSE	0
299360	297354	19691J	PARTICIPANT	\N	EXCUSE	0
299361	297354	19583F	PARTICIPANT	\N	EXCUSE	0
299362	297354	98005N	PARTICIPANT	\N	EXCUSE	0
299364	297354	14275Y	PARTICIPANT	\N	EXCUSE	0
299864	299863	19667J	PARTICIPANT	\N	PRESENT	0
299865	299863	14255U	PARTICIPANT	\N	PRESENT	0
299866	299863	19701S	PARTICIPANT	\N	PRESENT	0
299867	299863	14281W	PARTICIPANT	\N	PRESENT	0
301006	301002	11109J	PARTICIPANT	\N	PRESENT	0
301007	301002	14195A	PARTICIPANT	\N	PRESENT	0
301008	301002	80013X	PARTICIPANT	\N	PRESENT	0
301009	301002	14327T	PARTICIPANT	\N	PRESENT	0
301011	301002	14213J	PARTICIPANT	\N	PRESENT	0
301012	301002	11099A	PARTICIPANT	\N	PRESENT	0
301014	301002	04049K	PARTICIPANT	\N	PRESENT	0
301015	301002	08015R	PARTICIPANT	\N	PRESENT	0
301017	301002	08039A	PARTICIPANT	\N	EXCUSE	0
301018	301002	19369B	PARTICIPANT	\N	EXCUSE	0
301019	301002	14109K	PARTICIPANT	\N	PRESENT	0
301020	301002	14169X	PARTICIPANT	\N	EXCUSE	0
301021	301002	19503N	PARTICIPANT	\N	PRESENT	0
301022	301002	04045F	PARTICIPANT	\N	EXCUSE	0
301036	289200	19629C	PARTICIPANT	\N	PRESENT	0
301037	289200	14327T	PARTICIPANT	\N	PRESENT	0
301039	301038	08015R	PARTICIPANT	\N	PRESENT	0
301040	301038	14105F	PARTICIPANT	\N	PRESENT	0
301041	301038	14207L	PARTICIPANT	\N	PRESENT	0
301251	289201	11070L	PARTICIPANT	\N	PRESENT	0
301046	301038	19723Y	PARTICIPANT	\N	PRESENT	0
301044	301038	19719D	PARTICIPANT	\N	PRESENT	0
301045	301038	04049K	PARTICIPANT	\N	PRESENT	0
301257	289201	14187A	PARTICIPANT	\N	PRESENT	0
301258	289201	11090Q	PARTICIPANT	\N	PRESENT	0
301259	289201	19565D	PARTICIPANT	\N	PRESENT	0
301260	289201	11099A	PARTICIPANT	\N	PRESENT	0
301261	289201	04057K	PARTICIPANT	\N	PRESENT	0
301262	289201	19681G	PARTICIPANT	\N	PRESENT	0
301263	289201	14079W	PARTICIPANT	\N	PRESENT	0
301264	289201	19611R	PARTICIPANT	\N	PRESENT	0
301265	289201	14215L	PARTICIPANT	\N	PRESENT	0
301266	289201	14087W	PARTICIPANT	\N	PRESENT	0
301267	289201	80013X	PARTICIPANT	\N	PRESENT	0
301268	289201	19295A	PARTICIPANT	\N	PRESENT	0
301269	289201	19727D	PARTICIPANT	\N	PRESENT	0
301270	289201	04043D	PARTICIPANT	\N	PRESENT	0
301271	289201	19711U	PARTICIPANT	\N	PRESENT	0
301272	289201	14265W	PARTICIPANT	\N	PRESENT	0
301273	289201	14041T	PARTICIPANT	\N	PRESENT	0
301274	289201	08018U	PARTICIPANT	\N	PRESENT	0
299118	299099	19253P	PARTICIPANT	\N	PRESENT	0
299120	299099	14041T	PARTICIPANT	\N	EXCUSE	0
301275	289201	98005N	PARTICIPANT	\N	PRESENT	0
301276	289201	14331P	PARTICIPANT	\N	PRESENT	0
301277	289201	19347U	PARTICIPANT	\N	PRESENT	0
301278	289201	08060W	PARTICIPANT	\N	PRESENT	0
301279	289201	08016S	PARTICIPANT	\N	PRESENT	0
301280	289201	14157T	PARTICIPANT	\N	PRESENT	0
301281	289201	14033T	PARTICIPANT	\N	PRESENT	0
301282	289201	19507S	PARTICIPANT	\N	PRESENT	0
301283	289201	11101A	PARTICIPANT	\N	PRESENT	0
301284	289201	19591F	PARTICIPANT	\N	PRESENT	0
301285	289201	11077T	PARTICIPANT	\N	PRESENT	0
301286	289201	95063L	PARTICIPANT	\N	PRESENT	0
301287	289201	14093U	PARTICIPANT	\N	PRESENT	0
301288	289201	19737F	PARTICIPANT	\N	PRESENT	0
301289	289201	19631V	PARTICIPANT	\N	PRESENT	0
301290	289201	14039A	PARTICIPANT	\N	PRESENT	0
301291	289201	19515S	PARTICIPANT	\N	PRESENT	0
301292	289201	19667J	PARTICIPANT	\N	PRESENT	0
301293	289201	19415P	PARTICIPANT	\N	PRESENT	0
301294	289201	19703U	PARTICIPANT	\N	PRESENT	0
301295	289201	14038Y	PARTICIPANT	\N	PRESENT	0
301296	289201	11033F	PARTICIPANT	\N	PRESENT	0
301297	289201	19695N	PARTICIPANT	\N	PRESENT	0
301298	289201	14034U	PARTICIPANT	\N	PRESENT	0
301299	289201	11012A	PARTICIPANT	\N	PRESENT	0
301300	289201	19253P	PARTICIPANT	\N	PRESENT	0
301301	289201	14205J	PARTICIPANT	\N	PRESENT	0
301302	289201	19749K	PARTICIPANT	\N	PRESENT	0
301303	289201	19369B	PARTICIPANT	\N	PRESENT	0
301304	289201	19745F	PARTICIPANT	\N	PRESENT	0
301305	289201	19671E	PARTICIPANT	\N	PRESENT	0
301306	289201	04018C	PARTICIPANT	\N	PRESENT	0
301307	289201	14357A	PARTICIPANT	\N	PRESENT	0
301308	289201	19651A	PARTICIPANT	\N	PRESENT	0
301309	289201	18083K	PARTICIPANT	\N	PRESENT	0
301311	289201	08019V	PARTICIPANT	\N	PRESENT	0
301312	289201	19399H	PARTICIPANT	\N	PRESENT	0
301313	289201	08034U	PARTICIPANT	\N	PRESENT	0
301314	289201	19443T	PARTICIPANT	\N	PRESENT	0
301316	289201	19673G	PARTICIPANT	\N	PRESENT	0
301317	289201	04088S	PARTICIPANT	\N	PRESENT	0
301318	289201	14327T	PARTICIPANT	\N	PRESENT	0
301319	289201	01028R	PARTICIPANT	\N	PRESENT	0
301320	289201	19687N	PARTICIPANT	\N	PRESENT	0
301321	289201	04086Q	PARTICIPANT	\N	PRESENT	0
301322	289201	04049K	PARTICIPANT	\N	PRESENT	0
301324	289201	04044E	PARTICIPANT	\N	PRESENT	0
301325	289201	12016W	PARTICIPANT	\N	PRESENT	0
301327	289201	14051J	PARTICIPANT	\N	PRESENT	0
301328	289201	19697Q	PARTICIPANT	\N	PRESENT	0
301329	289201	19717B	PARTICIPANT	\N	PRESENT	0
301330	289201	19563B	PARTICIPANT	\N	PRESENT	0
301331	289201	14231L	PARTICIPANT	\N	PRESENT	0
301332	289201	08038Y	PARTICIPANT	\N	PRESENT	0
301333	289201	99004R	PARTICIPANT	\N	PRESENT	0
301334	289201	19447X	PARTICIPANT	\N	PRESENT	0
301335	289201	04035D	PARTICIPANT	\N	PRESENT	0
301336	289201	11067R	PARTICIPANT	\N	PRESENT	0
301337	289201	19657G	PARTICIPANT	\N	PRESENT	0
301338	289201	14083S	PARTICIPANT	\N	PRESENT	0
301339	289201	01043Q	PARTICIPANT	\N	PRESENT	0
301340	289201	11056N	PARTICIPANT	\N	PRESENT	0
301341	289201	14229S	PARTICIPANT	\N	PRESENT	0
301342	289201	19289C	PARTICIPANT	\N	PRESENT	0
301343	289201	11065P	PARTICIPANT	\N	PRESENT	0
301344	289201	19599P	PARTICIPANT	\N	PRESENT	0
301345	289201	19713W	PARTICIPANT	\N	PRESENT	0
301346	289201	14042U	PARTICIPANT	\N	PRESENT	0
301348	301347	01024M	PARTICIPANT	\N	PRESENT	0
301350	301349	04047H	PARTICIPANT	\N	PRESENT	0
301351	301349	01024M	PARTICIPANT	\N	PRESENT	0
301353	301352	01024M	PARTICIPANT	\N	PRESENT	0
301355	301354	04047H	PARTICIPANT	\N	PRESENT	0
301356	301354	01024M	PARTICIPANT	\N	PRESENT	0
301358	301357	04047H	PARTICIPANT	\N	PRESENT	0
301359	301357	01024M	PARTICIPANT	\N	PRESENT	0
301362	289201	01058X	PARTICIPANT	\N	PRESENT	0
301363	289201	19629C	PARTICIPANT	\N	PRESENT	0
301364	289201	19647E	PARTICIPANT	\N	PRESENT	0
301365	289201	08017T	PARTICIPANT	\N	PRESENT	0
301366	289201	08015R	PARTICIPANT	\N	PRESENT	0
301367	289201	04085P	PARTICIPANT	\N	PRESENT	0
301368	289201	14219Q	PARTICIPANT	\N	PRESENT	0
301369	289201	19735D	PARTICIPANT	\N	PRESENT	0
301370	289201	19543W	PARTICIPANT	\N	PRESENT	0
301371	289201	11085T	PARTICIPANT	\N	PRESENT	0
301372	289201	04033B	PARTICIPANT	\N	PRESENT	0
301373	289201	04008A	PARTICIPANT	\N	PRESENT	0
301374	289201	17637T	PARTICIPANT	\N	PRESENT	0
301375	289201	08010L	PARTICIPANT	\N	PRESENT	0
301376	289201	19551W	PARTICIPANT	\N	PRESENT	0
276393	276038	18083K	PARTICIPANT	\N	PRESENT	0
276394	276038	08068F	PARTICIPANT	\N	PRESENT	0
276395	276038	19415P	PARTICIPANT	\N	PRESENT	0
276396	276038	14033T	PARTICIPANT	\N	PRESENT	0
276397	276038	19687N	PARTICIPANT	\N	PRESENT	0
276398	276038	11026G	PARTICIPANT	\N	PRESENT	0
276399	276038	19693L	PARTICIPANT	\N	PRESENT	0
276400	276038	19269X	PARTICIPANT	\N	PRESENT	0
276401	276038	04034C	PARTICIPANT	\N	PRESENT	0
276402	276038	14147R	PARTICIPANT	\N	PRESENT	0
276403	276038	19707Y	PARTICIPANT	\N	PRESENT	0
276404	276038	19705W	PARTICIPANT	\N	PRESENT	0
276405	276038	14265W	PARTICIPANT	\N	PRESENT	0
276406	276038	19729F	PARTICIPANT	\N	PRESENT	0
276407	276038	19443T	PARTICIPANT	\N	PRESENT	0
276408	276038	19741B	PARTICIPANT	\N	PRESENT	0
276410	276038	14029X	PARTICIPANT	\N	PRESENT	0
276412	276038	19709B	PARTICIPANT	\N	PRESENT	0
276414	276038	08019V	PARTICIPANT	\N	PRESENT	0
276415	276038	19651A	PARTICIPANT	\N	PRESENT	0
276416	276038	08018U	PARTICIPANT	\N	PRESENT	0
276417	276038	14041T	PARTICIPANT	\N	PRESENT	0
276418	276038	04088S	PARTICIPANT	\N	PRESENT	0
276419	276038	19367Y	PARTICIPANT	\N	PRESENT	0
276430	276038	04043D	PARTICIPANT	\N	PRESENT	0
276421	276038	98024R	PARTICIPANT	\N	PRESENT	0
276422	276038	14355X	PARTICIPANT	\N	PRESENT	0
276423	276038	08062Y	PARTICIPANT	\N	PRESENT	0
276425	276038	14187A	PARTICIPANT	\N	PRESENT	0
276428	276038	19663E	PARTICIPANT	\N	PRESENT	0
276441	276038	19733B	PARTICIPANT	\N	PRESENT	0
276433	276038	07029T	PARTICIPANT	\N	PRESENT	0
276434	276038	08015R	PARTICIPANT	\N	PRESENT	0
276435	276038	14151M	PARTICIPANT	\N	PRESENT	0
276436	276038	08021P	PARTICIPANT	\N	PRESENT	0
276437	276038	14061L	PARTICIPANT	\N	PRESENT	0
276442	276038	11063M	PARTICIPANT	\N	PRESENT	0
276444	276038	04038G	PARTICIPANT	\N	PRESENT	0
276445	276038	14357A	PARTICIPANT	\N	PRESENT	0
276446	276038	95063L	PARTICIPANT	\N	PRESENT	0
276447	276038	19713W	PARTICIPANT	\N	PRESENT	0
276448	276038	19621T	PARTICIPANT	\N	PRESENT	0
276450	276038	11080N	PARTICIPANT	\N	PRESENT	0
276451	276038	14179A	PARTICIPANT	\N	PRESENT	0
276452	276038	11110B	PARTICIPANT	\N	PRESENT	0
276456	276038	08009T	PARTICIPANT	\N	PRESENT	0
276454	276038	14213J	PARTICIPANT	\N	PRESENT	0
276455	276038	11041F	PARTICIPANT	\N	PRESENT	0
276457	276038	14221J	PARTICIPANT	\N	PRESENT	0
276458	276038	19573D	PARTICIPANT	\N	PRESENT	0
276459	276038	14329V	PARTICIPANT	\N	PRESENT	0
276460	276038	19701S	PARTICIPANT	\N	PRESENT	0
276461	276038	14123H	PARTICIPANT	\N	PRESENT	0
276462	276038	19383Y	PARTICIPANT	\N	PRESENT	0
276463	276038	14205J	PARTICIPANT	\N	PRESENT	0
276464	276038	19335Q	PARTICIPANT	\N	PRESENT	0
276467	276038	19479G	PARTICIPANT	\N	PRESENT	0
276468	276038	95067Q	PARTICIPANT	\N	PRESENT	0
276469	276038	19511N	PARTICIPANT	\N	PRESENT	0
276471	276038	17589D	PARTICIPANT	\N	PRESENT	0
276472	276038	14069U	PARTICIPANT	\N	PRESENT	0
276473	276038	14227Q	PARTICIPANT	\N	PRESENT	0
276476	276029	08048B	PARTICIPANT	\N	EXCUSE	0
276477	276029	14217N	PARTICIPANT	\N	EXCUSE	0
276482	276038	14038Y	PARTICIPANT	\N	PRESENT	0
276805	263768	86034E	PARTICIPANT	\N	PRESENT	0
276806	263768	12041X	PARTICIPANT	\N	PRESENT	0
276807	263768	19565D	PARTICIPANT	\N	PRESENT	0
276808	263768	19695N	PARTICIPANT	\N	PRESENT	0
276809	263768	19593H	PARTICIPANT	\N	PRESENT	0
276810	263768	11033F	PARTICIPANT	\N	PRESENT	0
276811	263768	19687N	PARTICIPANT	\N	PRESENT	0
276812	263768	14235Q	PARTICIPANT	\N	PRESENT	0
276813	263768	04038G	PARTICIPANT	\N	PRESENT	0
276814	263768	14133K	PARTICIPANT	\N	PRESENT	0
276815	263768	19515S	PARTICIPANT	\N	PRESENT	0
276816	263768	19707Y	PARTICIPANT	\N	PRESENT	0
276817	263768	05008E	PARTICIPANT	\N	PRESENT	0
276818	263768	19741B	PARTICIPANT	\N	PRESENT	0
276819	263768	19667J	PARTICIPANT	\N	PRESENT	0
276820	263768	19575F	PARTICIPANT	\N	PRESENT	0
276821	263768	14115H	PARTICIPANT	\N	PRESENT	0
276822	263768	96004D	PARTICIPANT	\N	PRESENT	0
276823	263768	19367Y	PARTICIPANT	\N	PRESENT	0
276824	263768	14069U	PARTICIPANT	\N	PRESENT	0
276825	263768	19415P	PARTICIPANT	\N	PRESENT	0
276826	263768	19733B	PARTICIPANT	\N	PRESENT	0
276827	263768	14105F	PARTICIPANT	\N	PRESENT	0
276828	263768	19643A	PARTICIPANT	\N	PRESENT	0
276829	263768	19747H	PARTICIPANT	\N	PRESENT	0
276830	263768	19651A	PARTICIPANT	\N	PRESENT	0
276831	263768	19383Y	PARTICIPANT	\N	PRESENT	0
276832	263768	19621T	PARTICIPANT	\N	PRESENT	0
276833	263768	08020N	PARTICIPANT	\N	PRESENT	0
276834	263768	04047H	PARTICIPANT	\N	PRESENT	0
276835	263768	11101A	PARTICIPANT	\N	PRESENT	0
276836	263768	04042C	PARTICIPANT	\N	PRESENT	0
276837	263768	95063L	PARTICIPANT	\N	PRESENT	0
276838	263768	08061X	PARTICIPANT	\N	PRESENT	0
276839	263768	14053L	PARTICIPANT	\N	PRESENT	0
276840	263768	11103C	PARTICIPANT	\N	PRESENT	0
276841	263768	95015C	PARTICIPANT	\N	PRESENT	0
276842	263768	14329V	PARTICIPANT	\N	PRESENT	0
276843	263768	14038Y	PARTICIPANT	\N	PRESENT	0
276844	263768	11080N	PARTICIPANT	\N	PRESENT	0
276845	263768	08028W	PARTICIPANT	\N	PRESENT	0
276846	263768	19467C	PARTICIPANT	\N	PRESENT	0
276847	263768	19701S	PARTICIPANT	\N	PRESENT	0
276848	263768	98023Q	PARTICIPANT	\N	PRESENT	0
276849	263768	11115U	PARTICIPANT	\N	PRESENT	0
276850	263768	18083K	PARTICIPANT	\N	PRESENT	0
276851	263768	14357A	PARTICIPANT	\N	PRESENT	0
276852	263768	89017R	PARTICIPANT	\N	PRESENT	0
276853	263768	14079W	PARTICIPANT	\N	PRESENT	0
276854	263768	19685L	PARTICIPANT	\N	PRESENT	0
276855	263768	19731Y	PARTICIPANT	\N	PRESENT	0
276856	263768	01060R	PARTICIPANT	\N	PRESENT	0
276857	263768	19745F	PARTICIPANT	\N	PRESENT	0
276858	263768	95037J	PARTICIPANT	\N	PRESENT	0
276859	263768	98029W	PARTICIPANT	\N	PRESENT	0
276860	263768	04086Q	PARTICIPANT	\N	PRESENT	0
276861	263768	04045F	PARTICIPANT	\N	PRESENT	0
276862	263768	19693L	PARTICIPANT	\N	PRESENT	0
276863	263768	04034C	PARTICIPANT	\N	PRESENT	0
276864	263768	14259Y	PARTICIPANT	\N	PRESENT	0
276865	263768	98018T	PARTICIPANT	\N	PRESENT	0
276866	263768	19663E	PARTICIPANT	\N	PRESENT	0
276867	263768	19659J	PARTICIPANT	\N	PRESENT	0
276868	263768	98024R	PARTICIPANT	\N	PRESENT	0
276869	263768	10006L	PARTICIPANT	\N	PRESENT	0
276870	263768	19349W	PARTICIPANT	\N	PRESENT	0
276871	263768	14041T	PARTICIPANT	\N	PRESENT	0
276872	263768	19637C	PARTICIPANT	\N	PRESENT	0
276873	263768	14217N	PARTICIPANT	\N	PRESENT	0
276874	263768	14215L	PARTICIPANT	\N	PRESENT	0
276875	263768	11072N	PARTICIPANT	\N	PRESENT	0
276876	263768	11083R	PARTICIPANT	\N	PRESENT	0
276877	263768	04071H	PARTICIPANT	\N	PRESENT	0
276878	263768	87003B	PARTICIPANT	\N	PRESENT	0
276879	263768	07033P	PARTICIPANT	\N	PRESENT	0
276880	263768	19507S	PARTICIPANT	\N	PRESENT	0
276888	263768	19673G	PARTICIPANT	\N	PRESENT	0
276882	263768	95030B	PARTICIPANT	\N	PRESENT	0
276883	263768	19269X	PARTICIPANT	\N	PRESENT	0
276884	263768	19697Q	PARTICIPANT	\N	PRESENT	0
276885	263768	08021P	PARTICIPANT	\N	PRESENT	0
276887	263768	14187A	PARTICIPANT	\N	PRESENT	0
276889	263768	19329S	PARTICIPANT	\N	PRESENT	0
276890	263768	14087W	PARTICIPANT	\N	PRESENT	0
276891	263768	97011G	PARTICIPANT	\N	PRESENT	0
276892	263768	08018U	PARTICIPANT	\N	PRESENT	0
276893	263768	14039A	PARTICIPANT	\N	PRESENT	0
276899	263768	19717B	PARTICIPANT	\N	PRESENT	0
276895	263768	04035D	PARTICIPANT	\N	PRESENT	0
276896	263768	14199E	PARTICIPANT	\N	PRESENT	0
276897	263768	14355X	PARTICIPANT	\N	PRESENT	0
276898	263768	14261S	PARTICIPANT	\N	PRESENT	0
276900	263768	15447F	PARTICIPANT	\N	PRESENT	0
276901	263768	19629C	PARTICIPANT	\N	PRESENT	0
276902	263768	14211G	PARTICIPANT	\N	PRESENT	0
276903	263768	14033T	PARTICIPANT	\N	PRESENT	0
276904	263768	14034U	PARTICIPANT	\N	PRESENT	0
276905	263768	08031R	PARTICIPANT	\N	PRESENT	0
276906	263768	11049P	PARTICIPANT	\N	PRESENT	0
276907	263768	08016S	PARTICIPANT	\N	PRESENT	0
276908	263768	14123H	PARTICIPANT	\N	PRESENT	0
276909	263768	14026U	PARTICIPANT	\N	PRESENT	0
276910	263768	98022P	PARTICIPANT	\N	PRESENT	0
276911	263768	01057W	PARTICIPANT	\N	PRESENT	0
286713	286589	19758L	PARTICIPANT	\N	EXCUSE	0
286714	286589	04057K	PARTICIPANT	\N	EXCUSE	0
286738	286267	19575F	PARTICIPANT	\N	PRESENT	0
286739	286267	11103C	PARTICIPANT	\N	PRESENT	0
286740	286267	14195A	PARTICIPANT	\N	PRESENT	0
286741	286267	08052W	PARTICIPANT	\N	PRESENT	0
286742	286267	98024R	PARTICIPANT	\N	PRESENT	0
286743	286267	14217N	PARTICIPANT	\N	PRESENT	0
286744	286267	14042U	PARTICIPANT	\N	PRESENT	0
286745	286267	14281W	PARTICIPANT	\N	PRESENT	0
286746	286267	14087W	PARTICIPANT	\N	PRESENT	0
286747	286267	19727D	PARTICIPANT	\N	PRESENT	0
286748	286267	14026U	PARTICIPANT	\N	PRESENT	0
286749	286267	19569H	PARTICIPANT	\N	PRESENT	0
286750	286267	14213J	PARTICIPANT	\N	PRESENT	0
286751	286267	11067R	PARTICIPANT	\N	PRESENT	0
286752	286267	19335Q	PARTICIPANT	\N	PRESENT	0
286753	286267	04092N	PRESIDENT	0	PRESENT	0
286754	286267	14119M	PARTICIPANT	\N	PRESENT	0
286755	286267	14071N	PARTICIPANT	\N	PRESENT	0
286756	286267	11097X	PARTICIPANT	\N	PRESENT	0
286757	286267	04045F	PARTICIPANT	\N	PRESENT	0
286758	286267	14227Q	PARTICIPANT	\N	PRESENT	0
286759	286267	01034P	PARTICIPANT	\N	PRESENT	0
286760	286267	11063M	PARTICIPANT	\N	PRESENT	0
286761	286267	17779H	PARTICIPANT	\N	PRESENT	0
286762	286267	19703U	PARTICIPANT	\N	PRESENT	0
286764	286267	19527W	PARTICIPANT	\N	PRESENT	0
287630	273914	08043V	PARTICIPANT	\N	PRESENT	0
287631	273914	14030Q	PARTICIPANT	\N	PRESENT	0
287649	273914	04057K	PARTICIPANT	\N	PRESENT	0
287650	273914	19659J	PARTICIPANT	\N	PRESENT	0
287651	273914	19549D	PARTICIPANT	\N	PRESENT	0
287652	273914	14229S	PARTICIPANT	\N	PRESENT	0
287653	273914	14159V	PARTICIPANT	\N	PRESENT	0
287654	273914	08010L	PARTICIPANT	\N	PRESENT	0
287655	273914	14083S	PARTICIPANT	\N	PRESENT	0
287656	273914	04086Q	PARTICIPANT	\N	PRESENT	0
287657	273914	14251Q	PARTICIPANT	\N	PRESENT	0
287658	273914	14205J	PARTICIPANT	\N	PRESENT	0
287659	273914	19489J	PARTICIPANT	\N	PRESENT	0
287660	273914	11048N	PARTICIPANT	\N	PRESENT	0
287661	273914	14135M	PARTICIPANT	\N	PRESENT	0
287662	273914	19681G	PARTICIPANT	\N	PRESENT	0
287663	273914	19721W	PARTICIPANT	\N	PRESENT	0
287664	273914	11101A	PARTICIPANT	\N	PRESENT	0
287669	273914	04049K	PARTICIPANT	\N	PRESENT	0
287670	273914	14079W	PARTICIPANT	\N	PRESENT	0
287676	273914	14038Y	PARTICIPANT	\N	PRESENT	0
287677	273914	19585H	PARTICIPANT	\N	PRESENT	0
287678	273914	14061L	PARTICIPANT	\N	PRESENT	0
287679	273914	19741B	PARTICIPANT	\N	PRESENT	0
287680	273914	19563B	PARTICIPANT	\N	PRESENT	0
287681	273914	19399H	PARTICIPANT	\N	PRESENT	0
287682	273914	08015R	PARTICIPANT	\N	PRESENT	0
287683	273914	14225N	PARTICIPANT	\N	PRESENT	0
287684	273914	14034U	PARTICIPANT	\N	PRESENT	0
287685	273914	11064N	PARTICIPANT	\N	PRESENT	0
287688	273914	14259Y	PARTICIPANT	\N	PRESENT	0
287689	273914	14249W	PARTICIPANT	\N	PRESENT	0
287690	273914	19503N	PARTICIPANT	\N	PRESENT	0
287691	273914	14207L	PARTICIPANT	\N	PRESENT	0
287692	273914	14051J	PARTICIPANT	\N	PRESENT	0
287693	273914	04044E	PARTICIPANT	\N	PRESENT	0
287694	273914	08034U	PARTICIPANT	\N	PRESENT	0
287697	273914	08073C	PARTICIPANT	\N	PRESENT	0
287698	273914	19295A	PARTICIPANT	\N	PRESENT	0
287699	273914	19551W	PARTICIPANT	\N	PRESENT	0
287700	273914	14195A	PARTICIPANT	\N	PRESENT	0
287701	273914	19553Y	PARTICIPANT	\N	PRESENT	0
287702	273914	08044W	PARTICIPANT	\N	PRESENT	0
287703	273914	08069G	PARTICIPANT	\N	PRESENT	0
287814	273915	11026G	PARTICIPANT	\N	PRESENT	0
287815	273915	19715Y	PARTICIPANT	\N	PRESENT	0
287816	273915	04085P	PARTICIPANT	\N	PRESENT	0
287817	273915	19565D	PARTICIPANT	\N	PRESENT	0
287818	273915	19695N	PARTICIPANT	\N	PRESENT	0
287819	273915	19503N	PARTICIPANT	\N	PRESENT	0
287820	273915	19295A	PARTICIPANT	\N	PRESENT	0
287821	273915	11067R	PARTICIPANT	\N	PRESENT	0
287822	273915	19413M	PARTICIPANT	\N	PRESENT	0
287823	273915	14051J	PARTICIPANT	\N	PRESENT	0
287824	273915	14207L	PARTICIPANT	\N	PRESENT	0
287825	273915	14065Q	PARTICIPANT	\N	PRESENT	0
287826	273915	04047H	PARTICIPANT	\N	PRESENT	0
287827	273915	19651A	PARTICIPANT	\N	PRESENT	0
287828	273915	08061X	PARTICIPANT	\N	PRESENT	0
287829	273915	19515S	PARTICIPANT	\N	PRESENT	0
287830	273915	19585H	PARTICIPANT	\N	PRESENT	0
287831	273915	14195A	PARTICIPANT	\N	PRESENT	0
287832	273915	14111D	PARTICIPANT	\N	PRESENT	0
287833	273915	19467C	PARTICIPANT	\N	PRESENT	0
287834	273915	80013X	PARTICIPANT	\N	PRESENT	0
287835	273915	19629C	PARTICIPANT	\N	PRESENT	0
287836	273915	19447X	PARTICIPANT	\N	PRESENT	0
287837	273915	19253P	PARTICIPANT	\N	PRESENT	0
287838	273915	14157T	PARTICIPANT	\N	PRESENT	0
287839	273915	14261S	PARTICIPANT	\N	PRESENT	0
287840	273915	19723Y	PARTICIPANT	\N	PRESENT	0
287841	273915	19575F	PARTICIPANT	\N	PRESENT	0
287842	273915	19737F	PARTICIPANT	\N	PRESENT	0
287843	273915	01024M	PARTICIPANT	\N	PRESENT	0
287844	273915	14147R	PARTICIPANT	\N	PRESENT	0
287845	273915	14327T	PARTICIPANT	\N	PRESENT	0
287846	273915	19521Q	PARTICIPANT	\N	PRESENT	0
287847	273915	14223L	PARTICIPANT	\N	PRESENT	0
287848	273915	14001X	PARTICIPANT	\N	PRESENT	0
287849	273915	99004R	PARTICIPANT	\N	PRESENT	0
287850	273915	19333N	PARTICIPANT	\N	PRESENT	0
287851	273915	19671E	PARTICIPANT	\N	PRESENT	0
287852	273915	05008E	PARTICIPANT	\N	PRESENT	0
287853	273915	14039A	PARTICIPANT	\N	PRESENT	0
287854	273915	19329S	PARTICIPANT	\N	PRESENT	0
287855	273915	19679N	PARTICIPANT	\N	PRESENT	0
287856	273915	14151M	PARTICIPANT	\N	PRESENT	0
287857	273915	04018C	PARTICIPANT	\N	PRESENT	0
287858	273915	14215L	PARTICIPANT	\N	PRESENT	0
287859	273915	11097X	PARTICIPANT	\N	PRESENT	0
287860	273915	19747H	PARTICIPANT	\N	PRESENT	0
287861	273915	14105F	PARTICIPANT	\N	PRESENT	0
287862	273915	08031R	PARTICIPANT	\N	PRESENT	0
287863	273915	19673G	PARTICIPANT	\N	PRESENT	0
287864	273915	11033F	PARTICIPANT	\N	PRESENT	0
287865	273915	14055N	PARTICIPANT	\N	PRESENT	0
287866	273915	19347U	PARTICIPANT	\N	PRESENT	0
287867	273915	11056N	PARTICIPANT	\N	PRESENT	0
287868	273915	14033T	PARTICIPANT	\N	PRESENT	0
287869	273915	14217N	PARTICIPANT	\N	PRESENT	0
287870	273915	14061L	PARTICIPANT	\N	PRESENT	0
287871	273915	14097Y	PARTICIPANT	\N	PRESENT	0
287872	273915	19729F	PARTICIPANT	\N	PRESENT	0
287873	273915	19441R	PARTICIPANT	\N	PRESENT	0
287874	273915	11109J	PARTICIPANT	\N	PRESENT	0
287875	273915	01034P	PARTICIPANT	\N	PRESENT	0
287876	273915	19649G	PARTICIPANT	\N	PRESENT	0
287877	273915	19591F	PARTICIPANT	\N	PRESENT	0
287878	273915	04059M	PARTICIPANT	\N	PRESENT	0
287879	273915	14119M	PARTICIPANT	\N	PRESENT	0
287880	273915	19739H	PARTICIPANT	\N	PRESENT	0
287881	273915	14229S	PARTICIPANT	\N	PRESENT	0
287882	273915	14265W	PARTICIPANT	\N	PRESENT	0
287883	273915	14213J	PARTICIPANT	\N	PRESENT	0
287884	273915	08020N	PARTICIPANT	\N	PRESENT	0
287885	273915	19489J	PARTICIPANT	\N	PRESENT	0
287886	273915	19507S	PARTICIPANT	\N	PRESENT	0
287887	273915	14135M	PARTICIPANT	\N	PRESENT	0
287888	273915	04088S	PARTICIPANT	\N	PRESENT	0
287889	273915	10015M	PARTICIPANT	\N	PRESENT	0
287890	273915	19689Q	PARTICIPANT	\N	PRESENT	0
287891	273915	19713W	PARTICIPANT	\N	PRESENT	0
287892	273915	04044E	PARTICIPANT	\N	PRESENT	0
287893	273915	11072N	PARTICIPANT	\N	PRESENT	0
287894	273915	19599P	PARTICIPANT	\N	PRESENT	0
287895	273915	17779H	PARTICIPANT	\N	PRESENT	0
287896	273915	08019V	PARTICIPANT	\N	PRESENT	0
287897	273915	14030Q	PARTICIPANT	\N	PRESENT	0
287898	273915	14069U	PARTICIPANT	\N	PRESENT	0
287899	273915	14237S	PARTICIPANT	\N	PRESENT	0
287900	273915	19727D	PARTICIPANT	\N	PRESENT	0
287901	273915	19741B	PARTICIPANT	\N	PRESENT	0
287902	273915	14241N	PARTICIPANT	\N	PRESENT	0
287903	273915	14021P	PARTICIPANT	\N	PRESENT	0
287904	273915	19749K	PARTICIPANT	\N	PRESENT	0
287905	273915	19703U	PARTICIPANT	\N	PRESENT	0
287906	273915	08015R	PARTICIPANT	\N	PRESENT	0
287907	273915	14038Y	PARTICIPANT	\N	PRESENT	0
287911	273915	04070G	PARTICIPANT	\N	PRESENT	0
287909	273915	08068F	PARTICIPANT	\N	PRESENT	0
287910	273915	14187A	PARTICIPANT	\N	PRESENT	0
278184	278101	14001X	PARTICIPANT	\N	PRESENT	0
278185	278101	01060R	PARTICIPANT	\N	PRESENT	0
278186	278101	19543W	PARTICIPANT	\N	PRESENT	0
278187	278101	19581D	PARTICIPANT	\N	PRESENT	0
278188	278101	04044E	PARTICIPANT	\N	PRESENT	0
278189	278101	19585H	PARTICIPANT	\N	PRESENT	0
278190	278101	04047H	PARTICIPANT	\N	PRESENT	0
278191	278101	19673G	PARTICIPANT	\N	PRESENT	0
278192	278101	01028R	PARTICIPANT	\N	PRESENT	0
278193	278101	05008E	PRESIDENT	0	PRESENT	0
278194	278101	19447X	PARTICIPANT	\N	PRESENT	0
278195	278101	14231L	PARTICIPANT	\N	PRESENT	0
278197	278101	19489J	PARTICIPANT	\N	PRESENT	0
278198	278101	14275Y	PARTICIPANT	\N	PRESENT	0
278199	278101	14041T	PARTICIPANT	\N	PRESENT	0
278200	278101	14147R	PARTICIPANT	\N	PRESENT	0
278201	278101	14179A	PARTICIPANT	\N	PRESENT	0
278202	278101	14151M	PARTICIPANT	\N	PRESENT	0
278203	278101	14215L	PARTICIPANT	\N	PRESENT	0
278204	278101	08018U	PARTICIPANT	\N	PRESENT	0
278205	278101	14259Y	PARTICIPANT	\N	PRESENT	0
278206	278101	11072N	PARTICIPANT	\N	PRESENT	0
278207	278101	14053L	PARTICIPANT	\N	PRESENT	0
278208	278101	98035U	PARTICIPANT	\N	PRESENT	0
278209	278101	14065Q	PARTICIPANT	\N	PRESENT	0
278210	278101	19649G	PARTICIPANT	\N	PRESENT	0
278211	278101	14111D	PARTICIPANT	\N	PRESENT	0
278212	278101	07034Q	PRESIDENT	1	PRESENT	0
278213	278101	10015M	PARTICIPANT	\N	PRESENT	0
278214	278101	08045X	PARTICIPANT	\N	PRESENT	0
278215	278101	11026G	PARTICIPANT	\N	PRESENT	0
278216	278101	19253P	PARTICIPANT	\N	PRESENT	0
278217	278101	01024M	PARTICIPANT	\N	PRESENT	0
278218	278101	04038G	PARTICIPANT	\N	PRESENT	0
278219	278101	19719D	PARTICIPANT	\N	PRESENT	0
278220	278101	11033F	PARTICIPANT	\N	PRESENT	0
278221	278101	19725B	PARTICIPANT	\N	PRESENT	0
278222	278101	14089Y	PARTICIPANT	\N	PRESENT	0
278223	278101	19729F	PARTICIPANT	\N	PRESENT	0
278224	278101	19629C	PARTICIPANT	\N	PRESENT	0
278226	278101	08044W	PARTICIPANT	\N	PRESENT	0
278227	278101	14069U	PARTICIPANT	\N	PRESENT	0
278228	278101	11085T	PARTICIPANT	\N	PRESENT	0
278229	278101	11049P	PARTICIPANT	\N	PRESENT	0
278230	278101	04008A	PARTICIPANT	\N	PRESENT	0
278231	278101	14021P	PARTICIPANT	\N	EXCUSE	0
278246	275842	01043Q	PARTICIPANT	\N	PRESENT	0
278247	275842	19563B	PARTICIPANT	\N	PRESENT	0
278248	275842	14033T	PARTICIPANT	\N	PRESENT	0
278249	275842	19507S	PARTICIPANT	\N	PRESENT	0
278250	275842	04089T	PARTICIPANT	\N	EXCUSE	0
278251	275842	11081P	PARTICIPANT	\N	EXCUSE	0
278361	275758	14331P	PARTICIPANT	\N	PRESENT	0
278362	275758	04071H	PARTICIPANT	\N	PRESENT	0
278363	275758	01048V	PARTICIPANT	\N	PRESENT	0
278364	275758	01057W	PARTICIPANT	\N	PRESENT	0
278365	275758	19667J	PARTICIPANT	\N	PRESENT	0
278366	275758	11074Q	PRESIDENT	0	PRESENT	0
278367	275758	19671E	PARTICIPANT	\N	PRESENT	0
278368	275758	11070L	PARTICIPANT	\N	PRESENT	0
278369	275758	88008L	PARTICIPANT	\N	PRESENT	0
278370	275758	14225N	PARTICIPANT	\N	PRESENT	0
278371	275758	07029T	PARTICIPANT	\N	PRESENT	0
278372	275758	14085U	PARTICIPANT	\N	PRESENT	0
278373	275758	19349W	PARTICIPANT	\N	PRESENT	0
278374	275758	08010L	PARTICIPANT	\N	PRESENT	0
278375	275758	14253S	PARTICIPANT	\N	PRESENT	0
278376	275758	19647E	PARTICIPANT	\N	PRESENT	0
278377	275758	19479G	PARTICIPANT	\N	PRESENT	0
278378	275758	11048N	PARTICIPANT	\N	PRESENT	0
278379	275758	19711U	PARTICIPANT	\N	PRESENT	0
278380	275758	08034U	PARTICIPANT	\N	PRESENT	0
278381	275758	14034U	PARTICIPANT	\N	PRESENT	0
278382	275758	04086Q	PARTICIPANT	\N	PRESENT	0
278383	275758	11040E	PARTICIPANT	\N	PRESENT	0
278384	275758	14083S	PARTICIPANT	\N	PRESENT	0
278385	275758	14121F	PARTICIPANT	\N	PRESENT	0
278386	275758	19741B	PARTICIPANT	\N	PRESENT	0
278387	275758	99004R	PARTICIPANT	\N	PRESENT	0
278388	275758	04061F	PARTICIPANT	\N	PRESENT	0
278389	275758	08011M	PARTICIPANT	\N	EXCUSE	0
278390	275758	08014Q	PARTICIPANT	\N	EXCUSE	0
278391	278102	19649G	PARTICIPANT	\N	PRESENT	0
278392	278102	11026G	PARTICIPANT	\N	PRESENT	0
278393	278102	19253P	PARTICIPANT	\N	PRESENT	0
278394	278102	01024M	PARTICIPANT	\N	PRESENT	0
278395	278102	04047H	PARTICIPANT	\N	PRESENT	0
278396	278102	19673G	PARTICIPANT	\N	PRESENT	0
278397	278102	01028R	PARTICIPANT	\N	PRESENT	0
278398	278102	05008E	PRESIDENT	0	PRESENT	0
278399	278102	19447X	PARTICIPANT	\N	PRESENT	0
278400	278102	14089Y	PARTICIPANT	\N	PRESENT	0
278401	278102	14215L	PARTICIPANT	\N	PRESENT	0
278402	278102	14123H	PARTICIPANT	\N	PRESENT	0
278403	278102	11072N	PARTICIPANT	\N	PRESENT	0
278404	278102	14053L	PARTICIPANT	\N	PRESENT	0
278405	278102	14111D	PARTICIPANT	\N	PRESENT	0
278406	278102	14065Q	PARTICIPANT	\N	PRESENT	0
278407	278102	10015M	PARTICIPANT	\N	PRESENT	0
278408	278102	08045X	PARTICIPANT	\N	PRESENT	0
278409	278102	07034Q	PARTICIPANT	\N	PRESENT	0
278410	278102	14001X	PARTICIPANT	\N	PRESENT	0
278411	278102	19543W	PARTICIPANT	\N	PRESENT	0
278412	278102	19581D	PARTICIPANT	\N	PRESENT	0
278413	278102	19725B	PARTICIPANT	\N	PRESENT	0
278414	278102	19729F	PARTICIPANT	\N	PRESENT	0
278415	278102	19629C	PARTICIPANT	\N	PRESENT	0
278416	278102	14179A	PARTICIPANT	\N	PRESENT	0
278417	278102	14151M	PARTICIPANT	\N	PRESENT	0
278418	278102	11049P	PARTICIPANT	\N	PRESENT	0
278419	278102	14259Y	PARTICIPANT	\N	PRESENT	0
278420	278102	14021P	PARTICIPANT	\N	PRESENT	0
278453	263771	04059M	PARTICIPANT	\N	PRESENT	0
278454	263771	19387D	PARTICIPANT	\N	PRESENT	0
278455	263771	80013X	PARTICIPANT	\N	PRESENT	0
278456	263771	14063N	PARTICIPANT	\N	PRESENT	0
278457	263771	98023Q	PARTICIPANT	\N	PRESENT	0
278458	263771	08019V	PARTICIPANT	\N	PRESENT	0
278040	276033	14039A	PARTICIPANT	\N	PRESENT	0
278041	276033	14107H	PARTICIPANT	\N	PRESENT	0
278042	276033	08017T	PARTICIPANT	\N	PRESENT	0
278043	276033	07033P	PARTICIPANT	\N	PRESENT	0
278044	276033	08012N	PARTICIPANT	\N	PRESENT	0
278045	276033	08016S	PARTICIPANT	\N	PRESENT	0
278046	276033	08031R	PARTICIPANT	\N	PRESENT	0
278047	276033	19593H	PARTICIPANT	\N	PRESENT	0
278048	276033	19643A	PARTICIPANT	\N	PRESENT	0
278049	276033	04057K	PARTICIPANT	\N	PRESENT	0
278050	276033	14073Q	PARTICIPANT	\N	PRESENT	0
278051	276033	19611R	PARTICIPANT	\N	PRESENT	0
278052	276033	08035V	PARTICIPANT	\N	PRESENT	0
278053	276033	19693L	PARTICIPANT	\N	PRESENT	0
278054	276033	87003B	PARTICIPANT	\N	PRESENT	0
278055	276033	19399H	PARTICIPANT	\N	PRESENT	0
278056	276033	14201E	PARTICIPANT	\N	PRESENT	0
278057	276033	14030Q	PARTICIPANT	\N	PRESENT	0
278058	276033	19731Y	PARTICIPANT	\N	PRESENT	0
278059	276033	14251Q	PARTICIPANT	\N	PRESENT	0
278060	276033	04059M	PARTICIPANT	\N	PRESENT	0
278061	276033	19735D	PARTICIPANT	\N	PRESENT	0
278062	276033	14063N	PARTICIPANT	\N	PRESENT	0
278063	276033	14109K	PARTICIPANT	\N	PRESENT	0
278064	276033	11083R	PARTICIPANT	\N	PRESENT	0
278065	276033	14123H	PARTICIPANT	\N	PRESENT	0
278066	276033	11104D	PARTICIPANT	\N	PRESENT	0
278067	276033	19749K	PARTICIPANT	\N	PRESENT	0
278068	276033	04018C	PARTICIPANT	\N	PRESENT	0
278069	276033	14059S	PARTICIPANT	\N	EXCUSE	0
278070	276033	14061L	PARTICIPANT	\N	EXCUSE	0
278071	276033	08043V	PARTICIPANT	\N	EXCUSE	0
278072	276033	14249W	PARTICIPANT	\N	EXCUSE	0
278112	275134	11027H	PARTICIPANT	\N	PRESENT	0
278459	263771	14157T	PARTICIPANT	\N	PRESENT	0
278460	263771	19713W	PARTICIPANT	\N	PRESENT	0
278461	263771	08009T	PARTICIPANT	\N	PRESENT	0
278462	263771	19731Y	PARTICIPANT	\N	PRESENT	0
278463	263771	14219Q	PARTICIPANT	\N	PRESENT	0
278464	263771	19593H	PARTICIPANT	\N	PRESENT	0
278465	263771	19347U	PARTICIPANT	\N	PRESENT	0
278466	263771	11031D	PARTICIPANT	\N	PRESENT	0
278467	263771	19695N	PARTICIPANT	\N	PRESENT	0
278468	263771	19637C	PARTICIPANT	\N	PRESENT	0
278469	263771	04085P	PARTICIPANT	\N	PRESENT	0
278470	263771	19333N	PARTICIPANT	\N	PRESENT	0
278471	263771	11054L	PARTICIPANT	\N	PRESENT	0
278472	263771	19525U	PARTICIPANT	\N	PRESENT	0
278473	263771	08055A	PARTICIPANT	\N	PRESENT	0
278474	263771	11065P	PARTICIPANT	\N	PRESENT	0
278475	263771	19681G	PARTICIPANT	\N	PRESENT	0
287418	286236	08009T	PARTICIPANT	\N	PRESENT	0
287419	286236	19549D	PARTICIPANT	\N	PRESENT	0
287420	286236	14031R	PARTICIPANT	\N	PRESENT	0
287421	286236	19637C	PARTICIPANT	\N	PRESENT	0
287422	286236	14103D	PARTICIPANT	\N	PRESENT	0
287423	286236	14219Q	PARTICIPANT	\N	PRESENT	0
287424	286236	19289C	PARTICIPANT	\N	PRESENT	0
287425	286236	04097T	PARTICIPANT	\N	PRESENT	0
287426	286236	19745F	PARTICIPANT	\N	PRESENT	0
287427	286236	05012A	PARTICIPANT	\N	PRESENT	0
287428	286236	19503N	PARTICIPANT	\N	PRESENT	0
287429	286236	19739H	PARTICIPANT	\N	PRESENT	0
287430	286236	17583W	PARTICIPANT	\N	PRESENT	0
287431	286236	19713W	PARTICIPANT	\N	PRESENT	0
287432	286236	14051J	PARTICIPANT	\N	PRESENT	0
287433	286236	17637T	PARTICIPANT	\N	PRESENT	0
287434	286236	14169X	PARTICIPANT	\N	PRESENT	0
287435	286236	14221J	PARTICIPANT	\N	PRESENT	0
287436	286236	19551W	PARTICIPANT	\N	PRESENT	0
287437	286236	19333N	PARTICIPANT	\N	PRESENT	0
287438	286236	19347U	PARTICIPANT	\N	PRESENT	0
287439	286236	11065P	PARTICIPANT	\N	PRESENT	0
287440	286236	19525U	PARTICIPANT	\N	PRESENT	0
287441	286236	19599P	PARTICIPANT	\N	PRESENT	0
287442	286236	19701S	PARTICIPANT	\N	PRESENT	0
287443	286236	18083K	PARTICIPANT	\N	PRESENT	0
287444	286236	08024S	PARTICIPANT	\N	PRESENT	0
287445	286236	19383Y	PARTICIPANT	\N	PRESENT	0
287446	286236	96004D	PARTICIPANT	\N	PRESENT	0
287447	286236	19659J	PARTICIPANT	\N	PRESENT	0
287448	286236	14093U	PARTICIPANT	\N	PRESENT	0
287449	286236	98023Q	PARTICIPANT	\N	PRESENT	0
301379	289201	19553Y	PARTICIPANT	\N	PRESENT	0
301384	289201	12041X	PARTICIPANT	\N	PRESENT	0
301385	289201	08068F	PARTICIPANT	\N	PRESENT	0
301495	289202	14187A	PARTICIPANT	\N	PRESENT	0
301496	289202	19591F	PARTICIPANT	\N	PRESENT	0
301497	289202	19631V	PARTICIPANT	\N	PRESENT	0
301498	289202	19551W	PARTICIPANT	\N	PRESENT	0
301499	289202	19289C	PARTICIPANT	\N	PRESENT	0
301500	289202	02002K	PARTICIPANT	\N	PRESENT	0
301501	289202	11065P	PARTICIPANT	\N	PRESENT	0
301502	289202	95063L	PARTICIPANT	\N	PRESENT	0
301503	289202	14093U	PARTICIPANT	\N	PRESENT	0
301504	289202	19717B	PARTICIPANT	\N	PRESENT	0
301505	289202	14051J	PARTICIPANT	\N	PRESENT	0
301506	289202	14041T	PARTICIPANT	\N	PRESENT	0
301507	289202	19447X	PARTICIPANT	\N	PRESENT	0
301508	289202	14038Y	PARTICIPANT	\N	PRESENT	0
301509	289202	19667J	PARTICIPANT	\N	PRESENT	0
301510	289202	19399H	PARTICIPANT	\N	PRESENT	0
301511	289202	08034U	PARTICIPANT	\N	PRESENT	0
301512	289202	04035D	PARTICIPANT	\N	PRESENT	0
301513	289202	19727D	PARTICIPANT	\N	PRESENT	0
301514	289202	19301E	PARTICIPANT	\N	PRESENT	0
301515	289202	19553Y	PARTICIPANT	\N	PRESENT	0
301516	289202	11012A	PARTICIPANT	\N	PRESENT	0
301517	289202	19253P	PARTICIPANT	\N	PRESENT	0
301518	289202	19611R	PARTICIPANT	\N	PRESENT	0
301519	289202	19713W	PARTICIPANT	\N	PRESENT	0
301520	289202	19599P	PARTICIPANT	\N	PRESENT	0
301521	289202	19735D	PARTICIPANT	\N	PRESENT	0
301522	289202	14083S	PARTICIPANT	\N	PRESENT	0
301523	289202	19687N	PARTICIPANT	\N	PRESENT	0
301524	289202	19515S	PARTICIPANT	\N	PRESENT	0
301525	289202	19643A	PARTICIPANT	\N	PRESENT	0
301526	289202	19657G	PARTICIPANT	\N	PRESENT	0
301527	289202	04043D	PARTICIPANT	\N	PRESENT	0
301528	289202	19711U	PARTICIPANT	\N	PRESENT	0
301529	289202	04008A	PARTICIPANT	\N	PRESENT	0
301530	289202	08019V	PARTICIPANT	\N	PRESENT	0
301531	289202	04033B	PARTICIPANT	\N	PRESENT	0
301532	289202	14357A	PARTICIPANT	\N	PRESENT	0
301533	289202	14215L	PARTICIPANT	\N	PRESENT	0
301534	289202	19565D	PARTICIPANT	\N	PRESENT	0
301535	289202	04018C	PARTICIPANT	\N	PRESENT	0
301536	289202	04086Q	PARTICIPANT	\N	PRESENT	0
301537	289202	11077T	PARTICIPANT	\N	PRESENT	0
301538	289202	14157T	PARTICIPANT	\N	PRESENT	0
301539	289202	04042C	PARTICIPANT	\N	PRESENT	0
301540	289202	11090Q	PARTICIPANT	\N	PRESENT	0
301541	289202	14229S	PARTICIPANT	\N	PRESENT	0
301542	289202	17637T	PARTICIPANT	\N	PRESENT	0
301543	289202	07029T	PARTICIPANT	\N	PRESENT	0
301544	289202	19695N	PARTICIPANT	\N	PRESENT	0
301545	289202	08038Y	PARTICIPANT	\N	PRESENT	0
301546	289202	08068F	PARTICIPANT	\N	PRESENT	0
301547	289202	19369B	PARTICIPANT	\N	PRESENT	0
301548	289202	14249W	PARTICIPANT	\N	PRESENT	0
301549	289202	14265W	PARTICIPANT	\N	PRESENT	0
301550	289202	19749K	PARTICIPANT	\N	PRESENT	0
301551	289202	12016W	PARTICIPANT	\N	PRESENT	0
301552	289202	16685X	PARTICIPANT	\N	PRESENT	0
301553	289202	01028R	PARTICIPANT	\N	PRESENT	0
301554	289202	08010L	PARTICIPANT	\N	PRESENT	0
301555	289202	08016S	PARTICIPANT	\N	PRESENT	0
301556	300451	08052W	PRESIDENT	0	PRESENT	0
301557	300451	17589D	PARTICIPANT	\N	PRESENT	0
301558	300451	19727D	PARTICIPANT	\N	PRESENT	0
301559	300451	19735D	PARTICIPANT	\N	PRESENT	0
301560	300451	19553Y	PARTICIPANT	\N	PRESENT	0
301603	289203	11109J	PARTICIPANT	\N	PRESENT	0
301604	289203	01043Q	PARTICIPANT	\N	PRESENT	0
301605	289203	01025N	PARTICIPANT	\N	PRESENT	0
301606	289203	14157T	PARTICIPANT	\N	PRESENT	0
301607	289203	19399H	PARTICIPANT	\N	PRESENT	0
301608	289203	19599P	PARTICIPANT	\N	PRESENT	0
301609	289203	04049K	PARTICIPANT	\N	PRESENT	0
301610	289203	19673G	PARTICIPANT	\N	PRESENT	0
301611	289203	19447X	PARTICIPANT	\N	PRESENT	0
301612	289203	14119M	PARTICIPANT	\N	PRESENT	0
301613	289203	14249W	PARTICIPANT	\N	PRESENT	0
301614	289203	19515S	PARTICIPANT	\N	PRESENT	0
301615	289203	19739H	PARTICIPANT	\N	PRESENT	0
301616	289203	19593H	PARTICIPANT	\N	PRESENT	0
301617	289203	01028R	PARTICIPANT	\N	PRESENT	0
301618	289203	04018C	PARTICIPANT	\N	PRESENT	0
301619	289203	19611R	PARTICIPANT	\N	PRESENT	0
301620	289203	19683J	PARTICIPANT	\N	PRESENT	0
301621	289203	19289C	PARTICIPANT	\N	PRESENT	0
301622	289203	16685X	PARTICIPANT	\N	PRESENT	0
301626	289203	99004R	PARTICIPANT	\N	PRESENT	0
301629	289203	19503N	PARTICIPANT	\N	PRESENT	0
301630	289203	19553Y	PARTICIPANT	\N	PRESENT	0
301631	289203	19649G	PARTICIPANT	\N	PRESENT	0
301377	289201	19503N	PARTICIPANT	\N	PRESENT	0
301378	289201	02002K	PARTICIPANT	\N	PRESENT	0
301695	289204	04044E	PARTICIPANT	\N	PRESENT	0
301696	289204	14187A	PARTICIPANT	\N	PRESENT	0
301697	289204	11090Q	PARTICIPANT	\N	PRESENT	0
301698	289204	11077T	PARTICIPANT	\N	PRESENT	0
301699	289204	19631V	PARTICIPANT	\N	PRESENT	0
301700	289204	01025N	PARTICIPANT	\N	PRESENT	0
301701	289204	19599P	PARTICIPANT	\N	PRESENT	0
301702	289204	08038Y	PARTICIPANT	\N	PRESENT	0
301703	289204	11056N	PARTICIPANT	\N	PRESENT	0
301704	289204	19503N	PARTICIPANT	\N	PRESENT	0
301705	289204	04057K	PARTICIPANT	\N	PRESENT	0
301706	289204	14229S	PARTICIPANT	\N	PRESENT	0
301707	289204	19611R	PARTICIPANT	\N	PRESENT	0
301708	289204	14041T	PARTICIPANT	\N	PRESENT	0
301709	289204	19399H	PARTICIPANT	\N	PRESENT	0
301710	289204	19515S	PARTICIPANT	\N	PRESENT	0
301711	289204	14038Y	PARTICIPANT	\N	PRESENT	0
301493	289202	04044E	PARTICIPANT	\N	PRESENT	0
301494	289202	11056N	PARTICIPANT	\N	PRESENT	0
301712	289204	19447X	PARTICIPANT	\N	PRESENT	0
301713	289204	08019V	PARTICIPANT	\N	PRESENT	0
301714	289204	14265W	PARTICIPANT	\N	PRESENT	0
301715	289204	19591F	PARTICIPANT	\N	PRESENT	0
301716	289204	19565D	PARTICIPANT	\N	PRESENT	0
301717	289204	19695N	PARTICIPANT	\N	PRESENT	0
301718	289204	19749K	PARTICIPANT	\N	PRESENT	0
301719	289204	04018C	PARTICIPANT	\N	PRESENT	0
301720	289204	19651A	PARTICIPANT	\N	PRESENT	0
301721	289204	11065P	PARTICIPANT	\N	PRESENT	0
301722	289204	19289C	PARTICIPANT	\N	PRESENT	0
301723	289204	19687N	PARTICIPANT	\N	PRESENT	0
301724	289204	08068F	PARTICIPANT	\N	PRESENT	0
301725	289204	04086Q	PARTICIPANT	\N	PRESENT	0
301726	289204	19681G	PARTICIPANT	\N	PRESENT	0
301727	289204	14215L	PARTICIPANT	\N	PRESENT	0
301728	289204	14083S	PARTICIPANT	\N	PRESENT	0
301729	289204	01043Q	PARTICIPANT	\N	PRESENT	0
301730	289204	19671E	PARTICIPANT	\N	PRESENT	0
301731	289204	19253P	PARTICIPANT	\N	PRESENT	0
301732	289204	11109J	PARTICIPANT	\N	PRESENT	0
301733	289204	08034U	PARTICIPANT	\N	PRESENT	0
276912	263768	08069G	PARTICIPANT	\N	PRESENT	0
276913	263768	19253P	PARTICIPANT	\N	PRESENT	0
277021	263768	19599P	PARTICIPANT	\N	PRESENT	0
276915	263768	08049C	PARTICIPANT	\N	PRESENT	0
276916	263768	04097T	PARTICIPANT	\N	PRESENT	0
276917	263768	11048N	PARTICIPANT	\N	PRESENT	0
276918	263768	14213J	PARTICIPANT	\N	PRESENT	0
276919	263768	19447X	PARTICIPANT	\N	PRESENT	0
276920	263768	19563B	PARTICIPANT	\N	PRESENT	0
276921	263768	14201E	PARTICIPANT	\N	PRESENT	0
276922	263768	99004R	PARTICIPANT	\N	PRESENT	0
276923	263768	14239U	PARTICIPANT	\N	PRESENT	0
277492	263769	14197C	PARTICIPANT	\N	PRESENT	0
276925	263768	14061L	PARTICIPANT	\N	PRESENT	0
276926	263768	07029T	PARTICIPANT	\N	PRESENT	0
276927	263768	04049K	PARTICIPANT	\N	PRESENT	0
276928	263768	14241N	PARTICIPANT	\N	PRESENT	0
276929	263768	14029X	PARTICIPANT	\N	PRESENT	0
276930	263768	19723Y	PARTICIPANT	\N	PRESENT	0
276931	263768	98005N	PARTICIPANT	\N	PRESENT	0
276932	263768	19711U	PARTICIPANT	\N	PRESENT	0
276933	263768	08015R	PARTICIPANT	\N	PRESENT	0
276934	263768	08010L	PARTICIPANT	\N	PRESENT	0
276935	263768	08034U	PARTICIPANT	\N	PRESENT	0
276936	263768	08039A	PARTICIPANT	\N	PRESENT	0
276937	263768	19729F	PARTICIPANT	\N	PRESENT	0
276938	263768	19581D	PARTICIPANT	\N	PRESENT	0
276939	263768	19719D	PARTICIPANT	\N	PRESENT	0
276940	263768	19709B	PARTICIPANT	\N	PRESENT	0
277493	263769	19503N	PARTICIPANT	\N	PRESENT	0
276942	263768	88008L	PARTICIPANT	\N	PRESENT	0
276943	263768	08019V	PARTICIPANT	\N	PRESENT	0
276944	263768	14031R	PARTICIPANT	\N	PRESENT	0
276946	263768	19681G	PARTICIPANT	\N	PRESENT	0
276947	263768	08062Y	PARTICIPANT	\N	PRESENT	0
276948	263768	11099A	PARTICIPANT	\N	PRESENT	0
276949	263768	14147R	PARTICIPANT	\N	PRESENT	0
276950	263768	19671E	PARTICIPANT	\N	PRESENT	0
276951	263768	14223L	PARTICIPANT	\N	PRESENT	0
276952	263768	04092N	PARTICIPANT	\N	PRESENT	0
277016	263768	01028R	PARTICIPANT	\N	PRESENT	0
276954	263768	14265W	PARTICIPANT	\N	PRESENT	0
276955	263768	19289C	PARTICIPANT	\N	PRESENT	0
276956	263768	14119M	PARTICIPANT	\N	PRESENT	0
276957	263768	19387D	PARTICIPANT	\N	PRESENT	0
276958	263768	14071N	PARTICIPANT	\N	PRESENT	0
276959	263768	11012A	PARTICIPANT	\N	PRESENT	0
276960	263768	14169X	PARTICIPANT	\N	PRESENT	0
276961	263768	11065P	PARTICIPANT	\N	PRESENT	0
276962	263768	14253S	PARTICIPANT	\N	PRESENT	0
276963	263768	19573D	PARTICIPANT	\N	PRESENT	0
276964	263768	19553Y	PARTICIPANT	\N	PRESENT	0
276965	263768	14191V	PARTICIPANT	\N	PRESENT	0
276966	263768	14111D	PARTICIPANT	\N	PRESENT	0
277494	263769	08058D	PARTICIPANT	\N	PRESENT	0
276968	263768	17589D	PARTICIPANT	\N	PRESENT	0
276969	263768	19533U	PARTICIPANT	\N	PRESENT	0
276970	263768	04088S	PARTICIPANT	\N	PRESENT	0
276971	263768	11064N	PARTICIPANT	\N	PRESENT	0
276972	263768	07034Q	PARTICIPANT	\N	PRESENT	0
276973	263768	19583F	PARTICIPANT	\N	PRESENT	0
276974	263768	05012A	PARTICIPANT	\N	PRESENT	0
276975	263768	98050T	PARTICIPANT	\N	PRESENT	0
276976	263768	02002K	PARTICIPANT	\N	PRESENT	0
276977	263768	11090Q	PARTICIPANT	\N	PRESENT	0
276978	263768	04057K	PARTICIPANT	\N	PRESENT	0
276979	263768	04043D	PARTICIPANT	\N	PRESENT	0
276980	263768	19679N	PARTICIPANT	\N	PRESENT	0
276981	263768	14195A	PARTICIPANT	\N	PRESENT	0
276982	263768	17637T	PARTICIPANT	\N	PRESENT	0
276983	263768	17583W	PARTICIPANT	\N	PRESENT	0
276984	263768	19443T	PARTICIPANT	\N	PRESENT	0
276985	263768	14135M	PARTICIPANT	\N	PRESENT	0
277011	263768	11077T	PARTICIPANT	\N	PRESENT	0
276987	263768	11109J	PARTICIPANT	\N	PRESENT	0
276988	263768	10015M	PARTICIPANT	\N	PRESENT	0
276989	263768	04085P	PARTICIPANT	\N	PRESENT	0
276990	263768	19705W	PARTICIPANT	\N	PRESENT	0
276991	263768	04033B	PARTICIPANT	\N	PRESENT	0
276992	263768	11056N	PARTICIPANT	\N	PRESENT	0
276993	263768	95062K	PARTICIPANT	\N	PRESENT	0
276994	263768	19421M	PARTICIPANT	\N	PRESENT	0
276995	263768	19347U	PARTICIPANT	\N	PRESENT	0
276996	263768	11097X	PARTICIPANT	\N	PRESENT	0
276997	263768	11043H	PARTICIPANT	\N	PRESENT	0
276998	263768	04018C	PARTICIPANT	\N	PRESENT	0
276999	263768	01058X	PARTICIPANT	\N	PRESENT	0
277000	263768	19675J	PARTICIPANT	\N	PRESENT	0
277001	263768	11031D	PARTICIPANT	\N	PRESENT	0
277002	263768	19703U	PARTICIPANT	\N	PRESENT	0
277003	263768	04044E	PARTICIPANT	\N	PRESENT	0
277004	263768	11063M	PARTICIPANT	\N	PRESENT	0
277005	263768	14157T	PARTICIPANT	\N	PRESENT	0
277006	263768	95067Q	PARTICIPANT	\N	PRESENT	0
277007	263768	14173T	PARTICIPANT	\N	PRESENT	0
277008	263768	14251Q	PARTICIPANT	\N	PRESENT	0
277009	263768	11074Q	PARTICIPANT	\N	PRESENT	0
277010	263768	04059M	PARTICIPANT	\N	PRESENT	0
277012	263768	98035U	PARTICIPANT	\N	PRESENT	0
277013	263768	08055A	PARTICIPANT	\N	PRESENT	0
277014	263768	14229S	PARTICIPANT	\N	PRESENT	0
277015	263768	08052W	PARTICIPANT	\N	PRESENT	0
279063	268444	01048V	PRESIDENT	0	PRESENT	0
277018	263768	08068F	PARTICIPANT	\N	PRESENT	0
277019	263768	14051J	PARTICIPANT	\N	PRESENT	0
277020	263768	14151M	PARTICIPANT	\N	PRESENT	0
277023	263768	14225N	PARTICIPANT	\N	PRESENT	0
277024	263768	08045X	PARTICIPANT	\N	PRESENT	0
277025	263768	14107H	PARTICIPANT	\N	PRESENT	0
277026	263768	14159V	PARTICIPANT	\N	PRESENT	0
277027	263768	01062T	PARTICIPANT	\N	PRESENT	0
277028	263768	08060W	PARTICIPANT	\N	PRESENT	0
277029	263768	08038Y	PARTICIPANT	\N	PRESENT	0
277495	276029	14355X	PARTICIPANT	\N	PRESENT	0
277031	263768	80013X	PARTICIPANT	\N	PRESENT	0
277032	263768	08024S	PARTICIPANT	\N	PRESENT	0
277033	263768	14197C	PARTICIPANT	\N	PRESENT	0
277034	263768	19649G	PARTICIPANT	\N	PRESENT	0
277036	263768	14028W	PARTICIPANT	\N	PRESENT	0
277037	263768	19647E	PARTICIPANT	\N	PRESENT	0
277038	263768	11110B	PARTICIPANT	\N	PRESENT	0
277039	263768	08012N	PARTICIPANT	\N	PRESENT	0
277040	263768	08035V	PARTICIPANT	\N	PRESENT	0
277041	263768	19727D	PARTICIPANT	\N	PRESENT	0
277042	263768	19725B	PARTICIPANT	\N	PRESENT	0
277043	263768	19489J	PARTICIPANT	\N	PRESENT	0
277044	263768	17779H	PARTICIPANT	\N	PRESENT	0
277045	263768	08058D	PARTICIPANT	\N	PRESENT	0
277046	263768	14121F	PARTICIPANT	\N	PRESENT	0
277047	263768	14085U	PARTICIPANT	\N	PRESENT	0
277048	263768	14021P	PARTICIPANT	\N	PRESENT	0
277049	263768	14227Q	PARTICIPANT	\N	PRESENT	0
277050	263768	19683J	PARTICIPANT	\N	PRESENT	0
277051	263768	14097Y	PARTICIPANT	\N	PRESENT	0
277052	263768	19631V	PARTICIPANT	\N	PRESENT	0
277053	263768	11054L	PARTICIPANT	\N	PRESENT	0
277054	263768	19413M	PARTICIPANT	\N	PRESENT	0
277055	263768	19251M	PARTICIPANT	\N	PRESENT	0
277056	263768	11026G	PARTICIPANT	\N	PRESENT	0
277057	263768	19591F	PARTICIPANT	\N	PRESENT	0
277058	263768	19333N	PARTICIPANT	\N	PRESENT	0
277059	263768	11067R	PARTICIPANT	\N	PRESENT	0
277060	263768	19551W	PARTICIPANT	\N	PRESENT	0
277061	263768	08017T	PARTICIPANT	\N	PRESENT	0
277062	263768	19527W	PARTICIPANT	\N	PRESENT	0
277063	263768	11066Q	PARTICIPANT	\N	PRESENT	0
277064	263768	14001X	PARTICIPANT	\N	PRESENT	0
277065	263768	14063N	PARTICIPANT	\N	PRESENT	0
277066	263768	19503N	PARTICIPANT	\N	PRESENT	0
277067	263768	14257W	PARTICIPANT	\N	PRESENT	0
277068	263768	11104D	PARTICIPANT	\N	PRESENT	0
277069	263768	14109K	PARTICIPANT	\N	PRESENT	0
277071	263768	19669L	PARTICIPANT	\N	PRESENT	0
277072	263768	11041F	PARTICIPANT	\N	PRESENT	0
277073	263768	19689Q	PARTICIPANT	\N	PRESENT	0
277074	263768	11045K	PARTICIPANT	\N	PRESENT	0
277075	263768	08053X	PARTICIPANT	\N	PRESENT	0
277076	263768	19549D	PARTICIPANT	\N	PRESENT	0
277496	276029	14223L	PARTICIPANT	\N	PRESENT	0
277497	263769	19683J	PARTICIPANT	\N	PRESENT	0
277498	263769	19413M	PARTICIPANT	\N	PRESENT	0
277499	263769	19333N	PARTICIPANT	\N	PRESENT	0
277500	263769	11104D	PARTICIPANT	\N	PRESENT	0
277501	263769	14225N	PARTICIPANT	\N	PRESENT	0
277502	263769	95063L	PARTICIPANT	\N	PRESENT	0
277503	276029	19569H	PARTICIPANT	\N	PRESENT	0
277504	276029	19335Q	PARTICIPANT	\N	PRESENT	0
279062	268444	19503N	PARTICIPANT	\N	PRESENT	0
286221	286220	14053L	PARTICIPANT	\N	PRESENT	0
286222	286220	19719D	PARTICIPANT	\N	PRESENT	0
286223	286220	14281W	PARTICIPANT	\N	PRESENT	0
286224	286220	14026U	PARTICIPANT	\N	PRESENT	0
286226	286225	14053L	PARTICIPANT	\N	PRESENT	0
286227	286225	19719D	PARTICIPANT	\N	PRESENT	0
286228	286225	14026U	PARTICIPANT	\N	PRESENT	0
286230	286229	19719D	PARTICIPANT	\N	PRESENT	0
286231	286229	14053L	PARTICIPANT	\N	PRESENT	0
286232	286229	14281W	PARTICIPANT	\N	PRESENT	0
286234	286233	14053L	PARTICIPANT	\N	PRESENT	0
287914	273915	14042U	PARTICIPANT	\N	PRESENT	0
287915	273915	14231L	PARTICIPANT	\N	PRESENT	0
287916	273915	95063L	PARTICIPANT	\N	PRESENT	0
287917	273915	19669L	PARTICIPANT	\N	PRESENT	0
287918	273915	01057W	PARTICIPANT	\N	PRESENT	0
287919	273915	01028R	PARTICIPANT	\N	PRESENT	0
287923	273915	11077T	PARTICIPANT	\N	PRESENT	0
287921	273915	14089Y	PARTICIPANT	\N	PRESENT	0
287922	273915	19551W	PARTICIPANT	\N	PRESENT	0
287924	273915	11012A	PARTICIPANT	\N	PRESENT	0
287925	273915	07029T	PARTICIPANT	\N	PRESENT	0
287926	273915	19569H	PARTICIPANT	\N	PRESENT	0
287927	273915	14179A	PARTICIPANT	\N	PRESENT	0
287912	273915	17637T	PARTICIPANT	\N	PRESENT	0
287913	273915	08039A	PARTICIPANT	\N	PRESENT	0
289313	279374	19709B	PARTICIPANT	\N	EXCUSE	0
294066	293442	14111D	PARTICIPANT	\N	PRESENT	0
294067	293442	14065Q	PARTICIPANT	\N	PRESENT	0
294068	293442	11010L	PARTICIPANT	\N	PRESENT	0
294069	293442	07034Q	PRESIDENT	0	PRESENT	0
294070	293442	08045X	PARTICIPANT	\N	PRESENT	0
294071	293442	19253P	PARTICIPANT	\N	PRESENT	0
294072	293442	01024M	PARTICIPANT	\N	PRESENT	0
294073	293442	04038G	PARTICIPANT	\N	PRESENT	0
294074	293442	14089Y	PARTICIPANT	\N	PRESENT	0
294075	293442	19629C	PARTICIPANT	\N	PRESENT	0
294076	293442	08044W	PARTICIPANT	\N	PRESENT	0
294077	293442	11049P	PARTICIPANT	\N	PRESENT	0
294078	293442	14021P	PARTICIPANT	\N	PRESENT	0
294079	293442	14259Y	PARTICIPANT	\N	EXCUSE	0
294080	293442	19719D	PARTICIPANT	\N	EXCUSE	0
294081	292359	19333N	PARTICIPANT	\N	PRESENT	0
294082	292359	14031R	PARTICIPANT	\N	PRESENT	0
294083	292359	19549D	PARTICIPANT	\N	PRESENT	0
294084	292359	19387D	PARTICIPANT	\N	PRESENT	0
294085	292359	14221J	PARTICIPANT	\N	PRESENT	0
294086	292359	19599P	PARTICIPANT	\N	PRESENT	0
294087	292359	14169X	PARTICIPANT	\N	PRESENT	0
294088	292359	18083K	PARTICIPANT	\N	PRESENT	0
294089	292359	14237S	PARTICIPANT	\N	PRESENT	0
294090	292359	05012A	PARTICIPANT	\N	PRESENT	0
294091	292359	08009T	PRESIDENT	0	PRESENT	0
294092	292359	19503N	PARTICIPANT	\N	PRESENT	0
294093	292359	19739H	PARTICIPANT	\N	PRESENT	0
294094	292359	98023Q	PARTICIPANT	\N	PRESENT	0
294095	292359	14051J	PARTICIPANT	\N	EXCUSE	0
294096	292359	95062K	PARTICIPANT	\N	EXCUSE	0
294097	292359	96004D	PARTICIPANT	\N	EXCUSE	0
294098	292359	19347U	PARTICIPANT	\N	EXCUSE	0
294099	292359	14157T	PARTICIPANT	\N	PRESENT	0
294100	292359	14219Q	PARTICIPANT	\N	PRESENT	0
294101	292359	19737F	PARTICIPANT	\N	PRESENT	0
294102	292359	11065P	PARTICIPANT	\N	PRESENT	0
294103	292359	19701S	PARTICIPANT	\N	PRESENT	0
294105	294104	19533U	PARTICIPANT	\N	PRESENT	0
294106	294104	08012N	PARTICIPANT	\N	PRESENT	0
294109	294107	19533U	PARTICIPANT	\N	PRESENT	0
294110	294107	08012N	PARTICIPANT	\N	PRESENT	0
294111	294107	14123H	PARTICIPANT	\N	PRESENT	0
294112	292359	19383Y	PARTICIPANT	\N	PRESENT	0
294113	292359	17583W	PARTICIPANT	\N	PRESENT	0
294114	292359	04097T	PARTICIPANT	\N	PRESENT	0
294115	293992	04033B	PARTICIPANT	\N	PRESENT	0
294116	293992	19329S	PARTICIPANT	\N	PRESENT	0
294117	293992	14229S	PARTICIPANT	\N	PRESENT	0
294118	293992	19573D	PARTICIPANT	\N	PRESENT	0
294119	293992	08017T	PARTICIPANT	\N	PRESENT	0
294120	293992	14249W	PARTICIPANT	\N	PRESENT	0
294121	293992	08039A	PARTICIPANT	\N	PRESENT	0
294122	293992	14059S	PARTICIPANT	\N	PRESENT	0
294123	293992	19643A	PARTICIPANT	\N	PRESENT	0
294124	293992	19693L	PARTICIPANT	\N	PRESENT	0
294125	293992	87003B	PARTICIPANT	\N	PRESENT	0
294126	293992	19399H	PARTICIPANT	\N	PRESENT	0
294127	293992	14251Q	PARTICIPANT	\N	PRESENT	0
294128	293992	04059M	PARTICIPANT	\N	PRESENT	0
294129	293992	19735D	PARTICIPANT	\N	PRESENT	0
294130	293992	14109K	PARTICIPANT	\N	PRESENT	0
294131	293992	11043H	PARTICIPANT	\N	PRESENT	0
294132	293992	19749K	PARTICIPANT	\N	PRESENT	0
294133	293992	19758L	PARTICIPANT	\N	PRESENT	0
294134	292359	02002K	PARTICIPANT	\N	PRESENT	0
294137	294136	19533U	PARTICIPANT	\N	PRESENT	0
294140	294139	19533U	PARTICIPANT	\N	PRESENT	0
294141	294139	08031R	PARTICIPANT	\N	PRESENT	0
294142	292359	14103D	PARTICIPANT	\N	PRESENT	0
294144	294143	19533U	PARTICIPANT	\N	PRESENT	0
294145	294143	14241N	PARTICIPANT	\N	PRESENT	0
294146	294143	08012N	PARTICIPANT	\N	PRESENT	0
294147	294143	08031R	PARTICIPANT	\N	PRESENT	0
294149	294148	19533U	PARTICIPANT	\N	PRESENT	0
294150	293993	04070G	PRESIDENT	0	PRESENT	0
294151	293993	19699S	PARTICIPANT	\N	PRESENT	0
294152	293993	19533U	PARTICIPANT	\N	PRESENT	0
294153	293993	14229S	PARTICIPANT	\N	PRESENT	0
294154	293993	19573D	PARTICIPANT	\N	PRESENT	0
294155	293993	14107H	PARTICIPANT	\N	PRESENT	0
294156	293993	08017T	PARTICIPANT	\N	PRESENT	0
294157	293993	14249W	PARTICIPANT	\N	PRESENT	0
294158	293993	08039A	PARTICIPANT	\N	PRESENT	0
294159	293993	19593H	PARTICIPANT	\N	PRESENT	0
294160	293993	19643A	PARTICIPANT	\N	PRESENT	0
294161	293993	14059S	PARTICIPANT	\N	PRESENT	0
294162	293993	19611R	PARTICIPANT	\N	PRESENT	0
294163	293993	08043V	PARTICIPANT	\N	PRESENT	0
294164	293993	19693L	PARTICIPANT	\N	PRESENT	0
294165	293993	87003B	PARTICIPANT	\N	PRESENT	0
294166	293993	19399H	PARTICIPANT	\N	PRESENT	0
294167	293993	14030Q	PARTICIPANT	\N	PRESENT	0
294168	293993	19731Y	PARTICIPANT	\N	PRESENT	0
294169	293993	14251Q	PARTICIPANT	\N	PRESENT	0
294170	293993	04059M	PARTICIPANT	\N	PRESENT	0
294171	293993	19735D	PARTICIPANT	\N	PRESENT	0
294172	293993	14063N	PARTICIPANT	\N	PRESENT	0
294173	293993	14109K	PARTICIPANT	\N	PRESENT	0
294174	293993	14123H	PARTICIPANT	\N	PRESENT	0
294175	293993	11104D	PARTICIPANT	\N	PRESENT	0
294176	293993	11043H	PARTICIPANT	\N	PRESENT	0
294177	293993	19749K	PARTICIPANT	\N	PRESENT	0
294178	293993	19758L	PARTICIPANT	\N	PRESENT	0
294179	293993	19621T	PARTICIPANT	\N	PRESENT	0
294180	292361	19443T	PARTICIPANT	\N	PRESENT	0
294181	292361	12041X	PARTICIPANT	\N	PRESENT	0
294182	292361	95030B	PARTICIPANT	\N	PRESENT	0
294183	292361	01062T	PARTICIPANT	\N	PRESENT	0
294184	292361	11041F	PARTICIPANT	\N	PRESENT	0
294185	292361	08058D	PARTICIPANT	\N	PRESENT	0
294186	292361	14028W	PARTICIPANT	\N	PRESENT	0
294187	292361	11066Q	PARTICIPANT	\N	PRESENT	0
294188	292361	14105F	PARTICIPANT	\N	PRESENT	0
294189	292361	95037J	PARTICIPANT	\N	PRESENT	0
294190	292361	98018T	PRESIDENT	0	PRESENT	0
294191	292361	19421M	PARTICIPANT	\N	PRESENT	0
294192	292361	98022P	PARTICIPANT	\N	PRESENT	0
294193	292361	14193X	PARTICIPANT	\N	PRESENT	0
294194	292361	11064N	PARTICIPANT	\N	PRESENT	0
294195	292361	14267Y	PARTICIPANT	\N	PRESENT	0
294196	292361	98050T	PARTICIPANT	\N	PRESENT	0
294197	292361	97011G	PARTICIPANT	\N	PRESENT	0
294198	292361	08061X	PARTICIPANT	\N	PRESENT	0
294199	292361	19583F	PARTICIPANT	\N	PRESENT	0
294200	292361	08047A	PARTICIPANT	\N	PRESENT	0
294201	292361	98029W	PARTICIPANT	\N	PRESENT	0
294204	292361	98005N	PARTICIPANT	\N	PRESENT	0
294205	292361	16685X	PARTICIPANT	\N	PRESENT	0
294206	292361	14133K	PARTICIPANT	\N	PRESENT	0
294207	292361	04034C	PARTICIPANT	\N	PRESENT	0
294216	292933	14327T	PARTICIPANT	\N	PRESENT	0
294217	292933	14331P	PARTICIPANT	\N	PRESENT	0
294218	292933	04071H	PARTICIPANT	\N	PRESENT	0
294219	292933	01048V	PARTICIPANT	\N	PRESENT	0
294220	292933	19545Y	PARTICIPANT	\N	PRESENT	0
294221	292933	01057W	PARTICIPANT	\N	PRESENT	0
294222	292933	11053K	PARTICIPANT	\N	PRESENT	0
294223	292933	19667J	PARTICIPANT	\N	PRESENT	0
294224	292933	11070L	PARTICIPANT	\N	PRESENT	0
294225	292933	88008L	PRESIDENT	0	PRESENT	0
294226	292933	07029T	PARTICIPANT	\N	PRESENT	0
278476	263771	19413M	PARTICIPANT	\N	PRESENT	0
278477	263771	11077T	PARTICIPANT	\N	PRESENT	0
278478	263771	14051J	PARTICIPANT	\N	PRESENT	0
278479	263771	19551W	PARTICIPANT	\N	PRESENT	0
278480	263771	19737F	PARTICIPANT	\N	PRESENT	0
278481	263771	01025N	PARTICIPANT	\N	PRESENT	0
278482	263771	14207L	PARTICIPANT	\N	PRESENT	0
278483	263771	19747H	PARTICIPANT	\N	PRESENT	0
278484	263771	19533U	PARTICIPANT	\N	PRESENT	0
278485	263771	14329V	PARTICIPANT	\N	PRESENT	0
278486	263771	19675J	PARTICIPANT	\N	PRESENT	0
278487	263771	97011G	PARTICIPANT	\N	PRESENT	0
278488	263771	19745F	PARTICIPANT	\N	PRESENT	0
278489	263771	02002K	PARTICIPANT	\N	PRESENT	0
278490	263771	19687N	PARTICIPANT	\N	PRESENT	0
278491	263771	19565D	PARTICIPANT	\N	PRESENT	0
278492	263771	14213J	PARTICIPANT	\N	PRESENT	0
278493	263771	07029T	PARTICIPANT	\N	PRESENT	0
278494	263771	19723Y	PARTICIPANT	\N	PRESENT	0
278495	263771	19573D	PARTICIPANT	\N	PRESENT	0
278496	263771	14119M	PARTICIPANT	\N	PRESENT	0
278497	263771	87003B	PARTICIPANT	\N	PRESENT	0
278498	263771	19575F	PARTICIPANT	\N	PRESENT	0
278499	263771	11080N	PARTICIPANT	\N	PRESENT	0
278500	263771	08061X	PARTICIPANT	\N	PRESENT	0
278501	263771	11012A	PARTICIPANT	\N	PRESENT	0
278502	263771	11056N	PARTICIPANT	\N	PRESENT	0
278503	263771	08024S	PARTICIPANT	\N	PRESENT	0
278504	263771	14030Q	PARTICIPANT	\N	PRESENT	0
278505	263771	19733B	PARTICIPANT	\N	PRESENT	0
278506	263771	04057K	PARTICIPANT	\N	PRESENT	0
278507	263771	19543W	PARTICIPANT	\N	PRESENT	0
278508	263771	08062Y	PARTICIPANT	\N	PRESENT	0
278509	263771	10006L	PARTICIPANT	\N	PRESENT	0
278510	263771	14259Y	PARTICIPANT	\N	PRESENT	0
278511	263771	14265W	PARTICIPANT	\N	PRESENT	0
278512	263771	19611R	PARTICIPANT	\N	PRESENT	0
278513	263771	08010L	PARTICIPANT	\N	PRESENT	0
278514	263771	08038Y	PARTICIPANT	\N	PRESENT	0
278515	263771	04061F	PARTICIPANT	\N	PRESENT	0
278516	263771	14041T	PARTICIPANT	\N	PRESENT	0
278517	263771	14215L	PARTICIPANT	\N	PRESENT	0
278518	263771	19629C	PARTICIPANT	\N	PRESENT	0
278519	263771	95030B	PARTICIPANT	\N	PRESENT	0
278520	263771	19349W	PARTICIPANT	\N	PRESENT	0
278521	263771	08016S	PARTICIPANT	\N	PRESENT	0
278522	263771	14121F	PARTICIPANT	\N	PRESENT	0
278523	263771	17637T	PARTICIPANT	\N	PRESENT	0
278524	263771	19253P	PARTICIPANT	\N	PRESENT	0
278525	263771	95062K	PARTICIPANT	\N	PRESENT	0
278526	263771	14069U	PARTICIPANT	\N	PRESENT	0
278527	263771	98050T	PARTICIPANT	\N	PRESENT	0
278528	263771	19503N	PARTICIPANT	\N	PRESENT	0
278529	263771	19673G	PARTICIPANT	\N	PRESENT	0
278530	263771	08034U	PARTICIPANT	\N	PRESENT	0
278531	263771	14083S	PARTICIPANT	\N	PRESENT	0
278532	263771	14034U	PARTICIPANT	\N	PRESENT	0
278533	263771	19553Y	PARTICIPANT	\N	PRESENT	0
278534	263771	14197C	PARTICIPANT	\N	PRESENT	0
278535	263771	11099A	PARTICIPANT	\N	PRESENT	0
278536	263771	19741B	PARTICIPANT	\N	PRESENT	0
278537	263771	19715Y	PARTICIPANT	\N	PRESENT	0
278538	263771	14169X	PARTICIPANT	\N	PRESENT	0
278539	263771	08060W	PARTICIPANT	\N	PRESENT	0
278540	263771	14257W	PARTICIPANT	\N	PRESENT	0
278541	263771	01058X	PARTICIPANT	\N	PRESENT	0
278542	263771	08020N	PARTICIPANT	\N	PRESENT	0
278543	263771	11033F	PARTICIPANT	\N	PRESENT	0
278544	263771	19549D	PARTICIPANT	\N	PRESENT	0
278545	263771	14205J	PARTICIPANT	\N	PRESENT	0
278546	263771	14073Q	PARTICIPANT	\N	PRESENT	0
278547	263771	14327T	PARTICIPANT	\N	PRESENT	0
278548	263771	11097X	PARTICIPANT	\N	PRESENT	0
278549	263771	11048N	PARTICIPANT	\N	PRESENT	0
278550	263771	19531S	PARTICIPANT	\N	PRESENT	0
278551	263771	19703U	PARTICIPANT	\N	PRESENT	0
278552	263771	19591F	PARTICIPANT	\N	PRESENT	0
278553	263771	14275Y	PARTICIPANT	\N	PRESENT	0
278554	263771	08049C	PARTICIPANT	\N	PRESENT	0
278555	263771	19689Q	PARTICIPANT	\N	PRESENT	0
278556	263771	19621T	PARTICIPANT	\N	PRESENT	0
278557	263771	08052W	PARTICIPANT	\N	PRESENT	0
278558	263771	11067R	PARTICIPANT	\N	PRESENT	0
278559	263771	08017T	PARTICIPANT	\N	PRESENT	0
278560	263771	14195A	PARTICIPANT	\N	PRESENT	0
278561	263771	19563B	PARTICIPANT	\N	PRESENT	0
278671	263772	11070L	PARTICIPANT	\N	PRESENT	0
278672	263772	98023Q	PARTICIPANT	\N	PRESENT	0
278673	263772	08009T	PARTICIPANT	\N	PRESENT	0
278674	263772	14195A	PARTICIPANT	\N	PRESENT	0
278675	263772	07029T	PARTICIPANT	\N	PRESENT	0
278676	263772	04085P	PARTICIPANT	\N	PRESENT	0
278677	263772	19593H	PARTICIPANT	\N	PRESENT	0
278678	263772	19695N	PARTICIPANT	\N	PRESENT	0
278679	263772	19531S	PARTICIPANT	\N	PRESENT	0
278680	263772	08024S	PARTICIPANT	\N	PRESENT	0
278681	263772	11065P	PARTICIPANT	\N	PRESENT	0
278682	263772	18083K	PARTICIPANT	\N	PRESENT	0
278683	263772	19737F	PARTICIPANT	\N	PRESENT	0
278684	263772	19253P	PARTICIPANT	\N	PRESENT	0
278685	263772	19727D	PARTICIPANT	\N	PRESENT	0
278686	263772	19565D	PARTICIPANT	\N	PRESENT	0
278687	263772	19347U	PARTICIPANT	\N	PRESENT	0
278688	263772	19387D	PARTICIPANT	\N	PRESENT	0
278689	263772	19563B	PARTICIPANT	\N	PRESENT	0
278690	263772	19551W	PARTICIPANT	\N	PRESENT	0
278691	263772	19637C	PARTICIPANT	\N	PRESENT	0
278692	263772	19687N	PARTICIPANT	\N	PRESENT	0
278693	263772	14157T	PARTICIPANT	\N	PRESENT	0
278694	263772	08034U	PARTICIPANT	\N	PRESENT	0
278695	263772	19447X	PARTICIPANT	\N	PRESENT	0
278696	263772	11056N	PARTICIPANT	\N	PRESENT	0
278697	263772	11031D	PARTICIPANT	\N	PRESENT	0
278698	263772	14087W	PARTICIPANT	\N	PRESENT	0
278699	263772	95062K	PARTICIPANT	\N	PRESENT	0
278700	263772	14219Q	PARTICIPANT	\N	PRESENT	0
278701	263772	19681G	PARTICIPANT	\N	PRESENT	0
278702	263772	14215L	PARTICIPANT	\N	PRESENT	0
278703	263772	12041X	PARTICIPANT	\N	PRESENT	0
278704	263772	14327T	PARTICIPANT	\N	PRESENT	0
278705	263772	19713W	PARTICIPANT	\N	PRESENT	0
278706	263772	19723Y	PARTICIPANT	\N	PRESENT	0
278707	263772	08020N	PARTICIPANT	\N	PRESENT	0
278708	263772	19697Q	PARTICIPANT	\N	PRESENT	0
278709	263772	14331P	PARTICIPANT	\N	PRESENT	0
278710	263772	14147R	PARTICIPANT	\N	PRESENT	0
278711	263772	14217N	PARTICIPANT	\N	PRESENT	0
278712	263772	19643A	PARTICIPANT	\N	PRESENT	0
278713	263772	08049C	PARTICIPANT	\N	PRESENT	0
278714	263772	02002K	PARTICIPANT	\N	PRESENT	0
278715	263772	11048N	PARTICIPANT	\N	PRESENT	0
278716	263772	11012A	PARTICIPANT	\N	PRESENT	0
278717	263772	11099A	PARTICIPANT	\N	PRESENT	0
278718	263772	14357A	PARTICIPANT	\N	PRESENT	0
278719	263772	04088S	PARTICIPANT	\N	PRESENT	0
278720	263772	14169X	PARTICIPANT	\N	PRESENT	0
278721	263772	10006L	PARTICIPANT	\N	PRESENT	0
278722	263772	11067R	PARTICIPANT	\N	PRESENT	0
278723	263772	05012A	PARTICIPANT	\N	PRESENT	0
278724	263772	19689Q	PARTICIPANT	\N	PRESENT	0
278725	263772	14231L	PARTICIPANT	\N	PRESENT	0
278726	263772	14265W	PARTICIPANT	\N	PRESENT	0
278727	263772	14213J	PARTICIPANT	\N	PRESENT	0
278728	263772	19741B	PARTICIPANT	\N	PRESENT	0
278729	263772	11097X	PARTICIPANT	\N	PRESENT	0
278730	263772	14033T	PARTICIPANT	\N	PRESENT	0
278731	263772	04061F	PARTICIPANT	\N	PRESENT	0
278732	263772	19575F	PARTICIPANT	\N	PRESENT	0
278733	263772	19503N	PARTICIPANT	\N	PRESENT	0
278734	263772	14051J	PARTICIPANT	\N	PRESENT	0
278735	263772	08055A	PARTICIPANT	\N	PRESENT	0
278736	263772	01024M	PARTICIPANT	\N	PRESENT	0
278737	263772	19413M	PARTICIPANT	\N	PRESENT	0
278738	263772	19553Y	PARTICIPANT	\N	PRESENT	0
278739	263772	19525U	PARTICIPANT	\N	PRESENT	0
278740	263772	04047H	PARTICIPANT	\N	PRESENT	0
278741	263772	14030Q	PARTICIPANT	\N	PRESENT	0
278742	263772	08052W	PARTICIPANT	\N	PRESENT	0
278743	263772	08019V	PARTICIPANT	\N	PRESENT	0
278744	263772	08060W	PARTICIPANT	\N	PRESENT	0
278745	263772	14257W	PARTICIPANT	\N	PRESENT	0
278746	263772	19333N	PARTICIPANT	\N	PRESENT	0
278747	263772	08068F	PARTICIPANT	\N	PRESENT	0
278748	263772	19573D	PARTICIPANT	\N	PRESENT	0
278749	263772	14034U	PARTICIPANT	\N	PRESENT	0
278750	263772	14073Q	PARTICIPANT	\N	PRESENT	0
278751	263772	14083S	PARTICIPANT	\N	PRESENT	0
278752	263772	19507S	PARTICIPANT	\N	PRESENT	0
278098	263008	19717B	PARTICIPANT	\N	PRESENT	0
278099	263008	14195A	PARTICIPANT	\N	PRESENT	0
278100	263008	19415P	PARTICIPANT	\N	PRESENT	0
278439	278438	19737F	PARTICIPANT	\N	PRESENT	0
278440	278438	11097X	PARTICIPANT	\N	EXCUSE	0
278441	278438	99004R	PRESIDENT	0	PRESENT	0
278443	278438	19713W	PARTICIPANT	\N	PRESENT	0
281418	273866	19631V	PARTICIPANT	\N	PRESENT	0
281419	273863	19631V	PARTICIPANT	\N	PRESENT	0
281420	273863	19515S	PARTICIPANT	\N	PRESENT	0
281421	273863	05008E	PARTICIPANT	\N	PRESENT	0
281422	273863	19543W	PARTICIPANT	\N	PRESENT	0
281423	273863	19575F	PARTICIPANT	\N	PRESENT	0
281424	273863	14115H	PARTICIPANT	\N	PRESENT	0
281425	273863	14065Q	PARTICIPANT	\N	PRESENT	0
281426	273863	96004D	PARTICIPANT	\N	PRESENT	0
281428	273863	08043V	PARTICIPANT	\N	PRESENT	0
281429	273863	14069U	PARTICIPANT	\N	PRESENT	0
281430	273863	19415P	PARTICIPANT	\N	PRESENT	0
281505	280500	08043V	PARTICIPANT	\N	PRESENT	0
281432	273863	14089Y	PARTICIPANT	\N	PRESENT	0
281436	273863	19747H	PARTICIPANT	\N	PRESENT	0
281434	273863	19733B	PARTICIPANT	\N	PRESENT	0
281435	273863	14105F	PARTICIPANT	\N	PRESENT	0
281437	273863	08020N	PARTICIPANT	\N	PRESENT	0
281438	273863	19758L	PARTICIPANT	\N	PRESENT	0
281439	273863	11101A	PARTICIPANT	\N	PRESENT	0
281440	273863	04042C	PARTICIPANT	\N	PRESENT	0
281441	273863	14053L	PARTICIPANT	\N	PRESENT	0
281442	273863	14329V	PARTICIPANT	\N	PRESENT	0
281443	273863	14038Y	PARTICIPANT	\N	PRESENT	0
281444	273863	19467C	PARTICIPANT	\N	PRESENT	0
281445	273863	18083K	PARTICIPANT	\N	PRESENT	0
281446	273863	19701S	PARTICIPANT	\N	PRESENT	0
281447	273863	04038G	PARTICIPANT	\N	PRESENT	0
281448	273863	19253P	PARTICIPANT	\N	PRESENT	0
281449	273863	11070L	PARTICIPANT	\N	PRESENT	0
281450	273863	98024R	PARTICIPANT	\N	PRESENT	0
281451	273863	19507S	PARTICIPANT	\N	PRESENT	0
281452	273863	14249W	PARTICIPANT	\N	PRESENT	0
281453	273863	11074Q	PARTICIPANT	\N	PRESENT	0
281454	273863	95030B	PARTICIPANT	\N	PRESENT	0
281455	273863	14187A	PARTICIPANT	\N	PRESENT	0
281456	273863	97011G	PARTICIPANT	\N	PRESENT	0
281457	273863	14034U	PARTICIPANT	\N	PRESENT	0
281458	273863	14231L	PARTICIPANT	\N	PRESENT	0
281459	273863	19387D	PARTICIPANT	\N	PRESENT	0
281460	273863	14033T	PARTICIPANT	\N	PRESENT	0
281461	273863	19569H	PARTICIPANT	\N	PRESENT	0
281462	273863	04097T	PARTICIPANT	\N	PRESENT	0
281463	273863	11048N	PARTICIPANT	\N	PRESENT	0
281464	273863	14213J	PARTICIPANT	\N	PRESENT	0
281465	273863	19715Y	PARTICIPANT	\N	PRESENT	0
281466	273863	19447X	PARTICIPANT	\N	PRESENT	0
281467	273863	19731Y	PARTICIPANT	\N	PRESENT	0
281468	273863	14073Q	PARTICIPANT	\N	PRESENT	0
281469	273863	07029T	PARTICIPANT	\N	PRESENT	0
281470	273863	14029X	PARTICIPANT	\N	PRESENT	0
281471	273863	86034E	PARTICIPANT	\N	PRESENT	0
281472	273863	19711U	PARTICIPANT	\N	PRESENT	0
281473	273863	19709B	PARTICIPANT	\N	PRESENT	0
281474	273863	01043Q	PARTICIPANT	\N	PRESENT	0
281475	273863	14219Q	PARTICIPANT	\N	PRESENT	0
281476	273863	19441R	PARTICIPANT	\N	PRESENT	0
281477	273863	14031R	PARTICIPANT	\N	PRESENT	0
281478	273863	14111D	PARTICIPANT	\N	PRESENT	0
281479	273863	08009T	PARTICIPANT	\N	PRESENT	0
281480	273863	19671E	PARTICIPANT	\N	PRESENT	0
281481	273863	14223L	PARTICIPANT	\N	PRESENT	0
281482	273863	04092N	PARTICIPANT	\N	PRESENT	0
281483	273863	19335Q	PARTICIPANT	\N	PRESENT	0
281484	273863	14257W	PARTICIPANT	\N	PRESENT	0
281485	273863	14265W	PARTICIPANT	\N	PRESENT	0
281486	273863	04070G	PARTICIPANT	\N	PRESENT	0
281487	273863	14119M	PARTICIPANT	\N	PRESENT	0
281488	273863	19593H	PARTICIPANT	\N	PRESENT	0
281489	273863	14237S	PARTICIPANT	\N	PRESENT	0
281490	273863	19745F	PARTICIPANT	\N	PRESENT	0
281491	273863	98050T	PARTICIPANT	\N	PRESENT	0
281492	273863	11090Q	PARTICIPANT	\N	PRESENT	0
281493	273863	19739H	PARTICIPANT	\N	PRESENT	0
281494	273863	14331P	PARTICIPANT	\N	PRESENT	0
281495	273863	95062K	PARTICIPANT	\N	PRESENT	0
281496	273863	95063L	PARTICIPANT	\N	PRESENT	0
281497	273863	11097X	PARTICIPANT	\N	PRESENT	0
281498	273863	11043H	PARTICIPANT	\N	PRESENT	0
281499	273863	19703U	PARTICIPANT	\N	PRESENT	0
281500	273863	01028R	PARTICIPANT	\N	PRESENT	0
281501	273863	04044E	PARTICIPANT	\N	PRESENT	0
281502	273863	19479G	PARTICIPANT	\N	PRESENT	0
281503	273863	19737F	PARTICIPANT	\N	PRESENT	0
281504	280500	04018C	PARTICIPANT	\N	PRESENT	0
281506	280500	14109K	PARTICIPANT	\N	PRESENT	0
281508	281507	08043V	PARTICIPANT	\N	PRESENT	0
281509	281507	04018C	PARTICIPANT	\N	PRESENT	0
286325	286324	19701S	PARTICIPANT	\N	PRESENT	0
286326	286324	19667J	PARTICIPANT	\N	PRESENT	0
286327	282453	14219Q	PARTICIPANT	\N	EXCUSE	0
289324	289323	19647E	PARTICIPANT	\N	PRESENT	0
289326	289325	04071H	PARTICIPANT	\N	PRESENT	0
289356	289355	19251M	PARTICIPANT	\N	PRESENT	0
289357	289355	19593H	PARTICIPANT	\N	PRESENT	0
289358	289355	19689Q	PARTICIPANT	\N	PRESENT	0
301736	289204	04043D	PARTICIPANT	\N	PRESENT	0
301737	289204	14079W	PARTICIPANT	\N	PRESENT	0
301738	289204	04085P	PARTICIPANT	\N	PRESENT	0
301739	289204	19673G	PARTICIPANT	\N	PRESENT	0
301740	289204	19295A	PARTICIPANT	\N	PRESENT	0
301741	289204	04008A	PARTICIPANT	\N	PRESENT	0
301742	289204	19647E	PARTICIPANT	\N	PRESENT	0
301743	289204	01028R	PARTICIPANT	\N	PRESENT	0
301744	289204	19657G	PARTICIPANT	\N	PRESENT	0
301745	289204	11099A	PARTICIPANT	\N	PRESENT	0
301746	289204	99004R	PARTICIPANT	\N	PRESENT	0
301747	289204	19593H	PARTICIPANT	\N	PRESENT	0
301748	289204	14119M	PARTICIPANT	\N	PRESENT	0
301749	289204	02002K	PARTICIPANT	\N	PRESENT	0
301750	289204	19697Q	PARTICIPANT	\N	PRESENT	0
301752	301751	99004R	PARTICIPANT	\N	PRESENT	0
301753	289204	04049K	PARTICIPANT	\N	PRESENT	0
301754	289204	08010L	PARTICIPANT	\N	PRESENT	0
301756	301755	19503N	PARTICIPANT	\N	PRESENT	0
301757	289204	12016W	PARTICIPANT	\N	PRESENT	0
301758	289204	04035D	PARTICIPANT	\N	PRESENT	0
301760	301759	07004J	PARTICIPANT	\N	PRESENT	0
301794	289206	19651A	PARTICIPANT	\N	PRESENT	0
301795	289206	19697Q	PARTICIPANT	\N	PRESENT	0
301734	289204	14026U	PARTICIPANT	\N	PRESENT	0
301735	289204	19711U	PARTICIPANT	\N	PRESENT	0
301796	289206	11099A	PARTICIPANT	\N	PRESENT	0
301797	289206	19295A	PARTICIPANT	\N	PRESENT	0
301798	289206	19695N	PARTICIPANT	\N	PRESENT	0
301799	289206	11056N	PARTICIPANT	\N	PRESENT	0
301800	289206	19253P	PARTICIPANT	\N	PRESENT	0
301801	289206	14083S	PARTICIPANT	\N	PRESENT	0
301802	289206	14026U	PARTICIPANT	\N	PRESENT	0
301803	289206	04035D	PARTICIPANT	\N	PRESENT	0
301804	289206	19657G	PARTICIPANT	\N	PRESENT	0
301805	289206	11077T	PARTICIPANT	\N	PRESENT	0
301806	289206	11090Q	PARTICIPANT	\N	PRESENT	0
301807	289206	14187A	PARTICIPANT	\N	PRESENT	0
301808	289206	19591F	PARTICIPANT	\N	PRESENT	0
301809	289206	08019V	PARTICIPANT	\N	PRESENT	0
301810	289206	99004R	PARTICIPANT	\N	PRESENT	0
301811	289206	19671E	PARTICIPANT	\N	PRESENT	0
301812	289206	04086Q	PARTICIPANT	\N	PRESENT	0
301813	289206	08068F	PARTICIPANT	\N	PRESENT	0
301814	289206	14038Y	PARTICIPANT	\N	PRESENT	0
301815	289206	08010L	PARTICIPANT	\N	PRESENT	0
301816	289206	19593H	PARTICIPANT	\N	PRESENT	0
301817	289206	07029T	PARTICIPANT	\N	PRESENT	0
301818	289206	19565D	PARTICIPANT	\N	PRESENT	0
301819	289206	08038Y	PARTICIPANT	\N	PRESENT	0
301820	289206	19749K	PARTICIPANT	\N	PRESENT	0
301821	289206	11109J	PARTICIPANT	\N	PRESENT	0
301833	300455	08052W	PRESIDENT	0	PRESENT	0
301834	300455	17589D	PARTICIPANT	\N	PRESENT	0
301836	301835	86034E	PARTICIPANT	\N	PRESENT	0
301792	289206	11072N	PARTICIPANT	\N	PRESENT	0
301793	289206	19631V	PARTICIPANT	\N	PRESENT	0
301837	301835	19711U	PARTICIPANT	\N	PRESENT	0
301838	301835	04085P	PARTICIPANT	\N	PRESENT	0
301839	301835	08019V	PARTICIPANT	\N	PRESENT	0
301840	301835	04086Q	PARTICIPANT	\N	PRESENT	0
301841	301835	19717B	PARTICIPANT	\N	PRESENT	0
301842	301835	19611R	PARTICIPANT	\N	PRESENT	0
301843	301832	19649G	PARTICIPANT	\N	PRESENT	0
301844	301832	14065Q	PARTICIPANT	\N	PRESENT	0
301845	301832	19629C	PARTICIPANT	\N	PRESENT	0
275295	275294	14231L	PARTICIPANT	\N	PRESENT	0
275297	275296	14231L	PARTICIPANT	\N	PRESENT	0
276031	273669	19295A	PARTICIPANT	\N	EXCUSE	0
276032	273669	19583F	PARTICIPANT	\N	EXCUSE	0
278837	278833	19667J	PARTICIPANT	\N	PRESENT	0
278839	278838	19667J	PARTICIPANT	\N	PRESENT	0
278841	278840	19667J	PARTICIPANT	\N	PRESENT	0
278885	278884	04061F	PARTICIPANT	\N	PRESENT	0
278891	278890	04061F	PARTICIPANT	\N	PRESENT	0
278893	278892	04061F	PARTICIPANT	\N	PRESENT	0
279064	268444	19709B	PARTICIPANT	\N	PRESENT	0
279066	268444	14299H	PARTICIPANT	\N	PRESENT	0
279290	279289	08058D	PRESIDENT	0	PRESENT	0
279291	279289	11049P	PARTICIPANT	\N	PRESENT	0
279292	279289	14097Y	PARTICIPANT	\N	PRESENT	0
279293	279289	04071H	PARTICIPANT	\N	PRESENT	0
279294	279289	19251M	PARTICIPANT	\N	PRESENT	0
279295	279289	19703U	PARTICIPANT	\N	PRESENT	0
279296	279289	08034U	PARTICIPANT	\N	PRESENT	0
279297	279289	19729F	PARTICIPANT	\N	PRESENT	0
279298	279289	19443T	PARTICIPANT	\N	PRESENT	0
279300	279299	08058D	PARTICIPANT	\N	PRESENT	0
279301	279299	11049P	PARTICIPANT	\N	PRESENT	0
279303	279299	04071H	PARTICIPANT	\N	PRESENT	0
279304	279299	19251M	PARTICIPANT	\N	PRESENT	0
279305	279299	19703U	PARTICIPANT	\N	PRESENT	0
279306	279299	08034U	PARTICIPANT	\N	PRESENT	0
279307	279299	19729F	PARTICIPANT	\N	PRESENT	0
279308	279299	19443T	PARTICIPANT	\N	PRESENT	0
279372	279263	19489J	PARTICIPANT	\N	PRESENT	0
279386	279263	04044E	PARTICIPANT	\N	PRESENT	0
279823	279822	96004D	PARTICIPANT	\N	PRESENT	0
279824	279822	14089Y	PARTICIPANT	\N	PRESENT	0
279825	279388	96004D	PARTICIPANT	\N	PRESENT	0
279826	279388	14089Y	PARTICIPANT	\N	PRESENT	0
284005	284004	11026G	PARTICIPANT	\N	PRESENT	0
284006	284004	14237S	PARTICIPANT	\N	PRESENT	0
284060	284059	19719D	PARTICIPANT	\N	PRESENT	0
284077	284076	14147R	PARTICIPANT	\N	PRESENT	0
284079	284078	14147R	PARTICIPANT	\N	PRESENT	0
278763	278761	14253S	PARTICIPANT	\N	PRESENT	0
278764	278761	14085U	PARTICIPANT	\N	PRESENT	0
284797	284796	11040E	PARTICIPANT	\N	PRESENT	0
284798	284796	19629C	PARTICIPANT	\N	PRESENT	0
284799	284796	19681G	PARTICIPANT	\N	PRESENT	0
284800	284796	08031R	PARTICIPANT	\N	PRESENT	0
284801	284796	95037J	PARTICIPANT	\N	PRESENT	0
284802	284796	14135M	PARTICIPANT	\N	PRESENT	0
284803	284796	95067Q	PARTICIPANT	\N	PRESENT	0
284804	284796	14255U	PARTICIPANT	\N	PRESENT	0
285110	285109	14225N	PARTICIPANT	\N	PRESENT	0
284826	284816	19631V	PARTICIPANT	\N	PRESENT	0
284827	284816	19515S	PARTICIPANT	\N	PRESENT	0
284828	284816	19707Y	PARTICIPANT	\N	PRESENT	0
284829	284816	11081P	PARTICIPANT	\N	EXCUSE	0
284830	284816	14115H	PARTICIPANT	\N	PRESENT	0
284831	284816	19747H	PARTICIPANT	\N	PRESENT	0
285111	285109	11026G	PARTICIPANT	\N	PRESENT	0
284833	284816	14207L	PARTICIPANT	\N	PRESENT	0
289475	289088	11085T	PARTICIPANT	\N	PRESENT	0
289476	289088	19697Q	PARTICIPANT	\N	PRESENT	0
284836	284816	08028W	PARTICIPANT	\N	PRESENT	0
284837	284816	19467C	PARTICIPANT	\N	PRESENT	0
289488	289088	08069G	PARTICIPANT	\N	PRESENT	0
284839	284816	80013X	PARTICIPANT	\N	PRESENT	0
289489	279374	19723Y	PARTICIPANT	\N	EXCUSE	0
284841	284816	14357A	PARTICIPANT	\N	PRESENT	0
284842	284816	08038Y	PARTICIPANT	\N	PRESENT	0
284843	284816	17589D	PARTICIPANT	\N	PRESENT	0
284844	284816	04089T	PARTICIPANT	\N	EXCUSE	0
284845	284816	19507S	PARTICIPANT	\N	PRESENT	0
284846	284816	14197C	PARTICIPANT	\N	PRESENT	0
289490	279374	14239U	PARTICIPANT	\N	EXCUSE	0
284848	284816	01025N	PARTICIPANT	\N	PRESENT	0
284849	284816	19695N	PARTICIPANT	\N	PRESENT	0
284850	284816	19565D	PARTICIPANT	\N	PRESENT	0
284851	284816	14033T	PARTICIPANT	\N	PRESENT	0
284852	284816	14081Q	PARTICIPANT	\N	PRESENT	0
289491	289088	11109J	PARTICIPANT	\N	PRESENT	0
284854	284816	19511N	PARTICIPANT	\N	PRESENT	0
284855	284816	11099A	PARTICIPANT	\N	PRESENT	0
284856	284816	04049K	PARTICIPANT	\N	PRESENT	0
284857	284816	08015R	PARTICIPANT	\N	PRESENT	0
289602	289601	10006L	PARTICIPANT	\N	PRESENT	0
284859	284816	14205J	PARTICIPANT	\N	PRESENT	0
284860	284816	19441R	PARTICIPANT	\N	PRESENT	0
289603	289601	16685X	PARTICIPANT	\N	PRESENT	0
284862	284816	08062Y	PARTICIPANT	\N	PRESENT	0
284863	284816	19563B	PARTICIPANT	\N	PRESENT	0
284864	284816	19369B	PARTICIPANT	\N	PRESENT	0
284865	284816	14257W	PARTICIPANT	\N	PRESENT	0
284866	284816	14265W	PARTICIPANT	\N	PRESENT	0
289604	289601	14073Q	PARTICIPANT	\N	PRESENT	0
284868	284816	04088S	PARTICIPANT	\N	PRESENT	0
284869	284816	11090Q	PRESIDENT	0	PRESENT	0
284870	284816	04043D	PARTICIPANT	\N	PRESENT	0
284871	284816	14135M	PARTICIPANT	\N	PRESENT	0
284872	284816	19269X	PARTICIPANT	\N	PRESENT	0
284873	284816	19705W	PARTICIPANT	\N	PRESENT	0
284874	284816	19619A	PARTICIPANT	\N	PRESENT	0
289605	289601	01058X	PARTICIPANT	\N	PRESENT	0
284876	284816	19413M	PARTICIPANT	\N	PRESENT	0
289606	289601	08031R	PARTICIPANT	\N	PRESENT	0
289607	289601	14097Y	PARTICIPANT	\N	PRESENT	0
289734	289578	14135M	PARTICIPANT	\N	PRESENT	0
289735	289578	19515S	PARTICIPANT	\N	PRESENT	0
289736	289578	19565D	PARTICIPANT	\N	PRESENT	0
289737	289578	14357A	PARTICIPANT	\N	PRESENT	0
289738	289578	19441R	PARTICIPANT	\N	PRESENT	0
289739	289578	19413M	PARTICIPANT	\N	PRESENT	0
289740	289578	11090Q	PRESIDENT	0	PRESENT	0
289741	289578	80013X	PARTICIPANT	\N	PRESENT	0
289742	289578	19269X	PARTICIPANT	\N	PRESENT	0
289743	289578	14205J	PARTICIPANT	\N	PRESENT	0
289744	289578	11099A	PARTICIPANT	\N	PRESENT	0
289745	289578	14115H	PARTICIPANT	\N	PRESENT	0
289746	289578	19705W	PARTICIPANT	\N	PRESENT	0
289747	289578	08019V	PARTICIPANT	\N	PRESENT	0
289748	289578	19369B	PARTICIPANT	\N	PRESENT	0
289749	289578	19747H	PARTICIPANT	\N	PRESENT	0
289750	289578	19511N	PARTICIPANT	\N	PRESENT	0
289751	289578	14265W	PARTICIPANT	\N	PRESENT	0
289752	289578	14329V	PARTICIPANT	\N	PRESENT	0
289753	289578	14257W	PARTICIPANT	\N	PRESENT	0
289758	289733	14053L	PARTICIPANT	\N	PRESENT	0
289759	289733	14111D	PARTICIPANT	\N	PRESENT	0
289760	289733	14065Q	PARTICIPANT	\N	PRESENT	0
289761	289733	11010L	PARTICIPANT	\N	PRESENT	0
289762	289733	07034Q	PARTICIPANT	\N	PRESENT	0
289763	289733	19253P	PARTICIPANT	\N	PRESENT	0
289764	289733	01024M	PARTICIPANT	\N	PRESENT	0
289765	289733	04038G	PARTICIPANT	\N	PRESENT	0
289766	289733	19581D	PARTICIPANT	\N	PRESENT	0
289767	289733	19585H	PARTICIPANT	\N	PRESENT	0
289768	289733	04047H	PARTICIPANT	\N	PRESENT	0
289769	289733	19719D	PARTICIPANT	\N	PRESENT	0
289770	289733	19447X	PARTICIPANT	\N	PRESENT	0
289771	289733	05008E	PRESIDENT	0	PRESENT	0
289772	289733	19729F	PARTICIPANT	\N	PRESENT	0
289773	289733	19489J	PARTICIPANT	\N	PRESENT	0
289774	289733	14041T	PARTICIPANT	\N	PRESENT	0
289775	289733	14179A	PARTICIPANT	\N	PRESENT	0
289776	289733	14151M	PARTICIPANT	\N	PRESENT	0
289777	289733	14069U	PARTICIPANT	\N	PRESENT	0
289778	289733	14215L	PARTICIPANT	\N	PRESENT	0
289779	289733	11072N	PARTICIPANT	\N	PRESENT	0
289780	289733	19543W	PARTICIPANT	\N	PRESENT	0
289781	289733	01028R	PARTICIPANT	\N	PRESENT	0
289782	289733	04044E	PARTICIPANT	\N	EXCUSE	0
290045	289756	19543W	PARTICIPANT	\N	PRESENT	0
290046	289756	19671E	PARTICIPANT	\N	PRESENT	0
290047	289756	19747H	PARTICIPANT	\N	PRESENT	0
290048	289756	19367Y	PARTICIPANT	\N	PRESENT	0
290049	289756	14026U	PARTICIPANT	\N	PRESENT	0
290050	289756	19707Y	PARTICIPANT	\N	PRESENT	0
290051	289756	19581D	PARTICIPANT	\N	PRESENT	0
290052	289756	05008E	PARTICIPANT	\N	PRESENT	0
290053	289756	19383Y	PARTICIPANT	\N	PRESENT	0
290054	289756	04047H	PARTICIPANT	\N	PRESENT	0
290055	289756	19701S	PARTICIPANT	\N	PRESENT	0
273697	261023	11067R	PARTICIPANT	\N	PRESENT	0
273698	261023	04092N	PARTICIPANT	\N	PRESENT	0
273699	261023	14195A	PARTICIPANT	\N	PRESENT	0
273701	273700	14071N	PARTICIPANT	\N	PRESENT	0
273703	273702	14071N	PARTICIPANT	\N	PRESENT	0
273705	273704	14071N	PARTICIPANT	\N	PRESENT	0
273707	273706	14179A	PARTICIPANT	\N	PRESENT	0
273709	273708	14179A	PARTICIPANT	\N	PRESENT	0
273710	273708	11026G	PARTICIPANT	\N	PRESENT	0
273712	273711	14179A	PARTICIPANT	\N	PRESENT	0
273717	273666	19659J	PARTICIPANT	\N	EXCUSE	0
273718	273666	14275Y	PARTICIPANT	\N	EXCUSE	0
276040	270299	04061F	PARTICIPANT	\N	PRESENT	0
276041	270299	19713W	PARTICIPANT	\N	PRESENT	0
286002	276479	14071N	PARTICIPANT	\N	PRESENT	0
286006	285951	89017R	PARTICIPANT	\N	EXCUSE	0
286007	285951	14030Q	PARTICIPANT	\N	EXCUSE	0
286008	285951	08060W	PARTICIPANT	\N	EXCUSE	0
286009	285951	08068F	PARTICIPANT	\N	EXCUSE	0
286010	285951	14255U	PARTICIPANT	\N	EXCUSE	0
286011	285951	19545Y	PARTICIPANT	\N	EXCUSE	0
286012	285951	11031D	PARTICIPANT	\N	EXCUSE	0
286013	285951	14079W	PARTICIPANT	\N	EXCUSE	0
286014	285951	14041T	PARTICIPANT	\N	EXCUSE	0
286015	285951	14034U	PARTICIPANT	\N	EXCUSE	0
286016	285951	14026U	PARTICIPANT	\N	EXCUSE	0
286017	285951	14061L	PARTICIPANT	\N	EXCUSE	0
286018	285951	11099A	PARTICIPANT	\N	EXCUSE	0
286020	285951	08015R	PARTICIPANT	\N	EXCUSE	0
286021	285951	14265W	PARTICIPANT	\N	EXCUSE	0
286022	285951	14253S	PARTICIPANT	\N	EXCUSE	0
286024	285951	08047A	PARTICIPANT	\N	EXCUSE	0
286033	286032	08038Y	PARTICIPANT	\N	PRESENT	0
294227	292933	14085U	PARTICIPANT	\N	PRESENT	0
294228	292933	19349W	PARTICIPANT	\N	PRESENT	0
294229	292933	08010L	PARTICIPANT	\N	PRESENT	0
294231	292933	14253S	PARTICIPANT	\N	PRESENT	0
294232	292933	19479G	PARTICIPANT	\N	PRESENT	0
294233	292933	19711U	PARTICIPANT	\N	PRESENT	0
294234	292933	08034U	PARTICIPANT	\N	PRESENT	0
294235	292933	08069G	PARTICIPANT	\N	PRESENT	0
294236	292933	19687N	PARTICIPANT	\N	PRESENT	0
294237	292933	12016W	PARTICIPANT	\N	PRESENT	0
294238	292933	08011M	PARTICIPANT	\N	PRESENT	0
294239	292933	14034U	PARTICIPANT	\N	PRESENT	0
294240	292933	14159V	PARTICIPANT	\N	PRESENT	0
294241	292933	14173T	PARTICIPANT	\N	PRESENT	0
294242	292933	04086Q	PARTICIPANT	\N	PRESENT	0
294243	292933	11040E	PARTICIPANT	\N	PRESENT	0
294244	292933	14083S	PARTICIPANT	\N	PRESENT	0
294245	292933	14199E	PARTICIPANT	\N	PRESENT	0
294246	292933	11012A	PARTICIPANT	\N	PRESENT	0
294247	292933	19741B	PARTICIPANT	\N	PRESENT	0
294248	292933	14121F	PARTICIPANT	\N	PRESENT	0
294249	292933	99004R	PARTICIPANT	\N	PRESENT	0
294250	292933	04061F	PARTICIPANT	\N	PRESENT	0
294251	292933	11074Q	PARTICIPANT	\N	EXCUSE	0
294252	292361	04040A	PARTICIPANT	\N	PRESENT	0
294254	293992	14201E	PARTICIPANT	\N	EXCUSE	0
294255	293992	14241N	PARTICIPANT	\N	EXCUSE	0
294256	293992	14061L	PARTICIPANT	\N	EXCUSE	0
294257	293992	08031R	PARTICIPANT	\N	EXCUSE	0
294258	293992	04018C	PARTICIPANT	\N	EXCUSE	0
294259	293993	14201E	PARTICIPANT	\N	EXCUSE	0
294260	293993	14241N	PARTICIPANT	\N	EXCUSE	0
294261	293993	14061L	PARTICIPANT	\N	EXCUSE	0
294262	293993	08031R	PARTICIPANT	\N	EXCUSE	0
294263	293993	04018C	PARTICIPANT	\N	EXCUSE	0
294265	293446	19515S	PARTICIPANT	\N	PRESENT	0
294266	293446	19565D	PARTICIPANT	\N	PRESENT	0
294267	293446	14357A	PARTICIPANT	\N	PRESENT	0
294268	293446	19441R	PARTICIPANT	\N	PRESENT	0
294269	293446	14081Q	PARTICIPANT	\N	PRESENT	0
294270	293446	19631V	PARTICIPANT	\N	PRESENT	0
294271	293446	08068F	PARTICIPANT	\N	PRESENT	0
294272	293446	04049K	PARTICIPANT	\N	PRESENT	0
294273	293446	08015R	PARTICIPANT	\N	PRESENT	0
294274	293446	14197C	PARTICIPANT	\N	PRESENT	0
294275	293446	19369B	PARTICIPANT	\N	PRESENT	0
294276	293446	19511N	PARTICIPANT	\N	PRESENT	0
294277	293446	19563B	PARTICIPANT	\N	PRESENT	0
294278	293446	14265W	PARTICIPANT	\N	PRESENT	0
294279	293446	14329V	PARTICIPANT	\N	PRESENT	0
294280	293446	19591F	PARTICIPANT	\N	PRESENT	0
294281	293446	14135M	PARTICIPANT	\N	PRESENT	0
294282	293446	14038Y	PARTICIPANT	\N	PRESENT	0
294283	293446	19467C	PARTICIPANT	\N	PRESENT	0
294284	293446	14187A	PARTICIPANT	\N	PRESENT	0
294285	293446	08038Y	PARTICIPANT	\N	PRESENT	0
294286	293446	08062Y	PARTICIPANT	\N	PRESENT	0
294287	293446	19301E	PARTICIPANT	\N	PRESENT	0
294288	293446	19695N	PARTICIPANT	\N	PRESENT	0
294289	293446	11090Q	PRESIDENT	0	PRESENT	0
294290	293446	14033T	PARTICIPANT	\N	PRESENT	0
294291	293446	14205J	PARTICIPANT	\N	PRESENT	0
294292	293446	04088S	PARTICIPANT	\N	PRESENT	0
294293	293446	04089T	PARTICIPANT	\N	PRESENT	0
294294	293446	14115H	PARTICIPANT	\N	PRESENT	0
294295	293446	11101A	PARTICIPANT	\N	PRESENT	0
294296	293446	19507S	PARTICIPANT	\N	PRESENT	0
294297	293446	19747H	PARTICIPANT	\N	PRESENT	0
294298	293446	14207L	PARTICIPANT	\N	PRESENT	0
294299	293446	04043D	PARTICIPANT	\N	PRESENT	0
294300	293446	04008A	PARTICIPANT	\N	PRESENT	0
294301	293446	17589D	PARTICIPANT	\N	PRESENT	0
294302	293446	19619A	PARTICIPANT	\N	PRESENT	0
294303	293446	14257W	PARTICIPANT	\N	PRESENT	0
294304	293446	08021P	PARTICIPANT	\N	EXCUSE	0
294305	293446	11081P	PARTICIPANT	\N	EXCUSE	0
294308	294307	04044E	PARTICIPANT	\N	PRESENT	0
294309	294307	19319Q	PARTICIPANT	\N	PRESENT	0
294310	294307	07034Q	PARTICIPANT	\N	PRESENT	0
294312	293442	11026G	PARTICIPANT	\N	PRESENT	0
294313	294307	14223L	PARTICIPANT	\N	PRESENT	0
294314	294307	19599P	PARTICIPANT	\N	PRESENT	0
294315	294307	14215L	PARTICIPANT	\N	PRESENT	0
294316	294307	19367Y	PARTICIPANT	\N	PRESENT	0
294317	294307	14217N	PARTICIPANT	\N	PRESENT	0
294318	294307	11103C	PARTICIPANT	\N	PRESENT	0
294319	294307	10006L	PARTICIPANT	\N	PRESENT	0
294320	294307	14147R	PARTICIPANT	\N	PRESENT	0
294321	294307	14030Q	PARTICIPANT	\N	PRESENT	0
294322	294307	11067R	PARTICIPANT	\N	PRESENT	0
294323	294307	08043V	PARTICIPANT	\N	PRESENT	0
294324	294307	14231L	PARTICIPANT	\N	PRESENT	0
294325	294307	08044W	PARTICIPANT	\N	PRESENT	0
294326	294307	19629C	PARTICIPANT	\N	PRESENT	0
294327	294307	14081Q	PARTICIPANT	\N	PRESENT	0
294328	294307	19731Y	PARTICIPANT	\N	PRESENT	0
294329	294307	07029T	PARTICIPANT	\N	PRESENT	0
294330	294307	19575F	PARTICIPANT	\N	PRESENT	0
294331	294307	19701S	PARTICIPANT	\N	PRESENT	0
294332	294307	14267Y	PARTICIPANT	\N	PRESENT	0
294333	294307	08061X	PARTICIPANT	\N	PRESENT	0
294334	294307	19543W	PARTICIPANT	\N	PRESENT	0
294335	294307	11031D	PARTICIPANT	\N	PRESENT	0
294336	294307	19723Y	PARTICIPANT	\N	PRESENT	0
294337	294307	05008E	PARTICIPANT	\N	PRESENT	0
294338	294307	14119M	PARTICIPANT	\N	PRESENT	0
294339	294307	19715Y	PARTICIPANT	\N	PRESENT	0
294340	294307	19649G	PARTICIPANT	\N	PRESENT	0
294341	294307	11045K	PARTICIPANT	\N	PRESENT	0
294342	294307	14109K	PARTICIPANT	\N	PRESENT	0
294343	294307	19585H	PARTICIPANT	\N	PRESENT	0
294344	294307	19695N	PARTICIPANT	\N	PRESENT	0
294345	294307	19735D	PARTICIPANT	\N	PRESENT	0
294347	294307	19447X	PARTICIPANT	\N	PRESENT	0
294348	294307	14031R	PARTICIPANT	\N	PRESENT	0
294349	294346	19253P	PARTICIPANT	\N	PRESENT	0
294350	294346	04038G	PARTICIPANT	\N	PRESENT	0
294351	294307	08045X	PARTICIPANT	\N	PRESENT	0
294352	294346	11041F	PARTICIPANT	\N	PRESENT	0
294353	294346	08043V	PARTICIPANT	\N	PRESENT	0
294354	294307	99004R	PARTICIPANT	\N	PRESENT	0
294355	294307	11104D	PARTICIPANT	\N	PRESENT	0
294356	294307	14065Q	PARTICIPANT	\N	PRESENT	0
294357	294307	14187A	PARTICIPANT	\N	PRESENT	0
294358	294307	14329V	PARTICIPANT	\N	PRESENT	0
294360	294307	19749K	PARTICIPANT	\N	PRESENT	0
294361	294307	14265W	PARTICIPANT	\N	PRESENT	0
294362	294359	08043V	PARTICIPANT	\N	PRESENT	0
294363	294307	19697Q	PARTICIPANT	\N	PRESENT	0
294364	294359	04038G	PARTICIPANT	\N	PRESENT	0
294365	294307	04047H	PARTICIPANT	\N	PRESENT	0
294366	294359	19253P	PARTICIPANT	\N	PRESENT	0
294367	294359	11070L	PRESIDENT	0	PRESENT	0
278755	263772	14069U	PARTICIPANT	\N	PRESENT	0
278908	278907	04018C	PARTICIPANT	\N	PRESENT	0
278909	278907	19643A	PARTICIPANT	\N	PRESENT	0
278910	278907	19749K	PARTICIPANT	\N	PRESENT	0
278911	278907	19611R	PARTICIPANT	\N	PRESENT	0
278912	278907	11083R	PARTICIPANT	\N	PRESENT	0
278913	278907	14109K	PARTICIPANT	\N	PRESENT	0
278917	278916	11053K	PARTICIPANT	\N	PRESENT	0
278918	278916	14159V	PARTICIPANT	\N	PRESENT	0
278919	278916	05012A	PARTICIPANT	\N	PRESENT	0
278921	275724	14030Q	PRESIDENT	0	PRESENT	0
278922	275724	19643A	PARTICIPANT	\N	PRESENT	0
278923	275724	08020N	PARTICIPANT	\N	PRESENT	0
278924	275724	08024S	PARTICIPANT	\N	PRESENT	0
278925	275724	11031D	PARTICIPANT	\N	PRESENT	0
278926	275724	19693L	PARTICIPANT	\N	PRESENT	0
278927	275724	14217N	PARTICIPANT	\N	PRESENT	0
278928	275724	19599P	PARTICIPANT	\N	EXCUSE	0
278929	275724	19715Y	PARTICIPANT	\N	PRESENT	0
278930	275724	19731Y	PARTICIPANT	\N	PRESENT	0
278931	275724	07029T	PARTICIPANT	\N	PRESENT	0
278933	275724	08017T	PARTICIPANT	\N	PRESENT	0
278934	275724	01043Q	PARTICIPANT	\N	EXCUSE	0
278935	275724	14235Q	PARTICIPANT	\N	EXCUSE	0
278936	275724	11045K	PARTICIPANT	\N	PRESENT	0
278937	275724	19749K	PARTICIPANT	\N	PRESENT	0
279422	278758	14051J	PARTICIPANT	\N	PRESENT	0
278753	263772	19549D	PARTICIPANT	\N	PRESENT	0
278754	263772	19591F	PARTICIPANT	\N	PRESENT	0
279423	278758	19387D	PARTICIPANT	\N	PRESENT	0
279424	278758	14237S	PARTICIPANT	\N	PRESENT	0
279425	278758	19347U	PARTICIPANT	\N	PRESENT	0
279426	278758	19685L	PARTICIPANT	\N	PRESENT	0
279427	278758	19701S	PARTICIPANT	\N	PRESENT	0
279428	278758	19681G	PARTICIPANT	\N	PRESENT	0
279429	278758	14219Q	PARTICIPANT	\N	PRESENT	0
279430	278758	14093U	PARTICIPANT	\N	PRESENT	0
279431	278758	19733B	PARTICIPANT	\N	PRESENT	0
279437	279251	14327T	PARTICIPANT	\N	PRESENT	0
279438	279251	11053K	PARTICIPANT	\N	PRESENT	0
279439	279251	19667J	PARTICIPANT	\N	PRESENT	0
279440	279251	11074Q	PRESIDENT	0	PRESENT	0
279441	279251	89017R	PARTICIPANT	\N	PRESENT	0
279442	279251	14225N	PARTICIPANT	\N	PRESENT	0
279443	279251	19671E	PARTICIPANT	\N	PRESENT	0
279444	279251	11110B	PARTICIPANT	\N	PRESENT	0
279445	279251	05012A	PARTICIPANT	\N	PRESENT	0
279446	279251	08068F	PARTICIPANT	\N	PRESENT	0
279447	279251	14085U	PARTICIPANT	\N	PRESENT	0
279448	279251	07004J	PARTICIPANT	\N	PRESENT	0
279449	279251	14253S	PARTICIPANT	\N	PRESENT	0
279450	279251	11048N	PARTICIPANT	\N	PRESENT	0
279451	279251	19711U	PARTICIPANT	\N	PRESENT	0
279452	279251	19531S	PARTICIPANT	\N	PRESENT	0
279453	279251	08069G	PARTICIPANT	\N	PRESENT	0
279454	279251	19687N	PARTICIPANT	\N	PRESENT	0
279455	279251	08011M	PARTICIPANT	\N	PRESENT	0
279456	279251	14034U	PARTICIPANT	\N	PRESENT	0
279457	279251	14159V	PARTICIPANT	\N	PRESENT	0
279458	279251	14173T	PARTICIPANT	\N	PRESENT	0
279459	279251	04086Q	PARTICIPANT	\N	PRESENT	0
279460	279251	19741B	PARTICIPANT	\N	PRESENT	0
279461	279251	99004R	PARTICIPANT	\N	PRESENT	0
279462	279251	04061F	PARTICIPANT	\N	PRESENT	0
279463	279251	04071H	PARTICIPANT	\N	PRESENT	0
279464	279251	07029T	PARTICIPANT	\N	EXCUSE	0
279465	279251	14331P	PARTICIPANT	\N	EXCUSE	0
279466	279251	11012A	PARTICIPANT	\N	EXCUSE	0
279467	279251	19689Q	PARTICIPANT	\N	EXCUSE	0
279468	279251	14121F	PARTICIPANT	\N	EXCUSE	0
279469	279251	08014Q	PARTICIPANT	\N	EXCUSE	0
279470	279251	88008L	PARTICIPANT	\N	EXCUSE	0
279471	279401	14053L	PARTICIPANT	\N	PRESENT	0
279472	279401	14065Q	PARTICIPANT	\N	PRESENT	0
279473	279401	11026G	PARTICIPANT	\N	PRESENT	0
279474	279401	07034Q	PRESIDENT	1	PRESENT	0
279475	279401	19581D	PARTICIPANT	\N	PRESENT	0
279476	279401	19585H	PARTICIPANT	\N	PRESENT	0
279477	279401	01028R	PARTICIPANT	\N	PRESENT	0
279478	279401	11033F	PARTICIPANT	\N	PRESENT	0
279479	279401	05008E	PRESIDENT	0	PRESENT	0
279480	279401	14231L	PARTICIPANT	\N	PRESENT	0
279481	279401	19447X	PARTICIPANT	\N	PRESENT	0
279482	279401	14179A	PARTICIPANT	\N	PRESENT	0
279483	279401	14215L	PARTICIPANT	\N	PRESENT	0
279484	279401	11049P	PARTICIPANT	\N	PRESENT	0
279485	279401	14259Y	PARTICIPANT	\N	PRESENT	0
279486	279401	17589D	PARTICIPANT	\N	PRESENT	0
279487	279401	14021P	PARTICIPANT	\N	PRESENT	0
279488	279401	14111D	PARTICIPANT	\N	PRESENT	0
279489	279401	95063L	PARTICIPANT	\N	PRESENT	0
279490	279401	14069U	PARTICIPANT	\N	PRESENT	0
279491	279401	14151M	PARTICIPANT	\N	PRESENT	0
279492	279401	19729F	PARTICIPANT	\N	EXCUSE	0
279493	279251	19369B	PARTICIPANT	\N	PRESENT	0
280181	273865	14079W	PARTICIPANT	\N	PRESENT	0
280182	273865	89017R	PARTICIPANT	\N	PRESENT	0
280183	273865	98023Q	PARTICIPANT	\N	PRESENT	0
280184	273865	07029T	PARTICIPANT	\N	PRESENT	0
280185	273865	19575F	PARTICIPANT	\N	PRESENT	0
280186	273865	19533U	PARTICIPANT	\N	PRESENT	0
280187	273865	14265W	PARTICIPANT	\N	PRESENT	0
280188	273865	18083K	PARTICIPANT	\N	PRESENT	0
280189	273865	11043H	PARTICIPANT	\N	PRESENT	0
280190	273865	19629C	PARTICIPANT	\N	PRESENT	0
280191	273865	14235Q	PARTICIPANT	\N	PRESENT	0
280192	273865	11048N	PARTICIPANT	\N	PRESENT	0
280193	273865	14199E	PARTICIPANT	\N	PRESENT	0
280256	273866	19683J	PARTICIPANT	\N	PRESENT	0
280257	273866	19503N	PARTICIPANT	\N	PRESENT	0
280258	273866	19543W	PARTICIPANT	\N	PRESENT	0
280259	273866	19415P	PARTICIPANT	\N	PRESENT	0
280260	273866	95030B	PARTICIPANT	\N	PRESENT	0
280261	273866	14135M	PARTICIPANT	\N	PRESENT	0
280262	273866	19533U	PARTICIPANT	\N	PRESENT	0
280263	273866	14029X	PARTICIPANT	\N	PRESENT	0
280264	273866	14115H	PARTICIPANT	\N	PRESENT	0
280265	273866	19703U	PARTICIPANT	\N	PRESENT	0
280266	273866	19349W	PARTICIPANT	\N	PRESENT	0
280267	273866	19447X	PARTICIPANT	\N	PRESENT	0
280268	273866	19383Y	PARTICIPANT	\N	PRESENT	0
280269	273866	19701S	PARTICIPANT	\N	PRESENT	0
280270	273866	05008E	PARTICIPANT	\N	PRESENT	0
280271	273866	17637T	PARTICIPANT	\N	PRESENT	0
280272	273866	02002K	PARTICIPANT	\N	PRESENT	0
280273	273866	19713W	PARTICIPANT	\N	PRESENT	0
280274	273866	19737F	PARTICIPANT	\N	PRESENT	0
280275	273866	19739H	PARTICIPANT	\N	PRESENT	0
280276	273866	08060W	PARTICIPANT	\N	PRESENT	0
280277	273866	19347U	PARTICIPANT	\N	PRESENT	0
280278	273866	14265W	PARTICIPANT	\N	PRESENT	0
280279	273866	19507S	PARTICIPANT	\N	PRESENT	0
280280	273866	19729F	PARTICIPANT	\N	PRESENT	0
280281	273866	18083K	PARTICIPANT	\N	PRESENT	0
280282	273866	19443T	PARTICIPANT	\N	PRESENT	0
280283	273866	19253P	PARTICIPANT	\N	PRESENT	0
280284	273866	19721W	PARTICIPANT	\N	PRESENT	0
280285	273866	19553Y	PARTICIPANT	\N	PRESENT	0
280286	273866	19479G	PARTICIPANT	\N	PRESENT	0
280287	273866	19691J	PARTICIPANT	\N	PRESENT	0
280288	273866	14073Q	PARTICIPANT	\N	PRESENT	0
280289	273866	14267Y	PARTICIPANT	\N	PRESENT	0
280290	273866	19747H	PARTICIPANT	\N	PRESENT	0
280291	273866	14197C	PARTICIPANT	\N	PRESENT	0
280292	273866	11056N	PARTICIPANT	\N	PRESENT	0
280293	279252	14327T	PARTICIPANT	\N	PRESENT	0
280294	279252	04071H	PARTICIPANT	\N	PRESENT	0
280295	279252	95041E	PARTICIPANT	\N	PRESENT	0
280296	279252	01048V	PARTICIPANT	\N	PRESENT	0
280297	279252	01057W	PARTICIPANT	\N	PRESENT	0
280298	279252	19667J	PARTICIPANT	\N	PRESENT	0
280299	279252	11074Q	PRESIDENT	0	PRESENT	0
280300	279252	89017R	PARTICIPANT	\N	PRESENT	0
280301	279252	19671E	PARTICIPANT	\N	PRESENT	0
280302	279252	14225N	PARTICIPANT	\N	PRESENT	0
280303	279252	07029T	PARTICIPANT	\N	PRESENT	0
280304	279252	14085U	PARTICIPANT	\N	PRESENT	0
280305	279252	07004J	PARTICIPANT	\N	PRESENT	0
280306	279252	19369B	PARTICIPANT	\N	PRESENT	0
280307	279252	14253S	PARTICIPANT	\N	PRESENT	0
280308	279252	19479G	PARTICIPANT	\N	PRESENT	0
280309	279252	11048N	PARTICIPANT	\N	PRESENT	0
280310	279252	19711U	PARTICIPANT	\N	PRESENT	0
280311	279252	08034U	PARTICIPANT	\N	PRESENT	0
280312	279252	19531S	PARTICIPANT	\N	PRESENT	0
280313	279252	19687N	PARTICIPANT	\N	PRESENT	0
280314	279252	08011M	PARTICIPANT	\N	PRESENT	0
280254	273866	14034U	PARTICIPANT	\N	PRESENT	0
280255	273866	11067R	PARTICIPANT	\N	PRESENT	0
272604	272603	19507S	PARTICIPANT	\N	PRESENT	0
272610	272603	14033T	PARTICIPANT	\N	PRESENT	0
272611	272603	14135M	PARTICIPANT	\N	PRESENT	0
272615	272614	19515S	PARTICIPANT	\N	PRESENT	0
272616	272614	19507S	PARTICIPANT	\N	PRESENT	0
272617	272614	14033T	PARTICIPANT	\N	PRESENT	0
272619	272614	19511N	PARTICIPANT	\N	PRESENT	0
272620	272614	04049K	PARTICIPANT	\N	PRESENT	0
272621	272614	14205J	PARTICIPANT	\N	PRESENT	0
272622	272614	19369B	PARTICIPANT	\N	PRESENT	0
272623	272614	14135M	PARTICIPANT	\N	PRESENT	0
272642	272641	14135M	PARTICIPANT	\N	PRESENT	0
272643	272641	14205J	PARTICIPANT	\N	PRESENT	0
272658	272657	14135M	PARTICIPANT	\N	PRESENT	0
272659	272657	14205J	PARTICIPANT	\N	PRESENT	0
272673	272665	19511N	PARTICIPANT	\N	PRESENT	0
272674	272665	11099A	PARTICIPANT	\N	PRESENT	0
272675	272665	14205J	PARTICIPANT	\N	PRESENT	0
272683	272682	14135M	PARTICIPANT	\N	PRESENT	0
272684	272682	14205J	PARTICIPANT	\N	PRESENT	0
272792	271077	08058D	PRESIDENT	0	PRESENT	0
272793	271077	19721W	PARTICIPANT	\N	PRESENT	0
272794	271077	19251M	PARTICIPANT	\N	PRESENT	0
272795	271077	11049P	PARTICIPANT	\N	PRESENT	0
272796	271077	14097Y	PARTICIPANT	\N	PRESENT	0
272797	271077	08034U	PARTICIPANT	\N	PRESENT	0
272798	271077	19729F	PARTICIPANT	\N	PRESENT	0
272799	271077	19581D	PARTICIPANT	\N	PRESENT	0
272800	271077	14205J	PARTICIPANT	\N	PRESENT	0
272801	271077	19443T	PARTICIPANT	\N	PRESENT	0
272802	271077	19703U	PARTICIPANT	\N	PRESENT	0
284422	281722	19569H	PARTICIPANT	\N	PRESENT	0
284423	281722	11045K	PARTICIPANT	\N	PRESENT	0
284425	281723	14239U	PARTICIPANT	\N	PRESENT	0
284426	281723	14261S	PARTICIPANT	\N	PRESENT	0
284427	281723	19717B	PARTICIPANT	\N	PRESENT	0
284428	281723	19575F	PARTICIPANT	\N	PRESENT	0
284429	281723	19367Y	PARTICIPANT	\N	PRESENT	0
284430	281723	19415P	PARTICIPANT	\N	PRESENT	0
284431	281723	11103C	PARTICIPANT	\N	PRESENT	0
284432	281723	14195A	PARTICIPANT	\N	PRESENT	0
289641	273919	11070L	PARTICIPANT	\N	PRESENT	0
284434	281723	08052W	PARTICIPANT	\N	PRESENT	0
284435	281723	19663E	PARTICIPANT	\N	EXCUSE	0
284436	281723	98024R	PARTICIPANT	\N	PRESENT	0
284437	281723	10006L	PARTICIPANT	\N	PRESENT	0
284438	281723	14217N	PARTICIPANT	\N	PRESENT	0
289642	273919	04047H	PARTICIPANT	\N	PRESENT	0
289643	273919	05008E	PARTICIPANT	\N	PRESENT	0
284441	281723	14281W	PARTICIPANT	\N	PRESENT	0
284442	281723	14087W	PARTICIPANT	\N	PRESENT	0
284443	281723	19521Q	PARTICIPANT	\N	PRESENT	0
289644	273919	19685L	PARTICIPANT	\N	PRESENT	0
284445	281723	08048B	PARTICIPANT	\N	EXCUSE	0
284446	281723	08041T	PARTICIPANT	\N	EXCUSE	0
284447	281723	19727D	PARTICIPANT	\N	PRESENT	0
284448	281723	14026U	PARTICIPANT	\N	PRESENT	0
284449	281723	19691J	PARTICIPANT	\N	PRESENT	0
284450	281723	19553Y	PARTICIPANT	\N	PRESENT	0
284451	281723	19569H	PARTICIPANT	\N	PRESENT	0
284452	281723	14213J	PARTICIPANT	\N	PRESENT	0
284453	281723	19715Y	PARTICIPANT	\N	PRESENT	0
284454	281723	19683J	PARTICIPANT	\N	PRESENT	0
284455	281723	19723Y	PARTICIPANT	\N	PRESENT	0
284456	281723	19697Q	PARTICIPANT	\N	PRESENT	0
284457	281723	11077T	PARTICIPANT	\N	PRESENT	0
284458	281723	17779H	PARTICIPANT	\N	PRESENT	0
284459	281723	19657G	PARTICIPANT	\N	PRESENT	0
284460	281723	11067R	PARTICIPANT	\N	PRESENT	0
284461	281723	14223L	PARTICIPANT	\N	PRESENT	0
284462	281723	04092N	PRESIDENT	0	PRESENT	0
289645	273919	11072N	PARTICIPANT	\N	PRESENT	0
284464	281723	14119M	PARTICIPANT	\N	PRESENT	0
284465	281723	14071N	PARTICIPANT	\N	PRESENT	0
284466	281723	19679N	PARTICIPANT	\N	PRESENT	0
284467	281723	11045K	PARTICIPANT	\N	PRESENT	0
284468	281723	11097X	PARTICIPANT	\N	PRESENT	0
284469	281723	04045F	PARTICIPANT	\N	PRESENT	0
284470	281723	19703U	PARTICIPANT	\N	PRESENT	0
289646	273919	19329S	PARTICIPANT	\N	PRESENT	0
284472	281723	14227Q	PARTICIPANT	\N	PRESENT	0
284473	281723	19527W	PARTICIPANT	\N	PRESENT	0
289647	273919	19669L	PARTICIPANT	\N	PRESENT	0
301846	301832	11026G	PARTICIPANT	\N	PRESENT	0
289648	273919	11027H	PARTICIPANT	\N	PRESENT	0
289649	273919	11031D	PARTICIPANT	\N	PRESENT	0
289650	273919	19673G	PARTICIPANT	\N	PRESENT	0
289651	273919	14029X	PARTICIPANT	\N	PRESENT	0
289652	273919	07029T	PARTICIPANT	\N	PRESENT	0
289653	273919	14089Y	PARTICIPANT	\N	PRESENT	0
289654	273919	19671E	PARTICIPANT	\N	PRESENT	0
289655	273919	11026G	PARTICIPANT	\N	PRESENT	0
289656	273919	19711U	PARTICIPANT	\N	PRESENT	0
289657	273919	08020N	PARTICIPANT	\N	PRESENT	0
289658	273919	14229S	PARTICIPANT	\N	PRESENT	0
289659	273919	04085P	PARTICIPANT	\N	PRESENT	0
289660	273919	14281W	PARTICIPANT	\N	PRESENT	0
289661	273919	11045K	PARTICIPANT	\N	PRESENT	0
289662	273919	19591F	PARTICIPANT	\N	PRESENT	0
289663	273919	11109J	PARTICIPANT	\N	PRESENT	0
289664	273919	14065Q	PARTICIPANT	\N	PRESENT	0
289665	273919	14039A	PARTICIPANT	\N	PRESENT	0
289666	273919	11033F	PARTICIPANT	\N	PRESENT	0
289667	273919	19695N	PARTICIPANT	\N	PRESENT	0
289668	273919	11064N	PARTICIPANT	\N	PRESENT	0
289669	273919	14042U	PARTICIPANT	\N	PRESENT	0
289670	273919	08010L	PARTICIPANT	\N	PRESENT	0
289671	273919	14069U	PARTICIPANT	\N	PRESENT	0
289672	273919	14053L	PARTICIPANT	\N	PRESENT	0
289673	273919	04018C	PARTICIPANT	\N	PRESENT	0
289674	273919	19701S	PARTICIPANT	\N	PRESENT	0
289675	273919	14055N	PARTICIPANT	\N	PRESENT	0
289676	273919	14030Q	PARTICIPANT	\N	PRESENT	0
289677	273919	19467C	PARTICIPANT	\N	PRESENT	0
289678	273919	14033T	PARTICIPANT	\N	PRESENT	0
289679	273919	19649G	PARTICIPANT	\N	PRESENT	0
289680	273919	19413M	PARTICIPANT	\N	PRESENT	0
289681	273919	19593H	PARTICIPANT	\N	PRESENT	0
289682	273919	19758L	PARTICIPANT	\N	PRESENT	0
289683	273919	95063L	PARTICIPANT	\N	PRESENT	0
289684	273919	19693L	PARTICIPANT	\N	PRESENT	0
289685	273919	14261S	PARTICIPANT	\N	PRESENT	0
289686	273919	19253P	PARTICIPANT	\N	PRESENT	0
289687	273919	19629C	PARTICIPANT	\N	PRESENT	0
289688	273919	19663E	PARTICIPANT	\N	PRESENT	0
289689	273919	08034U	PARTICIPANT	\N	PRESENT	0
289690	273919	14021P	PARTICIPANT	\N	PRESENT	0
289691	273919	19585H	PARTICIPANT	\N	PRESENT	0
289692	273919	14193X	PARTICIPANT	\N	PRESENT	0
289693	273919	19573D	PARTICIPANT	\N	PRESENT	0
289694	273919	19667J	PARTICIPANT	\N	PRESENT	0
289695	273919	04059M	PARTICIPANT	\N	PRESENT	0
289696	273919	04088S	PARTICIPANT	\N	PRESENT	0
289697	273919	19447X	PARTICIPANT	\N	PRESENT	0
289698	273919	19647E	PARTICIPANT	\N	PRESENT	0
289699	273919	11012A	PARTICIPANT	\N	PRESENT	0
289700	273919	19507S	PARTICIPANT	\N	PRESENT	0
289701	273919	14157T	PARTICIPANT	\N	PRESENT	0
289702	273919	04035D	PARTICIPANT	\N	PRESENT	0
289703	273919	14151M	PARTICIPANT	\N	PRESENT	0
289704	273919	19643A	PARTICIPANT	\N	PRESENT	0
289705	273919	04043D	PARTICIPANT	\N	PRESENT	0
289706	273919	11048N	PARTICIPANT	\N	PRESENT	0
289707	273919	19651A	PARTICIPANT	\N	PRESENT	0
289708	273919	19683J	PARTICIPANT	\N	PRESENT	0
289709	273919	01028R	PARTICIPANT	\N	PRESENT	0
289710	273919	19703U	PARTICIPANT	\N	PRESENT	0
289711	273919	19689Q	PARTICIPANT	\N	PRESENT	0
289712	273919	08017T	PARTICIPANT	\N	PRESENT	0
289713	273919	19717B	PARTICIPANT	\N	PRESENT	0
289714	273919	19737F	PARTICIPANT	\N	PRESENT	0
289715	273919	99004R	PARTICIPANT	\N	PRESENT	0
289716	273919	14071N	PARTICIPANT	\N	PRESENT	0
289717	273919	08073C	PARTICIPANT	\N	PRESENT	0
289718	273919	19347U	PARTICIPANT	\N	PRESENT	0
289719	273919	04044E	PARTICIPANT	\N	PRESENT	0
289720	273919	14235Q	PARTICIPANT	\N	PRESENT	0
289721	273919	19531S	PARTICIPANT	\N	PRESENT	0
289722	273919	04034C	PARTICIPANT	\N	PRESENT	0
289723	273919	14093U	PARTICIPANT	\N	PRESENT	0
289724	273919	19749K	PARTICIPANT	\N	PRESENT	0
289725	273919	14001X	PARTICIPANT	\N	PRESENT	0
289726	273919	19611R	PARTICIPANT	\N	PRESENT	0
301847	301832	14041T	PARTICIPANT	\N	PRESENT	0
301848	301832	14147R	PARTICIPANT	\N	PRESENT	0
301849	301832	04038G	PARTICIPANT	\N	PRESENT	0
301850	301832	19585H	PARTICIPANT	\N	PRESENT	0
301851	301832	04047H	PARTICIPANT	\N	PRESENT	0
301852	301832	11033F	PARTICIPANT	\N	PRESENT	0
278901	278895	11074Q	PARTICIPANT	\N	PRESENT	0
284103	281772	14327T	PARTICIPANT	\N	PRESENT	0
284081	281772	14277B	PARTICIPANT	\N	PRESENT	0
284082	281772	14225N	PRESIDENT	0	PRESENT	0
284083	281772	14173T	PARTICIPANT	\N	PRESENT	0
284084	281772	14331P	PARTICIPANT	\N	PRESENT	0
284085	281772	11048N	PARTICIPANT	\N	PRESENT	0
284086	281772	19531S	PARTICIPANT	\N	PRESENT	0
284087	281772	19687N	PARTICIPANT	\N	PRESENT	0
284088	281772	11053K	PARTICIPANT	\N	PRESENT	0
284089	281772	19667J	PARTICIPANT	\N	PRESENT	0
284090	281772	89017R	PARTICIPANT	\N	PRESENT	0
284091	281772	08011M	PARTICIPANT	\N	PRESENT	0
284092	281772	19671E	PARTICIPANT	\N	PRESENT	0
284093	281772	14159V	PARTICIPANT	\N	PRESENT	0
284094	281772	11110B	PARTICIPANT	\N	PRESENT	0
284095	281772	04086Q	PARTICIPANT	\N	PRESENT	0
284096	281772	11012A	PARTICIPANT	\N	PRESENT	0
284097	281772	14085U	PARTICIPANT	\N	PRESENT	0
284098	281772	07004J	PARTICIPANT	\N	PRESENT	0
284099	281772	14121F	PARTICIPANT	\N	PRESENT	0
284100	281772	14253S	PARTICIPANT	\N	PRESENT	0
284101	281772	11074Q	PARTICIPANT	\N	EXCUSE	0
284104	281772	01057W	PARTICIPANT	\N	PRESENT	0
284105	281772	88008L	PARTICIPANT	\N	PRESENT	0
284106	281772	07029T	PARTICIPANT	\N	PRESENT	0
284107	281772	05012A	PARTICIPANT	\N	PRESENT	0
284108	281772	19349W	PARTICIPANT	\N	PRESENT	0
284109	281772	19479G	PARTICIPANT	\N	PRESENT	0
284110	281772	14083S	PARTICIPANT	\N	PRESENT	0
284111	281772	08073C	PARTICIPANT	\N	PRESENT	0
284112	281772	19741B	PARTICIPANT	\N	PRESENT	0
284113	281772	19711U	PARTICIPANT	\N	PRESENT	0
284114	281772	19689Q	PARTICIPANT	\N	PRESENT	0
284115	281772	99004R	PARTICIPANT	\N	PRESENT	0
284116	281772	08014Q	PARTICIPANT	\N	EXCUSE	0
284117	282586	19333N	PARTICIPANT	\N	PRESENT	0
284118	282586	19383Y	PARTICIPANT	\N	PRESENT	0
284119	282586	14038Y	PARTICIPANT	\N	PRESENT	0
284120	282586	17583W	PARTICIPANT	\N	PRESENT	0
284121	282586	14031R	PARTICIPANT	\N	PRESENT	0
284122	282586	19713W	PARTICIPANT	\N	PRESENT	0
284123	282586	19549D	PARTICIPANT	\N	PRESENT	0
284124	282586	95062K	PARTICIPANT	\N	PRESENT	0
284125	282586	19599P	PARTICIPANT	\N	PRESENT	0
284126	282586	19637C	PARTICIPANT	\N	PRESENT	0
284127	282586	14169X	PARTICIPANT	\N	PRESENT	0
284128	282586	18083K	PARTICIPANT	\N	PRESENT	0
284129	282586	15447F	PARTICIPANT	\N	PRESENT	0
284130	282586	14051J	PARTICIPANT	\N	PRESENT	0
284131	282586	19733B	PARTICIPANT	\N	PRESENT	0
284132	282586	08009T	PRESIDENT	0	PRESENT	0
284133	282586	19347U	PARTICIPANT	\N	PRESENT	0
284134	282586	19503N	PARTICIPANT	\N	PRESENT	0
284135	282586	19739H	PARTICIPANT	\N	PRESENT	0
284136	282586	14157T	PARTICIPANT	\N	PRESENT	0
284137	282586	11065P	PARTICIPANT	\N	PRESENT	0
284138	282586	17637T	PARTICIPANT	\N	PRESENT	0
284139	282586	19701S	PARTICIPANT	\N	PRESENT	0
284140	281772	08010L	PARTICIPANT	\N	PRESENT	0
284141	281772	19651A	PARTICIPANT	\N	PRESENT	0
284142	281772	08034U	PARTICIPANT	\N	PRESENT	0
284143	281772	04061F	PARTICIPANT	\N	PRESENT	0
284144	282586	19525U	PARTICIPANT	\N	PRESENT	0
284145	282586	08060W	PARTICIPANT	\N	PRESENT	0
284146	282586	08024S	PARTICIPANT	\N	PRESENT	0
284147	281772	01048V	PARTICIPANT	\N	PRESENT	0
284148	281772	19647E	PARTICIPANT	\N	PRESENT	0
284149	281772	11040E	PARTICIPANT	\N	PRESENT	0
284170	281772	08069G	PARTICIPANT	\N	PRESENT	0
284171	282586	19551W	PARTICIPANT	\N	PRESENT	0
284172	281772	08068F	PARTICIPANT	\N	PRESENT	0
284173	282692	19515S	PARTICIPANT	\N	PRESENT	0
284174	282692	19565D	PARTICIPANT	\N	PRESENT	0
284175	282692	14357A	PARTICIPANT	\N	PRESENT	0
284176	282692	19441R	PARTICIPANT	\N	PRESENT	0
284177	282692	19413M	PARTICIPANT	\N	PRESENT	0
284178	282692	14081Q	PARTICIPANT	\N	PRESENT	0
284179	282692	14221J	PARTICIPANT	\N	PRESENT	0
284180	282692	80013X	PARTICIPANT	\N	PRESENT	0
284181	282692	08021P	PARTICIPANT	\N	PRESENT	0
284182	282692	11099A	PARTICIPANT	\N	PRESENT	0
284183	282692	04049K	PARTICIPANT	\N	PRESENT	0
284184	282692	19705W	PARTICIPANT	\N	PRESENT	0
284185	282692	19707Y	PARTICIPANT	\N	PRESENT	0
284186	282692	08015R	PARTICIPANT	\N	PRESENT	0
284187	282692	14197C	PARTICIPANT	\N	PRESENT	0
284188	282692	19369B	PARTICIPANT	\N	PRESENT	0
284189	282692	19511N	PARTICIPANT	\N	PRESENT	0
284190	282692	19563B	PARTICIPANT	\N	PRESENT	0
284191	282692	08028W	PARTICIPANT	\N	PRESENT	0
284192	282692	14265W	PARTICIPANT	\N	PRESENT	0
284193	282692	14329V	PARTICIPANT	\N	PRESENT	0
284194	282692	19591F	PARTICIPANT	\N	PRESENT	0
284195	282692	14135M	PARTICIPANT	\N	PRESENT	0
284196	282692	19467C	PARTICIPANT	\N	PRESENT	0
284197	282692	14187A	PARTICIPANT	\N	PRESENT	0
284198	282692	08062Y	PARTICIPANT	\N	PRESENT	0
284199	282692	19695N	PARTICIPANT	\N	PRESENT	0
284200	282692	01025N	PARTICIPANT	\N	PRESENT	0
284201	282692	11090Q	PRESIDENT	0	PRESENT	0
284202	282692	14033T	PARTICIPANT	\N	PRESENT	0
284203	282692	19269X	PARTICIPANT	\N	PRESENT	0
284204	282692	14205J	PARTICIPANT	\N	PRESENT	0
284205	282692	11056N	PARTICIPANT	\N	PRESENT	0
284206	282692	04088S	PARTICIPANT	\N	PRESENT	0
284207	282692	04089T	PARTICIPANT	\N	PRESENT	0
284208	282692	14115H	PARTICIPANT	\N	PRESENT	0
284209	282692	19507S	PARTICIPANT	\N	PRESENT	0
284210	282692	14207L	PARTICIPANT	\N	PRESENT	0
284211	282692	19747H	PARTICIPANT	\N	PRESENT	0
284212	282692	04043D	PARTICIPANT	\N	PRESENT	0
284213	282692	19619A	PARTICIPANT	\N	PRESENT	0
284214	282692	17589D	PARTICIPANT	\N	PRESENT	0
284215	282692	14257W	PARTICIPANT	\N	PRESENT	0
284226	284102	01060R	PARTICIPANT	\N	PRESENT	0
284227	284102	14001X	PARTICIPANT	\N	PRESENT	0
284228	284102	19543W	PARTICIPANT	\N	PRESENT	0
284229	284102	04044E	PARTICIPANT	\N	PRESENT	0
284230	284102	19581D	PARTICIPANT	\N	PRESENT	0
284231	284102	19585H	PARTICIPANT	\N	PRESENT	0
284232	284102	04047H	PARTICIPANT	\N	PRESENT	0
284233	284102	19673G	PARTICIPANT	\N	PRESENT	0
284234	284102	01028R	PARTICIPANT	\N	PRESENT	0
284235	284102	05008E	PRESIDENT	0	PRESENT	0
284236	284102	19447X	PARTICIPANT	\N	PRESENT	0
284237	284102	14231L	PARTICIPANT	\N	PRESENT	0
284238	284102	19489J	PARTICIPANT	\N	PRESENT	0
284239	284102	14275Y	PARTICIPANT	\N	PRESENT	0
284240	284102	14041T	PARTICIPANT	\N	PRESENT	0
284241	284102	14147R	PARTICIPANT	\N	PRESENT	0
284242	284102	14179A	PARTICIPANT	\N	PRESENT	0
284243	284102	14151M	PARTICIPANT	\N	PRESENT	0
284244	284102	14215L	PARTICIPANT	\N	PRESENT	0
284245	284102	14259Y	PARTICIPANT	\N	PRESENT	0
284246	284102	14053L	PARTICIPANT	\N	PRESENT	0
284247	284102	98035U	PARTICIPANT	\N	PRESENT	0
284248	284102	14111D	PARTICIPANT	\N	PRESENT	0
284249	284102	14065Q	PARTICIPANT	\N	PRESENT	0
284250	284102	19649G	PARTICIPANT	\N	PRESENT	0
284251	284102	07034Q	PARTICIPANT	\N	PRESENT	0
284252	284102	08045X	PARTICIPANT	\N	PRESENT	0
284253	284102	10015M	PARTICIPANT	\N	PRESENT	0
284254	284102	19253P	PARTICIPANT	\N	PRESENT	0
284255	284102	04038G	PARTICIPANT	\N	PRESENT	0
284256	284102	11033F	PARTICIPANT	\N	PRESENT	0
284257	284102	19725B	PARTICIPANT	\N	PRESENT	0
284258	284102	14089Y	PARTICIPANT	\N	PRESENT	0
284259	284102	19729F	PARTICIPANT	\N	PRESENT	0
284260	284102	19629C	PARTICIPANT	\N	PRESENT	0
284261	284102	14069U	PARTICIPANT	\N	PRESENT	0
284262	284102	14021P	PARTICIPANT	\N	PRESENT	0
284263	284102	19719D	PARTICIPANT	\N	EXCUSE	0
284264	284102	04008A	PARTICIPANT	\N	PRESENT	0
284265	281722	08048B	PARTICIPANT	\N	EXCUSE	0
284266	281722	19663E	PARTICIPANT	\N	EXCUSE	0
284267	281722	19715Y	PARTICIPANT	\N	PRESENT	0
284268	281722	08041T	PARTICIPANT	\N	EXCUSE	0
284269	284102	95063L	PARTICIPANT	\N	PRESENT	0
284307	282586	05012A	PARTICIPANT	\N	PRESENT	0
284308	281773	11048N	PARTICIPANT	\N	PRESENT	0
284309	281722	19697Q	PARTICIPANT	\N	PRESENT	0
284310	281722	11077T	PARTICIPANT	\N	PRESENT	0
284311	281722	04092N	PRESIDENT	0	PRESENT	0
284312	281722	19415P	PARTICIPANT	\N	PRESENT	0
284313	281722	17779H	PARTICIPANT	\N	PRESENT	0
284314	281722	14239U	PARTICIPANT	\N	PRESENT	0
294368	294359	14179A	PARTICIPANT	\N	PRESENT	0
294369	294359	04097T	PARTICIPANT	\N	PRESENT	0
294370	294359	95062K	PARTICIPANT	\N	PRESENT	0
294371	294359	11041F	PARTICIPANT	\N	PRESENT	0
294372	294307	19349W	PARTICIPANT	\N	PRESENT	0
294373	294307	14111D	PARTICIPANT	\N	PRESENT	0
294374	294359	12016W	PARTICIPANT	\N	PRESENT	0
294375	294307	98050T	PARTICIPANT	\N	PRESENT	0
294376	294307	14159V	PARTICIPANT	\N	PRESENT	0
294377	294307	14107H	PARTICIPANT	\N	PRESENT	0
294378	294307	11033F	PARTICIPANT	\N	PRESENT	0
294379	294307	14331P	PARTICIPANT	\N	PRESENT	0
294380	294307	08024S	PARTICIPANT	\N	PRESENT	0
294381	294307	08017T	PARTICIPANT	\N	PRESENT	0
294382	294307	14249W	PARTICIPANT	\N	PRESENT	0
294383	294307	14021P	PARTICIPANT	\N	PRESENT	0
294384	292361	01058X	PARTICIPANT	\N	PRESENT	0
294385	294307	14257W	PARTICIPANT	\N	PRESENT	0
294386	292361	14255U	PARTICIPANT	\N	EXCUSE	0
294387	292361	14097Y	PARTICIPANT	\N	EXCUSE	0
294388	292361	11054L	PARTICIPANT	\N	EXCUSE	0
294389	294307	19693L	PARTICIPANT	\N	PRESENT	0
294390	292361	08049C	PARTICIPANT	\N	EXCUSE	0
294391	294307	14169X	PARTICIPANT	\N	PRESENT	0
294392	294307	11066Q	PARTICIPANT	\N	PRESENT	0
294393	294307	14063N	PARTICIPANT	\N	PRESENT	0
294394	294307	19549D	PARTICIPANT	\N	PRESENT	0
294435	294307	14173T	PARTICIPANT	\N	PRESENT	0
294441	294307	19253P	PARTICIPANT	\N	PRESENT	0
294442	294307	01024M	PARTICIPANT	\N	PRESENT	0
294443	294307	19515S	PARTICIPANT	\N	PRESENT	0
294444	294307	19301E	PARTICIPANT	\N	PRESENT	0
294445	293444	19631V	PARTICIPANT	\N	PRESENT	0
294446	293444	19515S	PARTICIPANT	\N	PRESENT	0
294447	293444	11081P	PARTICIPANT	\N	EXCUSE	0
294448	293444	14115H	PARTICIPANT	\N	PRESENT	0
294449	294307	19583F	PARTICIPANT	\N	PRESENT	0
294450	293444	19747H	PARTICIPANT	\N	PRESENT	0
294451	294307	14197C	PARTICIPANT	\N	PRESENT	0
294452	293444	14207L	PARTICIPANT	\N	PRESENT	0
294453	293444	11101A	PARTICIPANT	\N	PRESENT	0
294454	293444	19467C	PARTICIPANT	\N	PRESENT	0
294455	293444	11056N	PARTICIPANT	\N	PRESENT	0
294456	293444	14357A	PARTICIPANT	\N	EXCUSE	0
294457	293444	08038Y	PARTICIPANT	\N	PRESENT	0
294458	293444	04089T	PARTICIPANT	\N	PRESENT	0
294459	293444	19507S	PARTICIPANT	\N	PRESENT	0
294460	293444	14187A	PARTICIPANT	\N	PRESENT	0
294461	293444	01025N	PARTICIPANT	\N	PRESENT	0
294462	293444	19695N	PARTICIPANT	\N	PRESENT	0
294463	293444	19565D	PARTICIPANT	\N	PRESENT	0
294464	293444	14033T	PARTICIPANT	\N	PRESENT	0
294465	293444	14081Q	PARTICIPANT	\N	PRESENT	0
294466	293444	19591F	PARTICIPANT	\N	PRESENT	0
294467	293444	19511N	PARTICIPANT	\N	PRESENT	0
294468	293444	11099A	PARTICIPANT	\N	PRESENT	0
294469	293444	04049K	PARTICIPANT	\N	PRESENT	0
294470	294307	14038Y	PARTICIPANT	\N	PRESENT	0
294471	293444	08015R	PARTICIPANT	\N	PRESENT	0
294472	293444	01043Q	PARTICIPANT	\N	PRESENT	0
294473	293444	14205J	PARTICIPANT	\N	PRESENT	0
294474	293444	19441R	PARTICIPANT	\N	PRESENT	0
294475	293444	08019V	PARTICIPANT	\N	PRESENT	0
294476	293444	08062Y	PARTICIPANT	\N	PRESENT	0
294477	293444	19563B	PARTICIPANT	\N	PRESENT	0
294478	293444	19369B	PARTICIPANT	\N	PRESENT	0
294479	293444	14257W	PARTICIPANT	\N	PRESENT	0
294480	293444	14265W	PARTICIPANT	\N	PRESENT	0
294481	294307	19689Q	PARTICIPANT	\N	PRESENT	0
294482	293444	08021P	PARTICIPANT	\N	EXCUSE	0
294483	293444	04088S	PARTICIPANT	\N	PRESENT	0
294484	293444	11090Q	PRESIDENT	0	PRESENT	0
294485	293444	04043D	PARTICIPANT	\N	PRESENT	0
294486	293444	14135M	PARTICIPANT	\N	PRESENT	0
294487	293444	19269X	PARTICIPANT	\N	PRESENT	0
294488	293444	19705W	PARTICIPANT	\N	PRESENT	0
294489	293444	19619A	PARTICIPANT	\N	PRESENT	0
294490	293444	19301E	PARTICIPANT	\N	PRESENT	0
294491	293444	19413M	PARTICIPANT	\N	PRESENT	0
294492	294307	88008L	PARTICIPANT	\N	PRESENT	0
294493	294307	12016W	PARTICIPANT	\N	PRESENT	0
294496	294307	14239U	PARTICIPANT	\N	PRESENT	0
294497	294495	08056B	PARTICIPANT	\N	PRESENT	0
294498	294495	14199E	PARTICIPANT	\N	PRESENT	0
294499	294495	19611R	PARTICIPANT	\N	PRESENT	0
294500	294495	19421M	PARTICIPANT	\N	PRESENT	0
294501	294495	98022P	PARTICIPANT	\N	PRESENT	0
294502	294495	98050T	PARTICIPANT	\N	PRESENT	0
294503	294495	08010L	PARTICIPANT	\N	PRESENT	0
294504	294495	19669L	PARTICIPANT	\N	PRESENT	0
294505	294495	19673G	PARTICIPANT	\N	PRESENT	0
294506	294495	98029W	PRESIDENT	0	PRESENT	0
294507	294495	14089Y	PARTICIPANT	\N	PRESENT	0
294508	294495	19575F	PARTICIPANT	\N	PRESENT	0
294509	294307	04085P	PARTICIPANT	\N	PRESENT	0
294510	294307	14042U	PARTICIPANT	\N	PRESENT	0
294511	294307	19737F	PARTICIPANT	\N	PRESENT	0
294512	294307	19581D	PARTICIPANT	\N	PRESENT	0
294513	294307	19747H	PARTICIPANT	\N	PRESENT	0
294514	294307	97011G	PARTICIPANT	\N	PRESENT	0
294515	294307	08035V	PARTICIPANT	\N	PRESENT	0
294516	294307	19631V	PARTICIPANT	\N	PRESENT	0
294517	294307	95030B	PARTICIPANT	\N	PRESENT	0
294518	294307	19503N	PARTICIPANT	\N	PRESENT	0
294520	294519	08043V	PARTICIPANT	\N	PRESENT	0
294521	294307	19577H	PARTICIPANT	\N	PRESENT	0
294522	294519	14109K	PARTICIPANT	\N	PRESENT	0
294523	294519	19611R	PARTICIPANT	\N	PRESENT	0
294524	294307	19657G	PARTICIPANT	\N	PRESENT	0
294525	294519	19749K	PARTICIPANT	\N	PRESENT	0
294526	294519	11083R	PARTICIPANT	\N	PRESENT	0
294528	294527	08043V	PARTICIPANT	\N	PRESENT	0
294529	294527	04018C	PARTICIPANT	\N	PRESENT	0
294530	293444	08039A	PARTICIPANT	\N	PRESENT	0
294531	293444	14038Y	PARTICIPANT	\N	PRESENT	0
294532	293444	04008A	PARTICIPANT	\N	PRESENT	0
294534	294533	19399H	PARTICIPANT	\N	PRESENT	0
294535	294533	19735D	PARTICIPANT	\N	PRESENT	0
294536	294533	19593H	PARTICIPANT	\N	PRESENT	0
294537	294533	14229S	PARTICIPANT	\N	PRESENT	0
294538	293445	19631V	PARTICIPANT	\N	PRESENT	0
294539	293445	11081P	PARTICIPANT	\N	EXCUSE	0
294540	293445	19515S	PARTICIPANT	\N	PRESENT	0
294541	293445	19707Y	PARTICIPANT	\N	PRESENT	0
294542	293445	14115H	PARTICIPANT	\N	PRESENT	0
294543	293445	19747H	PARTICIPANT	\N	PRESENT	0
294544	293445	14207L	PARTICIPANT	\N	PRESENT	0
294545	293445	11101A	PARTICIPANT	\N	PRESENT	0
294546	293445	19467C	PARTICIPANT	\N	PRESENT	0
294547	293445	14357A	PARTICIPANT	\N	PRESENT	0
294548	293445	14187A	PARTICIPANT	\N	PRESENT	0
294549	293445	19565D	PARTICIPANT	\N	PRESENT	0
294550	293445	14081Q	PARTICIPANT	\N	PRESENT	0
294551	293445	19591F	PARTICIPANT	\N	PRESENT	0
294552	293445	14033T	PARTICIPANT	\N	PRESENT	0
294553	293445	19511N	PARTICIPANT	\N	PRESENT	0
294554	294495	11080N	PARTICIPANT	\N	PRESENT	0
294555	294495	11026G	PARTICIPANT	\N	PRESENT	0
294556	294495	02002K	PARTICIPANT	\N	PRESENT	0
294557	293445	08038Y	PARTICIPANT	\N	PRESENT	0
294558	293445	11090Q	PRESIDENT	0	PRESENT	0
294559	293445	19619A	PARTICIPANT	\N	PRESENT	0
294560	293445	19705W	PARTICIPANT	\N	PRESENT	0
294561	293445	04088S	PARTICIPANT	\N	PRESENT	0
294562	293445	08021P	PARTICIPANT	\N	EXCUSE	0
294563	293445	14257W	PARTICIPANT	\N	PRESENT	0
294564	293445	08062Y	PARTICIPANT	\N	PRESENT	0
294565	293445	14265W	PARTICIPANT	\N	PRESENT	0
294566	293445	08019V	PARTICIPANT	\N	PRESENT	0
294567	293445	19507S	PARTICIPANT	\N	PRESENT	0
294568	293445	08015R	PARTICIPANT	\N	PRESENT	0
294569	293445	14205J	PARTICIPANT	\N	PRESENT	0
294570	294307	19489J	PARTICIPANT	\N	PRESENT	0
294571	294307	19413M	PARTICIPANT	\N	PRESENT	0
294572	294307	19727D	PARTICIPANT	\N	PRESENT	0
294573	293445	14135M	PARTICIPANT	\N	PRESENT	0
294574	293445	14197C	PARTICIPANT	\N	EXCUSE	0
294575	293444	14197C	PARTICIPANT	\N	EXCUSE	0
294576	294307	08019V	PARTICIPANT	\N	PRESENT	0
294577	293445	04043D	PARTICIPANT	\N	PRESENT	0
294578	293445	04049K	PARTICIPANT	\N	PRESENT	0
294579	293445	08039A	PARTICIPANT	\N	PRESENT	0
294580	293445	14038Y	PARTICIPANT	\N	PRESENT	0
294581	293445	04008A	PARTICIPANT	\N	PRESENT	0
294582	293445	19441R	PARTICIPANT	\N	PRESENT	0
294583	294307	19621T	PARTICIPANT	\N	PRESENT	0
294584	294307	14105F	PARTICIPANT	\N	PRESENT	0
294585	294307	05012A	PARTICIPANT	\N	PRESENT	0
294586	294307	04034C	PARTICIPANT	\N	PRESENT	0
280589	279254	19711U	PARTICIPANT	\N	PRESENT	0
280590	279288	19569H	PARTICIPANT	\N	PRESENT	0
280591	279288	19723Y	PARTICIPANT	\N	PRESENT	0
280594	278292	19697Q	PARTICIPANT	\N	PRESENT	0
280595	278292	11067R	PARTICIPANT	\N	PRESENT	0
280596	278292	11077T	PARTICIPANT	\N	PRESENT	0
280597	278292	14355X	PARTICIPANT	\N	PRESENT	0
280598	278292	19569H	PARTICIPANT	\N	PRESENT	0
280599	278292	11097X	PARTICIPANT	\N	PRESENT	0
280600	278292	19415P	PARTICIPANT	\N	PRESENT	0
280601	278292	14223L	PARTICIPANT	\N	PRESENT	0
280602	278292	04045F	PARTICIPANT	\N	PRESENT	0
280603	278292	14026U	PARTICIPANT	\N	PRESENT	0
280604	278292	14227Q	PARTICIPANT	\N	PRESENT	0
280605	278292	19675J	PARTICIPANT	\N	PRESENT	0
280606	278292	17779H	PARTICIPANT	\N	PRESENT	0
280607	278292	19703U	PARTICIPANT	\N	PRESENT	0
280608	278292	14239U	PARTICIPANT	\N	PRESENT	0
280609	278292	19553Y	PARTICIPANT	\N	PRESENT	0
280610	278292	11031D	PARTICIPANT	\N	PRESENT	0
280611	278292	14087W	PARTICIPANT	\N	PRESENT	0
280612	278292	14281W	PARTICIPANT	\N	PRESENT	0
280613	278292	19679N	PARTICIPANT	\N	PRESENT	0
280614	278292	14042U	PARTICIPANT	\N	PRESENT	0
280615	278292	19575F	PARTICIPANT	\N	PRESENT	0
280616	278292	14195A	PARTICIPANT	\N	PRESENT	0
280617	278292	19367Y	PARTICIPANT	\N	PRESENT	0
280618	278292	14213J	PARTICIPANT	\N	PRESENT	0
280619	278292	14217N	PARTICIPANT	\N	PRESENT	0
280620	278292	19335Q	PARTICIPANT	\N	PRESENT	0
280621	278292	10006L	PARTICIPANT	\N	PRESENT	0
280622	278292	19521Q	PARTICIPANT	\N	PRESENT	0
280623	278292	98024R	PARTICIPANT	\N	PRESENT	0
280624	278292	19527W	PARTICIPANT	\N	PRESENT	0
280625	278292	01034P	PARTICIPANT	\N	PRESENT	0
280626	278292	04092N	PRESIDENT	0	PRESENT	0
280627	278292	08052W	PARTICIPANT	\N	PRESENT	0
280628	278292	19715Y	PARTICIPANT	\N	PRESENT	0
280629	278292	19691J	PARTICIPANT	\N	PRESENT	0
280630	278292	19723Y	PARTICIPANT	\N	PRESENT	0
280631	278292	19727D	PARTICIPANT	\N	PRESENT	0
280632	278292	14119M	PARTICIPANT	\N	PRESENT	0
280633	278292	11103C	PARTICIPANT	\N	PRESENT	0
280634	278292	14071N	PARTICIPANT	\N	PRESENT	0
280635	278292	19657G	PARTICIPANT	\N	PRESENT	0
280636	278292	08048B	PARTICIPANT	\N	EXCUSE	0
280637	278292	08041T	PARTICIPANT	\N	EXCUSE	0
280643	280395	14001X	PARTICIPANT	\N	PRESENT	0
280644	280395	19543W	PARTICIPANT	\N	PRESENT	0
280645	280395	04044E	PARTICIPANT	\N	PRESENT	0
280646	280395	19581D	PARTICIPANT	\N	PRESENT	0
280647	280395	19585H	PARTICIPANT	\N	PRESENT	0
280648	280395	04047H	PARTICIPANT	\N	PRESENT	0
280649	280395	19673G	PARTICIPANT	\N	PRESENT	0
280650	280395	01028R	PARTICIPANT	\N	PRESENT	0
280651	280395	05008E	PRESIDENT	0	PRESENT	0
280652	280395	19447X	PARTICIPANT	\N	PRESENT	0
280653	280395	14231L	PARTICIPANT	\N	PRESENT	0
280654	280395	19489J	PARTICIPANT	\N	PRESENT	0
280655	280395	14147R	PARTICIPANT	\N	PRESENT	0
280656	280395	14179A	PARTICIPANT	\N	PRESENT	0
280657	280395	14215L	PARTICIPANT	\N	PRESENT	0
280658	280395	14259Y	PARTICIPANT	\N	PRESENT	0
280659	280395	11072N	PARTICIPANT	\N	PRESENT	0
280660	280395	14053L	PARTICIPANT	\N	PRESENT	0
280661	280395	14065Q	PARTICIPANT	\N	PRESENT	0
280662	280395	14111D	PARTICIPANT	\N	PRESENT	0
280663	280395	10015M	PARTICIPANT	\N	PRESENT	0
280664	280395	07034Q	PRESIDENT	1	PRESENT	0
280665	280395	11026G	PARTICIPANT	\N	PRESENT	0
280666	280395	08045X	PARTICIPANT	\N	PRESENT	0
280667	280395	19253P	PARTICIPANT	\N	PRESENT	0
280668	280395	01024M	PARTICIPANT	\N	PRESENT	0
280669	280395	04038G	PARTICIPANT	\N	PRESENT	0
280670	280395	19719D	PARTICIPANT	\N	PRESENT	0
280671	280395	14169X	PARTICIPANT	\N	PRESENT	0
280672	280395	11033F	PARTICIPANT	\N	PRESENT	0
280673	280395	19725B	PARTICIPANT	\N	PRESENT	0
280674	280395	19729F	PARTICIPANT	\N	PRESENT	0
280675	280395	19629C	PARTICIPANT	\N	PRESENT	0
280676	280395	08044W	PARTICIPANT	\N	PRESENT	0
280677	280395	14069U	PARTICIPANT	\N	PRESENT	0
280678	280395	11085T	PARTICIPANT	\N	PRESENT	0
280679	280395	14123H	PARTICIPANT	\N	PRESENT	0
280680	280395	11049P	PARTICIPANT	\N	PRESENT	0
280681	280395	04008A	PARTICIPANT	\N	PRESENT	0
280682	280395	98035U	PARTICIPANT	\N	PRESENT	0
280683	280395	19649G	PARTICIPANT	\N	PRESENT	0
280684	280395	95063L	PARTICIPANT	\N	PRESENT	0
280685	280395	14151M	PARTICIPANT	\N	PRESENT	0
280686	280395	14021P	PARTICIPANT	\N	PRESENT	0
280687	279254	19647E	PARTICIPANT	\N	PRESENT	0
280688	279254	19689Q	PARTICIPANT	\N	PRESENT	0
280689	278292	11045K	PARTICIPANT	\N	PRESENT	0
280776	278292	19683J	PARTICIPANT	\N	PRESENT	0
280781	279079	19443T	PARTICIPANT	\N	PRESENT	0
280782	279079	95030B	PARTICIPANT	\N	PRESENT	0
280783	279079	01058X	PARTICIPANT	\N	PRESENT	0
280784	279079	16685X	PARTICIPANT	\N	PRESENT	0
280785	279079	04042C	PRESIDENT	0	PRESENT	0
280786	279079	11054L	PARTICIPANT	\N	PRESENT	0
280787	279079	11066Q	PARTICIPANT	\N	PRESENT	0
280788	279079	95037J	PARTICIPANT	\N	PRESENT	0
280789	279079	19421M	PARTICIPANT	\N	PRESENT	0
280790	279079	14193X	PARTICIPANT	\N	PRESENT	0
280791	279079	08053X	PARTICIPANT	\N	PRESENT	0
280792	279079	97011G	PARTICIPANT	\N	PRESENT	0
280793	279079	08061X	PARTICIPANT	\N	PRESENT	0
280794	279079	08047A	PARTICIPANT	\N	PRESENT	0
280795	279079	14097Y	PARTICIPANT	\N	PRESENT	0
280796	279079	01062T	PARTICIPANT	\N	PRESENT	0
280797	279079	11041F	PARTICIPANT	\N	PRESENT	0
280798	279079	14235Q	PARTICIPANT	\N	PRESENT	0
280799	279079	08058D	PARTICIPANT	\N	PRESENT	0
280800	279079	14028W	PARTICIPANT	\N	PRESENT	0
280801	279079	19251M	PARTICIPANT	\N	PRESENT	0
280802	279079	19721W	PARTICIPANT	\N	PRESENT	0
280803	279079	14105F	PARTICIPANT	\N	PRESENT	0
280804	279079	98018T	PARTICIPANT	\N	PRESENT	0
280805	279079	98022P	PARTICIPANT	\N	PRESENT	0
280806	279079	14267Y	PARTICIPANT	\N	PRESENT	0
280807	279079	98050T	PARTICIPANT	\N	PRESENT	0
280808	279079	19583F	PARTICIPANT	\N	PRESENT	0
280810	279079	98005N	PARTICIPANT	\N	PRESENT	0
280811	279079	14255U	PARTICIPANT	\N	PRESENT	0
280812	279079	98029W	PARTICIPANT	\N	PRESENT	0
280813	279079	08049C	PARTICIPANT	\N	PRESENT	0
280814	279079	11064N	PARTICIPANT	\N	PRESENT	0
280815	279079	19709B	PARTICIPANT	\N	PRESENT	0
280816	279257	14331P	PARTICIPANT	\N	PRESENT	0
280817	279257	01048V	PARTICIPANT	\N	PRESENT	0
280818	279257	19545Y	PARTICIPANT	\N	PRESENT	0
280819	279257	01057W	PARTICIPANT	\N	PRESENT	0
280820	279257	11074Q	PRESIDENT	0	PRESENT	0
280821	279257	89017R	PARTICIPANT	\N	PRESENT	0
280822	279257	14225N	PARTICIPANT	\N	PRESENT	0
280823	279257	07029T	PARTICIPANT	\N	PRESENT	0
280824	279257	14085U	PARTICIPANT	\N	PRESENT	0
280825	279257	19349W	PARTICIPANT	\N	PRESENT	0
280826	279257	14253S	PARTICIPANT	\N	PRESENT	0
280827	279257	19479G	PARTICIPANT	\N	PRESENT	0
280828	279257	11048N	PARTICIPANT	\N	PRESENT	0
280829	279257	19711U	PARTICIPANT	\N	PRESENT	0
280830	279257	19531S	PARTICIPANT	\N	PRESENT	0
280831	279257	08034U	PARTICIPANT	\N	PRESENT	0
280832	279257	08069G	PARTICIPANT	\N	PRESENT	0
280833	279257	19689Q	PARTICIPANT	\N	PRESENT	0
280834	279257	08011M	PARTICIPANT	\N	PRESENT	0
280835	279257	14034U	PARTICIPANT	\N	PRESENT	0
280836	279257	14159V	PARTICIPANT	\N	PRESENT	0
280837	279257	04086Q	PARTICIPANT	\N	PRESENT	0
280838	279257	11040E	PARTICIPANT	\N	PRESENT	0
280839	279257	14199E	PARTICIPANT	\N	PRESENT	0
280840	279257	14121F	PARTICIPANT	\N	PRESENT	0
280841	279257	99004R	PARTICIPANT	\N	PRESENT	0
280842	279257	04061F	PARTICIPANT	\N	PRESENT	0
280843	279257	14083S	PARTICIPANT	\N	EXCUSE	0
280844	279257	11012A	PARTICIPANT	\N	EXCUSE	0
280845	279257	08014Q	PARTICIPANT	\N	EXCUSE	0
280846	279257	88008L	PARTICIPANT	\N	EXCUSE	0
280847	279257	11053K	PARTICIPANT	\N	PRESENT	0
280848	279079	19319Q	PARTICIPANT	\N	PRESENT	0
280849	280690	19441R	PARTICIPANT	\N	PRESENT	0
280850	280690	08028W	PARTICIPANT	\N	PRESENT	0
280851	280690	19269X	PARTICIPANT	\N	PRESENT	0
280882	279503	14061L	PARTICIPANT	\N	PRESENT	0
280883	279503	14065Q	PARTICIPANT	\N	PRESENT	0
280884	279503	14079W	PARTICIPANT	\N	PRESENT	0
280885	279503	19251M	PARTICIPANT	\N	PRESENT	0
271227	270980	19467C	PARTICIPANT	\N	PRESENT	0
273312	273311	11070L	PARTICIPANT	\N	PRESENT	0
273313	273311	19647E	PARTICIPANT	\N	PRESENT	0
273400	273399	11053K	PARTICIPANT	\N	PRESENT	0
273402	273401	11053K	PARTICIPANT	\N	PRESENT	0
273422	273421	07029T	PARTICIPANT	\N	PRESENT	0
273424	273423	08069G	PARTICIPANT	\N	PRESENT	0
273425	273423	08014Q	PARTICIPANT	\N	PRESENT	0
273427	273426	07029T	PARTICIPANT	\N	PRESENT	0
273435	273434	14277B	PARTICIPANT	\N	PRESENT	0
273436	273434	08073C	PARTICIPANT	\N	PRESENT	0
273664	271231	04045F	PARTICIPANT	\N	EXCUSE	0
273665	272043	05012A	PARTICIPANT	\N	EXCUSE	0
273842	271231	08049C	PARTICIPANT	\N	EXCUSE	0
274036	271231	04040A	PRESIDENT	0	PRESENT	0
274037	271231	14327T	PARTICIPANT	\N	PRESENT	0
274038	271231	11110B	PARTICIPANT	\N	PRESENT	0
274039	271231	14281W	PARTICIPANT	\N	PRESENT	0
274040	271231	19565D	PARTICIPANT	\N	PRESENT	0
274041	271231	11048N	PARTICIPANT	\N	PRESENT	0
274042	271231	14231L	PARTICIPANT	\N	PRESENT	0
274043	271231	14103D	PARTICIPANT	\N	PRESENT	0
274044	271231	14028W	PARTICIPANT	\N	PRESENT	0
274045	271231	95063L	PARTICIPANT	\N	PRESENT	0
274046	271231	01057W	PARTICIPANT	\N	PRESENT	0
275060	275059	04047H	PARTICIPANT	\N	PRESENT	0
275061	275059	19649G	PARTICIPANT	\N	PRESENT	0
275062	275059	19253P	PARTICIPANT	\N	PRESENT	0
275063	275059	11026G	PARTICIPANT	\N	PRESENT	0
275064	275059	19673G	PARTICIPANT	\N	PRESENT	0
275066	275065	04047H	PARTICIPANT	\N	PRESENT	0
275067	275065	19673G	PARTICIPANT	\N	PRESENT	0
275068	275065	19629C	PARTICIPANT	\N	PRESENT	0
275069	275065	11026G	PARTICIPANT	\N	PRESENT	0
275152	275151	04042C	PARTICIPANT	\N	PRESENT	0
275153	275151	98022P	PARTICIPANT	\N	PRESENT	0
275154	275151	04088S	PARTICIPANT	\N	PRESENT	0
275970	275969	04047H	PARTICIPANT	\N	PRESENT	0
275971	275969	11072N	PARTICIPANT	\N	PRESENT	0
275972	275969	11026G	PARTICIPANT	\N	PRESENT	0
275973	275969	19329S	PARTICIPANT	\N	PRESENT	0
275975	275974	11033F	PARTICIPANT	\N	PRESENT	0
275976	275974	04047H	PARTICIPANT	\N	PRESENT	0
275977	275974	19629C	PARTICIPANT	\N	PRESENT	0
275978	275974	19253P	PARTICIPANT	\N	PRESENT	0
275979	275974	14215L	PARTICIPANT	\N	PRESENT	0
275980	275974	08045X	PARTICIPANT	\N	PRESENT	0
275981	275974	11026G	PARTICIPANT	\N	PRESENT	0
275982	275833	11033F	PARTICIPANT	\N	PRESENT	0
275983	275833	04047H	PARTICIPANT	\N	PRESENT	0
275984	275833	19629C	PARTICIPANT	\N	PRESENT	0
275985	275833	19253P	PARTICIPANT	\N	PRESENT	0
275986	275833	14215L	PARTICIPANT	\N	PRESENT	0
275987	275833	08045X	PARTICIPANT	\N	PRESENT	0
275988	275833	11026G	PARTICIPANT	\N	PRESENT	0
275990	275989	04047H	PARTICIPANT	\N	PRESENT	0
275991	275989	19649G	PARTICIPANT	\N	PRESENT	0
275992	275989	11026G	PARTICIPANT	\N	PRESENT	0
275993	275989	19629C	PARTICIPANT	\N	PRESENT	0
275994	275989	19673G	PARTICIPANT	\N	PRESENT	0
275996	275995	04047H	PARTICIPANT	\N	PRESENT	0
275997	275995	11026G	PARTICIPANT	\N	PRESENT	0
275998	275995	19673G	PARTICIPANT	\N	PRESENT	0
276000	275999	04047H	PARTICIPANT	\N	PRESENT	0
276001	275999	11026G	PARTICIPANT	\N	PRESENT	0
276003	276002	04047H	PARTICIPANT	\N	PRESENT	0
276004	275844	04047H	PARTICIPANT	\N	PRESENT	0
276005	275844	14215L	PARTICIPANT	\N	PRESENT	0
276007	276006	04047H	PARTICIPANT	\N	PRESENT	0
276008	276006	14215L	PARTICIPANT	\N	PRESENT	0
276018	276017	14079W	PARTICIPANT	\N	PRESENT	0
276019	276017	14097Y	PARTICIPANT	\N	PRESENT	0
283822	283821	04018C	PARTICIPANT	\N	PRESENT	0
283826	283821	08043V	PARTICIPANT	\N	PRESENT	0
283827	283821	19749K	PARTICIPANT	\N	PRESENT	0
286670	286267	19663E	PARTICIPANT	\N	EXCUSE	0
286671	286267	08048B	PARTICIPANT	\N	PRESENT	0
293333	289574	14221J	PARTICIPANT	\N	PRESENT	0
293334	289574	14205J	PARTICIPANT	\N	PRESENT	0
293335	289574	19593H	PARTICIPANT	\N	PRESENT	0
293336	289574	14207L	PARTICIPANT	\N	PRESENT	0
293337	289574	14257W	PARTICIPANT	\N	PRESENT	0
293338	289574	19301E	PARTICIPANT	\N	PRESENT	0
293339	289574	19563B	PARTICIPANT	\N	PRESENT	0
293340	289574	19667J	PARTICIPANT	\N	PRESENT	0
293341	289574	14265W	PARTICIPANT	\N	PRESENT	0
293342	289574	19643A	PARTICIPANT	\N	PRESENT	0
293343	289574	14327T	PARTICIPANT	\N	PRESENT	0
293344	289574	19269X	PARTICIPANT	\N	PRESENT	0
293345	289574	19583F	PARTICIPANT	\N	PRESENT	0
293346	289574	11099A	PARTICIPANT	\N	PRESENT	0
293347	289574	14033T	PARTICIPANT	\N	PRESENT	0
293348	289574	19707Y	PARTICIPANT	\N	PRESENT	0
293349	289574	14135M	PARTICIPANT	\N	PRESENT	0
293350	289574	08060W	PARTICIPANT	\N	PRESENT	0
293351	289574	19705W	PARTICIPANT	\N	PRESENT	0
293352	289574	08016S	PARTICIPANT	\N	PRESENT	0
293353	289574	95063L	PARTICIPANT	\N	PRESENT	0
293354	289574	14357A	PARTICIPANT	\N	PRESENT	0
293355	289574	08062Y	PARTICIPANT	\N	PRESENT	0
293356	289574	11109J	PARTICIPANT	\N	PRESENT	0
297406	289182	14061L	PARTICIPANT	\N	PRESENT	0
297407	289182	19760E	PARTICIPANT	\N	PRESENT	0
293331	289574	11072N	PARTICIPANT	\N	PRESENT	0
293332	289574	11090Q	PARTICIPANT	\N	PRESENT	0
297408	289182	14059S	PARTICIPANT	\N	PRESENT	0
297409	289182	19367Y	PARTICIPANT	\N	PRESENT	0
297410	289182	19629C	PARTICIPANT	\N	PRESENT	0
297411	289182	19667J	PARTICIPANT	\N	PRESENT	0
297412	289182	19723Y	PARTICIPANT	\N	PRESENT	0
297413	289182	14119M	PARTICIPANT	\N	PRESENT	0
297414	289182	19333N	PARTICIPANT	\N	PRESENT	0
297415	289182	18083K	PARTICIPANT	\N	PRESENT	0
297416	289182	14041T	PARTICIPANT	\N	PRESENT	0
297417	289182	11045K	PARTICIPANT	\N	PRESENT	0
297418	289182	14249W	PARTICIPANT	\N	PRESENT	0
297419	289182	14215L	PARTICIPANT	\N	PRESENT	0
297420	289182	19533U	PARTICIPANT	\N	PRESENT	0
297421	289182	19657G	PARTICIPANT	\N	PRESENT	0
297422	289182	19575F	PARTICIPANT	\N	PRESENT	0
297423	289182	19553Y	PARTICIPANT	\N	PRESENT	0
297424	289182	95030B	PARTICIPANT	\N	PRESENT	0
297425	289182	14039A	PARTICIPANT	\N	PRESENT	0
297426	289182	19699S	PARTICIPANT	\N	PRESENT	0
297427	289182	10006L	PARTICIPANT	\N	PRESENT	0
297428	289182	14053L	PARTICIPANT	\N	PRESENT	0
297429	289182	99004R	PARTICIPANT	\N	PRESENT	0
297430	289182	15447F	PARTICIPANT	\N	PRESENT	0
297431	289182	14265W	PARTICIPANT	\N	PRESENT	0
297432	289182	04088S	PARTICIPANT	\N	PRESENT	0
297433	289182	11043H	PARTICIPANT	\N	PRESENT	0
297434	289182	14267Y	PARTICIPANT	\N	PRESENT	0
297435	289182	19387D	PARTICIPANT	\N	PRESENT	0
297436	289182	19695N	PARTICIPANT	\N	PRESENT	0
297437	289182	19701S	PARTICIPANT	\N	PRESENT	0
297438	289182	14038Y	PARTICIPANT	\N	PRESENT	0
297439	289182	19581D	PARTICIPANT	\N	PRESENT	0
297440	289182	04085P	PARTICIPANT	\N	PRESENT	0
297441	289182	19733B	PARTICIPANT	\N	PRESENT	0
297442	289182	19619A	PARTICIPANT	\N	PRESENT	0
297443	289182	14187A	PARTICIPANT	\N	PRESENT	0
297444	289182	14033T	PARTICIPANT	\N	PRESENT	0
297445	289182	19413M	PARTICIPANT	\N	PRESENT	0
297446	289182	14329V	PARTICIPANT	\N	PRESENT	0
297447	289182	19673G	PARTICIPANT	\N	PRESENT	0
297448	289182	07029T	PARTICIPANT	\N	PRESENT	0
297449	289182	19447X	PARTICIPANT	\N	PRESENT	0
297450	289182	11064N	PARTICIPANT	\N	PRESENT	0
297451	289182	19515S	PARTICIPANT	\N	PRESENT	0
297452	289182	19611R	PARTICIPANT	\N	PRESENT	0
297453	289182	08056B	PARTICIPANT	\N	PRESENT	0
297454	289182	14042U	PARTICIPANT	\N	PRESENT	0
297455	289182	19349W	PARTICIPANT	\N	PRESENT	0
297456	289182	19745F	PARTICIPANT	\N	PRESENT	0
297457	289182	14217N	PARTICIPANT	\N	PRESENT	0
297458	289182	19599P	PARTICIPANT	\N	PRESENT	0
297459	289182	19735D	PARTICIPANT	\N	PRESENT	0
297460	289182	19715Y	PARTICIPANT	\N	PRESENT	0
297461	289182	14257W	PARTICIPANT	\N	PRESENT	0
297462	289182	14251Q	PARTICIPANT	\N	PRESENT	0
297463	289182	19669L	PARTICIPANT	\N	PRESENT	0
297464	289182	97011G	PARTICIPANT	\N	PRESENT	0
297465	289182	14147R	PARTICIPANT	\N	PRESENT	0
274719	263758	19581D	PARTICIPANT	\N	PRESENT	0
274720	263758	14241N	PARTICIPANT	\N	PRESENT	0
274721	263758	19507S	PARTICIPANT	\N	PRESENT	0
274722	263758	14235Q	PARTICIPANT	\N	PRESENT	0
274790	263758	08053X	PARTICIPANT	\N	PRESENT	0
274724	263758	14267Y	PARTICIPANT	\N	PRESENT	0
274725	263758	04088S	PARTICIPANT	\N	PRESENT	0
274726	263758	04057K	PARTICIPANT	\N	PRESENT	0
274727	263758	14111D	PARTICIPANT	\N	PRESENT	0
274728	263758	19349W	PARTICIPANT	\N	PRESENT	0
274772	263758	19333N	PARTICIPANT	\N	PRESENT	0
274730	263758	19387D	PARTICIPANT	\N	PRESENT	0
274791	263758	14089Y	PARTICIPANT	\N	PRESENT	0
274732	263758	14069U	PARTICIPANT	\N	PRESENT	0
274733	263758	14265W	PARTICIPANT	\N	PRESENT	0
274734	263758	04035D	PARTICIPANT	\N	PRESENT	0
274781	263758	11056N	PARTICIPANT	\N	PRESENT	0
274779	263758	08047A	PARTICIPANT	\N	PRESENT	0
274737	263758	11103C	PARTICIPANT	\N	PRESENT	0
274738	263758	19525U	PARTICIPANT	\N	PRESENT	0
274739	263758	19701S	PARTICIPANT	\N	PRESENT	0
274740	263758	14115H	PARTICIPANT	\N	PRESENT	0
274789	263758	14205J	PARTICIPANT	\N	PRESENT	0
274742	263758	19383Y	PARTICIPANT	\N	PRESENT	0
274743	263758	14133K	PARTICIPANT	\N	PRESENT	0
274744	263758	19685L	PARTICIPANT	\N	PRESENT	0
274778	263758	08034U	PARTICIPANT	\N	PRESENT	0
274746	263758	14135M	PARTICIPANT	\N	PRESENT	0
274747	263758	14053L	PARTICIPANT	\N	PRESENT	0
274748	263758	16685X	PARTICIPANT	\N	PRESENT	0
274749	263758	11027H	PARTICIPANT	\N	PRESENT	0
274750	263758	11064N	PARTICIPANT	\N	PRESENT	0
274751	263758	98050T	PARTICIPANT	\N	PRESENT	0
274752	263758	04034C	PARTICIPANT	\N	PRESENT	0
274753	263758	08020N	PARTICIPANT	\N	PRESENT	0
274754	263758	14021P	PARTICIPANT	\N	PRESENT	0
274755	263758	14103D	PARTICIPANT	\N	PRESENT	0
274756	263758	19709B	PARTICIPANT	\N	PRESENT	0
274757	263758	11104D	PARTICIPANT	\N	PRESENT	0
274758	263758	14255U	PARTICIPANT	\N	PRESENT	0
274759	263758	14028W	PARTICIPANT	\N	PRESENT	0
274760	263758	19673G	PARTICIPANT	\N	PRESENT	0
274761	263758	19745F	PARTICIPANT	\N	PRESENT	0
274762	263758	14257W	PARTICIPANT	\N	PRESENT	0
274792	263758	19447X	PARTICIPANT	\N	PRESENT	0
274764	263758	19421M	PARTICIPANT	\N	PRESENT	0
274793	263758	14055N	PARTICIPANT	\N	PRESENT	0
274766	263758	95037J	PARTICIPANT	\N	PRESENT	0
274767	263758	19565D	PARTICIPANT	\N	PRESENT	0
274768	263758	08058D	PARTICIPANT	\N	PRESENT	0
274769	263758	97011G	PARTICIPANT	\N	PRESENT	0
274770	263758	04042C	PARTICIPANT	\N	PRESENT	0
274771	263758	11054L	PARTICIPANT	\N	PRESENT	0
274773	263758	11066Q	PARTICIPANT	\N	PRESENT	0
274774	263758	01062T	PARTICIPANT	\N	PRESENT	0
274775	263758	08016S	PARTICIPANT	\N	PRESENT	0
274776	263758	14093U	PARTICIPANT	\N	PRESENT	0
274777	263758	19729F	PARTICIPANT	\N	PRESENT	0
274780	263758	19695N	PARTICIPANT	\N	PRESENT	0
274782	263758	14051J	PARTICIPANT	\N	PRESENT	0
274783	263758	19251M	PARTICIPANT	\N	PRESENT	0
274784	263758	19681G	PARTICIPANT	\N	PRESENT	0
274785	263758	19543W	PARTICIPANT	\N	PRESENT	0
274786	263758	98029W	PARTICIPANT	\N	PRESENT	0
274787	263758	11012A	PARTICIPANT	\N	PRESENT	0
274788	263758	08049C	PARTICIPANT	\N	PRESENT	0
274794	263758	19683J	PARTICIPANT	\N	PRESENT	0
274795	263758	19575F	PARTICIPANT	\N	PRESENT	0
274796	263758	19563B	PARTICIPANT	\N	PRESENT	0
274797	263758	14121F	PARTICIPANT	\N	PRESENT	0
274798	263758	14107H	PARTICIPANT	\N	PRESENT	0
274799	263758	14033T	PARTICIPANT	\N	PRESENT	0
274800	263758	19585H	PARTICIPANT	\N	PRESENT	0
274801	263758	19657G	PARTICIPANT	\N	PRESENT	0
274802	263758	11045K	PARTICIPANT	\N	PRESENT	0
274803	263758	01058X	PARTICIPANT	\N	PRESENT	0
274804	263758	01048V	PARTICIPANT	\N	PRESENT	0
274805	263758	19699S	PARTICIPANT	\N	PRESENT	0
274806	263758	19733B	PARTICIPANT	\N	PRESENT	0
274807	263758	04040A	PARTICIPANT	\N	PRESENT	0
274808	263758	14237S	PARTICIPANT	\N	PRESENT	0
274809	263758	18083K	PARTICIPANT	\N	PRESENT	0
274811	263758	11067R	PARTICIPANT	\N	PRESENT	0
274814	263758	19611R	PARTICIPANT	\N	PRESENT	0
274816	263758	95067Q	PARTICIPANT	\N	PRESENT	0
274818	263758	14029X	PARTICIPANT	\N	PRESENT	0
274819	263758	14030Q	PARTICIPANT	\N	PRESENT	0
274821	273328	14327T	PARTICIPANT	\N	PRESENT	0
274822	273328	01057W	PARTICIPANT	\N	PRESENT	0
274823	273328	11053K	PARTICIPANT	\N	PRESENT	0
274824	273328	11074Q	PRESIDENT	0	PRESENT	0
274825	273328	19667J	PARTICIPANT	\N	PRESENT	0
274826	273328	19671E	PARTICIPANT	\N	PRESENT	0
274827	273328	14225N	PARTICIPANT	\N	PRESENT	0
274828	273328	11110B	PARTICIPANT	\N	PRESENT	0
274829	273328	14085U	PARTICIPANT	\N	PRESENT	0
274830	273328	19349W	PARTICIPANT	\N	PRESENT	0
274831	273328	14253S	PARTICIPANT	\N	PRESENT	0
274832	273328	19479G	PARTICIPANT	\N	PRESENT	0
274833	273328	19647E	PARTICIPANT	\N	PRESENT	0
274834	273328	19531S	PARTICIPANT	\N	PRESENT	0
274835	273328	19651A	PARTICIPANT	\N	PRESENT	0
274836	273328	08069G	PARTICIPANT	\N	PRESENT	0
274837	273328	19687N	PARTICIPANT	\N	PRESENT	0
274838	273328	19689Q	PARTICIPANT	\N	PRESENT	0
274839	273328	08011M	PARTICIPANT	\N	PRESENT	0
274840	273328	14159V	PARTICIPANT	\N	PRESENT	0
274841	273328	11040E	PARTICIPANT	\N	PRESENT	0
274842	273328	14083S	PARTICIPANT	\N	PRESENT	0
274843	273328	14121F	PARTICIPANT	\N	PRESENT	0
274844	273328	99004R	PARTICIPANT	\N	PRESENT	0
274845	273328	04061F	PARTICIPANT	\N	PRESENT	0
274846	273328	07029T	PARTICIPANT	\N	EXCUSE	0
274847	273328	14331P	PARTICIPANT	\N	EXCUSE	0
274848	273328	04071H	PARTICIPANT	\N	PRESENT	0
274849	273328	14034U	PARTICIPANT	\N	PRESENT	0
274850	263758	19621T	PARTICIPANT	\N	PRESENT	0
274854	273328	08034U	PARTICIPANT	\N	PRESENT	0
274861	263758	19573D	PARTICIPANT	\N	PRESENT	0
274862	263758	05012A	PARTICIPANT	\N	PRESENT	0
274863	263758	19703U	PARTICIPANT	\N	PRESENT	0
274864	263758	19467C	PARTICIPANT	\N	PRESENT	0
274865	263758	17583W	PARTICIPANT	\N	PRESENT	0
274866	263758	98018T	PARTICIPANT	\N	PRESENT	0
274871	263758	19503N	PARTICIPANT	\N	PRESENT	0
274872	263758	04045F	PARTICIPANT	\N	PRESENT	0
274873	263758	08069G	PARTICIPANT	\N	PRESENT	0
274874	263758	19415P	PARTICIPANT	\N	PRESENT	0
274875	263758	14213J	PARTICIPANT	\N	PRESENT	0
274876	263758	01024M	PARTICIPANT	\N	PRESENT	0
274877	273328	01048V	PARTICIPANT	\N	PRESENT	0
274878	273328	11070L	PARTICIPANT	\N	PRESENT	0
274879	273328	08010L	PARTICIPANT	\N	PRESENT	0
274880	273328	11048N	PARTICIPANT	\N	PRESENT	0
274881	273328	04086Q	PARTICIPANT	\N	PRESENT	0
274882	273328	14199E	PARTICIPANT	\N	PRESENT	0
274883	273328	08073C	PARTICIPANT	\N	EXCUSE	0
274884	273328	14277B	PARTICIPANT	\N	EXCUSE	0
274885	273328	08014Q	PARTICIPANT	\N	EXCUSE	0
274886	263758	14201E	PARTICIPANT	\N	PRESENT	0
274887	263758	95062K	PARTICIPANT	\N	PRESENT	0
274888	263758	14197C	PARTICIPANT	\N	PRESENT	0
274889	263758	19549D	PARTICIPANT	\N	PRESENT	0
274891	263758	04086Q	PARTICIPANT	\N	PRESENT	0
274892	263758	14042U	PARTICIPANT	\N	PRESENT	0
274893	263758	14219Q	PARTICIPANT	\N	PRESENT	0
274894	263758	08015R	PARTICIPANT	\N	PRESENT	0
274895	263758	14079W	PARTICIPANT	\N	PRESENT	0
274897	263758	14041T	PARTICIPANT	\N	PRESENT	0
274898	263758	08031R	PARTICIPANT	\N	PRESENT	0
274899	263758	08061X	PARTICIPANT	\N	PRESENT	0
274900	263758	08043V	PARTICIPANT	\N	PRESENT	0
274901	263758	14097Y	PARTICIPANT	\N	PRESENT	0
274902	263758	14253S	PARTICIPANT	\N	PRESENT	0
274903	263758	14071N	PARTICIPANT	\N	PRESENT	0
274904	263758	19553Y	PARTICIPANT	\N	PRESENT	0
274905	263758	04085P	PARTICIPANT	\N	PRESENT	0
274906	263758	19569H	PARTICIPANT	\N	PRESENT	0
274907	263758	11097X	PARTICIPANT	\N	PRESENT	0
274908	263758	11043H	PARTICIPANT	\N	PRESENT	0
273516	273515	14221J	PARTICIPANT	\N	PRESENT	0
273532	268443	19723Y	PARTICIPANT	\N	PRESENT	0
273534	270980	19713W	PARTICIPANT	\N	PRESENT	0
296574	295690	08024S	PARTICIPANT	\N	PRESENT	0
296575	295690	19551W	PARTICIPANT	\N	PRESENT	0
296576	295691	19551W	PARTICIPANT	\N	PRESENT	0
299275	289191	19689Q	PARTICIPANT	\N	PRESENT	0
299276	289191	11033F	PARTICIPANT	\N	PRESENT	0
299277	289191	14071N	PARTICIPANT	\N	PRESENT	0
299278	289191	19525U	PARTICIPANT	\N	PRESENT	0
299279	289191	08069G	PARTICIPANT	\N	PRESENT	0
299280	289191	14030Q	PARTICIPANT	\N	PRESENT	0
299281	294874	01024M	PARTICIPANT	\N	PRESENT	0
299282	289191	10006L	PARTICIPANT	\N	PRESENT	0
299283	289191	19479G	PARTICIPANT	\N	PRESENT	0
299285	299284	08038Y	PARTICIPANT	\N	PRESENT	0
299286	299284	19727D	PARTICIPANT	\N	PRESENT	0
299287	299284	19489J	PARTICIPANT	\N	PRESENT	0
299288	299284	14071N	PARTICIPANT	\N	PRESENT	0
299289	299284	19619A	PARTICIPANT	\N	PRESENT	0
299290	299284	19689Q	PARTICIPANT	\N	PRESENT	0
299291	289191	80013X	PARTICIPANT	\N	PRESENT	0
299292	289191	14249W	PARTICIPANT	\N	PRESENT	0
299293	289191	19349W	PARTICIPANT	\N	PRESENT	0
299294	289191	14059S	PARTICIPANT	\N	PRESENT	0
299295	289191	14151M	PARTICIPANT	\N	PRESENT	0
299296	289191	19737F	PARTICIPANT	\N	PRESENT	0
299297	289191	19693L	PARTICIPANT	\N	PRESENT	0
299298	289191	14217N	PARTICIPANT	\N	PRESENT	0
299299	289191	95067Q	PARTICIPANT	\N	PRESENT	0
299300	289191	11097X	PARTICIPANT	\N	PRESENT	0
299301	289191	14029X	PARTICIPANT	\N	PRESENT	0
299307	299306	08043V	PARTICIPANT	\N	PRESENT	0
299308	299306	04018C	PARTICIPANT	\N	PRESENT	0
299309	299306	14109K	PARTICIPANT	\N	PRESENT	0
299314	289191	07029T	PARTICIPANT	\N	PRESENT	0
299316	289191	08062Y	PARTICIPANT	\N	PRESENT	0
299317	289191	08056B	PARTICIPANT	\N	PRESENT	0
299318	289191	11026G	PARTICIPANT	\N	PRESENT	0
299320	299319	08055A	PARTICIPANT	\N	PRESENT	0
299321	299319	04047H	PARTICIPANT	\N	PRESENT	0
299322	299319	19545Y	PARTICIPANT	\N	PRESENT	0
299323	299319	14085U	PARTICIPANT	\N	PRESENT	0
299324	299319	11080N	PARTICIPANT	\N	PRESENT	0
299325	299319	11083R	PARTICIPANT	\N	PRESENT	0
299326	299319	01057W	PARTICIPANT	\N	PRESENT	0
299327	299319	14157T	PARTICIPANT	\N	PRESENT	0
299328	289191	14089Y	PARTICIPANT	\N	PRESENT	0
299329	289191	04059M	PARTICIPANT	\N	PRESENT	0
299331	299330	08055A	PARTICIPANT	\N	PRESENT	0
299332	299330	04047H	PARTICIPANT	\N	PRESENT	0
299333	299330	14085U	PARTICIPANT	\N	PRESENT	0
299334	299330	08049C	PARTICIPANT	\N	EXCUSE	0
299335	289191	19762G	PARTICIPANT	\N	PRESENT	0
299336	289191	11048N	PARTICIPANT	\N	PRESENT	0
299338	289191	19729F	PARTICIPANT	\N	PRESENT	0
299343	289191	01058X	PARTICIPANT	\N	PRESENT	0
299347	289191	19675J	PARTICIPANT	\N	PRESENT	0
299349	289191	14357A	PARTICIPANT	\N	PRESENT	0
299350	289191	19758L	PARTICIPANT	\N	PRESENT	0
299351	289191	04092N	PARTICIPANT	\N	PRESENT	0
299352	289191	92040Q	PARTICIPANT	\N	PRESENT	0
299353	289191	14053L	PARTICIPANT	\N	PRESENT	0
299354	289191	19725B	PARTICIPANT	\N	PRESENT	0
299355	289191	11072N	PARTICIPANT	\N	PRESENT	0
299356	289191	14259Y	PARTICIPANT	\N	PRESENT	0
299363	289191	19647E	PARTICIPANT	\N	PRESENT	0
299365	289191	05012A	PARTICIPANT	\N	PRESENT	0
299366	289191	11043H	PARTICIPANT	\N	PRESENT	0
299367	289191	19733B	PARTICIPANT	\N	PRESENT	0
299368	289191	04057K	PARTICIPANT	\N	PRESENT	0
299369	289191	19549D	PARTICIPANT	\N	PRESENT	0
299370	289191	11053K	PARTICIPANT	\N	PRESENT	0
299375	289191	19679N	PARTICIPANT	\N	PRESENT	0
299376	289191	01028R	PARTICIPANT	\N	PRESENT	0
299377	289191	08048B	PARTICIPANT	\N	PRESENT	0
299378	289191	14231L	PARTICIPANT	\N	PRESENT	0
299379	289191	19551W	PARTICIPANT	\N	PRESENT	0
299393	289191	01062T	PARTICIPANT	\N	PRESENT	0
299394	289191	14267Y	PARTICIPANT	\N	PRESENT	0
299395	289191	89017R	PARTICIPANT	\N	PRESENT	0
299554	289192	04059M	PARTICIPANT	\N	PRESENT	0
299555	289192	14187A	PARTICIPANT	\N	PRESENT	0
299556	289192	11090Q	PARTICIPANT	\N	PRESENT	0
299557	289192	11056N	PARTICIPANT	\N	PRESENT	0
299558	289192	19565D	PARTICIPANT	\N	PRESENT	0
299559	289192	19695N	PARTICIPANT	\N	PRESENT	0
299560	289192	12016W	PARTICIPANT	\N	PRESENT	0
299561	289192	19413M	PARTICIPANT	\N	PRESENT	0
299562	289192	19631V	PARTICIPANT	\N	PRESENT	0
299563	289192	08038Y	PARTICIPANT	\N	PRESENT	0
299564	289192	19591F	PARTICIPANT	\N	PRESENT	0
299565	289192	08055A	PARTICIPANT	\N	PRESENT	0
299566	289192	19349W	PARTICIPANT	\N	PRESENT	0
299567	289192	11077T	PARTICIPANT	\N	PRESENT	0
299568	289192	14195A	PARTICIPANT	\N	PRESENT	0
299569	289192	19713W	PARTICIPANT	\N	PRESENT	0
299570	289192	14042U	PARTICIPANT	\N	PRESENT	0
299571	289192	19735D	PARTICIPANT	\N	PRESENT	0
299572	289192	19737F	PARTICIPANT	\N	PRESENT	0
299573	289192	14030Q	PARTICIPANT	\N	PRESENT	0
299574	289192	01025N	PARTICIPANT	\N	PRESENT	0
299575	289192	19747H	PARTICIPANT	\N	PRESENT	0
299576	289192	19671E	PARTICIPANT	\N	PRESENT	0
299577	289192	19621T	PARTICIPANT	\N	PRESENT	0
299578	289192	04018C	PARTICIPANT	\N	PRESENT	0
299579	289192	14357A	PARTICIPANT	\N	PRESENT	0
299580	289192	14265W	PARTICIPANT	\N	PRESENT	0
299581	289192	14223L	PARTICIPANT	\N	PRESENT	0
299582	289192	19399H	PARTICIPANT	\N	PRESENT	0
299583	289192	11099A	PARTICIPANT	\N	PRESENT	0
299584	289192	19387D	PARTICIPANT	\N	PRESENT	0
299585	289192	14157T	PARTICIPANT	\N	PRESENT	0
299586	289192	08039A	PARTICIPANT	\N	PRESENT	0
299587	289192	19703U	PARTICIPANT	\N	PRESENT	0
299588	289192	19673G	PARTICIPANT	\N	PRESENT	0
299589	289192	19515S	PARTICIPANT	\N	PRESENT	0
299590	289192	14191V	PARTICIPANT	\N	PRESENT	0
299591	289192	14038Y	PARTICIPANT	\N	PRESENT	0
299592	289192	95062K	PARTICIPANT	\N	PRESENT	0
299593	289192	04008A	PARTICIPANT	\N	PRESENT	0
299594	289192	96004D	PARTICIPANT	\N	PRESENT	0
299595	289192	19679N	PARTICIPANT	\N	PRESENT	0
299596	289192	19573D	PARTICIPANT	\N	PRESENT	0
299597	289192	04086Q	PARTICIPANT	\N	PRESENT	0
299598	289192	14071N	PARTICIPANT	\N	PRESENT	0
299599	289192	89017R	PARTICIPANT	\N	PRESENT	0
299600	289192	19701S	PARTICIPANT	\N	PRESENT	0
299601	289192	19503N	PARTICIPANT	\N	PRESENT	0
299602	289192	08068F	PARTICIPANT	\N	PRESENT	0
299603	289192	14109K	PARTICIPANT	\N	PRESENT	0
299604	289192	14257W	PARTICIPANT	\N	PRESENT	0
299605	289192	08060W	PARTICIPANT	\N	PRESENT	0
299606	289192	14229S	PARTICIPANT	\N	PRESENT	0
299607	289192	19651A	PARTICIPANT	\N	PRESENT	0
299608	289192	19347U	PARTICIPANT	\N	PRESENT	0
299609	289192	11104D	PARTICIPANT	\N	PRESENT	0
299610	289192	19719D	PARTICIPANT	\N	PRESENT	0
299611	289192	14197C	PARTICIPANT	\N	PRESENT	0
299612	289192	19739H	PARTICIPANT	\N	PRESENT	0
299613	289192	19745F	PARTICIPANT	\N	PRESENT	0
299614	289192	14089Y	PARTICIPANT	\N	PRESENT	0
299615	289192	14213J	PARTICIPANT	\N	PRESENT	0
299616	289192	95067Q	PARTICIPANT	\N	PRESENT	0
299617	289192	19657G	PARTICIPANT	\N	PRESENT	0
299618	289192	14051J	PARTICIPANT	\N	PRESENT	0
299619	289192	08045X	PARTICIPANT	\N	PRESENT	0
299620	289192	19681G	PARTICIPANT	\N	PRESENT	0
299621	289192	08043V	PARTICIPANT	\N	PRESENT	0
299622	289192	14029X	PARTICIPANT	\N	PRESENT	0
299623	289192	19443T	PARTICIPANT	\N	PRESENT	0
299624	289192	14026U	PARTICIPANT	\N	PRESENT	0
299625	289192	14217N	PARTICIPANT	\N	PRESENT	0
299626	289192	19421M	PARTICIPANT	\N	PRESENT	0
299627	289192	11097X	PARTICIPANT	\N	PRESENT	0
299628	289192	04070G	PARTICIPANT	\N	PRESENT	0
299629	289192	08061X	PARTICIPANT	\N	PRESENT	0
299630	289192	14105F	PARTICIPANT	\N	PRESENT	0
299631	289192	11048N	PARTICIPANT	\N	PRESENT	0
299632	289192	04088S	PARTICIPANT	\N	PRESENT	0
299633	289192	11043H	PARTICIPANT	\N	PRESENT	0
299634	289192	19525U	PARTICIPANT	\N	PRESENT	0
299635	289192	14173T	PARTICIPANT	\N	PRESENT	0
299636	289192	19479G	PARTICIPANT	\N	PRESENT	0
299637	289192	14053L	PARTICIPANT	\N	PRESENT	0
299638	289192	14205J	PARTICIPANT	\N	PRESENT	0
299639	289192	16685X	PARTICIPANT	\N	PRESENT	0
299640	289192	14231L	PARTICIPANT	\N	PRESENT	0
281705	281704	14239U	PARTICIPANT	\N	PRESENT	0
281706	281704	19549D	PARTICIPANT	\N	PRESENT	0
281707	281704	19367Y	PARTICIPANT	\N	PRESENT	0
281708	281704	14217N	PARTICIPANT	\N	PRESENT	0
281709	281704	19697Q	PARTICIPANT	\N	PRESENT	0
281710	281704	14031R	PARTICIPANT	\N	PRESENT	0
281711	281704	11067R	PARTICIPANT	\N	PRESENT	0
281712	281704	14119M	PARTICIPANT	\N	PRESENT	0
281713	281704	11045K	PRESIDENT	0	PRESENT	0
281714	281704	04044E	PARTICIPANT	\N	PRESENT	0
281804	281803	14147R	PARTICIPANT	\N	PRESENT	0
281825	281824	14147R	PARTICIPANT	\N	PRESENT	0
282021	282020	14065Q	PARTICIPANT	\N	PRESENT	0
282022	282020	96004D	PRESIDENT	0	PRESENT	0
282024	282020	14249W	PARTICIPANT	\N	EXCUSE	0
282025	282020	08018U	PARTICIPANT	\N	EXCUSE	0
282027	282020	11083R	PARTICIPANT	\N	PRESENT	0
282029	282020	14033T	PARTICIPANT	\N	EXCUSE	0
282032	282020	19725B	PARTICIPANT	\N	PRESENT	0
282034	282020	95037J	PARTICIPANT	\N	PRESENT	0
282035	282020	04097T	PARTICIPANT	\N	PRESENT	0
282036	282020	08044W	PARTICIPANT	\N	EXCUSE	0
282037	282020	14097Y	PARTICIPANT	\N	PRESENT	0
282038	282020	14061L	PARTICIPANT	\N	PRESENT	0
282039	282020	14073Q	PARTICIPANT	\N	PRESENT	0
282043	282020	08039A	PARTICIPANT	\N	PRESENT	0
282045	282020	04057K	PARTICIPANT	\N	EXCUSE	0
282047	282020	19563B	PARTICIPANT	\N	PRESENT	0
282048	282020	19593H	PARTICIPANT	\N	EXCUSE	0
282049	282020	14237S	PARTICIPANT	\N	PRESENT	0
282050	282020	14331P	PARTICIPANT	\N	PRESENT	0
282051	282020	10015M	PARTICIPANT	\N	PRESENT	0
282052	282020	98035U	PARTICIPANT	\N	PRESENT	0
282342	282340	14121F	PARTICIPANT	\N	PRESENT	0
282522	282508	98035U	PARTICIPANT	\N	PRESENT	0
282523	282508	14053L	PARTICIPANT	\N	PRESENT	0
280886	279503	14219Q	PARTICIPANT	\N	PRESENT	0
280887	279503	19695N	PARTICIPANT	\N	PRESENT	0
280888	279503	11090Q	PARTICIPANT	\N	PRESENT	0
280889	279503	19631V	PARTICIPANT	\N	PRESENT	0
280890	279503	14237S	PARTICIPANT	\N	PRESENT	0
280891	279503	08068F	PARTICIPANT	\N	PRESENT	0
280892	279503	08015R	PARTICIPANT	\N	PRESENT	0
280893	279503	19737F	PARTICIPANT	\N	PRESENT	0
280894	279503	19681G	PARTICIPANT	\N	PRESENT	0
280895	279503	08028W	PRESIDENT	0	PRESENT	0
280896	279503	14257W	PARTICIPANT	\N	PRESENT	0
280897	279503	19585H	PARTICIPANT	\N	EXCUSE	0
281528	280690	14026U	PARTICIPANT	\N	PRESENT	0
282524	282508	14111D	PARTICIPANT	\N	PRESENT	0
282525	282508	07034Q	PARTICIPANT	\N	PRESENT	0
282526	282508	11026G	PARTICIPANT	\N	PRESENT	0
282527	282508	08045X	PARTICIPANT	\N	PRESENT	0
282528	282508	14001X	PARTICIPANT	\N	PRESENT	0
282529	282508	19253P	PARTICIPANT	\N	PRESENT	0
282530	282508	19581D	PARTICIPANT	\N	PRESENT	0
282531	282508	04038G	PARTICIPANT	\N	PRESENT	0
282532	282508	01028R	PARTICIPANT	\N	PRESENT	0
282533	282508	19447X	PARTICIPANT	\N	PRESENT	0
282534	282508	05008E	PRESIDENT	0	PRESENT	0
282535	282508	14231L	PARTICIPANT	\N	PRESENT	0
282536	282508	19729F	PARTICIPANT	\N	PRESENT	0
282537	282508	14041T	PARTICIPANT	\N	PRESENT	0
282538	282508	14147R	PARTICIPANT	\N	PRESENT	0
282539	282508	14179A	PARTICIPANT	\N	PRESENT	0
282540	282508	14069U	PARTICIPANT	\N	PRESENT	0
282541	282508	14259Y	PARTICIPANT	\N	PRESENT	0
282542	282508	95063L	PARTICIPANT	\N	PRESENT	0
282543	282508	14065Q	PARTICIPANT	\N	EXCUSE	0
282544	282508	04044E	PARTICIPANT	\N	EXCUSE	0
282545	282490	04097T	PARTICIPANT	\N	PRESENT	0
282546	282490	19347U	PARTICIPANT	\N	PRESENT	0
282547	282508	19585H	PARTICIPANT	\N	PRESENT	0
282548	282508	19629C	PARTICIPANT	\N	PRESENT	0
282584	273890	04044E	PARTICIPANT	\N	PRESENT	0
282587	273890	19731Y	PARTICIPANT	\N	PRESENT	0
282588	273890	11066Q	PARTICIPANT	\N	PRESENT	0
282589	273890	88008L	PARTICIPANT	\N	PRESENT	0
282590	273890	19611R	PARTICIPANT	\N	PRESENT	0
282591	273890	14241N	PARTICIPANT	\N	PRESENT	0
282592	273890	19479G	PARTICIPANT	\N	PRESENT	0
282593	273890	19333N	PARTICIPANT	\N	PRESENT	0
282594	273890	19533U	PARTICIPANT	\N	PRESENT	0
282595	273890	14033T	PARTICIPANT	\N	PRESENT	0
282596	273890	14215L	PARTICIPANT	\N	PRESENT	0
282597	273890	14105F	PARTICIPANT	\N	PRESENT	0
282598	273890	14038Y	PARTICIPANT	\N	PRESENT	0
282599	273890	95063L	PARTICIPANT	\N	PRESENT	0
282600	273890	02002K	PARTICIPANT	\N	PRESENT	0
282601	273890	19715Y	PARTICIPANT	\N	PRESENT	0
282602	273890	19599P	PARTICIPANT	\N	PRESENT	0
282603	273890	14225N	PARTICIPANT	\N	PRESENT	0
282604	273890	14001X	PARTICIPANT	\N	PRESENT	0
282605	273890	14121F	PARTICIPANT	\N	PRESENT	0
282606	273890	19369B	PARTICIPANT	\N	PRESENT	0
282607	273890	19447X	PARTICIPANT	\N	PRESENT	0
282608	273890	04086Q	PARTICIPANT	\N	PRESENT	0
282609	273890	04043D	PARTICIPANT	\N	PRESENT	0
282613	273890	14028W	PARTICIPANT	\N	PRESENT	0
282611	273890	11056N	PARTICIPANT	\N	PRESENT	0
282612	273890	08053X	PARTICIPANT	\N	PRESENT	0
282614	273890	14157T	PARTICIPANT	\N	PRESENT	0
282615	273890	14061L	PARTICIPANT	\N	PRESENT	0
282616	273890	11026G	PARTICIPANT	\N	PRESENT	0
282617	273890	19717B	PARTICIPANT	\N	PRESENT	0
282618	273890	19441R	PARTICIPANT	\N	PRESENT	0
282619	273890	14042U	PARTICIPANT	\N	PRESENT	0
282620	273890	19585H	PARTICIPANT	\N	PRESENT	0
282621	273890	04057K	PARTICIPANT	\N	PRESENT	0
282622	273890	08016S	PARTICIPANT	\N	PRESENT	0
282623	273890	19543W	PARTICIPANT	\N	PRESENT	0
282624	273890	14107H	PARTICIPANT	\N	PRESENT	0
282625	273890	08056B	PARTICIPANT	\N	PRESENT	0
282626	273890	19583F	PARTICIPANT	\N	PRESENT	0
282627	273890	19347U	PARTICIPANT	\N	PRESENT	0
282628	273890	19251M	PARTICIPANT	\N	PRESENT	0
282629	273890	01024M	PARTICIPANT	\N	PRESENT	0
282630	273890	16685X	PARTICIPANT	\N	PRESENT	0
282631	273890	14083S	PARTICIPANT	\N	PRESENT	0
282632	273890	14255U	PARTICIPANT	\N	PRESENT	0
282633	273890	19545Y	PARTICIPANT	\N	PRESENT	0
282634	273890	19758L	PARTICIPANT	\N	PRESENT	0
282635	273890	04088S	PARTICIPANT	\N	PRESENT	0
282636	273890	14031R	PARTICIPANT	\N	PRESENT	0
282637	273890	05008E	PARTICIPANT	\N	PRESENT	0
282638	273890	14179A	PARTICIPANT	\N	PRESENT	0
282639	273890	08031R	PARTICIPANT	\N	PRESENT	0
282640	273890	19329S	PARTICIPANT	\N	PRESENT	0
282641	273890	19349W	PARTICIPANT	\N	PRESENT	0
282642	273890	14111D	PARTICIPANT	\N	PRESENT	0
282643	273890	14030Q	PARTICIPANT	\N	PRESENT	0
282644	273890	14259Y	PARTICIPANT	\N	PRESENT	0
282645	273890	19629C	PARTICIPANT	\N	PRESENT	0
282646	273890	04038G	PARTICIPANT	\N	PRESENT	0
282647	273890	08018U	PARTICIPANT	\N	PRESENT	0
282648	273890	19681G	PARTICIPANT	\N	PRESENT	0
282649	273890	14041T	PARTICIPANT	\N	PRESENT	0
282650	273890	04070G	PARTICIPANT	\N	PRESENT	0
282651	273890	19525U	PARTICIPANT	\N	PRESENT	0
282652	273890	14267Y	PARTICIPANT	\N	PRESENT	0
282653	273890	01028R	PARTICIPANT	\N	PRESENT	0
282654	273890	11097X	PARTICIPANT	\N	PRESENT	0
282655	273890	19671E	PARTICIPANT	\N	PRESENT	0
282656	273890	04059M	PARTICIPANT	\N	PRESENT	0
282658	273890	19415P	PARTICIPANT	\N	PRESENT	0
282659	273890	08045X	PARTICIPANT	\N	PRESENT	0
282660	273890	14211G	PARTICIPANT	\N	PRESENT	0
282661	273890	19443T	PARTICIPANT	\N	PRESENT	0
282662	273890	14169X	PARTICIPANT	\N	PRESENT	0
282663	273890	19503N	PARTICIPANT	\N	PRESENT	0
282664	273890	10006L	PARTICIPANT	\N	PRESENT	0
282665	273890	19489J	PARTICIPANT	\N	PRESENT	0
282666	273890	14221J	PARTICIPANT	\N	PRESENT	0
282685	273890	14223L	PARTICIPANT	\N	PRESENT	0
282686	273890	11048N	PARTICIPANT	\N	PRESENT	0
282687	273890	08020N	PARTICIPANT	\N	PRESENT	0
282688	273890	04033B	PARTICIPANT	\N	PRESENT	0
282689	273890	19383Y	PARTICIPANT	\N	PRESENT	0
282690	273890	19253P	PARTICIPANT	\N	PRESENT	0
282691	273890	11067R	PARTICIPANT	\N	PRESENT	0
283735	281771	19479G	PARTICIPANT	\N	PRESENT	0
283736	281771	19711U	PARTICIPANT	\N	PRESENT	0
283737	281771	08011M	PARTICIPANT	\N	PRESENT	0
283738	281771	11074Q	PRESIDENT	0	PRESENT	0
283739	281771	14034U	PARTICIPANT	\N	PRESENT	0
283740	281771	88008L	PARTICIPANT	\N	PRESENT	0
283742	281771	14173T	PARTICIPANT	\N	PRESENT	0
275158	266861	19593H	PARTICIPANT	\N	PRESENT	0
275161	266863	19593H	PARTICIPANT	\N	PRESENT	0
275766	275765	14195A	PARTICIPANT	\N	EXCUSE	0
275767	275765	14327T	PARTICIPANT	\N	PRESENT	0
275768	275765	08045X	PARTICIPANT	\N	EXCUSE	0
275769	275765	19347U	PARTICIPANT	\N	PRESENT	0
275770	275765	95037J	PARTICIPANT	\N	PRESENT	0
275771	275765	14213J	PRESIDENT	0	PRESENT	0
275772	275765	19683J	PARTICIPANT	\N	PRESENT	0
275773	275765	11099A	PARTICIPANT	\N	PRESENT	0
275774	275765	04049K	PARTICIPANT	\N	PRESENT	0
275775	275765	08015R	PARTICIPANT	\N	PRESENT	0
275776	275765	08017T	PARTICIPANT	\N	PRESENT	0
275777	275765	19441R	PARTICIPANT	\N	EXCUSE	0
275778	275765	19369B	PARTICIPANT	\N	PRESENT	0
275779	275765	14109K	PARTICIPANT	\N	PRESENT	0
275780	275765	14169X	PARTICIPANT	\N	PRESENT	0
275781	275765	19503N	PARTICIPANT	\N	PRESENT	0
275782	275765	04045F	PARTICIPANT	\N	EXCUSE	0
275783	275765	08049C	PARTICIPANT	\N	EXCUSE	0
275784	275765	14173T	PARTICIPANT	\N	EXCUSE	0
275789	275788	14195A	PARTICIPANT	\N	EXCUSE	0
275790	275788	08045X	PARTICIPANT	\N	EXCUSE	0
275791	275788	14213J	PRESIDENT	0	PRESENT	0
275792	275788	11099A	PARTICIPANT	\N	PRESENT	0
275793	275788	04049K	PARTICIPANT	\N	EXCUSE	0
275794	275788	19441R	PARTICIPANT	\N	EXCUSE	0
275795	275788	14109K	PARTICIPANT	\N	PRESENT	0
275796	275788	14169X	PARTICIPANT	\N	PRESENT	0
275797	275788	19503N	PARTICIPANT	\N	PRESENT	0
275798	275788	04043D	PARTICIPANT	\N	PRESENT	0
275799	275788	04045F	PARTICIPANT	\N	EXCUSE	0
275800	275788	08049C	PARTICIPANT	\N	EXCUSE	0
275801	275788	14173T	PARTICIPANT	\N	EXCUSE	0
275802	275788	08017T	PARTICIPANT	\N	PRESENT	0
276060	276036	19333N	PARTICIPANT	\N	PRESENT	0
276061	276036	19383Y	PARTICIPANT	\N	PRESENT	0
276062	276036	14103D	PARTICIPANT	\N	PRESENT	0
276063	276036	19701S	PARTICIPANT	\N	PRESENT	0
276064	276036	95062K	PARTICIPANT	\N	PRESENT	0
276065	276036	08055A	PARTICIPANT	\N	PRESENT	0
276066	276036	19289C	PARTICIPANT	\N	PRESENT	0
276067	276036	14169X	PARTICIPANT	\N	PRESENT	0
276068	276036	19637C	PARTICIPANT	\N	PRESENT	0
276069	276036	19551W	PARTICIPANT	\N	PRESENT	0
276070	276036	15447F	PARTICIPANT	\N	PRESENT	0
276071	276036	14029X	PARTICIPANT	\N	PRESENT	0
276072	276036	19739H	PARTICIPANT	\N	PRESENT	0
276073	276036	11065P	PARTICIPANT	\N	PRESENT	0
276074	276036	19525U	PARTICIPANT	\N	PRESENT	0
276076	276036	19599P	PARTICIPANT	\N	PRESENT	0
276077	276036	08024S	PARTICIPANT	\N	PRESENT	0
276079	276036	19733B	PARTICIPANT	\N	PRESENT	0
276080	276036	19745F	PARTICIPANT	\N	PRESENT	0
276081	276028	11067R	PARTICIPANT	\N	PRESENT	0
276082	276028	04092N	PRESIDENT	0	PRESENT	0
276083	276028	14355X	PARTICIPANT	\N	PRESENT	0
276084	276028	08034U	PARTICIPANT	\N	PRESENT	0
276085	276028	11097X	PARTICIPANT	\N	PRESENT	0
276086	276028	19415P	PARTICIPANT	\N	PRESENT	0
276087	276028	19691J	PARTICIPANT	\N	PRESENT	0
276088	276028	19717B	PARTICIPANT	\N	PRESENT	0
276089	276028	14223L	PARTICIPANT	\N	PRESENT	0
276090	276028	19675J	PARTICIPANT	\N	PRESENT	0
276091	276028	17779H	PARTICIPANT	\N	PRESENT	0
276092	276028	19703U	PARTICIPANT	\N	PRESENT	0
276093	276028	07029T	PARTICIPANT	\N	PRESENT	0
276094	276028	14119M	PARTICIPANT	\N	PRESENT	0
276095	276028	14281W	PARTICIPANT	\N	PRESENT	0
276096	276028	19679N	PARTICIPANT	\N	PRESENT	0
276097	276028	14071N	PARTICIPANT	\N	PRESENT	0
276098	276028	14217N	PARTICIPANT	\N	PRESENT	0
276099	276028	08048B	PARTICIPANT	\N	EXCUSE	0
276100	276028	19715Y	PARTICIPANT	\N	EXCUSE	0
276128	276028	14087W	PARTICIPANT	\N	PRESENT	0
276129	276028	11031D	PARTICIPANT	\N	PRESENT	0
276130	276028	19723Y	PARTICIPANT	\N	PRESENT	0
276132	276036	14237S	PARTICIPANT	\N	PRESENT	0
276133	276038	86034E	PARTICIPANT	\N	PRESENT	0
276134	276038	19585H	PARTICIPANT	\N	PRESENT	0
276135	276038	19319Q	PARTICIPANT	\N	PRESENT	0
276136	276038	11103C	PARTICIPANT	\N	PRESENT	0
276137	276038	19675J	PARTICIPANT	\N	PRESENT	0
276138	276038	19583F	PARTICIPANT	\N	PRESENT	0
276139	276038	19349W	PARTICIPANT	\N	PRESENT	0
276140	276038	19525U	PARTICIPANT	\N	PRESENT	0
276141	276038	14281W	PARTICIPANT	\N	PRESENT	0
276142	276038	19333N	PARTICIPANT	\N	PRESENT	0
276143	276038	08055A	PARTICIPANT	\N	PRESENT	0
276144	276038	19387D	PARTICIPANT	\N	PRESENT	0
276145	276038	19737F	PARTICIPANT	\N	PRESENT	0
276146	276038	19441R	PARTICIPANT	\N	PRESENT	0
276147	276038	19739H	PARTICIPANT	\N	PRESENT	0
276148	276038	19745F	PARTICIPANT	\N	PRESENT	0
276149	276038	14111D	PARTICIPANT	\N	PRESENT	0
276150	276038	14277B	PARTICIPANT	\N	PRESENT	0
276151	276038	14201E	PARTICIPANT	\N	PRESENT	0
276152	276038	11066Q	PARTICIPANT	\N	PRESENT	0
276153	276038	17779H	PARTICIPANT	\N	PRESENT	0
276154	276038	19289C	PARTICIPANT	\N	PRESENT	0
276155	276038	98029W	PARTICIPANT	\N	PRESENT	0
276156	276038	04018C	PARTICIPANT	\N	PRESENT	0
276157	276038	14169X	PARTICIPANT	\N	PRESENT	0
276158	276038	15447F	PARTICIPANT	\N	PRESENT	0
276159	276038	14173T	PARTICIPANT	\N	PRESENT	0
276160	276038	19515S	PARTICIPANT	\N	PRESENT	0
276161	276038	19703U	PARTICIPANT	\N	PRESENT	0
276162	276038	19723Y	PARTICIPANT	\N	PRESENT	0
276163	276038	11040E	PARTICIPANT	\N	PRESENT	0
276164	276038	11054L	PARTICIPANT	\N	PRESENT	0
276165	276038	19717B	PARTICIPANT	\N	PRESENT	0
276166	276038	98022P	PARTICIPANT	\N	PRESENT	0
276167	276038	11067R	PARTICIPANT	\N	PRESENT	0
276168	276038	14051J	PARTICIPANT	\N	PRESENT	0
276169	276038	19413M	PARTICIPANT	\N	PRESENT	0
276170	276038	19503N	PARTICIPANT	\N	PRESENT	0
276171	276038	19599P	PARTICIPANT	\N	PRESENT	0
276172	276038	19727D	PARTICIPANT	\N	PRESENT	0
276173	276038	14028W	PARTICIPANT	\N	PRESENT	0
276174	276038	14195A	PARTICIPANT	\N	PRESENT	0
276175	276038	19659J	PARTICIPANT	\N	PRESENT	0
276176	276038	88008L	PARTICIPANT	\N	PRESENT	0
276177	276038	19253P	PARTICIPANT	\N	PRESENT	0
276178	276038	04040A	PARTICIPANT	\N	PRESENT	0
276179	276038	19695N	PARTICIPANT	\N	PRESENT	0
276180	276038	19565D	PARTICIPANT	\N	PRESENT	0
276181	276038	14197C	PARTICIPANT	\N	PRESENT	0
276182	276038	08053X	PARTICIPANT	\N	PRESENT	0
276183	276038	11033F	PARTICIPANT	\N	PRESENT	0
276184	276038	11027H	PARTICIPANT	\N	PRESENT	0
276185	276038	08024S	PARTICIPANT	\N	PRESENT	0
276186	276038	08052W	PARTICIPANT	\N	PRESENT	0
276187	276038	08060W	PARTICIPANT	\N	PRESENT	0
276188	276038	04085P	PARTICIPANT	\N	PRESENT	0
276189	276038	11056N	PARTICIPANT	\N	PRESENT	0
276190	276038	14211G	PARTICIPANT	\N	PRESENT	0
276191	276038	12041X	PARTICIPANT	\N	PRESENT	0
276192	276038	14135M	PARTICIPANT	\N	PRESENT	0
276193	276038	19347U	PARTICIPANT	\N	PRESENT	0
276194	276038	17637T	PARTICIPANT	\N	PRESENT	0
276195	276038	19679N	PARTICIPANT	\N	PRESENT	0
276196	276038	19711U	PARTICIPANT	\N	PRESENT	0
276197	276038	19593H	PARTICIPANT	\N	PRESENT	0
276198	276038	11101A	PARTICIPANT	\N	PRESENT	0
276199	276038	19689Q	PARTICIPANT	\N	PRESENT	0
276200	276038	04035D	PARTICIPANT	\N	PRESENT	0
276201	276038	95062K	PARTICIPANT	\N	PRESENT	0
276202	276038	14239U	PARTICIPANT	\N	PRESENT	0
276203	276038	08061X	PARTICIPANT	\N	PRESENT	0
276204	276038	95037J	PARTICIPANT	\N	PRESENT	0
276205	276038	04045F	PARTICIPANT	\N	PRESENT	0
276206	276038	19543W	PARTICIPANT	\N	PRESENT	0
276207	276038	11083R	PARTICIPANT	\N	PRESENT	0
276208	276038	19697Q	PARTICIPANT	\N	PRESENT	0
276209	276038	14157T	PARTICIPANT	\N	PRESENT	0
276210	276038	08073C	PARTICIPANT	\N	PRESENT	0
276211	276038	14039A	PARTICIPANT	\N	PRESENT	0
276212	276038	96004D	PARTICIPANT	\N	PRESENT	0
276213	276038	01058X	PARTICIPANT	\N	PRESENT	0
276214	276038	04057K	PARTICIPANT	\N	PRESENT	0
276215	276038	99004R	PARTICIPANT	\N	PRESENT	0
276216	276038	02002K	PARTICIPANT	\N	PRESENT	0
276217	276038	95030B	PARTICIPANT	\N	PRESENT	0
274989	263759	11054L	PARTICIPANT	\N	PRESENT	0
274990	263759	11027H	PARTICIPANT	\N	PRESENT	0
274991	263759	19251M	PARTICIPANT	\N	PRESENT	0
274992	263759	08058D	PARTICIPANT	\N	PRESENT	0
274993	263759	11066Q	PARTICIPANT	\N	PRESENT	0
274994	263759	14097Y	PARTICIPANT	\N	PRESENT	0
274995	263759	98029W	PARTICIPANT	\N	PRESENT	0
274996	263759	95037J	PARTICIPANT	\N	PRESENT	0
274997	263759	19719D	PARTICIPANT	\N	PRESENT	0
274998	263759	19583F	PARTICIPANT	\N	PRESENT	0
274999	263759	19319Q	PARTICIPANT	\N	PRESENT	0
275000	263759	19691J	PARTICIPANT	\N	PRESENT	0
275001	263759	19479G	PARTICIPANT	\N	PRESENT	0
275002	263759	08047A	PARTICIPANT	\N	PRESENT	0
275003	263759	14267Y	PARTICIPANT	\N	PRESENT	0
275004	263759	19737F	PARTICIPANT	\N	PRESENT	0
275005	263759	08056B	PARTICIPANT	\N	PRESENT	0
275006	263759	98050T	PARTICIPANT	\N	PRESENT	0
275007	263759	01062T	PARTICIPANT	\N	PRESENT	0
275008	263759	14079W	PARTICIPANT	\N	PRESENT	0
275009	263759	19679N	PARTICIPANT	\N	PRESENT	0
275013	263759	01057W	PARTICIPANT	\N	PRESENT	0
275011	263759	98018T	PARTICIPANT	\N	PRESENT	0
275012	263759	01058X	PARTICIPANT	\N	PRESENT	0
275014	263759	19421M	PARTICIPANT	\N	PRESENT	0
275015	263759	19447X	PARTICIPANT	\N	PRESENT	0
275016	263759	95030B	PARTICIPANT	\N	PRESENT	0
275017	263759	19565D	PARTICIPANT	\N	PRESENT	0
275018	263759	14235Q	PARTICIPANT	\N	PRESENT	0
275019	263759	04040A	PARTICIPANT	\N	PRESENT	0
275020	263759	19367Y	PARTICIPANT	\N	PRESENT	0
275021	263759	19709B	PARTICIPANT	\N	PRESENT	0
275022	263759	01024M	PARTICIPANT	\N	PRESENT	0
275023	263759	04034C	PARTICIPANT	\N	PRESENT	0
275024	263759	14083S	PARTICIPANT	\N	PRESENT	0
275025	263759	11064N	PARTICIPANT	\N	PRESENT	0
275026	263759	14069U	PARTICIPANT	\N	PRESENT	0
275027	263759	14053L	PARTICIPANT	\N	PRESENT	0
275028	263759	19573D	PARTICIPANT	\N	PRESENT	0
275029	263759	19521Q	PARTICIPANT	\N	PRESENT	0
275030	263759	08034U	PARTICIPANT	\N	PRESENT	0
275031	263759	08061X	PARTICIPANT	\N	PRESENT	0
275032	263759	14147R	PARTICIPANT	\N	PRESENT	0
275033	263759	14030Q	PARTICIPANT	\N	PRESENT	0
275034	263759	08053X	PARTICIPANT	\N	PRESENT	0
275035	263759	19563B	PARTICIPANT	\N	PRESENT	0
275036	263759	14133K	PARTICIPANT	\N	PRESENT	0
275037	263759	14261S	PARTICIPANT	\N	PRESENT	0
275038	263759	14255U	PARTICIPANT	\N	PRESENT	0
275042	263759	19467C	PARTICIPANT	\N	PRESENT	0
275040	263759	14213J	PARTICIPANT	\N	PRESENT	0
275041	263759	14187A	PARTICIPANT	\N	PRESENT	0
275043	263759	19575F	PARTICIPANT	\N	PRESENT	0
275044	263759	14265W	PARTICIPANT	\N	PRESENT	0
275045	263759	14033T	PARTICIPANT	\N	PRESENT	0
275046	263759	19507S	PARTICIPANT	\N	PRESENT	0
275047	263759	19383Y	PARTICIPANT	\N	PRESENT	0
275048	263759	19669L	PARTICIPANT	\N	PRESENT	0
275049	263759	14357A	PARTICIPANT	\N	PRESENT	0
275050	263759	11097X	PARTICIPANT	\N	PRESENT	0
275051	263759	04088S	PARTICIPANT	\N	PRESENT	0
275052	263759	19733B	PARTICIPANT	\N	PRESENT	0
275053	263759	14253S	PARTICIPANT	\N	PRESENT	0
275054	263759	08015R	PARTICIPANT	\N	PRESENT	0
275055	263759	14135M	PARTICIPANT	\N	PRESENT	0
275056	263759	19621T	PARTICIPANT	\N	PRESENT	0
281406	281404	04008A	PARTICIPANT	\N	PRESENT	0
281759	281678	08045X	PARTICIPANT	\N	PRESENT	0
281760	281678	14215L	PARTICIPANT	\N	EXCUSE	0
274987	263759	11070L	PARTICIPANT	\N	PRESENT	0
274988	263759	04042C	PARTICIPANT	\N	PRESENT	0
281958	273883	08011M	PARTICIPANT	\N	PRESENT	0
282030	273883	04071H	PARTICIPANT	\N	PRESENT	0
282013	273883	86034E	PARTICIPANT	\N	PRESENT	0
281961	273883	14187A	PARTICIPANT	\N	PRESENT	0
281962	273883	14123H	PARTICIPANT	\N	PRESENT	0
281963	273883	04044E	PARTICIPANT	\N	PRESENT	0
281964	273883	04086Q	PARTICIPANT	\N	PRESENT	0
281965	273883	14119M	PARTICIPANT	\N	PRESENT	0
282059	273883	19531S	PARTICIPANT	\N	PRESENT	0
281967	273883	07034Q	PARTICIPANT	\N	PRESENT	0
281968	273883	19581D	PARTICIPANT	\N	PRESENT	0
281969	273883	10015M	PARTICIPANT	\N	PRESENT	0
281970	273883	95067Q	PARTICIPANT	\N	PRESENT	0
281972	273883	19707Y	PARTICIPANT	\N	PRESENT	0
281973	273883	11090Q	PARTICIPANT	\N	PRESENT	0
281974	273883	19741B	PARTICIPANT	\N	PRESENT	0
281975	273883	19507S	PARTICIPANT	\N	PRESENT	0
281976	273883	08015R	PARTICIPANT	\N	PRESENT	0
281977	273883	98050T	PARTICIPANT	\N	PRESENT	0
281978	273883	08018U	PARTICIPANT	\N	PRESENT	0
281979	273883	14213J	PARTICIPANT	\N	PRESENT	0
281980	273883	08053X	PARTICIPANT	\N	PRESENT	0
281981	273883	19447X	PARTICIPANT	\N	PRESENT	0
281982	273883	19367Y	PARTICIPANT	\N	PRESENT	0
281983	273883	04043D	PARTICIPANT	\N	PRESENT	0
281984	273883	08062Y	PARTICIPANT	\N	PRESENT	0
281985	273883	14329V	PARTICIPANT	\N	PRESENT	0
281986	273883	19701S	PARTICIPANT	\N	PRESENT	0
281987	273883	19545Y	PARTICIPANT	\N	PRESENT	0
281988	273883	04057K	PARTICIPANT	\N	PRESENT	0
281989	273883	08068F	PARTICIPANT	\N	PRESENT	0
281990	273883	14029X	PARTICIPANT	\N	PRESENT	0
281991	273883	04049K	PARTICIPANT	\N	PRESENT	0
281992	273883	14071N	PARTICIPANT	\N	PRESENT	0
281993	273883	14061L	PARTICIPANT	\N	PRESENT	0
281994	273883	14357A	PARTICIPANT	\N	PRESENT	0
281995	273883	19503N	PARTICIPANT	\N	PRESENT	0
282000	273883	19749K	PARTICIPANT	\N	PRESENT	0
281997	273883	14255U	PARTICIPANT	\N	PRESENT	0
281998	273883	14041T	PARTICIPANT	\N	PRESENT	0
281999	273883	14217N	PARTICIPANT	\N	PRESENT	0
282001	273883	10006L	PARTICIPANT	\N	PRESENT	0
282002	273883	19621T	PARTICIPANT	\N	PRESENT	0
282003	273883	04061F	PARTICIPANT	\N	PRESENT	0
282004	273883	19467C	PARTICIPANT	\N	PRESENT	0
282005	273883	14089Y	PARTICIPANT	\N	PRESENT	0
282006	273883	08034U	PARTICIPANT	\N	PRESENT	0
282007	273883	11049P	PARTICIPANT	\N	PRESENT	0
282008	273883	14191V	PARTICIPANT	\N	PRESENT	0
282009	273883	14034U	PARTICIPANT	\N	PRESENT	0
282010	273883	19729F	PARTICIPANT	\N	PRESENT	0
282011	273883	19657G	PARTICIPANT	\N	PRESENT	0
282012	273883	99004R	PARTICIPANT	\N	PRESENT	0
282014	273883	19671E	PARTICIPANT	\N	PRESENT	0
282015	273883	19573D	PARTICIPANT	\N	PRESENT	0
282016	273883	19705W	PARTICIPANT	\N	PRESENT	0
282017	273883	19675J	PARTICIPANT	\N	PRESENT	0
282018	273883	01058X	PARTICIPANT	\N	PRESENT	0
282058	273883	11053K	PARTICIPANT	\N	PRESENT	0
282041	273883	14069U	PARTICIPANT	\N	PRESENT	0
282054	273883	89017R	PARTICIPANT	\N	PRESENT	0
282060	273883	11099A	PARTICIPANT	\N	PRESENT	0
282061	273883	19709B	PARTICIPANT	\N	PRESENT	0
282062	273883	19347U	PARTICIPANT	\N	PRESENT	0
282292	273884	04044E	PARTICIPANT	\N	PRESENT	0
282301	273884	19583F	PARTICIPANT	\N	PRESENT	0
282299	273884	19711U	PARTICIPANT	\N	PRESENT	0
282300	273884	19253P	PARTICIPANT	\N	PRESENT	0
282302	273884	14219Q	PARTICIPANT	\N	PRESENT	0
282303	273884	14195A	PARTICIPANT	\N	PRESENT	0
282304	273884	04018C	PARTICIPANT	\N	PRESENT	0
282305	273884	98050T	PARTICIPANT	\N	PRESENT	0
282306	273884	04049K	PARTICIPANT	\N	PRESENT	0
282307	273884	14253S	PARTICIPANT	\N	PRESENT	0
282308	273884	14121F	PARTICIPANT	\N	PRESENT	0
282309	273884	19507S	PARTICIPANT	\N	PRESENT	0
282310	273884	14115H	PARTICIPANT	\N	PRESENT	0
282311	273884	14026U	PARTICIPANT	\N	PRESENT	0
282312	273884	14157T	PARTICIPANT	\N	PRESENT	0
282313	273884	19295A	PARTICIPANT	\N	PRESENT	0
282314	273884	11074Q	PARTICIPANT	\N	PRESENT	0
282315	273884	14159V	PARTICIPANT	\N	PRESENT	0
282316	273884	14119M	PARTICIPANT	\N	PRESENT	0
282317	273884	14327T	PARTICIPANT	\N	PRESENT	0
282318	273884	18083K	PARTICIPANT	\N	PRESENT	0
282319	273884	04092N	PARTICIPANT	\N	PRESENT	0
282320	273884	19687N	PARTICIPANT	\N	PRESENT	0
282321	273884	19367Y	PARTICIPANT	\N	PRESENT	0
282322	273884	08073C	PARTICIPANT	\N	PRESENT	0
282323	273884	19701S	PARTICIPANT	\N	PRESENT	0
282324	273884	08069G	PARTICIPANT	\N	PRESENT	0
282325	273884	19671E	PARTICIPANT	\N	PRESENT	0
282326	273884	11066Q	PARTICIPANT	\N	PRESENT	0
282327	273884	19545Y	PARTICIPANT	\N	PRESENT	0
282334	273884	04057K	PARTICIPANT	\N	PRESENT	0
282335	273884	14357A	PARTICIPANT	\N	PRESENT	0
282336	273884	04045F	PARTICIPANT	\N	PRESENT	0
282337	273884	19631V	PARTICIPANT	\N	PRESENT	0
273397	273396	14079W	PARTICIPANT	\N	PRESENT	0
273535	273533	19741B	PARTICIPANT	\N	PRESENT	0
273536	273533	08043V	PARTICIPANT	\N	PRESENT	0
273537	273533	04038G	PARTICIPANT	\N	PRESENT	0
273538	273533	19253P	PARTICIPANT	\N	PRESENT	0
273539	273533	11070L	PRESIDENT	0	PRESENT	0
273540	273533	04097T	PARTICIPANT	\N	PRESENT	0
273541	273533	19711U	PARTICIPANT	\N	PRESENT	0
273542	273533	12016W	PARTICIPANT	\N	PRESENT	0
273543	273533	17637T	PARTICIPANT	\N	PRESENT	0
273544	273533	19689Q	PARTICIPANT	\N	PRESENT	0
273545	273533	11041F	PARTICIPANT	\N	PRESENT	0
273546	273533	95062K	PARTICIPANT	\N	EXCUSE	0
273548	273547	96004D	PRESIDENT	0	PRESENT	0
273549	273547	14089Y	PARTICIPANT	\N	EXCUSE	0
273550	273547	08014Q	PARTICIPANT	\N	PRESENT	0
273551	273547	14079W	PARTICIPANT	\N	PRESENT	0
273552	273547	04035D	PARTICIPANT	\N	PRESENT	0
273553	273547	11083R	PARTICIPANT	\N	PRESENT	0
273554	273547	14033T	PARTICIPANT	\N	PRESENT	0
273555	273547	19725B	PARTICIPANT	\N	PRESENT	0
273556	273547	95037J	PARTICIPANT	\N	PRESENT	0
273557	273547	19569H	PARTICIPANT	\N	EXCUSE	0
273558	273547	04097T	PARTICIPANT	\N	PRESENT	0
273559	273547	14097Y	PARTICIPANT	\N	PRESENT	0
273560	273547	14073Q	PARTICIPANT	\N	PRESENT	0
273561	273547	14205J	PARTICIPANT	\N	PRESENT	0
273566	273547	10015M	PARTICIPANT	\N	PRESENT	0
273563	273547	04057K	PARTICIPANT	\N	PRESENT	0
273564	273547	19563B	PARTICIPANT	\N	PRESENT	0
273565	273547	14135M	PARTICIPANT	\N	PRESENT	0
273567	273547	98035U	PARTICIPANT	\N	PRESENT	0
273568	273547	11026G	PARTICIPANT	\N	EXCUSE	0
273569	273547	04061F	PARTICIPANT	\N	EXCUSE	0
273570	273547	14331P	PARTICIPANT	\N	EXCUSE	0
273600	273599	14133K	PARTICIPANT	\N	PRESENT	0
273601	273599	08058D	PARTICIPANT	\N	PRESENT	0
275172	273857	08028W	PARTICIPANT	\N	PRESENT	0
275173	273857	08068F	PARTICIPANT	\N	PRESENT	0
275174	273857	14237S	PARTICIPANT	\N	PRESENT	0
275177	273857	14257W	PARTICIPANT	\N	PRESENT	0
275189	275187	08028W	PARTICIPANT	\N	PRESENT	0
275191	275187	08068F	PARTICIPANT	\N	PRESENT	0
275192	275187	14257W	PARTICIPANT	\N	PRESENT	0
275214	275213	14065Q	PARTICIPANT	\N	EXCUSE	0
275215	275213	96004D	PRESIDENT	0	PRESENT	0
275216	275213	14089Y	PARTICIPANT	\N	PRESENT	0
275217	275213	08014Q	PARTICIPANT	\N	EXCUSE	0
275218	275213	14357A	PARTICIPANT	\N	PRESENT	0
275219	275213	08018U	PARTICIPANT	\N	EXCUSE	0
275220	275213	11083R	PARTICIPANT	\N	PRESENT	0
275221	275213	19725B	PARTICIPANT	\N	PRESENT	0
275222	275213	19569H	PARTICIPANT	\N	PRESENT	0
275223	275213	04097T	PARTICIPANT	\N	EXCUSE	0
275224	275213	04061F	PARTICIPANT	\N	PRESENT	0
275225	275213	11026G	PARTICIPANT	\N	PRESENT	0
275238	275234	08018U	PARTICIPANT	\N	EXCUSE	0
275227	275213	19593H	PARTICIPANT	\N	PRESENT	0
275228	275213	19563B	PARTICIPANT	\N	PRESENT	0
275229	275213	14237S	PARTICIPANT	\N	PRESENT	0
275230	275213	14225N	PARTICIPANT	\N	PRESENT	0
275231	275213	10015M	PARTICIPANT	\N	PRESENT	0
275232	275213	14135M	PARTICIPANT	\N	EXCUSE	0
275233	275213	14001X	PARTICIPANT	\N	PRESENT	0
275235	275234	14065Q	PARTICIPANT	\N	EXCUSE	0
275236	275213	14079W	PARTICIPANT	\N	PRESENT	0
275237	275234	08014Q	PARTICIPANT	\N	EXCUSE	0
275239	275234	04097T	PARTICIPANT	\N	EXCUSE	0
275240	275234	14135M	PARTICIPANT	\N	EXCUSE	0
275241	275234	96004D	PRESIDENT	0	PRESENT	0
275242	275234	14089Y	PARTICIPANT	\N	PRESENT	0
275243	275234	14357A	PARTICIPANT	\N	PRESENT	0
275244	275234	14079W	PARTICIPANT	\N	PRESENT	0
275245	275234	11083R	PARTICIPANT	\N	PRESENT	0
275246	275234	14033T	PARTICIPANT	\N	PRESENT	0
275247	275234	19725B	PARTICIPANT	\N	PRESENT	0
275248	275234	19569H	PARTICIPANT	\N	PRESENT	0
275253	275234	19563B	PARTICIPANT	\N	PRESENT	0
275250	275234	11026G	PARTICIPANT	\N	PRESENT	0
275251	275234	14001X	PARTICIPANT	\N	PRESENT	0
275252	275234	14221J	PARTICIPANT	\N	PRESENT	0
275254	275234	04057K	PARTICIPANT	\N	PRESENT	0
275255	275234	14237S	PARTICIPANT	\N	PRESENT	0
275256	275234	14225N	PARTICIPANT	\N	PRESENT	0
275257	275234	14229S	PARTICIPANT	\N	PRESENT	0
275258	275234	10015M	PARTICIPANT	\N	PRESENT	0
275259	275234	11074Q	PARTICIPANT	\N	PRESENT	0
275260	275234	08011M	PARTICIPANT	\N	PRESENT	0
275261	275234	19687N	PARTICIPANT	\N	PRESENT	0
275262	275234	11048N	PARTICIPANT	\N	PRESENT	0
275263	275234	14083S	PARTICIPANT	\N	PRESENT	0
275264	275234	19479G	PARTICIPANT	\N	PRESENT	0
275265	275234	19741B	PARTICIPANT	\N	PRESENT	0
275266	275234	19689Q	PARTICIPANT	\N	PRESENT	0
275267	275234	19711U	PARTICIPANT	\N	PRESENT	0
275268	275234	14121F	PARTICIPANT	\N	PRESENT	0
275269	275234	19531S	PARTICIPANT	\N	PRESENT	0
275883	273310	04092N	PARTICIPANT	\N	PRESENT	0
275884	273310	14213J	PARTICIPANT	\N	PRESENT	0
275885	273310	11097X	PARTICIPANT	\N	PRESENT	0
275886	273310	04097T	PARTICIPANT	\N	PRESENT	0
275887	273310	01024M	PARTICIPANT	\N	PRESENT	0
275888	273310	95030B	PARTICIPANT	\N	PRESENT	0
275889	273310	19667J	PARTICIPANT	\N	PRESENT	0
275890	273310	19515S	PARTICIPANT	\N	PRESENT	0
275891	273310	14187A	PARTICIPANT	\N	PRESENT	0
275892	273310	14038Y	PARTICIPANT	\N	PRESENT	0
275893	273310	19467C	PARTICIPANT	\N	PRESENT	0
275894	273310	14357A	PARTICIPANT	\N	PRESENT	0
275896	275895	14026U	PARTICIPANT	\N	PRESENT	0
275898	275897	14026U	PARTICIPANT	\N	PRESENT	0
275900	275899	10006L	PARTICIPANT	\N	PRESENT	0
275902	275901	10006L	PARTICIPANT	\N	PRESENT	0
276021	276020	11074Q	PARTICIPANT	\N	PRESENT	0
276022	276020	14239U	PARTICIPANT	\N	PRESENT	0
276023	276020	04043D	PARTICIPANT	\N	PRESENT	0
276024	276020	14255U	PARTICIPANT	\N	PRESENT	0
299641	289192	14119M	PARTICIPANT	\N	PRESENT	0
299642	289192	04049K	PARTICIPANT	\N	PRESENT	0
299643	289192	05012A	PARTICIPANT	\N	PRESENT	0
299644	289192	11101A	PARTICIPANT	\N	PRESENT	0
299645	289192	14083S	PARTICIPANT	\N	PRESENT	0
299646	289192	19749K	PARTICIPANT	\N	PRESENT	0
299647	289192	19383Y	PARTICIPANT	\N	PRESENT	0
299648	289192	10006L	PARTICIPANT	\N	PRESENT	0
299649	289192	19507S	PARTICIPANT	\N	PRESENT	0
299650	289192	14033T	PARTICIPANT	\N	PRESENT	0
299651	289192	18083K	PARTICIPANT	\N	PRESENT	0
299652	289192	14199E	PARTICIPANT	\N	PRESENT	0
299653	289192	19693L	PARTICIPANT	\N	PRESENT	0
299654	289192	14069U	PARTICIPANT	\N	PRESENT	0
299655	289192	08034U	PARTICIPANT	\N	PRESENT	0
299656	289192	11065P	PARTICIPANT	\N	PRESENT	0
299657	289192	14215L	PARTICIPANT	\N	PRESENT	0
299658	289192	02002K	PARTICIPANT	\N	PRESENT	0
299659	289192	14225N	PARTICIPANT	\N	PRESENT	0
299660	289192	14147R	PARTICIPANT	\N	PRESENT	0
299661	289192	14235Q	PARTICIPANT	\N	PRESENT	0
299662	289192	19301E	PARTICIPANT	\N	PRESENT	0
299663	289192	08062Y	PARTICIPANT	\N	PRESENT	0
299664	289192	04033B	PARTICIPANT	\N	PRESENT	0
299665	289192	08015R	PARTICIPANT	\N	PRESENT	0
299666	289192	14034U	PARTICIPANT	\N	PRESENT	0
299667	289192	17637T	PARTICIPANT	\N	PRESENT	0
299668	289192	19447X	PARTICIPANT	\N	PRESENT	0
299669	289192	19563B	PARTICIPANT	\N	PRESENT	0
299670	289192	14241N	PARTICIPANT	\N	PRESENT	0
299671	299357	19515S	PARTICIPANT	\N	PRESENT	0
299672	299357	14357A	PARTICIPANT	\N	PRESENT	0
299673	299357	19413M	PARTICIPANT	\N	PRESENT	0
299674	299357	19631V	PARTICIPANT	\N	PRESENT	0
299675	299357	08068F	PARTICIPANT	\N	PRESENT	0
299676	299357	04049K	PARTICIPANT	\N	PRESENT	0
299677	299357	08015R	PARTICIPANT	\N	PRESENT	0
299678	299357	08019V	PARTICIPANT	\N	PRESENT	0
299679	299357	14197C	PARTICIPANT	\N	PRESENT	0
299680	299357	19511N	PARTICIPANT	\N	PRESENT	0
299681	299357	08028W	PARTICIPANT	\N	PRESENT	0
299682	299357	14265W	PARTICIPANT	\N	PRESENT	0
299683	299357	14329V	PARTICIPANT	\N	PRESENT	0
299684	299357	14187A	PARTICIPANT	\N	PRESENT	0
299685	299357	08038Y	PARTICIPANT	\N	PRESENT	0
299686	299357	08062Y	PARTICIPANT	\N	PRESENT	0
299687	299357	19301E	PARTICIPANT	\N	PRESENT	0
299688	299357	11090Q	PRESIDENT	0	PRESENT	0
299689	299357	01025N	PARTICIPANT	\N	PRESENT	0
299690	299357	04088S	PARTICIPANT	\N	PRESENT	0
299691	299357	11101A	PARTICIPANT	\N	PRESENT	0
299692	299357	19507S	PARTICIPANT	\N	PRESENT	0
282464	282463	19649G	PARTICIPANT	\N	PRESENT	0
282465	282463	14111D	PARTICIPANT	\N	PRESENT	0
282466	282463	07034Q	PARTICIPANT	\N	PRESENT	0
282467	282463	14147R	PARTICIPANT	\N	PRESENT	0
282468	282463	01024M	PARTICIPANT	\N	PRESENT	0
282469	282463	19581D	PARTICIPANT	\N	PRESENT	0
282470	282463	11033F	PARTICIPANT	\N	PRESENT	0
282471	282463	05008E	PRESIDENT	0	PRESENT	0
282472	282463	19697Q	PARTICIPANT	\N	PRESENT	0
282473	282463	04035D	PARTICIPANT	\N	PRESENT	0
282474	282463	19701S	PARTICIPANT	\N	PRESENT	0
282475	282463	19693L	PARTICIPANT	\N	PRESENT	0
282476	282463	19269X	PARTICIPANT	\N	PRESENT	0
282477	282463	14030Q	PARTICIPANT	\N	PRESENT	0
282478	282463	14251Q	PARTICIPANT	\N	PRESENT	0
282479	282463	19503N	PARTICIPANT	\N	PRESENT	0
282480	282463	11083R	PARTICIPANT	\N	PRESENT	0
282481	282463	19621T	PARTICIPANT	\N	PRESENT	0
282482	282463	14089Y	PARTICIPANT	\N	EXCUSE	0
282483	282463	19729F	PARTICIPANT	\N	EXCUSE	0
282484	282463	14065Q	PARTICIPANT	\N	EXCUSE	0
282485	282463	14179A	PARTICIPANT	\N	EXCUSE	0
282486	282463	11085T	PARTICIPANT	\N	EXCUSE	0
282487	282463	04047H	PARTICIPANT	\N	EXCUSE	0
282488	282463	14041T	PARTICIPANT	\N	EXCUSE	0
282489	282463	08031R	PARTICIPANT	\N	PRESENT	0
283743	281771	11040E	PARTICIPANT	\N	PRESENT	0
283744	281771	07029T	PARTICIPANT	\N	PRESENT	0
283745	281771	14085U	PARTICIPANT	\N	PRESENT	0
283746	281771	07004J	PARTICIPANT	\N	PRESENT	0
283747	281771	19349W	PARTICIPANT	\N	PRESENT	0
283748	281771	19741B	PARTICIPANT	\N	PRESENT	0
283749	273896	19489J	PARTICIPANT	\N	PRESENT	0
283750	273896	14001X	PARTICIPANT	\N	PRESENT	0
283751	273896	14051J	PARTICIPANT	\N	PRESENT	0
283752	273896	08060W	PARTICIPANT	\N	PRESENT	0
283753	273896	19543W	PARTICIPANT	\N	PRESENT	0
283754	273896	19651A	PARTICIPANT	\N	PRESENT	0
283755	273896	19629C	PARTICIPANT	\N	PRESENT	0
283756	281771	08010L	PARTICIPANT	\N	EXCUSE	0
283757	281771	19687N	PARTICIPANT	\N	EXCUSE	0
283758	273896	01028R	PARTICIPANT	\N	PRESENT	0
283759	273896	19549D	PARTICIPANT	\N	PRESENT	0
283760	273896	19551W	PARTICIPANT	\N	PRESENT	0
283761	273896	19347U	PARTICIPANT	\N	PRESENT	0
283762	273896	19545Y	PARTICIPANT	\N	PRESENT	0
283763	273896	14241N	PARTICIPANT	\N	PRESENT	0
283764	273896	14231L	PARTICIPANT	\N	PRESENT	0
283765	273896	14327T	PARTICIPANT	\N	PRESENT	0
283766	273896	01024M	PARTICIPANT	\N	PRESENT	0
283767	273896	14073Q	PARTICIPANT	\N	PRESENT	0
283768	273896	95062K	PARTICIPANT	\N	PRESENT	0
283769	273896	14123H	PARTICIPANT	\N	PRESENT	0
283770	273896	19573D	PARTICIPANT	\N	PRESENT	0
283771	273896	19415P	PARTICIPANT	\N	PRESENT	0
283772	273896	19657G	PARTICIPANT	\N	PRESENT	0
283773	273896	97011G	PARTICIPANT	\N	PRESENT	0
283774	273896	11103C	PARTICIPANT	\N	PRESENT	0
283775	273896	01058X	PARTICIPANT	\N	PRESENT	0
283776	273896	19583F	PARTICIPANT	\N	PRESENT	0
283777	273896	11012A	PARTICIPANT	\N	PRESENT	0
283778	273896	14251Q	PARTICIPANT	\N	PRESENT	0
283779	273896	08061X	PARTICIPANT	\N	PRESENT	0
283780	273896	14105F	PARTICIPANT	\N	PRESENT	0
283781	273896	19553Y	PARTICIPANT	\N	PRESENT	0
283782	273896	19335Q	PARTICIPANT	\N	PRESENT	0
283783	273896	14061L	PARTICIPANT	\N	PRESENT	0
283784	273896	19447X	PARTICIPANT	\N	PRESENT	0
283785	273896	18083K	PARTICIPANT	\N	PRESENT	0
283786	273896	14119M	PARTICIPANT	\N	PRESENT	0
283787	273896	14157T	PARTICIPANT	\N	PRESENT	0
283788	273896	19383Y	PARTICIPANT	\N	PRESENT	0
283789	273896	19733B	PARTICIPANT	\N	PRESENT	0
283790	273896	14026U	PARTICIPANT	\N	PRESENT	0
283791	273896	08034U	PARTICIPANT	\N	PRESENT	0
283792	273896	19533U	PARTICIPANT	\N	PRESENT	0
283793	273896	10006L	PARTICIPANT	\N	PRESENT	0
283794	273896	14069U	PARTICIPANT	\N	PRESENT	0
283795	273896	14053L	PARTICIPANT	\N	PRESENT	0
283796	273896	14215L	PARTICIPANT	\N	PRESENT	0
283797	273896	04038G	PARTICIPANT	\N	PRESENT	0
283798	273896	14079W	PARTICIPANT	\N	PRESENT	0
283799	273896	19367Y	PARTICIPANT	\N	PRESENT	0
283800	273896	14211G	PARTICIPANT	\N	PRESENT	0
283801	273896	04018C	PARTICIPANT	\N	PRESENT	0
283802	273896	95030B	PARTICIPANT	\N	PRESENT	0
283803	273896	17583W	PARTICIPANT	\N	PRESENT	0
283804	273896	05008E	PARTICIPANT	\N	PRESENT	0
283805	273896	14259Y	PARTICIPANT	\N	PRESENT	0
283806	273896	14169X	PARTICIPANT	\N	PRESENT	0
283808	273896	14097Y	PARTICIPANT	\N	PRESENT	0
283809	273896	14179A	PARTICIPANT	\N	PRESENT	0
283810	273896	19569H	PARTICIPANT	\N	PRESENT	0
283811	273896	19739H	PARTICIPANT	\N	PRESENT	0
283812	273896	08016S	PARTICIPANT	\N	PRESENT	0
283813	273896	19691J	PARTICIPANT	\N	PRESENT	0
283814	273896	11043H	PARTICIPANT	\N	PRESENT	0
283815	273896	19703U	PARTICIPANT	\N	PRESENT	0
283816	273896	14029X	PARTICIPANT	\N	PRESENT	0
283817	273896	14041T	PARTICIPANT	\N	PRESENT	0
283818	273896	11097X	PARTICIPANT	\N	PRESENT	0
283819	273896	14213J	PARTICIPANT	\N	PRESENT	0
283820	273896	04085P	PARTICIPANT	\N	PRESENT	0
283823	273896	19758L	PARTICIPANT	\N	PRESENT	0
283824	273896	14038Y	PARTICIPANT	\N	PRESENT	0
283825	273896	19723Y	PARTICIPANT	\N	PRESENT	0
283828	273896	17637T	PARTICIPANT	\N	PRESENT	0
283829	273896	14223L	PARTICIPANT	\N	PRESENT	0
283830	273896	19507S	PARTICIPANT	\N	PRESENT	0
283831	273896	19585H	PARTICIPANT	\N	PRESENT	0
283832	273896	19503N	PARTICIPANT	\N	PRESENT	0
283833	273896	89017R	PARTICIPANT	\N	PRESENT	0
283834	273896	14083S	PARTICIPANT	\N	PRESENT	0
283835	281771	11048N	PARTICIPANT	\N	PRESENT	0
283836	281771	89017R	PARTICIPANT	\N	PRESENT	0
283837	281771	14225N	PARTICIPANT	\N	PRESENT	0
283838	281771	14083S	PARTICIPANT	\N	PRESENT	0
283839	281771	19667J	PARTICIPANT	\N	PRESENT	0
283840	281771	08014Q	PARTICIPANT	\N	EXCUSE	0
283841	273896	14195A	PARTICIPANT	\N	PRESENT	0
283842	273896	19349W	PARTICIPANT	\N	PRESENT	0
283843	273896	14021P	PARTICIPANT	\N	PRESENT	0
283844	273896	08009T	PARTICIPANT	\N	PRESENT	0
283845	273896	14329V	PARTICIPANT	\N	PRESENT	0
283858	273896	11067R	PARTICIPANT	\N	PRESENT	0
283859	273896	11056N	PARTICIPANT	\N	PRESENT	0
283860	273896	14357A	PARTICIPANT	\N	PRESENT	0
283861	273896	14031R	PARTICIPANT	\N	PRESENT	0
283862	273896	19621T	PARTICIPANT	\N	PRESENT	0
283863	273896	19399H	PARTICIPANT	\N	PRESENT	0
283864	273896	19711U	PARTICIPANT	\N	PRESENT	0
283865	273896	19575F	PARTICIPANT	\N	PRESENT	0
283866	273896	11048N	PARTICIPANT	\N	PRESENT	0
283867	273896	08056B	PARTICIPANT	\N	PRESENT	0
283868	273896	19725B	PARTICIPANT	\N	PRESENT	0
283869	273896	14217N	PARTICIPANT	\N	PRESENT	0
283870	273896	14199E	PARTICIPANT	\N	PRESENT	0
283871	273896	19673G	PARTICIPANT	\N	PRESENT	0
283872	273896	14042U	PARTICIPANT	\N	PRESENT	0
283886	273896	04047H	PARTICIPANT	\N	PRESENT	0
283887	273896	04033B	PARTICIPANT	\N	PRESENT	0
283888	273896	19333N	PARTICIPANT	\N	PRESENT	0
283889	273896	14193X	PARTICIPANT	\N	PRESENT	0
283890	273896	07029T	PARTICIPANT	\N	PRESENT	0
283891	273896	19253P	PARTICIPANT	\N	PRESENT	0
283892	273896	19713W	PARTICIPANT	\N	PRESENT	0
283893	273896	14034U	PARTICIPANT	\N	PRESENT	0
283894	273896	14030Q	PARTICIPANT	\N	PRESENT	0
271935	271934	19631V	PARTICIPANT	\N	PRESENT	0
271936	271934	19515S	PARTICIPANT	\N	PRESENT	0
271937	271934	19707Y	PARTICIPANT	\N	PRESENT	0
271938	271934	11081P	PARTICIPANT	\N	EXCUSE	0
271939	271934	14115H	PARTICIPANT	\N	PRESENT	0
271940	271934	19747H	PARTICIPANT	\N	PRESENT	0
271941	271934	08068F	PARTICIPANT	\N	PRESENT	0
271942	271934	14207L	PARTICIPANT	\N	PRESENT	0
271943	271934	11101A	PARTICIPANT	\N	PRESENT	0
271944	271934	14329V	PARTICIPANT	\N	PRESENT	0
271945	271934	08028W	PARTICIPANT	\N	PRESENT	0
271946	271934	19467C	PARTICIPANT	\N	PRESENT	0
271947	271934	19295A	PARTICIPANT	\N	PRESENT	0
271948	271934	80013X	PARTICIPANT	\N	PRESENT	0
271949	271934	14357A	PARTICIPANT	\N	PRESENT	0
271950	271934	08038Y	PARTICIPANT	\N	PRESENT	0
271951	271934	17589D	PARTICIPANT	\N	PRESENT	0
271952	271934	04089T	PARTICIPANT	\N	EXCUSE	0
271953	271934	19507S	PARTICIPANT	\N	PRESENT	0
271954	271934	14197C	PARTICIPANT	\N	PRESENT	0
271955	271934	14187A	PARTICIPANT	\N	PRESENT	0
271956	271934	01025N	PARTICIPANT	\N	PRESENT	0
271957	271934	19695N	PARTICIPANT	\N	PRESENT	0
271958	271934	19565D	PARTICIPANT	\N	PRESENT	0
271959	271934	14033T	PARTICIPANT	\N	PRESENT	0
271960	271934	19511N	PARTICIPANT	\N	PRESENT	0
271961	271934	11099A	PARTICIPANT	\N	PRESENT	0
271962	271934	04049K	PARTICIPANT	\N	EXCUSE	0
272406	271234	19367Y	PARTICIPANT	\N	PRESENT	0
271964	271934	14205J	PARTICIPANT	\N	PRESENT	0
271965	271934	19441R	PARTICIPANT	\N	PRESENT	0
271966	271934	08015R	PARTICIPANT	\N	PRESENT	0
271967	271934	08062Y	PARTICIPANT	\N	PRESENT	0
271968	271934	19563B	PARTICIPANT	\N	PRESENT	0
271969	271934	19369B	PARTICIPANT	\N	PRESENT	0
271970	271934	14257W	PARTICIPANT	\N	PRESENT	0
271971	271934	14265W	PARTICIPANT	\N	PRESENT	0
271972	271934	08021P	PARTICIPANT	\N	PRESENT	0
271973	271934	11090Q	PRESIDENT	0	PRESENT	0
271974	271934	04088S	PARTICIPANT	\N	PRESENT	0
271975	271934	14135M	PARTICIPANT	\N	PRESENT	0
271976	271934	19705W	PARTICIPANT	\N	PRESENT	0
271977	271934	19301E	PARTICIPANT	\N	PRESENT	0
271978	271934	19413M	PARTICIPANT	\N	PRESENT	0
271979	271934	19619A	PARTICIPANT	\N	PRESENT	0
272407	271234	14195A	PARTICIPANT	\N	PRESENT	0
272408	271234	19295A	PRESIDENT	0	PRESENT	0
272409	271234	19253P	PARTICIPANT	\N	PRESENT	0
272410	271234	14041T	PARTICIPANT	\N	PRESENT	0
272411	271234	14217N	PARTICIPANT	\N	PRESENT	0
272412	271234	14087W	PARTICIPANT	\N	PRESENT	0
272413	271234	19697Q	PARTICIPANT	\N	PRESENT	0
272414	271234	14147R	PARTICIPANT	\N	PRESENT	0
272415	271234	14223L	PARTICIPANT	\N	PRESENT	0
272416	271234	14119M	PARTICIPANT	\N	PRESENT	0
272417	271234	04044E	PARTICIPANT	\N	EXCUSE	0
272599	272597	08043V	PARTICIPANT	\N	PRESENT	0
272600	272597	04018C	PARTICIPANT	\N	PRESENT	0
272601	272597	19749K	PARTICIPANT	\N	PRESENT	0
272404	271234	14239U	PARTICIPANT	\N	PRESENT	0
272602	272597	19643A	PARTICIPANT	\N	PRESENT	0
272606	272605	08043V	PARTICIPANT	\N	PRESENT	0
272607	272605	04018C	PARTICIPANT	\N	PRESENT	0
272608	272605	19749K	PARTICIPANT	\N	PRESENT	0
272609	272605	14109K	PARTICIPANT	\N	PRESENT	0
273888	273666	19703U	PARTICIPANT	\N	EXCUSE	0
273889	273666	19583F	PARTICIPANT	\N	EXCUSE	0
273891	273667	19583F	PARTICIPANT	\N	EXCUSE	0
273893	273668	19583F	PARTICIPANT	\N	EXCUSE	0
274868	274867	08052W	PARTICIPANT	\N	PRESENT	0
274869	274867	10006L	PARTICIPANT	\N	PRESENT	0
272405	271234	14065Q	PARTICIPANT	\N	EXCUSE	0
274870	274867	19553Y	PARTICIPANT	\N	PRESENT	0
276218	276038	04047H	PARTICIPANT	\N	PRESENT	0
276219	276038	14026U	PARTICIPANT	\N	PRESENT	0
276220	276038	11099A	PARTICIPANT	\N	PRESENT	0
276221	276038	04097T	PARTICIPANT	\N	PRESENT	0
276222	276038	08039A	PARTICIPANT	\N	PRESENT	0
276223	276038	08020N	PARTICIPANT	\N	PRESENT	0
276224	276038	14241N	PARTICIPANT	\N	PRESENT	0
276225	276038	08010L	PARTICIPANT	\N	PRESENT	0
276226	276038	19563B	PARTICIPANT	\N	PRESENT	0
276227	276038	19629C	PARTICIPANT	\N	PRESENT	0
276228	276038	95015C	PARTICIPANT	\N	PRESENT	0
276230	276038	08049C	PARTICIPANT	\N	PRESENT	0
276231	276038	04042C	PARTICIPANT	\N	PRESENT	0
276232	276038	14261S	PARTICIPANT	\N	PRESENT	0
276233	276038	11012A	PARTICIPANT	\N	PRESENT	0
276234	276038	08016S	PARTICIPANT	\N	PRESENT	0
276235	276038	19553Y	PARTICIPANT	\N	PRESENT	0
276236	276038	04086Q	PARTICIPANT	\N	PRESENT	0
276237	276038	08031R	PARTICIPANT	\N	PRESENT	0
276238	276038	04092N	PARTICIPANT	\N	PRESENT	0
276239	276038	14034U	PARTICIPANT	\N	PRESENT	0
276240	276038	98018T	PARTICIPANT	\N	PRESENT	0
276241	276038	04044E	PARTICIPANT	\N	PRESENT	0
276242	276038	19681G	PARTICIPANT	\N	PRESENT	0
276243	276038	89017R	PARTICIPANT	\N	PRESENT	0
276244	276038	14055N	PARTICIPANT	\N	PRESENT	0
276245	276038	19643A	PARTICIPANT	\N	PRESENT	0
276246	276038	19685L	PARTICIPANT	\N	PRESENT	0
276247	276038	19731Y	PARTICIPANT	\N	PRESENT	0
276248	276038	01060R	PARTICIPANT	\N	PRESENT	0
276249	276038	04071H	PARTICIPANT	\N	PRESENT	0
276250	276038	19719D	PARTICIPANT	\N	PRESENT	0
276251	276038	11109J	PARTICIPANT	\N	PRESENT	0
276252	276038	14223L	PARTICIPANT	\N	PRESENT	0
276253	276038	19631V	PARTICIPANT	\N	PRESENT	0
276254	276038	10015M	PARTICIPANT	\N	PRESENT	0
276255	276038	14065Q	PARTICIPANT	\N	PRESENT	0
276256	276038	19549D	PARTICIPANT	\N	PRESENT	0
276257	276038	11043H	PARTICIPANT	\N	PRESENT	0
276258	276038	08028W	PARTICIPANT	\N	PRESENT	0
276259	276038	11031D	PARTICIPANT	\N	PRESENT	0
276260	276038	14235Q	PARTICIPANT	\N	PRESENT	0
276261	276038	01048V	PARTICIPANT	\N	PRESENT	0
276262	276038	19531S	PARTICIPANT	\N	PRESENT	0
276263	276038	04033B	PARTICIPANT	\N	PRESENT	0
276264	276038	19683J	PARTICIPANT	\N	PRESENT	0
276265	276038	14071N	PARTICIPANT	\N	PRESENT	0
276266	276038	98035U	PARTICIPANT	\N	PRESENT	0
276267	276038	11077T	PARTICIPANT	\N	PRESENT	0
276268	276038	04059M	PARTICIPANT	\N	PRESENT	0
276269	276038	05008E	PARTICIPANT	\N	PRESENT	0
276270	276038	11074Q	PARTICIPANT	\N	PRESENT	0
276271	276038	01028R	PARTICIPANT	\N	PRESENT	0
276272	276038	14159V	PARTICIPANT	\N	PRESENT	0
276273	276038	14021P	PARTICIPANT	\N	PRESENT	0
276274	276038	08045X	PARTICIPANT	\N	PRESENT	0
276275	276038	14225N	PARTICIPANT	\N	PRESENT	0
276276	276038	19421M	PARTICIPANT	\N	PRESENT	0
276277	276038	14229S	PARTICIPANT	\N	PRESENT	0
276278	276038	11097X	PARTICIPANT	\N	PRESENT	0
276279	276038	14257W	PARTICIPANT	\N	PRESENT	0
276280	276038	08058D	PARTICIPANT	\N	PRESENT	0
276281	276038	14085U	PARTICIPANT	\N	PRESENT	0
276282	276038	14207L	PARTICIPANT	\N	PRESENT	0
276283	276038	14121F	PARTICIPANT	\N	PRESENT	0
276284	276038	14215L	PARTICIPANT	\N	PRESENT	0
276285	276038	19489J	PARTICIPANT	\N	PRESENT	0
276286	276038	14087W	PARTICIPANT	\N	PRESENT	0
276287	276038	19647E	PARTICIPANT	\N	PRESENT	0
276288	276038	14053L	PARTICIPANT	\N	PRESENT	0
276289	276038	19591F	PARTICIPANT	\N	PRESENT	0
276290	276038	19551W	PARTICIPANT	\N	PRESENT	0
276291	276038	11090Q	PARTICIPANT	\N	PRESENT	0
276292	276038	19527W	PARTICIPANT	\N	PRESENT	0
276293	276038	14063N	PARTICIPANT	\N	PRESENT	0
276294	276038	14001X	PARTICIPANT	\N	PRESENT	0
276295	276038	14109K	PARTICIPANT	\N	PRESENT	0
276296	276038	87003B	PARTICIPANT	\N	PRESENT	0
276297	276038	14097Y	PARTICIPANT	\N	PRESENT	0
276299	276038	14259Y	PARTICIPANT	\N	PRESENT	0
276300	276038	19329S	PARTICIPANT	\N	PRESENT	0
276301	276038	19637C	PARTICIPANT	\N	PRESENT	0
276302	276038	08069G	PARTICIPANT	\N	PRESENT	0
276303	276038	14191V	PARTICIPANT	\N	PRESENT	0
276304	276038	08017T	PARTICIPANT	\N	PRESENT	0
276305	276038	19669L	PARTICIPANT	\N	PRESENT	0
276306	276038	01062T	PARTICIPANT	\N	PRESENT	0
276307	276038	14107H	PARTICIPANT	\N	PRESENT	0
276308	276038	11045K	PARTICIPANT	\N	PRESENT	0
276309	276038	19673G	PARTICIPANT	\N	PRESENT	0
276310	276038	11104D	PARTICIPANT	\N	PRESENT	0
276311	276038	14031R	PARTICIPANT	\N	PRESENT	0
276312	276038	11072N	PARTICIPANT	\N	PRESENT	0
276313	276038	19725B	PARTICIPANT	\N	PRESENT	0
276314	276036	14219Q	PARTICIPANT	\N	PRESENT	0
282338	273884	04061F	PARTICIPANT	\N	PRESENT	0
282339	273884	19467C	PARTICIPANT	\N	PRESENT	0
282341	273884	19657G	PARTICIPANT	\N	PRESENT	0
282343	273884	11077T	PARTICIPANT	\N	PRESENT	0
282344	273884	11067R	PARTICIPANT	\N	PRESENT	0
282345	273884	19667J	PARTICIPANT	\N	PRESENT	0
282346	273884	14255U	PARTICIPANT	\N	PRESENT	0
282347	273884	14083S	PARTICIPANT	\N	PRESENT	0
282348	273884	19697Q	PARTICIPANT	\N	PRESENT	0
282349	273884	19695N	PARTICIPANT	\N	PRESENT	0
282350	273884	04043D	PARTICIPANT	\N	PRESENT	0
282351	273884	19713W	PARTICIPANT	\N	PRESENT	0
282352	273884	01024M	PARTICIPANT	\N	PRESENT	0
282353	273884	19691J	PARTICIPANT	\N	PRESENT	0
282360	273884	98005N	PARTICIPANT	\N	PRESENT	0
282361	273884	01058X	PARTICIPANT	\N	PRESENT	0
282362	273884	14034U	PARTICIPANT	\N	PRESENT	0
284824	284823	14239U	PARTICIPANT	\N	PRESENT	0
284825	284823	19549D	PARTICIPANT	\N	PRESENT	0
284877	284823	19295A	PARTICIPANT	\N	PRESENT	0
284879	284823	14217N	PARTICIPANT	\N	PRESENT	0
284880	284823	14215L	PARTICIPANT	\N	PRESENT	0
284881	284823	19691J	PARTICIPANT	\N	PRESENT	0
284882	284823	14031R	PARTICIPANT	\N	EXCUSE	0
284883	284823	14119M	PARTICIPANT	\N	PRESENT	0
284884	284823	11045K	PARTICIPANT	0	PRESENT	0
284885	284823	04044E	PRESIDENT	0	PRESENT	0
285172	285171	04008A	PARTICIPANT	\N	PRESENT	0
285175	285174	04008A	PARTICIPANT	\N	PRESENT	0
285178	285177	04008A	PARTICIPANT	\N	PRESENT	0
285180	285179	04008A	PARTICIPANT	\N	PRESENT	0
285183	285182	04008A	PARTICIPANT	\N	PRESENT	0
286241	286240	04038G	PARTICIPANT	\N	PRESENT	0
286242	286240	14357A	PARTICIPANT	\N	PRESENT	0
286243	286240	11070L	PRESIDENT	0	PRESENT	0
286244	286240	19711U	PARTICIPANT	\N	PRESENT	0
286245	286240	04097T	PARTICIPANT	\N	EXCUSE	0
286246	286240	19531S	PARTICIPANT	\N	EXCUSE	0
286331	285992	11040E	PARTICIPANT	\N	PRESENT	0
286332	285992	14085U	PARTICIPANT	\N	PRESENT	0
286333	285992	04086Q	PARTICIPANT	\N	PRESENT	0
286334	285992	11070L	PARTICIPANT	\N	PRESENT	0
286335	285992	14327T	PARTICIPANT	\N	EXCUSE	0
286336	285992	11074Q	PRESIDENT	0	PRESENT	0
286337	285992	14121F	PARTICIPANT	\N	PRESENT	0
286338	285992	99004R	PARTICIPANT	\N	PRESENT	0
286339	285992	14159V	PARTICIPANT	\N	PRESENT	0
286340	285992	19711U	PARTICIPANT	\N	PRESENT	0
286341	285992	08010L	PARTICIPANT	\N	PRESENT	0
286342	285992	08014Q	PARTICIPANT	\N	EXCUSE	0
286343	285992	89017R	PARTICIPANT	\N	EXCUSE	0
286344	285992	19531S	PARTICIPANT	\N	EXCUSE	0
286345	285992	19689Q	PARTICIPANT	\N	PRESENT	0
286346	285992	14225N	PARTICIPANT	\N	PRESENT	0
286347	285992	14331P	PARTICIPANT	\N	PRESENT	0
286348	285992	19671E	PARTICIPANT	\N	PRESENT	0
286349	285992	19741B	PARTICIPANT	\N	PRESENT	0
287668	287666	14221J	PARTICIPANT	\N	PRESENT	0
286351	285992	11053K	PARTICIPANT	\N	PRESENT	0
286352	285992	04061F	PARTICIPANT	\N	PRESENT	0
286353	285992	08011M	PARTICIPANT	\N	PRESENT	0
286354	285992	07029T	PARTICIPANT	\N	EXCUSE	0
287667	287666	19725B	PARTICIPANT	\N	PRESENT	0
287983	287982	95015C	PARTICIPANT	\N	PRESENT	0
287984	287982	08043V	PARTICIPANT	\N	PRESENT	0
287985	287982	19727D	PARTICIPANT	\N	PRESENT	0
287986	287982	19565D	PARTICIPANT	\N	PRESENT	0
287987	287982	11067R	PARTICIPANT	\N	PRESENT	0
287988	287982	19441R	PARTICIPANT	\N	PRESENT	0
287989	287982	19669L	PARTICIPANT	\N	PRESENT	0
287990	287982	14065Q	PARTICIPANT	\N	PRESENT	0
288340	288339	95015C	PARTICIPANT	\N	PRESENT	0
288341	288339	19575F	PARTICIPANT	\N	PRESENT	0
288342	288339	19545Y	PARTICIPANT	\N	PRESENT	0
288343	288339	19565D	PARTICIPANT	\N	PRESENT	0
288344	288339	08017T	PARTICIPANT	\N	PRESENT	0
288345	288339	11083R	PARTICIPANT	\N	PRESENT	0
289116	287976	19631V	PARTICIPANT	\N	PRESENT	0
289117	287976	19515S	PARTICIPANT	\N	PRESENT	0
289118	287976	19707Y	PARTICIPANT	\N	PRESENT	0
289119	287976	11081P	PARTICIPANT	\N	EXCUSE	0
289169	287976	01025N	PARTICIPANT	\N	EXCUSE	0
289121	287976	19747H	PARTICIPANT	\N	PRESENT	0
289122	287976	08068F	PARTICIPANT	\N	PRESENT	0
289123	287976	14207L	PARTICIPANT	\N	PRESENT	0
289124	287976	11101A	PARTICIPANT	\N	PRESENT	0
289170	287976	19369B	PARTICIPANT	\N	EXCUSE	0
289171	287976	08021P	PARTICIPANT	\N	EXCUSE	0
289127	287976	19467C	PARTICIPANT	\N	PRESENT	0
289172	287976	14135M	PARTICIPANT	\N	EXCUSE	0
289129	287976	80013X	PARTICIPANT	\N	PRESENT	0
289130	287976	11056N	PARTICIPANT	\N	PRESENT	0
292360	289102	11070L	PARTICIPANT	\N	PRESENT	0
292363	289102	04042C	PARTICIPANT	\N	PRESENT	0
292364	289102	14207L	PARTICIPANT	\N	PRESENT	0
292365	289102	19333N	PARTICIPANT	\N	PRESENT	0
289135	287976	19507S	PARTICIPANT	\N	PRESENT	0
289136	287976	14197C	PARTICIPANT	\N	PRESENT	0
289137	287976	14187A	PARTICIPANT	\N	PRESENT	0
292366	289102	14235Q	PARTICIPANT	\N	PRESENT	0
289139	287976	19695N	PARTICIPANT	\N	PRESENT	0
289140	287976	19565D	PARTICIPANT	\N	PRESENT	0
289141	287976	14033T	PRESIDENT	0	PRESENT	0
289142	287976	14081Q	PARTICIPANT	\N	PRESENT	0
289143	287976	19591F	PARTICIPANT	\N	PRESENT	0
289144	287976	19511N	PARTICIPANT	\N	PRESENT	0
289145	287976	11099A	PARTICIPANT	\N	EXCUSE	0
289146	287976	04049K	PARTICIPANT	\N	PRESENT	0
289147	287976	08015R	PARTICIPANT	\N	PRESENT	0
292367	289102	11099A	PARTICIPANT	\N	PRESENT	0
289149	287976	14205J	PARTICIPANT	\N	PRESENT	0
292368	289102	14257W	PARTICIPANT	\N	PRESENT	0
292369	289102	19349W	PARTICIPANT	\N	PRESENT	0
292370	289102	11027H	PARTICIPANT	\N	PRESENT	0
292371	289102	19441R	PARTICIPANT	\N	PRESENT	0
292372	289102	01025N	PARTICIPANT	\N	PRESENT	0
289155	287976	14257W	PARTICIPANT	\N	PRESENT	0
289156	287976	14265W	PARTICIPANT	\N	PRESENT	0
292373	289102	16685X	PARTICIPANT	\N	PRESENT	0
289158	287976	04088S	PARTICIPANT	\N	PRESENT	0
289159	287976	11090Q	PARTICIPANT	\N	EXCUSE	0
292374	289102	98050T	PARTICIPANT	\N	PRESENT	0
292375	289102	14123H	PARTICIPANT	\N	PRESENT	0
292376	289102	08061X	PARTICIPANT	\N	PRESENT	0
289163	287976	19705W	PARTICIPANT	\N	PRESENT	0
292377	289102	01058X	PARTICIPANT	\N	PRESENT	0
292378	289102	98018T	PARTICIPANT	\N	PRESENT	0
289166	287976	19413M	PARTICIPANT	\N	PRESENT	0
292379	289102	19443T	PARTICIPANT	\N	PRESENT	0
292380	289102	04088S	PARTICIPANT	\N	PRESENT	0
292381	289102	17583W	PARTICIPANT	\N	PRESENT	0
292382	289102	19737F	PARTICIPANT	\N	PRESENT	0
292383	289102	14133K	PARTICIPANT	\N	PRESENT	0
292384	289102	14079W	PARTICIPANT	\N	PRESENT	0
292389	289102	19741B	PARTICIPANT	\N	PRESENT	0
292386	289102	11012A	PARTICIPANT	\N	PRESENT	0
292387	289102	19387D	PARTICIPANT	\N	PRESENT	0
292388	289102	14097Y	PARTICIPANT	\N	PRESENT	0
292390	289102	11097X	PARTICIPANT	\N	PRESENT	0
292391	289102	14107H	PARTICIPANT	\N	PRESENT	0
292392	289102	14069U	PARTICIPANT	\N	PRESENT	0
292393	289102	14021P	PARTICIPANT	\N	PRESENT	0
292397	289102	04040A	PARTICIPANT	\N	PRESENT	0
292399	289102	95063L	PARTICIPANT	\N	PRESENT	0
292403	289102	95062K	PARTICIPANT	\N	PRESENT	0
292404	289102	19507S	PARTICIPANT	\N	PRESENT	0
292415	289102	11054L	PARTICIPANT	\N	PRESENT	0
292433	289102	14255U	PARTICIPANT	\N	PRESENT	0
292435	289102	19447X	PARTICIPANT	\N	PRESENT	0
292437	289102	80013X	PARTICIPANT	\N	PRESENT	0
292438	289102	14215L	PARTICIPANT	\N	PRESENT	0
292456	289102	19695N	PARTICIPANT	\N	PRESENT	0
292458	289102	19413M	PARTICIPANT	\N	PRESENT	0
292464	289102	14033T	PARTICIPANT	\N	PRESENT	0
292465	289102	19383Y	PARTICIPANT	\N	PRESENT	0
292466	289102	17589D	PARTICIPANT	\N	PRESENT	0
292504	289102	08010L	PARTICIPANT	\N	PRESENT	0
292509	289102	19563B	PARTICIPANT	\N	PRESENT	0
273604	273602	11074Q	PARTICIPANT	\N	PRESENT	0
273605	273602	19651A	PARTICIPANT	\N	PRESENT	0
273613	270980	08024S	PARTICIPANT	\N	PRESENT	0
273614	270980	99004R	PARTICIPANT	\N	PRESENT	0
275841	275840	19549D	PARTICIPANT	\N	PRESENT	0
277648	277645	14239U	PARTICIPANT	\N	PRESENT	0
277649	277645	19295A	PARTICIPANT	\N	EXCUSE	0
277650	277645	14217N	PARTICIPANT	\N	PRESENT	0
277651	277645	14215L	PARTICIPANT	\N	PRESENT	0
277652	277645	11067R	PARTICIPANT	\N	PRESENT	0
277653	277645	04044E	PRESIDENT	0	PRESENT	0
278255	275134	04035D	PARTICIPANT	\N	EXCUSE	0
278256	275134	08056B	PARTICIPANT	\N	EXCUSE	0
278257	275134	19583F	PARTICIPANT	\N	EXCUSE	0
279121	279119	14255U	PARTICIPANT	\N	PRESENT	0
279107	279105	07033P	PARTICIPANT	\N	PRESENT	0
279120	279119	08053X	PARTICIPANT	\N	PRESENT	0
279122	279119	14225N	PARTICIPANT	\N	PRESENT	0
279123	279119	18083K	PARTICIPANT	\N	PRESENT	0
279124	279119	19447X	PARTICIPANT	\N	PRESENT	0
279147	279146	08038Y	PARTICIPANT	\N	PRESENT	0
279148	279146	14115H	PARTICIPANT	\N	PRESENT	0
279149	279146	14225N	PARTICIPANT	\N	PRESENT	0
279150	279146	14105F	PARTICIPANT	\N	PRESENT	0
299700	297489	19697Q	PARTICIPANT	\N	PRESENT	0
299701	297489	14239U	PARTICIPANT	\N	PRESENT	0
299702	297489	11067R	PARTICIPANT	\N	PRESENT	0
299703	297489	04092N	PRESIDENT	0	PRESENT	0
299704	297489	19679N	PARTICIPANT	\N	PRESENT	0
299705	297489	08052W	PARTICIPANT	\N	PRESENT	0
299706	297489	14195A	PARTICIPANT	\N	PRESENT	0
299707	297489	19335Q	PARTICIPANT	\N	PRESENT	0
299708	297489	14227Q	PARTICIPANT	\N	PRESENT	0
299709	297489	19760E	PARTICIPANT	\N	PRESENT	0
299710	297489	11045K	PARTICIPANT	\N	PRESENT	0
299711	297489	14223L	PARTICIPANT	\N	PRESENT	0
299693	299357	19747H	PARTICIPANT	\N	PRESENT	0
299694	299357	14207L	PARTICIPANT	\N	PRESENT	0
299695	299357	04043D	PARTICIPANT	\N	PRESENT	0
299696	299357	14257W	PARTICIPANT	\N	PRESENT	0
299697	299357	04008A	PARTICIPANT	\N	PRESENT	0
299698	299357	08021P	PARTICIPANT	\N	EXCUSE	0
299699	299357	11081P	PARTICIPANT	\N	EXCUSE	0
299712	297489	17779H	PARTICIPANT	\N	PRESENT	0
299713	297489	19703U	PARTICIPANT	\N	PRESENT	0
299714	297489	11103C	PARTICIPANT	\N	PRESENT	0
299715	297489	19367Y	PARTICIPANT	\N	PRESENT	0
299716	297489	14213J	PARTICIPANT	\N	PRESENT	0
299717	297489	98024R	PARTICIPANT	\N	PRESENT	0
299718	297489	19521Q	PARTICIPANT	\N	PRESENT	0
299719	297489	14281W	PARTICIPANT	\N	PRESENT	0
299720	299311	04070G	PARTICIPANT	\N	PRESENT	0
299721	299311	19699S	PARTICIPANT	\N	PRESENT	0
299722	299311	19533U	PARTICIPANT	\N	PRESENT	0
299723	299311	95015C	PRESIDENT	0	PRESENT	0
299724	299311	04033B	PARTICIPANT	\N	PRESENT	0
299725	299311	14229S	PARTICIPANT	\N	PRESENT	0
299726	299311	14241N	PARTICIPANT	\N	PRESENT	0
299727	299311	19573D	PARTICIPANT	\N	PRESENT	0
299728	299311	14039A	PARTICIPANT	\N	PRESENT	0
299729	299311	14107H	PARTICIPANT	\N	PRESENT	0
299730	299311	08017T	PARTICIPANT	\N	PRESENT	0
299731	299311	07033P	PARTICIPANT	\N	PRESENT	0
299732	299311	08012N	PARTICIPANT	\N	PRESENT	0
299733	299311	08018U	PARTICIPANT	\N	PRESENT	0
299734	299311	14249W	PARTICIPANT	\N	PRESENT	0
299735	299311	08039A	PARTICIPANT	\N	PRESENT	0
299736	299311	19593H	PARTICIPANT	\N	PRESENT	0
299737	299311	19643A	PARTICIPANT	\N	PRESENT	0
299738	299311	14059S	PARTICIPANT	\N	PRESENT	0
299739	299311	04057K	PARTICIPANT	\N	PRESENT	0
299740	299311	14073Q	PARTICIPANT	\N	PRESENT	0
299741	299311	19611R	PARTICIPANT	\N	PRESENT	0
299742	299311	08043V	PARTICIPANT	\N	PRESENT	0
299743	299311	19399H	PARTICIPANT	\N	PRESENT	0
299744	299311	14030Q	PARTICIPANT	\N	PRESENT	0
299745	299311	14251Q	PARTICIPANT	\N	PRESENT	0
299746	299311	04059M	PARTICIPANT	\N	PRESENT	0
299747	299311	19735D	PARTICIPANT	\N	PRESENT	0
299748	299311	11109J	PARTICIPANT	\N	PRESENT	0
299749	299311	14063N	PARTICIPANT	\N	PRESENT	0
299750	299311	11083R	PARTICIPANT	\N	PRESENT	0
299751	299311	14109K	PARTICIPANT	\N	PRESENT	0
299752	299311	11043H	PARTICIPANT	\N	PRESENT	0
299753	299311	11104D	PARTICIPANT	\N	PRESENT	0
299754	299311	19749K	PARTICIPANT	\N	PRESENT	0
299755	299311	04018C	PARTICIPANT	\N	PRESENT	0
299756	299311	19758L	PARTICIPANT	\N	PRESENT	0
299757	299311	19621T	PARTICIPANT	\N	PRESENT	0
299758	297489	11097X	PARTICIPANT	\N	PRESENT	0
299759	297489	14119M	PARTICIPANT	\N	PRESENT	0
299760	297489	14026U	PARTICIPANT	\N	PRESENT	0
299761	297489	10006L	PARTICIPANT	\N	PRESENT	0
299762	297489	14071N	PARTICIPANT	\N	PRESENT	0
299763	297489	19575F	PARTICIPANT	\N	EXCUSE	0
299764	297489	08041T	PARTICIPANT	\N	EXCUSE	0
299765	297489	14217N	PARTICIPANT	\N	PRESENT	0
299766	297489	01034P	PARTICIPANT	\N	PRESENT	0
299767	299311	19693L	PARTICIPANT	\N	PRESENT	0
299768	299311	08031R	PARTICIPANT	\N	EXCUSE	0
299769	297489	14042U	PARTICIPANT	\N	PRESENT	0
299770	297489	19727D	PARTICIPANT	\N	PRESENT	0
299804	298280	14199E	PARTICIPANT	\N	PRESENT	0
299805	298280	04061F	PARTICIPANT	\N	PRESENT	0
299806	299357	01043Q	PARTICIPANT	\N	PRESENT	0
299807	299357	19441R	PARTICIPANT	\N	PRESENT	0
299808	299357	80013X	PARTICIPANT	\N	PRESENT	0
299809	299357	11099A	PARTICIPANT	\N	PRESENT	0
299810	299357	19369B	PARTICIPANT	\N	PRESENT	0
299811	299357	14033T	PARTICIPANT	\N	PRESENT	0
299812	299357	14205J	PARTICIPANT	\N	PRESENT	0
299813	299357	19619A	PARTICIPANT	\N	PRESENT	0
299815	299814	04061F	PARTICIPANT	\N	PRESENT	0
299819	299818	04070G	PARTICIPANT	\N	PRESENT	0
299820	299818	14030Q	PARTICIPANT	\N	PRESENT	0
299821	299818	14357A	PARTICIPANT	\N	PRESENT	0
299822	299818	19421M	PARTICIPANT	\N	PRESENT	0
299823	299818	95067Q	PARTICIPANT	\N	PRESENT	0
299825	299824	04070G	PARTICIPANT	\N	PRESENT	0
299826	299824	14357A	PARTICIPANT	\N	PRESENT	0
299827	299824	19421M	PARTICIPANT	\N	PRESENT	0
299828	299824	14030Q	PARTICIPANT	\N	PRESENT	0
299829	299824	19735D	PARTICIPANT	\N	PRESENT	0
299830	299824	04018C	PARTICIPANT	\N	PRESENT	0
299831	299824	95067Q	PARTICIPANT	\N	PRESENT	0
299832	299824	11026G	PARTICIPANT	\N	PRESENT	0
299833	299824	14255U	PARTICIPANT	\N	PRESENT	0
299838	299311	14123H	PARTICIPANT	\N	EXCUSE	0
299839	299315	19593H	PARTICIPANT	\N	PRESENT	0
299840	299315	04070G	PRESIDENT	0	PRESENT	0
299841	299315	14059S	PARTICIPANT	\N	PRESENT	0
299842	299315	19699S	PARTICIPANT	\N	PRESENT	0
299843	299315	04057K	PARTICIPANT	\N	PRESENT	0
299844	299315	19611R	PARTICIPANT	\N	PRESENT	0
299845	299315	95015C	PARTICIPANT	\N	PRESENT	0
299846	299315	08043V	PARTICIPANT	\N	PRESENT	0
299847	299315	19693L	PARTICIPANT	\N	PRESENT	0
299848	299315	19399H	PARTICIPANT	\N	PRESENT	0
299849	299315	14229S	PARTICIPANT	\N	PRESENT	0
299850	299315	14030Q	PARTICIPANT	\N	PRESENT	0
299851	299315	14241N	PARTICIPANT	\N	PRESENT	0
299852	299315	19573D	PARTICIPANT	\N	PRESENT	0
299853	299315	04059M	PARTICIPANT	\N	PRESENT	0
299854	299315	19735D	PARTICIPANT	\N	PRESENT	0
299855	299315	11109J	PARTICIPANT	\N	PRESENT	0
299856	299315	11083R	PARTICIPANT	\N	PRESENT	0
299857	299315	08012N	PARTICIPANT	\N	PRESENT	0
299858	299315	19749K	PARTICIPANT	\N	PRESENT	0
299859	299315	19758L	PARTICIPANT	\N	PRESENT	0
299860	299315	04018C	PARTICIPANT	\N	PRESENT	0
299861	299315	08039A	PARTICIPANT	\N	PRESENT	0
299862	299315	08031R	PARTICIPANT	\N	EXCUSE	0
299916	289193	14195A	PARTICIPANT	\N	PRESENT	0
299908	299315	08017T	PARTICIPANT	\N	PRESENT	0
299909	299315	14123H	PARTICIPANT	\N	EXCUSE	0
299915	289193	11072N	PARTICIPANT	\N	PRESENT	0
299917	289193	19681G	PARTICIPANT	\N	PRESENT	0
299918	289193	17589D	PARTICIPANT	\N	PRESENT	0
299919	289193	14073Q	PARTICIPANT	\N	PRESENT	0
299920	289193	14265W	PARTICIPANT	\N	PRESENT	0
299921	289193	14105F	PARTICIPANT	\N	PRESENT	0
299922	289193	19507S	PARTICIPANT	\N	PRESENT	0
299923	289193	14041T	PARTICIPANT	\N	PRESENT	0
299924	289193	14157T	PARTICIPANT	\N	PRESENT	0
299925	289193	01025N	PARTICIPANT	\N	PRESENT	0
299926	289193	11043H	PARTICIPANT	\N	PRESENT	0
299927	289193	14038Y	PARTICIPANT	\N	PRESENT	0
299928	289193	14051J	PARTICIPANT	\N	PRESENT	0
299929	289193	11056N	PARTICIPANT	\N	PRESENT	0
284009	283807	11056N	PARTICIPANT	\N	PRESENT	0
284010	283807	19489J	PARTICIPANT	\N	PRESENT	0
284011	283807	19573D	PARTICIPANT	\N	PRESENT	0
284012	283807	19447X	PARTICIPANT	\N	PRESENT	0
284013	283807	14211G	PARTICIPANT	\N	PRESENT	0
284014	283807	14038Y	PARTICIPANT	\N	PRESENT	0
284015	283807	14029X	PARTICIPANT	\N	PRESENT	0
284016	283807	19399H	PARTICIPANT	\N	PRESENT	0
284017	283807	14105F	PARTICIPANT	\N	PRESENT	0
284018	283807	14147R	PARTICIPANT	\N	PRESENT	0
284019	283807	14329V	PARTICIPANT	\N	PRESENT	0
284020	283807	19383Y	PARTICIPANT	\N	PRESENT	0
284021	283807	19533U	PARTICIPANT	\N	PRESENT	0
284022	283807	14327T	PARTICIPANT	\N	PRESENT	0
284023	283807	14030Q	PARTICIPANT	\N	PRESENT	0
284024	283807	01024M	PARTICIPANT	\N	PRESENT	0
284025	283807	08056B	PARTICIPANT	\N	PRESENT	0
284026	283807	05008E	PARTICIPANT	\N	PRESENT	0
284027	283807	14001X	PARTICIPANT	\N	PRESENT	0
284028	283807	14241N	PARTICIPANT	\N	PRESENT	0
284029	283807	19629C	PARTICIPANT	\N	PRESENT	0
284030	283807	14195A	PARTICIPANT	\N	PRESENT	0
284031	283807	04038G	PARTICIPANT	\N	PRESENT	0
284032	283807	14215L	PARTICIPANT	\N	PRESENT	0
284033	283807	14217N	PARTICIPANT	\N	PRESENT	0
284034	283807	14231L	PARTICIPANT	\N	PRESENT	0
284035	283807	11097X	PARTICIPANT	\N	PRESENT	0
284036	283807	14119M	PARTICIPANT	\N	PRESENT	0
284037	283807	04070G	PARTICIPANT	\N	PRESENT	0
284038	283807	01058X	PARTICIPANT	\N	PRESENT	0
284039	283807	14053L	PARTICIPANT	\N	PRESENT	0
284040	283807	14026U	PARTICIPANT	\N	PRESENT	0
284041	283807	17583W	PARTICIPANT	\N	PRESENT	0
284042	283807	19621T	PARTICIPANT	\N	PRESENT	0
284043	283807	14357A	PARTICIPANT	\N	PRESENT	0
284044	283807	14065Q	PARTICIPANT	\N	PRESENT	0
284045	283807	10006L	PARTICIPANT	\N	PRESENT	0
284046	283807	19543W	PARTICIPANT	\N	PRESENT	0
284047	283807	14213J	PARTICIPANT	\N	PRESENT	0
284587	284585	19531S	PARTICIPANT	\N	PRESENT	0
284049	283807	14179A	PARTICIPANT	\N	PRESENT	0
284050	283807	19733B	PARTICIPANT	\N	PRESENT	0
284051	283807	11064N	PARTICIPANT	\N	PRESENT	0
284052	283807	04040A	PARTICIPANT	\N	PRESENT	0
284053	283807	14111D	PARTICIPANT	\N	PRESENT	0
284054	283807	04033B	PARTICIPANT	\N	PRESENT	0
284055	283807	14083S	PARTICIPANT	\N	PRESENT	0
284056	283807	19713W	PARTICIPANT	\N	PRESENT	0
284057	283807	14097Y	PARTICIPANT	\N	PRESENT	0
284058	283807	14061L	PARTICIPANT	\N	PRESENT	0
284061	283807	14069U	PARTICIPANT	\N	PRESENT	0
284062	283807	19551W	PARTICIPANT	\N	PRESENT	0
284063	283807	14249W	PARTICIPANT	\N	PRESENT	0
284064	283807	14073Q	PARTICIPANT	\N	PRESENT	0
284065	283807	08031R	PARTICIPANT	\N	PRESENT	0
284066	283807	07029T	PARTICIPANT	\N	PRESENT	0
284067	283807	18083K	PARTICIPANT	\N	PRESENT	0
284068	283807	11048N	PARTICIPANT	\N	PRESENT	0
284069	283807	14033T	PARTICIPANT	\N	PRESENT	0
284070	283807	08015R	PARTICIPANT	\N	PRESENT	0
284071	283807	19507S	PARTICIPANT	\N	PRESENT	0
284072	283807	14265W	PARTICIPANT	\N	PRESENT	0
284073	283807	19563B	PARTICIPANT	\N	PRESENT	0
284074	283807	11099A	PARTICIPANT	\N	PRESENT	0
284075	283807	19549D	PARTICIPANT	\N	PRESENT	0
284596	284595	89017R	PARTICIPANT	\N	PRESENT	0
284942	284941	05008E	PRESIDENT	0	PRESENT	0
284943	284941	11033F	PARTICIPANT	\N	PRESENT	0
284944	284941	14065Q	PARTICIPANT	\N	PRESENT	0
284946	284941	04047H	PARTICIPANT	\N	PRESENT	0
284947	284941	14053L	PARTICIPANT	\N	PRESENT	0
284949	284941	19253P	PARTICIPANT	\N	PRESENT	0
284950	284941	04038G	PARTICIPANT	\N	PRESENT	0
284952	284941	14259Y	PARTICIPANT	\N	PRESENT	0
284953	284941	14041T	PARTICIPANT	\N	PRESENT	0
284954	284941	01024M	PARTICIPANT	\N	PRESENT	0
284956	284941	14215L	PARTICIPANT	\N	PRESENT	0
284957	284941	19673G	PARTICIPANT	\N	PRESENT	0
284958	284941	08018U	PARTICIPANT	\N	PRESENT	0
284959	284941	14231L	PARTICIPANT	\N	PRESENT	0
284960	284941	19649G	PARTICIPANT	\N	PRESENT	0
284962	284941	19725B	PARTICIPANT	\N	PRESENT	0
284963	284941	19447X	PARTICIPANT	\N	PRESENT	0
284964	284941	19489J	PARTICIPANT	\N	PRESENT	0
284965	284941	19729F	PARTICIPANT	\N	PRESENT	0
284966	284941	14111D	PARTICIPANT	\N	PRESENT	0
284967	284941	14001X	PARTICIPANT	\N	PRESENT	0
284968	284941	14147R	PARTICIPANT	\N	PRESENT	0
284007	283807	14034U	PARTICIPANT	\N	PRESENT	0
284008	283807	14259Y	PARTICIPANT	\N	PRESENT	0
284969	284941	10015M	PARTICIPANT	\N	PRESENT	0
284970	284941	01028R	PARTICIPANT	\N	PRESENT	0
284971	284941	04044E	PARTICIPANT	\N	PRESENT	0
284972	284941	19585H	PARTICIPANT	\N	PRESENT	0
284974	284941	95063L	PARTICIPANT	\N	PRESENT	0
284975	284941	07034Q	PARTICIPANT	\N	PRESENT	0
285009	285008	04008A	PARTICIPANT	\N	PRESENT	0
285011	285010	04008A	PARTICIPANT	\N	PRESENT	0
285014	285013	04008A	PARTICIPANT	\N	PRESENT	0
285018	285017	04008A	PARTICIPANT	\N	PRESENT	0
285097	285096	04008A	PARTICIPANT	\N	PRESENT	0
285099	285098	04008A	PARTICIPANT	\N	PRESENT	0
285102	285101	04008A	PARTICIPANT	\N	PRESENT	0
285103	285101	95063L	PARTICIPANT	\N	PRESENT	0
285105	285104	04008A	PARTICIPANT	\N	PRESENT	0
285127	285116	08011M	PARTICIPANT	\N	PRESENT	0
285128	285116	07004J	PARTICIPANT	\N	PRESENT	0
285135	285015	11074Q	PARTICIPANT	\N	PRESENT	0
285137	285015	08011M	PARTICIPANT	\N	PRESENT	0
285202	284536	11109J	PARTICIPANT	\N	PRESENT	0
285203	284536	14327T	PARTICIPANT	\N	PRESENT	0
285204	284536	98024R	PARTICIPANT	\N	PRESENT	0
285205	284536	14213J	PARTICIPANT	\N	EXCUSE	0
285206	284536	11099A	PARTICIPANT	\N	PRESENT	0
285207	284536	19441R	PARTICIPANT	\N	PRESENT	0
285208	284536	14221J	PARTICIPANT	\N	PRESENT	0
285209	284536	14109K	PARTICIPANT	\N	PRESENT	0
285210	284536	14169X	PARTICIPANT	\N	PRESENT	0
285211	284536	19503N	PARTICIPANT	\N	PRESENT	0
285212	284536	04045F	PARTICIPANT	\N	EXCUSE	0
285213	284536	08049C	PARTICIPANT	\N	PRESENT	0
285214	284536	08015R	PARTICIPANT	\N	EXCUSE	0
285503	279154	14071N	PARTICIPANT	\N	PRESENT	0
286037	286036	01028R	PARTICIPANT	\N	PRESENT	0
286209	282453	95062K	PARTICIPANT	\N	EXCUSE	0
286210	282453	04043D	PARTICIPANT	\N	EXCUSE	0
286211	282453	19583F	PARTICIPANT	\N	EXCUSE	0
286270	273988	19511N	PARTICIPANT	\N	EXCUSE	0
286275	286274	11099A	PARTICIPANT	\N	PRESENT	0
286277	286276	11099A	PARTICIPANT	\N	PRESENT	0
286281	286280	14187A	PARTICIPANT	\N	PRESENT	0
286283	286282	14187A	PARTICIPANT	\N	PRESENT	0
286286	286285	19631V	PARTICIPANT	\N	PRESENT	0
286287	286285	08038Y	PARTICIPANT	\N	PRESENT	0
286288	286285	11070L	PARTICIPANT	\N	PRESENT	0
286289	286285	11074Q	PARTICIPANT	\N	PRESENT	0
286290	286285	04018C	PARTICIPANT	\N	PRESENT	0
286291	286285	19413M	PARTICIPANT	\N	PRESENT	0
286292	286285	08035V	PARTICIPANT	\N	PRESENT	0
286293	286284	08011M	PARTICIPANT	\N	PRESENT	0
286294	286284	07004J	PARTICIPANT	\N	PRESENT	0
286295	286284	04071H	PARTICIPANT	\N	PRESENT	0
286297	286296	08011M	PARTICIPANT	\N	PRESENT	0
286298	286296	07004J	PARTICIPANT	\N	PRESENT	0
286299	286296	19689Q	PARTICIPANT	\N	PRESENT	0
286301	286300	08011M	PARTICIPANT	\N	PRESENT	0
286302	286300	07004J	PARTICIPANT	\N	PRESENT	0
286303	286300	19689Q	PARTICIPANT	\N	PRESENT	0
286304	284818	08024S	PARTICIPANT	\N	PRESENT	0
286305	284818	11065P	PARTICIPANT	\N	EXCUSE	0
286306	284818	19667J	PARTICIPANT	\N	EXCUSE	0
286307	284818	19551W	PARTICIPANT	\N	PRESENT	0
286308	284818	19479G	PARTICIPANT	\N	EXCUSE	0
286309	284818	19737F	PARTICIPANT	\N	PRESENT	0
286310	284818	11097X	PARTICIPANT	\N	EXCUSE	0
286311	284818	19515S	PARTICIPANT	\N	PRESENT	0
286312	284818	08012N	PARTICIPANT	\N	EXCUSE	0
286313	284818	19369B	PARTICIPANT	\N	EXCUSE	0
286314	284818	19647E	PARTICIPANT	\N	EXCUSE	0
286315	284818	19713W	PARTICIPANT	\N	PRESENT	0
286316	284818	19629C	PARTICIPANT	\N	EXCUSE	0
286317	284818	99004R	PRESIDENT	0	PRESENT	0
286318	284818	02002K	PARTICIPANT	\N	EXCUSE	0
286329	284818	89017R	PARTICIPANT	\N	EXCUSE	0
286330	273911	04044E	PARTICIPANT	\N	PRESENT	0
287604	287603	14079W	PARTICIPANT	\N	PRESENT	0
287605	287603	14097Y	PARTICIPANT	\N	PRESENT	0
287606	287603	10015M	PARTICIPANT	\N	PRESENT	0
287633	287632	96004D	PARTICIPANT	\N	PRESENT	0
276315	276038	08012N	PARTICIPANT	\N	PRESENT	0
276316	276038	19667J	PARTICIPANT	\N	PRESENT	0
276317	276038	11115U	PARTICIPANT	\N	PRESENT	0
276318	276038	80013X	PARTICIPANT	\N	PRESENT	0
276319	276038	14199E	PARTICIPANT	\N	PRESENT	0
276320	276038	08038Y	PARTICIPANT	\N	PRESENT	0
276321	276038	19575F	PARTICIPANT	\N	PRESENT	0
276322	276038	08035V	PARTICIPANT	\N	PRESENT	0
276323	276038	14253S	PARTICIPANT	\N	PRESENT	0
276324	276038	19251M	PARTICIPANT	\N	PRESENT	0
276325	276038	98023Q	PARTICIPANT	\N	PRESENT	0
276326	276038	98050T	PARTICIPANT	\N	PRESENT	0
276327	276038	19611R	PARTICIPANT	\N	PRESENT	0
276328	276038	05012A	PARTICIPANT	\N	PRESENT	0
276329	276038	11065P	PARTICIPANT	\N	PRESENT	0
276330	276038	08034U	PARTICIPANT	\N	PRESENT	0
276331	276038	11064N	PARTICIPANT	\N	PRESENT	0
276332	276038	14251Q	PARTICIPANT	\N	PRESENT	0
276333	276038	19533U	PARTICIPANT	\N	PRESENT	0
276334	276038	10006L	PARTICIPANT	\N	PRESENT	0
276335	276038	07034Q	PARTICIPANT	\N	PRESENT	0
276336	276038	17583W	PARTICIPANT	\N	PRESENT	0
276337	276038	14237S	PARTICIPANT	\N	PRESENT	0
276338	276038	19649G	PARTICIPANT	\N	PRESENT	0
276339	276036	14221J	PARTICIPANT	\N	PRESENT	0
276340	276036	14191V	PARTICIPANT	\N	PRESENT	0
277077	263768	14065Q	PARTICIPANT	\N	PRESENT	0
277078	263768	14207L	PARTICIPANT	\N	PRESENT	0
277079	263768	19525U	PARTICIPANT	\N	PRESENT	0
277080	263768	08073C	PARTICIPANT	\N	PRESENT	0
277081	263768	11027H	PARTICIPANT	\N	PRESENT	0
277082	263768	14030Q	PARTICIPANT	\N	PRESENT	0
277083	263768	19713W	PARTICIPANT	\N	PRESENT	0
277084	263768	19319Q	PARTICIPANT	\N	PRESENT	0
277085	263768	14277B	PARTICIPANT	\N	PRESENT	0
277086	263768	14275Y	PARTICIPANT	\N	PRESENT	0
277087	263768	19441R	PARTICIPANT	\N	PRESENT	0
277088	263768	19479G	PARTICIPANT	\N	PRESENT	0
277089	263768	14219Q	PARTICIPANT	\N	PRESENT	0
277090	263768	14042U	PARTICIPANT	\N	PRESENT	0
277091	263768	19569H	PARTICIPANT	\N	PRESENT	0
277092	263768	08056B	PARTICIPANT	\N	PRESENT	0
277093	263768	07004J	PARTICIPANT	\N	PRESENT	0
277094	263768	19735D	PARTICIPANT	\N	PRESENT	0
277095	263768	19739H	PARTICIPANT	\N	PRESENT	0
277096	263768	16685X	PARTICIPANT	\N	PRESENT	0
277097	263768	19699S	PARTICIPANT	\N	PRESENT	0
277098	263768	14255U	PARTICIPANT	\N	PRESENT	0
277099	263768	19721W	PARTICIPANT	\N	PRESENT	0
277100	263768	14267Y	PARTICIPANT	\N	PRESENT	0
277101	263768	11053K	PARTICIPANT	\N	PRESENT	0
277102	263768	19619A	PARTICIPANT	\N	PRESENT	0
277103	263768	19511N	PARTICIPANT	\N	PRESENT	0
277104	263768	08044W	PARTICIPANT	\N	PRESENT	0
277105	263768	08009T	PARTICIPANT	\N	PRESENT	0
277106	263768	11085T	PARTICIPANT	\N	PRESENT	0
277107	263768	14221J	PARTICIPANT	\N	PRESENT	0
277108	263768	19335Q	PARTICIPANT	\N	PRESENT	0
277109	263768	19611R	PARTICIPANT	\N	PRESENT	0
277110	263768	14073Q	PARTICIPANT	\N	PRESENT	0
277111	263768	01034P	PARTICIPANT	\N	PRESENT	0
277112	263768	19369B	PARTICIPANT	\N	PRESENT	0
277113	263768	19691J	PARTICIPANT	\N	PRESENT	0
277114	263768	01025N	PARTICIPANT	\N	PRESENT	0
277115	263768	14231L	PARTICIPANT	\N	PRESENT	0
277116	263768	19521Q	PARTICIPANT	\N	PRESENT	0
277117	263768	14327T	PARTICIPANT	\N	PRESENT	0
277118	263768	14179A	PARTICIPANT	\N	PRESENT	0
277119	263768	01024M	PARTICIPANT	\N	PRESENT	0
277120	263768	04040A	PARTICIPANT	\N	PRESENT	0
277121	263768	14089Y	PARTICIPANT	\N	PRESENT	0
277122	263768	14083S	PARTICIPANT	\N	PRESENT	0
277123	263768	14103D	PARTICIPANT	\N	PRESENT	0
277124	263768	04070G	PARTICIPANT	\N	PRESENT	0
277125	263768	19737F	PARTICIPANT	\N	PRESENT	0
277126	263768	19749K	PARTICIPANT	\N	PRESENT	0
277127	263768	14205J	PARTICIPANT	\N	PRESENT	0
277128	263768	19543W	PARTICIPANT	\N	PRESENT	0
277129	263768	14055N	PARTICIPANT	\N	PRESENT	0
277130	263768	19531S	PARTICIPANT	\N	PRESENT	0
277131	263768	08047A	PARTICIPANT	\N	PRESENT	0
277132	263768	04008A	PARTICIPANT	\N	PRESENT	0
277133	263768	19585H	PARTICIPANT	\N	PRESENT	0
277134	263768	14281W	PARTICIPANT	\N	PRESENT	0
277136	263768	19399H	PARTICIPANT	\N	PRESENT	0
277137	263768	11040E	PARTICIPANT	\N	PRESENT	0
277139	263768	14237S	PARTICIPANT	\N	PRESENT	0
277459	263769	11072N	PARTICIPANT	\N	PRESENT	0
277460	263769	98023Q	PARTICIPANT	\N	PRESENT	0
277461	263769	08009T	PARTICIPANT	\N	PRESENT	0
277462	263769	14235Q	PARTICIPANT	\N	PRESENT	0
277463	263769	11031D	PARTICIPANT	\N	PRESENT	0
277464	263769	11056N	PARTICIPANT	\N	PRESENT	0
277465	263769	04085P	PARTICIPANT	\N	PRESENT	0
277466	263769	19687N	PARTICIPANT	\N	PRESENT	0
277467	263769	19695N	PARTICIPANT	\N	PRESENT	0
277468	263769	12041X	PARTICIPANT	\N	PRESENT	0
277469	263769	11063M	PARTICIPANT	\N	PRESENT	0
277470	263769	19593H	PARTICIPANT	\N	PRESENT	0
277471	263769	19347U	PARTICIPANT	\N	PRESENT	0
277472	263769	11040E	PARTICIPANT	\N	PRESENT	0
277473	263769	19565D	PARTICIPANT	\N	PRESENT	0
277474	263769	19525U	PARTICIPANT	\N	PRESENT	0
277475	263769	19551W	PARTICIPANT	\N	PRESENT	0
277476	263769	19651A	PARTICIPANT	\N	PRESENT	0
277477	263769	14121F	PARTICIPANT	\N	PRESENT	0
277478	263769	14051J	PARTICIPANT	\N	PRESENT	0
277479	263769	08060W	PARTICIPANT	\N	PRESENT	0
277480	263769	80013X	PARTICIPANT	\N	PRESENT	0
277481	263769	14281W	PARTICIPANT	\N	PRESENT	0
277482	263769	08024S	PARTICIPANT	\N	PRESENT	0
277483	276029	19703U	PARTICIPANT	\N	PRESENT	0
277484	276029	14119M	PARTICIPANT	\N	PRESENT	0
277485	276029	04092N	PRESIDENT	0	PRESENT	0
277486	276029	14087W	PARTICIPANT	\N	PRESENT	0
277487	276029	11103C	PARTICIPANT	\N	PRESENT	0
277488	276029	19717B	PARTICIPANT	\N	PRESENT	0
277489	276029	14026U	PARTICIPANT	\N	PRESENT	0
277490	276029	19521Q	PARTICIPANT	\N	PRESENT	0
277491	276029	17779H	PARTICIPANT	\N	PRESENT	0
277505	263769	08061X	PARTICIPANT	\N	PRESENT	0
277506	263769	04045F	PARTICIPANT	\N	PRESENT	0
277507	263769	19697Q	PARTICIPANT	\N	PRESENT	0
277508	263769	19637C	PARTICIPANT	\N	PRESENT	0
277509	263769	19349W	PARTICIPANT	\N	PRESENT	0
277510	263769	19669L	PARTICIPANT	\N	PRESENT	0
277511	276029	11097X	PARTICIPANT	\N	PRESENT	0
277512	276029	19727D	PARTICIPANT	\N	PRESENT	0
277513	276029	14071N	PARTICIPANT	\N	PRESENT	0
277514	263769	19289C	PARTICIPANT	\N	PRESENT	0
277515	263769	19387D	PARTICIPANT	\N	PRESENT	0
277516	263769	19631V	PARTICIPANT	\N	PRESENT	0
277517	263769	04057K	PARTICIPANT	\N	PRESENT	0
277518	263769	02002K	PARTICIPANT	\N	PRESENT	0
277519	263769	14021P	PARTICIPANT	\N	PRESENT	0
277520	263769	14042U	PARTICIPANT	\N	PRESENT	0
277521	263769	14219Q	PARTICIPANT	\N	PRESENT	0
277522	263769	19479G	PARTICIPANT	\N	PRESENT	0
277523	263769	19735D	PARTICIPANT	\N	PRESENT	0
277524	263769	19737F	PARTICIPANT	\N	PRESENT	0
277525	263769	11012A	PARTICIPANT	\N	PRESENT	0
277526	263769	95062K	PARTICIPANT	\N	PRESENT	0
277527	263769	08016S	PARTICIPANT	\N	PRESENT	0
277528	276029	19697Q	PARTICIPANT	\N	PRESENT	0
277529	276029	04045F	PARTICIPANT	\N	PRESENT	0
277530	276029	19553Y	PARTICIPANT	\N	PRESENT	0
277531	263769	08049C	PARTICIPANT	\N	PRESENT	0
277532	263769	19447X	PARTICIPANT	\N	PRESENT	0
277533	276029	19575F	PARTICIPANT	\N	PRESENT	0
277534	263769	14157T	PARTICIPANT	\N	PRESENT	0
277535	263769	04097T	PARTICIPANT	\N	PRESENT	0
277536	263769	08010L	PARTICIPANT	\N	PRESENT	0
277537	276029	19415P	PARTICIPANT	\N	PRESENT	0
277538	276029	19723Y	PARTICIPANT	\N	PRESENT	0
277539	276029	14195A	PARTICIPANT	\N	PRESENT	0
277540	263769	19253P	PARTICIPANT	\N	PRESENT	0
277541	263769	08044W	PARTICIPANT	\N	PRESENT	0
277542	263769	14327T	PARTICIPANT	\N	PRESENT	0
277543	263769	01025N	PARTICIPANT	\N	PRESENT	0
277544	263769	19747H	PARTICIPANT	\N	PRESENT	0
277545	263769	08028W	PARTICIPANT	\N	PRESENT	0
277546	263769	19581D	PARTICIPANT	\N	PRESENT	0
277547	263769	19749K	PARTICIPANT	\N	PRESENT	0
277548	263769	01057W	PARTICIPANT	\N	PRESENT	0
277549	276029	01034P	PARTICIPANT	\N	PRESENT	0
277550	263769	19745F	PARTICIPANT	\N	PRESENT	0
277551	263769	07029T	PARTICIPANT	\N	PRESENT	0
277552	263769	19739H	PARTICIPANT	\N	PRESENT	0
287210	285994	04071H	PARTICIPANT	\N	PRESENT	0
287211	285994	11070L	PARTICIPANT	\N	PRESENT	0
287212	285994	14121F	PARTICIPANT	\N	PRESENT	0
287213	285994	04061F	PARTICIPANT	\N	PRESENT	0
287214	285994	07029T	PARTICIPANT	\N	EXCUSE	0
287215	285994	08034U	PARTICIPANT	\N	EXCUSE	0
287216	285994	89017R	PARTICIPANT	\N	EXCUSE	0
287217	285994	08014Q	PARTICIPANT	\N	EXCUSE	0
287218	286215	98029W	PARTICIPANT	\N	PRESENT	0
287219	286235	19551W	PARTICIPANT	\N	PRESENT	0
287282	286235	11065P	PARTICIPANT	\N	PRESENT	0
287364	286236	14237S	PARTICIPANT	\N	PRESENT	0
287365	286236	15447F	PARTICIPANT	\N	PRESENT	0
287366	286236	14029X	PARTICIPANT	\N	PRESENT	0
287367	286236	08060W	PARTICIPANT	\N	PRESENT	0
287368	286236	19387D	PARTICIPANT	\N	PRESENT	0
287369	286236	19737F	PARTICIPANT	\N	PRESENT	0
287370	286236	08055A	PARTICIPANT	\N	PRESENT	0
287371	286236	19681G	PARTICIPANT	\N	EXCUSE	0
287372	286236	95062K	PARTICIPANT	\N	PRESENT	0
287373	286236	19685L	PARTICIPANT	\N	EXCUSE	0
287454	285998	04086Q	PARTICIPANT	\N	PRESENT	0
287455	285998	14085U	PARTICIPANT	\N	PRESENT	0
287456	285998	19349W	PARTICIPANT	\N	PRESENT	0
287457	285998	14121F	PARTICIPANT	\N	PRESENT	0
287458	285998	19667J	PARTICIPANT	\N	PRESENT	0
287459	285998	11074Q	PRESIDENT	0	PRESENT	0
287178	286215	19443T	PARTICIPANT	\N	PRESENT	0
287179	286215	12041X	PARTICIPANT	\N	PRESENT	0
287180	286215	95030B	PARTICIPANT	\N	PRESENT	0
287181	286215	11080N	PARTICIPANT	\N	PRESENT	0
287182	286215	04034C	PARTICIPANT	\N	PRESENT	0
287183	286215	14079W	PARTICIPANT	\N	PRESENT	0
287184	286215	01058X	PARTICIPANT	\N	PRESENT	0
287185	286215	11027H	PARTICIPANT	\N	PRESENT	0
287186	286215	04042C	PRESIDENT	0	PRESENT	0
287187	286215	11066Q	PARTICIPANT	\N	PRESENT	0
287188	286215	08056B	PARTICIPANT	\N	PRESENT	0
287189	286215	95037J	PARTICIPANT	\N	PRESENT	0
287190	286215	14055N	PARTICIPANT	\N	PRESENT	0
287191	286215	19421M	PARTICIPANT	\N	PRESENT	0
287192	286215	08053X	PARTICIPANT	\N	PRESENT	0
287193	286215	08061X	PARTICIPANT	\N	PRESENT	0
287194	286215	08047A	PARTICIPANT	\N	PRESENT	0
287195	286215	14097Y	PARTICIPANT	\N	PRESENT	0
287196	286215	04035D	PARTICIPANT	\N	PRESENT	0
287197	286215	01062T	PARTICIPANT	\N	PRESENT	0
287198	286215	14133K	PARTICIPANT	\N	PRESENT	0
287199	286215	11041F	PARTICIPANT	\N	PRESENT	0
287200	286215	08058D	PARTICIPANT	\N	PRESENT	0
287201	286215	14028W	PARTICIPANT	\N	PRESENT	0
287202	286215	19251M	PARTICIPANT	\N	PRESENT	0
287203	286215	19721W	PARTICIPANT	\N	PRESENT	0
287204	286215	14105F	PARTICIPANT	\N	PRESENT	0
287205	286215	14267Y	PARTICIPANT	\N	PRESENT	0
287206	286215	98050T	PARTICIPANT	\N	PRESENT	0
287207	286215	14211G	PARTICIPANT	\N	PRESENT	0
287208	286215	14255U	PARTICIPANT	\N	PRESENT	0
287209	286235	19659J	PARTICIPANT	\N	PRESENT	0
287460	285998	19671E	PARTICIPANT	\N	PRESENT	0
287461	285998	14225N	PARTICIPANT	\N	PRESENT	0
287462	285998	04061F	PARTICIPANT	\N	PRESENT	0
287463	273914	11077T	PARTICIPANT	\N	PRESENT	0
287464	285998	11048N	PARTICIPANT	\N	PRESENT	0
287465	285998	07029T	PARTICIPANT	\N	EXCUSE	0
287466	285998	08034U	PARTICIPANT	\N	EXCUSE	0
287467	285998	89017R	PARTICIPANT	\N	EXCUSE	0
287468	285998	08014Q	PARTICIPANT	\N	EXCUSE	0
287469	285998	08010L	PARTICIPANT	\N	PRESENT	0
287470	273914	04047H	PARTICIPANT	\N	PRESENT	0
287471	273914	05008E	PARTICIPANT	\N	PRESENT	0
287472	273914	19731Y	PARTICIPANT	\N	PRESENT	0
287473	273914	99004R	PARTICIPANT	\N	PRESENT	0
287474	273914	19701S	PARTICIPANT	\N	PRESENT	0
287475	273914	14001X	PARTICIPANT	\N	PRESENT	0
287476	273914	14219Q	PARTICIPANT	\N	PRESENT	0
287477	273914	04092N	PARTICIPANT	\N	PRESENT	0
287478	273914	19673G	PARTICIPANT	\N	PRESENT	0
287479	273914	11066Q	PARTICIPANT	\N	PRESENT	0
287480	273914	04034C	PARTICIPANT	\N	PRESENT	0
287481	273914	11026G	PARTICIPANT	\N	PRESENT	0
287482	273914	14215L	PARTICIPANT	\N	PRESENT	0
287483	273914	04059M	PARTICIPANT	\N	PRESENT	0
287484	273914	95063L	PARTICIPANT	\N	PRESENT	0
287485	273914	19565D	PARTICIPANT	\N	PRESENT	0
287486	273914	04088S	PARTICIPANT	\N	PRESENT	0
287487	273914	04085P	PARTICIPANT	\N	PRESENT	0
287488	273914	19525U	PARTICIPANT	\N	PRESENT	0
287489	273914	19729F	PARTICIPANT	\N	PRESENT	0
287490	273914	19333N	PARTICIPANT	\N	PRESENT	0
287491	273914	01028R	PARTICIPANT	\N	PRESENT	0
287492	273914	11072N	PARTICIPANT	\N	PRESENT	0
287493	273914	14041T	PARTICIPANT	\N	PRESENT	0
287494	273914	19745F	PARTICIPANT	\N	PRESENT	0
287495	273914	19671E	PARTICIPANT	\N	PRESENT	0
287496	273914	19695N	PARTICIPANT	\N	PRESENT	0
287497	273914	14055N	PARTICIPANT	\N	PRESENT	0
287498	273914	14223L	PARTICIPANT	\N	PRESENT	0
287499	273914	19533U	PARTICIPANT	\N	PRESENT	0
287500	273914	14331P	PARTICIPANT	\N	PRESENT	0
287501	273914	14267Y	PARTICIPANT	\N	PRESENT	0
287502	273914	14147R	PARTICIPANT	\N	PRESENT	0
287503	273914	14217N	PARTICIPANT	\N	PRESENT	0
287504	273914	19723Y	PARTICIPANT	\N	PRESENT	0
287505	273914	19693L	PARTICIPANT	\N	PRESENT	0
287506	273914	14265W	PARTICIPANT	\N	PRESENT	0
287507	273914	14065Q	PARTICIPANT	\N	PRESENT	0
287508	273914	11045K	PARTICIPANT	\N	PRESENT	0
287509	273914	14261S	PARTICIPANT	\N	PRESENT	0
287510	273914	11056N	PARTICIPANT	\N	PRESENT	0
287511	273914	95030B	PARTICIPANT	\N	PRESENT	0
287512	273914	19573D	PARTICIPANT	\N	PRESENT	0
287513	273914	11109J	PARTICIPANT	\N	PRESENT	0
287514	273914	19669L	PARTICIPANT	\N	PRESENT	0
287515	273914	19329S	PARTICIPANT	\N	PRESENT	0
287516	273914	19683J	PARTICIPANT	\N	PRESENT	0
287517	273914	14151M	PARTICIPANT	\N	PRESENT	0
287518	273914	11031D	PARTICIPANT	\N	PRESENT	0
287519	273914	16685X	PARTICIPANT	\N	PRESENT	0
287520	273914	14089Y	PARTICIPANT	\N	PRESENT	0
287521	273914	19739H	PARTICIPANT	\N	PRESENT	0
287522	273914	07034Q	PARTICIPANT	\N	PRESENT	0
287523	273914	11103C	PARTICIPANT	\N	PRESENT	0
287524	273914	19447X	PARTICIPANT	\N	PRESENT	0
287525	273914	19467C	PARTICIPANT	\N	PRESENT	0
287526	273914	19575F	PARTICIPANT	\N	PRESENT	0
287527	273914	19651A	PARTICIPANT	\N	PRESENT	0
287528	273914	08061X	PARTICIPANT	\N	PRESENT	0
287529	273914	08020N	PARTICIPANT	\N	PRESENT	0
287530	273914	19611R	PARTICIPANT	\N	PRESENT	0
287531	273914	01024M	PARTICIPANT	\N	PRESENT	0
287532	273914	19663E	PARTICIPANT	\N	PRESENT	0
287533	273914	14021P	PARTICIPANT	\N	PRESENT	0
287534	273914	14109K	PARTICIPANT	\N	PRESENT	0
287535	273914	14039A	PARTICIPANT	\N	PRESENT	0
287537	273914	14213J	PARTICIPANT	\N	PRESENT	0
287538	273914	08056B	PARTICIPANT	\N	PRESENT	0
287539	273914	19629C	PARTICIPANT	\N	PRESENT	0
287541	273914	19577H	PARTICIPANT	\N	PRESENT	0
287542	273914	14093U	PARTICIPANT	\N	PRESENT	0
287547	273914	08068F	PARTICIPANT	\N	PRESENT	0
287548	273914	14103D	PARTICIPANT	\N	PRESENT	0
287549	273914	04043D	PARTICIPANT	\N	PRESENT	0
287550	273914	95015C	PARTICIPANT	\N	PRESENT	0
287551	273914	11040E	PARTICIPANT	\N	PRESENT	0
287552	273914	14053L	PARTICIPANT	\N	PRESENT	0
287553	273914	19543W	PARTICIPANT	\N	PRESENT	0
287554	273914	19737F	PARTICIPANT	\N	PRESENT	0
287555	273914	14115H	PARTICIPANT	\N	PRESENT	0
287556	273914	19527W	PARTICIPANT	\N	PRESENT	0
287557	273914	19593H	PARTICIPANT	\N	PRESENT	0
287558	273914	19347U	PARTICIPANT	\N	PRESENT	0
287559	273914	08058D	PARTICIPANT	\N	PRESENT	0
287560	273914	19621T	PARTICIPANT	\N	PRESENT	0
287561	273914	11104D	PARTICIPANT	\N	PRESENT	0
287562	273914	19649G	PARTICIPANT	\N	PRESENT	0
287563	273914	14237S	PARTICIPANT	\N	PRESENT	0
287564	273914	19725B	PARTICIPANT	\N	PRESENT	0
287565	273914	08016S	PARTICIPANT	\N	PRESENT	0
287566	273914	92040Q	PARTICIPANT	\N	PRESENT	0
287567	273914	19591F	PARTICIPANT	\N	PRESENT	0
287568	273914	14031R	PARTICIPANT	\N	PRESENT	0
287569	273914	19441R	PARTICIPANT	\N	PRESENT	0
287570	273914	04071H	PARTICIPANT	\N	PRESENT	0
287571	273914	08062Y	PARTICIPANT	\N	PRESENT	0
287572	285998	08011M	PARTICIPANT	\N	PRESENT	0
287573	273914	19253P	PARTICIPANT	\N	PRESENT	0
287574	273914	88008L	PARTICIPANT	\N	PRESENT	0
287575	273914	14042U	PARTICIPANT	\N	PRESENT	0
273280	263475	14147R	PARTICIPANT	\N	PRESENT	0
274261	273666	19715Y	PARTICIPANT	\N	PRESENT	0
274262	273667	14275Y	PARTICIPANT	\N	EXCUSE	0
275163	275162	14187A	PARTICIPANT	\N	PRESENT	0
275165	275164	14187A	PARTICIPANT	\N	PRESENT	0
275166	275164	04049K	PARTICIPANT	\N	PRESENT	0
275167	275164	04008A	PARTICIPANT	\N	PRESENT	0
275169	275168	14187A	PARTICIPANT	\N	PRESENT	0
275171	275170	14187A	PARTICIPANT	\N	PRESENT	0
275180	275176	14187A	PARTICIPANT	\N	PRESENT	0
275188	275183	14187A	PARTICIPANT	\N	PRESENT	0
275291	275290	14065Q	PARTICIPANT	\N	PRESENT	0
275292	275290	07034Q	PARTICIPANT	\N	PRESENT	0
278172	278170	10015M	PARTICIPANT	\N	PRESENT	0
278176	278170	19703U	PARTICIPANT	\N	PRESENT	0
278179	278170	14034U	PARTICIPANT	\N	PRESENT	0
278181	278170	07004J	PARTICIPANT	\N	PRESENT	0
278183	278170	19697Q	PARTICIPANT	\N	PRESENT	0
278232	278170	04040A	PARTICIPANT	\N	PRESENT	0
278233	278170	04061F	PARTICIPANT	\N	PRESENT	0
278253	278252	98035U	PARTICIPANT	\N	PRESENT	0
278352	278351	08010L	PARTICIPANT	\N	PRESENT	0
278353	278351	14255U	PARTICIPANT	\N	PRESENT	0
278354	278351	04043D	PARTICIPANT	\N	PRESENT	0
278355	278351	04045F	PARTICIPANT	\N	PRESENT	0
279243	279242	08058D	PRESIDENT	0	PRESENT	0
279244	279242	11053K	PARTICIPANT	\N	PRESENT	0
279245	279242	04071H	PARTICIPANT	\N	PRESENT	0
279246	279242	11049P	PARTICIPANT	\N	PRESENT	0
279247	279242	19703U	PARTICIPANT	\N	PRESENT	0
279248	279242	19721W	PARTICIPANT	\N	PRESENT	0
289016	286237	08055A	PARTICIPANT	\N	PRESENT	0
289017	286237	96004D	PARTICIPANT	\N	PRESENT	0
289018	286237	18083K	PARTICIPANT	\N	PRESENT	0
289019	286237	19599P	PARTICIPANT	\N	PRESENT	0
289020	286237	15447F	PARTICIPANT	\N	PRESENT	0
289021	286237	19347U	PARTICIPANT	\N	PRESENT	0
289022	286237	19333N	PARTICIPANT	\N	PRESENT	0
289023	286237	04097T	PARTICIPANT	\N	PRESENT	0
289024	286237	19551W	PARTICIPANT	\N	PRESENT	0
289025	286237	19387D	PARTICIPANT	\N	PRESENT	0
289026	286237	19289C	PARTICIPANT	\N	PRESENT	0
289027	286237	14219Q	PARTICIPANT	\N	PRESENT	0
289028	286237	14103D	PARTICIPANT	\N	PRESENT	0
289030	286237	08009T	PRESIDENT	0	PRESENT	0
289031	286237	14169X	PARTICIPANT	\N	PRESENT	0
289516	289514	04059M	PARTICIPANT	\N	PRESENT	0
289033	286237	19745F	PARTICIPANT	\N	PRESENT	0
289035	286237	19503N	PARTICIPANT	\N	PRESENT	0
289036	286237	05012A	PARTICIPANT	\N	PRESENT	0
289037	286237	19739H	PARTICIPANT	\N	PRESENT	0
289038	286237	14237S	PARTICIPANT	\N	PRESENT	0
289040	286237	19701S	PARTICIPANT	\N	EXCUSE	0
289041	286237	19685L	PARTICIPANT	\N	EXCUSE	0
289042	286237	14051J	PARTICIPANT	\N	PRESENT	0
289044	286237	14221J	PARTICIPANT	\N	PRESENT	0
289046	286237	14121F	PARTICIPANT	\N	PRESENT	0
289047	286237	19531S	PARTICIPANT	\N	PRESENT	0
289054	286237	08073C	PARTICIPANT	\N	PRESENT	0
289055	286237	10015M	PARTICIPANT	\N	PRESENT	0
289056	286237	95037J	PARTICIPANT	\N	PRESENT	0
289057	286237	11083R	PARTICIPANT	\N	PRESENT	0
289058	286237	14133K	PARTICIPANT	\N	PRESENT	0
289059	286237	14135M	PARTICIPANT	\N	PRESENT	0
289060	286237	14073Q	PARTICIPANT	\N	PRESENT	0
289061	286237	14061L	PARTICIPANT	\N	PRESENT	0
289063	286237	14089Y	PARTICIPANT	\N	PRESENT	0
289064	286237	14033T	PARTICIPANT	\N	PRESENT	0
289065	286237	14079W	PARTICIPANT	\N	PRESENT	0
289066	286237	14327T	PARTICIPANT	\N	PRESENT	0
289067	286237	14229S	PARTICIPANT	\N	PRESENT	0
289068	286237	19725B	PARTICIPANT	\N	PRESENT	0
289069	286237	19563B	PARTICIPANT	\N	PRESENT	0
289071	286237	19569H	PARTICIPANT	\N	PRESENT	0
289075	286237	14001X	PARTICIPANT	\N	PRESENT	0
289077	286237	14065Q	PARTICIPANT	\N	PRESENT	0
289518	289514	19711U	PARTICIPANT	\N	PRESENT	0
289519	289514	07034Q	PARTICIPANT	\N	PRESENT	0
289520	289514	14039A	PARTICIPANT	\N	PRESENT	0
289523	289514	11012A	PARTICIPANT	\N	PRESENT	0
289524	289514	14038Y	PARTICIPANT	\N	PRESENT	0
289525	289514	04047H	PARTICIPANT	\N	PRESENT	0
289526	289514	14061L	PARTICIPANT	\N	PRESENT	0
289527	289514	11026G	PARTICIPANT	\N	PRESENT	0
289528	289514	19443T	PARTICIPANT	\N	PRESENT	0
289529	289514	99004R	PARTICIPANT	\N	PRESENT	0
289530	289514	01024M	PARTICIPANT	\N	PRESENT	0
289531	289514	19533U	PARTICIPANT	\N	PRESENT	0
289534	289514	04043D	PARTICIPANT	\N	PRESENT	0
289535	289514	04034C	PARTICIPANT	\N	PRESENT	0
289536	289514	04085P	PARTICIPANT	\N	PRESENT	0
289537	289514	05008E	PARTICIPANT	\N	PRESENT	0
289538	289514	11072N	PARTICIPANT	\N	PRESENT	0
289539	289514	14261S	PARTICIPANT	\N	PRESENT	0
289540	289514	14089Y	PARTICIPANT	\N	PRESENT	0
289541	289514	19447X	PARTICIPANT	\N	PRESENT	0
289542	289514	95063L	PARTICIPANT	\N	PRESENT	0
289543	289514	01058X	PARTICIPANT	\N	PRESENT	0
289544	289514	14251Q	PARTICIPANT	\N	PRESENT	0
289545	289514	17637T	PARTICIPANT	\N	PRESENT	0
289546	289514	04033B	PARTICIPANT	\N	PRESENT	0
289547	289514	19649G	PARTICIPANT	\N	PRESENT	0
289548	289514	19709B	PARTICIPANT	\N	PRESENT	0
289549	289514	19689Q	PARTICIPANT	\N	PRESENT	0
289550	289514	19489J	PARTICIPANT	\N	PRESENT	0
289551	289514	19695N	PARTICIPANT	\N	PRESENT	0
289552	289514	19697Q	PARTICIPANT	\N	PRESENT	0
289553	289514	19717B	PARTICIPANT	\N	PRESENT	0
289554	289514	11070L	PARTICIPANT	\N	PRESENT	0
289555	289514	19671E	PARTICIPANT	\N	PRESENT	0
289556	289514	19591F	PARTICIPANT	\N	PRESENT	0
289557	289514	14041T	PARTICIPANT	\N	PRESENT	0
289558	289514	19651A	PARTICIPANT	\N	PRESENT	0
289559	289514	14021P	PARTICIPANT	\N	PRESENT	0
289560	289514	08061X	PARTICIPANT	\N	PRESENT	0
289561	289514	07033P	PARTICIPANT	\N	PRESENT	0
289562	289514	19683J	PARTICIPANT	\N	PRESENT	0
289563	289514	11080N	PARTICIPANT	\N	PRESENT	0
289564	289514	19673G	PARTICIPANT	\N	PRESENT	0
289565	289514	19543W	PARTICIPANT	\N	PRESENT	0
289566	289514	08017T	PARTICIPANT	\N	PRESENT	0
289567	289514	11109J	PARTICIPANT	\N	PRESENT	0
289568	289514	19729F	PARTICIPANT	\N	PRESENT	0
289569	289514	11027H	PARTICIPANT	\N	PRESENT	0
289570	289514	19593H	PARTICIPANT	\N	PRESENT	0
289571	289514	04086Q	PARTICIPANT	\N	PRESENT	0
289575	289514	14065Q	PARTICIPANT	\N	PRESENT	0
289576	289514	19551W	PARTICIPANT	\N	PRESENT	0
289577	289514	11083R	PARTICIPANT	\N	PRESENT	0
289608	289514	95067Q	PARTICIPANT	\N	PRESENT	0
289609	289514	95015C	PARTICIPANT	\N	PRESENT	0
289610	289514	04035D	PARTICIPANT	\N	PRESENT	0
289611	289514	14211G	PARTICIPANT	\N	PRESENT	0
289612	289514	14169X	PARTICIPANT	\N	PRESENT	0
289638	289514	19329S	PARTICIPANT	\N	PRESENT	0
289639	289514	19733B	PARTICIPANT	\N	PRESENT	0
289640	289514	14123H	PARTICIPANT	\N	PRESENT	0
289727	289514	01028R	PARTICIPANT	\N	PRESENT	0
289728	289514	14053L	PARTICIPANT	\N	PRESENT	0
289729	289514	19581D	PARTICIPANT	\N	PRESENT	0
289730	289514	19441R	PARTICIPANT	\N	PRESENT	0
289731	289514	11085T	PARTICIPANT	\N	PRESENT	0
289732	289514	19719D	PARTICIPANT	\N	PRESENT	0
292744	270190	14030Q	PARTICIPANT	\N	PRESENT	0
292745	270190	08024S	PARTICIPANT	\N	PRESENT	0
292746	270190	18083K	PARTICIPANT	\N	PRESENT	0
292747	270190	19701S	PARTICIPANT	\N	EXCUSE	0
292748	270190	04035D	PARTICIPANT	\N	PRESENT	0
292749	270190	08031R	PARTICIPANT	\N	EXCUSE	0
292750	270190	07029T	PARTICIPANT	\N	EXCUSE	0
292751	270190	11045K	PARTICIPANT	\N	PRESENT	0
292752	270190	19749K	PARTICIPANT	\N	PRESENT	0
292800	292799	14133K	PARTICIPANT	\N	PRESENT	0
292801	292799	96004D	PRESIDENT	0	PRESENT	0
292802	292799	19725B	PARTICIPANT	\N	PRESENT	0
292803	292799	14089Y	PARTICIPANT	\N	PRESENT	0
292804	292799	98035U	PARTICIPANT	\N	EXCUSE	0
292806	292799	14237S	PARTICIPANT	\N	EXCUSE	0
292809	292799	14065Q	PARTICIPANT	\N	EXCUSE	0
292810	292799	08014Q	PARTICIPANT	\N	EXCUSE	0
292839	292799	14073Q	PARTICIPANT	\N	EXCUSE	0
292840	292799	14061L	PARTICIPANT	\N	EXCUSE	0
292841	292799	10015M	PARTICIPANT	\N	EXCUSE	0
292845	292844	14133K	PARTICIPANT	\N	PRESENT	0
292846	292844	14065Q	PARTICIPANT	\N	EXCUSE	0
292847	292844	96004D	PRESIDENT	0	PRESENT	0
292848	292844	08014Q	PARTICIPANT	\N	EXCUSE	0
292849	292844	14079W	PARTICIPANT	\N	PRESENT	0
292850	292844	19725B	PARTICIPANT	\N	PRESENT	0
287634	287632	14255U	PARTICIPANT	\N	PRESENT	0
287635	287632	04042C	PARTICIPANT	\N	PRESENT	0
287636	287632	19251M	PARTICIPANT	\N	PRESENT	0
287637	287632	04035D	PARTICIPANT	\N	PRESENT	0
287638	287632	98022P	PARTICIPANT	\N	EXCUSE	0
287639	287632	04097T	PARTICIPANT	\N	PRESENT	0
287640	287632	14097Y	PARTICIPANT	\N	PRESENT	0
287641	287632	14073Q	PARTICIPANT	\N	PRESENT	0
287642	287632	19709B	PARTICIPANT	\N	EXCUSE	0
287643	287632	14001X	PARTICIPANT	\N	EXCUSE	0
287644	287632	14221J	PARTICIPANT	\N	PRESENT	0
287645	287632	04057K	PARTICIPANT	\N	EXCUSE	0
287646	287632	98050T	PARTICIPANT	\N	PRESENT	0
287647	287632	98035U	PARTICIPANT	\N	PRESENT	0
287648	287632	04034C	PARTICIPANT	\N	PRESENT	0
287687	287686	08039A	PARTICIPANT	\N	PRESENT	0
287929	287928	08018U	PARTICIPANT	\N	PRESENT	0
287931	287930	08018U	PARTICIPANT	\N	PRESENT	0
289279	287933	14028W	PARTICIPANT	\N	EXCUSE	0
289354	289353	08019V	PARTICIPANT	\N	PRESENT	0
289453	287933	14231L	PARTICIPANT	\N	EXCUSE	0
289468	287933	08048B	PARTICIPANT	\N	EXCUSE	0
289471	287933	14259Y	PARTICIPANT	\N	EXCUSE	0
289478	289477	08043V	PARTICIPANT	\N	PRESENT	0
289479	289477	04038G	PARTICIPANT	\N	PRESENT	0
289480	289477	14357A	PARTICIPANT	\N	EXCUSE	0
289481	289477	11070L	PARTICIPANT	\N	PRESENT	0
289482	289477	19711U	PARTICIPANT	\N	PRESENT	0
289483	289477	04097T	PARTICIPANT	\N	PRESENT	0
289484	289477	14179A	PARTICIPANT	\N	PRESENT	0
289485	289477	17637T	PARTICIPANT	\N	PRESENT	0
289486	289477	11041F	PARTICIPANT	\N	PRESENT	0
289487	289477	19531S	PARTICIPANT	\N	EXCUSE	0
289583	282397	14087W	PARTICIPANT	\N	PRESENT	0
289584	282397	19521Q	PARTICIPANT	\N	PRESENT	0
289585	282397	19679N	PARTICIPANT	\N	PRESENT	0
289586	282397	14071N	PARTICIPANT	\N	PRESENT	0
289588	289587	14087W	PARTICIPANT	\N	PRESENT	0
289589	289587	19521Q	PARTICIPANT	\N	PRESENT	0
289590	289587	19679N	PARTICIPANT	\N	PRESENT	0
289591	289587	14071N	PARTICIPANT	\N	PRESENT	0
289593	289592	14087W	PARTICIPANT	\N	PRESENT	0
289594	289592	19521Q	PARTICIPANT	\N	PRESENT	0
289595	289592	14071N	PARTICIPANT	\N	PRESENT	0
289596	289592	19679N	PARTICIPANT	\N	PRESENT	0
289598	289597	14087W	PARTICIPANT	\N	PRESENT	0
289599	289597	19679N	PARTICIPANT	\N	PRESENT	0
289600	289597	14071N	PARTICIPANT	\N	PRESENT	0
289789	289578	08015R	PARTICIPANT	\N	PRESENT	0
289790	289578	19695N	PARTICIPANT	\N	PRESENT	0
289791	289578	14033T	PARTICIPANT	\N	PRESENT	0
289792	289578	01025N	PARTICIPANT	\N	PRESENT	0
289793	289578	04088S	PARTICIPANT	\N	PRESENT	0
289794	289578	19507S	PARTICIPANT	\N	PRESENT	0
289795	289578	08062Y	PARTICIPANT	\N	PRESENT	0
289797	289796	14225N	PARTICIPANT	\N	PRESENT	0
289798	289796	14133K	PARTICIPANT	\N	PRESENT	0
289799	289796	14053L	PARTICIPANT	\N	PRESENT	0
289800	289796	18083K	PARTICIPANT	\N	PRESENT	0
289801	289796	19647E	PARTICIPANT	\N	PRESENT	0
289802	289796	11026G	PARTICIPANT	\N	PRESENT	0
289803	289796	16685X	PARTICIPANT	\N	PRESENT	0
289804	289796	14107H	PARTICIPANT	\N	PRESENT	0
289811	289580	14135M	PARTICIPANT	\N	PRESENT	0
289812	289580	19467C	PARTICIPANT	\N	PRESENT	0
289813	289580	08038Y	PARTICIPANT	\N	PRESENT	0
289814	289580	19441R	PARTICIPANT	\N	PRESENT	0
289815	289580	08062Y	PARTICIPANT	\N	PRESENT	0
289816	289580	11090Q	PRESIDENT	0	PRESENT	0
289817	289580	14033T	PARTICIPANT	\N	PRESENT	0
289818	289580	80013X	PARTICIPANT	\N	PRESENT	0
289819	289580	14205J	PARTICIPANT	\N	PRESENT	0
289820	289580	04088S	PARTICIPANT	\N	PRESENT	0
289821	289580	11099A	PARTICIPANT	\N	PRESENT	0
289822	289580	04049K	PARTICIPANT	\N	PRESENT	0
289823	289580	19705W	PARTICIPANT	\N	PRESENT	0
289824	289580	19507S	PARTICIPANT	\N	PRESENT	0
289825	289580	08015R	PARTICIPANT	\N	PRESENT	0
289826	289580	19369B	PARTICIPANT	\N	PRESENT	0
289827	289580	14207L	PARTICIPANT	\N	PRESENT	0
289828	289580	19511N	PARTICIPANT	\N	PRESENT	0
289829	289580	08028W	PARTICIPANT	\N	PRESENT	0
289830	289580	14257W	PARTICIPANT	\N	PRESENT	0
289845	289756	14331P	PARTICIPANT	\N	PRESENT	0
289833	289580	14081Q	PARTICIPANT	\N	PRESENT	0
289834	289580	08068F	PARTICIPANT	\N	PRESENT	0
289835	289580	08019V	PARTICIPANT	\N	PRESENT	0
289836	289580	14197C	PARTICIPANT	\N	PRESENT	0
289837	289580	14265W	PARTICIPANT	\N	PRESENT	0
289838	289580	19591F	PARTICIPANT	\N	PRESENT	0
289839	289580	19269X	PARTICIPANT	\N	PRESENT	0
289840	289580	14115H	PARTICIPANT	\N	PRESENT	0
289841	289580	19747H	PARTICIPANT	\N	PRESENT	0
289842	289580	11081P	PARTICIPANT	\N	EXCUSE	0
289843	289756	86034E	PARTICIPANT	\N	PRESENT	0
289844	289756	11027H	PARTICIPANT	\N	PRESENT	0
289846	289756	14275Y	PARTICIPANT	\N	PRESENT	0
289847	289756	19447X	PARTICIPANT	\N	PRESENT	0
289848	289756	14105F	PARTICIPANT	\N	PRESENT	0
289849	289756	14029X	PARTICIPANT	\N	PRESENT	0
289850	289756	19681G	PARTICIPANT	\N	PRESENT	0
289851	289756	14042U	PARTICIPANT	\N	PRESENT	0
289852	289756	11110B	PARTICIPANT	\N	PRESENT	0
289855	289756	19758L	PARTICIPANT	\N	PRESENT	0
289856	289756	19479G	PARTICIPANT	\N	PRESENT	0
289857	289756	08053X	PARTICIPANT	\N	PRESENT	0
289858	289756	11074Q	PARTICIPANT	\N	PRESENT	0
289859	289756	14231L	PARTICIPANT	\N	PRESENT	0
289860	289756	19387D	PARTICIPANT	\N	PRESENT	0
289861	289756	19599P	PARTICIPANT	\N	PRESENT	0
289862	289756	08052W	PARTICIPANT	\N	PRESENT	0
289863	289756	14039A	PARTICIPANT	\N	PRESENT	0
289864	289756	98022P	PARTICIPANT	\N	PRESENT	0
289865	289756	08055A	PARTICIPANT	\N	PRESENT	0
289866	289756	08016S	PARTICIPANT	\N	PRESENT	0
289867	289756	19549D	PARTICIPANT	\N	PRESENT	0
289868	289756	19715Y	PARTICIPANT	\N	PRESENT	0
289869	289756	14051J	PARTICIPANT	\N	PRESENT	0
289870	289756	11066Q	PARTICIPANT	\N	PRESENT	0
289871	289756	14085U	PARTICIPANT	\N	PRESENT	0
289872	289756	11104D	PARTICIPANT	\N	PRESENT	0
289873	289756	08060W	PARTICIPANT	\N	PRESENT	0
289874	289756	19637C	PARTICIPANT	\N	PRESENT	0
289875	289756	19745F	PARTICIPANT	\N	PRESENT	0
289876	289756	19503N	PARTICIPANT	\N	PRESENT	0
289877	289756	19413M	PARTICIPANT	\N	PRESENT	0
289878	289756	19649G	PARTICIPANT	\N	PRESENT	0
289879	289756	14021P	PARTICIPANT	\N	PRESENT	0
289880	289756	95063L	PARTICIPANT	\N	PRESENT	0
289881	289756	11040E	PARTICIPANT	\N	PRESENT	0
289882	289756	19737F	PARTICIPANT	\N	PRESENT	0
289883	289756	19569H	PARTICIPANT	\N	PRESENT	0
289884	289756	11067R	PARTICIPANT	\N	PRESENT	0
289885	289756	08017T	PARTICIPANT	\N	PRESENT	0
289886	289756	14201E	PARTICIPANT	\N	PRESENT	0
289887	289756	19253P	PARTICIPANT	\N	PRESENT	0
289888	289756	14028W	PARTICIPANT	\N	PRESENT	0
289889	289756	11033F	PARTICIPANT	\N	PRESENT	0
289890	289756	04085P	PARTICIPANT	\N	PRESENT	0
289891	289756	19347U	PARTICIPANT	\N	PRESENT	0
289892	289756	19695N	PARTICIPANT	\N	PRESENT	0
289893	289756	08058D	PARTICIPANT	\N	PRESENT	0
289894	289756	08061X	PARTICIPANT	\N	PRESENT	0
289895	289756	11083R	PARTICIPANT	\N	PRESENT	0
289896	289756	19349W	PARTICIPANT	\N	PRESENT	0
289897	289756	19659J	PARTICIPANT	\N	PRESENT	0
289898	289756	11072N	PARTICIPANT	\N	PRESENT	0
289899	289756	11056N	PARTICIPANT	\N	PRESENT	0
289900	289756	08031R	PARTICIPANT	\N	PRESENT	0
289901	289756	19629C	PARTICIPANT	\N	PRESENT	0
289902	289756	19697Q	PARTICIPANT	\N	PRESENT	0
289903	289756	04059M	PARTICIPANT	\N	PRESENT	0
289904	289756	14197C	PARTICIPANT	\N	PRESENT	0
289905	289756	08068F	PARTICIPANT	\N	PRESENT	0
289906	289756	01028R	PARTICIPANT	\N	PRESENT	0
289907	289756	14107H	PARTICIPANT	\N	PRESENT	0
289908	289756	11077T	PARTICIPANT	\N	PRESENT	0
289909	289756	14211G	PARTICIPANT	\N	PRESENT	0
289910	289756	80013X	PARTICIPANT	\N	PRESENT	0
289911	289756	08038Y	PARTICIPANT	\N	PRESENT	0
289912	289756	17637T	PARTICIPANT	\N	PRESENT	0
289913	289756	14229S	PARTICIPANT	\N	PRESENT	0
289914	289756	14065Q	PARTICIPANT	\N	PRESENT	0
289915	289756	11101A	PARTICIPANT	\N	PRESENT	0
289916	289756	98018T	PARTICIPANT	\N	PRESENT	0
289917	289756	14281W	PARTICIPANT	\N	PRESENT	0
289918	289756	19727D	PARTICIPANT	\N	PRESENT	0
289919	289756	99004R	PARTICIPANT	\N	PRESENT	0
289920	289756	01058X	PARTICIPANT	\N	PRESENT	0
271700	270566	14239U	PARTICIPANT	\N	PRESENT	0
271701	270566	19367Y	PARTICIPANT	\N	PRESENT	0
272046	271980	08028W	PARTICIPANT	\N	PRESENT	0
272047	271980	19467C	PARTICIPANT	\N	PRESENT	0
272048	271980	19295A	PARTICIPANT	\N	PRESENT	0
272049	271980	80013X	PARTICIPANT	\N	PRESENT	0
272050	271980	08068F	PARTICIPANT	\N	PRESENT	0
272051	271980	14207L	PARTICIPANT	\N	PRESENT	0
272052	271980	11101A	PARTICIPANT	\N	PRESENT	0
272053	271980	14329V	PARTICIPANT	\N	PRESENT	0
272054	271980	19507S	PARTICIPANT	\N	PRESENT	0
272055	271980	14197C	PARTICIPANT	\N	PRESENT	0
272056	271980	14187A	PARTICIPANT	\N	PRESENT	0
272057	271980	01025N	PARTICIPANT	\N	PRESENT	0
272058	271980	14357A	PARTICIPANT	\N	PRESENT	0
272059	271980	08038Y	PARTICIPANT	\N	PRESENT	0
272060	271980	17589D	PARTICIPANT	\N	PRESENT	0
272061	271980	04089T	PARTICIPANT	\N	EXCUSE	0
272062	271980	11099A	PARTICIPANT	\N	PRESENT	0
272063	271980	04049K	PARTICIPANT	\N	EXCUSE	0
272064	271980	14205J	PARTICIPANT	\N	PRESENT	0
272065	271980	19695N	PARTICIPANT	\N	PRESENT	0
272066	271980	19565D	PARTICIPANT	\N	PRESENT	0
272067	271980	14033T	PARTICIPANT	\N	PRESENT	0
272068	271980	19511N	PARTICIPANT	\N	PRESENT	0
272069	271980	19369B	PARTICIPANT	\N	PRESENT	0
272070	271980	14257W	PARTICIPANT	\N	PRESENT	0
272071	271980	14265W	PARTICIPANT	\N	PRESENT	0
272072	271980	08021P	PARTICIPANT	\N	PRESENT	0
272073	271980	19441R	PARTICIPANT	\N	PRESENT	0
272074	271980	08015R	PARTICIPANT	\N	PRESENT	0
272075	271980	08062Y	PARTICIPANT	\N	PRESENT	0
272076	271980	19563B	PARTICIPANT	\N	PRESENT	0
272077	271980	19301E	PARTICIPANT	\N	PRESENT	0
272078	271980	19413M	PARTICIPANT	\N	PRESENT	0
272079	271980	19619A	PARTICIPANT	\N	PRESENT	0
272080	271980	11090Q	PARTICIPANT	\N	PRESENT	0
272081	271980	04088S	PARTICIPANT	\N	PRESENT	0
272082	271980	14135M	PARTICIPANT	\N	PRESENT	0
272083	271980	19705W	PARTICIPANT	\N	PRESENT	0
272084	271980	19707Y	PARTICIPANT	\N	PRESENT	0
272085	271980	11081P	PARTICIPANT	\N	EXCUSE	0
272086	271980	14115H	PARTICIPANT	\N	PRESENT	0
272087	271980	19747H	PARTICIPANT	\N	PRESENT	0
272088	271980	19631V	PARTICIPANT	\N	PRESENT	0
272089	271980	19515S	PARTICIPANT	\N	PRESENT	0
272090	271980	11083R	PARTICIPANT	\N	PRESENT	0
272524	270871	14133K	PARTICIPANT	\N	PRESENT	0
272525	270871	04040A	PARTICIPANT	\N	PRESENT	0
272526	270871	14105F	PARTICIPANT	\N	PRESENT	0
272527	270871	08058D	PARTICIPANT	\N	PRESENT	0
272528	270871	14255U	PARTICIPANT	\N	PRESENT	0
272529	270871	04042C	PRESIDENT	0	PRESENT	0
272530	270871	19721W	PARTICIPANT	\N	PRESENT	0
272531	270871	98029W	PARTICIPANT	\N	PRESENT	0
272532	270871	11080N	PARTICIPANT	\N	PRESENT	0
272533	270871	14267Y	PARTICIPANT	\N	PRESENT	0
272534	270871	11027H	PARTICIPANT	\N	PRESENT	0
272535	270871	11115U	PARTICIPANT	\N	PRESENT	0
272536	270871	14079W	PARTICIPANT	\N	PRESENT	0
272537	270871	98018T	PARTICIPANT	\N	PRESENT	0
272538	270871	19251M	PARTICIPANT	\N	PRESENT	0
272539	270871	95030B	PARTICIPANT	\N	PRESENT	0
272540	270871	98053W	PARTICIPANT	\N	EXCUSE	0
272541	270871	97011G	PARTICIPANT	\N	PRESENT	0
272542	270871	04035D	PARTICIPANT	\N	PRESENT	0
272543	270871	08056B	PARTICIPANT	\N	PRESENT	0
272544	270871	14211G	PARTICIPANT	\N	PRESENT	0
272545	270871	98022P	PARTICIPANT	\N	PRESENT	0
272546	270871	11064N	PARTICIPANT	\N	PRESENT	0
272547	270871	95037J	PARTICIPANT	\N	PRESENT	0
272548	270871	14097Y	PARTICIPANT	\N	PRESENT	0
272549	270871	19583F	PARTICIPANT	\N	EXCUSE	0
272612	270525	98053W	PARTICIPANT	\N	EXCUSE	0
272551	270871	19709B	PARTICIPANT	\N	PRESENT	0
272552	270871	16685X	PARTICIPANT	\N	PRESENT	0
272553	270871	08053X	PARTICIPANT	\N	PRESENT	0
272554	270871	08061X	PARTICIPANT	\N	PRESENT	0
272555	270871	08047A	PARTICIPANT	\N	PRESENT	0
272556	270871	14028W	PARTICIPANT	\N	PRESENT	0
272557	270871	14193X	PARTICIPANT	\N	PRESENT	0
274055	274053	19741B	PARTICIPANT	\N	PRESENT	0
272559	270871	98050T	PARTICIPANT	\N	PRESENT	0
272560	270871	14235Q	PARTICIPANT	\N	PRESENT	0
272561	270871	19443T	PARTICIPANT	\N	PRESENT	0
274056	274053	08043V	PARTICIPANT	\N	PRESENT	0
272563	270871	11054L	PARTICIPANT	\N	PRESENT	0
272564	270871	19421M	PARTICIPANT	\N	PRESENT	0
272565	270871	01058X	PARTICIPANT	\N	PRESENT	0
272566	270871	19669L	PARTICIPANT	\N	PRESENT	0
272567	270871	01062T	PARTICIPANT	\N	PRESENT	0
272568	270871	11041F	PARTICIPANT	\N	PRESENT	0
272569	270871	08049C	PARTICIPANT	\N	PRESENT	0
272570	270871	11066Q	PARTICIPANT	\N	PRESENT	0
272571	270871	95067Q	PARTICIPANT	\N	PRESENT	0
272572	270871	04034C	PARTICIPANT	\N	PRESENT	0
274057	274053	04038G	PARTICIPANT	\N	PRESENT	0
274058	274053	14357A	PARTICIPANT	\N	PRESENT	0
274059	274053	11070L	PRESIDENT	0	PRESENT	0
274060	274053	04097T	PARTICIPANT	\N	PRESENT	0
274061	274053	19711U	PARTICIPANT	\N	PRESENT	0
274062	274053	19533U	PARTICIPANT	\N	PRESENT	0
274063	274053	95062K	PARTICIPANT	\N	PRESENT	0
274064	274053	19689Q	PARTICIPANT	\N	PRESENT	0
274065	274053	19253P	PARTICIPANT	\N	EXCUSE	0
274066	274053	11041F	PARTICIPANT	\N	EXCUSE	0
275869	275868	05008E	PRESIDENT	0	PRESENT	0
275870	275868	14069U	PARTICIPANT	\N	PRESENT	0
275871	275868	08018U	PARTICIPANT	\N	PRESENT	0
275872	275868	14089Y	PARTICIPANT	\N	PRESENT	0
275873	275868	11026G	PARTICIPANT	\N	PRESENT	0
275874	275868	14151M	PARTICIPANT	\N	PRESENT	0
275875	275868	11072N	PARTICIPANT	\N	PRESENT	0
275876	275868	19649G	PARTICIPANT	\N	PRESENT	0
275879	275878	14193X	PARTICIPANT	\N	PRESENT	0
275880	275878	08053X	PARTICIPANT	\N	PRESENT	0
275881	275878	95067Q	PARTICIPANT	\N	PRESENT	0
275882	275878	14235Q	PARTICIPANT	\N	PRESENT	0
277553	263769	19733B	PARTICIPANT	\N	PRESENT	0
277554	263769	18083K	PARTICIPANT	\N	PRESENT	0
277555	263769	01024M	PARTICIPANT	\N	PRESENT	0
277556	263769	19507S	PARTICIPANT	\N	PRESENT	0
277557	263769	04088S	PARTICIPANT	\N	PRESENT	0
277558	263769	98018T	PARTICIPANT	\N	PRESENT	0
277559	263769	04061F	PARTICIPANT	\N	PRESENT	0
277560	263769	14069U	PARTICIPANT	\N	PRESENT	0
277561	263769	97011G	PARTICIPANT	\N	PRESENT	0
277562	263769	14055N	PARTICIPANT	\N	PRESENT	0
277563	276029	19367Y	PARTICIPANT	\N	PRESENT	0
277564	263769	19731Y	PARTICIPANT	\N	PRESENT	0
277565	263769	14029X	PARTICIPANT	\N	PRESENT	0
277566	263769	19515S	PARTICIPANT	\N	PRESENT	0
277567	263769	14105F	PARTICIPANT	\N	PRESENT	0
277568	276029	11063M	PARTICIPANT	\N	PRESENT	0
277569	263769	19621T	PARTICIPANT	\N	PRESENT	0
277570	276029	14042U	PARTICIPANT	\N	PRESENT	0
277571	276029	11045K	PARTICIPANT	\N	PRESENT	0
277572	263769	19399H	PARTICIPANT	\N	PRESENT	0
277573	263769	08062Y	PARTICIPANT	\N	PRESENT	0
277574	263769	14265W	PARTICIPANT	\N	PRESENT	0
277575	263769	19383Y	PARTICIPANT	\N	PRESENT	0
277576	263769	19671E	PARTICIPANT	\N	PRESENT	0
277577	263769	14079W	PARTICIPANT	\N	PRESENT	0
277578	263769	88008L	PARTICIPANT	\N	PRESENT	0
277579	263769	08045X	PARTICIPANT	\N	PRESENT	0
277580	263769	19629C	PARTICIPANT	\N	PRESENT	0
277581	276029	19691J	PARTICIPANT	\N	PRESENT	0
277582	263769	14073Q	PARTICIPANT	\N	PRESENT	0
277583	276029	19527W	PARTICIPANT	\N	PRESENT	0
277584	263769	19713W	PARTICIPANT	\N	PRESENT	0
277585	263769	14031R	PARTICIPANT	\N	PRESENT	0
277586	263769	08055A	PARTICIPANT	\N	PRESENT	0
277587	276029	19675J	PARTICIPANT	\N	PRESENT	0
277588	276029	19679N	PARTICIPANT	\N	PRESENT	0
277589	276029	14213J	PARTICIPANT	\N	PRESENT	0
277590	276029	08052W	PARTICIPANT	\N	PRESENT	0
277591	263769	19549D	PARTICIPANT	\N	PRESENT	0
277592	263769	19489J	PARTICIPANT	\N	PRESENT	0
277593	263769	19543W	PARTICIPANT	\N	PRESENT	0
277594	263769	14191V	PARTICIPANT	\N	PRESENT	0
277595	263769	14033T	PARTICIPANT	\N	PRESENT	0
277596	263769	14103D	PARTICIPANT	\N	PRESENT	0
277597	263769	11048N	PARTICIPANT	\N	PRESENT	0
277598	263769	14241N	PARTICIPANT	\N	PRESENT	0
277599	276029	11067R	PARTICIPANT	\N	EXCUSE	0
277600	263769	08012N	PARTICIPANT	\N	PRESENT	0
277601	263769	01028R	PARTICIPANT	\N	PRESENT	0
277602	263769	98022P	PARTICIPANT	\N	PRESENT	0
277603	263769	11033F	PARTICIPANT	\N	PRESENT	0
285477	276229	14087W	PARTICIPANT	\N	PRESENT	0
285478	276229	19521Q	PARTICIPANT	\N	PRESENT	0
285479	276229	19679N	PARTICIPANT	\N	PRESENT	0
285481	285480	14087W	PARTICIPANT	\N	PRESENT	0
285482	285480	19521Q	PARTICIPANT	\N	PRESENT	0
285483	285480	19679N	PARTICIPANT	\N	PRESENT	0
285484	276347	14087W	PARTICIPANT	\N	PRESENT	0
285485	276347	19521Q	PARTICIPANT	\N	PRESENT	0
285486	276347	19679N	PARTICIPANT	\N	PRESENT	0
285487	276449	14087W	PARTICIPANT	\N	PRESENT	0
285488	276449	19521Q	PARTICIPANT	\N	PRESENT	0
285489	276449	19679N	PARTICIPANT	\N	PRESENT	0
285491	285490	14087W	PARTICIPANT	\N	PRESENT	0
285492	285490	19521Q	PARTICIPANT	\N	PRESENT	0
285493	285490	19679N	PARTICIPANT	\N	PRESENT	0
285494	276466	14087W	PARTICIPANT	\N	PRESENT	0
285495	276466	19521Q	PARTICIPANT	\N	PRESENT	0
285496	276466	19679N	PARTICIPANT	\N	PRESENT	0
285497	276466	08052W	PARTICIPANT	\N	PRESENT	0
285498	276466	19697Q	PARTICIPANT	\N	PRESENT	0
285499	276470	14087W	PARTICIPANT	\N	PRESENT	0
285500	276470	19521Q	PARTICIPANT	\N	PRESENT	0
285501	276470	19679N	PARTICIPANT	\N	PRESENT	0
285502	276470	19569H	PARTICIPANT	\N	PRESENT	0
285504	276474	19521Q	PARTICIPANT	\N	PRESENT	0
285505	276474	14087W	PARTICIPANT	\N	PRESENT	0
285507	276474	19679N	PARTICIPANT	\N	PRESENT	0
285564	276479	14087W	PARTICIPANT	\N	PRESENT	0
285565	276479	19521Q	PARTICIPANT	\N	PRESENT	0
285566	276479	19679N	PARTICIPANT	\N	PRESENT	0
285574	276486	14087W	PARTICIPANT	\N	PRESENT	0
285575	276486	19521Q	PARTICIPANT	\N	PRESENT	0
285576	276486	19679N	PARTICIPANT	\N	PRESENT	0
285581	284424	14087W	PARTICIPANT	\N	PRESENT	0
285582	284424	19521Q	PARTICIPANT	\N	PRESENT	0
285583	284424	19679N	PARTICIPANT	\N	PRESENT	0
285630	284424	14071N	PARTICIPANT	\N	PRESENT	0
285631	284424	11067R	PARTICIPANT	\N	PRESENT	0
285634	284599	14087W	PARTICIPANT	\N	PRESENT	0
285635	284599	19521Q	PARTICIPANT	\N	PRESENT	0
285638	284599	19679N	PARTICIPANT	\N	PRESENT	0
285640	284599	14071N	PARTICIPANT	\N	PRESENT	0
285641	284624	14087W	PARTICIPANT	\N	PRESENT	0
285642	284624	19521Q	PARTICIPANT	\N	PRESENT	0
285643	284624	14071N	PARTICIPANT	\N	PRESENT	0
285644	284624	19679N	PARTICIPANT	\N	PRESENT	0
285645	284627	14087W	PARTICIPANT	\N	PRESENT	0
285646	284627	19521Q	PARTICIPANT	\N	PRESENT	0
285647	284627	19679N	PARTICIPANT	\N	PRESENT	0
285649	284627	14071N	PARTICIPANT	\N	PRESENT	0
285650	284758	14087W	PARTICIPANT	\N	PRESENT	0
285651	284758	19521Q	PARTICIPANT	\N	PRESENT	0
285652	284758	14071N	PARTICIPANT	\N	PRESENT	0
285653	284758	19679N	PARTICIPANT	\N	PRESENT	0
285656	284793	14087W	PARTICIPANT	\N	PRESENT	0
285657	284793	19521Q	PARTICIPANT	\N	PRESENT	0
285658	284793	14071N	PARTICIPANT	\N	PRESENT	0
285659	284793	19679N	PARTICIPANT	\N	PRESENT	0
286449	286328	14065Q	PARTICIPANT	\N	EXCUSE	0
286452	286328	19729F	PARTICIPANT	\N	EXCUSE	0
286518	286328	19543W	PARTICIPANT	\N	PRESENT	0
287576	285998	14083S	PARTICIPANT	\N	PRESENT	0
287577	273914	14119M	PARTICIPANT	\N	PRESENT	0
287578	273914	08017T	PARTICIPANT	\N	PRESENT	0
287579	273914	08039A	PARTICIPANT	\N	PRESENT	0
287580	273914	08031R	PARTICIPANT	\N	PRESENT	0
287581	273914	11067R	PARTICIPANT	\N	PRESENT	0
287582	273914	19387D	PARTICIPANT	\N	PRESENT	0
287583	273914	14028W	PARTICIPANT	\N	PRESENT	0
287584	273914	15447F	PARTICIPANT	\N	PRESENT	0
287585	273914	17637T	PARTICIPANT	\N	PRESENT	0
287586	273914	19643A	PARTICIPANT	\N	PRESENT	0
287587	273914	19515S	PARTICIPANT	\N	PRESENT	0
287588	273914	11012A	PARTICIPANT	\N	PRESENT	0
287589	273914	14105F	PARTICIPANT	\N	PRESENT	0
287590	273914	19715Y	PARTICIPANT	\N	PRESENT	0
287591	273914	11027H	PARTICIPANT	\N	PRESENT	0
287592	273914	12041X	PARTICIPANT	\N	PRESENT	0
287593	273914	11033F	PARTICIPANT	\N	PRESENT	0
287594	273914	19747H	PARTICIPANT	\N	PRESENT	0
287595	273914	08019V	PARTICIPANT	\N	PRESENT	0
287596	273914	11080N	PARTICIPANT	\N	PRESENT	0
289754	287933	05012A	PARTICIPANT	\N	EXCUSE	0
292555	273930	08055A	PARTICIPANT	\N	PRESENT	0
292556	273930	14207L	PARTICIPANT	\N	PRESENT	0
292557	273930	14021P	PARTICIPANT	\N	PRESENT	0
292558	273930	80013X	PARTICIPANT	\N	PRESENT	0
292559	273930	19503N	PARTICIPANT	\N	PRESENT	0
292560	273930	08060W	PARTICIPANT	\N	PRESENT	0
292561	273930	14107H	PARTICIPANT	\N	PRESENT	0
292562	273930	19413M	PARTICIPANT	\N	PRESENT	0
292563	273930	14097Y	PARTICIPANT	\N	PRESENT	0
292564	273930	17589D	PARTICIPANT	\N	PRESENT	0
292565	273930	19737F	PARTICIPANT	\N	PRESENT	0
292566	273930	14255U	PARTICIPANT	\N	PRESENT	0
292567	273930	14215L	PARTICIPANT	\N	PRESENT	0
292568	273930	11097X	PARTICIPANT	\N	PRESENT	0
292569	273930	19383Y	PARTICIPANT	\N	PRESENT	0
292570	273930	98050T	PARTICIPANT	\N	PRESENT	0
292571	273930	14265W	PARTICIPANT	\N	PRESENT	0
292572	273930	19507S	PARTICIPANT	\N	PRESENT	0
292574	273930	14033T	PARTICIPANT	\N	PRESENT	0
292575	273930	19349W	PARTICIPANT	\N	PRESENT	0
292576	273930	14157T	PARTICIPANT	\N	PRESENT	0
292579	273930	19447X	PARTICIPANT	\N	PRESENT	0
292581	273930	95062K	PARTICIPANT	\N	PRESENT	0
292583	273930	11099A	PARTICIPANT	\N	PRESENT	0
292585	273930	08010L	PARTICIPANT	\N	PRESENT	0
292592	273930	19563B	PARTICIPANT	\N	PRESENT	0
292593	273930	11090Q	PARTICIPANT	\N	PRESENT	0
292594	273930	14205J	PARTICIPANT	\N	PRESENT	0
292595	273930	14135M	PARTICIPANT	\N	PRESENT	0
292596	273930	11056N	PARTICIPANT	\N	PRESENT	0
292597	273930	19695N	PARTICIPANT	\N	PRESENT	0
292553	273930	11070L	PARTICIPANT	\N	PRESENT	0
292554	273930	19333N	PARTICIPANT	\N	PRESENT	0
292598	273930	19741B	PARTICIPANT	\N	PRESENT	0
292599	273930	19549D	PARTICIPANT	\N	PRESENT	0
292600	273930	19441R	PARTICIPANT	\N	PRESENT	0
292601	273930	14221J	PARTICIPANT	\N	PRESENT	0
292602	273930	19347U	PARTICIPANT	\N	PRESENT	0
292603	273930	19683J	PARTICIPANT	\N	PRESENT	0
292604	273930	08019V	PARTICIPANT	\N	PRESENT	0
292605	273930	04045F	PARTICIPANT	\N	PRESENT	0
292606	273930	14257W	PARTICIPANT	\N	PRESENT	0
292607	273930	19747H	PARTICIPANT	\N	PRESENT	0
292608	273930	04085P	PARTICIPANT	\N	PRESENT	0
292609	273930	19565D	PARTICIPANT	\N	PRESENT	0
292610	273930	11033F	PARTICIPANT	\N	PRESENT	0
292611	273930	08016S	PARTICIPANT	\N	PRESENT	0
292612	273930	19619A	PARTICIPANT	\N	PRESENT	0
292613	273930	14357A	PARTICIPANT	\N	PRESENT	0
292614	273930	19301E	PARTICIPANT	\N	PRESENT	0
292615	273930	08034U	PARTICIPANT	\N	PRESENT	0
292880	273967	11045K	PARTICIPANT	\N	PRESENT	0
292881	273967	98050T	PARTICIPANT	\N	PRESENT	0
292882	273967	17589D	PARTICIPANT	\N	PRESENT	0
292883	273967	95062K	PARTICIPANT	\N	PRESENT	0
292884	273967	08052W	PARTICIPANT	\N	PRESENT	0
292885	273967	19693L	PARTICIPANT	\N	PRESENT	0
292886	273967	14083S	PARTICIPANT	\N	PRESENT	0
292887	273967	14069U	PARTICIPANT	\N	PRESENT	0
292888	273967	19399H	PARTICIPANT	\N	PRESENT	0
292889	273967	80013X	PARTICIPANT	\N	PRESENT	0
292890	273967	05012A	PARTICIPANT	\N	PRESENT	0
292894	273967	17637T	PARTICIPANT	\N	PRESENT	0
292895	273967	19621T	PARTICIPANT	\N	PRESENT	0
292896	273967	04070G	PARTICIPANT	\N	PRESENT	0
292897	273967	11056N	PARTICIPANT	\N	PRESENT	0
292910	273967	19697Q	PARTICIPANT	\N	PRESENT	0
292911	273967	11012A	PARTICIPANT	\N	PRESENT	0
292912	273967	19657G	PARTICIPANT	\N	PRESENT	0
292913	273967	11026G	PARTICIPANT	\N	PRESENT	0
292919	273967	19269X	PARTICIPANT	\N	PRESENT	0
292934	273967	08009T	PARTICIPANT	\N	PRESENT	0
292935	273967	19387D	PARTICIPANT	\N	PRESENT	0
292936	273967	19713W	PARTICIPANT	\N	PRESENT	0
271249	271231	08048B	PARTICIPANT	\N	EXCUSE	0
272425	272424	19741B	PARTICIPANT	\N	EXCUSE	0
272426	272424	08043V	PARTICIPANT	\N	PRESENT	0
272427	272424	04038G	PARTICIPANT	\N	PRESENT	0
272428	272424	19253P	PARTICIPANT	\N	PRESENT	0
272429	272424	14357A	PARTICIPANT	\N	PRESENT	0
272430	272424	11070L	PRESIDENT	0	PRESENT	0
272431	272424	19711U	PARTICIPANT	\N	PRESENT	0
272432	272424	12016W	PARTICIPANT	\N	PRESENT	0
272433	272424	17637T	PARTICIPANT	\N	PRESENT	0
272434	272424	19533U	PARTICIPANT	\N	PRESENT	0
272435	272424	95062K	PARTICIPANT	\N	PRESENT	0
272436	272424	11041F	PARTICIPANT	\N	PRESENT	0
272437	272424	04097T	PARTICIPANT	\N	EXCUSE	0
272438	272424	19671E	PARTICIPANT	\N	EXCUSE	0
272440	272439	19741B	PARTICIPANT	\N	PRESENT	0
272441	272439	08043V	PARTICIPANT	\N	EXCUSE	0
272442	272439	04038G	PARTICIPANT	\N	PRESENT	0
272443	272439	19253P	PARTICIPANT	\N	PRESENT	0
272444	272439	14357A	PARTICIPANT	\N	PRESENT	0
272445	272439	11070L	PRESIDENT	0	PRESENT	0
272446	272439	04097T	PARTICIPANT	\N	EXCUSE	0
272447	272439	19711U	PARTICIPANT	\N	PRESENT	0
272448	272439	12016W	PARTICIPANT	\N	PRESENT	0
272449	272439	19671E	PARTICIPANT	\N	PRESENT	0
272450	272439	17637T	PARTICIPANT	\N	PRESENT	0
272451	272439	19533U	PARTICIPANT	\N	PRESENT	0
272452	272439	95062K	PARTICIPANT	\N	PRESENT	0
272453	272439	11041F	PARTICIPANT	\N	PRESENT	0
272455	272454	19741B	PARTICIPANT	\N	PRESENT	0
272456	272454	08043V	PARTICIPANT	\N	PRESENT	0
272457	272454	04038G	PARTICIPANT	\N	PRESENT	0
272458	272454	14357A	PARTICIPANT	\N	PRESENT	0
272459	272454	11070L	PRESIDENT	0	PRESENT	0
272460	272454	04097T	PARTICIPANT	\N	PRESENT	0
272461	272454	19711U	PARTICIPANT	\N	PRESENT	0
272462	272454	17637T	PARTICIPANT	\N	PRESENT	0
272463	272454	19533U	PARTICIPANT	\N	PRESENT	0
272464	272454	19689Q	PARTICIPANT	\N	PRESENT	0
272465	272454	11041F	PARTICIPANT	\N	PRESENT	0
272466	272454	12016W	PARTICIPANT	\N	PRESENT	0
272520	272519	04047H	PARTICIPANT	\N	PRESENT	0
272521	272519	11026G	PARTICIPANT	\N	PRESENT	0
273461	273460	14133K	PARTICIPANT	\N	PRESENT	0
273462	273460	14097Y	PARTICIPANT	\N	PRESENT	0
273488	273487	04047H	PARTICIPANT	\N	PRESENT	0
273490	273487	19673G	PARTICIPANT	\N	PRESENT	0
273491	273487	11026G	PARTICIPANT	\N	PRESENT	0
276131	274851	04044E	PARTICIPANT	\N	EXCUSE	0
276465	274851	08038Y	PARTICIPANT	\N	EXCUSE	0
277970	277969	11066Q	PARTICIPANT	\N	PRESENT	0
277971	277969	14097Y	PARTICIPANT	\N	PRESENT	0
277972	277969	08053X	PARTICIPANT	\N	PRESENT	0
277973	277969	95067Q	PARTICIPANT	\N	PRESENT	0
278857	278358	10015M	PARTICIPANT	\N	PRESENT	0
278858	278358	14331P	PARTICIPANT	\N	PRESENT	0
278859	278358	14327T	PARTICIPANT	\N	PRESENT	0
278860	278358	19503N	PARTICIPANT	\N	PRESENT	0
278861	278358	19531S	PARTICIPANT	\N	PRESENT	0
278862	278358	19383Y	PARTICIPANT	\N	PRESENT	0
279095	279094	08018U	PARTICIPANT	\N	PRESENT	0
279258	276025	14239U	PARTICIPANT	\N	PRESENT	0
292852	292844	14097Y	PARTICIPANT	\N	PRESENT	0
292853	292844	14061L	PARTICIPANT	\N	EXCUSE	0
292854	292844	14073Q	PARTICIPANT	\N	EXCUSE	0
292855	292844	04057K	PARTICIPANT	\N	PRESENT	0
292856	292844	19563B	PARTICIPANT	\N	PRESENT	0
292857	292844	14237S	PARTICIPANT	\N	EXCUSE	0
292858	292844	98035U	PARTICIPANT	\N	EXCUSE	0
292859	292844	10015M	PARTICIPANT	\N	EXCUSE	0
292860	292844	04049K	PARTICIPANT	\N	PRESENT	0
292861	292844	04088S	PARTICIPANT	\N	PRESENT	0
292862	292844	14265W	PARTICIPANT	\N	PRESENT	0
292863	292844	16685X	PARTICIPANT	\N	PRESENT	0
292864	292844	14051J	PARTICIPANT	\N	PRESENT	0
292865	292844	14121F	PARTICIPANT	\N	PRESENT	0
292866	292844	14087W	PARTICIPANT	\N	PRESENT	0
292867	292844	14255U	PARTICIPANT	\N	PRESENT	0
299930	289193	19565D	PARTICIPANT	\N	PRESENT	0
300068	289193	14225N	PARTICIPANT	\N	PRESENT	0
300069	289193	11109J	PARTICIPANT	\N	PRESENT	0
300070	289193	14329V	PARTICIPANT	\N	PRESENT	0
300071	289193	08016S	PARTICIPANT	\N	PRESENT	0
300072	289193	14179A	PARTICIPANT	\N	PRESENT	0
300073	289193	01058X	PARTICIPANT	\N	PRESENT	0
300074	289193	04033B	PARTICIPANT	\N	PRESENT	0
300075	289193	14071N	PARTICIPANT	\N	PRESENT	0
300076	289193	99004R	PARTICIPANT	\N	PRESENT	0
300077	289193	10015M	PARTICIPANT	\N	PRESENT	0
300078	289193	14123H	PARTICIPANT	\N	PRESENT	0
300079	289193	11033F	PARTICIPANT	\N	PRESENT	0
300080	289193	19693L	PARTICIPANT	\N	PRESENT	0
300081	289193	08034U	PARTICIPANT	\N	PRESENT	0
300082	289193	14241N	PARTICIPANT	\N	PRESENT	0
300083	289193	14085U	PARTICIPANT	\N	PRESENT	0
300084	289193	19585H	PARTICIPANT	\N	PRESENT	0
300085	289193	14111D	PARTICIPANT	\N	PRESENT	0
300086	289193	19253P	PARTICIPANT	\N	PRESENT	0
300087	289193	19762G	PARTICIPANT	\N	PRESENT	0
300088	289193	07034Q	PARTICIPANT	\N	PRESENT	0
300089	289193	14193X	PARTICIPANT	\N	PRESENT	0
300090	289193	04061F	PARTICIPANT	\N	PRESENT	0
300091	289193	19733B	PARTICIPANT	\N	PRESENT	0
300092	289193	14031R	PARTICIPANT	\N	PRESENT	0
300093	289193	14259Y	PARTICIPANT	\N	PRESENT	0
300094	289193	14205J	PARTICIPANT	\N	PRESENT	0
300095	289193	14251Q	PARTICIPANT	\N	PRESENT	0
300096	289193	14257W	PARTICIPANT	\N	PRESENT	0
300097	289193	80013X	PARTICIPANT	\N	PRESENT	0
300098	289193	19581D	PARTICIPANT	\N	PRESENT	0
300099	289193	19479G	PARTICIPANT	\N	PRESENT	0
300100	289193	14069U	PARTICIPANT	\N	PRESENT	0
300101	289193	14267Y	PARTICIPANT	\N	PRESENT	0
300102	289193	11101A	PARTICIPANT	\N	PRESENT	0
300103	289193	04043D	PARTICIPANT	\N	PRESENT	0
300104	289193	11053K	PARTICIPANT	\N	PRESENT	0
300114	289193	19295A	PARTICIPANT	\N	PRESENT	0
300115	289193	01028R	PARTICIPANT	\N	PRESENT	0
300139	289193	14053L	PARTICIPANT	\N	PRESENT	0
300140	289193	11099A	PARTICIPANT	\N	PRESENT	0
300141	289193	19369B	PARTICIPANT	\N	PRESENT	0
300143	289193	14213J	PARTICIPANT	\N	PRESENT	0
300144	300142	04042C	PARTICIPANT	\N	PRESENT	0
300145	300142	19643A	PARTICIPANT	\N	PRESENT	0
300146	300142	04033B	PARTICIPANT	\N	PRESENT	0
300147	300142	08034U	PARTICIPANT	\N	PRESENT	0
300148	300142	19647E	PARTICIPANT	\N	PRESENT	0
300149	300142	14021P	PARTICIPANT	\N	PRESENT	0
300150	300142	19367Y	PARTICIPANT	\N	PRESENT	0
300151	300142	04035D	PARTICIPANT	\N	PRESENT	0
300152	300142	10006L	PARTICIPANT	\N	PRESENT	0
300153	300142	95062K	PARTICIPANT	\N	PRESENT	0
300154	300142	14026U	PARTICIPANT	\N	PRESENT	0
300155	289193	19647E	PARTICIPANT	\N	PRESENT	0
300156	300142	08058D	PARTICIPANT	\N	PRESENT	0
300157	300142	01058X	PARTICIPANT	\N	PRESENT	0
300158	300142	08048B	PARTICIPANT	\N	PRESENT	0
300159	300142	14041T	PARTICIPANT	\N	PRESENT	0
300160	300142	14331P	PARTICIPANT	\N	PRESENT	0
300161	300142	04097T	PARTICIPANT	\N	PRESENT	0
300162	300142	10015M	PARTICIPANT	\N	PRESENT	0
300163	300142	97011G	PARTICIPANT	\N	PRESENT	0
300164	300142	04049K	PARTICIPANT	\N	PRESENT	0
300165	300142	18083K	PARTICIPANT	\N	PRESENT	0
300166	289193	19421M	PARTICIPANT	\N	PRESENT	0
300168	289193	19553Y	PARTICIPANT	\N	PRESENT	0
289921	289756	08012N	PARTICIPANT	\N	PRESENT	0
289922	289756	96004D	PARTICIPANT	\N	PRESENT	0
289923	289756	17779H	PARTICIPANT	\N	PRESENT	0
289924	289756	14157T	PARTICIPANT	\N	PRESENT	0
289925	289756	14121F	PARTICIPANT	\N	PRESENT	0
289926	289756	08039A	PARTICIPANT	\N	PRESENT	0
289927	289756	08010L	PARTICIPANT	\N	PRESENT	0
289928	289756	14159V	PARTICIPANT	\N	PRESENT	0
289929	289756	19647E	PARTICIPANT	\N	PRESENT	0
289930	289756	95015C	PARTICIPANT	\N	PRESENT	0
289931	289756	04092N	PARTICIPANT	\N	PRESENT	0
289932	289756	04044E	PARTICIPANT	\N	PRESENT	0
289933	289756	11097X	PARTICIPANT	\N	PRESENT	0
289934	289756	14081Q	PARTICIPANT	\N	PRESENT	0
289935	289756	11045K	PARTICIPANT	\N	PRESENT	0
289936	289756	14207L	PARTICIPANT	\N	PRESENT	0
289937	289756	08024S	PARTICIPANT	\N	PRESENT	0
289938	289756	19725B	PARTICIPANT	\N	PRESENT	0
289939	289756	19333N	PARTICIPANT	\N	PRESENT	0
289940	289756	14187A	PARTICIPANT	\N	PRESENT	0
289941	289756	14001X	PARTICIPANT	\N	PRESENT	0
289942	289756	14227Q	PARTICIPANT	\N	PRESENT	0
289943	289756	04033B	PARTICIPANT	\N	PRESENT	0
289944	289756	19489J	PARTICIPANT	\N	PRESENT	0
289945	289756	08028W	PARTICIPANT	\N	PRESENT	0
289946	289756	19689Q	PARTICIPANT	\N	PRESENT	0
289947	289756	14223L	PARTICIPANT	\N	PRESENT	0
289948	289756	11026G	PARTICIPANT	\N	PRESENT	0
289949	289756	10015M	PARTICIPANT	\N	PRESENT	0
289950	289756	19591F	PARTICIPANT	\N	PRESENT	0
289951	289756	15447F	PARTICIPANT	\N	PRESENT	0
289952	289756	19515S	PARTICIPANT	\N	PRESENT	0
289953	289756	19551W	PARTICIPANT	\N	PRESENT	0
289954	289756	19527W	PARTICIPANT	\N	PRESENT	0
289955	289756	19631V	PARTICIPANT	\N	PRESENT	0
289956	289756	14191V	PARTICIPANT	\N	PRESENT	0
289957	289756	11080N	PARTICIPANT	\N	PRESENT	0
289958	289756	14109K	PARTICIPANT	\N	PRESENT	0
289959	289756	14097Y	PARTICIPANT	\N	PRESENT	0
289960	289756	14257W	PARTICIPANT	\N	PRESENT	0
289961	289756	19669L	PARTICIPANT	\N	PRESENT	0
289962	289756	19295A	PARTICIPANT	\N	PRESENT	0
289963	289756	14151M	PARTICIPANT	\N	PRESENT	0
289964	289756	04038G	PARTICIPANT	\N	PRESENT	0
289965	289756	19565D	PARTICIPANT	\N	PRESENT	0
289966	289756	12041X	PARTICIPANT	\N	PRESENT	0
289967	289756	14235Q	PARTICIPANT	\N	PRESENT	0
289968	289756	19687N	PARTICIPANT	\N	PRESENT	0
289969	289756	04045F	PARTICIPANT	\N	PRESENT	0
289970	289756	88008L	PARTICIPANT	\N	PRESENT	0
289971	289756	19269X	PARTICIPANT	\N	PRESENT	0
289972	289756	19301E	PARTICIPANT	\N	PRESENT	0
289973	289756	01057W	PARTICIPANT	\N	PRESENT	0
289974	289756	87003B	PARTICIPANT	\N	PRESENT	0
289975	289756	19651A	PARTICIPANT	\N	PRESENT	0
289976	289756	14215L	PARTICIPANT	\N	PRESENT	0
289977	289756	14055N	PARTICIPANT	\N	PRESENT	0
289978	289756	14239U	PARTICIPANT	\N	PRESENT	0
289979	289756	14111D	PARTICIPANT	\N	PRESENT	0
289980	289756	19585H	PARTICIPANT	\N	PRESENT	0
289981	289756	19545Y	PARTICIPANT	\N	PRESENT	0
289982	289756	04057K	PARTICIPANT	\N	PRESENT	0
289983	289756	19563B	PARTICIPANT	\N	PRESENT	0
289984	289756	11099A	PARTICIPANT	\N	PRESENT	0
289985	289756	14193X	PARTICIPANT	\N	PRESENT	0
289986	289756	07034Q	PARTICIPANT	\N	PRESENT	0
289987	289756	19289C	PARTICIPANT	\N	PRESENT	0
289988	289756	19719D	PARTICIPANT	\N	PRESENT	0
289989	289756	19553Y	PARTICIPANT	\N	PRESENT	0
289990	289756	19533U	PARTICIPANT	\N	PRESENT	0
289991	289756	14261S	PARTICIPANT	\N	PRESENT	0
289992	289756	11012A	PARTICIPANT	\N	PRESENT	0
289993	289756	14093U	PARTICIPANT	\N	PRESENT	0
289994	289756	19741B	PARTICIPANT	\N	PRESENT	0
289995	289756	08034U	PARTICIPANT	\N	PRESENT	0
289996	289756	14030Q	PARTICIPANT	\N	PRESENT	0
289997	289756	98023Q	PARTICIPANT	\N	PRESENT	0
289998	289756	04040A	PARTICIPANT	\N	PRESENT	0
289999	289756	19369B	PARTICIPANT	\N	PRESENT	0
290000	289756	14205J	PARTICIPANT	\N	PRESENT	0
290001	289756	19511N	PARTICIPANT	\N	PRESENT	0
290002	289756	19691J	PARTICIPANT	\N	PRESENT	0
290003	289756	19575F	PARTICIPANT	\N	PRESENT	0
290004	289756	19667J	PARTICIPANT	\N	PRESENT	0
290005	289756	19699S	PARTICIPANT	\N	PRESENT	0
290006	289756	14031R	PARTICIPANT	\N	PRESENT	0
290007	289756	19721W	PARTICIPANT	\N	PRESENT	0
290008	289756	16685X	PARTICIPANT	\N	PRESENT	0
290009	289756	11010L	PARTICIPANT	\N	PRESENT	0
290010	289756	19717B	PARTICIPANT	\N	PRESENT	0
290011	289756	19673G	PARTICIPANT	\N	PRESENT	0
290012	289756	19703U	PARTICIPANT	\N	PRESENT	0
290013	289756	14173T	PARTICIPANT	\N	PRESENT	0
290014	289756	19441R	PARTICIPANT	\N	PRESENT	0
290015	289756	14221J	PARTICIPANT	\N	PRESENT	0
290016	289756	19335Q	PARTICIPANT	\N	PRESENT	0
290017	289756	14199E	PARTICIPANT	\N	PRESENT	0
290018	289756	89017R	PARTICIPANT	\N	PRESENT	0
290019	289756	01060R	PARTICIPANT	\N	PRESENT	0
290020	289756	11070L	PARTICIPANT	\N	PRESENT	0
290021	289756	19573D	PARTICIPANT	\N	PRESENT	0
290022	289756	07004J	PARTICIPANT	\N	PRESENT	0
290023	289756	14133K	PARTICIPANT	\N	PRESENT	0
290024	289756	08056B	PARTICIPANT	\N	PRESENT	0
290025	289756	14069U	PARTICIPANT	\N	PRESENT	0
290026	289756	19415P	PARTICIPANT	\N	PRESENT	0
290027	289756	11064N	PARTICIPANT	\N	PRESENT	0
290028	289756	92040Q	PARTICIPANT	\N	PRESENT	0
290029	289756	11085T	PARTICIPANT	\N	PRESENT	0
290030	289756	19577H	PARTICIPANT	\N	PRESENT	0
290031	289756	08020N	PARTICIPANT	\N	PRESENT	0
290032	289756	04070G	PARTICIPANT	\N	PRESENT	0
290033	289756	01024M	PARTICIPANT	\N	PRESENT	0
290034	289756	11049P	PARTICIPANT	\N	PRESENT	0
290035	289756	19329S	PARTICIPANT	\N	PRESENT	0
290036	289756	14115H	PARTICIPANT	\N	PRESENT	0
290037	289756	04049K	PARTICIPANT	\N	PRESENT	0
290038	289756	11103C	PARTICIPANT	\N	PRESENT	0
290039	289756	07033P	PARTICIPANT	\N	PRESENT	0
290040	289756	14217N	PARTICIPANT	\N	PRESENT	0
290041	289756	11048N	PARTICIPANT	\N	PRESENT	0
290042	289756	14103D	PARTICIPANT	\N	PRESENT	0
290043	289756	14079W	PARTICIPANT	\N	PRESENT	0
290044	289756	11054L	PARTICIPANT	\N	PRESENT	0
290564	273921	14199E	PARTICIPANT	\N	PRESENT	0
290565	273921	19269X	PARTICIPANT	\N	PRESENT	0
290566	273921	14173T	PARTICIPANT	\N	PRESENT	0
290567	273921	11072N	PARTICIPANT	\N	PRESENT	0
290568	273921	19447X	PARTICIPANT	\N	PRESENT	0
290569	273921	04045F	PARTICIPANT	\N	PRESENT	0
290570	273921	14133K	PARTICIPANT	\N	PRESENT	0
290571	273921	92040Q	PARTICIPANT	\N	PRESENT	0
290572	273921	19543W	PARTICIPANT	\N	PRESENT	0
290573	273921	11083R	PARTICIPANT	\N	PRESENT	0
290574	273921	11049P	PARTICIPANT	\N	PRESENT	0
290575	273921	19659J	PARTICIPANT	\N	PRESENT	0
290576	273921	14115H	PARTICIPANT	\N	PRESENT	0
290577	273921	14105F	PARTICIPANT	\N	PRESENT	0
290578	273921	04049K	PARTICIPANT	\N	PRESENT	0
290579	273921	11012A	PARTICIPANT	\N	PRESENT	0
290580	273921	08016S	PARTICIPANT	\N	PRESENT	0
290581	273921	14038Y	PARTICIPANT	\N	PRESENT	0
290582	273921	08031R	PARTICIPANT	\N	PRESENT	0
290583	273921	19723Y	PARTICIPANT	\N	PRESENT	0
290584	273921	19253P	PARTICIPANT	\N	PRESENT	0
290585	273921	19467C	PARTICIPANT	\N	PRESENT	0
290586	273921	14261S	PARTICIPANT	\N	PRESENT	0
290587	273921	19629C	PARTICIPANT	\N	PRESENT	0
290588	273921	19415P	PARTICIPANT	\N	PRESENT	0
290589	273921	14201E	PARTICIPANT	\N	PRESENT	0
290590	273921	14033T	PARTICIPANT	\N	PRESENT	0
290591	273921	08019V	PARTICIPANT	\N	PRESENT	0
290592	273921	08035V	PARTICIPANT	\N	PRESENT	0
290593	273921	19399H	PARTICIPANT	\N	PRESENT	0
290594	273921	19649G	PARTICIPANT	\N	PRESENT	0
290595	273921	19693L	PARTICIPANT	\N	PRESENT	0
290596	273921	14265W	PARTICIPANT	\N	PRESENT	0
290597	273921	14111D	PARTICIPANT	\N	PRESENT	0
290598	273921	04057K	PARTICIPANT	\N	PRESENT	0
290599	273921	14213J	PARTICIPANT	\N	PRESENT	0
290600	273921	19585H	PARTICIPANT	\N	PRESENT	0
290601	273921	11064N	PARTICIPANT	\N	PRESENT	0
290602	273921	08048B	PARTICIPANT	\N	PRESENT	0
290603	273921	02002K	PARTICIPANT	\N	PRESENT	0
290604	273921	19705W	PARTICIPANT	\N	PRESENT	0
290605	273921	19741B	PARTICIPANT	\N	PRESENT	0
290606	273921	19507S	PARTICIPANT	\N	PRESENT	0
290607	273921	19745F	PARTICIPANT	\N	PRESENT	0
277604	263769	14034U	PARTICIPANT	\N	PRESENT	0
277605	263769	04049K	PARTICIPANT	\N	PRESENT	0
277606	263769	01048V	PARTICIPANT	\N	PRESENT	0
277607	263769	14119M	PARTICIPANT	\N	PRESENT	0
277608	263769	14001X	PARTICIPANT	\N	PRESENT	0
277609	263769	08031R	PARTICIPANT	\N	PRESENT	0
277610	263769	14041T	PARTICIPANT	\N	PRESENT	0
277611	263769	14053L	PARTICIPANT	\N	PRESENT	0
277612	263769	14223L	PARTICIPANT	\N	PRESENT	0
277613	263769	19553Y	PARTICIPANT	\N	PRESENT	0
277614	263769	08052W	PARTICIPANT	\N	PRESENT	0
277615	263769	19723Y	PARTICIPANT	\N	PRESENT	0
277616	263769	11103C	PARTICIPANT	\N	PRESENT	0
277617	263769	11097X	PARTICIPANT	\N	PRESENT	0
277618	263769	19415P	PARTICIPANT	\N	PRESENT	0
277619	263769	01034P	PARTICIPANT	\N	PRESENT	0
277620	263769	11043H	PARTICIPANT	\N	PRESENT	0
277622	263769	19441R	PARTICIPANT	\N	PRESENT	0
277623	263769	19367Y	PARTICIPANT	\N	PRESENT	0
277624	263769	19679N	PARTICIPANT	\N	PRESENT	0
277625	263769	19575F	PARTICIPANT	\N	PRESENT	0
277626	263769	19741B	PARTICIPANT	\N	PRESENT	0
277627	263769	14030Q	PARTICIPANT	\N	PRESENT	0
277628	263769	19647E	PARTICIPANT	\N	PRESENT	0
277629	263769	14237S	PARTICIPANT	\N	PRESENT	0
277630	263769	14329V	PARTICIPANT	\N	PRESENT	0
277631	263769	95030B	PARTICIPANT	\N	PRESENT	0
277632	263769	14087W	PARTICIPANT	\N	PRESENT	0
277633	263769	01062T	PARTICIPANT	\N	PRESENT	0
277634	263769	19727D	PARTICIPANT	\N	PRESENT	0
277635	263769	14083S	PARTICIPANT	\N	PRESENT	0
277636	263769	14026U	PARTICIPANT	\N	PRESENT	0
277638	263769	14357A	PARTICIPANT	\N	PRESENT	0
277640	277639	19521Q	PARTICIPANT	\N	PRESENT	0
277641	277639	01048V	PARTICIPANT	\N	PRESENT	0
277642	277639	98050T	PARTICIPANT	\N	PRESENT	0
277643	277639	19503N	PARTICIPANT	\N	PRESENT	0
277644	277639	04097T	PARTICIPANT	\N	PRESENT	0
277656	263769	11053K	PARTICIPANT	\N	PRESENT	0
277647	277639	08053X	PARTICIPANT	\N	PRESENT	0
277654	263769	14038Y	PARTICIPANT	\N	PRESENT	0
277655	263769	14217N	PARTICIPANT	\N	PRESENT	0
277657	263769	14187A	PARTICIPANT	\N	PRESENT	0
277658	263769	19689Q	PARTICIPANT	\N	PRESENT	0
277659	263769	14213J	PARTICIPANT	\N	PRESENT	0
277660	263769	19521Q	PARTICIPANT	\N	PRESENT	0
277661	263769	08068F	PARTICIPANT	\N	PRESENT	0
277662	263769	14261S	PARTICIPANT	\N	PRESENT	0
277663	263769	19719D	PARTICIPANT	\N	PRESENT	0
277664	263769	11065P	PARTICIPANT	\N	PRESENT	0
277665	263769	08020N	PARTICIPANT	\N	PRESENT	0
277667	277666	10015M	PARTICIPANT	\N	PRESENT	0
277668	263769	14195A	PARTICIPANT	\N	PRESENT	0
277669	263769	14239U	PARTICIPANT	\N	PRESENT	0
277670	263769	19563B	PARTICIPANT	\N	PRESENT	0
277671	263769	19573D	PARTICIPANT	\N	PRESENT	0
277672	263769	14169X	PARTICIPANT	\N	PRESENT	0
277833	263770	04044E	PARTICIPANT	\N	PRESENT	0
277834	263770	98023Q	PARTICIPANT	\N	PRESENT	0
277835	263770	08055A	PARTICIPANT	\N	PRESENT	0
277836	263770	19637C	PARTICIPANT	\N	PRESENT	0
277837	263770	14051J	PARTICIPANT	\N	PRESENT	0
277838	263770	08060W	PARTICIPANT	\N	PRESENT	0
277839	263770	11077T	PARTICIPANT	\N	PRESENT	0
277840	263770	19551W	PARTICIPANT	\N	PRESENT	0
277841	263770	08009T	PARTICIPANT	\N	PRESENT	0
277842	263770	19525U	PARTICIPANT	\N	PRESENT	0
277843	263770	11104D	PARTICIPANT	\N	PRESENT	0
277844	263770	19333N	PARTICIPANT	\N	PRESENT	0
277845	263770	19413M	PARTICIPANT	\N	PRESENT	0
277846	263770	19503N	PARTICIPANT	\N	PRESENT	0
277847	263770	19347U	PARTICIPANT	\N	PRESENT	0
277848	263770	19695N	PARTICIPANT	\N	PRESENT	0
277849	263770	14030Q	PARTICIPANT	\N	PRESENT	0
277850	263770	01057W	PARTICIPANT	\N	PRESENT	0
277851	263770	19739H	PARTICIPANT	\N	PRESENT	0
277852	263770	19447X	PARTICIPANT	\N	PRESENT	0
277853	263770	19573D	PARTICIPANT	\N	PRESENT	0
277854	263770	19693L	PARTICIPANT	\N	PRESENT	0
277855	263770	07029T	PARTICIPANT	\N	PRESENT	0
277856	263770	19575F	PARTICIPANT	\N	PRESENT	0
277857	263770	95063L	PARTICIPANT	\N	PRESENT	0
277858	263770	19651A	PARTICIPANT	\N	PRESENT	0
277859	263770	14239U	PARTICIPANT	\N	PRESENT	0
277860	263770	19349W	PARTICIPANT	\N	PRESENT	0
277861	263770	11067R	PARTICIPANT	\N	PRESENT	0
277862	263770	08068F	PARTICIPANT	\N	PRESENT	0
277863	263770	08052W	PARTICIPANT	\N	PRESENT	0
277864	263770	14097Y	PARTICIPANT	\N	PRESENT	0
277865	263770	19549D	PARTICIPANT	\N	PRESENT	0
277866	263770	19387D	PARTICIPANT	\N	PRESENT	0
277867	263770	11065P	PARTICIPANT	\N	PRESENT	0
277868	263770	11056N	PARTICIPANT	\N	PRESENT	0
277869	263770	19713W	PARTICIPANT	\N	PRESENT	0
277870	263770	14219Q	PARTICIPANT	\N	PRESENT	0
277871	263770	19737F	PARTICIPANT	\N	PRESENT	0
277872	263770	01025N	PARTICIPANT	\N	PRESENT	0
277873	263770	14105F	PARTICIPANT	\N	PRESENT	0
277874	263770	14215L	PARTICIPANT	\N	PRESENT	0
277875	263770	04061F	PARTICIPANT	\N	PRESENT	0
277876	263770	14079W	PARTICIPANT	\N	PRESENT	0
277877	263770	14225N	PARTICIPANT	\N	PRESENT	0
277878	263770	14257W	PARTICIPANT	\N	PRESENT	0
277879	263770	08062Y	PARTICIPANT	\N	PRESENT	0
277880	263770	14327T	PARTICIPANT	\N	PRESENT	0
277881	263770	19621T	PARTICIPANT	\N	PRESENT	0
277882	263770	02002K	PARTICIPANT	\N	PRESENT	0
277883	263770	08049C	PARTICIPANT	\N	PRESENT	0
277884	263770	14241N	PARTICIPANT	\N	PRESENT	0
277885	263770	19563B	PARTICIPANT	\N	PRESENT	0
277886	263770	01024M	PARTICIPANT	\N	PRESENT	0
277887	263770	08015R	PARTICIPANT	\N	PRESENT	0
277888	263770	95030B	PARTICIPANT	\N	PRESENT	0
277889	263770	14261S	PARTICIPANT	\N	PRESENT	0
277890	263770	04085P	PARTICIPANT	\N	PRESENT	0
277891	263770	19593H	PARTICIPANT	\N	PRESENT	0
277892	263770	14071N	PARTICIPANT	\N	PRESENT	0
277893	263770	14147R	PARTICIPANT	\N	PRESENT	0
277894	263770	19731Y	PARTICIPANT	\N	PRESENT	0
277895	263770	19415P	PARTICIPANT	\N	PRESENT	0
277896	263770	08020N	PARTICIPANT	\N	PRESENT	0
277897	263770	19629C	PARTICIPANT	\N	PRESENT	0
277898	263770	11012A	PARTICIPANT	\N	PRESENT	0
277899	263770	11026G	PARTICIPANT	\N	PRESENT	0
277900	263770	14053L	PARTICIPANT	\N	PRESENT	0
277901	263770	14197C	PARTICIPANT	\N	PRESENT	0
277902	263770	14231L	PARTICIPANT	\N	PRESENT	0
277903	263770	14169X	PARTICIPANT	\N	PRESENT	0
277904	263770	19369B	PARTICIPANT	\N	PRESENT	0
277905	263770	19719D	PARTICIPANT	\N	PRESENT	0
277906	263770	14267Y	PARTICIPANT	\N	PRESENT	0
277907	263770	14031R	PARTICIPANT	\N	PRESENT	0
277908	263770	19723Y	PARTICIPANT	\N	PRESENT	0
277909	263770	19741B	PARTICIPANT	\N	PRESENT	0
277910	263770	19467C	PARTICIPANT	\N	PRESENT	0
277911	263770	11097X	PARTICIPANT	\N	PRESENT	0
277912	263770	04049K	PARTICIPANT	\N	PRESENT	0
277913	263770	04033B	PARTICIPANT	\N	PRESENT	0
277914	263770	14026U	PARTICIPANT	\N	PRESENT	0
277915	263770	14034U	PARTICIPANT	\N	PRESENT	0
277916	263770	14187A	PARTICIPANT	\N	PRESENT	0
277917	263770	19479G	PARTICIPANT	\N	PRESENT	0
277918	263770	19733B	PARTICIPANT	\N	PRESENT	0
277919	263770	19687N	PARTICIPANT	\N	PRESENT	0
277920	263770	14235Q	PARTICIPANT	\N	PRESENT	0
277921	263770	04097T	PARTICIPANT	\N	PRESENT	0
277922	263770	14083S	PARTICIPANT	\N	PRESENT	0
277923	263770	14213J	PARTICIPANT	\N	PRESENT	0
277924	263770	14179A	PARTICIPANT	\N	PRESENT	0
277925	263770	14029X	PARTICIPANT	\N	PRESENT	0
277926	263770	14033T	PARTICIPANT	\N	PRESENT	0
277927	263770	18083K	PARTICIPANT	\N	PRESENT	0
277928	263770	19383Y	PARTICIPANT	\N	PRESENT	0
277929	263770	14135M	PARTICIPANT	\N	PRESENT	0
278765	278102	14147R	PARTICIPANT	\N	PRESENT	0
278831	278827	14065Q	PARTICIPANT	\N	PRESENT	0
278832	278827	07034Q	PARTICIPANT	\N	PRESENT	0
279260	279259	14231L	PARTICIPANT	\N	PRESENT	0
279262	279261	14231L	PARTICIPANT	\N	PRESENT	0
279264	276025	19709B	PARTICIPANT	\N	EXCUSE	0
279273	279272	14231L	PARTICIPANT	\N	PRESENT	0
279275	279274	14147R	PARTICIPANT	\N	PRESENT	0
279277	279276	14147R	PARTICIPANT	\N	PRESENT	0
280701	280698	14147R	PARTICIPANT	\N	PRESENT	0
293008	273969	14205J	PARTICIPANT	\N	PRESENT	0
293009	273969	14207L	PARTICIPANT	\N	PRESENT	0
293010	273969	08060W	PARTICIPANT	\N	PRESENT	0
293011	273969	19503N	PARTICIPANT	\N	PRESENT	0
293012	273969	19667J	PARTICIPANT	\N	PRESENT	0
293013	273969	19413M	PARTICIPANT	\N	PRESENT	0
293014	273969	14257W	PARTICIPANT	\N	PRESENT	0
293015	273969	18083K	PARTICIPANT	\N	PRESENT	0
293016	273969	19301E	PARTICIPANT	\N	PRESENT	0
293017	273969	19563B	PARTICIPANT	\N	PRESENT	0
293018	273969	95030B	PARTICIPANT	\N	PRESENT	0
293019	273969	04043D	PARTICIPANT	\N	PRESENT	0
293020	273969	19711U	PARTICIPANT	\N	PRESENT	0
293025	273969	11045K	PARTICIPANT	\N	PRESENT	0
293022	273969	19663E	PARTICIPANT	\N	PRESENT	0
293023	273969	07033P	PARTICIPANT	\N	PRESENT	0
293024	273969	14107H	PARTICIPANT	\N	PRESENT	0
293026	273969	04045F	PARTICIPANT	\N	PRESENT	0
293027	273969	14265W	PARTICIPANT	\N	PRESENT	0
293028	273969	19689Q	PARTICIPANT	\N	PRESENT	0
293029	273969	19551W	PARTICIPANT	\N	PRESENT	0
293030	273969	19347U	PARTICIPANT	\N	PRESENT	0
293031	273969	19269X	PARTICIPANT	\N	PRESENT	0
293032	273969	19441R	PARTICIPANT	\N	PRESENT	0
293033	273969	11099A	PARTICIPANT	\N	PRESENT	0
293034	273969	19695N	PARTICIPANT	\N	PRESENT	0
293035	273969	14219Q	PARTICIPANT	\N	PRESENT	0
293036	273969	19715Y	PARTICIPANT	\N	PRESENT	0
293037	273969	14083S	PARTICIPANT	\N	PRESENT	0
293038	273969	19619A	PARTICIPANT	\N	PRESENT	0
293039	273969	14357A	PARTICIPANT	\N	PRESENT	0
293040	273969	08034U	PARTICIPANT	\N	PRESENT	0
293041	273969	14033T	PARTICIPANT	\N	PRESENT	0
293042	273969	19507S	PARTICIPANT	\N	PRESENT	0
293043	273969	17589D	PARTICIPANT	\N	PRESENT	0
293044	273969	19657G	PARTICIPANT	\N	PRESENT	0
293045	273969	80013X	PARTICIPANT	\N	PRESENT	0
293046	273969	19643A	PARTICIPANT	\N	PRESENT	0
293047	273969	11056N	PARTICIPANT	\N	PRESENT	0
293048	273969	19565D	PARTICIPANT	\N	PRESENT	0
293049	273969	19553Y	PARTICIPANT	\N	PRESENT	0
293050	273969	11090Q	PARTICIPANT	\N	PRESENT	0
293051	273969	14135M	PARTICIPANT	\N	PRESENT	0
293052	273969	19713W	PARTICIPANT	\N	PRESENT	0
293053	273969	08019V	PARTICIPANT	\N	PRESENT	0
293054	273969	14239U	PARTICIPANT	\N	PRESENT	0
293055	273969	04049K	PARTICIPANT	\N	PRESENT	0
293056	273969	08016S	PARTICIPANT	\N	PRESENT	0
293057	273969	11012A	PARTICIPANT	\N	PRESENT	0
293058	273969	19591F	PARTICIPANT	\N	PRESENT	0
293059	273969	07029T	PARTICIPANT	\N	PRESENT	0
293063	273969	11109J	PARTICIPANT	\N	PRESENT	0
293061	273969	08009T	PARTICIPANT	\N	PRESENT	0
293062	273969	19693L	PARTICIPANT	\N	PRESENT	0
293064	273969	17637T	PARTICIPANT	\N	PRESENT	0
293373	293372	96004D	PARTICIPANT	\N	PRESENT	0
293006	273969	11077T	PARTICIPANT	\N	PRESENT	0
293007	273969	14221J	PARTICIPANT	\N	PRESENT	0
293374	293372	14255U	PARTICIPANT	\N	PRESENT	0
293375	293372	19709B	PARTICIPANT	\N	PRESENT	0
293376	293372	14097Y	PARTICIPANT	\N	PRESENT	0
293377	293372	14001X	PARTICIPANT	\N	PRESENT	0
293382	293381	04042C	PARTICIPANT	\N	PRESENT	0
293384	293383	14073Q	PARTICIPANT	\N	PRESENT	0
293385	293383	04035D	PARTICIPANT	\N	PRESENT	0
293390	293389	14071N	PARTICIPANT	\N	PRESENT	0
293659	289103	08015R	PARTICIPANT	\N	PRESENT	0
293585	292930	19711U	PARTICIPANT	\N	PRESENT	0
293586	292930	95041E	PARTICIPANT	\N	PRESENT	0
293587	292930	01048V	PARTICIPANT	\N	PRESENT	0
293588	292930	19687N	PARTICIPANT	\N	PRESENT	0
293589	292930	08011M	PARTICIPANT	\N	PRESENT	0
293590	292930	11074Q	PRESIDENT	0	PRESENT	0
293591	292930	19667J	PARTICIPANT	\N	PRESENT	0
293592	292930	14159V	PARTICIPANT	\N	PRESENT	0
293593	292930	11040E	PARTICIPANT	\N	PRESENT	0
293594	292930	04086Q	PARTICIPANT	\N	PRESENT	0
293595	292930	14083S	PARTICIPANT	\N	PRESENT	0
293596	292930	07004J	PARTICIPANT	\N	PRESENT	0
293597	292930	19349W	PARTICIPANT	\N	PRESENT	0
293598	292930	14253S	PARTICIPANT	\N	PRESENT	0
293599	292930	08014Q	PARTICIPANT	\N	EXCUSE	0
293600	292930	19479G	PARTICIPANT	\N	PRESENT	0
293601	292930	19545Y	PARTICIPANT	\N	PRESENT	0
293602	292930	07029T	PARTICIPANT	\N	PRESENT	0
293603	292930	19741B	PARTICIPANT	\N	PRESENT	0
293604	292930	11070L	PARTICIPANT	\N	PRESENT	0
293607	292930	12016W	PARTICIPANT	\N	PRESENT	0
293608	289103	04059M	PARTICIPANT	\N	PRESENT	0
293609	292930	11048N	PARTICIPANT	\N	PRESENT	0
293610	292930	14034U	PARTICIPANT	\N	PRESENT	0
293611	289103	19681G	PARTICIPANT	\N	PRESENT	0
293612	289103	14219Q	PARTICIPANT	\N	PRESENT	0
293613	292930	08010L	PARTICIPANT	\N	PRESENT	0
293614	292930	14121F	PARTICIPANT	\N	PRESENT	0
293660	289103	19441R	PARTICIPANT	\N	PRESENT	0
293616	293441	11010L	PARTICIPANT	\N	PRESENT	0
293617	293441	07034Q	PRESIDENT	1	PRESENT	0
293618	293441	11026G	PARTICIPANT	\N	PRESENT	0
293619	293441	19253P	PARTICIPANT	\N	PRESENT	0
293620	293441	01024M	PARTICIPANT	\N	PRESENT	0
293621	293441	19543W	PARTICIPANT	\N	PRESENT	0
293622	293441	19581D	PARTICIPANT	\N	PRESENT	0
293661	289103	89017R	PARTICIPANT	\N	PRESENT	0
293624	293441	04047H	PARTICIPANT	\N	PRESENT	0
293625	293441	11033F	PARTICIPANT	\N	PRESENT	0
293626	293441	01028R	PARTICIPANT	\N	PRESENT	0
293627	293441	19447X	PARTICIPANT	\N	PRESENT	0
293628	293441	05008E	PRESIDENT	0	PRESENT	0
293629	293441	14147R	PARTICIPANT	\N	PRESENT	0
293630	293441	14069U	PARTICIPANT	\N	PRESENT	0
293631	293441	11072N	PARTICIPANT	\N	PRESENT	0
293632	293441	19719D	PARTICIPANT	\N	PRESENT	0
293633	292930	14199E	PARTICIPANT	\N	PRESENT	0
293634	289103	19719D	PARTICIPANT	\N	PRESENT	0
293635	292930	04071H	PARTICIPANT	\N	PRESENT	0
293636	289103	14257W	PARTICIPANT	\N	PRESENT	0
293637	289103	14217N	PARTICIPANT	\N	PRESENT	0
293638	289103	19415P	PARTICIPANT	\N	PRESENT	0
293639	289103	14327T	PARTICIPANT	\N	PRESENT	0
293640	289103	14083S	PARTICIPANT	\N	PRESENT	0
293641	289103	19301E	PARTICIPANT	\N	PRESENT	0
293642	289103	14073Q	PARTICIPANT	\N	PRESENT	0
293643	289103	14069U	PARTICIPANT	\N	PRESENT	0
293644	289103	19507S	PARTICIPANT	\N	PRESENT	0
293645	292930	14085U	PARTICIPANT	\N	PRESENT	0
293646	289103	11064N	PARTICIPANT	\N	PRESENT	0
293647	292930	19531S	PARTICIPANT	\N	PRESENT	0
293650	289103	14038Y	PARTICIPANT	\N	PRESENT	0
293651	293441	14179A	PARTICIPANT	\N	PRESENT	0
293656	293441	14111D	PARTICIPANT	\N	PRESENT	0
293657	293441	19585H	PARTICIPANT	\N	PRESENT	0
293658	289103	14147R	PARTICIPANT	\N	PRESENT	0
293662	289103	14053L	PARTICIPANT	\N	PRESENT	0
293663	289103	19673G	PARTICIPANT	\N	PRESENT	0
293664	289103	14179A	PARTICIPANT	\N	PRESENT	0
293665	289103	19251M	PARTICIPANT	\N	PRESENT	0
293667	289103	04008A	PARTICIPANT	\N	PRESENT	0
293668	289103	19667J	PARTICIPANT	\N	PRESENT	0
293669	289103	11054L	PARTICIPANT	\N	PRESENT	0
293679	289103	14119M	PARTICIPANT	\N	PRESENT	0
293680	289103	19631V	PARTICIPANT	\N	PRESENT	0
293681	289103	08043V	PARTICIPANT	\N	PRESENT	0
293682	289103	19691J	PARTICIPANT	\N	PRESENT	0
293683	289103	01062T	PARTICIPANT	\N	PRESENT	0
293684	289103	07029T	PARTICIPANT	\N	PRESENT	0
293705	289104	19689Q	PARTICIPANT	\N	PRESENT	0
293706	289104	14085U	PARTICIPANT	\N	PRESENT	0
293707	289104	19333N	PARTICIPANT	\N	PRESENT	0
293708	289104	14063N	PARTICIPANT	\N	PRESENT	0
293709	289104	08011M	PARTICIPANT	\N	PRESENT	0
293710	289104	19719D	PARTICIPANT	\N	PRESENT	0
293711	289104	19349W	PARTICIPANT	\N	PRESENT	0
293718	289104	99004R	PARTICIPANT	\N	PRESENT	0
293713	289104	12016W	PARTICIPANT	\N	PRESENT	0
293714	289104	19649G	PARTICIPANT	\N	PRESENT	0
293715	289104	11066Q	PARTICIPANT	\N	PRESENT	0
293716	289104	19637C	PARTICIPANT	\N	PRESENT	0
293717	289104	19545Y	PARTICIPANT	\N	PRESENT	0
293719	289104	01057W	PARTICIPANT	\N	PRESENT	0
293720	289104	14157T	PARTICIPANT	\N	PRESENT	0
293721	289104	19447X	PARTICIPANT	\N	PRESENT	0
293722	289104	19741B	PARTICIPANT	\N	PRESENT	0
293702	289104	14034U	PARTICIPANT	\N	PRESENT	0
293704	289104	11040E	PARTICIPANT	\N	PRESENT	0
293723	289104	87003B	PARTICIPANT	\N	PRESENT	0
293724	289104	19663E	PARTICIPANT	\N	PRESENT	0
293725	289104	14265W	PARTICIPANT	\N	PRESENT	0
293726	289104	14105F	PARTICIPANT	\N	PRESENT	0
271559	271232	19295A	PARTICIPANT	\N	PRESENT	0
271560	271232	14217N	PARTICIPANT	\N	PRESENT	0
271561	271232	19697Q	PARTICIPANT	\N	PRESENT	0
271593	271232	14147R	PARTICIPANT	\N	PRESENT	0
271595	271232	14223L	PARTICIPANT	\N	PRESENT	0
271596	271232	14119M	PARTICIPANT	\N	PRESENT	0
271614	271232	14065Q	PARTICIPANT	\N	EXCUSE	0
272920	272919	14133K	PARTICIPANT	\N	PRESENT	0
272921	272919	96004D	PARTICIPANT	\N	PRESENT	0
272922	272919	14255U	PARTICIPANT	\N	PRESENT	0
272923	272919	04042C	PARTICIPANT	\N	EXCUSE	0
272924	272919	04035D	PARTICIPANT	\N	PRESENT	0
272925	272919	04097T	PARTICIPANT	\N	PRESENT	0
272926	272919	04061F	PARTICIPANT	\N	EXCUSE	0
272927	272919	14001X	PARTICIPANT	\N	EXCUSE	0
272928	272919	04057K	PARTICIPANT	\N	PRESENT	0
272929	272919	98050T	PARTICIPANT	\N	PRESENT	0
272930	272919	01062T	PARTICIPANT	\N	PRESENT	0
272931	272919	04034C	PARTICIPANT	\N	PRESENT	0
273524	273521	19621T	PARTICIPANT	\N	PRESENT	0
273525	273521	08031R	PARTICIPANT	\N	PRESENT	0
273572	273571	14187A	PARTICIPANT	\N	PRESENT	0
273573	273571	19295A	PARTICIPANT	\N	PRESENT	0
273575	273574	14187A	PARTICIPANT	\N	PRESENT	0
273577	273576	14187A	PARTICIPANT	\N	PRESENT	0
273578	273576	19515S	PARTICIPANT	\N	PRESENT	0
273581	273579	04061F	PARTICIPANT	\N	PRESENT	0
273582	273579	14225N	PARTICIPANT	\N	PRESENT	0
273584	273583	14079W	PARTICIPANT	\N	PRESENT	0
275270	273667	14038Y	PARTICIPANT	\N	EXCUSE	0
275271	273667	19715Y	PARTICIPANT	\N	PRESENT	0
275272	273667	19319Q	PARTICIPANT	\N	PRESENT	0
275273	273667	11072N	PARTICIPANT	\N	EXCUSE	0
275274	273667	08019V	PRESIDENT	0	PRESENT	0
275275	273667	19657G	PARTICIPANT	\N	PRESENT	0
275276	273667	14097Y	PARTICIPANT	\N	PRESENT	0
275277	273667	19729F	PARTICIPANT	\N	PRESENT	0
275278	273668	14038Y	PARTICIPANT	\N	EXCUSE	0
275279	273668	19691J	PARTICIPANT	\N	EXCUSE	0
275280	273668	98005N	PARTICIPANT	\N	EXCUSE	0
275281	273668	14097Y	PARTICIPANT	\N	PRESENT	0
275282	273668	19729F	PARTICIPANT	\N	PRESENT	0
275283	273668	11072N	PARTICIPANT	\N	PRESENT	0
275284	273668	19657G	PARTICIPANT	\N	PRESENT	0
275285	273668	95062K	PARTICIPANT	\N	PRESENT	0
275286	273668	14275Y	PARTICIPANT	\N	EXCUSE	0
275287	273668	19703U	PARTICIPANT	\N	PRESENT	0
275288	273668	19319Q	PARTICIPANT	\N	PRESENT	0
275289	273668	08019V	PRESIDENT	0	PRESENT	0
275743	273669	14038Y	PARTICIPANT	\N	EXCUSE	0
275744	273669	19577H	PARTICIPANT	\N	EXCUSE	0
275747	273669	14059S	PARTICIPANT	\N	EXCUSE	0
275748	273669	14331P	PARTICIPANT	\N	EXCUSE	0
275749	273669	11010L	PARTICIPANT	\N	EXCUSE	0
280506	280501	19725B	PARTICIPANT	\N	PRESENT	0
292053	292052	11054L	PARTICIPANT	\N	PRESENT	0
292054	292052	11064N	PARTICIPANT	\N	PRESENT	0
300299	289194	11070L	PARTICIPANT	\N	PRESENT	0
300300	289194	11090Q	PARTICIPANT	\N	PRESENT	0
300301	289194	14187A	PARTICIPANT	\N	PRESENT	0
300302	289194	08038Y	PARTICIPANT	\N	PRESENT	0
300303	289194	19631V	PARTICIPANT	\N	PRESENT	0
300304	289194	12016W	PARTICIPANT	\N	PRESENT	0
300305	289194	19413M	PARTICIPANT	\N	PRESENT	0
300306	289194	19503N	PARTICIPANT	\N	PRESENT	0
300307	289194	08061X	PARTICIPANT	\N	PRESENT	0
300308	289194	19301E	PARTICIPANT	\N	PRESENT	0
300309	289194	19585H	PARTICIPANT	\N	PRESENT	0
300310	289194	19629C	PARTICIPANT	\N	PRESENT	0
300311	289194	11056N	PARTICIPANT	\N	PRESENT	0
300312	289194	19713W	PARTICIPANT	\N	PRESENT	0
300313	289194	14042U	PARTICIPANT	\N	PRESENT	0
300314	289194	14231L	PARTICIPANT	\N	PRESENT	0
300315	289194	19737F	PARTICIPANT	\N	PRESENT	0
300316	289194	14227Q	PARTICIPANT	\N	PRESENT	0
300317	289194	08039A	PARTICIPANT	\N	PRESENT	0
300318	289194	19565D	PARTICIPANT	\N	PRESENT	0
300319	289194	19593H	PARTICIPANT	\N	PRESENT	0
300320	289194	11109J	PARTICIPANT	\N	PRESENT	0
300321	289194	19387D	PARTICIPANT	\N	PRESENT	0
300322	289194	19719D	PARTICIPANT	\N	PRESENT	0
300323	289194	08016S	PARTICIPANT	\N	PRESENT	0
300324	289194	19745F	PARTICIPANT	\N	PRESENT	0
300325	289194	19747H	PARTICIPANT	\N	PRESENT	0
300326	289194	19671E	PARTICIPANT	\N	PRESENT	0
300327	289194	19551W	PARTICIPANT	\N	PRESENT	0
300328	289194	19515S	PARTICIPANT	\N	PRESENT	0
300329	289194	14215L	PARTICIPANT	\N	PRESENT	0
300330	289194	14191V	PARTICIPANT	\N	PRESENT	0
300331	289194	14329V	PARTICIPANT	\N	PRESENT	0
300332	289194	19695N	PARTICIPANT	\N	PRESENT	0
300333	289194	19703U	PARTICIPANT	\N	PRESENT	0
300334	289194	11101A	PARTICIPANT	\N	PRESENT	0
300335	289194	19673G	PARTICIPANT	\N	PRESENT	0
300336	289194	19399H	PARTICIPANT	\N	PRESENT	0
300337	289194	14038Y	PARTICIPANT	\N	PRESENT	0
300338	289194	14199E	PARTICIPANT	\N	PRESENT	0
300339	289194	19447X	PARTICIPANT	\N	PRESENT	0
300340	289194	19611R	PARTICIPANT	\N	PRESENT	0
300341	289194	14265W	PARTICIPANT	\N	PRESENT	0
300342	289194	01025N	PARTICIPANT	\N	PRESENT	0
300343	289194	19711U	PARTICIPANT	\N	PRESENT	0
300344	289194	19295A	PARTICIPANT	\N	PRESENT	0
300345	289194	04086Q	PARTICIPANT	\N	PRESENT	0
300346	289194	14195A	PARTICIPANT	\N	PRESENT	0
300347	289194	04008A	PARTICIPANT	\N	PRESENT	0
300348	289194	19735D	PARTICIPANT	\N	PRESENT	0
300349	289194	14107H	PARTICIPANT	\N	PRESENT	0
300350	289194	08069G	PARTICIPANT	\N	PRESENT	0
300351	289194	19727D	PARTICIPANT	\N	PRESENT	0
300352	289194	14083S	PARTICIPANT	\N	PRESENT	0
300353	289194	19657G	PARTICIPANT	\N	PRESENT	0
300354	289194	19739H	PARTICIPANT	\N	PRESENT	0
300355	289194	19717B	PARTICIPANT	\N	PRESENT	0
300356	289194	11077T	PARTICIPANT	\N	PRESENT	0
300357	289194	19347U	PARTICIPANT	\N	PRESENT	0
300358	289194	14235Q	PARTICIPANT	\N	PRESENT	0
300359	289194	04070G	PARTICIPANT	\N	PRESENT	0
300360	289194	19533U	PARTICIPANT	\N	PRESENT	0
300361	289194	10006L	PARTICIPANT	\N	PRESENT	0
300362	289194	14229S	PARTICIPANT	\N	PRESENT	0
300363	289194	14021P	PARTICIPANT	\N	PRESENT	0
300364	289194	95063L	PARTICIPANT	\N	PRESENT	0
300365	289194	19367Y	PARTICIPANT	\N	PRESENT	0
300366	289194	04018C	PARTICIPANT	\N	PRESENT	0
300367	289194	19701S	PARTICIPANT	\N	PRESENT	0
300368	289194	05012A	PARTICIPANT	\N	PRESENT	0
300369	289194	19729F	PARTICIPANT	\N	PRESENT	0
300370	289194	04047H	PARTICIPANT	\N	PRESENT	0
300371	289194	14205J	PARTICIPANT	\N	PRESENT	0
300372	289194	14034U	PARTICIPANT	\N	PRESENT	0
300373	289194	19525U	PARTICIPANT	\N	PRESENT	0
300378	289194	04085P	PARTICIPANT	\N	PRESENT	0
300375	289194	01043Q	PARTICIPANT	\N	PRESENT	0
300376	289194	19573D	PARTICIPANT	\N	PRESENT	0
300377	289194	19693L	PARTICIPANT	\N	PRESENT	0
300379	289194	11067R	PARTICIPANT	\N	PRESENT	0
300380	289194	14109K	PARTICIPANT	\N	PRESENT	0
300384	289194	08068F	PARTICIPANT	\N	PRESENT	0
300382	289194	08019V	PARTICIPANT	\N	PRESENT	0
300383	289194	14029X	PARTICIPANT	\N	PRESENT	0
300385	289194	19441R	PARTICIPANT	\N	PRESENT	0
300386	289194	14123H	PARTICIPANT	\N	PRESENT	0
300387	289194	17637T	PARTICIPANT	\N	PRESENT	0
300388	289194	17589D	PARTICIPANT	\N	PRESENT	0
300389	289194	14217N	PARTICIPANT	\N	PRESENT	0
300390	289194	14157T	PARTICIPANT	\N	PRESENT	0
300391	289194	14053L	PARTICIPANT	\N	PRESENT	0
300392	289194	19591F	PARTICIPANT	\N	PRESENT	0
300393	289194	11099A	PARTICIPANT	\N	PRESENT	0
300394	289194	19415P	PARTICIPANT	\N	PRESENT	0
300395	289194	14033T	PARTICIPANT	\N	PRESENT	0
300396	289194	08015R	PARTICIPANT	\N	PRESENT	0
300397	289194	11048N	PARTICIPANT	\N	PRESENT	0
300398	289194	19553Y	PARTICIPANT	\N	PRESENT	0
300399	289194	01028R	PARTICIPANT	\N	PRESENT	0
300400	289194	14357A	PARTICIPANT	\N	PRESENT	0
300401	289194	19421M	PARTICIPANT	\N	PRESENT	0
300402	289194	11097X	PARTICIPANT	\N	PRESENT	0
300403	289194	04088S	PARTICIPANT	\N	PRESENT	0
300404	289194	14105F	PARTICIPANT	\N	PRESENT	0
300405	289194	04049K	PARTICIPANT	\N	PRESENT	0
300406	289194	02002K	PARTICIPANT	\N	PRESENT	0
300407	289194	19443T	PARTICIPANT	\N	PRESENT	0
300408	289194	14071N	PARTICIPANT	\N	PRESENT	0
300409	289194	14119M	PARTICIPANT	\N	PRESENT	0
300410	289194	19507S	PARTICIPANT	\N	PRESENT	0
300411	289194	18083K	PARTICIPANT	\N	PRESENT	0
300412	289194	14089Y	PARTICIPANT	\N	PRESENT	0
282549	282452	14030Q	PRESIDENT	0	PRESENT	0
282550	282452	19621T	PARTICIPANT	\N	PRESENT	0
282551	282452	19701S	PARTICIPANT	\N	PRESENT	0
282552	282452	19693L	PARTICIPANT	\N	PRESENT	0
282553	282452	04035D	PARTICIPANT	\N	PRESENT	0
282554	282452	08031R	PARTICIPANT	\N	PRESENT	0
282555	282452	19697Q	PARTICIPANT	\N	PRESENT	0
282556	282452	14251Q	PARTICIPANT	\N	PRESENT	0
282557	282452	19269X	PARTICIPANT	\N	PRESENT	0
282558	282452	05008E	PARTICIPANT	\N	PRESENT	0
282559	282452	11083R	PARTICIPANT	\N	PRESENT	0
282560	282452	19503N	PARTICIPANT	\N	PRESENT	0
282561	282452	11033F	PARTICIPANT	\N	PRESENT	0
282562	282452	01024M	PARTICIPANT	\N	PRESENT	0
282563	282452	19649G	PARTICIPANT	\N	PRESENT	0
282564	282452	19581D	PARTICIPANT	\N	PRESENT	0
282565	282452	14111D	PARTICIPANT	\N	PRESENT	0
282566	282452	14147R	PARTICIPANT	\N	PRESENT	0
282567	282452	07034Q	PARTICIPANT	\N	PRESENT	0
290608	273921	19663E	PARTICIPANT	\N	PRESENT	0
290609	273921	04088S	PARTICIPANT	\N	PRESENT	0
290610	273921	01057W	PARTICIPANT	\N	PRESENT	0
290611	273921	14031R	PARTICIPANT	\N	PRESENT	0
290612	273921	19573D	PARTICIPANT	\N	PRESENT	0
290613	273921	87003B	PARTICIPANT	\N	PRESENT	0
290614	273921	98023Q	PARTICIPANT	\N	PRESENT	0
290615	273921	19729F	PARTICIPANT	\N	PRESENT	0
290616	273921	14026U	PARTICIPANT	\N	PRESENT	0
290617	273921	14039A	PARTICIPANT	\N	PRESENT	0
290618	273921	95067Q	PARTICIPANT	\N	PRESENT	0
290619	273921	11099A	PARTICIPANT	\N	PRESENT	0
290620	273921	19289C	PARTICIPANT	\N	PRESENT	0
290621	273921	14041T	PARTICIPANT	\N	PRESENT	0
290622	273921	08018U	PARTICIPANT	\N	PRESENT	0
290623	273921	95063L	PARTICIPANT	\N	PRESENT	0
290624	273921	07029T	PARTICIPANT	\N	PRESENT	0
290625	273921	14355X	PARTICIPANT	\N	PRESENT	0
290626	273921	08062Y	PARTICIPANT	\N	PRESENT	0
290627	273921	08015R	PARTICIPANT	\N	PRESENT	0
290628	273921	19707Y	PARTICIPANT	\N	PRESENT	0
290629	273921	01048V	PARTICIPANT	\N	PRESENT	0
290630	273921	11110B	PARTICIPANT	\N	PRESENT	0
290631	273921	04033B	PARTICIPANT	\N	PRESENT	0
290632	273921	11074Q	PARTICIPANT	\N	PRESENT	0
290633	273921	14119M	PARTICIPANT	\N	PRESENT	0
290634	273921	08068F	PARTICIPANT	\N	PRESENT	0
290635	273921	19667J	PARTICIPANT	\N	PRESENT	0
290636	273921	98050T	PARTICIPANT	\N	PRESENT	0
290637	273921	14061L	PARTICIPANT	\N	PRESENT	0
290638	273921	14059S	PARTICIPANT	\N	PRESENT	0
290639	273921	19733B	PARTICIPANT	\N	PRESENT	0
290640	273921	14329V	PARTICIPANT	\N	PRESENT	0
290641	273921	08055A	PARTICIPANT	\N	PRESENT	0
290642	273921	14357A	PARTICIPANT	\N	PRESENT	0
290643	273921	14065Q	PARTICIPANT	\N	PRESENT	0
290644	273921	19675J	PARTICIPANT	\N	PRESENT	0
290645	273921	08073C	PARTICIPANT	\N	PRESENT	0
290646	273921	19383Y	PARTICIPANT	\N	PRESENT	0
290647	273921	04018C	PARTICIPANT	\N	PRESENT	0
290648	273921	04034C	PARTICIPANT	\N	PRESENT	0
290649	273921	14207L	PARTICIPANT	\N	PRESENT	0
290650	273921	14085U	PARTICIPANT	\N	PRESENT	0
290651	273921	19643A	PARTICIPANT	\N	PRESENT	0
290652	273921	08024S	PARTICIPANT	\N	PRESENT	0
290653	273921	04061F	PARTICIPANT	\N	PRESENT	0
290654	273921	19295A	PARTICIPANT	\N	PRESENT	0
290655	273921	14331P	PARTICIPANT	\N	PRESENT	0
290656	273921	14159V	PARTICIPANT	\N	PRESENT	0
290657	273921	14217N	PARTICIPANT	\N	PRESENT	0
290658	273921	11077T	PARTICIPANT	\N	PRESENT	0
290659	273921	08017T	PARTICIPANT	\N	PRESENT	0
290660	273921	11103C	PARTICIPANT	\N	PRESENT	0
290661	273921	04059M	PARTICIPANT	\N	PRESENT	0
290662	273921	19549D	PARTICIPANT	\N	PRESENT	0
290663	273921	14021P	PARTICIPANT	\N	PRESENT	0
290664	273921	04086Q	PARTICIPANT	\N	PRESENT	0
290665	273921	14107H	PARTICIPANT	\N	PRESENT	0
290666	273921	14225N	PARTICIPANT	\N	PRESENT	0
290667	273921	14169X	PARTICIPANT	\N	PRESENT	0
290668	273921	19503N	PARTICIPANT	\N	PRESENT	0
290669	273921	05012A	PARTICIPANT	\N	PRESENT	0
290670	273921	08034U	PARTICIPANT	\N	PRESENT	0
290671	273921	08012N	PARTICIPANT	\N	PRESENT	0
290673	273921	14151M	PARTICIPANT	\N	PRESENT	0
290674	273921	19533U	PARTICIPANT	\N	PRESENT	0
290676	273921	04043D	PARTICIPANT	\N	PRESENT	0
290677	273921	14028W	PARTICIPANT	\N	PRESENT	0
290678	273921	14069U	PARTICIPANT	\N	PRESENT	0
290679	273921	14053L	PARTICIPANT	\N	PRESENT	0
290680	273921	14087W	PARTICIPANT	\N	PRESENT	0
290681	273921	14001X	PARTICIPANT	\N	PRESENT	0
290682	273921	08053X	PARTICIPANT	\N	PRESENT	0
290683	273921	14215L	PARTICIPANT	\N	PRESENT	0
290684	273921	19531S	PARTICIPANT	\N	PRESENT	0
290685	273921	14193X	PARTICIPANT	\N	PRESENT	0
290687	273921	14237S	PARTICIPANT	\N	PRESENT	0
290689	273921	17779H	PARTICIPANT	\N	PRESENT	0
290691	273921	17583W	PARTICIPANT	\N	PRESENT	0
290692	273921	08058D	PARTICIPANT	\N	PRESENT	0
290695	273921	19421M	PARTICIPANT	\N	PRESENT	0
290697	273921	11066Q	PARTICIPANT	\N	PRESENT	0
290698	273921	11097X	PARTICIPANT	\N	PRESENT	0
290700	273921	11054L	PARTICIPANT	\N	PRESENT	0
290701	273921	19251M	PARTICIPANT	\N	PRESENT	0
290703	273921	14071N	PARTICIPANT	\N	PRESENT	0
290704	273921	08038Y	PARTICIPANT	\N	PRESENT	0
290705	273921	14187A	PARTICIPANT	\N	PRESENT	0
290706	273921	11101A	PARTICIPANT	\N	PRESENT	0
290707	273921	19551W	PARTICIPANT	\N	PRESENT	0
290708	273921	04035D	PARTICIPANT	\N	PRESENT	0
290709	273921	19631V	PARTICIPANT	\N	PRESENT	0
290710	273921	14253S	PARTICIPANT	\N	PRESENT	0
290711	273921	11027H	PARTICIPANT	\N	PRESENT	0
290712	273921	19725B	PARTICIPANT	\N	PRESENT	0
290713	273921	05008E	PARTICIPANT	\N	PRESENT	0
290714	273921	19689Q	PARTICIPANT	\N	PRESENT	0
290715	273921	11104D	PARTICIPANT	\N	PRESENT	0
290716	273921	89017R	PARTICIPANT	\N	PRESENT	0
290717	273921	08009T	PARTICIPANT	\N	PRESENT	0
290718	273921	14083S	PARTICIPANT	\N	PRESENT	0
290719	273921	07004J	PARTICIPANT	\N	PRESENT	0
290720	273921	19367Y	PARTICIPANT	\N	PRESENT	0
290721	273921	04008A	PARTICIPANT	\N	PRESENT	0
290722	273921	11063M	PARTICIPANT	\N	PRESENT	0
290723	273921	19721W	PARTICIPANT	\N	PRESENT	0
290724	273921	11048N	PARTICIPANT	\N	PRESENT	0
290725	273921	14030Q	PARTICIPANT	\N	PRESENT	0
290726	273921	04040A	PARTICIPANT	\N	PRESENT	0
290727	273921	14089Y	PARTICIPANT	\N	PRESENT	0
290728	273921	19747H	PARTICIPANT	\N	PRESENT	0
290729	273921	01024M	PARTICIPANT	\N	PRESENT	0
290730	273921	01025N	PARTICIPANT	\N	PRESENT	0
290731	273921	19577H	PARTICIPANT	\N	PRESENT	0
290732	273921	11085T	PARTICIPANT	\N	PRESENT	0
290733	273921	19621T	PARTICIPANT	\N	PRESENT	0
290734	273921	19521Q	PARTICIPANT	\N	PRESENT	0
290735	273921	04047H	PARTICIPANT	\N	PRESENT	0
290736	273921	14103D	PARTICIPANT	\N	PRESENT	0
290737	273921	16685X	PARTICIPANT	\N	PRESENT	0
290738	273921	14073Q	PARTICIPANT	\N	PRESENT	0
290739	273921	14221J	PARTICIPANT	\N	PRESENT	0
290740	273921	14034U	PARTICIPANT	\N	PRESENT	0
290741	273921	19735D	PARTICIPANT	\N	PRESENT	0
290742	273921	08056B	PARTICIPANT	\N	PRESENT	0
290743	273921	19569H	PARTICIPANT	\N	PRESENT	0
290744	273921	19737F	PARTICIPANT	\N	PRESENT	0
290745	273921	19749K	PARTICIPANT	\N	PRESENT	0
290746	273921	19699S	PARTICIPANT	\N	PRESENT	0
290747	273921	98018T	PARTICIPANT	\N	PRESENT	0
290748	273921	19369B	PARTICIPANT	\N	PRESENT	0
290749	273921	14179A	PARTICIPANT	\N	PRESENT	0
290750	273921	19691J	PARTICIPANT	\N	PRESENT	0
290751	273921	01034P	PARTICIPANT	\N	PRESENT	0
290752	273921	08061X	PARTICIPANT	\N	PRESENT	0
290753	273921	19717B	PARTICIPANT	\N	PRESENT	0
290754	273921	98022P	PARTICIPANT	\N	PRESENT	0
290755	273921	19545Y	PARTICIPANT	\N	PRESENT	0
290756	273921	11053K	PARTICIPANT	\N	PRESENT	0
290757	273921	14327T	PARTICIPANT	\N	PRESENT	0
290758	273921	19739H	PARTICIPANT	\N	PRESENT	0
290759	273921	14211G	PARTICIPANT	\N	PRESENT	0
290760	273921	19443T	PARTICIPANT	\N	PRESENT	0
290761	273921	07034Q	PARTICIPANT	\N	PRESENT	0
290762	273921	19711U	PARTICIPANT	\N	PRESENT	0
290763	273921	19581D	PARTICIPANT	\N	PRESENT	0
290765	273921	08011M	PARTICIPANT	\N	PRESENT	0
290766	273921	11026G	PARTICIPANT	\N	PRESENT	0
272227	270980	19515S	PARTICIPANT	\N	PRESENT	0
276052	273669	19703U	PARTICIPANT	\N	EXCUSE	0
273627	273626	14215L	PARTICIPANT	\N	PRESENT	0
273629	273628	14215L	PARTICIPANT	\N	PRESENT	0
279156	279155	08055A	PARTICIPANT	\N	PRESENT	0
279157	279155	19549D	PARTICIPANT	\N	PRESENT	0
279158	279155	19681G	PARTICIPANT	\N	PRESENT	0
279159	279155	98023Q	PARTICIPANT	\N	PRESENT	0
279160	279155	19347U	PARTICIPANT	\N	PRESENT	0
279161	279155	19333N	PARTICIPANT	\N	PRESENT	0
279162	279155	14219Q	PARTICIPANT	\N	PRESENT	0
279163	279155	19637C	PARTICIPANT	\N	PRESENT	0
279164	279155	08009T	PRESIDENT	0	PRESENT	0
279165	279155	05012A	PARTICIPANT	\N	PRESENT	0
279166	279155	19503N	PARTICIPANT	\N	PRESENT	0
279167	279155	14157T	PARTICIPANT	\N	PRESENT	0
279169	279155	19551W	PARTICIPANT	\N	PRESENT	0
293652	289103	04038G	PARTICIPANT	\N	PRESENT	0
282400	282399	11097X	PARTICIPANT	\N	PRESENT	0
286763	273988	19553Y	PARTICIPANT	\N	EXCUSE	0
286768	284818	08069G	PARTICIPANT	\N	EXCUSE	0
286769	284818	19467C	PARTICIPANT	\N	PRESENT	0
286770	284818	19349W	PARTICIPANT	\N	EXCUSE	0
286771	284818	08062Y	PARTICIPANT	\N	EXCUSE	0
286772	284818	19399H	PARTICIPANT	\N	EXCUSE	0
286773	284818	11066Q	PARTICIPANT	\N	PRESENT	0
293648	289103	19443T	PARTICIPANT	\N	PRESENT	0
293649	289103	19527W	PARTICIPANT	\N	PRESENT	0
293653	293441	14053L	PARTICIPANT	\N	EXCUSE	0
293654	293441	14065Q	PARTICIPANT	\N	EXCUSE	0
293655	293441	14259Y	PARTICIPANT	\N	EXCUSE	0
293766	289104	19611R	PARTICIPANT	\N	PRESENT	0
293767	289104	88008L	PARTICIPANT	\N	PRESENT	0
293768	289104	19533U	PARTICIPANT	\N	PRESENT	0
293769	289104	08044W	PARTICIPANT	\N	PRESENT	0
293770	289104	19367Y	PARTICIPANT	\N	PRESENT	0
293771	289104	14103D	PARTICIPANT	\N	PRESENT	0
293772	289104	97011G	PARTICIPANT	\N	PRESENT	0
293775	289104	18083K	PARTICIPANT	\N	PRESENT	0
293776	289104	19335Q	PARTICIPANT	\N	PRESENT	0
293777	289104	04059M	PARTICIPANT	\N	PRESENT	0
293778	289104	14021P	PARTICIPANT	\N	PRESENT	0
293779	289104	11104D	PARTICIPANT	\N	PRESENT	0
293780	289104	11045K	PARTICIPANT	\N	PRESENT	0
293781	289104	14030Q	PARTICIPANT	\N	PRESENT	0
293782	289104	19679N	PARTICIPANT	\N	PRESENT	0
293783	289104	08061X	PARTICIPANT	\N	PRESENT	0
293784	289104	19551W	PARTICIPANT	\N	PRESENT	0
293785	289104	14251Q	PARTICIPANT	\N	PRESENT	0
293786	289104	19687N	PARTICIPANT	\N	PRESENT	0
293787	289104	14089Y	PARTICIPANT	\N	PRESENT	0
293790	289104	14123H	PARTICIPANT	\N	PRESENT	0
293791	289104	95030B	PARTICIPANT	\N	PRESENT	0
293792	289104	08069G	PARTICIPANT	\N	PRESENT	0
293793	289104	19443T	PARTICIPANT	\N	PRESENT	0
293794	289104	08010L	PARTICIPANT	\N	PRESENT	0
293795	289104	11012A	PARTICIPANT	\N	PRESENT	0
293796	289104	14249W	PARTICIPANT	\N	PRESENT	0
293797	289104	19727D	PARTICIPANT	\N	PRESENT	0
293798	289104	14083S	PARTICIPANT	\N	PRESENT	0
293799	289104	04086Q	PARTICIPANT	\N	PRESENT	0
293800	289104	19569H	PARTICIPANT	\N	PRESENT	0
293801	289104	08052W	PARTICIPANT	\N	PRESENT	0
293802	289104	01048V	PARTICIPANT	\N	PRESENT	0
293803	289104	19549D	PARTICIPANT	\N	PRESENT	0
293804	289104	19713W	PARTICIPANT	\N	PRESENT	0
293805	289104	11097X	PARTICIPANT	\N	PRESENT	0
293806	289104	08045X	PARTICIPANT	\N	PRESENT	0
293807	289104	01034P	PARTICIPANT	\N	PRESENT	0
293808	289104	14121F	PARTICIPANT	\N	PRESENT	0
293809	289104	14215L	PARTICIPANT	\N	PRESENT	0
293810	289104	19399H	PARTICIPANT	\N	PRESENT	0
293811	289104	14053L	PARTICIPANT	\N	PRESENT	0
293812	289104	04040A	PARTICIPANT	\N	PRESENT	0
293813	289104	11067R	PARTICIPANT	\N	PRESENT	0
293814	289104	98022P	PARTICIPANT	\N	PRESENT	0
293815	289104	19573D	PARTICIPANT	\N	PRESENT	0
293816	289104	08034U	PARTICIPANT	\N	PRESENT	0
293818	289104	01058X	PARTICIPANT	\N	PRESENT	0
293819	289104	19563B	PARTICIPANT	\N	PRESENT	0
293820	289104	19553Y	PARTICIPANT	\N	PRESENT	0
293821	289104	14199E	PARTICIPANT	\N	PRESENT	0
293822	289104	11043H	PARTICIPANT	\N	PRESENT	0
293823	289104	01060R	PARTICIPANT	\N	PRESENT	0
293829	289104	14173T	PARTICIPANT	\N	PRESENT	0
293830	289104	14107H	PARTICIPANT	\N	PRESENT	0
293831	289104	14213J	PARTICIPANT	\N	PRESENT	0
293832	289104	19421M	PARTICIPANT	\N	PRESENT	0
285302	273901	04086Q	PARTICIPANT	\N	PRESENT	0
285303	273901	19369B	PARTICIPANT	\N	PRESENT	0
285304	273901	19565D	PARTICIPANT	\N	PRESENT	0
285305	273901	19593H	PARTICIPANT	\N	PRESENT	0
285306	273901	80013X	PARTICIPANT	\N	PRESENT	0
285307	273901	08039A	PARTICIPANT	\N	PRESENT	0
285308	273901	19667J	PARTICIPANT	\N	PRESENT	0
285309	273901	19503N	PARTICIPANT	\N	PRESENT	0
285310	273901	19295A	PARTICIPANT	\N	PRESENT	0
285311	273901	11067R	PARTICIPANT	\N	PRESENT	0
285312	273901	19333N	PARTICIPANT	\N	PRESENT	0
285313	273901	19413M	PARTICIPANT	\N	PRESENT	0
285314	273901	19531S	PARTICIPANT	\N	PRESENT	0
285315	273901	19591F	PARTICIPANT	\N	PRESENT	0
285316	273901	14151M	PARTICIPANT	\N	PRESENT	0
285317	273901	19727D	PARTICIPANT	\N	PRESENT	0
285318	273901	19631V	PARTICIPANT	\N	PRESENT	0
285319	273901	14257W	PARTICIPANT	\N	PRESENT	0
285320	273901	19349W	PARTICIPANT	\N	PRESENT	0
285321	273901	19269X	PARTICIPANT	\N	PRESENT	0
285322	273901	08068F	PARTICIPANT	\N	PRESENT	0
285323	273901	04045F	PARTICIPANT	\N	PRESENT	0
285324	273901	19735D	PARTICIPANT	\N	PRESENT	0
285325	273901	14327T	PARTICIPANT	\N	PRESENT	0
285326	273901	04070G	PARTICIPANT	\N	PRESENT	0
285327	273901	14179A	PARTICIPANT	\N	PRESENT	0
285328	273901	11012A	PARTICIPANT	\N	PRESENT	0
285329	273901	14195A	PARTICIPANT	\N	PRESENT	0
285330	273901	04040A	PARTICIPANT	\N	PRESENT	0
285331	273901	01025N	PARTICIPANT	\N	PRESENT	0
285332	273901	14197C	PARTICIPANT	\N	PRESENT	0
285333	273901	01028R	PARTICIPANT	\N	PRESENT	0
285334	273901	14251Q	PARTICIPANT	\N	PRESENT	0
285335	273901	19747H	PARTICIPANT	\N	PRESENT	0
285336	273901	14169X	PARTICIPANT	\N	PRESENT	0
285337	273901	19367Y	PARTICIPANT	\N	PRESENT	0
285338	273901	19621T	PARTICIPANT	\N	PRESENT	0
285339	273901	19515S	PARTICIPANT	\N	PRESENT	0
285340	273901	07034Q	PARTICIPANT	\N	PRESENT	0
285341	273901	17637T	PARTICIPANT	\N	PRESENT	0
285342	273901	05012A	PARTICIPANT	\N	PRESENT	0
285343	273901	14034U	PARTICIPANT	\N	PRESENT	0
285344	273901	19629C	PARTICIPANT	\N	PRESENT	0
285345	273901	19399H	PARTICIPANT	\N	PRESENT	0
285346	273901	11056N	PARTICIPANT	\N	PRESENT	0
285347	273901	19447X	PARTICIPANT	\N	PRESENT	0
285348	273901	19693L	PARTICIPANT	\N	PRESENT	0
285349	273901	14109K	PARTICIPANT	\N	PRESENT	0
285350	273901	19701S	PARTICIPANT	\N	PRESENT	0
285351	273901	11109J	PARTICIPANT	\N	PRESENT	0
285352	273901	01024M	PARTICIPANT	\N	PRESENT	0
285353	273901	11090Q	PARTICIPANT	\N	PRESENT	0
285354	273901	14053L	PARTICIPANT	\N	PRESENT	0
285355	273901	19441R	PARTICIPANT	\N	PRESENT	0
285361	273901	14231L	PARTICIPANT	\N	PRESENT	0
285359	273901	14083S	PARTICIPANT	\N	PRESENT	0
285358	273901	11048N	PARTICIPANT	\N	PRESENT	0
285360	273901	19749K	PARTICIPANT	\N	PRESENT	0
285362	273901	14147R	PARTICIPANT	\N	PRESENT	0
285363	273901	14187A	PARTICIPANT	\N	PRESENT	0
285364	273901	14105F	PARTICIPANT	\N	PRESENT	0
285365	273901	14157T	PARTICIPANT	\N	PRESENT	0
285366	273901	14357A	PARTICIPANT	\N	PRESENT	0
285367	273901	04049K	PARTICIPANT	\N	PRESENT	0
285368	273901	19575F	PARTICIPANT	\N	PRESENT	0
285369	273901	14329V	PARTICIPANT	\N	PRESENT	0
285370	273901	11097X	PARTICIPANT	\N	PRESENT	0
285371	273901	14265W	PARTICIPANT	\N	PRESENT	0
285372	273901	08016S	PARTICIPANT	\N	PRESENT	0
285373	273901	11077T	PARTICIPANT	\N	PRESENT	0
285374	273901	14087W	PARTICIPANT	\N	PRESENT	0
285375	273901	19713W	PARTICIPANT	\N	PRESENT	0
285376	273901	14069U	PARTICIPANT	\N	PRESENT	0
285377	273901	14217N	PARTICIPANT	\N	PRESENT	0
285378	273901	04088S	PARTICIPANT	\N	PRESENT	0
285379	273901	19687N	PARTICIPANT	\N	PRESENT	0
285380	273901	14135M	PARTICIPANT	\N	PRESENT	0
282667	282328	14030Q	PRESIDENT	0	PRESENT	0
282668	282328	08043V	PARTICIPANT	\N	PRESENT	0
282669	282328	19643A	PARTICIPANT	\N	PRESENT	0
282670	282328	08020N	PARTICIPANT	\N	PRESENT	0
282671	282328	19701S	PARTICIPANT	\N	PRESENT	0
282672	282328	11031D	PARTICIPANT	\N	PRESENT	0
282673	282328	14249W	PARTICIPANT	\N	PRESENT	0
282674	282328	19599P	PARTICIPANT	\N	PRESENT	0
282675	282328	14179A	PARTICIPANT	\N	PRESENT	0
282676	282328	19715Y	PARTICIPANT	\N	PRESENT	0
282677	282328	08031R	PARTICIPANT	\N	PRESENT	0
282678	282328	07029T	PARTICIPANT	\N	EXCUSE	0
282679	282328	08017T	PARTICIPANT	\N	PRESENT	0
282680	282328	01043Q	PARTICIPANT	\N	EXCUSE	0
282681	282328	14109K	PARTICIPANT	\N	EXCUSE	0
282682	282328	19269X	PARTICIPANT	\N	PRESENT	0
282683	282328	11045K	PARTICIPANT	\N	PRESENT	0
282684	282328	19749K	PARTICIPANT	\N	EXCUSE	0
284165	281772	11070L	PARTICIPANT	\N	PRESENT	0
284169	281772	14199E	PARTICIPANT	\N	PRESENT	0
284225	281772	04071H	PARTICIPANT	\N	PRESENT	0
284275	284102	01024M	PARTICIPANT	\N	PRESENT	0
284276	281773	04071H	PARTICIPANT	\N	PRESENT	0
284277	281773	01057W	PARTICIPANT	\N	PRESENT	0
284278	281773	11053K	PARTICIPANT	\N	PRESENT	0
284279	281773	19667J	PARTICIPANT	\N	PRESENT	0
284280	281773	19671E	PARTICIPANT	\N	PRESENT	0
284281	281773	14225N	PRESIDENT	0	PRESENT	0
284282	281773	07029T	PARTICIPANT	\N	PRESENT	0
284283	281773	14085U	PARTICIPANT	\N	PRESENT	0
284284	281773	14277B	PARTICIPANT	\N	PRESENT	0
284285	281773	19349W	PARTICIPANT	\N	PRESENT	0
284286	281773	08010L	PARTICIPANT	\N	PRESENT	0
284287	281773	14253S	PARTICIPANT	\N	PRESENT	0
284288	281773	19647E	PARTICIPANT	\N	PRESENT	0
284289	281773	19479G	PARTICIPANT	\N	PRESENT	0
284290	281773	19711U	PARTICIPANT	\N	PRESENT	0
284291	281773	08034U	PARTICIPANT	\N	PRESENT	0
284292	281773	19689Q	PARTICIPANT	\N	PRESENT	0
284293	281773	14034U	PARTICIPANT	\N	PRESENT	0
284294	281773	14159V	PARTICIPANT	\N	PRESENT	0
284295	281773	14173T	PARTICIPANT	\N	PRESENT	0
284296	281773	04086Q	PARTICIPANT	\N	PRESENT	0
284297	281773	14083S	PARTICIPANT	\N	PRESENT	0
284298	281773	11012A	PARTICIPANT	\N	PRESENT	0
284299	281773	08073C	PARTICIPANT	\N	PRESENT	0
284300	281773	19741B	PARTICIPANT	\N	PRESENT	0
284301	281773	14121F	PARTICIPANT	\N	PRESENT	0
284302	281773	99004R	PARTICIPANT	\N	PRESENT	0
284303	281773	04061F	PARTICIPANT	\N	PRESENT	0
284304	281773	08011M	PARTICIPANT	\N	EXCUSE	0
284305	281773	11074Q	PARTICIPANT	\N	EXCUSE	0
284306	281773	08014Q	PARTICIPANT	\N	EXCUSE	0
284322	281773	08069G	PARTICIPANT	\N	PRESENT	0
284323	281722	11097X	PARTICIPANT	\N	PRESENT	0
284324	281722	19717B	PARTICIPANT	\N	PRESENT	0
284325	281722	14213J	PARTICIPANT	\N	PRESENT	0
284326	281722	14071N	PARTICIPANT	\N	PRESENT	0
284476	281773	11110B	PARTICIPANT	\N	PRESENT	0
284477	284102	08018U	PARTICIPANT	\N	PRESENT	0
284478	282693	19515S	PARTICIPANT	\N	PRESENT	0
284479	282693	14357A	PARTICIPANT	\N	PRESENT	0
284480	282693	19441R	PARTICIPANT	\N	PRESENT	0
284481	282693	19413M	PARTICIPANT	\N	PRESENT	0
284482	282693	14081Q	PARTICIPANT	\N	PRESENT	0
284483	282693	80013X	PARTICIPANT	\N	PRESENT	0
284484	282693	19631V	PARTICIPANT	\N	PRESENT	0
284485	282693	11099A	PARTICIPANT	\N	PRESENT	0
284486	282693	08068F	PARTICIPANT	\N	PRESENT	0
284487	282693	04049K	PARTICIPANT	\N	PRESENT	0
284488	282693	08015R	PARTICIPANT	\N	PRESENT	0
284489	282693	14197C	PARTICIPANT	\N	PRESENT	0
284490	282693	14157T	PARTICIPANT	\N	PRESENT	0
284491	282693	19369B	PARTICIPANT	\N	PRESENT	0
284492	282693	08028W	PARTICIPANT	\N	PRESENT	0
284493	282693	19563B	PARTICIPANT	\N	PRESENT	0
284494	282693	14265W	PARTICIPANT	\N	PRESENT	0
284495	282693	14329V	PARTICIPANT	\N	PRESENT	0
284496	282693	19591F	PARTICIPANT	\N	PRESENT	0
284497	282693	14038Y	PARTICIPANT	\N	PRESENT	0
284498	282693	14135M	PARTICIPANT	\N	PRESENT	0
284499	282693	14187A	PARTICIPANT	\N	PRESENT	0
284500	282693	08038Y	PARTICIPANT	\N	PRESENT	0
284501	282693	19695N	PARTICIPANT	\N	PRESENT	0
284502	282693	08062Y	PARTICIPANT	\N	PRESENT	0
284503	282693	19301E	PARTICIPANT	\N	PRESENT	0
284504	282693	11090Q	PRESIDENT	0	PRESENT	0
284505	282693	01025N	PARTICIPANT	\N	PRESENT	0
284506	282693	14033T	PARTICIPANT	\N	PRESENT	0
284507	282693	19295A	PARTICIPANT	\N	PRESENT	0
284508	282693	19269X	PARTICIPANT	\N	PRESENT	0
284509	282693	14205J	PARTICIPANT	\N	PRESENT	0
284510	282693	11056N	PARTICIPANT	\N	PRESENT	0
284511	282693	04088S	PARTICIPANT	\N	PRESENT	0
284512	282693	04089T	PARTICIPANT	\N	PRESENT	0
284513	282693	19507S	PARTICIPANT	\N	PRESENT	0
284514	282693	19747H	PARTICIPANT	\N	PRESENT	0
284515	282693	14207L	PARTICIPANT	\N	PRESENT	0
284516	282693	04008A	PARTICIPANT	\N	PRESENT	0
284517	282693	04043D	PARTICIPANT	\N	PRESENT	0
284518	282693	17589D	PARTICIPANT	\N	PRESENT	0
284519	282693	19619A	PARTICIPANT	\N	PRESENT	0
284520	282693	14257W	PARTICIPANT	\N	PRESENT	0
284521	282693	14115H	PARTICIPANT	\N	PRESENT	0
284522	282693	11081P	PARTICIPANT	\N	EXCUSE	0
284540	273897	19715Y	PARTICIPANT	\N	PRESENT	0
284538	273897	11070L	PARTICIPANT	\N	PRESENT	0
284539	273897	14195A	PARTICIPANT	\N	PRESENT	0
284541	273897	19683J	PARTICIPANT	\N	PRESENT	0
284542	273897	19631V	PARTICIPANT	\N	PRESENT	0
284543	273897	19585H	PARTICIPANT	\N	PRESENT	0
284544	273897	14111D	PARTICIPANT	\N	PRESENT	0
284545	273897	17589D	PARTICIPANT	\N	PRESENT	0
284546	273897	04045F	PARTICIPANT	\N	PRESENT	0
284547	273897	19749K	PARTICIPANT	\N	PRESENT	0
284548	273897	08056B	PARTICIPANT	\N	PRESENT	0
284549	273897	19671E	PARTICIPANT	\N	PRESENT	0
284550	273897	19367Y	PARTICIPANT	\N	PRESENT	0
284551	273897	19731Y	PARTICIPANT	\N	PRESENT	0
284552	273897	19383Y	PARTICIPANT	\N	PRESENT	0
284553	273897	11103C	PARTICIPANT	\N	PRESENT	0
284554	273897	04035D	PARTICIPANT	\N	PRESENT	0
284555	273897	14223L	PARTICIPANT	\N	PRESENT	0
284556	273897	14069U	PARTICIPANT	\N	PRESENT	0
284557	273897	19253P	PARTICIPANT	\N	PRESENT	0
284558	273897	19441R	PARTICIPANT	\N	PRESENT	0
284559	273897	14157T	PARTICIPANT	\N	PRESENT	0
284560	273897	14265W	PARTICIPANT	\N	PRESENT	0
284561	273897	14241N	PARTICIPANT	\N	PRESENT	0
284562	273897	19741B	PARTICIPANT	\N	PRESENT	0
284563	273897	11065P	PARTICIPANT	\N	PRESENT	0
284564	273897	14207L	PARTICIPANT	\N	PRESENT	0
284565	273897	14071N	PARTICIPANT	\N	PRESENT	0
284566	273897	14249W	PARTICIPANT	\N	PRESENT	0
284567	273897	14073Q	PARTICIPANT	\N	PRESENT	0
284568	273897	08069G	PARTICIPANT	\N	PRESENT	0
284569	273897	04092N	PARTICIPANT	\N	PRESENT	0
284570	273897	19415P	PARTICIPANT	\N	PRESENT	0
284571	273897	19447X	PARTICIPANT	\N	PRESENT	0
284572	273897	19727D	PARTICIPANT	\N	PRESENT	0
284573	273897	97011G	PARTICIPANT	\N	PRESENT	0
284574	273897	11031D	PARTICIPANT	\N	PRESENT	0
284575	273897	19681G	PARTICIPANT	\N	PRESENT	0
284576	273897	14251Q	PARTICIPANT	\N	PRESENT	0
284577	273897	19301E	PARTICIPANT	\N	PRESENT	0
284578	273897	14179A	PARTICIPANT	\N	PRESENT	0
284579	273897	11040E	PARTICIPANT	\N	PRESENT	0
284580	273897	98022P	PARTICIPANT	\N	PRESENT	0
284581	273897	14033T	PARTICIPANT	\N	PRESENT	0
284582	273897	01025N	PARTICIPANT	\N	PRESENT	0
284583	273897	14063N	PARTICIPANT	\N	PRESENT	0
284584	273897	19599P	PARTICIPANT	\N	PRESENT	0
284586	273897	14259Y	PARTICIPANT	\N	PRESENT	0
284588	273897	14217N	PARTICIPANT	\N	PRESENT	0
284589	273897	19467C	PARTICIPANT	\N	PRESENT	0
284590	273897	95062K	PARTICIPANT	\N	PRESENT	0
284591	273897	98024R	PARTICIPANT	\N	PRESENT	0
284592	273897	19507S	PARTICIPANT	\N	PRESENT	0
284593	273897	98050T	PARTICIPANT	\N	PRESENT	0
284594	273897	14173T	PARTICIPANT	\N	PRESENT	0
284597	273897	14029X	PARTICIPANT	\N	PRESENT	0
284598	273897	19503N	PARTICIPANT	\N	PRESENT	0
284600	273897	14105F	PARTICIPANT	\N	PRESENT	0
284601	273897	11048N	PARTICIPANT	\N	PRESENT	0
284602	273897	19553Y	PARTICIPANT	\N	PRESENT	0
284603	273897	14261S	PARTICIPANT	\N	PRESENT	0
284604	273897	04088S	PARTICIPANT	\N	PRESENT	0
284605	273897	19543W	PARTICIPANT	\N	PRESENT	0
284606	273897	04086Q	PARTICIPANT	\N	PRESENT	0
272648	270350	19683J	PARTICIPANT	\N	PRESENT	0
272649	270350	19553Y	PARTICIPANT	\N	PRESENT	0
272650	270350	19663E	PARTICIPANT	\N	PRESENT	0
272651	270350	14221J	PARTICIPANT	\N	PRESENT	0
273942	273941	05008E	PARTICIPANT	\N	PRESENT	0
273943	273941	14069U	PARTICIPANT	\N	PRESENT	0
273944	273941	14259Y	PARTICIPANT	\N	PRESENT	0
273945	273941	19725B	PARTICIPANT	\N	PRESENT	0
273948	273941	01028R	PARTICIPANT	\N	PRESENT	0
273949	273941	19543W	PARTICIPANT	\N	PRESENT	0
273950	273941	14089Y	PARTICIPANT	\N	PRESENT	0
273951	273941	19629C	PARTICIPANT	\N	PRESENT	0
273952	273941	19507S	PARTICIPANT	\N	PRESENT	0
279827	279498	14087W	PARTICIPANT	\N	PRESENT	0
280879	280178	08016S	PARTICIPANT	\N	EXCUSE	0
282420	282419	19667J	PARTICIPANT	\N	PRESENT	0
282421	282419	19575F	PARTICIPANT	\N	PRESENT	0
282422	282419	14069U	PARTICIPANT	\N	PRESENT	0
282423	282419	14083S	PARTICIPANT	\N	PRESENT	0
282424	282419	11053K	PARTICIPANT	\N	PRESENT	0
282425	282419	14267Y	PARTICIPANT	\N	PRESENT	0
282426	282419	14041T	PARTICIPANT	\N	PRESENT	0
282427	282419	14081Q	PARTICIPANT	\N	PRESENT	0
282428	282419	19569H	PARTICIPANT	\N	PRESENT	0
282429	282419	14179A	PARTICIPANT	\N	PRESENT	0
282430	282419	19333N	PARTICIPANT	\N	PRESENT	0
282431	282419	08031R	PARTICIPANT	\N	PRESENT	0
282432	282419	19611R	PARTICIPANT	\N	PRESENT	0
282433	282419	19671E	PARTICIPANT	\N	PRESENT	0
282434	282419	19739H	PARTICIPANT	\N	PRESENT	0
282436	282435	08018U	PARTICIPANT	\N	PRESENT	0
282437	282435	19649G	PARTICIPANT	\N	PRESENT	0
282439	282438	08018U	PARTICIPANT	\N	PRESENT	0
299931	289193	04034C	PARTICIPANT	\N	PRESENT	0
299932	289193	16685X	PARTICIPANT	\N	PRESENT	0
299933	289193	19443T	PARTICIPANT	\N	PRESENT	0
299934	289193	14133K	PARTICIPANT	\N	PRESENT	0
299935	289193	19631V	PARTICIPANT	\N	PRESENT	0
299936	289193	08039A	PARTICIPANT	\N	PRESENT	0
299937	289193	04086Q	PARTICIPANT	\N	PRESENT	0
299938	289193	19591F	PARTICIPANT	\N	PRESENT	0
299939	289193	04088S	PARTICIPANT	\N	PRESENT	0
299940	289193	18083K	PARTICIPANT	\N	PRESENT	0
299941	289193	19760E	PARTICIPANT	\N	PRESENT	0
299942	289193	08038Y	PARTICIPANT	\N	PRESENT	0
299943	289193	19737F	PARTICIPANT	\N	PRESENT	0
299944	289193	19713W	PARTICIPANT	\N	PRESENT	0
299945	289193	19745F	PARTICIPANT	\N	PRESENT	0
299946	289193	11066Q	PARTICIPANT	\N	PRESENT	0
299947	289193	14063N	PARTICIPANT	\N	PRESENT	0
299948	289193	04018C	PARTICIPANT	\N	PRESENT	0
299949	289193	19515S	PARTICIPANT	\N	PRESENT	0
299950	289193	14191V	PARTICIPANT	\N	PRESENT	0
299951	289193	19699S	PARTICIPANT	\N	PRESENT	0
299952	289193	02002K	PARTICIPANT	\N	PRESENT	0
299953	289193	08060W	PARTICIPANT	\N	PRESENT	0
299954	289193	14197C	PARTICIPANT	\N	PRESENT	0
299955	289193	19349W	PARTICIPANT	\N	PRESENT	0
299956	289193	11065P	PARTICIPANT	\N	PRESENT	0
299957	289193	14229S	PARTICIPANT	\N	PRESENT	0
299958	289193	11104D	PARTICIPANT	\N	PRESENT	0
299959	289193	14089Y	PARTICIPANT	\N	PRESENT	0
299960	289193	19671E	PARTICIPANT	\N	PRESENT	0
299961	289193	14237S	PARTICIPANT	\N	PRESENT	0
299962	289193	19387D	PARTICIPANT	\N	PRESENT	0
299963	289193	08068F	PARTICIPANT	\N	PRESENT	0
299964	289193	19413M	PARTICIPANT	\N	PRESENT	0
299965	289193	19301E	PARTICIPANT	\N	PRESENT	0
299966	289193	14227Q	PARTICIPANT	\N	PRESENT	0
299967	289193	14093U	PARTICIPANT	\N	PRESENT	0
299968	289193	19629C	PARTICIPANT	\N	PRESENT	0
299969	289193	19563B	PARTICIPANT	\N	PRESENT	0
299970	289193	19739H	PARTICIPANT	\N	PRESENT	0
299971	289193	19729F	PARTICIPANT	\N	PRESENT	0
299972	289193	08015R	PARTICIPANT	\N	PRESENT	0
299973	289193	19383Y	PARTICIPANT	\N	PRESENT	0
299974	289193	14147R	PARTICIPANT	\N	PRESENT	0
299975	289193	19663E	PARTICIPANT	\N	PRESENT	0
299976	289193	14119M	PARTICIPANT	\N	PRESENT	0
299977	289193	14033T	PARTICIPANT	\N	PRESENT	0
299978	289193	19415P	PARTICIPANT	\N	PRESENT	0
299979	289193	19703U	PARTICIPANT	\N	PRESENT	0
299980	289193	19643A	PARTICIPANT	\N	PRESENT	0
299981	289193	19525U	PARTICIPANT	\N	PRESENT	0
299982	289193	95037J	PARTICIPANT	\N	PRESENT	0
299983	289193	14357A	PARTICIPANT	\N	PRESENT	0
299984	289193	19399H	PARTICIPANT	\N	PRESENT	0
299985	289193	95015C	PARTICIPANT	\N	PRESENT	0
299986	289193	96004D	PARTICIPANT	\N	PRESENT	0
299987	289193	04008A	PARTICIPANT	\N	PRESENT	0
299988	289193	14187A	PARTICIPANT	\N	PRESENT	0
299989	289193	19573D	PARTICIPANT	\N	PRESENT	0
299990	289193	19447X	PARTICIPANT	\N	PRESENT	0
299991	289193	14215L	PARTICIPANT	\N	PRESENT	0
299992	289193	19621T	PARTICIPANT	\N	PRESENT	0
299993	289193	14327T	PARTICIPANT	\N	PRESENT	0
299994	289193	17637T	PARTICIPANT	\N	PRESENT	0
299995	289193	19758L	PARTICIPANT	\N	PRESENT	0
299996	289193	19347U	PARTICIPANT	\N	PRESENT	0
299997	289193	19695N	PARTICIPANT	\N	PRESENT	0
299998	289193	19467C	PARTICIPANT	\N	PRESENT	0
299999	289193	08017T	PARTICIPANT	\N	PRESENT	0
300000	289193	97011G	PARTICIPANT	\N	PRESENT	0
300001	289193	14107H	PARTICIPANT	\N	PRESENT	0
300002	289193	11097X	PARTICIPANT	\N	PRESENT	0
300003	289193	19651A	PARTICIPANT	\N	PRESENT	0
300004	289193	08045X	PARTICIPANT	\N	PRESENT	0
300005	289193	19619A	PARTICIPANT	\N	PRESENT	0
300006	289193	14207L	PARTICIPANT	\N	PRESENT	0
300007	289193	19749K	PARTICIPANT	\N	PRESENT	0
300008	289193	19747H	PARTICIPANT	\N	PRESENT	0
300009	289193	12016W	PARTICIPANT	\N	PRESENT	0
300010	289193	19367Y	PARTICIPANT	\N	PRESENT	0
300011	289193	14039A	PARTICIPANT	\N	PRESENT	0
300012	289193	14030Q	PARTICIPANT	\N	PRESENT	0
300013	289193	19687N	PARTICIPANT	\N	PRESENT	0
300014	289193	01043Q	PARTICIPANT	\N	PRESENT	0
300015	289193	19711U	PARTICIPANT	\N	PRESENT	0
300016	289193	14223L	PARTICIPANT	\N	PRESENT	0
300017	289193	11090Q	PARTICIPANT	\N	PRESENT	0
300018	289193	08062Y	PARTICIPANT	\N	PRESENT	0
300019	289193	14029X	PARTICIPANT	\N	PRESENT	0
300020	289193	19741B	PARTICIPANT	\N	PRESENT	0
300021	289193	11103C	PARTICIPANT	\N	PRESENT	0
300022	289193	14331P	PARTICIPANT	\N	PRESENT	0
300023	289193	05008E	PARTICIPANT	\N	PRESENT	0
300024	289193	11085T	PARTICIPANT	\N	PRESENT	0
300026	289193	14021P	PARTICIPANT	\N	PRESENT	0
300027	289193	19701S	PARTICIPANT	\N	PRESENT	0
300028	289193	19611R	PARTICIPANT	\N	PRESENT	0
300029	289193	95062K	PARTICIPANT	\N	PRESENT	0
300030	289193	95067Q	PARTICIPANT	\N	PRESENT	0
300031	289193	11048N	PARTICIPANT	\N	PRESENT	0
300032	289193	11012A	PARTICIPANT	\N	PRESENT	0
300035	289193	19673G	PARTICIPANT	\N	PRESENT	0
300036	289193	19533U	PARTICIPANT	\N	PRESENT	0
300037	289193	14217N	PARTICIPANT	\N	PRESENT	0
300038	289193	11077T	PARTICIPANT	\N	PRESENT	0
300039	289193	19689Q	PARTICIPANT	\N	PRESENT	0
300040	289193	19717B	PARTICIPANT	\N	PRESENT	0
300041	289193	19735D	PARTICIPANT	\N	PRESENT	0
300042	289193	19675J	PARTICIPANT	\N	PRESENT	0
300044	289193	19657G	PARTICIPANT	\N	PRESENT	0
300045	289193	19543W	PARTICIPANT	\N	PRESENT	0
300046	289193	19669L	PARTICIPANT	\N	PRESENT	0
300047	289193	19549D	PARTICIPANT	\N	PRESENT	0
300048	289193	08019V	PARTICIPANT	\N	PRESENT	0
300049	289193	14026U	PARTICIPANT	\N	PRESENT	0
300050	289193	19511N	PARTICIPANT	\N	PRESENT	0
300051	289193	19441R	PARTICIPANT	\N	PRESENT	0
300052	289193	14042U	PARTICIPANT	\N	PRESENT	0
300053	289193	11045K	PARTICIPANT	\N	PRESENT	0
300054	289193	07004J	PARTICIPANT	\N	PRESENT	0
300055	289193	19667J	PARTICIPANT	\N	PRESENT	0
300056	289193	04085P	PARTICIPANT	\N	PRESENT	0
300057	289193	19551W	PARTICIPANT	\N	PRESENT	0
300058	289193	19489J	PARTICIPANT	\N	PRESENT	0
300059	289193	19727D	PARTICIPANT	\N	PRESENT	0
300060	289193	11067R	PARTICIPANT	\N	PRESENT	0
300061	289193	19649G	PARTICIPANT	\N	PRESENT	0
300062	289193	19659J	PARTICIPANT	\N	PRESENT	0
300063	289193	14083S	PARTICIPANT	\N	PRESENT	0
300064	289193	19593H	PARTICIPANT	\N	PRESENT	0
300065	289193	19679N	PARTICIPANT	\N	PRESENT	0
300066	289193	17779H	PARTICIPANT	\N	PRESENT	0
300067	289193	10006L	PARTICIPANT	\N	PRESENT	0
290767	273921	04089T	PARTICIPANT	\N	PRESENT	0
290768	273921	11090Q	PARTICIPANT	\N	PRESENT	0
290769	273921	19671E	PARTICIPANT	\N	PRESENT	0
290775	273921	14231L	PARTICIPANT	\N	PRESENT	0
290771	273921	14157T	PARTICIPANT	\N	PRESENT	0
290772	273921	19511N	PARTICIPANT	\N	PRESENT	0
290773	273921	04044E	PARTICIPANT	\N	PRESENT	0
290774	273921	14205J	PARTICIPANT	\N	PRESENT	0
290776	273921	95015C	PARTICIPANT	\N	PRESENT	0
290777	273921	04070G	PARTICIPANT	\N	PRESENT	0
290778	273921	01060R	PARTICIPANT	\N	PRESENT	0
290779	273921	14079W	PARTICIPANT	\N	PRESENT	0
290780	273921	19611R	PARTICIPANT	\N	PRESENT	0
290781	273921	19575F	PARTICIPANT	\N	PRESENT	0
290782	273921	14251Q	PARTICIPANT	\N	PRESENT	0
290783	273921	19687N	PARTICIPANT	\N	PRESENT	0
290784	273921	14029X	PARTICIPANT	\N	PRESENT	0
291087	273923	11072N	PARTICIPANT	\N	PRESENT	0
291088	273923	19715Y	PARTICIPANT	\N	PRESENT	0
291089	273923	14197C	PARTICIPANT	\N	PRESENT	0
291094	273923	19503N	PARTICIPANT	\N	PRESENT	0
291095	273923	19333N	PARTICIPANT	\N	PRESENT	0
291092	273923	12041X	PARTICIPANT	\N	PRESENT	0
291093	273923	08017T	PARTICIPANT	\N	PRESENT	0
291096	273923	14121F	PARTICIPANT	\N	PRESENT	0
291097	273923	11104D	PARTICIPANT	\N	PRESENT	0
291098	273923	19725B	PARTICIPANT	\N	PRESENT	0
291099	273923	14207L	PARTICIPANT	\N	PRESENT	0
291100	273923	08053X	PARTICIPANT	\N	PRESENT	0
291101	273923	14097Y	PARTICIPANT	\N	PRESENT	0
291102	273923	14257W	PARTICIPANT	\N	PRESENT	0
291103	273923	19447X	PARTICIPANT	\N	PRESENT	0
291104	273923	14107H	PARTICIPANT	\N	PRESENT	0
291105	273923	08055A	PARTICIPANT	\N	PRESENT	0
291106	273923	19643A	PARTICIPANT	\N	PRESENT	0
291107	273923	08060W	PARTICIPANT	\N	PRESENT	0
291108	273923	19637C	PARTICIPANT	\N	PRESENT	0
291109	273923	19651A	PARTICIPANT	\N	PRESENT	0
291110	273923	14221J	PARTICIPANT	\N	PRESENT	0
291111	273923	14205J	PARTICIPANT	\N	PRESENT	0
291112	273923	14135M	PARTICIPANT	\N	PRESENT	0
291113	273923	11033F	PARTICIPANT	\N	PRESENT	0
291114	273923	19543W	PARTICIPANT	\N	PRESENT	0
291115	273923	19269X	PARTICIPANT	\N	PRESENT	0
291116	273923	04045F	PARTICIPANT	\N	PRESENT	0
291117	273923	19349W	PARTICIPANT	\N	PRESENT	0
291118	273923	08061X	PARTICIPANT	\N	PRESENT	0
291119	273923	08016S	PARTICIPANT	\N	PRESENT	0
291120	273923	19563B	PARTICIPANT	\N	PRESENT	0
291121	273923	14029X	PARTICIPANT	\N	PRESENT	0
291122	273923	11099A	PARTICIPANT	\N	PRESENT	0
291123	273923	04088S	PARTICIPANT	\N	PRESENT	0
291124	273923	19719D	PARTICIPANT	\N	PRESENT	0
291125	273923	19507S	PARTICIPANT	\N	PRESENT	0
291126	273923	19301E	PARTICIPANT	\N	PRESENT	0
291127	273923	14033T	PARTICIPANT	\N	PRESENT	0
291128	273923	17589D	PARTICIPANT	\N	PRESENT	0
291129	273923	11064N	PARTICIPANT	\N	PRESENT	0
291130	273923	18083K	PARTICIPANT	\N	PRESENT	0
291131	273923	14195A	PARTICIPANT	\N	PRESENT	0
291132	273923	14157T	PARTICIPANT	\N	PRESENT	0
291133	273923	19441R	PARTICIPANT	\N	PRESENT	0
291134	273923	01057W	PARTICIPANT	\N	PRESENT	0
291135	273923	19479G	PARTICIPANT	\N	PRESENT	0
291136	273923	14069U	PARTICIPANT	\N	PRESENT	0
291137	273923	14219Q	PARTICIPANT	\N	PRESENT	0
291138	273923	14223L	PARTICIPANT	\N	PRESENT	0
291139	273923	19369B	PARTICIPANT	\N	PRESENT	0
291140	273923	19569H	PARTICIPANT	\N	PRESENT	0
291141	273923	14115H	PARTICIPANT	\N	PRESENT	0
291142	273923	19735D	PARTICIPANT	\N	PRESENT	0
291143	273923	19443T	PARTICIPANT	\N	PRESENT	0
291144	273923	01025N	PARTICIPANT	\N	PRESENT	0
291145	273923	01024M	PARTICIPANT	\N	PRESENT	0
291146	273923	11097X	PARTICIPANT	\N	PRESENT	0
291147	273923	95030B	PARTICIPANT	\N	PRESENT	0
291148	273923	14191V	PARTICIPANT	\N	PRESENT	0
291149	273923	11090Q	PARTICIPANT	\N	PRESENT	0
291150	273923	11056N	PARTICIPANT	\N	PRESENT	0
291151	273923	19533U	PARTICIPANT	\N	PRESENT	0
291152	273923	11103C	PARTICIPANT	\N	PRESENT	0
291153	273923	14331P	PARTICIPANT	\N	PRESENT	0
291154	273923	04049K	PARTICIPANT	\N	PRESENT	0
291155	273923	19383Y	PARTICIPANT	\N	PRESENT	0
291156	273923	19387D	PARTICIPANT	\N	PRESENT	0
291157	273923	14329V	PARTICIPANT	\N	PRESENT	0
291158	273923	14213J	PARTICIPANT	\N	PRESENT	0
291159	273923	14079W	PARTICIPANT	\N	PRESENT	0
291160	273923	89017R	PARTICIPANT	\N	PRESENT	0
291161	273923	19745F	PARTICIPANT	\N	PRESENT	0
291162	273923	19749K	PARTICIPANT	\N	PRESENT	0
291163	273923	14327T	PARTICIPANT	\N	PRESENT	0
291164	273923	19467C	PARTICIPANT	\N	PRESENT	0
291165	273923	08009T	PARTICIPANT	\N	PRESENT	0
291166	273923	19758L	PARTICIPANT	\N	PRESENT	0
291167	273923	19695N	PARTICIPANT	\N	PRESENT	0
291168	273923	19593H	PARTICIPANT	\N	PRESENT	0
291169	273923	19573D	PARTICIPANT	\N	PRESENT	0
291170	273923	19747H	PARTICIPANT	\N	PRESENT	0
291171	273923	14038Y	PARTICIPANT	\N	PRESENT	0
291172	273923	19619A	PARTICIPANT	\N	PRESENT	0
291173	273923	19667J	PARTICIPANT	\N	PRESENT	0
291174	273923	19399H	PARTICIPANT	\N	PRESENT	0
291175	273923	14265W	PARTICIPANT	\N	PRESENT	0
291176	273923	87003B	PARTICIPANT	\N	PRESENT	0
291177	273923	14217N	PARTICIPANT	\N	PRESENT	0
291178	273923	19553Y	PARTICIPANT	\N	PRESENT	0
291179	273923	11012A	PARTICIPANT	\N	PRESENT	0
291180	273923	01034P	PARTICIPANT	\N	PRESENT	0
291181	273923	14201E	PARTICIPANT	\N	PRESENT	0
291182	273923	19511N	PARTICIPANT	\N	PRESENT	0
291183	273923	19551W	PARTICIPANT	\N	PRESENT	0
291184	273923	80013X	PARTICIPANT	\N	PRESENT	0
291187	273923	19621T	PARTICIPANT	\N	PRESENT	0
291188	273923	14231L	PARTICIPANT	\N	PRESENT	0
291189	273923	14061L	PARTICIPANT	\N	PRESENT	0
291190	273923	08015R	PARTICIPANT	\N	PRESENT	0
291191	273923	14105F	PARTICIPANT	\N	PRESENT	0
291192	273923	19515S	PARTICIPANT	\N	PRESENT	0
291193	273923	17583W	PARTICIPANT	\N	PRESENT	0
291194	273923	19531S	PARTICIPANT	\N	PRESENT	0
291195	273923	19413M	PARTICIPANT	\N	PRESENT	0
291196	273923	01048V	PARTICIPANT	\N	PRESENT	0
291197	273923	14119M	PARTICIPANT	\N	PRESENT	0
291198	273923	14083S	PARTICIPANT	\N	PRESENT	0
291199	273923	19347U	PARTICIPANT	\N	PRESENT	0
291200	273923	19549D	PARTICIPANT	\N	PRESENT	0
291201	273923	14357A	PARTICIPANT	\N	PRESENT	0
291202	273923	14031R	PARTICIPANT	\N	PRESENT	0
291203	273923	05012A	PARTICIPANT	\N	PRESENT	0
291204	273923	04097T	PARTICIPANT	\N	PRESENT	0
291205	273923	16685X	PARTICIPANT	\N	PRESENT	0
291206	273923	19565D	PARTICIPANT	\N	PRESENT	0
291207	273923	14030Q	PARTICIPANT	\N	PRESENT	0
291208	273923	19629C	PARTICIPANT	\N	PRESENT	0
291209	273923	14237S	PARTICIPANT	\N	PRESENT	0
291210	273923	01058X	PARTICIPANT	\N	PRESENT	0
291211	273923	08010L	PARTICIPANT	\N	PRESENT	0
291212	273923	08024S	PARTICIPANT	\N	PRESENT	0
291213	273923	14051J	PARTICIPANT	\N	PRESENT	0
291214	273923	08056B	PARTICIPANT	\N	PRESENT	0
291215	273923	14123H	PARTICIPANT	\N	PRESENT	0
291216	273923	08020N	PARTICIPANT	\N	PRESENT	0
291217	273923	14215L	PARTICIPANT	\N	PRESENT	0
291218	273923	07029T	PARTICIPANT	\N	PRESENT	0
291219	273923	19703U	PARTICIPANT	\N	PRESENT	0
291220	273923	14042U	PARTICIPANT	\N	PRESENT	0
271569	271568	04070G	PARTICIPANT	\N	PRESENT	0
271570	271568	08031R	PARTICIPANT	\N	PRESENT	0
271571	271568	08039A	PARTICIPANT	\N	PRESENT	0
271578	271232	14031R	PARTICIPANT	\N	PRESENT	0
273331	273330	08035V	PARTICIPANT	\N	PRESENT	0
273332	273330	19631V	PARTICIPANT	\N	PRESENT	0
273333	273330	14255U	PARTICIPANT	\N	PRESENT	0
273334	273330	08038Y	PARTICIPANT	\N	PRESENT	0
273335	273330	11070L	PARTICIPANT	\N	PRESENT	0
273336	273330	19251M	PARTICIPANT	\N	PRESENT	0
273337	273330	19347U	PARTICIPANT	\N	PRESENT	0
273338	273330	14179A	PARTICIPANT	\N	PRESENT	0
273339	273330	19591F	PARTICIPANT	\N	PRESENT	0
273340	273330	08053X	PARTICIPANT	\N	PRESENT	0
273341	273330	19563B	PARTICIPANT	\N	PRESENT	0
273342	273330	14235Q	PARTICIPANT	\N	PRESENT	0
273343	273330	19687N	PARTICIPANT	\N	PRESENT	0
273344	273330	01062T	PARTICIPANT	\N	PRESENT	0
273345	273330	08049C	PARTICIPANT	\N	PRESENT	0
273356	273354	19631V	PARTICIPANT	\N	PRESENT	0
273359	273354	19251M	PARTICIPANT	\N	PRESENT	0
273360	273354	08035V	PARTICIPANT	\N	PRESENT	0
273362	273354	19347U	PARTICIPANT	\N	PRESENT	0
273363	273354	11049P	PARTICIPANT	\N	PRESENT	0
273365	273354	11064N	PARTICIPANT	\N	PRESENT	0
273367	273354	08053X	PARTICIPANT	\N	PRESENT	0
273368	273354	14235Q	PARTICIPANT	\N	PRESENT	0
273369	273354	19687N	PARTICIPANT	\N	PRESENT	0
273370	273354	04018C	PARTICIPANT	\N	PRESENT	0
273371	273354	19669L	PARTICIPANT	\N	PRESENT	0
273372	273354	19413M	PARTICIPANT	\N	PRESENT	0
273373	273354	01062T	PARTICIPANT	\N	PRESENT	0
273374	273354	95067Q	PARTICIPANT	\N	PRESENT	0
275105	273327	07029T	PARTICIPANT	\N	EXCUSE	0
275106	273327	14331P	PARTICIPANT	\N	EXCUSE	0
275107	273327	08034U	PARTICIPANT	\N	EXCUSE	0
275108	273327	08073C	PARTICIPANT	\N	EXCUSE	0
275109	273327	14277B	PARTICIPANT	\N	EXCUSE	0
275110	273327	08010L	PARTICIPANT	\N	EXCUSE	0
275111	273327	08014Q	PARTICIPANT	\N	EXCUSE	0
275155	273327	96004D	PARTICIPANT	\N	PRESENT	0
275293	263766	86034E	PARTICIPANT	\N	PRESENT	0
275309	263766	14223L	PARTICIPANT	\N	PRESENT	0
275311	263766	19581D	PARTICIPANT	\N	PRESENT	0
275320	263766	08055A	PARTICIPANT	\N	PRESENT	0
275321	263766	14107H	PARTICIPANT	\N	PRESENT	0
275322	263766	14121F	PARTICIPANT	\N	PRESENT	0
275323	263766	11104D	PARTICIPANT	\N	PRESENT	0
275324	263766	19651A	PARTICIPANT	\N	PRESENT	0
275325	263766	19319Q	PARTICIPANT	\N	PRESENT	0
275326	263766	19569H	PARTICIPANT	\N	PRESENT	0
275327	263766	19583F	PARTICIPANT	\N	PRESENT	0
275328	263766	14201E	PARTICIPANT	\N	PRESENT	0
275329	263766	14063N	PARTICIPANT	\N	PRESENT	0
275330	263766	19553Y	PARTICIPANT	\N	PRESENT	0
275331	263766	19619A	PARTICIPANT	\N	PRESENT	0
275332	263766	19563B	PARTICIPANT	\N	PRESENT	0
275333	263766	04085P	PARTICIPANT	\N	PRESENT	0
275334	263766	19695N	PARTICIPANT	\N	PRESENT	0
275335	263766	14235Q	PARTICIPANT	\N	PRESENT	0
275336	263766	19565D	PARTICIPANT	\N	PRESENT	0
275337	263766	14159V	PARTICIPANT	\N	PRESENT	0
275338	263766	08043V	PARTICIPANT	\N	PRESENT	0
275339	263766	19719D	PARTICIPANT	\N	PRESENT	0
275340	263766	14111D	PARTICIPANT	\N	PRESENT	0
275341	263766	08016S	PARTICIPANT	\N	PRESENT	0
275343	263766	19349W	PARTICIPANT	\N	PRESENT	0
275344	263766	19253P	PARTICIPANT	\N	PRESENT	0
275346	263766	19681G	PARTICIPANT	\N	PRESENT	0
275347	263766	19549D	PARTICIPANT	\N	PRESENT	0
275348	263766	19725B	PARTICIPANT	\N	PRESENT	0
275349	263766	19525U	PARTICIPANT	\N	PRESENT	0
275350	263766	19251M	PARTICIPANT	\N	PRESENT	0
275351	263766	11040E	PARTICIPANT	\N	PRESENT	0
275352	263766	14051J	PARTICIPANT	\N	PRESENT	0
275353	263766	11033F	PARTICIPANT	\N	PRESENT	0
275355	263766	19533U	PARTICIPANT	\N	PRESENT	0
275358	263766	14267Y	PARTICIPANT	\N	PRESENT	0
275359	263766	19721W	PARTICIPANT	\N	PRESENT	0
275363	263766	19333N	PARTICIPANT	\N	PRESENT	0
275364	263766	19637C	PARTICIPANT	\N	PRESENT	0
275365	263766	14221J	PARTICIPANT	\N	PRESENT	0
275366	263766	14097Y	PARTICIPANT	\N	PRESENT	0
275367	263766	19715Y	PARTICIPANT	\N	PRESENT	0
275368	263766	19683J	PARTICIPANT	\N	PRESENT	0
275369	263766	19713W	PARTICIPANT	\N	PRESENT	0
275370	263766	17779H	PARTICIPANT	\N	PRESENT	0
275371	263766	08060W	PARTICIPANT	\N	PRESENT	0
275372	263766	11012A	PARTICIPANT	\N	PRESENT	0
275373	263766	19687N	PARTICIPANT	\N	PRESENT	0
275374	263766	11077T	PARTICIPANT	\N	PRESENT	0
275375	263766	08061X	PARTICIPANT	\N	PRESENT	0
275376	263766	08024S	PARTICIPANT	\N	PRESENT	0
275377	263766	95063L	PARTICIPANT	\N	PRESENT	0
275378	263766	08017T	PARTICIPANT	\N	PRESENT	0
275379	263766	19611R	PARTICIPANT	\N	PRESENT	0
275380	263766	98029W	PARTICIPANT	\N	PRESENT	0
275381	263766	95037J	PARTICIPANT	\N	PRESENT	0
275382	263766	11066Q	PARTICIPANT	\N	PRESENT	0
275383	263766	11067R	PARTICIPANT	\N	PRESENT	0
275384	263766	08035V	PARTICIPANT	\N	PRESENT	0
275385	263766	19717B	PARTICIPANT	\N	PRESENT	0
275386	263766	08058D	PARTICIPANT	\N	PRESENT	0
275387	263766	19413M	PARTICIPANT	\N	PRESENT	0
275388	263766	14227Q	PARTICIPANT	\N	PRESENT	0
275389	263766	19503N	PARTICIPANT	\N	PRESENT	0
275390	263766	19669L	PARTICIPANT	\N	PRESENT	0
275391	263766	14001X	PARTICIPANT	\N	PRESENT	0
275392	263766	19697Q	PARTICIPANT	\N	PRESENT	0
275393	263766	19387D	PARTICIPANT	\N	PRESENT	0
275394	263766	11072N	PARTICIPANT	\N	PRESENT	0
275400	263766	08068F	PARTICIPANT	\N	PRESENT	0
275403	263766	12016W	PARTICIPANT	\N	PRESENT	0
275407	263766	11048N	PARTICIPANT	\N	PRESENT	0
275410	263766	98023Q	PARTICIPANT	\N	PRESENT	0
275411	263766	12041X	PARTICIPANT	\N	PRESENT	0
275413	263766	19593H	PARTICIPANT	\N	PRESENT	0
275414	263766	08039A	PARTICIPANT	\N	PRESENT	0
275416	263766	95062K	PARTICIPANT	\N	PRESENT	0
275417	263766	19443T	PARTICIPANT	\N	PRESENT	0
275418	263766	14034U	PARTICIPANT	\N	PRESENT	0
275419	263766	08031R	PARTICIPANT	\N	PRESENT	0
275421	263766	19741B	PARTICIPANT	\N	PRESENT	0
275423	263766	14261S	PARTICIPANT	\N	PRESENT	0
275425	263766	14029X	PARTICIPANT	\N	PRESENT	0
275426	263766	14038Y	PARTICIPANT	\N	PRESENT	0
275427	263766	14241N	PARTICIPANT	\N	PRESENT	0
275429	263766	19723Y	PARTICIPANT	\N	PRESENT	0
275430	263766	19467C	PARTICIPANT	\N	PRESENT	0
275431	263766	19289C	PARTICIPANT	\N	PRESENT	0
275433	263766	19507S	PARTICIPANT	\N	PRESENT	0
275435	263766	11064N	PARTICIPANT	\N	PRESENT	0
275437	263766	19415P	PARTICIPANT	\N	PRESENT	0
275438	263766	14093U	PARTICIPANT	\N	PRESENT	0
275439	263766	04088S	PARTICIPANT	\N	PRESENT	0
275440	263766	14041T	PARTICIPANT	\N	PRESENT	0
275441	263766	19685L	PARTICIPANT	\N	PRESENT	0
275442	263766	08018U	PARTICIPANT	\N	PRESENT	0
275443	263766	19731Y	PARTICIPANT	\N	PRESENT	0
275444	263766	14033T	PARTICIPANT	\N	PRESENT	0
275445	263766	92040Q	PARTICIPANT	\N	PRESENT	0
275446	263766	14133K	PARTICIPANT	\N	PRESENT	0
275447	263766	98005N	PARTICIPANT	\N	PRESENT	0
275448	263766	19745F	PARTICIPANT	\N	PRESENT	0
275449	263766	19573D	PARTICIPANT	\N	PRESENT	0
275450	263766	14055N	PARTICIPANT	\N	PRESENT	0
275451	263766	04057K	PARTICIPANT	\N	PRESENT	0
275452	263766	17589D	PARTICIPANT	\N	PRESENT	0
275453	263766	19447X	PARTICIPANT	\N	PRESENT	0
275455	263766	19673G	PARTICIPANT	\N	PRESENT	0
275456	263766	11115U	PARTICIPANT	\N	PRESENT	0
275457	263766	14239U	PARTICIPANT	\N	PRESENT	0
275458	263766	01057W	PARTICIPANT	\N	PRESENT	0
275459	263766	04034C	PARTICIPANT	\N	PRESENT	0
275461	263766	11080N	PARTICIPANT	\N	PRESENT	0
275462	263766	11083R	PARTICIPANT	\N	PRESENT	0
275463	263766	14191V	PARTICIPANT	\N	PRESENT	0
275464	263766	19269X	PARTICIPANT	\N	PRESENT	0
275465	263766	19515S	PARTICIPANT	\N	PRESENT	0
275466	263766	19329S	PARTICIPANT	\N	PRESENT	0
275467	263766	14021P	PARTICIPANT	\N	PRESENT	0
275468	263766	11074Q	PARTICIPANT	\N	PRESENT	0
275469	263766	15447F	PARTICIPANT	\N	PRESENT	0
275470	263766	04059M	PARTICIPANT	\N	PRESENT	0
275471	263766	19679N	PARTICIPANT	\N	PRESENT	0
281788	276025	04092N	PARTICIPANT	\N	PRESENT	0
282412	282411	19647E	PARTICIPANT	\N	PRESENT	0
284607	273897	19533U	PARTICIPANT	\N	PRESENT	0
284608	273897	01024M	PARTICIPANT	\N	PRESENT	0
284609	273897	14121F	PARTICIPANT	\N	PRESENT	0
284610	273897	19691J	PARTICIPANT	\N	PRESENT	0
284613	273897	19673G	PARTICIPANT	\N	PRESENT	0
284614	273897	08015R	PARTICIPANT	\N	PRESENT	0
284623	273897	14083S	PARTICIPANT	\N	PRESENT	0
284625	273897	19515S	PARTICIPANT	\N	PRESENT	0
284626	273897	19335Q	PARTICIPANT	\N	PRESENT	0
284628	273897	19413M	PARTICIPANT	\N	PRESENT	0
284629	273897	19701S	PARTICIPANT	\N	PRESENT	0
284630	273897	19747H	PARTICIPANT	\N	PRESENT	0
284631	273897	19717B	PARTICIPANT	\N	PRESENT	0
284632	273897	04057K	PARTICIPANT	\N	PRESENT	0
284633	273897	02002K	PARTICIPANT	\N	PRESENT	0
284634	273897	17779H	PARTICIPANT	\N	PRESENT	0
284635	273897	11056N	PARTICIPANT	\N	PRESENT	0
284636	273897	14093U	PARTICIPANT	\N	PRESENT	0
284637	273897	08010L	PARTICIPANT	\N	PRESENT	0
284638	273897	18083K	PARTICIPANT	\N	PRESENT	0
284639	273897	99004R	PARTICIPANT	\N	PRESENT	0
284640	273897	19349W	PARTICIPANT	\N	PRESENT	0
284641	273897	14275Y	PARTICIPANT	\N	PRESENT	0
284642	273897	19479G	PARTICIPANT	\N	PRESENT	0
284643	273897	80013X	PARTICIPANT	\N	PRESENT	0
284644	273897	14021P	PARTICIPANT	\N	PRESENT	0
284645	273897	14038Y	PARTICIPANT	\N	PRESENT	0
284646	273897	11043H	PARTICIPANT	\N	PRESENT	0
284647	273897	04085P	PARTICIPANT	\N	PRESENT	0
284648	273897	19733B	PARTICIPANT	\N	PRESENT	0
284745	273898	19585H	PARTICIPANT	\N	PRESENT	0
284746	273898	11056N	PARTICIPANT	\N	PRESENT	0
284747	273898	04085P	PARTICIPANT	\N	PRESENT	0
284748	273898	80013X	PARTICIPANT	\N	PRESENT	0
284749	273898	17779H	PARTICIPANT	\N	PRESENT	0
284750	273898	14121F	PARTICIPANT	\N	PRESENT	0
284751	273898	19599P	PARTICIPANT	\N	PRESENT	0
284752	273898	19715Y	PARTICIPANT	\N	PRESENT	0
284753	273898	14021P	PARTICIPANT	\N	PRESENT	0
284754	273898	19301E	PARTICIPANT	\N	PRESENT	0
284755	273898	14261S	PARTICIPANT	\N	PRESENT	0
284756	273898	19543W	PARTICIPANT	\N	PRESENT	0
284757	273898	14257W	PARTICIPANT	\N	PRESENT	0
284759	273898	14179A	PARTICIPANT	\N	PRESENT	0
284760	273898	02002K	PARTICIPANT	\N	PRESENT	0
284761	273898	04057K	PARTICIPANT	\N	PRESENT	0
284762	273898	19717B	PARTICIPANT	\N	PRESENT	0
284763	273898	14195A	PARTICIPANT	\N	PRESENT	0
284764	273898	14111D	PARTICIPANT	\N	PRESENT	0
284765	273898	19583F	PARTICIPANT	\N	PRESENT	0
284766	273898	19479G	PARTICIPANT	\N	PRESENT	0
284767	273898	19691J	PARTICIPANT	\N	PRESENT	0
284768	273898	19749K	PARTICIPANT	\N	PRESENT	0
284769	273898	14083S	PARTICIPANT	\N	PRESENT	0
284770	273898	19671E	PARTICIPANT	\N	PRESENT	0
284771	273898	01024M	PARTICIPANT	\N	PRESENT	0
284772	273898	01025N	PARTICIPANT	\N	PRESENT	0
284773	273898	14089Y	PARTICIPANT	\N	PRESENT	0
284774	273898	19731Y	PARTICIPANT	\N	PRESENT	0
284775	273898	04035D	PARTICIPANT	\N	PRESENT	0
284776	273898	99004R	PARTICIPANT	\N	PRESENT	0
284777	273898	11043H	PARTICIPANT	\N	PRESENT	0
284778	273898	18083K	PARTICIPANT	\N	PRESENT	0
284779	273898	98050T	PARTICIPANT	\N	PRESENT	0
284780	273898	14029X	PARTICIPANT	\N	PRESENT	0
284781	273898	19733B	PARTICIPANT	\N	PRESENT	0
284782	273898	14038Y	PARTICIPANT	\N	PRESENT	0
284783	273898	19467C	PARTICIPANT	\N	PRESENT	0
284784	273898	14173T	PARTICIPANT	\N	PRESENT	0
284785	273898	19447X	PARTICIPANT	\N	PRESENT	0
284786	273898	19515S	PARTICIPANT	\N	PRESENT	0
284787	273898	19747H	PARTICIPANT	\N	PRESENT	0
284788	273898	04086Q	PARTICIPANT	\N	PRESENT	0
284789	273898	14063N	PARTICIPANT	\N	PRESENT	0
284790	273898	08061X	PARTICIPANT	\N	PRESENT	0
284791	273898	14275Y	PARTICIPANT	\N	PRESENT	0
284792	273898	08010L	PARTICIPANT	\N	PRESENT	0
284794	273898	04088S	PARTICIPANT	\N	PRESENT	0
284795	273898	97011G	PARTICIPANT	\N	PRESENT	0
284807	273898	14157T	PARTICIPANT	\N	PRESENT	0
284808	273898	11049P	PARTICIPANT	\N	PRESENT	0
284809	273898	19729F	PARTICIPANT	\N	PRESENT	0
284810	273898	14265W	PARTICIPANT	\N	PRESENT	0
284811	273898	01034P	PARTICIPANT	\N	PRESENT	0
284812	273898	14051J	PARTICIPANT	\N	PRESENT	0
284813	273898	19551W	PARTICIPANT	\N	PRESENT	0
284814	273898	19695N	PARTICIPANT	\N	PRESENT	0
284815	273898	19565D	PARTICIPANT	\N	PRESENT	0
284817	273898	11067R	PARTICIPANT	\N	PRESENT	0
284819	273898	19549D	PARTICIPANT	\N	PRESENT	0
284821	273898	19651A	PARTICIPANT	\N	PRESENT	0
284878	273898	19251M	PARTICIPANT	\N	PRESENT	0
284937	273898	14097Y	PARTICIPANT	\N	PRESENT	0
284938	273898	14197C	PARTICIPANT	\N	PRESENT	0
284939	273898	14205J	PARTICIPANT	\N	PRESENT	0
284940	273898	08056B	PARTICIPANT	\N	PRESENT	0
284955	273898	11026G	PARTICIPANT	\N	PRESENT	0
284961	273898	19725B	PARTICIPANT	\N	PRESENT	0
284977	273898	19713W	PARTICIPANT	\N	PRESENT	0
284979	273898	01028R	PARTICIPANT	\N	PRESENT	0
284985	273898	07029T	PARTICIPANT	\N	PRESENT	0
284990	273898	19489J	PARTICIPANT	\N	PRESENT	0
284992	273898	14069U	PARTICIPANT	\N	PRESENT	0
285594	279263	04040A	PRESIDENT	0	PRESENT	0
285600	279263	01057W	PARTICIPANT	\N	PRESENT	0
285602	279263	14069U	PARTICIPANT	\N	PRESENT	0
285605	279263	19565D	PARTICIPANT	\N	PRESENT	0
285606	279263	08010L	PARTICIPANT	\N	PRESENT	0
285608	279263	14231L	PARTICIPANT	\N	PRESENT	0
285609	279263	14195A	PARTICIPANT	\N	PRESENT	0
285610	279263	14259Y	PARTICIPANT	\N	PRESENT	0
285612	279263	95063L	PARTICIPANT	\N	PRESENT	0
285613	279263	08038Y	PARTICIPANT	\N	PRESENT	0
285614	279263	19735D	PARTICIPANT	\N	PRESENT	0
285615	279263	04045F	PARTICIPANT	\N	PRESENT	0
285616	279263	14281W	PARTICIPANT	\N	PRESENT	0
285617	279263	14063N	PARTICIPANT	\N	PRESENT	0
285619	279263	19525U	PARTICIPANT	\N	PRESENT	0
285620	279263	19253P	PARTICIPANT	\N	PRESENT	0
285622	279263	14327T	PARTICIPANT	\N	PRESENT	0
285623	279263	11049P	PARTICIPANT	\N	PRESENT	0
285624	279263	19687N	PARTICIPANT	\N	PRESENT	0
285907	285906	08043V	PARTICIPANT	\N	PRESENT	0
285929	273985	14299H	PARTICIPANT	\N	PRESENT	0
284743	273898	11070L	PARTICIPANT	\N	PRESENT	0
284744	273898	17589D	PARTICIPANT	\N	PRESENT	0
285936	273985	80013X	PARTICIPANT	\N	PRESENT	0
285937	273985	19709B	PARTICIPANT	\N	PRESENT	0
285938	273985	01048V	PRESIDENT	0	PRESENT	0
285939	273985	19533U	PARTICIPANT	\N	PRESENT	0
285940	273985	14221J	PARTICIPANT	\N	EXCUSE	0
285999	282453	96004D	PARTICIPANT	\N	EXCUSE	0
289276	289275	14147R	PARTICIPANT	\N	PRESENT	0
289278	289277	14147R	PARTICIPANT	\N	PRESENT	0
291524	290492	19713W	PARTICIPANT	\N	PRESENT	0
292396	292395	14147R	PARTICIPANT	\N	PRESENT	0
292398	292395	08018U	PARTICIPANT	\N	PRESENT	0
292400	292395	14069U	PARTICIPANT	\N	PRESENT	0
292401	292395	14041T	PARTICIPANT	\N	PRESENT	0
292402	292395	08044W	PARTICIPANT	\N	PRESENT	0
292450	292449	08058D	PARTICIPANT	\N	PRESENT	0
292451	292449	11049P	PARTICIPANT	\N	PRESENT	0
292452	292449	08035V	PARTICIPANT	\N	PRESENT	0
292453	292449	14097Y	PARTICIPANT	\N	PRESENT	0
292454	292449	08034U	PARTICIPANT	\N	PRESENT	0
292455	292449	19729F	PARTICIPANT	\N	PRESENT	0
292501	292496	08058D	PARTICIPANT	\N	PRESENT	0
292503	292496	11049P	PARTICIPANT	\N	PRESENT	0
292505	292496	08035V	PARTICIPANT	\N	PRESENT	0
292506	292496	14097Y	PARTICIPANT	\N	PRESENT	0
292507	292496	08034U	PARTICIPANT	\N	PRESENT	0
292508	292496	19729F	PARTICIPANT	\N	PRESENT	0
292577	292573	08058D	PARTICIPANT	\N	PRESENT	0
292578	292573	11049P	PARTICIPANT	\N	PRESENT	0
292580	292573	19543W	PARTICIPANT	\N	PRESENT	0
292582	292573	19251M	PARTICIPANT	\N	PRESENT	0
271643	271642	14239U	PARTICIPANT	\N	PRESENT	0
271644	271642	07004J	PARTICIPANT	\N	PRESENT	0
271645	271642	19647E	PARTICIPANT	\N	PRESENT	0
271657	271656	14239U	PARTICIPANT	\N	PRESENT	0
271658	271656	19647E	PARTICIPANT	\N	PRESENT	0
271659	271656	07004J	PARTICIPANT	\N	PRESENT	0
272654	272653	14001X	PARTICIPANT	\N	PRESENT	0
279151	274867	11067R	PARTICIPANT	\N	PRESENT	0
279152	274867	11097X	PARTICIPANT	\N	PRESENT	0
300415	289194	14241N	PARTICIPANT	\N	PRESENT	0
300416	289194	14193X	PARTICIPANT	\N	PRESENT	0
300417	289194	14257W	PARTICIPANT	\N	PRESENT	0
300418	289194	19749K	PARTICIPANT	\N	PRESENT	0
300419	289194	07029T	PARTICIPANT	\N	PRESENT	0
300421	300420	96004D	PRESIDENT	0	PRESENT	0
300422	300420	14089Y	PARTICIPANT	\N	PRESENT	0
300423	300420	14357A	PARTICIPANT	\N	PRESENT	0
300424	300420	14249W	PARTICIPANT	\N	PRESENT	0
300425	300420	04035D	PARTICIPANT	\N	PRESENT	0
300426	300420	11083R	PARTICIPANT	\N	PRESENT	0
300427	300420	14026U	PARTICIPANT	\N	PRESENT	0
300428	300420	95037J	PARTICIPANT	\N	PRESENT	0
300429	300420	04097T	PARTICIPANT	\N	PRESENT	0
300430	300420	04061F	PARTICIPANT	\N	PRESENT	0
300431	300420	11026G	PARTICIPANT	\N	PRESENT	0
300432	300420	14205J	PARTICIPANT	\N	PRESENT	0
300433	300420	04057K	PARTICIPANT	\N	PRESENT	0
300434	300420	19563B	PARTICIPANT	\N	PRESENT	0
300435	300420	14237S	PARTICIPANT	\N	PRESENT	0
300436	300420	14225N	PARTICIPANT	\N	PRESENT	0
300437	300420	14331P	PARTICIPANT	\N	PRESENT	0
300438	300420	98035U	PARTICIPANT	\N	PRESENT	0
300439	300420	10015M	PARTICIPANT	\N	PRESENT	0
300440	300420	14135M	PARTICIPANT	\N	EXCUSE	0
300441	300420	19593H	PARTICIPANT	\N	EXCUSE	0
300442	300420	14073Q	PARTICIPANT	\N	PRESENT	0
300443	300420	14061L	PARTICIPANT	\N	EXCUSE	0
300444	300420	14065Q	PARTICIPANT	\N	EXCUSE	0
300446	300445	14213J	PARTICIPANT	\N	EXCUSE	0
300447	300445	04045F	PARTICIPANT	\N	EXCUSE	0
300449	300448	14213J	PARTICIPANT	\N	EXCUSE	0
300450	300448	04045F	PARTICIPANT	\N	EXCUSE	0
300452	300451	14213J	PARTICIPANT	\N	EXCUSE	0
300453	300451	04045F	PARTICIPANT	\N	EXCUSE	0
300454	300451	14357A	PARTICIPANT	\N	EXCUSE	0
300456	300455	14213J	PARTICIPANT	\N	EXCUSE	0
300457	300455	14357A	PARTICIPANT	\N	EXCUSE	0
300458	300455	04045F	PARTICIPANT	\N	EXCUSE	0
300524	300523	14105F	PARTICIPANT	\N	PRESENT	0
300526	300523	14255U	PARTICIPANT	\N	PRESENT	0
300527	300523	14039A	PARTICIPANT	\N	PRESENT	0
300528	300523	04049K	PRESIDENT	0	PRESENT	0
300530	300523	19671E	PARTICIPANT	\N	PRESENT	0
300531	300523	14265W	PARTICIPANT	\N	PRESENT	0
300532	300523	04088S	PARTICIPANT	\N	PRESENT	0
300534	300523	14051J	PARTICIPANT	\N	PRESENT	0
300536	300523	19575F	PARTICIPANT	\N	EXCUSE	0
300538	300523	14030Q	PARTICIPANT	\N	EXCUSE	0
300539	300523	08068F	PARTICIPANT	\N	EXCUSE	0
300541	300523	14053L	PARTICIPANT	\N	EXCUSE	0
300542	300540	14255U	PARTICIPANT	\N	PRESENT	0
300543	300523	14083S	PARTICIPANT	\N	EXCUSE	0
300544	300540	97011G	PARTICIPANT	\N	PRESENT	0
300545	300540	08018U	PARTICIPANT	\N	PRESENT	0
300546	300523	19545Y	PARTICIPANT	\N	EXCUSE	0
300548	300523	14041T	PARTICIPANT	\N	EXCUSE	0
300549	300540	11026G	PARTICIPANT	\N	PRESENT	0
300550	300540	08034U	PARTICIPANT	\N	PRESENT	0
300551	300523	14187A	PARTICIPANT	\N	EXCUSE	0
300552	300523	14087W	PARTICIPANT	\N	EXCUSE	0
300553	300523	19521Q	PARTICIPANT	\N	EXCUSE	0
300554	300523	14026U	PARTICIPANT	\N	EXCUSE	0
300555	300523	14121F	PARTICIPANT	\N	EXCUSE	0
300556	300523	14061L	PARTICIPANT	\N	EXCUSE	0
300557	300523	11099A	PARTICIPANT	\N	EXCUSE	0
300558	300523	08015R	PARTICIPANT	\N	EXCUSE	0
300559	300523	14253S	PARTICIPANT	\N	EXCUSE	0
300560	300523	19527W	PARTICIPANT	\N	EXCUSE	0
300562	300561	14123H	PARTICIPANT	\N	PRESENT	0
300563	300561	19533U	PARTICIPANT	\N	PRESENT	0
300564	300561	19621T	PARTICIPANT	\N	PRESENT	0
300565	300561	08012N	PARTICIPANT	\N	PRESENT	0
300567	300561	08017T	PARTICIPANT	\N	PRESENT	0
300568	300561	14241N	PARTICIPANT	\N	PRESENT	0
300569	300561	14030Q	PARTICIPANT	\N	PRESENT	0
300647	300645	19593H	PARTICIPANT	\N	PRESENT	0
300661	300660	14133K	PARTICIPANT	\N	PRESENT	0
300662	300660	10006L	PARTICIPANT	\N	PRESENT	0
300663	300660	14147R	PARTICIPANT	\N	PRESENT	0
300664	300660	14281W	PARTICIPANT	\N	PRESENT	0
300665	300660	14265W	PARTICIPANT	\N	PRESENT	0
300666	300660	14217N	PARTICIPANT	\N	PRESENT	0
300667	280904	14030Q	PRESIDENT	0	PRESENT	0
300668	280904	08043V	PARTICIPANT	\N	EXCUSE	0
300669	280904	11031D	PARTICIPANT	\N	EXCUSE	0
300670	280904	19693L	PARTICIPANT	\N	PRESENT	0
300671	280904	19599P	PARTICIPANT	\N	EXCUSE	0
300672	280904	07029T	PARTICIPANT	\N	PRESENT	0
300673	280904	08017T	PARTICIPANT	\N	PRESENT	0
300674	280904	01043Q	PARTICIPANT	\N	EXCUSE	0
300675	280904	19697Q	PARTICIPANT	\N	PRESENT	0
300676	280904	19679N	PARTICIPANT	\N	PRESENT	0
300677	280904	11045K	PARTICIPANT	\N	PRESENT	0
300678	280904	19749K	PARTICIPANT	\N	PRESENT	0
300807	300806	08017T	PARTICIPANT	\N	PRESENT	0
300809	300806	97011G	PARTICIPANT	\N	PRESENT	0
301025	300448	14357A	PARTICIPANT	\N	EXCUSE	0
301026	300448	08052W	PRESIDENT	0	PRESENT	0
301028	300448	17589D	PARTICIPANT	\N	PRESENT	0
301029	300448	19727D	PARTICIPANT	\N	PRESENT	0
301030	300448	19553Y	PARTICIPANT	\N	PRESENT	0
301031	300448	14237S	PARTICIPANT	\N	PRESENT	0
301032	300448	19735D	PARTICIPANT	\N	PRESENT	0
301033	300448	95062K	PARTICIPANT	\N	PRESENT	0
301250	298556	08024S	PARTICIPANT	\N	PRESENT	0
300413	289194	11053K	PARTICIPANT	\N	PRESENT	0
301252	298556	19551W	PARTICIPANT	\N	PRESENT	0
301253	298556	19737F	PARTICIPANT	\N	PRESENT	0
301254	297472	08024S	PARTICIPANT	\N	PRESENT	0
301255	297472	19551W	PARTICIPANT	\N	PRESENT	0
301256	297472	19737F	PARTICIPANT	\N	PRESENT	0
301315	301310	08011M	PARTICIPANT	\N	PRESENT	0
301326	301323	14331P	PARTICIPANT	\N	PRESENT	0
301360	289200	19441R	PARTICIPANT	\N	PRESENT	0
301361	289200	19749K	PARTICIPANT	\N	PRESENT	0
301382	301380	19663E	PARTICIPANT	\N	PRESENT	0
301561	289203	04059M	PARTICIPANT	\N	PRESENT	0
301562	289203	14187A	PARTICIPANT	\N	PRESENT	0
301563	289203	19591F	PARTICIPANT	\N	PRESENT	0
301564	289203	11077T	PARTICIPANT	\N	PRESENT	0
301565	289203	12016W	PARTICIPANT	\N	PRESENT	0
301566	289203	04057K	PARTICIPANT	\N	PRESENT	0
301567	289203	19565D	PARTICIPANT	\N	PRESENT	0
301568	289203	19695N	PARTICIPANT	\N	PRESENT	0
301569	289203	19253P	PARTICIPANT	\N	PRESENT	0
301570	289203	14357A	PARTICIPANT	\N	PRESENT	0
301571	289203	14215L	PARTICIPANT	\N	PRESENT	0
301572	289203	19671E	PARTICIPANT	\N	PRESENT	0
301573	289203	19631V	PARTICIPANT	\N	PRESENT	0
301574	289203	14026U	PARTICIPANT	\N	PRESENT	0
301575	289203	14265W	PARTICIPANT	\N	PRESENT	0
301576	289203	14041T	PARTICIPANT	\N	PRESENT	0
301577	289203	08019V	PARTICIPANT	\N	PRESENT	0
301578	289203	14083S	PARTICIPANT	\N	PRESENT	0
301579	289203	19711U	PARTICIPANT	\N	PRESENT	0
301580	289203	19643A	PARTICIPANT	\N	PRESENT	0
301581	289203	04033B	PARTICIPANT	\N	PRESENT	0
301582	289203	08034U	PARTICIPANT	\N	PRESENT	0
301583	289203	04086Q	PARTICIPANT	\N	PRESENT	0
301584	289203	19657G	PARTICIPANT	\N	PRESENT	0
301585	289203	19369B	PARTICIPANT	\N	PRESENT	0
301601	289203	11090Q	PARTICIPANT	\N	PRESENT	0
301587	289203	08010L	PARTICIPANT	\N	PRESENT	0
301588	289203	08068F	PARTICIPANT	\N	PRESENT	0
301589	289203	19443T	PARTICIPANT	\N	PRESENT	0
301590	289203	11056N	PARTICIPANT	\N	PRESENT	0
301591	289203	14229S	PARTICIPANT	\N	PRESENT	0
301592	289203	14038Y	PARTICIPANT	\N	PRESENT	0
301593	289203	04008A	PARTICIPANT	\N	PRESENT	0
301594	289203	95063L	PARTICIPANT	\N	PRESENT	0
301595	289203	08038Y	PARTICIPANT	\N	PRESENT	0
301596	289203	19697Q	PARTICIPANT	\N	PRESENT	0
301597	289203	19749K	PARTICIPANT	\N	PRESENT	0
301598	289203	19681G	PARTICIPANT	\N	PRESENT	0
301599	289203	19651A	PARTICIPANT	\N	PRESENT	0
301600	289203	11065P	PARTICIPANT	\N	PRESENT	0
301602	289203	04043D	PARTICIPANT	\N	PRESENT	0
281724	279389	14089Y	PARTICIPANT	\N	PRESENT	0
281727	281725	19725B	PARTICIPANT	\N	PRESENT	0
281728	281725	10015M	PARTICIPANT	\N	PRESENT	0
281729	281725	19531S	PARTICIPANT	\N	PRESENT	0
281730	281725	19569H	PARTICIPANT	\N	PRESENT	0
281731	281725	19503N	PARTICIPANT	\N	PRESENT	0
282354	273702	14195A	PARTICIPANT	\N	PRESENT	0
282355	273704	11067R	PARTICIPANT	\N	PRESENT	0
291289	273922	19593H	PARTICIPANT	\N	PRESENT	0
291290	273922	07004J	PARTICIPANT	\N	PRESENT	0
291291	273922	19467C	PARTICIPANT	\N	PRESENT	0
291292	273922	14133K	PARTICIPANT	\N	PRESENT	0
291293	273922	14105F	PARTICIPANT	\N	PRESENT	0
291294	273922	19443T	PARTICIPANT	\N	PRESENT	0
291295	273922	19531S	PARTICIPANT	\N	PRESENT	0
291296	273922	19703U	PARTICIPANT	\N	PRESENT	0
291297	273922	19575F	PARTICIPANT	\N	PRESENT	0
291298	273922	11083R	PARTICIPANT	\N	PRESENT	0
291299	273922	14079W	PARTICIPANT	\N	PRESENT	0
291300	273922	10015M	PARTICIPANT	\N	PRESENT	0
291301	273922	96004D	PARTICIPANT	\N	PRESENT	0
291302	273922	98018T	PARTICIPANT	\N	PRESENT	0
291303	273922	11026G	PARTICIPANT	\N	PRESENT	0
291304	273922	19758L	PARTICIPANT	\N	PRESENT	0
291305	273922	11012A	PARTICIPANT	\N	PRESENT	0
291306	273922	14089Y	PARTICIPANT	\N	PRESENT	0
291307	273922	14225N	PARTICIPANT	\N	PRESENT	0
291308	273922	04070G	PARTICIPANT	\N	PRESENT	0
291309	273922	04045F	PARTICIPANT	\N	PRESENT	0
291310	273922	08020N	PARTICIPANT	\N	PRESENT	0
291311	273922	04057K	PARTICIPANT	\N	PRESENT	0
291312	273922	14073Q	PARTICIPANT	\N	PRESENT	0
291313	273922	14119M	PARTICIPANT	\N	PRESENT	0
291314	273922	95030B	PARTICIPANT	\N	PRESENT	0
291315	273922	17589D	PARTICIPANT	\N	PRESENT	0
291316	273922	14235Q	PARTICIPANT	\N	PRESENT	0
291317	273922	19387D	PARTICIPANT	\N	PRESENT	0
291318	273922	19479G	PARTICIPANT	\N	PRESENT	0
291319	273922	14237S	PARTICIPANT	\N	PRESENT	0
291320	273922	14026U	PARTICIPANT	\N	PRESENT	0
291321	273922	04061F	PARTICIPANT	\N	PRESENT	0
291322	273922	14029X	PARTICIPANT	\N	PRESENT	0
291323	273922	14115H	PARTICIPANT	\N	PRESENT	0
291324	273922	07029T	PARTICIPANT	\N	PRESENT	0
291325	273922	14331P	PARTICIPANT	\N	PRESENT	0
291326	273922	11097X	PARTICIPANT	\N	PRESENT	0
291327	273922	08011M	PARTICIPANT	\N	PRESENT	0
291328	273922	14033T	PARTICIPANT	\N	PRESENT	0
291329	273922	19507S	PARTICIPANT	\N	PRESENT	0
291287	273922	14034U	PARTICIPANT	\N	PRESENT	0
291288	273922	19715Y	PARTICIPANT	\N	PRESENT	0
291330	273922	18083K	PARTICIPANT	\N	PRESENT	0
291332	291331	14239U	PARTICIPANT	\N	PRESENT	0
291333	291331	19549D	PARTICIPANT	\N	PRESENT	0
291334	291331	14215L	PARTICIPANT	\N	PRESENT	0
291335	291331	14087W	PARTICIPANT	\N	EXCUSE	0
291336	291331	14031R	PARTICIPANT	\N	PRESENT	0
291337	291331	14119M	PARTICIPANT	\N	PRESENT	0
291338	291331	04044E	PRESIDENT	0	PRESENT	0
291738	288052	08047A	PARTICIPANT	\N	EXCUSE	0
291739	288052	14028W	PARTICIPANT	\N	EXCUSE	0
291740	288052	08049C	PARTICIPANT	\N	EXCUSE	0
291741	288052	11041F	PARTICIPANT	\N	EXCUSE	0
292406	292405	14087W	PARTICIPANT	\N	PRESENT	0
292407	292405	14121F	PARTICIPANT	\N	PRESENT	0
292408	292405	04049K	PRESIDENT	0	PRESENT	0
292409	292405	16685X	PARTICIPANT	\N	PRESENT	0
292410	292405	14265W	PARTICIPANT	\N	PRESENT	0
292411	292405	04088S	PARTICIPANT	\N	PRESENT	0
292412	292405	14051J	PARTICIPANT	\N	PRESENT	0
292413	292405	89017R	PARTICIPANT	\N	EXCUSE	0
292414	292405	19575F	PARTICIPANT	\N	EXCUSE	0
292416	292405	14030Q	PARTICIPANT	\N	EXCUSE	0
292417	292405	08060W	PARTICIPANT	\N	EXCUSE	0
292418	292405	14105F	PARTICIPANT	\N	EXCUSE	0
292419	292405	08068F	PARTICIPANT	\N	EXCUSE	0
292420	292405	14053L	PARTICIPANT	\N	EXCUSE	0
292421	292405	14083S	PARTICIPANT	\N	EXCUSE	0
292422	292405	11031D	PARTICIPANT	\N	EXCUSE	0
292423	292405	14079W	PARTICIPANT	\N	EXCUSE	0
292424	292405	14041T	PARTICIPANT	\N	EXCUSE	0
292425	292405	14187A	PARTICIPANT	\N	EXCUSE	0
292426	292405	14034U	PARTICIPANT	\N	EXCUSE	0
292427	292405	14026U	PARTICIPANT	\N	EXCUSE	0
292428	292405	14255U	PARTICIPANT	\N	PRESENT	0
292429	292405	11099A	PARTICIPANT	\N	EXCUSE	0
292430	292405	08015R	PARTICIPANT	\N	EXCUSE	0
292431	292405	14253S	PARTICIPANT	\N	EXCUSE	0
292432	292405	08047A	PARTICIPANT	\N	EXCUSE	0
292434	292405	04034C	PARTICIPANT	\N	EXCUSE	0
292436	292405	14061L	PARTICIPANT	\N	EXCUSE	0
292468	292467	14087W	PARTICIPANT	\N	PRESENT	0
292469	292467	14121F	PARTICIPANT	\N	PRESENT	0
292470	292467	04049K	PRESIDENT	0	PRESENT	0
292471	292467	16685X	PARTICIPANT	\N	PRESENT	0
292472	292467	14265W	PARTICIPANT	\N	PRESENT	0
292473	292467	04088S	PARTICIPANT	\N	PRESENT	0
292474	292467	14051J	PARTICIPANT	\N	PRESENT	0
292475	292467	14255U	PARTICIPANT	\N	PRESENT	0
292476	292467	14079W	PARTICIPANT	\N	PRESENT	0
292477	292467	89017R	PARTICIPANT	\N	EXCUSE	0
292478	292467	19575F	PARTICIPANT	\N	EXCUSE	0
292479	292467	14030Q	PARTICIPANT	\N	EXCUSE	0
292480	292467	08060W	PARTICIPANT	\N	EXCUSE	0
292481	292467	14105F	PARTICIPANT	\N	EXCUSE	0
292482	292467	08068F	PARTICIPANT	\N	EXCUSE	0
292483	292467	14053L	PARTICIPANT	\N	EXCUSE	0
292484	292467	14083S	PARTICIPANT	\N	EXCUSE	0
292485	292467	11031D	PARTICIPANT	\N	EXCUSE	0
292486	292467	14041T	PARTICIPANT	\N	EXCUSE	0
292487	292467	14187A	PARTICIPANT	\N	EXCUSE	0
292488	292467	14034U	PARTICIPANT	\N	EXCUSE	0
292489	292467	14026U	PARTICIPANT	\N	EXCUSE	0
292490	292467	14061L	PARTICIPANT	\N	EXCUSE	0
292491	292467	11099A	PARTICIPANT	\N	EXCUSE	0
292492	292467	08015R	PARTICIPANT	\N	EXCUSE	0
292493	292467	14253S	PARTICIPANT	\N	EXCUSE	0
292494	292467	08047A	PARTICIPANT	\N	EXCUSE	0
292495	292467	04034C	PARTICIPANT	\N	EXCUSE	0
292497	292467	19563B	PARTICIPANT	\N	PRESENT	0
292498	292467	96004D	PARTICIPANT	\N	PRESENT	0
292499	292467	14133K	PARTICIPANT	\N	PRESENT	0
292500	292467	14097Y	PARTICIPANT	\N	PRESENT	0
292502	292467	19725B	PARTICIPANT	\N	PRESENT	0
294876	289109	04086Q	PARTICIPANT	\N	PRESENT	0
294882	289109	19649G	PARTICIPANT	\N	PRESENT	0
294878	289109	05008E	PARTICIPANT	\N	PRESENT	0
294879	289109	19319Q	PARTICIPANT	\N	PRESENT	0
294880	289109	19731Y	PARTICIPANT	\N	PRESENT	0
294881	289109	14147R	PARTICIPANT	\N	PRESENT	0
294883	289109	11067R	PARTICIPANT	\N	PRESENT	0
294884	289109	11066Q	PARTICIPANT	\N	PRESENT	0
294885	289109	19599P	PARTICIPANT	\N	PRESENT	0
294886	289109	08043V	PARTICIPANT	\N	PRESENT	0
294887	289109	19629C	PARTICIPANT	\N	PRESENT	0
294888	289109	08031R	PARTICIPANT	\N	PRESENT	0
294889	289109	11012A	PARTICIPANT	\N	PRESENT	0
294890	289109	19515S	PARTICIPANT	\N	PRESENT	0
294891	289109	14105F	PARTICIPANT	\N	PRESENT	0
294892	289109	19693L	PARTICIPANT	\N	PRESENT	0
294893	289109	19447X	PARTICIPANT	\N	PRESENT	0
294894	289109	08017T	PARTICIPANT	\N	PRESENT	0
294895	289109	19725B	PARTICIPANT	\N	PRESENT	0
294896	289109	11031D	PARTICIPANT	\N	PRESENT	0
294897	289109	11045K	PARTICIPANT	\N	PRESENT	0
294898	289109	14021P	PARTICIPANT	\N	PRESENT	0
294899	289109	19543W	PARTICIPANT	\N	PRESENT	0
294900	289109	14089Y	PARTICIPANT	\N	PRESENT	0
294901	289109	19749K	PARTICIPANT	\N	PRESENT	0
294902	289109	14030Q	PARTICIPANT	\N	PRESENT	0
294903	289109	19367Y	PARTICIPANT	\N	PRESENT	0
294904	289109	07034Q	PARTICIPANT	\N	PRESENT	0
295686	293468	19575F	PARTICIPANT	\N	EXCUSE	0
295687	293468	95062K	PARTICIPANT	\N	EXCUSE	0
295688	293468	08052W	PARTICIPANT	\N	EXCUSE	0
295689	293468	11031D	PRESIDENT	0	PRESENT	0
295692	295675	96004D	PRESIDENT	0	PRESENT	0
295694	295675	14089Y	PARTICIPANT	\N	PRESENT	0
295695	295675	14249W	PARTICIPANT	\N	PRESENT	0
295696	295675	11083R	PARTICIPANT	\N	PRESENT	0
295697	295675	19725B	PARTICIPANT	\N	PRESENT	0
295698	295675	04097T	PARTICIPANT	\N	PRESENT	0
295699	295675	14097Y	PARTICIPANT	\N	PRESENT	0
295700	295675	14073Q	PARTICIPANT	\N	PRESENT	0
273671	273666	19631V	PARTICIPANT	\N	EXCUSE	0
273672	273666	14259Y	PARTICIPANT	\N	EXCUSE	0
273673	273667	14259Y	PARTICIPANT	\N	EXCUSE	0
273674	273668	14259Y	PARTICIPANT	\N	EXCUSE	0
273675	273668	14135M	PARTICIPANT	\N	EXCUSE	0
273676	273666	19295A	PARTICIPANT	\N	EXCUSE	0
273677	273667	19295A	PARTICIPANT	\N	EXCUSE	0
273678	273668	19295A	PARTICIPANT	\N	EXCUSE	0
273679	273668	19717B	PARTICIPANT	\N	EXCUSE	0
273680	273667	19717B	PARTICIPANT	\N	EXCUSE	0
273681	273666	19717B	PARTICIPANT	\N	EXCUSE	0
273713	273666	14059S	PARTICIPANT	\N	EXCUSE	0
273714	273667	14059S	PARTICIPANT	\N	EXCUSE	0
273715	273668	14059S	PARTICIPANT	\N	EXCUSE	0
275211	275210	14079W	PARTICIPANT	\N	PRESENT	0
278788	263774	08009T	PARTICIPANT	\N	PRESENT	0
275472	263766	10015M	PARTICIPANT	\N	PRESENT	0
275473	263766	14229S	PARTICIPANT	\N	PRESENT	0
275474	263766	08052W	PARTICIPANT	\N	PRESENT	0
275475	263766	11043H	PARTICIPANT	\N	PRESENT	0
275476	263766	01028R	PARTICIPANT	\N	PRESENT	0
275477	263766	08010L	PARTICIPANT	\N	PRESENT	0
275478	263766	14151M	PARTICIPANT	\N	PRESENT	0
275479	263766	14225N	PARTICIPANT	\N	PRESENT	0
275480	263766	04042C	PARTICIPANT	\N	PRESENT	0
275481	263766	01062T	PARTICIPANT	\N	PRESENT	0
275482	263766	14028W	PARTICIPANT	\N	PRESENT	0
275483	263766	19649G	PARTICIPANT	\N	PRESENT	0
275484	263766	19591F	PARTICIPANT	\N	PRESENT	0
275485	263766	19707Y	PARTICIPANT	\N	PRESENT	0
275486	263766	14281W	PARTICIPANT	\N	PRESENT	0
275487	263766	99004R	PARTICIPANT	\N	PRESENT	0
275488	263766	01058X	PARTICIPANT	\N	PRESENT	0
275489	263766	14157T	PARTICIPANT	\N	PRESENT	0
275490	263766	08053X	PARTICIPANT	\N	PRESENT	0
275491	263766	08011M	PARTICIPANT	\N	PRESENT	0
275492	263766	11110B	PARTICIPANT	\N	PRESENT	0
275493	263766	19711U	PARTICIPANT	\N	PRESENT	0
275494	263766	14085U	PARTICIPANT	\N	PRESENT	0
275495	263766	19489J	PARTICIPANT	\N	PRESENT	0
275496	263766	11054L	PARTICIPANT	\N	PRESENT	0
275497	263766	14253S	PARTICIPANT	\N	PRESENT	0
275498	263766	19575F	PARTICIPANT	\N	PRESENT	0
275499	263766	14199E	PARTICIPANT	\N	PRESENT	0
275500	263766	14169X	PARTICIPANT	\N	PRESENT	0
275501	263766	11049P	PARTICIPANT	\N	PRESENT	0
275502	263766	14026U	PARTICIPANT	\N	PRESENT	0
275503	263766	14115H	PARTICIPANT	\N	PRESENT	0
275504	263766	04049K	PARTICIPANT	\N	PRESENT	0
275505	263766	14147R	PARTICIPANT	\N	PRESENT	0
275506	263766	14105F	PARTICIPANT	\N	PRESENT	0
275507	263766	01034P	PARTICIPANT	\N	PRESENT	0
275508	263766	19369B	PARTICIPANT	\N	PRESENT	0
275509	263766	08019V	PARTICIPANT	\N	PRESENT	0
275510	263766	19691J	PARTICIPANT	\N	PRESENT	0
275511	263766	19399H	PARTICIPANT	\N	PRESENT	0
275512	263766	11053K	PARTICIPANT	\N	PRESENT	0
275513	263766	19693L	PARTICIPANT	\N	PRESENT	0
275514	263766	14205J	PARTICIPANT	\N	PRESENT	0
275515	263766	04086Q	PARTICIPANT	\N	PRESENT	0
275516	263766	19737F	PARTICIPANT	\N	PRESENT	0
275517	263766	19729F	PARTICIPANT	\N	PRESENT	0
275518	263766	19699S	PARTICIPANT	\N	PRESENT	0
275519	263766	14265W	PARTICIPANT	\N	PRESENT	0
275520	263766	14213J	PARTICIPANT	\N	PRESENT	0
275521	263766	16685X	PARTICIPANT	\N	PRESENT	0
275522	263766	19705W	PARTICIPANT	\N	PRESENT	0
275523	263766	08056B	PARTICIPANT	\N	PRESENT	0
275524	263766	08015R	PARTICIPANT	\N	PRESENT	0
275525	263766	14251Q	PARTICIPANT	\N	PRESENT	0
275526	263766	08062Y	PARTICIPANT	\N	PRESENT	0
275527	263766	11045K	PARTICIPANT	\N	PRESENT	0
275528	263766	19657G	PARTICIPANT	\N	PRESENT	0
275529	263766	14219Q	PARTICIPANT	\N	PRESENT	0
275530	263766	19479G	PARTICIPANT	\N	PRESENT	0
275531	263766	07029T	PARTICIPANT	\N	PRESENT	0
275532	263766	19347U	PARTICIPANT	\N	PRESENT	0
275533	263766	11070L	PARTICIPANT	\N	PRESENT	0
275534	263766	14275Y	PARTICIPANT	\N	PRESENT	0
275535	263766	98050T	PARTICIPANT	\N	PRESENT	0
275536	263766	19689Q	PARTICIPANT	\N	PRESENT	0
275537	263766	14207L	PARTICIPANT	\N	PRESENT	0
275538	263766	19643A	PARTICIPANT	\N	PRESENT	0
275539	263766	04071H	PARTICIPANT	\N	PRESENT	0
275540	263766	14329V	PARTICIPANT	\N	PRESENT	0
275541	263766	14030Q	PARTICIPANT	\N	PRESENT	0
275542	263766	14327T	PARTICIPANT	\N	PRESENT	0
275543	263766	14357A	PARTICIPANT	\N	PRESENT	0
275544	263766	01025N	PARTICIPANT	\N	PRESENT	0
275545	263766	19675J	PARTICIPANT	\N	PRESENT	0
275546	263766	01024M	PARTICIPANT	\N	PRESENT	0
275547	263766	04040A	PARTICIPANT	\N	PRESENT	0
275548	263766	04070G	PARTICIPANT	\N	PRESENT	0
275549	263766	05008E	PARTICIPANT	\N	PRESENT	0
275550	263766	19663E	PARTICIPANT	\N	PRESENT	0
275551	263766	07004J	PARTICIPANT	\N	PRESENT	0
275552	263766	14255U	PARTICIPANT	\N	PRESENT	0
275553	263766	19383Y	PARTICIPANT	\N	PRESENT	0
275554	263766	04018C	PARTICIPANT	\N	PRESENT	0
275555	263766	19521Q	PARTICIPANT	\N	PRESENT	0
275557	263766	19551W	PARTICIPANT	\N	PRESENT	0
275558	263766	19701S	PARTICIPANT	\N	PRESENT	0
275559	263766	14089Y	PARTICIPANT	\N	PRESENT	0
275560	263766	97011G	PARTICIPANT	\N	PRESENT	0
275561	263766	19749K	PARTICIPANT	\N	PRESENT	0
275562	263766	11103C	PARTICIPANT	\N	PRESENT	0
275563	263766	14103D	PARTICIPANT	\N	PRESENT	0
275564	263766	07033P	PARTICIPANT	\N	PRESENT	0
275565	263766	14217N	PARTICIPANT	\N	PRESENT	0
275566	263766	14331P	PARTICIPANT	\N	PRESENT	0
275567	263766	04061F	PARTICIPANT	\N	PRESENT	0
275568	263766	19335Q	PARTICIPANT	\N	PRESENT	0
275569	263766	14079W	PARTICIPANT	\N	PRESENT	0
275570	263766	19621T	PARTICIPANT	\N	PRESENT	0
275571	263766	19367Y	PARTICIPANT	\N	PRESENT	0
275572	263766	14193X	PARTICIPANT	\N	PRESENT	0
275574	263766	19735D	PARTICIPANT	\N	PRESENT	0
275575	263766	17583W	PARTICIPANT	\N	PRESENT	0
275577	263766	08021P	PARTICIPANT	\N	PRESENT	0
275578	263766	14187A	PARTICIPANT	\N	PRESENT	0
275580	263766	04092N	PARTICIPANT	\N	PRESENT	0
275582	263766	14071N	PARTICIPANT	\N	PRESENT	0
275583	263766	14087W	PARTICIPANT	\N	PRESENT	0
275585	263766	11097X	PARTICIPANT	\N	PRESENT	0
275586	263766	19421M	PARTICIPANT	\N	PRESENT	0
275587	263766	95030B	PARTICIPANT	\N	PRESENT	0
275588	263766	04047H	PARTICIPANT	\N	PRESENT	0
275589	263766	14135M	PARTICIPANT	\N	PRESENT	0
275590	263766	98024R	PARTICIPANT	\N	PRESENT	0
275591	263766	04035D	PARTICIPANT	\N	PRESENT	0
275600	263766	19733B	PARTICIPANT	\N	PRESENT	0
275593	263766	95067Q	PARTICIPANT	\N	PRESENT	0
275594	263766	14069U	PARTICIPANT	\N	PRESENT	0
275595	263766	04043D	PARTICIPANT	\N	PRESENT	0
275598	263766	08034U	PARTICIPANT	\N	PRESENT	0
275597	263766	05012A	PARTICIPANT	\N	PRESENT	0
275599	263766	11099A	PARTICIPANT	\N	PRESENT	0
275601	263766	11027H	PARTICIPANT	\N	PRESENT	0
275602	263766	08038Y	PARTICIPANT	\N	PRESENT	0
275612	263766	14109K	PARTICIPANT	\N	PRESENT	0
278762	263774	14034U	PARTICIPANT	\N	PRESENT	0
278789	263774	98023Q	PARTICIPANT	\N	PRESENT	0
278790	263774	19593H	PARTICIPANT	\N	PRESENT	0
278791	263774	19695N	PARTICIPANT	\N	PRESENT	0
278792	263774	04085P	PARTICIPANT	\N	PRESENT	0
278793	263774	19347U	PARTICIPANT	\N	PRESENT	0
278794	263774	04034C	PARTICIPANT	\N	PRESENT	0
278795	263774	08060W	PARTICIPANT	\N	PRESENT	0
278796	263774	14051J	PARTICIPANT	\N	PRESENT	0
278797	263774	19333N	PARTICIPANT	\N	PRESENT	0
278798	263774	19681G	PARTICIPANT	\N	PRESENT	0
278799	263774	19387D	PARTICIPANT	\N	PRESENT	0
278800	263774	08055A	PARTICIPANT	\N	PRESENT	0
278801	263774	08068F	PARTICIPANT	\N	PRESENT	0
278802	263774	19551W	PARTICIPANT	\N	PRESENT	0
278803	263774	19713W	PARTICIPANT	\N	PRESENT	0
278804	263774	19319Q	PARTICIPANT	\N	PRESENT	0
278805	263774	19737F	PARTICIPANT	\N	PRESENT	0
278806	263774	14219Q	PARTICIPANT	\N	PRESENT	0
278807	263774	04018C	PARTICIPANT	\N	PRESENT	0
278808	263774	98050T	PARTICIPANT	\N	PRESENT	0
278809	263774	97011G	PARTICIPANT	\N	PRESENT	0
278810	263774	19711U	PARTICIPANT	\N	PRESENT	0
278811	263774	11077T	PARTICIPANT	\N	PRESENT	0
278812	263774	14169X	PARTICIPANT	\N	PRESENT	0
278813	263774	98005N	PARTICIPANT	\N	PRESENT	0
278814	263774	04088S	PARTICIPANT	\N	PRESENT	0
278815	263774	14147R	PARTICIPANT	\N	PRESENT	0
278816	263774	07029T	PARTICIPANT	\N	PRESENT	0
282455	282454	04038G	PARTICIPANT	\N	PRESENT	0
282456	282454	11070L	PRESIDENT	0	PRESENT	0
282457	282454	19711U	PARTICIPANT	\N	PRESENT	0
282458	282454	19689Q	PARTICIPANT	\N	PRESENT	0
282459	282454	04097T	PARTICIPANT	\N	PRESENT	0
282460	282454	95062K	PARTICIPANT	\N	EXCUSE	0
282461	282454	19531S	PARTICIPANT	\N	EXCUSE	0
282462	282454	14357A	PARTICIPANT	\N	EXCUSE	0
286507	286267	14355X	PARTICIPANT	\N	EXCUSE	0
286509	286267	19679N	PARTICIPANT	\N	EXCUSE	0
286511	286510	14041T	PARTICIPANT	\N	PRESENT	0
286512	286510	19295A	PARTICIPANT	\N	PRESENT	0
286513	286510	14087W	PARTICIPANT	\N	PRESENT	0
286514	286510	04044E	PARTICIPANT	\N	PRESENT	0
286557	286539	19637C	PARTICIPANT	\N	PRESENT	0
286543	286539	19733B	PARTICIPANT	\N	PRESENT	0
286544	286539	19681G	PARTICIPANT	\N	PRESENT	0
286545	286539	98023Q	PARTICIPANT	\N	PRESENT	0
286546	286539	19525U	PARTICIPANT	\N	PRESENT	0
286547	286539	19551W	PARTICIPANT	\N	PRESENT	0
286548	286539	04061F	PARTICIPANT	\N	PRESENT	0
292584	292573	19729F	PARTICIPANT	\N	PRESENT	0
292586	292573	19443T	PARTICIPANT	\N	PRESENT	0
286551	286539	08009T	PRESIDENT	0	PRESENT	0
292587	292573	19703U	PARTICIPANT	\N	PRESENT	0
286554	286539	19503N	PARTICIPANT	\N	PRESENT	0
286555	286539	14157T	PARTICIPANT	\N	PRESENT	0
292739	292510	19735D	PARTICIPANT	\N	EXCUSE	0
292740	292510	04040A	PRESIDENT	0	PRESENT	0
292753	292510	14071N	PARTICIPANT	\N	EXCUSE	0
293235	293109	14275Y	PARTICIPANT	\N	EXCUSE	0
293233	293109	96004D	PARTICIPANT	\N	EXCUSE	0
293234	293109	19295A	PARTICIPANT	\N	EXCUSE	0
293666	292898	19629C	PARTICIPANT	\N	EXCUSE	0
293727	289104	14069U	PARTICIPANT	\N	PRESENT	0
293728	289104	19711U	PARTICIPANT	\N	PRESENT	0
293729	289104	17583W	PARTICIPANT	\N	PRESENT	0
293730	289104	14267Y	PARTICIPANT	\N	PRESENT	0
293731	289104	19479G	PARTICIPANT	\N	PRESENT	0
293732	289104	19737F	PARTICIPANT	\N	PRESENT	0
293733	289104	19583F	PARTICIPANT	\N	PRESENT	0
293734	289104	19525U	PARTICIPANT	\N	PRESENT	0
293735	289104	07004J	PARTICIPANT	\N	PRESENT	0
293736	289104	19758L	PARTICIPANT	\N	PRESENT	0
293737	289104	11074Q	PARTICIPANT	\N	PRESENT	0
293738	289104	11048N	PARTICIPANT	\N	PRESENT	0
293739	289104	19731Y	PARTICIPANT	\N	PRESENT	0
293740	289104	19507S	PARTICIPANT	\N	PRESENT	0
293741	289104	19415P	PARTICIPANT	\N	PRESENT	0
293742	289104	14119M	PARTICIPANT	\N	PRESENT	0
293743	289104	04071H	PARTICIPANT	\N	PRESENT	0
293744	289104	08024S	PARTICIPANT	\N	PRESENT	0
293745	289104	98050T	PARTICIPANT	\N	PRESENT	0
293746	289104	14211G	PARTICIPANT	\N	PRESENT	0
293747	289104	19575F	PARTICIPANT	\N	PRESENT	0
293748	289104	19543W	PARTICIPANT	\N	PRESENT	0
293749	289104	14179A	PARTICIPANT	\N	PRESENT	0
293750	289104	19599P	PARTICIPANT	\N	PRESENT	0
293751	289104	19531S	PARTICIPANT	\N	PRESENT	0
293752	289104	19503N	PARTICIPANT	\N	PRESENT	0
293753	289104	19581D	PARTICIPANT	\N	PRESENT	0
293754	289104	19739H	PARTICIPANT	\N	PRESENT	0
293755	289104	14219Q	PARTICIPANT	\N	PRESENT	0
293756	289104	01024M	PARTICIPANT	\N	PRESENT	0
293757	289104	11103C	PARTICIPANT	\N	PRESENT	0
293758	289104	14147R	PARTICIPANT	\N	PRESENT	0
293759	289104	19675J	PARTICIPANT	\N	PRESENT	0
293760	289104	07029T	PARTICIPANT	\N	PRESENT	0
293761	289104	19667J	PARTICIPANT	\N	PRESENT	0
293762	289104	19701S	PARTICIPANT	\N	PRESENT	0
293763	289104	14195A	PARTICIPANT	\N	PRESENT	0
293764	289104	10006L	PARTICIPANT	\N	PRESENT	0
293765	289104	19413M	PARTICIPANT	\N	PRESENT	0
293773	292898	08069G	PARTICIPANT	\N	EXCUSE	0
294011	294010	11097X	PARTICIPANT	\N	PRESENT	0
294138	292898	08045X	PARTICIPANT	\N	PRESENT	0
295011	295010	11109J	PARTICIPANT	\N	EXCUSE	0
295012	295010	14079W	PARTICIPANT	\N	EXCUSE	0
295013	295010	14327T	PARTICIPANT	\N	EXCUSE	0
295014	295010	08045X	PARTICIPANT	\N	PRESENT	0
295015	295010	19347U	PARTICIPANT	\N	PRESENT	0
295016	295010	14213J	PRESIDENT	0	PRESENT	0
295017	295010	11099A	PARTICIPANT	\N	PRESENT	0
295018	295010	04049K	PARTICIPANT	\N	EXCUSE	0
295019	295010	19441R	PARTICIPANT	\N	PRESENT	0
295020	295010	19369B	PARTICIPANT	\N	PRESENT	0
295021	295010	14109K	PARTICIPANT	\N	PRESENT	0
295022	295010	14169X	PARTICIPANT	\N	PRESENT	0
295023	295010	19503N	PARTICIPANT	\N	PRESENT	0
295024	295010	04043D	PARTICIPANT	\N	PRESENT	0
295025	295010	04045F	PARTICIPANT	\N	EXCUSE	0
295029	295028	14195A	PARTICIPANT	\N	PRESENT	0
295030	295028	11109J	PARTICIPANT	\N	EXCUSE	0
295031	295028	14079W	PARTICIPANT	\N	EXCUSE	0
295032	295028	14327T	PARTICIPANT	\N	EXCUSE	0
295033	295028	08045X	PARTICIPANT	\N	PRESENT	0
295034	295028	19347U	PARTICIPANT	\N	PRESENT	0
295035	295028	14213J	PRESIDENT	0	PRESENT	0
295036	295028	19683J	PARTICIPANT	\N	PRESENT	0
295037	295028	11099A	PARTICIPANT	\N	PRESENT	0
295038	295028	04049K	PARTICIPANT	\N	EXCUSE	0
295039	295028	19441R	PARTICIPANT	\N	PRESENT	0
295777	289110	14089Y	PARTICIPANT	\N	PRESENT	0
296028	296027	19741B	PARTICIPANT	\N	PRESENT	0
295042	295028	04045F	PARTICIPANT	\N	EXCUSE	0
295043	295028	19503N	PARTICIPANT	\N	PRESENT	0
296029	296027	14030Q	PARTICIPANT	\N	PRESENT	0
296030	296027	14255U	PARTICIPANT	\N	PRESENT	0
296031	296027	95037J	PARTICIPANT	\N	PRESENT	0
296032	296027	98005N	PARTICIPANT	\N	PRESENT	0
296033	296027	01034P	PARTICIPANT	\N	PRESENT	0
296034	296027	08053X	PARTICIPANT	\N	PRESENT	0
297571	297568	04044E	PARTICIPANT	\N	PRESENT	0
297572	289182	01058X	PARTICIPANT	\N	PRESENT	0
297579	289182	17589D	PARTICIPANT	\N	PRESENT	0
297580	297338	80013X	PARTICIPANT	\N	PRESENT	0
297581	297353	11109J	PARTICIPANT	\N	EXCUSE	0
297582	297353	14079W	PARTICIPANT	\N	EXCUSE	0
297583	297353	19347U	PARTICIPANT	\N	PRESENT	0
297584	297353	14213J	PRESIDENT	0	PRESENT	0
297585	297353	11099A	PARTICIPANT	\N	PRESENT	0
297586	297353	04049K	PARTICIPANT	\N	PRESENT	0
297587	297353	08015R	PARTICIPANT	\N	PRESENT	0
297588	297353	14109K	PARTICIPANT	\N	PRESENT	0
297589	297353	14169X	PRESIDENT	1	PRESENT	0
297590	297353	19503N	PARTICIPANT	\N	PRESENT	0
297591	297353	04045F	PARTICIPANT	\N	PRESENT	0
297592	297353	19657G	PARTICIPANT	\N	PRESENT	0
297759	289183	11077T	PARTICIPANT	\N	PRESENT	0
297760	289183	04092N	PARTICIPANT	\N	PRESENT	0
297761	289183	19521Q	PARTICIPANT	\N	PRESENT	0
297762	289183	14087W	PARTICIPANT	\N	PRESENT	0
297763	289183	19679N	PARTICIPANT	\N	PRESENT	0
297764	289183	17779H	PARTICIPANT	\N	PRESENT	0
297765	289183	19727D	PARTICIPANT	\N	PRESENT	0
297766	289183	19631V	PARTICIPANT	\N	PRESENT	0
297767	289183	08017T	PARTICIPANT	\N	PRESENT	0
297768	289183	14281W	PARTICIPANT	\N	PRESENT	0
297769	289183	11067R	PARTICIPANT	\N	PRESENT	0
297770	289183	08052W	PARTICIPANT	\N	PRESENT	0
297771	289183	14021P	PARTICIPANT	\N	PRESENT	0
297772	289183	14039A	PARTICIPANT	\N	PRESENT	0
297773	289183	19697Q	PARTICIPANT	\N	PRESENT	0
297774	289183	11031D	PARTICIPANT	\N	PRESENT	0
297775	289183	19515S	PARTICIPANT	\N	PRESENT	0
297776	289183	08031R	PARTICIPANT	\N	PRESENT	0
297777	289183	19629C	PARTICIPANT	\N	PRESENT	0
297778	289183	19703U	PARTICIPANT	\N	PRESENT	0
297779	289183	04070G	PARTICIPANT	\N	PRESENT	0
297780	289183	14033T	PARTICIPANT	\N	PRESENT	0
297781	289183	19611R	PARTICIPANT	\N	PRESENT	0
297782	289183	19737F	PARTICIPANT	\N	PRESENT	0
297783	289183	14119M	PARTICIPANT	\N	PRESENT	0
297784	289183	19619A	PARTICIPANT	\N	PRESENT	0
297785	289183	14195A	PARTICIPANT	\N	PRESENT	0
297786	289183	14042U	PARTICIPANT	\N	PRESENT	0
297787	289183	19713W	PARTICIPANT	\N	PRESENT	0
297788	289183	19575F	PARTICIPANT	\N	PRESENT	0
297789	289183	17589D	PARTICIPANT	\N	PRESENT	0
297790	289183	19758L	PARTICIPANT	\N	PRESENT	0
297791	289183	19553Y	PARTICIPANT	\N	PRESENT	0
297792	289183	11103C	PARTICIPANT	\N	PRESENT	0
297793	289183	19747H	PARTICIPANT	\N	PRESENT	0
297794	289183	19367Y	PARTICIPANT	\N	PRESENT	0
297795	289183	14217N	PARTICIPANT	\N	PRESENT	0
297796	289183	19621T	PARTICIPANT	\N	PRESENT	0
275630	275629	14105F	PARTICIPANT	\N	PRESENT	0
275631	275629	14207L	PARTICIPANT	\N	PRESENT	0
275632	275629	14329V	PARTICIPANT	\N	PRESENT	0
275633	275629	19719D	PARTICIPANT	\N	PRESENT	0
275634	275629	01024M	PARTICIPANT	\N	PRESENT	0
275635	275629	01025N	PARTICIPANT	\N	PRESENT	0
275636	275629	14026U	PARTICIPANT	\N	PRESENT	0
275637	275629	19725B	PARTICIPANT	\N	PRESENT	0
275638	275629	14213J	PARTICIPANT	\N	PRESENT	0
275639	275629	04049K	PARTICIPANT	\N	PRESENT	0
275640	275629	19723Y	PARTICIPANT	\N	PRESENT	0
275641	275629	08015R	PARTICIPANT	\N	PRESENT	0
275642	275629	08053X	PARTICIPANT	\N	PRESENT	0
275643	275629	14109K	PARTICIPANT	\N	PRESENT	0
275644	275629	08061X	PARTICIPANT	\N	PRESENT	0
275645	275629	19745F	PARTICIPANT	\N	PRESENT	0
275646	275629	19443T	PARTICIPANT	\N	PRESENT	0
275647	275629	11097X	PARTICIPANT	\N	PRESENT	0
275650	275649	14221J	PARTICIPANT	\N	PRESENT	0
275652	275651	14221J	PARTICIPANT	\N	PRESENT	0
275667	271247	14030Q	PRESIDENT	0	PRESENT	0
275668	271247	08043V	PARTICIPANT	\N	PRESENT	0
275669	271247	19621T	PARTICIPANT	\N	PRESENT	0
275670	271247	08020N	PARTICIPANT	\N	PRESENT	0
275671	271247	11031D	PARTICIPANT	\N	PRESENT	0
275673	271247	19693L	PARTICIPANT	\N	PRESENT	0
275676	271247	19715Y	PARTICIPANT	\N	PRESENT	0
275677	271247	19731Y	PARTICIPANT	\N	PRESENT	0
275678	271247	08031R	PARTICIPANT	\N	PRESENT	0
275679	271247	14109K	PARTICIPANT	\N	PRESENT	0
275680	271247	19749K	PARTICIPANT	\N	PRESENT	0
275682	271247	04040A	PARTICIPANT	\N	PRESENT	0
275683	271247	14069U	PARTICIPANT	\N	PRESENT	0
275684	271247	19253P	PARTICIPANT	\N	PRESENT	0
275685	271247	08038Y	PARTICIPANT	\N	PRESENT	0
275686	271247	14327T	PARTICIPANT	\N	PRESENT	0
275687	271247	14281W	PARTICIPANT	\N	PRESENT	0
275688	271247	19565D	PARTICIPANT	\N	PRESENT	0
275689	271247	01057W	PARTICIPANT	\N	PRESENT	0
275691	271247	19489J	PARTICIPANT	\N	PRESENT	0
275693	271247	08010L	PARTICIPANT	\N	PRESENT	0
275694	271247	14063N	PARTICIPANT	\N	PRESENT	0
275695	271247	14071N	PARTICIPANT	\N	PRESENT	0
275696	271247	14028W	PARTICIPANT	\N	PRESENT	0
275697	271247	95063L	PARTICIPANT	\N	PRESENT	0
275698	271247	95067Q	PARTICIPANT	\N	PRESENT	0
278073	275842	19565D	PARTICIPANT	\N	PRESENT	0
278074	275842	19441R	PARTICIPANT	\N	PRESENT	0
278075	275842	19413M	PARTICIPANT	\N	PRESENT	0
278076	275842	19667J	PARTICIPANT	\N	PRESENT	0
278077	275842	80013X	PARTICIPANT	\N	PRESENT	0
278078	275842	19631V	PARTICIPANT	\N	PRESENT	0
278079	275842	08021P	PARTICIPANT	\N	PRESENT	0
278080	275842	11099A	PARTICIPANT	\N	PRESENT	0
278081	275842	05012A	PARTICIPANT	\N	PRESENT	0
278082	275842	08068F	PARTICIPANT	\N	PRESENT	0
278083	275842	14197C	PARTICIPANT	\N	PRESENT	0
278084	275842	19369B	PARTICIPANT	\N	PRESENT	0
278085	275842	19511N	PARTICIPANT	\N	PRESENT	0
278086	275842	08039A	PARTICIPANT	\N	PRESENT	0
278087	275842	19591F	PARTICIPANT	\N	PRESENT	0
278088	275842	08038Y	PARTICIPANT	\N	PRESENT	0
278089	275842	19695N	PARTICIPANT	\N	PRESENT	0
278090	275842	01025N	PARTICIPANT	\N	PRESENT	0
278091	275842	19269X	PARTICIPANT	\N	PRESENT	0
278092	275842	14205J	PARTICIPANT	\N	PRESENT	0
278093	275842	11056N	PARTICIPANT	\N	PRESENT	0
278094	275842	14207L	PARTICIPANT	\N	PRESENT	0
278095	275842	19619A	PARTICIPANT	\N	PRESENT	0
278096	275842	17589D	PARTICIPANT	\N	PRESENT	0
278097	275842	14257W	PARTICIPANT	\N	PRESENT	0
278105	275756	04071H	PARTICIPANT	\N	PRESENT	0
278106	275756	19545Y	PARTICIPANT	\N	PRESENT	0
278107	275756	19671E	PARTICIPANT	\N	PRESENT	0
278108	275756	11070L	PARTICIPANT	\N	PRESENT	0
278109	275756	19647E	PARTICIPANT	\N	PRESENT	0
278110	275756	19687N	PARTICIPANT	\N	PRESENT	0
278111	275756	11053K	PARTICIPANT	\N	PRESENT	0
278113	275757	14331P	PARTICIPANT	\N	PRESENT	0
278114	275757	19479G	PARTICIPANT	\N	PRESENT	0
278115	275757	19711U	PARTICIPANT	\N	PRESENT	0
278116	275757	01048V	PARTICIPANT	\N	PRESENT	0
278117	275757	01057W	PARTICIPANT	\N	PRESENT	0
278118	275757	11053K	PARTICIPANT	\N	PRESENT	0
278119	275757	11074Q	PRESIDENT	0	PRESENT	0
278120	275757	14034U	PARTICIPANT	\N	PRESENT	0
278121	275757	11070L	PARTICIPANT	\N	PRESENT	0
278122	275757	04086Q	PARTICIPANT	\N	PRESENT	0
278123	275757	07029T	PARTICIPANT	\N	PRESENT	0
278124	275757	14083S	PARTICIPANT	\N	PRESENT	0
278125	275757	14085U	PARTICIPANT	\N	PRESENT	0
278126	275757	08073C	PARTICIPANT	\N	PRESENT	0
278127	275757	19741B	PARTICIPANT	\N	PRESENT	0
278128	275757	08010L	PARTICIPANT	\N	PRESENT	0
278129	275757	14121F	PARTICIPANT	\N	PRESENT	0
278130	275757	14253S	PARTICIPANT	\N	PRESENT	0
278131	276033	08020N	PARTICIPANT	\N	PRESENT	0
278132	276033	11109J	PARTICIPANT	\N	PRESENT	0
278133	276033	19621T	PARTICIPANT	\N	PRESENT	0
278134	275757	08069G	PARTICIPANT	\N	PRESENT	0
278159	275757	08011M	PARTICIPANT	\N	EXCUSE	0
278160	275757	08014Q	PARTICIPANT	\N	EXCUSE	0
278169	275134	11115U	PARTICIPANT	\N	PRESENT	0
278254	275757	11012A	PARTICIPANT	\N	PRESENT	0
278258	274817	14239U	PARTICIPANT	\N	PRESENT	0
278259	274817	11067R	PARTICIPANT	\N	PRESENT	0
278260	274817	04092N	PRESIDENT	0	PRESENT	0
278261	274817	14281W	PARTICIPANT	\N	PRESENT	0
278262	274817	11103C	PARTICIPANT	\N	PRESENT	0
278263	274817	14195A	PARTICIPANT	\N	PRESENT	0
278264	274817	19367Y	PARTICIPANT	\N	PRESENT	0
278265	274817	14223L	PARTICIPANT	\N	PRESENT	0
278266	274817	10006L	PARTICIPANT	\N	PRESENT	0
278267	274817	19683J	PARTICIPANT	\N	PRESENT	0
278268	274817	19521Q	PARTICIPANT	\N	PRESENT	0
278269	274817	19675J	PARTICIPANT	\N	PRESENT	0
278270	274817	08048B	PARTICIPANT	\N	EXCUSE	0
278271	274817	19715Y	PARTICIPANT	\N	PRESENT	0
278272	274817	19697Q	PARTICIPANT	\N	PRESENT	0
278273	274817	14355X	PARTICIPANT	\N	PRESENT	0
278274	274817	11097X	PARTICIPANT	\N	PRESENT	0
278275	274817	19415P	PARTICIPANT	\N	PRESENT	0
278276	274817	04045F	PARTICIPANT	\N	PRESENT	0
278277	274817	14227Q	PARTICIPANT	\N	PRESENT	0
278278	274817	11063M	PARTICIPANT	\N	PRESENT	0
278279	274817	17779H	PARTICIPANT	\N	PRESENT	0
278280	274817	11031D	PARTICIPANT	\N	PRESENT	0
278281	274817	14087W	PARTICIPANT	\N	PRESENT	0
278282	274817	19679N	PARTICIPANT	\N	PRESENT	0
278283	274817	19335Q	PARTICIPANT	\N	PRESENT	0
278284	274817	98024R	PARTICIPANT	\N	PRESENT	0
278285	274817	11045K	PARTICIPANT	\N	PRESENT	0
278286	274817	08052W	PARTICIPANT	\N	PRESENT	0
278287	274817	14119M	PARTICIPANT	\N	PRESENT	0
278288	274851	04045F	PARTICIPANT	\N	EXCUSE	0
278289	274817	14217N	PARTICIPANT	\N	PRESENT	0
278290	274817	19691J	PARTICIPANT	\N	PRESENT	0
278291	274817	19703U	PARTICIPANT	\N	PRESENT	0
278293	274817	19723Y	PARTICIPANT	\N	PRESENT	0
278294	274817	19727D	PARTICIPANT	\N	PRESENT	0
278295	274817	14213J	PARTICIPANT	\N	PRESENT	0
278296	274817	19663E	PARTICIPANT	\N	PRESENT	0
278297	274817	14026U	PARTICIPANT	\N	PRESENT	0
278298	274817	19527W	PARTICIPANT	\N	PRESENT	0
278299	274817	14071N	PARTICIPANT	\N	PRESENT	0
278300	274817	19553Y	PARTICIPANT	\N	PRESENT	0
278301	274817	14042U	PARTICIPANT	\N	PRESENT	0
278302	274817	19575F	PARTICIPANT	\N	PRESENT	0
278303	274817	04043D	PARTICIPANT	\N	PRESENT	0
278345	274817	19569H	PARTICIPANT	\N	PRESENT	0
278346	274817	11077T	PARTICIPANT	\N	PRESENT	0
278360	274851	14195A	PARTICIPANT	\N	EXCUSE	0
279402	278758	17637T	PARTICIPANT	\N	PRESENT	0
279419	278758	98023Q	PARTICIPANT	\N	PRESENT	0
279404	278758	08009T	PRESIDENT	0	PRESENT	0
279405	278758	14038Y	PARTICIPANT	\N	PRESENT	0
279406	278758	08060W	PARTICIPANT	\N	PRESENT	0
279407	278758	19737F	PARTICIPANT	\N	PRESENT	0
279408	278758	08055A	PARTICIPANT	\N	PRESENT	0
279409	278758	14103D	PARTICIPANT	\N	PRESENT	0
279410	278758	19713W	PARTICIPANT	\N	PRESENT	0
279411	278758	14031R	PARTICIPANT	\N	PRESENT	0
279412	278758	19549D	PARTICIPANT	\N	PRESENT	0
279413	278758	19599P	PARTICIPANT	\N	PRESENT	0
279414	278758	14169X	PARTICIPANT	\N	PRESENT	0
279415	278758	15447F	PARTICIPANT	\N	PRESENT	0
279416	278758	19503N	PARTICIPANT	\N	PRESENT	0
279417	278758	19739H	PARTICIPANT	\N	PRESENT	0
279418	278758	08024S	PARTICIPANT	\N	PRESENT	0
284981	278103	14281W	PARTICIPANT	\N	PRESENT	0
284982	278103	14087W	PARTICIPANT	\N	PRESENT	0
284983	278103	19521Q	PARTICIPANT	\N	PRESENT	0
284984	278103	19703U	PARTICIPANT	\N	PRESENT	0
284999	277022	14087W	PARTICIPANT	\N	PRESENT	0
285000	277022	19521Q	PARTICIPANT	\N	PRESENT	0
285001	277022	19679N	PARTICIPANT	\N	PRESENT	0
285002	277022	14071N	PARTICIPANT	\N	PRESENT	0
285004	278168	14087W	PARTICIPANT	\N	PRESENT	0
285005	278168	19521Q	PARTICIPANT	\N	PRESENT	0
285006	278168	19679N	PARTICIPANT	\N	PRESENT	0
292077	292076	14237S	PARTICIPANT	\N	PRESENT	0
292078	292076	08018U	PARTICIPANT	\N	PRESENT	0
295701	295675	12041X	PARTICIPANT	\N	PRESENT	0
295702	295675	11026G	PARTICIPANT	\N	PRESENT	0
295703	295675	14001X	PARTICIPANT	\N	PRESENT	0
295704	295675	19593H	PARTICIPANT	\N	EXCUSE	0
295705	295675	14237S	PARTICIPANT	\N	PRESENT	0
295706	295675	14331P	PARTICIPANT	\N	PRESENT	0
295707	295675	14065Q	PARTICIPANT	\N	PRESENT	0
295708	295675	14061L	PARTICIPANT	\N	EXCUSE	0
295709	295675	04057K	PARTICIPANT	\N	EXCUSE	0
295710	295675	04061F	PARTICIPANT	\N	EXCUSE	0
295712	295711	19741B	PARTICIPANT	\N	PRESENT	0
295713	295711	04038G	PARTICIPANT	\N	PRESENT	0
295714	295711	11070L	PRESIDENT	0	PRESENT	0
295715	295711	04097T	PARTICIPANT	\N	PRESENT	0
295716	295711	12016W	PARTICIPANT	\N	PRESENT	0
295717	295711	17637T	PARTICIPANT	\N	PRESENT	0
295718	295711	19533U	PARTICIPANT	\N	PRESENT	0
295719	295711	95062K	PARTICIPANT	\N	PRESENT	0
295720	295711	19689Q	PARTICIPANT	\N	PRESENT	0
295721	295711	11041F	PARTICIPANT	\N	PRESENT	0
295727	295726	19741B	PARTICIPANT	\N	PRESENT	0
295728	295726	04038G	PARTICIPANT	\N	PRESENT	0
295729	295726	14357A	PARTICIPANT	\N	PRESENT	0
295730	295726	11070L	PARTICIPANT	\N	EXCUSE	0
295731	295726	04097T	PARTICIPANT	\N	PRESENT	0
295732	295726	19711U	PARTICIPANT	\N	PRESENT	0
295733	295726	95062K	PARTICIPANT	\N	PRESENT	0
295734	295726	19689Q	PARTICIPANT	\N	PRESENT	0
295735	295726	11041F	PRESIDENT	0	PRESENT	0
295737	295736	19741B	PARTICIPANT	\N	PRESENT	0
295738	295736	04038G	PARTICIPANT	\N	PRESENT	0
295739	295736	14357A	PARTICIPANT	\N	PRESENT	0
295740	295736	11070L	PARTICIPANT	\N	EXCUSE	0
295741	295736	04097T	PARTICIPANT	\N	PRESENT	0
295742	295736	19711U	PARTICIPANT	\N	PRESENT	0
295743	295736	95062K	PARTICIPANT	\N	PRESENT	0
295744	295736	19689Q	PARTICIPANT	\N	PRESENT	0
295745	295736	11041F	PRESIDENT	0	PRESENT	0
295747	295746	08043V	PARTICIPANT	\N	PRESENT	0
295748	295746	04038G	PARTICIPANT	\N	PRESENT	0
295749	295746	11070L	PARTICIPANT	\N	EXCUSE	0
295750	295746	95062K	PARTICIPANT	\N	PRESENT	0
295751	295746	19689Q	PARTICIPANT	\N	PRESENT	0
295752	295746	11041F	PRESIDENT	0	PRESENT	0
295827	295826	11074Q	PARTICIPANT	\N	PRESENT	0
295828	295826	08011M	PARTICIPANT	\N	PRESENT	0
295829	295826	19741B	PARTICIPANT	\N	PRESENT	0
295830	295826	14331P	PARTICIPANT	\N	PRESENT	0
295831	295826	19479G	PARTICIPANT	\N	PRESENT	0
295832	295826	14225N	PARTICIPANT	\N	PRESENT	0
295833	295826	19349W	PARTICIPANT	\N	PRESENT	0
295837	295834	19697Q	PARTICIPANT	\N	PRESENT	0
295838	295834	11067R	PARTICIPANT	\N	PRESENT	0
295839	295834	14355X	PARTICIPANT	\N	PRESENT	0
295840	295834	19569H	PARTICIPANT	\N	PRESENT	0
295841	295834	11097X	PRESIDENT	0	PRESENT	0
295842	295834	19415P	PARTICIPANT	\N	PRESENT	0
295843	295834	04045F	PARTICIPANT	\N	PRESENT	0
295844	295834	14223L	PARTICIPANT	\N	PRESENT	0
295845	295834	14026U	PARTICIPANT	\N	PRESENT	0
295846	295834	14227Q	PARTICIPANT	\N	PRESENT	0
295847	295834	17779H	PARTICIPANT	\N	PRESENT	0
295848	295834	19703U	PARTICIPANT	\N	PRESENT	0
295849	295834	14239U	PARTICIPANT	\N	PRESENT	0
295850	295834	19553Y	PARTICIPANT	\N	PRESENT	0
295851	295834	11031D	PARTICIPANT	\N	PRESENT	0
295852	295834	14087W	PARTICIPANT	\N	PRESENT	0
295853	295834	14281W	PARTICIPANT	\N	PRESENT	0
295854	295834	19679N	PARTICIPANT	\N	PRESENT	0
295855	295834	14042U	PARTICIPANT	\N	PRESENT	0
295856	295834	14195A	PARTICIPANT	\N	PRESENT	0
295857	295834	19575F	PARTICIPANT	\N	PRESENT	0
295858	295834	14213J	PARTICIPANT	\N	PRESENT	0
295859	295834	19367Y	PARTICIPANT	\N	PRESENT	0
295860	295834	19335Q	PARTICIPANT	\N	PRESENT	0
295861	295834	10006L	PARTICIPANT	\N	PRESENT	0
295862	295834	19521Q	PARTICIPANT	\N	PRESENT	0
295863	295834	04092N	PRESIDENT	1	PRESENT	0
295864	295834	08052W	PARTICIPANT	\N	PRESENT	0
295865	295834	19715Y	PARTICIPANT	\N	PRESENT	0
295866	295834	19723Y	PARTICIPANT	\N	PRESENT	0
295867	295834	19727D	PARTICIPANT	\N	PRESENT	0
295868	295834	14119M	PARTICIPANT	\N	PRESENT	0
295869	295834	11103C	PARTICIPANT	\N	PRESENT	0
295870	295834	19657G	PARTICIPANT	\N	PRESENT	0
295871	295834	19760E	PARTICIPANT	\N	PRESENT	0
295872	295834	01034P	PARTICIPANT	\N	EXCUSE	0
295873	295834	14071N	PARTICIPANT	\N	EXCUSE	0
295874	295834	08041T	PARTICIPANT	\N	EXCUSE	0
295876	295835	04092N	PRESIDENT	0	PRESENT	0
295877	295835	14087W	PARTICIPANT	\N	PRESENT	0
295878	295835	14281W	PARTICIPANT	\N	PRESENT	0
295879	295835	19679N	PARTICIPANT	\N	PRESENT	0
295880	295835	14227Q	PARTICIPANT	\N	PRESENT	0
295881	295835	19521Q	PARTICIPANT	\N	PRESENT	0
295882	295835	08048B	PARTICIPANT	\N	EXCUSE	0
295883	295835	19715Y	PARTICIPANT	\N	PRESENT	0
295884	295835	08041T	PARTICIPANT	\N	EXCUSE	0
295885	295835	19697Q	PARTICIPANT	\N	PRESENT	0
295886	295835	11067R	PARTICIPANT	\N	PRESENT	0
295887	295835	11097X	PARTICIPANT	\N	PRESENT	0
295888	295835	08052W	PARTICIPANT	\N	PRESENT	0
295889	295835	14223L	PARTICIPANT	\N	PRESENT	0
295890	295835	14026U	PARTICIPANT	\N	PRESENT	0
295891	295835	19723Y	PARTICIPANT	\N	PRESENT	0
295892	295835	14119M	PARTICIPANT	\N	PRESENT	0
295893	295835	19367Y	PARTICIPANT	\N	PRESENT	0
295894	295835	14213J	PARTICIPANT	\N	PRESENT	0
295895	295835	10006L	PARTICIPANT	\N	PRESENT	0
295896	295835	19760E	PARTICIPANT	\N	PRESENT	0
295897	295835	14355X	PARTICIPANT	\N	PRESENT	0
295898	295835	19657G	PARTICIPANT	\N	PRESENT	0
295899	295835	19727D	PARTICIPANT	\N	PRESENT	0
295900	295835	19703U	PARTICIPANT	\N	PRESENT	0
295901	295835	11045K	PARTICIPANT	\N	PRESENT	0
295902	295835	14195A	PARTICIPANT	\N	PRESENT	0
295903	295835	19415P	PARTICIPANT	\N	PRESENT	0
295904	295835	14042U	PARTICIPANT	\N	PRESENT	0
295905	295835	04045F	PARTICIPANT	\N	PRESENT	0
295906	295835	17779H	PARTICIPANT	\N	PRESENT	0
295907	289178	04059M	PARTICIPANT	\N	PRESENT	0
295908	295835	01034P	PARTICIPANT	\N	PRESENT	0
295909	295835	19335Q	PARTICIPANT	\N	PRESENT	0
295910	295835	19575F	PARTICIPANT	\N	PRESENT	0
295911	289178	19731Y	PARTICIPANT	\N	PRESENT	0
295912	289178	14227Q	PARTICIPANT	\N	PRESENT	0
295913	289178	19443T	PARTICIPANT	\N	PRESENT	0
295914	289178	19319Q	PARTICIPANT	\N	PRESENT	0
295915	289178	19671E	PARTICIPANT	\N	PRESENT	0
295916	289178	14087W	PARTICIPANT	\N	PRESENT	0
295917	289178	19611R	PARTICIPANT	\N	PRESENT	0
295918	289178	19565D	PARTICIPANT	\N	PRESENT	0
295919	289178	08052W	PARTICIPANT	\N	PRESENT	0
295920	289178	11067R	PARTICIPANT	\N	PRESENT	0
295921	289178	14281W	PARTICIPANT	\N	PRESENT	0
295922	289178	19715Y	PARTICIPANT	\N	PRESENT	0
295923	289178	19333N	PARTICIPANT	\N	PRESENT	0
295924	289178	14081Q	PARTICIPANT	\N	PRESENT	0
295925	289178	19553Y	PARTICIPANT	\N	PRESENT	0
295926	289178	14195A	PARTICIPANT	\N	PRESENT	0
295927	289178	19569H	PARTICIPANT	\N	PRESENT	0
295928	289178	19758L	PARTICIPANT	\N	PRESENT	0
295929	289178	11031D	PARTICIPANT	\N	PRESENT	0
295930	289178	19760E	PARTICIPANT	\N	PRESENT	0
295931	289178	04092N	PARTICIPANT	\N	PRESENT	0
295932	289178	19521Q	PARTICIPANT	\N	PRESENT	0
295933	289178	19679N	PARTICIPANT	\N	PRESENT	0
295934	289178	14235Q	PARTICIPANT	\N	PRESENT	0
295935	289178	19697Q	PARTICIPANT	\N	PRESENT	0
295936	289178	14239U	PARTICIPANT	\N	PRESENT	0
295937	289178	04045F	PARTICIPANT	\N	PRESENT	0
295938	289178	11104D	PARTICIPANT	\N	PRESENT	0
295939	289178	14063N	PARTICIPANT	\N	PRESENT	0
295940	289178	19515S	PARTICIPANT	\N	PRESENT	0
295941	289178	11045K	PARTICIPANT	\N	PRESENT	0
295942	289178	19725B	PARTICIPANT	\N	PRESENT	0
278446	278445	04049K	PARTICIPANT	\N	PRESENT	0
278447	278445	14121F	PARTICIPANT	\N	PRESENT	0
278448	278445	19671E	PARTICIPANT	\N	PRESENT	0
278449	278445	14083S	PARTICIPANT	\N	PRESENT	0
278450	278445	14051J	PARTICIPANT	\N	PRESENT	0
278451	278445	14261S	PARTICIPANT	\N	PRESENT	0
278452	278445	14034U	PARTICIPANT	\N	PRESENT	0
278817	263774	14157T	PARTICIPANT	\N	PRESENT	0
278818	263774	19447X	PARTICIPANT	\N	PRESENT	0
278819	263774	14121F	PARTICIPANT	\N	PRESENT	0
278820	263774	19413M	PARTICIPANT	\N	PRESENT	0
278821	263774	14033T	PARTICIPANT	\N	PRESENT	0
278822	263774	08010L	PARTICIPANT	\N	PRESENT	0
278823	263774	11065P	PARTICIPANT	\N	PRESENT	0
278824	263774	19637C	PARTICIPANT	\N	PRESENT	0
278825	263774	04061F	PARTICIPANT	\N	PRESENT	0
278826	263774	19573D	PARTICIPANT	\N	PRESENT	0
278828	263774	14207L	PARTICIPANT	\N	PRESENT	0
278829	263774	19747H	PARTICIPANT	\N	PRESENT	0
278830	263774	08019V	PARTICIPANT	\N	PRESENT	0
278834	263774	14331P	PARTICIPANT	\N	PRESENT	0
278835	263774	19663E	PARTICIPANT	\N	PRESENT	0
278836	263774	14275Y	PARTICIPANT	\N	PRESENT	0
278842	263774	14042U	PARTICIPANT	\N	PRESENT	0
278843	263774	02002K	PARTICIPANT	\N	PRESENT	0
278844	263774	14063N	PARTICIPANT	\N	PRESENT	0
278845	263774	19503N	PARTICIPANT	\N	PRESENT	0
278846	263774	96004D	PARTICIPANT	\N	PRESENT	0
278863	263774	19643A	PARTICIPANT	\N	PRESENT	0
278864	263774	14215L	PARTICIPANT	\N	PRESENT	0
278865	263774	01024M	PARTICIPANT	\N	PRESENT	0
278866	263774	14257W	PARTICIPANT	\N	PRESENT	0
278867	263774	19549D	PARTICIPANT	\N	PRESENT	0
278868	263774	19683J	PARTICIPANT	\N	PRESENT	0
278869	263774	08016S	PARTICIPANT	\N	PRESENT	0
278870	263774	19693L	PARTICIPANT	\N	PRESENT	0
278871	263774	19543W	PARTICIPANT	\N	PRESENT	0
278872	263774	19563B	PARTICIPANT	\N	PRESENT	0
278873	263774	11054L	PARTICIPANT	\N	PRESENT	0
278874	263774	14123H	PARTICIPANT	\N	PRESENT	0
278876	263774	11031D	PARTICIPANT	\N	PRESENT	0
278877	263774	07033P	PARTICIPANT	\N	PRESENT	0
278878	263774	14097Y	PARTICIPANT	\N	PRESENT	0
278879	263774	14217N	PARTICIPANT	\N	PRESENT	0
278880	263774	04057K	PARTICIPANT	\N	PRESENT	0
278881	263774	19741B	PARTICIPANT	\N	PRESENT	0
278882	263774	19533U	PARTICIPANT	\N	PRESENT	0
278883	263774	14327T	PARTICIPANT	\N	PRESENT	0
278886	263774	11067R	PARTICIPANT	\N	PRESENT	0
278887	263774	14030Q	PARTICIPANT	\N	PRESENT	0
278888	263774	14251Q	PARTICIPANT	\N	PRESENT	0
278889	263774	11097X	PARTICIPANT	\N	PRESENT	0
278894	263774	19725B	PARTICIPANT	\N	PRESENT	0
278897	263774	19611R	PARTICIPANT	\N	PRESENT	0
278898	263774	08020N	PARTICIPANT	\N	PRESENT	0
278899	263774	04086Q	PARTICIPANT	\N	PRESENT	0
278900	263774	10006L	PARTICIPANT	\N	PRESENT	0
278905	263774	11049P	PARTICIPANT	\N	PRESENT	0
278914	263774	08045X	PARTICIPANT	\N	PRESENT	0
278915	263774	99004R	PARTICIPANT	\N	PRESENT	0
278920	263774	14021P	PARTICIPANT	\N	PRESENT	0
278932	263774	14079W	PARTICIPANT	\N	PRESENT	0
278938	263774	04059M	PARTICIPANT	\N	PRESENT	0
278939	263774	19731Y	PARTICIPANT	\N	PRESENT	0
279029	263775	19693L	PARTICIPANT	\N	PRESENT	0
279030	263775	19399H	PARTICIPANT	\N	PRESENT	0
279031	263775	04018C	PARTICIPANT	\N	PRESENT	0
279032	263775	19737F	PARTICIPANT	\N	PRESENT	0
279033	263775	08055A	PARTICIPANT	\N	PRESENT	0
279034	263775	08052W	PARTICIPANT	\N	PRESENT	0
279035	263775	08009T	PARTICIPANT	\N	PRESENT	0
279036	263775	98023Q	PARTICIPANT	\N	PRESENT	0
279037	263775	19503N	PARTICIPANT	\N	PRESENT	0
279038	263775	04085P	PARTICIPANT	\N	PRESENT	0
279039	263775	07004J	PARTICIPANT	\N	PRESENT	0
279040	263775	04061F	PARTICIPANT	\N	PRESENT	0
279041	263775	19731Y	PARTICIPANT	\N	PRESENT	0
279042	263775	04088S	PARTICIPANT	\N	PRESENT	0
279043	263775	19347U	PARTICIPANT	\N	PRESENT	0
279044	263775	07029T	PARTICIPANT	\N	PRESENT	0
279045	263775	08010L	PARTICIPANT	\N	PRESENT	0
279046	263775	14157T	PARTICIPANT	\N	PRESENT	0
279047	263775	19637C	PARTICIPANT	\N	PRESENT	0
279048	263775	19695N	PARTICIPANT	\N	PRESENT	0
279049	263775	19747H	PARTICIPANT	\N	PRESENT	0
279050	263775	19711U	PARTICIPANT	\N	PRESENT	0
279051	263775	11097X	PARTICIPANT	\N	PRESENT	0
279052	263775	14051J	PARTICIPANT	\N	PRESENT	0
279054	263775	19551W	PARTICIPANT	\N	PRESENT	0
279055	263775	19681G	PARTICIPANT	\N	PRESENT	0
279056	263775	99004R	PARTICIPANT	\N	PRESENT	0
279057	263775	14033T	PARTICIPANT	\N	PRESENT	0
279058	263775	19447X	PARTICIPANT	\N	PRESENT	0
279059	263775	14135M	PARTICIPANT	\N	PRESENT	0
279060	263775	98050T	PARTICIPANT	\N	PRESENT	0
279061	263775	11031D	PARTICIPANT	\N	PRESENT	0
279074	263775	14079W	PARTICIPANT	\N	PRESENT	0
279076	263775	19507S	PARTICIPANT	\N	PRESENT	0
279077	263775	11077T	PARTICIPANT	\N	PRESENT	0
279078	263775	01034P	PARTICIPANT	\N	PRESENT	0
279080	263775	19689Q	PARTICIPANT	\N	PRESENT	0
279086	263775	16685X	PARTICIPANT	\N	PRESENT	0
279090	263775	02002K	PARTICIPANT	\N	PRESENT	0
279091	263775	11065P	PARTICIPANT	\N	PRESENT	0
279092	263775	19333N	PARTICIPANT	\N	PRESENT	0
279093	263775	19611R	PARTICIPANT	\N	PRESENT	0
279096	263775	19253P	PARTICIPANT	\N	PRESENT	0
279097	263775	19591F	PARTICIPANT	\N	PRESENT	0
279098	263775	11067R	PARTICIPANT	\N	PRESENT	0
279099	263775	01048V	PARTICIPANT	\N	PRESENT	0
279100	263775	04086Q	PARTICIPANT	\N	PRESENT	0
279101	263775	04043D	PARTICIPANT	\N	PRESENT	0
279102	263775	19687N	PARTICIPANT	\N	PRESENT	0
279103	263775	14195A	PARTICIPANT	\N	PRESENT	0
279104	263775	05012A	PARTICIPANT	\N	PRESENT	0
279108	263775	19741B	PARTICIPANT	\N	PRESENT	0
279109	263775	11109J	PARTICIPANT	\N	PRESENT	0
279110	263775	14213J	PARTICIPANT	\N	PRESENT	0
279111	263775	04035D	PARTICIPANT	\N	PRESENT	0
279112	263775	19649G	PARTICIPANT	\N	PRESENT	0
279113	263775	14257W	PARTICIPANT	\N	PRESENT	0
279114	263775	19549D	PARTICIPANT	\N	PRESENT	0
279115	263775	14197C	PARTICIPANT	\N	PRESENT	0
279116	263775	19669L	PARTICIPANT	\N	PRESENT	0
279117	263775	11045K	PARTICIPANT	\N	PRESENT	0
279118	263775	14021P	PARTICIPANT	\N	PRESENT	0
279143	263775	14034U	PARTICIPANT	\N	PRESENT	0
279144	263775	14357A	PARTICIPANT	\N	PRESENT	0
279145	263775	11053K	PARTICIPANT	\N	PRESENT	0
279168	263775	14169X	PARTICIPANT	\N	PRESENT	0
279170	263775	19543W	PARTICIPANT	\N	PRESENT	0
279171	263775	08069G	PARTICIPANT	\N	PRESENT	0
279172	263775	14261S	PARTICIPANT	\N	PRESENT	0
279173	263775	12041X	PARTICIPANT	\N	PRESENT	0
279211	263780	04044E	PARTICIPANT	\N	PRESENT	0
279212	263780	08009T	PARTICIPANT	\N	PRESENT	0
279213	263780	98023Q	PARTICIPANT	\N	PRESENT	0
279214	263780	19697Q	PARTICIPANT	\N	PRESENT	0
279215	263780	08052W	PARTICIPANT	\N	PRESENT	0
279216	263780	19503N	PARTICIPANT	\N	PRESENT	0
279217	263780	19611R	PARTICIPANT	\N	PRESENT	0
279218	263780	99004R	PARTICIPANT	\N	PRESENT	0
279219	263780	19711U	PARTICIPANT	\N	PRESENT	0
279220	263780	14157T	PARTICIPANT	\N	PRESENT	0
279221	263780	07029T	PARTICIPANT	\N	PRESENT	0
279222	263780	14219Q	PARTICIPANT	\N	PRESENT	0
279223	263780	04061F	PARTICIPANT	\N	PRESENT	0
279224	263780	19695N	PARTICIPANT	\N	PRESENT	0
279225	263780	19687N	PARTICIPANT	\N	PRESENT	0
279226	263780	04086Q	PARTICIPANT	\N	PRESENT	0
279227	263780	19551W	PARTICIPANT	\N	PRESENT	0
279027	263775	19387D	PARTICIPANT	\N	PRESENT	0
279028	263775	14219Q	PARTICIPANT	\N	PRESENT	0
279228	263780	19637C	PARTICIPANT	\N	PRESENT	0
279229	263780	19543W	PARTICIPANT	\N	PRESENT	0
279230	263780	14169X	PARTICIPANT	\N	PRESENT	0
279231	263780	14261S	PARTICIPANT	\N	PRESENT	0
279232	263780	19647E	PARTICIPANT	\N	PRESENT	0
279233	263780	14135M	PARTICIPANT	\N	PRESENT	0
279234	263780	19693L	PARTICIPANT	\N	PRESENT	0
279235	263780	04085P	PARTICIPANT	\N	PRESENT	0
279236	263780	19347U	PARTICIPANT	\N	PRESENT	0
279237	263780	11077T	PARTICIPANT	\N	PRESENT	0
279238	263780	17637T	PARTICIPANT	\N	PRESENT	0
279239	263780	11064N	PARTICIPANT	\N	PRESENT	0
279240	263780	08069G	PARTICIPANT	\N	PRESENT	0
279241	263780	14123H	PARTICIPANT	\N	PRESENT	0
280759	280758	19383Y	PARTICIPANT	\N	PRESENT	0
281720	281719	08018U	PARTICIPANT	\N	PRESENT	0
295129	289110	86034E	PARTICIPANT	\N	PRESENT	0
293817	293109	14038Y	PARTICIPANT	\N	EXCUSE	0
293825	293824	19399H	PARTICIPANT	\N	PRESENT	0
293826	293824	08031R	PARTICIPANT	\N	PRESENT	0
293827	293824	19735D	PARTICIPANT	\N	PRESENT	0
293828	293824	14229S	PARTICIPANT	\N	PRESENT	0
294203	294202	19673G	PARTICIPANT	\N	PRESENT	0
294907	289109	19441R	PARTICIPANT	\N	PRESENT	0
294908	289109	18083K	PARTICIPANT	\N	PRESENT	0
294909	289109	11033F	PARTICIPANT	\N	PRESENT	0
294910	289109	14109K	PARTICIPANT	\N	PRESENT	0
294905	289109	14119M	PARTICIPANT	\N	PRESENT	0
294906	289109	19467C	PARTICIPANT	\N	PRESENT	0
294911	289109	14231L	PARTICIPANT	\N	PRESENT	0
294912	289109	11097X	PARTICIPANT	\N	PRESENT	0
294913	289109	14215L	PARTICIPANT	\N	PRESENT	0
294914	289109	19715Y	PARTICIPANT	\N	PRESENT	0
294915	289109	11040E	PARTICIPANT	\N	PRESENT	0
294916	289109	14217N	PARTICIPANT	\N	PRESENT	0
294917	289109	14219Q	PARTICIPANT	\N	PRESENT	0
294918	289109	19745F	PARTICIPANT	\N	PRESENT	0
294919	289109	04092N	PARTICIPANT	\N	PRESENT	0
294920	289109	19737F	PARTICIPANT	\N	PRESENT	0
294921	289109	14065Q	PARTICIPANT	\N	PRESENT	0
294922	289109	14329V	PARTICIPANT	\N	PRESENT	0
294923	289109	14257W	PARTICIPANT	\N	PRESENT	0
294924	289109	14255U	PARTICIPANT	\N	PRESENT	0
294925	289109	98050T	PARTICIPANT	\N	PRESENT	0
294926	289109	14169X	PARTICIPANT	\N	PRESENT	0
294931	289109	19565D	PARTICIPANT	\N	PRESENT	0
294934	289109	14159V	PARTICIPANT	\N	PRESENT	0
294935	289109	14121F	PARTICIPANT	\N	PRESENT	0
294936	289109	19699S	PARTICIPANT	\N	PRESENT	0
294937	289109	14103D	PARTICIPANT	\N	PRESENT	0
294938	289109	19701S	PARTICIPANT	\N	PRESENT	0
294939	289109	14223L	PARTICIPANT	\N	PRESENT	0
294940	289109	14237S	PARTICIPANT	\N	PRESENT	0
294941	289109	08010L	PARTICIPANT	\N	PRESENT	0
294942	289109	04040A	PARTICIPANT	\N	PRESENT	0
294943	289109	19719D	PARTICIPANT	\N	PRESENT	0
294944	289109	14331P	PARTICIPANT	\N	PRESENT	0
294945	289109	98022P	PARTICIPANT	\N	PRESENT	0
294946	289109	11010L	PARTICIPANT	\N	PRESENT	0
294947	289109	19657G	PARTICIPANT	\N	PRESENT	0
294948	289109	19679N	PARTICIPANT	\N	PRESENT	0
294949	289109	08034U	PARTICIPANT	\N	PRESENT	0
294950	289109	17779H	PARTICIPANT	\N	PRESENT	0
294951	289109	01024M	PARTICIPANT	\N	PRESENT	0
294952	289109	99004R	PARTICIPANT	\N	PRESENT	0
294953	289109	19479G	PARTICIPANT	\N	PRESENT	0
294954	289109	19663E	PARTICIPANT	\N	PRESENT	0
294957	289109	10006L	PARTICIPANT	\N	PRESENT	0
294973	289109	19253P	PARTICIPANT	\N	PRESENT	0
294974	289109	14083S	PARTICIPANT	\N	PRESENT	0
294975	289109	08015R	PARTICIPANT	\N	PRESENT	0
294976	289109	98005N	PARTICIPANT	\N	PRESENT	0
294977	289109	19723Y	PARTICIPANT	\N	PRESENT	0
294978	289109	14205J	PARTICIPANT	\N	PRESENT	0
294979	289109	98018T	PARTICIPANT	\N	PRESENT	0
294980	289109	19741B	PARTICIPANT	\N	PRESENT	0
294981	289109	14157T	PARTICIPANT	\N	PRESENT	0
294982	289109	04047H	PARTICIPANT	\N	PRESENT	0
294983	289109	04059M	PARTICIPANT	\N	PRESENT	0
294984	289109	19637C	PARTICIPANT	\N	PRESENT	0
294987	289109	04088S	PARTICIPANT	\N	PRESENT	0
294988	289109	14135M	PARTICIPANT	\N	PRESENT	0
294989	289109	16685X	PARTICIPANT	\N	PRESENT	0
294990	289109	14187A	PARTICIPANT	\N	PRESENT	0
294991	289109	19697Q	PARTICIPANT	\N	PRESENT	0
294992	289109	01057W	PARTICIPANT	\N	PRESENT	0
294993	289109	14042U	PARTICIPANT	\N	PRESENT	0
294994	289109	11083R	PARTICIPANT	\N	PRESENT	0
295133	289110	19479G	PARTICIPANT	\N	PRESENT	0
295134	289110	14331P	PARTICIPANT	\N	PRESENT	0
295135	289110	19731Y	PARTICIPANT	\N	PRESENT	0
295136	289110	07004J	PARTICIPANT	\N	PRESENT	0
295137	289110	14231L	PARTICIPANT	\N	PRESENT	0
295138	289110	98022P	PARTICIPANT	\N	PRESENT	0
295139	289110	14103D	PARTICIPANT	\N	PRESENT	0
295140	289110	19749K	PARTICIPANT	\N	PRESENT	0
295141	289110	14105F	PARTICIPANT	\N	PRESENT	0
295142	289110	19367Y	PARTICIPANT	\N	PRESENT	0
295143	289110	19619A	PARTICIPANT	\N	PRESENT	0
295144	289110	14073Q	PARTICIPANT	\N	PRESENT	0
295145	289110	14123H	PARTICIPANT	\N	PRESENT	0
295146	289110	04088S	PARTICIPANT	\N	PRESENT	0
295147	289110	19515S	PARTICIPANT	\N	PRESENT	0
295148	289110	19525U	PARTICIPANT	\N	PRESENT	0
295149	289110	01058X	PARTICIPANT	\N	PRESENT	0
295150	289110	14157T	PARTICIPANT	\N	PRESENT	0
295151	289110	99004R	PARTICIPANT	\N	PRESENT	0
295152	289110	19369B	PARTICIPANT	\N	PRESENT	0
295153	289110	19611R	PARTICIPANT	\N	PRESENT	0
295163	289110	19695N	PARTICIPANT	\N	PRESENT	0
295164	289110	17637T	PARTICIPANT	\N	PRESENT	0
295165	289110	19565D	PARTICIPANT	\N	PRESENT	0
295166	289110	11040E	PARTICIPANT	\N	PRESENT	0
295167	289110	95062K	PARTICIPANT	\N	PRESENT	0
295168	289110	04085P	PARTICIPANT	\N	PRESENT	0
295169	289110	19679N	PARTICIPANT	\N	PRESENT	0
295170	289110	19651A	PARTICIPANT	\N	PRESENT	0
295171	289110	19637C	PARTICIPANT	\N	PRESENT	0
295172	289110	19643A	PARTICIPANT	\N	PRESENT	0
295173	289110	19543W	PARTICIPANT	\N	PRESENT	0
295174	289110	95037J	PARTICIPANT	\N	PRESENT	0
295175	289110	95063L	PARTICIPANT	\N	PRESENT	0
295176	289110	04045F	PARTICIPANT	\N	PRESENT	0
295177	289110	08073C	PARTICIPANT	\N	PRESENT	0
295178	289110	04086Q	PARTICIPANT	\N	PRESENT	0
295179	289110	17779H	PARTICIPANT	\N	PRESENT	0
295180	289110	19489J	PARTICIPANT	\N	PRESENT	0
295181	289110	98018T	PARTICIPANT	\N	PRESENT	0
295182	289110	19715Y	PARTICIPANT	\N	PRESENT	0
295183	289110	04092N	PARTICIPANT	\N	PRESENT	0
295184	289110	08038Y	PARTICIPANT	\N	PRESENT	0
295185	289110	19711U	PARTICIPANT	\N	PRESENT	0
295186	289110	98024R	PARTICIPANT	\N	PRESENT	0
295187	289110	04097T	PARTICIPANT	\N	PRESENT	0
295188	289110	14187A	PARTICIPANT	\N	PRESENT	0
295189	289110	08010L	PARTICIPANT	\N	PRESENT	0
295190	289110	19697Q	PARTICIPANT	\N	PRESENT	0
295191	289110	11097X	PARTICIPANT	\N	PRESENT	0
295192	289110	19301E	PARTICIPANT	\N	PRESENT	0
295193	289110	14249W	PARTICIPANT	\N	PRESENT	0
295194	289110	11043H	PARTICIPANT	\N	PRESENT	0
295195	289110	14237S	PARTICIPANT	\N	PRESENT	0
295196	289110	14169X	PARTICIPANT	\N	PRESENT	0
295197	289110	19585H	PARTICIPANT	\N	PRESENT	0
295198	289110	14223L	PARTICIPANT	\N	PRESENT	0
295199	289110	17589D	PARTICIPANT	\N	PRESENT	0
295200	289110	14195A	PARTICIPANT	\N	PRESENT	0
295201	289110	01057W	PARTICIPANT	\N	PRESENT	0
295202	289110	19563B	PARTICIPANT	\N	PRESENT	0
295203	289110	11099A	PARTICIPANT	\N	PRESENT	0
295204	289110	10006L	PARTICIPANT	\N	PRESENT	0
295205	289110	19629C	PARTICIPANT	\N	PRESENT	0
295206	289110	19253P	PARTICIPANT	\N	PRESENT	0
295207	289110	19421M	PARTICIPANT	\N	PRESENT	0
295208	289110	04059M	PARTICIPANT	\N	PRESENT	0
295209	289110	08034U	PARTICIPANT	\N	PRESENT	0
295210	289110	08045X	PARTICIPANT	\N	PRESENT	0
295211	289110	14159V	PARTICIPANT	\N	PRESENT	0
295212	289110	11048N	PARTICIPANT	\N	PRESENT	0
295213	289110	19758L	PARTICIPANT	\N	PRESENT	0
295214	289110	19760E	PARTICIPANT	\N	PRESENT	0
295215	289110	19347U	PARTICIPANT	\N	PRESENT	0
295216	289110	19667J	PARTICIPANT	\N	PRESENT	0
295217	289110	19575F	PARTICIPANT	\N	PRESENT	0
295218	289110	14107H	PARTICIPANT	\N	PRESENT	0
295219	289110	19683J	PARTICIPANT	\N	PRESENT	0
295220	289110	19693L	PARTICIPANT	\N	PRESENT	0
295221	289110	08052W	PARTICIPANT	\N	PRESENT	0
295222	289110	14021P	PARTICIPANT	\N	PRESENT	0
295223	289110	14215L	PARTICIPANT	\N	PRESENT	0
295224	289110	19599P	PARTICIPANT	\N	PRESENT	0
295225	289110	19747H	PARTICIPANT	\N	PRESENT	0
295226	289110	19649G	PARTICIPANT	\N	PRESENT	0
295132	289110	14097Y	PARTICIPANT	\N	PRESENT	0
295227	289110	19647E	PARTICIPANT	\N	PRESENT	0
295228	289110	01062T	PARTICIPANT	\N	PRESENT	0
295229	289110	04071H	PARTICIPANT	\N	PRESENT	0
295230	289110	14121F	PARTICIPANT	\N	PRESENT	0
295231	289110	08012N	PARTICIPANT	\N	PRESENT	0
295232	289110	19727D	PARTICIPANT	\N	PRESENT	0
295233	289110	14085U	PARTICIPANT	\N	PRESENT	0
295236	289110	19689Q	PARTICIPANT	\N	PRESENT	0
279082	279081	14187A	PARTICIPANT	\N	PRESENT	0
279083	279081	04008A	PARTICIPANT	\N	PRESENT	0
279085	279084	14187A	PARTICIPANT	\N	PRESENT	0
279088	279087	14187A	PARTICIPANT	\N	PRESENT	0
279089	279087	14038Y	PARTICIPANT	\N	PRESENT	0
279420	278758	19525U	PARTICIPANT	\N	PRESENT	0
279421	278758	95062K	PARTICIPANT	\N	PRESENT	0
279432	278758	19551W	PARTICIPANT	\N	EXCUSE	0
279433	278758	04097T	PARTICIPANT	\N	PRESENT	0
279500	279498	86034E	PARTICIPANT	\N	PRESENT	0
279506	279498	19319Q	PARTICIPANT	\N	PRESENT	0
279507	279498	08019V	PARTICIPANT	\N	PRESENT	0
279508	279498	19443T	PARTICIPANT	\N	PRESENT	0
279509	279498	14237S	PARTICIPANT	\N	PRESENT	0
279510	279498	19731Y	PARTICIPANT	\N	PRESENT	0
279511	279498	19703U	PARTICIPANT	\N	PRESENT	0
279512	279498	19681G	PARTICIPANT	\N	PRESENT	0
279513	279498	14115H	PARTICIPANT	\N	PRESENT	0
279514	279498	99004R	PARTICIPANT	\N	PRESENT	0
279515	279498	08009T	PARTICIPANT	\N	PRESENT	0
279516	279498	14111D	PARTICIPANT	\N	PRESENT	0
279517	279498	19581D	PARTICIPANT	\N	PRESENT	0
279518	279498	19585H	PARTICIPANT	\N	PRESENT	0
279519	279498	04088S	PARTICIPANT	\N	PRESENT	0
279520	279498	95062K	PARTICIPANT	\N	PRESENT	0
279521	279498	15447F	PARTICIPANT	\N	PRESENT	0
279522	279498	19739H	PARTICIPANT	\N	PRESENT	0
279523	279498	07034Q	PARTICIPANT	\N	PRESENT	0
279525	279498	08055A	PARTICIPANT	\N	PRESENT	0
279526	279498	04085P	PARTICIPANT	\N	PRESENT	0
279527	279498	19758L	PARTICIPANT	\N	PRESENT	0
279528	279498	14235Q	PARTICIPANT	\N	PRESENT	0
279529	279498	11031D	PARTICIPANT	\N	PRESENT	0
279530	279498	19593H	PARTICIPANT	\N	PRESENT	0
279531	279498	19711U	PARTICIPANT	\N	PRESENT	0
279532	279498	19583F	PARTICIPANT	\N	PRESENT	0
279533	279498	14103D	PARTICIPANT	\N	PRESENT	0
279534	279498	19737F	PARTICIPANT	\N	PRESENT	0
279535	279498	19749K	PARTICIPANT	\N	PRESENT	0
279536	279498	19611R	PARTICIPANT	\N	PRESENT	0
279537	279498	14331P	PARTICIPANT	\N	PRESENT	0
279538	279498	04097T	PARTICIPANT	\N	PRESENT	0
279539	279498	19705W	PARTICIPANT	\N	PRESENT	0
279540	279498	19707Y	PARTICIPANT	\N	PRESENT	0
279541	279498	19699S	PARTICIPANT	\N	PRESENT	0
279542	279498	14029X	PARTICIPANT	\N	PRESENT	0
279543	279498	87003B	PARTICIPANT	\N	PRESENT	0
279544	279498	14157T	PARTICIPANT	\N	PRESENT	0
279545	279498	14105F	PARTICIPANT	\N	PRESENT	0
279546	279498	19413M	PARTICIPANT	\N	PRESENT	0
279547	279498	14197C	PARTICIPANT	\N	PRESENT	0
279548	279498	19333N	PARTICIPANT	\N	PRESENT	0
279549	279498	01028R	PARTICIPANT	\N	PRESENT	0
279550	279498	98035U	PARTICIPANT	\N	PRESENT	0
279551	279498	19387D	PARTICIPANT	\N	PRESENT	0
279552	279498	19551W	PARTICIPANT	\N	PRESENT	0
279553	279498	19637C	PARTICIPANT	\N	PRESENT	0
279554	279498	19367Y	PARTICIPANT	\N	PRESENT	0
279555	279498	19695N	PARTICIPANT	\N	PRESENT	0
279556	279498	12041X	PARTICIPANT	\N	PRESENT	0
279557	279498	08012N	PARTICIPANT	\N	PRESENT	0
279558	279498	17779H	PARTICIPANT	\N	PRESENT	0
279559	279498	14001X	PARTICIPANT	\N	PRESENT	0
279560	279498	14151M	PARTICIPANT	\N	PRESENT	0
279561	279498	11066Q	PARTICIPANT	\N	PRESENT	0
279562	279498	08052W	PARTICIPANT	\N	PRESENT	0
279563	279498	19687N	PARTICIPANT	\N	PRESENT	0
279564	279498	98029W	PARTICIPANT	\N	PRESENT	0
279565	279498	11074Q	PARTICIPANT	\N	PRESENT	0
279566	279498	14051J	PARTICIPANT	\N	PRESENT	0
279567	279498	11104D	PARTICIPANT	\N	PRESENT	0
279568	279498	19525U	PARTICIPANT	\N	PRESENT	0
279569	279498	11067R	PARTICIPANT	\N	PRESENT	0
279570	279498	14281W	PARTICIPANT	\N	PRESENT	0
279571	279498	14085U	PARTICIPANT	\N	PRESENT	0
279572	279498	19647E	PARTICIPANT	\N	PRESENT	0
279573	279498	14065Q	PARTICIPANT	\N	PRESENT	0
279574	279498	19527W	PARTICIPANT	\N	PRESENT	0
279575	279498	14063N	PARTICIPANT	\N	PRESENT	0
279576	279498	19549D	PARTICIPANT	\N	PRESENT	0
279577	279498	19669L	PARTICIPANT	\N	PRESENT	0
279578	279498	14097Y	PARTICIPANT	\N	PRESENT	0
279579	279498	11077T	PARTICIPANT	\N	PRESENT	0
279580	279498	11056N	PARTICIPANT	\N	PRESENT	0
279581	279498	14239U	PARTICIPANT	\N	PRESENT	0
279582	279498	11083R	PARTICIPANT	\N	PRESENT	0
279583	279498	08021P	PARTICIPANT	\N	PRESENT	0
279584	279498	19329S	PARTICIPANT	\N	PRESENT	0
279585	279498	14081Q	PARTICIPANT	\N	PRESENT	0
279586	279498	14257W	PARTICIPANT	\N	PRESENT	0
279587	279498	08011M	PARTICIPANT	\N	PRESENT	0
279588	279498	11045K	PARTICIPANT	\N	PRESENT	0
279589	279498	11054L	PARTICIPANT	\N	PRESENT	0
279590	279498	14123H	PARTICIPANT	\N	PRESENT	0
279591	279498	08060W	PARTICIPANT	\N	PRESENT	0
279592	279498	19715Y	PARTICIPANT	\N	PRESENT	0
279593	279498	19503N	PARTICIPANT	\N	PRESENT	0
279594	279498	14207L	PARTICIPANT	\N	PRESENT	0
279595	279498	01058X	PARTICIPANT	\N	PRESENT	0
279596	279498	19289C	PARTICIPANT	\N	PRESENT	0
279597	279498	14241N	PARTICIPANT	\N	PRESENT	0
279598	279498	19631V	PARTICIPANT	\N	PRESENT	0
279599	279498	08043V	PARTICIPANT	\N	PRESENT	0
279600	279498	11101A	PARTICIPANT	\N	PRESENT	0
279601	279498	14109K	PARTICIPANT	\N	PRESENT	0
279602	279498	14211G	PARTICIPANT	\N	PRESENT	0
279603	279498	19545Y	PARTICIPANT	\N	PRESENT	0
279605	279498	19643A	PARTICIPANT	\N	PRESENT	0
279606	279498	19683J	PARTICIPANT	\N	PRESENT	0
279607	279498	19599P	PARTICIPANT	\N	PRESENT	0
279608	279498	11080N	PARTICIPANT	\N	PRESENT	0
279609	279498	19697Q	PARTICIPANT	\N	PRESENT	0
279610	279498	01057W	PARTICIPANT	\N	PRESENT	0
279611	279498	19301E	PARTICIPANT	\N	PRESENT	0
279612	279498	08016S	PARTICIPANT	\N	PRESENT	0
279613	279498	11065P	PARTICIPANT	\N	PRESENT	0
279614	279498	19629C	PARTICIPANT	\N	PRESENT	0
279615	279498	11043H	PARTICIPANT	\N	PRESENT	0
279616	279498	14223L	PARTICIPANT	\N	PRESENT	0
279617	279498	19725B	PARTICIPANT	\N	PRESENT	0
279618	279498	08024S	PARTICIPANT	\N	PRESENT	0
279619	279498	19727D	PARTICIPANT	\N	PRESENT	0
279620	279498	08028W	PARTICIPANT	\N	PRESENT	0
279621	279498	04033B	PARTICIPANT	\N	PRESENT	0
279622	279498	04086Q	PARTICIPANT	\N	PRESENT	0
279623	279498	19553Y	PARTICIPANT	\N	PRESENT	0
279624	279498	95030B	PARTICIPANT	\N	PRESENT	0
279625	279498	98018T	PARTICIPANT	\N	PRESENT	0
279626	279498	14093U	PARTICIPANT	\N	PRESENT	0
279627	279498	14251Q	PARTICIPANT	\N	PRESENT	0
279628	279498	11064N	PARTICIPANT	\N	PRESENT	0
279629	279498	14159V	PARTICIPANT	\N	PRESENT	0
279630	279498	08038Y	PARTICIPANT	\N	PRESENT	0
279631	279498	14107H	PARTICIPANT	\N	PRESENT	0
279632	279498	04038G	PARTICIPANT	\N	PRESENT	0
279633	279498	11033F	PARTICIPANT	\N	PRESENT	0
279634	279498	19347U	PARTICIPANT	\N	PRESENT	0
279635	279498	19649G	PARTICIPANT	\N	PRESENT	0
279636	279498	08053X	PARTICIPANT	\N	PRESENT	0
279637	279498	17589D	PARTICIPANT	\N	PRESENT	0
279638	279498	95037J	PARTICIPANT	\N	PRESENT	0
279639	279498	17637T	PARTICIPANT	\N	PRESENT	0
279640	279498	19685L	PARTICIPANT	\N	PRESENT	0
279641	279498	04057K	PARTICIPANT	\N	PRESENT	0
279642	279498	01034P	PARTICIPANT	\N	PRESENT	0
279643	279498	19691J	PARTICIPANT	\N	PRESENT	0
279644	279498	19741B	PARTICIPANT	\N	PRESENT	0
279645	279498	01062T	PARTICIPANT	\N	PRESENT	0
279646	279498	19253P	PARTICIPANT	\N	PRESENT	0
279647	279498	98022P	PARTICIPANT	\N	PRESENT	0
279648	279498	14195A	PARTICIPANT	\N	PRESENT	0
279649	279498	04047H	PARTICIPANT	\N	PRESENT	0
279650	279498	08073C	PARTICIPANT	\N	PRESENT	0
279651	279498	14039A	PARTICIPANT	\N	PRESENT	0
279652	279498	11041F	PARTICIPANT	\N	PRESENT	0
279653	279498	11109J	PARTICIPANT	\N	PRESENT	0
279654	279498	08045X	PARTICIPANT	\N	PRESENT	0
279655	279498	14021P	PARTICIPANT	\N	PRESENT	0
279656	279498	80013X	PARTICIPANT	\N	PRESENT	0
279657	279498	19295A	PARTICIPANT	\N	PRESENT	0
279658	279498	19679N	PARTICIPANT	\N	PRESENT	0
279659	279498	14071N	PARTICIPANT	\N	PRESENT	0
279660	279498	14187A	PARTICIPANT	\N	PRESENT	0
279661	279498	19713W	PARTICIPANT	\N	PRESENT	0
279662	279498	14259Y	PARTICIPANT	\N	PRESENT	0
279663	279498	19721W	PARTICIPANT	\N	PRESENT	0
271031	263474	11049P	PARTICIPANT	\N	PRESENT	0
285952	285951	19575F	PARTICIPANT	\N	PRESENT	0
285955	285951	14105F	PARTICIPANT	\N	PRESENT	0
285956	285951	14083S	PARTICIPANT	\N	PRESENT	0
285957	285951	14329V	PARTICIPANT	\N	PRESENT	0
285958	285951	14187A	PARTICIPANT	\N	PRESENT	0
285959	285951	14087W	PARTICIPANT	\N	PRESENT	0
285960	285951	19521Q	PARTICIPANT	\N	PRESENT	0
292441	287933	14281W	PARTICIPANT	\N	PRESENT	0
285962	285951	14121F	PARTICIPANT	\N	PRESENT	0
285963	285951	14039A	PARTICIPANT	\N	PRESENT	0
285964	285951	04049K	PRESIDENT	0	PRESENT	0
285965	285951	19671E	PARTICIPANT	\N	PRESENT	0
285966	285951	04088S	PARTICIPANT	\N	PRESENT	0
285967	285951	14051J	PARTICIPANT	\N	PRESENT	0
285968	285951	14157T	PARTICIPANT	\N	PRESENT	0
285969	285951	04034C	PARTICIPANT	\N	PRESENT	0
292439	287933	14069U	PARTICIPANT	\N	PRESENT	0
292440	287933	19525U	PARTICIPANT	\N	PRESENT	0
292442	287933	19565D	PARTICIPANT	\N	PRESENT	0
292443	287933	11049P	PARTICIPANT	\N	PRESENT	0
292444	287933	08010L	PARTICIPANT	\N	PRESENT	0
292445	287933	14063N	PARTICIPANT	\N	PRESENT	0
292446	287933	14257W	PARTICIPANT	\N	PRESENT	0
292447	287933	95063L	PARTICIPANT	\N	PRESENT	0
292448	287933	04045F	PARTICIPANT	\N	PRESENT	0
292648	292362	14030Q	PARTICIPANT	\N	EXCUSE	0
292649	292362	08031R	PARTICIPANT	\N	EXCUSE	0
292655	292654	11027H	PARTICIPANT	\N	PRESENT	0
292656	292654	14079W	PARTICIPANT	\N	PRESENT	0
292657	292654	04049K	PARTICIPANT	\N	PRESENT	0
292658	292654	95063L	PARTICIPANT	\N	PRESENT	0
292659	292654	04034C	PARTICIPANT	\N	PRESENT	0
292660	292654	14028W	PARTICIPANT	\N	PRESENT	0
292715	292714	04059M	PARTICIPANT	\N	PRESENT	0
292716	292714	11040E	PARTICIPANT	\N	PRESENT	0
292717	292714	11053K	PARTICIPANT	\N	PRESENT	0
292718	292714	04086Q	PARTICIPANT	\N	PRESENT	0
292719	292714	08052W	PARTICIPANT	\N	PRESENT	0
292720	292714	11070L	PARTICIPANT	\N	PRESENT	0
292721	292714	10006L	PARTICIPANT	\N	PRESENT	0
292722	292714	14041T	PARTICIPANT	\N	PRESENT	0
292726	292714	14081Q	PARTICIPANT	\N	PRESENT	0
292724	292714	14231L	PARTICIPANT	\N	PRESENT	0
292725	292714	11064N	PARTICIPANT	\N	PRESENT	0
292727	292714	14241N	PARTICIPANT	\N	PRESENT	0
292728	292714	14061L	PARTICIPANT	\N	PRESENT	0
292729	292714	14159V	PARTICIPANT	\N	PRESENT	0
292730	292714	86034E	PARTICIPANT	\N	PRESENT	0
292731	292714	08034U	PARTICIPANT	\N	PRESENT	0
292732	292714	11077T	PARTICIPANT	\N	PRESENT	0
292733	292714	12016W	PARTICIPANT	\N	PRESENT	0
292734	292714	11072N	PARTICIPANT	\N	PRESENT	0
292735	292714	05012A	PARTICIPANT	\N	PRESENT	0
292736	292714	14135M	PARTICIPANT	\N	PRESENT	0
292737	292714	04044E	PARTICIPANT	\N	PRESENT	0
295943	289178	14191V	PARTICIPANT	\N	PRESENT	0
295944	289178	17779H	PARTICIPANT	\N	PRESENT	0
295945	289178	19727D	PARTICIPANT	\N	PRESENT	0
295946	289178	19703U	PARTICIPANT	\N	PRESENT	0
295947	289178	10015M	PARTICIPANT	\N	PRESENT	0
295948	289178	08017T	PARTICIPANT	\N	PRESENT	0
295949	289178	14223L	PARTICIPANT	\N	PRESENT	0
295950	289178	19575F	PARTICIPANT	\N	PRESENT	0
295951	289178	19543W	PARTICIPANT	\N	PRESENT	0
295952	289178	14042U	PARTICIPANT	\N	PRESENT	0
295953	289178	14105F	PARTICIPANT	\N	PRESENT	0
295954	289178	08056B	PARTICIPANT	\N	PRESENT	0
295955	289178	01034P	PARTICIPANT	\N	PRESENT	0
295956	289178	14213J	PARTICIPANT	\N	PRESENT	0
295957	289178	14021P	PARTICIPANT	\N	PRESENT	0
295958	289178	14265W	PARTICIPANT	\N	PRESENT	0
295959	289178	19335Q	PARTICIPANT	\N	PRESENT	0
295960	289178	14119M	PARTICIPANT	\N	PRESENT	0
295961	289178	19415P	PARTICIPANT	\N	PRESENT	0
295962	289178	18083K	PARTICIPANT	\N	PRESENT	0
295963	289178	19723Y	PARTICIPANT	\N	PRESENT	0
295964	289178	04088S	PARTICIPANT	\N	PRESENT	0
295965	289178	19762G	PARTICIPANT	\N	PRESENT	0
295966	289178	19657G	PARTICIPANT	\N	PRESENT	0
295967	289178	14355X	PARTICIPANT	\N	PRESENT	0
295968	289178	04018C	PARTICIPANT	\N	PRESENT	0
295969	289178	19399H	PARTICIPANT	\N	PRESENT	0
295970	289178	14053L	PARTICIPANT	\N	PRESENT	0
295971	289178	19583F	PARTICIPANT	\N	PRESENT	0
295972	289178	15447F	PARTICIPANT	\N	PRESENT	0
295973	289178	87003B	PARTICIPANT	\N	PRESENT	0
295974	289178	19711U	PARTICIPANT	\N	PRESENT	0
295975	289178	11103C	PARTICIPANT	\N	PRESENT	0
295976	289178	14026U	PARTICIPANT	\N	PRESENT	0
295977	289178	19367Y	PARTICIPANT	\N	PRESENT	0
295978	289178	19747H	PARTICIPANT	\N	PRESENT	0
295979	289178	11097X	PARTICIPANT	\N	PRESENT	0
295980	289178	14083S	PARTICIPANT	\N	PRESENT	0
295981	289178	14089Y	PARTICIPANT	\N	PRESENT	0
295982	289178	14111D	PARTICIPANT	\N	PRESENT	0
295983	289178	04033B	PARTICIPANT	\N	PRESENT	0
295984	289178	19441R	PARTICIPANT	\N	PRESENT	0
295985	289178	19593H	PARTICIPANT	\N	PRESENT	0
295986	289178	19699S	PARTICIPANT	\N	PRESENT	0
295987	289178	14038Y	PARTICIPANT	\N	PRESENT	0
295988	289178	16685X	PARTICIPANT	\N	PRESENT	0
295989	289178	11054L	PARTICIPANT	\N	PRESENT	0
295990	289178	14187A	PARTICIPANT	\N	PRESENT	0
295991	289178	19549D	PARTICIPANT	\N	PRESENT	0
295992	289178	08028W	PARTICIPANT	\N	PRESENT	0
295993	289178	19735D	PARTICIPANT	\N	PRESENT	0
295994	289178	14267Y	PARTICIPANT	\N	PRESENT	0
295995	289178	19693L	PARTICIPANT	\N	PRESENT	0
295996	289178	19533U	PARTICIPANT	\N	PRESENT	0
295997	289178	14151M	PARTICIPANT	\N	PRESENT	0
295998	289178	04085P	PARTICIPANT	\N	PRESENT	0
295999	289178	14331P	PARTICIPANT	\N	PRESENT	0
296000	289178	04061F	PARTICIPANT	\N	PRESENT	0
296001	289178	19701S	PARTICIPANT	\N	PRESENT	0
296002	289178	14041T	PARTICIPANT	\N	PRESENT	0
296003	289178	14039A	PARTICIPANT	\N	PRESENT	0
296004	289178	19295A	PARTICIPANT	\N	PRESENT	0
296005	289178	12016W	PARTICIPANT	\N	PRESENT	0
296006	289178	19745F	PARTICIPANT	\N	PRESENT	0
296007	289178	08012N	PARTICIPANT	\N	PRESENT	0
296008	289178	19503N	PARTICIPANT	\N	PRESENT	0
296012	289178	14147R	PARTICIPANT	\N	PRESENT	0
296010	289178	97011G	PARTICIPANT	\N	PRESENT	0
296011	289178	08053X	PARTICIPANT	\N	PRESENT	0
296013	289178	19525U	PARTICIPANT	\N	PRESENT	0
296014	289178	19741B	PARTICIPANT	\N	PRESENT	0
296015	289178	11066Q	PARTICIPANT	\N	PRESENT	0
296016	289178	11072N	PARTICIPANT	\N	PRESENT	0
296017	289178	88008L	PARTICIPANT	\N	PRESENT	0
296018	289178	08031R	PARTICIPANT	\N	PRESENT	0
296019	289178	19621T	PARTICIPANT	\N	PRESENT	0
296020	289178	19599P	PARTICIPANT	\N	PRESENT	0
296021	289178	19673G	PARTICIPANT	\N	PRESENT	0
296022	289178	19253P	PARTICIPANT	\N	PRESENT	0
296023	289178	19675J	PARTICIPANT	\N	PRESENT	0
296024	289178	19383Y	PARTICIPANT	\N	PRESENT	0
296025	289178	95030B	PARTICIPANT	\N	PRESENT	0
296026	289178	98050T	PARTICIPANT	\N	PRESENT	0
296035	289178	11043H	PARTICIPANT	\N	PRESENT	0
296036	289178	14275Y	PARTICIPANT	\N	PRESENT	0
296037	289178	14179A	PARTICIPANT	\N	PRESENT	0
296038	289178	19511N	PARTICIPANT	\N	PRESENT	0
296039	289178	04057K	PARTICIPANT	\N	PRESENT	0
296040	289178	19467C	PARTICIPANT	\N	PRESENT	0
296041	289178	10006L	PARTICIPANT	\N	PRESENT	0
296042	289178	14030Q	PARTICIPANT	\N	PRESENT	0
296043	289178	11056N	PARTICIPANT	\N	PRESENT	0
296044	289178	11085T	PARTICIPANT	\N	PRESENT	0
296045	289178	14061L	PARTICIPANT	\N	PRESENT	0
296046	289178	14229S	PARTICIPANT	\N	PRESENT	0
296047	289178	19489J	PARTICIPANT	\N	PRESENT	0
296048	289178	19739H	PARTICIPANT	\N	PRESENT	0
296049	289178	19651A	PARTICIPANT	\N	PRESENT	0
296050	289178	14157T	PARTICIPANT	\N	PRESENT	0
296051	289178	19637C	PARTICIPANT	\N	PRESENT	0
296052	289178	14197C	PARTICIPANT	\N	PRESENT	0
296053	289178	95037J	PARTICIPANT	\N	PRESENT	0
296054	289178	19349W	PARTICIPANT	\N	PRESENT	0
296055	289178	14121F	PARTICIPANT	\N	PRESENT	0
296056	289178	19573D	PARTICIPANT	\N	PRESENT	0
296057	289178	04034C	PARTICIPANT	\N	PRESENT	0
296058	289178	14115H	PARTICIPANT	\N	PRESENT	0
296059	289178	14215L	PARTICIPANT	\N	PRESENT	0
296060	289178	19581D	PARTICIPANT	\N	PRESENT	0
296061	289178	08048B	PARTICIPANT	\N	PRESENT	0
296062	289178	08016S	PARTICIPANT	\N	PRESENT	0
296063	289178	19719D	PARTICIPANT	\N	PRESENT	0
296064	289178	19713W	PARTICIPANT	\N	PRESENT	0
271250	271232	14239U	PARTICIPANT	\N	PRESENT	0
271251	271232	04044E	PRESIDENT	0	PRESENT	0
271252	271232	19549D	PARTICIPANT	\N	PRESENT	0
271253	271232	14087W	PARTICIPANT	\N	EXCUSE	0
271254	271232	11067R	PARTICIPANT	\N	PRESENT	0
273608	273607	14205J	PARTICIPANT	\N	PRESENT	0
273610	273609	14205J	PARTICIPANT	\N	PRESENT	0
273612	273611	14205J	PARTICIPANT	\N	PRESENT	0
273616	273615	19369B	PARTICIPANT	\N	PRESENT	0
273618	273617	19369B	PARTICIPANT	\N	PRESENT	0
273621	273620	19369B	PARTICIPANT	\N	PRESENT	0
273623	273622	19369B	PARTICIPANT	\N	PRESENT	0
280762	280758	18083K	PARTICIPANT	\N	PRESENT	0
280763	280758	14357A	PARTICIPANT	\N	PRESENT	0
280764	280758	17589D	PARTICIPANT	\N	PRESENT	0
280765	280758	87003B	PARTICIPANT	\N	PRESENT	0
280766	280758	19507S	PARTICIPANT	\N	PRESENT	0
280760	280758	11103C	PARTICIPANT	\N	PRESENT	0
280761	280758	19467C	PARTICIPANT	\N	PRESENT	0
280767	280758	19563B	PARTICIPANT	\N	PRESENT	0
280768	280758	14119M	PARTICIPANT	\N	PRESENT	0
280769	280758	14265W	PARTICIPANT	\N	PRESENT	0
280770	280758	04088S	PARTICIPANT	\N	PRESENT	0
280771	280758	05012A	PARTICIPANT	\N	PRESENT	0
280772	280758	98050T	PARTICIPANT	\N	PRESENT	0
280773	280758	19739H	PARTICIPANT	\N	PRESENT	0
280774	280758	17583W	PARTICIPANT	\N	PRESENT	0
280775	280758	19679N	PARTICIPANT	\N	PRESENT	0
280777	280758	14331P	PARTICIPANT	\N	PRESENT	0
280778	280758	14107H	PARTICIPANT	\N	PRESENT	0
280779	280758	19619A	PARTICIPANT	\N	PRESENT	0
280780	280758	14173T	PARTICIPANT	\N	PRESENT	0
280809	280758	19575F	PARTICIPANT	\N	PRESENT	0
281681	281678	14053L	PARTICIPANT	\N	PRESENT	0
281682	281678	17583W	PARTICIPANT	\N	PRESENT	0
281683	281678	07034Q	PARTICIPANT	\N	PRESENT	0
281684	281678	11026G	PARTICIPANT	\N	PRESENT	0
281685	281678	19253P	PARTICIPANT	\N	PRESENT	0
281686	281678	01024M	PARTICIPANT	\N	PRESENT	0
281687	281678	04038G	PARTICIPANT	\N	PRESENT	0
281688	281678	04044E	PARTICIPANT	\N	PRESENT	0
281689	281678	01028R	PARTICIPANT	\N	PRESENT	0
281690	281678	05008E	PRESIDENT	0	PRESENT	0
281691	281678	14237S	PARTICIPANT	\N	PRESENT	0
281692	281678	14089Y	PARTICIPANT	\N	PRESENT	0
281693	281678	19729F	PARTICIPANT	\N	PRESENT	0
281694	281678	95063L	PARTICIPANT	\N	PRESENT	0
281695	281678	14179A	PARTICIPANT	\N	PRESENT	0
281696	281678	14147R	PARTICIPANT	\N	PRESENT	0
281697	281678	14211G	PARTICIPANT	\N	PRESENT	0
281698	281678	14041T	PARTICIPANT	\N	EXCUSE	0
281699	281678	14061L	PARTICIPANT	\N	PRESENT	0
281700	281678	14065Q	PARTICIPANT	\N	PRESENT	0
281701	281678	14073Q	PARTICIPANT	\N	PRESENT	0
281702	281678	08031R	PARTICIPANT	\N	PRESENT	0
281703	281678	14069U	PARTICIPANT	\N	PRESENT	0
282405	282404	11083R	PARTICIPANT	\N	PRESENT	0
282407	282406	11083R	PARTICIPANT	\N	PRESENT	0
282409	282408	11083R	PARTICIPANT	\N	PRESENT	0
282410	282408	14073Q	PARTICIPANT	\N	PRESENT	0
285383	273901	01057W	PARTICIPANT	\N	PRESENT	0
285384	273901	07029T	PARTICIPANT	\N	PRESENT	0
286068	276038	01057W	PARTICIPANT	\N	PRESENT	0
287936	287935	14239U	PARTICIPANT	\N	PRESENT	0
287937	287935	14031R	PARTICIPANT	\N	PRESENT	0
287938	287935	11067R	PARTICIPANT	\N	PRESENT	0
287939	287935	14119M	PARTICIPANT	\N	PRESENT	0
287940	287935	04044E	PRESIDENT	0	PRESENT	0
287941	284612	14239U	PARTICIPANT	\N	EXCUSE	0
287942	284612	19717B	PARTICIPANT	\N	PRESENT	0
285381	273901	14033T	PARTICIPANT	\N	PRESENT	0
285382	273901	14065Q	PARTICIPANT	\N	PRESENT	0
287943	284612	19575F	PARTICIPANT	\N	PRESENT	0
287944	284612	11103C	PARTICIPANT	\N	PRESENT	0
287945	284612	14195A	PARTICIPANT	\N	PRESENT	0
287946	284612	08052W	PARTICIPANT	\N	PRESENT	0
287947	284612	19663E	PARTICIPANT	\N	PRESENT	0
287948	284612	98024R	PARTICIPANT	\N	PRESENT	0
287949	284612	14217N	PARTICIPANT	\N	PRESENT	0
287950	284612	14281W	PARTICIPANT	\N	PRESENT	0
287951	284612	14087W	PARTICIPANT	\N	PRESENT	0
287952	284612	19521Q	PARTICIPANT	\N	PRESENT	0
287953	284612	14355X	PARTICIPANT	\N	EXCUSE	0
287954	284612	08041T	PARTICIPANT	\N	EXCUSE	0
287955	284612	19727D	PARTICIPANT	\N	PRESENT	0
287956	284612	14026U	PARTICIPANT	\N	PRESENT	0
287957	284612	19553Y	PARTICIPANT	\N	PRESENT	0
287958	284612	19569H	PARTICIPANT	\N	PRESENT	0
287959	284612	14213J	PARTICIPANT	\N	PRESENT	0
287960	284612	19723Y	PARTICIPANT	\N	PRESENT	0
287961	284612	19697Q	PARTICIPANT	\N	PRESENT	0
287962	284612	17779H	PARTICIPANT	\N	PRESENT	0
287963	284612	11067R	PARTICIPANT	\N	PRESENT	0
287964	284612	14223L	PARTICIPANT	\N	PRESENT	0
287965	284612	04092N	PRESIDENT	0	PRESENT	0
287966	284612	14119M	PARTICIPANT	\N	PRESENT	0
287967	284612	14071N	PARTICIPANT	\N	PRESENT	0
287968	284612	19679N	PARTICIPANT	\N	PRESENT	0
287969	284612	11097X	PARTICIPANT	\N	PRESENT	0
287970	284612	19703U	PARTICIPANT	\N	PRESENT	0
287971	284612	14227Q	PARTICIPANT	\N	PRESENT	0
287972	284612	19527W	PARTICIPANT	\N	PRESENT	0
287973	284612	01034P	PARTICIPANT	\N	PRESENT	0
287978	287977	14069U	PARTICIPANT	\N	PRESENT	0
287979	287977	04088S	PARTICIPANT	\N	PRESENT	0
287980	287977	04044E	PARTICIPANT	\N	PRESENT	0
287981	287977	19511N	PARTICIPANT	\N	PRESENT	0
291786	291185	08043V	PARTICIPANT	\N	EXCUSE	0
291788	291185	19735D	PARTICIPANT	\N	EXCUSE	0
291789	291185	04018C	PARTICIPANT	\N	EXCUSE	0
291790	291185	14249W	PARTICIPANT	\N	EXCUSE	0
291791	291186	08043V	PARTICIPANT	\N	EXCUSE	0
291792	291186	07033P	PARTICIPANT	\N	EXCUSE	0
291793	291186	14249W	PARTICIPANT	\N	EXCUSE	0
291794	291186	11083R	PARTICIPANT	\N	EXCUSE	0
291795	291186	14073Q	PARTICIPANT	\N	EXCUSE	0
291796	291186	19735D	PARTICIPANT	\N	EXCUSE	0
291797	291186	04018C	PARTICIPANT	\N	EXCUSE	0
292068	292067	19671E	PARTICIPANT	\N	PRESENT	0
292082	292081	11070L	PARTICIPANT	\N	PRESENT	0
292083	292081	19647E	PARTICIPANT	\N	PRESENT	0
292085	292084	11070L	PARTICIPANT	\N	PRESENT	0
292086	292084	19647E	PARTICIPANT	\N	PRESENT	0
292088	292087	11070L	PARTICIPANT	\N	PRESENT	0
292089	292087	19647E	PARTICIPANT	\N	PRESENT	0
292093	292092	08018U	PARTICIPANT	\N	PRESENT	0
292095	292094	08018U	PARTICIPANT	\N	PRESENT	0
292099	288053	08047A	PARTICIPANT	\N	EXCUSE	0
292100	288053	14028W	PARTICIPANT	\N	EXCUSE	0
292101	288053	08049C	PARTICIPANT	\N	EXCUSE	0
292102	288053	11041F	PARTICIPANT	\N	EXCUSE	0
292108	292107	96004D	PRESIDENT	0	PRESENT	0
292109	292107	14089Y	PARTICIPANT	\N	PRESENT	0
292110	292107	14079W	PARTICIPANT	\N	PRESENT	0
292111	292107	19725B	PARTICIPANT	\N	PRESENT	0
292112	292107	04097T	PARTICIPANT	\N	PRESENT	0
292113	292107	11026G	PARTICIPANT	\N	PRESENT	0
292114	292107	14237S	PARTICIPANT	\N	PRESENT	0
292115	292107	14331P	PARTICIPANT	\N	PRESENT	0
292116	292107	18083K	PARTICIPANT	\N	PRESENT	0
292117	292107	19599P	PARTICIPANT	\N	PRESENT	0
292118	292107	15447F	PARTICIPANT	\N	PRESENT	0
292119	292107	19333N	PARTICIPANT	\N	PRESENT	0
292120	292107	19551W	PARTICIPANT	\N	PRESENT	0
292121	292107	14219Q	PARTICIPANT	\N	PRESENT	0
292122	292107	08009T	PARTICIPANT	\N	PRESENT	0
292123	292107	14031R	PARTICIPANT	\N	PRESENT	0
292124	292107	14169X	PARTICIPANT	\N	PRESENT	0
292125	292107	19745F	PARTICIPANT	\N	PRESENT	0
292126	292107	19503N	PARTICIPANT	\N	PRESENT	0
292127	292107	19739H	PARTICIPANT	\N	PRESENT	0
292128	292107	14051J	PARTICIPANT	\N	PRESENT	0
292129	292107	08014Q	PARTICIPANT	\N	EXCUSE	0
292132	292107	14073Q	PARTICIPANT	\N	EXCUSE	0
292133	292107	14065Q	PARTICIPANT	\N	EXCUSE	0
292134	292107	14249W	PARTICIPANT	\N	EXCUSE	0
292135	292107	10015M	PARTICIPANT	\N	EXCUSE	0
293439	293438	01028R	PARTICIPANT	\N	PRESENT	0
293833	289104	16685X	PARTICIPANT	\N	PRESENT	0
293834	289104	14033T	PARTICIPANT	\N	PRESENT	0
293836	289104	14159V	PARTICIPANT	\N	PRESENT	0
293837	289104	08015R	PARTICIPANT	\N	PRESENT	0
293838	289104	08016S	PARTICIPANT	\N	PRESENT	0
293839	289104	02002K	PARTICIPANT	\N	PRESENT	0
293840	289104	14217N	PARTICIPANT	\N	PRESENT	0
293841	289104	19733B	PARTICIPANT	\N	PRESENT	0
293846	289104	11085T	PARTICIPANT	\N	PRESENT	0
293848	289104	14042U	PARTICIPANT	\N	PRESENT	0
293849	289104	01062T	PARTICIPANT	\N	PRESENT	0
281789	278438	14107H	PARTICIPANT	\N	PRESENT	0
295237	289110	11067R	PARTICIPANT	\N	PRESENT	0
295238	289110	01048V	PARTICIPANT	\N	PRESENT	0
295239	289110	19707Y	PARTICIPANT	\N	PRESENT	0
295241	289110	19705W	PARTICIPANT	\N	PRESENT	0
295242	289110	19503N	PARTICIPANT	\N	PRESENT	0
295243	289110	11049P	PARTICIPANT	\N	PRESENT	0
295244	289110	98050T	PARTICIPANT	\N	PRESENT	0
295245	289110	19631V	PARTICIPANT	\N	PRESENT	0
295246	289110	19527W	PARTICIPANT	\N	PRESENT	0
295247	289110	14061L	PARTICIPANT	\N	PRESENT	0
295248	289110	14063N	PARTICIPANT	\N	PRESENT	0
295249	289110	14257W	PARTICIPANT	\N	PRESENT	0
295250	289110	14357A	PARTICIPANT	\N	PRESENT	0
295251	289110	14065Q	PARTICIPANT	\N	PRESENT	0
295252	289110	19549D	PARTICIPANT	\N	PRESENT	0
295253	289110	11045K	PARTICIPANT	\N	PRESENT	0
295254	289110	14329V	PARTICIPANT	\N	PRESENT	0
295255	289110	14207L	PARTICIPANT	\N	PRESENT	0
295256	289110	14229S	PARTICIPANT	\N	PRESENT	0
295257	289110	14213J	PARTICIPANT	\N	PRESENT	0
295258	289110	19545Y	PARTICIPANT	\N	PRESENT	0
295259	289110	08015R	PARTICIPANT	\N	PRESENT	0
295260	289110	11054L	PARTICIPANT	\N	PRESENT	0
295261	289110	14217N	PARTICIPANT	\N	PRESENT	0
295262	289110	19591F	PARTICIPANT	\N	PRESENT	0
295263	289110	19719D	PARTICIPANT	\N	PRESENT	0
295264	289110	14147R	PARTICIPANT	\N	PRESENT	0
295265	289110	19289C	PARTICIPANT	\N	PRESENT	0
295266	289110	11041F	PARTICIPANT	\N	PRESENT	0
295267	289110	11066Q	PARTICIPANT	\N	PRESENT	0
295268	289110	08043V	PARTICIPANT	\N	PRESENT	0
295269	289110	19675J	PARTICIPANT	\N	PRESENT	0
295270	289110	11083R	PARTICIPANT	\N	PRESENT	0
295271	289110	19447X	PARTICIPANT	\N	PRESENT	0
295272	289110	19573D	PARTICIPANT	\N	PRESENT	0
295273	289110	19713W	PARTICIPANT	\N	PRESENT	0
295274	289110	98005N	PARTICIPANT	\N	PRESENT	0
295275	289110	19319Q	PARTICIPANT	\N	PRESENT	0
295276	289110	14119M	PARTICIPANT	\N	PRESENT	0
295277	289110	14042U	PARTICIPANT	\N	PRESENT	0
295278	289110	19691J	PARTICIPANT	\N	PRESENT	0
295279	289110	19701S	PARTICIPANT	\N	PRESENT	0
295280	289110	11053K	PARTICIPANT	\N	PRESENT	0
295281	289110	19699S	PARTICIPANT	\N	PRESENT	0
295282	289110	19737F	PARTICIPANT	\N	PRESENT	0
295283	289110	16685X	PARTICIPANT	\N	PRESENT	0
295284	289110	19709B	PARTICIPANT	\N	PRESENT	0
295285	289110	19583F	PARTICIPANT	\N	PRESENT	0
295286	289110	19467C	PARTICIPANT	\N	PRESENT	0
295287	289110	18083K	PARTICIPANT	\N	PRESENT	0
295288	289110	11085T	PARTICIPANT	\N	PRESENT	0
295289	289110	04040A	PARTICIPANT	\N	PRESENT	0
295290	289110	14030Q	PARTICIPANT	\N	PRESENT	0
295291	289110	08017T	PARTICIPANT	\N	PRESENT	0
295292	289110	01024M	PARTICIPANT	\N	PRESENT	0
295293	289110	19663E	PARTICIPANT	\N	PRESENT	0
295294	289110	19723Y	PARTICIPANT	\N	PRESENT	0
295295	289110	04043D	PARTICIPANT	\N	PRESENT	0
295296	289110	19741B	PARTICIPANT	\N	PRESENT	0
295339	289110	19399H	PARTICIPANT	\N	PRESENT	0
295298	289110	11033F	PARTICIPANT	\N	PRESENT	0
295299	289110	89017R	PARTICIPANT	\N	PRESENT	0
295358	289110	11026G	PARTICIPANT	\N	PRESENT	0
295301	289110	19745F	PARTICIPANT	\N	PRESENT	0
295302	289110	14255U	PARTICIPANT	\N	PRESENT	0
295303	289110	11065P	PARTICIPANT	\N	PRESENT	0
295305	289110	19577H	PARTICIPANT	\N	PRESENT	0
295306	289110	02002K	PARTICIPANT	\N	PRESENT	0
295307	289110	19657G	PARTICIPANT	\N	PRESENT	0
295309	289110	14251Q	PARTICIPANT	\N	PRESENT	0
295310	289110	19441R	PARTICIPANT	\N	PRESENT	0
295311	289110	08068F	PARTICIPANT	\N	PRESENT	0
295312	289110	14001X	PARTICIPANT	\N	PRESENT	0
295314	289110	14034U	PARTICIPANT	\N	PRESENT	0
295332	289110	14219Q	PARTICIPANT	\N	PRESENT	0
295335	289110	11077T	PARTICIPANT	\N	PRESENT	0
295336	289110	05008E	PARTICIPANT	\N	PRESENT	0
295337	289110	95067Q	PARTICIPANT	\N	PRESENT	0
295338	289110	11010L	PARTICIPANT	\N	PRESENT	0
295367	289110	07034Q	PARTICIPANT	\N	PRESENT	0
295543	289111	11070L	PARTICIPANT	\N	PRESENT	0
295544	289111	19737F	PARTICIPANT	\N	PRESENT	0
295545	289111	14215L	PARTICIPANT	\N	PRESENT	0
295546	289111	19749K	PARTICIPANT	\N	PRESENT	0
295547	289111	19583F	PARTICIPANT	\N	PRESENT	0
295548	289111	19367Y	PARTICIPANT	\N	PRESENT	0
295549	289111	19711U	PARTICIPANT	\N	PRESENT	0
295550	289111	04043D	PARTICIPANT	\N	PRESENT	0
295551	289111	19577H	PARTICIPANT	\N	PRESENT	0
295552	289111	14237S	PARTICIPANT	\N	PRESENT	0
295553	289111	11031D	PARTICIPANT	\N	PRESENT	0
295554	289111	14147R	PARTICIPANT	\N	PRESENT	0
295555	289111	98005N	PARTICIPANT	\N	PRESENT	0
295556	289111	14231L	PARTICIPANT	\N	PRESENT	0
295557	289111	14030Q	PARTICIPANT	\N	PRESENT	0
295558	289111	19667J	PARTICIPANT	\N	PRESENT	0
295559	289111	19741B	PARTICIPANT	\N	PRESENT	0
295560	289111	08017T	PARTICIPANT	\N	PRESENT	0
295561	289111	08043V	PARTICIPANT	\N	PRESENT	0
295562	289111	11067R	PARTICIPANT	\N	PRESENT	0
295563	289111	19649G	PARTICIPANT	\N	PRESENT	0
295564	289111	11045K	PARTICIPANT	\N	PRESENT	0
295565	289111	19543W	PARTICIPANT	\N	PRESENT	0
295566	289111	19629C	PARTICIPANT	\N	PRESENT	0
295567	289111	19599P	PARTICIPANT	\N	PRESENT	0
295568	289111	08019V	PARTICIPANT	\N	PRESENT	0
295569	289111	07034Q	PARTICIPANT	\N	PRESENT	0
295570	289111	19715Y	PARTICIPANT	\N	PRESENT	0
295571	289111	11033F	PARTICIPANT	\N	PRESENT	0
295572	289111	19693L	PARTICIPANT	\N	PRESENT	0
295573	289111	19573D	PARTICIPANT	\N	PRESENT	0
295574	289111	19447X	PARTICIPANT	\N	PRESENT	0
295575	289111	05008E	PARTICIPANT	\N	PRESENT	0
295576	289111	19631V	PARTICIPANT	\N	PRESENT	0
295577	289111	19657G	PARTICIPANT	\N	PRESENT	0
295578	289111	14061L	PARTICIPANT	\N	PRESENT	0
295579	289111	19701S	PARTICIPANT	\N	PRESENT	0
295580	289111	04086Q	PARTICIPANT	\N	PRESENT	0
295581	289111	14065Q	PARTICIPANT	\N	PRESENT	0
295582	289111	08015R	PARTICIPANT	\N	PRESENT	0
295583	289111	14219Q	PARTICIPANT	\N	PRESENT	0
295586	289111	19289C	PARTICIPANT	\N	PRESENT	0
295587	289111	19253P	PARTICIPANT	\N	PRESENT	0
295588	289111	11077T	PARTICIPANT	\N	PRESENT	0
295589	289111	19467C	PARTICIPANT	\N	PRESENT	0
295590	289111	11097X	PARTICIPANT	\N	PRESENT	0
295591	289111	14073Q	PARTICIPANT	\N	PRESENT	0
295592	289111	19663E	PARTICIPANT	\N	PRESENT	0
295593	289111	11010L	PARTICIPANT	\N	PRESENT	0
295594	289111	19643A	PARTICIPANT	\N	PRESENT	0
295595	289111	19647E	PARTICIPANT	\N	PRESENT	0
295596	289111	04035D	PARTICIPANT	\N	PRESENT	0
295597	289111	14033T	PARTICIPANT	\N	PRESENT	0
295609	289111	01048V	PARTICIPANT	\N	PRESENT	0
295614	289111	17589D	PARTICIPANT	\N	PRESENT	0
295615	289111	19611R	PARTICIPANT	\N	PRESENT	0
295616	289111	14255U	PARTICIPANT	\N	PRESENT	0
295617	289111	19695N	PARTICIPANT	\N	PRESENT	0
295618	289111	14249W	PARTICIPANT	\N	PRESENT	0
295619	289111	04085P	PARTICIPANT	\N	PRESENT	0
279664	279498	14042U	PARTICIPANT	\N	PRESENT	0
279665	279498	19673G	PARTICIPANT	\N	PRESENT	0
279666	279498	11048N	PARTICIPANT	\N	PRESENT	0
279667	279498	01025N	PARTICIPANT	\N	PRESENT	0
279668	279498	19369B	PARTICIPANT	\N	PRESENT	0
279669	279498	08017T	PARTICIPANT	\N	PRESENT	0
279670	279498	14069U	PARTICIPANT	\N	PRESENT	0
279671	279498	05008E	PARTICIPANT	\N	PRESENT	0
279672	279498	19591F	PARTICIPANT	\N	PRESENT	0
279673	279498	04042C	PARTICIPANT	\N	PRESENT	0
279674	279498	14073Q	PARTICIPANT	\N	PRESENT	0
279675	279498	89017R	PARTICIPANT	\N	PRESENT	0
279676	279498	14267Y	PARTICIPANT	\N	PRESENT	0
279677	279498	04044E	PARTICIPANT	\N	PRESENT	0
279678	279498	14221J	PARTICIPANT	\N	PRESENT	0
279679	279498	14173T	PARTICIPANT	\N	PRESENT	0
279680	279498	19447X	PARTICIPANT	\N	PRESENT	0
279681	279498	19335Q	PARTICIPANT	\N	PRESENT	0
279682	279498	19745F	PARTICIPANT	\N	PRESENT	0
279683	279498	19531S	PARTICIPANT	\N	PRESENT	0
279684	279498	10015M	PARTICIPANT	\N	PRESENT	0
279685	279498	14201E	PARTICIPANT	\N	PRESENT	0
279686	279498	19719D	PARTICIPANT	\N	PRESENT	0
279687	279498	14031R	PARTICIPANT	\N	PRESENT	0
279688	279498	11072N	PARTICIPANT	\N	PRESENT	0
279689	279498	14219Q	PARTICIPANT	\N	PRESENT	0
279690	279498	08061X	PARTICIPANT	\N	PRESENT	0
279691	279498	14030Q	PARTICIPANT	\N	PRESENT	0
279692	279498	04070G	PARTICIPANT	\N	PRESENT	0
279693	279498	11099A	PARTICIPANT	\N	PRESENT	0
279694	279498	11026G	PARTICIPANT	\N	PRESENT	0
279695	279498	19349W	PARTICIPANT	\N	PRESENT	0
279696	279498	14225N	PARTICIPANT	\N	PRESENT	0
279697	279498	14227Q	PARTICIPANT	\N	PRESENT	0
279698	279498	95063L	PARTICIPANT	\N	PRESENT	0
279699	279498	08049C	PARTICIPANT	\N	PRESENT	0
279700	279498	19489J	PARTICIPANT	\N	PRESENT	0
279701	279498	19667J	PARTICIPANT	\N	PRESENT	0
279702	279498	19729F	PARTICIPANT	\N	PRESENT	0
279703	279498	14169X	PARTICIPANT	\N	PRESENT	0
279704	279498	14327T	PARTICIPANT	\N	PRESENT	0
279705	279498	11070L	PARTICIPANT	\N	PRESENT	0
279706	279498	19575F	PARTICIPANT	\N	PRESENT	0
279707	279498	19441R	PARTICIPANT	\N	PRESENT	0
279708	279498	19733B	PARTICIPANT	\N	PRESENT	0
279709	279498	04018C	PARTICIPANT	\N	PRESENT	0
279710	279498	04049K	PARTICIPANT	\N	PRESENT	0
279711	279498	14119M	PARTICIPANT	\N	PRESENT	0
279712	279498	19621T	PARTICIPANT	\N	PRESENT	0
279713	279498	14028W	PARTICIPANT	\N	PRESENT	0
279714	279498	19479G	PARTICIPANT	\N	PRESENT	0
279715	279498	19563B	PARTICIPANT	\N	PRESENT	0
279716	279498	14053L	PARTICIPANT	\N	PRESENT	0
279717	279498	04008A	PARTICIPANT	\N	PRESENT	0
279718	279498	14329V	PARTICIPANT	\N	PRESENT	0
279719	279498	19543W	PARTICIPANT	\N	PRESENT	0
279720	279498	14357A	PARTICIPANT	\N	PRESENT	0
279721	279498	11040E	PARTICIPANT	\N	PRESENT	0
279722	279498	11063M	PARTICIPANT	\N	PRESENT	0
279723	279498	08020N	PARTICIPANT	\N	PRESENT	0
279724	279498	19507S	PARTICIPANT	\N	PRESENT	0
279725	279498	02002K	PARTICIPANT	\N	PRESENT	0
279726	279498	01048V	PARTICIPANT	\N	PRESENT	0
279727	279498	18083K	PARTICIPANT	\N	PRESENT	0
279728	279498	19467C	PARTICIPANT	\N	PRESENT	0
279729	279498	14038Y	PARTICIPANT	\N	PRESENT	0
279730	279498	19415P	PARTICIPANT	\N	PRESENT	0
279731	279498	14033T	PARTICIPANT	\N	PRESENT	0
279732	279498	14135M	PARTICIPANT	\N	PRESENT	0
279733	279498	07029T	PARTICIPANT	\N	PRESENT	0
279734	279498	04059M	PARTICIPANT	\N	PRESENT	0
279735	279498	08018U	PARTICIPANT	\N	PRESENT	0
279781	279498	14213J	PARTICIPANT	\N	PRESENT	0
279737	279498	19521Q	PARTICIPANT	\N	PRESENT	0
279738	279498	95067Q	PARTICIPANT	\N	PRESENT	0
279739	279498	08069G	PARTICIPANT	\N	PRESENT	0
279740	279498	19663E	PARTICIPANT	\N	PRESENT	0
279741	279498	19251M	PARTICIPANT	\N	PRESENT	0
279742	279498	92040Q	PARTICIPANT	\N	PRESENT	0
279743	279498	05012A	PARTICIPANT	\N	PRESENT	0
279778	279498	14255U	PARTICIPANT	\N	PRESENT	0
279782	279498	98023Q	PARTICIPANT	\N	PRESENT	0
279746	279498	19657G	PARTICIPANT	\N	PRESENT	0
279747	279498	96004D	PARTICIPANT	\N	PRESENT	0
279748	279498	14061L	PARTICIPANT	\N	PRESENT	0
279749	279498	19383Y	PARTICIPANT	\N	PRESENT	0
279750	279498	19701S	PARTICIPANT	\N	PRESENT	0
279751	279498	19675J	PARTICIPANT	\N	PRESENT	0
279752	279498	11103C	PARTICIPANT	\N	PRESENT	0
279753	279498	07033P	PARTICIPANT	\N	PRESENT	0
279754	279498	14217N	PARTICIPANT	\N	PRESENT	0
279755	279498	04061F	PARTICIPANT	\N	PRESENT	0
279756	279498	14199E	PARTICIPANT	\N	PRESENT	0
279757	279498	10006L	PARTICIPANT	\N	PRESENT	0
279758	279498	14079W	PARTICIPANT	\N	PRESENT	0
279759	279498	98024R	PARTICIPANT	\N	PRESENT	0
279760	279498	04071H	PARTICIPANT	\N	PRESENT	0
279761	279498	08034U	PARTICIPANT	\N	PRESENT	0
279762	279498	11053K	PARTICIPANT	\N	PRESENT	0
279763	279498	14083S	PARTICIPANT	\N	PRESENT	0
279764	279498	14249W	PARTICIPANT	\N	PRESENT	0
279765	279498	04043D	PARTICIPANT	\N	PRESENT	0
279766	279498	11097X	PARTICIPANT	\N	PRESENT	0
279767	279498	14215L	PARTICIPANT	\N	PRESENT	0
279768	279498	08068F	PARTICIPANT	\N	PRESENT	0
279769	279498	95041E	PARTICIPANT	\N	PRESENT	0
279770	279498	19533U	PARTICIPANT	\N	PRESENT	0
279771	279498	14193X	PARTICIPANT	\N	PRESENT	0
279772	279498	19671E	PARTICIPANT	\N	PRESENT	0
279773	279498	17583W	PARTICIPANT	\N	PRESENT	0
279774	279498	14253S	PARTICIPANT	\N	PRESENT	0
279775	279498	19747H	PARTICIPANT	\N	PRESENT	0
279776	279498	97011G	PARTICIPANT	\N	PRESENT	0
279777	279498	08047A	PARTICIPANT	\N	PRESENT	0
279779	279498	19515S	PARTICIPANT	\N	PRESENT	0
279780	279498	11090Q	PARTICIPANT	\N	PRESENT	0
279783	279498	16685X	PARTICIPANT	\N	PRESENT	0
279784	279498	04045F	PARTICIPANT	\N	PRESENT	0
279785	279498	08035V	PARTICIPANT	\N	PRESENT	0
279786	279498	14355X	PARTICIPANT	\N	PRESENT	0
279787	279498	07004J	PARTICIPANT	\N	PRESENT	0
279788	279498	04035D	PARTICIPANT	\N	PRESENT	0
279789	279498	98005N	PARTICIPANT	\N	PRESENT	0
279790	279498	14265W	PARTICIPANT	\N	PRESENT	0
279791	279498	19709B	PARTICIPANT	\N	PRESENT	0
279792	279498	11110B	PARTICIPANT	\N	PRESENT	0
279793	279498	98050T	PARTICIPANT	\N	PRESENT	0
279794	279498	19573D	PARTICIPANT	\N	PRESENT	0
279795	279498	14205J	PARTICIPANT	\N	PRESENT	0
279796	279498	14231L	PARTICIPANT	\N	PRESENT	0
279804	279498	14179A	PARTICIPANT	\N	PRESENT	0
279807	279498	08044W	PARTICIPANT	\N	PRESENT	0
279817	279498	08062Y	PARTICIPANT	\N	PRESENT	0
279818	279498	19511N	PARTICIPANT	\N	PRESENT	0
279819	279498	14034U	PARTICIPANT	\N	PRESENT	0
279820	279498	14147R	PARTICIPANT	\N	PRESENT	0
279821	279498	19569H	PARTICIPANT	\N	PRESENT	0
279828	276025	04043D	PARTICIPANT	\N	PRESENT	0
280126	273865	11070L	PARTICIPANT	\N	PRESENT	0
280127	273865	19593H	PARTICIPANT	\N	PRESENT	0
280128	273865	19758L	PARTICIPANT	\N	PRESENT	0
280129	273865	14051J	PARTICIPANT	\N	PRESENT	0
280130	273865	19599P	PARTICIPANT	\N	PRESENT	0
280131	273865	19525U	PARTICIPANT	\N	PRESENT	0
280132	273865	19737F	PARTICIPANT	\N	PRESENT	0
280133	273865	19441R	PARTICIPANT	\N	PRESENT	0
280134	273865	14105F	PARTICIPANT	\N	PRESENT	0
280135	273865	14157T	PARTICIPANT	\N	PRESENT	0
280136	273865	87003B	PARTICIPANT	\N	PRESENT	0
280137	273865	95062K	PARTICIPANT	\N	PRESENT	0
280138	273865	19515S	PARTICIPANT	\N	PRESENT	0
280139	273865	11049P	PARTICIPANT	\N	PRESENT	0
280140	273865	14069U	PARTICIPANT	\N	PRESENT	0
280141	273865	19731Y	PARTICIPANT	\N	PRESENT	0
280142	273865	04018C	PARTICIPANT	\N	PRESENT	0
280143	273865	14331P	PARTICIPANT	\N	PRESENT	0
280144	273865	14053L	PARTICIPANT	\N	PRESENT	0
280145	273865	11056N	PARTICIPANT	\N	PRESENT	0
280146	273865	02002K	PARTICIPANT	\N	PRESENT	0
280147	273865	97011G	PARTICIPANT	\N	PRESENT	0
280148	273865	95030B	PARTICIPANT	\N	PRESENT	0
280149	273865	19443T	PARTICIPANT	\N	PRESENT	0
280150	273865	19349W	PARTICIPANT	\N	PRESENT	0
280151	273865	11064N	PARTICIPANT	\N	PRESENT	0
280152	273865	19713W	PARTICIPANT	\N	PRESENT	0
280153	273865	14030Q	PARTICIPANT	\N	PRESENT	0
280154	273865	19747H	PARTICIPANT	\N	PRESENT	0
280155	273865	14031R	PARTICIPANT	\N	PRESENT	0
283419	283418	11053K	PARTICIPANT	\N	PRESENT	0
283420	283418	14159V	PARTICIPANT	\N	PRESENT	0
283421	283418	05012A	PARTICIPANT	\N	PRESENT	0
296065	289178	14219Q	PARTICIPANT	\N	PRESENT	0
296069	289178	14207L	PARTICIPANT	\N	PRESENT	0
296070	289178	19749K	PARTICIPANT	\N	PRESENT	0
296071	289178	14257W	PARTICIPANT	\N	PRESENT	0
296072	289178	19347U	PARTICIPANT	\N	PRESENT	0
296073	295816	04043D	PARTICIPANT	\N	PRESENT	0
296076	296075	04043D	PARTICIPANT	\N	PRESENT	0
296078	289178	14107H	PARTICIPANT	\N	PRESENT	0
296079	289178	14193X	PARTICIPANT	\N	PRESENT	0
296080	289178	11012A	PARTICIPANT	\N	PRESENT	0
296081	289178	14059S	PARTICIPANT	\N	PRESENT	0
296084	289178	19591F	PARTICIPANT	\N	PRESENT	0
296087	289178	08062Y	PARTICIPANT	\N	PRESENT	0
296088	289178	14073Q	PARTICIPANT	\N	PRESENT	0
296089	289178	01058X	PARTICIPANT	\N	PRESENT	0
296090	289178	19527W	PARTICIPANT	\N	PRESENT	0
296091	289178	11026G	PARTICIPANT	\N	PRESENT	0
296092	289178	19689Q	PARTICIPANT	\N	PRESENT	0
296093	289178	11041F	PARTICIPANT	\N	PRESENT	0
296094	289178	01024M	PARTICIPANT	\N	PRESENT	0
296095	289178	08019V	PARTICIPANT	\N	PRESENT	0
296096	289178	19479G	PARTICIPANT	\N	PRESENT	0
296097	289178	19629C	PARTICIPANT	\N	PRESENT	0
296098	289178	19387D	PARTICIPANT	\N	PRESENT	0
296099	289178	11064N	PARTICIPANT	\N	PRESENT	0
296101	289178	19507S	PARTICIPANT	\N	PRESENT	0
296102	289178	17589D	PARTICIPANT	\N	PRESENT	0
296103	289178	14033T	PARTICIPANT	\N	PRESENT	0
296104	289178	08045X	PARTICIPANT	\N	PRESENT	0
296105	289178	08034U	PARTICIPANT	\N	PRESENT	0
296106	289178	19737F	PARTICIPANT	\N	PRESENT	0
296107	289178	19685L	PARTICIPANT	\N	PRESENT	0
296108	289178	08055A	PARTICIPANT	\N	PRESENT	0
296285	289179	86034E	PARTICIPANT	\N	PRESENT	0
296286	289179	14235Q	PARTICIPANT	\N	PRESENT	0
296287	289179	19565D	PARTICIPANT	\N	PRESENT	0
296288	289179	19347U	PARTICIPANT	\N	PRESENT	0
296289	289179	14107H	PARTICIPANT	\N	PRESENT	0
296290	289179	19591F	PARTICIPANT	\N	PRESENT	0
296291	289179	14227Q	PARTICIPANT	\N	PRESENT	0
296292	289179	11026G	PARTICIPANT	\N	PRESENT	0
296293	289179	04092N	PARTICIPANT	\N	PRESENT	0
296294	289179	14121F	PARTICIPANT	\N	PRESENT	0
296295	289179	08045X	PARTICIPANT	\N	PRESENT	0
296296	289179	87003B	PARTICIPANT	\N	PRESENT	0
296297	289179	14021P	PARTICIPANT	\N	PRESENT	0
296298	289179	95030B	PARTICIPANT	\N	PRESENT	0
296299	289179	14069U	PARTICIPANT	\N	PRESENT	0
296300	289179	19711U	PARTICIPANT	\N	PRESENT	0
296301	289179	14223L	PARTICIPANT	\N	PRESENT	0
296302	289179	19527W	PARTICIPANT	\N	PRESENT	0
296303	289179	19631V	PARTICIPANT	\N	PRESENT	0
296304	289179	19747H	PARTICIPANT	\N	PRESENT	0
296305	289179	19725B	PARTICIPANT	\N	PRESENT	0
296306	289179	14265W	PARTICIPANT	\N	PRESENT	0
296307	289179	19762G	PARTICIPANT	\N	PRESENT	0
296308	289179	01058X	PARTICIPANT	\N	PRESENT	0
296309	289179	14257W	PARTICIPANT	\N	PRESENT	0
296310	289179	19525U	PARTICIPANT	\N	PRESENT	0
296311	289179	08055A	PARTICIPANT	\N	PRESENT	0
296312	289179	11056N	PARTICIPANT	\N	PRESENT	0
296313	289179	19760E	PARTICIPANT	\N	PRESENT	0
296314	289179	04085P	PARTICIPANT	\N	PRESENT	0
296315	289179	11049P	PARTICIPANT	\N	PRESENT	0
296316	289179	19349W	PARTICIPANT	\N	PRESENT	0
296317	289179	14115H	PARTICIPANT	\N	PRESENT	0
296318	289179	08061X	PARTICIPANT	\N	PRESENT	0
296319	289179	08039A	PARTICIPANT	\N	PRESENT	0
296320	289179	19651A	PARTICIPANT	\N	PRESENT	0
296321	289179	11104D	PARTICIPANT	\N	PRESENT	0
296322	289179	19693L	PARTICIPANT	\N	PRESENT	0
296323	289179	08034U	PARTICIPANT	\N	PRESENT	0
296324	289179	08060W	PARTICIPANT	\N	PRESENT	0
296325	289179	14357A	PARTICIPANT	\N	PRESENT	0
296326	289179	08073C	PARTICIPANT	\N	PRESENT	0
296327	289179	19507S	PARTICIPANT	\N	PRESENT	0
296328	289179	17589D	PARTICIPANT	\N	PRESENT	0
296329	289179	08048B	PARTICIPANT	\N	PRESENT	0
296330	289179	04088S	PARTICIPANT	\N	PRESENT	0
296331	289179	08062Y	PARTICIPANT	\N	PRESENT	0
296332	289179	08019V	PARTICIPANT	\N	PRESENT	0
296333	289179	04097T	PARTICIPANT	\N	PRESENT	0
296334	289179	14081Q	PARTICIPANT	\N	PRESENT	0
296335	289179	19583F	PARTICIPANT	\N	PRESENT	0
296336	289179	14195A	PARTICIPANT	\N	PRESENT	0
296337	289179	95037J	PARTICIPANT	\N	PRESENT	0
296338	289179	14157T	PARTICIPANT	\N	PRESENT	0
296339	289179	92040Q	PARTICIPANT	\N	PRESENT	0
296340	289179	14173T	PARTICIPANT	\N	PRESENT	0
296341	289179	14026U	PARTICIPANT	\N	PRESENT	0
296342	289179	08028W	PARTICIPANT	\N	PRESENT	0
296343	289179	14147R	PARTICIPANT	\N	PRESENT	0
296344	289179	14211G	PARTICIPANT	\N	PRESENT	0
296345	289179	14033T	PARTICIPANT	\N	PRESENT	0
296346	289179	97011G	PARTICIPANT	\N	PRESENT	0
296347	289179	98018T	PARTICIPANT	\N	PRESENT	0
296348	289179	99004R	PARTICIPANT	\N	PRESENT	0
296349	289179	11097X	PARTICIPANT	\N	PRESENT	0
296350	289179	95062K	PARTICIPANT	\N	PRESENT	0
296351	289179	11080N	PARTICIPANT	\N	PRESENT	0
296352	289179	19515S	PARTICIPANT	\N	PRESENT	0
296353	289179	11033F	PARTICIPANT	\N	PRESENT	0
296354	289179	04038G	PARTICIPANT	\N	PRESENT	0
296355	289179	11040E	PARTICIPANT	\N	PRESENT	0
296356	289179	11031D	PARTICIPANT	\N	PRESENT	0
296357	289179	12041X	PARTICIPANT	\N	PRESENT	0
296358	289179	19593H	PARTICIPANT	\N	PRESENT	0
296359	289179	19695N	PARTICIPANT	\N	PRESENT	0
296360	289179	19758L	PARTICIPANT	\N	PRESENT	0
296361	289179	04045F	PARTICIPANT	\N	PRESENT	0
296362	289179	98029W	PARTICIPANT	\N	PRESENT	0
296363	289179	14039A	PARTICIPANT	\N	PRESENT	0
296364	289179	11083R	PARTICIPANT	\N	PRESENT	0
296365	289179	14111D	PARTICIPANT	\N	PRESENT	0
296366	289179	19545Y	PARTICIPANT	\N	PRESENT	0
296367	289179	17637T	PARTICIPANT	\N	PRESENT	0
296368	289179	95063L	PARTICIPANT	\N	PRESENT	0
296369	289179	11012A	PARTICIPANT	\N	PRESENT	0
296370	289179	19253P	PARTICIPANT	\N	PRESENT	0
296371	289179	04042C	PARTICIPANT	\N	PRESENT	0
296372	289179	19629C	PARTICIPANT	\N	PRESENT	0
296373	289179	19387D	PARTICIPANT	\N	PRESENT	0
296374	289179	14201E	PARTICIPANT	\N	PRESENT	0
296375	289179	15447F	PARTICIPANT	\N	PRESENT	0
296376	289179	88008L	PARTICIPANT	\N	PRESENT	0
296377	289179	19563B	PARTICIPANT	\N	PRESENT	0
296378	289179	19719D	PARTICIPANT	\N	PRESENT	0
296379	289179	11043H	PARTICIPANT	\N	PRESENT	0
296380	289179	14191V	PARTICIPANT	\N	PRESENT	0
296381	289179	14251Q	PARTICIPANT	\N	PRESENT	0
296382	289179	14034U	PARTICIPANT	\N	PRESENT	0
296383	289179	14259Y	PARTICIPANT	\N	PRESENT	0
296384	289179	01057W	PARTICIPANT	\N	PRESENT	0
296385	289179	04059M	PARTICIPANT	\N	PRESENT	0
296386	289179	19731Y	PARTICIPANT	\N	PRESENT	0
296387	289179	11048N	PARTICIPANT	\N	PRESENT	0
296388	289179	19703U	PARTICIPANT	\N	PRESENT	0
296389	289179	11010L	PARTICIPANT	\N	PRESENT	0
296390	289179	19687N	PARTICIPANT	\N	PRESENT	0
296391	289179	14031R	PARTICIPANT	\N	PRESENT	0
296392	289179	14239U	PARTICIPANT	\N	PRESENT	0
296393	289179	14199E	PARTICIPANT	\N	PRESENT	0
296394	289179	08031R	PARTICIPANT	\N	PRESENT	0
296395	289179	19251M	PARTICIPANT	\N	PRESENT	0
296396	289179	19575F	PARTICIPANT	\N	PRESENT	0
296397	289179	01028R	PARTICIPANT	\N	PRESENT	0
296398	289179	98035U	PARTICIPANT	\N	PRESENT	0
296399	289179	19533U	PARTICIPANT	\N	PRESENT	0
296400	289179	14229S	PARTICIPANT	\N	PRESENT	0
296401	289179	10006L	PARTICIPANT	\N	PRESENT	0
296402	289179	08052W	PARTICIPANT	\N	PRESENT	0
296403	289179	11090Q	PARTICIPANT	\N	PRESENT	0
296404	289179	14051J	PARTICIPANT	\N	PRESENT	0
296405	289179	14053L	PARTICIPANT	\N	PRESENT	0
296406	289179	19715Y	PARTICIPANT	\N	PRESENT	0
296407	289179	12016W	PARTICIPANT	\N	PRESENT	0
296408	289179	04033B	PARTICIPANT	\N	PRESENT	0
296409	289179	14187A	PARTICIPANT	\N	PRESENT	0
296410	289179	08024S	PARTICIPANT	\N	PRESENT	0
296411	289179	19649G	PARTICIPANT	\N	PRESENT	0
296412	289179	14197C	PARTICIPANT	\N	PRESENT	0
296413	289179	19531S	PARTICIPANT	\N	PRESENT	0
296414	289179	11045K	PARTICIPANT	\N	PRESENT	0
296415	289179	19727D	PARTICIPANT	\N	PRESENT	0
296416	289179	19647E	PARTICIPANT	\N	PRESENT	0
286279	286278	14147R	PARTICIPANT	\N	PRESENT	0
290536	290535	96004D	PARTICIPANT	\N	PRESENT	0
290537	290535	14097Y	PARTICIPANT	\N	PRESENT	0
290538	290535	14237S	PARTICIPANT	\N	PRESENT	0
290544	290535	95063L	PARTICIPANT	\N	PRESENT	0
290545	290535	19701S	PARTICIPANT	\N	PRESENT	0
293850	289104	19253P	PARTICIPANT	\N	PRESENT	0
293851	289104	14031R	PARTICIPANT	\N	PRESENT	0
293852	289104	19387D	PARTICIPANT	\N	PRESENT	0
293853	289104	19691J	PARTICIPANT	\N	PRESENT	0
293854	289104	19383Y	PARTICIPANT	\N	PRESENT	0
293855	289104	08048B	PARTICIPANT	\N	PRESENT	0
293856	289104	14065Q	PARTICIPANT	\N	PRESENT	0
293857	289104	14109K	PARTICIPANT	\N	PRESENT	0
293858	289104	14223L	PARTICIPANT	\N	PRESENT	0
293859	289104	19760E	PARTICIPANT	\N	PRESENT	0
293935	289105	19719D	PARTICIPANT	\N	PRESENT	0
293936	289105	11040E	PARTICIPANT	\N	PRESENT	0
293937	289105	19760E	PARTICIPANT	\N	PRESENT	0
293938	289105	19758L	PARTICIPANT	\N	PRESENT	0
293939	289105	11067R	PARTICIPANT	\N	PRESENT	0
293940	289105	19649G	PARTICIPANT	\N	PRESENT	0
293941	289105	19689Q	PARTICIPANT	\N	PRESENT	0
293942	289105	19531S	PARTICIPANT	\N	PRESENT	0
293943	289105	19545Y	PARTICIPANT	\N	PRESENT	0
293944	289105	11074Q	PARTICIPANT	\N	PRESENT	0
293945	289105	14215L	PARTICIPANT	\N	PRESENT	0
293946	289105	07004J	PARTICIPANT	\N	PRESENT	0
293947	289105	19443T	PARTICIPANT	\N	PRESENT	0
293948	289105	19629C	PARTICIPANT	\N	PRESENT	0
293949	289105	19737F	PARTICIPANT	\N	PRESENT	0
293950	289105	08052W	PARTICIPANT	\N	PRESENT	0
293951	289105	14085U	PARTICIPANT	\N	PRESENT	0
293952	289105	04071H	PARTICIPANT	\N	PRESENT	0
293953	289105	19679N	PARTICIPANT	\N	PRESENT	0
293954	289105	14211G	PARTICIPANT	\N	PRESENT	0
293955	289105	19349W	PARTICIPANT	\N	PRESENT	0
293956	289105	14119M	PARTICIPANT	\N	PRESENT	0
293957	289105	19447X	PARTICIPANT	\N	PRESENT	0
293958	289105	14147R	PARTICIPANT	\N	PRESENT	0
293959	289105	14231L	PARTICIPANT	\N	PRESENT	0
293960	289105	07029T	PARTICIPANT	\N	PRESENT	0
293961	289105	11043H	PARTICIPANT	\N	PRESENT	0
293962	289105	19713W	PARTICIPANT	\N	PRESENT	0
293963	289105	01057W	PARTICIPANT	\N	PRESENT	0
293964	289105	14173T	PARTICIPANT	\N	PRESENT	0
293965	289105	14217N	PARTICIPANT	\N	PRESENT	0
293966	289105	11097X	PARTICIPANT	\N	PRESENT	0
293967	289105	19415P	PARTICIPANT	\N	PRESENT	0
293968	289105	14213J	PARTICIPANT	\N	PRESENT	0
293969	289105	14223L	PARTICIPANT	\N	PRESENT	0
293970	289105	88008L	PARTICIPANT	\N	PRESENT	0
293971	289105	19741B	PARTICIPANT	\N	PRESENT	0
293972	289105	14059S	PARTICIPANT	\N	PRESENT	0
293973	289105	19701S	PARTICIPANT	\N	PRESENT	0
293974	289105	14042U	PARTICIPANT	\N	PRESENT	0
293975	289105	17637T	PARTICIPANT	\N	PRESENT	0
293976	289105	04097T	PARTICIPANT	\N	PRESENT	0
293977	289105	04033B	PARTICIPANT	\N	PRESENT	0
293978	289105	14065Q	PARTICIPANT	\N	PRESENT	0
293979	289105	04086Q	PARTICIPANT	\N	PRESENT	0
293980	289105	14034U	PARTICIPANT	\N	PRESENT	0
293981	289105	19563B	PARTICIPANT	\N	PRESENT	0
293982	289105	11048N	PARTICIPANT	\N	PRESENT	0
293983	289105	14033T	PARTICIPANT	\N	PRESENT	0
293984	289105	14265W	PARTICIPANT	\N	PRESENT	0
293985	289105	08034U	PARTICIPANT	\N	PRESENT	0
293986	289105	18083K	PARTICIPANT	\N	PRESENT	0
293987	289105	11090Q	PARTICIPANT	\N	PRESENT	0
293988	289105	14083S	PARTICIPANT	\N	PRESENT	0
293989	289105	19573D	PARTICIPANT	\N	PRESENT	0
293990	289105	19479G	PARTICIPANT	\N	PRESENT	0
293991	289105	08038Y	PARTICIPANT	\N	PRESENT	0
297193	295308	04061F	PARTICIPANT	\N	PRESENT	0
297194	295308	99004R	PARTICIPANT	\N	PRESENT	0
297195	295308	07004J	PARTICIPANT	\N	EXCUSE	0
297196	295308	08014Q	PARTICIPANT	\N	EXCUSE	0
297197	295774	19383Y	PARTICIPANT	\N	PRESENT	0
297198	295774	19333N	PARTICIPANT	\N	PRESENT	0
297199	295774	14103D	PARTICIPANT	\N	PRESENT	0
297200	295774	95062K	PARTICIPANT	\N	PRESENT	0
297201	295774	19387D	PARTICIPANT	\N	PRESENT	0
297202	295774	08055A	PARTICIPANT	\N	PRESENT	0
297203	295774	19599P	PARTICIPANT	\N	PRESENT	0
297204	295774	19637C	PARTICIPANT	\N	PRESENT	0
297205	295774	18083K	PARTICIPANT	\N	PRESENT	0
297206	295774	19551W	PARTICIPANT	\N	PRESENT	0
297207	295774	15447F	PARTICIPANT	\N	PRESENT	0
297208	295774	05012A	PARTICIPANT	\N	PRESENT	0
293933	289105	11072N	PARTICIPANT	\N	PRESENT	0
293934	289105	08011M	PARTICIPANT	\N	PRESENT	0
297209	295774	14051J	PARTICIPANT	\N	PRESENT	0
297210	295774	08060W	PARTICIPANT	\N	PRESENT	0
297211	295774	08009T	PRESIDENT	0	PRESENT	0
297212	295774	19737F	PARTICIPANT	\N	PRESENT	0
297213	295774	14157T	PARTICIPANT	\N	PRESENT	0
297214	295774	96004D	PARTICIPANT	\N	EXCUSE	0
297215	295774	19685L	PARTICIPANT	\N	EXCUSE	0
297216	295774	14038Y	PARTICIPANT	\N	PRESENT	0
297217	295774	17583W	PARTICIPANT	\N	PRESENT	0
297218	295774	14031R	PARTICIPANT	\N	PRESENT	0
297305	294986	19443T	PARTICIPANT	\N	PRESENT	0
297220	295774	14237S	PARTICIPANT	\N	PRESENT	0
297221	295774	19733B	PARTICIPANT	\N	PRESENT	0
297222	295836	11077T	PARTICIPANT	\N	PRESENT	0
297223	295836	17779H	PARTICIPANT	\N	PRESENT	0
297224	295836	11031D	PARTICIPANT	\N	PRESENT	0
297225	295836	14195A	PARTICIPANT	\N	PRESENT	0
297226	295836	19335Q	PARTICIPANT	\N	PRESENT	0
297227	295836	19527W	PARTICIPANT	\N	PRESENT	0
297228	295836	19723Y	PARTICIPANT	\N	PRESENT	0
297229	295774	19701S	PARTICIPANT	\N	PRESENT	0
297230	295774	14219Q	PARTICIPANT	\N	PRESENT	0
297231	295774	19503N	PARTICIPANT	\N	PRESENT	0
297232	295774	07034Q	PARTICIPANT	\N	PRESENT	0
297233	295774	04097T	PARTICIPANT	\N	PRESENT	0
297234	295774	19745F	PARTICIPANT	\N	PRESENT	0
297235	295774	19347U	PARTICIPANT	\N	PRESENT	0
297236	295774	14093U	PARTICIPANT	\N	PRESENT	0
297252	294985	14097Y	PARTICIPANT	\N	PRESENT	0
297253	294985	95067Q	PARTICIPANT	\N	PRESENT	0
297254	294985	19443T	PARTICIPANT	\N	PRESENT	0
297255	294985	01062T	PARTICIPANT	\N	PRESENT	0
297256	294985	14079W	PARTICIPANT	\N	PRESENT	0
297257	294985	11027H	PARTICIPANT	\N	PRESENT	0
297258	294985	04042C	PRESIDENT	0	PRESENT	0
297259	294985	11066Q	PARTICIPANT	\N	PRESENT	0
297260	294985	19319Q	PARTICIPANT	\N	PRESENT	0
297261	294985	14105F	PARTICIPANT	\N	PRESENT	0
297262	294985	14267Y	PARTICIPANT	\N	PRESENT	0
297263	294985	08053X	PARTICIPANT	\N	PRESENT	0
297264	294985	97011G	PARTICIPANT	\N	PRESENT	0
297265	294985	14211G	PARTICIPANT	\N	PRESENT	0
297266	294985	19583F	PARTICIPANT	\N	PRESENT	0
297267	294985	08047A	PARTICIPANT	\N	PRESENT	0
297268	294985	19251M	PARTICIPANT	\N	PRESENT	0
297269	294985	98018T	PARTICIPANT	\N	PRESENT	0
297270	294985	08061X	PARTICIPANT	\N	PRESENT	0
297271	295836	19760E	PARTICIPANT	\N	PRESENT	0
297272	294985	19421M	PARTICIPANT	\N	PRESENT	0
297273	294985	95030B	PARTICIPANT	\N	PRESENT	0
297274	294985	01058X	PARTICIPANT	\N	PRESENT	0
297275	294985	12041X	PARTICIPANT	\N	PRESENT	0
297321	294986	08061X	PARTICIPANT	\N	PRESENT	0
297277	294985	11064N	PARTICIPANT	\N	PRESENT	0
297278	294985	98050T	PARTICIPANT	\N	PRESENT	0
297279	295308	89017R	PARTICIPANT	\N	PRESENT	0
297280	295774	19549D	PARTICIPANT	\N	PRESENT	0
297281	295774	19681G	PARTICIPANT	\N	PRESENT	0
297282	295774	08024S	PARTICIPANT	\N	PRESENT	0
297283	295774	11065P	PARTICIPANT	\N	PRESENT	0
297284	294985	08056B	PARTICIPANT	\N	PRESENT	0
297285	294985	19709B	PARTICIPANT	\N	PRESENT	0
297286	294985	11041F	PARTICIPANT	\N	PRESENT	0
297306	294986	12041X	PARTICIPANT	\N	PRESENT	0
297307	294986	95030B	PARTICIPANT	\N	PRESENT	0
297308	294986	14079W	PARTICIPANT	\N	PRESENT	0
297309	294986	01058X	PARTICIPANT	\N	PRESENT	0
297310	294986	04040A	PARTICIPANT	\N	PRESENT	0
297311	294986	11027H	PARTICIPANT	\N	PRESENT	0
297312	294986	04042C	PRESIDENT	0	PRESENT	0
297313	294986	11066Q	PARTICIPANT	\N	PRESENT	0
297314	294986	08056B	PARTICIPANT	\N	PRESENT	0
297315	294986	95037J	PARTICIPANT	\N	PRESENT	0
297316	294986	19421M	PARTICIPANT	\N	PRESENT	0
297317	294986	19709B	PARTICIPANT	\N	PRESENT	0
297318	294986	14193X	PARTICIPANT	\N	PRESENT	0
297319	294986	08053X	PARTICIPANT	\N	PRESENT	0
297320	294986	97011G	PARTICIPANT	\N	PRESENT	0
284388	281721	19717B	PARTICIPANT	\N	PRESENT	0
284392	281721	14195A	PARTICIPANT	\N	PRESENT	0
284390	281721	11103C	PARTICIPANT	\N	PRESENT	0
284391	281721	19575F	PARTICIPANT	\N	PRESENT	0
284393	281721	08052W	PARTICIPANT	\N	PRESENT	0
284394	281721	98024R	PARTICIPANT	\N	PRESENT	0
284395	281721	14217N	PARTICIPANT	\N	PRESENT	0
284396	281721	14281W	PARTICIPANT	\N	PRESENT	0
284397	281721	14087W	PARTICIPANT	\N	PRESENT	0
284398	281721	19521Q	PARTICIPANT	\N	PRESENT	0
284399	281721	08048B	PARTICIPANT	\N	EXCUSE	0
284400	281721	08041T	PARTICIPANT	\N	EXCUSE	0
284401	281721	19727D	PARTICIPANT	\N	PRESENT	0
284402	281721	14026U	PARTICIPANT	\N	PRESENT	0
284403	281721	19691J	PARTICIPANT	\N	PRESENT	0
284404	281721	19569H	PARTICIPANT	\N	PRESENT	0
284405	281721	14213J	PARTICIPANT	\N	PRESENT	0
284406	281721	19715Y	PARTICIPANT	\N	PRESENT	0
284407	281721	19723Y	PARTICIPANT	\N	PRESENT	0
284408	281721	19657G	PARTICIPANT	\N	PRESENT	0
284409	281721	11067R	PARTICIPANT	\N	PRESENT	0
284410	281721	14223L	PARTICIPANT	\N	PRESENT	0
284411	281721	04092N	PRESIDENT	0	PRESENT	0
284412	281721	14119M	PARTICIPANT	\N	PRESENT	0
284413	281721	14071N	PARTICIPANT	\N	PRESENT	0
284414	281721	19679N	PARTICIPANT	\N	PRESENT	0
284415	281721	11097X	PARTICIPANT	\N	PRESENT	0
284416	281721	19703U	PARTICIPANT	\N	PRESENT	0
284417	281721	14227Q	PARTICIPANT	\N	PRESENT	0
284418	281721	01034P	PARTICIPANT	\N	PRESENT	0
284419	281721	19527W	PARTICIPANT	\N	PRESENT	0
284420	281721	19663E	PARTICIPANT	\N	EXCUSE	0
284421	281721	04045F	PARTICIPANT	\N	PRESENT	0
284989	284822	11081P	PARTICIPANT	\N	EXCUSE	0
284993	284822	14221J	PARTICIPANT	\N	PRESENT	0
284997	284816	14221J	PARTICIPANT	\N	PRESENT	0
285984	285983	97011G	PARTICIPANT	\N	PRESENT	0
297799	289183	14053L	PARTICIPANT	\N	PRESENT	0
297800	289183	10006L	PARTICIPANT	\N	PRESENT	0
297801	289183	14059S	PARTICIPANT	\N	PRESENT	0
297802	289183	14329V	PARTICIPANT	\N	PRESENT	0
297803	289183	04049K	PARTICIPANT	\N	PRESENT	0
297804	289183	14265W	PARTICIPANT	\N	PRESENT	0
297805	289183	19467C	PARTICIPANT	\N	PRESENT	0
297806	289183	14097Y	PARTICIPANT	\N	PRESENT	0
297807	289183	19760E	PARTICIPANT	\N	PRESENT	0
297808	289183	19657G	PARTICIPANT	\N	PRESENT	0
297809	289183	19569H	PARTICIPANT	\N	PRESENT	0
297810	289183	14115H	PARTICIPANT	\N	PRESENT	0
297811	289183	95062K	PARTICIPANT	\N	PRESENT	0
297812	289183	14187A	PARTICIPANT	\N	PRESENT	0
297813	289183	04088S	PARTICIPANT	\N	PRESENT	0
297814	289183	14231L	PARTICIPANT	\N	PRESENT	0
297815	289183	14029X	PARTICIPANT	\N	PRESENT	0
297816	289183	14026U	PARTICIPANT	\N	PRESENT	0
297817	289183	11027H	PARTICIPANT	\N	PRESENT	0
297818	289183	04045F	PARTICIPANT	\N	PRESENT	0
297819	289183	19651A	PARTICIPANT	\N	PRESENT	0
297820	289183	14227Q	PARTICIPANT	\N	PRESENT	0
297821	289183	01034P	PARTICIPANT	\N	PRESENT	0
297822	289183	14357A	PARTICIPANT	\N	PRESENT	0
297823	289183	19715Y	PARTICIPANT	\N	PRESENT	0
297824	289183	19447X	PARTICIPANT	\N	PRESENT	0
297825	289183	19527W	PARTICIPANT	\N	PRESENT	0
297826	289183	19723Y	PARTICIPANT	\N	PRESENT	0
297827	289183	19693L	PARTICIPANT	\N	PRESENT	0
297828	289183	14215L	PARTICIPANT	\N	PRESENT	0
297829	289183	19387D	PARTICIPANT	\N	PRESENT	0
297830	289183	95063L	PARTICIPANT	\N	PRESENT	0
297831	289183	11104D	PARTICIPANT	\N	PRESENT	0
297832	289183	14239U	PARTICIPANT	\N	PRESENT	0
297833	289183	14197C	PARTICIPANT	\N	PRESENT	0
297834	289183	19319Q	PARTICIPANT	\N	PRESENT	0
297835	289183	19441R	PARTICIPANT	\N	PRESENT	0
297836	289183	14179A	PARTICIPANT	\N	PRESENT	0
297837	289183	14249W	PARTICIPANT	\N	PRESENT	0
297838	289183	19691J	PARTICIPANT	\N	PRESENT	0
297839	289183	08015R	PARTICIPANT	\N	PRESENT	0
297840	289183	14083S	PARTICIPANT	\N	PRESENT	0
297841	289183	95067Q	PARTICIPANT	\N	PRESENT	0
297842	289183	19335Q	PARTICIPANT	\N	PRESENT	0
297843	289183	19733B	PARTICIPANT	\N	PRESENT	0
297844	289183	14034U	PARTICIPANT	\N	PRESENT	0
297845	289183	07029T	PARTICIPANT	\N	PRESENT	0
297848	295636	11070L	PARTICIPANT	\N	PRESENT	0
297849	295636	19760E	PARTICIPANT	\N	PRESENT	0
297850	295636	19715Y	PARTICIPANT	\N	PRESENT	0
297851	295636	14281W	PARTICIPANT	\N	PRESENT	0
297852	295636	11067R	PARTICIPANT	\N	PRESENT	0
297853	295636	08052W	PARTICIPANT	\N	PRESENT	0
297854	295636	14227Q	PARTICIPANT	\N	PRESENT	0
297855	295636	04092N	PARTICIPANT	\N	PRESENT	0
297856	295636	19521Q	PARTICIPANT	\N	PRESENT	0
297857	295636	14087W	PARTICIPANT	\N	PRESENT	0
297858	295636	04045F	PARTICIPANT	\N	PRESENT	0
297859	295636	19569H	PARTICIPANT	\N	PRESENT	0
297860	295636	19479G	PARTICIPANT	\N	PRESENT	0
297861	295636	19697Q	PARTICIPANT	\N	PRESENT	0
297862	295636	19553Y	PARTICIPANT	\N	PRESENT	0
297863	295636	11012A	PARTICIPANT	\N	PRESENT	0
297865	295636	19631V	PARTICIPANT	\N	PRESENT	0
297868	295636	14195A	PARTICIPANT	\N	PRESENT	0
297872	295636	14059S	PARTICIPANT	\N	PRESENT	0
297797	289183	11097X	PARTICIPANT	\N	PRESENT	0
297798	289183	14071N	PARTICIPANT	\N	PRESENT	0
297875	295636	98050T	PARTICIPANT	\N	PRESENT	0
297876	295636	14329V	PARTICIPANT	\N	PRESENT	0
297877	295636	14217N	PARTICIPANT	\N	PRESENT	0
297878	295636	11103C	PARTICIPANT	\N	PRESENT	0
297879	295636	19711U	PARTICIPANT	\N	PRESENT	0
297880	295636	19693L	PARTICIPANT	\N	PRESENT	0
297881	295636	14041T	PARTICIPANT	\N	PRESENT	0
297882	295636	14033T	PARTICIPANT	\N	PRESENT	0
297883	295636	04088S	PARTICIPANT	\N	PRESENT	0
297884	295636	19741B	PARTICIPANT	\N	PRESENT	0
297885	295636	19723Y	PARTICIPANT	\N	PRESENT	0
297886	295636	19515S	PARTICIPANT	\N	PRESENT	0
297887	295636	04071H	PARTICIPANT	\N	PRESENT	0
297888	295636	19727D	PARTICIPANT	\N	PRESENT	0
297889	295636	19737F	PARTICIPANT	\N	PRESENT	0
297890	295636	11097X	PARTICIPANT	\N	PRESENT	0
297891	295636	19421M	PARTICIPANT	\N	PRESENT	0
297892	295636	14215L	PARTICIPANT	\N	PRESENT	0
297893	295636	19621T	PARTICIPANT	\N	PRESENT	0
297894	295636	14071N	PARTICIPANT	\N	PRESENT	0
297895	295636	95062K	PARTICIPANT	\N	PRESENT	0
297896	295636	19691J	PARTICIPANT	\N	PRESENT	0
297897	295636	04057K	PARTICIPANT	\N	PRESENT	0
297898	295636	19441R	PARTICIPANT	\N	PRESENT	0
297899	295636	14219Q	PARTICIPANT	\N	PRESENT	0
297900	295636	14083S	PARTICIPANT	\N	PRESENT	0
297901	295636	95063L	PARTICIPANT	\N	PRESENT	0
297902	295636	14039A	PARTICIPANT	\N	PRESENT	0
297903	295636	10006L	PARTICIPANT	\N	PRESENT	0
297904	295636	19611R	PARTICIPANT	\N	PRESENT	0
297905	295636	19367Y	PARTICIPANT	\N	PRESENT	0
297906	295636	19335Q	PARTICIPANT	\N	PRESENT	0
297907	295636	19575F	PARTICIPANT	\N	PRESENT	0
297908	295636	19319Q	PARTICIPANT	\N	PRESENT	0
297909	295636	97011G	PARTICIPANT	\N	PRESENT	0
297910	295636	07029T	PARTICIPANT	\N	PRESENT	0
297911	295636	19725B	PARTICIPANT	\N	PRESENT	0
297912	295636	14073Q	PARTICIPANT	\N	PRESENT	0
297913	295636	19747H	PARTICIPANT	\N	PRESENT	0
297914	295636	01057W	PARTICIPANT	\N	PRESENT	0
297915	295636	14121F	PARTICIPANT	\N	PRESENT	0
297916	295636	11031D	PARTICIPANT	\N	PRESENT	0
297917	295636	98005N	PARTICIPANT	\N	PRESENT	0
297918	295636	19679N	PARTICIPANT	\N	PRESENT	0
297919	295636	19735D	PARTICIPANT	\N	PRESENT	0
297920	295636	19525U	PARTICIPANT	\N	PRESENT	0
297921	295636	01034P	PARTICIPANT	\N	PRESENT	0
297922	295636	19657G	PARTICIPANT	\N	PRESENT	0
297923	295636	14119M	PARTICIPANT	\N	PRESENT	0
297924	295636	19701S	PARTICIPANT	\N	PRESENT	0
297925	295636	19543W	PARTICIPANT	\N	PRESENT	0
297926	295636	19663E	PARTICIPANT	\N	PRESENT	0
297927	295636	08031R	PARTICIPANT	\N	PRESENT	0
297928	295636	19581D	PARTICIPANT	\N	PRESENT	0
297929	295636	14357A	PARTICIPANT	\N	PRESENT	0
297930	295636	08010L	PARTICIPANT	\N	PRESENT	0
297931	295636	14038Y	PARTICIPANT	\N	PRESENT	0
297933	297932	04086Q	PARTICIPANT	\N	PRESENT	0
297934	295636	11085T	PARTICIPANT	\N	PRESENT	0
297935	295636	14157T	PARTICIPANT	\N	PRESENT	0
297936	295636	19758L	PARTICIPANT	\N	PRESENT	0
297937	295636	19709B	PARTICIPANT	\N	PRESENT	0
297938	295636	19387D	PARTICIPANT	\N	PRESENT	0
297939	295636	04086Q	PARTICIPANT	\N	PRESENT	0
271626	271625	04033B	PARTICIPANT	\N	PRESENT	0
271628	271627	14237S	PARTICIPANT	\N	PRESENT	0
271629	271627	04092N	PARTICIPANT	\N	PRESENT	0
271630	271627	19709B	PARTICIPANT	\N	PRESENT	0
271631	271627	95067Q	PARTICIPANT	\N	PRESENT	0
271632	271627	08056B	PARTICIPANT	\N	PRESENT	0
271633	271627	08020N	PARTICIPANT	\N	PRESENT	0
271634	271627	11026G	PARTICIPANT	\N	PRESENT	0
271635	271627	04086Q	PARTICIPANT	\N	PRESENT	0
271636	271627	19637C	PARTICIPANT	\N	PRESENT	0
271637	271627	14079W	PARTICIPANT	\N	PRESENT	0
271704	270525	14255U	PARTICIPANT	\N	PRESENT	0
271662	270395	80027E	PARTICIPANT	\N	EXCUSE	0
271663	270395	19701S	PARTICIPANT	\N	EXCUSE	0
271664	270395	19685L	PARTICIPANT	\N	EXCUSE	0
271665	270525	19443T	PARTICIPANT	\N	PRESENT	0
271666	270525	14133K	PARTICIPANT	\N	PRESENT	0
271667	270525	11080N	PARTICIPANT	\N	PRESENT	0
271668	270525	14235Q	PARTICIPANT	\N	PRESENT	0
271669	270525	14079W	PARTICIPANT	\N	PRESENT	0
271670	270525	04040A	PARTICIPANT	\N	PRESENT	0
271671	270525	08058D	PARTICIPANT	\N	PRESENT	0
271672	270525	11027H	PARTICIPANT	\N	PRESENT	0
271673	270525	04042C	PRESIDENT	0	PRESENT	0
271674	270525	19251M	PARTICIPANT	\N	PRESENT	0
271675	270525	19721W	PARTICIPANT	\N	PRESENT	0
271676	270525	14089Y	PARTICIPANT	\N	PRESENT	0
271677	270525	98018T	PARTICIPANT	\N	PRESENT	0
271678	270525	19421M	PARTICIPANT	\N	PRESENT	0
271679	270525	14267Y	PARTICIPANT	\N	PRESENT	0
271680	270525	11064N	PARTICIPANT	\N	PRESENT	0
271681	270525	08049C	PARTICIPANT	\N	PRESENT	0
271682	270525	14193X	PARTICIPANT	\N	PRESENT	0
271683	270525	08053X	PARTICIPANT	\N	PRESENT	0
271684	270525	14211G	PARTICIPANT	\N	PRESENT	0
271685	270525	08047A	PARTICIPANT	\N	PRESENT	0
271686	270525	95030B	PARTICIPANT	\N	PRESENT	0
271687	270525	04034C	PARTICIPANT	\N	PRESENT	0
271688	270525	16685X	PARTICIPANT	\N	PRESENT	0
271689	270525	11066Q	PARTICIPANT	\N	PRESENT	0
271690	270525	97011G	PARTICIPANT	\N	PRESENT	0
271691	270525	08061X	PARTICIPANT	\N	PRESENT	0
271692	270525	98022P	PARTICIPANT	\N	PRESENT	0
271694	270525	19709B	PARTICIPANT	\N	PRESENT	0
271695	270525	98029W	PARTICIPANT	\N	PRESENT	0
271696	270525	14028W	PARTICIPANT	\N	PRESENT	0
271697	270525	11054L	PARTICIPANT	\N	PRESENT	0
271698	270525	08034U	PARTICIPANT	\N	PRESENT	0
271699	270395	14221J	PARTICIPANT	\N	PRESENT	0
271702	270525	95037J	PARTICIPANT	\N	PRESENT	0
271703	270525	01062T	PARTICIPANT	\N	PRESENT	0
271864	270396	14221J	PARTICIPANT	\N	PRESENT	0
272045	270528	11070L	PARTICIPANT	\N	PRESENT	0
272091	270528	04085P	PARTICIPANT	\N	PRESENT	0
272092	270528	11056N	PARTICIPANT	\N	PRESENT	0
272093	270528	11031D	PARTICIPANT	\N	PRESENT	0
272094	270528	11040E	PARTICIPANT	\N	PRESENT	0
272095	270528	19347U	PARTICIPANT	\N	PRESENT	0
272096	270528	14051J	PARTICIPANT	\N	PRESENT	0
272097	270528	11063M	PARTICIPANT	\N	PRESENT	0
272098	270528	19503N	PARTICIPANT	\N	PRESENT	0
272099	270528	08024S	PARTICIPANT	\N	PRESENT	0
272100	270528	19725B	PARTICIPANT	\N	PRESENT	0
272101	270528	19525U	PARTICIPANT	\N	PRESENT	0
272102	270528	19333N	PARTICIPANT	\N	PRESENT	0
272103	270528	14063N	PARTICIPANT	\N	PRESENT	0
272104	270528	19599P	PARTICIPANT	\N	PRESENT	0
272105	270528	14229S	PARTICIPANT	\N	PRESENT	0
272106	270528	19659J	PARTICIPANT	\N	PRESENT	0
272107	270528	07004J	PARTICIPANT	\N	PRESENT	0
272108	270528	19551W	PARTICIPANT	\N	PRESENT	0
272109	270528	95062K	PARTICIPANT	\N	PRESENT	0
272110	270528	14157T	PARTICIPANT	\N	PRESENT	0
272111	270528	19515S	PARTICIPANT	\N	PRESENT	0
272112	270528	19723Y	PARTICIPANT	\N	PRESENT	0
272113	270528	88008L	PARTICIPANT	\N	PRESENT	0
272114	270528	14111D	PARTICIPANT	\N	PRESENT	0
272116	270528	19295A	PARTICIPANT	\N	PRESENT	0
272117	270528	08015R	PARTICIPANT	\N	PRESENT	0
272118	270528	19549D	PARTICIPANT	\N	PRESENT	0
272119	270528	14105F	PARTICIPANT	\N	PRESENT	0
272120	270528	19733B	PARTICIPANT	\N	PRESENT	0
272121	270528	19507S	PARTICIPANT	\N	PRESENT	0
272122	270528	14029X	PARTICIPANT	\N	PRESENT	0
272123	270528	19563B	PARTICIPANT	\N	PRESENT	0
272124	270528	11065P	PARTICIPANT	\N	PRESENT	0
272125	270528	14159V	PARTICIPANT	\N	PRESENT	0
272126	270528	14038Y	PARTICIPANT	\N	PRESENT	0
272127	270528	19695N	PARTICIPANT	\N	PRESENT	0
272128	270528	19565D	PARTICIPANT	\N	PRESENT	0
272129	270528	14031R	PARTICIPANT	\N	PRESENT	0
272130	270528	14219Q	PARTICIPANT	\N	PRESENT	0
272131	270528	14107H	PARTICIPANT	\N	PRESENT	0
272132	270528	19383Y	PARTICIPANT	\N	PRESENT	0
272133	270528	01025N	PARTICIPANT	\N	PRESENT	0
272134	270528	14103D	PARTICIPANT	\N	PRESENT	0
272135	270528	14207L	PARTICIPANT	\N	PRESENT	0
272136	270528	14121F	PARTICIPANT	\N	PRESENT	0
272138	270528	14223L	PARTICIPANT	\N	PRESENT	0
272139	270528	01024M	PARTICIPANT	\N	PRESENT	0
272140	270528	14109K	PARTICIPANT	\N	PRESENT	0
272141	270528	14331P	PARTICIPANT	\N	PRESENT	0
272142	270528	11109J	PARTICIPANT	\N	PRESENT	0
272143	270528	08056B	PARTICIPANT	\N	PRESENT	0
272144	270528	08060W	PARTICIPANT	\N	PRESENT	0
272145	270528	19747H	PARTICIPANT	\N	PRESENT	0
272147	270397	80027E	PARTICIPANT	\N	EXCUSE	0
272148	270397	19701S	PARTICIPANT	\N	EXCUSE	0
272149	270397	19685L	PARTICIPANT	\N	EXCUSE	0
272150	270528	14028W	PARTICIPANT	\N	PRESENT	0
272151	270528	19631V	PARTICIPANT	\N	PRESENT	0
272152	270528	14257W	PARTICIPANT	\N	PRESENT	0
272153	270528	08061X	PARTICIPANT	\N	PRESENT	0
272162	270528	14227Q	PARTICIPANT	\N	PRESENT	0
272166	270528	17779H	PARTICIPANT	\N	PRESENT	0
272171	270528	08017T	PARTICIPANT	\N	PRESENT	0
272176	270528	14021P	PARTICIPANT	\N	PRESENT	0
272179	270528	14030Q	PARTICIPANT	\N	PRESENT	0
272181	270528	19741B	PARTICIPANT	\N	PRESENT	0
272182	270528	14197C	PARTICIPANT	\N	PRESENT	0
272183	270528	14093U	PARTICIPANT	\N	PRESENT	0
272184	270528	98022P	PARTICIPANT	\N	PRESENT	0
272185	270528	08020N	PARTICIPANT	\N	PRESENT	0
272186	270528	14151M	PARTICIPANT	\N	PRESENT	0
272187	270528	19479G	PARTICIPANT	\N	PRESENT	0
272188	270528	11104D	PARTICIPANT	\N	PRESENT	0
272189	270528	19467C	PARTICIPANT	\N	PRESENT	0
272190	270528	14265W	PARTICIPANT	\N	PRESENT	0
272191	270528	01028R	PARTICIPANT	\N	PRESENT	0
272192	270528	97011G	PARTICIPANT	\N	PRESENT	0
272193	270528	18083K	PARTICIPANT	\N	PRESENT	0
272194	270528	19447X	PARTICIPANT	\N	PRESENT	0
272195	270528	19545Y	PARTICIPANT	\N	PRESENT	0
272196	270528	14225N	PARTICIPANT	\N	PRESENT	0
272197	270528	14215L	PARTICIPANT	\N	PRESENT	0
272198	270528	11103C	PARTICIPANT	\N	PRESENT	0
272199	270528	19527W	PARTICIPANT	\N	PRESENT	0
272200	270528	08038Y	PARTICIPANT	\N	PRESENT	0
272201	270528	19649G	PARTICIPANT	\N	PRESENT	0
272202	270528	19667J	PARTICIPANT	\N	PRESENT	0
272203	270528	14115H	PARTICIPANT	\N	PRESENT	0
272204	270528	08010L	PARTICIPANT	\N	PRESENT	0
272205	270528	19689Q	PARTICIPANT	\N	PRESENT	0
272208	270528	19651A	PARTICIPANT	\N	PRESENT	0
272209	270528	14073Q	PARTICIPANT	\N	PRESENT	0
272210	270528	14267Y	PARTICIPANT	\N	PRESENT	0
272211	270528	08009T	PARTICIPANT	\N	PRESENT	0
272212	270528	05008E	PARTICIPANT	\N	PRESENT	0
272213	270528	19745F	PARTICIPANT	\N	PRESENT	0
272214	270528	19671E	PARTICIPANT	\N	PRESENT	0
272215	270528	19573D	PARTICIPANT	\N	PRESENT	0
272216	270528	14069U	PARTICIPANT	\N	PRESENT	0
272217	270528	19721W	PARTICIPANT	\N	PRESENT	0
272218	270528	98050T	PARTICIPANT	\N	PRESENT	0
272219	270528	19699S	PARTICIPANT	\N	PRESENT	0
272220	270528	01048V	PARTICIPANT	\N	PRESENT	0
272221	270528	04059M	PARTICIPANT	\N	PRESENT	0
272222	270528	14085U	PARTICIPANT	\N	PRESENT	0
272223	270528	14041T	PARTICIPANT	\N	PRESENT	0
272224	270528	19399H	PARTICIPANT	\N	PRESENT	0
272225	270528	19489J	PARTICIPANT	\N	PRESENT	0
272226	270528	95030B	PARTICIPANT	\N	PRESENT	0
272229	270528	19647E	PARTICIPANT	\N	PRESENT	0
286004	284624	19703U	PARTICIPANT	\N	PRESENT	0
286005	284793	19611R	PARTICIPANT	\N	PRESENT	0
296419	289179	14085U	PARTICIPANT	\N	PRESENT	0
296420	289179	04047H	PARTICIPANT	\N	PRESENT	0
296421	289179	11101A	PARTICIPANT	\N	PRESENT	0
296422	289179	17779H	PARTICIPANT	\N	PRESENT	0
296423	289179	19489J	PARTICIPANT	\N	PRESENT	0
296424	289179	19413M	PARTICIPANT	\N	PRESENT	0
296425	289179	19573D	PARTICIPANT	\N	PRESENT	0
296426	289179	98005N	PARTICIPANT	\N	PRESENT	0
296427	289179	08035V	PARTICIPANT	\N	PRESENT	0
296428	289179	14225N	PARTICIPANT	\N	PRESENT	0
296429	289179	14119M	PARTICIPANT	\N	PRESENT	0
296430	289179	11067R	PARTICIPANT	\N	PRESENT	0
296431	289179	14151M	PARTICIPANT	\N	PRESENT	0
296432	289179	19503N	PARTICIPANT	\N	PRESENT	0
296433	289179	11027H	PARTICIPANT	\N	PRESENT	0
296434	289179	19551W	PARTICIPANT	\N	PRESENT	0
296435	289179	08047A	PARTICIPANT	\N	PRESENT	0
296436	289179	14063N	PARTICIPANT	\N	PRESENT	0
296437	289179	14105F	PARTICIPANT	\N	PRESENT	0
296438	289179	14038Y	PARTICIPANT	\N	PRESENT	0
296439	289179	19723Y	PARTICIPANT	\N	PRESENT	0
296440	289179	14097Y	PARTICIPANT	\N	PRESENT	0
296441	289179	19467C	PARTICIPANT	\N	PRESENT	0
296442	289179	11041F	PARTICIPANT	\N	PRESENT	0
296443	289179	11066Q	PARTICIPANT	\N	PRESENT	0
296444	289179	01062T	PARTICIPANT	\N	PRESENT	0
296445	289179	19415P	PARTICIPANT	\N	PRESENT	0
296446	289179	19549D	PARTICIPANT	\N	PRESENT	0
296447	289179	80013X	PARTICIPANT	\N	PRESENT	0
296448	289179	08038Y	PARTICIPANT	\N	PRESENT	0
296449	289179	08017T	PARTICIPANT	\N	PRESENT	0
296450	289179	14281W	PARTICIPANT	\N	PRESENT	0
296451	289179	14213J	PARTICIPANT	\N	PRESENT	0
296452	289179	08053X	PARTICIPANT	\N	PRESENT	0
296453	289179	19333N	PARTICIPANT	\N	PRESENT	0
296454	289179	14329V	PARTICIPANT	\N	PRESENT	0
296455	289179	19675J	PARTICIPANT	\N	PRESENT	0
296456	289179	14109K	PARTICIPANT	\N	PRESENT	0
296457	289179	19383Y	PARTICIPANT	\N	PRESENT	0
296458	289179	19689Q	PARTICIPANT	\N	PRESENT	0
296459	289179	19599P	PARTICIPANT	\N	PRESENT	0
296460	289179	19701S	PARTICIPANT	\N	PRESENT	0
296461	289179	04018C	PARTICIPANT	\N	PRESENT	0
296462	289179	89017R	PARTICIPANT	\N	PRESENT	0
296417	289179	04044E	PARTICIPANT	\N	PRESENT	0
296418	289179	08012N	PARTICIPANT	\N	PRESENT	0
296463	289179	19621T	PARTICIPANT	\N	PRESENT	0
296464	289179	19685L	PARTICIPANT	\N	PRESENT	0
296465	289179	19367Y	PARTICIPANT	\N	PRESENT	0
296466	289179	19671E	PARTICIPANT	\N	PRESENT	0
296467	289179	19745F	PARTICIPANT	\N	PRESENT	0
296468	289179	19581D	PARTICIPANT	\N	PRESENT	0
296469	289179	04061F	PARTICIPANT	\N	PRESENT	0
296470	289179	14331P	PARTICIPANT	\N	PRESENT	0
296471	289179	11103C	PARTICIPANT	\N	PRESENT	0
296472	289179	14241N	PARTICIPANT	\N	PRESENT	0
296473	289179	07034Q	PARTICIPANT	\N	PRESENT	0
296474	289179	19643A	PARTICIPANT	\N	PRESENT	0
296475	289179	04008A	PARTICIPANT	\N	PRESENT	0
296476	289179	11064N	PARTICIPANT	\N	PRESENT	0
296477	289179	98050T	PARTICIPANT	\N	PRESENT	0
296478	289179	04043D	PARTICIPANT	\N	PRESENT	0
296479	289179	19713W	PARTICIPANT	\N	PRESENT	0
296480	289179	14275Y	PARTICIPANT	\N	PRESENT	0
296481	289179	14061L	PARTICIPANT	\N	PRESENT	0
296482	289179	14059S	PARTICIPANT	\N	PRESENT	0
296483	289179	01034P	PARTICIPANT	\N	PRESENT	0
296484	289179	19733B	PARTICIPANT	\N	PRESENT	0
296485	289179	19369B	PARTICIPANT	\N	PRESENT	0
296486	289179	19673G	PARTICIPANT	\N	PRESENT	0
296487	289179	14179A	PARTICIPANT	\N	PRESENT	0
296488	289179	19511N	PARTICIPANT	\N	PRESENT	0
296489	289179	11070L	PARTICIPANT	\N	PRESENT	0
296490	289179	19699S	PARTICIPANT	\N	PRESENT	0
296491	289179	19619A	PARTICIPANT	\N	PRESENT	0
296492	289179	16685X	PARTICIPANT	\N	PRESENT	0
296493	289179	19707Y	PARTICIPANT	\N	PRESENT	0
296494	289179	08056B	PARTICIPANT	\N	PRESENT	0
296495	289179	19705W	PARTICIPANT	\N	PRESENT	0
296496	289179	19735D	PARTICIPANT	\N	PRESENT	0
296497	289179	08015R	PARTICIPANT	\N	PRESENT	0
296498	289179	14042U	PARTICIPANT	\N	PRESENT	0
296499	289179	14219Q	PARTICIPANT	\N	PRESENT	0
296500	289179	14355X	PARTICIPANT	\N	PRESENT	0
296501	289179	19441R	PARTICIPANT	\N	PRESENT	0
296502	289179	19657G	PARTICIPANT	\N	PRESENT	0
296503	289179	14041T	PARTICIPANT	\N	PRESENT	0
296504	289179	19663E	PARTICIPANT	\N	PRESENT	0
296505	289179	19443T	PARTICIPANT	\N	PRESENT	0
296506	289179	19319Q	PARTICIPANT	\N	PRESENT	0
296507	289179	19741B	PARTICIPANT	\N	PRESENT	0
296508	289179	19569H	PARTICIPANT	\N	PRESENT	0
296509	289179	08010L	PARTICIPANT	\N	PRESENT	0
296510	289179	14193X	PARTICIPANT	\N	PRESENT	0
296511	289179	17583W	PARTICIPANT	\N	PRESENT	0
296512	289179	14215L	PARTICIPANT	\N	PRESENT	0
296513	289179	19479G	PARTICIPANT	\N	PRESENT	0
296514	289179	14087W	PARTICIPANT	\N	PRESENT	0
296515	289179	19737F	PARTICIPANT	\N	PRESENT	0
296516	289179	11065P	PARTICIPANT	\N	PRESENT	0
296517	289179	10015M	PARTICIPANT	\N	PRESENT	0
296518	289179	14083S	PARTICIPANT	\N	PRESENT	0
296519	289179	14267Y	PARTICIPANT	\N	PRESENT	0
296520	289179	14089Y	PARTICIPANT	\N	PRESENT	0
296521	289179	04089T	PARTICIPANT	\N	PRESENT	0
296522	289179	19421M	PARTICIPANT	\N	PRESENT	0
296523	289179	19739H	PARTICIPANT	\N	PRESENT	0
296524	289179	19335Q	PARTICIPANT	\N	PRESENT	0
296525	289179	14073Q	PARTICIPANT	\N	PRESENT	0
296526	289179	19749K	PARTICIPANT	\N	PRESENT	0
296527	289179	14255U	PARTICIPANT	\N	PRESENT	0
296528	289179	19691J	PARTICIPANT	\N	PRESENT	0
296529	289179	11085T	PARTICIPANT	\N	PRESENT	0
296530	289179	04040A	PARTICIPANT	\N	PRESENT	0
296531	289179	04070G	PARTICIPANT	\N	PRESENT	0
296532	289179	01024M	PARTICIPANT	\N	PRESENT	0
296533	289179	14030Q	PARTICIPANT	\N	PRESENT	0
296534	289179	14327T	PARTICIPANT	\N	PRESENT	0
296535	289179	14093U	PARTICIPANT	\N	PRESENT	0
296536	289179	04057K	PARTICIPANT	\N	PRESENT	0
296537	289179	19521Q	PARTICIPANT	\N	PRESENT	0
296538	289179	11072N	PARTICIPANT	\N	PRESENT	0
296539	289179	04034C	PARTICIPANT	\N	PRESENT	0
296540	289179	01048V	PARTICIPANT	\N	PRESENT	0
296541	289179	19553Y	PARTICIPANT	\N	PRESENT	0
296542	289179	14207L	PARTICIPANT	\N	PRESENT	0
296543	289179	19295A	PARTICIPANT	\N	PRESENT	0
296544	289179	11110B	PARTICIPANT	\N	PRESENT	0
296545	289179	11074Q	PARTICIPANT	\N	PRESENT	0
296546	289179	14159V	PARTICIPANT	\N	PRESENT	0
296547	289179	04071H	PARTICIPANT	\N	PRESENT	0
296548	289179	05012A	PARTICIPANT	\N	PRESENT	0
296549	289179	11054L	PARTICIPANT	\N	PRESENT	0
296550	289179	19611R	PARTICIPANT	\N	PRESENT	0
296551	289179	14205J	PARTICIPANT	\N	PRESENT	0
296552	289179	14079W	PARTICIPANT	\N	PRESENT	0
296553	289179	14169X	PARTICIPANT	\N	PRESENT	0
296554	289179	02002K	PARTICIPANT	\N	PRESENT	0
296559	289179	18083K	PARTICIPANT	\N	PRESENT	0
296560	289179	11053K	PARTICIPANT	\N	PRESENT	0
296561	289179	08009T	PARTICIPANT	\N	PRESENT	0
296566	289179	14221J	PARTICIPANT	\N	PRESENT	0
296563	289179	08016S	PARTICIPANT	\N	PRESENT	0
296564	289179	11099A	PARTICIPANT	\N	PRESENT	0
296565	289179	95067Q	PARTICIPANT	\N	PRESENT	0
296572	289179	19679N	PARTICIPANT	\N	PRESENT	0
296573	289179	14249W	PARTICIPANT	\N	PRESENT	0
273693	273666	14219Q	PARTICIPANT	\N	EXCUSE	0
273694	273667	14219Q	PARTICIPANT	\N	EXCUSE	0
275581	275573	08015R	PARTICIPANT	\N	PRESENT	0
275460	244334	19681G	PARTICIPANT	\N	PRESENT	0
275576	275573	08028W	PARTICIPANT	\N	PRESENT	0
275579	275573	08068F	PARTICIPANT	\N	PRESENT	0
275584	275573	14257W	PARTICIPANT	\N	PRESENT	0
275604	275603	08068F	PARTICIPANT	\N	PRESENT	0
275605	275603	14073Q	PARTICIPANT	\N	PRESENT	0
275606	275603	19251M	PARTICIPANT	\N	PRESENT	0
275728	275726	11012A	PARTICIPANT	\N	PRESENT	0
275609	275603	01043Q	PARTICIPANT	\N	PRESENT	0
275662	275660	08068F	PARTICIPANT	\N	PRESENT	0
275663	275660	14073Q	PARTICIPANT	\N	PRESENT	0
275664	275660	14219Q	PARTICIPANT	\N	PRESENT	0
275672	275666	08068F	PARTICIPANT	\N	PRESENT	0
275674	275666	19695N	PARTICIPANT	\N	PRESENT	0
275681	275666	08015R	PARTICIPANT	\N	PRESENT	0
275704	275703	08068F	PARTICIPANT	\N	PRESENT	0
275727	275726	88008L	PARTICIPANT	\N	PRESENT	0
275739	275737	08034U	PARTICIPANT	\N	PRESENT	0
275741	275740	11074Q	PARTICIPANT	\N	PRESENT	0
275742	275740	19651A	PARTICIPANT	\N	PRESENT	0
275745	273682	14253S	PARTICIPANT	\N	PRESENT	0
275746	273682	14085U	PARTICIPANT	\N	PRESENT	0
276010	276009	11053K	PARTICIPANT	\N	PRESENT	0
275752	275750	19689Q	PARTICIPANT	\N	PRESENT	0
276011	276009	14159V	PARTICIPANT	\N	PRESENT	0
275762	275759	14085U	PARTICIPANT	\N	PRESENT	0
275763	275759	14253S	PARTICIPANT	\N	PRESENT	0
276012	276009	05012A	PARTICIPANT	\N	PRESENT	0
276014	276013	11053K	PARTICIPANT	\N	PRESENT	0
276015	276013	14159V	PARTICIPANT	\N	PRESENT	0
276016	276013	05012A	PARTICIPANT	\N	PRESENT	0
278348	278347	08039A	PARTICIPANT	\N	PRESENT	0
278350	278349	14079W	PARTICIPANT	\N	PRESENT	0
278359	278358	19725B	PARTICIPANT	\N	PRESENT	0
279434	278438	04061F	PARTICIPANT	\N	PRESENT	0
279494	278438	04038G	PARTICIPANT	\N	EXCUSE	0
279495	278438	19467C	PARTICIPANT	\N	EXCUSE	0
279496	278438	19421M	PARTICIPANT	\N	EXCUSE	0
280880	279079	04040A	PARTICIPANT	\N	EXCUSE	0
280881	279079	08056B	PARTICIPANT	\N	EXCUSE	0
283846	282329	14030Q	PRESIDENT	0	PRESENT	0
283847	282329	19643A	PARTICIPANT	\N	PRESENT	0
283848	282329	19701S	PARTICIPANT	\N	PRESENT	0
283849	282329	19693L	PARTICIPANT	\N	PRESENT	0
283850	282329	19599P	PARTICIPANT	\N	PRESENT	0
283851	282329	19715Y	PARTICIPANT	\N	PRESENT	0
283852	282329	19731Y	PARTICIPANT	\N	PRESENT	0
283853	282329	08031R	PARTICIPANT	\N	PRESENT	0
283854	282329	08017T	PARTICIPANT	\N	PRESENT	0
283855	282329	01043Q	PARTICIPANT	\N	EXCUSE	0
283856	282329	11045K	PARTICIPANT	\N	PRESENT	0
283857	282329	19749K	PARTICIPANT	\N	PRESENT	0
297322	294986	08047A	PARTICIPANT	\N	PRESENT	0
297323	294986	14097Y	PARTICIPANT	\N	PRESENT	0
297324	294986	95067Q	PARTICIPANT	\N	PRESENT	0
297325	294986	01062T	PARTICIPANT	\N	PRESENT	0
297326	294986	11041F	PARTICIPANT	\N	PRESENT	0
297327	294986	19319Q	PARTICIPANT	\N	PRESENT	0
297328	294986	14105F	PARTICIPANT	\N	PRESENT	0
297329	294986	98018T	PARTICIPANT	\N	PRESENT	0
297330	294986	14267Y	PARTICIPANT	\N	PRESENT	0
297331	294986	11064N	PARTICIPANT	\N	PRESENT	0
297332	294986	98050T	PARTICIPANT	\N	PRESENT	0
297333	294986	14211G	PARTICIPANT	\N	PRESENT	0
297334	294986	19583F	PARTICIPANT	\N	PRESENT	0
297335	294986	19251M	PARTICIPANT	\N	PRESENT	0
297336	295657	19723Y	PARTICIPANT	\N	EXCUSE	0
297466	289182	14225N	PARTICIPANT	\N	PRESENT	0
297467	289182	08061X	PARTICIPANT	\N	PRESENT	0
297468	289182	04045F	PARTICIPANT	\N	PRESENT	0
297469	289182	14179A	PARTICIPANT	\N	PRESENT	0
297470	289182	95037J	PARTICIPANT	\N	PRESENT	0
297471	289182	17779H	PARTICIPANT	\N	PRESENT	0
297473	289182	14355X	PARTICIPANT	\N	PRESENT	0
297474	289182	04057K	PARTICIPANT	\N	PRESENT	0
297475	289182	19443T	PARTICIPANT	\N	PRESENT	0
297476	289182	19527W	PARTICIPANT	\N	PRESENT	0
297477	289182	04033B	PARTICIPANT	\N	PRESENT	0
297478	289182	14097Y	PARTICIPANT	\N	PRESENT	0
297479	289182	19565D	PARTICIPANT	\N	PRESENT	0
297480	289182	14111D	PARTICIPANT	\N	PRESENT	0
297482	297481	11040E	PARTICIPANT	\N	PRESENT	0
297484	297483	11040E	PARTICIPANT	\N	PRESENT	0
297485	289182	19631V	PARTICIPANT	\N	PRESENT	0
297486	289182	08024S	PARTICIPANT	\N	PRESENT	0
297487	289182	08060W	PARTICIPANT	\N	PRESENT	0
297488	289182	19543W	PARTICIPANT	\N	PRESENT	0
297490	289182	08068F	PARTICIPANT	\N	PRESENT	0
297491	289182	08055A	PARTICIPANT	\N	PRESENT	0
297492	289182	04070G	PARTICIPANT	\N	PRESENT	0
297493	289182	01057W	PARTICIPANT	\N	PRESENT	0
297494	289182	08015R	PARTICIPANT	\N	PRESENT	0
297495	289182	11012A	PARTICIPANT	\N	PRESENT	0
297496	289182	95063L	PARTICIPANT	\N	PRESENT	0
297497	289182	14159V	PARTICIPANT	\N	PRESENT	0
297498	289182	14219Q	PARTICIPANT	\N	PRESENT	0
297499	289182	14115H	PARTICIPANT	\N	PRESENT	0
297500	289182	07033P	PARTICIPANT	\N	PRESENT	0
297501	289182	19691J	PARTICIPANT	\N	PRESENT	0
297503	297502	19531S	PARTICIPANT	\N	PRESENT	0
297504	289182	14259Y	PARTICIPANT	\N	PRESENT	0
297505	289182	04018C	PARTICIPANT	\N	PRESENT	0
297506	289182	19713W	PARTICIPANT	\N	PRESENT	0
297507	289182	01048V	PARTICIPANT	\N	PRESENT	0
297508	289182	11067R	PARTICIPANT	\N	PRESENT	0
297509	295308	95041E	PARTICIPANT	\N	EXCUSE	0
297510	289182	19689Q	PARTICIPANT	\N	PRESENT	0
297511	293387	11048N	PRESIDENT	0	PRESENT	0
297512	293387	14103D	PARTICIPANT	\N	PRESENT	0
297513	293387	11067R	PARTICIPANT	\N	PRESENT	0
297514	293387	19479G	PARTICIPANT	\N	PRESENT	0
297515	293387	19711U	PARTICIPANT	\N	PRESENT	0
297516	293387	19651A	PARTICIPANT	\N	PRESENT	0
297517	293387	19533U	PARTICIPANT	\N	PRESENT	0
297518	293387	19689Q	PARTICIPANT	\N	PRESENT	0
297519	293387	19441R	PARTICIPANT	\N	PRESENT	0
297520	293387	12016W	PARTICIPANT	\N	PRESENT	0
297521	293387	14026U	PARTICIPANT	\N	PRESENT	0
297522	293387	19399H	PARTICIPANT	\N	PRESENT	0
297523	293387	19719D	PARTICIPANT	\N	PRESENT	0
297524	293387	04049K	PARTICIPANT	\N	PRESENT	0
297525	293387	14087W	PARTICIPANT	\N	PRESENT	0
297526	293387	19503N	PARTICIPANT	\N	PRESENT	0
297527	293387	14157T	PARTICIPANT	\N	PRESENT	0
297528	293387	19749K	PARTICIPANT	\N	PRESENT	0
297529	293387	19515S	PARTICIPANT	\N	PRESENT	0
297530	293387	14031R	PARTICIPANT	\N	PRESENT	0
297531	293387	14207L	PARTICIPANT	\N	PRESENT	0
297532	293387	01024M	PARTICIPANT	\N	EXCUSE	0
297533	289182	14199E	PARTICIPANT	\N	PRESENT	0
297534	289182	19703U	PARTICIPANT	\N	PRESENT	0
297535	289182	08010L	PARTICIPANT	\N	PRESENT	0
297536	289182	19749K	PARTICIPANT	\N	PRESENT	0
297537	289182	14103D	PARTICIPANT	\N	PRESENT	0
297538	289182	08062Y	PARTICIPANT	\N	PRESENT	0
297539	289182	19369B	PARTICIPANT	\N	PRESENT	0
297540	289182	01034P	PARTICIPANT	\N	PRESENT	0
297541	289182	19711U	PARTICIPANT	\N	PRESENT	0
297542	289182	19441R	PARTICIPANT	\N	PRESENT	0
297543	289182	19479G	PARTICIPANT	\N	PRESENT	0
297544	289182	14026U	PARTICIPANT	\N	PRESENT	0
297545	289182	19651A	PARTICIPANT	\N	PRESENT	0
297546	289182	19647E	PARTICIPANT	\N	PRESENT	0
297547	289182	14231L	PARTICIPANT	\N	PRESENT	0
297548	289182	12016W	PARTICIPANT	\N	PRESENT	0
297549	289182	14211G	PARTICIPANT	\N	PRESENT	0
297550	289182	08031R	PARTICIPANT	\N	PRESENT	0
297551	289182	19549D	PARTICIPANT	\N	PRESENT	0
297552	289182	19637C	PARTICIPANT	\N	PRESENT	0
297553	289182	14229S	PARTICIPANT	\N	PRESENT	0
297554	289182	14151M	PARTICIPANT	\N	PRESENT	0
297555	289182	98050T	PARTICIPANT	\N	PRESENT	0
297556	289182	14051J	PARTICIPANT	\N	PRESENT	0
297557	289182	19399H	PARTICIPANT	\N	PRESENT	0
297558	289182	08034U	PARTICIPANT	\N	PRESENT	0
297559	289182	08017T	PARTICIPANT	\N	PRESENT	0
297560	289182	19649G	PARTICIPANT	\N	PRESENT	0
297561	289182	14169X	PARTICIPANT	\N	PRESENT	0
297562	289182	19719D	PARTICIPANT	\N	PRESENT	0
297563	289182	14109K	PARTICIPANT	\N	PRESENT	0
297564	289182	04049K	PARTICIPANT	\N	PRESENT	0
297565	289182	11027H	PARTICIPANT	\N	PRESENT	0
297566	289182	14157T	PARTICIPANT	\N	PRESENT	0
297567	289182	14121F	PARTICIPANT	\N	PRESENT	0
297569	297568	04057K	PARTICIPANT	\N	PRESENT	0
297570	297568	08017T	PARTICIPANT	\N	PRESENT	0
281047	280690	14357A	PARTICIPANT	\N	PRESENT	0
281048	280690	11099A	PARTICIPANT	\N	PRESENT	0
281051	280499	19565D	PARTICIPANT	\N	EXCUSE	0
281118	280499	14329V	PARTICIPANT	\N	EXCUSE	0
281133	280690	14329V	PARTICIPANT	\N	EXCUSE	0
281134	280690	19565D	PARTICIPANT	\N	EXCUSE	0
293242	293109	11072N	PARTICIPANT	\N	EXCUSE	0
293243	293109	11109J	PARTICIPANT	\N	EXCUSE	0
293244	293109	11010L	PARTICIPANT	\N	PRESENT	0
293252	292898	19369B	PARTICIPANT	\N	PRESENT	0
295599	293109	19631V	PARTICIPANT	\N	PRESENT	0
295600	293109	14259Y	PARTICIPANT	\N	EXCUSE	0
295601	293109	19577H	PARTICIPANT	\N	EXCUSE	0
295602	293109	19691J	PARTICIPANT	\N	PRESENT	0
295603	293109	19715Y	PARTICIPANT	\N	PRESENT	0
295604	293109	98005N	PARTICIPANT	\N	PRESENT	0
295605	293109	19583F	PARTICIPANT	\N	EXCUSE	0
295606	293109	08019V	PRESIDENT	0	PRESENT	0
295607	293109	12016W	PARTICIPANT	\N	EXCUSE	0
295608	293109	19657G	PARTICIPANT	\N	EXCUSE	0
295610	293109	19301E	PARTICIPANT	\N	PRESENT	0
297940	295636	16685X	PARTICIPANT	\N	PRESENT	0
295612	293109	04043D	PARTICIPANT	\N	PRESENT	0
295613	293109	11054L	PARTICIPANT	\N	PRESENT	0
297942	297941	14133K	PARTICIPANT	\N	EXCUSE	0
297943	297941	96004D	PARTICIPANT	\N	PRESENT	0
297944	297941	14255U	PARTICIPANT	\N	PRESENT	0
297945	297941	04042C	PARTICIPANT	\N	PRESENT	0
297946	297941	19251M	PARTICIPANT	\N	EXCUSE	0
297947	297941	98022P	PARTICIPANT	\N	EXCUSE	0
297948	297941	04097T	PARTICIPANT	\N	EXCUSE	0
297949	297941	14097Y	PARTICIPANT	\N	PRESENT	0
297950	297941	04061F	PARTICIPANT	\N	PRESENT	0
297951	297941	14073Q	PARTICIPANT	\N	EXCUSE	0
297952	297941	01062T	PARTICIPANT	\N	PRESENT	0
297953	297941	98035U	PARTICIPANT	\N	PRESENT	0
297954	297941	98050T	PARTICIPANT	\N	PRESENT	0
297955	297941	04057K	PARTICIPANT	\N	EXCUSE	0
297956	295636	17779H	PARTICIPANT	\N	PRESENT	0
297958	297957	14133K	PARTICIPANT	\N	EXCUSE	0
297959	297957	96004D	PRESIDENT	0	PRESENT	0
297960	297957	14089Y	PARTICIPANT	\N	EXCUSE	0
297961	297957	08014Q	PARTICIPANT	\N	EXCUSE	0
297962	297957	14357A	PARTICIPANT	\N	PRESENT	0
297963	297957	08018U	PARTICIPANT	\N	EXCUSE	0
297964	297957	98035U	PARTICIPANT	\N	PRESENT	0
297965	297957	19593H	PARTICIPANT	\N	EXCUSE	0
297966	297957	04057K	PARTICIPANT	\N	EXCUSE	0
297967	297957	19725B	PARTICIPANT	\N	PRESENT	0
297968	297957	14097Y	PARTICIPANT	\N	PRESENT	0
297969	297957	11026G	PARTICIPANT	\N	PRESENT	0
297970	297957	14061L	PARTICIPANT	\N	EXCUSE	0
297971	297957	04097T	PARTICIPANT	\N	EXCUSE	0
297972	297957	11083R	PARTICIPANT	\N	EXCUSE	0
297973	297957	14079W	PARTICIPANT	\N	EXCUSE	0
297974	297957	14331P	PARTICIPANT	\N	EXCUSE	0
297975	297957	14135M	PARTICIPANT	\N	EXCUSE	0
297976	297957	14073Q	PARTICIPANT	\N	PRESENT	0
298050	289184	19583F	PARTICIPANT	\N	PRESENT	0
298051	289184	14105F	PARTICIPANT	\N	PRESENT	0
298052	289184	04088S	PARTICIPANT	\N	PRESENT	0
298053	289184	08073C	PARTICIPANT	\N	PRESENT	0
298054	289184	04044E	PARTICIPANT	\N	PRESENT	0
298055	289184	14041T	PARTICIPANT	\N	PRESENT	0
298056	289184	04086Q	PARTICIPANT	\N	PRESENT	0
298057	289184	19687N	PARTICIPANT	\N	PRESENT	0
298058	289184	11040E	PARTICIPANT	\N	PRESENT	0
298059	289184	95063L	PARTICIPANT	\N	PRESENT	0
298060	289184	11070L	PARTICIPANT	\N	PRESENT	0
298061	289184	14073Q	PARTICIPANT	\N	PRESENT	0
298062	289184	19711U	PARTICIPANT	\N	PRESENT	0
298063	289184	11012A	PARTICIPANT	\N	PRESENT	0
298064	289184	14119M	PARTICIPANT	\N	PRESENT	0
298065	289184	98005N	PARTICIPANT	\N	PRESENT	0
298066	289184	14038Y	PARTICIPANT	\N	PRESENT	0
298067	289184	19737F	PARTICIPANT	\N	PRESENT	0
298068	289184	12016W	PARTICIPANT	\N	PRESENT	0
298069	289184	14083S	PARTICIPANT	\N	PRESENT	0
298070	289184	01057W	PARTICIPANT	\N	PRESENT	0
298071	289184	14021P	PARTICIPANT	\N	PRESENT	0
298072	289184	19545Y	PARTICIPANT	\N	PRESENT	0
298073	289184	19701S	PARTICIPANT	\N	PRESENT	0
298074	289184	19741B	PARTICIPANT	\N	PRESENT	0
298075	289184	14225N	PARTICIPANT	\N	PRESENT	0
298076	289184	14033T	PARTICIPANT	\N	PRESENT	0
298077	289184	99004R	PARTICIPANT	\N	PRESENT	0
298078	289184	14085U	PARTICIPANT	\N	PRESENT	0
298079	289184	19723Y	PARTICIPANT	\N	PRESENT	0
298080	289184	19593H	PARTICIPANT	\N	PRESENT	0
298081	289184	11097X	PARTICIPANT	\N	PRESENT	0
298118	289185	01034P	PARTICIPANT	\N	PRESENT	0
298119	289185	19687N	PARTICIPANT	\N	PRESENT	0
298120	289185	01057W	PARTICIPANT	\N	PRESENT	0
298121	289185	19593H	PARTICIPANT	\N	PRESENT	0
298122	289185	11040E	PARTICIPANT	\N	PRESENT	0
298123	289185	14119M	PARTICIPANT	\N	PRESENT	0
298124	289185	14085U	PARTICIPANT	\N	PRESENT	0
298125	289185	07029T	PARTICIPANT	\N	PRESENT	0
298126	289185	12016W	PARTICIPANT	\N	PRESENT	0
298127	289185	14021P	PARTICIPANT	\N	PRESENT	0
298128	289185	14041T	PARTICIPANT	\N	PRESENT	0
298129	289185	11045K	PARTICIPANT	\N	PRESENT	0
298130	289185	14225N	PARTICIPANT	\N	PRESENT	0
298131	289185	04088S	PARTICIPANT	\N	PRESENT	0
298132	289185	95063L	PARTICIPANT	\N	PRESENT	0
298133	289185	19545Y	PARTICIPANT	\N	PRESENT	0
298134	289185	19741B	PARTICIPANT	\N	PRESENT	0
298135	289185	19583F	PARTICIPANT	\N	PRESENT	0
298136	289185	14038Y	PARTICIPANT	\N	PRESENT	0
298137	289185	19723Y	PARTICIPANT	\N	PRESENT	0
298138	289185	19319Q	PARTICIPANT	\N	PRESENT	0
298139	289185	98005N	PARTICIPANT	\N	PRESENT	0
298140	289185	19387D	PARTICIPANT	\N	PRESENT	0
298141	289185	11012A	PARTICIPANT	\N	PRESENT	0
298142	289185	14033T	PARTICIPANT	\N	PRESENT	0
298143	289185	19737F	PARTICIPANT	\N	PRESENT	0
298144	289185	11070L	PARTICIPANT	\N	PRESENT	0
298145	289185	19711U	PARTICIPANT	\N	PRESENT	0
298146	289185	14083S	PARTICIPANT	\N	PRESENT	0
298147	289185	14073Q	PARTICIPANT	\N	PRESENT	0
298148	289185	04086Q	PARTICIPANT	\N	PRESENT	0
298149	289185	11097X	PARTICIPANT	\N	PRESENT	0
298150	289185	08073C	PARTICIPANT	\N	PRESENT	0
298151	289185	19701S	PARTICIPANT	\N	PRESENT	0
298116	289185	11072N	PARTICIPANT	\N	PRESENT	0
298117	289185	08011M	PARTICIPANT	\N	PRESENT	0
298152	289185	99004R	PARTICIPANT	\N	PRESENT	0
298153	289185	11074Q	PARTICIPANT	\N	PRESENT	0
298154	289185	19441R	PARTICIPANT	\N	PRESENT	0
298048	289184	11072N	PARTICIPANT	\N	PRESENT	0
298049	289184	19319Q	PARTICIPANT	\N	PRESENT	0
298155	289185	14034U	PARTICIPANT	\N	PRESENT	0
298156	289185	11048N	PARTICIPANT	\N	PRESENT	0
298157	289185	08052W	PARTICIPANT	\N	PRESENT	0
298158	289185	19715Y	PARTICIPANT	\N	PRESENT	0
298159	289185	19651A	PARTICIPANT	\N	PRESENT	0
298160	289185	19575F	PARTICIPANT	\N	PRESENT	0
298161	289185	08019V	PARTICIPANT	\N	PRESENT	0
298162	289185	19667J	PARTICIPANT	\N	PRESENT	0
298163	289185	19647E	PARTICIPANT	\N	PRESENT	0
298164	289185	04071H	PARTICIPANT	\N	PRESENT	0
298165	289185	08010L	PARTICIPANT	\N	PRESENT	0
298166	289185	11026G	PARTICIPANT	\N	PRESENT	0
298167	289185	19581D	PARTICIPANT	\N	PRESENT	0
298183	289185	04092N	PARTICIPANT	\N	PRESENT	0
298184	289185	14219Q	PARTICIPANT	\N	PRESENT	0
298185	289185	19689Q	PARTICIPANT	\N	PRESENT	0
298187	289185	14039A	PARTICIPANT	\N	PRESENT	0
298188	289185	14281W	PARTICIPANT	\N	PRESENT	0
298189	289185	14231L	PARTICIPANT	\N	PRESENT	0
298191	298190	01028R	PARTICIPANT	\N	PRESENT	0
298192	289185	14059S	PARTICIPANT	\N	PRESENT	0
298193	289185	19657G	PARTICIPANT	\N	PRESENT	0
298194	289185	19335Q	PARTICIPANT	\N	PRESENT	0
298195	289185	14227Q	PARTICIPANT	\N	PRESENT	0
298196	289185	11067R	PARTICIPANT	\N	PRESENT	0
298197	289185	14030Q	PARTICIPANT	\N	PRESENT	0
298198	289185	11085T	PARTICIPANT	\N	PRESENT	0
298199	289185	19521Q	PARTICIPANT	\N	PRESENT	0
298200	289185	04085P	PARTICIPANT	\N	PRESENT	0
272336	270529	19741B	PARTICIPANT	\N	PRESENT	0
272337	270529	04071H	PARTICIPANT	\N	PRESENT	0
272338	270529	11040E	PARTICIPANT	\N	PRESENT	0
272339	270529	07004J	PARTICIPANT	\N	PRESENT	0
272340	270529	19689Q	PARTICIPANT	\N	PRESENT	0
272341	270529	19545Y	PARTICIPANT	\N	PRESENT	0
272342	270529	88008L	PARTICIPANT	\N	PRESENT	0
272343	270529	19651A	PARTICIPANT	\N	PRESENT	0
272344	270529	08010L	PARTICIPANT	\N	PRESENT	0
272345	270529	01048V	PARTICIPANT	\N	PRESENT	0
272346	270529	19565D	PARTICIPANT	\N	PRESENT	0
272347	270529	19695N	PARTICIPANT	\N	PRESENT	0
272348	270529	19347U	PARTICIPANT	\N	PRESENT	0
272349	270529	19413M	PARTICIPANT	\N	PRESENT	0
272350	270529	19489J	PARTICIPANT	\N	PRESENT	0
272351	270529	17779H	PARTICIPANT	\N	PRESENT	0
272352	270529	14197C	PARTICIPANT	\N	PRESENT	0
272353	270529	19647E	PARTICIPANT	\N	PRESENT	0
272354	270529	19715Y	PARTICIPANT	\N	PRESENT	0
272355	270529	14021P	PARTICIPANT	\N	PRESENT	0
272356	270529	08060W	PARTICIPANT	\N	PRESENT	0
272357	270529	14159V	PARTICIPANT	\N	PRESENT	0
272358	270529	08038Y	PARTICIPANT	\N	PRESENT	0
272359	270529	19725B	PARTICIPANT	\N	PRESENT	0
272360	270529	11104D	PARTICIPANT	\N	PRESENT	0
272361	270529	14207L	PARTICIPANT	\N	PRESENT	0
272362	270529	19599P	PARTICIPANT	\N	PRESENT	0
272363	270529	19333N	PARTICIPANT	\N	PRESENT	0
272364	270529	19551W	PARTICIPANT	\N	PRESENT	0
272365	270529	19527W	PARTICIPANT	\N	PRESENT	0
272366	270529	14063N	PARTICIPANT	\N	PRESENT	0
272367	270529	19631V	PARTICIPANT	\N	PRESENT	0
272368	270529	14257W	PARTICIPANT	\N	PRESENT	0
272369	270529	19549D	PARTICIPANT	\N	PRESENT	0
272370	270529	14225N	PARTICIPANT	\N	PRESENT	0
272371	270529	19479G	PARTICIPANT	\N	PRESENT	0
272372	270529	14219Q	PARTICIPANT	\N	PRESENT	0
272373	270529	14267Y	PARTICIPANT	\N	PRESENT	0
272374	270529	14030Q	PARTICIPANT	\N	PRESENT	0
272375	270529	01024M	PARTICIPANT	\N	PRESENT	0
272376	270529	19747H	PARTICIPANT	\N	PRESENT	0
272377	270529	19671E	PARTICIPANT	\N	PRESENT	0
272378	270529	19745F	PARTICIPANT	\N	PRESENT	0
272379	270529	19383Y	PARTICIPANT	\N	PRESENT	0
272380	270529	11103C	PARTICIPANT	\N	PRESENT	0
272381	270529	14147R	PARTICIPANT	\N	PRESENT	0
272382	270529	95062K	PARTICIPANT	\N	PRESENT	0
272383	270529	14115H	PARTICIPANT	\N	PRESENT	0
272384	270529	19733B	PARTICIPANT	\N	PRESENT	0
272385	270529	14119M	PARTICIPANT	\N	PRESENT	0
272386	270529	14069U	PARTICIPANT	\N	PRESENT	0
272387	270529	14041T	PARTICIPANT	\N	PRESENT	0
272388	270529	14029X	PARTICIPANT	\N	PRESENT	0
272389	270529	19447X	PARTICIPANT	\N	PRESENT	0
272390	270529	19667J	PARTICIPANT	\N	PRESENT	0
272391	270529	19673G	PARTICIPANT	\N	PRESENT	0
272392	270529	19573D	PARTICIPANT	\N	PRESENT	0
272393	270529	19515S	PARTICIPANT	\N	PRESENT	0
272394	270529	14157T	PARTICIPANT	\N	PRESENT	0
272395	270529	95030B	PARTICIPANT	\N	PRESENT	0
272396	270529	14151M	PARTICIPANT	\N	PRESENT	0
272397	270529	19531S	PARTICIPANT	\N	PRESENT	0
272398	270529	14331P	PARTICIPANT	\N	PRESENT	0
272399	270529	14042U	PARTICIPANT	\N	PRESENT	0
272401	270529	14083S	PARTICIPANT	\N	PRESENT	0
272418	270529	19295A	PARTICIPANT	\N	PRESENT	0
272419	270529	14073Q	PARTICIPANT	\N	PRESENT	0
272420	270529	18083K	PARTICIPANT	\N	PRESENT	0
272421	270529	14109K	PARTICIPANT	\N	PRESENT	0
272422	270529	08014Q	PARTICIPANT	\N	PRESENT	0
272423	270529	14217N	PARTICIPANT	\N	PRESENT	0
272467	270397	18083K	PARTICIPANT	\N	PRESENT	0
272468	270397	14169X	PARTICIPANT	\N	PRESENT	0
272469	270529	19301E	PARTICIPANT	\N	PRESENT	0
272470	270397	19737F	PARTICIPANT	\N	EXCUSE	0
272471	270529	17583W	PARTICIPANT	\N	PRESENT	0
272502	270529	19727D	PARTICIPANT	\N	PRESENT	0
272473	270397	14051J	PARTICIPANT	\N	PRESENT	0
272474	270397	08060W	PARTICIPANT	\N	PRESENT	0
272475	270397	19745F	PARTICIPANT	\N	PRESENT	0
272476	270397	08009T	PRESIDENT	0	PRESENT	0
272478	270397	19599P	PARTICIPANT	\N	PRESENT	0
272479	270397	98023Q	PARTICIPANT	\N	PRESENT	0
272480	272477	04070G	PRESIDENT	0	PRESENT	0
272481	272477	19699S	PARTICIPANT	\N	PRESENT	0
272482	272477	04057K	PARTICIPANT	\N	PRESENT	0
272483	272477	08043V	PARTICIPANT	\N	PRESENT	0
272484	272477	19693L	PARTICIPANT	\N	PRESENT	0
272485	272477	14229S	PARTICIPANT	\N	PRESENT	0
272486	272477	14241N	PARTICIPANT	\N	PRESENT	0
272487	272477	19731Y	PARTICIPANT	\N	PRESENT	0
272488	272477	04059M	PARTICIPANT	\N	PRESENT	0
272489	272477	19735D	PARTICIPANT	\N	PRESENT	0
272490	272477	08017T	PARTICIPANT	\N	PRESENT	0
272491	272477	11104D	PARTICIPANT	\N	PRESENT	0
272492	272477	04018C	PARTICIPANT	\N	PRESENT	0
272493	272477	19643A	PARTICIPANT	\N	EXCUSE	0
272494	272477	14061L	PARTICIPANT	\N	EXCUSE	0
272495	272477	14109K	PARTICIPANT	\N	EXCUSE	0
272334	270529	11070L	PARTICIPANT	\N	PRESENT	0
272335	270529	19649G	PARTICIPANT	\N	PRESENT	0
272496	272477	19749K	PARTICIPANT	\N	EXCUSE	0
272497	270397	14031R	PARTICIPANT	\N	PRESENT	0
272498	270397	19289C	PARTICIPANT	\N	PRESENT	0
272499	270397	19525U	PARTICIPANT	\N	PRESENT	0
272500	270529	11067R	PARTICIPANT	\N	PRESENT	0
272501	270529	08068F	PARTICIPANT	\N	PRESENT	0
272503	270529	19629C	PARTICIPANT	\N	PRESENT	0
272504	270529	08043V	PARTICIPANT	\N	PRESENT	0
272505	270397	19333N	PARTICIPANT	\N	PRESENT	0
272506	270397	19551W	PARTICIPANT	\N	PRESENT	0
272507	270397	19347U	PARTICIPANT	\N	PRESENT	0
272508	270397	19739H	PARTICIPANT	\N	PRESENT	0
272509	270397	14038Y	PARTICIPANT	\N	PRESENT	0
272510	270397	14219Q	PARTICIPANT	\N	PRESENT	0
272511	270397	14157T	PARTICIPANT	\N	PRESENT	0
272512	270397	04061F	PARTICIPANT	\N	PRESENT	0
272513	270397	08055A	PARTICIPANT	\N	PRESENT	0
272514	270397	95062K	PARTICIPANT	\N	PRESENT	0
272515	270397	14221J	PARTICIPANT	\N	PRESENT	0
272516	270529	19441R	PARTICIPANT	\N	PRESENT	0
272517	270529	07034Q	PARTICIPANT	\N	PRESENT	0
272518	270529	08031R	PARTICIPANT	\N	PRESENT	0
272522	270397	19549D	PARTICIPANT	\N	PRESENT	0
272523	270397	11065P	PARTICIPANT	\N	PRESENT	0
272573	270397	14103D	PARTICIPANT	\N	PRESENT	0
272574	270397	05012A	PARTICIPANT	\N	PRESENT	0
272575	270397	19503N	PARTICIPANT	\N	PRESENT	0
272581	270397	19733B	PARTICIPANT	\N	PRESENT	0
272613	270529	19335Q	PARTICIPANT	\N	PRESENT	0
272618	270529	19553Y	PARTICIPANT	\N	PRESENT	0
272624	270529	11027H	PARTICIPANT	\N	PRESENT	0
272625	270529	19533U	PARTICIPANT	\N	PRESENT	0
272626	270529	19253P	PARTICIPANT	\N	PRESENT	0
272627	270529	04059M	PARTICIPANT	\N	PRESENT	0
272628	270529	14085U	PARTICIPANT	\N	PRESENT	0
272629	270529	14265W	PARTICIPANT	\N	PRESENT	0
272630	270529	11090Q	PARTICIPANT	\N	PRESENT	0
272640	270529	14135M	PARTICIPANT	\N	PRESENT	0
272645	270529	01057W	PARTICIPANT	\N	PRESENT	0
272646	270529	19399H	PARTICIPANT	\N	PRESENT	0
272652	270529	11012A	PARTICIPANT	\N	PRESENT	0
272655	270529	14033T	PARTICIPANT	\N	PRESENT	0
272656	270529	11056N	PARTICIPANT	\N	PRESENT	0
272660	270529	19683J	PARTICIPANT	\N	PRESENT	0
272661	270397	19637C	PARTICIPANT	\N	PRESENT	0
272662	270529	01058X	PARTICIPANT	\N	PRESENT	0
272663	270529	08017T	PARTICIPANT	\N	PRESENT	0
272670	270529	04088S	PARTICIPANT	\N	PRESENT	0
272671	270529	19511N	PARTICIPANT	\N	PRESENT	0
272672	272477	08031R	PARTICIPANT	\N	PRESENT	0
272676	270529	19581D	PARTICIPANT	\N	PRESENT	0
272677	270529	95067Q	PARTICIPANT	\N	PRESENT	0
272678	270529	89017R	PARTICIPANT	\N	PRESENT	0
272685	270529	80013X	PARTICIPANT	\N	PRESENT	0
282055	273872	19593H	PARTICIPANT	\N	PRESENT	0
284987	284986	99004R	PARTICIPANT	\N	PRESENT	0
284996	284994	19689Q	PARTICIPANT	\N	PRESENT	0
292137	292136	14239U	PARTICIPANT	\N	PRESENT	0
292138	292136	19295A	PARTICIPANT	\N	PRESENT	0
292139	292136	14087W	PARTICIPANT	\N	EXCUSE	0
292140	292136	19691J	PARTICIPANT	\N	PRESENT	0
292141	292136	14031R	PARTICIPANT	\N	PRESENT	0
292142	292136	14119M	PARTICIPANT	\N	PRESENT	0
292143	292136	04044E	PRESIDENT	0	PRESENT	0
293847	291386	17637T	PARTICIPANT	\N	PRESENT	0
296083	296082	04043D	PARTICIPANT	\N	PRESENT	0
296856	289180	04059M	PARTICIPANT	\N	PRESENT	0
296857	289180	14087W	PARTICIPANT	\N	PRESENT	0
296858	289180	19521Q	PARTICIPANT	\N	PRESENT	0
296859	289180	19295A	PARTICIPANT	\N	PRESENT	0
296860	289180	19515S	PARTICIPANT	\N	PRESENT	0
296861	289180	17779H	PARTICIPANT	\N	PRESENT	0
296862	289180	19727D	PARTICIPANT	\N	PRESENT	0
296863	289180	14197C	PARTICIPANT	\N	PRESENT	0
296864	289180	14191V	PARTICIPANT	\N	PRESENT	0
296865	289180	19715Y	PARTICIPANT	\N	PRESENT	0
296866	289180	19703U	PARTICIPANT	\N	PRESENT	0
296867	289180	19758L	PARTICIPANT	\N	PRESENT	0
296868	289180	11031D	PARTICIPANT	\N	PRESENT	0
296869	289180	14227Q	PARTICIPANT	\N	PRESENT	0
296870	289180	80013X	PARTICIPANT	\N	PRESENT	0
296871	289180	14281W	PARTICIPANT	\N	PRESENT	0
296872	289180	14021P	PARTICIPANT	\N	PRESENT	0
296873	289180	01057W	PARTICIPANT	\N	PRESENT	0
296874	289180	08052W	PARTICIPANT	\N	PRESENT	0
296875	289180	14119M	PARTICIPANT	\N	PRESENT	0
296876	289180	19415P	PARTICIPANT	\N	PRESENT	0
296877	289180	19723Y	PARTICIPANT	\N	PRESENT	0
296878	289180	98005N	PARTICIPANT	\N	PRESENT	0
296879	289180	19711U	PARTICIPANT	\N	PRESENT	0
296880	289180	14069U	PARTICIPANT	\N	PRESENT	0
296881	289180	11103C	PARTICIPANT	\N	PRESENT	0
296882	289180	14331P	PARTICIPANT	\N	PRESENT	0
296883	289180	19701S	PARTICIPANT	\N	PRESENT	0
296884	289180	19762G	PARTICIPANT	\N	PRESENT	0
296885	289180	14059S	PARTICIPANT	\N	PRESENT	0
296886	289180	19733B	PARTICIPANT	\N	PRESENT	0
296887	289180	11045K	PARTICIPANT	\N	PRESENT	0
296888	289180	19621T	PARTICIPANT	\N	PRESENT	0
296889	289180	14097Y	PARTICIPANT	\N	PRESENT	0
296890	289180	19333N	PARTICIPANT	\N	PRESENT	0
296891	289180	19367Y	PARTICIPANT	\N	PRESENT	0
296892	289180	95037J	PARTICIPANT	\N	PRESENT	0
296893	289180	11097X	PARTICIPANT	\N	PRESENT	0
296894	289180	19697Q	PARTICIPANT	\N	PRESENT	0
296895	289180	14239U	PARTICIPANT	\N	PRESENT	0
296896	289180	19581D	PARTICIPANT	\N	PRESENT	0
296897	289180	19651A	PARTICIPANT	\N	PRESENT	0
296898	289180	19545Y	PARTICIPANT	\N	PRESENT	0
296899	289180	19657G	PARTICIPANT	\N	PRESENT	0
296900	289180	04057K	PARTICIPANT	\N	PRESENT	0
296901	289180	14041T	PARTICIPANT	\N	PRESENT	0
296902	289180	19689Q	PARTICIPANT	\N	PRESENT	0
296903	289180	19760E	PARTICIPANT	\N	PRESENT	0
296904	289180	08019V	PARTICIPANT	\N	PRESENT	0
296905	289180	04092N	PARTICIPANT	\N	PRESENT	0
296906	289180	19679N	PARTICIPANT	\N	PRESENT	0
296907	289180	19565D	PARTICIPANT	\N	PRESENT	0
296908	289180	14223L	PARTICIPANT	\N	PRESENT	0
296909	289180	19413M	PARTICIPANT	\N	PRESENT	0
296910	289180	11064N	PARTICIPANT	\N	PRESENT	0
296911	289180	14195A	PARTICIPANT	\N	PRESENT	0
296912	289180	19479G	PARTICIPANT	\N	PRESENT	0
296913	289180	14042U	PARTICIPANT	\N	PRESENT	0
296914	289180	19569H	PARTICIPANT	\N	PRESENT	0
296915	289180	11012A	PARTICIPANT	\N	PRESENT	0
296916	289180	08031R	PARTICIPANT	\N	PRESENT	0
296917	289180	14355X	PARTICIPANT	\N	PRESENT	0
296918	289180	88008L	PARTICIPANT	\N	PRESENT	0
296919	289180	01034P	PARTICIPANT	\N	PRESENT	0
296920	289180	08056B	PARTICIPANT	\N	PRESENT	0
296921	289180	11056N	PARTICIPANT	\N	PRESENT	0
296922	289180	01048V	PARTICIPANT	\N	PRESENT	0
296923	289180	19593H	PARTICIPANT	\N	PRESENT	0
296924	289180	14213J	PARTICIPANT	\N	PRESENT	0
296925	289180	11043H	PARTICIPANT	\N	PRESENT	0
296926	289180	19553Y	PARTICIPANT	\N	PRESENT	0
296927	289180	19631V	PARTICIPANT	\N	PRESENT	0
296928	289180	14249W	PARTICIPANT	\N	PRESENT	0
296929	289180	14061L	PARTICIPANT	\N	PRESENT	0
296930	289180	19575F	PARTICIPANT	\N	PRESENT	0
296931	289180	14105F	PARTICIPANT	\N	PRESENT	0
296932	289180	14026U	PARTICIPANT	\N	PRESENT	0
296933	289180	14073Q	PARTICIPANT	\N	PRESENT	0
296934	289180	95030B	PARTICIPANT	\N	PRESENT	0
296935	289180	19747H	PARTICIPANT	\N	PRESENT	0
296936	289180	14083S	PARTICIPANT	\N	PRESENT	0
296937	289180	19611R	PARTICIPANT	\N	PRESENT	0
296938	289180	14053L	PARTICIPANT	\N	PRESENT	0
296939	289180	18083K	PARTICIPANT	\N	PRESENT	0
296940	289180	08061X	PARTICIPANT	\N	PRESENT	0
296941	289180	11083R	PARTICIPANT	\N	PRESENT	0
296942	289180	14215L	PARTICIPANT	\N	PRESENT	0
296943	289180	04044E	PARTICIPANT	\N	PRESENT	0
296944	289180	87003B	PARTICIPANT	\N	PRESENT	0
296945	289180	08045X	PARTICIPANT	\N	PRESENT	0
296946	289180	11067R	PARTICIPANT	\N	PRESENT	0
296947	289180	14147R	PARTICIPANT	\N	PRESENT	0
296948	289180	01062T	PARTICIPANT	\N	PRESENT	0
296949	289180	19527W	PARTICIPANT	\N	PRESENT	0
296950	289180	14157T	PARTICIPANT	\N	PRESENT	0
296951	289180	19387D	PARTICIPANT	\N	PRESENT	0
296952	289180	08039A	PARTICIPANT	\N	PRESENT	0
296953	289180	04088S	PARTICIPANT	\N	PRESENT	0
296954	289180	14187A	PARTICIPANT	\N	PRESENT	0
296955	289180	19647E	PARTICIPANT	\N	PRESENT	0
296956	289180	19649G	PARTICIPANT	\N	PRESENT	0
296957	289180	11104D	PARTICIPANT	\N	PRESENT	0
296958	289180	19551W	PARTICIPANT	\N	PRESENT	0
296962	289180	14030Q	PARTICIPANT	\N	PRESENT	0
296960	289180	14205J	PARTICIPANT	\N	PRESENT	0
296961	289180	14033T	PARTICIPANT	\N	PRESENT	0
296963	289180	08017T	PARTICIPANT	\N	PRESENT	0
296964	289180	01058X	PARTICIPANT	\N	PRESENT	0
296965	289180	14357A	PARTICIPANT	\N	PRESENT	0
296966	289180	97011G	PARTICIPANT	\N	PRESENT	0
296967	289180	14179A	PARTICIPANT	\N	PRESENT	0
296968	289180	19737F	PARTICIPANT	\N	PRESENT	0
296969	289180	19253P	PARTICIPANT	\N	PRESENT	0
296970	289180	10006L	PARTICIPANT	\N	PRESENT	0
296971	289180	14265W	PARTICIPANT	\N	PRESENT	0
296972	289180	19691J	PARTICIPANT	\N	PRESENT	0
296973	289180	19749K	PARTICIPANT	\N	PRESENT	0
296974	289180	19725B	PARTICIPANT	\N	PRESENT	0
296975	289180	19349W	PARTICIPANT	\N	PRESENT	0
296976	289180	08015R	PARTICIPANT	\N	PRESENT	0
296977	289180	04061F	PARTICIPANT	\N	PRESENT	0
297035	289181	14034U	PARTICIPANT	\N	PRESENT	0
297036	289181	14087W	PARTICIPANT	\N	PRESENT	0
297037	289181	19521Q	PARTICIPANT	\N	PRESENT	0
297038	289181	08052W	PARTICIPANT	\N	PRESENT	0
297039	289181	11067R	PARTICIPANT	\N	PRESENT	0
297040	289181	19715Y	PARTICIPANT	\N	PRESENT	0
297041	289181	14227Q	PARTICIPANT	\N	PRESENT	0
297042	289181	17779H	PARTICIPANT	\N	PRESENT	0
297043	289181	14281W	PARTICIPANT	\N	PRESENT	0
297044	289181	14042U	PARTICIPANT	\N	PRESENT	0
297045	289181	19737F	PARTICIPANT	\N	PRESENT	0
297046	289181	19629C	PARTICIPANT	\N	PRESENT	0
297047	289181	19253P	PARTICIPANT	\N	PRESENT	0
297048	289181	19691J	PARTICIPANT	\N	PRESENT	0
297049	289181	04045F	PARTICIPANT	\N	PRESENT	0
297050	289181	19697Q	PARTICIPANT	\N	PRESENT	0
297051	289181	19719D	PARTICIPANT	\N	PRESENT	0
297052	289181	19387D	PARTICIPANT	\N	PRESENT	0
297053	289181	04097T	PARTICIPANT	\N	PRESENT	0
297054	289181	19703U	PARTICIPANT	\N	PRESENT	0
297055	289181	19515S	PARTICIPANT	\N	PRESENT	0
297056	289181	19723Y	PARTICIPANT	\N	PRESENT	0
297057	289181	14029X	PARTICIPANT	\N	PRESENT	0
297058	289181	19663E	PARTICIPANT	\N	PRESENT	0
297059	289181	04088S	PARTICIPANT	\N	PRESENT	0
297060	289181	14033T	PARTICIPANT	\N	PRESENT	0
297061	289181	14157T	PARTICIPANT	\N	PRESENT	0
297062	289181	14041T	PARTICIPANT	\N	PRESENT	0
297063	289181	07029T	PARTICIPANT	\N	PRESENT	0
297064	289181	08019V	PARTICIPANT	\N	PRESENT	0
297065	289181	19575F	PARTICIPANT	\N	PRESENT	0
297066	289181	14357A	PARTICIPANT	\N	PRESENT	0
297067	289181	14061L	PARTICIPANT	\N	PRESENT	0
297068	289181	10006L	PARTICIPANT	\N	PRESENT	0
297069	289181	14059S	PARTICIPANT	\N	PRESENT	0
275952	274851	08048B	PARTICIPANT	\N	EXCUSE	0
276030	274851	95063L	PARTICIPANT	\N	EXCUSE	0
279266	279263	14071N	PARTICIPANT	\N	EXCUSE	0
279267	279263	11048N	PARTICIPANT	\N	EXCUSE	0
279268	279263	08048B	PARTICIPANT	\N	EXCUSE	0
281790	273883	98022P	PARTICIPANT	\N	PRESENT	0
281791	273883	14267Y	PARTICIPANT	\N	PRESENT	0
281792	273883	14331P	PARTICIPANT	\N	PRESENT	0
281793	273883	14219Q	PARTICIPANT	\N	PRESENT	0
281794	273883	19511N	PARTICIPANT	\N	PRESENT	0
281795	273883	14105F	PARTICIPANT	\N	PRESENT	0
281796	273883	08069G	PARTICIPANT	\N	PRESENT	0
281797	273883	08039A	PARTICIPANT	\N	PRESENT	0
281798	273883	14087W	PARTICIPANT	\N	PRESENT	0
281799	273883	18083K	PARTICIPANT	\N	PRESENT	0
281800	273883	14051J	PARTICIPANT	\N	PRESENT	0
281801	273883	80013X	PARTICIPANT	\N	PRESENT	0
281802	273883	87003B	PARTICIPANT	\N	PRESENT	0
281805	273883	95062K	PARTICIPANT	\N	PRESENT	0
281806	273883	19415P	PARTICIPANT	\N	PRESENT	0
281807	273883	17779H	PARTICIPANT	\N	PRESENT	0
281808	273883	19731Y	PARTICIPANT	\N	PRESENT	0
281809	273883	14026U	PARTICIPANT	\N	PRESENT	0
281810	273883	08045X	PARTICIPANT	\N	PRESENT	0
281811	273883	14115H	PARTICIPANT	\N	PRESENT	0
281812	273883	19715Y	PARTICIPANT	\N	PRESENT	0
281813	273883	14038Y	PARTICIPANT	\N	PRESENT	0
281814	273883	07004J	PARTICIPANT	\N	PRESENT	0
281815	273883	08043V	PARTICIPANT	\N	PRESENT	0
281816	273883	97011G	PARTICIPANT	\N	PRESENT	0
281817	273883	04088S	PARTICIPANT	\N	PRESENT	0
281818	273883	04097T	PARTICIPANT	\N	PRESENT	0
281819	273883	04018C	PARTICIPANT	\N	PRESENT	0
281820	273883	19479G	PARTICIPANT	\N	PRESENT	0
281821	273883	14237S	PARTICIPANT	\N	PRESENT	0
281822	273883	11063M	PARTICIPANT	\N	PRESENT	0
281823	273883	19725B	PARTICIPANT	\N	PRESENT	0
281826	273883	19739H	PARTICIPANT	\N	PRESENT	0
281827	273883	14081Q	PARTICIPANT	\N	PRESENT	0
281828	273883	19611R	PARTICIPANT	\N	PRESENT	0
281829	273883	19683J	PARTICIPANT	\N	PRESENT	0
281830	273883	14157T	PARTICIPANT	\N	PRESENT	0
281831	273883	19723Y	PARTICIPANT	\N	PRESENT	0
281832	273883	14121F	PARTICIPANT	\N	PRESENT	0
281833	273883	14073Q	PARTICIPANT	\N	PRESENT	0
281834	273883	19583F	PARTICIPANT	\N	PRESENT	0
281835	273883	14227Q	PARTICIPANT	\N	PRESENT	0
281836	273883	19333N	PARTICIPANT	\N	PRESENT	0
281837	273883	19745F	PARTICIPANT	\N	PRESENT	0
281838	273883	19525U	PARTICIPANT	\N	PRESENT	0
281839	273883	11103C	PARTICIPANT	\N	PRESENT	0
281840	273883	19319Q	PARTICIPANT	\N	PRESENT	0
281841	273883	19691J	PARTICIPANT	\N	PRESENT	0
281842	273883	11110B	PARTICIPANT	\N	PRESENT	0
281843	273883	98029W	PARTICIPANT	\N	PRESENT	0
281844	273883	11041F	PARTICIPANT	\N	PRESENT	0
281845	273883	19747H	PARTICIPANT	\N	PRESENT	0
281846	273883	08052W	PARTICIPANT	\N	PRESENT	0
281847	273883	11066Q	PARTICIPANT	\N	PRESENT	0
281848	273883	19685L	PARTICIPANT	\N	PRESENT	0
281849	273883	04092N	PARTICIPANT	\N	PRESENT	0
281850	273883	92040Q	PARTICIPANT	\N	PRESENT	0
281851	273883	98005N	PARTICIPANT	\N	PRESENT	0
281852	273883	98035U	PARTICIPANT	\N	PRESENT	0
281853	273883	19549D	PARTICIPANT	\N	PRESENT	0
281854	273883	19727D	PARTICIPANT	\N	PRESENT	0
281855	273883	19673G	PARTICIPANT	\N	PRESENT	0
281856	273883	14265W	PARTICIPANT	\N	PRESENT	0
281857	273883	19697Q	PARTICIPANT	\N	PRESENT	0
281858	273883	95037J	PARTICIPANT	\N	PRESENT	0
281859	273883	14239U	PARTICIPANT	\N	PRESENT	0
281860	273883	14107H	PARTICIPANT	\N	PRESENT	0
281861	273883	14201E	PARTICIPANT	\N	PRESENT	0
281862	273883	14109K	PARTICIPANT	\N	PRESENT	0
281863	273883	08061X	PARTICIPANT	\N	PRESENT	0
281864	273883	19631V	PARTICIPANT	\N	PRESENT	0
281865	273883	19737F	PARTICIPANT	\N	PRESENT	0
281866	273883	19521Q	PARTICIPANT	\N	PRESENT	0
281867	273883	04045F	PARTICIPANT	\N	PRESENT	0
281868	273883	14207L	PARTICIPANT	\N	PRESENT	0
281869	273883	17589D	PARTICIPANT	\N	PRESENT	0
281870	273883	19441R	PARTICIPANT	\N	PRESENT	0
281871	273883	08024S	PARTICIPANT	\N	PRESENT	0
281872	273883	08017T	PARTICIPANT	\N	PRESENT	0
281873	273883	19335Q	PARTICIPANT	\N	PRESENT	0
281874	273883	19563B	PARTICIPANT	\N	PRESENT	0
281875	273883	19575F	PARTICIPANT	\N	PRESENT	0
281876	273883	07033P	PARTICIPANT	\N	PRESENT	0
281877	273883	12041X	PARTICIPANT	\N	PRESENT	0
281878	273883	11031D	PARTICIPANT	\N	PRESENT	0
281879	273883	19593H	PARTICIPANT	\N	PRESENT	0
281880	273883	19758L	PARTICIPANT	\N	PRESENT	0
281881	273883	19695N	PARTICIPANT	\N	PRESENT	0
281882	273883	19687N	PARTICIPANT	\N	PRESENT	0
281883	273883	19295A	PARTICIPANT	\N	PRESENT	0
281884	273883	08012N	PARTICIPANT	\N	PRESENT	0
281885	273883	19647E	PARTICIPANT	\N	PRESENT	0
281886	273883	14211G	PARTICIPANT	\N	PRESENT	0
281887	273883	19651A	PARTICIPANT	\N	PRESENT	0
281888	273883	11083R	PARTICIPANT	\N	PRESENT	0
281889	273883	11065P	PARTICIPANT	\N	PRESENT	0
281890	273883	19387D	PARTICIPANT	\N	PRESENT	0
281891	273883	19253P	PARTICIPANT	\N	PRESENT	0
281892	273883	17637T	PARTICIPANT	\N	PRESENT	0
281893	273883	14251Q	PARTICIPANT	\N	PRESENT	0
281894	273883	08073C	PARTICIPANT	\N	PRESENT	0
281895	273883	19329S	PARTICIPANT	\N	PRESENT	0
281896	273883	14241N	PARTICIPANT	\N	PRESENT	0
281897	273883	14195A	PARTICIPANT	\N	PRESENT	0
281898	273883	19719D	PARTICIPANT	\N	PRESENT	0
281899	273883	95063L	PARTICIPANT	\N	PRESENT	0
281900	273883	11101A	PARTICIPANT	\N	PRESENT	0
281901	273883	19301E	PARTICIPANT	\N	PRESENT	0
281902	273883	11072N	PARTICIPANT	\N	PRESENT	0
281903	273883	01062T	PARTICIPANT	\N	PRESENT	0
281904	273883	04059M	PARTICIPANT	\N	PRESENT	0
281905	273883	01028R	PARTICIPANT	\N	PRESENT	0
281906	273883	08055A	PARTICIPANT	\N	PRESENT	0
281907	273883	04035D	PARTICIPANT	\N	PRESENT	0
281908	273883	08010L	PARTICIPANT	\N	PRESENT	0
281909	273883	14021P	PARTICIPANT	\N	PRESENT	0
281910	273883	19649G	PARTICIPANT	\N	PRESENT	0
281911	273883	15447F	PARTICIPANT	\N	PRESENT	0
281912	273883	14097Y	PARTICIPANT	\N	PRESENT	0
281913	273883	19669L	PARTICIPANT	\N	PRESENT	0
281914	273883	19643A	PARTICIPANT	\N	PRESENT	0
281915	273883	11045K	PARTICIPANT	\N	PRESENT	0
281916	273883	11067R	PARTICIPANT	\N	PRESENT	0
281917	273883	14085U	PARTICIPANT	\N	PRESENT	0
281918	273883	11109J	PARTICIPANT	\N	PRESENT	0
281919	273883	11080N	PARTICIPANT	\N	PRESENT	0
281920	273883	04085P	PARTICIPANT	\N	PRESENT	0
281921	273883	11033F	PARTICIPANT	\N	PRESENT	0
281922	273883	11074Q	PARTICIPANT	\N	PRESENT	0
281923	273883	01057W	PARTICIPANT	\N	PRESENT	0
281924	273883	14065Q	PARTICIPANT	\N	PRESENT	0
281925	273883	19515S	PARTICIPANT	\N	PRESENT	0
281926	273883	08058D	PARTICIPANT	\N	PRESENT	0
281927	273883	19527W	PARTICIPANT	\N	PRESENT	0
281928	273883	11077T	PARTICIPANT	\N	PRESENT	0
281929	273883	14031R	PARTICIPANT	\N	PRESENT	0
281930	273883	08031R	PARTICIPANT	\N	PRESENT	0
281931	273883	19667J	PARTICIPANT	\N	PRESENT	0
281932	273883	11115U	PARTICIPANT	\N	PRESENT	0
281933	273883	19713W	PARTICIPANT	\N	PRESENT	0
281934	273883	14083S	PARTICIPANT	\N	PRESENT	0
281935	273883	19369B	PARTICIPANT	\N	PRESENT	0
281936	273883	14205J	PARTICIPANT	\N	PRESENT	0
281937	273883	19699S	PARTICIPANT	\N	PRESENT	0
281938	273883	16685X	PARTICIPANT	\N	PRESENT	0
281939	273883	11085T	PARTICIPANT	\N	PRESENT	0
281940	273883	04089T	PARTICIPANT	\N	PRESENT	0
281941	273883	08044W	PARTICIPANT	\N	PRESENT	0
281942	273883	14253S	PARTICIPANT	\N	PRESENT	0
281943	273883	01024M	PARTICIPANT	\N	PRESENT	0
281944	273883	14030Q	PARTICIPANT	\N	PRESENT	0
281945	273883	96004D	PARTICIPANT	\N	PRESENT	0
281946	273883	14327T	PARTICIPANT	\N	PRESENT	0
281947	273883	05008E	PARTICIPANT	\N	PRESENT	0
281948	273883	14151M	PARTICIPANT	\N	PRESENT	0
281949	273883	11026G	PARTICIPANT	\N	PRESENT	0
281950	273883	19679N	PARTICIPANT	\N	PRESENT	0
281951	273883	04047H	PARTICIPANT	\N	PRESENT	0
281952	273883	98023Q	PARTICIPANT	\N	PRESENT	0
281953	273883	19689Q	PARTICIPANT	\N	PRESENT	0
281954	273883	14159V	PARTICIPANT	\N	PRESENT	0
281955	273883	05012A	PARTICIPANT	\N	PRESENT	0
281956	273883	95015C	PARTICIPANT	\N	PRESENT	0
281957	273883	19711U	PARTICIPANT	\N	PRESENT	0
286724	286723	11053K	PARTICIPANT	\N	PRESENT	0
286725	286723	14159V	PARTICIPANT	\N	PRESENT	0
286726	286723	05012A	PARTICIPANT	\N	PRESENT	0
286728	286727	04008A	PARTICIPANT	\N	PRESENT	0
292922	292921	11053K	PARTICIPANT	\N	PRESENT	0
292923	292921	14159V	PARTICIPANT	\N	PRESENT	0
292924	292921	05012A	PARTICIPANT	\N	PRESENT	0
292926	292925	11053K	PARTICIPANT	\N	PRESENT	0
292927	292925	14159V	PARTICIPANT	\N	PRESENT	0
292928	292925	05012A	PARTICIPANT	\N	PRESENT	0
298271	298201	19521Q	PARTICIPANT	\N	PRESENT	0
298272	298201	04092N	PARTICIPANT	\N	PRESENT	0
298273	298201	14041T	PARTICIPANT	\N	PRESENT	0
298274	298201	98005N	PARTICIPANT	\N	PRESENT	0
298275	298201	08019V	PARTICIPANT	\N	PRESENT	0
298276	298201	19621T	PARTICIPANT	\N	PRESENT	0
298277	298201	19319Q	PARTICIPANT	\N	PRESENT	0
298278	298201	95063L	PARTICIPANT	\N	PRESENT	0
298281	298201	12016W	PARTICIPANT	\N	PRESENT	0
298282	298201	04085P	PARTICIPANT	\N	PRESENT	0
298283	298201	19758L	PARTICIPANT	\N	PRESENT	0
298284	298201	19593H	PARTICIPANT	\N	PRESENT	0
298285	298201	14039A	PARTICIPANT	\N	PRESENT	0
298286	298201	08012N	PARTICIPANT	\N	PRESENT	0
298287	298201	14227Q	PARTICIPANT	\N	PRESENT	0
298288	298201	11067R	PARTICIPANT	\N	PRESENT	0
298289	298201	11045K	PARTICIPANT	\N	PRESENT	0
298290	298201	14281W	PARTICIPANT	\N	PRESENT	0
298291	298201	08052W	PARTICIPANT	\N	PRESENT	0
298292	298201	04045F	PARTICIPANT	\N	PRESENT	0
298293	298201	19697Q	PARTICIPANT	\N	PRESENT	0
298294	298201	19657G	PARTICIPANT	\N	PRESENT	0
298295	298201	14217N	PARTICIPANT	\N	PRESENT	0
298296	298201	11097X	PARTICIPANT	\N	PRESENT	0
298297	298201	19335Q	PARTICIPANT	\N	PRESENT	0
298298	298201	14119M	PARTICIPANT	\N	PRESENT	0
298299	298201	19663E	PARTICIPANT	\N	PRESENT	0
298300	298201	10006L	PARTICIPANT	\N	PRESENT	0
298301	298201	14219Q	PARTICIPANT	\N	PRESENT	0
298302	298201	14195A	PARTICIPANT	\N	PRESENT	0
298303	298201	14071N	PARTICIPANT	\N	PRESENT	0
298304	298201	11012A	PARTICIPANT	\N	PRESENT	0
298305	298201	19760E	PARTICIPANT	\N	PRESENT	0
298306	298201	19679N	PARTICIPANT	\N	PRESENT	0
298307	298201	17779H	PARTICIPANT	\N	PRESENT	0
298309	298308	04038G	PARTICIPANT	\N	PRESENT	0
298310	298308	11041F	PARTICIPANT	\N	PRESENT	0
298311	298308	04097T	PARTICIPANT	\N	PRESENT	0
298312	298308	95062K	PARTICIPANT	\N	PRESENT	0
298313	298308	17637T	PARTICIPANT	\N	PRESENT	0
298315	298314	04038G	PARTICIPANT	\N	PRESENT	0
298316	298314	14357A	PARTICIPANT	\N	PRESENT	0
298317	298314	11070L	PRESIDENT	0	PRESENT	0
298318	298314	04097T	PARTICIPANT	\N	PRESENT	0
298319	298201	14083S	PARTICIPANT	\N	PRESENT	0
298320	298201	19727D	PARTICIPANT	\N	PRESENT	0
298321	298314	12016W	PARTICIPANT	\N	PRESENT	0
298322	298314	17637T	PARTICIPANT	\N	PRESENT	0
298323	298314	95062K	PARTICIPANT	\N	PRESENT	0
298324	298314	19689Q	PARTICIPANT	\N	PRESENT	0
298325	298314	11041F	PARTICIPANT	\N	PRESENT	0
298327	298314	14179A	PARTICIPANT	\N	PRESENT	0
298328	298201	19715Y	PARTICIPANT	\N	PRESENT	0
298330	298201	08010L	PARTICIPANT	\N	PRESENT	0
298336	298333	19253P	PARTICIPANT	\N	PRESENT	0
298332	298308	14357A	PARTICIPANT	\N	PRESENT	0
298334	298333	19741B	PARTICIPANT	\N	PRESENT	0
298335	298333	04038G	PARTICIPANT	\N	PRESENT	0
298269	298201	11072N	PARTICIPANT	\N	PRESENT	0
298270	298201	14087W	PARTICIPANT	\N	PRESENT	0
298337	298333	14357A	PARTICIPANT	\N	PRESENT	0
298338	298333	11070L	PRESIDENT	0	PRESENT	0
298339	298333	04097T	PARTICIPANT	\N	PRESENT	0
298340	298333	19711U	PARTICIPANT	\N	PRESENT	0
298341	298333	12016W	PARTICIPANT	\N	PRESENT	0
298342	298333	95062K	PARTICIPANT	\N	PRESENT	0
298343	298333	19689Q	PARTICIPANT	\N	PRESENT	0
298345	298344	04038G	PARTICIPANT	\N	PRESENT	0
298346	298344	19741B	PARTICIPANT	\N	PRESENT	0
298347	298344	14357A	PARTICIPANT	\N	PRESENT	0
298348	298344	04097T	PARTICIPANT	\N	PRESENT	0
298349	298344	95062K	PARTICIPANT	\N	PRESENT	0
298350	298344	11041F	PARTICIPANT	\N	PRESENT	0
298352	298351	14357A	PARTICIPANT	\N	PRESENT	0
298353	298351	14179A	PARTICIPANT	\N	PRESENT	0
298354	298351	04097T	PARTICIPANT	\N	PRESENT	0
298355	298351	19711U	PRESIDENT	0	PRESENT	0
298356	298351	12016W	PARTICIPANT	\N	PRESENT	0
298357	298351	95062K	PARTICIPANT	\N	PRESENT	0
298358	298351	11070L	PARTICIPANT	\N	EXCUSE	0
298359	298351	04038G	PARTICIPANT	\N	EXCUSE	0
298360	298201	04086Q	PARTICIPANT	\N	PRESENT	0
298361	298201	11031D	PARTICIPANT	\N	PRESENT	0
298362	298201	19687N	PARTICIPANT	\N	PRESENT	0
298417	295637	04092N	PARTICIPANT	\N	PRESENT	0
298418	295637	14087W	PARTICIPANT	\N	PRESENT	0
298419	295637	19521Q	PARTICIPANT	\N	PRESENT	0
298420	295637	19679N	PARTICIPANT	\N	PRESENT	0
298421	295637	19715Y	PARTICIPANT	\N	PRESENT	0
298422	295637	11031D	PARTICIPANT	\N	PRESENT	0
298423	295637	14281W	PARTICIPANT	\N	PRESENT	0
298424	295637	19689Q	PARTICIPANT	\N	PRESENT	0
298425	295637	19727D	PARTICIPANT	\N	PRESENT	0
298426	295637	19711U	PARTICIPANT	\N	PRESENT	0
298427	295637	17779H	PARTICIPANT	\N	PRESENT	0
298428	295637	08012N	PARTICIPANT	\N	PRESENT	0
298429	295637	04045F	PARTICIPANT	\N	PRESENT	0
298430	295637	19697Q	PARTICIPANT	\N	PRESENT	0
298431	295637	19611R	PARTICIPANT	\N	PRESENT	0
298436	295637	08052W	PARTICIPANT	\N	PRESENT	0
298433	295637	19553Y	PARTICIPANT	\N	PRESENT	0
298434	295637	14195A	PARTICIPANT	\N	PRESENT	0
298435	295637	19569H	PARTICIPANT	\N	PRESENT	0
298437	295637	11097X	PARTICIPANT	\N	PRESENT	0
298438	295637	19335Q	PARTICIPANT	\N	PRESENT	0
298439	295637	19758L	PARTICIPANT	\N	PRESENT	0
298440	295637	19760E	PARTICIPANT	\N	PRESENT	0
298441	295637	11067R	PARTICIPANT	\N	PRESENT	0
298442	295637	19663E	PARTICIPANT	\N	PRESENT	0
298443	295637	14217N	PARTICIPANT	\N	PRESENT	0
298444	295637	19621T	PARTICIPANT	\N	PRESENT	0
298445	295637	19657G	PARTICIPANT	\N	PRESENT	0
298446	295637	14119M	PARTICIPANT	\N	PRESENT	0
298447	295637	10006L	PARTICIPANT	\N	PRESENT	0
298448	295637	14071N	PARTICIPANT	\N	PRESENT	0
298449	295637	95063L	PARTICIPANT	\N	PRESENT	0
298450	295637	14029X	PARTICIPANT	\N	PRESENT	0
298451	295637	14105F	PARTICIPANT	\N	PRESENT	0
298452	295637	14059S	PARTICIPANT	\N	PRESENT	0
298453	295637	14083S	PARTICIPANT	\N	PRESENT	0
298454	295637	11012A	PARTICIPANT	\N	PRESENT	0
298500	290145	19663E	PARTICIPANT	\N	PRESENT	0
298501	290145	14239U	PARTICIPANT	\N	PRESENT	0
298502	290147	19663E	PARTICIPANT	\N	PRESENT	0
298503	290147	14239U	PARTICIPANT	\N	PRESENT	0
298579	298578	19709B	PARTICIPANT	\N	PRESENT	0
298580	298578	19575F	PARTICIPANT	\N	PRESENT	0
298581	298578	04045F	PARTICIPANT	\N	PRESENT	0
298415	295637	04044E	PARTICIPANT	\N	PRESENT	0
298416	295637	14227Q	PARTICIPANT	\N	PRESENT	0
298582	298578	14151M	PARTICIPANT	\N	PRESENT	0
298583	298578	11012A	PARTICIPANT	\N	PRESENT	0
298588	298585	14259Y	PARTICIPANT	\N	PRESENT	0
298589	298585	19629C	PARTICIPANT	\N	PRESENT	0
298590	298585	14053L	PARTICIPANT	\N	PRESENT	0
298634	298633	19673G	PARTICIPANT	\N	PRESENT	0
298789	295772	04070G	PARTICIPANT	\N	EXCUSE	0
298816	295638	14123H	PARTICIPANT	\N	PRESENT	0
272804	270530	11056N	PARTICIPANT	\N	PRESENT	0
272805	270530	11033F	PARTICIPANT	\N	PRESENT	0
272806	270530	19565D	PARTICIPANT	\N	PRESENT	0
272807	270530	11031D	PARTICIPANT	\N	PRESENT	0
272808	270530	11040E	PARTICIPANT	\N	PRESENT	0
272809	270530	12041X	PARTICIPANT	\N	PRESENT	0
272810	270530	14235Q	PARTICIPANT	\N	PRESENT	0
272811	270530	19687N	PARTICIPANT	\N	PRESENT	0
272812	270530	19695N	PARTICIPANT	\N	PRESENT	0
272813	270530	19593H	PARTICIPANT	\N	PRESENT	0
272814	270530	19531S	PARTICIPANT	\N	PRESENT	0
272815	270530	19489J	PARTICIPANT	\N	PRESENT	0
272816	270530	17779H	PARTICIPANT	\N	PRESENT	0
272817	270530	19683J	PARTICIPANT	\N	PRESENT	0
272818	270530	14227Q	PARTICIPANT	\N	PRESENT	0
272819	270530	11067R	PARTICIPANT	\N	PRESENT	0
272820	270530	11109J	PARTICIPANT	\N	PRESENT	0
272821	270530	14197C	PARTICIPANT	\N	PRESENT	0
272822	270530	19715Y	PARTICIPANT	\N	PRESENT	0
272823	270530	80013X	PARTICIPANT	\N	PRESENT	0
272824	270530	19727D	PARTICIPANT	\N	PRESENT	0
272825	270530	19413M	PARTICIPANT	\N	PRESENT	0
272826	270530	14109K	PARTICIPANT	\N	PRESENT	0
272827	270530	14097Y	PARTICIPANT	\N	PRESENT	0
272828	270530	14257W	PARTICIPANT	\N	PRESENT	0
272829	270530	14207L	PARTICIPANT	\N	PRESENT	0
272830	270530	14229S	PARTICIPANT	\N	PRESENT	0
272831	270530	11104D	PARTICIPANT	\N	PRESENT	0
272832	270530	14159V	PARTICIPANT	\N	PRESENT	0
272833	270530	08024S	PARTICIPANT	\N	PRESENT	0
272834	270530	08052W	PARTICIPANT	\N	PRESENT	0
272835	270530	04034C	PARTICIPANT	\N	PRESENT	0
272836	270530	19697Q	PARTICIPANT	\N	PRESENT	0
272837	270530	08061X	PARTICIPANT	\N	PRESENT	0
272838	270530	04092N	PARTICIPANT	\N	PRESENT	0
272839	270530	11063M	PARTICIPANT	\N	PRESENT	0
272840	270530	88008L	PARTICIPANT	\N	PRESENT	0
272841	270530	19253P	PARTICIPANT	\N	PRESENT	0
272842	270530	08031R	PARTICIPANT	\N	PRESENT	0
273586	273585	96004D	PARTICIPANT	\N	PRESENT	0
273587	273585	14073Q	PARTICIPANT	\N	PRESENT	0
273589	273588	96004D	PARTICIPANT	\N	PRESENT	0
273590	273588	14073Q	PARTICIPANT	\N	PRESENT	0
273597	273596	04061F	PARTICIPANT	\N	PRESENT	0
273598	273596	14001X	PARTICIPANT	\N	PRESENT	0
273606	273603	14225N	PARTICIPANT	\N	PRESENT	0
273632	273295	14097Y	PARTICIPANT	\N	PRESENT	0
273633	273295	04035D	PARTICIPANT	\N	PRESENT	0
273634	273295	19443T	PARTICIPANT	\N	PRESENT	0
273635	273295	14133K	PARTICIPANT	\N	PRESENT	0
273636	273295	04034C	PARTICIPANT	\N	PRESENT	0
273637	273295	14235Q	PARTICIPANT	\N	PRESENT	0
273638	273295	01058X	PARTICIPANT	\N	PRESENT	0
273639	273295	11027H	PARTICIPANT	\N	PRESENT	0
273640	273295	08058D	PARTICIPANT	\N	PRESENT	0
273641	273295	16685X	PARTICIPANT	\N	PRESENT	0
273642	273295	04042C	PRESIDENT	0	PRESENT	0
273643	273295	19251M	PARTICIPANT	\N	PRESENT	0
273644	273295	11066Q	PARTICIPANT	\N	PRESENT	0
273645	273295	19319Q	PARTICIPANT	\N	PRESENT	0
273646	273295	95037J	PARTICIPANT	\N	PRESENT	0
273647	273295	14055N	PARTICIPANT	\N	PRESENT	0
273648	273295	19709B	PARTICIPANT	\N	PRESENT	0
273649	273295	98050T	PARTICIPANT	\N	PRESENT	0
273650	273295	97011G	PARTICIPANT	\N	PRESENT	0
273651	273295	14211G	PARTICIPANT	\N	PRESENT	0
273652	273295	19583F	PARTICIPANT	\N	PRESENT	0
273653	273295	08047A	PARTICIPANT	\N	PRESENT	0
273654	273295	98029W	PARTICIPANT	\N	PRESENT	0
273655	273295	11054L	PARTICIPANT	\N	PRESENT	0
273656	273295	08053X	PARTICIPANT	\N	PRESENT	0
273657	273295	19421M	PARTICIPANT	\N	PRESENT	0
273658	273295	95067Q	PARTICIPANT	\N	PRESENT	0
273659	273295	08056B	PARTICIPANT	\N	PRESENT	0
273660	273295	98005N	PARTICIPANT	\N	PRESENT	0
273661	273295	04040A	PARTICIPANT	\N	PRESENT	0
273662	273295	14193X	PARTICIPANT	\N	PRESENT	0
273663	273295	14267Y	PARTICIPANT	\N	PRESENT	0
273928	263484	19695N	PARTICIPANT	\N	PRESENT	0
273929	263484	19553Y	PARTICIPANT	\N	PRESENT	0
273931	263484	14119M	PARTICIPANT	\N	PRESENT	0
273932	263484	19349W	PARTICIPANT	\N	PRESENT	0
273933	273625	14237S	PARTICIPANT	\N	PRESENT	0
273968	273625	98023Q	PARTICIPANT	\N	PRESENT	0
273935	273625	95062K	PARTICIPANT	\N	EXCUSE	0
273936	273625	19685L	PARTICIPANT	\N	EXCUSE	0
273939	263484	14173T	PARTICIPANT	\N	PRESENT	0
273940	263484	04086Q	PARTICIPANT	\N	PRESENT	0
272791	270530	86034E	PARTICIPANT	\N	PRESENT	0
272803	270530	04085P	PARTICIPANT	\N	PRESENT	0
273946	273625	19737F	PARTICIPANT	\N	PRESENT	0
273947	273625	19387D	PARTICIPANT	\N	PRESENT	0
273953	263484	14026U	PARTICIPANT	\N	PRESENT	0
273954	263484	19573D	PARTICIPANT	\N	PRESENT	0
273955	263484	14201E	PARTICIPANT	\N	PRESENT	0
273957	273625	15447F	PARTICIPANT	\N	PRESENT	0
273958	273625	14029X	PARTICIPANT	\N	PRESENT	0
273959	273625	08060W	PARTICIPANT	\N	PRESENT	0
273960	273625	08055A	PARTICIPANT	\N	PRESENT	0
273961	273625	19681G	PARTICIPANT	\N	PRESENT	0
273963	273625	14038Y	PARTICIPANT	\N	PRESENT	0
273964	273625	14031R	PARTICIPANT	\N	PRESENT	0
273965	273625	19733B	PARTICIPANT	\N	PRESENT	0
273966	273625	14157T	PARTICIPANT	\N	PRESENT	0
273970	273625	19333N	PARTICIPANT	\N	PRESENT	0
273971	273625	19637C	PARTICIPANT	\N	PRESENT	0
273972	273625	14051J	PARTICIPANT	\N	PRESENT	0
273973	273625	08009T	PRESIDENT	0	PRESENT	0
273974	273625	19347U	PARTICIPANT	\N	PRESENT	0
273975	273625	14219Q	PARTICIPANT	\N	PRESENT	0
273976	263484	11064N	PARTICIPANT	\N	PRESENT	0
273977	263484	14135M	PARTICIPANT	\N	PRESENT	0
273978	273625	19599P	PARTICIPANT	\N	PRESENT	0
273979	273625	19503N	PARTICIPANT	\N	PRESENT	0
273980	273625	04097T	PARTICIPANT	\N	PRESENT	0
273982	273625	19551W	PARTICIPANT	\N	PRESENT	0
273983	263484	19643A	PARTICIPANT	\N	PRESENT	0
273984	263484	19593H	PARTICIPANT	\N	PRESENT	0
273986	263484	07029T	PARTICIPANT	\N	PRESENT	0
273990	263484	14109K	PARTICIPANT	\N	PRESENT	0
273991	273625	11065P	PARTICIPANT	\N	PRESENT	0
273992	273625	14103D	PARTICIPANT	\N	PRESENT	0
273993	263484	19691J	PARTICIPANT	\N	PRESENT	0
273994	263484	19533U	PARTICIPANT	\N	PRESENT	0
274007	263484	17583W	PARTICIPANT	\N	PRESENT	0
274008	263484	14071N	PARTICIPANT	\N	PRESENT	0
274009	263484	08017T	PARTICIPANT	\N	PRESENT	0
274010	263484	19697Q	PARTICIPANT	\N	PRESENT	0
274011	263484	19413M	PARTICIPANT	\N	PRESENT	0
274012	263484	14251Q	PARTICIPANT	\N	PRESENT	0
274013	273619	14053L	PARTICIPANT	\N	PRESENT	0
274014	273619	14065Q	PARTICIPANT	\N	PRESENT	0
274015	273619	14111D	PARTICIPANT	\N	PRESENT	0
274016	273619	10015M	PARTICIPANT	\N	PRESENT	0
274017	273619	14001X	PARTICIPANT	\N	PRESENT	0
274018	273619	19543W	PARTICIPANT	\N	PRESENT	0
274019	273619	01024M	PARTICIPANT	\N	PRESENT	0
274020	273619	04038G	PARTICIPANT	\N	PRESENT	0
274021	273619	01028R	PARTICIPANT	\N	PRESENT	0
274022	273619	05008E	PRESIDENT	0	PRESENT	0
274023	273619	19447X	PARTICIPANT	\N	PRESENT	0
274024	273619	19725B	PARTICIPANT	\N	PRESENT	0
274025	273619	19489J	PARTICIPANT	\N	PRESENT	0
274026	273619	14041T	PARTICIPANT	\N	PRESENT	0
274027	273619	14147R	PARTICIPANT	\N	PRESENT	0
274028	273619	14069U	PARTICIPANT	\N	PRESENT	0
274029	273619	11049P	PARTICIPANT	\N	PRESENT	0
274030	273619	11072N	PARTICIPANT	\N	PRESENT	0
274031	273619	04044E	PARTICIPANT	\N	EXCUSE	0
274032	273619	04047H	PARTICIPANT	\N	EXCUSE	0
274033	273619	14259Y	PARTICIPANT	\N	EXCUSE	0
274034	263484	14221J	PARTICIPANT	\N	PRESENT	0
274035	273625	18083K	PARTICIPANT	\N	PRESENT	0
274067	263484	99004R	PARTICIPANT	\N	PRESENT	0
274068	263484	10006L	PARTICIPANT	\N	PRESENT	0
274069	263484	19347U	PARTICIPANT	\N	PRESENT	0
274070	263484	14215L	PARTICIPANT	\N	PRESENT	0
274071	263484	14199E	PARTICIPANT	\N	PRESENT	0
274072	263484	14069U	PARTICIPANT	\N	PRESENT	0
274073	263484	14197C	PARTICIPANT	\N	PRESENT	0
274074	263484	04047H	PARTICIPANT	\N	PRESENT	0
274075	263484	14191V	PARTICIPANT	\N	PRESENT	0
297070	289181	19621T	PARTICIPANT	\N	PRESENT	0
297071	289181	14187A	PARTICIPANT	\N	PRESENT	0
297072	289181	14213J	PARTICIPANT	\N	PRESENT	0
297073	289181	14265W	PARTICIPANT	\N	PRESENT	0
297074	289181	19367Y	PARTICIPANT	\N	PRESENT	0
297075	289181	14119M	PARTICIPANT	\N	PRESENT	0
297076	289181	19693L	PARTICIPANT	\N	PRESENT	0
297081	289181	04044E	PARTICIPANT	\N	PRESENT	0
297078	289181	19467C	PARTICIPANT	\N	PRESENT	0
297079	289181	14147R	PARTICIPANT	\N	PRESENT	0
297080	289181	04033B	PARTICIPANT	\N	PRESENT	0
297082	289181	19631V	PARTICIPANT	\N	PRESENT	0
297083	289181	11097X	PARTICIPANT	\N	PRESENT	0
297084	289181	14231L	PARTICIPANT	\N	PRESENT	0
297085	289181	19553Y	PARTICIPANT	\N	PRESENT	0
297086	289181	14223L	PARTICIPANT	\N	PRESENT	0
297087	289181	04070G	PARTICIPANT	\N	PRESENT	0
297088	289181	14329V	PARTICIPANT	\N	PRESENT	0
297089	289181	19733B	PARTICIPANT	\N	PRESENT	0
297090	289181	11103C	PARTICIPANT	\N	PRESENT	0
297094	289181	11031D	PARTICIPANT	\N	PRESENT	0
297092	289181	14105F	PARTICIPANT	\N	PRESENT	0
297093	289181	14215L	PARTICIPANT	\N	PRESENT	0
297095	289181	19679N	PARTICIPANT	\N	PRESENT	0
297096	289181	19735D	PARTICIPANT	\N	PRESENT	0
297097	289181	19569H	PARTICIPANT	\N	PRESENT	0
297098	289181	04092N	PARTICIPANT	\N	PRESENT	0
297099	289181	14195A	PARTICIPANT	\N	PRESENT	0
297100	289181	14205J	PARTICIPANT	\N	PRESENT	0
297101	289181	19749K	PARTICIPANT	\N	PRESENT	0
297102	289181	14030Q	PARTICIPANT	\N	PRESENT	0
297103	289181	11043H	PARTICIPANT	\N	PRESENT	0
297104	289181	19383Y	PARTICIPANT	\N	PRESENT	0
297105	289181	08015R	PARTICIPANT	\N	PRESENT	0
297106	289181	19760E	PARTICIPANT	\N	PRESENT	0
297107	289181	08031R	PARTICIPANT	\N	PRESENT	0
297108	289181	01057W	PARTICIPANT	\N	PRESENT	0
297109	289181	19727D	PARTICIPANT	\N	PRESENT	0
297110	289181	19689Q	PARTICIPANT	\N	PRESENT	0
297111	289181	95030B	PARTICIPANT	\N	PRESENT	0
297112	289181	19413M	PARTICIPANT	\N	PRESENT	0
297113	289181	19531S	PARTICIPANT	\N	PRESENT	0
297114	289181	19349W	PARTICIPANT	\N	PRESENT	0
297115	289181	08061X	PARTICIPANT	\N	PRESENT	0
297116	289181	14207L	PARTICIPANT	\N	PRESENT	0
297117	289181	19503N	PARTICIPANT	\N	PRESENT	0
297118	289181	19713W	PARTICIPANT	\N	PRESENT	0
297119	289181	18083K	PARTICIPANT	\N	PRESENT	0
297120	289181	14097Y	PARTICIPANT	\N	PRESENT	0
297121	289181	14219Q	PARTICIPANT	\N	PRESENT	0
297122	289181	19741B	PARTICIPANT	\N	PRESENT	0
297123	289181	14229S	PARTICIPANT	\N	PRESENT	0
297124	289181	19565D	PARTICIPANT	\N	PRESENT	0
297125	289181	14069U	PARTICIPANT	\N	PRESENT	0
297126	289181	14083S	PARTICIPANT	\N	PRESENT	0
297127	289181	19479G	PARTICIPANT	\N	PRESENT	0
297128	289181	14026U	PARTICIPANT	\N	PRESENT	0
297129	295836	19697Q	PARTICIPANT	\N	PRESENT	0
297130	295836	11067R	PARTICIPANT	\N	PRESENT	0
297131	295836	14355X	PARTICIPANT	\N	PRESENT	0
297132	295836	19569H	PARTICIPANT	\N	PRESENT	0
297133	295836	11097X	PARTICIPANT	\N	PRESENT	0
297134	295836	04045F	PARTICIPANT	\N	PRESENT	0
297135	295836	14223L	PARTICIPANT	\N	PRESENT	0
297136	295836	14026U	PARTICIPANT	\N	PRESENT	0
297137	295836	14227Q	PARTICIPANT	\N	PRESENT	0
297138	295836	19703U	PARTICIPANT	\N	PRESENT	0
297139	295836	19553Y	PARTICIPANT	\N	PRESENT	0
297140	295836	14087W	PARTICIPANT	\N	PRESENT	0
297141	295836	14281W	PARTICIPANT	\N	PRESENT	0
297142	295836	19679N	PARTICIPANT	\N	PRESENT	0
297143	295836	14042U	PARTICIPANT	\N	PRESENT	0
297144	295836	19575F	PARTICIPANT	\N	PRESENT	0
297145	295836	14213J	PARTICIPANT	\N	PRESENT	0
297146	295836	19367Y	PARTICIPANT	\N	PRESENT	0
297147	295836	14217N	PARTICIPANT	\N	PRESENT	0
297148	295836	10006L	PARTICIPANT	\N	PRESENT	0
297149	295836	98024R	PARTICIPANT	\N	PRESENT	0
297150	295836	19521Q	PARTICIPANT	\N	PRESENT	0
297151	295836	04092N	PRESIDENT	0	PRESENT	0
297152	295836	08052W	PARTICIPANT	\N	PRESENT	0
297153	295836	19691J	PARTICIPANT	\N	PRESENT	0
297154	295836	19727D	PARTICIPANT	\N	PRESENT	0
297155	295836	14119M	PARTICIPANT	\N	PRESENT	0
297156	295836	11103C	PARTICIPANT	\N	PRESENT	0
297157	295836	14071N	PARTICIPANT	\N	PRESENT	0
297158	295836	19657G	PARTICIPANT	\N	PRESENT	0
297159	295836	08048B	PARTICIPANT	\N	PRESENT	0
297160	295836	19715Y	PARTICIPANT	\N	EXCUSE	0
297161	295836	08041T	PARTICIPANT	\N	EXCUSE	0
297162	295308	14327T	PARTICIPANT	\N	PRESENT	0
297163	295308	14331P	PARTICIPANT	\N	PRESENT	0
297164	295308	04071H	PARTICIPANT	\N	PRESENT	0
297165	295308	01048V	PARTICIPANT	\N	PRESENT	0
297166	295308	19545Y	PARTICIPANT	\N	PRESENT	0
297167	295308	01057W	PARTICIPANT	\N	PRESENT	0
297168	295308	11074Q	PRESIDENT	0	PRESENT	0
297169	295308	19667J	PARTICIPANT	\N	PRESENT	0
297170	295308	88008L	PARTICIPANT	\N	PRESENT	0
297171	295308	11070L	PARTICIPANT	\N	PRESENT	0
297172	295308	19671E	PARTICIPANT	\N	PRESENT	0
297173	295308	07029T	PARTICIPANT	\N	PRESENT	0
297174	295308	14085U	PARTICIPANT	\N	PRESENT	0
297175	295308	08010L	PARTICIPANT	\N	PRESENT	0
297176	295308	14253S	PARTICIPANT	\N	PRESENT	0
297177	295308	11048N	PARTICIPANT	\N	PRESENT	0
297178	295308	19479G	PARTICIPANT	\N	PRESENT	0
297179	295308	19647E	PARTICIPANT	\N	PRESENT	0
297180	295308	19711U	PARTICIPANT	\N	PRESENT	0
297181	295308	08034U	PARTICIPANT	\N	PRESENT	0
297182	295308	19531S	PARTICIPANT	\N	PRESENT	0
297183	295308	19689Q	PARTICIPANT	\N	PRESENT	0
297184	295308	08011M	PARTICIPANT	\N	PRESENT	0
297185	295308	14159V	PARTICIPANT	\N	PRESENT	0
297186	295308	11040E	PARTICIPANT	\N	PRESENT	0
297187	295308	14199E	PARTICIPANT	\N	PRESENT	0
297188	295308	08073C	PARTICIPANT	\N	PRESENT	0
297189	295308	19741B	PARTICIPANT	\N	PRESENT	0
297190	295308	14121F	PARTICIPANT	\N	PRESENT	0
297191	295308	11053K	PARTICIPANT	\N	PRESENT	0
297192	295308	14225N	PARTICIPANT	\N	PRESENT	0
297287	294985	04040A	PARTICIPANT	\N	PRESENT	0
297288	295836	19663E	PARTICIPANT	\N	PRESENT	0
297292	294985	95037J	PARTICIPANT	\N	PRESENT	0
297299	295774	02002K	PARTICIPANT	\N	PRESENT	0
297300	295774	17637T	PARTICIPANT	\N	PRESENT	0
297301	295774	19713W	PARTICIPANT	\N	PRESENT	0
297302	294985	14193X	PARTICIPANT	\N	PRESENT	0
297303	295774	19731Y	PARTICIPANT	\N	PRESENT	0
297337	294209	19713W	PARTICIPANT	\N	PRESENT	0
297361	289182	11070L	PARTICIPANT	\N	PRESENT	0
297362	289182	19319Q	PARTICIPANT	\N	PRESENT	0
297363	289182	19731Y	PARTICIPANT	\N	PRESENT	0
297364	289182	14223L	PARTICIPANT	\N	PRESENT	0
297365	289182	11103C	PARTICIPANT	\N	PRESENT	0
297366	289182	07034Q	PARTICIPANT	\N	PRESENT	0
297367	289182	19521Q	PARTICIPANT	\N	PRESENT	0
297368	289182	04092N	PARTICIPANT	\N	PRESENT	0
297369	289182	14087W	PARTICIPANT	\N	PRESENT	0
297370	289182	19679N	PARTICIPANT	\N	PRESENT	0
297371	289182	14195A	PARTICIPANT	\N	PRESENT	0
297372	289182	19583F	PARTICIPANT	\N	PRESENT	0
297373	289182	08052W	PARTICIPANT	\N	PRESENT	0
297374	289182	14030Q	PARTICIPANT	\N	PRESENT	0
297375	289182	19697Q	PARTICIPANT	\N	PRESENT	0
297376	289182	19671E	PARTICIPANT	\N	PRESENT	0
297380	289182	14281W	PARTICIPANT	\N	PRESENT	0
297381	289182	19675J	PARTICIPANT	\N	PRESENT	0
297382	289182	19621T	PARTICIPANT	\N	PRESENT	0
297383	289182	19569H	PARTICIPANT	\N	PRESENT	0
297384	289182	19737F	PARTICIPANT	\N	PRESENT	0
297385	289182	19467C	PARTICIPANT	\N	PRESENT	0
297389	289182	14227Q	PARTICIPANT	\N	PRESENT	0
297390	289182	14205J	PARTICIPANT	\N	PRESENT	0
297391	289182	14105F	PARTICIPANT	\N	PRESENT	0
297392	289182	14063N	PARTICIPANT	\N	PRESENT	0
297393	289182	11031D	PARTICIPANT	\N	PRESENT	0
297394	289182	08019V	PARTICIPANT	\N	PRESENT	0
297395	289182	19335Q	PARTICIPANT	\N	PRESENT	0
297396	289182	19727D	PARTICIPANT	\N	PRESENT	0
297397	289182	19643A	PARTICIPANT	\N	PRESENT	0
297398	289182	19693L	PARTICIPANT	\N	PRESENT	0
297399	289182	10015M	PARTICIPANT	\N	PRESENT	0
297400	289182	11056N	PARTICIPANT	\N	PRESENT	0
297401	289182	19687N	PARTICIPANT	\N	PRESENT	0
297402	289182	11104D	PARTICIPANT	\N	PRESENT	0
297403	289182	19758L	PARTICIPANT	\N	PRESENT	0
297404	289182	14071N	PARTICIPANT	\N	PRESENT	0
297405	289182	14073Q	PARTICIPANT	\N	PRESENT	0
274259	273624	19333N	PARTICIPANT	\N	PRESENT	0
274260	273624	08060W	PARTICIPANT	\N	PRESENT	0
274311	273906	04070G	PRESIDENT	0	PRESENT	0
274312	273906	19699S	PARTICIPANT	\N	PRESENT	0
274313	273906	08035V	PARTICIPANT	\N	PRESENT	0
274314	273906	08043V	PARTICIPANT	\N	PRESENT	0
274315	273906	19693L	PARTICIPANT	\N	PRESENT	0
274316	273906	14201E	PARTICIPANT	\N	PRESENT	0
274317	273906	19731Y	PARTICIPANT	\N	PRESENT	0
274318	273906	08020N	PARTICIPANT	\N	PRESENT	0
274319	273906	19573D	PARTICIPANT	\N	PRESENT	0
274320	273906	04059M	PARTICIPANT	\N	PRESENT	0
274321	273906	19735D	PARTICIPANT	\N	PRESENT	0
274322	273906	14063N	PARTICIPANT	\N	PRESENT	0
274323	273906	11083R	PARTICIPANT	\N	PRESENT	0
274324	273906	11043H	PARTICIPANT	\N	PRESENT	0
274325	273906	04018C	PARTICIPANT	\N	PRESENT	0
274326	273906	08039A	PARTICIPANT	\N	PRESENT	0
274327	273906	14059S	PARTICIPANT	\N	EXCUSE	0
274328	273906	14061L	PARTICIPANT	\N	EXCUSE	0
274329	273624	19383Y	PARTICIPANT	\N	PRESENT	0
274330	273624	19681G	PARTICIPANT	\N	PRESENT	0
274331	273624	14169X	PARTICIPANT	\N	PRESENT	0
274332	273624	19685L	PARTICIPANT	\N	PRESENT	0
274334	273624	18083K	PARTICIPANT	\N	PRESENT	0
274335	273906	14229S	PARTICIPANT	\N	PRESENT	0
274336	273906	14241N	PARTICIPANT	\N	PRESENT	0
274337	273906	08016S	PARTICIPANT	\N	PRESENT	0
274338	273906	19593H	PARTICIPANT	\N	PRESENT	0
274339	273906	19643A	PARTICIPANT	\N	PRESENT	0
274340	273906	87003B	PARTICIPANT	\N	PRESENT	0
274341	273906	14030Q	PARTICIPANT	\N	PRESENT	0
274342	273906	14109K	PARTICIPANT	\N	PRESENT	0
274343	273906	19749K	PARTICIPANT	\N	PRESENT	0
274344	273906	12041X	PARTICIPANT	\N	PRESENT	0
274345	273906	19533U	PARTICIPANT	\N	PRESENT	0
274346	273906	08017T	PARTICIPANT	\N	PRESENT	0
274347	273906	92040Q	PARTICIPANT	\N	PRESENT	0
274348	273906	08031R	PARTICIPANT	\N	PRESENT	0
274349	273906	04057K	PARTICIPANT	\N	PRESENT	0
274350	273906	14251Q	PARTICIPANT	\N	PRESENT	0
274351	273906	14107H	PARTICIPANT	\N	PRESENT	0
274352	273302	14097Y	PARTICIPANT	\N	PRESENT	0
274353	273302	14105F	PARTICIPANT	\N	PRESENT	0
274354	273302	98018T	PARTICIPANT	\N	PRESENT	0
274355	273302	04042C	PRESIDENT	0	PRESENT	0
274356	273302	14028W	PARTICIPANT	\N	PRESENT	0
274357	273302	11066Q	PARTICIPANT	\N	PRESENT	0
274358	273302	08049C	PARTICIPANT	\N	PRESENT	0
274359	273624	11065P	PARTICIPANT	\N	PRESENT	0
274360	273624	19289C	PARTICIPANT	\N	PRESENT	0
274361	273302	04034C	PARTICIPANT	\N	PRESENT	0
274362	273302	19669L	PARTICIPANT	\N	PRESENT	0
274363	273302	19721W	PARTICIPANT	\N	PRESENT	0
274364	273302	19319Q	PARTICIPANT	\N	PRESENT	0
274365	273302	95037J	PARTICIPANT	\N	PRESENT	0
274366	273302	19709B	PARTICIPANT	\N	PRESENT	0
274367	273302	14267Y	PARTICIPANT	\N	PRESENT	0
274368	273302	14193X	PARTICIPANT	\N	PRESENT	0
274369	273302	98050T	PARTICIPANT	\N	PRESENT	0
274370	273302	08053X	PARTICIPANT	\N	PRESENT	0
274371	273302	97011G	PARTICIPANT	\N	PRESENT	0
274372	273302	19583F	PARTICIPANT	\N	PRESENT	0
274373	273302	08047A	PARTICIPANT	\N	PRESENT	0
274374	273302	19421M	PARTICIPANT	\N	PRESENT	0
274375	273302	14235Q	PARTICIPANT	\N	PRESENT	0
274376	273302	95030B	PARTICIPANT	\N	PRESENT	0
274377	273302	14055N	PARTICIPANT	\N	PRESENT	0
274378	273302	08058D	PARTICIPANT	\N	PRESENT	0
274379	273302	11064N	PARTICIPANT	\N	PRESENT	0
274380	273302	98005N	PARTICIPANT	\N	PRESENT	0
274381	273302	19251M	PARTICIPANT	\N	PRESENT	0
274382	273302	11080N	PARTICIPANT	\N	PRESENT	0
274383	273302	01058X	PARTICIPANT	\N	PRESENT	0
274384	273302	04040A	PARTICIPANT	\N	PRESENT	0
274385	273302	11054L	PARTICIPANT	\N	PRESENT	0
274386	273302	08061X	PARTICIPANT	\N	PRESENT	0
274387	273302	98029W	PARTICIPANT	\N	PRESENT	0
274388	273302	04035D	PARTICIPANT	\N	PRESENT	0
274389	273302	95067Q	PARTICIPANT	\N	PRESENT	0
274390	273302	14133K	PARTICIPANT	\N	PRESENT	0
274391	273302	01062T	PARTICIPANT	\N	PRESENT	0
274392	273302	14255U	PARTICIPANT	\N	PRESENT	0
274413	273302	16685X	PARTICIPANT	\N	PRESENT	0
274414	273304	98005N	PARTICIPANT	\N	PRESENT	0
274415	273304	95030B	PARTICIPANT	\N	PRESENT	0
274416	273304	11080N	PARTICIPANT	\N	PRESENT	0
274417	273304	04034C	PARTICIPANT	\N	PRESENT	0
274418	273304	01058X	PARTICIPANT	\N	PRESENT	0
274419	273304	04040A	PARTICIPANT	\N	PRESENT	0
274420	273304	14079W	PARTICIPANT	\N	PRESENT	0
274421	273304	11027H	PARTICIPANT	\N	PRESENT	0
274422	273304	16685X	PARTICIPANT	\N	PRESENT	0
274423	273304	04042C	PRESIDENT	0	PRESENT	0
274424	273304	11054L	PARTICIPANT	\N	PRESENT	0
274425	273304	11066Q	PARTICIPANT	\N	PRESENT	0
274426	273304	19669L	PARTICIPANT	\N	PRESENT	0
274427	273304	08056B	PARTICIPANT	\N	PRESENT	0
274428	273304	95037J	PARTICIPANT	\N	PRESENT	0
274429	273304	14055N	PARTICIPANT	\N	PRESENT	0
274430	273304	19421M	PARTICIPANT	\N	PRESENT	0
274431	273304	19709B	PARTICIPANT	\N	PRESENT	0
274432	273304	08049C	PARTICIPANT	\N	PRESENT	0
274433	273304	14193X	PARTICIPANT	\N	PRESENT	0
274434	273304	08053X	PARTICIPANT	\N	PRESENT	0
274435	273304	97011G	PARTICIPANT	\N	PRESENT	0
274436	273304	08061X	PARTICIPANT	\N	PRESENT	0
274437	273304	08047A	PARTICIPANT	\N	PRESENT	0
274438	273304	98029W	PARTICIPANT	\N	PRESENT	0
274439	273304	14097Y	PARTICIPANT	\N	PRESENT	0
274440	273304	04035D	PARTICIPANT	\N	PRESENT	0
274441	273304	95067Q	PARTICIPANT	\N	PRESENT	0
274442	273304	14133K	PARTICIPANT	\N	PRESENT	0
274443	273304	01062T	PARTICIPANT	\N	PRESENT	0
274444	273304	14235Q	PARTICIPANT	\N	PRESENT	0
274445	273304	08058D	PARTICIPANT	\N	PRESENT	0
274446	273304	14028W	PARTICIPANT	\N	PRESENT	0
274447	273304	19251M	PARTICIPANT	\N	PRESENT	0
274448	273304	19721W	PARTICIPANT	\N	PRESENT	0
274449	273304	19319Q	PARTICIPANT	\N	PRESENT	0
274450	273304	14105F	PARTICIPANT	\N	PRESENT	0
274451	273304	98018T	PARTICIPANT	\N	PRESENT	0
274452	273304	14267Y	PARTICIPANT	\N	PRESENT	0
274453	273304	11064N	PARTICIPANT	\N	PRESENT	0
274454	273304	98050T	PARTICIPANT	\N	PRESENT	0
274455	273304	19583F	PARTICIPANT	\N	PRESENT	0
274456	273304	14211G	PARTICIPANT	\N	PRESENT	0
274457	273304	14255U	PARTICIPANT	\N	PRESENT	0
274459	273907	04070G	PRESIDENT	0	PRESENT	0
274460	273907	19699S	PARTICIPANT	\N	PRESENT	0
274461	273907	12041X	PARTICIPANT	\N	PRESENT	0
274462	273907	19533U	PARTICIPANT	\N	PRESENT	0
274463	273907	14229S	PARTICIPANT	\N	PRESENT	0
274464	273907	14241N	PARTICIPANT	\N	PRESENT	0
274465	273907	19573D	PARTICIPANT	\N	PRESENT	0
274466	273907	08017T	PARTICIPANT	\N	PRESENT	0
274467	273907	92040Q	PARTICIPANT	\N	PRESENT	0
274468	273907	08039A	PARTICIPANT	\N	PRESENT	0
274469	273907	08031R	PARTICIPANT	\N	PRESENT	0
274470	273907	19593H	PARTICIPANT	\N	PRESENT	0
274471	273907	19643A	PARTICIPANT	\N	PRESENT	0
274472	273907	04057K	PARTICIPANT	\N	PRESENT	0
274473	273907	19693L	PARTICIPANT	\N	PRESENT	0
274474	273907	14201E	PARTICIPANT	\N	PRESENT	0
274475	273907	19731Y	PARTICIPANT	\N	PRESENT	0
274476	273907	14251Q	PARTICIPANT	\N	PRESENT	0
274477	273907	08020N	PARTICIPANT	\N	PRESENT	0
274478	273907	19735D	PARTICIPANT	\N	PRESENT	0
274479	273907	14063N	PARTICIPANT	\N	PRESENT	0
274480	273907	14109K	PARTICIPANT	\N	PRESENT	0
274481	273907	11104D	PARTICIPANT	\N	PRESENT	0
274482	273907	11043H	PARTICIPANT	\N	PRESENT	0
274483	273907	19749K	PARTICIPANT	\N	PRESENT	0
274484	273907	04018C	PARTICIPANT	\N	PRESENT	0
274485	273907	04059M	PARTICIPANT	\N	PRESENT	0
274486	273907	08035V	PARTICIPANT	\N	PRESENT	0
274487	273907	14107H	PARTICIPANT	\N	PRESENT	0
274488	273907	11083R	PARTICIPANT	\N	PRESENT	0
274489	273907	08043V	PARTICIPANT	\N	PRESENT	0
274490	273907	87003B	PARTICIPANT	\N	PRESENT	0
274491	273907	08016S	PARTICIPANT	\N	PRESENT	0
274492	273907	19399H	PARTICIPANT	\N	PRESENT	0
274493	273907	14030Q	PARTICIPANT	\N	PRESENT	0
274494	273907	19621T	PARTICIPANT	\N	PRESENT	0
274495	273907	14059S	PARTICIPANT	\N	EXCUSE	0
274496	273907	14061L	PARTICIPANT	\N	EXCUSE	0
274502	273667	14331P	PARTICIPANT	\N	EXCUSE	0
274503	273668	14331P	PARTICIPANT	\N	EXCUSE	0
274505	273325	19711U	PARTICIPANT	\N	PRESENT	0
298891	289189	14241N	PARTICIPANT	\N	PRESENT	0
298892	289189	14039A	PARTICIPANT	\N	PRESENT	0
298893	289189	04085P	PARTICIPANT	\N	PRESENT	0
298894	289189	19593H	PARTICIPANT	\N	PRESENT	0
298895	289189	19735D	PARTICIPANT	\N	PRESENT	0
298896	289189	08012N	PARTICIPANT	\N	PRESENT	0
298897	289189	04057K	PARTICIPANT	\N	PRESENT	0
298898	289189	14123H	PARTICIPANT	\N	PRESENT	0
298899	289189	19693L	PARTICIPANT	\N	PRESENT	0
298900	289189	19565D	PARTICIPANT	\N	PRESENT	0
298901	289189	19727D	PARTICIPANT	\N	PRESENT	0
298902	289189	11067R	PARTICIPANT	\N	PRESENT	0
298903	289189	11109J	PARTICIPANT	\N	PRESENT	0
298904	289189	08017T	PARTICIPANT	\N	PRESENT	0
298905	289189	14281W	PARTICIPANT	\N	PRESENT	0
298906	289189	08043V	PARTICIPANT	\N	PRESENT	0
298907	289189	11083R	PARTICIPANT	\N	PRESENT	0
298908	289189	08039A	PARTICIPANT	\N	PRESENT	0
298909	289189	14251Q	PARTICIPANT	\N	PRESENT	0
298910	289189	19553Y	PARTICIPANT	\N	PRESENT	0
298911	289189	11012A	PARTICIPANT	\N	PRESENT	0
298974	298973	14187A	PARTICIPANT	\N	PRESENT	0
298913	289189	19521Q	PARTICIPANT	\N	PRESENT	0
298914	289189	19747H	PARTICIPANT	\N	PRESENT	0
298915	289189	14087W	PARTICIPANT	\N	PRESENT	0
298916	289189	05012A	PARTICIPANT	\N	PRESENT	0
298917	289189	19573D	PARTICIPANT	\N	PRESENT	0
298918	289189	19399H	PARTICIPANT	\N	PRESENT	0
298919	289189	14041T	PARTICIPANT	\N	PRESENT	0
298920	289189	19679N	PARTICIPANT	\N	PRESENT	0
298921	289189	14021P	PARTICIPANT	\N	PRESENT	0
298922	289189	17637T	PARTICIPANT	\N	PRESENT	0
298923	289189	19711U	PARTICIPANT	\N	PRESENT	0
298924	289189	14059S	PARTICIPANT	\N	PRESENT	0
298925	289189	04018C	PARTICIPANT	\N	PRESENT	0
298926	289189	19621T	PARTICIPANT	\N	PRESENT	0
298927	289189	14073Q	PARTICIPANT	\N	PRESENT	0
298975	298973	19441R	PARTICIPANT	\N	PRESENT	0
298929	298622	19515S	PARTICIPANT	\N	PRESENT	0
298930	298622	14187A	PARTICIPANT	\N	PRESENT	0
298931	298622	19441R	PARTICIPANT	\N	PRESENT	0
298932	298622	08062Y	PARTICIPANT	\N	PRESENT	0
298933	298622	19695N	PARTICIPANT	\N	PRESENT	0
298934	298622	11090Q	PRESIDENT	0	PRESENT	0
298935	298622	19631V	PARTICIPANT	\N	PRESENT	0
298936	298622	04088S	PARTICIPANT	\N	PRESENT	0
298937	298622	11056N	PARTICIPANT	\N	PRESENT	0
298938	298622	08019V	PARTICIPANT	\N	PRESENT	0
298939	298622	19747H	PARTICIPANT	\N	PRESENT	0
298940	298622	14265W	PARTICIPANT	\N	PRESENT	0
298941	298622	19591F	PARTICIPANT	\N	PRESENT	0
298942	289189	19647E	PARTICIPANT	\N	PRESENT	0
298889	289189	11070L	PARTICIPANT	\N	PRESENT	0
298890	289189	19533U	PARTICIPANT	\N	PRESENT	0
298943	298622	08038Y	PARTICIPANT	\N	PRESENT	0
298944	298622	04008A	PARTICIPANT	\N	PRESENT	0
298956	298622	08068F	PARTICIPANT	\N	PRESENT	0
298976	298973	08062Y	PARTICIPANT	\N	PRESENT	0
298977	298973	11090Q	PRESIDENT	0	PRESENT	0
298978	298973	19631V	PARTICIPANT	\N	PRESENT	0
298979	298973	04088S	PARTICIPANT	\N	PRESENT	0
298980	298973	08068F	PARTICIPANT	\N	PRESENT	0
298981	298973	19507S	PARTICIPANT	\N	PRESENT	0
298982	298973	08019V	PARTICIPANT	\N	PRESENT	0
298983	298973	14197C	PARTICIPANT	\N	PRESENT	0
298984	298973	19369B	PARTICIPANT	\N	PRESENT	0
298985	298973	19747H	PARTICIPANT	\N	PRESENT	0
298986	298973	19511N	PARTICIPANT	\N	PRESENT	0
298987	298973	08028W	PARTICIPANT	\N	PRESENT	0
298988	298973	14265W	PARTICIPANT	\N	PRESENT	0
298989	298973	14329V	PARTICIPANT	\N	PRESENT	0
298990	298973	19591F	PARTICIPANT	\N	PRESENT	0
298991	294874	19649G	PARTICIPANT	\N	PRESENT	0
298992	294874	07034Q	PRESIDENT	0	PRESENT	0
298993	294874	04044E	PARTICIPANT	\N	PRESENT	0
298994	294874	19585H	PARTICIPANT	\N	PRESENT	0
298995	294874	19447X	PARTICIPANT	\N	PRESENT	0
298996	294874	05008E	PRESIDENT	1	PRESENT	0
298997	294874	14089Y	PARTICIPANT	\N	PRESENT	0
298998	294874	19489J	PARTICIPANT	\N	PRESENT	0
298999	294874	19629C	PARTICIPANT	\N	PRESENT	0
299000	294874	14041T	PARTICIPANT	\N	PRESENT	0
299001	294874	14147R	PARTICIPANT	\N	PRESENT	0
299002	294874	14151M	PARTICIPANT	\N	PRESENT	0
299003	294874	08018U	PARTICIPANT	\N	PRESENT	0
299004	294874	11049P	PARTICIPANT	\N	PRESENT	0
299005	294874	11072N	PARTICIPANT	\N	PRESENT	0
299006	294874	19762G	PARTICIPANT	\N	PRESENT	0
299007	294874	98035U	PARTICIPANT	\N	PRESENT	0
299008	294874	11026G	PARTICIPANT	\N	PRESENT	0
299009	294874	11085T	PARTICIPANT	\N	PRESENT	0
299010	294874	01028R	PARTICIPANT	\N	PRESENT	0
299011	294874	14053L	PARTICIPANT	\N	EXCUSE	0
299012	294874	19729F	PARTICIPANT	\N	EXCUSE	0
299013	294874	14065Q	PARTICIPANT	\N	EXCUSE	0
299014	294874	04038G	PARTICIPANT	\N	EXCUSE	0
299015	294874	04047H	PARTICIPANT	\N	EXCUSE	0
299016	294874	14259Y	PARTICIPANT	\N	EXCUSE	0
299017	294874	04008A	PARTICIPANT	\N	EXCUSE	0
299018	294874	14231L	PARTICIPANT	\N	EXCUSE	0
299019	298973	14357A	PARTICIPANT	\N	PRESENT	0
299020	298973	80013X	PARTICIPANT	\N	PRESENT	0
299021	298973	11099A	PARTICIPANT	\N	PRESENT	0
299022	298973	08015R	PARTICIPANT	\N	PRESENT	0
299023	298973	08038Y	PARTICIPANT	\N	PRESENT	0
299024	298973	14033T	PARTICIPANT	\N	PRESENT	0
299025	298973	01025N	PARTICIPANT	\N	PRESENT	0
299026	298973	14207L	PARTICIPANT	\N	PRESENT	0
299027	298973	19619A	PARTICIPANT	\N	PRESENT	0
299028	298973	14257W	PARTICIPANT	\N	PRESENT	0
299037	299031	14259Y	PARTICIPANT	\N	PRESENT	0
299038	299031	14053L	PARTICIPANT	\N	PRESENT	0
299039	299031	04038G	PARTICIPANT	\N	PRESENT	0
299040	299031	14111D	PARTICIPANT	\N	PRESENT	0
299041	299032	14259Y	PARTICIPANT	\N	PRESENT	0
299042	299032	14053L	PARTICIPANT	\N	PRESENT	0
299043	299032	04038G	PARTICIPANT	\N	PRESENT	0
299044	299033	14259Y	PARTICIPANT	\N	PRESENT	0
299045	299033	14053L	PARTICIPANT	\N	PRESENT	0
299046	299033	04038G	PARTICIPANT	\N	PRESENT	0
299047	299035	14259Y	PARTICIPANT	\N	PRESENT	0
299048	299035	14053L	PARTICIPANT	\N	PRESENT	0
299049	299035	04038G	PARTICIPANT	\N	PRESENT	0
299063	299062	04088S	PARTICIPANT	\N	PRESENT	0
299064	299062	04049K	PARTICIPANT	\N	PRESENT	0
299065	299062	14187A	PARTICIPANT	\N	PRESENT	0
299066	299062	08062Y	PARTICIPANT	\N	PRESENT	0
299067	299062	11090Q	PRESIDENT	0	PRESENT	0
299068	299062	19747H	PARTICIPANT	\N	PRESENT	0
299069	299062	80013X	PARTICIPANT	\N	PRESENT	0
299070	299062	04043D	PARTICIPANT	\N	PRESENT	0
299071	299062	08028W	PARTICIPANT	\N	PRESENT	0
299072	299062	19631V	PARTICIPANT	\N	PRESENT	0
299073	299062	14265W	PARTICIPANT	\N	PRESENT	0
299074	299062	19619A	PARTICIPANT	\N	PRESENT	0
299075	299062	19441R	PARTICIPANT	\N	PRESENT	0
299076	299062	08015R	PARTICIPANT	\N	PRESENT	0
299077	299062	19511N	PARTICIPANT	\N	PRESENT	0
299078	299062	01043Q	PARTICIPANT	\N	PRESENT	0
299079	299062	08038Y	PARTICIPANT	\N	PRESENT	0
299080	299062	01025N	PARTICIPANT	\N	PRESENT	0
299081	299062	08068F	PARTICIPANT	\N	PRESENT	0
299082	289191	14034U	PARTICIPANT	\N	PRESENT	0
299091	289191	14265W	PARTICIPANT	\N	PRESENT	0
299084	299062	19413M	PARTICIPANT	\N	PRESENT	0
299085	299062	08019V	PARTICIPANT	\N	PRESENT	0
299086	299062	14197C	PARTICIPANT	\N	PRESENT	0
299087	299062	19369B	PARTICIPANT	\N	PRESENT	0
299088	299062	14033T	PARTICIPANT	\N	PRESENT	0
299089	299062	14205J	PARTICIPANT	\N	PRESENT	0
299090	289191	14207L	PARTICIPANT	\N	PRESENT	0
299092	289191	19681G	PARTICIPANT	\N	PRESENT	0
299093	289191	19621T	PARTICIPANT	\N	PRESENT	0
299094	289191	11056N	PARTICIPANT	\N	PRESENT	0
299095	289191	14105F	PARTICIPANT	\N	PRESENT	0
299096	289191	08019V	PARTICIPANT	\N	PRESENT	0
299097	289191	04088S	PARTICIPANT	\N	PRESENT	0
299098	289191	14041T	PARTICIPANT	\N	PRESENT	0
299100	289191	08039A	PARTICIPANT	\N	PRESENT	0
299101	289191	04018C	PARTICIPANT	\N	PRESENT	0
299102	289191	14147R	PARTICIPANT	\N	PRESENT	0
299103	289191	19631V	PARTICIPANT	\N	PRESENT	0
299104	289191	14223L	PARTICIPANT	\N	PRESENT	0
299106	289191	14191V	PARTICIPANT	\N	PRESENT	0
299107	289191	19515S	PARTICIPANT	\N	PRESENT	0
299110	289191	04008A	PARTICIPANT	\N	PRESENT	0
299115	289191	19511N	PARTICIPANT	\N	PRESENT	0
299117	289191	19619A	PARTICIPANT	\N	PRESENT	0
299119	289191	14205J	PARTICIPANT	\N	PRESENT	0
274179	263485	11027H	PARTICIPANT	\N	PRESENT	0
274180	263485	19583F	PARTICIPANT	\N	PRESENT	0
274181	263485	19251M	PARTICIPANT	\N	PRESENT	0
274182	263485	98029W	PARTICIPANT	\N	PRESENT	0
274183	263485	04034C	PARTICIPANT	\N	PRESENT	0
274184	263485	01062T	PARTICIPANT	\N	PRESENT	0
274185	263485	08053X	PARTICIPANT	\N	PRESENT	0
274186	263485	14097Y	PARTICIPANT	\N	PRESENT	0
274187	263485	11054L	PARTICIPANT	\N	PRESENT	0
274188	263485	19629C	PARTICIPANT	\N	PRESENT	0
274189	263485	19681G	PARTICIPANT	\N	PRESENT	0
274190	263485	08049C	PARTICIPANT	\N	PRESENT	0
274191	263485	04042C	PARTICIPANT	\N	PRESENT	0
274192	263485	19695N	PARTICIPANT	\N	PRESENT	0
274193	263485	11064N	PARTICIPANT	\N	PRESENT	0
274194	263485	19737F	PARTICIPANT	\N	PRESENT	0
274195	263485	19691J	PARTICIPANT	\N	PRESENT	0
274196	263485	01024M	PARTICIPANT	\N	PRESENT	0
274197	263485	14267Y	PARTICIPANT	\N	PRESENT	0
274198	263485	04040A	PARTICIPANT	\N	PRESENT	0
274199	263485	19421M	PARTICIPANT	\N	PRESENT	0
274200	263485	19367Y	PARTICIPANT	\N	PRESENT	0
274201	263485	19621T	PARTICIPANT	\N	PRESENT	0
274202	263485	98050T	PARTICIPANT	\N	PRESENT	0
274203	263485	14133K	PARTICIPANT	\N	PRESENT	0
274204	263485	08047A	PARTICIPANT	\N	PRESENT	0
274205	263485	98018T	PARTICIPANT	\N	PRESENT	0
274206	263485	04035D	PARTICIPANT	\N	PRESENT	0
274207	263485	14193X	PARTICIPANT	\N	PRESENT	0
274208	263485	95037J	PARTICIPANT	\N	PRESENT	0
274209	263485	14235Q	PARTICIPANT	\N	PRESENT	0
274210	263485	08034U	PARTICIPANT	\N	PRESENT	0
274211	263485	14119M	PARTICIPANT	\N	PRESENT	0
274212	263485	08058D	PARTICIPANT	\N	PRESENT	0
274213	263485	97011G	PARTICIPANT	\N	PRESENT	0
274214	263485	14089Y	PARTICIPANT	\N	PRESENT	0
274215	263485	14211G	PARTICIPANT	\N	PRESENT	0
274216	263485	19565D	PARTICIPANT	\N	PRESENT	0
274217	263485	19669L	PARTICIPANT	\N	PRESENT	0
274218	263485	95067Q	PARTICIPANT	\N	PRESENT	0
274219	263485	01058X	PARTICIPANT	\N	PRESENT	0
274220	263485	14169X	PARTICIPANT	\N	PRESENT	0
274221	263485	95030B	PARTICIPANT	\N	PRESENT	0
274222	263485	14069U	PARTICIPANT	\N	PRESENT	0
274223	263485	19545Y	PARTICIPANT	\N	PRESENT	0
274224	263485	11048N	PARTICIPANT	\N	PRESENT	0
274225	263485	18083K	PARTICIPANT	\N	PRESENT	0
274226	263485	14357A	PARTICIPANT	\N	PRESENT	0
274227	263485	05008E	PARTICIPANT	\N	PRESENT	0
274228	263485	19733B	PARTICIPANT	\N	PRESENT	0
274229	263485	08020N	PARTICIPANT	\N	PRESENT	0
274230	263485	19709B	PARTICIPANT	\N	PRESENT	0
274231	263485	19467C	PARTICIPANT	\N	PRESENT	0
274232	263485	14105F	PARTICIPANT	\N	PRESENT	0
274233	263485	11066Q	PARTICIPANT	\N	PRESENT	0
274234	263485	19479G	PARTICIPANT	\N	PRESENT	0
274235	263485	14265W	PARTICIPANT	\N	PRESENT	0
274236	263485	07029T	PARTICIPANT	\N	PRESENT	0
274237	263485	08015R	PARTICIPANT	\N	PRESENT	0
274238	263485	14026U	PARTICIPANT	\N	PRESENT	0
274239	263485	19533U	PARTICIPANT	\N	PRESENT	0
274240	263485	19447X	PARTICIPANT	\N	PRESENT	0
274241	263485	10006L	PARTICIPANT	\N	PRESENT	0
274242	263485	14215L	PARTICIPANT	\N	PRESENT	0
274243	263485	19575F	PARTICIPANT	\N	PRESENT	0
274244	263485	14079W	PARTICIPANT	\N	PRESENT	0
274245	263485	11056N	PARTICIPANT	\N	PRESENT	0
274246	263485	14147R	PARTICIPANT	\N	PRESENT	0
274247	263485	14083S	PARTICIPANT	\N	PRESENT	0
274248	263485	14231L	PARTICIPANT	\N	PRESENT	0
274249	263485	14255U	PARTICIPANT	\N	PRESENT	0
274250	263485	14213J	PARTICIPANT	\N	PRESENT	0
274588	273302	19443T	PARTICIPANT	\N	EXCUSE	0
274589	273304	19443T	PARTICIPANT	\N	EXCUSE	0
274613	273494	14355X	PARTICIPANT	\N	EXCUSE	0
274616	273494	04045F	PARTICIPANT	\N	EXCUSE	0
274618	273494	14239U	PARTICIPANT	\N	EXCUSE	0
274620	273494	19577H	PARTICIPANT	\N	EXCUSE	0
275057	272043	04045F	PARTICIPANT	\N	EXCUSE	0
275058	272043	08049C	PARTICIPANT	\N	EXCUSE	0
275396	275395	04059M	PARTICIPANT	\N	PRESENT	0
275397	275395	11040E	PARTICIPANT	\N	PRESENT	0
275611	275607	14205J	PARTICIPANT	\N	PRESENT	0
275399	275395	11053K	PARTICIPANT	\N	PRESENT	0
275401	275395	04086Q	PARTICIPANT	\N	PRESENT	0
275402	275395	08052W	PARTICIPANT	\N	PRESENT	0
275404	275395	11070L	PARTICIPANT	\N	PRESENT	0
275405	275395	10006L	PARTICIPANT	\N	PRESENT	0
275406	275395	14041T	PARTICIPANT	\N	PRESENT	0
275408	275395	14034U	PARTICIPANT	\N	PRESENT	0
275409	275395	14231L	PARTICIPANT	\N	PRESENT	0
275412	275395	11064N	PARTICIPANT	\N	PRESENT	0
275415	275395	14241N	PARTICIPANT	\N	PRESENT	0
275420	275395	14159V	PARTICIPANT	\N	PRESENT	0
275422	275395	86034E	PARTICIPANT	\N	PRESENT	0
275424	275395	08034U	PARTICIPANT	\N	PRESENT	0
275428	275395	11077T	PARTICIPANT	\N	PRESENT	0
274177	263485	14034U	PARTICIPANT	\N	PRESENT	0
274178	263485	19563B	PARTICIPANT	\N	PRESENT	0
275432	275395	12016W	PARTICIPANT	\N	PRESENT	0
275434	275395	05012A	PARTICIPANT	\N	PRESENT	0
275436	275395	14135M	PARTICIPANT	\N	PRESENT	0
275610	275607	14135M	PARTICIPANT	\N	PRESENT	0
275625	275624	19295A	PARTICIPANT	\N	PRESENT	0
275626	275624	14205J	PARTICIPANT	\N	PRESENT	0
275627	275624	14135M	PARTICIPANT	\N	PRESENT	0
275654	275653	19467C	PARTICIPANT	\N	PRESENT	0
275655	275653	14033T	PARTICIPANT	\N	PRESENT	0
275656	275653	14205J	PARTICIPANT	\N	PRESENT	0
275657	275653	14135M	PARTICIPANT	\N	PRESENT	0
275658	275653	19619A	PARTICIPANT	\N	PRESENT	0
275692	275690	19369B	PARTICIPANT	\N	PRESENT	0
275700	275699	19369B	PARTICIPANT	\N	PRESENT	0
275702	275701	19369B	PARTICIPANT	\N	PRESENT	0
275706	275705	19369B	PARTICIPANT	\N	PRESENT	0
275708	275707	19369B	PARTICIPANT	\N	PRESENT	0
275710	275709	08055A	PARTICIPANT	\N	PRESENT	0
275711	275709	08043V	PARTICIPANT	\N	PRESENT	0
275713	275709	14085U	PARTICIPANT	\N	PRESENT	0
275714	275709	14195A	PARTICIPANT	\N	PRESENT	0
275715	275709	95037J	PARTICIPANT	\N	PRESENT	0
275716	275709	14213J	PARTICIPANT	\N	PRESENT	0
275717	275709	19441R	PARTICIPANT	\N	PRESENT	0
275718	275709	08053X	PARTICIPANT	\N	PRESENT	0
275719	275709	19369B	PARTICIPANT	\N	PRESENT	0
275720	275709	14109K	PARTICIPANT	\N	PRESENT	0
275721	275709	14265W	PARTICIPANT	\N	PRESENT	0
275722	275709	14107H	PARTICIPANT	\N	PRESENT	0
275723	275709	11097X	PARTICIPANT	\N	PRESENT	0
275725	274851	14028W	PARTICIPANT	\N	EXCUSE	0
275754	274851	14071N	PARTICIPANT	\N	EXCUSE	0
275904	275903	04038G	PARTICIPANT	\N	PRESENT	0
275905	275903	19253P	PARTICIPANT	\N	EXCUSE	0
275906	275903	11070L	PRESIDENT	0	PRESENT	0
275907	275903	04097T	PARTICIPANT	\N	PRESENT	0
275908	275903	19711U	PARTICIPANT	\N	PRESENT	0
275909	275903	95062K	PARTICIPANT	\N	PRESENT	0
275910	275903	19689Q	PARTICIPANT	\N	PRESENT	0
275911	275903	11041F	PARTICIPANT	\N	PRESENT	0
275914	275912	04038G	PARTICIPANT	\N	PRESENT	0
275915	275912	19253P	PARTICIPANT	\N	EXCUSE	0
275916	275912	14357A	PARTICIPANT	\N	PRESENT	0
275917	275912	11070L	PARTICIPANT	\N	EXCUSE	0
275918	275912	04097T	PARTICIPANT	\N	PRESENT	0
275919	275912	19711U	PRESIDENT	0	PRESENT	0
275921	275912	95062K	PARTICIPANT	\N	PRESENT	0
275922	275912	19689Q	PARTICIPANT	\N	PRESENT	0
275923	275912	11041F	PARTICIPANT	\N	EXCUSE	0
275925	275924	04038G	PARTICIPANT	\N	PRESENT	0
275926	275924	19253P	PARTICIPANT	\N	EXCUSE	0
275927	275924	14357A	PARTICIPANT	\N	PRESENT	0
275928	275924	11070L	PARTICIPANT	\N	EXCUSE	0
275929	275924	04097T	PARTICIPANT	\N	PRESENT	0
275930	275924	19711U	PRESIDENT	0	PRESENT	0
275931	275924	95062K	PARTICIPANT	\N	PRESENT	0
275932	275924	19689Q	PARTICIPANT	\N	PRESENT	0
275933	275924	11041F	PARTICIPANT	\N	EXCUSE	0
278304	275843	19631V	PARTICIPANT	\N	PRESENT	0
278305	275843	19515S	PARTICIPANT	\N	PRESENT	0
278306	275843	19707Y	PARTICIPANT	\N	PRESENT	0
278307	275843	11081P	PARTICIPANT	\N	EXCUSE	0
278308	275843	14115H	PARTICIPANT	\N	PRESENT	0
278309	275843	19747H	PARTICIPANT	\N	PRESENT	0
278310	275843	08068F	PARTICIPANT	\N	PRESENT	0
278311	275843	14207L	PARTICIPANT	\N	PRESENT	0
278312	275843	11101A	PARTICIPANT	\N	PRESENT	0
278313	275843	08028W	PARTICIPANT	\N	PRESENT	0
278314	275843	19467C	PARTICIPANT	\N	PRESENT	0
278315	275843	08038Y	PARTICIPANT	\N	PRESENT	0
280898	273877	11072N	PARTICIPANT	\N	PRESENT	0
280899	273877	14331P	PARTICIPANT	\N	PRESENT	0
280900	273877	19569H	PARTICIPANT	\N	PRESENT	0
280901	273877	19619A	PARTICIPANT	\N	PRESENT	0
280902	273877	10006L	PARTICIPANT	\N	PRESENT	0
280903	273877	14239U	PARTICIPANT	\N	PRESENT	0
280905	273877	19553Y	PARTICIPANT	\N	PRESENT	0
280906	273877	96004D	PARTICIPANT	\N	PRESENT	0
280908	273877	19319Q	PARTICIPANT	\N	PRESENT	0
280909	273877	14105F	PARTICIPANT	\N	PRESENT	0
280910	273877	14195A	PARTICIPANT	\N	PRESENT	0
280911	273877	19703U	PARTICIPANT	\N	PRESENT	0
280912	273877	11103C	PARTICIPANT	\N	PRESENT	0
280913	280395	08018U	PARTICIPANT	\N	PRESENT	0
280934	273877	14217N	PARTICIPANT	\N	PRESENT	0
280935	273877	14026U	PARTICIPANT	\N	PRESENT	0
280936	273877	19758L	PARTICIPANT	\N	PRESENT	0
280938	273877	14063N	PARTICIPANT	\N	PRESENT	0
280939	273877	14219Q	PARTICIPANT	\N	PRESENT	0
280940	273877	19335Q	PARTICIPANT	\N	PRESENT	0
280941	273877	14213J	PARTICIPANT	\N	PRESENT	0
280942	273877	95030B	PARTICIPANT	\N	PRESENT	0
280943	273877	14211G	PARTICIPANT	\N	PRESENT	0
280944	273877	98024R	PARTICIPANT	\N	PRESENT	0
280945	273877	19527W	PARTICIPANT	\N	PRESENT	0
280947	273877	19367Y	PARTICIPANT	\N	PRESENT	0
280948	273877	98022P	PARTICIPANT	\N	PRESENT	0
280949	273877	14029X	PARTICIPANT	\N	PRESENT	0
280950	273877	07029T	PARTICIPANT	\N	PRESENT	0
280951	273877	19675J	PARTICIPANT	\N	PRESENT	0
280952	273877	98050T	PARTICIPANT	\N	PRESENT	0
280953	280937	14053L	PARTICIPANT	\N	PRESENT	0
280954	280937	14065Q	PARTICIPANT	\N	PRESENT	0
280955	280937	19649G	PARTICIPANT	\N	PRESENT	0
280956	280937	14111D	PARTICIPANT	\N	PRESENT	0
280957	280937	07034Q	PARTICIPANT	\N	PRESENT	0
280958	280937	11026G	PARTICIPANT	\N	PRESENT	0
280959	280937	10015M	PARTICIPANT	\N	PRESENT	0
280960	280937	14001X	PARTICIPANT	\N	PRESENT	0
280961	280937	01024M	PARTICIPANT	\N	PRESENT	0
280962	280937	19581D	PARTICIPANT	\N	PRESENT	0
280963	280937	04044E	PARTICIPANT	\N	PRESENT	0
280964	280937	04047H	PARTICIPANT	\N	PRESENT	0
280965	280937	19673G	PARTICIPANT	\N	PRESENT	0
280966	280937	01028R	PARTICIPANT	\N	PRESENT	0
280967	280937	11033F	PARTICIPANT	\N	PRESENT	0
280968	280937	05008E	PRESIDENT	0	PRESENT	0
280969	280937	19447X	PARTICIPANT	\N	PRESENT	0
280970	280937	19729F	PARTICIPANT	\N	PRESENT	0
280971	280937	95063L	PARTICIPANT	\N	PRESENT	0
280972	280937	19629C	PARTICIPANT	\N	PRESENT	0
280973	280937	08044W	PARTICIPANT	\N	PRESENT	0
280974	280937	14147R	PARTICIPANT	\N	PRESENT	0
280975	280937	14151M	PARTICIPANT	\N	PRESENT	0
280976	280937	14215L	PARTICIPANT	\N	PRESENT	0
280977	280937	14231L	PARTICIPANT	\N	PRESENT	0
280978	273877	19663E	PARTICIPANT	\N	PRESENT	0
280979	273877	89017R	PARTICIPANT	\N	PRESENT	0
281042	273877	14123H	PARTICIPANT	\N	PRESENT	0
293066	289572	04059M	PARTICIPANT	\N	PRESENT	0
293067	289572	11090Q	PARTICIPANT	\N	PRESENT	0
293068	289572	14205J	PARTICIPANT	\N	PRESENT	0
293072	289572	19503N	PARTICIPANT	\N	PRESENT	0
293070	289572	14221J	PARTICIPANT	\N	PRESENT	0
293071	289572	14135M	PARTICIPANT	\N	PRESENT	0
293073	289572	19683J	PARTICIPANT	\N	PRESENT	0
293074	289572	80013X	PARTICIPANT	\N	PRESENT	0
293075	289572	08060W	PARTICIPANT	\N	PRESENT	0
293076	289572	14207L	PARTICIPANT	\N	PRESENT	0
293077	289572	14257W	PARTICIPANT	\N	PRESENT	0
293078	289572	19413M	PARTICIPANT	\N	PRESENT	0
293079	289572	19269X	PARTICIPANT	\N	PRESENT	0
293080	289572	19301E	PARTICIPANT	\N	PRESENT	0
293081	289572	11072N	PARTICIPANT	\N	PRESENT	0
293082	289572	17589D	PARTICIPANT	\N	PRESENT	0
293083	289572	08016S	PARTICIPANT	\N	PRESENT	0
293084	289572	11099A	PARTICIPANT	\N	PRESENT	0
293085	289572	11056N	PARTICIPANT	\N	PRESENT	0
293086	289572	11012A	PARTICIPANT	\N	PRESENT	0
293087	289572	19619A	PARTICIPANT	\N	PRESENT	0
293088	289572	14083S	PARTICIPANT	\N	PRESENT	0
293089	289572	19695N	PARTICIPANT	\N	PRESENT	0
293090	289572	19565D	PARTICIPANT	\N	PRESENT	0
293091	289572	19347U	PARTICIPANT	\N	PRESENT	0
293092	289572	14033T	PARTICIPANT	\N	PRESENT	0
293093	289572	08019V	PARTICIPANT	\N	PRESENT	0
293094	289572	14357A	PARTICIPANT	\N	PRESENT	0
293095	289572	04043D	PARTICIPANT	\N	PRESENT	0
293096	289572	95030B	PARTICIPANT	\N	PRESENT	0
293097	289572	08034U	PARTICIPANT	\N	PRESENT	0
293098	289572	14265W	PARTICIPANT	\N	PRESENT	0
293099	289572	08010L	PARTICIPANT	\N	PRESENT	0
293100	289572	19643A	PARTICIPANT	\N	PRESENT	0
293101	289572	11109J	PARTICIPANT	\N	PRESENT	0
293102	289572	19507S	PARTICIPANT	\N	PRESENT	0
293103	289572	01048V	PARTICIPANT	\N	PRESENT	0
293104	289572	98050T	PARTICIPANT	\N	PRESENT	0
293105	289572	19711U	PARTICIPANT	\N	PRESENT	0
293106	289572	19563B	PARTICIPANT	\N	PRESENT	0
293107	289572	07029T	PARTICIPANT	\N	PRESENT	0
293108	289572	19551W	PARTICIPANT	\N	PRESENT	0
293112	289572	19705W	PARTICIPANT	\N	PRESENT	0
293113	289572	19693L	PARTICIPANT	\N	PRESENT	0
293114	289572	19583F	PARTICIPANT	\N	PRESENT	0
293115	289572	04057K	PARTICIPANT	\N	PRESENT	0
293116	289572	14327T	PARTICIPANT	\N	PRESENT	0
293117	289572	19707Y	PARTICIPANT	\N	PRESENT	0
293127	289572	14069U	PARTICIPANT	\N	PRESENT	0
293128	289572	08062Y	PARTICIPANT	\N	PRESENT	0
293136	289572	99004R	PARTICIPANT	\N	PRESENT	0
293196	289573	14205J	PARTICIPANT	\N	PRESENT	0
293197	289573	19695N	PARTICIPANT	\N	PRESENT	0
293198	289573	19347U	PARTICIPANT	\N	PRESENT	0
293199	289573	08060W	PARTICIPANT	\N	PRESENT	0
293200	289573	14207L	PARTICIPANT	\N	PRESENT	0
293201	289573	11109J	PARTICIPANT	\N	PRESENT	0
293202	289573	04045F	PARTICIPANT	\N	PRESENT	0
293203	289573	14257W	PARTICIPANT	\N	PRESENT	0
293204	289573	11099A	PARTICIPANT	\N	PRESENT	0
293205	289573	04057K	PARTICIPANT	\N	PRESENT	0
293206	289573	14327T	PARTICIPANT	\N	PRESENT	0
293207	289573	19619A	PARTICIPANT	\N	PRESENT	0
293208	289573	19711U	PARTICIPANT	\N	PRESENT	0
293209	289573	14217N	PARTICIPANT	\N	PRESENT	0
293210	289573	14265W	PARTICIPANT	\N	PRESENT	0
293211	289573	14033T	PARTICIPANT	\N	PRESENT	0
293212	289573	19693L	PARTICIPANT	\N	PRESENT	0
293213	289573	19413M	PARTICIPANT	\N	PRESENT	0
293214	289573	19507S	PARTICIPANT	\N	PRESENT	0
293215	289573	08062Y	PARTICIPANT	\N	PRESENT	0
293216	289573	14135M	PARTICIPANT	\N	PRESENT	0
293217	289573	98050T	PARTICIPANT	\N	PRESENT	0
293218	289573	95030B	PARTICIPANT	\N	PRESENT	0
293219	289573	19563B	PARTICIPANT	\N	PRESENT	0
293220	289573	08016S	PARTICIPANT	\N	PRESENT	0
293221	289573	08019V	PARTICIPANT	\N	PRESENT	0
293222	289573	19269X	PARTICIPANT	\N	PRESENT	0
293224	289573	19705W	PARTICIPANT	\N	PRESENT	0
293225	289573	11072N	PARTICIPANT	\N	PRESENT	0
293226	289573	19583F	PARTICIPANT	\N	PRESENT	0
293227	289573	04085P	PARTICIPANT	\N	PRESENT	0
293228	289573	08010L	PARTICIPANT	\N	PRESENT	0
293229	289573	19667J	PARTICIPANT	\N	PRESENT	0
293231	289573	14357A	PARTICIPANT	\N	PRESENT	0
293232	289573	80013X	PARTICIPANT	\N	PRESENT	0
293236	289573	14069U	PARTICIPANT	\N	PRESENT	0
293240	289573	01048V	PARTICIPANT	\N	PRESENT	0
293241	289573	19643A	PARTICIPANT	\N	PRESENT	0
293245	289573	19593H	PARTICIPANT	\N	PRESENT	0
293261	289573	05008E	PARTICIPANT	\N	PRESENT	0
293262	289573	19301E	PARTICIPANT	\N	PRESENT	0
293194	289573	11070L	PARTICIPANT	\N	PRESENT	0
293195	289573	11090Q	PARTICIPANT	\N	PRESENT	0
273443	273442	08055A	PARTICIPANT	\N	PRESENT	0
273444	273442	04047H	PARTICIPANT	\N	PRESENT	0
273445	273442	14085U	PARTICIPANT	\N	PRESENT	0
273446	273442	11080N	PARTICIPANT	\N	PRESENT	0
273447	273442	11083R	PARTICIPANT	\N	PRESENT	0
273448	273442	01057W	PARTICIPANT	\N	PRESENT	0
273449	273442	08049C	PARTICIPANT	\N	EXCUSE	0
273450	273442	14157T	PARTICIPANT	\N	PRESENT	0
273456	273455	08053X	PARTICIPANT	\N	PRESENT	0
273457	273455	95067Q	PARTICIPANT	\N	PRESENT	0
274506	273325	19531S	PARTICIPANT	\N	PRESENT	0
274507	273325	01057W	PARTICIPANT	\N	PRESENT	0
274508	273325	19689Q	PARTICIPANT	\N	PRESENT	0
274509	273325	11074Q	PRESIDENT	0	PRESENT	0
274510	273325	08011M	PARTICIPANT	\N	PRESENT	0
274511	273325	14225N	PARTICIPANT	\N	PRESENT	0
274512	273325	14159V	PARTICIPANT	\N	PRESENT	0
274513	273325	14173T	PARTICIPANT	\N	PRESENT	0
274514	273325	04086Q	PARTICIPANT	\N	PRESENT	0
274515	273325	07029T	PARTICIPANT	\N	PRESENT	0
274516	273325	14083S	PARTICIPANT	\N	PRESENT	0
274517	273325	11012A	PARTICIPANT	\N	PRESENT	0
274518	273325	14199E	PARTICIPANT	\N	PRESENT	0
274519	273325	14121F	PARTICIPANT	\N	PRESENT	0
274520	273325	11048N	PARTICIPANT	\N	PRESENT	0
274521	273325	19479G	PARTICIPANT	\N	PRESENT	0
274522	273325	08034U	PARTICIPANT	\N	PRESENT	0
274523	273325	01048V	PARTICIPANT	\N	PRESENT	0
274524	273325	19545Y	PARTICIPANT	\N	PRESENT	0
274525	273325	08069G	PARTICIPANT	\N	PRESENT	0
274526	273325	11053K	PARTICIPANT	\N	PRESENT	0
274527	273325	19671E	PARTICIPANT	\N	PRESENT	0
274528	273325	11070L	PARTICIPANT	\N	PRESENT	0
274529	273325	11110B	PARTICIPANT	\N	PRESENT	0
274530	273325	11040E	PARTICIPANT	\N	PRESENT	0
274531	273325	14085U	PARTICIPANT	\N	PRESENT	0
274532	273325	19349W	PARTICIPANT	\N	PRESENT	0
274533	273325	08010L	PARTICIPANT	\N	PRESENT	0
274534	273325	99004R	PARTICIPANT	\N	PRESENT	0
274535	273325	14331P	PARTICIPANT	\N	EXCUSE	0
274536	273325	04071H	PARTICIPANT	\N	EXCUSE	0
274537	273325	08073C	PARTICIPANT	\N	EXCUSE	0
274538	273325	14277B	PARTICIPANT	\N	EXCUSE	0
274587	263756	11077T	PARTICIPANT	\N	PRESENT	0
274590	263756	19669L	PARTICIPANT	\N	PRESENT	0
274591	263756	19447X	PARTICIPANT	\N	PRESENT	0
274592	263756	95063L	PARTICIPANT	\N	PRESENT	0
274593	263756	14193X	PARTICIPANT	\N	PRESENT	0
274594	263756	19415P	PARTICIPANT	\N	PRESENT	0
274595	263756	19731Y	PARTICIPANT	\N	PRESENT	0
274596	263756	19583F	PARTICIPANT	\N	PRESENT	0
274597	263756	14223L	PARTICIPANT	\N	PRESENT	0
274598	263756	14191V	PARTICIPANT	\N	PRESENT	0
274599	263756	14063N	PARTICIPANT	\N	PRESENT	0
274600	263756	11083R	PARTICIPANT	\N	PRESENT	0
274601	263756	07029T	PARTICIPANT	\N	PRESENT	0
274602	263756	19319Q	PARTICIPANT	\N	PRESENT	0
274603	263756	14327T	PARTICIPANT	\N	PRESENT	0
274604	263756	04085P	PARTICIPANT	\N	PRESENT	0
274605	263756	19253P	PARTICIPANT	\N	PRESENT	0
274606	263756	19629C	PARTICIPANT	\N	PRESENT	0
274607	263756	14225N	PARTICIPANT	\N	PRESENT	0
274608	263756	11026G	PARTICIPANT	\N	PRESENT	0
274609	263756	14089Y	PARTICIPANT	\N	PRESENT	0
274610	263756	14083S	PARTICIPANT	\N	PRESENT	0
274611	263756	19737F	PARTICIPANT	\N	PRESENT	0
274612	263756	19367Y	PARTICIPANT	\N	PRESENT	0
274614	263756	19729F	PARTICIPANT	\N	PRESENT	0
274615	263756	14119M	PARTICIPANT	\N	PRESENT	0
274617	263756	08015R	PARTICIPANT	\N	PRESENT	0
274619	263756	14105F	PARTICIPANT	\N	PRESENT	0
274621	263756	08010L	PARTICIPANT	\N	PRESENT	0
274622	263756	08056B	PARTICIPANT	\N	PRESENT	0
274623	263756	14261S	PARTICIPANT	\N	PRESENT	0
274624	263756	11040E	PARTICIPANT	\N	PRESENT	0
274625	263756	19671E	PARTICIPANT	\N	PRESENT	0
274626	263756	95030B	PARTICIPANT	\N	PRESENT	0
274627	263756	14026U	PARTICIPANT	\N	PRESENT	0
274628	263756	19621T	PARTICIPANT	\N	PRESENT	0
274629	263756	01024M	PARTICIPANT	\N	PRESENT	0
274630	263756	14211G	PARTICIPANT	\N	PRESENT	0
274631	263756	19581D	PARTICIPANT	\N	PRESENT	0
274632	263756	14241N	PARTICIPANT	\N	PRESENT	0
274633	263756	19507S	PARTICIPANT	\N	PRESENT	0
274634	263756	14235Q	PARTICIPANT	\N	PRESENT	0
274635	263756	11043H	PARTICIPANT	\N	PRESENT	0
274636	263756	14267Y	PARTICIPANT	\N	PRESENT	0
274637	263756	04088S	PARTICIPANT	\N	PRESENT	0
274638	263756	04057K	PARTICIPANT	\N	PRESENT	0
274639	263756	14111D	PARTICIPANT	\N	PRESENT	0
274640	263756	19349W	PARTICIPANT	\N	PRESENT	0
274641	263756	05008E	PARTICIPANT	\N	PRESENT	0
274642	263756	19387D	PARTICIPANT	\N	PRESENT	0
274643	263756	19479G	PARTICIPANT	\N	PRESENT	0
274644	263756	14069U	PARTICIPANT	\N	PRESENT	0
274645	263756	14265W	PARTICIPANT	\N	PRESENT	0
274646	263756	04035D	PARTICIPANT	\N	PRESENT	0
274647	263756	08039A	PARTICIPANT	\N	PRESENT	0
274648	263756	14251Q	PARTICIPANT	\N	PRESENT	0
274649	263756	11103C	PARTICIPANT	\N	PRESENT	0
274650	263756	19525U	PARTICIPANT	\N	PRESENT	0
274651	263756	19701S	PARTICIPANT	\N	PRESENT	0
274652	263756	14115H	PARTICIPANT	\N	PRESENT	0
274653	263756	11048N	PARTICIPANT	\N	PRESENT	0
274654	263756	19383Y	PARTICIPANT	\N	PRESENT	0
274655	263756	14133K	PARTICIPANT	\N	PRESENT	0
274656	263756	19685L	PARTICIPANT	\N	PRESENT	0
274657	263756	01060R	PARTICIPANT	\N	PRESENT	0
274658	263756	14135M	PARTICIPANT	\N	PRESENT	0
274659	263756	14053L	PARTICIPANT	\N	PRESENT	0
274660	263756	16685X	PARTICIPANT	\N	PRESENT	0
274661	263756	11027H	PARTICIPANT	\N	PRESENT	0
274662	263756	11064N	PARTICIPANT	\N	PRESENT	0
274663	263756	98050T	PARTICIPANT	\N	PRESENT	0
274664	263756	04034C	PARTICIPANT	\N	PRESENT	0
274665	263756	08020N	PARTICIPANT	\N	PRESENT	0
274666	263756	14021P	PARTICIPANT	\N	PRESENT	0
274667	263756	14103D	PARTICIPANT	\N	PRESENT	0
274668	263756	19709B	PARTICIPANT	\N	PRESENT	0
274669	263756	11104D	PARTICIPANT	\N	PRESENT	0
274670	263756	14255U	PARTICIPANT	\N	PRESENT	0
274671	263756	14028W	PARTICIPANT	\N	PRESENT	0
274672	263756	19673G	PARTICIPANT	\N	PRESENT	0
274673	263756	19745F	PARTICIPANT	\N	PRESENT	0
274674	263756	14257W	PARTICIPANT	\N	PRESENT	0
274675	263756	19659J	PARTICIPANT	\N	PRESENT	0
274676	263756	19421M	PARTICIPANT	\N	PRESENT	0
274677	263756	17583W	PARTICIPANT	\N	PRESENT	0
274678	263756	95037J	PARTICIPANT	\N	PRESENT	0
274679	263756	19565D	PARTICIPANT	\N	PRESENT	0
274680	263756	08016S	PARTICIPANT	\N	PRESENT	0
274681	263756	08058D	PARTICIPANT	\N	PRESENT	0
274682	263756	97011G	PARTICIPANT	\N	PRESENT	0
274683	263758	11077T	PARTICIPANT	\N	PRESENT	0
274684	263758	19669L	PARTICIPANT	\N	PRESENT	0
274687	263758	14193X	PARTICIPANT	\N	PRESENT	0
274690	263758	19583F	PARTICIPANT	\N	PRESENT	0
274691	263758	14223L	PARTICIPANT	\N	PRESENT	0
274692	263758	14191V	PARTICIPANT	\N	PRESENT	0
274693	263758	14063N	PARTICIPANT	\N	PRESENT	0
274695	263758	07029T	PARTICIPANT	\N	PRESENT	0
274696	263758	19319Q	PARTICIPANT	\N	PRESENT	0
274700	263758	19629C	PARTICIPANT	\N	PRESENT	0
274701	263758	14225N	PARTICIPANT	\N	PRESENT	0
274702	263758	11026G	PARTICIPANT	\N	PRESENT	0
274704	263758	14083S	PARTICIPANT	\N	PRESENT	0
274705	263758	19737F	PARTICIPANT	\N	PRESENT	0
274706	263758	19367Y	PARTICIPANT	\N	PRESENT	0
274709	263758	08010L	PARTICIPANT	\N	PRESENT	0
274710	263758	08056B	PARTICIPANT	\N	PRESENT	0
274711	263758	14261S	PARTICIPANT	\N	PRESENT	0
274713	263758	19671E	PARTICIPANT	\N	PRESENT	0
274714	263758	95030B	PARTICIPANT	\N	PRESENT	0
282389	282388	11097X	PARTICIPANT	\N	PRESENT	0
282391	282390	19415P	PARTICIPANT	\N	PRESENT	0
282392	282390	11097X	PARTICIPANT	\N	PRESENT	0
282394	282393	11097X	PARTICIPANT	\N	PRESENT	0
282396	282395	11097X	PARTICIPANT	\N	PRESENT	0
282569	282568	04033B	PARTICIPANT	\N	PRESENT	0
282570	282568	95062K	PARTICIPANT	\N	PRESENT	0
282571	282568	11049P	PARTICIPANT	\N	PRESENT	0
282572	282568	10015M	PARTICIPANT	\N	PRESENT	0
282573	282568	95067Q	PARTICIPANT	\N	PRESENT	0
282574	282568	08034U	PARTICIPANT	\N	PRESENT	0
282575	282568	19367Y	PARTICIPANT	\N	PRESENT	0
282576	282568	14217N	PARTICIPANT	\N	PRESENT	0
282577	282568	87003B	PARTICIPANT	\N	PRESENT	0
282578	282568	04035D	PARTICIPANT	\N	PRESENT	0
282579	282568	14105F	PARTICIPANT	\N	PRESENT	0
282580	282568	98022P	PARTICIPANT	\N	PRESENT	0
282581	282568	16685X	PARTICIPANT	\N	PRESENT	0
282582	282568	18083K	PARTICIPANT	\N	PRESENT	0
282583	282568	19663E	PARTICIPANT	\N	PRESENT	0
282738	279265	08038Y	PARTICIPANT	\N	PRESENT	0
282739	279265	04040A	PARTICIPANT	\N	PRESENT	0
291656	286323	14135M	PARTICIPANT	\N	PRESENT	0
291657	286323	14030Q	PARTICIPANT	\N	PRESENT	0
291658	286323	04049K	PARTICIPANT	\N	PRESENT	0
297847	297846	19725B	PARTICIPANT	\N	PRESENT	0
297866	297864	19575F	PARTICIPANT	\N	PRESENT	0
297867	297864	14357A	PARTICIPANT	\N	PRESENT	0
297869	297864	17589D	PARTICIPANT	\N	PRESENT	0
297870	297864	08052W	PRESIDENT	0	PRESENT	0
297871	297864	19735D	PARTICIPANT	\N	PRESENT	0
297873	297864	04045F	PARTICIPANT	\N	PRESENT	0
297874	297864	19421M	PARTICIPANT	\N	PRESENT	0
299121	289191	19507S	PARTICIPANT	\N	PRESENT	0
299124	289191	19253P	PARTICIPANT	\N	PRESENT	0
299125	289191	19611R	PARTICIPANT	\N	PRESENT	0
299127	289191	11109J	PARTICIPANT	\N	PRESENT	0
299131	289191	19695N	PARTICIPANT	\N	PRESENT	0
299134	289191	08038Y	PARTICIPANT	\N	PRESENT	0
299138	289191	04086Q	PARTICIPANT	\N	PRESENT	0
299142	289191	19599P	PARTICIPANT	\N	PRESENT	0
299143	289191	19715Y	PARTICIPANT	\N	PRESENT	0
299144	289191	19347U	PARTICIPANT	\N	PRESENT	0
299145	289191	19301E	PARTICIPANT	\N	PRESENT	0
299146	289191	12016W	PARTICIPANT	\N	PRESENT	0
299147	289191	19651A	PARTICIPANT	\N	PRESENT	0
299148	289191	14229S	PARTICIPANT	\N	PRESENT	0
299149	289191	11012A	PARTICIPANT	\N	PRESENT	0
299150	289191	01025N	PARTICIPANT	\N	PRESENT	0
299151	289191	14042U	PARTICIPANT	\N	PRESENT	0
299152	289191	14219Q	PARTICIPANT	\N	PRESENT	0
299153	289191	19441R	PARTICIPANT	\N	PRESENT	0
299154	289191	19591F	PARTICIPANT	\N	PRESENT	0
299155	289191	11067R	PARTICIPANT	\N	PRESENT	0
299156	289191	08068F	PARTICIPANT	\N	PRESENT	0
299157	289191	19413M	PARTICIPANT	\N	PRESENT	0
299158	289191	14195A	PARTICIPANT	\N	PRESENT	0
299159	289191	19369B	PARTICIPANT	\N	PRESENT	0
299160	289191	19521Q	PARTICIPANT	\N	PRESENT	0
299161	289191	11070L	PARTICIPANT	\N	PRESENT	0
299162	289191	19713W	PARTICIPANT	\N	PRESENT	0
299163	289191	01034P	PARTICIPANT	\N	PRESENT	0
299164	289191	19747H	PARTICIPANT	\N	PRESENT	0
299165	289191	01043Q	PARTICIPANT	\N	PRESENT	0
299166	289191	05008E	PARTICIPANT	\N	PRESENT	0
299167	289191	19745F	PARTICIPANT	\N	PRESENT	0
299168	289191	19739H	PARTICIPANT	\N	PRESENT	0
299169	289191	19335Q	PARTICIPANT	\N	PRESENT	0
299170	289191	10015M	PARTICIPANT	\N	PRESENT	0
299171	289191	14199E	PARTICIPANT	\N	PRESENT	0
299172	289191	11103C	PARTICIPANT	\N	PRESENT	0
299173	289191	19443T	PARTICIPANT	\N	PRESENT	0
299174	289191	14157T	PARTICIPANT	\N	PRESENT	0
299175	289191	14033T	PARTICIPANT	\N	PRESENT	0
299176	289191	18083K	PARTICIPANT	\N	PRESENT	0
299177	289191	19447X	PARTICIPANT	\N	PRESENT	0
299178	289191	14173T	PARTICIPANT	\N	PRESENT	0
299179	289191	14038Y	PARTICIPANT	\N	PRESENT	0
299180	289191	11099A	PARTICIPANT	\N	PRESENT	0
299181	289191	04043D	PARTICIPANT	\N	PRESENT	0
299182	289191	19565D	PARTICIPANT	\N	PRESENT	0
299183	289191	19760E	PARTICIPANT	\N	PRESENT	0
299184	289191	08017T	PARTICIPANT	\N	PRESENT	0
299185	289191	08012N	PARTICIPANT	\N	PRESENT	0
299186	289191	11077T	PARTICIPANT	\N	PRESENT	0
299187	289191	11104D	PARTICIPANT	\N	PRESENT	0
299188	289191	95037J	PARTICIPANT	\N	PRESENT	0
299189	289191	19735D	PARTICIPANT	\N	PRESENT	0
299190	289191	19629C	PARTICIPANT	\N	PRESENT	0
299191	289191	19671E	PARTICIPANT	\N	PRESENT	0
299192	289191	19289C	PARTICIPANT	\N	PRESENT	0
299193	289191	19667J	PARTICIPANT	\N	PRESENT	0
299194	289191	19703U	PARTICIPANT	\N	PRESENT	0
299195	289191	19673G	PARTICIPANT	\N	PRESENT	0
299196	289191	04049K	PARTICIPANT	\N	PRESENT	0
299197	289191	19387D	PARTICIPANT	\N	PRESENT	0
299198	289191	11090Q	PARTICIPANT	\N	PRESENT	0
299199	289191	14187A	PARTICIPANT	\N	PRESENT	0
299200	289191	08045X	PARTICIPANT	\N	PRESENT	0
299201	289191	19383Y	PARTICIPANT	\N	PRESENT	0
299202	289191	01057W	PARTICIPANT	\N	PRESENT	0
299203	289191	17637T	PARTICIPANT	\N	PRESENT	0
299204	289191	11085T	PARTICIPANT	\N	PRESENT	0
299205	289191	19711U	PARTICIPANT	\N	PRESENT	0
299206	289191	08034U	PARTICIPANT	\N	PRESENT	0
299207	289191	19575F	PARTICIPANT	\N	PRESENT	0
299208	289191	04070G	PARTICIPANT	\N	PRESENT	0
299209	289191	08043V	PARTICIPANT	\N	PRESENT	0
299210	289191	19563B	PARTICIPANT	\N	PRESENT	0
299211	289191	19581D	PARTICIPANT	\N	PRESENT	0
299212	289191	04045F	PARTICIPANT	\N	PRESENT	0
299213	289191	08060W	PARTICIPANT	\N	PRESENT	0
299214	289191	14215L	PARTICIPANT	\N	PRESENT	0
299215	289191	08061X	PARTICIPANT	\N	PRESENT	0
299216	289191	14073Q	PARTICIPANT	\N	PRESENT	0
299217	289191	14028W	PARTICIPANT	\N	PRESENT	0
299218	289191	14257W	PARTICIPANT	\N	PRESENT	0
299219	289191	14051J	PARTICIPANT	\N	PRESENT	0
299220	289191	16685X	PARTICIPANT	\N	PRESENT	0
299221	289191	08010L	PARTICIPANT	\N	PRESENT	0
299222	289191	19503N	PARTICIPANT	\N	PRESENT	0
299223	289191	02002K	PARTICIPANT	\N	PRESENT	0
299224	289191	19367Y	PARTICIPANT	\N	PRESENT	0
299225	289191	19399H	PARTICIPANT	\N	PRESENT	0
299226	289191	14119M	PARTICIPANT	\N	PRESENT	0
299227	289191	98050T	PARTICIPANT	\N	PRESENT	0
299228	289191	14063N	PARTICIPANT	\N	PRESENT	0
299229	289191	08028W	PARTICIPANT	\N	PRESENT	0
299230	289191	97011G	PARTICIPANT	\N	PRESENT	0
299231	289191	14026U	PARTICIPANT	\N	PRESENT	0
299232	289191	04085P	PARTICIPANT	\N	PRESENT	0
299233	289191	95062K	PARTICIPANT	\N	PRESENT	0
299234	289191	19749K	PARTICIPANT	\N	PRESENT	0
299235	289191	19701S	PARTICIPANT	\N	PRESENT	0
299236	289191	19643A	PARTICIPANT	\N	PRESENT	0
299237	289191	08015R	PARTICIPANT	\N	PRESENT	0
299238	289191	95030B	PARTICIPANT	\N	PRESENT	0
299239	289191	19727D	PARTICIPANT	\N	PRESENT	0
299241	289191	19697Q	PARTICIPANT	\N	PRESENT	0
299242	289191	14239U	PARTICIPANT	\N	PRESENT	0
299245	289191	19669L	PARTICIPANT	\N	PRESENT	0
299246	289191	17779H	PARTICIPANT	\N	PRESENT	0
299247	289191	19741B	PARTICIPANT	\N	PRESENT	0
299251	289191	14197C	PARTICIPANT	\N	PRESENT	0
299252	289191	08016S	PARTICIPANT	\N	PRESENT	0
299253	289191	99004R	PARTICIPANT	\N	PRESENT	0
299254	289191	14211G	PARTICIPANT	\N	PRESENT	0
299255	289191	14083S	PARTICIPANT	\N	PRESENT	0
299256	289191	14121F	PARTICIPANT	\N	PRESENT	0
299257	289191	11045K	PARTICIPANT	\N	PRESENT	0
299258	289191	14107H	PARTICIPANT	\N	PRESENT	0
299259	289191	98022P	PARTICIPANT	\N	PRESENT	0
299260	289191	11065P	PARTICIPANT	\N	PRESENT	0
299261	289191	19659J	PARTICIPANT	\N	PRESENT	0
299262	289191	14069U	PARTICIPANT	\N	PRESENT	0
299263	289191	19533U	PARTICIPANT	\N	PRESENT	0
299264	289191	19687N	PARTICIPANT	\N	PRESENT	0
299265	289191	19489J	PARTICIPANT	\N	PRESENT	0
299266	289191	11066Q	PARTICIPANT	\N	PRESENT	0
299267	289191	14213J	PARTICIPANT	\N	PRESENT	0
299268	289191	14241N	PARTICIPANT	\N	PRESENT	0
299269	289191	19543W	PARTICIPANT	\N	PRESENT	0
299270	289191	19421M	PARTICIPANT	\N	PRESENT	0
299271	289191	19649G	PARTICIPANT	\N	PRESENT	0
299272	289191	19657G	PARTICIPANT	\N	PRESENT	0
299273	289191	14133K	PARTICIPANT	\N	PRESENT	0
299274	289191	04033B	PARTICIPANT	\N	PRESENT	0
274047	273619	11033F	PARTICIPANT	\N	EXCUSE	0
274048	273619	19629C	PARTICIPANT	\N	EXCUSE	0
274049	273619	19253P	PARTICIPANT	\N	EXCUSE	0
274050	273619	14215L	PARTICIPANT	\N	EXCUSE	0
274051	273619	08045X	PARTICIPANT	\N	EXCUSE	0
274052	273619	11026G	PARTICIPANT	\N	EXCUSE	0
274054	273619	19585H	PARTICIPANT	\N	EXCUSE	0
274458	270980	19349W	PARTICIPANT	\N	PRESENT	0
278316	275843	17589D	PARTICIPANT	\N	PRESENT	0
278317	275843	04089T	PARTICIPANT	\N	EXCUSE	0
278318	275843	19507S	PARTICIPANT	\N	PRESENT	0
278319	275843	14197C	PARTICIPANT	\N	PRESENT	0
278320	275843	14187A	PARTICIPANT	\N	PRESENT	0
278321	275843	01025N	PARTICIPANT	\N	PRESENT	0
278322	275843	19695N	PARTICIPANT	\N	PRESENT	0
278323	275843	19565D	PARTICIPANT	\N	PRESENT	0
278324	275843	14033T	PARTICIPANT	\N	PRESENT	0
278325	275843	19591F	PARTICIPANT	\N	PRESENT	0
278326	275843	19511N	PARTICIPANT	\N	PRESENT	0
278327	275843	11099A	PARTICIPANT	\N	PRESENT	0
278328	275843	04049K	PARTICIPANT	\N	PRESENT	0
278329	275843	01043Q	PARTICIPANT	\N	PRESENT	0
278330	275843	14205J	PARTICIPANT	\N	PRESENT	0
278331	275843	19441R	PARTICIPANT	\N	PRESENT	0
278332	275843	08019V	PARTICIPANT	\N	PRESENT	0
278333	275843	08062Y	PARTICIPANT	\N	PRESENT	0
278334	275843	19369B	PARTICIPANT	\N	PRESENT	0
278335	275843	14257W	PARTICIPANT	\N	PRESENT	0
278336	275843	14265W	PARTICIPANT	\N	PRESENT	0
278337	275843	08021P	PARTICIPANT	\N	PRESENT	0
278338	275843	11090Q	PRESIDENT	0	PRESENT	0
278339	275843	04088S	PARTICIPANT	\N	PRESENT	0
278340	275843	04043D	PARTICIPANT	\N	PRESENT	0
278341	275843	19269X	PARTICIPANT	\N	PRESENT	0
278342	275843	19705W	PARTICIPANT	\N	PRESENT	0
278343	275843	19619A	PARTICIPANT	\N	PRESENT	0
278344	275843	19413M	PARTICIPANT	\N	PRESENT	0
278848	274851	04040A	PRESIDENT	0	PRESENT	0
278849	274851	08049C	PARTICIPANT	\N	PRESENT	0
278850	274851	19565D	PARTICIPANT	\N	PRESENT	0
278851	274851	04086Q	PARTICIPANT	\N	PRESENT	0
278852	274851	14063N	PARTICIPANT	\N	PRESENT	0
278853	274851	11049P	PARTICIPANT	\N	PRESENT	0
278854	274851	14257W	PARTICIPANT	\N	PRESENT	0
278855	274851	08010L	PARTICIPANT	\N	PRESENT	0
278856	274851	19735D	PARTICIPANT	\N	PRESENT	0
279053	278438	11066Q	PARTICIPANT	\N	PRESENT	0
279126	279125	11109J	PARTICIPANT	\N	PRESENT	0
279127	279125	14195A	PARTICIPANT	\N	PRESENT	0
279128	279125	14327T	PARTICIPANT	\N	PRESENT	0
279129	279125	98024R	PARTICIPANT	\N	PRESENT	0
279130	279125	08045X	PARTICIPANT	\N	PRESENT	0
279131	279125	19347U	PARTICIPANT	\N	PRESENT	0
279132	279125	95037J	PARTICIPANT	\N	EXCUSE	0
279133	279125	14213J	PRESIDENT	0	PRESENT	0
279134	279125	19683J	PARTICIPANT	\N	PRESENT	0
279135	279125	11099A	PARTICIPANT	\N	PRESENT	0
279136	279125	08015R	PARTICIPANT	\N	EXCUSE	0
279137	279125	08017T	PARTICIPANT	\N	PRESENT	0
279138	279125	19369B	PARTICIPANT	\N	EXCUSE	0
279139	279125	14169X	PARTICIPANT	\N	PRESENT	0
279140	279125	19503N	PARTICIPANT	\N	PRESENT	0
279141	279125	04045F	PARTICIPANT	\N	EXCUSE	0
279142	279125	08049C	PARTICIPANT	\N	PRESENT	0
279309	273985	19663E	PARTICIPANT	\N	EXCUSE	0
279312	279302	19545Y	PARTICIPANT	\N	PRESENT	0
279313	279302	14267Y	PARTICIPANT	\N	PRESENT	0
279314	279302	04038G	PARTICIPANT	\N	PRESENT	0
279315	279302	14357A	PRESIDENT	0	PRESENT	0
279316	279302	11070L	PARTICIPANT	\N	EXCUSE	0
279317	279302	19531S	PARTICIPANT	\N	PRESENT	0
279318	279302	19533U	PARTICIPANT	\N	PRESENT	0
279319	279302	95062K	PARTICIPANT	\N	PRESENT	0
279320	279302	19689Q	PARTICIPANT	\N	PRESENT	0
279321	279302	08043V	PARTICIPANT	\N	EXCUSE	0
279327	279326	19545Y	PARTICIPANT	\N	PRESENT	0
279328	279326	04038G	PARTICIPANT	\N	PRESENT	0
279329	279326	14357A	PARTICIPANT	\N	PRESENT	0
279331	279326	17637T	PARTICIPANT	\N	PRESENT	0
279332	279326	95062K	PARTICIPANT	\N	PRESENT	0
279333	279326	19689Q	PARTICIPANT	\N	PRESENT	0
279335	279326	08043V	PARTICIPANT	\N	EXCUSE	0
279336	279326	11070L	PRESIDENT	0	PRESENT	0
279338	279337	19741B	PARTICIPANT	\N	PRESENT	0
279339	279337	08043V	PARTICIPANT	\N	EXCUSE	0
279340	279337	04038G	PARTICIPANT	\N	PRESENT	0
279341	279337	14357A	PRESIDENT	0	PRESENT	0
279342	279337	11070L	PARTICIPANT	\N	EXCUSE	0
279343	279337	19531S	PARTICIPANT	\N	PRESENT	0
279344	279337	17637T	PARTICIPANT	\N	PRESENT	0
279345	279337	19533U	PARTICIPANT	\N	PRESENT	0
279346	279337	95062K	PARTICIPANT	\N	PRESENT	0
279347	279337	19689Q	PARTICIPANT	\N	PRESENT	0
279348	279337	11041F	PARTICIPANT	\N	PRESENT	0
279350	279349	19741B	PARTICIPANT	\N	PRESENT	0
279351	279349	08043V	PARTICIPANT	\N	EXCUSE	0
279352	279349	04038G	PARTICIPANT	\N	PRESENT	0
279353	279349	14357A	PRESIDENT	0	PRESENT	0
279354	279349	11070L	PARTICIPANT	\N	EXCUSE	0
279355	279349	19531S	PARTICIPANT	\N	PRESENT	0
279356	279349	17637T	PARTICIPANT	\N	PRESENT	0
279357	279349	19533U	PARTICIPANT	\N	PRESENT	0
279358	279349	95062K	PARTICIPANT	\N	PRESENT	0
279359	279349	19689Q	PARTICIPANT	\N	PRESENT	0
279360	279349	11041F	PARTICIPANT	\N	PRESENT	0
279361	278438	19515S	PARTICIPANT	\N	PRESENT	0
279362	278438	02002K	PARTICIPANT	\N	EXCUSE	0
279436	279435	14221J	PARTICIPANT	\N	PRESENT	0
280156	273865	19681G	PARTICIPANT	\N	PRESENT	0
280157	273865	17583W	PARTICIPANT	\N	PRESENT	0
280158	273865	19507S	PARTICIPANT	\N	PRESENT	0
280159	273865	19415P	PARTICIPANT	\N	PRESENT	0
280160	273865	14115H	PARTICIPANT	\N	PRESENT	0
280161	273865	19733B	PARTICIPANT	\N	PRESENT	0
280162	273865	14357A	PARTICIPANT	\N	PRESENT	0
280163	273865	14029X	PARTICIPANT	\N	PRESENT	0
280164	273865	19739H	PARTICIPANT	\N	PRESENT	0
280166	280165	08011M	PARTICIPANT	\N	PRESENT	0
280167	273865	08028W	PARTICIPANT	\N	PRESENT	0
280168	273865	14033T	PARTICIPANT	\N	PRESENT	0
280169	273865	14217N	PARTICIPANT	\N	PRESENT	0
280170	273865	11097X	PARTICIPANT	\N	PRESENT	0
280171	273865	14223L	PARTICIPANT	\N	PRESENT	0
280172	273865	04088S	PARTICIPANT	\N	PRESENT	0
280173	273865	11103C	PARTICIPANT	\N	PRESENT	0
280175	280174	11053K	PARTICIPANT	\N	PRESENT	0
280176	280174	14159V	PARTICIPANT	\N	PRESENT	0
280177	280174	05012A	PARTICIPANT	\N	PRESENT	0
280179	273865	19729F	PARTICIPANT	\N	PRESENT	0
280180	273865	17589D	PARTICIPANT	\N	PRESENT	0
280357	273866	14235Q	PARTICIPANT	\N	PRESENT	0
280358	273866	19629C	PARTICIPANT	\N	PRESENT	0
280359	273866	08045X	PARTICIPANT	\N	PRESENT	0
280360	273866	19727D	PARTICIPANT	\N	PRESENT	0
280361	273866	11043H	PARTICIPANT	\N	PRESENT	0
280362	273866	08049C	PARTICIPANT	\N	PRESENT	0
280363	273866	14030Q	PARTICIPANT	\N	PRESENT	0
280364	273866	19719D	PARTICIPANT	\N	PRESENT	0
280365	273866	14147R	PARTICIPANT	\N	PRESENT	0
280366	273866	14069U	PARTICIPANT	\N	PRESENT	0
280367	273866	19681G	PARTICIPANT	\N	PRESENT	0
280368	273866	14249W	PARTICIPANT	\N	PRESENT	0
280369	273866	14026U	PARTICIPANT	\N	PRESENT	0
280370	273866	14331P	PARTICIPANT	\N	PRESENT	0
280371	273866	07029T	PARTICIPANT	\N	PRESENT	0
280372	273866	04088S	PARTICIPANT	\N	PRESENT	0
280373	273866	14031R	PARTICIPANT	\N	PRESENT	0
280374	273866	98023Q	PARTICIPANT	\N	PRESENT	0
280375	273866	08009T	PARTICIPANT	\N	PRESENT	0
280376	273866	14357A	PARTICIPANT	\N	PRESENT	0
280377	273866	11097X	PARTICIPANT	\N	PRESENT	0
280378	273866	01024M	PARTICIPANT	\N	PRESENT	0
280379	273866	19549D	PARTICIPANT	\N	PRESENT	0
280380	273866	14061L	PARTICIPANT	\N	PRESENT	0
280381	273866	10006L	PARTICIPANT	\N	PRESENT	0
280382	273866	14213J	PARTICIPANT	\N	PRESENT	0
280383	273866	14217N	PARTICIPANT	\N	PRESENT	0
280384	273866	14038Y	PARTICIPANT	\N	PRESENT	0
280385	273866	14205J	PARTICIPANT	\N	PRESENT	0
280386	273866	05012A	PARTICIPANT	\N	PRESENT	0
280387	273866	19387D	PARTICIPANT	\N	PRESENT	0
280388	273866	14105F	PARTICIPANT	\N	PRESENT	0
280389	273866	14241N	PARTICIPANT	\N	PRESENT	0
280390	273866	19563B	PARTICIPANT	\N	PRESENT	0
280391	273866	19545Y	PARTICIPANT	\N	PRESENT	0
280392	273866	08020N	PARTICIPANT	\N	PRESENT	0
280393	273866	89017R	PARTICIPANT	\N	PRESENT	0
280394	273866	14231L	PARTICIPANT	\N	PRESENT	0
310033	307506	19679N	PARTICIPANT	\N	PRESENT	0
310034	307506	19717B	PARTICIPANT	\N	EXCUSE	0
310035	307506	19575F	PARTICIPANT	\N	PRESENT	0
310036	307506	11031D	PARTICIPANT	\N	PRESENT	0
310037	307506	14355X	PARTICIPANT	\N	PRESENT	0
310038	309124	14331P	PARTICIPANT	\N	PRESENT	0
310039	309124	11048N	PARTICIPANT	\N	PRESENT	0
310040	309124	19711U	PARTICIPANT	\N	PRESENT	0
310041	309124	08069G	PARTICIPANT	\N	PRESENT	0
310042	309124	01057W	PARTICIPANT	\N	PRESENT	0
310043	309124	11074Q	PRESIDENT	0	PRESENT	0
310044	309124	89017R	PARTICIPANT	\N	PRESENT	0
310045	309124	11070L	PARTICIPANT	\N	PRESENT	0
310046	309124	11040E	PARTICIPANT	\N	PRESENT	0
310047	309124	04086Q	PARTICIPANT	\N	PRESENT	0
310048	309124	14199E	PARTICIPANT	\N	PRESENT	0
310049	309124	08010L	PARTICIPANT	\N	PRESENT	0
310050	309124	14253S	PARTICIPANT	\N	PRESENT	0
310051	309124	99004R	PARTICIPANT	\N	PRESENT	0
310052	309124	14159V	PARTICIPANT	\N	PRESENT	0
310053	309124	14085U	PARTICIPANT	\N	PRESENT	0
310054	309124	19507S	PARTICIPANT	\N	PRESENT	0
310055	309124	14327T	PARTICIPANT	\N	EXCUSE	0
310056	309124	11012A	PARTICIPANT	\N	EXCUSE	0
310057	309124	08034U	PARTICIPANT	\N	EXCUSE	0
310058	309124	08014Q	PARTICIPANT	\N	EXCUSE	0
310059	309124	19545Y	PARTICIPANT	\N	PRESENT	0
310060	309124	14225N	PARTICIPANT	\N	PRESENT	0
310061	309124	19667J	PARTICIPANT	\N	PRESENT	0
310062	309124	08011M	PARTICIPANT	\N	PRESENT	0
310063	309124	01048V	PARTICIPANT	\N	PRESENT	0
310064	309124	04061F	PARTICIPANT	\N	PRESENT	0
310065	309124	14083S	PARTICIPANT	\N	PRESENT	0
310066	309124	07029T	PARTICIPANT	\N	PRESENT	0
310067	309124	19479G	PARTICIPANT	\N	PRESENT	0
310068	309153	08009T	PRESIDENT	0	PRESENT	0
310069	309153	14051J	PARTICIPANT	\N	EXCUSE	0
310070	309153	19701S	PARTICIPANT	\N	EXCUSE	0
310071	309153	19549D	PARTICIPANT	\N	EXCUSE	0
310072	309153	96004D	PARTICIPANT	\N	EXCUSE	0
310073	309153	19637C	PARTICIPANT	\N	EXCUSE	0
310075	309153	19383Y	PARTICIPANT	\N	PRESENT	0
310076	309153	19333N	PARTICIPANT	\N	PRESENT	0
310077	309153	14038Y	PARTICIPANT	\N	PRESENT	0
310078	309153	17583W	PARTICIPANT	\N	PRESENT	0
310079	309153	14219Q	PARTICIPANT	\N	PRESENT	0
310080	309153	08055A	PARTICIPANT	\N	PRESENT	0
310081	309153	19599P	PARTICIPANT	\N	PRESENT	0
310082	309153	14093U	PARTICIPANT	\N	PRESENT	0
310083	309153	19347U	PARTICIPANT	\N	PRESENT	0
310084	309153	19739H	PARTICIPANT	\N	PRESENT	0
310085	309153	14157T	PARTICIPANT	\N	PRESENT	0
310086	309153	08024S	PARTICIPANT	\N	PRESENT	0
310087	309153	05012A	PARTICIPANT	\N	PRESENT	0
310088	309124	19349W	PARTICIPANT	\N	PRESENT	0
310089	309124	19671E	PARTICIPANT	\N	PRESENT	0
310090	307508	19697Q	PARTICIPANT	\N	PRESENT	0
310091	307508	11067R	PARTICIPANT	\N	PRESENT	0
310092	307508	14355X	PARTICIPANT	\N	PRESENT	0
310093	307508	19569H	PARTICIPANT	\N	PRESENT	0
310094	307508	11097X	PARTICIPANT	\N	PRESENT	0
310095	307508	19415P	PARTICIPANT	\N	PRESENT	0
310096	307508	14223L	PARTICIPANT	\N	PRESENT	0
310097	307508	04045F	PARTICIPANT	\N	PRESENT	0
310098	307508	14026U	PARTICIPANT	\N	PRESENT	0
310099	307508	14227Q	PARTICIPANT	\N	PRESENT	0
310100	307508	19675J	PARTICIPANT	\N	PRESENT	0
310101	307508	17779H	PARTICIPANT	\N	PRESENT	0
310102	307508	14239U	PARTICIPANT	\N	PRESENT	0
310103	307508	19703U	PARTICIPANT	\N	PRESENT	0
310104	307508	11031D	PARTICIPANT	\N	PRESENT	0
310105	307508	14087W	PARTICIPANT	\N	PRESENT	0
310106	307508	14281W	PARTICIPANT	\N	PRESENT	0
310107	307508	19679N	PARTICIPANT	\N	PRESENT	0
310108	307508	14042U	PARTICIPANT	\N	PRESENT	0
310109	307508	19575F	PARTICIPANT	\N	PRESENT	0
310110	307508	19367Y	PARTICIPANT	\N	PRESENT	0
310111	307508	14213J	PARTICIPANT	\N	PRESENT	0
310112	307508	14217N	PARTICIPANT	\N	PRESENT	0
310113	307508	19335Q	PARTICIPANT	\N	PRESENT	0
310114	307508	14261S	PARTICIPANT	\N	PRESENT	0
310115	307508	19683J	PARTICIPANT	\N	PRESENT	0
310116	307508	10006L	PARTICIPANT	\N	PRESENT	0
310117	307508	98024R	PARTICIPANT	\N	PRESENT	0
310118	307508	19521Q	PARTICIPANT	\N	PRESENT	0
310119	307508	01034P	PARTICIPANT	\N	PRESENT	0
310120	307508	04092N	PRESIDENT	0	PRESENT	0
310121	307508	11045K	PARTICIPANT	\N	PRESENT	0
310122	307508	08052W	PARTICIPANT	\N	PRESENT	0
310123	307508	19691J	PARTICIPANT	\N	PRESENT	0
310124	307508	19723Y	PARTICIPANT	\N	PRESENT	0
310125	307508	19727D	PARTICIPANT	\N	PRESENT	0
310126	307508	14119M	PARTICIPANT	\N	PRESENT	0
310127	307508	11103C	PARTICIPANT	\N	PRESENT	0
310128	307508	19657G	PARTICIPANT	\N	PRESENT	0
310129	307508	14071N	PARTICIPANT	\N	PRESENT	0
310130	307508	19577H	PARTICIPANT	\N	PRESENT	0
310131	307508	19553Y	PARTICIPANT	\N	PRESENT	0
310132	307508	08048B	PARTICIPANT	\N	PRESENT	0
310133	307508	19715Y	PARTICIPANT	\N	PRESENT	0
310134	307508	19717B	PARTICIPANT	\N	EXCUSE	0
310135	307508	08041T	PARTICIPANT	\N	EXCUSE	0
310136	307506	19760E	PARTICIPANT	\N	PRESENT	0
310137	309054	14001X	PARTICIPANT	\N	PRESENT	0
310138	309054	19585H	PARTICIPANT	\N	PRESENT	0
310139	309054	19489J	PARTICIPANT	\N	PRESENT	0
310140	309054	14179A	PARTICIPANT	\N	PRESENT	0
310141	309054	14065Q	PARTICIPANT	\N	PRESENT	0
310142	309054	19725B	PARTICIPANT	\N	PRESENT	0
310143	309054	19629C	PARTICIPANT	\N	PRESENT	0
310144	309054	14069U	PARTICIPANT	\N	PRESENT	0
310145	309124	19647E	PARTICIPANT	\N	PRESENT	0
310146	309153	14031R	PARTICIPANT	\N	PRESENT	0
310147	309153	19713W	PARTICIPANT	\N	PRESENT	0
310148	309153	95062K	PARTICIPANT	\N	PRESENT	0
310149	309153	14221J	PARTICIPANT	\N	PRESENT	0
310150	309153	14029X	PARTICIPANT	\N	PRESENT	0
310151	309153	19503N	PARTICIPANT	\N	PRESENT	0
310152	309153	19681G	PARTICIPANT	\N	PRESENT	0
310153	307508	19760E	PARTICIPANT	\N	PRESENT	0
310154	309153	17637T	PARTICIPANT	\N	PRESENT	0
310155	309153	19525U	PARTICIPANT	\N	PRESENT	0
310156	309153	14237S	PARTICIPANT	\N	PRESENT	0
310158	307294	19443T	PARTICIPANT	\N	PRESENT	0
310159	307294	12041X	PARTICIPANT	\N	PRESENT	0
310160	307294	04034C	PARTICIPANT	\N	PRESENT	0
310161	307294	04040A	PARTICIPANT	\N	PRESENT	0
310162	307294	01058X	PARTICIPANT	\N	PRESENT	0
310163	307294	04042C	PRESIDENT	0	PRESENT	0
310164	307294	11054L	PARTICIPANT	\N	PRESENT	0
310165	307294	11066Q	PARTICIPANT	\N	PRESENT	0
310166	307294	08056B	PARTICIPANT	\N	PRESENT	0
310167	307294	95037J	PARTICIPANT	\N	PRESENT	0
310168	307294	19709B	PARTICIPANT	\N	PRESENT	0
310169	307294	14193X	PARTICIPANT	\N	PRESENT	0
310170	307294	08061X	PARTICIPANT	\N	PRESENT	0
310171	307294	08047A	PARTICIPANT	\N	PRESENT	0
310172	307294	14133K	PARTICIPANT	\N	PRESENT	0
310173	307294	14235Q	PARTICIPANT	\N	PRESENT	0
310174	307294	08058D	PARTICIPANT	\N	PRESENT	0
310175	307294	14028W	PARTICIPANT	\N	PRESENT	0
310176	307294	19251M	PARTICIPANT	\N	PRESENT	0
310177	307294	98018T	PARTICIPANT	\N	PRESENT	0
310178	307294	98022P	PARTICIPANT	\N	PRESENT	0
310179	307294	11064N	PARTICIPANT	\N	PRESENT	0
310180	307294	14267Y	PARTICIPANT	\N	PRESENT	0
310181	307294	98050T	PARTICIPANT	\N	PRESENT	0
310182	307294	19583F	PARTICIPANT	\N	PRESENT	0
310183	307294	14211G	PARTICIPANT	\N	PRESENT	0
310184	309153	02002K	PARTICIPANT	\N	PRESENT	0
310185	307294	11027H	PARTICIPANT	\N	PRESENT	0
310186	307294	11115U	PARTICIPANT	\N	PRESENT	0
310187	307294	14097Y	PARTICIPANT	\N	PRESENT	0
310188	307294	04035D	PARTICIPANT	\N	PRESENT	0
310189	307294	98005N	PARTICIPANT	\N	PRESENT	0
310190	307294	95030B	PARTICIPANT	\N	PRESENT	0
310191	309056	01060R	PARTICIPANT	\N	PRESENT	0
310192	309056	14001X	PARTICIPANT	\N	PRESENT	0
310193	309056	19543W	PARTICIPANT	\N	PRESENT	0
310194	309056	04044E	PARTICIPANT	\N	PRESENT	0
310195	309056	19585H	PARTICIPANT	\N	PRESENT	0
310196	309056	04047H	PARTICIPANT	\N	PRESENT	0
310197	309056	19673G	PARTICIPANT	\N	PRESENT	0
310198	309056	14231L	PARTICIPANT	\N	PRESENT	0
310199	309056	19447X	PARTICIPANT	\N	PRESENT	0
310200	309056	05008E	PRESIDENT	0	PRESENT	0
310201	309056	14041T	PARTICIPANT	\N	PRESENT	0
310202	309056	14147R	PARTICIPANT	\N	PRESENT	0
310203	309056	14215L	PARTICIPANT	\N	PRESENT	0
309108	309107	11097X	PARTICIPANT	\N	PRESENT	0
309398	309053	14111D	PARTICIPANT	\N	PRESENT	0
309399	309053	19649G	PARTICIPANT	\N	PRESENT	0
309400	309053	07034Q	PARTICIPANT	\N	PRESENT	0
309401	309053	08045X	PARTICIPANT	\N	PRESENT	0
309402	309053	19253P	PARTICIPANT	\N	PRESENT	0
309403	309053	01024M	PARTICIPANT	\N	PRESENT	0
309404	309053	19543W	PARTICIPANT	\N	PRESENT	0
309405	309053	04044E	PARTICIPANT	\N	PRESENT	0
309406	309053	19581D	PARTICIPANT	\N	PRESENT	0
309407	309053	04038G	PARTICIPANT	\N	PRESENT	0
309408	309053	19585H	PARTICIPANT	\N	PRESENT	0
309409	309053	04047H	PARTICIPANT	\N	PRESENT	0
309410	309053	01028R	PARTICIPANT	\N	PRESENT	0
309411	309053	05008E	PRESIDENT	0	PRESENT	0
309412	309053	19447X	PARTICIPANT	\N	PRESENT	0
309413	309053	19629C	PARTICIPANT	\N	PRESENT	0
309414	309053	14041T	PARTICIPANT	\N	PRESENT	0
309415	309053	14147R	PARTICIPANT	\N	PRESENT	0
309416	309053	14215L	PARTICIPANT	\N	PRESENT	0
309417	309053	19762G	PARTICIPANT	\N	PRESENT	0
309418	309053	14089Y	PARTICIPANT	\N	PRESENT	0
309419	309053	14069U	PARTICIPANT	\N	PRESENT	0
309420	309053	14151M	PARTICIPANT	\N	PRESENT	0
309421	309053	19729F	PARTICIPANT	\N	EXCUSE	0
309422	309053	14231L	PARTICIPANT	\N	EXCUSE	0
309766	307423	14215L	PARTICIPANT	\N	PRESENT	0
309767	307290	19647E	PARTICIPANT	\N	PRESENT	0
309768	307290	01062T	PARTICIPANT	\N	PRESENT	0
309769	307423	14241N	PARTICIPANT	\N	PRESENT	0
309771	307423	19727D	PARTICIPANT	\N	PRESENT	0
309772	307423	19543W	PARTICIPANT	\N	PRESENT	0
309773	307290	14097Y	PARTICIPANT	\N	PRESENT	0
309774	307423	19739H	PARTICIPANT	\N	PRESENT	0
309775	307290	19251M	PARTICIPANT	\N	PRESENT	0
309776	307423	19747H	PARTICIPANT	\N	PRESENT	0
309779	307423	14259Y	PARTICIPANT	\N	PRESENT	0
309780	307423	08028W	PARTICIPANT	\N	PRESENT	0
309785	307290	04040A	PARTICIPANT	\N	PRESENT	0
309787	307423	10006L	PARTICIPANT	\N	PRESENT	0
309788	307423	07034Q	PARTICIPANT	\N	PRESENT	0
309789	307423	19723Y	PARTICIPANT	\N	PRESENT	0
309793	307423	14115H	PARTICIPANT	\N	PRESENT	0
309794	307423	01043Q	PARTICIPANT	\N	PRESENT	0
309795	307423	08039A	PARTICIPANT	\N	PRESENT	0
309802	307423	19695N	PARTICIPANT	\N	PRESENT	0
309803	307423	14231L	PARTICIPANT	\N	PRESENT	0
309804	307423	19367Y	PARTICIPANT	\N	PRESENT	0
309805	307423	14059S	PARTICIPANT	\N	PRESENT	0
314015	313768	14169X	PARTICIPANT	\N	PRESENT	0
314016	313774	08009T	PARTICIPANT	\N	PRESENT	0
314017	313774	14219Q	PARTICIPANT	\N	PRESENT	0
314018	313774	19333N	PARTICIPANT	\N	PRESENT	0
314019	313774	14221J	PARTICIPANT	\N	PRESENT	0
314020	313774	14169X	PARTICIPANT	\N	PRESENT	0
314021	313774	19713W	PARTICIPANT	\N	PRESENT	0
314022	313774	14157T	PARTICIPANT	\N	PRESENT	0
314023	313777	08009T	PARTICIPANT	\N	PRESENT	0
314024	313777	14219Q	PARTICIPANT	\N	PRESENT	0
314025	313777	19333N	PARTICIPANT	\N	PRESENT	0
314026	313777	14221J	PARTICIPANT	\N	PRESENT	0
314027	313777	14169X	PARTICIPANT	\N	PRESENT	0
314028	313777	19713W	PARTICIPANT	\N	PRESENT	0
314029	313777	14157T	PARTICIPANT	\N	PRESENT	0
316400	316399	19533U	PARTICIPANT	\N	PRESENT	0
318883	318328	14133K	PARTICIPANT	\N	EXCUSE	0
318887	318328	04049K	PARTICIPANT	\N	EXCUSE	0
318888	318328	96004D	PARTICIPANT	\N	EXCUSE	0
318889	318463	14133K	PARTICIPANT	\N	EXCUSE	0
318890	318463	96004D	PARTICIPANT	\N	EXCUSE	0
323392	321791	19569H	PARTICIPANT	\N	PRESENT	0
323994	314152	11031D	PARTICIPANT	\N	PRESENT	0
323995	314152	14281W	PARTICIPANT	\N	PRESENT	0
323996	321055	14277B	PARTICIPANT	\N	PRESENT	0
323997	321055	07004J	PARTICIPANT	\N	PRESENT	0
323998	321055	19741B	PARTICIPANT	\N	PRESENT	0
323999	321055	19671E	PARTICIPANT	\N	PRESENT	0
324000	321055	08014Q	PARTICIPANT	\N	EXCUSE	0
324001	321055	14034U	PARTICIPANT	\N	EXCUSE	0
324002	314152	19575F	PARTICIPANT	\N	PRESENT	0
324003	314152	19760E	PARTICIPANT	\N	PRESENT	0
324004	314152	11056N	PARTICIPANT	\N	PRESENT	0
324005	314152	19295A	PARTICIPANT	\N	PRESENT	0
324006	314152	14207L	PARTICIPANT	\N	PRESENT	0
324007	314152	04092N	PARTICIPANT	\N	PRESENT	0
324008	314152	01034P	PARTICIPANT	\N	PRESENT	0
324009	314152	08015R	PARTICIPANT	\N	PRESENT	0
324010	314152	14237S	PARTICIPANT	\N	PRESENT	0
324011	314152	19599P	PARTICIPANT	\N	PRESENT	0
324012	314152	19727D	PARTICIPANT	\N	PRESENT	0
324013	314152	02002K	PARTICIPANT	\N	PRESENT	0
324014	314152	01025N	PARTICIPANT	\N	PRESENT	0
324015	314152	19507S	PARTICIPANT	\N	PRESENT	0
324016	314152	14191V	PARTICIPANT	\N	PRESENT	0
324017	314152	14115H	PARTICIPANT	\N	PRESENT	0
324018	314152	19723Y	PARTICIPANT	\N	PRESENT	0
324019	314152	19515S	PARTICIPANT	\N	PRESENT	0
324020	314152	19747H	PARTICIPANT	\N	PRESENT	0
324072	314152	14215L	PARTICIPANT	\N	PRESENT	0
324073	314152	10006L	PARTICIPANT	\N	PRESENT	0
324074	314152	97011G	PARTICIPANT	\N	PRESENT	0
324076	314152	19467C	PARTICIPANT	\N	PRESENT	0
324077	314152	19713W	PARTICIPANT	\N	PRESENT	0
324078	314152	19621T	PARTICIPANT	\N	PRESENT	0
324079	314152	14151M	PARTICIPANT	\N	PRESENT	0
324080	314152	19333N	PARTICIPANT	\N	PRESENT	0
324081	314152	11110B	PARTICIPANT	\N	PRESENT	0
324082	321055	99004R	PARTICIPANT	\N	PRESENT	0
324083	314152	14071N	PARTICIPANT	\N	PRESENT	0
324084	314152	19715Y	PARTICIPANT	\N	PRESENT	0
324085	314152	08055A	PARTICIPANT	\N	PRESENT	0
324086	314152	14073Q	PARTICIPANT	\N	PRESENT	0
324087	314152	19413M	PARTICIPANT	\N	PRESENT	0
324088	314152	19663E	PARTICIPANT	\N	PRESENT	0
324089	314152	14265W	PARTICIPANT	\N	PRESENT	0
324090	314152	08048B	PARTICIPANT	\N	PRESENT	0
324093	314152	14213J	PARTICIPANT	\N	PRESENT	0
324094	314152	14081Q	PARTICIPANT	\N	PRESENT	0
324095	314152	14026U	PARTICIPANT	\N	PRESENT	0
324096	314152	14219Q	PARTICIPANT	\N	PRESENT	0
324097	314152	17779H	PARTICIPANT	\N	PRESENT	0
324098	314152	14251Q	PARTICIPANT	\N	PRESENT	0
324099	314152	19683J	PARTICIPANT	\N	PRESENT	0
324100	314152	19693L	PARTICIPANT	\N	PRESENT	0
324101	321055	08073C	PARTICIPANT	\N	PRESENT	0
324102	314152	08028W	PARTICIPANT	\N	PRESENT	0
324103	314152	14223L	PARTICIPANT	\N	PRESENT	0
324104	314152	95037J	PARTICIPANT	\N	PRESENT	0
324105	314152	19695N	PARTICIPANT	\N	PRESENT	0
324106	314152	04085P	PARTICIPANT	\N	PRESENT	0
324107	314152	14147R	PARTICIPANT	\N	PRESENT	0
324108	321055	14083S	PARTICIPANT	\N	PRESENT	0
324109	321055	08010L	PARTICIPANT	\N	PRESENT	0
324110	314152	14235Q	PARTICIPANT	\N	PRESENT	0
324111	314152	19335Q	PARTICIPANT	\N	PRESENT	0
324112	314152	19289C	PARTICIPANT	\N	PRESENT	0
324113	314152	19691J	PARTICIPANT	\N	PRESENT	0
324114	314152	04059M	PARTICIPANT	\N	PRESENT	0
324115	314152	14119M	PARTICIPANT	\N	PRESENT	0
324116	314152	19577H	PARTICIPANT	\N	PRESENT	0
324117	314152	19657G	PARTICIPANT	\N	PRESENT	0
324118	314152	08020N	PARTICIPANT	\N	PRESENT	0
324119	321055	08034U	PARTICIPANT	\N	PRESENT	0
324120	314152	19739H	PARTICIPANT	\N	PRESENT	0
324121	314152	19741B	PARTICIPANT	\N	PRESENT	0
324122	314152	14329V	PARTICIPANT	\N	PRESENT	0
324123	314152	14193X	PARTICIPANT	\N	PRESENT	0
324124	314152	01043Q	PARTICIPANT	\N	PRESENT	0
324125	314152	04034C	PARTICIPANT	\N	PRESENT	0
324126	314152	14039A	PARTICIPANT	\N	PRESENT	0
324127	314152	01048V	PARTICIPANT	\N	PRESENT	0
324128	314152	01024M	PARTICIPANT	\N	PRESENT	0
324129	314152	14231L	PARTICIPANT	\N	PRESENT	0
324130	314152	19329S	PARTICIPANT	\N	PRESENT	0
324131	314152	19637C	PARTICIPANT	\N	PRESENT	0
324132	314152	98050T	PARTICIPANT	\N	PRESENT	0
324133	314152	14275Y	PARTICIPANT	\N	PRESENT	0
324134	314152	19631V	PARTICIPANT	\N	PRESENT	0
324135	314152	19443T	PARTICIPANT	\N	PRESENT	0
324136	314152	08031R	PARTICIPANT	\N	PRESENT	0
324137	314152	14261S	PARTICIPANT	\N	PRESENT	0
324138	314152	19533U	PARTICIPANT	\N	PRESENT	0
324139	314152	19543W	PARTICIPANT	\N	PRESENT	0
324140	314152	11045K	PARTICIPANT	\N	PRESENT	0
324141	321055	19545Y	PARTICIPANT	\N	PRESENT	0
324143	314152	14205J	PARTICIPANT	\N	PRESENT	0
324144	314152	19521Q	PARTICIPANT	\N	PRESENT	0
324145	314152	19701S	PARTICIPANT	\N	PRESENT	0
305974	305883	19565D	PARTICIPANT	\N	EXCUSE	0
305975	305883	19253P	PARTICIPANT	\N	EXCUSE	0
305976	305954	19709B	PARTICIPANT	\N	PRESENT	0
306014	305883	14063N	PARTICIPANT	\N	EXCUSE	0
308228	308227	01060R	PARTICIPANT	\N	PRESENT	0
308229	308227	04044E	PARTICIPANT	\N	PRESENT	0
308230	308227	19581D	PARTICIPANT	\N	PRESENT	0
308231	308227	19585H	PARTICIPANT	\N	PRESENT	0
308232	308227	04047H	PARTICIPANT	\N	PRESENT	0
308233	308227	19673G	PARTICIPANT	\N	PRESENT	0
308234	308227	01028R	PARTICIPANT	\N	PRESENT	0
308235	308227	19447X	PARTICIPANT	\N	PRESENT	0
308236	308227	14231L	PARTICIPANT	\N	PRESENT	0
308237	308227	14151M	PARTICIPANT	\N	PRESENT	0
308238	308227	14215L	PARTICIPANT	\N	PRESENT	0
308239	308227	11072N	PARTICIPANT	\N	PRESENT	0
308240	308227	14053L	PARTICIPANT	\N	PRESENT	0
308241	308227	98035U	PARTICIPANT	\N	PRESENT	0
308242	308227	14111D	PARTICIPANT	\N	PRESENT	0
308243	308227	19649G	PARTICIPANT	\N	PRESENT	0
308244	308227	14065Q	PARTICIPANT	\N	PRESENT	0
308245	308227	08045X	PARTICIPANT	\N	PRESENT	0
308246	308227	19253P	PARTICIPANT	\N	PRESENT	0
308247	308227	01024M	PARTICIPANT	\N	PRESENT	0
308248	308227	04038G	PARTICIPANT	\N	PRESENT	0
308249	308227	19719D	PARTICIPANT	\N	PRESENT	0
308250	308227	11033F	PARTICIPANT	\N	PRESENT	0
308251	308227	14089Y	PARTICIPANT	\N	PRESENT	0
308252	308227	95063L	PARTICIPANT	\N	PRESENT	0
308253	308227	19629C	PARTICIPANT	\N	PRESENT	0
308254	308227	19762G	PARTICIPANT	\N	PRESENT	0
308255	308227	05008E	PRESIDENT	0	PRESENT	0
308256	308227	10015M	PARTICIPANT	\N	PRESENT	0
308257	308227	19489J	PARTICIPANT	\N	PRESENT	0
308258	308227	19725B	PARTICIPANT	\N	PRESENT	0
308259	308227	14259Y	PARTICIPANT	\N	PRESENT	0
308260	308227	08044W	PARTICIPANT	\N	PRESENT	0
308261	308227	11085T	PARTICIPANT	\N	PRESENT	0
308262	307064	08060W	PARTICIPANT	\N	EXCUSE	0
308263	307064	08009T	PARTICIPANT	\N	EXCUSE	0
308264	307064	02002K	PARTICIPANT	\N	EXCUSE	0
308265	307064	98023Q	PRESIDENT	0	PRESENT	0
308266	307030	14105F	PARTICIPANT	\N	PRESENT	0
308267	307030	12041X	PARTICIPANT	\N	PRESENT	0
308268	307030	98018T	PARTICIPANT	\N	PRESENT	0
308269	307030	19709B	PARTICIPANT	\N	PRESENT	0
308270	307030	14235Q	PARTICIPANT	\N	PRESENT	0
308271	307030	14267Y	PARTICIPANT	\N	PRESENT	0
308272	307030	04042C	PRESIDENT	0	PRESENT	0
308273	307030	14028W	PARTICIPANT	\N	PRESENT	0
308274	307030	19583F	PARTICIPANT	\N	PRESENT	0
308275	307030	08047A	PARTICIPANT	\N	PRESENT	0
308276	307030	11066Q	PARTICIPANT	\N	PRESENT	0
308277	307030	14211G	PARTICIPANT	\N	PRESENT	0
308278	307030	08049C	PARTICIPANT	\N	PRESENT	0
308279	307030	19669L	PARTICIPANT	\N	PRESENT	0
308280	307030	19443T	PARTICIPANT	\N	PRESENT	0
308281	307030	08058D	PARTICIPANT	\N	PRESENT	0
308282	307030	11027H	PARTICIPANT	\N	PRESENT	0
308283	307030	19721W	PARTICIPANT	\N	PRESENT	0
308284	307030	98022P	PARTICIPANT	\N	PRESENT	0
308285	307030	14193X	PARTICIPANT	\N	PRESENT	0
308286	307064	19333N	PARTICIPANT	\N	PRESENT	0
308287	307064	14237S	PARTICIPANT	\N	PRESENT	0
308288	307064	14051J	PARTICIPANT	\N	PRESENT	0
308289	307064	14031R	PARTICIPANT	\N	PRESENT	0
308290	307064	04097T	PARTICIPANT	\N	PRESENT	0
308291	307064	08024S	PARTICIPANT	\N	PRESENT	0
308292	307064	14169X	PARTICIPANT	\N	PRESENT	0
308293	307030	95030B	PARTICIPANT	\N	PRESENT	0
308294	307030	14255U	PARTICIPANT	\N	PRESENT	0
308295	307030	08053X	PARTICIPANT	\N	PRESENT	0
308296	307030	97011G	PARTICIPANT	\N	PRESENT	0
308297	307030	14097Y	PARTICIPANT	\N	PRESENT	0
308298	307030	19251M	PARTICIPANT	\N	PRESENT	0
308299	307030	04040A	PARTICIPANT	\N	PRESENT	0
308300	307030	14079W	PARTICIPANT	\N	PRESENT	0
308301	307030	01058X	PARTICIPANT	\N	PRESENT	0
308302	307030	19421M	PARTICIPANT	\N	PRESENT	0
308303	307030	14055N	PARTICIPANT	\N	PRESENT	0
308304	307030	98050T	PARTICIPANT	\N	PRESENT	0
308305	307030	11054L	PARTICIPANT	\N	PRESENT	0
308306	307030	11064N	PARTICIPANT	\N	PRESENT	0
308307	307064	18083K	PARTICIPANT	\N	PRESENT	0
308308	307064	19383Y	PARTICIPANT	\N	PRESENT	0
308309	307064	05012A	PARTICIPANT	\N	PRESENT	0
308310	307064	19347U	PARTICIPANT	\N	PRESENT	0
308442	307064	14038Y	PARTICIPANT	\N	PRESENT	0
308443	307064	14103D	PARTICIPANT	\N	PRESENT	0
308444	307457	19766L	PARTICIPANT	\N	PRESENT	0
308445	307457	04070G	PRESIDENT	0	PRESENT	0
308446	307457	19699S	PARTICIPANT	\N	PRESENT	0
308447	307457	14229S	PARTICIPANT	\N	PRESENT	0
308448	307457	14241N	PARTICIPANT	\N	PRESENT	0
308449	307457	19573D	PARTICIPANT	\N	PRESENT	0
308450	307457	14107H	PARTICIPANT	\N	PRESENT	0
308451	307457	08017T	PARTICIPANT	\N	PRESENT	0
308452	307457	92040Q	PARTICIPANT	\N	PRESENT	0
308453	307457	08012N	PARTICIPANT	\N	PRESENT	0
308454	307457	08039A	PARTICIPANT	\N	PRESENT	0
308455	307457	08031R	PARTICIPANT	\N	PRESENT	0
308456	307457	19593H	PARTICIPANT	\N	PRESENT	0
308457	307457	19643A	PARTICIPANT	\N	PRESENT	0
308458	307457	14059S	PARTICIPANT	\N	PRESENT	0
308459	307457	04057K	PARTICIPANT	\N	PRESENT	0
308460	307457	14073Q	PARTICIPANT	\N	PRESENT	0
308461	307457	19611R	PARTICIPANT	\N	PRESENT	0
308462	307457	08043V	PARTICIPANT	\N	PRESENT	0
308463	307457	19693L	PARTICIPANT	\N	PRESENT	0
308464	307457	87003B	PARTICIPANT	\N	PRESENT	0
308465	307457	14030Q	PARTICIPANT	\N	PRESENT	0
308466	307457	08020N	PARTICIPANT	\N	PRESENT	0
308467	307457	04059M	PARTICIPANT	\N	PRESENT	0
308468	307457	14063N	PARTICIPANT	\N	PRESENT	0
308469	307457	11083R	PARTICIPANT	\N	PRESENT	0
308470	307457	11043H	PARTICIPANT	\N	PRESENT	0
308471	307457	11104D	PARTICIPANT	\N	PRESENT	0
308472	307457	19749K	PARTICIPANT	\N	PRESENT	0
308473	307457	04018C	PARTICIPANT	\N	PRESENT	0
308474	307457	19758L	PARTICIPANT	\N	PRESENT	0
308475	307457	19621T	PARTICIPANT	\N	PRESENT	0
308476	307457	19533U	PARTICIPANT	\N	PRESENT	0
308477	307457	19731Y	PARTICIPANT	\N	EXCUSE	0
308478	307457	08016S	PARTICIPANT	\N	EXCUSE	0
308479	307064	14093U	PARTICIPANT	\N	PRESENT	0
308480	307064	17637T	PARTICIPANT	\N	PRESENT	0
308481	307457	07033P	PARTICIPANT	\N	PRESENT	0
308482	307457	14109K	PARTICIPANT	\N	PRESENT	0
308483	307457	14123H	PARTICIPANT	\N	PRESENT	0
308484	307457	14039A	PARTICIPANT	\N	EXCUSE	0
308485	307457	19399H	PARTICIPANT	\N	EXCUSE	0
310229	309124	11053K	PARTICIPANT	\N	PRESENT	0
310230	307294	16685X	PARTICIPANT	\N	PRESENT	0
310231	307294	19421M	PARTICIPANT	\N	PRESENT	0
310232	309124	95041E	PARTICIPANT	\N	PRESENT	0
310233	309153	19551W	PARTICIPANT	\N	PRESENT	0
310234	309153	04097T	PARTICIPANT	\N	PRESENT	0
310254	309056	19581D	PARTICIPANT	\N	PRESENT	0
310255	309056	14111D	PARTICIPANT	\N	PRESENT	0
310256	309056	14089Y	PARTICIPANT	\N	PRESENT	0
310272	309702	19768N	PARTICIPANT	\N	PRESENT	0
310273	309702	19515S	PARTICIPANT	\N	PRESENT	0
310274	309702	19565D	PARTICIPANT	\N	PRESENT	0
310275	309702	14357A	PARTICIPANT	\N	PRESENT	0
310276	309702	19441R	PARTICIPANT	\N	PRESENT	0
310277	309702	14081Q	PARTICIPANT	\N	PRESENT	0
310278	309702	80013X	PARTICIPANT	\N	PRESENT	0
310279	309702	04049K	PARTICIPANT	\N	PRESENT	0
310280	309702	19705W	PARTICIPANT	\N	PRESENT	0
310281	309702	14197C	PARTICIPANT	\N	PRESENT	0
310282	309702	19369B	PARTICIPANT	\N	PRESENT	0
310283	309702	19511N	PARTICIPANT	\N	PRESENT	0
310284	309702	08028W	PARTICIPANT	\N	PRESENT	0
310285	309702	14265W	PARTICIPANT	\N	PRESENT	0
310286	309702	14329V	PARTICIPANT	\N	PRESENT	0
310287	309702	14135M	PARTICIPANT	\N	PRESENT	0
310288	309702	19467C	PARTICIPANT	\N	PRESENT	0
310289	309702	14187A	PARTICIPANT	\N	PRESENT	0
310290	309702	08038Y	PARTICIPANT	\N	PRESENT	0
310291	309702	19695N	PARTICIPANT	\N	PRESENT	0
310292	309702	14033T	PARTICIPANT	\N	PRESENT	0
310293	309702	11090Q	PRESIDENT	0	PRESENT	0
310294	309702	01025N	PARTICIPANT	\N	PRESENT	0
310295	309702	19269X	PARTICIPANT	\N	PRESENT	0
310296	309702	14205J	PARTICIPANT	\N	PRESENT	0
310297	309702	04088S	PARTICIPANT	\N	PRESENT	0
310298	309702	11056N	PARTICIPANT	\N	PRESENT	0
310299	309702	14115H	PARTICIPANT	\N	PRESENT	0
310300	309702	11101A	PARTICIPANT	\N	PRESENT	0
313541	313509	11026G	PARTICIPANT	\N	PRESENT	0
313542	313509	19729F	PARTICIPANT	\N	PRESENT	0
313543	313509	19581D	PARTICIPANT	\N	PRESENT	0
313544	313509	14111D	PARTICIPANT	\N	PRESENT	0
313560	309274	14357A	PARTICIPANT	\N	PRESENT	0
313546	313509	11085T	PARTICIPANT	\N	PRESENT	0
313547	313509	01060R	PARTICIPANT	\N	PRESENT	0
313562	309274	14193X	PARTICIPANT	\N	PRESENT	0
313549	313509	11072N	PARTICIPANT	\N	PRESENT	0
313550	313509	07034Q	PARTICIPANT	\N	PRESENT	0
313551	313509	10015M	PARTICIPANT	\N	PRESENT	0
313552	313509	95063L	PARTICIPANT	\N	PRESENT	0
313553	313509	19762G	PARTICIPANT	\N	PRESENT	0
313554	313509	01028R	PARTICIPANT	\N	PRESENT	0
313555	313509	98035U	PARTICIPANT	\N	PRESENT	0
313556	313509	14275Y	PARTICIPANT	\N	PRESENT	0
313557	313509	04044E	PARTICIPANT	\N	PRESENT	0
313558	313509	19585H	PARTICIPANT	\N	PRESENT	0
313559	309274	98029W	PARTICIPANT	\N	PRESENT	0
313561	309274	98050T	PARTICIPANT	\N	PRESENT	0
313563	309274	10015M	PARTICIPANT	\N	PRESENT	0
313564	309274	01057W	PARTICIPANT	\N	PRESENT	0
313565	309274	19573D	PARTICIPANT	\N	PRESENT	0
313566	309274	80013X	PARTICIPANT	\N	PRESENT	0
313567	309274	19647E	PARTICIPANT	\N	PRESENT	0
313568	309274	07029T	PARTICIPANT	\N	PRESENT	0
313569	309274	19467C	PARTICIPANT	\N	PRESENT	0
313570	309274	14197C	PARTICIPANT	\N	PRESENT	0
313571	309274	19479G	PARTICIPANT	\N	PRESENT	0
313572	309274	14257W	PARTICIPANT	\N	PRESENT	0
313573	309274	14249W	PARTICIPANT	\N	PRESENT	0
313574	313509	04008A	PARTICIPANT	\N	PRESENT	0
313575	309274	04097T	PARTICIPANT	\N	PRESENT	0
313576	309274	08039A	PARTICIPANT	\N	PRESENT	0
313577	309274	19737F	PARTICIPANT	\N	PRESENT	0
313579	309274	14331P	PARTICIPANT	\N	PRESENT	0
313580	309274	14079W	PARTICIPANT	\N	PRESENT	0
313581	309274	14071N	PARTICIPANT	\N	PRESENT	0
313582	309274	14211G	PARTICIPANT	\N	PRESENT	0
313583	309274	19758L	PARTICIPANT	\N	PRESENT	0
313584	309274	14213J	PARTICIPANT	\N	PRESENT	0
313585	309274	97011G	PARTICIPANT	\N	PRESENT	0
313586	309274	01058X	PARTICIPANT	\N	PRESENT	0
313587	309274	99004R	PARTICIPANT	\N	PRESENT	0
313588	309274	11012A	PARTICIPANT	\N	PRESENT	0
313589	309274	19565D	PARTICIPANT	\N	PRESENT	0
313593	309274	14173T	PARTICIPANT	\N	PRESENT	0
313591	309274	19611R	PARTICIPANT	\N	PRESENT	0
313592	309274	19747H	PARTICIPANT	\N	PRESENT	0
313594	309274	08020N	PARTICIPANT	\N	PRESENT	0
313595	309274	04040A	PARTICIPANT	\N	PRESENT	0
313596	309274	88008L	PARTICIPANT	\N	PRESENT	0
313597	309274	14001X	PARTICIPANT	\N	PRESENT	0
313598	309274	10006L	PARTICIPANT	\N	PRESENT	0
313599	309274	14265W	PARTICIPANT	\N	PRESENT	0
313600	309274	19521Q	PARTICIPANT	\N	PRESENT	0
313601	309274	14327T	PARTICIPANT	\N	PRESENT	0
313602	309274	14267Y	PARTICIPANT	\N	PRESENT	0
313603	309274	14063N	PARTICIPANT	\N	PRESENT	0
313604	309274	11067R	PARTICIPANT	\N	PRESENT	0
313605	309274	14051J	PARTICIPANT	\N	PRESENT	0
313606	309274	14083S	PARTICIPANT	\N	PRESENT	0
313607	309274	19251M	PARTICIPANT	\N	PRESENT	0
313608	309274	04059M	PARTICIPANT	\N	PRESENT	0
313609	309274	01024M	PARTICIPANT	\N	PRESENT	0
313610	309274	11045K	PARTICIPANT	\N	PRESENT	0
313612	309274	14085U	PARTICIPANT	\N	PRESENT	0
313613	309274	16685X	PARTICIPANT	\N	PRESENT	0
313614	309274	14026U	PARTICIPANT	\N	PRESENT	0
313621	309274	19719D	PARTICIPANT	\N	PRESENT	0
313622	309274	14038Y	PARTICIPANT	\N	PRESENT	0
313623	309274	19643A	PARTICIPANT	\N	PRESENT	0
313624	309274	04086Q	PARTICIPANT	\N	PRESENT	0
313625	309274	04047H	PARTICIPANT	\N	PRESENT	0
313626	309274	14121F	PARTICIPANT	\N	PRESENT	0
313627	309274	11072N	PARTICIPANT	\N	PRESENT	0
313628	309274	14179A	PARTICIPANT	\N	PRESENT	0
313629	309274	08044W	PARTICIPANT	\N	PRESENT	0
313630	309274	19649G	PARTICIPANT	\N	PRESENT	0
313631	309274	19691J	PARTICIPANT	\N	PRESENT	0
313632	309274	19619A	PARTICIPANT	\N	PRESENT	0
313633	309274	14109K	PARTICIPANT	\N	PRESENT	0
313635	309274	14031R	PARTICIPANT	\N	PRESENT	0
313636	309274	07034Q	PARTICIPANT	\N	PRESENT	0
313637	309274	19629C	PARTICIPANT	\N	PRESENT	0
313638	309274	14059S	PARTICIPANT	\N	PRESENT	0
313696	309275	14121F	PARTICIPANT	\N	PRESENT	0
313697	309275	01024M	PARTICIPANT	\N	PRESENT	0
313698	309275	05008E	PARTICIPANT	\N	PRESENT	0
313699	309275	04047H	PARTICIPANT	\N	PRESENT	0
313700	309275	14063N	PARTICIPANT	\N	PRESENT	0
313701	309275	14109K	PARTICIPANT	\N	PRESENT	0
313702	309275	14065Q	PARTICIPANT	\N	PRESENT	0
313703	309275	11072N	PARTICIPANT	\N	PRESENT	0
313704	309275	19629C	PARTICIPANT	\N	PRESENT	0
313705	309275	08044W	PARTICIPANT	\N	PRESENT	0
313706	309275	14205J	PARTICIPANT	\N	PRESENT	0
313707	309275	19691J	PARTICIPANT	\N	PRESENT	0
313708	309275	19521Q	PARTICIPANT	\N	PRESENT	0
313709	309275	19619A	PARTICIPANT	\N	PRESENT	0
313710	309275	19479G	PARTICIPANT	\N	PRESENT	0
313711	309275	14103D	PARTICIPANT	\N	PRESENT	0
313712	309275	14267Y	PARTICIPANT	\N	PRESENT	0
313713	309275	19737F	PARTICIPANT	\N	PRESENT	0
313714	309275	14215L	PARTICIPANT	\N	PRESENT	0
313715	309275	14237S	PARTICIPANT	\N	PRESENT	0
313716	309275	14249W	PARTICIPANT	\N	PRESENT	0
313717	309275	07034Q	PARTICIPANT	\N	PRESENT	0
313718	309275	19565D	PARTICIPANT	\N	PRESENT	0
313719	309275	04043D	PARTICIPANT	\N	PRESENT	0
313720	309275	97011G	PARTICIPANT	\N	PRESENT	0
313721	309275	14059S	PARTICIPANT	\N	PRESENT	0
313722	309275	19731Y	PARTICIPANT	\N	PRESENT	0
313723	309275	07029T	PARTICIPANT	\N	PRESENT	0
313724	309275	08015R	PARTICIPANT	\N	PRESENT	0
313725	309275	98005N	PARTICIPANT	\N	PRESENT	0
313726	309275	14031R	PARTICIPANT	\N	PRESENT	0
313727	309275	19573D	PARTICIPANT	\N	PRESENT	0
313728	309275	19447X	PARTICIPANT	\N	PRESENT	0
313729	309275	19643A	PARTICIPANT	\N	PRESENT	0
313730	309275	14069U	PARTICIPANT	\N	PRESENT	0
313731	309275	04086Q	PARTICIPANT	\N	PRESENT	0
313732	309275	95030B	PARTICIPANT	\N	PRESENT	0
313733	309275	01058X	PARTICIPANT	\N	PRESENT	0
313734	309275	08020N	PARTICIPANT	\N	PRESENT	0
313735	309275	14211G	PARTICIPANT	\N	PRESENT	0
313736	309275	95063L	PARTICIPANT	\N	PRESENT	0
313737	309275	19507S	PARTICIPANT	\N	PRESENT	0
313738	309275	17583W	PARTICIPANT	\N	PRESENT	0
313739	309275	01028R	PARTICIPANT	\N	PRESENT	0
313740	309275	10015M	PARTICIPANT	\N	PRESENT	0
313741	309275	19253P	PARTICIPANT	\N	PRESENT	0
313742	309275	19611R	PARTICIPANT	\N	PRESENT	0
313743	309275	14033T	PARTICIPANT	\N	PRESENT	0
313744	309275	19443T	PARTICIPANT	\N	PRESENT	0
313745	309275	19725B	PARTICIPANT	\N	PRESENT	0
313746	309275	14089Y	PARTICIPANT	\N	PRESENT	0
313747	309275	19673G	PARTICIPANT	\N	PRESENT	0
313748	309275	14219Q	PARTICIPANT	\N	PRESENT	0
313749	309275	19762G	PARTICIPANT	\N	PRESENT	0
313756	309275	19649G	PARTICIPANT	\N	PRESENT	0
313694	309275	01043Q	PARTICIPANT	\N	PRESENT	0
313695	309275	04085P	PARTICIPANT	\N	PRESENT	0
313757	309275	11045K	PARTICIPANT	\N	PRESENT	0
313758	309275	19747H	PARTICIPANT	\N	PRESENT	0
313759	309275	11012A	PARTICIPANT	\N	PRESENT	0
313760	309275	08061X	PARTICIPANT	\N	PRESENT	0
313761	309275	19727D	PARTICIPANT	\N	PRESENT	0
313762	309275	14265W	PARTICIPANT	\N	PRESENT	0
313763	309275	14042U	PARTICIPANT	\N	PRESENT	0
313764	309275	19713W	PARTICIPANT	\N	PRESENT	0
313765	309275	14231L	PARTICIPANT	\N	PRESENT	0
313766	309275	11010L	PARTICIPANT	\N	PRESENT	0
313767	309275	08039A	PARTICIPANT	\N	PRESENT	0
313775	309275	14213J	PARTICIPANT	\N	PRESENT	0
313776	309275	11097X	PARTICIPANT	\N	PRESENT	0
313778	311346	12041X	PARTICIPANT	\N	PRESENT	0
313779	311346	19443T	PARTICIPANT	\N	PRESENT	0
313780	311346	11080N	PARTICIPANT	\N	PRESENT	0
313781	311346	95030B	PARTICIPANT	\N	PRESENT	0
313782	311346	04040A	PARTICIPANT	\N	PRESENT	0
313783	311346	14079W	PARTICIPANT	\N	PRESENT	0
313784	311346	01058X	PARTICIPANT	\N	PRESENT	0
313785	311346	16685X	PARTICIPANT	\N	PRESENT	0
313786	311346	04042C	PRESIDENT	0	PRESENT	0
313787	311346	11066Q	PARTICIPANT	\N	PRESENT	0
313788	311346	19709B	PARTICIPANT	\N	PRESENT	0
313789	311346	14193X	PARTICIPANT	\N	PRESENT	0
305824	305823	04070G	PARTICIPANT	\N	PRESENT	0
305825	305823	11104D	PARTICIPANT	\N	PRESENT	0
305826	305823	04057K	PARTICIPANT	\N	PRESENT	0
305827	305823	19693L	PARTICIPANT	\N	PRESENT	0
305828	305823	08012N	PARTICIPANT	\N	PRESENT	0
305829	305823	14109K	PARTICIPANT	\N	PRESENT	0
305830	305577	14109K	PARTICIPANT	\N	PRESENT	0
305831	305576	05008E	PRESIDENT	0	PRESENT	0
305880	305576	14089Y	PARTICIPANT	\N	PRESENT	0
305833	305576	11033F	PARTICIPANT	\N	PRESENT	0
310204	309056	14259Y	PARTICIPANT	\N	PRESENT	0
310205	309056	11072N	PARTICIPANT	\N	PRESENT	0
305838	305576	14053L	PARTICIPANT	\N	PRESENT	0
305839	305576	19629C	PARTICIPANT	\N	PRESENT	0
305840	305576	04038G	PARTICIPANT	\N	PRESENT	0
305841	305576	19253P	PARTICIPANT	\N	PRESENT	0
305842	305576	14259Y	PARTICIPANT	\N	PRESENT	0
305843	305576	04008A	PARTICIPANT	\N	PRESENT	0
305844	305576	19719D	PARTICIPANT	\N	EXCUSE	0
305845	305576	14041T	PARTICIPANT	\N	EXCUSE	0
305846	305576	01024M	PARTICIPANT	\N	PRESENT	0
305847	305576	14215L	PARTICIPANT	\N	PRESENT	0
305848	305576	14151M	PARTICIPANT	\N	PRESENT	0
305849	305576	19673G	PARTICIPANT	\N	PRESENT	0
305850	305576	08045X	PARTICIPANT	\N	PRESENT	0
305851	305576	08018U	PARTICIPANT	\N	EXCUSE	0
310206	309056	14053L	PARTICIPANT	\N	PRESENT	0
305853	305576	14231L	PARTICIPANT	\N	PRESENT	0
305854	305576	19649G	PARTICIPANT	\N	PRESENT	0
305855	305576	11049P	PARTICIPANT	\N	PRESENT	0
305856	305576	19725B	PARTICIPANT	\N	PRESENT	0
305857	305576	14179A	PARTICIPANT	\N	PRESENT	0
305858	305576	08044W	PARTICIPANT	\N	PRESENT	0
305859	305576	19447X	PARTICIPANT	\N	PRESENT	0
305860	305576	14021P	PARTICIPANT	\N	PRESENT	0
305861	305576	19489J	PARTICIPANT	\N	PRESENT	0
305862	305576	11026G	PARTICIPANT	\N	PRESENT	0
305863	305576	19729F	PARTICIPANT	\N	PRESENT	0
305864	305576	19581D	PARTICIPANT	\N	PRESENT	0
305865	305576	14111D	PARTICIPANT	\N	PRESENT	0
305866	305576	14001X	PARTICIPANT	\N	PRESENT	0
310207	309056	98035U	PARTICIPANT	\N	PRESENT	0
310208	309056	14065Q	PARTICIPANT	\N	PRESENT	0
305869	305576	14147R	PARTICIPANT	\N	PRESENT	0
310209	309056	07034Q	PARTICIPANT	\N	PRESENT	0
305871	305576	07034Q	PARTICIPANT	\N	PRESENT	0
310210	309056	10015M	PARTICIPANT	\N	PRESENT	0
310211	309056	08045X	PARTICIPANT	\N	PRESENT	0
305874	305576	19762G	PARTICIPANT	\N	PRESENT	0
305875	305576	01028R	PARTICIPANT	\N	PRESENT	0
310212	309056	19253P	PARTICIPANT	\N	PRESENT	0
310213	309056	01024M	PARTICIPANT	\N	PRESENT	0
305878	305576	04044E	PARTICIPANT	\N	PRESENT	0
305879	305576	19585H	PARTICIPANT	\N	PRESENT	0
310214	309056	19719D	PARTICIPANT	\N	PRESENT	0
310215	309056	11033F	PARTICIPANT	\N	PRESENT	0
310216	309056	19729F	PARTICIPANT	\N	PRESENT	0
310217	309056	95063L	PARTICIPANT	\N	PRESENT	0
310218	309056	19629C	PARTICIPANT	\N	PRESENT	0
310219	309056	08044W	PARTICIPANT	\N	PRESENT	0
310220	309056	14069U	PARTICIPANT	\N	PRESENT	0
310221	309056	11085T	PARTICIPANT	\N	PRESENT	0
310222	309056	11049P	PARTICIPANT	\N	PRESENT	0
310223	309056	04008A	PARTICIPANT	\N	PRESENT	0
310224	309056	19762G	PARTICIPANT	\N	PRESENT	0
310225	309056	14021P	PARTICIPANT	\N	PRESENT	0
313341	309517	08048B	PARTICIPANT	\N	PRESENT	0
313384	309521	08048B	PARTICIPANT	\N	PRESENT	0
313387	313340	08048B	PARTICIPANT	\N	PRESENT	0
313388	309620	08048B	PARTICIPANT	\N	PRESENT	0
316529	316528	14026U	PARTICIPANT	\N	PRESENT	0
316531	316530	14026U	PARTICIPANT	\N	PRESENT	0
316798	316797	89017R	PARTICIPANT	\N	PRESENT	0
316801	316797	19575F	PARTICIPANT	\N	PRESENT	0
316804	316797	14261S	PARTICIPANT	\N	EXCUSE	0
316806	316797	14030Q	PARTICIPANT	\N	PRESENT	0
316809	316797	14105F	PARTICIPANT	\N	EXCUSE	0
316816	316797	08068F	PARTICIPANT	\N	PRESENT	0
316817	316797	14255U	PARTICIPANT	\N	PRESENT	0
316818	316797	14053L	PARTICIPANT	\N	PRESENT	0
316819	316797	14083S	PARTICIPANT	\N	PRESENT	0
316820	316797	19545Y	PARTICIPANT	\N	EXCUSE	0
316822	316797	14329V	PARTICIPANT	\N	EXCUSE	0
316824	316797	14079W	PARTICIPANT	\N	EXCUSE	0
316825	316797	14041T	PARTICIPANT	\N	EXCUSE	0
316826	316797	14151M	PARTICIPANT	\N	EXCUSE	0
316828	316797	14187A	PARTICIPANT	\N	PRESENT	0
316832	316797	14087W	PARTICIPANT	\N	EXCUSE	0
316833	316797	19521Q	PARTICIPANT	\N	PRESENT	0
316835	316797	14026U	PARTICIPANT	\N	PRESENT	0
316836	316797	14121F	PARTICIPANT	\N	PRESENT	0
316837	316797	14039A	PARTICIPANT	\N	EXCUSE	0
316838	316797	14061L	PARTICIPANT	\N	PRESENT	0
316839	316797	11099A	PARTICIPANT	\N	EXCUSE	0
316840	316797	04049K	PRESIDENT	0	PRESENT	0
316842	316797	08015R	PARTICIPANT	\N	PRESENT	0
316843	316797	16685X	PARTICIPANT	\N	EXCUSE	0
316844	316797	14205J	PARTICIPANT	\N	EXCUSE	0
316845	316797	19671E	PARTICIPANT	\N	EXCUSE	0
316846	316797	14265W	PARTICIPANT	\N	PRESENT	0
316848	316797	14253S	PARTICIPANT	\N	PRESENT	0
316849	316797	08047A	PARTICIPANT	\N	EXCUSE	0
316850	316797	04088S	PARTICIPANT	\N	PRESENT	0
316851	316797	14051J	PARTICIPANT	\N	EXCUSE	0
316852	316797	19527W	PARTICIPANT	\N	EXCUSE	0
316853	316797	14157T	PARTICIPANT	\N	PRESENT	0
316855	316797	19669L	PARTICIPANT	\N	EXCUSE	0
325178	322759	19729F	PARTICIPANT	\N	EXCUSE	0
326505	324291	11033F	PARTICIPANT	\N	PRESENT	0
326506	324291	14089Y	PARTICIPANT	\N	PRESENT	0
326507	324291	19729F	PARTICIPANT	\N	PRESENT	0
326508	324291	95063L	PARTICIPANT	\N	PRESENT	0
326509	324291	19629C	PARTICIPANT	\N	PRESENT	0
326510	324291	04008A	PARTICIPANT	\N	PRESENT	0
326511	324291	19762G	PARTICIPANT	\N	PRESENT	0
326512	324906	08069G	PARTICIPANT	\N	PRESENT	0
326513	324906	11048N	PARTICIPANT	\N	PRESENT	0
326514	326411	11045K	PARTICIPANT	\N	PRESENT	0
326515	324906	08034U	PARTICIPANT	\N	PRESENT	0
326516	324291	08051V	PARTICIPANT	\N	PRESENT	0
326517	326411	19760E	PARTICIPANT	\N	PRESENT	0
326518	326411	19301E	PARTICIPANT	\N	PRESENT	0
326522	324291	19725B	PARTICIPANT	\N	PRESENT	0
326523	324291	14069U	PARTICIPANT	\N	PRESENT	0
326558	324906	11053K	PARTICIPANT	\N	PRESENT	0
326559	324906	14225N	PARTICIPANT	\N	PRESENT	0
326560	324906	19647E	PARTICIPANT	\N	PRESENT	0
326561	324906	19687N	PARTICIPANT	\N	PRESENT	0
326562	324906	14199E	PARTICIPANT	\N	PRESENT	0
326563	325784	19768N	PARTICIPANT	\N	PRESENT	0
326564	325784	19515S	PARTICIPANT	\N	PRESENT	0
326565	325784	19782L	PARTICIPANT	\N	PRESENT	0
326566	325784	01043Q	PARTICIPANT	\N	PRESENT	0
313441	311341	98018T	PARTICIPANT	\N	EXCUSE	0
311755	311754	19415P	PARTICIPANT	\N	PRESENT	0
311756	311754	11067R	PARTICIPANT	\N	PRESENT	0
313442	311341	14097Y	PARTICIPANT	\N	EXCUSE	0
313444	311342	98018T	PARTICIPANT	\N	EXCUSE	0
313445	311342	14097Y	PARTICIPANT	\N	EXCUSE	0
317339	317338	14111D	PARTICIPANT	\N	PRESENT	0
324146	314152	04018C	PARTICIPANT	\N	PRESENT	0
324515	324514	14065Q	PARTICIPANT	\N	PRESENT	0
324516	324514	96004D	PARTICIPANT	\N	EXCUSE	0
324517	324514	14357A	PARTICIPANT	\N	PRESENT	0
324518	324514	11083R	PARTICIPANT	\N	PRESENT	0
324519	324514	19725B	PARTICIPANT	\N	PRESENT	0
324520	324514	95037J	PARTICIPANT	\N	PRESENT	0
324521	324514	04061F	PARTICIPANT	\N	PRESENT	0
324522	324514	14001X	PARTICIPANT	\N	PRESENT	0
324523	324514	19563B	PARTICIPANT	\N	PRESENT	0
324524	324514	14229S	PARTICIPANT	\N	PRESENT	0
324525	324514	98035U	PARTICIPANT	\N	PRESENT	0
324526	324514	14331P	PARTICIPANT	\N	PRESENT	0
324527	324514	14237S	PARTICIPANT	\N	PRESENT	0
324528	324514	10015M	PRESIDENT	0	PRESENT	0
324529	324514	19569H	PARTICIPANT	\N	PRESENT	0
324530	324514	14089Y	PARTICIPANT	\N	PRESENT	0
324531	324514	08018U	PARTICIPANT	\N	EXCUSE	0
324532	324514	11026G	PARTICIPANT	\N	EXCUSE	0
324533	324514	14061L	PARTICIPANT	\N	EXCUSE	0
324534	324514	04035D	PARTICIPANT	\N	EXCUSE	0
324535	324514	14073Q	PARTICIPANT	\N	PRESENT	0
324557	324514	14221J	PARTICIPANT	\N	PRESENT	0
325164	325162	08011M	PARTICIPANT	\N	PRESENT	0
325366	314162	14229S	PARTICIPANT	\N	PRESENT	0
325172	325171	14001X	PARTICIPANT	\N	PRESENT	0
325173	325171	14215L	PARTICIPANT	\N	PRESENT	0
325218	325217	14111D	PARTICIPANT	\N	PRESENT	0
325260	324877	11074Q	PRESIDENT	0	PRESENT	0
325220	325217	04047H	PARTICIPANT	\N	PRESENT	0
325367	314162	08055A	PARTICIPANT	\N	PRESENT	0
325274	324877	14331P	PARTICIPANT	\N	PRESENT	0
325275	324877	08011M	PARTICIPANT	\N	PRESENT	0
325276	324877	19667J	PARTICIPANT	\N	PRESENT	0
325277	324877	07004J	PARTICIPANT	\N	PRESENT	0
325278	324877	14034U	PARTICIPANT	\N	PRESENT	0
325279	324877	19687N	PARTICIPANT	\N	PRESENT	0
325280	324877	11070L	PARTICIPANT	\N	PRESENT	0
325281	314160	04044E	PARTICIPANT	\N	PRESENT	0
325282	314160	19581D	PARTICIPANT	\N	PRESENT	0
325283	314160	04034C	PARTICIPANT	\N	PRESENT	0
325284	314160	19651A	PARTICIPANT	\N	PRESENT	0
325285	314160	19593H	PARTICIPANT	\N	PRESENT	0
325286	314160	19711U	PARTICIPANT	\N	PRESENT	0
325287	314160	19667J	PARTICIPANT	\N	PRESENT	0
325288	314160	14331P	PARTICIPANT	\N	PRESENT	0
325289	314160	19679N	PARTICIPANT	\N	PRESENT	0
325290	314160	19367Y	PARTICIPANT	\N	PRESENT	0
325291	314160	08034U	PARTICIPANT	\N	PRESENT	0
325292	314160	01057W	PARTICIPANT	\N	PRESENT	0
325293	314160	07004J	PARTICIPANT	\N	PRESENT	0
325294	314160	14225N	PARTICIPANT	\N	PRESENT	0
325295	314160	11012A	PARTICIPANT	\N	PRESENT	0
325296	314160	04086Q	PARTICIPANT	\N	PRESENT	0
325297	314160	19687N	PARTICIPANT	\N	PRESENT	0
325298	314160	11040E	PARTICIPANT	\N	PRESENT	0
325299	314160	14159V	PARTICIPANT	\N	PRESENT	0
325300	314160	19545Y	PARTICIPANT	\N	PRESENT	0
325301	314160	11072N	PARTICIPANT	\N	PRESENT	0
325302	314160	19741B	PARTICIPANT	\N	PRESENT	0
325303	314160	14265W	PARTICIPANT	\N	PRESENT	0
325304	314160	11053K	PARTICIPANT	\N	PRESENT	0
325305	314160	04071H	PARTICIPANT	\N	PRESENT	0
325306	314160	11074Q	PARTICIPANT	\N	PRESENT	0
325307	314160	08011M	PARTICIPANT	\N	PRESENT	0
325308	314160	99004R	PARTICIPANT	\N	PRESENT	0
325309	314160	08010L	PARTICIPANT	\N	PRESENT	0
325310	314160	14327T	PARTICIPANT	\N	PRESENT	0
325311	314160	14211G	PARTICIPANT	\N	PRESENT	0
325261	324877	07029T	PARTICIPANT	\N	EXCUSE	0
325262	324877	08014Q	PARTICIPANT	\N	EXCUSE	0
325263	324877	04086Q	PARTICIPANT	\N	PRESENT	0
325264	324877	11012A	PARTICIPANT	\N	PRESENT	0
325265	324877	19711U	PARTICIPANT	\N	PRESENT	0
325266	324877	19545Y	PARTICIPANT	\N	PRESENT	0
325267	324877	01057W	PARTICIPANT	\N	PRESENT	0
325268	324877	11053K	PARTICIPANT	\N	PRESENT	0
325269	324877	14253S	PARTICIPANT	\N	PRESENT	0
325270	324877	99004R	PARTICIPANT	\N	PRESENT	0
325271	324877	14159V	PARTICIPANT	\N	PRESENT	0
325272	324877	14225N	PARTICIPANT	\N	PRESENT	0
325312	314160	14034U	PARTICIPANT	\N	PRESENT	0
325313	314160	04043D	PARTICIPANT	\N	PRESENT	0
325314	314160	14187A	PARTICIPANT	\N	PRESENT	0
325315	314160	14041T	PARTICIPANT	\N	PRESENT	0
325316	314160	14191V	PARTICIPANT	\N	PRESENT	0
325317	314160	95063L	PARTICIPANT	\N	PRESENT	0
325323	314160	11027H	PARTICIPANT	\N	PRESENT	0
325324	314160	14085U	PARTICIPANT	\N	PRESENT	0
325325	314160	14055N	PARTICIPANT	\N	PRESENT	0
325326	314160	11064N	PARTICIPANT	\N	PRESENT	0
325327	314160	08061X	PARTICIPANT	\N	PRESENT	0
325328	314160	19533U	PARTICIPANT	\N	PRESENT	0
325329	314160	04042C	PARTICIPANT	\N	PRESENT	0
325330	314160	14083S	PARTICIPANT	\N	PRESENT	0
325331	314160	19683J	PARTICIPANT	\N	PRESENT	0
325332	314160	11109J	PARTICIPANT	\N	PRESENT	0
325333	314160	11085T	PARTICIPANT	\N	PRESENT	0
325338	314162	04044E	PARTICIPANT	\N	PRESENT	0
325368	314162	14051J	PARTICIPANT	\N	PRESENT	0
325369	314162	17583W	PARTICIPANT	\N	PRESENT	0
325370	314162	11049P	PARTICIPANT	\N	PRESENT	0
325343	324297	19581D	PARTICIPANT	\N	PRESENT	0
325371	314162	14191V	PARTICIPANT	\N	PRESENT	0
325372	314162	19631V	PARTICIPANT	\N	PRESENT	0
325373	314162	19611R	PARTICIPANT	\N	PRESENT	0
325347	324297	14231L	PARTICIPANT	\N	PRESENT	0
325348	324297	19447X	PARTICIPANT	\N	PRESENT	0
325374	314162	19399H	PARTICIPANT	\N	PRESENT	0
325375	314162	19301E	PARTICIPANT	\N	PRESENT	0
325351	324297	14215L	PARTICIPANT	\N	PRESENT	0
325352	324297	14053L	PARTICIPANT	\N	PRESENT	0
325380	314162	04043D	PARTICIPANT	\N	PRESENT	0
325381	314162	14105F	PARTICIPANT	\N	PRESENT	0
325384	314162	80027E	PARTICIPANT	\N	PRESENT	0
325385	314162	14265W	PARTICIPANT	\N	PRESENT	0
325386	314162	19679N	PARTICIPANT	\N	PRESENT	0
325358	324297	04038G	PARTICIPANT	\N	PRESENT	0
325387	314162	04085P	PARTICIPANT	\N	PRESENT	0
325388	314162	19565D	PARTICIPANT	\N	PRESENT	0
325389	314162	19681G	PARTICIPANT	\N	PRESENT	0
325390	314162	19719D	PARTICIPANT	\N	PRESENT	0
325391	314162	14081Q	PARTICIPANT	\N	PRESENT	0
325364	324297	14041T	PARTICIPANT	\N	PRESENT	0
325365	324297	19585H	PARTICIPANT	\N	PRESENT	0
325392	324885	14331P	PARTICIPANT	\N	PRESENT	0
325393	324885	19479G	PARTICIPANT	\N	PRESENT	0
325394	324885	19711U	PARTICIPANT	\N	PRESENT	0
325395	324885	01048V	PARTICIPANT	\N	PRESENT	0
325396	324885	08034U	PARTICIPANT	\N	PRESENT	0
325397	324885	08069G	PARTICIPANT	\N	PRESENT	0
325398	324885	01057W	PARTICIPANT	\N	PRESENT	0
325399	324885	11074Q	PRESIDENT	0	PRESENT	0
325400	324885	08011M	PARTICIPANT	\N	PRESENT	0
325401	324885	89017R	PARTICIPANT	\N	PRESENT	0
325402	324885	08014Q	PARTICIPANT	\N	PRESENT	0
325403	324885	19671E	PARTICIPANT	\N	PRESENT	0
325404	324885	14225N	PARTICIPANT	\N	PRESENT	0
325405	324885	11070L	PARTICIPANT	\N	PRESENT	0
325406	324885	14159V	PARTICIPANT	\N	PRESENT	0
325407	324885	11110B	PARTICIPANT	\N	PRESENT	0
325408	324885	11040E	PARTICIPANT	\N	PRESENT	0
325409	324885	07029T	PARTICIPANT	\N	PRESENT	0
325410	324885	14083S	PARTICIPANT	\N	PRESENT	0
325411	324885	14085U	PARTICIPANT	\N	PRESENT	0
325412	324885	19507S	PARTICIPANT	\N	PRESENT	0
325413	324885	19741B	PARTICIPANT	\N	PRESENT	0
325414	324885	08010L	PARTICIPANT	\N	PRESENT	0
325415	324885	99004R	PARTICIPANT	\N	PRESENT	0
325416	314162	19749K	PARTICIPANT	\N	PRESENT	0
325417	314162	19581D	PARTICIPANT	\N	PRESENT	0
325428	324297	14111D	PARTICIPANT	\N	PRESENT	0
325429	324297	07034Q	PARTICIPANT	\N	PRESENT	0
325430	324297	08045X	PARTICIPANT	\N	PRESENT	0
325431	324297	10015M	PARTICIPANT	\N	PRESENT	0
325432	324297	01024M	PARTICIPANT	\N	PRESENT	0
325433	324297	04047H	PARTICIPANT	\N	PRESENT	0
325434	324297	05008E	PARTICIPANT	\N	PRESENT	0
325435	324297	19725B	PARTICIPANT	\N	PRESENT	0
325436	324297	14147R	PARTICIPANT	\N	PRESENT	0
325437	324297	14151M	PARTICIPANT	\N	PRESENT	0
325438	324297	14069U	PARTICIPANT	\N	PRESENT	0
304589	303956	14281W	PARTICIPANT	\N	PRESENT	0
304590	303956	08038Y	PARTICIPANT	\N	PRESENT	0
304592	304591	05008E	PRESIDENT	1	PRESENT	0
304593	304591	14089Y	PARTICIPANT	\N	PRESENT	0
304594	304591	14053L	PARTICIPANT	\N	PRESENT	0
304595	304591	14215L	PRESIDENT	0	PRESENT	0
304596	304591	19673G	PARTICIPANT	\N	PRESENT	0
304597	304591	08018U	PARTICIPANT	\N	PRESENT	0
304598	304591	11049P	PARTICIPANT	\N	PRESENT	0
304599	304591	19725B	PARTICIPANT	\N	PRESENT	0
304600	304591	14179A	PARTICIPANT	\N	PRESENT	0
304601	304591	19447X	PARTICIPANT	\N	PRESENT	0
304602	304591	11026G	PARTICIPANT	\N	PRESENT	0
304603	304591	11085T	PARTICIPANT	\N	PRESENT	0
304604	304591	01028R	PARTICIPANT	\N	PRESENT	0
304605	303728	14089Y	PARTICIPANT	\N	PRESENT	0
304606	303728	04047H	PARTICIPANT	\N	PRESENT	0
304607	303728	11085T	PARTICIPANT	\N	PRESENT	0
304608	303728	95063L	PARTICIPANT	\N	PRESENT	0
304609	303728	19669L	PARTICIPANT	\N	PRESENT	0
304610	303728	11045K	PARTICIPANT	\N	PRESENT	0
304611	303728	19679N	PARTICIPANT	\N	PRESENT	0
304612	303728	19503N	PARTICIPANT	\N	PRESENT	0
304614	303728	04038G	PARTICIPANT	\N	PRESENT	0
304615	303728	11080N	PARTICIPANT	\N	PRESENT	0
306077	305954	19723Y	PARTICIPANT	\N	EXCUSE	0
308985	308984	19699S	PARTICIPANT	\N	PRESENT	0
308986	308984	19749K	PARTICIPANT	\N	PRESENT	0
310301	309702	19507S	PARTICIPANT	\N	PRESENT	0
310302	309702	19747H	PARTICIPANT	\N	PRESENT	0
310303	309702	14207L	PARTICIPANT	\N	PRESENT	0
310304	309702	04043D	PARTICIPANT	\N	PRESENT	0
310305	309702	17589D	PARTICIPANT	\N	PRESENT	0
310306	309702	19591F	PARTICIPANT	\N	EXCUSE	0
310311	309265	14034U	PARTICIPANT	\N	PRESENT	0
310478	310257	14073Q	PARTICIPANT	\N	EXCUSE	0
310479	310257	04034C	PARTICIPANT	\N	EXCUSE	0
310480	310257	08043V	PARTICIPANT	\N	EXCUSE	0
310481	310257	19251M	PARTICIPANT	\N	EXCUSE	0
310482	310257	01058X	PARTICIPANT	\N	PRESENT	0
310483	310257	01060R	PARTICIPANT	\N	PRESENT	0
310484	310257	14089Y	PARTICIPANT	\N	PRESENT	0
310485	310462	19697Q	PARTICIPANT	\N	PRESENT	0
310486	310462	11067R	PARTICIPANT	\N	PRESENT	0
310487	310462	14355X	PARTICIPANT	\N	PRESENT	0
310488	310462	11097X	PARTICIPANT	\N	PRESENT	0
310489	310462	19415P	PARTICIPANT	\N	PRESENT	0
310490	310462	04045F	PARTICIPANT	\N	PRESENT	0
310491	310462	14227Q	PARTICIPANT	\N	PRESENT	0
310492	310462	17779H	PARTICIPANT	\N	PRESENT	0
310493	310462	19703U	PARTICIPANT	\N	PRESENT	0
310494	310462	11031D	PARTICIPANT	\N	PRESENT	0
310495	310462	14239U	PARTICIPANT	\N	PRESENT	0
310496	310462	19553Y	PARTICIPANT	\N	PRESENT	0
310497	310462	14087W	PARTICIPANT	\N	PRESENT	0
310498	310462	14281W	PARTICIPANT	\N	PRESENT	0
310499	310462	14042U	PARTICIPANT	\N	PRESENT	0
310500	310462	14195A	PARTICIPANT	\N	PRESENT	0
310501	310462	19575F	PARTICIPANT	\N	PRESENT	0
310502	310462	19367Y	PARTICIPANT	\N	PRESENT	0
310503	310462	14213J	PARTICIPANT	\N	PRESENT	0
310504	310462	19335Q	PARTICIPANT	\N	PRESENT	0
310505	310462	14217N	PARTICIPANT	\N	PRESENT	0
310506	310462	14261S	PARTICIPANT	\N	PRESENT	0
310507	310462	19683J	PARTICIPANT	\N	PRESENT	0
310508	310462	10006L	PARTICIPANT	\N	PRESENT	0
310509	310462	98024R	PRESIDENT	1	PRESENT	0
310510	310462	19521Q	PARTICIPANT	\N	PRESENT	0
310511	310462	01034P	PARTICIPANT	\N	PRESENT	0
310512	310462	04092N	PRESIDENT	0	PRESENT	0
310513	310462	11045K	PARTICIPANT	\N	PRESENT	0
310514	310462	08052W	PARTICIPANT	\N	PRESENT	0
310515	310462	19663E	PARTICIPANT	\N	PRESENT	0
310516	310462	19723Y	PARTICIPANT	\N	PRESENT	0
310517	310462	19727D	PARTICIPANT	\N	PRESENT	0
310518	310462	14119M	PARTICIPANT	\N	PRESENT	0
310519	310462	11103C	PARTICIPANT	\N	PRESENT	0
310520	310462	19657G	PARTICIPANT	\N	PRESENT	0
310521	310462	14071N	PARTICIPANT	\N	PRESENT	0
310522	310462	19577H	PARTICIPANT	\N	PRESENT	0
310523	310462	08048B	PARTICIPANT	\N	PRESENT	0
310524	310462	19715Y	PARTICIPANT	\N	PRESENT	0
310525	310462	08041T	PARTICIPANT	\N	EXCUSE	0
310526	309265	01048V	PARTICIPANT	\N	PRESENT	0
310527	309265	17583W	PARTICIPANT	\N	PRESENT	0
310528	310257	04057K	PARTICIPANT	\N	PRESENT	0
310529	310257	14001X	PARTICIPANT	\N	PRESENT	0
310530	310257	14205J	PARTICIPANT	\N	PRESENT	0
310531	310257	19507S	PARTICIPANT	\N	PRESENT	0
310532	310257	08017T	PARTICIPANT	\N	PRESENT	0
310533	310257	04061F	PARTICIPANT	\N	PRESENT	0
310534	309265	14267Y	PARTICIPANT	\N	PRESENT	0
310535	310257	04097T	PARTICIPANT	\N	PRESENT	0
310536	310257	19333N	PARTICIPANT	\N	PRESENT	0
310537	310257	19573D	PARTICIPANT	\N	PRESENT	0
310538	310257	14069U	PARTICIPANT	\N	PRESENT	0
310539	309265	14241N	PARTICIPANT	\N	PRESENT	0
310540	309265	19737F	PARTICIPANT	\N	PRESENT	0
310541	309265	19713W	PARTICIPANT	\N	PRESENT	0
310544	309265	19503N	PARTICIPANT	\N	PRESENT	0
310545	309265	14069U	PARTICIPANT	\N	PRESENT	0
310546	310543	14237S	PARTICIPANT	\N	EXCUSE	0
310547	310543	19593H	PARTICIPANT	\N	EXCUSE	0
310548	310543	19549D	PARTICIPANT	\N	EXCUSE	0
310549	310543	19735D	PARTICIPANT	\N	EXCUSE	0
310550	309265	08031R	PARTICIPANT	\N	PRESENT	0
310551	309265	98022P	PARTICIPANT	\N	PRESENT	0
310552	309265	19349W	PARTICIPANT	\N	PRESENT	0
310553	309265	02002K	PARTICIPANT	\N	PRESENT	0
310554	309265	04061F	PARTICIPANT	\N	PRESENT	0
310555	310543	19725B	PARTICIPANT	\N	PRESENT	0
310556	310543	14061L	PARTICIPANT	\N	PRESENT	0
310557	310543	04049K	PARTICIPANT	\N	PRESENT	0
310558	310543	14115H	PARTICIPANT	\N	PRESENT	0
310559	310543	96004D	PARTICIPANT	\N	PRESENT	0
310560	310543	19503N	PARTICIPANT	\N	PRESENT	0
310561	310543	14079W	PRESIDENT	0	PRESENT	0
310562	310543	19739H	PARTICIPANT	\N	PRESENT	0
310563	310543	14033T	PARTICIPANT	\N	PRESENT	0
310564	310543	19669L	PARTICIPANT	\N	PRESENT	0
310569	309265	14030Q	PARTICIPANT	\N	PRESENT	0
310570	310543	04044E	PARTICIPANT	\N	PRESENT	0
310571	310543	95063L	PARTICIPANT	\N	PRESENT	0
310572	310543	14207L	PARTICIPANT	\N	PRESENT	0
310573	310543	19563B	PARTICIPANT	\N	PRESENT	0
310574	310543	08039A	PARTICIPANT	\N	PRESENT	0
310575	310543	14031R	PARTICIPANT	\N	PRESENT	0
310576	310543	10015M	PARTICIPANT	\N	PRESENT	0
310577	310543	19347U	PARTICIPANT	\N	PRESENT	0
310579	310543	14001X	PARTICIPANT	\N	PRESENT	0
310580	310543	19747H	PARTICIPANT	\N	PRESENT	0
310581	310543	14215L	PARTICIPANT	\N	PRESENT	0
310582	309265	19695N	PARTICIPANT	\N	PRESENT	0
310583	310543	19335Q	PARTICIPANT	\N	PRESENT	0
310586	310543	14229S	PARTICIPANT	\N	PRESENT	0
310599	309265	14121F	PARTICIPANT	\N	PRESENT	0
310600	309265	11053K	PARTICIPANT	\N	PRESENT	0
310601	309265	14097Y	PARTICIPANT	\N	PRESENT	0
310602	309265	11109J	PARTICIPANT	\N	PRESENT	0
310603	310462	14223L	PARTICIPANT	\N	PRESENT	0
310605	309265	14021P	PARTICIPANT	\N	PRESENT	0
310606	309265	11085T	PARTICIPANT	\N	PRESENT	0
313790	311346	97011G	PARTICIPANT	\N	PRESENT	0
313791	311346	08061X	PARTICIPANT	\N	PRESENT	0
313792	311346	08047A	PARTICIPANT	\N	PRESENT	0
313793	311346	98029W	PARTICIPANT	\N	PRESENT	0
313794	311346	14133K	PARTICIPANT	\N	PRESENT	0
313795	311346	01062T	PARTICIPANT	\N	PRESENT	0
313796	311346	08034U	PARTICIPANT	\N	PRESENT	0
313797	311346	11041F	PARTICIPANT	\N	PRESENT	0
313798	311346	14235Q	PARTICIPANT	\N	PRESENT	0
313799	311346	08058D	PARTICIPANT	\N	PRESENT	0
313800	311346	19251M	PARTICIPANT	\N	PRESENT	0
313801	311346	98022P	PARTICIPANT	\N	PRESENT	0
313802	311346	11064N	PARTICIPANT	\N	PRESENT	0
313803	311346	98050T	PARTICIPANT	\N	PRESENT	0
313804	311346	19583F	PARTICIPANT	\N	PRESENT	0
313805	311346	14255U	PARTICIPANT	\N	PRESENT	0
313806	311346	14097Y	PARTICIPANT	\N	EXCUSE	0
313807	309275	04059M	PARTICIPANT	\N	PRESENT	0
313808	309275	19701S	PARTICIPANT	\N	PRESENT	0
313809	309275	14357A	PARTICIPANT	\N	PRESENT	0
313810	309275	11083R	PARTICIPANT	\N	PRESENT	0
313811	309275	11090Q	PARTICIPANT	\N	PRESENT	0
313812	309275	14061L	PARTICIPANT	\N	PRESENT	0
313877	313876	96004D	PRESIDENT	0	PRESENT	0
313878	313876	14089Y	PARTICIPANT	\N	PRESENT	0
313879	313876	14357A	PARTICIPANT	\N	PRESENT	0
313880	313876	14079W	PARTICIPANT	\N	PRESENT	0
313881	313876	11083R	PARTICIPANT	\N	PRESENT	0
313882	313876	19725B	PARTICIPANT	\N	PRESENT	0
313883	313876	19569H	PARTICIPANT	\N	PRESENT	0
313884	313876	11026G	PARTICIPANT	\N	PRESENT	0
313885	313876	19593H	PARTICIPANT	\N	PRESENT	0
313886	313876	10015M	PARTICIPANT	\N	PRESENT	0
313887	313876	98035U	PARTICIPANT	\N	PRESENT	0
313888	313876	14237S	PARTICIPANT	\N	PRESENT	0
313889	313876	14331P	PARTICIPANT	\N	EXCUSE	0
313890	313876	14135M	PARTICIPANT	\N	EXCUSE	0
313891	313876	14097Y	PARTICIPANT	\N	EXCUSE	0
313892	313876	14221J	PARTICIPANT	\N	PRESENT	0
313893	313876	14001X	PARTICIPANT	\N	PRESENT	0
313894	313876	14249W	PARTICIPANT	\N	PRESENT	0
313898	313876	14073Q	PARTICIPANT	\N	PRESENT	0
313899	311809	11067R	PARTICIPANT	\N	PRESENT	0
313917	305978	19511N	PARTICIPANT	\N	EXCUSE	0
313918	305978	19693L	PARTICIPANT	\N	EXCUSE	0
313919	305978	14093U	PARTICIPANT	\N	EXCUSE	0
313920	305978	19593H	PARTICIPANT	\N	EXCUSE	0
313921	305978	19723Y	PARTICIPANT	\N	PRESENT	0
313922	305978	19683J	PARTICIPANT	\N	PRESENT	0
313925	313924	19533U	PARTICIPANT	\N	PRESENT	0
313928	313927	19533U	PARTICIPANT	\N	PRESENT	0
313932	313930	19533U	PARTICIPANT	\N	PRESENT	0
313934	313933	19533U	PARTICIPANT	\N	PRESENT	0
313937	313936	19533U	PARTICIPANT	\N	PRESENT	0
313944	312040	19727D	PARTICIPANT	\N	PRESENT	0
313945	312040	08052W	PARTICIPANT	\N	PRESENT	0
313999	313998	14261S	PARTICIPANT	\N	PRESENT	0
314001	314000	08009T	PARTICIPANT	\N	PRESENT	0
314002	314000	14219Q	PARTICIPANT	\N	PRESENT	0
314003	314000	19333N	PARTICIPANT	\N	PRESENT	0
314004	314000	19713W	PARTICIPANT	\N	PRESENT	0
314005	314000	14157T	PARTICIPANT	\N	PRESENT	0
314006	313773	08009T	PARTICIPANT	\N	PRESENT	0
314007	313773	14219Q	PARTICIPANT	\N	PRESENT	0
314008	313773	19333N	PARTICIPANT	\N	PRESENT	0
314009	313773	14221J	PARTICIPANT	\N	PRESENT	0
314010	313773	14169X	PARTICIPANT	\N	PRESENT	0
314011	313773	19713W	PARTICIPANT	\N	PRESENT	0
314012	313773	14157T	PARTICIPANT	\N	PRESENT	0
314051	305978	14299H	PARTICIPANT	\N	PRESENT	0
314052	305978	19663E	PARTICIPANT	\N	PRESENT	0
314058	305978	01048V	PRESIDENT	0	PRESENT	0
314059	305978	04043D	PARTICIPANT	\N	PRESENT	0
314061	305978	01058X	PARTICIPANT	\N	PRESENT	0
314070	314069	14028W	PARTICIPANT	\N	PRESENT	0
314071	314069	95067Q	PARTICIPANT	\N	PRESENT	0
314073	314072	14028W	PARTICIPANT	\N	PRESENT	0
314074	314072	95067Q	PARTICIPANT	\N	PRESENT	0
314089	314088	08034U	PARTICIPANT	\N	PRESENT	0
314093	314092	19689Q	PARTICIPANT	\N	PRESENT	0
314094	314092	19545Y	PARTICIPANT	\N	PRESENT	0
314099	314098	08034U	PARTICIPANT	\N	PRESENT	0
314111	314109	19689Q	PARTICIPANT	\N	PRESENT	0
314113	314112	08034U	PARTICIPANT	\N	PRESENT	0
314115	314114	08034U	PARTICIPANT	\N	PRESENT	0
314118	314117	01048V	PARTICIPANT	\N	PRESENT	0
314120	314106	14217N	PARTICIPANT	\N	PRESENT	0
314121	314116	14217N	PARTICIPANT	\N	PRESENT	0
314123	314119	14217N	PARTICIPANT	\N	PRESENT	0
314124	314122	11070L	PARTICIPANT	\N	PRESENT	0
314125	314122	19647E	PARTICIPANT	\N	PRESENT	0
314128	314127	14026U	PARTICIPANT	\N	PRESENT	0
314131	314130	14026U	PARTICIPANT	\N	PRESENT	0
314132	314129	11070L	PARTICIPANT	\N	PRESENT	0
314133	314129	19647E	PARTICIPANT	\N	PRESENT	0
314137	314136	99004R	PARTICIPANT	\N	PRESENT	0
314139	314138	11074Q	PARTICIPANT	\N	PRESENT	0
314140	314135	14069U	PARTICIPANT	\N	PRESENT	0
314141	314135	19701S	PARTICIPANT	\N	PRESENT	0
314142	314135	14034U	PARTICIPANT	\N	PRESENT	0
314260	314259	19533U	PARTICIPANT	\N	PRESENT	0
314144	314135	14031R	PARTICIPANT	\N	PRESENT	0
314145	314135	19637C	PARTICIPANT	\N	PRESENT	0
314146	314135	19762G	PARTICIPANT	\N	PRESENT	0
314183	305897	08069G	PARTICIPANT	\N	EXCUSE	0
314261	314257	19533U	PARTICIPANT	\N	PRESENT	0
314262	314257	14229S	PARTICIPANT	\N	PRESENT	0
314264	314263	19533U	PARTICIPANT	\N	PRESENT	0
314267	311802	19709B	PARTICIPANT	\N	PRESENT	0
314289	314288	14039A	PARTICIPANT	\N	PRESENT	0
314291	314290	14039A	PARTICIPANT	\N	PRESENT	0
314293	314292	14157T	PARTICIPANT	\N	PRESENT	0
314295	314294	08009T	PARTICIPANT	\N	PRESENT	0
314296	314294	14219Q	PARTICIPANT	\N	PRESENT	0
314297	314294	14157T	PARTICIPANT	\N	PRESENT	0
314298	314294	19503N	PARTICIPANT	\N	PRESENT	0
314299	314294	14038Y	PARTICIPANT	\N	PRESENT	0
314302	314301	19701S	PARTICIPANT	\N	PRESENT	0
314394	314392	11026G	PARTICIPANT	\N	PRESENT	0
314400	314399	19533U	PARTICIPANT	\N	PRESENT	0
314403	314402	19533U	PARTICIPANT	\N	PRESENT	0
314408	313990	19585H	PARTICIPANT	\N	PRESENT	0
315850	315844	14071N	PARTICIPANT	\N	PRESENT	0
315941	311802	19511N	PARTICIPANT	\N	PRESENT	0
315942	311802	19693L	PARTICIPANT	\N	PRESENT	0
315952	314390	11081P	PARTICIPANT	\N	EXCUSE	0
315953	314390	14329V	PARTICIPANT	\N	EXCUSE	0
315954	314390	08062Y	PARTICIPANT	\N	EXCUSE	0
315955	314390	19631V	PARTICIPANT	\N	EXCUSE	0
315956	314390	11090Q	PARTICIPANT	\N	EXCUSE	0
315957	314390	08021P	PARTICIPANT	\N	EXCUSE	0
315996	315995	11072N	PARTICIPANT	\N	PRESENT	0
315999	315998	11072N	PARTICIPANT	\N	PRESENT	0
316001	316000	11072N	PARTICIPANT	\N	PRESENT	0
316328	316327	19533U	PARTICIPANT	\N	PRESENT	0
316329	316327	14229S	PARTICIPANT	\N	PRESENT	0
316331	316330	19533U	PARTICIPANT	\N	PRESENT	0
316333	316332	19533U	PARTICIPANT	\N	PRESENT	0
316334	316332	14229S	PARTICIPANT	\N	PRESENT	0
316335	316332	19593H	PARTICIPANT	\N	PRESENT	0
316337	316336	11043H	PARTICIPANT	\N	PRESENT	0
316338	316336	08012N	PARTICIPANT	\N	PRESENT	0
316339	316336	14073Q	PARTICIPANT	\N	PRESENT	0
316466	305897	04061F	PARTICIPANT	\N	PRESENT	0
316865	316864	08055A	PARTICIPANT	\N	PRESENT	0
316866	316864	08043V	PARTICIPANT	\N	PRESENT	0
316867	316864	14105F	PARTICIPANT	\N	PRESENT	0
316869	316864	14207L	PARTICIPANT	\N	PRESENT	0
316870	316864	14085U	PARTICIPANT	\N	PRESENT	0
316871	316864	14195A	PARTICIPANT	\N	PRESENT	0
305308	305307	14193X	PARTICIPANT	\N	PRESENT	0
305309	305307	04040A	PARTICIPANT	\N	PRESENT	0
305310	305307	14255U	PARTICIPANT	\N	PRESENT	0
305311	305307	14267Y	PARTICIPANT	\N	PRESENT	0
305312	305307	19647E	PARTICIPANT	\N	PRESENT	0
305313	305307	19421M	PARTICIPANT	\N	PRESENT	0
307426	307425	08058D	PARTICIPANT	\N	PRESENT	0
307427	307425	11027H	PARTICIPANT	\N	PRESENT	0
307428	307425	14193X	PARTICIPANT	\N	PRESENT	0
307747	307071	11067R	PARTICIPANT	\N	PRESENT	0
310846	310845	04044E	PARTICIPANT	\N	PRESENT	0
316514	311802	14239U	PARTICIPANT	\N	PRESENT	0
316516	311802	80013X	PARTICIPANT	\N	PRESENT	0
316517	311802	14299H	PARTICIPANT	\N	PRESENT	0
316518	311802	19663E	PARTICIPANT	\N	PRESENT	0
316521	311802	19683J	PARTICIPANT	\N	PRESENT	0
316522	311802	01048V	PRESIDENT	0	PRESENT	0
316523	311802	19593H	PARTICIPANT	\N	PRESENT	0
316524	311802	19503N	PARTICIPANT	\N	PRESENT	0
316525	311802	04043D	PARTICIPANT	\N	PRESENT	0
318372	318369	14331P	PARTICIPANT	\N	PRESENT	0
318417	318416	01057W	PARTICIPANT	\N	PRESENT	0
318418	318416	14225N	PARTICIPANT	\N	PRESENT	0
319325	318863	14073Q	PARTICIPANT	\N	PRESENT	0
319341	319338	04070G	PRESIDENT	0	PRESENT	0
319342	319338	19699S	PARTICIPANT	\N	PRESENT	0
319343	319338	19533U	PARTICIPANT	\N	PRESENT	0
319344	319338	19329S	PARTICIPANT	\N	PRESENT	0
319345	319338	14229S	PARTICIPANT	\N	PRESENT	0
319346	319338	14241N	PARTICIPANT	\N	PRESENT	0
319347	319338	19573D	PARTICIPANT	\N	PRESENT	0
319348	319338	14039A	PARTICIPANT	\N	PRESENT	0
319349	319338	08039A	PARTICIPANT	\N	PRESENT	0
319350	319338	08031R	PARTICIPANT	\N	PRESENT	0
319351	319338	19593H	PARTICIPANT	\N	PRESENT	0
319352	319338	14061L	PARTICIPANT	\N	PRESENT	0
319353	319338	04057K	PARTICIPANT	\N	PRESENT	0
319354	319338	14073Q	PARTICIPANT	\N	PRESENT	0
319355	319338	08043V	PARTICIPANT	\N	PRESENT	0
319356	319338	19693L	PARTICIPANT	\N	PRESENT	0
319357	319338	19399H	PARTICIPANT	\N	PRESENT	0
319358	319338	14030Q	PARTICIPANT	\N	PRESENT	0
319359	319338	19731Y	PARTICIPANT	\N	PRESENT	0
319360	319338	08020N	PARTICIPANT	\N	PRESENT	0
319361	319338	14251Q	PARTICIPANT	\N	PRESENT	0
319362	319338	04059M	PARTICIPANT	\N	PRESENT	0
319363	319338	19735D	PARTICIPANT	\N	PRESENT	0
319364	319338	11104D	PARTICIPANT	\N	PRESENT	0
319365	319338	04018C	PARTICIPANT	\N	PRESENT	0
319366	319338	19758L	PARTICIPANT	\N	PRESENT	0
319367	319338	14109K	PARTICIPANT	\N	EXCUSE	0
319368	319338	14249W	PARTICIPANT	\N	EXCUSE	0
319369	314087	19593H	PARTICIPANT	\N	PRESENT	0
319370	314087	05008E	PARTICIPANT	\N	PRESENT	0
319371	314087	19758L	PARTICIPANT	\N	PRESENT	0
319372	314087	19565D	PARTICIPANT	\N	PRESENT	0
319373	314087	08012N	PARTICIPANT	\N	PRESENT	0
319374	314087	08043V	PARTICIPANT	\N	PRESENT	0
319375	314087	11104D	PARTICIPANT	\N	PRESENT	0
319376	314087	14229S	PARTICIPANT	\N	PRESENT	0
319377	314087	08017T	PARTICIPANT	\N	PRESENT	0
319378	317558	19701S	PARTICIPANT	\N	PRESENT	0
319379	317558	14133K	PARTICIPANT	\N	PRESENT	0
319380	317558	14079W	PRESIDENT	0	PRESENT	0
319381	317558	14033T	PARTICIPANT	\N	PRESENT	0
319382	317558	19669L	PARTICIPANT	\N	PRESENT	0
319383	317558	19725B	PARTICIPANT	\N	PRESENT	0
319384	317558	14115H	PARTICIPANT	\N	PRESENT	0
319385	317558	04049K	PARTICIPANT	\N	PRESENT	0
319386	317558	19503N	PARTICIPANT	\N	PRESENT	0
319387	317558	19347U	PARTICIPANT	\N	PRESENT	0
319388	317558	19739H	PARTICIPANT	\N	PRESENT	0
319389	317558	14213J	PARTICIPANT	\N	PRESENT	0
319390	317558	14215L	PARTICIPANT	\N	PRESENT	0
319391	317558	19335Q	PARTICIPANT	\N	PRESENT	0
319392	317558	19747H	PARTICIPANT	\N	PRESENT	0
319393	317558	14207L	PARTICIPANT	\N	PRESENT	0
319394	317558	14255U	PARTICIPANT	\N	PRESENT	0
319395	317558	14257W	PARTICIPANT	\N	PRESENT	0
319396	314087	04059M	PARTICIPANT	\N	PRESENT	0
319397	314087	19301E	PARTICIPANT	\N	PRESENT	0
319398	314087	14039A	PARTICIPANT	\N	PRESENT	0
319399	314087	14241N	PARTICIPANT	\N	PRESENT	0
319400	314087	04057K	PARTICIPANT	\N	PRESENT	0
319401	314087	17589D	PARTICIPANT	\N	PRESENT	0
319402	314087	19717B	PARTICIPANT	\N	PRESENT	0
319403	314087	19699S	PARTICIPANT	\N	PRESENT	0
319404	314087	14219Q	PARTICIPANT	\N	PRESENT	0
319405	314087	19737F	PARTICIPANT	\N	PRESENT	0
319406	314087	19611R	PARTICIPANT	\N	PRESENT	0
319407	314087	11083R	PARTICIPANT	\N	PRESENT	0
319408	314087	14030Q	PARTICIPANT	\N	PRESENT	0
319409	314087	11066Q	PARTICIPANT	\N	PRESENT	0
319410	314087	19735D	PARTICIPANT	\N	PRESENT	0
319411	314087	14073Q	PARTICIPANT	\N	PRESENT	0
319412	314087	14221J	PARTICIPANT	\N	PRESENT	0
319414	314087	19731Y	PARTICIPANT	\N	PRESENT	0
319415	314087	04018C	PARTICIPANT	\N	PRESENT	0
319416	314087	19533U	PARTICIPANT	\N	PRESENT	0
319417	314087	95062K	PARTICIPANT	\N	PRESENT	0
319418	314087	11027H	PARTICIPANT	\N	PRESENT	0
319419	314087	08039A	PARTICIPANT	\N	PRESENT	0
319421	314087	19679N	PARTICIPANT	\N	PRESENT	0
319422	314087	19515S	PARTICIPANT	\N	PRESENT	0
319423	319213	14327T	PARTICIPANT	\N	PRESENT	0
319424	319213	14331P	PARTICIPANT	\N	PRESENT	0
319425	319213	19479G	PARTICIPANT	\N	PRESENT	0
319426	319213	95041E	PARTICIPANT	\N	PRESENT	0
319427	319213	19711U	PARTICIPANT	\N	PRESENT	0
319428	319213	08069G	PARTICIPANT	\N	PRESENT	0
319429	319213	19687N	PARTICIPANT	\N	PRESENT	0
319430	319213	19689Q	PARTICIPANT	\N	PRESENT	0
319431	319213	12016W	PARTICIPANT	\N	PRESENT	0
319432	319213	19667J	PARTICIPANT	\N	PRESENT	0
319433	319213	11074Q	PRESIDENT	0	PRESENT	0
319434	319213	08011M	PARTICIPANT	\N	PRESENT	0
319435	319213	14034U	PARTICIPANT	\N	PRESENT	0
319436	319213	14225N	PARTICIPANT	\N	PRESENT	0
319437	319213	19671E	PARTICIPANT	\N	PRESENT	0
319438	319213	14173T	PARTICIPANT	\N	PRESENT	0
319439	319213	04086Q	PARTICIPANT	\N	PRESENT	0
319440	319213	11040E	PARTICIPANT	\N	PRESENT	0
319441	319213	11012A	PARTICIPANT	\N	PRESENT	0
319442	319213	14085U	PARTICIPANT	\N	PRESENT	0
319443	319213	19349W	PARTICIPANT	\N	PRESENT	0
319444	319213	99004R	PARTICIPANT	\N	PRESENT	0
319445	319213	14253S	PARTICIPANT	\N	PRESENT	0
319446	319213	04061F	PARTICIPANT	\N	PRESENT	0
319447	314087	14191V	PARTICIPANT	\N	PRESENT	0
319448	314087	15447F	PARTICIPANT	\N	PRESENT	0
319449	314087	19447X	PARTICIPANT	\N	PRESENT	0
319450	314087	19637C	PARTICIPANT	\N	PRESENT	0
319451	314087	18083K	PARTICIPANT	\N	PRESENT	0
319452	314087	04088S	PARTICIPANT	\N	PRESENT	0
319453	314087	08047A	PARTICIPANT	\N	PRESENT	0
319454	314087	19719D	PARTICIPANT	\N	PRESENT	0
319455	314087	14235Q	PARTICIPANT	\N	PRESENT	0
319456	314087	19443T	PARTICIPANT	\N	PRESENT	0
319457	314087	14147R	PARTICIPANT	\N	PRESENT	0
319458	314087	04070G	PARTICIPANT	\N	PRESENT	0
319459	314087	08018U	PARTICIPANT	\N	PRESENT	0
319460	314087	14267Y	PARTICIPANT	\N	PRESENT	0
319461	317558	04089T	PARTICIPANT	\N	PRESENT	0
319462	317558	96004D	PARTICIPANT	\N	EXCUSE	0
319735	314090	19565D	PARTICIPANT	\N	PRESENT	0
319736	314090	14001X	PARTICIPANT	\N	PRESENT	0
319737	314090	19333N	PARTICIPANT	\N	PRESENT	0
319738	314090	08017T	PARTICIPANT	\N	PRESENT	0
319739	314090	14081Q	PARTICIPANT	\N	PRESENT	0
319740	314090	04034C	PARTICIPANT	\N	PRESENT	0
319741	314090	19651A	PARTICIPANT	\N	PRESENT	0
319742	314090	19387D	PARTICIPANT	\N	PRESENT	0
319743	314090	04057K	PARTICIPANT	\N	PRESENT	0
319744	314090	17589D	PARTICIPANT	\N	PRESENT	0
319745	314090	14219Q	PARTICIPANT	\N	PRESENT	0
319746	314090	14205J	PARTICIPANT	\N	PRESENT	0
319747	314090	08068F	PARTICIPANT	\N	PRESENT	0
319748	314090	11040E	PARTICIPANT	\N	PRESENT	0
319749	314090	96004D	PARTICIPANT	\N	PRESENT	0
319750	314090	98050T	PARTICIPANT	\N	PRESENT	0
319751	314090	01058X	PARTICIPANT	\N	PRESENT	0
319752	314090	95030B	PARTICIPANT	\N	PRESENT	0
319753	314090	98018T	PARTICIPANT	\N	PRESENT	0
319754	314090	95063L	PARTICIPANT	\N	PRESENT	0
313616	313615	19415P	PARTICIPANT	\N	PRESENT	0
313617	313615	11067R	PARTICIPANT	\N	PRESENT	0
313619	313618	19415P	PARTICIPANT	\N	PRESENT	0
313620	313618	11067R	PARTICIPANT	\N	PRESENT	0
315626	315528	19766L	PARTICIPANT	\N	PRESENT	0
315627	315528	04070G	PARTICIPANT	\N	PRESENT	0
315628	315528	19699S	PARTICIPANT	\N	PRESENT	0
315629	315528	19329S	PARTICIPANT	\N	PRESENT	0
315630	315528	14229S	PARTICIPANT	\N	PRESENT	0
315631	315528	14241N	PARTICIPANT	\N	PRESENT	0
315632	315528	19573D	PARTICIPANT	\N	PRESENT	0
315633	315528	14039A	PARTICIPANT	\N	PRESENT	0
315634	315528	14107H	PARTICIPANT	\N	PRESENT	0
315635	315528	08012N	PARTICIPANT	\N	PRESENT	0
315636	315528	08039A	PARTICIPANT	\N	PRESENT	0
315637	315528	08031R	PARTICIPANT	\N	PRESENT	0
315638	315528	19593H	PARTICIPANT	\N	PRESENT	0
315639	315528	14059S	PARTICIPANT	\N	PRESENT	0
315640	315528	14061L	PARTICIPANT	\N	PRESENT	0
315641	315528	04057K	PARTICIPANT	\N	PRESENT	0
315642	315528	19611R	PARTICIPANT	\N	PRESENT	0
315643	315528	08043V	PARTICIPANT	\N	PRESENT	0
315644	315528	87003B	PARTICIPANT	\N	PRESENT	0
315645	315528	19399H	PARTICIPANT	\N	PRESENT	0
315646	315528	14201E	PARTICIPANT	\N	PRESENT	0
315647	315528	14030Q	PARTICIPANT	\N	PRESENT	0
315648	315528	14251Q	PARTICIPANT	\N	PRESENT	0
315649	315528	14063N	PARTICIPANT	\N	PRESENT	0
315650	315528	11083R	PARTICIPANT	\N	PRESENT	0
315651	315528	14123H	PRESIDENT	0	PRESENT	0
315652	315528	11104D	PARTICIPANT	\N	PRESENT	0
315653	315528	19749K	PARTICIPANT	\N	PRESENT	0
315654	315528	04018C	PARTICIPANT	\N	PRESENT	0
315655	315528	19758L	PARTICIPANT	\N	PRESENT	0
315656	313943	98029W	PARTICIPANT	\N	PRESENT	0
315657	314014	14031R	PARTICIPANT	\N	PRESENT	0
315658	314014	08024S	PARTICIPANT	\N	PRESENT	0
315659	313943	11041F	PARTICIPANT	\N	PRESENT	0
315660	314014	19565D	PARTICIPANT	\N	PRESENT	0
315661	314014	19637C	PARTICIPANT	\N	PRESENT	0
315662	314014	19515S	PARTICIPANT	\N	PRESENT	0
315663	314014	19441R	PARTICIPANT	\N	PRESENT	0
315664	314014	19369B	PARTICIPANT	\N	PRESENT	0
315665	314014	19591F	PARTICIPANT	\N	PRESENT	0
315666	314014	14205J	PARTICIPANT	\N	PRESENT	0
315667	314014	04089T	PARTICIPANT	\N	PRESENT	0
315668	314014	14115H	PARTICIPANT	\N	PRESENT	0
315669	314014	04097T	PARTICIPANT	\N	PRESENT	0
315670	314014	19619A	PARTICIPANT	\N	PRESENT	0
315671	314014	02002K	PARTICIPANT	\N	PRESENT	0
315672	314014	11101A	PARTICIPANT	\N	PRESENT	0
315673	314014	19747H	PARTICIPANT	\N	PRESENT	0
315674	314014	19768N	PARTICIPANT	\N	PRESENT	0
315675	314014	14187A	PARTICIPANT	\N	PRESENT	0
315676	314014	14357A	PARTICIPANT	\N	PRESENT	0
315677	314014	19705W	PARTICIPANT	\N	PRESENT	0
315678	314014	08015R	PARTICIPANT	\N	PRESENT	0
315679	314014	08019V	PARTICIPANT	\N	PRESENT	0
315680	314014	08028W	PARTICIPANT	\N	PRESENT	0
315681	314014	14265W	PARTICIPANT	\N	PRESENT	0
315682	314014	19467C	PARTICIPANT	\N	PRESENT	0
315683	314014	14033T	PARTICIPANT	\N	PRESENT	0
315684	314014	04088S	PARTICIPANT	\N	PRESENT	0
315685	314014	19507S	PARTICIPANT	\N	PRESENT	0
315686	314014	19551W	PARTICIPANT	\N	PRESENT	0
315687	314014	11065P	PARTICIPANT	\N	PRESENT	0
315688	314014	14237S	PARTICIPANT	\N	PRESENT	0
315689	314014	19549D	PARTICIPANT	\N	PRESENT	0
315690	313986	07029T	PARTICIPANT	\N	PRESENT	0
315691	313986	19689Q	PARTICIPANT	\N	PRESENT	0
315692	313986	14083S	PARTICIPANT	\N	PRESENT	0
315693	313986	99004R	PARTICIPANT	\N	PRESENT	0
315694	314390	19768N	PARTICIPANT	\N	PRESENT	0
315695	314390	19515S	PARTICIPANT	\N	PRESENT	0
315696	314390	01043Q	PARTICIPANT	\N	PRESENT	0
315697	314390	19565D	PARTICIPANT	\N	PRESENT	0
315698	314390	14357A	PARTICIPANT	\N	PRESENT	0
315699	314390	19441R	PARTICIPANT	\N	PRESENT	0
315700	314390	14081Q	PARTICIPANT	\N	PRESENT	0
315701	314390	19413M	PARTICIPANT	\N	PRESENT	0
315702	314390	80013X	PARTICIPANT	\N	PRESENT	0
315703	314390	04049K	PRESIDENT	0	PRESENT	0
315704	314390	19705W	PARTICIPANT	\N	PRESENT	0
315705	314390	08015R	PARTICIPANT	\N	PRESENT	0
315706	314390	08019V	PARTICIPANT	\N	PRESENT	0
315707	314390	14197C	PARTICIPANT	\N	PRESENT	0
315708	314390	19369B	PARTICIPANT	\N	PRESENT	0
315709	314390	19511N	PARTICIPANT	\N	PRESENT	0
315710	314390	08028W	PARTICIPANT	\N	PRESENT	0
315711	314390	19563B	PARTICIPANT	\N	PRESENT	0
315712	314390	14265W	PARTICIPANT	\N	PRESENT	0
315713	314390	19591F	PARTICIPANT	\N	PRESENT	0
315714	314390	19467C	PARTICIPANT	\N	PRESENT	0
315715	314390	14187A	PARTICIPANT	\N	PRESENT	0
315716	314390	08038Y	PARTICIPANT	\N	PRESENT	0
315717	314390	19695N	PARTICIPANT	\N	PRESENT	0
315718	314390	14033T	PARTICIPANT	\N	PRESENT	0
315719	314390	01025N	PARTICIPANT	\N	PRESENT	0
315720	314390	14205J	PARTICIPANT	\N	PRESENT	0
315721	314390	04088S	PARTICIPANT	\N	PRESENT	0
315722	314390	04089T	PARTICIPANT	\N	PRESENT	0
315723	314390	14115H	PARTICIPANT	\N	PRESENT	0
315724	314390	11101A	PARTICIPANT	\N	PRESENT	0
315725	314390	19507S	PARTICIPANT	\N	PRESENT	0
315726	314390	19747H	PARTICIPANT	\N	PRESENT	0
315727	314390	14207L	PARTICIPANT	\N	PRESENT	0
315728	314390	19619A	PARTICIPANT	\N	PRESENT	0
315729	314390	14257W	PARTICIPANT	\N	PRESENT	0
315730	313989	14001X	PARTICIPANT	\N	PRESENT	0
315731	313989	04044E	PARTICIPANT	\N	PRESENT	0
315732	313989	19581D	PARTICIPANT	\N	PRESENT	0
315733	313989	19585H	PARTICIPANT	\N	PRESENT	0
315734	313989	19673G	PARTICIPANT	\N	PRESENT	0
315735	313989	01028R	PARTICIPANT	\N	PRESENT	0
315736	313989	19447X	PARTICIPANT	\N	PRESENT	0
315737	313989	05008E	PRESIDENT	0	PRESENT	0
315738	313989	14041T	PARTICIPANT	\N	PRESENT	0
315739	313989	14147R	PARTICIPANT	\N	PRESENT	0
315740	313989	14151M	PARTICIPANT	\N	PRESENT	0
315741	313989	14215L	PARTICIPANT	\N	PRESENT	0
315742	313989	98035U	PARTICIPANT	\N	PRESENT	0
315743	313989	14053L	PARTICIPANT	\N	PRESENT	0
315744	313989	14111D	PARTICIPANT	\N	PRESENT	0
315745	313989	07034Q	PARTICIPANT	\N	PRESENT	0
315746	313989	08045X	PARTICIPANT	\N	PRESENT	0
315747	313989	19253P	PARTICIPANT	\N	PRESENT	0
315748	313989	01024M	PARTICIPANT	\N	PRESENT	0
315749	313989	04038G	PARTICIPANT	\N	PRESENT	0
315750	313989	19719D	PARTICIPANT	\N	PRESENT	0
315751	313989	19729F	PARTICIPANT	\N	PRESENT	0
315752	313989	19629C	PARTICIPANT	\N	PRESENT	0
315753	313989	14069U	PARTICIPANT	\N	PRESENT	0
315754	313989	11049P	PARTICIPANT	\N	PRESENT	0
315755	313989	14021P	PARTICIPANT	\N	PRESENT	0
315756	313989	14065Q	PARTICIPANT	\N	EXCUSE	0
315757	313989	14179A	PARTICIPANT	\N	EXCUSE	0
315758	314014	14221J	PARTICIPANT	\N	PRESENT	0
315760	313989	14259Y	PARTICIPANT	\N	PRESENT	0
315761	313943	19421M	PARTICIPANT	\N	PRESENT	0
315851	313439	11067R	PARTICIPANT	\N	PRESENT	0
315852	313439	11077T	PARTICIPANT	\N	PRESENT	0
315853	313439	14355X	PARTICIPANT	\N	PRESENT	0
315854	313439	19569H	PARTICIPANT	\N	PRESENT	0
315855	313439	11097X	PARTICIPANT	\N	PRESENT	0
315856	313439	19415P	PARTICIPANT	\N	PRESENT	0
315857	313439	14223L	PARTICIPANT	\N	PRESENT	0
315858	313439	04045F	PARTICIPANT	\N	PRESENT	0
315859	313439	14026U	PARTICIPANT	\N	PRESENT	0
315860	313439	14227Q	PARTICIPANT	\N	PRESENT	0
315861	313439	19675J	PARTICIPANT	\N	PRESENT	0
315862	313439	17779H	PARTICIPANT	\N	PRESENT	0
315863	313439	19703U	PARTICIPANT	\N	PRESENT	0
315864	313439	19553Y	PARTICIPANT	\N	PRESENT	0
315865	313439	14239U	PARTICIPANT	\N	PRESENT	0
315866	313439	11031D	PARTICIPANT	\N	PRESENT	0
315867	313439	14281W	PARTICIPANT	\N	PRESENT	0
315868	313439	19679N	PARTICIPANT	\N	PRESENT	0
315869	313439	14042U	PARTICIPANT	\N	PRESENT	0
315870	313439	19575F	PARTICIPANT	\N	PRESENT	0
315871	313439	08048B	PARTICIPANT	\N	PRESENT	0
315872	313439	14195A	PARTICIPANT	\N	PRESENT	0
315873	313439	19367Y	PARTICIPANT	\N	PRESENT	0
315874	313439	14213J	PARTICIPANT	\N	PRESENT	0
315875	313439	14217N	PARTICIPANT	\N	PRESENT	0
315876	313439	19335Q	PARTICIPANT	\N	PRESENT	0
315877	313439	14261S	PARTICIPANT	\N	PRESENT	0
315878	313439	10006L	PARTICIPANT	\N	PRESENT	0
315879	313439	19683J	PARTICIPANT	\N	PRESENT	0
315880	313439	98024R	PARTICIPANT	\N	PRESENT	0
303729	302442	14329V	PARTICIPANT	\N	PRESENT	0
303730	302442	11048N	PARTICIPANT	\N	PRESENT	0
303731	302442	04038G	PARTICIPANT	\N	PRESENT	0
303732	302442	14237S	PARTICIPANT	\N	PRESENT	0
303733	302442	14111D	PARTICIPANT	\N	PRESENT	0
303734	302442	11026G	PARTICIPANT	\N	PRESENT	0
303735	301908	19593H	PARTICIPANT	\N	PRESENT	0
303736	301908	04070G	PRESIDENT	0	PRESENT	0
303737	301908	19643A	PARTICIPANT	\N	PRESENT	0
303738	301908	19699S	PARTICIPANT	\N	PRESENT	0
303739	301908	14073Q	PARTICIPANT	\N	PRESENT	0
303740	301908	19533U	PARTICIPANT	\N	PRESENT	0
303741	301908	95015C	PARTICIPANT	\N	PRESENT	0
303742	301908	04033B	PARTICIPANT	\N	PRESENT	0
303743	301908	87003B	PARTICIPANT	\N	PRESENT	0
303744	301908	14030Q	PARTICIPANT	\N	PRESENT	0
303745	301908	19731Y	PARTICIPANT	\N	PRESENT	0
303746	301908	19573D	PARTICIPANT	\N	PRESENT	0
303747	301908	14251Q	PARTICIPANT	\N	PRESENT	0
303748	301908	04059M	PARTICIPANT	\N	PRESENT	0
303749	301908	08017T	PARTICIPANT	\N	PRESENT	0
303750	301908	92040Q	PARTICIPANT	\N	PRESENT	0
303751	301908	11083R	PARTICIPANT	\N	PRESENT	0
303788	301909	04057K	PARTICIPANT	\N	EXCUSE	0
303753	301908	19749K	PARTICIPANT	\N	PRESENT	0
303754	301908	04018C	PARTICIPANT	\N	PRESENT	0
303755	301908	08039A	PARTICIPANT	\N	PRESENT	0
303756	301908	08031R	PARTICIPANT	\N	PRESENT	0
303757	301908	19621T	PARTICIPANT	\N	PRESENT	0
303758	301908	08043V	PARTICIPANT	\N	PRESENT	0
303759	301908	19611R	PARTICIPANT	\N	EXCUSE	0
303760	301908	14107H	PARTICIPANT	\N	EXCUSE	0
303761	301908	19735D	PARTICIPANT	\N	PRESENT	0
303762	301909	19593H	PARTICIPANT	\N	PRESENT	0
303763	301909	04070G	PRESIDENT	0	PRESENT	0
303764	301909	19643A	PARTICIPANT	\N	PRESENT	0
303765	301909	19699S	PARTICIPANT	\N	PRESENT	0
303766	301909	14073Q	PARTICIPANT	\N	PRESENT	0
303767	301909	19533U	PARTICIPANT	\N	PRESENT	0
303768	301909	95015C	PARTICIPANT	\N	PRESENT	0
303769	301909	04033B	PARTICIPANT	\N	PRESENT	0
303770	301909	08043V	PARTICIPANT	\N	PRESENT	0
303771	301909	87003B	PARTICIPANT	\N	PRESENT	0
303772	301909	14030Q	PARTICIPANT	\N	PRESENT	0
303773	301909	19731Y	PARTICIPANT	\N	PRESENT	0
303774	301909	19573D	PARTICIPANT	\N	PRESENT	0
303775	301909	14251Q	PARTICIPANT	\N	PRESENT	0
303776	301909	04059M	PARTICIPANT	\N	PRESENT	0
303777	301909	19735D	PARTICIPANT	\N	PRESENT	0
303778	301909	08017T	PARTICIPANT	\N	PRESENT	0
303779	301909	92040Q	PARTICIPANT	\N	PRESENT	0
303780	301909	11083R	PARTICIPANT	\N	PRESENT	0
303781	301909	19749K	PARTICIPANT	\N	PRESENT	0
303782	301909	04018C	PARTICIPANT	\N	PRESENT	0
303783	301909	08039A	PARTICIPANT	\N	PRESENT	0
303784	301909	08031R	PARTICIPANT	\N	PRESENT	0
303785	301909	19621T	PARTICIPANT	\N	PRESENT	0
303786	301909	19611R	PARTICIPANT	\N	EXCUSE	0
303787	301909	14107H	PARTICIPANT	\N	EXCUSE	0
303789	301909	19693L	PARTICIPANT	\N	EXCUSE	0
303790	301909	19399H	PARTICIPANT	\N	EXCUSE	0
303791	301909	19758L	PARTICIPANT	\N	EXCUSE	0
303792	301909	14229S	PARTICIPANT	\N	PRESENT	0
303793	301909	11043H	PARTICIPANT	\N	PRESENT	0
303794	301909	11104D	PARTICIPANT	\N	PRESENT	0
303795	301909	14061L	PARTICIPANT	\N	PRESENT	0
303796	301909	14123H	PARTICIPANT	\N	PRESENT	0
303797	301909	14241N	PARTICIPANT	\N	PRESENT	0
303798	301628	04086Q	PARTICIPANT	\N	PRESENT	0
303799	301628	14073Q	PARTICIPANT	\N	PRESENT	0
303800	301628	01057W	PARTICIPANT	\N	PRESENT	0
303801	301628	11074Q	PRESIDENT	0	PRESENT	0
303802	301628	19667J	PARTICIPANT	\N	PRESENT	0
303803	301628	11070L	PARTICIPANT	\N	PRESENT	0
303804	301628	14225N	PARTICIPANT	\N	PRESENT	0
303805	301628	14173T	PARTICIPANT	\N	PRESENT	0
303806	301628	07029T	PARTICIPANT	\N	EXCUSE	0
303807	301628	14331P	PARTICIPANT	\N	EXCUSE	0
303808	301628	07004J	PARTICIPANT	\N	EXCUSE	0
303809	301628	08014Q	PARTICIPANT	\N	EXCUSE	0
303810	301628	19647E	PARTICIPANT	\N	PRESENT	0
303811	301628	19479G	PARTICIPANT	\N	PRESENT	0
303812	301628	19531S	PARTICIPANT	\N	PRESENT	0
303813	301628	08034U	PARTICIPANT	\N	PRESENT	0
303814	301628	11053K	PARTICIPANT	\N	PRESENT	0
303815	301628	89017R	PARTICIPANT	\N	PRESENT	0
303816	301628	08011M	PARTICIPANT	\N	PRESENT	0
303817	301628	14159V	PARTICIPANT	\N	PRESENT	0
303818	301628	14083S	PARTICIPANT	\N	PRESENT	0
303819	301628	11012A	PARTICIPANT	\N	PRESENT	0
303820	301628	14121F	PARTICIPANT	\N	PRESENT	0
303821	301628	99004R	PARTICIPANT	\N	PRESENT	0
303822	301628	19689Q	PARTICIPANT	\N	PRESENT	0
303823	301628	14085U	PARTICIPANT	\N	PRESENT	0
303824	301628	11048N	PARTICIPANT	\N	PRESENT	0
303984	302704	14123H	PARTICIPANT	\N	PRESENT	0
303985	302704	19749K	PARTICIPANT	\N	PRESENT	0
303986	302704	11065P	PARTICIPANT	\N	PRESENT	0
303987	302704	14030Q	PARTICIPANT	\N	PRESENT	0
303988	302704	16685X	PARTICIPANT	\N	PRESENT	0
304003	302704	14061L	PARTICIPANT	\N	PRESENT	0
304005	302704	08039A	PARTICIPANT	\N	PRESENT	0
304006	302704	19421M	PARTICIPANT	\N	PRESENT	0
304010	302704	19289C	PARTICIPANT	\N	PRESENT	0
304011	302704	14265W	PARTICIPANT	\N	PRESENT	0
304012	302704	14147R	PARTICIPANT	\N	PRESENT	0
304013	302704	95015C	PARTICIPANT	\N	PRESENT	0
304014	302704	14179A	PARTICIPANT	\N	PRESENT	0
304015	302704	14157T	PARTICIPANT	\N	PRESENT	0
304020	302704	95030B	PARTICIPANT	\N	PRESENT	0
304021	302704	14069U	PARTICIPANT	\N	PRESENT	0
304022	302704	19531S	PARTICIPANT	\N	PRESENT	0
304023	302704	19575F	PARTICIPANT	\N	PRESENT	0
304024	302704	04033B	PARTICIPANT	\N	PRESENT	0
304025	302704	14329V	PARTICIPANT	\N	PRESENT	0
304026	302704	11097X	PARTICIPANT	\N	PRESENT	0
304027	302704	19413M	PARTICIPANT	\N	PRESENT	0
304028	302704	08031R	PARTICIPANT	\N	PRESENT	0
304029	302704	19521Q	PARTICIPANT	\N	PRESENT	0
304030	302704	19669L	PARTICIPANT	\N	PRESENT	0
304031	302704	08061X	PARTICIPANT	\N	PRESENT	0
304032	302704	14111D	PARTICIPANT	\N	PRESENT	0
304033	302704	14034U	PARTICIPANT	\N	PRESENT	0
304034	302704	11085T	PARTICIPANT	\N	PRESENT	0
304035	302704	19591F	PARTICIPANT	\N	PRESENT	0
304074	302704	08034U	PARTICIPANT	\N	PRESENT	0
304075	302704	14053L	PARTICIPANT	\N	PRESENT	0
304076	302704	19479G	PARTICIPANT	\N	PRESENT	0
304077	302704	19533U	PARTICIPANT	\N	PRESENT	0
304078	302704	19719D	PARTICIPANT	\N	PRESENT	0
314413	314412	19693L	PARTICIPANT	\N	PRESENT	0
314415	314414	19693L	PARTICIPANT	\N	PRESENT	0
316873	316864	95037J	PARTICIPANT	\N	PRESENT	0
316877	316864	14061L	PARTICIPANT	\N	PRESENT	0
316878	316864	08015R	PARTICIPANT	\N	PRESENT	0
316879	316864	14059S	PARTICIPANT	\N	PRESENT	0
316880	316864	08053X	PARTICIPANT	\N	PRESENT	0
316881	316864	19369B	PARTICIPANT	\N	PRESENT	0
316882	316864	14109K	PARTICIPANT	\N	PRESENT	0
316883	316864	14265W	PARTICIPANT	\N	PRESENT	0
316884	316864	14107H	PARTICIPANT	\N	PRESENT	0
316885	316864	11097X	PARTICIPANT	\N	PRESENT	0
316886	316864	14213J	PARTICIPANT	\N	PRESENT	0
316899	316888	19631V	PARTICIPANT	\N	PRESENT	0
316901	316888	19747H	PARTICIPANT	\N	PRESENT	0
316902	316888	14197C	PARTICIPANT	\N	PRESENT	0
316904	316888	14265W	PARTICIPANT	\N	PRESENT	0
316905	316888	19413M	PARTICIPANT	\N	PRESENT	0
316907	316888	14033T	PARTICIPANT	\N	PRESENT	0
316915	316914	08020N	PARTICIPANT	\N	PRESENT	0
316916	316914	19467C	PARTICIPANT	\N	PRESENT	0
316917	316914	14281W	PARTICIPANT	\N	PRESENT	0
316918	316914	19727D	PARTICIPANT	\N	PRESENT	0
316919	316914	14033T	PARTICIPANT	\N	PRESENT	0
316920	316914	14265W	PARTICIPANT	\N	PRESENT	0
317145	316914	19735D	PARTICIPANT	\N	PRESENT	0
317178	316914	14135M	PARTICIPANT	\N	PRESENT	0
317179	316914	19511N	PARTICIPANT	\N	PRESENT	0
317180	316914	19441R	PARTICIPANT	\N	PRESENT	0
317211	316888	14109K	PARTICIPANT	\N	PRESENT	0
317219	316888	19383Y	PARTICIPANT	\N	PRESENT	0
317221	305897	19421M	PARTICIPANT	\N	PRESENT	0
317230	317223	19415P	PARTICIPANT	\N	PRESENT	0
317234	317223	14217N	PARTICIPANT	\N	PRESENT	0
317242	316888	19575F	PARTICIPANT	\N	PRESENT	0
317243	317241	19415P	PARTICIPANT	\N	PRESENT	0
317244	317241	14217N	PARTICIPANT	\N	PRESENT	0
317245	317241	14223L	PARTICIPANT	\N	PRESENT	0
317253	317252	08049C	PARTICIPANT	\N	PRESENT	0
317254	317252	04035D	PARTICIPANT	\N	PRESENT	0
317257	317256	08049C	PARTICIPANT	\N	PRESENT	0
317258	317256	04035D	PARTICIPANT	\N	PRESENT	0
317260	317259	04042C	PARTICIPANT	\N	PRESENT	0
317261	317259	14193X	PARTICIPANT	\N	PRESENT	0
317263	317259	95067Q	PARTICIPANT	\N	PRESENT	0
317264	317259	11066Q	PARTICIPANT	\N	PRESENT	0
317269	317268	14255U	PARTICIPANT	\N	PRESENT	0
317290	317289	04040A	PARTICIPANT	\N	PRESENT	0
317291	317289	14235Q	PARTICIPANT	\N	PRESENT	0
317293	317292	04040A	PARTICIPANT	\N	PRESENT	0
317384	317383	14111D	PARTICIPANT	\N	PRESENT	0
317514	317513	08012N	PARTICIPANT	\N	PRESENT	0
317527	317526	14123H	PARTICIPANT	\N	PRESENT	0
317529	317528	14123H	PARTICIPANT	\N	PRESENT	0
317531	317530	08031R	PARTICIPANT	\N	PRESENT	0
317533	317532	14123H	PARTICIPANT	\N	PRESENT	0
317540	317539	08055A	PARTICIPANT	\N	PRESENT	0
317541	317539	08043V	PARTICIPANT	\N	PRESENT	0
317542	317539	14105F	PARTICIPANT	\N	PRESENT	0
317543	317539	14085U	PARTICIPANT	\N	PRESENT	0
317544	317539	14195A	PARTICIPANT	\N	PRESENT	0
317545	317539	95037J	PARTICIPANT	\N	PRESENT	0
317546	317539	14213J	PARTICIPANT	\N	PRESENT	0
317547	317539	14061L	PARTICIPANT	\N	PRESENT	0
317548	317539	08015R	PARTICIPANT	\N	PRESENT	0
317549	317539	14059S	PARTICIPANT	\N	PRESENT	0
317550	317539	08053X	PARTICIPANT	\N	PRESENT	0
317551	317539	19369B	PARTICIPANT	\N	PRESENT	0
317552	317539	14109K	PARTICIPANT	\N	PRESENT	0
317553	317539	14265W	PARTICIPANT	\N	PRESENT	0
317554	317539	14107H	PARTICIPANT	\N	PRESENT	0
317555	317539	11097X	PARTICIPANT	\N	PRESENT	0
317556	317539	14207L	PARTICIPANT	\N	PRESENT	0
317583	316891	04061F	PARTICIPANT	\N	PRESENT	0
317584	316891	04057K	PARTICIPANT	\N	PRESENT	0
317585	316891	08031R	PARTICIPANT	\N	EXCUSE	0
317586	316891	19251M	PARTICIPANT	\N	PRESENT	0
317587	316891	98022P	PARTICIPANT	\N	PRESENT	0
317588	316891	01062T	PARTICIPANT	\N	PRESENT	0
317773	317770	14111D	PARTICIPANT	\N	PRESENT	0
317771	317770	01024M	PARTICIPANT	\N	PRESENT	0
317922	309290	98005N	PARTICIPANT	\N	PRESENT	0
317923	309290	01062T	PARTICIPANT	\N	PRESENT	0
317924	309290	14051J	PARTICIPANT	\N	PRESENT	0
317925	309290	86034E	PARTICIPANT	\N	PRESENT	0
317926	309290	05012A	PARTICIPANT	\N	PRESENT	0
317927	309290	14109K	PARTICIPANT	\N	PRESENT	0
317597	316891	19421M	PARTICIPANT	\N	PRESENT	0
317928	309290	08034U	PARTICIPANT	\N	PRESENT	0
317929	309290	19533U	PARTICIPANT	\N	PRESENT	0
317930	309290	19333N	PARTICIPANT	\N	PRESENT	0
317938	309290	14249W	PARTICIPANT	\N	PRESENT	0
317932	309290	14001X	PARTICIPANT	\N	PRESENT	0
317933	309290	19631V	PARTICIPANT	\N	PRESENT	0
317934	309290	04033B	PARTICIPANT	\N	PRESENT	0
317935	309290	19549D	PARTICIPANT	\N	PRESENT	0
317936	309290	14207L	PARTICIPANT	\N	PRESENT	0
317937	309290	17583W	PARTICIPANT	\N	PRESENT	0
317939	309290	14087W	PARTICIPANT	\N	PRESENT	0
317940	309290	14215L	PARTICIPANT	\N	PRESENT	0
317941	309290	08052W	PARTICIPANT	\N	PRESENT	0
317942	309290	14187A	PARTICIPANT	\N	PRESENT	0
317943	309290	01028R	PARTICIPANT	\N	PRESENT	0
317944	309290	14159V	PARTICIPANT	\N	PRESENT	0
317945	309290	14071N	PARTICIPANT	\N	PRESENT	0
317946	309290	11110B	PARTICIPANT	\N	PRESENT	0
317947	309290	05008E	PARTICIPANT	\N	PRESENT	0
317948	309290	14257W	PARTICIPANT	\N	PRESENT	0
317949	309290	19525U	PARTICIPANT	\N	PRESENT	0
317951	309290	08053X	PARTICIPANT	\N	PRESENT	0
317952	309290	14085U	PARTICIPANT	\N	PRESENT	0
317953	309290	14121F	PARTICIPANT	\N	PRESENT	0
317772	317770	08044W	PARTICIPANT	\N	PRESENT	0
317954	309290	19531S	PARTICIPANT	\N	PRESENT	0
317955	309290	04092N	PARTICIPANT	\N	PRESENT	0
317956	309290	08058D	PARTICIPANT	\N	PRESENT	0
317957	309290	11054L	PARTICIPANT	\N	PRESENT	0
317958	309290	98018T	PARTICIPANT	\N	PRESENT	0
317959	309290	08043V	PARTICIPANT	\N	PRESENT	0
317960	309290	04044E	PARTICIPANT	\N	PRESENT	0
317961	309290	19727D	PARTICIPANT	\N	PRESENT	0
317962	309290	14191V	PARTICIPANT	\N	PRESENT	0
317963	309290	11074Q	PARTICIPANT	\N	PRESENT	0
317964	309290	08060W	PARTICIPANT	\N	PRESENT	0
317965	309290	19347U	PARTICIPANT	\N	PRESENT	0
317966	309290	14281W	PARTICIPANT	\N	PRESENT	0
317967	309290	04047H	PARTICIPANT	\N	PRESENT	0
317968	309290	11104D	PARTICIPANT	\N	PRESENT	0
317969	309290	08012N	PARTICIPANT	\N	PRESENT	0
317970	309290	14026U	PARTICIPANT	\N	PRESENT	0
317971	309290	04035D	PARTICIPANT	\N	PRESENT	0
317972	309290	19647E	PARTICIPANT	\N	PRESENT	0
317973	309290	19709B	PARTICIPANT	\N	PRESENT	0
317974	309290	19663E	PARTICIPANT	\N	PRESENT	0
317975	309290	08035V	PARTICIPANT	\N	PRESENT	0
317976	309290	89017R	PARTICIPANT	\N	PRESENT	0
317977	309290	19725B	PARTICIPANT	\N	PRESENT	0
317978	309290	19681G	PARTICIPANT	\N	PRESENT	0
317979	309290	14063N	PARTICIPANT	\N	PRESENT	0
317980	309290	14225N	PARTICIPANT	\N	PRESENT	0
317981	309290	08020N	PARTICIPANT	\N	PRESENT	0
317982	309290	19599P	PARTICIPANT	\N	PRESENT	0
317983	309290	14030Q	PARTICIPANT	\N	PRESENT	0
317984	309290	16685X	PARTICIPANT	\N	PRESENT	0
317985	309290	19441R	PARTICIPANT	\N	PRESENT	0
317986	309290	14219Q	PARTICIPANT	\N	PRESENT	0
317987	309290	14042U	PARTICIPANT	\N	PRESENT	0
317988	309290	19699S	PARTICIPANT	\N	PRESENT	0
317989	309290	19479G	PARTICIPANT	\N	PRESENT	0
317990	309290	19737F	PARTICIPANT	\N	PRESENT	0
317991	309290	19735D	PARTICIPANT	\N	PRESENT	0
317992	309290	08056B	PARTICIPANT	\N	PRESENT	0
317993	309290	11085T	PARTICIPANT	\N	PRESENT	0
317994	309290	14221J	PARTICIPANT	\N	PRESENT	0
317995	309290	19611R	PARTICIPANT	\N	PRESENT	0
317996	309290	14205J	PARTICIPANT	\N	PRESENT	0
317997	309290	14073Q	PARTICIPANT	\N	PRESENT	0
317998	309290	19619A	PARTICIPANT	\N	PRESENT	0
317999	309290	04061F	PARTICIPANT	\N	PRESENT	0
318000	309290	19739H	PARTICIPANT	\N	PRESENT	0
318001	309290	19745F	PARTICIPANT	\N	PRESENT	0
318002	309290	19749K	PARTICIPANT	\N	PRESENT	0
318003	309290	11053K	PARTICIPANT	\N	PRESENT	0
318004	309290	10006L	PARTICIPANT	\N	PRESENT	0
318005	309290	19723Y	PARTICIPANT	\N	PRESENT	0
318006	309290	19521Q	PARTICIPANT	\N	PRESENT	0
317181	309289	11070L	PARTICIPANT	\N	PRESENT	0
317182	309289	11031D	PARTICIPANT	\N	PRESENT	0
317183	309289	19695N	PARTICIPANT	\N	PRESENT	0
317184	309289	19593H	PARTICIPANT	\N	PRESENT	0
317185	309289	19295A	PARTICIPANT	\N	PRESENT	0
317186	309289	11109J	PARTICIPANT	\N	PRESENT	0
317187	309289	14227Q	PARTICIPANT	\N	PRESENT	0
317188	309289	19715Y	PARTICIPANT	\N	PRESENT	0
317189	309289	04092N	PARTICIPANT	\N	PRESENT	0
317190	309289	19569H	PARTICIPANT	\N	PRESENT	0
317191	309289	04045F	PARTICIPANT	\N	PRESENT	0
317192	309289	19760E	PARTICIPANT	\N	PRESENT	0
317193	309289	14261S	PARTICIPANT	\N	PRESENT	0
317194	309289	14042U	PARTICIPANT	\N	PRESENT	0
317195	309289	14219Q	PARTICIPANT	\N	PRESENT	0
317196	309289	19441R	PARTICIPANT	\N	PRESENT	0
317197	309289	19479G	PARTICIPANT	\N	PRESENT	0
317198	309289	19727D	PARTICIPANT	\N	PRESENT	0
317199	309289	17589D	PARTICIPANT	\N	PRESENT	0
317200	309289	04057K	PARTICIPANT	\N	PRESENT	0
317201	309289	14327T	PARTICIPANT	\N	PRESENT	0
317202	309289	14255U	PARTICIPANT	\N	PRESENT	0
317203	309289	19577H	PARTICIPANT	\N	PRESENT	0
317205	309289	14089Y	PARTICIPANT	\N	PRESENT	0
317206	309289	19739H	PARTICIPANT	\N	PRESENT	0
317207	309289	19367Y	PARTICIPANT	\N	PRESENT	0
317208	309289	04018C	PARTICIPANT	\N	PRESENT	0
317209	309289	19693L	PARTICIPANT	\N	PRESENT	0
317210	309289	19399H	PARTICIPANT	\N	PRESENT	0
317212	309289	14119M	PARTICIPANT	\N	PRESENT	0
317213	309289	98005N	PARTICIPANT	\N	PRESENT	0
317214	309289	19711U	PARTICIPANT	\N	PRESENT	0
317215	309289	08020N	PARTICIPANT	\N	PRESENT	0
317216	309289	14071N	PARTICIPANT	\N	PRESENT	0
317217	309289	19643A	PARTICIPANT	\N	PRESENT	0
317218	309289	14197C	PARTICIPANT	\N	PRESENT	0
317225	309289	14073Q	PARTICIPANT	\N	PRESENT	0
317228	309289	19631V	PARTICIPANT	\N	PRESENT	0
317236	309289	08010L	PARTICIPANT	\N	PRESENT	0
317237	309289	19691J	PARTICIPANT	\N	PRESENT	0
317238	309289	14033T	PARTICIPANT	\N	PRESENT	0
317239	309289	19335Q	PARTICIPANT	\N	PRESENT	0
317240	309289	19657G	PARTICIPANT	\N	PRESENT	0
317246	309289	04088S	PARTICIPANT	\N	PRESENT	0
317247	309289	14030Q	PARTICIPANT	\N	PRESENT	0
317248	309289	19735D	PARTICIPANT	\N	PRESENT	0
317249	309289	19667J	PARTICIPANT	\N	PRESENT	0
317255	309289	19421M	PARTICIPANT	\N	PRESENT	0
317270	309289	08015R	PARTICIPANT	\N	PRESENT	0
317271	309289	19758L	PARTICIPANT	\N	PRESENT	0
317288	309289	11085T	PARTICIPANT	\N	PRESENT	0
317294	309289	04085P	PARTICIPANT	\N	PRESENT	0
317295	309289	08019V	PARTICIPANT	\N	PRESENT	0
317298	309289	19713W	PARTICIPANT	\N	PRESENT	0
317309	309289	14083S	PARTICIPANT	\N	PRESENT	0
317310	309289	11012A	PARTICIPANT	\N	PRESENT	0
317311	309289	19629C	PARTICIPANT	\N	PRESENT	0
317326	309289	11053K	PARTICIPANT	\N	PRESENT	0
317327	309289	19253P	PARTICIPANT	\N	PRESENT	0
317328	309289	14281W	PARTICIPANT	\N	PRESENT	0
317329	309289	14039A	PARTICIPANT	\N	PRESENT	0
317342	309289	14231L	PARTICIPANT	\N	PRESENT	0
317387	310074	07029T	PARTICIPANT	\N	PRESENT	0
317388	310074	98005N	PARTICIPANT	\N	PRESENT	0
317389	310074	19573D	PARTICIPANT	\N	PRESENT	0
317390	310074	08019V	PARTICIPANT	\N	PRESENT	0
317391	310074	19399H	PARTICIPANT	\N	PRESENT	0
317392	310074	19693L	PARTICIPANT	\N	PRESENT	0
317393	310074	14357A	PARTICIPANT	\N	PRESENT	0
317394	310074	19711U	PARTICIPANT	\N	PRESENT	0
317395	310074	19691J	PARTICIPANT	\N	PRESENT	0
317396	310074	19577H	PARTICIPANT	\N	PRESENT	0
317397	310074	14083S	PARTICIPANT	\N	PRESENT	0
317398	310074	14231L	PARTICIPANT	\N	PRESENT	0
317399	310074	11053K	PARTICIPANT	\N	PRESENT	0
317400	310074	19713W	PARTICIPANT	\N	PRESENT	0
317401	310074	14042U	PARTICIPANT	\N	PRESENT	0
317402	310074	04070G	PARTICIPANT	\N	PRESENT	0
317403	310074	14281W	PARTICIPANT	\N	PRESENT	0
317404	310074	19715Y	PARTICIPANT	\N	PRESENT	0
317405	310074	04057K	PARTICIPANT	\N	PRESENT	0
317406	310074	14261S	PARTICIPANT	\N	PRESENT	0
317407	310074	11031D	PARTICIPANT	\N	PRESENT	0
317408	310074	19695N	PARTICIPANT	\N	PRESENT	0
317409	310074	14030Q	PARTICIPANT	\N	PRESENT	0
317410	310074	19569H	PARTICIPANT	\N	PRESENT	0
317412	317411	14085U	PARTICIPANT	\N	PRESENT	0
317413	317411	14253S	PARTICIPANT	\N	PRESENT	0
317415	317414	14085U	PARTICIPANT	\N	PRESENT	0
317416	317414	14253S	PARTICIPANT	\N	PRESENT	0
317427	317426	14085U	PARTICIPANT	\N	PRESENT	0
317428	317426	14253S	PARTICIPANT	\N	PRESENT	0
317431	317430	08011M	PARTICIPANT	\N	PRESENT	0
317434	317433	08011M	PARTICIPANT	\N	PRESENT	0
317436	317435	11074Q	PARTICIPANT	\N	PRESENT	0
317437	317435	08011M	PARTICIPANT	\N	PRESENT	0
317438	317435	11040E	PARTICIPANT	\N	PRESENT	0
317439	317435	04071H	PARTICIPANT	\N	PRESENT	0
317440	317435	19689Q	PARTICIPANT	\N	PRESENT	0
317442	317441	08011M	PARTICIPANT	\N	PRESENT	0
317444	317443	11041F	PARTICIPANT	\N	PRESENT	0
317445	317443	98018T	PARTICIPANT	\N	PRESENT	0
317385	310074	11070L	PARTICIPANT	\N	PRESENT	0
317386	310074	19758L	PARTICIPANT	\N	PRESENT	0
317447	317446	98018T	PARTICIPANT	\N	PRESENT	0
317449	317448	11054L	PARTICIPANT	\N	PRESENT	0
317450	317448	11064N	PARTICIPANT	\N	PRESENT	0
317639	317638	11026G	PARTICIPANT	\N	PRESENT	0
317665	317664	14207L	PARTICIPANT	\N	PRESENT	0
317666	317664	19507S	PARTICIPANT	\N	PRESENT	0
317667	317664	01025N	PARTICIPANT	\N	PRESENT	0
317679	317677	14207L	PARTICIPANT	\N	PRESENT	0
317681	317677	19507S	PARTICIPANT	\N	PRESENT	0
317682	317677	01025N	PARTICIPANT	\N	PRESENT	0
317757	317756	08028W	PARTICIPANT	\N	PRESENT	0
317761	317760	18083K	PARTICIPANT	\N	PRESENT	0
317762	317758	18083K	PARTICIPANT	\N	PRESENT	0
317763	317759	18083K	PARTICIPANT	\N	PRESENT	0
319215	319214	14229S	PARTICIPANT	\N	PRESENT	0
319216	319214	19735D	PARTICIPANT	\N	PRESENT	0
319218	319217	14229S	PARTICIPANT	\N	PRESENT	0
319219	319217	19735D	PARTICIPANT	\N	PRESENT	0
319221	319220	14229S	PARTICIPANT	\N	PRESENT	0
319222	319220	19735D	PARTICIPANT	\N	PRESENT	0
319226	319224	92040Q	PARTICIPANT	\N	PRESENT	0
319227	319224	14109K	PARTICIPANT	\N	PRESENT	0
319228	319224	19749K	PARTICIPANT	\N	PRESENT	0
319229	319224	19735D	PARTICIPANT	\N	PRESENT	0
319236	319235	19693L	PARTICIPANT	\N	PRESENT	0
319237	319235	19593H	PARTICIPANT	\N	PRESENT	0
319239	319238	19693L	PARTICIPANT	\N	PRESENT	0
319241	319240	19693L	PARTICIPANT	\N	PRESENT	0
319243	319242	19693L	PARTICIPANT	\N	PRESENT	0
319244	319242	14030Q	PARTICIPANT	\N	PRESENT	0
319246	319245	19693L	PARTICIPANT	\N	PRESENT	0
319248	319247	08039A	PARTICIPANT	\N	PRESENT	0
319249	319247	19399H	PARTICIPANT	\N	PRESENT	0
319251	319250	08039A	PARTICIPANT	\N	PRESENT	0
319252	319250	19399H	PARTICIPANT	\N	PRESENT	0
319755	314090	08031R	PARTICIPANT	\N	PRESENT	0
319756	314090	19253P	PARTICIPANT	\N	PRESENT	0
319757	314090	08043V	PARTICIPANT	\N	PRESENT	0
319758	314090	19421M	PARTICIPANT	\N	PRESENT	0
319759	314090	04061F	PARTICIPANT	\N	PRESENT	0
319760	314090	14053L	PARTICIPANT	\N	PRESENT	0
319761	314090	14331P	PARTICIPANT	\N	PRESENT	0
319762	314090	19731Y	PARTICIPANT	\N	PRESENT	0
319764	314090	14059S	PARTICIPANT	\N	PRESENT	0
319765	314090	14265W	PARTICIPANT	\N	PRESENT	0
319766	314090	14105F	PARTICIPANT	\N	PRESENT	0
319768	314090	11049P	PARTICIPANT	\N	PRESENT	0
319769	314090	11103C	PARTICIPANT	\N	PRESENT	0
319770	314090	01057W	PARTICIPANT	\N	PRESENT	0
319771	314090	14191V	PARTICIPANT	\N	PRESENT	0
319772	314090	19679N	PARTICIPANT	\N	PRESENT	0
319773	314090	19703U	PARTICIPANT	\N	PRESENT	0
319774	314090	18083K	PARTICIPANT	\N	PRESENT	0
319775	314090	14169X	PARTICIPANT	\N	PRESENT	0
319776	314090	14135M	PARTICIPANT	\N	PRESENT	0
319777	314090	14033T	PARTICIPANT	\N	PRESENT	0
319778	314090	14133K	PARTICIPANT	\N	PRESENT	0
319779	314090	19507S	PARTICIPANT	\N	PRESENT	0
319780	314090	04088S	PARTICIPANT	\N	PRESENT	0
319781	314090	14255U	PARTICIPANT	\N	PRESENT	0
319782	314090	14231L	PARTICIPANT	\N	PRESENT	0
319783	314090	01025N	PARTICIPANT	\N	PRESENT	0
319785	314090	19669L	PARTICIPANT	\N	PRESENT	0
319786	314090	19631V	PARTICIPANT	\N	PRESENT	0
315881	313439	19521Q	PARTICIPANT	\N	PRESENT	0
315882	313439	19527W	PARTICIPANT	\N	PRESENT	0
315883	313439	01034P	PARTICIPANT	\N	PRESENT	0
315884	313439	04092N	PRESIDENT	0	PRESENT	0
315885	313439	11045K	PARTICIPANT	\N	PRESENT	0
315886	313439	08052W	PARTICIPANT	\N	PRESENT	0
315887	313439	19663E	PARTICIPANT	\N	PRESENT	0
315888	313439	19715Y	PARTICIPANT	\N	PRESENT	0
315889	313439	19691J	PARTICIPANT	\N	PRESENT	0
315890	313439	19723Y	PARTICIPANT	\N	PRESENT	0
315891	313439	19727D	PARTICIPANT	\N	PRESENT	0
315892	313439	14119M	PARTICIPANT	\N	PRESENT	0
315893	313439	11103C	PARTICIPANT	\N	PRESENT	0
315894	313439	19657G	PARTICIPANT	\N	PRESENT	0
315895	313439	19577H	PARTICIPANT	\N	PRESENT	0
315896	313439	19760E	PARTICIPANT	\N	PRESENT	0
315897	313439	19697Q	PARTICIPANT	\N	EXCUSE	0
315898	313439	14087W	PARTICIPANT	\N	EXCUSE	0
315899	313439	08041T	PARTICIPANT	\N	EXCUSE	0
315900	315530	19766L	PARTICIPANT	\N	PRESENT	0
315901	315530	04070G	PARTICIPANT	\N	PRESENT	0
315902	315530	19699S	PARTICIPANT	\N	PRESENT	0
315903	315530	19533U	PARTICIPANT	\N	PRESENT	0
315904	315530	19329S	PARTICIPANT	\N	PRESENT	0
315905	315530	14229S	PARTICIPANT	\N	PRESENT	0
315906	315530	14241N	PARTICIPANT	\N	PRESENT	0
315907	315530	19573D	PARTICIPANT	\N	PRESENT	0
315908	315530	14039A	PARTICIPANT	\N	PRESENT	0
315909	315530	14107H	PARTICIPANT	\N	PRESENT	0
315910	315530	92040Q	PARTICIPANT	\N	PRESENT	0
315911	315530	08012N	PARTICIPANT	\N	PRESENT	0
315912	315530	14249W	PARTICIPANT	\N	PRESENT	0
315913	315530	08039A	PARTICIPANT	\N	PRESENT	0
315914	315530	08031R	PARTICIPANT	\N	PRESENT	0
315915	315530	19593H	PARTICIPANT	\N	PRESENT	0
315916	315530	19643A	PARTICIPANT	\N	PRESENT	0
315917	315530	14059S	PARTICIPANT	\N	PRESENT	0
315918	315530	14061L	PARTICIPANT	\N	PRESENT	0
315919	315530	04057K	PARTICIPANT	\N	PRESENT	0
315920	315530	14073Q	PARTICIPANT	\N	PRESENT	0
315921	315530	19611R	PARTICIPANT	\N	PRESENT	0
315922	315530	08043V	PARTICIPANT	\N	PRESENT	0
315923	315530	19693L	PARTICIPANT	\N	PRESENT	0
315924	315530	19399H	PARTICIPANT	\N	PRESENT	0
315925	315530	87003B	PARTICIPANT	\N	PRESENT	0
315926	315530	14030Q	PARTICIPANT	\N	PRESENT	0
315927	315530	19731Y	PARTICIPANT	\N	PRESENT	0
315928	315530	08020N	PARTICIPANT	\N	PRESENT	0
315929	315530	14251Q	PARTICIPANT	\N	PRESENT	0
315930	315530	04059M	PARTICIPANT	\N	PRESENT	0
315931	315530	19735D	PARTICIPANT	\N	PRESENT	0
315932	315530	11109J	PARTICIPANT	\N	PRESENT	0
315933	315530	11083R	PARTICIPANT	\N	PRESENT	0
315934	315530	14063N	PARTICIPANT	\N	PRESENT	0
315935	315530	14109K	PARTICIPANT	\N	PRESENT	0
315936	315530	14123H	PRESIDENT	0	PRESENT	0
315937	315530	19749K	PARTICIPANT	\N	PRESENT	0
315938	315530	04018C	PARTICIPANT	\N	PRESENT	0
315939	315530	19758L	PARTICIPANT	\N	PRESENT	0
315951	309282	01043Q	PARTICIPANT	\N	PRESENT	0
315958	309282	11031D	PARTICIPANT	\N	PRESENT	0
315959	309282	19727D	PARTICIPANT	\N	PRESENT	0
315960	309282	19565D	PARTICIPANT	\N	PRESENT	0
315961	309282	01060R	PARTICIPANT	\N	PRESENT	0
315962	309282	19731Y	PARTICIPANT	\N	PRESENT	0
315963	309282	19673G	PARTICIPANT	\N	PRESENT	0
315964	309282	19760E	PARTICIPANT	\N	PRESENT	0
315965	309282	19367Y	PARTICIPANT	\N	PRESENT	0
315966	309282	14105F	PARTICIPANT	\N	PRESENT	0
315967	309282	14239U	PARTICIPANT	\N	PRESENT	0
315968	309282	19703U	PARTICIPANT	\N	PRESENT	0
315969	309282	19667J	PARTICIPANT	\N	PRESENT	0
315970	309282	19599P	PARTICIPANT	\N	PRESENT	0
315971	309282	14026U	PARTICIPANT	\N	PRESENT	0
315972	309282	04085P	PARTICIPANT	\N	PRESENT	0
315974	309282	07029T	PARTICIPANT	\N	PRESENT	0
315977	309282	19737F	PARTICIPANT	\N	PRESENT	0
315978	309282	04092N	PARTICIPANT	\N	PRESENT	0
315979	309282	19527W	PARTICIPANT	\N	PRESENT	0
315980	309282	17589D	PARTICIPANT	\N	PRESENT	0
315981	309282	14195A	PARTICIPANT	\N	PRESENT	0
315982	309282	08056B	PARTICIPANT	\N	PRESENT	0
315983	309282	19687N	PARTICIPANT	\N	PRESENT	0
315984	309282	04088S	PARTICIPANT	\N	PRESENT	0
315985	309282	14041T	PARTICIPANT	\N	PRESENT	0
315986	309282	14033T	PARTICIPANT	\N	PRESENT	0
315987	309282	19723Y	PARTICIPANT	\N	PRESENT	0
315988	309282	11103C	PARTICIPANT	\N	PRESENT	0
315989	309282	19768N	PARTICIPANT	\N	PRESENT	0
315990	309282	14223L	PARTICIPANT	\N	PRESENT	0
315991	309282	19553Y	PARTICIPANT	\N	PRESENT	0
315992	309282	19253P	PARTICIPANT	\N	PRESENT	0
315993	309282	19575F	PARTICIPANT	\N	PRESENT	0
315994	309282	95030B	PARTICIPANT	\N	PRESENT	0
315997	309282	19691J	PARTICIPANT	\N	PRESENT	0
316002	309282	19715Y	PARTICIPANT	\N	PRESENT	0
316004	309282	14261S	PARTICIPANT	\N	PRESENT	0
316005	309282	11033F	PARTICIPANT	\N	PRESENT	0
316006	309282	19758L	PARTICIPANT	\N	PRESENT	0
316007	309282	11056N	PARTICIPANT	\N	PRESENT	0
316008	309282	14249W	PARTICIPANT	\N	PRESENT	0
316009	309282	14107H	PARTICIPANT	\N	PRESENT	0
316010	309282	19415P	PARTICIPANT	\N	PRESENT	0
316011	309282	19447X	PARTICIPANT	\N	PRESENT	0
316012	309282	19369B	PARTICIPANT	\N	PRESENT	0
316013	309282	14265W	PARTICIPANT	\N	PRESENT	0
316014	309282	14029X	PARTICIPANT	\N	PRESENT	0
316015	309282	14135M	PARTICIPANT	\N	PRESENT	0
316016	309282	19347U	PARTICIPANT	\N	PRESENT	0
316017	309282	17779H	PARTICIPANT	\N	PRESENT	0
316018	309282	14217N	PARTICIPANT	\N	PRESENT	0
316019	309282	08020N	PARTICIPANT	\N	PRESENT	0
316020	309282	14191V	PARTICIPANT	\N	PRESENT	0
316021	309282	87003B	PARTICIPANT	\N	PRESENT	0
316022	309282	19467C	PARTICIPANT	\N	PRESENT	0
316023	309282	16685X	PARTICIPANT	\N	PRESENT	0
316024	309282	14151M	PARTICIPANT	\N	PRESENT	0
316025	309282	19629C	PARTICIPANT	\N	PRESENT	0
316026	309282	08015R	PARTICIPANT	\N	PRESENT	0
316027	309282	19413M	PARTICIPANT	\N	PRESENT	0
316028	309282	14197C	PARTICIPANT	\N	PRESENT	0
316029	309282	14103D	PARTICIPANT	\N	PRESENT	0
316030	309282	14213J	PARTICIPANT	\N	PRESENT	0
316031	309282	11085T	PARTICIPANT	\N	PRESENT	0
316032	309282	19387D	PARTICIPANT	\N	PRESENT	0
316033	309282	19269X	PARTICIPANT	\N	PRESENT	0
316034	309282	19611R	PARTICIPANT	\N	PRESENT	0
316035	309282	97011G	PARTICIPANT	\N	PRESENT	0
316036	309282	08068F	PARTICIPANT	\N	PRESENT	0
316037	309282	14063N	PARTICIPANT	\N	PRESENT	0
316038	309282	14211G	PARTICIPANT	\N	PRESENT	0
316039	309282	14219Q	PARTICIPANT	\N	PRESENT	0
316040	309282	08012N	PARTICIPANT	\N	PRESENT	0
316041	309282	14147R	PARTICIPANT	\N	PRESENT	0
316042	309282	14097Y	PARTICIPANT	\N	PRESENT	0
316043	309282	11040E	PARTICIPANT	\N	PRESENT	0
316044	309282	11109J	PARTICIPANT	\N	PRESENT	0
316045	309282	14123H	PARTICIPANT	\N	PRESENT	0
316046	309282	19421M	PARTICIPANT	\N	PRESENT	0
316047	309282	11070L	PARTICIPANT	\N	PRESENT	0
316048	316003	14061L	PARTICIPANT	\N	PRESENT	0
316049	316003	19701S	PARTICIPANT	\N	PRESENT	0
316050	316003	14133K	PRESIDENT	0	PRESENT	0
316051	316003	14031R	PARTICIPANT	\N	PRESENT	0
316052	316003	14033T	PARTICIPANT	\N	PRESENT	0
316053	316003	14229S	PARTICIPANT	\N	PRESENT	0
316054	316003	19725B	PARTICIPANT	\N	PRESENT	0
316055	316003	14237S	PARTICIPANT	\N	PRESENT	0
316056	316003	14115H	PARTICIPANT	\N	PRESENT	0
316057	316003	04049K	PARTICIPANT	\N	PRESENT	0
316058	316003	95063L	PARTICIPANT	\N	PRESENT	0
316059	316003	19735D	PARTICIPANT	\N	PRESENT	0
316060	316003	19347U	PARTICIPANT	\N	PRESENT	0
316061	316003	19503N	PARTICIPANT	\N	PRESENT	0
316062	316003	11083R	PARTICIPANT	\N	PRESENT	0
316063	316003	19739H	PARTICIPANT	\N	PRESENT	0
316064	316003	14215L	PARTICIPANT	\N	PRESENT	0
316065	316003	19747H	PARTICIPANT	\N	PRESENT	0
316066	316003	19335Q	PARTICIPANT	\N	PRESENT	0
316067	316003	19563B	PARTICIPANT	\N	PRESENT	0
316068	316003	14255U	PARTICIPANT	\N	PRESENT	0
316069	316003	17589D	PARTICIPANT	\N	PRESENT	0
316070	316003	08039A	PARTICIPANT	\N	PRESENT	0
316071	309282	19581D	PARTICIPANT	\N	PRESENT	0
316072	316003	19441R	PARTICIPANT	\N	PRESENT	0
316073	316003	10015M	PARTICIPANT	\N	EXCUSE	0
316074	316003	96004D	PARTICIPANT	\N	EXCUSE	0
316075	316003	04044E	PARTICIPANT	\N	EXCUSE	0
316076	309282	11048N	PARTICIPANT	\N	PRESENT	0
302480	289207	19383Y	PARTICIPANT	\N	PRESENT	0
302481	289207	19701S	PARTICIPANT	\N	PRESENT	0
302482	289207	19441R	PARTICIPANT	\N	PRESENT	0
302483	289207	19415P	PARTICIPANT	\N	PRESENT	0
302484	289207	14187A	PARTICIPANT	\N	PRESENT	0
302485	289207	14069U	PARTICIPANT	\N	PRESENT	0
302486	289207	11115U	PARTICIPANT	\N	PRESENT	0
302487	289207	14193X	PARTICIPANT	\N	PRESENT	0
302488	289207	19335Q	PARTICIPANT	\N	PRESENT	0
302489	289207	19611R	PARTICIPANT	\N	PRESENT	0
302506	301625	14331P	PARTICIPANT	\N	PRESENT	0
302507	301625	11048N	PARTICIPANT	\N	PRESENT	0
302508	301625	19647E	PARTICIPANT	\N	PRESENT	0
302509	301625	19479G	PARTICIPANT	\N	PRESENT	0
302510	301625	19711U	PARTICIPANT	\N	PRESENT	0
302511	301625	08069G	PARTICIPANT	\N	PRESENT	0
302512	301625	19687N	PARTICIPANT	\N	PRESENT	0
302513	301625	11053K	PARTICIPANT	\N	PRESENT	0
302514	301625	11074Q	PRESIDENT	0	PRESENT	0
302515	301625	89017R	PARTICIPANT	\N	PRESENT	0
302516	301625	08011M	PARTICIPANT	\N	PRESENT	0
302517	301625	19671E	PARTICIPANT	\N	PRESENT	0
302518	301625	07029T	PARTICIPANT	\N	PRESENT	0
302519	301625	14083S	PARTICIPANT	\N	PRESENT	0
302520	301625	19741B	PARTICIPANT	\N	PRESENT	0
302521	301625	08010L	PARTICIPANT	\N	PRESENT	0
302522	301625	14121F	PARTICIPANT	\N	PRESENT	0
302523	301625	99004R	PARTICIPANT	\N	PRESENT	0
302524	301625	04061F	PARTICIPANT	\N	PRESENT	0
302525	301625	14327T	PARTICIPANT	\N	EXCUSE	0
302526	301625	07004J	PARTICIPANT	\N	EXCUSE	0
302527	301625	08014Q	PARTICIPANT	\N	EXCUSE	0
302528	289207	14109K	PARTICIPANT	\N	PRESENT	0
302530	289207	08028W	PARTICIPANT	\N	PRESENT	0
302531	289207	19479G	PARTICIPANT	\N	PRESENT	0
302532	289207	11027H	PARTICIPANT	\N	PRESENT	0
302533	289207	14211G	PARTICIPANT	\N	PRESENT	0
302534	289207	14031R	PARTICIPANT	\N	PRESENT	0
302535	289207	14219Q	PARTICIPANT	\N	PRESENT	0
302536	289207	19715Y	PARTICIPANT	\N	PRESENT	0
302537	289207	19689Q	PARTICIPANT	\N	PRESENT	0
302553	289207	04034C	PARTICIPANT	\N	PRESENT	0
302554	289207	19593H	PARTICIPANT	\N	PRESENT	0
302555	289207	08068F	PARTICIPANT	\N	PRESENT	0
302556	289207	14237S	PARTICIPANT	\N	PRESENT	0
302557	289207	19301E	PARTICIPANT	\N	PRESENT	0
302558	289207	19553Y	PARTICIPANT	\N	PRESENT	0
302559	289207	14205J	PARTICIPANT	\N	PRESENT	0
302560	289207	14042U	PARTICIPANT	\N	PRESENT	0
302588	295644	11090Q	PARTICIPANT	\N	PRESENT	0
302589	295644	14187A	PARTICIPANT	\N	PRESENT	0
302590	295644	19565D	PARTICIPANT	\N	PRESENT	0
302591	295644	08068F	PARTICIPANT	\N	PRESENT	0
302582	295644	04044E	PARTICIPANT	\N	PRESENT	0
302584	302583	19629C	PARTICIPANT	\N	PRESENT	0
302585	302583	14041T	PARTICIPANT	\N	PRESENT	0
302586	302583	07034Q	PARTICIPANT	\N	PRESENT	0
302587	302583	19673G	PARTICIPANT	\N	PRESENT	0
302592	295644	14229S	PARTICIPANT	\N	PRESENT	0
302593	295644	04045F	PARTICIPANT	\N	PRESENT	0
302594	295644	19737F	PARTICIPANT	\N	PRESENT	0
302595	295644	19739H	PARTICIPANT	\N	PRESENT	0
302596	295644	19367Y	PARTICIPANT	\N	PRESENT	0
302597	295644	19515S	PARTICIPANT	\N	PRESENT	0
302598	295644	14331P	PARTICIPANT	\N	PRESENT	0
302599	295644	19347U	PARTICIPANT	\N	PRESENT	0
302875	289210	19711U	PARTICIPANT	\N	PRESENT	0
302876	289210	11080N	PARTICIPANT	\N	PRESENT	0
302877	289210	08010L	PARTICIPANT	\N	PRESENT	0
302878	289210	11090Q	PARTICIPANT	\N	PRESENT	0
302879	289210	14157T	PARTICIPANT	\N	PRESENT	0
302880	289210	14223L	PARTICIPANT	\N	PRESENT	0
302881	289210	87003B	PARTICIPANT	\N	PRESENT	0
302882	289210	14259Y	PARTICIPANT	\N	PRESENT	0
302883	289210	08047A	PARTICIPANT	\N	PRESENT	0
302884	289210	19415P	PARTICIPANT	\N	PRESENT	0
302885	289210	08019V	PARTICIPANT	\N	PRESENT	0
302886	289210	14033T	PARTICIPANT	\N	PRESENT	0
302887	289210	11097X	PARTICIPANT	\N	PRESENT	0
302888	289210	19421M	PARTICIPANT	\N	PRESENT	0
302889	289210	11103C	PARTICIPANT	\N	PRESENT	0
302890	289210	14331P	PARTICIPANT	\N	PRESENT	0
302891	289210	14026U	PARTICIPANT	\N	PRESENT	0
302892	289210	04044E	PARTICIPANT	\N	PRESENT	0
302893	289210	11043H	PARTICIPANT	\N	PRESENT	0
302894	289210	97011G	PARTICIPANT	\N	PRESENT	0
302895	289210	14031R	PARTICIPANT	\N	PRESENT	0
302896	289210	08028W	PARTICIPANT	\N	PRESENT	0
302897	289210	14105F	PARTICIPANT	\N	PRESENT	0
302898	289210	99004R	PARTICIPANT	\N	PRESENT	0
302899	289210	04097T	PARTICIPANT	\N	PRESENT	0
302900	289210	07029T	PARTICIPANT	\N	PRESENT	0
302901	289210	01057W	PARTICIPANT	\N	PRESENT	0
302902	289210	19673G	PARTICIPANT	\N	PRESENT	0
302903	289210	08011M	PARTICIPANT	\N	PRESENT	0
302904	289210	19741B	PARTICIPANT	\N	PRESENT	0
302905	289210	04047H	PARTICIPANT	\N	PRESENT	0
302906	289210	04059M	PARTICIPANT	\N	PRESENT	0
302907	289210	08055A	PARTICIPANT	\N	PRESENT	0
302908	289210	12041X	PARTICIPANT	\N	PRESENT	0
302909	289210	14235Q	PARTICIPANT	\N	PRESENT	0
302910	289210	11056N	PARTICIPANT	\N	PRESENT	0
302911	289210	96004D	PARTICIPANT	\N	PRESENT	0
302912	289210	01058X	PARTICIPANT	\N	PRESENT	0
302913	289210	01028R	PARTICIPANT	\N	PRESENT	0
302914	289210	19760E	PARTICIPANT	\N	PRESENT	0
302915	289210	19347U	PARTICIPANT	\N	PRESENT	0
302916	289210	19695N	PARTICIPANT	\N	PRESENT	0
302917	289210	19565D	PARTICIPANT	\N	PRESENT	0
302918	289210	04085P	PARTICIPANT	\N	PRESENT	0
302919	289210	19679N	PARTICIPANT	\N	PRESENT	0
302920	289210	08039A	PARTICIPANT	\N	PRESENT	0
302921	289210	11033F	PARTICIPANT	\N	PRESENT	0
302922	289210	19593H	PARTICIPANT	\N	PRESENT	0
302923	289210	04086Q	PARTICIPANT	\N	PRESENT	0
302924	289210	14021P	PARTICIPANT	\N	PRESENT	0
302925	289210	19687N	PARTICIPANT	\N	PRESENT	0
302926	289210	04071H	PARTICIPANT	\N	PRESENT	0
302927	289210	19651A	PARTICIPANT	\N	PRESENT	0
302928	289210	95063L	PARTICIPANT	\N	PRESENT	0
302929	289210	19643A	PARTICIPANT	\N	PRESENT	0
302930	289210	95037J	PARTICIPANT	\N	PRESENT	0
302931	289210	04045F	PARTICIPANT	\N	PRESENT	0
302932	289210	04033B	PARTICIPANT	\N	PRESENT	0
302933	289210	04034C	PARTICIPANT	\N	PRESENT	0
302934	289210	19349W	PARTICIPANT	\N	PRESENT	0
302935	289210	14187A	PARTICIPANT	\N	PRESENT	0
302936	289210	11083R	PARTICIPANT	\N	PRESENT	0
302937	289210	19543W	PARTICIPANT	\N	PRESENT	0
302938	289210	14071N	PARTICIPANT	\N	PRESENT	0
302939	289210	19637C	PARTICIPANT	\N	PRESENT	0
302940	289210	19515S	PARTICIPANT	\N	PRESENT	0
302941	289210	19301E	PARTICIPANT	\N	PRESENT	0
302942	289210	11072N	PARTICIPANT	\N	PRESENT	0
302943	289210	08069G	PARTICIPANT	\N	PRESENT	0
302944	289210	08024S	PARTICIPANT	\N	PRESENT	0
302945	289210	89017R	PARTICIPANT	\N	PRESENT	0
302946	289210	19731Y	PARTICIPANT	\N	PRESENT	0
302947	289210	95067Q	PARTICIPANT	\N	PRESENT	0
302948	289210	14055N	PARTICIPANT	\N	PRESENT	0
302949	289210	19719D	PARTICIPANT	\N	PRESENT	0
302950	289210	08016S	PARTICIPANT	\N	PRESENT	0
302951	289210	14069U	PARTICIPANT	\N	PRESENT	0
302952	289210	14034U	PARTICIPANT	\N	PRESENT	0
302953	289210	08031R	PARTICIPANT	\N	PRESENT	0
302954	289210	14053L	PARTICIPANT	\N	PRESENT	0
302955	289210	11012A	PARTICIPANT	\N	PRESENT	0
302956	289210	14261S	PARTICIPANT	\N	PRESENT	0
302957	289210	14215L	PARTICIPANT	\N	PRESENT	0
302958	289210	19703U	PARTICIPANT	\N	PRESENT	0
302959	289210	19697Q	PARTICIPANT	\N	PRESENT	0
302960	289210	19629C	PARTICIPANT	\N	PRESENT	0
302961	289210	19253P	PARTICIPANT	\N	PRESENT	0
302962	289210	19667J	PARTICIPANT	\N	PRESENT	0
302963	289210	19563B	PARTICIPANT	\N	PRESENT	0
302964	289210	14201E	PARTICIPANT	\N	PRESENT	0
302965	289210	19575F	PARTICIPANT	\N	PRESENT	0
302966	289210	14241N	PARTICIPANT	\N	PRESENT	0
302967	289210	11048N	PARTICIPANT	\N	PRESENT	0
302968	289210	19289C	PARTICIPANT	\N	PRESENT	0
302969	289210	19387D	PARTICIPANT	\N	PRESENT	0
302970	289210	05012A	PARTICIPANT	\N	PRESENT	0
302971	289210	19553Y	PARTICIPANT	\N	PRESENT	0
302972	289210	19717B	PARTICIPANT	\N	PRESENT	0
302973	289210	08034U	PARTICIPANT	\N	PRESENT	0
302974	289210	19533U	PARTICIPANT	\N	PRESENT	0
302975	289210	14251Q	PARTICIPANT	\N	PRESENT	0
302976	289210	07034Q	PARTICIPANT	\N	PRESENT	0
302977	289210	17589D	PARTICIPANT	\N	PRESENT	0
318007	309290	19691J	PARTICIPANT	\N	PRESENT	0
318008	309290	19369B	PARTICIPANT	\N	PRESENT	0
318009	309290	19721W	PARTICIPANT	\N	PRESENT	0
318010	309290	04071H	PARTICIPANT	\N	PRESENT	0
318011	309290	14327T	PARTICIPANT	\N	PRESENT	0
318012	309290	01024M	PARTICIPANT	\N	PRESENT	0
318013	309290	01025N	PARTICIPANT	\N	PRESENT	0
318014	309290	04040A	PARTICIPANT	\N	PRESENT	0
318015	309290	14231L	PARTICIPANT	\N	PRESENT	0
318016	309290	04089T	PARTICIPANT	\N	PRESENT	0
318017	309290	19511N	PARTICIPANT	\N	PRESENT	0
318018	309290	08044W	PARTICIPANT	\N	PRESENT	0
318019	309290	11070L	PARTICIPANT	\N	PRESENT	0
318020	309290	14355X	PARTICIPANT	\N	PRESENT	0
318021	309290	19335Q	PARTICIPANT	\N	PRESENT	0
318022	309290	08068F	PARTICIPANT	\N	PRESENT	0
318023	309290	14033T	PARTICIPANT	\N	PRESENT	0
318024	309290	14055N	PARTICIPANT	\N	PRESENT	0
318026	309290	08015R	PARTICIPANT	\N	PRESENT	0
318027	309290	01034P	PARTICIPANT	\N	PRESENT	0
318028	309290	11027H	PARTICIPANT	\N	PRESENT	0
318029	309290	08011M	PARTICIPANT	\N	PRESENT	0
318030	309290	14053L	PARTICIPANT	\N	PRESENT	0
318031	309290	14028W	PARTICIPANT	\N	PRESENT	0
318032	309290	11090Q	PARTICIPANT	\N	PRESENT	0
318033	309290	14255U	PARTICIPANT	\N	PRESENT	0
318034	309290	14083S	PARTICIPANT	\N	PRESENT	0
318035	309290	14179A	PARTICIPANT	\N	PRESENT	0
318056	309290	11026G	PARTICIPANT	\N	PRESENT	0
318040	309290	11077T	PARTICIPANT	\N	PRESENT	0
318043	309290	02002K	PARTICIPANT	\N	PRESENT	0
318051	309290	14103D	PARTICIPANT	\N	PRESENT	0
318052	309290	14111D	PARTICIPANT	\N	PRESENT	0
318053	309290	14089Y	PARTICIPANT	\N	PRESENT	0
318054	309290	14229S	PARTICIPANT	\N	PRESENT	0
318055	309290	19421M	PARTICIPANT	\N	PRESENT	0
318327	309291	86034E	PARTICIPANT	\N	PRESENT	0
318329	309291	96004D	PARTICIPANT	\N	PRESENT	0
318330	309291	04042C	PARTICIPANT	\N	PRESENT	0
318331	309291	99004R	PARTICIPANT	\N	PRESENT	0
318332	309291	08010L	PARTICIPANT	\N	PRESENT	0
318333	309291	95062K	PARTICIPANT	\N	PRESENT	0
318334	309291	14157T	PARTICIPANT	\N	PRESENT	0
318335	309291	14169X	PARTICIPANT	\N	PRESENT	0
318336	309291	14119M	PARTICIPANT	\N	PRESENT	0
318337	309291	07029T	PARTICIPANT	\N	PRESENT	0
318338	309291	19731Y	PARTICIPANT	\N	PRESENT	0
318339	309291	12041X	PARTICIPANT	\N	PRESENT	0
318340	309291	04085P	PARTICIPANT	\N	PRESENT	0
318341	309291	19593H	PARTICIPANT	\N	PRESENT	0
318343	318342	14021P	PARTICIPANT	\N	PRESENT	0
318344	309291	14121F	PARTICIPANT	\N	PRESENT	0
318345	309291	14109K	PARTICIPANT	\N	PRESENT	0
318346	309291	01028R	PARTICIPANT	\N	PRESENT	0
318347	309291	11026G	PARTICIPANT	\N	PRESENT	0
318348	309291	14028W	PARTICIPANT	\N	PRESENT	0
318349	309291	08053X	PARTICIPANT	\N	PRESENT	0
318350	309291	04034C	PARTICIPANT	\N	PRESENT	0
318351	309291	98022P	PARTICIPANT	\N	PRESENT	0
318352	309291	04059M	PARTICIPANT	\N	PRESENT	0
318353	309291	19737F	PARTICIPANT	\N	PRESENT	0
318354	309291	04097T	PARTICIPANT	\N	PRESENT	0
318355	309291	14089Y	PARTICIPANT	\N	PRESENT	0
318356	309291	04047H	PARTICIPANT	\N	PRESENT	0
318357	309291	01058X	PARTICIPANT	\N	PRESENT	0
318358	309291	98018T	PARTICIPANT	\N	PRESENT	0
318359	309291	04040A	PARTICIPANT	\N	PRESENT	0
318360	309291	08034U	PARTICIPANT	\N	PRESENT	0
318361	309291	14281W	PARTICIPANT	\N	PRESENT	0
318362	309291	19415P	PARTICIPANT	\N	PRESENT	0
318363	309291	19421M	PARTICIPANT	\N	PRESENT	0
318364	309291	14105F	PARTICIPANT	\N	PRESENT	0
318365	309291	14331P	PARTICIPANT	\N	PRESENT	0
318366	309291	04018C	PARTICIPANT	\N	PRESENT	0
318367	309291	14055N	PARTICIPANT	\N	PRESENT	0
318368	309291	08020N	PARTICIPANT	\N	PRESENT	0
318370	309291	19671E	PARTICIPANT	\N	PRESENT	0
318371	309291	18083K	PARTICIPANT	\N	PRESENT	0
318373	309291	19383Y	PARTICIPANT	\N	PRESENT	0
318374	309291	95030B	PARTICIPANT	\N	PRESENT	0
318375	309291	14235Q	PARTICIPANT	\N	PRESENT	0
318376	309291	19251M	PARTICIPANT	\N	PRESENT	0
318377	309291	11104D	PARTICIPANT	\N	PRESENT	0
318378	309291	19647E	PARTICIPANT	\N	PRESENT	0
318420	318415	19593H	PARTICIPANT	\N	PRESENT	0
318421	318415	19533U	PARTICIPANT	\N	PRESENT	0
318427	318426	14123H	PARTICIPANT	\N	PRESENT	0
318428	318426	19611R	PARTICIPANT	\N	PRESENT	0
318440	309291	14097Y	PARTICIPANT	\N	PRESENT	0
318542	316079	19697Q	PARTICIPANT	\N	PRESENT	0
318543	316079	19569H	PARTICIPANT	\N	PRESENT	0
318544	316079	19415P	PARTICIPANT	\N	PRESENT	0
318545	316079	14223L	PARTICIPANT	\N	PRESENT	0
318546	316079	14227Q	PARTICIPANT	\N	PRESENT	0
318547	316079	19703U	PARTICIPANT	\N	PRESENT	0
318548	316079	14239U	PARTICIPANT	\N	PRESENT	0
318549	316079	14281W	PARTICIPANT	\N	PRESENT	0
318550	316079	19679N	PARTICIPANT	\N	PRESENT	0
318551	316079	14042U	PARTICIPANT	\N	PRESENT	0
318552	316079	19575F	PARTICIPANT	\N	PRESENT	0
318553	316079	14195A	PARTICIPANT	\N	PRESENT	0
318554	316079	19367Y	PARTICIPANT	\N	PRESENT	0
318555	316079	14213J	PARTICIPANT	\N	PRESENT	0
318556	316079	14217N	PARTICIPANT	\N	PRESENT	0
318557	316079	19335Q	PARTICIPANT	\N	PRESENT	0
318558	316079	14261S	PARTICIPANT	\N	PRESENT	0
318559	316079	10006L	PARTICIPANT	\N	PRESENT	0
318560	316079	19683J	PARTICIPANT	\N	PRESENT	0
318561	316079	98024R	PARTICIPANT	\N	PRESENT	0
318562	316079	19521Q	PARTICIPANT	\N	PRESENT	0
318563	316079	01034P	PARTICIPANT	\N	PRESENT	0
318564	316079	04092N	PRESIDENT	0	PRESENT	0
318565	316079	08052W	PARTICIPANT	\N	PRESENT	0
318566	316079	19717B	PARTICIPANT	\N	PRESENT	0
318567	316079	19723Y	PARTICIPANT	\N	PRESENT	0
318568	316079	14119M	PARTICIPANT	\N	PRESENT	0
318569	316079	11103C	PARTICIPANT	\N	PRESENT	0
318571	316079	14087W	PARTICIPANT	\N	PRESENT	0
318572	316532	14327T	PARTICIPANT	\N	PRESENT	0
318573	316532	14331P	PARTICIPANT	\N	PRESENT	0
318574	316532	95041E	PARTICIPANT	\N	PRESENT	0
318575	316532	01048V	PARTICIPANT	\N	PRESENT	0
318576	316532	01057W	PARTICIPANT	\N	PRESENT	0
318577	316532	11053K	PARTICIPANT	\N	PRESENT	0
318578	316532	19667J	PARTICIPANT	\N	PRESENT	0
318579	316532	89017R	PARTICIPANT	\N	PRESENT	0
318580	316532	11074Q	PRESIDENT	0	PRESENT	0
318581	316532	11070L	PARTICIPANT	\N	PRESENT	0
318582	316532	14225N	PARTICIPANT	\N	PRESENT	0
318583	316532	19671E	PARTICIPANT	\N	PRESENT	0
318584	316532	19349W	PARTICIPANT	\N	PRESENT	0
318585	316532	08010L	PARTICIPANT	\N	PRESENT	0
318586	316532	14253S	PARTICIPANT	\N	PRESENT	0
318587	316532	19479G	PARTICIPANT	\N	PRESENT	0
318588	316532	19711U	PARTICIPANT	\N	PRESENT	0
318589	316532	19531S	PARTICIPANT	\N	PRESENT	0
318590	316532	08034U	PARTICIPANT	\N	PRESENT	0
318591	316532	19689Q	PARTICIPANT	\N	PRESENT	0
318592	316532	08011M	PARTICIPANT	\N	PRESENT	0
318593	316532	14159V	PARTICIPANT	\N	PRESENT	0
318594	316532	11040E	PARTICIPANT	\N	PRESENT	0
318595	316532	14083S	PARTICIPANT	\N	PRESENT	0
318596	316532	14199E	PARTICIPANT	\N	PRESENT	0
318597	316532	99004R	PARTICIPANT	\N	PRESENT	0
318598	316532	04061F	PARTICIPANT	\N	PRESENT	0
318599	316532	07004J	PARTICIPANT	\N	EXCUSE	0
318600	316532	08014Q	PARTICIPANT	\N	EXCUSE	0
318601	316537	14221J	PARTICIPANT	\N	PRESENT	0
318662	316079	19663E	PARTICIPANT	\N	PRESENT	0
318663	313974	19737F	PARTICIPANT	\N	PRESENT	0
318664	313974	19349W	PARTICIPANT	\N	PRESENT	0
318665	313974	02002K	PARTICIPANT	\N	PRESENT	0
318666	313974	19551W	PARTICIPANT	\N	PRESENT	0
318674	314276	19723Y	PARTICIPANT	\N	PRESENT	0
318675	314278	14223L	PARTICIPANT	\N	PRESENT	0
318676	314278	19703U	PARTICIPANT	\N	PRESENT	0
318749	305885	19467C	PARTICIPANT	\N	EXCUSE	0
318754	316532	14034U	PARTICIPANT	\N	PRESENT	0
318755	317525	19383Y	PARTICIPANT	\N	PRESENT	0
318756	317525	19333N	PARTICIPANT	\N	PRESENT	0
318757	317525	17583W	PARTICIPANT	\N	PRESENT	0
318758	317525	19701S	PARTICIPANT	\N	PRESENT	0
318759	317525	95062K	PARTICIPANT	\N	PRESENT	0
318760	317525	19549D	PARTICIPANT	\N	PRESENT	0
318761	317525	19387D	PARTICIPANT	\N	PRESENT	0
318762	317525	14219Q	PARTICIPANT	\N	PRESENT	0
318763	317525	14221J	PARTICIPANT	\N	PRESENT	0
318764	317525	02002K	PARTICIPANT	\N	PRESENT	0
304216	301908	19758L	PARTICIPANT	\N	EXCUSE	0
304217	301908	19693L	PARTICIPANT	\N	EXCUSE	0
304218	301908	19399H	PARTICIPANT	\N	EXCUSE	0
304219	301908	04057K	PARTICIPANT	\N	EXCUSE	0
304228	304227	11099A	PARTICIPANT	\N	PRESENT	0
305037	305036	14213J	PARTICIPANT	\N	PRESENT	0
305038	305036	11099A	PARTICIPANT	\N	PRESENT	0
305039	305036	14109K	PARTICIPANT	\N	PRESENT	0
305040	305036	19347U	PARTICIPANT	\N	PRESENT	0
305041	305036	04049K	PARTICIPANT	\N	PRESENT	0
305042	305036	19503N	PARTICIPANT	\N	PRESENT	0
305284	305283	10006L	PARTICIPANT	\N	PRESENT	0
309425	309053	14065Q	PARTICIPANT	\N	PRESENT	0
309426	309053	14179A	PARTICIPANT	\N	PRESENT	0
309440	307422	04059M	PARTICIPANT	\N	PRESENT	0
309441	307422	08011M	PARTICIPANT	\N	PRESENT	0
309442	307422	19583F	PARTICIPANT	\N	PRESENT	0
309443	307422	19507S	PARTICIPANT	\N	PRESENT	0
309444	307422	14231L	PARTICIPANT	\N	PRESENT	0
309445	307422	14042U	PARTICIPANT	\N	PRESENT	0
309446	307422	19729F	PARTICIPANT	\N	PRESENT	0
309447	307422	19683J	PARTICIPANT	\N	PRESENT	0
309448	307422	14085U	PARTICIPANT	\N	PRESENT	0
309449	307422	18083K	PARTICIPANT	\N	PRESENT	0
309450	307422	14041T	PARTICIPANT	\N	PRESENT	0
309451	307422	14033T	PARTICIPANT	\N	PRESENT	0
309452	307422	14265W	PARTICIPANT	\N	PRESENT	0
309453	307422	14357A	PARTICIPANT	\N	PRESENT	0
309454	307422	08028W	PARTICIPANT	\N	PRESENT	0
309455	307422	14331P	PARTICIPANT	\N	PRESENT	0
309456	307422	14079W	PARTICIPANT	\N	PRESENT	0
309457	307422	19545Y	PARTICIPANT	\N	PRESENT	0
309458	307422	11040E	PARTICIPANT	\N	PRESENT	0
309459	307422	19731Y	PARTICIPANT	\N	PRESENT	0
309460	307422	19703U	PARTICIPANT	\N	PRESENT	0
309461	307422	19515S	PARTICIPANT	\N	PRESENT	0
309462	307422	19741B	PARTICIPANT	\N	PRESENT	0
309463	307422	19719D	PARTICIPANT	\N	PRESENT	0
309464	307422	19629C	PARTICIPANT	\N	PRESENT	0
309465	307422	19711U	PARTICIPANT	\N	PRESENT	0
309466	307422	19479G	PARTICIPANT	\N	PRESENT	0
309467	307422	19415P	PARTICIPANT	\N	PRESENT	0
309468	307422	01057W	PARTICIPANT	\N	PRESENT	0
309469	307422	11083R	PARTICIPANT	\N	PRESENT	0
309470	307422	08061X	PARTICIPANT	\N	PRESENT	0
309471	307422	14063N	PARTICIPANT	\N	PRESENT	0
309472	307422	14147R	PARTICIPANT	\N	PRESENT	0
309473	307422	19443T	PARTICIPANT	\N	PRESENT	0
309474	307422	08015R	PARTICIPANT	\N	PRESENT	0
309475	307422	14267Y	PARTICIPANT	\N	PRESENT	0
309476	307422	04086Q	PARTICIPANT	\N	PRESENT	0
309477	307422	14107H	PARTICIPANT	\N	PRESENT	0
309478	307422	14261S	PARTICIPANT	\N	PRESENT	0
309479	307422	14219Q	PARTICIPANT	\N	PRESENT	0
309480	307422	19737F	PARTICIPANT	\N	PRESENT	0
309481	307422	14221J	PARTICIPANT	\N	PRESENT	0
309482	307422	14115H	PARTICIPANT	\N	PRESENT	0
309483	307422	19671E	PARTICIPANT	\N	PRESENT	0
309484	307422	14069U	PARTICIPANT	\N	PRESENT	0
309485	307422	11074Q	PARTICIPANT	\N	PRESENT	0
309486	307422	19447X	PARTICIPANT	\N	PRESENT	0
309487	307422	14038Y	PARTICIPANT	\N	PRESENT	0
309488	307422	11104D	PARTICIPANT	\N	PRESENT	0
309489	307422	14207L	PARTICIPANT	\N	PRESENT	0
309490	307422	14034U	PARTICIPANT	\N	PRESENT	0
309491	307422	11043H	PARTICIPANT	\N	PRESENT	0
309492	307422	07034Q	PARTICIPANT	\N	PRESENT	0
309493	307422	01024M	PARTICIPANT	\N	PRESENT	0
309494	307422	07004J	PARTICIPANT	\N	PRESENT	0
309495	307422	11048N	PARTICIPANT	\N	PRESENT	0
309496	307422	08010L	PARTICIPANT	\N	PRESENT	0
309497	307422	19253P	PARTICIPANT	\N	PRESENT	0
309498	307422	19689Q	PARTICIPANT	\N	PRESENT	0
309499	307422	14223L	PARTICIPANT	\N	PRESENT	0
309500	307422	08038Y	PARTICIPANT	\N	PRESENT	0
309501	307422	14119M	PARTICIPANT	\N	PRESENT	0
309502	307422	87003B	PARTICIPANT	\N	PRESENT	0
309503	307422	14253S	PARTICIPANT	\N	PRESENT	0
309504	307422	08034U	PARTICIPANT	\N	PRESENT	0
309505	307422	19467C	PARTICIPANT	\N	PRESENT	0
309506	307422	19569H	PARTICIPANT	\N	PRESENT	0
309507	307422	14217N	PARTICIPANT	\N	PRESENT	0
309508	307422	19441R	PARTICIPANT	\N	PRESENT	0
309509	307422	19747H	PARTICIPANT	\N	PRESENT	0
309510	307422	08020N	PARTICIPANT	\N	PRESENT	0
309511	307422	08056B	PARTICIPANT	\N	PRESENT	0
309512	307422	19621T	PARTICIPANT	\N	PRESENT	0
309513	307422	19611R	PARTICIPANT	\N	PRESENT	0
309515	307422	19399H	PARTICIPANT	\N	PRESENT	0
309516	307422	14157T	PARTICIPANT	\N	PRESENT	0
309518	307422	08053X	PARTICIPANT	\N	PRESENT	0
309519	307422	95030B	PARTICIPANT	\N	PRESENT	0
309520	307422	19768N	PARTICIPANT	\N	PRESENT	0
309522	307422	19725B	PARTICIPANT	\N	PRESENT	0
309523	307422	19667J	PARTICIPANT	\N	PRESENT	0
309524	307422	19637C	PARTICIPANT	\N	PRESENT	0
309525	307422	19599P	PARTICIPANT	\N	PRESENT	0
309526	307422	95062K	PARTICIPANT	\N	PRESENT	0
309527	307422	01025N	PARTICIPANT	\N	PRESENT	0
309528	307422	01058X	PARTICIPANT	\N	PRESENT	0
309529	307422	14187A	PARTICIPANT	\N	PRESENT	0
309530	307422	14021P	PARTICIPANT	\N	PRESENT	0
309531	307422	14097Y	PARTICIPANT	\N	PRESENT	0
309532	307422	14211G	PARTICIPANT	\N	PRESENT	0
309533	307422	17637T	PARTICIPANT	\N	PRESENT	0
309534	307422	19533U	PARTICIPANT	\N	PRESENT	0
309535	307422	95063L	PARTICIPANT	\N	PRESENT	0
309616	307423	04059M	PARTICIPANT	\N	PRESENT	0
309617	307423	04085P	PARTICIPANT	\N	PRESENT	0
309618	307423	14028W	PARTICIPANT	\N	PRESENT	0
309619	307423	19503N	PARTICIPANT	\N	PRESENT	0
309621	307423	14063N	PARTICIPANT	\N	PRESENT	0
309622	307423	14097Y	PARTICIPANT	\N	PRESENT	0
309623	307423	19725B	PARTICIPANT	\N	PRESENT	0
309624	307423	14207L	PARTICIPANT	\N	PRESENT	0
309625	307423	14021P	PARTICIPANT	\N	PRESENT	0
309626	307423	14085U	PARTICIPANT	\N	PRESENT	0
309627	307423	14261S	PARTICIPANT	\N	PRESENT	0
309628	307423	19441R	PARTICIPANT	\N	PRESENT	0
309629	307423	14219Q	PARTICIPANT	\N	PRESENT	0
309630	307423	19713W	PARTICIPANT	\N	PRESENT	0
309631	307423	14042U	PARTICIPANT	\N	PRESENT	0
309632	307423	14089Y	PARTICIPANT	\N	PRESENT	0
309633	307423	19737F	PARTICIPANT	\N	PRESENT	0
309634	307423	19731Y	PARTICIPANT	\N	PRESENT	0
309635	307423	19621T	PARTICIPANT	\N	PRESENT	0
309636	307423	14331P	PARTICIPANT	\N	PRESENT	0
309637	307423	14357A	PARTICIPANT	\N	PRESENT	0
309638	307423	14217N	PARTICIPANT	\N	PRESENT	0
309639	307423	11083R	PARTICIPANT	\N	PRESENT	0
309640	307423	19768N	PARTICIPANT	\N	PRESENT	0
309641	307423	14265W	PARTICIPANT	\N	PRESENT	0
309642	307423	14157T	PARTICIPANT	\N	PRESENT	0
309643	307423	19545Y	PARTICIPANT	\N	PRESENT	0
309644	307423	11040E	PARTICIPANT	\N	PRESENT	0
309645	307423	04047H	PARTICIPANT	\N	PRESENT	0
309646	307423	01024M	PARTICIPANT	\N	PRESENT	0
309647	307423	14111D	PARTICIPANT	\N	PRESENT	0
309648	307423	19333N	PARTICIPANT	\N	PRESENT	0
309649	307423	01025N	PARTICIPANT	\N	PRESENT	0
309650	307423	11072N	PARTICIPANT	\N	PRESENT	0
309651	307423	19711U	PARTICIPANT	\N	PRESENT	0
309652	307423	08056B	PARTICIPANT	\N	PRESENT	0
309653	307423	11103C	PARTICIPANT	\N	PRESENT	0
309654	307423	11067R	PARTICIPANT	\N	PRESENT	0
309655	307423	19762G	PARTICIPANT	\N	PRESENT	0
309656	307423	14041T	PARTICIPANT	\N	PRESENT	0
309657	307423	04088S	PARTICIPANT	\N	PRESENT	0
309658	307423	19533U	PARTICIPANT	\N	PRESENT	0
309659	307423	14069U	PARTICIPANT	\N	PRESENT	0
309660	307423	14187A	PARTICIPANT	\N	PRESENT	0
309661	307423	95030B	PARTICIPANT	\N	PRESENT	0
309662	307423	08010L	PARTICIPANT	\N	PRESENT	0
309663	307423	01048V	PARTICIPANT	\N	PRESENT	0
309664	307423	11043H	PARTICIPANT	\N	PRESENT	0
309665	307423	08045X	PARTICIPANT	\N	PRESENT	0
309666	307423	11048N	PARTICIPANT	\N	PRESENT	0
309667	307423	87003B	PARTICIPANT	\N	PRESENT	0
309668	307423	08020N	PARTICIPANT	\N	PRESENT	0
309669	307423	01057W	PARTICIPANT	\N	PRESENT	0
309670	307423	19443T	PARTICIPANT	\N	PRESENT	0
309671	307423	19507S	PARTICIPANT	\N	PRESENT	0
309672	307423	18083K	PARTICIPANT	\N	PRESENT	0
309673	307423	19703U	PARTICIPANT	\N	PRESENT	0
309674	307423	19515S	PARTICIPANT	\N	PRESENT	0
309675	307423	14038Y	PARTICIPANT	\N	PRESENT	0
309676	307423	14211G	PARTICIPANT	\N	PRESENT	0
309677	307423	95063L	PARTICIPANT	\N	PRESENT	0
309678	307423	14147R	PARTICIPANT	\N	PRESENT	0
316077	309282	14073Q	PARTICIPANT	\N	PRESENT	0
316078	309282	11077T	PARTICIPANT	\N	PRESENT	0
316080	309282	19521Q	PARTICIPANT	\N	PRESENT	0
316081	309282	19399H	PARTICIPANT	\N	PRESENT	0
316082	309282	14173T	PARTICIPANT	\N	PRESENT	0
316083	309282	04043D	PARTICIPANT	\N	PRESENT	0
316084	309282	14251Q	PARTICIPANT	\N	PRESENT	0
316182	309283	11070L	PARTICIPANT	\N	PRESENT	0
316184	309283	08010L	PARTICIPANT	\N	PRESENT	0
316185	309283	14223L	PARTICIPANT	\N	PRESENT	0
316186	309283	19575F	PARTICIPANT	\N	PRESENT	0
316187	309283	11048N	PARTICIPANT	\N	PRESENT	0
316188	309283	14191V	PARTICIPANT	\N	PRESENT	0
316189	309283	14041T	PARTICIPANT	\N	PRESENT	0
316190	309283	19467C	PARTICIPANT	\N	PRESENT	0
316191	309283	08015R	PARTICIPANT	\N	PRESENT	0
316192	309283	07029T	PARTICIPANT	\N	PRESENT	0
316193	309283	14265W	PARTICIPANT	\N	PRESENT	0
316194	309283	17589D	PARTICIPANT	\N	PRESENT	0
316195	309283	19531S	PARTICIPANT	\N	PRESENT	0
316196	309283	11109J	PARTICIPANT	\N	PRESENT	0
316197	309283	04088S	PARTICIPANT	\N	PRESENT	0
316198	309283	08068F	PARTICIPANT	\N	PRESENT	0
316199	309283	19599P	PARTICIPANT	\N	PRESENT	0
316200	309283	19723Y	PARTICIPANT	\N	PRESENT	0
316201	309283	19387D	PARTICIPANT	\N	PRESENT	0
316202	309283	14157T	PARTICIPANT	\N	PRESENT	0
316203	309283	14073Q	PARTICIPANT	\N	PRESENT	0
316204	309283	19737F	PARTICIPANT	\N	PRESENT	0
316205	309283	11056N	PARTICIPANT	\N	PRESENT	0
316206	309283	11040E	PARTICIPANT	\N	PRESENT	0
316207	309283	11077T	PARTICIPANT	\N	PRESENT	0
316208	309283	04085P	PARTICIPANT	\N	PRESENT	0
316209	309283	19399H	PARTICIPANT	\N	PRESENT	0
316210	309283	19657G	PARTICIPANT	\N	PRESENT	0
316211	309283	19731Y	PARTICIPANT	\N	PRESENT	0
316212	309283	14211G	PARTICIPANT	\N	PRESENT	0
316213	309283	14257W	PARTICIPANT	\N	PRESENT	0
316214	309283	98022P	PARTICIPANT	\N	PRESENT	0
316216	309283	14119M	PARTICIPANT	\N	PRESENT	0
316217	309283	19715Y	PARTICIPANT	\N	PRESENT	0
316218	309283	14205J	PARTICIPANT	\N	PRESENT	0
316219	309283	19760E	PARTICIPANT	\N	PRESENT	0
316220	309283	14021P	PARTICIPANT	\N	PRESENT	0
316221	309283	19349W	PARTICIPANT	\N	PRESENT	0
316222	309283	97011G	PARTICIPANT	\N	PRESENT	0
316223	309283	14213J	PARTICIPANT	\N	PRESENT	0
316464	311802	08053X	PARTICIPANT	\N	EXCUSE	0
316465	311802	19723Y	PARTICIPANT	\N	PRESENT	0
316472	316364	08014Q	PARTICIPANT	\N	EXCUSE	0
316473	316364	10015M	PARTICIPANT	\N	EXCUSE	0
316474	316364	08018U	PARTICIPANT	\N	EXCUSE	0
316475	316364	14097Y	PARTICIPANT	\N	EXCUSE	0
316476	316364	11026G	PARTICIPANT	\N	EXCUSE	0
316477	316364	08039A	PARTICIPANT	\N	PRESENT	0
316478	316364	14205J	PARTICIPANT	\N	PRESENT	0
316479	316364	14001X	PARTICIPANT	\N	PRESENT	0
316480	316364	04057K	PARTICIPANT	\N	PRESENT	0
316481	316364	14225N	PARTICIPANT	\N	PRESENT	0
316482	316364	98035U	PARTICIPANT	\N	PRESENT	0
316483	316364	96004D	PRESIDENT	0	PRESENT	0
316484	316364	14357A	PARTICIPANT	\N	PRESENT	0
316485	316364	14249W	PARTICIPANT	\N	PRESENT	0
316486	316364	11083R	PARTICIPANT	\N	PRESENT	0
316487	316364	14033T	PARTICIPANT	\N	PRESENT	0
316488	316364	19725B	PARTICIPANT	\N	PRESENT	0
316489	316364	95037J	PARTICIPANT	\N	PRESENT	0
316490	316364	04097T	PARTICIPANT	\N	PRESENT	0
316491	316364	14073Q	PARTICIPANT	\N	PRESENT	0
316492	316364	14221J	PARTICIPANT	\N	PRESENT	0
316493	316364	14135M	PARTICIPANT	\N	PRESENT	0
316494	316364	14331P	PARTICIPANT	\N	PRESENT	0
316495	316342	08018U	PARTICIPANT	\N	EXCUSE	0
316496	316342	11026G	PARTICIPANT	\N	EXCUSE	0
316497	316342	10015M	PARTICIPANT	\N	EXCUSE	0
319326	318797	19565D	PARTICIPANT	\N	EXCUSE	0
319334	318797	14195A	PARTICIPANT	\N	EXCUSE	0
325439	324297	08051V	PARTICIPANT	\N	PRESENT	0
325440	324297	19762G	PARTICIPANT	\N	PRESENT	0
325441	324297	11072N	PARTICIPANT	\N	PRESENT	0
325444	314162	19705W	PARTICIPANT	\N	PRESENT	0
325445	314162	19527W	PARTICIPANT	\N	PRESENT	0
325446	314162	19762G	PARTICIPANT	\N	PRESENT	0
325447	314162	14187A	PARTICIPANT	\N	PRESENT	0
325448	314162	14039A	PARTICIPANT	\N	PRESENT	0
325449	314162	14205J	PARTICIPANT	\N	PRESENT	0
325450	314162	14231L	PARTICIPANT	\N	PRESENT	0
325452	314162	14033T	PARTICIPANT	\N	PRESENT	0
325453	314162	14217N	PARTICIPANT	\N	PRESENT	0
325454	314162	19747H	PARTICIPANT	\N	PRESENT	0
325455	314162	14069U	PARTICIPANT	\N	PRESENT	0
325456	314162	02002K	PARTICIPANT	\N	PRESENT	0
325457	314162	14038Y	PARTICIPANT	\N	PRESENT	0
325458	314162	14087W	PARTICIPANT	\N	PRESENT	0
325459	314162	11045K	PARTICIPANT	\N	PRESENT	0
316178	309283	01043Q	PARTICIPANT	\N	PRESENT	0
316180	309283	19687N	PARTICIPANT	\N	PRESENT	0
325470	325382	86034E	PARTICIPANT	\N	PRESENT	0
325461	314162	19531S	PARTICIPANT	\N	PRESENT	0
325472	325382	19629C	PARTICIPANT	\N	PRESENT	0
325473	325382	14195A	PARTICIPANT	\N	PRESENT	0
325474	325382	04089T	PARTICIPANT	\N	PRESENT	0
325475	325382	11072N	PARTICIPANT	\N	PRESENT	0
325476	325382	19679N	PARTICIPANT	\N	PRESENT	0
325477	325382	14277B	PARTICIPANT	\N	PRESENT	0
325478	325382	17637T	PARTICIPANT	\N	PRESENT	0
325479	325382	19533U	PARTICIPANT	\N	PRESENT	0
325471	325382	19583F	PARTICIPANT	\N	PRESENT	0
325480	325382	14191V	PARTICIPANT	\N	PRESENT	0
325481	325382	19569H	PARTICIPANT	\N	PRESENT	0
325482	325382	19673G	PARTICIPANT	\N	PRESENT	0
325483	325382	04088S	PARTICIPANT	\N	PRESENT	0
325484	325382	19659J	PARTICIPANT	\N	PRESENT	0
325485	325382	19413M	PARTICIPANT	\N	PRESENT	0
325486	325382	19387D	PARTICIPANT	\N	PRESENT	0
325487	325382	99004R	PARTICIPANT	\N	PRESENT	0
325489	325382	19717B	PARTICIPANT	\N	PRESENT	0
325490	325382	19503N	PARTICIPANT	\N	PRESENT	0
325491	325382	19703U	PARTICIPANT	\N	PRESENT	0
325492	325382	08052W	PARTICIPANT	\N	PRESENT	0
325493	325382	19367Y	PARTICIPANT	\N	PRESENT	0
325494	325382	14059S	PARTICIPANT	\N	PRESENT	0
325495	325382	98029W	PARTICIPANT	\N	PRESENT	0
325496	325382	11101A	PARTICIPANT	\N	PRESENT	0
325497	325382	14239U	PARTICIPANT	\N	PRESENT	0
325498	325382	04092N	PARTICIPANT	\N	PRESENT	0
325499	325382	19643A	PARTICIPANT	\N	PRESENT	0
325500	325382	14355X	PARTICIPANT	\N	PRESENT	0
325501	325382	14253S	PARTICIPANT	\N	PRESENT	0
325502	325382	14193X	PARTICIPANT	\N	PRESENT	0
325503	325382	19349W	PARTICIPANT	\N	PRESENT	0
325504	325382	08012N	PARTICIPANT	\N	PRESENT	0
325505	325382	14038Y	PARTICIPANT	\N	PRESENT	0
325506	325382	19683J	PARTICIPANT	\N	PRESENT	0
325507	325382	19709B	PARTICIPANT	\N	PRESENT	0
325508	325382	08053X	PARTICIPANT	\N	PRESENT	0
325509	325382	07034Q	PARTICIPANT	\N	PRESENT	0
325510	325382	19725B	PARTICIPANT	\N	PRESENT	0
325511	325382	80013X	PARTICIPANT	\N	PRESENT	0
325512	325382	19631V	PARTICIPANT	\N	PRESENT	0
325513	325382	15447F	PARTICIPANT	\N	PRESENT	0
325514	325382	14231L	PARTICIPANT	\N	PRESENT	0
325515	325382	19415P	PARTICIPANT	\N	PRESENT	0
325516	325382	19619A	PARTICIPANT	\N	PRESENT	0
325517	325382	98024R	PARTICIPANT	\N	PRESENT	0
325518	325382	11031D	PARTICIPANT	\N	PRESENT	0
325519	325382	01034P	PARTICIPANT	\N	PRESENT	0
325520	325382	14331P	PARTICIPANT	\N	PRESENT	0
325521	325382	19711U	PARTICIPANT	\N	PRESENT	0
325522	325382	19515S	PARTICIPANT	\N	PRESENT	0
325523	325382	08047A	PARTICIPANT	\N	PRESENT	0
325524	325382	19621T	PARTICIPANT	\N	PRESENT	0
325525	325382	04086Q	PARTICIPANT	\N	PRESENT	0
325526	325382	95062K	PARTICIPANT	\N	PRESENT	0
325527	325382	11097X	PARTICIPANT	\N	PRESENT	0
325528	325382	19667J	PARTICIPANT	\N	PRESENT	0
325529	325382	08018U	PARTICIPANT	\N	PRESENT	0
325530	325382	19399H	PARTICIPANT	\N	PRESENT	0
325531	325382	11074Q	PARTICIPANT	\N	PRESENT	0
325532	325382	04018C	PARTICIPANT	\N	PRESENT	0
325533	325382	11080N	PARTICIPANT	\N	PRESENT	0
325534	325382	11067R	PARTICIPANT	\N	PRESENT	0
325535	325382	14281W	PARTICIPANT	\N	PRESENT	0
325536	325382	05008E	PARTICIPANT	\N	PRESENT	0
325537	325382	08043V	PARTICIPANT	\N	PRESENT	0
325538	325382	19669L	PARTICIPANT	\N	PRESENT	0
325539	325382	01062T	PARTICIPANT	\N	PRESENT	0
325540	325382	11049P	PARTICIPANT	\N	PRESENT	0
302978	289210	14193X	PARTICIPANT	\N	PRESENT	0
302979	289210	19585H	PARTICIPANT	\N	PRESENT	0
302980	289210	14111D	PARTICIPANT	\N	PRESENT	0
302981	289210	14237S	PARTICIPANT	\N	PRESENT	0
302986	289210	11049P	PARTICIPANT	\N	PRESENT	0
302983	289210	14173T	PARTICIPANT	\N	PRESENT	0
302984	289210	19447X	PARTICIPANT	\N	PRESENT	0
302985	289210	19573D	PARTICIPANT	\N	PRESENT	0
302987	289210	19631V	PARTICIPANT	\N	PRESENT	0
302988	289210	11074Q	PARTICIPANT	\N	PRESENT	0
302989	289210	11110B	PARTICIPANT	\N	PRESENT	0
302990	289210	98035U	PARTICIPANT	\N	PRESENT	0
302991	289210	14159V	PARTICIPANT	\N	PRESENT	0
302992	289210	04049K	PARTICIPANT	\N	PRESENT	0
302993	289210	14229S	PARTICIPANT	\N	PRESENT	0
302994	289210	14147R	PARTICIPANT	\N	PRESENT	0
302995	289210	14065Q	PARTICIPANT	\N	PRESENT	0
302996	289210	14217N	PARTICIPANT	\N	PRESENT	0
302997	289210	11027H	PARTICIPANT	\N	PRESENT	0
302998	289210	08052W	PARTICIPANT	\N	PRESENT	0
302999	289210	19581D	PARTICIPANT	\N	PRESENT	0
303000	289210	08038Y	PARTICIPANT	\N	PRESENT	0
303001	289210	08045X	PARTICIPANT	\N	PRESENT	0
303002	289210	19747H	PARTICIPANT	\N	PRESENT	0
303003	289210	14239U	PARTICIPANT	\N	PRESENT	0
303004	289210	14038Y	PARTICIPANT	\N	PRESENT	0
303005	289210	19669L	PARTICIPANT	\N	PRESENT	0
303006	289210	19467C	PARTICIPANT	\N	PRESENT	0
303007	289210	19715Y	PARTICIPANT	\N	PRESENT	0
303008	289210	18083K	PARTICIPANT	\N	PRESENT	0
303009	289210	19599P	PARTICIPANT	\N	PRESENT	0
303010	289210	12016W	PARTICIPANT	\N	PRESENT	0
303011	289210	17779H	PARTICIPANT	\N	PRESENT	0
303012	289210	19647E	PARTICIPANT	\N	PRESENT	0
303013	289210	14197C	PARTICIPANT	\N	PRESENT	0
303014	289210	19729F	PARTICIPANT	\N	PRESENT	0
303015	289210	19649G	PARTICIPANT	\N	PRESENT	0
303016	289210	14265W	PARTICIPANT	\N	PRESENT	0
303017	289210	11045K	PARTICIPANT	\N	PRESENT	0
303018	289210	14213J	PARTICIPANT	\N	PRESENT	0
303019	289210	11054L	PARTICIPANT	\N	PRESENT	0
303020	289210	14329V	PARTICIPANT	\N	PRESENT	0
303021	289210	95015C	PARTICIPANT	\N	PRESENT	0
303022	289210	14357A	PARTICIPANT	\N	PRESENT	0
303023	289210	19675J	PARTICIPANT	\N	PRESENT	0
303024	289210	19727D	PARTICIPANT	\N	PRESENT	0
303025	289210	11066Q	PARTICIPANT	\N	PRESENT	0
303026	289210	14093U	PARTICIPANT	\N	PRESENT	0
303027	289210	19383Y	PARTICIPANT	\N	PRESENT	0
303028	289210	14281W	PARTICIPANT	\N	PRESENT	0
303029	289210	08043V	PARTICIPANT	\N	PRESENT	0
303030	289210	19701S	PARTICIPANT	\N	PRESENT	0
303031	289210	11104D	PARTICIPANT	\N	PRESENT	0
303127	289210	19705W	PARTICIPANT	\N	PRESENT	0
303033	289210	08068F	PARTICIPANT	\N	PRESENT	0
303112	289210	19671E	PARTICIPANT	\N	PRESENT	0
303115	289210	14059S	PARTICIPANT	\N	PRESENT	0
303036	289210	19531S	PARTICIPANT	\N	PRESENT	0
303037	289210	19683J	PARTICIPANT	\N	PRESENT	0
303116	289210	08062Y	PARTICIPANT	\N	PRESENT	0
303039	289210	19489J	PARTICIPANT	\N	PRESENT	0
303040	289210	14061L	PARTICIPANT	\N	PRESENT	0
303041	289210	14121F	PARTICIPANT	\N	PRESENT	0
303042	289210	14085U	PARTICIPANT	\N	PRESENT	0
303119	289210	19443T	PARTICIPANT	\N	PRESENT	0
303044	289210	08017T	PARTICIPANT	\N	PRESENT	0
303130	289210	11026G	PARTICIPANT	\N	PRESENT	0
303046	289210	19525U	PARTICIPANT	\N	PRESENT	0
303047	289210	08015R	PARTICIPANT	\N	PRESENT	0
303117	289210	14211G	PARTICIPANT	\N	PRESENT	0
303049	289210	19725B	PARTICIPANT	\N	PRESENT	0
303050	289210	14355X	PARTICIPANT	\N	PRESENT	0
303051	289210	14051J	PARTICIPANT	\N	PRESENT	0
303052	289210	14227Q	PARTICIPANT	\N	PRESENT	0
303053	289210	19657G	PARTICIPANT	\N	PRESENT	0
303123	289210	04038G	PARTICIPANT	\N	PRESENT	0
303055	289210	19413M	PARTICIPANT	\N	PRESENT	0
303056	289210	04088S	PARTICIPANT	\N	PRESENT	0
303057	289210	19689Q	PARTICIPANT	\N	PRESENT	0
303058	289210	19503N	PARTICIPANT	\N	PRESENT	0
303059	289210	19663E	PARTICIPANT	\N	PRESENT	0
303060	289210	19591F	PARTICIPANT	\N	PRESENT	0
303061	289210	11067R	PARTICIPANT	\N	PRESENT	0
303062	289210	19507S	PARTICIPANT	\N	PRESENT	0
303063	289210	19551W	PARTICIPANT	\N	PRESENT	0
303064	289210	14063N	PARTICIPANT	\N	PRESENT	0
303128	289210	04018C	PARTICIPANT	\N	PRESENT	0
303066	289210	11065P	PARTICIPANT	\N	PRESENT	0
303067	289210	14207L	PARTICIPANT	\N	PRESENT	0
303068	289210	14109K	PARTICIPANT	\N	PRESENT	0
303069	289210	14257W	PARTICIPANT	\N	PRESENT	0
303070	289210	14030Q	PARTICIPANT	\N	PRESENT	0
303071	289210	14179A	PARTICIPANT	\N	PRESENT	0
303072	289210	08061X	PARTICIPANT	\N	PRESENT	0
303073	289210	01034P	PARTICIPANT	\N	PRESENT	0
303074	289210	08009T	PARTICIPANT	\N	PRESENT	0
303075	289210	19369B	PARTICIPANT	\N	PRESENT	0
303076	289210	11053K	PARTICIPANT	\N	PRESENT	0
303077	289210	19611R	PARTICIPANT	\N	PRESENT	0
303118	289210	19707Y	PARTICIPANT	\N	PRESENT	0
303079	289210	19511N	PARTICIPANT	\N	PRESENT	0
303080	289210	19737F	PARTICIPANT	\N	PRESENT	0
303081	289210	14205J	PARTICIPANT	\N	PRESENT	0
303082	289210	19699S	PARTICIPANT	\N	PRESENT	0
303083	289210	19619A	PARTICIPANT	\N	PRESENT	0
303084	289210	19721W	PARTICIPANT	\N	PRESENT	0
303085	289210	04035D	PARTICIPANT	\N	PRESENT	0
303086	289210	08056B	PARTICIPANT	\N	PRESENT	0
303087	289210	19735D	PARTICIPANT	\N	PRESENT	0
303088	289210	16685X	PARTICIPANT	\N	PRESENT	0
303089	289210	19441R	PARTICIPANT	\N	PRESENT	0
303090	289210	19479G	PARTICIPANT	\N	PRESENT	0
303091	289210	04040A	PARTICIPANT	\N	PRESENT	0
303092	289210	14042U	PARTICIPANT	\N	PRESENT	0
303093	289210	19749K	PARTICIPANT	\N	PRESENT	0
303114	289210	19367Y	PARTICIPANT	\N	PRESENT	0
303095	289210	14103D	PARTICIPANT	\N	PRESENT	0
303096	289210	19739H	PARTICIPANT	\N	PRESENT	0
303097	289210	14073Q	PARTICIPANT	\N	PRESENT	0
303098	289210	14083S	PARTICIPANT	\N	PRESENT	0
303099	289210	14089Y	PARTICIPANT	\N	PRESENT	0
303100	289210	19521Q	PARTICIPANT	\N	PRESENT	0
303101	289210	19745F	PARTICIPANT	\N	PRESENT	0
303102	289210	14255U	PARTICIPANT	\N	PRESENT	0
303103	289210	11085T	PARTICIPANT	\N	PRESENT	0
303104	289210	86034E	PARTICIPANT	\N	PRESENT	0
303105	289210	04061F	PARTICIPANT	\N	PRESENT	0
303106	289210	04070G	PARTICIPANT	\N	PRESENT	0
303107	289210	01024M	PARTICIPANT	\N	PRESENT	0
303108	289210	11099A	PARTICIPANT	\N	PRESENT	0
303109	289210	01025N	PARTICIPANT	\N	PRESENT	0
303110	289210	14327T	PARTICIPANT	\N	PRESENT	0
303111	289210	19621T	PARTICIPANT	\N	PRESENT	0
303113	289210	05008E	PARTICIPANT	\N	PRESENT	0
303124	289210	98029W	PARTICIPANT	\N	PRESENT	0
303125	289210	98024R	PARTICIPANT	\N	PRESENT	0
303126	289210	14041T	PARTICIPANT	\N	PRESENT	0
303376	289211	04044E	PARTICIPANT	\N	PRESENT	0
303131	289210	19335Q	PARTICIPANT	\N	PRESENT	0
303377	289211	19711U	PARTICIPANT	\N	PRESENT	0
303378	289211	04035D	PARTICIPANT	\N	PRESENT	0
303379	289211	11043H	PARTICIPANT	\N	PRESENT	0
303380	289211	19679N	PARTICIPANT	\N	PRESENT	0
303381	289211	08069G	PARTICIPANT	\N	PRESENT	0
303382	289211	19703U	PARTICIPANT	\N	PRESENT	0
303383	289211	14033T	PARTICIPANT	\N	PRESENT	0
303384	289211	19573D	PARTICIPANT	\N	PRESENT	0
303385	289211	19575F	PARTICIPANT	\N	PRESENT	0
303386	289211	11103C	PARTICIPANT	\N	PRESENT	0
303387	289211	14038Y	PARTICIPANT	\N	PRESENT	0
303388	289211	19443T	PARTICIPANT	\N	PRESENT	0
303389	289211	08068F	PARTICIPANT	\N	PRESENT	0
303390	289211	19507S	PARTICIPANT	\N	PRESENT	0
303391	289211	14121F	PARTICIPANT	\N	PRESENT	0
303392	289211	08043V	PARTICIPANT	\N	PRESENT	0
303393	289211	19467C	PARTICIPANT	\N	PRESENT	0
303394	289211	14229S	PARTICIPANT	\N	PRESENT	0
303395	289211	19515S	PARTICIPANT	\N	PRESENT	0
303396	289211	19631V	PARTICIPANT	\N	PRESENT	0
303397	289211	19421M	PARTICIPANT	\N	PRESENT	0
303401	289211	19651A	PARTICIPANT	\N	PRESENT	0
303399	289211	19637C	PARTICIPANT	\N	PRESENT	0
303400	289211	14265W	PARTICIPANT	\N	PRESENT	0
303402	289211	14071N	PARTICIPANT	\N	PRESENT	0
303403	289211	11090Q	PARTICIPANT	\N	PRESENT	0
303404	289211	14187A	PARTICIPANT	\N	PRESENT	0
303405	289211	14073Q	PARTICIPANT	\N	PRESENT	0
303406	289211	19563B	PARTICIPANT	\N	PRESENT	0
314441	314188	04057K	PARTICIPANT	\N	EXCUSE	0
315047	314189	19333N	PARTICIPANT	\N	PRESENT	0
315048	314189	04057K	PARTICIPANT	\N	PRESENT	0
315050	314189	01057W	PARTICIPANT	\N	PRESENT	0
315051	314189	96004D	PRESIDENT	0	PRESENT	0
315052	314189	01058X	PARTICIPANT	\N	PRESENT	0
315053	314189	98050T	PARTICIPANT	\N	PRESENT	0
315054	314189	04097T	PARTICIPANT	\N	PRESENT	0
315055	314189	14221J	PARTICIPANT	\N	PRESENT	0
315056	314754	08058D	PARTICIPANT	\N	PRESENT	0
315057	314754	08053X	PARTICIPANT	\N	PRESENT	0
315058	314754	14121F	PARTICIPANT	\N	PRESENT	0
315059	314754	11109J	PARTICIPANT	\N	PRESENT	0
315060	314754	19503N	PARTICIPANT	\N	PRESENT	0
315061	314754	19413M	PARTICIPANT	\N	PRESENT	0
315062	314754	19689Q	PARTICIPANT	\N	PRESENT	0
315063	314754	11027H	PARTICIPANT	\N	PRESENT	0
315064	314754	19725B	PARTICIPANT	\N	PRESENT	0
315065	314754	19647E	PARTICIPANT	\N	PRESENT	0
315066	314754	19549D	PARTICIPANT	\N	PRESENT	0
315067	314189	14097Y	PARTICIPANT	\N	PRESENT	0
315068	314189	01062T	PARTICIPANT	\N	PRESENT	0
315069	314189	14001X	PARTICIPANT	\N	PRESENT	0
315070	314189	14205J	PARTICIPANT	\N	PRESENT	0
315071	314189	08031R	PARTICIPANT	\N	PRESENT	0
315072	314754	14081Q	PARTICIPANT	\N	PRESENT	0
315073	314754	11072N	PARTICIPANT	\N	PRESENT	0
315074	314754	14107H	PARTICIPANT	\N	PRESENT	0
315075	314754	14159V	PARTICIPANT	\N	PRESENT	0
315076	314754	19585H	PARTICIPANT	\N	PRESENT	0
315077	314754	14111D	PARTICIPANT	\N	PRESENT	0
315078	314754	17589D	PARTICIPANT	\N	PRESENT	0
315079	314754	19629C	PARTICIPANT	\N	PRESENT	0
315080	314754	19563B	PARTICIPANT	\N	PRESENT	0
315081	314754	19289C	PARTICIPANT	\N	PRESENT	0
315082	314754	19760E	PARTICIPANT	\N	PRESENT	0
315169	314754	11070L	PARTICIPANT	\N	PRESENT	0
315170	314754	14231L	PARTICIPANT	\N	PRESENT	0
315171	314754	14055N	PARTICIPANT	\N	PRESENT	0
315172	314754	14069U	PARTICIPANT	\N	PRESENT	0
315173	314754	19383Y	PARTICIPANT	\N	PRESENT	0
315174	314754	08045X	PARTICIPANT	\N	PRESENT	0
315175	314754	19347U	PARTICIPANT	\N	PRESENT	0
315176	314754	19762G	PARTICIPANT	\N	PRESENT	0
315177	314754	14021P	PARTICIPANT	\N	PRESENT	0
315178	314754	80013X	PARTICIPANT	\N	PRESENT	0
315179	314754	11049P	PARTICIPANT	\N	PRESENT	0
315180	314754	08056B	PARTICIPANT	\N	PRESENT	0
315181	314754	11056N	PARTICIPANT	\N	PRESENT	0
315182	314307	19593H	PARTICIPANT	\N	PRESENT	0
315183	314307	04070G	PRESIDENT	0	PRESENT	0
315184	314307	19699S	PARTICIPANT	\N	PRESENT	0
315185	314307	14061L	PARTICIPANT	\N	PRESENT	0
315186	314307	19533U	PARTICIPANT	\N	PRESENT	0
315187	314307	19611R	PARTICIPANT	\N	PRESENT	0
315188	314307	08043V	PARTICIPANT	\N	PRESENT	0
315189	314307	89017R	PARTICIPANT	\N	PRESENT	0
315190	314307	87003B	PARTICIPANT	\N	PRESENT	0
315191	314307	14030Q	PARTICIPANT	\N	PRESENT	0
315192	314307	14241N	PARTICIPANT	\N	PRESENT	0
315193	314307	19573D	PARTICIPANT	\N	PRESENT	0
315194	314307	14039A	PARTICIPANT	\N	PRESENT	0
315195	314307	14107H	PARTICIPANT	\N	PRESENT	0
315196	314307	14063N	PARTICIPANT	\N	PRESENT	0
315197	314307	14109K	PARTICIPANT	\N	PRESENT	0
315198	314307	14123H	PARTICIPANT	\N	PRESENT	0
315199	314307	11104D	PARTICIPANT	\N	PRESENT	0
315200	314307	19758L	PARTICIPANT	\N	PRESENT	0
315201	314307	08039A	PARTICIPANT	\N	PRESENT	0
315202	314307	08031R	PARTICIPANT	\N	PRESENT	0
315203	314307	04057K	PARTICIPANT	\N	PRESENT	0
315204	314754	88008L	PARTICIPANT	\N	PRESENT	0
315205	314754	19657G	PARTICIPANT	\N	PRESENT	0
315220	314754	14193X	PARTICIPANT	\N	PRESENT	0
315221	314754	11066Q	PARTICIPANT	\N	PRESENT	0
315222	314754	19565D	PARTICIPANT	\N	PRESENT	0
315223	314754	19739H	PARTICIPANT	\N	PRESENT	0
315224	314754	14237S	PARTICIPANT	\N	PRESENT	0
315250	314754	14059S	PARTICIPANT	\N	PRESENT	0
315251	314754	14249W	PARTICIPANT	\N	PRESENT	0
315336	309281	01028R	PARTICIPANT	\N	PRESENT	0
315337	309281	19565D	PARTICIPANT	\N	PRESENT	0
315338	309281	11067R	PARTICIPANT	\N	PRESENT	0
315339	309281	19549D	PARTICIPANT	\N	PRESENT	0
315340	309281	11033F	PARTICIPANT	\N	PRESENT	0
315341	309281	19585H	PARTICIPANT	\N	PRESENT	0
315342	309281	19691J	PARTICIPANT	\N	PRESENT	0
315343	309281	19441R	PARTICIPANT	\N	PRESENT	0
315344	309281	19347U	PARTICIPANT	\N	PRESENT	0
315345	309281	19719D	PARTICIPANT	\N	PRESENT	0
315346	309281	14073Q	PARTICIPANT	\N	PRESENT	0
315347	309281	19747H	PARTICIPANT	\N	PRESENT	0
315348	309281	05008E	PARTICIPANT	\N	PRESENT	0
315349	309281	14215L	PARTICIPANT	\N	PRESENT	0
315350	309281	01024M	PARTICIPANT	\N	PRESENT	0
315351	309281	14179A	PARTICIPANT	\N	PRESENT	0
315352	309281	14219Q	PARTICIPANT	\N	PRESENT	0
315353	309281	19621T	PARTICIPANT	\N	PRESENT	0
315354	309281	14237S	PARTICIPANT	\N	PRESENT	0
315355	309281	04044E	PARTICIPANT	\N	PRESENT	0
315356	309281	04038G	PARTICIPANT	\N	PRESENT	0
315357	309281	04049K	PARTICIPANT	\N	PRESENT	0
315358	309281	14217N	PARTICIPANT	\N	PRESENT	0
315359	309281	14329V	PARTICIPANT	\N	PRESENT	0
315360	309281	19675J	PARTICIPANT	\N	PRESENT	0
315361	309281	19383Y	PARTICIPANT	\N	PRESENT	0
315362	309281	11097X	PARTICIPANT	\N	PRESENT	0
315363	309281	19768N	PARTICIPANT	\N	PRESENT	0
315364	309281	14213J	PARTICIPANT	\N	PRESENT	0
315365	309281	14355X	PARTICIPANT	\N	PRESENT	0
315366	309281	14135M	PARTICIPANT	\N	PRESENT	0
315367	309281	07029T	PARTICIPANT	\N	PRESENT	0
315368	309281	04088S	PARTICIPANT	\N	PRESENT	0
315369	309281	08068F	PARTICIPANT	\N	PRESENT	0
315370	309281	19415P	PARTICIPANT	\N	PRESENT	0
315371	309281	19723Y	PARTICIPANT	\N	PRESENT	0
315372	309281	14281W	PARTICIPANT	\N	PRESENT	0
315373	309281	19467C	PARTICIPANT	\N	PRESENT	0
315374	309281	14133K	PARTICIPANT	\N	PRESENT	0
315375	309281	14119M	PARTICIPANT	\N	PRESENT	0
315376	309281	14033T	PARTICIPANT	\N	PRESENT	0
315377	309281	19447X	PARTICIPANT	\N	PRESENT	0
315378	309281	19703U	PARTICIPANT	\N	PRESENT	0
315379	309281	19515S	PARTICIPANT	\N	PRESENT	0
315380	309281	17637T	PARTICIPANT	\N	PRESENT	0
315381	309281	19679N	PARTICIPANT	\N	PRESENT	0
315382	309281	08020N	PARTICIPANT	\N	PRESENT	0
315383	309281	11048N	PARTICIPANT	\N	PRESENT	0
315384	309281	14147R	PARTICIPANT	\N	PRESENT	0
315385	309281	19711U	PARTICIPANT	\N	PRESENT	0
315386	309281	14357A	PARTICIPANT	\N	PRESENT	0
315387	309281	08015R	PARTICIPANT	\N	PRESENT	0
315388	309281	14199E	PARTICIPANT	\N	PRESENT	0
315389	309281	19335Q	PARTICIPANT	\N	PRESENT	0
315390	309281	11053K	PARTICIPANT	\N	PRESENT	0
315391	309281	19569H	PARTICIPANT	\N	PRESENT	0
315392	309281	14187A	PARTICIPANT	\N	PRESENT	0
315393	309281	19521Q	PARTICIPANT	\N	PRESENT	0
315394	309281	14026U	PARTICIPANT	\N	PRESENT	0
315395	309281	19741B	PARTICIPANT	\N	PRESENT	0
315410	309281	19762G	PARTICIPANT	\N	PRESENT	0
315411	309281	14105F	PARTICIPANT	\N	PRESENT	0
315412	309281	14083S	PARTICIPANT	\N	PRESENT	0
315413	309281	14157T	PARTICIPANT	\N	PRESENT	0
315414	309281	19543W	PARTICIPANT	\N	PRESENT	0
315415	309281	14173T	PARTICIPANT	\N	PRESENT	0
315416	309281	11049P	PARTICIPANT	\N	PRESENT	0
315417	309281	14327T	PARTICIPANT	\N	PRESENT	0
315418	309281	19507S	PARTICIPANT	\N	PRESENT	0
315420	309281	14255U	PARTICIPANT	\N	PRESENT	0
315421	309281	01025N	PARTICIPANT	\N	PRESENT	0
315422	309281	08056B	PARTICIPANT	\N	PRESENT	0
315423	309281	14030Q	PARTICIPANT	\N	PRESENT	0
315424	309281	14221J	PARTICIPANT	\N	PRESENT	0
315425	309281	14191V	PARTICIPANT	\N	PRESENT	0
315426	309281	14021P	PARTICIPANT	\N	PRESENT	0
315334	309281	04059M	PARTICIPANT	\N	PRESENT	0
315335	309281	08045X	PARTICIPANT	\N	PRESENT	0
307017	307016	08044W	PARTICIPANT	\N	PRESENT	0
308576	308568	04059M	PARTICIPANT	\N	PRESENT	0
308540	308538	14038Y	PARTICIPANT	\N	PRESENT	0
308541	308538	11056N	PARTICIPANT	\N	PRESENT	0
308542	308538	04008A	PARTICIPANT	\N	PRESENT	0
308543	308538	08038Y	PARTICIPANT	\N	PRESENT	0
308544	308538	14187A	PARTICIPANT	\N	PRESENT	0
308545	308538	19591F	PARTICIPANT	\N	PRESENT	0
308546	308538	08039A	PARTICIPANT	\N	PRESENT	0
308547	308538	01043Q	PARTICIPANT	\N	PRESENT	0
308548	308538	11090Q	PRESIDENT	0	PRESENT	0
308549	308538	19735D	PARTICIPANT	\N	PRESENT	0
308550	308538	11012A	PARTICIPANT	\N	PRESENT	0
308551	308538	14229S	PARTICIPANT	\N	PRESENT	0
308552	308538	14157T	PARTICIPANT	\N	PRESENT	0
308554	308553	04059M	PARTICIPANT	\N	PRESENT	0
308555	308553	05008E	PARTICIPANT	\N	PRESENT	0
308556	308553	14069U	PARTICIPANT	\N	PRESENT	0
308557	308553	19629C	PARTICIPANT	\N	PRESENT	0
308558	308553	14151M	PARTICIPANT	\N	PRESENT	0
308608	307457	19735D	PARTICIPANT	\N	PRESENT	0
308560	308553	11083R	PARTICIPANT	\N	PRESENT	0
308561	308553	19699S	PARTICIPANT	\N	PRESENT	0
308562	308553	08039A	PARTICIPANT	\N	PRESENT	0
308563	308553	04070G	PARTICIPANT	\N	PRESENT	0
308564	308553	19593H	PARTICIPANT	\N	PRESENT	0
308565	308553	19573D	PARTICIPANT	\N	PRESENT	0
308566	308553	07034Q	PRESIDENT	0	PRESENT	0
308567	308553	14229S	PARTICIPANT	\N	PRESENT	0
308577	308568	05008E	PARTICIPANT	\N	PRESENT	0
308578	308568	14069U	PARTICIPANT	\N	PRESENT	0
308579	308568	19629C	PARTICIPANT	\N	PRESENT	0
308580	308568	14151M	PARTICIPANT	\N	PRESENT	0
308581	308568	08018U	PARTICIPANT	\N	PRESENT	0
308582	308568	11083R	PARTICIPANT	\N	PRESENT	0
308583	308568	19699S	PARTICIPANT	\N	PRESENT	0
308584	308568	08039A	PARTICIPANT	\N	PRESENT	0
308585	308568	04070G	PRESIDENT	0	PRESENT	0
308586	308568	19593H	PARTICIPANT	\N	PRESENT	0
308587	308568	19573D	PARTICIPANT	\N	PRESENT	0
308588	308568	07034Q	PARTICIPANT	\N	PRESENT	0
308589	308568	14229S	PARTICIPANT	\N	PRESENT	0
308610	308609	14073Q	PARTICIPANT	\N	PRESENT	0
308817	308816	11043H	PARTICIPANT	\N	PRESENT	0
308818	308816	08012N	PARTICIPANT	\N	PRESENT	0
308819	308816	14241N	PARTICIPANT	\N	PRESENT	0
308820	308816	19711U	PARTICIPANT	\N	PRESENT	0
308821	308816	14107H	PARTICIPANT	\N	PRESENT	0
308822	308816	19643A	PARTICIPANT	\N	PRESENT	0
309681	307423	05008E	PARTICIPANT	\N	PRESENT	0
309682	307423	14329V	PARTICIPANT	\N	PRESENT	0
309683	307423	19253P	PARTICIPANT	\N	PRESENT	0
309684	307423	19301E	PARTICIPANT	\N	PRESENT	0
309685	307423	04057K	PARTICIPANT	\N	PRESENT	0
309686	307423	19719D	PARTICIPANT	\N	PRESENT	0
309687	307423	19629C	PARTICIPANT	\N	PRESENT	0
309688	307423	14257W	PARTICIPANT	\N	PRESENT	0
309689	307423	19581D	PARTICIPANT	\N	PRESENT	0
309690	307423	14223L	PARTICIPANT	\N	PRESENT	0
309691	307423	19575F	PARTICIPANT	\N	PRESENT	0
309692	307423	17583W	PARTICIPANT	\N	PRESENT	0
309693	307423	98022P	PARTICIPANT	\N	PRESENT	0
309694	307423	19549D	PARTICIPANT	\N	PRESENT	0
309695	307423	11054L	PARTICIPANT	\N	PRESENT	0
309696	307423	01028R	PARTICIPANT	\N	PRESENT	0
309697	307423	14065Q	PARTICIPANT	\N	PRESENT	0
309698	307423	19729F	PARTICIPANT	\N	PRESENT	0
309679	307423	08034U	PARTICIPANT	\N	PRESENT	0
309680	307423	11033F	PARTICIPANT	\N	PRESENT	0
309699	307423	08031R	PARTICIPANT	\N	PRESENT	0
309700	307423	19383Y	PARTICIPANT	\N	PRESENT	0
309701	307423	14123H	PARTICIPANT	\N	PRESENT	0
309703	307423	14119M	PARTICIPANT	\N	PRESENT	0
309704	307423	08038Y	PARTICIPANT	\N	PRESENT	0
309705	307423	11066Q	PARTICIPANT	\N	PRESENT	0
309706	307423	11101A	PARTICIPANT	\N	PRESENT	0
309707	307423	80013X	PARTICIPANT	\N	PRESENT	0
309708	307423	16685X	PARTICIPANT	\N	PRESENT	0
309709	307423	11070L	PARTICIPANT	\N	PRESENT	0
309710	307423	14083S	PARTICIPANT	\N	PRESENT	0
309711	307423	04034C	PARTICIPANT	\N	PRESENT	0
309712	307423	19573D	PARTICIPANT	\N	PRESENT	0
309713	307423	19447X	PARTICIPANT	\N	PRESENT	0
309714	307423	11012A	PARTICIPANT	\N	PRESENT	0
309715	307423	08044W	PARTICIPANT	\N	PRESENT	0
309716	307423	11056N	PARTICIPANT	\N	PRESENT	0
309717	307423	19649G	PARTICIPANT	\N	PRESENT	0
309718	307423	14251Q	PARTICIPANT	\N	PRESENT	0
309719	307423	19689Q	PARTICIPANT	\N	PRESENT	0
309720	307423	08015R	PARTICIPANT	\N	PRESENT	0
309721	307423	14135M	PARTICIPANT	\N	PRESENT	0
309722	307423	19415P	PARTICIPANT	\N	PRESENT	0
309723	307423	19687N	PARTICIPANT	\N	PRESENT	0
309724	307423	14061L	PARTICIPANT	\N	PRESENT	0
309727	307423	11064N	PARTICIPANT	\N	PRESENT	0
309728	307423	14031R	PARTICIPANT	\N	PRESENT	0
309729	307423	11031D	PARTICIPANT	\N	PRESENT	0
309730	307423	14107H	PARTICIPANT	\N	PRESENT	0
309731	307423	14121F	PARTICIPANT	\N	PRESENT	0
309732	307423	14281W	PARTICIPANT	\N	PRESENT	0
309733	307423	19489J	PARTICIPANT	\N	PRESENT	0
309734	307423	14151M	PARTICIPANT	\N	PRESENT	0
309735	307423	19691J	PARTICIPANT	\N	PRESENT	0
309736	307290	19443T	PARTICIPANT	\N	PRESENT	0
309737	307290	95030B	PARTICIPANT	\N	PRESENT	0
309738	307290	11080N	PARTICIPANT	\N	PRESENT	0
309739	307290	04034C	PARTICIPANT	\N	PRESENT	0
309740	307290	01058X	PARTICIPANT	\N	PRESENT	0
309741	307290	16685X	PARTICIPANT	\N	PRESENT	0
309742	307290	11027H	PARTICIPANT	\N	PRESENT	0
309743	307290	04042C	PRESIDENT	0	PRESENT	0
309744	307290	11054L	PARTICIPANT	\N	PRESENT	0
309745	307290	11066Q	PARTICIPANT	\N	PRESENT	0
309746	307290	19669L	PARTICIPANT	\N	PRESENT	0
309747	307290	11070L	PARTICIPANT	\N	PRESENT	0
309748	307290	08056B	PARTICIPANT	\N	PRESENT	0
309749	307290	95037J	PARTICIPANT	\N	PRESENT	0
309750	307290	19421M	PARTICIPANT	\N	PRESENT	0
309751	307290	08053X	PARTICIPANT	\N	PRESENT	0
309752	307290	08061X	PARTICIPANT	\N	PRESENT	0
309753	307290	08047A	PARTICIPANT	\N	PRESENT	0
309754	307290	04035D	PARTICIPANT	\N	PRESENT	0
309755	307290	14133K	PARTICIPANT	\N	PRESENT	0
309756	307290	14235Q	PARTICIPANT	\N	PRESENT	0
309757	307290	08058D	PARTICIPANT	\N	PRESENT	0
309758	307290	14028W	PARTICIPANT	\N	PRESENT	0
309759	307290	98018T	PARTICIPANT	\N	PRESENT	0
309760	307290	98022P	PARTICIPANT	\N	PRESENT	0
309761	307290	11064N	PARTICIPANT	\N	PRESENT	0
309762	307290	98050T	PARTICIPANT	\N	PRESENT	0
309763	307290	14211G	PARTICIPANT	\N	PRESENT	0
309764	307290	14255U	PARTICIPANT	\N	PRESENT	0
309765	307290	14079W	PARTICIPANT	\N	PRESENT	0
309796	309702	11081P	PARTICIPANT	\N	EXCUSE	0
309797	309702	08015R	PARTICIPANT	\N	EXCUSE	0
309798	309702	08062Y	PARTICIPANT	\N	EXCUSE	0
309799	309702	19563B	PARTICIPANT	\N	EXCUSE	0
309800	309702	08021P	PARTICIPANT	\N	EXCUSE	0
309806	307423	04043D	PARTICIPANT	\N	PRESENT	0
309807	307423	14213J	PARTICIPANT	\N	PRESENT	0
309808	307423	11097X	PARTICIPANT	\N	PRESENT	0
309809	307423	08016S	PARTICIPANT	\N	PRESENT	0
309810	307423	14001X	PARTICIPANT	\N	PRESENT	0
309811	307423	99004R	PARTICIPANT	\N	PRESENT	0
309812	307423	05012A	PARTICIPANT	\N	PRESENT	0
309813	307423	14030Q	PARTICIPANT	\N	PRESENT	0
309814	307423	19479G	PARTICIPANT	\N	PRESENT	0
309815	307423	10015M	PARTICIPANT	\N	PRESENT	0
309816	307423	19295A	PARTICIPANT	\N	PRESENT	0
309817	307423	14235Q	PARTICIPANT	\N	PRESENT	0
309818	307423	14071N	PARTICIPANT	\N	PRESENT	0
325541	325382	11041F	PARTICIPANT	\N	PRESENT	0
325542	325382	14097Y	PARTICIPANT	\N	PRESENT	0
325543	325382	14063N	PARTICIPANT	\N	PRESENT	0
325544	325382	01057W	PARTICIPANT	\N	PRESENT	0
325545	325382	19715Y	PARTICIPANT	\N	PRESENT	0
325546	325382	14159V	PARTICIPANT	\N	PRESENT	0
325547	325382	14031R	PARTICIPANT	\N	PRESENT	0
325548	325382	14257W	PARTICIPANT	\N	PRESENT	0
325549	325382	98050T	PARTICIPANT	\N	PRESENT	0
325550	325382	19585H	PARTICIPANT	\N	PRESENT	0
325551	325382	17589D	PARTICIPANT	\N	PRESENT	0
325552	325382	14079W	PARTICIPANT	\N	PRESENT	0
325553	325382	08021P	PARTICIPANT	\N	PRESENT	0
325554	325382	14119M	PARTICIPANT	\N	PRESENT	0
325555	325382	19301E	PARTICIPANT	\N	PRESENT	0
325556	325382	04045F	PARTICIPANT	\N	PRESENT	0
325557	325382	14201E	PARTICIPANT	\N	PRESENT	0
325558	325382	19467C	PARTICIPANT	\N	PRESENT	0
325559	325382	11103C	PARTICIPANT	\N	PRESENT	0
325560	325382	19527W	PARTICIPANT	\N	PRESENT	0
325561	325382	19693L	PARTICIPANT	\N	PRESENT	0
325562	325382	14081Q	PARTICIPANT	\N	PRESENT	0
325563	325382	14071N	PARTICIPANT	\N	PRESENT	0
325564	325382	14039A	PARTICIPANT	\N	PRESENT	0
325565	325382	04038G	PARTICIPANT	\N	PRESENT	0
325566	325382	12041X	PARTICIPANT	\N	PRESENT	0
325567	325382	19695N	PARTICIPANT	\N	PRESENT	0
325568	325382	07029T	PARTICIPANT	\N	PRESENT	0
325569	325382	11065P	PARTICIPANT	\N	PRESENT	0
325570	325382	19657G	PARTICIPANT	\N	PRESENT	0
325571	325382	19545Y	PARTICIPANT	\N	PRESENT	0
325572	325382	04042C	PARTICIPANT	\N	PRESENT	0
325573	325382	11077T	PARTICIPANT	\N	PRESENT	0
325574	325382	14187A	PARTICIPANT	\N	PRESENT	0
325575	325382	19649G	PARTICIPANT	\N	PRESENT	0
325576	325382	14265W	PARTICIPANT	\N	PRESENT	0
325577	325382	08035V	PARTICIPANT	\N	PRESENT	0
325578	325382	11066Q	PARTICIPANT	\N	PRESENT	0
325579	325382	19489J	PARTICIPANT	\N	PRESENT	0
325580	325382	08017T	PARTICIPANT	\N	PRESENT	0
325581	325382	11054L	PARTICIPANT	\N	PRESENT	0
325582	325382	19563B	PARTICIPANT	\N	PRESENT	0
325583	325382	08034U	PARTICIPANT	\N	PRESENT	0
325584	325382	11083R	PARTICIPANT	\N	PRESENT	0
325585	325382	14229S	PARTICIPANT	\N	PRESENT	0
325586	325382	14085U	PARTICIPANT	\N	PRESENT	0
325587	325382	08058D	PARTICIPANT	\N	PRESENT	0
325588	325382	04008A	PARTICIPANT	\N	PRESENT	0
325589	325382	11045K	PARTICIPANT	\N	PRESENT	0
325590	325382	19443T	PARTICIPANT	\N	PRESENT	0
325591	325382	19333N	PARTICIPANT	\N	PRESENT	0
325593	325382	12016W	PARTICIPANT	\N	PRESENT	0
325594	325382	19525U	PARTICIPANT	\N	PRESENT	0
325595	325382	11104D	PARTICIPANT	\N	PRESENT	0
325596	325382	14123H	PARTICIPANT	\N	PRESENT	0
325597	325382	08055A	PARTICIPANT	\N	PRESENT	0
325598	325382	11040E	PARTICIPANT	\N	PRESENT	0
325599	325382	14028W	PARTICIPANT	\N	PRESENT	0
325600	325382	19565D	PARTICIPANT	\N	PRESENT	0
325601	325382	97011G	PARTICIPANT	\N	PRESENT	0
325602	325382	19681G	PARTICIPANT	\N	PRESENT	0
325603	325382	19289C	PARTICIPANT	\N	PRESENT	0
325604	325382	19575F	PARTICIPANT	\N	PRESENT	0
325605	325382	11012A	PARTICIPANT	\N	PRESENT	0
325606	325382	19701S	PARTICIPANT	\N	PRESENT	0
325607	325382	08031R	PARTICIPANT	\N	PRESENT	0
325608	325382	14261S	PARTICIPANT	\N	PRESENT	0
325609	325382	08061X	PARTICIPANT	\N	PRESENT	0
325610	325382	92040Q	PARTICIPANT	\N	PRESENT	0
325611	325382	19347U	PARTICIPANT	\N	PRESENT	0
325612	325382	14021P	PARTICIPANT	\N	PRESENT	0
325613	325382	17583W	PARTICIPANT	\N	PRESENT	0
325614	325382	19737F	PARTICIPANT	\N	PRESENT	0
325615	325382	19691J	PARTICIPANT	\N	PRESENT	0
325616	325382	11053K	PARTICIPANT	\N	PRESENT	0
325617	325382	01024M	PARTICIPANT	\N	PRESENT	0
325618	325382	14267Y	PARTICIPANT	\N	PRESENT	0
325619	325382	04059M	PARTICIPANT	\N	PRESENT	0
325620	325382	19687N	PARTICIPANT	\N	PRESENT	0
325621	325382	14051J	PARTICIPANT	\N	PRESENT	0
325622	325382	07004J	PARTICIPANT	\N	PRESENT	0
325623	325382	11085T	PARTICIPANT	\N	PRESENT	0
325624	325382	19760E	PARTICIPANT	\N	PRESENT	0
325625	325382	14030Q	PARTICIPANT	\N	PRESENT	0
325626	325382	19697Q	PARTICIPANT	\N	PRESENT	0
325627	325382	14211G	PARTICIPANT	\N	PRESENT	0
325628	325382	19599P	PARTICIPANT	\N	PRESENT	0
325629	325382	14001X	PARTICIPANT	\N	PRESENT	0
325630	325382	19591F	PARTICIPANT	\N	PRESENT	0
325631	325382	04097T	PARTICIPANT	\N	PRESENT	0
325632	325382	19689Q	PARTICIPANT	\N	PRESENT	0
325633	325382	14093U	PARTICIPANT	\N	PRESENT	0
325634	325382	11033F	PARTICIPANT	\N	PRESENT	0
325635	325382	19705W	PARTICIPANT	\N	PRESENT	0
325636	325382	19577H	PARTICIPANT	\N	PRESENT	0
325637	325382	14053L	PARTICIPANT	\N	PRESENT	0
325638	325382	14225N	PARTICIPANT	\N	PRESENT	0
325639	325382	08044W	PARTICIPANT	\N	PRESENT	0
325640	325382	08056B	PARTICIPANT	\N	PRESENT	0
325641	325382	19663E	PARTICIPANT	\N	PRESENT	0
325642	325382	19647E	PARTICIPANT	\N	PRESENT	0
325643	325382	08048B	PARTICIPANT	\N	PRESENT	0
325644	325382	07033P	PARTICIPANT	\N	PRESENT	0
325645	325382	08038Y	PARTICIPANT	\N	PRESENT	0
325646	325382	14327T	PARTICIPANT	\N	PRESENT	0
325647	325382	01043Q	PARTICIPANT	\N	PRESENT	0
325648	325382	19581D	PARTICIPANT	\N	PRESENT	0
325649	325382	19729F	PARTICIPANT	\N	PRESENT	0
325650	325382	08068F	PARTICIPANT	\N	PRESENT	0
325651	325382	04033B	PARTICIPANT	\N	PRESENT	0
325652	325382	19511N	PARTICIPANT	\N	PRESENT	0
325653	325382	14042U	PARTICIPANT	\N	PRESENT	0
325654	325382	19721W	PARTICIPANT	\N	PRESENT	0
325655	325382	14275Y	PARTICIPANT	\N	PRESENT	0
325656	325382	01025N	PARTICIPANT	\N	PRESENT	0
325657	325382	14219Q	PARTICIPANT	\N	PRESENT	0
325658	325382	14227Q	PARTICIPANT	\N	PRESENT	0
325659	325382	05012A	PARTICIPANT	\N	PRESENT	0
325660	325382	19447X	PARTICIPANT	\N	PRESENT	0
325661	325382	19329S	PARTICIPANT	\N	PRESENT	0
325662	325382	11064N	PARTICIPANT	\N	PRESENT	0
325663	325382	11056N	PARTICIPANT	\N	PRESENT	0
325664	325382	19551W	PARTICIPANT	\N	PRESENT	0
325665	325382	19731Y	PARTICIPANT	\N	PRESENT	0
325666	325382	14055N	PARTICIPANT	\N	PRESENT	0
325667	325382	11090Q	PARTICIPANT	\N	PRESENT	0
325679	325382	14235Q	PARTICIPANT	\N	PRESENT	0
325697	325382	11115U	PARTICIPANT	\N	PRESENT	0
325670	325382	98018T	PARTICIPANT	\N	PRESENT	0
325671	325382	11048N	PARTICIPANT	\N	PRESENT	0
325672	325382	04044E	PARTICIPANT	\N	PRESENT	0
325673	325382	98022P	PARTICIPANT	\N	PRESENT	0
325674	325382	11109J	PARTICIPANT	\N	PRESENT	0
325675	325382	11026G	PARTICIPANT	\N	PRESENT	0
325676	325382	08045X	PARTICIPANT	\N	PRESENT	0
325677	325382	80027E	PARTICIPANT	\N	PRESENT	0
325678	325382	14069U	PARTICIPANT	\N	PRESENT	0
325702	325382	14115H	PARTICIPANT	\N	PRESENT	0
325681	325382	14107H	PARTICIPANT	\N	PRESENT	0
325682	325382	11070L	PARTICIPANT	\N	PRESENT	0
325683	325382	14103D	PARTICIPANT	\N	PRESENT	0
325684	325382	19719D	PARTICIPANT	\N	PRESENT	0
325685	325382	14249W	PARTICIPANT	\N	PRESENT	0
325687	325382	04043D	PARTICIPANT	\N	PRESENT	0
325705	325382	01028R	PARTICIPANT	\N	PRESENT	0
325689	325382	19747H	PARTICIPANT	\N	PRESENT	0
325690	325382	14241N	PARTICIPANT	\N	PRESENT	0
325691	325382	14033T	PARTICIPANT	\N	PRESENT	0
325692	325382	19573D	PARTICIPANT	\N	PRESENT	0
325693	325382	19335Q	PARTICIPANT	\N	PRESENT	0
325694	325382	14109K	PARTICIPANT	\N	PRESENT	0
325695	325382	08062Y	PARTICIPANT	\N	PRESENT	0
325696	325382	19741B	PARTICIPANT	\N	PRESENT	0
325698	325382	14111D	PARTICIPANT	\N	PRESENT	0
325699	325382	14251Q	PARTICIPANT	\N	PRESENT	0
325700	325382	18083K	PARTICIPANT	\N	PRESENT	0
325701	325382	19383Y	PARTICIPANT	\N	PRESENT	0
325703	325382	14105F	PARTICIPANT	\N	PRESENT	0
325704	325382	08010L	PARTICIPANT	\N	PRESENT	0
325706	325382	11027H	PARTICIPANT	\N	PRESENT	0
325707	325382	08060W	PARTICIPANT	\N	PRESENT	0
325708	325382	19549D	PARTICIPANT	\N	PRESENT	0
325709	325382	19733B	PARTICIPANT	\N	PRESENT	0
325710	325382	19735D	PARTICIPANT	\N	PRESENT	0
325711	325382	01060R	PARTICIPANT	\N	PRESENT	0
325712	325382	14121F	PARTICIPANT	\N	PRESENT	0
325713	325382	14041T	PARTICIPANT	\N	PRESENT	0
302164	295670	19575F	PARTICIPANT	\N	PRESENT	0
302165	295670	14255U	PARTICIPANT	\N	PRESENT	0
302167	295670	17589D	PARTICIPANT	\N	PRESENT	0
302169	295670	19691J	PARTICIPANT	\N	PRESENT	0
302170	295670	14179A	PARTICIPANT	\N	PRESENT	0
302173	295670	14265W	PARTICIPANT	\N	PRESENT	0
302186	295670	14119M	PARTICIPANT	\N	PRESENT	0
302188	295670	19349W	PARTICIPANT	\N	PRESENT	0
302229	302228	14239U	PARTICIPANT	\N	PRESENT	0
302230	302228	19667J	PARTICIPANT	\N	PRESENT	0
302231	302228	19701S	PARTICIPANT	\N	PRESENT	0
302232	302228	10006L	PARTICIPANT	\N	PRESENT	0
302233	302228	19565D	PARTICIPANT	\N	PRESENT	0
302234	302228	19723Y	PARTICIPANT	\N	PRESENT	0
302235	302228	14331P	PARTICIPANT	\N	PRESENT	0
302236	302228	95062K	PARTICIPANT	\N	PRESENT	0
302241	302240	11099A	PARTICIPANT	\N	PRESENT	0
303407	289211	04018C	PARTICIPANT	\N	PRESENT	0
303408	289211	19387D	PARTICIPANT	\N	PRESENT	0
303409	289211	14205J	PARTICIPANT	\N	PRESENT	0
303410	289211	04070G	PARTICIPANT	\N	PRESENT	0
303411	289211	19749K	PARTICIPANT	\N	PRESENT	0
303412	289211	99004R	PARTICIPANT	\N	PRESENT	0
303413	289211	19735D	PARTICIPANT	\N	PRESENT	0
303414	289211	19737F	PARTICIPANT	\N	PRESENT	0
303415	289211	11048N	PARTICIPANT	\N	PRESENT	0
303416	289211	04086Q	PARTICIPANT	\N	PRESENT	0
303417	289211	19667J	PARTICIPANT	\N	PRESENT	0
303418	289211	08034U	PARTICIPANT	\N	PRESENT	0
303419	289211	04088S	PARTICIPANT	\N	PRESENT	0
303420	289211	11097X	PARTICIPANT	\N	PRESENT	0
303446	289211	19479G	PARTICIPANT	\N	PRESENT	0
303425	289211	14042U	PARTICIPANT	\N	PRESENT	0
303423	289211	19695N	PARTICIPANT	\N	PRESENT	0
303424	289211	08031R	PARTICIPANT	\N	PRESENT	0
303426	289211	19565D	PARTICIPANT	\N	PRESENT	0
303427	289211	11065P	PARTICIPANT	\N	PRESENT	0
303428	289211	19289C	PARTICIPANT	\N	PRESENT	0
303429	289211	19591F	PARTICIPANT	\N	PRESENT	0
303430	289211	19335Q	PARTICIPANT	\N	PRESENT	0
303431	289211	14083S	PARTICIPANT	\N	PRESENT	0
303432	289211	19747H	PARTICIPANT	\N	PRESENT	0
303433	289211	08038Y	PARTICIPANT	\N	PRESENT	0
303434	289211	19657G	PARTICIPANT	\N	PRESENT	0
303435	289211	14217N	PARTICIPANT	\N	PRESENT	0
303436	289211	14059S	PARTICIPANT	\N	PRESENT	0
303437	289211	19727D	PARTICIPANT	\N	PRESENT	0
303438	289211	19599P	PARTICIPANT	\N	PRESENT	0
303439	289211	19441R	PARTICIPANT	\N	PRESENT	0
303440	289211	01057W	PARTICIPANT	\N	PRESENT	0
303441	289211	19369B	PARTICIPANT	\N	PRESENT	0
303442	289211	14030Q	PARTICIPANT	\N	PRESENT	0
303443	289211	05012A	PARTICIPANT	\N	PRESENT	0
303444	289211	11053K	PARTICIPANT	\N	PRESENT	0
303445	289211	19687N	PARTICIPANT	\N	PRESENT	0
303447	289211	08011M	PARTICIPANT	\N	PRESENT	0
303448	289211	19543W	PARTICIPANT	\N	PRESENT	0
303449	289211	11056N	PARTICIPANT	\N	PRESENT	0
303450	289211	19760E	PARTICIPANT	\N	PRESENT	0
303451	289211	19701S	PARTICIPANT	\N	PRESENT	0
303452	289211	04045F	PARTICIPANT	\N	PRESENT	0
303453	289211	14051J	PARTICIPANT	\N	PRESENT	0
303454	289211	14026U	PARTICIPANT	\N	PRESENT	0
303455	302874	11027H	PARTICIPANT	\N	PRESENT	0
303456	302874	19543W	PARTICIPANT	\N	PRESENT	0
303457	302874	89017R	PARTICIPANT	\N	PRESENT	0
303458	302874	19673G	PARTICIPANT	\N	PRESENT	0
303459	302874	01028R	PARTICIPANT	\N	PRESENT	0
303460	302874	19447X	PARTICIPANT	\N	PRESENT	0
303461	302874	19551W	PARTICIPANT	\N	PRESENT	0
303462	302874	14041T	PARTICIPANT	\N	PRESENT	0
303463	302874	14147R	PARTICIPANT	\N	PRESENT	0
303464	302874	14061L	PARTICIPANT	\N	PRESENT	0
303465	302874	14065Q	PARTICIPANT	\N	PRESENT	0
303466	302874	19649G	PARTICIPANT	\N	PRESENT	0
303467	302874	14073Q	PARTICIPANT	\N	PRESENT	0
303468	302874	08052W	PARTICIPANT	\N	PRESENT	0
303469	302874	04038G	PARTICIPANT	\N	PRESENT	0
303470	302874	11033F	PARTICIPANT	\N	PRESENT	0
303471	302874	14089Y	PARTICIPANT	\N	PRESENT	0
303472	302874	04059M	PARTICIPANT	\N	PRESENT	0
303473	302874	14069U	PARTICIPANT	\N	PRESENT	0
303474	302874	11049P	PARTICIPANT	\N	PRESENT	0
303475	302874	14207L	PARTICIPANT	\N	PRESENT	0
303476	302874	14211G	PARTICIPANT	\N	PRESENT	0
303477	302874	14021P	PARTICIPANT	\N	PRESENT	0
303478	302874	04071H	PARTICIPANT	\N	PRESENT	0
303479	302874	19581D	PARTICIPANT	\N	PRESENT	0
303480	302874	11074Q	PARTICIPANT	\N	PRESENT	0
303481	302874	19585H	PARTICIPANT	\N	PRESENT	0
303482	302874	04047H	PARTICIPANT	\N	PRESENT	0
303483	302874	05008E	PRESIDENT	0	PRESENT	0
303484	302874	19489J	PARTICIPANT	\N	PRESENT	0
303485	302874	19707Y	PARTICIPANT	\N	PRESENT	0
303486	302874	14281W	PARTICIPANT	\N	PRESENT	0
303487	302874	19367Y	PARTICIPANT	\N	PRESENT	0
303488	302874	14215L	PARTICIPANT	\N	PRESENT	0
303489	302874	14259Y	PARTICIPANT	\N	PRESENT	0
303490	302874	19511N	PARTICIPANT	\N	PRESENT	0
303491	302874	11072N	PARTICIPANT	\N	PRESENT	0
303492	302874	14329V	PARTICIPANT	\N	PRESENT	0
303493	302874	14111D	PARTICIPANT	\N	PRESENT	0
303494	302874	07034Q	PARTICIPANT	\N	PRESENT	0
303495	302874	08045X	PARTICIPANT	\N	PRESENT	0
303496	302874	11026G	PARTICIPANT	\N	PRESENT	0
303497	302874	19253P	PARTICIPANT	\N	PRESENT	0
303498	302874	19719D	PARTICIPANT	\N	PRESENT	0
303499	302874	04085P	PARTICIPANT	\N	PRESENT	0
303500	302874	19725B	PARTICIPANT	\N	PRESENT	0
303501	302874	19729F	PARTICIPANT	\N	PRESENT	0
303502	302874	19731Y	PARTICIPANT	\N	PRESENT	0
303503	302874	19629C	PARTICIPANT	\N	PRESENT	0
303504	302874	11083R	PARTICIPANT	\N	PRESENT	0
303553	289211	19383Y	PARTICIPANT	\N	PRESENT	0
303506	302874	14331P	PARTICIPANT	\N	PRESENT	0
303507	302874	11066Q	PARTICIPANT	\N	PRESENT	0
303508	302874	19671E	PARTICIPANT	\N	PRESENT	0
303509	302874	19675J	PARTICIPANT	\N	PRESENT	0
303510	302874	14157T	PARTICIPANT	\N	PRESENT	0
303511	302874	95067Q	PARTICIPANT	\N	PRESENT	0
303512	302874	19689Q	PARTICIPANT	\N	PRESENT	0
303513	302874	12041X	PARTICIPANT	\N	PRESENT	0
303514	302874	14223L	PARTICIPANT	\N	PRESENT	0
303515	302874	04045F	PARTICIPANT	\N	PRESENT	0
303516	302874	17779H	PARTICIPANT	\N	PRESENT	0
303517	302874	14237S	PARTICIPANT	\N	PRESENT	0
303518	302874	19703U	PARTICIPANT	\N	PRESENT	0
303519	302874	04049K	PARTICIPANT	\N	PRESENT	0
303520	302874	14055N	PARTICIPANT	\N	PRESENT	0
303521	302874	19705W	PARTICIPANT	\N	PRESENT	0
303522	302874	08017T	PARTICIPANT	\N	PRESENT	0
303523	302874	14193X	PARTICIPANT	\N	PRESENT	0
303524	302874	19503N	PARTICIPANT	\N	PRESENT	0
303525	302874	19593H	PARTICIPANT	\N	PRESENT	0
303526	302874	14103D	PARTICIPANT	\N	PRESENT	0
303527	302874	12016W	PARTICIPANT	\N	PRESENT	0
303528	302874	19745F	PARTICIPANT	\N	PRESENT	0
303529	302874	01024M	PARTICIPANT	\N	PRESENT	0
303530	302874	14179A	PARTICIPANT	\N	PRESENT	0
303531	302874	14053L	PARTICIPANT	\N	PRESENT	0
303532	302874	11085T	PARTICIPANT	\N	PRESENT	0
303533	302874	08056B	PARTICIPANT	\N	PRESENT	0
303534	302874	19611R	PARTICIPANT	\N	PRESENT	0
303535	302874	14257W	PARTICIPANT	\N	PRESENT	0
303536	302874	19383Y	PARTICIPANT	\N	PRESENT	0
303537	302874	14357A	PARTICIPANT	\N	PRESENT	0
303538	289211	19347U	PARTICIPANT	\N	PRESENT	0
303539	289211	19621T	PARTICIPANT	\N	PRESENT	0
303540	289211	14213J	PARTICIPANT	\N	PRESENT	0
303541	289211	04049K	PARTICIPANT	\N	PRESENT	0
303542	289211	17589D	PARTICIPANT	\N	PRESENT	0
303543	289211	11012A	PARTICIPANT	\N	PRESENT	0
303544	289211	14223L	PARTICIPANT	\N	PRESENT	0
303545	289211	14105F	PARTICIPANT	\N	PRESENT	0
303546	289211	14157T	PARTICIPANT	\N	PRESENT	0
303547	302874	19669L	PARTICIPANT	\N	PRESENT	0
303548	302874	14105F	PARTICIPANT	\N	PRESENT	0
303549	302874	19413M	PARTICIPANT	\N	PRESENT	0
303550	302874	08015R	PARTICIPANT	\N	PRESENT	0
303551	302874	14197C	PARTICIPANT	\N	PRESENT	0
303552	289211	19715Y	PARTICIPANT	\N	PRESENT	0
303554	289211	08015R	PARTICIPANT	\N	PRESENT	0
303555	289211	89017R	PARTICIPANT	\N	PRESENT	0
303556	289211	19367Y	PARTICIPANT	\N	PRESENT	0
303557	289211	14061L	PARTICIPANT	\N	PRESENT	0
303558	289211	19581D	PARTICIPANT	\N	PRESENT	0
316343	316342	14133K	PARTICIPANT	\N	PRESENT	0
316344	316342	96004D	PRESIDENT	0	PRESENT	0
316345	316342	08014Q	PARTICIPANT	\N	EXCUSE	0
316346	316342	14357A	PARTICIPANT	\N	PRESENT	0
316347	316342	14249W	PARTICIPANT	\N	PRESENT	0
316348	316342	11083R	PARTICIPANT	\N	PRESENT	0
316349	316342	14033T	PARTICIPANT	\N	PRESENT	0
316350	316342	14026U	PARTICIPANT	\N	PRESENT	0
316351	316342	19553Y	PARTICIPANT	\N	PRESENT	0
316352	316342	19725B	PARTICIPANT	\N	PRESENT	0
316353	316342	95037J	PARTICIPANT	\N	PRESENT	0
316354	316342	04097T	PARTICIPANT	\N	PRESENT	0
316355	316342	14097Y	PARTICIPANT	\N	PRESENT	0
316356	316342	14205J	PARTICIPANT	\N	PRESENT	0
316357	316342	14001X	PARTICIPANT	\N	PRESENT	0
316358	316342	14221J	PARTICIPANT	\N	PRESENT	0
316359	316342	04057K	PARTICIPANT	\N	PRESENT	0
316360	316342	19563B	PARTICIPANT	\N	PRESENT	0
316361	316342	19593H	PARTICIPANT	\N	PRESENT	0
316362	316342	14135M	PARTICIPANT	\N	PRESENT	0
316363	316342	14331P	PARTICIPANT	\N	PRESENT	0
318786	317525	08009T	PRESIDENT	0	PRESENT	0
318787	317525	19737F	PARTICIPANT	\N	PRESENT	0
318788	317525	19739H	PARTICIPANT	\N	PRESENT	0
318789	317525	04097T	PARTICIPANT	\N	PRESENT	0
318790	317525	19659J	PARTICIPANT	\N	PRESENT	0
318791	317525	14093U	PARTICIPANT	\N	EXCUSE	0
318792	317525	19637C	PARTICIPANT	\N	EXCUSE	0
318798	318797	04040A	PRESIDENT	0	PRESENT	0
318799	316532	04047H	PARTICIPANT	\N	PRESENT	0
318800	305885	19713W	PARTICIPANT	\N	EXCUSE	0
318802	316079	19553Y	PARTICIPANT	\N	PRESENT	0
318803	318797	14231L	PARTICIPANT	\N	EXCUSE	0
318805	316532	14021P	PARTICIPANT	\N	PRESENT	0
318806	318797	11101A	PARTICIPANT	\N	EXCUSE	0
319115	314179	14034U	PARTICIPANT	\N	PRESENT	0
319033	310950	19551W	PARTICIPANT	\N	PRESENT	0
319034	310950	02002K	PARTICIPANT	\N	PRESENT	0
319035	310950	19737F	PARTICIPANT	\N	PRESENT	0
319036	316498	02002K	PARTICIPANT	\N	PRESENT	0
319037	316498	19551W	PARTICIPANT	\N	PRESENT	0
319038	316498	19737F	PARTICIPANT	\N	PRESENT	0
319039	316534	19667J	PARTICIPANT	\N	PRESENT	0
319041	319040	08012N	PARTICIPANT	\N	PRESENT	0
319042	319040	11043H	PARTICIPANT	\N	PRESENT	0
319333	319327	04043D	PARTICIPANT	\N	PRESENT	0
319331	319327	11026G	PARTICIPANT	\N	PRESENT	0
319332	319327	19573D	PARTICIPANT	\N	PRESENT	0
319593	319592	10006L	PARTICIPANT	\N	PRESENT	0
319834	319833	11053K	PARTICIPANT	\N	PRESENT	0
319590	319583	10006L	PARTICIPANT	\N	PRESENT	0
319835	319833	14159V	PARTICIPANT	\N	PRESENT	0
319836	319833	05012A	PARTICIPANT	\N	PRESENT	0
320018	318025	08009T	PRESIDENT	0	PRESENT	0
320019	318025	96004D	PARTICIPANT	\N	EXCUSE	0
320020	318025	04097T	PARTICIPANT	\N	EXCUSE	0
320021	318025	19685L	PARTICIPANT	\N	EXCUSE	0
320022	318025	19659J	PARTICIPANT	\N	EXCUSE	0
320023	318025	14191V	PARTICIPANT	\N	PRESENT	0
320024	318025	14169X	PARTICIPANT	\N	PRESENT	0
320025	318025	19387D	PARTICIPANT	\N	PRESENT	0
320026	318025	08024S	PARTICIPANT	\N	PRESENT	0
320027	318025	98023Q	PARTICIPANT	\N	PRESENT	0
320028	318025	19333N	PARTICIPANT	\N	PRESENT	0
320029	318025	14029X	PARTICIPANT	\N	PRESENT	0
320030	318025	08060W	PARTICIPANT	\N	PRESENT	0
319116	314179	14179A	PARTICIPANT	\N	PRESENT	0
319117	314179	18083K	PARTICIPANT	\N	PRESENT	0
319118	314179	19731Y	PARTICIPANT	\N	PRESENT	0
319119	314179	14063N	PARTICIPANT	\N	PRESENT	0
319120	314179	14021P	PARTICIPANT	\N	PRESENT	0
319121	314179	05008E	PARTICIPANT	\N	PRESENT	0
319122	314179	19543W	PARTICIPANT	\N	PRESENT	0
319123	314179	19681G	PARTICIPANT	\N	PRESENT	0
319124	314179	19717B	PARTICIPANT	\N	PRESENT	0
319125	314179	14215L	PARTICIPANT	\N	PRESENT	0
319126	314179	07034Q	PARTICIPANT	\N	PRESENT	0
319127	314179	19383Y	PARTICIPANT	\N	PRESENT	0
319128	314179	08060W	PARTICIPANT	\N	PRESENT	0
319129	314179	19768N	PARTICIPANT	\N	PRESENT	0
319130	314179	14173T	PARTICIPANT	\N	PRESENT	0
319131	314179	08015R	PARTICIPANT	\N	PRESENT	0
319132	314179	19525U	PARTICIPANT	\N	PRESENT	0
319133	314179	08068F	PARTICIPANT	\N	PRESENT	0
319134	314179	14157T	PARTICIPANT	\N	PRESENT	0
319135	314179	14038Y	PARTICIPANT	\N	PRESENT	0
319136	314179	19413M	PARTICIPANT	\N	PRESENT	0
319137	314179	14257W	PARTICIPANT	\N	PRESENT	0
319138	314179	19737F	PARTICIPANT	\N	PRESENT	0
319139	314179	19441R	PARTICIPANT	\N	PRESENT	0
319140	314179	14231L	PARTICIPANT	\N	PRESENT	0
319141	314179	14237S	PARTICIPANT	\N	PRESENT	0
319142	314179	04018C	PARTICIPANT	\N	PRESENT	0
319143	314179	19701S	PARTICIPANT	\N	PRESENT	0
319144	314179	14061L	PARTICIPANT	\N	PRESENT	0
319145	314179	04038G	PARTICIPANT	\N	PRESENT	0
319146	314179	19447X	PARTICIPANT	\N	PRESENT	0
318765	317525	18083K	PARTICIPANT	\N	PRESENT	0
318766	317525	14237S	PARTICIPANT	\N	PRESENT	0
318767	317525	19551W	PARTICIPANT	\N	PRESENT	0
318768	317525	14051J	PARTICIPANT	\N	PRESENT	0
318769	317525	08060W	PARTICIPANT	\N	PRESENT	0
318770	317525	19347U	PARTICIPANT	\N	PRESENT	0
318771	317525	19503N	PARTICIPANT	\N	PRESENT	0
318772	317525	96004D	PARTICIPANT	\N	PRESENT	0
318773	317525	14157T	PARTICIPANT	\N	PRESENT	0
318774	317525	08024S	PARTICIPANT	\N	PRESENT	0
318775	317525	19681G	PARTICIPANT	\N	PRESENT	0
318776	317525	17637T	PARTICIPANT	\N	PRESENT	0
318777	317525	11065P	PARTICIPANT	\N	PRESENT	0
318778	317525	19525U	PARTICIPANT	\N	PRESENT	0
318779	317525	14038Y	PARTICIPANT	\N	PRESENT	0
318780	317525	14103D	PARTICIPANT	\N	PRESENT	0
318781	317525	14031R	PARTICIPANT	\N	PRESENT	0
318782	317525	14191V	PARTICIPANT	\N	PRESENT	0
318783	317525	14169X	PARTICIPANT	\N	PRESENT	0
318784	317525	04085P	PARTICIPANT	\N	PRESENT	0
318785	317525	11012A	PARTICIPANT	\N	PRESENT	0
319147	314179	19663E	PARTICIPANT	\N	PRESENT	0
319148	314179	04008A	PARTICIPANT	\N	PRESENT	0
319149	314179	14119M	PARTICIPANT	\N	PRESENT	0
319150	314179	11103C	PARTICIPANT	\N	PRESENT	0
319151	314179	08012N	PARTICIPANT	\N	PRESENT	0
319152	314179	19253P	PARTICIPANT	\N	PRESENT	0
319153	314179	19629C	PARTICIPANT	\N	PRESENT	0
319154	314179	14147R	PARTICIPANT	\N	PRESENT	0
319155	314179	14219Q	PARTICIPANT	\N	PRESENT	0
319156	314179	14187A	PARTICIPANT	\N	PRESENT	0
319157	314179	97011G	PARTICIPANT	\N	PRESENT	0
319158	314179	19553Y	PARTICIPANT	\N	PRESENT	0
319159	314179	04059M	PARTICIPANT	\N	PRESENT	0
319160	314179	04044E	PARTICIPANT	\N	PRESENT	0
319161	314179	08061X	PARTICIPANT	\N	PRESENT	0
319162	314179	11012A	PARTICIPANT	\N	PRESENT	0
319163	314179	11066Q	PARTICIPANT	\N	PRESENT	0
319164	314179	19585H	PARTICIPANT	\N	PRESENT	0
319165	314179	19599P	PARTICIPANT	\N	PRESENT	0
319166	314179	19747H	PARTICIPANT	\N	PRESENT	0
319167	314179	14028W	PARTICIPANT	\N	PRESENT	0
319168	314179	19721W	PARTICIPANT	\N	PRESENT	0
319169	314179	14033T	PARTICIPANT	\N	PRESENT	0
319170	314179	95062K	PARTICIPANT	\N	PRESENT	0
319171	314179	19503N	PARTICIPANT	\N	PRESENT	0
319172	314179	19479G	PARTICIPANT	\N	PRESENT	0
319173	314179	14085U	PARTICIPANT	\N	PRESENT	0
319174	314179	14103D	PARTICIPANT	\N	PRESENT	0
319175	314179	14265W	PARTICIPANT	\N	PRESENT	0
319176	314179	04088S	PARTICIPANT	\N	PRESENT	0
319177	314179	01028R	PARTICIPANT	\N	PRESENT	0
319178	314179	14223L	PARTICIPANT	\N	PRESENT	0
319179	314179	08020N	PARTICIPANT	\N	PRESENT	0
319180	314179	87003B	PARTICIPANT	\N	PRESENT	0
319181	314179	19741B	PARTICIPANT	\N	PRESENT	0
319182	314179	14213J	PARTICIPANT	\N	PRESENT	0
319183	314179	08062Y	PARTICIPANT	\N	PRESENT	0
319184	314179	19703U	PARTICIPANT	\N	PRESENT	0
319185	314179	19671E	PARTICIPANT	\N	PRESENT	0
319186	314179	17583W	PARTICIPANT	\N	PRESENT	0
319187	314179	07029T	PARTICIPANT	\N	PRESENT	0
319188	314179	11101A	PARTICIPANT	\N	PRESENT	0
319189	314179	14249W	PARTICIPANT	\N	PRESENT	0
319190	314179	14030Q	PARTICIPANT	\N	PRESENT	0
319191	314179	19745F	PARTICIPANT	\N	PRESENT	0
319192	314179	19349W	PARTICIPANT	\N	PRESENT	0
319328	319327	08010L	PARTICIPANT	\N	PRESENT	0
319329	319327	04040A	PARTICIPANT	\N	PRESENT	0
305753	305571	11066Q	PARTICIPANT	\N	PRESENT	0
305754	305571	08047A	PARTICIPANT	\N	PRESENT	0
305755	305571	07029T	PARTICIPANT	\N	EXCUSE	0
305766	305571	01048V	PARTICIPANT	\N	PRESENT	0
305767	305571	04061F	PARTICIPANT	\N	PRESENT	0
305795	305522	19333N	PARTICIPANT	\N	PRESENT	0
305782	305522	17583W	PARTICIPANT	\N	EXCUSE	0
305783	305522	19701S	PARTICIPANT	\N	EXCUSE	0
305784	305522	96004D	PARTICIPANT	\N	EXCUSE	0
305785	305522	19737F	PARTICIPANT	\N	EXCUSE	0
305786	305522	14219Q	PARTICIPANT	\N	EXCUSE	0
305787	305522	08024S	PARTICIPANT	\N	EXCUSE	0
305788	305522	19599P	PARTICIPANT	\N	EXCUSE	0
305789	305522	14169X	PARTICIPANT	\N	EXCUSE	0
305790	305522	11065P	PARTICIPANT	\N	EXCUSE	0
305791	305522	17637T	PARTICIPANT	\N	EXCUSE	0
305792	305522	18083K	PARTICIPANT	\N	PRESENT	0
305793	305522	14221J	PARTICIPANT	\N	PRESENT	0
305794	305522	15447F	PARTICIPANT	\N	PRESENT	0
305796	305522	14031R	PARTICIPANT	\N	PRESENT	0
305797	305522	14051J	PARTICIPANT	\N	PRESENT	0
305798	305522	08009T	PRESIDENT	0	PRESENT	0
305799	305522	19503N	PARTICIPANT	\N	PRESENT	0
305800	305522	19347U	PARTICIPANT	\N	PRESENT	0
305801	305522	19739H	PARTICIPANT	\N	PRESENT	0
305802	305522	04097T	PARTICIPANT	\N	PRESENT	0
305803	305522	19745F	PARTICIPANT	\N	PRESENT	0
305804	305522	19681G	PARTICIPANT	\N	PRESENT	0
305805	305522	98023Q	PARTICIPANT	\N	PRESENT	0
305806	305522	19637C	PARTICIPANT	\N	PRESENT	0
305807	305522	19733B	PARTICIPANT	\N	PRESENT	0
305808	305522	19383Y	PARTICIPANT	\N	PRESENT	0
305809	305522	19713W	PARTICIPANT	\N	PRESENT	0
305810	305522	95062K	PARTICIPANT	\N	PRESENT	0
305811	305522	19549D	PARTICIPANT	\N	PRESENT	0
305812	305522	19387D	PARTICIPANT	\N	PRESENT	0
305813	305522	19551W	PARTICIPANT	\N	PRESENT	0
305814	305522	14093U	PARTICIPANT	\N	PRESENT	0
305815	305522	08060W	PARTICIPANT	\N	PRESENT	0
305817	305522	04061F	PARTICIPANT	\N	PRESENT	0
305818	305522	14237S	PARTICIPANT	\N	PRESENT	0
305982	305907	14327T	PARTICIPANT	\N	PRESENT	0
305983	305907	14331P	PARTICIPANT	\N	PRESENT	0
305984	305907	19479G	PARTICIPANT	\N	PRESENT	0
305985	305907	11048N	PARTICIPANT	\N	PRESENT	0
305986	305907	04071H	PARTICIPANT	\N	PRESENT	0
305987	305907	19711U	PARTICIPANT	\N	PRESENT	0
305988	305907	95041E	PARTICIPANT	\N	PRESENT	0
305989	305907	08034U	PARTICIPANT	\N	PRESENT	0
305990	305907	19545Y	PARTICIPANT	\N	PRESENT	0
305991	305907	01057W	PARTICIPANT	\N	PRESENT	0
305992	305907	19689Q	PARTICIPANT	\N	PRESENT	0
305993	305907	11053K	PARTICIPANT	\N	PRESENT	0
305994	305907	11074Q	PRESIDENT	0	PRESENT	0
305995	305907	08011M	PARTICIPANT	\N	PRESENT	0
305996	305907	19671E	PARTICIPANT	\N	PRESENT	0
305997	305907	14159V	PARTICIPANT	\N	PRESENT	0
305998	305907	04086Q	PARTICIPANT	\N	PRESENT	0
305999	305907	11040E	PARTICIPANT	\N	PRESENT	0
306000	305907	08073C	PARTICIPANT	\N	PRESENT	0
306001	305907	14085U	PARTICIPANT	\N	PRESENT	0
306002	305907	19349W	PARTICIPANT	\N	PRESENT	0
306003	305907	07029T	PARTICIPANT	\N	EXCUSE	0
306004	305907	08010L	PARTICIPANT	\N	EXCUSE	0
306005	305907	14121F	PARTICIPANT	\N	EXCUSE	0
306006	305907	89017R	PARTICIPANT	\N	EXCUSE	0
306007	305907	14034U	PARTICIPANT	\N	EXCUSE	0
309350	309349	19631V	PARTICIPANT	\N	PRESENT	0
309351	309349	14105F	PARTICIPANT	\N	PRESENT	0
309352	309349	19383Y	PARTICIPANT	\N	PRESENT	0
309353	309349	08020N	PARTICIPANT	\N	PRESENT	0
309354	309349	14207L	PARTICIPANT	\N	PRESENT	0
309355	309349	14038Y	PARTICIPANT	\N	PRESENT	0
309356	309349	19467C	PARTICIPANT	\N	PRESENT	0
309357	309349	80013X	PARTICIPANT	\N	PRESENT	0
309358	309349	19719D	PARTICIPANT	\N	PRESENT	0
309359	309349	01025N	PARTICIPANT	\N	PRESENT	0
309360	309349	14199E	PARTICIPANT	\N	PRESENT	0
309361	309349	14213J	PARTICIPANT	\N	PRESENT	0
309362	309349	14061L	PARTICIPANT	\N	PRESENT	0
309363	309349	19611R	PARTICIPANT	\N	PRESENT	0
309364	309349	04049K	PARTICIPANT	\N	PRESENT	0
309365	309349	14029X	PARTICIPANT	\N	PRESENT	0
309366	309349	19723Y	PARTICIPANT	\N	PRESENT	0
309367	309349	12041X	PARTICIPANT	\N	PRESENT	0
309368	309349	14219Q	PARTICIPANT	\N	PRESENT	0
309369	309349	19441R	PARTICIPANT	\N	PRESENT	0
309370	309349	04092N	PARTICIPANT	\N	PRESENT	0
309371	309349	19369B	PARTICIPANT	\N	PRESENT	0
309372	309349	14109K	PARTICIPANT	\N	PRESENT	0
309373	309349	14265W	PARTICIPANT	\N	PRESENT	0
309374	309349	05012A	PARTICIPANT	\N	PRESENT	0
309375	309349	19443T	PARTICIPANT	\N	PRESENT	0
309376	309349	14135M	PARTICIPANT	\N	PRESENT	0
309377	309349	11012A	PARTICIPANT	\N	PRESENT	0
309888	309060	01024M	PARTICIPANT	\N	PRESENT	0
309889	309060	11033F	PARTICIPANT	\N	PRESENT	0
309890	309060	19503N	PARTICIPANT	\N	PRESENT	0
309891	309060	14065Q	PARTICIPANT	\N	PRESENT	0
309892	309060	11072N	PARTICIPANT	\N	PRESENT	0
309893	309060	19649G	PARTICIPANT	\N	PRESENT	0
309894	309060	19719D	PARTICIPANT	\N	PRESENT	0
309895	309060	19713W	PARTICIPANT	\N	PRESENT	0
309896	309060	14231L	PARTICIPANT	\N	PRESENT	0
309897	309060	04085P	PARTICIPANT	\N	PRESENT	0
309898	309060	19737F	PARTICIPANT	\N	PRESENT	0
309899	309060	08044W	PARTICIPANT	\N	PRESENT	0
309900	309060	19762G	PARTICIPANT	\N	PRESENT	0
309901	309060	07034Q	PARTICIPANT	\N	PRESENT	0
309902	309060	14069U	PARTICIPANT	\N	PRESENT	0
309903	309060	14223L	PARTICIPANT	\N	PRESENT	0
309904	309060	14151M	PARTICIPANT	\N	PRESENT	0
309905	309060	19629C	PARTICIPANT	\N	PRESENT	0
309906	309060	19253P	PARTICIPANT	\N	PRESENT	0
309907	309060	01025N	PARTICIPANT	\N	PRESENT	0
309908	309060	11043H	PARTICIPANT	\N	PRESENT	0
309909	309060	18083K	PARTICIPANT	\N	PRESENT	0
309910	309060	19447X	PARTICIPANT	\N	PRESENT	0
309911	309060	19703U	PARTICIPANT	\N	PRESENT	0
309912	309060	04040A	PARTICIPANT	\N	PRESENT	0
309913	309060	14179A	PARTICIPANT	\N	PRESENT	0
309914	309060	19515S	PARTICIPANT	\N	PRESENT	0
309915	309060	14087W	PARTICIPANT	\N	PRESENT	0
309916	309060	14215L	PARTICIPANT	\N	PRESENT	0
309917	309060	19575F	PARTICIPANT	\N	PRESENT	0
309918	309060	19441R	PARTICIPANT	\N	PRESENT	0
309919	309060	19747H	PARTICIPANT	\N	PRESENT	0
309920	309060	11067R	PARTICIPANT	\N	PRESENT	0
309921	309060	11048N	PARTICIPANT	\N	PRESENT	0
309922	309060	14042U	PARTICIPANT	\N	PRESENT	0
309923	309060	14119M	PARTICIPANT	\N	PRESENT	0
309924	309060	19415P	PARTICIPANT	\N	PRESENT	0
309925	309060	07029T	PARTICIPANT	\N	PRESENT	0
309926	309060	14147R	PARTICIPANT	\N	PRESENT	0
309927	309060	14257W	PARTICIPANT	\N	PRESENT	0
309928	309060	05008E	PARTICIPANT	\N	PRESENT	0
309929	309060	14029X	PARTICIPANT	\N	PRESENT	0
309930	309060	14265W	PARTICIPANT	\N	PRESENT	0
309931	309060	19295A	PARTICIPANT	\N	PRESENT	0
309932	309060	14197C	PARTICIPANT	\N	PRESENT	0
309933	309060	14031R	PARTICIPANT	\N	PRESENT	0
309934	309060	14133K	PARTICIPANT	\N	PRESENT	0
309935	309060	19545Y	PARTICIPANT	\N	PRESENT	0
309936	309060	14083S	PARTICIPANT	\N	PRESENT	0
309937	309060	14187A	PARTICIPANT	\N	PRESENT	0
309886	309060	01043Q	PARTICIPANT	\N	PRESENT	0
309887	309060	04047H	PARTICIPANT	\N	PRESENT	0
309938	309060	19507S	PARTICIPANT	\N	PRESENT	0
309939	309060	10015M	PARTICIPANT	\N	PRESENT	0
309940	309060	14213J	PARTICIPANT	\N	PRESENT	0
309941	309060	14071N	PARTICIPANT	\N	PRESENT	0
309942	309060	08061X	PARTICIPANT	\N	PRESENT	0
309943	309060	07004J	PARTICIPANT	\N	PRESENT	0
309944	309060	08045X	PARTICIPANT	\N	PRESENT	0
309945	309060	04088S	PARTICIPANT	\N	PRESENT	0
309946	309060	11026G	PARTICIPANT	\N	PRESENT	0
309947	309060	11097X	PARTICIPANT	\N	PRESENT	0
309948	309060	14053L	PARTICIPANT	\N	PRESENT	0
309949	309060	95030B	PARTICIPANT	\N	PRESENT	0
309950	309060	14034U	PARTICIPANT	\N	PRESENT	0
309951	309060	19543W	PARTICIPANT	\N	PRESENT	0
309952	309060	19383Y	PARTICIPANT	\N	PRESENT	0
309953	309060	14357A	PARTICIPANT	\N	PRESENT	0
309954	309060	14259Y	PARTICIPANT	\N	PRESENT	0
310238	309124	19741B	PARTICIPANT	\N	PRESENT	0
310239	309124	14173T	PARTICIPANT	\N	PRESENT	0
310240	309153	11065P	PARTICIPANT	\N	PRESENT	0
310241	309153	19733B	PARTICIPANT	\N	PRESENT	0
310242	309056	01028R	PARTICIPANT	\N	PRESENT	0
325714	325382	19699S	PARTICIPANT	\N	PRESENT	0
325715	325382	19611R	PARTICIPANT	\N	PRESENT	0
325716	325382	04049K	PARTICIPANT	\N	PRESENT	0
325717	325382	19745F	PARTICIPANT	\N	PRESENT	0
325718	325382	19749K	PARTICIPANT	\N	PRESENT	0
325719	325382	08049C	PARTICIPANT	\N	PRESENT	0
325720	325382	14207L	PARTICIPANT	\N	PRESENT	0
325721	325382	19269X	PARTICIPANT	\N	PRESENT	0
325722	325382	14147R	PARTICIPANT	\N	PRESENT	0
325723	325382	14061L	PARTICIPANT	\N	PRESENT	0
325724	325382	08073C	PARTICIPANT	\N	PRESENT	0
325725	325382	14151M	PARTICIPANT	\N	PRESENT	0
325726	325382	14087W	PARTICIPANT	\N	PRESENT	0
325727	325382	19441R	PARTICIPANT	\N	PRESENT	0
325728	325382	10015M	PARTICIPANT	\N	PRESENT	0
325738	325382	19723Y	PARTICIPANT	\N	PRESENT	0
325730	325382	14065Q	PARTICIPANT	\N	PRESENT	0
325731	325382	19651A	PARTICIPANT	\N	PRESENT	0
325732	325382	95037J	PARTICIPANT	\N	PRESENT	0
325733	325382	14215L	PARTICIPANT	\N	PRESENT	0
325734	325382	08015R	PARTICIPANT	\N	PRESENT	0
325735	325382	19479G	PARTICIPANT	\N	PRESENT	0
325736	325382	19762G	PARTICIPANT	\N	PRESENT	0
325737	325382	14073Q	PARTICIPANT	\N	PRESENT	0
325739	325382	11010L	PARTICIPANT	\N	PRESENT	0
325740	325382	19593H	PARTICIPANT	\N	PRESENT	0
325741	325382	19507S	PARTICIPANT	\N	PRESENT	0
325742	325382	98023Q	PARTICIPANT	\N	PRESENT	0
325743	325382	04057K	PARTICIPANT	\N	PRESENT	0
325744	325382	14205J	PARTICIPANT	\N	PRESENT	0
325745	325382	04070G	PARTICIPANT	\N	PRESENT	0
325746	325382	08011M	PARTICIPANT	\N	PRESENT	0
325747	325382	95041E	PARTICIPANT	\N	PRESENT	0
325748	325382	01058X	PARTICIPANT	\N	PRESENT	0
325749	325382	04061F	PARTICIPANT	\N	PRESENT	0
325750	325382	14083S	PARTICIPANT	\N	PRESENT	0
325751	325382	19521Q	PARTICIPANT	\N	PRESENT	0
325755	325382	14199E	PARTICIPANT	\N	PRESENT	0
325753	325382	08024S	PARTICIPANT	\N	PRESENT	0
325754	325382	14157T	PARTICIPANT	\N	PRESENT	0
325756	325382	14029X	PARTICIPANT	\N	PRESENT	0
325764	325382	19671E	PARTICIPANT	\N	PRESENT	0
325758	325382	11110B	PARTICIPANT	\N	PRESENT	0
325759	325382	19543W	PARTICIPANT	\N	PRESENT	0
325760	325382	19421M	PARTICIPANT	\N	PRESENT	0
325761	325382	08069G	PARTICIPANT	\N	PRESENT	0
325766	325382	88008L	PARTICIPANT	\N	PRESENT	0
325765	325382	04047H	PARTICIPANT	\N	PRESENT	0
325767	325382	08019V	PARTICIPANT	\N	PRESENT	0
325768	325382	04071H	PARTICIPANT	\N	PRESENT	0
325769	325382	89017R	PARTICIPANT	\N	PRESENT	0
325770	325382	08014Q	PARTICIPANT	\N	PRESENT	0
325771	325382	14221J	PARTICIPANT	\N	PRESENT	0
325775	325382	19713W	PARTICIPANT	\N	PRESENT	0
325773	325382	95030B	PARTICIPANT	\N	PRESENT	0
325774	325382	02002K	PARTICIPANT	\N	PRESENT	0
325776	325382	19766L	PARTICIPANT	\N	PRESENT	0
325777	325382	19739H	PARTICIPANT	\N	PRESENT	0
325782	325382	19768N	PARTICIPANT	\N	PRESENT	0
325779	325382	14179A	PARTICIPANT	\N	PRESENT	0
325783	325382	19782L	PARTICIPANT	\N	PRESENT	0
325781	325382	14237S	PARTICIPANT	\N	PRESENT	0
325788	325382	19369B	PARTICIPANT	\N	PRESENT	0
325786	325382	01048V	PARTICIPANT	\N	PRESENT	0
325787	325382	04034C	PARTICIPANT	\N	PRESENT	0
325789	325382	87003B	PARTICIPANT	\N	PRESENT	0
325791	325382	11043H	PARTICIPANT	\N	PRESENT	0
325795	325382	14329V	PARTICIPANT	\N	PRESENT	0
325807	322456	08012N	PARTICIPANT	\N	EXCUSE	0
325794	325382	14357A	PARTICIPANT	\N	PRESENT	0
325796	325382	14213J	PARTICIPANT	\N	PRESENT	0
326119	314165	11027H	PARTICIPANT	\N	PRESENT	0
326120	314165	11033F	PARTICIPANT	\N	PRESENT	0
326121	314165	19593H	PARTICIPANT	\N	PRESENT	0
326122	314165	19347U	PARTICIPANT	\N	PRESENT	0
326123	314165	19695N	PARTICIPANT	\N	PRESENT	0
326124	314165	19413M	PARTICIPANT	\N	PRESENT	0
326125	314165	19503N	PARTICIPANT	\N	PRESENT	0
326126	314165	14121F	PARTICIPANT	\N	PRESENT	0
326127	314165	19333N	PARTICIPANT	\N	PRESENT	0
326128	314165	19599P	PARTICIPANT	\N	PRESENT	0
326129	314165	14051J	PARTICIPANT	\N	PRESENT	0
326130	314165	19782L	PARTICIPANT	\N	PRESENT	0
326131	314165	08017T	PARTICIPANT	\N	PRESENT	0
326132	314165	04034C	PARTICIPANT	\N	PRESENT	0
326133	314165	14241N	PARTICIPANT	\N	PRESENT	0
326134	314165	14107H	PARTICIPANT	\N	PRESENT	0
326135	314165	98022P	PARTICIPANT	\N	PRESENT	0
326136	314165	11065P	PARTICIPANT	\N	PRESENT	0
326137	314165	17589D	PARTICIPANT	\N	PRESENT	0
326138	314165	19583F	PARTICIPANT	\N	PRESENT	0
326139	314165	19441R	PARTICIPANT	\N	PRESENT	0
326140	314165	19479G	PARTICIPANT	\N	PRESENT	0
326141	314165	14219Q	PARTICIPANT	\N	PRESENT	0
326142	314165	19369B	PARTICIPANT	\N	PRESENT	0
326143	314165	16685X	PARTICIPANT	\N	PRESENT	0
326144	314165	08044W	PARTICIPANT	\N	PRESENT	0
326145	314165	14073Q	PARTICIPANT	\N	PRESENT	0
326146	314165	19745F	PARTICIPANT	\N	PRESENT	0
326147	314165	19521Q	PARTICIPANT	\N	PRESENT	0
326148	314165	19737F	PARTICIPANT	\N	PRESENT	0
326149	314165	19747H	PARTICIPANT	\N	PRESENT	0
326150	314165	17583W	PARTICIPANT	\N	PRESENT	0
326151	314165	14237S	PARTICIPANT	\N	PRESENT	0
326152	314165	14055N	PARTICIPANT	\N	PRESENT	0
326153	314165	19731Y	PARTICIPANT	\N	PRESENT	0
326154	314165	19733B	PARTICIPANT	\N	PRESENT	0
326155	314165	14093U	PARTICIPANT	\N	PRESENT	0
326156	314165	19383Y	PARTICIPANT	\N	PRESENT	0
326157	314165	19533U	PARTICIPANT	\N	PRESENT	0
326158	314165	04043D	PARTICIPANT	\N	PRESENT	0
326159	314165	19768N	PARTICIPANT	\N	PRESENT	0
326160	324892	04086Q	PARTICIPANT	\N	PRESENT	0
326161	324892	07029T	PARTICIPANT	\N	PRESENT	0
326162	324892	95041E	PARTICIPANT	\N	PRESENT	0
326163	324892	19711U	PARTICIPANT	\N	PRESENT	0
326164	324892	01057W	PARTICIPANT	\N	PRESENT	0
326165	324892	99004R	PARTICIPANT	\N	PRESENT	0
326166	324892	19667J	PARTICIPANT	\N	PRESENT	0
326167	324892	19671E	PARTICIPANT	\N	PRESENT	0
326168	324892	14331P	PARTICIPANT	\N	PRESENT	0
326178	314165	14031R	PARTICIPANT	\N	PRESENT	0
326179	314165	14191V	PARTICIPANT	\N	PRESENT	0
326180	314165	15447F	PARTICIPANT	\N	PRESENT	0
326181	314165	19679N	PARTICIPANT	\N	PRESENT	0
326182	314165	04097T	PARTICIPANT	\N	PRESENT	0
326183	314165	95062K	PARTICIPANT	\N	PRESENT	0
326184	314165	14157T	PARTICIPANT	\N	PRESENT	0
326185	314165	19741B	PARTICIPANT	\N	PRESENT	0
326186	314165	08060W	PARTICIPANT	\N	PRESENT	0
326187	314165	19549D	PARTICIPANT	\N	PRESENT	0
326188	314165	11067R	PARTICIPANT	\N	PRESENT	0
326189	314165	19421M	PARTICIPANT	\N	PRESENT	0
326190	314165	08031R	PARTICIPANT	\N	PRESENT	0
326191	314165	14041T	PARTICIPANT	\N	PRESENT	0
326192	324892	14119M	PARTICIPANT	\N	PRESENT	0
326193	324892	14187A	PARTICIPANT	\N	PRESENT	0
326194	324892	11074Q	PRESIDENT	0	PRESENT	0
326195	324892	14169X	PARTICIPANT	\N	PRESENT	0
326196	314165	18083K	PARTICIPANT	\N	PRESENT	0
326197	314165	19581D	PARTICIPANT	\N	PRESENT	0
326198	324892	14327T	PARTICIPANT	\N	PRESENT	0
326199	324892	14225N	PARTICIPANT	\N	PRESENT	0
326200	324892	19349W	PARTICIPANT	\N	PRESENT	0
326201	324892	08010L	PARTICIPANT	\N	PRESENT	0
326202	324892	19647E	PARTICIPANT	\N	PRESENT	0
326203	324892	19479G	PARTICIPANT	\N	PRESENT	0
326204	324892	19531S	PARTICIPANT	\N	PRESENT	0
326205	324892	19689Q	PARTICIPANT	\N	PRESENT	0
326206	324892	08011M	PARTICIPANT	\N	PRESENT	0
326207	324892	14173T	PARTICIPANT	\N	PRESENT	0
326208	324892	14083S	PARTICIPANT	\N	PRESENT	0
326209	324892	11012A	PARTICIPANT	\N	PRESENT	0
326210	324892	19741B	PARTICIPANT	\N	PRESENT	0
326211	324892	08034U	PARTICIPANT	\N	PRESENT	0
326212	324892	14159V	PARTICIPANT	\N	PRESENT	0
326213	324892	14121F	PARTICIPANT	\N	PRESENT	0
326214	314165	14231L	PARTICIPANT	\N	PRESENT	0
326215	314165	08056B	PARTICIPANT	\N	PRESENT	0
326216	322456	19467C	PARTICIPANT	\N	EXCUSE	0
326218	314165	14147R	PARTICIPANT	\N	PRESENT	0
326219	314165	97011G	PARTICIPANT	\N	PRESENT	0
326220	326217	19701S	PARTICIPANT	\N	PRESENT	0
326221	314165	19681G	PARTICIPANT	\N	PRESENT	0
326222	324892	11053K	PARTICIPANT	\N	PRESENT	0
326223	324892	88008L	PARTICIPANT	\N	PRESENT	0
326224	314165	19629C	PARTICIPANT	\N	PRESENT	0
326225	324892	08014Q	PARTICIPANT	\N	PRESENT	0
326226	314165	19507S	PARTICIPANT	\N	PRESENT	0
303625	289212	11077T	PARTICIPANT	\N	PRESENT	0
303626	289212	11090Q	PARTICIPANT	\N	PRESENT	0
303627	289212	14187A	PARTICIPANT	\N	PRESENT	0
303628	289212	08038Y	PARTICIPANT	\N	PRESENT	0
303629	289212	14051J	PARTICIPANT	\N	PRESENT	0
303630	289212	19591F	PARTICIPANT	\N	PRESENT	0
303631	289212	14257W	PARTICIPANT	\N	PRESENT	0
303632	289212	14207L	PARTICIPANT	\N	PRESENT	0
303633	289212	19715Y	PARTICIPANT	\N	PRESENT	0
303634	289212	19599P	PARTICIPANT	\N	PRESENT	0
303635	289212	19515S	PARTICIPANT	\N	PRESENT	0
303636	289212	95063L	PARTICIPANT	\N	PRESENT	0
303637	289212	19443T	PARTICIPANT	\N	PRESENT	0
303638	289212	19349W	PARTICIPANT	\N	PRESENT	0
303639	289212	14033T	PARTICIPANT	\N	PRESENT	0
303640	289212	19565D	PARTICIPANT	\N	PRESENT	0
303641	289212	14038Y	PARTICIPANT	\N	PRESENT	0
303642	289212	11065P	PARTICIPANT	\N	PRESENT	0
303643	289212	11043H	PARTICIPANT	\N	PRESENT	0
303644	289212	19387D	PARTICIPANT	\N	PRESENT	0
303645	289212	19679N	PARTICIPANT	\N	PRESENT	0
303646	289212	11099A	PARTICIPANT	\N	PRESENT	0
303647	289212	14105F	PARTICIPANT	\N	PRESENT	0
303648	289212	99004R	PARTICIPANT	\N	PRESENT	0
303649	289212	19289C	PARTICIPANT	\N	PRESENT	0
303650	289212	14147R	PARTICIPANT	\N	PRESENT	0
303651	289212	14329V	PARTICIPANT	\N	PRESENT	0
303652	289212	19695N	PARTICIPANT	\N	PRESENT	0
303653	289212	14069U	PARTICIPANT	\N	PRESENT	0
303654	289212	14073Q	PARTICIPANT	\N	PRESENT	0
303655	289212	19533U	PARTICIPANT	\N	PRESENT	0
303656	289212	19737F	PARTICIPANT	\N	PRESENT	0
303657	289212	04086Q	PARTICIPANT	\N	PRESENT	0
303658	289212	14215L	PARTICIPANT	\N	PRESENT	0
303659	289212	19747H	PARTICIPANT	\N	PRESENT	0
303660	289212	19367Y	PARTICIPANT	\N	PRESENT	0
303661	289212	04033B	PARTICIPANT	\N	PRESENT	0
303662	289212	19703U	PARTICIPANT	\N	PRESENT	0
303663	289212	08031R	PARTICIPANT	\N	PRESENT	0
303664	289212	17589D	PARTICIPANT	\N	PRESENT	0
303665	289212	14205J	PARTICIPANT	\N	PRESENT	0
303666	289212	19253P	PARTICIPANT	\N	PRESENT	0
303667	289212	14197C	PARTICIPANT	\N	PRESENT	0
303668	289212	11012A	PARTICIPANT	\N	PRESENT	0
303669	289212	19735D	PARTICIPANT	\N	PRESENT	0
303670	289212	14042U	PARTICIPANT	\N	PRESENT	0
303671	289212	11048N	PARTICIPANT	\N	PRESENT	0
303672	289212	19447X	PARTICIPANT	\N	PRESENT	0
303673	289212	19760E	PARTICIPANT	\N	PRESENT	0
303674	289212	19687N	PARTICIPANT	\N	PRESENT	0
303675	289212	19347U	PARTICIPANT	\N	PRESENT	0
303676	289212	04088S	PARTICIPANT	\N	PRESENT	0
303677	289212	19467C	PARTICIPANT	\N	PRESENT	0
303678	289212	14223L	PARTICIPANT	\N	PRESENT	0
303679	289212	19657G	PARTICIPANT	\N	PRESENT	0
303680	289212	14157T	PARTICIPANT	\N	PRESENT	0
303681	289212	11097X	PARTICIPANT	\N	PRESENT	0
303682	289212	14053L	PARTICIPANT	\N	PRESENT	0
303683	289212	14071N	PARTICIPANT	\N	PRESENT	0
303684	289212	19503N	PARTICIPANT	\N	PRESENT	0
303685	289212	19631V	PARTICIPANT	\N	PRESENT	0
303686	289212	19725B	PARTICIPANT	\N	PRESENT	0
303687	289212	14217N	PARTICIPANT	\N	PRESENT	0
303688	289212	14061L	PARTICIPANT	\N	PRESENT	0
303689	289212	19575F	PARTICIPANT	\N	PRESENT	0
303690	289212	14265W	PARTICIPANT	\N	PRESENT	0
303691	289212	08015R	PARTICIPANT	\N	PRESENT	0
303692	289212	14026U	PARTICIPANT	\N	PRESENT	0
303693	289212	08068F	PARTICIPANT	\N	PRESENT	0
303694	289212	14083S	PARTICIPANT	\N	PRESENT	0
303695	289212	14213J	PARTICIPANT	\N	PRESENT	0
303696	289212	01057W	PARTICIPANT	\N	PRESENT	0
303697	289212	04045F	PARTICIPANT	\N	PRESENT	0
303698	289212	19531S	PARTICIPANT	\N	PRESENT	0
303699	289212	14034U	PARTICIPANT	\N	PRESENT	0
303700	289212	08010L	PARTICIPANT	\N	PRESENT	0
303701	289212	04049K	PARTICIPANT	\N	PRESENT	0
303702	289212	19383Y	PARTICIPANT	\N	PRESENT	0
303703	289212	07029T	PARTICIPANT	\N	PRESENT	0
303970	303969	14259Y	PARTICIPANT	\N	PRESENT	0
303971	303969	14053L	PARTICIPANT	\N	PRESENT	0
303975	303968	14053L	PARTICIPANT	\N	PRESENT	0
303973	303969	14111D	PARTICIPANT	\N	PRESENT	0
303974	303969	14231L	PARTICIPANT	\N	PRESENT	0
303976	303968	14259Y	PARTICIPANT	\N	PRESENT	0
303977	303968	19629C	PARTICIPANT	\N	PRESENT	0
304018	304017	14205J	PARTICIPANT	\N	PRESENT	0
304019	304016	14205J	PARTICIPANT	\N	PRESENT	0
304080	302704	19551W	PARTICIPANT	\N	PRESENT	0
304081	302704	14089Y	PARTICIPANT	\N	PRESENT	0
304082	302704	19679N	PARTICIPANT	\N	PRESENT	0
304083	302704	04085P	PARTICIPANT	\N	PRESENT	0
304084	302704	14251Q	PARTICIPANT	\N	PRESENT	0
304085	302704	19725B	PARTICIPANT	\N	PRESENT	0
304086	302704	19689Q	PARTICIPANT	\N	PRESENT	0
304087	302704	11074Q	PARTICIPANT	\N	PRESENT	0
304088	302704	08017T	PARTICIPANT	\N	PRESENT	0
304089	302704	95063L	PARTICIPANT	\N	PRESENT	0
304090	302704	11027H	PARTICIPANT	\N	PRESENT	0
304091	302704	14021P	PARTICIPANT	\N	PRESENT	0
304092	302704	19647E	PARTICIPANT	\N	PRESENT	0
304093	302704	19253P	PARTICIPANT	\N	PRESENT	0
304193	289213	04059M	PARTICIPANT	\N	PRESENT	0
304194	289213	08011M	PARTICIPANT	\N	PRESENT	0
304195	289213	11074Q	PARTICIPANT	\N	PRESENT	0
304196	289213	11012A	PARTICIPANT	\N	PRESENT	0
304197	289213	19651A	PARTICIPANT	\N	PRESENT	0
304198	289213	19687N	PARTICIPANT	\N	PRESENT	0
304199	289213	14327T	PARTICIPANT	\N	PRESENT	0
304200	289213	19647E	PARTICIPANT	\N	PRESENT	0
304201	289213	14251Q	PARTICIPANT	\N	PRESENT	0
304202	289213	19711U	PARTICIPANT	\N	PRESENT	0
304204	289213	19503N	PARTICIPANT	\N	PRESENT	0
304205	289213	08017T	PARTICIPANT	\N	PRESENT	0
304206	289213	19689Q	PARTICIPANT	\N	PRESENT	0
304207	289213	19479G	PARTICIPANT	\N	PRESENT	0
304208	289213	14103D	PARTICIPANT	\N	PRESENT	0
304209	289213	11048N	PARTICIPANT	\N	PRESENT	0
304210	289213	99004R	PARTICIPANT	\N	PRESENT	0
304211	289213	97011G	PARTICIPANT	\N	PRESENT	0
304212	289213	19387D	PARTICIPANT	\N	PRESENT	0
304213	289213	19703U	PARTICIPANT	\N	PRESENT	0
304214	289213	19667J	PARTICIPANT	\N	PRESENT	0
304215	289213	14026U	PARTICIPANT	\N	PRESENT	0
304220	289213	04040A	PARTICIPANT	\N	PRESENT	0
304221	289213	19719D	PARTICIPANT	\N	PRESENT	0
304222	289213	19289C	PARTICIPANT	\N	PRESENT	0
304223	289213	19521Q	PARTICIPANT	\N	PRESENT	0
304224	289213	19737F	PARTICIPANT	\N	PRESENT	0
304225	289213	11097X	PARTICIPANT	\N	PRESENT	0
304229	289213	14265W	PARTICIPANT	\N	PRESENT	0
304230	289213	14157T	PARTICIPANT	\N	PRESENT	0
304231	289213	14207L	PARTICIPANT	\N	PRESENT	0
304232	289213	04088S	PARTICIPANT	\N	PRESENT	0
304233	289213	19543W	PARTICIPANT	\N	PRESENT	0
305373	305372	19701S	PARTICIPANT	\N	PRESENT	0
305375	305374	14255U	PARTICIPANT	\N	PRESENT	0
305376	305374	19701S	PARTICIPANT	\N	PRESENT	0
305377	305374	11026G	PARTICIPANT	\N	PRESENT	0
305519	305512	14089Y	PARTICIPANT	\N	PRESENT	0
305520	305517	14205J	PARTICIPANT	\N	PRESENT	0
305524	305523	14331P	PARTICIPANT	\N	PRESENT	0
305526	305525	19701S	PARTICIPANT	\N	PRESENT	0
305527	305525	14281W	PARTICIPANT	\N	PRESENT	0
305528	305525	11026G	PARTICIPANT	\N	PRESENT	0
305534	305533	08010L	PARTICIPANT	\N	PRESENT	0
305531	305529	19701S	PARTICIPANT	\N	PRESENT	0
305532	305529	14281W	PARTICIPANT	\N	PRESENT	0
305536	305535	08010L	PARTICIPANT	\N	PRESENT	0
305542	305539	14205J	PARTICIPANT	\N	PRESENT	0
305543	305540	14205J	PARTICIPANT	\N	PRESENT	0
305544	305541	14205J	PARTICIPANT	\N	PRESENT	0
305545	305537	14089Y	PARTICIPANT	\N	PRESENT	0
305903	305902	08010L	PARTICIPANT	\N	PRESENT	0
305905	305904	14173T	PARTICIPANT	\N	PRESENT	0
306914	305925	14001X	PARTICIPANT	\N	PRESENT	0
306915	305925	19649G	PARTICIPANT	\N	PRESENT	0
306916	305925	11026G	PARTICIPANT	\N	PRESENT	0
306917	305925	95063L	PARTICIPANT	\N	PRESENT	0
306918	306070	04057K	PARTICIPANT	\N	PRESENT	0
306919	306070	14123H	PARTICIPANT	\N	PRESENT	0
306920	306070	08020N	PARTICIPANT	\N	EXCUSE	0
306921	306070	08016S	PARTICIPANT	\N	EXCUSE	0
306948	306070	14241N	PARTICIPANT	\N	PRESENT	0
306949	306070	07033P	PARTICIPANT	\N	PRESENT	0
306950	306070	14249W	PARTICIPANT	\N	PRESENT	0
306951	306070	19611R	PARTICIPANT	\N	PRESENT	0
306952	305925	11045K	PARTICIPANT	\N	PRESENT	0
310312	307506	14195A	PARTICIPANT	\N	EXCUSE	0
310313	307508	14195A	PARTICIPANT	\N	EXCUSE	0
311772	311724	11010L	PARTICIPANT	\N	EXCUSE	0
311773	311724	11054L	PARTICIPANT	\N	EXCUSE	0
311774	311724	14135M	PARTICIPANT	\N	EXCUSE	0
320031	318025	17637T	PARTICIPANT	\N	PRESENT	0
320047	318025	19383Y	PARTICIPANT	\N	PRESENT	0
320048	318025	19549D	PARTICIPANT	\N	PRESENT	0
320049	318025	80027E	PARTICIPANT	\N	PRESENT	0
320050	317486	19697Q	PARTICIPANT	\N	PRESENT	0
320051	317486	14355X	PARTICIPANT	\N	EXCUSE	0
320052	317486	14087W	PARTICIPANT	\N	PRESENT	0
320053	317486	14195A	PARTICIPANT	\N	PRESENT	0
320054	317486	19367Y	PARTICIPANT	\N	PRESENT	0
320055	317486	08041T	PARTICIPANT	\N	EXCUSE	0
320056	317486	19675J	PARTICIPANT	\N	PRESENT	0
320057	317486	17779H	PARTICIPANT	\N	PRESENT	0
320058	317486	11097X	PARTICIPANT	\N	PRESENT	0
320059	317486	19415P	PARTICIPANT	\N	PRESENT	0
320060	317486	14223L	PARTICIPANT	\N	PRESENT	0
320061	317486	04045F	PARTICIPANT	\N	PRESENT	0
320062	317486	14227Q	PARTICIPANT	\N	PRESENT	0
320063	317486	19703U	PARTICIPANT	\N	PRESENT	0
320064	317486	14239U	PARTICIPANT	\N	PRESENT	0
320065	317486	14281W	PARTICIPANT	\N	PRESENT	0
320066	317486	19679N	PARTICIPANT	\N	PRESENT	0
320067	317486	14042U	PARTICIPANT	\N	PRESENT	0
320068	317486	19575F	PARTICIPANT	\N	PRESENT	0
320069	317486	08048B	PARTICIPANT	\N	PRESENT	0
320070	317486	14213J	PARTICIPANT	\N	PRESENT	0
320071	317486	14217N	PARTICIPANT	\N	PRESENT	0
320072	317486	19335Q	PARTICIPANT	\N	PRESENT	0
320073	317486	10006L	PARTICIPANT	\N	PRESENT	0
320074	317486	19683J	PARTICIPANT	\N	PRESENT	0
320075	317486	98024R	PARTICIPANT	\N	PRESENT	0
320076	317486	19521Q	PARTICIPANT	\N	PRESENT	0
320077	317486	01034P	PARTICIPANT	\N	PRESENT	0
320078	317486	04092N	PRESIDENT	0	PRESENT	0
320079	317486	11045K	PARTICIPANT	\N	PRESENT	0
320080	317486	19691J	PARTICIPANT	\N	PRESENT	0
320081	317486	19717B	PARTICIPANT	\N	PRESENT	0
320082	317486	19723Y	PARTICIPANT	\N	PRESENT	0
320083	317486	19727D	PARTICIPANT	\N	PRESENT	0
320084	317486	11103C	PARTICIPANT	\N	PRESENT	0
320085	317486	14071N	PARTICIPANT	\N	PRESENT	0
320086	317486	19657G	PARTICIPANT	\N	PRESENT	0
320087	317486	19577H	PARTICIPANT	\N	PRESENT	0
320088	317486	19760E	PARTICIPANT	\N	PRESENT	0
320089	317486	14119M	PARTICIPANT	\N	PRESENT	0
320090	317486	11067R	PARTICIPANT	\N	PRESENT	0
320091	318025	19503N	PARTICIPANT	\N	PRESENT	0
320092	318025	19347U	PARTICIPANT	\N	PRESENT	0
320093	318025	14157T	PARTICIPANT	\N	PRESENT	0
320094	318025	19525U	PARTICIPANT	\N	PRESENT	0
320095	318025	19713W	PARTICIPANT	\N	PRESENT	0
320096	318025	14237S	PARTICIPANT	\N	PRESENT	0
320097	317486	11077T	PARTICIPANT	\N	PRESENT	0
320099	318672	14001X	PARTICIPANT	\N	PRESENT	0
320100	318672	19581D	PARTICIPANT	\N	PRESENT	0
320101	318672	04047H	PARTICIPANT	\N	PRESENT	0
320102	318672	01028R	PARTICIPANT	\N	PRESENT	0
320103	318672	14231L	PARTICIPANT	\N	PRESENT	0
320104	318672	19447X	PARTICIPANT	\N	PRESENT	0
320105	318672	05008E	PRESIDENT	0	PRESENT	0
320106	318672	14147R	PARTICIPANT	\N	PRESENT	0
320107	318672	14179A	PARTICIPANT	\N	PRESENT	0
320108	318672	14215L	PARTICIPANT	\N	PRESENT	0
320109	318672	14259Y	PARTICIPANT	\N	PRESENT	0
320110	318672	11072N	PARTICIPANT	\N	PRESENT	0
320111	318672	14053L	PARTICIPANT	\N	PRESENT	0
320112	318672	19649G	PARTICIPANT	\N	PRESENT	0
320113	318672	14111D	PARTICIPANT	\N	PRESENT	0
320114	318672	07034Q	PARTICIPANT	\N	PRESENT	0
320115	318672	08045X	PARTICIPANT	\N	PRESENT	0
320116	318672	10015M	PARTICIPANT	\N	PRESENT	0
320117	318672	19253P	PARTICIPANT	\N	PRESENT	0
320118	318672	01024M	PARTICIPANT	\N	PRESENT	0
320119	318672	04038G	PARTICIPANT	\N	PRESENT	0
320120	318672	19719D	PARTICIPANT	\N	PRESENT	0
320121	318672	11033F	PARTICIPANT	\N	PRESENT	0
320122	318672	14089Y	PARTICIPANT	\N	PRESENT	0
320123	318672	19729F	PARTICIPANT	\N	PRESENT	0
320124	318672	19629C	PARTICIPANT	\N	PRESENT	0
320125	318672	19762G	PARTICIPANT	\N	PRESENT	0
320126	318672	19543W	PARTICIPANT	\N	EXCUSE	0
320127	318672	04044E	PARTICIPANT	\N	EXCUSE	0
320128	317486	11031D	PARTICIPANT	\N	PRESENT	0
320129	318025	02002K	PARTICIPANT	\N	PRESENT	0
320130	317486	19553Y	PARTICIPANT	\N	PRESENT	0
320131	318025	19733B	PARTICIPANT	\N	PRESENT	0
320132	318025	04085P	PARTICIPANT	\N	PRESENT	0
320139	318859	14097Y	PARTICIPANT	\N	PRESENT	0
320140	318859	04035D	PARTICIPANT	\N	PRESENT	0
320141	318859	95030B	PARTICIPANT	\N	PRESENT	0
320142	318859	04034C	PARTICIPANT	\N	PRESENT	0
320143	318859	11041F	PARTICIPANT	\N	PRESENT	0
320144	318859	14235Q	PARTICIPANT	\N	PRESENT	0
320145	318859	08058D	PARTICIPANT	\N	PRESENT	0
320146	318859	04042C	PRESIDENT	0	PRESENT	0
320147	318859	14028W	PARTICIPANT	\N	PRESENT	0
320148	318859	11054L	PARTICIPANT	\N	PRESENT	0
320149	318859	11066Q	PARTICIPANT	\N	PRESENT	0
320150	318859	19669L	PARTICIPANT	\N	PRESENT	0
320151	318859	08056B	PARTICIPANT	\N	PRESENT	0
320152	318859	14105F	PARTICIPANT	\N	PRESENT	0
320153	318859	98018T	PRESIDENT	1	PRESENT	0
320154	318859	14267Y	PARTICIPANT	\N	PRESENT	0
320155	318859	08049C	PARTICIPANT	\N	PRESENT	0
320156	318859	14193X	PARTICIPANT	\N	PRESENT	0
320157	318859	98050T	PARTICIPANT	\N	PRESENT	0
320158	318859	08061X	PARTICIPANT	\N	PRESENT	0
320159	318859	14211G	PARTICIPANT	\N	PRESENT	0
320160	318859	14255U	PARTICIPANT	\N	PRESENT	0
320161	318859	08047A	PARTICIPANT	\N	PRESENT	0
320162	318859	98029W	PARTICIPANT	\N	PRESENT	0
320163	318859	11080N	PARTICIPANT	\N	PRESENT	0
320164	318859	01058X	PARTICIPANT	\N	PRESENT	0
320165	318859	04040A	PARTICIPANT	\N	PRESENT	0
320166	318859	95037J	PARTICIPANT	\N	PRESENT	0
320167	318859	14055N	PARTICIPANT	\N	PRESENT	0
320168	318859	01062T	PARTICIPANT	\N	PRESENT	0
320169	318859	19443T	PARTICIPANT	\N	PRESENT	0
320170	318859	08053X	PARTICIPANT	\N	PRESENT	0
320171	318859	19721W	PARTICIPANT	\N	PRESENT	0
320172	318859	98022P	PARTICIPANT	\N	PRESENT	0
320173	318672	14151M	PARTICIPANT	\N	PRESENT	0
320174	318672	14065Q	PARTICIPANT	\N	PRESENT	0
320175	318672	19725B	PARTICIPANT	\N	PRESENT	0
320176	318672	14069U	PARTICIPANT	\N	PRESENT	0
320177	318672	11049P	PARTICIPANT	\N	PRESENT	0
320178	318672	14021P	PARTICIPANT	\N	PRESENT	0
320179	318672	11085T	PARTICIPANT	\N	PRESENT	0
320180	318859	14079W	PARTICIPANT	\N	PRESENT	0
320181	318859	11115U	PARTICIPANT	\N	PRESENT	0
320183	320182	19577H	PARTICIPANT	\N	PRESENT	0
320184	318025	19701S	PARTICIPANT	\N	PRESENT	0
320185	318025	14103D	PARTICIPANT	\N	PRESENT	0
320186	318859	16685X	PARTICIPANT	\N	PRESENT	0
320187	318859	19421M	PARTICIPANT	\N	PRESENT	0
320188	317486	19569H	PARTICIPANT	\N	PRESENT	0
320189	317486	19527W	PARTICIPANT	\N	PRESENT	0
320190	317486	19663E	PARTICIPANT	\N	PRESENT	0
320191	317486	19715Y	PARTICIPANT	\N	PRESENT	0
320199	318859	95067Q	PARTICIPANT	\N	PRESENT	0
320200	318038	19333N	PARTICIPANT	\N	PRESENT	0
320201	318038	14103D	PARTICIPANT	\N	PRESENT	0
320202	318038	19713W	PARTICIPANT	\N	PRESENT	0
320203	318038	19549D	PARTICIPANT	\N	PRESENT	0
320204	318038	19387D	PARTICIPANT	\N	PRESENT	0
320205	318038	14219Q	PARTICIPANT	\N	PRESENT	0
320206	318038	08055A	PARTICIPANT	\N	PRESENT	0
320207	318038	19599P	PARTICIPANT	\N	PRESENT	0
320208	318038	19637C	PARTICIPANT	\N	PRESENT	0
320209	318038	14051J	PARTICIPANT	\N	PRESENT	0
320210	318038	08060W	PARTICIPANT	\N	PRESENT	0
320211	318038	08009T	PRESIDENT	0	PRESENT	0
320212	318038	19347U	PARTICIPANT	\N	PRESENT	0
320213	318038	19503N	PARTICIPANT	\N	PRESENT	0
320214	318038	19745F	PARTICIPANT	\N	PRESENT	0
320215	318038	08024S	PARTICIPANT	\N	PRESENT	0
320216	318038	96004D	PARTICIPANT	\N	EXCUSE	0
320217	318038	04097T	PARTICIPANT	\N	EXCUSE	0
320218	318038	19685L	PARTICIPANT	\N	EXCUSE	0
320219	318038	19659J	PARTICIPANT	\N	EXCUSE	0
320220	318038	14038Y	PARTICIPANT	\N	PRESENT	0
320221	318038	19701S	PARTICIPANT	\N	PRESENT	0
320222	318038	14169X	PARTICIPANT	\N	PRESENT	0
320223	318038	18083K	PARTICIPANT	\N	PRESENT	0
320224	318038	15447F	PARTICIPANT	\N	PRESENT	0
307131	305283	19701S	PARTICIPANT	\N	PRESENT	0
307132	305283	11067R	PARTICIPANT	\N	PRESENT	0
307135	306069	14259Y	PARTICIPANT	\N	PRESENT	0
307163	306069	14053L	PARTICIPANT	\N	PRESENT	0
307174	306069	14001X	PARTICIPANT	\N	PRESENT	0
307176	306069	14231L	PARTICIPANT	\N	PRESENT	0
309104	309069	04040A	PRESIDENT	0	PRESENT	0
309105	309069	08034U	PARTICIPANT	\N	EXCUSE	0
309126	309069	11101A	PARTICIPANT	\N	PRESENT	0
309215	309214	19721W	PARTICIPANT	\N	PRESENT	0
309216	309214	14079W	PARTICIPANT	\N	PRESENT	0
309217	309214	08052W	PARTICIPANT	\N	PRESENT	0
309218	309214	15447F	PARTICIPANT	\N	PRESENT	0
309219	309214	98022P	PARTICIPANT	\N	PRESENT	0
309220	309214	14097Y	PARTICIPANT	\N	PRESENT	0
309221	309214	19711U	PARTICIPANT	\N	PRESENT	0
309222	309214	11026G	PARTICIPANT	\N	PRESENT	0
309223	309214	01048V	PARTICIPANT	\N	PRESENT	0
309224	309214	19503N	PARTICIPANT	\N	PRESENT	0
309225	309214	19421M	PARTICIPANT	\N	PRESENT	0
309226	309214	98050T	PARTICIPANT	\N	PRESENT	0
309227	309214	95067Q	PARTICIPANT	\N	PRESENT	0
309238	305977	08053X	PARTICIPANT	\N	EXCUSE	0
309240	309239	14207L	PARTICIPANT	\N	PRESENT	0
309241	309239	19507S	PARTICIPANT	\N	PRESENT	0
309242	309239	14197C	PARTICIPANT	\N	PRESENT	0
309243	309239	04049K	PARTICIPANT	\N	PRESENT	0
309244	309239	19369B	PARTICIPANT	\N	PRESENT	0
309245	309239	14265W	PARTICIPANT	\N	PRESENT	0
309246	309239	19619A	PARTICIPANT	\N	PRESENT	0
309247	309239	19413M	PARTICIPANT	\N	PRESENT	0
309248	309239	14033T	PARTICIPANT	\N	PRESENT	0
309249	309239	14187A	PARTICIPANT	\N	PRESENT	0
309250	309239	14109K	PARTICIPANT	\N	PRESENT	0
309251	309239	19347U	PARTICIPANT	\N	PRESENT	0
309257	309255	11104D	PARTICIPANT	\N	PRESENT	0
309258	309252	11104D	PARTICIPANT	\N	PRESENT	0
309259	309253	11104D	PARTICIPANT	\N	PRESENT	0
309260	309253	19758L	PARTICIPANT	\N	PRESENT	0
309263	309261	14073Q	PARTICIPANT	\N	PRESENT	0
309264	309262	14073Q	PARTICIPANT	\N	PRESENT	0
310243	309056	19489J	PARTICIPANT	\N	PRESENT	0
310244	309056	14179A	PARTICIPANT	\N	PRESENT	0
310245	309056	14151M	PARTICIPANT	\N	PRESENT	0
310246	309056	08018U	PARTICIPANT	\N	PRESENT	0
310247	309056	19649G	PARTICIPANT	\N	PRESENT	0
310248	309056	11026G	PARTICIPANT	\N	PRESENT	0
310249	309056	19725B	PARTICIPANT	\N	PRESENT	0
310252	309124	14121F	PARTICIPANT	\N	PRESENT	0
310253	307294	08049C	PARTICIPANT	\N	PRESENT	0
310318	309265	19581D	PARTICIPANT	\N	PRESENT	0
310319	309265	14041T	PARTICIPANT	\N	PRESENT	0
310320	309265	04047H	PARTICIPANT	\N	PRESENT	0
310321	309265	95062K	PARTICIPANT	\N	PRESENT	0
310322	309265	19611R	PARTICIPANT	\N	PRESENT	0
310323	309265	96004D	PARTICIPANT	\N	PRESENT	0
310324	309265	14085U	PARTICIPANT	\N	PRESENT	0
310325	309265	01024M	PARTICIPANT	\N	PRESENT	0
310326	309265	11045K	PARTICIPANT	\N	PRESENT	0
310327	309265	19521Q	PARTICIPANT	\N	PRESENT	0
310328	309265	19667J	PARTICIPANT	\N	PRESENT	0
310329	309265	19669L	PARTICIPANT	\N	PRESENT	0
310330	309265	19683J	PARTICIPANT	\N	PRESENT	0
310331	309265	19689Q	PARTICIPANT	\N	PRESENT	0
310332	309265	14223L	PARTICIPANT	\N	PRESENT	0
310333	309265	19725B	PARTICIPANT	\N	PRESENT	0
310334	309265	04085P	PARTICIPANT	\N	PRESENT	0
310335	309265	14033T	PARTICIPANT	\N	PRESENT	0
310336	309265	19599P	PARTICIPANT	\N	PRESENT	0
310337	309265	19649G	PARTICIPANT	\N	PRESENT	0
310340	309265	11072N	PARTICIPANT	\N	PRESENT	0
310341	309265	14079W	PARTICIPANT	\N	PRESENT	0
310342	309265	07029T	PARTICIPANT	\N	PRESENT	0
310343	309265	11033F	PARTICIPANT	\N	PRESENT	0
310344	309265	14109K	PARTICIPANT	\N	PRESENT	0
310345	309265	14065Q	PARTICIPANT	\N	PRESENT	0
310346	309265	19479G	PARTICIPANT	\N	PRESENT	0
310347	309265	01025N	PARTICIPANT	\N	PRESENT	0
310348	309265	08017T	PARTICIPANT	\N	PRESENT	0
310349	309265	19629C	PARTICIPANT	\N	PRESENT	0
310350	309265	19253P	PARTICIPANT	\N	PRESENT	0
310351	309265	19335Q	PARTICIPANT	\N	PRESENT	0
310352	309265	08044W	PARTICIPANT	\N	PRESENT	0
310353	309265	14207L	PARTICIPANT	\N	PRESENT	0
310354	309265	19515S	PARTICIPANT	\N	PRESENT	0
310355	309265	19703U	PARTICIPANT	\N	PRESENT	0
310356	309265	19447X	PARTICIPANT	\N	PRESENT	0
310357	309265	14119M	PARTICIPANT	\N	PRESENT	0
310358	309265	19507S	PARTICIPANT	\N	PRESENT	0
310359	309265	08028W	PARTICIPANT	\N	PRESENT	0
310360	309265	04044E	PARTICIPANT	\N	PRESENT	0
310361	309265	10015M	PARTICIPANT	\N	PRESENT	0
310362	309265	04057K	PARTICIPANT	\N	PRESENT	0
310363	309265	19747H	PARTICIPANT	\N	PRESENT	0
310364	309265	14231L	PARTICIPANT	\N	PRESENT	0
310365	309265	19415P	PARTICIPANT	\N	PRESENT	0
310366	309265	11048N	PARTICIPANT	\N	PRESENT	0
310367	309265	14215L	PARTICIPANT	\N	PRESENT	0
310368	309265	07004J	PARTICIPANT	\N	PRESENT	0
310369	309265	14031R	PARTICIPANT	\N	PRESENT	0
310370	309265	04088S	PARTICIPANT	\N	PRESENT	0
310371	309265	14081Q	PARTICIPANT	\N	PRESENT	0
310372	309265	08038Y	PARTICIPANT	\N	PRESENT	0
310373	309265	19621T	PARTICIPANT	\N	PRESENT	0
310374	309265	19441R	PARTICIPANT	\N	PRESENT	0
310375	309265	14265W	PARTICIPANT	\N	PRESENT	0
310376	309265	19729F	PARTICIPANT	\N	PRESENT	0
310377	309265	14001X	PARTICIPANT	\N	PRESENT	0
310378	309265	08016S	PARTICIPANT	\N	PRESENT	0
310379	309265	19719D	PARTICIPANT	\N	PRESENT	0
310380	309265	14111D	PARTICIPANT	\N	PRESENT	0
310381	309265	19762G	PARTICIPANT	\N	PRESENT	0
310382	309265	14205J	PARTICIPANT	\N	PRESENT	0
310383	309265	19295A	PARTICIPANT	\N	PRESENT	0
310384	309265	08045X	PARTICIPANT	\N	PRESENT	0
310385	309265	01028R	PARTICIPANT	\N	PRESENT	0
310386	309265	05008E	PARTICIPANT	\N	PRESENT	0
310387	309265	14029X	PARTICIPANT	\N	PRESENT	0
310388	309265	95063L	PARTICIPANT	\N	PRESENT	0
310389	309265	04034C	PARTICIPANT	\N	PRESENT	0
310390	309265	14179A	PARTICIPANT	\N	PRESENT	0
310391	309265	17589D	PARTICIPANT	\N	PRESENT	0
310392	309265	14063N	PARTICIPANT	\N	PRESENT	0
310393	309265	19647E	PARTICIPANT	\N	PRESENT	0
310394	309265	19643A	PARTICIPANT	\N	PRESENT	0
310395	309265	14115H	PARTICIPANT	\N	PRESENT	0
310396	309265	11103C	PARTICIPANT	\N	PRESENT	0
310397	309265	14038Y	PARTICIPANT	\N	PRESENT	0
310398	309265	19619A	PARTICIPANT	\N	PRESENT	0
310399	309265	14217N	PARTICIPANT	\N	PRESENT	0
310400	309265	08015R	PARTICIPANT	\N	PRESENT	0
310401	309265	14083S	PARTICIPANT	\N	PRESENT	0
310402	309265	08034U	PARTICIPANT	\N	PRESENT	0
310403	309265	19731Y	PARTICIPANT	\N	PRESENT	0
310404	309265	19768N	PARTICIPANT	\N	PRESENT	0
310405	309265	14219Q	PARTICIPANT	\N	PRESENT	0
310406	309265	19727D	PARTICIPANT	\N	PRESENT	0
310407	309265	08061X	PARTICIPANT	\N	PRESENT	0
310408	309265	14193X	PARTICIPANT	\N	PRESENT	0
310409	309265	98050T	PARTICIPANT	\N	PRESENT	0
310410	309265	19565D	PARTICIPANT	\N	PRESENT	0
310411	309265	19681G	PARTICIPANT	\N	PRESENT	0
310412	309265	19333N	PARTICIPANT	\N	PRESENT	0
310413	309265	01057W	PARTICIPANT	\N	PRESENT	0
310414	309265	08020N	PARTICIPANT	\N	PRESENT	0
310415	309265	19399H	PARTICIPANT	\N	PRESENT	0
310416	309265	19467C	PARTICIPANT	\N	PRESENT	0
310417	309265	14151M	PARTICIPANT	\N	PRESENT	0
310418	309265	19383Y	PARTICIPANT	\N	PRESENT	0
310422	309265	14147R	PARTICIPANT	\N	PRESENT	0
310423	309265	14173T	PARTICIPANT	\N	PRESENT	0
310424	309265	80013X	PARTICIPANT	\N	PRESENT	0
310425	309265	04086Q	PARTICIPANT	\N	PRESENT	0
310426	309265	19733B	PARTICIPANT	\N	PRESENT	0
310427	309265	19553Y	PARTICIPANT	\N	PRESENT	0
310428	309265	14201E	PARTICIPANT	\N	PRESENT	0
310429	309265	19663E	PARTICIPANT	\N	PRESENT	0
310430	309265	14197C	PARTICIPANT	\N	PRESENT	0
310431	309265	08055A	PARTICIPANT	\N	PRESENT	0
310432	309265	14042U	PARTICIPANT	\N	PRESENT	0
310433	309265	16685X	PARTICIPANT	\N	PRESENT	0
310434	309265	19489J	PARTICIPANT	\N	PRESENT	0
310435	309265	14225N	PARTICIPANT	\N	PRESENT	0
310436	309265	11101A	PARTICIPANT	\N	PRESENT	0
310437	309265	95030B	PARTICIPANT	\N	PRESENT	0
310438	309265	08010L	PARTICIPANT	\N	PRESENT	0
310439	309265	14061L	PARTICIPANT	\N	PRESENT	0
310440	309265	19367Y	PARTICIPANT	\N	PRESENT	0
310441	309265	19575F	PARTICIPANT	\N	PRESENT	0
326227	324892	01048V	PARTICIPANT	\N	PRESENT	0
326228	314165	08053X	PARTICIPANT	\N	PRESENT	0
326229	314165	14205J	PARTICIPANT	\N	PRESENT	0
326230	314165	01024M	PARTICIPANT	\N	PRESENT	0
326231	314165	19703U	PARTICIPANT	\N	PRESENT	0
326232	314165	11103C	PARTICIPANT	\N	PRESENT	0
326233	314165	14179A	PARTICIPANT	\N	PRESENT	0
326234	322456	19399H	PARTICIPANT	\N	PRESENT	0
326235	314165	14030Q	PARTICIPANT	\N	PRESENT	0
326236	324892	19545Y	PARTICIPANT	\N	PRESENT	0
326237	314165	01025N	PARTICIPANT	\N	PRESENT	0
326238	314165	14267Y	PARTICIPANT	\N	PRESENT	0
326239	314165	14193X	PARTICIPANT	\N	PRESENT	0
326240	314165	14053L	PARTICIPANT	\N	PRESENT	0
326241	314165	04070G	PARTICIPANT	\N	PRESENT	0
326242	314165	14042U	PARTICIPANT	\N	PRESENT	0
326243	314165	14229S	PARTICIPANT	\N	PRESENT	0
326244	314165	19693L	PARTICIPANT	\N	PRESENT	0
326301	314181	14109K	PARTICIPANT	\N	PRESENT	0
326302	314181	08058D	PARTICIPANT	\N	PRESENT	0
326303	314181	08060W	PARTICIPANT	\N	PRESENT	0
326304	314181	08017T	PARTICIPANT	\N	PRESENT	0
326305	314181	11083R	PARTICIPANT	\N	PRESENT	0
326306	314181	17589D	PARTICIPANT	\N	PRESENT	0
326307	314181	04057K	PARTICIPANT	\N	PRESENT	0
326308	314181	19593H	PARTICIPANT	\N	PRESENT	0
326309	314181	19737F	PARTICIPANT	\N	PRESENT	0
326310	314181	19699S	PARTICIPANT	\N	PRESENT	0
326311	314181	19611R	PARTICIPANT	\N	PRESENT	0
326312	314181	19581D	PARTICIPANT	\N	PRESENT	0
326313	314181	19747H	PARTICIPANT	\N	PRESENT	0
326314	314181	14191V	PARTICIPANT	\N	PRESENT	0
326315	314181	08031R	PARTICIPANT	\N	PRESENT	0
326316	314181	95030B	PARTICIPANT	\N	PRESENT	0
326317	314181	14105F	PARTICIPANT	\N	PRESENT	0
326318	314181	19693L	PARTICIPANT	\N	PRESENT	0
326319	314181	14042U	PARTICIPANT	\N	PRESENT	0
326320	314181	19735D	PARTICIPANT	\N	PRESENT	0
326321	314181	14229S	PARTICIPANT	\N	PRESENT	0
326322	314181	08043V	PARTICIPANT	\N	PRESENT	0
326323	314181	14147R	PARTICIPANT	\N	PRESENT	0
326324	314181	11109J	PARTICIPANT	\N	PRESENT	0
326325	314181	19703U	PARTICIPANT	\N	PRESENT	0
326326	314181	11101A	PARTICIPANT	\N	PRESENT	0
326329	314181	14241N	PARTICIPANT	\N	PRESENT	0
326330	314181	19681G	PARTICIPANT	\N	PRESENT	0
326331	314181	19507S	PARTICIPANT	\N	PRESENT	0
326332	314181	19467C	PARTICIPANT	\N	PRESENT	0
326333	314181	19741B	PARTICIPANT	\N	PRESENT	0
326334	314181	19629C	PARTICIPANT	\N	PRESENT	0
326335	314181	19675J	PARTICIPANT	\N	PRESENT	0
326336	314181	07029T	PARTICIPANT	\N	PRESENT	0
326337	314181	11056N	PARTICIPANT	\N	PRESENT	0
326338	314181	19760E	PARTICIPANT	\N	PRESENT	0
326339	314181	08068F	PARTICIPANT	\N	PRESENT	0
326378	314169	11026G	PARTICIPANT	\N	PRESENT	0
326379	314169	19565D	PARTICIPANT	\N	PRESENT	0
326380	314169	19717B	PARTICIPANT	\N	PRESENT	0
326381	314169	11064N	PARTICIPANT	\N	PRESENT	0
326382	314169	11083R	PARTICIPANT	\N	PRESENT	0
326383	314169	19569H	PARTICIPANT	\N	PRESENT	0
326384	314169	14089Y	PARTICIPANT	\N	PRESENT	0
326385	314169	17583W	PARTICIPANT	\N	PRESENT	0
326386	314169	08062Y	PARTICIPANT	\N	PRESENT	0
326387	314169	07029T	PARTICIPANT	\N	PRESENT	0
326388	314169	11090Q	PARTICIPANT	\N	PRESENT	0
326389	314169	99004R	PARTICIPANT	\N	PRESENT	0
326390	314169	19347U	PARTICIPANT	\N	PRESENT	0
326391	314169	19441R	PARTICIPANT	\N	PRESENT	0
326392	314169	19766L	PARTICIPANT	\N	PRESENT	0
326393	314169	19681G	PARTICIPANT	\N	PRESENT	0
326394	314169	11077T	PARTICIPANT	\N	PRESENT	0
326299	314181	11027H	PARTICIPANT	\N	PRESENT	0
326300	314181	04070G	PARTICIPANT	\N	PRESENT	0
326395	314169	14001X	PARTICIPANT	\N	PRESENT	0
326396	314169	14205J	PARTICIPANT	\N	PRESENT	0
326397	314169	95030B	PARTICIPANT	\N	PRESENT	0
326398	314169	11110B	PARTICIPANT	\N	PRESENT	0
326399	314169	14147R	PARTICIPANT	\N	PRESENT	0
326400	314169	19521Q	PARTICIPANT	\N	PRESENT	0
326401	314169	14021P	PARTICIPANT	\N	PRESENT	0
326402	314169	19383Y	PARTICIPANT	\N	PRESENT	0
326403	314169	14071N	PARTICIPANT	\N	PRESENT	0
326404	314169	19507S	PARTICIPANT	\N	PRESENT	0
326405	314169	01062T	PARTICIPANT	\N	PRESENT	0
326406	314169	19741B	PARTICIPANT	\N	PRESENT	0
326407	314169	14265W	PARTICIPANT	\N	PRESENT	0
326408	314169	14219Q	PARTICIPANT	\N	PRESENT	0
326567	325784	19565D	PARTICIPANT	\N	PRESENT	0
326568	325784	19441R	PARTICIPANT	\N	PRESENT	0
326569	325784	14081Q	PARTICIPANT	\N	PRESENT	0
326570	325784	19413M	PARTICIPANT	\N	PRESENT	0
326571	325784	19631V	PARTICIPANT	\N	PRESENT	0
326376	314169	01043Q	PARTICIPANT	\N	PRESENT	0
326377	314169	19695N	PARTICIPANT	\N	PRESENT	0
326572	325784	08021P	PARTICIPANT	\N	PRESENT	0
326573	325784	08068F	PARTICIPANT	\N	PRESENT	0
326574	325784	08015R	PARTICIPANT	\N	PRESENT	0
326575	325784	08019V	PARTICIPANT	\N	PRESENT	0
326576	325784	19369B	PARTICIPANT	\N	PRESENT	0
326577	325784	14265W	PARTICIPANT	\N	PRESENT	0
326578	325784	14329V	PARTICIPANT	\N	PRESENT	0
326579	325784	19467C	PARTICIPANT	\N	PRESENT	0
326580	325784	14187A	PARTICIPANT	\N	PRESENT	0
326581	325784	08062Y	PARTICIPANT	\N	PRESENT	0
326582	325784	14033T	PARTICIPANT	\N	PRESENT	0
326583	325784	11090Q	PRESIDENT	0	PRESENT	0
326584	325784	01025N	PARTICIPANT	\N	PRESENT	0
326585	325784	14205J	PARTICIPANT	\N	PRESENT	0
326586	325784	11056N	PARTICIPANT	\N	PRESENT	0
326587	325784	04089T	PARTICIPANT	\N	PRESENT	0
326588	325784	14115H	PARTICIPANT	\N	PRESENT	0
326589	325784	11101A	PARTICIPANT	\N	PRESENT	0
326590	325784	19507S	PARTICIPANT	\N	PRESENT	0
326591	325784	19747H	PARTICIPANT	\N	PRESENT	0
326592	325784	14207L	PARTICIPANT	\N	PRESENT	0
326593	325784	04043D	PARTICIPANT	\N	PRESENT	0
326594	325784	17589D	PARTICIPANT	\N	PRESENT	0
326595	325784	14257W	PARTICIPANT	\N	PRESENT	0
327000	325057	19581D	PARTICIPANT	\N	PRESENT	0
327001	325057	01024M	PARTICIPANT	\N	PRESENT	0
327007	327004	01028R	PARTICIPANT	\N	PRESENT	0
327010	327009	01028R	PARTICIPANT	\N	PRESENT	0
327588	321318	11027H	PARTICIPANT	\N	PRESENT	0
327589	327587	19593H	PARTICIPANT	\N	PRESENT	0
327590	327587	04070G	PRESIDENT	0	PRESENT	0
327591	327587	19699S	PARTICIPANT	\N	PRESENT	0
327592	327587	04057K	PARTICIPANT	\N	PRESENT	0
327593	327587	08043V	PARTICIPANT	\N	PRESENT	0
327594	327587	19693L	PARTICIPANT	\N	PRESENT	0
327595	327587	14030Q	PARTICIPANT	\N	PRESENT	0
327596	327587	04059M	PARTICIPANT	\N	PRESENT	0
327597	327587	14109K	PARTICIPANT	\N	PRESENT	0
327598	327587	19335Q	PARTICIPANT	\N	PRESENT	0
327599	327587	11104D	PARTICIPANT	\N	PRESENT	0
327600	327587	19749K	PARTICIPANT	\N	PRESENT	0
327601	327587	04018C	PARTICIPANT	\N	PRESENT	0
327602	327587	08031R	PARTICIPANT	\N	PRESENT	0
327681	321318	19749K	PARTICIPANT	\N	PRESENT	0
327682	321318	14173T	PARTICIPANT	\N	PRESENT	0
327683	321318	14041T	PARTICIPANT	\N	PRESENT	0
327684	321318	19399H	PARTICIPANT	\N	PRESENT	0
327685	321318	19349W	PARTICIPANT	\N	PRESENT	0
327686	321318	14147R	PARTICIPANT	\N	PRESENT	0
327687	321318	19679N	PARTICIPANT	\N	PRESENT	0
327688	321318	14331P	PARTICIPANT	\N	PRESENT	0
327689	321318	99004R	PARTICIPANT	\N	PRESENT	0
327690	321318	14225N	PARTICIPANT	\N	PRESENT	0
327691	321318	19333N	PARTICIPANT	\N	PRESENT	0
327692	321318	19687N	PARTICIPANT	\N	PRESENT	0
327693	321318	19715Y	PARTICIPANT	\N	PRESENT	0
327694	321318	19741B	PARTICIPANT	\N	PRESENT	0
327695	321318	19667J	PARTICIPANT	\N	PRESENT	0
327696	321318	04086Q	PARTICIPANT	\N	PRESENT	0
327697	321318	11074Q	PARTICIPANT	\N	PRESENT	0
327698	321318	08011M	PARTICIPANT	\N	PRESENT	0
327699	321318	14085U	PARTICIPANT	\N	PRESENT	0
327700	321318	14097Y	PARTICIPANT	\N	PRESENT	0
327701	321318	15447F	PARTICIPANT	\N	PRESENT	0
327702	321318	19737F	PARTICIPANT	\N	PRESENT	0
327703	321318	14059S	PARTICIPANT	\N	PRESENT	0
327704	321318	19711U	PARTICIPANT	\N	PRESENT	0
327705	321318	07029T	PARTICIPANT	\N	PRESENT	0
327706	321318	19782L	PARTICIPANT	\N	PRESENT	0
327707	321318	98035U	PARTICIPANT	\N	PRESENT	0
327708	321318	19695N	PARTICIPANT	\N	PRESENT	0
327709	321318	19629C	PARTICIPANT	\N	PRESENT	0
327710	321318	14089Y	PARTICIPANT	\N	PRESENT	0
327711	321318	14267Y	PARTICIPANT	\N	PRESENT	0
305757	305756	11097X	PARTICIPANT	\N	PRESENT	0
305759	305758	11097X	PARTICIPANT	\N	PRESENT	0
305761	305760	11097X	PARTICIPANT	\N	PRESENT	0
305763	305762	11097X	PARTICIPANT	\N	PRESENT	0
305939	305938	19741B	PARTICIPANT	\N	EXCUSE	0
305940	305938	04038G	PARTICIPANT	\N	PRESENT	0
305941	305938	19253P	PARTICIPANT	\N	PRESENT	0
305942	305938	14357A	PARTICIPANT	\N	PRESENT	0
305943	305938	11070L	PARTICIPANT	\N	PRESENT	0
305944	305938	19711U	PARTICIPANT	\N	PRESENT	0
305945	305938	19689Q	PARTICIPANT	\N	PRESENT	0
305946	305938	04097T	PARTICIPANT	\N	PRESENT	0
305947	305938	11041F	PARTICIPANT	\N	EXCUSE	0
305948	305938	95062K	PARTICIPANT	\N	EXCUSE	0
305949	305938	08043V	PARTICIPANT	\N	EXCUSE	0
306953	305925	04044E	PARTICIPANT	\N	PRESENT	0
306954	305925	14105F	PARTICIPANT	\N	PRESENT	0
306955	305925	08044W	PARTICIPANT	\N	PRESENT	0
306956	305925	14021P	PARTICIPANT	\N	PRESENT	0
306957	305925	14193X	PARTICIPANT	\N	PRESENT	0
306971	305910	14331P	PARTICIPANT	\N	PRESENT	0
306972	305910	04071H	PARTICIPANT	\N	PRESENT	0
306973	305910	19545Y	PARTICIPANT	\N	PRESENT	0
306974	305910	01057W	PARTICIPANT	\N	PRESENT	0
306975	305910	11053K	PARTICIPANT	\N	PRESENT	0
306976	305910	19667J	PARTICIPANT	\N	PRESENT	0
306977	305910	11074Q	PRESIDENT	0	PRESENT	0
306978	305910	19671E	PARTICIPANT	\N	PRESENT	0
306979	305910	14225N	PARTICIPANT	\N	PRESENT	0
306980	305910	11070L	PARTICIPANT	\N	PRESENT	0
306981	305910	07029T	PARTICIPANT	\N	PRESENT	0
306982	305910	14085U	PARTICIPANT	\N	PRESENT	0
305147	305146	08015R	PARTICIPANT	\N	PRESENT	0
305752	305751	11097X	PARTICIPANT	\N	PRESENT	0
306983	305910	19349W	PARTICIPANT	\N	PRESENT	0
306984	305910	08010L	PARTICIPANT	\N	PRESENT	0
306985	305910	11048N	PARTICIPANT	\N	PRESENT	0
306986	305910	19479G	PARTICIPANT	\N	PRESENT	0
306987	305910	19711U	PARTICIPANT	\N	PRESENT	0
306988	305910	19689Q	PARTICIPANT	\N	PRESENT	0
306989	305910	14034U	PARTICIPANT	\N	PRESENT	0
306990	305910	14159V	PARTICIPANT	\N	PRESENT	0
306991	305910	04086Q	PARTICIPANT	\N	PRESENT	0
306992	305910	14083S	PARTICIPANT	\N	PRESENT	0
306993	305910	08073C	PARTICIPANT	\N	PRESENT	0
306994	305910	99004R	PARTICIPANT	\N	PRESENT	0
306995	305910	04061F	PARTICIPANT	\N	PRESENT	0
306996	305910	14327T	PARTICIPANT	\N	PRESENT	0
306997	305910	14199E	PARTICIPANT	\N	PRESENT	0
306998	305910	14121F	PARTICIPANT	\N	EXCUSE	0
307032	305954	18003S	PARTICIPANT	\N	EXCUSE	0
307035	305954	14299H	PARTICIPANT	\N	EXCUSE	0
307039	305954	14093U	PARTICIPANT	\N	PRESENT	0
307041	305954	19503N	PARTICIPANT	\N	PRESENT	0
307051	305921	11033F	PARTICIPANT	\N	EXCUSE	0
307052	305921	14065Q	PARTICIPANT	\N	EXCUSE	0
307053	305921	08045X	PARTICIPANT	\N	EXCUSE	0
307056	307055	04047H	PARTICIPANT	\N	PRESENT	0
307057	307055	01024M	PARTICIPANT	\N	PRESENT	0
307059	307058	04047H	PARTICIPANT	\N	PRESENT	0
307060	307058	01024M	PARTICIPANT	\N	PRESENT	0
307062	307061	04047H	PARTICIPANT	\N	PRESENT	0
307063	307061	01024M	PARTICIPANT	\N	PRESENT	0
307066	307065	11097X	PARTICIPANT	\N	PRESENT	0
307074	307069	19760E	PARTICIPANT	\N	PRESENT	0
307075	307071	19760E	PARTICIPANT	\N	PRESENT	0
307076	307072	19760E	PARTICIPANT	\N	PRESENT	0
307077	307073	19760E	PARTICIPANT	\N	PRESENT	0
307079	307078	11097X	PARTICIPANT	\N	PRESENT	0
307081	307080	11097X	PARTICIPANT	\N	PRESENT	0
307083	307082	11097X	PARTICIPANT	\N	PRESENT	0
307085	307084	11097X	PARTICIPANT	\N	PRESENT	0
307087	307086	11097X	PARTICIPANT	\N	PRESENT	0
307089	307088	11097X	PARTICIPANT	\N	PRESENT	0
307090	307088	01034P	PARTICIPANT	\N	PRESENT	0
307092	307091	11097X	PARTICIPANT	\N	PRESENT	0
307094	307093	11097X	PARTICIPANT	\N	PRESENT	0
307096	307095	11097X	PARTICIPANT	\N	PRESENT	0
307292	307136	08062Y	PARTICIPANT	\N	PRESENT	0
307293	307136	14157T	PARTICIPANT	\N	PRESENT	0
307295	307136	14241N	PARTICIPANT	\N	PRESENT	0
307296	307136	14061L	PARTICIPANT	\N	PRESENT	0
307297	307048	88008L	PARTICIPANT	\N	PRESENT	0
307298	307048	07029T	PARTICIPANT	\N	PRESENT	0
307299	307136	14069U	PARTICIPANT	\N	PRESENT	0
307300	307136	14231L	PARTICIPANT	\N	PRESENT	0
307301	307136	11104D	PARTICIPANT	\N	PRESENT	0
307302	307136	19503N	PARTICIPANT	\N	PRESENT	0
307303	307048	14225N	PARTICIPANT	\N	PRESENT	0
307430	307137	87003B	PARTICIPANT	\N	PRESENT	0
307431	307137	14191V	PARTICIPANT	\N	PRESENT	0
307432	307137	14253S	PARTICIPANT	\N	PRESENT	0
307433	307137	14173T	PARTICIPANT	\N	PRESENT	0
307434	307137	19709B	PARTICIPANT	\N	PRESENT	0
307435	307137	98018T	PARTICIPANT	\N	PRESENT	0
307436	307137	04088S	PARTICIPANT	\N	PRESENT	0
307437	307137	08062Y	PARTICIPANT	\N	PRESENT	0
307438	307137	19673G	PARTICIPANT	\N	PRESENT	0
307439	307137	08048B	PARTICIPANT	\N	PRESENT	0
307440	307137	19711U	PARTICIPANT	\N	PRESENT	0
307441	307137	14249W	PARTICIPANT	\N	PRESENT	0
307442	307137	14053L	PARTICIPANT	\N	PRESENT	0
307443	307137	14331P	PARTICIPANT	\N	PRESENT	0
307444	307137	11103C	PARTICIPANT	\N	PRESENT	0
307445	307137	95067Q	PARTICIPANT	\N	PRESENT	0
307446	307137	19515S	PARTICIPANT	\N	PRESENT	0
307447	307137	14355X	PARTICIPANT	\N	PRESENT	0
307448	307137	14059S	PARTICIPANT	\N	PRESENT	0
307449	307137	92040Q	PARTICIPANT	\N	PRESENT	0
307450	307137	95030B	PARTICIPANT	\N	PRESENT	0
307451	307137	19415P	PARTICIPANT	\N	PRESENT	0
307452	307137	18083K	PARTICIPANT	\N	PRESENT	0
307453	307137	95062K	PARTICIPANT	\N	PRESENT	0
307454	307137	08034U	PARTICIPANT	\N	PRESENT	0
307455	307137	04097T	PARTICIPANT	\N	PRESENT	0
307456	307137	07033P	PARTICIPANT	\N	PRESENT	0
307458	307137	19467C	PARTICIPANT	\N	PRESENT	0
307459	307137	19447X	PARTICIPANT	\N	PRESENT	0
307460	307137	19693L	PARTICIPANT	\N	PRESENT	0
307461	307137	19703U	PARTICIPANT	\N	PRESENT	0
307462	307137	14119M	PARTICIPANT	\N	PRESENT	0
307463	307137	19533U	PARTICIPANT	\N	PRESENT	0
307464	307137	15447F	PARTICIPANT	\N	PRESENT	0
307465	307137	17637T	PARTICIPANT	\N	PRESENT	0
307466	307137	98023Q	PARTICIPANT	\N	PRESENT	0
307467	307137	14031R	PARTICIPANT	\N	PRESENT	0
307468	307137	14123H	PARTICIPANT	\N	PRESENT	0
307469	307137	14211G	PARTICIPANT	\N	PRESENT	0
307470	307137	19443T	PARTICIPANT	\N	PRESENT	0
307471	307137	99004R	PARTICIPANT	\N	PRESENT	0
307472	307137	10006L	PARTICIPANT	\N	PRESENT	0
307473	307137	96004D	PARTICIPANT	\N	PRESENT	0
307474	307137	11048N	PARTICIPANT	\N	PRESENT	0
307475	307137	98050T	PARTICIPANT	\N	PRESENT	0
307476	307137	07034Q	PARTICIPANT	\N	PRESENT	0
307477	307137	14199E	PARTICIPANT	\N	PRESENT	0
307478	307137	19667J	PARTICIPANT	\N	PRESENT	0
307479	307137	08020N	PARTICIPANT	\N	PRESENT	0
307480	307137	19766L	PARTICIPANT	\N	PRESENT	0
307481	307137	10015M	PARTICIPANT	\N	PRESENT	0
307482	307137	11056N	PARTICIPANT	\N	PRESENT	0
307483	307137	14157T	PARTICIPANT	\N	PRESENT	0
307484	307137	01058X	PARTICIPANT	\N	PRESENT	0
307485	307137	12041X	PARTICIPANT	\N	PRESENT	0
307486	307137	19760E	PARTICIPANT	\N	PRESENT	0
307487	307137	19565D	PARTICIPANT	\N	PRESENT	0
307488	307137	14235Q	PARTICIPANT	\N	PRESENT	0
307489	307137	19695N	PARTICIPANT	\N	PRESENT	0
307490	307137	19687N	PARTICIPANT	\N	PRESENT	0
307491	307137	11040E	PARTICIPANT	\N	PRESENT	0
307492	307137	11033F	PARTICIPANT	\N	PRESENT	0
307493	307137	19593H	PARTICIPANT	\N	PRESENT	0
307494	307137	95063L	PARTICIPANT	\N	PRESENT	0
307495	307137	95037J	PARTICIPANT	\N	PRESENT	0
307496	307137	04045F	PARTICIPANT	\N	PRESENT	0
307497	307137	04034C	PARTICIPANT	\N	PRESENT	0
320225	318038	14029X	PARTICIPANT	\N	PRESENT	0
320226	318038	14157T	PARTICIPANT	\N	PRESENT	0
320227	318038	98023Q	PARTICIPANT	\N	PRESENT	0
320228	318038	19383Y	PARTICIPANT	\N	PRESENT	0
320229	318038	14191V	PARTICIPANT	\N	PRESENT	0
320230	318038	19737F	PARTICIPANT	\N	PRESENT	0
320232	318038	19525U	PARTICIPANT	\N	PRESENT	0
320233	318038	17583W	PARTICIPANT	\N	PRESENT	0
320234	318038	14237S	PARTICIPANT	\N	PRESENT	0
320236	318038	19733B	PARTICIPANT	\N	PRESENT	0
320237	319497	19565D	PARTICIPANT	\N	PRESENT	0
320238	319497	14357A	PARTICIPANT	\N	PRESENT	0
320239	319497	19413M	PARTICIPANT	\N	PRESENT	0
320240	319497	80013X	PARTICIPANT	\N	PRESENT	0
320241	319497	19631V	PARTICIPANT	\N	PRESENT	0
320242	319497	19705W	PARTICIPANT	\N	PRESENT	0
320243	319497	08015R	PARTICIPANT	\N	PRESENT	0
320244	319497	08019V	PARTICIPANT	\N	PRESENT	0
320245	319497	19369B	PARTICIPANT	\N	PRESENT	0
320246	319497	19511N	PARTICIPANT	\N	PRESENT	0
320247	319497	08028W	PARTICIPANT	\N	PRESENT	0
320248	319497	14265W	PARTICIPANT	\N	PRESENT	0
320249	319497	14329V	PARTICIPANT	\N	PRESENT	0
320250	319497	19467C	PARTICIPANT	\N	PRESENT	0
320251	319497	14187A	PARTICIPANT	\N	PRESENT	0
320252	319497	08038Y	PARTICIPANT	\N	PRESENT	0
320253	319497	19301E	PARTICIPANT	\N	PRESENT	0
320254	319497	19695N	PARTICIPANT	\N	PRESENT	0
320255	319497	14033T	PARTICIPANT	\N	PRESENT	0
320256	319497	11090Q	PARTICIPANT	\N	PRESENT	0
320257	319497	01025N	PARTICIPANT	\N	PRESENT	0
320258	319497	14205J	PARTICIPANT	\N	PRESENT	0
320259	319497	04088S	PARTICIPANT	\N	PRESENT	0
320260	319497	14115H	PARTICIPANT	\N	PRESENT	0
320261	319497	11101A	PARTICIPANT	\N	PRESENT	0
320262	319497	19507S	PARTICIPANT	\N	PRESENT	0
320263	319497	19747H	PARTICIPANT	\N	PRESENT	0
320264	319497	14207L	PARTICIPANT	\N	PRESENT	0
320265	319497	19619A	PARTICIPANT	\N	PRESENT	0
320266	319497	14257W	PARTICIPANT	\N	PRESENT	0
320267	319497	17589D	PARTICIPANT	\N	PRESENT	0
320268	319497	08068F	PARTICIPANT	\N	PRESENT	0
320269	319497	19269X	PARTICIPANT	\N	PRESENT	0
320270	319275	14327T	PARTICIPANT	\N	PRESENT	0
320271	319275	14331P	PARTICIPANT	\N	PRESENT	0
320272	319275	04071H	PARTICIPANT	\N	PRESENT	0
320273	319275	01048V	PARTICIPANT	\N	PRESENT	0
320274	319275	19545Y	PARTICIPANT	\N	PRESENT	0
320275	319275	01057W	PARTICIPANT	\N	PRESENT	0
320276	319275	11053K	PARTICIPANT	\N	PRESENT	0
320277	319275	11074Q	PRESIDENT	0	PRESENT	0
320278	319275	89017R	PARTICIPANT	\N	PRESENT	0
320279	319275	19667J	PARTICIPANT	\N	PRESENT	0
320280	319275	19671E	PARTICIPANT	\N	PRESENT	0
320281	319275	14225N	PARTICIPANT	\N	PRESENT	0
320282	319275	88008L	PARTICIPANT	\N	PRESENT	0
320283	319275	14085U	PARTICIPANT	\N	PRESENT	0
320284	319275	19349W	PARTICIPANT	\N	PRESENT	0
320285	319275	08010L	PARTICIPANT	\N	PRESENT	0
320286	319275	14253S	PARTICIPANT	\N	PRESENT	0
320287	319275	11048N	PARTICIPANT	\N	PRESENT	0
320288	319275	19479G	PARTICIPANT	\N	PRESENT	0
320289	319275	19647E	PARTICIPANT	\N	PRESENT	0
320290	319275	19711U	PARTICIPANT	\N	PRESENT	0
320291	319275	08069G	PARTICIPANT	\N	PRESENT	0
320292	319275	19687N	PARTICIPANT	\N	PRESENT	0
320293	319275	19689Q	PARTICIPANT	\N	PRESENT	0
320294	319275	12016W	PARTICIPANT	\N	PRESENT	0
320295	319275	08011M	PARTICIPANT	\N	PRESENT	0
320296	319275	14034U	PARTICIPANT	\N	PRESENT	0
320297	319275	14159V	PARTICIPANT	\N	PRESENT	0
320298	319275	14173T	PARTICIPANT	\N	PRESENT	0
320299	319275	11040E	PARTICIPANT	\N	PRESENT	0
320300	319275	04086Q	PARTICIPANT	\N	PRESENT	0
320301	319275	11012A	PARTICIPANT	\N	PRESENT	0
320302	319275	14199E	PARTICIPANT	\N	PRESENT	0
320303	319275	08073C	PARTICIPANT	\N	PRESENT	0
320304	319275	19741B	PARTICIPANT	\N	PRESENT	0
320305	319275	14121F	PARTICIPANT	\N	PRESENT	0
320306	319275	99004R	PARTICIPANT	\N	PRESENT	0
320307	319275	04061F	PARTICIPANT	\N	PRESENT	0
320308	319275	07029T	PARTICIPANT	\N	EXCUSE	0
320309	319275	08014Q	PARTICIPANT	\N	EXCUSE	0
320310	318672	95063L	PARTICIPANT	\N	PRESENT	0
320311	318672	98035U	PARTICIPANT	\N	PRESENT	0
320312	318672	19489J	PARTICIPANT	\N	PRESENT	0
320313	319497	19563B	PARTICIPANT	\N	PRESENT	0
320366	318859	19583F	PARTICIPANT	\N	EXCUSE	0
320493	314105	14135M	PARTICIPANT	\N	PRESENT	0
320491	314105	11077T	PARTICIPANT	\N	PRESENT	0
320492	314105	14191V	PARTICIPANT	\N	PRESENT	0
320494	314105	19415P	PARTICIPANT	\N	PRESENT	0
320495	319283	98018T	PARTICIPANT	\N	PRESENT	0
320496	314105	95037J	PARTICIPANT	\N	PRESENT	0
320497	314105	19575F	PARTICIPANT	\N	PRESENT	0
320498	314105	19681G	PARTICIPANT	\N	PRESENT	0
320499	314105	19383Y	PARTICIPANT	\N	PRESENT	0
320500	314105	98023Q	PARTICIPANT	\N	PRESENT	0
320501	314105	14069U	PARTICIPANT	\N	PRESENT	0
320502	314105	11083R	PARTICIPANT	\N	PRESENT	0
320503	314105	14215L	PARTICIPANT	\N	PRESENT	0
320504	319283	11074Q	PRESIDENT	1	PRESENT	0
320505	319283	14225N	PARTICIPANT	\N	PRESENT	0
320506	319283	19349W	PARTICIPANT	\N	PRESENT	0
320507	319283	14253S	PARTICIPANT	\N	PRESENT	0
320508	314105	19533U	PARTICIPANT	\N	PRESENT	0
320510	320509	19503N	PARTICIPANT	\N	PRESENT	0
320512	320511	19503N	PARTICIPANT	\N	PRESENT	0
320514	320513	19503N	PARTICIPANT	\N	PRESENT	0
320515	314105	19679N	PARTICIPANT	\N	PRESENT	0
320516	314105	98022P	PARTICIPANT	\N	PRESENT	0
320554	320553	08015R	PARTICIPANT	\N	PRESENT	0
320555	320553	14225N	PARTICIPANT	\N	PRESENT	0
320556	320553	19735D	PARTICIPANT	\N	PRESENT	0
320557	320553	14001X	PARTICIPANT	\N	PRESENT	0
320558	320553	19467C	PARTICIPANT	\N	PRESENT	0
320649	318050	19525U	PARTICIPANT	\N	PRESENT	0
320650	318050	19745F	PARTICIPANT	\N	PRESENT	0
320651	318050	11065P	PARTICIPANT	\N	PRESENT	0
320652	318050	95062K	PARTICIPANT	\N	PRESENT	0
320653	318050	19549D	PARTICIPANT	\N	PRESENT	0
320654	318050	19713W	PARTICIPANT	\N	PRESENT	0
320655	318050	80027E	PARTICIPANT	\N	PRESENT	0
320656	318050	05012A	PARTICIPANT	\N	PRESENT	0
320657	318050	14103D	PARTICIPANT	\N	PRESENT	0
320660	318050	19701S	PARTICIPANT	\N	PRESENT	0
320663	320363	19766L	PARTICIPANT	\N	PRESENT	0
320664	320363	04070G	PRESIDENT	0	PRESENT	0
320665	320363	19699S	PARTICIPANT	\N	PRESENT	0
320666	320363	19533U	PARTICIPANT	\N	PRESENT	0
320667	320363	14229S	PARTICIPANT	\N	PRESENT	0
320668	320363	14241N	PARTICIPANT	\N	PRESENT	0
320669	320363	19573D	PARTICIPANT	\N	PRESENT	0
320670	320363	14039A	PARTICIPANT	\N	PRESENT	0
320671	320363	14107H	PARTICIPANT	\N	PRESENT	0
320672	320363	08017T	PARTICIPANT	\N	PRESENT	0
320673	320363	08012N	PARTICIPANT	\N	PRESENT	0
320674	320363	08039A	PARTICIPANT	\N	PRESENT	0
320675	320363	08031R	PARTICIPANT	\N	PRESENT	0
320676	320363	19593H	PARTICIPANT	\N	PRESENT	0
320677	320363	19643A	PARTICIPANT	\N	PRESENT	0
320678	320363	14059S	PARTICIPANT	\N	PRESENT	0
320679	320363	14061L	PARTICIPANT	\N	PRESENT	0
320680	320363	04057K	PARTICIPANT	\N	PRESENT	0
320681	320363	14073Q	PARTICIPANT	\N	PRESENT	0
320682	320363	19611R	PARTICIPANT	\N	PRESENT	0
320683	320363	08043V	PARTICIPANT	\N	PRESENT	0
320684	320363	19693L	PARTICIPANT	\N	PRESENT	0
320685	320363	19399H	PARTICIPANT	\N	PRESENT	0
320686	320363	14030Q	PARTICIPANT	\N	PRESENT	0
320687	320363	19731Y	PARTICIPANT	\N	PRESENT	0
320688	320363	14251Q	PARTICIPANT	\N	PRESENT	0
320689	320363	04059M	PARTICIPANT	\N	PRESENT	0
320690	320363	19735D	PARTICIPANT	\N	PRESENT	0
320691	320363	14063N	PARTICIPANT	\N	PRESENT	0
320692	320363	14123H	PARTICIPANT	\N	PRESENT	0
320693	320363	11043H	PARTICIPANT	\N	PRESENT	0
320694	320363	11104D	PARTICIPANT	\N	PRESENT	0
320695	320363	04018C	PARTICIPANT	\N	PRESENT	0
320696	320363	19758L	PARTICIPANT	\N	PRESENT	0
320697	320363	19621T	PARTICIPANT	\N	PRESENT	0
320698	319336	14034U	PARTICIPANT	\N	PRESENT	0
320724	320363	14109K	PARTICIPANT	\N	EXCUSE	0
320725	320363	14249W	PARTICIPANT	\N	EXCUSE	0
320791	305885	19515S	PARTICIPANT	\N	PRESENT	0
320792	305885	04038G	PARTICIPANT	\N	PRESENT	0
320793	305885	04061F	PARTICIPANT	\N	PRESENT	0
320794	305885	19711U	PARTICIPANT	\N	PRESENT	0
320795	305885	14147R	PARTICIPANT	\N	PRESENT	0
305103	305102	19333N	PARTICIPANT	\N	PRESENT	0
305899	305883	19735D	PARTICIPANT	\N	EXCUSE	0
305908	305756	14217N	PARTICIPANT	\N	PRESENT	0
305912	305911	19533U	PARTICIPANT	\N	PRESENT	0
305915	305914	14093U	PARTICIPANT	\N	PRESENT	0
305917	305916	14093U	PARTICIPANT	\N	PRESENT	0
305919	305918	19533U	PARTICIPANT	\N	PRESENT	0
305923	305922	19533U	PARTICIPANT	\N	PRESENT	0
305931	305929	19533U	PARTICIPANT	\N	PRESENT	0
305934	305932	19533U	PARTICIPANT	\N	PRESENT	0
305937	305935	19533U	PARTICIPANT	\N	PRESENT	0
305951	305950	19533U	PARTICIPANT	\N	PRESENT	0
306924	306922	11040E	PARTICIPANT	\N	PRESENT	0
305958	305883	11101A	PARTICIPANT	\N	EXCUSE	0
306923	306922	04059M	PARTICIPANT	\N	PRESENT	0
306925	306922	14053L	PARTICIPANT	\N	PRESENT	0
306926	306922	11053K	PARTICIPANT	\N	PRESENT	0
306927	306922	04086Q	PARTICIPANT	\N	PRESENT	0
306928	306922	08052W	PARTICIPANT	\N	PRESENT	0
306929	306922	11070L	PARTICIPANT	\N	PRESENT	0
306930	306922	14041T	PARTICIPANT	\N	PRESENT	0
306931	306922	04089T	PARTICIPANT	\N	PRESENT	0
306932	306922	14034U	PARTICIPANT	\N	PRESENT	0
306933	306922	14231L	PARTICIPANT	\N	PRESENT	0
306934	306922	11064N	PARTICIPANT	\N	PRESENT	0
306935	306922	14081Q	PARTICIPANT	\N	PRESENT	0
306936	306922	14241N	PARTICIPANT	\N	PRESENT	0
306937	306922	14061L	PARTICIPANT	\N	PRESENT	0
306938	306922	14159V	PARTICIPANT	\N	PRESENT	0
306939	306922	86034E	PARTICIPANT	\N	PRESENT	0
306940	306922	08034U	PARTICIPANT	\N	PRESENT	0
306941	306922	01043Q	PARTICIPANT	\N	PRESENT	0
306942	306922	11077T	PARTICIPANT	\N	PRESENT	0
306943	306922	11072N	PARTICIPANT	\N	PRESENT	0
306944	306922	05012A	PARTICIPANT	\N	PRESENT	0
306945	306922	14135M	PARTICIPANT	\N	PRESENT	0
306946	306922	04044E	PARTICIPANT	\N	PRESENT	0
307029	307028	99004R	PARTICIPANT	\N	PRESENT	0
310442	309265	04049K	PARTICIPANT	\N	PRESENT	0
310443	309265	01058X	PARTICIPANT	\N	PRESENT	0
310444	309265	04035D	PARTICIPANT	\N	PRESENT	0
310445	309265	19563B	PARTICIPANT	\N	PRESENT	0
310446	309265	11056N	PARTICIPANT	\N	PRESENT	0
310447	309265	19573D	PARTICIPANT	\N	PRESENT	0
310461	309265	88008L	PARTICIPANT	\N	PRESENT	0
310463	309265	14213J	PARTICIPANT	\N	PRESENT	0
310465	309265	11012A	PARTICIPANT	\N	PRESENT	0
310466	309265	19723Y	PARTICIPANT	\N	PRESENT	0
310467	310257	11040E	PARTICIPANT	\N	PRESENT	0
310468	310257	14097Y	PARTICIPANT	\N	PRESENT	0
310469	310257	04035D	PARTICIPANT	\N	PRESENT	0
310470	310257	01062T	PARTICIPANT	\N	PRESENT	0
310471	310257	19421M	PARTICIPANT	\N	PRESENT	0
310472	310257	19709B	PARTICIPANT	\N	PRESENT	0
310473	310257	01057W	PARTICIPANT	\N	PRESENT	0
310474	310257	98022P	PARTICIPANT	\N	PRESENT	0
310475	310257	96004D	PARTICIPANT	\N	PRESENT	0
310476	310257	98050T	PRESIDENT	0	PRESENT	0
310477	310257	08031R	PARTICIPANT	\N	PRESENT	0
313507	313503	10015M	PARTICIPANT	\N	PRESENT	0
313578	305978	19709B	PARTICIPANT	\N	EXCUSE	0
313752	313750	08012N	PARTICIPANT	\N	PRESENT	0
313753	313750	11043H	PARTICIPANT	\N	PRESENT	0
313754	313751	08012N	PARTICIPANT	\N	PRESENT	0
313755	313751	11043H	PARTICIPANT	\N	PRESENT	0
313771	313770	11104D	PARTICIPANT	\N	PRESENT	0
313772	313769	11104D	PARTICIPANT	\N	PRESENT	0
313895	311346	98018T	PARTICIPANT	\N	EXCUSE	0
313896	311346	14028W	PARTICIPANT	\N	EXCUSE	0
313897	311346	11054L	PARTICIPANT	\N	EXCUSE	0
313901	313900	96004D	PARTICIPANT	\N	PRESENT	0
313902	313900	98050T	PARTICIPANT	\N	PRESENT	0
313904	313903	96004D	PARTICIPANT	\N	PRESENT	0
313905	313903	98050T	PARTICIPANT	\N	PRESENT	0
313906	313903	04061F	PARTICIPANT	\N	PRESENT	0
313907	313903	01058X	PARTICIPANT	\N	PRESENT	0
313908	313903	08043V	PARTICIPANT	\N	PRESENT	0
313909	313903	08017T	PARTICIPANT	\N	PRESENT	0
313910	313903	14205J	PARTICIPANT	\N	PRESENT	0
313911	313903	14331P	PARTICIPANT	\N	PRESENT	0
313912	313903	19333N	PARTICIPANT	\N	PRESENT	0
313913	313903	19569H	PARTICIPANT	\N	PRESENT	0
313916	313915	08019V	PARTICIPANT	\N	PRESENT	0
313940	313939	11064N	PARTICIPANT	\N	PRESENT	0
314266	314265	10006L	PARTICIPANT	\N	PRESENT	0
314269	314268	10006L	PARTICIPANT	\N	PRESENT	0
314271	314270	10006L	PARTICIPANT	\N	PRESENT	0
314273	314272	10006L	PARTICIPANT	\N	PRESENT	0
314275	314274	10006L	PARTICIPANT	\N	PRESENT	0
314277	314276	10006L	PARTICIPANT	\N	PRESENT	0
314279	314278	10006L	PARTICIPANT	\N	PRESENT	0
314281	314280	14119M	PARTICIPANT	\N	PRESENT	0
314283	314282	14119M	PARTICIPANT	\N	PRESENT	0
314285	314284	14119M	PARTICIPANT	\N	PRESENT	0
314287	314286	14119M	PARTICIPANT	\N	PRESENT	0
314352	314344	11090Q	PARTICIPANT	\N	PRESENT	0
314353	314344	19515S	PARTICIPANT	\N	PRESENT	0
314355	314344	14033T	PARTICIPANT	\N	PRESENT	0
314356	314344	19369B	PARTICIPANT	\N	PRESENT	0
314357	314344	04088S	PARTICIPANT	\N	PRESENT	0
314358	314344	14135M	PARTICIPANT	\N	PRESENT	0
314359	314344	19301E	PARTICIPANT	\N	PRESENT	0
314446	314445	14031R	PARTICIPANT	\N	PRESENT	0
314453	314452	98023Q	PARTICIPANT	\N	PRESENT	0
314455	314454	19563B	PARTICIPANT	\N	PRESENT	0
314456	314454	08043V	PARTICIPANT	\N	PRESENT	0
314467	314465	98029W	PARTICIPANT	\N	PRESENT	0
315944	315943	04042C	PARTICIPANT	\N	PRESENT	0
315945	315943	98018T	PARTICIPANT	\N	PRESENT	0
315946	315943	14193X	PARTICIPANT	\N	PRESENT	0
315947	315943	14133K	PARTICIPANT	\N	PRESENT	0
315948	315943	11054L	PARTICIPANT	\N	PRESENT	0
315949	315943	98022P	PARTICIPANT	\N	PRESENT	0
316458	316457	19729F	PARTICIPANT	\N	PRESENT	0
316861	316783	08019V	PARTICIPANT	\N	PRESENT	0
316862	316572	08019V	PARTICIPANT	\N	PRESENT	0
316863	316583	08019V	PARTICIPANT	\N	PRESENT	0
317220	317204	14331P	PARTICIPANT	\N	PRESENT	0
317224	317222	08009T	PARTICIPANT	\N	PRESENT	0
317226	317222	14029X	PARTICIPANT	\N	PRESENT	0
317227	317222	04085P	PARTICIPANT	\N	PRESENT	0
317229	317222	19333N	PARTICIPANT	\N	PRESENT	0
317231	317222	14038Y	PARTICIPANT	\N	PRESENT	0
317232	317222	19637C	PARTICIPANT	\N	PRESENT	0
317233	317222	19525U	PARTICIPANT	\N	PRESENT	0
317235	317222	19713W	PARTICIPANT	\N	PRESENT	0
317251	317250	08010L	PARTICIPANT	\N	PRESENT	0
317266	317262	01057W	PARTICIPANT	\N	PRESENT	0
317281	317280	08011M	PARTICIPANT	\N	PRESENT	0
317287	317286	14327T	PARTICIPANT	\N	PRESENT	0
317297	317296	14327T	PARTICIPANT	\N	PRESENT	0
317313	317312	11070L	PARTICIPANT	\N	PRESENT	0
317314	317312	19647E	PARTICIPANT	\N	PRESENT	0
317323	317322	14034U	PARTICIPANT	\N	PRESENT	0
317331	317330	19667J	PARTICIPANT	\N	PRESENT	0
317332	317330	11040E	PARTICIPANT	\N	PRESENT	0
317334	317333	11040E	PARTICIPANT	\N	PRESENT	0
317336	317335	19667J	PARTICIPANT	\N	PRESENT	0
317337	317335	11040E	PARTICIPANT	\N	PRESENT	0
317341	317340	19667J	PARTICIPANT	\N	PRESENT	0
318807	311803	14093U	PARTICIPANT	\N	EXCUSE	0
318884	311803	19723Y	PARTICIPANT	\N	EXCUSE	0
319207	305885	19369B	PARTICIPANT	\N	EXCUSE	0
319208	305885	19399H	PARTICIPANT	\N	PRESENT	0
319225	305885	08069G	PARTICIPANT	\N	EXCUSE	0
319261	305885	19629C	PARTICIPANT	\N	EXCUSE	0
319262	305885	08062Y	PARTICIPANT	\N	EXCUSE	0
319788	314090	15447F	PARTICIPANT	\N	PRESENT	0
319789	314090	11097X	PARTICIPANT	\N	PRESENT	0
319790	314090	19629C	PARTICIPANT	\N	PRESENT	0
319791	314090	19367Y	PARTICIPANT	\N	PRESENT	0
319792	314090	08044W	PARTICIPANT	\N	PRESENT	0
319793	314090	04045F	PARTICIPANT	\N	PRESENT	0
319794	314090	19697Q	PARTICIPANT	\N	PRESENT	0
319826	314090	04049K	PARTICIPANT	\N	PRESENT	0
319831	314090	14173T	PARTICIPANT	\N	PRESENT	0
319832	314090	14065Q	PARTICIPANT	\N	PRESENT	0
319837	314090	17583W	PARTICIPANT	\N	PRESENT	0
319838	314090	14215L	PARTICIPANT	\N	PRESENT	0
319839	314090	14147R	PARTICIPANT	\N	PRESENT	0
319840	314090	14223L	PARTICIPANT	\N	PRESENT	0
319841	314090	11083R	PARTICIPANT	\N	PRESENT	0
312064	312061	08031R	PARTICIPANT	\N	PRESENT	0
312066	312062	08031R	PARTICIPANT	\N	PRESENT	0
312256	312247	08012N	PARTICIPANT	\N	PRESENT	0
312257	312247	11043H	PARTICIPANT	\N	PRESENT	0
312258	312247	19611R	PARTICIPANT	\N	PRESENT	0
326791	322778	14097Y	PARTICIPANT	\N	PRESENT	0
326792	322778	14039A	PARTICIPANT	\N	PRESENT	0
326793	322778	14219Q	PARTICIPANT	\N	PRESENT	0
326794	322778	12016W	PARTICIPANT	\N	PRESENT	0
326795	322778	08019V	PARTICIPANT	\N	PRESENT	0
326796	322778	14059S	PARTICIPANT	\N	PRESENT	0
326797	322778	19657G	PARTICIPANT	\N	PRESENT	0
326798	322778	11072N	PARTICIPANT	\N	PRESENT	0
326799	322778	14275Y	PARTICIPANT	\N	PRESENT	0
326800	322778	19301E	PARTICIPANT	\N	PRESENT	0
326801	322778	19691J	PARTICIPANT	\N	PRESENT	0
326802	322778	11109J	PARTICIPANT	\N	PRESENT	0
327151	314174	11056N	PARTICIPANT	\N	PRESENT	0
327152	314174	19631V	PARTICIPANT	\N	PRESENT	0
327153	314174	19503N	PARTICIPANT	\N	PRESENT	0
327154	314174	14051J	PARTICIPANT	\N	PRESENT	0
327155	314174	08060W	PARTICIPANT	\N	PRESENT	0
327156	314174	08024S	PARTICIPANT	\N	PRESENT	0
327157	314174	19349W	PARTICIPANT	\N	PRESENT	0
327158	314174	98022P	PARTICIPANT	\N	PRESENT	0
327159	314174	14107H	PARTICIPANT	\N	PRESENT	0
327160	314174	14195A	PARTICIPANT	\N	PRESENT	0
327161	314174	19717B	PARTICIPANT	\N	PRESENT	0
327162	314174	19479G	PARTICIPANT	\N	PRESENT	0
327163	314174	19691J	PARTICIPANT	\N	PRESENT	0
327164	314174	19737F	PARTICIPANT	\N	PRESENT	0
327165	314174	14034U	PARTICIPANT	\N	PRESENT	0
327166	314174	19629C	PARTICIPANT	\N	PRESENT	0
327167	314174	11041F	PARTICIPANT	\N	PRESENT	0
327168	314174	08051V	PARTICIPANT	\N	PRESENT	0
327169	314174	88008L	PARTICIPANT	\N	PRESENT	0
327170	314174	14215L	PARTICIPANT	\N	PRESENT	0
327171	314174	19762G	PARTICIPANT	\N	PRESENT	0
327172	314174	19383Y	PARTICIPANT	\N	PRESENT	0
327173	314174	19675J	PARTICIPANT	\N	PRESENT	0
327174	314174	14217N	PARTICIPANT	\N	PRESENT	0
327175	314174	14059S	PARTICIPANT	\N	PRESENT	0
327176	314174	19729F	PARTICIPANT	\N	PRESENT	0
327177	314174	08034U	PARTICIPANT	\N	PRESENT	0
327178	314174	19399H	PARTICIPANT	\N	PRESENT	0
327179	314174	19693L	PARTICIPANT	\N	PRESENT	0
327180	314174	14199E	PARTICIPANT	\N	PRESENT	0
326789	322778	19577H	PARTICIPANT	\N	PRESENT	0
326790	322778	19715Y	PARTICIPANT	\N	PRESENT	0
327181	314174	01057W	PARTICIPANT	\N	PRESENT	0
327182	314174	14041T	PARTICIPANT	\N	PRESENT	0
327183	314174	18083K	PARTICIPANT	\N	PRESENT	0
327184	314174	14259Y	PARTICIPANT	\N	PRESENT	0
327185	314174	14191V	PARTICIPANT	\N	PRESENT	0
327186	314174	19741B	PARTICIPANT	\N	PRESENT	0
327187	314174	01058X	PARTICIPANT	\N	PRESENT	0
327188	314174	95062K	PARTICIPANT	\N	PRESENT	0
327189	324911	11067R	PARTICIPANT	\N	PRESENT	0
327190	324911	19649G	PARTICIPANT	\N	PRESENT	0
327191	324911	19415P	PARTICIPANT	\N	PRESENT	0
327192	324911	08043V	PARTICIPANT	\N	PRESENT	0
327193	324911	04047H	PARTICIPANT	\N	PRESENT	0
327194	324911	19673G	PARTICIPANT	\N	PRESENT	0
327195	324911	01028R	PARTICIPANT	\N	PRESENT	0
327196	324911	11033F	PARTICIPANT	\N	PRESENT	0
327197	324911	19723Y	PARTICIPANT	\N	PRESENT	0
327198	324911	19447X	PARTICIPANT	\N	PRESENT	0
327199	324911	14030Q	PARTICIPANT	\N	PRESENT	0
327200	324911	14147R	PARTICIPANT	\N	PRESENT	0
327201	324911	11083R	PARTICIPANT	\N	PRESENT	0
327202	324911	14213J	PARTICIPANT	\N	PRESENT	0
327203	324911	10006L	PRESIDENT	0	PRESENT	0
327204	324911	08031R	PARTICIPANT	\N	PRESENT	0
327205	314174	19367Y	PARTICIPANT	\N	PRESENT	0
327206	314174	14241N	PARTICIPANT	\N	PRESENT	0
327207	314174	19701S	PARTICIPANT	\N	PRESENT	0
327208	324911	19553Y	PARTICIPANT	\N	PRESENT	0
327209	324911	19749K	PARTICIPANT	\N	PRESENT	0
327212	314174	19745F	PARTICIPANT	\N	PRESENT	0
327213	314174	19347U	PARTICIPANT	\N	PRESENT	0
327214	314174	97011G	PARTICIPANT	\N	PRESENT	0
327216	314174	08049C	PARTICIPANT	\N	PRESENT	0
327217	314174	11104D	PARTICIPANT	\N	PRESENT	0
327218	314174	14235Q	PARTICIPANT	\N	PRESENT	0
327219	314174	14097Y	PARTICIPANT	\N	PRESENT	0
327220	324911	19533U	PARTICIPANT	\N	PRESENT	0
327221	324911	19569H	PARTICIPANT	\N	EXCUSE	0
327222	324911	14223L	PARTICIPANT	\N	EXCUSE	0
327223	324911	14231L	PARTICIPANT	\N	EXCUSE	0
327224	314174	17583W	PARTICIPANT	\N	PRESENT	0
327232	314174	14083S	PARTICIPANT	\N	PRESENT	0
327233	314174	17637T	PARTICIPANT	\N	PRESENT	0
327234	314174	11103C	PARTICIPANT	\N	PRESENT	0
327235	314174	19739H	PARTICIPANT	\N	PRESENT	0
327236	314174	08053X	PARTICIPANT	\N	PRESENT	0
327237	314174	14103D	PARTICIPANT	\N	PRESENT	0
327238	314174	14021P	PARTICIPANT	\N	PRESENT	0
327244	314174	14257W	PARTICIPANT	\N	PRESENT	0
327240	325790	80013X	PARTICIPANT	\N	PRESENT	0
327241	325790	04049K	PARTICIPANT	\N	PRESENT	0
327149	314174	01043Q	PARTICIPANT	\N	PRESENT	0
327150	314174	11012A	PARTICIPANT	\N	PRESENT	0
327242	325790	14187A	PARTICIPANT	\N	PRESENT	0
327243	314174	08045X	PARTICIPANT	\N	PRESENT	0
327245	314174	14239U	PARTICIPANT	\N	PRESENT	0
327246	314174	19269X	PARTICIPANT	\N	PRESENT	0
327247	314174	19659J	PARTICIPANT	\N	PRESENT	0
327248	314174	19333N	PARTICIPANT	\N	PRESENT	0
327249	314174	15447F	PARTICIPANT	\N	PRESENT	0
327250	314174	08061X	PARTICIPANT	\N	PRESENT	0
327251	314174	14069U	PARTICIPANT	\N	PRESENT	0
327252	314174	19551W	PARTICIPANT	\N	PRESENT	0
327336	314175	14275Y	PARTICIPANT	\N	PRESENT	0
327337	314175	19367Y	PARTICIPANT	\N	PRESENT	0
327394	314175	14217N	PARTICIPANT	\N	PRESENT	0
327395	314175	14061L	PARTICIPANT	\N	PRESENT	0
327396	314175	14033T	PARTICIPANT	\N	PRESENT	0
327397	324913	14331P	PARTICIPANT	\N	PRESENT	0
327398	324913	11048N	PARTICIPANT	\N	PRESENT	0
327399	324913	19647E	PARTICIPANT	\N	PRESENT	0
327400	324913	04071H	PARTICIPANT	\N	PRESENT	0
327401	324913	19711U	PARTICIPANT	\N	PRESENT	0
327402	324913	19531S	PARTICIPANT	\N	PRESENT	0
327403	324913	08034U	PARTICIPANT	\N	PRESENT	0
327404	324913	11053K	PARTICIPANT	\N	PRESENT	0
327405	324913	19667J	PARTICIPANT	\N	PRESENT	0
327406	324913	11074Q	PRESIDENT	0	PRESENT	0
327407	324913	08011M	PARTICIPANT	\N	PRESENT	0
327408	324913	04086Q	PARTICIPANT	\N	PRESENT	0
327409	324913	07029T	PARTICIPANT	\N	PRESENT	0
327410	324913	14085U	PARTICIPANT	\N	PRESENT	0
327411	324913	19741B	PARTICIPANT	\N	PRESENT	0
327412	324913	08010L	PARTICIPANT	\N	PRESENT	0
327413	324913	99004R	PARTICIPANT	\N	PRESENT	0
327414	324913	04061F	PARTICIPANT	\N	PRESENT	0
327415	314175	19701S	PARTICIPANT	\N	PRESENT	0
327416	314175	04044E	PARTICIPANT	\N	PRESENT	0
327417	314175	08062Y	PARTICIPANT	\N	PRESENT	0
327418	314175	19543W	PARTICIPANT	\N	PRESENT	0
327419	314175	08015R	PARTICIPANT	\N	PRESENT	0
327420	314175	07029T	PARTICIPANT	\N	PRESENT	0
327421	314175	19563B	PARTICIPANT	\N	PRESENT	0
327422	314175	08024S	PARTICIPANT	\N	PRESENT	0
327423	314175	14042U	PARTICIPANT	\N	PRESENT	0
327424	314175	19549D	PARTICIPANT	\N	PRESENT	0
327425	314175	14357A	PARTICIPANT	\N	PRESENT	0
327426	314175	19521Q	PARTICIPANT	\N	PRESENT	0
327427	314175	19333N	PARTICIPANT	\N	PRESENT	0
327428	314175	19553Y	PARTICIPANT	\N	PRESENT	0
327429	314175	01048V	PARTICIPANT	\N	PRESENT	0
327430	314175	14207L	PARTICIPANT	\N	PRESENT	0
327431	314175	11056N	PARTICIPANT	\N	PRESENT	0
327432	314175	14331P	PARTICIPANT	\N	PRESENT	0
327433	314175	11048N	PARTICIPANT	\N	PRESENT	0
327434	314175	19687N	PARTICIPANT	\N	PRESENT	0
327435	314175	95041E	PARTICIPANT	\N	PRESENT	0
327436	314175	80013X	PARTICIPANT	\N	PRESENT	0
303980	303978	04047H	PARTICIPANT	\N	PRESENT	0
303981	303978	01024M	PARTICIPANT	\N	PRESENT	0
303999	302442	11049P	PARTICIPANT	\N	PRESENT	0
304000	302442	04085P	PARTICIPANT	\N	PRESENT	0
304001	302442	12041X	PARTICIPANT	\N	PRESENT	0
304002	302442	14197C	PARTICIPANT	\N	PRESENT	0
304004	302583	14053L	PARTICIPANT	\N	PRESENT	0
304008	304007	04047H	PARTICIPANT	\N	PRESENT	0
304009	304007	01024M	PARTICIPANT	\N	PRESENT	0
307500	307137	19349W	PARTICIPANT	\N	PRESENT	0
307501	307137	19697Q	PARTICIPANT	\N	PRESENT	0
307502	307137	14169X	PARTICIPANT	\N	PRESENT	0
307503	307137	08073C	PARTICIPANT	\N	PRESENT	0
307504	307137	19659J	PARTICIPANT	\N	PRESENT	0
307505	307137	14223L	PARTICIPANT	\N	PRESENT	0
307509	307137	08028W	PARTICIPANT	\N	PRESENT	0
307510	307137	08024S	PARTICIPANT	\N	PRESENT	0
307511	307137	11043H	PARTICIPANT	\N	PRESENT	0
307512	307137	11072N	PARTICIPANT	\N	PRESENT	0
307513	307137	01057W	PARTICIPANT	\N	PRESENT	0
307526	307137	14195A	PARTICIPANT	\N	PRESENT	0
307515	307137	17589D	PARTICIPANT	\N	PRESENT	0
307516	307137	19585H	PARTICIPANT	\N	PRESENT	0
307517	307137	14111D	PARTICIPANT	\N	PRESENT	0
307518	307137	11115U	PARTICIPANT	\N	PRESENT	0
307519	307137	19545Y	PARTICIPANT	\N	PRESENT	0
307520	307137	14251Q	PARTICIPANT	\N	PRESENT	0
307521	307137	11090Q	PARTICIPANT	\N	PRESENT	0
307522	307137	19651A	PARTICIPANT	\N	PRESENT	0
307523	307137	19543W	PARTICIPANT	\N	PRESENT	0
307524	307137	19573D	PARTICIPANT	\N	PRESENT	0
307525	307137	11064N	PARTICIPANT	\N	PRESENT	0
307527	307137	11049P	PARTICIPANT	\N	PRESENT	0
307528	307137	11012A	PARTICIPANT	\N	PRESENT	0
307529	307137	08016S	PARTICIPANT	\N	PRESENT	0
307530	307137	19629C	PARTICIPANT	\N	PRESENT	0
307531	307137	08049C	PARTICIPANT	\N	PRESENT	0
307532	307137	14115H	PARTICIPANT	\N	PRESENT	0
307533	307137	19563B	PARTICIPANT	\N	PRESENT	0
307534	307137	08047A	PARTICIPANT	\N	PRESENT	0
307535	307137	14105F	PARTICIPANT	\N	PRESENT	0
307536	307137	14201E	PARTICIPANT	\N	PRESENT	0
307537	307137	14147R	PARTICIPANT	\N	PRESENT	0
307538	307137	14241N	PARTICIPANT	\N	PRESENT	0
307539	307137	98022P	PARTICIPANT	\N	PRESENT	0
307540	307137	88008L	PARTICIPANT	\N	PRESENT	0
307541	307137	14061L	PARTICIPANT	\N	PRESENT	0
307542	307137	11099A	PARTICIPANT	\N	PRESENT	0
307543	307137	14038Y	PARTICIPANT	\N	PRESENT	0
307544	307137	19723Y	PARTICIPANT	\N	PRESENT	0
307545	307137	19583F	PARTICIPANT	\N	PRESENT	0
307546	307137	86034E	PARTICIPANT	\N	PRESENT	0
307498	307137	19643A	PARTICIPANT	\N	PRESENT	0
307499	307137	11083R	PARTICIPANT	\N	PRESENT	0
307547	307137	19387D	PARTICIPANT	\N	PRESENT	0
307548	307137	19507S	PARTICIPANT	\N	PRESENT	0
307549	307137	19289C	PARTICIPANT	\N	PRESENT	0
307550	307137	19681G	PARTICIPANT	\N	PRESENT	0
307551	307137	14135M	PARTICIPANT	\N	PRESENT	0
307552	307137	19553Y	PARTICIPANT	\N	PRESENT	0
307553	307137	14107H	PARTICIPANT	\N	PRESENT	0
307554	307137	19399H	PARTICIPANT	\N	PRESENT	0
307555	307137	08031R	PARTICIPANT	\N	PRESENT	0
307556	307137	19729F	PARTICIPANT	\N	PRESENT	0
307557	307137	14034U	PARTICIPANT	\N	PRESENT	0
307558	307137	14265W	PARTICIPANT	\N	PRESENT	0
307559	307137	14055N	PARTICIPANT	\N	PRESENT	0
307560	307137	01060R	PARTICIPANT	\N	PRESENT	0
307561	307137	80027E	PARTICIPANT	\N	PRESENT	0
307562	307137	19741B	PARTICIPANT	\N	PRESENT	0
307563	307137	11074Q	PARTICIPANT	\N	PRESENT	0
307564	307137	14029X	PARTICIPANT	\N	PRESENT	0
307565	307137	04059M	PARTICIPANT	\N	PRESENT	0
307566	307137	14033T	PARTICIPANT	\N	PRESENT	0
307567	307137	11077T	PARTICIPANT	\N	PRESENT	0
307568	307137	19663E	PARTICIPANT	\N	PRESENT	0
307569	307137	11031D	PARTICIPANT	\N	PRESENT	0
307570	307137	14159V	PARTICIPANT	\N	PRESENT	0
307571	307137	98035U	PARTICIPANT	\N	PRESENT	0
307572	307137	08055A	PARTICIPANT	\N	PRESENT	0
307573	307137	19631V	PARTICIPANT	\N	PRESENT	0
307574	307137	08052W	PARTICIPANT	\N	PRESENT	0
307575	307137	08018U	PARTICIPANT	\N	PRESENT	0
307576	307137	07029T	PARTICIPANT	\N	PRESENT	0
307577	307137	19657G	PARTICIPANT	\N	PRESENT	0
307578	307137	11027H	PARTICIPANT	\N	PRESENT	0
307579	307137	14051J	PARTICIPANT	\N	PRESENT	0
307580	307137	19669L	PARTICIPANT	\N	PRESENT	0
307581	307137	08015R	PARTICIPANT	\N	PRESENT	0
307582	307137	12016W	PARTICIPANT	\N	PRESENT	0
307583	307137	17779H	PARTICIPANT	\N	PRESENT	0
307584	307137	19768N	PARTICIPANT	\N	PRESENT	0
307585	307137	14021P	PARTICIPANT	\N	PRESENT	0
307586	307137	19705W	PARTICIPANT	\N	PRESENT	0
307587	307137	08045X	PARTICIPANT	\N	PRESENT	0
307588	307137	14225N	PARTICIPANT	\N	PRESENT	0
307589	307137	11101A	PARTICIPANT	\N	PRESENT	0
307590	307137	14026U	PARTICIPANT	\N	PRESENT	0
307591	307137	04086Q	PARTICIPANT	\N	PRESENT	0
307592	307137	04092N	PARTICIPANT	\N	PRESENT	0
307593	307137	04044E	PARTICIPANT	\N	PRESENT	0
307594	307137	95041E	PARTICIPANT	\N	PRESENT	0
307595	307137	14187A	PARTICIPANT	\N	PRESENT	0
307596	307137	14071N	PARTICIPANT	\N	PRESENT	0
307597	307137	05008E	PARTICIPANT	\N	PRESENT	0
307598	307137	19599P	PARTICIPANT	\N	PRESENT	0
307599	307137	11097X	PARTICIPANT	\N	PRESENT	0
307600	307137	19421M	PARTICIPANT	\N	PRESENT	0
307601	307137	04033B	PARTICIPANT	\N	PRESENT	0
307602	307137	01062T	PARTICIPANT	\N	PRESENT	0
307603	307137	04043D	PARTICIPANT	\N	PRESENT	0
307604	307137	08038Y	PARTICIPANT	\N	PRESENT	0
307605	307137	80013X	PARTICIPANT	\N	PRESENT	0
307606	307137	11045K	PARTICIPANT	\N	PRESENT	0
307607	307137	14028W	PARTICIPANT	\N	PRESENT	0
307608	307137	04038G	PARTICIPANT	\N	PRESENT	0
307609	307137	14069U	PARTICIPANT	\N	PRESENT	0
307610	307137	19649G	PARTICIPANT	\N	PRESENT	0
307611	307137	05012A	PARTICIPANT	\N	PRESENT	0
307612	307137	14197C	PARTICIPANT	\N	PRESENT	0
307613	307137	19647E	PARTICIPANT	\N	PRESENT	0
307614	307137	19531S	PARTICIPANT	\N	PRESENT	0
307615	307137	19758L	PARTICIPANT	\N	PRESENT	0
307616	307137	14193X	PARTICIPANT	\N	PRESENT	0
307617	307137	17583W	PARTICIPANT	\N	PRESENT	0
307618	307137	19727D	PARTICIPANT	\N	PRESENT	0
307619	307137	08035V	PARTICIPANT	\N	PRESENT	0
307620	307137	14151M	PARTICIPANT	\N	PRESENT	0
307621	307137	08012N	PARTICIPANT	\N	PRESENT	0
307622	307137	11104D	PARTICIPANT	\N	PRESENT	0
307623	307137	97011G	PARTICIPANT	\N	PRESENT	0
307624	307137	08043V	PARTICIPANT	\N	PRESENT	0
307625	307137	19719D	PARTICIPANT	\N	PRESENT	0
307626	307137	14217N	PARTICIPANT	\N	PRESENT	0
307627	307137	11066Q	PARTICIPANT	\N	PRESENT	0
307628	307137	04061F	PARTICIPANT	\N	PRESENT	0
307629	307137	14065Q	PARTICIPANT	\N	PRESENT	0
307630	307137	14079W	PARTICIPANT	\N	PRESENT	0
307631	307137	19549D	PARTICIPANT	\N	PRESENT	0
307632	307137	19581D	PARTICIPANT	\N	PRESENT	0
307633	307137	19747H	PARTICIPANT	\N	PRESENT	0
307634	307137	14329V	PARTICIPANT	\N	PRESENT	0
307635	307137	11065P	PARTICIPANT	\N	PRESENT	0
307636	307137	14357A	PARTICIPANT	\N	PRESENT	0
307637	307137	14081Q	PARTICIPANT	\N	PRESENT	0
307638	307137	19675J	PARTICIPANT	\N	PRESENT	0
307639	307137	14257W	PARTICIPANT	\N	PRESENT	0
307640	307137	19383Y	PARTICIPANT	\N	PRESENT	0
307641	307137	19525U	PARTICIPANT	\N	PRESENT	0
307642	307137	19762G	PARTICIPANT	\N	PRESENT	0
307643	307137	08053X	PARTICIPANT	\N	PRESENT	0
307644	307137	08017T	PARTICIPANT	\N	PRESENT	0
307645	307137	14085U	PARTICIPANT	\N	PRESENT	0
307646	307137	08058D	PARTICIPANT	\N	PRESENT	0
307647	307137	19701S	PARTICIPANT	\N	PRESENT	0
307648	307137	19489J	PARTICIPANT	\N	PRESENT	0
307649	307137	04018C	PARTICIPANT	\N	PRESENT	0
307650	307137	19347U	PARTICIPANT	\N	PRESENT	0
307651	307137	19621T	PARTICIPANT	\N	PRESENT	0
307652	307137	11054L	PARTICIPANT	\N	PRESENT	0
307653	307137	19367Y	PARTICIPANT	\N	PRESENT	0
307654	307137	19295A	PARTICIPANT	\N	PRESENT	0
307655	307137	19683J	PARTICIPANT	\N	PRESENT	0
307656	307137	14227Q	PARTICIPANT	\N	PRESENT	0
307657	307137	19733B	PARTICIPANT	\N	PRESENT	0
307658	307137	14001X	PARTICIPANT	\N	PRESENT	0
307659	307137	19333N	PARTICIPANT	\N	PRESENT	0
307660	307137	04049K	PARTICIPANT	\N	PRESENT	0
310250	307290	97011G	PARTICIPANT	\N	EXCUSE	0
310251	307290	11041F	PARTICIPANT	\N	EXCUSE	0
320796	305885	14107H	PARTICIPANT	\N	PRESENT	0
320797	305885	11097X	PARTICIPANT	\N	PRESENT	0
320798	305885	01028R	PARTICIPANT	\N	PRESENT	0
320799	305885	11066Q	PARTICIPANT	\N	PRESENT	0
320903	319285	14331P	PARTICIPANT	\N	EXCUSE	0
320953	319285	08011M	PARTICIPANT	\N	EXCUSE	0
321186	321164	19333N	PARTICIPANT	\N	PRESENT	0
321187	321164	19525U	PARTICIPANT	\N	PRESENT	0
321189	321164	19681G	PARTICIPANT	\N	PRESENT	0
321193	321164	08009T	PARTICIPANT	\N	PRESENT	0
321194	321164	14038Y	PARTICIPANT	\N	PRESENT	0
321196	321164	14029X	PARTICIPANT	\N	PRESENT	0
321309	314126	01048V	PARTICIPANT	\N	PRESENT	0
321310	314126	19737F	PARTICIPANT	\N	PRESENT	0
321311	314126	19745F	PARTICIPANT	\N	PRESENT	0
321312	314126	02002K	PARTICIPANT	\N	PRESENT	0
321316	314126	14187A	PARTICIPANT	\N	PRESENT	0
321314	314126	05008E	PARTICIPANT	\N	PRESENT	0
321315	314126	14089Y	PARTICIPANT	\N	PRESENT	0
321317	314126	14249W	PARTICIPANT	\N	PRESENT	0
321333	314126	98029W	PARTICIPANT	\N	PRESENT	0
321930	314147	04086Q	PARTICIPANT	\N	PRESENT	0
321931	321929	19515S	PARTICIPANT	\N	PRESENT	0
321932	321929	04049K	PARTICIPANT	\N	PRESENT	0
321933	321898	19577H	PARTICIPANT	\N	PRESENT	0
321934	321898	10006L	PARTICIPANT	\N	PRESENT	0
321935	321898	19521Q	PARTICIPANT	\N	PRESENT	0
321936	314147	14227Q	PARTICIPANT	\N	PRESENT	0
321937	314147	19727D	PARTICIPANT	\N	PRESENT	0
321938	314147	17779H	PARTICIPANT	\N	PRESENT	0
321939	314147	08052W	PARTICIPANT	\N	PRESENT	0
321940	314147	11045K	PARTICIPANT	\N	PRESENT	0
321941	314147	19683J	PARTICIPANT	\N	PRESENT	0
321942	314147	11031D	PARTICIPANT	\N	PRESENT	0
321943	314147	19760E	PARTICIPANT	\N	PRESENT	0
321944	314147	11067R	PARTICIPANT	\N	PRESENT	0
321945	314147	11103C	PARTICIPANT	\N	PRESENT	0
321946	314147	11072N	PARTICIPANT	\N	PRESENT	0
321947	314147	19553Y	PARTICIPANT	\N	PRESENT	0
321948	314147	14195A	PARTICIPANT	\N	PRESENT	0
321949	314147	01034P	PARTICIPANT	\N	PRESENT	0
321950	314147	98024R	PARTICIPANT	\N	PRESENT	0
321951	314147	11097X	PARTICIPANT	\N	PRESENT	0
321952	314147	14217N	PARTICIPANT	\N	PRESENT	0
321953	314147	14213J	PARTICIPANT	\N	PRESENT	0
321954	314147	19415P	PARTICIPANT	\N	PRESENT	0
321955	314147	19575F	PARTICIPANT	\N	PRESENT	0
321956	314147	14281W	PARTICIPANT	\N	PRESENT	0
321957	314147	19671E	PARTICIPANT	\N	PRESENT	0
321958	314147	19663E	PARTICIPANT	\N	PRESENT	0
321959	314147	10006L	PARTICIPANT	\N	PRESENT	0
321960	314147	19577H	PARTICIPANT	\N	PRESENT	0
321961	314147	19657G	PARTICIPANT	\N	PRESENT	0
321962	314147	14329V	PARTICIPANT	\N	PRESENT	0
321963	314147	19295A	PARTICIPANT	\N	PRESENT	0
321964	314147	14259Y	PARTICIPANT	\N	PRESENT	0
321965	314147	14087W	PARTICIPANT	\N	PRESENT	0
321966	314147	88008L	PARTICIPANT	\N	PRESENT	0
321967	314147	19521Q	PARTICIPANT	\N	PRESENT	0
321968	314147	14115H	PARTICIPANT	\N	PRESENT	0
321969	314147	19768N	PARTICIPANT	\N	PRESENT	0
321973	321972	08019V	PARTICIPANT	\N	PRESENT	0
321975	321974	08019V	PARTICIPANT	\N	PRESENT	0
321977	321976	08019V	PARTICIPANT	\N	PRESENT	0
321979	321978	08019V	PARTICIPANT	\N	PRESENT	0
321981	321980	04089T	PARTICIPANT	\N	PRESENT	0
321983	321982	04089T	PARTICIPANT	\N	PRESENT	0
321984	314147	19691J	PARTICIPANT	\N	PRESENT	0
321986	321985	14033T	PARTICIPANT	\N	PRESENT	0
321988	321987	14033T	PARTICIPANT	\N	PRESENT	0
321990	321989	14033T	PARTICIPANT	\N	PRESENT	0
321991	314147	07034Q	PARTICIPANT	\N	PRESENT	0
321993	321992	14033T	PARTICIPANT	\N	PRESENT	0
321994	314147	19593H	PARTICIPANT	\N	PRESENT	0
321995	314147	04045F	PARTICIPANT	\N	PRESENT	0
321996	314147	19701S	PARTICIPANT	\N	PRESENT	0
321997	314147	95041E	PARTICIPANT	\N	PRESENT	0
321998	314147	11048N	PARTICIPANT	\N	PRESENT	0
321999	314147	08047A	PARTICIPANT	\N	PRESENT	0
321724	321723	19741B	PARTICIPANT	\N	PRESENT	0
321726	321725	19741B	PARTICIPANT	\N	PRESENT	0
321728	321727	19741B	PARTICIPANT	\N	PRESENT	0
321730	321729	04086Q	PARTICIPANT	\N	PRESENT	0
322000	321788	14042U	PARTICIPANT	\N	EXCUSE	0
321733	321732	04061F	PARTICIPANT	\N	PRESENT	0
321735	321734	01048V	PARTICIPANT	\N	PRESENT	0
322001	321788	08041T	PARTICIPANT	\N	EXCUSE	0
322002	314147	19689Q	PARTICIPANT	\N	PRESENT	0
321739	321738	11053K	PARTICIPANT	\N	PRESENT	0
322003	321788	01034P	PARTICIPANT	\N	PRESENT	0
321742	321740	11048N	PARTICIPANT	\N	PRESENT	0
322004	321788	04092N	PARTICIPANT	\N	PRESENT	0
322287	322283	08039A	PARTICIPANT	\N	PRESENT	0
322288	322283	19731Y	PARTICIPANT	\N	PRESENT	0
323951	322159	19619A	PARTICIPANT	\N	EXCUSE	0
323967	323965	11097X	PARTICIPANT	\N	PRESENT	0
321761	321760	19629C	PARTICIPANT	\N	PRESENT	0
321801	321800	11072N	PARTICIPANT	\N	PRESENT	0
321810	321809	08058D	PARTICIPANT	\N	PRESENT	0
321812	321811	11054L	PARTICIPANT	\N	PRESENT	0
321813	321811	04042C	PARTICIPANT	\N	PRESENT	0
321814	321811	98018T	PARTICIPANT	\N	PRESENT	0
321815	321811	14133K	PARTICIPANT	\N	PRESENT	0
321819	321818	14071N	PARTICIPANT	\N	PRESENT	0
321830	321829	04040A	PARTICIPANT	\N	PRESENT	0
321831	321829	96004D	PARTICIPANT	\N	PRESENT	0
321833	321829	14169X	PARTICIPANT	\N	PRESENT	0
321834	321829	19611R	PARTICIPANT	\N	PRESENT	0
321835	321829	08009T	PARTICIPANT	\N	PRESENT	0
321836	321829	10015M	PARTICIPANT	\N	PRESENT	0
321837	321829	19585H	PARTICIPANT	\N	PRESENT	0
321838	321829	19591F	PARTICIPANT	\N	PRESENT	0
321860	321859	19515S	PARTICIPANT	\N	PRESENT	0
321861	321859	14105F	PARTICIPANT	\N	PRESENT	0
321862	321859	08020N	PARTICIPANT	\N	PRESENT	0
321863	321859	14207L	PARTICIPANT	\N	PRESENT	0
321864	321859	14329V	PARTICIPANT	\N	PRESENT	0
321865	321859	19467C	PARTICIPANT	\N	PRESENT	0
321866	321859	80013X	PARTICIPANT	\N	PRESENT	0
321867	321859	95037J	PARTICIPANT	\N	PRESENT	0
321868	321859	14213J	PARTICIPANT	\N	PRESENT	0
321869	321859	04049K	PARTICIPANT	\N	PRESENT	0
321870	321859	19723Y	PARTICIPANT	\N	PRESENT	0
321871	321859	08015R	PARTICIPANT	\N	PRESENT	0
321872	321859	14257W	PARTICIPANT	\N	PRESENT	0
321873	321859	05012A	PARTICIPANT	\N	PRESENT	0
321874	321859	19443T	PARTICIPANT	\N	PRESENT	0
321875	321859	11097X	PARTICIPANT	\N	PRESENT	0
321876	321859	14357A	PARTICIPANT	\N	PRESENT	0
321878	321877	04049K	PARTICIPANT	\N	PRESENT	0
321879	321877	19515S	PARTICIPANT	\N	PRESENT	0
321880	321877	89017R	PARTICIPANT	\N	PRESENT	0
321881	321877	19441R	PARTICIPANT	\N	PRESENT	0
321882	321877	11090Q	PARTICIPANT	\N	PRESENT	0
321884	321883	04049K	PARTICIPANT	\N	PRESENT	0
321885	321883	11090Q	PARTICIPANT	\N	PRESENT	0
321887	321886	04049K	PARTICIPANT	\N	PRESENT	0
321888	321886	19515S	PARTICIPANT	\N	PRESENT	0
321889	321886	11090Q	PARTICIPANT	\N	PRESENT	0
321891	321890	04049K	PARTICIPANT	\N	PRESENT	0
321892	321890	89017R	PARTICIPANT	\N	PRESENT	0
321893	321890	19515S	PARTICIPANT	\N	PRESENT	0
321894	321890	11090Q	PARTICIPANT	\N	PRESENT	0
321896	321895	04049K	PARTICIPANT	\N	PRESENT	0
321927	314147	14239U	PARTICIPANT	\N	PRESENT	0
321928	314147	19697Q	PARTICIPANT	\N	PRESENT	0
324092	324091	11097X	PARTICIPANT	\N	PRESENT	0
324147	314152	19527W	PARTICIPANT	\N	PRESENT	0
324148	314152	08060W	PARTICIPANT	\N	PRESENT	0
324149	314152	14249W	PARTICIPANT	\N	PRESENT	0
324150	314152	01058X	PARTICIPANT	\N	PRESENT	0
324151	314152	19399H	PARTICIPANT	\N	PRESENT	0
324152	314152	08019V	PARTICIPANT	\N	PRESENT	0
324153	314152	14083S	PARTICIPANT	\N	PRESENT	0
324154	314152	19421M	PARTICIPANT	\N	PRESENT	0
324155	314152	14105F	PARTICIPANT	\N	PRESENT	0
324156	314152	19619A	PARTICIPANT	\N	PRESENT	0
324157	314152	19503N	PARTICIPANT	\N	PRESENT	0
324158	314152	14241N	PARTICIPANT	\N	PRESENT	0
324159	314152	11033F	PARTICIPANT	\N	PRESENT	0
324160	314152	19703U	PARTICIPANT	\N	PRESENT	0
324161	321055	01057W	PARTICIPANT	\N	PRESENT	0
324162	321055	89017R	PARTICIPANT	\N	PRESENT	0
324164	314152	08024S	PARTICIPANT	\N	PRESENT	0
324165	324163	14038Y	PARTICIPANT	\N	PRESENT	0
324166	324163	11064N	PARTICIPANT	\N	PRESENT	0
305769	305768	98029W	PARTICIPANT	\N	PRESENT	0
305771	305770	98029W	PARTICIPANT	\N	PRESENT	0
305928	305926	19533U	PARTICIPANT	\N	PRESENT	0
305955	305954	19553Y	PARTICIPANT	\N	EXCUSE	0
305956	305954	19533U	PARTICIPANT	\N	PRESENT	0
305957	305954	04043D	PARTICIPANT	\N	EXCUSE	0
315765	315763	14229S	PARTICIPANT	\N	PRESENT	0
315766	315763	19735D	PARTICIPANT	\N	PRESENT	0
319844	314090	19415P	PARTICIPANT	\N	PRESENT	0
319845	314090	19441R	PARTICIPANT	\N	PRESENT	0
319846	314090	14267Y	PARTICIPANT	\N	PRESENT	0
319847	314090	08053X	PARTICIPANT	\N	PRESENT	0
319848	314090	19725B	PARTICIPANT	\N	PRESENT	0
319849	314090	98022P	PARTICIPANT	\N	PRESENT	0
319850	314090	08028W	PARTICIPANT	\N	PRESENT	0
319851	314090	80013X	PARTICIPANT	\N	PRESENT	0
319852	314090	14179A	PARTICIPANT	\N	PRESENT	0
319853	319213	11053K	PARTICIPANT	\N	PRESENT	0
319854	314090	19681G	PARTICIPANT	\N	PRESENT	0
319855	314090	19369B	PARTICIPANT	\N	PRESENT	0
319856	314090	11010L	PARTICIPANT	\N	PRESENT	0
319857	314090	19447X	PARTICIPANT	\N	PRESENT	0
319858	314090	14115H	PARTICIPANT	\N	PRESENT	0
319859	314090	04092N	PARTICIPANT	\N	PRESENT	0
319860	314090	88008L	PARTICIPANT	\N	PRESENT	0
319861	314090	11012A	PARTICIPANT	\N	PRESENT	0
319862	314090	14121F	PARTICIPANT	\N	PRESENT	0
319863	314090	19503N	PARTICIPANT	\N	PRESENT	0
319864	314090	14225N	PARTICIPANT	\N	PRESENT	0
319865	314090	19553Y	PARTICIPANT	\N	PRESENT	0
319866	314090	14221J	PARTICIPANT	\N	PRESENT	0
319867	314090	08020N	PARTICIPANT	\N	PRESENT	0
319868	314090	14213J	PARTICIPANT	\N	PRESENT	0
319869	314090	19695N	PARTICIPANT	\N	PRESENT	0
319870	314090	14021P	PARTICIPANT	\N	PRESENT	0
319871	314090	08055A	PARTICIPANT	\N	PRESENT	0
319872	314090	87003B	PARTICIPANT	\N	PRESENT	0
319873	314090	19671E	PARTICIPANT	\N	PRESENT	0
319874	314090	19399H	PARTICIPANT	\N	PRESENT	0
319875	314090	14241N	PARTICIPANT	\N	PRESENT	0
319876	314090	14199E	PARTICIPANT	\N	PRESENT	0
319877	314090	14357A	PARTICIPANT	\N	PRESENT	0
320748	320747	14089Y	PARTICIPANT	\N	PRESENT	0
320749	320747	14357A	PARTICIPANT	\N	PRESENT	0
320750	320747	14079W	PARTICIPANT	\N	PRESENT	0
320751	320747	14249W	PARTICIPANT	\N	PRESENT	0
320752	320747	11083R	PARTICIPANT	\N	PRESENT	0
320753	320747	19725B	PARTICIPANT	\N	PRESENT	0
320754	320747	04097T	PARTICIPANT	\N	PRESENT	0
320755	320747	14097Y	PARTICIPANT	\N	PRESENT	0
320756	320747	14061L	PARTICIPANT	\N	PRESENT	0
319842	314090	14097Y	PARTICIPANT	\N	PRESENT	0
319843	314090	14217N	PARTICIPANT	\N	PRESENT	0
320757	320747	14073Q	PARTICIPANT	\N	PRESENT	0
320758	320747	14205J	PARTICIPANT	\N	PRESENT	0
320759	320747	14221J	PARTICIPANT	\N	PRESENT	0
320760	320747	04057K	PARTICIPANT	\N	PRESENT	0
320761	320747	95037J	PARTICIPANT	\N	PRESENT	0
320762	320747	19563B	PARTICIPANT	\N	PRESENT	0
320763	320747	19593H	PARTICIPANT	\N	PRESENT	0
320764	320747	10015M	PRESIDENT	0	PRESENT	0
320765	320747	98035U	PARTICIPANT	\N	PRESENT	0
320766	320747	96004D	PARTICIPANT	\N	EXCUSE	0
320767	320747	08014Q	PARTICIPANT	\N	EXCUSE	0
320768	320747	08018U	PARTICIPANT	\N	EXCUSE	0
320769	320747	11026G	PARTICIPANT	\N	EXCUSE	0
320770	320747	14331P	PARTICIPANT	\N	EXCUSE	0
320809	314107	14034U	PARTICIPANT	\N	PRESENT	0
320810	314107	19721W	PARTICIPANT	\N	PRESENT	0
320811	314107	14237S	PARTICIPANT	\N	PRESENT	0
320812	314107	04057K	PARTICIPANT	\N	PRESENT	0
320813	314107	95062K	PARTICIPANT	\N	PRESENT	0
320814	314107	11056N	PARTICIPANT	\N	PRESENT	0
320815	314107	19443T	PARTICIPANT	\N	PRESENT	0
320816	314107	14267Y	PARTICIPANT	\N	PRESENT	0
320817	314107	08009T	PARTICIPANT	\N	PRESENT	0
320818	314107	18083K	PARTICIPANT	\N	PRESENT	0
320819	314107	19717B	PARTICIPANT	\N	PRESENT	0
320820	314107	14169X	PARTICIPANT	\N	PRESENT	0
320821	314107	01025N	PARTICIPANT	\N	PRESENT	0
320822	314107	04038G	PARTICIPANT	\N	PRESENT	0
320823	314107	11012A	PARTICIPANT	\N	PRESENT	0
320824	314107	19383Y	PARTICIPANT	\N	PRESENT	0
320825	314107	14051J	PARTICIPANT	\N	PRESENT	0
320826	314107	19253P	PARTICIPANT	\N	PRESENT	0
320827	314107	19629C	PARTICIPANT	\N	PRESENT	0
320828	314107	14147R	PARTICIPANT	\N	PRESENT	0
320829	314107	14219Q	PARTICIPANT	\N	PRESENT	0
320830	314107	19387D	PARTICIPANT	\N	PRESENT	0
320831	314107	02002K	PARTICIPANT	\N	PRESENT	0
320832	314107	19681G	PARTICIPANT	\N	PRESENT	0
320833	314107	19333N	PARTICIPANT	\N	PRESENT	0
320834	314107	19733B	PARTICIPANT	\N	PRESENT	0
320835	314107	14029X	PARTICIPANT	\N	PRESENT	0
320836	314107	11085T	PARTICIPANT	\N	PRESENT	0
320837	314107	14103D	PARTICIPANT	\N	PRESENT	0
320838	314107	19747H	PARTICIPANT	\N	PRESENT	0
320839	314107	07034Q	PARTICIPANT	\N	PRESENT	0
320840	314107	19347U	PARTICIPANT	\N	PRESENT	0
320841	314107	95037J	PARTICIPANT	\N	PRESENT	0
320842	314107	14241N	PARTICIPANT	\N	PRESENT	0
320843	314107	19441R	PARTICIPANT	\N	PRESENT	0
320844	314107	15447F	PARTICIPANT	\N	PRESENT	0
320845	314107	19301E	PARTICIPANT	\N	PRESENT	0
320846	314107	19531S	PARTICIPANT	\N	PRESENT	0
320847	314107	19503N	PARTICIPANT	\N	PRESENT	0
320848	314107	14191V	PARTICIPANT	\N	PRESENT	0
320849	314107	14107H	PARTICIPANT	\N	PRESENT	0
320850	314107	19335Q	PARTICIPANT	\N	PRESENT	0
320851	314107	11103C	PARTICIPANT	\N	PRESENT	0
320852	314107	19349W	PARTICIPANT	\N	PRESENT	0
320853	314107	14042U	PARTICIPANT	\N	PRESENT	0
320854	314107	14259Y	PARTICIPANT	\N	PRESENT	0
320855	314107	14069U	PARTICIPANT	\N	PRESENT	0
320856	314107	11064N	PARTICIPANT	\N	PRESENT	0
320857	314107	19551W	PARTICIPANT	\N	PRESENT	0
320858	314107	19399H	PARTICIPANT	\N	PRESENT	0
320859	314107	19563B	PARTICIPANT	\N	PRESENT	0
320860	314107	19725B	PARTICIPANT	\N	PRESENT	0
320861	319285	19479G	PARTICIPANT	\N	PRESENT	0
320862	319285	11048N	PARTICIPANT	\N	PRESENT	0
320863	319285	19711U	PARTICIPANT	\N	PRESENT	0
320864	319285	08034U	PARTICIPANT	\N	PRESENT	0
320865	319285	01057W	PARTICIPANT	\N	PRESENT	0
320866	319285	12016W	PARTICIPANT	\N	PRESENT	0
320867	319285	19667J	PARTICIPANT	\N	PRESENT	0
320868	319285	11074Q	PRESIDENT	0	PRESENT	0
320869	319285	89017R	PARTICIPANT	\N	PRESENT	0
320870	319285	19671E	PARTICIPANT	\N	PRESENT	0
320871	319285	11070L	PARTICIPANT	\N	PRESENT	0
320872	319285	14159V	PARTICIPANT	\N	PRESENT	0
320873	319285	11110B	PARTICIPANT	\N	PRESENT	0
320874	319285	04086Q	PARTICIPANT	\N	PRESENT	0
320875	319285	11040E	PARTICIPANT	\N	PRESENT	0
320876	319285	07029T	PARTICIPANT	\N	PRESENT	0
320877	319285	14085U	PARTICIPANT	\N	PRESENT	0
320878	319285	19349W	PARTICIPANT	\N	PRESENT	0
320879	319285	08010L	PARTICIPANT	\N	PRESENT	0
320880	319285	19741B	PARTICIPANT	\N	PRESENT	0
320881	319285	14121F	PARTICIPANT	\N	PRESENT	0
320882	319285	99004R	PARTICIPANT	\N	PRESENT	0
320883	319285	01048V	PARTICIPANT	\N	PRESENT	0
320884	319285	14327T	PARTICIPANT	\N	EXCUSE	0
320885	319285	08014Q	PARTICIPANT	\N	EXCUSE	0
320886	314107	08068F	PARTICIPANT	\N	PRESENT	0
320887	314107	14033T	PARTICIPANT	\N	PRESENT	0
320888	314107	04092N	PARTICIPANT	\N	PRESENT	0
320889	314107	08055A	PARTICIPANT	\N	PRESENT	0
320890	314107	14119M	PARTICIPANT	\N	PRESENT	0
320898	314107	07029T	PARTICIPANT	\N	PRESENT	0
320913	314107	08024S	PARTICIPANT	\N	PRESENT	0
320914	314107	04086Q	PARTICIPANT	\N	PRESENT	0
320915	314107	08010L	PARTICIPANT	\N	PRESENT	0
320916	314107	14187A	PARTICIPANT	\N	PRESENT	0
320917	314107	14257W	PARTICIPANT	\N	PRESENT	0
320918	314107	11066Q	PARTICIPANT	\N	PRESENT	0
320919	314107	19479G	PARTICIPANT	\N	PRESENT	0
320920	314107	19739H	PARTICIPANT	\N	PRESENT	0
320930	314107	14105F	PARTICIPANT	\N	PRESENT	0
320931	314107	19737F	PARTICIPANT	\N	PRESENT	0
320932	314107	08056B	PARTICIPANT	\N	PRESENT	0
320933	314107	99004R	PARTICIPANT	\N	PRESENT	0
320934	314107	08049C	PARTICIPANT	\N	PRESENT	0
320935	314107	14327T	PARTICIPANT	\N	PRESENT	0
320936	314107	14061L	PARTICIPANT	\N	PRESENT	0
320937	314107	14157T	PARTICIPANT	\N	PRESENT	0
320938	314107	19467C	PARTICIPANT	\N	PRESENT	0
320939	314107	19701S	PARTICIPANT	\N	PRESENT	0
310598	307080	17779H	PARTICIPANT	\N	PRESENT	0
310849	310847	14083S	PARTICIPANT	\N	PRESENT	0
310856	310855	99004R	PARTICIPANT	\N	PRESENT	0
310874	310867	99004R	PARTICIPANT	\N	PRESENT	0
310934	310933	19531S	PARTICIPANT	\N	PRESENT	0
310960	310959	19711U	PARTICIPANT	\N	PRESENT	0
310962	310961	95041E	PARTICIPANT	\N	PRESENT	0
310985	305977	14093U	PARTICIPANT	\N	PRESENT	0
310986	305977	80013X	PARTICIPANT	\N	PRESENT	0
310987	305977	19693L	PARTICIPANT	\N	EXCUSE	0
310988	305977	19663E	PARTICIPANT	\N	PRESENT	0
311046	305977	14221J	PARTICIPANT	\N	PRESENT	0
311047	305977	19593H	PARTICIPANT	\N	PRESENT	0
311048	305977	19503N	PARTICIPANT	\N	PRESENT	0
311049	305977	04043D	PARTICIPANT	\N	PRESENT	0
311051	311050	19349W	PARTICIPANT	\N	PRESENT	0
311053	311052	19349W	PARTICIPANT	\N	PRESENT	0
311140	311133	08010L	PARTICIPANT	\N	PRESENT	0
311345	311344	08011M	PARTICIPANT	\N	PRESENT	0
326804	326803	14239U	PARTICIPANT	\N	PRESENT	0
326805	326803	14261S	PARTICIPANT	\N	PRESENT	0
326806	326803	19415P	PARTICIPANT	\N	PRESENT	0
326819	326818	19741B	PARTICIPANT	\N	PRESENT	0
326808	326803	08052W	PARTICIPANT	\N	PRESENT	0
326859	323962	14231L	PARTICIPANT	\N	EXCUSE	0
326810	326803	10006L	PARTICIPANT	\N	PRESENT	0
326821	326818	14083S	PARTICIPANT	\N	PRESENT	0
326860	323962	11048N	PARTICIPANT	\N	EXCUSE	0
326813	326803	11067R	PARTICIPANT	\N	PRESENT	0
326814	326803	04092N	PRESIDENT	0	PRESENT	0
326815	326803	11097X	PARTICIPANT	\N	PRESENT	0
326822	326818	04086Q	PARTICIPANT	\N	PRESENT	0
326817	326803	01034P	PARTICIPANT	\N	PRESENT	0
328160	321323	11053K	PARTICIPANT	\N	PRESENT	0
326824	326818	11074Q	PRESIDENT	0	PRESENT	0
328161	321323	19611R	PARTICIPANT	\N	PRESENT	0
326826	326818	19711U	PARTICIPANT	\N	PRESENT	0
326827	326818	08034U	PARTICIPANT	\N	PRESENT	0
328162	321323	19511N	PARTICIPANT	\N	PRESENT	0
326829	326818	08011M	PARTICIPANT	\N	PRESENT	0
326830	326818	08073C	PARTICIPANT	\N	PRESENT	0
326831	326818	14225N	PARTICIPANT	\N	PRESENT	0
326832	326818	11012A	PARTICIPANT	\N	PRESENT	0
328163	321323	19551W	PARTICIPANT	\N	PRESENT	0
328164	321323	19619A	PARTICIPANT	\N	PRESENT	0
328165	321323	19575F	PARTICIPANT	\N	PRESENT	0
328166	321323	19699S	PARTICIPANT	\N	PRESENT	0
328167	321323	04070G	PARTICIPANT	\N	PRESENT	0
328168	321323	04047H	PARTICIPANT	\N	PRESENT	0
328169	321323	19737F	PARTICIPANT	\N	PRESENT	0
328170	321323	16685X	PARTICIPANT	\N	PRESENT	0
328171	321323	19717B	PARTICIPANT	\N	PRESENT	0
328172	321323	19441R	PARTICIPANT	\N	PRESENT	0
328173	321323	14219Q	PARTICIPANT	\N	PRESENT	0
328174	321323	19479G	PARTICIPANT	\N	PRESENT	0
328175	321323	19713W	PARTICIPANT	\N	PRESENT	0
328176	321323	19319Q	PARTICIPANT	\N	PRESENT	0
328177	321323	14277B	PARTICIPANT	\N	PRESENT	0
328178	321323	14275Y	PARTICIPANT	\N	PRESENT	0
328179	321323	14267Y	PARTICIPANT	\N	PRESENT	0
328180	321323	04089T	PARTICIPANT	\N	PRESENT	0
328181	321323	19739H	PARTICIPANT	\N	PRESENT	0
328182	321323	14221J	PARTICIPANT	\N	PRESENT	0
328183	321323	19335Q	PARTICIPANT	\N	PRESENT	0
328184	321323	19745F	PARTICIPANT	\N	PRESENT	0
328185	321323	19749K	PARTICIPANT	\N	PRESENT	0
328186	321323	14083S	PARTICIPANT	\N	PRESENT	0
328187	321323	14089Y	PARTICIPANT	\N	PRESENT	0
328188	321323	08056B	PARTICIPANT	\N	PRESENT	0
328189	321323	19577H	PARTICIPANT	\N	PRESENT	0
328190	321323	01048V	PARTICIPANT	\N	PRESENT	0
328191	321323	14073Q	PARTICIPANT	\N	PRESENT	0
328192	321323	04040A	PARTICIPANT	\N	PRESENT	0
328193	321323	01024M	PARTICIPANT	\N	PRESENT	0
328194	321323	14030Q	PARTICIPANT	\N	PRESENT	0
328195	321323	14327T	PARTICIPANT	\N	PRESENT	0
328196	321323	01043Q	PARTICIPANT	\N	PRESENT	0
328197	321323	14205J	PARTICIPANT	\N	PRESENT	0
328198	321323	89017R	PARTICIPANT	\N	PRESENT	0
328199	321323	01060R	PARTICIPANT	\N	PRESENT	0
328200	321323	14055N	PARTICIPANT	\N	PRESENT	0
328201	321323	11072N	PARTICIPANT	\N	PRESENT	0
328202	321323	14021P	PARTICIPANT	\N	PRESENT	0
328203	321323	11048N	PARTICIPANT	\N	PRESENT	0
328205	321323	14034U	PARTICIPANT	\N	PRESENT	0
328207	321323	11070L	PARTICIPANT	\N	PRESENT	0
328208	321323	14038Y	PARTICIPANT	\N	PRESENT	0
328209	321323	19721W	PARTICIPANT	\N	PRESENT	0
328210	321323	19679N	PARTICIPANT	\N	PRESENT	0
328213	321323	08011M	PARTICIPANT	\N	PRESENT	0
328214	321323	14253S	PARTICIPANT	\N	PRESENT	0
328216	321323	19733B	PARTICIPANT	\N	PRESENT	0
328220	321323	04085P	PARTICIPANT	\N	PRESENT	0
328221	321323	11031D	PARTICIPANT	\N	PRESENT	0
328222	321323	08061X	PARTICIPANT	\N	PRESENT	0
328223	321323	19531S	PARTICIPANT	\N	PRESENT	0
328224	321323	98023Q	PARTICIPANT	\N	PRESENT	0
328225	321323	05008E	PARTICIPANT	\N	PRESENT	0
328226	321323	19766L	PARTICIPANT	\N	PRESENT	0
328227	321323	19747H	PARTICIPANT	\N	PRESENT	0
328524	321319	11070L	PARTICIPANT	\N	PRESENT	0
328556	321319	19447X	PARTICIPANT	\N	PRESENT	0
328526	321319	14225N	PARTICIPANT	\N	PRESENT	0
328527	321319	19647E	PARTICIPANT	\N	PRESENT	0
328528	321319	19333N	PARTICIPANT	\N	PRESENT	0
328529	321319	14085U	PARTICIPANT	\N	PRESENT	0
328530	321319	14159V	PARTICIPANT	\N	PRESENT	0
328531	321319	19545Y	PARTICIPANT	\N	PRESENT	0
328532	321319	04057K	PARTICIPANT	\N	PRESENT	0
328533	321319	19349W	PARTICIPANT	\N	PRESENT	0
328534	321319	19651A	PARTICIPANT	\N	PRESENT	0
328559	321319	19629C	PARTICIPANT	\N	PRESENT	0
328536	321319	12016W	PARTICIPANT	\N	PRESENT	0
328537	321319	19479G	PARTICIPANT	\N	PRESENT	0
328538	321319	19593H	PARTICIPANT	\N	PRESENT	0
328539	321319	14073Q	PARTICIPANT	\N	PRESENT	0
328540	321319	14231L	PARTICIPANT	\N	PRESENT	0
328541	321319	14327T	PARTICIPANT	\N	PRESENT	0
328542	321319	01024M	PARTICIPANT	\N	PRESENT	0
328543	321319	19737F	PARTICIPANT	\N	PRESENT	0
328544	321319	19711U	PARTICIPANT	\N	PRESENT	0
328545	321319	04033B	PARTICIPANT	\N	PRESENT	0
328546	321319	08010L	PARTICIPANT	\N	PRESENT	0
328547	321319	04086Q	PARTICIPANT	\N	PRESENT	0
328548	321319	19295A	PARTICIPANT	\N	PRESENT	0
328549	321319	07029T	PARTICIPANT	\N	PRESENT	0
328550	321319	10006L	PARTICIPANT	\N	PRESENT	0
328551	321319	14029X	PARTICIPANT	\N	PRESENT	0
328552	321319	19667J	PARTICIPANT	\N	PRESENT	0
328553	321319	19643A	PARTICIPANT	\N	PRESENT	0
328554	321319	19675J	PARTICIPANT	\N	PRESENT	0
328555	321319	19533U	PARTICIPANT	\N	PRESENT	0
328557	321319	19583F	PARTICIPANT	\N	PRESENT	0
328558	321319	88008L	PARTICIPANT	\N	PRESENT	0
328560	321319	19703U	PARTICIPANT	\N	PRESENT	0
328561	321319	04088S	PARTICIPANT	\N	PRESENT	0
328562	321319	14041T	PARTICIPANT	\N	PRESENT	0
328563	321319	19507S	PARTICIPANT	\N	PRESENT	0
328564	321319	14157T	PARTICIPANT	\N	PRESENT	0
328565	321319	19399H	PARTICIPANT	\N	PRESENT	0
328566	321319	14151M	PARTICIPANT	\N	PRESENT	0
328567	321319	11040E	PARTICIPANT	\N	PRESENT	0
328568	321319	19649G	PARTICIPANT	\N	PRESENT	0
328569	321319	19611R	PARTICIPANT	\N	PRESENT	0
328570	321319	19621T	PARTICIPANT	\N	PRESENT	0
328571	321319	14187A	PARTICIPANT	\N	PRESENT	0
328572	321319	14211G	PARTICIPANT	\N	PRESENT	0
328573	321319	04071H	PARTICIPANT	\N	PRESENT	0
328574	321319	99004R	PARTICIPANT	\N	PRESENT	0
328575	321319	08043V	PARTICIPANT	\N	PRESENT	0
328577	321319	11109J	PARTICIPANT	\N	PRESENT	0
328579	321319	11053K	PARTICIPANT	\N	PRESENT	0
328580	321319	14357A	PARTICIPANT	\N	PRESENT	0
328581	321319	01048V	PARTICIPANT	\N	PRESENT	0
328582	321319	01057W	PARTICIPANT	\N	PRESENT	0
328583	321319	08011M	PARTICIPANT	\N	PRESENT	0
328584	321319	11074Q	PARTICIPANT	\N	PRESENT	0
328585	321319	19581D	PARTICIPANT	\N	PRESENT	0
328586	321319	14033T	PARTICIPANT	\N	PRESENT	0
328587	321319	80013X	PARTICIPANT	\N	PRESENT	0
328588	321319	14089Y	PARTICIPANT	\N	PRESENT	0
328589	321319	11077T	PARTICIPANT	\N	PRESENT	0
328590	321319	14249W	PARTICIPANT	\N	PRESENT	0
328591	321319	14331P	PARTICIPANT	\N	PRESENT	0
328592	321319	14030Q	PARTICIPANT	\N	PRESENT	0
328593	321319	19543W	PARTICIPANT	\N	PRESENT	0
328594	321319	14069U	PARTICIPANT	\N	PRESENT	0
328595	321319	19733B	PARTICIPANT	\N	PRESENT	0
328596	321319	19687N	PARTICIPANT	\N	PRESENT	0
302529	301625	14159V	PARTICIPANT	\N	PRESENT	0
302539	302538	05008E	PARTICIPANT	\N	PRESENT	0
303990	303989	19747H	PARTICIPANT	\N	PRESENT	0
303991	303989	14207L	PARTICIPANT	\N	PRESENT	0
303992	303989	19507S	PARTICIPANT	\N	PRESENT	0
302543	302538	19629C	PARTICIPANT	\N	PRESENT	0
302544	302538	14041T	PARTICIPANT	\N	PRESENT	0
302545	302538	14215L	PARTICIPANT	\N	PRESENT	0
302546	302538	19649G	PARTICIPANT	\N	PRESENT	0
302547	302538	14179A	PARTICIPANT	\N	PRESENT	0
303993	303989	14197C	PARTICIPANT	\N	PRESENT	0
303994	303989	19441R	PARTICIPANT	\N	PRESENT	0
302550	302538	11085T	PARTICIPANT	\N	PRESENT	0
302551	302538	14147R	PARTICIPANT	\N	PRESENT	0
302552	302538	11045K	PARTICIPANT	\N	PRESENT	0
303995	303989	19369B	PARTICIPANT	\N	PRESENT	0
303996	303989	14265W	PARTICIPANT	\N	PRESENT	0
303997	303989	04088S	PARTICIPANT	\N	PRESENT	0
303998	303989	19413M	PARTICIPANT	\N	PRESENT	0
305971	305968	19503N	PARTICIPANT	\N	PRESENT	0
305973	305883	14257W	PARTICIPANT	\N	PRESENT	0
307661	307137	19725B	PARTICIPANT	\N	PRESENT	0
307662	307137	14207L	PARTICIPANT	\N	PRESENT	0
307663	307137	11041F	PARTICIPANT	\N	PRESENT	0
307664	307137	14097Y	PARTICIPANT	\N	PRESENT	0
307665	307137	14109K	PARTICIPANT	\N	PRESENT	0
307666	307137	19527W	PARTICIPANT	\N	PRESENT	0
307667	307137	14063N	PARTICIPANT	\N	PRESENT	0
307668	307137	11067R	PARTICIPANT	\N	PRESENT	0
307669	307137	19503N	PARTICIPANT	\N	PRESENT	0
307670	307137	19591F	PARTICIPANT	\N	PRESENT	0
307671	307137	19251M	PARTICIPANT	\N	PRESENT	0
307672	307137	19413M	PARTICIPANT	\N	PRESENT	0
307673	307137	04057K	PARTICIPANT	\N	PRESENT	0
307674	307137	11080N	PARTICIPANT	\N	PRESENT	0
307675	307137	04042C	PARTICIPANT	\N	PRESENT	0
307676	307137	14259Y	PARTICIPANT	\N	PRESENT	0
307677	307137	14239U	PARTICIPANT	\N	PRESENT	0
307678	307137	19689Q	PARTICIPANT	\N	PRESENT	0
307679	307137	98024R	PARTICIPANT	\N	PRESENT	0
307680	307137	19269X	PARTICIPANT	\N	PRESENT	0
307681	307137	04071H	PARTICIPANT	\N	PRESENT	0
307682	307137	89017R	PARTICIPANT	\N	PRESENT	0
307684	307137	19717B	PARTICIPANT	\N	PRESENT	0
307686	307137	19713W	PARTICIPANT	\N	PRESENT	0
307687	307137	19441R	PARTICIPANT	\N	PRESENT	0
307688	307137	07004J	PARTICIPANT	\N	PRESENT	0
307689	307137	14219Q	PARTICIPANT	\N	PRESENT	0
307690	307137	19479G	PARTICIPANT	\N	PRESENT	0
307692	307137	19569H	PARTICIPANT	\N	PRESENT	0
307693	307137	14042U	PARTICIPANT	\N	PRESENT	0
307694	307137	19735D	PARTICIPANT	\N	PRESENT	0
307695	307137	11110B	PARTICIPANT	\N	PRESENT	0
307696	307137	14213J	PARTICIPANT	\N	PRESENT	0
307697	307137	16685X	PARTICIPANT	\N	PRESENT	0
307698	307137	19619A	PARTICIPANT	\N	PRESENT	0
307699	307137	19721W	PARTICIPANT	\N	PRESENT	0
307700	307137	14267Y	PARTICIPANT	\N	PRESENT	0
307701	307137	19699S	PARTICIPANT	\N	PRESENT	0
307702	307137	19737F	PARTICIPANT	\N	PRESENT	0
307703	307137	14237S	PARTICIPANT	\N	PRESENT	0
307704	307137	08010L	PARTICIPANT	\N	PRESENT	0
307705	307137	19511N	PARTICIPANT	\N	PRESENT	0
307706	307137	19611R	PARTICIPANT	\N	PRESENT	0
307707	307137	11053K	PARTICIPANT	\N	PRESENT	0
307708	307137	14205J	PARTICIPANT	\N	PRESENT	0
307709	307137	08039A	PARTICIPANT	\N	PRESENT	0
307710	307137	19691J	PARTICIPANT	\N	PRESENT	0
307711	307137	19369B	PARTICIPANT	\N	PRESENT	0
307712	307137	01034P	PARTICIPANT	\N	PRESENT	0
307713	307137	08069G	PARTICIPANT	\N	PRESENT	0
307714	307137	08044W	PARTICIPANT	\N	PRESENT	0
307715	307137	14179A	PARTICIPANT	\N	PRESENT	0
307716	307137	14231L	PARTICIPANT	\N	PRESENT	0
307717	307137	04089T	PARTICIPANT	\N	PRESENT	0
307718	307137	01025N	PARTICIPANT	\N	PRESENT	0
307719	307137	01043Q	PARTICIPANT	\N	PRESENT	0
307720	307137	14030Q	PARTICIPANT	\N	PRESENT	0
307721	307137	14327T	PARTICIPANT	\N	PRESENT	0
307722	307137	08011M	PARTICIPANT	\N	PRESENT	0
307723	307137	04040A	PARTICIPANT	\N	PRESENT	0
307724	307137	04070G	PARTICIPANT	\N	PRESENT	0
307725	307137	11085T	PARTICIPANT	\N	PRESENT	0
307726	307137	08009T	PARTICIPANT	\N	PRESENT	0
307727	307137	11070L	PARTICIPANT	\N	PRESENT	0
307728	307137	14103D	PARTICIPANT	\N	PRESENT	0
307729	307137	14221J	PARTICIPANT	\N	PRESENT	0
307730	307137	19739H	PARTICIPANT	\N	PRESENT	0
307731	307137	14073Q	PARTICIPANT	\N	PRESENT	0
307732	307137	14083S	PARTICIPANT	\N	PRESENT	0
307733	307137	14089Y	PARTICIPANT	\N	PRESENT	0
307734	307137	19521Q	PARTICIPANT	\N	PRESENT	0
307735	307137	19335Q	PARTICIPANT	\N	PRESENT	0
307736	307137	19745F	PARTICIPANT	\N	PRESENT	0
307737	307137	19749K	PARTICIPANT	\N	PRESENT	0
307738	307137	14255U	PARTICIPANT	\N	PRESENT	0
307739	307137	04047H	PARTICIPANT	\N	PRESENT	0
307740	307137	14229S	PARTICIPANT	\N	PRESENT	0
307741	307137	19551W	PARTICIPANT	\N	PRESENT	0
307742	307137	14093U	PARTICIPANT	\N	PRESENT	0
307743	307137	08068F	PARTICIPANT	\N	PRESENT	0
307748	307137	01024M	PARTICIPANT	\N	PRESENT	0
307745	307137	14215L	PARTICIPANT	\N	PRESENT	0
307746	307137	14041T	PARTICIPANT	\N	PRESENT	0
307749	307137	02002K	PARTICIPANT	\N	PRESENT	0
307762	307137	19253P	PARTICIPANT	\N	PRESENT	0
308077	307138	04086Q	PARTICIPANT	\N	PRESENT	0
308078	307138	19703U	PARTICIPANT	\N	PRESENT	0
308079	307138	11031D	PARTICIPANT	\N	PRESENT	0
308080	307138	12016W	PARTICIPANT	\N	PRESENT	0
308081	307138	19683J	PARTICIPANT	\N	PRESENT	0
308082	307138	11067R	PARTICIPANT	\N	PRESENT	0
308083	307138	19631V	PARTICIPANT	\N	PRESENT	0
308084	307138	19599P	PARTICIPANT	\N	PRESENT	0
308085	307138	14239U	PARTICIPANT	\N	PRESENT	0
308086	307138	14241N	PARTICIPANT	\N	PRESENT	0
308087	307138	19553Y	PARTICIPANT	\N	PRESENT	0
308088	307138	14195A	PARTICIPANT	\N	PRESENT	0
308089	307138	19441R	PARTICIPANT	\N	PRESENT	0
308090	307138	19479G	PARTICIPANT	\N	PRESENT	0
308091	307138	19713W	PARTICIPANT	\N	PRESENT	0
308092	307138	19737F	PARTICIPANT	\N	PRESENT	0
308093	307138	19413M	PARTICIPANT	\N	PRESENT	0
308094	307138	14331P	PARTICIPANT	\N	PRESENT	0
308095	307138	14031R	PARTICIPANT	\N	PRESENT	0
308096	307138	19415P	PARTICIPANT	\N	PRESENT	0
308097	307138	18083K	PARTICIPANT	\N	PRESENT	0
308098	307138	19657G	PARTICIPANT	\N	PRESENT	0
308099	307138	19583F	PARTICIPANT	\N	PRESENT	0
308100	307138	14213J	PARTICIPANT	\N	PRESENT	0
308101	307138	14033T	PARTICIPANT	\N	PRESENT	0
308102	307138	97011G	PARTICIPANT	\N	PRESENT	0
308103	307138	08010L	PARTICIPANT	\N	PRESENT	0
308104	307138	10006L	PARTICIPANT	\N	PRESENT	0
308105	307138	14223L	PARTICIPANT	\N	PRESENT	0
308106	307138	14105F	PARTICIPANT	\N	PRESENT	0
308107	307138	14115H	PARTICIPANT	\N	PRESENT	0
308108	307138	14029X	PARTICIPANT	\N	PRESENT	0
308109	307138	14119M	PARTICIPANT	\N	PRESENT	0
308110	307138	14038Y	PARTICIPANT	\N	PRESENT	0
308111	307138	14147R	PARTICIPANT	\N	PRESENT	0
308112	307138	14187A	PARTICIPANT	\N	PRESENT	0
308113	307138	04088S	PARTICIPANT	\N	PRESENT	0
308114	307138	80013X	PARTICIPANT	\N	PRESENT	0
308115	307138	19289C	PARTICIPANT	\N	PRESENT	0
308116	307138	04092N	PARTICIPANT	\N	PRESENT	0
308117	307138	19733B	PARTICIPANT	\N	PRESENT	0
308118	307138	19349W	PARTICIPANT	\N	PRESENT	0
308119	307138	19675J	PARTICIPANT	\N	PRESENT	0
308120	307138	19335Q	PARTICIPANT	\N	PRESENT	0
308121	307138	14089Y	PARTICIPANT	\N	PRESENT	0
308122	307138	14357A	PARTICIPANT	\N	PRESENT	0
308123	307138	14157T	PARTICIPANT	\N	PRESENT	0
308124	307138	04061F	PARTICIPANT	\N	PRESENT	0
308125	307138	19629C	PARTICIPANT	\N	PRESENT	0
308126	307138	19387D	PARTICIPANT	\N	PRESENT	0
308127	307138	11049P	PARTICIPANT	\N	PRESENT	0
308128	307138	11012A	PARTICIPANT	\N	PRESENT	0
308129	307138	14053L	PARTICIPANT	\N	PRESENT	0
308130	307138	95030B	PARTICIPANT	\N	PRESENT	0
308131	307138	19369B	PARTICIPANT	\N	PRESENT	0
308132	307138	14073Q	PARTICIPANT	\N	PRESENT	0
308133	307138	01058X	PARTICIPANT	\N	PRESENT	0
310587	310585	08039A	PARTICIPANT	\N	PRESENT	0
310588	310585	19749K	PARTICIPANT	\N	PRESENT	0
310589	310585	08017T	PARTICIPANT	\N	PRESENT	0
310590	310584	08039A	PARTICIPANT	\N	PRESENT	0
310591	310584	19749K	PARTICIPANT	\N	PRESENT	0
310592	310584	19611R	PARTICIPANT	\N	PRESENT	0
310593	310584	14241N	PARTICIPANT	\N	PRESENT	0
310595	310594	08039A	PARTICIPANT	\N	PRESENT	0
310596	310594	19749K	PARTICIPANT	\N	PRESENT	0
310597	310594	19611R	PARTICIPANT	\N	PRESENT	0
316539	316538	19415P	PARTICIPANT	\N	PRESENT	0
316540	316538	14195A	PARTICIPANT	\N	PRESENT	0
316547	316545	19415P	PARTICIPANT	\N	PRESENT	0
316550	316545	11067R	PARTICIPANT	\N	PRESENT	0
316576	316570	14111D	PARTICIPANT	\N	PRESENT	0
316622	316613	19415P	PARTICIPANT	\N	PRESENT	0
324169	317557	14261S	PARTICIPANT	\N	PRESENT	0
324170	317557	19631V	PARTICIPANT	\N	PRESENT	0
324171	317557	19577H	PARTICIPANT	\N	PRESENT	0
324172	317557	19715Y	PARTICIPANT	\N	PRESENT	0
324173	317557	19657G	PARTICIPANT	\N	PRESENT	0
324174	317557	08019V	PRESIDENT	0	PRESENT	0
324175	317557	14331P	PARTICIPANT	\N	PRESENT	0
324176	317557	14275Y	PARTICIPANT	\N	PRESENT	0
324177	314152	14030Q	PARTICIPANT	\N	PRESENT	0
324178	317557	19329S	PARTICIPANT	\N	PRESENT	0
324179	317557	95062K	PARTICIPANT	\N	PRESENT	0
324180	314152	95062K	PARTICIPANT	\N	PRESENT	0
324184	314152	11066Q	PARTICIPANT	\N	PRESENT	0
324185	321055	11012A	PARTICIPANT	\N	PRESENT	0
324186	314152	08017T	PARTICIPANT	\N	PRESENT	0
324191	314152	04057K	PARTICIPANT	\N	PRESENT	0
324192	314152	19387D	PARTICIPANT	\N	PRESENT	0
324193	320716	08009T	PRESIDENT	0	PRESENT	0
324194	320716	96004D	PARTICIPANT	\N	EXCUSE	0
324195	320716	19685L	PARTICIPANT	\N	EXCUSE	0
324196	314152	19573D	PARTICIPANT	\N	PRESENT	0
324197	314152	12016W	PARTICIPANT	\N	PRESENT	0
324198	314152	19441R	PARTICIPANT	\N	PRESENT	0
324199	314152	11043H	PARTICIPANT	\N	PRESENT	0
324200	314152	04086Q	PARTICIPANT	\N	PRESENT	0
324201	322292	04070G	PRESIDENT	0	PRESENT	0
324202	322292	11074Q	PARTICIPANT	\N	PRESENT	0
324203	322292	14229S	PARTICIPANT	\N	PRESENT	0
324204	322292	14241N	PARTICIPANT	\N	PRESENT	0
324205	322292	19573D	PARTICIPANT	\N	PRESENT	0
324206	322292	08017T	PARTICIPANT	\N	PRESENT	0
324207	322292	92040Q	PARTICIPANT	\N	PRESENT	0
324208	322292	08039A	PARTICIPANT	\N	PRESENT	0
324209	322292	08031R	PARTICIPANT	\N	PRESENT	0
324210	322292	19593H	PARTICIPANT	\N	PRESENT	0
324211	322292	19643A	PARTICIPANT	\N	PRESENT	0
324212	322292	04057K	PARTICIPANT	\N	PRESENT	0
324213	322292	19611R	PARTICIPANT	\N	PRESENT	0
324214	322292	08043V	PARTICIPANT	\N	PRESENT	0
324215	322292	19399H	PARTICIPANT	\N	PRESENT	0
324216	322292	14030Q	PARTICIPANT	\N	PRESENT	0
324217	322292	19731Y	PARTICIPANT	\N	PRESENT	0
324218	322292	08020N	PARTICIPANT	\N	PRESENT	0
324219	322292	14251Q	PARTICIPANT	\N	PRESENT	0
324220	322292	04059M	PARTICIPANT	\N	PRESENT	0
324221	322292	19735D	PARTICIPANT	\N	PRESENT	0
324222	322292	14063N	PARTICIPANT	\N	PRESENT	0
324223	322292	11083R	PARTICIPANT	\N	PRESENT	0
324224	322292	14123H	PARTICIPANT	\N	PRESENT	0
324225	322292	19749K	PARTICIPANT	\N	PRESENT	0
324226	322292	04018C	PARTICIPANT	\N	PRESENT	0
324227	322292	19766L	PARTICIPANT	\N	EXCUSE	0
324228	322292	14061L	PARTICIPANT	\N	EXCUSE	0
324229	314152	11067R	PARTICIPANT	\N	PRESENT	0
324230	320716	19333N	PARTICIPANT	\N	PRESENT	0
324231	320716	14038Y	PARTICIPANT	\N	PRESENT	0
324232	320716	14237S	PARTICIPANT	\N	PRESENT	0
324233	320716	14051J	PARTICIPANT	\N	PRESENT	0
324234	320716	95062K	PARTICIPANT	\N	PRESENT	0
324235	320716	19503N	PARTICIPANT	\N	PRESENT	0
324236	320716	19737F	PARTICIPANT	\N	PRESENT	0
324237	320716	19347U	PARTICIPANT	\N	PRESENT	0
324238	320716	14221J	PARTICIPANT	\N	PRESENT	0
324239	320716	19599P	PARTICIPANT	\N	PRESENT	0
324240	320716	14169X	PARTICIPANT	\N	PRESENT	0
324241	314152	99004R	PARTICIPANT	\N	PRESENT	0
324269	314152	14187A	PARTICIPANT	\N	PRESENT	0
324270	321822	14215L	PARTICIPANT	\N	PRESENT	0
324271	314152	14331P	PARTICIPANT	\N	PRESENT	0
324272	321822	14231L	PARTICIPANT	\N	PRESENT	0
324273	314152	19671E	PARTICIPANT	\N	PRESENT	0
324274	314152	14121F	PARTICIPANT	\N	PRESENT	0
324275	314152	19545Y	PARTICIPANT	\N	PRESENT	0
324276	314152	08010L	PARTICIPANT	\N	PRESENT	0
324277	314152	19569H	PARTICIPANT	\N	PRESENT	0
324676	324675	11053K	PARTICIPANT	\N	PRESENT	0
324677	324675	14159V	PARTICIPANT	\N	PRESENT	0
324678	324675	05012A	PARTICIPANT	\N	PRESENT	0
324688	322456	99004R	PRESIDENT	0	PRESENT	0
324689	322456	11097X	PARTICIPANT	\N	PRESENT	0
324690	322456	19711U	PARTICIPANT	\N	EXCUSE	0
324850	322456	11066Q	PARTICIPANT	\N	EXCUSE	0
324882	322456	19713W	PARTICIPANT	\N	EXCUSE	0
324883	322456	19737F	PARTICIPANT	\N	PRESENT	0
324884	322456	14107H	PARTICIPANT	\N	PRESENT	0
324887	322456	08024S	PARTICIPANT	\N	PRESENT	0
324898	324897	14107H	PARTICIPANT	\N	PRESENT	0
324903	322456	19421M	PARTICIPANT	\N	PRESENT	0
324904	322456	01028R	PARTICIPANT	\N	EXCUSE	0
324167	324163	14169X	PARTICIPANT	\N	PRESENT	0
324168	324163	08053X	PARTICIPANT	\N	PRESENT	0
324907	322456	04038G	PARTICIPANT	\N	PRESENT	0
325027	314157	11070L	PARTICIPANT	\N	PRESENT	0
325028	314157	19575F	PARTICIPANT	\N	PRESENT	0
325029	314157	08052W	PARTICIPANT	\N	PRESENT	0
325030	314157	10006L	PARTICIPANT	\N	PRESENT	0
325031	314157	14223L	PARTICIPANT	\N	PRESENT	0
325032	314157	19657G	PARTICIPANT	\N	PRESENT	0
325033	314157	19697Q	PARTICIPANT	\N	PRESENT	0
325034	314157	04092N	PARTICIPANT	\N	PRESENT	0
325035	314157	19693L	PARTICIPANT	\N	PRESENT	0
325036	314157	11097X	PARTICIPANT	\N	PRESENT	0
325037	314157	14215L	PARTICIPANT	\N	PRESENT	0
325038	314157	19760E	PARTICIPANT	\N	PRESENT	0
325039	314157	11045K	PARTICIPANT	\N	PRESENT	0
325040	314157	14281W	PARTICIPANT	\N	PRESENT	0
325041	314157	14261S	PARTICIPANT	\N	PRESENT	0
325042	314157	19727D	PARTICIPANT	\N	PRESENT	0
325043	314157	19515S	PARTICIPANT	\N	PRESENT	0
325044	314157	19553Y	PARTICIPANT	\N	PRESENT	0
325045	314157	14042U	PARTICIPANT	\N	PRESENT	0
325046	314157	19415P	PARTICIPANT	\N	PRESENT	0
325047	314157	11031D	PARTICIPANT	\N	PRESENT	0
325048	314157	98024R	PARTICIPANT	\N	PRESENT	0
325049	314157	04045F	PARTICIPANT	\N	PRESENT	0
325050	314157	17779H	PARTICIPANT	\N	PRESENT	0
325051	314157	19683J	PARTICIPANT	\N	PRESENT	0
325052	314157	19527W	PARTICIPANT	\N	PRESENT	0
325053	314157	19329S	PARTICIPANT	\N	PRESENT	0
325054	314157	14213J	PARTICIPANT	\N	PRESENT	0
325056	314157	19715Y	PARTICIPANT	\N	PRESENT	0
325061	314157	14039A	PARTICIPANT	\N	PRESENT	0
325062	314157	14157T	PARTICIPANT	\N	PRESENT	0
325063	314157	08047A	PARTICIPANT	\N	PRESENT	0
325064	314157	19741B	PARTICIPANT	\N	PRESENT	0
325067	314157	99004R	PARTICIPANT	\N	PRESENT	0
325068	314157	14239U	PARTICIPANT	\N	PRESENT	0
325069	314157	14093U	PARTICIPANT	\N	PRESENT	0
325070	314157	01034P	PARTICIPANT	\N	PRESENT	0
325071	314157	04018C	PARTICIPANT	\N	PRESENT	0
325072	314157	14071N	PARTICIPANT	\N	PRESENT	0
325073	314157	11072N	PARTICIPANT	\N	PRESENT	0
325074	314157	04044E	PARTICIPANT	\N	PRESENT	0
325075	314157	11067R	PARTICIPANT	\N	PRESENT	0
325076	314157	14069U	PARTICIPANT	\N	PRESENT	0
325077	314157	19663E	PARTICIPANT	\N	PRESENT	0
325078	314157	19711U	PARTICIPANT	\N	PRESENT	0
325079	314157	04086Q	PARTICIPANT	\N	PRESENT	0
306073	306072	11083R	PARTICIPANT	\N	PRESENT	0
306074	306072	04057K	PARTICIPANT	\N	PRESENT	0
306075	306071	14089Y	PARTICIPANT	\N	PRESENT	0
309378	306017	02002K	PARTICIPANT	\N	PRESENT	0
309379	305886	02002K	PARTICIPANT	\N	EXCUSE	0
320940	314107	19745F	PARTICIPANT	\N	PRESENT	0
320941	314107	19521Q	PARTICIPANT	\N	PRESENT	0
320949	314107	80013X	PARTICIPANT	\N	PRESENT	0
320950	314107	11097X	PARTICIPANT	\N	PRESENT	0
320951	314107	14121F	PARTICIPANT	\N	PRESENT	0
320952	314107	19549D	PARTICIPANT	\N	PRESENT	0
320956	314107	08012N	PARTICIPANT	\N	PRESENT	0
320957	314107	19447X	PARTICIPANT	\N	PRESENT	0
320958	314107	14215L	PARTICIPANT	\N	PRESENT	0
320959	314107	19719D	PARTICIPANT	\N	PRESENT	0
320960	314107	19553Y	PARTICIPANT	\N	PRESENT	0
320961	314107	08015R	PARTICIPANT	\N	PRESENT	0
320962	314107	98023Q	PARTICIPANT	\N	PRESENT	0
320963	314107	04040A	PARTICIPANT	\N	PRESENT	0
320964	314107	19507S	PARTICIPANT	\N	PRESENT	0
320965	314107	14205J	PARTICIPANT	\N	PRESENT	0
320966	314107	98022P	PARTICIPANT	\N	PRESENT	0
320967	314107	19758L	PARTICIPANT	\N	PRESENT	0
320968	314107	19687N	PARTICIPANT	\N	PRESENT	0
320969	314107	14073Q	PARTICIPANT	\N	PRESENT	0
320971	314107	98050T	PARTICIPANT	\N	PRESENT	0
320974	314107	14115H	PARTICIPANT	\N	PRESENT	0
321068	314126	08020N	PARTICIPANT	\N	PRESENT	0
321069	314126	14259Y	PARTICIPANT	\N	PRESENT	0
321070	314126	14191V	PARTICIPANT	\N	PRESENT	0
321071	314126	19581D	PARTICIPANT	\N	PRESENT	0
321072	314126	14073Q	PARTICIPANT	\N	PRESENT	0
321073	314126	98023Q	PARTICIPANT	\N	PRESENT	0
321074	314126	80013X	PARTICIPANT	\N	PRESENT	0
321075	314126	11103C	PARTICIPANT	\N	PRESENT	0
321079	314126	19467C	PARTICIPANT	\N	PRESENT	0
321082	314126	07034Q	PARTICIPANT	\N	PRESENT	0
321083	314126	19367Y	PARTICIPANT	\N	PRESENT	0
321084	314126	04089T	PARTICIPANT	\N	PRESENT	0
321085	314126	08019V	PARTICIPANT	\N	PRESENT	0
321086	314126	14111D	PARTICIPANT	\N	PRESENT	0
321087	314126	98022P	PARTICIPANT	\N	PRESENT	0
321088	314126	14051J	PARTICIPANT	\N	PRESENT	0
321089	314126	19683J	PARTICIPANT	\N	PRESENT	0
321090	314126	14063N	PARTICIPANT	\N	PRESENT	0
321091	314126	19387D	PARTICIPANT	\N	PRESENT	0
321092	314126	14105F	PARTICIPANT	\N	PRESENT	0
321093	314126	19593H	PARTICIPANT	\N	PRESENT	0
321094	314126	07033P	PARTICIPANT	\N	PRESENT	0
321095	314126	19717B	PARTICIPANT	\N	PRESENT	0
321096	314126	14157T	PARTICIPANT	\N	PRESENT	0
321097	314126	95062K	PARTICIPANT	\N	PRESENT	0
321098	314126	11054L	PARTICIPANT	\N	PRESENT	0
321099	314126	14219Q	PARTICIPANT	\N	PRESENT	0
321100	314126	19731Y	PARTICIPANT	\N	PRESENT	0
321101	314126	19766L	PARTICIPANT	\N	PRESENT	0
321102	314126	11097X	PARTICIPANT	\N	PRESENT	0
321103	314126	99004R	PARTICIPANT	\N	PRESENT	0
321104	314126	04097T	PARTICIPANT	\N	PRESENT	0
321105	314126	19741B	PARTICIPANT	\N	PRESENT	0
321109	314126	11048N	PARTICIPANT	\N	PRESENT	0
321107	314126	15447F	PARTICIPANT	\N	PRESENT	0
321108	314126	19711U	PARTICIPANT	\N	PRESENT	0
321110	314126	08015R	PARTICIPANT	\N	PRESENT	0
321111	314126	14211G	PARTICIPANT	\N	PRESENT	0
321112	314126	19703U	PARTICIPANT	\N	PRESENT	0
321113	314126	19443T	PARTICIPANT	\N	PRESENT	0
321114	314126	18083K	PARTICIPANT	\N	PRESENT	0
321115	314126	14135M	PARTICIPANT	\N	PRESENT	0
321116	314126	17637T	PARTICIPANT	\N	PRESENT	0
321117	314126	08028W	PARTICIPANT	\N	PRESENT	0
321118	314126	07029T	PARTICIPANT	\N	PRESENT	0
321119	314126	98050T	PARTICIPANT	\N	PRESENT	0
321120	314126	01058X	PARTICIPANT	\N	PRESENT	0
321121	314126	11043H	PARTICIPANT	\N	PRESENT	0
321122	314126	19533U	PARTICIPANT	\N	PRESENT	0
321123	314126	10006L	PARTICIPANT	\N	PRESENT	0
321124	314126	08039A	PARTICIPANT	\N	PRESENT	0
321125	314126	19679N	PARTICIPANT	\N	PRESENT	0
321126	314126	04086Q	PARTICIPANT	\N	PRESENT	0
321127	314126	08034U	PARTICIPANT	\N	PRESENT	0
321128	314126	04033B	PARTICIPANT	\N	PRESENT	0
321129	314126	19421M	PARTICIPANT	\N	PRESENT	0
321130	314126	14169X	PARTICIPANT	\N	PRESENT	0
321131	314126	11031D	PARTICIPANT	\N	PRESENT	0
321132	314126	12041X	PARTICIPANT	\N	PRESENT	0
321133	314126	19695N	PARTICIPANT	\N	PRESENT	0
321135	314126	11056N	PARTICIPANT	\N	PRESENT	0
321136	314126	04035D	PARTICIPANT	\N	PRESENT	0
321137	314126	19758L	PARTICIPANT	\N	PRESENT	0
321138	314126	11040E	PARTICIPANT	\N	PRESENT	0
321139	314126	04085P	PARTICIPANT	\N	PRESENT	0
321140	314126	04034C	PARTICIPANT	\N	PRESENT	0
321141	314126	19515S	PARTICIPANT	\N	PRESENT	0
321142	314126	95037J	PARTICIPANT	\N	PRESENT	0
321143	314126	11080N	PARTICIPANT	\N	PRESENT	0
321144	314126	10015M	PARTICIPANT	\N	PRESENT	0
321145	314126	19697Q	PARTICIPANT	\N	PRESENT	0
321146	314126	01057W	PARTICIPANT	\N	PRESENT	0
321147	314126	14239U	PARTICIPANT	\N	PRESENT	0
321148	314126	11083R	PARTICIPANT	\N	PRESENT	0
321149	314126	19575F	PARTICIPANT	\N	PRESENT	0
321066	314126	08068F	PARTICIPANT	\N	PRESENT	0
321067	314126	11072N	PARTICIPANT	\N	PRESENT	0
321150	314126	08021P	PARTICIPANT	\N	PRESENT	0
321151	314126	08073C	PARTICIPANT	\N	PRESENT	0
321152	314126	19301E	PARTICIPANT	\N	PRESENT	0
321153	314126	08024S	PARTICIPANT	\N	PRESENT	0
321154	314126	89017R	PARTICIPANT	\N	PRESENT	0
321155	314126	19643A	PARTICIPANT	\N	PRESENT	0
321156	314126	19719D	PARTICIPANT	\N	PRESENT	0
321157	314126	14034U	PARTICIPANT	\N	PRESENT	0
321158	314126	11065P	PARTICIPANT	\N	PRESENT	0
321159	314126	11012A	PARTICIPANT	\N	PRESENT	0
321160	314126	19573D	PARTICIPANT	\N	PRESENT	0
321161	314126	19253P	PARTICIPANT	\N	PRESENT	0
321168	314126	14115H	PARTICIPANT	\N	PRESENT	0
321163	314126	19447X	PARTICIPANT	\N	PRESENT	0
321165	314126	92040Q	PARTICIPANT	\N	PRESENT	0
321166	314126	11049P	PARTICIPANT	\N	PRESENT	0
321167	314126	08049C	PARTICIPANT	\N	PRESENT	0
321169	314126	19629C	PARTICIPANT	\N	PRESENT	0
321170	314126	14201E	PARTICIPANT	\N	PRESENT	0
321171	314126	04049K	PARTICIPANT	\N	PRESENT	0
321172	314126	14241N	PARTICIPANT	\N	PRESENT	0
321173	314126	14147R	PARTICIPANT	\N	PRESENT	0
321174	314126	08010L	PARTICIPANT	\N	PRESENT	0
321175	314126	19563B	PARTICIPANT	\N	PRESENT	0
321176	314126	04042C	PARTICIPANT	\N	PRESENT	0
321177	314126	11099A	PARTICIPANT	\N	PRESENT	0
321178	314126	14107H	PARTICIPANT	\N	PRESENT	0
321179	314126	14038Y	PARTICIPANT	\N	PRESENT	0
321180	314126	19681G	PARTICIPANT	\N	PRESENT	0
321181	314126	19687N	PARTICIPANT	\N	PRESENT	0
321182	314126	04057K	PARTICIPANT	\N	PRESENT	0
321183	314126	11064N	PARTICIPANT	\N	PRESENT	0
321184	314126	19545Y	PARTICIPANT	\N	PRESENT	0
321185	314126	19585H	PARTICIPANT	\N	PRESENT	0
321188	314126	19269X	PARTICIPANT	\N	PRESENT	0
321190	314126	19723Y	PARTICIPANT	\N	PRESENT	0
321191	314126	14251Q	PARTICIPANT	\N	PRESENT	0
321192	314126	14033T	PARTICIPANT	\N	PRESENT	0
321195	314126	14119M	PARTICIPANT	\N	PRESENT	0
321197	314126	19693L	PARTICIPANT	\N	PRESENT	0
321198	314126	19349W	PARTICIPANT	\N	PRESENT	0
321199	314126	08048B	PARTICIPANT	\N	PRESENT	0
321200	314126	14213J	PARTICIPANT	\N	PRESENT	0
321201	314126	19591F	PARTICIPANT	\N	PRESENT	0
321202	314126	98035U	PARTICIPANT	\N	PRESENT	0
321203	314126	19705W	PARTICIPANT	\N	PRESENT	0
321204	314126	19503N	PARTICIPANT	\N	PRESENT	0
321205	314126	14121F	PARTICIPANT	\N	PRESENT	0
321206	314126	14029X	PARTICIPANT	\N	PRESENT	0
321207	314126	17779H	PARTICIPANT	\N	PRESENT	0
321208	314126	19489J	PARTICIPANT	\N	PRESENT	0
321209	314126	19507S	PARTICIPANT	\N	PRESENT	0
321210	314126	14207L	PARTICIPANT	\N	PRESENT	0
321211	314126	14001X	PARTICIPANT	\N	PRESENT	0
321212	314126	19399H	PARTICIPANT	\N	PRESENT	0
321213	314126	14257W	PARTICIPANT	\N	PRESENT	0
321214	314126	11066Q	PARTICIPANT	\N	PRESENT	0
321215	314126	14281W	PARTICIPANT	\N	PRESENT	0
321216	314126	08062Y	PARTICIPANT	\N	PRESENT	0
321217	314126	11110B	PARTICIPANT	\N	PRESENT	0
321218	314126	19651A	PARTICIPANT	\N	PRESENT	0
321219	314126	19729F	PARTICIPANT	\N	PRESENT	0
321220	314126	14229S	PARTICIPANT	\N	PRESENT	0
321221	314126	05012A	PARTICIPANT	\N	PRESENT	0
310464	309153	19659J	PARTICIPANT	\N	PRESENT	0
327712	321318	11070L	PARTICIPANT	\N	PRESENT	0
328597	321319	19671E	PARTICIPANT	\N	PRESENT	0
328598	321319	11012A	PARTICIPANT	\N	PRESENT	0
328599	321319	95041E	PARTICIPANT	\N	PRESENT	0
328600	321319	14267Y	PARTICIPANT	\N	PRESENT	0
328601	321319	08051V	PARTICIPANT	\N	PRESENT	0
328602	321319	19301E	PARTICIPANT	\N	PRESENT	0
328603	321319	19691J	PARTICIPANT	\N	PRESENT	0
328604	321319	08034U	PARTICIPANT	\N	PRESENT	0
328605	321319	04043D	PARTICIPANT	\N	PRESENT	0
328606	321319	19289C	PARTICIPANT	\N	PRESENT	0
328607	321319	14257W	PARTICIPANT	\N	PRESENT	0
328608	321319	19531S	PARTICIPANT	\N	PRESENT	0
328610	321319	11048N	PARTICIPANT	\N	PRESENT	0
328611	321319	11083R	PARTICIPANT	\N	PRESENT	0
328613	321319	98035U	PARTICIPANT	\N	PRESENT	0
328615	321319	02002K	PARTICIPANT	\N	PRESENT	0
328616	321319	18083K	PARTICIPANT	\N	PRESENT	0
328617	321319	14083S	PARTICIPANT	\N	PRESENT	0
328618	321319	14034U	PARTICIPANT	\N	PRESENT	0
328619	324921	11074Q	PRESIDENT	0	PRESENT	0
328620	324921	04086Q	PARTICIPANT	\N	PRESENT	0
328621	324921	11040E	PARTICIPANT	\N	PRESENT	0
328622	324921	14327T	PARTICIPANT	\N	PRESENT	0
328623	324921	07029T	PARTICIPANT	\N	PRESENT	0
328624	324921	11070L	PARTICIPANT	\N	PRESENT	0
328626	328625	14179A	PARTICIPANT	\N	PRESENT	0
328627	324921	19479G	PARTICIPANT	\N	PRESENT	0
328628	324921	08034U	PARTICIPANT	\N	PRESENT	0
328629	324921	01057W	PARTICIPANT	\N	PRESENT	0
328630	324921	08011M	PARTICIPANT	\N	PRESENT	0
328631	324921	14225N	PARTICIPANT	\N	PRESENT	0
328632	324921	14083S	PARTICIPANT	\N	PRESENT	0
328633	324921	19741B	PARTICIPANT	\N	PRESENT	0
328634	324921	95041E	PARTICIPANT	\N	PRESENT	0
328635	324921	19545Y	PARTICIPANT	\N	PRESENT	0
328636	324921	14034U	PARTICIPANT	\N	PRESENT	0
328637	324921	08010L	PARTICIPANT	\N	PRESENT	0
328638	324921	19647E	PARTICIPANT	\N	PRESENT	0
328639	324921	11048N	PARTICIPANT	\N	PRESENT	0
328640	324921	88008L	PARTICIPANT	\N	PRESENT	0
328641	324921	11053K	PARTICIPANT	\N	PRESENT	0
328697	328696	97011G	PARTICIPANT	\N	PRESENT	0
328723	328722	14053L	PARTICIPANT	\N	PRESENT	0
328725	328724	01028R	PARTICIPANT	\N	PRESENT	0
328752	328751	11048N	PARTICIPANT	\N	PRESENT	0
328754	328753	11048N	PARTICIPANT	\N	PRESENT	0
328855	318809	14219Q	PARTICIPANT	\N	PRESENT	0
328856	318809	11109J	PARTICIPANT	\N	PRESENT	0
329119	321342	12016W	PARTICIPANT	\N	PRESENT	0
329120	321342	19689Q	PARTICIPANT	\N	PRESENT	0
329121	321342	19545Y	PARTICIPANT	\N	PRESENT	0
329122	321342	08056B	PARTICIPANT	\N	PRESENT	0
329123	321342	19383Y	PARTICIPANT	\N	PRESENT	0
329124	321342	19762G	PARTICIPANT	\N	PRESENT	0
329125	321342	11103C	PARTICIPANT	\N	PRESENT	0
329126	321342	08015R	PARTICIPANT	\N	PRESENT	0
329127	321342	08062Y	PARTICIPANT	\N	PRESENT	0
329128	321342	14105F	PARTICIPANT	\N	PRESENT	0
329129	321342	19507S	PARTICIPANT	\N	PRESENT	0
329130	321342	14029X	PARTICIPANT	\N	PRESENT	0
329131	321342	19415P	PARTICIPANT	\N	PRESENT	0
329132	321342	19703U	PARTICIPANT	\N	PRESENT	0
329133	321342	19667J	PARTICIPANT	\N	PRESENT	0
329134	321342	01057W	PARTICIPANT	\N	PRESENT	0
329135	321342	87003B	PARTICIPANT	\N	PRESENT	0
329136	321342	19447X	PARTICIPANT	\N	PRESENT	0
329137	321342	19565D	PARTICIPANT	\N	PRESENT	0
329138	321342	19333N	PARTICIPANT	\N	PRESENT	0
329139	321342	19599P	PARTICIPANT	\N	PRESENT	0
329140	321342	19563B	PARTICIPANT	\N	PRESENT	0
329141	321342	19611R	PARTICIPANT	\N	PRESENT	0
329142	321342	19737F	PARTICIPANT	\N	PRESENT	0
329143	321342	14267Y	PARTICIPANT	\N	PRESENT	0
329144	321342	14021P	PARTICIPANT	\N	PRESENT	0
329145	321342	04045F	PARTICIPANT	\N	PRESENT	0
329146	321342	04086Q	PARTICIPANT	\N	PRESENT	0
329147	321342	14223L	PARTICIPANT	\N	PRESENT	0
329148	321342	14026U	PARTICIPANT	\N	PRESENT	0
329149	321342	08019V	PARTICIPANT	\N	PRESENT	0
329150	321342	14157T	PARTICIPANT	\N	PRESENT	0
329151	321342	14119M	PARTICIPANT	\N	PRESENT	0
329152	321342	19741B	PARTICIPANT	\N	PRESENT	0
329153	321342	95062K	PARTICIPANT	\N	PRESENT	0
329154	321342	19479G	PARTICIPANT	\N	PRESENT	0
329155	321342	14327T	PARTICIPANT	\N	PRESENT	0
329156	321342	16685X	PARTICIPANT	\N	PRESENT	0
329157	321342	19671E	PARTICIPANT	\N	PRESENT	0
329160	321342	19701S	PARTICIPANT	\N	PRESENT	0
329161	321342	97011G	PARTICIPANT	\N	PRESENT	0
329179	321342	14034U	PARTICIPANT	\N	PRESENT	0
329163	321342	19621T	PARTICIPANT	\N	PRESENT	0
329164	321342	08020N	PARTICIPANT	\N	PRESENT	0
329165	321342	14115H	PARTICIPANT	\N	PRESENT	0
329166	321342	14107H	PARTICIPANT	\N	PRESENT	0
329167	321342	04097T	PARTICIPANT	\N	PRESENT	0
329168	321342	19733B	PARTICIPANT	\N	PRESENT	0
329169	321342	95030B	PARTICIPANT	\N	PRESENT	0
329170	321342	19782L	PARTICIPANT	\N	PRESENT	0
329171	321342	14213J	PARTICIPANT	\N	PRESENT	0
329172	321342	04033B	PARTICIPANT	\N	PRESENT	0
329173	321342	19575F	PARTICIPANT	\N	PRESENT	0
329174	321342	04089T	PARTICIPANT	\N	PRESENT	0
329175	321342	19467C	PARTICIPANT	\N	PRESENT	0
329176	321342	11110B	PARTICIPANT	\N	PRESENT	0
329177	321342	14179A	PARTICIPANT	\N	PRESENT	0
329178	321342	15447F	PARTICIPANT	\N	PRESENT	0
329180	321342	19521Q	PARTICIPANT	\N	PRESENT	0
329181	321342	80027E	PARTICIPANT	\N	PRESENT	0
329182	321342	19301E	PARTICIPANT	\N	PRESENT	0
329183	321342	95067Q	PARTICIPANT	\N	PRESENT	0
329184	321342	08028W	PARTICIPANT	\N	PRESENT	0
329185	321342	14061L	PARTICIPANT	\N	PRESENT	0
329186	321342	14073Q	PARTICIPANT	\N	PRESENT	0
329187	321342	14169X	PARTICIPANT	\N	PRESENT	0
329188	321342	14207L	PARTICIPANT	\N	PRESENT	0
329189	321342	14087W	PARTICIPANT	\N	PRESENT	0
329190	321342	19369B	PARTICIPANT	\N	PRESENT	0
329191	321342	14187A	PARTICIPANT	\N	PRESENT	0
329192	321342	19745F	PARTICIPANT	\N	PRESENT	0
329193	321342	14219Q	PARTICIPANT	\N	PRESENT	0
329194	321342	89017R	PARTICIPANT	\N	PRESENT	0
329195	321342	19739H	PARTICIPANT	\N	PRESENT	0
329196	321342	07029T	PARTICIPANT	\N	PRESENT	0
329197	321342	98050T	PARTICIPANT	\N	PRESENT	0
329198	321342	19583F	PARTICIPANT	\N	PRESENT	0
329199	321342	04018C	PARTICIPANT	\N	PRESENT	0
329200	321342	14147R	PARTICIPANT	\N	PRESENT	0
329201	321342	19581D	PARTICIPANT	\N	PRESENT	0
329202	321342	01043Q	PARTICIPANT	\N	PRESENT	0
329203	321342	19349W	PARTICIPANT	\N	PRESENT	0
329204	321342	14053L	PARTICIPANT	\N	PRESENT	0
329205	321342	19713W	PARTICIPANT	\N	PRESENT	0
329328	321345	08060W	PARTICIPANT	\N	PRESENT	0
329329	321345	14051J	PARTICIPANT	\N	PRESENT	0
329330	321345	08043V	PARTICIPANT	\N	PRESENT	0
329331	321345	14207L	PARTICIPANT	\N	PRESENT	0
329332	321345	80013X	PARTICIPANT	\N	PRESENT	0
329333	321345	12016W	PARTICIPANT	\N	PRESENT	0
329334	321345	19681G	PARTICIPANT	\N	PRESENT	0
329335	321345	19583F	PARTICIPANT	\N	PRESENT	0
329336	321345	19731Y	PARTICIPANT	\N	PRESENT	0
329346	321345	11041F	PARTICIPANT	\N	PRESENT	0
329347	321345	11067R	PARTICIPANT	\N	PRESENT	0
329348	321345	11066Q	PARTICIPANT	\N	PRESENT	0
329340	321345	14227Q	PARTICIPANT	\N	PRESENT	0
329349	321345	19479G	PARTICIPANT	\N	PRESENT	0
329350	321345	14275Y	PARTICIPANT	\N	PRESENT	0
329351	321345	07004J	PARTICIPANT	\N	PRESENT	0
329352	321345	19599P	PARTICIPANT	\N	PRESENT	0
329345	321345	19651A	PARTICIPANT	\N	PRESENT	0
329353	321345	95062K	PARTICIPANT	\N	PRESENT	0
329354	321345	19766L	PARTICIPANT	\N	PRESENT	0
329355	321345	19349W	PARTICIPANT	\N	PRESENT	0
329356	321345	14223L	PARTICIPANT	\N	PRESENT	0
329357	321345	19741B	PARTICIPANT	\N	PRESENT	0
329358	321345	19383Y	PARTICIPANT	\N	PRESENT	0
329359	321345	87003B	PARTICIPANT	\N	PRESENT	0
329360	321345	14069U	PARTICIPANT	\N	PRESENT	0
329361	321345	08024S	PARTICIPANT	\N	PRESENT	0
329362	321345	14237S	PARTICIPANT	\N	PRESENT	0
329363	321345	14217N	PARTICIPANT	\N	PRESENT	0
329364	321345	14105F	PARTICIPANT	\N	PRESENT	0
329365	321345	19703U	PARTICIPANT	\N	PRESENT	0
329366	321345	14173T	PARTICIPANT	\N	PRESENT	0
329367	321345	14029X	PARTICIPANT	\N	PRESENT	0
329368	321345	17589D	PARTICIPANT	\N	PRESENT	0
305286	305285	04040A	PARTICIPANT	\N	PRESENT	0
305287	305285	11027H	PARTICIPANT	\N	PRESENT	0
305288	305285	14073Q	PARTICIPANT	\N	PRESENT	0
305289	305285	95063L	PARTICIPANT	\N	PRESENT	0
305290	305285	04034C	PARTICIPANT	\N	PRESENT	0
305350	305347	19503N	PARTICIPANT	\N	PRESENT	0
305348	305347	97011G	PARTICIPANT	\N	PRESENT	0
305349	305347	04092N	PARTICIPANT	\N	PRESENT	0
305351	305347	95067Q	PARTICIPANT	\N	PRESENT	0
305358	305357	08053X	PARTICIPANT	\N	PRESENT	0
305359	305357	97011G	PARTICIPANT	\N	PRESENT	0
305428	305427	14239U	PARTICIPANT	\N	PRESENT	0
305429	305427	14217N	PARTICIPANT	\N	PRESENT	0
305430	305427	11045K	PARTICIPANT	\N	PRESENT	0
305566	305436	11074Q	PARTICIPANT	\N	PRESENT	0
305567	305436	19741B	PARTICIPANT	\N	PRESENT	0
305568	305436	08011M	PARTICIPANT	\N	PRESENT	0
305569	305436	19531S	PARTICIPANT	\N	PRESENT	0
305570	305436	19479G	PARTICIPANT	\N	PRESENT	0
306035	305883	14327T	PARTICIPANT	\N	EXCUSE	0
308180	307140	14357A	PARTICIPANT	\N	PRESENT	0
308181	307140	14191V	PARTICIPANT	\N	PRESENT	0
308182	307140	14223L	PARTICIPANT	\N	PRESENT	0
308183	307140	19703U	PARTICIPANT	\N	PRESENT	0
308184	307140	11090Q	PARTICIPANT	\N	PRESENT	0
308185	307140	14187A	PARTICIPANT	\N	PRESENT	0
308186	307140	01058X	PARTICIPANT	\N	PRESENT	0
308187	307140	14053L	PARTICIPANT	\N	PRESENT	0
308188	307140	19335Q	PARTICIPANT	\N	PRESENT	0
308189	307140	14219Q	PARTICIPANT	\N	PRESENT	0
308190	307140	14073Q	PARTICIPANT	\N	PRESENT	0
308191	307140	14237S	PARTICIPANT	\N	PRESENT	0
308192	307140	14103D	PARTICIPANT	\N	PRESENT	0
308193	307140	11031D	PARTICIPANT	\N	PRESENT	0
308194	307140	19695N	PARTICIPANT	\N	PRESENT	0
308195	307140	80013X	PARTICIPANT	\N	PRESENT	0
308196	307140	19413M	PARTICIPANT	\N	PRESENT	0
308197	307140	19387D	PARTICIPANT	\N	PRESENT	0
308198	307140	19629C	PARTICIPANT	\N	PRESENT	0
308199	307140	14241N	PARTICIPANT	\N	PRESENT	0
308200	307140	19349W	PARTICIPANT	\N	PRESENT	0
308201	307140	14195A	PARTICIPANT	\N	PRESENT	0
308202	307140	19599P	PARTICIPANT	\N	PRESENT	0
308203	307140	19760E	PARTICIPANT	\N	PRESENT	0
308204	307140	14033T	PARTICIPANT	\N	PRESENT	0
308205	307140	95030B	PARTICIPANT	\N	PRESENT	0
308206	307140	17583W	PARTICIPANT	\N	PRESENT	0
308210	307140	19553Y	PARTICIPANT	\N	PRESENT	0
308208	307140	04061F	PARTICIPANT	\N	PRESENT	0
308209	307140	14093U	PARTICIPANT	\N	PRESENT	0
308211	307140	11012A	PARTICIPANT	\N	PRESENT	0
308212	307140	11048N	PARTICIPANT	\N	PRESENT	0
308213	307140	14119M	PARTICIPANT	\N	PRESENT	0
308214	307140	14199E	PARTICIPANT	\N	PRESENT	0
308215	307140	19253P	PARTICIPANT	\N	PRESENT	0
308216	307140	11056N	PARTICIPANT	\N	PRESENT	0
308217	307140	11065P	PARTICIPANT	\N	PRESENT	0
308218	307140	14038Y	PARTICIPANT	\N	PRESENT	0
308219	307140	95067Q	PARTICIPANT	\N	PRESENT	0
308220	307140	19733B	PARTICIPANT	\N	PRESENT	0
308221	307140	04088S	PARTICIPANT	\N	PRESENT	0
308222	307140	19347U	PARTICIPANT	\N	PRESENT	0
308178	307140	18083K	PARTICIPANT	\N	PRESENT	0
308179	307140	19675J	PARTICIPANT	\N	PRESENT	0
308223	307140	07029T	PARTICIPANT	\N	PRESENT	0
308224	307140	19383Y	PARTICIPANT	\N	PRESENT	0
308225	307140	11043H	PARTICIPANT	\N	PRESENT	0
308226	307140	11064N	PARTICIPANT	\N	PRESENT	0
308811	308810	19631V	PARTICIPANT	\N	PRESENT	0
308812	308810	14197C	PARTICIPANT	\N	PRESENT	0
308813	308810	19369B	PARTICIPANT	\N	PRESENT	0
308814	308810	14265W	PARTICIPANT	\N	PRESENT	0
308815	308810	19413M	PARTICIPANT	\N	PRESENT	0
308823	308810	14237S	PARTICIPANT	\N	PRESENT	0
308824	308810	19629C	PARTICIPANT	\N	PRESENT	0
308825	308810	19347U	PARTICIPANT	\N	PRESENT	0
308827	308826	08055A	PARTICIPANT	\N	PRESENT	0
308828	308826	08043V	PARTICIPANT	\N	PRESENT	0
308829	308826	14105F	PARTICIPANT	\N	PRESENT	0
308830	308826	08020N	PARTICIPANT	\N	PRESENT	0
308831	308826	14085U	PARTICIPANT	\N	PRESENT	0
308832	308826	88008L	PARTICIPANT	\N	PRESENT	0
308833	308826	14197C	PARTICIPANT	\N	PRESENT	0
308834	308826	95037J	PARTICIPANT	\N	PRESENT	0
308835	308826	14213J	PARTICIPANT	\N	PRESENT	0
308836	308826	14097Y	PARTICIPANT	\N	PRESENT	0
308837	308826	08015R	PARTICIPANT	\N	PRESENT	0
308838	308826	14059S	PARTICIPANT	\N	PRESENT	0
308840	308826	08053X	PARTICIPANT	\N	PRESENT	0
308841	308826	19369B	PARTICIPANT	\N	PRESENT	0
308842	308826	14109K	PARTICIPANT	\N	PRESENT	0
308843	308826	14265W	PARTICIPANT	\N	PRESENT	0
308844	308826	92040Q	PARTICIPANT	\N	PRESENT	0
308845	308826	19503N	PARTICIPANT	\N	PRESENT	0
308846	308826	14225N	PARTICIPANT	\N	PRESENT	0
308847	308826	11012A	PARTICIPANT	\N	PRESENT	0
308848	308826	14107H	PARTICIPANT	\N	PRESENT	0
308849	308826	11097X	PARTICIPANT	\N	PRESENT	0
308850	308826	19669L	PARTICIPANT	\N	PRESENT	0
308851	308826	01062T	PARTICIPANT	\N	PRESENT	0
308852	308826	14257W	PARTICIPANT	\N	PRESENT	0
308856	308855	19515S	PARTICIPANT	\N	PRESENT	0
308857	308855	19367Y	PARTICIPANT	\N	PRESENT	0
308858	308855	14069U	PARTICIPANT	\N	PRESENT	0
308859	308855	19383Y	PARTICIPANT	\N	PRESENT	0
308860	308855	17589D	PARTICIPANT	\N	PRESENT	0
308861	308855	19507S	PARTICIPANT	\N	PRESENT	0
308862	308855	14033T	PARTICIPANT	\N	PRESENT	0
308863	308855	19551W	PARTICIPANT	\N	PRESENT	0
308864	308855	19511N	PARTICIPANT	\N	PRESENT	0
308865	308855	14097Y	PARTICIPANT	\N	PRESENT	0
308866	308855	08015R	PARTICIPANT	\N	PRESENT	0
308867	308855	19563B	PARTICIPANT	\N	PRESENT	0
308868	308855	14265W	PARTICIPANT	\N	PRESENT	0
308869	308855	19745F	PARTICIPANT	\N	PRESENT	0
308870	308855	04088S	PARTICIPANT	\N	PRESENT	0
308871	308855	14135M	PARTICIPANT	\N	PRESENT	0
308872	308855	14107H	PARTICIPANT	\N	PRESENT	0
308873	308855	11097X	PARTICIPANT	\N	PRESENT	0
308874	308855	08049C	PARTICIPANT	\N	PRESENT	0
308875	308855	14109K	PARTICIPANT	\N	PRESENT	0
308877	308855	08020N	PARTICIPANT	\N	PRESENT	0
308878	308855	19441R	PARTICIPANT	\N	PRESENT	0
308879	308855	19747H	PARTICIPANT	\N	PRESENT	0
308899	308898	08055A	PARTICIPANT	\N	PRESENT	0
308900	308898	14069U	PARTICIPANT	\N	PRESENT	0
308901	308898	14207L	PARTICIPANT	\N	PRESENT	0
308902	308898	11103C	PARTICIPANT	\N	PRESENT	0
308903	308898	14329V	PARTICIPANT	\N	PRESENT	0
308904	308898	11080N	PARTICIPANT	\N	PRESENT	0
308905	308898	19467C	PARTICIPANT	\N	PRESENT	0
308906	308898	18083K	PARTICIPANT	\N	PRESENT	0
308907	308898	14357A	PARTICIPANT	\N	PRESENT	0
308908	308898	17589D	PARTICIPANT	\N	PRESENT	0
308909	308898	04089T	PARTICIPANT	\N	PRESENT	0
308910	308898	19507S	PARTICIPANT	\N	PRESENT	0
308911	308898	14187A	PARTICIPANT	\N	PRESENT	0
308912	308898	01057W	PARTICIPANT	\N	PRESENT	0
308913	308898	19551W	PARTICIPANT	\N	PRESENT	0
308914	308898	19723Y	PARTICIPANT	\N	PRESENT	0
308915	308898	08034U	PARTICIPANT	\N	PRESENT	0
308916	308898	16685X	PARTICIPANT	\N	PRESENT	0
308917	308898	14059S	PARTICIPANT	\N	PRESENT	0
308918	308898	17779H	PARTICIPANT	\N	PRESENT	0
308919	308898	08053X	PARTICIPANT	\N	PRESENT	0
308920	308898	14221J	PARTICIPANT	\N	PRESENT	0
308921	308898	19563B	PARTICIPANT	\N	PRESENT	0
308922	308898	14119M	PARTICIPANT	\N	PRESENT	0
308923	308898	14265W	PARTICIPANT	\N	PRESENT	0
308924	308898	04088S	PARTICIPANT	\N	PRESENT	0
308925	308898	05012A	PARTICIPANT	\N	PRESENT	0
308926	308898	98050T	PARTICIPANT	\N	PRESENT	0
308927	308898	19739H	PARTICIPANT	\N	PRESENT	0
308928	308898	17583W	PARTICIPANT	\N	PRESENT	0
308929	308898	19679N	PARTICIPANT	\N	PRESENT	0
308930	308898	14331P	PARTICIPANT	\N	PRESENT	0
308931	308898	14107H	PARTICIPANT	\N	PRESENT	0
308932	308898	19619A	PARTICIPANT	\N	PRESENT	0
309063	309062	04043D	PARTICIPANT	\N	PRESENT	0
309154	306017	11097X	PARTICIPANT	\N	EXCUSE	0
309155	305886	11097X	PARTICIPANT	\N	EXCUSE	0
309334	305573	08010L	PARTICIPANT	\N	PRESENT	0
309381	309380	19733B	PARTICIPANT	\N	PRESENT	0
309382	309380	18083K	PARTICIPANT	\N	PRESENT	0
309383	309380	19659J	PARTICIPANT	\N	PRESENT	0
309384	309380	19347U	PARTICIPANT	\N	PRESENT	0
309385	309380	14219Q	PARTICIPANT	\N	PRESENT	0
316499	316398	19593H	PARTICIPANT	\N	PRESENT	0
316500	316398	04070G	PARTICIPANT	\N	PRESENT	0
316501	316398	19699S	PARTICIPANT	\N	PRESENT	0
316502	316398	19611R	PARTICIPANT	\N	PRESENT	0
316503	316398	87003B	PARTICIPANT	\N	PRESENT	0
316504	316398	19399H	PARTICIPANT	\N	PRESENT	0
316505	316398	08020N	PARTICIPANT	\N	PRESENT	0
316506	316398	19573D	PARTICIPANT	\N	PRESENT	0
316507	316398	04059M	PARTICIPANT	\N	PRESENT	0
316508	316398	19735D	PARTICIPANT	\N	PRESENT	0
316509	316398	11109J	PARTICIPANT	\N	PRESENT	0
316510	316398	14063N	PARTICIPANT	\N	PRESENT	0
316511	316398	92040Q	PARTICIPANT	\N	PRESENT	0
316512	316398	04018C	PARTICIPANT	\N	PRESENT	0
316513	316398	08039A	PARTICIPANT	\N	PRESENT	0
316544	309288	19721W	PARTICIPANT	\N	PRESENT	0
316546	309288	14039A	PARTICIPANT	\N	PRESENT	0
316551	309288	19683J	PARTICIPANT	\N	PRESENT	0
316552	309288	08021P	PARTICIPANT	\N	PRESENT	0
316553	309288	98022P	PARTICIPANT	\N	PRESENT	0
316554	309288	19591F	PARTICIPANT	\N	PRESENT	0
316555	309288	19347U	PARTICIPANT	\N	PRESENT	0
316556	309288	14001X	PARTICIPANT	\N	PRESENT	0
316557	309288	19629C	PARTICIPANT	\N	PRESENT	0
316558	309288	04059M	PARTICIPANT	\N	PRESENT	0
316559	309288	19737F	PARTICIPANT	\N	PRESENT	0
316560	309288	11085T	PARTICIPANT	\N	PRESENT	0
316561	309288	19695N	PARTICIPANT	\N	PRESENT	0
316562	309288	19760E	PARTICIPANT	\N	PRESENT	0
316563	309288	14107H	PARTICIPANT	\N	PRESENT	0
316564	309288	19599P	PARTICIPANT	\N	PRESENT	0
316566	309288	19413M	PARTICIPANT	\N	PRESENT	0
316567	309288	11104D	PARTICIPANT	\N	PRESENT	0
316568	309288	11045K	PARTICIPANT	\N	PRESENT	0
316571	309288	14197C	PARTICIPANT	\N	PRESENT	0
316573	309288	19549D	PARTICIPANT	\N	PRESENT	0
316574	309288	14111D	PARTICIPANT	\N	PRESENT	0
316577	309288	80013X	PARTICIPANT	\N	PRESENT	0
316579	309288	08024S	PARTICIPANT	\N	PRESENT	0
316580	309288	19333N	PARTICIPANT	\N	PRESENT	0
316581	309288	08045X	PARTICIPANT	\N	PRESENT	0
316582	309288	14227Q	PARTICIPANT	\N	PRESENT	0
316584	309288	14097Y	PARTICIPANT	\N	PRESENT	0
316585	309288	14281W	PARTICIPANT	\N	PRESENT	0
316586	309288	08060W	PARTICIPANT	\N	PRESENT	0
316587	309288	19489J	PARTICIPANT	\N	PRESENT	0
316588	309288	14063N	PARTICIPANT	\N	PRESENT	0
316589	309288	04045F	PARTICIPANT	\N	PRESENT	0
316590	309288	95063L	PARTICIPANT	\N	PRESENT	0
316591	309288	08061X	PARTICIPANT	\N	PRESENT	0
316592	309288	14201E	PARTICIPANT	\N	PRESENT	0
316593	309288	08058D	PARTICIPANT	\N	PRESENT	0
316594	309288	11066Q	PARTICIPANT	\N	PRESENT	0
316595	309288	98029W	PARTICIPANT	\N	PRESENT	0
316596	309288	19511N	PARTICIPANT	\N	PRESENT	0
316597	309288	19691J	PARTICIPANT	\N	PRESENT	0
316598	309288	16685X	PARTICIPANT	\N	PRESENT	0
316599	309288	04038G	PARTICIPANT	\N	PRESENT	0
316600	309288	19565D	PARTICIPANT	\N	PRESENT	0
316601	309288	04085P	PARTICIPANT	\N	PRESENT	0
316602	309288	11074Q	PARTICIPANT	\N	PRESENT	0
316603	309288	98035U	PARTICIPANT	\N	PRESENT	0
316604	309288	08052W	PARTICIPANT	\N	PRESENT	0
316605	309288	19715Y	PARTICIPANT	\N	PRESENT	0
316606	309288	19503N	PARTICIPANT	\N	PRESENT	0
316607	309288	11040E	PARTICIPANT	\N	PRESENT	0
316609	309288	19593H	PARTICIPANT	\N	PRESENT	0
316610	309288	19687N	PARTICIPANT	\N	PRESENT	0
316611	309288	11054L	PARTICIPANT	\N	PRESENT	0
316612	309288	14159V	PARTICIPANT	\N	PRESENT	0
316614	309288	14257W	PARTICIPANT	\N	PRESENT	0
316615	309288	19725B	PARTICIPANT	\N	PRESENT	0
316616	309288	08055A	PARTICIPANT	\N	PRESENT	0
316617	309288	14225N	PARTICIPANT	\N	PRESENT	0
316618	309288	08038Y	PARTICIPANT	\N	PRESENT	0
316619	309288	11110B	PARTICIPANT	\N	PRESENT	0
316620	309288	04057K	PARTICIPANT	\N	PRESENT	0
316621	309288	19387D	PARTICIPANT	\N	PRESENT	0
316623	309288	11099A	PARTICIPANT	\N	PRESENT	0
316624	309288	19563B	PARTICIPANT	\N	PRESENT	0
316625	309288	08049C	PARTICIPANT	\N	PRESENT	0
316626	309288	11077T	PARTICIPANT	\N	PRESENT	0
316627	309288	14081Q	PARTICIPANT	\N	PRESENT	0
316628	309288	19637C	PARTICIPANT	\N	PRESENT	0
316629	309288	19735D	PARTICIPANT	\N	PRESENT	0
316630	309288	19569H	PARTICIPANT	\N	PRESENT	0
316631	309288	19479G	PARTICIPANT	\N	PRESENT	0
316632	309288	19699S	PARTICIPANT	\N	PRESENT	0
316633	309288	11033F	PARTICIPANT	\N	PRESENT	0
316634	309288	19758L	PARTICIPANT	\N	PRESENT	0
316635	309288	11083R	PARTICIPANT	\N	PRESENT	0
316636	309288	19651A	PARTICIPANT	\N	PRESENT	0
316637	309288	19697Q	PARTICIPANT	\N	PRESENT	0
316638	309288	19669L	PARTICIPANT	\N	PRESENT	0
316639	309288	14034U	PARTICIPANT	\N	PRESENT	0
316640	309288	08031R	PARTICIPANT	\N	PRESENT	0
316641	309288	19253P	PARTICIPANT	\N	PRESENT	0
316642	309288	14261S	PARTICIPANT	\N	PRESENT	0
316643	309288	08011M	PARTICIPANT	\N	PRESENT	0
316644	309288	04034C	PARTICIPANT	\N	PRESENT	0
316646	309288	19585H	PARTICIPANT	\N	PRESENT	0
316647	309288	17589D	PARTICIPANT	\N	PRESENT	0
316648	309288	11064N	PARTICIPANT	\N	PRESENT	0
316649	309288	19711U	PARTICIPANT	\N	PRESENT	0
316650	309288	14055N	PARTICIPANT	\N	PRESENT	0
316651	309288	01060R	PARTICIPANT	\N	PRESENT	0
316652	309288	14157T	PARTICIPANT	\N	PRESENT	0
316653	309288	19551W	PARTICIPANT	\N	PRESENT	0
316654	309288	19545Y	PARTICIPANT	\N	PRESENT	0
316655	309288	01028R	PARTICIPANT	\N	PRESENT	0
316656	309288	12016W	PARTICIPANT	\N	PRESENT	0
316658	309288	95037J	PARTICIPANT	\N	PRESENT	0
316659	309288	19553Y	PARTICIPANT	\N	PRESENT	0
316660	309288	04097T	PARTICIPANT	\N	PRESENT	0
316661	309288	08039A	PARTICIPANT	\N	PRESENT	0
316662	309288	19329S	PARTICIPANT	\N	PRESENT	0
316663	309288	08020N	PARTICIPANT	\N	PRESENT	0
316664	309288	19649G	PARTICIPANT	\N	PRESENT	0
316665	309288	08069G	PARTICIPANT	\N	PRESENT	0
316666	309288	14123H	PARTICIPANT	\N	PRESENT	0
316667	309288	08012N	PARTICIPANT	\N	PRESENT	0
316668	309288	08010L	PARTICIPANT	\N	PRESENT	0
316669	309288	19727D	PARTICIPANT	\N	PRESENT	0
316671	309288	11065P	PARTICIPANT	\N	PRESENT	0
316672	309288	14121F	PARTICIPANT	\N	PRESENT	0
316673	309288	14085U	PARTICIPANT	\N	PRESENT	0
316674	309288	17779H	PARTICIPANT	\N	PRESENT	0
316675	309288	04071H	PARTICIPANT	\N	PRESENT	0
316676	309288	14223L	PARTICIPANT	\N	PRESENT	0
316677	309288	19515S	PARTICIPANT	\N	PRESENT	0
316678	309288	19295A	PARTICIPANT	\N	PRESENT	0
316679	309288	14191V	PARTICIPANT	\N	PRESENT	0
316680	309288	11080N	PARTICIPANT	\N	PRESENT	0
316681	309288	19631V	PARTICIPANT	\N	PRESENT	0
316682	309288	19689Q	PARTICIPANT	\N	PRESENT	0
316683	309288	19766L	PARTICIPANT	\N	PRESENT	0
316684	309288	14259Y	PARTICIPANT	\N	PRESENT	0
316685	309288	01057W	PARTICIPANT	\N	PRESENT	0
316686	309288	19527W	PARTICIPANT	\N	PRESENT	0
316687	309288	87003B	PARTICIPANT	\N	PRESENT	0
316688	309288	11090Q	PARTICIPANT	\N	PRESENT	0
316689	309288	14031R	PARTICIPANT	\N	PRESENT	0
316690	309288	96004D	PARTICIPANT	\N	PRESENT	0
316691	309288	19525U	PARTICIPANT	\N	PRESENT	0
316692	309288	19667J	PARTICIPANT	\N	PRESENT	0
316693	309288	14199E	PARTICIPANT	\N	PRESENT	0
316694	309288	14207L	PARTICIPANT	\N	PRESENT	0
316695	309288	11072N	PARTICIPANT	\N	PRESENT	0
316696	309288	14253S	PARTICIPANT	\N	PRESENT	0
316697	309288	11041F	PARTICIPANT	\N	PRESENT	0
316698	309288	19673G	PARTICIPANT	\N	PRESENT	0
316699	309288	01062T	PARTICIPANT	\N	PRESENT	0
316700	309288	11048N	PARTICIPANT	\N	PRESENT	0
316701	309288	19507S	PARTICIPANT	\N	PRESENT	0
316702	309288	14021P	PARTICIPANT	\N	PRESENT	0
316703	309288	19447X	PARTICIPANT	\N	PRESENT	0
316704	309288	19573D	PARTICIPANT	\N	PRESENT	0
316705	309288	11031D	PARTICIPANT	\N	PRESENT	0
316706	309288	98005N	PARTICIPANT	\N	PRESENT	0
316708	309288	14119M	PARTICIPANT	\N	PRESENT	0
316709	309288	08047A	PARTICIPANT	\N	PRESENT	0
316710	309288	14115H	PARTICIPANT	\N	PRESENT	0
316711	309288	04049K	PARTICIPANT	\N	PRESENT	0
316713	309288	14038Y	PARTICIPANT	\N	PRESENT	0
316714	309288	14231L	PARTICIPANT	\N	PRESENT	0
316715	309288	19723Y	PARTICIPANT	\N	PRESENT	0
305389	305388	14255U	PARTICIPANT	\N	PRESENT	0
305390	305388	19701S	PARTICIPANT	\N	PRESENT	0
305391	305388	19671E	PARTICIPANT	\N	PRESENT	0
308652	305550	14030Q	PARTICIPANT	\N	PRESENT	0
308653	305550	08043V	PRESIDENT	0	PRESENT	0
308654	305550	19367Y	PARTICIPANT	\N	PRESENT	0
308655	305550	19643A	PARTICIPANT	\N	PRESENT	0
308656	305550	19621T	PARTICIPANT	\N	PRESENT	0
308657	305550	08020N	PARTICIPANT	\N	EXCUSE	0
308658	305550	08024S	PARTICIPANT	\N	EXCUSE	0
308659	305550	19701S	PARTICIPANT	\N	PRESENT	0
308660	305550	11031D	PARTICIPANT	\N	EXCUSE	0
308661	305550	19693L	PARTICIPANT	\N	PRESENT	0
308662	305550	14217N	PARTICIPANT	\N	PRESENT	0
308663	305550	19599P	PARTICIPANT	\N	EXCUSE	0
308664	305550	19715Y	PARTICIPANT	\N	EXCUSE	0
308665	305550	19731Y	PARTICIPANT	\N	EXCUSE	0
308666	305550	08031R	PARTICIPANT	\N	PRESENT	0
308667	305550	07029T	PARTICIPANT	\N	PRESENT	0
308668	305550	08017T	PARTICIPANT	\N	PRESENT	0
308669	305550	01043Q	PARTICIPANT	\N	EXCUSE	0
308670	305550	19697Q	PARTICIPANT	\N	EXCUSE	0
308671	305550	14251Q	PARTICIPANT	\N	PRESENT	0
308672	305550	19563B	PARTICIPANT	\N	PRESENT	0
308673	305550	14109K	PARTICIPANT	\N	EXCUSE	0
308674	305550	14235Q	PARTICIPANT	\N	PRESENT	0
308675	305550	19269X	PARTICIPANT	\N	PRESENT	0
308676	305550	11045K	PARTICIPANT	\N	PRESENT	0
308677	305550	19749K	PARTICIPANT	\N	PRESENT	0
308678	305550	19577H	PARTICIPANT	\N	EXCUSE	0
308689	307133	11081P	PARTICIPANT	\N	EXCUSE	0
311722	305978	08053X	PARTICIPANT	\N	EXCUSE	0
311723	305978	19533U	PARTICIPANT	\N	EXCUSE	0
311726	307069	11067R	PARTICIPANT	\N	PRESENT	0
311727	307072	11067R	PARTICIPANT	\N	PRESENT	0
311728	307073	11067R	PARTICIPANT	\N	PRESENT	0
318852	318848	14159V	PARTICIPANT	\N	PRESENT	0
318853	318848	11110B	PARTICIPANT	\N	PRESENT	0
318865	318864	11074Q	PARTICIPANT	\N	PRESENT	0
318868	318867	11074Q	PARTICIPANT	\N	PRESENT	0
321222	314126	14097Y	PARTICIPANT	\N	PRESENT	0
321223	314126	12016W	PARTICIPANT	\N	PRESENT	0
318836	318820	19667J	PARTICIPANT	\N	PRESENT	0
318838	318820	11040E	PARTICIPANT	\N	PRESENT	0
321224	314126	14329V	PARTICIPANT	\N	PRESENT	0
321225	314126	14028W	PARTICIPANT	\N	PRESENT	0
321226	314126	14357A	PARTICIPANT	\N	PRESENT	0
321227	314126	19727D	PARTICIPANT	\N	PRESENT	0
321228	314126	19383Y	PARTICIPANT	\N	PRESENT	0
321229	314126	11045K	PARTICIPANT	\N	PRESENT	0
321230	314126	04018C	PARTICIPANT	\N	PRESENT	0
321231	314126	19649G	PARTICIPANT	\N	PRESENT	0
321232	314126	19701S	PARTICIPANT	\N	PRESENT	0
321233	314126	19647E	PARTICIPANT	\N	PRESENT	0
321234	314126	11074Q	PARTICIPANT	\N	PRESENT	0
321235	314126	14159V	PARTICIPANT	\N	PRESENT	0
321752	321751	04061F	PARTICIPANT	\N	PRESENT	0
321237	314126	14227Q	PARTICIPANT	\N	PRESENT	0
321238	314126	19549D	PARTICIPANT	\N	PRESENT	0
321239	314126	19333N	PARTICIPANT	\N	PRESENT	0
321240	314126	19725B	PARTICIPANT	\N	PRESENT	0
321241	314126	19631V	PARTICIPANT	\N	PRESENT	0
321242	314126	08012N	PARTICIPANT	\N	PRESENT	0
321243	314126	11041F	PARTICIPANT	\N	PRESENT	0
321244	314126	19531S	PARTICIPANT	\N	PRESENT	0
321245	314126	04092N	PARTICIPANT	\N	PRESENT	0
321246	314126	04044E	PARTICIPANT	\N	PRESENT	0
321247	314126	04038G	PARTICIPANT	\N	PRESENT	0
321248	314126	95041E	PARTICIPANT	\N	PRESENT	0
321249	314126	14071N	PARTICIPANT	\N	PRESENT	0
321250	314126	14151M	PARTICIPANT	\N	PRESENT	0
321251	314126	19715Y	PARTICIPANT	\N	PRESENT	0
321252	314126	01028R	PARTICIPANT	\N	PRESENT	0
321253	314126	08055A	PARTICIPANT	\N	PRESENT	0
321254	314126	08052W	PARTICIPANT	\N	PRESENT	0
321255	314126	19669L	PARTICIPANT	\N	PRESENT	0
321256	314126	08045X	PARTICIPANT	\N	PRESENT	0
321257	314126	14069U	PARTICIPANT	\N	PRESENT	0
321258	314126	08038Y	PARTICIPANT	\N	PRESENT	0
321754	321753	11053K	PARTICIPANT	\N	PRESENT	0
321260	314126	14237S	PARTICIPANT	\N	PRESENT	0
321261	314126	14087W	PARTICIPANT	\N	PRESENT	0
321262	314126	14215L	PARTICIPANT	\N	PRESENT	0
321263	314126	14081Q	PARTICIPANT	\N	PRESENT	0
321264	314126	11090Q	PARTICIPANT	\N	PRESENT	0
321265	314126	14085U	PARTICIPANT	\N	PRESENT	0
321266	314126	19347U	PARTICIPANT	\N	PRESENT	0
321267	314126	11077T	PARTICIPANT	\N	PRESENT	0
321268	314126	14217N	PARTICIPANT	\N	PRESENT	0
321269	314126	19413M	PARTICIPANT	\N	PRESENT	0
321270	314126	04061F	PARTICIPANT	\N	PRESENT	0
321271	314126	11053K	PARTICIPANT	\N	PRESENT	0
321272	314126	14061L	PARTICIPANT	\N	PRESENT	0
321273	314126	19441R	PARTICIPANT	\N	PRESENT	0
321274	314126	01024M	PARTICIPANT	\N	PRESENT	0
321275	314126	14059S	PARTICIPANT	\N	PRESENT	0
321276	314126	19479G	PARTICIPANT	\N	PRESENT	0
321277	314126	14042U	PARTICIPANT	\N	PRESENT	0
321278	314126	19551W	PARTICIPANT	\N	PRESENT	0
321279	314126	19733B	PARTICIPANT	\N	PRESENT	0
321280	314126	19569H	PARTICIPANT	\N	PRESENT	0
321281	314126	08056B	PARTICIPANT	\N	PRESENT	0
321282	314126	19735D	PARTICIPANT	\N	PRESENT	0
321283	314126	14123H	PARTICIPANT	\N	PRESENT	0
321284	314126	16685X	PARTICIPANT	\N	PRESENT	0
321285	314126	19721W	PARTICIPANT	\N	PRESENT	0
321286	314126	19611R	PARTICIPANT	\N	PRESENT	0
321287	314126	01025N	PARTICIPANT	\N	PRESENT	0
321288	314126	19521Q	PARTICIPANT	\N	PRESENT	0
321289	314126	14205J	PARTICIPANT	\N	PRESENT	0
321290	314126	14221J	PARTICIPANT	\N	PRESENT	0
321291	314126	14267Y	PARTICIPANT	\N	PRESENT	0
321292	314126	08044W	PARTICIPANT	\N	PRESENT	0
321293	314126	19739H	PARTICIPANT	\N	PRESENT	0
321294	314126	19747H	PARTICIPANT	\N	PRESENT	0
321295	314126	19619A	PARTICIPANT	\N	PRESENT	0
321296	314126	19749K	PARTICIPANT	\N	PRESENT	0
321297	314126	19699S	PARTICIPANT	\N	PRESENT	0
321298	314126	04070G	PARTICIPANT	\N	PRESENT	0
321299	314126	14103D	PARTICIPANT	\N	PRESENT	0
321300	314126	14030Q	PARTICIPANT	\N	PRESENT	0
321301	314126	04040A	PARTICIPANT	\N	PRESENT	0
321302	314126	19663E	PARTICIPANT	\N	PRESENT	0
321303	314126	19335Q	PARTICIPANT	\N	PRESENT	0
321304	314126	19691J	PARTICIPANT	\N	PRESENT	0
321305	314126	14327T	PARTICIPANT	\N	PRESENT	0
321306	314126	08009T	PARTICIPANT	\N	PRESENT	0
321307	314126	14055N	PARTICIPANT	\N	PRESENT	0
321308	314126	88008L	PARTICIPANT	\N	PRESENT	0
321750	321749	11053K	PARTICIPANT	\N	PRESENT	0
321756	321755	19689Q	PARTICIPANT	\N	PRESENT	0
321758	321757	19545Y	PARTICIPANT	\N	PRESENT	0
321759	321757	19689Q	PARTICIPANT	\N	PRESENT	0
321763	321762	12016W	PARTICIPANT	\N	PRESENT	0
321765	321764	19479G	PARTICIPANT	\N	PRESENT	0
321781	321780	11048N	PARTICIPANT	\N	PRESENT	0
321783	321782	11048N	PARTICIPANT	\N	PRESENT	0
321785	321784	11048N	PARTICIPANT	\N	PRESENT	0
321787	321786	11074Q	PARTICIPANT	\N	PRESENT	0
321899	314147	04059M	PARTICIPANT	\N	PRESENT	0
321900	314147	04092N	PARTICIPANT	\N	PRESENT	0
321901	314147	99004R	PARTICIPANT	\N	PRESENT	0
321902	321898	11067R	PARTICIPANT	\N	PRESENT	0
321903	321898	01034P	PARTICIPANT	\N	PRESENT	0
321904	321898	04092N	PRESIDENT	0	PRESENT	0
321905	321898	11097X	PARTICIPANT	\N	PRESENT	0
321906	321898	08052W	PARTICIPANT	\N	PRESENT	0
321907	321898	19663E	PARTICIPANT	\N	PRESENT	0
321908	321898	19415P	PARTICIPANT	\N	PRESENT	0
321909	321898	14227Q	PARTICIPANT	\N	PRESENT	0
321910	321898	17779H	PARTICIPANT	\N	PRESENT	0
321911	321898	19727D	PARTICIPANT	\N	PRESENT	0
321912	321898	11031D	PARTICIPANT	\N	PRESENT	0
321913	321898	14281W	PARTICIPANT	\N	PRESENT	0
321914	321898	11103C	PARTICIPANT	\N	PRESENT	0
321915	321898	19575F	PARTICIPANT	\N	PRESENT	0
321916	321898	14213J	PARTICIPANT	\N	PRESENT	0
321917	321898	19657G	PARTICIPANT	\N	PRESENT	0
321918	321898	14217N	PARTICIPANT	\N	PRESENT	0
321919	321898	19683J	PARTICIPANT	\N	PRESENT	0
321920	321898	98024R	PARTICIPANT	\N	PRESENT	0
321921	321898	14087W	PARTICIPANT	\N	EXCUSE	0
321922	321898	14042U	PARTICIPANT	\N	EXCUSE	0
321923	321898	14195A	PARTICIPANT	\N	PRESENT	0
321924	321898	04045F	PARTICIPANT	\N	EXCUSE	0
321925	321898	08041T	PARTICIPANT	\N	EXCUSE	0
321926	321898	19760E	PARTICIPANT	\N	PRESENT	0
322005	321788	19663E	PARTICIPANT	\N	PRESENT	0
322006	321788	19697Q	PARTICIPANT	\N	PRESENT	0
301999	301918	19687N	PARTICIPANT	\N	PRESENT	0
315768	315762	14229S	PARTICIPANT	\N	PRESENT	0
315769	315762	19735D	PARTICIPANT	\N	PRESENT	0
315770	315762	08043V	PARTICIPANT	\N	PRESENT	0
315773	315759	14229S	PARTICIPANT	\N	PRESENT	0
315846	315845	96004D	PARTICIPANT	\N	PRESENT	0
315847	315845	19725B	PARTICIPANT	\N	PRESENT	0
316366	314445	19549D	PARTICIPANT	\N	PRESENT	0
316367	314445	14069U	PARTICIPANT	\N	PRESENT	0
316368	314445	14083S	PARTICIPANT	\N	PRESENT	0
316369	314445	14073Q	PARTICIPANT	\N	PRESENT	0
316370	314445	19637C	PARTICIPANT	\N	PRESENT	0
316371	314445	11085T	PARTICIPANT	\N	PRESENT	0
316372	314445	08049C	PARTICIPANT	\N	PRESENT	0
316373	314445	14219Q	PARTICIPANT	\N	PRESENT	0
316374	314303	88008L	PARTICIPANT	\N	PRESENT	0
316375	314303	08038Y	PARTICIPANT	\N	PRESENT	0
316376	314303	19745F	PARTICIPANT	\N	PRESENT	0
316377	314303	19533U	PARTICIPANT	\N	PRESENT	0
316378	314303	11097X	PARTICIPANT	\N	PRESENT	0
316379	314303	97011G	PARTICIPANT	\N	PRESENT	0
316380	314303	14033T	PARTICIPANT	\N	PRESENT	0
316381	314303	19725B	PARTICIPANT	\N	PRESENT	0
316382	314303	11048N	PARTICIPANT	\N	PRESENT	0
316383	314303	14265W	PARTICIPANT	\N	PRESENT	0
326679	326678	04038G	PARTICIPANT	\N	PRESENT	0
327215	318991	14042U	PARTICIPANT	\N	PRESENT	0
327253	322456	04061F	PARTICIPANT	\N	EXCUSE	0
327527	314178	08060W	PARTICIPANT	\N	PRESENT	0
327528	314178	19543W	PARTICIPANT	\N	PRESENT	0
327529	314178	19782L	PARTICIPANT	\N	PRESENT	0
327530	314178	19269X	PARTICIPANT	\N	PRESENT	0
327531	314178	19659J	PARTICIPANT	\N	PRESENT	0
327532	314178	08024S	PARTICIPANT	\N	PRESENT	0
327533	314178	08049C	PARTICIPANT	\N	PRESENT	0
327534	314178	19553Y	PARTICIPANT	\N	PRESENT	0
327535	314178	17589D	PARTICIPANT	\N	PRESENT	0
327536	314178	17637T	PARTICIPANT	\N	PRESENT	0
327537	314178	19399H	PARTICIPANT	\N	PRESENT	0
327538	314178	17583W	PARTICIPANT	\N	PRESENT	0
327539	314178	19637C	PARTICIPANT	\N	PRESENT	0
327540	314178	14083S	PARTICIPANT	\N	PRESENT	0
327541	314178	98023Q	PARTICIPANT	\N	PRESENT	0
327542	314178	19737F	PARTICIPANT	\N	PRESENT	0
327543	314178	19687N	PARTICIPANT	\N	PRESENT	0
327544	314178	95030B	PARTICIPANT	\N	PRESENT	0
327545	314178	14221J	PARTICIPANT	\N	PRESENT	0
327546	314178	19549D	PARTICIPANT	\N	PRESENT	0
327547	314178	19565D	PARTICIPANT	\N	PRESENT	0
327548	314178	14031R	PARTICIPANT	\N	PRESENT	0
327549	314178	14249W	PARTICIPANT	\N	PRESENT	0
327550	314178	80013X	PARTICIPANT	\N	PRESENT	0
327551	314178	19383Y	PARTICIPANT	\N	PRESENT	0
327552	314178	14147R	PARTICIPANT	\N	PRESENT	0
327553	314178	07029T	PARTICIPANT	\N	PRESENT	0
327554	314178	14265W	PARTICIPANT	\N	PRESENT	0
327555	314178	11048N	PARTICIPANT	\N	PRESENT	0
327556	314178	14033T	PARTICIPANT	\N	PRESENT	0
327557	314178	14219Q	PARTICIPANT	\N	PRESENT	0
327558	314178	14061L	PARTICIPANT	\N	PRESENT	0
327559	314178	04088S	PARTICIPANT	\N	PRESENT	0
327560	314178	19467C	PARTICIPANT	\N	PRESENT	0
327561	314178	19551W	PARTICIPANT	\N	PRESENT	0
327562	314178	14073Q	PARTICIPANT	\N	PRESENT	0
327563	314178	14357A	PARTICIPANT	\N	PRESENT	0
327564	314178	14071N	PARTICIPANT	\N	PRESENT	0
327565	314178	19447X	PARTICIPANT	\N	PRESENT	0
327566	314178	08051V	PARTICIPANT	\N	PRESENT	0
327567	314178	88008L	PARTICIPANT	\N	PRESENT	0
327568	314178	08061X	PARTICIPANT	\N	PRESENT	0
327569	314178	19349W	PARTICIPANT	\N	PRESENT	0
327605	327604	08044W	PARTICIPANT	\N	PRESENT	0
327606	327604	14065Q	PARTICIPANT	\N	PRESENT	0
329371	321345	19629C	PARTICIPANT	\N	PRESENT	0
329372	321345	14033T	PARTICIPANT	\N	PRESENT	0
329373	321345	14041T	PARTICIPANT	\N	PRESENT	0
329374	321345	14073Q	PARTICIPANT	\N	PRESENT	0
329375	321345	19581D	PARTICIPANT	\N	PRESENT	0
329376	321345	14030Q	PARTICIPANT	\N	PRESENT	0
329377	321345	19593H	PARTICIPANT	\N	PRESENT	0
329378	321345	14026U	PARTICIPANT	\N	PRESENT	0
329379	321345	11103C	PARTICIPANT	\N	PRESENT	0
329380	321345	08010L	PARTICIPANT	\N	PRESENT	0
329381	321345	19399H	PARTICIPANT	\N	PRESENT	0
329382	321345	19563B	PARTICIPANT	\N	PRESENT	0
329383	321345	01048V	PARTICIPANT	\N	PRESENT	0
329384	321345	08058D	PARTICIPANT	\N	PRESENT	0
329385	321345	14063N	PARTICIPANT	\N	PRESENT	0
329386	321345	08055A	PARTICIPANT	\N	PRESENT	0
329387	321345	14259Y	PARTICIPANT	\N	PRESENT	0
329388	321345	86034E	PARTICIPANT	\N	PRESENT	0
329389	321345	19569H	PARTICIPANT	\N	PRESENT	0
329390	321345	19521Q	PARTICIPANT	\N	PRESENT	0
329369	321345	19415P	PARTICIPANT	\N	PRESENT	0
329370	321345	19733B	PARTICIPANT	\N	PRESENT	0
329391	321345	08053X	PARTICIPANT	\N	PRESENT	0
329392	321345	01025N	PARTICIPANT	\N	PRESENT	0
329393	321345	95030B	PARTICIPANT	\N	PRESENT	0
329394	321345	14169X	PARTICIPANT	\N	PRESENT	0
329395	321345	04049K	PARTICIPANT	\N	PRESENT	0
329396	321345	19693L	PARTICIPANT	\N	PRESENT	0
329397	321345	14031R	PARTICIPANT	\N	PRESENT	0
329398	321345	08062Y	PARTICIPANT	\N	PRESENT	0
329399	321345	19683J	PARTICIPANT	\N	PRESENT	0
327525	314178	04086Q	PARTICIPANT	\N	PRESENT	0
327526	314178	14051J	PARTICIPANT	\N	PRESENT	0
329400	321345	14357A	PARTICIPANT	\N	PRESENT	0
329401	321345	14157T	PARTICIPANT	\N	PRESENT	0
329402	321345	19745F	PARTICIPANT	\N	PRESENT	0
329403	321345	08034U	PARTICIPANT	\N	PRESENT	0
329404	321345	19717B	PARTICIPANT	\N	PRESENT	0
329405	321345	08015R	PARTICIPANT	\N	PRESENT	0
329406	321345	19441R	PARTICIPANT	\N	PRESENT	0
329407	321345	14329V	PARTICIPANT	\N	PRESENT	0
329408	321345	19295A	PARTICIPANT	\N	PRESENT	0
329409	321345	11101A	PARTICIPANT	\N	PRESENT	0
329410	321345	14179A	PARTICIPANT	\N	PRESENT	0
329411	321345	04018C	PARTICIPANT	\N	PRESENT	0
329412	321345	14061L	PARTICIPANT	\N	PRESENT	0
329413	321345	97011G	PARTICIPANT	\N	PRESENT	0
329414	321345	19533U	PARTICIPANT	\N	PRESENT	0
329415	321345	15447F	PARTICIPANT	\N	PRESENT	0
329416	321345	08028W	PARTICIPANT	\N	PRESENT	0
329417	321345	95037J	PARTICIPANT	\N	PRESENT	0
329418	321345	19611R	PARTICIPANT	\N	PRESENT	0
329419	321345	98050T	PARTICIPANT	\N	PRESENT	0
329420	321345	07034Q	PARTICIPANT	\N	PRESENT	0
329421	321345	10006L	PARTICIPANT	\N	PRESENT	0
329422	321345	19507S	PARTICIPANT	\N	PRESENT	0
329423	321345	99004R	PARTICIPANT	\N	PRESENT	0
329424	321345	14053L	PARTICIPANT	\N	PRESENT	0
329425	321345	19711U	PARTICIPANT	\N	PRESENT	0
329426	321345	17583W	PARTICIPANT	\N	PRESENT	0
329427	321345	19768N	PARTICIPANT	\N	PRESENT	0
329428	321345	18083K	PARTICIPANT	\N	PRESENT	0
329429	321345	14199E	PARTICIPANT	\N	PRESENT	0
329430	321345	14119M	PARTICIPANT	\N	PRESENT	0
329431	321345	19758L	PARTICIPANT	\N	PRESENT	0
329432	321345	11045K	PARTICIPANT	\N	PRESENT	0
329433	321345	08047A	PARTICIPANT	\N	PRESENT	0
329434	321345	08052W	PARTICIPANT	\N	PRESENT	0
329435	321345	19679N	PARTICIPANT	\N	PRESENT	0
329436	321345	14021P	PARTICIPANT	\N	PRESENT	0
329437	321345	04059M	PARTICIPANT	\N	PRESENT	0
329438	321345	14187A	PARTICIPANT	\N	PRESENT	0
329439	321345	14087W	PARTICIPANT	\N	PRESENT	0
329440	321345	14121F	PARTICIPANT	\N	PRESENT	0
329441	321345	19503N	PARTICIPANT	\N	PRESENT	0
329442	321345	14059S	PARTICIPANT	\N	PRESENT	0
329443	321345	11104D	PARTICIPANT	\N	PRESENT	0
329444	321345	17637T	PARTICIPANT	\N	PRESENT	0
329445	321345	80027E	PARTICIPANT	\N	PRESENT	0
329446	321345	19782L	PARTICIPANT	\N	PRESENT	0
329448	321345	04045F	PARTICIPANT	\N	PRESENT	0
329449	321345	11027H	PARTICIPANT	\N	PRESENT	0
329450	321345	11090Q	PARTICIPANT	\N	PRESENT	0
329451	321345	14107H	PARTICIPANT	\N	PRESENT	0
329452	321345	11053K	PARTICIPANT	\N	PRESENT	0
329453	321345	04086Q	PARTICIPANT	\N	PRESENT	0
329454	321345	08056B	PARTICIPANT	\N	PRESENT	0
329455	321345	04035D	PARTICIPANT	\N	PRESENT	0
329456	321345	08009T	PARTICIPANT	\N	PRESENT	0
329457	321345	16685X	PARTICIPANT	\N	PRESENT	0
329458	321345	14215L	PARTICIPANT	\N	PRESENT	0
329459	321345	19673G	PARTICIPANT	\N	PRESENT	0
329460	321345	14038Y	PARTICIPANT	\N	PRESENT	0
329461	321345	14147R	PARTICIPANT	\N	PRESENT	0
304852	304774	14053L	PARTICIPANT	\N	PRESENT	0
304853	304774	08045X	PARTICIPANT	\N	PRESENT	0
304854	304774	01024M	PARTICIPANT	\N	PRESENT	0
304855	304774	04042C	PARTICIPANT	\N	PRESENT	0
304856	304774	19581D	PARTICIPANT	\N	PRESENT	0
304857	304774	04044E	PARTICIPANT	\N	PRESENT	0
304858	304774	01028R	PARTICIPANT	\N	PRESENT	0
304859	304774	19447X	PARTICIPANT	\N	PRESENT	0
304860	304774	05008E	PRESIDENT	0	PRESENT	0
304861	304774	95063L	PARTICIPANT	\N	PRESENT	0
304862	304774	19629C	PARTICIPANT	\N	PRESENT	0
304863	304774	14041T	PARTICIPANT	\N	PRESENT	0
304864	304774	14215L	PARTICIPANT	\N	PRESENT	0
304865	304774	07034Q	PARTICIPANT	\N	PRESENT	0
304866	304774	19663E	PARTICIPANT	\N	PRESENT	0
304867	304774	04085P	PARTICIPANT	\N	PRESENT	0
304868	304774	14237S	PARTICIPANT	\N	PRESENT	0
304869	304774	11040E	PARTICIPANT	\N	PRESENT	0
304870	304774	14281W	PARTICIPANT	\N	PRESENT	0
304871	304774	97011G	PARTICIPANT	\N	PRESENT	0
304872	304774	19729F	PARTICIPANT	\N	EXCUSE	0
304873	304774	19719D	PARTICIPANT	\N	EXCUSE	0
304874	304774	19643A	PARTICIPANT	\N	PRESENT	0
304875	304774	14065Q	PARTICIPANT	\N	PRESENT	0
304876	304774	11026G	PARTICIPANT	\N	PRESENT	0
304877	304774	14147R	PARTICIPANT	\N	PRESENT	0
304878	304774	14257W	PARTICIPANT	\N	PRESENT	0
304879	304774	14081Q	PARTICIPANT	\N	PRESENT	0
304880	304774	17637T	PARTICIPANT	\N	PRESENT	0
304881	304774	19649G	PARTICIPANT	\N	PRESENT	0
304882	304774	08044W	PARTICIPANT	\N	PRESENT	0
304894	289219	14227Q	PARTICIPANT	\N	PRESENT	0
304895	289219	17779H	PARTICIPANT	\N	PRESENT	0
304896	289219	04092N	PARTICIPANT	\N	PRESENT	0
304897	289219	14281W	PARTICIPANT	\N	PRESENT	0
304898	289219	08052W	PARTICIPANT	\N	PRESENT	0
304899	289219	14087W	PARTICIPANT	\N	PRESENT	0
304900	289219	19760E	PARTICIPANT	\N	PRESENT	0
304901	289219	08031R	PARTICIPANT	\N	PRESENT	0
304902	289219	11012A	PARTICIPANT	\N	PRESENT	0
304903	289219	19629C	PARTICIPANT	\N	PRESENT	0
304904	289219	14195A	PARTICIPANT	\N	PRESENT	0
304905	289219	19697Q	PARTICIPANT	\N	PRESENT	0
304959	304777	11081P	PARTICIPANT	\N	PRESENT	0
304960	304777	14123H	PARTICIPANT	\N	PRESENT	0
305356	305355	01028R	PARTICIPANT	\N	PRESENT	0
309389	309387	19733B	PARTICIPANT	\N	PRESENT	0
309390	309387	19347U	PARTICIPANT	\N	PRESENT	0
309781	309777	08039A	PARTICIPANT	\N	PRESENT	0
309782	309777	19749K	PARTICIPANT	\N	PRESENT	0
309783	309777	14241N	PARTICIPANT	\N	PRESENT	0
309784	309777	14229S	PARTICIPANT	\N	PRESENT	0
309786	309778	08039A	PARTICIPANT	\N	PRESENT	0
309790	309778	14241N	PARTICIPANT	\N	PRESENT	0
309791	309778	19611R	PARTICIPANT	\N	PRESENT	0
309792	309778	19749K	PARTICIPANT	\N	PRESENT	0
309967	309054	98035U	PARTICIPANT	\N	PRESENT	0
309968	309054	14053L	PARTICIPANT	\N	PRESENT	0
309969	309054	14111D	PARTICIPANT	\N	PRESENT	0
309970	309054	07034Q	PARTICIPANT	\N	PRESENT	0
309971	309054	08045X	PARTICIPANT	\N	PRESENT	0
309972	309054	11026G	PARTICIPANT	\N	PRESENT	0
309973	309054	19581D	PARTICIPANT	\N	PRESENT	0
309974	309054	04044E	PARTICIPANT	\N	PRESENT	0
309975	309054	19673G	PARTICIPANT	\N	PRESENT	0
309976	309054	19719D	PARTICIPANT	\N	PRESENT	0
309977	309054	01028R	PARTICIPANT	\N	PRESENT	0
309978	309054	11033F	PARTICIPANT	\N	PRESENT	0
309979	309054	05008E	PRESIDENT	0	PRESENT	0
309980	309054	19447X	PARTICIPANT	\N	PRESENT	0
309981	309054	14231L	PARTICIPANT	\N	PRESENT	0
309982	309054	19729F	PARTICIPANT	\N	PRESENT	0
309983	309054	95063L	PARTICIPANT	\N	PRESENT	0
309984	309054	14041T	PARTICIPANT	\N	PRESENT	0
309985	309054	14147R	PARTICIPANT	\N	PRESENT	0
309986	309054	14151M	PARTICIPANT	\N	PRESENT	0
309987	309054	14215L	PARTICIPANT	\N	PRESENT	0
309988	309054	14021P	PARTICIPANT	\N	PRESENT	0
309989	309054	19762G	PARTICIPANT	\N	PRESENT	0
309990	307506	04092N	PRESIDENT	0	PRESENT	0
309991	307506	19569H	PARTICIPANT	\N	PRESENT	0
309992	307506	11097X	PARTICIPANT	\N	PRESENT	0
309993	307506	19415P	PARTICIPANT	\N	PRESENT	0
309994	307506	14223L	PARTICIPANT	\N	PRESENT	0
309995	307506	14227Q	PARTICIPANT	\N	PRESENT	0
309996	307506	19675J	PARTICIPANT	\N	PRESENT	0
309997	307506	19723Y	PARTICIPANT	\N	PRESENT	0
309998	307506	14239U	PARTICIPANT	\N	PRESENT	0
309999	307506	19703U	PARTICIPANT	\N	PRESENT	0
310000	307506	14119M	PARTICIPANT	\N	PRESENT	0
310001	307506	14087W	PARTICIPANT	\N	PRESENT	0
310002	307506	11103C	PARTICIPANT	\N	PRESENT	0
310157	309153	19737F	PARTICIPANT	\N	PRESENT	0
310032	307506	11067R	PARTICIPANT	\N	PRESENT	0
310005	307506	19367Y	PARTICIPANT	\N	PRESENT	0
310006	307506	14213J	PARTICIPANT	\N	PRESENT	0
310007	307506	19657G	PARTICIPANT	\N	PRESENT	0
310008	307506	14071N	PARTICIPANT	\N	PRESENT	0
310009	307506	14217N	PARTICIPANT	\N	PRESENT	0
310010	307506	19683J	PARTICIPANT	\N	PRESENT	0
310011	307506	10006L	PARTICIPANT	\N	PRESENT	0
310012	307506	98024R	PARTICIPANT	\N	PRESENT	0
310013	307506	19553Y	PARTICIPANT	\N	PRESENT	0
310014	307506	08048B	PARTICIPANT	\N	PRESENT	0
310015	307506	19715Y	PARTICIPANT	\N	PRESENT	0
310016	307506	08041T	PARTICIPANT	\N	EXCUSE	0
310017	307506	19697Q	PARTICIPANT	\N	PRESENT	0
310018	307506	04045F	PARTICIPANT	\N	PRESENT	0
310019	307506	17779H	PARTICIPANT	\N	PRESENT	0
310020	307506	14281W	PARTICIPANT	\N	PRESENT	0
310021	307506	14042U	PARTICIPANT	\N	PRESENT	0
310022	307506	19335Q	PARTICIPANT	\N	PRESENT	0
310023	307506	14261S	PARTICIPANT	\N	PRESENT	0
310024	307506	19521Q	PARTICIPANT	\N	PRESENT	0
310025	307506	01034P	PARTICIPANT	\N	PRESENT	0
310026	307506	11045K	PARTICIPANT	\N	PRESENT	0
310027	307506	08052W	PARTICIPANT	\N	PRESENT	0
310028	307506	19691J	PARTICIPANT	\N	PRESENT	0
310029	307506	19727D	PARTICIPANT	\N	PRESENT	0
310030	307506	19577H	PARTICIPANT	\N	PRESENT	0
310031	307506	14026U	PARTICIPANT	\N	PRESENT	0
310236	310235	14211G	PARTICIPANT	\N	PRESENT	0
310237	310235	19669L	PARTICIPANT	\N	PRESENT	0
310681	309266	04086Q	PARTICIPANT	\N	PRESENT	0
310682	309266	04047H	PARTICIPANT	\N	PRESENT	0
310683	309266	01024M	PARTICIPANT	\N	PRESENT	0
310684	309266	11033F	PARTICIPANT	\N	PRESENT	0
310685	309266	04085P	PARTICIPANT	\N	PRESENT	0
310686	309266	19715Y	PARTICIPANT	\N	PRESENT	0
310687	309266	19649G	PARTICIPANT	\N	PRESENT	0
310688	309266	19295A	PARTICIPANT	\N	PRESENT	0
310689	309266	14065Q	PARTICIPANT	\N	PRESENT	0
310690	309266	14097Y	PARTICIPANT	\N	PRESENT	0
310691	309266	19349W	PARTICIPANT	\N	PRESENT	0
310692	309266	11072N	PARTICIPANT	\N	PRESENT	0
310693	309266	19585H	PARTICIPANT	\N	PRESENT	0
310694	309266	19737F	PARTICIPANT	\N	PRESENT	0
310695	309266	19253P	PARTICIPANT	\N	PRESENT	0
310696	309266	19515S	PARTICIPANT	\N	PRESENT	0
310697	309266	19729F	PARTICIPANT	\N	PRESENT	0
310698	309266	14147R	PARTICIPANT	\N	PRESENT	0
310699	309266	14215L	PARTICIPANT	\N	PRESENT	0
310700	309266	19695N	PARTICIPANT	\N	PRESENT	0
310701	309266	19565D	PARTICIPANT	\N	PRESENT	0
310702	309266	19621T	PARTICIPANT	\N	PRESENT	0
310703	309266	01028R	PARTICIPANT	\N	PRESENT	0
310704	309266	08045X	PARTICIPANT	\N	PRESENT	0
310705	309266	14069U	PARTICIPANT	\N	PRESENT	0
310706	309266	19703U	PARTICIPANT	\N	PRESENT	0
310707	309266	19727D	PARTICIPANT	\N	PRESENT	0
309386	309380	19503N	PARTICIPANT	\N	PRESENT	0
309388	309387	08009T	PARTICIPANT	\N	PRESENT	0
310708	309266	11067R	PARTICIPANT	\N	PRESENT	0
310709	309266	04044E	PARTICIPANT	\N	PRESENT	0
310710	309266	14071N	PARTICIPANT	\N	PRESENT	0
310711	309266	19415P	PARTICIPANT	\N	PRESENT	0
310712	309266	08061X	PARTICIPANT	\N	PRESENT	0
310713	309266	14119M	PARTICIPANT	\N	PRESENT	0
310714	309266	19521Q	PARTICIPANT	\N	PRESENT	0
310715	309266	88008L	PARTICIPANT	\N	PRESENT	0
310716	309266	95063L	PARTICIPANT	\N	PRESENT	0
310717	309266	11109J	PARTICIPANT	\N	PRESENT	0
310718	309266	19747H	PARTICIPANT	\N	PRESENT	0
310719	309266	19489J	PARTICIPANT	\N	PRESENT	0
310720	309266	19766L	PARTICIPANT	\N	PRESENT	0
310721	309266	19762G	PARTICIPANT	\N	PRESENT	0
310722	309266	08031R	PARTICIPANT	\N	PRESENT	0
310723	309266	05008E	PARTICIPANT	\N	PRESENT	0
310724	309266	14265W	PARTICIPANT	\N	PRESENT	0
310747	309267	11072N	PARTICIPANT	\N	PRESENT	0
310768	309267	14235Q	PARTICIPANT	\N	PRESENT	0
310769	309267	04085P	PARTICIPANT	\N	PRESENT	0
310770	309267	11033F	PARTICIPANT	\N	PRESENT	0
310771	309267	04047H	PARTICIPANT	\N	PRESENT	0
310772	309267	14065Q	PARTICIPANT	\N	PRESENT	0
310773	309267	11066Q	PARTICIPANT	\N	PRESENT	0
310774	309267	98022P	PARTICIPANT	\N	PRESENT	0
310775	309267	14089Y	PARTICIPANT	\N	PRESENT	0
310776	309267	14267Y	PARTICIPANT	\N	PRESENT	0
310777	309267	19649G	PARTICIPANT	\N	PRESENT	0
310778	309267	01024M	PARTICIPANT	\N	PRESENT	0
310779	309267	19768N	PARTICIPANT	\N	PRESENT	0
310780	309267	11067R	PARTICIPANT	\N	PRESENT	0
310781	309267	14215L	PARTICIPANT	\N	PRESENT	0
310782	309267	19747H	PARTICIPANT	\N	PRESENT	0
310783	309267	19507S	PARTICIPANT	\N	PRESENT	0
310784	309267	19729F	PARTICIPANT	\N	PRESENT	0
310785	309267	19301E	PARTICIPANT	\N	PRESENT	0
310786	309267	08044W	PARTICIPANT	\N	PRESENT	0
310787	309267	19253P	PARTICIPANT	\N	PRESENT	0
310788	309267	19443T	PARTICIPANT	\N	PRESENT	0
310789	309267	19447X	PARTICIPANT	\N	PRESENT	0
310790	309267	01058X	PARTICIPANT	\N	PRESENT	0
310791	309267	11012A	PARTICIPANT	\N	PRESENT	0
310792	309267	19725B	PARTICIPANT	\N	PRESENT	0
310793	309267	05008E	PARTICIPANT	\N	PRESENT	0
310794	309267	14147R	PARTICIPANT	\N	PRESENT	0
310795	309267	99004R	PARTICIPANT	\N	PRESENT	0
310796	309267	10015M	PARTICIPANT	\N	PRESENT	0
310802	309267	19489J	PARTICIPANT	\N	PRESENT	0
310805	309267	11109J	PARTICIPANT	\N	PRESENT	0
310822	309267	19737F	PARTICIPANT	\N	PRESENT	0
310823	309267	19515S	PARTICIPANT	\N	PRESENT	0
310825	309267	14223L	PARTICIPANT	\N	PRESENT	0
310827	309267	19711U	PARTICIPANT	\N	PRESENT	0
310831	309267	19659J	PARTICIPANT	\N	PRESENT	0
310832	309267	19479G	PARTICIPANT	\N	PRESENT	0
310833	309267	14069U	PARTICIPANT	\N	PRESENT	0
310834	309267	17583W	PARTICIPANT	\N	PRESENT	0
310835	309267	19295A	PARTICIPANT	\N	PRESENT	0
310836	309267	08045X	PARTICIPANT	\N	PRESENT	0
310837	309267	08015R	PARTICIPANT	\N	PRESENT	0
310838	309267	14159V	PARTICIPANT	\N	PRESENT	0
310839	309267	19349W	PARTICIPANT	\N	PRESENT	0
310840	309267	19621T	PARTICIPANT	\N	PRESENT	0
310841	309267	19399H	PARTICIPANT	\N	PRESENT	0
310842	309267	95063L	PARTICIPANT	\N	PRESENT	0
310843	309267	14205J	PARTICIPANT	\N	PRESENT	0
310844	309267	19441R	PARTICIPANT	\N	PRESENT	0
310850	309267	14151M	PARTICIPANT	\N	PRESENT	0
310851	309267	14213J	PARTICIPANT	\N	PRESENT	0
310852	309267	04086Q	PARTICIPANT	\N	PRESENT	0
310853	309267	19741B	PARTICIPANT	\N	PRESENT	0
310854	309267	19709B	PARTICIPANT	\N	PRESENT	0
310857	309267	01028R	PARTICIPANT	\N	PRESENT	0
310858	309267	19581D	PARTICIPANT	\N	PRESENT	0
310859	309267	08031R	PARTICIPANT	\N	PRESENT	0
310860	309267	19762G	PARTICIPANT	\N	PRESENT	0
310861	309267	14063N	PARTICIPANT	\N	PRESENT	0
310862	309267	19545Y	PARTICIPANT	\N	PRESENT	0
310863	309267	19575F	PARTICIPANT	\N	PRESENT	0
310864	309267	19715Y	PARTICIPANT	\N	PRESENT	0
310865	309267	08020N	PARTICIPANT	\N	PRESENT	0
310866	309267	19675J	PARTICIPANT	\N	PRESENT	0
310882	309267	19713W	PARTICIPANT	\N	PRESENT	0
310905	309267	80013X	PARTICIPANT	\N	PRESENT	0
310919	309267	88008L	PARTICIPANT	\N	PRESENT	0
310935	309267	19701S	PARTICIPANT	\N	PRESENT	0
310936	309267	19611R	PARTICIPANT	\N	PRESENT	0
310937	309267	14042U	PARTICIPANT	\N	PRESENT	0
310938	309267	04057K	PARTICIPANT	\N	PRESENT	0
310939	309267	07004J	PARTICIPANT	\N	PRESENT	0
310944	309267	14097Y	PARTICIPANT	\N	PRESENT	0
310947	309267	98050T	PARTICIPANT	\N	PRESENT	0
310948	309267	01057W	PARTICIPANT	\N	PRESENT	0
310952	309267	14041T	PARTICIPANT	\N	PRESENT	0
310955	309267	11101A	PARTICIPANT	\N	PRESENT	0
310956	309267	04044E	PARTICIPANT	\N	PRESENT	0
310957	309267	08062Y	PARTICIPANT	\N	PRESENT	0
310958	309267	04088S	PARTICIPANT	\N	PRESENT	0
310963	309267	19369B	PARTICIPANT	\N	PRESENT	0
310964	309267	14107H	PARTICIPANT	\N	PRESENT	0
310983	309267	14061L	PARTICIPANT	\N	PRESENT	0
310984	309267	19415P	PARTICIPANT	\N	PRESENT	0
311086	309268	14107H	PARTICIPANT	\N	PRESENT	0
311087	309268	98022P	PARTICIPANT	\N	PRESENT	0
311088	309268	19479G	PARTICIPANT	\N	PRESENT	0
311089	309268	14179A	PARTICIPANT	\N	PRESENT	0
311090	309268	19441R	PARTICIPANT	\N	PRESENT	0
311091	309268	17583W	PARTICIPANT	\N	PRESENT	0
311092	309268	99004R	PARTICIPANT	\N	PRESENT	0
311093	309268	14079W	PARTICIPANT	\N	PRESENT	0
311094	309268	14223L	PARTICIPANT	\N	PRESENT	0
311095	309268	04018C	PARTICIPANT	\N	PRESENT	0
311096	309268	11103C	PARTICIPANT	\N	PRESENT	0
311097	309268	19383Y	PARTICIPANT	\N	PRESENT	0
311098	309268	19399H	PARTICIPANT	\N	PRESENT	0
311100	309268	14041T	PARTICIPANT	\N	PRESENT	0
311101	309268	14355X	PARTICIPANT	\N	PRESENT	0
311102	309268	14042U	PARTICIPANT	\N	PRESENT	0
311103	309268	14115H	PARTICIPANT	\N	PRESENT	0
311104	309268	14275Y	PARTICIPANT	\N	PRESENT	0
311106	309268	19367Y	PARTICIPANT	\N	PRESENT	0
311108	309268	19507S	PARTICIPANT	\N	PRESENT	0
311109	309268	14031R	PARTICIPANT	\N	PRESENT	0
311110	309268	19663E	PARTICIPANT	\N	PRESENT	0
311112	309268	14061L	PARTICIPANT	\N	PRESENT	0
311114	309268	19731Y	PARTICIPANT	\N	PRESENT	0
311115	309268	04088S	PARTICIPANT	\N	PRESENT	0
311116	309268	01043Q	PARTICIPANT	\N	PRESENT	0
311117	309268	07033P	PARTICIPANT	\N	PRESENT	0
311118	309268	11085T	PARTICIPANT	\N	PRESENT	0
311119	309268	19675J	PARTICIPANT	\N	PRESENT	0
311120	309268	14267Y	PARTICIPANT	\N	PRESENT	0
311121	309268	04035D	PARTICIPANT	\N	PRESENT	0
311122	309268	14219Q	PARTICIPANT	\N	PRESENT	0
311123	309268	19253P	PARTICIPANT	\N	PRESENT	0
311124	309268	19729F	PARTICIPANT	\N	PRESENT	0
311125	309268	04008A	PARTICIPANT	\N	PRESENT	0
311126	309268	19711U	PARTICIPANT	\N	PRESENT	0
311127	309268	19737F	PARTICIPANT	\N	PRESENT	0
311128	309268	19611R	PARTICIPANT	\N	PRESENT	0
311129	309268	08009T	PARTICIPANT	\N	PRESENT	0
311130	309268	16685X	PARTICIPANT	\N	PRESENT	0
311131	309268	04097T	PARTICIPANT	\N	PRESENT	0
311132	309268	14033T	PARTICIPANT	\N	PRESENT	0
311134	309268	19739H	PARTICIPANT	\N	PRESENT	0
311135	309268	14147R	PARTICIPANT	\N	PRESENT	0
311136	309268	01048V	PARTICIPANT	\N	PRESENT	0
311137	309268	19749K	PARTICIPANT	\N	PRESENT	0
311138	309268	19621T	PARTICIPANT	\N	PRESENT	0
311139	309268	01057W	PARTICIPANT	\N	PRESENT	0
311141	309268	14030Q	PARTICIPANT	\N	PRESENT	0
311142	309268	04047H	PARTICIPANT	\N	PRESENT	0
311143	309268	07004J	PARTICIPANT	\N	PRESENT	0
311144	309268	14217N	PARTICIPANT	\N	PRESENT	0
311084	309268	14227Q	PARTICIPANT	\N	PRESENT	0
311085	309268	11066Q	PARTICIPANT	\N	PRESENT	0
311145	309268	14195A	PARTICIPANT	\N	PRESENT	0
311146	309268	19577H	PARTICIPANT	\N	PRESENT	0
311147	309268	19643A	PARTICIPANT	\N	PRESENT	0
311148	309268	04040A	PARTICIPANT	\N	PRESENT	0
311149	309268	19369B	PARTICIPANT	\N	PRESENT	0
311150	309268	10015M	PARTICIPANT	\N	PRESENT	0
311151	309268	08044W	PARTICIPANT	\N	PRESENT	0
311152	309268	19667J	PARTICIPANT	\N	PRESENT	0
311153	309268	01025N	PARTICIPANT	\N	PRESENT	0
311154	309268	07029T	PARTICIPANT	\N	PRESENT	0
311155	309268	19691J	PARTICIPANT	\N	PRESENT	0
311156	309268	19447X	PARTICIPANT	\N	PRESENT	0
311157	309268	08020N	PARTICIPANT	\N	PRESENT	0
311158	309268	01058X	PARTICIPANT	\N	PRESENT	0
311159	309268	12041X	PARTICIPANT	\N	PRESENT	0
311160	309268	19515S	PARTICIPANT	\N	PRESENT	0
311161	309268	19593H	PARTICIPANT	\N	PRESENT	0
311162	309268	14259Y	PARTICIPANT	\N	PRESENT	0
311163	309268	08061X	PARTICIPANT	\N	PRESENT	0
311164	309268	19723Y	PARTICIPANT	\N	PRESENT	0
311165	309268	19349W	PARTICIPANT	\N	PRESENT	0
311166	309268	08015R	PARTICIPANT	\N	PRESENT	0
311167	309268	04045F	PARTICIPANT	\N	PRESENT	0
311168	309268	95037J	PARTICIPANT	\N	PRESENT	0
308988	308987	08038Y	PARTICIPANT	\N	PRESENT	0
309035	309034	11053K	PARTICIPANT	\N	PRESENT	0
309036	309034	14159V	PARTICIPANT	\N	PRESENT	0
309037	309034	05012A	PARTICIPANT	\N	PRESENT	0
309040	309039	04070G	PARTICIPANT	\N	PRESENT	0
309041	309039	19399H	PARTICIPANT	\N	PRESENT	0
309042	309039	19693L	PARTICIPANT	\N	PRESENT	0
309043	309039	14030Q	PARTICIPANT	\N	PRESENT	0
309044	309039	19735D	PARTICIPANT	\N	PRESENT	0
309045	309039	19611R	PARTICIPANT	\N	PRESENT	0
309046	309039	04057K	PARTICIPANT	\N	PRESENT	0
309047	309039	19766L	PARTICIPANT	\N	PRESENT	0
309048	309039	08031R	PARTICIPANT	\N	PRESENT	0
309049	309039	19758L	PARTICIPANT	\N	PRESENT	0
309050	309039	11083R	PARTICIPANT	\N	PRESENT	0
309051	309039	14249W	PARTICIPANT	\N	PRESENT	0
322007	321788	11067R	PARTICIPANT	\N	PRESENT	0
322008	321788	11097X	PARTICIPANT	\N	PRESENT	0
322009	321788	19415P	PARTICIPANT	\N	PRESENT	0
322010	321788	14223L	PARTICIPANT	\N	PRESENT	0
322011	321788	17779H	PARTICIPANT	\N	PRESENT	0
322012	321788	11031D	PARTICIPANT	\N	PRESENT	0
322013	321788	14239U	PARTICIPANT	\N	PRESENT	0
322014	321788	19553Y	PARTICIPANT	\N	PRESENT	0
322015	321788	14281W	PARTICIPANT	\N	PRESENT	0
322016	321788	14087W	PARTICIPANT	\N	PRESENT	0
322017	321788	19575F	PARTICIPANT	\N	PRESENT	0
322018	321788	14195A	PARTICIPANT	\N	PRESENT	0
322019	321788	14213J	PARTICIPANT	\N	PRESENT	0
322020	321788	14217N	PARTICIPANT	\N	PRESENT	0
322021	321788	19683J	PARTICIPANT	\N	PRESENT	0
322022	321788	10006L	PARTICIPANT	\N	PRESENT	0
322023	321788	98024R	PARTICIPANT	\N	PRESENT	0
322024	321788	19521Q	PARTICIPANT	\N	PRESENT	0
322025	321788	08052W	PARTICIPANT	\N	PRESENT	0
322026	321788	19691J	PARTICIPANT	\N	PRESENT	0
322027	321788	19727D	PARTICIPANT	\N	PRESENT	0
322028	321788	14119M	PARTICIPANT	\N	PRESENT	0
322029	321788	11103C	PARTICIPANT	\N	PRESENT	0
322030	321788	14071N	PARTICIPANT	\N	PRESENT	0
322031	321788	19657G	PARTICIPANT	\N	PRESENT	0
322032	321788	19577H	PARTICIPANT	\N	PRESENT	0
322033	321788	19760E	PARTICIPANT	\N	PRESENT	0
322083	322082	96004D	PARTICIPANT	\N	PRESENT	0
322084	322082	14089Y	PARTICIPANT	\N	PRESENT	0
322085	322082	14097Y	PARTICIPANT	\N	PRESENT	0
322086	322082	14331P	PARTICIPANT	\N	PRESENT	0
322087	322082	98035U	PARTICIPANT	\N	PRESENT	0
322761	322759	19295A	PARTICIPANT	\N	EXCUSE	0
322762	322759	96004D	PARTICIPANT	\N	EXCUSE	0
322763	322759	11054L	PARTICIPANT	\N	EXCUSE	0
322764	322759	14135M	PARTICIPANT	\N	EXCUSE	0
322765	322759	19319Q	PARTICIPANT	\N	EXCUSE	0
322766	322759	19717B	PARTICIPANT	\N	EXCUSE	0
322767	322759	11010L	PARTICIPANT	\N	EXCUSE	0
322772	317557	12016W	PARTICIPANT	\N	EXCUSE	0
322773	317557	19717B	PARTICIPANT	\N	EXCUSE	0
322774	317557	14038Y	PARTICIPANT	\N	EXCUSE	0
322777	322776	14111D	PARTICIPANT	\N	PRESENT	0
323266	323264	89017R	PARTICIPANT	\N	PRESENT	0
323267	323264	04085P	PARTICIPANT	\N	PRESENT	0
323268	323264	04059M	PARTICIPANT	\N	PRESENT	0
323269	323264	05008E	PARTICIPANT	\N	PRESENT	0
323271	323264	11027H	PARTICIPANT	\N	PRESENT	0
323272	323264	14079W	PARTICIPANT	\N	PRESENT	0
323273	323264	11074Q	PARTICIPANT	\N	PRESENT	0
323274	323264	14187A	PARTICIPANT	\N	PRESENT	0
323278	323264	14073Q	PARTICIPANT	\N	PRESENT	0
323276	323264	19521Q	PARTICIPANT	\N	PRESENT	0
323277	323264	14034U	PARTICIPANT	\N	PRESENT	0
323280	323264	14159V	PARTICIPANT	\N	PRESENT	0
323281	323264	14251Q	PARTICIPANT	\N	PRESENT	0
323282	323264	11085T	PARTICIPANT	\N	PRESENT	0
323283	323264	08009T	PARTICIPANT	\N	PRESENT	0
323284	323264	04092N	PARTICIPANT	\N	PRESENT	0
323286	323264	11072N	PARTICIPANT	\N	PRESENT	0
323287	323264	08011M	PARTICIPANT	\N	PRESENT	0
323288	323264	14237S	PARTICIPANT	\N	PRESENT	0
323289	323264	98018T	PARTICIPANT	\N	PRESENT	0
323290	323264	11090Q	PARTICIPANT	\N	PRESENT	0
323291	323264	11012A	PARTICIPANT	\N	PRESENT	0
323292	323264	01028R	PARTICIPANT	\N	PRESENT	0
323293	323264	04044E	PARTICIPANT	\N	PRESENT	0
323324	323323	11074Q	PARTICIPANT	\N	PRESENT	0
323327	323323	07034Q	PARTICIPANT	\N	PRESENT	0
323328	323323	08045X	PARTICIPANT	\N	PRESENT	0
323329	323323	11049P	PARTICIPANT	\N	PRESENT	0
323331	314151	11048N	PARTICIPANT	\N	PRESENT	0
323391	322159	08038Y	PARTICIPANT	\N	PRESENT	0
323602	320977	14327T	PARTICIPANT	\N	PRESENT	0
323603	320977	14331P	PARTICIPANT	\N	PRESENT	0
323604	320977	95041E	PARTICIPANT	\N	PRESENT	0
323668	320977	19531S	PARTICIPANT	\N	PRESENT	0
323606	320977	11074Q	PRESIDENT	0	PRESENT	0
323607	320977	19667J	PARTICIPANT	\N	PRESENT	0
323669	320977	19479G	PARTICIPANT	\N	PRESENT	0
323609	320977	14225N	PARTICIPANT	\N	PRESENT	0
323610	320977	88008L	PARTICIPANT	\N	PRESENT	0
323611	320977	19671E	PARTICIPANT	\N	PRESENT	0
323612	320977	07029T	PARTICIPANT	\N	PRESENT	0
323613	320977	14277B	PARTICIPANT	\N	PRESENT	0
323614	320977	14085U	PARTICIPANT	\N	PRESENT	0
323615	320977	07004J	PARTICIPANT	\N	PRESENT	0
323616	320977	19349W	PARTICIPANT	\N	PRESENT	0
323617	320977	08010L	PARTICIPANT	\N	PRESENT	0
323619	320977	14253S	PARTICIPANT	\N	PRESENT	0
323670	320977	04071H	PARTICIPANT	\N	PRESENT	0
323621	320977	19711U	PARTICIPANT	\N	PRESENT	0
323671	320977	08069G	PARTICIPANT	\N	PRESENT	0
323623	320977	12016W	PARTICIPANT	\N	PRESENT	0
323624	320977	08011M	PARTICIPANT	\N	PRESENT	0
323625	320977	14159V	PARTICIPANT	\N	PRESENT	0
323626	320977	04086Q	PARTICIPANT	\N	PRESENT	0
323627	320977	11040E	PARTICIPANT	\N	PRESENT	0
323628	320977	14083S	PARTICIPANT	\N	PRESENT	0
323629	320977	11012A	PARTICIPANT	\N	PRESENT	0
323630	320977	14199E	PARTICIPANT	\N	PRESENT	0
323631	320977	14121F	PARTICIPANT	\N	PRESENT	0
323632	320977	99004R	PARTICIPANT	\N	PRESENT	0
323633	320977	08014Q	PARTICIPANT	\N	EXCUSE	0
323634	322290	04070G	PARTICIPANT	\N	PRESENT	0
323635	322290	19443T	PARTICIPANT	\N	PRESENT	0
323636	322290	19533U	PARTICIPANT	\N	PRESENT	0
323637	322290	19329S	PARTICIPANT	\N	PRESENT	0
323638	322290	14229S	PARTICIPANT	\N	PRESENT	0
323639	322290	14039A	PARTICIPANT	\N	PRESENT	0
323640	322290	14107H	PARTICIPANT	\N	PRESENT	0
323641	322290	08017T	PARTICIPANT	\N	PRESENT	0
323642	322290	92040Q	PARTICIPANT	\N	PRESENT	0
323643	322290	07033P	PARTICIPANT	\N	PRESENT	0
323644	322290	08024S	PARTICIPANT	\N	PRESENT	0
323645	322290	08039A	PRESIDENT	0	PRESENT	0
323646	322290	08031R	PARTICIPANT	\N	PRESENT	0
323647	322290	19593H	PARTICIPANT	\N	PRESENT	0
323648	322290	14073Q	PARTICIPANT	\N	PRESENT	0
323649	322290	08035V	PARTICIPANT	\N	PRESENT	0
323650	322290	08043V	PARTICIPANT	\N	PRESENT	0
323651	322290	19693L	PARTICIPANT	\N	PRESENT	0
323652	322290	19399H	PARTICIPANT	\N	PRESENT	0
323653	322290	14201E	PARTICIPANT	\N	PRESENT	0
323654	322290	19731Y	PARTICIPANT	\N	PRESENT	0
323655	322290	19735D	PARTICIPANT	\N	PRESENT	0
323656	322290	14063N	PARTICIPANT	\N	PRESENT	0
323657	322290	11083R	PARTICIPANT	\N	PRESENT	0
323658	322290	14123H	PARTICIPANT	\N	PRESENT	0
323659	322290	11104D	PARTICIPANT	\N	PRESENT	0
323660	322290	19758L	PARTICIPANT	\N	PRESENT	0
323661	322290	04018C	PARTICIPANT	\N	PRESENT	0
323662	322290	19621T	PARTICIPANT	\N	PRESENT	0
323663	322290	87003B	PARTICIPANT	\N	PRESENT	0
323664	320977	01057W	PARTICIPANT	\N	PRESENT	0
323665	320977	11053K	PARTICIPANT	\N	PRESENT	0
323666	320977	04061F	PARTICIPANT	\N	PRESENT	0
323667	320977	19545Y	PARTICIPANT	\N	PRESENT	0
323672	320977	19741B	PARTICIPANT	\N	PRESENT	0
323674	320713	19685L	PARTICIPANT	\N	EXCUSE	0
323675	320977	19687N	PARTICIPANT	\N	PRESENT	0
323676	320977	08073C	PARTICIPANT	\N	PRESENT	0
323677	320977	89017R	PARTICIPANT	\N	PRESENT	0
323678	320977	11110B	PARTICIPANT	\N	PRESENT	0
323679	320713	95062K	PARTICIPANT	\N	PRESENT	0
323680	321792	14042U	PARTICIPANT	\N	EXCUSE	0
323681	321792	08041T	PARTICIPANT	\N	EXCUSE	0
323682	321792	19521Q	PARTICIPANT	\N	EXCUSE	0
323684	320713	05012A	PARTICIPANT	\N	PRESENT	0
323685	320713	80027E	PARTICIPANT	\N	PRESENT	0
323686	320713	14029X	PARTICIPANT	\N	PRESENT	0
323687	320713	08060W	PARTICIPANT	\N	PRESENT	0
323688	320713	14219Q	PARTICIPANT	\N	PRESENT	0
313482	311721	08014Q	PARTICIPANT	\N	EXCUSE	0
313497	311706	08014Q	PARTICIPANT	\N	EXCUSE	0
313499	311706	19545Y	PARTICIPANT	\N	EXCUSE	0
313501	311706	14083S	PARTICIPANT	\N	PRESENT	0
315233	311802	01058X	PARTICIPANT	\N	EXCUSE	0
315252	314307	19399H	PARTICIPANT	\N	EXCUSE	0
315253	314307	04059M	PARTICIPANT	\N	EXCUSE	0
315397	315396	14030Q	PRESIDENT	0	PRESENT	0
315398	315396	08043V	PARTICIPANT	\N	PRESENT	0
315399	315396	19367Y	PARTICIPANT	\N	PRESENT	0
315400	315396	19643A	PARTICIPANT	\N	EXCUSE	0
315401	315396	18083K	PARTICIPANT	\N	PRESENT	0
315402	315396	19701S	PARTICIPANT	\N	PRESENT	0
315403	315396	11031D	PARTICIPANT	\N	PRESENT	0
315404	315396	80013X	PARTICIPANT	\N	PRESENT	0
315405	315396	19715Y	PARTICIPANT	\N	PRESENT	0
315406	315396	07029T	PARTICIPANT	\N	PRESENT	0
315407	315396	11067R	PARTICIPANT	\N	EXCUSE	0
315408	315396	14109K	PARTICIPANT	\N	PRESENT	0
315409	315396	19749K	PARTICIPANT	\N	PRESENT	0
315950	305897	19647E	PARTICIPANT	\N	PRESENT	0
315973	313943	14267Y	PARTICIPANT	\N	EXCUSE	0
315975	313943	19583F	PARTICIPANT	\N	EXCUSE	0
315976	313943	14028W	PARTICIPANT	\N	EXCUSE	0
316088	316087	14123H	PARTICIPANT	\N	PRESENT	0
316089	316087	19611R	PARTICIPANT	\N	PRESENT	0
316181	316179	08043V	PARTICIPANT	\N	PRESENT	0
316183	316179	14123H	PARTICIPANT	\N	PRESENT	0
316284	305897	19479G	PARTICIPANT	\N	PRESENT	0
319580	319579	14033T	PARTICIPANT	\N	PRESENT	0
319586	319585	14033T	PARTICIPANT	\N	PRESENT	0
319596	319595	18083K	PARTICIPANT	\N	PRESENT	0
319602	319601	19507S	PARTICIPANT	\N	PRESENT	0
319603	319601	14207L	PARTICIPANT	\N	PRESENT	0
319733	319601	01025N	PARTICIPANT	\N	PRESENT	0
319767	319763	14221J	PARTICIPANT	\N	PRESENT	0
319787	319784	14221J	PARTICIPANT	\N	PRESENT	0
319827	318988	19575F	PARTICIPANT	\N	PRESENT	0
326609	326608	11048N	PARTICIPANT	\N	PRESENT	0
326934	325060	04040A	PARTICIPANT	\N	EXCUSE	0
327046	327045	01028R	PARTICIPANT	\N	PRESENT	0
327210	326974	11101A	PARTICIPANT	\N	EXCUSE	0
327211	326974	04040A	PRESIDENT	0	PRESENT	0
328647	321327	11072N	PARTICIPANT	\N	PRESENT	0
328648	321327	19721W	PARTICIPANT	\N	PRESENT	0
328649	321327	04088S	PARTICIPANT	\N	PRESENT	0
328650	321327	19711U	PARTICIPANT	\N	PRESENT	0
328651	321327	14030Q	PARTICIPANT	\N	PRESENT	0
328652	321327	14225N	PARTICIPANT	\N	PRESENT	0
328653	321327	19319Q	PARTICIPANT	\N	PRESENT	0
328654	321327	99004R	PARTICIPANT	\N	PRESENT	0
328655	321327	11074Q	PARTICIPANT	\N	PRESENT	0
328656	321327	19651A	PARTICIPANT	\N	PRESENT	0
328657	321327	14041T	PARTICIPANT	\N	PRESENT	0
328658	321327	11040E	PARTICIPANT	\N	PRESENT	0
328659	321327	19447X	PARTICIPANT	\N	PRESENT	0
328660	321327	01057W	PARTICIPANT	\N	PRESENT	0
328661	321327	19667J	PARTICIPANT	\N	PRESENT	0
328662	321327	11053K	PARTICIPANT	\N	PRESENT	0
328663	321327	08011M	PARTICIPANT	\N	PRESENT	0
328664	321327	04086Q	PARTICIPANT	\N	PRESENT	0
328665	321327	19687N	PARTICIPANT	\N	PRESENT	0
328666	321327	08043V	PARTICIPANT	\N	PRESENT	0
328667	321327	14083S	PARTICIPANT	\N	PRESENT	0
328668	321327	19741B	PARTICIPANT	\N	PRESENT	0
328669	321327	07029T	PARTICIPANT	\N	PRESENT	0
328670	321327	19581D	PARTICIPANT	\N	PRESENT	0
328671	321327	14034U	PARTICIPANT	\N	PRESENT	0
328672	321327	14327T	PARTICIPANT	\N	PRESENT	0
328673	321327	11048N	PARTICIPANT	\N	PRESENT	0
328674	321327	19647E	PARTICIPANT	\N	PRESENT	0
328675	321327	08019V	PARTICIPANT	\N	PRESENT	0
328676	321327	08034U	PARTICIPANT	\N	PRESENT	0
328677	321327	19545Y	PARTICIPANT	\N	PRESENT	0
328678	321327	14081Q	PARTICIPANT	\N	PRESENT	0
328679	321327	80013X	PARTICIPANT	\N	PRESENT	0
328680	321327	19649G	PARTICIPANT	\N	PRESENT	0
328681	321327	04071H	PARTICIPANT	\N	PRESENT	0
328682	321327	04043D	PARTICIPANT	\N	PRESENT	0
328683	321327	88008L	PARTICIPANT	\N	PRESENT	0
328684	321327	04033B	PARTICIPANT	\N	PRESENT	0
328685	321327	19643A	PARTICIPANT	\N	PRESENT	0
328686	321327	19593H	PARTICIPANT	\N	PRESENT	0
328687	321327	04049K	PARTICIPANT	\N	PRESENT	0
328689	321327	11109J	PARTICIPANT	\N	PRESENT	0
328690	321327	11110B	PARTICIPANT	\N	PRESENT	0
328691	321327	12016W	PARTICIPANT	\N	PRESENT	0
328692	321327	19301E	PARTICIPANT	\N	PRESENT	0
328693	321327	95041E	PARTICIPANT	\N	PRESENT	0
328694	321327	19733B	PARTICIPANT	\N	PRESENT	0
328695	321327	19549D	PARTICIPANT	\N	PRESENT	0
328698	321327	14157T	PARTICIPANT	\N	PRESENT	0
328699	321327	19551W	PARTICIPANT	\N	PRESENT	0
329015	328726	14331P	PARTICIPANT	\N	PRESENT	0
329016	328726	01048V	PARTICIPANT	\N	PRESENT	0
329017	328726	19545Y	PARTICIPANT	\N	PRESENT	0
329018	328726	11053K	PARTICIPANT	\N	PRESENT	0
329019	328726	11074Q	PRESIDENT	0	PRESENT	0
329020	328726	89017R	PARTICIPANT	\N	PRESENT	0
329021	328726	19671E	PARTICIPANT	\N	PRESENT	0
329022	328726	14225N	PARTICIPANT	\N	PRESENT	0
329023	328726	11110B	PARTICIPANT	\N	PRESENT	0
329024	328726	07029T	PARTICIPANT	\N	PRESENT	0
329025	328726	14085U	PARTICIPANT	\N	PRESENT	0
329026	328726	07004J	PARTICIPANT	\N	PRESENT	0
329027	328726	08010L	PARTICIPANT	\N	PRESENT	0
329028	328726	14253S	PARTICIPANT	\N	PRESENT	0
329029	328726	19711U	PARTICIPANT	\N	PRESENT	0
329030	328726	08034U	PARTICIPANT	\N	PRESENT	0
329031	328726	19689Q	PARTICIPANT	\N	PRESENT	0
329032	328726	08011M	PARTICIPANT	\N	PRESENT	0
329033	328726	14034U	PARTICIPANT	\N	PRESENT	0
329034	328726	14159V	PARTICIPANT	\N	PRESENT	0
329035	328726	11040E	PARTICIPANT	\N	PRESENT	0
329036	328726	04086Q	PARTICIPANT	\N	PRESENT	0
329037	328726	14083S	PARTICIPANT	\N	PRESENT	0
329038	328726	14199E	PARTICIPANT	\N	PRESENT	0
329039	328726	19741B	PARTICIPANT	\N	PRESENT	0
329040	328726	99004R	PARTICIPANT	\N	PRESENT	0
329042	324910	07034Q	PARTICIPANT	\N	PRESENT	0
329043	324910	14041T	PARTICIPANT	\N	PRESENT	0
329044	324910	14147R	PARTICIPANT	\N	PRESENT	0
329045	324910	14151M	PARTICIPANT	\N	PRESENT	0
329046	324910	14069U	PARTICIPANT	\N	PRESENT	0
329047	324910	04038G	PARTICIPANT	\N	PRESENT	0
329048	324910	01028R	PARTICIPANT	\N	PRESENT	0
329049	324910	19447X	PARTICIPANT	\N	PRESENT	0
329050	324910	05008E	PRESIDENT	0	PRESENT	0
329051	324910	19762G	PARTICIPANT	\N	PRESENT	0
329052	324910	98035U	PARTICIPANT	\N	PRESENT	0
329053	324910	14089Y	PARTICIPANT	\N	PRESENT	0
329054	324910	19489J	PARTICIPANT	\N	PRESENT	0
329055	324910	95063L	PARTICIPANT	\N	PRESENT	0
329056	324910	14111D	PARTICIPANT	\N	PRESENT	0
329057	324910	08045X	PARTICIPANT	\N	PRESENT	0
329058	324910	01024M	PARTICIPANT	\N	PRESENT	0
329059	324910	19585H	PARTICIPANT	\N	PRESENT	0
329060	324910	14021P	PARTICIPANT	\N	PRESENT	0
329061	324910	11072N	PARTICIPANT	\N	PRESENT	0
329062	324910	19729F	PARTICIPANT	\N	EXCUSE	0
329063	324910	08018U	PARTICIPANT	\N	EXCUSE	0
329071	321342	04059M	PARTICIPANT	\N	PRESENT	0
329072	321342	08011M	PARTICIPANT	\N	PRESENT	0
329073	321342	19681G	PARTICIPANT	\N	PRESENT	0
329074	321342	19651A	PARTICIPANT	\N	PRESENT	0
329075	321342	04088S	PARTICIPANT	\N	PRESENT	0
329076	321342	14033T	PARTICIPANT	\N	PRESENT	0
329077	321342	19387D	PARTICIPANT	\N	PRESENT	0
329078	321342	99004R	PARTICIPANT	\N	PRESENT	0
329079	321342	19711U	PARTICIPANT	\N	PRESENT	0
329080	321342	14331P	PARTICIPANT	\N	PRESENT	0
329081	321342	14265W	PARTICIPANT	\N	PRESENT	0
329082	321342	19687N	PARTICIPANT	\N	PRESENT	0
329086	321342	19731Y	PARTICIPANT	\N	PRESENT	0
329104	321342	19683J	PARTICIPANT	\N	PRESENT	0
329105	321342	11040E	PARTICIPANT	\N	PRESENT	0
329106	321342	11067R	PARTICIPANT	\N	PRESENT	0
329107	321342	14225N	PARTICIPANT	\N	PRESENT	0
329108	321342	14159V	PARTICIPANT	\N	PRESENT	0
329109	321342	11074Q	PARTICIPANT	\N	PRESENT	0
329110	321342	19719D	PARTICIPANT	\N	PRESENT	0
329111	321342	19727D	PARTICIPANT	\N	PRESENT	0
329112	321342	08031R	PARTICIPANT	\N	PRESENT	0
329113	321342	11012A	PARTICIPANT	\N	PRESENT	0
329114	321342	07004J	PARTICIPANT	\N	PRESENT	0
329115	321342	14083S	PARTICIPANT	\N	PRESENT	0
329116	321342	11097X	PARTICIPANT	\N	PRESENT	0
329117	321342	14085U	PARTICIPANT	\N	PRESENT	0
329118	321342	19525U	PARTICIPANT	\N	PRESENT	0
305254	305012	98035U	PARTICIPANT	\N	PRESENT	0
305255	305012	14089Y	PARTICIPANT	\N	PRESENT	0
305256	305012	95063L	PARTICIPANT	\N	PRESENT	0
305257	305012	14041T	PARTICIPANT	\N	PRESENT	0
305258	305012	14147R	PARTICIPANT	\N	PRESENT	0
305259	305012	14215L	PARTICIPANT	\N	PRESENT	0
305260	305012	04044E	PARTICIPANT	\N	PRESENT	0
305261	305012	01028R	PARTICIPANT	\N	PRESENT	0
305262	305012	19447X	PARTICIPANT	\N	PRESENT	0
305263	305012	05008E	PRESIDENT	0	PRESENT	0
305264	305012	19729F	PARTICIPANT	\N	EXCUSE	0
305265	305012	14065Q	PARTICIPANT	\N	EXCUSE	0
305266	305012	19719D	PARTICIPANT	\N	EXCUSE	0
305578	305577	19581D	PARTICIPANT	\N	PRESENT	0
305579	305577	05008E	PRESIDENT	0	PRESENT	0
305580	305577	14041T	PARTICIPANT	\N	EXCUSE	0
305581	305577	19719D	PARTICIPANT	\N	EXCUSE	0
305582	305577	04070G	PARTICIPANT	\N	PRESENT	0
305583	305577	08009T	PARTICIPANT	\N	PRESENT	0
305584	305577	11066Q	PARTICIPANT	\N	PRESENT	0
305585	305577	19611R	PARTICIPANT	\N	PRESENT	0
305586	305577	08010L	PARTICIPANT	\N	PRESENT	0
305587	305577	08047A	PARTICIPANT	\N	PRESENT	0
305588	305577	14097Y	PARTICIPANT	\N	PRESENT	0
305589	305577	11080N	PARTICIPANT	\N	PRESENT	0
305590	305577	08052W	PARTICIPANT	\N	PRESENT	0
305591	305577	14033T	PARTICIPANT	\N	PRESENT	0
305592	305577	19693L	PARTICIPANT	\N	PRESENT	0
305593	305577	15447F	PARTICIPANT	\N	PRESENT	0
305594	305577	04088S	PARTICIPANT	\N	PRESENT	0
305595	305577	14157T	PARTICIPANT	\N	PRESENT	0
305596	305577	14265W	PARTICIPANT	\N	PRESENT	0
305597	305577	08060W	PARTICIPANT	\N	PRESENT	0
305598	305577	19533U	PARTICIPANT	\N	PRESENT	0
305599	305577	14357A	PARTICIPANT	\N	PRESENT	0
305600	305577	14115H	PARTICIPANT	\N	PRESENT	0
305601	305577	11040E	PARTICIPANT	\N	PRESENT	0
305602	305577	14051J	PARTICIPANT	\N	PRESENT	0
305603	305577	14217N	PARTICIPANT	\N	PRESENT	0
305604	305577	04086Q	PARTICIPANT	\N	PRESENT	0
305605	305577	14331P	PARTICIPANT	\N	PRESENT	0
305606	305577	19673G	PARTICIPANT	\N	PRESENT	0
305607	305577	01028R	PARTICIPANT	\N	PRESENT	0
305608	305577	19447X	PARTICIPANT	\N	PRESENT	0
305609	305577	14147R	PARTICIPANT	\N	PRESENT	0
305610	305577	14151M	PARTICIPANT	\N	PRESENT	0
305611	305577	19643A	PARTICIPANT	\N	PRESENT	0
305612	305577	11048N	PARTICIPANT	\N	PRESENT	0
305613	305577	14061L	PARTICIPANT	\N	PRESENT	0
305614	305577	19649G	PARTICIPANT	\N	PRESENT	0
305615	305577	10015M	PARTICIPANT	\N	PRESENT	0
305616	305577	01024M	PARTICIPANT	\N	PRESENT	0
305617	305577	04038G	PARTICIPANT	\N	PRESENT	0
305618	305577	11033F	PARTICIPANT	\N	PRESENT	0
305619	305577	14089Y	PARTICIPANT	\N	PRESENT	0
305620	305577	08044W	PARTICIPANT	\N	PRESENT	0
305621	305577	14123H	PARTICIPANT	\N	PRESENT	0
305622	305577	11049P	PARTICIPANT	\N	PRESENT	0
305623	305577	04008A	PARTICIPANT	\N	PRESENT	0
305624	305577	14021P	PARTICIPANT	\N	PRESENT	0
305625	305577	04071H	PARTICIPANT	\N	PRESENT	0
305626	305577	14001X	PARTICIPANT	\N	PRESENT	0
305627	305577	04044E	PARTICIPANT	\N	PRESENT	0
305628	305577	14231L	PARTICIPANT	\N	PRESENT	0
305629	305577	11031D	PARTICIPANT	\N	PRESENT	0
305630	305577	19489J	PARTICIPANT	\N	PRESENT	0
305631	305577	14055N	PARTICIPANT	\N	PRESENT	0
305632	305577	14179A	PARTICIPANT	\N	PRESENT	0
305633	305577	14215L	PARTICIPANT	\N	PRESENT	0
305634	305577	14259Y	PARTICIPANT	\N	PRESENT	0
305635	305577	14135M	PARTICIPANT	\N	PRESENT	0
305636	305577	14053L	PARTICIPANT	\N	PRESENT	0
305637	305577	19467C	PARTICIPANT	\N	PRESENT	0
305638	305577	08045X	PARTICIPANT	\N	PRESENT	0
305639	305577	07034Q	PARTICIPANT	\N	PRESENT	0
305640	305577	11026G	PARTICIPANT	\N	PRESENT	0
305641	305577	19253P	PARTICIPANT	\N	PRESENT	0
305642	305577	19725B	PARTICIPANT	\N	PRESENT	0
305643	305577	19729F	PARTICIPANT	\N	PRESENT	0
305644	305577	19762G	PARTICIPANT	\N	PRESENT	0
305645	305577	14073Q	PARTICIPANT	\N	PRESENT	0
305646	305577	19695N	PARTICIPANT	\N	PRESENT	0
305647	305577	19399H	PARTICIPANT	\N	PRESENT	0
305648	305577	11056N	PARTICIPANT	\N	PRESENT	0
305649	305577	19585H	PARTICIPANT	\N	PRESENT	0
305650	305577	14111D	PARTICIPANT	\N	PRESENT	0
305651	305577	08018U	PARTICIPANT	\N	EXCUSE	0
305652	305577	19383Y	PARTICIPANT	\N	PRESENT	0
305653	305571	04086Q	PARTICIPANT	\N	PRESENT	0
305654	305571	14331P	PARTICIPANT	\N	PRESENT	0
305655	305571	19479G	PARTICIPANT	\N	PRESENT	0
305656	305571	11012A	PARTICIPANT	\N	PRESENT	0
305657	305571	19711U	PARTICIPANT	\N	PRESENT	0
305658	305571	19687N	PARTICIPANT	\N	PRESENT	0
305659	305571	19741B	PARTICIPANT	\N	PRESENT	0
305660	305571	11074Q	PRESIDENT	0	PRESENT	0
305661	305571	11070L	PARTICIPANT	\N	PRESENT	0
305662	305571	14327T	PARTICIPANT	\N	EXCUSE	0
305663	305571	14121F	PARTICIPANT	\N	EXCUSE	0
305664	305574	19643A	PARTICIPANT	\N	PRESENT	0
305665	305574	14241N	PARTICIPANT	\N	PRESENT	0
305666	305574	04057K	PARTICIPANT	\N	PRESENT	0
305667	305574	19573D	PARTICIPANT	\N	PRESENT	0
305668	305574	04033B	PARTICIPANT	\N	PRESENT	0
305669	305574	14109K	PARTICIPANT	\N	PRESENT	0
305670	305574	08012N	PARTICIPANT	\N	PRESENT	0
305671	305574	19693L	PARTICIPANT	\N	PRESENT	0
305672	305574	11104D	PARTICIPANT	\N	PRESENT	0
305673	305574	14229S	PARTICIPANT	\N	PRESENT	0
305674	305574	08039A	PARTICIPANT	\N	PRESENT	0
305675	305574	19621T	PARTICIPANT	\N	PRESENT	0
305676	305577	19573D	PARTICIPANT	\N	PRESENT	0
305677	305577	19545Y	PARTICIPANT	\N	PRESENT	0
305678	305577	19669L	PARTICIPANT	\N	PRESENT	0
305679	305577	14038Y	PARTICIPANT	\N	PRESENT	0
305680	305577	14071N	PARTICIPANT	\N	PRESENT	0
305681	305577	19575F	PARTICIPANT	\N	PRESENT	0
305682	305577	19415P	PARTICIPANT	\N	PRESENT	0
305683	305577	19593H	PARTICIPANT	\N	PRESENT	0
305684	305577	04085P	PARTICIPANT	\N	PRESENT	0
305685	305577	19629C	PARTICIPANT	\N	PRESENT	0
305686	305577	11104D	PARTICIPANT	\N	PRESENT	0
305687	305577	80013X	PARTICIPANT	\N	PRESENT	0
305688	305575	19768N	PARTICIPANT	\N	PRESENT	0
305689	305575	19515S	PARTICIPANT	\N	PRESENT	0
305690	305575	19413M	PARTICIPANT	\N	PRESENT	0
305691	305575	14081Q	PARTICIPANT	\N	PRESENT	0
305692	305575	80013X	PARTICIPANT	\N	PRESENT	0
305693	305575	19631V	PARTICIPANT	\N	PRESENT	0
305694	305575	11099A	PARTICIPANT	\N	PRESENT	0
305695	305575	08068F	PARTICIPANT	\N	PRESENT	0
305696	305575	19705W	PARTICIPANT	\N	PRESENT	0
305697	305575	14197C	PARTICIPANT	\N	PRESENT	0
305698	305575	19369B	PARTICIPANT	\N	PRESENT	0
305699	305575	19511N	PARTICIPANT	\N	PRESENT	0
305700	305575	19563B	PARTICIPANT	\N	PRESENT	0
305701	305575	08028W	PARTICIPANT	\N	PRESENT	0
305702	305575	14265W	PARTICIPANT	\N	PRESENT	0
305703	305575	14135M	PARTICIPANT	\N	PRESENT	0
305704	305575	14187A	PARTICIPANT	\N	PRESENT	0
305705	305575	19695N	PARTICIPANT	\N	PRESENT	0
305706	305575	11090Q	PRESIDENT	0	PRESENT	0
305707	305575	14033T	PARTICIPANT	\N	PRESENT	0
305708	305575	19269X	PARTICIPANT	\N	PRESENT	0
305709	305575	14205J	PARTICIPANT	\N	PRESENT	0
305710	305575	04088S	PARTICIPANT	\N	PRESENT	0
305711	305575	11056N	PARTICIPANT	\N	PRESENT	0
305712	305575	14115H	PARTICIPANT	\N	PRESENT	0
305713	305575	19507S	PARTICIPANT	\N	PRESENT	0
305714	305575	19747H	PARTICIPANT	\N	PRESENT	0
305715	305575	14207L	PARTICIPANT	\N	PRESENT	0
305716	305575	17589D	PARTICIPANT	\N	PRESENT	0
305717	305575	14257W	PARTICIPANT	\N	PRESENT	0
305718	305571	04071H	PARTICIPANT	\N	PRESENT	0
305719	305571	19545Y	PARTICIPANT	\N	PRESENT	0
305720	305571	01057W	PARTICIPANT	\N	PRESENT	0
305721	305571	11053K	PARTICIPANT	\N	PRESENT	0
305722	305571	19667J	PARTICIPANT	\N	PRESENT	0
305723	305571	89017R	PARTICIPANT	\N	PRESENT	0
305724	305571	14225N	PARTICIPANT	\N	PRESENT	0
305725	305571	14085U	PARTICIPANT	\N	PRESENT	0
305726	305571	19349W	PARTICIPANT	\N	PRESENT	0
305727	305571	11048N	PARTICIPANT	\N	PRESENT	0
305728	305571	19531S	PARTICIPANT	\N	PRESENT	0
305729	305571	08034U	PARTICIPANT	\N	PRESENT	0
305730	305571	19689Q	PARTICIPANT	\N	PRESENT	0
305731	305571	08011M	PARTICIPANT	\N	PRESENT	0
305732	305571	14034U	PARTICIPANT	\N	PRESENT	0
305733	305571	14159V	PARTICIPANT	\N	PRESENT	0
311169	309268	08062Y	PARTICIPANT	\N	PRESENT	0
311170	309268	19766L	PARTICIPANT	\N	PRESENT	0
311171	309268	19585H	PARTICIPANT	\N	PRESENT	0
311172	309268	11065P	PARTICIPANT	\N	PRESENT	0
311173	309268	19701S	PARTICIPANT	\N	PRESENT	0
311174	309268	14193X	PARTICIPANT	\N	PRESENT	0
311175	309268	88008L	PARTICIPANT	\N	PRESENT	0
311176	309268	96004D	PARTICIPANT	\N	PRESENT	0
311177	309268	14199E	PARTICIPANT	\N	PRESENT	0
311178	309268	11048N	PARTICIPANT	\N	PRESENT	0
311179	309268	04061F	PARTICIPANT	\N	PRESENT	0
311180	309268	04085P	PARTICIPANT	\N	PRESENT	0
311181	309268	11040E	PARTICIPANT	\N	PRESENT	0
311182	309268	19758L	PARTICIPANT	\N	PRESENT	0
311183	309268	11101A	PARTICIPANT	\N	PRESENT	0
311184	309268	19760E	PARTICIPANT	\N	PRESENT	0
311185	309268	19565D	PARTICIPANT	\N	PRESENT	0
311186	309268	19695N	PARTICIPANT	\N	PRESENT	0
311226	309268	14169X	PARTICIPANT	\N	PRESENT	0
311227	309268	11072N	PARTICIPANT	\N	PRESENT	0
311228	309268	05012A	PARTICIPANT	\N	PRESENT	0
311229	309268	19575F	PARTICIPANT	\N	PRESENT	0
311230	309268	14159V	PARTICIPANT	\N	PRESENT	0
311231	309268	98035U	PARTICIPANT	\N	PRESENT	0
311232	309268	11033F	PARTICIPANT	\N	PRESENT	0
311233	309268	19703U	PARTICIPANT	\N	PRESENT	0
311234	309268	19573D	PARTICIPANT	\N	PRESENT	0
311235	309268	98005N	PARTICIPANT	\N	PRESENT	0
311236	309268	08055A	PARTICIPANT	\N	PRESENT	0
311237	309268	14119M	PARTICIPANT	\N	PRESENT	0
311238	309268	14229S	PARTICIPANT	\N	PRESENT	0
311239	309268	01028R	PARTICIPANT	\N	PRESENT	0
311240	309268	04049K	PARTICIPANT	\N	PRESENT	0
311241	309268	08052W	PARTICIPANT	\N	PRESENT	0
311242	309268	12016W	PARTICIPANT	\N	PRESENT	0
311243	309268	19599P	PARTICIPANT	\N	PRESENT	0
311244	309268	14225N	PARTICIPANT	\N	PRESENT	0
311245	309268	08045X	PARTICIPANT	\N	PRESENT	0
311246	309268	86034E	PARTICIPANT	\N	PRESENT	0
311247	309268	14021P	PARTICIPANT	\N	PRESENT	0
311248	309268	80013X	PARTICIPANT	\N	PRESENT	0
311249	309268	08038Y	PARTICIPANT	\N	PRESENT	0
311250	309268	11045K	PARTICIPANT	\N	PRESENT	0
311251	309268	14028W	PARTICIPANT	\N	PRESENT	0
311252	309268	19647E	PARTICIPANT	\N	PRESENT	0
311253	309268	19649G	PARTICIPANT	\N	PRESENT	0
311254	309268	19747H	PARTICIPANT	\N	PRESENT	0
311255	309268	14281W	PARTICIPANT	\N	PRESENT	0
311256	309268	19727D	PARTICIPANT	\N	PRESENT	0
311257	309268	14065Q	PARTICIPANT	\N	PRESENT	0
311258	309268	19549D	PARTICIPANT	\N	PRESENT	0
311259	309268	14081Q	PARTICIPANT	\N	PRESENT	0
311260	309268	11110B	PARTICIPANT	\N	PRESENT	0
311261	309268	19525U	PARTICIPANT	\N	PRESENT	0
311262	309268	08053X	PARTICIPANT	\N	PRESENT	0
311263	309268	19709B	PARTICIPANT	\N	PRESENT	0
311264	309268	19705W	PARTICIPANT	\N	PRESENT	0
311265	309268	19503N	PARTICIPANT	\N	PRESENT	0
311266	309268	19443T	PARTICIPANT	\N	PRESENT	0
311267	309268	14085U	PARTICIPANT	\N	PRESENT	0
311268	309268	08058D	PARTICIPANT	\N	PRESENT	0
311269	309268	14029X	PARTICIPANT	\N	PRESENT	0
311270	309268	17779H	PARTICIPANT	\N	PRESENT	0
311271	309268	19489J	PARTICIPANT	\N	PRESENT	0
311272	309268	19741B	PARTICIPANT	\N	PRESENT	0
311273	309268	19295A	PARTICIPANT	\N	PRESENT	0
311274	309268	19683J	PARTICIPANT	\N	PRESENT	0
311275	309268	14087W	PARTICIPANT	\N	PRESENT	0
311276	309268	14097Y	PARTICIPANT	\N	PRESENT	0
311277	309268	08018U	PARTICIPANT	\N	PRESENT	0
311278	309268	14001X	PARTICIPANT	\N	PRESENT	0
311279	309268	19725B	PARTICIPANT	\N	PRESENT	0
311280	309268	19657G	PARTICIPANT	\N	PRESENT	0
311281	309268	14207L	PARTICIPANT	\N	PRESENT	0
311282	309268	14063N	PARTICIPANT	\N	PRESENT	0
311283	309268	11067R	PARTICIPANT	\N	PRESENT	0
311284	309268	98050T	PARTICIPANT	\N	PRESENT	0
311285	309268	11109J	PARTICIPANT	\N	PRESENT	0
311286	309268	14059S	PARTICIPANT	\N	PRESENT	0
311287	309268	19591F	PARTICIPANT	\N	PRESENT	0
311288	309268	19581D	PARTICIPANT	\N	PRESENT	0
311289	309268	14231L	PARTICIPANT	\N	PRESENT	0
311290	309268	11097X	PARTICIPANT	\N	PRESENT	0
311291	309268	11053K	PARTICIPANT	\N	PRESENT	0
311292	309268	19733B	PARTICIPANT	\N	PRESENT	0
311293	309268	19619A	PARTICIPANT	\N	PRESENT	0
311294	309268	19699S	PARTICIPANT	\N	PRESENT	0
311295	309268	14205J	PARTICIPANT	\N	PRESENT	0
311296	309268	19415P	PARTICIPANT	\N	PRESENT	0
311297	309268	98023Q	PARTICIPANT	\N	PRESENT	0
311298	309268	19713W	PARTICIPANT	\N	PRESENT	0
311299	309268	19421M	PARTICIPANT	\N	PRESENT	0
311300	309268	19762G	PARTICIPANT	\N	PRESENT	0
311301	309268	08011M	PARTICIPANT	\N	PRESENT	0
311302	309268	19319Q	PARTICIPANT	\N	PRESENT	0
311303	309268	14277B	PARTICIPANT	\N	PRESENT	0
311304	309268	08017T	PARTICIPANT	\N	PRESENT	0
311305	309268	14103D	PARTICIPANT	\N	PRESENT	0
311306	309268	14221J	PARTICIPANT	\N	PRESENT	0
311307	309268	19335Q	PARTICIPANT	\N	PRESENT	0
311308	309268	14083S	PARTICIPANT	\N	PRESENT	0
311309	309268	11070L	PARTICIPANT	\N	PRESENT	0
311310	309268	19521Q	PARTICIPANT	\N	PRESENT	0
311311	309268	14327T	PARTICIPANT	\N	PRESENT	0
311312	309268	01024M	PARTICIPANT	\N	PRESENT	0
311313	309268	08048B	PARTICIPANT	\N	PRESENT	0
311314	309268	01062T	PARTICIPANT	\N	PRESENT	0
311315	309268	89017R	PARTICIPANT	\N	PRESENT	0
311316	309268	14055N	PARTICIPANT	\N	PRESENT	0
311317	309268	14253S	PARTICIPANT	\N	PRESENT	0
311318	309268	01060R	PARTICIPANT	\N	PRESENT	0
311319	309268	19715Y	PARTICIPANT	\N	PRESENT	0
311320	309268	19669L	PARTICIPANT	\N	PRESENT	0
311321	309268	11031D	PARTICIPANT	\N	PRESENT	0
311322	309268	19687N	PARTICIPANT	\N	PRESENT	0
311323	309268	08039A	PARTICIPANT	\N	PRESENT	0
311324	309268	19689Q	PARTICIPANT	\N	PRESENT	0
311325	309268	05008E	PARTICIPANT	\N	PRESENT	0
311326	309268	14093U	PARTICIPANT	\N	PRESENT	0
311327	309268	14089Y	PARTICIPANT	\N	PRESENT	0
311328	309268	19553Y	PARTICIPANT	\N	PRESENT	0
311329	309268	19543W	PARTICIPANT	\N	PRESENT	0
311330	309268	80027E	PARTICIPANT	\N	PRESENT	0
311581	309269	04044E	PARTICIPANT	\N	PRESENT	0
311582	309269	04047H	PARTICIPANT	\N	PRESENT	0
311583	309269	01024M	PARTICIPANT	\N	PRESENT	0
311584	309269	11067R	PARTICIPANT	\N	PRESENT	0
311585	309269	11109J	PARTICIPANT	\N	PRESENT	0
311586	309269	19649G	PARTICIPANT	\N	PRESENT	0
311587	309269	19715Y	PARTICIPANT	\N	PRESENT	0
311588	309269	14111D	PARTICIPANT	\N	PRESENT	0
311589	309269	11072N	PARTICIPANT	\N	PRESENT	0
311590	309269	19737F	PARTICIPANT	\N	PRESENT	0
311591	309269	07004J	PARTICIPANT	\N	PRESENT	0
311592	309269	14065Q	PARTICIPANT	\N	PRESENT	0
311593	309269	05008E	PARTICIPANT	\N	PRESENT	0
311594	309269	19447X	PARTICIPANT	\N	PRESENT	0
311595	309269	07029T	PARTICIPANT	\N	PRESENT	0
311596	309269	19507S	PARTICIPANT	\N	PRESENT	0
311597	309269	98005N	PARTICIPANT	\N	PRESENT	0
311598	309269	01028R	PARTICIPANT	\N	PRESENT	0
311599	309269	19573D	PARTICIPANT	\N	PRESENT	0
311600	309269	14147R	PARTICIPANT	\N	PRESENT	0
311601	309269	19762G	PARTICIPANT	\N	PRESENT	0
311602	309269	19593H	PARTICIPANT	\N	PRESENT	0
311603	309269	11033F	PARTICIPANT	\N	PRESENT	0
311605	309269	04085P	PARTICIPANT	\N	PRESENT	0
311606	309269	14261S	PARTICIPANT	\N	PRESENT	0
311607	309269	19711U	PARTICIPANT	\N	PRESENT	0
311608	309269	19583F	PARTICIPANT	\N	PRESENT	0
311609	309269	08044W	PARTICIPANT	\N	PRESENT	0
311610	309269	14215L	PARTICIPANT	\N	PRESENT	0
311611	309269	04088S	PARTICIPANT	\N	PRESENT	0
311613	309269	19479G	PARTICIPANT	\N	PRESENT	0
311622	309269	14093U	PARTICIPANT	\N	PRESENT	0
311631	309269	19301E	PARTICIPANT	\N	PRESENT	0
311633	309269	19295A	PARTICIPANT	\N	PRESENT	0
311647	309269	19703U	PARTICIPANT	\N	PRESENT	0
311648	309269	19549D	PARTICIPANT	\N	PRESENT	0
311649	309269	19691J	PARTICIPANT	\N	PRESENT	0
311650	309269	11012A	PARTICIPANT	\N	PRESENT	0
311651	309269	14069U	PARTICIPANT	\N	PRESENT	0
311652	309269	19663E	PARTICIPANT	\N	PRESENT	0
311653	309269	19399H	PARTICIPANT	\N	PRESENT	0
311654	309269	19253P	PARTICIPANT	\N	PRESENT	0
311655	309269	11101A	PARTICIPANT	\N	PRESENT	0
311656	309269	08010L	PARTICIPANT	\N	PRESENT	0
311657	309269	14259Y	PARTICIPANT	\N	PRESENT	0
305547	305546	11074Q	PARTICIPANT	\N	PRESENT	0
305549	305548	11074Q	PARTICIPANT	\N	PRESENT	0
305553	305552	19647E	PARTICIPANT	\N	PRESENT	0
305554	305552	14239U	PARTICIPANT	\N	PRESENT	0
305560	305559	19569H	PARTICIPANT	\N	PRESENT	0
305561	305559	19577H	PARTICIPANT	\N	PRESENT	0
305562	305555	19569H	PARTICIPANT	\N	PRESENT	0
305563	305556	19569H	PARTICIPANT	\N	PRESENT	0
305564	305557	19569H	PARTICIPANT	\N	PRESENT	0
305565	305558	19569H	PARTICIPANT	\N	PRESENT	0
305963	305962	14089Y	PARTICIPANT	\N	PRESENT	0
305965	305964	10015M	PARTICIPANT	\N	PRESENT	0
305966	305897	08012N	PARTICIPANT	\N	PRESENT	0
305967	305885	08012N	PARTICIPANT	\N	PRESENT	0
311188	309268	95063L	PARTICIPANT	\N	PRESENT	0
311189	309268	08010L	PARTICIPANT	\N	PRESENT	0
311191	309268	19637C	PARTICIPANT	\N	PRESENT	0
311192	309268	08021P	PARTICIPANT	\N	PRESENT	0
311193	309268	19697Q	PARTICIPANT	\N	PRESENT	0
311194	309268	19659J	PARTICIPANT	\N	PRESENT	0
311195	309268	08024S	PARTICIPANT	\N	PRESENT	0
311196	309268	17637T	PARTICIPANT	\N	PRESENT	0
311197	309268	19301E	PARTICIPANT	\N	PRESENT	0
311198	309268	11012A	PARTICIPANT	\N	PRESENT	0
311199	309268	14034U	PARTICIPANT	\N	PRESENT	0
311200	309268	04086Q	PARTICIPANT	\N	PRESENT	0
311201	309268	08016S	PARTICIPANT	\N	PRESENT	0
311202	309268	08031R	PARTICIPANT	\N	PRESENT	0
311203	309268	14261S	PARTICIPANT	\N	PRESENT	0
311204	309268	04044E	PARTICIPANT	\N	PRESENT	0
311205	309268	19563B	PARTICIPANT	\N	PRESENT	0
311207	309268	14201E	PARTICIPANT	\N	PRESENT	0
311208	309268	14071N	PARTICIPANT	\N	PRESENT	0
311209	309268	19269X	PARTICIPANT	\N	PRESENT	0
311210	309268	19545Y	PARTICIPANT	\N	PRESENT	0
311211	309268	04071H	PARTICIPANT	\N	PRESENT	0
311212	309268	14111D	PARTICIPANT	\N	PRESENT	0
311213	309268	04057K	PARTICIPANT	\N	PRESENT	0
311215	309268	11080N	PARTICIPANT	\N	PRESENT	0
311216	309268	14251Q	PARTICIPANT	\N	PRESENT	0
311218	309268	04042C	PARTICIPANT	\N	PRESENT	0
311219	309268	19583F	PARTICIPANT	\N	PRESENT	0
311220	309268	14069U	PARTICIPANT	\N	PRESENT	0
311221	309268	14215L	PARTICIPANT	\N	PRESENT	0
311222	309268	17589D	PARTICIPANT	\N	PRESENT	0
311224	309268	10006L	PARTICIPANT	\N	PRESENT	0
311225	309268	19651A	PARTICIPANT	\N	PRESENT	0
317508	317507	14215L	PARTICIPANT	\N	PRESENT	0
317510	317509	14215L	PARTICIPANT	\N	PRESENT	0
317512	317511	14215L	PARTICIPANT	\N	PRESENT	0
320659	320658	14187A	PARTICIPANT	\N	PRESENT	0
320662	320661	14187A	PARTICIPANT	\N	PRESENT	0
323689	320713	08055A	PARTICIPANT	\N	PRESENT	0
323690	320713	19659J	PARTICIPANT	\N	PRESENT	0
323691	320713	19681G	PARTICIPANT	\N	PRESENT	0
323692	320713	14191V	PARTICIPANT	\N	PRESENT	0
323693	320713	14169X	PARTICIPANT	\N	PRESENT	0
323694	320977	11070L	PARTICIPANT	\N	PRESENT	0
323695	320713	19333N	PARTICIPANT	\N	PRESENT	0
323696	320713	17583W	PARTICIPANT	\N	PRESENT	0
323697	320713	14031R	PARTICIPANT	\N	PRESENT	0
323698	320713	19549D	PARTICIPANT	\N	PRESENT	0
323699	320713	19387D	PARTICIPANT	\N	PRESENT	0
323700	320713	19599P	PARTICIPANT	\N	PRESENT	0
323701	320713	19637C	PARTICIPANT	\N	PRESENT	0
323702	320713	14051J	PARTICIPANT	\N	PRESENT	0
323703	320713	08009T	PRESIDENT	0	PRESENT	0
323704	320713	08024S	PARTICIPANT	\N	PRESENT	0
323705	320713	98023Q	PARTICIPANT	\N	PRESENT	0
323706	320713	19525U	PARTICIPANT	\N	PRESENT	0
323707	320722	14001X	PARTICIPANT	\N	PRESENT	0
323708	322290	19699S	PARTICIPANT	\N	PRESENT	0
323709	322290	04033B	PARTICIPANT	\N	PRESENT	0
323710	322290	14237S	PARTICIPANT	\N	PRESENT	0
323711	322290	19573D	PARTICIPANT	\N	PRESENT	0
323712	322290	14147R	PARTICIPANT	\N	PRESENT	0
323713	322290	08012N	PARTICIPANT	\N	PRESENT	0
323714	322290	14249W	PARTICIPANT	\N	PRESENT	0
323715	322290	19643A	PARTICIPANT	\N	PRESENT	0
323716	322290	04057K	PARTICIPANT	\N	PRESENT	0
323717	322290	19611R	PARTICIPANT	\N	PRESENT	0
323718	322290	14030Q	PARTICIPANT	\N	PRESENT	0
323719	322290	08020N	PARTICIPANT	\N	PRESENT	0
323720	322290	14251Q	PARTICIPANT	\N	PRESENT	0
323721	322290	04059M	PARTICIPANT	\N	PRESENT	0
323722	322290	14109K	PARTICIPANT	\N	PRESENT	0
323723	322290	11043H	PARTICIPANT	\N	PRESENT	0
323724	322290	19749K	PARTICIPANT	\N	PRESENT	0
323725	322290	19766L	PARTICIPANT	\N	EXCUSE	0
323726	322290	14061L	PARTICIPANT	\N	EXCUSE	0
323727	320713	19745F	PARTICIPANT	\N	PRESENT	0
323728	320713	19503N	PARTICIPANT	\N	PRESENT	0
323729	320713	19739H	PARTICIPANT	\N	PRESENT	0
323730	320713	14237S	PARTICIPANT	\N	PRESENT	0
323731	321134	19443T	PARTICIPANT	\N	PRESENT	0
323732	321134	12041X	PARTICIPANT	\N	PRESENT	0
323733	321134	04034C	PARTICIPANT	\N	PRESENT	0
323734	321134	01058X	PARTICIPANT	\N	PRESENT	0
323735	321134	16685X	PARTICIPANT	\N	PRESENT	0
323736	321134	04042C	PRESIDENT	0	PRESENT	0
323737	321134	11066Q	PARTICIPANT	\N	PRESENT	0
323738	321134	11115U	PARTICIPANT	\N	PRESENT	0
323739	321134	19421M	PARTICIPANT	\N	PRESENT	0
323740	321134	08049C	PARTICIPANT	\N	PRESENT	0
323741	321134	14193X	PARTICIPANT	0	PRESENT	0
323742	321134	08053X	PARTICIPANT	\N	PRESENT	0
323743	321134	97011G	PARTICIPANT	\N	PRESENT	0
323744	321134	08061X	PARTICIPANT	\N	PRESENT	0
323745	321134	08047A	PARTICIPANT	\N	PRESENT	0
323746	321134	98029W	PARTICIPANT	\N	PRESENT	0
323747	321134	01062T	PARTICIPANT	\N	PRESENT	0
323748	321134	11041F	PARTICIPANT	\N	PRESENT	0
323749	321134	14235Q	PARTICIPANT	\N	PRESENT	0
323750	321134	19721W	PARTICIPANT	\N	PRESENT	0
323751	321134	14105F	PARTICIPANT	\N	PRESENT	0
323752	321134	98018T	PARTICIPANT	\N	PRESENT	0
323753	321134	14267Y	PARTICIPANT	\N	PRESENT	0
323754	321134	11064N	PARTICIPANT	\N	PRESENT	0
323755	321134	98050T	PARTICIPANT	\N	PRESENT	0
323756	321134	14211G	PARTICIPANT	\N	PRESENT	0
323757	320977	14034U	PARTICIPANT	\N	PRESENT	0
323758	321134	95037J	PARTICIPANT	\N	PRESENT	0
323759	321134	14097Y	PARTICIPANT	\N	PRESENT	0
323760	321134	11080N	PARTICIPANT	\N	PRESENT	0
323761	321134	14255U	PARTICIPANT	\N	PRESENT	0
323762	321134	04040A	PARTICIPANT	\N	PRESENT	0
323763	321134	11027H	PARTICIPANT	\N	PRESENT	0
323764	321134	14028W	PARTICIPANT	\N	PRESENT	0
323765	320713	19347U	PARTICIPANT	\N	PRESENT	0
323766	320713	14157T	PARTICIPANT	\N	PRESENT	0
323767	320713	14038Y	PARTICIPANT	\N	PRESENT	0
323768	320713	19733B	PARTICIPANT	\N	PRESENT	0
323769	321134	14055N	PARTICIPANT	\N	PRESENT	0
323770	320713	17637T	PARTICIPANT	\N	PRESENT	0
323771	320713	14093U	PARTICIPANT	\N	PRESENT	0
323772	322194	19768N	PARTICIPANT	\N	PRESENT	0
323773	322194	19515S	PARTICIPANT	\N	PRESENT	0
323774	322194	19565D	PARTICIPANT	\N	PRESENT	0
323775	322194	14357A	PARTICIPANT	\N	PRESENT	0
323776	322194	19441R	PARTICIPANT	\N	PRESENT	0
323777	322194	19413M	PARTICIPANT	\N	PRESENT	0
323778	322194	14081Q	PARTICIPANT	\N	PRESENT	0
323779	322194	80013X	PARTICIPANT	\N	PRESENT	0
323780	322194	19631V	PARTICIPANT	\N	PRESENT	0
323781	322194	08021P	PARTICIPANT	\N	PRESENT	0
323782	322194	08068F	PARTICIPANT	\N	PRESENT	0
323783	322194	04049K	PARTICIPANT	\N	PRESENT	0
323784	322194	19705W	PARTICIPANT	\N	PRESENT	0
323785	322194	08015R	PARTICIPANT	\N	PRESENT	0
323786	322194	08019V	PARTICIPANT	\N	PRESENT	0
323787	322194	19369B	PARTICIPANT	\N	PRESENT	0
323788	322194	19511N	PARTICIPANT	\N	PRESENT	0
323789	322194	08028W	PARTICIPANT	\N	PRESENT	0
323790	322194	14265W	PARTICIPANT	\N	PRESENT	0
323791	322194	14329V	PARTICIPANT	\N	PRESENT	0
323792	322194	19591F	PARTICIPANT	\N	PRESENT	0
323793	322194	19467C	PARTICIPANT	\N	PRESENT	0
323794	322194	14187A	PARTICIPANT	\N	PRESENT	0
323795	322194	08062Y	PARTICIPANT	\N	PRESENT	0
323796	322194	19695N	PARTICIPANT	\N	PRESENT	0
323797	322194	14033T	PARTICIPANT	\N	PRESENT	0
323798	322194	11090Q	PRESIDENT	0	PRESENT	0
323799	322194	01025N	PARTICIPANT	\N	PRESENT	0
323800	322194	14205J	PARTICIPANT	\N	PRESENT	0
323801	322194	04088S	PARTICIPANT	\N	PRESENT	0
323802	322194	04089T	PARTICIPANT	\N	PRESENT	0
323803	322194	11101A	PARTICIPANT	\N	PRESENT	0
323804	322194	19507S	PARTICIPANT	\N	PRESENT	0
323805	322194	19747H	PARTICIPANT	\N	PRESENT	0
318801	311803	19709B	PARTICIPANT	\N	EXCUSE	0
318804	311803	19593H	PARTICIPANT	\N	PRESENT	0
319302	319301	19762G	PARTICIPANT	\N	PRESENT	0
319303	319301	11085T	PARTICIPANT	\N	PRESENT	0
319305	319304	19762G	PARTICIPANT	\N	PRESENT	0
326596	324696	18083K	PARTICIPANT	\N	PRESENT	0
326597	324696	14051J	PARTICIPANT	\N	PRESENT	0
326598	324696	14221J	PARTICIPANT	\N	PRESENT	0
326599	324696	98023Q	PRESIDENT	0	PRESENT	0
326600	324696	19637C	PARTICIPANT	\N	PRESENT	0
326601	324696	19685L	PARTICIPANT	\N	EXCUSE	0
326602	325784	11081P	PARTICIPANT	\N	EXCUSE	0
326603	324291	19581D	PARTICIPANT	\N	PRESENT	0
326604	324906	19651A	PARTICIPANT	\N	PRESENT	0
326605	325784	80013X	PARTICIPANT	\N	PRESENT	0
326606	325784	19591F	PARTICIPANT	\N	PRESENT	0
326607	325784	04088S	PARTICIPANT	\N	PRESENT	0
326610	324906	19533U	PARTICIPANT	\N	PRESENT	0
326611	324906	19693L	PARTICIPANT	\N	PRESENT	0
326612	324696	19383Y	PARTICIPANT	\N	PRESENT	0
326613	324696	19333N	PARTICIPANT	\N	PRESENT	0
326614	324696	17583W	PARTICIPANT	\N	PRESENT	0
326615	324696	19701S	PARTICIPANT	\N	PRESENT	0
326616	324696	95062K	PARTICIPANT	\N	PRESENT	0
326617	324696	19387D	PARTICIPANT	\N	PRESENT	0
326618	324696	14219Q	PARTICIPANT	\N	PRESENT	0
326619	324696	19599P	PARTICIPANT	\N	PRESENT	0
326620	324696	14237S	PARTICIPANT	\N	PRESENT	0
326621	324696	80027E	PARTICIPANT	\N	PRESENT	0
326622	324696	05012A	PARTICIPANT	\N	PRESENT	0
326623	324696	08060W	PARTICIPANT	\N	PRESENT	0
326624	324696	19503N	PARTICIPANT	\N	PRESENT	0
326625	324696	19347U	PARTICIPANT	\N	PRESENT	0
326626	324696	14157T	PARTICIPANT	\N	PRESENT	0
326627	324696	19681G	PARTICIPANT	\N	PRESENT	0
326628	324696	08024S	PARTICIPANT	\N	PRESENT	0
326629	324696	17637T	PARTICIPANT	\N	PRESENT	0
326630	324696	19525U	PARTICIPANT	\N	PRESENT	0
326631	324696	14038Y	PARTICIPANT	\N	PRESENT	0
326632	324696	14103D	PARTICIPANT	\N	PRESENT	0
326633	324696	14031R	PARTICIPANT	\N	PRESENT	0
326634	324696	08055A	PARTICIPANT	\N	PRESENT	0
326635	324696	14191V	PARTICIPANT	\N	PRESENT	0
326636	324696	15447F	PARTICIPANT	\N	PRESENT	0
326637	324696	14029X	PARTICIPANT	\N	PRESENT	0
326638	324696	19733B	PARTICIPANT	\N	PRESENT	0
326639	324696	04097T	PARTICIPANT	\N	PRESENT	0
326640	324696	19739H	PARTICIPANT	\N	PRESENT	0
326641	324696	19745F	PARTICIPANT	\N	PRESENT	0
326642	324696	19659J	PARTICIPANT	\N	PRESENT	0
326693	326519	19766L	PARTICIPANT	\N	PRESENT	0
326694	326519	04070G	PRESIDENT	0	PRESENT	0
326695	326519	19699S	PARTICIPANT	\N	PRESENT	0
326696	326519	19329S	PARTICIPANT	\N	PRESENT	0
326697	326519	04033B	PARTICIPANT	\N	PRESENT	0
326698	326519	14229S	PARTICIPANT	\N	PRESENT	0
326699	326519	14241N	PARTICIPANT	\N	PRESENT	0
326700	326519	19573D	PARTICIPANT	\N	PRESENT	0
326701	326519	14039A	PARTICIPANT	\N	PRESENT	0
326702	326519	14107H	PARTICIPANT	\N	PRESENT	0
326703	326519	08017T	PARTICIPANT	\N	PRESENT	0
326704	326519	07033P	PARTICIPANT	\N	PRESENT	0
326705	326519	08012N	PARTICIPANT	\N	PRESENT	0
326706	326519	08031R	PARTICIPANT	\N	PRESENT	0
326707	326519	19593H	PARTICIPANT	\N	PRESENT	0
326708	326519	19643A	PARTICIPANT	\N	PRESENT	0
326709	326519	14059S	PARTICIPANT	\N	PRESENT	0
326710	326519	14061L	PARTICIPANT	\N	PRESENT	0
326711	326519	04057K	PARTICIPANT	\N	PRESENT	0
326712	326519	14073Q	PARTICIPANT	\N	PRESENT	0
326713	326519	19611R	PARTICIPANT	\N	PRESENT	0
326714	326519	08035V	PARTICIPANT	\N	PRESENT	0
326715	326519	08043V	PARTICIPANT	\N	PRESENT	0
326716	326519	19399H	PARTICIPANT	\N	PRESENT	0
326717	326519	14201E	PARTICIPANT	\N	PRESENT	0
326718	326519	14030Q	PARTICIPANT	\N	PRESENT	0
326719	326519	19731Y	PARTICIPANT	\N	PRESENT	0
326720	326519	14251Q	PARTICIPANT	\N	PRESENT	0
326721	326519	04059M	PARTICIPANT	\N	PRESENT	0
326722	326519	19735D	PARTICIPANT	\N	PRESENT	0
326723	326519	11109J	PARTICIPANT	\N	PRESENT	0
326724	326519	14109K	PARTICIPANT	\N	PRESENT	0
326725	326519	11083R	PARTICIPANT	\N	PRESENT	0
326726	326519	11104D	PARTICIPANT	\N	PRESENT	0
326727	326519	11043H	PARTICIPANT	\N	PRESENT	0
326728	326519	19749K	PARTICIPANT	\N	PRESENT	0
326729	326519	04018C	PARTICIPANT	\N	PRESENT	0
326730	326519	08039A	PARTICIPANT	\N	EXCUSE	0
326731	324696	19551W	PARTICIPANT	\N	PRESENT	0
326732	324696	11065P	PARTICIPANT	\N	PRESENT	0
326843	325060	04035D	PARTICIPANT	\N	EXCUSE	0
326943	326861	19593H	PARTICIPANT	\N	PRESENT	0
326944	326861	04070G	PRESIDENT	0	PRESENT	0
326945	326861	14073Q	PARTICIPANT	\N	PRESENT	0
326946	326861	19533U	PARTICIPANT	\N	PRESENT	0
326947	326861	19611R	PARTICIPANT	\N	PRESENT	0
326948	326861	08043V	PARTICIPANT	\N	PRESENT	0
326949	326861	87003B	PARTICIPANT	\N	PRESENT	0
326950	326861	19399H	PARTICIPANT	\N	PRESENT	0
326951	326861	14229S	PARTICIPANT	\N	PRESENT	0
326952	326861	19731Y	PARTICIPANT	\N	PRESENT	0
326953	326861	19573D	PARTICIPANT	\N	PRESENT	0
326954	326861	14039A	PARTICIPANT	\N	PRESENT	0
326955	326861	04059M	PARTICIPANT	\N	PRESENT	0
326956	326861	19735D	PARTICIPANT	\N	PRESENT	0
326957	326861	14063N	PARTICIPANT	\N	PRESENT	0
326958	326861	14109K	PARTICIPANT	\N	PRESENT	0
326959	326861	08012N	PARTICIPANT	\N	PRESENT	0
326960	326861	14123H	PARTICIPANT	\N	PRESENT	0
326961	326861	11104D	PARTICIPANT	\N	PRESENT	0
326962	326861	19335Q	PARTICIPANT	\N	PRESENT	0
326963	326861	11043H	PARTICIPANT	\N	PRESENT	0
326964	326861	04018C	PARTICIPANT	\N	PRESENT	0
326965	326861	08031R	PARTICIPANT	\N	PRESENT	0
326966	326861	14241N	PARTICIPANT	\N	PRESENT	0
326967	326861	14107H	PARTICIPANT	\N	PRESENT	0
326968	326861	19758L	PARTICIPANT	\N	EXCUSE	0
326969	326861	08039A	PARTICIPANT	\N	EXCUSE	0
326970	314173	19581D	PARTICIPANT	\N	PRESENT	0
326971	314173	14073Q	PARTICIPANT	\N	PRESENT	0
326972	314173	14063N	PARTICIPANT	\N	PRESENT	0
326973	314173	14179A	PARTICIPANT	\N	PRESENT	0
326975	314173	14195A	PARTICIPANT	\N	PRESENT	0
326976	314173	04059M	PARTICIPANT	\N	PRESENT	0
326977	314173	14207L	PARTICIPANT	\N	PRESENT	0
326980	314173	19399H	PARTICIPANT	\N	PRESENT	0
326981	314173	08031R	PARTICIPANT	\N	PRESENT	0
326985	314173	14033T	PARTICIPANT	\N	PRESENT	0
326986	314173	19507S	PARTICIPANT	\N	PRESENT	0
326987	314173	19383Y	PARTICIPANT	\N	PRESENT	0
326988	314173	19745F	PARTICIPANT	\N	PRESENT	0
326989	314173	19335Q	PARTICIPANT	\N	PRESENT	0
326990	314173	19681G	PARTICIPANT	\N	PRESENT	0
326992	314173	04088S	PARTICIPANT	\N	PRESENT	0
326993	314173	14187A	PARTICIPANT	\N	PRESENT	0
326994	314173	14259Y	PARTICIPANT	\N	PRESENT	0
326995	314173	19741B	PARTICIPANT	\N	PRESENT	0
326996	314173	08034U	PARTICIPANT	\N	PRESENT	0
326997	314173	18083K	PARTICIPANT	\N	PRESENT	0
326998	314173	14059S	PARTICIPANT	\N	PRESENT	0
326999	314173	14103D	PARTICIPANT	\N	PRESENT	0
327002	314173	19693L	PARTICIPANT	\N	PRESENT	0
327003	314173	07029T	PARTICIPANT	\N	PRESENT	0
327005	314173	19760E	PARTICIPANT	\N	PRESENT	0
327006	314173	19503N	PARTICIPANT	\N	PRESENT	0
327008	314173	19675J	PARTICIPANT	\N	PRESENT	0
327011	314173	19691J	PARTICIPANT	\N	PRESENT	0
327012	314173	14193X	PARTICIPANT	\N	PRESENT	0
327047	314173	14217N	PARTICIPANT	\N	PRESENT	0
327048	314173	19631V	PARTICIPANT	\N	PRESENT	0
305393	305392	11053K	PARTICIPANT	\N	PRESENT	0
305394	305392	14159V	PARTICIPANT	\N	PRESENT	0
305395	305392	05012A	PARTICIPANT	\N	PRESENT	0
305397	305396	04059M	PARTICIPANT	\N	PRESENT	0
305398	305396	19637C	PARTICIPANT	\N	PRESENT	0
305399	305396	19347U	PARTICIPANT	\N	PRESENT	0
305748	305577	19551W	PARTICIPANT	\N	PRESENT	0
305749	305577	19681G	PARTICIPANT	\N	PRESENT	0
305750	305577	05012A	PARTICIPANT	\N	PRESENT	0
305772	305575	19565D	PARTICIPANT	\N	PRESENT	0
305773	305575	01043Q	PARTICIPANT	\N	PRESENT	0
305774	305575	08038Y	PARTICIPANT	\N	PRESENT	0
305775	305575	08062Y	PARTICIPANT	\N	PRESENT	0
305776	305577	11099A	PARTICIPANT	\N	PRESENT	0
305959	305883	11049P	PARTICIPANT	\N	EXCUSE	0
305960	305883	14071N	PARTICIPANT	\N	EXCUSE	0
305961	305886	08012N	PARTICIPANT	\N	EXCUSE	0
309203	309202	89017R	PARTICIPANT	\N	PRESENT	0
309205	309204	19711U	PARTICIPANT	\N	PRESENT	0
309207	309206	19711U	PARTICIPANT	\N	PRESENT	0
309209	309208	14173T	PARTICIPANT	\N	PRESENT	0
309211	309210	14121F	PARTICIPANT	\N	PRESENT	0
309213	309212	19711U	PARTICIPANT	\N	PRESENT	0
309229	309228	08010L	PARTICIPANT	\N	PRESENT	0
309231	309230	08010L	PARTICIPANT	\N	PRESENT	0
309233	309232	08010L	PARTICIPANT	\N	PRESENT	0
309236	309235	04071H	PARTICIPANT	\N	PRESENT	0
309256	309254	11053K	PARTICIPANT	\N	PRESENT	0
310727	309266	08044W	PARTICIPANT	\N	PRESENT	0
310728	309266	04088S	PARTICIPANT	\N	PRESENT	0
310729	309266	14081Q	PARTICIPANT	\N	PRESENT	0
310725	309266	14029X	PARTICIPANT	\N	PRESENT	0
310726	309266	14115H	PARTICIPANT	\N	PRESENT	0
310730	309266	14033T	PARTICIPANT	\N	PRESENT	0
310731	309266	14213J	PARTICIPANT	\N	PRESENT	0
310732	309266	19447X	PARTICIPANT	\N	PRESENT	0
310733	309266	11097X	PARTICIPANT	\N	PRESENT	0
310734	309266	19507S	PARTICIPANT	\N	PRESENT	0
310735	309266	19383Y	PARTICIPANT	\N	PRESENT	0
310736	309266	04033B	PARTICIPANT	\N	PRESENT	0
310737	309266	14261S	PARTICIPANT	\N	PRESENT	0
310738	309266	10006L	PARTICIPANT	\N	PRESENT	0
310739	309266	18083K	PARTICIPANT	\N	PRESENT	0
310740	309266	14111D	PARTICIPANT	\N	PRESENT	0
310741	309266	14083S	PARTICIPANT	\N	PRESENT	0
310742	309266	14231L	PARTICIPANT	\N	PRESENT	0
310743	309266	19733B	PARTICIPANT	\N	PRESENT	0
310744	309266	10015M	PARTICIPANT	\N	PRESENT	0
310745	309266	14034U	PARTICIPANT	\N	PRESENT	0
311615	311614	19549D	PARTICIPANT	\N	PRESENT	0
311616	311614	19701S	PARTICIPANT	\N	PRESENT	0
311617	311614	14079W	PRESIDENT	0	PRESENT	0
311618	311614	14215L	PARTICIPANT	\N	PRESENT	0
311619	311614	14033T	PARTICIPANT	\N	PRESENT	0
311620	311614	14031R	PARTICIPANT	\N	PRESENT	0
311621	311614	19563B	PARTICIPANT	\N	PRESENT	0
311623	311614	14001X	PARTICIPANT	\N	EXCUSE	0
311624	311614	14115H	PARTICIPANT	\N	EXCUSE	0
311625	311614	14213J	PARTICIPANT	\N	EXCUSE	0
311626	311614	19593H	PARTICIPANT	\N	EXCUSE	0
311627	311614	19735D	PARTICIPANT	\N	EXCUSE	0
311628	311614	11083R	PARTICIPANT	\N	EXCUSE	0
311629	311614	19335Q	PARTICIPANT	\N	EXCUSE	0
311630	311614	04044E	PARTICIPANT	\N	EXCUSE	0
311632	311614	14061L	PARTICIPANT	\N	EXCUSE	0
311671	311670	14227Q	PARTICIPANT	\N	PRESENT	0
311672	311670	14097Y	PARTICIPANT	\N	PRESENT	0
311708	307122	19533U	PARTICIPANT	\N	PRESENT	0
311711	311709	19533U	PARTICIPANT	\N	PRESENT	0
311714	311712	19533U	PARTICIPANT	\N	PRESENT	0
311717	311715	19533U	PARTICIPANT	\N	PRESENT	0
311719	311718	19533U	PARTICIPANT	\N	PRESENT	0
311780	311779	04040A	PARTICIPANT	\N	PRESENT	0
311781	311779	14235Q	PARTICIPANT	\N	PRESENT	0
311783	311782	04040A	PARTICIPANT	\N	PRESENT	0
311784	311782	14235Q	PARTICIPANT	\N	PRESENT	0
311786	311785	98050T	PARTICIPANT	\N	PRESENT	0
311788	311787	98050T	PARTICIPANT	\N	PRESENT	0
313080	310419	11067R	PARTICIPANT	\N	PRESENT	0
313081	310419	01034P	PARTICIPANT	\N	PRESENT	0
313082	310419	19569H	PARTICIPANT	\N	PRESENT	0
313083	310419	11097X	PARTICIPANT	\N	PRESENT	0
313084	310419	19415P	PARTICIPANT	\N	PRESENT	0
313085	310419	19691J	PARTICIPANT	\N	PRESENT	0
313086	310419	14223L	PARTICIPANT	\N	PRESENT	0
313087	310419	19703U	PARTICIPANT	\N	PRESENT	0
313088	310419	14239U	PARTICIPANT	\N	PRESENT	0
313089	310419	14087W	PARTICIPANT	\N	PRESENT	0
313090	310419	11103C	PARTICIPANT	\N	PRESENT	0
313209	310940	15447F	PARTICIPANT	\N	PRESENT	0
313092	310419	19367Y	PARTICIPANT	\N	PRESENT	0
313093	310419	14213J	PARTICIPANT	\N	PRESENT	0
313094	310419	14071N	PARTICIPANT	\N	PRESENT	0
313095	310419	14261S	PARTICIPANT	\N	PRESENT	0
313096	310419	19683J	PARTICIPANT	\N	PRESENT	0
313097	310419	98024R	PRESIDENT	0	PRESENT	0
313098	310419	19760E	PARTICIPANT	\N	PRESENT	0
313099	310419	04092N	PARTICIPANT	\N	EXCUSE	0
313100	310419	14355X	PARTICIPANT	\N	EXCUSE	0
313101	310419	08048B	PARTICIPANT	\N	PRESENT	0
313102	310419	19715Y	PARTICIPANT	\N	PRESENT	0
313103	310419	08041T	PARTICIPANT	\N	EXCUSE	0
313104	310419	11077T	PARTICIPANT	\N	PRESENT	0
313105	310419	04045F	PARTICIPANT	\N	PRESENT	0
313106	310419	19723Y	PARTICIPANT	\N	PRESENT	0
313107	310419	19521Q	PARTICIPANT	\N	PRESENT	0
313108	310419	17779H	PARTICIPANT	\N	PRESENT	0
313109	310419	11031D	PARTICIPANT	\N	PRESENT	0
313110	310419	14217N	PARTICIPANT	\N	PRESENT	0
313111	310419	19335Q	PARTICIPANT	\N	PRESENT	0
313112	310419	10006L	PARTICIPANT	\N	PRESENT	0
313113	310419	11045K	PARTICIPANT	\N	PRESENT	0
313114	310419	19727D	PARTICIPANT	\N	PRESENT	0
313115	310419	14227Q	PARTICIPANT	\N	EXCUSE	0
313116	310419	19553Y	PARTICIPANT	\N	PRESENT	0
313117	310419	19697Q	PARTICIPANT	\N	PRESENT	0
313118	310419	14026U	PARTICIPANT	\N	PRESENT	0
313119	310419	08052W	PARTICIPANT	\N	PRESENT	0
313120	310419	14195A	PARTICIPANT	\N	PRESENT	0
313122	310940	14093U	PARTICIPANT	\N	EXCUSE	0
313123	310940	96004D	PARTICIPANT	\N	EXCUSE	0
313124	310940	19739H	PARTICIPANT	\N	PRESENT	0
313125	310940	19685L	PARTICIPANT	\N	EXCUSE	0
313126	310419	19527W	PARTICIPANT	\N	PRESENT	0
313127	310419	14119M	PARTICIPANT	\N	PRESENT	0
313128	310940	14031R	PARTICIPANT	\N	EXCUSE	0
313208	310419	14042U	PARTICIPANT	\N	PRESENT	0
313210	310940	19551W	PARTICIPANT	\N	PRESENT	0
313211	310940	17583W	PARTICIPANT	\N	PRESENT	0
313212	310940	19599P	PARTICIPANT	\N	PRESENT	0
313213	310940	08024S	PARTICIPANT	\N	PRESENT	0
313214	310940	19333N	PARTICIPANT	\N	PRESENT	0
313215	310940	19549D	PARTICIPANT	\N	PRESENT	0
313269	311342	98005N	PARTICIPANT	\N	PRESENT	0
313270	311342	19443T	PARTICIPANT	\N	PRESENT	0
313271	311342	12041X	PARTICIPANT	\N	PRESENT	0
313272	311342	04034C	PARTICIPANT	\N	PRESENT	0
313273	311342	14079W	PARTICIPANT	\N	PRESENT	0
313274	311342	01058X	PARTICIPANT	\N	PRESENT	0
313275	311342	04040A	PARTICIPANT	\N	PRESENT	0
313276	311342	16685X	PARTICIPANT	\N	PRESENT	0
313277	311342	04042C	PRESIDENT	0	PRESENT	0
313278	311342	11054L	PARTICIPANT	\N	PRESENT	0
313279	311342	19669L	PARTICIPANT	\N	PRESENT	0
313280	311342	11066Q	PARTICIPANT	\N	PRESENT	0
313281	311342	08056B	PARTICIPANT	\N	PRESENT	0
313282	311342	11115U	PARTICIPANT	\N	PRESENT	0
313283	311342	14055N	PARTICIPANT	\N	PRESENT	0
313284	311342	19709B	PARTICIPANT	\N	PRESENT	0
313285	311342	08049C	PARTICIPANT	\N	PRESENT	0
313286	311342	14193X	PARTICIPANT	\N	PRESENT	0
313287	311342	08053X	PARTICIPANT	\N	PRESENT	0
313288	311342	97011G	PARTICIPANT	\N	PRESENT	0
313289	311342	08061X	PARTICIPANT	\N	PRESENT	0
313290	311342	08047A	PARTICIPANT	\N	PRESENT	0
313291	311342	95067Q	PARTICIPANT	\N	PRESENT	0
313292	311342	14133K	PARTICIPANT	\N	PRESENT	0
313293	311342	01062T	PARTICIPANT	\N	PRESENT	0
313294	311342	11041F	PARTICIPANT	\N	PRESENT	0
313295	311342	14235Q	PARTICIPANT	\N	PRESENT	0
313296	311342	08058D	PARTICIPANT	\N	PRESENT	0
313297	311342	14028W	PARTICIPANT	\N	PRESENT	0
313298	311342	19251M	PARTICIPANT	\N	PRESENT	0
313299	311342	19721W	PARTICIPANT	\N	PRESENT	0
310879	310877	14121F	PARTICIPANT	\N	PRESENT	0
310880	310877	14083S	PARTICIPANT	\N	PRESENT	0
310884	310877	19695N	PARTICIPANT	\N	PRESENT	0
310887	310877	04088S	PARTICIPANT	\N	PRESENT	0
310888	310877	14265W	PARTICIPANT	\N	PRESENT	0
310889	310877	19521Q	PARTICIPANT	\N	PRESENT	0
310891	310877	14061L	PARTICIPANT	\N	PRESENT	0
310893	310877	14205J	PARTICIPANT	\N	PRESENT	0
310895	310877	14079W	PARTICIPANT	\N	PRESENT	0
310896	310877	04049K	PRESIDENT	0	PRESENT	0
310898	310877	14034U	PARTICIPANT	\N	PRESENT	0
310900	310877	14261S	PARTICIPANT	\N	PRESENT	0
310902	310877	14087W	PARTICIPANT	\N	PRESENT	0
310903	310877	14151M	PARTICIPANT	\N	PRESENT	0
310904	310877	16685X	PARTICIPANT	\N	PRESENT	0
310906	310877	08015R	PARTICIPANT	\N	PRESENT	0
310907	310877	14253S	PARTICIPANT	\N	PRESENT	0
310908	310877	19575F	PARTICIPANT	\N	PRESENT	0
310909	310877	89017R	PARTICIPANT	\N	EXCUSE	0
310913	310877	14030Q	PARTICIPANT	\N	EXCUSE	0
310914	310877	08060W	PARTICIPANT	\N	EXCUSE	0
310915	310877	08068F	PARTICIPANT	\N	EXCUSE	0
310916	310877	14255U	PARTICIPANT	\N	EXCUSE	0
310917	310877	14053L	PARTICIPANT	\N	EXCUSE	0
310918	310877	19545Y	PARTICIPANT	\N	EXCUSE	0
310920	310877	14329V	PARTICIPANT	\N	EXCUSE	0
310921	310877	11031D	PARTICIPANT	\N	EXCUSE	0
310922	310877	14041T	PARTICIPANT	\N	EXCUSE	0
310923	310877	14187A	PARTICIPANT	\N	EXCUSE	0
310924	310877	14026U	PARTICIPANT	\N	EXCUSE	0
310925	310877	19591F	PARTICIPANT	\N	EXCUSE	0
310926	310877	14039A	PARTICIPANT	\N	EXCUSE	0
310927	310877	11099A	PARTICIPANT	\N	EXCUSE	0
310928	310877	19671E	PARTICIPANT	\N	EXCUSE	0
310929	310877	14051J	PARTICIPANT	\N	EXCUSE	0
310930	310877	19527W	PARTICIPANT	\N	EXCUSE	0
310931	310877	14157T	PARTICIPANT	\N	EXCUSE	0
310932	310877	04034C	PARTICIPANT	\N	EXCUSE	0
311604	309268	14151M	PARTICIPANT	\N	PRESENT	0
311658	309269	17637T	PARTICIPANT	\N	PRESENT	0
311668	309269	14089Y	PARTICIPANT	\N	PRESENT	0
311669	309269	19727D	PARTICIPANT	\N	PRESENT	0
311673	309269	19695N	PARTICIPANT	\N	PRESENT	0
311674	309269	04035D	PARTICIPANT	\N	PRESENT	0
311750	311749	11053K	PARTICIPANT	\N	PRESENT	0
316716	309288	19467C	PARTICIPANT	\N	PRESENT	0
316717	309288	14030Q	PARTICIPANT	\N	PRESENT	0
316718	309288	01025N	PARTICIPANT	\N	PRESENT	0
316719	309288	19369B	PARTICIPANT	\N	PRESENT	0
316720	309288	11053K	PARTICIPANT	\N	PRESENT	0
316721	309288	18083K	PARTICIPANT	\N	PRESENT	0
316722	309288	14219Q	PARTICIPANT	\N	PRESENT	0
316723	309288	14042U	PARTICIPANT	\N	PRESENT	0
316724	309288	19441R	PARTICIPANT	\N	PRESENT	0
316725	309288	14221J	PARTICIPANT	\N	PRESENT	0
316726	309288	19415P	PARTICIPANT	\N	PRESENT	0
316727	309288	14135M	PARTICIPANT	\N	PRESENT	0
316728	309288	19611R	PARTICIPANT	\N	PRESENT	0
316729	309288	08019V	PARTICIPANT	\N	PRESENT	0
316730	309288	19399H	PARTICIPANT	\N	PRESENT	0
316731	309288	19619A	PARTICIPANT	\N	PRESENT	0
316733	309288	19693L	PARTICIPANT	\N	PRESENT	0
316734	309288	14073Q	PARTICIPANT	\N	PRESENT	0
316735	309288	14103D	PARTICIPANT	\N	PRESENT	0
316736	309288	19739H	PARTICIPANT	\N	PRESENT	0
316737	309288	19335Q	PARTICIPANT	\N	PRESENT	0
316738	309288	14083S	PARTICIPANT	\N	PRESENT	0
316739	309288	19729F	PARTICIPANT	\N	PRESENT	0
316740	309288	11070L	PARTICIPANT	\N	PRESENT	0
316741	309288	14265W	PARTICIPANT	\N	PRESENT	0
316742	309288	08048B	PARTICIPANT	\N	PRESENT	0
316743	309288	19521Q	PARTICIPANT	\N	PRESENT	0
316744	309288	14065Q	PARTICIPANT	\N	PRESENT	0
316745	309288	14255U	PARTICIPANT	\N	PRESENT	0
316746	309288	19443T	PARTICIPANT	\N	PRESENT	0
316747	309288	14205J	PARTICIPANT	\N	PRESENT	0
316748	309288	14029X	PARTICIPANT	\N	PRESENT	0
316749	309288	19577H	PARTICIPANT	\N	PRESENT	0
316750	309288	04040A	PARTICIPANT	\N	PRESENT	0
316751	309288	19709B	PARTICIPANT	\N	PRESENT	0
316752	309288	01024M	PARTICIPANT	\N	PRESENT	0
316753	309288	19663E	PARTICIPANT	\N	PRESENT	0
316754	309288	14327T	PARTICIPANT	\N	PRESENT	0
316755	309288	19741B	PARTICIPANT	\N	PRESENT	0
316756	309288	04088S	PARTICIPANT	\N	PRESENT	0
316757	309288	08073C	PARTICIPANT	\N	PRESENT	0
316758	309288	14041T	PARTICIPANT	\N	PRESENT	0
316759	309288	08018U	PARTICIPANT	\N	PRESENT	0
316760	309288	19745F	PARTICIPANT	\N	PRESENT	0
316761	309288	07029T	PARTICIPANT	\N	PRESENT	0
316762	309288	19657G	PARTICIPANT	\N	PRESENT	0
316763	309288	08015R	PARTICIPANT	\N	PRESENT	0
316764	309288	19768N	PARTICIPANT	\N	PRESENT	0
316765	309288	19643A	PARTICIPANT	\N	PRESENT	0
316766	309288	19705W	PARTICIPANT	\N	PRESENT	0
316767	309288	99004R	PARTICIPANT	\N	PRESENT	0
316768	309288	11101A	PARTICIPANT	\N	PRESENT	0
316770	309288	11109J	PARTICIPANT	\N	PRESENT	0
316771	309288	04035D	PARTICIPANT	\N	PRESENT	0
316772	309288	04047H	PARTICIPANT	\N	PRESENT	0
316773	309288	04086Q	PARTICIPANT	\N	PRESENT	0
316774	309288	04092N	PARTICIPANT	\N	PRESENT	0
316776	309288	04044E	PARTICIPANT	\N	PRESENT	0
316777	309288	95041E	PARTICIPANT	\N	PRESENT	0
316778	309288	04033B	PARTICIPANT	\N	PRESENT	0
316779	309288	14187A	PARTICIPANT	\N	PRESENT	0
316780	309288	05008E	PARTICIPANT	\N	PRESENT	0
316781	309288	11097X	PARTICIPANT	\N	PRESENT	0
316782	309288	19421M	PARTICIPANT	\N	PRESENT	0
316784	309288	98018T	PARTICIPANT	\N	PRESENT	0
316785	309288	86034E	PARTICIPANT	\N	PRESENT	0
316786	309288	04043D	PARTICIPANT	\N	PRESENT	0
316787	309288	14053L	PARTICIPANT	\N	PRESENT	0
316789	309288	05012A	PARTICIPANT	\N	PRESENT	0
316790	309288	08034U	PARTICIPANT	\N	PRESENT	0
316791	309288	10006L	PARTICIPANT	\N	PRESENT	0
316792	309288	04061F	PARTICIPANT	\N	PRESENT	0
316794	309288	14079W	PARTICIPANT	\N	PRESENT	0
316795	309288	19581D	PARTICIPANT	\N	PRESENT	0
316796	309288	19747H	PARTICIPANT	\N	PRESENT	0
316799	309288	14329V	PARTICIPANT	\N	PRESENT	0
316800	309288	14357A	PARTICIPANT	\N	PRESENT	0
316802	309288	19383Y	PARTICIPANT	\N	PRESENT	0
316803	309288	19575F	PARTICIPANT	\N	PRESENT	0
316805	309288	19762G	PARTICIPANT	\N	PRESENT	0
316807	309288	04018C	PARTICIPANT	\N	PRESENT	0
316808	309288	14033T	PARTICIPANT	\N	PRESENT	0
316810	309288	19701S	PARTICIPANT	\N	PRESENT	0
316811	309288	14061L	PARTICIPANT	\N	PRESENT	0
316812	309288	14059S	PARTICIPANT	\N	PRESENT	0
316813	309288	14331P	PARTICIPANT	\N	PRESENT	0
316814	309288	19367Y	PARTICIPANT	\N	PRESENT	0
316815	309288	19621T	PARTICIPANT	\N	PRESENT	0
316821	309288	19713W	PARTICIPANT	\N	PRESENT	0
316823	309288	14217N	PARTICIPANT	\N	PRESENT	0
316827	309288	97011G	PARTICIPANT	\N	PRESENT	0
316829	309288	89017R	PARTICIPANT	\N	PRESENT	0
316830	309288	19731Y	PARTICIPANT	\N	PRESENT	0
316831	309288	07034Q	PARTICIPANT	\N	PRESENT	0
316834	309288	01048V	PARTICIPANT	\N	PRESENT	0
316841	309288	04070G	PARTICIPANT	\N	PRESENT	0
316859	309288	19647E	PARTICIPANT	\N	PRESENT	0
316854	309288	11103C	PARTICIPANT	\N	PRESENT	0
316856	309288	14093U	PARTICIPANT	\N	PRESENT	0
316857	309288	14089Y	PARTICIPANT	\N	PRESENT	0
316858	309288	95067Q	PARTICIPANT	\N	PRESENT	0
316860	309288	14193X	PARTICIPANT	\N	PRESENT	0
316887	309288	14071N	PARTICIPANT	\N	PRESENT	0
316889	309288	19749K	PARTICIPANT	\N	PRESENT	0
316890	309288	19531S	PARTICIPANT	\N	PRESENT	0
317272	314743	08009T	PARTICIPANT	\N	PRESENT	0
317273	314743	14038Y	PARTICIPANT	\N	PRESENT	0
317274	314743	19525U	PARTICIPANT	\N	PRESENT	0
317275	314743	19681G	PARTICIPANT	\N	PRESENT	0
317276	314743	19333N	PARTICIPANT	\N	PRESENT	0
317277	314743	14029X	PARTICIPANT	\N	PRESENT	0
317278	314743	14221J	PARTICIPANT	\N	PRESENT	0
317279	314743	19713W	PARTICIPANT	\N	PRESENT	0
317283	317282	08009T	PARTICIPANT	\N	PRESENT	0
317284	317282	14038Y	PARTICIPANT	\N	PRESENT	0
317285	317282	19525U	PARTICIPANT	\N	PRESENT	0
323972	323971	19503N	PARTICIPANT	\N	PRESENT	0
323806	322194	14207L	PARTICIPANT	\N	PRESENT	0
323807	322194	14257W	PARTICIPANT	\N	PRESENT	0
323808	322194	11081P	PARTICIPANT	\N	EXCUSE	0
323809	320713	04061F	PARTICIPANT	\N	PRESENT	0
323810	320977	01048V	PARTICIPANT	\N	PRESENT	0
323811	320713	19383Y	PARTICIPANT	\N	PRESENT	0
323812	320713	04085P	PARTICIPANT	\N	PRESENT	0
323813	321134	11054L	PARTICIPANT	\N	PRESENT	0
323814	321134	14133K	PARTICIPANT	\N	PRESENT	0
323815	321134	08058D	PARTICIPANT	\N	PRESENT	0
323817	323816	14179A	PARTICIPANT	\N	PRESENT	0
323818	323816	14069U	PARTICIPANT	\N	PRESENT	0
323819	323816	14001X	PARTICIPANT	\N	PRESENT	0
323820	321134	08056B	PARTICIPANT	\N	PRESENT	0
323821	322194	01043Q	PARTICIPANT	\N	PRESENT	0
323822	322194	11056N	PARTICIPANT	\N	PRESENT	0
323823	320713	14221J	PARTICIPANT	\N	PRESENT	0
323824	320713	96004D	PARTICIPANT	\N	PRESENT	0
323825	320713	19713W	PARTICIPANT	\N	PRESENT	0
323826	320713	04097T	PARTICIPANT	\N	PRESENT	0
323827	321134	98022P	PARTICIPANT	\N	PRESENT	0
323828	320713	02002K	PARTICIPANT	\N	PRESENT	0
323829	320713	11065P	PARTICIPANT	\N	PRESENT	0
323830	321792	11067R	PARTICIPANT	\N	PRESENT	0
323831	321792	14355X	PARTICIPANT	\N	PRESENT	0
323832	321792	19569H	PARTICIPANT	\N	PRESENT	0
323833	321792	11097X	PARTICIPANT	\N	PRESENT	0
323834	321792	19415P	PARTICIPANT	\N	PRESENT	0
323835	321792	14223L	PARTICIPANT	\N	PRESENT	0
323836	321792	14026U	PARTICIPANT	\N	PRESENT	0
323837	321792	14227Q	PARTICIPANT	\N	PRESENT	0
323838	321792	19675J	PARTICIPANT	\N	PRESENT	0
323839	321792	17779H	PARTICIPANT	\N	PRESENT	0
323840	321792	14239U	PARTICIPANT	\N	PRESENT	0
323841	321792	19703U	PARTICIPANT	\N	PRESENT	0
323842	321792	19553Y	PARTICIPANT	\N	PRESENT	0
323843	321792	14087W	PARTICIPANT	\N	PRESENT	0
323844	321792	14281W	PARTICIPANT	\N	PRESENT	0
323845	321792	19679N	PARTICIPANT	\N	PRESENT	0
323846	321792	08048B	PARTICIPANT	\N	PRESENT	0
323847	321792	14195A	PARTICIPANT	\N	PRESENT	0
323848	321792	14213J	PARTICIPANT	\N	PRESENT	0
323849	321792	14217N	PARTICIPANT	\N	PRESENT	0
323850	321792	19335Q	PARTICIPANT	\N	PRESENT	0
323851	321792	14261S	PARTICIPANT	\N	PRESENT	0
323852	321792	19683J	PARTICIPANT	\N	PRESENT	0
323853	321792	10006L	PARTICIPANT	\N	PRESENT	0
323854	321792	98024R	PARTICIPANT	\N	PRESENT	0
323855	321792	01034P	PARTICIPANT	\N	PRESENT	0
323856	321792	04092N	PRESIDENT	0	PRESENT	0
323857	321792	11045K	PARTICIPANT	\N	PRESENT	0
323858	321792	08052W	PARTICIPANT	\N	PRESENT	0
323859	321792	19715Y	PARTICIPANT	\N	PRESENT	0
323860	321792	19691J	PARTICIPANT	\N	PRESENT	0
323861	321792	19723Y	PARTICIPANT	\N	PRESENT	0
323862	321792	19727D	PARTICIPANT	\N	PRESENT	0
323863	321792	14119M	PARTICIPANT	\N	PRESENT	0
323864	321792	11103C	PARTICIPANT	\N	PRESENT	0
323865	321792	19657G	PARTICIPANT	\N	PRESENT	0
323866	321792	14071N	PARTICIPANT	\N	PRESENT	0
323867	321792	19577H	PARTICIPANT	\N	PRESENT	0
323868	321792	19760E	PARTICIPANT	\N	PRESENT	0
323869	320713	19551W	PARTICIPANT	\N	PRESENT	0
323870	319828	14001X	PARTICIPANT	\N	PRESENT	0
323871	319828	19581D	PARTICIPANT	\N	PRESENT	0
323872	319828	04047H	PARTICIPANT	\N	PRESENT	0
323980	314152	14034U	PARTICIPANT	\N	PRESENT	0
323874	319828	01028R	PARTICIPANT	\N	PRESENT	0
323875	319828	19447X	PARTICIPANT	\N	PRESENT	0
323876	319828	05008E	PRESIDENT	0	PRESENT	0
323877	319828	19489J	PARTICIPANT	\N	PRESENT	0
323878	319828	14179A	PARTICIPANT	\N	PRESENT	0
323879	319828	14147R	PARTICIPANT	\N	PRESENT	0
323880	319828	14151M	PARTICIPANT	\N	PRESENT	0
323881	319828	14215L	PARTICIPANT	\N	PRESENT	0
323882	319828	14259Y	PARTICIPANT	\N	PRESENT	0
323883	319828	98035U	PARTICIPANT	\N	PRESENT	0
323884	319828	14053L	PARTICIPANT	\N	PRESENT	0
323885	319828	14111D	PARTICIPANT	\N	PRESENT	0
323886	319828	14065Q	PARTICIPANT	\N	PRESENT	0
323887	319828	08045X	PARTICIPANT	\N	PRESENT	0
323888	319828	07034Q	PARTICIPANT	\N	PRESENT	0
323889	319828	10015M	PARTICIPANT	\N	PRESENT	0
323890	319828	19253P	PARTICIPANT	\N	PRESENT	0
323891	319828	01024M	PARTICIPANT	\N	PRESENT	0
323892	319828	11033F	PARTICIPANT	\N	PRESENT	0
323893	319828	19725B	PARTICIPANT	\N	PRESENT	0
323894	319828	14089Y	PARTICIPANT	\N	PRESENT	0
323895	319828	19729F	PARTICIPANT	\N	PRESENT	0
323896	319828	95063L	PARTICIPANT	\N	PRESENT	0
323897	319828	08044W	PARTICIPANT	\N	PRESENT	0
323898	319828	14069U	PARTICIPANT	\N	PRESENT	0
323899	319828	11049P	PARTICIPANT	\N	PRESENT	0
323900	319828	19762G	PARTICIPANT	\N	PRESENT	0
323901	319828	14021P	PARTICIPANT	\N	PRESENT	0
323902	319828	14231L	PARTICIPANT	\N	EXCUSE	0
323903	319828	08018U	PARTICIPANT	\N	PRESENT	0
323904	319828	11072N	PARTICIPANT	\N	PRESENT	0
323905	319828	19719D	PARTICIPANT	\N	PRESENT	0
323906	319828	11085T	PARTICIPANT	\N	PRESENT	0
323907	321134	95030B	PARTICIPANT	\N	PRESENT	0
323908	321134	95067Q	PARTICIPANT	\N	PRESENT	0
323909	320977	08034U	PARTICIPANT	\N	PRESENT	0
323910	320977	19689Q	PARTICIPANT	\N	PRESENT	0
323911	321134	19669L	PARTICIPANT	\N	PRESENT	0
323912	321792	19697Q	PARTICIPANT	\N	PRESENT	0
323913	321792	04045F	PARTICIPANT	\N	PRESENT	0
323914	321792	11031D	PARTICIPANT	\N	PRESENT	0
323915	321792	19575F	PARTICIPANT	\N	PRESENT	0
323916	321792	19663E	PARTICIPANT	\N	PRESENT	0
323917	322291	04070G	PRESIDENT	0	PRESENT	0
323918	322291	19699S	PARTICIPANT	\N	PRESENT	0
323919	322291	19533U	PARTICIPANT	\N	PRESENT	0
323920	322291	14229S	PARTICIPANT	\N	PRESENT	0
323921	322291	19573D	PARTICIPANT	\N	PRESENT	0
323922	322291	14039A	PARTICIPANT	\N	PRESENT	0
323923	322291	14107H	PARTICIPANT	\N	PRESENT	0
323924	322291	08017T	PARTICIPANT	\N	PRESENT	0
323925	322291	07033P	PARTICIPANT	\N	PRESENT	0
323926	322291	08012N	PARTICIPANT	\N	PRESENT	0
323927	322291	14249W	PARTICIPANT	\N	PRESENT	0
323928	322291	08039A	PARTICIPANT	\N	PRESENT	0
323929	322291	08031R	PARTICIPANT	\N	PRESENT	0
323930	322291	19593H	PARTICIPANT	\N	PRESENT	0
323931	322291	04057K	PARTICIPANT	\N	PRESENT	0
323932	322291	14073Q	PARTICIPANT	\N	PRESENT	0
323933	322291	19611R	PARTICIPANT	\N	PRESENT	0
323934	322291	08043V	PARTICIPANT	\N	PRESENT	0
323935	322291	19693L	PARTICIPANT	\N	PRESENT	0
323936	322291	19399H	PARTICIPANT	\N	PRESENT	0
323937	322291	14030Q	PARTICIPANT	\N	PRESENT	0
323938	322291	19731Y	PARTICIPANT	\N	PRESENT	0
323939	322291	14251Q	PARTICIPANT	\N	PRESENT	0
323940	322291	08020N	PARTICIPANT	\N	PRESENT	0
323941	322291	19735D	PARTICIPANT	\N	PRESENT	0
323942	322291	14109K	PARTICIPANT	\N	PRESENT	0
323943	322291	14063N	PARTICIPANT	\N	PRESENT	0
323944	322291	11083R	PARTICIPANT	\N	PRESENT	0
323945	322291	14123H	PARTICIPANT	\N	PRESENT	0
323946	322291	11043H	PARTICIPANT	\N	PRESENT	0
323947	322291	11104D	PARTICIPANT	\N	PRESENT	0
323948	322291	04018C	PARTICIPANT	\N	PRESENT	0
323949	322291	19758L	PARTICIPANT	\N	PRESENT	0
323950	322291	19621T	PARTICIPANT	\N	PRESENT	0
323952	322194	11099A	PARTICIPANT	\N	PRESENT	0
323953	322194	19563B	PARTICIPANT	\N	PRESENT	0
323954	322194	19269X	PARTICIPANT	\N	PRESENT	0
323955	322194	14115H	PARTICIPANT	\N	PRESENT	0
323956	322194	17589D	PARTICIPANT	\N	PRESENT	0
323957	322194	19619A	PARTICIPANT	\N	PRESENT	0
323958	322194	08038Y	PARTICIPANT	\N	EXCUSE	0
323959	322194	19295A	PARTICIPANT	\N	PRESENT	0
323960	319828	14275Y	PARTICIPANT	\N	PRESENT	0
323961	319828	19629C	PARTICIPANT	\N	PRESENT	0
323974	322291	92040Q	PARTICIPANT	\N	PRESENT	0
323975	322291	08035V	PARTICIPANT	\N	PRESENT	0
323976	322291	04059M	PARTICIPANT	\N	PRESENT	0
323977	322291	19749K	PARTICIPANT	\N	PRESENT	0
323978	322291	19766L	PARTICIPANT	\N	EXCUSE	0
323979	322291	14061L	PARTICIPANT	\N	EXCUSE	0
323985	314152	19731Y	PARTICIPANT	\N	PRESENT	0
323986	314152	19581D	PARTICIPANT	\N	PRESENT	0
323987	314152	14227Q	PARTICIPANT	\N	PRESENT	0
323988	314152	17589D	PARTICIPANT	\N	PRESENT	0
323989	314152	08052W	PARTICIPANT	\N	PRESENT	0
323990	314152	14257W	PARTICIPANT	\N	PRESENT	0
323991	314152	14157T	PARTICIPANT	\N	PRESENT	0
323992	314152	07034Q	PARTICIPANT	\N	PRESENT	0
323993	314152	14089Y	PARTICIPANT	\N	PRESENT	0
311770	311769	08010L	PARTICIPANT	\N	PRESENT	0
311771	311769	04045F	PARTICIPANT	\N	PRESENT	0
311776	311775	08010L	PARTICIPANT	\N	PRESENT	0
311777	311775	04045F	PARTICIPANT	\N	PRESENT	0
327672	323962	11101A	PARTICIPANT	\N	PRESENT	0
326782	326519	92040Q	PARTICIPANT	\N	PRESENT	0
327673	323962	08038Y	PARTICIPANT	\N	PRESENT	0
326978	326861	04057K	PARTICIPANT	\N	EXCUSE	0
326979	326861	08017T	PARTICIPANT	\N	EXCUSE	0
326982	326861	14030Q	PARTICIPANT	\N	PRESENT	0
326983	326861	19693L	PARTICIPANT	\N	PRESENT	0
327671	323962	14069U	PARTICIPANT	\N	PRESENT	0
327674	323962	19489J	PARTICIPANT	\N	PRESENT	0
327675	323962	14028W	PARTICIPANT	\N	PRESENT	0
327676	323962	08049C	PARTICIPANT	\N	PRESENT	0
327677	323962	95067Q	PARTICIPANT	\N	PRESENT	0
327678	323962	19565D	PARTICIPANT	\N	PRESENT	0
327679	323962	08051V	PARTICIPANT	\N	PRESENT	0
327680	323962	11049P	PARTICIPANT	\N	PRESENT	0
327713	321318	19575F	PARTICIPANT	\N	PRESENT	0
327714	321318	87003B	PARTICIPANT	\N	PRESENT	0
327715	321318	01057W	PARTICIPANT	\N	PRESENT	0
327716	321318	04088S	PARTICIPANT	\N	PRESENT	0
327717	321318	19545Y	PARTICIPANT	\N	PRESENT	0
327718	321318	19367Y	PARTICIPANT	\N	PRESENT	0
327719	321318	04061F	PARTICIPANT	\N	PRESENT	0
327721	321318	19301E	PARTICIPANT	\N	PRESENT	0
327722	321318	14327T	PARTICIPANT	\N	PRESENT	0
327723	321318	19647E	PARTICIPANT	\N	PRESENT	0
327724	321318	19415P	PARTICIPANT	\N	PRESENT	0
327725	321318	19479G	PARTICIPANT	\N	PRESENT	0
327726	321318	19747H	PARTICIPANT	\N	PRESENT	0
327727	321318	04071H	PARTICIPANT	\N	PRESENT	0
327728	321318	14033T	PARTICIPANT	\N	PRESENT	0
327729	321318	19643A	PARTICIPANT	\N	PRESENT	0
327730	321318	14169X	PARTICIPANT	\N	PRESENT	0
327731	321318	11103C	PARTICIPANT	\N	PRESENT	0
327732	321318	04057K	PARTICIPANT	\N	PRESENT	0
327733	321318	19651A	PARTICIPANT	\N	PRESENT	0
327734	321318	08068F	PARTICIPANT	\N	PRESENT	0
327735	321318	11012A	PARTICIPANT	\N	PRESENT	0
327737	321318	14211G	PARTICIPANT	\N	PRESENT	0
327738	321318	95030B	PARTICIPANT	\N	PRESENT	0
327739	321318	11067R	PARTICIPANT	\N	PRESENT	0
327740	321318	14261S	PARTICIPANT	\N	PRESENT	0
327741	321318	89017R	PARTICIPANT	\N	PRESENT	0
327742	321318	14215L	PARTICIPANT	\N	PRESENT	0
327743	321318	14219Q	PARTICIPANT	\N	PRESENT	0
327744	321318	14107H	PARTICIPANT	\N	PRESENT	0
327745	321318	08062Y	PARTICIPANT	\N	PRESENT	0
327754	327747	14001X	PARTICIPANT	\N	PRESENT	0
327757	327747	14331P	PARTICIPANT	\N	PRESENT	0
327758	321318	19733B	PARTICIPANT	\N	PRESENT	0
327761	321318	19515S	PARTICIPANT	\N	PRESENT	0
327762	321318	14083S	PARTICIPANT	\N	PRESENT	0
327763	321318	14179A	PARTICIPANT	\N	PRESENT	0
327764	321318	14079W	PARTICIPANT	\N	PRESENT	0
327765	321318	19565D	PARTICIPANT	\N	PRESENT	0
327766	327746	14001X	PARTICIPANT	\N	PRESENT	0
327767	327746	14331P	PARTICIPANT	\N	PRESENT	0
327768	321318	11040E	PARTICIPANT	\N	PRESENT	0
327769	321318	19729F	PARTICIPANT	\N	PRESENT	0
327770	321318	14069U	PARTICIPANT	\N	PRESENT	0
327771	321318	19507S	PARTICIPANT	\N	PRESENT	0
327772	321318	14187A	PARTICIPANT	\N	PRESENT	0
327773	321318	04085P	PARTICIPANT	\N	PRESENT	0
327774	321318	19467C	PARTICIPANT	\N	PRESENT	0
327775	321318	19637C	PARTICIPANT	\N	PRESENT	0
327776	321318	14021P	PARTICIPANT	\N	PRESENT	0
327777	321318	08024S	PARTICIPANT	\N	PRESENT	0
327780	321318	14109K	PARTICIPANT	\N	PRESENT	0
327783	321318	14028W	PARTICIPANT	\N	PRESENT	0
327784	321318	11053K	PARTICIPANT	\N	PRESENT	0
327785	321318	19760E	PARTICIPANT	\N	PRESENT	0
327786	321318	14235Q	PARTICIPANT	\N	PRESENT	0
327787	321318	14119M	PARTICIPANT	\N	PRESENT	0
327788	321318	11048N	PARTICIPANT	\N	PRESENT	0
327789	321318	19703U	PARTICIPANT	\N	PRESENT	0
327790	321318	14031R	PARTICIPANT	\N	PRESENT	0
327791	321318	08010L	PARTICIPANT	\N	PRESENT	0
327793	327792	11053K	PARTICIPANT	\N	PRESENT	0
327794	327792	14159V	PARTICIPANT	\N	PRESENT	0
327795	327792	05012A	PARTICIPANT	\N	PRESENT	0
327796	321318	08051V	PARTICIPANT	\N	PRESENT	0
327800	321318	17583W	PARTICIPANT	\N	PRESENT	0
327802	321318	19663E	PARTICIPANT	\N	PRESENT	0
327803	321318	14030Q	PARTICIPANT	\N	PRESENT	0
327804	321318	98022P	PARTICIPANT	\N	PRESENT	0
327805	321318	19611R	PARTICIPANT	\N	PRESENT	0
327806	321318	14159V	PARTICIPANT	\N	PRESENT	0
327807	321318	04033B	PARTICIPANT	\N	PRESENT	0
327808	321318	14257W	PARTICIPANT	\N	PRESENT	0
327809	321318	19441R	PARTICIPANT	\N	PRESENT	0
327811	321318	08060W	PARTICIPANT	\N	PRESENT	0
327814	321318	08038Y	PARTICIPANT	\N	PRESENT	0
327815	321318	08043V	PARTICIPANT	\N	PRESENT	0
327816	321318	14065Q	PARTICIPANT	\N	PRESENT	0
327817	321318	19725B	PARTICIPANT	\N	PRESENT	0
327818	321318	01024M	PARTICIPANT	\N	PRESENT	0
327819	321318	08034U	PARTICIPANT	\N	PRESENT	0
327820	321318	14039A	PARTICIPANT	\N	PRESENT	0
327821	321318	14329V	PARTICIPANT	\N	PRESENT	0
327822	321318	16685X	PARTICIPANT	\N	PRESENT	0
327823	321318	14265W	PARTICIPANT	\N	PRESENT	0
327824	321318	11097X	PARTICIPANT	\N	PRESENT	0
327825	321318	14071N	PARTICIPANT	\N	PRESENT	0
327826	321318	14217N	PARTICIPANT	\N	PRESENT	0
327827	321318	12016W	PARTICIPANT	\N	PRESENT	0
327828	321318	14105F	PARTICIPANT	\N	PRESENT	0
327829	321318	08053X	PARTICIPANT	\N	PRESENT	0
327830	321318	19553Y	PARTICIPANT	\N	PRESENT	0
327831	321318	95062K	PARTICIPANT	\N	PRESENT	0
327832	321318	14275Y	PARTICIPANT	\N	PRESENT	0
327833	321318	14042U	PARTICIPANT	\N	PRESENT	0
327926	321323	15447F	PARTICIPANT	\N	PRESENT	0
327927	321323	19643A	PARTICIPANT	\N	PRESENT	0
327928	321323	04097T	PARTICIPANT	\N	PRESENT	0
327929	321323	14191V	PARTICIPANT	\N	PRESENT	0
327930	321323	11101A	PARTICIPANT	\N	PRESENT	0
327931	321323	95030B	PARTICIPANT	\N	PRESENT	0
327932	321323	19703U	PARTICIPANT	\N	PRESENT	0
327933	321323	19467C	PARTICIPANT	\N	PRESENT	0
327934	321323	14173T	PARTICIPANT	\N	PRESENT	0
327935	321323	18083K	PARTICIPANT	\N	PRESENT	0
327936	321323	14041T	PARTICIPANT	\N	PRESENT	0
327937	321323	04088S	PARTICIPANT	\N	PRESENT	0
327938	321323	04038G	PARTICIPANT	\N	PRESENT	0
327939	321323	99004R	PARTICIPANT	\N	PRESENT	0
327940	321323	87003B	PARTICIPANT	\N	PRESENT	0
327941	321323	95062K	PARTICIPANT	\N	PRESENT	0
327942	321323	01058X	PARTICIPANT	\N	PRESENT	0
327943	321323	19415P	PARTICIPANT	\N	PRESENT	0
327944	321323	19399H	PARTICIPANT	\N	PRESENT	0
327945	321323	14105F	PARTICIPANT	\N	PRESENT	0
327946	321323	14033T	PARTICIPANT	\N	PRESENT	0
327947	321323	19515S	PARTICIPANT	\N	PRESENT	0
327948	321323	14265W	PARTICIPANT	\N	PRESENT	0
327951	321323	11103C	PARTICIPANT	\N	PRESENT	0
327954	321323	14087W	PARTICIPANT	\N	PRESENT	0
327955	321323	14079W	PARTICIPANT	\N	PRESENT	0
327958	321323	14259Y	PARTICIPANT	\N	PRESENT	0
327960	321323	19657G	PARTICIPANT	\N	PRESENT	0
327962	321323	98024R	PARTICIPANT	\N	PRESENT	0
327964	321323	17583W	PARTICIPANT	\N	PRESENT	0
327965	321323	01057W	PARTICIPANT	\N	PRESENT	0
327967	321323	19675J	PARTICIPANT	\N	PRESENT	0
327968	321323	19383Y	PARTICIPANT	\N	PRESENT	0
327969	321323	19693L	PARTICIPANT	\N	PRESENT	0
327970	321323	14329V	PARTICIPANT	\N	PRESENT	0
327974	321323	14331P	PARTICIPANT	\N	PRESENT	0
327975	321323	08034U	PARTICIPANT	\N	PRESENT	0
327976	321323	14199E	PARTICIPANT	\N	PRESENT	0
327977	321323	19443T	PARTICIPANT	\N	PRESENT	0
327978	321323	04042C	PARTICIPANT	\N	PRESENT	0
327979	321323	07034Q	PARTICIPANT	\N	PRESENT	0
327980	321323	14249W	PARTICIPANT	\N	PRESENT	0
327981	321323	07029T	PARTICIPANT	\N	PRESENT	0
327982	321323	14217N	PARTICIPANT	\N	PRESENT	0
327983	321323	19667J	PARTICIPANT	\N	PRESENT	0
327984	321323	19709B	PARTICIPANT	\N	PRESENT	0
327985	321323	98050T	PARTICIPANT	\N	PRESENT	0
327986	321323	08019V	PARTICIPANT	\N	PRESENT	0
327987	321323	04086Q	PARTICIPANT	\N	PRESENT	0
327988	321323	14211G	PARTICIPANT	\N	PRESENT	0
327989	321323	14187A	PARTICIPANT	\N	PRESENT	0
327990	321323	14357A	PARTICIPANT	\N	PRESENT	0
327991	321323	96004D	PARTICIPANT	\N	PRESENT	0
304884	304883	14213J	PARTICIPANT	\N	PRESENT	0
304885	304883	11099A	PARTICIPANT	\N	PRESENT	0
304886	304883	10006L	PARTICIPANT	\N	PRESENT	0
304887	304883	14109K	PARTICIPANT	\N	PRESENT	0
304888	304883	19503N	PARTICIPANT	\N	PRESENT	0
304889	304883	19533U	PARTICIPANT	\N	PRESENT	0
305884	305883	04040A	PRESIDENT	0	PRESENT	0
305887	305886	19713W	PARTICIPANT	\N	PRESENT	0
305888	305886	19651A	PARTICIPANT	\N	PRESENT	0
305889	305886	04061F	PARTICIPANT	\N	PRESENT	0
305890	305886	99004R	PRESIDENT	0	PRESENT	0
305891	305885	99004R	PRESIDENT	0	PRESENT	0
305892	305885	08024S	PARTICIPANT	\N	PRESENT	0
305893	305885	02002K	PARTICIPANT	\N	PRESENT	0
305894	305885	19551W	PARTICIPANT	\N	PRESENT	0
305895	305885	19349W	PARTICIPANT	\N	PRESENT	0
305896	305885	19737F	PARTICIPANT	\N	PRESENT	0
305898	305897	99004R	PRESIDENT	0	PRESENT	0
305901	305900	99004R	PARTICIPANT	\N	PRESENT	0
308755	308754	19701S	PARTICIPANT	\N	PRESENT	0
308756	308754	11049P	PARTICIPANT	\N	PRESENT	0
313300	311342	14105F	PARTICIPANT	\N	PRESENT	0
313301	311342	98022P	PARTICIPANT	\N	PRESENT	0
313302	311342	14267Y	PARTICIPANT	\N	PRESENT	0
313303	311342	11064N	PARTICIPANT	\N	PRESENT	0
313304	311342	98050T	PARTICIPANT	\N	PRESENT	0
313305	311342	19583F	PARTICIPANT	\N	PRESENT	0
313306	311342	14211G	PARTICIPANT	\N	PRESENT	0
313307	311342	14255U	PARTICIPANT	\N	PRESENT	0
313308	311721	04071H	PARTICIPANT	\N	PRESENT	0
313309	311721	19545Y	PARTICIPANT	\N	PRESENT	0
313310	311721	14083S	PARTICIPANT	\N	PRESENT	0
313311	311721	08073C	PARTICIPANT	\N	PRESENT	0
313312	310940	19713W	PARTICIPANT	\N	PRESENT	0
313313	310940	19503N	PARTICIPANT	\N	PRESENT	0
313314	310940	19733B	PARTICIPANT	\N	PRESENT	0
313315	310940	04097T	PARTICIPANT	\N	PRESENT	0
313316	310940	08060W	PARTICIPANT	\N	PRESENT	0
313317	310940	08009T	PRESIDENT	0	PRESENT	0
313318	311341	14105F	PARTICIPANT	\N	PRESENT	0
313319	311342	95030B	PARTICIPANT	\N	PRESENT	0
313320	310940	18083K	PARTICIPANT	\N	PRESENT	0
313321	310940	19383Y	PARTICIPANT	\N	PRESENT	0
313322	310940	19701S	PARTICIPANT	\N	PRESENT	0
313323	310419	19575F	PARTICIPANT	\N	PRESENT	0
313324	310421	19575F	PARTICIPANT	\N	PRESENT	0
313327	313326	14038Y	PARTICIPANT	\N	PRESENT	0
313328	313326	11064N	PARTICIPANT	\N	PRESENT	0
313329	313326	14179A	PARTICIPANT	\N	PRESENT	0
313330	313326	14241N	PARTICIPANT	\N	PRESENT	0
313331	313326	08053X	PARTICIPANT	\N	PRESENT	0
313342	312053	19766L	PARTICIPANT	\N	PRESENT	0
313343	312053	04070G	PRESIDENT	0	PRESENT	0
313344	312053	19699S	PARTICIPANT	\N	PRESENT	0
313345	312053	19533U	PARTICIPANT	\N	PRESENT	0
313346	312053	14241N	PARTICIPANT	\N	PRESENT	0
313347	312053	19573D	PARTICIPANT	\N	PRESENT	0
313348	312053	14039A	PARTICIPANT	\N	PRESENT	0
313349	312053	14107H	PARTICIPANT	\N	PRESENT	0
313350	312053	08017T	PARTICIPANT	\N	PRESENT	0
313351	312053	92040Q	PARTICIPANT	\N	PRESENT	0
313352	312053	07033P	PARTICIPANT	\N	PRESENT	0
313353	312053	08012N	PARTICIPANT	\N	PRESENT	0
313354	312053	14249W	PARTICIPANT	\N	PRESENT	0
313355	312053	08039A	PARTICIPANT	\N	PRESENT	0
313356	312053	08031R	PARTICIPANT	\N	PRESENT	0
313357	312053	19593H	PARTICIPANT	\N	PRESENT	0
313358	312053	19643A	PARTICIPANT	\N	PRESENT	0
313359	312053	14059S	PARTICIPANT	\N	PRESENT	0
313360	312053	14061L	PARTICIPANT	\N	PRESENT	0
313361	312053	04057K	PARTICIPANT	\N	PRESENT	0
313362	312053	14073Q	PARTICIPANT	\N	PRESENT	0
313363	312053	19611R	PARTICIPANT	\N	PRESENT	0
313364	312053	08035V	PARTICIPANT	\N	PRESENT	0
313365	312053	08043V	PARTICIPANT	\N	PRESENT	0
313366	312053	19693L	PARTICIPANT	\N	PRESENT	0
313367	312053	87003B	PARTICIPANT	\N	PRESENT	0
313368	312053	19399H	PARTICIPANT	\N	PRESENT	0
313369	312053	14201E	PARTICIPANT	\N	PRESENT	0
313370	312053	14030Q	PARTICIPANT	\N	PRESENT	0
313371	312053	14251Q	PARTICIPANT	\N	PRESENT	0
313372	312053	08020N	PARTICIPANT	\N	PRESENT	0
313373	312053	19735D	PARTICIPANT	\N	PRESENT	0
313374	312053	11083R	PARTICIPANT	\N	PRESENT	0
313375	312053	14063N	PARTICIPANT	\N	PRESENT	0
313376	312053	14109K	PARTICIPANT	\N	PRESENT	0
313377	312053	14123H	PARTICIPANT	\N	PRESENT	0
313378	312053	11104D	PARTICIPANT	\N	PRESENT	0
313379	312053	11043H	PARTICIPANT	\N	PRESENT	0
313380	312053	19749K	PARTICIPANT	\N	PRESENT	0
313381	312053	19758L	PARTICIPANT	\N	PRESENT	0
313382	312053	04018C	PARTICIPANT	\N	PRESENT	0
313383	312053	04059M	PARTICIPANT	\N	PRESENT	0
313391	311721	14217N	PARTICIPANT	\N	PRESENT	0
313392	311721	11026G	PARTICIPANT	\N	PRESENT	0
313393	311721	14255U	PARTICIPANT	\N	PRESENT	0
313460	309274	01043Q	PARTICIPANT	\N	PRESENT	0
313461	309274	96004D	PARTICIPANT	\N	PRESENT	0
313462	309274	04042C	PARTICIPANT	\N	PRESENT	0
313463	309274	11074Q	PARTICIPANT	\N	PRESENT	0
313464	309274	19731Y	PARTICIPANT	\N	PRESENT	0
313465	309274	11026G	PARTICIPANT	\N	PRESENT	0
313466	309274	12041X	PARTICIPANT	\N	PRESENT	0
313467	309274	14237S	PARTICIPANT	\N	PRESENT	0
313468	309274	01060R	PARTICIPANT	\N	PRESENT	0
313469	309274	14133K	PARTICIPANT	\N	PRESENT	0
313470	309274	19443T	PARTICIPANT	\N	PRESENT	0
313480	309274	14205J	PARTICIPANT	\N	PRESENT	0
313472	309274	19725B	PARTICIPANT	\N	PRESENT	0
313473	309274	14041T	PARTICIPANT	\N	PRESENT	0
313474	309274	11083R	PARTICIPANT	\N	PRESENT	0
313475	309274	11066Q	PARTICIPANT	\N	PRESENT	0
313476	309274	19593H	PARTICIPANT	\N	PRESENT	0
313477	309274	98035U	PARTICIPANT	\N	PRESENT	0
313478	309274	17583W	PARTICIPANT	\N	PRESENT	0
313479	309274	14089Y	PARTICIPANT	\N	PRESENT	0
313481	309274	14073Q	PARTICIPANT	\N	PRESENT	0
313483	309274	19533U	PARTICIPANT	\N	PRESENT	0
313484	309274	14105F	PARTICIPANT	\N	PRESENT	0
313485	309274	14235Q	PARTICIPANT	\N	PRESENT	0
313486	309274	14255U	PARTICIPANT	\N	PRESENT	0
313487	309274	11103C	PARTICIPANT	\N	PRESENT	0
313488	309274	19739H	PARTICIPANT	\N	PRESENT	0
313489	309274	19729F	PARTICIPANT	\N	PRESENT	0
313490	309274	19507S	PARTICIPANT	\N	PRESENT	0
313491	309274	18083K	PARTICIPANT	\N	PRESENT	0
313492	309274	19701S	PARTICIPANT	\N	PRESENT	0
313493	309274	11097X	PARTICIPANT	\N	PRESENT	0
313494	309274	95030B	PARTICIPANT	\N	PRESENT	0
313495	309274	98005N	PARTICIPANT	\N	PRESENT	0
313496	309274	19581D	PARTICIPANT	\N	PRESENT	0
313498	309274	19575F	PARTICIPANT	\N	PRESENT	0
313500	309274	04061F	PARTICIPANT	\N	PRESENT	0
313502	309274	19543W	PARTICIPANT	\N	PRESENT	0
313504	309274	19503N	PARTICIPANT	\N	PRESENT	0
313505	309274	95063L	PARTICIPANT	\N	PRESENT	0
313506	309274	11104D	PARTICIPANT	\N	PRESENT	0
313508	309274	04057K	PARTICIPANT	\N	PRESENT	0
313510	313509	05008E	PRESIDENT	0	PRESENT	0
313512	313509	11033F	PARTICIPANT	\N	PRESENT	0
313513	313509	14065Q	PARTICIPANT	\N	PRESENT	0
313514	313509	14069U	PARTICIPANT	\N	PRESENT	0
313515	313509	14089Y	PARTICIPANT	\N	PRESENT	0
313516	313509	04047H	PARTICIPANT	\N	PRESENT	0
313518	313509	19629C	PARTICIPANT	\N	PRESENT	0
313519	313509	04038G	PARTICIPANT	\N	PRESENT	0
313520	313509	19253P	PARTICIPANT	\N	PRESENT	0
313523	313509	19719D	PARTICIPANT	\N	PRESENT	0
313524	313509	14041T	PARTICIPANT	\N	PRESENT	0
313525	313509	01024M	PARTICIPANT	\N	PRESENT	0
313526	313509	14215L	PARTICIPANT	\N	PRESENT	0
313527	313509	14151M	PARTICIPANT	\N	PRESENT	0
313528	313509	19673G	PARTICIPANT	\N	PRESENT	0
313529	313509	08045X	PARTICIPANT	\N	PRESENT	0
313530	313509	08018U	PARTICIPANT	\N	PRESENT	0
313532	313509	14231L	PARTICIPANT	\N	PRESENT	0
313533	313509	19649G	PARTICIPANT	\N	PRESENT	0
313534	313509	11049P	PARTICIPANT	\N	PRESENT	0
313535	313509	19725B	PARTICIPANT	\N	PRESENT	0
313536	313509	14179A	PARTICIPANT	\N	PRESENT	0
313537	313509	08044W	PARTICIPANT	\N	PRESENT	0
313538	313509	19447X	PARTICIPANT	\N	PRESENT	0
313539	313509	14021P	PARTICIPANT	\N	PRESENT	0
313540	313509	19489J	PARTICIPANT	\N	PRESENT	0
316303	316300	04059M	PARTICIPANT	\N	PRESENT	0
316304	316300	05008E	PARTICIPANT	\N	PRESENT	0
316305	316300	96004D	PARTICIPANT	\N	PRESENT	0
316306	316300	04086Q	PARTICIPANT	\N	PRESENT	0
316307	316300	98024R	PARTICIPANT	\N	PRESENT	0
316308	316300	11074Q	PARTICIPANT	\N	PRESENT	0
316309	316300	19521Q	PARTICIPANT	\N	PRESENT	0
316310	316300	14034U	PARTICIPANT	\N	PRESENT	0
316311	316300	14021P	PARTICIPANT	\N	PRESENT	0
316312	316300	01043Q	PARTICIPANT	\N	PRESENT	0
316313	316300	14251Q	PARTICIPANT	\N	PRESENT	0
316314	316300	14031R	PARTICIPANT	\N	PRESENT	0
316315	316300	11085T	PARTICIPANT	\N	PRESENT	0
316316	316300	11072N	PARTICIPANT	\N	PRESENT	0
316317	316300	04070G	PARTICIPANT	\N	PRESENT	0
316318	316300	08061X	PARTICIPANT	\N	PRESENT	0
316319	316300	14193X	PARTICIPANT	\N	PRESENT	0
316320	316300	04042C	PARTICIPANT	\N	PRESENT	0
316321	316300	05012A	PARTICIPANT	\N	PRESENT	0
316322	316300	11090Q	PARTICIPANT	\N	PRESENT	0
316323	316300	11012A	PARTICIPANT	\N	PRESENT	0
316324	316300	04033B	PARTICIPANT	\N	PRESENT	0
316325	316300	04044E	PARTICIPANT	\N	PRESENT	0
316326	316300	01034P	PARTICIPANT	\N	PRESENT	0
316340	313977	19551W	PARTICIPANT	\N	PRESENT	0
316341	313977	19349W	PARTICIPANT	\N	PRESENT	0
316365	316215	04033B	PARTICIPANT	\N	EXCUSE	0
325126	314158	19415P	PARTICIPANT	\N	PRESENT	0
325127	314158	19760E	PARTICIPANT	\N	PRESENT	0
325128	314158	19727D	PARTICIPANT	\N	PRESENT	0
325129	314158	11097X	PARTICIPANT	\N	PRESENT	0
325130	314158	19741B	PARTICIPANT	\N	PRESENT	0
325131	314158	19657G	PARTICIPANT	\N	PRESENT	0
325132	314158	14281W	PARTICIPANT	\N	PRESENT	0
325133	314158	04045F	PARTICIPANT	\N	PRESENT	0
325134	314158	11045K	PARTICIPANT	\N	PRESENT	0
325135	314158	08052W	PARTICIPANT	\N	PRESENT	0
325136	314158	19553Y	PARTICIPANT	\N	PRESENT	0
325137	314158	14071N	PARTICIPANT	\N	PRESENT	0
325138	314158	19711U	PARTICIPANT	\N	PRESENT	0
325139	314158	14042U	PARTICIPANT	\N	PRESENT	0
325140	314158	04044E	PARTICIPANT	\N	PRESENT	0
325141	314158	14239U	PARTICIPANT	\N	PRESENT	0
325142	314158	19715Y	PARTICIPANT	\N	PRESENT	0
325143	314158	98024R	PARTICIPANT	\N	PRESENT	0
325144	314158	04057K	PARTICIPANT	\N	PRESENT	0
325145	314158	14021P	PARTICIPANT	\N	PRESENT	0
325146	314158	01034P	PARTICIPANT	\N	PRESENT	0
325147	314158	19663E	PARTICIPANT	\N	PRESENT	0
325124	314158	04086Q	PARTICIPANT	\N	PRESENT	0
325125	314158	04092N	PARTICIPANT	\N	PRESENT	0
325149	314158	14213J	PARTICIPANT	\N	PRESENT	0
325150	314158	19683J	PARTICIPANT	\N	PRESENT	0
325151	314158	11031D	PARTICIPANT	\N	PRESENT	0
325152	314158	19421M	PARTICIPANT	\N	PRESENT	0
325153	314158	04018C	PARTICIPANT	\N	PRESENT	0
325154	314158	11085T	PARTICIPANT	\N	PRESENT	0
325155	314158	19697Q	PARTICIPANT	\N	PRESENT	0
316301	316300	89017R	PARTICIPANT	\N	PRESENT	0
316302	316300	04085P	PARTICIPANT	\N	PRESENT	0
325156	314158	10006L	PARTICIPANT	\N	PRESENT	0
325157	314158	11012A	PARTICIPANT	\N	PRESENT	0
325158	314158	19577H	PARTICIPANT	\N	PRESENT	0
325159	314158	14215L	PARTICIPANT	\N	PRESENT	0
325160	314158	11067R	PARTICIPANT	\N	PRESENT	0
325165	314158	08019V	PARTICIPANT	\N	PRESENT	0
325166	314158	19719D	PARTICIPANT	\N	PRESENT	0
325167	314158	14261S	PARTICIPANT	\N	PRESENT	0
325168	314158	14039A	PARTICIPANT	\N	PRESENT	0
325169	314158	19695N	PARTICIPANT	\N	PRESENT	0
325174	314158	14357A	PARTICIPANT	\N	PRESENT	0
325175	314158	19295A	PARTICIPANT	\N	PRESENT	0
325176	314158	04085P	PARTICIPANT	\N	PRESENT	0
325181	314158	14065Q	PARTICIPANT	\N	PRESENT	0
325186	314158	19593H	PARTICIPANT	\N	PRESENT	0
325187	325185	04038G	PARTICIPANT	\N	PRESENT	0
326409	324906	14277B	PARTICIPANT	\N	PRESENT	0
326410	324906	11074Q	PRESIDENT	0	PRESENT	0
326413	326411	14355X	PARTICIPANT	\N	PRESENT	0
326414	326411	04092N	PRESIDENT	0	PRESENT	0
326415	326411	11097X	PARTICIPANT	\N	PRESENT	0
326416	326411	08052W	PARTICIPANT	\N	PRESENT	0
326417	326411	19717B	PARTICIPANT	\N	PRESENT	0
326418	326411	19675J	PARTICIPANT	\N	PRESENT	0
326419	326411	19703U	PARTICIPANT	\N	PRESENT	0
326420	326411	14119M	PARTICIPANT	\N	PRESENT	0
326421	326411	14281W	PARTICIPANT	\N	PRESENT	0
326422	326411	19679N	PARTICIPANT	\N	PRESENT	0
326423	326411	11103C	PARTICIPANT	\N	PRESENT	0
326424	326411	19367Y	PARTICIPANT	\N	PRESENT	0
326425	326411	19657G	PARTICIPANT	\N	PRESENT	0
326441	324906	14327T	PARTICIPANT	\N	PRESENT	0
326427	326411	11067R	PARTICIPANT	\N	PRESENT	0
326428	326411	14042U	PARTICIPANT	\N	PRESENT	0
326429	326411	14195A	PARTICIPANT	\N	PRESENT	0
326430	326411	08041T	PARTICIPANT	\N	EXCUSE	0
326431	326411	19415P	PARTICIPANT	\N	PRESENT	0
326432	326411	19691J	PARTICIPANT	\N	PRESENT	0
326433	326411	19575F	PARTICIPANT	\N	PRESENT	0
326434	326411	19577H	PARTICIPANT	\N	PRESENT	0
326435	326411	19727D	PARTICIPANT	\N	PRESENT	0
326436	326411	14087W	PARTICIPANT	\N	PRESENT	0
326437	326411	14217N	PARTICIPANT	\N	PRESENT	0
326438	326411	98024R	PARTICIPANT	\N	PRESENT	0
326439	326411	19723Y	PARTICIPANT	\N	PRESENT	0
326440	326411	19521Q	PARTICIPANT	\N	PRESENT	0
326442	324906	14331P	PARTICIPANT	\N	PRESENT	0
326443	324906	19479G	PARTICIPANT	\N	PRESENT	0
326444	324906	95041E	PARTICIPANT	\N	PRESENT	0
326445	324906	19711U	PARTICIPANT	\N	PRESENT	0
326446	324906	19545Y	PARTICIPANT	\N	PRESENT	0
326447	324906	01057W	PARTICIPANT	\N	PRESENT	0
326448	324906	12016W	PARTICIPANT	\N	PRESENT	0
326449	324906	08011M	PARTICIPANT	\N	PRESENT	0
326450	324906	19667J	PARTICIPANT	\N	PRESENT	0
326451	324906	88008L	PARTICIPANT	\N	PRESENT	0
326452	324906	19671E	PARTICIPANT	\N	PRESENT	0
326453	324906	14173T	PARTICIPANT	\N	PRESENT	0
326454	324906	04086Q	PARTICIPANT	\N	PRESENT	0
326455	324906	14083S	PARTICIPANT	\N	PRESENT	0
326456	324906	11012A	PARTICIPANT	\N	PRESENT	0
326457	324906	14085U	PARTICIPANT	\N	PRESENT	0
326458	324906	08073C	PARTICIPANT	\N	PRESENT	0
326459	324906	19349W	PARTICIPANT	\N	PRESENT	0
326460	324906	19741B	PARTICIPANT	\N	PRESENT	0
326461	324906	08010L	PARTICIPANT	\N	PRESENT	0
326462	324906	14253S	PARTICIPANT	\N	PRESENT	0
326463	326411	11077T	PARTICIPANT	\N	PRESENT	0
326464	326411	14026U	PARTICIPANT	\N	PRESENT	0
326465	326411	19553Y	PARTICIPANT	\N	PRESENT	0
326466	326411	08048B	PARTICIPANT	\N	PRESENT	0
326467	326411	14213J	PARTICIPANT	\N	PRESENT	0
326468	326411	19683J	PARTICIPANT	\N	PRESENT	0
326469	326411	10006L	PARTICIPANT	\N	PRESENT	0
326470	324906	01048V	PARTICIPANT	\N	PRESENT	0
326471	324906	89017R	PARTICIPANT	\N	PRESENT	0
326472	326411	14227Q	PARTICIPANT	\N	PRESENT	0
326473	326411	04045F	PARTICIPANT	\N	PRESENT	0
326474	324906	19531S	PARTICIPANT	\N	PRESENT	0
326475	324906	04071H	PARTICIPANT	\N	PRESENT	0
326476	326411	11031D	PARTICIPANT	\N	PRESENT	0
326477	324906	11040E	PARTICIPANT	\N	PRESENT	0
326478	324906	07029T	PARTICIPANT	\N	PRESENT	0
326479	324906	14159V	PARTICIPANT	\N	PRESENT	0
326480	326411	14239U	PARTICIPANT	\N	PRESENT	0
326481	324291	14001X	PARTICIPANT	\N	PRESENT	0
326482	324291	19543W	PARTICIPANT	\N	PRESENT	0
326483	324291	04047H	PARTICIPANT	\N	PRESENT	0
326484	324291	19673G	PARTICIPANT	\N	PRESENT	0
326485	324291	01028R	PARTICIPANT	\N	PRESENT	0
326486	324291	19447X	PARTICIPANT	\N	PRESENT	0
326487	324291	05008E	PRESIDENT	0	PRESENT	0
326488	324291	14231L	PARTICIPANT	\N	PRESENT	0
326489	324291	19489J	PARTICIPANT	\N	PRESENT	0
326490	324291	14275Y	PARTICIPANT	\N	PRESENT	0
326491	324291	14041T	PARTICIPANT	\N	PRESENT	0
326492	324291	14147R	PARTICIPANT	\N	PRESENT	0
326493	324291	14179A	PARTICIPANT	\N	PRESENT	0
326494	324291	14151M	PARTICIPANT	\N	PRESENT	0
326495	324291	14215L	PARTICIPANT	\N	PRESENT	0
326496	324291	08018U	PARTICIPANT	\N	PRESENT	0
326497	324291	11072N	PARTICIPANT	\N	PRESENT	0
326498	324291	14111D	PARTICIPANT	\N	PRESENT	0
326499	324291	14065Q	PARTICIPANT	\N	PRESENT	0
326500	324291	07034Q	PRESIDENT	1	PRESENT	0
326501	324291	08045X	PARTICIPANT	\N	PRESENT	0
326502	324291	01024M	PARTICIPANT	\N	PRESENT	0
326503	324291	04038G	PARTICIPANT	\N	PRESENT	0
326504	324291	19719D	PARTICIPANT	\N	PRESENT	0
306963	306962	08015R	PARTICIPANT	\N	PRESENT	0
306964	306962	14001X	PARTICIPANT	\N	PRESENT	0
306965	306962	04049K	PARTICIPANT	\N	PRESENT	0
306966	306962	89017R	PARTICIPANT	\N	PRESENT	0
306967	306962	11026G	PARTICIPANT	\N	PRESENT	0
306968	306962	14173T	PARTICIPANT	\N	PRESENT	0
306969	306962	19737F	PARTICIPANT	\N	PRESENT	0
307105	307104	04059M	PARTICIPANT	\N	PRESENT	0
307107	307106	19533U	PARTICIPANT	\N	PRESENT	0
307110	307109	19533U	PARTICIPANT	\N	PRESENT	0
307113	307112	19533U	PARTICIPANT	\N	PRESENT	0
307139	307136	04086Q	PARTICIPANT	\N	PRESENT	0
307117	307116	19533U	PARTICIPANT	\N	PRESENT	0
307141	307136	14237S	PARTICIPANT	\N	PRESENT	0
307142	307136	19745F	PARTICIPANT	\N	PRESENT	0
307143	307136	15447F	PARTICIPANT	\N	PRESENT	0
307144	307136	08016S	PARTICIPANT	\N	PRESENT	0
307145	307136	14111D	PARTICIPANT	\N	PRESENT	0
307146	307136	19507S	PARTICIPANT	\N	PRESENT	0
307147	307136	14253S	PARTICIPANT	\N	PRESENT	0
307148	307136	14265W	PARTICIPANT	\N	PRESENT	0
307149	307136	11066Q	PARTICIPANT	\N	PRESENT	0
307150	307136	19467C	PARTICIPANT	\N	PRESENT	0
307151	307136	19629C	PARTICIPANT	\N	PRESENT	0
307152	307136	14219Q	PARTICIPANT	\N	PRESENT	0
307153	307136	11040E	PARTICIPANT	\N	PRESENT	0
307154	307136	11056N	PARTICIPANT	\N	PRESENT	0
307155	307136	19695N	PARTICIPANT	\N	PRESENT	0
307156	307136	19565D	PARTICIPANT	\N	PRESENT	0
307157	307136	19593H	PARTICIPANT	\N	PRESENT	0
307158	307136	19347U	PARTICIPANT	\N	PRESENT	0
307159	307136	14197C	PARTICIPANT	\N	PRESENT	0
307160	307136	19631V	PARTICIPANT	\N	PRESENT	0
307161	307136	19413M	PARTICIPANT	\N	PRESENT	0
307162	307136	14257W	PARTICIPANT	\N	PRESENT	0
307164	307136	14207L	PARTICIPANT	\N	PRESENT	0
307165	307136	19269X	PARTICIPANT	\N	PRESENT	0
307166	307136	14107H	PARTICIPANT	\N	PRESENT	0
307167	307136	19619A	PARTICIPANT	\N	PRESENT	0
307168	307136	14267Y	PARTICIPANT	\N	PRESENT	0
307169	307136	19369B	PARTICIPANT	\N	PRESENT	0
307170	307136	14221J	PARTICIPANT	\N	PRESENT	0
307171	307136	08009T	PARTICIPANT	\N	PRESENT	0
307172	307136	19479G	PARTICIPANT	\N	PRESENT	0
307173	307136	19441R	PARTICIPANT	\N	PRESENT	0
307175	307136	19583F	PARTICIPANT	\N	PRESENT	0
307177	307136	19671E	PARTICIPANT	\N	PRESENT	0
307178	307136	19747H	PARTICIPANT	\N	PRESENT	0
307179	307136	14329V	PARTICIPANT	\N	PRESENT	0
307180	307136	14357A	PARTICIPANT	\N	PRESENT	0
307181	307136	19675J	PARTICIPANT	\N	PRESENT	0
307182	307136	19383Y	PARTICIPANT	\N	PRESENT	0
307183	307136	19737F	PARTICIPANT	\N	PRESENT	0
307184	307136	07034Q	PARTICIPANT	\N	PRESENT	0
307185	307136	08034U	PARTICIPANT	\N	PRESENT	0
307186	307136	11103C	PARTICIPANT	\N	PRESENT	0
307187	307136	11090Q	PARTICIPANT	\N	PRESENT	0
307188	307136	87003B	PARTICIPANT	\N	PRESENT	0
307189	307136	04033B	PARTICIPANT	\N	PRESENT	0
307190	307136	98024R	PARTICIPANT	\N	PRESENT	0
307191	307136	14123H	PARTICIPANT	\N	PRESENT	0
307192	307136	14147R	PARTICIPANT	\N	PRESENT	0
307193	307136	14026U	PARTICIPANT	\N	PRESENT	0
307194	307136	19387D	PARTICIPANT	\N	PRESENT	0
307195	307136	08068F	PARTICIPANT	\N	PRESENT	0
307196	307136	14109K	PARTICIPANT	\N	PRESENT	0
307197	307136	08038Y	PARTICIPANT	\N	PRESENT	0
307198	307136	19543W	PARTICIPANT	\N	PRESENT	0
307199	307136	19701S	PARTICIPANT	\N	PRESENT	0
307200	307136	19762G	PARTICIPANT	\N	PRESENT	0
307201	307136	04049K	PARTICIPANT	\N	PRESENT	0
307202	307136	14105F	PARTICIPANT	\N	PRESENT	0
307203	307136	04088S	PARTICIPANT	\N	PRESENT	0
307204	307136	04097T	PARTICIPANT	\N	PRESENT	0
307205	307136	08039A	PARTICIPANT	\N	PRESENT	0
307206	307136	19703U	PARTICIPANT	\N	PRESENT	0
307207	307136	19447X	PARTICIPANT	\N	PRESENT	0
307208	307136	14033T	PARTICIPANT	\N	PRESENT	0
307209	307136	19573D	PARTICIPANT	\N	PRESENT	0
307210	307136	01057W	PARTICIPANT	\N	PRESENT	0
307211	307136	19693L	PARTICIPANT	\N	PRESENT	0
307212	307136	11012A	PARTICIPANT	\N	PRESENT	0
307213	307136	08031R	PARTICIPANT	\N	PRESENT	0
307214	307136	19657G	PARTICIPANT	\N	PRESENT	0
307215	307136	08028W	PARTICIPANT	\N	PRESENT	0
307216	307136	19687N	PARTICIPANT	\N	PRESENT	0
307217	307136	14195A	PARTICIPANT	\N	PRESENT	0
307218	307136	11110B	PARTICIPANT	\N	PRESENT	0
307219	307136	01062T	PARTICIPANT	\N	PRESENT	0
307220	307136	14187A	PARTICIPANT	\N	PRESENT	0
307221	307136	19569H	PARTICIPANT	\N	PRESENT	0
307222	307136	11067R	PARTICIPANT	\N	PRESENT	0
307223	307136	14191V	PARTICIPANT	\N	PRESENT	0
307224	307136	14053L	PARTICIPANT	\N	PRESENT	0
307225	307136	19725B	PARTICIPANT	\N	PRESENT	0
307226	307136	08069G	PARTICIPANT	\N	PRESENT	0
307227	307136	14119M	PARTICIPANT	\N	PRESENT	0
307228	307136	14103D	PARTICIPANT	\N	PRESENT	0
307229	307136	14073Q	PARTICIPANT	\N	PRESENT	0
307230	307136	14079W	PARTICIPANT	\N	PRESENT	0
307231	307136	19637C	PARTICIPANT	\N	PRESENT	0
307232	307136	95062K	PARTICIPANT	\N	PRESENT	0
307233	307136	14063N	PARTICIPANT	\N	PRESENT	0
307234	307136	19749K	PARTICIPANT	\N	PRESENT	0
307235	307136	14179A	PARTICIPANT	\N	PRESENT	0
307236	307136	11048N	PARTICIPANT	\N	PRESENT	0
307237	307136	14021P	PARTICIPANT	\N	PRESENT	0
307238	307136	14081Q	PARTICIPANT	\N	PRESENT	0
307244	307048	14327T	PARTICIPANT	\N	PRESENT	0
307245	307048	14331P	PARTICIPANT	\N	PRESENT	0
307247	307048	04071H	PARTICIPANT	\N	PRESENT	0
307248	307048	11048N	PARTICIPANT	\N	PRESENT	0
307249	307048	19479G	PARTICIPANT	\N	PRESENT	0
307250	307048	19711U	PARTICIPANT	\N	PRESENT	0
307251	307048	19531S	PARTICIPANT	\N	PRESENT	0
307252	307048	01057W	PARTICIPANT	\N	PRESENT	0
307253	307048	12016W	PARTICIPANT	\N	PRESENT	0
307254	307048	11074Q	PRESIDENT	0	PRESENT	0
307255	307048	19667J	PARTICIPANT	\N	PRESENT	0
307256	307048	89017R	PARTICIPANT	\N	PRESENT	0
307257	307048	19671E	PARTICIPANT	\N	PRESENT	0
307258	307048	11040E	PARTICIPANT	\N	PRESENT	0
307259	307048	11012A	PARTICIPANT	\N	PRESENT	0
307260	307048	14085U	PARTICIPANT	\N	PRESENT	0
307261	307048	19349W	PARTICIPANT	\N	PRESENT	0
307262	307048	19741B	PARTICIPANT	\N	PRESENT	0
307263	307048	08010L	PARTICIPANT	\N	PRESENT	0
307264	307048	99004R	PARTICIPANT	\N	PRESENT	0
307265	307048	14253S	PARTICIPANT	\N	PRESENT	0
307266	307048	04061F	PARTICIPANT	\N	PRESENT	0
307267	307136	18083K	PARTICIPANT	\N	PRESENT	0
307268	307136	11097X	PARTICIPANT	\N	PRESENT	0
307269	307136	08020N	PARTICIPANT	\N	PRESENT	0
307270	307048	95041E	PARTICIPANT	\N	PRESENT	0
307271	307048	08011M	PARTICIPANT	\N	PRESENT	0
307272	307136	19727D	PARTICIPANT	\N	PRESENT	0
307273	307136	14030Q	PARTICIPANT	\N	PRESENT	0
307274	307136	95030B	PARTICIPANT	\N	PRESENT	0
307275	307048	19647E	PARTICIPANT	\N	PRESENT	0
307276	307048	14173T	PARTICIPANT	\N	PRESENT	0
307277	307136	19563B	PARTICIPANT	\N	PRESENT	0
307278	307136	19659J	PARTICIPANT	\N	PRESENT	0
307279	307136	08055A	PARTICIPANT	\N	PRESENT	0
307280	307048	14034U	PARTICIPANT	\N	PRESENT	0
307281	307048	14083S	PARTICIPANT	\N	PRESENT	0
307282	307048	08034U	PARTICIPANT	\N	PRESENT	0
307283	307136	19415P	PARTICIPANT	\N	PRESENT	0
307284	307136	19681G	PARTICIPANT	\N	PRESENT	0
307286	307136	11101A	PARTICIPANT	\N	PRESENT	0
307287	307136	19551W	PARTICIPANT	\N	PRESENT	0
307288	307136	11043H	PARTICIPANT	\N	PRESENT	0
307289	307136	19553Y	PARTICIPANT	\N	PRESENT	0
307291	307048	19545Y	PARTICIPANT	\N	PRESENT	0
307751	307750	08012N	PARTICIPANT	\N	PRESENT	0
307752	307750	19758L	PARTICIPANT	\N	PRESENT	0
307753	307750	19611R	PARTICIPANT	\N	PRESENT	0
307754	307750	11043H	PARTICIPANT	\N	PRESENT	0
307756	307755	08012N	PARTICIPANT	\N	PRESENT	0
307757	307755	19758L	PARTICIPANT	\N	PRESENT	0
307758	307755	19611R	PARTICIPANT	\N	PRESENT	0
307760	307759	08012N	PARTICIPANT	\N	PRESENT	0
307761	307759	19758L	PARTICIPANT	\N	PRESENT	0
307764	307763	14215L	PARTICIPANT	\N	PRESENT	0
307765	307763	14001X	PARTICIPANT	\N	PRESENT	0
318036	317764	08031R	PARTICIPANT	\N	PRESENT	0
318039	317764	04059M	PARTICIPANT	\N	PRESENT	0
318041	317764	19611R	PARTICIPANT	\N	PRESENT	0
318042	317764	19749K	PARTICIPANT	\N	PRESENT	0
318045	318044	08039A	PARTICIPANT	\N	PRESENT	0
318046	318044	19399H	PARTICIPANT	\N	PRESENT	0
318048	318047	08039A	PARTICIPANT	\N	PRESENT	0
318049	318047	19399H	PARTICIPANT	\N	PRESENT	0
327668	327667	14026U	PARTICIPANT	\N	PRESENT	0
327670	327669	14026U	PARTICIPANT	\N	PRESENT	0
327994	321323	19729F	PARTICIPANT	\N	PRESENT	0
327995	321323	19762G	PARTICIPANT	\N	PRESENT	0
327996	321323	04008A	PARTICIPANT	\N	PRESENT	0
327997	321323	08018U	PARTICIPANT	\N	PRESENT	0
327998	321323	11080N	PARTICIPANT	\N	PRESENT	0
327999	321323	14029X	PARTICIPANT	\N	PRESENT	0
328000	321323	19573D	PARTICIPANT	\N	PRESENT	0
328001	321323	14059S	PARTICIPANT	\N	PRESENT	0
328002	321323	92040Q	PARTICIPANT	\N	PRESENT	0
328003	321323	08015R	PARTICIPANT	\N	PRESENT	0
328004	321323	07033P	PARTICIPANT	\N	PRESENT	0
328005	321323	08062Y	PARTICIPANT	\N	PRESENT	0
328006	321323	11097X	PARTICIPANT	\N	PRESENT	0
328007	321323	11056N	PARTICIPANT	\N	PRESENT	0
328008	321323	19565D	PARTICIPANT	\N	PRESENT	0
328009	321323	11040E	PARTICIPANT	\N	PRESENT	0
328010	321323	19621T	PARTICIPANT	\N	PRESENT	0
328011	321323	19593H	PARTICIPANT	\N	PRESENT	0
328012	321323	19695N	PARTICIPANT	\N	PRESENT	0
328013	321323	19687N	PARTICIPANT	\N	PRESENT	0
328014	321323	11010L	PARTICIPANT	\N	PRESENT	0
328015	321323	04059M	PARTICIPANT	\N	PRESENT	0
328016	321323	11027H	PARTICIPANT	\N	PRESENT	0
328017	321323	11043H	PARTICIPANT	\N	PRESENT	0
328018	321323	11074Q	PARTICIPANT	\N	PRESENT	0
328019	321323	14159V	PARTICIPANT	\N	PRESENT	0
328020	321323	14119M	PARTICIPANT	\N	PRESENT	0
328021	321323	98035U	PARTICIPANT	\N	PRESENT	0
328022	321323	08055A	PARTICIPANT	\N	PRESENT	0
328023	321323	14229S	PARTICIPANT	\N	PRESENT	0
328024	321323	04035D	PARTICIPANT	\N	PRESENT	0
328025	321323	08052W	PARTICIPANT	\N	PRESENT	0
328026	321323	95041E	PARTICIPANT	\N	PRESENT	0
327992	321323	19507S	PARTICIPANT	\N	PRESENT	0
327993	321323	11049P	PARTICIPANT	\N	PRESENT	0
328027	321323	01028R	PARTICIPANT	\N	PRESENT	0
328028	321323	08068F	PARTICIPANT	\N	PRESENT	0
328029	321323	19705W	PARTICIPANT	\N	PRESENT	0
328030	321323	14051J	PARTICIPANT	\N	PRESENT	0
328031	321323	14151M	PARTICIPANT	\N	PRESENT	0
328032	321323	19715Y	PARTICIPANT	\N	PRESENT	0
328033	321323	12016W	PARTICIPANT	\N	PRESENT	0
328034	321323	19599P	PARTICIPANT	\N	PRESENT	0
328035	321323	08010L	PARTICIPANT	\N	PRESENT	0
328036	321323	14225N	PARTICIPANT	\N	PRESENT	0
328037	321323	08045X	PARTICIPANT	\N	PRESENT	0
328038	321323	17637T	PARTICIPANT	\N	PRESENT	0
328039	321323	11033F	PARTICIPANT	\N	PRESENT	0
328040	321323	19760E	PARTICIPANT	\N	PRESENT	0
328041	321323	19711U	PARTICIPANT	\N	PRESENT	0
328042	321323	19669L	PARTICIPANT	\N	PRESENT	0
328043	321323	98018T	PARTICIPANT	\N	PRESENT	0
328044	321323	08038Y	PARTICIPANT	\N	PRESENT	0
328045	321323	11090Q	PARTICIPANT	\N	PRESENT	0
328046	321323	08060W	PARTICIPANT	\N	PRESENT	0
328047	321323	80013X	PARTICIPANT	\N	PRESENT	0
328048	321323	11045K	PARTICIPANT	\N	PRESENT	0
328049	321323	19649G	PARTICIPANT	\N	PRESENT	0
328050	321323	14157T	PARTICIPANT	\N	PRESENT	0
328051	321323	14071N	PARTICIPANT	\N	PRESENT	0
328052	321323	14065Q	PARTICIPANT	\N	PRESENT	0
328053	321323	04033B	PARTICIPANT	\N	PRESENT	0
328054	321323	19421M	PARTICIPANT	\N	PRESENT	0
328055	321323	14215L	PARTICIPANT	\N	PRESENT	0
328056	321323	01062T	PARTICIPANT	\N	PRESENT	0
328057	321323	14028W	PARTICIPANT	\N	PRESENT	0
328058	321323	11066Q	PARTICIPANT	\N	PRESENT	0
328059	321323	14069U	PARTICIPANT	\N	PRESENT	0
328060	321323	08043V	PARTICIPANT	\N	PRESENT	0
328061	321323	11104D	PARTICIPANT	\N	PRESENT	0
328062	321323	08012N	PARTICIPANT	\N	PRESENT	0
328063	321323	14085U	PARTICIPANT	\N	PRESENT	0
328064	321323	08058D	PARTICIPANT	\N	PRESENT	0
328065	321323	08053X	PARTICIPANT	\N	PRESENT	0
328066	321323	11115U	PARTICIPANT	\N	PRESENT	0
328068	321323	19525U	PARTICIPANT	\N	PRESENT	0
328069	321323	14257W	PARTICIPANT	\N	PRESENT	0
328071	321323	14081Q	PARTICIPANT	\N	PRESENT	0
328072	321323	19725B	PARTICIPANT	\N	PRESENT	0
328073	321323	04049K	PARTICIPANT	\N	PRESENT	0
328074	321323	14207L	PARTICIPANT	\N	PRESENT	0
328075	321323	97011G	PARTICIPANT	\N	PRESENT	0
328076	321323	19333N	PARTICIPANT	\N	PRESENT	0
328077	321323	14213J	PARTICIPANT	\N	PRESENT	0
328078	321323	14001X	PARTICIPANT	\N	PRESENT	0
328079	321323	19768N	PARTICIPANT	\N	PRESENT	0
328080	321323	19549D	PARTICIPANT	\N	PRESENT	0
328081	321323	14227Q	PARTICIPANT	\N	PRESENT	0
328082	321323	19683J	PARTICIPANT	\N	PRESENT	0
328084	321323	14061L	PARTICIPANT	\N	PRESENT	0
328085	321323	11109J	PARTICIPANT	\N	PRESENT	0
328086	321323	19701S	PARTICIPANT	\N	PRESENT	0
328087	321323	19295A	PARTICIPANT	\N	PRESENT	0
328089	321323	11054L	PARTICIPANT	\N	PRESENT	0
328090	321323	19413M	PARTICIPANT	\N	PRESENT	0
328091	321323	19503N	PARTICIPANT	\N	PRESENT	0
328092	321323	19367Y	PARTICIPANT	\N	PRESENT	0
328093	321323	19591F	PARTICIPANT	\N	PRESENT	0
328094	321323	11067R	PARTICIPANT	\N	PRESENT	0
328095	321323	10006L	PARTICIPANT	\N	PRESENT	0
328096	321323	19527W	PARTICIPANT	\N	PRESENT	0
328097	321323	19533U	PARTICIPANT	\N	PRESENT	0
328098	321323	14063N	PARTICIPANT	\N	PRESENT	0
328099	321323	05012A	PARTICIPANT	\N	PRESENT	0
328100	321323	14109K	PARTICIPANT	\N	PRESENT	0
328101	321323	19631V	PARTICIPANT	\N	PRESENT	0
328102	321323	11041F	PARTICIPANT	\N	PRESENT	0
328103	321323	14169X	PARTICIPANT	\N	PRESENT	0
328105	321323	95067Q	PARTICIPANT	\N	PRESENT	0
328106	321323	95037J	PARTICIPANT	\N	PRESENT	0
328107	321323	98029W	PARTICIPANT	\N	PRESENT	0
328108	321323	04071H	PARTICIPANT	\N	PRESENT	0
328109	321323	11083R	PARTICIPANT	\N	PRESENT	0
328110	321323	19543W	PARTICIPANT	\N	PRESENT	0
328111	321323	19671E	PARTICIPANT	\N	PRESENT	0
328112	321323	19651A	PARTICIPANT	\N	PRESENT	0
328113	321323	19581D	PARTICIPANT	\N	PRESENT	0
328114	321323	19637C	PARTICIPANT	\N	PRESENT	0
328115	321323	19349W	PARTICIPANT	\N	PRESENT	0
328116	321323	19269X	PARTICIPANT	\N	PRESENT	0
328117	321323	08073C	PARTICIPANT	\N	PRESENT	0
328118	321323	08021P	PARTICIPANT	\N	PRESENT	0
328119	321323	19697Q	PARTICIPANT	\N	PRESENT	0
328120	321323	19659J	PARTICIPANT	\N	PRESENT	0
328121	321323	14039A	PARTICIPANT	\N	PRESENT	0
328122	321323	08024S	PARTICIPANT	\N	PRESENT	0
328123	321323	19447X	PARTICIPANT	\N	PRESENT	0
328124	321323	19301E	PARTICIPANT	\N	PRESENT	0
328125	321323	19782L	PARTICIPANT	\N	PRESENT	0
328126	321323	19545Y	PARTICIPANT	\N	PRESENT	0
328128	321323	19585H	PARTICIPANT	\N	PRESENT	0
328129	321323	19647E	PARTICIPANT	\N	PRESENT	0
328130	321323	19663E	PARTICIPANT	\N	PRESENT	0
328131	321323	19583F	PARTICIPANT	\N	PRESENT	0
328133	321323	04057K	PARTICIPANT	\N	PRESENT	0
328135	321323	14251Q	PARTICIPANT	\N	PRESENT	0
328136	321323	14093U	PARTICIPANT	\N	PRESENT	0
328138	321323	11064N	PARTICIPANT	\N	PRESENT	0
328139	321323	17589D	PARTICIPANT	\N	PRESENT	0
328140	321323	11012A	PARTICIPANT	\N	PRESENT	0
328141	321323	08051V	PARTICIPANT	\N	PRESENT	0
328142	321323	88008L	PARTICIPANT	\N	PRESENT	0
328143	321323	04043D	PARTICIPANT	\N	PRESENT	0
328144	321323	08031R	PARTICIPANT	\N	PRESENT	0
328146	321323	19629C	PARTICIPANT	\N	PRESENT	0
328147	321323	19563B	PARTICIPANT	\N	PRESENT	0
328148	321323	98022P	PARTICIPANT	\N	PRESENT	0
328149	321323	14241N	PARTICIPANT	\N	PRESENT	0
328150	321323	19719D	PARTICIPANT	\N	PRESENT	0
328151	321323	19289C	PARTICIPANT	\N	PRESENT	0
328152	321323	19387D	PARTICIPANT	\N	PRESENT	0
328153	321323	19347U	PARTICIPANT	\N	PRESENT	0
328154	321323	14235Q	PARTICIPANT	\N	PRESENT	0
328155	321323	11077T	PARTICIPANT	\N	PRESENT	0
328156	321323	14231L	PARTICIPANT	\N	PRESENT	0
328157	321323	14179A	PARTICIPANT	\N	PRESENT	0
328158	321323	08044W	PARTICIPANT	\N	PRESENT	0
328159	321323	19369B	PARTICIPANT	\N	PRESENT	0
312479	309271	19527W	PARTICIPANT	\N	PRESENT	0
312480	309271	14063N	PARTICIPANT	\N	PRESENT	0
312481	309271	19549D	PARTICIPANT	\N	PRESENT	0
312552	309271	11026G	PARTICIPANT	\N	PRESENT	0
312484	309271	11067R	PARTICIPANT	\N	PRESENT	0
312485	309271	08048B	PARTICIPANT	\N	PRESENT	0
312486	309271	19329S	PARTICIPANT	\N	PRESENT	0
312487	309271	11072N	PARTICIPANT	\N	PRESENT	0
312488	309271	19413M	PARTICIPANT	\N	PRESENT	0
312489	309271	19251M	PARTICIPANT	\N	PRESENT	0
312490	309271	14030Q	PARTICIPANT	\N	PRESENT	0
312491	309271	19713W	PARTICIPANT	\N	PRESENT	0
312492	309271	14275Y	PARTICIPANT	\N	PRESENT	0
312493	309271	14179A	PARTICIPANT	\N	PRESENT	0
312494	309271	19441R	PARTICIPANT	\N	PRESENT	0
312495	309271	19479G	PARTICIPANT	\N	PRESENT	0
312496	309271	14219Q	PARTICIPANT	\N	PRESENT	0
312497	309271	04071H	PARTICIPANT	\N	PRESENT	0
312498	309271	14042U	PARTICIPANT	\N	PRESENT	0
312499	309271	19569H	PARTICIPANT	\N	PRESENT	0
312500	309271	08056B	PARTICIPANT	\N	PRESENT	0
312501	309271	19735D	PARTICIPANT	\N	PRESENT	0
312502	309271	16685X	PARTICIPANT	\N	PRESENT	0
312503	309271	19619A	PARTICIPANT	\N	PRESENT	0
312504	309271	19721W	PARTICIPANT	\N	PRESENT	0
312505	309271	14205J	PARTICIPANT	\N	PRESENT	0
312506	309271	19699S	PARTICIPANT	\N	PRESENT	0
312507	309271	11115U	PARTICIPANT	\N	PRESENT	0
312508	309271	08009T	PARTICIPANT	\N	PRESENT	0
312509	309271	11053K	PARTICIPANT	\N	PRESENT	0
312510	309271	19611R	PARTICIPANT	\N	PRESENT	0
312511	309271	19511N	PARTICIPANT	\N	PRESENT	0
312512	309271	19691J	PARTICIPANT	\N	PRESENT	0
312513	309271	19369B	PARTICIPANT	\N	PRESENT	0
312514	309271	01034P	PARTICIPANT	\N	PRESENT	0
312515	309271	08044W	PARTICIPANT	\N	PRESENT	0
312516	309271	19543W	PARTICIPANT	\N	PRESENT	0
312517	309271	14231L	PARTICIPANT	\N	PRESENT	0
312518	309271	04061F	PARTICIPANT	\N	PRESENT	0
312519	309271	14267Y	PARTICIPANT	\N	PRESENT	0
312521	309271	14103D	PARTICIPANT	\N	PRESENT	0
312522	309271	19335Q	PARTICIPANT	\N	PRESENT	0
312523	309271	14083S	PARTICIPANT	\N	PRESENT	0
312524	309271	19749K	PARTICIPANT	\N	PRESENT	0
312525	309271	19521Q	PARTICIPANT	\N	PRESENT	0
312526	309271	11070L	PARTICIPANT	\N	PRESENT	0
312527	309271	07004J	PARTICIPANT	\N	PRESENT	0
312528	309271	14255U	PARTICIPANT	\N	PRESENT	0
312529	309271	11085T	PARTICIPANT	\N	PRESENT	0
312530	309271	04040A	PARTICIPANT	\N	PRESENT	0
312531	309271	01025N	PARTICIPANT	\N	PRESENT	0
312532	309271	01024M	PARTICIPANT	\N	PRESENT	0
312533	309271	14327T	PARTICIPANT	\N	PRESENT	0
312534	309271	01043Q	PARTICIPANT	\N	PRESENT	0
312535	309271	14277B	PARTICIPANT	\N	PRESENT	0
312536	309271	14221J	PARTICIPANT	\N	PRESENT	0
312537	309271	19739H	PARTICIPANT	\N	PRESENT	0
312538	309271	19745F	PARTICIPANT	\N	PRESENT	0
312539	309271	19768N	PARTICIPANT	\N	PRESENT	0
312549	309271	19631V	PARTICIPANT	\N	PRESENT	0
312541	309271	08018U	PARTICIPANT	\N	PRESENT	0
312542	309271	01058X	PARTICIPANT	\N	PRESENT	0
312543	309271	04042C	PARTICIPANT	\N	PRESENT	0
312544	309271	14135M	PARTICIPANT	\N	PRESENT	0
312550	309271	19689Q	PARTICIPANT	\N	PRESENT	0
312551	309271	11041F	PARTICIPANT	\N	PRESENT	0
312553	309271	14085U	PARTICIPANT	\N	PRESENT	0
312554	309271	14169X	PARTICIPANT	\N	PRESENT	0
312567	309271	11065P	PARTICIPANT	\N	PRESENT	0
312558	309271	14089Y	PARTICIPANT	\N	PRESENT	0
312563	309271	04089T	PARTICIPANT	\N	PRESENT	0
312870	309272	14034U	PARTICIPANT	\N	PRESENT	0
312871	309272	01024M	PARTICIPANT	\N	PRESENT	0
312872	309272	04047H	PARTICIPANT	\N	PRESENT	0
313941	305897	17637T	PARTICIPANT	\N	EXCUSE	0
313942	305897	19711U	PARTICIPANT	\N	PRESENT	0
313955	305897	11097X	PARTICIPANT	\N	PRESENT	0
313956	305897	08024S	PARTICIPANT	\N	PRESENT	0
313957	305897	19551W	PARTICIPANT	\N	PRESENT	0
313968	305897	08045X	PARTICIPANT	\N	PRESENT	0
313985	305897	08062Y	PARTICIPANT	\N	EXCUSE	0
313987	305897	01028R	PARTICIPANT	\N	PRESENT	0
314030	305897	19651A	PARTICIPANT	\N	PRESENT	0
314031	305897	19399H	PARTICIPANT	\N	PRESENT	0
314032	305897	19713W	PARTICIPANT	\N	PRESENT	0
314182	314180	11074Q	PARTICIPANT	\N	PRESENT	0
314185	314184	88008L	PARTICIPANT	\N	PRESENT	0
314186	314184	11012A	PARTICIPANT	\N	PRESENT	0
314191	314190	11026G	PARTICIPANT	\N	PRESENT	0
314193	314192	14030Q	PARTICIPANT	\N	PRESENT	0
314194	314192	08017T	PARTICIPANT	\N	PRESENT	0
314195	314192	19693L	PARTICIPANT	\N	PRESENT	0
314196	314192	14249W	PARTICIPANT	\N	PRESENT	0
314197	314192	11045K	PARTICIPANT	\N	PRESENT	0
314198	314192	14109K	PARTICIPANT	\N	PRESENT	0
314199	314192	11067R	PARTICIPANT	\N	PRESENT	0
314200	314192	19715Y	PARTICIPANT	\N	PRESENT	0
314201	314192	08043V	PARTICIPANT	\N	PRESENT	0
314202	314192	19701S	PARTICIPANT	\N	PRESENT	0
314203	314192	18083K	PARTICIPANT	\N	PRESENT	0
314204	314192	19731Y	PARTICIPANT	\N	PRESENT	0
314205	314192	08031R	PARTICIPANT	\N	PRESENT	0
314206	314192	07029T	PARTICIPANT	\N	PRESENT	0
314207	314192	19621T	PARTICIPANT	\N	PRESENT	0
314367	314364	11090Q	PARTICIPANT	\N	PRESENT	0
314368	314364	04043D	PARTICIPANT	\N	PRESENT	0
314369	314364	19565D	PARTICIPANT	\N	PRESENT	0
314370	314364	14033T	PARTICIPANT	\N	PRESENT	0
314371	314364	14257W	PARTICIPANT	\N	PRESENT	0
314372	314364	14135M	PARTICIPANT	\N	PRESENT	0
314373	314364	19515S	PARTICIPANT	\N	PRESENT	0
314374	314364	14231L	PARTICIPANT	\N	PRESENT	0
314385	314384	98029W	PARTICIPANT	\N	PRESENT	0
314645	314348	08056B	PARTICIPANT	\N	PRESENT	0
314646	314348	04089T	PARTICIPANT	\N	PRESENT	0
314647	314348	14053L	PARTICIPANT	\N	PRESENT	0
314648	314348	14221J	PARTICIPANT	\N	PRESENT	0
314649	314348	19739H	PARTICIPANT	\N	PRESENT	0
314654	314348	19745F	PARTICIPANT	\N	PRESENT	0
314651	314348	19335Q	PARTICIPANT	\N	PRESENT	0
314652	314348	14193X	PARTICIPANT	\N	PRESENT	0
314653	314348	14249W	PARTICIPANT	\N	PRESENT	0
314655	314348	14215L	PARTICIPANT	\N	PRESENT	0
314656	314348	14255U	PARTICIPANT	\N	PRESENT	0
314657	314348	05012A	PARTICIPANT	\N	PRESENT	0
314658	314348	14034U	PARTICIPANT	\N	PRESENT	0
314659	314348	19533U	PARTICIPANT	\N	PRESENT	0
314660	314348	19593H	PARTICIPANT	\N	PRESENT	0
314661	314348	98023Q	PARTICIPANT	\N	PRESENT	0
314662	314348	17779H	PARTICIPANT	\N	PRESENT	0
314663	314348	01060R	PARTICIPANT	\N	PRESENT	0
314664	314348	10006L	PARTICIPANT	\N	PRESENT	0
314665	314348	07034Q	PARTICIPANT	\N	PRESENT	0
314666	314348	11097X	PARTICIPANT	\N	PRESENT	0
314667	314348	04018C	PARTICIPANT	\N	PRESENT	0
314668	314348	19701S	PARTICIPANT	\N	PRESENT	0
314669	314348	19762G	PARTICIPANT	\N	PRESENT	0
314670	314348	01058X	PARTICIPANT	\N	PRESENT	0
314671	314348	97011G	PARTICIPANT	\N	PRESENT	0
314672	314348	19675J	PARTICIPANT	\N	PRESENT	0
314673	314348	11103C	PARTICIPANT	\N	PRESENT	0
314674	314348	04045F	PARTICIPANT	\N	PRESENT	0
314675	314348	14331P	PARTICIPANT	\N	PRESENT	0
314676	314348	19269X	PARTICIPANT	\N	PRESENT	0
314677	314348	04061F	PARTICIPANT	\N	PRESENT	0
314678	314348	14173T	PARTICIPANT	\N	PRESENT	0
314700	314348	19651A	PARTICIPANT	\N	PRESENT	0
314680	314348	14213J	PARTICIPANT	\N	PRESENT	0
314681	314348	19569H	PARTICIPANT	\N	PRESENT	0
314682	314348	14329V	PARTICIPANT	\N	PRESENT	0
314683	314348	11085T	PARTICIPANT	\N	PRESENT	0
314684	314348	14357A	PARTICIPANT	\N	PRESENT	0
314685	314348	08024S	PARTICIPANT	\N	PRESENT	0
314686	314348	19749K	PARTICIPANT	\N	PRESENT	0
314687	314348	14147R	PARTICIPANT	\N	PRESENT	0
314688	314348	04057K	PARTICIPANT	\N	PRESENT	0
314689	314348	19531S	PARTICIPANT	\N	PRESENT	0
314690	314348	14111D	PARTICIPANT	\N	PRESENT	0
314691	314348	19581D	PARTICIPANT	\N	PRESENT	0
314692	314348	98050T	PARTICIPANT	\N	PRESENT	0
314693	314348	14059S	PARTICIPANT	\N	PRESENT	0
314698	314348	14265W	PARTICIPANT	\N	PRESENT	0
314695	314348	95067Q	PARTICIPANT	\N	PRESENT	0
314696	314348	14135M	PARTICIPANT	\N	PRESENT	0
314697	314348	19709B	PARTICIPANT	\N	PRESENT	0
314699	314348	02002K	PARTICIPANT	\N	PRESENT	0
314701	314348	11012A	PARTICIPANT	\N	PRESENT	0
314702	314348	14105F	PARTICIPANT	\N	PRESENT	0
314703	314348	19695N	PARTICIPANT	\N	PRESENT	0
317765	309290	08069G	PARTICIPANT	\N	PRESENT	0
317766	309290	14173T	PARTICIPANT	\N	PRESENT	0
317561	316891	96004D	PRESIDENT	0	PRESENT	0
317562	316891	14053L	PARTICIPANT	\N	PRESENT	0
317563	316891	19333N	PARTICIPANT	\N	PRESENT	0
317564	316891	14097Y	PARTICIPANT	\N	PRESENT	0
317565	316891	14331P	PARTICIPANT	\N	PRESENT	0
317566	316891	04035D	PARTICIPANT	\N	PRESENT	0
317567	316891	12041X	PARTICIPANT	\N	PRESENT	0
317568	316891	19569H	PARTICIPANT	\N	PRESENT	0
317569	316891	04034C	PARTICIPANT	\N	PRESENT	0
317570	316891	01057W	PARTICIPANT	\N	PRESENT	0
317571	316891	01058X	PARTICIPANT	\N	PRESENT	0
317572	316891	14001X	PARTICIPANT	\N	PRESENT	0
317573	316891	01060R	PARTICIPANT	\N	PRESENT	0
317574	316891	08043V	PARTICIPANT	\N	PRESENT	0
317575	316891	14221J	PARTICIPANT	\N	PRESENT	0
317576	316891	14089Y	PARTICIPANT	\N	PRESENT	0
317577	316891	11040E	PARTICIPANT	\N	PRESENT	0
317578	316891	14205J	PARTICIPANT	\N	PRESENT	0
317579	316891	19507S	PARTICIPANT	\N	PRESENT	0
317580	316891	19709B	PARTICIPANT	\N	PRESENT	0
317581	316891	98050T	PARTICIPANT	\N	PRESENT	0
317582	316891	04097T	PARTICIPANT	\N	PRESENT	0
317767	309290	14199E	PARTICIPANT	\N	PRESENT	0
317768	309290	01060R	PARTICIPANT	\N	PRESENT	0
317769	309290	19731Y	PARTICIPANT	\N	PRESENT	0
317774	309290	04088S	PARTICIPANT	\N	PRESENT	0
317775	309290	19507S	PARTICIPANT	\N	PRESENT	0
317776	309290	19741B	PARTICIPANT	\N	PRESENT	0
317777	309290	87003B	PARTICIPANT	\N	PRESENT	0
317778	309290	14223L	PARTICIPANT	\N	PRESENT	0
317779	309290	07034Q	PARTICIPANT	\N	PRESENT	0
317780	309290	14069U	PARTICIPANT	\N	PRESENT	0
317781	309290	14331P	PARTICIPANT	\N	PRESENT	0
317782	309290	19679N	PARTICIPANT	\N	PRESENT	0
317783	309290	19711U	PARTICIPANT	\N	PRESENT	0
317784	309290	19701S	PARTICIPANT	\N	PRESENT	0
317785	309290	97011G	PARTICIPANT	\N	PRESENT	0
317786	309290	11103C	PARTICIPANT	\N	PRESENT	0
317787	309290	19675J	PARTICIPANT	\N	PRESENT	0
317788	309290	08010L	PARTICIPANT	\N	PRESENT	0
317789	309290	95062K	PARTICIPANT	\N	PRESENT	0
317790	309290	04097T	PARTICIPANT	\N	PRESENT	0
317791	309290	14259Y	PARTICIPANT	\N	PRESENT	0
317792	309290	14105F	PARTICIPANT	\N	PRESENT	0
317793	309290	95030B	PARTICIPANT	\N	PRESENT	0
317797	309290	14211G	PARTICIPANT	\N	PRESENT	0
317795	309290	14169X	PARTICIPANT	\N	PRESENT	0
317796	309290	19415P	PARTICIPANT	\N	PRESENT	0
317798	309290	14115H	PARTICIPANT	\N	PRESENT	0
317799	309290	08018U	PARTICIPANT	\N	PRESENT	0
317800	309290	08062Y	PARTICIPANT	\N	PRESENT	0
317801	309290	18083K	PARTICIPANT	\N	PRESENT	0
317802	309290	19703U	PARTICIPANT	\N	PRESENT	0
317803	309290	19673G	PARTICIPANT	\N	PRESENT	0
317807	309290	11049P	PARTICIPANT	\N	PRESENT	0
317805	309290	19667J	PARTICIPANT	\N	PRESENT	0
317806	309290	19729F	PARTICIPANT	\N	PRESENT	0
317808	309290	04043D	PARTICIPANT	\N	PRESENT	0
317809	309290	99004R	PARTICIPANT	\N	PRESENT	0
317810	309290	04008A	PARTICIPANT	\N	PRESENT	0
317811	309290	98024R	PARTICIPANT	\N	PRESENT	0
317812	309290	11101A	PARTICIPANT	\N	PRESENT	0
317813	309290	19447X	PARTICIPANT	\N	PRESENT	0
317814	309290	19573D	PARTICIPANT	\N	PRESENT	0
317815	309290	14237S	PARTICIPANT	\N	PRESENT	0
317816	309290	17637T	PARTICIPANT	\N	PRESENT	0
317817	309290	14157T	PARTICIPANT	\N	PRESENT	0
317818	309290	96004D	PARTICIPANT	\N	PRESENT	0
317819	309290	01058X	PARTICIPANT	\N	PRESENT	0
317820	309290	11031D	PARTICIPANT	\N	PRESENT	0
317821	309290	19758L	PARTICIPANT	\N	PRESENT	0
317822	309290	14123H	PARTICIPANT	\N	PRESENT	0
317823	309290	14235Q	PARTICIPANT	\N	PRESENT	0
317824	309290	04042C	PARTICIPANT	\N	PRESENT	0
317825	309290	19593H	PARTICIPANT	\N	PRESENT	0
317826	309290	19695N	PARTICIPANT	\N	PRESENT	0
317827	309290	19760E	PARTICIPANT	\N	PRESENT	0
317828	309290	11033F	PARTICIPANT	\N	PRESENT	0
317829	309290	12041X	PARTICIPANT	\N	PRESENT	0
317830	309290	19643A	PARTICIPANT	\N	PRESENT	0
317831	309290	04085P	PARTICIPANT	\N	PRESENT	0
317832	309290	11040E	PARTICIPANT	\N	PRESENT	0
317833	309290	04038G	PARTICIPANT	\N	PRESENT	0
317834	309290	11056N	PARTICIPANT	\N	PRESENT	0
317835	309290	11043H	PARTICIPANT	\N	PRESENT	0
317836	309290	19515S	PARTICIPANT	\N	PRESENT	0
317837	309290	11080N	PARTICIPANT	\N	PRESENT	0
317838	309290	08024S	PARTICIPANT	\N	PRESENT	0
317839	309290	98029W	PARTICIPANT	\N	PRESENT	0
317840	309290	19697Q	PARTICIPANT	\N	PRESENT	0
317841	309290	14031R	PARTICIPANT	\N	PRESENT	0
317842	309290	19575F	PARTICIPANT	\N	PRESENT	0
317843	309290	14253S	PARTICIPANT	\N	PRESENT	0
317844	309290	11048N	PARTICIPANT	\N	PRESENT	0
317845	309290	19349W	PARTICIPANT	\N	PRESENT	0
317846	309290	19651A	PARTICIPANT	\N	PRESENT	0
317847	309290	19543W	PARTICIPANT	\N	PRESENT	0
317848	309290	92040Q	PARTICIPANT	\N	PRESENT	0
317849	309290	14119M	PARTICIPANT	\N	PRESENT	0
317850	309290	04034C	PARTICIPANT	\N	PRESENT	0
317851	309290	19659J	PARTICIPANT	\N	PRESENT	0
317852	309290	14239U	PARTICIPANT	\N	PRESENT	0
317853	309290	19269X	PARTICIPANT	\N	PRESENT	0
317854	309290	08047A	PARTICIPANT	\N	PRESENT	0
317855	309290	95063L	PARTICIPANT	\N	PRESENT	0
317856	309290	14147R	PARTICIPANT	\N	PRESENT	0
317857	309290	95037J	PARTICIPANT	\N	PRESENT	0
317858	309290	14038Y	PARTICIPANT	\N	PRESENT	0
317859	309290	08061X	PARTICIPANT	\N	PRESENT	0
317860	309290	19467C	PARTICIPANT	\N	PRESENT	0
317861	309290	08019V	PARTICIPANT	\N	PRESENT	0
317862	309290	19717B	PARTICIPANT	\N	PRESENT	0
317863	309290	19629C	PARTICIPANT	\N	PRESENT	0
317864	309290	19693L	PARTICIPANT	\N	PRESENT	0
317865	309290	08049C	PARTICIPANT	\N	PRESENT	0
317866	309290	14034U	PARTICIPANT	\N	PRESENT	0
317867	309290	11012A	PARTICIPANT	\N	PRESENT	0
317868	309290	08048B	PARTICIPANT	\N	PRESENT	0
317869	309290	19289C	PARTICIPANT	\N	PRESENT	0
317870	309290	14265W	PARTICIPANT	\N	PRESENT	0
317871	309290	01057W	PARTICIPANT	\N	PRESENT	0
317872	309290	19253P	PARTICIPANT	\N	PRESENT	0
317873	309290	14135M	PARTICIPANT	\N	PRESENT	0
317874	309290	08031R	PARTICIPANT	\N	PRESENT	0
317875	309290	19553Y	PARTICIPANT	\N	PRESENT	0
317876	309290	98022P	PARTICIPANT	\N	PRESENT	0
317877	309290	07029T	PARTICIPANT	\N	PRESENT	0
317878	309290	19657G	PARTICIPANT	\N	PRESENT	0
317879	309290	19671E	PARTICIPANT	\N	PRESENT	0
317880	309290	19768N	PARTICIPANT	\N	PRESENT	0
317881	309290	19705W	PARTICIPANT	\N	PRESENT	0
317882	309290	14261S	PARTICIPANT	\N	PRESENT	0
317883	309290	98050T	PARTICIPANT	\N	PRESENT	0
317884	309290	19387D	PARTICIPANT	\N	PRESENT	0
317885	309290	08039A	PARTICIPANT	\N	PRESENT	0
317886	309290	14061L	PARTICIPANT	\N	PRESENT	0
317887	309290	11065P	PARTICIPANT	\N	PRESENT	0
317888	309290	14059S	PARTICIPANT	\N	PRESENT	0
317889	309290	17589D	PARTICIPANT	\N	PRESENT	0
317890	309290	19585H	PARTICIPANT	\N	PRESENT	0
317891	309290	19399H	PARTICIPANT	\N	PRESENT	0
317892	309290	11064N	PARTICIPANT	\N	PRESENT	0
317893	309290	14251Q	PARTICIPANT	\N	PRESENT	0
317894	309290	04057K	PARTICIPANT	\N	PRESENT	0
317895	309290	14329V	PARTICIPANT	\N	PRESENT	0
317896	309290	14195A	PARTICIPANT	\N	PRESENT	0
317897	309290	14357A	PARTICIPANT	\N	PRESENT	0
317898	309290	19383Y	PARTICIPANT	\N	PRESENT	0
317899	309290	19762G	PARTICIPANT	\N	PRESENT	0
317900	309290	04059M	PARTICIPANT	\N	PRESENT	0
317901	309290	04018C	PARTICIPANT	\N	PRESENT	0
317902	309290	19621T	PARTICIPANT	\N	PRESENT	0
317903	309290	19413M	PARTICIPANT	\N	PRESENT	0
317904	309290	19367Y	PARTICIPANT	\N	PRESENT	0
317905	309290	19251M	PARTICIPANT	\N	PRESENT	0
317906	309290	19591F	PARTICIPANT	\N	PRESENT	0
317907	309290	04049K	PARTICIPANT	\N	PRESENT	0
317908	309290	19503N	PARTICIPANT	\N	PRESENT	0
317909	309290	19489J	PARTICIPANT	\N	PRESENT	0
317910	309290	14213J	PARTICIPANT	\N	PRESENT	0
317911	309290	14021P	PARTICIPANT	\N	PRESENT	0
317912	309290	19551W	PARTICIPANT	\N	PRESENT	0
317913	309290	19683J	PARTICIPANT	\N	PRESENT	0
317914	309290	14097Y	PARTICIPANT	\N	PRESENT	0
317915	309290	14217N	PARTICIPANT	\N	PRESENT	0
317916	309290	14079W	PARTICIPANT	\N	PRESENT	0
324436	314153	19691J	PARTICIPANT	\N	PRESENT	0
324437	314153	14231L	PARTICIPANT	\N	PRESENT	0
324438	314153	11097X	PARTICIPANT	\N	PRESENT	0
324439	314153	19760E	PARTICIPANT	\N	PRESENT	0
324440	314153	14229S	PARTICIPANT	\N	PRESENT	0
324441	314153	19703U	PARTICIPANT	\N	PRESENT	0
324442	314153	19447X	PARTICIPANT	\N	PRESENT	0
324443	314153	19663E	PARTICIPANT	\N	PRESENT	0
324444	314153	14029X	PARTICIPANT	\N	PRESENT	0
324434	314153	19569H	PARTICIPANT	\N	PRESENT	0
324435	314153	19737F	PARTICIPANT	\N	PRESENT	0
324445	314153	19415P	PARTICIPANT	\N	PRESENT	0
324446	314153	07029T	PARTICIPANT	\N	PRESENT	0
324447	314153	19573D	PARTICIPANT	\N	PRESENT	0
324448	314153	14026U	PARTICIPANT	\N	PRESENT	0
324449	314153	14213J	PARTICIPANT	\N	PRESENT	0
324450	314153	14115H	PARTICIPANT	\N	PRESENT	0
324451	314153	08047A	PARTICIPANT	\N	PRESENT	0
324452	314153	11103C	PARTICIPANT	\N	PRESENT	0
324453	314153	17637T	PARTICIPANT	\N	PRESENT	0
324454	314153	04070G	PARTICIPANT	\N	PRESENT	0
324455	314153	19715Y	PARTICIPANT	\N	PRESENT	0
324456	314153	19295A	PARTICIPANT	\N	PRESENT	0
324457	314153	19693L	PARTICIPANT	\N	PRESENT	0
324458	314153	14239U	PARTICIPANT	\N	PRESENT	0
324459	314153	19413M	PARTICIPANT	\N	PRESENT	0
324460	314153	19697Q	PARTICIPANT	\N	PRESENT	0
324461	314153	19723Y	PARTICIPANT	\N	PRESENT	0
324462	314153	14217N	PARTICIPANT	\N	PRESENT	0
324463	314153	04018C	PARTICIPANT	\N	PRESENT	0
324464	314153	10006L	PARTICIPANT	\N	PRESENT	0
324465	314153	05012A	PARTICIPANT	\N	PRESENT	0
324466	314153	14223L	PARTICIPANT	\N	PRESENT	0
324467	314153	04045F	PARTICIPANT	\N	PRESENT	0
324468	314153	08052W	PARTICIPANT	\N	PRESENT	0
324469	314153	11067R	PARTICIPANT	\N	PRESENT	0
324470	314153	19577H	PARTICIPANT	\N	PRESENT	0
324471	314153	19657G	PARTICIPANT	\N	PRESENT	0
324472	314153	19527W	PARTICIPANT	\N	PRESENT	0
324473	314153	17779H	PARTICIPANT	\N	PRESENT	0
324474	314153	95037J	PARTICIPANT	\N	PRESENT	0
324475	314153	19683J	PARTICIPANT	\N	PRESENT	0
324476	314153	98024R	PARTICIPANT	\N	PRESENT	0
324477	314153	19727D	PARTICIPANT	\N	PRESENT	0
324478	314153	14227Q	PARTICIPANT	\N	PRESENT	0
324479	314153	14281W	PARTICIPANT	\N	PRESENT	0
324480	314153	08031R	PARTICIPANT	\N	PRESENT	0
324481	314153	19553Y	PARTICIPANT	\N	PRESENT	0
324482	314153	19479G	PARTICIPANT	\N	PRESENT	0
324483	314153	19713W	PARTICIPANT	\N	PRESENT	0
324484	314153	14215L	PARTICIPANT	\N	PRESENT	0
324485	314153	19515S	PARTICIPANT	\N	PRESENT	0
324486	314153	19443T	PARTICIPANT	\N	PRESENT	0
324487	314153	14329V	PARTICIPANT	\N	PRESENT	0
324488	314153	19421M	PARTICIPANT	\N	PRESENT	0
324489	314153	14169X	PARTICIPANT	\N	PRESENT	0
324490	314153	14261S	PARTICIPANT	\N	PRESENT	0
324491	314153	19621T	PARTICIPANT	\N	PRESENT	0
324492	314153	19747H	PARTICIPANT	\N	PRESENT	0
324493	314153	14265W	PARTICIPANT	\N	PRESENT	0
324494	314153	08015R	PARTICIPANT	\N	PRESENT	0
324495	314153	01057W	PARTICIPANT	\N	PRESENT	0
324496	314153	19575F	PARTICIPANT	\N	PRESENT	0
324497	314153	14083S	PARTICIPANT	\N	PRESENT	0
324498	314153	11064N	PARTICIPANT	\N	PRESENT	0
324499	314153	14021P	PARTICIPANT	\N	PRESENT	0
324500	314153	14257W	PARTICIPANT	\N	PRESENT	0
324501	314153	14357A	PARTICIPANT	\N	PRESENT	0
324502	314153	14071N	PARTICIPANT	\N	PRESENT	0
324503	314153	14119M	PARTICIPANT	\N	PRESENT	0
324504	314153	14147R	PARTICIPANT	\N	PRESENT	0
324505	314153	14069U	PARTICIPANT	\N	PRESENT	0
324506	314153	14053L	PARTICIPANT	\N	PRESENT	0
324507	314153	14251Q	PARTICIPANT	\N	PRESENT	0
324509	314153	14089Y	PARTICIPANT	\N	PRESENT	0
324510	314153	19551W	PARTICIPANT	\N	PRESENT	0
324511	314153	19629C	PARTICIPANT	\N	PRESENT	0
324512	314153	19671E	PARTICIPANT	\N	PRESENT	0
324513	314153	14034U	PARTICIPANT	\N	PRESENT	0
324536	322117	11067R	PARTICIPANT	\N	PRESENT	0
324537	322117	19649G	PARTICIPANT	\N	PRESENT	0
324538	322117	19569H	PARTICIPANT	\N	PRESENT	0
324539	322117	11045K	PARTICIPANT	\N	PRESENT	0
324540	322117	19415P	PARTICIPANT	\N	PRESENT	0
324541	322117	08043V	PRESIDENT	0	PRESENT	0
324542	322117	19585H	PARTICIPANT	\N	PRESENT	0
324543	322117	01028R	PARTICIPANT	\N	PRESENT	0
324544	322117	19447X	PARTICIPANT	\N	PRESENT	0
324545	322117	19723Y	PARTICIPANT	\N	PRESENT	0
324546	322117	14030Q	PARTICIPANT	\N	PRESENT	0
324547	322117	14231L	PARTICIPANT	\N	PRESENT	0
324548	322117	14147R	PARTICIPANT	\N	PRESENT	0
324549	322117	11083R	PARTICIPANT	\N	PRESENT	0
324550	322117	14213J	PARTICIPANT	\N	PRESENT	0
324551	322117	19749K	PARTICIPANT	\N	PRESENT	0
324552	322117	10006L	PRESIDENT	1	PRESENT	0
324553	322117	08031R	PARTICIPANT	\N	PRESENT	0
324554	322117	14223L	PARTICIPANT	\N	PRESENT	0
324555	322117	11033F	PARTICIPANT	\N	PRESENT	0
324556	322117	19621T	PARTICIPANT	\N	PRESENT	0
324558	322117	04047H	PARTICIPANT	\N	EXCUSE	0
324559	322117	11043H	PARTICIPANT	\N	PRESENT	0
324560	314154	11027H	PARTICIPANT	\N	PRESENT	0
324561	314154	04092N	PARTICIPANT	\N	PRESENT	0
324562	314154	01034P	PARTICIPANT	\N	PRESENT	0
324563	314154	04034C	PARTICIPANT	\N	PRESENT	0
324564	314154	19715Y	PARTICIPANT	\N	PRESENT	0
324565	314154	19727D	PARTICIPANT	\N	PRESENT	0
324566	314154	19760E	PARTICIPANT	\N	PRESENT	0
324567	314154	11031D	PARTICIPANT	\N	PRESENT	0
324568	314154	19697Q	PARTICIPANT	\N	PRESENT	0
324569	314154	11012A	PARTICIPANT	\N	PRESENT	0
324570	314154	08031R	PARTICIPANT	\N	PRESENT	0
324571	314154	19689Q	PARTICIPANT	\N	PRESENT	0
324572	314154	19569H	PARTICIPANT	\N	PRESENT	0
324573	314154	19737F	PARTICIPANT	\N	PRESENT	0
324574	314154	07004J	PARTICIPANT	\N	PRESENT	0
324575	314154	14147R	PARTICIPANT	\N	PRESENT	0
324576	314154	11103C	PARTICIPANT	\N	PRESENT	0
324577	314154	14223L	PARTICIPANT	\N	PRESENT	0
324578	314154	04086Q	PARTICIPANT	\N	PRESENT	0
324579	314154	19657G	PARTICIPANT	\N	PRESENT	0
324580	314154	19415P	PARTICIPANT	\N	PRESENT	0
324581	314154	14133K	PARTICIPANT	\N	PRESENT	0
324582	314154	14029X	PARTICIPANT	\N	PRESENT	0
324583	314154	19723Y	PARTICIPANT	\N	PRESENT	0
324584	314154	08019V	PARTICIPANT	\N	PRESENT	0
324585	314154	95062K	PARTICIPANT	\N	PRESENT	0
324586	314154	19553Y	PARTICIPANT	\N	PRESENT	0
324587	314154	14121F	PARTICIPANT	\N	PRESENT	0
324588	314154	14281W	PARTICIPANT	\N	PRESENT	0
324589	314154	19683J	PARTICIPANT	\N	PRESENT	0
324590	314154	08052W	PARTICIPANT	\N	PRESENT	0
324591	314154	11072N	PARTICIPANT	\N	PRESENT	0
324592	314154	14231L	PARTICIPANT	\N	PRESENT	0
324593	314154	10006L	PARTICIPANT	\N	PRESENT	0
324594	314154	19711U	PARTICIPANT	\N	PRESENT	0
324595	314154	19515S	PARTICIPANT	\N	PRESENT	0
324596	314154	19703U	PARTICIPANT	\N	PRESENT	0
324597	314154	19713W	PARTICIPANT	\N	PRESENT	0
324598	314154	14215L	PARTICIPANT	\N	PRESENT	0
324599	314154	11097X	PARTICIPANT	\N	PRESENT	0
324600	314154	14227Q	PARTICIPANT	\N	PRESENT	0
324601	314154	11045K	PARTICIPANT	\N	PRESENT	0
324602	314154	11040E	PARTICIPANT	\N	PRESENT	0
324603	314154	19695N	PARTICIPANT	\N	PRESENT	0
324604	314154	98024R	PARTICIPANT	\N	PRESENT	0
324605	314154	14195A	PARTICIPANT	\N	PRESENT	0
324606	314154	14053L	PARTICIPANT	\N	PRESENT	0
324607	314154	04045F	PARTICIPANT	\N	PRESENT	0
324611	314154	14257W	PARTICIPANT	\N	PRESENT	0
324612	314154	14239U	PARTICIPANT	\N	PRESENT	0
324613	314154	14069U	PARTICIPANT	\N	PRESENT	0
324614	314154	01057W	PARTICIPANT	\N	PRESENT	0
324617	314154	19741B	PARTICIPANT	\N	PRESENT	0
324618	324616	19611R	PARTICIPANT	\N	PRESENT	0
324619	324616	08015R	PARTICIPANT	\N	PRESENT	0
324620	324616	01048V	PARTICIPANT	\N	PRESENT	0
324621	324616	19503N	PARTICIPANT	\N	PRESENT	0
324622	324616	05012A	PARTICIPANT	\N	PRESENT	0
324623	324616	04044E	PARTICIPANT	\N	PRESENT	0
324624	324616	19619A	PARTICIPANT	\N	PRESENT	0
324625	314154	19443T	PARTICIPANT	\N	PRESENT	0
324626	314154	19731Y	PARTICIPANT	\N	PRESENT	0
324627	314154	04018C	PARTICIPANT	\N	PRESENT	0
324628	314154	19705W	PARTICIPANT	\N	PRESENT	0
324629	314154	14119M	PARTICIPANT	\N	PRESENT	0
324630	314154	19687N	PARTICIPANT	\N	PRESENT	0
324631	314154	08047A	PARTICIPANT	\N	PRESENT	0
307416	307415	04044E	PARTICIPANT	\N	PRESENT	0
307420	307419	04044E	PARTICIPANT	\N	PRESENT	0
309071	309070	96004D	PARTICIPANT	\N	PRESENT	0
309072	309070	14089Y	PARTICIPANT	\N	PRESENT	0
309073	309070	14097Y	PARTICIPANT	\N	PRESENT	0
309074	309070	11083R	PARTICIPANT	\N	PRESENT	0
309075	309070	14221J	PARTICIPANT	\N	PRESENT	0
309076	309070	04057K	PARTICIPANT	\N	PRESENT	0
309077	309070	19593H	PARTICIPANT	\N	PRESENT	0
309078	309070	04061F	PARTICIPANT	\N	PRESENT	0
309079	309070	14001X	PARTICIPANT	\N	PRESENT	0
309080	309070	98035U	PARTICIPANT	\N	PRESENT	0
309081	309070	10015M	PARTICIPANT	\N	PRESENT	0
309082	309070	04097T	PARTICIPANT	\N	PRESENT	0
309083	309058	96004D	PRESIDENT	0	PRESENT	0
309084	309058	14089Y	PARTICIPANT	\N	PRESENT	0
309085	309058	08014Q	PARTICIPANT	\N	EXCUSE	0
309086	309058	14357A	PARTICIPANT	\N	PRESENT	0
309087	309058	14079W	PARTICIPANT	\N	PRESENT	0
309088	309058	11083R	PARTICIPANT	\N	PRESENT	0
309089	309058	19569H	PARTICIPANT	\N	PRESENT	0
309090	309058	14097Y	PARTICIPANT	\N	PRESENT	0
309091	309058	04061F	PARTICIPANT	\N	PRESENT	0
309092	309058	14073Q	PARTICIPANT	\N	PRESENT	0
309093	309058	11026G	PARTICIPANT	\N	PRESENT	0
309094	309058	14001X	PARTICIPANT	\N	PRESENT	0
309095	309058	14221J	PARTICIPANT	\N	PRESENT	0
309096	309058	04057K	PARTICIPANT	\N	PRESENT	0
309097	309058	10015M	PARTICIPANT	\N	PRESENT	0
309098	309058	98035U	PARTICIPANT	\N	PRESENT	0
309099	309058	19593H	PARTICIPANT	\N	PRESENT	0
309101	309058	14065Q	PARTICIPANT	\N	EXCUSE	0
309102	309058	14061L	PARTICIPANT	\N	EXCUSE	0
309103	309058	14237S	PARTICIPANT	\N	EXCUSE	0
309110	309109	19569H	PARTICIPANT	\N	PRESENT	0
309111	309109	11026G	PARTICIPANT	\N	PRESENT	0
309112	309109	10015M	PARTICIPANT	\N	PRESENT	0
309115	309114	11074Q	PRESIDENT	0	PRESENT	0
309116	309114	08011M	PARTICIPANT	\N	PRESENT	0
309117	309114	04071H	PARTICIPANT	\N	PRESENT	0
309118	309114	19479G	PARTICIPANT	\N	PRESENT	0
309119	309114	19689Q	PARTICIPANT	\N	PRESENT	0
309120	309114	19741B	PARTICIPANT	\N	PRESENT	0
309121	309114	11040E	PARTICIPANT	\N	PRESENT	0
309122	309114	14085U	PARTICIPANT	\N	PRESENT	0
309123	309114	19719D	PARTICIPANT	\N	PRESENT	0
310307	306017	08024S	PARTICIPANT	\N	PRESENT	0
310308	306017	19551W	PARTICIPANT	\N	PRESENT	0
310309	306017	19737F	PARTICIPANT	\N	PRESENT	0
310310	306017	19349W	PARTICIPANT	\N	PRESENT	0
316536	316535	19741B	PARTICIPANT	\N	PRESENT	0
316542	316541	11074Q	PARTICIPANT	\N	PRESENT	0
316543	316541	19651A	PARTICIPANT	\N	PRESENT	0
316549	316548	04086Q	PARTICIPANT	\N	PRESENT	0
316569	316565	04086Q	PARTICIPANT	\N	PRESENT	0
316578	316575	04086Q	PARTICIPANT	\N	PRESENT	0
316793	316788	04061F	PARTICIPANT	\N	PRESENT	0
316732	316707	11048N	PARTICIPANT	\N	PRESENT	0
316775	316769	04061F	PARTICIPANT	\N	PRESENT	0
317918	309290	19527W	PARTICIPANT	\N	PRESENT	0
317919	309290	11041F	PARTICIPANT	\N	PRESENT	0
317920	309290	19747H	PARTICIPANT	\N	PRESENT	0
317921	309290	11066Q	PARTICIPANT	\N	PRESENT	0
318379	309291	19575F	PARTICIPANT	\N	PRESENT	0
318380	317663	19768N	PARTICIPANT	\N	PRESENT	0
318381	317663	19515S	PARTICIPANT	\N	PRESENT	0
318382	317663	14357A	PARTICIPANT	\N	PRESENT	0
318383	317663	19441R	PARTICIPANT	\N	PRESENT	0
318384	317663	19413M	PARTICIPANT	\N	PRESENT	0
318385	317663	19631V	PARTICIPANT	\N	PRESENT	0
318386	317663	08068F	PARTICIPANT	\N	PRESENT	0
318387	317663	04049K	PARTICIPANT	\N	PRESENT	0
318388	317663	19705W	PARTICIPANT	\N	PRESENT	0
318389	317663	08015R	PARTICIPANT	\N	PRESENT	0
318390	317663	08019V	PARTICIPANT	\N	PRESENT	0
318391	317663	19369B	PARTICIPANT	\N	PRESENT	0
318392	317663	19511N	PARTICIPANT	\N	PRESENT	0
318393	317663	14265W	PARTICIPANT	\N	PRESENT	0
318394	317663	14135M	PARTICIPANT	\N	PRESENT	0
318395	317663	19467C	PARTICIPANT	\N	PRESENT	0
318396	317663	14187A	PARTICIPANT	\N	PRESENT	0
318397	317663	08062Y	PARTICIPANT	\N	PRESENT	0
318398	317663	19695N	PARTICIPANT	\N	PRESENT	0
318399	317663	14033T	PARTICIPANT	\N	PRESENT	0
318400	317663	11090Q	PRESIDENT	0	PRESENT	0
318401	317663	01025N	PARTICIPANT	\N	PRESENT	0
318402	317663	19269X	PARTICIPANT	\N	PRESENT	0
318403	317663	14205J	PARTICIPANT	\N	PRESENT	0
318404	317663	04088S	PARTICIPANT	\N	PRESENT	0
318405	317663	14115H	PARTICIPANT	\N	PRESENT	0
318406	317663	11101A	PARTICIPANT	\N	PRESENT	0
318407	317663	19507S	PARTICIPANT	\N	PRESENT	0
318408	317663	19747H	PARTICIPANT	\N	PRESENT	0
318409	317663	14207L	PARTICIPANT	\N	PRESENT	0
318410	317663	04043D	PARTICIPANT	\N	PRESENT	0
318411	317663	19619A	PARTICIPANT	\N	PRESENT	0
318412	317663	17589D	PARTICIPANT	\N	PRESENT	0
318413	317663	14257W	PARTICIPANT	\N	PRESENT	0
318414	309291	14179A	PARTICIPANT	\N	PRESENT	0
318419	309291	19399H	PARTICIPANT	\N	PRESENT	0
318422	309291	14251Q	PARTICIPANT	\N	PRESENT	0
318423	309291	11103C	PARTICIPANT	\N	PRESENT	0
318424	309291	14253S	PARTICIPANT	\N	PRESENT	0
318425	309291	11064N	PARTICIPANT	\N	PRESENT	0
318429	317663	14197C	PARTICIPANT	\N	EXCUSE	0
318449	309291	14069U	PARTICIPANT	\N	PRESENT	0
318431	317663	11081P	PARTICIPANT	\N	EXCUSE	0
318432	317663	14329V	PARTICIPANT	\N	PRESENT	0
318433	309291	14249W	PARTICIPANT	\N	PRESENT	0
318434	317663	19565D	PARTICIPANT	\N	EXCUSE	0
318435	317663	08038Y	PARTICIPANT	\N	EXCUSE	0
318436	317663	14081Q	PARTICIPANT	\N	EXCUSE	0
318437	317663	19295A	PARTICIPANT	\N	EXCUSE	0
318438	309291	14038Y	PARTICIPANT	\N	PRESENT	0
318441	309291	08049C	PARTICIPANT	\N	PRESENT	0
318442	317663	19383Y	PARTICIPANT	\N	PRESENT	0
318443	309291	11012A	PARTICIPANT	\N	PRESENT	0
318444	309291	14034U	PARTICIPANT	\N	PRESENT	0
318445	309291	14191V	PARTICIPANT	\N	PRESENT	0
318446	309291	11043H	PARTICIPANT	\N	PRESENT	0
318447	309291	04061F	PARTICIPANT	\N	PRESENT	0
318448	309291	19387D	PARTICIPANT	\N	PRESENT	0
318450	309291	19679N	PARTICIPANT	\N	PRESENT	0
318451	317663	11056N	PARTICIPANT	\N	PRESENT	0
318452	309291	19479G	PARTICIPANT	\N	PRESENT	0
318453	309291	14223L	PARTICIPANT	\N	PRESENT	0
318454	309291	19703U	PARTICIPANT	\N	PRESENT	0
318455	309291	08024S	PARTICIPANT	\N	PRESENT	0
318456	309291	17583W	PARTICIPANT	\N	PRESENT	0
318457	309291	14053L	PARTICIPANT	\N	PRESENT	0
318458	309291	19729F	PARTICIPANT	\N	PRESENT	0
318459	317663	04089T	PARTICIPANT	\N	EXCUSE	0
318460	309291	08044W	PARTICIPANT	\N	PRESENT	0
318461	309291	19711U	PARTICIPANT	\N	PRESENT	0
318462	309291	11027H	PARTICIPANT	\N	PRESENT	0
318464	318328	19701S	PARTICIPANT	\N	PRESENT	0
318465	318328	19549D	PARTICIPANT	\N	PRESENT	0
318466	318328	14079W	PRESIDENT	0	PRESENT	0
318467	318328	04044E	PARTICIPANT	\N	PRESENT	0
318468	318328	14229S	PARTICIPANT	\N	PRESENT	0
318469	318328	19725B	PARTICIPANT	\N	PRESENT	0
318470	318328	14237S	PARTICIPANT	\N	PRESENT	0
318471	318328	19553Y	PARTICIPANT	\N	PRESENT	0
318472	318328	19735D	PARTICIPANT	\N	PRESENT	0
318473	318328	19503N	PARTICIPANT	\N	PRESENT	0
318474	318328	19347U	PARTICIPANT	\N	PRESENT	0
318475	318328	19739H	PARTICIPANT	\N	PRESENT	0
318476	318328	14213J	PARTICIPANT	\N	PRESENT	0
318477	318328	14215L	PARTICIPANT	\N	PRESENT	0
318478	318328	19335Q	PARTICIPANT	\N	PRESENT	0
318479	318328	14255U	PARTICIPANT	\N	PRESENT	0
318480	318328	04089T	PARTICIPANT	\N	PRESENT	0
318481	318328	95063L	PARTICIPANT	\N	PRESENT	0
318482	318328	14031R	PARTICIPANT	\N	PRESENT	0
318483	318328	14001X	PARTICIPANT	\N	PRESENT	0
318484	318328	08039A	PARTICIPANT	\N	PRESENT	0
318485	318328	19593H	PARTICIPANT	\N	EXCUSE	0
318486	318328	14033T	PARTICIPANT	\N	EXCUSE	0
318487	318463	19725B	PARTICIPANT	\N	PRESENT	0
318488	318463	19701S	PARTICIPANT	\N	PRESENT	0
318489	318463	19735D	PARTICIPANT	\N	PRESENT	0
318490	318463	14079W	PRESIDENT	0	PRESENT	0
318491	318463	19347U	PARTICIPANT	\N	PRESENT	0
318492	318463	19503N	PARTICIPANT	\N	PRESENT	0
318493	318463	19739H	PARTICIPANT	\N	PRESENT	0
318494	318463	14215L	PARTICIPANT	\N	PRESENT	0
318495	318463	04044E	PARTICIPANT	\N	PRESENT	0
318496	318463	19335Q	PARTICIPANT	\N	PRESENT	0
318497	318463	14255U	PARTICIPANT	\N	PRESENT	0
314704	314348	19735D	PARTICIPANT	\N	PRESENT	0
315207	315206	19569H	PARTICIPANT	\N	PRESENT	0
315208	315206	89017R	PARTICIPANT	\N	PRESENT	0
315209	315206	04040A	PARTICIPANT	\N	PRESENT	0
315210	315206	19667J	PARTICIPANT	\N	PRESENT	0
315211	315206	14065Q	PARTICIPANT	\N	PRESENT	0
315212	315206	14083S	PARTICIPANT	\N	PRESENT	0
315213	315206	19611R	PARTICIPANT	\N	PRESENT	0
315214	315206	11026G	PARTICIPANT	\N	PRESENT	0
315215	315206	14063N	PARTICIPANT	\N	PRESENT	0
315216	315206	19269X	PARTICIPANT	\N	PRESENT	0
315217	314348	19725B	PARTICIPANT	\N	PRESENT	0
315218	314348	19527W	PARTICIPANT	\N	PRESENT	0
315219	314348	19521Q	PARTICIPANT	\N	PRESENT	0
315772	314014	17589D	PARTICIPANT	\N	PRESENT	0
315774	314390	19549D	PARTICIPANT	\N	PRESENT	0
315775	314390	19347U	PARTICIPANT	\N	PRESENT	0
315776	314390	98023Q	PARTICIPANT	\N	PRESENT	0
315777	314390	14038Y	PARTICIPANT	\N	PRESENT	0
315778	314390	08055A	PARTICIPANT	\N	PRESENT	0
315779	314390	17589D	PARTICIPANT	\N	PRESENT	0
315780	314390	19387D	PARTICIPANT	\N	PRESENT	0
315781	314390	14219Q	PARTICIPANT	\N	PRESENT	0
315782	314390	14221J	PARTICIPANT	\N	PRESENT	0
315783	314390	19637C	PARTICIPANT	\N	PRESENT	0
315784	314390	18083K	PARTICIPANT	\N	PRESENT	0
315785	314390	19503N	PARTICIPANT	\N	PRESENT	0
315786	314390	08024S	PARTICIPANT	\N	PRESENT	0
315787	314390	17637T	PARTICIPANT	\N	PRESENT	0
315788	314390	14135M	PARTICIPANT	\N	PRESENT	0
315789	314390	15447F	PARTICIPANT	\N	PRESENT	0
315790	314390	08009T	PARTICIPANT	\N	PRESENT	0
315791	314390	19737F	PARTICIPANT	\N	PRESENT	0
315792	315528	19533U	PARTICIPANT	\N	PRESENT	0
315793	315528	92040Q	PARTICIPANT	\N	PRESENT	0
315794	315528	19643A	PARTICIPANT	\N	PRESENT	0
315795	315528	14073Q	PARTICIPANT	\N	PRESENT	0
315796	315528	19693L	PARTICIPANT	\N	PRESENT	0
315797	315528	08020N	PARTICIPANT	\N	PRESENT	0
315798	315528	04059M	PARTICIPANT	\N	PRESENT	0
315799	315528	19735D	PARTICIPANT	\N	PRESENT	0
315800	314390	19333N	PARTICIPANT	\N	PRESENT	0
315801	314390	17583W	PARTICIPANT	\N	PRESENT	0
315802	314390	02002K	PARTICIPANT	\N	PRESENT	0
315803	314390	19551W	PARTICIPANT	\N	PRESENT	0
315804	314390	14157T	PARTICIPANT	\N	PRESENT	0
315805	314390	11065P	PARTICIPANT	\N	PRESENT	0
315806	314390	14191V	PARTICIPANT	\N	PRESENT	0
315807	314390	19599P	PARTICIPANT	\N	PRESENT	0
315808	314390	14237S	PARTICIPANT	\N	PRESENT	0
315809	314390	14103D	PARTICIPANT	\N	PRESENT	0
315810	314390	14031R	PARTICIPANT	\N	PRESENT	0
315811	314390	14029X	PARTICIPANT	\N	PRESENT	0
315812	314390	19733B	PARTICIPANT	\N	PRESENT	0
315813	314390	19739H	PARTICIPANT	\N	PRESENT	0
315814	314390	04097T	PARTICIPANT	\N	PRESENT	0
315815	314390	19745F	PARTICIPANT	\N	PRESENT	0
315816	313989	04047H	PARTICIPANT	\N	PRESENT	0
315817	313989	14231L	PARTICIPANT	\N	PRESENT	0
315818	313989	95063L	PARTICIPANT	\N	PRESENT	0
315819	313986	11110B	PARTICIPANT	\N	PRESENT	0
315820	313986	19479G	PARTICIPANT	\N	PRESENT	0
315821	313986	19651A	PARTICIPANT	\N	PRESENT	0
315822	313986	14034U	PARTICIPANT	\N	PRESENT	0
315823	313986	04061F	PARTICIPANT	\N	PRESENT	0
315824	313943	01062T	PARTICIPANT	\N	PRESENT	0
315825	313634	14026U	PARTICIPANT	\N	PRESENT	0
315826	313634	19691J	PARTICIPANT	\N	PRESENT	0
315827	313634	04045F	PARTICIPANT	\N	PRESENT	0
315828	314390	19269X	PARTICIPANT	\N	PRESENT	0
315829	314014	19269X	PARTICIPANT	\N	PRESENT	0
315830	305897	02002K	PARTICIPANT	\N	PRESENT	0
315831	314014	08068F	PARTICIPANT	\N	PRESENT	0
315832	314390	08068F	PARTICIPANT	\N	PRESENT	0
315833	315528	14249W	PARTICIPANT	\N	PRESENT	0
315834	315528	19731Y	PARTICIPANT	\N	PRESENT	0
315835	315528	11109J	PARTICIPANT	\N	PRESENT	0
315836	315528	14109K	PARTICIPANT	\N	PRESENT	0
315837	315528	11043H	PARTICIPANT	\N	PRESENT	0
315838	313986	01048V	PARTICIPANT	\N	PRESENT	0
315839	313634	19683J	PARTICIPANT	\N	PRESENT	0
315840	313943	11080N	PARTICIPANT	\N	PRESENT	0
315841	313989	11072N	PARTICIPANT	\N	PRESENT	0
315842	314014	11056N	PARTICIPANT	\N	PRESENT	0
315843	314390	11056N	PARTICIPANT	\N	PRESENT	0
315848	313634	14261S	PARTICIPANT	\N	PRESENT	0
315849	313634	11045K	PARTICIPANT	\N	PRESENT	0
315940	315530	11043H	PARTICIPANT	\N	PRESENT	0
316228	316215	04070G	PRESIDENT	0	PRESENT	0
316229	316215	19699S	PARTICIPANT	\N	PRESENT	0
316230	316215	14241N	PARTICIPANT	\N	PRESENT	0
316231	316215	19573D	PARTICIPANT	\N	PRESENT	0
316232	316215	14107H	PARTICIPANT	\N	PRESENT	0
316233	316215	08017T	PARTICIPANT	\N	PRESENT	0
316234	316215	08012N	PARTICIPANT	\N	PRESENT	0
316235	316215	14249W	PARTICIPANT	\N	PRESENT	0
316236	316215	08039A	PARTICIPANT	\N	PRESENT	0
316237	316215	08031R	PARTICIPANT	\N	PRESENT	0
316238	316215	19643A	PARTICIPANT	\N	PRESENT	0
316239	316215	14059S	PARTICIPANT	\N	PRESENT	0
316240	316215	14061L	PARTICIPANT	\N	PRESENT	0
316241	316215	04057K	PARTICIPANT	\N	PRESENT	0
316242	316215	14073Q	PARTICIPANT	\N	PRESENT	0
316243	316215	19611R	PARTICIPANT	\N	PRESENT	0
316244	316215	08043V	PARTICIPANT	\N	PRESENT	0
316245	316215	19693L	PARTICIPANT	\N	PRESENT	0
316246	316215	87003B	PARTICIPANT	\N	PRESENT	0
316247	316215	14030Q	PARTICIPANT	\N	PRESENT	0
316248	316215	19731Y	PARTICIPANT	\N	PRESENT	0
316249	316215	08020N	PARTICIPANT	\N	PRESENT	0
316250	316215	14063N	PARTICIPANT	\N	PRESENT	0
316251	316215	14109K	PARTICIPANT	\N	PRESENT	0
316252	316215	14121F	PARTICIPANT	\N	PRESENT	0
316253	316215	11104D	PARTICIPANT	\N	PRESENT	0
316254	316215	11043H	PARTICIPANT	\N	PRESENT	0
316255	316215	19749K	PARTICIPANT	\N	PRESENT	0
316256	316215	19758L	PARTICIPANT	\N	PRESENT	0
316257	316215	04018C	PARTICIPANT	\N	PRESENT	0
316264	309283	14069U	PARTICIPANT	\N	PRESENT	0
316269	309283	14031R	PARTICIPANT	\N	PRESENT	0
316271	309283	04049K	PARTICIPANT	\N	PRESENT	0
316272	309283	04043D	PARTICIPANT	\N	PRESENT	0
316273	309283	14147R	PARTICIPANT	\N	PRESENT	0
316274	309283	19549D	PARTICIPANT	\N	PRESENT	0
316275	309283	19762G	PARTICIPANT	\N	PRESENT	0
316276	309283	19415P	PARTICIPANT	\N	PRESENT	0
316277	309283	14033T	PARTICIPANT	\N	PRESENT	0
316279	309283	14135M	PARTICIPANT	\N	PRESENT	0
316280	309283	14034U	PARTICIPANT	\N	PRESENT	0
316281	309283	19441R	PARTICIPANT	\N	PRESENT	0
316282	309283	18083K	PARTICIPANT	\N	PRESENT	0
316285	309283	19711U	PARTICIPANT	\N	PRESENT	0
316286	309283	19747H	PARTICIPANT	\N	PRESENT	0
316287	309283	19703U	PARTICIPANT	\N	PRESENT	0
316288	314265	08052W	PARTICIPANT	\N	PRESENT	0
316289	311922	01034P	PARTICIPANT	\N	PRESENT	0
316292	309283	11031D	PARTICIPANT	\N	PRESENT	0
316293	316215	19766L	PARTICIPANT	\N	PRESENT	0
316294	316215	19533U	PARTICIPANT	\N	PRESENT	0
316295	316215	19735D	PARTICIPANT	\N	PRESENT	0
316296	316215	19399H	PARTICIPANT	\N	PRESENT	0
316297	309283	14187A	PARTICIPANT	\N	PRESENT	0
316298	309283	19479G	PARTICIPANT	\N	PRESENT	0
316299	309283	19333N	PARTICIPANT	\N	PRESENT	0
316387	311724	19703U	PARTICIPANT	\N	EXCUSE	0
316388	311724	04043D	PARTICIPANT	\N	EXCUSE	0
316390	316389	19533U	PARTICIPANT	\N	PRESENT	0
316893	311724	11109J	PARTICIPANT	\N	PRESENT	0
316393	316392	19533U	PARTICIPANT	\N	PRESENT	0
316894	311724	14261S	PARTICIPANT	\N	PRESENT	0
316396	316395	19533U	PARTICIPANT	\N	PRESENT	0
316895	311724	19631V	PARTICIPANT	\N	PRESENT	0
316412	316410	19693L	PARTICIPANT	\N	PRESENT	0
316414	316413	11104D	PARTICIPANT	\N	PRESENT	0
316415	316413	19611R	PARTICIPANT	\N	PRESENT	0
316417	316416	11104D	PARTICIPANT	\N	PRESENT	0
316419	316418	19693L	PARTICIPANT	\N	PRESENT	0
316420	316418	19593H	PARTICIPANT	\N	PRESENT	0
316422	316421	19693L	PARTICIPANT	\N	PRESENT	0
316896	311724	14038Y	PARTICIPANT	\N	PRESENT	0
316897	311724	14199E	PARTICIPANT	\N	PRESENT	0
316898	311724	19691J	PARTICIPANT	\N	PRESENT	0
316900	311724	19329S	PARTICIPANT	\N	PRESENT	0
316903	311724	19715Y	PARTICIPANT	\N	PRESENT	0
316906	311724	14039A	PARTICIPANT	\N	PRESENT	0
316908	311724	14059S	PARTICIPANT	\N	PRESENT	0
316909	311724	19729F	PARTICIPANT	\N	PRESENT	0
316910	311724	08019V	PRESIDENT	0	PRESENT	0
316911	311724	11072N	PARTICIPANT	\N	PRESENT	0
311791	311790	11109J	PARTICIPANT	\N	PRESENT	0
311792	311790	08024S	PARTICIPANT	\N	PRESENT	0
311793	311790	14219Q	PARTICIPANT	\N	PRESENT	0
311794	311790	19441R	PARTICIPANT	\N	PRESENT	0
311795	311790	01062T	PARTICIPANT	\N	PRESENT	0
311797	311796	11027H	PARTICIPANT	\N	PRESENT	0
311798	311796	19295A	PARTICIPANT	\N	PRESENT	0
311804	309514	14119M	PARTICIPANT	\N	PRESENT	0
311805	309514	14281W	PARTICIPANT	\N	PRESENT	0
311806	309514	19703U	PARTICIPANT	\N	PRESENT	0
311808	311807	98024R	PARTICIPANT	\N	PRESENT	0
311810	311809	98024R	PARTICIPANT	\N	PRESENT	0
311812	311811	14042U	PARTICIPANT	\N	PRESENT	0
311923	311922	14042U	PARTICIPANT	\N	PRESENT	0
311926	311925	14042U	PARTICIPANT	\N	PRESENT	0
312039	312038	10006L	PARTICIPANT	\N	PRESENT	0
312041	312040	10006L	PARTICIPANT	\N	PRESENT	0
312241	312038	08052W	PARTICIPANT	\N	PRESENT	0
313981	313980	08049C	PARTICIPANT	\N	PRESENT	0
313982	313980	04035D	PARTICIPANT	\N	PRESENT	0
313984	313983	14255U	PARTICIPANT	\N	PRESENT	0
317917	309290	14227Q	PARTICIPANT	\N	PRESENT	0
318506	316537	08009T	PRESIDENT	0	PRESENT	0
318507	316537	14093U	PARTICIPANT	\N	EXCUSE	0
318508	316537	19637C	PARTICIPANT	\N	EXCUSE	0
318509	316537	95062K	PARTICIPANT	\N	PRESENT	0
318510	316537	14219Q	PARTICIPANT	\N	PRESENT	0
318511	316537	14191V	PARTICIPANT	\N	PRESENT	0
318512	316537	14038Y	PARTICIPANT	\N	PRESENT	0
318513	316537	17583W	PARTICIPANT	\N	PRESENT	0
318514	316537	19387D	PARTICIPANT	\N	PRESENT	0
318515	316537	14051J	PARTICIPANT	\N	PRESENT	0
318516	316537	19347U	PARTICIPANT	\N	PRESENT	0
318517	316537	19739H	PARTICIPANT	\N	PRESENT	0
318518	316537	08024S	PARTICIPANT	\N	PRESENT	0
318519	316537	17637T	PARTICIPANT	\N	PRESENT	0
318520	316537	19525U	PARTICIPANT	\N	PRESENT	0
318521	316537	19383Y	PARTICIPANT	\N	PRESENT	0
318522	316537	19333N	PARTICIPANT	\N	PRESENT	0
318523	316537	19701S	PARTICIPANT	\N	PRESENT	0
318524	316537	02002K	PARTICIPANT	\N	PRESENT	0
318525	316537	18083K	PARTICIPANT	\N	PRESENT	0
318526	316537	14237S	PARTICIPANT	\N	PRESENT	0
318527	316537	19551W	PARTICIPANT	\N	PRESENT	0
318528	316537	08060W	PARTICIPANT	\N	PRESENT	0
318529	316537	19503N	PARTICIPANT	\N	PRESENT	0
318530	316537	19681G	PARTICIPANT	\N	PRESENT	0
318531	316537	14103D	PARTICIPANT	\N	PRESENT	0
318532	316537	14031R	PARTICIPANT	\N	PRESENT	0
318533	316537	14169X	PARTICIPANT	\N	PRESENT	0
318534	316537	04097T	PARTICIPANT	\N	PRESENT	0
318535	316537	19659J	PARTICIPANT	\N	PRESENT	0
318536	316537	11012A	PARTICIPANT	\N	PRESENT	0
318537	316537	19549D	PARTICIPANT	\N	PRESENT	0
318538	316537	14157T	PARTICIPANT	\N	PRESENT	0
318539	316537	19737F	PARTICIPANT	\N	PRESENT	0
318540	316537	11065P	PARTICIPANT	\N	PRESENT	0
318604	316079	19727D	PARTICIPANT	\N	PRESENT	0
318605	316079	19760E	PARTICIPANT	\N	PRESENT	0
318606	316079	14355X	PARTICIPANT	\N	EXCUSE	0
318607	316079	08041T	PARTICIPANT	\N	EXCUSE	0
318608	316079	19675J	PARTICIPANT	\N	EXCUSE	0
318609	316079	17779H	PARTICIPANT	\N	EXCUSE	0
318610	316085	14097Y	PARTICIPANT	\N	PRESENT	0
318611	316085	12041X	PARTICIPANT	\N	PRESENT	0
318612	316085	19443T	PARTICIPANT	\N	PRESENT	0
318613	316085	95030B	PARTICIPANT	\N	PRESENT	0
318614	316085	04034C	PARTICIPANT	\N	PRESENT	0
318615	316085	11041F	PARTICIPANT	\N	PRESENT	0
318616	316085	14235Q	PARTICIPANT	\N	PRESENT	0
318617	316085	01058X	PARTICIPANT	\N	PRESENT	0
318618	316085	16685X	PARTICIPANT	\N	PRESENT	0
318619	316085	04042C	PRESIDENT	0	PRESENT	0
318620	316085	14105F	PARTICIPANT	\N	PRESENT	0
318621	316085	98018T	PARTICIPANT	\N	PRESENT	0
318622	316085	19709B	PARTICIPANT	\N	PRESENT	0
318623	316085	08049C	PARTICIPANT	\N	PRESENT	0
318624	316085	04035D	PARTICIPANT	\N	PRESENT	0
318625	316085	14079W	PARTICIPANT	\N	PRESENT	0
318626	316085	11066Q	PARTICIPANT	\N	PRESENT	0
318627	316085	08061X	PARTICIPANT	\N	PRESENT	0
318628	316085	14255U	PARTICIPANT	\N	PRESENT	0
318629	316085	08058D	PARTICIPANT	\N	PRESENT	0
318630	316085	11027H	PARTICIPANT	\N	PRESENT	0
318631	316085	14028W	PARTICIPANT	\N	PRESENT	0
318632	316085	98022P	PARTICIPANT	\N	PRESENT	0
318633	316085	11054L	PARTICIPANT	\N	PRESENT	0
318634	316085	08053X	PARTICIPANT	\N	PRESENT	0
318635	316085	98050T	PARTICIPANT	\N	PRESENT	0
318636	316085	19251M	PARTICIPANT	\N	PRESENT	0
318637	316079	19527W	PARTICIPANT	\N	PRESENT	0
318638	316085	04040A	PARTICIPANT	\N	PRESENT	0
318639	316085	97011G	PARTICIPANT	\N	PRESENT	0
318640	316085	98005N	PARTICIPANT	\N	PRESENT	0
318641	316085	95037J	PARTICIPANT	\N	PRESENT	0
318642	316085	14055N	PARTICIPANT	\N	PRESENT	0
318643	316085	19421M	PARTICIPANT	\N	PRESENT	0
318644	316085	19721W	PARTICIPANT	\N	PRESENT	0
318645	316085	11064N	PARTICIPANT	\N	PRESENT	0
318646	316079	14026U	PARTICIPANT	\N	PRESENT	0
318647	316085	98029W	PARTICIPANT	\N	PRESENT	0
318648	316079	14071N	PARTICIPANT	\N	PRESENT	0
318649	316079	19691J	PARTICIPANT	\N	PRESENT	0
318650	316537	96004D	PARTICIPANT	\N	PRESENT	0
318651	316085	08047A	PARTICIPANT	\N	PRESENT	0
318652	316532	19545Y	PARTICIPANT	\N	PRESENT	0
318653	316532	11110B	PARTICIPANT	\N	PRESENT	0
318654	316532	07029T	PARTICIPANT	\N	PRESENT	0
318655	316532	14085U	PARTICIPANT	\N	PRESENT	0
318656	316532	11048N	PARTICIPANT	\N	PRESENT	0
318657	316532	19647E	PARTICIPANT	\N	PRESENT	0
318658	316532	19651A	PARTICIPANT	\N	PRESENT	0
318659	316532	14173T	PARTICIPANT	\N	PRESENT	0
318660	316532	19741B	PARTICIPANT	\N	PRESENT	0
318661	316532	14121F	PARTICIPANT	\N	PRESENT	0
318667	316079	11097X	PARTICIPANT	\N	EXCUSE	0
318668	316085	08056B	PARTICIPANT	\N	PRESENT	0
318669	316079	11067R	PARTICIPANT	\N	PRESENT	0
318670	316079	08048B	PARTICIPANT	\N	EXCUSE	0
318671	316537	04085P	PARTICIPANT	\N	PRESENT	0
318673	316085	95067Q	PARTICIPANT	\N	PRESENT	0
318686	316532	04071H	PARTICIPANT	\N	PRESENT	0
318694	316086	98005N	PARTICIPANT	\N	PRESENT	0
318695	316086	12041X	PARTICIPANT	\N	PRESENT	0
318696	316086	19443T	PARTICIPANT	\N	PRESENT	0
318697	316086	95030B	PARTICIPANT	\N	PRESENT	0
318698	316086	04034C	PARTICIPANT	\N	PRESENT	0
318699	316086	01058X	PARTICIPANT	\N	PRESENT	0
318700	316086	14079W	PARTICIPANT	\N	PRESENT	0
318701	316086	04040A	PARTICIPANT	\N	PRESENT	0
318702	316086	16685X	PARTICIPANT	\N	PRESENT	0
318703	316086	11027H	PARTICIPANT	\N	PRESENT	0
318704	316086	04042C	PRESIDENT	0	PRESENT	0
318705	316086	11054L	PARTICIPANT	\N	PRESENT	0
318706	316086	11066Q	PARTICIPANT	\N	PRESENT	0
318707	316086	08056B	PARTICIPANT	\N	PRESENT	0
318708	316086	95037J	PARTICIPANT	\N	PRESENT	0
318709	316086	14055N	PARTICIPANT	\N	PRESENT	0
318710	316086	19421M	PARTICIPANT	\N	PRESENT	0
318711	316086	19709B	PARTICIPANT	\N	PRESENT	0
318712	316086	08049C	PARTICIPANT	\N	PRESENT	0
318713	316086	08053X	PARTICIPANT	\N	PRESENT	0
318714	316086	08061X	PARTICIPANT	\N	PRESENT	0
318715	316086	97011G	PARTICIPANT	\N	PRESENT	0
318716	316086	08047A	PARTICIPANT	\N	PRESENT	0
318717	316086	98029W	PARTICIPANT	\N	PRESENT	0
318718	316086	14097Y	PARTICIPANT	\N	PRESENT	0
318719	316086	04035D	PARTICIPANT	\N	PRESENT	0
318720	316086	95067Q	PARTICIPANT	\N	PRESENT	0
318721	316086	11041F	PARTICIPANT	\N	PRESENT	0
318722	316086	14235Q	PARTICIPANT	\N	PRESENT	0
318723	316086	08058D	PARTICIPANT	\N	PRESENT	0
318724	316086	14028W	PARTICIPANT	\N	PRESENT	0
318725	316086	19251M	PARTICIPANT	\N	PRESENT	0
318726	316086	19721W	PARTICIPANT	\N	PRESENT	0
318727	316086	14105F	PARTICIPANT	\N	PRESENT	0
318728	316086	98018T	PARTICIPANT	\N	PRESENT	0
318729	316086	98022P	PARTICIPANT	\N	PRESENT	0
318730	316086	11064N	PARTICIPANT	\N	PRESENT	0
318731	316086	98050T	PARTICIPANT	\N	PRESENT	0
318732	316086	14255U	PARTICIPANT	\N	PRESENT	0
318808	309292	11077T	PARTICIPANT	\N	PRESENT	0
318811	309292	14257W	PARTICIPANT	\N	PRESENT	0
318812	309292	17589D	PARTICIPANT	\N	PRESENT	0
318813	309292	19563B	PARTICIPANT	\N	PRESENT	0
318814	309292	19387D	PARTICIPANT	\N	PRESENT	0
318815	309292	19681G	PARTICIPANT	\N	PRESENT	0
318816	309292	19553Y	PARTICIPANT	\N	PRESENT	0
318817	309292	19569H	PARTICIPANT	\N	PRESENT	0
324635	314154	19577H	PARTICIPANT	\N	PRESENT	0
324636	314154	11043H	PARTICIPANT	\N	PRESENT	0
324641	314154	14063N	PARTICIPANT	\N	PRESENT	0
324642	314154	14107H	PARTICIPANT	\N	PRESENT	0
324651	314154	14071N	PARTICIPANT	\N	PRESENT	0
324652	314154	14089Y	PARTICIPANT	\N	PRESENT	0
324653	314154	14251Q	PARTICIPANT	\N	PRESENT	0
324654	314154	19581D	PARTICIPANT	\N	PRESENT	0
324655	314154	14217N	PARTICIPANT	\N	PRESENT	0
324656	314154	08010L	PARTICIPANT	\N	PRESENT	0
324657	314154	14115H	PARTICIPANT	\N	PRESENT	0
324658	314154	19747H	PARTICIPANT	\N	PRESENT	0
324659	314154	11067R	PARTICIPANT	\N	PRESENT	0
324660	323962	95063L	PARTICIPANT	\N	EXCUSE	0
324661	314154	19762G	PARTICIPANT	\N	PRESENT	0
324662	314154	19629C	PARTICIPANT	\N	PRESENT	0
324663	314154	14179A	PARTICIPANT	\N	PRESENT	0
324664	314154	97011G	PARTICIPANT	\N	PRESENT	0
324665	314154	14159V	PARTICIPANT	\N	PRESENT	0
324666	314154	19479G	PARTICIPANT	\N	PRESENT	0
324667	314154	01058X	PARTICIPANT	\N	PRESENT	0
324668	314154	04057K	PARTICIPANT	\N	PRESENT	0
324669	314154	80013X	PARTICIPANT	\N	PRESENT	0
324670	314154	04043D	PARTICIPANT	\N	PRESENT	0
324671	314154	19575F	PARTICIPANT	\N	PRESENT	0
324672	314154	14213J	PARTICIPANT	\N	PRESENT	0
324681	314154	14021P	PARTICIPANT	\N	PRESENT	0
324682	314154	19663E	PARTICIPANT	\N	PRESENT	0
324683	314154	01048V	PARTICIPANT	\N	PRESENT	0
324684	314154	19691J	PARTICIPANT	\N	PRESENT	0
324685	314154	14219Q	PARTICIPANT	\N	PRESENT	0
324686	314154	14073Q	PARTICIPANT	\N	PRESENT	0
324687	314154	19701S	PARTICIPANT	\N	PRESENT	0
324691	314154	14357A	PARTICIPANT	\N	PRESENT	0
324692	314154	14157T	PARTICIPANT	\N	PRESENT	0
324693	314154	14030Q	PARTICIPANT	\N	PRESENT	0
324694	314154	08015R	PARTICIPANT	\N	PRESENT	0
324695	314154	14083S	PARTICIPANT	\N	PRESENT	0
324697	314154	14329V	PARTICIPANT	\N	PRESENT	0
324703	324702	11090Q	PARTICIPANT	\N	PRESENT	0
324705	324704	19511N	PARTICIPANT	\N	PRESENT	0
324707	324706	95037J	PARTICIPANT	\N	PRESENT	0
324708	324706	19563B	PARTICIPANT	\N	PRESENT	0
324783	314155	19731Y	PARTICIPANT	\N	PRESENT	0
324784	314155	14157T	PARTICIPANT	\N	PRESENT	0
324785	314155	14213J	PARTICIPANT	\N	PRESENT	0
324786	314155	19695N	PARTICIPANT	\N	PRESENT	0
324787	314155	14223L	PARTICIPANT	\N	PRESENT	0
324788	314155	14195A	PARTICIPANT	\N	PRESENT	0
324789	314155	01034P	PARTICIPANT	\N	PRESENT	0
324790	314155	14227Q	PARTICIPANT	\N	PRESENT	0
324791	314155	11045K	PARTICIPANT	\N	PRESENT	0
324792	314155	11103C	PARTICIPANT	\N	PRESENT	0
324793	314155	99004R	PARTICIPANT	\N	PRESENT	0
324794	314155	11040E	PARTICIPANT	\N	PRESENT	0
324795	314155	19760E	PARTICIPANT	\N	PRESENT	0
324796	314155	19415P	PARTICIPANT	\N	PRESENT	0
324797	314155	08052W	PARTICIPANT	\N	PRESENT	0
324798	314155	04092N	PARTICIPANT	\N	PRESENT	0
324799	314155	19569H	PARTICIPANT	\N	PRESENT	0
324800	314155	07029T	PARTICIPANT	\N	PRESENT	0
324801	314155	08047A	PARTICIPANT	\N	PRESENT	0
324802	314155	08010L	PARTICIPANT	\N	PRESENT	0
324803	314155	11097X	PARTICIPANT	\N	PRESENT	0
324804	314155	14071N	PARTICIPANT	\N	PRESENT	0
324805	314155	98024R	PARTICIPANT	\N	PRESENT	0
324806	314155	10006L	PARTICIPANT	\N	PRESENT	0
324807	314155	01048V	PARTICIPANT	\N	PRESENT	0
324808	314155	19683J	PARTICIPANT	\N	PRESENT	0
324809	314155	07004J	PARTICIPANT	\N	PRESENT	0
324810	314155	19697Q	PARTICIPANT	\N	PRESENT	0
324811	314155	19657G	PARTICIPANT	\N	PRESENT	0
324812	314155	08019V	PARTICIPANT	\N	PRESENT	0
324813	314155	19703U	PARTICIPANT	\N	PRESENT	0
324814	314155	14217N	PARTICIPANT	\N	PRESENT	0
324815	314155	14261S	PARTICIPANT	\N	PRESENT	0
324816	314155	14030Q	PARTICIPANT	\N	PRESENT	0
324817	314155	95062K	PARTICIPANT	\N	PRESENT	0
324818	314155	19575F	PARTICIPANT	\N	PRESENT	0
324819	314155	11031D	PARTICIPANT	\N	PRESENT	0
324820	314155	19515S	PARTICIPANT	\N	PRESENT	0
324821	314155	19553Y	PARTICIPANT	\N	PRESENT	0
324822	314155	14029X	PARTICIPANT	\N	PRESENT	0
324823	314155	11048N	PARTICIPANT	\N	PRESENT	0
324824	314155	19611R	PARTICIPANT	\N	PRESENT	0
324825	314155	19689Q	PARTICIPANT	\N	PRESENT	0
324826	314155	14281W	PARTICIPANT	\N	PRESENT	0
324827	314155	11067R	PARTICIPANT	\N	PRESENT	0
324828	314155	19691J	PARTICIPANT	\N	PRESENT	0
324829	314155	08034U	PARTICIPANT	\N	PRESENT	0
324902	314155	14083S	PARTICIPANT	\N	PRESENT	0
324834	314155	19621T	PARTICIPANT	\N	PRESENT	0
324837	314155	19629C	PARTICIPANT	\N	PRESENT	0
324838	314155	19727D	PARTICIPANT	\N	PRESENT	0
324839	314155	14239U	PARTICIPANT	\N	PRESENT	0
324840	314155	19711U	PARTICIPANT	\N	PRESENT	0
324841	314155	04086Q	PARTICIPANT	\N	PRESENT	0
324842	314155	17779H	PARTICIPANT	\N	PRESENT	0
324843	314155	19663E	PARTICIPANT	\N	PRESENT	0
324844	314155	14119M	PARTICIPANT	\N	PRESENT	0
324845	314155	04085P	PARTICIPANT	\N	PRESENT	0
324846	314155	19715Y	PARTICIPANT	\N	PRESENT	0
324847	314155	14042U	PARTICIPANT	\N	PRESENT	0
324848	314155	19479G	PARTICIPANT	\N	PRESENT	0
324849	314155	14249W	PARTICIPANT	\N	PRESENT	0
324851	314155	19737F	PARTICIPANT	\N	PRESENT	0
324852	314155	14107H	PARTICIPANT	\N	PRESENT	0
324856	314155	04034C	PARTICIPANT	\N	PRESENT	0
324857	314155	14021P	PARTICIPANT	\N	PRESENT	0
324858	314155	04045F	PARTICIPANT	\N	PRESENT	0
324781	314155	11072N	PARTICIPANT	\N	PRESENT	0
324782	314155	14331P	PARTICIPANT	\N	PRESENT	0
324859	314155	11033F	PARTICIPANT	\N	PRESENT	0
324860	314155	08017T	PARTICIPANT	\N	PRESENT	0
324861	321832	14053L	PARTICIPANT	\N	PRESENT	0
324862	321832	01057W	PARTICIPANT	\N	PRESENT	0
324863	321832	08015R	PARTICIPANT	\N	PRESENT	0
324864	321832	14063N	PARTICIPANT	\N	PRESENT	0
324865	321832	14001X	PARTICIPANT	\N	PRESENT	0
324866	321832	14215L	PARTICIPANT	\N	PRESENT	0
324867	321832	19671E	PARTICIPANT	\N	PRESENT	0
324868	321832	14259Y	PARTICIPANT	\N	PRESENT	0
324869	321832	19762G	PARTICIPANT	\N	PRESENT	0
324870	321832	19447X	PARTICIPANT	\N	PRESENT	0
324871	321832	14231L	PARTICIPANT	\N	PRESENT	0
324872	314155	19747H	PARTICIPANT	\N	PRESENT	0
324873	314155	19295A	PARTICIPANT	\N	PRESENT	0
324874	314155	14199E	PARTICIPANT	\N	PRESENT	0
324875	314155	04018C	PARTICIPANT	\N	PRESENT	0
324876	314155	04043D	PARTICIPANT	\N	PRESENT	0
324878	314155	11012A	PARTICIPANT	\N	PRESENT	0
324879	314155	19289C	PARTICIPANT	\N	PRESENT	0
324880	314155	19687N	PARTICIPANT	\N	PRESENT	0
324881	314155	08015R	PARTICIPANT	\N	PRESENT	0
324886	314155	19693L	PARTICIPANT	\N	PRESENT	0
324888	314155	19762G	PARTICIPANT	\N	PRESENT	0
324889	314155	01057W	PARTICIPANT	\N	PRESENT	0
324890	314155	19503N	PARTICIPANT	\N	PRESENT	0
324891	314155	19399H	PARTICIPANT	\N	PRESENT	0
324893	314155	19713W	PARTICIPANT	\N	PRESENT	0
324894	314155	11064N	PARTICIPANT	\N	PRESENT	0
324895	323962	04044E	PARTICIPANT	\N	PRESENT	0
324896	314155	14034U	PARTICIPANT	\N	PRESENT	0
324899	314155	14089Y	PARTICIPANT	\N	PRESENT	0
324900	314155	19527W	PARTICIPANT	\N	PRESENT	0
324901	314155	19723Y	PARTICIPANT	\N	PRESENT	0
324908	314155	19701S	PARTICIPANT	\N	PRESENT	0
324918	314155	14215L	PARTICIPANT	\N	PRESENT	0
324914	321832	19441R	PARTICIPANT	\N	PRESENT	0
324915	321832	05008E	PARTICIPANT	\N	PRESENT	0
324916	314155	14093U	PARTICIPANT	\N	PRESENT	0
324919	314155	17637T	PARTICIPANT	\N	PRESENT	0
324922	314155	04044E	PARTICIPANT	\N	PRESENT	0
304828	304827	11065P	PARTICIPANT	\N	PRESENT	0
304829	304827	14255U	PARTICIPANT	\N	PRESENT	0
305247	305246	11099A	PARTICIPANT	\N	PRESENT	0
315427	313634	11077T	PARTICIPANT	\N	PRESENT	0
315428	313634	14355X	PARTICIPANT	\N	PRESENT	0
315429	313634	19569H	PARTICIPANT	\N	PRESENT	0
315430	313634	11097X	PARTICIPANT	\N	PRESENT	0
315431	313634	19415P	PARTICIPANT	\N	PRESENT	0
315432	313634	14223L	PARTICIPANT	\N	PRESENT	0
315433	313634	14227Q	PARTICIPANT	\N	PRESENT	0
315434	313634	19675J	PARTICIPANT	\N	PRESENT	0
315435	313634	17779H	PARTICIPANT	\N	PRESENT	0
315436	313634	19703U	PARTICIPANT	\N	PRESENT	0
315437	313634	14239U	PARTICIPANT	\N	PRESENT	0
315438	313634	14281W	PARTICIPANT	\N	PRESENT	0
315439	313634	19679N	PARTICIPANT	\N	PRESENT	0
315440	313634	14042U	PARTICIPANT	\N	PRESENT	0
315441	313634	14195A	PARTICIPANT	\N	PRESENT	0
315442	313634	08048B	PARTICIPANT	\N	PRESENT	0
315443	313634	19575F	PARTICIPANT	\N	PRESENT	0
315444	313634	14213J	PARTICIPANT	\N	PRESENT	0
315445	313634	19367Y	PARTICIPANT	\N	PRESENT	0
315446	313634	14217N	PARTICIPANT	\N	PRESENT	0
315447	313634	19335Q	PARTICIPANT	\N	PRESENT	0
315448	313634	98024R	PARTICIPANT	\N	PRESENT	0
315449	313634	19521Q	PARTICIPANT	\N	PRESENT	0
315450	313634	01034P	PARTICIPANT	\N	PRESENT	0
315451	313634	04092N	PRESIDENT	0	PRESENT	0
315452	313634	08052W	PARTICIPANT	\N	PRESENT	0
315453	313634	19715Y	PARTICIPANT	\N	PRESENT	0
315454	313634	19723Y	PARTICIPANT	\N	PRESENT	0
315455	313634	19727D	PARTICIPANT	\N	PRESENT	0
315456	313634	14119M	PARTICIPANT	\N	PRESENT	0
315457	313634	11103C	PARTICIPANT	\N	PRESENT	0
315458	313634	19657G	PARTICIPANT	\N	PRESENT	0
315459	313634	19577H	PARTICIPANT	\N	PRESENT	0
315460	313634	19760E	PARTICIPANT	\N	PRESENT	0
315461	313634	19697Q	PARTICIPANT	\N	EXCUSE	0
315462	313634	14087W	PARTICIPANT	\N	EXCUSE	0
315463	313634	08041T	PARTICIPANT	\N	EXCUSE	0
315464	313988	19543W	PARTICIPANT	\N	PRESENT	0
315465	313988	19581D	PARTICIPANT	\N	PRESENT	0
315466	313988	04044E	PARTICIPANT	\N	PRESENT	0
315467	313988	19585H	PARTICIPANT	\N	PRESENT	0
315468	313988	19673G	PARTICIPANT	\N	PRESENT	0
315469	313988	01028R	PARTICIPANT	\N	PRESENT	0
315470	313988	05008E	PARTICIPANT	\N	PRESENT	0
315471	313988	19447X	PARTICIPANT	\N	PRESENT	0
315472	313988	14231L	PARTICIPANT	\N	PRESENT	0
315473	313988	14237S	PARTICIPANT	\N	PRESENT	0
315474	313988	19489J	PARTICIPANT	\N	PRESENT	0
315475	313988	14147R	PARTICIPANT	\N	PRESENT	0
315476	313988	14151M	PARTICIPANT	\N	PRESENT	0
315477	313988	14215L	PARTICIPANT	\N	PRESENT	0
315478	313988	14053L	PARTICIPANT	\N	PRESENT	0
315479	313988	98035U	PARTICIPANT	\N	PRESENT	0
315480	313988	14111D	PARTICIPANT	\N	PRESENT	0
315481	313988	07034Q	PRESIDENT	0	PRESENT	0
315482	313988	08045X	PARTICIPANT	\N	PRESENT	0
315483	313988	19253P	PARTICIPANT	\N	PRESENT	0
315484	313988	01024M	PARTICIPANT	\N	PRESENT	0
315485	313988	04038G	PARTICIPANT	\N	PRESENT	0
315486	313988	19719D	PARTICIPANT	\N	PRESENT	0
315487	313988	19725B	PARTICIPANT	\N	PRESENT	0
315488	313988	19729F	PARTICIPANT	\N	PRESENT	0
315489	313988	19629C	PARTICIPANT	\N	PRESENT	0
315490	313988	14021P	PARTICIPANT	\N	PRESENT	0
315491	314014	08009T	PRESIDENT	0	PRESENT	0
315492	314014	19701S	PARTICIPANT	\N	EXCUSE	0
315493	314014	96004D	PARTICIPANT	\N	EXCUSE	0
315494	314014	19685L	PARTICIPANT	\N	EXCUSE	0
315495	314014	19659J	PARTICIPANT	\N	EXCUSE	0
315496	314014	19681G	PARTICIPANT	\N	EXCUSE	0
315497	313988	14001X	PARTICIPANT	\N	PRESENT	0
315498	313988	01060R	PARTICIPANT	\N	PRESENT	0
315499	313988	14041T	PARTICIPANT	\N	PRESENT	0
315500	313988	08020N	PARTICIPANT	\N	PRESENT	0
315501	313988	14065Q	PARTICIPANT	\N	EXCUSE	0
315502	313943	19443T	PARTICIPANT	\N	PRESENT	0
315503	313943	95030B	PARTICIPANT	\N	PRESENT	0
315504	313943	14133K	PARTICIPANT	\N	PRESENT	0
315505	313943	04034C	PARTICIPANT	\N	PRESENT	0
315506	313943	14235Q	PARTICIPANT	\N	PRESENT	0
315507	313943	04040A	PARTICIPANT	\N	PRESENT	0
315508	313943	01058X	PARTICIPANT	\N	PRESENT	0
315509	313943	16685X	PARTICIPANT	\N	PRESENT	0
315510	313943	04042C	PRESIDENT	0	PRESENT	0
315511	313943	11054L	PARTICIPANT	\N	PRESENT	0
315512	313943	11066Q	PARTICIPANT	\N	PRESENT	0
315513	313943	19721W	PARTICIPANT	\N	PRESENT	0
315514	313943	14105F	PARTICIPANT	\N	PRESENT	0
315515	313943	98018T	PARTICIPANT	\N	PRESENT	0
315516	313943	19709B	PARTICIPANT	\N	PRESENT	0
315517	313943	98022P	PARTICIPANT	\N	PRESENT	0
315518	313943	14193X	PARTICIPANT	\N	PRESENT	0
315519	313943	97011G	PARTICIPANT	\N	PRESENT	0
315520	313943	14211G	PARTICIPANT	\N	PRESENT	0
315521	313943	14255U	PARTICIPANT	\N	PRESENT	0
315522	313943	08047A	PARTICIPANT	\N	PRESENT	0
315523	313943	19251M	PARTICIPANT	\N	PRESENT	0
315524	313943	08049C	PARTICIPANT	\N	PRESENT	0
315525	313943	11027H	PARTICIPANT	\N	PRESENT	0
315526	313943	98005N	PARTICIPANT	\N	PRESENT	0
315527	313943	08061X	PARTICIPANT	\N	PRESENT	0
315529	313943	04035D	PARTICIPANT	\N	PRESENT	0
315531	313943	95037J	PARTICIPANT	\N	PRESENT	0
315532	313988	04047H	PARTICIPANT	\N	PRESENT	0
315533	313988	19649G	PARTICIPANT	\N	PRESENT	0
315534	313988	14179A	PARTICIPANT	\N	EXCUSE	0
315535	313943	95067Q	PARTICIPANT	\N	PRESENT	0
315536	313988	11049P	PARTICIPANT	\N	PRESENT	0
315537	313943	08053X	PARTICIPANT	\N	PRESENT	0
315538	313634	11067R	PARTICIPANT	\N	PRESENT	0
315539	313634	19553Y	PARTICIPANT	\N	PRESENT	0
315540	313634	11031D	PARTICIPANT	\N	PRESENT	0
315541	313634	10006L	PARTICIPANT	\N	PRESENT	0
315542	313634	19527W	PARTICIPANT	\N	PRESENT	0
315543	313634	19479G	PARTICIPANT	\N	PRESENT	0
315544	313634	19663E	PARTICIPANT	\N	PRESENT	0
315545	313943	14097Y	PARTICIPANT	\N	PRESENT	0
315546	313943	08056B	PARTICIPANT	\N	PRESENT	0
315547	313943	08058D	PARTICIPANT	\N	PRESENT	0
315548	313986	14327T	PARTICIPANT	\N	PRESENT	0
315549	313986	14331P	PARTICIPANT	\N	PRESENT	0
315550	313986	04071H	PARTICIPANT	\N	PRESENT	0
315551	313986	19545Y	PARTICIPANT	\N	PRESENT	0
315552	313986	11053K	PARTICIPANT	\N	PRESENT	0
315553	313986	11074Q	PRESIDENT	0	PRESENT	0
315554	313986	19667J	PARTICIPANT	\N	PRESENT	0
315555	313986	89017R	PARTICIPANT	\N	PRESENT	0
315556	313986	88008L	PARTICIPANT	\N	PRESENT	0
315557	313986	14225N	PARTICIPANT	\N	PRESENT	0
315558	313986	14085U	PARTICIPANT	\N	PRESENT	0
315559	313986	19349W	PARTICIPANT	\N	PRESENT	0
315560	313986	08010L	PARTICIPANT	\N	PRESENT	0
315561	313986	14253S	PARTICIPANT	\N	PRESENT	0
315562	313986	11048N	PARTICIPANT	\N	PRESENT	0
315563	313986	19711U	PARTICIPANT	\N	PRESENT	0
315564	313986	19531S	PARTICIPANT	\N	PRESENT	0
315565	313986	19687N	PARTICIPANT	\N	PRESENT	0
315566	313986	12016W	PARTICIPANT	\N	PRESENT	0
315567	313986	14173T	PARTICIPANT	\N	PRESENT	0
315568	313986	11040E	PARTICIPANT	\N	PRESENT	0
315569	313986	04086Q	PARTICIPANT	\N	PRESENT	0
315570	313986	14199E	PARTICIPANT	\N	PRESENT	0
315571	313986	08073C	PARTICIPANT	\N	PRESENT	0
315572	313986	14121F	PARTICIPANT	\N	PRESENT	0
315573	313986	19741B	PARTICIPANT	\N	PRESENT	0
315574	313986	11012A	PARTICIPANT	\N	EXCUSE	0
315575	313986	07004J	PARTICIPANT	\N	EXCUSE	0
315576	313986	08069G	PARTICIPANT	\N	PRESENT	0
315577	313986	08014Q	PARTICIPANT	\N	EXCUSE	0
315578	314014	14038Y	PARTICIPANT	\N	PRESENT	0
315579	314014	19333N	PARTICIPANT	\N	PRESENT	0
315580	314014	17583W	PARTICIPANT	\N	PRESENT	0
315581	314014	19387D	PARTICIPANT	\N	PRESENT	0
315582	314014	08055A	PARTICIPANT	\N	PRESENT	0
315583	314014	19599P	PARTICIPANT	\N	PRESENT	0
315584	314014	18083K	PARTICIPANT	\N	PRESENT	0
315585	314014	15447F	PARTICIPANT	\N	PRESENT	0
315586	314014	19503N	PARTICIPANT	\N	PRESENT	0
315587	314014	19347U	PARTICIPANT	\N	PRESENT	0
315588	314014	19739H	PARTICIPANT	\N	PRESENT	0
315589	314014	14157T	PARTICIPANT	\N	PRESENT	0
315590	314014	17637T	PARTICIPANT	\N	PRESENT	0
315594	314014	19695N	PARTICIPANT	\N	PRESENT	0
315595	314014	14029X	PARTICIPANT	\N	PRESENT	0
315596	314014	04049K	PARTICIPANT	\N	PRESENT	0
315597	314014	19745F	PARTICIPANT	\N	PRESENT	0
316912	311724	08073C	PARTICIPANT	\N	PRESENT	0
316913	311724	14331P	PARTICIPANT	\N	EXCUSE	0
317452	317451	14159V	PARTICIPANT	\N	PRESENT	0
317453	317451	11110B	PARTICIPANT	\N	PRESENT	0
317455	317454	11074Q	PARTICIPANT	\N	PRESENT	0
317456	317454	08011M	PARTICIPANT	\N	PRESENT	0
317458	317457	08069G	PARTICIPANT	\N	PRESENT	0
317460	317459	07029T	PARTICIPANT	\N	PRESENT	0
317462	317461	14331P	PARTICIPANT	\N	PRESENT	0
317464	317463	14331P	PARTICIPANT	\N	PRESENT	0
317466	317465	95041E	PARTICIPANT	\N	PRESENT	0
317468	317467	19545Y	PARTICIPANT	\N	PRESENT	0
317469	317467	19689Q	PARTICIPANT	\N	PRESENT	0
317471	317470	01048V	PARTICIPANT	\N	PRESENT	0
317477	317472	19689Q	PARTICIPANT	\N	PRESENT	0
317478	317472	19545Y	PARTICIPANT	\N	PRESENT	0
317482	317481	01048V	PARTICIPANT	\N	PRESENT	0
317484	317483	19545Y	PARTICIPANT	\N	PRESENT	0
317485	317483	19689Q	PARTICIPANT	\N	PRESENT	0
317488	317487	19689Q	PARTICIPANT	\N	PRESENT	0
317490	317489	19689Q	PARTICIPANT	\N	PRESENT	0
317491	313991	04071H	PARTICIPANT	\N	PRESENT	0
318498	318463	14229S	PARTICIPANT	\N	PRESENT	0
318499	318463	19593H	PARTICIPANT	\N	EXCUSE	0
318500	318463	14033T	PARTICIPANT	\N	PRESENT	0
318501	318463	14237S	PARTICIPANT	\N	PRESENT	0
318502	318463	95063L	PARTICIPANT	\N	PRESENT	0
318503	318463	14213J	PARTICIPANT	\N	PRESENT	0
318504	318463	14207L	PARTICIPANT	\N	PRESENT	0
318505	318463	19747H	PARTICIPANT	\N	PRESENT	0
318570	318541	04061F	PARTICIPANT	\N	PRESENT	0
318603	318602	11048N	PARTICIPANT	\N	PRESENT	0
318678	318677	14105F	PARTICIPANT	\N	PRESENT	0
318679	318677	19383Y	PARTICIPANT	\N	PRESENT	0
318680	318677	14207L	PARTICIPANT	\N	PRESENT	0
318681	318677	11103C	PARTICIPANT	\N	PRESENT	0
318682	318677	14329V	PARTICIPANT	\N	PRESENT	0
318752	318750	04047H	PARTICIPANT	\N	PRESENT	0
318753	318750	11026G	PARTICIPANT	\N	PRESENT	0
318794	318793	14111D	PARTICIPANT	\N	PRESENT	0
318796	318795	19729F	PARTICIPANT	\N	PRESENT	0
319210	319209	11048N	PARTICIPANT	\N	PRESENT	0
319212	319211	14327T	PARTICIPANT	\N	PRESENT	0
319230	318988	14071N	PARTICIPANT	\N	PRESENT	0
319231	318989	14071N	PARTICIPANT	\N	PRESENT	0
319233	318990	14071N	PARTICIPANT	\N	PRESENT	0
319234	318991	14071N	PARTICIPANT	\N	PRESENT	0
319255	319254	19533U	PARTICIPANT	\N	PRESENT	0
319256	319254	19611R	PARTICIPANT	\N	PRESENT	0
319257	319254	14229S	PARTICIPANT	\N	PRESENT	0
319258	318797	04044E	PARTICIPANT	\N	EXCUSE	0
319260	319259	08068F	PARTICIPANT	\N	PRESENT	0
319264	319263	08068F	PARTICIPANT	\N	PRESENT	0
319266	319265	14081Q	PARTICIPANT	\N	PRESENT	0
319268	319267	14081Q	PARTICIPANT	\N	PRESENT	0
319270	319269	14081Q	PARTICIPANT	\N	PRESENT	0
319272	319271	14205J	PARTICIPANT	\N	PRESENT	0
319274	319273	14205J	PARTICIPANT	\N	PRESENT	0
319288	319287	14157T	PARTICIPANT	\N	PRESENT	0
319290	319289	14157T	PARTICIPANT	\N	PRESENT	0
319292	319291	14051J	PARTICIPANT	\N	PRESENT	0
319294	319293	98023Q	PARTICIPANT	\N	PRESENT	0
319295	319293	19681G	PARTICIPANT	\N	PRESENT	0
319297	319296	98023Q	PARTICIPANT	\N	PRESENT	0
319299	319298	14215L	PARTICIPANT	\N	PRESENT	0
319420	319413	14039A	PARTICIPANT	\N	PRESENT	0
319463	319338	14123H	PARTICIPANT	\N	PRESENT	0
319510	319508	14213J	PARTICIPANT	\N	PRESENT	0
319514	319513	14213J	PARTICIPANT	\N	PRESENT	0
319906	317558	19563B	PARTICIPANT	\N	EXCUSE	0
320032	318025	14051J	PARTICIPANT	\N	PRESENT	0
320033	318025	19737F	PARTICIPANT	\N	PRESENT	0
320034	318025	14221J	PARTICIPANT	\N	PRESENT	0
320035	318025	14093U	PARTICIPANT	\N	PRESENT	0
320036	318025	08055A	PARTICIPANT	\N	PRESENT	0
320037	318025	19551W	PARTICIPANT	\N	PRESENT	0
320038	318025	19599P	PARTICIPANT	\N	PRESENT	0
320039	318025	14038Y	PARTICIPANT	\N	PRESENT	0
320040	318025	17583W	PARTICIPANT	\N	PRESENT	0
320041	318025	19637C	PARTICIPANT	\N	PRESENT	0
320042	318025	18083K	PARTICIPANT	\N	PRESENT	0
320043	318025	19745F	PARTICIPANT	\N	PRESENT	0
320044	318025	19681G	PARTICIPANT	\N	PRESENT	0
320045	318025	14219Q	PARTICIPANT	\N	PRESENT	0
320046	318025	15447F	PARTICIPANT	\N	PRESENT	0
320134	320133	19729F	PARTICIPANT	\N	PRESENT	0
320135	320133	19719D	PARTICIPANT	\N	PRESENT	0
320136	320133	19581D	PARTICIPANT	\N	PRESENT	0
320138	320137	14179A	PARTICIPANT	\N	PRESENT	0
320193	320192	19667J	PARTICIPANT	\N	PRESENT	0
320194	320192	14255U	PARTICIPANT	\N	PRESENT	0
320195	320192	19701S	PARTICIPANT	\N	PRESENT	0
320196	320192	14281W	PARTICIPANT	\N	PRESENT	0
320197	320192	11049P	PARTICIPANT	\N	PRESENT	0
320198	320192	19671E	PARTICIPANT	\N	PRESENT	0
320231	318797	14327T	PARTICIPANT	\N	EXCUSE	0
320235	318038	19551W	PARTICIPANT	\N	PRESENT	0
320314	320098	19766L	PARTICIPANT	\N	PRESENT	0
320315	320098	04070G	PRESIDENT	0	PRESENT	0
320316	320098	19699S	PARTICIPANT	\N	PRESENT	0
320317	320098	19533U	PARTICIPANT	\N	PRESENT	0
320318	320098	19329S	PARTICIPANT	\N	PRESENT	0
320319	320098	04033B	PARTICIPANT	\N	PRESENT	0
320320	320098	14229S	PARTICIPANT	\N	PRESENT	0
320321	320098	19573D	PARTICIPANT	\N	PRESENT	0
320322	320098	14039A	PARTICIPANT	\N	PRESENT	0
320323	320098	14107H	PARTICIPANT	\N	PRESENT	0
320324	320098	08017T	PARTICIPANT	\N	PRESENT	0
320325	320098	92040Q	PARTICIPANT	\N	PRESENT	0
320326	320098	07033P	PARTICIPANT	\N	PRESENT	0
320327	320098	08012N	PARTICIPANT	\N	PRESENT	0
320328	320098	08039A	PARTICIPANT	\N	PRESENT	0
320329	320098	08031R	PARTICIPANT	\N	PRESENT	0
320330	320098	19593H	PARTICIPANT	\N	PRESENT	0
320331	320098	19643A	PARTICIPANT	\N	PRESENT	0
320332	320098	14059S	PARTICIPANT	\N	PRESENT	0
320333	320098	04057K	PARTICIPANT	\N	PRESENT	0
320334	320098	14073Q	PARTICIPANT	\N	PRESENT	0
320335	320098	08035V	PARTICIPANT	\N	PRESENT	0
320336	320098	19611R	PARTICIPANT	\N	PRESENT	0
320337	320098	08043V	PARTICIPANT	\N	PRESENT	0
320338	320098	19693L	PARTICIPANT	\N	PRESENT	0
320339	320098	19399H	PARTICIPANT	\N	PRESENT	0
320340	320098	87003B	PARTICIPANT	\N	PRESENT	0
320341	320098	14201E	PARTICIPANT	\N	PRESENT	0
320342	320098	14030Q	PARTICIPANT	\N	PRESENT	0
320343	320098	19731Y	PARTICIPANT	\N	PRESENT	0
320344	320098	08020N	PARTICIPANT	\N	PRESENT	0
320345	320098	14251Q	PARTICIPANT	\N	PRESENT	0
320346	320098	19735D	PARTICIPANT	\N	PRESENT	0
320347	320098	14063N	PARTICIPANT	\N	PRESENT	0
320348	320098	11083R	PARTICIPANT	\N	PRESENT	0
320349	320098	14123H	PARTICIPANT	\N	PRESENT	0
320350	320098	11104D	PARTICIPANT	\N	PRESENT	0
320351	320098	11043H	PARTICIPANT	\N	PRESENT	0
320352	320098	19758L	PARTICIPANT	\N	PRESENT	0
320353	320098	04018C	PARTICIPANT	\N	PRESENT	0
320354	320098	19621T	PARTICIPANT	\N	PRESENT	0
320355	320098	19749K	PARTICIPANT	\N	PRESENT	0
320356	320098	14061L	PARTICIPANT	\N	EXCUSE	0
320357	320098	14109K	PARTICIPANT	\N	EXCUSE	0
320358	320098	14249W	PARTICIPANT	\N	EXCUSE	0
320360	318859	11027H	PARTICIPANT	\N	PRESENT	0
320361	318859	11064N	PARTICIPANT	\N	PRESENT	0
320362	320098	14241N	PARTICIPANT	\N	EXCUSE	0
320364	319275	08034U	PARTICIPANT	\N	PRESENT	0
320365	319275	14071N	PARTICIPANT	\N	PRESENT	0
320367	314105	04044E	PARTICIPANT	\N	PRESENT	0
320368	314105	14157T	PARTICIPANT	\N	PRESENT	0
320369	314105	14223L	PARTICIPANT	\N	PRESENT	0
320370	314105	04089T	PARTICIPANT	\N	PRESENT	0
320371	314105	14079W	PARTICIPANT	\N	PRESENT	0
320373	320372	04040A	PARTICIPANT	\N	PRESENT	0
320374	320372	17589D	PARTICIPANT	\N	PRESENT	0
320375	320372	11083R	PARTICIPANT	\N	PRESENT	0
320376	320372	14073Q	PARTICIPANT	\N	PRESENT	0
320377	320372	14237S	PARTICIPANT	\N	PRESENT	0
320378	320372	95063L	PARTICIPANT	\N	PRESENT	0
320379	320372	98035U	PARTICIPANT	\N	PRESENT	0
320381	320372	04034C	PARTICIPANT	\N	PRESENT	0
320382	314105	11103C	PARTICIPANT	\N	PRESENT	0
320383	314105	04088S	PARTICIPANT	\N	PRESENT	0
320384	314105	19747H	PARTICIPANT	\N	PRESENT	0
320385	314105	19335Q	PARTICIPANT	\N	PRESENT	0
320386	314105	19593H	PARTICIPANT	\N	PRESENT	0
304406	304405	95015C	PARTICIPANT	\N	PRESENT	0
304407	304405	08043V	PARTICIPANT	\N	PRESENT	0
304408	304405	04038G	PARTICIPANT	\N	PRESENT	0
304409	304405	97011G	PARTICIPANT	\N	PRESENT	0
304410	304405	11083R	PARTICIPANT	\N	PRESENT	0
304411	304405	04070G	PARTICIPANT	\N	PRESENT	0
304412	304405	05012A	PARTICIPANT	\N	PRESENT	0
304413	304405	14179A	PARTICIPANT	\N	PRESENT	0
306098	306009	98029W	PARTICIPANT	\N	PRESENT	0
306099	306009	19349W	PARTICIPANT	\N	PRESENT	0
306100	306009	95037J	PARTICIPANT	\N	PRESENT	0
306101	306009	14039A	PARTICIPANT	\N	PRESENT	0
306102	306009	95063L	PARTICIPANT	\N	PRESENT	0
306103	306009	14107H	PARTICIPANT	\N	PRESENT	0
306104	306009	19563B	PARTICIPANT	\N	PRESENT	0
306105	306009	11012A	PARTICIPANT	\N	PRESENT	0
306106	306009	08031R	PARTICIPANT	\N	PRESENT	0
306107	306009	98022P	PARTICIPANT	\N	PRESENT	0
306108	306009	08061X	PARTICIPANT	\N	PRESENT	0
306109	306009	04045F	PARTICIPANT	\N	PRESENT	0
306110	306009	19637C	PARTICIPANT	\N	PRESENT	0
306111	306009	19681G	PARTICIPANT	\N	PRESENT	0
306112	306009	19253P	PARTICIPANT	\N	PRESENT	0
306113	306009	08016S	PARTICIPANT	\N	PRESENT	0
306114	306009	14081Q	PARTICIPANT	\N	PRESENT	0
306115	306009	01028R	PARTICIPANT	\N	PRESENT	0
306116	306009	08052W	PARTICIPANT	\N	PRESENT	0
306117	306009	08055A	PARTICIPANT	\N	PRESENT	0
306118	306009	11040E	PARTICIPANT	\N	PRESENT	0
306119	306009	04085P	PARTICIPANT	\N	PRESENT	0
306120	306009	19695N	PARTICIPANT	\N	PRESENT	0
306121	306009	19697Q	PARTICIPANT	\N	PRESENT	0
306122	306009	19687N	PARTICIPANT	\N	PRESENT	0
306123	306009	19593H	PARTICIPANT	\N	PRESENT	0
306124	306009	11056N	PARTICIPANT	\N	PRESENT	0
306125	306009	19758L	PARTICIPANT	\N	PRESENT	0
306126	306009	11033F	PARTICIPANT	\N	PRESENT	0
306127	306009	19766L	PARTICIPANT	\N	PRESENT	0
306128	306009	19347U	PARTICIPANT	\N	PRESENT	0
306129	306009	11054L	PARTICIPANT	\N	PRESENT	0
306130	306009	19565D	PARTICIPANT	\N	PRESENT	0
306131	306009	14259Y	PARTICIPANT	\N	PRESENT	0
306132	306009	19545Y	PARTICIPANT	\N	PRESENT	0
306133	306009	14111D	PARTICIPANT	\N	PRESENT	0
306134	306009	14211G	PARTICIPANT	\N	PRESENT	0
306135	306009	14239U	PARTICIPANT	\N	PRESENT	0
306136	306009	19711U	PARTICIPANT	\N	PRESENT	0
306137	306009	11083R	PARTICIPANT	\N	PRESENT	0
306138	306009	04008A	PARTICIPANT	\N	PRESENT	0
306139	306009	08073C	PARTICIPANT	\N	PRESENT	0
306140	306009	19651A	PARTICIPANT	\N	PRESENT	0
306141	306009	99004R	PARTICIPANT	\N	PRESENT	0
306142	306009	11072N	PARTICIPANT	\N	PRESENT	0
306143	306009	19269X	PARTICIPANT	\N	PRESENT	0
306144	306009	01058X	PARTICIPANT	\N	PRESENT	0
306145	306009	19731Y	PARTICIPANT	\N	PRESENT	0
306146	306009	14157T	PARTICIPANT	\N	PRESENT	0
306147	306009	14261S	PARTICIPANT	\N	PRESENT	0
306148	306009	14034U	PARTICIPANT	\N	PRESENT	0
306149	306009	14241N	PARTICIPANT	\N	PRESENT	0
306150	306009	14041T	PARTICIPANT	\N	PRESENT	0
306151	306009	19629C	PARTICIPANT	\N	PRESENT	0
306152	306009	08049C	PARTICIPANT	\N	PRESENT	0
306153	306009	19709B	PARTICIPANT	\N	PRESENT	0
306154	306009	08039A	PARTICIPANT	\N	PRESENT	0
306155	306009	19443T	PARTICIPANT	\N	PRESENT	0
306156	306009	19705W	PARTICIPANT	\N	PRESENT	0
306157	306009	19289C	PARTICIPANT	\N	PRESENT	0
306158	306009	14029X	PARTICIPANT	\N	PRESENT	0
306159	306009	04088S	PARTICIPANT	\N	PRESENT	0
306160	306009	11099A	PARTICIPANT	\N	PRESENT	0
306161	306009	19387D	PARTICIPANT	\N	PRESENT	0
306162	306009	19663E	PARTICIPANT	\N	PRESENT	0
306163	306009	19553Y	PARTICIPANT	\N	PRESENT	0
306164	306009	14135M	PARTICIPANT	\N	PRESENT	0
306165	306009	19719D	PARTICIPANT	\N	PRESENT	0
306166	306009	14033T	PARTICIPANT	\N	PRESENT	0
306167	306009	19717B	PARTICIPANT	\N	PRESENT	0
306168	306009	19415P	PARTICIPANT	\N	PRESENT	0
306169	306009	18083K	PARTICIPANT	\N	PRESENT	0
306170	306009	19467C	PARTICIPANT	\N	PRESENT	0
306171	306009	11080N	PARTICIPANT	\N	PRESENT	0
306172	306009	14093U	PARTICIPANT	\N	PRESENT	0
306173	306009	19507S	PARTICIPANT	\N	PRESENT	0
306174	306009	19723Y	PARTICIPANT	\N	PRESENT	0
306175	306009	17589D	PARTICIPANT	\N	PRESENT	0
306176	306009	19585H	PARTICIPANT	\N	PRESENT	0
306177	306009	04057K	PARTICIPANT	\N	PRESENT	0
306178	306009	14038Y	PARTICIPANT	\N	PRESENT	0
306179	306009	14173T	PARTICIPANT	\N	PRESENT	0
306180	306009	02002K	PARTICIPANT	\N	PRESENT	0
306181	306009	19447X	PARTICIPANT	\N	PRESENT	0
306182	306009	19573D	PARTICIPANT	\N	PRESENT	0
306183	306009	14251Q	PARTICIPANT	\N	PRESENT	0
306184	306009	14133K	PARTICIPANT	\N	PRESENT	0
306185	306009	19583F	PARTICIPANT	\N	PRESENT	0
306186	306009	11064N	PARTICIPANT	\N	PRESENT	0
306187	306009	92040Q	PARTICIPANT	\N	PRESENT	0
306188	306009	14195A	PARTICIPANT	\N	PRESENT	0
306189	306009	14119M	PARTICIPANT	\N	PRESENT	0
306190	306009	11049P	PARTICIPANT	\N	PRESENT	0
306191	306009	11074Q	PARTICIPANT	\N	PRESENT	0
306192	306009	04059M	PARTICIPANT	\N	PRESENT	0
306193	306009	11077T	PARTICIPANT	\N	PRESENT	0
306194	306009	14159V	PARTICIPANT	\N	PRESENT	0
306195	306009	19575F	PARTICIPANT	\N	PRESENT	0
306196	306009	14229S	PARTICIPANT	\N	PRESENT	0
306197	306009	11048N	PARTICIPANT	\N	PRESENT	0
306198	306009	04097T	PARTICIPANT	\N	PRESENT	0
306199	306009	98023Q	PARTICIPANT	\N	PRESENT	0
306200	306009	19599P	PARTICIPANT	\N	PRESENT	0
306201	306009	14051J	PARTICIPANT	\N	PRESENT	0
306202	306009	14105F	PARTICIPANT	\N	PRESENT	0
306203	306009	14225N	PARTICIPANT	\N	PRESENT	0
306204	306009	19669L	PARTICIPANT	\N	PRESENT	0
306205	306009	08047A	PARTICIPANT	\N	PRESENT	0
306206	306009	14021P	PARTICIPANT	\N	PRESENT	0
306207	306009	01062T	PARTICIPANT	\N	PRESENT	0
306208	306009	08060W	PARTICIPANT	\N	PRESENT	0
306209	306009	08043V	PARTICIPANT	\N	PRESENT	0
306210	306009	11066Q	PARTICIPANT	\N	PRESENT	0
306211	306009	04071H	PARTICIPANT	\N	PRESENT	0
306212	306009	19527W	PARTICIPANT	\N	PRESENT	0
306213	306009	14147R	PARTICIPANT	\N	PRESENT	0
306214	306009	04049K	PARTICIPANT	\N	PRESENT	0
306215	306009	14281W	PARTICIPANT	\N	PRESENT	0
306216	306009	14213J	PARTICIPANT	\N	PRESENT	0
306217	306009	11104D	PARTICIPANT	\N	PRESENT	0
306218	306009	14063N	PARTICIPANT	\N	PRESENT	0
306219	306009	14265W	PARTICIPANT	\N	PRESENT	0
306220	306009	14001X	PARTICIPANT	\N	PRESENT	0
306221	306009	08053X	PARTICIPANT	\N	PRESENT	0
306223	306009	08017T	PARTICIPANT	\N	PRESENT	0
306224	306009	11026G	PARTICIPANT	\N	PRESENT	0
306225	306009	19693L	PARTICIPANT	\N	PRESENT	0
306226	306009	19399H	PARTICIPANT	\N	PRESENT	0
306227	306009	14227Q	PARTICIPANT	\N	PRESENT	0
306228	306009	95062K	PARTICIPANT	\N	PRESENT	0
306229	306009	14257W	PARTICIPANT	\N	PRESENT	0
306230	306009	14207L	PARTICIPANT	\N	PRESENT	0
306231	306009	19703U	PARTICIPANT	\N	PRESENT	0
306232	306009	19549D	PARTICIPANT	\N	PRESENT	0
306233	306009	19673G	PARTICIPANT	\N	PRESENT	0
306234	306009	11041F	PARTICIPANT	\N	PRESENT	0
306235	306009	14031R	PARTICIPANT	\N	PRESENT	0
306236	306009	19251M	PARTICIPANT	\N	PRESENT	0
306237	306009	11043H	PARTICIPANT	\N	PRESENT	0
306238	306009	11115U	PARTICIPANT	\N	PRESENT	0
306239	306009	19329S	PARTICIPANT	\N	PRESENT	0
306240	306009	08069G	PARTICIPANT	\N	PRESENT	0
306241	306009	19725B	PARTICIPANT	\N	PRESENT	0
306242	306009	19515S	PARTICIPANT	\N	PRESENT	0
306243	306009	19631V	PARTICIPANT	\N	PRESENT	0
306244	306009	80027E	PARTICIPANT	\N	PRESENT	0
306245	306009	19551W	PARTICIPANT	\N	PRESENT	0
306246	306009	08010L	PARTICIPANT	\N	PRESENT	0
306247	306009	19489J	PARTICIPANT	\N	PRESENT	0
306248	306009	87003B	PARTICIPANT	\N	PRESENT	0
306249	306009	19333N	PARTICIPANT	\N	PRESENT	0
306250	306009	19503N	PARTICIPANT	\N	PRESENT	0
306251	306009	11067R	PARTICIPANT	\N	PRESENT	0
306252	306009	95067Q	PARTICIPANT	\N	PRESENT	0
306253	306009	11090Q	PARTICIPANT	\N	PRESENT	0
306254	306009	17779H	PARTICIPANT	\N	PRESENT	0
306255	306009	19591F	PARTICIPANT	\N	PRESENT	0
306256	306009	14069U	PARTICIPANT	\N	PRESENT	0
306257	306009	08058D	PARTICIPANT	\N	PRESENT	0
324979	314156	11031D	PARTICIPANT	\N	PRESENT	0
324980	314156	19760E	PARTICIPANT	\N	PRESENT	0
324981	314156	19695N	PARTICIPANT	\N	PRESENT	0
324982	314156	19715Y	PARTICIPANT	\N	PRESENT	0
324983	314156	11045K	PARTICIPANT	\N	PRESENT	0
324984	314156	19727D	PARTICIPANT	\N	PRESENT	0
324985	314156	14227Q	PARTICIPANT	\N	PRESENT	0
324986	314156	14281W	PARTICIPANT	\N	PRESENT	0
324987	314156	19683J	PARTICIPANT	\N	PRESENT	0
324988	314156	08052W	PARTICIPANT	\N	PRESENT	0
324989	314156	19329S	PARTICIPANT	\N	PRESENT	0
324990	314156	04045F	PARTICIPANT	\N	PRESENT	0
324991	314156	14239U	PARTICIPANT	\N	PRESENT	0
324992	314156	19415P	PARTICIPANT	\N	PRESENT	0
324993	314156	19697Q	PARTICIPANT	\N	PRESENT	0
324994	314156	08047A	PARTICIPANT	\N	PRESENT	0
324995	314156	14261S	PARTICIPANT	\N	PRESENT	0
324996	314156	19657G	PARTICIPANT	\N	PRESENT	0
324997	314156	19621T	PARTICIPANT	\N	PRESENT	0
324998	314156	04018C	PARTICIPANT	\N	PRESENT	0
324999	314156	19701S	PARTICIPANT	\N	PRESENT	0
325000	314156	14042U	PARTICIPANT	\N	PRESENT	0
325001	314156	19289C	PARTICIPANT	\N	PRESENT	0
325002	314156	14223L	PARTICIPANT	\N	PRESENT	0
325003	314156	10006L	PARTICIPANT	\N	PRESENT	0
325004	314156	19663E	PARTICIPANT	\N	PRESENT	0
325005	314156	98024R	PARTICIPANT	\N	PRESENT	0
325006	314156	04044E	PARTICIPANT	\N	PRESENT	0
325007	314156	14071N	PARTICIPANT	\N	PRESENT	0
325008	314156	14213J	PARTICIPANT	\N	PRESENT	0
325009	314156	14217N	PARTICIPANT	\N	PRESENT	0
325010	314156	11067R	PARTICIPANT	\N	PRESENT	0
325011	314156	08069G	PARTICIPANT	\N	PRESENT	0
325012	314156	19515S	PARTICIPANT	\N	PRESENT	0
325013	314156	14215L	PARTICIPANT	\N	PRESENT	0
325014	314156	11097X	PARTICIPANT	\N	PRESENT	0
325015	314156	19553Y	PARTICIPANT	\N	PRESENT	0
325016	314156	19575F	PARTICIPANT	\N	PRESENT	0
325017	314156	19577H	PARTICIPANT	\N	PRESENT	0
325018	314156	01034P	PARTICIPANT	\N	PRESENT	0
325019	314156	14021P	PARTICIPANT	\N	PRESENT	0
324977	314156	04086Q	PARTICIPANT	\N	PRESENT	0
324978	314156	04092N	PARTICIPANT	\N	PRESENT	0
325020	314156	14093U	PARTICIPANT	\N	PRESENT	0
325021	314156	19693L	PARTICIPANT	\N	PRESENT	0
325022	314156	17779H	PARTICIPANT	\N	PRESENT	0
325023	314156	11012A	PARTICIPANT	\N	PRESENT	0
325024	314156	14119M	PARTICIPANT	\N	PRESENT	0
325025	314156	19713W	PARTICIPANT	\N	PRESENT	0
325026	314156	17637T	PARTICIPANT	\N	PRESENT	0
325066	325065	01024M	PARTICIPANT	\N	PRESENT	0
325161	323962	08048B	PARTICIPANT	\N	EXCUSE	0
325177	323962	19735D	PARTICIPANT	\N	EXCUSE	0
325183	325182	14001X	PARTICIPANT	\N	PRESENT	0
325184	325182	14215L	PARTICIPANT	\N	PRESENT	0
325189	314158	19399H	PARTICIPANT	\N	PRESENT	0
325209	325208	10015M	PARTICIPANT	\N	PRESENT	0
325211	325210	04049K	PARTICIPANT	\N	PRESENT	0
325212	325210	14083S	PARTICIPANT	\N	PRESENT	0
325214	325213	04049K	PARTICIPANT	\N	PRESENT	0
325215	322759	19631V	PARTICIPANT	\N	EXCUSE	0
325319	325318	04042C	PARTICIPANT	\N	PRESENT	0
325320	325318	19741B	PARTICIPANT	\N	PRESENT	0
325321	325318	11083R	PARTICIPANT	\N	PRESENT	0
325322	325318	19611R	PARTICIPANT	\N	PRESENT	0
325334	322759	14331P	PARTICIPANT	\N	EXCUSE	0
325335	322759	14225N	PARTICIPANT	\N	EXCUSE	0
325336	322759	19583F	PARTICIPANT	\N	EXCUSE	0
325337	322759	19691J	PARTICIPANT	\N	EXCUSE	0
326327	325382	14034U	PARTICIPANT	\N	PRESENT	0
326328	325382	19531S	PARTICIPANT	\N	PRESENT	0
326786	326519	19693L	PARTICIPANT	\N	EXCUSE	0
326787	326519	14123H	PARTICIPANT	\N	PRESENT	0
326844	324696	19737F	PARTICIPANT	\N	PRESENT	0
326845	324696	08009T	PARTICIPANT	\N	EXCUSE	0
326847	325784	19619A	PARTICIPANT	\N	PRESENT	0
326853	326519	19758L	PARTICIPANT	\N	EXCUSE	0
326854	326521	19758L	PARTICIPANT	\N	EXCUSE	0
327603	323962	04045F	PARTICIPANT	\N	EXCUSE	0
327607	326974	11048N	PARTICIPANT	\N	EXCUSE	0
327633	327587	08017T	PARTICIPANT	\N	EXCUSE	0
327609	322456	19349W	PARTICIPANT	\N	PRESENT	0
327610	322456	08062Y	PARTICIPANT	\N	PRESENT	0
327611	322456	19515S	PARTICIPANT	\N	PRESENT	0
327632	327587	19399H	PARTICIPANT	\N	EXCUSE	0
327634	327587	14063N	PARTICIPANT	\N	EXCUSE	0
327749	327748	14069U	PARTICIPANT	\N	PRESENT	0
327750	327748	14083S	PARTICIPANT	\N	PRESENT	0
327751	327748	11053K	PARTICIPANT	\N	PRESENT	0
327752	327748	19333N	PARTICIPANT	\N	PRESENT	0
327753	327748	11048N	PARTICIPANT	\N	PRESENT	0
327755	327748	19611R	PARTICIPANT	\N	PRESENT	0
327756	327748	14059S	PARTICIPANT	\N	PRESENT	0
327759	327748	19671E	PARTICIPANT	\N	PRESENT	0
327760	327748	11097X	PARTICIPANT	\N	PRESENT	0
327779	327778	08011M	PARTICIPANT	\N	PRESENT	0
327782	327781	08010L	PARTICIPANT	\N	PRESENT	0
327798	327797	08011M	PARTICIPANT	\N	PRESENT	0
327799	327797	11074Q	PARTICIPANT	\N	PRESENT	0
327801	327797	19545Y	PARTICIPANT	\N	PRESENT	0
327810	326974	04086Q	PARTICIPANT	\N	EXCUSE	0
327813	327812	14034U	PARTICIPANT	\N	PRESENT	0
327922	327921	14193X	PARTICIPANT	\N	PRESENT	0
327923	327921	19721W	PARTICIPANT	\N	PRESENT	0
327924	327921	19709B	PARTICIPANT	\N	PRESENT	0
327925	326974	14028W	PARTICIPANT	\N	EXCUSE	0
327966	320563	14093U	PARTICIPANT	\N	PRESENT	0
327971	320563	19503N	PARTICIPANT	\N	PRESENT	0
327972	320563	01058X	PARTICIPANT	\N	PRESENT	0
328070	321847	14221J	PARTICIPANT	\N	PRESENT	0
328088	321848	14221J	PARTICIPANT	\N	PRESENT	0
328132	328127	04042C	PARTICIPANT	\N	PRESENT	0
328134	328127	08058D	PARTICIPANT	\N	PRESENT	0
328137	328127	11066Q	PARTICIPANT	\N	PRESENT	0
328206	328204	02002K	PARTICIPANT	\N	PRESENT	0
328212	328211	02002K	PARTICIPANT	\N	PRESENT	0
328217	328215	02002K	PARTICIPANT	\N	PRESENT	0
328219	328218	02002K	PARTICIPANT	\N	PRESENT	0
328578	328576	14053L	PARTICIPANT	\N	PRESENT	0
328609	320563	19593H	PARTICIPANT	\N	EXCUSE	0
328727	321331	11027H	PARTICIPANT	\N	PRESENT	0
328728	321331	19741B	PARTICIPANT	\N	PRESENT	0
328729	321331	86034E	PARTICIPANT	\N	PRESENT	0
328730	321331	08011M	PARTICIPANT	\N	PRESENT	0
328731	321331	11074Q	PARTICIPANT	\N	PRESENT	0
328732	321331	04059M	PARTICIPANT	\N	PRESENT	0
328733	321331	14229S	PARTICIPANT	\N	PRESENT	0
328734	321331	19549D	PARTICIPANT	\N	PRESENT	0
328735	321331	19647E	PARTICIPANT	\N	PRESENT	0
328736	321331	19295A	PARTICIPANT	\N	PRESENT	0
328738	328737	04040A	PARTICIPANT	\N	PRESENT	0
328739	328737	19467C	PARTICIPANT	\N	PRESENT	0
328740	328737	14151M	PARTICIPANT	\N	PRESENT	0
328741	328737	19709B	PARTICIPANT	\N	PRESENT	0
328742	328737	14031R	PARTICIPANT	\N	PRESENT	0
328743	328737	19533U	PARTICIPANT	\N	PRESENT	0
328744	328737	11012A	PARTICIPANT	\N	PRESENT	0
328745	328737	04044E	PARTICIPANT	\N	PRESENT	0
328746	328737	95067Q	PARTICIPANT	\N	PRESENT	0
328756	328755	14083S	PARTICIPANT	\N	PRESENT	0
328757	328755	12016W	PARTICIPANT	\N	PRESENT	0
328759	328758	14083S	PARTICIPANT	\N	PRESENT	0
328761	328760	04049K	PARTICIPANT	\N	PRESENT	0
328762	328760	19521Q	PARTICIPANT	\N	PRESENT	0
328763	328760	14083S	PARTICIPANT	\N	PRESENT	0
328764	328760	19515S	PARTICIPANT	\N	PRESENT	0
328765	328760	19441R	PARTICIPANT	\N	PRESENT	0
328767	328766	14083S	PARTICIPANT	\N	PRESENT	0
328768	328766	04049K	PARTICIPANT	\N	PRESENT	0
328770	328769	04049K	PARTICIPANT	\N	PRESENT	0
328772	328771	04049K	PARTICIPANT	\N	PRESENT	0
328773	328771	14083S	PARTICIPANT	\N	PRESENT	0
328774	328771	11053K	PARTICIPANT	\N	PRESENT	0
328840	328839	04038G	PARTICIPANT	\N	PRESENT	0
328842	328841	04038G	PARTICIPANT	\N	PRESENT	0
329013	328769	14083S	PARTICIPANT	\N	PRESENT	0
329014	328769	19515S	PARTICIPANT	\N	PRESENT	0
305062	289221	19737F	PARTICIPANT	\N	PRESENT	0
305112	305010	14053L	PARTICIPANT	\N	PRESENT	0
305064	289221	14028W	PARTICIPANT	\N	PRESENT	0
305065	289221	19593H	PARTICIPANT	\N	PRESENT	0
305066	289221	19581D	PARTICIPANT	\N	PRESENT	0
305113	305010	14147R	PARTICIPANT	\N	PRESENT	0
305121	289222	19649G	PARTICIPANT	\N	PRESENT	0
305069	289221	19611R	PARTICIPANT	\N	PRESENT	0
305114	305010	14179A	PARTICIPANT	\N	PRESENT	0
305122	289222	04047H	PARTICIPANT	\N	PRESENT	0
305072	289221	19335Q	PARTICIPANT	\N	PRESENT	0
305115	305010	04047H	PARTICIPANT	\N	PRESENT	0
305116	305010	05008E	PRESIDENT	0	PRESENT	0
305117	305010	19447X	PARTICIPANT	\N	PRESENT	0
305118	305010	19729F	PARTICIPANT	\N	EXCUSE	0
305119	305010	14065Q	PARTICIPANT	\N	EXCUSE	0
305120	305010	19719D	PARTICIPANT	\N	EXCUSE	0
305123	289222	08031R	PARTICIPANT	\N	PRESENT	0
305124	289222	14261S	PARTICIPANT	\N	PRESENT	0
305125	289222	14219Q	PARTICIPANT	\N	PRESENT	0
305126	289222	19737F	PARTICIPANT	\N	PRESENT	0
305127	289222	19749K	PARTICIPANT	\N	PRESENT	0
305128	289222	14053L	PARTICIPANT	\N	PRESENT	0
305129	289222	19447X	PARTICIPANT	\N	PRESENT	0
305130	289222	19667J	PARTICIPANT	\N	PRESENT	0
305131	289222	14033T	PARTICIPANT	\N	PRESENT	0
305132	289222	14195A	PARTICIPANT	\N	PRESENT	0
305133	289222	08017T	PARTICIPANT	\N	PRESENT	0
305134	289222	14357A	PARTICIPANT	\N	PRESENT	0
305135	289222	14147R	PARTICIPANT	\N	PRESENT	0
305136	289222	08061X	PARTICIPANT	\N	PRESENT	0
305137	289222	01028R	PARTICIPANT	\N	PRESENT	0
305138	289222	19467C	PARTICIPANT	\N	PRESENT	0
305139	289222	16685X	PARTICIPANT	\N	PRESENT	0
305140	289222	19629C	PARTICIPANT	\N	PRESENT	0
305141	289222	11027H	PARTICIPANT	\N	PRESENT	0
305142	289222	19687N	PARTICIPANT	\N	PRESENT	0
305143	289222	01057W	PARTICIPANT	\N	PRESENT	0
305144	289222	19651A	PARTICIPANT	\N	PRESENT	0
305145	289222	19689Q	PARTICIPANT	\N	PRESENT	0
305148	289222	14265W	PARTICIPANT	\N	PRESENT	0
305149	289222	14061L	PARTICIPANT	\N	PRESENT	0
305150	289222	99004R	PARTICIPANT	\N	PRESENT	0
305151	289222	11090Q	PARTICIPANT	\N	PRESENT	0
305152	289222	04085P	PARTICIPANT	\N	PRESENT	0
305153	289222	08024S	PARTICIPANT	\N	PRESENT	0
305154	289222	07029T	PARTICIPANT	\N	PRESENT	0
305155	289222	14041T	PARTICIPANT	\N	PRESENT	0
305156	289222	19387D	PARTICIPANT	\N	PRESENT	0
305157	289222	01024M	PARTICIPANT	\N	PRESENT	0
305158	289222	05008E	PARTICIPANT	\N	PRESENT	0
305159	289222	19329S	PARTICIPANT	\N	PRESENT	0
305160	289222	14215L	PARTICIPANT	\N	PRESENT	0
305161	289222	14089Y	PARTICIPANT	\N	PRESENT	0
305162	289222	11026G	PARTICIPANT	\N	PRESENT	0
305163	289222	95063L	PARTICIPANT	\N	PRESENT	0
305209	305164	05008E	PARTICIPANT	\N	PRESENT	0
305210	305164	19687N	PARTICIPANT	\N	PRESENT	0
305211	305164	04085P	PARTICIPANT	\N	PRESENT	0
305212	305164	11026G	PARTICIPANT	\N	PRESENT	0
305213	305164	08017T	PARTICIPANT	\N	PRESENT	0
305214	305164	19689Q	PARTICIPANT	\N	PRESENT	0
305215	305164	19329S	PARTICIPANT	\N	PRESENT	0
305216	305164	08024S	PARTICIPANT	\N	PRESENT	0
305217	305164	01028R	PARTICIPANT	\N	PRESENT	0
305218	305164	95063L	PARTICIPANT	\N	PRESENT	0
305219	305164	14219Q	PARTICIPANT	\N	PRESENT	0
305220	305164	14179A	PARTICIPANT	\N	PRESENT	0
305221	305164	19737F	PARTICIPANT	\N	PRESENT	0
305222	305164	14251Q	PARTICIPANT	\N	PRESENT	0
305223	305164	01024M	PARTICIPANT	\N	PRESENT	0
305224	305164	19749K	PARTICIPANT	\N	PRESENT	0
305225	305164	14061L	PARTICIPANT	\N	PRESENT	0
305226	305164	14357A	PARTICIPANT	\N	PRESENT	0
305227	305164	07029T	PARTICIPANT	\N	PRESENT	0
305228	305164	14041T	PARTICIPANT	\N	PRESENT	0
305229	305164	19467C	PARTICIPANT	\N	PRESENT	0
305230	305164	19667J	PARTICIPANT	\N	PRESENT	0
305231	305164	14089Y	PARTICIPANT	\N	PRESENT	0
305232	305164	19651A	PARTICIPANT	\N	PRESENT	0
305233	305164	08031R	PARTICIPANT	\N	PRESENT	0
305234	305164	14261S	PARTICIPANT	\N	PRESENT	0
305235	305164	14147R	PARTICIPANT	\N	PRESENT	0
305236	305164	01057W	PARTICIPANT	\N	PRESENT	0
305237	305164	14211G	PARTICIPANT	\N	PRESENT	0
305238	305164	99004R	PARTICIPANT	\N	PRESENT	0
305239	305164	04071H	PARTICIPANT	\N	PRESENT	0
305240	305164	14033T	PARTICIPANT	\N	PRESENT	0
305241	305164	14053L	PARTICIPANT	\N	PRESENT	0
305242	305164	14215L	PARTICIPANT	\N	PRESENT	0
305243	305164	19629C	PARTICIPANT	\N	PRESENT	0
305244	305164	08010L	PARTICIPANT	\N	PRESENT	0
305248	305164	11077T	PARTICIPANT	\N	PRESENT	0
305249	305164	08039A	PARTICIPANT	\N	PRESENT	0
305250	305164	08061X	PARTICIPANT	\N	PRESENT	0
305251	305164	19697Q	PARTICIPANT	\N	PRESENT	0
305252	305164	19441R	PARTICIPANT	\N	PRESENT	0
305253	305164	19447X	PARTICIPANT	\N	PRESENT	0
305207	305164	04044E	PARTICIPANT	\N	PRESENT	0
305208	305164	04047H	PARTICIPANT	\N	PRESENT	0
309308	309307	19631V	PARTICIPANT	\N	PRESENT	0
309309	309307	14105F	PARTICIPANT	\N	PRESENT	0
309310	309307	19383Y	PARTICIPANT	\N	PRESENT	0
309311	309307	08020N	PARTICIPANT	\N	PRESENT	0
309312	309307	14207L	PARTICIPANT	\N	PRESENT	0
309313	309307	14038Y	PARTICIPANT	\N	PRESENT	0
309314	309307	19467C	PARTICIPANT	\N	PRESENT	0
309315	309307	80013X	PARTICIPANT	\N	PRESENT	0
309316	309307	19719D	PARTICIPANT	\N	PRESENT	0
309317	309307	01025N	PARTICIPANT	\N	PRESENT	0
309318	309307	14199E	PARTICIPANT	\N	PRESENT	0
309319	309307	14213J	PARTICIPANT	\N	PRESENT	0
309320	309307	14061L	PARTICIPANT	\N	PRESENT	0
309321	309307	19611R	PARTICIPANT	\N	PRESENT	0
309322	309307	04049K	PARTICIPANT	\N	PRESENT	0
309323	309307	19723Y	PARTICIPANT	\N	PRESENT	0
309324	309307	12041X	PARTICIPANT	\N	PRESENT	0
309325	309307	14219Q	PARTICIPANT	\N	PRESENT	0
309326	309307	19441R	PARTICIPANT	\N	PRESENT	0
309327	309307	04092N	PARTICIPANT	\N	PRESENT	0
309328	309307	19369B	PARTICIPANT	\N	PRESENT	0
309329	309307	14109K	PARTICIPANT	\N	PRESENT	0
309330	309307	14265W	PARTICIPANT	\N	PRESENT	0
309331	309307	05012A	PARTICIPANT	\N	PRESENT	0
309332	309307	19443T	PARTICIPANT	\N	PRESENT	0
309333	309307	14135M	PARTICIPANT	\N	PRESENT	0
309335	309307	11012A	PARTICIPANT	\N	PRESENT	0
309336	305886	19399H	PARTICIPANT	\N	PRESENT	0
311676	311675	07004J	PARTICIPANT	\N	PRESENT	0
311678	311677	89017R	PARTICIPANT	\N	PRESENT	0
311680	311679	89017R	PARTICIPANT	\N	PRESENT	0
311683	311682	08034U	PARTICIPANT	\N	PRESENT	0
311702	311693	19545Y	PARTICIPANT	\N	PRESENT	0
311703	311693	19689Q	PARTICIPANT	\N	PRESENT	0
311725	311724	95062K	PARTICIPANT	\N	EXCUSE	0
315591	310953	19551W	PARTICIPANT	\N	PRESENT	0
315592	310953	08024S	PARTICIPANT	\N	PRESENT	0
315593	310953	02002K	PARTICIPANT	\N	PRESENT	0
315598	313988	95063L	PARTICIPANT	\N	PRESENT	0
315599	313988	11085T	PARTICIPANT	\N	PRESENT	0
315600	310953	19349W	PARTICIPANT	\N	PRESENT	0
315601	310578	08024S	PARTICIPANT	\N	PRESENT	0
315602	310578	19551W	PARTICIPANT	\N	PRESENT	0
315603	313943	98050T	PARTICIPANT	\N	PRESENT	0
315604	310578	02002K	PARTICIPANT	\N	PRESENT	0
315605	310578	19349W	PARTICIPANT	\N	PRESENT	0
315606	313986	01057W	PARTICIPANT	\N	PRESENT	0
315607	313986	11070L	PARTICIPANT	\N	PRESENT	0
315608	313986	19647E	PARTICIPANT	\N	PRESENT	0
315609	313986	08011M	PARTICIPANT	\N	PRESENT	0
315610	313986	14159V	PARTICIPANT	\N	PRESENT	0
315611	314014	14103D	PARTICIPANT	\N	PRESENT	0
315612	314014	98023Q	PARTICIPANT	\N	PRESENT	0
315613	314014	01043Q	PARTICIPANT	\N	PRESENT	0
315614	314014	14081Q	PARTICIPANT	\N	PRESENT	0
315615	314014	19413M	PARTICIPANT	\N	PRESENT	0
315616	314014	14219Q	PARTICIPANT	\N	PRESENT	0
315617	314014	80013X	PARTICIPANT	\N	PRESENT	0
315618	314014	14197C	PARTICIPANT	\N	PRESENT	0
315619	314014	19511N	PARTICIPANT	\N	PRESENT	0
315620	314014	19563B	PARTICIPANT	\N	PRESENT	0
315621	314014	08038Y	PARTICIPANT	\N	PRESENT	0
315622	314014	01025N	PARTICIPANT	\N	PRESENT	0
315623	314014	19733B	PARTICIPANT	\N	PRESENT	0
315624	314014	14207L	PARTICIPANT	\N	PRESENT	0
315625	314014	14257W	PARTICIPANT	\N	PRESENT	0
315764	314014	14191V	PARTICIPANT	\N	PRESENT	0
315767	314014	19737F	PARTICIPANT	\N	PRESENT	0
315771	314014	14135M	PARTICIPANT	\N	PRESENT	0
320387	314105	14033T	PARTICIPANT	\N	PRESENT	0
320388	314105	95030B	PARTICIPANT	\N	PRESENT	0
320389	314105	19701S	PARTICIPANT	\N	PRESENT	0
320390	314105	15447F	PARTICIPANT	\N	PRESENT	0
320391	314105	19703U	PARTICIPANT	\N	PRESENT	0
320392	314105	80027E	PARTICIPANT	\N	PRESENT	0
320393	314105	04085P	PARTICIPANT	\N	PRESENT	0
320394	314105	19503N	PARTICIPANT	\N	PRESENT	0
320395	314105	14207L	PARTICIPANT	\N	PRESENT	0
320396	314105	19725B	PARTICIPANT	\N	PRESENT	0
320397	314105	11012A	PARTICIPANT	\N	PRESENT	0
320398	314105	18083K	PARTICIPANT	\N	PRESENT	0
320548	314105	19253P	PARTICIPANT	\N	PRESENT	0
320400	314105	19443T	PARTICIPANT	\N	PRESENT	0
320401	314105	08020N	PARTICIPANT	\N	PRESENT	0
320402	314105	14267Y	PARTICIPANT	\N	PRESENT	0
320403	314105	14255U	PARTICIPANT	\N	PRESENT	0
320405	314105	19387D	PARTICIPANT	\N	PRESENT	0
320406	314105	19731Y	PARTICIPANT	\N	PRESENT	0
320407	314105	08056B	PARTICIPANT	\N	PRESENT	0
320408	314105	19301E	PARTICIPANT	\N	PRESENT	0
320409	314105	19599P	PARTICIPANT	\N	PRESENT	0
320410	314105	17589D	PARTICIPANT	\N	PRESENT	0
320411	319283	19479G	PARTICIPANT	\N	PRESENT	0
320412	319283	19647E	PARTICIPANT	\N	PRESENT	0
320413	319283	14073Q	PARTICIPANT	\N	PRESENT	0
320414	319283	19687N	PARTICIPANT	\N	PRESENT	0
320415	319283	19689Q	PARTICIPANT	\N	PRESENT	0
320416	319283	19667J	PARTICIPANT	\N	PRESENT	0
320417	319283	88008L	PARTICIPANT	\N	PRESENT	0
320418	319283	11070L	PARTICIPANT	\N	PRESENT	0
320419	319283	14159V	PARTICIPANT	\N	PRESENT	0
320420	319283	11040E	PARTICIPANT	\N	PRESENT	0
320421	319283	14085U	PARTICIPANT	\N	PRESENT	0
320422	319283	19741B	PARTICIPANT	\N	PRESENT	0
320423	319283	04061F	PRESIDENT	0	PRESENT	0
320424	319283	98029W	PARTICIPANT	\N	PRESENT	0
320425	319283	07029T	PARTICIPANT	\N	EXCUSE	0
320426	319283	08014Q	PARTICIPANT	\N	EXCUSE	0
320427	314105	14111D	PARTICIPANT	\N	PRESENT	0
320428	314105	14029X	PARTICIPANT	\N	PRESENT	0
320429	314105	11097X	PARTICIPANT	\N	PRESENT	0
320430	314105	19347U	PARTICIPANT	\N	PRESENT	0
320431	314105	19507S	PARTICIPANT	\N	PRESENT	0
320432	319283	08034U	PARTICIPANT	\N	PRESENT	0
320433	319283	01057W	PARTICIPANT	\N	PRESENT	0
320434	319283	08011M	PARTICIPANT	\N	PRESENT	0
320435	319335	19515S	PARTICIPANT	\N	PRESENT	0
320436	319335	04071H	PARTICIPANT	\N	PRESENT	0
320437	319335	11048N	PARTICIPANT	\N	PRESENT	0
320438	319335	19711U	PARTICIPANT	\N	PRESENT	0
320439	319335	04034C	PARTICIPANT	\N	PRESENT	0
320440	319335	19545Y	PARTICIPANT	\N	PRESENT	0
320441	319335	19441R	PARTICIPANT	\N	PRESENT	0
320442	319335	11053K	PARTICIPANT	\N	PRESENT	0
320443	319335	19413M	PARTICIPANT	\N	PRESENT	0
320444	319335	19695N	PARTICIPANT	\N	PRESENT	0
320445	319335	19717B	PARTICIPANT	\N	PRESENT	0
320446	319335	19399H	PARTICIPANT	\N	PRESENT	0
320447	319335	14227Q	PARTICIPANT	\N	PRESENT	0
320448	319335	19631V	PARTICIPANT	\N	PRESENT	0
320449	319335	14051J	PARTICIPANT	\N	PRESENT	0
320450	319335	04049K	PARTICIPANT	\N	PRESENT	0
320451	319335	14151M	PARTICIPANT	\N	PRESENT	0
320452	319335	19521Q	PRESIDENT	0	PRESENT	0
320453	319335	14329V	PARTICIPANT	\N	PRESENT	0
320454	319335	14083S	PARTICIPANT	\N	EXCUSE	0
320455	319335	08068F	PARTICIPANT	\N	EXCUSE	0
320456	319335	14026U	PARTICIPANT	\N	EXCUSE	0
320457	319335	19762G	PARTICIPANT	\N	EXCUSE	0
320458	314105	19611R	PARTICIPANT	\N	PRESENT	0
320459	314105	11099A	PARTICIPANT	\N	PRESENT	0
320460	314105	14219Q	PARTICIPANT	\N	PRESENT	0
320461	314105	19669L	PARTICIPANT	\N	PRESENT	0
320462	314105	08047A	PARTICIPANT	\N	PRESENT	0
320463	314105	14119M	PARTICIPANT	\N	PRESENT	0
320464	314105	19549D	PARTICIPANT	\N	PRESENT	0
320465	314105	14147R	PARTICIPANT	\N	PRESENT	0
320466	314105	01025N	PARTICIPANT	\N	PRESENT	0
320467	314105	95063L	PARTICIPANT	\N	PRESENT	0
320468	314105	14105F	PARTICIPANT	\N	PRESENT	0
320469	314105	19467C	PARTICIPANT	\N	PRESENT	0
320473	314105	14061L	PARTICIPANT	\N	PRESENT	0
320471	314105	14115H	PARTICIPANT	\N	PRESENT	0
320472	314105	19581D	PARTICIPANT	\N	PRESENT	0
320474	314105	19745F	PARTICIPANT	\N	PRESENT	0
320475	314105	08061X	PARTICIPANT	\N	PRESENT	0
320476	314105	19621T	PARTICIPANT	\N	PRESENT	0
320477	314105	19367Y	PARTICIPANT	\N	PRESENT	0
320478	314105	14217N	PARTICIPANT	\N	PRESENT	0
320479	319283	89017R	PARTICIPANT	\N	PRESENT	0
320480	319283	04086Q	PARTICIPANT	\N	PRESENT	0
320481	319283	11012A	PARTICIPANT	\N	PRESENT	0
320482	319283	98050T	PARTICIPANT	\N	PRESENT	0
320483	319283	14121F	PARTICIPANT	\N	PRESENT	0
320484	319283	99004R	PARTICIPANT	\N	PRESENT	0
320485	314105	08045X	PARTICIPANT	\N	PRESENT	0
320486	314105	19733B	PARTICIPANT	\N	PRESENT	0
320487	314105	19369B	PARTICIPANT	\N	PRESENT	0
320488	319335	14187A	PARTICIPANT	\N	PRESENT	0
320489	319335	12016W	PARTICIPANT	\N	PRESENT	0
320490	319335	11090Q	PARTICIPANT	\N	PRESENT	0
320517	314105	19691J	PARTICIPANT	\N	PRESENT	0
320518	314105	04018C	PARTICIPANT	\N	PRESENT	0
320519	314105	19413M	PARTICIPANT	\N	PRESENT	0
320520	314105	08015R	PARTICIPANT	\N	PRESENT	0
320521	314105	16685X	PARTICIPANT	\N	PRESENT	0
320522	314105	14042U	PARTICIPANT	\N	PRESENT	0
320523	314105	14038Y	PARTICIPANT	\N	PRESENT	0
320545	314105	14257W	PARTICIPANT	\N	PRESENT	0
320546	314105	19447X	PARTICIPANT	\N	PRESENT	0
320547	314105	14097Y	PARTICIPANT	\N	PRESENT	0
320549	314105	19737F	PARTICIPANT	\N	PRESENT	0
320550	319335	14173T	PARTICIPANT	\N	PRESENT	0
320551	314105	14103D	PARTICIPANT	\N	PRESENT	0
320552	314105	14107H	PARTICIPANT	\N	PRESENT	0
320559	314105	19551W	PARTICIPANT	\N	PRESENT	0
320560	314105	14065Q	PARTICIPANT	\N	PRESENT	0
320561	314105	19758L	PARTICIPANT	\N	PRESENT	0
320562	314105	14073Q	PARTICIPANT	\N	PRESENT	0
320564	314105	11067R	PARTICIPANT	\N	PRESENT	0
320565	314105	08055A	PARTICIPANT	\N	PRESENT	0
320566	314105	01024M	PARTICIPANT	\N	PRESENT	0
320567	314105	14357A	PARTICIPANT	\N	PRESENT	0
320568	314105	19269X	PARTICIPANT	\N	PRESENT	0
320569	314105	11064N	PARTICIPANT	\N	PRESENT	0
320573	314105	19563B	PARTICIPANT	\N	PRESENT	0
320571	314105	11065P	PARTICIPANT	\N	PRESENT	0
320572	314105	80013X	PARTICIPANT	\N	PRESENT	0
320574	314105	14151M	PARTICIPANT	\N	PRESENT	0
320575	318797	14063N	PARTICIPANT	\N	EXCUSE	0
320576	314105	08038Y	PARTICIPANT	\N	PRESENT	0
320577	314105	19585H	PARTICIPANT	\N	PRESENT	0
320578	314105	14231L	PARTICIPANT	\N	PRESENT	0
320579	314105	95062K	PARTICIPANT	\N	PRESENT	0
320580	314105	19333N	PARTICIPANT	\N	PRESENT	0
320581	318050	08009T	PRESIDENT	0	PRESENT	0
320582	318050	96004D	PARTICIPANT	\N	EXCUSE	0
320583	318050	04097T	PARTICIPANT	\N	EXCUSE	0
320584	318050	19685L	PARTICIPANT	\N	EXCUSE	0
320585	318050	19659J	PARTICIPANT	\N	EXCUSE	0
320586	305885	08045X	PARTICIPANT	\N	EXCUSE	0
320587	314105	14259Y	PARTICIPANT	\N	PRESENT	0
320588	305885	19479G	PARTICIPANT	\N	PRESENT	0
320589	314105	19643A	PARTICIPANT	\N	PRESENT	0
320590	314105	04049K	PARTICIPANT	\N	PRESENT	0
320591	314105	14028W	PARTICIPANT	\N	PRESENT	0
320592	319336	19515S	PARTICIPANT	\N	PRESENT	0
320593	319336	04071H	PARTICIPANT	\N	PRESENT	0
320594	319336	11048N	PARTICIPANT	\N	PRESENT	0
320595	319336	19711U	PARTICIPANT	\N	PRESENT	0
320596	319336	14187A	PARTICIPANT	\N	PRESENT	0
320597	319336	19441R	PARTICIPANT	\N	PRESENT	0
320598	319336	11053K	PARTICIPANT	\N	PRESENT	0
320599	319336	12016W	PARTICIPANT	\N	PRESENT	0
320600	319336	19695N	PARTICIPANT	\N	PRESENT	0
320601	319336	11090Q	PARTICIPANT	\N	PRESENT	0
320602	319336	19667J	PARTICIPANT	\N	PRESENT	0
320603	319336	19717B	PARTICIPANT	\N	PRESENT	0
320604	319336	19399H	PARTICIPANT	\N	PRESENT	0
320605	319336	19631V	PARTICIPANT	\N	PRESENT	0
320606	319336	14173T	PARTICIPANT	\N	PRESENT	0
320607	319336	14051J	PARTICIPANT	\N	PRESENT	0
320608	319336	14151M	PARTICIPANT	\N	PRESENT	0
320609	319336	14157T	PARTICIPANT	\N	PRESENT	0
320610	319336	19521Q	PRESIDENT	0	PRESENT	0
320611	319336	14329V	PARTICIPANT	\N	PRESENT	0
320612	319336	04049K	PARTICIPANT	\N	PRESENT	0
320613	319336	14083S	PARTICIPANT	\N	EXCUSE	0
302249	297354	19659J	PARTICIPANT	\N	EXCUSE	0
302250	297354	14039A	PARTICIPANT	\N	EXCUSE	0
302251	297354	11033F	PARTICIPANT	\N	EXCUSE	0
302252	297354	95062K	PARTICIPANT	\N	EXCUSE	0
302253	297354	19729F	PARTICIPANT	\N	EXCUSE	0
302254	297354	19319Q	PARTICIPANT	\N	EXCUSE	0
302255	297354	19657G	PARTICIPANT	\N	EXCUSE	0
302256	297354	19577H	PARTICIPANT	\N	EXCUSE	0
302259	297354	11109J	PARTICIPANT	\N	EXCUSE	0
302260	297354	19329S	PARTICIPANT	\N	EXCUSE	0
302266	302264	01024M	PARTICIPANT	\N	PRESENT	0
302269	302268	01024M	PARTICIPANT	\N	PRESENT	0
302270	302268	04047H	PARTICIPANT	\N	PRESENT	0
302271	302268	14065Q	PARTICIPANT	\N	PRESENT	0
302273	302272	04047H	PARTICIPANT	\N	PRESENT	0
302274	302272	01024M	PARTICIPANT	\N	PRESENT	0
302275	302272	19581D	PARTICIPANT	\N	PRESENT	0
302280	302278	14093U	PARTICIPANT	\N	PRESENT	0
305437	305412	11080N	PARTICIPANT	\N	PRESENT	0
305438	305412	04044E	PARTICIPANT	\N	PRESENT	0
305439	305412	19581D	PARTICIPANT	\N	PRESENT	0
305440	305412	04047H	PARTICIPANT	\N	PRESENT	0
305441	305412	01028R	PARTICIPANT	\N	PRESENT	0
305442	305412	19447X	PARTICIPANT	\N	PRESENT	0
305443	305412	05008E	PRESIDENT	0	PRESENT	0
305444	305412	14041T	PARTICIPANT	\N	PRESENT	0
305445	305412	14179A	PARTICIPANT	\N	PRESENT	0
305446	305412	14151M	PARTICIPANT	\N	PRESENT	0
305447	305412	14215L	PARTICIPANT	\N	PRESENT	0
305448	305412	08061X	PARTICIPANT	\N	PRESENT	0
305449	305412	14265W	PARTICIPANT	\N	PRESENT	0
305450	305412	11048N	PARTICIPANT	\N	PRESENT	0
305451	305412	14111D	PARTICIPANT	\N	PRESENT	0
305452	305412	19649G	PARTICIPANT	\N	PRESENT	0
305453	305412	14065Q	PARTICIPANT	\N	PRESENT	0
305454	305412	07034Q	PARTICIPANT	\N	PRESENT	0
305455	305412	11026G	PARTICIPANT	\N	PRESENT	0
305456	305412	19253P	PARTICIPANT	\N	PRESENT	0
305457	305412	04038G	PARTICIPANT	\N	PRESENT	0
305458	305412	19693L	PARTICIPANT	\N	PRESENT	0
305459	305412	19719D	PARTICIPANT	\N	PRESENT	0
305460	305412	11033F	PARTICIPANT	\N	PRESENT	0
305461	305412	14089Y	PARTICIPANT	\N	PRESENT	0
305462	305412	14069U	PARTICIPANT	\N	PRESENT	0
305463	305412	19657G	PARTICIPANT	\N	PRESENT	0
305464	305412	11049P	PARTICIPANT	\N	PRESENT	0
305465	305412	19762G	PARTICIPANT	\N	PRESENT	0
305466	305412	14021P	PARTICIPANT	\N	PRESENT	0
305471	305412	14231L	PARTICIPANT	\N	PRESENT	0
305472	305412	14147R	PARTICIPANT	\N	PRESENT	0
305473	305412	14259Y	PARTICIPANT	\N	PRESENT	0
305474	305412	01024M	PARTICIPANT	\N	PRESENT	0
305475	305412	19741B	PARTICIPANT	\N	PRESENT	0
305476	305412	04008A	PARTICIPANT	\N	PRESENT	0
305479	305412	19689Q	PARTICIPANT	\N	PRESENT	0
305480	305412	04086Q	PARTICIPANT	\N	PRESENT	0
305481	305412	95063L	PARTICIPANT	\N	PRESENT	0
305482	305412	19489J	PARTICIPANT	\N	PRESENT	0
305483	305412	19611R	PARTICIPANT	\N	PRESENT	0
305484	305412	04085P	PARTICIPANT	\N	PRESENT	0
305485	305412	19729F	PARTICIPANT	\N	EXCUSE	0
305486	305412	08018U	PARTICIPANT	\N	EXCUSE	0
305487	305412	04059M	PARTICIPANT	\N	PRESENT	0
305514	305413	19543W	PARTICIPANT	\N	PRESENT	0
305515	305413	05008E	PRESIDENT	0	PRESENT	0
305516	305413	14089Y	PARTICIPANT	\N	PRESENT	0
306258	306009	14249W	PARTICIPANT	\N	PRESENT	0
306259	306009	14053L	PARTICIPANT	\N	PRESENT	0
306260	306009	04042C	PARTICIPANT	\N	PRESENT	0
306261	306009	19683J	PARTICIPANT	\N	PRESENT	0
306262	306009	14215L	PARTICIPANT	\N	PRESENT	0
306263	306009	14087W	PARTICIPANT	\N	PRESENT	0
306264	306009	14197C	PARTICIPANT	\N	PRESENT	0
306265	306009	05012A	PARTICIPANT	\N	PRESENT	0
306266	306009	19649G	PARTICIPANT	\N	PRESENT	0
306267	306009	11045K	PARTICIPANT	\N	PRESENT	0
306268	306009	08034U	PARTICIPANT	\N	PRESENT	0
306269	306009	07034Q	PARTICIPANT	\N	PRESENT	0
306270	306009	19727D	PARTICIPANT	\N	PRESENT	0
306271	306009	14193X	PARTICIPANT	\N	PRESENT	0
306272	306009	14109K	PARTICIPANT	\N	PRESENT	0
306273	306009	14237S	PARTICIPANT	\N	PRESENT	0
306274	306009	17583W	PARTICIPANT	\N	PRESENT	0
306275	306009	11031D	PARTICIPANT	\N	PRESENT	0
306276	306009	19760E	PARTICIPANT	\N	PRESENT	0
306277	306009	12041X	PARTICIPANT	\N	PRESENT	0
306278	306009	19689Q	PARTICIPANT	\N	PRESENT	0
306279	306009	11097X	PARTICIPANT	\N	PRESENT	0
306280	306009	19733B	PARTICIPANT	\N	PRESENT	0
306281	306009	08038Y	PARTICIPANT	\N	PRESENT	0
306282	306009	19525U	PARTICIPANT	\N	PRESENT	0
306283	306009	05008E	PARTICIPANT	\N	PRESENT	0
306284	306009	08012N	PARTICIPANT	\N	PRESENT	0
306285	306009	14187A	PARTICIPANT	\N	PRESENT	0
306286	306009	14085U	PARTICIPANT	\N	PRESENT	0
306287	306009	04033B	PARTICIPANT	\N	PRESENT	0
306288	306009	08028W	PARTICIPANT	\N	PRESENT	0
306289	306009	14223L	PARTICIPANT	\N	PRESENT	0
306290	306009	19713W	PARTICIPANT	\N	PRESENT	0
306291	306009	01057W	PARTICIPANT	\N	PRESENT	0
306292	306009	14042U	PARTICIPANT	\N	PRESENT	0
306293	306009	14219Q	PARTICIPANT	\N	PRESENT	0
306294	306009	14169X	PARTICIPANT	\N	PRESENT	0
306295	306009	19479G	PARTICIPANT	\N	PRESENT	0
306296	306009	01034P	PARTICIPANT	\N	PRESENT	0
306355	306009	08020N	PARTICIPANT	\N	PRESENT	0
306298	306009	19643A	PARTICIPANT	\N	PRESENT	0
306299	306009	15447F	PARTICIPANT	\N	PRESENT	0
306300	306009	08044W	PARTICIPANT	\N	PRESENT	0
306301	306009	08056B	PARTICIPANT	\N	PRESENT	0
306302	306009	01025N	PARTICIPANT	\N	PRESENT	0
306303	306009	19521Q	PARTICIPANT	\N	PRESENT	0
306304	306009	16685X	PARTICIPANT	\N	PRESENT	0
306305	306009	19619A	PARTICIPANT	\N	PRESENT	0
306306	306009	19369B	PARTICIPANT	\N	PRESENT	0
306307	306009	11085T	PARTICIPANT	\N	PRESENT	0
306308	306009	96004D	PARTICIPANT	\N	PRESENT	0
306309	306009	14179A	PARTICIPANT	\N	PRESENT	0
306310	306009	19691J	PARTICIPANT	\N	PRESENT	0
306311	306009	19768N	PARTICIPANT	\N	PRESENT	0
306312	306009	08015R	PARTICIPANT	\N	PRESENT	0
306313	306009	14205J	PARTICIPANT	\N	PRESENT	0
306314	306009	14103D	PARTICIPANT	\N	PRESENT	0
306315	306009	14355X	PARTICIPANT	\N	PRESENT	0
306316	306009	14073Q	PARTICIPANT	\N	PRESENT	0
306317	306009	14329V	PARTICIPANT	\N	PRESENT	0
306318	306009	19511N	PARTICIPANT	\N	PRESENT	0
306319	306009	07033P	PARTICIPANT	\N	PRESENT	0
306320	306009	01024M	PARTICIPANT	\N	PRESENT	0
306321	306009	11070L	PARTICIPANT	\N	PRESENT	0
306322	306009	14267Y	PARTICIPANT	\N	PRESENT	0
306323	306009	19721W	PARTICIPANT	\N	PRESENT	0
306324	306009	11053K	PARTICIPANT	\N	PRESENT	0
306325	306009	11103C	PARTICIPANT	\N	PRESENT	0
306326	306009	14083S	PARTICIPANT	\N	PRESENT	0
306327	306009	01043Q	PARTICIPANT	\N	PRESENT	0
306328	306009	19675J	PARTICIPANT	\N	PRESENT	0
306329	306009	14231L	PARTICIPANT	\N	PRESENT	0
306330	306009	14217N	PARTICIPANT	\N	PRESENT	0
306331	306009	14089Y	PARTICIPANT	\N	PRESENT	0
306332	306009	04040A	PARTICIPANT	\N	PRESENT	0
306333	306009	19367Y	PARTICIPANT	\N	PRESENT	0
306334	306009	04018C	PARTICIPANT	\N	PRESENT	0
306335	306009	19739H	PARTICIPANT	\N	PRESENT	0
306336	306009	19621T	PARTICIPANT	\N	PRESENT	0
306337	306009	19745F	PARTICIPANT	\N	PRESENT	0
306338	306009	19735D	PARTICIPANT	\N	PRESENT	0
306339	306009	04070G	PARTICIPANT	\N	PRESENT	0
306340	306009	19335Q	PARTICIPANT	\N	PRESENT	0
306341	306009	19701S	PARTICIPANT	\N	PRESENT	0
306342	306009	19762G	PARTICIPANT	\N	PRESENT	0
306346	306009	14327T	PARTICIPANT	\N	PRESENT	0
306344	306009	14061L	PARTICIPANT	\N	PRESENT	0
306345	306009	19699S	PARTICIPANT	\N	PRESENT	0
306347	306009	98050T	PARTICIPANT	\N	PRESENT	0
306348	306009	19611R	PARTICIPANT	\N	PRESENT	0
306349	306009	04044E	PARTICIPANT	\N	PRESENT	0
306350	306009	19421M	PARTICIPANT	\N	PRESENT	0
306351	306009	19749K	PARTICIPANT	\N	PRESENT	0
306352	306009	04089T	PARTICIPANT	\N	PRESENT	0
306353	306009	19737F	PARTICIPANT	\N	PRESENT	0
306354	306009	04092N	PARTICIPANT	\N	PRESENT	0
306356	306009	04047H	PARTICIPANT	\N	PRESENT	0
306357	306009	95041E	PARTICIPANT	\N	PRESENT	0
306358	306009	14026U	PARTICIPANT	\N	PRESENT	0
306360	306009	08048B	PARTICIPANT	\N	PRESENT	0
329041	326974	14063N	PARTICIPANT	\N	EXCUSE	0
329066	329065	96004D	PARTICIPANT	\N	PRESENT	0
329067	329065	11026G	PARTICIPANT	\N	PRESENT	0
329068	329065	10015M	PARTICIPANT	\N	PRESENT	0
329462	321345	11043H	PARTICIPANT	\N	PRESENT	0
329463	321345	19729F	PARTICIPANT	\N	PRESENT	0
329464	321345	04088S	PARTICIPANT	\N	PRESENT	0
329465	321345	19573D	PARTICIPANT	\N	PRESENT	0
329466	321345	19515S	PARTICIPANT	\N	PRESENT	0
329467	321345	04097T	PARTICIPANT	\N	PRESENT	0
329468	321345	14123H	PARTICIPANT	\N	PRESENT	0
329469	321345	98024R	PARTICIPANT	\N	PRESENT	0
329470	321345	19467C	PARTICIPANT	\N	PRESENT	0
329471	321345	19421M	PARTICIPANT	\N	PRESENT	0
329472	321345	04033B	PARTICIPANT	\N	PRESENT	0
329473	321345	12041X	PARTICIPANT	\N	PRESENT	0
329474	321345	11040E	PARTICIPANT	\N	PRESENT	0
329475	321345	14071N	PARTICIPANT	\N	PRESENT	0
329476	321345	04085P	PARTICIPANT	\N	PRESENT	0
329477	321345	14211G	PARTICIPANT	\N	PRESENT	0
329478	321345	19695N	PARTICIPANT	\N	PRESENT	0
329479	321345	01058X	PARTICIPANT	\N	PRESENT	0
329480	321345	19687N	PARTICIPANT	\N	PRESENT	0
329484	321345	04042C	PARTICIPANT	\N	PRESENT	0
329482	321345	04038G	PARTICIPANT	\N	PRESENT	0
329483	321345	11056N	PARTICIPANT	\N	PRESENT	0
329485	321345	95063L	PARTICIPANT	\N	PRESENT	0
329486	321345	08061X	PARTICIPANT	\N	PRESENT	0
329487	321345	92040Q	PARTICIPANT	\N	PRESENT	0
329488	321345	98029W	PARTICIPANT	\N	PRESENT	0
329489	321345	04034C	PARTICIPANT	\N	PRESENT	0
329490	321345	11097X	PARTICIPANT	\N	PRESENT	0
329491	321345	11083R	PARTICIPANT	\N	PRESENT	0
329492	321345	08021P	PARTICIPANT	\N	PRESENT	0
329493	321345	19301E	PARTICIPANT	\N	PRESENT	0
329494	321345	11072N	PARTICIPANT	\N	PRESENT	0
329495	321345	19289C	PARTICIPANT	\N	PRESENT	0
329497	321345	14241N	PARTICIPANT	\N	PRESENT	0
329498	321345	19667J	PARTICIPANT	\N	PRESENT	0
329499	321345	14261S	PARTICIPANT	\N	PRESENT	0
329500	321345	01057W	PARTICIPANT	\N	PRESENT	0
329501	321345	08051V	PARTICIPANT	\N	PRESENT	0
329502	321345	11012A	PARTICIPANT	\N	PRESENT	0
329503	321345	08011M	PARTICIPANT	\N	PRESENT	0
329504	321345	14034U	PARTICIPANT	\N	PRESENT	0
329505	321345	19719D	PARTICIPANT	\N	PRESENT	0
329506	321345	19575F	PARTICIPANT	\N	PRESENT	0
329507	321345	11065P	PARTICIPANT	\N	PRESENT	0
329508	321345	19543W	PARTICIPANT	\N	PRESENT	0
329509	321345	14253S	PARTICIPANT	\N	PRESENT	0
329510	321345	14111D	PARTICIPANT	\N	PRESENT	0
329511	321345	19545Y	PARTICIPANT	\N	PRESENT	0
329512	321345	19585H	PARTICIPANT	\N	PRESENT	0
329513	321345	02002K	PARTICIPANT	\N	PRESENT	0
329514	321345	04057K	PARTICIPANT	\N	PRESENT	0
329515	321345	19269X	PARTICIPANT	\N	PRESENT	0
329516	321345	19697Q	PARTICIPANT	\N	PRESENT	0
329517	321345	11064N	PARTICIPANT	\N	PRESENT	0
329518	321345	19447X	PARTICIPANT	\N	PRESENT	0
329519	321345	14093U	PARTICIPANT	\N	PRESENT	0
329520	321345	14251Q	PARTICIPANT	\N	PRESENT	0
329521	321345	11080N	PARTICIPANT	\N	PRESENT	0
329522	321345	19387D	PARTICIPANT	\N	PRESENT	0
329523	321345	19723Y	PARTICIPANT	\N	PRESENT	0
329524	321345	89017R	PARTICIPANT	\N	PRESENT	0
329525	321345	08019V	PARTICIPANT	\N	PRESENT	0
329526	321345	14055N	PARTICIPANT	\N	PRESENT	0
329527	321345	19443T	PARTICIPANT	\N	PRESENT	0
329528	321345	01060R	PARTICIPANT	\N	PRESENT	0
329529	321345	14265W	PARTICIPANT	\N	PRESENT	0
329530	321345	19727D	PARTICIPANT	\N	PRESENT	0
329531	321345	14213J	PARTICIPANT	\N	PRESENT	0
329532	321345	11031D	PARTICIPANT	\N	PRESENT	0
329533	321345	11033F	PARTICIPANT	\N	PRESENT	0
329534	321345	19565D	PARTICIPANT	\N	PRESENT	0
329535	321345	19663E	PARTICIPANT	\N	PRESENT	0
329536	321345	14235Q	PARTICIPANT	\N	PRESENT	0
329537	321345	11077T	PARTICIPANT	\N	PRESENT	0
329538	321345	11074Q	PARTICIPANT	\N	PRESENT	0
329539	321345	07029T	PARTICIPANT	\N	PRESENT	0
329540	321345	14159V	PARTICIPANT	\N	PRESENT	0
329541	321345	14229S	PARTICIPANT	\N	PRESENT	0
329542	321345	01028R	PARTICIPANT	\N	PRESENT	0
329543	321345	08020N	PARTICIPANT	\N	PRESENT	0
329544	321345	08068F	PARTICIPANT	\N	PRESENT	0
329545	321345	19747H	PARTICIPANT	\N	PRESENT	0
329546	321345	14151M	PARTICIPANT	\N	PRESENT	0
329547	321345	19705W	PARTICIPANT	\N	PRESENT	0
329548	321345	14195A	PARTICIPANT	\N	PRESENT	0
329549	321345	14225N	PARTICIPANT	\N	PRESENT	0
329550	321345	19669L	PARTICIPANT	\N	PRESENT	0
329551	321345	08045X	PARTICIPANT	\N	PRESENT	0
329552	321345	01062T	PARTICIPANT	\N	PRESENT	0
329553	321345	98018T	PARTICIPANT	\N	PRESENT	0
329554	321345	08038Y	PARTICIPANT	\N	PRESENT	0
329555	321345	14281W	PARTICIPANT	\N	PRESENT	0
329556	321345	19762G	PARTICIPANT	\N	PRESENT	0
329557	321345	14065Q	PARTICIPANT	\N	PRESENT	0
329558	321345	19701S	PARTICIPANT	\N	PRESENT	0
329559	321345	14081Q	PARTICIPANT	\N	PRESENT	0
329560	321345	19525U	PARTICIPANT	\N	PRESENT	0
329561	321345	14257W	PARTICIPANT	\N	PRESENT	0
329562	321345	07033P	PARTICIPANT	\N	PRESENT	0
329563	321345	14001X	PARTICIPANT	\N	PRESENT	0
329564	321345	19333N	PARTICIPANT	\N	PRESENT	0
329565	321345	14331P	PARTICIPANT	\N	PRESENT	0
329566	321345	08014Q	PARTICIPANT	\N	PRESENT	0
329567	321345	04061F	PARTICIPANT	\N	PRESENT	0
329568	321345	19549D	PARTICIPANT	\N	PRESENT	0
329569	321345	11110B	PARTICIPANT	\N	PRESENT	0
329570	321345	14079W	PARTICIPANT	\N	PRESENT	0
329571	321345	14109K	PARTICIPANT	\N	PRESENT	0
329572	321345	19671E	PARTICIPANT	\N	PRESENT	0
329573	321345	19347U	PARTICIPANT	\N	PRESENT	0
329574	321345	19631V	PARTICIPANT	\N	PRESENT	0
329575	321345	05012A	PARTICIPANT	\N	PRESENT	0
329576	321345	19591F	PARTICIPANT	\N	PRESENT	0
329577	321345	19489J	PARTICIPANT	\N	PRESENT	0
329578	321345	19413M	PARTICIPANT	\N	PRESENT	0
329579	321345	04043D	PARTICIPANT	\N	PRESENT	0
329580	321345	19689Q	PARTICIPANT	\N	PRESENT	0
329581	321345	11054L	PARTICIPANT	\N	PRESENT	0
329582	321345	14249W	PARTICIPANT	\N	PRESENT	0
329583	321345	17779H	PARTICIPANT	\N	PRESENT	0
329584	321345	14085U	PARTICIPANT	\N	PRESENT	0
329585	321345	08012N	PARTICIPANT	\N	PRESENT	0
329586	321345	08035V	PARTICIPANT	\N	PRESENT	0
329587	321345	19531S	PARTICIPANT	\N	PRESENT	0
329588	321345	04092N	PARTICIPANT	\N	PRESENT	0
329589	321345	19649G	PARTICIPANT	\N	PRESENT	0
329590	321345	19527W	PARTICIPANT	\N	PRESENT	0
329591	321345	08017T	PARTICIPANT	\N	PRESENT	0
329592	321345	19760E	PARTICIPANT	\N	PRESENT	0
329593	321345	04047H	PARTICIPANT	\N	PRESENT	0
329594	321345	19713W	PARTICIPANT	\N	PRESENT	0
329595	321345	19319Q	PARTICIPANT	\N	PRESENT	0
329596	321345	14219Q	PARTICIPANT	\N	PRESENT	0
329597	321345	14042U	PARTICIPANT	\N	PRESENT	0
329598	321345	14115H	PARTICIPANT	\N	PRESENT	0
329599	321345	19735D	PARTICIPANT	\N	PRESENT	0
329600	321345	19699S	PARTICIPANT	\N	PRESENT	0
329601	321345	19737F	PARTICIPANT	\N	PRESENT	0
329602	321345	19511N	PARTICIPANT	\N	PRESENT	0
329603	321345	19691J	PARTICIPANT	\N	PRESENT	0
329604	321345	98023Q	PARTICIPANT	\N	PRESENT	0
329605	321345	19369B	PARTICIPANT	\N	PRESENT	0
329606	321345	01034P	PARTICIPANT	\N	PRESENT	0
329607	321345	08044W	PARTICIPANT	\N	PRESENT	0
329608	321345	14231L	PARTICIPANT	\N	PRESENT	0
329609	321345	04089T	PARTICIPANT	\N	PRESENT	0
329610	321345	19335Q	PARTICIPANT	\N	PRESENT	0
329611	321345	14267Y	PARTICIPANT	\N	PRESENT	0
329612	321345	14221J	PARTICIPANT	\N	PRESENT	0
329613	321345	19739H	PARTICIPANT	\N	PRESENT	0
329614	321345	14089Y	PARTICIPANT	\N	PRESENT	0
329615	321345	14083S	PARTICIPANT	\N	PRESENT	0
329616	321345	19749K	PARTICIPANT	\N	PRESENT	0
329617	321345	19367Y	PARTICIPANT	\N	PRESENT	0
329618	321345	19621T	PARTICIPANT	\N	PRESENT	0
329619	321345	11085T	PARTICIPANT	\N	PRESENT	0
329620	321345	95067Q	PARTICIPANT	\N	PRESENT	0
329621	321345	04008A	PARTICIPANT	\N	PRESENT	0
329622	321345	14205J	PARTICIPANT	\N	PRESENT	0
329623	321345	11109J	PARTICIPANT	\N	PRESENT	0
329624	321345	11049P	PARTICIPANT	\N	PRESENT	0
329625	321345	04040A	PARTICIPANT	\N	PRESENT	0
329626	321345	11070L	PARTICIPANT	\N	PRESENT	0
311667	311666	19443T	PARTICIPANT	\N	PRESENT	0
313129	311721	14327T	PARTICIPANT	\N	PRESENT	0
313130	311721	14331P	PARTICIPANT	\N	PRESENT	0
313131	311721	95041E	PARTICIPANT	\N	PRESENT	0
313132	311721	01057W	PARTICIPANT	\N	PRESENT	0
313133	311721	11074Q	PRESIDENT	0	PRESENT	0
313134	311721	88008L	PARTICIPANT	\N	PRESENT	0
313135	311721	07029T	PARTICIPANT	\N	PRESENT	0
313136	311721	14085U	PARTICIPANT	\N	PRESENT	0
313137	311721	14277B	PARTICIPANT	\N	PRESENT	0
313138	311721	07004J	PARTICIPANT	\N	PRESENT	0
313139	311721	08010L	PARTICIPANT	\N	PRESENT	0
313140	311721	14253S	PARTICIPANT	\N	PRESENT	0
313141	311721	08012N	PARTICIPANT	\N	PRESENT	0
313142	311721	11048N	PARTICIPANT	\N	PRESENT	0
313143	311721	19711U	PARTICIPANT	\N	PRESENT	0
313144	311721	19531S	PARTICIPANT	\N	PRESENT	0
313145	311721	08011M	PARTICIPANT	\N	PRESENT	0
313146	311721	04086Q	PARTICIPANT	\N	PRESENT	0
313147	311721	11040E	PARTICIPANT	\N	PRESENT	0
313148	311721	14199E	PARTICIPANT	\N	PRESENT	0
313149	311721	11012A	PARTICIPANT	\N	PRESENT	0
313150	311721	14121F	PARTICIPANT	\N	PRESENT	0
313151	311721	99004R	PARTICIPANT	\N	PRESENT	0
313152	311721	11104D	PARTICIPANT	\N	PRESENT	0
313153	311721	04061F	PARTICIPANT	\N	PRESENT	0
313154	310419	19679N	PARTICIPANT	\N	PRESENT	0
313155	311341	19443T	PARTICIPANT	\N	PRESENT	0
313156	311341	14235Q	PARTICIPANT	\N	PRESENT	0
313157	311341	14079W	PARTICIPANT	\N	PRESENT	0
313158	311341	08058D	PARTICIPANT	\N	PRESENT	0
313159	311341	04042C	PRESIDENT	0	PRESENT	0
313160	311341	14028W	PARTICIPANT	\N	PRESENT	0
313161	311341	19669L	PARTICIPANT	\N	PRESENT	0
313162	311341	11066Q	PARTICIPANT	\N	PRESENT	0
313163	311341	19721W	PARTICIPANT	\N	PRESENT	0
313164	311341	08056B	PARTICIPANT	\N	PRESENT	0
313165	311341	19709B	PARTICIPANT	\N	PRESENT	0
313166	311341	98022P	PARTICIPANT	\N	PRESENT	0
313167	311341	14267Y	PARTICIPANT	\N	PRESENT	0
313168	311341	08049C	PARTICIPANT	\N	PRESENT	0
313169	311341	97011G	PARTICIPANT	\N	PRESENT	0
313170	311341	19583F	PARTICIPANT	\N	PRESENT	0
313171	311341	01058X	PARTICIPANT	\N	PRESENT	0
313172	311341	11115U	PARTICIPANT	\N	PRESENT	0
313173	311341	14211G	PARTICIPANT	\N	PRESENT	0
313174	311341	98005N	PARTICIPANT	\N	PRESENT	0
313175	311341	04034C	PARTICIPANT	\N	PRESENT	0
313176	311341	04040A	PARTICIPANT	\N	PRESENT	0
313177	311341	14193X	PARTICIPANT	\N	PRESENT	0
313178	311341	08061X	PARTICIPANT	\N	PRESENT	0
313179	311341	08047A	PARTICIPANT	\N	PRESENT	0
313180	311341	11054L	PARTICIPANT	\N	PRESENT	0
313181	311341	16685X	PARTICIPANT	\N	PRESENT	0
313182	311341	14133K	PARTICIPANT	\N	PRESENT	0
313183	311341	19251M	PARTICIPANT	\N	PRESENT	0
313184	311341	14055N	PARTICIPANT	\N	PRESENT	0
313185	311341	95067Q	PARTICIPANT	\N	PRESENT	0
313186	311341	01062T	PARTICIPANT	\N	PRESENT	0
313187	311341	98050T	PARTICIPANT	\N	PRESENT	0
313188	311721	11053K	PARTICIPANT	\N	PRESENT	0
313189	311721	19667J	PARTICIPANT	\N	PRESENT	0
313190	311721	89017R	PARTICIPANT	\N	PRESENT	0
313191	311721	14225N	PARTICIPANT	\N	PRESENT	0
313192	311721	19647E	PARTICIPANT	\N	PRESENT	0
313193	311721	19479G	PARTICIPANT	\N	PRESENT	0
313194	311721	08034U	PARTICIPANT	\N	PRESENT	0
313195	311721	19651A	PARTICIPANT	\N	PRESENT	0
313196	311721	08069G	PARTICIPANT	\N	PRESENT	0
313197	311721	14173T	PARTICIPANT	\N	PRESENT	0
313198	311721	19741B	PARTICIPANT	\N	PRESENT	0
313199	311341	08053X	PARTICIPANT	\N	PRESENT	0
313200	311341	11064N	PARTICIPANT	\N	PRESENT	0
313201	311341	14255U	PARTICIPANT	\N	PRESENT	0
313202	311341	11041F	PARTICIPANT	\N	PRESENT	0
313203	311341	12041X	PARTICIPANT	\N	PRESENT	0
313204	310940	14051J	PARTICIPANT	\N	PRESENT	0
313205	310940	14219Q	PARTICIPANT	\N	PRESENT	0
313206	310940	98023Q	PARTICIPANT	\N	PRESENT	0
313207	310940	14169X	PARTICIPANT	\N	PRESENT	0
313216	310940	19745F	PARTICIPANT	\N	PRESENT	0
313217	310421	19697Q	PARTICIPANT	\N	PRESENT	0
313218	310421	11067R	PARTICIPANT	\N	PRESENT	0
313219	310421	11077T	PARTICIPANT	\N	PRESENT	0
313220	310421	19569H	PARTICIPANT	\N	PRESENT	0
313221	310421	11097X	PARTICIPANT	\N	PRESENT	0
313222	310421	19415P	PARTICIPANT	\N	PRESENT	0
313223	310421	14223L	PARTICIPANT	\N	PRESENT	0
313224	310421	04045F	PARTICIPANT	\N	PRESENT	0
313225	310421	14026U	PARTICIPANT	\N	PRESENT	0
313226	310421	17779H	PARTICIPANT	\N	PRESENT	0
313227	310421	19703U	PARTICIPANT	\N	PRESENT	0
313228	310421	14239U	PARTICIPANT	\N	PRESENT	0
313229	310421	11031D	PARTICIPANT	\N	PRESENT	0
313230	310421	19553Y	PARTICIPANT	\N	PRESENT	0
313231	310421	14087W	PARTICIPANT	\N	PRESENT	0
313232	310421	19679N	PARTICIPANT	\N	PRESENT	0
313233	310421	14042U	PARTICIPANT	\N	PRESENT	0
313234	310421	08048B	PARTICIPANT	\N	PRESENT	0
313235	310421	14195A	PARTICIPANT	\N	PRESENT	0
313236	310421	19367Y	PARTICIPANT	\N	PRESENT	0
313237	310421	14213J	PARTICIPANT	\N	PRESENT	0
313238	310421	14261S	PARTICIPANT	\N	PRESENT	0
313239	310421	14217N	PARTICIPANT	\N	PRESENT	0
313240	310421	19335Q	PARTICIPANT	\N	PRESENT	0
313241	310421	19683J	PARTICIPANT	\N	PRESENT	0
313242	310421	10006L	PARTICIPANT	\N	PRESENT	0
313243	310421	98024R	PRESIDENT	0	PRESENT	0
313244	310421	19521Q	PARTICIPANT	\N	PRESENT	0
313245	310421	19527W	PARTICIPANT	\N	PRESENT	0
313246	310421	01034P	PARTICIPANT	\N	PRESENT	0
313247	310421	11045K	PARTICIPANT	\N	PRESENT	0
313248	310421	08052W	PARTICIPANT	\N	PRESENT	0
313249	310421	19691J	PARTICIPANT	\N	PRESENT	0
313250	310421	19715Y	PARTICIPANT	\N	PRESENT	0
313251	310421	19723Y	PARTICIPANT	\N	PRESENT	0
313252	310421	19727D	PARTICIPANT	\N	PRESENT	0
313253	310421	14119M	PARTICIPANT	\N	PRESENT	0
313254	310421	11103C	PARTICIPANT	\N	PRESENT	0
313255	310421	14071N	PARTICIPANT	\N	PRESENT	0
313256	310421	19760E	PARTICIPANT	\N	PRESENT	0
313257	310421	04092N	PARTICIPANT	\N	EXCUSE	0
313258	310421	14355X	PARTICIPANT	\N	EXCUSE	0
313259	310421	08041T	PARTICIPANT	\N	EXCUSE	0
313260	310421	14227Q	PARTICIPANT	\N	EXCUSE	0
313261	310940	14038Y	PARTICIPANT	\N	PRESENT	0
313262	310940	14103D	PARTICIPANT	\N	PRESENT	0
313263	310940	05012A	PARTICIPANT	\N	PRESENT	0
313264	310940	19525U	PARTICIPANT	\N	PRESENT	0
313265	310940	14237S	PARTICIPANT	\N	PRESENT	0
313266	310940	14029X	PARTICIPANT	\N	PRESENT	0
313267	310940	19681G	PARTICIPANT	\N	EXCUSE	0
313268	310940	19737F	PARTICIPANT	\N	EXCUSE	0
313325	311342	98029W	PARTICIPANT	\N	PRESENT	0
313333	311721	11070L	PARTICIPANT	\N	PRESENT	0
313334	311721	11110B	PARTICIPANT	\N	PRESENT	0
313335	311721	19349W	PARTICIPANT	\N	PRESENT	0
313336	311721	19689Q	PARTICIPANT	\N	PRESENT	0
313337	311721	14034U	PARTICIPANT	\N	PRESENT	0
313396	311331	07034Q	PRESIDENT	1	PRESENT	0
313397	311331	19253P	PARTICIPANT	\N	PRESENT	0
313398	311331	01024M	PARTICIPANT	\N	PRESENT	0
313399	311331	19581D	PARTICIPANT	\N	PRESENT	0
313400	311331	04038G	PARTICIPANT	\N	PRESENT	0
313401	311331	19585H	PARTICIPANT	\N	PRESENT	0
313402	311331	04047H	PARTICIPANT	\N	PRESENT	0
313403	311331	19673G	PARTICIPANT	\N	PRESENT	0
313404	311331	01028R	PARTICIPANT	\N	PRESENT	0
313405	311331	11033F	PARTICIPANT	\N	PRESENT	0
313406	311331	05008E	PRESIDENT	0	PRESENT	0
313407	311331	19447X	PARTICIPANT	\N	PRESENT	0
313408	311331	19725B	PARTICIPANT	\N	PRESENT	0
313409	311331	19729F	PARTICIPANT	\N	PRESENT	0
313410	311331	14275Y	PARTICIPANT	\N	PRESENT	0
313411	311331	19629C	PARTICIPANT	\N	PRESENT	0
313412	311331	14041T	PARTICIPANT	\N	PRESENT	0
313413	311331	14151M	PARTICIPANT	\N	PRESENT	0
313414	311331	14215L	PARTICIPANT	\N	PRESENT	0
313415	311331	08018U	PARTICIPANT	\N	PRESENT	0
313416	311331	11049P	PARTICIPANT	\N	PRESENT	0
313417	311331	11072N	PARTICIPANT	\N	PRESENT	0
313418	311331	19762G	PARTICIPANT	\N	PRESENT	0
313419	311331	98035U	PARTICIPANT	\N	PRESENT	0
313420	311331	14111D	PARTICIPANT	\N	PRESENT	0
313421	311331	14065Q	PARTICIPANT	\N	PRESENT	0
313422	311331	19649G	PARTICIPANT	\N	PRESENT	0
313423	311331	11026G	PARTICIPANT	\N	PRESENT	0
313424	311331	08045X	PARTICIPANT	\N	PRESENT	0
313425	311331	10015M	PARTICIPANT	\N	PRESENT	0
320614	319336	08068F	PARTICIPANT	\N	EXCUSE	0
320615	319336	14026U	PARTICIPANT	\N	EXCUSE	0
320616	319336	19762G	PARTICIPANT	\N	EXCUSE	0
320617	314105	14205J	PARTICIPANT	\N	PRESENT	0
320618	314105	19479G	PARTICIPANT	\N	PRESENT	0
320619	314105	11104D	PARTICIPANT	\N	PRESENT	0
320620	318050	14051J	PARTICIPANT	\N	PRESENT	0
320621	318050	08060W	PARTICIPANT	\N	PRESENT	0
320622	318050	08055A	PARTICIPANT	\N	PRESENT	0
320623	318050	19681G	PARTICIPANT	\N	PRESENT	0
320624	319283	95067Q	PARTICIPANT	\N	PRESENT	0
320625	319283	14028W	PARTICIPANT	\N	PRESENT	0
320626	318050	14237S	PARTICIPANT	\N	PRESENT	0
320627	318050	14038Y	PARTICIPANT	\N	PRESENT	0
320628	318050	19733B	PARTICIPANT	\N	PRESENT	0
320629	318050	14221J	PARTICIPANT	\N	PRESENT	0
320630	318050	19289C	PARTICIPANT	\N	PRESENT	0
320631	318050	19333N	PARTICIPANT	\N	PRESENT	0
320632	318050	19387D	PARTICIPANT	\N	PRESENT	0
320633	318050	14219Q	PARTICIPANT	\N	PRESENT	0
320634	318050	14169X	PARTICIPANT	\N	PRESENT	0
320635	318050	19599P	PARTICIPANT	\N	PRESENT	0
320636	318050	14029X	PARTICIPANT	\N	PRESENT	0
320637	318050	19503N	PARTICIPANT	\N	PRESENT	0
320638	318050	14157T	PARTICIPANT	\N	PRESENT	0
320639	318050	18083K	PARTICIPANT	\N	PRESENT	0
320640	318050	19737F	PARTICIPANT	\N	PRESENT	0
320641	318050	08024S	PARTICIPANT	\N	PRESENT	0
320642	319283	14331P	PARTICIPANT	\N	PRESENT	0
320643	319283	01048V	PARTICIPANT	\N	PRESENT	0
320644	318050	02002K	PARTICIPANT	\N	PRESENT	0
320645	318050	19383Y	PARTICIPANT	\N	PRESENT	0
320646	318050	19551W	PARTICIPANT	\N	PRESENT	0
320647	318050	19347U	PARTICIPANT	\N	PRESENT	0
320648	318050	19739H	PARTICIPANT	\N	PRESENT	0
320700	320699	14229S	PARTICIPANT	\N	PRESENT	0
320702	320701	14229S	PARTICIPANT	\N	PRESENT	0
320703	320701	19611R	PARTICIPANT	\N	PRESENT	0
320704	320701	08043V	PARTICIPANT	\N	PRESENT	0
320705	320701	19735D	PARTICIPANT	\N	PRESENT	0
320707	320706	92040Q	PARTICIPANT	\N	PRESENT	0
320708	320706	19593H	PARTICIPANT	\N	PRESENT	0
320711	320709	04070G	PARTICIPANT	\N	PRESENT	0
320715	320712	04070G	PARTICIPANT	\N	PRESENT	0
320718	320717	19729F	PARTICIPANT	\N	PRESENT	0
320719	320717	19649G	PARTICIPANT	\N	PRESENT	0
320721	320720	19729F	PARTICIPANT	\N	PRESENT	0
320723	320722	14179A	PARTICIPANT	\N	PRESENT	0
320727	320726	08039A	PARTICIPANT	\N	PRESENT	0
320728	320726	19643A	PARTICIPANT	\N	PRESENT	0
320730	320729	08039A	PARTICIPANT	\N	PRESENT	0
320772	320771	96004D	PARTICIPANT	\N	PRESENT	0
320773	320771	95037J	PARTICIPANT	\N	PRESENT	0
320774	320771	14026U	PARTICIPANT	\N	PRESENT	0
320775	320771	14033T	PARTICIPANT	\N	PRESENT	0
320776	320771	14207L	PARTICIPANT	\N	PRESENT	0
320785	320771	14357A	PARTICIPANT	\N	PRESENT	0
320778	320771	11099A	PARTICIPANT	\N	PRESENT	0
320779	320771	14257W	PARTICIPANT	\N	PRESENT	0
320780	320771	11090Q	PARTICIPANT	\N	PRESENT	0
320781	320771	19441R	PARTICIPANT	\N	PRESENT	0
320787	317557	11010L	PARTICIPANT	\N	EXCUSE	0
320786	320771	19507S	PARTICIPANT	\N	PRESENT	0
320788	317557	98005N	PARTICIPANT	\N	EXCUSE	0
320789	317557	19319Q	PARTICIPANT	\N	EXCUSE	0
320790	317557	14059S	PARTICIPANT	\N	EXCUSE	0
320805	320802	14065Q	PARTICIPANT	\N	PRESENT	0
320806	320802	10015M	PARTICIPANT	\N	PRESENT	0
320807	320803	14065Q	PARTICIPANT	\N	PRESENT	0
320808	320803	10015M	PARTICIPANT	\N	PRESENT	0
320891	319337	14115H	PARTICIPANT	\N	PRESENT	0
320892	319337	14030Q	PRESIDENT	0	PRESENT	0
320893	319337	08043V	PARTICIPANT	\N	PRESENT	0
320894	319337	19367Y	PARTICIPANT	\N	PRESENT	0
320895	319337	19643A	PARTICIPANT	\N	PRESENT	0
320896	319337	18083K	PARTICIPANT	\N	PRESENT	0
320897	319337	11031D	PARTICIPANT	\N	PRESENT	0
320899	319337	80013X	PARTICIPANT	\N	PRESENT	0
320900	319337	19693L	PARTICIPANT	\N	PRESENT	0
320901	319337	14217N	PARTICIPANT	\N	PRESENT	0
320902	319337	19715Y	PARTICIPANT	\N	PRESENT	0
320904	319337	19731Y	PARTICIPANT	\N	PRESENT	0
320905	319337	08031R	PARTICIPANT	\N	PRESENT	0
320906	319337	11067R	PARTICIPANT	\N	PRESENT	0
320907	319337	19679N	PARTICIPANT	\N	PRESENT	0
320908	319337	11045K	PARTICIPANT	\N	PRESENT	0
320909	319337	19749K	PARTICIPANT	\N	PRESENT	0
320910	319337	08017T	PARTICIPANT	\N	EXCUSE	0
320911	319337	01043Q	PARTICIPANT	\N	EXCUSE	0
320912	319337	19577H	PARTICIPANT	\N	EXCUSE	0
320921	318797	08048B	PARTICIPANT	\N	PRESENT	0
320922	318797	11048N	PARTICIPANT	\N	PRESENT	0
320923	318797	01057W	PARTICIPANT	\N	PRESENT	0
320924	318797	08038Y	PARTICIPANT	\N	PRESENT	0
320925	318797	95063L	PARTICIPANT	\N	PRESENT	0
320926	318797	08049C	PARTICIPANT	\N	PRESENT	0
320927	318797	14028W	PARTICIPANT	\N	PRESENT	0
320928	318797	14103D	PARTICIPANT	\N	PRESENT	0
320929	318797	04045F	PARTICIPANT	\N	PRESENT	0
320942	320804	14133K	PARTICIPANT	\N	PRESENT	0
320943	320804	14331P	PARTICIPANT	\N	PRESENT	0
320944	320800	14133K	PARTICIPANT	\N	PRESENT	0
320945	320800	14001X	PARTICIPANT	\N	PRESENT	0
320946	320800	14331P	PARTICIPANT	\N	PRESENT	0
320947	320801	14001X	PARTICIPANT	\N	PRESENT	0
320948	320801	14331P	PARTICIPANT	\N	PRESENT	0
320955	320954	19762G	PARTICIPANT	\N	PRESENT	0
320973	320972	08045X	PARTICIPANT	\N	PRESENT	0
320975	320972	19581D	PARTICIPANT	\N	PRESENT	0
321056	311803	80013X	PARTICIPANT	\N	PRESENT	0
321057	311803	19693L	PARTICIPANT	\N	PRESENT	0
321058	311803	19663E	PARTICIPANT	\N	PRESENT	0
321059	311803	01048V	PRESIDENT	0	PRESENT	0
321060	311803	19533U	PARTICIPANT	\N	PRESENT	0
321061	311803	01058X	PARTICIPANT	\N	PRESENT	0
321062	311803	08053X	PARTICIPANT	\N	EXCUSE	0
321063	311803	04043D	PARTICIPANT	\N	EXCUSE	0
321077	321076	14179A	PARTICIPANT	\N	PRESENT	0
321078	321076	14059S	PARTICIPANT	\N	PRESENT	0
321080	321076	19551W	PARTICIPANT	\N	PRESENT	0
321081	321076	07033P	PARTICIPANT	\N	PRESENT	0
321371	321365	92040Q	PARTICIPANT	\N	PRESENT	0
321372	321365	19749K	PARTICIPANT	\N	PRESENT	0
321373	321365	19611R	PARTICIPANT	\N	PRESENT	0
321378	321376	92040Q	PARTICIPANT	\N	PRESENT	0
321379	321376	19749K	PARTICIPANT	\N	PRESENT	0
321383	321381	08012N	PARTICIPANT	\N	PRESENT	0
321389	321386	11104D	PARTICIPANT	\N	PRESENT	0
321796	321795	04047H	PARTICIPANT	\N	PRESENT	0
321797	321795	19649G	PARTICIPANT	\N	PRESENT	0
321799	321798	01024M	PARTICIPANT	\N	PRESENT	0
321803	321802	10015M	PARTICIPANT	\N	PRESENT	0
321804	321802	14071N	PARTICIPANT	\N	PRESENT	0
321805	321802	14034U	PARTICIPANT	\N	PRESENT	0
321806	321802	95062K	PARTICIPANT	\N	PRESENT	0
321807	321802	19703U	PARTICIPANT	\N	PRESENT	0
321808	321802	14061L	PARTICIPANT	\N	PRESENT	0
321816	320359	14021P	PARTICIPANT	\N	PRESENT	0
321817	319276	14021P	PARTICIPANT	\N	PRESENT	0
321821	321820	14021P	PARTICIPANT	\N	PRESENT	0
321825	309521	14119M	PARTICIPANT	\N	PRESENT	0
321826	309521	14281W	PARTICIPANT	\N	PRESENT	0
321827	317476	14087W	PARTICIPANT	\N	PRESENT	0
321828	317479	14087W	PARTICIPANT	\N	PRESENT	0
321850	321849	19503N	PARTICIPANT	\N	PRESENT	0
321852	321851	95067Q	PARTICIPANT	\N	PRESENT	0
321853	321851	04040A	PARTICIPANT	\N	PRESENT	0
321854	321851	14079W	PARTICIPANT	\N	PRESENT	0
321855	321851	19503N	PARTICIPANT	\N	PRESENT	0
321856	321851	01058X	PARTICIPANT	\N	PRESENT	0
321858	321857	14187A	PARTICIPANT	\N	PRESENT	0
321971	321970	14221J	PARTICIPANT	\N	PRESENT	0
322041	321789	19697Q	PARTICIPANT	\N	PRESENT	0
322042	321789	11097X	PARTICIPANT	\N	PRESENT	0
322043	321789	19415P	PARTICIPANT	\N	PRESENT	0
322044	321789	14223L	PARTICIPANT	\N	PRESENT	0
322045	321789	14227Q	PARTICIPANT	\N	PRESENT	0
322046	321789	17779H	PARTICIPANT	\N	PRESENT	0
322047	321789	11031D	PARTICIPANT	\N	PRESENT	0
322048	321789	14239U	PARTICIPANT	\N	PRESENT	0
305478	305477	01024M	PARTICIPANT	\N	PRESENT	0
306361	306009	19747H	PARTICIPANT	\N	PRESENT	0
306362	306009	14199E	PARTICIPANT	\N	PRESENT	0
306363	306009	14115H	PARTICIPANT	\N	PRESENT	0
306376	306009	19533U	PARTICIPANT	\N	PRESENT	0
306365	306009	04086Q	PARTICIPANT	\N	PRESENT	0
306366	306009	14357A	PARTICIPANT	\N	PRESENT	0
306367	306009	98024R	PARTICIPANT	\N	PRESENT	0
306368	306009	19581D	PARTICIPANT	\N	PRESENT	0
306369	306009	95030B	PARTICIPANT	\N	PRESENT	0
306370	306009	14123H	PARTICIPANT	\N	PRESENT	0
306371	306009	11101A	PARTICIPANT	\N	PRESENT	0
306377	306009	89017R	PARTICIPANT	\N	PRESENT	0
306378	306009	11027H	PARTICIPANT	\N	PRESENT	0
306379	306009	19647E	PARTICIPANT	\N	PRESENT	0
306380	306009	14151M	PARTICIPANT	\N	PRESENT	0
306381	306009	19667J	PARTICIPANT	\N	PRESENT	0
306382	306009	14221J	PARTICIPANT	\N	PRESENT	0
306383	306009	19729F	PARTICIPANT	\N	PRESENT	0
306390	306009	19413M	PARTICIPANT	\N	PRESENT	0
306673	306010	11072N	PARTICIPANT	\N	PRESENT	0
306674	306010	14135M	PARTICIPANT	\N	PRESENT	0
306675	306010	14205J	PARTICIPANT	\N	PRESENT	0
306676	306010	14221J	PARTICIPANT	\N	PRESENT	0
306677	306010	11090Q	PARTICIPANT	\N	PRESENT	0
306678	306010	19760E	PARTICIPANT	\N	PRESENT	0
306679	306010	19333N	PARTICIPANT	\N	PRESENT	0
306680	306010	08053X	PARTICIPANT	\N	PRESENT	0
306681	306010	11104D	PARTICIPANT	\N	PRESENT	0
306682	306010	14051J	PARTICIPANT	\N	PRESENT	0
306683	306010	14229S	PARTICIPANT	\N	PRESENT	0
306684	306010	08060W	PARTICIPANT	\N	PRESENT	0
306685	306010	19503N	PARTICIPANT	\N	PRESENT	0
306686	306010	08052W	PARTICIPANT	\N	PRESENT	0
306687	306010	08055A	PARTICIPANT	\N	PRESENT	0
306688	306010	19758L	PARTICIPANT	\N	PRESENT	0
306689	306010	19347U	PARTICIPANT	\N	PRESENT	0
306690	306010	08061X	PARTICIPANT	\N	PRESENT	0
306691	306010	14197C	PARTICIPANT	\N	PRESENT	0
306692	306010	14109K	PARTICIPANT	\N	PRESENT	0
306693	306010	19545Y	PARTICIPANT	\N	PRESENT	0
306694	306010	04057K	PARTICIPANT	\N	PRESENT	0
306696	306010	17589D	PARTICIPANT	\N	PRESENT	0
306698	306010	19583F	PARTICIPANT	\N	PRESENT	0
306699	306010	14261S	PARTICIPANT	\N	PRESENT	0
306700	306010	08016S	PARTICIPANT	\N	PRESENT	0
306701	306010	11012A	PARTICIPANT	\N	PRESENT	0
306702	306010	08031R	PARTICIPANT	\N	PRESENT	0
306703	306010	19563B	PARTICIPANT	\N	PRESENT	0
306704	306010	19691J	PARTICIPANT	\N	PRESENT	0
306705	306010	19369B	PARTICIPANT	\N	PRESENT	0
306706	306010	14219Q	PARTICIPANT	\N	PRESENT	0
306707	306010	19479G	PARTICIPANT	\N	PRESENT	0
306708	306010	01043Q	PARTICIPANT	\N	PRESENT	0
306709	306010	19527W	PARTICIPANT	\N	PRESENT	0
306710	306010	14257W	PARTICIPANT	\N	PRESENT	0
306711	306010	19549D	PARTICIPANT	\N	PRESENT	0
306712	306010	14207L	PARTICIPANT	\N	PRESENT	0
306713	306010	14085U	PARTICIPANT	\N	PRESENT	0
306714	306010	19631V	PARTICIPANT	\N	PRESENT	0
306715	306010	19727D	PARTICIPANT	\N	PRESENT	0
306716	306010	14083S	PARTICIPANT	\N	PRESENT	0
306717	306010	19619A	PARTICIPANT	\N	PRESENT	0
306718	306010	19335Q	PARTICIPANT	\N	PRESENT	0
306719	306010	19511N	PARTICIPANT	\N	PRESENT	0
306720	306010	19747H	PARTICIPANT	\N	PRESENT	0
306721	306010	19671E	PARTICIPANT	\N	PRESENT	0
306722	306010	01025N	PARTICIPANT	\N	PRESENT	0
306724	306010	19621T	PARTICIPANT	\N	PRESENT	0
306725	306010	89017R	PARTICIPANT	\N	PRESENT	0
306726	306010	04089T	PARTICIPANT	\N	PRESENT	0
306727	306010	14073Q	PARTICIPANT	\N	PRESENT	0
306728	306010	11067R	PARTICIPANT	\N	PRESENT	0
306729	306010	04097T	PARTICIPANT	\N	PRESENT	0
306730	306010	19515S	PARTICIPANT	\N	PRESENT	0
306731	306010	19703U	PARTICIPANT	\N	PRESENT	0
306732	306010	01057W	PARTICIPANT	\N	PRESENT	0
306733	306010	14119M	PARTICIPANT	\N	PRESENT	0
306739	306010	19415P	PARTICIPANT	\N	PRESENT	0
306737	306010	14033T	PARTICIPANT	\N	PRESENT	0
306738	306010	04088S	PARTICIPANT	\N	PRESENT	0
306740	306010	18083K	PARTICIPANT	\N	PRESENT	0
306741	306010	19467C	PARTICIPANT	\N	PRESENT	0
306742	306010	19507S	PARTICIPANT	\N	PRESENT	0
306743	306010	14029X	PARTICIPANT	\N	PRESENT	0
306744	306010	19733B	PARTICIPANT	\N	PRESENT	0
306745	306010	19399H	PARTICIPANT	\N	PRESENT	0
306746	306010	14115H	PARTICIPANT	\N	PRESENT	0
306747	306010	08015R	PARTICIPANT	\N	PRESENT	0
306748	306010	19711U	PARTICIPANT	\N	PRESENT	0
306749	306010	08028W	PARTICIPANT	\N	PRESENT	0
306750	306010	04049K	PARTICIPANT	\N	PRESENT	0
306751	306010	19575F	PARTICIPANT	\N	PRESENT	0
306752	306010	99004R	PARTICIPANT	\N	PRESENT	0
306753	306010	96004D	PARTICIPANT	\N	PRESENT	0
306754	306010	14123H	PARTICIPANT	\N	PRESENT	0
306755	306010	95030B	PARTICIPANT	\N	PRESENT	0
306756	306010	14187A	PARTICIPANT	\N	PRESENT	0
306757	306010	14193X	PARTICIPANT	\N	PRESENT	0
306758	306010	14249W	PARTICIPANT	\N	PRESENT	0
306759	306010	14357A	PARTICIPANT	\N	PRESENT	0
306760	306010	19731Y	PARTICIPANT	\N	PRESENT	0
306761	306010	04018C	PARTICIPANT	\N	PRESENT	0
306762	306010	14042U	PARTICIPANT	\N	PRESENT	0
306763	306010	14327T	PARTICIPANT	\N	PRESENT	0
306764	306010	19713W	PARTICIPANT	\N	PRESENT	0
306765	306010	14195A	PARTICIPANT	\N	PRESENT	0
306766	306010	19553Y	PARTICIPANT	\N	PRESENT	0
306767	306010	19717B	PARTICIPANT	\N	PRESENT	0
306768	306010	98029W	PARTICIPANT	\N	PRESENT	0
306769	306010	11056N	PARTICIPANT	\N	PRESENT	0
306770	306010	19695N	PARTICIPANT	\N	PRESENT	0
306771	306010	19593H	PARTICIPANT	\N	PRESENT	0
306772	306010	14267Y	PARTICIPANT	\N	PRESENT	0
306773	306010	14038Y	PARTICIPANT	\N	PRESENT	0
306774	306010	15447F	PARTICIPANT	\N	PRESENT	0
306775	306010	19269X	PARTICIPANT	\N	PRESENT	0
306776	306010	11099A	PARTICIPANT	\N	PRESENT	0
306777	306010	19387D	PARTICIPANT	\N	PRESENT	0
306778	306010	14241N	PARTICIPANT	\N	PRESENT	0
306779	306010	14107H	PARTICIPANT	\N	PRESENT	0
306780	306010	11070L	PARTICIPANT	\N	PRESENT	0
306781	306010	14081Q	PARTICIPANT	\N	PRESENT	0
306782	306010	14157T	PARTICIPANT	\N	PRESENT	0
306783	306010	11048N	PARTICIPANT	\N	PRESENT	0
306784	306010	19768N	PARTICIPANT	\N	PRESENT	0
306785	306010	19599P	PARTICIPANT	\N	PRESENT	0
306786	306010	14021P	PARTICIPANT	\N	PRESENT	0
306787	306010	14026U	PARTICIPANT	\N	PRESENT	0
306788	306010	19719D	PARTICIPANT	\N	PRESENT	0
306789	306010	19349W	PARTICIPANT	\N	PRESENT	0
306790	306010	14225N	PARTICIPANT	\N	PRESENT	0
306791	306010	19413M	PARTICIPANT	\N	PRESENT	0
306792	306010	14211G	PARTICIPANT	\N	PRESENT	0
306793	306010	14147R	PARTICIPANT	\N	PRESENT	0
306794	306010	14213J	PARTICIPANT	\N	PRESENT	0
306795	306010	19533U	PARTICIPANT	\N	PRESENT	0
306796	306010	08069G	PARTICIPANT	\N	PRESENT	0
306797	306010	19749K	PARTICIPANT	\N	PRESENT	0
306798	306010	11097X	PARTICIPANT	\N	PRESENT	0
306799	306010	19737F	PARTICIPANT	\N	PRESENT	0
306801	306010	19551W	PARTICIPANT	\N	PRESENT	0
306802	305921	19581D	PARTICIPANT	\N	PRESENT	0
306803	305921	04044E	PARTICIPANT	\N	PRESENT	0
306804	305921	04047H	PARTICIPANT	\N	PRESENT	0
306805	305921	01028R	PARTICIPANT	\N	PRESENT	0
306806	305921	05008E	PRESIDENT	0	PRESENT	0
306807	305921	19447X	PARTICIPANT	\N	PRESENT	0
306808	305921	14231L	PARTICIPANT	\N	PRESENT	0
306809	305921	14147R	PARTICIPANT	\N	PRESENT	0
306810	305921	14179A	PARTICIPANT	\N	PRESENT	0
306811	305921	14151M	PARTICIPANT	\N	PRESENT	0
306812	305921	08010L	PARTICIPANT	\N	PRESENT	0
306813	305921	14215L	PARTICIPANT	\N	PRESENT	0
306814	305921	14053L	PARTICIPANT	\N	PRESENT	0
306815	305921	14111D	PARTICIPANT	\N	PRESENT	0
306816	305921	19649G	PARTICIPANT	\N	PRESENT	0
306817	305921	07034Q	PARTICIPANT	\N	PRESENT	0
306818	305921	11026G	PARTICIPANT	\N	PRESENT	0
306819	305921	19253P	PARTICIPANT	\N	PRESENT	0
306820	305921	01024M	PARTICIPANT	\N	PRESENT	0
306821	305921	19725B	PARTICIPANT	\N	PRESENT	0
306822	305921	14089Y	PARTICIPANT	\N	PRESENT	0
306823	305921	19729F	PARTICIPANT	\N	PRESENT	0
306824	305921	08044W	PARTICIPANT	\N	PRESENT	0
306825	305921	14069U	PARTICIPANT	\N	PRESENT	0
306826	305921	11049P	PARTICIPANT	\N	PRESENT	0
306827	305921	19762G	PARTICIPANT	\N	PRESENT	0
329627	321345	14255U	PARTICIPANT	\N	PRESENT	0
331923	321353	08031R	PARTICIPANT	\N	PRESENT	0
331924	321353	19333N	PARTICIPANT	\N	PRESENT	0
331926	321353	11012A	PARTICIPANT	\N	PRESENT	0
331948	321353	07029T	PARTICIPANT	\N	PRESENT	0
331949	321353	19295A	PARTICIPANT	\N	PRESENT	0
331950	321353	18083K	PARTICIPANT	\N	PRESENT	0
331951	321353	11085T	PARTICIPANT	\N	PRESENT	0
331952	321353	08069G	PARTICIPANT	\N	PRESENT	0
331953	321353	08010L	PARTICIPANT	\N	PRESENT	0
331989	321354	19631V	PARTICIPANT	\N	PRESENT	0
331990	321354	04086Q	PARTICIPANT	\N	PRESENT	0
331991	321354	08051V	PARTICIPANT	\N	PRESENT	0
331992	321354	08031R	PARTICIPANT	\N	PRESENT	0
331993	321354	19545Y	PARTICIPANT	\N	PRESENT	0
331994	321354	07029T	PARTICIPANT	\N	PRESENT	0
331995	321354	04088S	PARTICIPANT	\N	PRESENT	0
331996	321354	07004J	PARTICIPANT	\N	PRESENT	0
331997	321354	11090Q	PARTICIPANT	\N	PRESENT	0
331998	321354	08069G	PARTICIPANT	\N	PRESENT	0
331999	321354	18083K	PARTICIPANT	\N	PRESENT	0
332000	321354	11012A	PARTICIPANT	\N	PRESENT	0
332001	321354	14169X	PARTICIPANT	\N	PRESENT	0
332002	321354	11077T	PARTICIPANT	\N	PRESENT	0
332003	321354	14327T	PARTICIPANT	\N	PRESENT	0
332004	321354	08010L	PARTICIPANT	\N	PRESENT	0
332005	321354	14081Q	PARTICIPANT	\N	PRESENT	0
332006	321354	11048N	PARTICIPANT	\N	PRESENT	0
332007	321354	14261S	PARTICIPANT	\N	PRESENT	0
332008	321354	95063L	PARTICIPANT	\N	PRESENT	0
332009	321354	19489J	PARTICIPANT	\N	PRESENT	0
332010	321354	08011M	PARTICIPANT	\N	PRESENT	0
332011	321354	19369B	PARTICIPANT	\N	PRESENT	0
332012	321354	04038G	PARTICIPANT	\N	PRESENT	0
332013	321354	19507S	PARTICIPANT	\N	PRESENT	0
332014	321354	14069U	PARTICIPANT	\N	PRESENT	0
332057	321355	14207L	PARTICIPANT	\N	PRESENT	0
332058	321355	19782L	PARTICIPANT	\N	PRESENT	0
332059	321355	04047H	PARTICIPANT	\N	PRESENT	0
332060	321355	11048N	PARTICIPANT	\N	PRESENT	0
332061	321355	95030B	PARTICIPANT	\N	PRESENT	0
332062	321355	14115H	PARTICIPANT	\N	PRESENT	0
332063	321355	01024M	PARTICIPANT	\N	PRESENT	0
331987	321354	11070L	PARTICIPANT	\N	PRESENT	0
331988	321354	01043Q	PARTICIPANT	\N	PRESENT	0
332064	321355	01028R	PARTICIPANT	\N	PRESENT	0
332065	321355	19467C	PARTICIPANT	\N	PRESENT	0
332066	321355	19399H	PARTICIPANT	\N	PRESENT	0
332067	321355	14157T	PARTICIPANT	\N	PRESENT	0
332068	321355	14085U	PARTICIPANT	\N	PRESENT	0
332069	321355	19413M	PARTICIPANT	\N	PRESENT	0
332070	321355	04086Q	PARTICIPANT	\N	PRESENT	0
332071	321355	11012A	PARTICIPANT	\N	PRESENT	0
332072	321355	08014Q	PARTICIPANT	\N	PRESENT	0
332073	321355	14093U	PARTICIPANT	\N	PRESENT	0
332074	321355	18083K	PARTICIPANT	\N	PRESENT	0
332075	321355	08062Y	PARTICIPANT	\N	PRESENT	0
332076	321355	08011M	PARTICIPANT	\N	PRESENT	0
332077	321355	19719D	PARTICIPANT	\N	PRESENT	0
332078	321355	01062T	PARTICIPANT	\N	PRESENT	0
332079	321355	08069G	PARTICIPANT	\N	PRESENT	0
332080	321355	19631V	PARTICIPANT	\N	PRESENT	0
332134	321356	08014Q	PARTICIPANT	\N	PRESENT	0
332135	321356	19507S	PARTICIPANT	\N	PRESENT	0
332136	321356	01025N	PARTICIPANT	\N	PRESENT	0
332137	321356	14207L	PARTICIPANT	\N	PRESENT	0
332138	321356	14257W	PARTICIPANT	\N	PRESENT	0
332139	321356	19631V	PARTICIPANT	\N	PRESENT	0
332140	321356	19441R	PARTICIPANT	\N	PRESENT	0
332141	321356	19369B	PARTICIPANT	\N	PRESENT	0
332142	321356	07004J	PARTICIPANT	\N	PRESENT	0
332143	321356	18083K	PARTICIPANT	\N	PRESENT	0
332144	321356	14033T	PARTICIPANT	\N	PRESENT	0
332145	321356	19693L	PARTICIPANT	\N	PRESENT	0
332146	321356	07029T	PARTICIPANT	\N	PRESENT	0
332147	321356	19399H	PARTICIPANT	\N	PRESENT	0
332148	321356	14157T	PARTICIPANT	\N	PRESENT	0
332149	321356	14115H	PARTICIPANT	\N	PRESENT	0
332150	321356	19671E	PARTICIPANT	\N	PRESENT	0
332151	321356	14357A	PARTICIPANT	\N	PRESENT	0
332152	321356	14253S	PARTICIPANT	\N	PRESENT	0
332153	321356	19467C	PARTICIPANT	\N	PRESENT	0
332154	321356	19413M	PARTICIPANT	\N	PRESENT	0
332155	321356	11056N	PARTICIPANT	\N	PRESENT	0
332156	321356	19563B	PARTICIPANT	\N	PRESENT	0
332157	321356	08019V	PARTICIPANT	\N	PRESENT	0
332158	321356	08062Y	PARTICIPANT	\N	PRESENT	0
332159	321356	14085U	PARTICIPANT	\N	PRESENT	0
332160	321356	99004R	PARTICIPANT	\N	PRESENT	0
332161	321356	19741B	PARTICIPANT	\N	PRESENT	0
332162	321356	17637T	PARTICIPANT	\N	PRESENT	0
332163	321356	11064N	PARTICIPANT	\N	PRESENT	0
332164	321356	19269X	PARTICIPANT	\N	PRESENT	0
332165	321356	01028R	PARTICIPANT	\N	PRESENT	0
332166	321356	95030B	PARTICIPANT	\N	PRESENT	0
332167	321356	11048N	PARTICIPANT	\N	PRESENT	0
332168	321356	19782L	PARTICIPANT	\N	PRESENT	0
332169	321356	19583F	PARTICIPANT	\N	PRESENT	0
332170	321356	14235Q	PARTICIPANT	\N	PRESENT	0
332171	321356	19503N	PARTICIPANT	\N	PRESENT	0
332172	321356	08034U	PARTICIPANT	\N	PRESENT	0
332173	321356	19629C	PARTICIPANT	\N	PRESENT	0
332174	321356	95062K	PARTICIPANT	\N	PRESENT	0
332175	321356	11012A	PARTICIPANT	\N	PRESENT	0
332176	321356	04088S	PARTICIPANT	\N	PRESENT	0
332177	321356	11085T	PARTICIPANT	\N	PRESENT	0
332178	321356	14069U	PARTICIPANT	\N	PRESENT	0
332179	321356	19689Q	PARTICIPANT	\N	PRESENT	0
332180	321356	01062T	PARTICIPANT	\N	PRESENT	0
332181	321356	08051V	PARTICIPANT	\N	PRESENT	0
332182	321356	19713W	PARTICIPANT	\N	PRESENT	0
332183	321356	14267Y	PARTICIPANT	\N	PRESENT	0
332184	321356	04042C	PARTICIPANT	\N	PRESENT	0
332132	321356	11072N	PARTICIPANT	\N	PRESENT	0
332133	321356	08069G	PARTICIPANT	\N	PRESENT	0
332185	321356	08010L	PARTICIPANT	\N	PRESENT	0
332186	321356	11027H	PARTICIPANT	\N	PRESENT	0
332187	321356	11054L	PARTICIPANT	\N	PRESENT	0
332188	321356	08058D	PARTICIPANT	\N	PRESENT	0
332189	321356	08044W	PARTICIPANT	\N	PRESENT	0
332190	321356	01058X	PARTICIPANT	\N	PRESENT	0
332191	321356	19421M	PARTICIPANT	\N	PRESENT	0
332192	321356	11074Q	PARTICIPANT	\N	PRESENT	0
332193	321356	95063L	PARTICIPANT	\N	PRESENT	0
332194	321356	19669L	PARTICIPANT	\N	PRESENT	0
332195	321356	11080N	PARTICIPANT	\N	PRESENT	0
332196	321356	04035D	PARTICIPANT	\N	PRESENT	0
332197	321356	04086Q	PARTICIPANT	\N	PRESENT	0
332198	321356	19717B	PARTICIPANT	\N	PRESENT	0
332199	321356	98018T	PARTICIPANT	\N	PRESENT	0
332200	321358	11070L	PARTICIPANT	\N	PRESENT	0
332201	321358	11048N	PARTICIPANT	\N	PRESENT	0
332202	321358	11053K	PARTICIPANT	\N	PRESENT	0
332203	321358	14225N	PARTICIPANT	\N	PRESENT	0
332204	321358	14207L	PARTICIPANT	\N	PRESENT	0
332205	321358	19525U	PARTICIPANT	\N	PRESENT	0
332206	321358	19333N	PARTICIPANT	\N	PRESENT	0
332207	321358	80013X	PARTICIPANT	\N	PRESENT	0
332208	321358	19549D	PARTICIPANT	\N	PRESENT	0
332209	321358	19599P	PARTICIPANT	\N	PRESENT	0
332210	321358	19503N	PARTICIPANT	\N	PRESENT	0
332211	321358	19347U	PARTICIPANT	\N	PRESENT	0
332212	321358	19349W	PARTICIPANT	\N	PRESENT	0
332213	321358	19637C	PARTICIPANT	\N	PRESENT	0
332214	321358	19681G	PARTICIPANT	\N	PRESENT	0
332215	321358	14093U	PARTICIPANT	\N	PRESENT	0
332216	321358	19319Q	PARTICIPANT	\N	PRESENT	0
332217	321358	14219Q	PARTICIPANT	\N	PRESENT	0
332218	321358	08009T	PARTICIPANT	\N	PRESENT	0
332219	321358	14253S	PARTICIPANT	\N	PRESENT	0
332220	321358	19533U	PARTICIPANT	\N	PRESENT	0
332221	321358	14157T	PARTICIPANT	\N	PRESENT	0
332222	321358	18083K	PARTICIPANT	\N	PRESENT	0
332223	321358	19671E	PARTICIPANT	\N	PRESENT	0
332224	321358	14033T	PARTICIPANT	\N	PRESENT	0
332225	321358	19667J	PARTICIPANT	\N	PRESENT	0
332226	321358	14031R	PARTICIPANT	\N	PRESENT	0
332227	321358	19507S	PARTICIPANT	\N	PRESENT	0
332228	321358	11090Q	PARTICIPANT	\N	PRESENT	0
332229	321358	19711U	PARTICIPANT	\N	PRESENT	0
332230	321358	04061F	PARTICIPANT	\N	PRESENT	0
332231	321358	19631V	PARTICIPANT	\N	PRESENT	0
332232	321358	19717B	PARTICIPANT	\N	PRESENT	0
332233	321358	11074Q	PARTICIPANT	\N	PRESENT	0
332234	321358	08044W	PARTICIPANT	\N	PRESENT	0
332235	321358	08051V	PARTICIPANT	\N	PRESENT	0
332236	321358	19629C	PARTICIPANT	\N	PRESENT	0
332237	321358	08024S	PARTICIPANT	\N	PRESENT	0
304363	303956	05008E	PRESIDENT	0	PRESENT	0
304364	303956	19447X	PARTICIPANT	\N	PRESENT	0
304365	303956	14217N	PARTICIPANT	\N	PRESENT	0
304366	303956	11049P	PARTICIPANT	\N	PRESENT	0
304367	303956	04088S	PARTICIPANT	\N	PRESENT	0
304368	303956	01024M	PARTICIPANT	\N	PRESENT	0
304369	303956	14089Y	PARTICIPANT	\N	PRESENT	0
304370	303956	19699S	PARTICIPANT	\N	PRESENT	0
304371	303956	05012A	PARTICIPANT	\N	PRESENT	0
304372	303956	19731Y	PARTICIPANT	\N	PRESENT	0
304373	303956	14257W	PARTICIPANT	\N	PRESENT	0
304374	303956	04085P	PARTICIPANT	\N	PRESENT	0
304375	303956	11048N	PARTICIPANT	\N	PRESENT	0
304376	303956	14061L	PARTICIPANT	\N	PRESENT	0
304377	303956	19703U	PARTICIPANT	\N	PRESENT	0
304378	302500	19697Q	PARTICIPANT	\N	PRESENT	0
304379	302500	11097X	PARTICIPANT	\N	PRESENT	0
304380	302500	08052W	PARTICIPANT	\N	PRESENT	0
304381	302500	14227Q	PARTICIPANT	\N	PRESENT	0
304382	302500	19727D	PARTICIPANT	\N	PRESENT	0
304383	302500	19703U	PARTICIPANT	\N	PRESENT	0
304384	302500	14087W	PARTICIPANT	\N	PRESENT	0
304385	302500	19679N	PARTICIPANT	\N	PRESENT	0
304386	302500	14042U	PARTICIPANT	\N	PRESENT	0
304387	302500	14195A	PARTICIPANT	\N	PRESENT	0
304388	302500	14071N	PARTICIPANT	\N	PRESENT	0
304389	302500	14217N	PARTICIPANT	\N	PRESENT	0
304390	302500	19521Q	PARTICIPANT	\N	PRESENT	0
304391	302500	98024R	PRESIDENT	0	PRESENT	0
304392	302500	19760E	PARTICIPANT	\N	PRESENT	0
304393	302500	11031D	PARTICIPANT	\N	EXCUSE	0
304394	302500	11067R	PARTICIPANT	\N	EXCUSE	0
304395	302500	04092N	PARTICIPANT	\N	EXCUSE	0
304396	302500	19569H	PARTICIPANT	\N	EXCUSE	0
304397	302500	08048B	PARTICIPANT	\N	EXCUSE	0
304398	302500	19715Y	PARTICIPANT	\N	EXCUSE	0
304399	302500	04045F	PARTICIPANT	\N	EXCUSE	0
304400	302500	19335Q	PARTICIPANT	\N	EXCUSE	0
304401	302500	08041T	PARTICIPANT	\N	EXCUSE	0
304402	302500	17779H	PARTICIPANT	\N	EXCUSE	0
304403	302500	14281W	PARTICIPANT	\N	PRESENT	0
304404	302500	11103C	PARTICIPANT	\N	PRESENT	0
304414	303956	19413M	PARTICIPANT	\N	PRESENT	0
304415	303956	08018U	PARTICIPANT	\N	PRESENT	0
304416	299337	14034U	PARTICIPANT	\N	PRESENT	0
304469	303961	19725B	PARTICIPANT	\N	PRESENT	0
304500	289215	19593H	PARTICIPANT	\N	PRESENT	0
304501	289215	08017T	PARTICIPANT	\N	PRESENT	0
304502	289215	08012N	PARTICIPANT	\N	PRESENT	0
304503	289215	04070G	PARTICIPANT	\N	PRESENT	0
304504	289215	11027H	PARTICIPANT	\N	PRESENT	0
304505	289215	14123H	PARTICIPANT	\N	PRESENT	0
304506	289215	95015C	PARTICIPANT	\N	PRESENT	0
304507	289215	97011G	PARTICIPANT	\N	PRESENT	0
304508	289215	14061L	PARTICIPANT	\N	PRESENT	0
304509	289215	14073Q	PARTICIPANT	\N	PRESENT	0
304510	289215	14195A	PARTICIPANT	\N	PRESENT	0
304511	289215	14241N	PARTICIPANT	\N	PRESENT	0
304512	289215	19387D	PARTICIPANT	\N	PRESENT	0
304513	289215	19731Y	PARTICIPANT	\N	PRESENT	0
304514	289215	14261S	PARTICIPANT	\N	PRESENT	0
304515	289215	19699S	PARTICIPANT	\N	PRESENT	0
304516	289215	11083R	PARTICIPANT	\N	PRESENT	0
304517	303961	14179A	PARTICIPANT	\N	PRESENT	0
304518	289215	08031R	PARTICIPANT	\N	PRESENT	0
304519	289215	19735D	PARTICIPANT	\N	PRESENT	0
304520	289215	19441R	PARTICIPANT	\N	PRESENT	0
304521	289215	19697Q	PARTICIPANT	\N	PRESENT	0
304522	289215	19413M	PARTICIPANT	\N	PRESENT	0
304523	289215	08069G	PARTICIPANT	\N	PRESENT	0
304524	289215	14179A	PARTICIPANT	\N	PRESENT	0
304525	289215	08018U	PARTICIPANT	\N	PRESENT	0
304526	289215	14089Y	PARTICIPANT	\N	PRESENT	0
304527	289215	14215L	PARTICIPANT	\N	PRESENT	0
304498	289215	14034U	PARTICIPANT	\N	PRESENT	0
304499	289215	19533U	PARTICIPANT	\N	PRESENT	0
304555	289218	11026G	PARTICIPANT	\N	PRESENT	0
304556	289218	08031R	PARTICIPANT	\N	PRESENT	0
304557	289218	19593H	PARTICIPANT	\N	PRESENT	0
304558	289218	14089Y	PARTICIPANT	\N	PRESENT	0
304559	289218	19731Y	PARTICIPANT	\N	PRESENT	0
304560	289218	97011G	PARTICIPANT	\N	PRESENT	0
304561	289218	08069G	PARTICIPANT	\N	PRESENT	0
304562	289218	19387D	PARTICIPANT	\N	PRESENT	0
304563	289218	08017T	PARTICIPANT	\N	PRESENT	0
304564	289218	19413M	PARTICIPANT	\N	PRESENT	0
304565	289218	14195A	PARTICIPANT	\N	PRESENT	0
304566	289218	19699S	PARTICIPANT	\N	PRESENT	0
304567	289218	14241N	PARTICIPANT	\N	PRESENT	0
304568	289218	14215L	PARTICIPANT	\N	PRESENT	0
304569	289218	14111D	PARTICIPANT	\N	PRESENT	0
304570	289218	14261S	PARTICIPANT	\N	PRESENT	0
304617	295655	11103C	PARTICIPANT	\N	PRESENT	0
304618	295655	11066Q	PARTICIPANT	\N	PRESENT	0
304619	295655	19673G	PARTICIPANT	\N	PRESENT	0
304620	295655	19703U	PARTICIPANT	\N	PRESENT	0
304625	295655	19443T	PARTICIPANT	\N	PRESENT	0
304622	295655	11049P	PARTICIPANT	\N	PRESENT	0
304623	295655	99004R	PARTICIPANT	\N	PRESENT	0
304626	295655	04086Q	PARTICIPANT	\N	PRESENT	0
304627	295655	04018C	PARTICIPANT	\N	PRESENT	0
304553	289218	14034U	PARTICIPANT	\N	PRESENT	0
304554	289218	14179A	PARTICIPANT	\N	PRESENT	0
304628	295655	19593H	PARTICIPANT	\N	PRESENT	0
304629	295655	05008E	PARTICIPANT	\N	PRESENT	0
304631	295655	04061F	PARTICIPANT	\N	PRESENT	0
304632	295655	14073Q	PARTICIPANT	\N	PRESENT	0
304633	295655	04085P	PARTICIPANT	\N	PRESENT	0
304634	295655	08039A	PARTICIPANT	\N	PRESENT	0
304635	295655	97011G	PARTICIPANT	\N	PRESENT	0
304636	295655	19667J	PARTICIPANT	\N	PRESENT	0
304637	295655	19447X	PARTICIPANT	\N	PRESENT	0
304613	295655	11072N	PARTICIPANT	\N	PRESENT	0
304616	295655	19387D	PARTICIPANT	\N	PRESENT	0
304638	295655	19725B	PARTICIPANT	\N	PRESENT	0
304639	295655	01028R	PARTICIPANT	\N	PRESENT	0
304640	295655	19585H	PARTICIPANT	\N	PRESENT	0
304641	295655	19699S	PARTICIPANT	\N	PRESENT	0
304642	295655	11070L	PARTICIPANT	\N	PRESENT	0
304643	295655	14157T	PARTICIPANT	\N	PRESENT	0
304644	295655	14053L	PARTICIPANT	\N	PRESENT	0
304645	295655	95063L	PARTICIPANT	\N	PRESENT	0
304646	295655	08017T	PARTICIPANT	\N	PRESENT	0
304647	295655	11012A	PARTICIPANT	\N	PRESENT	0
304648	295655	19749K	PARTICIPANT	\N	PRESENT	0
304649	295655	19687N	PARTICIPANT	\N	PRESENT	0
304650	295655	19647E	PARTICIPANT	\N	PRESENT	0
304651	295655	19737F	PARTICIPANT	\N	PRESENT	0
304652	295655	14215L	PARTICIPANT	\N	PRESENT	0
304653	295655	19543W	PARTICIPANT	\N	PRESENT	0
304654	295655	14261S	PARTICIPANT	\N	PRESENT	0
304655	295655	11080N	PARTICIPANT	\N	PRESENT	0
304656	295655	08031R	PARTICIPANT	\N	PRESENT	0
304657	295655	14021P	PARTICIPANT	\N	PRESENT	0
304658	295655	14241N	PARTICIPANT	\N	PRESENT	0
304659	295655	19649G	PARTICIPANT	\N	PRESENT	0
304660	295655	14229S	PARTICIPANT	\N	PRESENT	0
304661	295655	14357A	PARTICIPANT	\N	PRESENT	0
304662	295655	19413M	PARTICIPANT	\N	PRESENT	0
304663	295655	11026G	PARTICIPANT	\N	PRESENT	0
304664	295655	11045K	PARTICIPANT	\N	PRESENT	0
304665	295655	11083R	PARTICIPANT	\N	PRESENT	0
304666	295655	04059M	PARTICIPANT	\N	PRESENT	0
304667	295655	07029T	PARTICIPANT	\N	PRESENT	0
304668	295655	04070G	PARTICIPANT	\N	PRESENT	0
304669	295655	14111D	PARTICIPANT	\N	PRESENT	0
304670	295655	11085T	PARTICIPANT	\N	PRESENT	0
304675	295655	04033B	PARTICIPANT	\N	PRESENT	0
304676	295655	08010L	PARTICIPANT	\N	PRESENT	0
322049	321789	19553Y	PARTICIPANT	\N	PRESENT	0
322050	321789	14281W	PARTICIPANT	\N	PRESENT	0
322051	321789	14087W	PARTICIPANT	\N	PRESENT	0
322052	321789	19575F	PARTICIPANT	\N	PRESENT	0
322053	321789	14213J	PARTICIPANT	\N	PRESENT	0
322054	321789	14217N	PARTICIPANT	\N	PRESENT	0
322055	321789	19683J	PARTICIPANT	\N	PRESENT	0
322056	321789	10006L	PARTICIPANT	\N	PRESENT	0
322057	321789	19521Q	PARTICIPANT	\N	PRESENT	0
322058	321789	04092N	PRESIDENT	0	PRESENT	0
322059	321789	08052W	PARTICIPANT	\N	PRESENT	0
322060	321789	19691J	PARTICIPANT	\N	PRESENT	0
322061	321789	19727D	PARTICIPANT	\N	PRESENT	0
322062	321789	14119M	PARTICIPANT	\N	PRESENT	0
322063	321789	11103C	PARTICIPANT	\N	PRESENT	0
322064	321789	19657G	PARTICIPANT	\N	PRESENT	0
322065	321789	14071N	PARTICIPANT	\N	PRESENT	0
322066	321789	19760E	PARTICIPANT	\N	PRESENT	0
322067	321789	11067R	PARTICIPANT	\N	EXCUSE	0
322068	321789	14355X	PARTICIPANT	\N	EXCUSE	0
322069	321789	14042U	PARTICIPANT	\N	EXCUSE	0
322070	321789	14195A	PARTICIPANT	\N	PRESENT	0
322071	321789	19367Y	PARTICIPANT	\N	EXCUSE	0
322072	321789	08041T	PARTICIPANT	\N	EXCUSE	0
322073	321789	19675J	PARTICIPANT	\N	EXCUSE	0
322074	321789	14026U	PARTICIPANT	\N	PRESENT	0
322075	321789	01034P	PARTICIPANT	\N	PRESENT	0
322076	321789	04045F	PARTICIPANT	\N	PRESENT	0
322077	321789	19723Y	PARTICIPANT	\N	PRESENT	0
322079	321789	19577H	PARTICIPANT	\N	PRESENT	0
322080	321789	19679N	PARTICIPANT	\N	PRESENT	0
322081	321789	19663E	PARTICIPANT	\N	PRESENT	0
322088	321790	01034P	PARTICIPANT	\N	PRESENT	0
322089	321790	11067R	PARTICIPANT	\N	PRESENT	0
322090	321790	04092N	PRESIDENT	0	PRESENT	0
322091	321790	19577H	PARTICIPANT	\N	PRESENT	0
322092	321790	14355X	PARTICIPANT	\N	PRESENT	0
322093	321790	19569H	PARTICIPANT	\N	PRESENT	0
322094	321790	11097X	PARTICIPANT	\N	PRESENT	0
322095	321790	11045K	PARTICIPANT	\N	PRESENT	0
322096	321790	08052W	PARTICIPANT	\N	PRESENT	0
322097	321790	19723Y	PARTICIPANT	\N	PRESENT	0
322098	321790	19727D	PARTICIPANT	\N	PRESENT	0
322099	321790	14119M	PARTICIPANT	\N	PRESENT	0
322100	321790	14281W	PARTICIPANT	\N	PRESENT	0
322101	321790	19679N	PARTICIPANT	\N	PRESENT	0
322102	321790	14213J	PARTICIPANT	\N	PRESENT	0
322103	321790	14071N	PARTICIPANT	\N	PRESENT	0
322104	321790	10006L	PARTICIPANT	\N	PRESENT	0
322105	321790	19683J	PARTICIPANT	\N	PRESENT	0
322106	321790	98024R	PARTICIPANT	\N	PRESENT	0
322107	321790	19697Q	PARTICIPANT	\N	PRESENT	0
322108	321790	19715Y	PARTICIPANT	\N	PRESENT	0
322109	321790	14195A	PARTICIPANT	\N	PRESENT	0
322110	321790	19415P	PARTICIPANT	\N	PRESENT	0
322111	314148	04086Q	PARTICIPANT	\N	PRESENT	0
322112	321790	14223L	PARTICIPANT	\N	PRESENT	0
322113	321790	19575F	PARTICIPANT	\N	PRESENT	0
322114	321790	14217N	PARTICIPANT	\N	PRESENT	0
322115	321790	11031D	PARTICIPANT	\N	PRESENT	0
322116	321790	19760E	PARTICIPANT	\N	PRESENT	0
322121	314148	08052W	PARTICIPANT	\N	PRESENT	0
322122	314148	14227Q	PARTICIPANT	\N	PRESENT	0
322123	314148	19683J	PARTICIPANT	\N	PRESENT	0
322124	314148	04085P	PARTICIPANT	\N	PRESENT	0
322125	314148	07034Q	PARTICIPANT	\N	PRESENT	0
322126	314148	19723Y	PARTICIPANT	\N	PRESENT	0
322127	314148	19703U	PARTICIPANT	\N	PRESENT	0
322128	314148	19565D	PARTICIPANT	\N	PRESENT	0
322129	314148	14195A	PARTICIPANT	\N	PRESENT	0
322130	314148	19760E	PARTICIPANT	\N	PRESENT	0
322131	314148	11031D	PARTICIPANT	\N	PRESENT	0
322132	314148	12016W	PARTICIPANT	\N	PRESENT	0
322133	314148	19737F	PARTICIPANT	\N	PRESENT	0
322134	314148	19569H	PARTICIPANT	\N	PRESENT	0
322135	314148	11067R	PARTICIPANT	\N	PRESENT	0
322136	314148	14281W	PARTICIPANT	\N	PRESENT	0
322137	314148	01034P	PARTICIPANT	\N	PRESENT	0
322138	314148	04092N	PARTICIPANT	\N	PRESENT	0
322139	314148	19697Q	PARTICIPANT	\N	PRESENT	0
322140	314148	14213J	PARTICIPANT	\N	PRESENT	0
322141	314148	19443T	PARTICIPANT	\N	PRESENT	0
322142	314148	19575F	PARTICIPANT	\N	PRESENT	0
322143	314148	19415P	PARTICIPANT	\N	PRESENT	0
322144	314148	18083K	PARTICIPANT	\N	PRESENT	0
322145	314148	14223L	PARTICIPANT	\N	PRESENT	0
322146	314148	99004R	PARTICIPANT	\N	PRESENT	0
322147	314148	08047A	PARTICIPANT	\N	PRESENT	0
322148	314148	19333N	PARTICIPANT	\N	PRESENT	0
322149	314148	17779H	PARTICIPANT	\N	PRESENT	0
322150	314148	88008L	PARTICIPANT	\N	PRESENT	0
322151	314148	14239U	PARTICIPANT	\N	PRESENT	0
322152	314148	19553Y	PARTICIPANT	\N	PRESENT	0
322153	314148	95041E	PARTICIPANT	\N	PRESENT	0
322154	314148	19663E	PARTICIPANT	\N	PRESENT	0
322155	314148	08031R	PARTICIPANT	\N	PRESENT	0
322156	314148	19695N	PARTICIPANT	\N	PRESENT	0
322157	314148	19758L	PARTICIPANT	\N	PRESENT	0
322158	314148	19447X	PARTICIPANT	\N	PRESENT	0
322160	314148	08048B	PARTICIPANT	\N	PRESENT	0
322161	314148	14261S	PARTICIPANT	\N	PRESENT	0
322162	314148	14061L	PARTICIPANT	\N	PRESENT	0
322163	314148	98024R	PARTICIPANT	\N	PRESENT	0
322164	314148	95062K	PARTICIPANT	\N	PRESENT	0
322165	314148	19715Y	PARTICIPANT	\N	PRESENT	0
322166	314148	11066Q	PARTICIPANT	\N	PRESENT	0
322167	314148	14119M	PARTICIPANT	\N	PRESENT	0
322168	314148	14026U	PARTICIPANT	\N	PRESENT	0
322169	314148	95030B	PARTICIPANT	\N	PRESENT	0
322170	314148	14219Q	PARTICIPANT	\N	PRESENT	0
322171	314148	19739H	PARTICIPANT	\N	PRESENT	0
322172	314148	19679N	PARTICIPANT	\N	PRESENT	0
322173	314148	19253P	PARTICIPANT	\N	PRESENT	0
322174	314148	14355X	PARTICIPANT	\N	PRESENT	0
322175	314148	14265W	PARTICIPANT	\N	PRESENT	0
322176	314148	97011G	PARTICIPANT	\N	PRESENT	0
322180	314148	14147R	PARTICIPANT	\N	PRESENT	0
322181	314148	19507S	PARTICIPANT	\N	PRESENT	0
322182	314148	08019V	PARTICIPANT	\N	PRESENT	0
322183	314148	11033F	PARTICIPANT	\N	PRESENT	0
322184	314148	19747H	PARTICIPANT	\N	PRESENT	0
322185	314148	19671E	PARTICIPANT	\N	PRESENT	0
322186	314148	14039A	PARTICIPANT	\N	PRESENT	0
322187	314148	19599P	PARTICIPANT	\N	PRESENT	0
322188	314148	04018C	PARTICIPANT	\N	PRESENT	0
322189	314148	19762G	PARTICIPANT	\N	PRESENT	0
322190	314148	08073C	PARTICIPANT	\N	PRESENT	0
322192	314148	14069U	PARTICIPANT	\N	PRESENT	0
322193	314148	19591F	PARTICIPANT	\N	PRESENT	0
322195	314148	11045K	PARTICIPANT	\N	PRESENT	0
322196	314148	19527W	PARTICIPANT	\N	PRESENT	0
322197	314148	08056B	PARTICIPANT	\N	PRESENT	0
322198	314148	19329S	PARTICIPANT	\N	PRESENT	0
322199	314148	04045F	PARTICIPANT	\N	PRESENT	0
322200	314148	19733B	PARTICIPANT	\N	PRESENT	0
322201	314148	14123H	PARTICIPANT	\N	PRESENT	0
322202	314148	11077T	PARTICIPANT	\N	PRESENT	0
322203	314148	14021P	PARTICIPANT	\N	PRESENT	0
322204	314148	11103C	PARTICIPANT	\N	PRESENT	0
322205	314148	14073Q	PARTICIPANT	\N	PRESENT	0
322206	314148	19577H	PARTICIPANT	\N	PRESENT	0
322207	314148	11085T	PARTICIPANT	\N	PRESENT	0
322208	314148	14267Y	PARTICIPANT	\N	PRESENT	0
322209	314148	14105F	PARTICIPANT	\N	PRESENT	0
322210	314148	19657G	PARTICIPANT	\N	PRESENT	0
322211	314148	14029X	PARTICIPANT	\N	PRESENT	0
322212	314148	08024S	PARTICIPANT	\N	PRESENT	0
322215	314148	98023Q	PARTICIPANT	\N	PRESENT	0
322216	314148	04034C	PARTICIPANT	\N	PRESENT	0
322217	314148	11041F	PARTICIPANT	\N	PRESENT	0
322218	314148	19669L	PARTICIPANT	\N	PRESENT	0
322219	314148	11040E	PARTICIPANT	\N	PRESENT	0
322220	314148	14030Q	PARTICIPANT	\N	PRESENT	0
322221	314148	14051J	PARTICIPANT	\N	PRESENT	0
322222	314148	19525U	PARTICIPANT	\N	PRESENT	0
322223	314148	14038Y	PARTICIPANT	\N	PRESENT	0
322224	314148	19369B	PARTICIPANT	\N	PRESENT	0
322225	314148	11097X	PARTICIPANT	\N	PRESENT	0
322226	314148	19713W	PARTICIPANT	\N	PRESENT	0
322227	314148	14087W	PARTICIPANT	\N	PRESENT	0
322228	314148	11054L	PARTICIPANT	\N	PRESENT	0
322229	314148	19727D	PARTICIPANT	\N	PRESENT	0
322230	314148	17589D	PARTICIPANT	\N	PRESENT	0
322231	314148	14107H	PARTICIPANT	\N	PRESENT	0
322232	314148	14217N	PARTICIPANT	\N	PRESENT	0
322233	314148	19681G	PARTICIPANT	\N	PRESENT	0
306829	305921	95063L	PARTICIPANT	\N	PRESENT	0
306830	305921	19629C	PARTICIPANT	\N	PRESENT	0
306831	306010	17583W	PARTICIPANT	\N	PRESENT	0
306832	306010	14217N	PARTICIPANT	\N	PRESENT	0
306833	306010	08049C	PARTICIPANT	\N	PRESENT	0
306834	306010	14251Q	PARTICIPANT	\N	PRESENT	0
306835	306010	14265W	PARTICIPANT	\N	PRESENT	0
306836	306010	14105F	PARTICIPANT	\N	PRESENT	0
306837	306010	14031R	PARTICIPANT	\N	PRESENT	0
306838	306010	19689Q	PARTICIPANT	\N	PRESENT	0
307018	305981	19575F	PARTICIPANT	\N	PRESENT	0
307019	305981	11031D	PARTICIPANT	\N	PRESENT	0
307020	305981	98024R	PARTICIPANT	\N	PRESENT	0
307021	305981	19727D	PARTICIPANT	\N	PRESENT	0
307022	305981	14213J	PARTICIPANT	\N	PRESENT	0
307023	305981	19683J	PARTICIPANT	\N	PRESENT	0
307024	305981	04061F	PARTICIPANT	\N	PRESENT	0
307025	305981	04045F	PARTICIPANT	\N	PRESENT	0
307026	305981	19421M	PARTICIPANT	\N	PRESENT	0
307027	305981	19713W	PARTICIPANT	\N	PRESENT	0
309392	309391	14329V	PARTICIPANT	\N	PRESENT	0
309393	309391	14033T	PARTICIPANT	\N	PRESENT	0
309394	309391	08015R	PARTICIPANT	\N	PRESENT	0
309395	309391	14257W	PARTICIPANT	\N	PRESENT	0
309396	309391	11090Q	PARTICIPANT	\N	PRESENT	0
309397	309391	04043D	PARTICIPANT	\N	PRESENT	0
310604	305977	01048V	PRESIDENT	0	PRESENT	0
311800	311799	01048V	PARTICIPANT	\N	PRESENT	0
318819	309292	14207L	PARTICIPANT	\N	PRESENT	0
312546	312545	11053K	PARTICIPANT	\N	PRESENT	0
312547	312545	14159V	PARTICIPANT	\N	PRESENT	0
312548	312545	05012A	PARTICIPANT	\N	PRESENT	0
312564	312559	14169X	PARTICIPANT	\N	PRESENT	0
312565	312560	14169X	PARTICIPANT	\N	PRESENT	0
312566	312561	14169X	PARTICIPANT	\N	PRESENT	0
312568	312562	14169X	PARTICIPANT	\N	PRESENT	0
314228	314227	14039A	PARTICIPANT	\N	PRESENT	0
314229	314227	19593H	PARTICIPANT	\N	PRESENT	0
314231	314230	14039A	PARTICIPANT	\N	PRESENT	0
314232	314230	19593H	PARTICIPANT	\N	PRESENT	0
314234	314233	14039A	PARTICIPANT	\N	PRESENT	0
314235	314233	19593H	PARTICIPANT	\N	PRESENT	0
314237	314236	08031R	PARTICIPANT	\N	PRESENT	0
314238	314236	14229S	PARTICIPANT	\N	PRESENT	0
314240	314239	08031R	PARTICIPANT	\N	PRESENT	0
314241	314239	08039A	PARTICIPANT	\N	PRESENT	0
314243	314242	08031R	PARTICIPANT	\N	PRESENT	0
314244	314242	08039A	PARTICIPANT	\N	PRESENT	0
314246	314245	14123H	PARTICIPANT	\N	PRESENT	0
314247	314245	19611R	PARTICIPANT	\N	PRESENT	0
314249	314248	14123H	PARTICIPANT	\N	PRESENT	0
314250	314248	19611R	PARTICIPANT	\N	PRESENT	0
314252	314251	14123H	PARTICIPANT	\N	PRESENT	0
314254	314253	14123H	PARTICIPANT	\N	PRESENT	0
314256	314255	14123H	PARTICIPANT	\N	PRESENT	0
314304	314303	14205J	PARTICIPANT	\N	PRESENT	0
314306	314305	14219Q	PARTICIPANT	\N	PRESENT	0
318818	309292	14073Q	PARTICIPANT	\N	PRESENT	0
318821	309292	19695N	PARTICIPANT	\N	PRESENT	0
318822	309292	11040E	PARTICIPANT	\N	PRESENT	0
318823	309292	19479G	PARTICIPANT	\N	PRESENT	0
318824	309292	14030Q	PARTICIPANT	\N	PRESENT	0
318825	309292	08056B	PARTICIPANT	\N	PRESENT	0
318826	309292	14079W	PARTICIPANT	\N	PRESENT	0
318827	309292	19731Y	PARTICIPANT	\N	PRESENT	0
318828	309292	19701S	PARTICIPANT	\N	PRESENT	0
318829	309292	19711U	PARTICIPANT	\N	PRESENT	0
318830	309292	14069U	PARTICIPANT	\N	PRESENT	0
318831	309292	14265W	PARTICIPANT	\N	PRESENT	0
318832	309292	19399H	PARTICIPANT	\N	PRESENT	0
318833	309292	14115H	PARTICIPANT	\N	PRESENT	0
318834	309292	14157T	PARTICIPANT	\N	PRESENT	0
318835	309292	14033T	PARTICIPANT	\N	PRESENT	0
318837	309292	04088S	PARTICIPANT	\N	PRESENT	0
318839	309292	19747H	PARTICIPANT	\N	PRESENT	0
318840	309292	19723Y	PARTICIPANT	\N	PRESENT	0
318841	309292	19467C	PARTICIPANT	\N	PRESENT	0
318842	309292	19515S	PARTICIPANT	\N	PRESENT	0
318843	309292	08039A	PARTICIPANT	\N	PRESENT	0
318844	309292	04097T	PARTICIPANT	\N	PRESENT	0
318845	309292	19717B	PARTICIPANT	\N	PRESENT	0
318846	309292	95062K	PARTICIPANT	\N	PRESENT	0
318847	309292	95030B	PARTICIPANT	\N	PRESENT	0
318849	309292	14329V	PARTICIPANT	\N	PRESENT	0
318850	309292	19383Y	PARTICIPANT	\N	PRESENT	0
318851	309292	97011G	PARTICIPANT	\N	PRESENT	0
318854	309292	19762G	PARTICIPANT	\N	PRESENT	0
318855	309292	96004D	PARTICIPANT	\N	PRESENT	0
318856	309292	04049K	PARTICIPANT	\N	PRESENT	0
318857	309292	11043H	PARTICIPANT	\N	PRESENT	0
318860	309292	19683J	PARTICIPANT	\N	PRESENT	0
318861	309292	19593H	PARTICIPANT	\N	PRESENT	0
318862	309292	08019V	PARTICIPANT	\N	PRESENT	0
318866	309292	14105F	PARTICIPANT	\N	PRESENT	0
318869	309292	19667J	PARTICIPANT	\N	PRESENT	0
318870	309292	01024M	PARTICIPANT	\N	PRESENT	0
318871	309292	19521Q	PARTICIPANT	\N	PRESENT	0
318872	309292	14135M	PARTICIPANT	\N	PRESENT	0
318873	309292	14357A	PARTICIPANT	\N	PRESENT	0
318874	309292	19760E	PARTICIPANT	\N	PRESENT	0
318875	309292	08020N	PARTICIPANT	\N	PRESENT	0
318876	309292	19549D	PARTICIPANT	\N	PRESENT	0
318877	309292	19727D	PARTICIPANT	\N	PRESENT	0
318878	309292	19741B	PARTICIPANT	\N	PRESENT	0
318880	309292	19507S	PARTICIPANT	\N	PRESENT	0
318881	309292	19503N	PARTICIPANT	\N	PRESENT	0
318882	309292	11085T	PARTICIPANT	\N	PRESENT	0
318885	309292	18083K	PARTICIPANT	\N	PRESENT	0
318886	309292	14213J	PARTICIPANT	\N	PRESENT	0
318952	309293	11077T	PARTICIPANT	\N	PRESENT	0
318953	309293	19760E	PARTICIPANT	\N	PRESENT	0
318954	309293	14071N	PARTICIPANT	\N	PRESENT	0
318955	309293	19681G	PARTICIPANT	\N	PRESENT	0
318956	309293	19717B	PARTICIPANT	\N	PRESENT	0
318957	309293	19593H	PARTICIPANT	\N	PRESENT	0
318958	309293	19727D	PARTICIPANT	\N	PRESENT	0
318959	309293	19683J	PARTICIPANT	\N	PRESENT	0
318960	309293	19527W	PARTICIPANT	\N	PRESENT	0
318961	309293	19349W	PARTICIPANT	\N	PRESENT	0
318962	309293	01024M	PARTICIPANT	\N	PRESENT	0
318963	309293	19747H	PARTICIPANT	\N	PRESENT	0
318964	309293	11043H	PARTICIPANT	\N	PRESENT	0
318965	309293	11097X	PARTICIPANT	\N	PRESENT	0
318966	309293	19741B	PARTICIPANT	\N	PRESENT	0
318967	309293	18083K	PARTICIPANT	\N	PRESENT	0
318968	309293	19667J	PARTICIPANT	\N	PRESENT	0
318969	309293	14135M	PARTICIPANT	\N	PRESENT	0
318970	309293	04088S	PARTICIPANT	\N	PRESENT	0
318971	309293	14213J	PARTICIPANT	\N	PRESENT	0
318972	309293	97011G	PARTICIPANT	\N	PRESENT	0
318973	309293	19711U	PARTICIPANT	\N	PRESENT	0
318974	309293	14357A	PARTICIPANT	\N	PRESENT	0
318975	309293	19383Y	PARTICIPANT	\N	PRESENT	0
318976	309293	07029T	PARTICIPANT	\N	PRESENT	0
318977	309293	04092N	PARTICIPANT	\N	PRESENT	0
318978	309293	14051J	PARTICIPANT	\N	PRESENT	0
318979	309293	04085P	PARTICIPANT	\N	PRESENT	0
318980	309293	14195A	PARTICIPANT	\N	PRESENT	0
318981	309293	14249W	PARTICIPANT	\N	PRESENT	0
318982	309293	19521Q	PARTICIPANT	\N	PRESENT	0
318983	309293	19691J	PARTICIPANT	\N	PRESENT	0
318984	309293	14030Q	PARTICIPANT	\N	PRESENT	0
318985	309293	14217N	PARTICIPANT	\N	PRESENT	0
318986	309293	11027H	PARTICIPANT	\N	PRESENT	0
318987	309293	19467C	PARTICIPANT	\N	PRESENT	0
318993	309293	19553Y	PARTICIPANT	\N	PRESENT	0
318995	309293	14109K	PARTICIPANT	\N	PRESENT	0
318999	316534	14327T	PARTICIPANT	\N	PRESENT	0
319000	316534	11048N	PARTICIPANT	\N	PRESENT	0
319002	316534	19711U	PARTICIPANT	\N	PRESENT	0
319004	316534	01048V	PARTICIPANT	\N	PRESENT	0
319005	316534	08034U	PARTICIPANT	\N	PRESENT	0
319008	316534	11053K	PARTICIPANT	\N	PRESENT	0
319010	316534	08011M	PARTICIPANT	\N	PRESENT	0
319012	316534	89017R	PARTICIPANT	\N	PRESENT	0
319014	316534	11074Q	PRESIDENT	0	PRESENT	0
319016	316534	19671E	PARTICIPANT	\N	PRESENT	0
319017	316534	14225N	PARTICIPANT	\N	PRESENT	0
319020	316534	07029T	PARTICIPANT	\N	PRESENT	0
319022	316534	19741B	PARTICIPANT	\N	PRESENT	0
319024	316534	99004R	PARTICIPANT	\N	PRESENT	0
319026	316534	07004J	PARTICIPANT	\N	EXCUSE	0
319028	316534	08014Q	PARTICIPANT	\N	EXCUSE	0
319030	316534	14034U	PARTICIPANT	\N	EXCUSE	0
319566	317557	19583F	PARTICIPANT	\N	EXCUSE	0
319567	317557	96004D	PARTICIPANT	\N	EXCUSE	0
319568	317557	11054L	PARTICIPANT	\N	EXCUSE	0
319569	317557	14135M	PARTICIPANT	\N	EXCUSE	0
319573	305885	19647E	PARTICIPANT	\N	EXCUSE	0
317516	317515	14205J	PARTICIPANT	\N	PRESENT	0
317518	317517	04049K	PARTICIPANT	\N	PRESENT	0
317520	317519	08068F	PARTICIPANT	\N	PRESENT	0
317522	317521	08068F	PARTICIPANT	\N	PRESENT	0
317524	317523	08068F	PARTICIPANT	\N	PRESENT	0
317536	317535	11104D	PARTICIPANT	\N	PRESENT	0
317538	317537	14123H	PARTICIPANT	\N	PRESENT	0
329628	321345	01024M	PARTICIPANT	\N	PRESENT	0
329629	321345	14327T	PARTICIPANT	\N	PRESENT	0
329630	321345	01043Q	PARTICIPANT	\N	PRESENT	0
329631	321345	11048N	PARTICIPANT	\N	PRESENT	0
329632	321345	08048B	PARTICIPANT	\N	PRESENT	0
329633	321345	08031R	PARTICIPANT	\N	PRESENT	0
329634	321345	19551W	PARTICIPANT	\N	PRESENT	0
329636	321345	19647E	PARTICIPANT	\N	PRESENT	0
329642	321345	19619A	PARTICIPANT	\N	PRESENT	0
329638	321345	05008E	PARTICIPANT	\N	PRESENT	0
329641	321345	19643A	PARTICIPANT	\N	PRESENT	0
329953	321343	04059M	PARTICIPANT	\N	PRESENT	0
329954	321343	08011M	PARTICIPANT	\N	PRESENT	0
329955	321343	11074Q	PARTICIPANT	\N	PRESENT	0
329956	321343	19533U	PARTICIPANT	\N	PRESENT	0
330534	328614	19383Y	PARTICIPANT	\N	PRESENT	0
329958	321343	14029X	PARTICIPANT	\N	PRESENT	0
329959	321343	19507S	PARTICIPANT	\N	PRESENT	0
329960	321343	07029T	PARTICIPANT	\N	PRESENT	0
329961	321343	19768N	PARTICIPANT	\N	PRESENT	0
329962	321343	14265W	PARTICIPANT	\N	PRESENT	0
329963	321343	19693L	PARTICIPANT	\N	PRESENT	0
329964	321343	11043H	PARTICIPANT	\N	PRESENT	0
329965	321343	19711U	PARTICIPANT	\N	PRESENT	0
329966	321343	19447X	PARTICIPANT	\N	PRESENT	0
329967	321343	95030B	PARTICIPANT	\N	PRESENT	0
329968	321343	19295A	PARTICIPANT	\N	PRESENT	0
329969	321343	04043D	PARTICIPANT	\N	PRESENT	0
329970	321343	11109J	PARTICIPANT	\N	PRESENT	0
329971	321343	11067R	PARTICIPANT	\N	PRESENT	0
329972	321343	95067Q	PARTICIPANT	\N	PRESENT	0
329973	321343	14121F	PARTICIPANT	\N	PRESENT	0
329974	321343	14331P	PARTICIPANT	\N	PRESENT	0
329975	321343	14229S	PARTICIPANT	\N	PRESENT	0
329976	321343	80013X	PARTICIPANT	\N	PRESENT	0
329977	321343	19581D	PARTICIPANT	\N	PRESENT	0
329978	321343	08055A	PARTICIPANT	\N	PRESENT	0
329979	321343	87003B	PARTICIPANT	\N	PRESENT	0
329980	321343	08060W	PARTICIPANT	\N	PRESENT	0
329981	321343	19443T	PARTICIPANT	\N	PRESENT	0
329982	321343	14081Q	PARTICIPANT	\N	PRESENT	0
329983	321343	04034C	PARTICIPANT	\N	PRESENT	0
329984	321343	19543W	PARTICIPANT	\N	PRESENT	0
329985	321343	04086Q	PARTICIPANT	\N	PRESENT	0
329986	321343	14107H	PARTICIPANT	\N	PRESENT	0
329987	321343	14241N	PARTICIPANT	\N	PRESENT	0
329988	325451	19697Q	PARTICIPANT	\N	PRESENT	0
329989	325451	04092N	PRESIDENT	0	PRESENT	0
329990	325451	08052W	PARTICIPANT	\N	PRESENT	0
329991	325451	19717B	PARTICIPANT	\N	PRESENT	0
329992	325451	04045F	PARTICIPANT	\N	PRESENT	0
329993	325451	19723Y	PARTICIPANT	\N	PRESENT	0
329994	325451	19703U	PARTICIPANT	\N	PRESENT	0
329995	325451	19727D	PARTICIPANT	\N	PRESENT	0
329996	325451	14087W	PARTICIPANT	\N	PRESENT	0
329997	325451	19679N	PARTICIPANT	\N	PRESENT	0
329998	325451	19575F	PARTICIPANT	\N	PRESENT	0
329999	325451	19367Y	PARTICIPANT	\N	PRESENT	0
330000	325451	19760E	PARTICIPANT	\N	PRESENT	0
330001	325451	14355X	PARTICIPANT	\N	EXCUSE	0
330002	325451	08041T	PARTICIPANT	\N	EXCUSE	0
330003	321343	19545Y	PARTICIPANT	\N	PRESENT	0
330004	321343	17589D	PARTICIPANT	\N	PRESENT	0
330005	321343	01025N	PARTICIPANT	\N	PRESENT	0
330006	321343	19691J	PARTICIPANT	\N	PRESENT	0
330007	321343	01024M	PARTICIPANT	\N	PRESENT	0
330008	321343	14215L	PARTICIPANT	\N	PRESENT	0
330535	328614	19333N	PARTICIPANT	\N	PRESENT	0
330536	328614	17583W	PARTICIPANT	\N	PRESENT	0
330537	328614	19701S	PARTICIPANT	\N	PRESENT	0
330538	328614	19549D	PARTICIPANT	\N	PRESENT	0
330539	328614	14219Q	PARTICIPANT	\N	PRESENT	0
330395	328614	08055A	PARTICIPANT	\N	PRESENT	0
330540	328614	19599P	PARTICIPANT	\N	PRESENT	0
330541	328614	19637C	PARTICIPANT	\N	PRESENT	0
330542	328614	02002K	PARTICIPANT	\N	PRESENT	0
330543	328614	18083K	PARTICIPANT	\N	PRESENT	0
330400	328614	15447F	PARTICIPANT	\N	PRESENT	0
330544	328614	05012A	PARTICIPANT	\N	PRESENT	0
330545	328614	80027E	PARTICIPANT	\N	PRESENT	0
330403	328614	08060W	PARTICIPANT	\N	PRESENT	0
330546	328614	14051J	PARTICIPANT	\N	PRESENT	0
330547	328614	19503N	PARTICIPANT	\N	PRESENT	0
330548	328614	19347U	PARTICIPANT	\N	PRESENT	0
330407	328614	19681G	PARTICIPANT	\N	PRESENT	0
330549	328614	08024S	PARTICIPANT	\N	PRESENT	0
330550	328614	98023Q	PARTICIPANT	\N	PRESENT	0
330551	328614	17637T	PARTICIPANT	\N	PRESENT	0
330552	328614	19525U	PARTICIPANT	\N	PRESENT	0
330413	328614	14237S	PARTICIPANT	\N	PRESENT	0
330414	328614	19737F	PARTICIPANT	\N	PRESENT	0
330553	328614	14038Y	PARTICIPANT	\N	PRESENT	0
330554	328614	14031R	PARTICIPANT	\N	PRESENT	0
330417	328229	14079W	PARTICIPANT	\N	PRESENT	0
330418	328229	16685X	PARTICIPANT	\N	PRESENT	0
330419	328229	11027H	PARTICIPANT	\N	PRESENT	0
330420	328229	11054L	PARTICIPANT	\N	PRESENT	0
330421	328229	19669L	PARTICIPANT	\N	PRESENT	0
330422	328229	95037J	PARTICIPANT	\N	PRESENT	0
330423	328229	08053X	PARTICIPANT	\N	PRESENT	0
330424	328229	08061X	PARTICIPANT	\N	PRESENT	0
330425	328229	04035D	PARTICIPANT	\N	PRESENT	0
330426	328229	08058D	PARTICIPANT	\N	PRESENT	0
330427	328229	01058X	PARTICIPANT	\N	PRESENT	0
330428	328229	14255U	PARTICIPANT	\N	PRESENT	0
330555	328614	19713W	PARTICIPANT	\N	PRESENT	0
330430	328229	14055N	PARTICIPANT	\N	PRESENT	0
330556	328614	14169X	PARTICIPANT	\N	PRESENT	0
330557	328614	04085P	PARTICIPANT	\N	PRESENT	0
330558	328614	14093U	PARTICIPANT	\N	PRESENT	0
330559	328614	08009T	PRESIDENT	0	PRESENT	0
330435	328229	95067Q	PARTICIPANT	\N	PRESENT	0
330560	328614	04097T	PARTICIPANT	\N	PRESENT	0
330478	328229	11064N	PARTICIPANT	\N	PRESENT	0
330481	330074	19766L	PARTICIPANT	\N	PRESENT	0
330482	330074	04070G	PRESIDENT	0	PRESENT	0
330483	330074	19699S	PARTICIPANT	\N	PRESENT	0
330484	330074	19533U	PARTICIPANT	\N	PRESENT	0
330485	330074	14229S	PARTICIPANT	\N	PRESENT	0
330486	330074	14241N	PARTICIPANT	\N	PRESENT	0
330487	330074	14107H	PARTICIPANT	\N	PRESENT	0
330488	330074	08017T	PARTICIPANT	\N	PRESENT	0
330489	330074	92040Q	PARTICIPANT	\N	PRESENT	0
330490	330074	07033P	PARTICIPANT	\N	PRESENT	0
330491	330074	08012N	PARTICIPANT	\N	PRESENT	0
330492	330074	19335Q	PARTICIPANT	\N	PRESENT	0
330493	330074	14249W	PARTICIPANT	\N	PRESENT	0
330494	330074	08031R	PARTICIPANT	\N	PRESENT	0
330495	330074	19593H	PARTICIPANT	\N	PRESENT	0
330496	330074	14059S	PARTICIPANT	\N	PRESENT	0
330497	330074	19643A	PARTICIPANT	\N	PRESENT	0
330498	330074	14061L	PARTICIPANT	\N	PRESENT	0
330499	330074	04057K	PARTICIPANT	\N	PRESENT	0
330500	330074	14073Q	PARTICIPANT	\N	PRESENT	0
330501	330074	19611R	PARTICIPANT	\N	PRESENT	0
330502	330074	08043V	PARTICIPANT	\N	PRESENT	0
330503	330074	19693L	PARTICIPANT	\N	PRESENT	0
330504	330074	19399H	PARTICIPANT	\N	PRESENT	0
330505	330074	87003B	PARTICIPANT	\N	PRESENT	0
330506	330074	14030Q	PARTICIPANT	\N	PRESENT	0
330507	330074	19731Y	PARTICIPANT	\N	PRESENT	0
330508	330074	14251Q	PARTICIPANT	\N	PRESENT	0
330509	330074	08020N	PARTICIPANT	\N	PRESENT	0
330510	330074	04059M	PARTICIPANT	\N	PRESENT	0
330511	330074	19735D	PARTICIPANT	\N	PRESENT	0
330512	330074	11109J	PARTICIPANT	\N	PRESENT	0
330513	330074	14109K	PARTICIPANT	\N	PRESENT	0
330514	330074	14063N	PARTICIPANT	\N	PRESENT	0
330515	330074	11083R	PARTICIPANT	\N	PRESENT	0
330516	330074	14123H	PARTICIPANT	\N	PRESENT	0
330517	330074	11104D	PARTICIPANT	\N	PRESENT	0
330518	330074	11043H	PARTICIPANT	\N	PRESENT	0
330519	330074	19749K	PARTICIPANT	\N	PRESENT	0
330520	330074	04018C	PARTICIPANT	\N	PRESENT	0
330521	330074	19758L	PARTICIPANT	\N	PRESENT	0
330522	330074	19621T	PARTICIPANT	\N	PRESENT	0
330523	330074	04033B	PARTICIPANT	\N	EXCUSE	0
330524	330074	14201E	PARTICIPANT	\N	EXCUSE	0
330525	330074	08039A	PARTICIPANT	\N	EXCUSE	0
330561	328614	19739H	PARTICIPANT	\N	PRESENT	0
330532	328614	14029X	PARTICIPANT	\N	PRESENT	0
330533	328614	19387D	PARTICIPANT	\N	PRESENT	0
304733	295658	01028R	PARTICIPANT	\N	PRESENT	0
304734	295658	14229S	PARTICIPANT	\N	PRESENT	0
304735	295658	19725B	PARTICIPANT	\N	PRESENT	0
304736	295658	04070G	PARTICIPANT	\N	PRESENT	0
304737	295658	08018U	PARTICIPANT	\N	PRESENT	0
304738	295658	04085P	PARTICIPANT	\N	PRESENT	0
304739	295658	19593H	PARTICIPANT	\N	PRESENT	0
304740	295658	19649G	PARTICIPANT	\N	PRESENT	0
304741	295658	14241N	PARTICIPANT	\N	PRESENT	0
304742	295658	08031R	PARTICIPANT	\N	PRESENT	0
304743	295658	14111D	PARTICIPANT	\N	PRESENT	0
304744	295658	19699S	PARTICIPANT	\N	PRESENT	0
304745	295658	19737F	PARTICIPANT	\N	PRESENT	0
304746	295658	11026G	PARTICIPANT	\N	PRESENT	0
304747	295658	11083R	PARTICIPANT	\N	PRESENT	0
304748	295658	14215L	PARTICIPANT	\N	PRESENT	0
304749	295658	19747H	PARTICIPANT	\N	PRESENT	0
304750	295658	04018C	PARTICIPANT	\N	PRESENT	0
304751	295658	14053L	PARTICIPANT	\N	PRESENT	0
304752	295658	19447X	PARTICIPANT	\N	PRESENT	0
304753	295658	04033B	PARTICIPANT	\N	PRESENT	0
304754	295658	08010L	PARTICIPANT	\N	PRESENT	0
304755	295658	97011G	PARTICIPANT	\N	PRESENT	0
304756	295658	14357A	PARTICIPANT	\N	PRESENT	0
304757	295658	07029T	PARTICIPANT	\N	PRESENT	0
304758	295658	14157T	PARTICIPANT	\N	PRESENT	0
304759	295658	19667J	PARTICIPANT	\N	PRESENT	0
304760	295658	19673G	PARTICIPANT	\N	PRESENT	0
304761	295658	19703U	PARTICIPANT	\N	PRESENT	0
304762	295658	19573D	PARTICIPANT	\N	PRESENT	0
304763	295658	08039A	PARTICIPANT	\N	PRESENT	0
304764	295658	19543W	PARTICIPANT	\N	PRESENT	0
304765	295658	11070L	PARTICIPANT	\N	PRESENT	0
304766	295658	14069U	PARTICIPANT	\N	PRESENT	0
304731	295658	11072N	PARTICIPANT	\N	PRESENT	0
304732	295658	04059M	PARTICIPANT	\N	PRESENT	0
304767	295658	14257W	PARTICIPANT	\N	PRESENT	0
304768	295658	08017T	PARTICIPANT	\N	PRESENT	0
304769	295658	11049P	PARTICIPANT	\N	PRESENT	0
304770	295658	11053K	PARTICIPANT	\N	PRESENT	0
304771	295658	19749K	PARTICIPANT	\N	PRESENT	0
304772	295658	19647E	PARTICIPANT	\N	PRESENT	0
304773	295658	05008E	PARTICIPANT	\N	PRESENT	0
304775	295658	01024M	PARTICIPANT	\N	PRESENT	0
304776	295658	14255U	PARTICIPANT	\N	PRESENT	0
304778	295658	14251Q	PARTICIPANT	\N	PRESENT	0
304779	295658	14021P	PARTICIPANT	\N	PRESENT	0
304808	295660	04086Q	PARTICIPANT	\N	PRESENT	0
304809	295660	05008E	PARTICIPANT	\N	PRESENT	0
304810	295660	14069U	PARTICIPANT	\N	PRESENT	0
304811	295660	19593H	PARTICIPANT	\N	PRESENT	0
304812	295660	19347U	PARTICIPANT	\N	PRESENT	0
304813	295660	19725B	PARTICIPANT	\N	PRESENT	0
304814	295660	08031R	PARTICIPANT	\N	PRESENT	0
304815	295660	19749K	PARTICIPANT	\N	PRESENT	0
304816	295660	01024M	PARTICIPANT	\N	PRESENT	0
304817	295660	19447X	PARTICIPANT	\N	PRESENT	0
304818	295660	07029T	PARTICIPANT	\N	PRESENT	0
304819	295660	19543W	PARTICIPANT	\N	PRESENT	0
304820	295660	19747H	PARTICIPANT	\N	PRESENT	0
304821	295660	14327T	PARTICIPANT	\N	PRESENT	0
304822	295660	14215L	PARTICIPANT	\N	PRESENT	0
304823	295660	01028R	PARTICIPANT	\N	PRESENT	0
304824	295660	14034U	PARTICIPANT	\N	PRESENT	0
304825	295660	11053K	PARTICIPANT	\N	PRESENT	0
304826	295660	14021P	PARTICIPANT	\N	PRESENT	0
304890	304774	11048N	PARTICIPANT	\N	PRESENT	0
304891	289219	04044E	PARTICIPANT	\N	PRESENT	0
304892	304774	14357A	PARTICIPANT	\N	PRESENT	0
304893	304774	19489J	PARTICIPANT	\N	PRESENT	0
304906	289219	19521Q	PARTICIPANT	\N	PRESENT	0
304907	304777	14065Q	PARTICIPANT	\N	PRESENT	0
304908	304777	19719D	PARTICIPANT	\N	EXCUSE	0
304909	289219	19335Q	PARTICIPANT	\N	PRESENT	0
304910	289219	19727D	PARTICIPANT	\N	PRESENT	0
304911	289219	19667J	PARTICIPANT	\N	PRESENT	0
304912	289219	19575F	PARTICIPANT	\N	PRESENT	0
304913	289219	14071N	PARTICIPANT	\N	PRESENT	0
304914	289219	19679N	PARTICIPANT	\N	PRESENT	0
304915	289219	19349W	PARTICIPANT	\N	PRESENT	0
304916	289219	98024R	PARTICIPANT	\N	PRESENT	0
304917	289219	19687N	PARTICIPANT	\N	PRESENT	0
304918	289219	19531S	PARTICIPANT	\N	PRESENT	0
304919	289219	19689Q	PARTICIPANT	\N	PRESENT	0
304920	289219	08017T	PARTICIPANT	\N	PRESENT	0
304921	289219	14033T	PARTICIPANT	\N	PRESENT	0
304922	304777	14357A	PARTICIPANT	\N	PRESENT	0
304923	304777	11027H	PARTICIPANT	\N	PRESENT	0
304924	304777	04042C	PARTICIPANT	\N	PRESENT	0
304925	304777	19581D	PARTICIPANT	\N	PRESENT	0
304926	304777	19671E	PARTICIPANT	\N	PRESENT	0
304927	304777	14229S	PARTICIPANT	\N	PRESENT	0
304928	304777	01028R	PARTICIPANT	\N	PRESENT	0
304929	304777	05008E	PRESIDENT	0	PRESENT	0
304930	304777	19447X	PARTICIPANT	\N	PRESENT	0
304931	304777	14237S	PARTICIPANT	\N	PRESENT	0
304932	304777	19489J	PARTICIPANT	\N	PRESENT	0
304933	304777	14041T	PARTICIPANT	\N	PRESENT	0
304934	304777	14147R	PARTICIPANT	\N	PRESENT	0
304935	304777	08010L	PARTICIPANT	\N	PRESENT	0
304936	304777	08061X	PARTICIPANT	\N	PRESENT	0
304937	304777	14215L	PARTICIPANT	\N	PRESENT	0
304938	304777	17637T	PARTICIPANT	\N	PRESENT	0
304963	304777	01048V	PARTICIPANT	\N	PRESENT	0
304940	304777	14053L	PARTICIPANT	\N	PRESENT	0
304941	304777	11048N	PARTICIPANT	\N	PRESENT	0
304942	304777	19649G	PARTICIPANT	\N	PRESENT	0
304943	304777	19713W	PARTICIPANT	\N	PRESENT	0
304944	304777	08045X	PARTICIPANT	\N	PRESENT	0
304945	304777	11026G	PARTICIPANT	\N	PRESENT	0
304946	304777	07034Q	PARTICIPANT	\N	PRESENT	0
304947	304777	01024M	PARTICIPANT	\N	PRESENT	0
304948	304777	11040E	PARTICIPANT	\N	PRESENT	0
304949	304777	95063L	PARTICIPANT	\N	PRESENT	0
304950	304777	08044W	PARTICIPANT	\N	PRESENT	0
304951	304777	04061F	PARTICIPANT	\N	PRESENT	0
304952	304777	14257W	PARTICIPANT	\N	PRESENT	0
304953	289219	19573D	PARTICIPANT	\N	PRESENT	0
304954	289219	19643A	PARTICIPANT	\N	PRESENT	0
304955	289219	08061X	PARTICIPANT	\N	PRESENT	0
304956	289219	11066Q	PARTICIPANT	\N	PRESENT	0
304957	289219	19669L	PARTICIPANT	\N	PRESENT	0
304958	289219	11083R	PARTICIPANT	\N	PRESENT	0
304961	304777	14033T	PARTICIPANT	\N	PRESENT	0
305296	305295	19703U	PARTICIPANT	\N	PRESENT	0
304964	304777	19727D	PARTICIPANT	\N	PRESENT	0
304965	304777	19729F	PARTICIPANT	\N	EXCUSE	0
305298	305297	19703U	PARTICIPANT	\N	PRESENT	0
305302	305299	19703U	PARTICIPANT	\N	PRESENT	0
305303	305300	19703U	PARTICIPANT	\N	PRESENT	0
305304	305301	19703U	PARTICIPANT	\N	PRESENT	0
305306	305305	19703U	PARTICIPANT	\N	PRESENT	0
305488	305413	14111D	PARTICIPANT	\N	PRESENT	0
305489	305413	19649G	PARTICIPANT	\N	PRESENT	0
305490	305413	14065Q	PARTICIPANT	\N	PRESENT	0
305491	305413	07034Q	PARTICIPANT	\N	PRESENT	0
305492	305413	10015M	PARTICIPANT	\N	PRESENT	0
305493	305413	19253P	PARTICIPANT	\N	PRESENT	0
305494	305413	01024M	PARTICIPANT	\N	PRESENT	0
305495	305413	19581D	PARTICIPANT	\N	PRESENT	0
305496	305413	04038G	PARTICIPANT	\N	PRESENT	0
305497	305413	04044E	PARTICIPANT	\N	PRESENT	0
305498	305413	04047H	PARTICIPANT	\N	PRESENT	0
305499	305413	01028R	PARTICIPANT	\N	PRESENT	0
305500	305413	14231L	PARTICIPANT	\N	PRESENT	0
305501	305413	19447X	PARTICIPANT	\N	PRESENT	0
305502	305413	19489J	PARTICIPANT	\N	PRESENT	0
305503	305413	95063L	PARTICIPANT	\N	PRESENT	0
305504	305413	14147R	PARTICIPANT	\N	PRESENT	0
305505	305413	14179A	PARTICIPANT	\N	PRESENT	0
305506	305413	14151M	PARTICIPANT	\N	PRESENT	0
305507	305413	14215L	PARTICIPANT	\N	PRESENT	0
305508	305413	14259Y	PARTICIPANT	\N	PRESENT	0
305509	305413	14021P	PARTICIPANT	\N	PRESENT	0
305510	305413	19762G	PARTICIPANT	\N	PRESENT	0
305511	305413	11072N	PARTICIPANT	\N	PRESENT	0
307007	305883	14069U	PARTICIPANT	\N	PRESENT	0
307008	305883	08034U	PARTICIPANT	\N	PRESENT	0
307009	305883	95067Q	PARTICIPANT	\N	PRESENT	0
307010	305883	08049C	PARTICIPANT	\N	PRESENT	0
307011	305883	95063L	PARTICIPANT	\N	PRESENT	0
307012	305883	08010L	PARTICIPANT	\N	PRESENT	0
307013	305883	01057W	PARTICIPANT	\N	PRESENT	0
307014	305883	19525U	PARTICIPANT	\N	PRESENT	0
307015	305883	04061F	PARTICIPANT	\N	PRESENT	0
309428	309427	04086Q	PARTICIPANT	\N	PRESENT	0
309429	309427	99004R	PARTICIPANT	\N	PRESENT	0
309430	309427	04040A	PARTICIPANT	\N	PRESENT	0
322234	314148	19721W	PARTICIPANT	\N	PRESENT	0
322235	314148	98050T	PARTICIPANT	\N	PRESENT	0
322236	314148	80013X	PARTICIPANT	\N	PRESENT	0
322237	314148	14033T	PARTICIPANT	\N	PRESENT	0
322238	314148	19349W	PARTICIPANT	\N	PRESENT	0
322239	314148	08020N	PARTICIPANT	\N	PRESENT	0
322240	314148	14109K	PARTICIPANT	\N	PRESENT	0
322241	314148	14071N	PARTICIPANT	\N	PRESENT	0
322242	314148	08021P	PARTICIPANT	\N	PRESENT	0
322243	320970	14327T	PARTICIPANT	\N	PRESENT	0
322244	320970	19479G	PARTICIPANT	\N	PRESENT	0
322245	320970	19711U	PARTICIPANT	\N	PRESENT	0
322246	320970	19531S	PARTICIPANT	\N	PRESENT	0
322247	320970	08034U	PARTICIPANT	\N	PRESENT	0
322248	320970	11097X	PARTICIPANT	\N	PRESENT	0
322249	320970	01057W	PARTICIPANT	\N	PRESENT	0
322250	320970	19689Q	PARTICIPANT	\N	PRESENT	0
322251	320970	19387D	PARTICIPANT	\N	PRESENT	0
322252	320970	11053K	PARTICIPANT	\N	PRESENT	0
322253	320970	11074Q	PRESIDENT	0	PRESENT	0
322254	320970	08011M	PARTICIPANT	\N	PRESENT	0
322255	320970	14034U	PARTICIPANT	\N	PRESENT	0
322256	320970	88008L	PARTICIPANT	\N	PRESENT	0
322257	320970	19671E	PARTICIPANT	\N	PRESENT	0
322258	320970	11012A	PARTICIPANT	\N	PRESENT	0
322259	320970	14199E	PARTICIPANT	\N	PRESENT	0
322260	320970	14085U	PARTICIPANT	\N	PRESENT	0
322261	320970	08010L	PARTICIPANT	\N	PRESENT	0
322262	320970	14121F	PARTICIPANT	\N	PRESENT	0
322263	320970	19741B	PARTICIPANT	\N	PRESENT	0
322264	320970	95041E	PARTICIPANT	\N	PRESENT	0
322265	320970	19667J	PARTICIPANT	\N	PRESENT	0
322266	320970	89017R	PARTICIPANT	\N	PRESENT	0
322267	320970	11070L	PARTICIPANT	\N	PRESENT	0
322268	320970	11048N	PARTICIPANT	\N	EXCUSE	0
322269	320970	08014Q	PARTICIPANT	\N	EXCUSE	0
322270	314148	19691J	PARTICIPANT	\N	PRESENT	0
322271	314148	19725B	PARTICIPANT	\N	PRESENT	0
322272	314148	08062Y	PARTICIPANT	\N	PRESENT	0
322273	314148	95037J	PARTICIPANT	\N	PRESENT	0
322274	314148	01025N	PARTICIPANT	\N	PRESENT	0
322275	314148	19335Q	PARTICIPANT	\N	PRESENT	0
322276	314148	08060W	PARTICIPANT	\N	PRESENT	0
322277	314148	19413M	PARTICIPANT	\N	PRESENT	0
322278	314148	98022P	PARTICIPANT	\N	PRESENT	0
322279	314148	11056N	PARTICIPANT	\N	PRESENT	0
322280	314148	19731Y	PARTICIPANT	\N	PRESENT	0
322281	314148	98029W	PARTICIPANT	\N	PRESENT	0
322282	314148	14259Y	PARTICIPANT	\N	PRESENT	0
322284	314148	10006L	PARTICIPANT	\N	PRESENT	0
322285	314148	14031R	PARTICIPANT	\N	PRESENT	0
322286	314148	19719D	PARTICIPANT	\N	PRESENT	0
322293	314148	19581D	PARTICIPANT	\N	PRESENT	0
322294	314148	19611R	PARTICIPANT	\N	PRESENT	0
322295	314148	19699S	PARTICIPANT	\N	PRESENT	0
322296	314148	08043V	PARTICIPANT	\N	PRESENT	0
322297	320970	01048V	PARTICIPANT	\N	PRESENT	0
322298	320970	07029T	PARTICIPANT	\N	PRESENT	0
322299	314148	14081Q	PARTICIPANT	\N	PRESENT	0
322300	314148	01024M	PARTICIPANT	\N	PRESENT	0
322301	314148	14193X	PARTICIPANT	\N	PRESENT	0
322302	314148	19295A	PARTICIPANT	\N	PRESENT	0
322303	314148	19729F	PARTICIPANT	\N	PRESENT	0
322304	314148	17583W	PARTICIPANT	\N	PRESENT	0
322305	314148	19675J	PARTICIPANT	\N	PRESENT	0
322306	314148	14059S	PARTICIPANT	\N	PRESENT	0
322307	314148	04044E	PARTICIPANT	\N	PRESENT	0
322308	314148	19533U	PARTICIPANT	\N	PRESENT	0
322309	314148	19441R	PARTICIPANT	\N	PRESENT	0
322310	314148	87003B	PARTICIPANT	\N	PRESENT	0
322311	314148	19593H	PARTICIPANT	\N	PRESENT	0
322312	314148	14121F	PARTICIPANT	\N	PRESENT	0
322313	314148	19659J	PARTICIPANT	\N	PRESENT	0
322314	314148	14201E	PARTICIPANT	\N	PRESENT	0
322315	314148	14063N	PARTICIPANT	\N	PRESENT	0
322316	314148	19421M	PARTICIPANT	\N	PRESENT	0
322457	314151	95062K	PARTICIPANT	\N	PRESENT	0
322458	314151	98024R	PARTICIPANT	\N	PRESENT	0
322459	314151	95041E	PARTICIPANT	\N	PRESENT	0
322460	314151	14191V	PARTICIPANT	\N	PRESENT	0
322461	314151	98018T	PARTICIPANT	\N	PRESENT	0
322462	314151	08069G	PARTICIPANT	\N	PRESENT	0
322463	314151	08010L	PARTICIPANT	\N	PRESENT	0
322464	321790	19703U	PARTICIPANT	\N	PRESENT	0
322465	321790	19553Y	PARTICIPANT	\N	PRESENT	0
322466	321790	19521Q	PARTICIPANT	\N	PRESENT	0
322467	321790	19691J	PARTICIPANT	\N	PRESENT	0
322468	321790	08041T	PARTICIPANT	\N	EXCUSE	0
322469	314151	14029X	PARTICIPANT	\N	PRESENT	0
322470	314151	19447X	PARTICIPANT	\N	PRESENT	0
322471	314151	87003B	PARTICIPANT	\N	PRESENT	0
322472	314151	19533U	PARTICIPANT	\N	PRESENT	0
322473	314151	11103C	PARTICIPANT	\N	PRESENT	0
322474	314151	14147R	PARTICIPANT	\N	PRESENT	0
322475	314151	14105F	PARTICIPANT	\N	PRESENT	0
322476	314151	19703U	PARTICIPANT	\N	PRESENT	0
322477	314151	19443T	PARTICIPANT	\N	PRESENT	0
322478	314151	07029T	PARTICIPANT	\N	PRESENT	0
322479	314151	14133K	PARTICIPANT	\N	PRESENT	0
322480	314151	98023Q	PARTICIPANT	\N	PRESENT	0
322481	314151	14031R	PARTICIPANT	\N	PRESENT	0
322482	314151	08048B	PARTICIPANT	\N	PRESENT	0
322483	314151	14059S	PARTICIPANT	\N	PRESENT	0
322484	314151	11115U	PARTICIPANT	\N	PRESENT	0
322485	314151	08019V	PARTICIPANT	\N	PRESENT	0
322486	314151	14357A	PARTICIPANT	\N	PRESENT	0
322487	314151	05012A	PARTICIPANT	\N	PRESENT	0
322488	314151	95067Q	PARTICIPANT	\N	PRESENT	0
322489	314151	19467C	PARTICIPANT	\N	PRESENT	0
322490	314151	14265W	PARTICIPANT	\N	PRESENT	0
322491	314151	08028W	PARTICIPANT	\N	PRESENT	0
322492	314151	19762G	PARTICIPANT	\N	PRESENT	0
322493	314151	10006L	PARTICIPANT	\N	PRESENT	0
322494	314151	14087W	PARTICIPANT	\N	PRESENT	0
322495	314151	95030B	PARTICIPANT	\N	PRESENT	0
322496	314151	14193X	PARTICIPANT	\N	PRESENT	0
322497	314151	11101A	PARTICIPANT	\N	PRESENT	0
322498	314151	14211G	PARTICIPANT	\N	PRESENT	0
322499	314151	14026U	PARTICIPANT	\N	PRESENT	0
322500	314151	14259Y	PARTICIPANT	\N	PRESENT	0
322502	314151	01048V	PARTICIPANT	\N	PRESENT	0
322503	314151	14223L	PARTICIPANT	\N	PRESENT	0
322504	314151	14217N	PARTICIPANT	\N	PRESENT	0
322505	314151	19581D	PARTICIPANT	\N	PRESENT	0
322506	314151	19399H	PARTICIPANT	\N	PRESENT	0
322507	314151	92040Q	PARTICIPANT	\N	PRESENT	0
322508	314151	14253S	PARTICIPANT	\N	PRESENT	0
322509	314151	14038Y	PARTICIPANT	\N	PRESENT	0
322510	314151	04088S	PARTICIPANT	\N	PRESENT	0
322511	314151	18083K	PARTICIPANT	\N	PRESENT	0
322512	314151	19667J	PARTICIPANT	\N	PRESENT	0
322513	314151	19507S	PARTICIPANT	\N	PRESENT	0
322514	314151	08062Y	PARTICIPANT	\N	PRESENT	0
322515	314151	04033B	PARTICIPANT	\N	PRESENT	0
322516	314151	04049K	PARTICIPANT	\N	PRESENT	0
322517	314151	08015R	PARTICIPANT	\N	PRESENT	0
322518	314151	99004R	PARTICIPANT	\N	PRESENT	0
322519	314151	07034Q	PARTICIPANT	\N	PRESENT	0
322520	314151	11080N	PARTICIPANT	\N	PRESENT	0
322521	314151	04097T	PARTICIPANT	\N	PRESENT	0
322522	314151	11090Q	PARTICIPANT	\N	PRESENT	0
322523	314151	08039A	PARTICIPANT	\N	PRESENT	0
322524	314151	12041X	PARTICIPANT	\N	PRESENT	0
322525	314151	19643A	PARTICIPANT	\N	PRESENT	0
322526	314151	19695N	PARTICIPANT	\N	PRESENT	0
322527	314151	11056N	PARTICIPANT	\N	PRESENT	0
322528	314151	19679N	PARTICIPANT	\N	PRESENT	0
322529	314151	19760E	PARTICIPANT	\N	PRESENT	0
322530	314151	17637T	PARTICIPANT	\N	PRESENT	0
322531	314151	11031D	PARTICIPANT	\N	PRESENT	0
322532	314151	11040E	PARTICIPANT	\N	PRESENT	0
322533	314151	04085P	PARTICIPANT	\N	PRESENT	0
322534	314151	19711U	PARTICIPANT	\N	PRESENT	0
322535	314151	11033F	PARTICIPANT	\N	PRESENT	0
322536	314151	04008A	PARTICIPANT	\N	PRESENT	0
322537	314151	86034E	PARTICIPANT	\N	PRESENT	0
322538	314151	19758L	PARTICIPANT	\N	PRESENT	0
322539	314151	19347U	PARTICIPANT	\N	PRESENT	0
322540	314151	19565D	PARTICIPANT	\N	PRESENT	0
322541	314151	19593H	PARTICIPANT	\N	PRESENT	0
322542	314151	08011M	PARTICIPANT	\N	PRESENT	0
322543	314151	19687N	PARTICIPANT	\N	PRESENT	0
322544	314151	14157T	PARTICIPANT	\N	PRESENT	0
322545	314151	01058X	PARTICIPANT	\N	PRESENT	0
322546	314151	11077T	PARTICIPANT	\N	PRESENT	0
322547	314151	08020N	PARTICIPANT	\N	PRESENT	0
322548	314151	08061X	PARTICIPANT	\N	PRESENT	0
322549	314151	10015M	PARTICIPANT	\N	PRESENT	0
302285	301832	01024M	PARTICIPANT	\N	EXCUSE	0
302286	301832	04044E	PARTICIPANT	\N	EXCUSE	0
303854	301383	19663E	PARTICIPANT	\N	PRESENT	0
311752	311751	11067R	PARTICIPANT	\N	PRESENT	0
312873	309272	14249W	PARTICIPANT	\N	PRESENT	0
312874	309272	08019V	PARTICIPANT	\N	PRESENT	0
312875	309272	07029T	PARTICIPANT	\N	PRESENT	0
312876	309272	14029X	PARTICIPANT	\N	PRESENT	0
312878	309272	19741B	PARTICIPANT	\N	PRESENT	0
312880	309272	19729F	PARTICIPANT	\N	PRESENT	0
312881	309272	19581D	PARTICIPANT	\N	PRESENT	0
312882	309272	14059S	PARTICIPANT	\N	PRESENT	0
312883	309272	07004J	PARTICIPANT	\N	PRESENT	0
312884	309272	01028R	PARTICIPANT	\N	PRESENT	0
312885	309272	19737F	PARTICIPANT	\N	PRESENT	0
312886	309272	11033F	PARTICIPANT	\N	PRESENT	0
312887	309272	97011G	PARTICIPANT	\N	PRESENT	0
312888	309272	04057K	PARTICIPANT	\N	PRESENT	0
312889	309272	14065Q	PARTICIPANT	\N	PRESENT	0
312890	309272	14061L	PARTICIPANT	\N	PRESENT	0
312891	309272	01057W	PARTICIPANT	\N	PRESENT	0
312892	309272	19253P	PARTICIPANT	\N	PRESENT	0
312893	309272	19691J	PARTICIPANT	\N	PRESENT	0
312894	309272	14207L	PARTICIPANT	\N	PRESENT	0
312895	309272	19447X	PARTICIPANT	\N	PRESENT	0
312896	309272	14173T	PARTICIPANT	\N	PRESENT	0
312897	309272	11103C	PARTICIPANT	\N	PRESENT	0
312898	309272	11067R	PARTICIPANT	\N	PRESENT	0
312899	309272	04034C	PARTICIPANT	\N	PRESENT	0
312900	309272	05008E	PARTICIPANT	\N	PRESENT	0
312901	309272	17583W	PARTICIPANT	\N	PRESENT	0
312902	309272	10015M	PARTICIPANT	\N	PRESENT	0
312903	309272	19629C	PARTICIPANT	\N	PRESENT	0
312904	309272	11056N	PARTICIPANT	\N	PRESENT	0
312905	309272	08020N	PARTICIPANT	\N	PRESENT	0
312906	309272	19649G	PARTICIPANT	\N	PRESENT	0
312907	309272	19565D	PARTICIPANT	\N	PRESENT	0
312908	309272	08031R	PARTICIPANT	\N	PRESENT	0
312909	309272	14069U	PARTICIPANT	\N	PRESENT	0
312910	309272	08044W	PARTICIPANT	\N	PRESENT	0
312911	309272	19711U	PARTICIPANT	\N	PRESENT	0
312912	309272	17637T	PARTICIPANT	\N	PRESENT	0
312913	309272	19762G	PARTICIPANT	\N	PRESENT	0
312914	309272	14119M	PARTICIPANT	\N	PRESENT	0
312915	309272	19719D	PARTICIPANT	\N	PRESENT	0
312916	309272	08039A	PARTICIPANT	\N	PRESENT	0
312917	309272	14121F	PARTICIPANT	\N	PRESENT	0
312918	309272	14223L	PARTICIPANT	\N	PRESENT	0
312919	309272	19758L	PARTICIPANT	\N	PRESENT	0
312920	309272	19467C	PARTICIPANT	\N	PRESENT	0
312921	309272	14135M	PARTICIPANT	\N	PRESENT	0
312922	309272	08034U	PARTICIPANT	\N	PRESENT	0
312923	309272	19703U	PARTICIPANT	\N	PRESENT	0
312924	309272	19673G	PARTICIPANT	\N	PRESENT	0
312925	309272	19760E	PARTICIPANT	\N	PRESENT	0
312926	309272	19543W	PARTICIPANT	\N	PRESENT	0
312927	309272	14151M	PARTICIPANT	\N	PRESENT	0
312928	309272	04088S	PARTICIPANT	\N	PRESENT	0
312929	309272	98005N	PARTICIPANT	\N	PRESENT	0
312930	309272	14111D	PARTICIPANT	\N	PRESENT	0
312931	309272	14237S	PARTICIPANT	\N	PRESENT	0
312932	309272	19441R	PARTICIPANT	\N	PRESENT	0
312933	309272	19479G	PARTICIPANT	\N	PRESENT	0
312934	309272	19725B	PARTICIPANT	\N	PRESENT	0
312935	309272	14357A	PARTICIPANT	\N	PRESENT	0
312936	309272	14329V	PARTICIPANT	\N	PRESENT	0
312937	309272	87003B	PARTICIPANT	\N	PRESENT	0
312938	309272	19675J	PARTICIPANT	\N	PRESENT	0
312939	309272	19599P	PARTICIPANT	\N	PRESENT	0
312940	309272	19415P	PARTICIPANT	\N	PRESENT	0
312941	309272	01058X	PARTICIPANT	\N	PRESENT	0
312945	309272	11043H	PARTICIPANT	\N	PRESENT	0
312943	309272	16685X	PARTICIPANT	\N	PRESENT	0
312944	309272	08043V	PARTICIPANT	\N	PRESENT	0
312946	309272	19611R	PARTICIPANT	\N	PRESENT	0
312947	309272	14205J	PARTICIPANT	\N	PRESENT	0
312948	309272	14215L	PARTICIPANT	\N	PRESENT	0
312949	309272	07034Q	PARTICIPANT	\N	PRESENT	0
312952	309272	11012A	PARTICIPANT	\N	PRESENT	0
312953	309272	14213J	PARTICIPANT	\N	PRESENT	0
312954	309272	01034P	PARTICIPANT	\N	PRESENT	0
312955	309272	80013X	PARTICIPANT	\N	PRESENT	0
312956	309272	04085P	PARTICIPANT	\N	PRESENT	0
312957	309272	19733B	PARTICIPANT	\N	PRESENT	0
312958	309272	14217N	PARTICIPANT	\N	PRESENT	0
312959	309272	11097X	PARTICIPANT	\N	PRESENT	0
312960	309272	14331P	PARTICIPANT	\N	PRESENT	0
312961	309272	14265W	PARTICIPANT	\N	PRESENT	0
313027	309273	01024M	PARTICIPANT	\N	PRESENT	0
313028	309273	11072N	PARTICIPANT	\N	PRESENT	0
313029	309273	19737F	PARTICIPANT	\N	PRESENT	0
313030	309273	19467C	PARTICIPANT	\N	PRESENT	0
313031	309273	19415P	PARTICIPANT	\N	PRESENT	0
313032	309273	19447X	PARTICIPANT	\N	PRESENT	0
313033	309273	19741B	PARTICIPANT	\N	PRESENT	0
313034	309273	14105F	PARTICIPANT	\N	PRESENT	0
313035	309273	14065Q	PARTICIPANT	\N	PRESENT	0
313036	309273	04085P	PARTICIPANT	\N	PRESENT	0
313037	309273	19649G	PARTICIPANT	\N	PRESENT	0
313038	309273	14215L	PARTICIPANT	\N	PRESENT	0
313039	309273	19719D	PARTICIPANT	\N	PRESENT	0
313040	309273	14231L	PARTICIPANT	\N	PRESENT	0
313041	309273	19691J	PARTICIPANT	\N	PRESENT	0
313042	309273	07034Q	PARTICIPANT	\N	PRESENT	0
313043	309273	05008E	PARTICIPANT	\N	PRESENT	0
313044	309273	19253P	PARTICIPANT	\N	PRESENT	0
313045	309273	08020N	PARTICIPANT	\N	PRESENT	0
313046	309273	19629C	PARTICIPANT	\N	PRESENT	0
313047	309273	14151M	PARTICIPANT	\N	PRESENT	0
313051	309273	14111D	PARTICIPANT	\N	PRESENT	0
313049	309273	08045X	PARTICIPANT	\N	PRESENT	0
313050	309273	01028R	PARTICIPANT	\N	PRESENT	0
313052	309273	14069U	PARTICIPANT	\N	PRESENT	0
313053	309273	07029T	PARTICIPANT	\N	PRESENT	0
313054	309273	08056B	PARTICIPANT	\N	PRESENT	0
313055	309273	10015M	PARTICIPANT	\N	PRESENT	0
313056	309273	08031R	PARTICIPANT	\N	PRESENT	0
313057	309273	11012A	PARTICIPANT	\N	PRESENT	0
313058	309273	11033F	PARTICIPANT	\N	PRESENT	0
313059	309273	19545Y	PARTICIPANT	\N	PRESENT	0
313060	309273	19713W	PARTICIPANT	\N	PRESENT	0
313061	309273	08061X	PARTICIPANT	\N	PRESENT	0
313062	309273	19573D	PARTICIPANT	\N	PRESENT	0
313063	309273	14173T	PARTICIPANT	\N	PRESENT	0
313064	309273	19733B	PARTICIPANT	\N	PRESENT	0
313065	309273	19703U	PARTICIPANT	\N	PRESENT	0
313066	309273	14257W	PARTICIPANT	\N	PRESENT	0
313067	309273	95030B	PARTICIPANT	\N	PRESENT	0
313068	309273	14265W	PARTICIPANT	\N	PRESENT	0
313069	309273	19383Y	PARTICIPANT	\N	PRESENT	0
313070	309273	98005N	PARTICIPANT	\N	PRESENT	0
313071	309273	14135M	PARTICIPANT	\N	PRESENT	0
313072	309273	14026U	PARTICIPANT	\N	PRESENT	0
313073	309273	14213J	PARTICIPANT	\N	PRESENT	0
313074	309273	14179A	PARTICIPANT	\N	PRESENT	0
313075	309273	08044W	PARTICIPANT	\N	PRESENT	0
313076	309273	14211G	PARTICIPANT	\N	PRESENT	0
313077	309273	19507S	PARTICIPANT	\N	PRESENT	0
313078	309273	14083S	PARTICIPANT	\N	PRESENT	0
313079	309273	14133K	PARTICIPANT	\N	PRESENT	0
314166	314164	96004D	PARTICIPANT	\N	PRESENT	0
314167	314164	98050T	PARTICIPANT	\N	PRESENT	0
314170	314168	19333N	PARTICIPANT	\N	PRESENT	0
314171	314168	14001X	PARTICIPANT	\N	PRESENT	0
314172	314168	14205J	PARTICIPANT	\N	PRESENT	0
324031	314152	14195A	PARTICIPANT	\N	PRESENT	0
324032	314152	19737F	PARTICIPANT	\N	PRESENT	0
323970	320713	19289C	PARTICIPANT	\N	PRESENT	0
324021	321055	04071H	PARTICIPANT	\N	PRESENT	0
313025	309273	04086Q	PARTICIPANT	\N	PRESENT	0
313026	309273	04047H	PARTICIPANT	\N	PRESENT	0
324022	321055	19711U	PARTICIPANT	\N	PRESENT	0
324023	321055	01048V	PARTICIPANT	\N	PRESENT	0
324024	321055	12016W	PARTICIPANT	\N	PRESENT	0
324025	321055	19667J	PARTICIPANT	\N	PRESENT	0
324026	321055	11074Q	PRESIDENT	0	PRESENT	0
324027	321055	14225N	PARTICIPANT	\N	PRESENT	0
324028	321055	04086Q	PARTICIPANT	\N	PRESENT	0
324029	321055	07029T	PARTICIPANT	\N	PRESENT	0
324030	321055	14085U	PRESIDENT	1	PRESENT	0
324033	321055	19479G	PARTICIPANT	\N	PRESENT	0
324034	321055	19689Q	PARTICIPANT	\N	PRESENT	0
324035	314152	98024R	PARTICIPANT	\N	PRESENT	0
324036	314152	95030B	PARTICIPANT	\N	PRESENT	0
324037	314152	19719D	PARTICIPANT	\N	PRESENT	0
324038	314152	19629C	PARTICIPANT	\N	PRESENT	0
324039	314152	08047A	PARTICIPANT	\N	PRESENT	0
324040	314152	04045F	PARTICIPANT	\N	PRESENT	0
324041	314152	14069U	PARTICIPANT	\N	PRESENT	0
330009	325451	14119M	PARTICIPANT	\N	PRESENT	0
330010	325451	14213J	PARTICIPANT	\N	PRESENT	0
330011	325451	14217N	PARTICIPANT	\N	PRESENT	0
330012	321343	07004J	PARTICIPANT	\N	PRESENT	0
330013	325451	14223L	PARTICIPANT	\N	PRESENT	0
330014	325451	14281W	PARTICIPANT	\N	PRESENT	0
330015	325451	14195A	PARTICIPANT	\N	PRESENT	0
330016	321343	14235Q	PARTICIPANT	\N	PRESENT	0
330017	321343	11077T	PARTICIPANT	\N	PRESENT	0
330018	321343	19593H	PARTICIPANT	\N	PRESENT	0
330019	321343	08017T	PARTICIPANT	\N	PRESENT	0
330020	325451	11097X	PARTICIPANT	\N	PRESENT	0
330021	325451	19301E	PARTICIPANT	\N	PRESENT	0
330022	325451	17779H	PARTICIPANT	\N	PRESENT	0
330023	321343	19289C	PARTICIPANT	\N	PRESENT	0
330024	321343	11104D	PARTICIPANT	\N	PRESENT	0
330025	321343	19651A	PARTICIPANT	\N	PRESENT	0
330026	325451	01034P	PARTICIPANT	\N	PRESENT	0
330027	325451	19569H	PARTICIPANT	\N	PRESENT	0
330028	321343	11070L	PARTICIPANT	\N	PRESENT	0
330029	321343	14089Y	PARTICIPANT	\N	PRESENT	0
330030	321343	99004R	PARTICIPANT	\N	PRESENT	0
330031	325451	14042U	PARTICIPANT	\N	PRESENT	0
330032	325451	19521Q	PARTICIPANT	\N	PRESENT	0
330033	321343	19758L	PARTICIPANT	\N	PRESENT	0
330034	325451	19527W	PARTICIPANT	\N	PRESENT	0
330035	321343	19667J	PARTICIPANT	\N	PRESENT	0
330036	321343	14173T	PARTICIPANT	\N	PRESENT	0
330037	321343	19415P	PARTICIPANT	\N	PRESENT	0
330038	321343	14225N	PARTICIPANT	\N	PRESENT	0
330039	321343	14051J	PARTICIPANT	\N	PRESENT	0
330040	321343	18083K	PARTICIPANT	\N	PRESENT	0
330041	321343	19467C	PARTICIPANT	\N	PRESENT	0
330042	321343	12016W	PARTICIPANT	\N	PRESENT	0
330043	321343	14038Y	PARTICIPANT	\N	PRESENT	0
330044	321343	19599P	PARTICIPANT	\N	PRESENT	0
330045	321343	14085U	PARTICIPANT	\N	PRESENT	0
330046	321343	14123H	PARTICIPANT	\N	PRESENT	0
330047	321343	19782L	PARTICIPANT	\N	PRESENT	0
330048	321343	19629C	PARTICIPANT	\N	PRESENT	0
330049	321343	14147R	PARTICIPANT	\N	PRESENT	0
330050	321343	04088S	PARTICIPANT	\N	PRESENT	0
330053	321343	19673G	PARTICIPANT	\N	PRESENT	0
330055	325451	14071N	PARTICIPANT	\N	PRESENT	0
330056	321343	14083S	PARTICIPANT	\N	PRESENT	0
330057	321343	08010L	PARTICIPANT	\N	PRESENT	0
330058	321343	14069U	PARTICIPANT	\N	PRESENT	0
330059	321343	08019V	PARTICIPANT	\N	PRESENT	0
330060	321343	14187A	PARTICIPANT	\N	PRESENT	0
330061	321343	19762G	PARTICIPANT	\N	PRESENT	0
330062	321343	14255U	PARTICIPANT	\N	PRESENT	0
330063	321343	01057W	PARTICIPANT	\N	PRESENT	0
330064	321343	14030Q	PARTICIPANT	\N	PRESENT	0
330065	321343	11012A	PARTICIPANT	\N	PRESENT	0
330066	321343	19719D	PARTICIPANT	\N	PRESENT	0
330067	321343	19687N	PARTICIPANT	\N	PRESENT	0
330068	321343	19333N	PARTICIPANT	\N	PRESENT	0
330069	321343	19649G	PARTICIPANT	\N	PRESENT	0
330070	321343	08044W	PARTICIPANT	\N	PRESENT	0
330071	321343	14033T	PARTICIPANT	\N	PRESENT	0
330072	321343	04049K	PARTICIPANT	\N	PRESENT	0
330073	321343	01048V	PARTICIPANT	\N	PRESENT	0
330075	321343	19549D	PARTICIPANT	\N	PRESENT	0
330076	321343	19441R	PARTICIPANT	\N	PRESENT	0
330077	325451	98024R	PARTICIPANT	\N	PRESENT	0
330078	321343	14199E	PARTICIPANT	\N	PRESENT	0
330079	321343	19729F	PARTICIPANT	\N	PRESENT	0
330080	321343	19565D	PARTICIPANT	\N	PRESENT	0
330081	321343	98050T	PARTICIPANT	\N	PRESENT	0
330082	321343	11072N	PARTICIPANT	\N	PRESENT	0
330083	325451	11067R	PARTICIPANT	\N	PRESENT	0
330084	321343	19563B	PARTICIPANT	\N	PRESENT	0
330085	321343	14031R	PARTICIPANT	\N	PRESENT	0
330086	321343	19637C	PARTICIPANT	\N	PRESENT	0
330087	321343	14151M	PARTICIPANT	\N	PRESENT	0
330088	321343	04047H	PARTICIPANT	\N	PRESENT	0
330089	321343	14073Q	PARTICIPANT	\N	PRESENT	0
330090	321343	89017R	PARTICIPANT	\N	PRESENT	0
330091	321343	17583W	PARTICIPANT	\N	PRESENT	0
330092	321343	14169X	PARTICIPANT	\N	PRESENT	0
330093	321343	11110B	PARTICIPANT	\N	PRESENT	0
330094	321343	14115H	PARTICIPANT	\N	PRESENT	0
330095	321343	11097X	PARTICIPANT	\N	PRESENT	0
330099	321343	14237S	PARTICIPANT	\N	PRESENT	0
330097	321343	11101A	PARTICIPANT	\N	PRESENT	0
330098	321343	08043V	PARTICIPANT	\N	PRESENT	0
330106	321343	19647E	PARTICIPANT	\N	PRESENT	0
330101	321343	19611R	PARTICIPANT	\N	PRESENT	0
330102	321343	19621T	PARTICIPANT	\N	PRESENT	0
330103	321343	14223L	PARTICIPANT	\N	PRESENT	0
330104	321343	11048N	PARTICIPANT	\N	PRESENT	0
330105	321343	19663E	PARTICIPANT	\N	PRESENT	0
330107	321343	19369B	PARTICIPANT	\N	PRESENT	0
330108	321343	19573D	PARTICIPANT	\N	PRESENT	0
330109	321343	19413M	PARTICIPANT	\N	PRESENT	0
330110	321343	14257W	PARTICIPANT	\N	PRESENT	0
330111	321343	08038Y	PARTICIPANT	\N	PRESENT	0
330112	321343	14065Q	PARTICIPANT	\N	PRESENT	0
330113	321343	14109K	PARTICIPANT	\N	PRESENT	0
330114	321343	19349W	PARTICIPANT	\N	PRESENT	0
330115	321343	19503N	PARTICIPANT	\N	PRESENT	0
330116	321343	04061F	PARTICIPANT	\N	PRESENT	0
330117	321343	19301E	PARTICIPANT	\N	PRESENT	0
330185	321344	11070L	PARTICIPANT	\N	PRESENT	0
330186	321344	08011M	PARTICIPANT	\N	PRESENT	0
330187	321344	11074Q	PARTICIPANT	\N	PRESENT	0
330188	321344	08017T	PARTICIPANT	\N	PRESENT	0
330189	321344	19782L	PARTICIPANT	\N	PRESENT	0
330190	321344	19301E	PARTICIPANT	\N	PRESENT	0
330191	321344	19349W	PARTICIPANT	\N	PRESENT	0
330192	321344	04034C	PARTICIPANT	\N	PRESENT	0
330193	321344	11072N	PARTICIPANT	\N	PRESENT	0
330194	321344	19447X	PARTICIPANT	\N	PRESENT	0
330195	321344	19719D	PARTICIPANT	\N	PRESENT	0
330196	321344	14169X	PARTICIPANT	\N	PRESENT	0
330197	321344	14195A	PARTICIPANT	\N	PRESENT	0
330198	321344	01048V	PARTICIPANT	\N	PRESENT	0
330199	321344	19713W	PARTICIPANT	\N	PRESENT	0
330200	321344	19711U	PARTICIPANT	\N	PRESENT	0
330201	321344	14042U	PARTICIPANT	\N	PRESENT	0
330202	321344	11048N	PARTICIPANT	\N	PRESENT	0
330203	321344	19737F	PARTICIPANT	\N	PRESENT	0
330204	321344	14331P	PARTICIPANT	\N	PRESENT	0
330205	321344	14083S	PARTICIPANT	\N	PRESENT	0
330206	321344	14225N	PARTICIPANT	\N	PRESENT	0
330207	321344	19679N	PARTICIPANT	\N	PRESENT	0
330208	321344	19545Y	PARTICIPANT	\N	PRESENT	0
330209	321344	19295A	PARTICIPANT	\N	PRESENT	0
330210	321344	14255U	PARTICIPANT	\N	PRESENT	0
330211	321344	11043H	PARTICIPANT	\N	PRESENT	0
330212	321344	19687N	PARTICIPANT	\N	PRESENT	0
330213	321344	19367Y	PARTICIPANT	\N	PRESENT	0
330214	321344	14085U	PARTICIPANT	\N	PRESENT	0
330215	321344	95037J	PARTICIPANT	\N	PRESENT	0
330216	321344	14115H	PARTICIPANT	\N	PRESENT	0
330217	321344	11067R	PARTICIPANT	\N	PRESENT	0
330218	321344	19565D	PARTICIPANT	\N	PRESENT	0
330219	321344	11109J	PARTICIPANT	\N	PRESENT	0
330220	321344	14231L	PARTICIPANT	\N	PRESENT	0
330221	321344	14029X	PARTICIPANT	\N	PRESENT	0
330222	321344	12016W	PARTICIPANT	\N	PRESENT	0
330223	321344	01025N	PARTICIPANT	\N	PRESENT	0
330224	321344	08019V	PARTICIPANT	\N	PRESENT	0
330225	321344	14327T	PARTICIPANT	\N	PRESENT	0
330226	321344	80013X	PARTICIPANT	\N	PRESENT	0
330227	321344	14257W	PARTICIPANT	\N	PRESENT	0
330236	321344	18083K	PARTICIPANT	\N	PRESENT	0
330229	321344	19631V	PARTICIPANT	\N	PRESENT	0
330230	321344	19503N	PARTICIPANT	\N	PRESENT	0
330232	321344	19758L	PARTICIPANT	\N	PRESENT	0
330233	321344	19760E	PARTICIPANT	\N	PRESENT	0
330234	321344	19347U	PARTICIPANT	\N	PRESENT	0
330235	321344	17589D	PARTICIPANT	\N	PRESENT	0
330237	321344	19507S	PARTICIPANT	\N	PRESENT	0
330238	321344	95030B	PARTICIPANT	\N	PRESENT	0
330239	321344	17637T	PARTICIPANT	\N	PRESENT	0
330240	321344	19573D	PARTICIPANT	\N	PRESENT	0
330241	321344	14151M	PARTICIPANT	\N	PRESENT	0
330242	321344	14065Q	PARTICIPANT	\N	PRESENT	0
330243	321344	14105F	PARTICIPANT	\N	PRESENT	0
330244	321344	14147R	PARTICIPANT	\N	PRESENT	0
330245	321344	14038Y	PARTICIPANT	\N	PRESENT	0
330246	321344	19621T	PARTICIPANT	\N	PRESENT	0
330247	321344	19549D	PARTICIPANT	\N	PRESENT	0
330248	321344	19563B	PARTICIPANT	\N	PRESENT	0
330249	321344	14215L	PARTICIPANT	\N	PRESENT	0
330250	321344	19629C	PARTICIPANT	\N	PRESENT	0
330251	321344	14241N	PARTICIPANT	\N	PRESENT	0
305281	305280	14071N	PARTICIPANT	\N	PRESENT	0
309431	309427	11085T	PARTICIPANT	\N	PRESENT	0
309432	309427	14223L	PARTICIPANT	\N	PRESENT	0
309433	309427	04070G	PARTICIPANT	\N	PRESENT	0
309434	309427	14179A	PARTICIPANT	\N	PRESENT	0
309435	309427	19647E	PARTICIPANT	\N	PRESENT	0
309436	309427	19643A	PARTICIPANT	\N	PRESENT	0
309437	309427	19591F	PARTICIPANT	\N	PRESENT	0
309438	309427	14221J	PARTICIPANT	\N	PRESENT	0
309439	309427	19611R	PARTICIPANT	\N	PRESENT	0
309726	309725	14239U	PARTICIPANT	\N	PRESENT	0
310316	310314	96004D	PARTICIPANT	\N	PRESENT	0
310317	310315	96004D	PARTICIPANT	\N	PRESENT	0
310338	307294	97011G	PARTICIPANT	\N	EXCUSE	0
310339	307294	11041F	PARTICIPANT	\N	EXCUSE	0
310755	310749	14229S	PARTICIPANT	\N	PRESENT	0
310753	310748	14229S	PARTICIPANT	\N	PRESENT	0
310754	310748	08020N	PARTICIPANT	\N	PRESENT	0
310756	310750	14229S	PARTICIPANT	\N	PRESENT	0
310764	310751	14229S	PARTICIPANT	\N	PRESENT	0
310868	309069	14069U	PARTICIPANT	\N	PRESENT	0
310910	309069	95063L	PARTICIPANT	\N	PRESENT	0
310870	309069	19525U	PARTICIPANT	\N	PRESENT	0
310871	309069	14259Y	PARTICIPANT	\N	PRESENT	0
310872	309069	08038Y	PARTICIPANT	\N	PRESENT	0
310873	309069	14327T	PARTICIPANT	\N	PRESENT	0
310875	309069	14281W	PARTICIPANT	\N	PRESENT	0
310876	309069	14231L	PARTICIPANT	\N	PRESENT	0
310878	309069	19565D	PARTICIPANT	\N	PRESENT	0
310911	309069	04045F	PARTICIPANT	\N	PRESENT	0
310883	309069	01057W	PARTICIPANT	\N	PRESENT	0
310885	309069	11048N	PARTICIPANT	\N	PRESENT	0
310886	309069	19489J	PARTICIPANT	\N	PRESENT	0
310890	309069	08010L	PARTICIPANT	\N	PRESENT	0
310892	309069	14063N	PARTICIPANT	\N	PRESENT	0
310894	309069	14071N	PARTICIPANT	\N	PRESENT	0
310897	309069	14028W	PARTICIPANT	\N	PRESENT	0
310899	309069	05012A	PARTICIPANT	\N	PRESENT	0
310912	309069	04044E	PARTICIPANT	\N	PRESENT	0
310942	310941	14115H	PARTICIPANT	\N	PRESENT	0
310943	310941	19367Y	PARTICIPANT	\N	PRESENT	0
310945	310941	14041T	PARTICIPANT	\N	PRESENT	0
310946	310941	08048B	PARTICIPANT	\N	PRESENT	0
310949	310941	19766L	PARTICIPANT	\N	PRESENT	0
310951	310941	14223L	PARTICIPANT	\N	PRESENT	0
310954	310941	04033B	PARTICIPANT	\N	PRESENT	0
310965	305551	14030Q	PRESIDENT	0	PRESENT	0
310966	305551	19367Y	PARTICIPANT	\N	EXCUSE	0
310967	305551	19643A	PARTICIPANT	\N	EXCUSE	0
310968	305551	08020N	PARTICIPANT	\N	PRESENT	0
310969	305551	19701S	PARTICIPANT	\N	PRESENT	0
310970	305551	11031D	PARTICIPANT	\N	EXCUSE	0
310971	305551	80013X	PARTICIPANT	\N	PRESENT	0
310972	305551	19599P	PARTICIPANT	\N	PRESENT	0
310973	305551	19715Y	PARTICIPANT	\N	PRESENT	0
310974	305551	19731Y	PARTICIPANT	\N	PRESENT	0
310975	305551	08031R	PARTICIPANT	\N	PRESENT	0
310976	305551	07029T	PARTICIPANT	\N	EXCUSE	0
310977	305551	08017T	PARTICIPANT	\N	PRESENT	0
310978	305551	14109K	PARTICIPANT	\N	PRESENT	0
310979	305551	11045K	PARTICIPANT	\N	PRESENT	0
310980	305551	19749K	PARTICIPANT	\N	PRESENT	0
310981	305551	01043Q	PARTICIPANT	\N	EXCUSE	0
310982	305551	14179A	PARTICIPANT	\N	EXCUSE	0
311054	310767	89017R	PARTICIPANT	\N	PRESENT	0
311055	310767	19515S	PARTICIPANT	\N	PRESENT	0
311056	310767	14083S	PARTICIPANT	\N	PRESENT	0
311057	310767	19545Y	PARTICIPANT	\N	PRESENT	0
311080	311078	08058D	PARTICIPANT	\N	PRESENT	0
311059	310767	04071H	PARTICIPANT	\N	PRESENT	0
311060	310767	11053K	PARTICIPANT	\N	PRESENT	0
311061	310767	11110B	PARTICIPANT	\N	PRESENT	0
311062	310767	19521Q	PRESIDENT	1	PRESENT	0
311063	310767	14034U	PARTICIPANT	\N	PRESENT	0
311064	310767	19695N	PARTICIPANT	\N	PRESENT	0
311065	310767	14199E	PARTICIPANT	\N	PRESENT	0
311066	310767	19399H	PARTICIPANT	\N	PRESENT	0
311067	310767	11048N	PARTICIPANT	\N	PRESENT	0
311068	310767	04049K	PARTICIPANT	\N	PRESENT	0
311069	310767	19711U	PARTICIPANT	\N	PRESENT	0
311070	310767	12016W	PARTICIPANT	\N	PRESENT	0
311071	310767	04034C	PARTICIPANT	\N	EXCUSE	0
311072	310767	14227Q	PRESIDENT	0	PRESENT	0
311073	310767	14051J	PARTICIPANT	\N	EXCUSE	0
311074	310767	08034U	PARTICIPANT	\N	EXCUSE	0
311075	310767	19667J	PARTICIPANT	\N	PRESENT	0
311076	310767	14159V	PARTICIPANT	\N	PRESENT	0
311077	310767	19762G	PARTICIPANT	\N	PRESENT	0
311079	311078	14133K	PARTICIPANT	\N	PRESENT	0
311082	311081	14133K	PARTICIPANT	\N	PRESENT	0
311083	311081	08058D	PARTICIPANT	\N	PRESENT	0
311335	305886	19349W	PARTICIPANT	\N	PRESENT	0
311659	305977	18003S	PARTICIPANT	\N	EXCUSE	0
311660	305977	14299H	PARTICIPANT	\N	EXCUSE	0
311685	311684	08055A	PARTICIPANT	\N	PRESENT	0
311686	311684	19549D	PARTICIPANT	\N	PRESENT	0
311687	311684	19733B	PARTICIPANT	\N	PRESENT	0
311688	311684	19383Y	PARTICIPANT	\N	PRESENT	0
311689	311684	08024S	PARTICIPANT	\N	PRESENT	0
311690	311684	98023Q	PARTICIPANT	\N	PRESENT	0
311691	311684	11065P	PARTICIPANT	\N	PRESENT	0
311692	311684	02002K	PARTICIPANT	\N	PRESENT	0
311694	311684	14029X	PARTICIPANT	\N	PRESENT	0
311695	311684	14219Q	PARTICIPANT	\N	PRESENT	0
311696	311684	14031R	PARTICIPANT	\N	PRESENT	0
311697	311684	19637C	PARTICIPANT	\N	PRESENT	0
311698	311684	08009T	PARTICIPANT	\N	PRESENT	0
311699	311684	14169X	PARTICIPANT	\N	PRESENT	0
311700	311684	19739H	PARTICIPANT	\N	PRESENT	0
311701	311684	05012A	PARTICIPANT	\N	PRESENT	0
312951	312950	04070G	PARTICIPANT	\N	PRESENT	0
312963	312962	11072N	PARTICIPANT	\N	PRESENT	0
313426	311331	01060R	PARTICIPANT	\N	PRESENT	0
313427	311331	04044E	PARTICIPANT	\N	PRESENT	0
313428	311331	19719D	PARTICIPANT	\N	PRESENT	0
313429	311331	14231L	PARTICIPANT	\N	PRESENT	0
313430	311331	14089Y	PARTICIPANT	\N	PRESENT	0
313431	311331	19489J	PARTICIPANT	\N	PRESENT	0
313432	311331	95063L	PARTICIPANT	\N	PRESENT	0
313433	311331	08044W	PARTICIPANT	\N	PRESENT	0
313434	311331	14179A	PARTICIPANT	\N	PRESENT	0
313435	311331	14069U	PARTICIPANT	\N	PRESENT	0
313436	311331	11085T	PARTICIPANT	\N	PRESENT	0
313437	311331	04008A	PARTICIPANT	\N	PRESENT	0
313438	311331	14021P	PARTICIPANT	\N	PRESENT	0
313446	311706	19647E	PARTICIPANT	\N	PRESENT	0
313447	311706	11048N	PARTICIPANT	\N	PRESENT	0
313448	311706	19667J	PARTICIPANT	\N	PRESENT	0
313449	311706	89017R	PARTICIPANT	\N	PRESENT	0
313450	311706	08011M	PARTICIPANT	\N	PRESENT	0
313451	311706	11074Q	PRESIDENT	0	PRESENT	0
313452	311706	88008L	PARTICIPANT	\N	PRESENT	0
313453	311706	04086Q	PARTICIPANT	\N	PRESENT	0
313454	311706	07029T	PARTICIPANT	\N	PRESENT	0
313455	311706	11012A	PARTICIPANT	\N	PRESENT	0
313456	311706	14085U	PARTICIPANT	\N	PRESENT	0
313457	311706	07004J	PARTICIPANT	\N	PRESENT	0
313458	311706	14253S	PARTICIPANT	\N	PRESENT	0
313459	311706	04061F	PARTICIPANT	\N	PRESENT	0
313813	309275	14221J	PARTICIPANT	\N	PRESENT	0
322552	314151	04045F	PARTICIPANT	\N	PRESENT	0
322553	314151	14239U	PARTICIPANT	\N	PRESENT	0
322554	314151	19651A	PARTICIPANT	\N	PRESENT	0
322555	314151	19637C	PARTICIPANT	\N	PRESENT	0
322556	314151	19515S	PARTICIPANT	\N	PRESENT	0
322557	314151	19269X	PARTICIPANT	\N	PRESENT	0
322558	314151	19349W	PARTICIPANT	\N	PRESENT	0
322559	314151	14169X	PARTICIPANT	\N	PRESENT	0
322560	314151	19543W	PARTICIPANT	\N	PRESENT	0
322561	314151	19697Q	PARTICIPANT	\N	PRESENT	0
322562	314151	01057W	PARTICIPANT	\N	PRESENT	0
322563	314151	08073C	PARTICIPANT	\N	PRESENT	0
322564	314151	14039A	PARTICIPANT	\N	PRESENT	0
322565	314151	08024S	PARTICIPANT	\N	PRESENT	0
322566	314151	08021P	PARTICIPANT	\N	PRESENT	0
322567	314151	19329S	PARTICIPANT	\N	PRESENT	0
322568	314151	11072N	PARTICIPANT	\N	PRESENT	0
322569	314151	98029W	PARTICIPANT	\N	PRESENT	0
322570	314151	11083R	PARTICIPANT	\N	PRESENT	0
322571	314151	19659J	PARTICIPANT	\N	PRESENT	0
322572	314151	14055N	PARTICIPANT	\N	PRESENT	0
322573	314151	19731Y	PARTICIPANT	\N	PRESENT	0
322574	314151	89017R	PARTICIPANT	\N	PRESENT	0
322575	314151	14199E	PARTICIPANT	\N	PRESENT	0
322576	314151	11012A	PARTICIPANT	\N	PRESENT	0
322577	314151	19575F	PARTICIPANT	\N	PRESENT	0
322578	314151	08031R	PARTICIPANT	\N	PRESENT	0
322579	314151	88008L	PARTICIPANT	\N	PRESENT	0
322580	314151	14034U	PARTICIPANT	\N	PRESENT	0
322581	314151	14261S	PARTICIPANT	\N	PRESENT	0
322582	314151	19253P	PARTICIPANT	\N	PRESENT	0
322583	314151	08049C	PARTICIPANT	\N	PRESENT	0
322584	314151	19629C	PARTICIPANT	\N	PRESENT	0
322585	314151	19563B	PARTICIPANT	\N	PRESENT	0
322586	314151	19573D	PARTICIPANT	\N	PRESENT	0
322587	314151	14201E	PARTICIPANT	\N	PRESENT	0
322588	314151	14241N	PARTICIPANT	\N	PRESENT	0
322589	314151	98022P	PARTICIPANT	\N	PRESENT	0
322590	314151	11065P	PARTICIPANT	\N	PRESENT	0
322591	314151	14119M	PARTICIPANT	\N	PRESENT	0
322592	314151	11099A	PARTICIPANT	\N	PRESENT	0
322593	314151	19719D	PARTICIPANT	\N	PRESENT	0
322594	314151	11049P	PARTICIPANT	\N	PRESENT	0
322595	314151	19387D	PARTICIPANT	\N	PRESENT	0
322596	314151	19681G	PARTICIPANT	\N	PRESENT	0
322597	314151	14115H	PARTICIPANT	\N	PRESENT	0
322550	314151	95037J	PARTICIPANT	\N	PRESENT	0
322551	314151	04034C	PARTICIPANT	\N	PRESENT	0
322598	314151	19289C	PARTICIPANT	\N	PRESENT	0
322599	314151	14107H	PARTICIPANT	\N	PRESENT	0
322600	314151	08047A	PARTICIPANT	\N	PRESENT	0
322601	314151	19553Y	PARTICIPANT	\N	PRESENT	0
322602	314151	19723Y	PARTICIPANT	\N	PRESENT	0
322603	314151	14111D	PARTICIPANT	\N	PRESENT	0
322604	314151	17589D	PARTICIPANT	\N	PRESENT	0
322605	314151	14251Q	PARTICIPANT	\N	PRESENT	0
322606	314151	04057K	PARTICIPANT	\N	PRESENT	0
322607	314151	02002K	PARTICIPANT	\N	PRESENT	0
322608	314151	08018U	PARTICIPANT	\N	PRESENT	0
322609	314151	14195A	PARTICIPANT	\N	PRESENT	0
322610	314151	11064N	PARTICIPANT	\N	PRESENT	0
322611	314151	19415P	PARTICIPANT	\N	PRESENT	0
322612	314151	14093U	PARTICIPANT	\N	PRESENT	0
322613	314151	14033T	PARTICIPANT	\N	PRESENT	0
322614	314151	04059M	PARTICIPANT	\N	PRESENT	0
322615	314151	04092N	PARTICIPANT	\N	PRESENT	0
322616	314151	14159V	PARTICIPANT	\N	PRESENT	0
322617	314151	11027H	PARTICIPANT	\N	PRESENT	0
322618	314151	19693L	PARTICIPANT	\N	PRESENT	0
322619	314151	14235Q	PARTICIPANT	\N	PRESENT	0
322620	314151	19729F	PARTICIPANT	\N	PRESENT	0
322621	314151	11074Q	PARTICIPANT	\N	PRESENT	0
322622	314151	01028R	PARTICIPANT	\N	PRESENT	0
322623	314151	14213J	PARTICIPANT	\N	PRESENT	0
322624	314151	19689Q	PARTICIPANT	\N	PRESENT	0
322625	314151	14051J	PARTICIPANT	\N	PRESENT	0
322626	314151	19741B	PARTICIPANT	\N	PRESENT	0
322627	314151	08068F	PARTICIPANT	\N	PRESENT	0
322628	314151	08052W	PARTICIPANT	\N	PRESENT	0
322629	314151	14229S	PARTICIPANT	\N	PRESENT	0
322630	314151	08055A	PARTICIPANT	\N	PRESENT	0
322631	314151	14021P	PARTICIPANT	\N	PRESENT	0
322632	314151	19709B	PARTICIPANT	\N	PRESENT	0
322633	314151	08045X	PARTICIPANT	\N	PRESENT	0
322634	314151	19669L	PARTICIPANT	\N	PRESENT	0
322635	314151	19715Y	PARTICIPANT	\N	PRESENT	0
322636	314151	19599P	PARTICIPANT	\N	PRESENT	0
322637	314151	01062T	PARTICIPANT	\N	PRESENT	0
322638	314151	08060W	PARTICIPANT	\N	PRESENT	0
322639	314151	08038Y	PARTICIPANT	\N	PRESENT	0
322640	314151	80013X	PARTICIPANT	\N	PRESENT	0
322641	314151	19657G	PARTICIPANT	\N	PRESENT	0
322642	314151	11045K	PARTICIPANT	\N	PRESENT	0
322643	314151	14355X	PARTICIPANT	\N	PRESENT	0
322644	314151	19649G	PARTICIPANT	\N	PRESENT	0
322645	314151	19647E	PARTICIPANT	\N	PRESENT	0
322646	314151	19768N	PARTICIPANT	\N	PRESENT	0
322647	314151	19705W	PARTICIPANT	\N	PRESENT	0
322648	314151	14065Q	PARTICIPANT	\N	PRESENT	0
322649	314151	98050T	PARTICIPANT	\N	PRESENT	0
322650	314151	19549D	PARTICIPANT	\N	PRESENT	0
322651	314151	14061L	PARTICIPANT	\N	PRESENT	0
322652	314151	11066Q	PARTICIPANT	\N	PRESENT	0
322653	314151	08043V	PARTICIPANT	\N	PRESENT	0
322654	314151	19733B	PARTICIPANT	\N	PRESENT	0
322655	314151	11104D	PARTICIPANT	\N	PRESENT	0
322656	314151	14329V	PARTICIPANT	\N	PRESENT	0
322657	314151	14281W	PARTICIPANT	\N	PRESENT	0
322658	314151	08035V	PARTICIPANT	\N	PRESENT	0
322659	314151	19675J	PARTICIPANT	\N	PRESENT	0
322660	314151	19727D	PARTICIPANT	\N	PRESENT	0
322661	314151	19383Y	PARTICIPANT	\N	PRESENT	0
322662	314151	19531S	PARTICIPANT	\N	PRESENT	0
322663	314151	14081Q	PARTICIPANT	\N	PRESENT	0
322664	314151	14257W	PARTICIPANT	\N	PRESENT	0
322666	314151	04018C	PARTICIPANT	\N	PRESENT	0
322667	314151	19525U	PARTICIPANT	\N	PRESENT	0
322668	314151	11043H	PARTICIPANT	\N	PRESENT	0
322669	314151	08053X	PARTICIPANT	\N	PRESENT	0
322670	314151	08017T	PARTICIPANT	\N	PRESENT	0
322671	314151	14085U	PARTICIPANT	\N	PRESENT	0
322672	314151	19621T	PARTICIPANT	\N	PRESENT	0
322673	314151	14121F	PARTICIPANT	\N	PRESENT	0
322674	314151	97011G	PARTICIPANT	\N	PRESENT	0
322675	314151	08058D	PARTICIPANT	\N	PRESENT	0
322676	314151	17779H	PARTICIPANT	\N	PRESENT	0
322677	314151	19489J	PARTICIPANT	\N	PRESENT	0
322678	314151	07033P	PARTICIPANT	\N	PRESENT	0
322679	314151	19725B	PARTICIPANT	\N	PRESENT	0
322680	314151	14207L	PARTICIPANT	\N	PRESENT	0
322681	314151	19333N	PARTICIPANT	\N	PRESENT	0
322682	314151	14001X	PARTICIPANT	\N	PRESENT	0
322683	314151	14227Q	PARTICIPANT	\N	PRESENT	0
322684	314151	80027E	PARTICIPANT	\N	PRESENT	0
322685	314151	19747H	PARTICIPANT	\N	PRESENT	0
322686	314151	11041F	PARTICIPANT	\N	PRESENT	0
322687	314151	19671E	PARTICIPANT	\N	PRESENT	0
322688	314151	19631V	PARTICIPANT	\N	PRESENT	0
322689	314151	14063N	PARTICIPANT	\N	PRESENT	0
322690	314151	19527W	PARTICIPANT	\N	PRESENT	0
322691	314151	19551W	PARTICIPANT	\N	PRESENT	0
322692	314151	08034U	PARTICIPANT	\N	PRESENT	0
322693	314151	11067R	PARTICIPANT	\N	PRESENT	0
322694	314151	19591F	PARTICIPANT	\N	PRESENT	0
322695	314151	19503N	PARTICIPANT	\N	PRESENT	0
322696	314151	17583W	PARTICIPANT	\N	PRESENT	0
322697	314151	11026G	PARTICIPANT	\N	PRESENT	0
322698	314151	19413M	PARTICIPANT	\N	PRESENT	0
322699	314151	11054L	PARTICIPANT	\N	PRESENT	0
322700	314151	14069U	PARTICIPANT	\N	PRESENT	0
322701	314151	14249W	PARTICIPANT	\N	PRESENT	0
322702	314151	14053L	PARTICIPANT	\N	PRESENT	0
322703	314151	14219Q	PARTICIPANT	\N	PRESENT	0
322704	314151	04089T	PARTICIPANT	\N	PRESENT	0
322705	314151	14187A	PARTICIPANT	\N	PRESENT	0
322706	314151	14071N	PARTICIPANT	\N	PRESENT	0
322707	314151	05008E	PARTICIPANT	\N	PRESENT	0
322708	314151	11097X	PARTICIPANT	\N	PRESENT	0
322709	314151	08044W	PARTICIPANT	\N	PRESENT	0
322710	314151	19421M	PARTICIPANT	\N	PRESENT	0
322711	314151	14179A	PARTICIPANT	\N	PRESENT	0
322712	314151	04086Q	PARTICIPANT	\N	PRESENT	0
322713	314151	01034P	PARTICIPANT	\N	PRESENT	0
322714	314151	19369B	PARTICIPANT	\N	PRESENT	0
322715	314151	19691J	PARTICIPANT	\N	PRESENT	0
322716	314151	19511N	PARTICIPANT	\N	PRESENT	0
322717	314151	19611R	PARTICIPANT	\N	PRESENT	0
304830	304827	19531S	PARTICIPANT	\N	PRESENT	0
304831	304827	19699S	PARTICIPANT	\N	PRESENT	0
304832	304827	14059S	PARTICIPANT	\N	PRESENT	0
304833	304827	11072N	PARTICIPANT	\N	PRESENT	0
304834	304827	19421M	PARTICIPANT	\N	PRESENT	0
304835	304827	19749K	PARTICIPANT	\N	PRESENT	0
304836	304827	14173T	PARTICIPANT	\N	PRESENT	0
305078	304982	19719D	PARTICIPANT	\N	EXCUSE	0
305079	304982	19729F	PARTICIPANT	\N	EXCUSE	0
305521	305413	14041T	PARTICIPANT	\N	EXCUSE	0
306958	306070	14030Q	PARTICIPANT	\N	EXCUSE	0
306959	306070	14061L	PARTICIPANT	\N	EXCUSE	0
306960	306070	14201E	PARTICIPANT	\N	EXCUSE	0
307050	307049	19683J	PARTICIPANT	\N	PRESENT	0
308311	307030	16685X	PARTICIPANT	\N	PRESENT	0
308312	308227	19543W	PARTICIPANT	\N	PRESENT	0
308313	308227	14041T	PARTICIPANT	\N	PRESENT	0
308314	308227	14179A	PARTICIPANT	\N	PRESENT	0
308315	308227	14069U	PARTICIPANT	\N	PRESENT	0
308316	308227	11049P	PARTICIPANT	\N	PRESENT	0
308317	308227	04008A	PARTICIPANT	\N	PRESENT	0
308318	308227	14021P	PARTICIPANT	\N	PRESENT	0
308319	308227	14147R	PARTICIPANT	\N	PRESENT	0
308320	307030	04034C	PARTICIPANT	\N	PRESENT	0
308321	306947	19697Q	PARTICIPANT	\N	PRESENT	0
308322	306947	11067R	PARTICIPANT	\N	PRESENT	0
308323	306947	14355X	PARTICIPANT	\N	PRESENT	0
308324	306947	19569H	PARTICIPANT	\N	PRESENT	0
308325	306947	11097X	PARTICIPANT	\N	PRESENT	0
308326	306947	19415P	PARTICIPANT	\N	PRESENT	0
308327	306947	14223L	PARTICIPANT	\N	PRESENT	0
308328	306947	19703U	PARTICIPANT	\N	PRESENT	0
308329	306947	14239U	PARTICIPANT	\N	PRESENT	0
308330	306947	14281W	PARTICIPANT	\N	PRESENT	0
308331	306947	19679N	PARTICIPANT	\N	PRESENT	0
308332	306947	14042U	PARTICIPANT	\N	PRESENT	0
308333	306947	14195A	PARTICIPANT	\N	PRESENT	0
308334	306947	19367Y	PARTICIPANT	\N	PRESENT	0
308335	306947	14213J	PARTICIPANT	\N	PRESENT	0
308336	306947	19335Q	PARTICIPANT	\N	PRESENT	0
308337	306947	14217N	PARTICIPANT	\N	PRESENT	0
308338	306947	19683J	PARTICIPANT	\N	PRESENT	0
308339	306947	10006L	PARTICIPANT	\N	PRESENT	0
308340	306947	98024R	PARTICIPANT	\N	PRESENT	0
308341	306947	19521Q	PARTICIPANT	\N	PRESENT	0
308342	306947	01034P	PARTICIPANT	\N	PRESENT	0
308343	306947	04092N	PRESIDENT	0	PRESENT	0
308344	306947	08052W	PARTICIPANT	\N	PRESENT	0
308345	306947	19691J	PARTICIPANT	\N	PRESENT	0
308346	306947	19717B	PARTICIPANT	\N	PRESENT	0
308347	306947	19727D	PARTICIPANT	\N	PRESENT	0
308348	306947	14119M	PARTICIPANT	\N	PRESENT	0
308349	306947	19735D	PARTICIPANT	\N	PRESENT	0
308350	306947	19657G	PARTICIPANT	\N	PRESENT	0
308351	306947	14071N	PARTICIPANT	\N	PRESENT	0
308352	306947	19760E	PARTICIPANT	\N	PRESENT	0
308353	306947	11045K	PARTICIPANT	\N	EXCUSE	0
308354	306947	08048B	PARTICIPANT	\N	PRESENT	0
308355	306947	19575F	PARTICIPANT	\N	EXCUSE	0
308356	306947	19715Y	PARTICIPANT	\N	EXCUSE	0
308357	306947	08041T	PARTICIPANT	\N	EXCUSE	0
308358	306947	19675J	PARTICIPANT	\N	EXCUSE	0
308359	307064	19701S	PARTICIPANT	\N	PRESENT	0
308360	307064	19549D	PARTICIPANT	\N	PRESENT	0
308361	307064	19387D	PARTICIPANT	\N	PRESENT	0
308362	307064	14219Q	PARTICIPANT	\N	PRESENT	0
308363	307064	19599P	PARTICIPANT	\N	PRESENT	0
308364	307064	19637C	PARTICIPANT	\N	PRESENT	0
308365	307064	19503N	PARTICIPANT	\N	PRESENT	0
308366	307064	19681G	PARTICIPANT	\N	PRESENT	0
308367	307064	19713W	PARTICIPANT	\N	PRESENT	0
308384	307064	08055A	PARTICIPANT	\N	PRESENT	0
308369	307064	15447F	PARTICIPANT	\N	PRESENT	0
308370	307064	14029X	PARTICIPANT	\N	PRESENT	0
308371	307064	19737F	PARTICIPANT	\N	PRESENT	0
308372	307064	19659J	PARTICIPANT	\N	PRESENT	0
308374	308227	11026G	PARTICIPANT	\N	PRESENT	0
308375	306947	14026U	PARTICIPANT	\N	PRESENT	0
308376	306947	14227Q	PARTICIPANT	\N	PRESENT	0
308377	306947	11031D	PARTICIPANT	\N	PRESENT	0
308378	306947	19527W	PARTICIPANT	\N	PRESENT	0
308379	307030	95037J	PARTICIPANT	\N	PRESENT	0
308380	307030	11115U	PARTICIPANT	\N	PRESENT	0
308381	307030	95067Q	PARTICIPANT	\N	PRESENT	0
308382	307030	11041F	PARTICIPANT	\N	PRESENT	0
308383	307064	19525U	PARTICIPANT	\N	PRESENT	0
308385	307030	01062T	PARTICIPANT	\N	PRESENT	0
308386	307064	14221J	PARTICIPANT	\N	PRESENT	0
308387	307030	11080N	PARTICIPANT	\N	PRESENT	0
308388	308227	07034Q	PARTICIPANT	\N	PRESENT	0
308389	308227	19729F	PARTICIPANT	\N	PRESENT	0
308390	307064	19733B	PARTICIPANT	\N	PRESENT	0
308391	307064	19745F	PARTICIPANT	\N	PRESENT	0
308392	307064	17583W	PARTICIPANT	\N	PRESENT	0
308393	307064	19739H	PARTICIPANT	\N	PRESENT	0
308394	306947	04045F	PARTICIPANT	\N	PRESENT	0
308395	306947	19663E	PARTICIPANT	\N	PRESENT	0
308396	306947	19723Y	PARTICIPANT	\N	PRESENT	0
308397	306947	11103C	PARTICIPANT	\N	PRESENT	0
308398	307031	12041X	PARTICIPANT	\N	PRESENT	0
308399	307031	19443T	PARTICIPANT	\N	PRESENT	0
308400	307031	95030B	PARTICIPANT	\N	PRESENT	0
308401	307031	04034C	PARTICIPANT	\N	PRESENT	0
308402	307031	04040A	PARTICIPANT	\N	PRESENT	0
308403	307031	14079W	PARTICIPANT	\N	PRESENT	0
308404	307031	01058X	PARTICIPANT	\N	PRESENT	0
308405	307031	11027H	PARTICIPANT	\N	PRESENT	0
308406	307031	16685X	PARTICIPANT	\N	PRESENT	0
308407	307031	04042C	PRESIDENT	0	PRESENT	0
308408	307031	11054L	PARTICIPANT	\N	PRESENT	0
308409	307031	11066Q	PARTICIPANT	\N	PRESENT	0
308410	307031	19669L	PARTICIPANT	\N	PRESENT	0
308411	307031	95037J	PARTICIPANT	\N	PRESENT	0
308412	307031	11115U	PARTICIPANT	\N	PRESENT	0
308413	307031	14055N	PARTICIPANT	\N	PRESENT	0
308414	307031	19421M	PARTICIPANT	\N	PRESENT	0
308415	307031	19709B	PARTICIPANT	\N	PRESENT	0
308416	307031	08049C	PARTICIPANT	\N	PRESENT	0
308417	307031	14193X	PARTICIPANT	\N	PRESENT	0
308418	307031	08053X	PARTICIPANT	\N	PRESENT	0
308419	307031	97011G	PARTICIPANT	\N	PRESENT	0
308420	307031	08047A	PARTICIPANT	\N	PRESENT	0
308421	307031	14097Y	PARTICIPANT	\N	PRESENT	0
308422	307031	95067Q	PARTICIPANT	\N	PRESENT	0
308423	307031	01062T	PARTICIPANT	\N	PRESENT	0
308424	307031	11041F	PARTICIPANT	\N	PRESENT	0
308425	307031	14235Q	PARTICIPANT	\N	PRESENT	0
308426	307031	08058D	PARTICIPANT	\N	PRESENT	0
308427	307031	14028W	PARTICIPANT	\N	PRESENT	0
308428	307031	19251M	PARTICIPANT	\N	PRESENT	0
308429	307031	19721W	PARTICIPANT	\N	PRESENT	0
308430	307031	14105F	PARTICIPANT	\N	PRESENT	0
308431	307031	98018T	PARTICIPANT	\N	PRESENT	0
308432	307031	98022P	PARTICIPANT	\N	PRESENT	0
308433	307031	14267Y	PARTICIPANT	\N	PRESENT	0
308434	307031	11064N	PARTICIPANT	\N	PRESENT	0
308435	307031	98050T	PARTICIPANT	\N	PRESENT	0
308436	307031	19583F	PARTICIPANT	\N	PRESENT	0
308437	307031	14211G	PARTICIPANT	\N	PRESENT	0
308438	307031	14255U	PARTICIPANT	\N	PRESENT	0
308439	307064	11065P	PARTICIPANT	\N	PRESENT	0
308440	307064	14157T	PARTICIPANT	\N	PRESENT	0
308441	306947	14087W	PARTICIPANT	\N	PRESENT	0
308486	307133	19768N	PARTICIPANT	\N	PRESENT	0
308487	307133	19515S	PARTICIPANT	\N	PRESENT	0
308488	307133	01043Q	PARTICIPANT	\N	PRESENT	0
308489	307133	19565D	PARTICIPANT	\N	PRESENT	0
308490	307133	14357A	PARTICIPANT	\N	PRESENT	0
308491	307133	19441R	PARTICIPANT	\N	PRESENT	0
308492	307133	14081Q	PARTICIPANT	\N	PRESENT	0
308493	307133	19413M	PARTICIPANT	\N	PRESENT	0
308494	307133	80013X	PARTICIPANT	\N	PRESENT	0
308495	307133	19631V	PARTICIPANT	\N	PRESENT	0
308496	307133	08068F	PARTICIPANT	\N	PRESENT	0
308497	307133	04049K	PARTICIPANT	\N	PRESENT	0
308498	307133	19705W	PARTICIPANT	\N	PRESENT	0
308499	307133	08015R	PARTICIPANT	\N	PRESENT	0
308500	307133	14197C	PARTICIPANT	\N	PRESENT	0
308501	307133	19369B	PARTICIPANT	\N	PRESENT	0
308502	307133	19511N	PARTICIPANT	\N	PRESENT	0
308503	307133	08028W	PARTICIPANT	\N	PRESENT	0
308504	307133	19563B	PARTICIPANT	\N	PRESENT	0
308505	307133	14265W	PARTICIPANT	\N	PRESENT	0
308506	307133	14329V	PARTICIPANT	\N	PRESENT	0
308507	307133	19591F	PARTICIPANT	\N	PRESENT	0
308508	307133	14135M	PARTICIPANT	\N	PRESENT	0
308509	307133	19467C	PARTICIPANT	\N	PRESENT	0
308510	307133	14187A	PARTICIPANT	\N	PRESENT	0
308511	307133	08038Y	PARTICIPANT	\N	PRESENT	0
316225	316224	96004D	PARTICIPANT	\N	PRESENT	0
316226	316224	98050T	PARTICIPANT	\N	PRESENT	0
316258	316227	96004D	PARTICIPANT	\N	PRESENT	0
316259	316227	98050T	PARTICIPANT	\N	PRESENT	0
316260	316227	19333N	PARTICIPANT	\N	PRESENT	0
316261	316227	14331P	PARTICIPANT	\N	PRESENT	0
316262	316227	01058X	PARTICIPANT	\N	PRESENT	0
316263	316227	14001X	PARTICIPANT	\N	PRESENT	0
316265	316227	01057W	PARTICIPANT	\N	PRESENT	0
316266	316227	98022P	PARTICIPANT	\N	PRESENT	0
316267	316227	19569H	PARTICIPANT	\N	PRESENT	0
316268	316227	19573D	PARTICIPANT	\N	PRESENT	0
316270	316227	14205J	PARTICIPANT	\N	PRESENT	0
330965	330964	14255U	PARTICIPANT	\N	PRESENT	0
330966	330964	18083K	PARTICIPANT	\N	PRESENT	0
330967	330964	14151M	PARTICIPANT	\N	PRESENT	0
330968	330964	04049K	PARTICIPANT	\N	PRESENT	0
330969	330964	08017T	PARTICIPANT	\N	PRESENT	0
330970	330964	14265W	PARTICIPANT	\N	PRESENT	0
330971	330964	04070G	PARTICIPANT	\N	PRESENT	0
330972	330964	05012A	PARTICIPANT	\N	PRESENT	0
330984	330983	04038G	PARTICIPANT	\N	PRESENT	0
332238	321358	19551W	PARTICIPANT	\N	PRESENT	0
332239	321358	14069U	PARTICIPANT	\N	PRESENT	0
332240	321358	19441R	PARTICIPANT	\N	PRESENT	0
332241	321358	19399H	PARTICIPANT	\N	PRESENT	0
332242	321358	19713W	PARTICIPANT	\N	PRESENT	0
332243	321358	08019V	PARTICIPANT	\N	PRESENT	0
332244	321358	14029X	PARTICIPANT	\N	PRESENT	0
332245	321358	14021P	PARTICIPANT	\N	PRESENT	0
332246	321358	19758L	PARTICIPANT	\N	PRESENT	0
332247	321358	14235Q	PARTICIPANT	\N	PRESENT	0
332248	321358	08034U	PARTICIPANT	\N	PRESENT	0
332249	321358	08010L	PARTICIPANT	\N	PRESENT	0
332250	321358	11104D	PARTICIPANT	\N	PRESENT	0
332251	321358	14073Q	PARTICIPANT	\N	PRESENT	0
332252	321358	19289C	PARTICIPANT	\N	PRESENT	0
332307	321359	11053K	PARTICIPANT	\N	PRESENT	0
332308	321359	11048N	PARTICIPANT	\N	PRESENT	0
332309	321359	19347U	PARTICIPANT	\N	PRESENT	0
332310	321359	14207L	PARTICIPANT	\N	PRESENT	0
332311	321359	19631V	PARTICIPANT	\N	PRESENT	0
332312	321359	19549D	PARTICIPANT	\N	PRESENT	0
332313	321359	80013X	PARTICIPANT	\N	PRESENT	0
332314	321359	19503N	PARTICIPANT	\N	PRESENT	0
332315	321359	19599P	PARTICIPANT	\N	PRESENT	0
332316	321359	19551W	PARTICIPANT	\N	PRESENT	0
332317	321359	19637C	PARTICIPANT	\N	PRESENT	0
332318	321359	08024S	PARTICIPANT	\N	PRESENT	0
332319	321359	14093U	PARTICIPANT	\N	PRESENT	0
332320	321359	14073Q	PARTICIPANT	\N	PRESENT	0
332321	321359	07004J	PARTICIPANT	\N	PRESENT	0
332322	321359	19319Q	PARTICIPANT	\N	PRESENT	0
332323	321359	14219Q	PARTICIPANT	\N	PRESENT	0
332324	321359	08009T	PARTICIPANT	\N	PRESENT	0
332325	321359	19611R	PARTICIPANT	\N	PRESENT	0
332326	321359	08019V	PARTICIPANT	\N	PRESENT	0
332327	321359	19399H	PARTICIPANT	\N	PRESENT	0
332328	321359	14033T	PARTICIPANT	\N	PRESENT	0
332329	321359	19667J	PARTICIPANT	\N	PRESENT	0
332330	321359	14157T	PARTICIPANT	\N	PRESENT	0
332331	321359	11043H	PARTICIPANT	\N	PRESENT	0
332332	321359	14225N	PARTICIPANT	\N	PRESENT	0
332333	321359	08034U	PARTICIPANT	\N	PRESENT	0
332334	321359	99004R	PARTICIPANT	\N	PRESENT	0
332335	321359	08044W	PARTICIPANT	\N	PRESENT	0
332336	321359	19681G	PARTICIPANT	\N	PRESENT	0
332337	321359	19717B	PARTICIPANT	\N	PRESENT	0
332338	321359	19289C	PARTICIPANT	\N	PRESENT	0
332339	321359	08051V	PARTICIPANT	\N	PRESENT	0
332340	321359	11104D	PARTICIPANT	\N	PRESENT	0
332341	321359	19349W	PARTICIPANT	\N	PRESENT	0
332342	321359	19758L	PARTICIPANT	\N	PRESENT	0
332343	321359	04070G	PARTICIPANT	\N	PRESENT	0
332344	321359	14235Q	PARTICIPANT	\N	PRESENT	0
332345	321359	14229S	PARTICIPANT	\N	PRESENT	0
332346	321359	14031R	PARTICIPANT	\N	PRESENT	0
332347	321359	17637T	PARTICIPANT	\N	PRESENT	0
332349	321359	19643A	PARTICIPANT	\N	PRESENT	0
332350	321359	19573D	PARTICIPANT	\N	PRESENT	0
332351	321359	14121F	PARTICIPANT	\N	PRESENT	0
332352	321359	14021P	PARTICIPANT	\N	PRESENT	0
332353	321359	14253S	PARTICIPANT	\N	PRESENT	0
332354	321359	11085T	PARTICIPANT	\N	PRESENT	0
332355	321359	14241N	PARTICIPANT	\N	PRESENT	0
332356	321359	08012N	PARTICIPANT	\N	PRESENT	0
332357	321359	19647E	PARTICIPANT	\N	PRESENT	0
332358	321359	11012A	PARTICIPANT	\N	PRESENT	0
332364	331358	04044E	PARTICIPANT	\N	EXCUSE	0
332305	321359	11072N	PARTICIPANT	\N	PRESENT	0
332306	321359	11074Q	PARTICIPANT	\N	PRESENT	0
332365	331925	19647E	PARTICIPANT	\N	PRESENT	0
332366	331925	19711U	PARTICIPANT	\N	PRESENT	0
332367	331925	12016W	PARTICIPANT	\N	PRESENT	0
332368	331925	89017R	PARTICIPANT	\N	PRESENT	0
332369	331925	11074Q	PRESIDENT	0	PRESENT	0
332370	331925	11070L	PARTICIPANT	\N	PRESENT	0
332371	331925	88008L	PARTICIPANT	\N	PRESENT	0
332372	331925	14225N	PARTICIPANT	\N	PRESENT	0
332373	331925	04086Q	PARTICIPANT	\N	PRESENT	0
332374	331925	11012A	PARTICIPANT	\N	PRESENT	0
332375	331925	14277B	PARTICIPANT	\N	PRESENT	0
332376	331925	08073C	PARTICIPANT	\N	PRESENT	0
332377	331925	14253S	PARTICIPANT	\N	PRESENT	0
332378	331925	99004R	PARTICIPANT	\N	PRESENT	0
332379	331925	07029T	PARTICIPANT	\N	EXCUSE	0
332380	321361	86034E	PARTICIPANT	\N	PRESENT	0
332381	321361	12041X	PARTICIPANT	\N	PRESENT	0
332382	321361	04085P	PARTICIPANT	\N	PRESENT	0
332383	321361	14235Q	PARTICIPANT	\N	PRESENT	0
332384	321361	12016W	PARTICIPANT	\N	PRESENT	0
332385	321361	19295A	PARTICIPANT	\N	PRESENT	0
332386	321361	11033F	PARTICIPANT	\N	PRESENT	0
332387	321361	14039A	PARTICIPANT	\N	PRESENT	0
332388	321361	19717B	PARTICIPANT	\N	PRESENT	0
332389	321361	14261S	PARTICIPANT	\N	PRESENT	0
332390	321361	19691J	PARTICIPANT	\N	PRESENT	0
332391	321361	08073C	PARTICIPANT	\N	PRESENT	0
332392	321361	14277B	PARTICIPANT	\N	PRESENT	0
332393	321361	11072N	PARTICIPANT	\N	PRESENT	0
332394	321361	08019V	PARTICIPANT	\N	PRESENT	0
332395	321361	11074Q	PARTICIPANT	\N	PRESENT	0
332396	321361	19657G	PARTICIPANT	\N	PRESENT	0
332397	321361	19711U	PARTICIPANT	\N	PRESENT	0
332398	321361	99004R	PARTICIPANT	\N	PRESENT	0
332399	321361	04086Q	PARTICIPANT	\N	PRESENT	0
332400	321361	19583F	PARTICIPANT	\N	PRESENT	0
332401	321361	19631V	PARTICIPANT	\N	PRESENT	0
332402	321361	19695N	PARTICIPANT	\N	PRESENT	0
332403	321361	19715Y	PARTICIPANT	\N	PRESENT	0
332404	321361	19319Q	PARTICIPANT	\N	PRESENT	0
332405	321361	07004J	PARTICIPANT	\N	PRESENT	0
332406	321361	98050T	PARTICIPANT	\N	PRESENT	0
332407	321361	11070L	PARTICIPANT	\N	PRESENT	0
332408	321361	19329S	PARTICIPANT	\N	PRESENT	0
332409	321361	14159V	PARTICIPANT	\N	PRESENT	0
332410	321361	19647E	PARTICIPANT	\N	PRESENT	0
332411	321361	19689Q	PARTICIPANT	\N	PRESENT	0
332412	321361	04042C	PARTICIPANT	\N	PRESENT	0
332413	321361	88008L	PARTICIPANT	\N	PRESENT	0
332414	321361	19651A	PARTICIPANT	\N	PRESENT	0
332415	321361	14225N	PARTICIPANT	\N	PRESENT	0
332416	321361	11012A	PARTICIPANT	\N	PRESENT	0
332417	321361	11110B	PARTICIPANT	\N	PRESENT	0
332418	321361	14215L	PARTICIPANT	\N	PRESENT	0
332419	321361	80013X	PARTICIPANT	\N	PRESENT	0
332420	321361	14331P	PARTICIPANT	\N	PRESENT	0
332421	321361	14028W	PARTICIPANT	\N	PRESENT	0
332422	321361	11041F	PARTICIPANT	\N	PRESENT	0
332423	321361	98022P	PARTICIPANT	\N	PRESENT	0
332425	321361	01062T	PARTICIPANT	\N	PRESENT	0
332426	321361	19443T	PARTICIPANT	\N	PRESENT	0
332427	321361	19669L	PARTICIPANT	\N	PRESENT	0
332428	321361	11109J	PARTICIPANT	\N	PRESENT	0
332429	321361	04035D	PARTICIPANT	\N	PRESENT	0
332430	321361	89017R	PARTICIPANT	\N	PRESENT	0
332432	332431	04049K	PARTICIPANT	\N	PRESENT	0
332434	332433	89017R	PARTICIPANT	\N	PRESENT	0
332435	332433	04049K	PARTICIPANT	\N	PRESENT	0
332437	332436	04049K	PARTICIPANT	\N	PRESENT	0
332439	332438	04049K	PARTICIPANT	\N	PRESENT	0
332441	332440	14083S	PARTICIPANT	\N	PRESENT	0
332442	332436	14083S	PARTICIPANT	\N	PRESENT	0
332444	332443	04049K	PARTICIPANT	\N	PRESENT	0
303134	303133	11099A	PARTICIPANT	\N	PRESENT	0
304243	304242	11053K	PARTICIPANT	\N	PRESENT	0
304244	304242	14159V	PARTICIPANT	\N	PRESENT	0
304245	304242	05012A	PARTICIPANT	\N	PRESENT	0
306015	306009	86034E	PARTICIPANT	\N	PRESENT	0
306021	305572	08048B	PARTICIPANT	\N	PRESENT	0
306022	305572	19715Y	PARTICIPANT	\N	EXCUSE	0
306023	305572	08041T	PARTICIPANT	\N	EXCUSE	0
306024	305572	19727D	PARTICIPANT	\N	PRESENT	0
306025	305572	04092N	PRESIDENT	0	PRESENT	0
306026	305572	19569H	PARTICIPANT	\N	PRESENT	0
306027	305572	14195A	PARTICIPANT	\N	PRESENT	0
306028	305572	19335Q	PARTICIPANT	\N	PRESENT	0
306029	305572	19683J	PARTICIPANT	\N	PRESENT	0
306030	305572	14227Q	PARTICIPANT	\N	PRESENT	0
306031	305572	19697Q	PARTICIPANT	\N	PRESENT	0
306032	305572	19575F	PARTICIPANT	\N	PRESENT	0
306033	305572	19717B	PARTICIPANT	\N	PRESENT	0
306034	305572	14261S	PARTICIPANT	\N	PRESENT	0
306036	305572	14355X	PARTICIPANT	\N	PRESENT	0
306037	305572	95062K	PARTICIPANT	\N	PRESENT	0
306038	305572	19415P	PARTICIPANT	\N	PRESENT	0
306039	305572	19691J	PARTICIPANT	\N	PRESENT	0
306040	305572	04045F	PARTICIPANT	\N	PRESENT	0
306041	305572	14239U	PARTICIPANT	\N	PRESENT	0
306042	305572	19553Y	PARTICIPANT	\N	PRESENT	0
306043	305572	11103C	PARTICIPANT	\N	PRESENT	0
306044	305572	14213J	PARTICIPANT	\N	PRESENT	0
306045	305572	19367Y	PARTICIPANT	\N	PRESENT	0
306057	305572	14223L	PARTICIPANT	\N	PRESENT	0
306047	305572	14217N	PARTICIPANT	\N	PRESENT	0
306048	305572	14281W	PARTICIPANT	\N	PRESENT	0
306049	305572	14087W	PARTICIPANT	\N	PRESENT	0
306050	305572	19723Y	PARTICIPANT	\N	PRESENT	0
306051	305572	14119M	PARTICIPANT	\N	PRESENT	0
306052	305572	11067R	PARTICIPANT	\N	PRESENT	0
306053	305572	11097X	PARTICIPANT	\N	PRESENT	0
306054	305572	11031D	PARTICIPANT	\N	PRESENT	0
306055	305572	08052W	PARTICIPANT	\N	PRESENT	0
306056	305572	19760E	PARTICIPANT	\N	PRESENT	0
306061	305572	14042U	PARTICIPANT	\N	PRESENT	0
306062	305572	14026U	PARTICIPANT	\N	PRESENT	0
306063	305572	17779H	PARTICIPANT	\N	PRESENT	0
306064	305572	14237S	PARTICIPANT	\N	PRESENT	0
306065	305572	19527W	PARTICIPANT	\N	PRESENT	0
306066	305572	01034P	PARTICIPANT	\N	PRESENT	0
306067	305572	11077T	PARTICIPANT	\N	PRESENT	0
306068	305572	19521Q	PARTICIPANT	\N	PRESENT	0
306839	306020	14327T	PARTICIPANT	\N	PRESENT	0
306840	306020	04092N	PARTICIPANT	\N	PRESENT	0
306841	306020	14221J	PARTICIPANT	\N	PRESENT	0
306842	306020	14169X	PARTICIPANT	\N	PRESENT	0
306843	306020	11099A	PARTICIPANT	\N	PRESENT	0
306844	306020	95037J	PARTICIPANT	\N	PRESENT	0
306845	306020	04049K	PARTICIPANT	\N	PRESENT	0
306846	306020	08015R	PARTICIPANT	\N	PRESENT	0
306847	306020	19503N	PARTICIPANT	\N	PRESENT	0
306848	306020	08049C	PARTICIPANT	\N	PRESENT	0
306849	306020	19347U	PARTICIPANT	\N	PRESENT	0
306850	306020	14109K	PARTICIPANT	\N	PRESENT	0
306851	306020	14195A	PARTICIPANT	\N	PRESENT	0
306852	306020	14213J	PRESIDENT	0	PRESENT	0
306853	306020	19683J	PARTICIPANT	\N	PRESENT	0
306854	306020	98024R	PARTICIPANT	\N	PRESENT	0
306855	306020	08039A	PARTICIPANT	\N	PRESENT	0
306856	306020	04045F	PARTICIPANT	\N	PRESENT	0
308570	308569	14115H	PARTICIPANT	\N	PRESENT	0
308571	308569	04040A	PARTICIPANT	\N	PRESENT	0
308572	308569	19643A	PARTICIPANT	\N	PRESENT	0
308573	308569	14041T	PARTICIPANT	\N	PRESENT	0
308574	308569	10006L	PARTICIPANT	\N	PRESENT	0
308575	308569	97011G	PARTICIPANT	\N	PRESENT	0
308590	308569	14179A	PARTICIPANT	\N	PRESENT	0
308591	308569	14223L	PARTICIPANT	\N	PRESENT	0
308592	308569	14071N	PARTICIPANT	\N	PRESENT	0
308593	308569	07034Q	PARTICIPANT	\N	PRESENT	0
308594	308569	01058X	PARTICIPANT	\N	PRESENT	0
308595	308569	14147R	PARTICIPANT	\N	PRESENT	0
308596	308569	95067Q	PARTICIPANT	\N	PRESENT	0
308597	308569	04033B	PARTICIPANT	\N	PRESENT	0
308598	308569	14217N	PARTICIPANT	\N	PRESENT	0
308600	308599	14041T	PARTICIPANT	\N	PRESENT	0
308601	308599	95067Q	PARTICIPANT	\N	PRESENT	0
308602	308599	04033B	PARTICIPANT	\N	PRESENT	0
308604	308603	19543W	PARTICIPANT	\N	PRESENT	0
308605	308603	97011G	PARTICIPANT	\N	PRESENT	0
308606	308603	01058X	PARTICIPANT	\N	PRESENT	0
308607	308603	95067Q	PARTICIPANT	\N	PRESENT	0
311730	311729	19699S	PARTICIPANT	\N	PRESENT	0
311732	311731	04070G	PARTICIPANT	\N	PRESENT	0
311733	311731	04059M	PARTICIPANT	\N	PRESENT	0
311734	311731	19693L	PARTICIPANT	\N	PRESENT	0
311735	311731	14123H	PARTICIPANT	\N	PRESENT	0
311736	311731	14073Q	PARTICIPANT	\N	PRESENT	0
311737	311731	14039A	PARTICIPANT	\N	PRESENT	0
312310	312295	19415P	PARTICIPANT	\N	PRESENT	0
312312	312295	19527W	PARTICIPANT	\N	PRESENT	0
312520	312483	19415P	PARTICIPANT	\N	PRESENT	0
312556	312555	19415P	PARTICIPANT	\N	PRESENT	0
313854	309276	04085P	PARTICIPANT	\N	PRESENT	0
313855	309276	01028R	PARTICIPANT	\N	PRESENT	0
313856	309276	01024M	PARTICIPANT	\N	PRESENT	0
313857	309276	04047H	PARTICIPANT	\N	PRESENT	0
313858	309276	19583F	PARTICIPANT	\N	PRESENT	0
313859	309276	19737F	PARTICIPANT	\N	PRESENT	0
313860	309276	14231L	PARTICIPANT	\N	PRESENT	0
313861	309276	14215L	PARTICIPANT	\N	PRESENT	0
313862	309276	14061L	PARTICIPANT	\N	PRESENT	0
313863	309276	14357A	PARTICIPANT	\N	PRESENT	0
313864	309276	08015R	PARTICIPANT	\N	PRESENT	0
313865	309276	11097X	PARTICIPANT	\N	PRESENT	0
313866	309276	19447X	PARTICIPANT	\N	PRESENT	0
313867	309276	14069U	PARTICIPANT	\N	PRESENT	0
313868	309276	19253P	PARTICIPANT	\N	PRESENT	0
313869	309276	19629C	PARTICIPANT	\N	PRESENT	0
313870	309276	17637T	PARTICIPANT	\N	PRESENT	0
313871	309276	14265W	PARTICIPANT	\N	PRESENT	0
313852	309276	11072N	PARTICIPANT	\N	PRESENT	0
313853	309276	11033F	PARTICIPANT	\N	PRESENT	0
313872	309276	07029T	PARTICIPANT	\N	PRESENT	0
313873	309276	95063L	PARTICIPANT	\N	PRESENT	0
313874	309276	14030Q	PARTICIPANT	\N	PRESENT	0
313875	309276	18083K	PARTICIPANT	\N	PRESENT	0
314076	314075	11053K	PARTICIPANT	\N	PRESENT	0
314077	314075	14159V	PARTICIPANT	\N	PRESENT	0
314078	314075	05012A	PARTICIPANT	\N	PRESENT	0
314080	314079	11041F	PARTICIPANT	\N	PRESENT	0
314082	314081	98029W	PARTICIPANT	\N	PRESENT	0
314332	309279	19659J	PARTICIPANT	\N	PRESENT	0
314085	314083	98029W	PARTICIPANT	\N	PRESENT	0
314086	314083	98050T	PARTICIPANT	\N	PRESENT	0
314309	309279	04044E	PARTICIPANT	\N	PRESENT	0
314310	313990	98035U	PARTICIPANT	\N	PRESENT	0
314311	313990	14111D	PARTICIPANT	\N	PRESENT	0
314312	313990	07034Q	PARTICIPANT	\N	PRESENT	0
314313	313990	08045X	PARTICIPANT	\N	PRESENT	0
314314	313990	19253P	PARTICIPANT	\N	PRESENT	0
314315	313990	01024M	PARTICIPANT	\N	PRESENT	0
314316	313990	19543W	PARTICIPANT	\N	PRESENT	0
314317	313990	04038G	PARTICIPANT	\N	PRESENT	0
314318	313990	05008E	PRESIDENT	0	PRESENT	0
314319	313990	19447X	PARTICIPANT	\N	PRESENT	0
314320	313990	19489J	PARTICIPANT	\N	PRESENT	0
314321	313990	14041T	PARTICIPANT	\N	PRESENT	0
314322	313990	14147R	PARTICIPANT	\N	PRESENT	0
314323	313990	14151M	PARTICIPANT	\N	PRESENT	0
314324	313990	14069U	PARTICIPANT	\N	PRESENT	0
314325	313990	14215L	PARTICIPANT	\N	PRESENT	0
314326	313990	19762G	PARTICIPANT	\N	PRESENT	0
314327	313990	14179A	PARTICIPANT	\N	PRESENT	0
314328	313990	04044E	PARTICIPANT	\N	PRESENT	0
314329	313990	19729F	PARTICIPANT	\N	EXCUSE	0
314330	313990	14065Q	PARTICIPANT	\N	EXCUSE	0
314331	313990	04008A	PARTICIPANT	\N	EXCUSE	0
314333	309279	14213J	PARTICIPANT	\N	PRESENT	0
314334	309279	14157T	PARTICIPANT	\N	PRESENT	0
314335	309279	14179A	PARTICIPANT	\N	PRESENT	0
314336	309279	01060R	PARTICIPANT	\N	PRESENT	0
314337	309279	19543W	PARTICIPANT	\N	PRESENT	0
314338	309279	14265W	PARTICIPANT	\N	PRESENT	0
314339	309279	14030Q	PARTICIPANT	\N	PRESENT	0
314340	309279	14135M	PARTICIPANT	\N	PRESENT	0
314341	309279	14193X	PARTICIPANT	\N	PRESENT	0
314342	309279	11040E	PARTICIPANT	\N	PRESENT	0
314343	309279	14147R	PARTICIPANT	\N	PRESENT	0
314345	309279	19621T	PARTICIPANT	\N	PRESENT	0
314346	309279	08009T	PARTICIPANT	\N	PRESENT	0
314347	309279	19629C	PARTICIPANT	\N	PRESENT	0
314349	309279	19253P	PARTICIPANT	\N	PRESENT	0
322718	314151	11053K	PARTICIPANT	\N	PRESENT	0
322719	314151	08009T	PARTICIPANT	\N	PRESENT	0
322720	314151	19737F	PARTICIPANT	\N	PRESENT	0
322721	314151	19699S	PARTICIPANT	\N	PRESENT	0
322722	314151	14205J	PARTICIPANT	\N	PRESENT	0
322723	314151	19721W	PARTICIPANT	\N	PRESENT	0
322724	314151	19569H	PARTICIPANT	\N	PRESENT	0
322725	314151	08056B	PARTICIPANT	\N	PRESENT	0
322726	314151	19735D	PARTICIPANT	\N	PRESENT	0
322727	314151	16685X	PARTICIPANT	\N	PRESENT	0
322728	314151	04047H	PARTICIPANT	\N	PRESENT	0
322729	314151	19745F	PARTICIPANT	\N	PRESENT	0
322730	314151	14109K	PARTICIPANT	\N	PRESENT	0
322731	314151	19479G	PARTICIPANT	\N	PRESENT	0
322732	314151	19441R	PARTICIPANT	\N	PRESENT	0
322733	314151	14277B	PARTICIPANT	\N	PRESENT	0
322734	314151	14275Y	PARTICIPANT	\N	PRESENT	0
322735	314151	19663E	PARTICIPANT	\N	PRESENT	0
322736	314151	14267Y	PARTICIPANT	\N	PRESENT	0
322737	314151	14221J	PARTICIPANT	\N	PRESENT	0
322738	314151	04071H	PARTICIPANT	\N	PRESENT	0
322739	314151	19739H	PARTICIPANT	\N	PRESENT	0
322740	314151	19335Q	PARTICIPANT	\N	PRESENT	0
322741	314151	14073Q	PARTICIPANT	\N	PRESENT	0
322742	314151	14083S	PARTICIPANT	\N	PRESENT	0
322743	314151	19749K	PARTICIPANT	\N	PRESENT	0
322744	314151	11110B	PARTICIPANT	\N	PRESENT	0
322745	314151	11070L	PARTICIPANT	\N	PRESENT	0
322746	314151	11085T	PARTICIPANT	\N	PRESENT	0
322747	314151	07004J	PARTICIPANT	\N	PRESENT	0
322748	314151	19577H	PARTICIPANT	\N	PRESENT	0
322749	314151	04040A	PARTICIPANT	\N	PRESENT	0
322750	314151	04070G	PARTICIPANT	\N	PRESENT	0
322751	314151	01025N	PARTICIPANT	\N	PRESENT	0
322752	314151	01024M	PARTICIPANT	\N	PRESENT	0
322753	314151	14327T	PARTICIPANT	\N	PRESENT	0
322754	314151	14030Q	PARTICIPANT	\N	PRESENT	0
322755	314151	01043Q	PARTICIPANT	\N	PRESENT	0
322756	314151	14123H	PARTICIPANT	\N	PRESENT	0
322757	314151	12016W	PARTICIPANT	\N	PRESENT	0
322758	314151	19295A	PARTICIPANT	\N	PRESENT	0
322760	314151	19683J	PARTICIPANT	\N	PRESENT	0
322768	320710	08009T	PRESIDENT	0	PRESENT	0
322769	320710	19701S	PARTICIPANT	\N	EXCUSE	0
322770	320710	96004D	PARTICIPANT	\N	EXCUSE	0
322771	320710	19685L	PARTICIPANT	\N	EXCUSE	0
323079	314149	04086Q	PARTICIPANT	\N	PRESENT	0
322779	314151	14237S	PARTICIPANT	\N	PRESENT	0
322780	314151	14215L	PARTICIPANT	\N	PRESENT	0
323080	314149	04092N	PARTICIPANT	\N	PRESENT	0
323081	314149	01034P	PARTICIPANT	\N	PRESENT	0
323082	314149	11031D	PARTICIPANT	\N	PRESENT	0
323083	314149	11077T	PARTICIPANT	\N	PRESENT	0
323084	314149	19715Y	PARTICIPANT	\N	PRESENT	0
323085	314149	14227Q	PARTICIPANT	\N	PRESENT	0
323086	314149	14121F	PARTICIPANT	\N	PRESENT	0
323087	314149	04045F	PARTICIPANT	\N	PRESENT	0
323088	314149	95062K	PARTICIPANT	\N	PRESENT	0
323089	314149	08020N	PARTICIPANT	\N	PRESENT	0
323090	314149	04033B	PARTICIPANT	\N	PRESENT	0
323091	314149	19515S	PARTICIPANT	\N	PRESENT	0
323092	320710	19333N	PARTICIPANT	\N	PRESENT	0
323093	320710	17583W	PARTICIPANT	\N	PRESENT	0
323094	320710	19387D	PARTICIPANT	\N	PRESENT	0
323095	320710	14221J	PARTICIPANT	\N	PRESENT	0
323096	320710	08055A	PARTICIPANT	\N	PRESENT	0
323097	320710	19599P	PARTICIPANT	\N	PRESENT	0
323098	320710	19289C	PARTICIPANT	\N	PRESENT	0
323099	320710	14191V	PARTICIPANT	\N	PRESENT	0
323100	320710	14169X	PARTICIPANT	\N	PRESENT	0
323101	320710	14237S	PARTICIPANT	\N	PRESENT	0
323102	320710	14051J	PARTICIPANT	\N	PRESENT	0
323103	320710	14029X	PARTICIPANT	\N	PRESENT	0
323104	320710	08060W	PARTICIPANT	\N	PRESENT	0
323105	320710	19503N	PARTICIPANT	\N	PRESENT	0
323106	320710	19737F	PARTICIPANT	\N	PRESENT	0
323107	320710	19745F	PARTICIPANT	\N	PRESENT	0
323108	320710	98023Q	PARTICIPANT	\N	PRESENT	0
323109	320710	11065P	PARTICIPANT	\N	PRESENT	0
323110	320710	19525U	PARTICIPANT	\N	PRESENT	0
323111	314149	14033T	PARTICIPANT	\N	PRESENT	0
323112	320710	14031R	PARTICIPANT	\N	PRESENT	0
323113	320710	19549D	PARTICIPANT	\N	PRESENT	0
323114	314149	19669L	PARTICIPANT	\N	PRESENT	0
323115	314149	08047A	PARTICIPANT	\N	PRESENT	0
323116	314149	08052W	PARTICIPANT	\N	PRESENT	0
323117	314149	19329S	PARTICIPANT	\N	PRESENT	0
323118	314149	14026U	PARTICIPANT	\N	PRESENT	0
323119	314149	08073C	PARTICIPANT	\N	PRESENT	0
323120	314149	19659J	PARTICIPANT	\N	PRESENT	0
323121	314149	19683J	PARTICIPANT	\N	PRESENT	0
323122	314149	08019V	PARTICIPANT	\N	PRESENT	0
323123	314149	10006L	PARTICIPANT	\N	PRESENT	0
323124	314149	19727D	PARTICIPANT	\N	PRESENT	0
323125	314149	19527W	PARTICIPANT	\N	PRESENT	0
323126	320710	14219Q	PARTICIPANT	\N	PRESENT	0
323127	320710	19637C	PARTICIPANT	\N	PRESENT	0
323128	320710	14157T	PARTICIPANT	\N	PRESENT	0
323129	314149	14109K	PARTICIPANT	\N	PRESENT	0
323130	314149	19651A	PARTICIPANT	\N	PRESENT	0
323131	314149	14195A	PARTICIPANT	\N	PRESENT	0
323132	314149	17589D	PARTICIPANT	\N	PRESENT	0
323133	314149	02002K	PARTICIPANT	\N	PRESENT	0
323134	314149	14261S	PARTICIPANT	\N	PRESENT	0
323135	314149	19553Y	PARTICIPANT	\N	PRESENT	0
323136	314149	19253P	PARTICIPANT	\N	PRESENT	0
323137	314149	01025N	PARTICIPANT	\N	PRESENT	0
323138	320710	19347U	PARTICIPANT	\N	PRESENT	0
323139	320710	04097T	PARTICIPANT	\N	PRESENT	0
323140	320710	19739H	PARTICIPANT	\N	PRESENT	0
323141	314149	11085T	PARTICIPANT	\N	PRESENT	0
323142	314149	14073Q	PARTICIPANT	\N	PRESENT	0
323143	314149	19421M	PARTICIPANT	\N	PRESENT	0
323144	314149	19591F	PARTICIPANT	\N	PRESENT	0
323145	314149	19687N	PARTICIPANT	\N	PRESENT	0
323146	314149	19758L	PARTICIPANT	\N	PRESENT	0
323147	314149	19760E	PARTICIPANT	\N	PRESENT	0
323148	314149	11033F	PARTICIPANT	\N	PRESENT	0
323149	314149	19697Q	PARTICIPANT	\N	PRESENT	0
323150	320710	19383Y	PARTICIPANT	\N	PRESENT	0
323151	320710	05012A	PARTICIPANT	\N	PRESENT	0
323152	322289	19593H	PARTICIPANT	\N	PRESENT	0
323153	322289	04070G	PRESIDENT	0	PRESENT	0
323154	322289	04057K	PARTICIPANT	\N	PRESENT	0
323155	322289	08035V	PARTICIPANT	\N	PRESENT	0
323156	322289	08043V	PARTICIPANT	\N	PRESENT	0
323157	322289	87003B	PARTICIPANT	\N	PRESENT	0
323158	322289	14229S	PARTICIPANT	\N	PRESENT	0
323159	322289	14030Q	PARTICIPANT	\N	PRESENT	0
323160	322289	14241N	PARTICIPANT	\N	PRESENT	0
323161	322289	08020N	PARTICIPANT	\N	PRESENT	0
323162	322289	14039A	PARTICIPANT	\N	PRESENT	0
323163	322289	14107H	PARTICIPANT	\N	PRESENT	0
323164	322289	19735D	PARTICIPANT	\N	PRESENT	0
323165	322289	14063N	PARTICIPANT	\N	PRESENT	0
323166	322289	14123H	PARTICIPANT	\N	PRESENT	0
323167	322289	11104D	PARTICIPANT	\N	PRESENT	0
323168	322289	19749K	PARTICIPANT	\N	PRESENT	0
323169	322289	14249W	PARTICIPANT	\N	PRESENT	0
323170	322289	08031R	PARTICIPANT	\N	PRESENT	0
323171	322289	19621T	PARTICIPANT	\N	PRESENT	0
323172	322289	19399H	PARTICIPANT	\N	EXCUSE	0
323173	314149	19719D	PARTICIPANT	\N	PRESENT	0
323174	314149	14239U	PARTICIPANT	\N	PRESENT	0
323175	314149	98024R	PARTICIPANT	\N	PRESENT	0
323176	314149	04018C	PARTICIPANT	\N	PRESENT	0
323177	314149	19762G	PARTICIPANT	\N	PRESENT	0
323178	314149	14105F	PARTICIPANT	\N	PRESENT	0
323179	314149	11103C	PARTICIPANT	\N	PRESENT	0
323180	314149	19675J	PARTICIPANT	\N	PRESENT	0
323181	314149	95041E	PARTICIPANT	\N	PRESENT	0
323182	314149	17779H	PARTICIPANT	\N	PRESENT	0
323183	314149	12016W	PARTICIPANT	\N	PRESENT	0
323184	314149	14223L	PARTICIPANT	\N	PRESENT	0
323185	314149	11097X	PARTICIPANT	\N	PRESENT	0
323186	314149	99004R	PARTICIPANT	\N	PRESENT	0
323187	314149	14087W	PARTICIPANT	\N	PRESENT	0
323188	314149	19415P	PARTICIPANT	\N	PRESENT	0
323189	314149	14071N	PARTICIPANT	\N	PRESENT	0
323190	314149	19575F	PARTICIPANT	\N	PRESENT	0
323191	320710	02002K	PARTICIPANT	\N	PRESENT	0
323192	314149	14213J	PARTICIPANT	\N	PRESENT	0
323193	314149	19679N	PARTICIPANT	\N	PRESENT	0
323194	314149	19443T	PARTICIPANT	\N	PRESENT	0
323195	314149	19703U	PARTICIPANT	\N	PRESENT	0
323196	314149	14327T	PARTICIPANT	\N	PRESENT	0
323197	314149	95037J	PARTICIPANT	\N	PRESENT	0
323198	320710	14038Y	PARTICIPANT	\N	PRESENT	0
323199	320710	04085P	PARTICIPANT	\N	PRESENT	0
308512	307133	08062Y	PARTICIPANT	\N	PRESENT	0
308513	307133	19695N	PARTICIPANT	\N	PRESENT	0
308514	307133	14033T	PARTICIPANT	\N	PRESENT	0
308515	307133	11090Q	PRESIDENT	0	PRESENT	0
308516	307133	01025N	PARTICIPANT	\N	PRESENT	0
308517	307133	19269X	PARTICIPANT	\N	PRESENT	0
308518	307133	14205J	PARTICIPANT	\N	PRESENT	0
308519	307133	04088S	PARTICIPANT	\N	PRESENT	0
308520	307133	11056N	PARTICIPANT	\N	PRESENT	0
308521	307133	14115H	PARTICIPANT	\N	PRESENT	0
308522	307133	11101A	PARTICIPANT	\N	PRESENT	0
308523	307133	19507S	PARTICIPANT	\N	PRESENT	0
308524	307133	19747H	PARTICIPANT	\N	PRESENT	0
308525	307133	14207L	PARTICIPANT	\N	PRESENT	0
308526	307133	04043D	PARTICIPANT	\N	PRESENT	0
308527	307133	19619A	PARTICIPANT	\N	PRESENT	0
308528	307133	17589D	PARTICIPANT	\N	PRESENT	0
308529	307133	14257W	PARTICIPANT	\N	PRESENT	0
308530	307133	08021P	PARTICIPANT	\N	EXCUSE	0
308531	306947	17779H	PARTICIPANT	\N	PRESENT	0
308532	307457	14061L	PARTICIPANT	\N	PRESENT	0
308533	307457	08035V	PARTICIPANT	\N	PRESENT	0
308534	307457	14251Q	PARTICIPANT	\N	PRESENT	0
308535	308227	08018U	PARTICIPANT	\N	PRESENT	0
308536	306947	14261S	PARTICIPANT	\N	EXCUSE	0
308537	306947	19577H	PARTICIPANT	\N	PRESENT	0
308611	307054	14331P	PARTICIPANT	\N	PRESENT	0
308612	307054	04071H	PARTICIPANT	\N	PRESENT	0
308613	307054	01048V	PARTICIPANT	\N	PRESENT	0
308614	307054	19545Y	PARTICIPANT	\N	PRESENT	0
308615	307054	01057W	PARTICIPANT	\N	PRESENT	0
308616	307054	11053K	PARTICIPANT	\N	PRESENT	0
308617	307054	11074Q	PRESIDENT	0	PRESENT	0
308618	307054	19667J	PARTICIPANT	\N	PRESENT	0
308619	307054	89017R	PARTICIPANT	\N	PRESENT	0
308620	307054	11070L	PARTICIPANT	\N	PRESENT	0
308621	307054	14225N	PARTICIPANT	\N	PRESENT	0
308622	307054	19671E	PARTICIPANT	\N	PRESENT	0
308623	307054	11110B	PARTICIPANT	\N	PRESENT	0
308624	307054	07029T	PARTICIPANT	\N	PRESENT	0
308625	307054	14085U	PARTICIPANT	\N	PRESENT	0
308626	307054	19349W	PARTICIPANT	\N	PRESENT	0
308627	307054	08010L	PARTICIPANT	\N	PRESENT	0
308994	307418	19695N	PARTICIPANT	\N	PRESENT	0
308629	307054	14253S	PARTICIPANT	\N	PRESENT	0
308630	307054	11048N	PARTICIPANT	\N	PRESENT	0
308631	307054	19647E	PARTICIPANT	\N	PRESENT	0
308632	307054	19479G	PARTICIPANT	\N	PRESENT	0
308633	307054	19711U	PARTICIPANT	\N	PRESENT	0
308989	308745	01024M	PARTICIPANT	\N	PRESENT	0
308635	307054	08034U	PARTICIPANT	\N	PRESENT	0
308636	307054	19531S	PARTICIPANT	\N	PRESENT	0
308637	307054	08069G	PARTICIPANT	\N	PRESENT	0
308638	307054	19689Q	PARTICIPANT	\N	PRESENT	0
308639	307054	08011M	PARTICIPANT	\N	PRESENT	0
308640	307054	14034U	PARTICIPANT	\N	PRESENT	0
308641	307054	14159V	PARTICIPANT	\N	PRESENT	0
308642	307054	14173T	PARTICIPANT	\N	PRESENT	0
308643	307054	04086Q	PARTICIPANT	\N	PRESENT	0
308644	307054	11040E	PARTICIPANT	\N	PRESENT	0
308645	307054	14083S	PARTICIPANT	\N	PRESENT	0
308646	307054	11012A	PARTICIPANT	\N	PRESENT	0
308647	307054	19741B	PARTICIPANT	\N	PRESENT	0
308648	307054	14121F	PARTICIPANT	\N	PRESENT	0
308649	307054	99004R	PARTICIPANT	\N	PRESENT	0
308650	307054	04061F	PARTICIPANT	\N	PRESENT	0
308990	308745	04047H	PARTICIPANT	\N	PRESENT	0
308991	308745	14089Y	PARTICIPANT	\N	PRESENT	0
308995	307418	11056N	PARTICIPANT	\N	PRESENT	0
308992	307418	04044E	PARTICIPANT	\N	PRESENT	0
308996	307418	04085P	PARTICIPANT	\N	PRESENT	0
308997	307418	19333N	PARTICIPANT	\N	PRESENT	0
308998	307418	19631V	PARTICIPANT	\N	PRESENT	0
308999	307418	80013X	PARTICIPANT	\N	PRESENT	0
309000	307418	19347U	PARTICIPANT	\N	PRESENT	0
309001	307418	19251M	PARTICIPANT	\N	PRESENT	0
309002	307418	14257W	PARTICIPANT	\N	PRESENT	0
309003	307418	08049C	PARTICIPANT	\N	PRESENT	0
309004	307418	04034C	PARTICIPANT	\N	PRESENT	0
309005	307418	19637C	PARTICIPANT	\N	PRESENT	0
309006	307418	01043Q	PARTICIPANT	\N	PRESENT	0
309007	307418	14042U	PARTICIPANT	\N	PRESENT	0
309008	307418	14219Q	PARTICIPANT	\N	PRESENT	0
309009	307418	14089Y	PARTICIPANT	\N	PRESENT	0
309010	307418	14267Y	PARTICIPANT	\N	PRESENT	0
309011	307418	19747H	PARTICIPANT	\N	PRESENT	0
309012	307418	14157T	PARTICIPANT	\N	PRESENT	0
309013	307418	11048N	PARTICIPANT	\N	PRESENT	0
309014	307418	11090Q	PARTICIPANT	\N	PRESENT	0
309015	307418	14193X	PARTICIPANT	\N	PRESENT	0
309016	307418	97011G	PARTICIPANT	\N	PRESENT	0
309017	307418	04049K	PARTICIPANT	\N	PRESENT	0
309018	307418	19762G	PARTICIPANT	\N	PRESENT	0
309019	307418	19687N	PARTICIPANT	\N	PRESENT	0
309020	307418	95030B	PARTICIPANT	\N	PRESENT	0
309021	307418	19681G	PARTICIPANT	\N	PRESENT	0
309022	307418	19585H	PARTICIPANT	\N	PRESENT	0
309023	307418	14028W	PARTICIPANT	\N	PRESENT	0
309024	307418	14265W	PARTICIPANT	\N	PRESENT	0
309030	307418	08068F	PARTICIPANT	\N	PRESENT	0
309026	307418	19441R	PARTICIPANT	\N	PRESENT	0
309029	307418	08015R	PARTICIPANT	\N	PRESENT	0
309031	307418	08028W	PARTICIPANT	\N	PRESENT	0
309032	307418	19737F	PARTICIPANT	\N	PRESENT	0
309033	307418	14071N	PARTICIPANT	\N	PRESENT	0
309052	307418	19691J	PARTICIPANT	\N	PRESENT	0
310566	310565	11053K	PARTICIPANT	\N	PRESENT	0
310567	310565	14159V	PARTICIPANT	\N	PRESENT	0
310568	310565	05012A	PARTICIPANT	\N	PRESENT	0
310797	305886	19515S	PARTICIPANT	\N	PRESENT	0
310758	305900	11065P	PARTICIPANT	\N	PRESENT	0
310759	305900	02002K	PARTICIPANT	\N	PRESENT	0
311957	311954	04071H	PARTICIPANT	\N	PRESENT	0
310761	305900	14147R	PARTICIPANT	\N	PRESENT	0
310762	305900	14107H	PARTICIPANT	\N	PRESENT	0
310763	305900	11097X	PARTICIPANT	\N	PRESENT	0
310765	305900	19737F	PARTICIPANT	\N	PRESENT	0
310766	305900	19651A	PARTICIPANT	\N	PRESENT	0
310798	305886	19711U	PARTICIPANT	\N	PRESENT	0
310799	305886	14147R	PARTICIPANT	\N	PRESENT	0
310800	305886	14107H	PARTICIPANT	\N	PRESENT	0
310801	305886	11066Q	PARTICIPANT	\N	PRESENT	0
310803	305886	19479G	PARTICIPANT	\N	PRESENT	0
310804	305886	19737F	PARTICIPANT	\N	PRESENT	0
311646	305900	04061F	PARTICIPANT	\N	PRESENT	0
311955	311954	14083S	PARTICIPANT	\N	PRESENT	0
311958	311954	19521Q	PRESIDENT	0	PRESENT	0
311959	311954	14034U	PARTICIPANT	\N	PRESENT	0
311960	311954	19695N	PARTICIPANT	\N	PRESENT	0
311961	311954	11048N	PARTICIPANT	\N	PRESENT	0
311962	311954	04049K	PARTICIPANT	\N	PRESENT	0
311963	311954	08034U	PARTICIPANT	\N	PRESENT	0
311964	311954	19441R	PARTICIPANT	\N	PRESENT	0
311965	311954	04034C	PARTICIPANT	\N	PRESENT	0
311967	311954	14159V	PARTICIPANT	\N	PRESENT	0
311968	311954	19711U	PARTICIPANT	\N	PRESENT	0
318992	316537	19685L	PARTICIPANT	\N	EXCUSE	0
318994	317525	19685L	PARTICIPANT	\N	EXCUSE	0
318997	318996	04047H	PARTICIPANT	\N	PRESENT	0
318998	318996	19649G	PARTICIPANT	\N	PRESENT	0
324042	314152	11103C	PARTICIPANT	\N	PRESENT	0
324043	314152	19611R	PARTICIPANT	\N	PRESENT	0
324044	321055	19531S	PARTICIPANT	\N	PRESENT	0
324045	321055	08011M	PARTICIPANT	\N	PRESENT	0
324046	314152	19553Y	PARTICIPANT	\N	PRESENT	0
324047	314152	19699S	PARTICIPANT	\N	PRESENT	0
324048	314152	19415P	PARTICIPANT	\N	PRESENT	0
324049	314152	80013X	PARTICIPANT	\N	PRESENT	0
324050	314152	14267Y	PARTICIPANT	\N	PRESENT	0
324051	314152	14239U	PARTICIPANT	\N	PRESENT	0
324052	314152	19697Q	PARTICIPANT	\N	PRESENT	0
324053	314152	08039A	PARTICIPANT	\N	PRESENT	0
324054	314152	08056B	PARTICIPANT	\N	PRESENT	0
324055	314152	14063N	PARTICIPANT	\N	PRESENT	0
324056	314152	11097X	PARTICIPANT	\N	PRESENT	0
324057	314152	08043V	PARTICIPANT	\N	PRESENT	0
324058	321055	14121F	PARTICIPANT	\N	PRESENT	0
324059	314152	11090Q	PARTICIPANT	\N	PRESENT	0
324060	314152	11104D	PARTICIPANT	\N	PRESENT	0
324061	314152	19563B	PARTICIPANT	\N	PRESENT	0
324062	314152	14029X	PARTICIPANT	\N	PRESENT	0
324063	314152	14107H	PARTICIPANT	\N	PRESENT	0
324064	321055	11070L	PARTICIPANT	\N	PRESENT	0
324065	314152	14033T	PARTICIPANT	\N	PRESENT	0
324066	314152	14259Y	PARTICIPANT	\N	PRESENT	0
324067	314152	95041E	PARTICIPANT	\N	PRESENT	0
324068	314152	19447X	PARTICIPANT	\N	PRESENT	0
324069	314152	19762G	PARTICIPANT	\N	PRESENT	0
324070	314152	89017R	PARTICIPANT	\N	PRESENT	0
314705	314348	08062Y	PARTICIPANT	\N	PRESENT	0
314706	314348	08020N	PARTICIPANT	\N	PRESENT	0
314711	314348	14235Q	PARTICIPANT	\N	PRESENT	0
314708	314348	14103D	PARTICIPANT	\N	PRESENT	0
314709	314348	04038G	PARTICIPANT	\N	PRESENT	0
314710	314348	14259Y	PARTICIPANT	\N	PRESENT	0
314712	314348	14119M	PARTICIPANT	\N	PRESENT	0
314713	314348	08058D	PARTICIPANT	\N	PRESENT	0
314714	314348	14083S	PARTICIPANT	\N	PRESENT	0
314715	314348	19713W	PARTICIPANT	\N	PRESENT	0
314716	314348	08069G	PARTICIPANT	\N	PRESENT	0
314717	314348	19551W	PARTICIPANT	\N	PRESENT	0
314732	314348	01024M	PARTICIPANT	\N	PRESENT	0
314719	314348	08045X	PARTICIPANT	\N	PRESENT	0
314720	314348	19251M	PARTICIPANT	\N	PRESENT	0
314721	314348	08039A	PARTICIPANT	\N	PRESENT	0
314722	314348	19699S	PARTICIPANT	\N	PRESENT	0
314723	314348	14151M	PARTICIPANT	\N	PRESENT	0
314724	314348	14251Q	PARTICIPANT	\N	PRESENT	0
314725	314348	11115U	PARTICIPANT	\N	PRESENT	0
314726	314348	19329S	PARTICIPANT	\N	PRESENT	0
314727	314348	19747H	PARTICIPANT	\N	PRESENT	0
314728	314348	08038Y	PARTICIPANT	\N	PRESENT	0
314729	314348	19721W	PARTICIPANT	\N	PRESENT	0
314730	314348	14199E	PARTICIPANT	\N	PRESENT	0
314731	314348	19421M	PARTICIPANT	\N	PRESENT	0
314733	314348	19413M	PARTICIPANT	\N	PRESENT	0
314734	314348	01062T	PARTICIPANT	\N	PRESENT	0
314735	314348	11070L	PARTICIPANT	\N	PRESENT	0
314736	314348	11099A	PARTICIPANT	\N	PRESENT	0
314737	314348	19591F	PARTICIPANT	\N	PRESENT	0
314739	314348	88008L	PARTICIPANT	\N	PRESENT	0
314741	314348	19741B	PARTICIPANT	\N	PRESENT	0
314742	314348	17637T	PARTICIPANT	\N	PRESENT	0
314744	314348	11065P	PARTICIPANT	\N	PRESENT	0
314745	314348	14061L	PARTICIPANT	\N	PRESENT	0
314746	314348	14033T	PARTICIPANT	\N	PRESENT	0
314747	314348	04034C	PARTICIPANT	\N	PRESENT	0
314748	314348	19573D	PARTICIPANT	\N	PRESENT	0
314749	314348	11067R	PARTICIPANT	\N	PRESENT	0
314750	314348	11026G	PARTICIPANT	\N	PRESENT	0
314751	314348	19599P	PARTICIPANT	\N	PRESENT	0
314752	314348	14179A	PARTICIPANT	\N	PRESENT	0
314753	314348	14069U	PARTICIPANT	\N	PRESENT	0
314755	314348	14217N	PARTICIPANT	\N	PRESENT	0
315037	314754	04059M	PARTICIPANT	\N	PRESENT	0
315038	314754	11033F	PARTICIPANT	\N	PRESENT	0
315039	314754	19593H	PARTICIPANT	\N	PRESENT	0
315040	314754	04085P	PARTICIPANT	\N	PRESENT	0
315041	314754	01028R	PARTICIPANT	\N	PRESENT	0
315042	314754	12016W	PARTICIPANT	\N	PRESENT	0
315043	314754	19715Y	PARTICIPANT	\N	PRESENT	0
315044	314754	19599P	PARTICIPANT	\N	PRESENT	0
315045	314754	04044E	PARTICIPANT	\N	PRESENT	0
315046	314754	14151M	PARTICIPANT	\N	PRESENT	0
315049	314754	19649G	PARTICIPANT	\N	PRESENT	0
315083	314189	08043V	PARTICIPANT	\N	PRESENT	0
315084	314189	11083R	PARTICIPANT	\N	PRESENT	0
315085	314754	19758L	PARTICIPANT	\N	PRESENT	0
315086	314754	14034U	PARTICIPANT	\N	PRESENT	0
315087	314754	19737F	PARTICIPANT	\N	PRESENT	0
315088	314754	14261S	PARTICIPANT	\N	PRESENT	0
315089	314754	19479G	PARTICIPANT	\N	PRESENT	0
315090	314754	19441R	PARTICIPANT	\N	PRESENT	0
315091	314189	04034C	PARTICIPANT	\N	PRESENT	0
315092	314754	16685X	PARTICIPANT	\N	PRESENT	0
315093	314754	14103D	PARTICIPANT	\N	PRESENT	0
315094	314754	14073Q	PARTICIPANT	\N	PRESENT	0
315098	314754	19581D	PARTICIPANT	\N	PRESENT	0
315096	314754	19335Q	PARTICIPANT	\N	PRESENT	0
315097	314754	19745F	PARTICIPANT	\N	PRESENT	0
315099	314754	14195A	PARTICIPANT	\N	PRESENT	0
315100	314754	19747H	PARTICIPANT	\N	PRESENT	0
315101	314754	17583W	PARTICIPANT	\N	PRESENT	0
315102	314754	14215L	PARTICIPANT	\N	PRESENT	0
315103	314754	19421M	PARTICIPANT	\N	PRESENT	0
315104	314754	01024M	PARTICIPANT	\N	PRESENT	0
315105	314754	14030Q	PARTICIPANT	\N	PRESENT	0
315106	314754	14179A	PARTICIPANT	\N	PRESENT	0
315107	314754	19731Y	PARTICIPANT	\N	PRESENT	0
315108	314754	99004R	PARTICIPANT	\N	PRESENT	0
315109	314754	95030B	PARTICIPANT	\N	PRESENT	0
315110	314754	04033B	PARTICIPANT	\N	PRESENT	0
315111	314754	14187A	PARTICIPANT	\N	PRESENT	0
315112	314754	19533U	PARTICIPANT	\N	PRESENT	0
315113	314754	97011G	PARTICIPANT	\N	PRESENT	0
315114	314754	05008E	PARTICIPANT	\N	PRESENT	0
315115	314754	11103C	PARTICIPANT	\N	PRESENT	0
315116	314754	14329V	PARTICIPANT	\N	PRESENT	0
315117	314754	14357A	PARTICIPANT	\N	PRESENT	0
315118	314754	19733B	PARTICIPANT	\N	PRESENT	0
315119	314754	14061L	PARTICIPANT	\N	PRESENT	0
315120	314754	19768N	PARTICIPANT	\N	PRESENT	0
315121	314754	08015R	PARTICIPANT	\N	PRESENT	0
315122	314754	19729F	PARTICIPANT	\N	PRESENT	0
315123	314189	01060R	PARTICIPANT	\N	PRESENT	0
315124	314754	14033T	PARTICIPANT	\N	PRESENT	0
315125	314754	14026U	PARTICIPANT	\N	PRESENT	0
315126	314754	14265W	PARTICIPANT	\N	PRESENT	0
315127	314754	14147R	PARTICIPANT	\N	PRESENT	0
315128	314754	04049K	PARTICIPANT	\N	PRESENT	0
315129	314754	11090Q	PARTICIPANT	\N	PRESENT	0
315130	314754	08028W	PARTICIPANT	\N	PRESENT	0
315131	314189	14053L	PARTICIPANT	\N	PRESENT	0
315132	314754	08069G	PARTICIPANT	\N	PRESENT	0
315133	314754	14223L	PARTICIPANT	\N	PRESENT	0
315134	314754	95067Q	PARTICIPANT	\N	PRESENT	0
315135	314754	87003B	PARTICIPANT	\N	PRESENT	0
315136	314754	14217N	PARTICIPANT	\N	PRESENT	0
315137	314754	19766L	PARTICIPANT	\N	PRESENT	0
315138	314754	11080N	PARTICIPANT	\N	PRESENT	0
315227	314754	19675J	PARTICIPANT	\N	PRESENT	0
315140	314754	14115H	PARTICIPANT	\N	PRESENT	0
315141	314754	08019V	PARTICIPANT	\N	PRESENT	0
315142	314754	14041T	PARTICIPANT	\N	PRESENT	0
315143	314754	04088S	PARTICIPANT	\N	PRESENT	0
315144	314754	14135M	PARTICIPANT	\N	PRESENT	0
315145	314754	14029X	PARTICIPANT	\N	PRESENT	0
315146	314754	14119M	PARTICIPANT	\N	PRESENT	0
315147	314754	14157T	PARTICIPANT	\N	PRESENT	0
315148	314754	14031R	PARTICIPANT	\N	PRESENT	0
315149	314754	19443T	PARTICIPANT	\N	PRESENT	0
315150	314754	19467C	PARTICIPANT	\N	PRESENT	0
315151	314754	19723Y	PARTICIPANT	\N	PRESENT	0
315152	314754	19447X	PARTICIPANT	\N	PRESENT	0
315153	314754	19573D	PARTICIPANT	\N	PRESENT	0
315154	314754	19703U	PARTICIPANT	\N	PRESENT	0
315155	314754	19515S	PARTICIPANT	\N	PRESENT	0
315156	314754	15447F	PARTICIPANT	\N	PRESENT	0
315157	314189	19251M	PARTICIPANT	\N	PRESENT	0
315158	314754	14191V	PARTICIPANT	\N	PRESENT	0
315159	314754	14063N	PARTICIPANT	\N	PRESENT	0
315160	314754	11067R	PARTICIPANT	\N	PRESENT	0
315161	314754	19575F	PARTICIPANT	\N	PRESENT	0
315162	314754	19679N	PARTICIPANT	\N	PRESENT	0
315163	314754	08039A	PARTICIPANT	\N	PRESENT	0
315164	314754	17637T	PARTICIPANT	\N	PRESENT	0
315165	314754	19711U	PARTICIPANT	\N	PRESENT	0
315166	314754	11048N	PARTICIPANT	\N	PRESENT	0
315167	314754	08068F	PARTICIPANT	\N	PRESENT	0
315168	314189	04035D	PARTICIPANT	\N	PRESENT	0
315225	314754	14225N	PARTICIPANT	\N	PRESENT	0
315226	314754	08020N	PARTICIPANT	\N	PRESENT	0
315228	314754	14105F	PARTICIPANT	\N	PRESENT	0
315229	314754	14038Y	PARTICIPANT	\N	PRESENT	0
315230	314754	19741B	PARTICIPANT	\N	PRESENT	0
315231	314754	14042U	PARTICIPANT	\N	PRESENT	0
315232	314754	19521Q	PARTICIPANT	\N	PRESENT	0
315234	314307	14229S	PARTICIPANT	\N	PRESENT	0
315235	314307	14249W	PARTICIPANT	\N	PRESENT	0
315236	314307	14059S	PARTICIPANT	\N	PRESENT	0
315237	314307	14073Q	PARTICIPANT	\N	PRESENT	0
315238	314307	14251Q	PARTICIPANT	\N	PRESENT	0
315239	314307	19735D	PARTICIPANT	\N	PRESENT	0
315240	314307	11109J	PARTICIPANT	\N	PRESENT	0
315241	314307	19621T	PARTICIPANT	\N	PRESENT	0
315242	314754	19251M	PARTICIPANT	\N	PRESENT	0
315243	314754	19691J	PARTICIPANT	\N	PRESENT	0
315244	314754	14355X	PARTICIPANT	\N	PRESENT	0
315245	314754	19253P	PARTICIPANT	\N	PRESENT	0
315246	314754	19569H	PARTICIPANT	\N	PRESENT	0
315247	314754	11012A	PARTICIPANT	\N	PRESENT	0
315248	314754	01058X	PARTICIPANT	\N	PRESENT	0
315249	314754	14199E	PARTICIPANT	\N	PRESENT	0
302443	289207	04086Q	PARTICIPANT	\N	PRESENT	0
302444	302441	14053L	PARTICIPANT	\N	PRESENT	0
302445	302441	14111D	PARTICIPANT	\N	PRESENT	0
302446	302441	19629C	PARTICIPANT	\N	PRESENT	0
302447	302441	19253P	PARTICIPANT	\N	PRESENT	0
302448	302441	14147R	PARTICIPANT	\N	PRESENT	0
302449	302441	04047H	PRESIDENT	1	PRESENT	0
302450	302441	19673G	PARTICIPANT	\N	PRESENT	0
302451	302441	19447X	PARTICIPANT	\N	PRESENT	0
302452	302441	98035U	PARTICIPANT	\N	PRESENT	0
302453	302441	08045X	PARTICIPANT	\N	PRESENT	0
302454	302441	01024M	PARTICIPANT	\N	PRESENT	0
302455	302441	04038G	PARTICIPANT	\N	PRESENT	0
302456	302441	04044E	PARTICIPANT	\N	PRESENT	0
302457	302441	19581D	PARTICIPANT	\N	PRESENT	0
302458	302441	01028R	PARTICIPANT	\N	PRESENT	0
302459	302441	05008E	PRESIDENT	2	PRESENT	0
302460	302441	14089Y	PARTICIPANT	\N	PRESENT	0
302461	302441	95063L	PARTICIPANT	\N	PRESENT	0
302462	302441	14041T	PARTICIPANT	\N	PRESENT	0
302463	302441	14069U	PARTICIPANT	\N	PRESENT	0
302464	302441	14215L	PRESIDENT	0	PRESENT	0
302465	298803	11048N	PRESIDENT	0	PRESENT	0
302466	298803	19515S	PARTICIPANT	\N	PRESENT	0
302467	298803	19503N	PARTICIPANT	\N	PRESENT	0
302468	298803	01024M	PARTICIPANT	\N	PRESENT	0
302469	298803	14207L	PARTICIPANT	\N	PRESENT	0
302470	298803	19749K	PARTICIPANT	\N	PRESENT	0
302471	298803	11067R	PARTICIPANT	\N	PRESENT	0
302472	298803	14041T	PARTICIPANT	\N	EXCUSE	0
302473	298803	14173T	PARTICIPANT	\N	EXCUSE	0
302474	289207	14159V	PARTICIPANT	\N	PRESENT	0
302475	289207	19507S	PARTICIPANT	\N	PRESENT	0
302476	289207	14223L	PARTICIPANT	\N	PRESENT	0
302477	289207	14111D	PARTICIPANT	\N	PRESENT	0
302478	289207	11090Q	PARTICIPANT	\N	PRESENT	0
302479	289207	19745F	PARTICIPANT	\N	PRESENT	0
302490	298803	14103D	PARTICIPANT	\N	PRESENT	0
302491	298803	19479G	PARTICIPANT	\N	PRESENT	0
302492	298803	19711U	PARTICIPANT	\N	PRESENT	0
302493	298803	19533U	PARTICIPANT	\N	PRESENT	0
302494	298803	14031R	PARTICIPANT	\N	PRESENT	0
302495	298803	14026U	PARTICIPANT	\N	PRESENT	0
302496	298803	19719D	PARTICIPANT	\N	PRESENT	0
302497	298803	04049K	PARTICIPANT	\N	PRESENT	0
302498	298803	14157T	PARTICIPANT	\N	PRESENT	0
302499	298803	14071N	PARTICIPANT	\N	PRESENT	0
302501	289207	19575F	PARTICIPANT	\N	PRESENT	0
302502	289207	19421M	PARTICIPANT	\N	PRESENT	0
302503	289207	14179A	PARTICIPANT	\N	PRESENT	0
302504	289207	04043D	PARTICIPANT	\N	PRESENT	0
302505	289207	14105F	PARTICIPANT	\N	PRESENT	0
302600	295644	19745F	PARTICIPANT	\N	PRESENT	0
302601	295644	08056B	PARTICIPANT	\N	PRESENT	0
302602	295644	19507S	PARTICIPANT	\N	PRESENT	0
302603	295644	04088S	PARTICIPANT	\N	PRESENT	0
302604	295644	11077T	PARTICIPANT	\N	PRESENT	0
302605	295644	19687N	PARTICIPANT	\N	PRESENT	0
302606	295644	19695N	PARTICIPANT	\N	PRESENT	0
302607	295644	11056N	PARTICIPANT	\N	PRESENT	0
302608	295644	19671E	PARTICIPANT	\N	PRESENT	0
302609	295644	14329V	PARTICIPANT	\N	PRESENT	0
302610	295644	19675J	PARTICIPANT	\N	PRESENT	0
302611	295644	19383Y	PARTICIPANT	\N	PRESENT	0
302612	295644	19701S	PARTICIPANT	\N	PRESENT	0
302613	295644	08034U	PARTICIPANT	\N	PRESENT	0
302614	295644	08028W	PARTICIPANT	\N	PRESENT	0
302615	295644	14223L	PARTICIPANT	\N	PRESENT	0
302616	295644	08010L	PARTICIPANT	\N	PRESENT	0
302617	295644	99004R	PARTICIPANT	\N	PRESENT	0
302618	295644	19711U	PARTICIPANT	\N	PRESENT	0
302619	295644	19735D	PARTICIPANT	\N	PRESENT	0
302620	295644	05012A	PARTICIPANT	\N	PRESENT	0
302621	295644	87003B	PARTICIPANT	\N	PRESENT	0
302622	295644	11097X	PARTICIPANT	\N	PRESENT	0
302623	295644	14211G	PARTICIPANT	\N	PRESENT	0
302624	295644	14157T	PARTICIPANT	\N	PRESENT	0
302625	295644	19525U	PARTICIPANT	\N	PRESENT	0
302626	295644	14031R	PARTICIPANT	\N	PRESENT	0
302627	295644	19637C	PARTICIPANT	\N	PRESENT	0
302628	295644	19667J	PARTICIPANT	\N	PRESENT	0
302629	295644	14033T	PARTICIPANT	\N	PRESENT	0
302630	295644	19467C	PARTICIPANT	\N	PRESENT	0
302631	295644	14038Y	PARTICIPANT	\N	PRESENT	0
302632	295644	11048N	PARTICIPANT	\N	PRESENT	0
302633	295644	17589D	PARTICIPANT	\N	PRESENT	0
302634	295644	14241N	PARTICIPANT	\N	PRESENT	0
302635	295644	19563B	PARTICIPANT	\N	PRESENT	0
302636	295644	04086Q	PARTICIPANT	\N	PRESENT	0
302637	295644	19631V	PARTICIPANT	\N	PRESENT	0
302638	295644	19760E	PARTICIPANT	\N	PRESENT	0
302639	295644	14257W	PARTICIPANT	\N	PRESENT	0
302640	302583	12041X	PARTICIPANT	\N	PRESENT	0
302641	302583	19581D	PARTICIPANT	\N	PRESENT	0
302642	302583	11066Q	PARTICIPANT	\N	PRESENT	0
302643	302583	01028R	PARTICIPANT	\N	PRESENT	0
302644	302583	19447X	PARTICIPANT	\N	PRESENT	0
302645	302583	05008E	PRESIDENT	0	PRESENT	0
302646	302583	19489J	PARTICIPANT	\N	PRESENT	0
302648	302583	08017T	PARTICIPANT	\N	PRESENT	0
302649	302583	14193X	PARTICIPANT	\N	PRESENT	0
302650	302583	14147R	PARTICIPANT	\N	PRESENT	0
302651	302583	14179A	PARTICIPANT	\N	PRESENT	0
302652	302583	14215L	PARTICIPANT	\N	PRESENT	0
302653	302583	11072N	PARTICIPANT	\N	PRESENT	0
302654	302583	19649G	PARTICIPANT	\N	PRESENT	0
302655	302583	14065Q	PARTICIPANT	\N	PRESENT	0
302656	302583	08045X	PARTICIPANT	\N	PRESENT	0
302657	302583	11026G	PARTICIPANT	\N	PRESENT	0
302658	302583	04038G	PARTICIPANT	\N	PRESENT	0
302659	302583	19719D	PARTICIPANT	\N	PRESENT	0
302660	302583	11033F	PARTICIPANT	\N	PRESENT	0
302661	302583	04085P	PARTICIPANT	\N	PRESENT	0
302662	302583	19725B	PARTICIPANT	\N	PRESENT	0
302663	302583	14089Y	PARTICIPANT	\N	PRESENT	0
302664	302583	19729F	PARTICIPANT	\N	PRESENT	0
302665	302583	11085T	PARTICIPANT	\N	PRESENT	0
302666	302583	11049P	PARTICIPANT	\N	PRESENT	0
302667	302583	04061F	PARTICIPANT	\N	PRESENT	0
302668	302583	14021P	PARTICIPANT	\N	PRESENT	0
302669	295644	97011G	PARTICIPANT	\N	PRESENT	0
302670	295644	19573D	PARTICIPANT	\N	PRESENT	0
302671	295644	19575F	PARTICIPANT	\N	PRESENT	0
302672	295644	19349W	PARTICIPANT	\N	PRESENT	0
302673	295644	19705W	PARTICIPANT	\N	PRESENT	0
302674	295644	19369B	PARTICIPANT	\N	PRESENT	0
302675	295644	19599P	PARTICIPANT	\N	PRESENT	0
302676	295644	01034P	PARTICIPANT	\N	PRESENT	0
302677	295644	19611R	PARTICIPANT	\N	PRESENT	0
302678	295644	95015C	PARTICIPANT	\N	PRESENT	0
302679	295644	19651A	PARTICIPANT	\N	PRESENT	0
302680	295644	08038Y	PARTICIPANT	\N	PRESENT	0
302681	295644	14083S	PARTICIPANT	\N	PRESENT	0
302682	295644	19591F	PARTICIPANT	\N	PRESENT	0
302683	295644	14217N	PARTICIPANT	\N	PRESENT	0
302684	295644	19747H	PARTICIPANT	\N	PRESENT	0
302685	295644	19511N	PARTICIPANT	\N	PRESENT	0
302686	295644	19387D	PARTICIPANT	\N	PRESENT	0
302687	295644	19421M	PARTICIPANT	\N	PRESENT	0
302688	295644	11054L	PARTICIPANT	\N	PRESENT	0
302689	295644	11043H	PARTICIPANT	\N	PRESENT	0
302690	295644	14061L	PARTICIPANT	\N	PRESENT	0
302691	295644	18083K	PARTICIPANT	\N	PRESENT	0
302692	295644	11103C	PARTICIPANT	\N	PRESENT	0
302693	295644	08039A	PARTICIPANT	\N	PRESENT	0
302694	295644	19727D	PARTICIPANT	\N	PRESENT	0
302695	295644	17779H	PARTICIPANT	\N	PRESENT	0
302696	302583	11027H	PARTICIPANT	\N	PRESENT	0
302697	302583	95067Q	PARTICIPANT	\N	PRESENT	0
302698	302583	95063L	PARTICIPANT	\N	PRESENT	0
302699	302583	14207L	PARTICIPANT	\N	PRESENT	0
302700	295644	19699S	PARTICIPANT	\N	PRESENT	0
302701	295644	14281W	PARTICIPANT	\N	PRESENT	0
302702	295644	14105F	PARTICIPANT	\N	PRESENT	0
302703	295644	19533U	PARTICIPANT	\N	PRESENT	0
302705	295644	11067R	PARTICIPANT	\N	PRESENT	0
302706	295644	19657G	PARTICIPANT	\N	PRESENT	0
302707	295644	14089Y	PARTICIPANT	\N	PRESENT	0
302708	295644	19707Y	PARTICIPANT	\N	PRESENT	0
302709	295644	19731Y	PARTICIPANT	\N	PRESENT	0
302710	295644	04071H	PARTICIPANT	\N	PRESENT	0
302711	295644	19619A	PARTICIPANT	\N	PRESENT	0
302712	295644	08055A	PARTICIPANT	\N	PRESENT	0
302713	295644	04070G	PARTICIPANT	\N	PRESENT	0
302714	295644	16685X	PARTICIPANT	\N	PRESENT	0
302715	295644	01025N	PARTICIPANT	\N	PRESENT	0
302716	295644	19551W	PARTICIPANT	\N	PRESENT	0
302717	295644	14197C	PARTICIPANT	\N	PRESENT	0
323200	314149	19723Y	PARTICIPANT	\N	PRESENT	0
323201	314149	95030B	PARTICIPANT	\N	PRESENT	0
323202	322159	19768N	PARTICIPANT	\N	PRESENT	0
323203	322159	19565D	PARTICIPANT	\N	PRESENT	0
323204	322159	14357A	PARTICIPANT	\N	PRESENT	0
323205	322159	19441R	PARTICIPANT	\N	PRESENT	0
323206	322159	14081Q	PARTICIPANT	\N	PRESENT	0
323207	322159	19413M	PARTICIPANT	\N	PRESENT	0
323208	322159	80013X	PARTICIPANT	\N	PRESENT	0
323209	322159	19631V	PARTICIPANT	\N	PRESENT	0
323210	322159	08068F	PARTICIPANT	\N	PRESENT	0
323211	322159	08015R	PARTICIPANT	\N	PRESENT	0
323212	322159	19369B	PARTICIPANT	\N	PRESENT	0
323213	322159	19511N	PARTICIPANT	\N	PRESENT	0
323214	322159	08028W	PARTICIPANT	\N	PRESENT	0
323215	322159	14265W	PARTICIPANT	\N	PRESENT	0
323216	322159	14329V	PARTICIPANT	\N	PRESENT	0
323217	322159	14187A	PARTICIPANT	\N	PRESENT	0
323218	322159	08062Y	PARTICIPANT	\N	PRESENT	0
323219	322159	14033T	PARTICIPANT	\N	PRESENT	0
323220	322159	11090Q	PRESIDENT	0	PRESENT	0
323221	322159	14205J	PARTICIPANT	\N	PRESENT	0
323222	322159	04088S	PARTICIPANT	\N	PRESENT	0
323223	322159	11056N	PARTICIPANT	\N	PRESENT	0
323224	322159	04089T	PARTICIPANT	\N	PRESENT	0
323225	322159	14119M	PARTICIPANT	\N	PRESENT	0
323226	322159	14115H	PARTICIPANT	\N	PRESENT	0
323227	322159	11101A	PARTICIPANT	\N	PRESENT	0
323228	322159	19507S	PARTICIPANT	\N	PRESENT	0
323229	322159	19747H	PARTICIPANT	\N	PRESENT	0
323230	322159	14207L	PARTICIPANT	\N	PRESENT	0
323231	322159	14257W	PARTICIPANT	\N	PRESENT	0
323232	322159	11081P	PARTICIPANT	\N	EXCUSE	0
323233	314149	19349W	PARTICIPANT	\N	PRESENT	0
323234	314149	19577H	PARTICIPANT	\N	PRESENT	0
323235	314149	19657G	PARTICIPANT	\N	PRESENT	0
323236	314149	01048V	PARTICIPANT	\N	PRESENT	0
323237	319829	14053L	PARTICIPANT	\N	PRESENT	0
323238	319829	04071H	PARTICIPANT	\N	PRESENT	0
323239	319829	14111D	PARTICIPANT	\N	PRESENT	0
323240	319829	19649G	PARTICIPANT	\N	PRESENT	0
323241	319829	14065Q	PARTICIPANT	\N	PRESENT	0
323242	319829	07034Q	PARTICIPANT	\N	PRESENT	0
323243	319829	10015M	PARTICIPANT	\N	PRESENT	0
323244	319829	08045X	PARTICIPANT	\N	PRESENT	0
323245	319829	14001X	PARTICIPANT	\N	PRESENT	0
323246	319829	01024M	PARTICIPANT	\N	PRESENT	0
323247	319829	04047H	PARTICIPANT	\N	PRESENT	0
323248	319829	01028R	PARTICIPANT	\N	PRESENT	0
323249	319829	19447X	PARTICIPANT	\N	PRESENT	0
323250	319829	05008E	PRESIDENT	0	PRESENT	0
323251	319829	19729F	PARTICIPANT	\N	PRESENT	0
323252	319829	95063L	PARTICIPANT	\N	PRESENT	0
323253	319829	08044W	PARTICIPANT	\N	PRESENT	0
323254	319829	14147R	PARTICIPANT	\N	PRESENT	0
323255	319829	14069U	PARTICIPANT	\N	PRESENT	0
323256	319829	14215L	PARTICIPANT	\N	PRESENT	0
323257	319829	11049P	PARTICIPANT	\N	PRESENT	0
323258	319829	14179A	PARTICIPANT	\N	PRESENT	0
323259	319829	14231L	PARTICIPANT	\N	EXCUSE	0
323260	314149	08024S	PARTICIPANT	\N	PRESENT	0
323261	320710	19551W	PARTICIPANT	\N	PRESENT	0
323262	314149	14281W	PARTICIPANT	\N	PRESENT	0
323263	314149	19295A	PARTICIPANT	\N	PRESENT	0
323265	314149	11067R	PARTICIPANT	\N	PRESENT	0
323270	314149	19563B	PARTICIPANT	\N	PRESENT	0
323279	314149	97011G	PARTICIPANT	\N	PRESENT	0
323285	314149	11012A	PARTICIPANT	\N	PRESENT	0
323294	319829	14034U	PARTICIPANT	\N	PRESENT	0
323295	319829	19671E	PARTICIPANT	\N	PRESENT	0
323296	319829	14199E	PARTICIPANT	\N	PRESENT	0
323297	314149	14179A	PARTICIPANT	\N	PRESENT	0
323298	314149	19399H	PARTICIPANT	\N	PRESENT	0
323299	320710	08024S	PARTICIPANT	\N	PRESENT	0
323300	320710	19733B	PARTICIPANT	\N	PRESENT	0
323301	314149	19569H	PARTICIPANT	\N	PRESENT	0
323302	314149	14235Q	PARTICIPANT	\N	PRESENT	0
323303	322159	01043Q	PARTICIPANT	\N	PRESENT	0
323304	314149	14217N	PARTICIPANT	\N	PRESENT	0
323305	314149	19335Q	PARTICIPANT	\N	PRESENT	0
323306	314149	14147R	PARTICIPANT	\N	PRESENT	0
323307	319829	11072N	PARTICIPANT	\N	PRESENT	0
323308	319829	11026G	PARTICIPANT	\N	PRESENT	0
323309	319829	19725B	PARTICIPANT	\N	PRESENT	0
323310	314149	19691J	PARTICIPANT	\N	PRESENT	0
323311	314149	19507S	PARTICIPANT	\N	PRESENT	0
323312	314149	01058X	PARTICIPANT	\N	PRESENT	0
323313	314149	11045K	PARTICIPANT	\N	PRESENT	0
323314	314149	19479G	PARTICIPANT	\N	PRESENT	0
323315	314149	14355X	PARTICIPANT	\N	PRESENT	0
323316	314149	14249W	PARTICIPANT	\N	PRESENT	0
323317	314149	14237S	PARTICIPANT	\N	PRESENT	0
323318	314149	14191V	PARTICIPANT	\N	PRESENT	0
323319	314149	14029X	PARTICIPANT	\N	PRESENT	0
323320	314149	01057W	PARTICIPANT	\N	PRESENT	0
323321	314149	08056B	PARTICIPANT	\N	PRESENT	0
323322	314149	11064N	PARTICIPANT	\N	PRESENT	0
323325	322159	19591F	PARTICIPANT	\N	PRESENT	0
323326	322159	19467C	PARTICIPANT	\N	PRESENT	0
323330	314149	07034Q	PARTICIPANT	\N	PRESENT	0
323332	314149	11072N	PARTICIPANT	\N	PRESENT	0
323333	322289	19533U	PARTICIPANT	\N	PRESENT	0
323334	322289	19573D	PARTICIPANT	\N	PRESENT	0
323335	322289	08017T	PARTICIPANT	\N	PRESENT	0
323336	322289	14073Q	PARTICIPANT	\N	PRESENT	0
323337	322289	19693L	PARTICIPANT	\N	PRESENT	0
323338	322289	14109K	PARTICIPANT	\N	PRESENT	0
323339	322289	19766L	PARTICIPANT	\N	EXCUSE	0
323340	322289	14061L	PARTICIPANT	\N	EXCUSE	0
323341	322289	08039A	PARTICIPANT	\N	EXCUSE	0
323342	314149	07029T	PARTICIPANT	\N	PRESENT	0
323343	314149	11048N	PARTICIPANT	\N	PRESENT	0
323344	314149	14039A	PARTICIPANT	\N	PRESENT	0
323345	314149	14107H	PARTICIPANT	\N	PRESENT	0
323346	321791	19697Q	PARTICIPANT	\N	PRESENT	0
323347	321791	11067R	PARTICIPANT	\N	PRESENT	0
323348	321791	11097X	PARTICIPANT	\N	PRESENT	0
323349	321791	04045F	PARTICIPANT	\N	PRESENT	0
323350	321791	14223L	PARTICIPANT	\N	PRESENT	0
323351	321791	14227Q	PARTICIPANT	\N	PRESENT	0
323352	321791	17779H	PARTICIPANT	\N	PRESENT	0
323353	321791	11031D	PARTICIPANT	\N	PRESENT	0
323354	321791	14239U	PARTICIPANT	\N	PRESENT	0
323355	321791	19703U	PARTICIPANT	\N	PRESENT	0
323356	321791	14281W	PARTICIPANT	\N	PRESENT	0
323357	321791	14087W	PARTICIPANT	\N	PRESENT	0
323358	321791	19679N	PARTICIPANT	\N	PRESENT	0
323359	321791	19575F	PARTICIPANT	\N	PRESENT	0
323360	321791	14195A	PARTICIPANT	\N	PRESENT	0
323361	321791	14213J	PARTICIPANT	\N	PRESENT	0
323362	321791	14217N	PARTICIPANT	\N	PRESENT	0
323363	321791	19335Q	PARTICIPANT	\N	PRESENT	0
323364	321791	19683J	PARTICIPANT	\N	PRESENT	0
323365	321791	10006L	PARTICIPANT	\N	PRESENT	0
323366	321791	98024R	PARTICIPANT	\N	PRESENT	0
323367	321791	19527W	PARTICIPANT	\N	PRESENT	0
323368	321791	01034P	PARTICIPANT	\N	PRESENT	0
323369	321791	04092N	PRESIDENT	0	PRESENT	0
323370	321791	11045K	PARTICIPANT	\N	PRESENT	0
323371	321791	08052W	PARTICIPANT	\N	PRESENT	0
323372	321791	19663E	PARTICIPANT	\N	PRESENT	0
323373	321791	19715Y	PARTICIPANT	\N	PRESENT	0
323374	321791	19691J	PARTICIPANT	\N	PRESENT	0
323375	321791	19723Y	PARTICIPANT	\N	PRESENT	0
323376	321791	19727D	PARTICIPANT	\N	PRESENT	0
323377	321791	11103C	PARTICIPANT	\N	PRESENT	0
323378	321791	14355X	PARTICIPANT	\N	PRESENT	0
323379	321791	14042U	PARTICIPANT	\N	EXCUSE	0
323380	321791	19367Y	PARTICIPANT	\N	EXCUSE	0
323381	321791	08041T	PARTICIPANT	\N	EXCUSE	0
323382	321791	19675J	PARTICIPANT	\N	EXCUSE	0
323383	321791	19415P	PARTICIPANT	\N	PRESENT	0
323384	321791	14026U	PARTICIPANT	\N	PRESENT	0
323385	321791	19553Y	PARTICIPANT	\N	PRESENT	0
323386	321791	14261S	PARTICIPANT	\N	PRESENT	0
323387	321791	14119M	PARTICIPANT	\N	PRESENT	0
323388	321791	14071N	PARTICIPANT	\N	PRESENT	0
323389	321791	19657G	PARTICIPANT	\N	PRESENT	0
323390	321791	19577H	PARTICIPANT	\N	PRESENT	0
304329	303956	19649G	PARTICIPANT	\N	PRESENT	0
304330	303956	14111D	PARTICIPANT	\N	PRESENT	0
304331	303956	14041T	PARTICIPANT	\N	PRESENT	0
304332	303956	07034Q	PARTICIPANT	\N	PRESENT	0
304333	303956	08045X	PARTICIPANT	\N	PRESENT	0
304334	303956	14225N	PARTICIPANT	\N	PRESENT	0
304335	303956	08052W	PARTICIPANT	\N	PRESENT	0
304336	303956	14069U	PARTICIPANT	\N	PRESENT	0
304337	303956	14215L	PARTICIPANT	\N	PRESENT	0
304338	303956	19719D	PARTICIPANT	\N	PRESENT	0
304339	303956	14053L	PARTICIPANT	\N	PRESENT	0
304340	303956	04047H	PARTICIPANT	\N	PRESENT	0
304341	303956	19729F	PARTICIPANT	\N	PRESENT	0
304342	303956	08061X	PARTICIPANT	\N	PRESENT	0
304343	303956	19673G	PARTICIPANT	\N	PRESENT	0
304344	303956	14329V	PARTICIPANT	\N	PRESENT	0
304345	303956	11066Q	PARTICIPANT	\N	PRESENT	0
304346	303956	14055N	PARTICIPANT	\N	PRESENT	0
304347	303956	14097Y	PARTICIPANT	\N	PRESENT	0
304348	303956	04061F	PARTICIPANT	\N	PRESENT	0
304349	303956	04044E	PARTICIPANT	\N	PRESENT	0
304350	303956	04059M	PARTICIPANT	\N	PRESENT	0
304351	303956	19689Q	PARTICIPANT	\N	PRESENT	0
304352	303956	01028R	PARTICIPANT	\N	PRESENT	0
304353	303956	11026G	PARTICIPANT	\N	PRESENT	0
304354	303956	11033F	PARTICIPANT	\N	PRESENT	0
304355	303956	19725B	PARTICIPANT	\N	PRESENT	0
304356	303956	95063L	PARTICIPANT	\N	PRESENT	0
304357	303956	11085T	PARTICIPANT	\N	PRESENT	0
304358	303956	14021P	PARTICIPANT	\N	PRESENT	0
304359	303956	11097X	PARTICIPANT	\N	PRESENT	0
304360	303956	04038G	PARTICIPANT	\N	PRESENT	0
304417	303956	14179A	PARTICIPANT	\N	PRESENT	0
304418	299337	19593H	PARTICIPANT	\N	PRESENT	0
304419	299337	19695N	PARTICIPANT	\N	PRESENT	0
304420	299337	14079W	PARTICIPANT	\N	PRESENT	0
304421	299337	98018T	PARTICIPANT	\N	PRESENT	0
304422	299337	11066Q	PARTICIPANT	\N	PRESENT	0
304423	299337	11027H	PARTICIPANT	\N	PRESENT	0
304424	299337	19699S	PARTICIPANT	\N	PRESENT	0
304425	299337	14089Y	PARTICIPANT	\N	PRESENT	0
304426	299337	14255U	PARTICIPANT	\N	PRESENT	0
304427	299337	11083R	PARTICIPANT	\N	PRESENT	0
304428	299337	14261S	PARTICIPANT	\N	PRESENT	0
304429	299337	11012A	PARTICIPANT	\N	PRESENT	0
304430	299337	95015C	PARTICIPANT	\N	PRESENT	0
304431	299337	19441R	PARTICIPANT	\N	PRESENT	0
304432	303956	19533U	PARTICIPANT	\N	PRESENT	0
304433	299337	97011G	PARTICIPANT	\N	PRESENT	0
304434	303956	14123H	PARTICIPANT	\N	PRESENT	0
304435	299337	14073Q	PARTICIPANT	\N	PRESENT	0
304436	299337	08031R	PARTICIPANT	\N	PRESENT	0
304437	299337	04040A	PARTICIPANT	\N	PRESENT	0
304438	299337	19731Y	PARTICIPANT	\N	PRESENT	0
304439	299337	14042U	PARTICIPANT	\N	PRESENT	0
304440	299337	08017T	PARTICIPANT	\N	PRESENT	0
304441	299337	19533U	PARTICIPANT	\N	PRESENT	0
304442	299337	19443T	PARTICIPANT	\N	PRESENT	0
304443	299337	14251Q	PARTICIPANT	\N	PRESENT	0
304444	303961	07034Q	PARTICIPANT	\N	PRESENT	0
304445	303961	11026G	PARTICIPANT	\N	PRESENT	0
304446	303961	04044E	PARTICIPANT	\N	PRESENT	0
304447	303961	14215L	PRESIDENT	0	PRESENT	0
304448	303961	08018U	PARTICIPANT	\N	PRESENT	0
304449	303961	19673G	PARTICIPANT	\N	PRESENT	0
304451	303961	01028R	PARTICIPANT	\N	PRESENT	0
304452	299337	14111D	PARTICIPANT	\N	PRESENT	0
304453	299337	14241N	PARTICIPANT	\N	PRESENT	0
304454	303961	14089Y	PARTICIPANT	\N	PRESENT	0
304455	303961	11049P	PARTICIPANT	\N	PRESENT	0
304456	303961	19729F	PARTICIPANT	\N	EXCUSE	0
304457	303961	01024M	PARTICIPANT	\N	EXCUSE	0
304458	303961	14231L	PARTICIPANT	\N	EXCUSE	0
304459	303961	14053L	PARTICIPANT	\N	PRESENT	0
304460	299337	19387D	PARTICIPANT	\N	PRESENT	0
304461	299337	14179A	PARTICIPANT	\N	PRESENT	0
304462	299337	08034U	PARTICIPANT	\N	PRESENT	0
304463	299337	14195A	PARTICIPANT	\N	PRESENT	0
304464	299337	08012N	PARTICIPANT	\N	PRESENT	0
304465	299337	04070G	PARTICIPANT	\N	PRESENT	0
304466	299337	14061L	PARTICIPANT	\N	PRESENT	0
306697	306695	08017T	PARTICIPANT	\N	PRESENT	0
304468	299337	14123H	PARTICIPANT	\N	PRESENT	0
306723	305883	08038Y	PARTICIPANT	\N	EXCUSE	0
308880	308745	14111D	PARTICIPANT	\N	PRESENT	0
308881	308745	14065Q	PARTICIPANT	\N	PRESENT	0
308882	308745	19649G	PARTICIPANT	\N	PRESENT	0
308883	308745	10015M	PARTICIPANT	\N	PRESENT	0
308884	308745	19253P	PARTICIPANT	\N	PRESENT	0
308885	308745	19543W	PARTICIPANT	\N	PRESENT	0
308886	308745	01028R	PARTICIPANT	\N	PRESENT	0
308887	308745	05008E	PRESIDENT	0	PRESENT	0
308888	308745	19447X	PARTICIPANT	\N	PRESENT	0
308889	308745	95063L	PARTICIPANT	\N	PRESENT	0
308890	308745	19629C	PARTICIPANT	\N	PRESENT	0
308891	308745	08044W	PARTICIPANT	\N	PRESENT	0
308892	308745	14069U	PARTICIPANT	\N	PRESENT	0
308893	308745	14215L	PARTICIPANT	\N	PRESENT	0
308894	308745	19762G	PARTICIPANT	\N	PRESENT	0
308895	308745	14053L	PARTICIPANT	\N	EXCUSE	0
308896	308745	04044E	PARTICIPANT	\N	EXCUSE	0
308897	308745	19585H	PARTICIPANT	\N	EXCUSE	0
308933	307421	14026U	PARTICIPANT	\N	PRESENT	0
308934	307421	14219Q	PARTICIPANT	\N	PRESENT	0
308935	307421	19565D	PARTICIPANT	\N	PRESENT	0
308936	307421	08043V	PARTICIPANT	\N	PRESENT	0
308937	307421	19583F	PARTICIPANT	\N	PRESENT	0
308938	307421	14059S	PARTICIPANT	\N	PRESENT	0
308939	307421	19593H	PARTICIPANT	\N	PRESENT	0
308940	307421	11104D	PARTICIPANT	\N	PRESENT	0
308941	307421	14103D	PARTICIPANT	\N	PRESENT	0
308942	307421	04070G	PARTICIPANT	\N	PRESENT	0
308943	307421	14257W	PARTICIPANT	\N	PRESENT	0
308944	307421	19637C	PARTICIPANT	\N	PRESENT	0
308945	307421	04057K	PARTICIPANT	\N	PRESENT	0
308946	307421	19735D	PARTICIPANT	\N	PRESENT	0
308947	307421	01025N	PARTICIPANT	\N	PRESENT	0
308948	307421	14030Q	PARTICIPANT	\N	PRESENT	0
308949	307421	19758L	PARTICIPANT	\N	PRESENT	0
308950	307421	19295A	PARTICIPANT	\N	PRESENT	0
308951	307421	14109K	PARTICIPANT	\N	PRESENT	0
308952	307421	14241N	PARTICIPANT	\N	PRESENT	0
308953	307421	08024S	PARTICIPANT	\N	PRESENT	0
308954	307421	19659J	PARTICIPANT	\N	PRESENT	0
308955	307421	19737F	PARTICIPANT	\N	PRESENT	0
308956	307421	08031R	PARTICIPANT	\N	PRESENT	0
308957	307421	14123H	PARTICIPANT	\N	PRESENT	0
308958	307421	17583W	PARTICIPANT	\N	PRESENT	0
308959	307421	19533U	PARTICIPANT	\N	PRESENT	0
308960	307421	95030B	PARTICIPANT	\N	PRESENT	0
308961	307421	07029T	PARTICIPANT	\N	PRESENT	0
308962	307421	19507S	PARTICIPANT	\N	PRESENT	0
308963	307421	19573D	PARTICIPANT	\N	PRESENT	0
308964	307421	14033T	PARTICIPANT	\N	PRESENT	0
308965	307421	14157T	PARTICIPANT	\N	PRESENT	0
308966	307421	04044E	PARTICIPANT	\N	PRESENT	0
308967	307421	19681G	PARTICIPANT	\N	PRESENT	0
308968	307421	19693L	PARTICIPANT	\N	PRESENT	0
308969	307421	08028W	PARTICIPANT	\N	PRESENT	0
308970	307421	19621T	PARTICIPANT	\N	PRESENT	0
308971	307421	14028W	PARTICIPANT	\N	PRESENT	0
308972	307421	19611R	PARTICIPANT	\N	PRESENT	0
308973	307421	14105F	PARTICIPANT	\N	PRESENT	0
308974	307421	19697Q	PARTICIPANT	\N	PRESENT	0
308975	307421	19631V	PARTICIPANT	\N	PRESENT	0
308976	307421	80027E	PARTICIPANT	\N	PRESENT	0
308977	307421	08068F	PARTICIPANT	\N	PRESENT	0
308978	307421	19333N	PARTICIPANT	\N	PRESENT	0
308979	307421	19349W	PARTICIPANT	\N	PRESENT	0
330252	321344	14107H	PARTICIPANT	\N	PRESENT	0
330253	321344	14069U	PARTICIPANT	\N	PRESENT	0
330254	321344	14033T	PARTICIPANT	\N	PRESENT	0
330255	321344	14031R	PARTICIPANT	\N	PRESENT	0
330256	321344	04086Q	PARTICIPANT	\N	PRESENT	0
330257	321344	08020N	PARTICIPANT	\N	PRESENT	0
330258	321344	14261S	PARTICIPANT	\N	PRESENT	0
330259	321344	11012A	PARTICIPANT	\N	PRESENT	0
330260	321344	04088S	PARTICIPANT	\N	PRESENT	0
330261	321344	95067Q	PARTICIPANT	\N	PRESENT	0
330262	321344	19575F	PARTICIPANT	\N	PRESENT	0
330263	321344	11097X	PARTICIPANT	\N	PRESENT	0
330264	321344	14187A	PARTICIPANT	\N	PRESENT	0
330265	321344	14026U	PARTICIPANT	\N	PRESENT	0
330266	321344	14223L	PARTICIPANT	\N	PRESENT	0
330267	321344	19531S	PARTICIPANT	\N	PRESENT	0
330268	321344	19413M	PARTICIPANT	\N	PRESENT	0
330269	321344	14265W	PARTICIPANT	\N	PRESENT	0
330270	321344	04049K	PARTICIPANT	\N	PRESENT	0
330271	321344	19467C	PARTICIPANT	\N	PRESENT	0
330272	321344	14173T	PARTICIPANT	\N	PRESENT	0
330273	321344	14159V	PARTICIPANT	\N	PRESENT	0
330274	321344	07029T	PARTICIPANT	\N	PRESENT	0
330275	321344	14073Q	PARTICIPANT	\N	PRESENT	0
330276	321344	08010L	PARTICIPANT	\N	PRESENT	0
330277	321344	08034U	PARTICIPANT	\N	PRESENT	0
330278	321344	14071N	PARTICIPANT	\N	PRESENT	0
330279	321344	14329V	PARTICIPANT	\N	PRESENT	0
330280	321344	01057W	PARTICIPANT	\N	PRESENT	0
330281	321344	14213J	PARTICIPANT	\N	PRESENT	0
330282	321344	14034U	PARTICIPANT	\N	PRESENT	0
330283	321344	11110B	PARTICIPANT	\N	PRESENT	0
330284	321344	08068F	PARTICIPANT	\N	PRESENT	0
330285	321344	14357A	PARTICIPANT	\N	PRESENT	0
330289	321344	08031R	PARTICIPANT	\N	PRESENT	0
330287	321344	08015R	PARTICIPANT	\N	PRESENT	0
330288	321344	19569H	PARTICIPANT	\N	PRESENT	0
330290	321344	19647E	PARTICIPANT	\N	PRESENT	0
330291	321344	89017R	PARTICIPANT	\N	PRESENT	0
330292	321344	19551W	PARTICIPANT	\N	PRESENT	0
330293	321344	19671E	PARTICIPANT	\N	PRESENT	0
330294	321344	19489J	PARTICIPANT	\N	PRESENT	0
330295	321344	08051V	PARTICIPANT	\N	PRESENT	0
330626	328229	14097Y	PARTICIPANT	\N	EXCUSE	0
330627	328229	14028W	PARTICIPANT	\N	EXCUSE	0
330829	330828	14179A	PARTICIPANT	\N	PRESENT	0
330830	330828	08045X	PARTICIPANT	\N	PRESENT	0
331290	330479	11067R	PARTICIPANT	\N	EXCUSE	0
331291	330479	19715Y	PARTICIPANT	\N	EXCUSE	0
331292	330479	17779H	PARTICIPANT	\N	EXCUSE	0
331293	330479	19657G	PARTICIPANT	\N	EXCUSE	0
331294	330479	19577H	PARTICIPANT	\N	EXCUSE	0
331299	331298	14215L	PARTICIPANT	\N	PRESENT	0
331300	331298	14001X	PARTICIPANT	\N	PRESENT	0
331338	331337	11048N	PARTICIPANT	\N	PRESENT	0
331346	331345	11048N	PARTICIPANT	\N	PRESENT	0
331588	329159	08018U	PARTICIPANT	\N	EXCUSE	0
331594	330924	11031D	PARTICIPANT	\N	EXCUSE	0
331605	331603	11048N	PARTICIPANT	\N	PRESENT	0
331606	331602	14069U	PARTICIPANT	\N	PRESENT	0
331611	331610	04085P	PARTICIPANT	\N	PRESENT	0
331612	331610	14038Y	PARTICIPANT	\N	PRESENT	0
331613	331610	19525U	PARTICIPANT	\N	PRESENT	0
331614	331610	19333N	PARTICIPANT	\N	PRESENT	0
331615	331610	14029X	PARTICIPANT	\N	PRESENT	0
331616	331610	08009T	PARTICIPANT	\N	PRESENT	0
331617	331610	19637C	PARTICIPANT	\N	PRESENT	0
331618	331610	19713W	PARTICIPANT	\N	PRESENT	0
331635	321350	04049K	PARTICIPANT	\N	PRESENT	0
331688	321351	11074Q	PARTICIPANT	\N	PRESENT	0
331689	331636	07029T	PARTICIPANT	\N	PRESENT	0
331690	331636	14083S	PARTICIPANT	\N	PRESENT	0
331691	331636	19647E	PARTICIPANT	\N	PRESENT	0
331692	331636	11048N	PARTICIPANT	\N	PRESENT	0
331693	331636	19651A	PARTICIPANT	\N	PRESENT	0
331694	331636	07004J	PARTICIPANT	\N	PRESENT	0
331695	331636	01057W	PARTICIPANT	\N	PRESENT	0
331696	331636	08010L	PARTICIPANT	\N	PRESENT	0
331697	331636	08011M	PARTICIPANT	\N	PRESENT	0
331698	331636	11074Q	PRESIDENT	0	PRESENT	0
331699	331636	19671E	PARTICIPANT	\N	PRESENT	0
331700	331636	88008L	PARTICIPANT	\N	PRESENT	0
331701	331636	11012A	PARTICIPANT	\N	PRESENT	0
331702	331636	19687N	PARTICIPANT	\N	PRESENT	0
331703	331636	04086Q	PARTICIPANT	\N	PRESENT	0
331704	331636	19545Y	PARTICIPANT	\N	PRESENT	0
331705	331636	08034U	PARTICIPANT	\N	PRESENT	0
331706	331636	14327T	PARTICIPANT	\N	PRESENT	0
331800	321352	08031R	PARTICIPANT	\N	PRESENT	0
331801	321352	14327T	PARTICIPANT	\N	PRESENT	0
331802	321352	95041E	PARTICIPANT	\N	PRESENT	0
331803	321352	99004R	PARTICIPANT	\N	PRESENT	0
331804	321352	11085T	PARTICIPANT	\N	PRESENT	0
331805	321352	14179A	PARTICIPANT	\N	PRESENT	0
331806	321352	11056N	PARTICIPANT	\N	PRESENT	0
331807	321352	07029T	PARTICIPANT	\N	PRESENT	0
331808	321352	08019V	PARTICIPANT	\N	PRESENT	0
331809	321352	08011M	PARTICIPANT	\N	PRESENT	0
331810	321352	11065P	PARTICIPANT	\N	PRESENT	0
331811	321352	14069U	PARTICIPANT	\N	PRESENT	0
331856	321353	19399H	PARTICIPANT	\N	PRESENT	0
331857	329070	19667J	PARTICIPANT	\N	PRESENT	0
331890	331889	14179A	PARTICIPANT	\N	PRESENT	0
331916	331915	14179A	PARTICIPANT	\N	PRESENT	0
331917	331915	08045X	PARTICIPANT	\N	PRESENT	0
331919	331918	14179A	PARTICIPANT	\N	PRESENT	0
331928	331927	04040A	PARTICIPANT	\N	PRESENT	0
331929	331927	14105F	PARTICIPANT	\N	PRESENT	0
331930	331927	08058D	PARTICIPANT	\N	PRESENT	0
331931	331927	04042C	PARTICIPANT	\N	PRESENT	0
331932	331927	14267Y	PARTICIPANT	\N	PRESENT	0
331933	331927	11027H	PARTICIPANT	\N	PRESENT	0
331934	331927	14079W	PARTICIPANT	\N	PRESENT	0
331935	331927	95037J	PARTICIPANT	\N	PRESENT	0
331936	331927	16685X	PARTICIPANT	\N	PRESENT	0
331937	331927	95030B	PARTICIPANT	\N	PRESENT	0
331938	331927	19319Q	PARTICIPANT	\N	PRESENT	0
331939	331927	19443T	PARTICIPANT	\N	PRESENT	0
331686	321351	04044E	PARTICIPANT	\N	PRESENT	0
331687	321351	08011M	PARTICIPANT	\N	PRESENT	0
331940	331927	14055N	PARTICIPANT	\N	PRESENT	0
331941	331927	19421M	PARTICIPANT	\N	PRESENT	0
331942	331927	01058X	PARTICIPANT	\N	PRESENT	0
331943	331927	19669L	PARTICIPANT	\N	PRESENT	0
331944	331927	11066Q	PARTICIPANT	\N	PRESENT	0
331945	331927	95067Q	PARTICIPANT	\N	PRESENT	0
331946	331927	04034C	PARTICIPANT	\N	PRESENT	0
332027	321355	04059M	PARTICIPANT	\N	PRESENT	0
332028	321355	07029T	PARTICIPANT	\N	PRESENT	0
332029	321355	19583F	PARTICIPANT	\N	PRESENT	0
332030	321355	11056N	PARTICIPANT	\N	PRESENT	0
332031	321355	14281W	PARTICIPANT	\N	PRESENT	0
332032	321355	14217N	PARTICIPANT	\N	PRESENT	0
332033	321355	19717B	PARTICIPANT	\N	PRESENT	0
331845	321353	14034U	PARTICIPANT	\N	PRESENT	0
331846	329070	04086Q	PARTICIPANT	\N	PRESENT	0
331847	329070	07029T	PARTICIPANT	\N	PRESENT	0
331848	329070	11048N	PRESIDENT	0	PRESENT	0
331849	329070	19711U	PARTICIPANT	\N	PRESENT	0
331850	329070	08034U	PARTICIPANT	\N	PRESENT	0
331851	329070	19689Q	PARTICIPANT	\N	PRESENT	0
331852	329070	11053K	PARTICIPANT	\N	PRESENT	0
331853	329070	19741B	PARTICIPANT	\N	PRESENT	0
331854	329070	08011M	PARTICIPANT	\N	PRESENT	0
331855	329070	99004R	PARTICIPANT	\N	PRESENT	0
332034	321355	07004J	PARTICIPANT	\N	PRESENT	0
332035	321355	19507S	PARTICIPANT	\N	PRESENT	0
332036	321355	04088S	PARTICIPANT	\N	PRESENT	0
332037	321355	14265W	PARTICIPANT	\N	PRESENT	0
332038	321355	14253S	PARTICIPANT	\N	PRESENT	0
332039	321355	95062K	PARTICIPANT	\N	PRESENT	0
332040	321355	11072N	PARTICIPANT	\N	PRESENT	0
332041	321355	19691J	PARTICIPANT	\N	PRESENT	0
332042	321355	19369B	PARTICIPANT	\N	PRESENT	0
332043	321355	19563B	PARTICIPANT	\N	PRESENT	0
332044	321355	08010L	PARTICIPANT	\N	PRESENT	0
332045	321355	19671E	PARTICIPANT	\N	PRESENT	0
332046	321355	19581D	PARTICIPANT	\N	PRESENT	0
332047	321355	08044W	PARTICIPANT	\N	PRESENT	0
332048	321355	19629C	PARTICIPANT	\N	PRESENT	0
332049	321355	14033T	PARTICIPANT	\N	PRESENT	0
332050	321355	04085P	PARTICIPANT	\N	PRESENT	0
332051	321355	19649G	PARTICIPANT	\N	PRESENT	0
332052	321355	11085T	PARTICIPANT	\N	PRESENT	0
332053	321355	08051V	PARTICIPANT	\N	PRESENT	0
332054	321355	01025N	PARTICIPANT	\N	PRESENT	0
332055	321355	04035D	PARTICIPANT	\N	PRESENT	0
332056	321355	08019V	PARTICIPANT	\N	PRESENT	0
302718	295644	19521Q	PARTICIPANT	\N	PRESENT	0
302719	295644	08062Y	PARTICIPANT	\N	PRESENT	0
302720	295644	19703U	PARTICIPANT	\N	PRESENT	0
302721	295644	19301E	PARTICIPANT	\N	PRESENT	0
302722	295644	14042U	PARTICIPANT	\N	PRESENT	0
302723	302583	14111D	PARTICIPANT	\N	PRESENT	0
302724	302583	19689Q	PARTICIPANT	\N	PRESENT	0
302725	295644	19749K	PARTICIPANT	\N	PRESENT	0
302726	295644	14030Q	PARTICIPANT	\N	PRESENT	0
302727	295644	14073Q	PARTICIPANT	\N	PRESENT	0
302728	295644	19553Y	PARTICIPANT	\N	PRESENT	0
302729	295644	08043V	PARTICIPANT	\N	PRESENT	0
302730	295644	08069G	PARTICIPANT	\N	PRESENT	0
302731	295644	14051J	PARTICIPANT	\N	PRESENT	0
302732	295644	11065P	PARTICIPANT	\N	PRESENT	0
302733	295644	19543W	PARTICIPANT	\N	PRESENT	0
302734	295644	14103D	PARTICIPANT	\N	PRESENT	0
302735	295644	04018C	PARTICIPANT	\N	PRESENT	0
302736	295644	14059S	PARTICIPANT	\N	PRESENT	0
302737	295644	19741B	PARTICIPANT	\N	PRESENT	0
302738	295644	14063N	PARTICIPANT	\N	PRESENT	0
302739	295644	04049K	PARTICIPANT	\N	PRESENT	0
302740	295644	14026U	PARTICIPANT	\N	PRESENT	0
302741	295644	14265W	PARTICIPANT	\N	PRESENT	0
302742	295644	14357A	PARTICIPANT	\N	PRESENT	0
302743	295644	19441R	PARTICIPANT	\N	PRESENT	0
302744	295644	19479G	PARTICIPANT	\N	PRESENT	0
302745	295644	11066Q	PARTICIPANT	\N	PRESENT	0
302746	295644	14205J	PARTICIPANT	\N	PRESENT	0
302747	295644	14173T	PARTICIPANT	\N	PRESENT	0
302748	295644	04059M	PARTICIPANT	\N	PRESENT	0
302749	302583	04047H	PARTICIPANT	\N	PRESENT	0
302750	302583	14237S	PARTICIPANT	\N	PRESENT	0
302751	302583	14259Y	PARTICIPANT	\N	PRESENT	0
302752	302583	98035U	PARTICIPANT	\N	PRESENT	0
302753	302583	12016W	PARTICIPANT	\N	PRESENT	0
305779	305575	01025N	PARTICIPANT	\N	EXCUSE	0
305780	305575	08021P	PARTICIPANT	\N	EXCUSE	0
305816	305557	01043Q	PARTICIPANT	\N	PRESENT	0
305820	305819	11053K	PARTICIPANT	\N	PRESENT	0
305821	305819	14159V	PARTICIPANT	\N	PRESENT	0
305822	305819	05012A	PARTICIPANT	\N	PRESENT	0
306735	306009	19671E	PARTICIPANT	\N	PRESENT	0
306736	306009	08011M	PARTICIPANT	\N	PRESENT	0
310259	310258	19575F	PARTICIPANT	\N	PRESENT	0
310260	310258	14069U	PARTICIPANT	\N	PRESENT	0
310261	310258	19545Y	PARTICIPANT	\N	PRESENT	0
310262	310258	04086Q	PARTICIPANT	\N	PRESENT	0
310263	310258	19647E	PARTICIPANT	\N	PRESENT	0
310264	310258	14179A	PARTICIPANT	\N	PRESENT	0
310265	310258	19441R	PARTICIPANT	\N	PRESENT	0
310266	310258	11067R	PARTICIPANT	\N	PRESENT	0
310267	310258	05012A	PARTICIPANT	\N	PRESENT	0
310268	310258	19669L	PARTICIPANT	\N	PRESENT	0
310269	310258	01062T	PARTICIPANT	\N	PRESENT	0
310270	310258	19766L	PARTICIPANT	\N	PRESENT	0
310271	310258	19565D	PARTICIPANT	\N	PRESENT	0
311634	311614	17589D	PARTICIPANT	\N	EXCUSE	0
311645	311614	08039A	PARTICIPANT	\N	EXCUSE	0
314351	309279	19575F	PARTICIPANT	\N	PRESENT	0
314354	309279	19762G	PARTICIPANT	\N	PRESENT	0
314360	309279	19489J	PARTICIPANT	\N	PRESENT	0
314361	309279	14107H	PARTICIPANT	\N	PRESENT	0
314362	309279	14105F	PARTICIPANT	\N	PRESENT	0
314363	309279	19367Y	PARTICIPANT	\N	PRESENT	0
314365	309279	19691J	PARTICIPANT	\N	PRESENT	0
314366	309279	14111D	PARTICIPANT	\N	PRESENT	0
314375	309279	14001X	PARTICIPANT	\N	PRESENT	0
314376	309279	19581D	PARTICIPANT	\N	PRESENT	0
314377	311724	19583F	PARTICIPANT	\N	EXCUSE	0
314378	311724	14275Y	PARTICIPANT	\N	EXCUSE	0
314379	311724	14097Y	PARTICIPANT	\N	EXCUSE	0
314380	311724	19659J	PARTICIPANT	\N	EXCUSE	0
314381	309279	19719D	PARTICIPANT	\N	PRESENT	0
314382	309279	19549D	PARTICIPANT	\N	PRESENT	0
314383	309279	11049P	PARTICIPANT	\N	PRESENT	0
314386	309279	14069U	PARTICIPANT	\N	PRESENT	0
314387	309279	01025N	PARTICIPANT	\N	PRESENT	0
314388	309279	14207L	PARTICIPANT	\N	PRESENT	0
314389	309279	19573D	PARTICIPANT	\N	PRESENT	0
314391	309279	14227Q	PARTICIPANT	\N	PRESENT	0
314393	309279	19725B	PARTICIPANT	\N	PRESENT	0
314396	309279	95067Q	PARTICIPANT	\N	PRESENT	0
314397	309279	14235Q	PARTICIPANT	\N	PRESENT	0
314398	309279	05008E	PARTICIPANT	\N	PRESENT	0
314405	309279	19711U	PARTICIPANT	\N	PRESENT	0
314406	309279	18083K	PARTICIPANT	\N	PRESENT	0
314409	309279	14061L	PARTICIPANT	\N	PRESENT	0
314410	309279	14053L	PARTICIPANT	\N	PRESENT	0
314411	309279	14083S	PARTICIPANT	\N	PRESENT	0
314416	309279	07029T	PARTICIPANT	\N	PRESENT	0
314417	309279	08045X	PARTICIPANT	\N	PRESENT	0
314418	309279	08053X	PARTICIPANT	\N	PRESENT	0
314420	309279	19553Y	PARTICIPANT	\N	PRESENT	0
314424	314188	19333N	PARTICIPANT	\N	PRESENT	0
314425	314188	14053L	PARTICIPANT	\N	PRESENT	0
314426	314188	98035U	PARTICIPANT	\N	PRESENT	0
314427	314188	14331P	PARTICIPANT	\N	PRESENT	0
314428	314188	19569H	PARTICIPANT	\N	PRESENT	0
314429	314188	01057W	PARTICIPANT	\N	PRESENT	0
314430	314188	01058X	PARTICIPANT	\N	PRESENT	0
314431	314188	11040E	PARTICIPANT	\N	PRESENT	0
314432	314188	19421M	PARTICIPANT	\N	PRESENT	0
314433	314188	19507S	PARTICIPANT	\N	PRESENT	0
314434	314188	19709B	PARTICIPANT	\N	PRESENT	0
314435	314188	96004D	PRESIDENT	0	PRESENT	0
314436	314188	98050T	PARTICIPANT	\N	PRESENT	0
314437	314188	04097T	PARTICIPANT	\N	PRESENT	0
314438	314188	14069U	PARTICIPANT	\N	PRESENT	0
314439	314188	04061F	PARTICIPANT	\N	PRESENT	0
314464	314348	08019V	PARTICIPANT	\N	PRESENT	0
314466	314348	19731Y	PARTICIPANT	\N	PRESENT	0
314468	314348	19383Y	PARTICIPANT	\N	PRESENT	0
314469	314348	04097T	PARTICIPANT	\N	PRESENT	0
314470	314348	14219Q	PARTICIPANT	\N	PRESENT	0
314462	314348	86034E	PARTICIPANT	\N	PRESENT	0
314463	314348	19399H	PARTICIPANT	\N	PRESENT	0
314471	314348	14041T	PARTICIPANT	\N	PRESENT	0
314472	314348	14355X	PARTICIPANT	\N	PRESENT	0
314473	314348	19467C	PARTICIPANT	\N	PRESENT	0
314474	314348	04088S	PARTICIPANT	\N	PRESENT	0
314475	314348	19415P	PARTICIPANT	\N	PRESENT	0
314476	314348	04047H	PARTICIPANT	\N	PRESENT	0
314477	314348	14223L	PARTICIPANT	\N	PRESENT	0
314478	314348	11072N	PARTICIPANT	\N	PRESENT	0
314479	314348	99004R	PARTICIPANT	\N	PRESENT	0
314480	314348	14157T	PARTICIPANT	\N	PRESENT	0
314481	314348	19703U	PARTICIPANT	\N	PRESENT	0
314482	314348	14042U	PARTICIPANT	\N	PRESENT	0
314483	314348	19289C	PARTICIPANT	\N	PRESENT	0
314484	314348	95030B	PARTICIPANT	\N	PRESENT	0
314485	314348	18083K	PARTICIPANT	\N	PRESENT	0
314486	314348	11101A	PARTICIPANT	\N	PRESENT	0
314487	314348	19629C	PARTICIPANT	\N	PRESENT	0
314488	314348	19253P	PARTICIPANT	\N	PRESENT	0
314489	314348	19565D	PARTICIPANT	\N	PRESENT	0
314490	314348	19347U	PARTICIPANT	\N	PRESENT	0
314491	314348	11031D	PARTICIPANT	\N	PRESENT	0
314492	314348	04085P	PARTICIPANT	\N	PRESENT	0
314493	314348	19758L	PARTICIPANT	\N	PRESENT	0
314494	314348	08055A	PARTICIPANT	\N	PRESENT	0
314495	314348	08052W	PARTICIPANT	\N	PRESENT	0
314496	314348	11074Q	PARTICIPANT	\N	PRESENT	0
314497	314348	14021P	PARTICIPANT	\N	PRESENT	0
314498	314348	19669L	PARTICIPANT	\N	PRESENT	0
314499	314348	14225N	PARTICIPANT	\N	PRESENT	0
314500	314348	11056N	PARTICIPANT	\N	PRESENT	0
314501	314348	19760E	PARTICIPANT	\N	PRESENT	0
314502	314348	19711U	PARTICIPANT	\N	PRESENT	0
314503	314348	14239U	PARTICIPANT	\N	PRESENT	0
314504	314348	96004D	PARTICIPANT	\N	PRESENT	0
305777	305575	11081P	PARTICIPANT	\N	EXCUSE	0
305778	305575	08015R	PARTICIPANT	\N	EXCUSE	0
314506	314348	11040E	PARTICIPANT	\N	PRESENT	0
314507	314348	15447F	PARTICIPANT	\N	PRESENT	0
314508	314348	19687N	PARTICIPANT	\N	PRESENT	0
314509	314348	01048V	PARTICIPANT	\N	PRESENT	0
314510	314348	19515S	PARTICIPANT	\N	PRESENT	0
314511	314348	80013X	PARTICIPANT	\N	PRESENT	0
314512	314348	01028R	PARTICIPANT	\N	PRESENT	0
314513	314348	14191V	PARTICIPANT	\N	PRESENT	0
314514	314348	12016W	PARTICIPANT	\N	PRESENT	0
314515	314348	14065Q	PARTICIPANT	\N	PRESENT	0
317300	317299	08055A	PARTICIPANT	\N	PRESENT	0
317301	317299	04047H	PARTICIPANT	\N	PRESENT	0
317302	317299	14085U	PARTICIPANT	\N	PRESENT	0
317303	317299	11083R	PARTICIPANT	\N	PRESENT	0
317304	317299	01057W	PARTICIPANT	\N	PRESENT	0
317305	317299	19611R	PARTICIPANT	\N	PRESENT	0
317306	317299	19687N	PARTICIPANT	\N	PRESENT	0
317307	317299	08049C	PARTICIPANT	\N	PRESENT	0
317308	317299	14157T	PARTICIPANT	\N	PRESENT	0
323486	314150	01043Q	PARTICIPANT	\N	PRESENT	0
323487	314150	04092N	PARTICIPANT	\N	PRESENT	0
323488	314150	01034P	PARTICIPANT	\N	PRESENT	0
323489	314150	11031D	PARTICIPANT	\N	PRESENT	0
323490	314150	19760E	PARTICIPANT	\N	PRESENT	0
323491	314150	14235Q	PARTICIPANT	\N	PRESENT	0
323492	314150	19515S	PARTICIPANT	\N	PRESENT	0
323493	314150	19295A	PARTICIPANT	\N	PRESENT	0
323494	314150	11067R	PARTICIPANT	\N	PRESENT	0
323495	314150	14031R	PARTICIPANT	\N	PRESENT	0
323496	314150	12016W	PARTICIPANT	\N	PRESENT	0
323497	314150	14033T	PARTICIPANT	\N	PRESENT	0
323498	314150	08052W	PARTICIPANT	\N	PRESENT	0
323499	314150	19443T	PARTICIPANT	\N	PRESENT	0
323500	314150	14039A	PARTICIPANT	\N	PRESENT	0
323501	314150	08073C	PARTICIPANT	\N	PRESENT	0
323502	314150	19447X	PARTICIPANT	\N	PRESENT	0
323503	314150	04088S	PARTICIPANT	\N	PRESENT	0
323504	314150	14029X	PARTICIPANT	\N	PRESENT	0
323505	314150	08047A	PARTICIPANT	\N	PRESENT	0
323506	314150	04045F	PARTICIPANT	\N	PRESENT	0
323507	314150	19387D	PARTICIPANT	\N	PRESENT	0
323508	314150	08019V	PARTICIPANT	\N	PRESENT	0
323509	314150	19563B	PARTICIPANT	\N	PRESENT	0
323510	314150	19575F	PARTICIPANT	\N	PRESENT	0
323511	314150	19697Q	PARTICIPANT	\N	PRESENT	0
323512	314150	14261S	PARTICIPANT	\N	PRESENT	0
323513	314150	14105F	PARTICIPANT	\N	PRESENT	0
323514	314150	19768N	PARTICIPANT	\N	PRESENT	0
323515	314150	19719D	PARTICIPANT	\N	PRESENT	0
323516	314150	14257W	PARTICIPANT	\N	PRESENT	0
323517	314150	08015R	PARTICIPANT	\N	PRESENT	0
323518	314150	14281W	PARTICIPANT	\N	PRESENT	0
323519	314150	04018C	PARTICIPANT	\N	PRESENT	0
323520	314150	19727D	PARTICIPANT	\N	PRESENT	0
323521	314150	14327T	PARTICIPANT	\N	PRESENT	0
323522	314150	19569H	PARTICIPANT	\N	PRESENT	0
323523	314150	17779H	PARTICIPANT	\N	PRESENT	0
323524	314150	14265W	PARTICIPANT	\N	PRESENT	0
323525	314150	01025N	PARTICIPANT	\N	PRESENT	0
323526	314150	14215L	PARTICIPANT	\N	PRESENT	0
323527	314150	19691J	PARTICIPANT	\N	PRESENT	0
323528	314150	14115H	PARTICIPANT	\N	PRESENT	0
323529	314150	19715Y	PARTICIPANT	\N	PRESENT	0
323530	314150	19577H	PARTICIPANT	\N	PRESENT	0
323531	314150	11103C	PARTICIPANT	\N	PRESENT	0
323532	314150	14187A	PARTICIPANT	\N	PRESENT	0
323533	314150	95030B	PARTICIPANT	\N	PRESENT	0
323534	314150	14071N	PARTICIPANT	\N	PRESENT	0
323535	314150	98024R	PARTICIPANT	\N	PRESENT	0
323536	314150	19679N	PARTICIPANT	\N	PRESENT	0
323537	314150	14213J	PARTICIPANT	\N	PRESENT	0
323538	314150	17637T	PARTICIPANT	\N	PRESENT	0
323539	314150	08069G	PARTICIPANT	\N	PRESENT	0
323540	314150	99004R	PARTICIPANT	\N	PRESENT	0
323541	314150	19703U	PARTICIPANT	\N	PRESENT	0
323542	314150	19762G	PARTICIPANT	\N	PRESENT	0
323543	314150	19467C	PARTICIPANT	\N	PRESENT	0
323544	314150	14026U	PARTICIPANT	\N	PRESENT	0
323545	314150	14357A	PARTICIPANT	\N	PRESENT	0
323546	314150	19479G	PARTICIPANT	\N	PRESENT	0
323547	314150	19421M	PARTICIPANT	\N	PRESENT	0
323548	314150	19758L	PARTICIPANT	\N	PRESENT	0
323549	314150	19565D	PARTICIPANT	\N	PRESENT	0
323550	314150	14038Y	PARTICIPANT	\N	PRESENT	0
323551	314150	14195A	PARTICIPANT	\N	PRESENT	0
323552	314150	14107H	PARTICIPANT	\N	PRESENT	0
323553	314150	14223L	PARTICIPANT	\N	PRESENT	0
323554	314150	19657G	PARTICIPANT	\N	PRESENT	0
323555	314150	14119M	PARTICIPANT	\N	PRESENT	0
323556	314150	95041E	PARTICIPANT	\N	PRESENT	0
323557	314150	14227Q	PARTICIPANT	\N	PRESENT	0
323558	314150	08020N	PARTICIPANT	\N	PRESENT	0
323559	314150	19737F	PARTICIPANT	\N	PRESENT	0
323560	314150	19507S	PARTICIPANT	\N	PRESENT	0
323561	314150	11090Q	PARTICIPANT	\N	PRESENT	0
323562	314150	19413M	PARTICIPANT	\N	PRESENT	0
323563	314150	10006L	PARTICIPANT	\N	PRESENT	0
323564	314150	14217N	PARTICIPANT	\N	PRESENT	0
323565	314150	14239U	PARTICIPANT	\N	PRESENT	0
323566	314150	19415P	PARTICIPANT	\N	PRESENT	0
323567	314150	19383Y	PARTICIPANT	\N	PRESENT	0
323568	314150	14073Q	PARTICIPANT	\N	PRESENT	0
323569	314150	19663E	PARTICIPANT	\N	PRESENT	0
323570	314150	19723Y	PARTICIPANT	\N	PRESENT	0
323571	314150	14207L	PARTICIPANT	\N	PRESENT	0
323572	314150	19629C	PARTICIPANT	\N	PRESENT	0
323573	314150	80013X	PARTICIPANT	\N	PRESENT	0
323574	314150	19335Q	PARTICIPANT	\N	PRESENT	0
323578	314150	08024S	PARTICIPANT	\N	PRESENT	0
323576	314150	11056N	PARTICIPANT	\N	PRESENT	0
323577	314150	11097X	PARTICIPANT	\N	PRESENT	0
323579	314150	14087W	PARTICIPANT	\N	PRESENT	0
323580	314150	19683J	PARTICIPANT	\N	PRESENT	0
323581	314150	19621T	PARTICIPANT	\N	PRESENT	0
323582	314150	14030Q	PARTICIPANT	\N	PRESENT	0
323583	314150	17589D	PARTICIPANT	\N	PRESENT	0
323584	314150	08010L	PARTICIPANT	\N	PRESENT	0
323585	314150	19693L	PARTICIPANT	\N	PRESENT	0
323586	314150	19553Y	PARTICIPANT	\N	PRESENT	0
323587	314150	14147R	PARTICIPANT	\N	PRESENT	0
323588	314150	14229S	PARTICIPANT	\N	PRESENT	0
323589	314150	19573D	PARTICIPANT	\N	PRESENT	0
323590	314150	02002K	PARTICIPANT	\N	PRESENT	0
323591	314150	19713W	PARTICIPANT	\N	PRESENT	0
323592	314150	04070G	PARTICIPANT	\N	PRESENT	0
323593	314150	19527W	PARTICIPANT	\N	PRESENT	0
323594	314150	89017R	PARTICIPANT	\N	PRESENT	0
323595	314150	14083S	PARTICIPANT	\N	PRESENT	0
323596	314150	14069U	PARTICIPANT	\N	PRESENT	0
323597	314150	19699S	PARTICIPANT	\N	PRESENT	0
323598	314150	04033B	PARTICIPANT	\N	PRESENT	0
323599	317557	19659J	PARTICIPANT	\N	EXCUSE	0
323600	317557	14219Q	PARTICIPANT	\N	EXCUSE	0
323601	317557	14225N	PARTICIPANT	\N	EXCUSE	0
323683	321791	19521Q	PARTICIPANT	\N	EXCUSE	0
323963	323962	04040A	PRESIDENT	0	PRESENT	0
323968	321134	14079W	PARTICIPANT	\N	EXCUSE	0
323969	321134	04035D	PARTICIPANT	\N	EXCUSE	0
323982	323981	01024M	PARTICIPANT	\N	PRESENT	0
323984	323983	01024M	PARTICIPANT	\N	PRESENT	0
324188	324187	11053K	PARTICIPANT	\N	PRESENT	0
324189	324187	14159V	PARTICIPANT	\N	PRESENT	0
324190	324187	05012A	PARTICIPANT	\N	PRESENT	0
324609	324608	19593H	PARTICIPANT	\N	PRESENT	0
324610	324608	19251M	PARTICIPANT	\N	PRESENT	0
324633	324632	19533U	PARTICIPANT	\N	PRESENT	0
324638	324637	19533U	PARTICIPANT	\N	PRESENT	0
324644	324640	19629C	PARTICIPANT	\N	PRESENT	0
324646	324645	19533U	PARTICIPANT	\N	PRESENT	0
324649	324648	19533U	PARTICIPANT	\N	PRESENT	0
324674	324673	14051J	PARTICIPANT	\N	PRESENT	0
324680	324679	14169X	PARTICIPANT	\N	PRESENT	0
324710	324709	01057W	PARTICIPANT	\N	PRESENT	0
324711	324709	14225N	PARTICIPANT	\N	PRESENT	0
324713	324712	14331P	PARTICIPANT	\N	PRESENT	0
324832	324831	08039A	PARTICIPANT	\N	PRESENT	0
324833	324831	08043V	PARTICIPANT	\N	PRESENT	0
324836	324835	19699S	PARTICIPANT	\N	PRESENT	0
324854	324853	14133K	PARTICIPANT	\N	PRESENT	0
324855	324853	08058D	PARTICIPANT	\N	PRESENT	0
325055	322456	19551W	PARTICIPANT	\N	PRESENT	0
325058	322456	14147R	PARTICIPANT	\N	PRESENT	0
325059	322456	19369B	PARTICIPANT	\N	PRESENT	0
325148	322456	19667J	PARTICIPANT	\N	EXCUSE	0
325179	322456	08045X	PARTICIPANT	\N	PRESENT	0
325180	322456	19647E	PARTICIPANT	\N	EXCUSE	0
325207	323962	05012A	PARTICIPANT	\N	EXCUSE	0
325216	320182	19715Y	PARTICIPANT	\N	PRESENT	0
325377	325376	08043V	PARTICIPANT	\N	PRESENT	0
325379	325378	08043V	PARTICIPANT	\N	PRESENT	0
325418	322759	14038Y	PARTICIPANT	\N	PRESENT	0
325419	322759	14259Y	PARTICIPANT	\N	EXCUSE	0
325420	322759	19659J	PARTICIPANT	\N	EXCUSE	0
325421	322759	19715Y	PARTICIPANT	\N	PRESENT	0
325422	322759	14097Y	PARTICIPANT	\N	PRESENT	0
305368	305367	19667J	PARTICIPANT	\N	PRESENT	0
305369	305367	14255U	PARTICIPANT	\N	PRESENT	0
305370	305367	19701S	PARTICIPANT	\N	PRESENT	0
305371	305367	11026G	PARTICIPANT	\N	PRESENT	0
306391	305954	19663E	PARTICIPANT	\N	EXCUSE	0
308980	307421	19421M	PARTICIPANT	\N	PRESENT	0
308981	307421	04034C	PARTICIPANT	\N	PRESENT	0
308982	307421	14267Y	PARTICIPANT	\N	PRESENT	0
308983	307421	80013X	PARTICIPANT	\N	PRESENT	0
309173	309172	19583F	PARTICIPANT	\N	PRESENT	0
309174	309172	12041X	PARTICIPANT	\N	PRESENT	0
309175	309172	08049C	PARTICIPANT	\N	PRESENT	0
309176	309172	04034C	PARTICIPANT	\N	PRESENT	0
309177	309172	14267Y	PARTICIPANT	\N	PRESENT	0
309178	309172	08058D	PARTICIPANT	\N	PRESENT	0
309179	309172	14193X	PARTICIPANT	\N	PRESENT	0
309180	309172	04042C	PARTICIPANT	\N	PRESENT	0
309183	305977	19683J	PARTICIPANT	\N	PRESENT	0
309184	309057	19741B	PARTICIPANT	\N	PRESENT	0
309185	309057	08043V	PARTICIPANT	\N	PRESENT	0
309186	309057	04038G	PARTICIPANT	\N	PRESENT	0
309187	309057	19253P	PARTICIPANT	\N	PRESENT	0
309188	309057	14357A	PARTICIPANT	\N	PRESENT	0
309189	309057	11070L	PRESIDENT	0	PRESENT	0
309190	309057	04097T	PARTICIPANT	\N	PRESENT	0
309191	309057	19531S	PARTICIPANT	\N	PRESENT	0
309192	309057	19711U	PARTICIPANT	\N	PRESENT	0
309193	309057	12016W	PARTICIPANT	\N	PRESENT	0
309194	309057	17637T	PARTICIPANT	\N	PRESENT	0
313389	310419	19663E	PARTICIPANT	\N	EXCUSE	0
309196	309057	19689Q	PARTICIPANT	\N	PRESENT	0
309197	309057	11041F	PARTICIPANT	\N	PRESENT	0
309198	309057	19533U	PARTICIPANT	\N	PRESENT	0
309199	309057	95062K	PARTICIPANT	\N	EXCUSE	0
314395	305897	19629C	PARTICIPANT	\N	PRESENT	0
314419	305897	19349W	PARTICIPANT	\N	EXCUSE	0
314421	305897	14147R	PARTICIPANT	\N	PRESENT	0
314422	305897	11066Q	PARTICIPANT	\N	PRESENT	0
314423	305897	19737F	PARTICIPANT	\N	PRESENT	0
314440	305897	19515S	PARTICIPANT	\N	PRESENT	0
314442	305897	04038G	PARTICIPANT	\N	PRESENT	0
314443	305897	14107H	PARTICIPANT	\N	PRESENT	0
314444	305897	19369B	PARTICIPANT	\N	PRESENT	0
316431	314187	89017R	PARTICIPANT	\N	PRESENT	0
316432	314187	14083S	PARTICIPANT	\N	PRESENT	0
316433	314187	19711U	PARTICIPANT	\N	PRESENT	0
316434	314187	04049K	PARTICIPANT	\N	PRESENT	0
316435	314187	19760E	PARTICIPANT	\N	PRESENT	0
316437	314187	14187A	PARTICIPANT	\N	PRESENT	0
316438	314187	19521Q	PRESIDENT	0	PRESENT	0
316439	314187	19695N	PARTICIPANT	\N	PRESENT	0
316440	314187	14026U	PARTICIPANT	\N	PRESENT	0
316441	314187	19399H	PARTICIPANT	\N	PRESENT	0
316442	314187	14227Q	PARTICIPANT	\N	PRESENT	0
316443	314187	19515S	PARTICIPANT	\N	PRESENT	0
316444	314187	11070L	PARTICIPANT	\N	PRESENT	0
316445	314187	14329V	PARTICIPANT	\N	PRESENT	0
316446	314187	08034U	PARTICIPANT	\N	PRESENT	0
316447	314187	19631V	PARTICIPANT	\N	PRESENT	0
316448	314187	12016W	PARTICIPANT	\N	PRESENT	0
316449	314187	19441R	PARTICIPANT	\N	PRESENT	0
316450	314187	14159V	PARTICIPANT	\N	PRESENT	0
316451	314187	11053K	PARTICIPANT	\N	PRESENT	0
316452	314187	04034C	PARTICIPANT	\N	PRESENT	0
316453	314187	11048N	PARTICIPANT	\N	PRESENT	0
316454	314187	19762G	PARTICIPANT	\N	PRESENT	0
316455	314187	14157T	PARTICIPANT	\N	PRESENT	0
316456	314187	14199E	PARTICIPANT	\N	PRESENT	0
316459	314187	11110B	PARTICIPANT	\N	PRESENT	0
316463	314187	14034U	PARTICIPANT	\N	PRESENT	0
316467	314187	19717B	PARTICIPANT	\N	EXCUSE	0
316468	314187	08068F	PARTICIPANT	\N	EXCUSE	0
316469	314187	14051J	PARTICIPANT	\N	EXCUSE	0
316470	314187	14173T	PARTICIPANT	\N	EXCUSE	0
316471	314187	19545Y	PARTICIPANT	\N	EXCUSE	0
317418	317417	96004D	PARTICIPANT	\N	PRESENT	0
317419	317417	04035D	PARTICIPANT	\N	PRESENT	0
317420	317417	11040E	PARTICIPANT	\N	PRESENT	0
317421	317417	14001X	PARTICIPANT	\N	PRESENT	0
317422	317417	19333N	PARTICIPANT	\N	PRESENT	0
317423	317417	08031R	PARTICIPANT	\N	PRESENT	0
317424	317417	04097T	PARTICIPANT	\N	PRESENT	0
317425	317417	11083R	PARTICIPANT	\N	PRESENT	0
318745	317473	14087W	PARTICIPANT	\N	PRESENT	0
318746	317473	19679N	PARTICIPANT	\N	PRESENT	0
322035	322034	10015M	PARTICIPANT	\N	PRESENT	0
318748	317474	14087W	PARTICIPANT	\N	PRESENT	0
318751	317475	14087W	PARTICIPANT	\N	PRESENT	0
322037	322036	10015M	PARTICIPANT	\N	PRESENT	0
322039	322038	10015M	PARTICIPANT	\N	PRESENT	0
322078	322040	10015M	PARTICIPANT	\N	PRESENT	0
324071	314152	14217N	PARTICIPANT	\N	PRESENT	0
324242	314152	14199E	PARTICIPANT	\N	PRESENT	0
324243	321822	14053L	PARTICIPANT	\N	PRESENT	0
324244	321822	14065Q	PARTICIPANT	\N	PRESENT	0
324245	321822	01057W	PARTICIPANT	\N	PRESENT	0
324246	321822	07034Q	PARTICIPANT	\N	PRESENT	0
324247	321822	14001X	PARTICIPANT	\N	PRESENT	0
324248	321822	19581D	PARTICIPANT	\N	PRESENT	0
324249	321822	04044E	PARTICIPANT	\N	PRESENT	0
324250	321822	01028R	PARTICIPANT	\N	PRESENT	0
324251	321822	05008E	PRESIDENT	0	PRESENT	0
324252	321822	19447X	PARTICIPANT	\N	PRESENT	0
324253	321822	95063L	PARTICIPANT	\N	PRESENT	0
324254	321822	08044W	PARTICIPANT	\N	PRESENT	0
324255	321822	14147R	PARTICIPANT	\N	PRESENT	0
324256	321822	14179A	PARTICIPANT	\N	PRESENT	0
324257	321822	14069U	PARTICIPANT	\N	PRESENT	0
324258	321822	14151M	PARTICIPANT	\N	PRESENT	0
324259	321822	11085T	PARTICIPANT	\N	PRESENT	0
324260	321822	14259Y	PARTICIPANT	\N	PRESENT	0
324261	321822	19729F	PARTICIPANT	\N	EXCUSE	0
324262	321822	04047H	PARTICIPANT	\N	EXCUSE	0
324263	321822	14089Y	PARTICIPANT	\N	PRESENT	0
324264	314152	14087W	PARTICIPANT	\N	PRESENT	0
324265	314152	19349W	PARTICIPANT	\N	PRESENT	0
324266	320716	14219Q	PARTICIPANT	\N	PRESENT	0
324267	320716	19289C	PARTICIPANT	\N	PRESENT	0
324268	314152	07004J	PARTICIPANT	\N	PRESENT	0
324278	320716	19701S	PARTICIPANT	\N	PRESENT	0
324279	320716	19387D	PARTICIPANT	\N	PRESENT	0
324280	314152	17637T	PARTICIPANT	\N	PRESENT	0
324281	314152	19669L	PARTICIPANT	\N	PRESENT	0
324284	314152	08061X	PARTICIPANT	\N	PRESENT	0
324287	314152	19479G	PARTICIPANT	\N	PRESENT	0
324288	314152	11012A	PARTICIPANT	\N	PRESENT	0
324289	314152	14133K	PARTICIPANT	\N	PRESENT	0
324293	324290	08009T	PARTICIPANT	\N	PRESENT	0
324294	324290	19737F	PARTICIPANT	\N	PRESENT	0
324295	324290	19713W	PARTICIPANT	\N	PRESENT	0
324296	324290	19739H	PARTICIPANT	\N	PRESENT	0
324298	314152	19269X	PARTICIPANT	\N	PRESENT	0
324299	314152	11083R	PARTICIPANT	\N	PRESENT	0
324300	321822	08045X	PARTICIPANT	\N	PRESENT	0
324301	321822	01024M	PARTICIPANT	\N	PRESENT	0
324302	322292	19699S	PARTICIPANT	\N	PRESENT	0
324303	322292	14073Q	PARTICIPANT	\N	PRESENT	0
324304	322292	19693L	PARTICIPANT	\N	PRESENT	0
324305	314152	01057W	PARTICIPANT	\N	PRESENT	0
501138	500241	20108W	PARTICIPANT	\N	PRESENT	0
501153	500571	17367Q	PARTICIPANT	\N	PRESENT	0
501159	500241	19543W	PARTICIPANT	\N	PRESENT	0
501160	500241	04047H	PRESIDENT	0	PRESENT	0
501161	500241	01028R	PARTICIPANT	\N	PRESENT	0
501162	500241	14231L	PARTICIPANT	\N	PRESENT	0
501163	500241	11056N	PARTICIPANT	\N	PRESENT	0
501164	500241	17737W	PARTICIPANT	\N	PRESENT	0
501165	500241	95063L	PARTICIPANT	\N	PRESENT	0
501166	500241	14147R	PARTICIPANT	\N	PRESENT	0
501167	500241	20114U	PARTICIPANT	\N	PRESENT	0
501168	500241	14259Y	PARTICIPANT	\N	PRESENT	0
502389	502380	19631V	PARTICIPANT	\N	PRESENT	0
501538	500502	19467C	PARTICIPANT	\N	PRESENT	0
501539	500116	20142Y	PARTICIPANT	\N	PRESENT	0
502392	502391	20134Y	PARTICIPANT	\N	PRESENT	0
502393	502391	20058E	PARTICIPANT	\N	PRESENT	0
502394	502391	11104D	PARTICIPANT	\N	PRESENT	0
502397	502395	11104D	PARTICIPANT	\N	PRESENT	0
502398	502395	20058E	PARTICIPANT	\N	PRESENT	0
502399	502395	19527W	PARTICIPANT	\N	PRESENT	0
502404	502403	11104D	PARTICIPANT	\N	PRESENT	0
502407	502403	20058E	PARTICIPANT	\N	PRESENT	0
502408	502403	19527W	PARTICIPANT	\N	PRESENT	0
502409	502403	20098N	PARTICIPANT	\N	PRESENT	0
502411	502410	11104D	PARTICIPANT	\N	PRESENT	0
502412	502410	20058E	PARTICIPANT	\N	PRESENT	0
502413	502410	19527W	PARTICIPANT	\N	PRESENT	0
502416	502415	20134Y	PARTICIPANT	\N	PRESENT	0
330530	326842	19657G	PARTICIPANT	\N	EXCUSE	0
331296	331037	11065P	PARTICIPANT	\N	PRESENT	0
330528	326842	19663E	PARTICIPANT	\N	PRESENT	0
330529	326842	19577H	PARTICIPANT	\N	EXCUSE	0
331297	326848	11065P	PARTICIPANT	\N	PRESENT	0
332362	331358	08048B	PARTICIPANT	\N	EXCUSE	0
332360	331358	11101A	PARTICIPANT	\N	EXCUSE	0
332361	331358	14028W	PARTICIPANT	\N	EXCUSE	0
332363	331358	11048N	PARTICIPANT	\N	EXCUSE	0
332495	321362	11041F	PARTICIPANT	\N	PRESENT	0
332496	321362	19583F	PARTICIPANT	\N	PRESENT	0
332497	321362	19581D	PARTICIPANT	\N	PRESENT	0
332498	321362	88008L	PARTICIPANT	\N	PRESENT	0
332499	321362	04042C	PARTICIPANT	\N	PRESENT	0
332500	321362	19683J	PARTICIPANT	\N	PRESENT	0
332501	321362	12041X	PARTICIPANT	\N	PRESENT	0
332502	321362	19711U	PARTICIPANT	\N	PRESENT	0
332503	321362	11074Q	PARTICIPANT	\N	PRESENT	0
332504	321362	04034C	PARTICIPANT	\N	PRESENT	0
332505	321362	01062T	PARTICIPANT	\N	PRESENT	0
332506	321362	14235Q	PARTICIPANT	\N	PRESENT	0
332507	321362	16685X	PARTICIPANT	\N	PRESENT	0
332508	321362	04070G	PARTICIPANT	\N	PRESENT	0
332509	321362	01058X	PARTICIPANT	\N	PRESENT	0
332510	321362	19367Y	PARTICIPANT	\N	PRESENT	0
332511	321362	14211G	PARTICIPANT	\N	PRESENT	0
332512	321362	19669L	PARTICIPANT	\N	PRESENT	0
332513	321362	19651A	PARTICIPANT	\N	PRESENT	0
332514	321362	19695N	PARTICIPANT	\N	PRESENT	0
332515	321362	14028W	PARTICIPANT	\N	PRESENT	0
332516	321362	95067Q	PARTICIPANT	\N	PRESENT	0
332517	321362	14331P	PARTICIPANT	\N	PRESENT	0
332518	321362	14215L	PARTICIPANT	\N	PRESENT	0
332519	321362	04035D	PARTICIPANT	\N	PRESENT	0
332520	321362	98022P	PARTICIPANT	\N	PRESENT	0
332521	321362	19715Y	PARTICIPANT	\N	PRESENT	0
332522	321362	12016W	PARTICIPANT	\N	PRESENT	0
332523	321362	11027H	PARTICIPANT	\N	PRESENT	0
332524	321362	04033B	PARTICIPANT	\N	PRESENT	0
332525	321362	99004R	PARTICIPANT	\N	PRESENT	0
332526	321362	02002K	PARTICIPANT	\N	PRESENT	0
332527	321362	19533U	PARTICIPANT	\N	PRESENT	0
332528	321362	14073Q	PARTICIPANT	\N	PRESENT	0
332529	321362	14225N	PARTICIPANT	\N	PRESENT	0
332530	321362	04059M	PARTICIPANT	\N	PRESENT	0
332531	321362	19687N	PARTICIPANT	\N	PRESENT	0
332532	321362	98050T	PARTICIPANT	\N	PRESENT	0
332533	321362	08019V	PARTICIPANT	\N	PRESENT	0
332534	321362	11054L	PARTICIPANT	\N	PRESENT	0
332535	321362	14051J	PARTICIPANT	\N	PRESENT	0
332536	321362	19693L	PARTICIPANT	\N	PRESENT	0
332493	321362	11072N	PARTICIPANT	\N	PRESENT	0
332494	331358	14063N	PARTICIPANT	\N	EXCUSE	0
332537	321362	08017T	PARTICIPANT	\N	PRESENT	0
332538	321362	19443T	PARTICIPANT	\N	PRESENT	0
332539	321362	11026G	PARTICIPANT	\N	PRESENT	0
332541	321362	14237S	PARTICIPANT	\N	PRESENT	0
332542	321362	14159V	PARTICIPANT	\N	PRESENT	0
332543	321362	19611R	PARTICIPANT	\N	PRESENT	0
332544	321362	11070L	PARTICIPANT	\N	PRESENT	0
332545	321362	98018T	PARTICIPANT	\N	PRESENT	0
332546	321362	19741B	PARTICIPANT	\N	PRESENT	0
332547	321362	11012A	PARTICIPANT	\N	PRESENT	0
332548	321362	19657G	PARTICIPANT	\N	PRESENT	0
332549	321362	19647E	PARTICIPANT	\N	PRESENT	0
332550	321362	98029W	PARTICIPANT	\N	PRESENT	0
332551	321362	14255U	PARTICIPANT	\N	PRESENT	0
332552	321362	04086Q	PARTICIPANT	\N	PRESENT	0
332553	332445	04038G	PARTICIPANT	\N	PRESENT	0
332554	321362	08061X	PARTICIPANT	\N	PRESENT	0
332555	328145	14107H	PARTICIPANT	\N	PRESENT	0
332556	321362	11110B	PARTICIPANT	\N	PRESENT	0
332557	321362	04071H	PARTICIPANT	\N	PRESENT	0
332558	321362	19766L	PARTICIPANT	\N	PRESENT	0
332559	321362	19479G	PARTICIPANT	\N	PRESENT	0
332560	321362	19735D	PARTICIPANT	\N	PRESENT	0
332561	331358	95063L	PARTICIPANT	\N	EXCUSE	0
332562	321362	19621T	PARTICIPANT	\N	PRESENT	0
332563	321362	19725B	PARTICIPANT	\N	PRESENT	0
332564	321362	95037J	PARTICIPANT	\N	PRESENT	0
332566	321362	89017R	PARTICIPANT	\N	PRESENT	0
332567	321362	14085U	PARTICIPANT	\N	PRESENT	0
332568	321362	14249W	PARTICIPANT	\N	PRESENT	0
332569	321362	04043D	PARTICIPANT	\N	PRESENT	0
332570	321362	08031R	PARTICIPANT	\N	PRESENT	0
332571	321362	19593H	PARTICIPANT	\N	PRESENT	0
332572	321362	19673G	PARTICIPANT	\N	PRESENT	0
332573	321362	01057W	PARTICIPANT	\N	PRESENT	0
332574	321362	07034Q	PARTICIPANT	\N	PRESENT	0
332575	321362	14275Y	PARTICIPANT	\N	PRESENT	0
332576	321362	11083R	PARTICIPANT	\N	PRESENT	0
332577	321362	14030Q	PARTICIPANT	\N	PRESENT	0
332628	321363	14331P	PARTICIPANT	\N	PRESENT	0
332629	321363	11074Q	PARTICIPANT	\N	PRESENT	0
332630	321363	19593H	PARTICIPANT	\N	PRESENT	0
332631	321363	19503N	PARTICIPANT	\N	PRESENT	0
332632	321363	08017T	PARTICIPANT	\N	PRESENT	0
332633	321363	08043V	PARTICIPANT	\N	PRESENT	0
332634	321363	14051J	PARTICIPANT	\N	PRESENT	0
332635	321363	14039A	PARTICIPANT	\N	PRESENT	0
332636	321363	14275Y	PARTICIPANT	\N	PRESENT	0
332637	321363	19735D	PARTICIPANT	\N	PRESENT	0
332638	321363	19611R	PARTICIPANT	\N	PRESENT	0
332639	321363	14030Q	PARTICIPANT	\N	PRESENT	0
332640	321363	04089T	PARTICIPANT	\N	PRESENT	0
332641	321363	19367Y	PARTICIPANT	\N	PRESENT	0
332642	321363	19621T	PARTICIPANT	\N	PRESENT	0
332643	321363	04033B	PARTICIPANT	\N	PRESENT	0
332644	321363	19581D	PARTICIPANT	\N	PRESENT	0
332645	321363	14229S	PARTICIPANT	\N	PRESENT	0
332646	321363	14069U	PARTICIPANT	\N	PRESENT	0
332647	321363	04088S	PARTICIPANT	\N	PRESENT	0
332648	321363	19693L	PARTICIPANT	\N	PRESENT	0
332649	321363	19533U	PARTICIPANT	\N	PRESENT	0
332650	321363	15447F	PARTICIPANT	\N	PRESENT	0
332651	321363	14235Q	PARTICIPANT	\N	PRESENT	0
332652	321363	08031R	PARTICIPANT	\N	PRESENT	0
332653	321363	11083R	PARTICIPANT	\N	PRESENT	0
332654	321363	04043D	PARTICIPANT	\N	PRESENT	0
332655	321363	19741B	PARTICIPANT	\N	PRESENT	0
332656	321363	19747H	PARTICIPANT	\N	PRESENT	0
332657	321363	04070G	PARTICIPANT	\N	PRESENT	0
332658	321363	08015R	PARTICIPANT	\N	PRESENT	0
332659	321363	98022P	PARTICIPANT	\N	PRESENT	0
332660	321363	19647E	PARTICIPANT	\N	PRESENT	0
332661	321363	14159V	PARTICIPANT	\N	PRESENT	0
332662	321363	10006L	PARTICIPANT	\N	PRESENT	0
332663	321363	11026G	PARTICIPANT	\N	PRESENT	0
332664	321363	02002K	PARTICIPANT	\N	PRESENT	0
332665	321363	95041E	PARTICIPANT	\N	PRESENT	0
332666	321363	14249W	PARTICIPANT	\N	PRESENT	0
332667	321363	14151M	PARTICIPANT	\N	PRESENT	0
332668	321363	01028R	PARTICIPANT	\N	PRESENT	0
332669	321363	19479G	PARTICIPANT	\N	PRESENT	0
332670	321363	14073Q	PARTICIPANT	\N	PRESENT	0
332671	321363	05012A	PARTICIPANT	\N	PRESENT	0
332672	321363	08061X	PARTICIPANT	\N	PRESENT	0
332674	332673	04085P	PARTICIPANT	\N	PRESENT	0
332675	332673	04059M	PARTICIPANT	\N	PRESENT	0
332676	332673	19651A	PARTICIPANT	\N	PRESENT	0
332626	321363	04059M	PARTICIPANT	\N	PRESENT	0
332627	321363	89017R	PARTICIPANT	\N	PRESENT	0
332677	332673	04042C	PARTICIPANT	\N	PRESENT	0
332678	332673	11053K	PARTICIPANT	\N	PRESENT	0
332679	332673	19545Y	PARTICIPANT	\N	PRESENT	0
332680	332673	88008L	PARTICIPANT	\N	PRESENT	0
332681	332673	11027H	PARTICIPANT	\N	PRESENT	0
332682	332673	04086Q	PARTICIPANT	\N	PRESENT	0
332683	332673	11070L	PARTICIPANT	\N	PRESENT	0
332684	332673	07033P	PARTICIPANT	\N	PRESENT	0
332685	332673	11074Q	PARTICIPANT	\N	PRESENT	0
332686	332673	19647E	PARTICIPANT	\N	PRESENT	0
332687	332673	19447X	PARTICIPANT	\N	PRESENT	0
332688	332673	11072N	PARTICIPANT	\N	PRESENT	0
332689	332673	08011M	PARTICIPANT	\N	PRESENT	0
332690	332673	11090Q	PARTICIPANT	\N	PRESENT	0
332691	332673	04033B	PARTICIPANT	\N	PRESENT	0
332692	332673	14157T	PARTICIPANT	\N	PRESENT	0
332693	321363	14031R	PARTICIPANT	\N	PRESENT	0
332694	321363	19447X	PARTICIPANT	\N	PRESENT	0
332695	321363	14215L	PARTICIPANT	\N	PRESENT	0
332696	321363	14083S	PARTICIPANT	\N	PRESENT	0
332697	321363	88008L	PARTICIPANT	\N	PRESENT	0
332704	332348	89017R	PARTICIPANT	\N	PRESENT	0
332699	332348	11040E	PARTICIPANT	\N	PRESENT	0
332700	332348	14083S	PARTICIPANT	\N	PRESENT	0
332701	332348	99004R	PARTICIPANT	\N	PRESENT	0
332702	332348	11074Q	PRESIDENT	0	PRESENT	0
332703	332348	14253S	PARTICIPANT	\N	PRESENT	0
305882	305881	01048V	PARTICIPANT	\N	PRESENT	0
306079	306078	14239U	PARTICIPANT	\N	PRESENT	0
306080	306078	19367Y	PARTICIPANT	\N	PRESENT	0
306081	306078	14053L	PARTICIPANT	\N	PRESENT	0
306082	306078	14195A	PARTICIPANT	\N	PRESENT	0
306083	306078	19253P	PARTICIPANT	\N	PRESENT	0
306084	306078	14041T	PARTICIPANT	\N	EXCUSE	0
306085	306078	14217N	PARTICIPANT	\N	PRESENT	0
306086	306078	14215L	PARTICIPANT	\N	PRESENT	0
306087	306078	14087W	PARTICIPANT	\N	PRESENT	0
306088	306078	14231L	PARTICIPANT	\N	PRESENT	0
306089	306078	19691J	PARTICIPANT	\N	PRESENT	0
306090	306078	19697Q	PARTICIPANT	\N	PRESENT	0
306091	306078	14031R	PARTICIPANT	\N	PRESENT	0
306092	306078	14147R	PARTICIPANT	\N	PRESENT	0
306093	306078	11067R	PARTICIPANT	\N	PRESENT	0
306094	306078	14223L	PARTICIPANT	\N	PRESENT	0
306095	306078	14119M	PARTICIPANT	\N	PRESENT	0
306096	306078	11045K	PARTICIPANT	\N	PRESENT	0
306097	306078	04044E	PRESIDENT	0	PRESENT	0
306373	306372	11053K	PARTICIPANT	\N	PRESENT	0
306374	306372	14159V	PARTICIPANT	\N	PRESENT	0
306375	306372	05012A	PARTICIPANT	\N	PRESENT	0
306385	306384	04047H	PARTICIPANT	\N	PRESENT	0
306386	306384	01024M	PARTICIPANT	\N	PRESENT	0
306388	306387	04047H	PARTICIPANT	\N	PRESENT	0
306389	306387	01024M	PARTICIPANT	\N	PRESENT	0
306672	306392	14089Y	PARTICIPANT	\N	PRESENT	0
307001	305883	14281W	PARTICIPANT	\N	EXCUSE	0
307002	305954	19593H	PARTICIPANT	\N	EXCUSE	0
307003	305762	14217N	PARTICIPANT	\N	PRESENT	0
307125	307124	14041T	PARTICIPANT	\N	PRESENT	0
307126	307124	01024M	PARTICIPANT	\N	PRESENT	0
307127	307123	01024M	PARTICIPANT	\N	PRESENT	0
307128	307123	14041T	PARTICIPANT	\N	PRESENT	0
307240	307239	14173T	PARTICIPANT	\N	PRESENT	0
307241	307239	08034U	PARTICIPANT	\N	PRESENT	0
307242	307239	04044E	PARTICIPANT	\N	PRESENT	0
307243	307239	19447X	PARTICIPANT	\N	PRESENT	0
307246	307239	18083K	PARTICIPANT	\N	PRESENT	0
309068	309067	98050T	PARTICIPANT	\N	PRESENT	0
314516	314348	08043V	PARTICIPANT	\N	PRESENT	0
314517	314348	14281W	PARTICIPANT	\N	PRESENT	0
314518	314348	08012N	PARTICIPANT	\N	PRESENT	0
314519	314348	98035U	PARTICIPANT	\N	PRESENT	0
314520	314348	11027H	PARTICIPANT	\N	PRESENT	0
314521	314348	19679N	PARTICIPANT	\N	PRESENT	0
314522	314348	19727D	PARTICIPANT	\N	PRESENT	0
314523	314348	14121F	PARTICIPANT	\N	PRESENT	0
314524	314348	14085U	PARTICIPANT	\N	PRESENT	0
314525	314348	14123H	PARTICIPANT	\N	PRESENT	0
314526	314348	19525U	PARTICIPANT	\N	PRESENT	0
314527	314348	11080N	PARTICIPANT	\N	PRESENT	0
314528	314348	19766L	PARTICIPANT	\N	PRESENT	0
314529	314348	01057W	PARTICIPANT	\N	PRESENT	0
314530	314348	14159V	PARTICIPANT	\N	PRESENT	0
314531	314348	14257W	PARTICIPANT	\N	PRESENT	0
314532	314348	87003B	PARTICIPANT	\N	PRESENT	0
314533	314348	14207L	PARTICIPANT	\N	PRESENT	0
314534	314348	11110B	PARTICIPANT	\N	PRESENT	0
314535	314348	19333N	PARTICIPANT	\N	PRESENT	0
314536	314348	14001X	PARTICIPANT	\N	PRESENT	0
314537	314348	11054L	PARTICIPANT	\N	PRESENT	0
314538	314348	11090Q	PARTICIPANT	\N	PRESENT	0
314539	314348	11045K	PARTICIPANT	\N	PRESENT	0
314540	314348	14227Q	PARTICIPANT	\N	PRESENT	0
314541	314348	19673G	PARTICIPANT	\N	PRESENT	0
314542	314348	19503N	PARTICIPANT	\N	PRESENT	0
314543	314348	14031R	PARTICIPANT	\N	PRESENT	0
314544	314348	19575F	PARTICIPANT	\N	PRESENT	0
314545	314348	14063N	PARTICIPANT	\N	PRESENT	0
314546	314348	14253S	PARTICIPANT	\N	PRESENT	0
314547	314348	19689Q	PARTICIPANT	\N	PRESENT	0
314548	314348	19667J	PARTICIPANT	\N	PRESENT	0
314549	314348	19631V	PARTICIPANT	\N	PRESENT	0
314550	314348	19447X	PARTICIPANT	\N	PRESENT	0
314551	314348	11041F	PARTICIPANT	\N	PRESENT	0
314552	314348	98005N	PARTICIPANT	\N	PRESENT	0
314553	314348	11066Q	PARTICIPANT	\N	PRESENT	0
314554	314348	14133K	PARTICIPANT	\N	PRESENT	0
314555	314348	92040Q	PARTICIPANT	\N	PRESENT	0
314556	314348	14097Y	PARTICIPANT	\N	PRESENT	0
314557	314348	11049P	PARTICIPANT	\N	PRESENT	0
314558	314348	08047A	PARTICIPANT	\N	PRESENT	0
314559	314348	19723Y	PARTICIPANT	\N	PRESENT	0
314560	314348	19649G	PARTICIPANT	\N	PRESENT	0
314561	314348	19295A	PARTICIPANT	\N	PRESENT	0
314562	314348	19489J	PARTICIPANT	\N	PRESENT	0
314563	314348	04033B	PARTICIPANT	\N	PRESENT	0
314564	314348	14115H	PARTICIPANT	\N	PRESENT	0
314576	314348	19507S	PARTICIPANT	\N	PRESENT	0
314566	314348	95063L	PARTICIPANT	\N	PRESENT	0
314567	314348	95037J	PARTICIPANT	\N	PRESENT	0
314568	314348	19443T	PARTICIPANT	\N	PRESENT	0
314569	314348	11083R	PARTICIPANT	\N	PRESENT	0
314570	314348	19349W	PARTICIPANT	\N	PRESENT	0
314571	314348	14109K	PARTICIPANT	\N	PRESENT	0
314572	314348	19705W	PARTICIPANT	\N	PRESENT	0
314573	314348	19543W	PARTICIPANT	\N	PRESENT	0
314574	314348	14029X	PARTICIPANT	\N	PRESENT	0
314575	314348	08061X	PARTICIPANT	\N	PRESENT	0
314577	314348	04071H	PARTICIPANT	\N	PRESENT	0
314578	314348	19643A	PARTICIPANT	\N	PRESENT	0
314579	314348	08021P	PARTICIPANT	\N	PRESENT	0
314580	314348	14039A	PARTICIPANT	\N	PRESENT	0
314581	314348	19659J	PARTICIPANT	\N	PRESENT	0
314582	314348	07029T	PARTICIPANT	\N	PRESENT	0
314583	314348	14081Q	PARTICIPANT	\N	PRESENT	0
314584	314348	11033F	PARTICIPANT	\N	PRESENT	0
314585	314348	19657G	PARTICIPANT	\N	PRESENT	0
314586	314348	14261S	PARTICIPANT	\N	PRESENT	0
314587	314348	19729F	PARTICIPANT	\N	PRESENT	0
314588	314348	08015R	PARTICIPANT	\N	PRESENT	0
314589	314348	19647E	PARTICIPANT	\N	PRESENT	0
314590	314348	19768N	PARTICIPANT	\N	PRESENT	0
314591	314348	08031R	PARTICIPANT	\N	PRESENT	0
314592	314348	08049C	PARTICIPANT	\N	PRESENT	0
314593	314348	14201E	PARTICIPANT	\N	PRESENT	0
314594	314348	19563B	PARTICIPANT	\N	PRESENT	0
314595	314348	98022P	PARTICIPANT	\N	PRESENT	0
314596	314348	14241N	PARTICIPANT	\N	PRESENT	0
314597	314348	19719D	PARTICIPANT	\N	PRESENT	0
314598	314348	04043D	PARTICIPANT	\N	PRESENT	0
314599	314348	19553Y	PARTICIPANT	\N	PRESENT	0
314600	314348	14107H	PARTICIPANT	\N	PRESENT	0
314601	314348	04035D	PARTICIPANT	\N	PRESENT	0
314602	314348	14026U	PARTICIPANT	\N	PRESENT	0
314603	314348	08010L	PARTICIPANT	\N	PRESENT	0
314604	314348	08028W	PARTICIPANT	\N	PRESENT	0
314605	314348	19545Y	PARTICIPANT	\N	PRESENT	0
314606	314348	17589D	PARTICIPANT	\N	PRESENT	0
314607	314348	19585H	PARTICIPANT	\N	PRESENT	0
314608	314348	08048B	PARTICIPANT	\N	PRESENT	0
314609	314348	11077T	PARTICIPANT	\N	PRESENT	0
314610	314348	89017R	PARTICIPANT	\N	PRESENT	0
314611	314348	14055N	PARTICIPANT	\N	PRESENT	0
314612	314348	17583W	PARTICIPANT	\N	PRESENT	0
314613	314348	04086Q	PARTICIPANT	\N	PRESENT	0
314614	314348	14231L	PARTICIPANT	\N	PRESENT	0
314615	314348	11109J	PARTICIPANT	\N	PRESENT	0
314616	314348	05008E	PARTICIPANT	\N	PRESENT	0
314617	314348	01034P	PARTICIPANT	\N	PRESENT	0
314618	314348	19691J	PARTICIPANT	\N	PRESENT	0
314619	314348	04070G	PARTICIPANT	\N	PRESENT	0
314620	314348	19367Y	PARTICIPANT	\N	PRESENT	0
314621	314348	08009T	PARTICIPANT	\N	PRESENT	0
314622	314348	19511N	PARTICIPANT	\N	PRESENT	0
314623	314348	04044E	PARTICIPANT	\N	PRESENT	0
314624	314348	19737F	PARTICIPANT	\N	PRESENT	0
314625	314348	95041E	PARTICIPANT	\N	PRESENT	0
314626	314348	19549D	PARTICIPANT	\N	PRESENT	0
314627	314348	04092N	PARTICIPANT	\N	PRESENT	0
314628	314348	08053X	PARTICIPANT	\N	PRESENT	0
314629	314348	14195A	PARTICIPANT	\N	PRESENT	0
314630	314348	19441R	PARTICIPANT	\N	PRESENT	0
314631	314348	16685X	PARTICIPANT	\N	PRESENT	0
314632	314348	14205J	PARTICIPANT	\N	PRESENT	0
314633	314348	19479G	PARTICIPANT	\N	PRESENT	0
314634	314348	04059M	PARTICIPANT	\N	PRESENT	0
314635	314348	98018T	PARTICIPANT	\N	PRESENT	0
314636	314348	14030Q	PARTICIPANT	\N	PRESENT	0
314637	314348	14327T	PARTICIPANT	\N	PRESENT	0
314638	314348	14187A	PARTICIPANT	\N	PRESENT	0
314639	314348	04040A	PARTICIPANT	\N	PRESENT	0
314640	314348	01025N	PARTICIPANT	\N	PRESENT	0
314641	314348	19683J	PARTICIPANT	\N	PRESENT	0
314642	314348	08073C	PARTICIPANT	\N	PRESENT	0
314643	314348	19577H	PARTICIPANT	\N	PRESENT	0
314644	314348	14073Q	PARTICIPANT	\N	PRESENT	0
325423	322759	14039A	PARTICIPANT	\N	PRESENT	0
325424	322759	98005N	PARTICIPANT	\N	EXCUSE	0
325425	322759	14059S	PARTICIPANT	\N	PRESENT	0
325426	322759	08019V	PRESIDENT	0	PRESENT	0
325427	322759	19657G	PARTICIPANT	\N	PRESENT	0
325442	322759	19703U	PARTICIPANT	\N	PRESENT	0
325443	322759	14275Y	PARTICIPANT	\N	PRESENT	0
325797	324704	96004D	PARTICIPANT	\N	PRESENT	0
325798	324704	14357A	PARTICIPANT	\N	PRESENT	0
325799	324704	04097T	PARTICIPANT	\N	PRESENT	0
325800	323962	14195A	PARTICIPANT	\N	EXCUSE	0
325801	324702	96004D	PARTICIPANT	\N	PRESENT	0
325802	324702	14357A	PARTICIPANT	\N	PRESENT	0
325803	324702	95037J	PARTICIPANT	\N	PRESENT	0
325804	324702	04097T	PARTICIPANT	\N	PRESENT	0
325805	324702	19511N	PARTICIPANT	\N	PRESENT	0
325806	324702	19563B	PARTICIPANT	\N	PRESENT	0
325808	324706	96004D	PARTICIPANT	\N	PRESENT	0
325809	324706	14357A	PARTICIPANT	\N	PRESENT	0
325810	324706	04097T	PARTICIPANT	\N	PRESENT	0
325811	324706	11090Q	PARTICIPANT	\N	PRESENT	0
326169	314165	08015R	PARTICIPANT	\N	PRESENT	0
326170	314165	08062Y	PARTICIPANT	\N	PRESENT	0
326171	314165	19399H	PARTICIPANT	\N	PRESENT	0
326172	314165	14265W	PARTICIPANT	\N	PRESENT	0
326173	314165	14105F	PARTICIPANT	\N	PRESENT	0
326174	314165	07033P	PARTICIPANT	\N	PRESENT	0
326175	314165	19575F	PARTICIPANT	\N	PRESENT	0
326176	314165	01048V	PARTICIPANT	\N	PRESENT	0
326177	314165	11043H	PARTICIPANT	\N	PRESENT	0
326643	324696	19549D	PARTICIPANT	\N	PRESENT	0
326644	325060	19443T	PARTICIPANT	\N	PRESENT	0
326645	325060	11080N	PARTICIPANT	\N	PRESENT	0
326646	325060	04034C	PARTICIPANT	\N	PRESENT	0
326647	325060	14079W	PARTICIPANT	\N	PRESENT	0
326648	325060	01058X	PARTICIPANT	\N	PRESENT	0
326649	325060	16685X	PARTICIPANT	\N	PRESENT	0
326650	325060	11027H	PARTICIPANT	\N	PRESENT	0
326651	325060	04042C	PRESIDENT	0	PRESENT	0
326652	325060	11054L	PARTICIPANT	\N	PRESENT	0
326653	325060	11066Q	PARTICIPANT	\N	PRESENT	0
326654	325060	95037J	PARTICIPANT	\N	PRESENT	0
326655	325060	14055N	PARTICIPANT	\N	PRESENT	0
326656	325060	19421M	PARTICIPANT	\N	PRESENT	0
326657	325060	19709B	PARTICIPANT	\N	PRESENT	0
326658	325060	14193X	PARTICIPANT	\N	PRESENT	0
326659	325060	08049C	PARTICIPANT	\N	PRESENT	0
326660	325060	08053X	PARTICIPANT	\N	PRESENT	0
326661	325060	97011G	PARTICIPANT	\N	PRESENT	0
326662	325060	08061X	PARTICIPANT	\N	PRESENT	0
326663	325060	08047A	PARTICIPANT	\N	PRESENT	0
326664	325060	14097Y	PARTICIPANT	\N	PRESENT	0
326665	325060	01062T	PARTICIPANT	\N	PRESENT	0
326666	325060	14235Q	PARTICIPANT	\N	PRESENT	0
326667	325060	08058D	PARTICIPANT	\N	PRESENT	0
326668	325060	14028W	PARTICIPANT	\N	PRESENT	0
326669	325060	19721W	PARTICIPANT	\N	PRESENT	0
326670	325060	19319Q	PARTICIPANT	\N	PRESENT	0
326671	325060	14105F	PARTICIPANT	\N	PRESENT	0
326672	325060	98018T	PARTICIPANT	\N	PRESENT	0
326673	325060	98022P	PARTICIPANT	\N	PRESENT	0
326674	325060	14267Y	PARTICIPANT	\N	PRESENT	0
326675	325060	14211G	PARTICIPANT	\N	PRESENT	0
326676	325060	19583F	PARTICIPANT	\N	PRESENT	0
326677	325060	11064N	PARTICIPANT	\N	PRESENT	0
326680	325060	11041F	PARTICIPANT	\N	PRESENT	0
326681	324696	14169X	PARTICIPANT	\N	PRESENT	0
326682	325060	08056B	PARTICIPANT	\N	PRESENT	0
326683	325784	04049K	PARTICIPANT	\N	PRESENT	0
326684	325784	19705W	PARTICIPANT	\N	PRESENT	0
326685	325784	19563B	PARTICIPANT	\N	PRESENT	0
326686	325784	08038Y	PARTICIPANT	\N	PRESENT	0
326687	325784	19695N	PARTICIPANT	\N	PRESENT	0
326688	324696	14093U	PARTICIPANT	\N	PRESENT	0
326689	324696	96004D	PARTICIPANT	\N	PRESENT	0
326690	325060	95030B	PARTICIPANT	\N	PRESENT	0
326691	324906	11070L	PARTICIPANT	\N	PRESENT	0
326692	324696	19713W	PARTICIPANT	\N	PRESENT	0
326734	326521	19766L	PARTICIPANT	\N	PRESENT	0
326735	326521	04070G	PRESIDENT	0	PRESENT	0
326736	326521	19699S	PARTICIPANT	\N	PRESENT	0
326737	326521	19329S	PARTICIPANT	\N	PRESENT	0
326738	326521	04033B	PARTICIPANT	\N	PRESENT	0
326739	326521	14229S	PARTICIPANT	\N	PRESENT	0
326740	326521	14241N	PARTICIPANT	\N	PRESENT	0
326741	326521	19573D	PARTICIPANT	\N	PRESENT	0
326742	326521	14039A	PARTICIPANT	\N	PRESENT	0
326743	326521	14107H	PARTICIPANT	\N	PRESENT	0
326744	326521	08017T	PARTICIPANT	\N	PRESENT	0
326745	326521	92040Q	PARTICIPANT	\N	PRESENT	0
326746	326521	07033P	PARTICIPANT	\N	PRESENT	0
326747	326521	08012N	PARTICIPANT	\N	PRESENT	0
326748	326521	08031R	PARTICIPANT	\N	PRESENT	0
326749	326521	19593H	PARTICIPANT	\N	PRESENT	0
326750	326521	19643A	PARTICIPANT	\N	PRESENT	0
326751	326521	14059S	PARTICIPANT	\N	PRESENT	0
326752	326521	14061L	PARTICIPANT	\N	PRESENT	0
326753	326521	04057K	PARTICIPANT	\N	PRESENT	0
326754	326521	14073Q	PARTICIPANT	\N	PRESENT	0
326755	326521	19611R	PARTICIPANT	\N	PRESENT	0
326756	326521	08035V	PARTICIPANT	\N	PRESENT	0
326757	326521	08043V	PARTICIPANT	\N	PRESENT	0
326758	326521	19399H	PARTICIPANT	\N	PRESENT	0
326759	326521	87003B	PARTICIPANT	\N	PRESENT	0
326760	326521	14201E	PARTICIPANT	\N	PRESENT	0
326761	326521	14030Q	PARTICIPANT	\N	PRESENT	0
326762	326521	19731Y	PARTICIPANT	\N	PRESENT	0
326763	326521	14251Q	PARTICIPANT	\N	PRESENT	0
326764	326521	04059M	PARTICIPANT	\N	PRESENT	0
326765	326521	19735D	PARTICIPANT	\N	PRESENT	0
326766	326521	11109J	PARTICIPANT	\N	PRESENT	0
326767	326521	14109K	PARTICIPANT	\N	PRESENT	0
326768	326521	11083R	PARTICIPANT	\N	PRESENT	0
326769	326521	11104D	PARTICIPANT	\N	PRESENT	0
326770	326521	11043H	PARTICIPANT	\N	PRESENT	0
326771	326521	19749K	PARTICIPANT	\N	PRESENT	0
326772	326521	04018C	PARTICIPANT	\N	PRESENT	0
326773	326521	08039A	PARTICIPANT	\N	EXCUSE	0
326774	325060	98029W	PARTICIPANT	\N	PRESENT	0
326775	325784	19269X	PARTICIPANT	\N	PRESENT	0
326776	324291	01060R	PARTICIPANT	\N	PRESENT	0
326777	324291	04044E	PARTICIPANT	\N	PRESENT	0
326778	324291	98035U	PARTICIPANT	\N	PRESENT	0
326779	324291	11026G	PARTICIPANT	\N	PRESENT	0
326780	324291	08044W	PARTICIPANT	\N	PRESENT	0
326781	324291	11049P	PARTICIPANT	\N	PRESENT	0
326783	324906	14034U	PARTICIPANT	\N	PRESENT	0
326784	325060	11115U	PARTICIPANT	\N	PRESENT	0
326785	325060	95067Q	PARTICIPANT	\N	PRESENT	0
326788	324906	04061F	PARTICIPANT	\N	PRESENT	0
326834	326521	14249W	PARTICIPANT	\N	PRESENT	0
326835	326521	19335Q	PARTICIPANT	\N	EXCUSE	0
326836	326521	19693L	PARTICIPANT	\N	PRESENT	0
326837	324696	14331P	PARTICIPANT	\N	PRESENT	0
326838	324906	14179A	PARTICIPANT	\N	PRESENT	0
326839	326411	19569H	PARTICIPANT	\N	PRESENT	0
326840	326411	01034P	PARTICIPANT	\N	PRESENT	0
326841	326411	14071N	PARTICIPANT	\N	PRESENT	0
326846	324291	14021P	PARTICIPANT	\N	PRESENT	0
326849	326848	14107H	PARTICIPANT	\N	PRESENT	0
326856	326855	19551W	PARTICIPANT	\N	PRESENT	0
326857	326855	99004R	PARTICIPANT	\N	PRESENT	0
326858	314173	01043Q	PARTICIPANT	\N	PRESENT	0
326862	314173	11040E	PARTICIPANT	\N	PRESENT	0
326863	314173	19387D	PARTICIPANT	\N	PRESENT	0
326864	314173	19583F	PARTICIPANT	\N	PRESENT	0
326865	314173	14253S	PARTICIPANT	\N	PRESENT	0
326866	314173	19479G	PARTICIPANT	\N	PRESENT	0
326867	314173	14331P	PARTICIPANT	\N	PRESENT	0
326868	314173	14327T	PARTICIPANT	\N	PRESENT	0
326869	314173	14026U	PARTICIPANT	\N	PRESENT	0
326870	314173	15447F	PARTICIPANT	\N	PRESENT	0
326871	314173	19531S	PARTICIPANT	\N	PRESENT	0
326872	314173	14265W	PARTICIPANT	\N	PRESENT	0
326873	314173	08055A	PARTICIPANT	\N	PRESENT	0
326874	314173	19687N	PARTICIPANT	\N	PRESENT	0
326875	314173	11064N	PARTICIPANT	\N	PRESENT	0
326876	314173	11074Q	PARTICIPANT	\N	PRESENT	0
326877	314173	14085U	PARTICIPANT	\N	PRESENT	0
326878	314173	14241N	PARTICIPANT	\N	PRESENT	0
326879	314173	14107H	PARTICIPANT	\N	PRESENT	0
326880	314173	19629C	PARTICIPANT	\N	PRESENT	0
326881	314173	19553Y	PARTICIPANT	\N	PRESENT	0
326882	314173	19599P	PARTICIPANT	\N	PRESENT	0
326883	314173	08024S	PARTICIPANT	\N	PRESENT	0
326884	314173	14151M	PARTICIPANT	\N	PRESENT	0
326885	314173	11048N	PARTICIPANT	\N	PRESENT	0
326886	314173	19415P	PARTICIPANT	\N	PRESENT	0
326887	314173	14069U	PARTICIPANT	\N	PRESENT	0
302002	301918	11054L	PARTICIPANT	\N	PRESENT	0
302003	301918	19647E	PARTICIPANT	\N	PRESENT	0
302004	301918	19631V	PARTICIPANT	\N	PRESENT	0
302005	301918	08061X	PARTICIPANT	\N	PRESENT	0
302006	301918	19543W	PARTICIPANT	\N	PRESENT	0
302007	301918	19697Q	PARTICIPANT	\N	PRESENT	0
302008	301918	19563B	PARTICIPANT	\N	PRESENT	0
302009	301918	19629C	PARTICIPANT	\N	PRESENT	0
302010	301918	04057K	PARTICIPANT	\N	PRESENT	0
302000	301918	19649G	PARTICIPANT	\N	PRESENT	0
302001	301918	19683J	PARTICIPANT	\N	PRESENT	0
302011	301918	19289C	PARTICIPANT	\N	PRESENT	0
302012	301918	19717B	PARTICIPANT	\N	PRESENT	0
302013	301918	11077T	PARTICIPANT	\N	PRESENT	0
302014	301918	11045K	PARTICIPANT	\N	PRESENT	0
302015	301918	04085P	PARTICIPANT	\N	PRESENT	0
302016	301918	08038Y	PARTICIPANT	\N	PRESENT	0
302017	301918	08016S	PARTICIPANT	\N	PRESENT	0
302018	301918	11065P	PARTICIPANT	\N	PRESENT	0
302019	301918	19735D	PARTICIPANT	\N	PRESENT	0
302020	301918	08009T	PARTICIPANT	\N	PRESENT	0
302021	301918	11085T	PARTICIPANT	\N	PRESENT	0
302022	301918	11053K	PARTICIPANT	\N	PRESENT	0
302023	301918	01043Q	PARTICIPANT	\N	PRESENT	0
302024	301918	19421M	PARTICIPANT	\N	PRESENT	0
302025	301918	19671E	PARTICIPANT	\N	PRESENT	0
302026	301918	19581D	PARTICIPANT	\N	PRESENT	0
302027	301918	05008E	PARTICIPANT	\N	PRESENT	0
302028	301918	14187A	PARTICIPANT	\N	PRESENT	0
302029	301918	04086Q	PARTICIPANT	\N	PRESENT	0
302030	301918	05012A	PARTICIPANT	\N	PRESENT	0
302031	301918	19637C	PARTICIPANT	\N	PRESENT	0
302032	301918	14217N	PARTICIPANT	\N	PRESENT	0
302033	301918	19701S	PARTICIPANT	\N	PRESENT	0
302034	301918	04088S	PARTICIPANT	\N	PRESENT	0
302035	301918	98024R	PARTICIPANT	\N	PRESENT	0
302036	301918	19711U	PARTICIPANT	\N	PRESENT	0
302037	301918	19741B	PARTICIPANT	\N	PRESENT	0
302038	301918	11090Q	PARTICIPANT	\N	PRESENT	0
302039	301918	04033B	PARTICIPANT	\N	PRESENT	0
302040	301918	19447X	PARTICIPANT	\N	PRESENT	0
302041	301918	19415P	PARTICIPANT	\N	PRESENT	0
302042	301918	14038Y	PARTICIPANT	\N	PRESENT	0
302043	301918	19643A	PARTICIPANT	\N	PRESENT	0
302044	301918	04071H	PARTICIPANT	\N	PRESENT	0
302045	301918	08069G	PARTICIPANT	\N	PRESENT	0
302046	301918	12041X	PARTICIPANT	\N	PRESENT	0
302047	301918	19591F	PARTICIPANT	\N	PRESENT	0
302048	301918	08062Y	PARTICIPANT	\N	PRESENT	0
302049	301918	19573D	PARTICIPANT	\N	PRESENT	0
302050	301918	14157T	PARTICIPANT	\N	PRESENT	0
302051	301918	14065Q	PARTICIPANT	\N	PRESENT	0
302052	301918	95063L	PARTICIPANT	\N	PRESENT	0
302053	301918	11048N	PARTICIPANT	\N	PRESENT	0
302054	301918	14211G	PARTICIPANT	\N	PRESENT	0
302055	301918	04043D	PARTICIPANT	\N	PRESENT	0
302148	295641	04008A	PARTICIPANT	\N	PRESENT	0
302149	295641	11033F	PARTICIPANT	\N	PRESENT	0
302150	295641	11056N	PARTICIPANT	\N	PRESENT	0
302151	295641	19695N	PARTICIPANT	\N	PRESENT	0
302152	295641	19565D	PARTICIPANT	\N	PRESENT	0
302153	295641	19687N	PARTICIPANT	\N	PRESENT	0
302154	295641	12041X	PARTICIPANT	\N	PRESENT	0
302155	295641	19683J	PARTICIPANT	\N	PRESENT	0
302156	295641	14227Q	PARTICIPANT	\N	PRESENT	0
302157	295641	14207L	PARTICIPANT	\N	PRESENT	0
302158	295641	08017T	PARTICIPANT	\N	PRESENT	0
302159	295641	11077T	PARTICIPANT	\N	PRESENT	0
302160	295641	19647E	PARTICIPANT	\N	PRESENT	0
302161	295641	19591F	PARTICIPANT	\N	PRESENT	0
302162	295641	08038Y	PARTICIPANT	\N	PRESENT	0
302163	295641	19631V	PARTICIPANT	\N	PRESENT	0
302166	295641	14065Q	PARTICIPANT	\N	PRESENT	0
302168	295641	19301E	PARTICIPANT	\N	PRESENT	0
302171	295641	19289C	PARTICIPANT	\N	PRESENT	0
302172	295641	11099A	PARTICIPANT	\N	PRESENT	0
302174	295641	19563B	PARTICIPANT	\N	PRESENT	0
302175	295641	19637C	PARTICIPANT	\N	PRESENT	0
302176	295641	19697Q	PARTICIPANT	\N	PRESENT	0
302177	295641	95063L	PARTICIPANT	\N	PRESENT	0
302178	295641	19651A	PARTICIPANT	\N	PRESENT	0
302179	295641	11065P	PARTICIPANT	\N	PRESENT	0
302180	295641	19717B	PARTICIPANT	\N	PRESENT	0
302181	295641	19735D	PARTICIPANT	\N	PRESENT	0
302182	295641	08009T	PARTICIPANT	\N	PRESENT	0
302183	295641	11053K	PARTICIPANT	\N	PRESENT	0
302184	295641	19747H	PARTICIPANT	\N	PRESENT	0
302185	295641	19671E	PARTICIPANT	\N	PRESENT	0
302187	295641	14215L	PARTICIPANT	\N	PRESENT	0
302189	295641	14187A	PARTICIPANT	\N	PRESENT	0
302190	295641	04018C	PARTICIPANT	\N	PRESENT	0
302191	295641	19701S	PARTICIPANT	\N	PRESENT	0
302192	295641	14331P	PARTICIPANT	\N	PRESENT	0
302193	295641	14217N	PARTICIPANT	\N	PRESENT	0
302194	295641	19383Y	PARTICIPANT	\N	PRESENT	0
302195	295641	05012A	PARTICIPANT	\N	PRESENT	0
302196	295641	14147R	PARTICIPANT	\N	PRESENT	0
302197	295641	14265W	PARTICIPANT	\N	PRESENT	0
302198	295641	04086Q	PARTICIPANT	\N	PRESENT	0
302199	295641	98024R	PARTICIPANT	\N	PRESENT	0
302200	295641	99004R	PARTICIPANT	\N	PRESENT	0
302201	295641	08069G	PARTICIPANT	\N	PRESENT	0
302202	295641	04071H	PARTICIPANT	\N	PRESENT	0
302203	295641	19643A	PARTICIPANT	\N	PRESENT	0
302204	295641	19515S	PARTICIPANT	\N	PRESENT	0
302205	295641	19573D	PARTICIPANT	\N	PRESENT	0
302206	295641	19741B	PARTICIPANT	\N	PRESENT	0
302207	295641	14038Y	PARTICIPANT	\N	PRESENT	0
302208	295641	04088S	PARTICIPANT	\N	PRESENT	0
302209	295641	14041T	PARTICIPANT	\N	PRESENT	0
302210	295641	19415P	PARTICIPANT	\N	PRESENT	0
302211	295641	19667J	PARTICIPANT	\N	PRESENT	0
302212	295641	08019V	PARTICIPANT	\N	PRESENT	0
302213	295641	14157T	PARTICIPANT	\N	PRESENT	0
302214	295641	08062Y	PARTICIPANT	\N	PRESENT	0
302215	295641	19711U	PARTICIPANT	\N	PRESENT	0
302216	295641	11048N	PARTICIPANT	\N	PRESENT	0
302217	295641	19705W	PARTICIPANT	\N	PRESENT	0
302218	295641	19663E	PARTICIPANT	\N	PRESENT	0
302219	295641	08068F	PARTICIPANT	\N	PRESENT	0
302220	295641	01043Q	PARTICIPANT	\N	PRESENT	0
302222	295641	19611R	PARTICIPANT	\N	PRESENT	0
302223	295641	19421M	PARTICIPANT	\N	PRESENT	0
302224	295641	11026G	PARTICIPANT	\N	PRESENT	0
302225	295641	11054L	PARTICIPANT	\N	PRESENT	0
302226	295641	19749K	PARTICIPANT	\N	PRESENT	0
302227	295641	14211G	PARTICIPANT	\N	PRESENT	0
302237	295641	19715Y	PARTICIPANT	\N	PRESENT	0
302238	295641	11109J	PARTICIPANT	\N	PRESENT	0
302242	295641	14053L	PARTICIPANT	\N	PRESENT	0
302243	295641	04057K	PARTICIPANT	\N	PRESENT	0
302244	295641	02002K	PARTICIPANT	\N	PRESENT	0
302245	295641	19629C	PARTICIPANT	\N	PRESENT	0
302246	295641	04043D	PARTICIPANT	\N	PRESENT	0
302247	295641	11083R	PARTICIPANT	\N	PRESENT	0
302248	295641	08061X	PARTICIPANT	\N	PRESENT	0
302258	295641	11085T	PARTICIPANT	\N	PRESENT	0
302261	295641	19441R	PARTICIPANT	\N	PRESENT	0
302262	295641	04047H	PARTICIPANT	\N	PRESENT	0
302263	295641	97011G	PARTICIPANT	\N	PRESENT	0
302265	295641	19551W	PARTICIPANT	\N	PRESENT	0
302267	295641	04034C	PARTICIPANT	\N	PRESENT	0
302276	295641	04049K	PARTICIPANT	\N	PRESENT	0
302146	295641	04059M	PARTICIPANT	\N	PRESENT	0
302147	295641	11090Q	PARTICIPANT	\N	PRESENT	0
302277	295641	14259Y	PARTICIPANT	\N	PRESENT	0
302279	295641	08010L	PARTICIPANT	\N	PRESENT	0
302281	295641	14021P	PARTICIPANT	\N	PRESENT	0
302287	295641	19347U	PARTICIPANT	\N	PRESENT	0
302288	295641	04085P	PARTICIPANT	\N	PRESENT	0
302289	295641	19621T	PARTICIPANT	\N	PRESENT	0
302290	295641	04035D	PARTICIPANT	\N	PRESENT	0
302291	295641	14223L	PARTICIPANT	\N	PRESENT	0
329639	329635	14215L	PARTICIPANT	\N	PRESENT	0
329640	329635	14001X	PARTICIPANT	\N	PRESENT	0
329644	329643	19575F	PARTICIPANT	\N	PRESENT	0
329645	329643	10006L	PARTICIPANT	\N	PRESENT	0
329646	329643	11083R	PARTICIPANT	\N	PRESENT	0
329647	329643	11048N	PARTICIPANT	\N	PRESENT	0
329648	329643	14059S	PARTICIPANT	\N	PRESENT	0
329649	329643	14063N	PARTICIPANT	\N	PRESENT	0
329650	329643	04057K	PARTICIPANT	\N	PRESENT	0
329651	329643	14265W	PARTICIPANT	\N	PRESENT	0
330562	328614	19745F	PARTICIPANT	\N	PRESENT	0
330563	328614	11065P	PARTICIPANT	\N	PRESENT	0
330564	328229	19421M	PARTICIPANT	\N	PRESENT	0
330565	328229	95030B	PARTICIPANT	\N	PRESENT	0
330566	329159	19585H	PARTICIPANT	\N	PRESENT	0
330567	329159	01028R	PARTICIPANT	\N	PRESENT	0
330568	329159	14231L	PARTICIPANT	\N	PRESENT	0
330569	329159	19489J	PARTICIPANT	\N	PRESENT	0
330570	329159	14275Y	PARTICIPANT	\N	PRESENT	0
330571	329159	14179A	PARTICIPANT	\N	PRESENT	0
330572	329159	14259Y	PARTICIPANT	\N	PRESENT	0
330573	329159	14053L	PARTICIPANT	\N	PRESENT	0
330574	329159	19649G	PARTICIPANT	\N	PRESENT	0
330575	329159	14065Q	PARTICIPANT	\N	PRESENT	0
330576	329159	19629C	PARTICIPANT	\N	PRESENT	0
330577	329159	14069U	PARTICIPANT	\N	PRESENT	0
330578	329159	04008A	PARTICIPANT	\N	PRESENT	0
330579	329159	14021P	PARTICIPANT	\N	PRESENT	0
330580	329159	14089Y	PARTICIPANT	\N	PRESENT	0
330581	329159	01060R	PARTICIPANT	\N	PRESENT	0
330582	329159	14215L	PARTICIPANT	\N	PRESENT	0
330583	321346	14225N	PARTICIPANT	\N	PRESENT	0
330584	321346	19683J	PARTICIPANT	\N	PRESENT	0
330585	321346	11067R	PARTICIPANT	\N	PRESENT	0
330586	321346	08011M	PARTICIPANT	\N	PRESENT	0
330587	321346	19687N	PARTICIPANT	\N	PRESENT	0
330588	321346	19585H	PARTICIPANT	\N	PRESENT	0
330589	321346	19545Y	PARTICIPANT	\N	PRESENT	0
330590	321346	11072N	PARTICIPANT	\N	PRESENT	0
330591	321346	19413M	PARTICIPANT	\N	PRESENT	0
330592	321346	07004J	PARTICIPANT	\N	PRESENT	0
330593	321346	01034P	PARTICIPANT	\N	PRESENT	0
330594	321346	19301E	PARTICIPANT	\N	PRESENT	0
330595	321346	11012A	PARTICIPANT	\N	PRESENT	0
330596	321346	07029T	PARTICIPANT	\N	PRESENT	0
330597	321346	19415P	PARTICIPANT	\N	PRESENT	0
330598	321346	19723Y	PARTICIPANT	\N	PRESENT	0
330599	321346	89017R	PARTICIPANT	\N	PRESENT	0
330600	321346	11103C	PARTICIPANT	\N	PRESENT	0
330601	321346	14223L	PARTICIPANT	\N	PRESENT	0
330602	321346	14187A	PARTICIPANT	\N	PRESENT	0
330603	321346	19711U	PARTICIPANT	\N	PRESENT	0
330604	321346	11040E	PARTICIPANT	\N	PRESENT	0
330605	321346	14199E	PARTICIPANT	\N	PRESENT	0
330606	321346	01057W	PARTICIPANT	\N	PRESENT	0
330607	321346	08069G	PARTICIPANT	\N	PRESENT	0
330608	321346	04086Q	PARTICIPANT	\N	PRESENT	0
330609	321346	11074Q	PARTICIPANT	\N	PRESENT	0
330610	321346	11097X	PARTICIPANT	\N	PRESENT	0
330611	321346	14213J	PARTICIPANT	\N	PRESENT	0
330612	321346	19667J	PARTICIPANT	\N	PRESENT	0
330723	321346	14107H	PARTICIPANT	\N	PRESENT	0
330614	321346	14119M	PARTICIPANT	\N	PRESENT	0
330615	321346	08051V	PARTICIPANT	\N	PRESENT	0
330616	321346	14261S	PARTICIPANT	\N	PRESENT	0
330617	321346	19717B	PARTICIPANT	\N	PRESENT	0
330618	321346	19651A	PARTICIPANT	\N	PRESENT	0
330619	321346	14121F	PARTICIPANT	\N	PRESENT	0
330620	321346	04045F	PARTICIPANT	\N	PRESENT	0
330621	321346	19591F	PARTICIPANT	\N	PRESENT	0
330622	321346	14026U	PARTICIPANT	\N	PRESENT	0
330623	321346	04092N	PARTICIPANT	\N	PRESENT	0
330624	321346	99004R	PARTICIPANT	\N	PRESENT	0
330625	321346	14331P	PARTICIPANT	\N	PRESENT	0
330629	321346	14327T	PARTICIPANT	\N	PRESENT	0
330630	321346	14255U	PARTICIPANT	\N	PRESENT	0
330631	321346	14079W	PARTICIPANT	\N	PRESENT	0
330632	321346	14069U	PARTICIPANT	\N	PRESENT	0
330633	321346	01048V	PARTICIPANT	\N	PRESENT	0
330634	321346	11048N	PARTICIPANT	\N	PRESENT	0
330635	321346	14267Y	PARTICIPANT	\N	PRESENT	0
330636	321346	19713W	PARTICIPANT	\N	PRESENT	0
330637	321346	14105F	PARTICIPANT	\N	PRESENT	0
330638	321346	19575F	PARTICIPANT	\N	PRESENT	0
330639	321346	19649G	PARTICIPANT	\N	PRESENT	0
330640	321346	14087W	PARTICIPANT	\N	PRESENT	0
330641	329158	14331P	PARTICIPANT	\N	PRESENT	0
330642	329158	19515S	PARTICIPANT	\N	PRESENT	0
330643	329158	19565D	PARTICIPANT	\N	PRESENT	0
330644	329158	19591F	PARTICIPANT	\N	PRESENT	0
330703	321346	19441R	PARTICIPANT	\N	PRESENT	0
330646	329158	19695N	PARTICIPANT	\N	PRESENT	0
330647	329158	19269X	PARTICIPANT	\N	PRESENT	0
330648	329158	11056N	PARTICIPANT	\N	PRESENT	0
330649	329158	17589D	PARTICIPANT	\N	PRESENT	0
330650	321346	14083S	PARTICIPANT	\N	PRESENT	0
330651	321346	95067Q	PARTICIPANT	\N	PRESENT	0
330652	321346	19553Y	PARTICIPANT	\N	PRESENT	0
330660	321346	19543W	PARTICIPANT	\N	PRESENT	0
330661	321346	19681G	PARTICIPANT	\N	PRESENT	0
330662	321346	11053K	PARTICIPANT	\N	PRESENT	0
330663	321346	19369B	PARTICIPANT	\N	PRESENT	0
330664	321346	19663E	PARTICIPANT	\N	PRESENT	0
330665	321346	14173T	PARTICIPANT	\N	PRESENT	0
330666	321346	98050T	PARTICIPANT	\N	PRESENT	0
330667	321346	95030B	PARTICIPANT	\N	PRESENT	0
330668	321346	14038Y	PARTICIPANT	\N	PRESENT	0
330669	321346	14217N	PARTICIPANT	\N	PRESENT	0
330670	321346	11066Q	PARTICIPANT	\N	PRESENT	0
330671	321346	14029X	PARTICIPANT	\N	PRESENT	0
330672	321346	87003B	PARTICIPANT	\N	PRESENT	0
330673	321346	19383Y	PARTICIPANT	\N	PRESENT	0
330674	321346	14211G	PARTICIPANT	\N	PRESENT	0
330675	321346	19367Y	PARTICIPANT	\N	PRESENT	0
330676	321346	19531S	PARTICIPANT	\N	PRESENT	0
330677	321346	19695N	PARTICIPANT	\N	PRESENT	0
330678	330074	19573D	PARTICIPANT	\N	PRESENT	0
330679	330074	08035V	PARTICIPANT	\N	PRESENT	0
330680	321346	14219Q	PARTICIPANT	\N	PRESENT	0
330681	321346	19563B	PARTICIPANT	\N	PRESENT	0
330682	321346	08034U	PARTICIPANT	\N	PRESENT	0
330684	321346	08010L	PARTICIPANT	\N	PRESENT	0
330687	321346	19737F	PARTICIPANT	\N	PRESENT	0
330688	321346	14073Q	PARTICIPANT	\N	PRESENT	0
330689	321346	14151M	PARTICIPANT	\N	PRESENT	0
330690	321346	14030Q	PARTICIPANT	\N	PRESENT	0
330691	321346	19693L	PARTICIPANT	\N	PRESENT	0
330692	321346	04059M	PARTICIPANT	\N	PRESENT	0
330693	321346	08062Y	PARTICIPANT	\N	PRESENT	0
330694	321346	04088S	PARTICIPANT	\N	PRESENT	0
330695	321346	19507S	PARTICIPANT	\N	PRESENT	0
330696	321346	08038Y	PARTICIPANT	\N	PRESENT	0
330697	321346	14265W	PARTICIPANT	\N	PRESENT	0
330698	321346	14147R	PARTICIPANT	\N	PRESENT	0
330699	321346	14249W	PARTICIPANT	\N	PRESENT	0
330700	321346	14033T	PARTICIPANT	\N	PRESENT	0
330701	321346	08019V	PARTICIPANT	\N	PRESENT	0
330702	321346	16685X	PARTICIPANT	\N	PRESENT	0
330705	321346	11110B	PARTICIPANT	\N	PRESENT	0
330714	321346	11043H	PARTICIPANT	\N	PRESENT	0
330716	321346	14259Y	PARTICIPANT	\N	PRESENT	0
330719	321346	19565D	PARTICIPANT	\N	PRESENT	0
330721	321346	04042C	PARTICIPANT	\N	PRESENT	0
330722	321346	19387D	PARTICIPANT	\N	PRESENT	0
330724	321346	12016W	PARTICIPANT	\N	PRESENT	0
330725	321346	11049P	PARTICIPANT	\N	PRESENT	0
330726	321346	19611R	PARTICIPANT	\N	PRESENT	0
330727	321346	19319Q	PARTICIPANT	\N	PRESENT	0
330728	321346	19295A	PARTICIPANT	\N	PRESENT	0
330729	321346	14034U	PARTICIPANT	\N	PRESENT	0
330730	321346	08044W	PARTICIPANT	\N	PRESENT	0
330731	321346	14021P	PARTICIPANT	\N	PRESENT	0
330052	330051	19701S	PARTICIPANT	\N	PRESENT	0
330054	330051	11026G	PARTICIPANT	\N	PRESENT	0
303704	302442	14053L	PARTICIPANT	\N	PRESENT	0
303705	302442	19649G	PARTICIPANT	\N	PRESENT	0
303706	302442	07034Q	PRESIDENT	0	PRESENT	0
303707	302442	08045X	PARTICIPANT	\N	PRESENT	0
303708	302442	01024M	PARTICIPANT	\N	PRESENT	0
303709	302442	19415P	PARTICIPANT	\N	PRESENT	0
303710	302442	04044E	PARTICIPANT	\N	PRESENT	0
303711	302442	19581D	PARTICIPANT	\N	PRESENT	0
303712	302442	11074Q	PARTICIPANT	\N	PRESENT	0
303713	302442	11066Q	PARTICIPANT	\N	PRESENT	0
303714	302442	04047H	PARTICIPANT	\N	PRESENT	0
303715	302442	01028R	PARTICIPANT	\N	PRESENT	0
303716	302442	11033F	PARTICIPANT	\N	PRESENT	0
303717	302442	19447X	PARTICIPANT	\N	PRESENT	0
303718	302442	14173T	PARTICIPANT	\N	PRESENT	0
303719	302442	19725B	PARTICIPANT	\N	PRESENT	0
303720	302442	19729F	PARTICIPANT	\N	PRESENT	0
303721	302442	19489J	PARTICIPANT	\N	PRESENT	0
303722	302442	95063L	PARTICIPANT	\N	PRESENT	0
303723	302442	14041T	PARTICIPANT	\N	PRESENT	0
303724	302442	14147R	PARTICIPANT	\N	PRESENT	0
303725	302442	05008E	PRESIDENT	1	PRESENT	0
303726	302442	08017T	PARTICIPANT	\N	PRESENT	0
303727	302442	14179A	PARTICIPANT	\N	PRESENT	0
303825	301628	19741B	PARTICIPANT	\N	PRESENT	0
303826	301628	04071H	PARTICIPANT	\N	PRESENT	0
303827	301628	08010L	PARTICIPANT	\N	PRESENT	0
303828	302442	19585H	PARTICIPANT	\N	PRESENT	0
303829	302442	14193X	PARTICIPANT	\N	PRESENT	0
303830	302442	14215L	PARTICIPANT	\N	PRESENT	0
303831	302442	14259Y	PARTICIPANT	\N	PRESENT	0
303832	302442	98035U	PARTICIPANT	\N	PRESENT	0
303833	302442	19253P	PARTICIPANT	\N	PRESENT	0
303834	302442	19719D	PARTICIPANT	\N	PRESENT	0
303835	302442	14069U	PARTICIPANT	\N	PRESENT	0
303836	302442	11085T	PARTICIPANT	\N	PRESENT	0
303837	302442	14021P	PARTICIPANT	\N	PRESENT	0
303844	301628	19349W	PARTICIPANT	\N	PRESENT	0
303845	301909	14109K	PARTICIPANT	\N	PRESENT	0
303851	302442	01060R	PARTICIPANT	\N	PRESENT	0
303847	302442	14223L	PARTICIPANT	\N	PRESENT	0
303848	302442	19503N	PARTICIPANT	\N	PRESENT	0
303849	302442	14073Q	PARTICIPANT	\N	PRESENT	0
303850	301628	19711U	PARTICIPANT	\N	PRESENT	0
304236	289213	19725B	PARTICIPANT	\N	PRESENT	0
303853	302442	04040A	PARTICIPANT	\N	PRESENT	0
303855	302442	19383Y	PARTICIPANT	\N	PRESENT	0
303856	302442	04059M	PARTICIPANT	\N	PRESENT	0
303857	302704	04059M	PARTICIPANT	\N	PRESENT	0
303858	302704	11090Q	PARTICIPANT	\N	PRESENT	0
303859	302704	14187A	PARTICIPANT	\N	PRESENT	0
303860	302704	19711U	PARTICIPANT	\N	PRESENT	0
303861	302704	14223L	PARTICIPANT	\N	PRESENT	0
303862	302704	14217N	PARTICIPANT	\N	PRESENT	0
303863	303728	01060R	PARTICIPANT	\N	PRESENT	0
303864	302704	19731Y	PARTICIPANT	\N	PRESENT	0
303865	303728	08052W	PARTICIPANT	\N	PRESENT	0
303866	303728	14329V	PARTICIPANT	\N	PRESENT	0
303867	303728	14281W	PARTICIPANT	\N	PRESENT	0
303868	303728	07034Q	PRESIDENT	1	PRESENT	0
303869	303728	08017T	PARTICIPANT	\N	PRESENT	0
303870	303728	14229S	PARTICIPANT	\N	PRESENT	0
303871	303728	14053L	PARTICIPANT	\N	PRESENT	0
303872	303728	08061X	PARTICIPANT	\N	PRESENT	0
303873	302704	19739H	PARTICIPANT	\N	PRESENT	0
303874	302704	04018C	PARTICIPANT	\N	PRESENT	0
303875	302704	19565D	PARTICIPANT	\N	PRESENT	0
303876	302704	14042U	PARTICIPANT	\N	PRESENT	0
303877	302704	14105F	PARTICIPANT	\N	PRESENT	0
303878	302704	04086Q	PARTICIPANT	\N	PRESENT	0
303879	302704	99004R	PARTICIPANT	\N	PRESENT	0
303880	302704	14173T	PARTICIPANT	\N	PRESENT	0
303881	302704	19643A	PARTICIPANT	\N	PRESENT	0
303882	302704	19667J	PARTICIPANT	\N	PRESENT	0
303883	302704	19695N	PARTICIPANT	\N	PRESENT	0
303884	302704	19611R	PARTICIPANT	\N	PRESENT	0
303885	302704	19599P	PARTICIPANT	\N	PRESENT	0
303886	302704	14038Y	PARTICIPANT	\N	PRESENT	0
303887	303728	14147R	PARTICIPANT	\N	PRESENT	0
303888	303728	19253P	PARTICIPANT	\N	PRESENT	0
303889	303728	19415P	PARTICIPANT	\N	PRESENT	0
303890	302704	08038Y	PARTICIPANT	\N	PRESENT	0
303891	302704	19349W	PARTICIPANT	\N	PRESENT	0
303892	302704	14073Q	PARTICIPANT	\N	PRESENT	0
303893	302704	19515S	PARTICIPANT	\N	PRESENT	0
303894	302704	97011G	PARTICIPANT	\N	PRESENT	0
303895	302704	19467C	PARTICIPANT	\N	PRESENT	0
303896	302704	14071N	PARTICIPANT	\N	PRESENT	0
303897	303728	11027H	PARTICIPANT	\N	PRESENT	0
303898	303728	19581D	PARTICIPANT	\N	PRESENT	0
303899	303728	04044E	PARTICIPANT	\N	PRESENT	0
303900	302704	95062K	PARTICIPANT	\N	PRESENT	0
303901	302704	19511N	PARTICIPANT	\N	PRESENT	0
303902	303728	19383Y	PARTICIPANT	\N	PRESENT	0
303903	302704	11103C	PARTICIPANT	\N	PRESENT	0
303904	302704	04088S	PARTICIPANT	\N	PRESENT	0
303905	302704	11104D	PARTICIPANT	\N	PRESENT	0
303906	302704	19727D	PARTICIPANT	\N	PRESENT	0
303907	302704	19737F	PARTICIPANT	\N	PRESENT	0
303908	302704	14033T	PARTICIPANT	\N	PRESENT	0
303909	302704	19699S	PARTICIPANT	\N	PRESENT	0
303910	302704	19675J	PARTICIPANT	\N	PRESENT	0
303911	302704	19735D	PARTICIPANT	\N	PRESENT	0
303912	302704	11099A	PARTICIPANT	\N	PRESENT	0
303913	302704	19543W	PARTICIPANT	\N	PRESENT	0
303914	302704	04045F	PARTICIPANT	\N	PRESENT	0
303915	302704	19687N	PARTICIPANT	\N	PRESENT	0
303917	302704	14063N	PARTICIPANT	\N	PRESENT	0
303919	303728	01028R	PARTICIPANT	\N	PRESENT	0
303920	303728	05008E	PRESIDENT	0	PRESENT	0
303921	303728	19447X	PARTICIPANT	\N	PRESENT	0
303922	303728	19489J	PARTICIPANT	\N	PRESENT	0
303923	303728	14041T	PARTICIPANT	\N	PRESENT	0
303924	303728	14179A	PARTICIPANT	\N	PRESENT	0
303925	303728	14215L	PARTICIPANT	\N	PRESENT	0
303926	303728	19649G	PARTICIPANT	\N	PRESENT	0
303927	303728	08045X	PARTICIPANT	\N	PRESENT	0
303928	303728	19719D	PARTICIPANT	\N	PRESENT	0
303929	303728	11033F	PARTICIPANT	\N	PRESENT	0
303930	303728	19725B	PARTICIPANT	\N	PRESENT	0
303931	303728	19729F	PARTICIPANT	\N	PRESENT	0
303932	303728	11049P	PARTICIPANT	\N	PRESENT	0
303933	303728	14021P	PARTICIPANT	\N	PRESENT	0
303934	302704	11066Q	PARTICIPANT	\N	PRESENT	0
303935	302704	19715Y	PARTICIPANT	\N	PRESENT	0
303936	302704	04049K	PARTICIPANT	\N	PRESENT	0
303937	302704	18083K	PARTICIPANT	\N	PRESENT	0
303938	303728	14111D	PARTICIPANT	\N	PRESENT	0
303939	303728	11026G	PARTICIPANT	\N	PRESENT	0
303940	302704	19703U	PARTICIPANT	\N	PRESENT	0
303941	302704	08015R	PARTICIPANT	\N	PRESENT	0
303943	302704	19651A	PARTICIPANT	\N	PRESENT	0
303945	302704	08010L	PARTICIPANT	\N	PRESENT	0
303946	302704	14059S	PARTICIPANT	\N	PRESENT	0
303948	302704	14241N	PARTICIPANT	\N	PRESENT	0
303949	302704	19333N	PARTICIPANT	\N	PRESENT	0
303950	302704	14257W	PARTICIPANT	\N	PRESENT	0
303951	302704	11056N	PARTICIPANT	\N	PRESENT	0
303952	302704	14213J	PARTICIPANT	\N	PRESENT	0
303953	302704	11012A	PARTICIPANT	\N	PRESENT	0
303954	302704	19747H	PARTICIPANT	\N	PRESENT	0
303955	302704	19507S	PARTICIPANT	\N	PRESENT	0
303957	302704	14207L	PARTICIPANT	\N	PRESENT	0
303958	302704	19369B	PARTICIPANT	\N	PRESENT	0
303959	302704	14083S	PARTICIPANT	\N	PRESENT	0
303960	302704	19441R	PARTICIPANT	\N	PRESENT	0
303962	302704	19367Y	PARTICIPANT	\N	PRESENT	0
303963	303728	14055N	PARTICIPANT	\N	PRESENT	0
303964	303728	19689Q	PARTICIPANT	\N	PRESENT	0
303965	302704	14026U	PARTICIPANT	\N	PRESENT	0
303966	302704	11048N	PARTICIPANT	\N	PRESENT	0
303967	302704	01057W	PARTICIPANT	\N	PRESENT	0
303979	302704	92040Q	PARTICIPANT	\N	PRESENT	0
303982	302704	19387D	PARTICIPANT	\N	PRESENT	0
303983	302704	05012A	PARTICIPANT	\N	PRESENT	0
304235	289213	14281W	PARTICIPANT	\N	PRESENT	0
304237	289213	19413M	PARTICIPANT	\N	PRESENT	0
304238	289213	19441R	PARTICIPANT	\N	PRESENT	0
304239	289213	19727D	PARTICIPANT	\N	PRESENT	0
304240	289213	98018T	PARTICIPANT	\N	PRESENT	0
304241	289213	04044E	PARTICIPANT	\N	PRESENT	0
326888	314173	14038Y	PARTICIPANT	\N	PRESENT	0
326889	314173	95062K	PARTICIPANT	\N	PRESENT	0
326890	314173	98022P	PARTICIPANT	\N	PRESENT	0
326891	314173	11012A	PARTICIPANT	\N	PRESENT	0
326892	314173	88008L	PARTICIPANT	\N	PRESENT	0
326893	314173	14061L	PARTICIPANT	\N	PRESENT	0
326894	314173	19711U	PARTICIPANT	\N	PRESENT	0
326895	314173	11103C	PARTICIPANT	\N	PRESENT	0
326896	314173	19713W	PARTICIPANT	\N	PRESENT	0
326897	314173	14199E	PARTICIPANT	\N	PRESENT	0
326898	314173	19467C	PARTICIPANT	\N	PRESENT	0
326899	314173	14191V	PARTICIPANT	\N	PRESENT	0
326900	314173	08056B	PARTICIPANT	\N	PRESENT	0
326901	314173	19717B	PARTICIPANT	\N	PRESENT	0
326902	314173	01048V	PARTICIPANT	\N	PRESENT	0
326903	314173	17583W	PARTICIPANT	\N	PRESENT	0
326904	314173	11067R	PARTICIPANT	\N	PRESENT	0
326905	314173	11010L	PARTICIPANT	\N	PRESENT	0
326906	314173	14173T	PARTICIPANT	\N	PRESENT	0
326907	314173	19349W	PARTICIPANT	\N	PRESENT	0
326908	314173	08051V	PARTICIPANT	\N	PRESENT	0
326909	314173	19441R	PARTICIPANT	\N	PRESENT	0
326910	314173	14079W	PARTICIPANT	\N	PRESENT	0
326911	314173	01025N	PARTICIPANT	\N	PRESENT	0
326912	314173	14147R	PARTICIPANT	\N	PRESENT	0
326913	314173	11056N	PARTICIPANT	\N	PRESENT	0
326914	314173	19729F	PARTICIPANT	\N	PRESENT	0
326915	314173	14225N	PARTICIPANT	\N	PRESENT	0
326916	314173	19747H	PARTICIPANT	\N	PRESENT	0
326917	314173	19762G	PARTICIPANT	\N	PRESENT	0
326918	314173	19701S	PARTICIPANT	\N	PRESENT	0
326919	314173	14211G	PARTICIPANT	\N	PRESENT	0
326920	314173	19369B	PARTICIPANT	\N	PRESENT	0
326921	314173	19679N	PARTICIPANT	\N	PRESENT	0
326922	314173	14051J	PARTICIPANT	\N	PRESENT	0
326923	314173	19719D	PARTICIPANT	\N	PRESENT	0
326924	314173	19301E	PARTICIPANT	\N	PRESENT	0
326925	314173	08015R	PARTICIPANT	\N	PRESENT	0
326927	314173	04086Q	PARTICIPANT	\N	PRESENT	0
326928	314173	19667J	PARTICIPANT	\N	PRESENT	0
326929	314173	14231L	PARTICIPANT	\N	PRESENT	0
326930	314173	08060W	PARTICIPANT	\N	PRESENT	0
326931	314173	95030B	PARTICIPANT	\N	PRESENT	0
326932	314173	11072N	PARTICIPANT	\N	PRESENT	0
326933	314173	08047A	PARTICIPANT	\N	PRESENT	0
326935	314173	14041T	PARTICIPANT	\N	PRESENT	0
326936	314173	04047H	PARTICIPANT	\N	PRESENT	0
326937	314173	14031R	PARTICIPANT	\N	PRESENT	0
326938	314173	14267Y	PARTICIPANT	\N	PRESENT	0
326939	314173	14105F	PARTICIPANT	\N	PRESENT	0
326940	314173	01057W	PARTICIPANT	\N	PRESENT	0
326941	314173	19737F	PARTICIPANT	\N	PRESENT	0
326942	314173	14089Y	PARTICIPANT	\N	PRESENT	0
327226	320563	08053X	PARTICIPANT	\N	EXCUSE	0
327013	314173	14034U	PARTICIPANT	\N	PRESENT	0
327014	325790	19515S	PARTICIPANT	\N	PRESENT	0
327015	325790	19782L	PARTICIPANT	\N	PRESENT	0
327016	325790	19565D	PARTICIPANT	\N	PRESENT	0
327017	325790	14357A	PARTICIPANT	\N	PRESENT	0
327018	325790	19441R	PARTICIPANT	\N	PRESENT	0
327019	325790	19413M	PARTICIPANT	\N	PRESENT	0
327020	325790	08068F	PARTICIPANT	\N	PRESENT	0
327021	325790	08015R	PARTICIPANT	\N	PRESENT	0
327022	325790	19369B	PARTICIPANT	\N	PRESENT	0
327023	325790	19511N	PARTICIPANT	\N	PRESENT	0
327024	325790	19563B	PARTICIPANT	\N	PRESENT	0
327025	325790	14265W	PARTICIPANT	\N	PRESENT	0
327026	325790	14329V	PARTICIPANT	\N	PRESENT	0
327027	325790	19467C	PARTICIPANT	\N	PRESENT	0
327028	325790	08038Y	PARTICIPANT	\N	PRESENT	0
327029	325790	19695N	PARTICIPANT	\N	PRESENT	0
327030	325790	14033T	PARTICIPANT	\N	PRESENT	0
327031	325790	11090Q	PRESIDENT	0	PRESENT	0
327032	325790	01025N	PARTICIPANT	\N	PRESENT	0
327033	325790	19269X	PARTICIPANT	\N	PRESENT	0
327034	325790	14205J	PARTICIPANT	\N	PRESENT	0
327035	325790	04088S	PARTICIPANT	\N	PRESENT	0
327036	325790	04089T	PARTICIPANT	\N	PRESENT	0
327037	325790	14115H	PARTICIPANT	\N	PRESENT	0
327038	325790	19507S	PARTICIPANT	\N	PRESENT	0
327039	325790	19747H	PARTICIPANT	\N	PRESENT	0
327040	325790	14207L	PARTICIPANT	\N	PRESENT	0
327041	325790	04043D	PARTICIPANT	\N	PRESENT	0
327042	325790	19619A	PARTICIPANT	\N	PRESENT	0
327043	325790	14257W	PARTICIPANT	\N	PRESENT	0
327044	325790	11081P	PARTICIPANT	\N	EXCUSE	0
327225	320563	19723Y	PARTICIPANT	\N	EXCUSE	0
327227	320563	19511N	PARTICIPANT	\N	EXCUSE	0
327228	320563	19553Y	PARTICIPANT	\N	EXCUSE	0
327230	320563	19693L	PARTICIPANT	\N	PRESENT	0
327231	320563	01048V	PRESIDENT	0	PRESENT	0
327254	314174	14275Y	PARTICIPANT	\N	PRESENT	0
327255	314174	19637C	PARTICIPANT	\N	PRESENT	0
327256	314174	14042U	PARTICIPANT	\N	PRESENT	0
327257	314174	14073Q	PARTICIPANT	\N	PRESENT	0
327258	314174	19683J	PARTICIPANT	\N	PRESENT	0
327259	314174	19599P	PARTICIPANT	\N	PRESENT	0
327260	314174	19533U	PARTICIPANT	\N	PRESENT	0
327261	314174	19575F	PARTICIPANT	\N	PRESENT	0
327262	314174	19565D	PARTICIPANT	\N	PRESENT	0
327263	314174	04045F	PARTICIPANT	\N	PRESENT	0
327332	314175	19383Y	PARTICIPANT	\N	PRESENT	0
327333	314175	19675J	PARTICIPANT	\N	PRESENT	0
327334	314175	19533U	PARTICIPANT	\N	PRESENT	0
327335	314175	11103C	PARTICIPANT	\N	PRESENT	0
327338	314175	17589D	PARTICIPANT	\N	PRESENT	0
327339	314175	14111D	PARTICIPANT	\N	PRESENT	0
327340	314175	95062K	PARTICIPANT	\N	PRESENT	0
327341	314175	19585H	PARTICIPANT	\N	PRESENT	0
327342	314175	14191V	PARTICIPANT	\N	PRESENT	0
327343	314175	19447X	PARTICIPANT	\N	PRESENT	0
327344	314175	19683J	PARTICIPANT	\N	PRESENT	0
327345	314175	08060W	PARTICIPANT	\N	PRESENT	0
327346	314175	14031R	PARTICIPANT	\N	PRESENT	0
327347	314175	18083K	PARTICIPANT	\N	PRESENT	0
327348	314175	19599P	PARTICIPANT	\N	PRESENT	0
327349	314175	19399H	PARTICIPANT	\N	PRESENT	0
327350	314175	05008E	PARTICIPANT	\N	PRESENT	0
327351	314175	19575F	PARTICIPANT	\N	PRESENT	0
327352	314175	08061X	PARTICIPANT	\N	PRESENT	0
327353	314175	11083R	PARTICIPANT	\N	PRESENT	0
327354	314175	19711U	PARTICIPANT	\N	PRESENT	0
327355	314175	04045F	PARTICIPANT	\N	PRESENT	0
327356	314175	19621T	PARTICIPANT	\N	PRESENT	0
327357	314175	14069U	PARTICIPANT	\N	PRESENT	0
327358	314175	19659J	PARTICIPANT	\N	PRESENT	0
327359	314175	19269X	PARTICIPANT	\N	PRESENT	0
327360	314175	14147R	PARTICIPANT	\N	PRESENT	0
327361	314175	19637C	PARTICIPANT	\N	PRESENT	0
327362	314175	14241N	PARTICIPANT	\N	PRESENT	0
327363	314175	19729F	PARTICIPANT	\N	PRESENT	0
327364	314175	98022P	PARTICIPANT	\N	PRESENT	0
327365	314175	01028R	PARTICIPANT	\N	PRESENT	0
327366	314175	11012A	PARTICIPANT	\N	PRESENT	0
327367	314175	08051V	PARTICIPANT	\N	PRESENT	0
327368	314175	88008L	PARTICIPANT	\N	PRESENT	0
327369	314175	14034U	PARTICIPANT	\N	PRESENT	0
327370	314175	08044W	PARTICIPANT	\N	PRESENT	0
327371	314175	19301E	PARTICIPANT	\N	PRESENT	0
327372	314175	14239U	PARTICIPANT	\N	PRESENT	0
327373	314175	04085P	PARTICIPANT	\N	PRESENT	0
327374	314175	11033F	PARTICIPANT	\N	PRESENT	0
327375	314175	17583W	PARTICIPANT	\N	PRESENT	0
327376	314175	19725B	PARTICIPANT	\N	PRESENT	0
327377	314175	11072N	PARTICIPANT	\N	PRESENT	0
327378	314175	14021P	PARTICIPANT	\N	PRESENT	0
327379	314175	19565D	PARTICIPANT	\N	PRESENT	0
327380	314175	08049C	PARTICIPANT	\N	PRESENT	0
327381	314175	14051J	PARTICIPANT	\N	PRESENT	0
327382	314175	14257W	PARTICIPANT	\N	PRESENT	0
327383	314175	19467C	PARTICIPANT	\N	PRESENT	0
327384	314175	04088S	PARTICIPANT	\N	PRESENT	0
327385	314175	14215L	PARTICIPANT	\N	PRESENT	0
327393	314175	11027H	PARTICIPANT	\N	PRESENT	0
327387	314175	14187A	PARTICIPANT	\N	PRESENT	0
327388	314175	14251Q	PARTICIPANT	\N	PRESENT	0
327389	314175	14041T	PARTICIPANT	\N	PRESENT	0
327390	314175	19737F	PARTICIPANT	\N	PRESENT	0
327391	314175	19782L	PARTICIPANT	\N	PRESENT	0
327392	314175	14265W	PARTICIPANT	\N	PRESENT	0
327612	327587	14073Q	PARTICIPANT	\N	PRESENT	0
327613	327587	19611R	PARTICIPANT	\N	PRESENT	0
327614	327587	87003B	PARTICIPANT	\N	PRESENT	0
327615	327587	14039A	PARTICIPANT	\N	PRESENT	0
327616	327587	14249W	PARTICIPANT	\N	PRESENT	0
327617	327587	19731Y	PARTICIPANT	\N	EXCUSE	0
327330	314175	01043Q	PARTICIPANT	\N	PRESENT	0
327331	314175	19762G	PARTICIPANT	\N	PRESENT	0
302381	295642	14187A	PARTICIPANT	\N	PRESENT	0
302382	295642	04008A	PARTICIPANT	\N	PRESENT	0
302383	295642	19591F	PARTICIPANT	\N	PRESENT	0
302384	295642	19631V	PARTICIPANT	\N	PRESENT	0
302385	295642	19515S	PARTICIPANT	\N	PRESENT	0
302386	295642	19611R	PARTICIPANT	\N	PRESENT	0
302387	295642	19747H	PARTICIPANT	\N	PRESENT	0
302388	295642	19671E	PARTICIPANT	\N	PRESENT	0
302389	295642	19701S	PARTICIPANT	\N	PRESENT	0
302390	295642	04018C	PARTICIPANT	\N	PRESENT	0
302391	295642	05012A	PARTICIPANT	\N	PRESENT	0
302392	295642	04086Q	PARTICIPANT	\N	PRESENT	0
302393	295642	14038Y	PARTICIPANT	\N	PRESENT	0
302394	295642	19565D	PARTICIPANT	\N	PRESENT	0
302395	295642	12041X	PARTICIPANT	\N	PRESENT	0
302396	295642	14215L	PARTICIPANT	\N	PRESENT	0
302397	295642	08038Y	PARTICIPANT	\N	PRESENT	0
302398	295642	04085P	PARTICIPANT	\N	PRESENT	0
302399	295642	19421M	PARTICIPANT	\N	PRESENT	0
302400	295642	19347U	PARTICIPANT	\N	PRESENT	0
302401	295642	19687N	PARTICIPANT	\N	PRESENT	0
302402	295642	14251Q	PARTICIPANT	\N	PRESENT	0
302403	295642	19441R	PARTICIPANT	\N	PRESENT	0
302404	295642	95063L	PARTICIPANT	\N	PRESENT	0
302405	295642	98024R	PARTICIPANT	\N	PRESENT	0
302406	295642	19717B	PARTICIPANT	\N	PRESENT	0
302407	295642	11077T	PARTICIPANT	\N	PRESENT	0
302408	295642	19553Y	PARTICIPANT	\N	PRESENT	0
302409	295642	19637C	PARTICIPANT	\N	PRESENT	0
302410	295642	19563B	PARTICIPANT	\N	PRESENT	0
302411	295642	11056N	PARTICIPANT	\N	PRESENT	0
302412	295642	19383Y	PARTICIPANT	\N	PRESENT	0
302413	295642	11012A	PARTICIPANT	\N	PRESENT	0
302414	295642	04049K	PARTICIPANT	\N	PRESENT	0
302415	295642	19629C	PARTICIPANT	\N	PRESENT	0
302416	295642	19415P	PARTICIPANT	\N	PRESENT	0
302417	295642	14053L	PARTICIPANT	\N	PRESENT	0
302418	295642	14331P	PARTICIPANT	\N	PRESENT	0
302419	295642	04088S	PARTICIPANT	\N	PRESENT	0
302420	295642	14217N	PARTICIPANT	\N	PRESENT	0
302421	295642	14223L	PARTICIPANT	\N	PRESENT	0
302422	295642	11048N	PARTICIPANT	\N	PRESENT	0
302423	295642	04035D	PARTICIPANT	\N	PRESENT	0
302424	295642	19621T	PARTICIPANT	\N	PRESENT	0
302425	295642	19253P	PARTICIPANT	\N	PRESENT	0
302426	295642	14265W	PARTICIPANT	\N	PRESENT	0
302427	295642	07029T	PARTICIPANT	\N	PRESENT	0
302428	295642	08061X	PARTICIPANT	\N	PRESENT	0
302429	295642	08062Y	PARTICIPANT	\N	PRESENT	0
302430	295642	19551W	PARTICIPANT	\N	PRESENT	0
302431	295642	08069G	PARTICIPANT	\N	PRESENT	0
302432	295642	14073Q	PARTICIPANT	\N	PRESENT	0
302433	295642	14030Q	PARTICIPANT	\N	PRESENT	0
302434	295642	19369B	PARTICIPANT	\N	PRESENT	0
302435	295642	14083S	PARTICIPANT	\N	PRESENT	0
302436	295642	08068F	PARTICIPANT	\N	PRESENT	0
302437	295642	16685X	PARTICIPANT	\N	PRESENT	0
302438	295642	19739H	PARTICIPANT	\N	PRESENT	0
302439	295642	14211G	PARTICIPANT	\N	PRESENT	0
302440	295642	14219Q	PARTICIPANT	\N	PRESENT	0
302561	297354	14261S	PARTICIPANT	\N	PRESENT	0
302562	297354	19631V	PARTICIPANT	\N	PRESENT	0
302563	297354	96004D	PARTICIPANT	\N	EXCUSE	0
302564	297354	14259Y	PARTICIPANT	\N	PRESENT	0
302565	297354	08016S	PARTICIPANT	\N	PRESENT	0
302566	297354	19715Y	PARTICIPANT	\N	PRESENT	0
302567	297354	14059S	PARTICIPANT	\N	PRESENT	0
302568	297354	12016W	PARTICIPANT	\N	PRESENT	0
302569	297354	08019V	PRESIDENT	0	PRESENT	0
302570	297354	11072N	PARTICIPANT	\N	PRESENT	0
302571	297354	04043D	PARTICIPANT	\N	PRESENT	0
302572	297354	19703U	PARTICIPANT	\N	PRESENT	0
302379	295642	04044E	PARTICIPANT	\N	PRESENT	0
302380	295642	11090Q	PARTICIPANT	\N	PRESENT	0
302573	297354	19717B	PARTICIPANT	\N	PRESENT	0
302574	297354	14033T	PARTICIPANT	\N	EXCUSE	0
302575	297354	14038Y	PARTICIPANT	\N	EXCUSE	0
302576	297354	14199E	PARTICIPANT	\N	EXCUSE	0
302577	297354	14157T	PARTICIPANT	\N	EXCUSE	0
307134	306017	14107H	PARTICIPANT	\N	EXCUSE	0
307429	306017	01028R	PARTICIPANT	\N	EXCUSE	0
307683	306017	19467C	PARTICIPANT	\N	PRESENT	0
307685	305886	19467C	PARTICIPANT	\N	EXCUSE	0
307691	305897	19467C	PARTICIPANT	\N	PRESENT	0
310448	306017	19569H	PARTICIPANT	\N	PRESENT	0
310449	306017	04061F	PARTICIPANT	\N	PRESENT	0
310450	306017	19711U	PARTICIPANT	\N	PRESENT	0
310451	306017	08062Y	PARTICIPANT	\N	PRESENT	0
310452	306017	14147R	PARTICIPANT	\N	PRESENT	0
310453	306017	19713W	PARTICIPANT	\N	PRESENT	0
310454	306017	11066Q	PARTICIPANT	\N	PRESENT	0
310455	306017	19479G	PARTICIPANT	\N	PRESENT	0
310456	306017	08055A	PARTICIPANT	\N	PRESENT	0
310457	306017	19715Y	PARTICIPANT	\N	PRESENT	0
310458	306017	19347U	PARTICIPANT	\N	PRESENT	0
310459	306017	19503N	PARTICIPANT	\N	PRESENT	0
310460	306017	19441R	PARTICIPANT	\N	PRESENT	0
316291	316290	14169X	PARTICIPANT	\N	PRESENT	0
319306	318863	98035U	PARTICIPANT	\N	PRESENT	0
319307	318863	14053L	PARTICIPANT	\N	PRESENT	0
319308	318863	14097Y	PARTICIPANT	\N	PRESENT	0
319309	318863	14331P	PARTICIPANT	\N	PRESENT	0
319310	318863	01058X	PARTICIPANT	\N	PRESENT	0
319311	318863	08043V	PARTICIPANT	\N	PRESENT	0
319312	318863	11040E	PARTICIPANT	\N	PRESENT	0
319313	318863	19573D	PARTICIPANT	\N	PRESENT	0
319314	318863	19507S	PARTICIPANT	\N	PRESENT	0
319315	318863	96004D	PRESIDENT	0	PRESENT	0
319316	318863	08017T	PARTICIPANT	\N	PRESENT	0
319317	318863	98050T	PARTICIPANT	\N	PRESENT	0
319318	318863	11083R	PARTICIPANT	\N	PRESENT	0
319319	318863	04061F	PARTICIPANT	\N	PRESENT	0
319320	318863	08031R	PARTICIPANT	\N	PRESENT	0
319321	318863	14089Y	PARTICIPANT	\N	EXCUSE	0
319322	318863	04057K	PARTICIPANT	\N	EXCUSE	0
319323	318863	98022P	PARTICIPANT	\N	EXCUSE	0
319324	318863	14069U	PARTICIPANT	\N	PRESENT	0
319340	314087	86034E	PARTICIPANT	\N	PRESENT	0
319464	314087	14123H	PARTICIPANT	\N	PRESENT	0
319465	319213	04071H	PARTICIPANT	\N	PRESENT	0
319467	319213	11070L	PARTICIPANT	\N	PRESENT	0
319468	319213	11110B	PARTICIPANT	\N	PRESENT	0
319469	319213	08010L	PARTICIPANT	\N	PRESENT	0
319470	319213	19647E	PARTICIPANT	\N	PRESENT	0
319471	314087	11056N	PARTICIPANT	\N	PRESENT	0
319472	314087	19747H	PARTICIPANT	\N	PRESENT	0
319473	314087	19701S	PARTICIPANT	\N	PRESENT	0
319474	314087	19573D	PARTICIPANT	\N	PRESENT	0
319475	314087	14215L	PARTICIPANT	\N	PRESENT	0
319476	314087	19725B	PARTICIPANT	\N	PRESENT	0
319477	319213	08034U	PARTICIPANT	\N	PRESENT	0
319478	319213	14121F	PARTICIPANT	\N	PRESENT	0
319479	319213	08014Q	PARTICIPANT	\N	EXCUSE	0
319480	314087	14081Q	PARTICIPANT	\N	PRESENT	0
319481	314087	14063N	PARTICIPANT	\N	PRESENT	0
319482	314087	14079W	PARTICIPANT	\N	PRESENT	0
319483	314087	19621T	PARTICIPANT	\N	PRESENT	0
319484	314087	19415P	PARTICIPANT	\N	PRESENT	0
319485	314087	19387D	PARTICIPANT	\N	PRESENT	0
319486	314087	14179A	PARTICIPANT	\N	PRESENT	0
319487	314087	14107H	PARTICIPANT	\N	PRESENT	0
319488	314087	14223L	PARTICIPANT	\N	PRESENT	0
319489	314087	19575F	PARTICIPANT	\N	PRESENT	0
319490	314087	19553Y	PARTICIPANT	\N	PRESENT	0
319491	314087	19649G	PARTICIPANT	\N	PRESENT	0
319492	314087	14021P	PARTICIPANT	\N	PRESENT	0
319493	319213	19545Y	PARTICIPANT	\N	PRESENT	0
319494	319213	88008L	PARTICIPANT	\N	PRESENT	0
319495	319213	19741B	PARTICIPANT	\N	PRESENT	0
319496	314087	04049K	PARTICIPANT	\N	PRESENT	0
319498	314087	19693L	PARTICIPANT	\N	PRESENT	0
319499	314087	01028R	PARTICIPANT	\N	PRESENT	0
319500	314087	19467C	PARTICIPANT	\N	PRESENT	0
319501	314087	19695N	PARTICIPANT	\N	PRESENT	0
319502	314087	19413M	PARTICIPANT	\N	PRESENT	0
319503	314087	08028W	PARTICIPANT	\N	PRESENT	0
319504	314087	14255U	PARTICIPANT	\N	PRESENT	0
319505	314087	14119M	PARTICIPANT	\N	PRESENT	0
319506	314087	14069U	PARTICIPANT	\N	PRESENT	0
319507	314087	14055N	PARTICIPANT	\N	PRESENT	0
319509	314087	07033P	PARTICIPANT	\N	PRESENT	0
319511	314087	19591F	PARTICIPANT	\N	PRESENT	0
319512	314087	14265W	PARTICIPANT	\N	PRESENT	0
319515	314087	19367Y	PARTICIPANT	\N	PRESENT	0
319516	314087	19762G	PARTICIPANT	\N	PRESENT	0
319517	314087	19369B	PARTICIPANT	\N	PRESENT	0
319518	314087	08020N	PARTICIPANT	\N	PRESENT	0
330296	326842	19697Q	PARTICIPANT	\N	PRESENT	0
330297	326842	04092N	PARTICIPANT	\N	PRESENT	0
330298	326842	11097X	PARTICIPANT	\N	PRESENT	0
330299	326842	08052W	PARTICIPANT	\N	PRESENT	0
330300	326842	19691J	PARTICIPANT	\N	PRESENT	0
330301	326842	14223L	PARTICIPANT	\N	PRESENT	0
330302	326842	14227Q	PARTICIPANT	\N	PRESENT	0
330303	326842	19723Y	PARTICIPANT	\N	PRESENT	0
330304	326842	19703U	PARTICIPANT	\N	PRESENT	0
330305	326842	19553Y	PARTICIPANT	\N	PRESENT	0
330306	326842	14087W	PARTICIPANT	\N	PRESENT	0
330307	326842	14281W	PARTICIPANT	\N	PRESENT	0
330308	326842	11103C	PARTICIPANT	\N	PRESENT	0
330309	326842	14042U	PARTICIPANT	\N	PRESENT	0
330310	326842	08048B	PARTICIPANT	\N	PRESENT	0
330311	326842	14195A	PARTICIPANT	\N	PRESENT	0
330312	326842	14213J	PARTICIPANT	\N	PRESENT	0
330313	326842	19367Y	PARTICIPANT	\N	PRESENT	0
330314	326842	14217N	PARTICIPANT	\N	PRESENT	0
330315	326842	19683J	PARTICIPANT	\N	PRESENT	0
330316	326842	98024R	PARTICIPANT	\N	PRESENT	0
330317	326842	19760E	PARTICIPANT	\N	PRESENT	0
330318	326842	14355X	PARTICIPANT	\N	EXCUSE	0
330319	326842	08041T	PARTICIPANT	\N	EXCUSE	0
330320	326842	04045F	PARTICIPANT	\N	PRESENT	0
330321	326842	19727D	PARTICIPANT	\N	PRESENT	0
330322	326842	11067R	PARTICIPANT	\N	PRESENT	0
330323	326842	19521Q	PARTICIPANT	\N	PRESENT	0
330324	326842	19717B	PARTICIPANT	\N	PRESENT	0
330325	326842	19415P	PARTICIPANT	\N	PRESENT	0
330326	326842	14119M	PARTICIPANT	\N	PRESENT	0
330327	326842	14026U	PARTICIPANT	\N	PRESENT	0
330328	326842	17779H	PARTICIPANT	\N	PRESENT	0
330329	326842	19569H	PARTICIPANT	\N	PRESENT	0
330330	326842	11045K	PARTICIPANT	\N	PRESENT	0
330331	326842	19301E	PARTICIPANT	\N	PRESENT	0
330332	326842	14071N	PARTICIPANT	\N	PRESENT	0
330333	326842	19575F	PARTICIPANT	\N	PRESENT	0
330334	326842	14261S	PARTICIPANT	\N	PRESENT	0
330335	326842	19527W	PARTICIPANT	\N	PRESENT	0
330336	326842	11031D	PARTICIPANT	\N	PRESENT	0
330653	321346	11070L	PARTICIPANT	\N	PRESENT	0
330654	321346	11077T	PARTICIPANT	\N	PRESENT	0
330339	328614	95062K	PARTICIPANT	\N	EXCUSE	0
330340	328614	96004D	PARTICIPANT	\N	EXCUSE	0
330341	328614	19685L	PARTICIPANT	\N	EXCUSE	0
330342	321346	01043Q	PARTICIPANT	\N	PRESENT	0
330343	329159	14001X	PARTICIPANT	\N	PRESENT	0
330344	329159	04044E	PARTICIPANT	\N	PRESENT	0
330345	329159	19581D	PARTICIPANT	\N	PRESENT	0
330346	329159	04047H	PARTICIPANT	\N	PRESENT	0
330347	329159	19673G	PARTICIPANT	\N	PRESENT	0
330348	329159	19447X	PARTICIPANT	\N	PRESENT	0
330349	329159	05008E	PRESIDENT	0	PRESENT	0
330350	329159	14147R	PARTICIPANT	\N	PRESENT	0
330351	329159	14151M	PARTICIPANT	\N	PRESENT	0
330352	329159	11072N	PARTICIPANT	\N	PRESENT	0
330353	329159	08051V	PARTICIPANT	\N	PRESENT	0
330354	329159	98035U	PARTICIPANT	\N	PRESENT	0
330355	329159	14111D	PARTICIPANT	\N	PRESENT	0
330356	329159	07034Q	PARTICIPANT	\N	PRESENT	0
330357	329159	08045X	PARTICIPANT	\N	PRESENT	0
330358	329159	01024M	PARTICIPANT	\N	PRESENT	0
330359	329159	04038G	PARTICIPANT	\N	PRESENT	0
330360	329159	19719D	PARTICIPANT	\N	PRESENT	0
330361	329159	11033F	PARTICIPANT	\N	PRESENT	0
330362	329159	19729F	PARTICIPANT	\N	PRESENT	0
330363	329159	95063L	PARTICIPANT	\N	PRESENT	0
330364	329159	08044W	PARTICIPANT	\N	PRESENT	0
330365	329159	11085T	PARTICIPANT	\N	PRESENT	0
330366	329159	11049P	PARTICIPANT	\N	PRESENT	0
330367	329159	19762G	PARTICIPANT	\N	PRESENT	0
330368	326842	01034P	PARTICIPANT	\N	PRESENT	0
330369	328229	19443T	PARTICIPANT	\N	PRESENT	0
330370	328229	12041X	PARTICIPANT	\N	PRESENT	0
330371	328229	11080N	PARTICIPANT	\N	PRESENT	0
330372	328229	01062T	PARTICIPANT	\N	PRESENT	0
330373	328229	11041F	PARTICIPANT	\N	PRESENT	0
330374	328229	04034C	PARTICIPANT	\N	PRESENT	0
330375	328229	14235Q	PARTICIPANT	\N	PRESENT	0
330376	328229	04040A	PARTICIPANT	\N	PRESENT	0
330377	328229	04042C	PRESIDENT	0	PRESENT	0
330378	328229	11066Q	PARTICIPANT	\N	PRESENT	0
330379	328229	19319Q	PARTICIPANT	\N	PRESENT	0
330380	328229	14105F	PARTICIPANT	\N	PRESENT	0
330381	328229	98018T	PARTICIPANT	\N	PRESENT	0
330382	328229	08049C	PARTICIPANT	\N	PRESENT	0
330383	328229	14267Y	PARTICIPANT	\N	PRESENT	0
330384	328229	98050T	PARTICIPANT	\N	PRESENT	0
330385	328229	97011G	PARTICIPANT	\N	PRESENT	0
330386	328229	14211G	PARTICIPANT	\N	PRESENT	0
330387	328229	19583F	PARTICIPANT	\N	PRESENT	0
330388	328229	08047A	PARTICIPANT	\N	PRESENT	0
330389	326842	10006L	PARTICIPANT	\N	PRESENT	0
330436	329158	19768N	PARTICIPANT	\N	PRESENT	0
330437	329158	19782L	PARTICIPANT	\N	PRESENT	0
330438	329158	01043Q	PARTICIPANT	\N	PRESENT	0
330439	329158	14357A	PARTICIPANT	\N	PRESENT	0
330440	329158	19441R	PARTICIPANT	\N	PRESENT	0
330441	329158	14081Q	PARTICIPANT	\N	PRESENT	0
330442	329158	19413M	PARTICIPANT	\N	PRESENT	0
330443	329158	80013X	PARTICIPANT	\N	PRESENT	0
330444	329158	08021P	PARTICIPANT	\N	PRESENT	0
330445	329158	19631V	PARTICIPANT	\N	PRESENT	0
330446	329158	08068F	PARTICIPANT	\N	PRESENT	0
330447	329158	04049K	PARTICIPANT	\N	PRESENT	0
330448	329158	08015R	PARTICIPANT	\N	PRESENT	0
330449	329158	08019V	PARTICIPANT	\N	PRESENT	0
330450	329158	19369B	PARTICIPANT	\N	PRESENT	0
330451	329158	19511N	PARTICIPANT	\N	PRESENT	0
330452	329158	08028W	PARTICIPANT	\N	PRESENT	0
330453	329158	19563B	PARTICIPANT	\N	PRESENT	0
330454	329158	14265W	PARTICIPANT	\N	PRESENT	0
330455	329158	14329V	PARTICIPANT	\N	PRESENT	0
330456	329158	19467C	PARTICIPANT	\N	PRESENT	0
330457	329158	14187A	PARTICIPANT	\N	PRESENT	0
330458	329158	08038Y	PARTICIPANT	\N	PRESENT	0
330459	329158	08062Y	PARTICIPANT	\N	PRESENT	0
330460	329158	14033T	PRESIDENT	1	PRESENT	0
330461	329158	11090Q	PRESIDENT	0	PRESENT	0
330462	329158	01025N	PARTICIPANT	\N	PRESENT	0
330463	329158	19295A	PARTICIPANT	\N	PRESENT	0
330464	329158	14205J	PARTICIPANT	\N	PRESENT	0
330465	329158	04088S	PARTICIPANT	\N	PRESENT	0
330466	329158	04089T	PARTICIPANT	\N	PRESENT	0
330467	329158	14115H	PARTICIPANT	\N	PRESENT	0
330468	329158	11101A	PARTICIPANT	\N	PRESENT	0
330469	329158	19507S	PARTICIPANT	\N	PRESENT	0
330470	329158	19747H	PARTICIPANT	\N	PRESENT	0
330471	329158	14207L	PARTICIPANT	\N	PRESENT	0
330472	329158	04043D	PARTICIPANT	\N	PRESENT	0
330473	329158	14257W	PARTICIPANT	\N	PRESENT	0
330474	329158	11081P	PARTICIPANT	\N	EXCUSE	0
330475	328229	11115U	PARTICIPANT	\N	PRESENT	0
330476	328229	98029W	PARTICIPANT	\N	PRESENT	0
330655	321346	19629C	PARTICIPANT	\N	PRESENT	0
330656	321346	14111D	PARTICIPANT	\N	PRESENT	0
330657	321346	19583F	PARTICIPANT	\N	PRESENT	0
330658	321346	04034C	PARTICIPANT	\N	PRESENT	0
330659	321346	17583W	PARTICIPANT	\N	PRESENT	0
330685	330683	11048N	PARTICIPANT	\N	PRESENT	0
330706	330704	19643A	PARTICIPANT	\N	PRESENT	0
330707	330704	19447X	PARTICIPANT	\N	PRESENT	0
330708	330704	01043Q	PARTICIPANT	\N	PRESENT	0
330709	330704	14205J	PARTICIPANT	\N	PRESENT	0
330710	330704	05012A	PARTICIPANT	\N	PRESENT	0
330711	330704	19735D	PARTICIPANT	\N	PRESENT	0
330712	330704	04044E	PARTICIPANT	\N	PRESENT	0
330713	330704	14173T	PARTICIPANT	\N	PRESENT	0
330715	330704	14159V	PARTICIPANT	\N	PRESENT	0
330951	321347	14109K	PARTICIPANT	\N	PRESENT	0
330718	330704	14169X	PARTICIPANT	\N	PRESENT	0
330720	321346	19691J	PARTICIPANT	\N	PRESENT	0
330949	328688	19295A	PARTICIPANT	\N	PRESENT	0
330950	321347	01057W	PARTICIPANT	\N	PRESENT	0
330952	321347	11012A	PARTICIPANT	\N	PRESENT	0
330953	321347	08049C	PARTICIPANT	\N	PRESENT	0
330954	321347	01024M	PARTICIPANT	\N	PRESENT	0
330955	321347	19441R	PARTICIPANT	\N	PRESENT	0
330956	321347	11043H	PARTICIPANT	\N	PRESENT	0
330957	321347	19503N	PARTICIPANT	\N	PRESENT	0
330958	321347	19629C	PARTICIPANT	\N	PRESENT	0
330959	321347	14151M	PARTICIPANT	\N	PRESENT	0
330960	321347	19621T	PARTICIPANT	\N	PRESENT	0
330961	321347	08055A	PARTICIPANT	\N	PRESENT	0
330962	321347	14147R	PARTICIPANT	\N	PRESENT	0
330963	321347	11067R	PARTICIPANT	\N	PRESENT	0
330973	321347	19531S	PARTICIPANT	\N	PRESENT	0
330974	321347	04049K	PARTICIPANT	\N	PRESENT	0
303918	303916	14205J	PARTICIPANT	\N	PRESENT	0
303942	297577	14205J	PARTICIPANT	\N	PRESENT	0
303944	297578	14205J	PARTICIPANT	\N	PRESENT	0
304288	295654	08017T	PARTICIPANT	\N	PRESENT	0
304289	295654	19503N	PARTICIPANT	\N	PRESENT	0
304290	295654	14207L	PARTICIPANT	\N	PRESENT	0
304291	295654	19651A	PARTICIPANT	\N	PRESENT	0
304292	295654	14103D	PARTICIPANT	\N	PRESENT	0
304293	295654	14026U	PARTICIPANT	\N	PRESENT	0
304294	295654	19687N	PARTICIPANT	\N	PRESENT	0
304295	295654	19593H	PARTICIPANT	\N	PRESENT	0
304296	295654	11056N	PARTICIPANT	\N	PRESENT	0
304297	295654	19711U	PARTICIPANT	\N	PRESENT	0
304298	295654	19533U	PARTICIPANT	\N	PRESENT	0
304299	295654	14215L	PARTICIPANT	\N	PRESENT	0
304300	295654	14087W	PARTICIPANT	\N	PRESENT	0
304301	295654	19719D	PARTICIPANT	\N	PRESENT	0
304302	295654	19387D	PARTICIPANT	\N	PRESENT	0
304303	295654	19689Q	PARTICIPANT	\N	PRESENT	0
304304	295654	19647E	PARTICIPANT	\N	PRESENT	0
304305	295654	08039A	PARTICIPANT	\N	PRESENT	0
304306	295654	19289C	PARTICIPANT	\N	PRESENT	0
304307	295654	19737F	PARTICIPANT	\N	PRESENT	0
304308	295654	19479G	PARTICIPANT	\N	PRESENT	0
304309	295654	96004D	PARTICIPANT	\N	PRESENT	0
304310	295654	14053L	PARTICIPANT	\N	PRESENT	0
304311	295654	14021P	PARTICIPANT	\N	PRESENT	0
304312	295654	14217N	PARTICIPANT	\N	PRESENT	0
304313	295654	14061L	PARTICIPANT	\N	PRESENT	0
304314	295654	11097X	PARTICIPANT	\N	PRESENT	0
304315	295654	14157T	PARTICIPANT	\N	PRESENT	0
304316	295654	19749K	PARTICIPANT	\N	PRESENT	0
304317	295654	04088S	PARTICIPANT	\N	PRESENT	0
304318	295654	14251Q	PARTICIPANT	\N	PRESENT	0
304319	295654	19441R	PARTICIPANT	\N	PRESENT	0
304320	295654	04033B	PARTICIPANT	\N	PRESENT	0
304321	295654	14034U	PARTICIPANT	\N	PRESENT	0
304286	295654	11072N	PARTICIPANT	\N	PRESENT	0
304287	295654	19413M	PARTICIPANT	\N	PRESENT	0
304322	295654	04040A	PARTICIPANT	\N	PRESENT	0
304323	295654	14265W	PARTICIPANT	\N	PRESENT	0
304324	295654	07029T	PARTICIPANT	\N	PRESENT	0
304325	295654	19447X	PARTICIPANT	\N	PRESENT	0
304326	295654	11048N	PARTICIPANT	\N	PRESENT	0
304327	295654	08031R	PARTICIPANT	\N	PRESENT	0
304328	295654	14071N	PARTICIPANT	\N	PRESENT	0
305401	305400	04047H	PARTICIPANT	\N	PRESENT	0
305402	305400	01024M	PARTICIPANT	\N	PRESENT	0
305403	305400	14179A	PARTICIPANT	\N	PRESENT	0
305404	305400	95063L	PARTICIPANT	\N	PRESENT	0
305405	305400	11072N	PARTICIPANT	\N	PRESENT	0
305407	305406	04047H	PARTICIPANT	\N	PRESENT	0
305408	305406	01024M	PARTICIPANT	\N	PRESENT	0
305409	305406	14179A	PARTICIPANT	\N	PRESENT	0
305410	305406	11085T	PARTICIPANT	\N	PRESENT	0
305411	305406	95063L	PARTICIPANT	\N	PRESENT	0
305734	305574	08043V	PARTICIPANT	\N	EXCUSE	0
305735	305574	08020N	PARTICIPANT	\N	EXCUSE	0
305736	305574	19758L	PARTICIPANT	\N	EXCUSE	0
305737	305574	08016S	PARTICIPANT	\N	EXCUSE	0
305738	305574	19399H	PARTICIPANT	\N	EXCUSE	0
305739	305574	14039A	PARTICIPANT	\N	EXCUSE	0
305740	305574	14073Q	PARTICIPANT	\N	EXCUSE	0
305741	305574	08031R	PARTICIPANT	\N	EXCUSE	0
305742	305574	19699S	PARTICIPANT	\N	EXCUSE	0
305743	305574	08017T	PARTICIPANT	\N	EXCUSE	0
305744	305574	14059S	PARTICIPANT	\N	EXCUSE	0
305745	305574	92040Q	PARTICIPANT	\N	EXCUSE	0
305746	305574	19593H	PARTICIPANT	\N	EXCUSE	0
305747	305574	19766L	PARTICIPANT	\N	EXCUSE	0
306961	305954	01058X	PARTICIPANT	\N	PRESENT	0
306970	305883	14195A	PARTICIPANT	\N	EXCUSE	0
306999	305883	19489J	PARTICIPANT	\N	EXCUSE	0
307000	305883	14028W	PARTICIPANT	\N	PRESENT	0
308702	307030	08056B	PARTICIPANT	\N	EXCUSE	0
308704	307030	08061X	PARTICIPANT	\N	EXCUSE	0
308709	307031	08056B	PARTICIPANT	\N	EXCUSE	0
308710	307031	08061X	PARTICIPANT	\N	EXCUSE	0
308738	308737	08045X	PARTICIPANT	\N	PRESENT	0
309061	306017	19629C	PARTICIPANT	\N	EXCUSE	0
309161	309157	19699S	PARTICIPANT	\N	PRESENT	0
309159	309156	19699S	PARTICIPANT	\N	PRESENT	0
309160	309156	19749K	PARTICIPANT	\N	PRESENT	0
309162	309157	19749K	PARTICIPANT	\N	PRESENT	0
309338	309337	14225N	PARTICIPANT	\N	PRESENT	0
309339	309337	07033P	PARTICIPANT	\N	PRESENT	0
309340	309337	12041X	PARTICIPANT	\N	PRESENT	0
309341	309337	11026G	PARTICIPANT	\N	PRESENT	0
309342	309337	14087W	PARTICIPANT	\N	PRESENT	0
309343	309337	04097T	PARTICIPANT	\N	PRESENT	0
309344	309337	19515S	PARTICIPANT	\N	PRESENT	0
309345	309337	14097Y	PARTICIPANT	\N	PRESENT	0
309346	309337	08038Y	PARTICIPANT	\N	PRESENT	0
309347	309337	19251M	PARTICIPANT	\N	PRESENT	0
309348	309337	14109K	PARTICIPANT	\N	PRESENT	0
311206	311187	19699S	PARTICIPANT	\N	PRESENT	0
311214	311190	08031R	PARTICIPANT	\N	PRESENT	0
311217	311190	14229S	PARTICIPANT	\N	PRESENT	0
311223	311190	19593H	PARTICIPANT	\N	PRESENT	0
311337	311336	10006L	PARTICIPANT	\N	PRESENT	0
311338	311336	01034P	PARTICIPANT	\N	PRESENT	0
311339	311336	11067R	PARTICIPANT	\N	PRESENT	0
311340	311336	19723Y	PARTICIPANT	\N	PRESENT	0
311636	311635	10006L	PARTICIPANT	\N	PRESENT	0
311637	311635	08052W	PARTICIPANT	\N	PRESENT	0
311638	311635	19723Y	PARTICIPANT	\N	PRESENT	0
311640	311639	10006L	PARTICIPANT	\N	PRESENT	0
311813	311612	14089Y	PARTICIPANT	\N	PRESENT	0
311814	311612	01062T	PARTICIPANT	\N	PRESENT	0
311815	311612	01057W	PARTICIPANT	\N	PRESENT	0
311816	311612	98022P	PARTICIPANT	\N	PRESENT	0
311817	311612	19709B	PARTICIPANT	\N	PRESENT	0
311818	311612	96004D	PRESIDENT	0	PRESENT	0
311819	311612	01058X	PARTICIPANT	\N	PRESENT	0
311820	311612	98050T	PARTICIPANT	\N	PRESENT	0
311821	311612	19251M	PARTICIPANT	\N	PRESENT	0
311822	311612	19333N	PARTICIPANT	\N	PRESENT	0
311823	311612	14331P	PARTICIPANT	\N	PRESENT	0
311824	311612	08043V	PARTICIPANT	\N	PRESENT	0
311825	311612	08017T	PARTICIPANT	\N	PRESENT	0
311826	311612	04097T	PARTICIPANT	\N	PRESENT	0
311827	309270	14034U	PARTICIPANT	\N	PRESENT	0
311828	311612	14205J	PARTICIPANT	\N	PRESENT	0
311829	311612	04057K	PARTICIPANT	\N	PRESENT	0
311830	311612	11083R	PARTICIPANT	\N	PRESENT	0
311831	311612	04061F	PARTICIPANT	\N	PRESENT	0
311832	311612	14053L	PARTICIPANT	\N	EXCUSE	0
311833	311612	08031R	PARTICIPANT	\N	EXCUSE	0
311834	311612	19573D	PARTICIPANT	\N	PRESENT	0
311835	311612	04035D	PARTICIPANT	\N	PRESENT	0
311836	309270	14257W	PARTICIPANT	\N	PRESENT	0
311837	309270	19591F	PARTICIPANT	\N	PRESENT	0
311838	309270	08055A	PARTICIPANT	\N	PRESENT	0
311839	309270	11090Q	PARTICIPANT	\N	PRESENT	0
311840	309270	14187A	PARTICIPANT	\N	PRESENT	0
311841	309270	19583F	PARTICIPANT	\N	PRESENT	0
311842	309270	07004J	PARTICIPANT	\N	PRESENT	0
311843	309270	16685X	PARTICIPANT	\N	PRESENT	0
311844	309270	19747H	PARTICIPANT	\N	PRESENT	0
311845	311612	04034C	PARTICIPANT	\N	PRESENT	0
311846	309270	14207L	PARTICIPANT	\N	PRESENT	0
311847	309270	19631V	PARTICIPANT	\N	PRESENT	0
311848	309270	11056N	PARTICIPANT	\N	PRESENT	0
311849	309270	14197C	PARTICIPANT	\N	PRESENT	0
311850	309270	11066Q	PARTICIPANT	\N	PRESENT	0
311851	309270	19637C	PARTICIPANT	\N	PRESENT	0
311852	309270	19347U	PARTICIPANT	\N	PRESENT	0
311853	309270	19565D	PARTICIPANT	\N	PRESENT	0
311854	309270	08044W	PARTICIPANT	\N	PRESENT	0
311855	311612	14097Y	PARTICIPANT	\N	EXCUSE	0
311856	309270	14231L	PARTICIPANT	\N	PRESENT	0
311857	309270	19737F	PARTICIPANT	\N	PRESENT	0
311858	309270	14089Y	PARTICIPANT	\N	PRESENT	0
311859	309270	19721W	PARTICIPANT	\N	PRESENT	0
311860	309270	01025N	PARTICIPANT	\N	PRESENT	0
311861	309270	01043Q	PARTICIPANT	\N	PRESENT	0
311862	309270	19611R	PARTICIPANT	\N	PRESENT	0
311863	309270	19735D	PARTICIPANT	\N	PRESENT	0
311864	309270	04089T	PARTICIPANT	\N	PRESENT	0
311865	309270	19335Q	PARTICIPANT	\N	PRESENT	0
311866	309270	04018C	PARTICIPANT	\N	PRESENT	0
311867	309270	01060R	PARTICIPANT	\N	PRESENT	0
311868	309270	95063L	PARTICIPANT	\N	PRESENT	0
311869	309270	14329V	PARTICIPANT	\N	PRESENT	0
311870	309270	19768N	PARTICIPANT	\N	PRESENT	0
311871	309270	14151M	PARTICIPANT	\N	PRESENT	0
311872	309270	19349W	PARTICIPANT	\N	PRESENT	0
311873	309270	14267Y	PARTICIPANT	\N	PRESENT	0
311874	309270	14327T	PARTICIPANT	\N	PRESENT	0
327618	327587	14107H	PARTICIPANT	\N	EXCUSE	0
327619	327587	19758L	PARTICIPANT	\N	EXCUSE	0
327620	327587	08039A	PARTICIPANT	\N	EXCUSE	0
327621	327587	14229S	PARTICIPANT	\N	EXCUSE	0
327623	327622	98050T	PARTICIPANT	\N	PRESENT	0
327624	327622	98018T	PARTICIPANT	\N	PRESENT	0
327635	324917	04071H	PARTICIPANT	\N	PRESENT	0
327636	324917	19545Y	PARTICIPANT	\N	PRESENT	0
327637	324917	01057W	PARTICIPANT	\N	PRESENT	0
327638	324917	89017R	PARTICIPANT	\N	PRESENT	0
327639	324917	19667J	PARTICIPANT	\N	PRESENT	0
327640	324917	11074Q	PRESIDENT	0	PRESENT	0
327641	324917	14225N	PARTICIPANT	\N	PRESENT	0
327642	324917	11070L	PARTICIPANT	\N	PRESENT	0
327643	324917	19671E	PARTICIPANT	\N	PRESENT	0
327644	324917	07029T	PARTICIPANT	\N	PRESENT	0
327645	324917	14085U	PARTICIPANT	\N	PRESENT	0
327646	324917	19349W	PARTICIPANT	\N	PRESENT	0
327647	324917	08010L	PARTICIPANT	\N	PRESENT	0
328234	328231	14089Y	PARTICIPANT	\N	PRESENT	0
327649	324917	11048N	PARTICIPANT	\N	PRESENT	0
327650	324917	19479G	PARTICIPANT	\N	PRESENT	0
327651	324917	19647E	PARTICIPANT	\N	PRESENT	0
327652	324917	19711U	PARTICIPANT	\N	PRESENT	0
327653	324917	19531S	PARTICIPANT	\N	PRESENT	0
327654	324917	08034U	PARTICIPANT	\N	PRESENT	0
327655	324917	08011M	PARTICIPANT	\N	PRESENT	0
327656	324917	14034U	PARTICIPANT	\N	PRESENT	0
327657	324917	14159V	PARTICIPANT	\N	PRESENT	0
327658	324917	04086Q	PARTICIPANT	\N	PRESENT	0
327659	324917	11040E	PARTICIPANT	\N	PRESENT	0
327660	324917	11012A	PARTICIPANT	\N	PRESENT	0
327661	324917	14199E	PARTICIPANT	\N	PRESENT	0
327662	324917	19741B	PARTICIPANT	\N	PRESENT	0
327663	324917	99004R	PARTICIPANT	\N	PRESENT	0
327664	324917	04061F	PARTICIPANT	\N	PRESENT	0
327665	324917	14327T	PARTICIPANT	\N	PRESENT	0
327666	324917	14083S	PARTICIPANT	\N	PRESENT	0
328232	328231	14065Q	PARTICIPANT	\N	PRESENT	0
328233	328231	96004D	PRESIDENT	0	PRESENT	0
328235	328231	14249W	PARTICIPANT	\N	PRESENT	0
328236	328231	11083R	PARTICIPANT	\N	PRESENT	0
328237	328231	19725B	PARTICIPANT	\N	PRESENT	0
328238	328231	95037J	PARTICIPANT	\N	PRESENT	0
328239	328231	14097Y	PARTICIPANT	\N	PRESENT	0
328240	328231	04061F	PARTICIPANT	\N	PRESENT	0
328241	328231	14073Q	PARTICIPANT	\N	PRESENT	0
328242	328231	14001X	PARTICIPANT	\N	PRESENT	0
328243	328231	14221J	PARTICIPANT	\N	PRESENT	0
328244	328231	19563B	PARTICIPANT	\N	PRESENT	0
328245	328231	14331P	PARTICIPANT	\N	PRESENT	0
328246	328231	98035U	PARTICIPANT	\N	PRESENT	0
328247	328231	10015M	PARTICIPANT	\N	EXCUSE	0
328248	328231	14237S	PARTICIPANT	\N	EXCUSE	0
328249	328231	04057K	PARTICIPANT	\N	EXCUSE	0
328250	328231	11026G	PARTICIPANT	\N	EXCUSE	0
328646	320563	19709B	PARTICIPANT	\N	EXCUSE	0
328642	324921	19711U	PARTICIPANT	\N	PRESENT	0
328701	328700	89017R	PARTICIPANT	\N	PRESENT	0
328702	328700	11031D	PARTICIPANT	\N	PRESENT	0
328703	328700	11027H	PARTICIPANT	\N	PRESENT	0
328704	328700	98023Q	PARTICIPANT	\N	PRESENT	0
328705	328700	04086Q	PARTICIPANT	\N	PRESENT	0
328706	328700	11074Q	PARTICIPANT	\N	PRESENT	0
328707	328700	14187A	PARTICIPANT	\N	PRESENT	0
328708	328700	01025N	PARTICIPANT	\N	PRESENT	0
328709	328700	19521Q	PARTICIPANT	\N	PRESENT	0
328710	328700	14034U	PARTICIPANT	\N	PRESENT	0
328711	328700	14033T	PARTICIPANT	\N	PRESENT	0
328712	328700	14021P	PARTICIPANT	\N	PRESENT	0
328713	328700	14159V	PARTICIPANT	\N	PRESENT	0
328714	328700	01043Q	PARTICIPANT	\N	PRESENT	0
328715	328700	14251Q	PARTICIPANT	\N	PRESENT	0
328716	328700	04070G	PARTICIPANT	\N	PRESENT	0
328717	328700	14237S	PARTICIPANT	\N	PRESENT	0
328718	328700	98018T	PARTICIPANT	\N	PRESENT	0
328719	328700	07034Q	PARTICIPANT	\N	PRESENT	0
328720	328700	11012A	PARTICIPANT	\N	PRESENT	0
328721	328700	01034P	PARTICIPANT	\N	PRESENT	0
328747	326974	04044E	PARTICIPANT	\N	EXCUSE	0
328777	321340	11027H	PARTICIPANT	\N	PRESENT	0
328750	326974	14071N	PARTICIPANT	\N	PRESENT	0
328779	321340	19593H	PARTICIPANT	\N	PRESENT	0
328778	321340	19319Q	PARTICIPANT	\N	PRESENT	0
328780	321340	16685X	PARTICIPANT	\N	PRESENT	0
328781	321340	19683J	PARTICIPANT	\N	PRESENT	0
328782	321340	19643A	PARTICIPANT	\N	PRESENT	0
328783	321340	08011M	PARTICIPANT	\N	PRESENT	0
328784	321340	11074Q	PARTICIPANT	\N	PRESENT	0
328785	321340	07029T	PARTICIPANT	\N	PRESENT	0
328786	321340	14159V	PARTICIPANT	\N	PRESENT	0
328787	321340	11012A	PARTICIPANT	\N	PRESENT	0
328788	321340	19687N	PARTICIPANT	\N	PRESENT	0
328789	321340	04085P	PARTICIPANT	\N	PRESENT	0
328790	321340	19669L	PARTICIPANT	\N	PRESENT	0
328791	321340	19649G	PARTICIPANT	\N	PRESENT	0
328792	321340	11072N	PARTICIPANT	\N	PRESENT	0
328793	321340	19693L	PARTICIPANT	\N	PRESENT	0
328794	321340	19549D	PARTICIPANT	\N	PRESENT	0
328795	321340	80013X	PARTICIPANT	\N	PRESENT	0
328796	321340	19695N	PARTICIPANT	\N	PRESENT	0
328797	321340	19295A	PARTICIPANT	\N	PRESENT	0
328798	321340	11109J	PARTICIPANT	\N	PRESENT	0
328799	321340	14085U	PARTICIPANT	\N	PRESENT	0
328804	321340	19545Y	PARTICIPANT	\N	PRESENT	0
328801	321340	04059M	PARTICIPANT	\N	PRESENT	0
328802	321340	04034C	PARTICIPANT	\N	PRESENT	0
328803	321340	14225N	PARTICIPANT	\N	PRESENT	0
328805	321340	14261S	PARTICIPANT	\N	PRESENT	0
328806	321340	11053K	PARTICIPANT	\N	PRESENT	0
328807	321340	07004J	PARTICIPANT	\N	PRESENT	0
328808	321340	14357A	PARTICIPANT	\N	PRESENT	0
328809	321340	11048N	PARTICIPANT	\N	PRESENT	0
328810	321340	04086Q	PARTICIPANT	\N	PRESENT	0
328811	321340	11031D	PARTICIPANT	\N	PRESENT	0
328812	321340	19651A	PARTICIPANT	\N	PRESENT	0
328813	321340	19689Q	PARTICIPANT	\N	PRESENT	0
328814	321340	19647E	PARTICIPANT	\N	PRESENT	0
328815	321340	08010L	PARTICIPANT	\N	PRESENT	0
328816	321340	11090Q	PARTICIPANT	\N	PRESENT	0
328817	321340	19711U	PARTICIPANT	\N	PRESENT	0
328818	321340	01057W	PARTICIPANT	\N	PRESENT	0
328819	321340	19667J	PARTICIPANT	\N	PRESENT	0
328820	321340	14033T	PARTICIPANT	\N	PRESENT	0
328821	321340	14041T	PARTICIPANT	\N	PRESENT	0
328822	321340	01043Q	PARTICIPANT	\N	PRESENT	0
328823	321340	19301E	PARTICIPANT	\N	PRESENT	0
328824	321340	19289C	PARTICIPANT	\N	PRESENT	0
328825	321340	14107H	PARTICIPANT	\N	PRESENT	0
328826	321340	14275Y	PARTICIPANT	\N	PRESENT	0
328827	321340	08020N	PARTICIPANT	\N	PRESENT	0
328828	321340	19701S	PARTICIPANT	\N	PRESENT	0
328829	321340	19719D	PARTICIPANT	\N	PRESENT	0
328830	321340	19749K	PARTICIPANT	\N	PRESENT	0
328831	321340	01048V	PARTICIPANT	\N	PRESENT	0
328832	321340	11040E	PARTICIPANT	\N	PRESENT	0
328833	321340	99004R	PARTICIPANT	\N	PRESENT	0
328834	321340	14255U	PARTICIPANT	\N	PRESENT	0
328835	321340	19347U	PARTICIPANT	\N	PRESENT	0
328836	321340	11077T	PARTICIPANT	\N	PRESENT	0
328837	321340	08034U	PARTICIPANT	\N	PRESENT	0
328838	321340	19741B	PARTICIPANT	\N	PRESENT	0
328843	321340	11033F	PARTICIPANT	\N	PRESENT	0
328844	321340	11065P	PARTICIPANT	\N	PRESENT	0
328845	321340	11110B	PARTICIPANT	\N	PRESENT	0
328846	321340	11045K	PARTICIPANT	\N	PRESENT	0
328847	321340	19551W	PARTICIPANT	\N	PRESENT	0
328848	321340	19583F	PARTICIPANT	\N	PRESENT	0
328849	321340	08019V	PARTICIPANT	\N	PRESENT	0
328850	321340	14187A	PARTICIPANT	\N	PRESENT	0
328851	321340	04043D	PARTICIPANT	\N	PRESENT	0
328852	321340	95041E	PARTICIPANT	\N	PRESENT	0
328853	321340	04061F	PARTICIPANT	\N	PRESENT	0
328854	321340	98050T	PARTICIPANT	\N	PRESENT	0
328857	321340	08061X	PARTICIPANT	\N	PRESENT	0
328858	321340	14001X	PARTICIPANT	\N	PRESENT	0
328859	321340	14115H	PARTICIPANT	\N	PRESENT	0
328860	321340	08052W	PARTICIPANT	\N	PRESENT	0
328861	321340	08062Y	PARTICIPANT	\N	PRESENT	0
328862	321340	19335Q	PARTICIPANT	\N	PRESENT	0
328863	321340	11085T	PARTICIPANT	\N	PRESENT	0
328864	321340	14257W	PARTICIPANT	\N	PRESENT	0
328865	321340	04045F	PARTICIPANT	\N	PRESENT	0
328866	321340	08069G	PARTICIPANT	\N	PRESENT	0
328867	321340	19563B	PARTICIPANT	\N	PRESENT	0
328868	321340	14199E	PARTICIPANT	\N	PRESENT	0
328869	321340	04040A	PARTICIPANT	\N	PRESENT	0
328870	321340	14083S	PARTICIPANT	\N	PRESENT	0
303839	303838	14259Y	PARTICIPANT	\N	PRESENT	0
303840	303838	19715Y	PARTICIPANT	\N	PRESENT	0
303841	303838	12016W	PARTICIPANT	\N	PRESENT	0
303842	303838	08019V	PARTICIPANT	\N	PRESENT	0
303843	303838	14261S	PARTICIPANT	\N	PRESENT	0
305268	305267	04047H	PARTICIPANT	\N	PRESENT	0
305270	305269	04047H	PARTICIPANT	\N	PRESENT	0
305272	305271	01024M	PARTICIPANT	\N	PRESENT	0
305274	305273	04047H	PARTICIPANT	\N	PRESENT	0
305275	305273	01024M	PARTICIPANT	\N	PRESENT	0
307098	307097	14073Q	PARTICIPANT	\N	PRESENT	0
307099	307097	18083K	PARTICIPANT	\N	PRESENT	0
307100	307097	04040A	PARTICIPANT	\N	PRESENT	0
307101	307097	11026G	PARTICIPANT	\N	PRESENT	0
307103	307102	14073Q	PARTICIPANT	\N	PRESENT	0
307129	305900	08062Y	PARTICIPANT	\N	PRESENT	0
307130	305900	11066Q	PARTICIPANT	\N	PRESENT	0
309028	309027	14255U	PARTICIPANT	\N	PRESENT	0
310806	310746	14065Q	PARTICIPANT	\N	PRESENT	0
310807	310746	96004D	PRESIDENT	0	PRESENT	0
310808	310746	14089Y	PARTICIPANT	\N	PRESENT	0
310809	310746	14033T	PARTICIPANT	\N	PRESENT	0
310810	310746	19725B	PARTICIPANT	\N	PRESENT	0
310811	310746	95037J	PARTICIPANT	\N	PRESENT	0
310812	310746	08044W	PARTICIPANT	\N	PRESENT	0
310813	310746	11026G	PARTICIPANT	\N	PRESENT	0
310814	310746	04057K	PARTICIPANT	\N	PRESENT	0
310815	310746	19563B	PARTICIPANT	\N	PRESENT	0
310816	310746	19593H	PARTICIPANT	\N	PRESENT	0
310817	310746	14237S	PARTICIPANT	\N	PRESENT	0
310818	310746	98035U	PARTICIPANT	\N	PRESENT	0
310819	310746	14229S	PARTICIPANT	\N	PRESENT	0
310820	310746	10015M	PARTICIPANT	\N	PRESENT	0
310821	310746	14225N	PARTICIPANT	\N	PRESENT	0
310824	310746	14357A	PARTICIPANT	\N	EXCUSE	0
310826	310746	11083R	PARTICIPANT	\N	EXCUSE	0
310828	310746	04061F	PARTICIPANT	\N	EXCUSE	0
310829	310746	14135M	PARTICIPANT	\N	EXCUSE	0
310830	310746	14331P	PARTICIPANT	\N	EXCUSE	0
311744	311743	04071H	PARTICIPANT	\N	PRESENT	0
311746	311745	04071H	PARTICIPANT	\N	PRESENT	0
311748	311747	04071H	PARTICIPANT	\N	PRESENT	0
313394	310421	19663E	PARTICIPANT	\N	EXCUSE	0
313395	310421	14281W	PARTICIPANT	\N	EXCUSE	0
313443	310419	14281W	PARTICIPANT	\N	EXCUSE	0
313946	313876	14061L	PARTICIPANT	\N	EXCUSE	0
313947	313876	04097T	PARTICIPANT	\N	EXCUSE	0
313948	313876	14065Q	PARTICIPANT	\N	EXCUSE	0
313950	313949	19349W	PARTICIPANT	\N	PRESENT	0
313952	313951	07004J	PARTICIPANT	\N	PRESENT	0
313954	313953	04086Q	PARTICIPANT	\N	PRESENT	0
313959	313958	14199E	PARTICIPANT	\N	PRESENT	0
313961	313960	19479G	PARTICIPANT	\N	PRESENT	0
313963	313962	14083S	PARTICIPANT	\N	PRESENT	0
313965	313964	08010L	PARTICIPANT	\N	PRESENT	0
313967	313966	08010L	PARTICIPANT	\N	PRESENT	0
313970	313969	14331P	PARTICIPANT	\N	PRESENT	0
313972	313971	14085U	PARTICIPANT	\N	PRESENT	0
313973	313971	14253S	PARTICIPANT	\N	PRESENT	0
313976	313975	14121F	PARTICIPANT	\N	PRESENT	0
313979	313978	08011M	PARTICIPANT	\N	PRESENT	0
313993	313992	19667J	PARTICIPANT	\N	PRESENT	0
313994	313992	11040E	PARTICIPANT	\N	PRESENT	0
313996	313995	19667J	PARTICIPANT	\N	PRESENT	0
313997	313995	11040E	PARTICIPANT	\N	PRESENT	0
314064	314063	04061F	PARTICIPANT	\N	PRESENT	0
314066	314065	04061F	PARTICIPANT	\N	PRESENT	0
314068	314067	04061F	PARTICIPANT	\N	PRESENT	0
316874	316868	11053K	PARTICIPANT	\N	PRESENT	0
316875	316868	14159V	PARTICIPANT	\N	PRESENT	0
316876	316868	05012A	PARTICIPANT	\N	PRESENT	0
319519	314087	14133K	PARTICIPANT	\N	PRESENT	0
319520	314087	08015R	PARTICIPANT	\N	PRESENT	0
319521	314087	14213J	PARTICIPANT	\N	PRESENT	0
319522	314087	14042U	PARTICIPANT	\N	PRESENT	0
319523	314087	14105F	PARTICIPANT	\N	PRESENT	0
319524	314087	98018T	PARTICIPANT	\N	PRESENT	0
319525	314087	87003B	PARTICIPANT	\N	PRESENT	0
313385	310419	19675J	PARTICIPANT	\N	EXCUSE	0
313386	310421	19675J	PARTICIPANT	\N	EXCUSE	0
319526	314087	14089Y	PARTICIPANT	\N	PRESENT	0
319527	314087	14028W	PARTICIPANT	\N	PRESENT	0
319528	314087	08069G	PARTICIPANT	\N	PRESENT	0
319529	314087	19521Q	PARTICIPANT	\N	PRESENT	0
319530	314087	19253P	PARTICIPANT	\N	PRESENT	0
319531	314087	14217N	PARTICIPANT	\N	PRESENT	0
319532	314087	11064N	PARTICIPANT	\N	PRESENT	0
319533	314087	19631V	PARTICIPANT	\N	PRESENT	0
319540	319213	89017R	PARTICIPANT	\N	PRESENT	0
319577	314087	14331P	PARTICIPANT	\N	PRESENT	0
319536	314087	19703U	PARTICIPANT	\N	PRESENT	0
319537	319213	11048N	PARTICIPANT	\N	PRESENT	0
319538	314087	19599P	PARTICIPANT	\N	PRESENT	0
319539	314087	14097Y	PARTICIPANT	\N	PRESENT	0
319541	314087	19399H	PARTICIPANT	\N	PRESENT	0
319542	314087	11101A	PARTICIPANT	\N	PRESENT	0
319543	314087	19713W	PARTICIPANT	\N	PRESENT	0
319544	314087	11067R	PARTICIPANT	\N	PRESENT	0
319545	314087	14207L	PARTICIPANT	\N	PRESENT	0
319546	314087	19643A	PARTICIPANT	\N	PRESENT	0
319547	314087	11103C	PARTICIPANT	\N	PRESENT	0
319548	314087	95030B	PARTICIPANT	\N	PRESENT	0
319549	314087	14135M	PARTICIPANT	\N	PRESENT	0
319550	314087	14151M	PARTICIPANT	\N	PRESENT	0
319551	314087	14033T	PARTICIPANT	\N	PRESENT	0
319552	314087	14231L	PARTICIPANT	\N	PRESENT	0
319553	314087	19421M	PARTICIPANT	\N	PRESENT	0
319554	314087	11040E	PARTICIPANT	\N	PRESENT	0
319555	319213	14159V	PARTICIPANT	\N	PRESENT	0
319556	314087	08068F	PARTICIPANT	\N	PRESENT	0
319557	314087	19723Y	PARTICIPANT	\N	PRESENT	0
319558	314087	11099A	PARTICIPANT	\N	PRESENT	0
319559	314087	11085T	PARTICIPANT	\N	PRESENT	0
319560	314087	80013X	PARTICIPANT	\N	PRESENT	0
319561	314087	19507S	PARTICIPANT	\N	PRESENT	0
319562	314087	08038Y	PARTICIPANT	\N	PRESENT	0
319563	319213	11066Q	PARTICIPANT	\N	PRESENT	0
319564	319213	08047A	PARTICIPANT	\N	PRESENT	0
319565	314087	01058X	PARTICIPANT	\N	PRESENT	0
319570	314087	19441R	PARTICIPANT	\N	PRESENT	0
319571	314087	14053L	PARTICIPANT	\N	PRESENT	0
319572	314087	01057W	PARTICIPANT	\N	PRESENT	0
319574	314087	19503N	PARTICIPANT	\N	PRESENT	0
319575	319213	01057W	PARTICIPANT	\N	PRESENT	0
319576	314087	19669L	PARTICIPANT	\N	PRESENT	0
319578	314087	01034P	PARTICIPANT	\N	PRESENT	0
319581	314087	19681G	PARTICIPANT	\N	PRESENT	0
319582	314087	08044W	PARTICIPANT	\N	PRESENT	0
319584	314087	14205J	PARTICIPANT	\N	PRESENT	0
319587	314087	14059S	PARTICIPANT	\N	PRESENT	0
319591	314087	98050T	PARTICIPANT	\N	PRESENT	0
319598	314087	08031R	PARTICIPANT	\N	PRESENT	0
319599	314087	19333N	PARTICIPANT	\N	PRESENT	0
319600	314087	19651A	PARTICIPANT	\N	PRESENT	0
319734	314090	11027H	PARTICIPANT	\N	PRESENT	0
319795	319339	04070G	PRESIDENT	0	PRESENT	0
319796	319339	19699S	PARTICIPANT	\N	PRESENT	0
319797	319339	19533U	PARTICIPANT	\N	PRESENT	0
319798	319339	89017R	PARTICIPANT	\N	PRESENT	0
319799	319339	14229S	PARTICIPANT	\N	PRESENT	0
319800	319339	14241N	PARTICIPANT	\N	PRESENT	0
319801	319339	19573D	PARTICIPANT	\N	PRESENT	0
319802	319339	14107H	PARTICIPANT	\N	PRESENT	0
319803	319339	08039A	PARTICIPANT	\N	PRESENT	0
319804	319339	19593H	PARTICIPANT	\N	PRESENT	0
319805	319339	19643A	PARTICIPANT	\N	PRESENT	0
319806	319339	14061L	PARTICIPANT	\N	PRESENT	0
319807	319339	19611R	PARTICIPANT	\N	PRESENT	0
319808	319339	19693L	PARTICIPANT	\N	PRESENT	0
319809	319339	19399H	PARTICIPANT	\N	PRESENT	0
319810	319339	87003B	PARTICIPANT	\N	PRESENT	0
319811	319339	14030Q	PARTICIPANT	\N	PRESENT	0
319812	319339	04059M	PARTICIPANT	\N	PRESENT	0
319813	319339	19735D	PARTICIPANT	\N	PRESENT	0
319814	319339	14063N	PARTICIPANT	\N	PRESENT	0
319815	319339	14123H	PARTICIPANT	\N	PRESENT	0
319816	319339	11104D	PARTICIPANT	\N	PRESENT	0
319817	319339	04018C	PARTICIPANT	\N	PRESENT	0
319818	319339	19758L	PARTICIPANT	\N	PRESENT	0
319819	319339	19621T	PARTICIPANT	\N	PRESENT	0
319820	319339	19731Y	PARTICIPANT	\N	EXCUSE	0
319821	319339	04057K	PARTICIPANT	\N	EXCUSE	0
319822	319339	14109K	PARTICIPANT	\N	EXCUSE	0
319823	319339	14249W	PARTICIPANT	\N	EXCUSE	0
319824	319339	08031R	PARTICIPANT	\N	EXCUSE	0
319825	314090	08047A	PARTICIPANT	\N	PRESENT	0
319878	314090	14069U	PARTICIPANT	\N	PRESENT	0
319879	314090	14038Y	PARTICIPANT	\N	PRESENT	0
319880	314090	19573D	PARTICIPANT	\N	PRESENT	0
331210	330479	19553Y	PARTICIPANT	\N	PRESENT	0
331211	330479	19703U	PARTICIPANT	\N	PRESENT	0
331212	330479	01034P	PARTICIPANT	\N	PRESENT	0
331213	330479	04092N	PRESIDENT	0	PRESENT	0
331214	330479	11097X	PARTICIPANT	\N	PRESENT	0
331215	330479	08052W	PARTICIPANT	\N	PRESENT	0
331216	330479	19415P	PARTICIPANT	\N	PRESENT	0
331217	330479	14071N	PARTICIPANT	\N	PRESENT	0
331218	330479	19683J	PARTICIPANT	\N	PRESENT	0
331219	330479	19697Q	PARTICIPANT	\N	PRESENT	0
331220	330479	14195A	PARTICIPANT	\N	PRESENT	0
331221	330479	19723Y	PARTICIPANT	\N	PRESENT	0
331222	330479	14227Q	PARTICIPANT	\N	PRESENT	0
331223	330479	19727D	PARTICIPANT	\N	PRESENT	0
331224	330479	11031D	PARTICIPANT	\N	PRESENT	0
331225	330479	14213J	PARTICIPANT	\N	PRESENT	0
331226	330479	14217N	PARTICIPANT	\N	PRESENT	0
331227	330479	19521Q	PARTICIPANT	\N	PRESENT	0
331228	330479	14355X	PARTICIPANT	\N	EXCUSE	0
331229	330479	08041T	PARTICIPANT	\N	EXCUSE	0
331230	330479	19575F	PARTICIPANT	\N	PRESENT	0
331231	330479	14119M	PARTICIPANT	\N	PRESENT	0
331232	330479	19301E	PARTICIPANT	\N	PRESENT	0
331302	321349	04092N	PARTICIPANT	\N	PRESENT	0
331303	321349	01034P	PARTICIPANT	\N	PRESENT	0
331304	321349	11031D	PARTICIPANT	\N	PRESENT	0
331306	321349	19727D	PARTICIPANT	\N	PRESENT	0
331307	321349	14281W	PARTICIPANT	\N	PRESENT	0
331308	321349	19683J	PARTICIPANT	\N	PRESENT	0
331309	321349	08052W	PARTICIPANT	\N	PRESENT	0
331310	321349	19651A	PARTICIPANT	\N	PRESENT	0
331311	321349	08073C	PARTICIPANT	\N	PRESENT	0
331312	321349	19479G	PARTICIPANT	\N	PRESENT	0
331313	321349	14089Y	PARTICIPANT	\N	PRESENT	0
331314	321349	07004J	PARTICIPANT	\N	PRESENT	0
331315	321349	19697Q	PARTICIPANT	\N	PRESENT	0
331316	321349	19553Y	PARTICIPANT	\N	PRESENT	0
331317	321349	14213J	PARTICIPANT	\N	PRESENT	0
331318	321349	04086Q	PARTICIPANT	\N	PRESENT	0
331319	321349	14217N	PARTICIPANT	\N	PRESENT	0
331320	321349	19575F	PARTICIPANT	\N	PRESENT	0
331321	321349	08019V	PARTICIPANT	\N	PRESENT	0
331322	321349	14157T	PARTICIPANT	\N	PRESENT	0
331323	321349	14119M	PARTICIPANT	\N	PRESENT	0
331324	321349	19415P	PARTICIPANT	\N	PRESENT	0
331325	321349	19447X	PARTICIPANT	\N	PRESENT	0
331326	321349	19703U	PARTICIPANT	\N	PRESENT	0
331327	321349	19515S	PARTICIPANT	\N	PRESENT	0
331328	321349	08020N	PARTICIPANT	\N	PRESENT	0
331329	321349	14207L	PARTICIPANT	\N	PRESENT	0
331330	321349	01057W	PARTICIPANT	\N	PRESENT	0
331331	321349	08015R	PARTICIPANT	\N	PRESENT	0
331332	321349	97011G	PARTICIPANT	\N	PRESENT	0
331333	321349	19521Q	PARTICIPANT	\N	PRESENT	0
331360	331359	08024S	PARTICIPANT	\N	PRESENT	0
331361	331359	04043D	PARTICIPANT	\N	PRESENT	0
331362	331359	14059S	PARTICIPANT	\N	PRESENT	0
331394	330924	14030Q	PRESIDENT	0	PRESENT	0
331395	330924	08043V	PARTICIPANT	\N	PRESENT	0
331396	330924	19643A	PARTICIPANT	\N	PRESENT	0
331397	330924	19701S	PARTICIPANT	\N	PRESENT	0
331398	330924	19693L	PARTICIPANT	\N	PRESENT	0
331399	330924	19731Y	PARTICIPANT	\N	PRESENT	0
331400	330924	19715Y	PARTICIPANT	\N	EXCUSE	0
331401	330924	08031R	PARTICIPANT	\N	PRESENT	0
331402	330924	08017T	PARTICIPANT	\N	PRESENT	0
331403	330924	11067R	PARTICIPANT	\N	PRESENT	0
331404	330924	14109K	PARTICIPANT	\N	PRESENT	0
331405	330924	11045K	PARTICIPANT	\N	PRESENT	0
331406	330924	19749K	PARTICIPANT	\N	PRESENT	0
331407	330924	14179A	PARTICIPANT	\N	EXCUSE	0
331415	331414	14053L	PARTICIPANT	\N	PRESENT	0
331418	331417	14053L	PARTICIPANT	\N	PRESENT	0
331420	331419	14053L	PARTICIPANT	\N	PRESENT	0
331423	331422	14053L	PARTICIPANT	\N	PRESENT	0
331707	321351	11110B	PARTICIPANT	\N	PRESENT	0
331708	321351	19503N	PARTICIPANT	\N	PRESENT	0
331709	321351	19651A	PARTICIPANT	\N	PRESENT	0
331710	321351	19545Y	PARTICIPANT	\N	PRESENT	0
331711	321351	04088S	PARTICIPANT	\N	PRESENT	0
331295	321349	04059M	PARTICIPANT	\N	PRESENT	0
331712	321351	07029T	PARTICIPANT	\N	PRESENT	0
331713	321351	14119M	PARTICIPANT	\N	PRESENT	0
331714	321351	14157T	PARTICIPANT	\N	PRESENT	0
331715	321351	14357A	PARTICIPANT	\N	PRESENT	0
331716	321351	01057W	PARTICIPANT	\N	PRESENT	0
331717	321351	14329V	PARTICIPANT	\N	PRESENT	0
331718	321351	14265W	PARTICIPANT	\N	PRESENT	0
331719	321351	04049K	PARTICIPANT	\N	PRESENT	0
331720	321351	08034U	PARTICIPANT	\N	PRESENT	0
331721	321351	11048N	PARTICIPANT	\N	PRESENT	0
331722	321351	04086Q	PARTICIPANT	\N	PRESENT	0
331723	321351	14159V	PARTICIPANT	\N	PRESENT	0
331724	321351	19647E	PARTICIPANT	\N	PRESENT	0
331725	321351	07004J	PARTICIPANT	\N	PRESENT	0
331726	321351	19687N	PARTICIPANT	\N	PRESENT	0
331727	321351	08068F	PARTICIPANT	\N	PRESENT	0
331728	321351	14107H	PARTICIPANT	\N	PRESENT	0
331729	321351	11012A	PARTICIPANT	\N	PRESENT	0
331730	321351	88008L	PARTICIPANT	\N	PRESENT	0
331731	321351	04043D	PARTICIPANT	\N	PRESENT	0
331732	321351	14034U	PARTICIPANT	\N	PRESENT	0
331733	321351	19671E	PARTICIPANT	\N	PRESENT	0
331734	321351	19693L	PARTICIPANT	\N	PRESENT	0
331735	321351	19701S	PARTICIPANT	\N	PRESENT	0
331736	321351	04085P	PARTICIPANT	\N	PRESENT	0
331737	321351	14267Y	PARTICIPANT	\N	PRESENT	0
331738	321351	14083S	PARTICIPANT	\N	PRESENT	0
331739	321351	14179A	PARTICIPANT	\N	PRESENT	0
331740	321351	08051V	PARTICIPANT	\N	PRESENT	0
331741	321351	14327T	PARTICIPANT	\N	PRESENT	0
331742	321351	19479G	PARTICIPANT	\N	PRESENT	0
331743	321351	14069U	PARTICIPANT	\N	PRESENT	0
331744	321351	17637T	PARTICIPANT	\N	PRESENT	0
331745	321351	08069G	PARTICIPANT	\N	PRESENT	0
331746	321351	14257W	PARTICIPANT	\N	PRESENT	0
331747	329069	04086Q	PARTICIPANT	\N	PRESENT	0
331748	329069	14327T	PARTICIPANT	\N	PRESENT	0
331749	329069	07029T	PARTICIPANT	\N	PRESENT	0
331750	329069	11048N	PRESIDENT	0	PRESENT	0
331751	329069	19711U	PARTICIPANT	\N	PRESENT	0
331752	329069	08034U	PARTICIPANT	\N	PRESENT	0
331753	329069	07004J	PARTICIPANT	\N	PRESENT	0
331754	329069	19545Y	PARTICIPANT	\N	PRESENT	0
331755	329069	01057W	PARTICIPANT	\N	PRESENT	0
331756	329069	19741B	PARTICIPANT	\N	PRESENT	0
331757	329069	14159V	PARTICIPANT	\N	PRESENT	0
331758	321352	11072N	PARTICIPANT	\N	PRESENT	0
331759	321352	19295A	PARTICIPANT	\N	PRESENT	0
331760	321352	04049K	PARTICIPANT	\N	PRESENT	0
331761	321352	14265W	PARTICIPANT	\N	PRESENT	0
331762	329069	08011M	PARTICIPANT	\N	PRESENT	0
331763	329069	11110B	PARTICIPANT	\N	PRESENT	0
331764	329069	14085U	PARTICIPANT	\N	EXCUSE	0
331765	329069	11074Q	PARTICIPANT	\N	EXCUSE	0
331766	321352	19651A	PARTICIPANT	\N	PRESENT	0
331767	321352	19631V	PARTICIPANT	\N	PRESENT	0
331768	321352	14257W	PARTICIPANT	\N	PRESENT	0
331769	321352	01043Q	PARTICIPANT	\N	PRESENT	0
331770	321352	11110B	PARTICIPANT	\N	PRESENT	0
331771	321352	08068F	PARTICIPANT	\N	PRESENT	0
331772	321352	01057W	PARTICIPANT	\N	PRESENT	0
331773	321352	08034U	PARTICIPANT	\N	PRESENT	0
331774	321352	19711U	PARTICIPANT	\N	PRESENT	0
331775	321352	04086Q	PARTICIPANT	\N	PRESENT	0
331776	321352	14205J	PARTICIPANT	\N	PRESENT	0
331777	321352	11048N	PARTICIPANT	\N	PRESENT	0
331778	321352	14159V	PARTICIPANT	\N	PRESENT	0
331779	321352	10015M	PARTICIPANT	\N	PRESENT	0
331780	321352	07004J	PARTICIPANT	\N	PRESENT	0
331781	321352	19695N	PARTICIPANT	\N	PRESENT	0
331782	321352	12016W	PARTICIPANT	\N	PRESENT	0
331783	321352	19545Y	PARTICIPANT	\N	PRESENT	0
331784	321352	19687N	PARTICIPANT	\N	PRESENT	0
331785	321352	19319Q	PARTICIPANT	\N	PRESENT	0
331786	321352	14038Y	PARTICIPANT	\N	PRESENT	0
331787	321352	19531S	PARTICIPANT	\N	PRESENT	0
331788	321352	14107H	PARTICIPANT	\N	PRESENT	0
331789	321352	19689Q	PARTICIPANT	\N	PRESENT	0
331790	321352	19741B	PARTICIPANT	\N	PRESENT	0
331791	321352	88008L	PARTICIPANT	\N	PRESENT	0
331792	321352	14034U	PARTICIPANT	\N	PRESENT	0
331793	321352	08015R	PARTICIPANT	\N	PRESENT	0
331794	321352	14081Q	PARTICIPANT	\N	PRESENT	0
331795	321352	14157T	PARTICIPANT	\N	PRESENT	0
331796	321352	14329V	PARTICIPANT	\N	PRESENT	0
331797	321352	11012A	PARTICIPANT	\N	PRESENT	0
331798	321352	01048V	PARTICIPANT	\N	PRESENT	0
331799	321352	11090Q	PARTICIPANT	\N	PRESENT	0
304967	304966	14053L	PARTICIPANT	\N	PRESENT	0
304968	304966	14065Q	PARTICIPANT	\N	PRESENT	0
304969	304966	19649G	PARTICIPANT	\N	PRESENT	0
304970	304966	08045X	PARTICIPANT	\N	PRESENT	0
304971	304966	11026G	PARTICIPANT	\N	PRESENT	0
304972	304966	19581D	PARTICIPANT	\N	PRESENT	0
304973	304966	04044E	PARTICIPANT	\N	PRESENT	0
304974	304966	04047H	PARTICIPANT	\N	PRESENT	0
304975	304966	05008E	PRESIDENT	0	PRESENT	0
304976	304966	95063L	PARTICIPANT	\N	PRESENT	0
304977	304966	19629C	PARTICIPANT	\N	PRESENT	0
304978	304966	14041T	PARTICIPANT	\N	PRESENT	0
304979	304966	08044W	PARTICIPANT	\N	PRESENT	0
304980	304966	14147R	PARTICIPANT	\N	PRESENT	0
304981	304966	14215L	PARTICIPANT	\N	PRESENT	0
304983	304966	98035U	PARTICIPANT	\N	PRESENT	0
304984	304966	01024M	PARTICIPANT	\N	PRESENT	0
304985	304966	01028R	PARTICIPANT	\N	PRESENT	0
304986	304966	14357A	PARTICIPANT	\N	PRESENT	0
304987	304966	19329S	PARTICIPANT	\N	PRESENT	0
304988	304966	04042C	PARTICIPANT	\N	PRESENT	0
304989	304966	14219Q	PARTICIPANT	\N	PRESENT	0
304990	304966	14281W	PARTICIPANT	\N	PRESENT	0
304991	304966	08017T	PARTICIPANT	\N	PRESENT	0
304992	304966	14179A	PARTICIPANT	\N	PRESENT	0
304993	304966	08010L	PARTICIPANT	\N	PRESENT	0
304994	304966	08024S	PARTICIPANT	\N	PRESENT	0
304995	304966	19563B	PARTICIPANT	\N	PRESENT	0
304996	304966	19593H	PARTICIPANT	\N	PRESENT	0
304997	304966	14033T	PARTICIPANT	\N	PRESENT	0
304998	304966	04085P	PARTICIPANT	\N	PRESENT	0
304999	304966	14089Y	PARTICIPANT	\N	PRESENT	0
305000	304966	14115H	PARTICIPANT	\N	PRESENT	0
305001	304966	04061F	PARTICIPANT	\N	PRESENT	0
305002	304966	14257W	PARTICIPANT	\N	PRESENT	0
305003	304966	19729F	PARTICIPANT	\N	EXCUSE	0
305004	304966	19719D	PARTICIPANT	\N	EXCUSE	0
305005	304966	19671E	PARTICIPANT	\N	PRESENT	0
305006	304966	08061X	PARTICIPANT	\N	PRESENT	0
305007	304966	14259Y	PARTICIPANT	\N	PRESENT	0
305008	304966	19713W	PARTICIPANT	\N	PRESENT	0
305009	304966	19749K	PARTICIPANT	\N	PRESENT	0
305013	304966	11027H	PARTICIPANT	\N	PRESENT	0
305014	304966	19447X	PARTICIPANT	\N	PRESENT	0
305015	304966	19489J	PARTICIPANT	\N	PRESENT	0
305016	304966	14028W	PARTICIPANT	\N	PRESENT	0
305017	289221	11077T	PARTICIPANT	\N	PRESENT	0
305018	289221	11066Q	PARTICIPANT	\N	PRESENT	0
305019	289221	08024S	PARTICIPANT	\N	PRESENT	0
305082	289221	14041T	PARTICIPANT	\N	PRESENT	0
305083	289221	14033T	PARTICIPANT	\N	PRESENT	0
305081	289221	04044E	PARTICIPANT	\N	PRESENT	0
305084	289221	95015C	PARTICIPANT	\N	PRESENT	0
305024	289221	80013X	PARTICIPANT	\N	PRESENT	0
305025	289221	14331P	PARTICIPANT	\N	PRESENT	0
305085	289221	14219Q	PARTICIPANT	\N	PRESENT	0
305086	289221	14205J	PARTICIPANT	\N	PRESENT	0
305028	289221	19727D	PARTICIPANT	\N	PRESENT	0
305029	289221	19563B	PARTICIPANT	\N	PRESENT	0
305087	289221	14267Y	PARTICIPANT	\N	PRESENT	0
305088	289221	14103D	PARTICIPANT	\N	PRESENT	0
305032	289221	14257W	PARTICIPANT	\N	PRESENT	0
305089	289221	14031R	PARTICIPANT	\N	PRESENT	0
305090	289221	14265W	PARTICIPANT	\N	PRESENT	0
305091	289221	14357A	PARTICIPANT	\N	PRESENT	0
305043	304982	14053L	PARTICIPANT	\N	PRESENT	0
305044	304982	98035U	PARTICIPANT	\N	PRESENT	0
305045	304982	14065Q	PARTICIPANT	\N	PRESENT	0
305046	304982	11026G	PARTICIPANT	\N	PRESENT	0
305047	304982	19581D	PARTICIPANT	\N	PRESENT	0
305048	304982	04044E	PARTICIPANT	\N	PRESENT	0
305049	304982	04047H	PARTICIPANT	\N	PRESENT	0
305050	304982	01028R	PARTICIPANT	\N	PRESENT	0
305051	304982	05008E	PRESIDENT	0	PRESENT	0
305052	304982	19447X	PARTICIPANT	\N	PRESENT	0
305053	304982	14089Y	PARTICIPANT	\N	PRESENT	0
305054	304982	19489J	PARTICIPANT	\N	PRESENT	0
305055	304982	95063L	PARTICIPANT	\N	PRESENT	0
305056	304982	19629C	PARTICIPANT	\N	PRESENT	0
305057	304982	14041T	PARTICIPANT	\N	PRESENT	0
305058	304982	14147R	PARTICIPANT	\N	PRESENT	0
305059	304982	14179A	PARTICIPANT	\N	PRESENT	0
305060	304982	14215L	PARTICIPANT	\N	PRESENT	0
305061	304982	14259Y	PARTICIPANT	\N	PRESENT	0
305073	289221	14195A	PARTICIPANT	\N	PRESENT	0
305074	304982	01024M	PARTICIPANT	\N	PRESENT	0
305092	289221	08015R	PARTICIPANT	\N	PRESENT	0
305080	289221	19695N	PARTICIPANT	\N	PRESENT	0
305093	289221	01057W	PARTICIPANT	\N	PRESENT	0
305094	289221	01028R	PARTICIPANT	\N	PRESENT	0
305095	289221	08010L	PARTICIPANT	\N	PRESENT	0
305096	289221	19713W	PARTICIPANT	\N	PRESENT	0
305097	289221	19647E	PARTICIPANT	\N	PRESENT	0
305098	289221	14115H	PARTICIPANT	\N	PRESENT	0
305099	289221	14179A	PARTICIPANT	\N	PRESENT	0
305100	289221	98035U	PARTICIPANT	\N	PRESENT	0
305101	289221	14061L	PARTICIPANT	\N	PRESENT	0
306018	306017	99004R	PRESIDENT	0	PRESENT	0
306019	306017	11056N	PARTICIPANT	\N	EXCUSE	0
306059	306058	19551W	PARTICIPANT	\N	PRESENT	0
306060	306058	19737F	PARTICIPANT	\N	PRESENT	0
306857	305925	14111D	PARTICIPANT	\N	PRESENT	0
306858	305925	11080N	PARTICIPANT	\N	PRESENT	0
306859	305925	14031R	PARTICIPANT	\N	PRESENT	0
305111	289222	04044E	PARTICIPANT	\N	PRESENT	0
306016	305886	11056N	PARTICIPANT	\N	EXCUSE	0
306860	305925	07034Q	PARTICIPANT	\N	PRESENT	0
306861	305925	19253P	PARTICIPANT	\N	PRESENT	0
306862	305925	19581D	PARTICIPANT	\N	PRESENT	0
306863	305925	19585H	PARTICIPANT	\N	PRESENT	0
306864	305925	19719D	PARTICIPANT	\N	PRESENT	0
306865	305925	01028R	PARTICIPANT	\N	PRESENT	0
306866	305925	11033F	PARTICIPANT	\N	PRESENT	0
306867	305925	19447X	PARTICIPANT	\N	PRESENT	0
306868	305925	05008E	PRESIDENT	0	PRESENT	0
306869	305925	14237S	PARTICIPANT	\N	PRESENT	0
306870	305925	19729F	PARTICIPANT	\N	PRESENT	0
306871	305925	19629C	PARTICIPANT	\N	PRESENT	0
306872	305925	14147R	PARTICIPANT	\N	PRESENT	0
306873	305925	14179A	PARTICIPANT	\N	PRESENT	0
306874	305925	08010L	PARTICIPANT	\N	PRESENT	0
306875	305925	14069U	PARTICIPANT	\N	PRESENT	0
306876	305925	14151M	PARTICIPANT	\N	PRESENT	0
306877	305925	14215L	PARTICIPANT	\N	PRESENT	0
306878	305925	11049P	PARTICIPANT	\N	PRESENT	0
306879	305925	14259Y	PARTICIPANT	\N	PRESENT	0
306880	305925	19762G	PARTICIPANT	\N	PRESENT	0
306881	305925	14065Q	PARTICIPANT	\N	EXCUSE	0
306882	305925	08045X	PARTICIPANT	\N	EXCUSE	0
306883	306070	19766L	PARTICIPANT	\N	PRESENT	0
306884	306070	04070G	PARTICIPANT	\N	PRESENT	0
306885	306070	19699S	PARTICIPANT	\N	PRESENT	0
306886	306070	19533U	PARTICIPANT	\N	PRESENT	0
306887	306070	04033B	PARTICIPANT	\N	PRESENT	0
306888	306070	14229S	PARTICIPANT	\N	PRESENT	0
306889	306070	19573D	PARTICIPANT	\N	PRESENT	0
306890	306070	14039A	PARTICIPANT	\N	PRESENT	0
306891	306070	14107H	PARTICIPANT	\N	PRESENT	0
306892	306070	08017T	PARTICIPANT	\N	PRESENT	0
306893	306070	08012N	PARTICIPANT	\N	PRESENT	0
306894	306070	08039A	PARTICIPANT	\N	PRESENT	0
306895	306070	08031R	PARTICIPANT	\N	PRESENT	0
306896	306070	19593H	PARTICIPANT	\N	PRESENT	0
306897	306070	19643A	PARTICIPANT	\N	PRESENT	0
306898	306070	14073Q	PARTICIPANT	\N	PRESENT	0
306899	306070	08043V	PARTICIPANT	\N	PRESENT	0
306900	306070	19693L	PARTICIPANT	\N	PRESENT	0
306901	306070	87003B	PARTICIPANT	\N	PRESENT	0
306902	306070	19399H	PARTICIPANT	\N	PRESENT	0
306903	306070	19731Y	PARTICIPANT	\N	PRESENT	0
306904	306070	14251Q	PARTICIPANT	\N	PRESENT	0
306905	306070	04059M	PARTICIPANT	\N	PRESENT	0
306906	306070	14063N	PARTICIPANT	\N	PRESENT	0
306907	306070	11083R	PARTICIPANT	\N	PRESENT	0
306908	306070	11104D	PARTICIPANT	\N	PRESENT	0
306909	306070	11043H	PARTICIPANT	\N	PRESENT	0
306910	306070	19749K	PARTICIPANT	\N	PRESENT	0
306911	306070	04018C	PARTICIPANT	\N	PRESENT	0
306912	306070	19758L	PARTICIPANT	\N	PRESENT	0
306913	306070	19621T	PARTICIPANT	\N	PRESENT	0
309164	309163	95067Q	PARTICIPANT	\N	PRESENT	0
309165	309163	14028W	PARTICIPANT	\N	PRESENT	0
309167	309166	11041F	PARTICIPANT	\N	PRESENT	0
309168	309166	98018T	PARTICIPANT	\N	PRESENT	0
309170	309169	11041F	PARTICIPANT	\N	PRESENT	0
309171	309169	98018T	PARTICIPANT	\N	PRESENT	0
309181	305886	19551W	PARTICIPANT	\N	EXCUSE	0
309182	305886	08062Y	PARTICIPANT	\N	PRESENT	0
309234	305886	04038G	PARTICIPANT	\N	EXCUSE	0
328871	321340	14073Q	PARTICIPANT	\N	PRESENT	0
328872	321340	14021P	PARTICIPANT	\N	PRESENT	0
328873	321340	14071N	PARTICIPANT	\N	PRESENT	0
328874	321340	19503N	PARTICIPANT	\N	PRESENT	0
328940	321341	11074Q	PARTICIPANT	\N	PRESENT	0
328941	321341	99004R	PARTICIPANT	\N	PRESENT	0
328945	321341	19503N	PARTICIPANT	\N	PRESENT	0
328943	321341	11040E	PARTICIPANT	\N	PRESENT	0
328944	321341	19683J	PARTICIPANT	\N	PRESENT	0
328946	321341	19549D	PARTICIPANT	\N	PRESENT	0
328947	321341	14225N	PARTICIPANT	\N	PRESENT	0
328948	321341	04045F	PARTICIPANT	\N	PRESENT	0
328949	321341	19545Y	PARTICIPANT	\N	PRESENT	0
328950	321341	04086Q	PARTICIPANT	\N	PRESENT	0
328951	321341	95037J	PARTICIPANT	\N	PRESENT	0
328952	321341	19711U	PARTICIPANT	\N	PRESENT	0
328953	321341	08051V	PARTICIPANT	\N	PRESENT	0
328954	321341	11012A	PARTICIPANT	\N	PRESENT	0
328955	321341	11053K	PARTICIPANT	\N	PRESENT	0
328956	321341	11048N	PARTICIPANT	\N	PRESENT	0
328957	321341	14327T	PARTICIPANT	\N	PRESENT	0
328958	321341	14259Y	PARTICIPANT	\N	PRESENT	0
328959	321341	07004J	PARTICIPANT	\N	PRESENT	0
328960	321341	19647E	PARTICIPANT	\N	PRESENT	0
328961	321341	12016W	PARTICIPANT	\N	PRESENT	0
328962	321341	19347U	PARTICIPANT	\N	PRESENT	0
328963	321341	01057W	PARTICIPANT	\N	PRESENT	0
328964	321341	01048V	PARTICIPANT	\N	PRESENT	0
328965	321341	19719D	PARTICIPANT	\N	PRESENT	0
328966	321341	19687N	PARTICIPANT	\N	PRESENT	0
328967	321341	08034U	PARTICIPANT	\N	PRESENT	0
328968	321341	11110B	PARTICIPANT	\N	PRESENT	0
328969	321341	19747H	PARTICIPANT	\N	PRESENT	0
328970	321341	11090Q	PARTICIPANT	\N	PRESENT	0
328971	321341	11065P	PARTICIPANT	\N	PRESENT	0
328972	321341	14357A	PARTICIPANT	\N	PRESENT	0
328973	321341	19739H	PARTICIPANT	\N	PRESENT	0
328974	321341	14021P	PARTICIPANT	\N	PRESENT	0
328975	321341	19651A	PARTICIPANT	\N	PRESENT	0
328976	321341	08062Y	PARTICIPANT	\N	PRESENT	0
328977	321341	07029T	PARTICIPANT	\N	PRESENT	0
328978	321341	14033T	PARTICIPANT	\N	PRESENT	0
328979	321341	19693L	PARTICIPANT	\N	PRESENT	0
328980	321341	14199E	PARTICIPANT	\N	PRESENT	0
328981	321341	14187A	PARTICIPANT	\N	PRESENT	0
328982	321341	14071N	PARTICIPANT	\N	PRESENT	0
328983	321341	95041E	PARTICIPANT	\N	PRESENT	0
328984	321341	14265W	PARTICIPANT	\N	PRESENT	0
328985	321341	19575F	PARTICIPANT	\N	PRESENT	0
328986	321341	19447X	PARTICIPANT	\N	PRESENT	0
328987	321341	14085U	PARTICIPANT	\N	PRESENT	0
328988	321341	08068F	PARTICIPANT	\N	PRESENT	0
328989	321341	14111D	PARTICIPANT	\N	PRESENT	0
328990	321341	08019V	PARTICIPANT	\N	PRESENT	0
328991	321341	04033B	PARTICIPANT	\N	PRESENT	0
328992	321341	19563B	PARTICIPANT	\N	PRESENT	0
328993	321341	08010L	PARTICIPANT	\N	PRESENT	0
328994	321341	80013X	PARTICIPANT	\N	PRESENT	0
328995	321341	19689Q	PARTICIPANT	\N	PRESENT	0
328996	321341	19701S	PARTICIPANT	\N	PRESENT	0
328997	321341	04040A	PARTICIPANT	\N	PRESENT	0
328998	321341	08043V	PARTICIPANT	\N	PRESENT	0
328999	321341	14107H	PARTICIPANT	\N	PRESENT	0
329000	321341	14249W	PARTICIPANT	\N	PRESENT	0
329001	321341	16685X	PARTICIPANT	\N	PRESENT	0
329002	321341	14073Q	PARTICIPANT	\N	PRESENT	0
329003	321341	14083S	PARTICIPANT	\N	PRESENT	0
328938	321341	04044E	PARTICIPANT	\N	PRESENT	0
328939	321341	08011M	PARTICIPANT	\N	PRESENT	0
329004	321341	08069G	PARTICIPANT	\N	PRESENT	0
329005	321341	14219Q	PARTICIPANT	\N	PRESENT	0
329006	321341	19369B	PARTICIPANT	\N	PRESENT	0
329007	321341	14031R	PARTICIPANT	\N	PRESENT	0
329008	321341	14261S	PARTICIPANT	\N	PRESENT	0
329009	321341	14030Q	PARTICIPANT	\N	PRESENT	0
329010	321341	19741B	PARTICIPANT	\N	PRESENT	0
329011	321341	14255U	PARTICIPANT	\N	PRESENT	0
329012	321341	19349W	PARTICIPANT	\N	PRESENT	0
329084	329083	04085P	PARTICIPANT	\N	PRESENT	0
329085	329083	04059M	PARTICIPANT	\N	PRESENT	0
329087	329083	19651A	PARTICIPANT	\N	PRESENT	0
329088	329083	05008E	PARTICIPANT	\N	PRESENT	0
329089	329083	19545Y	PARTICIPANT	\N	PRESENT	0
329090	329083	11027H	PARTICIPANT	\N	PRESENT	0
329091	329083	04086Q	PARTICIPANT	\N	PRESENT	0
329092	329083	11070L	PARTICIPANT	\N	PRESENT	0
329093	329083	14041T	PARTICIPANT	\N	PRESENT	0
329094	329083	07033P	PARTICIPANT	\N	PRESENT	0
329095	329083	11074Q	PARTICIPANT	\N	PRESENT	0
329096	329083	14159V	PARTICIPANT	\N	PRESENT	0
329097	329083	01043Q	PARTICIPANT	\N	PRESENT	0
329098	329083	11085T	PARTICIPANT	\N	PRESENT	0
329099	329083	08011M	PARTICIPANT	\N	PRESENT	0
329100	329083	11090Q	PARTICIPANT	\N	PRESENT	0
329101	329083	14225N	PARTICIPANT	\N	PRESENT	0
329102	329083	11012A	PARTICIPANT	\N	PRESENT	0
329103	329083	14157T	PARTICIPANT	\N	PRESENT	0
329206	326991	11033F	PARTICIPANT	\N	PRESENT	0
329207	326991	10006L	PRESIDENT	0	PRESENT	0
329208	326991	11083R	PARTICIPANT	\N	PRESENT	0
329209	326991	19649G	PARTICIPANT	\N	PRESENT	0
329210	326991	08031R	PARTICIPANT	\N	PRESENT	0
329211	326991	14147R	PARTICIPANT	\N	PRESENT	0
329212	326991	11067R	PARTICIPANT	\N	PRESENT	0
329213	326991	19533U	PARTICIPANT	\N	PRESENT	0
329214	326991	19749K	PARTICIPANT	\N	PRESENT	0
329327	329326	04070G	PARTICIPANT	\N	PRESENT	0
330975	321347	14199E	PARTICIPANT	\N	PRESENT	0
330976	321347	08061X	PARTICIPANT	\N	PRESENT	0
330977	321347	11072N	PARTICIPANT	\N	PRESENT	0
330978	321347	19713W	PARTICIPANT	\N	PRESENT	0
330979	321347	08014Q	PARTICIPANT	\N	PRESENT	0
330980	321347	17637T	PARTICIPANT	\N	PRESENT	0
330981	321347	19737F	PARTICIPANT	\N	PRESENT	0
330982	321347	07033P	PARTICIPANT	\N	PRESENT	0
330985	321347	19553Y	PARTICIPANT	\N	PRESENT	0
330986	321347	14107H	PARTICIPANT	\N	PRESENT	0
330987	321347	11064N	PARTICIPANT	\N	PRESENT	0
330992	321347	14255U	PARTICIPANT	\N	PRESENT	0
330993	321347	19719D	PARTICIPANT	\N	PRESENT	0
330994	321347	14159V	PARTICIPANT	\N	PRESENT	0
330995	321347	19693L	PARTICIPANT	\N	PRESENT	0
330996	321347	19723Y	PARTICIPANT	\N	PRESENT	0
330997	321347	19447X	PARTICIPANT	\N	PRESENT	0
330998	321347	19673G	PARTICIPANT	\N	PRESENT	0
330999	321347	01034P	PARTICIPANT	\N	PRESENT	0
331000	321347	19515S	PARTICIPANT	\N	PRESENT	0
331007	321347	14079W	PARTICIPANT	\N	PRESENT	0
331008	321347	14213J	PARTICIPANT	\N	PRESENT	0
331009	321347	04045F	PARTICIPANT	\N	PRESENT	0
331010	321347	14042U	PARTICIPANT	\N	PRESENT	0
331011	321347	14281W	PARTICIPANT	\N	PRESENT	0
331013	321347	19521Q	PARTICIPANT	\N	PRESENT	0
331016	321347	14133K	PARTICIPANT	\N	PRESENT	0
331027	321347	11033F	PARTICIPANT	\N	PRESENT	0
331036	321347	19747H	PARTICIPANT	\N	PRESENT	0
331039	321347	08031R	PARTICIPANT	\N	PRESENT	0
331040	321347	14357A	PARTICIPANT	\N	PRESENT	0
331041	321347	14327T	PARTICIPANT	\N	PRESENT	0
331042	321347	01058X	PARTICIPANT	\N	PRESENT	0
331043	321347	11056N	PARTICIPANT	\N	PRESENT	0
331044	321347	11077T	PARTICIPANT	\N	PRESENT	0
331045	321347	19637C	PARTICIPANT	\N	PRESENT	0
331046	321347	19735D	PARTICIPANT	\N	PRESENT	0
306008	305883	05012A	PARTICIPANT	\N	PRESENT	0
311976	309270	19697Q	PARTICIPANT	\N	PRESENT	0
311977	309270	19533U	PARTICIPANT	\N	PRESENT	0
311978	311789	19768N	PARTICIPANT	\N	PRESENT	0
311979	311789	19467C	PARTICIPANT	\N	PRESENT	0
311980	311789	19515S	PARTICIPANT	\N	PRESENT	0
311981	311789	01043Q	PARTICIPANT	\N	PRESENT	0
311982	311789	14187A	PARTICIPANT	\N	PRESENT	0
311983	311789	08038Y	PARTICIPANT	\N	PRESENT	0
311984	311789	19441R	PARTICIPANT	\N	PRESENT	0
311985	311789	14081Q	PARTICIPANT	\N	PRESENT	0
311986	311789	08062Y	PARTICIPANT	\N	PRESENT	0
311987	311789	14033T	PARTICIPANT	\N	PRESENT	0
311988	311789	01025N	PARTICIPANT	\N	PRESENT	0
311989	311789	11090Q	PRESIDENT	0	PRESENT	0
311990	311789	04088S	PARTICIPANT	\N	PRESENT	0
311991	311789	08068F	PARTICIPANT	\N	PRESENT	0
311992	311789	04089T	PARTICIPANT	\N	PRESENT	0
311993	311789	19705W	PARTICIPANT	\N	PRESENT	0
311994	311789	14197C	PARTICIPANT	\N	PRESENT	0
311995	311789	19747H	PARTICIPANT	\N	PRESENT	0
311996	311789	14207L	PARTICIPANT	\N	PRESENT	0
311997	311789	04043D	PARTICIPANT	\N	PRESENT	0
311998	311789	08028W	PARTICIPANT	\N	PRESENT	0
311999	311789	14265W	PARTICIPANT	\N	PRESENT	0
312000	311789	14257W	PARTICIPANT	\N	PRESENT	0
312001	311789	11081P	PARTICIPANT	\N	EXCUSE	0
312002	309270	17637T	PARTICIPANT	\N	PRESENT	0
312003	309270	17589D	PARTICIPANT	\N	PRESENT	0
312004	309270	19549D	PARTICIPANT	\N	PRESENT	0
312005	309270	99004R	PARTICIPANT	\N	PRESENT	0
312006	309270	14059S	PARTICIPANT	\N	PRESENT	0
312007	309270	19741B	PARTICIPANT	\N	PRESENT	0
312008	309270	08069G	PARTICIPANT	\N	PRESENT	0
312009	309270	19715Y	PARTICIPANT	\N	PRESENT	0
312010	309270	08010L	PARTICIPANT	\N	PRESENT	0
312011	309270	14028W	PARTICIPANT	\N	PRESENT	0
312012	309270	05012A	PARTICIPANT	\N	PRESENT	0
312013	309270	11103C	PARTICIPANT	\N	PRESENT	0
312014	309270	97011G	PARTICIPANT	\N	PRESENT	0
312015	309270	95030B	PARTICIPANT	\N	PRESENT	0
312016	309270	08009T	PARTICIPANT	\N	PRESENT	0
312017	309270	14105F	PARTICIPANT	\N	PRESENT	0
312018	309270	14069U	PARTICIPANT	\N	PRESENT	0
312019	309270	19725B	PARTICIPANT	\N	PRESENT	0
312020	309270	14237S	PARTICIPANT	\N	PRESENT	0
312021	309270	19719D	PARTICIPANT	\N	PRESENT	0
312022	309270	19733B	PARTICIPANT	\N	PRESENT	0
312023	311612	11040E	PARTICIPANT	\N	PRESENT	0
312024	309270	19569H	PARTICIPANT	\N	PRESENT	0
312025	309270	04043D	PARTICIPANT	\N	PRESENT	0
312026	309270	14133K	PARTICIPANT	\N	PRESENT	0
312027	309270	11026G	PARTICIPANT	\N	PRESENT	0
312028	309270	14193X	PARTICIPANT	\N	PRESENT	0
312029	309270	19739H	PARTICIPANT	\N	PRESENT	0
312030	309270	14103D	PARTICIPANT	\N	PRESENT	0
312031	309270	08053X	PARTICIPANT	\N	PRESENT	0
312032	309270	19503N	PARTICIPANT	\N	PRESENT	0
312033	309270	19681G	PARTICIPANT	\N	PRESENT	0
312034	309270	14107H	PARTICIPANT	\N	PRESENT	0
312035	309270	14121F	PARTICIPANT	\N	PRESENT	0
312036	311612	98035U	PARTICIPANT	\N	PRESENT	0
312037	309270	19691J	PARTICIPANT	\N	PRESENT	0
312042	309270	19479G	PARTICIPANT	\N	PRESENT	0
312043	309270	14215L	PARTICIPANT	\N	PRESENT	0
312044	309270	14235Q	PARTICIPANT	\N	PRESENT	0
312045	309270	14275Y	PARTICIPANT	\N	PRESENT	0
312046	309270	80013X	PARTICIPANT	\N	PRESENT	0
312047	309270	08024S	PARTICIPANT	\N	PRESENT	0
312051	309270	14021P	PARTICIPANT	\N	PRESENT	0
312052	309270	14063N	PARTICIPANT	\N	PRESENT	0
312054	309270	19729F	PARTICIPANT	\N	PRESENT	0
312055	309270	07029T	PARTICIPANT	\N	PRESENT	0
312056	309270	19581D	PARTICIPANT	\N	PRESENT	0
312057	309270	08031R	PARTICIPANT	\N	PRESENT	0
312058	309270	04047H	PARTICIPANT	\N	PRESENT	0
312059	309270	19593H	PARTICIPANT	\N	PRESENT	0
312060	309270	19713W	PARTICIPANT	\N	PRESENT	0
312240	309271	86034E	PARTICIPANT	\N	PRESENT	0
312242	309271	19737F	PARTICIPANT	\N	PRESENT	0
312243	309271	08039A	PARTICIPANT	\N	PRESENT	0
312244	309271	19347U	PARTICIPANT	\N	PRESENT	0
312245	309271	08069G	PARTICIPANT	\N	PRESENT	0
312246	309271	19503N	PARTICIPANT	\N	PRESENT	0
312248	309271	08053X	PARTICIPANT	\N	PRESENT	0
312249	309271	08020N	PARTICIPANT	\N	PRESENT	0
312250	309271	17637T	PARTICIPANT	\N	PRESENT	0
312251	309271	19447X	PARTICIPANT	\N	PRESENT	0
312252	309271	95062K	PARTICIPANT	\N	PRESENT	0
312253	309271	08028W	PARTICIPANT	\N	PRESENT	0
312254	309271	95030B	PARTICIPANT	\N	PRESENT	0
312255	309271	95041E	PARTICIPANT	\N	PRESENT	0
316403	313440	19697Q	PARTICIPANT	\N	EXCUSE	0
316404	313440	14087W	PARTICIPANT	\N	EXCUSE	0
316405	313440	14355X	PARTICIPANT	\N	EXCUSE	0
316406	313440	11067R	PARTICIPANT	\N	EXCUSE	0
316407	313440	19703U	PARTICIPANT	\N	EXCUSE	0
316408	313440	14195A	PARTICIPANT	\N	EXCUSE	0
316409	313440	08041T	PARTICIPANT	\N	EXCUSE	0
316423	313440	14281W	PARTICIPANT	\N	PRESENT	0
316424	313440	98024R	PARTICIPANT	\N	PRESENT	0
316425	313440	14042U	PARTICIPANT	\N	PRESENT	0
316426	313440	11097X	PARTICIPANT	\N	PRESENT	0
316427	313440	14119M	PARTICIPANT	\N	PRESENT	0
316428	313440	04092N	PRESIDENT	0	PRESENT	0
316429	313440	11103C	PARTICIPANT	\N	PRESENT	0
316430	313440	11031D	PARTICIPANT	\N	PRESENT	0
316436	313440	11045K	PARTICIPANT	\N	PRESENT	0
316460	313440	14223L	PARTICIPANT	\N	PRESENT	0
316461	313440	19415P	PARTICIPANT	\N	PRESENT	0
316462	313440	14217N	PARTICIPANT	\N	PRESENT	0
319881	314090	19593H	PARTICIPANT	\N	PRESENT	0
319882	314090	14235Q	PARTICIPANT	\N	PRESENT	0
319883	314090	19758L	PARTICIPANT	\N	PRESENT	0
319884	314090	14207L	PARTICIPANT	\N	PRESENT	0
319885	314090	14079W	PARTICIPANT	\N	PRESENT	0
319886	314090	19735D	PARTICIPANT	\N	PRESENT	0
319887	314090	14030Q	PARTICIPANT	\N	PRESENT	0
319888	314090	14229S	PARTICIPANT	\N	PRESENT	0
319889	314090	19467C	PARTICIPANT	\N	PRESENT	0
319890	314090	19701S	PARTICIPANT	\N	PRESENT	0
319891	314090	14329V	PARTICIPANT	\N	PRESENT	0
319892	314090	11054L	PARTICIPANT	\N	PRESENT	0
319893	314090	01062T	PARTICIPANT	\N	PRESENT	0
319894	314090	10006L	PARTICIPANT	\N	PRESENT	0
319895	314090	11056N	PARTICIPANT	\N	PRESENT	0
319896	314090	11067R	PARTICIPANT	\N	PRESENT	0
319897	314090	14071N	PARTICIPANT	\N	PRESENT	0
319898	314090	19737F	PARTICIPANT	\N	PRESENT	0
319899	314090	19747H	PARTICIPANT	\N	PRESENT	0
319900	314090	14073Q	PARTICIPANT	\N	PRESENT	0
319901	314090	19741B	PARTICIPANT	\N	PRESENT	0
319902	314090	19515S	PARTICIPANT	\N	PRESENT	0
319903	314090	11070L	PARTICIPANT	\N	PRESENT	0
319904	314090	19719D	PARTICIPANT	\N	PRESENT	0
319905	314090	14157T	PARTICIPANT	\N	PRESENT	0
319907	314090	08069G	PARTICIPANT	\N	PRESENT	0
319908	314090	14327T	PARTICIPANT	\N	PRESENT	0
319909	314090	19335Q	PARTICIPANT	\N	PRESENT	0
319910	314090	19551W	PARTICIPANT	\N	PRESENT	0
501095	500571	19826F	PARTICIPANT	\N	PRESENT	0
501096	500571	20022R	PARTICIPANT	\N	PRESENT	0
501097	500571	20024T	PARTICIPANT	\N	PRESENT	0
501105	500571	19251M	PARTICIPANT	\N	PRESENT	0
501106	500571	20102Q	PARTICIPANT	\N	PRESENT	0
501107	500571	17637T	PARTICIPANT	\N	PRESENT	0
501115	500571	20046A	PARTICIPANT	\N	PRESENT	0
501116	500571	17229F	PARTICIPANT	\N	PRESENT	0
501117	500571	19637C	PARTICIPANT	\N	PRESENT	0
501118	500571	14169X	PARTICIPANT	\N	PRESENT	0
501119	500571	14237S	PARTICIPANT	\N	PRESENT	0
501120	500571	20100N	PARTICIPANT	\N	PRESENT	0
501121	500571	08060W	PARTICIPANT	\N	PRESENT	0
501122	500571	11101A	PARTICIPANT	\N	PRESENT	0
501123	500571	19503N	PARTICIPANT	\N	PRESENT	0
501124	500571	19745F	PARTICIPANT	\N	PRESENT	0
501125	500571	11065P	PARTICIPANT	\N	PRESENT	0
501128	500571	14221J	PARTICIPANT	\N	PRESENT	0
501129	500571	19599P	PARTICIPANT	\N	PRESENT	0
501130	500571	20106U	PARTICIPANT	\N	PRESENT	0
501131	500571	20136B	PARTICIPANT	\N	PRESENT	0
501137	500241	14041T	PARTICIPANT	\N	PRESENT	0
501088	500571	19551W	PARTICIPANT	\N	PRESENT	0
501089	500571	20038A	PARTICIPANT	\N	PRESENT	0
501090	500571	14031R	PARTICIPANT	\N	PRESENT	0
501091	500571	19387D	PARTICIPANT	\N	PRESENT	0
501092	500571	20020P	PARTICIPANT	\N	PRESENT	0
501093	500571	19820Y	PARTICIPANT	\N	PRESENT	0
501094	500571	14219Q	PRESIDENT	0	PRESENT	0
330807	328688	19697Q	PARTICIPANT	\N	PRESENT	0
330808	328688	11067R	PARTICIPANT	\N	PRESENT	0
330809	328688	19649G	PARTICIPANT	\N	PRESENT	0
330810	328688	19533U	PARTICIPANT	\N	PRESENT	0
330811	328688	19415P	PARTICIPANT	\N	PRESENT	0
330812	328688	08043V	PARTICIPANT	\N	PRESENT	0
330813	328688	19585H	PARTICIPANT	\N	PRESENT	0
330814	328688	14223L	PARTICIPANT	\N	PRESENT	0
330815	328688	19673G	PARTICIPANT	\N	PRESENT	0
330816	328688	11033F	PARTICIPANT	\N	PRESENT	0
330817	328688	01028R	PARTICIPANT	\N	PRESENT	0
330818	328688	19723Y	PARTICIPANT	\N	PRESENT	0
330819	328688	14030Q	PARTICIPANT	\N	PRESENT	0
330820	328688	19447X	PARTICIPANT	\N	PRESENT	0
330821	328688	14147R	PARTICIPANT	\N	PRESENT	0
330822	328688	14213J	PARTICIPANT	\N	PRESENT	0
330823	328688	11043H	PARTICIPANT	\N	PRESENT	0
330824	328688	19749K	PARTICIPANT	\N	PRESENT	0
330825	328688	10006L	PRESIDENT	0	PRESENT	0
330826	328688	19621T	PARTICIPANT	\N	PRESENT	0
330827	328688	04047H	PARTICIPANT	\N	PRESENT	0
330831	321347	07004J	PARTICIPANT	\N	PRESENT	0
330832	321347	19319Q	PARTICIPANT	\N	PRESENT	0
330833	321347	19583F	PARTICIPANT	\N	PRESENT	0
330834	321347	19593H	PARTICIPANT	\N	PRESENT	0
330835	328688	11045K	PARTICIPANT	\N	PRESENT	0
330836	321347	19671E	PARTICIPANT	\N	PRESENT	0
330837	321347	80013X	PARTICIPANT	\N	PRESENT	0
330838	321347	19731Y	PARTICIPANT	\N	PRESENT	0
330839	321347	19611R	PARTICIPANT	\N	PRESENT	0
330840	321347	14085U	PARTICIPANT	\N	PRESENT	0
330841	321347	12016W	PARTICIPANT	\N	PRESENT	0
330842	321347	11040E	PARTICIPANT	\N	PRESENT	0
330843	321347	14235Q	PARTICIPANT	\N	PRESENT	0
330844	321347	19651A	PARTICIPANT	\N	PRESENT	0
330845	321347	19599P	PARTICIPANT	\N	PRESENT	0
330846	321347	14121F	PARTICIPANT	\N	PRESENT	0
330847	321347	08028W	PARTICIPANT	\N	PRESENT	0
330848	321347	18083K	PARTICIPANT	\N	PRESENT	0
330849	321347	19711U	PARTICIPANT	\N	PRESENT	0
330850	321347	19413M	PARTICIPANT	\N	PRESENT	0
330851	321347	11103C	PARTICIPANT	\N	PRESENT	0
330852	321347	14249W	PARTICIPANT	\N	PRESENT	0
330853	321347	11097X	PARTICIPANT	\N	PRESENT	0
330854	321347	19667J	PARTICIPANT	\N	PRESENT	0
330855	321347	11104D	PARTICIPANT	\N	PRESENT	0
330856	321347	01025N	PARTICIPANT	\N	PRESENT	0
330857	321347	14029X	PARTICIPANT	\N	PRESENT	0
330858	321347	19301E	PARTICIPANT	\N	PRESENT	0
330859	321347	19695N	PARTICIPANT	\N	PRESENT	0
330860	321347	04085P	PARTICIPANT	\N	PRESENT	0
330861	321347	19545Y	PARTICIPANT	\N	PRESENT	0
330862	321347	19631V	PARTICIPANT	\N	PRESENT	0
330863	321347	04018C	PARTICIPANT	\N	PRESENT	0
330864	321347	14187A	PARTICIPANT	\N	PRESENT	0
330865	321347	01048V	PARTICIPANT	\N	PRESENT	0
330866	321347	14173T	PARTICIPANT	\N	PRESENT	0
330867	321347	19581D	PARTICIPANT	\N	PRESENT	0
330805	321347	04086Q	PARTICIPANT	\N	PRESENT	0
330806	321347	08011M	PARTICIPANT	\N	PRESENT	0
330868	321347	19367Y	PARTICIPANT	\N	PRESENT	0
330869	321347	95067Q	PARTICIPANT	\N	PRESENT	0
330870	321347	14219Q	PARTICIPANT	\N	PRESENT	0
330871	321347	19399H	PARTICIPANT	\N	PRESENT	0
330872	321347	14026U	PARTICIPANT	\N	PRESENT	0
330873	321347	11074Q	PARTICIPANT	\N	PRESENT	0
330874	321347	19543W	PARTICIPANT	\N	PRESENT	0
330875	321347	11066Q	PARTICIPANT	\N	PRESENT	0
330876	321347	19760E	PARTICIPANT	\N	PRESENT	0
330877	321347	14253S	PARTICIPANT	\N	PRESENT	0
330878	321347	19575F	PARTICIPANT	\N	PRESENT	0
330879	321347	19643A	PARTICIPANT	\N	PRESENT	0
330880	321347	08019V	PARTICIPANT	\N	PRESENT	0
330881	321347	98050T	PARTICIPANT	\N	PRESENT	0
330882	321347	08034U	PARTICIPANT	\N	PRESENT	0
330883	321347	08069G	PARTICIPANT	\N	PRESENT	0
330884	321347	19703U	PARTICIPANT	\N	PRESENT	0
330885	321347	14169X	PARTICIPANT	\N	PRESENT	0
330886	321347	14089Y	PARTICIPANT	\N	PRESENT	0
330887	321347	14205J	PARTICIPANT	\N	PRESENT	0
330888	321347	14275Y	PARTICIPANT	\N	PRESENT	0
330889	321347	14329V	PARTICIPANT	\N	PRESENT	0
330890	321347	97011G	PARTICIPANT	\N	PRESENT	0
330891	321347	14265W	PARTICIPANT	\N	PRESENT	0
330892	321347	19768N	PARTICIPANT	\N	PRESENT	0
330893	321347	19573D	PARTICIPANT	\N	PRESENT	0
330894	321347	14211G	PARTICIPANT	\N	PRESENT	0
330895	321347	95041E	PARTICIPANT	\N	PRESENT	0
330896	321347	14217N	PARTICIPANT	\N	PRESENT	0
330897	321347	14331P	PARTICIPANT	\N	PRESENT	0
330898	321347	19782L	PARTICIPANT	\N	PRESENT	0
330899	321347	14123H	PARTICIPANT	\N	PRESENT	0
330900	321347	19443T	PARTICIPANT	\N	PRESENT	0
330901	321347	19663E	PARTICIPANT	\N	PRESENT	0
330902	321347	14115H	PARTICIPANT	\N	PRESENT	0
330903	321347	95063L	PARTICIPANT	\N	PRESENT	0
330904	321347	19369B	PARTICIPANT	\N	PRESENT	0
330905	321347	04059M	PARTICIPANT	\N	PRESENT	0
330906	321347	14071N	PARTICIPANT	\N	PRESENT	0
330907	321347	19467C	PARTICIPANT	\N	PRESENT	0
330908	321347	04088S	PARTICIPANT	\N	PRESENT	0
330909	321347	14033T	PARTICIPANT	\N	PRESENT	0
330910	321347	14021P	PARTICIPANT	\N	PRESENT	0
330911	321347	99004R	PARTICIPANT	\N	PRESENT	0
330912	321347	08010L	PARTICIPANT	\N	PRESENT	0
330913	321347	19507S	PARTICIPANT	\N	PRESENT	0
330914	321347	19647E	PARTICIPANT	\N	PRESENT	0
330915	321347	14069U	PARTICIPANT	\N	PRESENT	0
330916	321347	08044W	PARTICIPANT	\N	PRESENT	0
330917	321347	08038Y	PARTICIPANT	\N	PRESENT	0
330918	321347	95037J	PARTICIPANT	\N	PRESENT	0
330919	321347	14259Y	PARTICIPANT	\N	PRESENT	0
330920	321347	14257W	PARTICIPANT	\N	PRESENT	0
330921	321347	08015R	PARTICIPANT	\N	PRESENT	0
330922	321347	19333N	PARTICIPANT	\N	PRESENT	0
330923	321347	19549D	PARTICIPANT	\N	PRESENT	0
330925	321347	19689Q	PARTICIPANT	\N	PRESENT	0
330926	321347	14207L	PARTICIPANT	\N	PRESENT	0
330927	321347	14001X	PARTICIPANT	\N	PRESENT	0
330928	321347	19489J	PARTICIPANT	\N	PRESENT	0
330929	321347	08020N	PARTICIPANT	\N	PRESENT	0
330930	321347	19335Q	PARTICIPANT	\N	PRESENT	0
330931	321347	14223L	PARTICIPANT	\N	PRESENT	0
330932	321347	19691J	PARTICIPANT	\N	PRESENT	0
330933	321347	14034U	PARTICIPANT	\N	PRESENT	0
330934	321347	11070L	PARTICIPANT	\N	PRESENT	0
330935	321347	14073Q	PARTICIPANT	\N	PRESENT	0
330936	321347	14051J	PARTICIPANT	\N	PRESENT	0
330937	321347	08017T	PARTICIPANT	\N	PRESENT	0
330938	321347	95030B	PARTICIPANT	\N	PRESENT	0
330939	321347	14061L	PARTICIPANT	\N	PRESENT	0
330940	321347	08062Y	PARTICIPANT	\N	PRESENT	0
330941	321347	89017R	PARTICIPANT	\N	PRESENT	0
330942	321347	19701S	PARTICIPANT	\N	PRESENT	0
330943	321347	14267Y	PARTICIPANT	\N	PRESENT	0
330944	321347	14229S	PARTICIPANT	\N	PRESENT	0
330945	321347	11110B	PARTICIPANT	\N	PRESENT	0
330946	321347	08043V	PARTICIPANT	\N	PRESENT	0
330947	321347	19591F	PARTICIPANT	\N	PRESENT	0
330948	321347	19681G	PARTICIPANT	\N	PRESENT	0
330989	330988	11053K	PARTICIPANT	\N	PRESENT	0
330990	330988	14159V	PARTICIPANT	\N	PRESENT	0
330991	330988	05012A	PARTICIPANT	\N	PRESENT	0
331012	326974	14069U	PARTICIPANT	\N	PRESENT	0
331014	326974	14195A	PARTICIPANT	\N	PRESENT	0
331015	326974	19525U	PARTICIPANT	\N	PRESENT	0
331017	326974	14259Y	PARTICIPANT	\N	PRESENT	0
331018	326974	08038Y	PARTICIPANT	\N	PRESENT	0
331019	326974	14327T	PARTICIPANT	\N	PRESENT	0
331020	326974	14281W	PARTICIPANT	\N	PRESENT	0
331021	326974	14231L	PARTICIPANT	\N	PRESENT	0
331022	326974	19565D	PARTICIPANT	\N	PRESENT	0
331023	326974	11049P	PARTICIPANT	\N	PRESENT	0
331024	326974	01057W	PARTICIPANT	\N	PRESENT	0
331025	326974	08010L	PARTICIPANT	\N	PRESENT	0
331026	326974	08051V	PARTICIPANT	\N	PRESENT	0
331028	326974	14257W	PARTICIPANT	\N	PRESENT	0
331029	326974	95067Q	PARTICIPANT	\N	PRESENT	0
331030	326974	08049C	PARTICIPANT	\N	PRESENT	0
331031	326974	95063L	PARTICIPANT	\N	PRESENT	0
331032	326974	04045F	PARTICIPANT	\N	PRESENT	0
331033	326974	19735D	PARTICIPANT	\N	PRESENT	0
331034	326974	05012A	PARTICIPANT	\N	PRESENT	0
331035	326974	19681G	PARTICIPANT	\N	PRESENT	0
331038	331037	14107H	PARTICIPANT	\N	PRESENT	0
331117	331116	14193X	PARTICIPANT	\N	PRESENT	0
331118	331116	19421M	PARTICIPANT	\N	PRESENT	0
331440	331301	14061L	PARTICIPANT	\N	EXCUSE	0
331441	331301	04033B	PARTICIPANT	\N	EXCUSE	0
304671	298817	19551W	PARTICIPANT	\N	PRESENT	0
304672	298817	19737F	PARTICIPANT	\N	PRESENT	0
304673	298614	19551W	PARTICIPANT	\N	PRESENT	0
304674	298614	19737F	PARTICIPANT	\N	PRESENT	0
309128	309127	89017R	PARTICIPANT	\N	PRESENT	0
309129	309127	04085P	PARTICIPANT	\N	PRESENT	0
309130	309127	04059M	PARTICIPANT	\N	PRESENT	0
309131	309127	05008E	PARTICIPANT	\N	PRESENT	0
309132	309127	96004D	PARTICIPANT	\N	PRESENT	0
309133	309127	98023Q	PARTICIPANT	\N	PRESENT	0
309134	309127	04086Q	PARTICIPANT	\N	PRESENT	0
309135	309127	11070L	PARTICIPANT	\N	PRESENT	0
309136	309127	11074Q	PARTICIPANT	\N	PRESENT	0
309137	309127	14034U	PARTICIPANT	\N	PRESENT	0
309138	309127	14021P	PARTICIPANT	\N	PRESENT	0
309139	309127	08039A	PARTICIPANT	\N	PRESENT	0
309140	309127	01043Q	PARTICIPANT	\N	PRESENT	0
309141	309127	11077T	PARTICIPANT	\N	PRESENT	0
309142	309127	14251Q	PARTICIPANT	\N	PRESENT	0
309143	309127	11085T	PARTICIPANT	\N	PRESENT	0
309144	309127	11072N	PARTICIPANT	\N	PRESENT	0
309145	309127	08061X	PARTICIPANT	\N	PRESENT	0
309146	309127	98018T	PARTICIPANT	\N	PRESENT	0
309147	309127	05012A	PARTICIPANT	\N	PRESENT	0
309148	309127	11090Q	PARTICIPANT	\N	PRESENT	0
309149	309127	11012A	PARTICIPANT	\N	PRESENT	0
309150	309127	04033B	PARTICIPANT	\N	PRESENT	0
309151	309127	04044E	PARTICIPANT	\N	PRESENT	0
309152	309127	01034P	PARTICIPANT	\N	PRESENT	0
309237	305886	19369B	PARTICIPANT	\N	PRESENT	0
309423	306017	19421M	PARTICIPANT	\N	EXCUSE	0
309424	305886	19421M	PARTICIPANT	\N	EXCUSE	0
309770	305886	08024S	PARTICIPANT	\N	EXCUSE	0
311875	309270	19413M	PARTICIPANT	\N	PRESENT	0
311876	309270	11077T	PARTICIPANT	\N	PRESENT	0
311877	309270	14081Q	PARTICIPANT	\N	PRESENT	0
311878	309270	14051J	PARTICIPANT	\N	PRESENT	0
311879	309270	08068F	PARTICIPANT	\N	PRESENT	0
311880	309270	19269X	PARTICIPANT	\N	PRESENT	0
311881	309270	14265W	PARTICIPANT	\N	PRESENT	0
311882	309270	19575F	PARTICIPANT	\N	PRESENT	0
311883	309270	19399H	PARTICIPANT	\N	PRESENT	0
311884	309270	14033T	PARTICIPANT	\N	PRESENT	0
311885	309270	14135M	PARTICIPANT	\N	PRESENT	0
311886	309270	04088S	PARTICIPANT	\N	PRESENT	0
311887	309270	18083K	PARTICIPANT	\N	PRESENT	0
311888	309270	19467C	PARTICIPANT	\N	PRESENT	0
311889	309270	19447X	PARTICIPANT	\N	PRESENT	0
311890	309270	19703U	PARTICIPANT	\N	PRESENT	0
311891	309270	19515S	PARTICIPANT	\N	PRESENT	0
311892	309270	19673G	PARTICIPANT	\N	PRESENT	0
311893	309270	14031R	PARTICIPANT	\N	PRESENT	0
311894	309270	14169X	PARTICIPANT	\N	PRESENT	0
311895	309270	95062K	PARTICIPANT	\N	PRESENT	0
311896	309270	08039A	PARTICIPANT	\N	PRESENT	0
311897	309270	19711U	PARTICIPANT	\N	PRESENT	0
311898	309270	04086Q	PARTICIPANT	\N	PRESENT	0
311899	309270	04008A	PARTICIPANT	\N	PRESENT	0
311900	309270	14223L	PARTICIPANT	\N	PRESENT	0
311901	309270	19705W	PARTICIPANT	\N	PRESENT	0
311902	309270	11049P	PARTICIPANT	\N	PRESENT	0
311903	309270	14357A	PARTICIPANT	\N	PRESENT	0
311904	309270	14030Q	PARTICIPANT	\N	PRESENT	0
311905	309270	19695N	PARTICIPANT	\N	PRESENT	0
311906	309270	01028R	PARTICIPANT	\N	PRESENT	0
311907	309270	11072N	PARTICIPANT	\N	PRESENT	0
311908	309270	19651A	PARTICIPANT	\N	PRESENT	0
311909	309270	08049C	PARTICIPANT	\N	PRESENT	0
311910	309270	08061X	PARTICIPANT	\N	PRESENT	0
311911	309270	19383Y	PARTICIPANT	\N	PRESENT	0
311912	309270	08056B	PARTICIPANT	\N	PRESENT	0
311913	309270	14221J	PARTICIPANT	\N	PRESENT	0
311914	309270	14038Y	PARTICIPANT	\N	PRESENT	0
311915	309270	11101A	PARTICIPANT	\N	PRESENT	0
311916	309270	19749K	PARTICIPANT	\N	PRESENT	0
311917	309270	04049K	PARTICIPANT	\N	PRESENT	0
311918	309270	14115H	PARTICIPANT	\N	PRESENT	0
311919	309270	08021P	PARTICIPANT	\N	PRESENT	0
311920	309270	14071N	PARTICIPANT	\N	PRESENT	0
311921	309270	08028W	PARTICIPANT	\N	PRESENT	0
311924	309270	14211G	PARTICIPANT	\N	PRESENT	0
311927	309270	08045X	PARTICIPANT	\N	PRESENT	0
311928	309270	14041T	PARTICIPANT	\N	PRESENT	0
311929	309270	14219Q	PARTICIPANT	\N	PRESENT	0
311930	309270	19511N	PARTICIPANT	\N	PRESENT	0
311931	309270	19629C	PARTICIPANT	\N	PRESENT	0
311932	309270	11054L	PARTICIPANT	\N	PRESENT	0
311933	309270	19551W	PARTICIPANT	\N	PRESENT	0
311934	309270	19619A	PARTICIPANT	\N	PRESENT	0
311935	309270	14213J	PARTICIPANT	\N	PRESENT	0
311936	309270	08019V	PARTICIPANT	\N	PRESENT	0
311937	309270	14026U	PARTICIPANT	\N	PRESENT	0
311938	309270	08038Y	PARTICIPANT	\N	PRESENT	0
311939	309270	08015R	PARTICIPANT	\N	PRESENT	0
311940	309270	19253P	PARTICIPANT	\N	PRESENT	0
311941	309270	11012A	PARTICIPANT	\N	PRESENT	0
311942	309270	19441R	PARTICIPANT	\N	PRESENT	0
311943	309270	14042U	PARTICIPANT	\N	PRESENT	0
311944	309270	14111D	PARTICIPANT	\N	PRESENT	0
311945	309270	14119M	PARTICIPANT	\N	PRESENT	0
311946	309270	14179A	PARTICIPANT	\N	PRESENT	0
311947	309270	14109K	PARTICIPANT	\N	PRESENT	0
311948	309270	14083S	PARTICIPANT	\N	PRESENT	0
311949	309270	14029X	PARTICIPANT	\N	PRESENT	0
311950	309270	95041E	PARTICIPANT	\N	PRESENT	0
311951	309270	19699S	PARTICIPANT	\N	PRESENT	0
311952	309270	19369B	PARTICIPANT	\N	PRESENT	0
311953	309270	14087W	PARTICIPANT	\N	PRESENT	0
311956	309270	87003B	PARTICIPANT	\N	PRESENT	0
311966	309270	01024M	PARTICIPANT	\N	PRESENT	0
311969	309270	11104D	PARTICIPANT	\N	PRESENT	0
311970	309270	19667J	PARTICIPANT	\N	PRESENT	0
311971	309270	08020N	PARTICIPANT	\N	PRESENT	0
311972	309270	15447F	PARTICIPANT	\N	PRESENT	0
311973	309270	19367Y	PARTICIPANT	\N	PRESENT	0
311974	309270	14199E	PARTICIPANT	\N	PRESENT	0
311975	309270	14239U	PARTICIPANT	\N	PRESENT	0
312259	309271	11101A	PARTICIPANT	\N	PRESENT	0
312260	309271	04097T	PARTICIPANT	\N	PRESENT	0
312261	309271	11049P	PARTICIPANT	\N	PRESENT	0
312262	309271	87003B	PARTICIPANT	\N	PRESENT	0
312263	309271	19711U	PARTICIPANT	\N	PRESENT	0
312264	309271	04008A	PARTICIPANT	\N	PRESENT	0
312265	309271	08011M	PARTICIPANT	\N	PRESENT	0
312266	309271	08055A	PARTICIPANT	\N	PRESENT	0
312267	309271	01028R	PARTICIPANT	\N	PRESENT	0
312268	309271	19399H	PARTICIPANT	\N	PRESENT	0
312269	309271	14187A	PARTICIPANT	\N	PRESENT	0
312270	309271	19741B	PARTICIPANT	\N	PRESENT	0
312271	309271	11090Q	PARTICIPANT	\N	PRESENT	0
312272	309271	19515S	PARTICIPANT	\N	PRESENT	0
312273	309271	19703U	PARTICIPANT	\N	PRESENT	0
312274	309271	19667J	PARTICIPANT	\N	PRESENT	0
312275	309271	14223L	PARTICIPANT	\N	PRESENT	0
312276	309271	04044E	PARTICIPANT	\N	PRESENT	0
312277	309271	14051J	PARTICIPANT	\N	PRESENT	0
312278	309271	19565D	PARTICIPANT	\N	PRESENT	0
312279	309271	04085P	PARTICIPANT	\N	PRESENT	0
312280	309271	14235Q	PARTICIPANT	\N	PRESENT	0
312281	309271	80013X	PARTICIPANT	\N	PRESENT	0
312282	309271	14197C	PARTICIPANT	\N	PRESENT	0
312283	309271	04086Q	PARTICIPANT	\N	PRESENT	0
312284	309271	98023Q	PARTICIPANT	\N	PRESENT	0
312285	309271	08012N	PARTICIPANT	\N	PRESENT	0
312286	309271	14121F	PARTICIPANT	\N	PRESENT	0
312287	309271	19683J	PARTICIPANT	\N	PRESENT	0
312288	309271	04047H	PARTICIPANT	\N	PRESENT	0
312289	309271	14253S	PARTICIPANT	\N	PRESENT	0
312290	309271	14119M	PARTICIPANT	\N	PRESENT	0
312291	309271	19766L	PARTICIPANT	\N	PRESENT	0
312292	309271	99004R	PARTICIPANT	\N	PRESENT	0
312293	309271	11080N	PARTICIPANT	\N	PRESENT	0
312294	309271	14211G	PARTICIPANT	\N	PRESENT	0
312296	309271	08010L	PARTICIPANT	\N	PRESENT	0
312297	309271	15447F	PARTICIPANT	\N	PRESENT	0
312298	309271	19643A	PARTICIPANT	\N	PRESENT	0
312299	309271	10015M	PARTICIPANT	\N	PRESENT	0
312300	309271	11033F	PARTICIPANT	\N	PRESENT	0
312301	309271	11043H	PARTICIPANT	\N	PRESENT	0
312302	309271	11040E	PARTICIPANT	\N	PRESENT	0
312303	309271	01048V	PARTICIPANT	\N	PRESENT	0
312304	309271	11031D	PARTICIPANT	\N	PRESENT	0
312305	309271	19758L	PARTICIPANT	\N	PRESENT	0
312306	309271	19760E	PARTICIPANT	\N	PRESENT	0
312307	309271	11077T	PARTICIPANT	\N	PRESENT	0
312308	309271	01057W	PARTICIPANT	\N	PRESENT	0
312309	309271	12041X	PARTICIPANT	\N	PRESENT	0
312311	309271	95067Q	PARTICIPANT	\N	PRESENT	0
312313	309271	11056N	PARTICIPANT	\N	PRESENT	0
331334	321349	14107H	PARTICIPANT	\N	PRESENT	0
331335	321349	14195A	PARTICIPANT	\N	PRESENT	0
331336	321349	19695N	PARTICIPANT	\N	PRESENT	0
331339	321349	95062K	PARTICIPANT	\N	PRESENT	0
331340	321349	19369B	PARTICIPANT	\N	PRESENT	0
331341	321349	19681G	PARTICIPANT	\N	PRESENT	0
331342	321349	19747H	PARTICIPANT	\N	PRESENT	0
331343	321349	19701S	PARTICIPANT	\N	PRESENT	0
331344	321349	19737F	PARTICIPANT	\N	PRESENT	0
331347	321349	19503N	PARTICIPANT	\N	PRESENT	0
331348	321349	11097X	PARTICIPANT	\N	PRESENT	0
331349	321349	19723Y	PARTICIPANT	\N	PRESENT	0
331350	321349	19733B	PARTICIPANT	\N	PRESENT	0
331351	321349	19671E	PARTICIPANT	\N	PRESENT	0
331352	321349	11067R	PARTICIPANT	\N	PRESENT	0
331353	321349	19441R	PARTICIPANT	\N	PRESENT	0
331354	321349	19629C	PARTICIPANT	\N	PRESENT	0
331355	321349	14331P	PARTICIPANT	\N	PRESENT	0
331356	321349	14219Q	PARTICIPANT	\N	PRESENT	0
331357	321349	99004R	PARTICIPANT	\N	PRESENT	0
331363	321349	04088S	PARTICIPANT	\N	PRESENT	0
331364	321349	14021P	PARTICIPANT	\N	PRESENT	0
331365	321349	11040E	PARTICIPANT	\N	PRESENT	0
331366	321349	08055A	PARTICIPANT	\N	PRESENT	0
331367	321349	95063L	PARTICIPANT	\N	PRESENT	0
331368	321349	19467C	PARTICIPANT	\N	PRESENT	0
331369	321349	07029T	PARTICIPANT	\N	PRESENT	0
331370	321349	14221J	PARTICIPANT	\N	PRESENT	0
331371	321349	11012A	PARTICIPANT	\N	PRESENT	0
331372	321349	11070L	PARTICIPANT	\N	PRESENT	0
331373	331301	04070G	PRESIDENT	0	PRESENT	0
331374	331301	19643A	PARTICIPANT	\N	PRESENT	0
331375	331301	19699S	PARTICIPANT	\N	PRESENT	0
331376	331301	04057K	PARTICIPANT	\N	PRESENT	0
331377	331301	14073Q	PARTICIPANT	\N	PRESENT	0
331378	331301	19611R	PARTICIPANT	\N	PRESENT	0
331379	331301	19693L	PARTICIPANT	\N	PRESENT	0
331380	331301	19399H	PARTICIPANT	\N	PRESENT	0
331381	331301	14030Q	PARTICIPANT	\N	PRESENT	0
331382	331301	19731Y	PARTICIPANT	\N	PRESENT	0
331383	331301	19735D	PARTICIPANT	\N	PRESENT	0
331384	331301	08017T	PARTICIPANT	\N	PRESENT	0
331385	331301	11083R	PARTICIPANT	\N	PRESENT	0
331386	331301	11043H	PARTICIPANT	\N	PRESENT	0
331387	331301	19749K	PARTICIPANT	\N	PRESENT	0
331388	331301	19758L	PARTICIPANT	\N	PRESENT	0
331389	331301	04018C	PARTICIPANT	\N	PRESENT	0
331390	331301	14249W	PARTICIPANT	\N	PRESENT	0
331391	331301	08031R	PARTICIPANT	\N	PRESENT	0
331392	331301	14201E	PARTICIPANT	\N	EXCUSE	0
331393	331301	08039A	PARTICIPANT	\N	EXCUSE	0
331408	321349	19691J	PARTICIPANT	\N	PRESENT	0
331409	321349	08060W	PARTICIPANT	\N	PRESENT	0
331410	321349	14073Q	PARTICIPANT	\N	PRESENT	0
331411	321349	11045K	PARTICIPANT	\N	PRESENT	0
331412	321349	14249W	PARTICIPANT	\N	PRESENT	0
331413	321349	19711U	PARTICIPANT	\N	PRESENT	0
331416	321349	08011M	PARTICIPANT	\N	PRESENT	0
331426	321349	14159V	PARTICIPANT	\N	PRESENT	0
331427	321349	14069U	PARTICIPANT	\N	PRESENT	0
331428	321349	19647E	PARTICIPANT	\N	PRESENT	0
331429	321349	14030Q	PARTICIPANT	\N	PRESENT	0
331430	321349	11074Q	PARTICIPANT	\N	PRESENT	0
331431	321349	89017R	PARTICIPANT	\N	PRESENT	0
331432	321349	14033T	PARTICIPANT	\N	PRESENT	0
331433	321349	14083S	PARTICIPANT	\N	PRESENT	0
331434	321349	14329V	PARTICIPANT	\N	PRESENT	0
331435	321349	11053K	PARTICIPANT	\N	PRESENT	0
331436	321349	19269X	PARTICIPANT	\N	PRESENT	0
331437	321349	11077T	PARTICIPANT	\N	PRESENT	0
331442	321349	19758L	PARTICIPANT	\N	PRESENT	0
331439	321349	08010L	PARTICIPANT	\N	PRESENT	0
331506	321350	07004J	PARTICIPANT	\N	PRESENT	0
331507	321350	19651A	PARTICIPANT	\N	PRESENT	0
331508	321350	11040E	PARTICIPANT	\N	PRESENT	0
331509	321350	11077T	PARTICIPANT	\N	PRESENT	0
331510	321350	19503N	PARTICIPANT	\N	PRESENT	0
331511	321350	19683J	PARTICIPANT	\N	PRESENT	0
331512	321350	19667J	PARTICIPANT	\N	PRESENT	0
331513	321350	14207L	PARTICIPANT	\N	PRESENT	0
331514	321350	14157T	PARTICIPANT	\N	PRESENT	0
331515	321350	08052W	PARTICIPANT	\N	PRESENT	0
331516	321350	19731Y	PARTICIPANT	\N	PRESENT	0
331517	321350	08020N	PARTICIPANT	\N	PRESENT	0
331518	321350	19681G	PARTICIPANT	\N	PRESENT	0
331519	321350	99004R	PARTICIPANT	\N	PRESENT	0
331520	321350	19545Y	PARTICIPANT	\N	PRESENT	0
331521	321350	04086Q	PARTICIPANT	\N	PRESENT	0
331522	321350	11053K	PARTICIPANT	\N	PRESENT	0
331523	321350	14327T	PARTICIPANT	\N	PRESENT	0
331524	321350	19521Q	PARTICIPANT	\N	PRESENT	0
331525	321350	19671E	PARTICIPANT	\N	PRESENT	0
331526	321350	88008L	PARTICIPANT	\N	PRESENT	0
331527	321350	11097X	PARTICIPANT	\N	PRESENT	0
331528	321350	14249W	PARTICIPANT	\N	PRESENT	0
331529	321350	08011M	PARTICIPANT	\N	PRESENT	0
331530	321350	11074Q	PARTICIPANT	\N	PRESENT	0
331531	321350	19695N	PARTICIPANT	\N	PRESENT	0
331532	321350	19687N	PARTICIPANT	\N	PRESENT	0
331533	321350	01057W	PARTICIPANT	\N	PRESENT	0
331534	321350	19758L	PARTICIPANT	\N	PRESENT	0
331535	321350	14033T	PARTICIPANT	\N	PRESENT	0
331536	321350	19647E	PARTICIPANT	\N	PRESENT	0
331537	321350	08034U	PARTICIPANT	\N	PRESENT	0
331538	321350	19691J	PARTICIPANT	\N	PRESENT	0
331540	321350	07029T	PARTICIPANT	\N	PRESENT	0
331541	321350	19467C	PARTICIPANT	\N	PRESENT	0
331542	321350	11043H	PARTICIPANT	\N	PRESENT	0
331543	321350	11012A	PARTICIPANT	\N	PRESENT	0
331544	321350	14231L	PARTICIPANT	\N	PRESENT	0
331545	321350	19525U	PARTICIPANT	\N	PRESENT	0
331546	321350	19573D	PARTICIPANT	\N	PRESENT	0
331547	321350	04059M	PARTICIPANT	\N	PRESENT	0
331548	321350	89017R	PARTICIPANT	\N	PRESENT	0
331549	321350	19593H	PARTICIPANT	\N	PRESENT	0
331550	321350	14069U	PARTICIPANT	\N	PRESENT	0
331564	321350	14119M	PARTICIPANT	\N	PRESENT	0
331565	321350	04043D	PARTICIPANT	\N	PRESENT	0
331566	321350	14083S	PARTICIPANT	\N	PRESENT	0
331567	321350	08031R	PARTICIPANT	\N	PRESENT	0
331568	321350	19699S	PARTICIPANT	\N	PRESENT	0
331569	321350	97011G	PARTICIPANT	\N	PRESENT	0
331570	321350	19369B	PARTICIPANT	\N	PRESENT	0
331571	321350	19747H	PARTICIPANT	\N	PRESENT	0
331572	321350	14329V	PARTICIPANT	\N	PRESENT	0
331573	321350	19333N	PARTICIPANT	\N	PRESENT	0
331574	321350	19591F	PARTICIPANT	\N	PRESENT	0
331575	321350	08051V	PARTICIPANT	\N	PRESENT	0
331576	321350	19295A	PARTICIPANT	\N	PRESENT	0
331578	321350	08010L	PARTICIPANT	\N	PRESENT	0
331579	321350	19631V	PARTICIPANT	\N	PRESENT	0
331580	321350	14038Y	PARTICIPANT	\N	PRESENT	0
331503	321350	14034U	PARTICIPANT	\N	PRESENT	0
331505	321350	19711U	PARTICIPANT	\N	PRESENT	0
331581	321350	19713W	PARTICIPANT	\N	PRESENT	0
331582	321350	19643A	PARTICIPANT	\N	PRESENT	0
331583	321350	14107H	PARTICIPANT	\N	PRESENT	0
331584	321350	95062K	PARTICIPANT	\N	PRESENT	0
331585	321350	08019V	PARTICIPANT	\N	PRESENT	0
331586	321350	14073Q	PARTICIPANT	\N	PRESENT	0
331587	321350	14257W	PARTICIPANT	\N	PRESENT	0
331589	321350	14001X	PARTICIPANT	\N	PRESENT	0
331591	321350	19399H	PARTICIPANT	\N	PRESENT	0
331593	321350	14021P	PARTICIPANT	\N	PRESENT	0
331595	321350	04088S	PARTICIPANT	\N	PRESENT	0
331596	321350	17589D	PARTICIPANT	\N	PRESENT	0
331597	321350	19611R	PARTICIPANT	\N	PRESENT	0
331598	321350	04085P	PARTICIPANT	\N	PRESENT	0
331599	321350	11033F	PARTICIPANT	\N	PRESENT	0
331600	321350	19737F	PARTICIPANT	\N	PRESENT	0
331601	321350	01048V	PARTICIPANT	\N	PRESENT	0
331604	321350	11065P	PARTICIPANT	\N	PRESENT	0
331607	321350	08015R	PARTICIPANT	\N	PRESENT	0
331608	321350	19479G	PARTICIPANT	\N	PRESENT	0
331609	321350	08068F	PARTICIPANT	\N	PRESENT	0
331619	321350	11048N	PARTICIPANT	\N	PRESENT	0
331621	321350	11045K	PARTICIPANT	\N	PRESENT	0
331622	321350	07033P	PARTICIPANT	\N	PRESENT	0
331623	321350	19741B	PARTICIPANT	\N	PRESENT	0
331624	321350	19441R	PARTICIPANT	\N	PRESENT	0
331625	321350	11110B	PARTICIPANT	\N	PRESENT	0
331626	321350	14159V	PARTICIPANT	\N	PRESENT	0
331627	321350	14357A	PARTICIPANT	\N	PRESENT	0
331629	321350	12016W	PARTICIPANT	\N	PRESENT	0
331630	321350	19621T	PARTICIPANT	\N	PRESENT	0
331631	321350	11083R	PARTICIPANT	\N	PRESENT	0
331632	321350	11026G	PARTICIPANT	\N	PRESENT	0
331633	321350	08069G	PARTICIPANT	\N	PRESENT	0
331634	321350	14265W	PARTICIPANT	\N	PRESENT	0
305432	305431	04086Q	PARTICIPANT	\N	PRESENT	0
305434	305433	11074Q	PARTICIPANT	\N	PRESENT	0
318687	318677	18083K	PARTICIPANT	\N	PRESENT	0
305468	305467	08012N	PARTICIPANT	\N	PRESENT	0
305469	305467	04057K	PARTICIPANT	\N	PRESENT	0
305470	305467	92040Q	PARTICIPANT	\N	PRESENT	0
309100	305977	19723Y	PARTICIPANT	\N	PRESENT	0
318688	318677	14357A	PARTICIPANT	\N	PRESENT	0
318689	318677	17589D	PARTICIPANT	\N	PRESENT	0
318690	318677	19507S	PARTICIPANT	\N	PRESENT	0
318691	318677	14179A	PARTICIPANT	\N	PRESENT	0
318692	318677	19723Y	PARTICIPANT	\N	PRESENT	0
318693	318677	08053X	PARTICIPANT	\N	PRESENT	0
318733	318677	14221J	PARTICIPANT	\N	PRESENT	0
318734	318677	19563B	PARTICIPANT	\N	PRESENT	0
318735	318677	14119M	PARTICIPANT	\N	PRESENT	0
318736	318677	14265W	PARTICIPANT	\N	PRESENT	0
318737	318677	04088S	PARTICIPANT	\N	PRESENT	0
318738	318677	05012A	PARTICIPANT	\N	PRESENT	0
318739	318677	17583W	PARTICIPANT	\N	PRESENT	0
318740	318677	19679N	PARTICIPANT	\N	PRESENT	0
318741	318677	14135M	PARTICIPANT	\N	PRESENT	0
318742	318677	14331P	PARTICIPANT	\N	PRESENT	0
318743	318677	19619A	PARTICIPANT	\N	PRESENT	0
318744	318677	95067Q	PARTICIPANT	\N	PRESENT	0
319958	314097	11070L	PARTICIPANT	\N	PRESENT	0
319959	314097	19701S	PARTICIPANT	\N	PRESENT	0
319960	314097	14255U	PARTICIPANT	\N	PRESENT	0
319961	314097	19347U	PARTICIPANT	\N	PRESENT	0
319962	314097	19551W	PARTICIPANT	\N	PRESENT	0
319963	314097	19503N	PARTICIPANT	\N	PRESENT	0
319964	314097	08055A	PARTICIPANT	\N	PRESENT	0
319965	314097	19725B	PARTICIPANT	\N	PRESENT	0
319966	314097	19669L	PARTICIPANT	\N	PRESENT	0
319967	314097	14207L	PARTICIPANT	\N	PRESENT	0
319968	314097	19737F	PARTICIPANT	\N	PRESENT	0
319969	314097	14030Q	PARTICIPANT	\N	PRESENT	0
319970	314097	95063L	PARTICIPANT	\N	PRESENT	0
319971	314097	01025N	PARTICIPANT	\N	PRESENT	0
319972	314097	19253P	PARTICIPANT	\N	PRESENT	0
319973	314097	19629C	PARTICIPANT	\N	PRESENT	0
319974	314097	19747H	PARTICIPANT	\N	PRESENT	0
319975	314097	14133K	PARTICIPANT	\N	PRESENT	0
319976	314097	19741B	PARTICIPANT	\N	PRESENT	0
319977	314097	11083R	PARTICIPANT	\N	PRESENT	0
319978	314097	10015M	PARTICIPANT	\N	PRESENT	0
319979	314097	11103C	PARTICIPANT	\N	PRESENT	0
319980	314097	11012A	PARTICIPANT	\N	PRESENT	0
319981	314097	14215L	PARTICIPANT	\N	PRESENT	0
319982	314097	19447X	PARTICIPANT	\N	PRESENT	0
319983	314097	19415P	PARTICIPANT	\N	PRESENT	0
319984	314097	19679N	PARTICIPANT	\N	PRESENT	0
319985	314097	95030B	PARTICIPANT	\N	PRESENT	0
319986	314097	17589D	PARTICIPANT	\N	PRESENT	0
319987	314097	14079W	PARTICIPANT	\N	PRESENT	0
319988	314097	04089T	PARTICIPANT	\N	PRESENT	0
319989	314097	19762G	PARTICIPANT	\N	PRESENT	0
319990	314097	14081Q	PARTICIPANT	\N	PRESENT	0
319991	314097	14119M	PARTICIPANT	\N	PRESENT	0
319992	314097	04049K	PARTICIPANT	\N	PRESENT	0
319993	314097	14001X	PARTICIPANT	\N	PRESENT	0
319994	314097	19565D	PARTICIPANT	\N	PRESENT	0
319995	314097	14235Q	PARTICIPANT	\N	PRESENT	0
319996	314097	14033T	PARTICIPANT	\N	PRESENT	0
319997	314097	14115H	PARTICIPANT	\N	PRESENT	0
319998	314097	14029X	PARTICIPANT	\N	PRESENT	0
319999	314097	14157T	PARTICIPANT	\N	PRESENT	0
320000	314097	14065Q	PARTICIPANT	\N	PRESENT	0
320001	314097	14213J	PARTICIPANT	\N	PRESENT	0
320002	314097	14199E	PARTICIPANT	\N	PRESENT	0
320003	314097	04088S	PARTICIPANT	\N	PRESENT	0
320004	314097	14217N	PARTICIPANT	\N	PRESENT	0
320005	314097	14265W	PARTICIPANT	\N	PRESENT	0
320006	314097	14147R	PARTICIPANT	\N	PRESENT	0
320007	314097	18083K	PARTICIPANT	\N	PRESENT	0
320008	314097	11090Q	PARTICIPANT	\N	PRESENT	0
320009	314097	19335Q	PARTICIPANT	\N	PRESENT	0
320010	314097	11097X	PARTICIPANT	\N	PRESENT	0
320011	314097	14069U	PARTICIPANT	\N	PRESENT	0
320012	314097	08068F	PARTICIPANT	\N	PRESENT	0
320013	314097	11099A	PARTICIPANT	\N	PRESENT	0
320014	314097	14105F	PARTICIPANT	\N	PRESENT	0
320015	314097	14135M	PARTICIPANT	\N	PRESENT	0
320016	314097	19569H	PARTICIPANT	\N	PRESENT	0
320017	314097	14034U	PARTICIPANT	\N	PRESENT	0
320525	320524	04059M	PARTICIPANT	\N	PRESENT	0
320526	320524	11053K	PARTICIPANT	\N	PRESENT	0
320527	320524	11027H	PARTICIPANT	\N	PRESENT	0
318684	318683	04035D	PARTICIPANT	\N	PRESENT	0
318685	318683	08049C	PARTICIPANT	\N	PRESENT	0
320528	320524	04086Q	PARTICIPANT	\N	PRESENT	0
320529	320524	11070L	PARTICIPANT	\N	PRESENT	0
320530	320524	04089T	PARTICIPANT	\N	PRESENT	0
320531	320524	14034U	PARTICIPANT	\N	PRESENT	0
320532	320524	11064N	PARTICIPANT	\N	PRESENT	0
320533	320524	14081Q	PARTICIPANT	\N	PRESENT	0
320534	320524	14241N	PARTICIPANT	\N	PRESENT	0
320535	320524	14061L	PARTICIPANT	\N	PRESENT	0
320536	320524	14159V	PARTICIPANT	\N	PRESENT	0
320537	320524	86034E	PARTICIPANT	\N	PRESENT	0
320538	320524	08034U	PARTICIPANT	\N	PRESENT	0
321768	321766	04040A	PARTICIPANT	\N	PRESENT	0
320540	320524	12016W	PARTICIPANT	\N	PRESENT	0
320541	320524	11072N	PARTICIPANT	\N	PRESENT	0
320542	320524	05012A	PARTICIPANT	\N	PRESENT	0
320543	320524	14135M	PARTICIPANT	\N	PRESENT	0
320544	320524	04044E	PARTICIPANT	\N	PRESENT	0
321767	321766	04042C	PARTICIPANT	\N	PRESENT	0
321769	321766	11054L	PARTICIPANT	\N	PRESENT	0
321771	321770	04042C	PARTICIPANT	\N	PRESENT	0
321772	321770	04040A	PARTICIPANT	\N	PRESENT	0
321773	321770	11054L	PARTICIPANT	\N	PRESENT	0
321774	321770	01062T	PARTICIPANT	\N	PRESENT	0
321776	321775	98029W	PARTICIPANT	\N	PRESENT	0
321779	321777	19533U	PARTICIPANT	\N	PRESENT	0
321794	319508	19703U	PARTICIPANT	\N	PRESENT	0
322177	321790	19663E	PARTICIPANT	\N	PRESENT	0
322178	321790	14042U	PARTICIPANT	\N	EXCUSE	0
322179	321790	14227Q	PARTICIPANT	\N	PRESENT	0
324182	324181	14065Q	PARTICIPANT	\N	PRESENT	0
324183	324181	08044W	PARTICIPANT	\N	PRESENT	0
324283	324282	19629C	PARTICIPANT	\N	PRESENT	0
324286	324285	19629C	PARTICIPANT	\N	PRESENT	0
324389	324142	19697Q	PARTICIPANT	\N	PRESENT	0
324390	324142	11067R	PARTICIPANT	\N	PRESENT	0
324391	324142	19569H	PARTICIPANT	\N	PRESENT	0
324392	324142	11097X	PARTICIPANT	\N	PRESENT	0
324393	324142	19415P	PARTICIPANT	\N	PRESENT	0
324394	324142	14223L	PARTICIPANT	\N	PRESENT	0
324395	324142	04045F	PARTICIPANT	\N	PRESENT	0
324396	324142	14026U	PARTICIPANT	\N	PRESENT	0
324397	324142	14227Q	PARTICIPANT	\N	PRESENT	0
324398	324142	17779H	PARTICIPANT	\N	PRESENT	0
324399	324142	19703U	PARTICIPANT	\N	PRESENT	0
324400	324142	14239U	PARTICIPANT	\N	PRESENT	0
324401	324142	14281W	PARTICIPANT	\N	PRESENT	0
324402	324142	14195A	PARTICIPANT	\N	PRESENT	0
324403	324142	19575F	PARTICIPANT	\N	PRESENT	0
324404	324142	14213J	PARTICIPANT	\N	PRESENT	0
324405	324142	14217N	PARTICIPANT	\N	PRESENT	0
324406	324142	10006L	PARTICIPANT	\N	PRESENT	0
324407	324142	19683J	PARTICIPANT	\N	PRESENT	0
324408	324142	98024R	PARTICIPANT	\N	PRESENT	0
324409	324142	01034P	PARTICIPANT	\N	PRESENT	0
324410	324142	04092N	PRESIDENT	0	PRESENT	0
324411	324142	08052W	PARTICIPANT	\N	PRESENT	0
324412	324142	19663E	PARTICIPANT	\N	PRESENT	0
324413	324142	19715Y	PARTICIPANT	\N	PRESENT	0
324414	324142	19691J	PARTICIPANT	\N	PRESENT	0
324415	324142	19723Y	PARTICIPANT	\N	PRESENT	0
324416	324142	19727D	PARTICIPANT	\N	PRESENT	0
324417	324142	14119M	PARTICIPANT	0	PRESENT	0
324418	324142	11103C	PARTICIPANT	\N	PRESENT	0
324419	324142	14071N	PARTICIPANT	\N	PRESENT	0
324420	324142	19657G	PARTICIPANT	\N	PRESENT	0
324421	324142	19577H	PARTICIPANT	\N	PRESENT	0
324422	324142	14355X	PARTICIPANT	\N	EXCUSE	0
324423	324142	14042U	PARTICIPANT	\N	EXCUSE	0
324424	324142	19367Y	PARTICIPANT	\N	EXCUSE	0
324425	324142	08041T	PARTICIPANT	\N	EXCUSE	0
324426	324142	19675J	PARTICIPANT	\N	EXCUSE	0
324427	324142	19521Q	PARTICIPANT	\N	EXCUSE	0
324428	314153	04044E	PARTICIPANT	\N	PRESENT	0
324429	314153	11031D	PARTICIPANT	\N	PRESENT	0
324430	314153	04092N	PARTICIPANT	\N	PRESENT	0
324431	314153	01034P	PARTICIPANT	\N	PRESENT	0
324432	314153	11110B	PARTICIPANT	\N	PRESENT	0
324433	314153	14195A	PARTICIPANT	\N	PRESENT	0
316283	316278	04086Q	PARTICIPANT	\N	PRESENT	0
317325	317324	08012N	PARTICIPANT	\N	PRESENT	0
331002	331001	96004D	PARTICIPANT	\N	PRESENT	0
331003	331001	14089Y	PARTICIPANT	\N	PRESENT	0
331004	331001	14073Q	PARTICIPANT	\N	PRESENT	0
331005	331001	04097T	PARTICIPANT	\N	PRESENT	0
331006	331001	04057K	PARTICIPANT	\N	PRESENT	0
331119	321348	14281W	PARTICIPANT	\N	PRESENT	0
331120	321348	14231L	PARTICIPANT	\N	PRESENT	0
331121	321348	19443T	PARTICIPANT	\N	PRESENT	0
331122	321348	14085U	PARTICIPANT	\N	PRESENT	0
331123	321348	11110B	PARTICIPANT	\N	PRESENT	0
331124	321348	19593H	PARTICIPANT	\N	PRESENT	0
331125	321348	19413M	PARTICIPANT	\N	PRESENT	0
331126	321348	80013X	PARTICIPANT	\N	PRESENT	0
331127	321348	08011M	PARTICIPANT	\N	PRESENT	0
331128	321348	19621T	PARTICIPANT	\N	PRESENT	0
331129	321348	11040E	PARTICIPANT	\N	PRESENT	0
331130	321348	07033P	PARTICIPANT	\N	PRESENT	0
331131	321348	07004J	PARTICIPANT	\N	PRESENT	0
331132	321348	14215L	PARTICIPANT	\N	PRESENT	0
331133	321348	19629C	PARTICIPANT	\N	PRESENT	0
331134	321348	04086Q	PARTICIPANT	\N	PRESENT	0
331135	321348	19667J	PARTICIPANT	\N	PRESENT	0
331136	321348	11070L	PARTICIPANT	\N	PRESENT	0
331177	321348	08010L	PARTICIPANT	\N	PRESENT	0
331138	321348	19565D	PARTICIPANT	\N	PRESENT	0
331139	321348	14157T	PARTICIPANT	\N	PRESENT	0
331140	321348	14217N	PARTICIPANT	\N	PRESENT	0
331141	321348	14357A	PARTICIPANT	\N	PRESENT	0
331142	321348	04018C	PARTICIPANT	\N	PRESENT	0
331143	321348	19681G	PARTICIPANT	\N	PRESENT	0
331144	321348	14069U	PARTICIPANT	\N	PRESENT	0
331145	321348	14213J	PARTICIPANT	\N	PRESENT	0
331146	321348	08034U	PARTICIPANT	\N	PRESENT	0
331147	321348	19575F	PARTICIPANT	\N	PRESENT	0
331148	321348	19711U	PARTICIPANT	\N	PRESENT	0
331149	321348	19651A	PARTICIPANT	\N	PRESENT	0
331150	321348	19521Q	PARTICIPANT	\N	PRESENT	0
331151	321348	19467C	PARTICIPANT	\N	PRESENT	0
331152	321348	14083S	PARTICIPANT	\N	PRESENT	0
331153	321348	14251Q	PARTICIPANT	\N	PRESENT	0
331154	321348	14033T	PARTICIPANT	\N	PRESENT	0
331155	321348	19515S	PARTICIPANT	\N	PRESENT	0
331156	321348	19735D	PARTICIPANT	\N	PRESENT	0
331157	321348	14265W	PARTICIPANT	\N	PRESENT	0
331158	321348	04088S	PARTICIPANT	\N	PRESENT	0
331159	321348	14329V	PARTICIPANT	\N	PRESENT	0
331160	321348	11097X	PARTICIPANT	\N	PRESENT	0
331114	321348	14034U	PARTICIPANT	\N	PRESENT	0
331115	321348	08043V	PARTICIPANT	\N	PRESENT	0
331161	321348	14071N	PARTICIPANT	\N	PRESENT	0
331162	321348	19631V	PARTICIPANT	\N	PRESENT	0
331163	321348	19727D	PARTICIPANT	\N	PRESENT	0
331164	321348	19733B	PARTICIPANT	\N	PRESENT	0
331165	321348	14107H	PARTICIPANT	\N	PRESENT	0
331176	321348	14255U	PARTICIPANT	\N	PRESENT	0
331167	321348	08051V	PARTICIPANT	\N	PRESENT	0
331168	321348	14029X	PARTICIPANT	\N	PRESENT	0
331169	321348	08020N	PARTICIPANT	\N	PRESENT	0
331170	321348	19747H	PARTICIPANT	\N	PRESENT	0
331171	321348	11048N	PARTICIPANT	\N	PRESENT	0
331172	321348	14257W	PARTICIPANT	\N	PRESENT	0
331173	321348	11077T	PARTICIPANT	\N	PRESENT	0
331174	321348	19691J	PARTICIPANT	\N	PRESENT	0
331175	321348	01024M	PARTICIPANT	\N	PRESENT	0
331178	321348	19269X	PARTICIPANT	\N	PRESENT	0
331179	321348	19713W	PARTICIPANT	\N	PRESENT	0
331180	321348	14089Y	PARTICIPANT	\N	PRESENT	0
331181	321348	14159V	PARTICIPANT	\N	PRESENT	0
331182	321348	14169X	PARTICIPANT	\N	PRESENT	0
331183	321348	19543W	PARTICIPANT	\N	PRESENT	0
331184	321348	19441R	PARTICIPANT	\N	PRESENT	0
331185	321348	14327T	PARTICIPANT	\N	PRESENT	0
331186	321348	14261S	PARTICIPANT	\N	PRESENT	0
331187	321348	08031R	PARTICIPANT	\N	PRESENT	0
331188	321348	19553Y	PARTICIPANT	\N	PRESENT	0
331189	321348	19647E	PARTICIPANT	\N	PRESENT	0
331190	321348	08015R	PARTICIPANT	\N	PRESENT	0
331191	321348	07029T	PARTICIPANT	\N	PRESENT	0
331192	321348	14030Q	PARTICIPANT	\N	PRESENT	0
331193	321348	19369B	PARTICIPANT	\N	PRESENT	0
331194	321348	14219Q	PARTICIPANT	\N	PRESENT	0
331195	321348	14021P	PARTICIPANT	\N	PRESENT	0
331196	321348	19503N	PARTICIPANT	\N	PRESENT	0
331197	321348	19703U	PARTICIPANT	\N	PRESENT	0
331198	321348	08055A	PARTICIPANT	\N	PRESENT	0
331199	321348	14249W	PARTICIPANT	\N	PRESENT	0
331200	321348	14275Y	PARTICIPANT	\N	PRESENT	0
331201	321348	14073Q	PARTICIPANT	\N	PRESENT	0
331202	321348	04049K	PARTICIPANT	\N	PRESENT	0
331203	321348	19737F	PARTICIPANT	\N	PRESENT	0
331204	321348	19551W	PARTICIPANT	\N	PRESENT	0
331205	321348	89017R	PARTICIPANT	\N	PRESENT	0
331206	321348	11074Q	PARTICIPANT	\N	PRESENT	0
331207	321348	11043H	PARTICIPANT	\N	PRESENT	0
331208	321348	19573D	PARTICIPANT	\N	PRESENT	0
331209	321348	11053K	PARTICIPANT	\N	PRESENT	0
331504	331358	14071N	PARTICIPANT	\N	EXCUSE	0
331539	325451	19715Y	PARTICIPANT	\N	EXCUSE	0
331558	322213	01048V	PRESIDENT	0	PRESENT	0
331559	322213	19533U	PARTICIPANT	\N	PRESENT	0
331560	322213	19709B	PARTICIPANT	\N	EXCUSE	0
331561	322213	08053X	PARTICIPANT	\N	EXCUSE	0
331562	322213	19693L	PARTICIPANT	\N	EXCUSE	0
331563	322213	19723Y	PARTICIPANT	\N	EXCUSE	0
331858	321353	19667J	PARTICIPANT	\N	PRESENT	0
331859	321353	19651A	PARTICIPANT	\N	PRESENT	0
331860	321353	14329V	PARTICIPANT	\N	PRESENT	0
331861	321353	19695N	PARTICIPANT	\N	PRESENT	0
331862	321353	19689Q	PARTICIPANT	\N	PRESENT	0
331863	321353	19515S	PARTICIPANT	\N	PRESENT	0
331864	321353	08034U	PARTICIPANT	\N	PRESENT	0
331865	321353	07004J	PARTICIPANT	\N	PRESENT	0
331866	321353	14169X	PARTICIPANT	\N	PRESENT	0
331867	321353	14327T	PARTICIPANT	\N	PRESENT	0
331868	321353	19711U	PARTICIPANT	\N	PRESENT	0
331869	321353	08068F	PARTICIPANT	\N	PRESENT	0
331870	321353	14081Q	PARTICIPANT	\N	PRESENT	0
331871	321353	11056N	PARTICIPANT	\N	PRESENT	0
331872	321353	19687N	PARTICIPANT	\N	PRESENT	0
331873	321353	14257W	PARTICIPANT	\N	PRESENT	0
331874	321353	12016W	PARTICIPANT	\N	PRESENT	0
331875	321353	19631V	PARTICIPANT	\N	PRESENT	0
331876	321353	14107H	PARTICIPANT	\N	PRESENT	0
331877	321353	19545Y	PARTICIPANT	\N	PRESENT	0
331878	321353	14187A	PARTICIPANT	\N	PRESENT	0
331879	321353	19741B	PARTICIPANT	\N	PRESENT	0
331880	321353	14069U	PARTICIPANT	\N	PRESENT	0
331882	331881	96004D	PRESIDENT	0	PRESENT	0
331883	331881	14089Y	PARTICIPANT	\N	PRESENT	0
331884	331881	08014Q	PARTICIPANT	\N	PRESENT	0
331885	331881	11083R	PARTICIPANT	\N	PRESENT	0
331886	321353	11053K	PARTICIPANT	\N	PRESENT	0
331887	321353	99004R	PARTICIPANT	\N	PRESENT	0
331888	321353	01058X	PARTICIPANT	\N	PRESENT	0
331891	321353	14157T	PARTICIPANT	\N	PRESENT	0
331892	321353	14357A	PARTICIPANT	\N	PRESENT	0
331893	321353	11090Q	PARTICIPANT	\N	PRESENT	0
331894	321353	14159V	PARTICIPANT	\N	PRESENT	0
331895	321353	01043Q	PARTICIPANT	\N	PRESENT	0
331896	321353	14205J	PARTICIPANT	\N	PRESENT	0
331897	331881	14073Q	PARTICIPANT	\N	PRESENT	0
331898	331881	11026G	PARTICIPANT	\N	PRESENT	0
331899	331881	14001X	PARTICIPANT	\N	PRESENT	0
331900	331881	04057K	PARTICIPANT	\N	PRESENT	0
331901	331881	14331P	PARTICIPANT	\N	PRESENT	0
331902	331881	14229S	PARTICIPANT	\N	PRESENT	0
331903	331881	98035U	PARTICIPANT	\N	PRESENT	0
331904	331881	04097T	PARTICIPANT	\N	EXCUSE	0
331905	331881	08018U	PARTICIPANT	\N	EXCUSE	0
331906	331881	14065Q	PARTICIPANT	\N	EXCUSE	0
331907	321353	19643A	PARTICIPANT	\N	PRESENT	0
331908	321353	19701S	PARTICIPANT	\N	PRESENT	0
331909	321353	11048N	PARTICIPANT	\N	PRESENT	0
331910	321353	04086Q	PARTICIPANT	\N	PRESENT	0
331911	321353	95041E	PARTICIPANT	\N	PRESENT	0
331912	321353	11077T	PARTICIPANT	\N	PRESENT	0
331913	321353	08009T	PARTICIPANT	\N	PRESENT	0
331914	321353	14119M	PARTICIPANT	\N	PRESENT	0
331921	331920	01048V	PARTICIPANT	\N	PRESENT	0
331922	321353	19591F	PARTICIPANT	\N	PRESENT	0
307004	305981	14357A	PARTICIPANT	\N	EXCUSE	0
307005	305981	17589D	PARTICIPANT	\N	PRESENT	0
307006	305981	08052W	PRESIDENT	0	PRESENT	0
312314	309271	19673G	PARTICIPANT	\N	PRESENT	0
312315	309271	11010L	PARTICIPANT	\N	PRESENT	0
312316	309271	19687N	PARTICIPANT	\N	PRESENT	0
312317	309271	19593H	PARTICIPANT	\N	PRESENT	0
312318	309271	19695N	PARTICIPANT	\N	PRESENT	0
312319	309271	14199E	PARTICIPANT	\N	PRESENT	0
312320	309271	19575F	PARTICIPANT	\N	PRESENT	0
312321	309271	11012A	PARTICIPANT	\N	PRESENT	0
312322	309271	08031R	PARTICIPANT	\N	PRESENT	0
312323	309271	14034U	PARTICIPANT	\N	PRESENT	0
312324	309271	14261S	PARTICIPANT	\N	PRESENT	0
312325	309271	88008L	PARTICIPANT	\N	PRESENT	0
312326	309271	19253P	PARTICIPANT	\N	PRESENT	0
312327	309271	08049C	PARTICIPANT	\N	PRESENT	0
312328	309271	19629C	PARTICIPANT	\N	PRESENT	0
312329	309271	14201E	PARTICIPANT	\N	PRESENT	0
312330	309271	98022P	PARTICIPANT	\N	PRESENT	0
312331	309271	11048N	PARTICIPANT	\N	PRESENT	0
312332	309271	19719D	PARTICIPANT	\N	PRESENT	0
312333	309271	14173T	PARTICIPANT	\N	PRESENT	0
312334	309271	19553Y	PARTICIPANT	\N	PRESENT	0
312335	309271	19573D	PARTICIPANT	\N	PRESENT	0
312336	309271	19289C	PARTICIPANT	\N	PRESENT	0
312337	309271	19563B	PARTICIPANT	\N	PRESENT	0
312338	309271	14107H	PARTICIPANT	\N	PRESENT	0
312339	309271	98005N	PARTICIPANT	\N	PRESENT	0
312340	309271	14133K	PARTICIPANT	\N	PRESENT	0
312341	309271	92040Q	PARTICIPANT	\N	PRESENT	0
312342	309271	14241N	PARTICIPANT	\N	PRESENT	0
312343	309271	14115H	PARTICIPANT	\N	PRESENT	0
312344	309271	95063L	PARTICIPANT	\N	PRESENT	0
312345	309271	08047A	PARTICIPANT	\N	PRESENT	0
312346	309271	08061X	PARTICIPANT	\N	PRESENT	0
312347	309271	14105F	PARTICIPANT	\N	PRESENT	0
312348	309271	98029W	PARTICIPANT	\N	PRESENT	0
312349	309271	04045F	PARTICIPANT	\N	PRESENT	0
312350	309271	04049K	PARTICIPANT	\N	PRESENT	0
312351	309271	14239U	PARTICIPANT	\N	PRESENT	0
312352	309271	04034C	PARTICIPANT	\N	PRESENT	0
312353	309271	14038Y	PARTICIPANT	\N	PRESENT	0
312354	309271	19651A	PARTICIPANT	\N	PRESENT	0
312355	309271	19637C	PARTICIPANT	\N	PRESENT	0
312356	309271	19269X	PARTICIPANT	\N	PRESENT	0
312357	309271	19723Y	PARTICIPANT	\N	PRESENT	0
312358	309271	19349W	PARTICIPANT	\N	PRESENT	0
312359	309271	19467C	PARTICIPANT	\N	PRESENT	0
312360	309271	19697Q	PARTICIPANT	\N	PRESENT	0
312361	309271	08021P	PARTICIPANT	\N	PRESENT	0
312362	309271	18083K	PARTICIPANT	\N	PRESENT	0
312363	309271	19301E	PARTICIPANT	\N	PRESENT	0
312364	309271	08073C	PARTICIPANT	\N	PRESENT	0
312365	309271	19415P	PARTICIPANT	\N	PRESENT	0
312366	309271	14033T	PARTICIPANT	\N	PRESENT	0
312367	309271	08019V	PARTICIPANT	\N	PRESENT	0
312368	309271	19681G	PARTICIPANT	\N	PRESENT	0
312369	309271	11083R	PARTICIPANT	\N	PRESENT	0
312370	309271	08024S	PARTICIPANT	\N	PRESENT	0
312371	309271	14265W	PARTICIPANT	\N	PRESENT	0
312372	309271	14213J	PARTICIPANT	\N	PRESENT	0
312373	309271	19545Y	PARTICIPANT	\N	PRESENT	0
312374	309271	19443T	PARTICIPANT	\N	PRESENT	0
312375	309271	17589D	PARTICIPANT	\N	PRESENT	0
312376	309271	14111D	PARTICIPANT	\N	PRESENT	0
312377	309271	19583F	PARTICIPANT	\N	PRESENT	0
312378	309271	11064N	PARTICIPANT	\N	PRESENT	0
312379	309271	14251Q	PARTICIPANT	\N	PRESENT	0
312380	309271	14029X	PARTICIPANT	\N	PRESENT	0
312381	309271	14195A	PARTICIPANT	\N	PRESENT	0
312382	309271	19709B	PARTICIPANT	\N	PRESENT	0
312383	309271	02002K	PARTICIPANT	\N	PRESENT	0
312384	309271	04057K	PARTICIPANT	\N	PRESENT	0
312385	309271	19585H	PARTICIPANT	\N	PRESENT	0
312386	309271	04088S	PARTICIPANT	\N	PRESENT	0
312387	309271	01060R	PARTICIPANT	\N	PRESENT	0
312388	309271	14041T	PARTICIPANT	\N	PRESENT	0
312389	309271	14055N	PARTICIPANT	\N	PRESENT	0
312390	309271	89017R	PARTICIPANT	\N	PRESENT	0
312391	309271	19663E	PARTICIPANT	\N	PRESENT	0
312392	309271	11074Q	PARTICIPANT	\N	PRESENT	0
312393	309271	07029T	PARTICIPANT	\N	PRESENT	0
312394	309271	98035U	PARTICIPANT	\N	PRESENT	0
312395	309271	14159V	PARTICIPANT	\N	PRESENT	0
312396	309271	96004D	PARTICIPANT	\N	PRESENT	0
312397	309271	19729F	PARTICIPANT	\N	PRESENT	0
312398	309271	08062Y	PARTICIPANT	\N	PRESENT	0
312399	309271	08015R	PARTICIPANT	\N	PRESENT	0
312400	309271	19705W	PARTICIPANT	\N	PRESENT	0
312401	309271	08052W	PARTICIPANT	\N	PRESENT	0
312402	309271	98050T	PARTICIPANT	\N	PRESENT	0
312403	309271	14061L	PARTICIPANT	\N	PRESENT	0
312404	309271	14021P	PARTICIPANT	\N	PRESENT	0
312405	309271	14059S	PARTICIPANT	\N	PRESENT	0
312406	309271	19733B	PARTICIPANT	\N	PRESENT	0
312407	309271	08045X	PARTICIPANT	\N	PRESENT	0
312408	309271	14329V	PARTICIPANT	\N	PRESENT	0
312409	309271	19669L	PARTICIPANT	\N	PRESENT	0
312410	309271	14357A	PARTICIPANT	\N	PRESENT	0
312411	309271	14225N	PARTICIPANT	\N	PRESENT	0
312412	309271	19675J	PARTICIPANT	\N	PRESENT	0
312413	309271	19383Y	PARTICIPANT	\N	PRESENT	0
312414	309271	19599P	PARTICIPANT	\N	PRESENT	0
312415	309271	19715Y	PARTICIPANT	\N	PRESENT	0
312416	309271	19762G	PARTICIPANT	\N	PRESENT	0
312417	309271	04018C	PARTICIPANT	\N	PRESENT	0
312418	309271	14151M	PARTICIPANT	\N	PRESENT	0
312419	309271	19621T	PARTICIPANT	\N	PRESENT	0
312420	309271	19649G	PARTICIPANT	\N	PRESENT	0
312421	309271	19367Y	PARTICIPANT	\N	PRESENT	0
312422	309271	19647E	PARTICIPANT	\N	PRESENT	0
312423	309271	97011G	PARTICIPANT	\N	PRESENT	0
312424	309271	11103C	PARTICIPANT	\N	PRESENT	0
312425	309271	11045K	PARTICIPANT	\N	PRESENT	0
312426	309271	14028W	PARTICIPANT	\N	PRESENT	0
312427	309271	07033P	PARTICIPANT	\N	PRESENT	0
312428	309271	14217N	PARTICIPANT	\N	PRESENT	0
312429	309271	08038Y	PARTICIPANT	\N	PRESENT	0
312430	309271	14331P	PARTICIPANT	\N	PRESENT	0
312431	309271	08060W	PARTICIPANT	\N	PRESENT	0
312432	309271	01062T	PARTICIPANT	\N	PRESENT	0
312433	309271	14079W	PARTICIPANT	\N	PRESENT	0
312434	309271	11066Q	PARTICIPANT	\N	PRESENT	0
312435	309271	19581D	PARTICIPANT	\N	PRESENT	0
312436	309271	08043V	PARTICIPANT	\N	PRESENT	0
312437	309271	19747H	PARTICIPANT	\N	PRESENT	0
312438	309271	11104D	PARTICIPANT	\N	PRESENT	0
312439	309271	08035V	PARTICIPANT	\N	PRESENT	0
312440	309271	05012A	PARTICIPANT	\N	PRESENT	0
312441	309271	08034U	PARTICIPANT	\N	PRESENT	0
312442	309271	19727D	PARTICIPANT	\N	PRESENT	0
312443	309271	19533U	PARTICIPANT	\N	PRESENT	0
312444	309271	17779H	PARTICIPANT	\N	PRESENT	0
312445	309271	10006L	PARTICIPANT	\N	PRESENT	0
312446	309271	19531S	PARTICIPANT	\N	PRESENT	0
312447	309271	07034Q	PARTICIPANT	\N	PRESENT	0
312448	309271	08058D	PARTICIPANT	\N	PRESENT	0
312449	309271	14193X	PARTICIPANT	\N	PRESENT	0
312450	309271	14237S	PARTICIPANT	\N	PRESENT	0
312451	309271	17583W	PARTICIPANT	\N	PRESENT	0
312452	309271	04043D	PARTICIPANT	\N	PRESENT	0
312454	309271	14069U	PARTICIPANT	\N	PRESENT	0
312455	309271	08017T	PARTICIPANT	\N	PRESENT	0
312456	309271	14249W	PARTICIPANT	\N	PRESENT	0
312457	309271	14087W	PARTICIPANT	\N	PRESENT	0
312458	309271	14257W	PARTICIPANT	\N	PRESENT	0
312459	309271	14215L	PARTICIPANT	\N	PRESENT	0
312460	309271	04033B	PARTICIPANT	\N	PRESENT	0
312461	309271	19725B	PARTICIPANT	\N	PRESENT	0
312462	309271	14081Q	PARTICIPANT	\N	PRESENT	0
312463	309271	14071N	PARTICIPANT	\N	PRESENT	0
312464	309271	14065Q	PARTICIPANT	\N	PRESENT	0
312465	309271	14207L	PARTICIPANT	\N	PRESENT	0
312466	309271	05008E	PARTICIPANT	\N	PRESENT	0
312467	309271	11097X	PARTICIPANT	\N	PRESENT	0
312468	309271	19421M	PARTICIPANT	\N	PRESENT	0
312469	309271	19525U	PARTICIPANT	\N	PRESENT	0
312470	309271	08014Q	PARTICIPANT	\N	PRESENT	0
312471	309271	19333N	PARTICIPANT	\N	PRESENT	0
312472	309271	08068F	PARTICIPANT	\N	PRESENT	0
312473	309271	11054L	PARTICIPANT	\N	PRESENT	0
312474	309271	14026U	PARTICIPANT	\N	PRESENT	0
312475	309271	19551W	PARTICIPANT	\N	PRESENT	0
312476	309271	14109K	PARTICIPANT	\N	PRESENT	0
312477	309271	98024R	PARTICIPANT	\N	PRESENT	0
312478	309271	04035D	PARTICIPANT	\N	PRESENT	0
335570	335567	14093U	PARTICIPANT	\N	PRESENT	0
335571	335567	18083K	PARTICIPANT	\N	PRESENT	0
335572	335567	19503N	PARTICIPANT	\N	PRESENT	0
335573	335567	08009T	PARTICIPANT	\N	PRESENT	0
335574	335567	19347U	PARTICIPANT	\N	PRESENT	0
335575	335566	14051J	PARTICIPANT	\N	PRESENT	0
340097	340096	14038Y	PARTICIPANT	\N	PRESENT	0
340098	340096	19333N	PARTICIPANT	\N	PRESENT	0
340099	340096	19681G	PARTICIPANT	\N	PRESENT	0
340100	340096	19713W	PARTICIPANT	\N	PRESENT	0
340101	340096	19637C	PARTICIPANT	\N	PRESENT	0
340102	340096	08009T	PARTICIPANT	\N	PRESENT	0
340104	340103	14255U	PARTICIPANT	\N	PRESENT	0
340105	340103	08053X	PARTICIPANT	\N	PRESENT	0
340107	340106	14255U	PARTICIPANT	\N	PRESENT	0
340108	340106	08053X	PARTICIPANT	\N	PRESENT	0
341305	340427	19511N	PARTICIPANT	\N	EXCUSE	0
341438	341437	08049C	PARTICIPANT	\N	PRESENT	0
341441	340483	04040A	PARTICIPANT	\N	EXCUSE	0
341442	340483	19443T	PARTICIPANT	\N	EXCUSE	0
341455	340484	04040A	PARTICIPANT	\N	EXCUSE	0
341457	340484	19443T	PARTICIPANT	\N	EXCUSE	0
342017	342016	11053K	PARTICIPANT	\N	PRESENT	0
342018	342016	14159V	PARTICIPANT	\N	PRESENT	0
342019	342016	05012A	PARTICIPANT	\N	PRESENT	0
344569	343404	08043V	PARTICIPANT	\N	EXCUSE	0
344570	343404	14249W	PARTICIPANT	\N	EXCUSE	0
344571	343404	14073Q	PARTICIPANT	\N	EXCUSE	0
344716	339506	14261S	PARTICIPANT	\N	PRESENT	0
344717	339506	19515S	PARTICIPANT	\N	PRESENT	0
344718	339506	05008E	PARTICIPANT	\N	PRESENT	0
344719	339506	14069U	PARTICIPANT	\N	PRESENT	0
344720	339506	19415P	PARTICIPANT	\N	PRESENT	0
344721	339506	19747H	PARTICIPANT	\N	PRESENT	0
344722	339506	04047H	PARTICIPANT	\N	PRESENT	0
344723	339506	14255U	PARTICIPANT	\N	PRESENT	0
344724	339506	14083S	PARTICIPANT	\N	PRESENT	0
344725	339506	19545Y	PARTICIPANT	\N	PRESENT	0
344726	339506	11103C	PARTICIPANT	\N	PRESENT	0
344727	339506	08024S	PARTICIPANT	\N	PRESENT	0
344728	339506	14038Y	PARTICIPANT	\N	PRESENT	0
344729	339506	88008L	PARTICIPANT	\N	PRESENT	0
344730	339506	04038G	PARTICIPANT	\N	PRESENT	0
344731	339506	11027H	PARTICIPANT	\N	PRESENT	0
344732	339506	19681G	PARTICIPANT	\N	PRESENT	0
344733	339506	80013X	PARTICIPANT	\N	PRESENT	0
344734	339506	17589D	PARTICIPANT	\N	PRESENT	0
344735	339506	11070L	PARTICIPANT	\N	PRESENT	0
344736	339506	19719D	PARTICIPANT	\N	PRESENT	0
344737	339506	14041T	PARTICIPANT	\N	PRESENT	0
344738	339506	14217N	PARTICIPANT	\N	PRESENT	0
344739	339506	01024M	PARTICIPANT	\N	PRESENT	0
344740	339506	14215L	PARTICIPANT	\N	PRESENT	0
344741	339506	19507S	PARTICIPANT	\N	PRESENT	0
344742	339506	95030B	PARTICIPANT	\N	PRESENT	0
344743	339506	14087W	PARTICIPANT	\N	PRESENT	0
344744	339506	08018U	PARTICIPANT	\N	PRESENT	0
344745	339506	04035D	PARTICIPANT	\N	PRESENT	0
344746	339506	19387D	PARTICIPANT	\N	PRESENT	0
344747	339506	08056B	PARTICIPANT	\N	PRESENT	0
344748	339506	19565D	PARTICIPANT	\N	PRESENT	0
344749	339506	14033T	PARTICIPANT	\N	PRESENT	0
344750	339506	98022P	PARTICIPANT	\N	PRESENT	0
344751	339506	14081Q	PARTICIPANT	\N	PRESENT	0
344752	339506	11048N	PARTICIPANT	\N	PRESENT	0
344753	339506	14213J	PARTICIPANT	\N	PRESENT	0
344754	339506	08044W	PARTICIPANT	\N	PRESENT	0
344755	339506	19447X	PARTICIPANT	\N	PRESENT	0
344756	339506	14021P	PARTICIPANT	\N	PRESENT	0
344757	339506	14029X	PARTICIPANT	\N	PRESENT	0
344758	339506	19699S	PARTICIPANT	\N	PRESENT	0
344759	339506	19709B	PARTICIPANT	\N	PRESENT	0
344760	339506	11026G	PARTICIPANT	\N	PRESENT	0
344761	339506	08017T	PARTICIPANT	\N	PRESENT	0
344762	339506	19581D	PARTICIPANT	\N	PRESENT	0
344763	339506	80027E	PARTICIPANT	\N	PRESENT	0
344765	339506	14111D	PARTICIPANT	\N	PRESENT	0
344766	339506	14147R	PARTICIPANT	\N	PRESENT	0
344786	339506	14223L	PARTICIPANT	\N	PRESENT	0
344787	339506	14265W	PARTICIPANT	\N	PRESENT	0
344788	339506	14119M	PARTICIPANT	\N	PRESENT	0
344790	339506	14191V	PARTICIPANT	\N	PRESENT	0
344791	339506	14237S	PARTICIPANT	\N	PRESENT	0
344792	339506	17637T	PARTICIPANT	\N	PRESENT	0
344793	339506	04088S	PARTICIPANT	\N	PRESENT	0
344795	339506	11012A	PARTICIPANT	\N	PRESENT	0
344796	339506	95062K	PARTICIPANT	\N	PRESENT	0
344797	339506	95063L	PARTICIPANT	\N	PRESENT	0
344798	339506	14107H	PARTICIPANT	\N	PRESENT	0
344799	339506	11043H	PARTICIPANT	\N	PRESENT	0
344800	339506	19703U	PARTICIPANT	\N	PRESENT	0
344801	339506	01028R	PARTICIPANT	\N	PRESENT	0
344802	339506	14157T	PARTICIPANT	\N	PRESENT	0
344803	339506	19479G	PARTICIPANT	\N	PRESENT	0
344812	339506	14241N	PARTICIPANT	\N	PRESENT	0
349786	349785	19721W	PARTICIPANT	\N	PRESENT	0
349787	349785	19693L	PARTICIPANT	\N	PRESENT	0
349789	349785	14259Y	PARTICIPANT	\N	PRESENT	0
349790	349785	97011G	PARTICIPANT	\N	PRESENT	0
349802	349785	14026U	PARTICIPANT	\N	PRESENT	0
349804	349785	04097T	PARTICIPANT	\N	PRESENT	0
349805	349785	19637C	PARTICIPANT	\N	PRESENT	0
349810	346480	14281W	PARTICIPANT	\N	EXCUSE	0
349811	346480	14071N	PARTICIPANT	\N	EXCUSE	0
349856	347017	11027H	PARTICIPANT	\N	EXCUSE	0
349857	347017	14028W	PARTICIPANT	\N	EXCUSE	0
349858	347017	98050T	PARTICIPANT	\N	EXCUSE	0
349859	347020	11027H	PARTICIPANT	\N	EXCUSE	0
349860	347020	14028W	PARTICIPANT	\N	EXCUSE	0
349861	347020	98050T	PARTICIPANT	\N	EXCUSE	0
350093	346333	19729F	PARTICIPANT	\N	EXCUSE	0
350094	346333	19577H	PARTICIPANT	\N	EXCUSE	0
350095	346333	19583F	PARTICIPANT	\N	EXCUSE	0
351726	351725	19667J	PARTICIPANT	\N	PRESENT	0
351727	351725	14255U	PARTICIPANT	\N	PRESENT	0
351728	351725	19701S	PARTICIPANT	\N	PRESENT	0
351729	351725	19693L	PARTICIPANT	\N	PRESENT	0
351730	351725	11026G	PARTICIPANT	\N	PRESENT	0
351731	351725	19671E	PARTICIPANT	\N	PRESENT	0
355790	355789	19719D	PARTICIPANT	\N	PRESENT	0
355793	355792	19719D	PARTICIPANT	\N	PRESENT	0
357055	356854	14061L	PARTICIPANT	\N	PRESENT	0
357056	356854	04057K	PARTICIPANT	\N	PRESENT	0
357057	356854	14073Q	PARTICIPANT	\N	PRESENT	0
357058	356854	19611R	PARTICIPANT	\N	PRESENT	0
357059	356854	08035V	PARTICIPANT	\N	PRESENT	0
357060	356854	19693L	PARTICIPANT	\N	PRESENT	0
357061	356854	19399H	PARTICIPANT	\N	PRESENT	0
357062	356854	87003B	PARTICIPANT	\N	PRESENT	0
357063	356854	14201E	PARTICIPANT	\N	PRESENT	0
357064	356854	14030Q	PARTICIPANT	\N	PRESENT	0
357065	356854	19731Y	PARTICIPANT	\N	PRESENT	0
357066	356854	14251Q	PARTICIPANT	\N	PRESENT	0
357067	356854	08020N	PARTICIPANT	\N	PRESENT	0
357068	356854	04059M	PARTICIPANT	\N	PRESENT	0
357069	356854	19735D	PARTICIPANT	\N	PRESENT	0
357070	356854	11109J	PARTICIPANT	\N	PRESENT	0
357071	356854	14109K	PARTICIPANT	\N	PRESENT	0
357072	356854	11083R	PARTICIPANT	\N	PRESENT	0
357073	356854	14123H	PARTICIPANT	\N	PRESENT	0
357074	356854	11104D	PARTICIPANT	\N	PRESENT	0
357075	356854	11043H	PARTICIPANT	\N	PRESENT	0
357076	356854	19758L	PARTICIPANT	\N	PRESENT	0
357077	356854	04018C	PARTICIPANT	\N	PRESENT	0
357078	356854	19621T	PARTICIPANT	\N	PRESENT	0
357079	356854	14107H	PARTICIPANT	\N	EXCUSE	0
357080	355935	14097Y	PARTICIPANT	\N	PRESENT	0
357081	355935	04040A	PARTICIPANT	\N	EXCUSE	0
357083	357082	14133K	PARTICIPANT	\N	PRESENT	0
357084	357082	11040E	PARTICIPANT	\N	PRESENT	0
357085	357082	04042C	PARTICIPANT	\N	PRESENT	0
357086	357082	14079W	PARTICIPANT	\N	PRESENT	0
357087	357082	15447F	PARTICIPANT	\N	PRESENT	0
357088	357082	98022P	PARTICIPANT	\N	PRESENT	0
357089	357082	04097T	PARTICIPANT	\N	PRESENT	0
357090	357082	19611R	PARTICIPANT	\N	PRESENT	0
357091	357082	19711U	PARTICIPANT	\N	PRESENT	0
357092	357082	01048V	PARTICIPANT	\N	PRESENT	0
357093	357082	19573D	PARTICIPANT	\N	PRESENT	0
357094	357082	04088S	PARTICIPANT	\N	PRESENT	0
357098	357082	98035U	PARTICIPANT	\N	PRESENT	0
357096	357082	98050T	PARTICIPANT	\N	PRESENT	0
357097	357082	19503N	PARTICIPANT	\N	PRESENT	0
357099	357082	95067Q	PARTICIPANT	\N	PRESENT	0
357102	356853	08041T	PARTICIPANT	\N	EXCUSE	0
357104	357103	04038G	PARTICIPANT	\N	PRESENT	0
357105	349806	11065P	PARTICIPANT	\N	PRESENT	0
357106	356330	14231L	PARTICIPANT	\N	PRESENT	0
357107	355935	11064N	PARTICIPANT	\N	PRESENT	0
346108	345105	19631V	PARTICIPANT	\N	PRESENT	0
346109	345105	19507S	PARTICIPANT	\N	PRESENT	0
346110	344975	04045F	PARTICIPANT	\N	PRESENT	0
346111	344975	14026U	PARTICIPANT	\N	PRESENT	0
346112	344975	19575F	PARTICIPANT	\N	PRESENT	0
346113	344975	10006L	PARTICIPANT	\N	PRESENT	0
346114	344975	19691J	PARTICIPANT	\N	PRESENT	0
346115	345036	11064N	PARTICIPANT	\N	PRESENT	0
346116	345036	19583F	PARTICIPANT	\N	PRESENT	0
346155	345251	04085P	PARTICIPANT	\N	PRESENT	0
346156	345251	14103D	PARTICIPANT	\N	PRESENT	0
346158	345251	14093U	PARTICIPANT	\N	PRESENT	0
346159	345036	11027H	PARTICIPANT	\N	PRESENT	0
346104	344975	11103C	PARTICIPANT	\N	PRESENT	0
346105	344975	19760E	PARTICIPANT	\N	PRESENT	0
346106	345105	19441R	PARTICIPANT	\N	PRESENT	0
346107	345105	14135M	PARTICIPANT	\N	PRESENT	0
346160	346157	98035U	PARTICIPANT	\N	PRESENT	0
346161	346157	19489J	PARTICIPANT	\N	PRESENT	0
346162	346157	19729F	PARTICIPANT	\N	PRESENT	0
346163	346157	19629C	PARTICIPANT	\N	PRESENT	0
346164	346157	14069U	PARTICIPANT	\N	PRESENT	0
346165	346157	01024M	PARTICIPANT	\N	PRESENT	0
346166	346157	14151M	PARTICIPANT	\N	PRESENT	0
346167	346157	14215L	PARTICIPANT	\N	PRESENT	0
346168	346157	19581D	PARTICIPANT	\N	PRESENT	0
346169	346157	11049P	PARTICIPANT	\N	PRESENT	0
346170	346157	05008E	PRESIDENT	0	PRESENT	0
346171	346157	19447X	PARTICIPANT	\N	PRESENT	0
346172	346157	04044E	PARTICIPANT	\N	EXCUSE	0
346174	346173	04070G	PRESIDENT	0	PRESENT	0
346175	346173	19699S	PARTICIPANT	\N	PRESENT	0
346176	346173	14229S	PARTICIPANT	\N	PRESENT	0
346177	346173	14241N	PARTICIPANT	\N	PRESENT	0
346178	346173	19573D	PARTICIPANT	\N	PRESENT	0
346179	346173	14107H	PARTICIPANT	\N	PRESENT	0
346180	346173	08017T	PARTICIPANT	\N	PRESENT	0
346181	346173	92040Q	PARTICIPANT	\N	PRESENT	0
346182	346173	08012N	PARTICIPANT	\N	PRESENT	0
346183	346173	14249W	PARTICIPANT	\N	PRESENT	0
346184	346173	08039A	PARTICIPANT	\N	PRESENT	0
346185	346173	08031R	PARTICIPANT	\N	PRESENT	0
346186	346173	19593H	PARTICIPANT	\N	PRESENT	0
346187	346173	14059S	PARTICIPANT	\N	PRESENT	0
346188	346173	19643A	PARTICIPANT	\N	PRESENT	0
346189	346173	04057K	PARTICIPANT	\N	PRESENT	0
346190	346173	19611R	PARTICIPANT	\N	PRESENT	0
346191	346173	19693L	PARTICIPANT	\N	PRESENT	0
346192	346173	87003B	PARTICIPANT	\N	PRESENT	0
346193	346173	19399H	PARTICIPANT	\N	PRESENT	0
346194	346173	14201E	PARTICIPANT	\N	PRESENT	0
346195	346173	14030Q	PARTICIPANT	\N	PRESENT	0
346196	346173	19731Y	PARTICIPANT	\N	PRESENT	0
346197	346173	04059M	PARTICIPANT	\N	PRESENT	0
346198	346173	14063N	PARTICIPANT	\N	PRESENT	0
346199	346173	11083R	PARTICIPANT	\N	PRESENT	0
346200	346173	11104D	PARTICIPANT	\N	PRESENT	0
346201	346173	11043H	PARTICIPANT	\N	PRESENT	0
346202	346173	19749K	PARTICIPANT	\N	PRESENT	0
346203	346173	04018C	PARTICIPANT	\N	PRESENT	0
346204	346173	19621T	PARTICIPANT	\N	PRESENT	0
346205	344991	14327T	PARTICIPANT	\N	PRESENT	0
346206	344991	14331P	PARTICIPANT	\N	PRESENT	0
346207	344991	04071H	PARTICIPANT	\N	PRESENT	0
346208	344991	01048V	PARTICIPANT	\N	PRESENT	0
346209	344991	19545Y	PARTICIPANT	\N	PRESENT	0
346210	344991	01057W	PARTICIPANT	\N	PRESENT	0
346211	344991	11053K	PARTICIPANT	\N	PRESENT	0
346212	344991	11074Q	PRESIDENT	0	PRESENT	0
346213	344991	89017R	PARTICIPANT	\N	PRESENT	0
346214	344991	88008L	PARTICIPANT	\N	PRESENT	0
346215	344991	14225N	PARTICIPANT	\N	PRESENT	0
346216	344991	11070L	PARTICIPANT	\N	PRESENT	0
346217	344991	11110B	PARTICIPANT	\N	PRESENT	0
346218	344991	07029T	PARTICIPANT	\N	PRESENT	0
346219	344991	07004J	PARTICIPANT	\N	PRESENT	0
346220	344991	19349W	PARTICIPANT	\N	PRESENT	0
346221	344991	08010L	PARTICIPANT	\N	PRESENT	0
346222	344991	14253S	PARTICIPANT	\N	PRESENT	0
346223	344991	11048N	PARTICIPANT	\N	PRESENT	0
346224	344991	19647E	PARTICIPANT	\N	PRESENT	0
346225	344991	19479G	PARTICIPANT	\N	PRESENT	0
346226	344991	19711U	PARTICIPANT	\N	PRESENT	0
346227	344991	19531S	PARTICIPANT	\N	PRESENT	0
346228	344991	08034U	PARTICIPANT	\N	PRESENT	0
346229	344991	08069G	PARTICIPANT	\N	PRESENT	0
346230	344991	19687N	PARTICIPANT	\N	PRESENT	0
346231	344991	19689Q	PARTICIPANT	\N	PRESENT	0
346232	344991	12016W	PARTICIPANT	\N	PRESENT	0
346233	344991	08011M	PARTICIPANT	\N	PRESENT	0
346234	344991	14034U	PARTICIPANT	\N	PRESENT	0
346235	344991	14159V	PARTICIPANT	\N	PRESENT	0
346236	344991	14173T	PARTICIPANT	\N	PRESENT	0
346237	344991	04086Q	PARTICIPANT	\N	PRESENT	0
346238	344991	11040E	PARTICIPANT	\N	PRESENT	0
346239	344991	14083S	PARTICIPANT	\N	PRESENT	0
346240	344991	14199E	PARTICIPANT	\N	PRESENT	0
346241	344991	11012A	PARTICIPANT	\N	PRESENT	0
346242	344991	08073C	PARTICIPANT	\N	PRESENT	0
346243	344991	14121F	PARTICIPANT	\N	PRESENT	0
346244	344991	99004R	PARTICIPANT	\N	PRESENT	0
346245	344991	04061F	PARTICIPANT	\N	PRESENT	0
346246	344991	95041E	PARTICIPANT	\N	EXCUSE	0
346247	344991	14085U	PARTICIPANT	\N	EXCUSE	0
346248	345036	04035D	PARTICIPANT	\N	PRESENT	0
346249	345036	98018T	PARTICIPANT	\N	EXCUSE	0
346250	345036	19421M	PARTICIPANT	\N	EXCUSE	0
346251	345036	04042C	PARTICIPANT	\N	EXCUSE	0
346253	346173	07033P	PARTICIPANT	\N	PRESENT	0
346254	346173	14109K	PARTICIPANT	\N	PRESENT	0
346255	346173	14073Q	PARTICIPANT	\N	EXCUSE	0
346256	346173	08020N	PARTICIPANT	\N	EXCUSE	0
346257	346173	08043V	PARTICIPANT	\N	EXCUSE	0
346258	346173	14123H	PARTICIPANT	\N	PRESENT	0
346260	346259	04040A	PARTICIPANT	\N	PRESENT	0
346261	344975	14087W	PARTICIPANT	\N	PRESENT	0
346262	344975	19521Q	PARTICIPANT	\N	PRESENT	0
346263	344975	19663E	PARTICIPANT	\N	PRESENT	0
346264	344975	19727D	PARTICIPANT	\N	PRESENT	0
346265	344975	14071N	PARTICIPANT	\N	PRESENT	0
346266	345036	14255U	PARTICIPANT	\N	PRESENT	0
346271	346173	11109J	PARTICIPANT	\N	PRESENT	0
346272	345590	04071H	PARTICIPANT	\N	PRESENT	0
346273	345590	11048N	PARTICIPANT	\N	PRESENT	0
346274	345590	08073C	PARTICIPANT	\N	PRESENT	0
346275	345590	04034C	PARTICIPANT	\N	PRESENT	0
346276	345590	19695N	PARTICIPANT	\N	PRESENT	0
346277	345590	14151M	PARTICIPANT	\N	PRESENT	0
346278	345590	14157T	PARTICIPANT	\N	PRESENT	0
346279	345590	14026U	PARTICIPANT	\N	PRESENT	0
346280	345590	14159V	PARTICIPANT	\N	PRESENT	0
346281	345590	19631V	PARTICIPANT	\N	PRESENT	0
346282	345590	14329V	PARTICIPANT	\N	PRESENT	0
346283	345590	19515S	PARTICIPANT	\N	PRESENT	0
346284	345590	19711U	PARTICIPANT	\N	PRESENT	0
346285	345590	08034U	PARTICIPANT	\N	PRESENT	0
346286	345590	14187A	PARTICIPANT	\N	PRESENT	0
346287	345590	19545Y	PARTICIPANT	\N	PRESENT	0
346288	345590	11053K	PARTICIPANT	\N	PRESENT	0
346289	345590	11090Q	PARTICIPANT	\N	PRESENT	0
346290	345590	14083S	PARTICIPANT	\N	PRESENT	0
346291	345590	14051J	PARTICIPANT	\N	PRESENT	0
346292	345590	04049K	PARTICIPANT	\N	PRESENT	0
346293	345590	19521Q	PRESIDENT	0	PRESENT	0
346294	345590	19762G	PARTICIPANT	\N	PRESENT	0
346295	339513	04044E	PARTICIPANT	\N	PRESENT	0
346493	339513	19703U	PARTICIPANT	\N	PRESENT	0
346494	339513	19643A	PARTICIPANT	\N	PRESENT	0
346495	339513	14059S	PARTICIPANT	\N	PRESENT	0
346496	339513	14030Q	PARTICIPANT	\N	PRESENT	0
346497	339513	19383Y	PARTICIPANT	\N	PRESENT	0
346498	339513	14069U	PARTICIPANT	\N	PRESENT	0
346499	339513	14063N	PARTICIPANT	\N	PRESENT	0
346500	339513	19731Y	PARTICIPANT	\N	PRESENT	0
346503	339513	01048V	PARTICIPANT	\N	PRESENT	0
346515	339513	19611R	PARTICIPANT	\N	PRESENT	0
346516	339513	14217N	PARTICIPANT	\N	PRESENT	0
346517	339513	08015R	PARTICIPANT	\N	PRESENT	0
346518	339513	14021P	PARTICIPANT	\N	PRESENT	0
346519	339513	14241N	PARTICIPANT	\N	PRESENT	0
346520	339513	14123H	PARTICIPANT	\N	PRESENT	0
346521	339513	87003B	PARTICIPANT	\N	PRESENT	0
346522	339513	11101A	PARTICIPANT	\N	PRESENT	0
346523	339513	14147R	PARTICIPANT	\N	PRESENT	0
346524	339513	19697Q	PARTICIPANT	\N	PRESENT	0
346525	339513	95062K	PARTICIPANT	\N	PRESENT	0
346526	339513	95030B	PARTICIPANT	\N	PRESENT	0
346527	339513	08061X	PARTICIPANT	\N	PRESENT	0
346528	339513	14121F	PARTICIPANT	\N	PRESENT	0
340461	340460	04059M	PARTICIPANT	\N	PRESENT	0
340462	340460	14229S	PARTICIPANT	\N	PRESENT	0
340464	340463	04059M	PARTICIPANT	\N	PRESENT	0
340465	340463	14229S	PARTICIPANT	\N	PRESENT	0
340466	340463	19611R	PARTICIPANT	\N	PRESENT	0
340511	230889	14135M	PARTICIPANT	\N	PRESENT	0
340512	230889	19673G	PARTICIPANT	\N	PRESENT	0
340514	340513	19673G	PARTICIPANT	\N	PRESENT	0
340516	340515	14083S	PARTICIPANT	\N	PRESENT	0
340631	340630	89017R	PARTICIPANT	\N	PRESENT	0
340632	340630	04085P	PARTICIPANT	\N	PRESENT	0
340633	340630	04059M	PARTICIPANT	\N	PRESENT	0
340635	340630	05008E	PARTICIPANT	\N	PRESENT	0
340636	340630	14093U	PARTICIPANT	\N	PRESENT	0
340637	340630	14030Q	PARTICIPANT	\N	PRESENT	0
340638	340630	96004D	PARTICIPANT	\N	PRESENT	0
340639	340630	04040A	PARTICIPANT	\N	PRESENT	0
340640	340630	04042C	PARTICIPANT	\N	PRESENT	0
340641	340630	11027H	PARTICIPANT	\N	PRESENT	0
340643	340630	04086Q	PARTICIPANT	\N	PRESENT	0
340644	340630	14079W	PARTICIPANT	\N	PRESENT	0
340645	340630	11070L	PARTICIPANT	\N	PRESENT	0
340646	340630	11074Q	PARTICIPANT	\N	PRESENT	0
340648	340630	19521Q	PARTICIPANT	\N	PRESENT	0
340649	340630	14034U	PARTICIPANT	\N	PRESENT	0
340651	340630	14021P	PARTICIPANT	\N	PRESENT	0
340652	340630	99004R	PARTICIPANT	\N	PRESENT	0
340653	340630	14159V	PARTICIPANT	\N	PRESENT	0
340654	340630	04049K	PARTICIPANT	\N	PRESENT	0
340655	340630	01043Q	PARTICIPANT	\N	PRESENT	0
340656	340630	08019V	PARTICIPANT	\N	PRESENT	0
340657	340630	11085T	PARTICIPANT	\N	PRESENT	0
340658	340630	08009T	PARTICIPANT	\N	PRESENT	0
340659	340630	04092N	PARTICIPANT	\N	PRESENT	0
340660	340630	11072N	PARTICIPANT	\N	PRESENT	0
340661	340630	08011M	PARTICIPANT	\N	PRESENT	0
340662	340630	04070G	PARTICIPANT	\N	PRESENT	0
340663	340630	08061X	PARTICIPANT	\N	PRESENT	0
340664	340630	07034Q	PARTICIPANT	\N	PRESENT	0
340665	340630	11090Q	PARTICIPANT	\N	PRESENT	0
340666	340630	04043D	PARTICIPANT	\N	PRESENT	0
340667	340630	11012A	PARTICIPANT	\N	PRESENT	0
340668	340630	04033B	PARTICIPANT	\N	PRESENT	0
340669	340630	04044E	PARTICIPANT	\N	PRESENT	0
340670	340630	01034P	PARTICIPANT	\N	PRESENT	0
341443	340397	08024S	PARTICIPANT	\N	PRESENT	0
341444	340397	19711U	PARTICIPANT	\N	PRESENT	0
341445	340397	19349W	PARTICIPANT	\N	PRESENT	0
341446	340397	19421M	PARTICIPANT	\N	PRESENT	0
341447	340397	19713W	PARTICIPANT	\N	PRESENT	0
341448	340397	19515S	PARTICIPANT	\N	PRESENT	0
341449	340397	19467C	PARTICIPANT	\N	PRESENT	0
342906	340427	01048V	PRESIDENT	0	PRESENT	0
342908	340427	01058X	PARTICIPANT	\N	PRESENT	0
342909	340427	19693L	PARTICIPANT	\N	EXCUSE	0
342910	340427	08053X	PARTICIPANT	\N	EXCUSE	0
342911	340427	19709B	PARTICIPANT	\N	EXCUSE	0
353807	353806	04086Q	PARTICIPANT	\N	PRESENT	0
356709	345116	14103D	PARTICIPANT	\N	PRESENT	0
356675	345116	11048N	PARTICIPANT	\N	PRESENT	0
356676	355933	04070G	PARTICIPANT	\N	PRESENT	0
356677	355933	19443T	PARTICIPANT	\N	PRESENT	0
356678	355933	14079W	PARTICIPANT	\N	PRESENT	0
356679	355933	01058X	PARTICIPANT	\N	PRESENT	0
356680	355933	16685X	PARTICIPANT	\N	PRESENT	0
356681	355933	11027H	PARTICIPANT	\N	PRESENT	0
356682	355933	04042C	PRESIDENT	0	PRESENT	0
356683	355933	11066Q	PARTICIPANT	\N	PRESENT	0
356684	355933	95037J	PARTICIPANT	\N	PRESENT	0
356685	355933	19421M	PARTICIPANT	\N	PRESENT	0
356686	355933	14039A	PARTICIPANT	\N	PRESENT	0
356687	355933	08017T	PARTICIPANT	\N	PRESENT	0
356688	355933	08053X	PARTICIPANT	\N	PRESENT	0
356689	355933	08061X	PARTICIPANT	\N	PRESENT	0
356690	355933	97011G	PARTICIPANT	\N	PRESENT	0
356691	355933	08047A	PARTICIPANT	\N	PRESENT	0
356692	355933	08031R	PARTICIPANT	\N	PRESENT	0
356693	355933	14097Y	PARTICIPANT	\N	PRESENT	0
356694	355933	95067Q	PARTICIPANT	\N	PRESENT	0
356695	355933	14133K	PARTICIPANT	\N	PRESENT	0
356696	355933	01062T	PARTICIPANT	\N	PRESENT	0
356697	355933	11041F	PARTICIPANT	\N	PRESENT	0
356698	355933	14235Q	PARTICIPANT	\N	PRESENT	0
356699	355933	08058D	PARTICIPANT	\N	PRESENT	0
356700	355933	14251Q	PARTICIPANT	\N	PRESENT	0
356701	355933	04059M	PARTICIPANT	\N	PRESENT	0
356702	355933	14267Y	PARTICIPANT	\N	PRESENT	0
356703	355933	11064N	PARTICIPANT	\N	PRESENT	0
356704	355933	98050T	PARTICIPANT	\N	PRESENT	0
356705	355933	14121F	PARTICIPANT	\N	PRESENT	0
356706	355933	14123H	PARTICIPANT	\N	PRESENT	0
356707	355933	98018T	PARTICIPANT	\N	EXCUSE	0
356708	355933	04040A	PARTICIPANT	\N	EXCUSE	0
356710	355933	07033P	PARTICIPANT	\N	PRESENT	0
356711	355933	14249W	PARTICIPANT	\N	PRESENT	0
356712	355933	08039A	PARTICIPANT	\N	PRESENT	0
356713	355933	14059S	PARTICIPANT	\N	PRESENT	0
356714	355933	19611R	PARTICIPANT	\N	PRESENT	0
356715	355933	11104D	PARTICIPANT	\N	PRESENT	0
356716	345116	11077T	PARTICIPANT	\N	PRESENT	0
356717	355933	19533U	PARTICIPANT	\N	PRESENT	0
356718	355933	14107H	PARTICIPANT	\N	PRESENT	0
356719	355933	04057K	PARTICIPANT	\N	PRESENT	0
356720	355933	14030Q	PARTICIPANT	\N	PRESENT	0
356721	345116	19737F	PARTICIPANT	\N	PRESENT	0
356722	345116	19745F	PARTICIPANT	\N	PRESENT	0
356723	345116	14083S	PARTICIPANT	\N	PRESENT	0
356724	345116	11012A	PARTICIPANT	\N	PRESENT	0
356725	355933	19251M	PARTICIPANT	\N	PRESENT	0
356726	355933	19735D	PARTICIPANT	\N	PRESENT	0
356727	345116	19503N	PARTICIPANT	\N	PRESENT	0
356728	355933	14109K	PARTICIPANT	\N	PRESENT	0
356729	345116	14219Q	PARTICIPANT	\N	PRESENT	0
356730	355933	19335Q	PARTICIPANT	\N	PRESENT	0
356731	355933	14073Q	PARTICIPANT	\N	PRESENT	0
356732	355933	19573D	PARTICIPANT	\N	PRESENT	0
356733	355933	19693L	PARTICIPANT	\N	PRESENT	0
356734	355933	19709B	PARTICIPANT	\N	PRESENT	0
356735	355933	08020N	PARTICIPANT	\N	PRESENT	0
356736	345116	11043H	PARTICIPANT	\N	PRESENT	0
356737	345116	14135M	PARTICIPANT	\N	PRESENT	0
356738	355933	08012N	PARTICIPANT	\N	PRESENT	0
356739	345116	14173T	PARTICIPANT	\N	PRESENT	0
356740	345116	01048V	PARTICIPANT	\N	PRESENT	0
356741	345116	19711U	PARTICIPANT	\N	PRESENT	0
356742	345116	08015R	PARTICIPANT	\N	PRESENT	0
356743	345116	14327T	PARTICIPANT	\N	PRESENT	0
356744	355933	14241N	PARTICIPANT	\N	PRESENT	0
356745	345116	14257W	PARTICIPANT	\N	PRESENT	0
356746	345116	14119M	PARTICIPANT	\N	PRESENT	0
356755	345116	04049K	PARTICIPANT	\N	PRESENT	0
356756	355933	11109J	PARTICIPANT	\N	PRESENT	0
356757	345116	17583W	PARTICIPANT	\N	PRESENT	0
356758	345116	19347U	PARTICIPANT	\N	PRESENT	0
356759	355933	11043H	PARTICIPANT	\N	PRESENT	0
356760	355933	87003B	PARTICIPANT	\N	PRESENT	0
356761	356361	19443T	PARTICIPANT	\N	PRESENT	0
356762	356361	19533U	PARTICIPANT	\N	PRESENT	0
356763	356361	01058X	PARTICIPANT	\N	PRESENT	0
356764	356361	16685X	PARTICIPANT	\N	PRESENT	0
356765	356361	11027H	PARTICIPANT	\N	PRESENT	0
356766	356361	11066Q	PARTICIPANT	\N	PRESENT	0
356767	356361	19573D	PARTICIPANT	\N	PRESENT	0
356768	356361	19421M	PARTICIPANT	\N	PRESENT	0
356769	356361	14039A	PARTICIPANT	\N	PRESENT	0
356770	356361	07033P	PARTICIPANT	\N	PRESENT	0
356771	356361	08053X	PARTICIPANT	\N	PRESENT	0
356772	356361	08061X	PARTICIPANT	\N	PRESENT	0
356773	356361	97011G	PARTICIPANT	\N	PRESENT	0
356774	356361	19335Q	PARTICIPANT	\N	PRESENT	0
356775	356361	08047A	PARTICIPANT	\N	PRESENT	0
356776	356361	14059S	PARTICIPANT	\N	PRESENT	0
356777	356361	95067Q	PARTICIPANT	\N	PRESENT	0
356778	356361	04057K	PARTICIPANT	\N	PRESENT	0
356779	356361	14073Q	PARTICIPANT	\N	PRESENT	0
356780	356361	19611R	PARTICIPANT	\N	PRESENT	0
356781	356361	14235Q	PARTICIPANT	\N	PRESENT	0
356782	356361	08058D	PARTICIPANT	\N	PRESENT	0
356783	356361	19693L	PARTICIPANT	\N	PRESENT	0
356784	356361	87003B	PARTICIPANT	\N	PRESENT	0
356785	356361	14030Q	PARTICIPANT	\N	PRESENT	0
356786	356361	14251Q	PARTICIPANT	\N	PRESENT	0
356787	356361	04059M	PARTICIPANT	\N	PRESENT	0
356788	356361	11109J	PARTICIPANT	\N	PRESENT	0
356789	356361	98050T	PARTICIPANT	\N	PRESENT	0
356790	356361	14109K	PARTICIPANT	\N	PRESENT	0
356791	356361	14121F	PARTICIPANT	\N	PRESENT	0
356792	356361	14123H	PARTICIPANT	\N	PRESENT	0
341287	340488	08024S	PARTICIPANT	\N	PRESENT	0
341288	340488	17637T	PARTICIPANT	\N	PRESENT	0
341289	340483	95037J	PARTICIPANT	\N	PRESENT	0
341290	340483	98022P	PARTICIPANT	\N	PRESENT	0
341291	340483	11064N	PARTICIPANT	\N	PRESENT	0
341292	340488	14029X	PARTICIPANT	\N	PRESENT	0
341293	340488	19739H	PARTICIPANT	\N	PRESENT	0
341307	340472	19768N	PARTICIPANT	\N	PRESENT	0
341308	340472	19515S	PARTICIPANT	\N	PRESENT	0
341309	340472	19782L	PARTICIPANT	\N	PRESENT	0
341310	340472	01043Q	PARTICIPANT	\N	PRESENT	0
341311	340472	14357A	PARTICIPANT	\N	PRESENT	0
341312	340472	19441R	PARTICIPANT	\N	PRESENT	0
341313	340472	19413M	PARTICIPANT	\N	PRESENT	0
341314	340472	14081Q	PARTICIPANT	\N	PRESENT	0
341315	340472	80013X	PARTICIPANT	\N	PRESENT	0
341316	340472	19631V	PARTICIPANT	\N	PRESENT	0
341317	340472	08021P	PARTICIPANT	\N	PRESENT	0
341318	340472	11099A	PARTICIPANT	\N	PRESENT	0
341319	340472	08068F	PARTICIPANT	\N	PRESENT	0
341320	340472	04049K	PARTICIPANT	\N	PRESENT	0
341321	340472	19705W	PARTICIPANT	\N	PRESENT	0
341322	340472	08015R	PARTICIPANT	\N	PRESENT	0
341323	340472	08019V	PARTICIPANT	\N	PRESENT	0
341324	340472	19369B	PARTICIPANT	\N	PRESENT	0
341325	340472	19511N	PARTICIPANT	\N	PRESENT	0
341326	340472	08028W	PARTICIPANT	\N	PRESENT	0
341327	340472	14265W	PARTICIPANT	\N	PRESENT	0
341328	340472	14329V	PARTICIPANT	\N	PRESENT	0
341329	340472	14135M	PARTICIPANT	\N	PRESENT	0
341330	340472	19467C	PARTICIPANT	\N	PRESENT	0
341331	340472	14187A	PARTICIPANT	\N	PRESENT	0
341332	340472	08038Y	PARTICIPANT	\N	PRESENT	0
341333	340472	19695N	PARTICIPANT	\N	PRESENT	0
341334	340472	14033T	PARTICIPANT	\N	PRESENT	0
341335	340472	11090Q	PRESIDENT	0	PRESENT	0
341336	340472	01025N	PARTICIPANT	\N	PRESENT	0
341337	340472	14205J	PARTICIPANT	\N	PRESENT	0
341338	340472	04088S	PARTICIPANT	\N	PRESENT	0
341339	340472	11056N	PARTICIPANT	\N	PRESENT	0
341340	340472	04089T	PARTICIPANT	\N	PRESENT	0
341341	340472	14115H	PARTICIPANT	\N	PRESENT	0
341342	340472	11101A	PARTICIPANT	\N	PRESENT	0
341343	340472	19507S	PARTICIPANT	\N	PRESENT	0
341344	340472	19747H	PARTICIPANT	\N	PRESENT	0
341345	340472	14207L	PARTICIPANT	\N	PRESENT	0
341346	340472	04043D	PARTICIPANT	\N	PRESENT	0
341347	340472	17589D	PARTICIPANT	\N	PRESENT	0
341348	340472	14257W	PARTICIPANT	\N	PRESENT	0
341349	340472	08062Y	PARTICIPANT	\N	EXCUSE	0
341350	340472	14197C	PARTICIPANT	\N	EXCUSE	0
341351	340472	11081P	PARTICIPANT	\N	EXCUSE	0
341352	340472	19591F	PARTICIPANT	\N	EXCUSE	0
341356	340484	12041X	PARTICIPANT	\N	PRESENT	0
341357	340484	11080N	PARTICIPANT	\N	PRESENT	0
341358	340484	95030B	PARTICIPANT	\N	PRESENT	0
341359	340484	04034C	PARTICIPANT	\N	PRESENT	0
341360	340484	14079W	PARTICIPANT	\N	PRESENT	0
341361	340484	01058X	PARTICIPANT	\N	PRESENT	0
341362	340484	16685X	PARTICIPANT	\N	PRESENT	0
341363	340484	11027H	PARTICIPANT	\N	PRESENT	0
341364	340484	04042C	PRESIDENT	0	PRESENT	0
341365	340484	11054L	PARTICIPANT	\N	PRESENT	0
341366	340484	11066Q	PARTICIPANT	\N	PRESENT	0
341367	340484	08056B	PARTICIPANT	\N	PRESENT	0
341368	340484	11115U	PARTICIPANT	\N	PRESENT	0
341369	340484	95037J	PARTICIPANT	\N	PRESENT	0
341370	340484	19421M	PARTICIPANT	\N	PRESENT	0
341371	340484	19709B	PARTICIPANT	\N	PRESENT	0
341372	340484	08049C	PARTICIPANT	\N	PRESENT	0
341373	340484	97011G	PARTICIPANT	\N	PRESENT	0
341374	340484	08061X	PARTICIPANT	\N	PRESENT	0
341375	340484	98029W	PARTICIPANT	\N	PRESENT	0
341376	340484	14097Y	PARTICIPANT	\N	PRESENT	0
341377	340484	04035D	PARTICIPANT	\N	PRESENT	0
341378	340484	95067Q	PARTICIPANT	\N	PRESENT	0
341379	340484	01062T	PARTICIPANT	\N	PRESENT	0
341380	340484	14133K	PARTICIPANT	\N	PRESENT	0
341381	340484	11041F	PARTICIPANT	\N	PRESENT	0
341382	340484	14235Q	PARTICIPANT	\N	PRESENT	0
341383	340484	08058D	PARTICIPANT	\N	PRESENT	0
341384	340484	14028W	PARTICIPANT	\N	PRESENT	0
341385	340484	19251M	PARTICIPANT	\N	PRESENT	0
341386	340484	19721W	PARTICIPANT	\N	PRESENT	0
341387	340484	14105F	PARTICIPANT	\N	PRESENT	0
341388	340484	98022P	PARTICIPANT	\N	PRESENT	0
341389	340484	14267Y	PARTICIPANT	\N	PRESENT	0
341390	340484	11064N	PARTICIPANT	\N	PRESENT	0
341391	340484	98050T	PARTICIPANT	\N	PRESENT	0
341392	340484	19583F	PARTICIPANT	\N	PRESENT	0
341393	340484	14211G	PARTICIPANT	\N	PRESENT	0
341394	340484	14255U	PARTICIPANT	\N	PRESENT	0
341400	340488	11053K	PARTICIPANT	\N	PRESENT	0
341401	340479	14331P	PARTICIPANT	\N	PRESENT	0
341402	340479	01048V	PARTICIPANT	\N	PRESENT	0
341403	340479	19545Y	PRESIDENT	0	PRESENT	0
341404	340479	01057W	PARTICIPANT	\N	PRESENT	0
341504	339496	19583F	PARTICIPANT	\N	PRESENT	0
341406	340479	89017R	PARTICIPANT	\N	PRESENT	0
341407	340479	19667J	PARTICIPANT	\N	PRESENT	0
341408	340479	88008L	PARTICIPANT	\N	PRESENT	0
341409	340479	14225N	PARTICIPANT	\N	PRESENT	0
341410	340479	19671E	PARTICIPANT	\N	PRESENT	0
341411	340479	07029T	PARTICIPANT	\N	PRESENT	0
341412	340479	14085U	PARTICIPANT	\N	PRESENT	0
341413	340479	19349W	PARTICIPANT	\N	PRESENT	0
341414	340479	08010L	PARTICIPANT	\N	PRESENT	0
341415	340479	11048N	PARTICIPANT	\N	PRESENT	0
341416	340479	19479G	PARTICIPANT	\N	PRESENT	0
341417	340479	19711U	PARTICIPANT	\N	PRESENT	0
341418	340479	08034U	PARTICIPANT	\N	PRESENT	0
341419	340479	08069G	PARTICIPANT	\N	PRESENT	0
341420	340479	19687N	PARTICIPANT	\N	PRESENT	0
341421	340479	19689Q	PARTICIPANT	\N	PRESENT	0
341422	340479	08011M	PARTICIPANT	\N	PRESENT	0
341423	340479	14034U	PARTICIPANT	\N	PRESENT	0
341424	340479	14159V	PARTICIPANT	\N	PRESENT	0
341425	340479	11040E	PARTICIPANT	\N	PRESENT	0
341426	340479	04086Q	PARTICIPANT	\N	PRESENT	0
341427	340479	14083S	PARTICIPANT	\N	PRESENT	0
341428	340479	14199E	PARTICIPANT	\N	PRESENT	0
341429	340479	11012A	PARTICIPANT	\N	PRESENT	0
341430	340479	08073C	PARTICIPANT	\N	PRESENT	0
341431	340479	14121F	PARTICIPANT	\N	PRESENT	0
341432	340479	19741B	PARTICIPANT	\N	PRESENT	0
341433	340479	99004R	PARTICIPANT	\N	PRESENT	0
341434	340479	04061F	PARTICIPANT	\N	PRESENT	0
341439	340479	14327T	PARTICIPANT	\N	EXCUSE	0
341440	340479	11074Q	PARTICIPANT	\N	EXCUSE	0
341474	339496	11072N	PARTICIPANT	\N	PRESENT	0
341476	341473	19515S	PARTICIPANT	\N	PRESENT	0
341477	341473	04034C	PARTICIPANT	\N	PRESENT	0
341478	341473	19545Y	PARTICIPANT	\N	PRESENT	0
341479	341473	19441R	PARTICIPANT	\N	PRESENT	0
341480	341473	11053K	PARTICIPANT	\N	PRESENT	0
341481	341473	19667J	PARTICIPANT	\N	PRESENT	0
341482	341473	14026U	PARTICIPANT	\N	PRESENT	0
341483	341473	11070L	PARTICIPANT	\N	PRESENT	0
341484	341473	19631V	PARTICIPANT	\N	PRESENT	0
341485	341473	14227Q	PARTICIPANT	\N	PRESENT	0
341486	341473	14051J	PARTICIPANT	\N	PRESENT	0
341487	341473	08068F	PARTICIPANT	\N	PRESENT	0
341488	341473	04049K	PARTICIPANT	\N	PRESENT	0
341489	341473	14157T	PARTICIPANT	\N	PRESENT	0
341490	341473	19521Q	PARTICIPANT	\N	PRESENT	0
341491	341473	14329V	PARTICIPANT	\N	PRESENT	0
341492	341473	11048N	PARTICIPANT	\N	PRESENT	0
341493	341473	19711U	PARTICIPANT	\N	PRESENT	0
341494	341473	19695N	PARTICIPANT	\N	PRESENT	0
341495	341473	14034U	PARTICIPANT	\N	PRESENT	0
341496	341473	14159V	PARTICIPANT	\N	PRESENT	0
341497	341473	19399H	PARTICIPANT	\N	PRESENT	0
341498	341473	14173T	PARTICIPANT	\N	PRESENT	0
341499	341473	14083S	PARTICIPANT	\N	PRESENT	0
341500	341473	14199E	PARTICIPANT	\N	PRESENT	0
341501	341473	19760E	PARTICIPANT	\N	PRESENT	0
341502	341473	19762G	PARTICIPANT	\N	PRESENT	0
341503	341473	11110B	PARTICIPANT	\N	EXCUSE	0
341505	339496	19593H	PARTICIPANT	\N	PRESENT	0
341506	339496	01025N	PARTICIPANT	\N	PRESENT	0
341507	339496	19715Y	PARTICIPANT	\N	PRESENT	0
341508	339496	04035D	PARTICIPANT	\N	PRESENT	0
341509	339496	19629C	PARTICIPANT	\N	PRESENT	0
341510	341473	04071H	PARTICIPANT	\N	PRESENT	0
341511	341473	08034U	PARTICIPANT	\N	PRESENT	0
341512	341473	08073C	PARTICIPANT	\N	PRESENT	0
341513	339496	19611R	PARTICIPANT	\N	PRESENT	0
341514	339496	19745F	PARTICIPANT	\N	PRESENT	0
338397	338289	14042U	PARTICIPANT	\N	PRESENT	0
338399	338287	14042U	PARTICIPANT	\N	PRESENT	0
338400	338290	14042U	PARTICIPANT	\N	PRESENT	0
338457	338456	19503N	PARTICIPANT	\N	PRESENT	0
338459	338458	04040A	PARTICIPANT	\N	PRESENT	0
338460	338458	14327T	PARTICIPANT	\N	PRESENT	0
338461	338458	14231L	PARTICIPANT	\N	PRESENT	0
338462	338458	01057W	PARTICIPANT	\N	PRESENT	0
338463	338458	11048N	PARTICIPANT	\N	PRESENT	0
338464	338458	14257W	PARTICIPANT	\N	PRESENT	0
338465	338458	08049C	PARTICIPANT	\N	PRESENT	0
338466	338458	14063N	PARTICIPANT	\N	PRESENT	0
338467	338458	14103D	PARTICIPANT	\N	PRESENT	0
338468	338458	19531S	PARTICIPANT	\N	PRESENT	0
340475	340474	04059M	PARTICIPANT	\N	PRESENT	0
340476	340474	14229S	PARTICIPANT	\N	PRESENT	0
340477	340474	19611R	PARTICIPANT	\N	PRESENT	0
340478	340474	11083R	PARTICIPANT	\N	PRESENT	0
342059	341936	19760E	PARTICIPANT	\N	PRESENT	0
342912	341956	19723Y	PARTICIPANT	\N	EXCUSE	0
342913	341956	19693L	PARTICIPANT	\N	EXCUSE	0
342914	341956	19511N	PARTICIPANT	\N	EXCUSE	0
343039	343003	14053L	PARTICIPANT	\N	PRESENT	0
343040	343003	19649G	PARTICIPANT	\N	PRESENT	0
343041	343003	14111D	PARTICIPANT	\N	PRESENT	0
343042	343003	14065Q	PARTICIPANT	\N	PRESENT	0
343043	343003	08045X	PARTICIPANT	\N	PRESENT	0
343044	343003	07034Q	PARTICIPANT	\N	PRESENT	0
343045	343003	11026G	PARTICIPANT	\N	PRESENT	0
343046	343003	19581D	PARTICIPANT	\N	PRESENT	0
343047	343003	04044E	PARTICIPANT	\N	PRESENT	0
343048	343003	19585H	PARTICIPANT	\N	PRESENT	0
343049	343003	04047H	PARTICIPANT	\N	PRESENT	0
343050	343003	01028R	PARTICIPANT	\N	PRESENT	0
343051	343003	11033F	PARTICIPANT	\N	PRESENT	0
343052	343003	05008E	PRESIDENT	0	PRESENT	0
343053	343003	19447X	PARTICIPANT	\N	PRESENT	0
343054	343003	19489J	PARTICIPANT	\N	PRESENT	0
343055	343003	14041T	PARTICIPANT	\N	PRESENT	0
343056	343003	08044W	PARTICIPANT	\N	PRESENT	0
343057	343003	14147R	PARTICIPANT	\N	PRESENT	0
343058	343003	14151M	PARTICIPANT	\N	PRESENT	0
343059	343003	14215L	PARTICIPANT	\N	PRESENT	0
343060	343003	08018U	PARTICIPANT	\N	PRESENT	0
343061	343003	11049P	PARTICIPANT	\N	PRESENT	0
343062	343003	14021P	PARTICIPANT	\N	PRESENT	0
343063	343003	19543W	PARTICIPANT	\N	PRESENT	0
343065	343003	11085T	PARTICIPANT	\N	PRESENT	0
346267	345036	08053X	PARTICIPANT	\N	EXCUSE	0
346413	346296	96004D	PARTICIPANT	\N	EXCUSE	0
346414	346296	14038Y	PARTICIPANT	\N	EXCUSE	0
346415	346296	19659J	PARTICIPANT	\N	EXCUSE	0
346417	346331	96004D	PARTICIPANT	\N	EXCUSE	0
346418	346331	14038Y	PARTICIPANT	\N	EXCUSE	0
346419	346331	14331P	PARTICIPANT	\N	EXCUSE	0
346420	346332	96004D	PARTICIPANT	\N	EXCUSE	0
346424	346333	96004D	PARTICIPANT	\N	EXCUSE	0
346422	346332	19295A	PARTICIPANT	\N	EXCUSE	0
346423	346332	19659J	PARTICIPANT	\N	EXCUSE	0
346425	346333	19295A	PARTICIPANT	\N	EXCUSE	0
346426	346333	19659J	PARTICIPANT	\N	EXCUSE	0
352314	352313	19631V	PARTICIPANT	\N	PRESENT	0
352315	352313	19515S	PARTICIPANT	\N	PRESENT	0
352316	352313	19747H	PARTICIPANT	\N	PRESENT	0
352317	352313	19441R	PARTICIPANT	\N	PRESENT	0
352318	352313	19369B	PARTICIPANT	\N	PRESENT	0
352319	352313	14265W	PARTICIPANT	\N	PRESENT	0
352320	352313	14135M	PARTICIPANT	\N	PRESENT	0
352321	352313	19705W	PARTICIPANT	\N	PRESENT	0
353793	353792	14193X	PARTICIPANT	\N	PRESENT	0
353795	353794	14193X	PARTICIPANT	\N	PRESENT	0
354218	354217	19621T	PARTICIPANT	\N	PRESENT	0
354219	354217	19593H	PARTICIPANT	\N	PRESENT	0
354220	354217	08043V	PARTICIPANT	\N	PRESENT	0
354221	354217	14039A	PARTICIPANT	\N	PRESENT	0
354223	354222	19593H	PARTICIPANT	\N	PRESENT	0
354224	354222	19621T	PARTICIPANT	\N	PRESENT	0
354225	354222	19611R	PARTICIPANT	\N	PRESENT	0
354226	354222	08043V	PARTICIPANT	\N	PRESENT	0
354227	354222	14109K	PARTICIPANT	\N	PRESENT	0
355195	352536	11045K	PARTICIPANT	\N	PRESENT	0
355204	348097	19565D	PARTICIPANT	\N	EXCUSE	0
355516	348097	14103D	PARTICIPANT	\N	EXCUSE	0
356120	356119	19621T	PARTICIPANT	\N	PRESENT	0
356121	356119	19611R	PARTICIPANT	\N	PRESENT	0
356123	356122	19621T	PARTICIPANT	\N	PRESENT	0
356124	356122	19611R	PARTICIPANT	\N	PRESENT	0
356126	356125	19621T	PARTICIPANT	\N	PRESENT	0
356127	356125	19573D	PARTICIPANT	\N	PRESENT	0
356128	356125	19693L	PARTICIPANT	\N	PRESENT	0
356130	356129	19621T	PARTICIPANT	\N	PRESENT	0
356131	356129	19573D	PARTICIPANT	\N	PRESENT	0
356132	356129	19693L	PARTICIPANT	\N	PRESENT	0
356133	356129	19611R	PARTICIPANT	\N	PRESENT	0
356139	356138	04040A	PARTICIPANT	\N	PRESENT	0
356140	356138	14235Q	PARTICIPANT	\N	PRESENT	0
356142	356141	98029W	PARTICIPANT	\N	PRESENT	0
357108	356273	14001X	PARTICIPANT	\N	PRESENT	0
357109	356273	19543W	PARTICIPANT	\N	PRESENT	0
357110	356273	19581D	PARTICIPANT	\N	PRESENT	0
357111	356273	19585H	PARTICIPANT	\N	PRESENT	0
357112	356273	19673G	PARTICIPANT	\N	PRESENT	0
357113	356273	01028R	PARTICIPANT	\N	PRESENT	0
357114	356273	05008E	PRESIDENT	0	PRESENT	0
357115	356273	14231L	PARTICIPANT	\N	PRESENT	0
357116	356273	14215L	PARTICIPANT	\N	PRESENT	0
357117	356273	11072N	PARTICIPANT	\N	PRESENT	0
357118	356273	98035U	PARTICIPANT	\N	PRESENT	0
357119	356273	14111D	PARTICIPANT	\N	PRESENT	0
357120	356273	14065Q	PARTICIPANT	\N	PRESENT	0
357121	356273	19649G	PARTICIPANT	\N	PRESENT	0
357122	356273	08045X	PARTICIPANT	\N	PRESENT	0
357123	356273	11026G	PARTICIPANT	\N	PRESENT	0
357124	356273	10015M	PARTICIPANT	\N	PRESENT	0
357125	356273	19253P	PARTICIPANT	\N	PRESENT	0
357126	356273	01024M	PARTICIPANT	\N	PRESENT	0
357127	356273	04038G	PARTICIPANT	\N	PRESENT	0
357128	356273	19719D	PARTICIPANT	\N	PRESENT	0
357129	356273	11033F	PARTICIPANT	\N	PRESENT	0
357130	356273	19725B	PARTICIPANT	\N	PRESENT	0
357131	356273	95063L	PARTICIPANT	\N	PRESENT	0
357132	356273	19629C	PARTICIPANT	\N	PRESENT	0
357133	356273	19762G	PARTICIPANT	\N	PRESENT	0
357134	356273	08044W	PARTICIPANT	\N	PRESENT	0
357135	356273	19489J	PARTICIPANT	\N	PRESENT	0
357136	356273	14073Q	PARTICIPANT	\N	PRESENT	0
357137	356273	19729F	PARTICIPANT	\N	EXCUSE	0
357138	356273	08018U	PARTICIPANT	\N	EXCUSE	0
357140	356273	04044E	PARTICIPANT	\N	PRESENT	0
357141	356273	11049P	PARTICIPANT	\N	PRESENT	0
357142	355955	19527W	PARTICIPANT	\N	EXCUSE	0
357143	355955	19565D	PARTICIPANT	\N	EXCUSE	0
357144	355955	19717B	PARTICIPANT	\N	EXCUSE	0
357145	356853	19717B	PARTICIPANT	\N	EXCUSE	0
357146	356853	19663E	PARTICIPANT	\N	EXCUSE	0
357147	356853	19565D	PARTICIPANT	\N	EXCUSE	0
357148	356853	19527W	PARTICIPANT	\N	EXCUSE	0
357149	355955	19663E	PARTICIPANT	\N	EXCUSE	0
357150	356273	04047H	PARTICIPANT	\N	PRESENT	0
357151	356273	14179A	PARTICIPANT	\N	PRESENT	0
357153	356855	04070G	PRESIDENT	0	PRESENT	0
357154	356855	14241N	PARTICIPANT	\N	PRESENT	0
357155	356855	19573D	PARTICIPANT	\N	PRESENT	0
357156	356855	14039A	PARTICIPANT	\N	PRESENT	0
357157	356855	08017T	PARTICIPANT	\N	PRESENT	0
357158	356855	07033P	PARTICIPANT	\N	PRESENT	0
357159	356855	08012N	PARTICIPANT	\N	PRESENT	0
357160	356855	08039A	PARTICIPANT	\N	PRESENT	0
357161	356855	08031R	PARTICIPANT	\N	PRESENT	0
357162	356855	19593H	PARTICIPANT	\N	PRESENT	0
357163	356855	19643A	PARTICIPANT	\N	PRESENT	0
357164	356855	14059S	PARTICIPANT	\N	PRESENT	0
357165	356855	14073Q	PARTICIPANT	\N	PRESENT	0
357166	356855	19611R	PARTICIPANT	\N	PRESENT	0
357167	356855	19693L	PARTICIPANT	\N	PRESENT	0
357168	356855	87003B	PARTICIPANT	\N	PRESENT	0
357169	356855	19399H	PARTICIPANT	\N	PRESENT	0
357170	356855	14030Q	PARTICIPANT	\N	PRESENT	0
357171	356855	19731Y	PARTICIPANT	\N	PRESENT	0
357172	356855	08020N	PARTICIPANT	\N	PRESENT	0
357173	356855	14251Q	PARTICIPANT	\N	PRESENT	0
357174	356855	04059M	PARTICIPANT	\N	PRESENT	0
357175	356855	19735D	PARTICIPANT	\N	PRESENT	0
357176	356855	11109J	PARTICIPANT	\N	PRESENT	0
357177	356855	14109K	PARTICIPANT	\N	PRESENT	0
357178	356855	11083R	PARTICIPANT	\N	PRESENT	0
357179	356855	11043H	PARTICIPANT	\N	PRESENT	0
357180	356855	04018C	PARTICIPANT	\N	PRESENT	0
357181	356855	19758L	PARTICIPANT	\N	PRESENT	0
346529	339513	98022P	PARTICIPANT	\N	PRESENT	0
346531	339513	11085T	PARTICIPANT	\N	PRESENT	0
346532	339513	14115H	PARTICIPANT	\N	PRESENT	0
346535	339513	19687N	PARTICIPANT	\N	PRESENT	0
346536	339513	19295A	PARTICIPANT	\N	PRESENT	0
346537	339513	19621T	PARTICIPANT	\N	PRESENT	0
346538	339513	11012A	PARTICIPANT	\N	PRESENT	0
346539	339513	19551W	PARTICIPANT	\N	PRESENT	0
346540	339513	19527W	PARTICIPANT	\N	PRESENT	0
346541	339513	11104D	PARTICIPANT	\N	PRESENT	0
346542	339513	19693L	PARTICIPANT	\N	PRESENT	0
346543	339513	08051V	PARTICIPANT	\N	PRESENT	0
346544	346441	14053L	PARTICIPANT	\N	PRESENT	0
346545	346441	14065Q	PARTICIPANT	\N	PRESENT	0
346546	346441	19649G	PARTICIPANT	\N	PRESENT	0
346547	346441	08045X	PARTICIPANT	\N	PRESENT	0
346548	346441	10015M	PARTICIPANT	\N	PRESENT	0
346549	346441	01024M	PARTICIPANT	\N	PRESENT	0
346550	346441	19581D	PARTICIPANT	\N	PRESENT	0
346551	346441	04047H	PARTICIPANT	\N	PRESENT	0
346552	346441	01028R	PARTICIPANT	\N	PRESENT	0
346553	346441	05008E	PRESIDENT	0	PRESENT	0
346554	346441	19447X	PARTICIPANT	\N	PRESENT	0
346555	346441	95063L	PARTICIPANT	\N	PRESENT	0
346556	346441	08044W	PARTICIPANT	\N	PRESENT	0
346557	346441	14147R	PARTICIPANT	\N	PRESENT	0
346558	346441	14215L	PARTICIPANT	\N	PRESENT	0
346559	346441	14259Y	PARTICIPANT	\N	PRESENT	0
346560	346441	04044E	PARTICIPANT	\N	EXCUSE	0
346561	339513	01058X	PARTICIPANT	\N	PRESENT	0
346562	339513	08038Y	PARTICIPANT	\N	PRESENT	0
346563	339513	14109K	PARTICIPANT	\N	PRESENT	0
346564	339513	14265W	PARTICIPANT	\N	PRESENT	0
346565	339513	14213J	PARTICIPANT	\N	PRESENT	0
346566	339513	14225N	PARTICIPANT	\N	PRESENT	0
346567	339513	08069G	PARTICIPANT	\N	PRESENT	0
346568	339513	14199E	PARTICIPANT	\N	PRESENT	0
346569	339513	14201E	PARTICIPANT	\N	PRESENT	0
346570	339513	17583W	PARTICIPANT	\N	PRESENT	0
346572	339513	19269X	PARTICIPANT	\N	PRESENT	0
346827	345123	11048N	PARTICIPANT	\N	EXCUSE	0
346839	345576	14195A	PARTICIPANT	\N	PRESENT	0
346840	345576	19703U	PARTICIPANT	\N	PRESENT	0
348068	348067	19533U	PARTICIPANT	\N	PRESENT	0
348072	348070	19533U	PARTICIPANT	\N	PRESENT	0
348075	348073	19533U	PARTICIPANT	\N	PRESENT	0
348077	348076	19533U	PARTICIPANT	\N	PRESENT	0
348081	348079	19533U	PARTICIPANT	\N	PRESENT	0
348083	348082	19533U	PARTICIPANT	\N	PRESENT	0
348086	348085	19533U	PARTICIPANT	\N	PRESENT	0
348090	348089	08009T	PARTICIPANT	\N	PRESENT	0
348113	343005	04038G	PARTICIPANT	\N	PRESENT	0
348295	339519	08017T	PARTICIPANT	\N	PRESENT	0
348115	345317	14107H	PARTICIPANT	\N	PRESENT	0
348116	340555	11065P	PARTICIPANT	\N	PRESENT	0
348117	340555	14107H	PARTICIPANT	\N	PRESENT	0
348294	339519	17779H	PARTICIPANT	\N	PRESENT	0
348296	339519	14357A	PARTICIPANT	\N	PRESENT	0
348297	339519	14217N	PARTICIPANT	\N	PRESENT	0
348300	339519	14249W	PARTICIPANT	\N	PRESENT	0
348301	339519	01058X	PARTICIPANT	\N	PRESENT	0
348308	339519	11045K	PARTICIPANT	\N	PRESENT	0
348309	339519	19511N	PARTICIPANT	\N	PRESENT	0
348310	339519	19543W	PARTICIPANT	\N	PRESENT	0
348311	339519	19703U	PARTICIPANT	\N	PRESENT	0
348312	339519	04086Q	PARTICIPANT	\N	PRESENT	0
348314	339519	14173T	PARTICIPANT	\N	PRESENT	0
348315	339519	14115H	PARTICIPANT	\N	PRESENT	0
348316	339519	87003B	PARTICIPANT	\N	PRESENT	0
348317	339519	19533U	PARTICIPANT	\N	PRESENT	0
348318	339519	01062T	PARTICIPANT	\N	PRESENT	0
348319	339519	14109K	PARTICIPANT	\N	PRESENT	0
348320	339519	14275Y	PARTICIPANT	\N	PRESENT	0
348322	339519	04089T	PARTICIPANT	\N	PRESENT	0
348325	339519	19479G	PARTICIPANT	\N	PRESENT	0
348326	339519	95062K	PARTICIPANT	\N	PRESENT	0
348327	339519	19697Q	PARTICIPANT	\N	PRESENT	0
348328	339519	08014Q	PARTICIPANT	\N	PRESENT	0
348330	339519	14237S	PARTICIPANT	\N	PRESENT	0
348331	339519	14179A	PARTICIPANT	\N	PRESENT	0
348332	339519	19527W	PARTICIPANT	\N	PRESENT	0
348333	339519	19715Y	PARTICIPANT	\N	PRESENT	0
348335	348334	19569H	PARTICIPANT	\N	PRESENT	0
348337	339519	11115U	PARTICIPANT	\N	PRESENT	0
348338	348336	19569H	PARTICIPANT	\N	PRESENT	0
348340	348339	19569H	PARTICIPANT	\N	PRESENT	0
348347	348345	19569H	PARTICIPANT	\N	PRESENT	0
348351	339519	14073Q	PARTICIPANT	\N	PRESENT	0
348352	339519	11067R	PARTICIPANT	\N	PRESENT	0
348353	339519	98022P	PARTICIPANT	\N	PRESENT	0
348354	339519	19563B	PARTICIPANT	\N	PRESENT	0
348357	339519	19733B	PARTICIPANT	\N	PRESENT	0
348358	339519	11064N	PARTICIPANT	\N	PRESENT	0
348359	339519	19585H	PARTICIPANT	\N	PRESENT	0
348524	339524	11101A	PARTICIPANT	\N	PRESENT	0
348525	339524	95062K	PARTICIPANT	\N	PRESENT	0
348526	339524	99004R	PARTICIPANT	\N	PRESENT	0
348527	339524	19703U	PARTICIPANT	\N	PRESENT	0
348528	339524	08010L	PARTICIPANT	\N	PRESENT	0
348529	339524	95030B	PARTICIPANT	\N	PRESENT	0
348530	339524	14223L	PARTICIPANT	\N	PRESENT	0
348531	339524	14157T	PARTICIPANT	\N	PRESENT	0
348532	339524	14259Y	PARTICIPANT	\N	PRESENT	0
348533	339524	19515S	PARTICIPANT	\N	PRESENT	0
348534	339524	19667J	PARTICIPANT	\N	PRESENT	0
348535	339524	11115U	PARTICIPANT	\N	PRESENT	0
348536	339524	11010L	PARTICIPANT	\N	PRESENT	0
348537	339524	19447X	PARTICIPANT	\N	PRESENT	0
348538	339524	14173T	PARTICIPANT	\N	PRESENT	0
348539	339524	14038Y	PARTICIPANT	\N	PRESENT	0
348540	339524	14029X	PARTICIPANT	\N	PRESENT	0
348541	339524	17637T	PARTICIPANT	\N	PRESENT	0
348542	339524	08034U	PARTICIPANT	\N	PRESENT	0
348543	339524	19415P	PARTICIPANT	\N	PRESENT	0
348544	339524	96004D	PARTICIPANT	\N	PRESENT	0
348545	339524	14211G	PARTICIPANT	\N	PRESENT	0
348546	339524	04071H	PARTICIPANT	\N	PRESENT	0
348547	339524	19643A	PARTICIPANT	\N	PRESENT	0
348548	339524	14199E	PARTICIPANT	\N	PRESENT	0
348549	339524	08018U	PARTICIPANT	\N	PRESENT	0
348550	339524	11080N	PARTICIPANT	\N	PRESENT	0
348551	339524	19709B	PARTICIPANT	\N	PRESENT	0
348552	339524	14105F	PARTICIPANT	\N	PRESENT	0
348553	339524	10015M	PARTICIPANT	\N	PRESENT	0
348554	339524	01057W	PARTICIPANT	\N	PRESENT	0
348555	339524	04097T	PARTICIPANT	\N	PRESENT	0
348556	339524	07033P	PARTICIPANT	\N	PRESENT	0
348557	339524	14026U	PARTICIPANT	\N	PRESENT	0
348558	339524	11103C	PARTICIPANT	\N	PRESENT	0
348559	339524	14253S	PARTICIPANT	\N	PRESENT	0
348560	339524	14133K	PARTICIPANT	\N	PRESENT	0
348561	339524	08019V	PARTICIPANT	\N	PRESENT	0
348562	339524	14123H	PARTICIPANT	\N	PRESENT	0
348563	339524	08062Y	PARTICIPANT	\N	PRESENT	0
348564	339524	19573D	PARTICIPANT	\N	PRESENT	0
348565	339524	19711U	PARTICIPANT	\N	PRESENT	0
348566	339524	19467C	PARTICIPANT	\N	PRESENT	0
348567	339524	04042C	PARTICIPANT	\N	PRESENT	0
348568	339524	87003B	PARTICIPANT	\N	PRESENT	0
348569	339524	12041X	PARTICIPANT	\N	PRESENT	0
348570	339524	86034E	PARTICIPANT	\N	PRESENT	0
348571	339524	11031D	PARTICIPANT	\N	PRESENT	0
348572	339524	04038G	PARTICIPANT	\N	PRESENT	0
348573	339524	19593H	PARTICIPANT	\N	PRESENT	0
348574	339524	19347U	PARTICIPANT	\N	PRESENT	0
348575	339524	04008A	PARTICIPANT	\N	PRESENT	0
348576	339524	11077T	PARTICIPANT	\N	PRESENT	0
348577	339524	01058X	PARTICIPANT	\N	PRESENT	0
348578	339524	15447F	PARTICIPANT	\N	PRESENT	0
348579	339524	11043H	PARTICIPANT	\N	PRESENT	0
348580	339524	19679N	PARTICIPANT	\N	PRESENT	0
348581	339524	19766L	PARTICIPANT	\N	PRESENT	0
348582	339524	14031R	PARTICIPANT	\N	PRESENT	0
348583	339524	11056N	PARTICIPANT	\N	PRESENT	0
348584	339524	04049K	PARTICIPANT	\N	PRESENT	0
348585	339524	19695N	PARTICIPANT	\N	PRESENT	0
348586	339524	19687N	PARTICIPANT	\N	PRESENT	0
348587	339524	95063L	PARTICIPANT	\N	PRESENT	0
348588	339524	08061X	PARTICIPANT	\N	PRESENT	0
348589	339524	19794Q	PARTICIPANT	\N	PRESENT	0
334338	332771	14331P	PARTICIPANT	\N	PRESENT	0
334339	332771	19479G	PARTICIPANT	\N	PRESENT	0
334340	332771	19711U	PARTICIPANT	\N	PRESENT	0
334341	332771	95041E	PARTICIPANT	\N	PRESENT	0
334342	332771	08034U	PARTICIPANT	\N	PRESENT	0
334343	332771	19687N	PARTICIPANT	\N	PRESENT	0
334344	332771	19667J	PARTICIPANT	\N	PRESENT	0
334345	332771	14034U	PARTICIPANT	\N	PRESENT	0
334346	332771	19671E	PARTICIPANT	\N	PRESENT	0
334347	332771	14225N	PARTICIPANT	\N	PRESENT	0
334348	332771	14159V	PARTICIPANT	\N	PRESENT	0
334349	332771	14173T	PARTICIPANT	\N	PRESENT	0
334350	332771	11040E	PRESIDENT	0	PRESENT	0
334351	332771	07029T	PARTICIPANT	\N	PRESENT	0
334352	332771	14083S	PARTICIPANT	\N	PRESENT	0
334353	332771	14085U	PARTICIPANT	\N	PRESENT	0
334354	332771	07004J	PARTICIPANT	\N	PRESENT	0
334355	332771	08010L	PARTICIPANT	\N	PRESENT	0
334356	332771	14121F	PARTICIPANT	\N	PRESENT	0
334357	332771	11074Q	PARTICIPANT	\N	EXCUSE	0
334358	332771	14253S	PARTICIPANT	\N	EXCUSE	0
334359	321375	01043Q	PARTICIPANT	\N	PRESENT	0
335200	332770	14034U	PARTICIPANT	\N	PRESENT	0
335201	332770	11074Q	PARTICIPANT	\N	EXCUSE	0
335202	321374	04086Q	PARTICIPANT	\N	PRESENT	0
335203	321374	11026G	PARTICIPANT	\N	PRESENT	0
335204	321374	19671E	PARTICIPANT	\N	PRESENT	0
335205	321374	04047H	PARTICIPANT	\N	PRESENT	0
335206	321374	19543W	PARTICIPANT	\N	PRESENT	0
335207	321374	19729F	PARTICIPANT	\N	PRESENT	0
335208	321374	11033F	PARTICIPANT	\N	PRESENT	0
335209	321374	04088S	PARTICIPANT	\N	PRESENT	0
335210	321374	18083K	PARTICIPANT	\N	PRESENT	0
335211	321374	19447X	PARTICIPANT	\N	PRESENT	0
335212	321374	19585H	PARTICIPANT	\N	PRESENT	0
335213	321374	14261S	PARTICIPANT	\N	PRESENT	0
335214	321374	19515S	PARTICIPANT	\N	PRESENT	0
335215	321374	99004R	PARTICIPANT	\N	PRESENT	0
335216	321374	08069G	PARTICIPANT	\N	PRESENT	0
335217	321374	11072N	PARTICIPANT	\N	PRESENT	0
335218	321374	08034U	PARTICIPANT	\N	PRESENT	0
335219	321374	14331P	PARTICIPANT	\N	PRESENT	0
335220	321374	01057W	PARTICIPANT	\N	PRESENT	0
335221	321374	01028R	PARTICIPANT	\N	PRESENT	0
335222	321374	07004J	PARTICIPANT	\N	PRESENT	0
335223	321374	04071H	PARTICIPANT	\N	PRESENT	0
335224	321374	14179A	PARTICIPANT	\N	PRESENT	0
335225	321374	14253S	PARTICIPANT	\N	PRESENT	0
335226	321374	11049P	PARTICIPANT	\N	PRESENT	0
335227	321374	14069U	PARTICIPANT	\N	PRESENT	0
335228	321374	08047A	PARTICIPANT	\N	PRESENT	0
335229	321374	04085P	PARTICIPANT	\N	PRESENT	0
335230	321374	19593H	PARTICIPANT	\N	PRESENT	0
335231	321374	19695N	PARTICIPANT	\N	PRESENT	0
335232	321374	17637T	PARTICIPANT	\N	PRESENT	0
335233	321374	08051V	PARTICIPANT	\N	PRESENT	0
335234	321374	19553Y	PARTICIPANT	\N	PRESENT	0
335235	321374	04044E	PARTICIPANT	\N	PRESENT	0
335236	321374	14034U	PARTICIPANT	\N	PRESENT	0
335237	321374	14173T	PARTICIPANT	\N	PRESENT	0
335238	321374	14083S	PARTICIPANT	\N	PRESENT	0
335239	321374	11066Q	PARTICIPANT	\N	PRESENT	0
335240	321374	08045X	PARTICIPANT	\N	PRESENT	0
335241	321374	07029T	PARTICIPANT	\N	PRESENT	0
336821	336820	14133K	PARTICIPANT	\N	PRESENT	0
336822	336820	04040A	PARTICIPANT	\N	PRESENT	0
336823	336820	19647E	PARTICIPANT	\N	PRESENT	0
336824	336820	08051V	PARTICIPANT	\N	PRESENT	0
336825	336820	98050T	PARTICIPANT	\N	PRESENT	0
336826	336820	95067Q	PARTICIPANT	\N	PRESENT	0
336835	336834	11026G	PARTICIPANT	\N	PRESENT	0
336836	336834	08051V	PARTICIPANT	\N	PRESENT	0
336837	336834	98050T	PARTICIPANT	\N	PRESENT	0
336838	336834	95067Q	PARTICIPANT	\N	PRESENT	0
353755	351932	11083R	PARTICIPANT	\N	PRESENT	0
353756	351932	14123H	PRESIDENT	1	PRESENT	0
355201	352732	08009T	PARTICIPANT	\N	EXCUSE	0
356232	356231	10006L	PARTICIPANT	\N	PRESENT	0
356233	356231	11097X	PARTICIPANT	\N	PRESENT	0
356235	356234	10006L	PARTICIPANT	\N	PRESENT	0
356236	356234	11097X	PARTICIPANT	\N	PRESENT	0
356239	356238	10006L	PARTICIPANT	\N	PRESENT	0
356240	356238	19553Y	PARTICIPANT	\N	PRESENT	0
356241	356238	08052W	PARTICIPANT	\N	PRESENT	0
356243	356242	08052W	PARTICIPANT	\N	PRESENT	0
356244	356242	10006L	PARTICIPANT	\N	PRESENT	0
356245	356242	19553Y	PARTICIPANT	\N	PRESENT	0
356793	356361	04070G	PRESIDENT	0	PRESENT	0
356794	356361	14079W	PARTICIPANT	\N	PRESENT	0
356795	356361	04042C	PARTICIPANT	\N	PRESENT	0
356796	356361	95037J	PARTICIPANT	\N	PRESENT	0
356797	356361	14241N	PARTICIPANT	\N	PRESENT	0
356798	356361	14107H	PARTICIPANT	\N	PRESENT	0
356799	356361	19709B	PARTICIPANT	\N	PRESENT	0
356800	356361	08017T	PARTICIPANT	\N	PRESENT	0
356801	356361	08012N	PARTICIPANT	\N	PRESENT	0
356802	356361	14249W	PARTICIPANT	\N	PRESENT	0
356803	356361	08039A	PARTICIPANT	\N	PRESENT	0
356804	356361	08031R	PARTICIPANT	\N	PRESENT	0
356805	356361	14097Y	PARTICIPANT	\N	PRESENT	0
356806	356361	14133K	PARTICIPANT	\N	PRESENT	0
356807	356361	01062T	PARTICIPANT	\N	PRESENT	0
356808	356361	11041F	PARTICIPANT	\N	PRESENT	0
356809	356361	19251M	PARTICIPANT	\N	PRESENT	0
356810	356361	08020N	PARTICIPANT	\N	PRESENT	0
356811	356361	19735D	PARTICIPANT	\N	PRESENT	0
356812	356361	14267Y	PARTICIPANT	\N	PRESENT	0
356813	356361	11064N	PARTICIPANT	\N	PRESENT	0
356814	356361	11104D	PARTICIPANT	\N	PRESENT	0
356815	356361	11043H	PARTICIPANT	\N	PRESENT	0
356917	355955	14223L	PARTICIPANT	\N	PRESENT	0
356918	355955	14087W	PARTICIPANT	\N	PRESENT	0
356919	355955	08048B	PARTICIPANT	\N	PRESENT	0
356920	355955	10006L	PARTICIPANT	\N	PRESENT	0
356921	355955	11045K	PARTICIPANT	\N	PRESENT	0
356923	356330	19581D	PARTICIPANT	\N	PRESENT	0
356924	356330	04047H	PARTICIPANT	\N	PRESENT	0
356925	356330	14041T	PARTICIPANT	\N	PRESENT	0
356926	356330	14215L	PARTICIPANT	\N	PRESENT	0
356927	356330	14259Y	PARTICIPANT	\N	PRESENT	0
356928	356330	11026G	PARTICIPANT	\N	PRESENT	0
356929	356330	19719D	PARTICIPANT	\N	PRESENT	0
356930	356330	19725B	PARTICIPANT	\N	PRESENT	0
356931	356330	11049P	PARTICIPANT	\N	PRESENT	0
356932	356330	19762G	PARTICIPANT	\N	PRESENT	0
356933	356330	14021P	PARTICIPANT	\N	PRESENT	0
356934	356330	98035U	PARTICIPANT	\N	PRESENT	0
356935	355935	08061X	PARTICIPANT	\N	PRESENT	0
356936	355935	98029W	PARTICIPANT	\N	PRESENT	0
356937	355935	11041F	PARTICIPANT	\N	PRESENT	0
356938	355935	98018T	PARTICIPANT	\N	EXCUSE	0
356939	355935	14193X	PARTICIPANT	\N	EXCUSE	0
356940	356330	14069U	PARTICIPANT	\N	PRESENT	0
356986	356985	11083R	PARTICIPANT	\N	PRESENT	0
356987	356985	08045X	PARTICIPANT	\N	PRESENT	0
356990	356254	19768N	PARTICIPANT	\N	PRESENT	0
356991	356254	19515S	PARTICIPANT	\N	PRESENT	0
356992	356254	19782L	PARTICIPANT	\N	PRESENT	0
356993	356254	11077T	PARTICIPANT	\N	PRESENT	0
356994	356254	14357A	PARTICIPANT	\N	PRESENT	0
356995	356254	19441R	PARTICIPANT	\N	PRESENT	0
356996	356254	14081Q	PARTICIPANT	\N	PRESENT	0
356997	356254	19413M	PARTICIPANT	\N	PRESENT	0
356998	356254	19631V	PARTICIPANT	\N	PRESENT	0
356999	356254	11099A	PARTICIPANT	\N	PRESENT	0
357000	356254	08068F	PARTICIPANT	\N	PRESENT	0
357001	356254	04049K	PARTICIPANT	\N	PRESENT	0
357002	356254	08015R	PARTICIPANT	\N	PRESENT	0
357003	356254	14197C	PARTICIPANT	\N	PRESENT	0
357004	356254	19369B	PARTICIPANT	\N	PRESENT	0
357005	356254	19511N	PARTICIPANT	\N	PRESENT	0
357006	356254	08028W	PARTICIPANT	\N	PRESENT	0
357007	356254	19563B	PARTICIPANT	\N	PRESENT	0
357008	356254	14265W	PARTICIPANT	\N	PRESENT	0
357009	356254	19591F	PARTICIPANT	\N	PRESENT	0
357010	356254	14135M	PARTICIPANT	\N	PRESENT	0
357011	356254	19467C	PARTICIPANT	\N	PRESENT	0
357012	356254	14187A	PARTICIPANT	\N	PRESENT	0
357013	356254	08038Y	PARTICIPANT	\N	PRESENT	0
357014	356254	08062Y	PARTICIPANT	\N	PRESENT	0
357015	356254	19695N	PARTICIPANT	\N	PRESENT	0
357016	356254	14033T	PARTICIPANT	\N	PRESENT	0
357017	356254	11090Q	PRESIDENT	0	PRESENT	0
357018	356254	01025N	PARTICIPANT	\N	PRESENT	0
357019	356254	14205J	PARTICIPANT	\N	PRESENT	0
357020	356254	04088S	PARTICIPANT	\N	PRESENT	0
357021	356254	11056N	PARTICIPANT	\N	PRESENT	0
357022	356254	04089T	PARTICIPANT	\N	PRESENT	0
341515	339496	08017T	PARTICIPANT	\N	PRESENT	0
341516	339496	14241N	PARTICIPANT	\N	PRESENT	0
341517	339496	14229S	PARTICIPANT	\N	PRESENT	0
341518	339496	08043V	PARTICIPANT	\N	PRESENT	0
341519	339496	19565D	PARTICIPANT	\N	PRESENT	0
341520	339496	19503N	PARTICIPANT	\N	PRESENT	0
341521	339496	14225N	PARTICIPANT	\N	PRESENT	0
341522	339496	19691J	PARTICIPANT	\N	PRESENT	0
341523	339496	19782L	PARTICIPANT	\N	PRESENT	0
341559	339496	14089Y	PARTICIPANT	\N	PRESENT	0
341525	339496	04088S	PARTICIPANT	\N	PRESENT	0
341526	339496	14021P	PARTICIPANT	\N	PRESENT	0
341527	339496	19467C	PARTICIPANT	\N	PRESENT	0
341528	339496	14133K	PARTICIPANT	\N	PRESENT	0
341529	339496	14073Q	PARTICIPANT	\N	PRESENT	0
341530	339496	19621T	PARTICIPANT	\N	PRESENT	0
341531	339496	04070G	PARTICIPANT	\N	PRESENT	0
341532	339496	08024S	PARTICIPANT	\N	PRESENT	0
341533	339496	14105F	PARTICIPANT	\N	PRESENT	0
341534	339496	11026G	PARTICIPANT	\N	PRESENT	0
341535	339496	19693L	PARTICIPANT	\N	PRESENT	0
341536	339496	14123H	PARTICIPANT	\N	PRESENT	0
341537	339496	19533U	PARTICIPANT	\N	PRESENT	0
341538	339496	14147R	PARTICIPANT	\N	PRESENT	0
341539	339496	14219Q	PARTICIPANT	\N	PRESENT	0
341540	339496	14121F	PARTICIPANT	\N	PRESENT	0
341541	339496	14111D	PARTICIPANT	\N	PRESENT	0
341542	339496	08056B	PARTICIPANT	\N	PRESENT	0
341543	339496	04059M	PARTICIPANT	\N	PRESENT	0
341544	339496	11049P	PARTICIPANT	\N	PRESENT	0
341549	339496	19727D	PARTICIPANT	\N	PRESENT	0
341550	339496	14107H	PARTICIPANT	\N	PRESENT	0
341551	339496	19387D	PARTICIPANT	\N	PRESENT	0
341552	339496	14063N	PARTICIPANT	\N	PRESENT	0
341553	339496	11066Q	PARTICIPANT	\N	PRESENT	0
341554	339496	11064N	PARTICIPANT	\N	PRESENT	0
341555	339496	19731Y	PARTICIPANT	\N	PRESENT	0
341556	339496	14223L	PARTICIPANT	\N	PRESENT	0
341557	339496	19369B	PARTICIPANT	\N	PRESENT	0
341558	339496	14030Q	PARTICIPANT	\N	PRESENT	0
341560	339496	08031R	PARTICIPANT	\N	PRESENT	0
341561	339496	19347U	PARTICIPANT	\N	PRESENT	0
341562	339496	19383Y	PARTICIPANT	\N	PRESENT	0
341563	339496	08015R	PARTICIPANT	\N	PRESENT	0
341564	339496	19573D	PARTICIPANT	\N	PRESENT	0
341565	339496	19515S	PARTICIPANT	\N	PRESENT	0
342126	342125	04059M	PARTICIPANT	\N	PRESENT	0
342293	339499	19731Y	PARTICIPANT	\N	PRESENT	0
342294	339499	11065P	PARTICIPANT	\N	PRESENT	0
342295	339499	19717B	PARTICIPANT	\N	PRESENT	0
342296	339499	88008L	PARTICIPANT	\N	PRESENT	0
342297	339499	17637T	PARTICIPANT	\N	PRESENT	0
342298	339499	19711U	PARTICIPANT	\N	PRESENT	0
342299	339499	14241N	PARTICIPANT	\N	PRESENT	0
342300	339499	04008A	PARTICIPANT	\N	PRESENT	0
342301	339499	11101A	PARTICIPANT	\N	PRESENT	0
342302	339499	98024R	PARTICIPANT	\N	PRESENT	0
342303	339499	95062K	PARTICIPANT	\N	PRESENT	0
342304	339499	96004D	PARTICIPANT	\N	PRESENT	0
342305	339499	01058X	PARTICIPANT	\N	PRESENT	0
342306	339499	08051V	PARTICIPANT	\N	PRESENT	0
342307	339499	99004R	PARTICIPANT	\N	PRESENT	0
342308	339499	04047H	PARTICIPANT	\N	PRESENT	0
342309	339499	04097T	PARTICIPANT	\N	PRESENT	0
342310	339499	04059M	PARTICIPANT	\N	PRESENT	0
342311	339499	12041X	PARTICIPANT	\N	PRESENT	0
342312	339499	08069G	PARTICIPANT	\N	PRESENT	0
342313	339499	98035U	PARTICIPANT	\N	PRESENT	0
342314	339499	04092N	PARTICIPANT	\N	PRESENT	0
342315	339499	14159V	PARTICIPANT	\N	PRESENT	0
342316	339499	19689Q	PARTICIPANT	\N	PRESENT	0
342317	339499	01028R	PARTICIPANT	\N	PRESENT	0
342318	339499	19679N	PARTICIPANT	\N	PRESENT	0
342319	339499	14229S	PARTICIPANT	\N	PRESENT	0
342320	339499	15447F	PARTICIPANT	\N	PRESENT	0
342321	339499	19643A	PARTICIPANT	\N	PRESENT	0
342322	339499	14169X	PARTICIPANT	\N	PRESENT	0
342323	339499	10015M	PARTICIPANT	\N	PRESENT	0
342324	339499	19649G	PARTICIPANT	\N	PRESENT	0
342325	339499	14223L	PARTICIPANT	\N	PRESENT	0
342326	339499	04033B	PARTICIPANT	\N	PRESENT	0
342327	339499	14187A	PARTICIPANT	\N	PRESENT	0
342329	339499	14071N	PARTICIPANT	\N	PRESENT	0
342330	339499	11097X	PARTICIPANT	\N	PRESENT	0
342332	339499	19421M	PARTICIPANT	\N	PRESENT	0
342334	339499	08038Y	PARTICIPANT	\N	PRESENT	0
342335	339499	01062T	PARTICIPANT	\N	PRESENT	0
342336	339499	11080N	PARTICIPANT	\N	PRESENT	0
342338	339499	19515S	PARTICIPANT	\N	PRESENT	0
342339	339499	19766L	PARTICIPANT	\N	PRESENT	0
342340	339499	01057W	PARTICIPANT	\N	PRESENT	0
342342	339499	87003B	PARTICIPANT	\N	PRESENT	0
342343	339499	19549D	PARTICIPANT	\N	PRESENT	0
342344	339499	04043D	PARTICIPANT	\N	PRESENT	0
342345	339499	14069U	PARTICIPANT	\N	PRESENT	0
342347	339499	14249W	PARTICIPANT	\N	PRESENT	0
342348	339499	19725B	PARTICIPANT	\N	PRESENT	0
342349	339499	11109J	PARTICIPANT	\N	PRESENT	0
342350	339499	11041F	PARTICIPANT	\N	PRESENT	0
342351	339499	14109K	PARTICIPANT	\N	PRESENT	0
342352	339499	19673G	PARTICIPANT	\N	PRESENT	0
342353	339499	14031R	PARTICIPANT	\N	PRESENT	0
342354	339499	19667J	PARTICIPANT	\N	PRESENT	0
342355	339499	19503N	PARTICIPANT	\N	PRESENT	0
342356	339499	14199E	PARTICIPANT	\N	PRESENT	0
342357	339499	19647E	PARTICIPANT	\N	PRESENT	0
342358	339499	19575F	PARTICIPANT	\N	PRESENT	0
342359	339499	19591F	PARTICIPANT	\N	PRESENT	0
342360	339499	11048N	PARTICIPANT	\N	PRESENT	0
342361	339499	19489J	PARTICIPANT	\N	PRESENT	0
342362	339499	04049K	PARTICIPANT	\N	PRESENT	0
342363	339499	05012A	PARTICIPANT	\N	PRESENT	0
342364	339499	19533U	PARTICIPANT	\N	PRESENT	0
342365	339499	07034Q	PARTICIPANT	\N	PRESENT	0
342366	339499	10006L	PARTICIPANT	\N	PRESENT	0
342367	339499	14193X	PARTICIPANT	\N	PRESENT	0
342368	339499	14237S	PARTICIPANT	\N	PRESENT	0
342369	339499	14151M	PARTICIPANT	\N	PRESENT	0
342370	339499	19447X	PARTICIPANT	\N	PRESENT	0
342371	339499	19369B	PARTICIPANT	\N	PRESENT	0
342372	339499	01034P	PARTICIPANT	\N	PRESENT	0
342373	339499	19573D	PARTICIPANT	\N	PRESENT	0
342374	339499	19794Q	PARTICIPANT	\N	PRESENT	0
342375	339499	19691J	PARTICIPANT	\N	PRESENT	0
342376	339499	14133K	PARTICIPANT	\N	PRESENT	0
342377	339499	11053K	PARTICIPANT	\N	PRESENT	0
342378	339499	14105F	PARTICIPANT	\N	PRESENT	0
342379	339499	14083S	PARTICIPANT	\N	PRESENT	0
342380	339499	19699S	PARTICIPANT	\N	PRESENT	0
342381	339499	17583W	PARTICIPANT	\N	PRESENT	0
342382	339499	19737F	PARTICIPANT	\N	PRESENT	0
342383	339499	97011G	PARTICIPANT	\N	PRESENT	0
342384	339499	19747H	PARTICIPANT	\N	PRESENT	0
342385	339499	11070L	PARTICIPANT	\N	PRESENT	0
342386	339499	11049P	PARTICIPANT	\N	PRESENT	0
342387	339499	14219Q	PARTICIPANT	\N	PRESENT	0
342388	339499	19441R	PARTICIPANT	\N	PRESENT	0
342389	339499	14042U	PARTICIPANT	\N	PRESENT	0
342390	339499	19713W	PARTICIPANT	\N	PRESENT	0
342391	339499	19749K	PARTICIPANT	\N	PRESENT	0
342392	339499	14093U	PARTICIPANT	\N	PRESENT	0
342393	339499	19577H	PARTICIPANT	\N	PRESENT	0
342394	339499	14073Q	PARTICIPANT	\N	PRESENT	0
342395	339499	19721W	PARTICIPANT	\N	PRESENT	0
342485	340480	14257W	PARTICIPANT	\N	PRESENT	0
342487	340480	08010L	PARTICIPANT	\N	PRESENT	0
342489	340480	08049C	PARTICIPANT	\N	PRESENT	0
342491	340480	11101A	PARTICIPANT	\N	PRESENT	0
342492	340480	19735D	PARTICIPANT	\N	PRESENT	0
342493	340480	14028W	PARTICIPANT	\N	PRESENT	0
342494	340480	14231L	PARTICIPANT	\N	PRESENT	0
342495	340480	05012A	PARTICIPANT	\N	PRESENT	0
343152	343151	11072N	PARTICIPANT	\N	PRESENT	0
343450	339504	04038G	PARTICIPANT	\N	PRESENT	0
343451	339504	19593H	PARTICIPANT	\N	PRESENT	0
343452	339504	19695N	PARTICIPANT	\N	PRESENT	0
343453	339504	04085P	PARTICIPANT	\N	PRESENT	0
343454	339504	11040E	PARTICIPANT	\N	PRESENT	0
343455	339504	19687N	PARTICIPANT	\N	PRESENT	0
343456	339504	01048V	PARTICIPANT	\N	PRESENT	0
343457	339504	19760E	PARTICIPANT	\N	PRESENT	0
343458	339504	01058X	PARTICIPANT	\N	PRESENT	0
343459	339504	19565D	PARTICIPANT	\N	PRESENT	0
343448	339504	11031D	PARTICIPANT	\N	PRESENT	0
343449	339504	19758L	PARTICIPANT	\N	PRESENT	0
343460	339504	11077T	PARTICIPANT	\N	PRESENT	0
343461	339504	19347U	PARTICIPANT	\N	PRESENT	0
343462	339504	19766L	PARTICIPANT	\N	PRESENT	0
337782	337781	19511N	PARTICIPANT	\N	PRESENT	0
337783	337781	11090Q	PARTICIPANT	\N	PRESENT	0
337784	337781	96004D	PARTICIPANT	\N	PRESENT	0
337786	337781	04097T	PARTICIPANT	\N	PRESENT	0
337787	337781	14357A	PARTICIPANT	\N	PRESENT	0
337788	337781	95037J	PARTICIPANT	\N	PRESENT	0
338175	337899	19533U	PARTICIPANT	\N	PRESENT	0
343155	343154	19717B	PARTICIPANT	\N	PRESENT	0
343156	343154	14065Q	PARTICIPANT	\N	PRESENT	0
343157	343154	14069U	PARTICIPANT	\N	PRESENT	0
343158	343154	19693L	PARTICIPANT	\N	PRESENT	0
343159	343154	19727D	PARTICIPANT	\N	PRESENT	0
343160	343154	14179A	PARTICIPANT	\N	PRESENT	0
343161	343154	08017T	PARTICIPANT	\N	PRESENT	0
343162	343154	04070G	PARTICIPANT	\N	PRESENT	0
343163	343154	05012A	PARTICIPANT	\N	PRESENT	0
348092	348091	08055A	PARTICIPANT	\N	PRESENT	0
343183	341436	14147R	PARTICIPANT	\N	PRESENT	0
343184	341436	08024S	PARTICIPANT	\N	PRESENT	0
348094	348091	14085U	PARTICIPANT	\N	PRESENT	0
348093	348091	04047H	PARTICIPANT	\N	PRESENT	0
354827	353834	14147R	PARTICIPANT	\N	PRESENT	0
354828	353834	11067R	PARTICIPANT	\N	PRESENT	0
354829	353834	19533U	PRESIDENT	0	PRESENT	0
356247	356246	99004R	PRESIDENT	0	PRESENT	0
354831	353834	19749K	PARTICIPANT	\N	PRESENT	0
354832	353834	11043H	PARTICIPANT	\N	PRESENT	0
356258	351756	99004R	PRESIDENT	0	PRESENT	0
356259	351756	19369B	PARTICIPANT	\N	PRESENT	0
356816	355933	19583F	PARTICIPANT	\N	EXCUSE	0
356817	355933	14028W	PARTICIPANT	\N	EXCUSE	0
356818	355933	14193X	PARTICIPANT	\N	EXCUSE	0
356819	355933	11054L	PARTICIPANT	\N	EXCUSE	0
357182	356855	14107H	PARTICIPANT	\N	EXCUSE	0
357183	356273	19447X	PARTICIPANT	\N	PRESENT	0
357184	356273	14259Y	PARTICIPANT	\N	PRESENT	0
357185	355935	19583F	PARTICIPANT	\N	EXCUSE	0
357186	355935	11054L	PARTICIPANT	\N	EXCUSE	0
357222	356865	19333N	PARTICIPANT	\N	PRESENT	0
357223	356865	19383Y	PARTICIPANT	\N	PRESENT	0
357224	356865	17583W	PARTICIPANT	\N	PRESENT	0
357225	356865	19794Q	PARTICIPANT	\N	PRESENT	0
357226	356865	95062K	PARTICIPANT	\N	PRESENT	0
357227	356865	19549D	PARTICIPANT	\N	PRESENT	0
357228	356865	19387D	PARTICIPANT	\N	PRESENT	0
357229	356865	14219Q	PARTICIPANT	\N	PRESENT	0
357230	356865	14221J	PARTICIPANT	\N	PRESENT	0
357231	356865	19599P	PARTICIPANT	\N	PRESENT	0
357232	356865	19637C	PARTICIPANT	\N	PRESENT	0
357233	356865	14231L	PARTICIPANT	\N	PRESENT	0
357234	356865	02002K	PARTICIPANT	\N	PRESENT	0
357235	356865	19551W	PARTICIPANT	\N	PRESENT	0
357236	356865	18083K	PARTICIPANT	\N	PRESENT	0
357237	356865	14237S	PARTICIPANT	\N	PRESENT	0
357238	356865	80027E	PARTICIPANT	\N	PRESENT	0
357239	356865	05012A	PARTICIPANT	\N	PRESENT	0
357240	356865	14051J	PARTICIPANT	\N	PRESENT	0
357241	356865	08060W	PARTICIPANT	\N	PRESENT	0
357242	356865	19347U	PARTICIPANT	\N	PRESENT	0
357243	356865	19503N	PARTICIPANT	\N	PRESENT	0
357244	356865	96004D	PARTICIPANT	\N	PRESENT	0
357245	356865	14157T	PARTICIPANT	\N	PRESENT	0
357246	356865	08024S	PARTICIPANT	\N	PRESENT	0
357247	356865	17637T	PARTICIPANT	\N	PRESENT	0
357248	356865	11065P	PARTICIPANT	\N	PRESENT	0
357249	356865	19525U	PARTICIPANT	\N	PRESENT	0
357250	356865	14038Y	PARTICIPANT	\N	PRESENT	0
357251	356865	14103D	PARTICIPANT	\N	PRESENT	0
357252	356865	19713W	PARTICIPANT	\N	PRESENT	0
357253	356865	14031R	PARTICIPANT	\N	PRESENT	0
357254	356865	08055A	PARTICIPANT	\N	PRESENT	0
357255	356865	19289C	PARTICIPANT	\N	PRESENT	0
357256	356865	14191V	PARTICIPANT	\N	PRESENT	0
357257	356865	04085P	PARTICIPANT	\N	PRESENT	0
357258	356865	15447F	PARTICIPANT	\N	PRESENT	0
357259	356865	14093U	PARTICIPANT	\N	PRESENT	0
357260	356865	14029X	PARTICIPANT	\N	PRESENT	0
357261	356865	19733B	PARTICIPANT	\N	PRESENT	0
357262	356865	08009T	PRESIDENT	0	PRESENT	0
357263	356865	19737F	PARTICIPANT	\N	PRESENT	0
357264	356865	04097T	PARTICIPANT	\N	PRESENT	0
357265	356865	19739H	PARTICIPANT	\N	PRESENT	0
357266	356865	19745F	PARTICIPANT	\N	PRESENT	0
357267	356865	19701S	PARTICIPANT	\N	EXCUSE	0
357268	356865	19685L	PARTICIPANT	\N	EXCUSE	0
357269	356865	19659J	PARTICIPANT	\N	EXCUSE	0
357270	356865	19681G	PARTICIPANT	\N	EXCUSE	0
357272	345117	01043Q	PARTICIPANT	\N	PRESENT	0
357273	345117	14039A	PARTICIPANT	\N	PRESENT	0
357274	345117	19731Y	PARTICIPANT	\N	PRESENT	0
357275	345117	17589D	PARTICIPANT	\N	PRESENT	0
357276	345117	04057K	PARTICIPANT	\N	PRESENT	0
357277	345117	14191V	PARTICIPANT	\N	PRESENT	0
357278	345117	14211G	PARTICIPANT	\N	PRESENT	0
357279	345117	99004R	PARTICIPANT	\N	PRESENT	0
357280	345117	14073Q	PARTICIPANT	\N	PRESENT	0
357281	345117	11043H	PARTICIPANT	\N	PRESENT	0
357282	345117	19711U	PARTICIPANT	\N	PRESENT	0
357283	345117	19335Q	PARTICIPANT	\N	PRESENT	0
357284	345117	14265W	PARTICIPANT	\N	PRESENT	0
357285	345117	14207L	PARTICIPANT	\N	PRESENT	0
357286	345117	19399H	PARTICIPANT	\N	PRESENT	0
357287	345117	14033T	PARTICIPANT	\N	PRESENT	0
357288	345117	14215L	PARTICIPANT	\N	PRESENT	0
357289	345117	19758L	PARTICIPANT	\N	PRESENT	0
357290	345117	11040E	PARTICIPANT	\N	PRESENT	0
357291	345117	08068F	PARTICIPANT	\N	PRESENT	0
357292	345117	14021P	PARTICIPANT	\N	PRESENT	0
357293	345117	19301E	PARTICIPANT	\N	PRESENT	0
357294	345117	14241N	PARTICIPANT	\N	PRESENT	0
357295	345117	19543W	PARTICIPANT	\N	PRESENT	0
357296	345117	14179A	PARTICIPANT	\N	PRESENT	0
357297	345117	14042U	PARTICIPANT	\N	PRESENT	0
357298	345117	97011G	PARTICIPANT	\N	PRESENT	0
357299	345117	14059S	PARTICIPANT	\N	PRESENT	0
357300	345117	89017R	PARTICIPANT	\N	PRESENT	0
357301	345117	04018C	PARTICIPANT	\N	PRESENT	0
357302	345117	11048N	PARTICIPANT	\N	PRESENT	0
357303	345117	14123H	PARTICIPANT	\N	PRESENT	0
357304	345117	14249W	PARTICIPANT	\N	PRESENT	0
357305	345117	08049C	PARTICIPANT	\N	PRESENT	0
357306	345117	19611R	PARTICIPANT	\N	PRESENT	0
357307	345117	19367Y	PARTICIPANT	\N	PRESENT	0
357308	345117	19673G	PARTICIPANT	\N	PRESENT	0
357309	345117	19703U	PARTICIPANT	\N	PRESENT	0
357310	345117	19723Y	PARTICIPANT	\N	PRESENT	0
357311	345117	04070G	PARTICIPANT	\N	PRESENT	0
357312	345117	19349W	PARTICIPANT	\N	PRESENT	0
357313	345117	08061X	PARTICIPANT	\N	PRESENT	0
357314	345117	14331P	PARTICIPANT	\N	PRESENT	0
357315	345117	14089Y	PARTICIPANT	\N	PRESENT	0
357316	345117	01025N	PARTICIPANT	\N	PRESENT	0
357317	345117	08015R	PARTICIPANT	\N	PRESENT	0
357318	345117	11103C	PARTICIPANT	\N	PRESENT	0
357319	345117	19762G	PARTICIPANT	\N	PRESENT	0
357320	345117	14061L	PARTICIPANT	\N	PRESENT	0
357321	357271	19333N	PARTICIPANT	\N	PRESENT	0
357322	357271	19383Y	PARTICIPANT	\N	PRESENT	0
357323	357271	17583W	PARTICIPANT	\N	PRESENT	0
357324	357271	19794Q	PARTICIPANT	\N	PRESENT	0
357325	357271	19549D	PARTICIPANT	\N	PRESENT	0
357326	357271	19387D	PARTICIPANT	\N	PRESENT	0
357327	357271	14219Q	PARTICIPANT	\N	PRESENT	0
357328	357271	19599P	PARTICIPANT	\N	PRESENT	0
357329	357271	19637C	PARTICIPANT	\N	PRESENT	0
357330	357271	19551W	PARTICIPANT	\N	PRESENT	0
357331	357271	18083K	PARTICIPANT	\N	PRESENT	0
357332	357271	14237S	PARTICIPANT	\N	PRESENT	0
357333	357271	14051J	PARTICIPANT	\N	PRESENT	0
357334	357271	08060W	PARTICIPANT	\N	PRESENT	0
357335	357271	19503N	PARTICIPANT	\N	PRESENT	0
357336	357271	19525U	PARTICIPANT	\N	PRESENT	0
357337	357271	14038Y	PARTICIPANT	\N	PRESENT	0
357338	357271	14103D	PARTICIPANT	\N	PRESENT	0
357339	357271	14031R	PARTICIPANT	\N	PRESENT	0
357340	357271	08055A	PARTICIPANT	\N	PRESENT	0
357341	357271	04085P	PARTICIPANT	\N	PRESENT	0
357342	357271	15447F	PARTICIPANT	\N	PRESENT	0
357343	357271	14029X	PARTICIPANT	\N	PRESENT	0
357344	357271	19733B	PARTICIPANT	\N	PRESENT	0
357345	357271	08009T	PRESIDENT	0	PRESENT	0
357346	357271	19739H	PARTICIPANT	\N	PRESENT	0
357347	357271	19701S	PARTICIPANT	\N	EXCUSE	0
357348	357271	19685L	PARTICIPANT	\N	EXCUSE	0
357349	357271	19659J	PARTICIPANT	\N	EXCUSE	0
357350	357271	19681G	PARTICIPANT	\N	EXCUSE	0
348592	339524	19758L	PARTICIPANT	\N	PRESENT	0
348593	339524	19565D	PARTICIPANT	\N	PRESENT	0
348594	339524	95037J	PARTICIPANT	\N	PRESENT	0
348595	339524	11083R	PARTICIPANT	\N	PRESENT	0
348596	339524	19349W	PARTICIPANT	\N	PRESENT	0
348597	339524	92040Q	PARTICIPANT	\N	PRESENT	0
348598	339524	19637C	PARTICIPANT	\N	PRESENT	0
348599	339524	14119M	PARTICIPANT	\N	PRESENT	0
348600	339524	14239U	PARTICIPANT	\N	PRESENT	0
348601	339524	19543W	PARTICIPANT	\N	PRESENT	0
348602	339524	11048N	PARTICIPANT	\N	PRESENT	0
348603	339524	19697Q	PARTICIPANT	\N	PRESENT	0
348604	339524	14039A	PARTICIPANT	\N	PRESENT	0
348605	339524	19301E	PARTICIPANT	\N	PRESENT	0
348606	339524	08024S	PARTICIPANT	\N	PRESENT	0
348607	339524	19782L	PARTICIPANT	\N	PRESENT	0
348608	339524	14033T	PARTICIPANT	\N	PRESENT	0
348609	339524	14135M	PARTICIPANT	\N	PRESENT	0
348610	339524	19399H	PARTICIPANT	\N	PRESENT	0
348611	339524	19585H	PARTICIPANT	\N	PRESENT	0
348612	339524	19693L	PARTICIPANT	\N	PRESENT	0
348613	339524	19545Y	PARTICIPANT	\N	PRESENT	0
348614	339524	17589D	PARTICIPANT	\N	PRESENT	0
348615	339524	14111D	PARTICIPANT	\N	PRESENT	0
348616	339524	04057K	PARTICIPANT	\N	PRESENT	0
348617	339524	14251Q	PARTICIPANT	\N	PRESENT	0
348618	339524	08048B	PARTICIPANT	\N	PRESENT	0
348619	339524	11064N	PARTICIPANT	\N	PRESENT	0
348620	339524	14265W	PARTICIPANT	\N	PRESENT	0
348621	339524	19583F	PARTICIPANT	\N	PRESENT	0
348622	339524	14213J	PARTICIPANT	\N	PRESENT	0
348623	339524	14195A	PARTICIPANT	\N	PRESENT	0
348624	339524	02002K	PARTICIPANT	\N	PRESENT	0
348625	339524	11090Q	PARTICIPANT	\N	PRESENT	0
348626	339524	19760E	PARTICIPANT	\N	PRESENT	0
348627	339524	14147R	PARTICIPANT	\N	PRESENT	0
348628	339524	19768N	PARTICIPANT	\N	PRESENT	0
348629	339524	04085P	PARTICIPANT	\N	PRESENT	0
348630	339524	14235Q	PARTICIPANT	\N	PRESENT	0
348631	339524	08015R	PARTICIPANT	\N	PRESENT	0
348632	339524	08039A	PARTICIPANT	\N	PRESENT	0
348633	339524	19731Y	PARTICIPANT	\N	PRESENT	0
348634	339524	11012A	PARTICIPANT	\N	PRESENT	0
348635	339524	14034U	PARTICIPANT	\N	PRESENT	0
348636	339524	08051V	PARTICIPANT	\N	PRESENT	0
348637	339524	14115H	PARTICIPANT	\N	PRESENT	0
348638	339524	14261S	PARTICIPANT	\N	PRESENT	0
348639	339524	88008L	PARTICIPANT	\N	PRESENT	0
348640	339524	19673G	PARTICIPANT	\N	PRESENT	0
348641	339524	19629C	PARTICIPANT	\N	PRESENT	0
348642	339524	08049C	PARTICIPANT	\N	PRESENT	0
348643	339524	04086Q	PARTICIPANT	\N	PRESENT	0
348644	339524	19563B	PARTICIPANT	\N	PRESENT	0
348645	339524	04092N	PARTICIPANT	\N	PRESENT	0
348646	339524	98022P	PARTICIPANT	\N	PRESENT	0
348647	339524	14241N	PARTICIPANT	\N	PRESENT	0
348648	339524	04044E	PARTICIPANT	\N	PRESENT	0
348649	339524	14107H	PARTICIPANT	\N	PRESENT	0
348650	339524	11065P	PARTICIPANT	\N	PRESENT	0
348651	339524	11097X	PARTICIPANT	\N	PRESENT	0
348652	339524	19421M	PARTICIPANT	\N	PRESENT	0
348653	339524	14071N	PARTICIPANT	\N	PRESENT	0
348654	339524	19681G	PARTICIPANT	\N	PRESENT	0
348655	339524	14187A	PARTICIPANT	\N	PRESENT	0
348656	339524	14069U	PARTICIPANT	\N	PRESENT	0
348657	339524	19289C	PARTICIPANT	\N	PRESENT	0
348658	339524	08031R	PARTICIPANT	\N	PRESENT	0
348659	339524	04035D	PARTICIPANT	\N	PRESENT	0
348660	339524	11109J	PARTICIPANT	\N	PRESENT	0
348661	339524	14249W	PARTICIPANT	\N	PRESENT	0
348662	339524	04059M	PARTICIPANT	\N	PRESENT	0
348663	339524	14229S	PARTICIPANT	\N	PRESENT	0
348664	339524	14215L	PARTICIPANT	\N	PRESENT	0
348665	339524	98035U	PARTICIPANT	\N	PRESENT	0
348666	339524	01028R	PARTICIPANT	\N	PRESENT	0
348667	339524	14237S	PARTICIPANT	\N	PRESENT	0
348668	339524	08055A	PARTICIPANT	\N	PRESENT	0
348669	339524	14193X	PARTICIPANT	\N	PRESENT	0
348670	339524	08052W	PARTICIPANT	\N	PRESENT	0
348671	339524	07034Q	PARTICIPANT	\N	PRESENT	0
348672	339524	19689Q	PARTICIPANT	\N	PRESENT	0
348673	339524	14051J	PARTICIPANT	\N	PRESENT	0
348674	339524	10006L	PARTICIPANT	\N	PRESENT	0
348675	339524	08068F	PARTICIPANT	\N	PRESENT	0
348676	339524	11074Q	PARTICIPANT	\N	PRESENT	0
348677	339524	19533U	PARTICIPANT	\N	PRESENT	0
348678	339524	14021P	PARTICIPANT	\N	PRESENT	0
348679	339524	05012A	PARTICIPANT	\N	PRESENT	0
348680	339524	08045X	PARTICIPANT	\N	PRESENT	0
348681	339524	19599P	PARTICIPANT	\N	PRESENT	0
348682	339524	97011G	PARTICIPANT	\N	PRESENT	0
348683	339524	19669L	PARTICIPANT	\N	PRESENT	0
348684	339524	14331P	PARTICIPANT	\N	PRESENT	0
348685	339524	14151M	PARTICIPANT	\N	PRESENT	0
348686	339524	19715Y	PARTICIPANT	\N	PRESENT	0
348687	339524	14217N	PARTICIPANT	\N	PRESENT	0
348590	339524	04045F	PARTICIPANT	\N	PRESENT	0
348591	339524	04034C	PARTICIPANT	\N	PRESENT	0
348688	339524	01062T	PARTICIPANT	\N	PRESENT	0
348689	339524	08060W	PARTICIPANT	\N	PRESENT	0
348690	339524	14079W	PARTICIPANT	\N	PRESENT	0
348691	339524	80013X	PARTICIPANT	\N	PRESENT	0
348692	339524	19649G	PARTICIPANT	\N	PRESENT	0
348693	339524	19671E	PARTICIPANT	\N	PRESENT	0
348694	339524	11045K	PARTICIPANT	\N	PRESENT	0
348695	339524	14065Q	PARTICIPANT	\N	PRESENT	0
348696	339524	19549D	PARTICIPANT	\N	PRESENT	0
348697	339524	19747H	PARTICIPANT	\N	PRESENT	0
348698	339524	08043V	PARTICIPANT	\N	PRESENT	0
348699	339524	11066Q	PARTICIPANT	\N	PRESENT	0
348700	339524	19581D	PARTICIPANT	\N	PRESENT	0
348701	339524	11104D	PARTICIPANT	\N	PRESENT	0
348702	339524	19631V	PARTICIPANT	\N	PRESENT	0
348703	339524	19621T	PARTICIPANT	\N	PRESENT	0
348704	339524	08035V	PARTICIPANT	\N	PRESENT	0
348705	339524	08012N	PARTICIPANT	\N	PRESENT	0
348706	339524	04018C	PARTICIPANT	\N	PRESENT	0
348707	339524	19727D	PARTICIPANT	\N	PRESENT	0
348708	339524	11110B	PARTICIPANT	\N	PRESENT	0
348709	339524	19525U	PARTICIPANT	\N	PRESENT	0
348710	339524	08017T	PARTICIPANT	\N	PRESENT	0
348711	339524	19701S	PARTICIPANT	\N	PRESENT	0
348712	339524	14085U	PARTICIPANT	\N	PRESENT	0
348713	339524	14121F	PARTICIPANT	\N	PRESENT	0
348714	339524	19762G	PARTICIPANT	\N	PRESENT	0
348715	339524	19489J	PARTICIPANT	\N	PRESENT	0
348716	339524	17779H	PARTICIPANT	\N	PRESENT	0
348717	339524	14169X	PARTICIPANT	\N	PRESENT	0
348745	339524	11067R	PARTICIPANT	\N	PRESENT	0
348719	339524	19383Y	PARTICIPANT	\N	PRESENT	0
348720	339524	08038Y	PARTICIPANT	\N	PRESENT	0
348721	339524	14357A	PARTICIPANT	\N	PRESENT	0
348722	339524	14329V	PARTICIPANT	\N	PRESENT	0
348723	339524	08014Q	PARTICIPANT	\N	PRESENT	0
348724	339524	19333N	PARTICIPANT	\N	PRESENT	0
348725	339524	14001X	PARTICIPANT	\N	PRESENT	0
348726	339524	19683J	PARTICIPANT	\N	PRESENT	0
348727	339524	14227Q	PARTICIPANT	\N	PRESENT	0
348728	339524	19675J	PARTICIPANT	\N	PRESENT	0
348729	339524	89017R	PARTICIPANT	\N	PRESENT	0
348730	339524	01060R	PARTICIPANT	\N	PRESENT	0
348731	339524	14061L	PARTICIPANT	\N	PRESENT	0
348732	339524	14059S	PARTICIPANT	\N	PRESENT	0
348733	339524	19733B	PARTICIPANT	\N	PRESENT	0
348734	339524	01048V	PARTICIPANT	\N	PRESENT	0
348735	339524	04043D	PARTICIPANT	\N	PRESENT	0
348736	339524	95067Q	PARTICIPANT	\N	PRESENT	0
348737	339524	19269X	PARTICIPANT	\N	PRESENT	0
348738	339524	19663E	PARTICIPANT	\N	PRESENT	0
348739	339524	14041T	PARTICIPANT	\N	PRESENT	0
348740	339524	11072N	PARTICIPANT	\N	PRESENT	0
348741	339524	19591F	PARTICIPANT	\N	PRESENT	0
348742	339524	14257W	PARTICIPANT	\N	PRESENT	0
348743	339524	14081Q	PARTICIPANT	\N	PRESENT	0
348744	339524	19725B	PARTICIPANT	\N	PRESENT	0
348746	339524	14063N	PARTICIPANT	\N	PRESENT	0
348747	339524	19527W	PARTICIPANT	\N	PRESENT	0
348748	339524	19551W	PARTICIPANT	\N	PRESENT	0
348749	339524	19503N	PARTICIPANT	\N	PRESENT	0
348750	339524	19413M	PARTICIPANT	\N	PRESENT	0
348751	339524	19251M	PARTICIPANT	\N	PRESENT	0
348752	339524	14097Y	PARTICIPANT	\N	PRESENT	0
348753	339524	14087W	PARTICIPANT	\N	PRESENT	0
348754	339524	14231L	PARTICIPANT	\N	PRESENT	0
348755	339524	04089T	PARTICIPANT	\N	PRESENT	0
348756	339524	14179A	PARTICIPANT	\N	PRESENT	0
348757	339524	01034P	PARTICIPANT	\N	PRESENT	0
348758	339524	19691J	PARTICIPANT	\N	PRESENT	0
333449	321368	86034E	PARTICIPANT	\N	PRESENT	0
333450	331590	19735D	PARTICIPANT	\N	PRESENT	0
333469	333056	11027H	PARTICIPANT	\N	PRESENT	0
333470	333056	14039A	PARTICIPANT	\N	PRESENT	0
333471	333056	19643A	PARTICIPANT	\N	PRESENT	0
333472	333056	14073Q	PARTICIPANT	\N	PRESENT	0
333473	333056	19693L	PARTICIPANT	\N	PRESENT	0
333474	333056	14109K	PARTICIPANT	\N	PRESENT	0
333475	333056	08012N	PARTICIPANT	\N	PRESENT	0
333476	333056	14249W	PARTICIPANT	\N	PRESENT	0
333477	333056	14097Y	PARTICIPANT	\N	PRESENT	0
333478	333056	19735D	PARTICIPANT	\N	PRESENT	0
333479	333056	11043H	PARTICIPANT	\N	PRESENT	0
333480	321368	14065Q	PARTICIPANT	\N	PRESENT	0
333481	321368	19687N	PARTICIPANT	\N	PRESENT	0
333482	321368	19631V	PARTICIPANT	\N	PRESENT	0
333483	321368	01057W	PARTICIPANT	\N	PRESENT	0
333485	321368	14225N	PARTICIPANT	\N	PRESENT	0
333487	321368	14179A	PARTICIPANT	\N	PRESENT	0
333488	321368	14121F	PARTICIPANT	\N	PRESENT	0
333489	321368	14001X	PARTICIPANT	\N	PRESENT	0
333490	321368	19441R	PARTICIPANT	\N	PRESENT	0
333491	321368	14219Q	PARTICIPANT	\N	PRESENT	0
333492	321368	19745F	PARTICIPANT	\N	PRESENT	0
333493	321368	04097T	PARTICIPANT	\N	PRESENT	0
333494	321368	01043Q	PARTICIPANT	\N	PRESENT	0
333495	321368	19667J	PARTICIPANT	\N	PRESENT	0
333496	321368	14327T	PARTICIPANT	\N	PRESENT	0
333497	321368	10015M	PARTICIPANT	\N	PRESENT	0
333498	321368	19711U	PARTICIPANT	\N	PRESENT	0
333499	321368	08009T	PARTICIPANT	\N	PRESENT	0
333500	321368	11012A	PARTICIPANT	\N	PRESENT	0
333501	321368	04086Q	PARTICIPANT	\N	PRESENT	0
333502	321368	88008L	PARTICIPANT	\N	PRESENT	0
333503	321368	17637T	PARTICIPANT	\N	PRESENT	0
333504	321368	19387D	PARTICIPANT	\N	PRESENT	0
333505	321368	14231L	PARTICIPANT	\N	PRESENT	0
333506	321368	14147R	PARTICIPANT	\N	PRESENT	0
333507	321368	11070L	PARTICIPANT	\N	PRESENT	0
333508	321368	07004J	PARTICIPANT	\N	PRESENT	0
333509	321368	19739H	PARTICIPANT	\N	PRESENT	0
333510	321368	08044W	PARTICIPANT	\N	PRESENT	0
333511	321368	04038G	PARTICIPANT	\N	PRESENT	0
333512	321368	04071H	PARTICIPANT	\N	PRESENT	0
333513	321368	04088S	PARTICIPANT	\N	PRESENT	0
333514	321368	19507S	PARTICIPANT	\N	PRESENT	0
333515	321368	14033T	PARTICIPANT	\N	PRESENT	0
333516	321368	15447F	PARTICIPANT	\N	PRESENT	0
333517	321368	14173T	PARTICIPANT	\N	PRESENT	0
333518	321368	19671E	PARTICIPANT	\N	PRESENT	0
333540	321368	14267Y	PARTICIPANT	\N	PRESENT	0
333541	333055	04070G	PRESIDENT	0	PRESENT	0
333542	333055	19643A	PARTICIPANT	\N	PRESENT	0
333543	333055	19699S	PARTICIPANT	\N	PRESENT	0
333544	333055	14061L	PARTICIPANT	\N	PRESENT	0
333545	333055	04057K	PARTICIPANT	\N	PRESENT	0
333546	333055	19533U	PARTICIPANT	\N	PRESENT	0
333547	333055	19611R	PARTICIPANT	\N	PRESENT	0
333548	333055	08043V	PARTICIPANT	\N	PRESENT	0
333549	333055	19693L	PARTICIPANT	\N	PRESENT	0
333550	333055	14201E	PARTICIPANT	\N	PRESENT	0
333551	333055	14241N	PARTICIPANT	\N	PRESENT	0
333552	333055	19731Y	PARTICIPANT	\N	PRESENT	0
333553	333055	19573D	PARTICIPANT	\N	PRESENT	0
333554	333055	14039A	PARTICIPANT	\N	PRESENT	0
333555	333055	19735D	PARTICIPANT	\N	PRESENT	0
333556	333055	08017T	PARTICIPANT	\N	PRESENT	0
333557	333055	14109K	PARTICIPANT	\N	PRESENT	0
333558	333055	14123H	PARTICIPANT	\N	PRESENT	0
333559	333055	11104D	PARTICIPANT	\N	PRESENT	0
333560	333055	19749K	PARTICIPANT	\N	PRESENT	0
333561	333055	04018C	PARTICIPANT	\N	PRESENT	0
333562	333055	19758L	PARTICIPANT	\N	PRESENT	0
333563	333055	19621T	PARTICIPANT	\N	PRESENT	0
333564	321368	08012N	PARTICIPANT	\N	PRESENT	0
333565	321368	19782L	PARTICIPANT	\N	PRESENT	0
333566	321368	97011G	PARTICIPANT	\N	PRESENT	0
333567	321368	19683J	PARTICIPANT	\N	PRESENT	0
333568	321368	08024S	PARTICIPANT	\N	PRESENT	0
333569	321368	14249W	PARTICIPANT	\N	PRESENT	0
333570	321368	14251Q	PARTICIPANT	\N	PRESENT	0
333571	321368	14073Q	PARTICIPANT	\N	PRESENT	0
333572	321368	08055A	PARTICIPANT	\N	PRESENT	0
333573	321368	14063N	PARTICIPANT	\N	PRESENT	0
333574	321368	01024M	PARTICIPANT	\N	PRESENT	0
333575	321368	08015R	PARTICIPANT	\N	PRESENT	0
333576	321368	95067Q	PARTICIPANT	\N	PRESENT	0
333577	321368	80013X	PARTICIPANT	\N	PRESENT	0
333578	321368	08069G	PARTICIPANT	\N	PRESENT	0
333579	321368	14061L	PARTICIPANT	\N	PRESENT	0
333580	321368	19531S	PARTICIPANT	\N	PRESENT	0
333581	321368	04044E	PARTICIPANT	\N	PRESENT	0
333582	321368	04033B	PARTICIPANT	\N	PRESENT	0
333583	321368	11104D	PARTICIPANT	\N	PRESENT	0
333584	321368	19545Y	PARTICIPANT	\N	PRESENT	0
333585	321368	95030B	PARTICIPANT	\N	PRESENT	0
333586	321368	19681G	PARTICIPANT	\N	PRESENT	0
333588	321368	14069U	PARTICIPANT	\N	PRESENT	0
333589	333055	14030Q	PARTICIPANT	\N	PRESENT	0
333590	333055	11109J	PARTICIPANT	\N	PRESENT	0
333591	333055	11043H	PARTICIPANT	\N	PRESENT	0
333592	321368	19515S	PARTICIPANT	\N	PRESENT	0
333593	321368	14257W	PARTICIPANT	\N	PRESENT	0
333594	321368	95063L	PARTICIPANT	\N	PRESENT	0
333595	321368	19673G	PARTICIPANT	\N	PRESENT	0
333596	321368	14083S	PARTICIPANT	\N	PRESENT	0
333600	321368	11049P	PARTICIPANT	\N	PRESENT	0
333601	321368	14157T	PARTICIPANT	\N	PRESENT	0
333602	321368	19399H	PARTICIPANT	\N	PRESENT	0
333603	321368	05008E	PARTICIPANT	\N	PRESENT	0
333604	321368	08038Y	PARTICIPANT	\N	PRESENT	0
333605	321368	11110B	PARTICIPANT	\N	PRESENT	0
333606	321368	11101A	PARTICIPANT	\N	PRESENT	0
333607	321368	99004R	PARTICIPANT	\N	PRESENT	0
333608	321368	19713W	PARTICIPANT	\N	PRESENT	0
333611	321368	19583F	PARTICIPANT	\N	PRESENT	0
333613	321368	14089Y	PARTICIPANT	\N	PRESENT	0
333614	321368	14331P	PARTICIPANT	\N	PRESENT	0
333615	321368	19741B	PARTICIPANT	\N	PRESENT	0
333616	321368	08051V	PARTICIPANT	\N	PRESENT	0
333617	321368	19447X	PARTICIPANT	\N	PRESENT	0
333618	321368	12016W	PARTICIPANT	\N	PRESENT	0
333619	321368	14187A	PARTICIPANT	\N	PRESENT	0
333620	321368	19611R	PARTICIPANT	\N	PRESENT	0
333621	321368	89017R	PARTICIPANT	\N	PRESENT	0
333622	321368	14021P	PARTICIPANT	\N	PRESENT	0
333623	321368	01058X	PARTICIPANT	\N	PRESENT	0
333624	330628	11067R	PARTICIPANT	\N	PRESENT	0
333625	330628	11097X	PARTICIPANT	\N	PRESENT	0
333626	330628	19415P	PARTICIPANT	\N	PRESENT	0
333627	330628	04045F	PARTICIPANT	\N	PRESENT	0
333628	330628	14223L	PARTICIPANT	\N	PRESENT	0
333629	330628	14026U	PARTICIPANT	\N	PRESENT	0
333630	330628	17779H	PARTICIPANT	\N	PRESENT	0
333631	330628	11031D	PARTICIPANT	\N	PRESENT	0
333632	330628	19703U	PARTICIPANT	\N	PRESENT	0
333633	330628	14087W	PARTICIPANT	\N	PRESENT	0
333634	330628	14281W	PARTICIPANT	\N	PRESENT	0
333635	330628	19679N	PARTICIPANT	\N	PRESENT	0
333636	330628	14042U	PARTICIPANT	\N	PRESENT	0
333637	330628	14195A	PARTICIPANT	\N	PRESENT	0
333638	330628	19575F	PARTICIPANT	\N	PRESENT	0
333639	330628	19367Y	PARTICIPANT	\N	PRESENT	0
333640	330628	14213J	PARTICIPANT	\N	PRESENT	0
333641	330628	14217N	PARTICIPANT	\N	PRESENT	0
333642	330628	14261S	PARTICIPANT	\N	PRESENT	0
333643	330628	98024R	PARTICIPANT	\N	PRESENT	0
333644	330628	19527W	PARTICIPANT	\N	PRESENT	0
333645	330628	01034P	PARTICIPANT	\N	PRESENT	0
333646	330628	04092N	PRESIDENT	0	PRESENT	0
333647	330628	11045K	PARTICIPANT	\N	PRESENT	0
333648	330628	08052W	PARTICIPANT	\N	PRESENT	0
333649	330628	19663E	PARTICIPANT	\N	PRESENT	0
333650	330628	19715Y	PARTICIPANT	\N	PRESENT	0
333651	330628	19691J	PARTICIPANT	\N	PRESENT	0
333652	330628	19717B	PARTICIPANT	\N	PRESENT	0
333653	330628	19723Y	PARTICIPANT	\N	PRESENT	0
333654	330628	19727D	PARTICIPANT	\N	PRESENT	0
333655	330628	11103C	PARTICIPANT	\N	PRESENT	0
333656	330628	14071N	PARTICIPANT	\N	PRESENT	0
333657	330628	19760E	PARTICIPANT	\N	PRESENT	0
333658	330628	08041T	PARTICIPANT	\N	EXCUSE	0
333659	330628	19675J	PARTICIPANT	\N	EXCUSE	0
333660	321368	19349W	PARTICIPANT	\N	PRESENT	0
333661	321368	14275Y	PARTICIPANT	\N	PRESENT	0
333662	330628	14119M	PARTICIPANT	\N	PRESENT	0
333663	330628	19553Y	PARTICIPANT	\N	EXCUSE	0
333664	333055	14073Q	PARTICIPANT	\N	PRESENT	0
333665	333055	04059M	PARTICIPANT	\N	PRESENT	0
343463	339504	12041X	PARTICIPANT	\N	PRESENT	0
343464	339504	14259Y	PARTICIPANT	\N	PRESENT	0
343465	339504	95063L	PARTICIPANT	\N	PRESENT	0
343466	339504	08061X	PARTICIPANT	\N	PRESENT	0
343467	339504	95037J	PARTICIPANT	\N	PRESENT	0
343468	339504	04045F	PARTICIPANT	\N	PRESENT	0
343469	339504	19667J	PARTICIPANT	\N	PRESENT	0
343470	339504	14239U	PARTICIPANT	\N	PRESENT	0
343471	339504	14199E	PARTICIPANT	\N	PRESENT	0
343472	339504	19651A	PARTICIPANT	\N	PRESENT	0
343473	339504	19637C	PARTICIPANT	\N	PRESENT	0
343474	339504	19349W	PARTICIPANT	\N	PRESENT	0
343475	339504	08021P	PARTICIPANT	\N	PRESENT	0
343476	339504	19697Q	PARTICIPANT	\N	PRESENT	0
343477	339504	11048N	PARTICIPANT	\N	PRESENT	0
343478	339504	19301E	PARTICIPANT	\N	PRESENT	0
343479	339504	08073C	PARTICIPANT	\N	PRESENT	0
343480	339504	01057W	PARTICIPANT	\N	PRESENT	0
343481	339504	08024S	PARTICIPANT	\N	PRESENT	0
343482	339504	19782L	PARTICIPANT	\N	PRESENT	0
343483	339504	08069G	PARTICIPANT	\N	PRESENT	0
343484	339504	19659J	PARTICIPANT	\N	PRESENT	0
343485	339504	14191V	PARTICIPANT	\N	PRESENT	0
343486	339504	17637T	PARTICIPANT	\N	PRESENT	0
343487	339504	19573D	PARTICIPANT	\N	PRESENT	0
343488	339504	08031R	PARTICIPANT	\N	PRESENT	0
343489	339504	08049C	PARTICIPANT	\N	PRESENT	0
343490	339504	19629C	PARTICIPANT	\N	PRESENT	0
343491	339504	14201E	PARTICIPANT	\N	PRESENT	0
343492	339504	98022P	PARTICIPANT	\N	PRESENT	0
343493	339504	14133K	PARTICIPANT	\N	PRESENT	0
343494	339504	19719D	PARTICIPANT	\N	PRESENT	0
343495	339504	14107H	PARTICIPANT	\N	PRESENT	0
343496	339504	11099A	PARTICIPANT	\N	PRESENT	0
343497	339504	92040Q	PARTICIPANT	\N	PRESENT	0
343498	339504	19387D	PARTICIPANT	\N	PRESENT	0
343499	339504	19289C	PARTICIPANT	\N	PRESENT	0
343500	339504	11049P	PARTICIPANT	\N	PRESENT	0
343501	339504	11043H	PARTICIPANT	\N	PRESENT	0
343502	339504	04042C	PARTICIPANT	\N	PRESENT	0
343503	339504	11090Q	PARTICIPANT	\N	PRESENT	0
343504	339504	14111D	PARTICIPANT	\N	PRESENT	0
343505	339504	19585H	PARTICIPANT	\N	PRESENT	0
343506	339504	04057K	PARTICIPANT	\N	PRESENT	0
343507	339504	14123H	PARTICIPANT	\N	PRESENT	0
343508	339504	17589D	PARTICIPANT	\N	PRESENT	0
343509	339504	11064N	PARTICIPANT	\N	PRESENT	0
343510	339504	19583F	PARTICIPANT	\N	PRESENT	0
343511	339504	08011M	PARTICIPANT	\N	PRESENT	0
343512	339504	14251Q	PARTICIPANT	\N	PRESENT	0
343513	339504	08039A	PARTICIPANT	\N	PRESENT	0
343514	339504	14211G	PARTICIPANT	\N	PRESENT	0
343515	339504	19543W	PARTICIPANT	\N	PRESENT	0
343516	339504	14039A	PARTICIPANT	\N	PRESENT	0
343517	339504	14105F	PARTICIPANT	\N	PRESENT	0
343518	339504	19681G	PARTICIPANT	\N	PRESENT	0
343519	339504	14055N	PARTICIPANT	\N	PRESENT	0
343520	339504	89017R	PARTICIPANT	\N	PRESENT	0
343521	339504	14038Y	PARTICIPANT	\N	PRESENT	0
343522	339504	19723Y	PARTICIPANT	\N	PRESENT	0
343523	339504	86034E	PARTICIPANT	\N	PRESENT	0
343524	339504	11074Q	PARTICIPANT	\N	PRESENT	0
343525	339504	19467C	PARTICIPANT	\N	PRESENT	0
343526	339504	19489J	PARTICIPANT	\N	PRESENT	0
343527	339504	17779H	PARTICIPANT	\N	PRESENT	0
343528	339504	19551W	PARTICIPANT	\N	PRESENT	0
343529	339504	11054L	PARTICIPANT	\N	PRESENT	0
343530	339504	19251M	PARTICIPANT	\N	PRESENT	0
343531	339504	19399H	PARTICIPANT	\N	PRESENT	0
343532	339504	19647E	PARTICIPANT	\N	PRESENT	0
343533	339504	19591F	PARTICIPANT	\N	PRESENT	0
343534	339504	14265W	PARTICIPANT	\N	PRESENT	0
343535	339504	19503N	PARTICIPANT	\N	PRESENT	0
343536	339504	14213J	PARTICIPANT	\N	PRESENT	0
343537	339504	14227Q	PARTICIPANT	\N	PRESENT	0
343538	339504	11067R	PARTICIPANT	\N	PRESENT	0
343539	339504	19741B	PARTICIPANT	\N	PRESENT	0
343540	339504	14085U	PARTICIPANT	\N	PRESENT	0
343541	339504	19709B	PARTICIPANT	\N	PRESENT	0
343542	339504	08012N	PARTICIPANT	\N	PRESENT	0
343543	339504	19663E	PARTICIPANT	\N	PRESENT	0
343544	339504	19727D	PARTICIPANT	\N	PRESENT	0
343545	339504	80027E	PARTICIPANT	\N	PRESENT	0
343546	339504	14028W	PARTICIPANT	\N	PRESENT	0
343547	339504	11045K	PARTICIPANT	\N	PRESENT	0
343548	339504	14151M	PARTICIPANT	\N	PRESENT	0
343549	339504	19599P	PARTICIPANT	\N	PRESENT	0
343550	339504	98024R	PARTICIPANT	\N	PRESENT	0
343551	339504	08062Y	PARTICIPANT	\N	PRESENT	0
343552	339504	19768N	PARTICIPANT	\N	PRESENT	0
343553	339504	19705W	PARTICIPANT	\N	PRESENT	0
343554	339504	95067Q	PARTICIPANT	\N	PRESENT	0
343555	339504	14065Q	PARTICIPANT	\N	PRESENT	0
343556	339504	08053X	PARTICIPANT	\N	PRESENT	0
343557	339504	14051J	PARTICIPANT	\N	PRESENT	0
343558	339504	19689Q	PARTICIPANT	\N	PRESENT	0
343559	339504	98050T	PARTICIPANT	\N	PRESENT	0
343560	339504	04059M	PARTICIPANT	\N	PRESENT	0
343561	339504	11027H	PARTICIPANT	\N	PRESENT	0
343562	339504	14061L	PARTICIPANT	\N	PRESENT	0
343563	339504	98035U	PARTICIPANT	\N	PRESENT	0
343564	339504	04071H	PARTICIPANT	\N	PRESENT	0
343565	339504	08052W	PARTICIPANT	\N	PRESENT	0
343566	339504	14059S	PARTICIPANT	\N	PRESENT	0
343567	339504	14229S	PARTICIPANT	\N	PRESENT	0
343568	339504	19733B	PARTICIPANT	\N	PRESENT	0
343569	339504	19669L	PARTICIPANT	\N	PRESENT	0
343570	339504	14021P	PARTICIPANT	\N	PRESENT	0
343571	339504	08045X	PARTICIPANT	\N	PRESENT	0
343572	339504	14031R	PARTICIPANT	\N	PRESENT	0
343573	339504	14173T	PARTICIPANT	\N	PRESENT	0
343574	339504	14329V	PARTICIPANT	\N	PRESENT	0
343575	339504	08038Y	PARTICIPANT	\N	PRESENT	0
343576	339504	19762G	PARTICIPANT	\N	PRESENT	0
343577	339504	08060W	PARTICIPANT	\N	PRESENT	0
343578	339504	01062T	PARTICIPANT	\N	PRESENT	0
343579	339504	19701S	PARTICIPANT	\N	PRESENT	0
343580	339504	12016W	PARTICIPANT	\N	PRESENT	0
343581	339504	14159V	PARTICIPANT	\N	PRESENT	0
343582	339504	19367Y	PARTICIPANT	\N	PRESENT	0
343583	339504	14093U	PARTICIPANT	\N	PRESENT	0
343584	339504	14081Q	PARTICIPANT	\N	PRESENT	0
343585	339504	19531S	PARTICIPANT	\N	PRESENT	0
343586	339504	19747H	PARTICIPANT	\N	PRESENT	0
343587	339504	11066Q	PARTICIPANT	\N	PRESENT	0
343588	339504	05012A	PARTICIPANT	\N	PRESENT	0
343589	339504	11104D	PARTICIPANT	\N	PRESENT	0
343590	339504	19533U	PARTICIPANT	\N	PRESENT	0
343591	339504	14281W	PARTICIPANT	\N	PRESENT	0
343592	339504	08017T	PARTICIPANT	\N	PRESENT	0
343593	339504	04043D	PARTICIPANT	\N	PRESENT	0
343594	339504	14069U	PARTICIPANT	\N	PRESENT	0
343595	339504	11072N	PARTICIPANT	\N	PRESENT	0
343596	339504	14053L	PARTICIPANT	\N	PRESENT	0
343597	339504	19329S	PARTICIPANT	\N	PRESENT	0
343598	339504	04061F	PARTICIPANT	\N	PRESENT	0
343599	339504	04033B	PARTICIPANT	\N	PRESENT	0
343600	339504	14187A	PARTICIPANT	\N	PRESENT	0
343601	339504	14071N	PARTICIPANT	\N	PRESENT	0
343602	339504	14257W	PARTICIPANT	\N	PRESENT	0
343603	339504	05008E	PARTICIPANT	\N	PRESENT	0
343604	339504	11097X	PARTICIPANT	\N	PRESENT	0
343605	339504	11110B	PARTICIPANT	\N	PRESENT	0
343606	339504	95030B	PARTICIPANT	\N	PRESENT	0
343607	339504	19725B	PARTICIPANT	\N	PRESENT	0
343608	339504	04092N	PARTICIPANT	\N	PRESENT	0
343609	339504	14207L	PARTICIPANT	\N	PRESENT	0
343610	339504	04047H	PARTICIPANT	\N	PRESENT	0
343611	339504	19333N	PARTICIPANT	\N	PRESENT	0
343612	339504	14001X	PARTICIPANT	\N	PRESENT	0
343613	339504	08055A	PARTICIPANT	\N	PRESENT	0
343614	339504	11056N	PARTICIPANT	\N	PRESENT	0
343615	339504	19527W	PARTICIPANT	\N	PRESENT	0
343616	339504	19575F	PARTICIPANT	\N	PRESENT	0
343617	339504	14063N	PARTICIPANT	\N	PRESENT	0
343618	339504	19631V	PARTICIPANT	\N	PRESENT	0
343619	339504	14097Y	PARTICIPANT	\N	PRESENT	0
343620	339504	14109K	PARTICIPANT	\N	PRESENT	0
343621	339504	19549D	PARTICIPANT	\N	PRESENT	0
343622	339504	11115U	PARTICIPANT	\N	PRESENT	0
343623	339504	14231L	PARTICIPANT	\N	PRESENT	0
343624	339504	14179A	PARTICIPANT	\N	PRESENT	0
343625	339504	08044W	PARTICIPANT	\N	PRESENT	0
343626	339504	19713W	PARTICIPANT	\N	PRESENT	0
343627	339504	14042U	PARTICIPANT	\N	PRESENT	0
343628	339504	14219Q	PARTICIPANT	\N	PRESENT	0
343629	339504	01034P	PARTICIPANT	\N	PRESENT	0
336967	334446	04035D	PARTICIPANT	\N	EXCUSE	0
336968	334446	19583F	PARTICIPANT	\N	EXCUSE	0
336969	334446	08053X	PARTICIPANT	\N	EXCUSE	0
336970	334446	11054L	PARTICIPANT	\N	EXCUSE	0
336971	334446	08049C	PARTICIPANT	\N	EXCUSE	0
336975	334446	98029W	PARTICIPANT	\N	PRESENT	0
338564	338563	14083S	PARTICIPANT	\N	PRESENT	0
338565	338563	19762G	PARTICIPANT	\N	PRESENT	0
338568	338567	04049K	PARTICIPANT	\N	PRESENT	0
338720	338719	96004D	PARTICIPANT	\N	PRESENT	0
338734	338719	14073Q	PARTICIPANT	\N	PRESENT	0
338722	338719	11083R	PARTICIPANT	\N	PRESENT	0
338770	338769	96004D	PRESIDENT	0	PRESENT	0
338724	338719	19569H	PARTICIPANT	\N	PRESENT	0
338771	338769	14089Y	PARTICIPANT	\N	EXCUSE	0
338772	338769	14357A	PARTICIPANT	\N	PRESENT	0
338773	338769	14079W	PARTICIPANT	\N	PRESENT	0
338728	338719	08017T	PARTICIPANT	\N	PRESENT	0
338729	338719	14001X	PARTICIPANT	\N	PRESENT	0
338774	338769	14249W	PARTICIPANT	\N	PRESENT	0
338731	338719	98050T	PARTICIPANT	\N	PRESENT	0
338732	338719	14331P	PARTICIPANT	\N	PRESENT	0
338733	338719	01062T	PARTICIPANT	\N	PRESENT	0
338775	338769	14026U	PARTICIPANT	\N	PRESENT	0
338776	338769	04097T	PARTICIPANT	\N	PRESENT	0
338777	338769	14097Y	PARTICIPANT	\N	PRESENT	0
338778	338769	04061F	PARTICIPANT	\N	EXCUSE	0
338779	338769	14073Q	PARTICIPANT	\N	PRESENT	0
338780	338769	08039A	PARTICIPANT	\N	PRESENT	0
338781	338769	04057K	PARTICIPANT	\N	PRESENT	0
338782	338769	14135M	PARTICIPANT	\N	PRESENT	0
338783	338769	14133K	PARTICIPANT	\N	PRESENT	0
338786	338769	08018U	PARTICIPANT	\N	EXCUSE	0
338787	338769	14237S	PARTICIPANT	\N	EXCUSE	0
338788	338769	10015M	PARTICIPANT	\N	EXCUSE	0
342887	334381	11109J	PARTICIPANT	\N	PRESENT	0
342888	334381	14261S	PARTICIPANT	\N	PRESENT	0
342889	334381	19717B	PARTICIPANT	\N	PRESENT	0
342890	334381	19691J	PARTICIPANT	\N	PRESENT	0
342891	334381	14039A	PARTICIPANT	\N	PRESENT	0
342892	334381	08019V	PRESIDENT	0	PRESENT	0
342893	334381	11072N	PARTICIPANT	\N	PRESENT	0
342894	334381	08073C	PARTICIPANT	\N	PRESENT	0
342895	334381	19301E	PARTICIPANT	\N	PRESENT	0
342896	334381	14229S	PARTICIPANT	\N	PRESENT	0
342897	334381	14030Q	PARTICIPANT	\N	PRESENT	0
342898	340438	19729F	PARTICIPANT	\N	EXCUSE	0
342899	340438	14039A	PARTICIPANT	\N	EXCUSE	0
342900	340438	11072N	PARTICIPANT	\N	PRESENT	0
342901	340438	19301E	PARTICIPANT	\N	EXCUSE	0
343066	339502	11027H	PARTICIPANT	\N	PRESENT	0
343067	339502	11115U	PARTICIPANT	\N	PRESENT	0
343068	339502	19369B	PARTICIPANT	\N	PRESENT	0
343069	342128	14135M	PARTICIPANT	\N	PRESENT	0
343070	342128	19768N	PARTICIPANT	\N	PRESENT	0
343071	342128	19515S	PARTICIPANT	\N	PRESENT	0
343072	342128	14357A	PARTICIPANT	\N	PRESENT	0
343073	342128	19695N	PARTICIPANT	\N	PRESENT	0
343074	342128	11090Q	PRESIDENT	0	PRESENT	0
343075	342128	19631V	PARTICIPANT	\N	PRESENT	0
343076	342128	11056N	PARTICIPANT	\N	PRESENT	0
343077	342128	08068F	PARTICIPANT	\N	PRESENT	0
343078	342128	19511N	PARTICIPANT	\N	PRESENT	0
343079	342128	08028W	PARTICIPANT	\N	PRESENT	0
343080	342128	14265W	PARTICIPANT	\N	PRESENT	0
343081	342128	14329V	PARTICIPANT	\N	PRESENT	0
343116	342128	14081Q	PARTICIPANT	\N	PRESENT	0
343117	342128	08015R	PARTICIPANT	\N	PRESENT	0
343118	342128	19747H	PARTICIPANT	\N	PRESENT	0
343119	342128	19619A	PARTICIPANT	\N	PRESENT	0
343120	341785	19531S	PARTICIPANT	\N	PRESENT	0
343121	341785	11053K	PARTICIPANT	\N	PRESENT	0
343122	341785	89017R	PARTICIPANT	\N	PRESENT	0
343123	339502	19593H	PARTICIPANT	\N	PRESENT	0
343124	341785	08011M	PARTICIPANT	\N	PRESENT	0
343125	341785	14034U	PARTICIPANT	\N	PRESENT	0
343126	339502	05012A	PARTICIPANT	\N	PRESENT	0
343127	339502	08024S	PARTICIPANT	\N	PRESENT	0
343128	341785	19671E	PARTICIPANT	\N	PRESENT	0
343129	341785	08069G	PARTICIPANT	\N	PRESENT	0
343130	341785	14253S	PARTICIPANT	\N	PRESENT	0
343131	339502	14071N	PARTICIPANT	\N	PRESENT	0
343132	339502	14327T	PARTICIPANT	\N	PRESENT	0
343134	341785	14331P	PARTICIPANT	\N	PRESENT	0
343135	341785	19349W	PARTICIPANT	\N	EXCUSE	0
343136	339502	11066Q	PARTICIPANT	\N	PRESENT	0
343137	339502	19507S	PARTICIPANT	\N	PRESENT	0
343138	339502	04043D	PARTICIPANT	\N	PRESENT	0
343139	339502	19301E	PARTICIPANT	\N	PRESENT	0
343141	339502	80027E	PARTICIPANT	\N	PRESENT	0
343142	339502	14031R	PARTICIPANT	\N	PRESENT	0
343143	341785	88008L	PARTICIPANT	\N	PRESENT	0
343144	341785	11012A	PARTICIPANT	\N	PRESENT	0
343145	339502	11101A	PARTICIPANT	\N	PRESENT	0
343146	339502	80013X	PARTICIPANT	\N	PRESENT	0
343147	339502	08045X	PARTICIPANT	\N	PRESENT	0
343148	339502	08060W	PARTICIPANT	\N	PRESENT	0
343149	339502	14147R	PARTICIPANT	\N	PRESENT	0
343150	339502	14237S	PARTICIPANT	\N	PRESENT	0
343153	341785	07004J	PARTICIPANT	\N	EXCUSE	0
343164	339502	14219Q	PARTICIPANT	\N	PRESENT	0
343165	339502	19533U	PARTICIPANT	\N	PRESENT	0
343166	339502	19367Y	PARTICIPANT	\N	PRESENT	0
343167	339502	14187A	PARTICIPANT	\N	PRESENT	0
343168	339502	19713W	PARTICIPANT	\N	PRESENT	0
343169	339502	19631V	PARTICIPANT	\N	PRESENT	0
343170	339502	04008A	PARTICIPANT	\N	PRESENT	0
343171	339502	11026G	PARTICIPANT	\N	PRESENT	0
343172	339502	14109K	PARTICIPANT	\N	PRESENT	0
343173	339502	14105F	PARTICIPANT	\N	PRESENT	0
343174	339502	19335Q	PARTICIPANT	\N	PRESENT	0
343175	339502	08015R	PARTICIPANT	\N	PRESENT	0
343176	339502	19691J	PARTICIPANT	\N	PRESENT	0
343177	339502	14193X	PARTICIPANT	\N	PRESENT	0
343178	339502	19721W	PARTICIPANT	\N	PRESENT	0
343179	339502	19782L	PARTICIPANT	\N	PRESENT	0
343181	339502	19733B	PARTICIPANT	\N	PRESENT	0
343182	339502	19573D	PARTICIPANT	\N	PRESENT	0
343193	339503	19583F	PARTICIPANT	\N	PRESENT	0
343194	339503	04035D	PARTICIPANT	\N	PRESENT	0
343195	339503	14038Y	PARTICIPANT	\N	PRESENT	0
343196	339503	19629C	PARTICIPANT	\N	PRESENT	0
343190	339503	11070L	PARTICIPANT	\N	PRESENT	0
343192	339503	14041T	PARTICIPANT	\N	PRESENT	0
343197	339503	14235Q	PARTICIPANT	\N	PRESENT	0
343198	339503	14217N	PARTICIPANT	\N	PRESENT	0
343199	339503	14331P	PARTICIPANT	\N	PRESENT	0
343200	339503	97011G	PARTICIPANT	\N	PRESENT	0
343201	339503	19611R	PARTICIPANT	\N	PRESENT	0
343202	339503	19289C	PARTICIPANT	\N	PRESENT	0
343203	339503	01060R	PARTICIPANT	\N	PRESENT	0
343204	339503	19731Y	PARTICIPANT	\N	PRESENT	0
343205	339503	14147R	PARTICIPANT	\N	PRESENT	0
343206	339503	14111D	PARTICIPANT	\N	PRESENT	0
343208	339503	08056B	PARTICIPANT	\N	PRESENT	0
343209	339503	19251M	PARTICIPANT	\N	PRESENT	0
343210	339503	11066Q	PARTICIPANT	\N	PRESENT	0
343211	339503	15447F	PARTICIPANT	\N	PRESENT	0
343212	339503	14029X	PARTICIPANT	\N	PRESENT	0
343213	339503	19507S	PARTICIPANT	\N	PRESENT	0
343214	339503	19647E	PARTICIPANT	\N	PRESENT	0
343215	339503	19565D	PARTICIPANT	\N	PRESENT	0
343216	339503	19794Q	PARTICIPANT	\N	PRESENT	0
343217	339503	11056N	PARTICIPANT	\N	PRESENT	0
343218	339503	04042C	PARTICIPANT	\N	PRESENT	0
343219	339503	95037J	PARTICIPANT	\N	PRESENT	0
343710	339504	14033T	PARTICIPANT	\N	PRESENT	0
343715	339504	14237S	PARTICIPANT	\N	PRESENT	0
343724	339504	04089T	PARTICIPANT	\N	PRESENT	0
348759	339524	19369B	PARTICIPANT	\N	PRESENT	0
348760	339524	08009T	PARTICIPANT	\N	PRESENT	0
348761	339524	11053K	PARTICIPANT	\N	PRESENT	0
348762	339524	19511N	PARTICIPANT	\N	PRESENT	0
348763	339524	19611R	PARTICIPANT	\N	PRESENT	0
348764	339524	19737F	PARTICIPANT	\N	PRESENT	0
348765	339524	14205J	PARTICIPANT	\N	PRESENT	0
348766	339524	19699S	PARTICIPANT	\N	PRESENT	0
348767	339524	19721W	PARTICIPANT	\N	PRESENT	0
348768	339524	19619A	PARTICIPANT	\N	PRESENT	0
348769	339524	19521Q	PARTICIPANT	\N	PRESENT	0
348770	339524	04047H	PARTICIPANT	\N	PRESENT	0
348771	339524	08056B	PARTICIPANT	\N	PRESENT	0
348772	339524	19735D	PARTICIPANT	\N	PRESENT	0
348773	339524	16685X	PARTICIPANT	\N	PRESENT	0
348774	339524	14042U	PARTICIPANT	\N	PRESENT	0
348775	339524	98005N	PARTICIPANT	\N	PRESENT	0
348776	339524	04061F	PARTICIPANT	\N	PRESENT	0
348777	339524	14219Q	PARTICIPANT	\N	PRESENT	0
348778	339524	19479G	PARTICIPANT	\N	PRESENT	0
348779	339524	19441R	PARTICIPANT	\N	PRESENT	0
348780	339524	19713W	PARTICIPANT	\N	PRESENT	0
348781	339524	19319Q	PARTICIPANT	\N	PRESENT	0
348782	339524	14275Y	PARTICIPANT	\N	PRESENT	0
348783	339524	04088S	PARTICIPANT	\N	PRESENT	0
348784	339524	01043Q	PARTICIPANT	\N	PRESENT	0
348785	339524	14327T	PARTICIPANT	\N	PRESENT	0
348786	339524	14030Q	PARTICIPANT	\N	PRESENT	0
348787	339524	01025N	PARTICIPANT	\N	PRESENT	0
348788	339524	01024M	PARTICIPANT	\N	PRESENT	0
348789	339524	04070G	PARTICIPANT	\N	PRESENT	0
348790	339524	04040A	PARTICIPANT	\N	PRESENT	0
348791	339524	11085T	PARTICIPANT	\N	PRESENT	0
348792	339524	08044W	PARTICIPANT	\N	PRESENT	0
348793	339524	11070L	PARTICIPANT	\N	PRESENT	0
348794	339524	14083S	PARTICIPANT	\N	PRESENT	0
348795	339524	14073Q	PARTICIPANT	\N	PRESENT	0
348796	339524	14089Y	PARTICIPANT	\N	PRESENT	0
348797	339524	14103D	PARTICIPANT	\N	PRESENT	0
348798	339524	19739H	PARTICIPANT	\N	PRESENT	0
348799	339524	19335Q	PARTICIPANT	\N	PRESENT	0
348800	339524	07004J	PARTICIPANT	\N	PRESENT	0
348801	339524	14093U	PARTICIPANT	\N	PRESENT	0
348802	339524	19749K	PARTICIPANT	\N	PRESENT	0
348803	339524	19745F	PARTICIPANT	\N	PRESENT	0
348804	339524	08047A	PARTICIPANT	\N	PRESENT	0
348805	339524	11033F	PARTICIPANT	\N	PRESENT	0
348806	339524	14207L	PARTICIPANT	\N	PRESENT	0
348807	339524	11026G	PARTICIPANT	\N	PRESENT	0
348808	339524	14028W	PARTICIPANT	\N	PRESENT	0
348809	339524	08069G	PARTICIPANT	\N	PRESENT	0
348810	339524	19575F	PARTICIPANT	\N	PRESENT	0
348811	339524	14109K	PARTICIPANT	\N	PRESENT	0
348812	339524	11041F	PARTICIPANT	\N	PRESENT	0
348813	339524	19705W	PARTICIPANT	\N	PRESENT	0
348814	339524	14225N	PARTICIPANT	\N	PRESENT	0
348815	339524	04033B	PARTICIPANT	\N	PRESENT	0
348816	339524	80027E	PARTICIPANT	\N	PRESENT	0
348817	339524	08011M	PARTICIPANT	\N	PRESENT	0
348818	339524	14055N	PARTICIPANT	\N	PRESENT	0
348819	339524	19553Y	PARTICIPANT	\N	PRESENT	0
348820	339524	98029W	PARTICIPANT	\N	PRESENT	0
348821	339524	08028W	PARTICIPANT	\N	PRESENT	0
348822	339524	08053X	PARTICIPANT	\N	PRESENT	0
348823	339524	14255U	PARTICIPANT	\N	PRESENT	0
349123	339522	01043Q	PARTICIPANT	\N	PRESENT	0
349124	339522	11048N	PARTICIPANT	\N	PRESENT	0
349125	339522	95062K	PARTICIPANT	\N	PRESENT	0
349126	339522	19679N	PARTICIPANT	\N	PRESENT	0
349127	339522	04071H	PARTICIPANT	\N	PRESENT	0
349128	339522	01048V	PARTICIPANT	\N	PRESENT	0
349129	339522	19521Q	PARTICIPANT	\N	PRESENT	0
349130	339522	04049K	PARTICIPANT	\N	PRESENT	0
349131	339522	19565D	PARTICIPANT	\N	PRESENT	0
349132	339522	12041X	PARTICIPANT	\N	PRESENT	0
349133	339522	19760E	PARTICIPANT	\N	PRESENT	0
349134	339522	19695N	PARTICIPANT	\N	PRESENT	0
349135	339522	19687N	PARTICIPANT	\N	PRESENT	0
349136	339522	19413M	PARTICIPANT	\N	PRESENT	0
349137	339522	11031D	PARTICIPANT	\N	PRESENT	0
349138	339522	19503N	PARTICIPANT	\N	PRESENT	0
349139	339522	14121F	PARTICIPANT	\N	PRESENT	0
349140	339522	19683J	PARTICIPANT	\N	PRESENT	0
349141	339522	14227Q	PARTICIPANT	\N	PRESENT	0
349142	339522	11067R	PARTICIPANT	\N	PRESENT	0
349143	339522	19689Q	PARTICIPANT	\N	PRESENT	0
349144	339522	14225N	PARTICIPANT	\N	PRESENT	0
349145	339522	19631V	PARTICIPANT	\N	PRESENT	0
349146	339522	14051J	PARTICIPANT	\N	PRESENT	0
349147	339522	11109J	PARTICIPANT	\N	PRESENT	0
349148	339522	08017T	PARTICIPANT	\N	PRESENT	0
349149	339522	19669L	PARTICIPANT	\N	PRESENT	0
349150	339522	14257W	PARTICIPANT	\N	PRESENT	0
349151	339522	14109K	PARTICIPANT	\N	PRESENT	0
349152	339522	14081Q	PARTICIPANT	\N	PRESENT	0
349153	339522	14021P	PARTICIPANT	\N	PRESENT	0
349154	339522	08068F	PARTICIPANT	\N	PRESENT	0
349155	339522	04059M	PARTICIPANT	\N	PRESENT	0
349156	339522	08052W	PARTICIPANT	\N	PRESENT	0
349157	339522	11110B	PARTICIPANT	\N	PRESENT	0
349158	339522	19489J	PARTICIPANT	\N	PRESENT	0
349159	339522	04034C	PARTICIPANT	\N	PRESENT	0
349160	339522	19349W	PARTICIPANT	\N	PRESENT	0
349161	339522	19727D	PARTICIPANT	\N	PRESENT	0
349162	339522	19545Y	PARTICIPANT	\N	PRESENT	0
349163	339522	17589D	PARTICIPANT	\N	PRESENT	0
349164	339522	02002K	PARTICIPANT	\N	PRESENT	0
349165	339522	14107H	PARTICIPANT	\N	PRESENT	0
349166	339522	98022P	PARTICIPANT	\N	PRESENT	0
349167	339522	19441R	PARTICIPANT	\N	PRESENT	0
349168	339522	19713W	PARTICIPANT	\N	PRESENT	0
349169	339522	11090Q	PARTICIPANT	\N	PRESENT	0
349170	339522	19479G	PARTICIPANT	\N	PRESENT	0
349171	339522	14219Q	PARTICIPANT	\N	PRESENT	0
349172	339522	19711U	PARTICIPANT	\N	PRESENT	0
349173	339522	14327T	PARTICIPANT	\N	PRESENT	0
349174	339522	99004R	PARTICIPANT	\N	PRESENT	0
349175	339522	11053K	PARTICIPANT	\N	PRESENT	0
349176	339522	95030B	PARTICIPANT	\N	PRESENT	0
349177	339522	11097X	PARTICIPANT	\N	PRESENT	0
349179	339522	14034U	PARTICIPANT	\N	PRESENT	0
349180	339522	14069U	PARTICIPANT	\N	PRESENT	0
349181	339522	11012A	PARTICIPANT	\N	PRESENT	0
349182	339522	19563B	PARTICIPANT	\N	PRESENT	0
349183	339522	14357A	PARTICIPANT	\N	PRESENT	0
349184	339522	19611R	PARTICIPANT	\N	PRESENT	0
349185	339522	19515S	PARTICIPANT	\N	PRESENT	0
349186	339522	19673G	PARTICIPANT	\N	PRESENT	0
349187	339522	14205J	PARTICIPANT	\N	PRESENT	0
349188	339522	14173T	PARTICIPANT	\N	PRESENT	0
349189	339522	19747H	PARTICIPANT	\N	PRESENT	0
349190	339522	14038Y	PARTICIPANT	\N	PRESENT	0
349191	339522	08044W	PARTICIPANT	\N	PRESENT	0
349192	339522	19794Q	PARTICIPANT	\N	PRESENT	0
349193	339522	14083S	PARTICIPANT	\N	PRESENT	0
349194	339522	04088S	PARTICIPANT	\N	PRESENT	0
349195	339522	19621T	PARTICIPANT	\N	PRESENT	0
349196	339522	19667J	PARTICIPANT	\N	PRESENT	0
349197	339522	14329V	PARTICIPANT	\N	PRESENT	0
349198	339522	19399H	PARTICIPANT	\N	PRESENT	0
349199	339522	08062Y	PARTICIPANT	\N	PRESENT	0
349200	339522	14029X	PARTICIPANT	\N	PRESENT	0
349201	339522	19768N	PARTICIPANT	\N	PRESENT	0
349202	339522	19551W	PARTICIPANT	\N	PRESENT	0
349203	339522	19347U	PARTICIPANT	\N	PRESENT	0
349204	339522	11077T	PARTICIPANT	\N	PRESENT	0
349205	339522	19593H	PARTICIPANT	\N	PRESENT	0
349206	339522	14157T	PARTICIPANT	\N	PRESENT	0
349207	339522	19333N	PARTICIPANT	\N	PRESENT	0
349208	339522	08060W	PARTICIPANT	\N	PRESENT	0
349209	339522	19725B	PARTICIPANT	\N	PRESENT	0
349210	339522	19782L	PARTICIPANT	\N	PRESENT	0
349211	339522	19525U	PARTICIPANT	\N	PRESENT	0
349212	339522	89017R	PARTICIPANT	\N	PRESENT	0
349213	339522	07033P	PARTICIPANT	\N	PRESENT	0
349214	339522	11103C	PARTICIPANT	\N	PRESENT	0
349215	339522	14026U	PARTICIPANT	\N	PRESENT	0
349216	339522	14042U	PARTICIPANT	\N	PRESENT	0
349217	339522	14065Q	PARTICIPANT	\N	PRESENT	0
349218	339522	04043D	PARTICIPANT	\N	PRESENT	0
349219	339522	04085P	PARTICIPANT	\N	PRESENT	0
349220	339522	17779H	PARTICIPANT	\N	PRESENT	0
349221	339522	08045X	PARTICIPANT	\N	PRESENT	0
349222	339522	14151M	PARTICIPANT	\N	PRESENT	0
349224	339522	08038Y	PARTICIPANT	\N	PRESENT	0
349225	339522	08055A	PARTICIPANT	\N	PRESENT	0
349226	339522	19629C	PARTICIPANT	\N	PRESENT	0
349227	339522	19553Y	PARTICIPANT	\N	PRESENT	0
333666	321368	14034U	PARTICIPANT	\N	PRESENT	0
333667	321368	19725B	PARTICIPANT	\N	PRESENT	0
333668	321368	08073C	PARTICIPANT	\N	PRESENT	0
333670	321368	11053K	PARTICIPANT	\N	PRESENT	0
333671	321368	19737F	PARTICIPANT	\N	PRESENT	0
333672	321368	14223L	PARTICIPANT	\N	PRESENT	0
333791	321369	01057W	PARTICIPANT	\N	PRESENT	0
333792	321369	14231L	PARTICIPANT	\N	PRESENT	0
333793	321369	19593H	PARTICIPANT	\N	PRESENT	0
333794	321369	19651A	PARTICIPANT	\N	PRESENT	0
333795	321369	11103C	PARTICIPANT	\N	PRESENT	0
333796	321369	14229S	PARTICIPANT	\N	PRESENT	0
333797	321369	14225N	PARTICIPANT	\N	PRESENT	0
333798	321369	14179A	PARTICIPANT	\N	PRESENT	0
333799	321369	19768N	PARTICIPANT	\N	PRESENT	0
333800	321369	07004J	PARTICIPANT	\N	PRESENT	0
333801	321369	14033T	PARTICIPANT	\N	PRESENT	0
333802	321369	19583F	PARTICIPANT	\N	PRESENT	0
333803	321369	14195A	PARTICIPANT	\N	PRESENT	0
333804	321369	14219Q	PARTICIPANT	\N	PRESENT	0
333805	321369	14001X	PARTICIPANT	\N	PRESENT	0
333806	321369	14121F	PARTICIPANT	\N	PRESENT	0
333807	321369	19671E	PARTICIPANT	\N	PRESENT	0
333808	321369	11048N	PARTICIPANT	\N	PRESENT	0
333809	321369	04088S	PARTICIPANT	\N	PRESENT	0
333810	321369	19447X	PARTICIPANT	\N	PRESENT	0
333811	321369	14107H	PARTICIPANT	\N	PRESENT	0
333812	321369	19667J	PARTICIPANT	\N	PRESENT	0
333813	321369	19387D	PARTICIPANT	\N	PRESENT	0
333814	321369	19349W	PARTICIPANT	\N	PRESENT	0
333815	321369	14105F	PARTICIPANT	\N	PRESENT	0
333816	321369	14034U	PARTICIPANT	\N	PRESENT	0
333817	321369	19731Y	PARTICIPANT	\N	PRESENT	0
333818	321369	14053L	PARTICIPANT	\N	PRESENT	0
333819	321369	14199E	PARTICIPANT	\N	PRESENT	0
333820	321369	08028W	PARTICIPANT	\N	PRESENT	0
333821	321369	14071N	PARTICIPANT	\N	PRESENT	0
333822	321369	19599P	PARTICIPANT	\N	PRESENT	0
333823	321369	11074Q	PARTICIPANT	\N	PRESENT	0
333824	321369	14257W	PARTICIPANT	\N	PRESENT	0
333828	321369	04038G	PARTICIPANT	\N	PRESENT	0
333833	321369	11040E	PARTICIPANT	\N	PRESENT	0
333836	321369	08073C	PARTICIPANT	\N	PRESENT	0
333837	321369	98018T	PARTICIPANT	\N	PRESENT	0
333838	321369	19693L	PARTICIPANT	\N	PRESENT	0
333839	321369	14259Y	PARTICIPANT	\N	PRESENT	0
333840	321369	19782L	PARTICIPANT	\N	PRESENT	0
333841	321369	14085U	PARTICIPANT	\N	PRESENT	0
333842	321369	14215L	PARTICIPANT	\N	PRESENT	0
333843	321369	19611R	PARTICIPANT	\N	PRESENT	0
333844	321369	14223L	PARTICIPANT	\N	PRESENT	0
333845	321369	14073Q	PARTICIPANT	\N	PRESENT	0
333846	321369	14187A	PARTICIPANT	\N	PRESENT	0
333847	321369	14249W	PARTICIPANT	\N	PRESENT	0
333848	321369	19729F	PARTICIPANT	\N	PRESENT	0
333849	321369	19415P	PARTICIPANT	\N	PRESENT	0
333851	321369	14151M	PARTICIPANT	\N	PRESENT	0
333852	321369	14237S	PARTICIPANT	\N	PRESENT	0
334060	321369	11067R	PARTICIPANT	\N	PRESENT	0
333855	321369	19762G	PARTICIPANT	\N	PRESENT	0
333856	321369	19467C	PARTICIPANT	\N	PRESENT	0
333858	321369	19533U	PARTICIPANT	\N	PRESENT	0
333860	321369	18083K	PARTICIPANT	\N	PRESENT	0
333861	321369	14265W	PARTICIPANT	\N	PRESENT	0
333862	321369	19687N	PARTICIPANT	\N	PRESENT	0
333863	321369	05008E	PARTICIPANT	\N	PRESENT	0
333864	321369	97011G	PARTICIPANT	\N	PRESENT	0
333865	321369	19717B	PARTICIPANT	\N	PRESENT	0
333866	321369	14251Q	PARTICIPANT	\N	PRESENT	0
333869	321369	19573D	PARTICIPANT	\N	PRESENT	0
333873	321369	14327T	PARTICIPANT	\N	PRESENT	0
333878	321369	08024S	PARTICIPANT	\N	PRESENT	0
333879	321369	08039A	PARTICIPANT	\N	PRESENT	0
333882	321369	89017R	PARTICIPANT	\N	PRESENT	0
333883	321369	19335Q	PARTICIPANT	\N	PRESENT	0
333884	321369	04047H	PARTICIPANT	\N	PRESENT	0
333885	321369	04040A	PARTICIPANT	\N	PRESENT	0
333886	321369	19647E	PARTICIPANT	\N	PRESENT	0
333890	321369	14147R	PARTICIPANT	\N	PRESENT	0
333906	321369	14157T	PARTICIPANT	\N	PRESENT	0
333907	321369	88008L	PARTICIPANT	\N	PRESENT	0
333909	321369	11070L	PARTICIPANT	\N	PRESENT	0
333916	321369	98050T	PARTICIPANT	\N	PRESENT	0
333919	321369	19631V	PARTICIPANT	\N	PRESENT	0
333920	321369	14063N	PARTICIPANT	\N	PRESENT	0
333922	321369	19543W	PARTICIPANT	\N	PRESENT	0
333925	321369	19575F	PARTICIPANT	\N	PRESENT	0
333933	321369	14253S	PARTICIPANT	\N	PRESENT	0
333934	321369	04097T	PARTICIPANT	\N	PRESENT	0
333935	321369	19679N	PARTICIPANT	\N	PRESENT	0
333936	321369	15447F	PARTICIPANT	\N	PRESENT	0
333937	321369	19507S	PARTICIPANT	\N	PRESENT	0
333938	321369	04045F	PARTICIPANT	\N	PRESENT	0
333939	321369	19749K	PARTICIPANT	\N	PRESENT	0
333940	321369	19735D	PARTICIPANT	\N	PRESENT	0
333941	321369	19531S	PARTICIPANT	\N	PRESENT	0
333942	321369	19681G	PARTICIPANT	\N	PRESENT	0
333943	321369	19733B	PARTICIPANT	\N	PRESENT	0
333944	321369	19621T	PARTICIPANT	\N	PRESENT	0
333945	321369	19663E	PARTICIPANT	\N	PRESENT	0
333947	321369	19383Y	PARTICIPANT	\N	PRESENT	0
333959	321369	14123H	PARTICIPANT	\N	PRESENT	0
333964	321369	14241N	PARTICIPANT	\N	PRESENT	0
333976	321369	11085T	PARTICIPANT	\N	PRESENT	0
333977	321369	14089Y	PARTICIPANT	\N	PRESENT	0
333978	321369	01028R	PARTICIPANT	\N	PRESENT	0
333979	321369	19673G	PARTICIPANT	\N	PRESENT	0
333987	321369	01043Q	PARTICIPANT	\N	PRESENT	0
333988	321369	19745F	PARTICIPANT	\N	PRESENT	0
334001	321369	08043V	PARTICIPANT	\N	PRESENT	0
334014	321369	01058X	PARTICIPANT	\N	PRESENT	0
334015	321369	95030B	PARTICIPANT	\N	PRESENT	0
334018	321369	14227Q	PARTICIPANT	\N	PRESENT	0
334020	321369	11054L	PARTICIPANT	\N	PRESENT	0
334021	321369	19747H	PARTICIPANT	\N	PRESENT	0
334022	321369	19551W	PARTICIPANT	\N	PRESENT	0
334023	321369	14281W	PARTICIPANT	\N	PRESENT	0
334032	321369	19637C	PARTICIPANT	\N	PRESENT	0
334041	321369	95063L	PARTICIPANT	\N	PRESENT	0
334044	321369	19521Q	PARTICIPANT	\N	PRESENT	0
334045	321369	19333N	PARTICIPANT	\N	PRESENT	0
333789	321369	04086Q	PARTICIPANT	\N	PRESENT	0
333790	321369	19711U	PARTICIPANT	\N	PRESENT	0
334046	321369	19739H	PARTICIPANT	\N	PRESENT	0
334047	321369	19525U	PARTICIPANT	\N	PRESENT	0
334048	321369	19413M	PARTICIPANT	\N	PRESENT	0
334050	321369	08034U	PARTICIPANT	\N	PRESENT	0
334051	321369	08015R	PARTICIPANT	\N	PRESENT	0
334052	321369	19479G	PARTICIPANT	\N	PRESENT	0
334053	321369	11104D	PARTICIPANT	\N	PRESENT	0
334054	321369	16685X	PARTICIPANT	\N	PRESENT	0
334055	321369	19713W	PARTICIPANT	\N	PRESENT	0
334056	321369	11110B	PARTICIPANT	\N	PRESENT	0
334057	321369	08010L	PARTICIPANT	\N	PRESENT	0
334058	321369	14213J	PARTICIPANT	\N	PRESENT	0
334059	321369	14038Y	PARTICIPANT	\N	PRESENT	0
334062	321369	19565D	PARTICIPANT	\N	PRESENT	0
334063	321369	14217N	PARTICIPANT	\N	PRESENT	0
334064	321369	14331P	PARTICIPANT	\N	PRESENT	0
334065	321369	99004R	PARTICIPANT	\N	PRESENT	0
334066	321369	11043H	PARTICIPANT	\N	PRESENT	0
334067	321369	14069U	PARTICIPANT	\N	PRESENT	0
334068	321369	04092N	PARTICIPANT	\N	PRESENT	0
334069	321369	10015M	PARTICIPANT	\N	PRESENT	0
334070	321369	14169X	PARTICIPANT	\N	PRESENT	0
334071	321369	14211G	PARTICIPANT	\N	PRESENT	0
334072	321369	08020N	PARTICIPANT	\N	PRESENT	0
334073	321369	80013X	PARTICIPANT	\N	PRESENT	0
334074	321369	14103D	PARTICIPANT	\N	PRESENT	0
334075	321369	19703U	PARTICIPANT	\N	PRESENT	0
334076	321369	17637T	PARTICIPANT	\N	PRESENT	0
334077	321369	14061L	PARTICIPANT	\N	PRESENT	0
334078	321369	08061X	PARTICIPANT	\N	PRESENT	0
334079	321369	19503N	PARTICIPANT	\N	PRESENT	0
334080	321369	19691J	PARTICIPANT	\N	PRESENT	0
334081	321369	11027H	PARTICIPANT	\N	PRESENT	0
334082	321369	19725B	PARTICIPANT	\N	PRESENT	0
334083	321369	08038Y	PARTICIPANT	\N	PRESENT	0
334084	321369	11101A	PARTICIPANT	\N	PRESENT	0
334085	321369	14109K	PARTICIPANT	\N	PRESENT	0
334086	321369	19399H	PARTICIPANT	\N	PRESENT	0
334090	321369	04071H	PARTICIPANT	\N	PRESENT	0
334091	321369	19643A	PARTICIPANT	\N	PRESENT	0
334092	321369	19723Y	PARTICIPANT	\N	PRESENT	0
334093	321369	08017T	PARTICIPANT	\N	PRESENT	0
334094	321369	14042U	PARTICIPANT	\N	PRESENT	0
334132	321369	08051V	PARTICIPANT	\N	PRESENT	0
343631	339504	19691J	PARTICIPANT	\N	PRESENT	0
343632	339504	19569H	PARTICIPANT	\N	PRESENT	0
343633	339504	19611R	PARTICIPANT	\N	PRESENT	0
343634	339504	19511N	PARTICIPANT	\N	PRESENT	0
343635	339504	11053K	PARTICIPANT	\N	PRESENT	0
343636	339504	08019V	PARTICIPANT	\N	PRESENT	0
343637	339504	08009T	PARTICIPANT	\N	PRESENT	0
343638	339504	11085T	PARTICIPANT	\N	PRESENT	0
343639	339504	19619A	PARTICIPANT	\N	PRESENT	0
343640	339504	19721W	PARTICIPANT	\N	PRESENT	0
343641	339504	14119M	PARTICIPANT	\N	PRESENT	0
343642	339504	19737F	PARTICIPANT	\N	PRESENT	0
343643	339504	14205J	PARTICIPANT	\N	PRESENT	0
343644	339504	08056B	PARTICIPANT	\N	PRESENT	0
343645	339504	19479G	PARTICIPANT	\N	PRESENT	0
343646	339504	19441R	PARTICIPANT	\N	PRESENT	0
343647	339504	14277B	PARTICIPANT	\N	PRESENT	0
343648	339504	04070G	PARTICIPANT	\N	PRESENT	0
343649	339504	19507S	PARTICIPANT	\N	PRESENT	0
343650	339504	14267Y	PARTICIPANT	\N	PRESENT	0
345045	339509	80013X	PARTICIPANT	\N	PRESENT	0
343652	339504	19717B	PARTICIPANT	\N	PRESENT	0
343653	339504	14275Y	PARTICIPANT	\N	PRESENT	0
343654	339504	19699S	PARTICIPANT	\N	PRESENT	0
343655	339504	14103D	PARTICIPANT	\N	PRESENT	0
343656	339504	01043Q	PARTICIPANT	\N	PRESENT	0
343657	339504	01024M	PARTICIPANT	\N	PRESENT	0
343658	339504	14327T	PARTICIPANT	\N	PRESENT	0
343659	339504	14030Q	PARTICIPANT	\N	PRESENT	0
343660	339504	11070L	PARTICIPANT	\N	PRESENT	0
343661	339504	04040A	PARTICIPANT	\N	PRESENT	0
343662	339504	19521Q	PARTICIPANT	\N	PRESENT	0
343663	339504	07004J	PARTICIPANT	\N	PRESENT	0
343664	339504	14083S	PARTICIPANT	\N	PRESENT	0
343665	339504	14089Y	PARTICIPANT	\N	PRESENT	0
343666	339504	19739H	PARTICIPANT	\N	PRESENT	0
343667	339504	19745F	PARTICIPANT	\N	PRESENT	0
343668	339504	19269X	PARTICIPANT	\N	PRESENT	0
343669	339504	95041E	PARTICIPANT	\N	PRESENT	0
343670	339504	14241N	PARTICIPANT	\N	PRESENT	0
343671	339504	19563B	PARTICIPANT	\N	PRESENT	0
343672	339504	19545Y	PARTICIPANT	\N	PRESENT	0
343673	339504	11109J	PARTICIPANT	\N	PRESENT	0
343674	339504	19649G	PARTICIPANT	\N	PRESENT	0
343675	339504	14221J	PARTICIPANT	\N	PRESENT	0
343676	339504	19335Q	PARTICIPANT	\N	PRESENT	0
343677	339504	19749K	PARTICIPANT	\N	PRESENT	0
343678	339504	14255U	PARTICIPANT	\N	PRESENT	0
343679	339504	14087W	PARTICIPANT	\N	PRESENT	0
343681	339504	01060R	PARTICIPANT	\N	PRESENT	0
343682	339504	19369B	PARTICIPANT	\N	PRESENT	0
343683	339504	01028R	PARTICIPANT	\N	PRESENT	0
343684	339504	14261S	PARTICIPANT	\N	PRESENT	0
343685	339504	14034U	PARTICIPANT	\N	PRESENT	0
343686	339504	11012A	PARTICIPANT	\N	PRESENT	0
343687	339504	11026G	PARTICIPANT	\N	PRESENT	0
343688	339504	14225N	PARTICIPANT	\N	PRESENT	0
343689	343207	95067Q	PARTICIPANT	\N	PRESENT	0
343690	343207	14031R	PARTICIPANT	\N	PRESENT	0
343691	343207	14187A	PARTICIPANT	\N	PRESENT	0
343692	343207	08038Y	PARTICIPANT	\N	PRESENT	0
343693	343207	14221J	PARTICIPANT	\N	PRESENT	0
343694	343207	19721W	PARTICIPANT	\N	PRESENT	0
343695	343207	14093U	PARTICIPANT	\N	PRESENT	0
343696	343207	14051J	PARTICIPANT	\N	PRESENT	0
343697	343207	08060W	PARTICIPANT	\N	PRESENT	0
343698	343207	19629C	PARTICIPANT	\N	PRESENT	0
343699	343207	19733B	PARTICIPANT	\N	PRESENT	0
343700	343207	08049C	PRESIDENT	0	PRESENT	0
343701	343207	19347U	PARTICIPANT	\N	PRESENT	0
343702	343207	14157T	PRESIDENT	1	PRESENT	0
343703	343207	19745F	PARTICIPANT	\N	PRESENT	0
343704	343207	19369B	PARTICIPANT	\N	PRESENT	0
343705	343207	19747H	PARTICIPANT	\N	PRESENT	0
343706	343207	14207L	PARTICIPANT	\N	PRESENT	0
343707	343207	08024S	PARTICIPANT	\N	PRESENT	0
343708	343207	19762G	PARTICIPANT	\N	PRESENT	0
343709	343207	14033T	PARTICIPANT	\N	EXCUSE	0
345043	339509	14231L	PARTICIPANT	\N	PRESENT	0
345044	339509	19599P	PARTICIPANT	\N	PRESENT	0
345046	339509	01028R	PARTICIPANT	\N	PRESENT	0
345047	342817	14069U	PARTICIPANT	\N	PRESENT	0
345048	342817	05012A	PARTICIPANT	\N	PRESENT	0
345049	342817	14231L	PARTICIPANT	\N	PRESENT	0
345050	342817	14327T	PARTICIPANT	\N	PRESENT	0
345051	342817	08049C	PARTICIPANT	\N	PRESENT	0
345052	342817	11048N	PARTICIPANT	\N	PRESENT	0
345053	339509	08012N	PARTICIPANT	\N	PRESENT	0
345054	342817	08034U	PARTICIPANT	\N	PRESENT	0
345055	342817	08010L	PARTICIPANT	\N	PRESENT	0
345056	342817	19565D	PARTICIPANT	\N	PRESENT	0
345057	339509	14207L	PARTICIPANT	\N	PRESENT	0
345058	339509	05008E	PARTICIPANT	\N	PRESENT	0
345114	339509	04059M	PARTICIPANT	\N	PRESENT	0
345060	339509	88008L	PARTICIPANT	\N	PRESENT	0
345061	339509	19387D	PARTICIPANT	\N	PRESENT	0
345062	339509	19737F	PARTICIPANT	\N	PRESENT	0
345063	339509	14021P	PARTICIPANT	\N	PRESENT	0
345064	339509	19421M	PARTICIPANT	\N	PRESENT	0
345065	339509	11048N	PARTICIPANT	\N	PRESENT	0
345066	339509	19747H	PARTICIPANT	\N	PRESENT	0
345067	339509	04086Q	PARTICIPANT	\N	PRESENT	0
345068	339509	14085U	PARTICIPANT	\N	PRESENT	0
345069	339509	19543W	PARTICIPANT	\N	PRESENT	0
345070	339509	19551W	PARTICIPANT	\N	PRESENT	0
345071	339509	11040E	PARTICIPANT	\N	PRESENT	0
345072	339509	19711U	PARTICIPANT	\N	PRESENT	0
345073	339509	14083S	PARTICIPANT	\N	PRESENT	0
345074	339509	14259Y	PARTICIPANT	\N	PRESENT	0
345077	339509	14061L	PARTICIPANT	\N	PRESENT	0
345079	339509	19762G	PARTICIPANT	\N	PRESENT	0
345080	341956	14093U	PARTICIPANT	\N	PRESENT	0
345081	341956	80013X	PARTICIPANT	\N	PRESENT	0
345082	341956	19709B	PARTICIPANT	\N	PRESENT	0
345083	341956	01048V	PARTICIPANT	\N	PRESENT	0
345084	341956	19503N	PARTICIPANT	\N	PRESENT	0
345085	341956	01058X	PARTICIPANT	\N	PRESENT	0
345086	339509	11067R	PARTICIPANT	\N	PRESENT	0
345087	339509	19727D	PARTICIPANT	\N	PRESENT	0
345088	339509	08060W	PARTICIPANT	\N	PRESENT	0
345089	339509	11056N	PARTICIPANT	\N	PRESENT	0
345090	339509	19593H	PARTICIPANT	\N	PRESENT	0
345091	339509	08019V	PARTICIPANT	\N	PRESENT	0
345092	339509	99004R	PARTICIPANT	\N	PRESENT	0
345093	339509	14159V	PARTICIPANT	\N	PRESENT	0
345094	339509	07004J	PARTICIPANT	\N	PRESENT	0
345095	339509	19573D	PARTICIPANT	\N	PRESENT	0
345096	339509	19533U	PARTICIPANT	\N	PRESENT	0
345097	339509	14135M	PARTICIPANT	\N	PRESENT	0
345098	339509	19301E	PARTICIPANT	\N	PRESENT	0
345099	339509	19503N	PARTICIPANT	\N	PRESENT	0
345103	339509	19693L	PARTICIPANT	\N	PRESENT	0
345113	339509	19611R	PARTICIPANT	\N	PRESENT	0
345122	339509	14229S	PARTICIPANT	\N	PRESENT	0
345124	339509	19695N	PARTICIPANT	\N	PRESENT	0
345125	339509	11065P	PARTICIPANT	\N	PRESENT	0
345126	339509	08039A	PARTICIPANT	\N	PRESENT	0
345127	339509	19683J	PARTICIPANT	\N	PRESENT	0
345128	339509	14249W	PARTICIPANT	\N	PRESENT	0
345130	339509	14034U	PARTICIPANT	\N	PRESENT	0
345133	339509	11085T	PARTICIPANT	\N	PRESENT	0
345135	339509	08031R	PARTICIPANT	\N	PRESENT	0
340410	340409	04043D	PARTICIPANT	\N	PRESENT	0
340411	340409	08012N	PARTICIPANT	\N	PRESENT	0
343729	340473	14033T	PARTICIPANT	\N	EXCUSE	0
344130	339507	11090Q	PARTICIPANT	\N	PRESENT	0
344131	339507	14187A	PARTICIPANT	\N	PRESENT	0
344132	339507	17589D	PARTICIPANT	\N	PRESENT	0
344133	339507	08051V	PARTICIPANT	\N	PRESENT	0
344134	339507	19629C	PARTICIPANT	\N	PRESENT	0
344135	339507	14033T	PARTICIPANT	\N	PRESENT	0
344136	339507	19762G	PARTICIPANT	\N	PRESENT	0
344137	339507	14069U	PARTICIPANT	\N	PRESENT	0
344138	339507	14031R	PARTICIPANT	\N	PRESENT	0
344139	339507	19515S	PARTICIPANT	\N	PRESENT	0
344140	339507	19703U	PARTICIPANT	\N	PRESENT	0
344141	339507	19695N	PARTICIPANT	\N	PRESENT	0
344142	339507	14193X	PARTICIPANT	\N	PRESENT	0
344143	339507	01043Q	PARTICIPANT	\N	PRESENT	0
344144	339507	95030B	PARTICIPANT	\N	PRESENT	0
344145	339507	11056N	PARTICIPANT	\N	PRESENT	0
344146	339507	17637T	PARTICIPANT	\N	PRESENT	0
344147	339507	14029X	PARTICIPANT	\N	PRESENT	0
344148	339507	19760E	PARTICIPANT	\N	PRESENT	0
344149	339507	14231L	PARTICIPANT	\N	PRESENT	0
344150	339507	19782L	PARTICIPANT	\N	PRESENT	0
344151	339507	08038Y	PARTICIPANT	\N	PRESENT	0
344155	339507	08068F	PARTICIPANT	\N	PRESENT	0
344153	339507	19447X	PARTICIPANT	\N	PRESENT	0
344154	339507	14053L	PARTICIPANT	\N	PRESENT	0
344156	339507	95063L	PARTICIPANT	\N	PRESENT	0
344157	339507	14147R	PARTICIPANT	\N	PRESENT	0
344158	339507	14065Q	PARTICIPANT	\N	PRESENT	0
344159	339507	14265W	PARTICIPANT	\N	PRESENT	0
344160	339507	19507S	PARTICIPANT	\N	PRESENT	0
344161	339507	14215L	PARTICIPANT	\N	PRESENT	0
344162	339507	18083K	PARTICIPANT	\N	PRESENT	0
344163	339507	19467C	PARTICIPANT	\N	PRESENT	0
344164	339507	14211G	PARTICIPANT	\N	PRESENT	0
344165	339507	14021P	PARTICIPANT	\N	PRESENT	0
344166	339507	14213J	PARTICIPANT	\N	PRESENT	0
344167	339507	19741B	PARTICIPANT	\N	PRESENT	0
344168	339507	14034U	PARTICIPANT	\N	PRESENT	0
344169	339507	08031R	PARTICIPANT	\N	PRESENT	0
344170	339507	07029T	PARTICIPANT	\N	PRESENT	0
344171	339507	14357A	PARTICIPANT	\N	PRESENT	0
344172	339507	14239U	PARTICIPANT	\N	PRESENT	0
344173	339507	14329V	PARTICIPANT	\N	PRESENT	0
344557	342188	97011G	PARTICIPANT	\N	EXCUSE	0
344558	342188	11041F	PARTICIPANT	\N	EXCUSE	0
345768	345617	01024M	PARTICIPANT	\N	EXCUSE	0
346477	346476	19701S	PARTICIPANT	\N	PRESENT	0
346478	346476	11026G	PARTICIPANT	\N	PRESENT	0
346479	346476	14179A	PARTICIPANT	\N	PRESENT	0
346984	346982	14065Q	PARTICIPANT	\N	EXCUSE	0
346986	346982	96004D	PRESIDENT	0	PRESENT	0
346988	346982	14089Y	PARTICIPANT	\N	PRESENT	0
346991	346982	08018U	PARTICIPANT	\N	EXCUSE	0
346992	346982	04035D	PARTICIPANT	\N	PRESENT	0
346993	346982	11083R	PARTICIPANT	\N	PRESENT	0
346994	346982	19553Y	PARTICIPANT	\N	PRESENT	0
346995	346982	19725B	PARTICIPANT	\N	EXCUSE	0
346997	346982	95037J	PARTICIPANT	\N	PRESENT	0
344100	344099	10006L	PARTICIPANT	\N	PRESENT	0
346998	346982	08044W	PARTICIPANT	\N	PRESENT	0
346999	346982	04097T	PARTICIPANT	\N	PRESENT	0
347001	346982	04061F	PARTICIPANT	\N	PRESENT	0
347002	346982	14205J	PARTICIPANT	\N	PRESENT	0
347003	346982	14221J	PARTICIPANT	\N	PRESENT	0
347004	346982	04057K	PARTICIPANT	\N	PRESENT	0
347005	346982	14073Q	PARTICIPANT	\N	EXCUSE	0
347006	346982	19593H	PARTICIPANT	\N	PRESENT	0
347007	346982	14237S	PARTICIPANT	\N	PRESENT	0
344128	339507	11072N	PARTICIPANT	\N	PRESENT	0
344129	339507	14081Q	PARTICIPANT	\N	PRESENT	0
347008	346982	10015M	PARTICIPANT	\N	PRESENT	0
347009	346982	98035U	PARTICIPANT	\N	PRESENT	0
347010	346982	14331P	PARTICIPANT	\N	EXCUSE	0
350998	350997	11085T	PARTICIPANT	\N	PRESENT	0
350999	350997	19637C	PARTICIPANT	\N	PRESENT	0
351000	350997	04034C	PARTICIPANT	\N	PRESENT	0
351001	350997	14069U	PARTICIPANT	\N	PRESENT	0
351002	350997	14179A	PARTICIPANT	\N	PRESENT	0
352232	352231	14069U	PARTICIPANT	\N	PRESENT	0
352233	352231	14255U	PARTICIPANT	\N	PRESENT	0
352234	352231	14038Y	PARTICIPANT	\N	PRESENT	0
352235	352231	11027H	PARTICIPANT	\N	PRESENT	0
352236	352231	19525U	PARTICIPANT	\N	PRESENT	0
352237	352231	14187A	PARTICIPANT	\N	PRESENT	0
352238	352231	14281W	PARTICIPANT	\N	PRESENT	0
352239	352231	14213J	PARTICIPANT	\N	PRESENT	0
352240	352231	14073Q	PARTICIPANT	\N	PRESENT	0
352241	352231	14193X	PARTICIPANT	\N	PRESENT	0
352242	352231	19533U	PARTICIPANT	\N	PRESENT	0
352243	352231	04088S	PARTICIPANT	\N	PRESENT	0
352244	352231	05012A	PARTICIPANT	\N	PRESENT	0
352245	352231	19735D	PARTICIPANT	\N	PRESENT	0
352246	352231	19766L	PARTICIPANT	\N	PRESENT	0
352247	352231	11043H	PARTICIPANT	\N	PRESENT	0
352543	352542	04042C	PARTICIPANT	\N	PRESENT	0
352544	352542	07033P	PARTICIPANT	\N	PRESENT	0
352545	352542	14187A	PARTICIPANT	\N	PRESENT	0
352546	352542	11049P	PARTICIPANT	\N	PRESENT	0
352547	352542	04070G	PARTICIPANT	\N	PRESENT	0
352548	352542	04088S	PARTICIPANT	\N	PRESENT	0
354924	352190	14357A	PARTICIPANT	\N	PRESENT	0
354925	352190	19467C	PARTICIPANT	\N	PRESENT	0
354926	354847	11010L	PARTICIPANT	\N	PRESENT	0
354927	352190	19441R	PARTICIPANT	\N	PRESENT	0
354928	352190	19369B	PARTICIPANT	\N	PRESENT	0
354929	352190	14265W	PARTICIPANT	\N	PRESENT	0
354930	352190	14135M	PARTICIPANT	\N	PRESENT	0
354931	352190	19295A	PARTICIPANT	\N	PRESENT	0
354932	352190	04088S	PARTICIPANT	\N	PRESENT	0
354933	352190	08015R	PARTICIPANT	\N	PRESENT	0
355192	352735	11027H	PARTICIPANT	\N	PRESENT	0
355193	352735	11054L	PARTICIPANT	\N	PRESENT	0
355194	352735	04035D	PARTICIPANT	\N	PRESENT	0
355198	352735	08058D	PARTICIPANT	\N	EXCUSE	0
355199	352735	08056B	PARTICIPANT	\N	EXCUSE	0
355200	352735	19319Q	PARTICIPANT	\N	EXCUSE	0
355468	345104	11070L	PARTICIPANT	\N	PRESENT	0
355283	355281	08068F	PARTICIPANT	\N	PRESENT	0
355284	355281	19782L	PARTICIPANT	\N	PRESENT	0
355469	345104	19681G	PARTICIPANT	\N	PRESENT	0
355470	345104	19637C	PARTICIPANT	\N	PRESENT	0
355287	355281	19599P	PARTICIPANT	\N	EXCUSE	0
355471	345104	14121F	PARTICIPANT	\N	PRESENT	0
355289	355281	11049P	PARTICIPANT	\N	PRESENT	0
355472	345104	14235Q	PARTICIPANT	\N	PRESENT	0
355291	355281	07029T	PARTICIPANT	\N	EXCUSE	0
355292	355281	04049K	PARTICIPANT	\N	PRESENT	0
355293	355281	19711U	PARTICIPANT	\N	PRESENT	0
355294	355281	01043Q	PARTICIPANT	\N	PRESENT	0
355295	355281	14205J	PARTICIPANT	\N	PRESENT	0
355296	355281	01048V	PARTICIPANT	\N	PRESENT	0
355297	355281	19637C	PARTICIPANT	\N	PRESENT	0
355298	355281	19563B	PARTICIPANT	\N	EXCUSE	0
355473	345104	19503N	PARTICIPANT	\N	PRESENT	0
355474	345104	19782L	PARTICIPANT	\N	PRESENT	0
355475	345104	02002K	PARTICIPANT	\N	PRESENT	0
355476	345104	19387D	PARTICIPANT	\N	PRESENT	0
355303	355281	19713W	PARTICIPANT	\N	PRESENT	0
355477	345104	19619A	PARTICIPANT	\N	PRESENT	0
355305	355281	01062T	PARTICIPANT	\N	EXCUSE	0
355306	355281	19527W	PARTICIPANT	\N	EXCUSE	0
355307	355281	95067Q	PRESIDENT	0	PRESENT	0
355478	345104	19721W	PARTICIPANT	\N	PRESENT	0
355479	345104	14107H	PARTICIPANT	\N	PRESENT	0
355480	345104	14103D	PARTICIPANT	\N	PRESENT	0
355481	345104	11012A	PARTICIPANT	\N	PRESENT	0
355482	345104	19713W	PARTICIPANT	\N	PRESENT	0
355483	345104	14083S	PARTICIPANT	\N	PRESENT	0
355484	345104	19479G	PARTICIPANT	\N	PRESENT	0
355485	345104	19737F	PARTICIPANT	\N	PRESENT	0
355486	345104	14241N	PARTICIPANT	\N	PRESENT	0
355487	345104	19629C	PARTICIPANT	\N	PRESENT	0
355488	345104	19701S	PARTICIPANT	\N	PRESENT	0
355489	345104	95030B	PARTICIPANT	\N	PRESENT	0
355490	345104	19575F	PARTICIPANT	\N	PRESENT	0
355491	345104	14033T	PARTICIPANT	\N	PRESENT	0
355492	345104	04088S	PARTICIPANT	\N	PRESENT	0
355493	345104	14217N	PARTICIPANT	\N	PRESENT	0
355494	345104	14169X	PARTICIPANT	\N	PRESENT	0
355495	345104	19533U	PARTICIPANT	\N	PRESENT	0
355496	345104	08010L	PARTICIPANT	\N	PRESENT	0
355497	345104	19583F	PARTICIPANT	\N	PRESENT	0
355498	345104	97011G	PARTICIPANT	\N	PRESENT	0
355499	345104	14201E	PARTICIPANT	\N	PRESENT	0
355500	345104	14191V	PARTICIPANT	\N	PRESENT	0
355501	345104	19573D	PARTICIPANT	\N	PRESENT	0
349228	339522	14119M	PARTICIPANT	\N	PRESENT	0
349229	339522	19575F	PARTICIPANT	\N	PRESENT	0
349230	339522	19369B	PARTICIPANT	\N	PRESENT	0
349231	339522	08028W	PARTICIPANT	\N	PRESENT	0
349232	339522	19693L	PARTICIPANT	\N	PRESENT	0
349233	339522	19758L	PARTICIPANT	\N	PRESENT	0
349234	339522	97011G	PARTICIPANT	\N	PRESENT	0
349235	339522	19533U	PARTICIPANT	\N	PRESENT	0
349236	339522	01028R	PARTICIPANT	\N	PRESENT	0
349237	339522	19383Y	PARTICIPANT	\N	PRESENT	0
349238	339522	19675J	PARTICIPANT	\N	PRESENT	0
349239	339522	01057W	PARTICIPANT	\N	PRESENT	0
349240	339522	14199E	PARTICIPANT	\N	PRESENT	0
349241	339522	19467C	PARTICIPANT	\N	PRESENT	0
349242	339522	08061X	PARTICIPANT	\N	PRESENT	0
349243	339522	08031R	PARTICIPANT	\N	PRESENT	0
349244	339522	14071N	PARTICIPANT	\N	PRESENT	0
349245	339522	14073Q	PARTICIPANT	\N	PRESENT	0
349246	339522	19643A	PARTICIPANT	\N	PRESENT	0
349247	339522	14195A	PARTICIPANT	\N	PRESENT	0
349248	339522	14213J	PARTICIPANT	\N	PRESENT	0
349249	339522	19573D	PARTICIPANT	\N	PRESENT	0
349250	339522	08049C	PARTICIPANT	\N	PRESENT	0
349251	339522	11033F	PARTICIPANT	\N	PRESENT	0
349252	339522	14041T	PARTICIPANT	\N	PRESENT	0
349253	339522	14223L	PARTICIPANT	\N	PRESENT	0
349254	339522	08024S	PARTICIPANT	\N	PRESENT	0
349255	339522	08034U	PARTICIPANT	\N	PRESENT	0
349256	339522	08011M	PARTICIPANT	\N	PRESENT	0
349257	339522	14147R	PARTICIPANT	\N	PRESENT	0
349258	339522	19762G	PARTICIPANT	\N	PRESENT	0
349259	339522	14187A	PARTICIPANT	\N	PRESENT	0
349260	339522	14215L	PARTICIPANT	\N	PRESENT	0
349261	339522	14265W	PARTICIPANT	\N	PRESENT	0
349270	339522	14231L	PARTICIPANT	\N	PRESENT	0
349272	339522	14331P	PARTICIPANT	\N	PRESENT	0
349273	339522	14237S	PARTICIPANT	\N	PRESENT	0
349274	339522	19599P	PARTICIPANT	\N	PRESENT	0
349275	339522	19715Y	PARTICIPANT	\N	PRESENT	0
349276	339522	19681G	PARTICIPANT	\N	PRESENT	0
349277	339522	14033T	PARTICIPANT	\N	PRESENT	0
349278	339522	14169X	PARTICIPANT	\N	PRESENT	0
349279	339522	19447X	PARTICIPANT	\N	PRESENT	0
349280	339522	19697Q	PARTICIPANT	\N	PRESENT	0
349281	339522	01025N	PARTICIPANT	\N	PRESENT	0
349282	339522	08056B	PARTICIPANT	\N	PRESENT	0
349283	339522	14251Q	PARTICIPANT	\N	PRESENT	0
349284	339522	14135M	PARTICIPANT	\N	PRESENT	0
349288	349285	10015M	PARTICIPANT	\N	PRESENT	0
349289	349286	10015M	PARTICIPANT	\N	PRESENT	0
349290	349287	10015M	PARTICIPANT	\N	PRESENT	0
349433	339523	04044E	PARTICIPANT	\N	PRESENT	0
349434	339523	19521Q	PARTICIPANT	\N	PRESENT	0
349435	339523	11048N	PARTICIPANT	\N	PRESENT	0
349436	339523	19695N	PARTICIPANT	\N	PRESENT	0
349437	339523	14151M	PARTICIPANT	\N	PRESENT	0
349438	339523	19715Y	PARTICIPANT	\N	PRESENT	0
349439	339523	19551W	PARTICIPANT	\N	PRESENT	0
349440	339523	19503N	PARTICIPANT	\N	PRESENT	0
349441	339523	19333N	PARTICIPANT	\N	PRESENT	0
349442	339523	19631V	PARTICIPANT	\N	PRESENT	0
349443	339523	19782L	PARTICIPANT	\N	PRESENT	0
349444	339523	11110B	PARTICIPANT	\N	PRESENT	0
349445	339523	14021P	PARTICIPANT	\N	PRESENT	0
349446	339523	08068F	PARTICIPANT	\N	PRESENT	0
349447	339523	04045F	PARTICIPANT	\N	PRESENT	0
349448	339523	14241N	PARTICIPANT	\N	PRESENT	0
349449	339523	80013X	PARTICIPANT	\N	PRESENT	0
349450	339523	14227Q	PARTICIPANT	\N	PRESENT	0
349451	339523	19689Q	PARTICIPANT	\N	PRESENT	0
349452	339523	19679N	PARTICIPANT	\N	PRESENT	0
349453	339523	14051J	PARTICIPANT	\N	PRESENT	0
349454	339523	19515S	PARTICIPANT	\N	PRESENT	0
349455	339523	99004R	PARTICIPANT	\N	PRESENT	0
349456	339523	95030B	PARTICIPANT	\N	PRESENT	0
349457	339523	19565D	PARTICIPANT	\N	PRESENT	0
349458	339523	11031D	PARTICIPANT	\N	PRESENT	0
349459	339523	19447X	PARTICIPANT	\N	PRESENT	0
349460	339523	14038Y	PARTICIPANT	\N	PRESENT	0
349461	339523	19697Q	PARTICIPANT	\N	PRESENT	0
349462	339523	19629C	PARTICIPANT	\N	PRESENT	0
349463	339523	14093U	PARTICIPANT	\N	PRESENT	0
349464	339523	11064N	PARTICIPANT	\N	PRESENT	0
349465	339523	14147R	PARTICIPANT	\N	PRESENT	0
349466	339523	19711U	PARTICIPANT	\N	PRESENT	0
349467	339523	19713W	PARTICIPANT	\N	PRESENT	0
349468	339523	19441R	PARTICIPANT	\N	PRESENT	0
349469	339523	19681G	PARTICIPANT	\N	PRESENT	0
349470	339523	19563B	PARTICIPANT	\N	PRESENT	0
349471	339523	19553Y	PARTICIPANT	\N	PRESENT	0
349472	339523	19669L	PARTICIPANT	\N	PRESENT	0
349473	339523	14109K	PARTICIPANT	\N	PRESENT	0
349474	339523	08034U	PARTICIPANT	\N	PRESENT	0
349475	339523	08051V	PARTICIPANT	\N	PRESENT	0
349476	339523	11053K	PARTICIPANT	\N	PRESENT	0
349477	339523	14173T	PARTICIPANT	\N	PRESENT	0
349478	339523	04085P	PARTICIPANT	\N	PRESENT	0
349479	339523	19758L	PARTICIPANT	\N	PRESENT	0
349480	339523	19760E	PARTICIPANT	\N	PRESENT	0
349481	339523	19687N	PARTICIPANT	\N	PRESENT	0
349482	339523	11077T	PARTICIPANT	\N	PRESENT	0
349483	339523	14081Q	PARTICIPANT	\N	PRESENT	0
349484	339523	08031R	PARTICIPANT	\N	PRESENT	0
349485	339523	14034U	PARTICIPANT	\N	PRESENT	0
349486	339523	19619A	PARTICIPANT	\N	PRESENT	0
349487	339523	19667J	PARTICIPANT	\N	PRESENT	0
349488	339523	19794Q	PARTICIPANT	\N	PRESENT	0
349489	339523	14231L	PARTICIPANT	\N	PRESENT	0
349490	339523	11090Q	PARTICIPANT	\N	PRESENT	0
349491	339523	14215L	PARTICIPANT	\N	PRESENT	0
349492	339523	14069U	PARTICIPANT	\N	PRESENT	0
349493	339523	08011M	PARTICIPANT	\N	PRESENT	0
349494	339523	89017R	PARTICIPANT	\N	PRESENT	0
349495	339523	19693L	PARTICIPANT	\N	PRESENT	0
349496	339523	14187A	PARTICIPANT	\N	PRESENT	0
349497	339523	08062Y	PARTICIPANT	\N	PRESENT	0
349498	339523	14083S	PARTICIPANT	\N	PRESENT	0
349499	339523	14205J	PARTICIPANT	\N	PRESENT	0
349500	339523	14033T	PARTICIPANT	\N	PRESENT	0
349501	339523	14265W	PARTICIPANT	\N	PRESENT	0
349502	339523	14061L	PARTICIPANT	\N	PRESENT	0
349503	339523	14107H	PARTICIPANT	\N	PRESENT	0
349504	339523	14071N	PARTICIPANT	\N	PRESENT	0
349505	339523	11097X	PARTICIPANT	\N	PRESENT	0
349506	339523	04071H	PARTICIPANT	\N	PRESENT	0
349507	339523	14331P	PARTICIPANT	\N	PRESENT	0
349508	339523	14213J	PARTICIPANT	\N	PRESENT	0
349509	339523	04049K	PARTICIPANT	\N	PRESENT	0
349510	339523	19347U	PARTICIPANT	\N	PRESENT	0
349511	339523	19573D	PARTICIPANT	\N	PRESENT	0
349512	339523	19383Y	PARTICIPANT	\N	PRESENT	0
349513	339523	14026U	PARTICIPANT	\N	PRESENT	0
349514	339523	19369B	PARTICIPANT	\N	PRESENT	0
349515	339523	14073Q	PARTICIPANT	\N	PRESENT	0
349516	339523	98022P	PARTICIPANT	\N	PRESENT	0
349517	339523	14329V	PARTICIPANT	\N	PRESENT	0
349518	339523	14219Q	PARTICIPANT	\N	PRESENT	0
349519	339523	14357A	PARTICIPANT	\N	PRESENT	0
349520	339523	08015R	PARTICIPANT	\N	PRESENT	0
349521	339523	19723Y	PARTICIPANT	\N	PRESENT	0
349528	349223	19699S	PARTICIPANT	\N	PRESENT	0
349529	349223	11043H	PARTICIPANT	\N	PRESENT	0
349530	349223	19758L	PARTICIPANT	\N	PRESENT	0
349531	349223	19766L	PARTICIPANT	\N	PRESENT	0
349532	349223	19593H	PARTICIPANT	\N	PRESENT	0
349533	349223	04070G	PRESIDENT	0	PRESENT	0
349534	349223	14063N	PARTICIPANT	\N	PRESENT	0
349535	349223	14109K	PARTICIPANT	\N	PRESENT	0
349536	349223	08043V	PARTICIPANT	\N	PRESENT	0
349537	349223	19335Q	PARTICIPANT	\N	PRESENT	0
349538	349223	19749K	PARTICIPANT	\N	PRESENT	0
349539	349223	04018C	PARTICIPANT	\N	PRESENT	0
349540	349223	08039A	PARTICIPANT	\N	PRESENT	0
349541	349223	14030Q	PARTICIPANT	\N	PRESENT	0
349543	349223	14241N	PARTICIPANT	\N	PRESENT	0
349544	347119	04086Q	PARTICIPANT	\N	PRESENT	0
349545	347119	14327T	PARTICIPANT	\N	PRESENT	0
349546	347119	14331P	PARTICIPANT	\N	PRESENT	0
349547	347119	14199E	PARTICIPANT	\N	PRESENT	0
349548	347119	19349W	PARTICIPANT	\N	PRESENT	0
349549	347119	08011M	PARTICIPANT	\N	PRESENT	0
349550	347119	14253S	PARTICIPANT	\N	PRESENT	0
349551	347119	19671E	PARTICIPANT	\N	PRESENT	0
349552	347119	88008L	PARTICIPANT	\N	PRESENT	0
349553	347119	99004R	PARTICIPANT	\N	PRESENT	0
349554	347119	11074Q	PRESIDENT	0	PRESENT	0
349555	347119	07004J	PARTICIPANT	\N	EXCUSE	0
349556	347017	95067Q	PARTICIPANT	\N	PRESENT	0
349557	347017	11080N	PARTICIPANT	\N	PRESENT	0
334133	321369	04042C	PARTICIPANT	\N	PRESENT	0
334134	331305	19599P	PARTICIPANT	\N	PRESENT	0
334135	321369	04057K	PARTICIPANT	\N	PRESENT	0
334136	331305	19551W	PARTICIPANT	\N	PRESENT	0
334142	321369	14205J	PARTICIPANT	\N	PRESENT	0
334143	321369	01024M	PARTICIPANT	\N	PRESENT	0
334144	331305	14237S	PARTICIPANT	\N	PRESENT	0
334145	331305	08051V	PARTICIPANT	\N	PRESENT	0
334301	321370	19733B	PARTICIPANT	\N	PRESENT	0
334302	321370	04018C	PARTICIPANT	\N	PRESENT	0
334303	321370	14231L	PARTICIPANT	\N	PRESENT	0
334304	321370	11074Q	PARTICIPANT	\N	PRESENT	0
334305	321370	08051V	PARTICIPANT	\N	PRESENT	0
334306	321370	14261S	PARTICIPANT	\N	PRESENT	0
334307	321370	19691J	PARTICIPANT	\N	PRESENT	0
334308	321370	14159V	PARTICIPANT	\N	PRESENT	0
334309	321370	08010L	PARTICIPANT	\N	PRESENT	0
334310	321370	19673G	PARTICIPANT	\N	PRESENT	0
334311	321370	14021P	PARTICIPANT	\N	PRESENT	0
334312	321370	17637T	PARTICIPANT	\N	PRESENT	0
334313	321370	19723Y	PARTICIPANT	\N	PRESENT	0
334314	321370	19703U	PARTICIPANT	\N	PRESENT	0
334315	321370	19447X	PARTICIPANT	\N	PRESENT	0
334316	321370	19441R	PARTICIPANT	\N	PRESENT	0
334317	321370	19693L	PARTICIPANT	\N	PRESENT	0
334318	321370	08031R	PARTICIPANT	\N	PRESENT	0
334319	321370	19479G	PARTICIPANT	\N	PRESENT	0
334320	321370	19647E	PARTICIPANT	\N	PRESENT	0
334321	321370	04045F	PARTICIPANT	\N	PRESENT	0
334322	321370	19737F	PARTICIPANT	\N	PRESENT	0
334323	321370	01024M	PARTICIPANT	\N	PRESENT	0
334324	321370	19551W	PARTICIPANT	\N	PRESENT	0
334325	321370	14327T	PARTICIPANT	\N	PRESENT	0
334326	321370	19713W	PARTICIPANT	\N	PRESENT	0
334327	321370	19553Y	PARTICIPANT	\N	PRESENT	0
334328	321370	11048N	PARTICIPANT	\N	PRESENT	0
334329	321370	01057W	PARTICIPANT	\N	PRESENT	0
334330	321370	07029T	PARTICIPANT	\N	PRESENT	0
334331	321370	18083K	PARTICIPANT	\N	PRESENT	0
334332	321370	08061X	PARTICIPANT	\N	PRESENT	0
334333	321370	14033T	PARTICIPANT	\N	PRESENT	0
334334	321370	14331P	PARTICIPANT	\N	PRESENT	0
334335	321370	14187A	PARTICIPANT	\N	PRESENT	0
334336	321370	14042U	PARTICIPANT	\N	PRESENT	0
334337	321370	19729F	PARTICIPANT	\N	PRESENT	0
335392	335391	14331P	PARTICIPANT	\N	PRESENT	0
335395	335394	11083R	PARTICIPANT	\N	PRESENT	0
335396	335393	11083R	PARTICIPANT	\N	PRESENT	0
335399	335398	11083R	PARTICIPANT	\N	PRESENT	0
335400	335398	14331P	PARTICIPANT	\N	PRESENT	0
335402	335401	11083R	PARTICIPANT	\N	PRESENT	0
335403	335401	14331P	PARTICIPANT	\N	PRESENT	0
335406	335405	11083R	PARTICIPANT	\N	PRESENT	0
335407	335405	14331P	PARTICIPANT	\N	PRESENT	0
335409	335408	11083R	PARTICIPANT	\N	PRESENT	0
335410	335408	14331P	PARTICIPANT	\N	PRESENT	0
335412	335411	11083R	PARTICIPANT	\N	PRESENT	0
335413	335411	14331P	PARTICIPANT	\N	PRESENT	0
335415	335414	11083R	PARTICIPANT	\N	PRESENT	0
335416	335414	14073Q	PARTICIPANT	\N	PRESENT	0
335418	335417	11083R	PARTICIPANT	\N	PRESENT	0
335419	335417	14073Q	PARTICIPANT	\N	PRESENT	0
335422	335421	11083R	PARTICIPANT	\N	PRESENT	0
335423	335421	14073Q	PARTICIPANT	\N	PRESENT	0
335424	335421	14237S	PARTICIPANT	\N	PRESENT	0
335426	335425	11083R	PARTICIPANT	\N	PRESENT	0
335427	335425	14073Q	PARTICIPANT	\N	PRESENT	0
335429	335428	11083R	PARTICIPANT	\N	PRESENT	0
335431	335430	11083R	PARTICIPANT	\N	PRESENT	0
335433	335432	96004D	PARTICIPANT	\N	PRESENT	0
335435	335432	11083R	PARTICIPANT	\N	PRESENT	0
335436	335432	14073Q	PARTICIPANT	\N	PRESENT	0
335438	335437	11083R	PARTICIPANT	\N	PRESENT	0
335439	335437	14073Q	PARTICIPANT	\N	PRESENT	0
335441	335440	11083R	PARTICIPANT	\N	PRESENT	0
335442	335440	14073Q	PARTICIPANT	\N	PRESENT	0
335444	335443	14187A	PARTICIPANT	\N	PRESENT	0
335445	335443	14231L	PARTICIPANT	\N	PRESENT	0
335446	335443	11083R	PARTICIPANT	\N	PRESENT	0
335447	335443	14059S	PARTICIPANT	\N	PRESENT	0
335741	335732	86034E	PARTICIPANT	\N	PRESENT	0
335757	335739	08017T	PARTICIPANT	\N	PRESENT	0
335758	335732	14021P	PARTICIPANT	\N	PRESENT	0
335759	335732	19715Y	PARTICIPANT	\N	PRESENT	0
335760	335732	19737F	PARTICIPANT	\N	PRESENT	0
335761	335732	19731Y	PARTICIPANT	\N	PRESENT	0
335762	335732	07004J	PARTICIPANT	\N	PRESENT	0
335763	335732	19413M	PARTICIPANT	\N	PRESENT	0
335764	335732	04045F	PARTICIPANT	\N	PRESENT	0
335765	335732	19387D	PARTICIPANT	\N	PRESENT	0
335766	335732	19739H	PARTICIPANT	\N	PRESENT	0
335767	335732	19511N	PARTICIPANT	\N	PRESENT	0
335768	335732	14085U	PARTICIPANT	\N	PRESENT	0
335769	335732	80027E	PARTICIPANT	\N	PRESENT	0
335770	335732	98022P	PARTICIPANT	\N	PRESENT	0
335771	335732	08024S	PARTICIPANT	\N	PRESENT	0
337900	335286	11067R	PARTICIPANT	\N	PRESENT	0
337901	335286	17779H	PARTICIPANT	\N	PRESENT	0
337902	335286	19703U	PARTICIPANT	\N	PRESENT	0
337903	335286	14087W	PARTICIPANT	\N	PRESENT	0
337904	335286	14195A	PARTICIPANT	\N	PRESENT	0
337905	335286	19575F	PARTICIPANT	\N	PRESENT	0
337906	335286	04092N	PRESIDENT	0	PRESENT	0
337907	335286	11045K	PARTICIPANT	\N	PRESENT	0
337908	335286	19663E	PARTICIPANT	\N	PRESENT	0
337909	335286	19715Y	PARTICIPANT	\N	PRESENT	0
337911	321411	19715Y	PARTICIPANT	\N	PRESENT	0
337912	321411	08043V	PARTICIPANT	\N	PRESENT	0
337913	321411	19591F	PARTICIPANT	\N	PRESENT	0
337914	321411	11066Q	PARTICIPANT	\N	PRESENT	0
337915	321411	11103C	PARTICIPANT	\N	PRESENT	0
337916	321411	14053L	PARTICIPANT	\N	PRESENT	0
337917	321411	14147R	PARTICIPANT	\N	PRESENT	0
337918	321411	19443T	PARTICIPANT	\N	PRESENT	0
337919	321411	19515S	PARTICIPANT	\N	PRESENT	0
337920	321411	14217N	PARTICIPANT	\N	PRESENT	0
337921	321411	14253S	PARTICIPANT	\N	PRESENT	0
337922	321411	01058X	PARTICIPANT	\N	PRESENT	0
337923	321411	14157T	PARTICIPANT	\N	PRESENT	0
337924	321411	07033P	PARTICIPANT	\N	PRESENT	0
337925	321411	99004R	PARTICIPANT	\N	PRESENT	0
337926	321411	08019V	PARTICIPANT	\N	PRESENT	0
337927	321411	14041T	PARTICIPANT	\N	PRESENT	0
337928	321411	19762G	PARTICIPANT	\N	PRESENT	0
337929	321411	19741B	PARTICIPANT	\N	PRESENT	0
337930	321411	19399H	PARTICIPANT	\N	PRESENT	0
337931	321411	04097T	PARTICIPANT	\N	PRESENT	0
337932	321411	04092N	PARTICIPANT	\N	PRESENT	0
337933	321411	17779H	PARTICIPANT	\N	PRESENT	0
337934	321411	11067R	PARTICIPANT	\N	PRESENT	0
337935	321411	14265W	PARTICIPANT	\N	PRESENT	0
337936	321411	19413M	PARTICIPANT	\N	PRESENT	0
337937	321411	19703U	PARTICIPANT	\N	PRESENT	0
337938	321411	08055A	PARTICIPANT	\N	PRESENT	0
337939	321411	14329V	PARTICIPANT	\N	PRESENT	0
337940	321411	08010L	PARTICIPANT	\N	PRESENT	0
337941	321411	19679N	PARTICIPANT	\N	PRESENT	0
337942	321411	19695N	PARTICIPANT	\N	PRESENT	0
337943	321411	96004D	PARTICIPANT	\N	PRESENT	0
337944	321411	14051J	PARTICIPANT	\N	PRESENT	0
337945	321411	04034C	PARTICIPANT	\N	PRESENT	0
337946	321411	07034Q	PARTICIPANT	\N	PRESENT	0
337947	321411	98029W	PARTICIPANT	\N	PRESENT	0
337948	321411	14071N	PARTICIPANT	\N	PRESENT	0
337949	321411	04018C	PARTICIPANT	\N	PRESENT	0
337950	321411	19631V	PARTICIPANT	\N	PRESENT	0
337951	321411	01062T	PARTICIPANT	\N	PRESENT	0
337952	321411	14133K	PARTICIPANT	\N	PRESENT	0
337953	321411	08069G	PARTICIPANT	\N	PRESENT	0
337954	321411	19549D	PARTICIPANT	\N	PRESENT	0
337955	321411	11097X	PARTICIPANT	\N	PRESENT	0
337956	321411	14061L	PARTICIPANT	\N	PRESENT	0
337957	321411	19333N	PARTICIPANT	\N	PRESENT	0
337958	321411	14355X	PARTICIPANT	\N	PRESENT	0
337959	321411	01028R	PARTICIPANT	\N	PRESENT	0
337960	321411	19599P	PARTICIPANT	\N	PRESENT	0
337961	321411	19766L	PARTICIPANT	\N	PRESENT	0
337962	321411	14039A	PARTICIPANT	\N	PRESENT	0
337963	321411	11010L	PARTICIPANT	\N	PRESENT	0
337964	321411	04008A	PARTICIPANT	\N	PRESENT	0
337965	321411	08045X	PARTICIPANT	\N	PRESENT	0
337966	321411	14187A	PARTICIPANT	\N	PRESENT	0
337967	321411	11054L	PARTICIPANT	\N	PRESENT	0
337968	321411	04044E	PARTICIPANT	\N	PRESENT	0
337969	321411	14201E	PARTICIPANT	\N	PRESENT	0
337970	321411	19415P	PARTICIPANT	\N	PRESENT	0
337971	321411	14241N	PARTICIPANT	\N	PRESENT	0
337972	321411	19563B	PARTICIPANT	\N	PRESENT	0
345178	339510	19583F	PARTICIPANT	\N	PRESENT	0
345179	339510	98050T	PARTICIPANT	\N	PRESENT	0
345180	339510	19611R	PARTICIPANT	\N	PRESENT	0
345181	339510	19693L	PARTICIPANT	\N	PRESENT	0
345182	339510	08039A	PARTICIPANT	\N	PRESENT	0
345183	339510	14229S	PARTICIPANT	\N	PRESENT	0
345184	339510	08031R	PARTICIPANT	\N	PRESENT	0
345185	339510	19593H	PARTICIPANT	\N	PRESENT	0
345186	339510	19711U	PARTICIPANT	\N	PRESENT	0
345187	339510	19683J	PARTICIPANT	\N	PRESENT	0
345188	339510	04059M	PARTICIPANT	\N	PRESENT	0
345189	339510	11083R	PARTICIPANT	\N	PRESENT	0
345190	339510	14249W	PARTICIPANT	\N	PRESENT	0
345191	339510	14251Q	PARTICIPANT	\N	PRESENT	0
345192	339510	14021P	PARTICIPANT	\N	PRESENT	0
345193	339510	04070G	PARTICIPANT	\N	PRESENT	0
345176	339510	11027H	PARTICIPANT	\N	PRESENT	0
345177	345123	14071N	PARTICIPANT	\N	EXCUSE	0
345194	339510	01028R	PARTICIPANT	\N	PRESENT	0
345195	339510	19647E	PARTICIPANT	\N	PRESENT	0
345202	339510	19629C	PARTICIPANT	\N	PRESENT	0
345206	339510	19695N	PARTICIPANT	\N	PRESENT	0
345207	339510	19643A	PARTICIPANT	\N	PRESENT	0
345307	345123	14063N	PARTICIPANT	\N	EXCUSE	0
345308	345123	04040A	PRESIDENT	0	PRESENT	0
345311	345123	04044E	PARTICIPANT	\N	EXCUSE	0
345312	341436	19349W	PARTICIPANT	\N	PRESENT	0
345425	345424	19515S	PARTICIPANT	\N	PRESENT	0
345426	345424	04034C	PARTICIPANT	\N	PRESENT	0
345427	345424	11053K	PARTICIPANT	\N	PRESENT	0
345428	345424	89017R	PARTICIPANT	\N	PRESENT	0
345429	345424	14026U	PARTICIPANT	\N	PRESENT	0
345430	345424	11070L	PARTICIPANT	\N	PRESENT	0
345431	345424	19631V	PARTICIPANT	\N	PRESENT	0
345432	345424	14227Q	PARTICIPANT	\N	PRESENT	0
345433	345424	08068F	PARTICIPANT	\N	PRESENT	0
345434	345424	14051J	PARTICIPANT	\N	PRESENT	0
345435	345424	04049K	PARTICIPANT	\N	PRESENT	0
345436	345424	14151M	PARTICIPANT	\N	PRESENT	0
345437	345424	14157T	PARTICIPANT	\N	PRESENT	0
345438	345424	19521Q	PRESIDENT	0	PRESENT	0
345439	345424	14329V	PARTICIPANT	\N	PRESENT	0
345440	345424	11048N	PARTICIPANT	\N	PRESENT	0
345441	345424	19711U	PARTICIPANT	\N	PRESENT	0
345442	345424	14187A	PARTICIPANT	\N	PRESENT	0
345443	345424	19695N	PARTICIPANT	\N	PRESENT	0
345444	345424	11090Q	PARTICIPANT	\N	PRESENT	0
345445	345424	14159V	PARTICIPANT	\N	PRESENT	0
345446	345424	14173T	PARTICIPANT	\N	PRESENT	0
345447	345424	14083S	PARTICIPANT	\N	PRESENT	0
345448	345424	08073C	PARTICIPANT	\N	PRESENT	0
345449	345424	19760E	PARTICIPANT	\N	PRESENT	0
345450	345424	14034U	PARTICIPANT	\N	PRESENT	0
345451	339511	86034E	PARTICIPANT	\N	PRESENT	0
345452	339511	04049K	PARTICIPANT	\N	PRESENT	0
345453	339511	11048N	PARTICIPANT	\N	PRESENT	0
345454	339511	14331P	PARTICIPANT	\N	PRESENT	0
345455	339511	14083S	PARTICIPANT	\N	PRESENT	0
345456	339511	14219Q	PARTICIPANT	\N	PRESENT	0
345457	339511	14227Q	PARTICIPANT	\N	PRESENT	0
345458	339511	19760E	PARTICIPANT	\N	PRESENT	0
345459	339511	14026U	PARTICIPANT	\N	PRESENT	0
345460	339511	04088S	PARTICIPANT	\N	PRESENT	0
345461	339511	11066Q	PARTICIPANT	\N	PRESENT	0
345462	339511	19631V	PARTICIPANT	\N	PRESENT	0
345463	339511	19711U	PARTICIPANT	\N	PRESENT	0
345464	339511	19399H	PARTICIPANT	\N	PRESENT	0
345465	339511	17779H	PARTICIPANT	\N	PRESENT	0
345466	339511	04034C	PARTICIPANT	\N	PRESENT	0
345467	339511	19683J	PARTICIPANT	\N	PRESENT	0
345468	339511	11054L	PARTICIPANT	\N	PRESENT	0
345469	339511	19741B	PARTICIPANT	\N	PRESENT	0
345470	339511	19593H	PARTICIPANT	\N	PRESENT	0
345471	339511	99004R	PARTICIPANT	\N	PRESENT	0
345472	339511	19611R	PARTICIPANT	\N	PRESENT	0
345473	339511	14173T	PARTICIPANT	\N	PRESENT	0
345474	339511	19695N	PARTICIPANT	\N	PRESENT	0
345475	339511	11110B	PARTICIPANT	\N	PRESENT	0
345476	339511	19545Y	PARTICIPANT	\N	PRESENT	0
345477	339511	19583F	PARTICIPANT	\N	PRESENT	0
345478	339511	19441R	PARTICIPANT	\N	PRESENT	0
345479	339511	19735D	PARTICIPANT	\N	PRESENT	0
345480	339511	08060W	PARTICIPANT	\N	PRESENT	0
345481	339511	14051J	PARTICIPANT	\N	PRESENT	0
345482	339511	19521Q	PARTICIPANT	\N	PRESENT	0
345483	339511	07004J	PARTICIPANT	\N	PRESENT	0
345484	339511	14327T	PARTICIPANT	\N	PRESENT	0
345485	339511	19421M	PARTICIPANT	\N	PRESENT	0
345486	339511	14089Y	PARTICIPANT	\N	PRESENT	0
345487	339511	11067R	PARTICIPANT	\N	PRESENT	0
345488	339511	11031D	PARTICIPANT	\N	PRESENT	0
345489	339511	08068F	PARTICIPANT	\N	PRESENT	0
345490	339511	08058D	PARTICIPANT	\N	PRESENT	0
345491	339511	08073C	PARTICIPANT	\N	PRESENT	0
345492	339511	14081Q	PARTICIPANT	\N	PRESENT	0
345493	339511	08024S	PARTICIPANT	\N	PRESENT	0
345494	339511	08061X	PARTICIPANT	\N	PRESENT	0
345495	339511	14034U	PARTICIPANT	\N	PRESENT	0
345496	339511	14179A	PARTICIPANT	\N	PRESENT	0
345497	339511	11053K	PARTICIPANT	\N	PRESENT	0
345498	339511	14267Y	PARTICIPANT	\N	PRESENT	0
345499	339511	19715Y	PARTICIPANT	\N	PRESENT	0
345500	339511	19651A	PARTICIPANT	\N	PRESENT	0
345501	339511	18083K	PARTICIPANT	\N	PRESENT	0
345502	339511	19515S	PARTICIPANT	\N	PRESENT	0
345503	339511	19647E	PARTICIPANT	\N	PRESENT	0
345504	339511	14151M	PARTICIPANT	\N	PRESENT	0
345505	339511	14107H	PARTICIPANT	\N	PRESENT	0
345506	339511	15447F	PARTICIPANT	\N	PRESENT	0
345507	339511	14157T	PARTICIPANT	\N	PRESENT	0
345508	339511	01057W	PARTICIPANT	\N	PRESENT	0
345509	339511	04071H	PARTICIPANT	\N	PRESENT	0
345510	339511	08028W	PARTICIPANT	\N	PRESENT	0
345511	339511	95063L	PARTICIPANT	\N	PRESENT	0
345512	339511	19701S	PARTICIPANT	\N	PRESENT	0
345513	339511	19762G	PARTICIPANT	\N	PRESENT	0
345514	339511	14069U	PARTICIPANT	\N	PRESENT	0
345515	339511	11040E	PARTICIPANT	\N	PRESENT	0
345516	339511	19347U	PARTICIPANT	\N	PRESENT	0
345517	339511	14111D	PARTICIPANT	\N	PRESENT	0
345518	339511	95030B	PARTICIPANT	\N	PRESENT	0
345519	339511	19689Q	PARTICIPANT	\N	PRESENT	0
345520	339511	14159V	PARTICIPANT	\N	PRESENT	0
345522	339511	14215L	PARTICIPANT	\N	PRESENT	0
345523	339511	14087W	PARTICIPANT	\N	PRESENT	0
345524	339511	19745F	PARTICIPANT	\N	PRESENT	0
345525	339511	89017R	PARTICIPANT	\N	PRESENT	0
345526	339511	19687N	PARTICIPANT	\N	PRESENT	0
345527	339511	11090Q	PARTICIPANT	\N	PRESENT	0
345528	339511	11103C	PARTICIPANT	\N	PRESENT	0
345529	339511	14147R	PARTICIPANT	\N	PRESENT	0
345530	339511	14071N	PARTICIPANT	\N	PRESENT	0
345531	339511	14235Q	PARTICIPANT	\N	PRESENT	0
345532	339511	04061F	PARTICIPANT	\N	PRESENT	0
345533	339511	14187A	PARTICIPANT	\N	PRESENT	0
345534	339511	14123H	PARTICIPANT	\N	PRESENT	0
345535	339511	19551W	PARTICIPANT	\N	PRESENT	0
345536	339511	19503N	PARTICIPANT	\N	PRESENT	0
345537	339511	19333N	PARTICIPANT	\N	PRESENT	0
345538	339511	19549D	PARTICIPANT	\N	PRESENT	0
345539	339511	19737F	PARTICIPANT	\N	PRESENT	0
345542	339511	19709B	PARTICIPANT	\N	PRESENT	0
345543	339511	08039A	PARTICIPANT	\N	PRESENT	0
345544	339511	19643A	PARTICIPANT	\N	PRESENT	0
345545	339511	19679N	PARTICIPANT	\N	PRESENT	0
345547	339511	14223L	PARTICIPANT	\N	PRESENT	0
345548	345546	19415P	PARTICIPANT	\N	PRESENT	0
345549	345546	11067R	PARTICIPANT	\N	PRESENT	0
345550	339511	11085T	PARTICIPANT	\N	PRESENT	0
345551	339511	19697Q	PARTICIPANT	\N	PRESENT	0
345552	339511	01048V	PARTICIPANT	\N	PRESENT	0
345553	339511	19467C	PARTICIPANT	\N	PRESENT	0
345554	339511	14213J	PARTICIPANT	\N	PRESENT	0
345555	339511	97011G	PARTICIPANT	\N	PRESENT	0
345556	339511	14281W	PARTICIPANT	\N	PRESENT	0
345557	339511	01043Q	PARTICIPANT	\N	PRESENT	0
345558	339511	08012N	PARTICIPANT	\N	PRESENT	0
345560	339511	19758L	PARTICIPANT	\N	PRESENT	0
345561	339511	11056N	PARTICIPANT	\N	PRESENT	0
345562	339511	19295A	PARTICIPANT	\N	PRESENT	0
345563	339511	19731Y	PARTICIPANT	\N	PRESENT	0
345564	339511	04033B	PARTICIPANT	\N	PRESENT	0
345565	339511	11077T	PARTICIPANT	\N	PRESENT	0
345566	339511	98050T	PARTICIPANT	\N	PRESENT	0
345567	339511	19629C	PARTICIPANT	\N	PRESENT	0
345568	339511	14259Y	PARTICIPANT	\N	PRESENT	0
345569	339511	14329V	PARTICIPANT	\N	PRESENT	0
345570	339511	19693L	PARTICIPANT	\N	PRESENT	0
345571	339511	14001X	PARTICIPANT	\N	PRESENT	0
348119	339519	19583F	PARTICIPANT	\N	PRESENT	0
348120	339519	07004J	PARTICIPANT	\N	PRESENT	0
348121	339519	19731Y	PARTICIPANT	\N	PRESENT	0
348122	339519	19709B	PARTICIPANT	\N	PRESENT	0
348123	339519	14063N	PARTICIPANT	\N	PRESENT	0
348124	339519	14327T	PARTICIPANT	\N	PRESENT	0
348125	348099	11048N	PARTICIPANT	\N	PRESENT	0
348126	348099	19711U	PARTICIPANT	\N	PRESENT	0
348127	348099	08034U	PARTICIPANT	\N	PRESENT	0
348128	348099	04034C	PARTICIPANT	\N	PRESENT	0
348129	348099	19545Y	PARTICIPANT	\N	PRESENT	0
348130	348099	19441R	PARTICIPANT	\N	PRESENT	0
348131	348099	89017R	PARTICIPANT	\N	PRESENT	0
348132	348099	19667J	PARTICIPANT	\N	PRESENT	0
348133	348099	14034U	PARTICIPANT	\N	PRESENT	0
348134	348099	14026U	PARTICIPANT	\N	PRESENT	0
348135	348099	19399H	PARTICIPANT	\N	PRESENT	0
348136	348099	11110B	PARTICIPANT	\N	PRESENT	0
348137	348099	19631V	PARTICIPANT	\N	PRESENT	0
348138	348099	14083S	PARTICIPANT	\N	PRESENT	0
348139	348099	08068F	PARTICIPANT	\N	PRESENT	0
348140	348099	14051J	PARTICIPANT	\N	PRESENT	0
348141	348099	04049K	PARTICIPANT	\N	PRESENT	0
348142	348099	14157T	PARTICIPANT	\N	PRESENT	0
348143	348099	19760E	PARTICIPANT	\N	PRESENT	0
348144	348099	19521Q	PRESIDENT	0	PRESENT	0
348145	348099	14329V	PARTICIPANT	\N	PRESENT	0
348146	339519	04045F	PARTICIPANT	\N	PRESENT	0
348147	339519	08045X	PARTICIPANT	\N	PRESENT	0
348148	339519	19637C	PARTICIPANT	\N	PRESENT	0
348149	339519	04018C	PARTICIPANT	\N	PRESENT	0
348150	339519	04049K	PARTICIPANT	\N	PRESENT	0
348151	339519	14227Q	PARTICIPANT	\N	PRESENT	0
348152	339519	19695N	PARTICIPANT	\N	PRESENT	0
348153	339519	19687N	PARTICIPANT	\N	PRESENT	0
348154	339519	19593H	PARTICIPANT	\N	PRESENT	0
348155	339519	08068F	PARTICIPANT	\N	PRESENT	0
348156	339519	11104D	PARTICIPANT	\N	PRESENT	0
348157	339519	14051J	PARTICIPANT	\N	PRESENT	0
348158	339519	19333N	PARTICIPANT	\N	PRESENT	0
348159	339519	19525U	PARTICIPANT	\N	PRESENT	0
348160	339519	11066Q	PARTICIPANT	\N	PRESENT	0
348161	339519	04034C	PARTICIPANT	\N	PRESENT	0
348162	339519	19521Q	PARTICIPANT	\N	PRESENT	0
348163	339519	19545Y	PARTICIPANT	\N	PRESENT	0
348164	339519	19413M	PARTICIPANT	\N	PRESENT	0
348165	339519	19441R	PARTICIPANT	\N	PRESENT	0
348166	339519	14089Y	PARTICIPANT	\N	PRESENT	0
348167	339519	14033T	PARTICIPANT	\N	PRESENT	0
348168	339519	19631V	PARTICIPANT	\N	PRESENT	0
348169	339519	14157T	PARTICIPANT	\N	PRESENT	0
348170	339519	11048N	PARTICIPANT	\N	PRESENT	0
348171	339519	14105F	PARTICIPANT	\N	PRESENT	0
348172	339519	19667J	PARTICIPANT	\N	PRESENT	0
348173	339519	19794Q	PARTICIPANT	\N	PRESENT	0
348174	339519	19447X	PARTICIPANT	\N	PRESENT	0
348175	339519	14069U	PARTICIPANT	\N	PRESENT	0
348176	339519	19575F	PARTICIPANT	\N	PRESENT	0
348177	339519	19515S	PARTICIPANT	\N	PRESENT	0
348178	339519	14038Y	PARTICIPANT	\N	PRESENT	0
348179	339519	99004R	PARTICIPANT	\N	PRESENT	0
348180	339519	19711U	PARTICIPANT	\N	PRESENT	0
348181	339519	08034U	PARTICIPANT	\N	PRESENT	0
348182	339519	89017R	PARTICIPANT	\N	PRESENT	0
348183	339519	19399H	PARTICIPANT	\N	PRESENT	0
348184	339519	14207L	PARTICIPANT	\N	PRESENT	0
348185	339519	19760E	PARTICIPANT	\N	PRESENT	0
348186	339519	19503N	PARTICIPANT	\N	PRESENT	0
348187	339519	11110B	PARTICIPANT	\N	PRESENT	0
348188	339519	19301E	PARTICIPANT	\N	PRESENT	0
348189	339519	19349W	PARTICIPANT	\N	PRESENT	0
348190	339519	04059M	PARTICIPANT	\N	PRESENT	0
348191	339519	80027E	PARTICIPANT	\N	PRESENT	0
348192	339519	11077T	PARTICIPANT	\N	PRESENT	0
348193	339519	14229S	PARTICIPANT	\N	PRESENT	0
348194	339519	19693L	PARTICIPANT	\N	PRESENT	0
348195	339519	14235Q	PARTICIPANT	\N	PRESENT	0
348196	339519	14151M	PARTICIPANT	\N	PRESENT	0
348197	339519	14257W	PARTICIPANT	\N	PRESENT	0
348198	339519	14119M	PARTICIPANT	\N	PRESENT	0
348199	339519	14083S	PARTICIPANT	\N	PRESENT	0
348209	339519	08056B	PARTICIPANT	\N	PRESENT	0
348210	339519	14187A	PARTICIPANT	\N	PRESENT	0
348211	339519	19689Q	PARTICIPANT	\N	PRESENT	0
348212	339519	19725B	PARTICIPANT	\N	PRESENT	0
348213	339519	19782L	PARTICIPANT	\N	PRESENT	0
348214	339519	08024S	PARTICIPANT	\N	PRESENT	0
348215	339519	14034U	PARTICIPANT	\N	PRESENT	0
348216	339519	14026U	PARTICIPANT	\N	PRESENT	0
348217	339519	11031D	PARTICIPANT	\N	PRESENT	0
348218	339519	19565D	PARTICIPANT	\N	PRESENT	0
348219	339519	04085P	PARTICIPANT	\N	PRESENT	0
348220	339519	19727D	PARTICIPANT	\N	PRESENT	0
348221	339519	08010L	PARTICIPANT	\N	PRESENT	0
348222	339519	14329V	PARTICIPANT	\N	PRESENT	0
348223	339519	11097X	PARTICIPANT	\N	PRESENT	0
348224	339519	19735D	PARTICIPANT	\N	PRESENT	0
348225	339519	14121F	PARTICIPANT	\N	PRESENT	0
348226	339519	19762G	PARTICIPANT	\N	PRESENT	0
348227	339519	19621T	PARTICIPANT	\N	PRESENT	0
348228	339519	19739H	PARTICIPANT	\N	PRESENT	0
348229	339519	14259Y	PARTICIPANT	\N	PRESENT	0
348230	339519	19671E	PARTICIPANT	\N	PRESENT	0
348231	339519	11103C	PARTICIPANT	\N	PRESENT	0
348232	339519	14111D	PARTICIPANT	\N	PRESENT	0
348233	339519	08043V	PARTICIPANT	\N	PRESENT	0
348234	339519	11090Q	PARTICIPANT	\N	PRESENT	0
348235	339519	14211G	PARTICIPANT	\N	PRESENT	0
348236	339519	19629C	PARTICIPANT	\N	PRESENT	0
348237	339519	19737F	PARTICIPANT	\N	PRESENT	0
348238	339519	08051V	PARTICIPANT	\N	PRESENT	0
348239	339519	08053X	PARTICIPANT	\N	PRESENT	0
348240	339519	14147R	PARTICIPANT	\N	PRESENT	0
348241	339519	15447F	PARTICIPANT	\N	PRESENT	0
348242	339519	14061L	PARTICIPANT	\N	PRESENT	0
348243	339519	19758L	PARTICIPANT	\N	PRESENT	0
348244	339519	14241N	PARTICIPANT	\N	PRESENT	0
348245	339519	19683J	PARTICIPANT	\N	PRESENT	0
348246	339519	14042U	PARTICIPANT	\N	PRESENT	0
348247	339519	14231L	PARTICIPANT	\N	PRESENT	0
348248	339519	19591F	PARTICIPANT	\N	PRESENT	0
348249	339519	14029X	PARTICIPANT	\N	PRESENT	0
348250	339519	17637T	PARTICIPANT	\N	PRESENT	0
348251	339519	14087W	PARTICIPANT	\N	PRESENT	0
345306	345305	08015R	PARTICIPANT	\N	PRESENT	0
348118	339519	01043Q	PARTICIPANT	\N	PRESENT	0
348252	339519	19467C	PARTICIPANT	\N	PRESENT	0
348253	339519	11056N	PARTICIPANT	\N	PRESENT	0
348254	339519	11010L	PARTICIPANT	\N	PRESENT	0
348255	339519	19573D	PARTICIPANT	\N	PRESENT	0
348256	339519	14107H	PARTICIPANT	\N	PRESENT	0
348257	339519	19669L	PARTICIPANT	\N	PRESENT	0
348258	339519	08060W	PARTICIPANT	\N	PRESENT	0
348259	339519	14081Q	PARTICIPANT	\N	PRESENT	0
348260	339519	08038Y	PARTICIPANT	\N	PRESENT	0
348261	339519	14021P	PARTICIPANT	\N	PRESENT	0
348262	339519	08052W	PARTICIPANT	\N	PRESENT	0
348263	339519	80013X	PARTICIPANT	\N	PRESENT	0
348264	339519	95063L	PARTICIPANT	\N	PRESENT	0
348265	339519	19681G	PARTICIPANT	\N	PRESENT	0
348266	339519	14219Q	PARTICIPANT	\N	PRESENT	0
348267	339519	19611R	PARTICIPANT	\N	PRESENT	0
348268	339519	08031R	PARTICIPANT	\N	PRESENT	0
348269	339519	19369B	PARTICIPANT	\N	PRESENT	0
348270	339519	11070L	PARTICIPANT	\N	PRESENT	0
348271	339519	01025N	PARTICIPANT	\N	PRESENT	0
348272	339519	19335Q	PARTICIPANT	\N	PRESENT	0
348273	339519	97011G	PARTICIPANT	\N	PRESENT	0
348274	339519	07033P	PARTICIPANT	\N	PRESENT	0
348275	339519	14265W	PARTICIPANT	\N	PRESENT	0
348276	339519	19581D	PARTICIPANT	\N	PRESENT	0
348277	339519	10006L	PARTICIPANT	\N	PRESENT	0
348278	339519	14079W	PARTICIPANT	\N	PRESENT	0
348279	339519	95030B	PARTICIPANT	\N	PRESENT	0
348280	339519	14223L	PARTICIPANT	\N	PRESENT	0
348281	339519	04088S	PARTICIPANT	\N	PRESENT	0
348282	339519	04071H	PARTICIPANT	\N	PRESENT	0
348283	339519	14103D	PARTICIPANT	\N	PRESENT	0
348284	339519	08055A	PARTICIPANT	\N	PRESENT	0
348285	339519	19701S	PARTICIPANT	\N	PRESENT	0
348286	339519	01060R	PARTICIPANT	\N	PRESENT	0
348287	339519	19549D	PARTICIPANT	\N	PRESENT	0
348288	339519	19768N	PARTICIPANT	\N	PRESENT	0
348289	339519	14065Q	PARTICIPANT	\N	PRESENT	0
348290	339519	01048V	PARTICIPANT	\N	PRESENT	0
348291	339519	19679N	PARTICIPANT	\N	PRESENT	0
348292	339519	14085U	PARTICIPANT	\N	PRESENT	0
348293	339519	08069G	PARTICIPANT	\N	PRESENT	0
349558	347017	95030B	PARTICIPANT	\N	PRESENT	0
349559	347017	04034C	PARTICIPANT	\N	PRESENT	0
349560	347017	14235Q	PARTICIPANT	\N	PRESENT	0
349561	347017	01058X	PARTICIPANT	\N	PRESENT	0
349562	347017	14079W	PARTICIPANT	\N	PRESENT	0
349563	347017	16685X	PARTICIPANT	\N	PRESENT	0
349564	347017	04042C	PRESIDENT	0	PRESENT	0
349565	347017	11066Q	PARTICIPANT	\N	PRESENT	0
349566	347017	19721W	PARTICIPANT	\N	PRESENT	0
349567	347017	08056B	PARTICIPANT	\N	PRESENT	0
349568	347017	19319Q	PARTICIPANT	\N	PRESENT	0
349569	347017	14055N	PARTICIPANT	\N	PRESENT	0
349570	347017	19421M	PARTICIPANT	\N	PRESENT	0
349571	347017	19709B	PARTICIPANT	\N	PRESENT	0
349572	347017	08049C	PARTICIPANT	\N	PRESENT	0
349573	347017	14193X	PARTICIPANT	\N	PRESENT	0
349574	347017	08053X	PARTICIPANT	\N	PRESENT	0
349575	347017	97011G	PARTICIPANT	\N	PRESENT	0
349576	347017	08061X	PARTICIPANT	\N	PRESENT	0
349577	347017	14211G	PARTICIPANT	\N	PRESENT	0
349578	347017	98029W	PARTICIPANT	\N	PRESENT	0
349579	347119	89017R	PARTICIPANT	\N	PRESENT	0
349580	347119	19711U	PARTICIPANT	\N	PRESENT	0
349581	347119	11110B	PARTICIPANT	\N	PRESENT	0
349582	347119	14083S	PARTICIPANT	\N	PRESENT	0
349583	347119	11040E	PARTICIPANT	\N	PRESENT	0
349584	347119	14085U	PARTICIPANT	\N	PRESENT	0
349585	347119	14121F	PARTICIPANT	\N	PRESENT	0
349586	347119	07029T	PARTICIPANT	\N	PRESENT	0
349587	347017	12041X	PARTICIPANT	\N	PRESENT	0
349588	347017	04040A	PARTICIPANT	\N	PRESENT	0
349589	347017	95037J	PARTICIPANT	\N	PRESENT	0
349590	347017	08047A	PARTICIPANT	\N	PRESENT	0
349591	347017	04035D	PARTICIPANT	\N	PRESENT	0
349592	347017	11041F	PARTICIPANT	\N	PRESENT	0
349593	347017	11064N	PARTICIPANT	\N	PRESENT	0
349594	347017	14255U	PARTICIPANT	\N	PRESENT	0
349595	347119	01057W	PARTICIPANT	\N	PRESENT	0
349596	347119	19479G	PARTICIPANT	\N	PRESENT	0
349597	347119	08010L	PARTICIPANT	\N	PRESENT	0
349598	347017	98005N	PARTICIPANT	\N	PRESENT	0
349599	347017	01062T	PARTICIPANT	\N	PRESENT	0
349600	347017	19251M	PARTICIPANT	\N	PRESENT	0
349601	347017	98022P	PARTICIPANT	\N	PRESENT	0
349602	347017	19583F	PARTICIPANT	\N	PRESENT	0
349603	347119	08069G	PARTICIPANT	\N	PRESENT	0
349604	347119	08034U	PARTICIPANT	\N	PRESENT	0
349605	346613	11090Q	PRESIDENT	0	PRESENT	0
349606	346613	14197C	PARTICIPANT	\N	EXCUSE	0
349607	346613	19295A	PARTICIPANT	\N	EXCUSE	0
349608	346613	08021P	PARTICIPANT	\N	EXCUSE	0
349609	346613	11081P	PARTICIPANT	\N	EXCUSE	0
349610	347017	11054L	PARTICIPANT	\N	PRESENT	0
349611	347017	11115U	PARTICIPANT	\N	PRESENT	0
349612	347017	14097Y	PARTICIPANT	\N	PRESENT	0
349613	347017	98018T	PARTICIPANT	\N	EXCUSE	0
349614	346613	19768N	PARTICIPANT	\N	PRESENT	0
349615	346613	19515S	PARTICIPANT	\N	PRESENT	0
349616	346613	19782L	PARTICIPANT	\N	PRESENT	0
349617	346613	14357A	PARTICIPANT	\N	PRESENT	0
349618	346613	19441R	PARTICIPANT	\N	PRESENT	0
349619	346613	14081Q	PARTICIPANT	\N	PRESENT	0
349620	346613	11099A	PARTICIPANT	\N	PRESENT	0
349621	346613	08068F	PARTICIPANT	\N	PRESENT	0
349622	346613	19705W	PARTICIPANT	\N	PRESENT	0
349623	346613	08015R	PARTICIPANT	\N	PRESENT	0
349624	346613	08019V	PARTICIPANT	\N	PRESENT	0
349625	346613	19369B	PARTICIPANT	\N	PRESENT	0
349626	346613	19511N	PARTICIPANT	\N	PRESENT	0
349627	346613	08028W	PARTICIPANT	\N	PRESENT	0
349628	346613	19563B	PARTICIPANT	\N	PRESENT	0
349629	346613	14265W	PARTICIPANT	\N	PRESENT	0
349630	346613	19591F	PARTICIPANT	\N	PRESENT	0
349631	346613	14135M	PARTICIPANT	\N	PRESENT	0
349632	346613	19467C	PARTICIPANT	\N	PRESENT	0
349633	346613	08062Y	PARTICIPANT	\N	PRESENT	0
349634	346613	14033T	PARTICIPANT	\N	PRESENT	0
349635	346613	01025N	PARTICIPANT	\N	PRESENT	0
349636	346613	04089T	PARTICIPANT	\N	PRESENT	0
349637	346613	14115H	PARTICIPANT	\N	PRESENT	0
349638	346613	11101A	PARTICIPANT	\N	PRESENT	0
349639	346613	19507S	PARTICIPANT	\N	PRESENT	0
349640	346613	19747H	PARTICIPANT	\N	PRESENT	0
349641	346613	19619A	PARTICIPANT	\N	PRESENT	0
349642	346613	17589D	PARTICIPANT	\N	PRESENT	0
349643	346613	14257W	PARTICIPANT	\N	PRESENT	0
349644	346613	08038Y	PARTICIPANT	\N	PRESENT	0
349645	347119	11048N	PARTICIPANT	\N	PRESENT	0
349646	346613	19413M	PARTICIPANT	\N	PRESENT	0
349647	346613	14205J	PARTICIPANT	\N	PRESENT	0
349648	346613	19695N	PARTICIPANT	\N	PRESENT	0
349649	346613	11056N	PARTICIPANT	\N	PRESENT	0
349651	349650	01057W	PARTICIPANT	\N	PRESENT	0
349652	349650	11074Q	PARTICIPANT	\N	PRESENT	0
349654	349653	14239U	PARTICIPANT	\N	PRESENT	0
349749	349223	04057K	PARTICIPANT	\N	PRESENT	0
349750	349223	14039A	PARTICIPANT	\N	PRESENT	0
349751	349223	14107H	PARTICIPANT	\N	PRESENT	0
349752	349223	19735D	PARTICIPANT	\N	PRESENT	0
349753	349223	08017T	PARTICIPANT	\N	PRESENT	0
349754	349223	11104D	PARTICIPANT	\N	PRESENT	0
349755	349223	19643A	PARTICIPANT	\N	PRESENT	0
349756	349223	14059S	PARTICIPANT	\N	PRESENT	0
349757	349223	14073Q	PARTICIPANT	\N	PRESENT	0
349758	349223	19611R	PARTICIPANT	\N	PRESENT	0
349862	347119	19545Y	PARTICIPANT	\N	PRESENT	0
349760	349223	19693L	PARTICIPANT	\N	PRESENT	0
349761	349223	87003B	PARTICIPANT	\N	PRESENT	0
349762	349223	19573D	PARTICIPANT	\N	PRESENT	0
349763	349223	14251Q	PARTICIPANT	\N	PRESENT	0
349764	349223	04059M	PARTICIPANT	\N	PRESENT	0
349765	349223	92040Q	PARTICIPANT	\N	PRESENT	0
349766	349223	07033P	PARTICIPANT	\N	PRESENT	0
349767	349223	14249W	PARTICIPANT	\N	PRESENT	0
349812	349527	04047H	PARTICIPANT	\N	PRESENT	0
349769	347119	01048V	PARTICIPANT	\N	PRESENT	0
349770	347119	19689Q	PARTICIPANT	\N	PRESENT	0
349771	347119	11053K	PARTICIPANT	\N	PRESENT	0
349813	349527	19673G	PARTICIPANT	\N	PRESENT	0
349814	349527	01028R	PARTICIPANT	\N	PRESENT	0
349815	349527	19447X	PARTICIPANT	\N	PRESENT	0
349816	349527	05008E	PRESIDENT	0	PRESENT	0
349817	349527	14231L	PARTICIPANT	\N	PRESENT	0
349818	349527	19489J	PARTICIPANT	\N	PRESENT	0
349819	349527	14275Y	PARTICIPANT	\N	PRESENT	0
349820	349527	14041T	PARTICIPANT	\N	PRESENT	0
349821	349527	14147R	PARTICIPANT	\N	PRESENT	0
349822	349527	14151M	PARTICIPANT	\N	PRESENT	0
349823	349527	14215L	PARTICIPANT	\N	PRESENT	0
349824	349527	08018U	PARTICIPANT	\N	PRESENT	0
349825	349527	14259Y	PARTICIPANT	\N	PRESENT	0
349826	349527	11072N	PARTICIPANT	\N	PRESENT	0
349827	349527	14111D	PARTICIPANT	\N	PRESENT	0
349828	349527	14065Q	PARTICIPANT	\N	PRESENT	0
349829	349527	11010L	PARTICIPANT	\N	PRESENT	0
349830	349527	01024M	PARTICIPANT	\N	PRESENT	0
349831	349527	04038G	PARTICIPANT	\N	PRESENT	0
349832	349527	19719D	PARTICIPANT	\N	PRESENT	0
349833	349527	11033F	PARTICIPANT	\N	PRESENT	0
349834	349527	19725B	PARTICIPANT	\N	PRESENT	0
349835	349527	08044W	PARTICIPANT	\N	PRESENT	0
349836	349527	19762G	PARTICIPANT	\N	PRESENT	0
349837	349527	98035U	PARTICIPANT	\N	PRESENT	0
349838	349527	14053L	PARTICIPANT	\N	PRESENT	0
349839	349527	19649G	PARTICIPANT	\N	PRESENT	0
349840	349527	07034Q	PARTICIPANT	\N	PRESENT	0
349841	349527	08045X	PARTICIPANT	\N	PRESENT	0
349842	349527	10015M	PARTICIPANT	\N	PRESENT	0
349843	349527	01060R	PARTICIPANT	\N	PRESENT	0
349844	349527	19543W	PARTICIPANT	\N	PRESENT	0
349845	349527	19581D	PARTICIPANT	\N	PRESENT	0
349846	349527	19585H	PARTICIPANT	\N	PRESENT	0
349847	349527	14089Y	PARTICIPANT	\N	PRESENT	0
349848	349527	19629C	PARTICIPANT	\N	PRESENT	0
349849	349527	14069U	PARTICIPANT	\N	PRESENT	0
349850	349527	11085T	PARTICIPANT	\N	PRESENT	0
349851	349527	04008A	PARTICIPANT	\N	PRESENT	0
349852	349527	08051V	PARTICIPANT	\N	PRESENT	0
349853	349527	19729F	PARTICIPANT	\N	EXCUSE	0
349854	349527	04044E	PARTICIPANT	\N	EXCUSE	0
349855	349527	14021P	PARTICIPANT	\N	EXCUSE	0
349863	339548	04059M	PARTICIPANT	\N	PRESENT	0
349864	339548	14041T	PARTICIPANT	\N	PRESENT	0
349865	347935	14038Y	PARTICIPANT	\N	PRESENT	0
349866	347935	14097Y	PARTICIPANT	\N	PRESENT	0
349867	347935	08038Y	PARTICIPANT	\N	PRESENT	0
349868	347935	14033T	PARTICIPANT	\N	PRESENT	0
349869	347935	19715Y	PARTICIPANT	\N	PRESENT	0
349870	347935	14051J	PARTICIPANT	\N	PRESENT	0
337973	321411	10015M	PARTICIPANT	\N	PRESENT	0
337974	321411	19651A	PARTICIPANT	\N	PRESENT	0
337975	321411	19733B	PARTICIPANT	\N	PRESENT	0
337976	321411	08060W	PARTICIPANT	\N	PRESENT	0
337977	321411	19251M	PARTICIPANT	\N	PRESENT	0
337978	321411	05012A	PARTICIPANT	\N	PRESENT	0
337979	321411	98035U	PARTICIPANT	\N	PRESENT	0
337980	321411	19681G	PARTICIPANT	\N	PRESENT	0
337981	321411	98022P	PARTICIPANT	\N	PRESENT	0
337982	321411	08034U	PARTICIPANT	\N	PRESENT	0
337983	321411	19689Q	PARTICIPANT	\N	PRESENT	0
337984	321411	08012N	PARTICIPANT	\N	PRESENT	0
337985	321411	14159V	PARTICIPANT	\N	PRESENT	0
337986	321411	19725B	PARTICIPANT	\N	PRESENT	0
337987	321411	19711U	PARTICIPANT	\N	PRESENT	0
337988	321411	19727D	PARTICIPANT	\N	PRESENT	0
337989	321411	01057W	PARTICIPANT	\N	PRESENT	0
337990	321411	14257W	PARTICIPANT	\N	PRESENT	0
337991	321411	14085U	PARTICIPANT	\N	PRESENT	0
337992	321411	19447X	PARTICIPANT	\N	PRESENT	0
337993	321411	19637C	PARTICIPANT	\N	PRESENT	0
337994	321411	19693L	PARTICIPANT	\N	PRESENT	0
337995	321411	19301E	PARTICIPANT	\N	PRESENT	0
337996	321411	19782L	PARTICIPANT	\N	PRESENT	0
337997	321411	14079W	PARTICIPANT	\N	PRESENT	0
337998	321411	08024S	PARTICIPANT	\N	PRESENT	0
337999	321411	14213J	PARTICIPANT	\N	PRESENT	0
338000	321411	19545Y	PARTICIPANT	\N	PRESENT	0
338001	321411	19573D	PARTICIPANT	\N	PRESENT	0
338002	321411	17589D	PARTICIPANT	\N	PRESENT	0
338003	321411	14251Q	PARTICIPANT	\N	PRESENT	0
338004	321411	19671E	PARTICIPANT	\N	PRESENT	0
338005	321411	14195A	PARTICIPANT	\N	PRESENT	0
338006	321411	14065Q	PARTICIPANT	\N	PRESENT	0
338007	321411	14021P	PARTICIPANT	\N	PRESENT	0
338008	321411	14193X	PARTICIPANT	\N	PRESENT	0
338009	321411	14111D	PARTICIPANT	\N	PRESENT	0
338010	321411	14357A	PARTICIPANT	\N	PRESENT	0
338011	321411	19387D	PARTICIPANT	\N	PRESENT	0
338012	321411	88008L	PARTICIPANT	\N	PRESENT	0
338013	321411	19667J	PARTICIPANT	\N	PRESENT	0
338014	321411	11012A	PARTICIPANT	\N	PRESENT	0
338015	321411	08051V	PARTICIPANT	\N	PRESENT	0
338016	321411	08061X	PARTICIPANT	\N	PRESENT	0
338017	321411	14029X	PARTICIPANT	\N	PRESENT	0
338018	321411	11049P	PARTICIPANT	\N	PRESENT	0
338019	321411	14105F	PARTICIPANT	\N	PRESENT	0
338020	321411	04038G	PARTICIPANT	\N	PRESENT	0
338021	321411	11031D	PARTICIPANT	\N	PRESENT	0
338022	321411	14115H	PARTICIPANT	\N	PRESENT	0
338023	321411	19657G	PARTICIPANT	\N	PRESENT	0
338024	321411	04085P	PARTICIPANT	\N	PRESENT	0
338025	321411	07029T	PARTICIPANT	\N	PRESENT	0
338026	321411	11040E	PARTICIPANT	\N	PRESENT	0
338027	321411	19565D	PARTICIPANT	\N	PRESENT	0
338028	321411	11056N	PARTICIPANT	\N	PRESENT	0
338029	321411	14259Y	PARTICIPANT	\N	PRESENT	0
338030	321411	95067Q	PARTICIPANT	\N	PRESENT	0
338031	321411	11048N	PARTICIPANT	\N	PRESENT	0
338032	321411	19760E	PARTICIPANT	\N	PRESENT	0
338033	321411	19593H	PARTICIPANT	\N	PRESENT	0
338034	321411	04042C	PARTICIPANT	\N	PRESENT	0
338035	321411	19643A	PARTICIPANT	\N	PRESENT	0
338036	321411	95063L	PARTICIPANT	\N	PRESENT	0
338037	321411	95037J	PARTICIPANT	\N	PRESENT	0
338038	321411	11083R	PARTICIPANT	\N	PRESENT	0
338039	321411	19697Q	PARTICIPANT	\N	PRESENT	0
338040	321411	19329S	PARTICIPANT	\N	PRESENT	0
338041	321411	08011M	PARTICIPANT	\N	PRESENT	0
338042	321411	08073C	PARTICIPANT	\N	PRESENT	0
338043	321411	04086Q	PARTICIPANT	\N	PRESENT	0
338044	321411	14199E	PARTICIPANT	\N	PRESENT	0
338045	321411	19575F	PARTICIPANT	\N	PRESENT	0
338046	321411	19731Y	PARTICIPANT	\N	PRESENT	0
338047	321411	08031R	PARTICIPANT	\N	PRESENT	0
338048	321411	11090Q	PARTICIPANT	\N	PRESENT	0
338049	321411	19629C	PARTICIPANT	\N	PRESENT	0
338050	321411	11099A	PARTICIPANT	\N	PRESENT	0
338051	321411	14119M	PARTICIPANT	\N	PRESENT	0
338052	321411	19289C	PARTICIPANT	\N	PRESENT	0
338053	321411	04049K	PARTICIPANT	\N	PRESENT	0
338054	321411	14038Y	PARTICIPANT	\N	PRESENT	0
338055	321411	11064N	PARTICIPANT	\N	PRESENT	0
338056	321411	19723Y	PARTICIPANT	\N	PRESENT	0
338057	321411	19467C	PARTICIPANT	\N	PRESENT	0
338058	321411	04057K	PARTICIPANT	\N	PRESENT	0
338059	321411	14135M	PARTICIPANT	\N	PRESENT	0
338060	321411	19583F	PARTICIPANT	\N	PRESENT	0
338061	321411	11074Q	PARTICIPANT	\N	PRESENT	0
338062	321411	04059M	PARTICIPANT	\N	PRESENT	0
338063	321411	19705W	PARTICIPANT	\N	PRESENT	0
338064	321411	19507S	PARTICIPANT	\N	PRESENT	0
338065	321411	14229S	PARTICIPANT	\N	PRESENT	0
338066	321411	19663E	PARTICIPANT	\N	PRESENT	0
338067	321411	08052W	PARTICIPANT	\N	PRESENT	0
338068	321411	04088S	PARTICIPANT	\N	PRESENT	0
338069	321411	14227Q	PARTICIPANT	\N	PRESENT	0
338070	321411	08018U	PARTICIPANT	\N	PRESENT	0
338071	321411	19269X	PARTICIPANT	\N	PRESENT	0
338072	321411	08048B	PARTICIPANT	\N	PRESENT	0
338073	321411	08015R	PARTICIPANT	\N	PRESENT	0
338074	321411	19768N	PARTICIPANT	\N	PRESENT	0
338075	321411	11045K	PARTICIPANT	\N	PRESENT	0
338076	321411	19647E	PARTICIPANT	\N	PRESENT	0
338077	321411	14059S	PARTICIPANT	\N	PRESENT	0
338078	321411	19489J	PARTICIPANT	\N	PRESENT	0
338079	321411	11109J	PARTICIPANT	\N	PRESENT	0
338080	321411	19621T	PARTICIPANT	\N	PRESENT	0
338081	321411	19367Y	PARTICIPANT	\N	PRESENT	0
338082	321411	14331P	PARTICIPANT	\N	PRESENT	0
338083	321411	19747H	PARTICIPANT	\N	PRESENT	0
338084	321411	11072N	PARTICIPANT	\N	PRESENT	0
338085	321411	11026G	PARTICIPANT	\N	PRESENT	0
338086	321411	14215L	PARTICIPANT	\N	PRESENT	0
338087	321411	19421M	PARTICIPANT	\N	PRESENT	0
338088	321411	11110B	PARTICIPANT	\N	PRESENT	0
338089	321411	08035V	PARTICIPANT	\N	PRESENT	0
338090	321411	14281W	PARTICIPANT	\N	PRESENT	0
338091	321411	08017T	PARTICIPANT	\N	PRESENT	0
338092	321411	14121F	PARTICIPANT	\N	PRESENT	0
338093	321411	14001X	PARTICIPANT	\N	PRESENT	0
338094	321411	86034E	PARTICIPANT	\N	PRESENT	0
338095	321411	14207L	PARTICIPANT	\N	PRESENT	0
338096	321411	08039A	PARTICIPANT	\N	PRESENT	0
338097	321411	14063N	PARTICIPANT	\N	PRESENT	0
338098	321411	19527W	PARTICIPANT	\N	PRESENT	0
338099	321411	14231L	PARTICIPANT	\N	PRESENT	0
338100	321411	08044W	PARTICIPANT	\N	PRESENT	0
338101	321411	08049C	PARTICIPANT	\N	PRESENT	0
338102	321411	19369B	PARTICIPANT	\N	PRESENT	0
338103	321411	01034P	PARTICIPANT	\N	PRESENT	0
338104	321411	04035D	PARTICIPANT	\N	PRESENT	0
338105	321411	19551W	PARTICIPANT	\N	PRESENT	0
338106	321411	19691J	PARTICIPANT	\N	PRESENT	0
338107	321411	14097Y	PARTICIPANT	\N	PRESENT	0
338108	321411	04047H	PARTICIPANT	\N	PRESENT	0
338109	321411	14109K	PARTICIPANT	\N	PRESENT	0
338110	321411	11053K	PARTICIPANT	\N	PRESENT	0
338111	321411	14069U	PARTICIPANT	\N	PRESENT	0
338112	321411	19611R	PARTICIPANT	\N	PRESENT	0
338113	321411	19737F	PARTICIPANT	\N	PRESENT	0
338114	321411	14205J	PARTICIPANT	\N	PRESENT	0
338115	321411	19699S	PARTICIPANT	\N	PRESENT	0
338116	321411	19619A	PARTICIPANT	\N	PRESENT	0
338117	321411	16685X	PARTICIPANT	\N	PRESENT	0
338118	321411	08056B	PARTICIPANT	\N	PRESENT	0
338119	321411	19735D	PARTICIPANT	\N	PRESENT	0
338120	321411	14219Q	PARTICIPANT	\N	PRESENT	0
338121	321411	19479G	PARTICIPANT	\N	PRESENT	0
338122	321411	04089T	PARTICIPANT	\N	PRESENT	0
338123	321411	14267Y	PARTICIPANT	\N	PRESENT	0
338124	321411	14103D	PARTICIPANT	\N	PRESENT	0
338125	321411	19739H	PARTICIPANT	\N	PRESENT	0
338126	321411	89017R	PARTICIPANT	\N	PRESENT	0
338127	321411	14073Q	PARTICIPANT	\N	PRESENT	0
338128	321411	14083S	PARTICIPANT	\N	PRESENT	0
338129	321411	19745F	PARTICIPANT	\N	PRESENT	0
338130	321411	14255U	PARTICIPANT	\N	PRESENT	0
338131	321411	19713W	PARTICIPANT	\N	PRESENT	0
338132	321411	07004J	PARTICIPANT	\N	PRESENT	0
338133	321411	11085T	PARTICIPANT	\N	PRESENT	0
338134	321411	19577H	PARTICIPANT	\N	PRESENT	0
338135	321411	04040A	PARTICIPANT	\N	PRESENT	0
338136	321411	04070G	PARTICIPANT	\N	PRESENT	0
338137	321411	01024M	PARTICIPANT	\N	PRESENT	0
338138	321411	14030Q	PARTICIPANT	\N	PRESENT	0
338139	321411	14327T	PARTICIPANT	\N	PRESENT	0
338140	321411	11043H	PARTICIPANT	\N	PRESENT	0
345572	339511	11104D	PARTICIPANT	\N	PRESENT	0
345573	339511	14207L	PARTICIPANT	\N	PRESENT	0
345574	339511	04059M	PARTICIPANT	\N	PRESENT	0
345575	339511	19681G	PARTICIPANT	\N	PRESENT	0
345577	345576	19415P	PARTICIPANT	\N	PRESENT	0
345578	339511	19565D	PARTICIPANT	\N	PRESENT	0
345579	345576	11067R	PARTICIPANT	\N	PRESENT	0
345580	339511	19719D	PARTICIPANT	\N	PRESENT	0
345581	339511	14041T	PARTICIPANT	\N	PRESENT	0
345582	339511	11097X	PARTICIPANT	\N	PRESENT	0
345583	345424	19399H	PARTICIPANT	\N	PRESENT	0
345584	339511	14265W	PARTICIPANT	\N	PRESENT	0
345585	339511	14033T	PARTICIPANT	\N	PRESENT	0
345586	339511	19507S	PARTICIPANT	\N	PRESENT	0
345587	339511	08038Y	PARTICIPANT	\N	PRESENT	0
345589	339511	14357A	PARTICIPANT	\N	PRESENT	0
345591	339511	14205J	PARTICIPANT	\N	PRESENT	0
345592	339511	14105F	PARTICIPANT	\N	PRESENT	0
345593	339511	08055A	PARTICIPANT	\N	PRESENT	0
345594	339511	19447X	PARTICIPANT	\N	PRESENT	0
345595	339511	14030Q	PARTICIPANT	\N	PRESENT	0
345596	339511	04086Q	PARTICIPANT	\N	PRESENT	0
345597	339511	08019V	PARTICIPANT	\N	PRESENT	0
345598	339511	87003B	PARTICIPANT	\N	PRESENT	0
345599	339511	19575F	PARTICIPANT	\N	PRESENT	0
345601	339511	11012A	PARTICIPANT	\N	PRESENT	0
345602	339511	08031R	PARTICIPANT	\N	PRESENT	0
345609	339511	14221J	PARTICIPANT	\N	PRESENT	0
345610	339511	19739H	PARTICIPANT	\N	PRESENT	0
345611	339511	14103D	PARTICIPANT	\N	PRESENT	0
345612	339511	14257W	PARTICIPANT	\N	PRESENT	0
345613	339511	01025N	PARTICIPANT	\N	PRESENT	0
345614	339511	19729F	PARTICIPANT	\N	PRESENT	0
345615	339511	19387D	PARTICIPANT	\N	PRESENT	0
345616	339511	88008L	PARTICIPANT	\N	PRESENT	0
345618	339511	80013X	PARTICIPANT	\N	PRESENT	0
345619	339511	08062Y	PARTICIPANT	\N	PRESENT	0
345620	339511	19621T	PARTICIPANT	\N	PRESENT	0
345621	339511	04085P	PARTICIPANT	\N	PRESENT	0
345622	339511	14211G	PARTICIPANT	\N	PRESENT	0
345623	339511	12016W	PARTICIPANT	\N	PRESENT	0
345624	339511	19659J	PARTICIPANT	\N	PRESENT	0
345625	339511	19533U	PARTICIPANT	\N	PRESENT	0
345627	339511	08051V	PARTICIPANT	\N	PRESENT	0
345628	339511	14135M	PARTICIPANT	\N	PRESENT	0
345629	339511	19563B	PARTICIPANT	\N	PRESENT	0
345630	339511	08015R	PARTICIPANT	\N	PRESENT	0
345632	339511	98029W	PARTICIPANT	\N	PRESENT	0
345633	339511	04089T	PARTICIPANT	\N	PRESENT	0
345634	339511	14121F	PARTICIPANT	\N	PRESENT	0
345635	339511	14042U	PARTICIPANT	\N	PRESENT	0
345636	339511	14231L	PARTICIPANT	\N	PRESENT	0
345637	339511	19713W	PARTICIPANT	\N	PRESENT	0
345638	339511	95037J	PARTICIPANT	\N	PRESENT	0
345639	339511	14021P	PARTICIPANT	\N	PRESENT	0
345640	339511	19581D	PARTICIPANT	\N	PRESENT	0
345641	339511	19367Y	PARTICIPANT	\N	PRESENT	0
345642	339511	19747H	PARTICIPANT	\N	PRESENT	0
345643	339511	14133K	PARTICIPANT	\N	PRESENT	0
345644	339511	19525U	PARTICIPANT	\N	PRESENT	0
345645	345252	19333N	PARTICIPANT	\N	PRESENT	0
345646	345252	14103D	PARTICIPANT	\N	PRESENT	0
345647	345252	19713W	PARTICIPANT	\N	PRESENT	0
345648	345252	14031R	PARTICIPANT	\N	PRESENT	0
345649	345252	19549D	PARTICIPANT	\N	PRESENT	0
345650	345252	19387D	PARTICIPANT	\N	PRESENT	0
345651	345252	08055A	PARTICIPANT	\N	PRESENT	0
345652	345252	18083K	PARTICIPANT	\N	PRESENT	0
345653	345252	15447F	PARTICIPANT	\N	PRESENT	0
345654	345252	80027E	PARTICIPANT	\N	PRESENT	0
345681	339511	19349W	PARTICIPANT	\N	PRESENT	0
345656	345252	19733B	PARTICIPANT	\N	PRESENT	0
345657	345252	08009T	PRESIDENT	0	PRESENT	0
345658	345252	19503N	PARTICIPANT	\N	PRESENT	0
345659	345252	19347U	PARTICIPANT	\N	PRESENT	0
345660	345252	19737F	PARTICIPANT	\N	PRESENT	0
345661	345252	19739H	PARTICIPANT	\N	PRESENT	0
345662	345252	19745F	PARTICIPANT	\N	PRESENT	0
345663	345252	19659J	PARTICIPANT	\N	PRESENT	0
345664	345252	19681G	PARTICIPANT	\N	PRESENT	0
345665	345252	19685L	PARTICIPANT	\N	EXCUSE	0
345666	339511	98022P	PARTICIPANT	\N	PRESENT	0
345667	339511	14115H	PARTICIPANT	\N	PRESENT	0
345668	339511	04057K	PARTICIPANT	\N	PRESENT	0
345669	339511	19479G	PARTICIPANT	\N	PRESENT	0
345670	339511	11045K	PARTICIPANT	\N	PRESENT	0
345671	339511	01058X	PARTICIPANT	\N	PRESENT	0
345672	339511	11109J	PARTICIPANT	\N	PRESENT	0
345673	339511	19413M	PARTICIPANT	\N	PRESENT	0
345674	339511	19717B	PARTICIPANT	\N	PRESENT	0
345675	339511	14059S	PARTICIPANT	\N	PRESENT	0
345676	339511	14038Y	PARTICIPANT	\N	PRESENT	0
345677	345252	14219Q	PARTICIPANT	\N	PRESENT	0
345678	345252	19637C	PARTICIPANT	\N	PRESENT	0
345679	345252	14169X	PARTICIPANT	\N	PRESENT	0
345683	339511	08010L	PARTICIPANT	\N	PRESENT	0
345682	339511	14109K	PARTICIPANT	\N	PRESENT	0
345684	339511	11043H	PARTICIPANT	\N	PRESENT	0
345685	339511	08034U	PARTICIPANT	\N	PRESENT	0
345686	345252	19701S	PARTICIPANT	\N	PRESENT	0
345687	345252	95062K	PARTICIPANT	\N	PRESENT	0
345688	345252	19599P	PARTICIPANT	\N	PRESENT	0
345689	345252	19551W	PARTICIPANT	\N	PRESENT	0
345690	345252	05012A	PARTICIPANT	\N	PRESENT	0
345691	345252	17637T	PARTICIPANT	\N	PRESENT	0
345692	339511	14061L	PARTICIPANT	\N	PRESENT	0
345693	345252	02002K	PARTICIPANT	\N	PRESENT	0
345694	345309	11067R	PARTICIPANT	\N	PRESENT	0
345695	345309	14147R	PARTICIPANT	\N	PRESENT	0
345696	345309	14223L	PARTICIPANT	\N	PRESENT	0
345697	345309	19295A	PARTICIPANT	\N	PRESENT	0
345698	345309	19749K	PARTICIPANT	\N	PRESENT	0
345699	345309	10006L	PRESIDENT	0	PRESENT	0
345700	345309	14030Q	PARTICIPANT	\N	PRESENT	0
345701	345309	08031R	PARTICIPANT	\N	PRESENT	0
345702	345309	08043V	PARTICIPANT	\N	EXCUSE	0
345703	339511	19782L	PARTICIPANT	\N	PRESENT	0
345704	339511	04018C	PARTICIPANT	\N	PRESENT	0
345705	339511	08056B	PARTICIPANT	\N	PRESENT	0
345706	339511	11070L	PARTICIPANT	\N	PRESENT	0
345707	345252	19545Y	PARTICIPANT	\N	PRESENT	0
345708	345252	14237S	PARTICIPANT	\N	PRESENT	0
345709	345252	14038Y	PARTICIPANT	\N	PRESENT	0
345710	339511	11027H	PARTICIPANT	\N	PRESENT	0
345711	345617	14111D	PARTICIPANT	\N	PRESENT	0
345712	345617	14065Q	PARTICIPANT	\N	PRESENT	0
345713	345617	10015M	PARTICIPANT	\N	PRESENT	0
345714	345617	11026G	PARTICIPANT	\N	PRESENT	0
345715	345617	14001X	PARTICIPANT	\N	PRESENT	0
345716	345617	04038G	PARTICIPANT	\N	PRESENT	0
345717	345617	19585H	PARTICIPANT	\N	PRESENT	0
345718	345617	11033F	PARTICIPANT	\N	PRESENT	0
345719	345617	01028R	PARTICIPANT	\N	PRESENT	0
345720	345617	19447X	PARTICIPANT	\N	PRESENT	0
345721	345617	05008E	PRESIDENT	0	PRESENT	0
345722	345617	19489J	PARTICIPANT	\N	PRESENT	0
345723	345617	19729F	PARTICIPANT	\N	PRESENT	0
345724	345617	95063L	PARTICIPANT	\N	PRESENT	0
345725	345617	14179A	PARTICIPANT	\N	PRESENT	0
345726	345617	14069U	PARTICIPANT	\N	PRESENT	0
345727	345617	14215L	PARTICIPANT	\N	PRESENT	0
345728	345617	11049P	PARTICIPANT	\N	PRESENT	0
345729	345617	19762G	PARTICIPANT	\N	PRESENT	0
345730	345617	08051V	PARTICIPANT	\N	PRESENT	0
345731	345617	14089Y	PARTICIPANT	\N	PRESENT	0
345732	345617	14147R	PARTICIPANT	\N	PRESENT	0
345733	339511	14029X	PARTICIPANT	\N	PRESENT	0
345734	339511	14199E	PARTICIPANT	\N	PRESENT	0
345735	345309	11045K	PARTICIPANT	\N	PRESENT	0
345736	345631	14111D	PARTICIPANT	\N	PRESENT	0
345737	345631	14065Q	PARTICIPANT	\N	PRESENT	0
345738	345631	11026G	PARTICIPANT	\N	PRESENT	0
345739	345631	10015M	PARTICIPANT	\N	PRESENT	0
345740	345631	14001X	PARTICIPANT	\N	PRESENT	0
345741	345631	04038G	PARTICIPANT	\N	PRESENT	0
345742	345631	19585H	PARTICIPANT	\N	PRESENT	0
345743	345631	01028R	PARTICIPANT	\N	PRESENT	0
345744	345631	11033F	PARTICIPANT	\N	PRESENT	0
345745	345631	05008E	PRESIDENT	0	PRESENT	0
345746	345631	19447X	PARTICIPANT	\N	PRESENT	0
345747	345631	19729F	PARTICIPANT	\N	PRESENT	0
345748	345631	19489J	PARTICIPANT	\N	PRESENT	0
345749	345631	95063L	PARTICIPANT	\N	PRESENT	0
345750	345631	14041T	PARTICIPANT	\N	PRESENT	0
345751	345631	14147R	PARTICIPANT	\N	PRESENT	0
345752	345631	14179A	PARTICIPANT	\N	PRESENT	0
345753	345631	14215L	PARTICIPANT	\N	PRESENT	0
345754	345631	11049P	PARTICIPANT	\N	PRESENT	0
345755	345631	19762G	PARTICIPANT	\N	PRESENT	0
332893	332892	19631V	PARTICIPANT	\N	PRESENT	0
332894	332892	19747H	PARTICIPANT	\N	PRESENT	0
332895	332892	14207L	PARTICIPANT	\N	PRESENT	0
332896	332892	19441R	PARTICIPANT	\N	PRESENT	0
332897	332892	14265W	PARTICIPANT	\N	PRESENT	0
332898	332892	19413M	PARTICIPANT	\N	PRESENT	0
332908	332907	19551W	PARTICIPANT	\N	PRESENT	0
332909	332907	19737F	PARTICIPANT	\N	PRESENT	0
332910	332907	19525U	PARTICIPANT	\N	PRESENT	0
332911	332907	19681G	PARTICIPANT	\N	PRESENT	0
332912	332907	19713W	PARTICIPANT	\N	PRESENT	0
332913	332907	19745F	PARTICIPANT	\N	PRESENT	0
332914	332907	19637C	PARTICIPANT	\N	PRESENT	0
332915	332907	14031R	PARTICIPANT	\N	PRESENT	0
335247	321380	04059M	PARTICIPANT	\N	PRESENT	0
335248	321380	11040E	PARTICIPANT	\N	PRESENT	0
335249	321380	14085U	PARTICIPANT	\N	PRESENT	0
335250	321380	01057W	PARTICIPANT	\N	PRESENT	0
335251	321380	14225N	PARTICIPANT	\N	PRESENT	0
335252	321380	11074Q	PARTICIPANT	\N	PRESENT	0
335253	321380	04018C	PARTICIPANT	\N	PRESENT	0
335254	321380	19671E	PARTICIPANT	\N	PRESENT	0
335255	321380	07029T	PARTICIPANT	\N	PRESENT	0
335256	321380	04088S	PARTICIPANT	\N	PRESENT	0
335257	321380	19447X	PARTICIPANT	\N	PRESENT	0
335258	321380	19515S	PARTICIPANT	\N	PRESENT	0
335259	321380	14031R	PARTICIPANT	\N	PRESENT	0
335260	321380	04086Q	PARTICIPANT	\N	PRESENT	0
335261	321380	14179A	PARTICIPANT	\N	PRESENT	0
335262	321380	19695N	PARTICIPANT	\N	PRESENT	0
335263	321380	14327T	PARTICIPANT	\N	PRESENT	0
335264	321380	99004R	PARTICIPANT	\N	PRESENT	0
335265	321380	19741B	PARTICIPANT	\N	PRESENT	0
335266	321380	19689Q	PARTICIPANT	\N	PRESENT	0
335267	321380	14081Q	PARTICIPANT	\N	PRESENT	0
335268	321380	19545Y	PARTICIPANT	\N	PRESENT	0
335269	321380	19711U	PARTICIPANT	\N	PRESENT	0
335270	321380	11110B	PARTICIPANT	\N	PRESENT	0
335271	321380	14083S	PARTICIPANT	\N	PRESENT	0
335272	321380	11026G	PARTICIPANT	\N	PRESENT	0
335273	321380	19651A	PARTICIPANT	\N	PRESENT	0
335274	321380	19657G	PARTICIPANT	\N	PRESENT	0
335275	321380	19693L	PARTICIPANT	\N	PRESENT	0
335276	321380	07004J	PARTICIPANT	\N	PRESENT	0
335277	321380	19717B	PARTICIPANT	\N	PRESENT	0
335279	321380	08011M	PARTICIPANT	\N	PRESENT	0
335280	321380	19569H	PARTICIPANT	\N	PRESENT	0
335281	321380	19553Y	PARTICIPANT	\N	PRESENT	0
335282	321380	19705W	PARTICIPANT	\N	PRESENT	0
335283	321380	98022P	PARTICIPANT	\N	PRESENT	0
335287	321380	14331P	PARTICIPANT	\N	PRESENT	0
335288	321380	19611R	PARTICIPANT	\N	PRESENT	0
335289	321380	11053K	PARTICIPANT	\N	PRESENT	0
335294	321380	19551W	PARTICIPANT	\N	PRESENT	0
335295	321380	14193X	PARTICIPANT	\N	PRESENT	0
335296	321380	14169X	PARTICIPANT	\N	PRESENT	0
335297	321380	14229S	PARTICIPANT	\N	PRESENT	0
335298	321380	11070L	PARTICIPANT	\N	PRESENT	0
335299	321380	14069U	PARTICIPANT	\N	PRESENT	0
335337	321382	14225N	PARTICIPANT	\N	PRESENT	0
335338	321382	11040E	PARTICIPANT	\N	PRESENT	0
335339	321382	19693L	PARTICIPANT	\N	PRESENT	0
335340	321382	19551W	PARTICIPANT	\N	PRESENT	0
335341	321382	19711U	PARTICIPANT	\N	PRESENT	0
335342	321382	08019V	PARTICIPANT	\N	PRESENT	0
335343	321382	07029T	PARTICIPANT	\N	PRESENT	0
335344	321382	07004J	PARTICIPANT	\N	PRESENT	0
335345	321382	14331P	PARTICIPANT	\N	PRESENT	0
335346	321382	14193X	PARTICIPANT	\N	PRESENT	0
335347	321382	14169X	PARTICIPANT	\N	PRESENT	0
335348	321382	04086Q	PARTICIPANT	\N	PRESENT	0
335349	321382	19515S	PARTICIPANT	\N	PRESENT	0
335350	321382	19657G	PARTICIPANT	\N	PRESENT	0
335351	321382	04088S	PARTICIPANT	\N	PRESENT	0
335352	321382	19447X	PARTICIPANT	\N	PRESENT	0
335353	321382	19667J	PARTICIPANT	\N	PRESENT	0
335354	321382	19671E	PARTICIPANT	\N	PRESENT	0
335355	321382	19695N	PARTICIPANT	\N	PRESENT	0
335356	321382	19687N	PARTICIPANT	\N	PRESENT	0
335357	321382	14085U	PARTICIPANT	\N	PRESENT	0
335358	321382	08011M	PARTICIPANT	\N	PRESENT	0
335359	321382	14083S	PARTICIPANT	\N	PRESENT	0
335363	321382	19545Y	PARTICIPANT	\N	PRESENT	0
335361	321382	19715Y	PARTICIPANT	\N	PRESENT	0
335362	321382	19503N	PARTICIPANT	\N	PRESENT	0
335364	321382	19689Q	PARTICIPANT	\N	PRESENT	0
335365	321382	11048N	PARTICIPANT	\N	PRESENT	0
335366	321382	14081Q	PARTICIPANT	\N	PRESENT	0
335367	321382	19569H	PARTICIPANT	\N	PRESENT	0
335368	321382	12016W	PARTICIPANT	\N	PRESENT	0
335373	321382	98022P	PARTICIPANT	\N	PRESENT	0
335375	321382	19717B	PARTICIPANT	\N	PRESENT	0
335376	321382	19741B	PARTICIPANT	\N	PRESENT	0
335377	321382	19651A	PARTICIPANT	\N	PRESENT	0
335335	321382	11070L	PARTICIPANT	\N	PRESENT	0
335336	321382	11074Q	PARTICIPANT	\N	PRESENT	0
335378	321382	19699S	PARTICIPANT	\N	PRESENT	0
335379	321382	11109J	PARTICIPANT	\N	PRESENT	0
335386	321382	19319Q	PARTICIPANT	\N	PRESENT	0
335387	321382	14229S	PARTICIPANT	\N	PRESENT	0
335388	321382	14039A	PARTICIPANT	\N	PRESENT	0
335389	321382	04018C	PARTICIPANT	\N	PRESENT	0
335390	321382	14253S	PARTICIPANT	\N	PRESENT	0
335397	321382	19647E	PARTICIPANT	\N	PRESENT	0
335404	321382	11090Q	PARTICIPANT	\N	PRESENT	0
335434	321382	04071H	PARTICIPANT	\N	PRESENT	0
335449	321382	19553Y	PARTICIPANT	\N	PRESENT	0
335450	321382	07033P	PARTICIPANT	\N	PRESENT	0
335451	321382	19705W	PARTICIPANT	\N	PRESENT	0
335452	321382	01058X	PARTICIPANT	\N	PRESENT	0
335453	321382	19611R	PARTICIPANT	\N	PRESENT	0
335454	321382	11085T	PARTICIPANT	\N	PRESENT	0
335455	321382	19643A	PARTICIPANT	\N	PRESENT	0
335457	321382	11053K	PARTICIPANT	\N	PRESENT	0
335493	321384	19687N	PARTICIPANT	\N	PRESENT	0
335494	321384	19591F	PARTICIPANT	\N	PRESENT	0
335495	321384	19647E	PARTICIPANT	\N	PRESENT	0
335496	321384	11074Q	PARTICIPANT	\N	PRESENT	0
335497	321384	08011M	PARTICIPANT	\N	PRESENT	0
335498	321384	19651A	PARTICIPANT	\N	PRESENT	0
335499	321384	11053K	PARTICIPANT	\N	PRESENT	0
335500	321384	19569H	PARTICIPANT	\N	PRESENT	0
335501	321384	04018C	PARTICIPANT	\N	PRESENT	0
335502	321384	04086Q	PARTICIPANT	\N	PRESENT	0
335503	321384	11090Q	PARTICIPANT	\N	PRESENT	0
335504	321384	19711U	PARTICIPANT	\N	PRESENT	0
335505	321384	19693L	PARTICIPANT	\N	PRESENT	0
335506	321384	07029T	PARTICIPANT	\N	PRESENT	0
335507	321384	19741B	PARTICIPANT	\N	PRESENT	0
335508	321384	19667J	PARTICIPANT	\N	PRESENT	0
335509	321384	19515S	PARTICIPANT	\N	PRESENT	0
335510	321384	19643A	PARTICIPANT	\N	PRESENT	0
335511	321384	19545Y	PARTICIPANT	\N	PRESENT	0
335512	321384	14085U	PARTICIPANT	\N	PRESENT	0
335513	321384	11109J	PARTICIPANT	\N	PRESENT	0
335514	321384	14193X	PARTICIPANT	\N	PRESENT	0
335515	321384	07004J	PARTICIPANT	\N	PRESENT	0
335516	321384	19715Y	PARTICIPANT	\N	PRESENT	0
335517	321384	04071H	PARTICIPANT	\N	PRESENT	0
335518	321384	19551W	PARTICIPANT	\N	PRESENT	0
335519	321384	14331P	PARTICIPANT	\N	PRESENT	0
335520	321384	11085T	PARTICIPANT	\N	PRESENT	0
335521	321384	98022P	PARTICIPANT	\N	PRESENT	0
335522	321384	19553Y	PARTICIPANT	\N	PRESENT	0
335523	321384	01058X	PARTICIPANT	\N	PRESENT	0
335524	321384	14083S	PARTICIPANT	\N	PRESENT	0
335525	321384	08019V	PARTICIPANT	\N	PRESENT	0
335491	321384	11072N	PARTICIPANT	\N	PRESENT	0
335492	321384	12041X	PARTICIPANT	\N	PRESENT	0
335734	326852	14107H	PARTICIPANT	\N	PRESENT	0
335735	326851	14107H	PARTICIPANT	\N	PRESENT	0
335737	335736	04038G	PARTICIPANT	\N	PRESENT	0
336569	336568	08009T	PARTICIPANT	\N	PRESENT	0
336570	336568	11026G	PARTICIPANT	\N	PRESENT	0
336571	336568	19713W	PARTICIPANT	\N	PRESENT	0
338516	337910	14119M	PARTICIPANT	\N	EXCUSE	0
338517	338217	19367Y	PARTICIPANT	\N	PRESENT	0
338518	338217	14223L	PARTICIPANT	\N	PRESENT	0
338519	338217	04088S	PARTICIPANT	\N	PRESENT	0
338520	338217	14105F	PARTICIPANT	\N	PRESENT	0
338521	338217	08052W	PARTICIPANT	\N	PRESENT	0
338522	338217	11031D	PARTICIPANT	\N	PRESENT	0
338523	338217	19727D	PARTICIPANT	\N	PRESENT	0
338524	338217	17779H	PARTICIPANT	\N	PRESENT	0
338525	338217	19415P	PARTICIPANT	\N	PRESENT	0
338526	338217	19575F	PARTICIPANT	\N	PRESENT	0
338527	338217	19679N	PARTICIPANT	\N	PRESENT	0
338528	338217	19731Y	PARTICIPANT	\N	PRESENT	0
349871	347935	08060W	PARTICIPANT	\N	PRESENT	0
349872	347935	19629C	PARTICIPANT	\N	PRESENT	0
349873	347935	19347U	PARTICIPANT	\N	PRESENT	0
349874	347935	08019V	PARTICIPANT	\N	PRESENT	0
349875	347935	14157T	PRESIDENT	0	PRESENT	0
349876	347935	19369B	PARTICIPANT	\N	PRESENT	0
349877	347935	19745F	PARTICIPANT	\N	PRESENT	0
349878	347935	19747H	PARTICIPANT	\N	PRESENT	0
349879	347935	19762G	PARTICIPANT	\N	PRESENT	0
349880	347935	11048N	PARTICIPANT	\N	EXCUSE	0
349881	347935	19733B	PARTICIPANT	\N	EXCUSE	0
349882	339548	08015R	PARTICIPANT	\N	PRESENT	0
349883	339548	14265W	PARTICIPANT	\N	PRESENT	0
349884	339548	19711U	PARTICIPANT	\N	PRESENT	0
349885	339548	14223L	PARTICIPANT	\N	PRESENT	0
349886	339548	14227Q	PARTICIPANT	\N	PRESENT	0
349887	339548	80013X	PARTICIPANT	\N	PRESENT	0
349888	339548	95030B	PARTICIPANT	\N	PRESENT	0
349889	339548	19399H	PARTICIPANT	\N	PRESENT	0
349891	339548	19619A	PARTICIPANT	\N	PRESENT	0
349892	339548	19731Y	PARTICIPANT	\N	PRESENT	0
349893	339548	04034C	PARTICIPANT	\N	PRESENT	0
349894	339548	19794Q	PARTICIPANT	\N	PRESENT	0
349895	339548	14237S	PARTICIPANT	\N	PRESENT	0
349896	339548	01025N	PARTICIPANT	\N	PRESENT	0
349898	339548	19723Y	PARTICIPANT	\N	PRESENT	0
349899	339548	14073Q	PARTICIPANT	\N	PRESENT	0
349900	339548	19521Q	PARTICIPANT	\N	PRESENT	0
349901	339548	19349W	PARTICIPANT	\N	PRESENT	0
349902	339548	11048N	PARTICIPANT	\N	PRESENT	0
349903	339548	19695N	PARTICIPANT	\N	PRESENT	0
349904	339548	11056N	PARTICIPANT	\N	PRESENT	0
349905	339548	11077T	PARTICIPANT	\N	PRESENT	0
349906	339548	08068F	PARTICIPANT	\N	PRESENT	0
349907	339548	14257W	PARTICIPANT	\N	PRESENT	0
349908	339548	19599P	PARTICIPANT	\N	PRESENT	0
349909	339548	14089Y	PARTICIPANT	\N	PRESENT	0
349910	339548	14083S	PARTICIPANT	\N	PRESENT	0
349911	339548	19671E	PARTICIPANT	\N	PRESENT	0
349912	339548	11097X	PARTICIPANT	\N	PRESENT	0
349913	339548	14119M	PARTICIPANT	\N	PRESENT	0
349914	339548	19467C	PARTICIPANT	\N	PRESENT	0
349915	339548	19758L	PARTICIPANT	\N	PRESENT	0
349916	339548	11040E	PARTICIPANT	\N	PRESENT	0
349917	339548	19515S	PARTICIPANT	\N	PRESENT	0
349918	339548	14241N	PARTICIPANT	\N	PRESENT	0
349919	339548	04057K	PARTICIPANT	\N	PRESENT	0
349920	339548	19697Q	PARTICIPANT	\N	PRESENT	0
349921	339548	14205J	PARTICIPANT	\N	PRESENT	0
349922	339548	19569H	PARTICIPANT	\N	PRESENT	0
349923	339548	11066Q	PARTICIPANT	\N	PRESENT	0
349924	339548	14103D	PARTICIPANT	\N	PRESENT	0
349925	339548	19631V	PARTICIPANT	\N	PRESENT	0
349926	339548	08045X	PARTICIPANT	\N	PRESENT	0
349927	339548	08062Y	PARTICIPANT	\N	PRESENT	0
349928	339548	97011G	PARTICIPANT	\N	PRESENT	0
349929	339548	04049K	PARTICIPANT	\N	PRESENT	0
349930	339548	14026U	PARTICIPANT	\N	PRESENT	0
349931	339548	19575F	PARTICIPANT	\N	PRESENT	0
349932	339548	19441R	PARTICIPANT	\N	PRESENT	0
349933	339548	19507S	PARTICIPANT	\N	PRESENT	0
349934	339548	19667J	PARTICIPANT	\N	PRESENT	0
349935	339548	14038Y	PARTICIPANT	\N	PRESENT	0
349936	339548	19415P	PARTICIPANT	\N	PRESENT	0
349937	339548	19673G	PARTICIPANT	\N	PRESENT	0
349938	339548	19563B	PARTICIPANT	\N	PRESENT	0
349939	339548	19725B	PARTICIPANT	\N	PRESENT	0
349940	339548	08028W	PARTICIPANT	\N	PRESENT	0
349941	339548	99004R	PARTICIPANT	\N	PRESENT	0
349942	339548	19681G	PARTICIPANT	\N	PRESENT	0
349943	339548	19737F	PARTICIPANT	\N	PRESENT	0
349944	339548	11104D	PARTICIPANT	\N	PRESENT	0
349945	339548	14069U	PARTICIPANT	\N	PRESENT	0
349946	339548	14219Q	PARTICIPANT	\N	PRESENT	0
349947	339548	14267Y	PARTICIPANT	\N	PRESENT	0
349948	339548	19383Y	PARTICIPANT	\N	PRESENT	0
349949	339548	19545Y	PARTICIPANT	\N	PRESENT	0
349950	339548	19585H	PARTICIPANT	\N	PRESENT	0
349951	339548	14231L	PARTICIPANT	\N	PRESENT	0
349952	339548	14331P	PARTICIPANT	\N	PRESENT	0
349953	339548	19782L	PARTICIPANT	\N	PRESENT	0
349954	339548	14169X	PARTICIPANT	\N	PRESENT	0
349955	339548	19413M	PARTICIPANT	\N	PRESENT	0
349956	339548	19689Q	PARTICIPANT	\N	PRESENT	0
349957	339548	14147R	PARTICIPANT	\N	PRESENT	0
349958	339548	11090Q	PARTICIPANT	\N	PRESENT	0
349959	339548	17637T	PARTICIPANT	\N	PRESENT	0
349960	339548	14079W	PARTICIPANT	\N	PRESENT	0
349961	339548	14215L	PARTICIPANT	\N	PRESENT	0
349962	339548	14217N	PARTICIPANT	\N	PRESENT	0
349963	339548	19549D	PARTICIPANT	\N	PRESENT	0
349964	339548	11072N	PARTICIPANT	\N	PRESENT	0
349965	339548	14107H	PARTICIPANT	\N	PRESENT	0
349966	339548	01024M	PARTICIPANT	\N	PRESENT	0
349967	339548	14029X	PARTICIPANT	\N	PRESENT	0
349968	339548	01058X	PARTICIPANT	\N	PRESENT	0
349969	339548	95063L	PARTICIPANT	\N	PRESENT	0
349970	339548	04018C	PARTICIPANT	\N	PRESENT	0
349971	339548	19527W	PARTICIPANT	\N	PRESENT	0
349972	339548	19663E	PARTICIPANT	\N	PRESENT	0
349973	339548	14151M	PARTICIPANT	\N	PRESENT	0
349974	339548	19543W	PARTICIPANT	\N	PRESENT	0
349975	339548	19479G	PARTICIPANT	\N	PRESENT	0
349976	339548	11010L	PARTICIPANT	\N	PRESENT	0
349977	339548	14187A	PARTICIPANT	\N	PRESENT	0
349978	339548	11110B	PARTICIPANT	\N	PRESENT	0
349979	339548	14109K	PARTICIPANT	\N	PRESENT	0
349980	339548	11012A	PARTICIPANT	\N	PRESENT	0
349981	339548	14239U	PARTICIPANT	\N	PRESENT	0
349982	339548	19611R	PARTICIPANT	\N	PRESENT	0
349983	339548	14061L	PARTICIPANT	\N	PRESENT	0
349984	339548	14034U	PARTICIPANT	\N	PRESENT	0
349985	339548	14121F	PARTICIPANT	\N	PRESENT	0
349986	346533	14237S	PARTICIPANT	\N	PRESENT	0
349987	346533	19333N	PARTICIPANT	\N	PRESENT	0
349988	346533	14031R	PARTICIPANT	\N	PRESENT	0
349989	346533	19713W	PARTICIPANT	\N	PRESENT	0
349990	346533	08009T	PRESIDENT	0	PRESENT	0
349991	346533	04097T	PARTICIPANT	\N	PRESENT	0
349992	346533	08055A	PARTICIPANT	\N	PRESENT	0
349993	346533	19599P	PARTICIPANT	\N	PRESENT	0
349994	346533	19525U	PARTICIPANT	\N	PRESENT	0
349995	346533	08060W	PARTICIPANT	\N	EXCUSE	0
349996	346533	95062K	PARTICIPANT	\N	EXCUSE	0
349997	346533	19685L	PARTICIPANT	\N	EXCUSE	0
349998	339548	08034U	PARTICIPANT	\N	PRESENT	0
349999	339548	01048V	PARTICIPANT	\N	PRESENT	0
350000	339548	10006L	PARTICIPANT	\N	PRESENT	0
350001	346533	14103D	PARTICIPANT	\N	PRESENT	0
350002	346533	19794Q	PARTICIPANT	\N	PRESENT	0
350026	346533	80027E	PARTICIPANT	\N	PRESENT	0
350004	346533	14219Q	PARTICIPANT	\N	PRESENT	0
350005	346533	14169X	PARTICIPANT	\N	PRESENT	0
350006	346533	19637C	PARTICIPANT	\N	PRESENT	0
350007	346533	02002K	PARTICIPANT	\N	PRESENT	0
350008	346533	19745F	PARTICIPANT	\N	PRESENT	0
350009	346533	19681G	PARTICIPANT	\N	PRESENT	0
350010	346533	19551W	PARTICIPANT	\N	PRESENT	0
350011	346533	05012A	PARTICIPANT	\N	PRESENT	0
350012	346533	14051J	PARTICIPANT	\N	PRESENT	0
350013	346533	19347U	PARTICIPANT	\N	PRESENT	0
350014	346533	19737F	PARTICIPANT	\N	PRESENT	0
350015	346533	17637T	PARTICIPANT	\N	PRESENT	0
350018	339548	19747H	PARTICIPANT	\N	PRESENT	0
350019	339548	16685X	PARTICIPANT	\N	PRESENT	0
350022	346533	19503N	PARTICIPANT	\N	PRESENT	0
350023	346533	11065P	PARTICIPANT	\N	PRESENT	0
350024	346533	19289C	PARTICIPANT	\N	PRESENT	0
350025	339548	19269X	PARTICIPANT	\N	PRESENT	0
350027	347935	08024S	PARTICIPANT	\N	PRESENT	0
350028	347935	08049C	PARTICIPANT	\N	EXCUSE	0
350029	339548	14135M	PARTICIPANT	\N	PRESENT	0
350030	339548	14033T	PARTICIPANT	\N	PRESENT	0
350031	339548	14199E	PARTICIPANT	\N	PRESENT	0
350032	339548	19629C	PARTICIPANT	\N	PRESENT	0
350033	346533	14157T	PARTICIPANT	\N	PRESENT	0
350034	346533	19701S	PARTICIPANT	\N	PRESENT	0
350035	348034	11067R	PARTICIPANT	\N	PRESENT	0
350036	348034	19649G	PARTICIPANT	\N	PRESENT	0
350037	348034	14147R	PARTICIPANT	\N	PRESENT	0
350038	348034	14213J	PARTICIPANT	\N	PRESENT	0
350039	348034	04047H	PARTICIPANT	\N	PRESENT	0
350040	348034	10006L	PRESIDENT	0	PRESENT	0
350041	348034	19673G	PARTICIPANT	\N	PRESENT	0
350042	348034	11033F	PARTICIPANT	\N	PRESENT	0
350043	348034	08031R	PARTICIPANT	\N	PRESENT	0
350044	348034	14231L	PARTICIPANT	\N	PRESENT	0
350045	348034	19295A	PARTICIPANT	\N	EXCUSE	0
350046	348034	19749K	PARTICIPANT	\N	EXCUSE	0
333203	331592	14053L	PARTICIPANT	\N	PRESENT	0
333204	331592	14111D	PARTICIPANT	\N	PRESENT	0
333255	331592	08018U	PARTICIPANT	\N	PRESENT	0
333206	331592	07034Q	PARTICIPANT	\N	PRESENT	0
333256	331590	95030B	PARTICIPANT	\N	PRESENT	0
333257	331590	04034C	PARTICIPANT	\N	PRESENT	0
333209	331592	14001X	PARTICIPANT	\N	PRESENT	0
333210	331592	19543W	PARTICIPANT	\N	PRESENT	0
333211	331592	04038G	PARTICIPANT	\N	PRESENT	0
333212	331592	19673G	PARTICIPANT	\N	PRESENT	0
333213	331592	01028R	PARTICIPANT	\N	PRESENT	0
333214	331592	14231L	PARTICIPANT	\N	PRESENT	0
333215	331592	05008E	PRESIDENT	0	PRESENT	0
333216	331592	19725B	PARTICIPANT	\N	PRESENT	0
333217	331592	19729F	PARTICIPANT	\N	PRESENT	0
333218	331592	19489J	PARTICIPANT	\N	PRESENT	0
333258	331590	11054L	PARTICIPANT	\N	PRESENT	0
333220	331592	19629C	PARTICIPANT	\N	PRESENT	0
333259	331590	19721W	PARTICIPANT	\N	PRESENT	0
333222	331592	14147R	PARTICIPANT	\N	PRESENT	0
333260	331590	14105F	PARTICIPANT	\N	PRESENT	0
333261	331590	95037J	PARTICIPANT	\N	PRESENT	0
333262	331590	97011G	PARTICIPANT	\N	PRESENT	0
333263	331590	01062T	PARTICIPANT	\N	PRESENT	0
333227	331592	19447X	PARTICIPANT	\N	PRESENT	0
333228	331592	14021P	PARTICIPANT	\N	PRESENT	0
333264	331590	14079W	PARTICIPANT	\N	PRESENT	0
333230	331592	19581D	PARTICIPANT	\N	PRESENT	0
333231	331592	14215L	PARTICIPANT	\N	PRESENT	0
333265	331590	08058D	PARTICIPANT	\N	PRESENT	0
333266	331590	98018T	PARTICIPANT	\N	PRESENT	0
333267	331590	19421M	PARTICIPANT	\N	PRESENT	0
333268	331590	01058X	PARTICIPANT	\N	PRESENT	0
333236	331590	19319Q	PARTICIPANT	\N	PRESENT	0
333237	331590	12041X	PARTICIPANT	\N	PRESENT	0
333238	331590	19731Y	PARTICIPANT	\N	PRESENT	0
333239	331590	14235Q	PARTICIPANT	\N	PRESENT	0
333240	331590	14267Y	PARTICIPANT	\N	PRESENT	0
333241	331590	04042C	PRESIDENT	0	PRESENT	0
333242	331590	11066Q	PARTICIPANT	\N	PRESENT	0
333243	331590	19583F	PARTICIPANT	\N	PRESENT	0
333244	331592	04047H	PARTICIPANT	\N	PRESENT	0
333245	331592	14179A	PARTICIPANT	\N	PRESENT	0
333246	331592	11072N	PARTICIPANT	\N	PRESENT	0
333247	331592	14065Q	PARTICIPANT	\N	PRESENT	0
333248	331592	10015M	PARTICIPANT	\N	PRESENT	0
333249	331592	11026G	PARTICIPANT	\N	PRESENT	0
333250	331592	95063L	PARTICIPANT	\N	PRESENT	0
333251	331592	14069U	PARTICIPANT	\N	PRESENT	0
333252	331592	11085T	PARTICIPANT	\N	PRESENT	0
333253	331592	04008A	PARTICIPANT	\N	PRESENT	0
333254	331592	14151M	PARTICIPANT	\N	PRESENT	0
333269	331590	14229S	PARTICIPANT	\N	PRESENT	0
333270	331590	14107H	PARTICIPANT	\N	PRESENT	0
333271	331590	08061X	PARTICIPANT	\N	PRESENT	0
333272	331590	08043V	PARTICIPANT	\N	PRESENT	0
333273	331590	87003B	PARTICIPANT	\N	PRESENT	0
333274	331590	14201E	PARTICIPANT	\N	PRESENT	0
333275	331590	14063N	PARTICIPANT	\N	PRESENT	0
333276	331590	98050T	PARTICIPANT	\N	PRESENT	0
333277	331590	11104D	PARTICIPANT	\N	PRESENT	0
333278	331590	19758L	PARTICIPANT	\N	PRESENT	0
333279	331590	04018C	PARTICIPANT	\N	PRESENT	0
333280	331590	14211G	PARTICIPANT	\N	PRESENT	0
333281	331590	95067Q	PARTICIPANT	\N	PRESENT	0
333282	331590	11041F	PARTICIPANT	\N	PRESENT	0
333283	331590	04070G	PARTICIPANT	\N	PRESENT	0
333284	331590	16685X	PARTICIPANT	\N	PRESENT	0
333285	331590	11064N	PARTICIPANT	\N	PRESENT	0
333286	331590	08017T	PARTICIPANT	\N	PRESENT	0
333287	331590	19611R	PARTICIPANT	\N	PRESENT	0
333288	331590	14123H	PARTICIPANT	\N	PRESENT	0
333289	331590	19749K	PARTICIPANT	\N	PRESENT	0
333290	331590	19766L	PARTICIPANT	\N	PRESENT	0
333291	331590	04035D	PARTICIPANT	\N	PRESENT	0
333292	333056	19766L	PARTICIPANT	\N	PRESENT	0
333293	333056	04070G	PRESIDENT	0	PRESENT	0
333294	333056	19699S	PARTICIPANT	\N	PRESENT	0
333295	333056	12041X	PARTICIPANT	\N	PRESENT	0
333296	333056	95030B	PARTICIPANT	\N	PRESENT	0
333297	333056	04034C	PARTICIPANT	\N	PRESENT	0
333298	333056	14079W	PARTICIPANT	\N	PRESENT	0
333299	333056	01058X	PARTICIPANT	\N	PRESENT	0
333300	333056	16685X	PARTICIPANT	\N	PRESENT	0
333301	333056	04042C	PARTICIPANT	\N	PRESENT	0
333302	333056	11054L	PARTICIPANT	\N	PRESENT	0
333303	333056	11066Q	PARTICIPANT	\N	PRESENT	0
333304	333056	14229S	PARTICIPANT	\N	PRESENT	0
333305	333056	95037J	PARTICIPANT	\N	PRESENT	0
333306	333056	19421M	PARTICIPANT	\N	PRESENT	0
333307	333056	14107H	PARTICIPANT	\N	PRESENT	0
333308	333056	08017T	PARTICIPANT	\N	PRESENT	0
333309	333056	97011G	PARTICIPANT	\N	PRESENT	0
333310	333056	08061X	PARTICIPANT	\N	PRESENT	0
333311	333056	04035D	PARTICIPANT	\N	PRESENT	0
333312	333056	95067Q	PARTICIPANT	\N	PRESENT	0
333313	333056	01062T	PARTICIPANT	\N	PRESENT	0
333314	333056	11041F	PARTICIPANT	\N	PRESENT	0
333315	333056	19611R	PARTICIPANT	\N	PRESENT	0
333316	333056	14235Q	PARTICIPANT	\N	PRESENT	0
333317	333056	08058D	PARTICIPANT	\N	PRESENT	0
333318	333056	08043V	PARTICIPANT	\N	PRESENT	0
333319	333056	87003B	PARTICIPANT	\N	PRESENT	0
333320	333056	14201E	PARTICIPANT	\N	PRESENT	0
333321	333056	19721W	PARTICIPANT	\N	PRESENT	0
333322	333056	19319Q	PARTICIPANT	\N	PRESENT	0
333323	333056	14105F	PARTICIPANT	\N	PRESENT	0
333324	333056	19731Y	PARTICIPANT	\N	PRESENT	0
333325	333056	98018T	PARTICIPANT	\N	PRESENT	0
333326	333056	14267Y	PARTICIPANT	\N	PRESENT	0
333327	333056	11064N	PARTICIPANT	\N	PRESENT	0
333328	333056	14063N	PARTICIPANT	\N	PRESENT	0
333329	333056	98050T	PARTICIPANT	\N	PRESENT	0
333330	333056	14123H	PARTICIPANT	\N	PRESENT	0
333331	333056	11104D	PARTICIPANT	\N	PRESENT	0
333332	333056	19749K	PARTICIPANT	\N	PRESENT	0
333333	333056	19758L	PARTICIPANT	\N	PRESENT	0
333334	333056	04018C	PARTICIPANT	\N	PRESENT	0
333335	333056	14211G	PARTICIPANT	\N	PRESENT	0
333336	333056	19583F	PARTICIPANT	\N	PRESENT	0
333337	331590	19699S	PARTICIPANT	\N	PRESENT	0
333338	331590	08039A	PARTICIPANT	\N	PRESENT	0
333339	331590	19573D	PARTICIPANT	\N	PRESENT	0
333340	331590	04033B	PARTICIPANT	\N	PRESENT	0
333341	331590	14028W	PARTICIPANT	\N	PRESENT	0
333342	331590	14061L	PARTICIPANT	\N	PRESENT	0
333343	331590	14030Q	PARTICIPANT	\N	PRESENT	0
333344	331590	14193X	PARTICIPANT	\N	PRESENT	0
333345	331590	11109J	PARTICIPANT	\N	PRESENT	0
333346	333056	19573D	PARTICIPANT	\N	PRESENT	0
333347	333056	14061L	PARTICIPANT	\N	PRESENT	0
333348	333056	14030Q	PARTICIPANT	\N	PRESENT	0
333349	333056	11109J	PARTICIPANT	\N	PRESENT	0
333350	333056	04033B	PARTICIPANT	\N	PRESENT	0
333351	333056	14193X	PARTICIPANT	\N	PRESENT	0
333352	333056	08039A	PARTICIPANT	\N	PRESENT	0
333353	333056	14028W	PARTICIPANT	\N	PRESENT	0
333354	332759	14327T	PARTICIPANT	\N	PRESENT	0
333355	332759	14331P	PARTICIPANT	\N	PRESENT	0
333356	332759	04071H	PARTICIPANT	\N	PRESENT	0
333357	332759	01057W	PARTICIPANT	\N	PRESENT	0
333358	332759	11074Q	PRESIDENT	0	PRESENT	0
333359	332759	89017R	PARTICIPANT	\N	PRESENT	0
333360	332759	19667J	PARTICIPANT	\N	PRESENT	0
333361	332759	11070L	PARTICIPANT	\N	PRESENT	0
333362	332759	88008L	PARTICIPANT	\N	PRESENT	0
333363	332759	14225N	PARTICIPANT	\N	PRESENT	0
333364	332759	19671E	PARTICIPANT	\N	PRESENT	0
333365	332759	14085U	PARTICIPANT	\N	PRESENT	0
333366	332759	07004J	PARTICIPANT	\N	PRESENT	0
333367	332759	19349W	PARTICIPANT	\N	PRESENT	0
333368	332759	14253S	PARTICIPANT	\N	PRESENT	0
333369	332759	11048N	PARTICIPANT	\N	PRESENT	0
333370	332759	19711U	PARTICIPANT	\N	PRESENT	0
333371	332759	08034U	PARTICIPANT	\N	PRESENT	0
333372	332759	19651A	PARTICIPANT	\N	PRESENT	0
333373	332759	19687N	PARTICIPANT	\N	PRESENT	0
333374	332759	12016W	PARTICIPANT	\N	PRESENT	0
333375	332759	14034U	PARTICIPANT	\N	PRESENT	0
333376	332759	14159V	PARTICIPANT	\N	PRESENT	0
333377	332759	14173T	PARTICIPANT	\N	PRESENT	0
333378	332759	11040E	PARTICIPANT	\N	PRESENT	0
333379	332759	04086Q	PARTICIPANT	\N	PRESENT	0
333380	332759	14199E	PARTICIPANT	\N	PRESENT	0
333381	332759	11012A	PARTICIPANT	\N	PRESENT	0
333382	332759	08073C	PARTICIPANT	\N	PRESENT	0
333383	332759	14121F	PARTICIPANT	\N	PRESENT	0
333384	332759	99004R	PARTICIPANT	\N	PRESENT	0
333385	332759	07029T	PARTICIPANT	\N	EXCUSE	0
345756	345631	14021P	PARTICIPANT	\N	PRESENT	0
345757	345631	08051V	PARTICIPANT	\N	PRESENT	0
345758	339511	14201E	PARTICIPANT	\N	PRESENT	0
345760	339511	14217N	PARTICIPANT	\N	PRESENT	0
345761	339511	14079W	PARTICIPANT	\N	PRESENT	0
345762	339511	19703U	PARTICIPANT	\N	PRESENT	0
345763	339511	19691J	PARTICIPANT	\N	PRESENT	0
345764	339511	11049P	PARTICIPANT	\N	PRESENT	0
345765	339511	14241N	PARTICIPANT	\N	PRESENT	0
345766	339511	19369B	PARTICIPANT	\N	PRESENT	0
345767	339511	10015M	PARTICIPANT	\N	PRESENT	0
345769	339511	04045F	PARTICIPANT	\N	PRESENT	0
345770	339511	14031R	PARTICIPANT	\N	PRESENT	0
345771	345309	01028R	PARTICIPANT	\N	PRESENT	0
345772	339511	95062K	PARTICIPANT	\N	PRESENT	0
345773	339511	05012A	PARTICIPANT	\N	PRESENT	0
345775	339511	14249W	PARTICIPANT	\N	PRESENT	0
345776	339511	14239U	PARTICIPANT	\N	PRESENT	0
345777	339511	95067Q	PARTICIPANT	\N	PRESENT	0
345778	339511	16685X	PARTICIPANT	\N	PRESENT	0
345780	339511	19733B	PARTICIPANT	\N	PRESENT	0
345781	339511	11099A	PARTICIPANT	\N	PRESENT	0
345905	339512	11109J	PARTICIPANT	\N	PRESENT	0
345906	339512	19333N	PARTICIPANT	\N	PRESENT	0
345907	339512	14227Q	PARTICIPANT	\N	PRESENT	0
345908	339512	14051J	PARTICIPANT	\N	PRESENT	0
345909	339512	19631V	PARTICIPANT	\N	PRESENT	0
345910	339512	19521Q	PARTICIPANT	\N	PRESENT	0
345911	339512	19782L	PARTICIPANT	\N	PRESENT	0
345912	339512	04034C	PARTICIPANT	\N	PRESENT	0
345913	339512	19651A	PARTICIPANT	\N	PRESENT	0
345914	339512	11031D	PARTICIPANT	\N	PRESENT	0
345915	339512	19565D	PARTICIPANT	\N	PRESENT	0
345916	339512	11099A	PARTICIPANT	\N	PRESENT	0
345917	339512	19629C	PARTICIPANT	\N	PRESENT	0
345918	339512	19719D	PARTICIPANT	\N	PRESENT	0
345919	339512	19503N	PARTICIPANT	\N	PRESENT	0
345920	339512	19760E	PARTICIPANT	\N	PRESENT	0
345921	339512	19695N	PARTICIPANT	\N	PRESENT	0
345922	339512	19691J	PARTICIPANT	\N	PRESENT	0
345923	339512	14042U	PARTICIPANT	\N	PRESENT	0
345924	339512	19441R	PARTICIPANT	\N	PRESENT	0
345925	339512	19737F	PARTICIPANT	\N	PRESENT	0
345926	339512	14267Y	PARTICIPANT	\N	PRESENT	0
345927	339512	14083S	PARTICIPANT	\N	PRESENT	0
345928	339512	19747H	PARTICIPANT	\N	PRESENT	0
345929	339512	14089Y	PARTICIPANT	\N	PRESENT	0
345930	339512	01025N	PARTICIPANT	\N	PRESENT	0
345931	339512	08051V	PARTICIPANT	\N	PRESENT	0
345932	339512	14079W	PARTICIPANT	\N	PRESENT	0
345933	339512	14249W	PARTICIPANT	\N	PRESENT	0
345934	339512	14069U	PARTICIPANT	\N	PRESENT	0
345935	339512	95030B	PARTICIPANT	\N	PRESENT	0
345936	339512	14147R	PARTICIPANT	\N	PRESENT	0
345937	339512	08019V	PARTICIPANT	\N	PRESENT	0
345938	339512	19399H	PARTICIPANT	\N	PRESENT	0
345939	339512	19681G	PARTICIPANT	\N	PRESENT	0
345940	339512	14038Y	PARTICIPANT	\N	PRESENT	0
345941	339512	19679N	PARTICIPANT	\N	PRESENT	0
345942	339512	08010L	PARTICIPANT	\N	PRESENT	0
345943	339512	11110B	PARTICIPANT	\N	PRESENT	0
345944	339512	14257W	PARTICIPANT	\N	PRESENT	0
345945	339512	19349W	PARTICIPANT	\N	PRESENT	0
345946	339512	04045F	PARTICIPANT	\N	PRESENT	0
345947	339512	19637C	PARTICIPANT	\N	PRESENT	0
345948	339512	14033T	PARTICIPANT	\N	PRESENT	0
345949	339512	14030Q	PARTICIPANT	\N	PRESENT	0
345950	339512	19621T	PARTICIPANT	\N	PRESENT	0
345951	339512	19762G	PARTICIPANT	\N	PRESENT	0
345952	339512	14031R	PARTICIPANT	\N	PRESENT	0
345953	339512	19533U	PARTICIPANT	\N	PRESENT	0
345954	339512	14331P	PARTICIPANT	\N	PRESENT	0
345955	339512	14187A	PARTICIPANT	\N	PRESENT	0
345956	339512	19711U	PARTICIPANT	\N	PRESENT	0
345957	339512	19713W	PARTICIPANT	\N	PRESENT	0
345958	339512	19715Y	PARTICIPANT	\N	PRESENT	0
345959	339512	14159V	PARTICIPANT	\N	PRESENT	0
345960	339512	19563B	PARTICIPANT	\N	PRESENT	0
345961	339512	14357A	PARTICIPANT	\N	PRESENT	0
345962	339512	11048N	PARTICIPANT	\N	PRESENT	0
345963	339512	08034U	PARTICIPANT	\N	PRESENT	0
345964	339512	18083K	PARTICIPANT	\N	PRESENT	0
345965	339512	19447X	PARTICIPANT	\N	PRESENT	0
345966	339512	19467C	PARTICIPANT	\N	PRESENT	0
345967	339512	14065Q	PARTICIPANT	\N	PRESENT	0
345968	339512	14133K	PARTICIPANT	\N	PRESENT	0
345969	339512	19703U	PARTICIPANT	\N	PRESENT	0
345970	339512	08038Y	PARTICIPANT	\N	PRESENT	0
345971	339512	19733B	PARTICIPANT	\N	PRESENT	0
345972	339512	07029T	PARTICIPANT	\N	PRESENT	0
345973	339512	14061L	PARTICIPANT	\N	PRESENT	0
345974	339512	14026U	PARTICIPANT	\N	PRESENT	0
345975	339512	14213J	PARTICIPANT	\N	PRESENT	0
345976	339512	14265W	PARTICIPANT	\N	PRESENT	0
345977	339512	19507S	PARTICIPANT	\N	PRESENT	0
345978	339512	04088S	PARTICIPANT	\N	PRESENT	0
345979	339512	14219Q	PARTICIPANT	\N	PRESENT	0
345980	339512	11053K	PARTICIPANT	\N	PRESENT	0
345981	339512	11097X	PARTICIPANT	\N	PRESENT	0
345982	339512	11090Q	PARTICIPANT	\N	PRESENT	0
345983	339512	12016W	PARTICIPANT	\N	PRESENT	0
345984	339512	04033B	PARTICIPANT	\N	PRESENT	0
345985	339512	11056N	PARTICIPANT	\N	PRESENT	0
345986	339512	14215L	PARTICIPANT	\N	PRESENT	0
345987	339512	14135M	PARTICIPANT	\N	PRESENT	0
345988	345588	19515S	PARTICIPANT	\N	PRESENT	0
345989	345588	11048N	PARTICIPANT	\N	PRESENT	0
345990	345588	19711U	PARTICIPANT	\N	PRESENT	0
345991	345588	14187A	PARTICIPANT	\N	PRESENT	0
345992	345588	19441R	PARTICIPANT	\N	PRESENT	0
345993	345588	12016W	PARTICIPANT	\N	PRESENT	0
345994	345588	89017R	PARTICIPANT	\N	PRESENT	0
345995	345588	19399H	PARTICIPANT	\N	PRESENT	0
345996	345588	14159V	PARTICIPANT	\N	PRESENT	0
345997	345588	14227Q	PARTICIPANT	\N	PRESENT	0
345998	345588	14173T	PARTICIPANT	\N	PRESENT	0
345999	345588	14083S	PARTICIPANT	\N	PRESENT	0
346000	345588	04049K	PARTICIPANT	\N	PRESENT	0
346001	345588	14199E	PARTICIPANT	\N	PRESENT	0
346002	345588	08073C	PARTICIPANT	\N	PRESENT	0
345903	339512	14034U	PARTICIPANT	\N	PRESENT	0
345904	339512	04049K	PARTICIPANT	\N	PRESENT	0
346003	345588	14151M	PARTICIPANT	\N	PRESENT	0
346004	345588	19760E	PARTICIPANT	\N	PRESENT	0
346005	345588	14329V	PARTICIPANT	\N	PRESENT	0
346006	345588	11090Q	PARTICIPANT	\N	PRESENT	0
346007	345588	14026U	PARTICIPANT	\N	PRESENT	0
346008	345588	14157T	PARTICIPANT	\N	PRESENT	0
346009	345588	19521Q	PRESIDENT	0	PRESENT	0
346010	345588	19762G	PARTICIPANT	\N	PRESENT	0
346011	345588	11053K	PARTICIPANT	\N	PRESENT	0
346012	345036	95067Q	PARTICIPANT	\N	PRESENT	0
346013	345036	12041X	PARTICIPANT	\N	PRESENT	0
346014	345036	14133K	PARTICIPANT	\N	PRESENT	0
346015	345036	01062T	PARTICIPANT	\N	PRESENT	0
346016	345036	04034C	PARTICIPANT	\N	PRESENT	0
346017	345036	14235Q	PARTICIPANT	\N	PRESENT	0
346018	345036	04040A	PARTICIPANT	\N	PRESENT	0
346019	345036	14079W	PARTICIPANT	\N	PRESENT	0
346020	345036	16685X	PARTICIPANT	\N	PRESENT	0
346021	345036	08058D	PARTICIPANT	\N	PRESENT	0
346022	345036	14028W	PARTICIPANT	\N	PRESENT	0
346023	345036	19251M	PARTICIPANT	\N	PRESENT	0
346024	345036	11054L	PARTICIPANT	\N	PRESENT	0
346025	345036	11066Q	PARTICIPANT	\N	PRESENT	0
346026	345036	19319Q	PARTICIPANT	\N	PRESENT	0
346027	345036	14105F	PARTICIPANT	\N	PRESENT	0
346028	345036	19709B	PARTICIPANT	\N	PRESENT	0
346029	345036	14193X	PRESIDENT	0	PRESENT	0
346030	345036	14267Y	PARTICIPANT	\N	PRESENT	0
346031	345036	98050T	PARTICIPANT	\N	PRESENT	0
346032	345036	08061X	PARTICIPANT	\N	PRESENT	0
346033	345036	08047A	PARTICIPANT	\N	PRESENT	0
346037	345036	98022P	PARTICIPANT	\N	PRESENT	0
346038	345105	19768N	PARTICIPANT	\N	PRESENT	0
346039	345105	19515S	PARTICIPANT	\N	PRESENT	0
346040	345105	19782L	PARTICIPANT	\N	PRESENT	0
346041	345105	14357A	PARTICIPANT	\N	PRESENT	0
346042	345105	80013X	PARTICIPANT	\N	PRESENT	0
346043	345105	19705W	PARTICIPANT	\N	PRESENT	0
346044	345105	08019V	PARTICIPANT	\N	PRESENT	0
346045	345105	19369B	PARTICIPANT	\N	PRESENT	0
346046	345105	19511N	PARTICIPANT	\N	PRESENT	0
346047	345105	08028W	PARTICIPANT	\N	PRESENT	0
346048	345105	19563B	PARTICIPANT	\N	PRESENT	0
346049	345105	14265W	PARTICIPANT	\N	PRESENT	0
346050	345105	19467C	PARTICIPANT	\N	PRESENT	0
346051	345105	14187A	PARTICIPANT	\N	PRESENT	0
333989	333981	04085P	PARTICIPANT	\N	PRESENT	0
333990	333981	04059M	PARTICIPANT	\N	PRESENT	0
333991	333981	96004D	PARTICIPANT	\N	PRESENT	0
333992	333981	04042C	PARTICIPANT	\N	PRESENT	0
333993	333981	11027H	PARTICIPANT	\N	PRESENT	0
333994	333981	98023Q	PARTICIPANT	\N	PRESENT	0
333995	333981	04086Q	PARTICIPANT	\N	PRESENT	0
333996	333981	14079W	PARTICIPANT	\N	PRESENT	0
333997	333981	11070L	PARTICIPANT	\N	PRESENT	0
333998	333981	11074Q	PARTICIPANT	\N	PRESENT	0
333999	333981	19521Q	PARTICIPANT	\N	PRESENT	0
334000	333981	14034U	PARTICIPANT	\N	PRESENT	0
334002	333981	14021P	PARTICIPANT	\N	PRESENT	0
334003	333981	14159V	PARTICIPANT	\N	PRESENT	0
334004	333981	01043Q	PARTICIPANT	\N	PRESENT	0
334005	333981	14251Q	PARTICIPANT	\N	PRESENT	0
334006	333981	11085T	PARTICIPANT	\N	PRESENT	0
334007	333981	04092N	PARTICIPANT	\N	PRESENT	0
334008	333981	11072N	PARTICIPANT	\N	PRESENT	0
334009	333981	08011M	PARTICIPANT	\N	PRESENT	0
334010	333981	08061X	PARTICIPANT	\N	PRESENT	0
334011	333981	07034Q	PARTICIPANT	\N	PRESENT	0
334012	333981	11090Q	PARTICIPANT	\N	PRESENT	0
334013	333981	11012A	PARTICIPANT	\N	PRESENT	0
334016	333981	04033B	PARTICIPANT	\N	PRESENT	0
334017	333981	04044E	PARTICIPANT	\N	PRESENT	0
334019	333981	01034P	PARTICIPANT	\N	PRESENT	0
334025	334024	04049K	PARTICIPANT	\N	PRESENT	0
334026	334024	14083S	PARTICIPANT	\N	PRESENT	0
334027	334024	14173T	PARTICIPANT	\N	PRESENT	0
334030	334029	04049K	PARTICIPANT	\N	PRESENT	0
334031	334029	14083S	PARTICIPANT	\N	PRESENT	0
334034	334033	04049K	PARTICIPANT	\N	PRESENT	0
334035	334033	14083S	PARTICIPANT	\N	PRESENT	0
334037	334036	04049K	PARTICIPANT	\N	PRESENT	0
334038	334036	14083S	PARTICIPANT	\N	PRESENT	0
334039	334036	19441R	PARTICIPANT	\N	PRESENT	0
334040	334036	14173T	PARTICIPANT	\N	PRESENT	0
334043	334042	04049K	PARTICIPANT	\N	PRESENT	0
334112	334111	11053K	PARTICIPANT	\N	PRESENT	0
334113	334111	14159V	PARTICIPANT	\N	PRESENT	0
334114	334111	05012A	PARTICIPANT	\N	PRESENT	0
334138	334137	19741B	PARTICIPANT	\N	PRESENT	0
334139	334137	10006L	PARTICIPANT	\N	PRESENT	0
334140	334137	08031R	PARTICIPANT	\N	PRESENT	0
334141	334137	11049P	PARTICIPANT	\N	PRESENT	0
334463	334154	14030Q	PRESIDENT	0	PRESENT	0
334464	334154	08043V	PARTICIPANT	\N	PRESENT	0
334465	334154	80013X	PARTICIPANT	\N	PRESENT	0
334466	334154	19693L	PARTICIPANT	\N	PRESENT	0
334467	334154	14217N	PARTICIPANT	\N	PRESENT	0
334468	334154	14249W	PARTICIPANT	\N	PRESENT	0
334469	334154	19715Y	PARTICIPANT	\N	PRESENT	0
334470	334154	19731Y	PARTICIPANT	\N	PRESENT	0
334471	334154	08031R	PARTICIPANT	\N	PRESENT	0
334472	334154	08017T	PARTICIPANT	\N	PRESENT	0
334473	334154	11067R	PARTICIPANT	\N	PRESENT	0
334474	334154	14109K	PARTICIPANT	\N	PRESENT	0
334475	334154	19749K	PARTICIPANT	\N	PRESENT	0
334476	334154	19701S	PARTICIPANT	\N	EXCUSE	0
334477	334154	11031D	PARTICIPANT	\N	EXCUSE	0
334478	334154	07029T	PARTICIPANT	\N	EXCUSE	0
334479	334154	01043Q	PARTICIPANT	\N	EXCUSE	0
334480	334154	18083K	PARTICIPANT	\N	EXCUSE	0
335530	321394	11070L	PARTICIPANT	\N	PRESENT	0
335531	321394	11074Q	PARTICIPANT	\N	PRESENT	0
335532	321394	08011M	PARTICIPANT	\N	PRESENT	0
335533	321394	11040E	PARTICIPANT	\N	PRESENT	0
335534	321394	04057K	PARTICIPANT	\N	PRESENT	0
335535	321394	07033P	PARTICIPANT	\N	PRESENT	0
335536	321394	19693L	PARTICIPANT	\N	PRESENT	0
335537	321394	14193X	PARTICIPANT	\N	PRESENT	0
335538	321394	14085U	PARTICIPANT	\N	PRESENT	0
335539	321394	08019V	PARTICIPANT	\N	PRESENT	0
335540	321394	19657G	PARTICIPANT	\N	PRESENT	0
335541	321394	07029T	PARTICIPANT	\N	PRESENT	0
335542	321394	19711U	PARTICIPANT	\N	PRESENT	0
335543	321394	14173T	PARTICIPANT	\N	PRESENT	0
335544	321394	04086Q	PARTICIPANT	\N	PRESENT	0
335545	321394	07004J	PARTICIPANT	\N	PRESENT	0
335546	321394	14205J	PARTICIPANT	\N	PRESENT	0
335547	321394	11012A	PARTICIPANT	\N	PRESENT	0
335548	321394	99004R	PARTICIPANT	\N	PRESENT	0
335549	321394	04085P	PARTICIPANT	\N	PRESENT	0
335550	321394	95063L	PARTICIPANT	\N	PRESENT	0
335551	321394	19689Q	PARTICIPANT	\N	PRESENT	0
335552	321394	19503N	PARTICIPANT	\N	PRESENT	0
335553	321394	04071H	PARTICIPANT	\N	PRESENT	0
335554	321394	14265W	PARTICIPANT	\N	PRESENT	0
335555	321394	14039A	PARTICIPANT	\N	PRESENT	0
335556	321394	14357A	PARTICIPANT	\N	PRESENT	0
335557	321394	14159V	PARTICIPANT	\N	PRESENT	0
335558	321394	11053K	PARTICIPANT	\N	PRESENT	0
335559	321394	19715Y	PARTICIPANT	\N	PRESENT	0
335560	321394	11072N	PARTICIPANT	\N	PRESENT	0
335561	321394	11090Q	PARTICIPANT	\N	PRESENT	0
335562	321394	04043D	PARTICIPANT	\N	PRESENT	0
335563	321394	04034C	PARTICIPANT	\N	PRESENT	0
335564	321394	14169X	PARTICIPANT	\N	PRESENT	0
335565	321394	14327T	PARTICIPANT	\N	PRESENT	0
335569	321394	19741B	PARTICIPANT	\N	PRESENT	0
335577	321394	08034U	PARTICIPANT	\N	PRESENT	0
335578	321394	11097X	PARTICIPANT	\N	PRESENT	0
335579	321394	19695N	PARTICIPANT	\N	PRESENT	0
335581	321394	98050T	PARTICIPANT	\N	PRESENT	0
335582	321394	19647E	PARTICIPANT	\N	PRESENT	0
335583	321394	11048N	PARTICIPANT	\N	PRESENT	0
335630	321395	19503N	PARTICIPANT	\N	PRESENT	0
335631	321395	04043D	PARTICIPANT	\N	PRESENT	0
335632	321395	19711U	PARTICIPANT	\N	PRESENT	0
335633	321395	07004J	PARTICIPANT	\N	PRESENT	0
335634	321395	11097X	PARTICIPANT	\N	PRESENT	0
335635	321395	04034C	PARTICIPANT	\N	PRESENT	0
335636	321395	14085U	PARTICIPANT	\N	PRESENT	0
335637	321395	08011M	PARTICIPANT	\N	PRESENT	0
335638	321395	11048N	PARTICIPANT	\N	PRESENT	0
335639	321395	07029T	PARTICIPANT	\N	PRESENT	0
335640	321395	11090Q	PARTICIPANT	\N	PRESENT	0
335641	321395	19693L	PARTICIPANT	\N	PRESENT	0
335642	321395	19695N	PARTICIPANT	\N	PRESENT	0
335643	321395	14265W	PARTICIPANT	\N	PRESENT	0
335644	321395	11040E	PARTICIPANT	\N	PRESENT	0
335645	321395	99004R	PARTICIPANT	\N	PRESENT	0
335646	321395	11012A	PARTICIPANT	\N	PRESENT	0
335647	321395	14041T	PARTICIPANT	\N	PRESENT	0
335648	321395	14327T	PARTICIPANT	\N	PRESENT	0
335649	321395	19689Q	PARTICIPANT	\N	PRESENT	0
335650	321395	19733B	PARTICIPANT	\N	PRESENT	0
335651	321395	19687N	PARTICIPANT	\N	PRESENT	0
335652	321395	19479G	PARTICIPANT	\N	PRESENT	0
335653	321395	14231L	PARTICIPANT	\N	PRESENT	0
335654	321395	04086Q	PARTICIPANT	\N	PRESENT	0
335655	321395	08019V	PARTICIPANT	\N	PRESENT	0
335656	321395	11109J	PARTICIPANT	\N	PRESENT	0
335684	321395	04057K	PARTICIPANT	\N	PRESENT	0
335686	321395	98050T	PARTICIPANT	\N	PRESENT	0
335689	321395	19657G	PARTICIPANT	\N	PRESENT	0
335690	321395	14159V	PARTICIPANT	\N	PRESENT	0
335704	321395	19741B	PARTICIPANT	\N	PRESENT	0
335707	321395	08034U	PARTICIPANT	\N	PRESENT	0
335708	321395	11074Q	PARTICIPANT	\N	PRESENT	0
335628	321395	11072N	PARTICIPANT	\N	PRESENT	0
335629	321395	14357A	PARTICIPANT	\N	PRESENT	0
335709	321395	19647E	PARTICIPANT	\N	PRESENT	0
335710	321395	14021P	PARTICIPANT	\N	PRESENT	0
335711	321395	04085P	PARTICIPANT	\N	PRESENT	0
335712	321395	14039A	PARTICIPANT	\N	PRESENT	0
335713	321395	19319Q	PARTICIPANT	\N	PRESENT	0
338529	338217	14219Q	PARTICIPANT	\N	PRESENT	0
338530	338217	19295A	PARTICIPANT	\N	PRESENT	0
338531	338217	19703U	PARTICIPANT	\N	PRESENT	0
338532	338217	11066Q	PARTICIPANT	\N	PRESENT	0
338533	338217	14213J	PARTICIPANT	\N	PRESENT	0
338534	338217	19629C	PARTICIPANT	\N	PRESENT	0
338535	338217	19691J	PARTICIPANT	\N	PRESENT	0
338536	338217	97011G	PARTICIPANT	\N	PRESENT	0
338537	338217	18083K	PARTICIPANT	\N	PRESENT	0
338538	338217	19671E	PARTICIPANT	\N	PRESENT	0
338539	338217	14195A	PARTICIPANT	\N	PRESENT	0
338540	338217	19251M	PARTICIPANT	\N	PRESENT	0
338541	338217	19697Q	PARTICIPANT	\N	PRESENT	0
338542	338217	14241N	PARTICIPANT	\N	PRESENT	0
338543	338217	14191V	PARTICIPANT	\N	PRESENT	0
338544	338217	95030B	PARTICIPANT	\N	PRESENT	0
338545	338217	14111D	PARTICIPANT	\N	PRESENT	0
338546	338217	14239U	PARTICIPANT	\N	PRESENT	0
338547	338217	19507S	PARTICIPANT	\N	PRESENT	0
338548	338217	19565D	PARTICIPANT	\N	PRESENT	0
338549	338217	04092N	PARTICIPANT	\N	PRESENT	0
350047	339548	08010L	PARTICIPANT	\N	PRESENT	0
350048	339548	14255U	PARTICIPANT	\N	PRESENT	0
350050	339548	14249W	PARTICIPANT	\N	PRESENT	0
350051	339548	14053L	PARTICIPANT	\N	PRESENT	0
350052	339548	08055A	PARTICIPANT	\N	PRESENT	0
350053	339548	08024S	PARTICIPANT	\N	PRESENT	0
350054	339548	08061X	PARTICIPANT	\N	PRESENT	0
350055	339548	11083R	PARTICIPANT	\N	PRESENT	0
350056	339548	89017R	PARTICIPANT	\N	PRESENT	0
350057	339548	14042U	PARTICIPANT	\N	PRESENT	0
350059	339548	04043D	PARTICIPANT	\N	PRESENT	0
350073	339548	19573D	PARTICIPANT	\N	PRESENT	0
350075	339548	11031D	PARTICIPANT	\N	PRESENT	0
350077	339548	08051V	PARTICIPANT	\N	PRESENT	0
350078	339548	14235Q	PARTICIPANT	\N	PRESENT	0
350079	339548	08038Y	PARTICIPANT	\N	PRESENT	0
350080	348034	19447X	PARTICIPANT	\N	PRESENT	0
350081	348034	19553Y	PARTICIPANT	\N	PRESENT	0
350082	348034	19621T	PARTICIPANT	\N	PRESENT	0
350083	339548	14051J	PARTICIPANT	\N	PRESENT	0
350085	339548	14157T	PARTICIPANT	\N	PRESENT	0
350086	339548	01028R	PARTICIPANT	\N	PRESENT	0
350087	339548	14065Q	PARTICIPANT	\N	PRESENT	0
350088	339548	01057W	PARTICIPANT	\N	PRESENT	0
350207	350206	19681G	PARTICIPANT	\N	PRESENT	0
350216	350214	19681G	PARTICIPANT	\N	PRESENT	0
350353	350340	19681G	PARTICIPANT	\N	PRESENT	0
350507	350505	10015M	PARTICIPANT	\N	PRESENT	0
350598	345626	19415P	PARTICIPANT	\N	PRESENT	0
350599	345626	04047H	PARTICIPANT	\N	PRESENT	0
350600	345626	10006L	PARTICIPANT	\N	PRESENT	0
350601	345626	11067R	PARTICIPANT	\N	PRESENT	0
350667	348035	19621T	PARTICIPANT	\N	EXCUSE	0
350668	348035	19295A	PARTICIPANT	\N	EXCUSE	0
350669	348035	14147R	PARTICIPANT	\N	EXCUSE	0
350670	348035	19749K	PARTICIPANT	\N	EXCUSE	0
350738	350737	14065Q	PARTICIPANT	\N	PRESENT	0
350739	350737	96004D	PARTICIPANT	\N	PRESENT	0
350740	350737	14089Y	PARTICIPANT	\N	PRESENT	0
350741	350737	14357A	PARTICIPANT	\N	PRESENT	0
350742	350737	19553Y	PARTICIPANT	\N	PRESENT	0
350743	350737	19569H	PARTICIPANT	\N	PRESENT	0
350745	350737	14097Y	PARTICIPANT	\N	PRESENT	0
350746	350737	04061F	PARTICIPANT	\N	PRESENT	0
350747	350737	14073Q	PARTICIPANT	\N	PRESENT	0
350748	350737	11026G	PARTICIPANT	\N	PRESENT	0
350749	350737	14001X	PARTICIPANT	\N	PRESENT	0
350750	350737	19563B	PARTICIPANT	\N	PRESENT	0
350751	350737	19593H	PARTICIPANT	\N	PRESENT	0
350753	350737	14135M	PARTICIPANT	\N	PRESENT	0
350754	350737	14225N	PARTICIPANT	\N	PRESENT	0
350755	350737	98035U	PARTICIPANT	\N	PRESENT	0
350757	350737	04057K	PARTICIPANT	\N	EXCUSE	0
350758	350737	10015M	PARTICIPANT	\N	EXCUSE	0
350817	350686	19295A	PARTICIPANT	\N	EXCUSE	0
350818	349542	19295A	PARTICIPANT	\N	EXCUSE	0
350848	332565	19713W	PARTICIPANT	\N	EXCUSE	0
350893	350892	19723Y	PARTICIPANT	\N	PRESENT	0
350895	350894	19723Y	PARTICIPANT	\N	PRESENT	0
350896	350894	10006L	PARTICIPANT	\N	PRESENT	0
350899	350897	19723Y	PARTICIPANT	\N	PRESENT	0
350900	350897	10006L	PARTICIPANT	\N	PRESENT	0
350904	350902	11072N	PARTICIPANT	\N	PRESENT	0
350905	350902	14028W	PARTICIPANT	\N	PRESENT	0
350906	350902	14253S	PARTICIPANT	\N	PRESENT	0
350907	350902	19301E	PARTICIPANT	\N	PRESENT	0
350908	350902	14173T	PARTICIPANT	\N	PRESENT	0
350909	350902	10006L	PARTICIPANT	\N	PRESENT	0
350911	350902	11110B	PARTICIPANT	\N	PRESENT	0
350912	350901	14053L	PARTICIPANT	\N	PRESENT	0
350913	350901	14111D	PARTICIPANT	\N	PRESENT	0
350914	350901	07034Q	PARTICIPANT	\N	PRESENT	0
350915	350901	08045X	PARTICIPANT	\N	PRESENT	0
350916	350901	11026G	PARTICIPANT	\N	PRESENT	0
350917	350901	01024M	PARTICIPANT	\N	PRESENT	0
350918	350901	19585H	PARTICIPANT	\N	PRESENT	0
350919	350901	04047H	PARTICIPANT	\N	PRESENT	0
350920	350901	11033F	PARTICIPANT	\N	PRESENT	0
350921	350901	01028R	PARTICIPANT	\N	PRESENT	0
350922	350901	19447X	PARTICIPANT	\N	PRESENT	0
350923	350901	05008E	PRESIDENT	0	PRESENT	0
350924	350901	14041T	PARTICIPANT	\N	PRESENT	0
350925	350901	14147R	PARTICIPANT	\N	PRESENT	0
350926	350901	14179A	PARTICIPANT	\N	PRESENT	0
350927	350901	14151M	PARTICIPANT	\N	PRESENT	0
350928	350901	14069U	PARTICIPANT	\N	PRESENT	0
350929	350901	14215L	PARTICIPANT	\N	PRESENT	0
350930	350901	98035U	PARTICIPANT	\N	PRESENT	0
350931	350901	19729F	PARTICIPANT	\N	EXCUSE	0
350933	350902	14069U	PARTICIPANT	\N	PRESENT	0
350934	350902	14265W	PARTICIPANT	\N	PRESENT	0
350935	350902	14041T	PARTICIPANT	\N	PRESENT	0
350936	350902	19479G	PARTICIPANT	\N	PRESENT	0
350937	350902	14179A	PARTICIPANT	\N	PRESENT	0
350938	350902	01062T	PARTICIPANT	\N	PRESENT	0
350942	350902	19349W	PARTICIPANT	\N	PRESENT	0
350943	350902	11043H	PARTICIPANT	\N	PRESENT	0
350944	350902	14107H	PARTICIPANT	\N	PRESENT	0
350945	350902	19768N	PARTICIPANT	\N	PRESENT	0
350946	350902	14147R	PARTICIPANT	\N	PRESENT	0
350948	350902	08043V	PARTICIPANT	\N	PRESENT	0
350950	350902	14281W	PARTICIPANT	\N	PRESENT	0
350951	350902	19760E	PARTICIPANT	\N	PRESENT	0
350952	350902	14267Y	PARTICIPANT	\N	PRESENT	0
350953	350902	14105F	PARTICIPANT	\N	PRESENT	0
350954	350902	14038Y	PARTICIPANT	\N	PRESENT	0
350955	350902	14033T	PARTICIPANT	\N	PRESENT	0
350957	350902	14083S	PARTICIPANT	\N	PRESENT	0
350958	350956	14179A	PARTICIPANT	\N	PRESENT	0
350959	350956	14021P	PARTICIPANT	\N	PRESENT	0
350960	350902	14191V	PARTICIPANT	\N	PRESENT	0
350961	350902	14205J	PARTICIPANT	\N	PRESENT	0
350962	350902	18083K	PARTICIPANT	\N	PRESENT	0
350963	350902	14249W	PARTICIPANT	\N	PRESENT	0
350964	350902	14001X	PARTICIPANT	\N	PRESENT	0
350965	350902	19679N	PARTICIPANT	\N	PRESENT	0
350966	350902	14223L	PARTICIPANT	\N	PRESENT	0
350967	350902	96004D	PARTICIPANT	\N	PRESENT	0
350968	350902	11054L	PARTICIPANT	\N	PRESENT	0
350969	350902	14039A	PARTICIPANT	\N	PRESENT	0
350970	350902	19727D	PARTICIPANT	\N	PRESENT	0
350971	350902	19553Y	PARTICIPANT	\N	PRESENT	0
350980	350902	97011G	PARTICIPANT	\N	PRESENT	0
350981	350902	14053L	PARTICIPANT	\N	PRESENT	0
350982	350902	14031R	PARTICIPANT	\N	PRESENT	0
350983	350902	19347U	PARTICIPANT	\N	PRESENT	0
350984	350902	19329S	PARTICIPANT	\N	PRESENT	0
350996	350902	19581D	PARTICIPANT	\N	PRESENT	0
351003	350790	11048N	PARTICIPANT	\N	PRESENT	0
351004	350790	19515S	PARTICIPANT	\N	PRESENT	0
351005	350790	04071H	PARTICIPANT	\N	PRESENT	0
351006	350790	04034C	PARTICIPANT	\N	PRESENT	0
351007	350790	14187A	PARTICIPANT	\N	PRESENT	0
351008	350790	19695N	PARTICIPANT	\N	PRESENT	0
351009	350790	11090Q	PARTICIPANT	\N	PRESENT	0
351010	350790	14083S	PARTICIPANT	\N	PRESENT	0
351011	350790	08068F	PARTICIPANT	\N	PRESENT	0
351012	350790	19760E	PARTICIPANT	\N	PRESENT	0
351013	350790	19521Q	PRESIDENT	0	PRESENT	0
351014	350790	14329V	PARTICIPANT	\N	PRESENT	0
351015	350790	19762G	PARTICIPANT	\N	PRESENT	0
351016	350790	19631V	PARTICIPANT	\N	EXCUSE	0
351032	350910	11056N	PARTICIPANT	\N	PRESENT	0
351033	350910	19760E	PARTICIPANT	\N	PRESENT	0
351034	350910	04085P	PARTICIPANT	\N	PRESENT	0
351035	350910	11040E	PARTICIPANT	\N	PRESENT	0
351036	350910	19695N	PARTICIPANT	\N	PRESENT	0
351037	350910	19593H	PARTICIPANT	\N	PRESENT	0
351038	350910	19758L	PARTICIPANT	\N	PRESENT	0
351039	350910	17637T	PARTICIPANT	\N	PRESENT	0
351040	350910	19711U	PARTICIPANT	\N	PRESENT	0
351030	350910	86034E	PARTICIPANT	\N	PRESENT	0
351031	350910	12041X	PARTICIPANT	\N	PRESENT	0
351041	350910	11101A	PARTICIPANT	\N	PRESENT	0
351042	350910	04035D	PARTICIPANT	\N	PRESENT	0
351043	350910	14211G	PARTICIPANT	\N	PRESENT	0
351044	350910	01058X	PARTICIPANT	\N	PRESENT	0
351045	350910	99004R	PARTICIPANT	\N	PRESENT	0
351046	350910	95030B	PARTICIPANT	\N	PRESENT	0
351047	350910	04047H	PARTICIPANT	\N	PRESENT	0
351048	350910	14026U	PARTICIPANT	\N	PRESENT	0
351049	350910	04086Q	PARTICIPANT	\N	PRESENT	0
351050	350910	04044E	PARTICIPANT	\N	PRESENT	0
351051	350910	95062K	PARTICIPANT	\N	PRESENT	0
351052	350910	15447F	PARTICIPANT	\N	PRESENT	0
351053	350910	14169X	PARTICIPANT	\N	PRESENT	0
351054	350910	19643A	PARTICIPANT	\N	PRESENT	0
351055	350910	10015M	PARTICIPANT	\N	PRESENT	0
333386	331590	14039A	PARTICIPANT	\N	PRESENT	0
333387	332759	01048V	PARTICIPANT	\N	PRESENT	0
333388	332759	19545Y	PARTICIPANT	\N	PRESENT	0
333389	332759	19531S	PARTICIPANT	\N	PRESENT	0
333390	332759	19741B	PARTICIPANT	\N	PRESENT	0
333391	331590	19643A	PARTICIPANT	\N	PRESENT	0
333392	331590	14073Q	PARTICIPANT	\N	PRESENT	0
333393	331592	04044E	PARTICIPANT	\N	PRESENT	0
333394	331592	14275Y	PARTICIPANT	\N	PRESENT	0
333395	331592	14259Y	PARTICIPANT	\N	PRESENT	0
333396	331592	19649G	PARTICIPANT	\N	PRESENT	0
333397	331592	01024M	PARTICIPANT	\N	PRESENT	0
333398	331592	11049P	PARTICIPANT	\N	PRESENT	0
333399	331592	19762G	PARTICIPANT	\N	PRESENT	0
333400	332759	95041E	PARTICIPANT	\N	PRESENT	0
333401	332759	19479G	PARTICIPANT	\N	PRESENT	0
333402	332759	14083S	PARTICIPANT	\N	PRESENT	0
333403	332759	08069G	PARTICIPANT	\N	PRESENT	0
333405	333404	19768N	PARTICIPANT	\N	PRESENT	0
333406	333404	19782L	PARTICIPANT	\N	PRESENT	0
333407	333404	19565D	PARTICIPANT	\N	PRESENT	0
333408	333404	19441R	PARTICIPANT	\N	PRESENT	0
333409	333404	80013X	PARTICIPANT	\N	PRESENT	0
333410	333404	19631V	PARTICIPANT	\N	PRESENT	0
333411	333404	08015R	PARTICIPANT	\N	PRESENT	0
333412	333404	19369B	PARTICIPANT	\N	PRESENT	0
333413	333404	19511N	PARTICIPANT	\N	PRESENT	0
333414	333404	08028W	PARTICIPANT	\N	PRESENT	0
333415	333404	19563B	PARTICIPANT	\N	PRESENT	0
333416	333404	14265W	PARTICIPANT	\N	PRESENT	0
333417	333404	19467C	PARTICIPANT	\N	PRESENT	0
333418	333404	14187A	PARTICIPANT	\N	PRESENT	0
333419	333404	08038Y	PARTICIPANT	\N	PRESENT	0
333420	333404	19695N	PARTICIPANT	\N	PRESENT	0
333421	333404	14033T	PARTICIPANT	\N	PRESENT	0
333422	333404	11090Q	PRESIDENT	0	PRESENT	0
333423	333404	04088S	PARTICIPANT	\N	PRESENT	0
333424	333404	11101A	PARTICIPANT	\N	PRESENT	0
333425	333404	19507S	PARTICIPANT	\N	PRESENT	0
333426	333404	19747H	PARTICIPANT	\N	PRESENT	0
333427	333404	14207L	PARTICIPANT	\N	PRESENT	0
333428	333404	19619A	PARTICIPANT	\N	PRESENT	0
333429	333404	14257W	PARTICIPANT	\N	PRESENT	0
333441	331590	19693L	PARTICIPANT	\N	PRESENT	0
333431	333404	11081P	PARTICIPANT	\N	EXCUSE	0
333432	332759	04061F	PARTICIPANT	\N	PRESENT	0
333433	332759	08011M	PARTICIPANT	\N	EXCUSE	0
333434	332759	19689Q	PARTICIPANT	\N	PRESENT	0
333435	332759	11053K	PARTICIPANT	\N	PRESENT	0
333436	331590	14097Y	PARTICIPANT	\N	PRESENT	0
333437	333404	08068F	PARTICIPANT	\N	EXCUSE	0
333438	333404	08021P	PARTICIPANT	\N	EXCUSE	0
333439	331590	11027H	PARTICIPANT	\N	PRESENT	0
333440	331590	08012N	PARTICIPANT	\N	PRESENT	0
333442	331590	14109K	PARTICIPANT	\N	PRESENT	0
333443	332759	19647E	PARTICIPANT	\N	PRESENT	0
333444	332759	08010L	PARTICIPANT	\N	PRESENT	0
333445	332759	11110B	PARTICIPANT	\N	PRESENT	0
333446	331590	11043H	PARTICIPANT	\N	PRESENT	0
333447	331590	14249W	PARTICIPANT	\N	PRESENT	0
333465	331592	14089Y	PARTICIPANT	\N	PRESENT	0
333466	331592	08044W	PARTICIPANT	\N	PRESENT	0
333467	321368	14085U	PARTICIPANT	\N	PRESENT	0
333468	321368	01028R	PARTICIPANT	\N	PRESENT	0
333519	321368	19729F	PARTICIPANT	\N	PRESENT	0
333520	321368	19768N	PARTICIPANT	\N	PRESENT	0
333521	321368	19762G	PARTICIPANT	\N	PRESENT	0
333522	321368	14265W	PARTICIPANT	\N	PRESENT	0
333523	321368	14111D	PARTICIPANT	\N	PRESENT	0
333524	321368	08028W	PARTICIPANT	\N	PRESENT	0
333525	321368	11074Q	PARTICIPANT	\N	PRESENT	0
333526	321368	14159V	PARTICIPANT	\N	PRESENT	0
333527	321368	19543W	PARTICIPANT	\N	PRESENT	0
333528	321368	19651A	PARTICIPANT	\N	PRESENT	0
333529	321368	14151M	PARTICIPANT	\N	PRESENT	0
333530	321368	19629C	PARTICIPANT	\N	PRESENT	0
333531	321368	17583W	PARTICIPANT	\N	PRESENT	0
333532	321368	19335Q	PARTICIPANT	\N	PRESENT	0
333533	321368	19413M	PARTICIPANT	\N	PRESENT	0
333534	321368	14207L	PARTICIPANT	\N	PRESENT	0
333535	321368	19581D	PARTICIPANT	\N	PRESENT	0
333536	321368	19383Y	PARTICIPANT	\N	PRESENT	0
333537	321368	14053L	PARTICIPANT	\N	PRESENT	0
333538	321368	14038Y	PARTICIPANT	\N	PRESENT	0
333539	321368	14029X	PARTICIPANT	\N	PRESENT	0
334095	331305	08060W	PARTICIPANT	\N	PRESENT	0
334096	331305	08009T	PRESIDENT	0	PRESENT	0
334097	331305	17583W	PARTICIPANT	\N	EXCUSE	0
334098	331305	19701S	PARTICIPANT	\N	EXCUSE	0
334099	331305	96004D	PARTICIPANT	\N	EXCUSE	0
334100	331305	19685L	PARTICIPANT	\N	EXCUSE	0
334101	331305	02002K	PARTICIPANT	\N	EXCUSE	0
334102	331305	08055A	PARTICIPANT	\N	PRESENT	0
334103	321369	19369B	PARTICIPANT	\N	PRESENT	0
334104	331305	18083K	PARTICIPANT	\N	PRESENT	0
334105	331305	14038Y	PARTICIPANT	\N	PRESENT	0
334106	331305	19387D	PARTICIPANT	\N	PRESENT	0
334107	321369	11012A	PARTICIPANT	\N	PRESENT	0
334108	321369	14119M	PARTICIPANT	\N	PRESENT	0
334109	321369	19715Y	PARTICIPANT	\N	PRESENT	0
334110	321369	11053K	PARTICIPANT	\N	PRESENT	0
334115	321369	14065Q	PARTICIPANT	\N	PRESENT	0
334116	321369	08012N	PARTICIPANT	\N	PRESENT	0
334117	331305	19333N	PARTICIPANT	\N	PRESENT	0
334118	331305	19383Y	PARTICIPANT	\N	PRESENT	0
334119	331305	14103D	PARTICIPANT	\N	PRESENT	0
334120	331305	19713W	PARTICIPANT	\N	PRESENT	0
334121	331305	14031R	PARTICIPANT	\N	PRESENT	0
334122	331305	14219Q	PARTICIPANT	\N	PRESENT	0
334123	331305	19637C	PARTICIPANT	\N	PRESENT	0
334124	331305	14169X	PARTICIPANT	\N	PRESENT	0
334125	331305	15447F	PARTICIPANT	\N	PRESENT	0
334126	331305	05012A	PARTICIPANT	\N	PRESENT	0
334127	331305	19733B	PARTICIPANT	\N	PRESENT	0
334128	331305	19503N	PARTICIPANT	\N	PRESENT	0
334129	331305	19739H	PARTICIPANT	\N	PRESENT	0
334130	331305	11065P	PARTICIPANT	\N	PRESENT	0
334131	331305	17637T	PARTICIPANT	\N	PRESENT	0
334148	321369	14030Q	PARTICIPANT	\N	PRESENT	0
334149	321369	01048V	PARTICIPANT	\N	PRESENT	0
334150	321369	19553Y	PARTICIPANT	\N	PRESENT	0
334151	321369	19515S	PARTICIPANT	\N	PRESENT	0
334153	321369	11097X	PARTICIPANT	\N	PRESENT	0
334155	331305	19681G	PARTICIPANT	\N	PRESENT	0
334156	321369	04044E	PARTICIPANT	\N	PRESENT	0
334157	321369	04070G	PARTICIPANT	\N	PRESENT	0
334158	321369	19295A	PARTICIPANT	\N	PRESENT	0
334159	321369	14083S	PARTICIPANT	\N	PRESENT	0
334160	321369	19441R	PARTICIPANT	\N	PRESENT	0
334161	321369	14031R	PARTICIPANT	\N	PRESENT	0
334162	321369	19563B	PARTICIPANT	\N	PRESENT	0
334163	321369	04049K	PARTICIPANT	\N	PRESENT	0
334180	321369	08009T	PARTICIPANT	\N	PRESENT	0
334181	321369	19629C	PARTICIPANT	\N	PRESENT	0
334182	321369	11109J	PARTICIPANT	\N	PRESENT	0
334183	321369	14357A	PARTICIPANT	\N	PRESENT	0
334269	321370	14034U	PARTICIPANT	\N	PRESENT	0
334270	321370	19593H	PARTICIPANT	\N	PRESENT	0
334271	321370	01048V	PARTICIPANT	\N	PRESENT	0
334272	321370	14123H	PARTICIPANT	\N	PRESENT	0
334273	321370	19515S	PARTICIPANT	\N	PRESENT	0
334274	321370	19415P	PARTICIPANT	\N	PRESENT	0
334275	321370	11056N	PARTICIPANT	\N	PRESENT	0
334276	321370	19467C	PARTICIPANT	\N	PRESENT	0
334277	321370	11109J	PARTICIPANT	\N	PRESENT	0
334278	321370	11043H	PARTICIPANT	\N	PRESENT	0
334279	321370	19413M	PARTICIPANT	\N	PRESENT	0
334280	321370	19533U	PARTICIPANT	\N	PRESENT	0
334281	321370	14207L	PARTICIPANT	\N	PRESENT	0
334282	321370	19621T	PARTICIPANT	\N	PRESENT	0
334283	321370	19631V	PARTICIPANT	\N	PRESENT	0
334284	321370	11104D	PARTICIPANT	\N	PRESENT	0
334285	321370	14053L	PARTICIPANT	\N	PRESENT	0
334286	321370	19715Y	PARTICIPANT	\N	PRESENT	0
334287	321370	08043V	PARTICIPANT	\N	PRESENT	0
334288	321370	19531S	PARTICIPANT	\N	PRESENT	0
334289	321370	19782L	PARTICIPANT	\N	PRESENT	0
334290	321370	04057K	PARTICIPANT	\N	PRESENT	0
334291	321370	19749K	PARTICIPANT	\N	PRESENT	0
334292	321370	14241N	PARTICIPANT	\N	PRESENT	0
334293	321370	19329S	PARTICIPANT	\N	PRESENT	0
334294	321370	14030Q	PARTICIPANT	\N	PRESENT	0
334295	321370	14179A	PARTICIPANT	\N	PRESENT	0
334296	321370	14039A	PARTICIPANT	\N	PRESENT	0
334297	321370	19735D	PARTICIPANT	\N	PRESENT	0
334298	321370	04070G	PARTICIPANT	\N	PRESENT	0
334299	321370	19758L	PARTICIPANT	\N	PRESENT	0
334300	321370	19347U	PARTICIPANT	\N	PRESENT	0
334835	334834	08053X	PARTICIPANT	\N	PRESENT	0
346052	345105	08062Y	PARTICIPANT	\N	PRESENT	0
346053	345105	14033T	PARTICIPANT	\N	PRESENT	0
346054	345105	11090Q	PRESIDENT	0	PRESENT	0
346055	345105	01025N	PARTICIPANT	\N	PRESENT	0
346385	339513	19441R	PARTICIPANT	\N	PRESENT	0
346057	345105	14205J	PARTICIPANT	\N	PRESENT	0
346058	345105	04088S	PARTICIPANT	\N	PRESENT	0
346059	345105	04089T	PARTICIPANT	\N	PRESENT	0
346060	345105	14115H	PARTICIPANT	\N	PRESENT	0
346061	345105	11101A	PARTICIPANT	\N	PRESENT	0
346062	345105	19747H	PARTICIPANT	\N	PRESENT	0
346063	345105	14207L	PARTICIPANT	\N	PRESENT	0
346064	345105	14257W	PARTICIPANT	\N	PRESENT	0
346065	345105	08038Y	PARTICIPANT	\N	PRESENT	0
346117	345251	19383Y	PARTICIPANT	\N	PRESENT	0
346118	345251	17583W	PARTICIPANT	\N	PRESENT	0
346119	345251	95062K	PARTICIPANT	\N	PRESENT	0
346120	345251	19549D	PARTICIPANT	\N	PRESENT	0
346121	345251	19387D	PARTICIPANT	\N	PRESENT	0
346122	345251	14219Q	PARTICIPANT	\N	PRESENT	0
346123	345251	14221J	PARTICIPANT	\N	PRESENT	0
346124	345251	19599P	PARTICIPANT	\N	PRESENT	0
346125	345251	19637C	PARTICIPANT	\N	PRESENT	0
346126	345251	02002K	PARTICIPANT	\N	PRESENT	0
346127	345251	14237S	PARTICIPANT	\N	PRESENT	0
346128	345251	18083K	PARTICIPANT	\N	PRESENT	0
346129	345251	80027E	PARTICIPANT	\N	PRESENT	0
346130	345251	05012A	PARTICIPANT	\N	PRESENT	0
346131	345251	14051J	PARTICIPANT	\N	PRESENT	0
346132	345251	08060W	PARTICIPANT	\N	PRESENT	0
346133	345251	19503N	PARTICIPANT	\N	PRESENT	0
346134	345251	19347U	PARTICIPANT	\N	PRESENT	0
346135	345251	14157T	PARTICIPANT	\N	PRESENT	0
346136	345251	19681G	PARTICIPANT	\N	PRESENT	0
346137	345251	08024S	PARTICIPANT	\N	PRESENT	0
346138	345251	19525U	PARTICIPANT	\N	PRESENT	0
346139	345251	14038Y	PARTICIPANT	\N	PRESENT	0
346140	345251	14031R	PARTICIPANT	\N	PRESENT	0
346141	345251	19713W	PARTICIPANT	\N	PRESENT	0
346142	345251	08055A	PARTICIPANT	\N	PRESENT	0
346143	345251	19269X	PARTICIPANT	\N	PRESENT	0
346144	345251	14169X	PARTICIPANT	\N	PRESENT	0
346145	345251	15447F	PARTICIPANT	\N	PRESENT	0
346146	345251	14029X	PARTICIPANT	\N	PRESENT	0
346147	345251	19733B	PARTICIPANT	\N	PRESENT	0
346148	345251	08009T	PRESIDENT	0	PRESENT	0
346149	345251	04097T	PARTICIPANT	\N	PRESENT	0
346150	345251	19739H	PARTICIPANT	\N	PRESENT	0
346151	345251	19659J	PARTICIPANT	\N	PRESENT	0
346152	345251	19685L	PARTICIPANT	\N	EXCUSE	0
346153	345251	19745F	PARTICIPANT	\N	EXCUSE	0
346154	345251	19701S	PARTICIPANT	\N	PRESENT	0
346297	346252	04070G	PRESIDENT	0	PRESENT	0
346298	346252	19699S	PARTICIPANT	\N	PRESENT	0
346299	346252	19533U	PARTICIPANT	\N	PRESENT	0
346300	346252	14229S	PARTICIPANT	\N	PRESENT	0
346301	346252	14241N	PARTICIPANT	\N	PRESENT	0
346302	346252	19573D	PARTICIPANT	\N	PRESENT	0
346303	346252	08017T	PARTICIPANT	\N	PRESENT	0
346304	346252	92040Q	PARTICIPANT	\N	PRESENT	0
346305	346252	07033P	PARTICIPANT	\N	PRESENT	0
346306	346252	08012N	PARTICIPANT	\N	PRESENT	0
346307	346252	14249W	PARTICIPANT	\N	PRESENT	0
346308	346252	08039A	PARTICIPANT	\N	PRESENT	0
346309	346252	08031R	PARTICIPANT	\N	PRESENT	0
346310	346252	19593H	PARTICIPANT	\N	PRESENT	0
346311	346252	19643A	PARTICIPANT	\N	PRESENT	0
346312	346252	14059S	PARTICIPANT	\N	PRESENT	0
346313	346252	14061L	PARTICIPANT	\N	PRESENT	0
346314	346252	04057K	PARTICIPANT	\N	PRESENT	0
346315	346252	19693L	PARTICIPANT	\N	PRESENT	0
346316	346252	14030Q	PARTICIPANT	\N	PRESENT	0
346317	346252	19731Y	PARTICIPANT	\N	PRESENT	0
346318	346252	04059M	PARTICIPANT	\N	PRESENT	0
346319	346252	11109J	PARTICIPANT	\N	PRESENT	0
346320	346252	14063N	PARTICIPANT	\N	PRESENT	0
346321	346252	14109K	PARTICIPANT	\N	PRESENT	0
346322	346252	14123H	PARTICIPANT	\N	PRESENT	0
346323	346252	11104D	PARTICIPANT	\N	PRESENT	0
346324	346252	11043H	PARTICIPANT	\N	PRESENT	0
346325	346252	19749K	PARTICIPANT	\N	PRESENT	0
346326	346252	04018C	PARTICIPANT	\N	PRESENT	0
346327	346252	19621T	PARTICIPANT	\N	PRESENT	0
346328	346252	14073Q	PARTICIPANT	\N	EXCUSE	0
346329	346252	08020N	PARTICIPANT	\N	EXCUSE	0
346330	346252	08043V	PARTICIPANT	\N	EXCUSE	0
346334	346252	87003B	PARTICIPANT	\N	PRESENT	0
346335	346252	11083R	PARTICIPANT	\N	PRESENT	0
346336	339513	19683J	PARTICIPANT	\N	PRESENT	0
346337	339513	14227Q	PARTICIPANT	\N	PRESENT	0
346338	339513	14159V	PARTICIPANT	\N	PRESENT	0
346339	339513	14231L	PARTICIPANT	\N	PRESENT	0
346340	339513	11103C	PARTICIPANT	\N	PRESENT	0
346341	339513	14219Q	PARTICIPANT	\N	PRESENT	0
346342	339513	14042U	PARTICIPANT	\N	PRESENT	0
346343	339513	19782L	PARTICIPANT	\N	PRESENT	0
346344	339513	19711U	PARTICIPANT	\N	PRESENT	0
346345	339513	19631V	PARTICIPANT	\N	PRESENT	0
346346	339513	19521Q	PARTICIPANT	\N	PRESENT	0
346347	339513	04049K	PARTICIPANT	\N	PRESENT	0
346348	339513	14051J	PARTICIPANT	\N	PRESENT	0
346349	339513	04034C	PARTICIPANT	\N	PRESENT	0
346350	339513	19637C	PARTICIPANT	\N	PRESENT	0
346351	339513	14207L	PARTICIPANT	\N	PRESENT	0
346352	339513	14001X	PARTICIPANT	\N	PRESENT	0
346353	339513	19715Y	PARTICIPANT	\N	PRESENT	0
346354	339513	19737F	PARTICIPANT	\N	PRESENT	0
346355	339513	14083S	PARTICIPANT	\N	PRESENT	0
346356	339513	08052W	PARTICIPANT	\N	PRESENT	0
346357	339513	19583F	PARTICIPANT	\N	PRESENT	0
346358	339513	11070L	PARTICIPANT	\N	PRESENT	0
346359	339513	19349W	PARTICIPANT	\N	PRESENT	0
346360	339513	19569H	PARTICIPANT	\N	PRESENT	0
346361	339513	14267Y	PARTICIPANT	\N	PRESENT	0
346362	339513	14327T	PARTICIPANT	\N	PRESENT	0
346363	339513	19599P	PARTICIPANT	\N	PRESENT	0
346364	339513	19695N	PARTICIPANT	\N	PRESENT	0
346365	339513	14235Q	PARTICIPANT	\N	PRESENT	0
346366	339513	19762G	PARTICIPANT	\N	PRESENT	0
346367	339513	14026U	PARTICIPANT	\N	PRESENT	0
346368	339513	19507S	PARTICIPANT	\N	PRESENT	0
346369	339513	08028W	PARTICIPANT	\N	PRESENT	0
346370	339513	18083K	PARTICIPANT	\N	PRESENT	0
346371	339513	19467C	PARTICIPANT	\N	PRESENT	0
346372	339513	14029X	PARTICIPANT	\N	PRESENT	0
346373	339513	14173T	PARTICIPANT	\N	PRESENT	0
346374	339513	19515S	PARTICIPANT	\N	PRESENT	0
346375	339513	19679N	PARTICIPANT	\N	PRESENT	0
346376	339513	19671E	PARTICIPANT	\N	PRESENT	0
346377	339513	19689Q	PARTICIPANT	\N	PRESENT	0
346378	339513	14119M	PARTICIPANT	\N	PRESENT	0
346379	339513	08019V	PARTICIPANT	\N	PRESENT	0
346380	339513	14034U	PARTICIPANT	\N	PRESENT	0
346381	339513	08049C	PARTICIPANT	\N	PRESENT	0
346382	339513	19387D	PARTICIPANT	\N	PRESENT	0
346383	339513	19553Y	PARTICIPANT	\N	PRESENT	0
346384	339513	19717B	PARTICIPANT	\N	PRESENT	0
346386	339513	11067R	PARTICIPANT	\N	PRESENT	0
338550	338217	19553Y	PARTICIPANT	\N	PRESENT	0
338551	338217	08017T	PARTICIPANT	\N	PRESENT	0
338552	338217	11049P	PARTICIPANT	\N	PRESENT	0
338553	338217	11054L	PARTICIPANT	\N	PRESENT	0
338554	338217	19739H	PARTICIPANT	\N	PRESENT	0
338555	338217	14259Y	PARTICIPANT	\N	PRESENT	0
338556	338217	11103C	PARTICIPANT	\N	PRESENT	0
338557	338217	14081Q	PARTICIPANT	\N	PRESENT	0
338558	338217	19725B	PARTICIPANT	\N	PRESENT	0
338559	338217	14026U	PARTICIPANT	\N	PRESENT	0
338560	338217	11097X	PARTICIPANT	\N	PRESENT	0
338561	338217	11067R	PARTICIPANT	\N	PRESENT	0
338562	338217	14231L	PARTICIPANT	\N	PRESENT	0
338566	338217	17589D	PARTICIPANT	\N	PRESENT	0
338569	338217	19545Y	PARTICIPANT	\N	PRESENT	0
338570	338217	04086Q	PARTICIPANT	\N	PRESENT	0
338571	338217	19387D	PARTICIPANT	\N	PRESENT	0
338572	338217	19349W	PARTICIPANT	\N	PRESENT	0
338573	338217	19413M	PARTICIPANT	\N	PRESENT	0
338574	338217	19441R	PARTICIPANT	\N	PRESENT	0
338575	338217	14257W	PARTICIPANT	\N	PRESENT	0
338576	338217	11072N	PARTICIPANT	\N	PRESENT	0
338577	338217	14265W	PARTICIPANT	\N	PRESENT	0
338578	338217	19683J	PARTICIPANT	\N	PRESENT	0
338579	338217	08019V	PARTICIPANT	\N	PRESENT	0
338580	338217	01058X	PARTICIPANT	\N	PRESENT	0
338581	338217	14073Q	PARTICIPANT	\N	PRESENT	0
338582	338217	08028W	PARTICIPANT	\N	PRESENT	0
338583	338217	08038Y	PARTICIPANT	\N	PRESENT	0
338584	338217	11045K	PARTICIPANT	\N	PRESENT	0
338585	338217	95062K	PARTICIPANT	\N	PRESENT	0
338586	338217	19335Q	PARTICIPANT	\N	PRESENT	0
338587	338217	14217N	PARTICIPANT	\N	PRESENT	0
338588	338217	19717B	PARTICIPANT	\N	PRESENT	0
338589	338217	19681G	PARTICIPANT	\N	PRESENT	0
338590	338217	11056N	PARTICIPANT	\N	PRESENT	0
338591	338217	19369B	PARTICIPANT	\N	PRESENT	0
338593	338217	87003B	PARTICIPANT	\N	PRESENT	0
338594	338217	19723Y	PARTICIPANT	\N	PRESENT	0
338595	338217	11109J	PARTICIPANT	\N	PRESENT	0
338596	338217	14121F	PARTICIPANT	\N	PRESENT	0
338597	338217	08069G	PARTICIPANT	\N	PRESENT	0
338598	338217	19443T	PARTICIPANT	\N	PRESENT	0
338670	321422	11056N	PARTICIPANT	\N	PRESENT	0
338671	321422	08052W	PARTICIPANT	\N	PRESENT	0
338672	321422	08038Y	PARTICIPANT	\N	PRESENT	0
338673	321422	11066Q	PARTICIPANT	\N	PRESENT	0
338674	321422	14081Q	PARTICIPANT	\N	PRESENT	0
338675	321422	14257W	PARTICIPANT	\N	PRESENT	0
338676	321422	19413M	PARTICIPANT	\N	PRESENT	0
338677	321422	19683J	PARTICIPANT	\N	PRESENT	0
338678	321422	11045K	PARTICIPANT	\N	PRESENT	0
338679	321422	08017T	PARTICIPANT	\N	PRESENT	0
338680	321422	11067R	PARTICIPANT	\N	PRESENT	0
338681	321422	11109J	PARTICIPANT	\N	PRESENT	0
338682	321422	19295A	PARTICIPANT	\N	PRESENT	0
338683	321422	17779H	PARTICIPANT	\N	PRESENT	0
338684	321422	14121F	PARTICIPANT	\N	PRESENT	0
338685	321422	19758L	PARTICIPANT	\N	PRESENT	0
338686	321422	11072N	PARTICIPANT	\N	PRESENT	0
338687	321422	19349W	PARTICIPANT	\N	PRESENT	0
338688	321422	19387D	PARTICIPANT	\N	PRESENT	0
338689	321422	19717B	PARTICIPANT	\N	PRESENT	0
338690	321422	14111D	PARTICIPANT	\N	PRESENT	0
338691	321422	17589D	PARTICIPANT	\N	PRESENT	0
338692	321422	19629C	PARTICIPANT	\N	PRESENT	0
338693	321422	14219Q	PARTICIPANT	\N	PRESENT	0
338694	321422	19441R	PARTICIPANT	\N	PRESENT	0
338695	321422	19691J	PARTICIPANT	\N	PRESENT	0
338696	321422	19671E	PARTICIPANT	\N	PRESENT	0
338697	321422	17583W	PARTICIPANT	\N	PRESENT	0
338698	321422	19731Y	PARTICIPANT	\N	PRESENT	0
338699	321422	97011G	PARTICIPANT	\N	PRESENT	0
338700	321422	14217N	PARTICIPANT	\N	PRESENT	0
338701	321422	08015R	PARTICIPANT	\N	PRESENT	0
338702	321422	14265W	PARTICIPANT	\N	PRESENT	0
338703	321422	14213J	PARTICIPANT	\N	PRESENT	0
338704	321422	01058X	PARTICIPANT	\N	PRESENT	0
338705	321422	08069G	PARTICIPANT	\N	PRESENT	0
338706	321422	95062K	PARTICIPANT	\N	PRESENT	0
338707	321422	08019V	PARTICIPANT	\N	PRESENT	0
338708	321422	19399H	PARTICIPANT	\N	PRESENT	0
338709	321422	87003B	PARTICIPANT	\N	PRESENT	0
338710	321422	14259Y	PARTICIPANT	\N	PRESENT	0
338711	321422	11097X	PARTICIPANT	\N	PRESENT	0
338712	321422	04088S	PARTICIPANT	\N	PRESENT	0
338713	321422	19415P	PARTICIPANT	\N	PRESENT	0
338714	321422	14191V	PARTICIPANT	\N	PRESENT	0
338715	321422	19703U	PARTICIPANT	\N	PRESENT	0
338716	321422	14038Y	PARTICIPANT	\N	PRESENT	0
338717	321422	19723Y	PARTICIPANT	\N	PRESENT	0
338718	321422	19369B	PARTICIPANT	\N	PRESENT	0
338735	321422	04085P	PARTICIPANT	\N	PRESENT	0
338736	321422	05008E	PARTICIPANT	\N	PRESENT	0
338737	321422	19729F	PARTICIPANT	\N	PRESENT	0
338738	321422	01048V	PARTICIPANT	\N	PRESENT	0
338739	321422	19329S	PARTICIPANT	\N	PRESENT	0
338740	321422	14221J	PARTICIPANT	\N	PRESENT	0
338741	321422	19335Q	PARTICIPANT	\N	PRESENT	0
338742	321422	11049P	PARTICIPANT	\N	PRESENT	0
338743	321422	19447X	PARTICIPANT	\N	PRESENT	0
338744	321422	19575F	PARTICIPANT	\N	PRESENT	0
338745	321422	14147R	PARTICIPANT	\N	PRESENT	0
338746	321422	14215L	PARTICIPANT	\N	PRESENT	0
338747	321422	95030B	PARTICIPANT	\N	PRESENT	0
338748	321422	14033T	PARTICIPANT	\N	PRESENT	0
338749	321422	14157T	PARTICIPANT	\N	PRESENT	0
338750	321422	19727D	PARTICIPANT	\N	PRESENT	0
338751	321422	14223L	PARTICIPANT	\N	PRESENT	0
338752	321422	14267Y	PARTICIPANT	\N	PRESENT	0
338753	321422	14079W	PARTICIPANT	\N	PRESENT	0
338754	321422	14053L	PARTICIPANT	\N	PRESENT	0
338668	321422	04059M	PARTICIPANT	\N	PRESENT	0
338669	321422	11031D	PARTICIPANT	\N	PRESENT	0
338755	321422	80013X	PARTICIPANT	\N	PRESENT	0
338756	321422	19782L	PARTICIPANT	\N	PRESENT	0
338757	321422	14107H	PARTICIPANT	\N	PRESENT	0
338758	321422	14249W	PARTICIPANT	\N	PRESENT	0
338759	321422	19737F	PARTICIPANT	\N	PRESENT	0
338760	321422	14205J	PARTICIPANT	\N	PRESENT	0
338761	321422	08068F	PARTICIPANT	\N	PRESENT	0
338762	321422	19479G	PARTICIPANT	\N	PRESENT	0
338763	321422	08028W	PARTICIPANT	\N	PRESENT	0
338764	321422	14026U	PARTICIPANT	\N	PRESENT	0
338765	321422	98050T	PARTICIPANT	\N	PRESENT	0
338766	321422	14173T	PARTICIPANT	\N	PRESENT	0
338767	321422	14083S	PARTICIPANT	\N	PRESENT	0
338768	321422	19701S	PARTICIPANT	\N	PRESENT	0
338784	321422	19673G	PARTICIPANT	\N	PRESENT	0
338785	321422	19467C	PARTICIPANT	\N	PRESENT	0
338789	321422	04034C	PARTICIPANT	\N	PRESENT	0
338866	321424	19758L	PARTICIPANT	\N	PRESENT	0
338867	321424	80013X	PARTICIPANT	\N	PRESENT	0
338868	321424	19599P	PARTICIPANT	\N	PRESENT	0
338869	321424	11067R	PARTICIPANT	\N	PRESENT	0
338870	321424	19727D	PARTICIPANT	\N	PRESENT	0
338871	321424	14085U	PARTICIPANT	\N	PRESENT	0
338872	321424	11109J	PARTICIPANT	\N	PRESENT	0
338873	321424	19295A	PARTICIPANT	\N	PRESENT	0
338874	321424	19329S	PARTICIPANT	\N	PRESENT	0
338875	321424	19782L	PARTICIPANT	\N	PRESENT	0
338876	321424	95062K	PARTICIPANT	\N	PRESENT	0
338877	321424	19387D	PARTICIPANT	\N	PRESENT	0
338878	321424	15447F	PARTICIPANT	\N	PRESENT	0
338879	321424	17589D	PARTICIPANT	\N	PRESENT	0
338880	321424	19611R	PARTICIPANT	\N	PRESENT	0
338881	321424	14219Q	PARTICIPANT	\N	PRESENT	0
338882	321424	19479G	PARTICIPANT	\N	PRESENT	0
338883	321424	14191V	PARTICIPANT	\N	PRESENT	0
338884	321424	19737F	PARTICIPANT	\N	PRESENT	0
338885	321424	11101A	PARTICIPANT	\N	PRESENT	0
338886	321424	14205J	PARTICIPANT	\N	PRESENT	0
338887	321424	87003B	PARTICIPANT	\N	PRESENT	0
338888	321424	19691J	PARTICIPANT	\N	PRESENT	0
338889	321424	19575F	PARTICIPANT	\N	PRESENT	0
338890	321424	14038Y	PARTICIPANT	\N	PRESENT	0
338891	321424	19565D	PARTICIPANT	\N	PRESENT	0
338892	321424	14031R	PARTICIPANT	\N	PRESENT	0
338893	321424	19673G	PARTICIPANT	\N	PRESENT	0
338894	321424	19703U	PARTICIPANT	\N	PRESENT	0
338895	321424	08039A	PARTICIPANT	\N	PRESENT	0
338896	321424	19447X	PARTICIPANT	\N	PRESENT	0
338897	321424	14223L	PARTICIPANT	\N	PRESENT	0
338898	321424	11043H	PARTICIPANT	\N	PRESENT	0
338899	321424	92040Q	PARTICIPANT	\N	PRESENT	0
338900	321424	19507S	PARTICIPANT	\N	PRESENT	0
338901	321424	19467C	PARTICIPANT	\N	PRESENT	0
338902	321424	08034U	PARTICIPANT	\N	PRESENT	0
351056	350910	11043H	PARTICIPANT	\N	PRESENT	0
351057	350910	04033B	PARTICIPANT	\N	PRESENT	0
351058	350910	14187A	PARTICIPANT	\N	PRESENT	0
351059	350910	14079W	PARTICIPANT	\N	PRESENT	0
351061	350910	19515S	PARTICIPANT	\N	PRESENT	0
351062	350910	19565D	PARTICIPANT	\N	PRESENT	0
351063	350910	11077T	PARTICIPANT	\N	PRESENT	0
351064	350910	14191V	PARTICIPANT	\N	PRESENT	0
351065	350910	19766L	PARTICIPANT	\N	PRESENT	0
351066	350910	08061X	PARTICIPANT	\N	PRESENT	0
351067	350910	04045F	PARTICIPANT	\N	PRESENT	0
351068	350910	19679N	PARTICIPANT	\N	PRESENT	0
351069	350910	98029W	PARTICIPANT	\N	PRESENT	0
351070	350910	11080N	PARTICIPANT	\N	PRESENT	0
351071	350910	04034C	PARTICIPANT	\N	PRESENT	0
351072	350910	87003B	PARTICIPANT	\N	PRESENT	0
351073	350910	19651A	PARTICIPANT	\N	PRESENT	0
351074	350910	14239U	PARTICIPANT	\N	PRESENT	0
351075	350910	11090Q	PARTICIPANT	\N	PRESENT	0
351076	350910	04043D	PARTICIPANT	\N	PRESENT	0
351077	350910	11083R	PARTICIPANT	\N	PRESENT	0
351078	350910	14249W	PARTICIPANT	\N	PRESENT	0
351079	350910	14053L	PARTICIPANT	\N	PRESENT	0
351080	350910	19637C	PARTICIPANT	\N	PRESENT	0
351081	350910	19349W	PARTICIPANT	\N	PRESENT	0
351082	350910	14215L	PARTICIPANT	\N	PRESENT	0
351083	350910	19703U	PARTICIPANT	\N	PRESENT	0
351084	350910	19543W	PARTICIPANT	\N	PRESENT	0
351085	350910	08021P	PARTICIPANT	\N	PRESENT	0
351086	350910	19301E	PARTICIPANT	\N	PRESENT	0
351087	350910	08024S	PARTICIPANT	\N	PRESENT	0
351088	350910	14039A	PARTICIPANT	\N	PRESENT	0
351089	350910	14031R	PARTICIPANT	\N	PRESENT	0
351090	350910	19659J	PARTICIPANT	\N	PRESENT	0
351091	350910	19667J	PARTICIPANT	\N	PRESENT	0
351092	350910	19269X	PARTICIPANT	\N	PRESENT	0
351093	350910	14199E	PARTICIPANT	\N	PRESENT	0
351094	350910	19545Y	PARTICIPANT	\N	PRESENT	0
351095	350910	19575F	PARTICIPANT	\N	PRESENT	0
351096	350910	14253S	PARTICIPANT	\N	PRESENT	0
351097	350910	05012A	PARTICIPANT	\N	PRESENT	0
351098	350910	98005N	PARTICIPANT	\N	PRESENT	0
351099	350910	08034U	PARTICIPANT	\N	PRESENT	0
351100	350910	14261S	PARTICIPANT	\N	PRESENT	0
351101	350910	19629C	PARTICIPANT	\N	PRESENT	0
351102	350910	19533U	PARTICIPANT	\N	PRESENT	0
351103	350910	14241N	PARTICIPANT	\N	PRESENT	0
351104	350910	10006L	PARTICIPANT	\N	PRESENT	0
351105	350910	14201E	PARTICIPANT	\N	PRESENT	0
351106	350910	14107H	PARTICIPANT	\N	PRESENT	0
351107	350910	07034Q	PARTICIPANT	\N	PRESENT	0
351108	350910	19289C	PARTICIPANT	\N	PRESENT	0
351109	350910	11065P	PARTICIPANT	\N	PRESENT	0
351110	350910	14173T	PARTICIPANT	\N	PRESENT	0
351111	350910	19563B	PARTICIPANT	\N	PRESENT	0
351112	350910	19794Q	PARTICIPANT	\N	PRESENT	0
351113	350910	08051V	PARTICIPANT	\N	PRESENT	0
351114	350910	14133K	PARTICIPANT	\N	PRESENT	0
351115	350910	19719D	PARTICIPANT	\N	PRESENT	0
351116	350910	92040Q	PARTICIPANT	\N	PRESENT	0
351117	350910	19553Y	PARTICIPANT	\N	PRESENT	0
351118	350910	08049C	PARTICIPANT	\N	PRESENT	0
351119	350910	01057W	PARTICIPANT	\N	PRESENT	0
351120	350910	14119M	PARTICIPANT	\N	PRESENT	0
351121	350910	11049P	PARTICIPANT	\N	PRESENT	0
351122	350910	01060R	PARTICIPANT	\N	PRESENT	0
351123	350910	19731Y	PARTICIPANT	\N	PRESENT	0
351124	350910	08047A	PARTICIPANT	\N	PRESENT	0
351125	350910	89017R	PARTICIPANT	\N	PRESENT	0
351126	350910	14147R	PARTICIPANT	\N	PRESENT	0
351127	350910	97011G	PARTICIPANT	\N	PRESENT	0
351128	350910	98035U	PARTICIPANT	\N	PRESENT	0
351129	350910	11103C	PARTICIPANT	\N	PRESENT	0
351130	350910	14159V	PARTICIPANT	\N	PRESENT	0
351131	350910	08068F	PARTICIPANT	\N	PRESENT	0
351132	350910	07033P	PARTICIPANT	\N	PRESENT	0
351133	350910	11031D	PARTICIPANT	\N	PRESENT	0
351134	350910	14217N	PARTICIPANT	\N	PRESENT	0
351135	350910	14331P	PARTICIPANT	\N	PRESENT	0
351136	350910	14051J	PARTICIPANT	\N	PRESENT	0
351137	350910	19671E	PARTICIPANT	\N	PRESENT	0
351138	350910	08052W	PARTICIPANT	\N	PRESENT	0
351139	350910	19747H	PARTICIPANT	\N	PRESENT	0
351140	350910	14229S	PARTICIPANT	\N	PRESENT	0
351141	350910	08055A	PARTICIPANT	\N	PRESENT	0
351142	350910	19669L	PARTICIPANT	\N	PRESENT	0
351143	350910	08011M	PARTICIPANT	\N	PRESENT	0
351144	350910	14225N	PARTICIPANT	\N	PRESENT	0
351145	350910	08069G	PARTICIPANT	\N	PRESENT	0
351146	350910	14021P	PARTICIPANT	\N	PRESENT	0
351147	350910	14157T	PARTICIPANT	\N	PRESENT	0
351148	350910	19599P	PARTICIPANT	\N	PRESENT	0
351149	350910	19715Y	PARTICIPANT	\N	PRESENT	0
351150	350910	14223L	PARTICIPANT	\N	PRESENT	0
351151	350910	11010L	PARTICIPANT	\N	PRESENT	0
351152	350910	11045K	PARTICIPANT	\N	PRESENT	0
351153	350910	14028W	PARTICIPANT	\N	PRESENT	0
351154	350910	19649G	PARTICIPANT	\N	PRESENT	0
351155	350910	19647E	PARTICIPANT	\N	PRESENT	0
351156	350910	80013X	PARTICIPANT	\N	PRESENT	0
351157	350910	08053X	PARTICIPANT	\N	PRESENT	0
351158	350910	14105F	PARTICIPANT	\N	PRESENT	0
351159	350910	14281W	PARTICIPANT	\N	PRESENT	0
351160	350910	08038Y	PARTICIPANT	\N	PRESENT	0
351161	350910	08045X	PARTICIPANT	\N	PRESENT	0
351162	350910	96004D	PARTICIPANT	\N	PRESENT	0
351163	350910	14065Q	PARTICIPANT	\N	PRESENT	0
351164	350910	14151M	PARTICIPANT	\N	PRESENT	0
351165	350910	08043V	PARTICIPANT	\N	PRESENT	0
351166	350910	04092N	PARTICIPANT	\N	PRESENT	0
351167	350910	11104D	PARTICIPANT	\N	PRESENT	0
351168	350910	08012N	PARTICIPANT	\N	PRESENT	0
351169	350910	19727D	PARTICIPANT	\N	PRESENT	0
351170	350910	14121F	PARTICIPANT	\N	PRESENT	0
351171	350910	14038Y	PARTICIPANT	\N	PRESENT	0
351172	350910	80027E	PARTICIPANT	\N	PRESENT	0
351173	350910	19467C	PARTICIPANT	\N	PRESENT	0
351174	350910	19525U	PARTICIPANT	\N	PRESENT	0
351175	350910	18083K	PARTICIPANT	\N	PRESENT	0
351176	350910	19415P	PARTICIPANT	\N	PRESENT	0
351177	350910	14081Q	PARTICIPANT	\N	PRESENT	0
351178	350910	14257W	PARTICIPANT	\N	PRESENT	0
351179	350910	14033T	PARTICIPANT	\N	PRESENT	0
351180	350910	14135M	PARTICIPANT	\N	PRESENT	0
351181	350910	14207L	PARTICIPANT	\N	PRESENT	0
351182	350910	19549D	PARTICIPANT	\N	PRESENT	0
351183	350910	14259Y	PARTICIPANT	\N	PRESENT	0
351184	350910	19725B	PARTICIPANT	\N	PRESENT	0
351185	350910	08019V	PARTICIPANT	\N	PRESENT	0
351186	350910	19399H	PARTICIPANT	\N	PRESENT	0
351187	350910	11041F	PARTICIPANT	\N	PRESENT	0
351188	350910	14097Y	PARTICIPANT	\N	PRESENT	0
351189	350910	19693L	PARTICIPANT	\N	PRESENT	0
351190	350910	14109K	PARTICIPANT	\N	PRESENT	0
351191	350910	14265W	PARTICIPANT	\N	PRESENT	0
351192	350910	19527W	PARTICIPANT	\N	PRESENT	0
351193	350910	14063N	PARTICIPANT	\N	PRESENT	0
351194	350910	14329V	PARTICIPANT	\N	PRESENT	0
351195	350910	19631V	PARTICIPANT	\N	PRESENT	0
351196	350910	14357A	PARTICIPANT	\N	PRESENT	0
351197	350910	14227Q	PARTICIPANT	\N	PRESENT	0
351198	350910	19675J	PARTICIPANT	\N	PRESENT	0
351199	350910	11067R	PARTICIPANT	\N	PRESENT	0
351200	350910	19503N	PARTICIPANT	\N	PRESENT	0
351201	350910	17779H	PARTICIPANT	\N	PRESENT	0
351202	350910	19383Y	PARTICIPANT	\N	PRESENT	0
351203	350910	19413M	PARTICIPANT	\N	PRESENT	0
351204	350910	11054L	PARTICIPANT	\N	PRESENT	0
351205	350910	11109J	PARTICIPANT	\N	PRESENT	0
351206	350910	19762G	PARTICIPANT	\N	PRESENT	0
351207	350910	19683J	PARTICIPANT	\N	PRESENT	0
351208	350910	04018C	PARTICIPANT	\N	PRESENT	0
351209	350910	19551W	PARTICIPANT	\N	PRESENT	0
351210	350910	19621T	PARTICIPANT	\N	PRESENT	0
351211	350910	04059M	PARTICIPANT	\N	PRESENT	0
351212	350910	14213J	PARTICIPANT	\N	PRESENT	0
351213	350910	14093U	PARTICIPANT	\N	PRESENT	0
351214	350910	14111D	PARTICIPANT	\N	PRESENT	0
351215	350910	19723Y	PARTICIPANT	\N	PRESENT	0
351216	350910	19741B	PARTICIPANT	\N	PRESENT	0
351217	350910	17589D	PARTICIPANT	\N	PRESENT	0
351218	350910	08073C	PARTICIPANT	\N	PRESENT	0
351219	350910	19697Q	PARTICIPANT	\N	PRESENT	0
351220	350910	95063L	PARTICIPANT	\N	PRESENT	0
351221	350910	14231L	PARTICIPANT	\N	PRESENT	0
351222	350910	14029X	PARTICIPANT	\N	PRESENT	0
351223	350910	04089T	PARTICIPANT	\N	PRESENT	0
334840	322214	14299H	PARTICIPANT	\N	EXCUSE	0
336748	336478	19766L	PARTICIPANT	\N	PRESENT	0
336749	336478	04070G	PRESIDENT	0	PRESENT	0
336750	336478	19699S	PARTICIPANT	\N	PRESENT	0
336751	336478	19533U	PARTICIPANT	\N	PRESENT	0
336752	336478	14241N	PARTICIPANT	\N	PRESENT	0
336753	336478	19573D	PARTICIPANT	\N	PRESENT	0
336754	336478	14039A	PARTICIPANT	\N	PRESENT	0
336755	336478	14107H	PARTICIPANT	\N	PRESENT	0
336756	336478	08017T	PARTICIPANT	\N	PRESENT	0
336757	336478	19335Q	PARTICIPANT	\N	PRESENT	0
336758	336478	08039A	PARTICIPANT	\N	PRESENT	0
336759	336478	08031R	PARTICIPANT	\N	PRESENT	0
336760	336478	19593H	PARTICIPANT	\N	PRESENT	0
336761	336478	08035V	PARTICIPANT	\N	PRESENT	0
336762	336478	08043V	PARTICIPANT	\N	PRESENT	0
336763	336478	19693L	PARTICIPANT	\N	PRESENT	0
336764	336478	19399H	PARTICIPANT	\N	PRESENT	0
336765	336478	14201E	PARTICIPANT	\N	PRESENT	0
336766	336478	19731Y	PARTICIPANT	\N	PRESENT	0
336767	336478	19735D	PARTICIPANT	\N	PRESENT	0
336768	336478	11109J	PARTICIPANT	\N	PRESENT	0
336769	336478	14109K	PARTICIPANT	\N	PRESENT	0
336770	336478	14063N	PARTICIPANT	\N	PRESENT	0
336771	336478	11083R	PARTICIPANT	\N	PRESENT	0
336772	336478	14123H	PARTICIPANT	\N	PRESENT	0
336773	336478	11104D	PARTICIPANT	\N	PRESENT	0
336774	336478	11043H	PARTICIPANT	\N	PRESENT	0
336775	336478	19749K	PARTICIPANT	\N	PRESENT	0
336776	336478	04018C	PARTICIPANT	\N	PRESENT	0
336777	336478	19758L	PARTICIPANT	\N	PRESENT	0
336778	336478	19621T	PARTICIPANT	\N	PRESENT	0
336779	336478	19643A	PARTICIPANT	\N	EXCUSE	0
336780	335284	14042U	PARTICIPANT	\N	PRESENT	0
336781	335284	04045F	PARTICIPANT	\N	PRESENT	0
336782	336154	19768N	PARTICIPANT	\N	PRESENT	0
336783	336154	19515S	PARTICIPANT	\N	PRESENT	0
336784	336154	19782L	PARTICIPANT	\N	PRESENT	0
336785	336154	19565D	PARTICIPANT	\N	PRESENT	0
336786	336154	14357A	PARTICIPANT	\N	PRESENT	0
336787	336154	19413M	PARTICIPANT	\N	PRESENT	0
336788	336154	19631V	PARTICIPANT	\N	PRESENT	0
336789	336154	08068F	PARTICIPANT	\N	PRESENT	0
336790	336154	19705W	PARTICIPANT	\N	PRESENT	0
336791	336154	08015R	PARTICIPANT	\N	PRESENT	0
336792	336154	19369B	PARTICIPANT	\N	PRESENT	0
336793	336154	19511N	PARTICIPANT	\N	PRESENT	0
336794	336154	08028W	PARTICIPANT	\N	PRESENT	0
336795	336154	19563B	PARTICIPANT	\N	PRESENT	0
336796	336154	14265W	PARTICIPANT	\N	PRESENT	0
336797	336154	14329V	PARTICIPANT	\N	PRESENT	0
336798	336154	14135M	PARTICIPANT	\N	PRESENT	0
336799	336154	19467C	PARTICIPANT	\N	PRESENT	0
336800	336154	08038Y	PARTICIPANT	\N	PRESENT	0
336801	336154	11090Q	PRESIDENT	0	PRESENT	0
336802	336154	14205J	PARTICIPANT	\N	PRESENT	0
336803	336154	04088S	PARTICIPANT	\N	PRESENT	0
336804	336154	04089T	PARTICIPANT	\N	PRESENT	0
336805	336154	14115H	PARTICIPANT	\N	PRESENT	0
336806	336154	11101A	PARTICIPANT	\N	PRESENT	0
336807	336154	19507S	PARTICIPANT	\N	PRESENT	0
336808	336154	19747H	PARTICIPANT	\N	PRESENT	0
336809	336154	14207L	PARTICIPANT	\N	PRESENT	0
336810	336154	04043D	PARTICIPANT	\N	PRESENT	0
336811	336154	19619A	PARTICIPANT	\N	PRESENT	0
336812	336154	17589D	PARTICIPANT	\N	PRESENT	0
336813	336154	14257W	PARTICIPANT	\N	PRESENT	0
336814	336154	19695N	PARTICIPANT	\N	PRESENT	0
336815	336154	11056N	PARTICIPANT	\N	PRESENT	0
336816	336154	14197C	PARTICIPANT	\N	EXCUSE	0
336817	336154	08021P	PARTICIPANT	\N	EXCUSE	0
336818	336154	11081P	PARTICIPANT	\N	EXCUSE	0
336819	335284	19521Q	PARTICIPANT	\N	PRESENT	0
336827	335284	11031D	PARTICIPANT	\N	PRESENT	0
336839	334446	19443T	PARTICIPANT	\N	PRESENT	0
336840	334446	12041X	PARTICIPANT	\N	PRESENT	0
336841	334446	95030B	PARTICIPANT	\N	PRESENT	0
336842	334446	04034C	PARTICIPANT	\N	PRESENT	0
336843	334446	01058X	PARTICIPANT	\N	PRESENT	0
336844	334446	14079W	PARTICIPANT	\N	PRESENT	0
336845	334446	04040A	PARTICIPANT	\N	PRESENT	0
336846	334446	16685X	PARTICIPANT	\N	PRESENT	0
336847	334446	11027H	PARTICIPANT	\N	PRESENT	0
336848	334446	04042C	PRESIDENT	0	PRESENT	0
336849	334446	11066Q	PARTICIPANT	\N	PRESENT	0
336850	334446	19421M	PARTICIPANT	\N	PRESENT	0
336851	334446	19709B	PARTICIPANT	\N	PRESENT	0
336852	334446	14193X	PARTICIPANT	\N	PRESENT	0
336853	334446	97011G	PARTICIPANT	\N	PRESENT	0
336854	334446	08061X	PARTICIPANT	\N	PRESENT	0
336855	334446	08047A	PARTICIPANT	\N	PRESENT	0
336856	334446	14097Y	PARTICIPANT	\N	PRESENT	0
336857	334446	95067Q	PARTICIPANT	\N	PRESENT	0
336858	334446	14133K	PRESIDENT	1	PRESENT	0
336859	334446	11041F	PARTICIPANT	\N	PRESENT	0
336860	334446	14235Q	PARTICIPANT	\N	PRESENT	0
336861	334446	14028W	PARTICIPANT	\N	PRESENT	0
336862	334446	19251M	PARTICIPANT	\N	PRESENT	0
336863	334446	19319Q	PARTICIPANT	\N	PRESENT	0
336864	334446	14105F	PARTICIPANT	\N	PRESENT	0
336865	334446	98022P	PARTICIPANT	\N	PRESENT	0
336866	334446	11064N	PARTICIPANT	\N	PRESENT	0
336867	334446	14267Y	PARTICIPANT	\N	PRESENT	0
336868	334446	98050T	PARTICIPANT	\N	PRESENT	0
336869	334446	14211G	PARTICIPANT	\N	PRESENT	0
336870	334446	14255U	PARTICIPANT	\N	PRESENT	0
336871	334446	08009T	PARTICIPANT	\N	PRESENT	0
336872	334446	98018T	PARTICIPANT	\N	EXCUSE	0
336873	336478	14249W	PARTICIPANT	\N	PRESENT	0
336874	336478	14059S	PARTICIPANT	\N	PRESENT	0
336875	336478	14061L	PARTICIPANT	\N	PRESENT	0
336876	336478	04057K	PARTICIPANT	\N	PRESENT	0
336877	336478	14073Q	PARTICIPANT	\N	PRESENT	0
336878	336478	19611R	PARTICIPANT	\N	PRESENT	0
336879	336478	14030Q	PARTICIPANT	\N	PRESENT	0
336880	336478	08020N	PARTICIPANT	\N	EXCUSE	0
336881	336478	87003B	PARTICIPANT	\N	EXCUSE	0
336925	335290	04071H	PARTICIPANT	\N	PRESENT	0
336926	335290	19651A	PARTICIPANT	\N	PRESENT	0
336927	335290	04086Q	PARTICIPANT	\N	PRESENT	0
336929	336154	01043Q	PARTICIPANT	\N	PRESENT	0
336930	336154	19441R	PARTICIPANT	\N	PRESENT	0
336931	334152	19333N	PARTICIPANT	\N	PRESENT	0
336932	334152	17583W	PARTICIPANT	\N	PRESENT	0
336933	334152	19549D	PARTICIPANT	\N	PRESENT	0
336934	334152	95062K	PARTICIPANT	\N	PRESENT	0
336935	334152	19387D	PARTICIPANT	\N	PRESENT	0
336936	334152	14219Q	PARTICIPANT	\N	PRESENT	0
336937	334152	14221J	PARTICIPANT	\N	PRESENT	0
336938	334152	19599P	PARTICIPANT	\N	PRESENT	0
336939	334152	19637C	PARTICIPANT	\N	PRESENT	0
336940	334152	02002K	PARTICIPANT	\N	PRESENT	0
336941	334152	80027E	PARTICIPANT	\N	PRESENT	0
336942	334152	05012A	PARTICIPANT	\N	PRESENT	0
336943	334152	14051J	PARTICIPANT	\N	PRESENT	0
336944	334152	08060W	PARTICIPANT	\N	PRESENT	0
336945	334152	98023Q	PARTICIPANT	\N	PRESENT	0
336946	334152	14038Y	PARTICIPANT	\N	PRESENT	0
336947	334152	14103D	PARTICIPANT	\N	PRESENT	0
336948	334152	19713W	PARTICIPANT	\N	PRESENT	0
336949	334152	08055A	PARTICIPANT	\N	PRESENT	0
336950	334152	04085P	PARTICIPANT	\N	PRESENT	0
336951	334152	14029X	PARTICIPANT	\N	PRESENT	0
336952	334152	19737F	PARTICIPANT	\N	PRESENT	0
336953	334152	04097T	PARTICIPANT	\N	PRESENT	0
336954	334152	19739H	PARTICIPANT	\N	PRESENT	0
336955	334152	19745F	PARTICIPANT	\N	PRESENT	0
336956	334152	19701S	PARTICIPANT	\N	PRESENT	0
336957	334152	19551W	PARTICIPANT	\N	PRESENT	0
336958	334152	14169X	PARTICIPANT	\N	PRESENT	0
336959	334152	17637T	PARTICIPANT	\N	PRESENT	0
336960	334152	19733B	PARTICIPANT	\N	PRESENT	0
336966	334446	08058D	PARTICIPANT	\N	PRESENT	0
338141	321411	19701S	PARTICIPANT	\N	PRESENT	0
338142	321411	14249W	PARTICIPANT	\N	PRESENT	0
338143	321411	14087W	PARTICIPANT	\N	PRESENT	0
338144	321411	08058D	PARTICIPANT	\N	PRESENT	0
338145	321411	19531S	PARTICIPANT	\N	PRESENT	0
338149	321411	19319Q	PARTICIPANT	\N	PRESENT	0
338147	321411	04071H	PARTICIPANT	\N	PRESENT	0
338148	321411	19543W	PARTICIPANT	\N	PRESENT	0
346387	339513	14041T	PARTICIPANT	\N	PRESENT	0
346388	339513	19709B	PARTICIPANT	\N	PRESENT	0
346389	339513	11090Q	PARTICIPANT	\N	PRESENT	0
346390	339513	04089T	PARTICIPANT	\N	PRESENT	0
346391	339513	01025N	PARTICIPANT	\N	PRESENT	0
346392	339513	11097X	PARTICIPANT	\N	PRESENT	0
346393	339513	19251M	PARTICIPANT	\N	PRESENT	0
346394	339513	14031R	PARTICIPANT	\N	PRESENT	0
346395	339513	19479G	PARTICIPANT	\N	PRESENT	0
346396	339513	14195A	PARTICIPANT	\N	PRESENT	0
346397	339513	14038Y	PARTICIPANT	\N	PRESENT	0
346398	339513	01028R	PARTICIPANT	\N	PRESENT	0
346399	339513	14105F	PARTICIPANT	\N	PRESENT	0
346400	339513	11110B	PARTICIPANT	\N	PRESENT	0
346401	339513	11048N	PARTICIPANT	\N	PRESENT	0
346402	339513	14103D	PARTICIPANT	\N	PRESENT	0
346403	339513	07004J	PARTICIPANT	\N	PRESENT	0
346404	339513	14079W	PARTICIPANT	\N	PRESENT	0
346405	339513	14151M	PARTICIPANT	\N	PRESENT	0
346406	339513	08034U	PARTICIPANT	\N	PRESENT	0
346407	339513	08010L	PARTICIPANT	\N	PRESENT	0
346408	339513	14237S	PARTICIPANT	\N	PRESENT	0
346409	339513	89017R	PARTICIPANT	\N	PRESENT	0
346410	339513	11053K	PARTICIPANT	\N	PRESENT	0
346411	339513	04086Q	PARTICIPANT	\N	PRESENT	0
346412	339513	14223L	PARTICIPANT	\N	PRESENT	0
346416	339513	10006L	PARTICIPANT	\N	PRESENT	0
346427	339513	14257W	PARTICIPANT	\N	PRESENT	0
346428	339513	14187A	PARTICIPANT	\N	PRESENT	0
346429	339513	19503N	PARTICIPANT	\N	PRESENT	0
346430	339513	19413M	PARTICIPANT	\N	PRESENT	0
346431	339513	19543W	PARTICIPANT	\N	PRESENT	0
346432	339513	11099A	PARTICIPANT	\N	PRESENT	0
346433	339513	04045F	PARTICIPANT	\N	PRESENT	0
346434	339513	14028W	PARTICIPANT	\N	PRESENT	0
346435	339513	14255U	PARTICIPANT	\N	PRESENT	0
346436	339513	98050T	PARTICIPANT	\N	PRESENT	0
346437	339513	14071N	PARTICIPANT	\N	PRESENT	0
346438	339513	19629C	PARTICIPANT	\N	PRESENT	0
346439	339513	19347U	PARTICIPANT	\N	PRESENT	0
346440	339513	19768N	PARTICIPANT	\N	PRESENT	0
346442	339513	08056B	PARTICIPANT	\N	PRESENT	0
346443	339513	19747H	PARTICIPANT	\N	PRESENT	0
346444	339513	19739H	PARTICIPANT	\N	PRESENT	0
346445	339513	19713W	PARTICIPANT	\N	PRESENT	0
346446	339513	14107H	PARTICIPANT	\N	PRESENT	0
346447	339513	14111D	PARTICIPANT	\N	PRESENT	0
346448	339513	99004R	PARTICIPANT	\N	PRESENT	0
346449	339513	19399H	PARTICIPANT	\N	PRESENT	0
346450	339513	11043H	PARTICIPANT	\N	PRESENT	0
346452	339513	08060W	PARTICIPANT	\N	PRESENT	0
346453	339513	08055A	PARTICIPANT	\N	PRESENT	0
346454	339513	11109J	PARTICIPANT	\N	PRESENT	0
346455	339513	19319Q	PARTICIPANT	\N	PRESENT	0
346456	339513	14097Y	PARTICIPANT	\N	PRESENT	0
346457	339513	14157T	PARTICIPANT	\N	PRESENT	0
346458	339513	15447F	PARTICIPANT	\N	PRESENT	0
346459	339513	14221J	PARTICIPANT	\N	PRESENT	0
346460	339513	08062Y	PARTICIPANT	\N	PRESENT	0
346461	339513	19415P	PARTICIPANT	\N	PRESENT	0
346462	339513	19729F	PARTICIPANT	\N	PRESENT	0
346463	339513	19575F	PARTICIPANT	\N	PRESENT	0
346464	339513	80013X	PARTICIPANT	\N	PRESENT	0
346465	339513	01062T	PARTICIPANT	\N	PRESENT	0
346466	339513	19549D	PARTICIPANT	\N	PRESENT	0
346467	339513	14061L	PARTICIPANT	\N	PRESENT	0
346468	339513	16685X	PARTICIPANT	\N	PRESENT	0
346469	339513	14169X	PARTICIPANT	\N	PRESENT	0
346470	339513	19591F	PARTICIPANT	\N	PRESENT	0
346471	339513	97011G	PARTICIPANT	\N	PRESENT	0
346472	339513	19333N	PARTICIPANT	\N	PRESENT	0
346473	339513	19745F	PARTICIPANT	\N	PRESENT	0
346474	339513	19563B	PARTICIPANT	\N	PRESENT	0
346475	339513	11064N	PARTICIPANT	\N	PRESENT	0
346481	339513	19369B	PARTICIPANT	\N	PRESENT	0
346482	339513	19719D	PARTICIPANT	\N	PRESENT	0
346483	339513	19727D	PARTICIPANT	\N	PRESENT	0
346484	339513	19545Y	PARTICIPANT	\N	PRESENT	0
346485	339513	19533U	PARTICIPANT	\N	PRESENT	0
346486	339513	04071H	PARTICIPANT	\N	PRESENT	0
346487	339513	04088S	PARTICIPANT	\N	PRESENT	0
346488	339513	08031R	PARTICIPANT	\N	PRESENT	0
346489	339513	95037J	PARTICIPANT	\N	PRESENT	0
346490	339513	14249W	PARTICIPANT	\N	PRESENT	0
346491	339513	10015M	PARTICIPANT	\N	PRESENT	0
346492	339513	11066Q	PARTICIPANT	\N	PRESENT	0
346582	346441	14001X	PARTICIPANT	\N	PRESENT	0
346583	339513	14087W	PARTICIPANT	\N	PRESENT	0
346584	339513	19733B	PARTICIPANT	\N	PRESENT	0
346585	339513	19681G	PARTICIPANT	\N	PRESENT	0
346587	339513	19659J	PARTICIPANT	\N	PRESENT	0
346588	339513	14357A	PARTICIPANT	\N	PRESENT	0
346591	346586	14053L	PARTICIPANT	\N	PRESENT	0
346592	346586	14065Q	PARTICIPANT	\N	PRESENT	0
346593	346586	19649G	PARTICIPANT	\N	PRESENT	0
346594	346586	10015M	PARTICIPANT	\N	PRESENT	0
346595	346586	08045X	PARTICIPANT	\N	PRESENT	0
346596	346586	01024M	PARTICIPANT	\N	PRESENT	0
346597	346586	19543W	PARTICIPANT	\N	PRESENT	0
346598	346586	19581D	PARTICIPANT	\N	PRESENT	0
346599	346586	04047H	PARTICIPANT	\N	PRESENT	0
346600	346586	01028R	PARTICIPANT	\N	PRESENT	0
346601	346586	05008E	PRESIDENT	0	PRESENT	0
346602	346586	19447X	PARTICIPANT	\N	PRESENT	0
346603	346586	14231L	PARTICIPANT	\N	PRESENT	0
346604	346586	14089Y	PARTICIPANT	\N	PRESENT	0
346605	346586	95063L	PARTICIPANT	\N	PRESENT	0
346606	346586	08044W	PARTICIPANT	\N	PRESENT	0
346607	346586	14147R	PARTICIPANT	\N	PRESENT	0
346608	346586	14215L	PARTICIPANT	\N	PRESENT	0
346609	346586	19762G	PARTICIPANT	\N	PRESENT	0
346610	346586	14021P	PARTICIPANT	\N	PRESENT	0
346611	339513	14033T	PARTICIPANT	\N	PRESENT	0
346612	339513	14135M	PARTICIPANT	\N	PRESENT	0
346614	339513	14329V	PARTICIPANT	\N	PRESENT	0
346615	339513	14205J	PARTICIPANT	\N	PRESENT	0
346616	339513	04085P	PARTICIPANT	\N	PRESENT	0
346617	346586	04044E	PARTICIPANT	\N	EXCUSE	0
346618	339513	08073C	PARTICIPANT	\N	PRESENT	0
346619	339513	17779H	PARTICIPANT	\N	PRESENT	0
346620	339513	14089Y	PARTICIPANT	\N	PRESENT	0
346621	339513	01043Q	PARTICIPANT	\N	PRESENT	0
346622	339513	19701S	PARTICIPANT	\N	PRESENT	0
346623	339513	19657G	PARTICIPANT	\N	PRESENT	0
346730	339514	14034U	PARTICIPANT	\N	PRESENT	0
346731	339514	04049K	PARTICIPANT	\N	PRESENT	0
346762	339514	19679N	PARTICIPANT	\N	PRESENT	0
346733	339514	14227Q	PARTICIPANT	\N	PRESENT	0
346734	339514	14151M	PARTICIPANT	\N	PRESENT	0
346735	339514	14097Y	PARTICIPANT	\N	PRESENT	0
346736	339514	19333N	PARTICIPANT	\N	PRESENT	0
346737	339514	11056N	PARTICIPANT	\N	PRESENT	0
346738	339514	04045F	PARTICIPANT	\N	PRESENT	0
346739	339514	19782L	PARTICIPANT	\N	PRESENT	0
346740	339514	08073C	PARTICIPANT	\N	PRESENT	0
346741	339514	19695N	PARTICIPANT	\N	PRESENT	0
346742	339514	19347U	PARTICIPANT	\N	PRESENT	0
346743	339514	14235Q	PARTICIPANT	\N	PRESENT	0
346744	339514	19545Y	PARTICIPANT	\N	PRESENT	0
346745	339514	14107H	PARTICIPANT	\N	PRESENT	0
346746	339514	19387D	PARTICIPANT	\N	PRESENT	0
346747	339514	19629C	PARTICIPANT	\N	PRESENT	0
346748	339514	14241N	PARTICIPANT	\N	PRESENT	0
346749	339514	19563B	PARTICIPANT	\N	PRESENT	0
346750	339514	19719D	PARTICIPANT	\N	PRESENT	0
346751	339514	14051J	PARTICIPANT	\N	PRESENT	0
346752	339514	19747H	PARTICIPANT	\N	PRESENT	0
346753	339514	17779H	PARTICIPANT	\N	PRESENT	0
346754	339514	14195A	PARTICIPANT	\N	PRESENT	0
346755	339514	17637T	PARTICIPANT	\N	PRESENT	0
346756	339514	19441R	PARTICIPANT	\N	PRESENT	0
346757	339514	19711U	PARTICIPANT	\N	PRESENT	0
346758	339514	19681G	PARTICIPANT	\N	PRESENT	0
346759	339514	19515S	PARTICIPANT	\N	PRESENT	0
346760	339514	14029X	PARTICIPANT	\N	PRESENT	0
346761	339514	19521Q	PARTICIPANT	\N	PRESENT	0
346763	339514	14267Y	PARTICIPANT	\N	PRESENT	0
346764	339514	19369B	PARTICIPANT	\N	PRESENT	0
346765	339514	19737F	PARTICIPANT	\N	PRESENT	0
346766	339514	19575F	PARTICIPANT	\N	PRESENT	0
346767	339514	11012A	PARTICIPANT	\N	PRESENT	0
346768	339514	14105F	PARTICIPANT	\N	PRESENT	0
346769	339514	19533U	PARTICIPANT	\N	PRESENT	0
346770	339514	14061L	PARTICIPANT	\N	PRESENT	0
346771	339514	14357A	PARTICIPANT	\N	PRESENT	0
346772	339514	19727D	PARTICIPANT	\N	PRESENT	0
346773	339514	14147R	PARTICIPANT	\N	PRESENT	0
346774	339514	19503N	PARTICIPANT	\N	PRESENT	0
338905	321424	14211G	PARTICIPANT	\N	PRESENT	0
338906	321424	08028W	PARTICIPANT	\N	PRESENT	0
338907	321424	96004D	PARTICIPANT	\N	PRESENT	0
338908	321424	11103C	PARTICIPANT	\N	PRESENT	0
338909	321424	04035D	PARTICIPANT	\N	PRESENT	0
338910	321424	19383Y	PARTICIPANT	\N	PRESENT	0
338911	321424	14249W	PARTICIPANT	\N	PRESENT	0
338912	321424	19762G	PARTICIPANT	\N	PRESENT	0
338913	321424	14217N	PARTICIPANT	\N	PRESENT	0
338914	321424	14215L	PARTICIPANT	\N	PRESENT	0
338915	321424	19533U	PARTICIPANT	\N	PRESENT	0
338916	321424	19581D	PARTICIPANT	\N	PRESENT	0
338917	321424	11054L	PARTICIPANT	\N	PRESENT	0
338918	321424	14053L	PARTICIPANT	\N	PRESENT	0
338919	321424	08052W	PARTICIPANT	\N	PRESENT	0
338920	321424	11080N	PARTICIPANT	\N	PRESENT	0
338921	321424	14229S	PARTICIPANT	\N	PRESENT	0
338922	321424	08015R	PARTICIPANT	\N	PRESENT	0
338923	321424	98029W	PARTICIPANT	\N	PRESENT	0
338924	321424	14133K	PARTICIPANT	\N	PRESENT	0
338925	321424	01062T	PARTICIPANT	\N	PRESENT	0
338926	321424	19563B	PARTICIPANT	\N	PRESENT	0
338927	321424	14241N	PARTICIPANT	\N	PRESENT	0
338928	321424	14107H	PARTICIPANT	\N	PRESENT	0
338929	321424	04018C	PARTICIPANT	\N	PRESENT	0
338930	321424	14079W	PARTICIPANT	\N	PRESENT	0
338931	321424	04057K	PARTICIPANT	\N	PRESENT	0
338932	321424	19415P	PARTICIPANT	\N	PRESENT	0
338933	321424	19681G	PARTICIPANT	\N	PRESENT	0
338934	321424	14111D	PARTICIPANT	\N	PRESENT	0
338935	321424	19701S	PARTICIPANT	\N	PRESENT	0
338936	321424	01058X	PARTICIPANT	\N	PRESENT	0
338937	321424	14147R	PARTICIPANT	\N	PRESENT	0
338938	321424	14173T	PARTICIPANT	\N	PRESENT	0
338939	321424	07033P	PARTICIPANT	\N	PRESENT	0
338940	321424	05008E	PARTICIPANT	\N	PRESENT	0
338941	321424	14253S	PARTICIPANT	\N	PRESENT	0
338942	321424	19593H	PARTICIPANT	\N	PRESENT	0
338943	321424	17583W	PARTICIPANT	\N	PRESENT	0
338903	321424	14157T	PARTICIPANT	\N	PRESENT	0
338904	321424	14026U	PARTICIPANT	\N	PRESENT	0
338944	321424	12041X	PARTICIPANT	\N	PRESENT	0
338945	321424	19347U	PARTICIPANT	\N	PRESENT	0
338946	321424	19503N	PARTICIPANT	\N	PRESENT	0
338947	321424	14199E	PARTICIPANT	\N	PRESENT	0
338948	321424	04097T	PARTICIPANT	\N	PRESENT	0
338949	321424	14329V	PARTICIPANT	\N	PRESENT	0
338950	321424	14357A	PARTICIPANT	\N	PRESENT	0
338951	321424	11048N	PARTICIPANT	\N	PRESENT	0
338952	321424	98024R	PARTICIPANT	\N	PRESENT	0
338953	321424	95030B	PARTICIPANT	\N	PRESENT	0
338954	321424	04008A	PARTICIPANT	\N	PRESENT	0
338955	321424	11097X	PARTICIPANT	\N	PRESENT	0
338956	321424	08047A	PARTICIPANT	\N	PRESENT	0
338957	321424	08011M	PARTICIPANT	\N	PRESENT	0
338958	321424	01048V	PARTICIPANT	\N	PRESENT	0
338959	321424	19399H	PARTICIPANT	\N	PRESENT	0
338960	321424	19679N	PARTICIPANT	\N	PRESENT	0
338961	321424	04049K	PARTICIPANT	\N	PRESENT	0
338962	321424	18083K	PARTICIPANT	\N	PRESENT	0
338963	321424	86034E	PARTICIPANT	\N	PRESENT	0
338964	321424	99004R	PARTICIPANT	\N	PRESENT	0
338965	321424	14259Y	PARTICIPANT	\N	PRESENT	0
338966	321424	07029T	PARTICIPANT	\N	PRESENT	0
338967	321424	14265W	PARTICIPANT	\N	PRESENT	0
338968	321424	97011G	PARTICIPANT	\N	PRESENT	0
338969	321424	19741B	PARTICIPANT	\N	PRESENT	0
338970	321424	14135M	PARTICIPANT	\N	PRESENT	0
338971	321424	19515S	PARTICIPANT	\N	PRESENT	0
338972	321424	19693L	PARTICIPANT	\N	PRESENT	0
338973	321424	08069G	PARTICIPANT	\N	PRESENT	0
338974	321424	14187A	PARTICIPANT	\N	PRESENT	0
338975	321424	08019V	PARTICIPANT	\N	PRESENT	0
338976	321424	08010L	PARTICIPANT	\N	PRESENT	0
338977	321424	04086Q	PARTICIPANT	\N	PRESENT	0
338978	321424	14331P	PARTICIPANT	\N	PRESENT	0
338979	321424	19766L	PARTICIPANT	\N	PRESENT	0
338980	321424	19621T	PARTICIPANT	\N	PRESENT	0
338981	321424	14235Q	PARTICIPANT	\N	PRESENT	0
338982	321424	14213J	PARTICIPANT	\N	PRESENT	0
338983	321424	11056N	PARTICIPANT	\N	PRESENT	0
338984	321424	98050T	PARTICIPANT	\N	PRESENT	0
338985	321424	19573D	PARTICIPANT	\N	PRESENT	0
338986	321424	19695N	PARTICIPANT	\N	PRESENT	0
338987	321424	19711U	PARTICIPANT	\N	PRESENT	0
338988	321424	17637T	PARTICIPANT	\N	PRESENT	0
338989	321424	04085P	PARTICIPANT	\N	PRESENT	0
338990	321424	11040E	PARTICIPANT	\N	PRESENT	0
338991	321424	04042C	PARTICIPANT	\N	PRESENT	0
338992	321424	07034Q	PARTICIPANT	\N	PRESENT	0
338993	321424	14061L	PARTICIPANT	\N	PRESENT	0
338994	321424	04034C	PARTICIPANT	\N	PRESENT	0
338995	321424	04061F	PARTICIPANT	\N	PRESENT	0
338996	321424	11077T	PARTICIPANT	\N	PRESENT	0
338997	321424	04045F	PARTICIPANT	\N	PRESENT	0
338998	321424	04092N	PARTICIPANT	\N	PRESENT	0
338999	321424	08061X	PARTICIPANT	\N	PRESENT	0
339000	321424	01057W	PARTICIPANT	\N	PRESENT	0
339001	321424	95037J	PARTICIPANT	\N	PRESENT	0
339002	321424	19637C	PARTICIPANT	\N	PRESENT	0
339003	321424	14119M	PARTICIPANT	\N	PRESENT	0
339004	321424	05012A	PARTICIPANT	\N	PRESENT	0
339005	321424	95063L	PARTICIPANT	\N	PRESENT	0
339006	321424	19651A	PARTICIPANT	\N	PRESENT	0
339007	321424	19697Q	PARTICIPANT	\N	PRESENT	0
339008	321424	19349W	PARTICIPANT	\N	PRESENT	0
339009	321424	08051V	PARTICIPANT	\N	PRESENT	0
339010	321424	11012A	PARTICIPANT	\N	PRESENT	0
339011	321424	88008L	PARTICIPANT	\N	PRESENT	0
339012	321424	19629C	PARTICIPANT	\N	PRESENT	0
339013	321424	98022P	PARTICIPANT	\N	PRESENT	0
339014	321424	08048B	PARTICIPANT	\N	PRESENT	0
339015	321424	11065P	PARTICIPANT	\N	PRESENT	0
339016	321424	11083R	PARTICIPANT	\N	PRESENT	0
339017	321424	04044E	PARTICIPANT	\N	PRESENT	0
339018	321424	08053X	PARTICIPANT	\N	PRESENT	0
339019	321424	19671E	PARTICIPANT	\N	PRESENT	0
339020	321424	95067Q	PARTICIPANT	\N	PRESENT	0
339021	321424	19289C	PARTICIPANT	\N	PRESENT	0
339022	321424	08062Y	PARTICIPANT	\N	PRESENT	0
339023	321424	08024S	PARTICIPANT	\N	PRESENT	0
339024	321424	19443T	PARTICIPANT	\N	PRESENT	0
339025	321424	14093U	PARTICIPANT	\N	PRESENT	0
339026	321424	14251Q	PARTICIPANT	\N	PRESENT	0
339027	321424	19545Y	PARTICIPANT	\N	PRESENT	0
339028	321424	14041T	PARTICIPANT	\N	PRESENT	0
339029	321424	19663E	PARTICIPANT	\N	PRESENT	0
339030	321424	11090Q	PARTICIPANT	\N	PRESENT	0
339031	321424	14059S	PARTICIPANT	\N	PRESENT	0
339032	321424	04059M	PARTICIPANT	\N	PRESENT	0
339033	321424	11074Q	PARTICIPANT	\N	PRESENT	0
339034	321424	11027H	PARTICIPANT	\N	PRESENT	0
339035	321424	14159V	PARTICIPANT	\N	PRESENT	0
339036	321424	08035V	PARTICIPANT	\N	PRESENT	0
339037	321424	19705W	PARTICIPANT	\N	PRESENT	0
339038	321424	08055A	PARTICIPANT	\N	PRESENT	0
339039	321424	08068F	PARTICIPANT	\N	PRESENT	0
339040	321424	19689Q	PARTICIPANT	\N	PRESENT	0
339041	321424	14051J	PARTICIPANT	\N	PRESENT	0
339042	321424	14151M	PARTICIPANT	\N	PRESENT	0
339043	321424	19367Y	PARTICIPANT	\N	PRESENT	0
339044	321424	14225N	PARTICIPANT	\N	PRESENT	0
339045	321424	14169X	PARTICIPANT	\N	PRESENT	0
339046	321424	19669L	PARTICIPANT	\N	PRESENT	0
339047	321424	14033T	PARTICIPANT	\N	PRESENT	0
339048	321424	08045X	PARTICIPANT	\N	PRESENT	0
339049	321424	14021P	PARTICIPANT	\N	PRESENT	0
339050	321424	08038Y	PARTICIPANT	\N	PRESENT	0
339051	321424	14028W	PARTICIPANT	\N	PRESENT	0
339052	321424	11045K	PARTICIPANT	\N	PRESENT	0
339053	321424	19647E	PARTICIPANT	\N	PRESENT	0
339054	321424	19747H	PARTICIPANT	\N	PRESENT	0
339055	321424	14065Q	PARTICIPANT	\N	PRESENT	0
339056	321424	11066Q	PARTICIPANT	\N	PRESENT	0
339057	321424	08043V	PARTICIPANT	\N	PRESENT	0
339058	321424	11104D	PARTICIPANT	\N	PRESENT	0
339059	321424	11049P	PARTICIPANT	\N	PRESENT	0
339060	321424	14281W	PARTICIPANT	\N	PRESENT	0
339061	321424	08017T	PARTICIPANT	\N	PRESENT	0
339062	321424	19525U	PARTICIPANT	\N	PRESENT	0
339063	321424	14257W	PARTICIPANT	\N	PRESENT	0
339064	321424	19725B	PARTICIPANT	\N	PRESENT	0
339065	321424	04088S	PARTICIPANT	\N	PRESENT	0
339066	321424	14207L	PARTICIPANT	\N	PRESENT	0
339067	321424	10015M	PARTICIPANT	\N	PRESENT	0
339068	321424	19333N	PARTICIPANT	\N	PRESENT	0
339069	321424	14123H	PARTICIPANT	\N	PRESENT	0
339070	321424	14001X	PARTICIPANT	\N	PRESENT	0
351224	350910	14034U	PARTICIPANT	\N	PRESENT	0
351225	350910	19507S	PARTICIPANT	\N	PRESENT	0
351226	350910	11026G	PARTICIPANT	\N	PRESENT	0
351227	350910	04088S	PARTICIPANT	\N	PRESENT	0
351228	350910	19737F	PARTICIPANT	\N	PRESENT	0
351229	350910	19691J	PARTICIPANT	\N	PRESENT	0
351230	350910	19511N	PARTICIPANT	\N	PRESENT	0
351231	350910	19619A	PARTICIPANT	\N	PRESENT	0
351232	350910	19721W	PARTICIPANT	\N	PRESENT	0
351233	350910	14041T	PARTICIPANT	\N	PRESENT	0
351234	350910	08018U	PARTICIPANT	\N	PRESENT	0
351235	350910	16685X	PARTICIPANT	\N	PRESENT	0
351236	350910	07029T	PARTICIPANT	\N	PRESENT	0
351237	350910	19569H	PARTICIPANT	\N	PRESENT	0
351238	350910	19657G	PARTICIPANT	\N	PRESENT	0
351239	350910	08056B	PARTICIPANT	\N	PRESENT	0
351240	350910	14355X	PARTICIPANT	\N	PRESENT	0
351241	350910	14219Q	PARTICIPANT	\N	PRESENT	0
351242	350910	08062Y	PARTICIPANT	\N	PRESENT	0
351243	350910	14042U	PARTICIPANT	\N	PRESENT	0
351244	350910	08015R	PARTICIPANT	\N	PRESENT	0
351245	350910	14267Y	PARTICIPANT	\N	PRESENT	0
351945	350812	11067R	PARTICIPANT	\N	PRESENT	0
351247	350910	19319Q	PARTICIPANT	\N	PRESENT	0
351248	350910	14275Y	PARTICIPANT	\N	PRESENT	0
351249	350910	19689Q	PARTICIPANT	\N	PRESENT	0
351250	350910	19705W	PARTICIPANT	\N	PRESENT	0
351251	350910	98050T	PARTICIPANT	\N	PRESENT	0
351927	350700	08009T	PRESIDENT	0	PRESENT	0
351928	350700	19549D	PARTICIPANT	\N	EXCUSE	0
351929	350700	19685L	PARTICIPANT	\N	EXCUSE	0
351933	350556	14097Y	PARTICIPANT	\N	PRESENT	0
351934	350556	04034C	PARTICIPANT	\N	PRESENT	0
351935	350556	14079W	PARTICIPANT	\N	PRESENT	0
351936	350556	14267Y	PARTICIPANT	\N	PRESENT	0
351937	350556	08049C	PARTICIPANT	\N	PRESENT	0
351938	350556	16685X	PARTICIPANT	\N	PRESENT	0
351939	350556	98050T	PARTICIPANT	\N	PRESENT	0
351940	350556	04042C	PRESIDENT	0	PRESENT	0
351941	350556	14028W	PARTICIPANT	\N	PRESENT	0
351942	350556	08053X	PARTICIPANT	\N	PRESENT	0
351943	350556	19251M	PARTICIPANT	\N	PRESENT	0
351944	350556	19721W	PARTICIPANT	\N	PRESENT	0
351946	350812	04092N	PRESIDENT	0	PRESENT	0
351947	350812	19565D	PARTICIPANT	\N	PRESENT	0
351948	350812	14355X	PARTICIPANT	\N	PRESENT	0
351949	350812	11097X	PARTICIPANT	\N	PRESENT	0
351950	350812	19679N	PARTICIPANT	\N	PRESENT	0
351951	350812	08052W	PARTICIPANT	\N	PRESENT	0
351952	350812	19715Y	PARTICIPANT	\N	PRESENT	0
351953	350812	19657G	PARTICIPANT	\N	PRESENT	0
351954	350812	19683J	PARTICIPANT	\N	PRESENT	0
351955	350812	19675J	PARTICIPANT	\N	PRESENT	0
351956	350812	19723Y	PARTICIPANT	\N	PRESENT	0
351957	350812	08041T	PARTICIPANT	\N	EXCUSE	0
351958	350556	01058X	PARTICIPANT	\N	PRESENT	0
351959	350556	14193X	PARTICIPANT	\N	PRESENT	0
351960	350556	97011G	PARTICIPANT	\N	PRESENT	0
351961	350812	14223L	PARTICIPANT	\N	PRESENT	0
351962	350812	11103C	PARTICIPANT	\N	PRESENT	0
351963	350812	19703U	PARTICIPANT	\N	PRESENT	0
351964	350812	14195A	PARTICIPANT	\N	PRESENT	0
351965	350812	10006L	PARTICIPANT	\N	PRESENT	0
351966	350812	14261S	PARTICIPANT	\N	PRESENT	0
351967	350556	95030B	PARTICIPANT	\N	PRESENT	0
351968	350556	14105F	PARTICIPANT	\N	PRESENT	0
351969	350556	08047A	PARTICIPANT	\N	PRESENT	0
351970	350556	14133K	PARTICIPANT	\N	PRESENT	0
351971	350556	19709B	PARTICIPANT	\N	PRESENT	0
351972	350812	19301E	PARTICIPANT	\N	PRESENT	0
351973	350812	17779H	PARTICIPANT	\N	PRESENT	0
351974	350556	11027H	PARTICIPANT	\N	PRESENT	0
351975	350765	14327T	PARTICIPANT	\N	PRESENT	0
351976	350765	14331P	PARTICIPANT	\N	PRESENT	0
351977	350765	11048N	PARTICIPANT	\N	PRESENT	0
351978	350765	19479G	PARTICIPANT	\N	PRESENT	0
351979	350765	19711U	PARTICIPANT	\N	PRESENT	0
351980	350765	01048V	PARTICIPANT	\N	PRESENT	0
351981	350765	08069G	PARTICIPANT	\N	PRESENT	0
351982	350765	14225N	PARTICIPANT	\N	PRESENT	0
351983	350765	88008L	PARTICIPANT	\N	PRESENT	0
351984	350765	14159V	PARTICIPANT	\N	PRESENT	0
351985	350765	11040E	PARTICIPANT	\N	PRESENT	0
351986	350765	14083S	PARTICIPANT	\N	PRESENT	0
351987	350765	11012A	PARTICIPANT	\N	PRESENT	0
351988	350765	08073C	PARTICIPANT	\N	PRESENT	0
351989	350765	19741B	PARTICIPANT	\N	PRESENT	0
351990	350765	99004R	PARTICIPANT	\N	PRESENT	0
351991	350765	14253S	PARTICIPANT	\N	PRESENT	0
351992	350556	08061X	PARTICIPANT	\N	PRESENT	0
351993	350556	14255U	PARTICIPANT	\N	PRESENT	0
351994	350812	19697Q	PARTICIPANT	\N	PRESENT	0
351995	350812	19569H	PARTICIPANT	\N	PRESENT	0
351996	350812	14239U	PARTICIPANT	\N	PRESENT	0
351997	350812	14087W	PARTICIPANT	\N	PRESENT	0
351998	350812	19691J	PARTICIPANT	\N	PRESENT	0
351999	350812	14071N	PARTICIPANT	\N	PRESENT	0
352000	350765	19687N	PARTICIPANT	\N	PRESENT	0
352001	350765	19671E	PARTICIPANT	\N	PRESENT	0
352002	350812	19727D	PARTICIPANT	\N	PRESENT	0
352003	350812	19760E	PARTICIPANT	\N	PRESENT	0
352004	350812	19415P	PARTICIPANT	\N	PRESENT	0
352005	350812	14042U	PARTICIPANT	\N	PRESENT	0
352006	350812	98024R	PARTICIPANT	\N	PRESENT	0
352007	350812	19553Y	PARTICIPANT	\N	PRESENT	0
352008	350812	14213J	PARTICIPANT	\N	PRESENT	0
352009	350812	14217N	PARTICIPANT	\N	PRESENT	0
352010	350812	11045K	PARTICIPANT	\N	PRESENT	0
352011	350765	19647E	PARTICIPANT	\N	PRESENT	0
352013	350765	01057W	PARTICIPANT	\N	PRESENT	0
352014	350765	11074Q	PRESIDENT	0	PRESENT	0
352015	350765	04086Q	PARTICIPANT	\N	PRESENT	0
352016	350765	07029T	PARTICIPANT	\N	EXCUSE	0
352017	350765	14085U	PARTICIPANT	\N	EXCUSE	0
352018	350765	19545Y	PARTICIPANT	\N	EXCUSE	0
352019	350812	14227Q	PARTICIPANT	\N	PRESENT	0
352020	350812	14119M	PARTICIPANT	\N	PRESENT	0
352021	351930	04070G	PRESIDENT	0	PRESENT	0
352022	351930	19699S	PARTICIPANT	\N	PRESENT	0
352023	351930	14229S	PARTICIPANT	\N	PRESENT	0
352024	351930	14241N	PARTICIPANT	\N	PRESENT	0
352025	351930	14039A	PARTICIPANT	\N	PRESENT	0
352026	351930	92040Q	PARTICIPANT	\N	PRESENT	0
352027	351930	07033P	PARTICIPANT	\N	PRESENT	0
352028	351930	08012N	PARTICIPANT	\N	EXCUSE	0
352029	351930	19335Q	PARTICIPANT	\N	PRESENT	0
352030	351930	19593H	PARTICIPANT	\N	PRESENT	0
352031	351930	19643A	PARTICIPANT	\N	PRESENT	0
352032	351930	14059S	PARTICIPANT	\N	PRESENT	0
352033	351930	04057K	PARTICIPANT	\N	PRESENT	0
352034	351930	14073Q	PARTICIPANT	\N	PRESENT	0
352035	351930	19611R	PARTICIPANT	\N	PRESENT	0
352036	351930	08043V	PARTICIPANT	\N	PRESENT	0
352037	351930	87003B	PARTICIPANT	\N	PRESENT	0
352038	351930	19399H	PARTICIPANT	\N	PRESENT	0
352039	351930	14201E	PARTICIPANT	\N	PRESENT	0
352040	351930	14030Q	PARTICIPANT	\N	PRESENT	0
352041	351930	19731Y	PARTICIPANT	\N	PRESENT	0
352042	351930	14063N	PARTICIPANT	\N	PRESENT	0
352043	351930	11083R	PARTICIPANT	\N	PRESENT	0
352044	351930	11104D	PARTICIPANT	\N	PRESENT	0
352045	351930	19749K	PARTICIPANT	\N	PRESENT	0
352046	351930	04018C	PARTICIPANT	\N	PRESENT	0
352047	351930	19758L	PARTICIPANT	\N	PRESENT	0
352048	351930	14061L	PARTICIPANT	\N	EXCUSE	0
352049	351930	08017T	PARTICIPANT	\N	EXCUSE	0
352050	351930	19693L	PARTICIPANT	\N	EXCUSE	0
352051	350213	19768N	PARTICIPANT	\N	PRESENT	0
352052	350213	19515S	PARTICIPANT	\N	PRESENT	0
352053	350213	19782L	PARTICIPANT	\N	PRESENT	0
352054	350213	14357A	PARTICIPANT	\N	PRESENT	0
352055	350213	19441R	PARTICIPANT	\N	PRESENT	0
352056	350213	19413M	PARTICIPANT	\N	PRESENT	0
352057	350213	80013X	PARTICIPANT	\N	PRESENT	0
352058	350213	19631V	PARTICIPANT	\N	PRESENT	0
352059	350213	11099A	PARTICIPANT	\N	PRESENT	0
352060	350213	08068F	PARTICIPANT	\N	PRESENT	0
352061	350213	19705W	PARTICIPANT	\N	PRESENT	0
352062	350213	08019V	PARTICIPANT	\N	PRESENT	0
352063	350213	19369B	PARTICIPANT	\N	PRESENT	0
352064	350213	19511N	PARTICIPANT	\N	PRESENT	0
352065	350213	08028W	PARTICIPANT	\N	PRESENT	0
352066	350213	14265W	PARTICIPANT	\N	PRESENT	0
352067	350213	19591F	PARTICIPANT	\N	PRESENT	0
352068	350213	14135M	PARTICIPANT	\N	PRESENT	0
352069	350213	19467C	PARTICIPANT	\N	PRESENT	0
352070	350213	14187A	PARTICIPANT	\N	PRESENT	0
352071	350213	08062Y	PARTICIPANT	\N	PRESENT	0
339689	321424	14239U	PARTICIPANT	\N	PRESENT	0
340147	337095	14281W	PARTICIPANT	\N	PRESENT	0
340148	337095	11065P	PARTICIPANT	\N	PRESENT	0
340149	337095	19551W	PARTICIPANT	\N	PRESENT	0
340434	340433	19629C	PARTICIPANT	\N	PRESENT	0
340435	331577	14135M	PARTICIPANT	\N	EXCUSE	0
340436	334381	14331P	PARTICIPANT	\N	EXCUSE	0
340437	334381	14135M	PARTICIPANT	\N	EXCUSE	0
340485	340397	19479G	PARTICIPANT	\N	PRESENT	0
340487	340397	08069G	PARTICIPANT	\N	EXCUSE	0
340498	340397	08062Y	PARTICIPANT	\N	EXCUSE	0
340499	340397	11066Q	PARTICIPANT	\N	PRESENT	0
340500	340397	19369B	PARTICIPANT	\N	PRESENT	0
340534	340480	14063N	PARTICIPANT	\N	EXCUSE	0
340535	340480	14103D	PARTICIPANT	\N	EXCUSE	0
340537	331577	19659J	PARTICIPANT	\N	EXCUSE	0
340538	331577	96004D	PARTICIPANT	\N	EXCUSE	0
340539	331577	14097Y	PARTICIPANT	\N	EXCUSE	0
340540	331577	11054L	PARTICIPANT	\N	EXCUSE	0
340543	334381	19659J	PARTICIPANT	\N	EXCUSE	0
340544	334381	96004D	PARTICIPANT	\N	EXCUSE	0
340545	334381	14097Y	PARTICIPANT	\N	EXCUSE	0
340546	334381	11054L	PARTICIPANT	\N	EXCUSE	0
340547	340438	19577H	PARTICIPANT	\N	EXCUSE	0
340548	340438	19717B	PARTICIPANT	\N	EXCUSE	0
340549	340438	19295A	PARTICIPANT	\N	EXCUSE	0
340550	340438	19659J	PARTICIPANT	\N	PRESENT	0
340551	340438	19715Y	PARTICIPANT	\N	EXCUSE	0
340552	340473	19577H	PARTICIPANT	\N	EXCUSE	0
340553	340473	19715Y	PARTICIPANT	\N	EXCUSE	0
340554	340473	19295A	PARTICIPANT	\N	EXCUSE	0
340765	339494	19715Y	PARTICIPANT	\N	PRESENT	0
340766	339494	80013X	PARTICIPANT	\N	PRESENT	0
340767	339494	08068F	PARTICIPANT	\N	PRESENT	0
340768	339494	08052W	PARTICIPANT	\N	PRESENT	0
340769	339494	19631V	PARTICIPANT	\N	PRESENT	0
340770	339494	14257W	PARTICIPANT	\N	PRESENT	0
340771	339494	14207L	PARTICIPANT	\N	PRESENT	0
340772	339494	19719D	PARTICIPANT	\N	PRESENT	0
340773	339494	19563B	PARTICIPANT	\N	PRESENT	0
340774	339494	19583F	PARTICIPANT	\N	PRESENT	0
340775	339494	19713W	PARTICIPANT	\N	PRESENT	0
340776	339494	14205J	PARTICIPANT	\N	PRESENT	0
340777	339494	19525U	PARTICIPANT	\N	PRESENT	0
340778	339494	14073Q	PARTICIPANT	\N	PRESENT	0
340779	339494	04089T	PARTICIPANT	\N	PRESENT	0
340780	339494	19737F	PARTICIPANT	\N	PRESENT	0
340781	339494	14219Q	PARTICIPANT	\N	PRESENT	0
340782	339494	19479G	PARTICIPANT	\N	PRESENT	0
340783	339494	01025N	PARTICIPANT	\N	PRESENT	0
340784	339494	11097X	PARTICIPANT	\N	PRESENT	0
340785	339494	19731Y	PARTICIPANT	\N	PRESENT	0
340786	339494	19521Q	PARTICIPANT	\N	PRESENT	0
340787	339494	14026U	PARTICIPANT	\N	PRESENT	0
340788	339494	11090Q	PARTICIPANT	\N	PRESENT	0
340789	339494	19507S	PARTICIPANT	\N	PRESENT	0
340790	339494	14133K	PARTICIPANT	\N	PRESENT	0
340791	339494	14033T	PARTICIPANT	\N	PRESENT	0
340792	339494	95030B	PARTICIPANT	\N	PRESENT	0
340793	339494	04088S	PARTICIPANT	\N	PRESENT	0
340794	339494	14069U	PARTICIPANT	\N	PRESENT	0
340795	339494	14121F	PARTICIPANT	\N	PRESENT	0
340796	339494	19347U	PARTICIPANT	\N	PRESENT	0
340808	339494	11056N	PARTICIPANT	\N	PRESENT	0
340809	339494	19503N	PARTICIPANT	\N	PRESENT	0
340812	339494	19467C	PARTICIPANT	\N	PRESENT	0
340813	339494	14029X	PARTICIPANT	\N	PRESENT	0
340814	339494	19515S	PARTICIPANT	\N	PRESENT	0
340815	339494	19727D	PARTICIPANT	\N	PRESENT	0
340816	339494	08010L	PARTICIPANT	\N	PRESENT	0
340817	339494	97011G	PARTICIPANT	\N	PRESENT	0
340818	339494	99004R	PARTICIPANT	\N	PRESENT	0
340820	339494	02002K	PARTICIPANT	\N	PRESENT	0
340822	339494	17637T	PARTICIPANT	\N	PRESENT	0
340824	339494	19599P	PARTICIPANT	\N	PRESENT	0
340825	339494	19349W	PARTICIPANT	\N	PRESENT	0
340826	339494	01034P	PARTICIPANT	\N	PRESENT	0
340828	339494	19383Y	PARTICIPANT	\N	PRESENT	0
340829	339494	11012A	PARTICIPANT	\N	PRESENT	0
340830	339494	14265W	PARTICIPANT	\N	PRESENT	0
340831	339494	89017R	PARTICIPANT	\N	PRESENT	0
340832	339494	14357A	PARTICIPANT	\N	PRESENT	0
340833	339494	15447F	PARTICIPANT	\N	PRESENT	0
340834	339494	14109K	PARTICIPANT	\N	PRESENT	0
340835	339494	08060W	PARTICIPANT	\N	PRESENT	0
340836	339494	08038Y	PARTICIPANT	\N	PRESENT	0
340838	339494	14135M	PARTICIPANT	\N	PRESENT	0
340839	339494	08055A	PARTICIPANT	\N	PRESENT	0
340840	339494	19760E	PARTICIPANT	\N	PRESENT	0
340841	339494	19681G	PARTICIPANT	\N	PRESENT	0
340843	339494	19545Y	PARTICIPANT	\N	PRESENT	0
340844	339494	19611R	PARTICIPANT	\N	PRESENT	0
340845	339494	19441R	PARTICIPANT	\N	PRESENT	0
340846	339494	14079W	PARTICIPANT	\N	PRESENT	0
340847	339494	01058X	PARTICIPANT	\N	PRESENT	0
341001	339495	08031R	PARTICIPANT	\N	PRESENT	0
340849	340563	19489J	PARTICIPANT	\N	PRESENT	0
340850	340563	14179A	PARTICIPANT	\N	PRESENT	0
340851	340563	14259Y	PARTICIPANT	\N	PRESENT	0
340852	339494	14223L	PARTICIPANT	\N	PRESENT	0
340853	339494	08015R	PARTICIPANT	\N	PRESENT	0
340854	339494	14041T	PARTICIPANT	\N	PRESENT	0
340855	339494	08024S	PARTICIPANT	\N	PRESENT	0
340857	339494	19533U	PARTICIPANT	\N	PRESENT	0
340858	339494	14123H	PARTICIPANT	\N	PRESENT	0
340859	339494	14179A	PARTICIPANT	\N	PRESENT	0
340860	339494	04086Q	PARTICIPANT	\N	PRESENT	0
340912	339495	19599P	PARTICIPANT	\N	PRESENT	0
340913	339495	19525U	PARTICIPANT	\N	PRESENT	0
340914	339495	19681G	PARTICIPANT	\N	PRESENT	0
340915	339495	02002K	PARTICIPANT	\N	PRESENT	0
340916	339495	19479G	PARTICIPANT	\N	PRESENT	0
340918	339495	19737F	PARTICIPANT	\N	PRESENT	0
340919	339495	14179A	PARTICIPANT	\N	PRESENT	0
340920	339495	19383Y	PARTICIPANT	\N	PRESENT	0
340921	339495	14265W	PARTICIPANT	\N	PRESENT	0
340922	339495	97011G	PARTICIPANT	\N	PRESENT	0
340923	339495	19507S	PARTICIPANT	\N	PRESENT	0
340924	339495	95030B	PARTICIPANT	\N	PRESENT	0
340925	339495	14033T	PARTICIPANT	\N	PRESENT	0
340926	339495	14157T	PARTICIPANT	\N	PRESENT	0
340927	339495	14031R	PARTICIPANT	\N	PRESENT	0
340928	339495	04088S	PARTICIPANT	\N	PRESENT	0
340929	339495	14029X	PARTICIPANT	\N	PRESENT	0
340930	339495	19467C	PARTICIPANT	\N	PRESENT	0
340931	339495	99004R	PARTICIPANT	\N	PRESENT	0
340932	339495	08024S	PARTICIPANT	\N	PRESENT	0
340933	339495	19551W	PARTICIPANT	\N	PRESENT	0
340934	339495	14089Y	PARTICIPANT	\N	PRESENT	0
340935	339495	04085P	PARTICIPANT	\N	PRESENT	0
340936	339495	19441R	PARTICIPANT	\N	PRESENT	0
340937	339495	19715Y	PARTICIPANT	\N	PRESENT	0
340938	339495	08060W	PARTICIPANT	\N	PRESENT	0
340940	340939	11097X	PARTICIPANT	\N	PRESENT	0
340941	339495	17583W	PARTICIPANT	\N	PRESENT	0
340942	339495	14331P	PARTICIPANT	\N	PRESENT	0
340943	339495	14119M	PARTICIPANT	\N	PRESENT	0
340944	339495	04071H	PARTICIPANT	\N	PRESENT	0
340945	339495	17637T	PARTICIPANT	\N	PRESENT	0
340946	339495	14219Q	PARTICIPANT	\N	PRESENT	0
340947	339495	19711U	PARTICIPANT	\N	PRESENT	0
340948	339495	19760E	PARTICIPANT	\N	PRESENT	0
340999	339495	19549D	PARTICIPANT	\N	PRESENT	0
341000	339495	11012A	PARTICIPANT	\N	PRESENT	0
341002	339495	14135M	PARTICIPANT	\N	PRESENT	0
341003	339495	11056N	PARTICIPANT	\N	PRESENT	0
341004	339495	14217N	PARTICIPANT	\N	PRESENT	0
341005	339495	19713W	PARTICIPANT	\N	PRESENT	0
341006	339495	19347U	PARTICIPANT	\N	PRESENT	0
341007	339495	01048V	PARTICIPANT	\N	PRESENT	0
341008	339495	11048N	PARTICIPANT	\N	PRESENT	0
341009	339495	95062K	PARTICIPANT	\N	PRESENT	0
342020	331577	11109J	PARTICIPANT	\N	PRESENT	0
342021	331577	14261S	PARTICIPANT	\N	PRESENT	0
342023	331577	19717B	PARTICIPANT	\N	PRESENT	0
342024	331577	19691J	PARTICIPANT	\N	PRESENT	0
340910	339495	04086Q	PARTICIPANT	\N	PRESENT	0
340911	339495	19349W	PARTICIPANT	\N	PRESENT	0
342025	331577	19583F	PARTICIPANT	\N	PRESENT	0
342026	331577	19729F	PARTICIPANT	\N	PRESENT	0
342027	331577	14219Q	PARTICIPANT	\N	PRESENT	0
342028	331577	14059S	PARTICIPANT	\N	PRESENT	0
342029	331577	08019V	PRESIDENT	0	PRESENT	0
342030	331577	19657G	PARTICIPANT	\N	PRESENT	0
342031	331577	11072N	PARTICIPANT	\N	PRESENT	0
342032	331577	08073C	PARTICIPANT	\N	PRESENT	0
342033	331577	14331P	PARTICIPANT	\N	PRESENT	0
342034	331577	95062K	PARTICIPANT	\N	EXCUSE	0
342035	331577	19703U	PARTICIPANT	\N	PRESENT	0
346777	339514	19479G	PARTICIPANT	\N	PRESENT	0
346778	339514	14083S	PARTICIPANT	\N	PRESENT	0
346779	339514	19399H	PARTICIPANT	\N	PRESENT	0
346780	339514	14115H	PARTICIPANT	\N	PRESENT	0
346781	339514	89017R	PARTICIPANT	\N	PRESENT	0
346782	339514	19741B	PARTICIPANT	\N	PRESENT	0
346783	339514	14159V	PARTICIPANT	\N	PRESENT	0
346784	339514	04033B	PARTICIPANT	\N	PRESENT	0
346785	339514	14231L	PARTICIPANT	\N	PRESENT	0
346786	339514	14030Q	PARTICIPANT	\N	PRESENT	0
346787	339514	11048N	PARTICIPANT	\N	PRESENT	0
346788	339514	19467C	PARTICIPANT	\N	PRESENT	0
346789	339514	14069U	PARTICIPANT	\N	PRESENT	0
346790	339514	19349W	PARTICIPANT	\N	PRESENT	0
346791	339514	14179A	PARTICIPANT	\N	PRESENT	0
346792	339514	19715Y	PARTICIPANT	\N	PRESENT	0
346793	339514	14033T	PARTICIPANT	\N	PRESENT	0
346794	339514	14329V	PARTICIPANT	\N	PRESENT	0
346795	339514	14213J	PARTICIPANT	\N	PRESENT	0
346796	339514	08034U	PARTICIPANT	\N	PRESENT	0
346797	339514	14087W	PARTICIPANT	\N	PRESENT	0
346798	339514	19383Y	PARTICIPANT	\N	PRESENT	0
346799	339514	11097X	PARTICIPANT	\N	PRESENT	0
346800	339514	19768N	PARTICIPANT	\N	PRESENT	0
346801	339514	14026U	PARTICIPANT	\N	PRESENT	0
346802	339514	14265W	PARTICIPANT	\N	PRESENT	0
346803	339514	04088S	PARTICIPANT	\N	PRESENT	0
346804	339514	11090Q	PARTICIPANT	\N	PRESENT	0
346805	339514	14205J	PARTICIPANT	\N	PRESENT	0
346806	339514	95063L	PARTICIPANT	\N	PRESENT	0
346807	339514	14187A	PARTICIPANT	\N	PRESENT	0
346808	339514	14215L	PARTICIPANT	\N	PRESENT	0
346809	339514	14089Y	PARTICIPANT	\N	PRESENT	0
346810	339514	01028R	PARTICIPANT	\N	PRESENT	0
346811	339514	08010L	PARTICIPANT	\N	PRESENT	0
346812	339514	19713W	PARTICIPANT	\N	PRESENT	0
346813	339514	19507S	PARTICIPANT	\N	PRESENT	0
346814	339514	19447X	PARTICIPANT	\N	PRESENT	0
346815	339514	12016W	PARTICIPANT	\N	PRESENT	0
346816	339514	19703U	PARTICIPANT	\N	PRESENT	0
346817	339514	11110B	PARTICIPANT	\N	PRESENT	0
346818	339514	08038Y	PARTICIPANT	\N	PRESENT	0
346819	339514	14021P	PARTICIPANT	\N	PRESENT	0
346820	339514	19657G	PARTICIPANT	\N	PRESENT	0
346821	339514	19733B	PARTICIPANT	\N	PRESENT	0
346822	339514	18083K	PARTICIPANT	\N	PRESENT	0
346823	339514	14059S	PARTICIPANT	\N	PRESENT	0
346824	339514	04071H	PARTICIPANT	\N	PRESENT	0
346825	339514	14038Y	PARTICIPANT	\N	PRESENT	0
346939	346938	19575F	PARTICIPANT	\N	PRESENT	0
346941	346938	14030Q	PARTICIPANT	\N	PRESENT	0
346942	346938	14105F	PARTICIPANT	\N	PRESENT	0
346943	346938	14255U	PARTICIPANT	\N	PRESENT	0
346944	346938	14079W	PARTICIPANT	\N	PRESENT	0
346945	346938	14026U	PARTICIPANT	\N	PRESENT	0
346947	346938	14121F	PARTICIPANT	\N	PRESENT	0
346948	346938	04049K	PRESIDENT	0	PRESENT	0
346950	346938	08015R	PARTICIPANT	\N	PRESENT	0
346951	346938	16685X	PARTICIPANT	\N	PRESENT	0
346952	346938	14265W	PARTICIPANT	\N	PRESENT	0
346954	346938	14253S	PARTICIPANT	\N	PRESENT	0
346956	346938	04088S	PARTICIPANT	\N	PRESENT	0
346775	339514	19631V	PARTICIPANT	\N	PRESENT	0
346776	339514	19549D	PARTICIPANT	\N	PRESENT	0
346957	346938	14051J	PARTICIPANT	\N	PRESENT	0
346958	346938	14157T	PARTICIPANT	\N	PRESENT	0
346959	346938	14261S	PARTICIPANT	\N	EXCUSE	0
346961	346938	08060W	PARTICIPANT	\N	EXCUSE	0
346962	346938	08068F	PARTICIPANT	\N	EXCUSE	0
346963	346938	14053L	PARTICIPANT	\N	EXCUSE	0
346964	346938	14083S	PARTICIPANT	\N	EXCUSE	0
346965	346938	19545Y	PARTICIPANT	\N	EXCUSE	0
346966	346938	14329V	PARTICIPANT	\N	EXCUSE	0
346968	346938	11031D	PARTICIPANT	\N	EXCUSE	0
346969	346938	14041T	PARTICIPANT	\N	EXCUSE	0
346970	346938	14151M	PARTICIPANT	\N	EXCUSE	0
346973	346938	14187A	PARTICIPANT	\N	EXCUSE	0
346974	346938	14087W	PARTICIPANT	\N	EXCUSE	0
346975	346938	19521Q	PARTICIPANT	\N	EXCUSE	0
346976	346938	14034U	PARTICIPANT	\N	EXCUSE	0
346978	346938	19591F	PARTICIPANT	\N	EXCUSE	0
346980	346938	14061L	PARTICIPANT	\N	EXCUSE	0
346981	346938	11099A	PARTICIPANT	\N	EXCUSE	0
346983	346938	19671E	PARTICIPANT	\N	EXCUSE	0
346985	346938	08047A	PARTICIPANT	\N	EXCUSE	0
346987	346938	19669L	PARTICIPANT	\N	EXCUSE	0
346989	346938	14227Q	PARTICIPANT	\N	EXCUSE	0
346990	346938	19527W	PARTICIPANT	\N	EXCUSE	0
347045	347044	04059M	PARTICIPANT	\N	PRESENT	0
347046	347044	11040E	PARTICIPANT	\N	PRESENT	0
347047	347044	14053L	PARTICIPANT	\N	PRESENT	0
347048	347044	11053K	PARTICIPANT	\N	PRESENT	0
347049	347044	11027H	PARTICIPANT	\N	PRESENT	0
347050	347044	04086Q	PARTICIPANT	\N	PRESENT	0
347051	347044	08052W	PARTICIPANT	\N	PRESENT	0
347052	347044	11070L	PARTICIPANT	\N	PRESENT	0
347053	347044	10006L	PARTICIPANT	\N	PRESENT	0
347054	347044	14041T	PARTICIPANT	\N	PRESENT	0
347055	347044	04089T	PARTICIPANT	\N	PRESENT	0
347056	347044	14034U	PARTICIPANT	\N	PRESENT	0
347057	347044	14231L	PARTICIPANT	\N	PRESENT	0
347058	347044	11064N	PARTICIPANT	\N	PRESENT	0
347059	347044	14081Q	PARTICIPANT	\N	PRESENT	0
347060	347044	14241N	PARTICIPANT	\N	PRESENT	0
347061	347044	14061L	PARTICIPANT	\N	PRESENT	0
347062	347044	14159V	PARTICIPANT	\N	PRESENT	0
347063	347044	86034E	PARTICIPANT	\N	PRESENT	0
347064	347044	08034U	PARTICIPANT	\N	PRESENT	0
347065	347044	01043Q	PARTICIPANT	\N	PRESENT	0
347066	347044	14135M	PARTICIPANT	\N	PRESENT	0
347067	347044	04044E	PARTICIPANT	\N	PRESENT	0
347930	347929	07033P	PARTICIPANT	\N	PRESENT	0
348007	346589	14042U	PARTICIPANT	\N	PRESENT	0
348028	348021	19681G	PARTICIPANT	\N	PRESENT	0
348029	348022	19681G	PARTICIPANT	\N	PRESENT	0
348030	348024	19681G	PARTICIPANT	\N	PRESENT	0
348031	348027	19681G	PARTICIPANT	\N	PRESENT	0
348102	348101	14001X	PARTICIPANT	\N	PRESENT	0
348104	348103	11083R	PARTICIPANT	\N	PRESENT	0
348109	348108	04061F	PARTICIPANT	\N	PRESENT	0
348110	348108	14225N	PARTICIPANT	\N	PRESENT	0
348112	348111	04061F	PARTICIPANT	\N	PRESENT	0
348323	348321	14065Q	PARTICIPANT	\N	PRESENT	0
348324	348321	10015M	PARTICIPANT	\N	PRESENT	0
349658	349657	08010L	PARTICIPANT	\N	PRESENT	0
349659	349657	04040A	PARTICIPANT	\N	PRESENT	0
349660	349657	14069U	PARTICIPANT	\N	PRESENT	0
349661	349657	19467C	PARTICIPANT	\N	PRESENT	0
349662	349657	08052W	PARTICIPANT	\N	PRESENT	0
349663	349657	19735D	PARTICIPANT	\N	PRESENT	0
349664	349657	14081Q	PARTICIPANT	\N	PRESENT	0
349665	349657	04057K	PARTICIPANT	\N	PRESENT	0
349666	349657	05012A	PARTICIPANT	\N	PRESENT	0
349667	349657	04045F	PARTICIPANT	\N	PRESENT	0
349778	349777	19721W	PARTICIPANT	\N	PRESENT	0
349779	349777	19693L	PARTICIPANT	\N	PRESENT	0
349780	349777	14259Y	PARTICIPANT	\N	PRESENT	0
349781	349777	97011G	PARTICIPANT	\N	PRESENT	0
349782	349777	14026U	PARTICIPANT	\N	PRESENT	0
349783	349777	19637C	PARTICIPANT	\N	PRESENT	0
349784	349777	04097T	PARTICIPANT	\N	PRESENT	0
350084	348100	04038G	PARTICIPANT	\N	PRESENT	0
350209	350208	14001X	PARTICIPANT	\N	PRESENT	0
350210	350208	14215L	PARTICIPANT	\N	PRESENT	0
350212	350211	14215L	PARTICIPANT	\N	PRESENT	0
350222	350221	19575F	PARTICIPANT	\N	PRESENT	0
350223	350221	08068F	PARTICIPANT	\N	PRESENT	0
350224	350221	19782L	PARTICIPANT	\N	PRESENT	0
350225	350221	11101A	PARTICIPANT	\N	PRESENT	0
350226	350221	19681G	PARTICIPANT	\N	EXCUSE	0
350227	350221	19599P	PARTICIPANT	\N	PRESENT	0
350228	350221	19695N	PARTICIPANT	\N	PRESENT	0
350230	350221	14073Q	PARTICIPANT	\N	PRESENT	0
350231	350221	07029T	PARTICIPANT	\N	PRESENT	0
350232	350221	04049K	PARTICIPANT	\N	EXCUSE	0
350233	350221	19711U	PARTICIPANT	\N	PRESENT	0
350234	350221	01043Q	PARTICIPANT	\N	PRESENT	0
350235	350221	14205J	PARTICIPANT	\N	PRESENT	0
350237	350221	19637C	PARTICIPANT	\N	PRESENT	0
350238	350221	19563B	PRESIDENT	1	PRESENT	0
350239	350221	14265W	PARTICIPANT	\N	PRESENT	0
350240	350221	19768N	PARTICIPANT	\N	PRESENT	0
350241	350221	14237S	PARTICIPANT	\N	PRESENT	0
350242	350221	19503N	PARTICIPANT	\N	PRESENT	0
350243	350221	19713W	PARTICIPANT	\N	PRESENT	0
350244	350221	19413M	PARTICIPANT	\N	PRESENT	0
350245	350221	01062T	PARTICIPANT	\N	PRESENT	0
339071	321424	19723Y	PARTICIPANT	\N	PRESENT	0
339072	321424	19527W	PARTICIPANT	\N	PRESENT	0
339073	321424	14109K	PARTICIPANT	\N	PRESENT	0
339074	321424	11072N	PARTICIPANT	\N	PRESENT	0
339075	321424	14097Y	PARTICIPANT	\N	PRESENT	0
339076	321424	08012N	PARTICIPANT	\N	PRESENT	0
339077	321424	80027E	PARTICIPANT	\N	PRESENT	0
339078	321424	19733B	PARTICIPANT	\N	PRESENT	0
339079	321424	14069U	PARTICIPANT	\N	PRESENT	0
339080	321424	19531S	PARTICIPANT	\N	PRESENT	0
339081	321424	19489J	PARTICIPANT	\N	PRESENT	0
339082	321424	17779H	PARTICIPANT	\N	PRESENT	0
339083	321424	14121F	PARTICIPANT	\N	PRESENT	0
339141	321424	08073C	PARTICIPANT	\N	PRESENT	0
339085	321424	19683J	PARTICIPANT	\N	PRESENT	0
339086	321424	19591F	PARTICIPANT	\N	PRESENT	0
339087	321424	04071H	PARTICIPANT	\N	PRESENT	0
339088	321424	19413M	PARTICIPANT	\N	PRESENT	0
339089	321424	11026G	PARTICIPANT	\N	PRESENT	0
339090	321424	19551W	PARTICIPANT	\N	PRESENT	0
339091	321424	19251M	PARTICIPANT	\N	PRESENT	0
339092	321424	14227Q	PARTICIPANT	\N	PRESENT	0
339093	321424	04043D	PARTICIPANT	\N	PRESENT	0
339094	321424	14081Q	PARTICIPANT	\N	PRESENT	0
339095	321424	11031D	PARTICIPANT	\N	PRESENT	0
339096	321424	19760E	PARTICIPANT	\N	PRESENT	0
339097	321424	19687N	PARTICIPANT	\N	PRESENT	0
339098	321424	19717B	PARTICIPANT	\N	PRESENT	0
339099	321424	04033B	PARTICIPANT	\N	PRESENT	0
339100	321424	19553Y	PARTICIPANT	\N	PRESENT	0
339101	321424	19421M	PARTICIPANT	\N	PRESENT	0
339102	321424	19549D	PARTICIPANT	\N	PRESENT	0
339103	321424	08031R	PARTICIPANT	\N	PRESENT	0
339104	321424	14034U	PARTICIPANT	\N	PRESENT	0
339105	321424	19643A	PARTICIPANT	\N	PRESENT	0
339106	321424	89017R	PARTICIPANT	\N	PRESENT	0
339107	321424	14231L	PARTICIPANT	\N	PRESENT	0
339108	321424	04089T	PARTICIPANT	\N	PRESENT	0
339109	321424	14179A	PARTICIPANT	\N	PRESENT	0
339110	321424	01034P	PARTICIPANT	\N	PRESENT	0
339111	321424	19369B	PARTICIPANT	\N	PRESENT	0
339112	321424	11053K	PARTICIPANT	\N	PRESENT	0
339113	321424	19699S	PARTICIPANT	\N	PRESENT	0
339114	321424	19735D	PARTICIPANT	\N	PRESENT	0
339115	321424	16685X	PARTICIPANT	\N	PRESENT	0
339116	321424	19441R	PARTICIPANT	\N	PRESENT	0
339117	321424	14042U	PARTICIPANT	\N	PRESENT	0
339118	321424	19749K	PARTICIPANT	\N	PRESENT	0
339119	321424	98005N	PARTICIPANT	\N	PRESENT	0
339120	321424	14267Y	PARTICIPANT	\N	PRESENT	0
339121	321424	07004J	PARTICIPANT	\N	PRESENT	0
339122	321424	14221J	PARTICIPANT	\N	PRESENT	0
339123	321424	19335Q	PARTICIPANT	\N	PRESENT	0
339124	321424	19739H	PARTICIPANT	\N	PRESENT	0
339125	321424	14073Q	PARTICIPANT	\N	PRESENT	0
339126	321424	14083S	PARTICIPANT	\N	PRESENT	0
339127	321424	19569H	PARTICIPANT	\N	PRESENT	0
339128	321424	19521Q	PARTICIPANT	\N	PRESENT	0
339129	321424	14255U	PARTICIPANT	\N	PRESENT	0
339130	321424	11085T	PARTICIPANT	\N	PRESENT	0
339131	321424	04040A	PARTICIPANT	\N	PRESENT	0
339132	321424	04070G	PARTICIPANT	\N	PRESENT	0
339133	321424	01024M	PARTICIPANT	\N	PRESENT	0
339134	321424	14030Q	PARTICIPANT	\N	PRESENT	0
339135	321424	14327T	PARTICIPANT	\N	PRESENT	0
339136	321424	01043Q	PARTICIPANT	\N	PRESENT	0
339137	321424	19269X	PARTICIPANT	\N	PRESENT	0
339138	321424	19721W	PARTICIPANT	\N	PRESENT	0
339139	321424	19745F	PARTICIPANT	\N	PRESENT	0
339140	321424	11115U	PARTICIPANT	\N	PRESENT	0
339142	321424	11099A	PARTICIPANT	\N	PRESENT	0
339143	321424	08058D	PARTICIPANT	\N	PRESENT	0
339150	321424	19713W	PARTICIPANT	\N	PRESENT	0
339145	321424	98023Q	PARTICIPANT	\N	PRESENT	0
339146	321424	11064N	PARTICIPANT	\N	PRESENT	0
339147	321424	08009T	PARTICIPANT	\N	PRESENT	0
339148	321424	19729F	PARTICIPANT	\N	PRESENT	0
339152	321424	11070L	PARTICIPANT	\N	PRESENT	0
339151	321424	02002K	PARTICIPANT	\N	PRESENT	0
339437	321425	04059M	PARTICIPANT	\N	PRESENT	0
339438	321425	11072N	PARTICIPANT	\N	PRESENT	0
339439	321425	80013X	PARTICIPANT	\N	PRESENT	0
339440	321425	14065Q	PARTICIPANT	\N	PRESENT	0
339441	321425	14081Q	PARTICIPANT	\N	PRESENT	0
339442	321425	19758L	PARTICIPANT	\N	PRESENT	0
339443	321425	19760E	PARTICIPANT	\N	PRESENT	0
339444	321425	04085P	PARTICIPANT	\N	PRESENT	0
339445	321425	19565D	PARTICIPANT	\N	PRESENT	0
339446	321425	19695N	PARTICIPANT	\N	PRESENT	0
339447	321425	19295A	PARTICIPANT	\N	PRESENT	0
339448	321425	11109J	PARTICIPANT	\N	PRESENT	0
339449	321425	08038Y	PARTICIPANT	\N	PRESENT	0
339450	321425	14109K	PARTICIPANT	\N	PRESENT	0
339451	321425	14097Y	PARTICIPANT	\N	PRESENT	0
339452	321425	14257W	PARTICIPANT	\N	PRESENT	0
339453	321425	19329S	PARTICIPANT	\N	PRESENT	0
339454	321425	19782L	PARTICIPANT	\N	PRESENT	0
339455	321425	19717B	PARTICIPANT	\N	PRESENT	0
339456	321425	19479G	PARTICIPANT	\N	PRESENT	0
339457	321425	08031R	PARTICIPANT	\N	PRESENT	0
339458	321425	11012A	PARTICIPANT	\N	PRESENT	0
339459	321425	05008E	PARTICIPANT	\N	PRESENT	0
339460	321425	14215L	PARTICIPANT	\N	PRESENT	0
339461	321425	14147R	PARTICIPANT	\N	PRESENT	0
339462	321425	14041T	PARTICIPANT	\N	PRESENT	0
339463	321425	19762G	PARTICIPANT	\N	PRESENT	0
339464	321425	14173T	PARTICIPANT	\N	PRESENT	0
339465	321425	14169X	PARTICIPANT	\N	PRESENT	0
339466	321425	08019V	PARTICIPANT	\N	PRESENT	0
339467	321425	14119M	PARTICIPANT	\N	PRESENT	0
339468	321425	08045X	PARTICIPANT	\N	PRESENT	0
339469	321425	01058X	PARTICIPANT	\N	PRESENT	0
339470	321425	19347U	PARTICIPANT	\N	PRESENT	0
339471	321425	14089Y	PARTICIPANT	\N	PRESENT	0
339472	321425	08058D	PARTICIPANT	\N	PRESENT	0
339474	321425	97011G	PARTICIPANT	\N	PRESENT	0
339487	337095	08009T	PRESIDENT	0	PRESENT	0
339488	337095	17583W	PARTICIPANT	\N	EXCUSE	0
339489	337095	08060W	PARTICIPANT	\N	EXCUSE	0
339490	337095	19701S	PARTICIPANT	\N	EXCUSE	0
339491	337095	19685L	PARTICIPANT	\N	EXCUSE	0
339492	337095	19637C	PARTICIPANT	\N	EXCUSE	0
339525	337095	14038Y	PARTICIPANT	\N	PRESENT	0
339526	337095	19333N	PARTICIPANT	\N	PRESENT	0
339527	337095	19383Y	PARTICIPANT	\N	PRESENT	0
339528	337095	14031R	PARTICIPANT	\N	PRESENT	0
339529	337095	19387D	PARTICIPANT	\N	PRESENT	0
339530	337095	14219Q	PARTICIPANT	\N	PRESENT	0
339531	337095	14221J	PARTICIPANT	\N	PRESENT	0
339532	337095	19599P	PARTICIPANT	\N	PRESENT	0
339533	337095	14169X	PARTICIPANT	\N	PRESENT	0
339534	337095	15447F	PARTICIPANT	\N	PRESENT	0
339535	337095	18083K	PARTICIPANT	\N	PRESENT	0
339536	337095	14237S	PARTICIPANT	\N	PRESENT	0
339537	337095	05012A	PARTICIPANT	\N	PRESENT	0
339538	337095	19737F	PARTICIPANT	\N	PRESENT	0
339539	337095	19347U	PARTICIPANT	\N	PRESENT	0
339540	337095	19503N	PARTICIPANT	\N	PRESENT	0
339541	337095	04097T	PARTICIPANT	\N	PRESENT	0
339542	337095	14157T	PARTICIPANT	\N	PRESENT	0
339543	337095	19745F	PARTICIPANT	\N	PRESENT	0
339544	337095	19681G	PARTICIPANT	\N	PRESENT	0
339545	337095	08024S	PARTICIPANT	\N	PRESENT	0
339546	337095	17637T	PARTICIPANT	\N	PRESENT	0
339554	337095	14051J	PARTICIPANT	\N	PRESENT	0
339560	339505	14001X	PARTICIPANT	\N	PRESENT	0
339561	339505	19543W	PARTICIPANT	\N	PRESENT	0
339562	339505	19581D	PARTICIPANT	\N	PRESENT	0
339563	339505	04047H	PARTICIPANT	\N	PRESENT	0
339564	339505	19673G	PARTICIPANT	\N	PRESENT	0
339565	339505	01028R	PARTICIPANT	\N	PRESENT	0
339566	339505	19447X	PARTICIPANT	\N	PRESENT	0
339567	339505	14231L	PARTICIPANT	\N	PRESENT	0
339568	339505	05008E	PRESIDENT	0	PRESENT	0
339569	339505	14041T	PARTICIPANT	\N	PRESENT	0
339570	339505	14147R	PARTICIPANT	\N	PRESENT	0
339571	339505	14179A	PARTICIPANT	\N	PRESENT	0
339572	339505	14151M	PARTICIPANT	\N	PRESENT	0
339573	339505	14215L	PARTICIPANT	\N	PRESENT	0
339574	339505	14259Y	PARTICIPANT	\N	PRESENT	0
339575	339505	11072N	PARTICIPANT	\N	PRESENT	0
339576	339505	08051V	PARTICIPANT	\N	PRESENT	0
339577	339505	14053L	PARTICIPANT	\N	PRESENT	0
339578	339505	14111D	PARTICIPANT	\N	PRESENT	0
339579	339505	07034Q	PRESIDENT	1	PRESENT	0
339580	339505	10015M	PARTICIPANT	\N	PRESENT	0
339581	339505	08045X	PARTICIPANT	\N	PRESENT	0
339582	339505	11026G	PARTICIPANT	\N	PRESENT	0
352072	350213	11090Q	PRESIDENT	0	PRESENT	0
352073	350213	14033T	PARTICIPANT	\N	PRESENT	0
352074	350213	01025N	PARTICIPANT	\N	PRESENT	0
352075	350213	14205J	PARTICIPANT	\N	PRESENT	0
352076	350213	04088S	PARTICIPANT	\N	PRESENT	0
352077	350213	11056N	PARTICIPANT	\N	PRESENT	0
352078	350213	14115H	PARTICIPANT	\N	PRESENT	0
352079	350213	11101A	PARTICIPANT	\N	PRESENT	0
352080	350213	19747H	PARTICIPANT	\N	PRESENT	0
352081	350213	14207L	PARTICIPANT	\N	PRESENT	0
352082	350213	14257W	PARTICIPANT	\N	PRESENT	0
352083	350556	08056B	PARTICIPANT	\N	PRESENT	0
352084	350556	95067Q	PARTICIPANT	\N	PRESENT	0
352085	350556	11041F	PARTICIPANT	\N	PRESENT	0
352086	350556	11064N	PARTICIPANT	\N	PRESENT	0
352087	350812	14281W	PARTICIPANT	\N	PRESENT	0
352088	350812	19575F	PARTICIPANT	\N	PRESENT	0
352089	350812	14026U	PARTICIPANT	\N	PRESENT	0
352090	350812	11031D	PARTICIPANT	\N	PRESENT	0
352091	350812	19527W	PARTICIPANT	\N	PRESENT	0
352092	350812	01034P	PARTICIPANT	\N	PRESENT	0
352093	350812	19367Y	PARTICIPANT	\N	EXCUSE	0
352094	350556	04040A	PARTICIPANT	\N	PRESENT	0
352095	350765	11053K	PARTICIPANT	\N	PRESENT	0
352096	350765	11070L	PARTICIPANT	\N	PRESENT	0
352097	350765	19689Q	PARTICIPANT	\N	PRESENT	0
352098	350765	14173T	PARTICIPANT	\N	PRESENT	0
352099	350765	04061F	PARTICIPANT	\N	PRESENT	0
352100	350812	19663E	PARTICIPANT	\N	PRESENT	0
352101	351930	19533U	PARTICIPANT	\N	PRESENT	0
352102	351930	14107H	PARTICIPANT	\N	PRESENT	0
352103	351930	14249W	PARTICIPANT	\N	PRESENT	0
352104	351930	19735D	PARTICIPANT	\N	PRESENT	0
352105	351930	08031R	PARTICIPANT	\N	EXCUSE	0
352106	350700	19347U	PARTICIPANT	\N	PRESENT	0
352107	350700	14157T	PARTICIPANT	\N	PRESENT	0
352108	350700	14191V	PARTICIPANT	\N	PRESENT	0
352109	350700	19745F	PARTICIPANT	\N	PRESENT	0
352157	350556	98029W	PARTICIPANT	\N	PRESENT	0
352111	351930	08039A	PARTICIPANT	\N	PRESENT	0
352112	350700	14103D	PARTICIPANT	\N	PRESENT	0
352113	350700	14029X	PARTICIPANT	\N	PRESENT	0
352114	350700	08060W	PARTICIPANT	\N	PRESENT	0
352115	350700	08055A	PARTICIPANT	\N	PRESENT	0
352116	350700	19659J	PARTICIPANT	\N	PRESENT	0
352117	350700	19681G	PARTICIPANT	\N	PRESENT	0
352126	350700	19333N	PARTICIPANT	\N	PRESENT	0
352127	350700	19383Y	PARTICIPANT	\N	PRESENT	0
352128	350700	17583W	PARTICIPANT	\N	PRESENT	0
352129	350700	19701S	PARTICIPANT	\N	PRESENT	0
352130	350700	19794Q	PARTICIPANT	\N	PRESENT	0
352131	350700	19387D	PARTICIPANT	\N	PRESENT	0
352132	350700	14219Q	PARTICIPANT	\N	PRESENT	0
352133	350700	14221J	PARTICIPANT	\N	PRESENT	0
352134	350700	19599P	PARTICIPANT	\N	PRESENT	0
352135	350700	19551W	PARTICIPANT	\N	PRESENT	0
352136	350700	18083K	PARTICIPANT	\N	PRESENT	0
352137	350700	14237S	PARTICIPANT	\N	PRESENT	0
352138	350700	05012A	PARTICIPANT	\N	PRESENT	0
352139	350700	14051J	PARTICIPANT	\N	PRESENT	0
352140	350700	19503N	PARTICIPANT	\N	PRESENT	0
352141	350700	96004D	PARTICIPANT	\N	PRESENT	0
352142	350700	08024S	PARTICIPANT	\N	PRESENT	0
352143	350700	19525U	PARTICIPANT	\N	PRESENT	0
352144	350700	14038Y	PARTICIPANT	\N	PRESENT	0
352145	350700	14031R	PARTICIPANT	\N	PRESENT	0
352146	350700	14169X	PARTICIPANT	\N	PRESENT	0
352147	350700	15447F	PARTICIPANT	\N	PRESENT	0
352148	350700	19733B	PARTICIPANT	\N	PRESENT	0
352149	350700	19737F	PARTICIPANT	\N	PRESENT	0
352150	350700	04097T	PARTICIPANT	\N	PRESENT	0
352151	350700	19739H	PARTICIPANT	\N	PRESENT	0
352159	350213	14081Q	PARTICIPANT	\N	PRESENT	0
352160	350213	08015R	PARTICIPANT	\N	PRESENT	0
352161	350213	19563B	PARTICIPANT	\N	PRESENT	0
352162	350213	08038Y	PARTICIPANT	\N	PRESENT	0
352163	350213	19695N	PARTICIPANT	\N	PRESENT	0
352164	350213	19507S	PARTICIPANT	\N	PRESENT	0
352165	350213	04043D	PARTICIPANT	\N	PRESENT	0
352166	350213	14197C	PARTICIPANT	\N	EXCUSE	0
352167	350213	19295A	PARTICIPANT	\N	EXCUSE	0
352168	350213	08021P	PARTICIPANT	\N	EXCUSE	0
352169	350213	11081P	PARTICIPANT	\N	EXCUSE	0
352170	350213	19619A	PARTICIPANT	\N	EXCUSE	0
352171	350700	80027E	PARTICIPANT	\N	PRESENT	0
352172	350700	17637T	PARTICIPANT	\N	PRESENT	0
352173	350700	14093U	PARTICIPANT	\N	PRESENT	0
352174	350700	08051V	PARTICIPANT	\N	PRESENT	0
352176	350700	11065P	PARTICIPANT	\N	PRESENT	0
352177	350765	08034U	PARTICIPANT	\N	PRESENT	0
352178	350700	19637C	PARTICIPANT	\N	PRESENT	0
352179	350812	04045F	PARTICIPANT	\N	PRESENT	0
352182	350700	19713W	PARTICIPANT	\N	PRESENT	0
352183	350700	04085P	PARTICIPANT	\N	PRESENT	0
352184	350765	14034U	PARTICIPANT	\N	PRESENT	0
352185	350765	08011M	PARTICIPANT	\N	PRESENT	0
352186	350700	02002K	PARTICIPANT	\N	PRESENT	0
352187	351930	08035V	PARTICIPANT	\N	PRESENT	0
352188	351930	11043H	PARTICIPANT	\N	PRESENT	0
352189	350765	89017R	PARTICIPANT	\N	PRESENT	0
352191	351930	14109K	PARTICIPANT	\N	PRESENT	0
352192	351930	14123H	PARTICIPANT	\N	PRESENT	0
352193	350556	19421M	PARTICIPANT	\N	PRESENT	0
352194	350556	98018T	PARTICIPANT	\N	EXCUSE	0
352197	352196	19760E	PARTICIPANT	\N	PRESENT	0
352198	352196	08055A	PARTICIPANT	\N	PRESENT	0
352202	352196	19782L	PARTICIPANT	\N	PRESENT	0
352200	352196	19383Y	PARTICIPANT	\N	PRESENT	0
352201	352196	04047H	PARTICIPANT	\N	PRESENT	0
352203	352196	14207L	PARTICIPANT	\N	PRESENT	0
352204	352196	11103C	PARTICIPANT	\N	PRESENT	0
352205	352196	14329V	PARTICIPANT	\N	PRESENT	0
352206	352196	19467C	PARTICIPANT	\N	PRESENT	0
352207	352196	18083K	PARTICIPANT	\N	PRESENT	0
352208	352196	14357A	PARTICIPANT	\N	PRESENT	0
352209	352196	17589D	PARTICIPANT	\N	PRESENT	0
352210	352196	14187A	PARTICIPANT	\N	PRESENT	0
352211	352196	14097Y	PARTICIPANT	\N	PRESENT	0
352212	352196	19723Y	PARTICIPANT	\N	PRESENT	0
352213	352196	16685X	PARTICIPANT	\N	PRESENT	0
352214	352196	14059S	PARTICIPANT	\N	PRESENT	0
352215	352196	14103D	PARTICIPANT	\N	PRESENT	0
352216	352196	08053X	PARTICIPANT	\N	PRESENT	0
352217	352196	19563B	PARTICIPANT	\N	PRESENT	0
352218	352196	14109K	PARTICIPANT	\N	PRESENT	0
352219	352196	14169X	PARTICIPANT	\N	PRESENT	0
352220	352196	08061X	PARTICIPANT	\N	PRESENT	0
352221	352196	04088S	PARTICIPANT	\N	PRESENT	0
352222	352196	98050T	PARTICIPANT	\N	PRESENT	0
352223	352196	19739H	PARTICIPANT	\N	PRESENT	0
352225	352196	17583W	PARTICIPANT	\N	PRESENT	0
352226	352196	19679N	PARTICIPANT	\N	PRESENT	0
352227	352196	14331P	PARTICIPANT	\N	PRESENT	0
352228	352196	14107H	PARTICIPANT	\N	PRESENT	0
352229	352196	95067Q	PARTICIPANT	\N	PRESENT	0
352230	352196	14173T	PARTICIPANT	\N	PRESENT	0
352250	352249	19723Y	PARTICIPANT	\N	PRESENT	0
352251	351798	14065Q	PARTICIPANT	\N	PRESENT	0
352252	351798	08045X	PARTICIPANT	\N	PRESENT	0
352253	351798	10015M	PARTICIPANT	\N	PRESENT	0
352254	351798	01024M	PARTICIPANT	\N	PRESENT	0
352255	351798	19581D	PARTICIPANT	\N	PRESENT	0
352256	351798	04044E	PARTICIPANT	\N	PRESENT	0
352257	351798	19673G	PARTICIPANT	\N	PRESENT	0
352258	351798	19719D	PARTICIPANT	\N	PRESENT	0
352259	351798	01028R	PARTICIPANT	\N	PRESENT	0
352260	351798	11033F	PARTICIPANT	\N	PRESENT	0
352261	351798	14231L	PARTICIPANT	\N	PRESENT	0
352262	351798	05008E	PRESIDENT	1	PRESENT	0
352263	351798	19447X	PARTICIPANT	\N	PRESENT	0
352264	351798	19725B	PARTICIPANT	\N	PRESENT	0
352265	351798	08044W	PARTICIPANT	\N	PRESENT	0
352266	351798	14179A	PARTICIPANT	\N	PRESENT	0
352267	351798	14147R	PARTICIPANT	\N	PRESENT	0
352268	351798	14151M	PARTICIPANT	\N	PRESENT	0
352269	351798	14215L	PARTICIPANT	\N	PRESENT	0
352270	351798	11072N	PARTICIPANT	\N	PRESENT	0
352271	351798	14053L	PARTICIPANT	\N	PRESENT	0
352272	351798	98035U	PARTICIPANT	\N	PRESENT	0
352273	351798	19649G	PARTICIPANT	\N	PRESENT	0
352274	351798	14111D	PARTICIPANT	\N	PRESENT	0
352275	351798	11010L	PARTICIPANT	\N	PRESENT	0
352276	351798	07034Q	PARTICIPANT	\N	PRESENT	0
352277	351798	11026G	PARTICIPANT	\N	PRESENT	0
352278	351798	14001X	PARTICIPANT	\N	PRESENT	0
352279	351798	01060R	PARTICIPANT	\N	PRESENT	0
352280	351798	19543W	PARTICIPANT	\N	PRESENT	0
352281	351798	04038G	PARTICIPANT	\N	PRESENT	0
352282	351798	04047H	PRESIDENT	0	PRESENT	0
352283	351798	14089Y	PARTICIPANT	\N	PRESENT	0
333598	333597	14001X	PARTICIPANT	\N	PRESENT	0
333599	333597	14215L	PARTICIPANT	\N	PRESENT	0
333854	333850	11048N	PARTICIPANT	\N	PRESENT	0
333859	333857	11048N	PARTICIPANT	\N	PRESENT	0
335658	335657	04008A	PARTICIPANT	\N	PRESENT	0
335659	335657	95063L	PARTICIPANT	\N	PRESENT	0
335679	335678	07034Q	PARTICIPANT	\N	PRESENT	0
335680	335678	19729F	PARTICIPANT	\N	PRESENT	0
335681	335678	01028R	PARTICIPANT	\N	PRESENT	0
335682	335678	95063L	PARTICIPANT	\N	PRESENT	0
335683	335678	14179A	PARTICIPANT	\N	PRESENT	0
335692	335691	19521Q	PARTICIPANT	\N	PRESENT	0
335699	335698	04049K	PARTICIPANT	\N	PRESENT	0
335694	335691	14157T	PARTICIPANT	\N	PRESENT	0
335696	335695	14083S	PARTICIPANT	\N	PRESENT	0
335697	335691	14083S	PARTICIPANT	\N	PRESENT	0
335701	335700	04049K	PARTICIPANT	\N	PRESENT	0
335702	335700	14083S	PARTICIPANT	\N	PRESENT	0
338182	337674	08018U	PARTICIPANT	\N	EXCUSE	0
338183	337674	14135M	PARTICIPANT	\N	EXCUSE	0
338184	337674	14065Q	PARTICIPANT	\N	EXCUSE	0
338185	337674	08014Q	PARTICIPANT	\N	EXCUSE	0
338186	337674	04061F	PARTICIPANT	\N	EXCUSE	0
338187	337701	14065Q	PARTICIPANT	\N	EXCUSE	0
338188	337701	08014Q	PARTICIPANT	\N	EXCUSE	0
338189	337701	08018U	PARTICIPANT	\N	EXCUSE	0
338190	337701	04061F	PARTICIPANT	\N	EXCUSE	0
338191	337701	14135M	PARTICIPANT	\N	EXCUSE	0
338192	337701	14061L	PARTICIPANT	\N	EXCUSE	0
338193	337674	14061L	PARTICIPANT	\N	EXCUSE	0
338199	338198	11074Q	PARTICIPANT	\N	PRESENT	0
338200	338198	08045X	PARTICIPANT	\N	PRESENT	0
342036	331577	04059M	PARTICIPANT	\N	PRESENT	0
342037	331577	19693L	PARTICIPANT	\N	PRESENT	0
342038	331577	07033P	PARTICIPANT	\N	PRESENT	0
342040	331577	14241N	PARTICIPANT	\N	PRESENT	0
342041	331577	08043V	PARTICIPANT	\N	PRESENT	0
342042	331577	11083R	PARTICIPANT	\N	PRESENT	0
342043	342039	19713W	PARTICIPANT	\N	PRESENT	0
342044	331577	19758L	PARTICIPANT	\N	PRESENT	0
342045	342039	19637C	PARTICIPANT	\N	PRESENT	0
342046	342039	14029X	PARTICIPANT	\N	PRESENT	0
342047	331577	14073Q	PARTICIPANT	\N	PRESENT	0
342048	342039	19681G	PARTICIPANT	\N	PRESENT	0
342050	342039	19525U	PARTICIPANT	\N	PRESENT	0
342049	331577	19699S	PARTICIPANT	\N	PRESENT	0
342051	342039	19333N	PARTICIPANT	\N	PRESENT	0
342052	331577	08039A	PARTICIPANT	\N	PRESENT	0
342053	342039	08009T	PARTICIPANT	\N	PRESENT	0
342054	331577	04057K	PARTICIPANT	\N	PRESENT	0
342055	331577	19335Q	PARTICIPANT	\N	PRESENT	0
342056	342039	14038Y	PARTICIPANT	\N	PRESENT	0
342057	331577	04070G	PARTICIPANT	\N	PRESENT	0
342058	331577	14229S	PARTICIPANT	\N	PRESENT	0
342074	331577	19573D	PARTICIPANT	\N	PRESENT	0
342075	331577	19735D	PARTICIPANT	\N	PRESENT	0
342101	331577	14039A	PARTICIPANT	\N	PRESENT	0
342102	342100	19525U	PARTICIPANT	\N	PRESENT	0
342103	342100	14038Y	PARTICIPANT	\N	PRESENT	0
342104	342100	08009T	PARTICIPANT	\N	PRESENT	0
342108	342107	19551W	PARTICIPANT	\N	PRESENT	0
342109	342107	14031R	PARTICIPANT	\N	PRESENT	0
342110	342107	19737F	PARTICIPANT	\N	PRESENT	0
342112	342111	19551W	PARTICIPANT	\N	PRESENT	0
342113	342111	19289C	PARTICIPANT	\N	PRESENT	0
342114	342111	14031R	PARTICIPANT	\N	PRESENT	0
342115	342111	19737F	PARTICIPANT	\N	PRESENT	0
342117	342116	19549D	PARTICIPANT	\N	PRESENT	0
342118	342116	19737F	PARTICIPANT	\N	PRESENT	0
342119	342116	14157T	PARTICIPANT	\N	PRESENT	0
342120	342116	14031R	PARTICIPANT	\N	PRESENT	0
342121	342116	14053L	PARTICIPANT	\N	PRESENT	0
342123	342122	19549D	PARTICIPANT	\N	PRESENT	0
342124	342122	14031R	PARTICIPANT	\N	PRESENT	0
342130	342129	14065Q	PARTICIPANT	\N	EXCUSE	0
342131	342129	96004D	PRESIDENT	0	PRESENT	0
342132	342129	14089Y	PARTICIPANT	\N	PRESENT	0
342133	342129	08014Q	PARTICIPANT	\N	EXCUSE	0
342134	342129	14357A	PARTICIPANT	\N	PRESENT	0
342135	342129	14079W	PARTICIPANT	\N	PRESENT	0
342136	342129	14249W	PARTICIPANT	\N	PRESENT	0
342137	342129	14033T	PARTICIPANT	\N	EXCUSE	0
342138	342129	19725B	PARTICIPANT	\N	PRESENT	0
342139	342129	14097Y	PARTICIPANT	\N	PRESENT	0
342140	342129	04061F	PARTICIPANT	\N	PRESENT	0
342141	342129	14073Q	PARTICIPANT	\N	PRESENT	0
342142	342129	11026G	PARTICIPANT	\N	PRESENT	0
342143	342129	14237S	PARTICIPANT	\N	PRESENT	0
342144	342129	04057K	PARTICIPANT	\N	EXCUSE	0
342145	342129	10015M	PARTICIPANT	\N	PRESENT	0
342146	342129	98035U	PARTICIPANT	\N	PRESENT	0
342229	342222	96004D	PRESIDENT	0	PRESENT	0
342275	342222	14133K	PARTICIPANT	\N	PRESENT	0
342276	342222	14255U	PARTICIPANT	\N	PRESENT	0
342277	342222	04042C	PARTICIPANT	\N	EXCUSE	0
342285	342222	04035D	PARTICIPANT	\N	PRESENT	0
342289	342222	98050T	PRESIDENT	1	PRESENT	0
342292	342222	01062T	PARTICIPANT	\N	PRESENT	0
342328	342222	04097T	PARTICIPANT	\N	PRESENT	0
342331	342222	04061F	PARTICIPANT	\N	PRESENT	0
342333	342222	14073Q	PARTICIPANT	\N	PRESENT	0
342337	342222	04057K	PARTICIPANT	\N	PRESENT	0
342341	342222	19251M	PARTICIPANT	\N	PRESENT	0
342346	342222	19421M	PARTICIPANT	\N	PRESENT	0
342499	342498	98050T	PARTICIPANT	\N	PRESENT	0
342500	342498	01062T	PARTICIPANT	\N	PRESENT	0
342501	342498	14079W	PARTICIPANT	\N	PRESENT	0
342505	342504	14205J	PARTICIPANT	\N	PRESENT	0
342506	342504	08055A	PARTICIPANT	\N	PRESENT	0
342507	342504	19725B	PARTICIPANT	\N	PRESENT	0
342508	342504	19745F	PARTICIPANT	\N	PRESENT	0
342942	340438	19631V	PARTICIPANT	\N	EXCUSE	0
342943	340438	14038Y	PARTICIPANT	\N	EXCUSE	0
342944	340438	11010L	PARTICIPANT	\N	EXCUSE	0
342945	340438	14021P	PARTICIPANT	\N	EXCUSE	0
342946	340438	98005N	PARTICIPANT	\N	EXCUSE	0
342947	340438	14219Q	PARTICIPANT	\N	EXCUSE	0
342948	340438	14277B	PARTICIPANT	\N	EXCUSE	0
342949	340438	12016W	PARTICIPANT	\N	EXCUSE	0
342950	340438	19319Q	PARTICIPANT	\N	EXCUSE	0
342951	340438	19657G	PARTICIPANT	\N	EXCUSE	0
342952	340438	14157T	PARTICIPANT	\N	EXCUSE	0
342953	340438	19703U	PARTICIPANT	\N	EXCUSE	0
342954	340438	04043D	PARTICIPANT	\N	EXCUSE	0
342955	340438	14225N	PARTICIPANT	\N	EXCUSE	0
342956	340438	14033T	PARTICIPANT	\N	EXCUSE	0
342957	340438	14199E	PARTICIPANT	\N	EXCUSE	0
344993	344992	19421M	PARTICIPANT	\N	PRESENT	0
344994	344992	14028W	PARTICIPANT	\N	PRESENT	0
344995	344992	04040A	PARTICIPANT	\N	PRESENT	0
344996	344992	11064N	PARTICIPANT	\N	PRESENT	0
344997	344980	11067R	PARTICIPANT	\N	PRESENT	0
344998	344980	19749K	PARTICIPANT	\N	PRESENT	0
344999	344980	10006L	PRESIDENT	0	PRESENT	0
345000	344980	19447X	PARTICIPANT	\N	PRESENT	0
345001	344980	14030Q	PARTICIPANT	\N	PRESENT	0
345002	344980	08031R	PARTICIPANT	\N	PRESENT	0
345004	345003	96004D	PRESIDENT	0	PRESENT	0
345005	345003	14089Y	PARTICIPANT	\N	PRESENT	0
345006	345003	14079W	PARTICIPANT	\N	PRESENT	0
345007	345003	95037J	PARTICIPANT	\N	PRESENT	0
345008	345003	14097Y	PARTICIPANT	\N	PRESENT	0
345009	345003	04061F	PARTICIPANT	\N	PRESENT	0
345010	345003	14061L	PARTICIPANT	\N	PRESENT	0
345011	345003	14073Q	PARTICIPANT	\N	PRESENT	0
345012	345003	14205J	PARTICIPANT	\N	PRESENT	0
345013	345003	14001X	PARTICIPANT	\N	PRESENT	0
345014	345003	14135M	PARTICIPANT	\N	PRESENT	0
345015	345003	98035U	PARTICIPANT	\N	PRESENT	0
345016	345003	14331P	PARTICIPANT	\N	EXCUSE	0
345017	345003	04057K	PARTICIPANT	\N	EXCUSE	0
345018	345003	11026G	PARTICIPANT	\N	EXCUSE	0
345019	345003	11083R	PARTICIPANT	\N	EXCUSE	0
345020	345003	14065Q	PARTICIPANT	\N	EXCUSE	0
345022	345021	08069G	PARTICIPANT	\N	PRESENT	0
345024	345023	08014Q	PARTICIPANT	\N	PRESENT	0
345025	344980	01028R	PARTICIPANT	\N	PRESENT	0
345026	344980	08043V	PARTICIPANT	\N	EXCUSE	0
345027	344980	19295A	PARTICIPANT	\N	EXCUSE	0
345028	344980	19621T	PARTICIPANT	\N	EXCUSE	0
345030	345029	19533U	PARTICIPANT	\N	PRESENT	0
345032	344980	14147R	PARTICIPANT	\N	EXCUSE	0
345035	339509	11027H	PARTICIPANT	\N	PRESENT	0
345037	339509	19731Y	PARTICIPANT	\N	PRESENT	0
345038	339509	19629C	PARTICIPANT	\N	PRESENT	0
345039	339509	19585H	PARTICIPANT	\N	PRESENT	0
345040	339509	19583F	PARTICIPANT	\N	PRESENT	0
345041	339509	19489J	PARTICIPANT	\N	PRESENT	0
345042	339509	04038G	PARTICIPANT	\N	PRESENT	0
350246	350221	19527W	PARTICIPANT	\N	PRESENT	0
350247	350221	95067Q	PRESIDENT	0	PRESENT	0
350561	348023	14069U	PARTICIPANT	\N	PRESENT	0
350560	348023	04040A	PARTICIPANT	\N	PRESENT	0
350562	348023	14195A	PARTICIPANT	\N	PRESENT	0
350563	348023	14327T	PARTICIPANT	\N	PRESENT	0
350564	348023	14281W	PARTICIPANT	\N	PRESENT	0
350565	348023	14231L	PARTICIPANT	\N	PRESENT	0
350566	348023	01057W	PARTICIPANT	\N	PRESENT	0
350567	348023	11048N	PARTICIPANT	\N	PRESENT	0
350568	348023	08034U	PARTICIPANT	\N	PRESENT	0
350569	348023	14103D	PARTICIPANT	\N	PRESENT	0
350570	348023	14257W	PARTICIPANT	\N	PRESENT	0
350571	348023	05012A	PARTICIPANT	\N	PRESENT	0
350604	350049	19713W	PARTICIPANT	\N	PRESENT	0
350573	348023	19735D	PARTICIPANT	\N	PRESENT	0
350574	348023	08049C	PARTICIPANT	\N	PRESENT	0
350603	350049	14051J	PARTICIPANT	\N	PRESENT	0
350605	350049	08009T	PARTICIPANT	\N	PRESENT	0
350606	350049	19637C	PARTICIPANT	\N	PRESENT	0
350664	350662	08053X	PARTICIPANT	\N	PRESENT	0
350608	350049	95062K	PARTICIPANT	\N	PRESENT	0
350609	350049	19525U	PARTICIPANT	\N	PRESENT	0
350663	350662	14255U	PARTICIPANT	\N	PRESENT	0
350688	350686	19729F	PARTICIPANT	\N	EXCUSE	0
350767	350766	14187A	PARTICIPANT	\N	PRESENT	0
350769	350768	11101A	PARTICIPANT	\N	PRESENT	0
350770	350768	14187A	PARTICIPANT	\N	PRESENT	0
350773	350772	14187A	PARTICIPANT	\N	PRESENT	0
350807	332565	11065P	PARTICIPANT	\N	EXCUSE	0
350808	332565	01028R	PARTICIPANT	\N	EXCUSE	0
350809	332565	14147R	PARTICIPANT	\N	PRESENT	0
350810	332565	08012N	PARTICIPANT	\N	EXCUSE	0
350811	332565	19369B	PARTICIPANT	\N	PRESENT	0
350816	332565	19515S	PARTICIPANT	\N	EXCUSE	0
350819	332565	08062Y	PARTICIPANT	\N	EXCUSE	0
350821	350815	14033T	PARTICIPANT	\N	PRESENT	0
350822	350820	14205J	PARTICIPANT	\N	PRESENT	0
350823	350814	14033T	PARTICIPANT	\N	PRESENT	0
350825	350824	19681G	PARTICIPANT	\N	PRESENT	0
350827	350826	19415P	PARTICIPANT	\N	PRESENT	0
350828	350826	11067R	PARTICIPANT	\N	PRESENT	0
350830	350829	19415P	PARTICIPANT	\N	PRESENT	0
350831	350829	11067R	PARTICIPANT	\N	PRESENT	0
350833	350832	19415P	PARTICIPANT	\N	PRESENT	0
350834	350832	11067R	PARTICIPANT	\N	PRESENT	0
350836	350835	19415P	PARTICIPANT	\N	PRESENT	0
350837	350835	11067R	PARTICIPANT	\N	PRESENT	0
350841	350840	04092N	PARTICIPANT	\N	PRESENT	0
350844	350842	04092N	PARTICIPANT	\N	PRESENT	0
350867	348095	14063N	PARTICIPANT	\N	EXCUSE	0
350868	348095	14028W	PARTICIPANT	\N	EXCUSE	0
350985	348095	14231L	PARTICIPANT	\N	EXCUSE	0
352295	350556	08058D	PARTICIPANT	\N	EXCUSE	0
352296	350556	98022P	PARTICIPANT	\N	EXCUSE	0
352297	350556	19583F	PARTICIPANT	\N	EXCUSE	0
352298	350556	14235Q	PARTICIPANT	\N	EXCUSE	0
352299	350556	11054L	PARTICIPANT	\N	EXCUSE	0
352506	352504	14133K	PARTICIPANT	\N	PRESENT	0
352507	352504	96004D	PRESIDENT	0	PRESENT	0
352508	352504	14255U	PARTICIPANT	\N	PRESENT	0
352509	352504	04042C	PRESIDENT	1	PRESENT	0
352510	352504	19251M	PARTICIPANT	\N	PRESENT	0
352511	352504	04035D	PARTICIPANT	\N	PRESENT	0
352512	352504	04097T	PARTICIPANT	\N	PRESENT	0
352513	352504	04061F	PARTICIPANT	\N	PRESENT	0
352514	352504	14073Q	PARTICIPANT	\N	PRESENT	0
352515	352504	14001X	PARTICIPANT	\N	PRESENT	0
352516	352504	04057K	PARTICIPANT	\N	EXCUSE	0
352517	352504	98050T	PARTICIPANT	\N	PRESENT	0
352518	352504	04034C	PARTICIPANT	\N	PRESENT	0
352529	352528	07033P	PARTICIPANT	\N	PRESENT	0
352530	352528	19551W	PARTICIPANT	\N	PRESENT	0
352531	352528	14059S	PARTICIPANT	\N	PRESENT	0
352736	352729	19611R	PARTICIPANT	\N	PRESENT	0
352737	352729	14241N	PARTICIPANT	\N	PRESENT	0
352739	352729	19758L	PARTICIPANT	\N	PRESENT	0
352740	352729	08043V	PARTICIPANT	\N	PRESENT	0
352750	352749	19621T	PARTICIPANT	\N	PRESENT	0
352751	352749	19611R	PARTICIPANT	\N	PRESENT	0
352752	352749	19533U	PARTICIPANT	\N	PRESENT	0
352753	352749	14229S	PARTICIPANT	\N	PRESENT	0
352754	352749	14109K	PARTICIPANT	\N	PRESENT	0
352755	352749	19693L	PARTICIPANT	\N	PRESENT	0
352817	352815	19643A	PARTICIPANT	\N	PRESENT	0
352818	352815	14229S	PARTICIPANT	\N	PRESENT	0
352819	352815	07033P	PARTICIPANT	\N	PRESENT	0
352820	352815	04057K	PARTICIPANT	\N	PRESENT	0
352821	352815	04070G	PARTICIPANT	\N	PRESENT	0
352822	352815	14039A	PARTICIPANT	\N	PRESENT	0
352823	352815	19735D	PARTICIPANT	\N	PRESENT	0
352824	352815	04018C	PARTICIPANT	\N	PRESENT	0
352825	352815	92040Q	PARTICIPANT	\N	PRESENT	0
352826	352815	11109J	PARTICIPANT	\N	PRESENT	0
352837	352836	19399H	PARTICIPANT	\N	PRESENT	0
352838	352836	14039A	PARTICIPANT	\N	PRESENT	0
352839	352836	14229S	PARTICIPANT	\N	PRESENT	0
352840	352836	04057K	PARTICIPANT	\N	PRESENT	0
352841	352836	19593H	PARTICIPANT	\N	PRESENT	0
352842	352836	08043V	PARTICIPANT	\N	PRESENT	0
352940	352937	11043H	PARTICIPANT	\N	PRESENT	0
352941	352937	14073Q	PARTICIPANT	\N	PRESENT	0
352942	352937	08012N	PARTICIPANT	\N	PRESENT	0
352944	352937	14107H	PARTICIPANT	\N	PRESENT	0
352946	352937	14063N	PARTICIPANT	\N	PRESENT	0
352947	352937	14241N	PARTICIPANT	\N	PRESENT	0
352949	352937	87003B	PARTICIPANT	\N	PRESENT	0
352951	352937	19711U	PARTICIPANT	\N	PRESENT	0
353676	353675	98050T	PARTICIPANT	\N	PRESENT	0
353677	353675	01062T	PARTICIPANT	\N	PRESENT	0
353679	353678	01062T	PARTICIPANT	\N	PRESENT	0
353680	353678	14079W	PARTICIPANT	\N	PRESENT	0
353682	353681	98050T	PARTICIPANT	\N	PRESENT	0
353683	353681	14079W	PARTICIPANT	\N	PRESENT	0
353731	353730	19667J	PARTICIPANT	\N	PRESENT	0
353732	353730	19643A	PARTICIPANT	\N	PRESENT	0
353733	353730	19467C	PARTICIPANT	\N	PRESENT	0
353734	353730	19507S	PARTICIPANT	\N	PRESENT	0
353735	353730	19511N	PARTICIPANT	\N	PRESENT	0
353736	353730	16685X	PARTICIPANT	\N	PRESENT	0
353737	353730	19441R	PARTICIPANT	\N	PRESENT	0
353738	353730	14265W	PARTICIPANT	\N	PRESENT	0
353739	353730	19745F	PARTICIPANT	\N	PRESENT	0
353740	353730	14135M	PARTICIPANT	\N	PRESENT	0
353742	353741	14093U	PARTICIPANT	\N	PRESENT	0
353743	353741	19387D	PARTICIPANT	\N	PRESENT	0
353744	353741	19347U	PARTICIPANT	\N	PRESENT	0
353745	353741	19637C	PARTICIPANT	\N	PRESENT	0
353746	353741	19713W	PARTICIPANT	\N	PRESENT	0
353747	353741	14051J	PARTICIPANT	\N	PRESENT	0
353758	352373	19563B	PRESIDENT	0	PRESENT	0
353759	352373	19575F	PARTICIPANT	\N	EXCUSE	0
353917	353884	14275Y	PARTICIPANT	\N	PRESENT	0
353916	353884	19583F	PARTICIPANT	\N	PRESENT	0
353918	353884	14073Q	PARTICIPANT	\N	PRESENT	0
353919	353884	19511N	PARTICIPANT	\N	PRESENT	0
353920	353884	08052W	PARTICIPANT	\N	PRESENT	0
353921	353884	11033F	PARTICIPANT	\N	PRESENT	0
353922	353884	19383Y	PARTICIPANT	\N	PRESENT	0
353924	353884	11066Q	PARTICIPANT	\N	PRESENT	0
353925	353884	04089T	PARTICIPANT	\N	PRESENT	0
353926	353884	19399H	PARTICIPANT	\N	PRESENT	0
353927	353884	14041T	PARTICIPANT	\N	PRESENT	0
353928	353884	15447F	PARTICIPANT	\N	PRESENT	0
353929	353884	14173T	PARTICIPANT	\N	PRESENT	0
353930	353884	14329V	PARTICIPANT	\N	PRESENT	0
353931	353884	19675J	PARTICIPANT	\N	PRESENT	0
353932	353884	19659J	PARTICIPANT	\N	PRESENT	0
353934	353884	19683J	PARTICIPANT	\N	PRESENT	0
353935	353884	19701S	PARTICIPANT	\N	PRESENT	0
353937	353884	19503N	PARTICIPANT	\N	PRESENT	0
353938	353884	08053X	PARTICIPANT	\N	PRESENT	0
353939	353884	17779H	PARTICIPANT	\N	PRESENT	0
353940	353884	11090Q	PARTICIPANT	\N	PRESENT	0
353941	353884	14277B	PARTICIPANT	\N	PRESENT	0
353942	353884	19794Q	PARTICIPANT	\N	PRESENT	0
353943	353884	88008L	PARTICIPANT	\N	PRESENT	0
353944	353884	19581D	PARTICIPANT	\N	PRESENT	0
353945	353884	19768N	PARTICIPANT	\N	PRESENT	0
353946	353884	19782L	PARTICIPANT	\N	PRESENT	0
353947	353884	14111D	PARTICIPANT	\N	PRESENT	0
353948	353884	14089Y	PARTICIPANT	\N	PRESENT	0
353949	353884	14357A	PARTICIPANT	\N	PRESENT	0
353950	353884	19681G	PARTICIPANT	\N	PRESENT	0
353951	353884	19619A	PARTICIPANT	\N	PRESENT	0
353952	353884	19387D	PARTICIPANT	\N	PRESENT	0
353953	353884	08019V	PARTICIPANT	\N	PRESENT	0
339583	339505	01024M	PARTICIPANT	\N	PRESENT	0
339584	339505	11033F	PARTICIPANT	\N	PRESENT	0
339585	339505	19729F	PARTICIPANT	\N	PRESENT	0
339586	339505	95063L	PARTICIPANT	\N	PRESENT	0
339587	339505	19629C	PARTICIPANT	\N	PRESENT	0
339588	339505	11085T	PARTICIPANT	\N	PRESENT	0
339589	339505	04008A	PARTICIPANT	\N	PRESENT	0
339590	339505	19762G	PARTICIPANT	\N	PRESENT	0
339591	339505	19725B	PARTICIPANT	\N	EXCUSE	0
339592	339505	08044W	PARTICIPANT	\N	EXCUSE	0
339593	339505	04044E	PARTICIPANT	\N	EXCUSE	0
339598	337742	14097Y	PARTICIPANT	\N	PRESENT	0
339599	337742	14105F	PARTICIPANT	\N	PRESENT	0
339600	337742	14193X	PARTICIPANT	\N	PRESENT	0
339601	337742	04042C	PRESIDENT	0	PRESENT	0
339602	337742	11054L	PARTICIPANT	\N	PRESENT	0
339603	337742	08053X	PARTICIPANT	\N	PRESENT	0
339604	337742	08047A	PARTICIPANT	\N	PRESENT	0
339605	337742	95037J	PARTICIPANT	\N	PRESENT	0
339606	337742	04034C	PARTICIPANT	\N	PRESENT	0
339607	337742	08061X	PARTICIPANT	\N	PRESENT	0
339636	337095	14331P	PARTICIPANT	\N	PRESENT	0
339609	337742	19721W	PARTICIPANT	\N	PRESENT	0
339610	339505	19489J	PARTICIPANT	\N	PRESENT	0
339611	339505	98035U	PARTICIPANT	\N	PRESENT	0
339612	339505	14089Y	PARTICIPANT	\N	PRESENT	0
339613	339505	14069U	PARTICIPANT	\N	PRESENT	0
339614	337742	98005N	PARTICIPANT	\N	PRESENT	0
339615	337742	19443T	PARTICIPANT	\N	PRESENT	0
339616	337742	12041X	PARTICIPANT	\N	PRESENT	0
339617	337742	11080N	PARTICIPANT	\N	PRESENT	0
339618	337742	14079W	PARTICIPANT	\N	PRESENT	0
339619	337742	04040A	PARTICIPANT	\N	PRESENT	0
339620	337742	16685X	PARTICIPANT	\N	PRESENT	0
339621	337742	11066Q	PARTICIPANT	\N	PRESENT	0
339622	337742	19421M	PARTICIPANT	\N	PRESENT	0
339623	337742	19709B	PARTICIPANT	\N	PRESENT	0
339624	337742	97011G	PARTICIPANT	\N	PRESENT	0
339625	337742	01062T	PARTICIPANT	\N	PRESENT	0
339626	337742	14133K	PARTICIPANT	\N	PRESENT	0
339627	337742	08058D	PARTICIPANT	\N	PRESENT	0
339628	337742	19251M	PARTICIPANT	\N	PRESENT	0
339629	337742	98022P	PARTICIPANT	\N	PRESENT	0
339630	337742	14267Y	PARTICIPANT	\N	PRESENT	0
339631	337742	11064N	PARTICIPANT	\N	PRESENT	0
339632	337742	11027H	PARTICIPANT	\N	PRESENT	0
339633	337742	01058X	PARTICIPANT	\N	PRESENT	0
339634	337742	14028W	PARTICIPANT	\N	PRESENT	0
339635	337742	14255U	PARTICIPANT	\N	PRESENT	0
339637	337095	19549D	PARTICIPANT	\N	PRESENT	0
339638	337095	80027E	PARTICIPANT	\N	PRESENT	0
339639	337095	08015R	PARTICIPANT	\N	PRESENT	0
339640	337095	14053L	PARTICIPANT	\N	PRESENT	0
339642	337095	14083S	PARTICIPANT	\N	PRESENT	0
339643	337095	19733B	PARTICIPANT	\N	PRESENT	0
339644	337742	04035D	PARTICIPANT	\N	PRESENT	0
339645	337742	19669L	PARTICIPANT	\N	PRESENT	0
339646	337742	98029W	PARTICIPANT	\N	PRESENT	0
339647	337742	95067Q	PARTICIPANT	\N	PRESENT	0
339695	337743	98005N	PARTICIPANT	\N	PRESENT	0
339696	337743	19443T	PARTICIPANT	\N	PRESENT	0
339697	337743	12041X	PARTICIPANT	\N	PRESENT	0
339698	337743	11080N	PARTICIPANT	\N	PRESENT	0
339699	337743	04034C	PARTICIPANT	\N	PRESENT	0
339700	337743	14079W	PARTICIPANT	\N	PRESENT	0
339701	337743	04040A	PARTICIPANT	\N	PRESENT	0
339702	337743	01058X	PARTICIPANT	\N	PRESENT	0
339703	337743	16685X	PARTICIPANT	\N	PRESENT	0
339704	337743	11027H	PARTICIPANT	\N	PRESENT	0
339705	337743	04042C	PRESIDENT	0	PRESENT	0
339706	337743	11054L	PARTICIPANT	\N	PRESENT	0
339707	337743	11066Q	PARTICIPANT	\N	PRESENT	0
339708	337743	19669L	PARTICIPANT	\N	PRESENT	0
339709	337743	95037J	PARTICIPANT	\N	PRESENT	0
339710	337743	19421M	PARTICIPANT	\N	PRESENT	0
339711	337743	19709B	PARTICIPANT	\N	PRESENT	0
339712	337743	14193X	PARTICIPANT	\N	PRESENT	0
339713	337743	08053X	PARTICIPANT	\N	PRESENT	0
339714	337743	08061X	PARTICIPANT	\N	PRESENT	0
339715	337743	97011G	PARTICIPANT	\N	PRESENT	0
339716	337743	08047A	PARTICIPANT	\N	PRESENT	0
339717	337743	98029W	PARTICIPANT	\N	PRESENT	0
339718	337743	14097Y	PARTICIPANT	\N	PRESENT	0
339719	337743	04035D	PARTICIPANT	\N	PRESENT	0
339720	337743	95067Q	PARTICIPANT	\N	PRESENT	0
339721	337743	01062T	PARTICIPANT	\N	PRESENT	0
339722	337743	14133K	PARTICIPANT	\N	PRESENT	0
339723	337743	08058D	PARTICIPANT	\N	PRESENT	0
339724	337743	19251M	PARTICIPANT	\N	PRESENT	0
339725	337743	14028W	PARTICIPANT	\N	PRESENT	0
339726	337743	19721W	PARTICIPANT	\N	PRESENT	0
339727	337743	14105F	PARTICIPANT	\N	PRESENT	0
339728	337743	98022P	PARTICIPANT	\N	PRESENT	0
339729	337743	14267Y	PARTICIPANT	\N	PRESENT	0
339730	337743	11064N	PARTICIPANT	\N	PRESENT	0
339731	337743	14255U	PARTICIPANT	\N	PRESENT	0
339732	337877	14034U	PARTICIPANT	\N	PRESENT	0
339733	337877	14083S	PARTICIPANT	\N	PRESENT	0
339761	321421	01043Q	PARTICIPANT	\N	PRESENT	0
339762	321421	08011M	PARTICIPANT	\N	PRESENT	0
339763	321421	11074Q	PARTICIPANT	\N	PRESENT	0
339789	338592	04070G	PRESIDENT	0	PRESENT	0
339790	338592	19699S	PARTICIPANT	\N	PRESENT	0
339791	338592	19533U	PARTICIPANT	\N	PRESENT	0
339792	338592	14229S	PARTICIPANT	\N	PRESENT	0
339793	338592	14241N	PARTICIPANT	\N	PRESENT	0
339794	338592	19573D	PARTICIPANT	\N	PRESENT	0
339795	338592	08017T	PARTICIPANT	\N	PRESENT	0
339796	338592	08012N	PARTICIPANT	\N	PRESENT	0
339797	338592	19335Q	PARTICIPANT	\N	PRESENT	0
339798	338592	08039A	PARTICIPANT	\N	PRESENT	0
339799	338592	08031R	PARTICIPANT	\N	PRESENT	0
339800	338592	19593H	PARTICIPANT	\N	PRESENT	0
339801	338592	14059S	PARTICIPANT	\N	PRESENT	0
339802	338592	04057K	PARTICIPANT	\N	PRESENT	0
339803	338592	14073Q	PARTICIPANT	\N	PRESENT	0
339804	338592	19611R	PARTICIPANT	\N	PRESENT	0
339805	338592	08043V	PARTICIPANT	\N	PRESENT	0
339806	338592	19693L	PARTICIPANT	\N	PRESENT	0
339807	338592	87003B	PARTICIPANT	\N	PRESENT	0
339808	338592	19399H	PARTICIPANT	\N	PRESENT	0
339810	338592	14030Q	PARTICIPANT	\N	PRESENT	0
339811	338592	19731Y	PARTICIPANT	\N	PRESENT	0
339812	338592	04059M	PARTICIPANT	\N	PRESENT	0
339813	338592	11109J	PARTICIPANT	\N	PRESENT	0
339814	338592	14063N	PARTICIPANT	\N	PRESENT	0
339815	338592	11083R	PARTICIPANT	\N	PRESENT	0
339816	338592	14123H	PARTICIPANT	\N	PRESENT	0
339817	338592	11043H	PARTICIPANT	\N	PRESENT	0
339818	338592	11104D	PARTICIPANT	\N	PRESENT	0
339819	338592	19749K	PARTICIPANT	\N	PRESENT	0
339820	338592	04018C	PARTICIPANT	\N	PRESENT	0
339821	338592	19758L	PARTICIPANT	\N	PRESENT	0
339822	338592	19735D	PARTICIPANT	\N	EXCUSE	0
339823	321421	11040E	PARTICIPANT	\N	PRESENT	0
339824	321421	19687N	PARTICIPANT	\N	PRESENT	0
339825	321421	19545Y	PARTICIPANT	\N	PRESENT	0
339826	321421	18083K	PARTICIPANT	\N	PRESENT	0
339827	321421	14267Y	PARTICIPANT	\N	PRESENT	0
339828	321421	14034U	PARTICIPANT	\N	PRESENT	0
339829	321421	19671E	PARTICIPANT	\N	PRESENT	0
339830	338592	14061L	PARTICIPANT	\N	EXCUSE	0
339914	339913	14231L	PARTICIPANT	\N	PRESENT	0
339916	339915	08045X	PARTICIPANT	\N	PRESENT	0
339917	339915	19762G	PARTICIPANT	\N	PRESENT	0
339919	339918	08045X	PARTICIPANT	\N	PRESENT	0
339920	339473	11097X	PRESIDENT	0	PRESENT	0
339921	339473	08052W	PARTICIPANT	\N	PRESENT	0
339922	339473	14195A	PARTICIPANT	\N	PRESENT	0
339923	339473	14281W	PARTICIPANT	\N	PRESENT	0
339924	339473	17779H	PARTICIPANT	\N	PRESENT	0
339942	339473	11045K	PARTICIPANT	\N	PRESENT	0
339943	339473	01034P	PARTICIPANT	\N	PRESENT	0
339944	339473	14239U	PARTICIPANT	\N	PRESENT	0
339945	339473	19697Q	PARTICIPANT	\N	PRESENT	0
339948	339473	19691J	PARTICIPANT	\N	PRESENT	0
339949	339473	19575F	PARTICIPANT	\N	PRESENT	0
339950	339473	14026U	PARTICIPANT	\N	PRESENT	0
339951	339473	19521Q	PARTICIPANT	\N	PRESENT	0
339952	339473	14119M	PARTICIPANT	\N	PRESENT	0
339953	339473	11067R	PARTICIPANT	\N	PRESENT	0
339956	339473	11031D	PARTICIPANT	\N	PRESENT	0
339957	339473	19760E	PARTICIPANT	\N	EXCUSE	0
339958	339473	08041T	PARTICIPANT	\N	EXCUSE	0
339959	339473	14213J	PARTICIPANT	\N	EXCUSE	0
339960	339473	04092N	PARTICIPANT	\N	EXCUSE	0
340072	337096	19269X	PARTICIPANT	\N	PRESENT	0
340075	337065	19269X	PARTICIPANT	\N	PRESENT	0
352284	351798	19489J	PARTICIPANT	\N	PRESENT	0
352285	351798	14275Y	PARTICIPANT	\N	PRESENT	0
352286	351798	95063L	PARTICIPANT	\N	PRESENT	0
352287	351798	14069U	PARTICIPANT	\N	PRESENT	0
352288	351798	11085T	PARTICIPANT	\N	PRESENT	0
352289	351798	08018U	PARTICIPANT	\N	PRESENT	0
352290	351798	11049P	PARTICIPANT	\N	PRESENT	0
352291	351798	14259Y	PARTICIPANT	\N	PRESENT	0
352292	351798	04008A	PARTICIPANT	\N	PRESENT	0
352293	351798	19762G	PARTICIPANT	\N	PRESENT	0
352294	351798	19729F	PARTICIPANT	\N	EXCUSE	0
352300	350765	14199E	PARTICIPANT	\N	PRESENT	0
352302	339558	14034U	PARTICIPANT	\N	PRESENT	0
352306	339558	19731Y	PARTICIPANT	\N	PRESENT	0
352304	339558	14275Y	PARTICIPANT	\N	PRESENT	0
352305	339558	19715Y	PARTICIPANT	\N	PRESENT	0
352309	339558	14039A	PARTICIPANT	\N	PRESENT	0
352310	339558	14259Y	PARTICIPANT	\N	PRESENT	0
352311	339558	19794Q	PARTICIPANT	\N	PRESENT	0
352312	339558	19659J	PARTICIPANT	\N	PRESENT	0
352322	339558	19441R	PARTICIPANT	\N	PRESENT	0
352323	339558	14223L	PARTICIPANT	\N	PRESENT	0
352324	339558	08019V	PARTICIPANT	\N	PRESENT	0
352325	339558	14277B	PARTICIPANT	\N	PRESENT	0
352326	339558	14215L	PARTICIPANT	\N	PRESENT	0
352327	339558	19629C	PARTICIPANT	\N	PRESENT	0
352328	339558	14265W	PARTICIPANT	\N	PRESENT	0
352329	339558	11033F	PARTICIPANT	\N	PRESENT	0
352330	339558	98005N	PARTICIPANT	\N	PRESENT	0
352331	339558	14038Y	PARTICIPANT	\N	PRESENT	0
352332	339558	14173T	PARTICIPANT	\N	PRESENT	0
352333	339558	01028R	PARTICIPANT	\N	PRESENT	0
352334	339558	14261S	PARTICIPANT	\N	PRESENT	0
352335	339558	11056N	PARTICIPANT	\N	PRESENT	0
352336	339558	08073C	PARTICIPANT	\N	PRESENT	0
352337	339558	95030B	PARTICIPANT	\N	PRESENT	0
352338	339558	97011G	PARTICIPANT	\N	PRESENT	0
352339	339558	14115H	PARTICIPANT	\N	PRESENT	0
352340	339558	19575F	PARTICIPANT	\N	PRESENT	0
352341	339558	04088S	PARTICIPANT	\N	PRESENT	0
352342	339558	14119M	PARTICIPANT	\N	PRESENT	0
352343	339558	14029X	PARTICIPANT	\N	PRESENT	0
352344	339558	15447F	PARTICIPANT	\N	PRESENT	0
352345	339558	19447X	PARTICIPANT	\N	PRESENT	0
352346	339558	11103C	PARTICIPANT	\N	PRESENT	0
352347	339558	01060R	PARTICIPANT	\N	PRESENT	0
352348	339558	14237S	PARTICIPANT	\N	PRESENT	0
352349	339558	14331P	PARTICIPANT	\N	PRESENT	0
352350	339558	08045X	PARTICIPANT	\N	PRESENT	0
352351	339558	14133K	PARTICIPANT	\N	PRESENT	0
352352	339558	08034U	PARTICIPANT	\N	PRESENT	0
352353	339558	14059S	PARTICIPANT	\N	PRESENT	0
352354	339558	11072N	PARTICIPANT	\N	PRESENT	0
352355	339558	11040E	PARTICIPANT	\N	PRESENT	0
352356	339558	05008E	PARTICIPANT	\N	PRESENT	0
352357	339558	19679N	PARTICIPANT	\N	PRESENT	0
352358	339558	14065Q	PARTICIPANT	\N	PRESENT	0
352359	339558	14207L	PARTICIPANT	\N	PRESENT	0
352360	339558	19681G	PARTICIPANT	\N	PRESENT	0
352361	339558	14033T	PARTICIPANT	\N	PRESENT	0
352362	339558	14191V	PARTICIPANT	\N	PRESENT	0
352363	339558	14042U	PARTICIPANT	\N	PRESENT	0
352364	339558	01024M	PARTICIPANT	\N	PRESENT	0
352365	339558	19782L	PARTICIPANT	\N	PRESENT	0
352366	339558	19657G	PARTICIPANT	\N	PRESENT	0
352367	339558	18083K	PARTICIPANT	\N	PRESENT	0
352368	339558	19387D	PARTICIPANT	\N	PRESENT	0
352369	339558	19631V	PARTICIPANT	\N	PRESENT	0
352370	339558	19671E	PARTICIPANT	\N	PRESENT	0
352371	339558	14071N	PARTICIPANT	\N	PRESENT	0
352372	339558	14063N	PARTICIPANT	\N	PRESENT	0
352374	339558	19413M	PARTICIPANT	\N	PRESENT	0
352375	339558	19507S	PARTICIPANT	\N	PRESENT	0
352376	339558	14069U	PARTICIPANT	\N	PRESENT	0
352377	339558	19479G	PARTICIPANT	\N	PRESENT	0
352379	339558	19467C	PARTICIPANT	\N	PRESENT	0
352380	339558	14105F	PARTICIPANT	\N	PRESENT	0
352381	339558	11085T	PARTICIPANT	\N	PRESENT	0
352382	339558	19577H	PARTICIPANT	\N	PRESENT	0
352383	339558	04085P	PARTICIPANT	\N	PRESENT	0
352384	339558	87003B	PARTICIPANT	\N	PRESENT	0
352385	339558	11010L	PARTICIPANT	\N	PRESENT	0
352386	339558	19701S	PARTICIPANT	\N	PRESENT	0
352387	339558	14179A	PARTICIPANT	\N	PRESENT	0
352388	339558	19543W	PARTICIPANT	\N	PRESENT	0
352389	339558	08051V	PARTICIPANT	\N	PRESENT	0
352391	339558	19563B	PARTICIPANT	\N	PRESENT	0
352392	339558	19737F	PARTICIPANT	\N	PRESENT	0
352393	339558	14231L	PARTICIPANT	\N	PRESENT	0
352394	339558	88008L	PARTICIPANT	\N	PRESENT	0
352395	339558	80013X	PARTICIPANT	\N	PRESENT	0
352396	339558	14221J	PARTICIPANT	\N	PRESENT	0
352397	339558	14103D	PARTICIPANT	\N	PRESENT	0
352398	339558	11043H	PARTICIPANT	\N	PRESENT	0
352399	339558	11109J	PARTICIPANT	\N	PRESENT	0
352400	339558	14169X	PARTICIPANT	\N	PRESENT	0
352401	339558	04057K	PARTICIPANT	\N	PRESENT	0
352402	339558	19383Y	PARTICIPANT	\N	PRESENT	0
352403	339558	14073Q	PARTICIPANT	\N	PRESENT	0
352404	339558	19369B	PARTICIPANT	\N	PRESENT	0
352405	339558	19533U	PARTICIPANT	\N	PRESENT	0
352406	339558	11099A	PARTICIPANT	\N	PRESENT	0
352407	339558	19713W	PARTICIPANT	\N	PRESENT	0
352408	339558	14219Q	PARTICIPANT	\N	PRESENT	0
352409	339558	19711U	PARTICIPANT	\N	PRESENT	0
352410	339558	14239U	PARTICIPANT	\N	PRESENT	0
352411	339558	11012A	PARTICIPANT	\N	PRESENT	0
352412	339558	14327T	PARTICIPANT	\N	PRESENT	0
352413	339558	01057W	PARTICIPANT	\N	PRESENT	0
352414	339558	19725B	PARTICIPANT	\N	PRESENT	0
352415	339558	19695N	PARTICIPANT	\N	PRESENT	0
352416	339558	04059M	PARTICIPANT	\N	PRESENT	0
352417	339558	99004R	PARTICIPANT	\N	PRESENT	0
352418	339558	11049P	PARTICIPANT	\N	PRESENT	0
352419	350702	19333N	PARTICIPANT	\N	PRESENT	0
352420	350702	08009T	PRESIDENT	0	PRESENT	0
352421	350702	08055A	PARTICIPANT	\N	PRESENT	0
352422	350702	19525U	PARTICIPANT	\N	PRESENT	0
352423	350702	19549D	PARTICIPANT	\N	EXCUSE	0
352424	350702	19685L	PARTICIPANT	\N	EXCUSE	0
352425	339558	14217N	PARTICIPANT	\N	PRESENT	0
352433	352378	14038Y	PARTICIPANT	\N	PRESENT	0
352434	352378	14097Y	PARTICIPANT	\N	PRESENT	0
352435	352378	11048N	PARTICIPANT	\N	PRESENT	0
352436	352378	95067Q	PARTICIPANT	\N	PRESENT	0
352437	352378	14187A	PARTICIPANT	\N	PRESENT	0
352438	352378	08038Y	PARTICIPANT	\N	PRESENT	0
352439	352378	14033T	PARTICIPANT	\N	PRESENT	0
352440	352378	14093U	PARTICIPANT	\N	PRESENT	0
352441	352378	14051J	PARTICIPANT	\N	PRESENT	0
352442	352378	08060W	PARTICIPANT	\N	PRESENT	0
352443	352378	19629C	PARTICIPANT	\N	PRESENT	0
352444	352378	19733B	PARTICIPANT	\N	PRESENT	0
352445	352378	19347U	PARTICIPANT	\N	PRESENT	0
352446	352378	19745F	PARTICIPANT	\N	PRESENT	0
352447	352378	14157T	PRESIDENT	0	PRESENT	0
352448	352378	14207L	PARTICIPANT	\N	PRESENT	0
352449	352378	19747H	PARTICIPANT	\N	PRESENT	0
352450	352378	08024S	PARTICIPANT	\N	PRESENT	0
352451	352378	19762G	PARTICIPANT	\N	PRESENT	0
352452	339558	08044W	PARTICIPANT	\N	PRESENT	0
352453	339558	14147R	PARTICIPANT	\N	PRESENT	0
352454	339558	14151M	PARTICIPANT	\N	PRESENT	0
352457	350702	19383Y	PARTICIPANT	\N	PRESENT	0
352458	350702	17583W	PARTICIPANT	\N	PRESENT	0
352459	350702	19794Q	PARTICIPANT	\N	PRESENT	0
352460	350702	19387D	PARTICIPANT	\N	PRESENT	0
352461	350702	11053K	PARTICIPANT	\N	PRESENT	0
352462	350702	14219Q	PARTICIPANT	\N	PRESENT	0
352463	350702	19599P	PARTICIPANT	\N	PRESENT	0
352464	350702	02002K	PARTICIPANT	\N	PRESENT	0
352465	350702	14231L	PARTICIPANT	\N	PRESENT	0
352466	350702	18083K	PARTICIPANT	\N	PRESENT	0
352467	350702	19551W	PARTICIPANT	\N	PRESENT	0
352468	350702	14237S	PARTICIPANT	\N	PRESENT	0
352469	350702	05012A	PARTICIPANT	\N	PRESENT	0
352470	350702	14051J	PARTICIPANT	\N	PRESENT	0
352471	350702	19503N	PARTICIPANT	\N	PRESENT	0
352472	350702	08024S	PARTICIPANT	\N	PRESENT	0
352473	350702	19681G	PARTICIPANT	\N	PRESENT	0
352474	350702	14038Y	PARTICIPANT	\N	PRESENT	0
352475	350702	14103D	PARTICIPANT	\N	PRESENT	0
352476	350702	19713W	PARTICIPANT	\N	PRESENT	0
352477	350702	14031R	PARTICIPANT	\N	PRESENT	0
352478	350702	19289C	PARTICIPANT	\N	PRESENT	0
352479	350702	14169X	PARTICIPANT	\N	PRESENT	0
352480	350702	04085P	PARTICIPANT	\N	PRESENT	0
352481	350702	14029X	PARTICIPANT	\N	PRESENT	0
352482	350702	19737F	PARTICIPANT	\N	PRESENT	0
343222	339503	19709B	PARTICIPANT	\N	PRESENT	0
343083	342128	19467C	PARTICIPANT	\N	EXCUSE	0
343084	342128	04049K	PARTICIPANT	\N	EXCUSE	0
343085	342128	01043Q	PARTICIPANT	\N	EXCUSE	0
343086	342128	19705W	PARTICIPANT	\N	EXCUSE	0
343087	342128	14033T	PARTICIPANT	\N	EXCUSE	0
343088	342128	11081P	PARTICIPANT	\N	EXCUSE	0
343089	342128	14187A	PARTICIPANT	\N	PRESENT	0
343090	342128	08019V	PARTICIPANT	\N	PRESENT	0
343091	342128	08021P	PARTICIPANT	\N	EXCUSE	0
343092	342128	19507S	PARTICIPANT	\N	PRESENT	0
343093	341785	11048N	PARTICIPANT	\N	PRESENT	0
343094	341785	19711U	PARTICIPANT	\N	PRESENT	0
343095	341785	01048V	PARTICIPANT	\N	PRESENT	0
343096	341785	19687N	PARTICIPANT	\N	PRESENT	0
343097	341785	19689Q	PARTICIPANT	\N	PRESENT	0
343098	341785	11074Q	PRESIDENT	0	PRESENT	0
343099	341785	14225N	PARTICIPANT	\N	PRESENT	0
343100	341785	04086Q	PARTICIPANT	\N	PRESENT	0
343101	341785	11040E	PARTICIPANT	\N	PRESENT	0
343102	341785	07029T	PARTICIPANT	\N	PRESENT	0
343103	341785	14085U	PARTICIPANT	\N	PRESENT	0
343104	341785	19741B	PARTICIPANT	\N	PRESENT	0
343105	341785	08010L	PARTICIPANT	\N	PRESENT	0
343106	341785	99004R	PARTICIPANT	\N	PRESENT	0
343107	341785	04061F	PARTICIPANT	\N	PRESENT	0
343108	341785	14121F	PARTICIPANT	\N	EXCUSE	0
343110	339502	19719D	PARTICIPANT	\N	PRESENT	0
343111	339502	19693L	PARTICIPANT	\N	PRESENT	0
343112	339502	19629C	PARTICIPANT	\N	PRESENT	0
343113	339502	19599P	PARTICIPANT	\N	PRESENT	0
343114	339502	04038G	PARTICIPANT	\N	PRESENT	0
343115	339502	14069U	PARTICIPANT	\N	PRESENT	0
343220	339503	17589D	PARTICIPANT	\N	PRESENT	0
343221	339503	14219Q	PARTICIPANT	\N	PRESENT	0
343223	339503	19467C	PARTICIPANT	\N	PRESENT	0
343224	339503	19367Y	PARTICIPANT	\N	PRESENT	0
343225	339503	14109K	PARTICIPANT	\N	PRESENT	0
343226	339503	14069U	PARTICIPANT	\N	PRESENT	0
343227	339503	95030B	PARTICIPANT	\N	PRESENT	0
343228	339503	14063N	PARTICIPANT	\N	PRESENT	0
343229	339503	14103D	PARTICIPANT	\N	PRESENT	0
343230	339503	14030Q	PARTICIPANT	\N	PRESENT	0
343231	339503	04040A	PARTICIPANT	\N	PRESENT	0
343232	339503	14133K	PARTICIPANT	\N	PRESENT	0
343233	339503	19447X	PARTICIPANT	\N	PRESENT	0
343234	339503	14187A	PARTICIPANT	\N	PRESENT	0
343235	339503	14223L	PARTICIPANT	\N	PRESENT	0
343236	339503	19758L	PARTICIPANT	\N	PRESENT	0
343237	339503	18083K	PARTICIPANT	\N	PRESENT	0
343238	339503	19741B	PARTICIPANT	\N	PRESENT	0
343239	339503	08047A	PARTICIPANT	\N	PRESENT	0
343240	339503	17583W	PARTICIPANT	\N	PRESENT	0
343241	339503	14105F	PARTICIPANT	\N	PRESENT	0
343242	339503	14157T	PARTICIPANT	\N	PRESENT	0
343243	339503	19621T	PARTICIPANT	\N	PRESENT	0
343244	339503	01048V	PARTICIPANT	\N	PRESENT	0
343245	339503	11026G	PARTICIPANT	\N	PRESENT	0
343246	339503	08069G	PARTICIPANT	\N	PRESENT	0
343247	339503	88008L	PARTICIPANT	\N	PRESENT	0
343248	339503	14215L	PARTICIPANT	\N	PRESENT	0
343249	339503	01062T	PARTICIPANT	\N	PRESENT	0
343250	339503	14159V	PARTICIPANT	\N	PRESENT	0
343251	339503	19563B	PARTICIPANT	\N	PRESENT	0
343252	339503	11067R	PARTICIPANT	\N	PRESENT	0
343253	339503	14237S	PARTICIPANT	\N	PRESENT	0
343254	339503	14087W	PARTICIPANT	\N	PRESENT	0
343255	339503	14267Y	PARTICIPANT	\N	PRESENT	0
343256	339503	19733B	PARTICIPANT	\N	PRESENT	0
343257	339503	14021P	PARTICIPANT	\N	PRESENT	0
343258	339503	11064N	PARTICIPANT	\N	PRESENT	0
343259	339503	10006L	PARTICIPANT	\N	PRESENT	0
343260	339503	08018U	PARTICIPANT	\N	PRESENT	0
343261	339503	11103C	PARTICIPANT	\N	PRESENT	0
343262	339503	04033B	PARTICIPANT	\N	PRESENT	0
343263	339503	11054L	PARTICIPANT	\N	PRESENT	0
343264	339503	08061X	PARTICIPANT	\N	PRESENT	0
343265	339503	98050T	PARTICIPANT	\N	PRESENT	0
343266	339503	14107H	PARTICIPANT	\N	PRESENT	0
343267	339503	14241N	PARTICIPANT	\N	PRESENT	0
343268	339503	11027H	PARTICIPANT	\N	PRESENT	0
343269	339503	01058X	PARTICIPANT	\N	PRESENT	0
343270	339503	14259Y	PARTICIPANT	\N	PRESENT	0
343271	339503	14265W	PARTICIPANT	\N	PRESENT	0
343272	339503	08017T	PARTICIPANT	\N	PRESENT	0
343273	339503	19387D	PARTICIPANT	\N	PRESENT	0
343274	339503	08053X	PARTICIPANT	\N	PRESENT	0
343275	339503	80013X	PARTICIPANT	\N	PRESENT	0
343276	339503	07029T	PARTICIPANT	\N	PRESENT	0
343277	339503	14026U	PARTICIPANT	\N	PRESENT	0
343278	339503	19511N	PARTICIPANT	\N	PRESENT	0
343279	339503	95062K	PARTICIPANT	\N	PRESENT	0
343280	339503	19569H	PARTICIPANT	\N	PRESENT	0
343281	339503	19479G	PARTICIPANT	\N	PRESENT	0
343282	339503	19719D	PARTICIPANT	\N	PRESENT	0
343283	339503	11101A	PARTICIPANT	\N	PRESENT	0
343284	339503	19703U	PARTICIPANT	\N	PRESENT	0
343292	339503	14028W	PARTICIPANT	\N	PRESENT	0
343374	339504	95062K	PARTICIPANT	\N	PRESENT	0
343375	339504	19679N	PARTICIPANT	\N	PRESENT	0
343376	339504	19703U	PARTICIPANT	\N	PRESENT	0
343377	339504	11101A	PARTICIPANT	\N	PRESENT	0
343378	339504	14029X	PARTICIPANT	\N	PRESENT	0
343379	339504	14041T	PARTICIPANT	\N	PRESENT	0
343380	339504	08018U	PARTICIPANT	\N	PRESENT	0
343381	339504	04035D	PARTICIPANT	\N	PRESENT	0
343382	339504	08010L	PARTICIPANT	\N	PRESENT	0
343383	339504	08047A	PARTICIPANT	\N	PRESENT	0
343384	339504	08048B	PARTICIPANT	\N	PRESENT	0
343385	339504	14215L	PARTICIPANT	\N	PRESENT	0
343386	339504	14079W	PARTICIPANT	\N	PRESENT	0
343387	339504	19383Y	PARTICIPANT	\N	PRESENT	0
343388	339504	19581D	PARTICIPANT	\N	PRESENT	0
343389	339504	19673G	PARTICIPANT	\N	PRESENT	0
343391	339504	19731Y	PARTICIPANT	\N	PRESENT	0
343393	339504	80013X	PARTICIPANT	\N	PRESENT	0
343394	339504	19683J	PARTICIPANT	\N	PRESENT	0
343395	339504	08068F	PARTICIPANT	\N	PRESENT	0
343396	339504	19525U	PARTICIPANT	\N	PRESENT	0
343397	339504	99004R	PARTICIPANT	\N	PRESENT	0
343398	339504	14223L	PARTICIPANT	\N	PRESENT	0
343399	339504	07034Q	PARTICIPANT	\N	PRESENT	0
343400	339504	19671E	PARTICIPANT	\N	PRESENT	0
343401	339504	14026U	PARTICIPANT	\N	PRESENT	0
343402	339504	11103C	PARTICIPANT	\N	PRESENT	0
343403	339504	19693L	PARTICIPANT	\N	PRESENT	0
343405	339504	19711U	PARTICIPANT	\N	PRESENT	0
343406	339504	88008L	PARTICIPANT	\N	PRESENT	0
343408	339504	04018C	PARTICIPANT	\N	PRESENT	0
343409	339504	14147R	PARTICIPANT	\N	PRESENT	0
343410	339504	08051V	PARTICIPANT	\N	PRESENT	0
343411	339504	14253S	PARTICIPANT	\N	PRESENT	0
343412	339504	14331P	PARTICIPANT	\N	PRESENT	0
343413	339504	14157T	PARTICIPANT	\N	PRESENT	0
343414	339504	15447F	PARTICIPANT	\N	PRESENT	0
343416	339504	19643A	PARTICIPANT	\N	PRESENT	0
343417	339504	08028W	PARTICIPANT	\N	PRESENT	0
343418	339504	07033P	PARTICIPANT	\N	PRESENT	0
343419	339504	14357A	PARTICIPANT	\N	PRESENT	0
343420	339504	04049K	PARTICIPANT	\N	PRESENT	0
343421	339504	04088S	PARTICIPANT	\N	PRESENT	0
343422	339504	04097T	PARTICIPANT	\N	PRESENT	0
343423	339504	19675J	PARTICIPANT	\N	PRESENT	0
343424	339504	14217N	PARTICIPANT	\N	PRESENT	0
343425	339504	19515S	PARTICIPANT	\N	PRESENT	0
343426	339504	19794Q	PARTICIPANT	\N	PRESENT	0
343427	339504	08015R	PARTICIPANT	\N	PRESENT	0
343428	339504	19729F	PARTICIPANT	\N	PRESENT	0
343429	339504	19415P	PARTICIPANT	\N	PRESENT	0
343430	339504	19421M	PARTICIPANT	\N	PRESENT	0
343431	339504	17583W	PARTICIPANT	\N	PRESENT	0
343432	339504	18083K	PARTICIPANT	\N	PRESENT	0
343433	339504	14193X	PARTICIPANT	\N	PRESENT	0
343434	339504	10006L	PARTICIPANT	\N	PRESENT	0
343435	339504	11080N	PARTICIPANT	\N	PRESENT	0
343436	339504	87003B	PARTICIPANT	\N	PRESENT	0
343437	339504	04044E	PARTICIPANT	\N	PRESENT	0
343438	339504	19621T	PARTICIPANT	\N	PRESENT	0
343439	339504	14135M	PARTICIPANT	\N	PRESENT	0
343440	339504	19447X	PARTICIPANT	\N	PRESENT	0
343441	339504	14169X	PARTICIPANT	\N	PRESENT	0
343442	339504	11033F	PARTICIPANT	\N	PRESENT	0
343443	339504	96004D	PARTICIPANT	\N	PRESENT	0
343445	339504	07029T	PARTICIPANT	\N	PRESENT	0
343446	339504	14235Q	PARTICIPANT	\N	PRESENT	0
343447	339504	08034U	PARTICIPANT	\N	PRESENT	0
353954	353884	04088S	PARTICIPANT	\N	PRESENT	0
353955	353884	08021P	PARTICIPANT	\N	PRESENT	0
353956	353884	19695N	PARTICIPANT	\N	PRESENT	0
353957	353884	12041X	PARTICIPANT	\N	PRESENT	0
353958	353884	14107H	PARTICIPANT	\N	PRESENT	0
353959	353884	19715Y	PARTICIPANT	\N	PRESENT	0
353960	353884	14197C	PARTICIPANT	\N	PRESENT	0
353961	353884	01025N	PARTICIPANT	\N	PRESENT	0
353962	353884	14281W	PARTICIPANT	\N	PRESENT	0
353963	353884	19649G	PARTICIPANT	\N	PRESENT	0
353964	353884	04045F	PARTICIPANT	\N	PRESENT	0
353965	353884	11045K	PARTICIPANT	\N	PRESENT	0
353966	353884	14051J	PARTICIPANT	\N	PRESENT	0
353968	353884	87003B	PARTICIPANT	\N	PRESENT	0
353969	353884	08028W	PARTICIPANT	\N	PRESENT	0
353970	353884	19543W	PARTICIPANT	\N	PRESENT	0
353971	353884	98035U	PARTICIPANT	\N	PRESENT	0
353972	353884	14026U	PARTICIPANT	\N	PRESENT	0
353973	353884	11027H	PARTICIPANT	\N	PRESENT	0
353974	353884	19717B	PARTICIPANT	\N	PRESENT	0
353975	353884	08060W	PARTICIPANT	\N	PRESENT	0
353976	353884	14225N	PARTICIPANT	\N	PRESENT	0
353977	353884	19697Q	PARTICIPANT	\N	PRESENT	0
353978	353884	19760E	PARTICIPANT	\N	PRESENT	0
353979	353884	19727D	PARTICIPANT	\N	PRESENT	0
353980	353884	19251M	PARTICIPANT	\N	PRESENT	0
353981	353884	14151M	PARTICIPANT	\N	PRESENT	0
353982	353884	14028W	PARTICIPANT	\N	PRESENT	0
353983	353884	80027E	PARTICIPANT	\N	PRESENT	0
353984	353884	08012N	PARTICIPANT	\N	PRESENT	0
353985	353884	14085U	PARTICIPANT	\N	PRESENT	0
353986	353884	80013X	PARTICIPANT	\N	PRESENT	0
353987	353884	14229S	PARTICIPANT	\N	PRESENT	0
353988	353884	11110B	PARTICIPANT	\N	PRESENT	0
353989	353884	19725B	PARTICIPANT	\N	PRESENT	0
353990	353884	01057W	PARTICIPANT	\N	PRESENT	0
353991	353884	14097Y	PARTICIPANT	\N	PRESENT	0
353992	353884	11109J	PARTICIPANT	\N	PRESENT	0
353993	353884	19515S	PARTICIPANT	\N	PRESENT	0
353994	353884	04059M	PARTICIPANT	\N	PRESENT	0
353995	353884	17637T	PARTICIPANT	\N	PRESENT	0
353996	353884	14211G	PARTICIPANT	\N	PRESENT	0
353997	353884	01058X	PARTICIPANT	\N	PRESENT	0
353998	353884	19647E	PARTICIPANT	\N	PRESENT	0
353999	353884	99004R	PARTICIPANT	\N	PRESENT	0
354000	353884	19631V	PARTICIPANT	\N	PRESENT	0
354001	353884	14063N	PARTICIPANT	\N	PRESENT	0
354002	353884	14123H	PARTICIPANT	\N	PRESENT	0
354003	353884	08069G	PARTICIPANT	\N	PRESENT	0
354004	353884	96004D	PARTICIPANT	\N	PRESENT	0
354005	353884	19329S	PARTICIPANT	\N	PRESENT	0
354006	353884	08039A	PARTICIPANT	\N	PRESENT	0
354007	353884	14039A	PARTICIPANT	\N	PRESENT	0
354008	353884	04034C	PARTICIPANT	\N	PRESENT	0
354009	353884	10015M	PARTICIPANT	\N	PRESENT	0
354010	353884	19651A	PARTICIPANT	\N	PRESENT	0
354011	353884	14207L	PARTICIPANT	\N	PRESENT	0
354012	353884	14169X	PARTICIPANT	\N	PRESENT	0
354013	353884	19531S	PARTICIPANT	\N	PRESENT	0
354014	353884	11083R	PARTICIPANT	\N	PRESENT	0
354015	353884	11080N	PARTICIPANT	\N	PRESENT	0
354016	353884	19347U	PARTICIPANT	\N	PRESENT	0
354017	353884	14261S	PARTICIPANT	\N	PRESENT	0
354018	353884	11012A	PARTICIPANT	\N	PRESENT	0
354019	353884	19629C	PARTICIPANT	\N	PRESENT	0
354020	353884	19703U	PARTICIPANT	\N	PRESENT	0
354021	353884	19719D	PARTICIPANT	\N	PRESENT	0
354022	353884	14241N	PARTICIPANT	\N	PRESENT	0
354023	353884	14239U	PARTICIPANT	\N	PRESENT	0
354024	353884	19673G	PARTICIPANT	\N	PRESENT	0
354025	353884	14121F	PARTICIPANT	\N	PRESENT	0
354026	353884	11104D	PARTICIPANT	\N	PRESENT	0
354027	353884	11010L	PARTICIPANT	\N	PRESENT	0
354028	353884	14201E	PARTICIPANT	\N	PRESENT	0
354029	353884	14235Q	PARTICIPANT	\N	PRESENT	0
354030	353884	11031D	PARTICIPANT	\N	PRESENT	0
354031	353884	19447X	PARTICIPANT	\N	PRESENT	0
354032	353884	17589D	PARTICIPANT	\N	PRESENT	0
354033	353884	19585H	PARTICIPANT	\N	PRESENT	0
354034	353884	14119M	PARTICIPANT	\N	PRESENT	0
354035	353884	19413M	PARTICIPANT	\N	PRESENT	0
354036	353884	92040Q	PARTICIPANT	\N	PRESENT	0
354037	353884	14195A	PARTICIPANT	\N	PRESENT	0
354038	353884	14055N	PARTICIPANT	\N	PRESENT	0
354039	353884	19527W	PARTICIPANT	\N	PRESENT	0
354040	353884	98024R	PARTICIPANT	\N	PRESENT	0
354041	353884	14030Q	PARTICIPANT	\N	PRESENT	0
354042	353884	14327T	PARTICIPANT	\N	PRESENT	0
354043	353884	04033B	PARTICIPANT	\N	PRESENT	0
354044	353884	01024M	PARTICIPANT	\N	PRESENT	0
354045	353884	14187A	PARTICIPANT	\N	PRESENT	0
354046	353884	07004J	PARTICIPANT	\N	PRESENT	0
354047	353884	14255U	PARTICIPANT	\N	PRESENT	0
354048	353884	14071N	PARTICIPANT	\N	PRESENT	0
354049	353884	08056B	PARTICIPANT	\N	PRESENT	0
354050	353884	14221J	PARTICIPANT	\N	PRESENT	0
354051	353884	14267Y	PARTICIPANT	\N	PRESENT	0
354052	353884	14219Q	PARTICIPANT	\N	PRESENT	0
354053	353884	08047A	PARTICIPANT	\N	PRESENT	0
354054	353884	19479G	PARTICIPANT	\N	PRESENT	0
354055	353884	16685X	PARTICIPANT	\N	PRESENT	0
354056	353884	11053K	PARTICIPANT	\N	PRESENT	0
354057	353884	11067R	PARTICIPANT	\N	PRESENT	0
354058	353884	14199E	PARTICIPANT	\N	PRESENT	0
354059	353884	19737F	PARTICIPANT	\N	PRESENT	0
354060	353884	14205J	PARTICIPANT	\N	PRESENT	0
354061	353884	19691J	PARTICIPANT	\N	PRESENT	0
354062	353884	14253S	PARTICIPANT	\N	PRESENT	0
354063	353884	19441R	PARTICIPANT	\N	PRESENT	0
354064	353884	04049K	PARTICIPANT	\N	PRESENT	0
354065	353884	14029X	PARTICIPANT	\N	PRESENT	0
354066	353884	11101A	PARTICIPANT	\N	PRESENT	0
354067	353884	14259Y	PARTICIPANT	\N	PRESENT	0
354068	353884	19295A	PARTICIPANT	\N	PRESENT	0
354069	353884	14065Q	PARTICIPANT	\N	PRESENT	0
354070	353884	08055A	PARTICIPANT	\N	PRESENT	0
354071	353884	19269X	PARTICIPANT	\N	PRESENT	0
354072	353884	95030B	PARTICIPANT	\N	PRESENT	0
354073	353884	14227Q	PARTICIPANT	\N	PRESENT	0
354074	353884	04092N	PARTICIPANT	\N	PRESENT	0
354075	353884	19525U	PARTICIPANT	\N	PRESENT	0
354076	353884	11056N	PARTICIPANT	\N	PRESENT	0
354077	353884	19549D	PARTICIPANT	\N	PRESENT	0
354078	353884	95041E	PARTICIPANT	\N	PRESENT	0
354079	353884	08073C	PARTICIPANT	\N	PRESENT	0
354080	353884	19591F	PARTICIPANT	\N	PRESENT	0
354081	353884	19443T	PARTICIPANT	\N	PRESENT	0
354082	353884	14038Y	PARTICIPANT	\N	PRESENT	0
354083	353884	11041F	PARTICIPANT	\N	PRESENT	0
354084	353884	19507S	PARTICIPANT	\N	PRESENT	0
354085	353884	08031R	PARTICIPANT	\N	PRESENT	0
354086	353884	01043Q	PARTICIPANT	\N	PRESENT	0
354087	353884	19663E	PARTICIPANT	\N	PRESENT	0
354088	353884	14103D	PARTICIPANT	\N	PRESENT	0
354089	353884	05012A	PARTICIPANT	\N	PRESENT	0
354090	353884	08068F	PARTICIPANT	\N	PRESENT	0
354091	353884	19415P	PARTICIPANT	\N	PRESENT	0
354092	353884	08014Q	PARTICIPANT	\N	PRESENT	0
354093	353884	14251Q	PARTICIPANT	\N	PRESENT	0
354094	353884	14257W	PARTICIPANT	\N	PRESENT	0
354096	353884	95037J	PARTICIPANT	\N	PRESENT	0
354097	353884	08045X	PARTICIPANT	\N	PRESENT	0
354098	353884	19669L	PARTICIPANT	\N	PRESENT	0
354099	353884	14115H	PARTICIPANT	\N	PRESENT	0
354100	353884	08051V	PARTICIPANT	\N	PRESENT	0
354101	353884	19693L	PARTICIPANT	\N	PRESENT	0
354102	353884	19745F	PARTICIPANT	\N	PRESENT	0
354103	353884	19749K	PARTICIPANT	\N	PRESENT	0
354104	353884	17583W	PARTICIPANT	\N	PRESENT	0
354105	353884	19739H	PARTICIPANT	\N	PRESENT	0
354106	353884	14265W	PARTICIPANT	\N	PRESENT	0
354107	353884	08017T	PARTICIPANT	\N	PRESENT	0
354108	353884	19705W	PARTICIPANT	\N	PRESENT	0
354109	353884	04085P	PARTICIPANT	\N	PRESENT	0
354110	353884	08015R	PARTICIPANT	\N	PRESENT	0
354111	353884	11074Q	PARTICIPANT	\N	PRESENT	0
354112	353884	08062Y	PARTICIPANT	\N	PRESENT	0
354113	353884	14355X	PARTICIPANT	\N	PRESENT	0
354114	353884	11077T	PARTICIPANT	\N	PRESENT	0
354115	353884	19657G	PARTICIPANT	\N	PRESENT	0
354116	353884	08010L	PARTICIPANT	\N	PRESENT	0
354117	353884	11099A	PARTICIPANT	\N	PRESENT	0
354118	353884	14033T	PARTICIPANT	\N	PRESENT	0
354119	353884	14135M	PARTICIPANT	\N	PRESENT	0
354120	353884	19711U	PARTICIPANT	\N	PRESENT	0
354121	353884	11097X	PARTICIPANT	\N	PRESENT	0
354122	353884	14193X	PARTICIPANT	\N	PRESENT	0
354123	353884	14087W	PARTICIPANT	\N	PRESENT	0
337640	334061	11103C	PARTICIPANT	\N	PRESENT	0
337641	334061	19415P	PARTICIPANT	\N	PRESENT	0
337642	334061	04092N	PRESIDENT	0	PRESENT	0
337643	334061	14071N	PARTICIPANT	\N	PRESENT	0
337645	334061	19679N	PARTICIPANT	\N	PRESENT	0
337646	334061	14227Q	PARTICIPANT	\N	PRESENT	0
337647	334061	19727D	PARTICIPANT	\N	PRESENT	0
337648	334061	19703U	PARTICIPANT	\N	PRESENT	0
337649	334061	14213J	PARTICIPANT	\N	PRESENT	0
337650	334061	04049K	PARTICIPANT	\N	PRESENT	0
337651	334061	14051J	PARTICIPANT	\N	PRESENT	0
337652	334061	14329V	PARTICIPANT	\N	PRESENT	0
337653	334061	14187A	PARTICIPANT	\N	PRESENT	0
337654	334061	14253S	PARTICIPANT	\N	PRESENT	0
337655	334061	08015R	PARTICIPANT	\N	PRESENT	0
337656	334061	19575F	PARTICIPANT	\N	PRESENT	0
337657	334061	04088S	PARTICIPANT	\N	PRESENT	0
337658	334061	14105F	PARTICIPANT	\N	PRESENT	0
337660	334061	14281W	PARTICIPANT	\N	PRESENT	0
337662	334061	11067R	PARTICIPANT	\N	PRESENT	0
337663	334061	14157T	PARTICIPANT	\N	PRESENT	0
337664	334061	14195A	PARTICIPANT	\N	PRESENT	0
337665	334061	08041T	PARTICIPANT	\N	EXCUSE	0
337666	334061	14355X	PARTICIPANT	\N	EXCUSE	0
337667	334061	11097X	PARTICIPANT	\N	PRESENT	0
337668	334061	14205J	PARTICIPANT	\N	PRESENT	0
337669	334061	19671E	PARTICIPANT	\N	PRESENT	0
337675	337674	14089Y	PARTICIPANT	\N	PRESENT	0
337677	337674	96004D	PRESIDENT	0	PRESENT	0
337678	337674	14357A	PARTICIPANT	\N	PRESENT	0
337679	337674	14079W	PARTICIPANT	\N	PRESENT	0
337681	337674	19725B	PARTICIPANT	\N	PRESENT	0
337682	337674	95037J	PARTICIPANT	\N	PRESENT	0
337683	337674	04097T	PARTICIPANT	\N	PRESENT	0
337684	337674	14097Y	PARTICIPANT	\N	PRESENT	0
337685	337674	11026G	PARTICIPANT	\N	PRESENT	0
337686	337674	14001X	PARTICIPANT	\N	PRESENT	0
337687	337674	19563B	PARTICIPANT	\N	PRESENT	0
337688	337674	14237S	PARTICIPANT	\N	PRESENT	0
337706	337701	14357A	PARTICIPANT	\N	PRESENT	0
337690	337674	14331P	PARTICIPANT	\N	PRESENT	0
337691	337674	10015M	PARTICIPANT	\N	PRESENT	0
337692	337674	14229S	PARTICIPANT	\N	PRESENT	0
337693	337674	98035U	PARTICIPANT	\N	PRESENT	0
337704	337701	14133K	PARTICIPANT	\N	PRESENT	0
337705	337701	96004D	PRESIDENT	0	PRESENT	0
337707	337701	14079W	PARTICIPANT	\N	PRESENT	0
337708	337701	14249W	PARTICIPANT	\N	PRESENT	0
337709	337701	19725B	PARTICIPANT	\N	PRESENT	0
337710	337701	04097T	PARTICIPANT	\N	PRESENT	0
337711	337701	14097Y	PARTICIPANT	\N	PRESENT	0
337712	337701	11026G	PARTICIPANT	\N	PRESENT	0
337713	337701	04057K	PARTICIPANT	\N	PRESENT	0
337714	337701	14237S	PARTICIPANT	\N	PRESENT	0
337715	337701	14331P	PARTICIPANT	\N	PRESENT	0
337716	337701	98035U	PARTICIPANT	\N	PRESENT	0
337725	337674	19741B	PARTICIPANT	\N	PRESENT	0
337727	337674	14085U	PARTICIPANT	\N	PRESENT	0
337728	337674	88008L	PARTICIPANT	\N	PRESENT	0
337729	337674	19531S	PARTICIPANT	\N	PRESENT	0
337730	337674	89017R	PARTICIPANT	\N	PRESENT	0
337731	337674	07004J	PARTICIPANT	\N	PRESENT	0
337732	337674	11074Q	PARTICIPANT	\N	PRESENT	0
337733	337674	08011M	PARTICIPANT	\N	PRESENT	0
337734	337674	19545Y	PARTICIPANT	\N	PRESENT	0
337735	337674	19671E	PARTICIPANT	\N	PRESENT	0
337736	337674	19711U	PARTICIPANT	\N	PRESENT	0
337737	337674	14083S	PARTICIPANT	\N	PRESENT	0
337738	337674	19479G	PARTICIPANT	\N	PRESENT	0
337739	337674	14121F	PARTICIPANT	\N	PRESENT	0
337740	337674	11048N	PARTICIPANT	\N	PRESENT	0
337741	337674	04071H	PARTICIPANT	\N	PRESENT	0
340180	340179	11048N	PARTICIPANT	\N	PRESENT	0
340185	340184	14231L	PARTICIPANT	\N	PRESENT	0
340314	340313	14031R	PARTICIPANT	\N	PRESENT	0
340315	340313	19637C	PARTICIPANT	\N	PRESENT	0
340317	340316	14031R	PARTICIPANT	\N	PRESENT	0
340318	340316	19637C	PARTICIPANT	\N	PRESENT	0
340320	340319	14031R	PARTICIPANT	\N	PRESENT	0
340322	340321	19737F	PARTICIPANT	\N	PRESENT	0
340323	340321	14031R	PARTICIPANT	\N	PRESENT	0
340325	340324	19551W	PARTICIPANT	\N	PRESENT	0
340326	340324	14031R	PARTICIPANT	\N	PRESENT	0
340327	340324	19737F	PARTICIPANT	\N	PRESENT	0
340329	340328	14031R	PARTICIPANT	\N	PRESENT	0
340331	340330	14038Y	PARTICIPANT	\N	PRESENT	0
340332	340330	14031R	PARTICIPANT	\N	PRESENT	0
340333	340330	19637C	PARTICIPANT	\N	PRESENT	0
340334	340330	19737F	PARTICIPANT	\N	PRESENT	0
340336	340335	14031R	PARTICIPANT	\N	PRESENT	0
340337	340335	19637C	PARTICIPANT	\N	PRESENT	0
340338	340335	19737F	PARTICIPANT	\N	PRESENT	0
340340	340339	19701S	PARTICIPANT	\N	PRESENT	0
340341	340339	02002K	PARTICIPANT	\N	PRESENT	0
340342	340339	19551W	PARTICIPANT	\N	PRESENT	0
340343	340339	14031R	PARTICIPANT	\N	PRESENT	0
340344	340339	19737F	PARTICIPANT	\N	PRESENT	0
340346	340345	19599P	PARTICIPANT	\N	PRESENT	0
340347	340345	14031R	PARTICIPANT	\N	PRESENT	0
340076	337065	19565D	PARTICIPANT	\N	EXCUSE	0
340178	340177	11048N	PARTICIPANT	\N	PRESENT	0
340348	340345	19737F	PARTICIPANT	\N	PRESENT	0
340350	340349	19551W	PARTICIPANT	\N	PRESENT	0
340351	340349	14031R	PARTICIPANT	\N	PRESENT	0
340353	340352	14031R	PARTICIPANT	\N	PRESENT	0
340354	340352	19737F	PARTICIPANT	\N	PRESENT	0
340356	340355	14031R	PARTICIPANT	\N	PRESENT	0
340358	340357	19681G	PARTICIPANT	\N	PRESENT	0
340359	340357	14031R	PARTICIPANT	\N	PRESENT	0
340361	340360	14031R	PARTICIPANT	\N	PRESENT	0
340363	340362	14031R	PARTICIPANT	\N	PRESENT	0
340364	340362	19737F	PARTICIPANT	\N	PRESENT	0
340366	340365	19347U	PARTICIPANT	\N	PRESENT	0
340367	340365	19737F	PARTICIPANT	\N	PRESENT	0
340492	340438	14059S	PARTICIPANT	\N	EXCUSE	0
340493	340438	14275Y	PARTICIPANT	\N	EXCUSE	0
340494	331577	14275Y	PARTICIPANT	\N	EXCUSE	0
340495	334381	14275Y	PARTICIPANT	\N	EXCUSE	0
340496	334381	14059S	PARTICIPANT	\N	EXCUSE	0
340542	340541	19629C	PARTICIPANT	\N	PRESENT	0
343133	342817	14063N	PARTICIPANT	\N	EXCUSE	0
343140	342817	14071N	PARTICIPANT	\N	EXCUSE	0
343191	342817	14028W	PARTICIPANT	\N	EXCUSE	0
344187	342916	14001X	PARTICIPANT	\N	PRESENT	0
344188	342916	01060R	PARTICIPANT	\N	PRESENT	0
344189	342916	19543W	PARTICIPANT	\N	PRESENT	0
344190	342916	19581D	PARTICIPANT	\N	PRESENT	0
344191	342916	19585H	PARTICIPANT	\N	PRESENT	0
344192	342916	04047H	PARTICIPANT	\N	PRESENT	0
344193	342916	19673G	PARTICIPANT	\N	PRESENT	0
344194	342916	01028R	PARTICIPANT	\N	PRESENT	0
344195	342916	14231L	PARTICIPANT	\N	PRESENT	0
344196	342916	05008E	PARTICIPANT	\N	PRESENT	0
344197	342916	14041T	PARTICIPANT	\N	PRESENT	0
344198	342916	14147R	PARTICIPANT	\N	PRESENT	0
344199	342916	14179A	PARTICIPANT	\N	PRESENT	0
344200	342916	14151M	PARTICIPANT	\N	PRESENT	0
344201	342916	14215L	PARTICIPANT	\N	PRESENT	0
344202	342916	14053L	PARTICIPANT	\N	PRESENT	0
344203	342916	98035U	PARTICIPANT	\N	PRESENT	0
344204	342916	14065Q	PARTICIPANT	\N	PRESENT	0
344205	342916	07034Q	PRESIDENT	0	PRESENT	0
344206	342916	11026G	PARTICIPANT	\N	PRESENT	0
344207	342916	08045X	PARTICIPANT	\N	PRESENT	0
344208	342916	01024M	PARTICIPANT	\N	PRESENT	0
344209	342916	11033F	PARTICIPANT	\N	PRESENT	0
344210	342916	19725B	PARTICIPANT	\N	PRESENT	0
344211	342916	19729F	PARTICIPANT	\N	PRESENT	0
344212	342916	19629C	PARTICIPANT	\N	PRESENT	0
344213	342916	11049P	PARTICIPANT	\N	PRESENT	0
344214	342916	19762G	PARTICIPANT	\N	PRESENT	0
344261	342919	14021P	PARTICIPANT	\N	PRESENT	0
344262	342172	19333N	PARTICIPANT	\N	PRESENT	0
344263	342172	17583W	PARTICIPANT	\N	PRESENT	0
344264	342172	14031R	PARTICIPANT	\N	PRESENT	0
344265	342172	19549D	PARTICIPANT	\N	PRESENT	0
344266	342172	19387D	PARTICIPANT	\N	PRESENT	0
344267	342172	14237S	PARTICIPANT	\N	PRESENT	0
344268	342172	19383Y	PARTICIPANT	\N	PRESENT	0
344269	342172	19701S	PARTICIPANT	\N	PRESENT	0
344270	342172	95062K	PARTICIPANT	\N	PRESENT	0
344271	342172	05012A	PARTICIPANT	\N	PRESENT	0
344272	342172	80027E	PARTICIPANT	\N	PRESENT	0
344273	342172	19503N	PARTICIPANT	\N	PRESENT	0
344274	342172	19347U	PARTICIPANT	\N	PRESENT	0
344275	342172	19713W	PARTICIPANT	\N	PRESENT	0
344276	340626	04092N	PRESIDENT	0	PRESENT	0
344277	340626	11097X	PARTICIPANT	\N	PRESENT	0
344278	340626	19415P	PARTICIPANT	\N	PRESENT	0
352483	350702	04097T	PARTICIPANT	\N	PRESENT	0
352484	350702	19739H	PARTICIPANT	\N	PRESENT	0
352485	350702	19745F	PARTICIPANT	\N	PRESENT	0
352486	350702	14221J	PARTICIPANT	\N	PRESENT	0
352487	350702	19637C	PARTICIPANT	\N	PRESENT	0
352488	350702	19347U	PARTICIPANT	\N	PRESENT	0
352489	350702	15447F	PARTICIPANT	\N	PRESENT	0
352490	350702	08060W	PARTICIPANT	\N	PRESENT	0
352491	350702	14157T	PARTICIPANT	\N	PRESENT	0
352492	350702	14093U	PARTICIPANT	\N	PRESENT	0
352493	350702	19701S	PARTICIPANT	\N	PRESENT	0
352494	339558	08053X	PARTICIPANT	\N	PRESENT	0
352495	339558	14201E	PARTICIPANT	\N	PRESENT	0
352496	350702	11065P	PARTICIPANT	\N	PRESENT	0
352497	339558	01058X	PARTICIPANT	\N	PRESENT	0
352498	339558	11101A	PARTICIPANT	\N	PRESENT	0
352499	339558	14026U	PARTICIPANT	\N	PRESENT	0
352500	339558	19691J	PARTICIPANT	\N	PRESENT	0
352501	350702	17637T	PARTICIPANT	\N	PRESENT	0
352502	339558	14267Y	PARTICIPANT	\N	PRESENT	0
352503	339558	04040A	PARTICIPANT	\N	PRESENT	0
352505	339558	19747H	PARTICIPANT	\N	PRESENT	0
352519	339558	19673G	PARTICIPANT	\N	PRESENT	0
352520	350702	19733B	PARTICIPANT	\N	PRESENT	0
352521	339558	11053K	PARTICIPANT	\N	PRESENT	0
352522	350702	14191V	PARTICIPANT	\N	PRESENT	0
352523	339558	08068F	PARTICIPANT	\N	PRESENT	0
352524	339558	14030Q	PARTICIPANT	\N	PRESENT	0
352525	339558	14195A	PARTICIPANT	\N	PRESENT	0
352527	339558	19611R	PARTICIPANT	\N	PRESENT	0
352539	352538	11053K	PARTICIPANT	\N	PRESENT	0
352540	352538	14159V	PARTICIPANT	\N	PRESENT	0
352541	352538	05012A	PARTICIPANT	\N	PRESENT	0
352550	350826	19301E	PARTICIPANT	\N	PRESENT	0
352553	350829	19727D	PARTICIPANT	\N	PRESENT	0
352780	349542	14261S	PARTICIPANT	\N	PRESENT	0
352782	349542	19329S	PARTICIPANT	\N	PRESENT	0
352784	349542	14059S	PARTICIPANT	\N	PRESENT	0
352785	349542	08019V	PRESIDENT	0	PRESENT	0
352786	349542	19657G	PARTICIPANT	\N	PRESENT	0
352787	349542	14331P	PARTICIPANT	\N	PRESENT	0
352790	349542	14097Y	PARTICIPANT	\N	EXCUSE	0
352980	352979	05008E	PRESIDENT	0	PRESENT	0
352981	352979	11033F	PARTICIPANT	\N	PRESENT	0
352982	352979	14215L	PARTICIPANT	\N	PRESENT	0
352983	352979	08018U	PARTICIPANT	\N	PRESENT	0
352984	352979	19729F	PARTICIPANT	\N	EXCUSE	0
352985	352979	11072N	PARTICIPANT	\N	PRESENT	0
352986	352979	95063L	PARTICIPANT	\N	PRESENT	0
352987	352979	01028R	PARTICIPANT	\N	PRESENT	0
352988	352979	19585H	PARTICIPANT	\N	PRESENT	0
352990	351931	08031R	PARTICIPANT	\N	EXCUSE	0
352991	351931	08017T	PARTICIPANT	\N	EXCUSE	0
352992	351931	19621T	PARTICIPANT	\N	EXCUSE	0
353054	353053	19719D	PARTICIPANT	\N	PRESENT	0
353085	350813	19367Y	PARTICIPANT	\N	EXCUSE	0
353748	346259	14069U	PARTICIPANT	\N	PRESENT	0
353749	346259	01057W	PARTICIPANT	\N	PRESENT	0
353750	346259	19489J	PARTICIPANT	\N	PRESENT	0
353751	346259	19735D	PARTICIPANT	\N	PRESENT	0
353752	346259	14257W	PARTICIPANT	\N	PRESENT	0
353753	346259	14103D	PARTICIPANT	\N	PRESENT	0
353754	346259	08049C	PARTICIPANT	\N	PRESENT	0
353797	353796	11074Q	PARTICIPANT	\N	PRESENT	0
353816	353815	14039A	PARTICIPANT	\N	PRESENT	0
353818	353814	14039A	PARTICIPANT	\N	PRESENT	0
353821	353820	08043V	PARTICIPANT	\N	PRESENT	0
353822	353820	19621T	PARTICIPANT	\N	PRESENT	0
353823	353820	19758L	PARTICIPANT	\N	PRESENT	0
353824	353820	19693L	PARTICIPANT	\N	PRESENT	0
353825	353820	11083R	PARTICIPANT	\N	PRESENT	0
353826	353820	19611R	PARTICIPANT	\N	PRESENT	0
353827	353820	19533U	PARTICIPANT	\N	PRESENT	0
353828	353820	14107H	PARTICIPANT	\N	PRESENT	0
353829	353820	14030Q	PARTICIPANT	\N	PRESENT	0
353830	353820	04070G	PARTICIPANT	\N	PRESENT	0
353831	353820	04057K	PARTICIPANT	\N	PRESENT	0
353911	353895	11026G	PARTICIPANT	\N	PRESENT	0
353923	353912	14033T	PARTICIPANT	\N	PRESENT	0
353933	353913	14033T	PARTICIPANT	\N	PRESENT	0
353936	353914	14033T	PARTICIPANT	\N	PRESENT	0
353967	353915	14033T	PARTICIPANT	\N	PRESENT	0
354095	353833	19569H	PARTICIPANT	\N	EXCUSE	0
354212	354209	01043Q	PARTICIPANT	\N	PRESENT	0
354849	354847	19581D	PARTICIPANT	\N	PRESENT	0
354850	354847	04047H	PARTICIPANT	\N	PRESENT	0
354851	354847	19673G	PARTICIPANT	\N	PRESENT	0
354852	354847	01028R	PARTICIPANT	\N	PRESENT	0
354853	354847	19447X	PARTICIPANT	\N	PRESENT	0
354854	354847	14231L	PARTICIPANT	\N	PRESENT	0
354855	354847	05008E	PRESIDENT	0	PRESENT	0
354856	354847	19489J	PARTICIPANT	\N	PRESENT	0
354857	354847	14041T	PARTICIPANT	\N	PRESENT	0
354858	354847	14179A	PARTICIPANT	\N	PRESENT	0
354859	354847	14147R	PARTICIPANT	\N	PRESENT	0
354860	354847	14151M	PARTICIPANT	\N	PRESENT	0
354861	354847	14215L	PARTICIPANT	\N	PRESENT	0
354862	354847	14259Y	PARTICIPANT	\N	PRESENT	0
354863	354847	11072N	PARTICIPANT	\N	PRESENT	0
354864	354847	14053L	PARTICIPANT	\N	PRESENT	0
354865	354847	98035U	PARTICIPANT	\N	PRESENT	0
354866	354847	14111D	PARTICIPANT	\N	PRESENT	0
354867	354847	19649G	PARTICIPANT	\N	PRESENT	0
354868	354847	07034Q	PARTICIPANT	\N	PRESENT	0
354869	354847	08045X	PARTICIPANT	\N	PRESENT	0
354870	354847	11026G	PARTICIPANT	\N	PRESENT	0
354871	354847	10015M	PARTICIPANT	\N	PRESENT	0
354872	354847	01024M	PARTICIPANT	\N	PRESENT	0
354873	354847	19719D	PARTICIPANT	\N	PRESENT	0
354874	354847	11033F	PARTICIPANT	\N	PRESENT	0
354875	354847	19725B	PARTICIPANT	\N	PRESENT	0
354876	354847	14089Y	PARTICIPANT	\N	PRESENT	0
354877	354847	95063L	PARTICIPANT	\N	PRESENT	0
354878	354847	19629C	PARTICIPANT	\N	PRESENT	0
354879	354847	14069U	PARTICIPANT	\N	PRESENT	0
354880	354847	11049P	PARTICIPANT	\N	PRESENT	0
354881	354847	14021P	PARTICIPANT	\N	PRESENT	0
354882	354847	11085T	PARTICIPANT	\N	PRESENT	0
354883	354847	19729F	PARTICIPANT	\N	EXCUSE	0
354884	354847	08018U	PARTICIPANT	\N	EXCUSE	0
354885	354847	14065Q	PARTICIPANT	\N	PRESENT	0
354886	354847	04044E	PARTICIPANT	\N	PRESENT	0
354887	354847	19543W	PARTICIPANT	\N	PRESENT	0
354888	352190	19768N	PARTICIPANT	\N	PRESENT	0
354889	352190	19515S	PARTICIPANT	\N	PRESENT	0
354890	352190	19705W	PARTICIPANT	\N	PRESENT	0
354891	352190	14187A	PARTICIPANT	\N	PRESENT	0
354892	352190	11101A	PARTICIPANT	\N	PRESENT	0
354893	352190	08019V	PARTICIPANT	\N	PRESENT	0
354894	352190	08062Y	PARTICIPANT	\N	PRESENT	0
354895	352190	14033T	PARTICIPANT	\N	PRESENT	0
354896	352190	11090Q	PRESIDENT	0	PRESENT	0
354897	352190	19747H	PARTICIPANT	\N	PRESENT	0
354898	352190	08028W	PARTICIPANT	\N	PRESENT	0
354899	352190	14329V	PARTICIPANT	\N	PRESENT	0
354900	352190	19782L	PARTICIPANT	\N	PRESENT	0
354901	352190	14081Q	PARTICIPANT	\N	PRESENT	0
354902	352190	19413M	PARTICIPANT	\N	PRESENT	0
354903	352190	80013X	PARTICIPANT	\N	PRESENT	0
354904	352190	19631V	PARTICIPANT	\N	PRESENT	0
354905	352190	08021P	PARTICIPANT	\N	PRESENT	0
354906	352190	11099A	PARTICIPANT	\N	PRESENT	0
354907	352190	08068F	PARTICIPANT	\N	PRESENT	0
354908	352190	14197C	PARTICIPANT	\N	PRESENT	0
354909	352190	19511N	PARTICIPANT	\N	PRESENT	0
354910	352190	01025N	PARTICIPANT	\N	PRESENT	0
354911	352190	19269X	PARTICIPANT	\N	PRESENT	0
354912	352190	14205J	PARTICIPANT	\N	PRESENT	0
354913	352190	19507S	PARTICIPANT	\N	PRESENT	0
354914	352190	17589D	PARTICIPANT	\N	PRESENT	0
354915	352190	14257W	PARTICIPANT	\N	PRESENT	0
354916	352190	11077T	PARTICIPANT	\N	PRESENT	0
354917	352190	04049K	PARTICIPANT	\N	PRESENT	0
354918	352190	19695N	PARTICIPANT	\N	PRESENT	0
354919	352190	11056N	PARTICIPANT	\N	PRESENT	0
354920	352190	14115H	PARTICIPANT	\N	PRESENT	0
354921	352190	04043D	PARTICIPANT	\N	PRESENT	0
354922	352190	11081P	PARTICIPANT	\N	EXCUSE	0
354923	352190	19563B	PARTICIPANT	\N	EXCUSE	0
354934	354228	19593H	PARTICIPANT	\N	PRESENT	0
354935	354228	04070G	PRESIDENT	0	PRESENT	0
354936	354228	04035D	PARTICIPANT	\N	PRESENT	0
354937	354228	08035V	PARTICIPANT	\N	PRESENT	0
354938	354228	19611R	PARTICIPANT	\N	PRESENT	0
354939	354228	08043V	PARTICIPANT	\N	PRESENT	0
354940	354228	19693L	PARTICIPANT	\N	PRESENT	0
354941	354228	19399H	PARTICIPANT	\N	PRESENT	0
354942	354228	87003B	PARTICIPANT	\N	PRESENT	0
354943	354228	14201E	PARTICIPANT	\N	PRESENT	0
337760	337759	04033B	PARTICIPANT	\N	PRESENT	0
337761	337759	19367Y	PARTICIPANT	\N	PRESENT	0
337762	337759	14115H	PARTICIPANT	\N	PRESENT	0
337763	337759	04042C	PARTICIPANT	\N	PRESENT	0
337765	337759	19545Y	PARTICIPANT	\N	PRESENT	0
337767	337759	14217N	PARTICIPANT	\N	PRESENT	0
337768	337759	04035D	PARTICIPANT	\N	PRESENT	0
337769	337759	19723Y	PARTICIPANT	\N	PRESENT	0
337770	337759	14147R	PARTICIPANT	\N	PRESENT	0
337771	337759	19766L	PARTICIPANT	\N	PRESENT	0
337773	337759	95067Q	PARTICIPANT	\N	PRESENT	0
337774	337759	14021P	PARTICIPANT	\N	PRESENT	0
337777	337759	19741B	PARTICIPANT	\N	PRESENT	0
340561	340560	14051J	PARTICIPANT	\N	PRESENT	0
340562	340560	12041X	PARTICIPANT	\N	PRESENT	0
342060	341936	19515S	PARTICIPANT	\N	PRESENT	0
342061	341936	04071H	PARTICIPANT	\N	PRESENT	0
342062	341936	11053K	PARTICIPANT	\N	PRESENT	0
342063	341936	11070L	PARTICIPANT	\N	PRESENT	0
342064	341936	14151M	PARTICIPANT	\N	PRESENT	0
342065	341936	14157T	PARTICIPANT	\N	PRESENT	0
342066	341936	14329V	PARTICIPANT	\N	PRESENT	0
342067	341936	11048N	PARTICIPANT	\N	PRESENT	0
342068	341936	08034U	PARTICIPANT	\N	PRESENT	0
342069	341936	14187A	PARTICIPANT	\N	PRESENT	0
342070	341936	19399H	PARTICIPANT	\N	PRESENT	0
342071	341936	14173T	PARTICIPANT	\N	PRESENT	0
342072	341936	08073C	PARTICIPANT	\N	PRESENT	0
342073	341936	19762G	PARTICIPANT	\N	PRESENT	0
342076	342001	98035U	PARTICIPANT	\N	PRESENT	0
342077	342001	07034Q	PARTICIPANT	\N	PRESENT	0
342078	342001	11026G	PARTICIPANT	\N	PRESENT	0
342079	342001	10015M	PARTICIPANT	\N	PRESENT	0
342080	342001	11027H	PARTICIPANT	\N	PRESENT	0
342081	342001	19543W	PARTICIPANT	\N	PRESENT	0
342082	342001	04038G	PARTICIPANT	\N	PRESENT	0
342083	342001	19585H	PARTICIPANT	\N	PRESENT	0
342084	342001	19719D	PARTICIPANT	\N	PRESENT	0
342085	342001	01028R	PRESIDENT	1	PRESENT	0
342086	342001	19447X	PARTICIPANT	\N	PRESENT	0
342087	342001	05008E	PRESIDENT	0	PRESENT	0
342088	342001	14089Y	PARTICIPANT	\N	PRESENT	0
342089	342001	19489J	PARTICIPANT	\N	PRESENT	0
342090	342001	19729F	PARTICIPANT	\N	PRESENT	0
342091	342001	95063L	PARTICIPANT	\N	PRESENT	0
342092	342001	19705W	PARTICIPANT	\N	PRESENT	0
342093	342001	14041T	PARTICIPANT	\N	PRESENT	0
342094	342001	19709B	PARTICIPANT	\N	PRESENT	0
342095	342001	08017T	PARTICIPANT	\N	PRESENT	0
342096	342001	14069U	PARTICIPANT	\N	PRESENT	0
342097	342001	14151M	PARTICIPANT	\N	PRESENT	0
342098	342001	08018U	PARTICIPANT	\N	PRESENT	0
342099	342001	11049P	PARTICIPANT	\N	PRESENT	0
342147	340502	11067R	PARTICIPANT	\N	PRESENT	0
342148	340502	14147R	PARTICIPANT	\N	PRESENT	0
342149	340502	08043V	PARTICIPANT	\N	PRESENT	0
342150	340502	19415P	PARTICIPANT	\N	PRESENT	0
342151	340502	19749K	PARTICIPANT	\N	PRESENT	0
342152	340502	19673G	PARTICIPANT	\N	PRESENT	0
342153	340502	10006L	PRESIDENT	0	PRESENT	0
342154	340502	14030Q	PARTICIPANT	\N	PRESENT	0
342155	340502	19533U	PARTICIPANT	\N	EXCUSE	0
342156	340502	08031R	PARTICIPANT	\N	EXCUSE	0
342157	340502	14231L	PARTICIPANT	\N	EXCUSE	0
342168	342001	04047H	PARTICIPANT	\N	PRESENT	0
342169	342001	14237S	PARTICIPANT	\N	PRESENT	0
342170	342001	14231L	PARTICIPANT	\N	PRESENT	0
342178	339499	19583F	PARTICIPANT	\N	PRESENT	0
342179	339499	98022P	PARTICIPANT	\N	PRESENT	0
342181	339499	80013X	PARTICIPANT	\N	PRESENT	0
342182	339499	14039A	PARTICIPANT	\N	PRESENT	0
342183	339499	19651A	PARTICIPANT	\N	PRESENT	0
342184	339499	19479G	PARTICIPANT	\N	PRESENT	0
342186	339499	08043V	PARTICIPANT	\N	PRESENT	0
342187	339499	11066Q	PARTICIPANT	\N	PRESENT	0
342190	339499	08056B	PARTICIPANT	\N	PRESENT	0
342192	339499	19719D	PARTICIPANT	\N	PRESENT	0
342193	339499	17779H	PARTICIPANT	\N	PRESENT	0
342194	339499	19593H	PARTICIPANT	\N	PRESENT	0
342195	339499	19683J	PARTICIPANT	\N	PRESENT	0
342196	339499	08017T	PARTICIPANT	\N	PRESENT	0
342197	339499	14231L	PARTICIPANT	\N	PRESENT	0
342198	339499	19251M	PARTICIPANT	\N	PRESENT	0
342199	339499	14107H	PARTICIPANT	\N	PRESENT	0
342200	339499	19619A	PARTICIPANT	\N	PRESENT	0
342201	339499	14085U	PARTICIPANT	\N	PRESENT	0
342202	339499	19565D	PARTICIPANT	\N	PRESENT	0
342203	339499	11040E	PARTICIPANT	\N	PRESENT	0
342204	339499	14028W	PARTICIPANT	\N	PRESENT	0
342205	339499	19569H	PARTICIPANT	\N	PRESENT	0
342206	339499	19611R	PARTICIPANT	\N	PRESENT	0
342207	339499	14201E	PARTICIPANT	\N	PRESENT	0
342208	339499	08045X	PARTICIPANT	\N	PRESENT	0
342209	339499	19525U	PARTICIPANT	\N	PRESENT	0
342210	339499	14063N	PARTICIPANT	\N	PRESENT	0
342211	339499	08021P	PARTICIPANT	\N	PRESENT	0
342212	339499	14034U	PARTICIPANT	\N	PRESENT	0
342213	339499	14257W	PARTICIPANT	\N	PRESENT	0
342214	339499	08052W	PARTICIPANT	\N	PRESENT	0
342215	339499	19333N	PARTICIPANT	\N	PRESENT	0
342216	339499	14235Q	PARTICIPANT	\N	PRESENT	0
342217	339499	19687N	PARTICIPANT	\N	PRESENT	0
342218	339499	11027H	PARTICIPANT	\N	PRESENT	0
342219	339499	11054L	PARTICIPANT	\N	PRESENT	0
342220	339499	11067R	PARTICIPANT	\N	PRESENT	0
342221	339499	14207L	PARTICIPANT	\N	PRESENT	0
342223	339499	04034C	PARTICIPANT	\N	PRESENT	0
342224	339499	08055A	PARTICIPANT	\N	PRESENT	0
342225	339499	95063L	PARTICIPANT	\N	PRESENT	0
342226	339499	98029W	PARTICIPANT	\N	PRESENT	0
342227	339499	04045F	PARTICIPANT	\N	PRESENT	0
342228	339499	14261S	PARTICIPANT	\N	PRESENT	0
342230	339499	19715Y	PARTICIPANT	\N	PRESENT	0
342231	339499	19727D	PARTICIPANT	\N	PRESENT	0
342232	339499	19527W	PARTICIPANT	\N	PRESENT	0
342233	339499	19329S	PARTICIPANT	\N	PRESENT	0
342234	339499	08024S	PARTICIPANT	\N	PRESENT	0
342235	339499	19782L	PARTICIPANT	\N	PRESENT	0
342236	339499	19387D	PARTICIPANT	\N	PRESENT	0
342237	339499	14227Q	PARTICIPANT	\N	PRESENT	0
342238	339499	19760E	PARTICIPANT	\N	PRESENT	0
342239	339499	11033F	PARTICIPANT	\N	PRESENT	0
342240	339499	11031D	PARTICIPANT	\N	PRESENT	0
342241	339499	14051J	PARTICIPANT	\N	PRESENT	0
342242	339499	19599P	PARTICIPANT	\N	PRESENT	0
342243	339499	19631V	PARTICIPANT	\N	PRESENT	0
342244	339499	14021P	PARTICIPANT	\N	PRESENT	0
342245	339499	14121F	PARTICIPANT	\N	PRESENT	0
342246	342171	14331P	PARTICIPANT	\N	PRESENT	0
342247	342171	19515S	PARTICIPANT	\N	PRESENT	0
342248	342171	11048N	PARTICIPANT	\N	PRESENT	0
342249	342171	19711U	PARTICIPANT	\N	PRESENT	0
342250	342171	08034U	PARTICIPANT	\N	PRESENT	0
342251	342171	04034C	PARTICIPANT	\N	PRESENT	0
342252	342171	14187A	PARTICIPANT	\N	PRESENT	0
342253	342171	19441R	PARTICIPANT	\N	PRESENT	0
342254	342171	11053K	PARTICIPANT	\N	PRESENT	0
342255	342171	19695N	PARTICIPANT	\N	PRESENT	0
342256	342171	19667J	PARTICIPANT	\N	PRESENT	0
342257	342171	19717B	PARTICIPANT	\N	PRESENT	0
342258	342171	19399H	PARTICIPANT	\N	PRESENT	0
342259	342171	14159V	PARTICIPANT	\N	PRESENT	0
342260	342171	14227Q	PARTICIPANT	\N	PRESENT	0
342261	342171	19631V	PARTICIPANT	\N	PRESENT	0
342262	342171	14083S	PARTICIPANT	\N	PRESENT	0
342263	342171	14051J	PARTICIPANT	\N	PRESENT	0
342264	342171	04049K	PARTICIPANT	\N	PRESENT	0
342265	342171	08073C	PARTICIPANT	\N	PRESENT	0
342266	342171	19521Q	PRESIDENT	0	PRESENT	0
342267	342171	19760E	PARTICIPANT	\N	PRESENT	0
342268	342171	19762G	PARTICIPANT	\N	PRESENT	0
342269	342171	11110B	PARTICIPANT	\N	EXCUSE	0
342270	339499	04085P	PARTICIPANT	\N	PRESENT	0
342271	339499	19695N	PARTICIPANT	\N	PRESENT	0
342272	339499	08061X	PARTICIPANT	\N	PRESENT	0
342273	339499	95037J	PARTICIPANT	\N	PRESENT	0
342274	339499	14239U	PARTICIPANT	\N	PRESENT	0
342278	339499	19349W	PARTICIPANT	\N	PRESENT	0
342279	339499	19637C	PARTICIPANT	\N	PRESENT	0
342280	339499	19697Q	PARTICIPANT	\N	PRESENT	0
342281	339499	08073C	PARTICIPANT	\N	PRESENT	0
342282	339499	11072N	PARTICIPANT	\N	PRESENT	0
342283	339499	19543W	PARTICIPANT	\N	PRESENT	0
342284	339499	17589D	PARTICIPANT	\N	PRESENT	0
342286	339499	19585H	PARTICIPANT	\N	PRESENT	0
342287	339499	11064N	PARTICIPANT	\N	PRESENT	0
342288	339499	11083R	PARTICIPANT	\N	PRESENT	0
342290	339499	04057K	PARTICIPANT	\N	PRESENT	0
342291	339499	14251Q	PARTICIPANT	\N	PRESENT	0
354124	353884	14215L	PARTICIPANT	\N	PRESENT	0
354125	353884	04043D	PARTICIPANT	\N	PRESENT	0
354126	353884	19289C	PARTICIPANT	\N	PRESENT	0
354127	353884	11040E	PARTICIPANT	\N	PRESENT	0
354128	353884	11072N	PARTICIPANT	\N	PRESENT	0
354129	353884	08034U	PARTICIPANT	\N	PRESENT	0
354130	353884	19637C	PARTICIPANT	\N	PRESENT	0
354131	353884	19533U	PARTICIPANT	\N	PRESENT	0
354132	353884	07034Q	PARTICIPANT	\N	PRESENT	0
354133	353884	19599P	PARTICIPANT	\N	PRESENT	0
354134	353884	04061F	PARTICIPANT	\N	PRESENT	0
354135	353884	14159V	PARTICIPANT	\N	PRESENT	0
354136	353884	14331P	PARTICIPANT	\N	PRESENT	0
354137	353884	19369B	PARTICIPANT	\N	PRESENT	0
354138	353884	14217N	PARTICIPANT	\N	PRESENT	0
354139	353884	07033P	PARTICIPANT	\N	PRESENT	0
354140	353884	97011G	PARTICIPANT	\N	PRESENT	0
354141	353884	04040A	PARTICIPANT	\N	PRESENT	0
354142	353884	19699S	PARTICIPANT	\N	PRESENT	0
354143	353884	14093U	PARTICIPANT	\N	PRESENT	0
354144	353884	01028R	PARTICIPANT	\N	PRESENT	0
354145	353884	04018C	PARTICIPANT	\N	PRESENT	0
354146	353884	14147R	PARTICIPANT	\N	PRESENT	0
354147	353884	19747H	PARTICIPANT	\N	PRESENT	0
354148	353884	11049P	PARTICIPANT	\N	PRESENT	0
354149	353884	19671E	PARTICIPANT	\N	PRESENT	0
354150	353884	08043V	PARTICIPANT	\N	PRESENT	0
354151	353884	98050T	PARTICIPANT	\N	PRESENT	0
354152	353884	98029W	PARTICIPANT	\N	PRESENT	0
354153	353884	19521Q	PARTICIPANT	\N	PRESENT	0
354154	353884	18083K	PARTICIPANT	\N	PRESENT	0
354155	353884	11103C	PARTICIPANT	\N	PRESENT	0
354156	353884	19611R	PARTICIPANT	\N	PRESENT	0
354157	353884	14034U	PARTICIPANT	\N	PRESENT	0
354164	353884	19709B	PARTICIPANT	\N	PRESENT	0
354159	353884	01060R	PARTICIPANT	\N	PRESENT	0
354160	353884	19545Y	PARTICIPANT	\N	PRESENT	0
354161	353884	19713W	PARTICIPANT	\N	PRESENT	0
354162	353884	04042C	PARTICIPANT	\N	PRESENT	0
354163	353884	04044E	PARTICIPANT	\N	PRESENT	0
354165	353884	11048N	PARTICIPANT	\N	PRESENT	0
354166	353884	14109K	PARTICIPANT	\N	PRESENT	0
354167	353884	14105F	PARTICIPANT	\N	PRESENT	0
354168	353884	19593H	PARTICIPANT	\N	PRESENT	0
354169	353884	14249W	PARTICIPANT	\N	PRESENT	0
354170	353884	19621T	PARTICIPANT	\N	PRESENT	0
354171	353884	19723Y	PARTICIPANT	\N	PRESENT	0
354172	353884	19489J	PARTICIPANT	\N	PRESENT	0
354173	353884	19551W	PARTICIPANT	\N	PRESENT	0
354184	353884	11085T	PARTICIPANT	\N	PRESENT	0
354175	353884	08035V	PARTICIPANT	\N	PRESENT	0
354176	353884	19577H	PARTICIPANT	\N	PRESENT	0
354177	353884	14021P	PARTICIPANT	\N	PRESENT	0
354178	353884	14231L	PARTICIPANT	\N	PRESENT	0
354179	353884	14031R	PARTICIPANT	\N	PRESENT	0
354183	353884	08048B	PARTICIPANT	\N	PRESENT	0
354181	353884	02002K	PARTICIPANT	\N	PRESENT	0
354182	353884	19335Q	PARTICIPANT	\N	PRESENT	0
354185	353884	14053L	PARTICIPANT	\N	PRESENT	0
354186	353884	04097T	PARTICIPANT	\N	PRESENT	0
354187	353884	19553Y	PARTICIPANT	\N	PRESENT	0
354188	353884	01034P	PARTICIPANT	\N	PRESENT	0
354189	353884	04071H	PARTICIPANT	\N	PRESENT	0
354190	353884	04057K	PARTICIPANT	\N	PRESENT	0
354191	353884	19573D	PARTICIPANT	\N	PRESENT	0
354192	353884	19689Q	PARTICIPANT	\N	PRESENT	0
354193	353884	08024S	PARTICIPANT	\N	PRESENT	0
354194	353884	14081Q	PARTICIPANT	\N	PRESENT	0
354195	353884	19733B	PARTICIPANT	\N	PRESENT	0
354196	353884	05008E	PARTICIPANT	\N	PRESENT	0
354197	353884	19575F	PARTICIPANT	\N	PRESENT	0
354198	353884	08038Y	PARTICIPANT	\N	PRESENT	0
354199	353884	11115U	PARTICIPANT	\N	PRESENT	0
354200	353884	19679N	PARTICIPANT	\N	PRESENT	0
354201	353884	95062K	PARTICIPANT	\N	PRESENT	0
354202	353884	19467C	PARTICIPANT	\N	PRESENT	0
354203	353884	07029T	PARTICIPANT	\N	PRESENT	0
354204	353884	11065P	PARTICIPANT	\N	PRESENT	0
354205	353884	04047H	PARTICIPANT	\N	PRESENT	0
354210	353884	14237S	PARTICIPANT	\N	PRESENT	0
354207	353884	11043H	PARTICIPANT	\N	PRESENT	0
354208	353884	19643A	PARTICIPANT	\N	PRESENT	0
354211	353884	19421M	PARTICIPANT	\N	PRESENT	0
354213	353884	11070L	PARTICIPANT	\N	PRESENT	0
354214	353884	14083S	PARTICIPANT	\N	PRESENT	0
354215	353884	11026G	PARTICIPANT	\N	PRESENT	0
354216	353884	01048V	PARTICIPANT	\N	PRESENT	0
354520	339597	11033F	PARTICIPANT	\N	PRESENT	0
354521	339597	11056N	PARTICIPANT	\N	PRESENT	0
354522	339597	14235Q	PARTICIPANT	\N	PRESENT	0
354523	339597	12041X	PARTICIPANT	\N	PRESENT	0
354524	339597	11040E	PARTICIPANT	\N	PRESENT	0
354525	339597	11031D	PARTICIPANT	\N	PRESENT	0
354526	339597	14211G	PARTICIPANT	\N	PRESENT	0
354527	339597	19593H	PARTICIPANT	\N	PRESENT	0
354528	339597	19347U	PARTICIPANT	\N	PRESENT	0
354529	339597	17637T	PARTICIPANT	\N	PRESENT	0
354530	339597	04045F	PARTICIPANT	\N	PRESENT	0
354531	339597	19711U	PARTICIPANT	\N	PRESENT	0
354532	339597	95037J	PARTICIPANT	\N	PRESENT	0
354533	339597	04034C	PARTICIPANT	\N	PRESENT	0
354534	339597	95062K	PARTICIPANT	\N	PRESENT	0
354535	339597	14239U	PARTICIPANT	\N	PRESENT	0
354536	339597	98029W	PARTICIPANT	\N	PRESENT	0
354537	339597	11083R	PARTICIPANT	\N	PRESENT	0
354538	339597	08011M	PARTICIPANT	\N	PRESENT	0
354539	339597	19651A	PARTICIPANT	\N	PRESENT	0
354540	339597	19349W	PARTICIPANT	\N	PRESENT	0
354541	339597	96004D	PARTICIPANT	\N	PRESENT	0
354542	339597	19637C	PARTICIPANT	\N	PRESENT	0
354543	339597	11072N	PARTICIPANT	\N	PRESENT	0
354544	339597	19329S	PARTICIPANT	\N	PRESENT	0
354545	339597	08021P	PARTICIPANT	\N	PRESENT	0
354546	339597	19659J	PARTICIPANT	\N	PRESENT	0
354547	339597	14039A	PARTICIPANT	\N	PRESENT	0
354548	339597	19679N	PARTICIPANT	\N	PRESENT	0
354549	339597	04097T	PARTICIPANT	\N	PRESENT	0
354550	339597	19782L	PARTICIPANT	\N	PRESENT	0
354551	339597	08039A	PARTICIPANT	\N	PRESENT	0
354552	339597	11012A	PARTICIPANT	\N	PRESENT	0
354553	339597	08010L	PARTICIPANT	\N	PRESENT	0
354554	339597	14034U	PARTICIPANT	\N	PRESENT	0
354555	339597	01058X	PARTICIPANT	\N	PRESENT	0
354556	339597	08049C	PARTICIPANT	\N	PRESENT	0
354557	339597	14201E	PARTICIPANT	\N	PRESENT	0
354558	339597	19387D	PARTICIPANT	\N	PRESENT	0
354568	339597	14111D	PARTICIPANT	\N	PRESENT	0
354560	339597	14107H	PARTICIPANT	\N	PRESENT	0
354561	339597	19719D	PARTICIPANT	\N	PRESENT	0
354562	339597	19553Y	PARTICIPANT	\N	PRESENT	0
354563	339597	19543W	PARTICIPANT	\N	PRESENT	0
354564	339597	11099A	PARTICIPANT	\N	PRESENT	0
354565	339597	19289C	PARTICIPANT	\N	PRESENT	0
354566	339597	19717B	PARTICIPANT	\N	PRESENT	0
354567	339597	14195A	PARTICIPANT	\N	PRESENT	0
354569	339597	19545Y	PARTICIPANT	\N	PRESENT	0
354570	339597	04057K	PARTICIPANT	\N	PRESENT	0
354571	339597	19681G	PARTICIPANT	\N	PRESENT	0
354572	339597	19583F	PARTICIPANT	\N	PRESENT	0
354573	339597	08069G	PARTICIPANT	\N	PRESENT	0
354574	339597	04085P	PARTICIPANT	\N	PRESENT	0
354575	339597	99004R	PARTICIPANT	\N	PRESENT	0
354576	339597	11027H	PARTICIPANT	\N	PRESENT	0
354577	339597	04059M	PARTICIPANT	\N	PRESENT	0
354578	339597	04042C	PARTICIPANT	\N	PRESENT	0
354579	339597	11074Q	PARTICIPANT	\N	PRESENT	0
354580	339597	14159V	PARTICIPANT	\N	PRESENT	0
354581	339597	98035U	PARTICIPANT	\N	PRESENT	0
354582	339597	08055A	PARTICIPANT	\N	PRESENT	0
354583	339597	14051J	PARTICIPANT	\N	PRESENT	0
354584	339597	08052W	PARTICIPANT	\N	PRESENT	0
354585	339597	01028R	PARTICIPANT	\N	PRESENT	0
354586	339597	08028W	PARTICIPANT	\N	PRESENT	0
354587	339597	08068F	PARTICIPANT	\N	PRESENT	0
354588	339597	01048V	PARTICIPANT	\N	PRESENT	0
354589	339597	14151M	PARTICIPANT	\N	PRESENT	0
354590	339597	19715Y	PARTICIPANT	\N	PRESENT	0
354591	339597	14225N	PARTICIPANT	\N	PRESENT	0
354592	339597	11043H	PARTICIPANT	\N	PRESENT	0
354593	339597	14229S	PARTICIPANT	\N	PRESENT	0
354594	339597	14259Y	PARTICIPANT	\N	PRESENT	0
354595	339597	19669L	PARTICIPANT	\N	PRESENT	0
354596	339597	04071H	PARTICIPANT	\N	PRESENT	0
354597	339597	08045X	PARTICIPANT	\N	PRESENT	0
354598	339597	08060W	PARTICIPANT	\N	PRESENT	0
354599	339597	19643A	PARTICIPANT	\N	PRESENT	0
354600	339597	15447F	PARTICIPANT	\N	PRESENT	0
354601	339597	08038Y	PARTICIPANT	\N	PRESENT	0
337608	335293	19711U	PARTICIPANT	\N	PRESENT	0
337609	335293	19531S	PARTICIPANT	\N	PRESENT	0
337623	335293	14097Y	PARTICIPANT	\N	PRESENT	0
333461	326855	19737F	PARTICIPANT	\N	PRESENT	0
333462	326855	08062Y	PARTICIPANT	\N	PRESENT	0
333463	326855	08024S	PARTICIPANT	\N	PRESENT	0
334164	332986	14065Q	PARTICIPANT	\N	PRESENT	0
334165	332986	96004D	PRESIDENT	0	PRESENT	0
334166	332986	14089Y	PARTICIPANT	\N	PRESENT	0
334167	332986	08014Q	PARTICIPANT	\N	EXCUSE	0
334168	332986	14357A	PARTICIPANT	\N	PRESENT	0
334169	332986	11083R	PARTICIPANT	\N	PRESENT	0
334170	332986	14026U	PARTICIPANT	\N	PRESENT	0
334171	332986	19725B	PARTICIPANT	\N	PRESENT	0
334172	332986	95037J	PARTICIPANT	\N	PRESENT	0
334173	332986	04061F	PARTICIPANT	\N	PRESENT	0
334174	332986	14061L	PARTICIPANT	\N	PRESENT	0
334175	332986	11026G	PARTICIPANT	\N	PRESENT	0
334176	332986	14221J	PARTICIPANT	\N	PRESENT	0
334177	332986	19593H	PARTICIPANT	\N	PRESENT	0
334178	332986	14237S	PARTICIPANT	\N	PRESENT	0
334179	332986	14331P	PARTICIPANT	\N	PRESENT	0
336973	336972	04049K	PARTICIPANT	\N	PRESENT	0
337610	335293	07004J	PARTICIPANT	\N	PRESENT	0
337611	335293	11053K	PARTICIPANT	\N	PRESENT	0
337612	335293	11074Q	PRESIDENT	0	PRESENT	0
337613	335293	89017R	PARTICIPANT	\N	PRESENT	0
337614	335293	88008L	PARTICIPANT	\N	PRESENT	0
337615	335293	19671E	PARTICIPANT	\N	PRESENT	0
337616	335293	98035U	PARTICIPANT	\N	PRESENT	0
337617	335293	10015M	PARTICIPANT	\N	PRESENT	0
337618	335293	19725B	PARTICIPANT	\N	PRESENT	0
337619	335293	14237S	PARTICIPANT	\N	PRESENT	0
337620	335293	95037J	PARTICIPANT	\N	PRESENT	0
337621	335293	04097T	PARTICIPANT	\N	PRESENT	0
337622	335293	19563B	PARTICIPANT	\N	PRESENT	0
337624	335293	19479G	PARTICIPANT	\N	PRESENT	0
337625	335293	14357A	PARTICIPANT	\N	PRESENT	0
337626	335293	19545Y	PARTICIPANT	\N	PRESENT	0
337627	335293	14001X	PARTICIPANT	\N	PRESENT	0
337628	335293	14083S	PARTICIPANT	\N	PRESENT	0
337629	335293	14121F	PARTICIPANT	\N	PRESENT	0
337630	335293	14089Y	PARTICIPANT	\N	PRESENT	0
337631	335293	08011M	PARTICIPANT	\N	PRESENT	0
337632	335293	14331P	PARTICIPANT	\N	PRESENT	0
337633	335293	14079W	PARTICIPANT	\N	PRESENT	0
337634	335293	14085U	PARTICIPANT	\N	PRESENT	0
337635	335293	14229S	PARTICIPANT	\N	PRESENT	0
337636	335293	11048N	PARTICIPANT	\N	PRESENT	0
337637	335293	04071H	PARTICIPANT	\N	PRESENT	0
337638	335293	11026G	PARTICIPANT	\N	PRESENT	0
337639	335293	19741B	PARTICIPANT	\N	PRESENT	0
337644	335293	96004D	PARTICIPANT	\N	PRESENT	0
337659	335293	14073Q	PARTICIPANT	\N	PRESENT	0
337661	335293	07029T	PARTICIPANT	\N	EXCUSE	0
337881	335286	19697Q	PARTICIPANT	\N	PRESENT	0
337882	335286	01034P	PARTICIPANT	\N	PRESENT	0
337883	335286	14355X	PARTICIPANT	\N	PRESENT	0
337884	335286	11097X	PARTICIPANT	\N	PRESENT	0
337885	335286	08052W	PARTICIPANT	\N	PRESENT	0
337886	335286	19415P	PARTICIPANT	\N	PRESENT	0
337887	335286	19691J	PARTICIPANT	\N	PRESENT	0
337888	335286	19723Y	PARTICIPANT	\N	PRESENT	0
337889	335286	19553Y	PARTICIPANT	\N	PRESENT	0
337890	335286	11031D	PARTICIPANT	\N	PRESENT	0
337891	335286	19727D	PARTICIPANT	\N	PRESENT	0
337892	335286	14119M	PARTICIPANT	\N	PRESENT	0
337893	335286	14281W	PARTICIPANT	\N	PRESENT	0
337894	335286	19367Y	PARTICIPANT	\N	PRESENT	0
337895	335286	14213J	PARTICIPANT	\N	PRESENT	0
337896	335286	14217N	PARTICIPANT	\N	PRESENT	0
337897	335286	08041T	PARTICIPANT	\N	EXCUSE	0
338150	337899	19593H	PARTICIPANT	\N	PRESENT	0
338151	337899	04070G	PRESIDENT	0	PRESENT	0
338152	337899	19699S	PARTICIPANT	\N	PRESENT	0
338153	337899	14073Q	PARTICIPANT	\N	PRESENT	0
338154	337899	19611R	PARTICIPANT	\N	PRESENT	0
338155	337899	19329S	PARTICIPANT	\N	PRESENT	0
338156	337899	19693L	PARTICIPANT	\N	PRESENT	0
338157	337899	14229S	PARTICIPANT	\N	PRESENT	0
338158	337899	14030Q	PARTICIPANT	\N	PRESENT	0
338159	337899	19731Y	PARTICIPANT	\N	PRESENT	0
338160	337899	19573D	PARTICIPANT	\N	PRESENT	0
338161	337899	19735D	PARTICIPANT	\N	PRESENT	0
338162	337899	08017T	PARTICIPANT	\N	PRESENT	0
338163	337899	11109J	PARTICIPANT	\N	PRESENT	0
338164	337899	11083R	PARTICIPANT	\N	PRESENT	0
338165	337899	08012N	PARTICIPANT	\N	PRESENT	0
338166	337899	19621T	PARTICIPANT	\N	PRESENT	0
338167	337899	14061L	PARTICIPANT	\N	EXCUSE	0
338168	337899	04057K	PARTICIPANT	\N	EXCUSE	0
338169	337899	87003B	PARTICIPANT	\N	EXCUSE	0
338170	337899	19399H	PARTICIPANT	\N	EXCUSE	0
338171	337899	19749K	PARTICIPANT	\N	EXCUSE	0
338172	337899	04018C	PARTICIPANT	\N	EXCUSE	0
338173	337899	19758L	PARTICIPANT	\N	EXCUSE	0
338174	337899	08039A	PARTICIPANT	\N	EXCUSE	0
338176	321411	14034U	PARTICIPANT	\N	PRESENT	0
340056	340055	11040E	PARTICIPANT	\N	PRESENT	0
340057	340055	14085U	PARTICIPANT	\N	PRESENT	0
340058	340055	04071H	PARTICIPANT	\N	PRESENT	0
340059	340055	11074Q	PRESIDENT	0	PRESENT	0
340060	340055	14199E	PARTICIPANT	\N	PRESENT	0
340061	340055	01057W	PARTICIPANT	\N	PRESENT	0
340062	340055	19531S	PARTICIPANT	\N	PRESENT	0
340063	340055	99004R	PARTICIPANT	\N	PRESENT	0
340064	340055	04086Q	PARTICIPANT	\N	PRESENT	0
340065	340055	07029T	PARTICIPANT	\N	PRESENT	0
340066	340055	19711U	PARTICIPANT	\N	PRESENT	0
340067	340055	08034U	PARTICIPANT	\N	PRESENT	0
340068	340055	19479G	PARTICIPANT	\N	PRESENT	0
340069	340055	19689Q	PARTICIPANT	\N	PRESENT	0
340070	340055	14225N	PARTICIPANT	\N	PRESENT	0
340071	340055	08011M	PARTICIPANT	\N	PRESENT	0
340073	339983	08017T	PARTICIPANT	\N	PRESENT	0
340074	339987	11027H	PARTICIPANT	\N	PRESENT	0
344279	340626	14223L	PARTICIPANT	\N	PRESENT	0
344280	340626	19723Y	PARTICIPANT	\N	PRESENT	0
344281	340626	19703U	PARTICIPANT	\N	PRESENT	0
344282	340626	11103C	PARTICIPANT	\N	PRESENT	0
344283	340626	19575F	PARTICIPANT	\N	PRESENT	0
344284	340626	19367Y	PARTICIPANT	\N	PRESENT	0
344285	340626	14213J	PARTICIPANT	\N	PRESENT	0
344286	340626	14217N	PARTICIPANT	\N	PRESENT	0
344287	340626	10006L	PARTICIPANT	\N	PRESENT	0
344288	340626	98024R	PRESIDENT	1	PRESENT	0
344289	340626	11067R	PARTICIPANT	\N	PRESENT	0
344290	340626	04045F	PARTICIPANT	\N	PRESENT	0
344291	340626	14227Q	PARTICIPANT	\N	PRESENT	0
344292	340626	19553Y	PARTICIPANT	\N	PRESENT	0
344293	340626	14281W	PARTICIPANT	\N	PRESENT	0
344294	340626	14042U	PARTICIPANT	\N	PRESENT	0
344295	340626	14261S	PARTICIPANT	\N	PRESENT	0
344296	340626	19683J	PARTICIPANT	\N	PRESENT	0
344297	340626	11045K	PARTICIPANT	\N	PRESENT	0
344298	340626	08052W	PARTICIPANT	\N	PRESENT	0
344299	340626	19301E	PARTICIPANT	\N	PRESENT	0
344300	340626	19691J	PARTICIPANT	\N	PRESENT	0
344301	340626	19717B	PARTICIPANT	\N	PRESENT	0
344302	340626	19727D	PARTICIPANT	\N	PRESENT	0
344303	340626	14071N	PARTICIPANT	\N	PRESENT	0
344304	340626	19760E	PARTICIPANT	\N	PRESENT	0
344305	340626	14119M	PARTICIPANT	\N	PRESENT	0
344306	340626	17779H	PARTICIPANT	\N	PRESENT	0
344307	340626	08048B	PARTICIPANT	\N	PRESENT	0
344308	342127	19768N	PARTICIPANT	\N	PRESENT	0
344309	342127	19515S	PARTICIPANT	\N	PRESENT	0
344310	342127	19782L	PARTICIPANT	\N	PRESENT	0
344311	342127	14357A	PARTICIPANT	\N	PRESENT	0
344312	342127	11099A	PARTICIPANT	\N	PRESENT	0
344313	342127	04049K	PARTICIPANT	\N	PRESENT	0
344314	342127	08015R	PARTICIPANT	\N	PRESENT	0
344315	342127	19369B	PARTICIPANT	\N	PRESENT	0
344316	342127	19511N	PARTICIPANT	\N	PRESENT	0
344317	342127	08028W	PARTICIPANT	\N	PRESENT	0
344318	342127	19563B	PARTICIPANT	\N	PRESENT	0
344319	342127	19591F	PARTICIPANT	\N	PRESENT	0
344320	342127	14135M	PARTICIPANT	\N	PRESENT	0
344321	342127	19467C	PARTICIPANT	\N	PRESENT	0
344322	342127	14187A	PARTICIPANT	\N	PRESENT	0
344323	342127	08062Y	PARTICIPANT	\N	PRESENT	0
344324	342127	11090Q	PRESIDENT	0	PRESENT	0
344325	342127	01025N	PARTICIPANT	\N	PRESENT	0
344326	342127	14033T	PARTICIPANT	\N	PRESENT	0
344327	342127	14205J	PARTICIPANT	\N	PRESENT	0
344328	342127	04088S	PARTICIPANT	\N	PRESENT	0
344329	342127	04089T	PARTICIPANT	\N	PRESENT	0
344330	342127	19507S	PARTICIPANT	\N	PRESENT	0
344331	342127	14207L	PARTICIPANT	\N	PRESENT	0
354944	354228	14229S	PARTICIPANT	\N	PRESENT	0
354945	354228	14241N	PARTICIPANT	\N	PRESENT	0
354946	354228	19573D	PARTICIPANT	\N	PRESENT	0
354947	354228	14039A	PARTICIPANT	\N	PRESENT	0
354948	354228	11083R	PARTICIPANT	\N	PRESENT	0
354949	354228	14063N	PARTICIPANT	\N	PRESENT	0
354950	354228	07033P	PARTICIPANT	\N	PRESENT	0
354951	354228	19335Q	PARTICIPANT	\N	PRESENT	0
354952	354228	19749K	PARTICIPANT	\N	PRESENT	0
354953	354228	04018C	PARTICIPANT	\N	PRESENT	0
354954	354228	08039A	PARTICIPANT	\N	PRESENT	0
354955	354228	08031R	PARTICIPANT	\N	PRESENT	0
354956	352732	14038Y	PRESIDENT	0	PRESENT	0
354957	352732	19681G	PARTICIPANT	\N	PRESENT	0
354958	352732	19685L	PARTICIPANT	\N	EXCUSE	0
354959	354228	19699S	PARTICIPANT	\N	PRESENT	0
354960	354228	04057K	PARTICIPANT	\N	PRESENT	0
354961	354228	11104D	PARTICIPANT	\N	PRESENT	0
354974	354228	14109K	PARTICIPANT	\N	PRESENT	0
354984	352732	19383Y	PARTICIPANT	\N	PRESENT	0
354985	352732	19794Q	PARTICIPANT	\N	PRESENT	0
354986	352732	14031R	PARTICIPANT	\N	PRESENT	0
354987	352732	95062K	PARTICIPANT	\N	PRESENT	0
354988	352732	19549D	PARTICIPANT	\N	PRESENT	0
354989	352732	14221J	PARTICIPANT	\N	PRESENT	0
354990	352732	19599P	PARTICIPANT	\N	PRESENT	0
354991	352732	14169X	PARTICIPANT	\N	PRESENT	0
354992	352732	19637C	PARTICIPANT	\N	PRESENT	0
354993	352732	15447F	PARTICIPANT	\N	PRESENT	0
354994	352732	14051J	PARTICIPANT	\N	PRESENT	0
354995	352732	14029X	PARTICIPANT	\N	PRESENT	0
354996	352732	08060W	PARTICIPANT	\N	PRESENT	0
354997	352732	19733B	PARTICIPANT	\N	PRESENT	0
354998	352732	19347U	PARTICIPANT	\N	PRESENT	0
354999	352732	19737F	PARTICIPANT	\N	PRESENT	0
355000	352732	19503N	PARTICIPANT	\N	PRESENT	0
355001	352732	19739H	PARTICIPANT	\N	PRESENT	0
355002	352732	19659J	PARTICIPANT	\N	PRESENT	0
355003	352732	08024S	PARTICIPANT	\N	PRESENT	0
355004	352732	19525U	PARTICIPANT	\N	PRESENT	0
355005	352732	80027E	PARTICIPANT	\N	PRESENT	0
355006	352732	14093U	PARTICIPANT	\N	PRESENT	0
355011	352732	04085P	PARTICIPANT	\N	PRESENT	0
355015	352732	19387D	PARTICIPANT	\N	PRESENT	0
355016	352732	14191V	PARTICIPANT	\N	PRESENT	0
355017	352732	19745F	PARTICIPANT	\N	PRESENT	0
355018	352732	14219Q	PARTICIPANT	\N	PRESENT	0
355019	352190	01043Q	PARTICIPANT	\N	PRESENT	0
355020	352190	19591F	PARTICIPANT	\N	PRESENT	0
355021	352190	08038Y	PARTICIPANT	\N	PRESENT	0
355022	352190	14207L	PARTICIPANT	\N	PRESENT	0
355025	352732	19713W	PARTICIPANT	\N	PRESENT	0
355027	352732	14237S	PARTICIPANT	\N	PRESENT	0
355028	352732	96004D	PARTICIPANT	\N	PRESENT	0
355046	352732	14103D	PARTICIPANT	\N	PRESENT	0
355047	352732	04097T	PARTICIPANT	\N	PRESENT	0
355048	354228	08012N	PARTICIPANT	\N	PRESENT	0
355049	354228	19643A	PARTICIPANT	\N	PRESENT	0
355050	354228	14123H	PARTICIPANT	\N	PRESENT	0
355051	354228	14061L	PARTICIPANT	\N	EXCUSE	0
355052	354228	08020N	PARTICIPANT	\N	EXCUSE	0
355053	354228	08017T	PARTICIPANT	\N	EXCUSE	0
355054	354228	19758L	PARTICIPANT	\N	EXCUSE	0
355057	352735	14097Y	PARTICIPANT	\N	PRESENT	0
355058	352735	95067Q	PARTICIPANT	\N	PRESENT	0
355059	352735	19443T	PARTICIPANT	\N	PRESENT	0
355060	352735	12041X	PARTICIPANT	\N	PRESENT	0
355061	352735	95030B	PARTICIPANT	\N	PRESENT	0
355062	352735	01062T	PARTICIPANT	\N	PRESENT	0
355063	352735	14235Q	PARTICIPANT	\N	PRESENT	0
355064	352735	14079W	PARTICIPANT	\N	PRESENT	0
355065	352735	04040A	PARTICIPANT	\N	PRESENT	0
355066	352735	16685X	PARTICIPANT	\N	PRESENT	0
355067	352735	04042C	PRESIDENT	0	PRESENT	0
355068	352735	14028W	PARTICIPANT	\N	PRESENT	0
355069	352735	11066Q	PARTICIPANT	\N	PRESENT	0
355070	352735	14105F	PARTICIPANT	\N	PRESENT	0
355071	352735	19421M	PARTICIPANT	\N	PRESENT	0
355072	352735	98022P	PARTICIPANT	\N	PRESENT	0
355073	352735	14193X	PARTICIPANT	\N	PRESENT	0
355074	352735	98050T	PARTICIPANT	\N	PRESENT	0
355075	352735	08061X	PARTICIPANT	\N	PRESENT	0
355076	352735	98029W	PARTICIPANT	\N	PRESENT	0
355077	352735	01058X	PARTICIPANT	\N	PRESENT	0
355078	352735	14267Y	PARTICIPANT	\N	PRESENT	0
355079	352190	19619A	PARTICIPANT	\N	PRESENT	0
355080	352735	19251M	PARTICIPANT	\N	PRESENT	0
355081	352735	19583F	PARTICIPANT	\N	PRESENT	0
355082	352732	05012A	PARTICIPANT	\N	PRESENT	0
355083	352735	97011G	PARTICIPANT	\N	PRESENT	0
355084	352735	08047A	PARTICIPANT	\N	PRESENT	0
355085	352735	14255U	PARTICIPANT	\N	PRESENT	0
355086	354847	01060R	PARTICIPANT	\N	PRESENT	0
355087	352732	19551W	PARTICIPANT	\N	PRESENT	0
355088	352732	02002K	PARTICIPANT	\N	PRESENT	0
355089	352735	11041F	PARTICIPANT	\N	PRESENT	0
355090	353808	14327T	PARTICIPANT	\N	PRESENT	0
355091	353808	14331P	PARTICIPANT	\N	PRESENT	0
355092	353808	95041E	PARTICIPANT	\N	PRESENT	0
355093	353808	19545Y	PARTICIPANT	\N	PRESENT	0
355094	353808	01057W	PARTICIPANT	\N	PRESENT	0
355095	353808	11053K	PARTICIPANT	\N	PRESENT	0
355096	353808	11074Q	PRESIDENT	0	PRESENT	0
355097	353808	89017R	PARTICIPANT	\N	PRESENT	0
355098	353808	19671E	PARTICIPANT	\N	PRESENT	0
355099	353808	14225N	PARTICIPANT	\N	PRESENT	0
355100	353808	88008L	PARTICIPANT	\N	PRESENT	0
355101	353808	14277B	PARTICIPANT	\N	PRESENT	0
355102	353808	14085U	PARTICIPANT	\N	PRESENT	0
355103	353808	07004J	PARTICIPANT	\N	PRESENT	0
355104	353808	08010L	PARTICIPANT	\N	PRESENT	0
355105	353808	14253S	PARTICIPANT	\N	PRESENT	0
355106	353808	11048N	PARTICIPANT	\N	PRESENT	0
355107	353808	19479G	PARTICIPANT	\N	PRESENT	0
355108	353808	19711U	PARTICIPANT	\N	PRESENT	0
355109	353808	19531S	PARTICIPANT	\N	PRESENT	0
355110	353808	08034U	PARTICIPANT	\N	PRESENT	0
355111	353808	19687N	PARTICIPANT	\N	PRESENT	0
355112	353808	19689Q	PARTICIPANT	\N	PRESENT	0
355113	353808	12016W	PARTICIPANT	\N	PRESENT	0
355114	353808	08011M	PARTICIPANT	\N	PRESENT	0
355115	353808	14034U	PARTICIPANT	\N	PRESENT	0
355116	353808	14159V	PARTICIPANT	\N	PRESENT	0
355117	353808	14173T	PARTICIPANT	\N	PRESENT	0
355118	353808	04086Q	PARTICIPANT	\N	PRESENT	0
355119	353808	11040E	PARTICIPANT	\N	PRESENT	0
355120	353808	14083S	PARTICIPANT	\N	PRESENT	0
355121	353808	14199E	PARTICIPANT	\N	PRESENT	0
355122	353808	08073C	PARTICIPANT	\N	PRESENT	0
355123	353808	99004R	PARTICIPANT	\N	PRESENT	0
355124	353808	04061F	PARTICIPANT	\N	PRESENT	0
355125	352732	17637T	PARTICIPANT	\N	PRESENT	0
355126	352732	19701S	PARTICIPANT	\N	PRESENT	0
355127	354228	11109J	PARTICIPANT	\N	PRESENT	0
355128	354228	11043H	PARTICIPANT	\N	PRESENT	0
355129	353808	11110B	PARTICIPANT	\N	PRESENT	0
355130	353808	08069G	PARTICIPANT	\N	PRESENT	0
355131	353808	14121F	PARTICIPANT	\N	PRESENT	0
355132	354228	14107H	PARTICIPANT	\N	PRESENT	0
355134	353808	19349W	PARTICIPANT	\N	PRESENT	0
355135	354228	19533U	PARTICIPANT	\N	PRESENT	0
355136	354228	04033B	PARTICIPANT	\N	PRESENT	0
355137	354228	14059S	PARTICIPANT	\N	PRESENT	0
355138	354228	19621T	PARTICIPANT	\N	PRESENT	0
355141	354229	04070G	PRESIDENT	0	PRESENT	0
355142	354229	19699S	PARTICIPANT	\N	PRESENT	0
355143	354229	19533U	PARTICIPANT	\N	PRESENT	0
355144	354229	04033B	PARTICIPANT	\N	PRESENT	0
355145	354229	19329S	PARTICIPANT	\N	PRESENT	0
355146	354229	14229S	PARTICIPANT	\N	PRESENT	0
355147	354229	14241N	PARTICIPANT	\N	PRESENT	0
355148	354229	19573D	PARTICIPANT	\N	PRESENT	0
355149	354229	14039A	PARTICIPANT	\N	PRESENT	0
355150	354229	14107H	PARTICIPANT	\N	PRESENT	0
355151	354229	92040Q	PARTICIPANT	\N	PRESENT	0
355152	354229	07033P	PARTICIPANT	\N	PRESENT	0
355153	354229	08012N	PARTICIPANT	\N	PRESENT	0
355154	354229	19335Q	PARTICIPANT	\N	PRESENT	0
355155	354229	08039A	PARTICIPANT	\N	PRESENT	0
355156	354229	08031R	PARTICIPANT	\N	PRESENT	0
355157	354229	19593H	PARTICIPANT	\N	PRESENT	0
355158	354229	19643A	PARTICIPANT	\N	PRESENT	0
355159	354229	14059S	PARTICIPANT	\N	PRESENT	0
355161	354229	04057K	PARTICIPANT	\N	PRESENT	0
355162	354229	08035V	PARTICIPANT	\N	PRESENT	0
355163	354229	19611R	PARTICIPANT	\N	PRESENT	0
355164	354229	08043V	PARTICIPANT	\N	PRESENT	0
333610	333609	04008A	PARTICIPANT	\N	PRESENT	0
333612	333609	95063L	PARTICIPANT	\N	PRESENT	0
338207	335130	19693L	PARTICIPANT	\N	PRESENT	0
338209	335130	04043D	PRESIDENT	0	PRESENT	0
338210	335130	01058X	PARTICIPANT	\N	PRESENT	0
338212	335130	19723Y	PARTICIPANT	\N	PRESENT	0
338214	335130	19709B	PARTICIPANT	\N	EXCUSE	0
338215	335130	19511N	PARTICIPANT	\N	EXCUSE	0
338216	335130	19533U	PARTICIPANT	\N	EXCUSE	0
338220	335130	18003S	PARTICIPANT	\N	EXCUSE	0
338223	335130	14299H	PARTICIPANT	\N	EXCUSE	0
338227	335130	01048V	PARTICIPANT	\N	EXCUSE	0
339648	337877	14327T	PARTICIPANT	\N	PRESENT	0
339649	337877	14331P	PARTICIPANT	\N	PRESENT	0
339650	337877	19545Y	PARTICIPANT	\N	PRESENT	0
339651	337877	01057W	PARTICIPANT	\N	PRESENT	0
339652	337877	11053K	PARTICIPANT	\N	PRESENT	0
339653	337877	11074Q	PRESIDENT	0	PRESENT	0
339654	337877	89017R	PARTICIPANT	\N	PRESENT	0
339655	337877	14225N	PARTICIPANT	\N	PRESENT	0
339656	337877	88008L	PARTICIPANT	\N	PRESENT	0
339657	337877	07029T	PARTICIPANT	\N	PRESENT	0
339658	337877	14085U	PARTICIPANT	\N	PRESENT	0
339659	337877	07004J	PARTICIPANT	\N	PRESENT	0
339660	337877	19349W	PARTICIPANT	\N	PRESENT	0
339661	337877	08010L	PARTICIPANT	\N	PRESENT	0
339662	337877	14253S	PARTICIPANT	\N	PRESENT	0
339663	337877	19479G	PARTICIPANT	\N	PRESENT	0
339664	337877	11048N	PARTICIPANT	\N	PRESENT	0
339665	337877	19711U	PARTICIPANT	\N	PRESENT	0
339666	337877	19651A	PARTICIPANT	\N	PRESENT	0
339667	337877	08034U	PARTICIPANT	\N	PRESENT	0
339668	337877	19531S	PARTICIPANT	\N	PRESENT	0
339669	337877	19687N	PARTICIPANT	\N	PRESENT	0
339670	337877	19689Q	PARTICIPANT	\N	PRESENT	0
339671	337877	08011M	PARTICIPANT	\N	PRESENT	0
339672	337877	14173T	PARTICIPANT	\N	PRESENT	0
339673	337877	11040E	PARTICIPANT	\N	PRESENT	0
339674	337877	04086Q	PARTICIPANT	\N	PRESENT	0
339675	337877	11012A	PARTICIPANT	\N	PRESENT	0
339676	337877	14199E	PARTICIPANT	\N	PRESENT	0
339677	337877	19741B	PARTICIPANT	\N	PRESENT	0
339678	337877	14121F	PARTICIPANT	\N	PRESENT	0
339679	337877	99004R	PARTICIPANT	\N	PRESENT	0
339680	337877	11110B	PARTICIPANT	\N	EXCUSE	0
339681	337877	19671E	PARTICIPANT	\N	PRESENT	0
339682	337877	08069G	PARTICIPANT	\N	PRESENT	0
339683	337877	04071H	PARTICIPANT	\N	PRESENT	0
339684	339505	11049P	PARTICIPANT	\N	PRESENT	0
339764	338266	19697Q	PARTICIPANT	\N	PRESENT	0
339765	338266	11067R	PARTICIPANT	\N	PRESENT	0
339766	338266	19649G	PRESIDENT	0	PRESENT	0
339767	338266	19533U	PARTICIPANT	\N	PRESENT	0
339768	338266	14147R	PARTICIPANT	\N	PRESENT	0
339769	338266	08043V	PARTICIPANT	\N	PRESENT	0
339770	338266	19415P	PARTICIPANT	\N	PRESENT	0
339771	338266	19749K	PARTICIPANT	\N	PRESENT	0
339772	338266	04047H	PARTICIPANT	\N	PRESENT	0
339773	338266	14030Q	PARTICIPANT	\N	PRESENT	0
339774	338266	14213J	PARTICIPANT	\N	EXCUSE	0
339775	338266	10006L	PARTICIPANT	\N	EXCUSE	0
339776	338266	19621T	PARTICIPANT	\N	EXCUSE	0
339777	321421	19479G	PARTICIPANT	\N	PRESENT	0
339778	321421	14121F	PARTICIPANT	\N	PRESENT	0
339779	321421	19399H	PARTICIPANT	\N	PRESENT	0
339780	321421	99004R	PARTICIPANT	\N	PRESENT	0
339781	321421	14225N	PARTICIPANT	\N	PRESENT	0
339782	321421	19731Y	PARTICIPANT	\N	PRESENT	0
339783	321421	04092N	PARTICIPANT	\N	PRESENT	0
339784	321421	19711U	PARTICIPANT	\N	PRESENT	0
339785	321421	14105F	PARTICIPANT	\N	PRESENT	0
339786	321421	19651A	PARTICIPANT	\N	PRESENT	0
339787	321421	14042U	PARTICIPANT	\N	PRESENT	0
339788	321421	08039A	PARTICIPANT	\N	PRESENT	0
339809	321421	07029T	PARTICIPANT	\N	PRESENT	0
339831	321421	01058X	PARTICIPANT	\N	PRESENT	0
339832	321421	14119M	PARTICIPANT	\N	PRESENT	0
339833	321421	01057W	PARTICIPANT	\N	PRESENT	0
339834	321421	19507S	PARTICIPANT	\N	PRESENT	0
339835	321421	19629C	PARTICIPANT	\N	PRESENT	0
339836	321421	11048N	PARTICIPANT	\N	PRESENT	0
339837	321421	11097X	PARTICIPANT	\N	PRESENT	0
339838	321421	14097Y	PARTICIPANT	\N	PRESENT	0
339839	321421	19367Y	PARTICIPANT	\N	PRESENT	0
339840	321421	14265W	PARTICIPANT	\N	PRESENT	0
339841	321421	08061X	PARTICIPANT	\N	PRESENT	0
339842	321421	19467C	PARTICIPANT	\N	PRESENT	0
339843	321421	19387D	PARTICIPANT	\N	PRESENT	0
339844	321421	04086Q	PARTICIPANT	\N	PRESENT	0
339845	321421	14109K	PARTICIPANT	\N	PRESENT	0
339846	321421	14281W	PARTICIPANT	\N	PRESENT	0
339847	321421	14107H	PARTICIPANT	\N	PRESENT	0
339848	321421	19543W	PARTICIPANT	\N	PRESENT	0
339849	321421	14033T	PARTICIPANT	\N	PRESENT	0
339850	321421	08015R	PARTICIPANT	\N	PRESENT	0
339851	321421	11104D	PARTICIPANT	\N	PRESENT	0
339852	321421	19581D	PARTICIPANT	\N	PRESENT	0
339853	321421	19719D	PARTICIPANT	\N	PRESENT	0
339854	321421	19441R	PARTICIPANT	\N	PRESENT	0
339855	321421	14327T	PARTICIPANT	\N	PRESENT	0
339856	321421	07004J	PARTICIPANT	\N	PRESENT	0
339857	321421	19673G	PARTICIPANT	\N	PRESENT	0
339858	321421	14089Y	PARTICIPANT	\N	PRESENT	0
339859	321421	14217N	PARTICIPANT	\N	PRESENT	0
339860	321421	89017R	PARTICIPANT	\N	PRESENT	0
339861	321421	19575F	PARTICIPANT	\N	PRESENT	0
339862	321421	14259Y	PARTICIPANT	\N	PRESENT	0
339863	321421	19741B	PARTICIPANT	\N	PRESENT	0
339864	321421	11070L	PARTICIPANT	\N	PRESENT	0
339868	321421	19747H	PARTICIPANT	\N	PRESENT	0
339866	321421	08028W	PARTICIPANT	\N	PRESENT	0
339867	321421	14215L	PARTICIPANT	\N	PRESENT	0
339869	321421	08010L	PARTICIPANT	\N	PRESENT	0
339870	321421	19447X	PARTICIPANT	\N	PRESENT	0
339871	321421	11012A	PARTICIPANT	\N	PRESENT	0
339872	321421	14123H	PARTICIPANT	\N	PRESENT	0
339873	321421	14219Q	PARTICIPANT	\N	PRESENT	0
339874	321421	08017T	PARTICIPANT	\N	PRESENT	0
339875	321421	97011G	PARTICIPANT	\N	PRESENT	0
339879	321421	08024S	PARTICIPANT	\N	PRESENT	0
339877	321421	19531S	PARTICIPANT	\N	PRESENT	0
339878	321421	19782L	PARTICIPANT	\N	PRESENT	0
339880	321421	14179A	PARTICIPANT	\N	PRESENT	0
339881	321421	19295A	PARTICIPANT	\N	PRESENT	0
339882	338266	11045K	PARTICIPANT	\N	PRESENT	0
339883	338266	01028R	PARTICIPANT	\N	PRESENT	0
339884	338266	11043H	PARTICIPANT	\N	PRESENT	0
339885	321421	80013X	PARTICIPANT	\N	PRESENT	0
339886	321421	01024M	PARTICIPANT	\N	PRESENT	0
339887	321421	19695N	PARTICIPANT	\N	PRESENT	0
339888	321421	14021P	PARTICIPANT	\N	PRESENT	0
339889	321421	14079W	PARTICIPANT	\N	PRESENT	0
339890	321421	14083S	PARTICIPANT	\N	PRESENT	0
339891	321421	04088S	PARTICIPANT	\N	PRESENT	0
339892	321421	14173T	PARTICIPANT	\N	PRESENT	0
339893	321421	14135M	PARTICIPANT	\N	PRESENT	0
339894	321421	19415P	PARTICIPANT	\N	PRESENT	0
339895	321421	14205J	PARTICIPANT	\N	PRESENT	0
339896	321421	14073Q	PARTICIPANT	\N	PRESENT	0
339897	321421	08034U	PARTICIPANT	\N	PRESENT	0
339898	321421	19683J	PARTICIPANT	\N	PRESENT	0
339899	321421	11109J	PARTICIPANT	\N	PRESENT	0
339900	321421	19689Q	PARTICIPANT	\N	PRESENT	0
339901	321421	04018C	PARTICIPANT	\N	PRESENT	0
339902	321421	88008L	PARTICIPANT	\N	PRESENT	0
339903	321421	08045X	PARTICIPANT	\N	PRESENT	0
339904	321421	19693L	PARTICIPANT	\N	PRESENT	0
339905	321421	19383Y	PARTICIPANT	\N	PRESENT	0
339906	321421	19533U	PARTICIPANT	\N	PRESENT	0
339907	321421	19503N	PARTICIPANT	\N	PRESENT	0
339908	321421	19569H	PARTICIPANT	\N	PRESENT	0
339909	321421	14147R	PARTICIPANT	\N	PRESENT	0
339910	321421	14038Y	PARTICIPANT	\N	PRESENT	0
339911	321421	11085T	PARTICIPANT	\N	PRESENT	0
339912	321421	08031R	PARTICIPANT	\N	PRESENT	0
339925	337096	14038Y	PARTICIPANT	\N	PRESENT	0
339926	337096	19383Y	PARTICIPANT	\N	PRESENT	0
339927	337096	19333N	PARTICIPANT	\N	PRESENT	0
339928	337096	19701S	PARTICIPANT	\N	PRESENT	0
339929	337096	14219Q	PARTICIPANT	\N	PRESENT	0
339930	337096	14169X	PARTICIPANT	\N	PRESENT	0
354602	339597	80013X	PARTICIPANT	\N	PRESENT	0
354603	339597	14028W	PARTICIPANT	\N	PRESENT	0
354604	339597	10015M	PARTICIPANT	\N	PRESENT	0
354605	339597	11045K	PARTICIPANT	\N	PRESENT	0
354606	339597	95067Q	PARTICIPANT	\N	PRESENT	0
354607	339597	14197C	PARTICIPANT	\N	PRESENT	0
354608	339597	87003B	PARTICIPANT	\N	PRESENT	0
354609	339597	19727D	PARTICIPANT	\N	PRESENT	0
354610	339597	01057W	PARTICIPANT	\N	PRESENT	0
354611	339597	11080N	PARTICIPANT	\N	PRESENT	0
354612	339597	19649G	PARTICIPANT	\N	PRESENT	0
354613	339597	08035V	PARTICIPANT	\N	PRESENT	0
354614	339597	14191V	PARTICIPANT	\N	PRESENT	0
354615	339597	11077T	PARTICIPANT	\N	PRESENT	0
354616	339597	19515S	PARTICIPANT	\N	PRESENT	0
354617	339597	14281W	PARTICIPANT	\N	PRESENT	0
354618	339597	19703U	PARTICIPANT	\N	PRESENT	0
354619	339597	11104D	PARTICIPANT	\N	PRESENT	0
354620	339597	19673G	PARTICIPANT	\N	PRESENT	0
354621	339597	08043V	PARTICIPANT	\N	PRESENT	0
354622	339597	11010L	PARTICIPANT	\N	PRESENT	0
354623	339597	11066Q	PARTICIPANT	\N	PRESENT	0
354624	339597	14065Q	PARTICIPANT	\N	PRESENT	0
354625	339597	11115U	PARTICIPANT	\N	PRESENT	0
354626	339597	14081Q	PARTICIPANT	\N	PRESENT	0
354627	339597	14199E	PARTICIPANT	\N	PRESENT	0
354628	339597	14173T	PARTICIPANT	\N	PRESENT	0
354629	339597	19447X	PARTICIPANT	\N	PRESENT	0
354630	339597	08012N	PARTICIPANT	\N	PRESENT	0
354631	339597	19573D	PARTICIPANT	\N	PRESENT	0
354632	339597	19531S	PARTICIPANT	\N	PRESENT	0
354633	339597	19794Q	PARTICIPANT	\N	PRESENT	0
354634	339597	14227Q	PARTICIPANT	\N	PRESENT	0
354636	339597	14257W	PARTICIPANT	\N	PRESENT	0
354637	339597	19525U	PARTICIPANT	\N	PRESENT	0
354638	339597	08053X	PARTICIPANT	\N	PRESENT	0
354639	339597	14119M	PARTICIPANT	\N	PRESENT	0
354640	339597	08017T	PARTICIPANT	\N	PRESENT	0
354641	339597	11049P	PARTICIPANT	\N	PRESENT	0
354642	339597	14033T	PARTICIPANT	\N	PRESENT	0
354643	339597	14085U	PARTICIPANT	\N	PRESENT	0
354644	339597	14135M	PARTICIPANT	\N	PRESENT	0
354645	339597	14121F	PARTICIPANT	\N	PRESENT	0
354646	339597	08019V	PARTICIPANT	\N	PRESENT	0
354647	339597	17779H	PARTICIPANT	\N	PRESENT	0
354648	339597	19489J	PARTICIPANT	\N	PRESENT	0
354649	339597	19399H	PARTICIPANT	\N	PRESENT	0
354650	339597	19295A	PARTICIPANT	\N	PRESENT	0
354651	339597	07029T	PARTICIPANT	\N	PRESENT	0
354652	339597	11065P	PARTICIPANT	\N	PRESENT	0
354653	339597	19415P	PARTICIPANT	\N	PRESENT	0
354654	339597	19689Q	PARTICIPANT	\N	PRESENT	0
354655	339597	19467C	PARTICIPANT	\N	PRESENT	0
354656	339597	08014Q	PARTICIPANT	\N	PRESENT	0
354657	339597	18083K	PARTICIPANT	\N	PRESENT	0
354658	339597	14207L	PARTICIPANT	\N	PRESENT	0
354659	339597	14038Y	PARTICIPANT	\N	PRESENT	0
354660	339597	19549D	PARTICIPANT	\N	PRESENT	0
354661	339597	19443T	PARTICIPANT	\N	PRESENT	0
354662	339597	11041F	PARTICIPANT	\N	PRESENT	0
354663	339597	19725B	PARTICIPANT	\N	PRESENT	0
354664	339597	14029X	PARTICIPANT	\N	PRESENT	0
354665	339597	19709B	PARTICIPANT	\N	PRESENT	0
354666	339597	14097Y	PARTICIPANT	\N	PRESENT	0
354667	339597	19663E	PARTICIPANT	\N	PRESENT	0
354668	339597	19631V	PARTICIPANT	\N	PRESENT	0
354669	339597	14063N	PARTICIPANT	\N	PRESENT	0
354670	339597	19527W	PARTICIPANT	\N	PRESENT	0
354671	339597	19551W	PARTICIPANT	\N	PRESENT	0
354672	339597	04088S	PARTICIPANT	\N	PRESENT	0
354673	339597	11067R	PARTICIPANT	\N	PRESENT	0
354674	339597	19503N	PARTICIPANT	\N	PRESENT	0
354675	339597	19591F	PARTICIPANT	\N	PRESENT	0
354676	339597	14041T	PARTICIPANT	\N	PRESENT	0
354677	339597	11026G	PARTICIPANT	\N	PRESENT	0
354678	339597	19251M	PARTICIPANT	\N	PRESENT	0
354679	339597	14031R	PARTICIPANT	\N	PRESENT	0
354680	339597	19413M	PARTICIPANT	\N	PRESENT	0
354681	339597	95030B	PARTICIPANT	\N	PRESENT	0
354682	339597	95063L	PARTICIPANT	\N	PRESENT	0
354683	339597	19269X	PARTICIPANT	\N	PRESENT	0
354684	339597	11101A	PARTICIPANT	\N	PRESENT	0
354685	339597	08073C	PARTICIPANT	\N	PRESENT	0
354686	339597	98024R	PARTICIPANT	\N	PRESENT	0
354687	339597	04047H	PARTICIPANT	\N	PRESENT	0
354688	339597	08024S	PARTICIPANT	\N	PRESENT	0
354689	339597	14026U	PARTICIPANT	\N	PRESENT	0
354690	339597	04092N	PARTICIPANT	\N	PRESENT	0
354691	339597	19697Q	PARTICIPANT	\N	PRESENT	0
354692	339597	04044E	PARTICIPANT	\N	PRESENT	0
354693	339597	14109K	PARTICIPANT	\N	PRESENT	0
354694	339597	04086Q	PARTICIPANT	\N	PRESENT	0
354695	339597	04033B	PARTICIPANT	\N	PRESENT	0
354696	339597	19687N	PARTICIPANT	\N	PRESENT	0
354697	339597	14187A	PARTICIPANT	\N	PRESENT	0
354698	339597	14069U	PARTICIPANT	\N	PRESENT	0
354699	339597	19695N	PARTICIPANT	\N	PRESENT	0
354700	339597	95041E	PARTICIPANT	\N	PRESENT	0
354701	339597	14055N	PARTICIPANT	\N	PRESENT	0
354702	339597	89017R	PARTICIPANT	\N	PRESENT	0
354703	339597	14053L	PARTICIPANT	\N	PRESENT	0
354704	339597	01060R	PARTICIPANT	\N	PRESENT	0
354730	339597	16685X	PARTICIPANT	\N	PRESENT	0
354706	339597	11097X	PARTICIPANT	\N	PRESENT	0
354707	339597	19421M	PARTICIPANT	\N	PRESENT	0
354708	339597	14261S	PARTICIPANT	\N	PRESENT	0
354709	339597	19629C	PARTICIPANT	\N	PRESENT	0
354710	339597	14237S	PARTICIPANT	\N	PRESENT	0
354711	339597	08031R	PARTICIPANT	\N	PRESENT	0
354712	339597	14241N	PARTICIPANT	\N	PRESENT	0
354713	339597	19671E	PARTICIPANT	\N	PRESENT	0
354714	339597	14193X	PARTICIPANT	\N	PRESENT	0
354715	339597	14231L	PARTICIPANT	\N	PRESENT	0
354716	339597	19691J	PARTICIPANT	\N	PRESENT	0
354717	339597	01034P	PARTICIPANT	\N	PRESENT	0
354718	339597	14215L	PARTICIPANT	\N	PRESENT	0
354719	339597	19369B	PARTICIPANT	\N	PRESENT	0
354720	339597	04070G	PARTICIPANT	\N	PRESENT	0
354721	339597	11053K	PARTICIPANT	\N	PRESENT	0
354722	339597	19747H	PARTICIPANT	\N	PRESENT	0
354723	339597	19611R	PARTICIPANT	\N	PRESENT	0
354724	339597	19737F	PARTICIPANT	\N	PRESENT	0
354725	339597	14205J	PARTICIPANT	\N	PRESENT	0
354726	339597	14331P	PARTICIPANT	\N	PRESENT	0
354727	339597	19699S	PARTICIPANT	\N	PRESENT	0
354728	339597	19619A	PARTICIPANT	\N	PRESENT	0
354729	339597	14087W	PARTICIPANT	\N	PRESENT	0
354731	339597	11070L	PARTICIPANT	\N	PRESENT	0
354732	339597	19533U	PARTICIPANT	\N	PRESENT	0
354733	339597	04089T	PARTICIPANT	\N	PRESENT	0
354734	339597	08034U	PARTICIPANT	\N	PRESENT	0
354735	339597	14042U	PARTICIPANT	\N	PRESENT	0
354736	339597	19713W	PARTICIPANT	\N	PRESENT	0
354737	339597	14219Q	PARTICIPANT	\N	PRESENT	0
354738	339597	19479G	PARTICIPANT	\N	PRESENT	0
354739	339597	19441R	PARTICIPANT	\N	PRESENT	0
354740	339597	14275Y	PARTICIPANT	\N	PRESENT	0
354741	339597	14169X	PARTICIPANT	\N	PRESENT	0
354742	339597	19575F	PARTICIPANT	\N	PRESENT	0
354743	339597	14267Y	PARTICIPANT	\N	PRESENT	0
354744	339597	80027E	PARTICIPANT	\N	PRESENT	0
354745	339597	08047A	PARTICIPANT	\N	PRESENT	0
354746	339597	14103D	PARTICIPANT	\N	PRESENT	0
354747	339597	14221J	PARTICIPANT	\N	PRESENT	0
354748	339597	19739H	PARTICIPANT	\N	PRESENT	0
354749	339597	14253S	PARTICIPANT	\N	PRESENT	0
354750	339597	11048N	PARTICIPANT	\N	PRESENT	0
354751	339597	14073Q	PARTICIPANT	\N	PRESENT	0
354752	339597	14089Y	PARTICIPANT	\N	PRESENT	0
354753	339597	19749K	PARTICIPANT	\N	PRESENT	0
354754	339597	19745F	PARTICIPANT	\N	PRESENT	0
354755	339597	04049K	PARTICIPANT	\N	PRESENT	0
354756	339597	11090Q	PARTICIPANT	\N	PRESENT	0
354757	339597	17583W	PARTICIPANT	\N	PRESENT	0
354758	339597	14147R	PARTICIPANT	\N	PRESENT	0
354759	339597	14265W	PARTICIPANT	\N	PRESENT	0
354760	339597	08048B	PARTICIPANT	\N	PRESENT	0
354761	339597	14115H	PARTICIPANT	\N	PRESENT	0
354762	339597	19768N	PARTICIPANT	\N	PRESENT	0
354763	339597	19705W	PARTICIPANT	\N	PRESENT	0
354764	339597	08015R	PARTICIPANT	\N	PRESENT	0
354765	339597	08062Y	PARTICIPANT	\N	PRESENT	0
354766	339597	14355X	PARTICIPANT	\N	PRESENT	0
354767	339597	14357A	PARTICIPANT	\N	PRESENT	0
354768	339597	14329V	PARTICIPANT	\N	PRESENT	0
354769	339597	11103C	PARTICIPANT	\N	PRESENT	0
354770	339597	97011G	PARTICIPANT	\N	PRESENT	0
333452	333451	14255U	PARTICIPANT	\N	PRESENT	0
333453	333451	14083S	PARTICIPANT	\N	PRESENT	0
333454	333451	11110B	PARTICIPANT	\N	PRESENT	0
333455	333451	11067R	PARTICIPANT	\N	PRESENT	0
333456	333451	01062T	PARTICIPANT	\N	PRESENT	0
333457	333451	11101A	PARTICIPANT	\N	PRESENT	0
335131	335130	08053X	PARTICIPANT	\N	EXCUSE	0
340439	340438	96004D	PARTICIPANT	\N	EXCUSE	0
340440	340438	14135M	PARTICIPANT	\N	EXCUSE	0
340441	340438	14331P	PARTICIPANT	\N	EXCUSE	0
340450	340449	10006L	PARTICIPANT	\N	PRESENT	0
344332	342127	17589D	PARTICIPANT	\N	PRESENT	0
344333	342127	19619A	PARTICIPANT	\N	PRESENT	0
344334	340626	14087W	PARTICIPANT	\N	PRESENT	0
344335	340626	08041T	PARTICIPANT	\N	EXCUSE	0
344336	342127	14081Q	PARTICIPANT	\N	PRESENT	0
344337	342127	08068F	PARTICIPANT	\N	PRESENT	0
344338	342127	19695N	PARTICIPANT	\N	PRESENT	0
344339	342127	14257W	PARTICIPANT	\N	PRESENT	0
344341	340626	19527W	PARTICIPANT	\N	PRESENT	0
344342	340626	01034P	PARTICIPANT	\N	PRESENT	0
344343	342172	08060W	PARTICIPANT	\N	PRESENT	0
344344	342172	19681G	PARTICIPANT	\N	PRESENT	0
344345	342172	08024S	PARTICIPANT	\N	PRESENT	0
344346	342172	04097T	PARTICIPANT	\N	PRESENT	0
344347	342172	19733B	PARTICIPANT	\N	PRESENT	0
344464	342919	14259Y	PARTICIPANT	\N	PRESENT	0
344465	342919	11072N	PARTICIPANT	\N	PRESENT	0
344466	342919	08044W	PARTICIPANT	\N	PRESENT	0
344467	342172	18083K	PARTICIPANT	\N	PRESENT	0
344468	342172	14093U	PARTICIPANT	\N	PRESENT	0
344469	342188	08056B	PARTICIPANT	\N	PRESENT	0
344941	344573	17779H	PARTICIPANT	\N	PRESENT	0
344942	344573	08052W	PARTICIPANT	\N	PRESENT	0
344943	344573	19683J	PARTICIPANT	\N	PRESENT	0
344944	344573	14207L	PARTICIPANT	\N	PRESENT	0
344945	344573	19301E	PARTICIPANT	\N	PRESENT	0
344946	344573	14073Q	PARTICIPANT	\N	PRESENT	0
344947	344573	08056B	PARTICIPANT	\N	PRESENT	0
344948	344573	19521Q	PARTICIPANT	\N	PRESENT	0
344949	344573	11085T	PARTICIPANT	\N	PRESENT	0
344950	344573	14219Q	PARTICIPANT	\N	PRESENT	0
344951	344573	19441R	PARTICIPANT	\N	PRESENT	0
344952	344573	14195A	PARTICIPANT	\N	PRESENT	0
344953	344573	19369B	PARTICIPANT	\N	PRESENT	0
344954	344573	19479G	PARTICIPANT	\N	PRESENT	0
344955	344573	19691J	PARTICIPANT	\N	PRESENT	0
344956	344573	19719D	PARTICIPANT	\N	PRESENT	0
344957	344573	19387D	PARTICIPANT	\N	PRESENT	0
344958	344573	07029T	PARTICIPANT	\N	PRESENT	0
344959	344823	08031R	PARTICIPANT	\N	PRESENT	0
344960	344573	08048B	PARTICIPANT	\N	PRESENT	0
344961	344573	19575F	PARTICIPANT	\N	PRESENT	0
344962	344573	19794Q	PARTICIPANT	\N	PRESENT	0
344963	344573	14217N	PARTICIPANT	\N	PRESENT	0
344964	344573	11031D	PARTICIPANT	\N	PRESENT	0
344965	344573	88008L	PARTICIPANT	\N	PRESENT	0
344966	344573	01024M	PARTICIPANT	\N	PRESENT	0
344967	344573	19703U	PARTICIPANT	\N	PRESENT	0
344969	344968	11053K	PARTICIPANT	\N	PRESENT	0
344970	344968	14159V	PARTICIPANT	\N	PRESENT	0
344602	343407	19593H	PARTICIPANT	\N	PRESENT	0
344603	343407	14059S	PARTICIPANT	\N	PRESENT	0
344604	343407	19643A	PARTICIPANT	\N	PRESENT	0
344605	343407	14061L	PARTICIPANT	\N	PRESENT	0
344606	343407	19699S	PARTICIPANT	\N	PRESENT	0
344607	343407	04057K	PARTICIPANT	\N	PRESENT	0
344608	343407	19611R	PARTICIPANT	\N	PRESENT	0
344609	343407	19693L	PARTICIPANT	\N	PRESENT	0
344610	343407	14229S	PARTICIPANT	\N	PRESENT	0
344611	343407	14030Q	PARTICIPANT	\N	PRESENT	0
344612	343407	14241N	PARTICIPANT	\N	PRESENT	0
344613	343407	19731Y	PARTICIPANT	\N	PRESENT	0
344614	343407	14251Q	PARTICIPANT	\N	PRESENT	0
344615	343407	19573D	PARTICIPANT	\N	PRESENT	0
344616	343407	14039A	PARTICIPANT	\N	PRESENT	0
344617	343407	11109J	PARTICIPANT	\N	PRESENT	0
344618	343407	14063N	PARTICIPANT	\N	PRESENT	0
344619	343407	14109K	PARTICIPANT	\N	PRESENT	0
344620	343407	14123H	PARTICIPANT	\N	PRESENT	0
344621	343407	08012N	PARTICIPANT	\N	PRESENT	0
344622	343407	11104D	PARTICIPANT	\N	PRESENT	0
344623	343407	19758L	PARTICIPANT	\N	PRESENT	0
344624	343407	08039A	PARTICIPANT	\N	PRESENT	0
344625	343407	08031R	PARTICIPANT	\N	PRESENT	0
344626	343407	14073Q	PARTICIPANT	\N	EXCUSE	0
344627	343407	08043V	PARTICIPANT	\N	EXCUSE	0
344628	343407	87003B	PARTICIPANT	\N	EXCUSE	0
344629	343407	14249W	PARTICIPANT	\N	EXCUSE	0
344971	344968	05012A	PARTICIPANT	\N	PRESENT	0
344972	344573	11101A	PARTICIPANT	\N	PRESENT	0
344973	344573	19553Y	PARTICIPANT	\N	PRESENT	0
344974	344573	14042U	PARTICIPANT	\N	PRESENT	0
344976	342191	97011G	PARTICIPANT	\N	EXCUSE	0
344977	342191	14028W	PARTICIPANT	\N	EXCUSE	0
344978	342191	11054L	PARTICIPANT	\N	EXCUSE	0
344979	342191	11041F	PARTICIPANT	\N	EXCUSE	0
345267	341436	19515S	PARTICIPANT	\N	PRESENT	0
345268	341436	04038G	PARTICIPANT	\N	PRESENT	0
345299	345295	14205J	PARTICIPANT	\N	PRESENT	0
345300	345296	14205J	PARTICIPANT	\N	PRESENT	0
345301	345297	14205J	PARTICIPANT	\N	PRESENT	0
345302	345298	14205J	PARTICIPANT	\N	PRESENT	0
345320	339508	01043Q	PARTICIPANT	\N	PRESENT	0
345304	345296	19745F	PARTICIPANT	\N	PRESENT	0
345319	341436	11066Q	PARTICIPANT	\N	PRESENT	0
345321	339508	07034Q	PARTICIPANT	\N	PRESENT	0
345322	339508	14053L	PARTICIPANT	\N	PRESENT	0
345323	339508	19583F	PARTICIPANT	\N	PRESENT	0
345324	339508	14207L	PARTICIPANT	\N	PRESENT	0
345325	339508	19631V	PARTICIPANT	\N	PRESENT	0
345326	339508	19681G	PARTICIPANT	\N	PRESENT	0
345327	339508	19629C	PARTICIPANT	\N	PRESENT	0
345328	339508	05008E	PARTICIPANT	\N	PRESENT	0
345329	339508	88008L	PARTICIPANT	\N	PRESENT	0
345330	339508	08056B	PARTICIPANT	\N	PRESENT	0
345331	339508	01060R	PARTICIPANT	\N	PRESENT	0
345332	339508	19467C	PARTICIPANT	\N	PRESENT	0
345333	339508	14069U	PARTICIPANT	\N	PRESENT	0
345334	339508	11056N	PARTICIPANT	\N	PRESENT	0
345335	339508	14135M	PARTICIPANT	\N	PRESENT	0
345336	339508	04088S	PARTICIPANT	\N	PRESENT	0
345337	339508	19415P	PARTICIPANT	\N	PRESENT	0
345338	339508	14105F	PARTICIPANT	\N	PRESENT	0
344939	344573	01043Q	PARTICIPANT	\N	PRESENT	0
345339	339508	14223L	PARTICIPANT	\N	PRESENT	0
345340	339508	02002K	PARTICIPANT	\N	PRESENT	0
345341	339508	08045X	PARTICIPANT	\N	PRESENT	0
345342	339508	08052W	PARTICIPANT	\N	PRESENT	0
345343	339508	01025N	PARTICIPANT	\N	PRESENT	0
345344	339508	19543W	PARTICIPANT	\N	PRESENT	0
345345	339508	19333N	PARTICIPANT	\N	PRESENT	0
345346	339508	14173T	PARTICIPANT	\N	PRESENT	0
345347	339508	18083K	PARTICIPANT	\N	PRESENT	0
344940	342191	19251M	PARTICIPANT	\N	PRESENT	0
345348	339508	14235Q	PARTICIPANT	\N	PRESENT	0
345349	339508	80027E	PARTICIPANT	\N	PRESENT	0
345350	339508	19673G	PARTICIPANT	\N	PRESENT	0
345351	339508	14219Q	PARTICIPANT	\N	PRESENT	0
345352	339508	14267Y	PARTICIPANT	\N	PRESENT	0
345353	339508	14327T	PARTICIPANT	\N	PRESENT	0
345354	339508	19758L	PARTICIPANT	\N	PRESENT	0
345355	339508	19565D	PARTICIPANT	\N	PRESENT	0
345356	339508	14063N	PARTICIPANT	\N	PRESENT	0
345357	339508	19731Y	PARTICIPANT	\N	PRESENT	0
345358	339508	14061L	PARTICIPANT	\N	PRESENT	0
345359	339508	14217N	PARTICIPANT	\N	PRESENT	0
345360	339508	14073Q	PARTICIPANT	\N	PRESENT	0
345361	339508	14109K	PARTICIPANT	\N	PRESENT	0
345362	339508	14107H	PARTICIPANT	\N	PRESENT	0
345363	339508	14241N	PARTICIPANT	\N	PRESENT	0
345364	339508	07029T	PARTICIPANT	\N	PRESENT	0
345365	339508	19713W	PARTICIPANT	\N	PRESENT	0
345366	339508	19747H	PARTICIPANT	\N	PRESENT	0
345367	339508	08034U	PARTICIPANT	\N	PRESENT	0
345368	339508	98050T	PARTICIPANT	\N	PRESENT	0
345369	339508	01024M	PARTICIPANT	\N	PRESENT	0
345370	339508	19301E	PARTICIPANT	\N	PRESENT	0
345371	339508	14030Q	PARTICIPANT	\N	PRESENT	0
345372	339508	08010L	PARTICIPANT	\N	PRESENT	0
345373	339508	19507S	PARTICIPANT	\N	PRESENT	0
345374	339508	14157T	PARTICIPANT	\N	PRESENT	0
344768	342191	14097Y	PARTICIPANT	\N	PRESENT	0
344769	342191	12041X	PARTICIPANT	\N	PRESENT	0
344770	342191	95030B	PARTICIPANT	\N	PRESENT	0
344771	342191	01062T	PARTICIPANT	\N	PRESENT	0
344772	342191	14133K	PARTICIPANT	\N	PRESENT	0
344773	342191	01058X	PARTICIPANT	\N	PRESENT	0
344774	342191	14079W	PARTICIPANT	\N	PRESENT	0
355165	354229	19693L	PARTICIPANT	\N	PRESENT	0
355166	354229	19399H	PARTICIPANT	\N	PRESENT	0
355167	354229	87003B	PARTICIPANT	\N	PRESENT	0
355168	354229	14201E	PARTICIPANT	\N	PRESENT	0
355169	354229	14030Q	PARTICIPANT	\N	PRESENT	0
355170	354229	11109J	PARTICIPANT	\N	PRESENT	0
355171	354229	11083R	PARTICIPANT	\N	PRESENT	0
355172	354229	14063N	PARTICIPANT	\N	PRESENT	0
355203	345100	11070L	PARTICIPANT	\N	PRESENT	0
355174	354229	14123H	PARTICIPANT	\N	PRESENT	0
355175	354229	11104D	PARTICIPANT	\N	PRESENT	0
355176	354229	11043H	PARTICIPANT	\N	PRESENT	0
355177	354229	19749K	PARTICIPANT	\N	PRESENT	0
355178	354229	04018C	PARTICIPANT	\N	PRESENT	0
355179	354229	19621T	PARTICIPANT	\N	PRESENT	0
355180	354229	14061L	PARTICIPANT	\N	EXCUSE	0
355181	354229	08020N	PARTICIPANT	\N	EXCUSE	0
355182	354229	08017T	PARTICIPANT	\N	EXCUSE	0
355183	354229	19758L	PARTICIPANT	\N	EXCUSE	0
355184	354229	14249W	PARTICIPANT	\N	PRESENT	0
355185	353808	11070L	PARTICIPANT	\N	PRESENT	0
355186	353808	11012A	PARTICIPANT	\N	PRESENT	0
355188	354229	14251Q	PARTICIPANT	\N	PRESENT	0
355202	354229	14073Q	PARTICIPANT	\N	PRESENT	0
355205	345100	08060W	PARTICIPANT	\N	PRESENT	0
355206	345100	19681G	PARTICIPANT	\N	PRESENT	0
355212	345100	14041T	PARTICIPANT	\N	PRESENT	0
355213	345100	14105F	PARTICIPANT	\N	PRESENT	0
355214	345100	01025N	PARTICIPANT	\N	PRESENT	0
355215	345100	19583F	PARTICIPANT	\N	PRESENT	0
355216	345100	19737F	PARTICIPANT	\N	PRESENT	0
355217	345100	14038Y	PARTICIPANT	\N	PRESENT	0
355218	345100	19387D	PARTICIPANT	\N	PRESENT	0
355219	345100	14107H	PARTICIPANT	\N	PRESENT	0
355220	345100	19637C	PARTICIPANT	\N	PRESENT	0
355221	345100	19629C	PARTICIPANT	\N	PRESENT	0
355222	345100	08031R	PARTICIPANT	\N	PRESENT	0
355223	345100	17637T	PARTICIPANT	\N	PRESENT	0
355224	345100	19503N	PARTICIPANT	\N	PRESENT	0
355225	345100	14197C	PARTICIPANT	\N	PRESENT	0
355226	345100	08051V	PARTICIPANT	\N	PRESENT	0
355227	345100	14063N	PARTICIPANT	\N	PRESENT	0
355228	345100	19347U	PARTICIPANT	\N	PRESENT	0
355229	345100	08049C	PARTICIPANT	\N	PRESENT	0
355230	345100	14033T	PARTICIPANT	\N	PRESENT	0
355231	345100	19383Y	PARTICIPANT	\N	PRESENT	0
355232	345100	95030B	PARTICIPANT	\N	PRESENT	0
355233	345100	97011G	PARTICIPANT	\N	PRESENT	0
355234	345100	14327T	PARTICIPANT	\N	PRESENT	0
355235	345100	19507S	PARTICIPANT	\N	PRESENT	0
355236	345100	04088S	PARTICIPANT	\N	PRESENT	0
355237	345100	14029X	PARTICIPANT	\N	PRESENT	0
355238	345100	08028W	PARTICIPANT	\N	PRESENT	0
355239	345100	14221J	PARTICIPANT	\N	PRESENT	0
355240	345100	11066Q	PARTICIPANT	\N	PRESENT	0
355241	345100	14147R	PARTICIPANT	\N	PRESENT	0
355242	345100	19553Y	PARTICIPANT	\N	PRESENT	0
355243	345100	14265W	PARTICIPANT	\N	PRESENT	0
355244	345100	95062K	PARTICIPANT	\N	PRESENT	0
355245	345100	99004R	PARTICIPANT	\N	PRESENT	0
355246	345100	14219Q	PARTICIPANT	\N	PRESENT	0
355247	345100	19399H	PARTICIPANT	\N	PRESENT	0
355248	345100	08012N	PARTICIPANT	\N	PRESENT	0
355249	345100	19525U	PARTICIPANT	\N	PRESENT	0
355250	345100	01062T	PARTICIPANT	\N	PRESENT	0
355251	345100	14207L	PARTICIPANT	\N	PRESENT	0
355252	345100	14331P	PARTICIPANT	\N	PRESENT	0
355253	345100	14026U	PARTICIPANT	\N	PRESENT	0
355254	345100	14257W	PARTICIPANT	\N	PRESENT	0
355255	345100	19794Q	PARTICIPANT	\N	PRESENT	0
355256	345100	19467C	PARTICIPANT	\N	PRESENT	0
355257	345100	17589D	PARTICIPANT	\N	PRESENT	0
355258	345100	14103D	PARTICIPANT	\N	PRESENT	0
355259	345100	19760E	PARTICIPANT	\N	PRESENT	0
355260	345100	19725B	PARTICIPANT	\N	PRESENT	0
355261	345100	88008L	PARTICIPANT	\N	PRESENT	0
355262	345100	11012A	PARTICIPANT	\N	PRESENT	0
355263	345100	19533U	PARTICIPANT	\N	PRESENT	0
355264	345100	08015R	PARTICIPANT	\N	PRESENT	0
355265	345100	19719D	PARTICIPANT	\N	PRESENT	0
355266	345100	14111D	PARTICIPANT	\N	PRESENT	0
355267	345100	19679N	PARTICIPANT	\N	PRESENT	0
355268	345100	19575F	PARTICIPANT	\N	PRESENT	0
355269	345100	14241N	PARTICIPANT	\N	PRESENT	0
355270	345100	11097X	PARTICIPANT	\N	PRESENT	0
355271	345100	19733B	PARTICIPANT	\N	PRESENT	0
355272	345100	11104D	PARTICIPANT	\N	PRESENT	0
355273	345100	19713W	PARTICIPANT	\N	PRESENT	0
355274	345100	14031R	PARTICIPANT	\N	PRESENT	0
355275	345100	02002K	PARTICIPANT	\N	PRESENT	0
355276	345100	19441R	PARTICIPANT	\N	PRESENT	0
355277	345100	19768N	PARTICIPANT	\N	PRESENT	0
355278	345100	14073Q	PARTICIPANT	\N	PRESENT	0
355279	345100	19703U	PARTICIPANT	\N	PRESENT	0
355280	345100	19631V	PARTICIPANT	\N	PRESENT	0
355309	345100	19739H	PARTICIPANT	\N	PRESENT	0
355310	345100	14051J	PARTICIPANT	\N	PRESENT	0
355311	345100	19543W	PARTICIPANT	\N	PRESENT	0
355312	345100	19782L	PARTICIPANT	\N	PRESENT	0
355313	345100	01058X	PARTICIPANT	\N	PRESENT	0
355314	345100	80027E	PARTICIPANT	\N	PRESENT	0
355315	345100	14065Q	PARTICIPANT	\N	PRESENT	0
355316	345100	80013X	PARTICIPANT	\N	PRESENT	0
355317	345100	14115H	PARTICIPANT	\N	PRESENT	0
355318	345100	08039A	PARTICIPANT	\N	PRESENT	0
355319	345100	01060R	PARTICIPANT	\N	PRESENT	0
355320	345100	14151M	PARTICIPANT	\N	PRESENT	0
355321	345100	14169X	PARTICIPANT	\N	PRESENT	0
355322	345100	14191V	PARTICIPANT	\N	PRESENT	0
355323	345100	14267Y	PARTICIPANT	\N	PRESENT	0
355324	345100	14121F	PARTICIPANT	\N	PRESENT	0
355325	345100	19573D	PARTICIPANT	\N	PRESENT	0
355326	345100	14042U	PARTICIPANT	\N	PRESENT	0
355327	345100	19745F	PARTICIPANT	\N	PRESENT	0
355328	354848	14065Q	PARTICIPANT	\N	PRESENT	0
355329	354848	19649G	PARTICIPANT	\N	PRESENT	0
355330	354848	14111D	PARTICIPANT	\N	PRESENT	0
355331	354848	07034Q	PARTICIPANT	\N	PRESENT	0
355332	354848	10015M	PARTICIPANT	\N	PRESENT	0
355333	354848	19543W	PARTICIPANT	\N	PRESENT	0
355334	354848	01024M	PARTICIPANT	\N	PRESENT	0
355335	354848	19673G	PARTICIPANT	\N	PRESENT	0
355336	354848	19719D	PARTICIPANT	\N	PRESENT	0
355337	354848	01028R	PARTICIPANT	\N	PRESENT	0
355346	345100	14217N	PARTICIPANT	\N	PRESENT	0
355339	354848	19447X	PARTICIPANT	\N	PRESENT	0
355340	354848	14041T	PARTICIPANT	\N	PRESENT	0
355341	354848	14147R	PARTICIPANT	\N	PRESENT	0
355342	354848	14151M	PARTICIPANT	\N	PRESENT	0
355343	354848	95063L	PARTICIPANT	\N	PRESENT	0
355344	345100	19619A	PARTICIPANT	\N	PRESENT	0
355345	345100	11065P	PARTICIPANT	\N	PRESENT	0
355347	345100	19443T	PARTICIPANT	\N	PRESENT	0
355348	345100	14179A	PARTICIPANT	\N	PRESENT	0
355349	345100	19659J	PARTICIPANT	\N	PRESENT	0
355350	345100	19479G	PARTICIPANT	\N	PRESENT	0
355351	345100	14235Q	PARTICIPANT	\N	PRESENT	0
355352	345100	11054L	PARTICIPANT	\N	PRESENT	0
355353	345100	14059S	PARTICIPANT	\N	PRESENT	0
355354	345100	08061X	PARTICIPANT	\N	PRESENT	0
355355	345100	19521Q	PARTICIPANT	\N	PRESENT	0
355356	345100	19511N	PARTICIPANT	\N	PRESENT	0
355357	345100	19721W	PARTICIPANT	\N	PRESENT	0
355358	345100	19749K	PARTICIPANT	\N	PRESENT	0
355392	355368	14097Y	PARTICIPANT	\N	PRESENT	0
355360	345100	14069U	PARTICIPANT	\N	PRESENT	0
355361	345100	19695N	PARTICIPANT	\N	PRESENT	0
355362	345100	14083S	PARTICIPANT	\N	PRESENT	0
355363	345100	14259Y	PARTICIPANT	\N	PRESENT	0
355364	353835	19553Y	PARTICIPANT	\N	PRESENT	0
355365	353835	14147R	PARTICIPANT	\N	PRESENT	0
355366	353835	19749K	PARTICIPANT	\N	PRESENT	0
355367	353835	08031R	PRESIDENT	0	PRESENT	0
355369	345100	19413M	PARTICIPANT	\N	PRESENT	0
355370	353835	19295A	PARTICIPANT	\N	PRESENT	0
355371	353835	11067R	PARTICIPANT	\N	EXCUSE	0
355372	353835	19569H	PARTICIPANT	\N	EXCUSE	0
355373	353835	14213J	PARTICIPANT	\N	EXCUSE	0
355374	353835	04047H	PARTICIPANT	\N	EXCUSE	0
355375	353835	10006L	PARTICIPANT	\N	EXCUSE	0
355376	353835	19621T	PARTICIPANT	\N	EXCUSE	0
355393	355368	11048N	PARTICIPANT	\N	PRESENT	0
355394	355368	14051J	PARTICIPANT	\N	PRESENT	0
355395	355368	95067Q	PARTICIPANT	\N	PRESENT	0
355396	355368	08060W	PARTICIPANT	\N	PRESENT	0
355397	355368	19733B	PRESIDENT	0	PRESENT	0
355398	355368	19745F	PARTICIPANT	\N	PRESENT	0
355399	355368	19747H	PARTICIPANT	\N	PRESENT	0
355400	355368	08024S	PARTICIPANT	\N	PRESENT	0
355401	355368	14038Y	PARTICIPANT	\N	EXCUSE	0
355402	355368	19629C	PARTICIPANT	\N	PRESENT	0
335381	335380	04040A	PARTICIPANT	\N	PRESENT	0
335382	335380	98022P	PARTICIPANT	\N	PRESENT	0
335383	335380	14241N	PARTICIPANT	\N	PRESENT	0
335384	335380	19563B	PARTICIPANT	\N	PRESENT	0
335385	335380	08015R	PARTICIPANT	\N	PRESENT	0
339931	337096	18083K	PARTICIPANT	\N	PRESENT	0
339932	337096	14051J	PARTICIPANT	\N	PRESENT	0
339933	337096	08009T	PRESIDENT	0	PRESENT	0
339934	337096	19503N	PARTICIPANT	\N	PRESENT	0
339935	337096	19737F	PARTICIPANT	\N	PRESENT	0
339936	337096	04097T	PARTICIPANT	\N	PRESENT	0
339937	337096	08024S	PARTICIPANT	\N	PRESENT	0
339938	337096	17583W	PARTICIPANT	\N	EXCUSE	0
339939	337096	08060W	PARTICIPANT	\N	EXCUSE	0
339940	337096	19685L	PARTICIPANT	\N	EXCUSE	0
339941	337096	19637C	PARTICIPANT	\N	EXCUSE	0
339946	337096	14157T	PARTICIPANT	\N	PRESENT	0
339947	337096	19347U	PARTICIPANT	\N	PRESENT	0
339954	337096	19549D	PARTICIPANT	\N	PRESENT	0
339955	337096	19387D	PARTICIPANT	\N	PRESENT	0
339961	337096	19782L	PARTICIPANT	\N	PRESENT	0
339962	337096	19441R	PARTICIPANT	\N	PRESENT	0
339963	337096	19413M	PARTICIPANT	\N	PRESENT	0
339964	337096	80013X	PARTICIPANT	\N	PRESENT	0
339965	337096	08068F	PARTICIPANT	\N	PRESENT	0
339966	337096	08015R	PARTICIPANT	\N	PRESENT	0
339967	337096	19511N	PARTICIPANT	\N	PRESENT	0
339968	337096	08028W	PARTICIPANT	\N	PRESENT	0
339969	337096	11065P	PARTICIPANT	\N	PRESENT	0
339970	337096	14265W	PARTICIPANT	\N	PRESENT	0
339971	337096	14135M	PARTICIPANT	\N	PRESENT	0
339972	337096	19695N	PARTICIPANT	\N	PRESENT	0
339973	337096	14033T	PARTICIPANT	\N	PRESENT	0
339974	337096	11090Q	PARTICIPANT	\N	PRESENT	0
339975	337096	14205J	PARTICIPANT	\N	PRESENT	0
339976	337096	04088S	PARTICIPANT	\N	PRESENT	0
339977	337096	19507S	PARTICIPANT	\N	PRESENT	0
339978	337096	19747H	PARTICIPANT	\N	PRESENT	0
339979	337096	14207L	PARTICIPANT	\N	PRESENT	0
339980	337096	17589D	PARTICIPANT	\N	PRESENT	0
339981	337096	19619A	PARTICIPANT	\N	PRESENT	0
339982	337096	14257W	PARTICIPANT	\N	PRESENT	0
339990	337096	14357A	PARTICIPANT	\N	PRESENT	0
339991	337096	19525U	PARTICIPANT	\N	PRESENT	0
339992	337096	05012A	PARTICIPANT	\N	PRESENT	0
339993	337096	19681G	PARTICIPANT	\N	PRESENT	0
339994	339983	14041T	PARTICIPANT	\N	PRESENT	0
340452	340408	04038G	PARTICIPANT	\N	PRESENT	0
339996	339984	14041T	PARTICIPANT	\N	PRESENT	0
339997	339984	11026G	PARTICIPANT	\N	PRESENT	0
339998	339985	14041T	PARTICIPANT	\N	PRESENT	0
339999	339985	11026G	PARTICIPANT	\N	PRESENT	0
340000	339986	14041T	PARTICIPANT	\N	PRESENT	0
340454	340453	14107H	PARTICIPANT	\N	PRESENT	0
340002	337065	19383Y	PARTICIPANT	\N	PRESENT	0
340003	337065	19333N	PARTICIPANT	\N	PRESENT	0
340004	337065	19782L	PARTICIPANT	\N	PRESENT	0
340005	337065	19701S	PARTICIPANT	\N	PRESENT	0
340006	337065	14357A	PARTICIPANT	\N	PRESENT	0
340007	337065	19549D	PARTICIPANT	\N	PRESENT	0
340008	337065	19441R	PARTICIPANT	\N	PRESENT	0
340009	337065	19387D	PARTICIPANT	\N	PRESENT	0
340010	337065	19413M	PARTICIPANT	\N	PRESENT	0
340011	337065	14219Q	PARTICIPANT	\N	PRESENT	0
340012	337065	80013X	PARTICIPANT	\N	PRESENT	0
340013	337065	18083K	PARTICIPANT	\N	PRESENT	0
340014	337065	05012A	PARTICIPANT	\N	PRESENT	0
340015	337065	08068F	PARTICIPANT	\N	PRESENT	0
340016	337065	14051J	PARTICIPANT	\N	PRESENT	0
340017	337065	08015R	PARTICIPANT	\N	PRESENT	0
340018	337065	19503N	PARTICIPANT	\N	PRESENT	0
340019	337065	19347U	PARTICIPANT	\N	PRESENT	0
340020	337065	14157T	PARTICIPANT	\N	PRESENT	0
340021	337065	19511N	PARTICIPANT	\N	PRESENT	0
340022	337065	19681G	PARTICIPANT	\N	PRESENT	0
340023	337065	08024S	PARTICIPANT	\N	PRESENT	0
340024	337065	08028W	PARTICIPANT	\N	PRESENT	0
340025	337065	14265W	PARTICIPANT	\N	PRESENT	0
340026	337065	11065P	PARTICIPANT	\N	PRESENT	0
340027	337065	19525U	PARTICIPANT	\N	PRESENT	0
340028	337065	14135M	PARTICIPANT	\N	PRESENT	0
340029	337065	14038Y	PARTICIPANT	\N	PRESENT	0
340030	337065	19695N	PARTICIPANT	\N	PRESENT	0
340031	337065	14033T	PARTICIPANT	\N	PRESENT	0
340032	337065	11090Q	PRESIDENT	0	PRESENT	0
340033	337065	14169X	PARTICIPANT	\N	PRESENT	0
340034	337065	14205J	PARTICIPANT	\N	PRESENT	0
340035	337065	04088S	PARTICIPANT	\N	PRESENT	0
340036	337065	19507S	PARTICIPANT	\N	PRESENT	0
340037	337065	08009T	PARTICIPANT	\N	PRESENT	0
340038	337065	19737F	PARTICIPANT	\N	PRESENT	0
340039	337065	04097T	PARTICIPANT	\N	PRESENT	0
340040	337065	19747H	PARTICIPANT	\N	PRESENT	0
340041	337065	14207L	PARTICIPANT	\N	PRESENT	0
340042	337065	17589D	PARTICIPANT	\N	PRESENT	0
340043	337065	19619A	PARTICIPANT	\N	PRESENT	0
340044	337065	14257W	PARTICIPANT	\N	PRESENT	0
340045	337065	19768N	PARTICIPANT	\N	EXCUSE	0
340046	337065	19515S	PARTICIPANT	\N	EXCUSE	0
340047	337065	04049K	PARTICIPANT	\N	EXCUSE	0
340048	337065	08038Y	PARTICIPANT	\N	EXCUSE	0
340049	337065	14197C	PARTICIPANT	\N	EXCUSE	0
340050	337065	08021P	PARTICIPANT	\N	EXCUSE	0
340051	337065	11081P	PARTICIPANT	\N	EXCUSE	0
340052	337065	19631V	PARTICIPANT	\N	EXCUSE	0
340053	339987	14041T	PARTICIPANT	\N	PRESENT	0
340486	340091	19715Y	PARTICIPANT	\N	PRESENT	0
340489	340480	04086Q	PARTICIPANT	\N	EXCUSE	0
340490	340480	04040A	PRESIDENT	0	PRESENT	0
340491	340480	11048N	PARTICIPANT	\N	EXCUSE	0
340497	340480	14071N	PARTICIPANT	\N	EXCUSE	0
341060	340388	14195A	PARTICIPANT	\N	PRESENT	0
341064	340388	14087W	PARTICIPANT	\N	PRESENT	0
341120	340388	19663E	PARTICIPANT	\N	PRESENT	0
341232	340483	12041X	PARTICIPANT	\N	PRESENT	0
341233	340483	11080N	PARTICIPANT	\N	PRESENT	0
341234	340483	95030B	PARTICIPANT	\N	PRESENT	0
341235	340483	04034C	PARTICIPANT	\N	PRESENT	0
341236	340483	14079W	PARTICIPANT	\N	PRESENT	0
341237	340483	01058X	PARTICIPANT	\N	PRESENT	0
341238	340483	04042C	PRESIDENT	0	PRESENT	0
341239	340483	11066Q	PARTICIPANT	\N	PRESENT	0
341240	340483	08056B	PARTICIPANT	\N	PRESENT	0
341241	340483	11115U	PARTICIPANT	\N	PRESENT	0
341242	340483	19421M	PARTICIPANT	\N	PRESENT	0
341243	340483	19709B	PARTICIPANT	\N	PRESENT	0
341244	340483	97011G	PARTICIPANT	\N	PRESENT	0
341245	340483	08061X	PARTICIPANT	\N	PRESENT	0
341246	340483	08047A	PARTICIPANT	\N	PRESENT	0
341247	340483	98029W	PARTICIPANT	\N	PRESENT	0
341248	340483	14097Y	PARTICIPANT	\N	PRESENT	0
341249	340483	01062T	PARTICIPANT	\N	PRESENT	0
341250	340483	14133K	PARTICIPANT	\N	PRESENT	0
341251	340483	11041F	PARTICIPANT	\N	PRESENT	0
341252	340483	14235Q	PARTICIPANT	\N	PRESENT	0
341253	340483	08058D	PARTICIPANT	\N	PRESENT	0
341254	340483	14028W	PARTICIPANT	\N	PRESENT	0
341255	340483	19251M	PARTICIPANT	\N	PRESENT	0
341256	340483	19721W	PARTICIPANT	\N	PRESENT	0
341257	340483	14105F	PARTICIPANT	\N	PRESENT	0
341258	340483	14267Y	PARTICIPANT	\N	PRESENT	0
341259	340483	19583F	PARTICIPANT	\N	PRESENT	0
341260	340483	14211G	PARTICIPANT	\N	PRESENT	0
341261	340483	14255U	PARTICIPANT	\N	PRESENT	0
341262	340483	16685X	PARTICIPANT	\N	PRESENT	0
341263	340483	11054L	PARTICIPANT	\N	PRESENT	0
341264	340483	04035D	PARTICIPANT	\N	PRESENT	0
341265	340483	98050T	PARTICIPANT	\N	PRESENT	0
341266	340488	19383Y	PARTICIPANT	\N	PRESENT	0
341267	340488	19701S	PARTICIPANT	\N	PRESENT	0
341268	340488	19794Q	PARTICIPANT	\N	PRESENT	0
341269	340488	14031R	PARTICIPANT	\N	PRESENT	0
341270	340488	95062K	PARTICIPANT	\N	PRESENT	0
341271	340488	19387D	PARTICIPANT	\N	PRESENT	0
341272	340488	14219Q	PARTICIPANT	\N	PRESENT	0
341273	340488	14221J	PARTICIPANT	\N	PRESENT	0
341274	340488	08055A	PARTICIPANT	\N	PRESENT	0
341275	340488	19599P	PARTICIPANT	\N	PRESENT	0
341276	340488	19637C	PARTICIPANT	\N	PRESENT	0
341277	340488	04085P	PARTICIPANT	\N	PRESENT	0
341278	340488	19551W	PARTICIPANT	\N	PRESENT	0
341279	340488	18083K	PARTICIPANT	\N	PRESENT	0
341280	340488	15447F	PARTICIPANT	\N	PRESENT	0
341281	340488	14237S	PARTICIPANT	\N	PRESENT	0
341282	340488	14051J	PARTICIPANT	\N	PRESENT	0
341283	340488	08060W	PARTICIPANT	\N	PRESENT	0
341284	340488	19503N	PARTICIPANT	\N	PRESENT	0
341285	340488	19347U	PARTICIPANT	\N	PRESENT	0
341286	340488	14157T	PARTICIPANT	\N	PRESENT	0
354773	339597	14217N	PARTICIPANT	\N	PRESENT	0
354774	339597	19675J	PARTICIPANT	\N	PRESENT	0
354775	339597	19383Y	PARTICIPANT	\N	PRESENT	0
354776	339597	19762G	PARTICIPANT	\N	PRESENT	0
354777	339597	19701S	PARTICIPANT	\N	PRESENT	0
354778	339597	04018C	PARTICIPANT	\N	PRESENT	0
354779	339597	14093U	PARTICIPANT	\N	PRESENT	0
354780	339597	19621T	PARTICIPANT	\N	PRESENT	0
354781	339597	07034Q	PARTICIPANT	\N	PRESENT	0
354782	339597	17589D	PARTICIPANT	\N	PRESENT	0
354783	339597	19733B	PARTICIPANT	\N	PRESENT	0
354784	339597	14083S	PARTICIPANT	\N	PRESENT	0
354785	339597	14059S	PARTICIPANT	\N	PRESENT	0
354786	339597	98050T	PARTICIPANT	\N	PRESENT	0
354787	339597	86034E	PARTICIPANT	\N	PRESENT	0
354788	339597	05012A	PARTICIPANT	\N	PRESENT	0
354789	339597	92040Q	PARTICIPANT	\N	PRESENT	0
354790	339597	14071N	PARTICIPANT	\N	PRESENT	0
354791	339597	08051V	PARTICIPANT	\N	PRESENT	0
354792	339597	02002K	PARTICIPANT	\N	PRESENT	0
354793	339597	19693L	PARTICIPANT	\N	PRESENT	0
354794	339597	05008E	PARTICIPANT	\N	PRESENT	0
354795	339597	04040A	PARTICIPANT	\N	PRESENT	0
354796	339597	19577H	PARTICIPANT	\N	PRESENT	0
354797	339597	01043Q	PARTICIPANT	\N	PRESENT	0
354798	339597	14030Q	PARTICIPANT	\N	PRESENT	0
354799	339597	14327T	PARTICIPANT	\N	PRESENT	0
354800	339597	01024M	PARTICIPANT	\N	PRESENT	0
354801	339597	01025N	PARTICIPANT	\N	PRESENT	0
354802	339597	11085T	PARTICIPANT	\N	PRESENT	0
354803	339597	07004J	PARTICIPANT	\N	PRESENT	0
354804	339597	14255U	PARTICIPANT	\N	PRESENT	0
354805	339597	19521Q	PARTICIPANT	\N	PRESENT	0
354806	339597	19335Q	PARTICIPANT	\N	PRESENT	0
354807	339597	19760E	PARTICIPANT	\N	PRESENT	0
354808	339597	19507S	PARTICIPANT	\N	PRESENT	0
354809	339597	11110B	PARTICIPANT	\N	PRESENT	0
354810	339597	04061F	PARTICIPANT	\N	PRESENT	0
354811	339597	11109J	PARTICIPANT	\N	PRESENT	0
354812	339597	14105F	PARTICIPANT	\N	PRESENT	0
354813	339597	19657G	PARTICIPANT	\N	PRESENT	0
354771	339597	07033P	PARTICIPANT	\N	PRESENT	0
354772	339597	14021P	PARTICIPANT	\N	PRESENT	0
354814	339597	19723Y	PARTICIPANT	\N	PRESENT	0
354815	339597	14251Q	PARTICIPANT	\N	PRESENT	0
354816	339597	14123H	PARTICIPANT	\N	PRESENT	0
354964	352536	19565D	PARTICIPANT	\N	PRESENT	0
354962	352536	19717B	PARTICIPANT	\N	PRESENT	0
354963	352536	19683J	PARTICIPANT	\N	PRESENT	0
354965	352536	08052W	PARTICIPANT	\N	PRESENT	0
354966	352536	11103C	PARTICIPANT	\N	PRESENT	0
354967	352536	14217N	PARTICIPANT	\N	PRESENT	0
354968	352536	04092N	PRESIDENT	0	PRESENT	0
354969	352536	14355X	PARTICIPANT	\N	PRESENT	0
354970	352536	19760E	PARTICIPANT	\N	PRESENT	0
354971	352536	19521Q	PARTICIPANT	\N	PRESENT	0
354972	352536	11031D	PARTICIPANT	\N	PRESENT	0
354973	352536	19577H	PARTICIPANT	\N	PRESENT	0
354975	352536	11067R	PARTICIPANT	\N	PRESENT	0
354976	352536	19415P	PARTICIPANT	\N	PRESENT	0
354977	352536	19663E	PARTICIPANT	\N	PRESENT	0
354978	352536	14281W	PARTICIPANT	\N	PRESENT	0
354979	352536	08048B	PARTICIPANT	\N	PRESENT	0
354980	352536	08041T	PARTICIPANT	\N	EXCUSE	0
354981	352536	19527W	PARTICIPANT	\N	EXCUSE	0
354982	352536	14261S	PARTICIPANT	\N	PRESENT	0
354983	352536	19715Y	PARTICIPANT	\N	PRESENT	0
355007	352536	98024R	PARTICIPANT	\N	PRESENT	0
355008	352536	19703U	PARTICIPANT	\N	PRESENT	0
355009	352536	14195A	PARTICIPANT	\N	PRESENT	0
355010	352536	14087W	PARTICIPANT	\N	PRESENT	0
355012	352536	19723Y	PARTICIPANT	\N	PRESENT	0
355013	352536	14071N	PARTICIPANT	\N	PRESENT	0
355014	352536	19679N	PARTICIPANT	\N	PRESENT	0
355023	352536	19657G	PARTICIPANT	\N	PRESENT	0
355026	352536	04045F	PARTICIPANT	\N	PRESENT	0
355029	352536	19575F	PARTICIPANT	\N	PRESENT	0
355034	352536	14227Q	PARTICIPANT	\N	PRESENT	0
355035	352536	19727D	PARTICIPANT	\N	PRESENT	0
355038	352536	14239U	PARTICIPANT	\N	PRESENT	0
355040	352536	19697Q	PARTICIPANT	\N	PRESENT	0
355041	352536	11097X	PARTICIPANT	\N	PRESENT	0
355042	352536	17779H	PARTICIPANT	\N	PRESENT	0
355044	352536	19553Y	PARTICIPANT	\N	PRESENT	0
355045	352536	19691J	PARTICIPANT	\N	PRESENT	0
355055	352536	14119M	PARTICIPANT	\N	PRESENT	0
355056	352536	14026U	PARTICIPANT	\N	PRESENT	0
355139	352536	14042U	PARTICIPANT	\N	PRESENT	0
355140	352536	01034P	PARTICIPANT	\N	PRESENT	0
355197	355196	04040A	PARTICIPANT	\N	PRESENT	0
355378	355377	19515S	PARTICIPANT	\N	PRESENT	0
355379	355377	08068F	PARTICIPANT	\N	PRESENT	0
355380	355377	14083S	PARTICIPANT	\N	PRESENT	0
355381	355377	04071H	PARTICIPANT	\N	PRESENT	0
355382	355377	11110B	PARTICIPANT	\N	PRESENT	0
355383	355377	19521Q	PARTICIPANT	\N	PRESENT	0
355384	355377	14034U	PARTICIPANT	\N	PRESENT	0
355385	355377	19695N	PARTICIPANT	\N	PRESENT	0
355386	355377	11048N	PARTICIPANT	\N	PRESENT	0
355387	355377	04049K	PARTICIPANT	\N	PRESENT	0
355388	355377	19711U	PARTICIPANT	\N	PRESENT	0
355552	353835	19673G	PARTICIPANT	\N	PRESENT	0
355596	355595	11040E	PARTICIPANT	\N	PRESENT	0
355597	355595	14255U	PARTICIPANT	\N	PRESENT	0
355598	355595	14147R	PARTICIPANT	\N	PRESENT	0
355599	355595	92040Q	PARTICIPANT	\N	PRESENT	0
355600	355595	14069U	PARTICIPANT	\N	PRESENT	0
355601	355595	96004D	PARTICIPANT	\N	PRESENT	0
355847	355707	14065Q	PARTICIPANT	\N	EXCUSE	0
355848	355707	08018U	PARTICIPANT	\N	EXCUSE	0
356320	356319	14187A	PARTICIPANT	\N	PRESENT	0
356321	356319	19695N	PARTICIPANT	\N	PRESENT	0
356322	356319	11090Q	PARTICIPANT	\N	PRESENT	0
356323	356319	04086Q	PARTICIPANT	\N	PRESENT	0
356325	356324	11056N	PARTICIPANT	\N	PRESENT	0
356326	356324	14187A	PARTICIPANT	\N	PRESENT	0
356327	356324	14115H	PARTICIPANT	\N	PRESENT	0
356328	356324	11090Q	PARTICIPANT	\N	PRESENT	0
356329	356324	08048B	PARTICIPANT	\N	PRESENT	0
356334	356333	08017T	PARTICIPANT	\N	PRESENT	0
356335	356333	14107H	PARTICIPANT	\N	PRESENT	0
356336	356333	19611R	PARTICIPANT	\N	PRESENT	0
356337	356333	19693L	PARTICIPANT	\N	PRESENT	0
356339	356338	14107H	PARTICIPANT	\N	PRESENT	0
356340	356338	19611R	PARTICIPANT	\N	PRESENT	0
356341	356338	08043V	PARTICIPANT	\N	PRESENT	0
356342	356338	19693L	PARTICIPANT	\N	PRESENT	0
356343	356338	08017T	PARTICIPANT	\N	PRESENT	0
356348	351756	08012N	PARTICIPANT	\N	PRESENT	0
356620	356618	04044E	PARTICIPANT	\N	PRESENT	0
356638	351756	89017R	PARTICIPANT	\N	EXCUSE	0
356644	351756	08024S	PARTICIPANT	\N	PRESENT	0
356748	356747	14107H	PARTICIPANT	\N	PRESENT	0
356749	356747	19611R	PARTICIPANT	\N	PRESENT	0
356750	356747	08017T	PARTICIPANT	\N	PRESENT	0
356752	356751	14107H	PARTICIPANT	\N	PRESENT	0
356753	356751	19611R	PARTICIPANT	\N	PRESENT	0
356754	356751	19621T	PARTICIPANT	\N	PRESENT	0
356980	341435	14107H	PARTICIPANT	\N	PRESENT	0
357023	356254	14115H	PARTICIPANT	\N	PRESENT	0
357024	356254	19507S	PARTICIPANT	\N	PRESENT	0
357025	356254	11101A	PARTICIPANT	\N	PRESENT	0
357026	356254	19747H	PARTICIPANT	\N	PRESENT	0
357027	356254	14207L	PARTICIPANT	\N	PRESENT	0
357028	356254	17589D	PARTICIPANT	\N	PRESENT	0
357029	356254	19619A	PARTICIPANT	\N	PRESENT	0
357030	356254	14257W	PARTICIPANT	\N	PRESENT	0
357031	356254	19705W	PARTICIPANT	\N	EXCUSE	0
357032	356254	19295A	PARTICIPANT	\N	EXCUSE	0
357033	356254	08021P	PARTICIPANT	\N	EXCUSE	0
357034	356254	11081P	PARTICIPANT	\N	EXCUSE	0
357035	356254	14329V	PARTICIPANT	\N	EXCUSE	0
357038	356854	04070G	PRESIDENT	0	PRESENT	0
357039	356854	19533U	PARTICIPANT	\N	PRESENT	0
357040	356854	04033B	PARTICIPANT	\N	PRESENT	0
357041	356854	14241N	PARTICIPANT	\N	PRESENT	0
357042	356854	19573D	PARTICIPANT	\N	PRESENT	0
357043	356854	14039A	PARTICIPANT	\N	PRESENT	0
357044	356854	08017T	PARTICIPANT	\N	PRESENT	0
357045	356854	92040Q	PARTICIPANT	\N	PRESENT	0
357046	356854	07033P	PARTICIPANT	\N	PRESENT	0
357047	356854	08012N	PARTICIPANT	\N	PRESENT	0
357048	356854	19335Q	PARTICIPANT	\N	PRESENT	0
357049	356854	14249W	PARTICIPANT	\N	PRESENT	0
357050	356854	08039A	PARTICIPANT	\N	PRESENT	0
357051	356854	08031R	PARTICIPANT	\N	PRESENT	0
357052	356854	19593H	PARTICIPANT	\N	PRESENT	0
357053	356854	19643A	PARTICIPANT	\N	PRESENT	0
357054	356854	14059S	PARTICIPANT	\N	PRESENT	0
333066	333065	11090Q	PARTICIPANT	\N	PRESENT	0
333067	333065	14033T	PARTICIPANT	\N	PRESENT	0
333068	333065	14257W	PARTICIPANT	\N	PRESENT	0
333069	333065	19619A	PARTICIPANT	\N	PRESENT	0
333070	333065	11056N	PARTICIPANT	\N	PRESENT	0
333071	333065	08015R	PARTICIPANT	\N	PRESENT	0
333908	333056	19621T	PARTICIPANT	\N	PRESENT	0
334832	334831	11048N	PARTICIPANT	\N	PRESENT	0
336136	335739	19251M	PARTICIPANT	\N	PRESENT	0
337751	337744	14215L	PARTICIPANT	\N	PRESENT	0
337752	337744	14001X	PARTICIPANT	\N	PRESENT	0
337753	337744	14071N	PARTICIPANT	\N	PRESENT	0
340095	340094	14231L	PARTICIPANT	\N	PRESENT	0
340110	340109	14083S	PARTICIPANT	\N	PRESENT	0
340111	340109	19521Q	PARTICIPANT	\N	PRESENT	0
340113	340112	14083S	PARTICIPANT	\N	PRESENT	0
340114	340112	04049K	PARTICIPANT	\N	PRESENT	0
340115	340112	14026U	PARTICIPANT	\N	PRESENT	0
340116	340112	14173T	PARTICIPANT	\N	PRESENT	0
340118	340117	14083S	PARTICIPANT	\N	PRESENT	0
340119	340117	04049K	PARTICIPANT	\N	PRESENT	0
340120	340117	11048N	PARTICIPANT	\N	PRESENT	0
340121	340117	14026U	PARTICIPANT	\N	PRESENT	0
340123	340122	04049K	PARTICIPANT	\N	PRESENT	0
340125	340124	04049K	PARTICIPANT	\N	PRESENT	0
340126	340124	14083S	PARTICIPANT	\N	PRESENT	0
340127	340124	11048N	PARTICIPANT	\N	PRESENT	0
340128	340124	08034U	PARTICIPANT	\N	PRESENT	0
340129	340124	19711U	PARTICIPANT	\N	PRESENT	0
340131	340130	14083S	PARTICIPANT	\N	PRESENT	0
340132	340130	11048N	PARTICIPANT	\N	PRESENT	0
341637	331577	14038Y	PARTICIPANT	\N	EXCUSE	0
341638	331577	11033F	PARTICIPANT	\N	EXCUSE	0
341639	331577	14259Y	PARTICIPANT	\N	EXCUSE	0
341641	334381	14038Y	PARTICIPANT	\N	EXCUSE	0
341642	334381	11033F	PARTICIPANT	\N	EXCUSE	0
341643	334381	14259Y	PARTICIPANT	\N	EXCUSE	0
341644	334381	95062K	PARTICIPANT	\N	EXCUSE	0
341648	340438	11033F	PARTICIPANT	\N	EXCUSE	0
341649	340438	14097Y	PARTICIPANT	\N	EXCUSE	0
341650	340438	95062K	PARTICIPANT	\N	EXCUSE	0
341651	340438	11054L	PARTICIPANT	\N	EXCUSE	0
341707	340473	14097Y	PARTICIPANT	\N	EXCUSE	0
341708	340473	14135M	PARTICIPANT	\N	PRESENT	0
341754	340451	11065P	PARTICIPANT	\N	PRESENT	0
341755	340451	14107H	PARTICIPANT	\N	PRESENT	0
344775	342191	11027H	PARTICIPANT	\N	PRESENT	0
344776	342191	04042C	PRESIDENT	0	PRESENT	0
344777	342191	11066Q	PARTICIPANT	\N	PRESENT	0
344778	342191	14105F	PARTICIPANT	\N	PRESENT	0
344779	342191	95037J	PARTICIPANT	\N	PRESENT	0
344780	342191	14193X	PARTICIPANT	\N	PRESENT	0
344781	342191	14267Y	PARTICIPANT	\N	PRESENT	0
344782	342191	11064N	PARTICIPANT	\N	PRESENT	0
344783	342191	98050T	PARTICIPANT	\N	PRESENT	0
344784	342191	08061X	PARTICIPANT	\N	PRESENT	0
344785	342191	08047A	PARTICIPANT	\N	PRESENT	0
345375	339508	11097X	PARTICIPANT	\N	PRESENT	0
344804	342191	14235Q	PARTICIPANT	\N	PRESENT	0
344807	342191	04035D	PARTICIPANT	\N	PRESENT	0
344808	342191	08053X	PARTICIPANT	\N	PRESENT	0
344809	342191	19583F	PARTICIPANT	\N	PRESENT	0
344810	342191	14255U	PARTICIPANT	\N	PRESENT	0
345376	339508	08049C	PARTICIPANT	\N	PRESENT	0
344814	342191	19709B	PARTICIPANT	\N	PRESENT	0
344815	342191	95067Q	PARTICIPANT	\N	PRESENT	0
344816	342191	98022P	PARTICIPANT	\N	PRESENT	0
344824	344823	11067R	PARTICIPANT	\N	PRESENT	0
344825	344823	19649G	PARTICIPANT	\N	PRESENT	0
344826	344823	19533U	PARTICIPANT	\N	PRESENT	0
344827	344823	11045K	PARTICIPANT	\N	PRESENT	0
344828	344823	19415P	PARTICIPANT	\N	PRESENT	0
344829	344823	14213J	PARTICIPANT	\N	PRESENT	0
344830	344823	19749K	PARTICIPANT	\N	PRESENT	0
344831	344823	10006L	PRESIDENT	0	PRESENT	0
344832	342191	04040A	PARTICIPANT	\N	PRESENT	0
344833	344823	14147R	PARTICIPANT	\N	EXCUSE	0
344834	344823	08043V	PARTICIPANT	\N	EXCUSE	0
344835	344823	04047H	PARTICIPANT	\N	EXCUSE	0
344836	344823	19295A	PARTICIPANT	\N	EXCUSE	0
345377	339508	14119M	PARTICIPANT	\N	PRESENT	0
345378	339508	14033T	PARTICIPANT	\N	PRESENT	0
345379	339508	11048N	PARTICIPANT	\N	PRESENT	0
345380	339508	19563B	PARTICIPANT	\N	PRESENT	0
345381	339508	14261S	PARTICIPANT	\N	PRESENT	0
345382	339508	08031R	PARTICIPANT	\N	PRESENT	0
345383	339508	11010L	PARTICIPANT	\N	PRESENT	0
345384	339508	19611R	PARTICIPANT	\N	PRESENT	0
345385	339508	14042U	PARTICIPANT	\N	PRESENT	0
345386	339508	14089Y	PARTICIPANT	\N	PRESENT	0
345387	339508	19441R	PARTICIPANT	\N	PRESENT	0
345388	339508	14001X	PARTICIPANT	\N	PRESENT	0
345389	339508	14187A	PARTICIPANT	\N	PRESENT	0
345390	339508	19369B	PARTICIPANT	\N	PRESENT	0
345391	339508	11067R	PARTICIPANT	\N	PRESENT	0
345392	339508	19695N	PARTICIPANT	\N	PRESENT	0
345393	339508	14221J	PARTICIPANT	\N	PRESENT	0
345394	339508	14179A	PARTICIPANT	\N	PRESENT	0
345395	339508	95063L	PARTICIPANT	\N	PRESENT	0
345396	339508	19719D	PARTICIPANT	\N	PRESENT	0
345397	339508	11066Q	PARTICIPANT	\N	PRESENT	0
345398	339508	14083S	PARTICIPANT	\N	PRESENT	0
345399	339508	14195A	PARTICIPANT	\N	PRESENT	0
345400	339508	19479G	PARTICIPANT	\N	PRESENT	0
345401	339508	19762G	PARTICIPANT	\N	PRESENT	0
345402	339508	01058X	PARTICIPANT	\N	PRESENT	0
345403	339508	14169X	PARTICIPANT	\N	PRESENT	0
345404	339508	08015R	PARTICIPANT	\N	PRESENT	0
345405	339508	19794Q	PARTICIPANT	\N	PRESENT	0
345406	339508	19575F	PARTICIPANT	\N	PRESENT	0
345407	339508	19691J	PARTICIPANT	\N	PRESENT	0
345408	339508	99004R	PARTICIPANT	\N	PRESENT	0
345409	339508	95030B	PARTICIPANT	\N	PRESENT	0
345410	339508	08061X	PARTICIPANT	\N	PRESENT	0
345411	339508	19693L	PARTICIPANT	\N	PRESENT	0
345412	339508	19521Q	PARTICIPANT	\N	PRESENT	0
345413	339508	11085T	PARTICIPANT	\N	PRESENT	0
345414	339508	19683J	PARTICIPANT	\N	PRESENT	0
345415	339508	04059M	PARTICIPANT	\N	PRESENT	0
345416	339508	17779H	PARTICIPANT	\N	PRESENT	0
345417	339508	19251M	PARTICIPANT	\N	PRESENT	0
345418	339508	14133K	PARTICIPANT	\N	PRESENT	0
345419	339508	19553Y	PARTICIPANT	\N	PRESENT	0
345420	339508	11012A	PARTICIPANT	\N	PRESENT	0
345421	339508	08048B	PARTICIPANT	\N	PRESENT	0
345422	339508	19387D	PARTICIPANT	\N	PRESENT	0
345423	339508	19703U	PARTICIPANT	\N	PRESENT	0
345521	340842	14107H	PARTICIPANT	\N	PRESENT	0
346034	345036	98005N	PARTICIPANT	\N	PRESENT	0
346035	345036	01058X	PARTICIPANT	\N	PRESENT	0
346036	345036	14097Y	PARTICIPANT	\N	PRESENT	0
346066	345036	95030B	PARTICIPANT	\N	PRESENT	0
346067	345036	08056B	PARTICIPANT	\N	PRESENT	0
346068	345036	98029W	PARTICIPANT	\N	PRESENT	0
346069	345036	11041F	PARTICIPANT	\N	PRESENT	0
346070	345105	11099A	PARTICIPANT	\N	PRESENT	0
346071	345105	19695N	PARTICIPANT	\N	PRESENT	0
346072	345105	11056N	PARTICIPANT	\N	PRESENT	0
346073	345105	08021P	PARTICIPANT	\N	EXCUSE	0
346074	345105	11081P	PARTICIPANT	\N	EXCUSE	0
346075	345105	19413M	PARTICIPANT	\N	PRESENT	0
346076	345105	01043Q	PARTICIPANT	\N	PRESENT	0
346077	345105	14081Q	PARTICIPANT	\N	PRESENT	0
346078	344975	19697Q	PARTICIPANT	\N	PRESENT	0
346079	344975	11067R	PARTICIPANT	\N	PRESENT	0
346080	344975	19565D	PARTICIPANT	\N	PRESENT	0
346081	344975	19569H	PARTICIPANT	\N	PRESENT	0
346082	344975	11097X	PARTICIPANT	\N	PRESENT	0
346083	344975	19415P	PARTICIPANT	\N	PRESENT	0
346084	344975	14223L	PARTICIPANT	\N	PRESENT	0
346085	344975	14227Q	PARTICIPANT	\N	PRESENT	0
346086	344975	19703U	PARTICIPANT	\N	PRESENT	0
346087	344975	11031D	PARTICIPANT	\N	PRESENT	0
346088	344975	19553Y	PARTICIPANT	\N	PRESENT	0
346089	344975	19679N	PARTICIPANT	\N	PRESENT	0
346090	344975	14042U	PARTICIPANT	\N	PRESENT	0
346091	344975	14195A	PARTICIPANT	\N	PRESENT	0
346092	344975	19367Y	PARTICIPANT	\N	PRESENT	0
346093	344975	14213J	PARTICIPANT	\N	PRESENT	0
346094	344975	14217N	PARTICIPANT	\N	PRESENT	0
346095	344975	19683J	PARTICIPANT	\N	PRESENT	0
346096	344975	98024R	PARTICIPANT	\N	PRESENT	0
346097	344975	19527W	PARTICIPANT	\N	PRESENT	0
346098	344975	04092N	PRESIDENT	0	PRESENT	0
346099	344975	11045K	PARTICIPANT	\N	PRESENT	0
346100	344975	08052W	PARTICIPANT	\N	PRESENT	0
346101	344975	19715Y	PARTICIPANT	\N	PRESENT	0
346102	344975	19723Y	PARTICIPANT	\N	PRESENT	0
346103	344975	14119M	PARTICIPANT	\N	PRESENT	0
355403	355368	08038Y	PARTICIPANT	\N	EXCUSE	0
355404	355368	08019V	PARTICIPANT	\N	EXCUSE	0
355405	355368	14157T	PARTICIPANT	\N	EXCUSE	0
355406	355368	19715Y	PARTICIPANT	\N	EXCUSE	0
355504	345104	11065P	PARTICIPANT	\N	PRESENT	0
355505	345104	08068F	PARTICIPANT	\N	PRESENT	0
355506	345104	11043H	PARTICIPANT	\N	PRESENT	0
355507	345104	14195A	PARTICIPANT	\N	PRESENT	0
355510	345104	19695N	PARTICIPANT	\N	PRESENT	0
355512	345104	14038Y	PARTICIPANT	\N	PRESENT	0
355515	345104	08051V	PARTICIPANT	\N	PRESENT	0
355521	345104	16685X	PARTICIPANT	\N	PRESENT	0
355522	345104	14197C	PARTICIPANT	\N	PRESENT	0
355524	345104	19549D	PARTICIPANT	\N	PRESENT	0
355525	345104	19399H	PARTICIPANT	\N	PRESENT	0
355526	352738	19443T	PARTICIPANT	\N	PRESENT	0
355527	352738	95067Q	PARTICIPANT	\N	PRESENT	0
355528	352738	95030B	PARTICIPANT	\N	PRESENT	0
355529	352738	11080N	PARTICIPANT	\N	PRESENT	0
355530	352738	01062T	PARTICIPANT	\N	PRESENT	0
355531	352738	11041F	PARTICIPANT	\N	PRESENT	0
355532	352738	14235Q	PARTICIPANT	\N	PRESENT	0
355533	352738	01058X	PARTICIPANT	\N	PRESENT	0
355534	352738	14079W	PARTICIPANT	\N	PRESENT	0
355535	352738	16685X	PARTICIPANT	\N	PRESENT	0
355536	352738	04042C	PRESIDENT	0	PRESENT	0
355537	352738	11054L	PARTICIPANT	\N	PRESENT	0
355538	352738	11066Q	PARTICIPANT	\N	PRESENT	0
355539	352738	95037J	PARTICIPANT	\N	PRESENT	0
355540	352738	19421M	PARTICIPANT	\N	PRESENT	0
355541	352738	19709B	PARTICIPANT	\N	PRESENT	0
355502	345104	19507S	PARTICIPANT	\N	PRESENT	0
355503	345104	14219Q	PARTICIPANT	\N	PRESENT	0
355542	352738	14267Y	PARTICIPANT	\N	PRESENT	0
355543	352738	14193X	PARTICIPANT	\N	PRESENT	0
355544	352738	98050T	PARTICIPANT	\N	PRESENT	0
355545	352738	08061X	PARTICIPANT	\N	PRESENT	0
355546	352738	19583F	PARTICIPANT	\N	PRESENT	0
355547	352738	98029W	PARTICIPANT	\N	PRESENT	0
355548	352738	11027H	PARTICIPANT	\N	PRESENT	0
355549	352738	08047A	PARTICIPANT	\N	PRESENT	0
355550	345104	14069U	PARTICIPANT	\N	PRESENT	0
355551	345104	19691J	PARTICIPANT	\N	PRESENT	0
355553	352738	04040A	PARTICIPANT	\N	PRESENT	0
355554	352738	97011G	PARTICIPANT	\N	PRESENT	0
355555	352738	14097Y	PARTICIPANT	\N	PRESENT	0
355556	352738	04035D	PARTICIPANT	\N	PRESENT	0
355591	345104	19631V	PARTICIPANT	\N	PRESENT	0
355592	345104	19719D	PARTICIPANT	\N	PRESENT	0
355593	345104	11048N	PARTICIPANT	\N	PRESENT	0
355594	345104	05012A	PARTICIPANT	\N	PRESENT	0
355602	345104	19269X	PARTICIPANT	\N	PRESENT	0
355603	345104	11085T	PARTICIPANT	\N	PRESENT	0
355649	345106	08024S	PARTICIPANT	\N	PRESENT	0
355650	345106	19269X	PARTICIPANT	\N	PRESENT	0
355651	345106	19631V	PARTICIPANT	\N	PRESENT	0
355652	345106	14281W	PARTICIPANT	\N	PRESENT	0
355653	345106	19549D	PARTICIPANT	\N	PRESENT	0
355654	345106	19413M	PARTICIPANT	\N	PRESENT	0
355655	345106	19347U	PARTICIPANT	\N	PRESENT	0
355656	345106	14195A	PARTICIPANT	\N	PRESENT	0
355657	345106	02002K	PARTICIPANT	\N	PRESENT	0
355658	345106	19565D	PARTICIPANT	\N	PRESENT	0
355659	345106	19553Y	PARTICIPANT	\N	PRESENT	0
355660	345106	14327T	PARTICIPANT	\N	PRESENT	0
355661	345106	14083S	PARTICIPANT	\N	PRESENT	0
355662	345106	11012A	PARTICIPANT	\N	PRESENT	0
355663	345106	19749K	PARTICIPANT	\N	PRESENT	0
355664	345106	14205J	PARTICIPANT	\N	PRESENT	0
355665	345106	19747H	PARTICIPANT	\N	PRESENT	0
355666	345106	19701S	PARTICIPANT	\N	PRESENT	0
355667	345106	08015R	PARTICIPANT	\N	PRESENT	0
355668	345106	11097X	PARTICIPANT	\N	PRESENT	0
355669	345106	11048N	PARTICIPANT	\N	PRESENT	0
355670	345106	08034U	PARTICIPANT	\N	PRESENT	0
355671	345106	01057W	PARTICIPANT	\N	PRESENT	0
355672	345106	14033T	PARTICIPANT	\N	PRESENT	0
355673	345106	19794Q	PARTICIPANT	\N	PRESENT	0
355674	345106	14191V	PARTICIPANT	\N	PRESENT	0
355675	345106	19703U	PARTICIPANT	\N	PRESENT	0
355676	345106	19673G	PARTICIPANT	\N	PRESENT	0
355677	345106	14073Q	PARTICIPANT	\N	PRESENT	0
355678	345106	04088S	PARTICIPANT	\N	PRESENT	0
355679	345106	14089Y	PARTICIPANT	\N	PRESENT	0
355680	345106	19713W	PARTICIPANT	\N	PRESENT	0
355681	345106	08039A	PARTICIPANT	\N	PRESENT	0
355682	345106	19503N	PARTICIPANT	\N	PRESENT	0
355683	345106	11031D	PARTICIPANT	\N	PRESENT	0
355639	345106	11027H	PARTICIPANT	\N	PRESENT	0
355644	345106	14038Y	PARTICIPANT	\N	PRESENT	0
355685	345106	01024M	PARTICIPANT	\N	PRESENT	0
355686	345106	14331P	PARTICIPANT	\N	PRESENT	0
355687	345106	05012A	PARTICIPANT	\N	PRESENT	0
355688	345106	89017R	PARTICIPANT	\N	PRESENT	0
355689	345106	19507S	PARTICIPANT	\N	PRESENT	0
355690	345106	01060R	PARTICIPANT	\N	PRESENT	0
355691	345106	97011G	PARTICIPANT	\N	PRESENT	0
355692	345106	19421M	PARTICIPANT	\N	PRESENT	0
355693	345106	19399H	PARTICIPANT	\N	PRESENT	0
355694	345106	11043H	PARTICIPANT	\N	PRESENT	0
355695	345106	14031R	PARTICIPANT	\N	PRESENT	0
355696	345106	14147R	PARTICIPANT	\N	PRESENT	0
355697	345106	08051V	PARTICIPANT	\N	PRESENT	0
355698	345106	14217N	PARTICIPANT	\N	PRESENT	0
355699	345106	19621T	PARTICIPANT	\N	PRESENT	0
355700	345106	19629C	PARTICIPANT	\N	PRESENT	0
355701	345106	07029T	PARTICIPANT	\N	PRESENT	0
355702	355368	14031R	PARTICIPANT	\N	PRESENT	0
355703	355368	14033T	PARTICIPANT	\N	PRESENT	0
355704	355368	14207L	PARTICIPANT	\N	PRESENT	0
355705	355368	08049C	PARTICIPANT	\N	EXCUSE	0
355706	355368	19369B	PARTICIPANT	\N	EXCUSE	0
355724	355723	19415P	PARTICIPANT	\N	PRESENT	0
355725	355723	11067R	PARTICIPANT	\N	PRESENT	0
355791	345033	14107H	PARTICIPANT	\N	PRESENT	0
355795	355794	96004D	PRESIDENT	0	PRESENT	0
355796	355794	14065Q	PARTICIPANT	\N	EXCUSE	0
355797	355794	14089Y	PARTICIPANT	\N	PRESENT	0
355798	355794	14079W	PARTICIPANT	\N	PRESENT	0
355799	355794	14033T	PARTICIPANT	\N	PRESENT	0
355800	355794	19725B	PARTICIPANT	\N	PRESENT	0
355801	355794	04097T	PARTICIPANT	\N	PRESENT	0
355802	355794	14097Y	PARTICIPANT	\N	PRESENT	0
355803	355794	04061F	PARTICIPANT	\N	PRESENT	0
355804	355794	11026G	PARTICIPANT	\N	PRESENT	0
355805	355794	14205J	PARTICIPANT	\N	PRESENT	0
355806	355794	14221J	PARTICIPANT	\N	PRESENT	0
355807	355794	04057K	PARTICIPANT	\N	PRESENT	0
355808	355794	19593H	PARTICIPANT	\N	PRESENT	0
355809	355794	14237S	PARTICIPANT	\N	PRESENT	0
355810	355794	14135M	PARTICIPANT	\N	PRESENT	0
355811	355794	14331P	PARTICIPANT	\N	PRESENT	0
355812	355794	10015M	PARTICIPANT	\N	PRESENT	0
355813	355794	14229S	PARTICIPANT	\N	PRESENT	0
355814	355794	08039A	PARTICIPANT	\N	PRESENT	0
355815	355794	98035U	PARTICIPANT	\N	PRESENT	0
355816	355794	19569H	PARTICIPANT	\N	EXCUSE	0
356052	348097	11049P	PARTICIPANT	\N	PRESENT	0
356053	348097	08010L	PARTICIPANT	\N	PRESENT	0
356054	348097	01057W	PARTICIPANT	\N	PRESENT	0
356055	348097	14327T	PARTICIPANT	\N	PRESENT	0
356056	348097	19525U	PARTICIPANT	\N	PRESENT	0
356058	348097	04045F	PARTICIPANT	\N	PRESENT	0
356059	348097	05012A	PARTICIPANT	\N	PRESENT	0
356060	348097	14069U	PARTICIPANT	\N	PRESENT	0
356074	350898	14107H	PARTICIPANT	\N	PRESENT	0
356249	356248	88008L	PARTICIPANT	\N	PRESENT	0
356250	356248	04035D	PARTICIPANT	\N	PRESENT	0
356251	356248	14059S	PARTICIPANT	\N	PRESENT	0
356268	356267	19659J	PARTICIPANT	\N	EXCUSE	0
356269	356267	19583F	PARTICIPANT	\N	EXCUSE	0
356270	356267	19319Q	PARTICIPANT	\N	EXCUSE	0
356271	356267	08019V	PARTICIPANT	\N	EXCUSE	0
356274	351756	19737F	PARTICIPANT	\N	EXCUSE	0
356275	351756	19551W	PARTICIPANT	\N	EXCUSE	0
356276	351756	19479G	PARTICIPANT	\N	EXCUSE	0
356277	351756	19467C	PARTICIPANT	\N	PRESENT	0
356278	351756	11065P	PARTICIPANT	\N	EXCUSE	0
356279	351756	14147R	PARTICIPANT	\N	EXCUSE	0
356287	351756	14107H	PARTICIPANT	\N	EXCUSE	0
356288	351756	19515S	PARTICIPANT	\N	EXCUSE	0
356289	351756	01028R	PARTICIPANT	\N	EXCUSE	0
356302	341435	11065P	PARTICIPANT	\N	PRESENT	0
356318	351756	19713W	PARTICIPANT	\N	EXCUSE	0
356345	356344	19251M	PARTICIPANT	\N	PRESENT	0
356346	356344	14087W	PARTICIPANT	\N	PRESENT	0
356347	356344	08053X	PARTICIPANT	\N	PRESENT	0
356359	356358	11115U	PARTICIPANT	\N	PRESENT	0
356674	345116	14191V	PARTICIPANT	\N	PRESENT	0
350096	339548	14031R	PARTICIPANT	\N	PRESENT	0
350097	339548	04085P	PARTICIPANT	\N	PRESENT	0
350098	339548	19551W	PARTICIPANT	\N	PRESENT	0
350099	339548	19713W	PARTICIPANT	\N	PRESENT	0
350150	339550	19697Q	PARTICIPANT	\N	PRESENT	0
350151	339550	14257W	PARTICIPANT	\N	PRESENT	0
350152	339550	14227Q	PARTICIPANT	\N	PRESENT	0
350153	339550	14231L	PARTICIPANT	\N	PRESENT	0
350154	339550	19515S	PARTICIPANT	\N	PRESENT	0
350155	339550	11090Q	PARTICIPANT	\N	PRESENT	0
350156	339550	19711U	PARTICIPANT	\N	PRESENT	0
350157	339550	14026U	PARTICIPANT	\N	PRESENT	0
350158	339550	19585H	PARTICIPANT	\N	PRESENT	0
350159	339550	14255U	PARTICIPANT	\N	PRESENT	0
350160	339550	14219Q	PARTICIPANT	\N	PRESENT	0
350161	339550	19747H	PARTICIPANT	\N	PRESENT	0
350162	339550	14083S	PARTICIPANT	\N	PRESENT	0
350163	339550	19521Q	PARTICIPANT	\N	PRESENT	0
350164	339550	11077T	PARTICIPANT	\N	PRESENT	0
350165	339550	19269X	PARTICIPANT	\N	PRESENT	0
350166	339550	19551W	PARTICIPANT	\N	PRESENT	0
350167	339550	19794Q	PARTICIPANT	\N	PRESENT	0
350168	339550	08034U	PARTICIPANT	\N	PRESENT	0
350169	339550	08031R	PARTICIPANT	\N	PRESENT	0
350170	339550	19737F	PARTICIPANT	\N	PRESENT	0
350171	339550	14034U	PARTICIPANT	\N	PRESENT	0
350172	339550	08049C	PARTICIPANT	\N	PRESENT	0
350173	339550	19713W	PARTICIPANT	\N	PRESENT	0
350174	339550	14261S	PARTICIPANT	\N	PRESENT	0
350178	339550	11031D	PARTICIPANT	\N	PRESENT	0
350176	339550	04088S	PARTICIPANT	\N	PRESENT	0
350177	339550	19447X	PARTICIPANT	\N	PRESENT	0
350179	339550	19565D	PARTICIPANT	\N	PRESENT	0
350180	339550	14215L	PARTICIPANT	\N	PRESENT	0
350181	339550	14041T	PARTICIPANT	\N	PRESENT	0
350182	339550	14031R	PARTICIPANT	\N	PRESENT	0
350183	339550	19563B	PARTICIPANT	\N	PRESENT	0
350184	339550	19695N	PARTICIPANT	\N	PRESENT	0
350185	339550	11056N	PARTICIPANT	\N	PRESENT	0
350186	339550	19760E	PARTICIPANT	\N	PRESENT	0
350187	339550	08061X	PARTICIPANT	\N	PRESENT	0
350188	339550	89017R	PARTICIPANT	\N	PRESENT	0
350189	339550	11048N	PARTICIPANT	\N	PRESENT	0
350190	339550	10006L	PARTICIPANT	\N	PRESENT	0
350191	339550	19741B	PARTICIPANT	\N	PRESENT	0
350192	339550	19573D	PARTICIPANT	\N	PRESENT	0
350193	339550	07029T	PARTICIPANT	\N	PRESENT	0
350194	339550	14069U	PARTICIPANT	\N	PRESENT	0
350195	339550	14179A	PARTICIPANT	\N	PRESENT	0
350196	339550	08068F	PARTICIPANT	\N	PRESENT	0
350197	339550	01024M	PARTICIPANT	\N	PRESENT	0
350198	339550	04049K	PARTICIPANT	\N	PRESENT	0
350148	339550	11070L	PARTICIPANT	\N	PRESENT	0
350149	339550	04034C	PARTICIPANT	\N	PRESENT	0
350199	339550	14249W	PARTICIPANT	\N	PRESENT	0
350200	339550	08038Y	PARTICIPANT	\N	PRESENT	0
350201	339550	14213J	PARTICIPANT	\N	PRESENT	0
350202	339550	14265W	PARTICIPANT	\N	PRESENT	0
350203	339550	11097X	PARTICIPANT	\N	PRESENT	0
350204	339550	14073Q	PARTICIPANT	\N	PRESENT	0
350205	339550	19631V	PARTICIPANT	\N	PRESENT	0
350313	348036	14042U	PARTICIPANT	\N	PRESENT	0
350578	348045	14195A	PARTICIPANT	\N	PRESENT	0
350580	348045	19565D	PARTICIPANT	\N	PRESENT	0
350671	339553	19695N	PARTICIPANT	\N	PRESENT	0
350672	339553	19697Q	PARTICIPANT	\N	PRESENT	0
350673	339553	19441R	PARTICIPANT	\N	PRESENT	0
350674	339553	19521Q	PARTICIPANT	\N	PRESENT	0
350675	339553	14083S	PARTICIPANT	\N	PRESENT	0
350676	339553	19399H	PARTICIPANT	\N	PRESENT	0
350677	339553	14105F	PARTICIPANT	\N	PRESENT	0
350678	339553	08039A	PARTICIPANT	\N	PRESENT	0
350679	339553	19794Q	PARTICIPANT	\N	PRESENT	0
350680	339553	19631V	PARTICIPANT	\N	PRESENT	0
350681	339553	11097X	PARTICIPANT	\N	PRESENT	0
350682	339553	19651A	PARTICIPANT	\N	PRESENT	0
350683	339553	11048N	PARTICIPANT	\N	PRESENT	0
350684	339553	14265W	PARTICIPANT	\N	PRESENT	0
350685	349542	19729F	PARTICIPANT	\N	EXCUSE	0
350687	339553	01028R	PARTICIPANT	\N	PRESENT	0
350689	339553	19447X	PARTICIPANT	\N	PRESENT	0
350690	339553	19515S	PARTICIPANT	\N	PRESENT	0
350691	339553	14073Q	PARTICIPANT	\N	PRESENT	0
350692	339553	19747H	PARTICIPANT	\N	PRESENT	0
350693	339553	14030Q	PARTICIPANT	\N	PRESENT	0
350694	339553	19669L	PARTICIPANT	\N	PRESENT	0
350695	339553	08068F	PARTICIPANT	\N	PRESENT	0
350696	339553	19301E	PARTICIPANT	\N	PRESENT	0
350697	339553	99004R	PARTICIPANT	\N	PRESENT	0
350698	339553	19563B	PARTICIPANT	\N	PRESENT	0
350699	339553	04018C	PARTICIPANT	\N	PRESENT	0
350701	339553	19611R	PARTICIPANT	\N	PRESENT	0
350703	339553	19663E	PARTICIPANT	\N	PRESENT	0
350704	339553	19573D	PARTICIPANT	\N	PRESENT	0
350705	339553	19741B	PARTICIPANT	\N	PRESENT	0
350707	339553	14042U	PARTICIPANT	\N	PRESENT	0
350709	339553	19545Y	PARTICIPANT	\N	PRESENT	0
350723	339553	14038Y	PARTICIPANT	\N	PRESENT	0
350724	339553	04043D	PARTICIPANT	\N	PRESENT	0
350725	339553	11031D	PARTICIPANT	\N	PRESENT	0
350726	339553	19701S	PARTICIPANT	\N	PRESENT	0
350727	339553	11010L	PARTICIPANT	\N	PRESENT	0
350728	339553	19543W	PARTICIPANT	\N	PRESENT	0
350729	339553	14281W	PARTICIPANT	\N	PRESENT	0
350733	339553	11045K	PARTICIPANT	\N	PRESENT	0
350734	339553	11090Q	PARTICIPANT	\N	PRESENT	0
350735	339553	14249W	PARTICIPANT	\N	PRESENT	0
350736	339553	19643A	PARTICIPANT	\N	PRESENT	0
350744	339553	19671E	PARTICIPANT	\N	PRESENT	0
350752	339553	80013X	PARTICIPANT	\N	PRESENT	0
350756	339553	14034U	PARTICIPANT	\N	PRESENT	0
350759	339553	14255U	PARTICIPANT	\N	PRESENT	0
350760	339553	11054L	PARTICIPANT	\N	PRESENT	0
350761	339553	19699S	PARTICIPANT	\N	PRESENT	0
350764	350763	10006L	PARTICIPANT	\N	PRESENT	0
350771	339553	11012A	PARTICIPANT	\N	PRESENT	0
350778	339553	07029T	PARTICIPANT	\N	PRESENT	0
350779	339553	08051V	PARTICIPANT	\N	PRESENT	0
350785	339553	08069G	PARTICIPANT	\N	PRESENT	0
350787	339553	04085P	PARTICIPANT	\N	PRESENT	0
350788	339553	19667J	PARTICIPANT	\N	PRESENT	0
350874	350871	01034P	PARTICIPANT	\N	PRESENT	0
350875	350872	01034P	PARTICIPANT	\N	PRESENT	0
350876	350873	01034P	PARTICIPANT	\N	PRESENT	0
350884	350883	19673G	PARTICIPANT	\N	PRESENT	0
350885	350883	19649G	PARTICIPANT	\N	PRESENT	0
350887	350886	19673G	PARTICIPANT	\N	PRESENT	0
350947	345316	11065P	PARTICIPANT	\N	PRESENT	0
350949	345316	14107H	PARTICIPANT	\N	PRESENT	0
352118	350686	11109J	PARTICIPANT	\N	PRESENT	0
351346	340471	11065P	PARTICIPANT	\N	PRESENT	0
351347	332565	08045X	PARTICIPANT	\N	PRESENT	0
352119	350686	14261S	PARTICIPANT	\N	PRESENT	0
352120	350686	19631V	PARTICIPANT	\N	PRESENT	0
352121	350686	19691J	PARTICIPANT	\N	PRESENT	0
352122	350686	19715Y	PARTICIPANT	\N	PRESENT	0
352123	350686	14097Y	PARTICIPANT	\N	PRESENT	0
352124	350686	98005N	PARTICIPANT	\N	PRESENT	0
352125	350686	14219Q	PARTICIPANT	\N	PRESENT	0
352152	350686	14059S	PARTICIPANT	\N	PRESENT	0
352153	350686	08019V	PRESIDENT	0	PRESENT	0
352154	350686	14135M	PARTICIPANT	\N	PRESENT	0
352155	350686	14331P	PARTICIPANT	\N	EXCUSE	0
352156	350686	19659J	PARTICIPANT	\N	EXCUSE	0
352158	350686	95062K	PARTICIPANT	\N	EXCUSE	0
352175	350686	14229S	PARTICIPANT	\N	PRESENT	0
352180	349542	19659J	PARTICIPANT	\N	EXCUSE	0
352181	349542	95062K	PARTICIPANT	\N	EXCUSE	0
352549	348095	14327T	PARTICIPANT	\N	EXCUSE	0
352599	350939	11070L	PARTICIPANT	\N	PRESENT	0
352601	350939	12041X	PARTICIPANT	\N	PRESENT	0
352602	350939	11026G	PARTICIPANT	\N	PRESENT	0
352603	350939	19251M	PARTICIPANT	\N	PRESENT	0
352604	350939	01062T	PARTICIPANT	\N	PRESENT	0
352605	350939	04034C	PARTICIPANT	\N	PRESENT	0
352606	350939	04057K	PARTICIPANT	\N	PRESENT	0
352607	350939	14089Y	PARTICIPANT	\N	PRESENT	0
352608	350939	14275Y	PARTICIPANT	\N	PRESENT	0
352609	350939	14041T	PARTICIPANT	\N	PRESENT	0
352610	350939	14105F	PARTICIPANT	\N	PRESENT	0
352611	350939	97011G	PARTICIPANT	\N	PRESENT	0
352612	350939	19711U	PARTICIPANT	\N	PRESENT	0
352613	350939	14069U	PARTICIPANT	\N	PRESENT	0
352614	350939	95063L	PARTICIPANT	\N	PRESENT	0
352615	350939	01060R	PARTICIPANT	\N	PRESENT	0
352616	350939	19667J	PARTICIPANT	\N	PRESENT	0
352617	350939	14079W	PARTICIPANT	\N	PRESENT	0
352618	351931	14061L	PARTICIPANT	\N	PRESENT	0
352619	351931	19699S	PARTICIPANT	\N	PRESENT	0
342005	342004	96004D	PRESIDENT	0	PRESENT	0
342006	342004	11083R	PARTICIPANT	\N	PRESENT	0
342007	342004	19553Y	PARTICIPANT	\N	PRESENT	0
342008	342004	04097T	PARTICIPANT	\N	PRESENT	0
342009	342004	14097Y	PARTICIPANT	\N	PRESENT	0
342010	342004	14089Y	PARTICIPANT	\N	PRESENT	0
342011	342004	19593H	PARTICIPANT	\N	PRESENT	0
342012	342004	14237S	PARTICIPANT	\N	PRESENT	0
342013	342004	98035U	PARTICIPANT	\N	PRESENT	0
342014	342004	10015M	PARTICIPANT	\N	PRESENT	0
342159	342158	96004D	PARTICIPANT	\N	PRESENT	0
342160	342158	11083R	PARTICIPANT	\N	PRESENT	0
342161	342158	19553Y	PARTICIPANT	\N	PRESENT	0
342162	342158	04097T	PARTICIPANT	\N	PRESENT	0
342163	342158	14097Y	PARTICIPANT	\N	PRESENT	0
342164	342158	04061F	PARTICIPANT	\N	PRESENT	0
342165	342158	14221J	PARTICIPANT	\N	PRESENT	0
342166	342158	14237S	PARTICIPANT	\N	PRESENT	0
342167	342158	14331P	PARTICIPANT	\N	PRESENT	0
344215	342172	08009T	PRESIDENT	0	PRESENT	0
344216	342172	19685L	PARTICIPANT	\N	EXCUSE	0
344217	342172	02002K	PARTICIPANT	\N	EXCUSE	0
344218	342172	14051J	PARTICIPANT	\N	PRESENT	0
344219	342172	19737F	PARTICIPANT	\N	PRESENT	0
344220	342172	19739H	PARTICIPANT	\N	PRESENT	0
344221	342172	14219Q	PARTICIPANT	\N	PRESENT	0
344222	342172	19745F	PARTICIPANT	\N	PRESENT	0
344223	342172	14221J	PARTICIPANT	\N	PRESENT	0
344224	342172	14038Y	PARTICIPANT	\N	PRESENT	0
344225	342172	14157T	PARTICIPANT	\N	PRESENT	0
344226	342172	08055A	PARTICIPANT	\N	PRESENT	0
344227	342172	19599P	PARTICIPANT	\N	PRESENT	0
344228	342919	14001X	PARTICIPANT	\N	PRESENT	0
344229	342919	01060R	PARTICIPANT	\N	PRESENT	0
344230	342919	19543W	PARTICIPANT	\N	PRESENT	0
344231	342919	19581D	PARTICIPANT	\N	PRESENT	0
344232	342919	19585H	PARTICIPANT	\N	PRESENT	0
344233	342919	04047H	PARTICIPANT	\N	PRESENT	0
344234	342919	19673G	PARTICIPANT	\N	PRESENT	0
344235	342919	01028R	PARTICIPANT	\N	PRESENT	0
344236	342919	05008E	PRESIDENT	0	PRESENT	0
344237	342919	14231L	PARTICIPANT	\N	PRESENT	0
344238	342919	14275Y	PARTICIPANT	\N	PRESENT	0
344239	342919	14041T	PARTICIPANT	\N	PRESENT	0
344240	342919	14147R	PARTICIPANT	\N	PRESENT	0
344241	342919	14179A	PARTICIPANT	\N	PRESENT	0
344242	342919	14151M	PARTICIPANT	\N	PRESENT	0
344243	342919	14215L	PARTICIPANT	\N	PRESENT	0
344244	342919	14053L	PARTICIPANT	\N	PRESENT	0
344245	342919	98035U	PARTICIPANT	\N	PRESENT	0
344246	342919	11010L	PARTICIPANT	\N	PRESENT	0
344247	342919	07034Q	PARTICIPANT	\N	PRESENT	0
344248	342919	08045X	PARTICIPANT	\N	PRESENT	0
344249	342919	11026G	PARTICIPANT	\N	PRESENT	0
344250	342919	01024M	PARTICIPANT	\N	PRESENT	0
344251	342919	04038G	PARTICIPANT	\N	PRESENT	0
344252	342919	11033F	PARTICIPANT	\N	PRESENT	0
344253	342919	19725B	PARTICIPANT	\N	PRESENT	0
344254	342919	19729F	PARTICIPANT	\N	PRESENT	0
344255	342919	19629C	PARTICIPANT	\N	PRESENT	0
344256	342919	19762G	PARTICIPANT	\N	PRESENT	0
344257	342172	19794Q	PARTICIPANT	\N	PRESENT	0
344258	342172	14169X	PARTICIPANT	\N	PRESENT	0
344259	342172	15447F	PARTICIPANT	\N	PRESENT	0
344260	342172	14029X	PARTICIPANT	\N	PRESENT	0
344348	342127	19441R	PARTICIPANT	\N	PRESENT	0
344349	342127	19747H	PARTICIPANT	\N	PRESENT	0
344350	342127	11081P	PARTICIPANT	\N	EXCUSE	0
344351	342919	19489J	PARTICIPANT	\N	PRESENT	0
344352	342919	08018U	PARTICIPANT	\N	PRESENT	0
344353	342919	08051V	PARTICIPANT	\N	PRESENT	0
344354	342919	95063L	PARTICIPANT	\N	PRESENT	0
344355	342919	11049P	PARTICIPANT	\N	PRESENT	0
344356	342919	19719D	PARTICIPANT	\N	PRESENT	0
344357	340626	14195A	PARTICIPANT	\N	PRESENT	0
344358	342172	19551W	PARTICIPANT	\N	PRESENT	0
344359	342188	12041X	PARTICIPANT	\N	PRESENT	0
344360	342188	95030B	PARTICIPANT	\N	PRESENT	0
344361	342188	01058X	PARTICIPANT	\N	PRESENT	0
344362	342188	04040A	PARTICIPANT	\N	PRESENT	0
344363	342188	14079W	PARTICIPANT	\N	PRESENT	0
344364	342188	11027H	PARTICIPANT	\N	PRESENT	0
344365	342188	04042C	PRESIDENT	0	PRESENT	0
344366	342188	11054L	PARTICIPANT	\N	PRESENT	0
344367	342188	11066Q	PARTICIPANT	\N	PRESENT	0
344368	342188	19669L	PARTICIPANT	\N	PRESENT	0
344369	342188	11115U	PARTICIPANT	\N	PRESENT	0
344370	342188	95037J	PARTICIPANT	\N	PRESENT	0
344371	342188	14055N	PARTICIPANT	\N	PRESENT	0
344372	342188	19709B	PARTICIPANT	\N	PRESENT	0
344373	342188	08049C	PARTICIPANT	\N	PRESENT	0
344374	342188	14193X	PARTICIPANT	\N	PRESENT	0
344375	342188	08053X	PARTICIPANT	\N	PRESENT	0
344376	342188	08061X	PARTICIPANT	\N	PRESENT	0
344377	342188	08047A	PARTICIPANT	\N	PRESENT	0
344378	342188	14097Y	PARTICIPANT	\N	PRESENT	0
344379	342188	04035D	PARTICIPANT	\N	PRESENT	0
344380	342188	14133K	PARTICIPANT	\N	PRESENT	0
344381	342188	01062T	PARTICIPANT	\N	PRESENT	0
344382	342188	14235Q	PARTICIPANT	\N	PRESENT	0
344383	342188	14028W	PARTICIPANT	\N	PRESENT	0
344384	342188	19251M	PARTICIPANT	\N	PRESENT	0
344385	342188	19721W	PARTICIPANT	\N	PRESENT	0
344386	342188	14105F	PARTICIPANT	\N	PRESENT	0
344387	342188	98022P	PARTICIPANT	\N	PRESENT	0
344388	342188	14267Y	PARTICIPANT	\N	PRESENT	0
344389	342188	11064N	PARTICIPANT	\N	PRESENT	0
344390	342188	98050T	PARTICIPANT	\N	PRESENT	0
344391	342188	14211G	PARTICIPANT	\N	PRESENT	0
344392	342188	19583F	PARTICIPANT	\N	PRESENT	0
344393	342188	14255U	PARTICIPANT	\N	PRESENT	0
344470	340626	14026U	PARTICIPANT	\N	PRESENT	0
344471	342919	19447X	PARTICIPANT	\N	PRESENT	0
344472	342189	12041X	PARTICIPANT	\N	PRESENT	0
344473	342189	95030B	PARTICIPANT	\N	PRESENT	0
344474	342189	01058X	PARTICIPANT	\N	PRESENT	0
344475	342189	04040A	PARTICIPANT	\N	PRESENT	0
344476	342189	14079W	PARTICIPANT	\N	PRESENT	0
344477	342189	11027H	PARTICIPANT	\N	PRESENT	0
344478	342189	04042C	PRESIDENT	0	PRESENT	0
344479	342189	11054L	PARTICIPANT	\N	PRESENT	0
344480	342189	11066Q	PARTICIPANT	\N	PRESENT	0
344481	342189	19669L	PARTICIPANT	\N	PRESENT	0
344482	342189	08056B	PARTICIPANT	\N	PRESENT	0
344483	342189	11115U	PARTICIPANT	\N	PRESENT	0
344484	342189	95037J	PARTICIPANT	\N	PRESENT	0
344485	342189	14055N	PARTICIPANT	\N	PRESENT	0
344486	342189	19709B	PARTICIPANT	\N	PRESENT	0
344487	342189	08049C	PARTICIPANT	\N	PRESENT	0
344488	342189	14193X	PARTICIPANT	\N	PRESENT	0
344489	342189	08053X	PARTICIPANT	\N	PRESENT	0
344490	342189	08061X	PARTICIPANT	\N	PRESENT	0
344491	342189	08047A	PARTICIPANT	\N	PRESENT	0
344492	342189	14097Y	PARTICIPANT	\N	PRESENT	0
344493	342189	04035D	PARTICIPANT	\N	PRESENT	0
344494	342189	14133K	PARTICIPANT	\N	PRESENT	0
344495	342189	01062T	PARTICIPANT	\N	PRESENT	0
344496	342189	14235Q	PARTICIPANT	\N	PRESENT	0
344497	342189	14028W	PARTICIPANT	\N	PRESENT	0
344498	342189	19251M	PARTICIPANT	\N	PRESENT	0
344499	342189	19721W	PARTICIPANT	\N	PRESENT	0
344500	342189	14105F	PARTICIPANT	\N	PRESENT	0
344501	342189	98022P	PARTICIPANT	\N	PRESENT	0
344502	342189	14267Y	PARTICIPANT	\N	PRESENT	0
344503	342189	11064N	PARTICIPANT	\N	PRESENT	0
344504	342189	98050T	PARTICIPANT	\N	PRESENT	0
344505	342189	14211G	PARTICIPANT	\N	PRESENT	0
344506	342189	19583F	PARTICIPANT	\N	PRESENT	0
344507	342189	14255U	PARTICIPANT	\N	PRESENT	0
344508	342172	17637T	PARTICIPANT	\N	PRESENT	0
344509	342189	95067Q	PARTICIPANT	\N	PRESENT	0
344510	340626	19663E	PARTICIPANT	\N	PRESENT	0
344511	343404	19643A	PARTICIPANT	\N	PRESENT	0
344512	343404	14059S	PARTICIPANT	\N	PRESENT	0
344513	343404	04070G	PRESIDENT	0	PRESENT	0
344514	343404	19699S	PARTICIPANT	\N	PRESENT	0
344515	343404	19711U	PARTICIPANT	\N	PRESENT	0
344516	343404	19611R	PARTICIPANT	\N	PRESENT	0
344517	343404	19693L	PARTICIPANT	\N	PRESENT	0
344518	343404	19399H	PARTICIPANT	\N	PRESENT	0
344519	343404	87003B	PARTICIPANT	\N	PRESENT	0
344520	343404	14201E	PARTICIPANT	\N	PRESENT	0
344521	343404	14229S	PARTICIPANT	\N	PRESENT	0
344522	343404	14030Q	PARTICIPANT	\N	PRESENT	0
344523	343404	14241N	PARTICIPANT	\N	PRESENT	0
344524	343404	19731Y	PARTICIPANT	\N	PRESENT	0
344525	343404	04059M	PARTICIPANT	\N	PRESENT	0
344526	343404	14107H	PARTICIPANT	\N	PRESENT	0
344527	343404	08012N	PARTICIPANT	\N	PRESENT	0
335926	335732	01057W	PARTICIPANT	\N	PRESENT	0
335927	335732	11031D	PARTICIPANT	\N	PRESENT	0
335928	335732	14223L	PARTICIPANT	\N	PRESENT	0
335929	335732	11090Q	PARTICIPANT	\N	PRESENT	0
335930	335732	14267Y	PARTICIPANT	\N	PRESENT	0
335931	335732	14249W	PARTICIPANT	\N	PRESENT	0
335932	335732	14087W	PARTICIPANT	\N	PRESENT	0
335933	335732	04089T	PARTICIPANT	\N	PRESENT	0
335934	335732	14179A	PARTICIPANT	\N	PRESENT	0
335935	335732	01034P	PARTICIPANT	\N	PRESENT	0
335936	335732	19421M	PARTICIPANT	\N	PRESENT	0
335937	335732	11053K	PARTICIPANT	\N	PRESENT	0
335938	335732	04070G	PARTICIPANT	\N	PRESENT	0
335939	335732	14028W	PARTICIPANT	\N	PRESENT	0
335940	335732	19703U	PARTICIPANT	\N	PRESENT	0
335941	335732	11109J	PARTICIPANT	\N	PRESENT	0
335942	335732	19673G	PARTICIPANT	\N	PRESENT	0
335943	335732	14205J	PARTICIPANT	\N	PRESENT	0
335944	335732	19699S	PARTICIPANT	\N	PRESENT	0
335945	335732	11010L	PARTICIPANT	\N	PRESENT	0
335946	335732	14031R	PARTICIPANT	\N	PRESENT	0
335947	335732	19553Y	PARTICIPANT	\N	PRESENT	0
335948	335732	19667J	PARTICIPANT	\N	PRESENT	0
335949	335732	19543W	PARTICIPANT	\N	PRESENT	0
335950	335732	19479G	PARTICIPANT	\N	PRESENT	0
335951	335732	19735D	PARTICIPANT	\N	PRESENT	0
335952	335732	14199E	PARTICIPANT	\N	PRESENT	0
335953	335732	14327T	PARTICIPANT	\N	PRESENT	0
335954	335732	01024M	PARTICIPANT	\N	PRESENT	0
335955	335732	11101A	PARTICIPANT	\N	PRESENT	0
335956	335732	04040A	PARTICIPANT	\N	PRESENT	0
335957	335732	19577H	PARTICIPANT	\N	PRESENT	0
335958	335732	19575F	PARTICIPANT	\N	PRESENT	0
335959	335732	14255U	PARTICIPANT	\N	PRESENT	0
335960	335732	14253S	PARTICIPANT	\N	PRESENT	0
335961	335732	11048N	PARTICIPANT	\N	PRESENT	0
335962	335732	11070L	PARTICIPANT	\N	PRESENT	0
335963	335732	19521Q	PARTICIPANT	\N	PRESENT	0
335964	335732	01043Q	PARTICIPANT	\N	PRESENT	0
335965	335732	98023Q	PARTICIPANT	\N	PRESENT	0
335966	335732	14083S	PARTICIPANT	\N	PRESENT	0
335967	335732	05012A	PARTICIPANT	\N	PRESENT	0
335968	335732	14107H	PARTICIPANT	\N	PRESENT	0
335969	335732	08034U	PARTICIPANT	\N	PRESENT	0
335970	335732	19533U	PARTICIPANT	\N	PRESENT	0
335971	335732	07034Q	PARTICIPANT	\N	PRESENT	0
335972	335732	14173T	PARTICIPANT	\N	PRESENT	0
335973	335732	14089Y	PARTICIPANT	\N	PRESENT	0
335974	335732	19447X	PARTICIPANT	\N	PRESENT	0
335975	335732	14133K	PARTICIPANT	\N	PRESENT	0
335976	335732	19637C	PARTICIPANT	\N	PRESENT	0
335977	335732	14119M	PARTICIPANT	\N	PRESENT	0
335978	335732	19758L	PARTICIPANT	\N	PRESENT	0
335979	335732	14115H	PARTICIPANT	\N	PRESENT	0
335980	335732	19369B	PARTICIPANT	\N	PRESENT	0
335981	335732	08047A	PARTICIPANT	\N	PRESENT	0
335982	335732	17779H	PARTICIPANT	\N	PRESENT	0
335983	335732	14105F	PARTICIPANT	\N	PRESENT	0
335984	335732	04049K	PARTICIPANT	\N	PRESENT	0
335985	335732	14281W	PARTICIPANT	\N	PRESENT	0
335986	335732	14097Y	PARTICIPANT	\N	PRESENT	0
335987	335732	92040Q	PARTICIPANT	\N	PRESENT	0
335988	335732	14111D	PARTICIPANT	\N	PRESENT	0
335989	335732	10006L	PARTICIPANT	\N	PRESENT	0
335990	335732	08035V	PARTICIPANT	\N	PRESENT	0
335991	335732	14147R	PARTICIPANT	\N	PRESENT	0
335992	335732	97011G	PARTICIPANT	\N	PRESENT	0
335993	335732	04059M	PARTICIPANT	\N	PRESENT	0
335994	335732	11103C	PARTICIPANT	\N	PRESENT	0
335995	335732	07033P	PARTICIPANT	\N	PRESENT	0
335996	335732	14257W	PARTICIPANT	\N	PRESENT	0
335997	335732	14217N	PARTICIPANT	\N	PRESENT	0
335998	335732	14331P	PARTICIPANT	\N	PRESENT	0
335999	335732	14079W	PARTICIPANT	\N	PRESENT	0
336000	335732	08051V	PARTICIPANT	\N	PRESENT	0
336001	335732	19671E	PARTICIPANT	\N	PRESENT	0
336002	335732	19581D	PARTICIPANT	\N	PRESENT	0
336003	335732	04008A	PARTICIPANT	\N	PRESENT	0
336004	335732	14265W	PARTICIPANT	\N	PRESENT	0
336005	335732	08011M	PARTICIPANT	\N	PRESENT	0
336006	335732	05008E	PARTICIPANT	\N	PRESENT	0
336007	335732	19675J	PARTICIPANT	\N	PRESENT	0
336008	335732	19741B	PARTICIPANT	\N	PRESENT	0
336009	335732	04018C	PARTICIPANT	\N	PRESENT	0
336010	335732	19705W	PARTICIPANT	\N	PRESENT	0
336011	335732	14135M	PARTICIPANT	\N	PRESENT	0
336012	335732	08062Y	PARTICIPANT	\N	PRESENT	0
336013	335732	19747H	PARTICIPANT	\N	PRESENT	0
336014	335732	98050T	PARTICIPANT	\N	PRESENT	0
336015	335732	04088S	PARTICIPANT	\N	PRESENT	0
336016	335732	14038Y	PARTICIPANT	\N	PRESENT	0
336017	335732	18083K	PARTICIPANT	\N	PRESENT	0
336018	335732	14329V	PARTICIPANT	\N	PRESENT	0
336019	335732	19701S	PARTICIPANT	\N	PRESENT	0
336020	335732	14029X	PARTICIPANT	\N	PRESENT	0
336021	335732	19723Y	PARTICIPANT	\N	PRESENT	0
336022	335732	08015R	PARTICIPANT	\N	PRESENT	0
336023	335732	19467C	PARTICIPANT	\N	PRESENT	0
336024	335732	14041T	PARTICIPANT	\N	PRESENT	0
336059	335732	19733B	PARTICIPANT	\N	PRESENT	0
336026	335732	19507S	PARTICIPANT	\N	PRESENT	0
336027	335732	14033T	PARTICIPANT	\N	PRESENT	0
336028	335732	14059S	PARTICIPANT	\N	PRESENT	0
336029	335732	08019V	PARTICIPANT	\N	PRESENT	0
336030	335732	19657G	PARTICIPANT	\N	PRESENT	0
336031	335732	19768N	PARTICIPANT	\N	PRESENT	0
336032	335732	19399H	PARTICIPANT	\N	PRESENT	0
336033	335732	19693L	PARTICIPANT	\N	PRESENT	0
336034	335732	02002K	PARTICIPANT	\N	PRESENT	0
336035	335732	19729F	PARTICIPANT	\N	PRESENT	0
336036	335732	08018U	PARTICIPANT	\N	PRESENT	0
336046	335732	19621T	PARTICIPANT	\N	PRESENT	0
336038	335732	14026U	PARTICIPANT	\N	PRESENT	0
336039	335732	14357A	PARTICIPANT	\N	PRESENT	0
336040	335732	19573D	PARTICIPANT	\N	PRESENT	0
336041	335732	14123H	PARTICIPANT	\N	PRESENT	0
336060	335732	14061L	PARTICIPANT	\N	PRESENT	0
336043	335732	19383Y	PARTICIPANT	\N	PRESENT	0
336044	335732	14215L	PARTICIPANT	\N	PRESENT	0
336045	335732	14213J	PARTICIPANT	\N	PRESENT	0
336047	335732	19443T	PARTICIPANT	\N	PRESENT	0
336048	335732	19727D	PARTICIPANT	\N	PRESENT	0
336049	335732	11026G	PARTICIPANT	\N	PRESENT	0
336050	335732	08044W	PARTICIPANT	\N	PRESENT	0
336051	335732	14069U	PARTICIPANT	\N	PRESENT	0
336052	335732	11085T	PARTICIPANT	\N	PRESENT	0
336053	335732	01048V	PARTICIPANT	\N	PRESENT	0
336054	335732	04042C	PARTICIPANT	\N	PRESENT	0
336055	335732	19681G	PARTICIPANT	\N	PRESENT	0
336061	335732	14053L	PARTICIPANT	\N	PRESENT	0
336062	335732	95062K	PARTICIPANT	\N	PRESENT	0
336058	335732	07029T	PARTICIPANT	\N	PRESENT	0
336063	335732	95067Q	PARTICIPANT	\N	PRESENT	0
336064	335732	19415P	PARTICIPANT	\N	PRESENT	0
336065	335732	19563B	PARTICIPANT	\N	PRESENT	0
336066	335732	19760E	PARTICIPANT	\N	PRESENT	0
336067	335732	14093U	PARTICIPANT	\N	PRESENT	0
336068	335732	04047H	PARTICIPANT	\N	PRESENT	0
336069	335732	19335Q	PARTICIPANT	\N	PRESENT	0
336070	335732	04035D	PARTICIPANT	\N	PRESENT	0
336077	335732	19619A	PARTICIPANT	\N	PRESENT	0
336072	335732	04043D	PARTICIPANT	\N	PRESENT	0
336073	335732	89017R	PARTICIPANT	\N	PRESENT	0
336074	335732	01058X	PARTICIPANT	\N	PRESENT	0
336075	335732	95041E	PARTICIPANT	\N	PRESENT	0
336076	335732	19762G	PARTICIPANT	\N	PRESENT	0
336081	335732	19709B	PARTICIPANT	\N	PRESENT	0
336079	335732	17583W	PARTICIPANT	\N	PRESENT	0
336083	335732	04034C	PARTICIPANT	\N	PRESENT	0
336082	335732	19745F	PARTICIPANT	\N	PRESENT	0
336084	335732	08038Y	PARTICIPANT	\N	PRESENT	0
336085	335732	98029W	PARTICIPANT	\N	PRESENT	0
336091	335740	14327T	PARTICIPANT	\N	PRESENT	0
336089	335732	19663E	PARTICIPANT	\N	PRESENT	0
336088	335732	11115U	PARTICIPANT	\N	PRESENT	0
336090	335732	19749K	PARTICIPANT	\N	PRESENT	0
336092	335740	14331P	PARTICIPANT	\N	PRESENT	0
336093	335740	04071H	PARTICIPANT	\N	PRESENT	0
336094	335740	95041E	PARTICIPANT	\N	PRESENT	0
336095	335740	01048V	PARTICIPANT	\N	PRESENT	0
336096	335740	19545Y	PARTICIPANT	\N	PRESENT	0
336097	335740	01057W	PARTICIPANT	\N	PRESENT	0
336098	335740	11053K	PARTICIPANT	\N	PRESENT	0
336099	335740	11074Q	PRESIDENT	0	PRESENT	0
336100	335740	89017R	PARTICIPANT	\N	PRESENT	0
336101	335740	19667J	PARTICIPANT	\N	PRESENT	0
336102	335740	14225N	PARTICIPANT	\N	PRESENT	0
336103	335740	19671E	PARTICIPANT	\N	PRESENT	0
335714	335703	14327T	PARTICIPANT	\N	PRESENT	0
335715	335703	11048N	PARTICIPANT	\N	PRESENT	0
335716	335703	19479G	PARTICIPANT	\N	PRESENT	0
335717	335703	19647E	PARTICIPANT	\N	PRESENT	0
335718	335703	19711U	PARTICIPANT	\N	PRESENT	0
335719	335703	08034U	PARTICIPANT	\N	PRESENT	0
335720	335703	19687N	PARTICIPANT	\N	PRESENT	0
335721	335703	11074Q	PRESIDENT	0	PRESENT	0
337413	326855	14147R	PARTICIPANT	\N	PRESENT	0
335723	335703	08011M	PARTICIPANT	\N	PRESENT	0
335724	335703	04086Q	PARTICIPANT	\N	PRESENT	0
335725	335703	11040E	PARTICIPANT	\N	PRESENT	0
335726	335703	11012A	PARTICIPANT	\N	PRESENT	0
335727	335703	14085U	PARTICIPANT	\N	PRESENT	0
335728	335703	07004J	PARTICIPANT	\N	PRESENT	0
335729	335703	99004R	PARTICIPANT	\N	PRESENT	0
336974	332424	02002K	PARTICIPANT	\N	EXCUSE	0
337412	326855	14107H	PARTICIPANT	\N	PRESENT	0
337414	326855	19421M	PARTICIPANT	\N	PRESENT	0
337415	326855	95063L	PARTICIPANT	\N	PRESENT	0
337416	326855	14031R	PARTICIPANT	\N	PRESENT	0
337417	326855	14237S	PARTICIPANT	\N	PRESENT	0
337418	326855	19533U	PARTICIPANT	\N	PRESENT	0
341595	341594	11109J	PARTICIPANT	\N	PRESENT	0
341596	341594	14195A	PARTICIPANT	\N	PRESENT	0
341597	341594	08038Y	PARTICIPANT	\N	PRESENT	0
341598	341594	19347U	PARTICIPANT	\N	PRESENT	0
341599	341594	19727D	PARTICIPANT	\N	PRESENT	0
341600	341594	14223L	PARTICIPANT	\N	PRESENT	0
341601	341594	19689Q	PARTICIPANT	\N	PRESENT	0
341602	341594	19413M	PARTICIPANT	\N	PRESENT	0
341603	341594	14051J	PARTICIPANT	\N	PRESENT	0
346828	346826	14083S	PARTICIPANT	\N	PRESENT	0
346829	346826	11048N	PARTICIPANT	\N	PRESENT	0
346830	346826	19711U	PARTICIPANT	\N	PRESENT	0
346831	346826	04034C	PARTICIPANT	\N	PRESENT	0
346832	346826	19441R	PARTICIPANT	\N	PRESENT	0
346833	346826	14151M	PARTICIPANT	\N	PRESENT	0
346834	346826	89017R	PARTICIPANT	\N	PRESENT	0
346835	346826	19399H	PARTICIPANT	\N	PRESENT	0
346836	346826	11110B	PARTICIPANT	\N	PRESENT	0
346837	346826	19521Q	PRESIDENT	0	PRESENT	0
346838	346826	19762G	PARTICIPANT	\N	PRESENT	0
346841	339515	11027H	PARTICIPANT	\N	PRESENT	0
346865	346842	19766L	PARTICIPANT	\N	PRESENT	0
346866	346842	19643A	PARTICIPANT	\N	PRESENT	0
346867	346842	04070G	PRESIDENT	0	PRESENT	0
346868	346842	19699S	PARTICIPANT	\N	PRESENT	0
346869	346842	04035D	PARTICIPANT	\N	PRESENT	0
346870	346842	19731Y	PARTICIPANT	\N	PRESENT	0
346871	346842	19573D	PARTICIPANT	\N	PRESENT	0
346872	346842	07033P	PARTICIPANT	\N	PRESENT	0
346873	346842	11104D	PARTICIPANT	\N	PRESENT	0
346874	346842	87003B	PARTICIPANT	\N	PRESENT	0
346875	346842	08039A	PARTICIPANT	\N	PRESENT	0
346876	346842	14030Q	PARTICIPANT	\N	PRESENT	0
346877	346842	14073Q	PARTICIPANT	\N	EXCUSE	0
346878	346842	08020N	PARTICIPANT	\N	EXCUSE	0
346879	346842	08043V	PARTICIPANT	\N	EXCUSE	0
346880	346842	19693L	PARTICIPANT	\N	EXCUSE	0
346881	339515	19691J	PARTICIPANT	\N	PRESENT	0
346882	339515	19415P	PARTICIPANT	\N	PRESENT	0
346883	339515	14033T	PARTICIPANT	\N	PRESENT	0
346884	339515	19447X	PARTICIPANT	\N	PRESENT	0
346885	339515	14157T	PARTICIPANT	\N	PRESENT	0
346886	339515	19563B	PARTICIPANT	\N	PRESENT	0
346887	339515	19301E	PARTICIPANT	\N	PRESENT	0
346888	339515	19527W	PARTICIPANT	\N	PRESENT	0
346889	339515	11104D	PARTICIPANT	\N	PRESENT	0
346890	339515	14227Q	PARTICIPANT	\N	PRESENT	0
346891	339515	19695N	PARTICIPANT	\N	PRESENT	0
346892	339515	12041X	PARTICIPANT	\N	PRESENT	0
346893	339515	14235Q	PARTICIPANT	\N	PRESENT	0
346894	339515	04034C	PARTICIPANT	\N	PRESENT	0
346895	339515	14089Y	PARTICIPANT	\N	PRESENT	0
346896	339515	08055A	PARTICIPANT	\N	PRESENT	0
346897	339515	14069U	PARTICIPANT	\N	PRESENT	0
346898	339515	19631V	PARTICIPANT	\N	PRESENT	0
346899	339515	19553Y	PARTICIPANT	\N	PRESENT	0
346900	339515	17589D	PARTICIPANT	\N	PRESENT	0
346901	339515	19583F	PARTICIPANT	\N	PRESENT	0
346902	339515	14038Y	PARTICIPANT	\N	PRESENT	0
346903	339515	19467C	PARTICIPANT	\N	PRESENT	0
346904	339515	19741B	PARTICIPANT	\N	PRESENT	0
346905	339515	14105F	PARTICIPANT	\N	PRESENT	0
346906	339515	01058X	PARTICIPANT	\N	PRESENT	0
346907	339515	04088S	PARTICIPANT	\N	PRESENT	0
346908	339515	04049K	PARTICIPANT	\N	PRESENT	0
346909	339515	14083S	PARTICIPANT	\N	PRESENT	0
346910	339515	11110B	PARTICIPANT	\N	PRESENT	0
346911	339515	17583W	PARTICIPANT	\N	PRESENT	0
346912	339515	11067R	PARTICIPANT	\N	PRESENT	0
346913	339515	19729F	PARTICIPANT	\N	PRESENT	0
346914	339515	11056N	PARTICIPANT	\N	PRESENT	0
346915	339515	19760E	PARTICIPANT	\N	PRESENT	0
346916	339515	14255U	PARTICIPANT	\N	PRESENT	0
346917	339515	14215L	PARTICIPANT	\N	PRESENT	0
346918	339515	19747H	PARTICIPANT	\N	PRESENT	0
346919	339515	08015R	PARTICIPANT	\N	PRESENT	0
346920	339515	19762G	PARTICIPANT	\N	PRESENT	0
346921	339515	19521Q	PARTICIPANT	\N	PRESENT	0
346922	339515	11090Q	PARTICIPANT	\N	PRESENT	0
346923	339515	11048N	PARTICIPANT	\N	PRESENT	0
346924	339515	14121F	PARTICIPANT	\N	PRESENT	0
346925	339515	11103C	PARTICIPANT	\N	PRESENT	0
346926	339515	14151M	PARTICIPANT	\N	PRESENT	0
346927	339515	14028W	PARTICIPANT	\N	PRESENT	0
346928	339515	19545Y	PARTICIPANT	\N	PRESENT	0
346929	339515	19667J	PARTICIPANT	\N	PRESENT	0
346940	339515	97011G	PARTICIPANT	\N	PRESENT	0
346946	339515	19479G	PARTICIPANT	\N	PRESENT	0
346949	339515	19399H	PARTICIPANT	\N	PRESENT	0
346960	339515	19711U	PARTICIPANT	\N	PRESENT	0
346967	339515	19739H	PARTICIPANT	\N	PRESENT	0
346971	339515	04018C	PARTICIPANT	\N	PRESENT	0
346972	339515	14026U	PARTICIPANT	\N	PRESENT	0
346977	339515	19689Q	PARTICIPANT	\N	PRESENT	0
346979	339515	14029X	PARTICIPANT	\N	PRESENT	0
346996	339515	18083K	PARTICIPANT	\N	PRESENT	0
347000	339515	07004J	PARTICIPANT	\N	PRESENT	0
347011	339515	19387D	PARTICIPANT	\N	PRESENT	0
347012	339515	19629C	PARTICIPANT	\N	PRESENT	0
347013	339515	14207L	PARTICIPANT	\N	PRESENT	0
347014	346842	14123H	PARTICIPANT	\N	PRESENT	0
347015	339515	14051J	PARTICIPANT	\N	PRESENT	0
347016	339515	14103D	PARTICIPANT	\N	PRESENT	0
347018	339515	08048B	PARTICIPANT	\N	PRESENT	0
347019	339515	19643A	PARTICIPANT	\N	PRESENT	0
347021	339515	19413M	PARTICIPANT	\N	PRESENT	0
347022	339515	14041T	PARTICIPANT	\N	PRESENT	0
347023	339515	89017R	PARTICIPANT	\N	PRESENT	0
347024	339515	14021P	PARTICIPANT	\N	PRESENT	0
347025	339515	19679N	PARTICIPANT	\N	PRESENT	0
347026	339515	19507S	PARTICIPANT	\N	PRESENT	0
347027	339515	04047H	PARTICIPANT	\N	PRESENT	0
347028	339515	19733B	PARTICIPANT	\N	PRESENT	0
347029	346842	19593H	PARTICIPANT	\N	EXCUSE	0
347030	339515	08009T	PARTICIPANT	\N	PRESENT	0
347031	339515	80013X	PARTICIPANT	\N	PRESENT	0
347032	339515	11031D	PARTICIPANT	\N	PRESENT	0
347033	339515	11040E	PARTICIPANT	\N	PRESENT	0
347034	339515	08053X	PARTICIPANT	\N	PRESENT	0
347035	339515	19703U	PARTICIPANT	\N	PRESENT	0
347036	339515	14199E	PARTICIPANT	\N	PRESENT	0
347037	339515	08073C	PARTICIPANT	\N	PRESENT	0
347038	339515	08038Y	PARTICIPANT	\N	PRESENT	0
347117	339515	08034U	PARTICIPANT	\N	PRESENT	0
347118	339515	14357A	PARTICIPANT	\N	PRESENT	0
347120	339515	95062K	PARTICIPANT	\N	PRESENT	0
347121	339515	14231L	PARTICIPANT	\N	PRESENT	0
347122	339515	11053K	PARTICIPANT	\N	PRESENT	0
347123	339515	04035D	PARTICIPANT	\N	PRESENT	0
347124	339515	99004R	PARTICIPANT	\N	PRESENT	0
347125	339515	01062T	PARTICIPANT	\N	PRESENT	0
347126	339515	14109K	PARTICIPANT	\N	PRESENT	0
347127	339515	14265W	PARTICIPANT	\N	PRESENT	0
352620	351931	14073Q	PARTICIPANT	\N	PRESENT	0
352621	351931	19611R	PARTICIPANT	\N	PRESENT	0
352622	351931	87003B	PARTICIPANT	\N	PRESENT	0
352623	351931	14241N	PARTICIPANT	\N	PRESENT	0
352624	351931	19731Y	PARTICIPANT	\N	PRESENT	0
352625	351931	19735D	PARTICIPANT	\N	PRESENT	0
352626	351931	14123H	PRESIDENT	0	PRESENT	0
352627	351931	08012N	PARTICIPANT	\N	PRESENT	0
352628	351931	11043H	PARTICIPANT	\N	PRESENT	0
352629	351931	14249W	PARTICIPANT	\N	PRESENT	0
352630	351931	19758L	PARTICIPANT	\N	PRESENT	0
352631	351931	04070G	PARTICIPANT	\N	EXCUSE	0
352632	350939	14219Q	PARTICIPANT	\N	PRESENT	0
352633	350939	11012A	PARTICIPANT	\N	PRESENT	0
352634	350939	19629C	PARTICIPANT	\N	PRESENT	0
352635	350939	19701S	PARTICIPANT	\N	PRESENT	0
352636	350939	14121F	PARTICIPANT	\N	PRESENT	0
352637	350939	14147R	PARTICIPANT	\N	PRESENT	0
352638	350939	19675J	PARTICIPANT	\N	PRESENT	0
352639	350939	99004R	PARTICIPANT	\N	PRESENT	0
352640	350939	17583W	PARTICIPANT	\N	PRESENT	0
352642	352641	14079W	PARTICIPANT	\N	PRESENT	0
352643	352641	97011G	PARTICIPANT	\N	PRESENT	0
352644	352641	08056B	PARTICIPANT	\N	PRESENT	0
352645	352641	14179A	PARTICIPANT	\N	PRESENT	0
352646	352641	95067Q	PARTICIPANT	\N	PRESENT	0
352647	352641	14169X	PARTICIPANT	\N	PRESENT	0
352648	352641	08034U	PARTICIPANT	\N	PRESENT	0
352649	352641	11026G	PARTICIPANT	\N	PRESENT	0
352650	350939	14107H	PARTICIPANT	\N	PRESENT	0
352651	350939	19691J	PARTICIPANT	\N	PRESENT	0
352652	350939	18083K	PARTICIPANT	\N	PRESENT	0
352653	350939	15447F	PARTICIPANT	\N	PRESENT	0
352654	350939	19349W	PARTICIPANT	\N	PRESENT	0
352655	350939	19585H	PARTICIPANT	\N	PRESENT	0
352656	350939	14267Y	PARTICIPANT	\N	PRESENT	0
352657	350939	19671E	PARTICIPANT	\N	PRESENT	0
352658	350939	19681G	PARTICIPANT	\N	PRESENT	0
352659	348095	14069U	PARTICIPANT	\N	PRESENT	0
352660	348095	11101A	PARTICIPANT	\N	PRESENT	0
352661	350215	19768N	PARTICIPANT	\N	PRESENT	0
352662	350215	19782L	PARTICIPANT	\N	PRESENT	0
352663	350215	14357A	PARTICIPANT	\N	PRESENT	0
352664	350215	19569H	PARTICIPANT	\N	PRESENT	0
352665	350215	19441R	PARTICIPANT	\N	PRESENT	0
352666	350215	14079W	PARTICIPANT	\N	PRESENT	0
352667	350215	19413M	PARTICIPANT	\N	PRESENT	0
352668	350215	14001X	PARTICIPANT	\N	PRESENT	0
352669	350215	14026U	PARTICIPANT	\N	PRESENT	0
352670	350215	19631V	PARTICIPANT	\N	PRESENT	0
352671	350215	14237S	PARTICIPANT	\N	PRESENT	0
352672	350215	11099A	PARTICIPANT	\N	PRESENT	0
352673	350215	08068F	PARTICIPANT	\N	PRESENT	0
352674	350215	95037J	PARTICIPANT	\N	PRESENT	0
352675	350215	08015R	PARTICIPANT	\N	PRESENT	0
352676	350215	96004D	PARTICIPANT	\N	PRESENT	0
352677	350215	19511N	PARTICIPANT	\N	PRESENT	0
352678	350215	19563B	PARTICIPANT	\N	PRESENT	0
352679	350215	14249W	PARTICIPANT	\N	PRESENT	0
352680	350215	14265W	PARTICIPANT	\N	PRESENT	0
352681	350215	14329V	PARTICIPANT	\N	PRESENT	0
352682	350215	14135M	PARTICIPANT	\N	PRESENT	0
352683	350215	19593H	PARTICIPANT	\N	PRESENT	0
352684	350215	98035U	PARTICIPANT	\N	PRESENT	0
352685	350215	14097Y	PARTICIPANT	\N	PRESENT	0
352686	350215	19467C	PARTICIPANT	\N	PRESENT	0
352687	350215	14061L	PARTICIPANT	\N	PRESENT	0
352688	350215	04057K	PARTICIPANT	\N	PRESENT	0
352689	350215	14073Q	PARTICIPANT	\N	PRESENT	0
352690	350215	14187A	PARTICIPANT	\N	PRESENT	0
352691	350215	08038Y	PARTICIPANT	\N	PRESENT	0
352692	350215	19695N	PARTICIPANT	\N	PRESENT	0
352693	350215	14033T	PARTICIPANT	\N	PRESENT	0
352694	350215	11090Q	PARTICIPANT	\N	PRESENT	0
352695	350215	19269X	PARTICIPANT	\N	PRESENT	0
352696	350215	19725B	PARTICIPANT	\N	PRESENT	0
352697	350215	14205J	PARTICIPANT	\N	PRESENT	0
352698	350215	14089Y	PARTICIPANT	\N	PRESENT	0
352699	350215	04088S	PARTICIPANT	\N	PRESENT	0
352700	350215	11056N	PARTICIPANT	\N	PRESENT	0
352701	350215	14115H	PARTICIPANT	\N	PRESENT	0
352702	350215	19507S	PARTICIPANT	\N	PRESENT	0
352703	350215	04097T	PARTICIPANT	\N	PRESENT	0
352704	350215	19747H	PARTICIPANT	\N	PRESENT	0
352705	350215	14207L	PARTICIPANT	\N	PRESENT	0
352706	350215	14257W	PARTICIPANT	\N	PRESENT	0
352707	350215	08021P	PARTICIPANT	\N	EXCUSE	0
352708	350215	08028W	PARTICIPANT	\N	EXCUSE	0
352709	350215	11081P	PARTICIPANT	\N	EXCUSE	0
352710	348095	04086Q	PARTICIPANT	\N	PRESENT	0
352711	348095	14259Y	PARTICIPANT	\N	PRESENT	0
352713	348095	14281W	PARTICIPANT	\N	PRESENT	0
352714	348095	19565D	PARTICIPANT	\N	PRESENT	0
352715	348095	11049P	PARTICIPANT	\N	PRESENT	0
352716	348095	11048N	PARTICIPANT	\N	PRESENT	0
352717	348095	14103D	PARTICIPANT	\N	PRESENT	0
352718	350939	14031R	PARTICIPANT	\N	PRESENT	0
352719	350939	11103C	PARTICIPANT	\N	PRESENT	0
352720	348095	05012A	PARTICIPANT	\N	PRESENT	0
352721	348095	19735D	PARTICIPANT	\N	PRESENT	0
352722	348095	08049C	PARTICIPANT	\N	PRESENT	0
352723	350939	98005N	PARTICIPANT	\N	PRESENT	0
352730	350939	04086Q	PARTICIPANT	\N	PRESENT	0
352731	350939	11072N	PARTICIPANT	\N	PRESENT	0
352734	350939	19657G	PARTICIPANT	\N	PRESENT	0
352744	350939	11056N	PARTICIPANT	\N	PRESENT	0
352742	350939	19565D	PARTICIPANT	\N	PRESENT	0
352743	350939	11040E	PARTICIPANT	\N	PRESENT	0
352745	350939	19507S	PARTICIPANT	\N	PRESENT	0
352746	350939	11049P	PARTICIPANT	\N	PRESENT	0
352747	350939	14261S	PARTICIPANT	\N	PRESENT	0
352748	350939	19782L	PARTICIPANT	\N	PRESENT	0
352756	350839	19553Y	PARTICIPANT	\N	PRESENT	0
352757	350839	11067R	PARTICIPANT	\N	PRESENT	0
352758	350839	14147R	PARTICIPANT	\N	PRESENT	0
352759	350839	14213J	PARTICIPANT	\N	PRESENT	0
352760	350839	19749K	PARTICIPANT	\N	PRESENT	0
352761	350839	10006L	PRESIDENT	0	PRESENT	0
352762	350839	08031R	PARTICIPANT	\N	PRESENT	0
352763	350839	04047H	PARTICIPANT	\N	EXCUSE	0
352764	350839	19295A	PARTICIPANT	\N	EXCUSE	0
352765	350939	14327T	PARTICIPANT	\N	PRESENT	0
352766	350939	19631V	PARTICIPANT	\N	PRESENT	0
352767	350939	80013X	PARTICIPANT	\N	PRESENT	0
352768	350939	19387D	PARTICIPANT	\N	PRESENT	0
352769	350939	19649G	PARTICIPANT	\N	PRESENT	0
352770	350939	01028R	PARTICIPANT	\N	PRESENT	0
352771	350939	14205J	PARTICIPANT	\N	PRESENT	0
352772	350939	14215L	PARTICIPANT	\N	PRESENT	0
352773	350939	19762G	PARTICIPANT	\N	PRESENT	0
352774	350939	14191V	PARTICIPANT	\N	PRESENT	0
352775	350939	19725B	PARTICIPANT	\N	PRESENT	0
352776	350939	04088S	PARTICIPANT	\N	PRESENT	0
352777	351931	19533U	PARTICIPANT	\N	PRESENT	0
352778	351931	08043V	PARTICIPANT	\N	PRESENT	0
352779	351931	14039A	PARTICIPANT	\N	PRESENT	0
352781	350939	19794Q	PARTICIPANT	\N	PRESENT	0
352783	350939	19741B	PARTICIPANT	\N	PRESENT	0
352788	350939	14026U	PARTICIPANT	\N	PRESENT	0
352789	350939	14249W	PARTICIPANT	\N	PRESENT	0
352791	350939	19479G	PARTICIPANT	\N	PRESENT	0
352792	350939	16685X	PARTICIPANT	\N	PRESENT	0
352793	350939	14033T	PARTICIPANT	\N	PRESENT	0
352794	344811	14030Q	PRESIDENT	0	PRESENT	0
352795	344811	08043V	PARTICIPANT	\N	PRESENT	0
352796	344811	18083K	PARTICIPANT	\N	PRESENT	0
352797	344811	11031D	PARTICIPANT	\N	PRESENT	0
352798	344811	80013X	PARTICIPANT	\N	PRESENT	0
352799	344811	14217N	PARTICIPANT	\N	PRESENT	0
352800	344811	04035D	PARTICIPANT	\N	PRESENT	0
352801	344811	19715Y	PARTICIPANT	\N	PRESENT	0
352802	344811	08031R	PARTICIPANT	\N	PRESENT	0
352803	344811	07029T	PARTICIPANT	\N	PRESENT	0
352804	344811	19749K	PARTICIPANT	\N	PRESENT	0
352805	344811	08020N	PARTICIPANT	\N	EXCUSE	0
352806	350939	14159V	PARTICIPANT	\N	PRESENT	0
352807	344811	19701S	PARTICIPANT	\N	EXCUSE	0
352808	344811	14179A	PARTICIPANT	\N	EXCUSE	0
352809	344811	08017T	PARTICIPANT	\N	EXCUSE	0
352810	344811	11067R	PARTICIPANT	\N	EXCUSE	0
352811	350939	95062K	PARTICIPANT	\N	PRESENT	0
352812	350939	19679N	PARTICIPANT	\N	PRESENT	0
352813	350939	19549D	PARTICIPANT	\N	PRESENT	0
352814	344811	01043Q	PARTICIPANT	\N	EXCUSE	0
352816	350939	08056B	PARTICIPANT	\N	PRESENT	0
352827	350939	19715Y	PARTICIPANT	\N	PRESENT	0
352828	350939	19369B	PARTICIPANT	\N	PRESENT	0
352829	350939	05008E	PARTICIPANT	\N	PRESENT	0
352830	350939	19413M	PARTICIPANT	\N	PRESENT	0
336717	335284	11067R	PARTICIPANT	\N	PRESENT	0
336718	335284	11097X	PARTICIPANT	\N	PRESENT	0
336719	335284	08052W	PARTICIPANT	\N	PRESENT	0
336720	335284	19301E	PARTICIPANT	\N	PRESENT	0
336721	335284	19415P	PARTICIPANT	\N	PRESENT	0
336722	335284	19717B	PARTICIPANT	\N	PRESENT	0
336723	335284	14239U	PARTICIPANT	\N	PRESENT	0
336724	335284	19703U	PARTICIPANT	\N	PRESENT	0
336725	335284	19727D	PARTICIPANT	\N	PRESENT	0
336726	335284	14281W	PARTICIPANT	\N	PRESENT	0
336727	335284	11103C	PARTICIPANT	\N	PRESENT	0
336728	335284	19679N	PARTICIPANT	\N	PRESENT	0
336729	335284	14195A	PARTICIPANT	\N	PRESENT	0
336730	335284	19575F	PARTICIPANT	\N	PRESENT	0
336731	335284	98024R	PARTICIPANT	\N	PRESENT	0
336732	335284	08041T	PARTICIPANT	\N	EXCUSE	0
336733	335284	10006L	PARTICIPANT	\N	PRESENT	0
336734	335284	19715Y	PARTICIPANT	\N	PRESENT	0
336735	335284	19691J	PARTICIPANT	\N	PRESENT	0
336736	335284	14355X	PARTICIPANT	\N	EXCUSE	0
336737	335284	17779H	PARTICIPANT	\N	PRESENT	0
336738	335284	04092N	PRESIDENT	0	PRESENT	0
336739	335284	14119M	PARTICIPANT	\N	PRESENT	0
336740	335284	14087W	PARTICIPANT	\N	PRESENT	0
336741	335284	14071N	PARTICIPANT	\N	PRESENT	0
336742	335284	19657G	PARTICIPANT	\N	PRESENT	0
336743	335284	14213J	PARTICIPANT	\N	PRESENT	0
336744	335284	14227Q	PARTICIPANT	\N	PRESENT	0
336745	335284	19527W	PARTICIPANT	\N	PRESENT	0
336746	335284	19760E	PARTICIPANT	\N	PRESENT	0
336747	335284	19553Y	PARTICIPANT	\N	PRESENT	0
336882	335290	14327T	PARTICIPANT	\N	PRESENT	0
336883	335290	14331P	PARTICIPANT	\N	PRESENT	0
336884	335290	01048V	PARTICIPANT	\N	PRESENT	0
336885	335290	19545Y	PARTICIPANT	\N	PRESENT	0
336886	335290	01057W	PARTICIPANT	\N	PRESENT	0
336887	335290	11053K	PARTICIPANT	\N	PRESENT	0
336888	335290	11074Q	PRESIDENT	0	PRESENT	0
336889	335290	89017R	PARTICIPANT	\N	PRESENT	0
336890	335290	19667J	PARTICIPANT	\N	PRESENT	0
336891	335290	11070L	PARTICIPANT	\N	PRESENT	0
336892	335290	19671E	PARTICIPANT	\N	PRESENT	0
336893	335290	88008L	PARTICIPANT	\N	PRESENT	0
336894	335290	07029T	PARTICIPANT	\N	PRESENT	0
336895	335290	14085U	PARTICIPANT	\N	PRESENT	0
336896	335290	07004J	PARTICIPANT	\N	PRESENT	0
336897	335290	19349W	PARTICIPANT	\N	PRESENT	0
336898	335290	08010L	PARTICIPANT	\N	PRESENT	0
336899	335290	14253S	PARTICIPANT	\N	PRESENT	0
336900	335290	19479G	PARTICIPANT	\N	PRESENT	0
336901	335290	11048N	PARTICIPANT	\N	PRESENT	0
336902	335290	19647E	PARTICIPANT	\N	PRESENT	0
336903	335290	19711U	PARTICIPANT	\N	PRESENT	0
336904	335290	19531S	PARTICIPANT	\N	PRESENT	0
336905	335290	08069G	PARTICIPANT	\N	PRESENT	0
336906	335290	19687N	PARTICIPANT	\N	PRESENT	0
336907	335290	19689Q	PARTICIPANT	\N	PRESENT	0
336908	335290	14159V	PARTICIPANT	\N	PRESENT	0
336909	335290	11040E	PARTICIPANT	\N	PRESENT	0
336910	335290	14083S	PARTICIPANT	\N	PRESENT	0
336911	335290	11012A	PARTICIPANT	\N	PRESENT	0
336912	335290	14199E	PARTICIPANT	\N	PRESENT	0
336913	335290	08073C	PARTICIPANT	\N	PRESENT	0
336914	335290	14121F	PARTICIPANT	\N	PRESENT	0
336915	335290	99004R	PARTICIPANT	\N	PRESENT	0
336916	335290	08011M	PARTICIPANT	\N	EXCUSE	0
336917	335284	19577H	PARTICIPANT	\N	PRESENT	0
336918	335284	01034P	PARTICIPANT	\N	PRESENT	0
336919	334152	08009T	PRESIDENT	0	PRESENT	0
336920	334152	18083K	PARTICIPANT	\N	EXCUSE	0
336921	334152	14093U	PARTICIPANT	\N	EXCUSE	0
336922	334152	19347U	PARTICIPANT	\N	EXCUSE	0
336923	334152	19503N	PARTICIPANT	\N	EXCUSE	0
336924	334152	19685L	PARTICIPANT	\N	EXCUSE	0
336928	336478	04059M	PARTICIPANT	\N	PRESENT	0
336961	334152	19383Y	PARTICIPANT	\N	PRESENT	0
336962	334152	15447F	PARTICIPANT	\N	PRESENT	0
336963	334152	19681G	PARTICIPANT	\N	PRESENT	0
336964	334152	08024S	PARTICIPANT	\N	PRESENT	0
336965	334152	96004D	PARTICIPANT	\N	PRESENT	0
336980	321406	04044E	PARTICIPANT	\N	PRESENT	0
336981	321406	19599P	PARTICIPANT	\N	PRESENT	0
336982	321406	08052W	PARTICIPANT	\N	PRESENT	0
336983	321406	14215L	PARTICIPANT	\N	PRESENT	0
336984	321406	14179A	PARTICIPANT	\N	PRESENT	0
336985	321406	14085U	PARTICIPANT	\N	PRESENT	0
336986	321406	11067R	PARTICIPANT	\N	PRESENT	0
336987	321406	08017T	PARTICIPANT	\N	PRESENT	0
336988	321406	19631V	PARTICIPANT	\N	PRESENT	0
336989	321406	19333N	PARTICIPANT	\N	PRESENT	0
336990	321406	14207L	PARTICIPANT	\N	PRESENT	0
336991	321406	11066Q	PARTICIPANT	\N	PRESENT	0
336992	321406	14028W	PARTICIPANT	\N	PRESENT	0
336993	321406	08043V	PARTICIPANT	\N	PRESENT	0
336994	321406	08045X	PARTICIPANT	\N	PRESENT	0
336995	321406	11027H	PARTICIPANT	\N	PRESENT	0
336996	321406	19591F	PARTICIPANT	\N	PRESENT	0
336997	321406	19649G	PARTICIPANT	\N	PRESENT	0
336998	321406	04038G	PARTICIPANT	\N	PRESENT	0
336999	321406	19593H	PARTICIPANT	\N	PRESENT	0
337000	321406	11074Q	PARTICIPANT	\N	PRESENT	0
337001	321406	95063L	PARTICIPANT	\N	PRESENT	0
337002	321406	17589D	PARTICIPANT	\N	PRESENT	0
337003	321406	19479G	PARTICIPANT	\N	PRESENT	0
337004	321406	19629C	PARTICIPANT	\N	PRESENT	0
337005	321406	14089Y	PARTICIPANT	\N	PRESENT	0
337006	321406	01024M	PARTICIPANT	\N	PRESENT	0
337007	321406	14231L	PARTICIPANT	\N	PRESENT	0
337008	321406	19731Y	PARTICIPANT	\N	PRESENT	0
337009	321406	19729F	PARTICIPANT	\N	PRESENT	0
337010	321406	19507S	PARTICIPANT	\N	PRESENT	0
337011	321406	19415P	PARTICIPANT	\N	PRESENT	0
337012	321406	19413M	PARTICIPANT	\N	PRESENT	0
337013	321406	11045K	PARTICIPANT	\N	PRESENT	0
337014	321406	10015M	PARTICIPANT	\N	PRESENT	0
337015	321406	11043H	PARTICIPANT	\N	PRESENT	0
337016	321406	19581D	PARTICIPANT	\N	PRESENT	0
337017	321406	14211G	PARTICIPANT	\N	PRESENT	0
337018	321406	19691J	PARTICIPANT	\N	PRESENT	0
337019	321406	19673G	PARTICIPANT	\N	PRESENT	0
337020	321406	14265W	PARTICIPANT	\N	PRESENT	0
337021	321406	14249W	PARTICIPANT	\N	PRESENT	0
337022	321406	14053L	PARTICIPANT	\N	PRESENT	0
337023	321406	19447X	PARTICIPANT	\N	PRESENT	0
337024	321406	14038Y	PARTICIPANT	\N	PRESENT	0
337025	321406	08058D	PARTICIPANT	\N	PRESENT	0
337026	321406	14111D	PARTICIPANT	\N	PRESENT	0
337027	321406	19739H	PARTICIPANT	\N	PRESENT	0
337028	321406	14103D	PARTICIPANT	\N	PRESENT	0
337029	321406	19549D	PARTICIPANT	\N	PRESENT	0
337030	321406	19697Q	PARTICIPANT	\N	PRESENT	0
337032	321406	14257W	PARTICIPANT	\N	PRESENT	0
337045	321406	01028R	PARTICIPANT	\N	PRESENT	0
337039	321406	14097Y	PARTICIPANT	\N	PRESENT	0
337044	321406	19543W	PARTICIPANT	\N	PRESENT	0
337046	321406	19715Y	PARTICIPANT	\N	PRESENT	0
337047	321406	14021P	PARTICIPANT	\N	PRESENT	0
337048	321406	08055A	PARTICIPANT	\N	PRESENT	0
337049	321406	11104D	PARTICIPANT	\N	PRESENT	0
337050	321406	19489J	PARTICIPANT	\N	PRESENT	0
337051	321406	11109J	PARTICIPANT	\N	PRESENT	0
337052	321406	19251M	PARTICIPANT	\N	PRESENT	0
337054	321406	14147R	PARTICIPANT	\N	PRESENT	0
337055	321406	14061L	PARTICIPANT	\N	PRESENT	0
337056	321406	14135M	PARTICIPANT	\N	PRESENT	0
337057	321406	17779H	PARTICIPANT	\N	PRESENT	0
337058	321406	14151M	PARTICIPANT	\N	PRESENT	0
337059	321406	14073Q	PARTICIPANT	\N	PRESENT	0
337060	321406	14059S	PARTICIPANT	\N	PRESENT	0
337061	321406	80027E	PARTICIPANT	\N	PRESENT	0
337062	321406	14063N	PARTICIPANT	\N	PRESENT	0
337063	321406	14267Y	PARTICIPANT	\N	PRESENT	0
337064	321406	14069U	PARTICIPANT	\N	PRESENT	0
337067	321406	19575F	PARTICIPANT	\N	PRESENT	0
337068	321406	19701S	PARTICIPANT	\N	PRESENT	0
337069	321406	14115H	PARTICIPANT	\N	PRESENT	0
337070	321406	19533U	PARTICIPANT	\N	PRESENT	0
337071	321406	19515S	PARTICIPANT	\N	PRESENT	0
337072	321406	14237S	PARTICIPANT	\N	PRESENT	0
337073	321406	11103C	PARTICIPANT	\N	PRESENT	0
337074	321406	19762G	PARTICIPANT	\N	PRESENT	0
337075	321406	14281W	PARTICIPANT	\N	PRESENT	0
337076	321406	19727D	PARTICIPANT	\N	PRESENT	0
337077	321406	14107H	PARTICIPANT	\N	PRESENT	0
337078	321406	04034C	PARTICIPANT	\N	PRESENT	0
337079	321406	19441R	PARTICIPANT	\N	PRESENT	0
337080	321406	11099A	PARTICIPANT	\N	PRESENT	0
337081	321406	19369B	PARTICIPANT	\N	PRESENT	0
336104	335740	88008L	PARTICIPANT	\N	PRESENT	0
336105	335740	11070L	PARTICIPANT	\N	PRESENT	0
336106	335740	07029T	PARTICIPANT	\N	PRESENT	0
336107	335740	14085U	PARTICIPANT	\N	PRESENT	0
336108	335740	07004J	PARTICIPANT	\N	PRESENT	0
336109	335740	19349W	PARTICIPANT	\N	PRESENT	0
336110	335740	08010L	PARTICIPANT	\N	PRESENT	0
336111	335740	14253S	PARTICIPANT	\N	PRESENT	0
336112	335740	19479G	PARTICIPANT	\N	PRESENT	0
336113	335740	11048N	PARTICIPANT	\N	PRESENT	0
336114	335740	19711U	PARTICIPANT	\N	PRESENT	0
336115	335740	08034U	PARTICIPANT	\N	PRESENT	0
336116	335740	19651A	PARTICIPANT	\N	PRESENT	0
336117	335740	19531S	PARTICIPANT	\N	PRESENT	0
336118	335740	08069G	PARTICIPANT	\N	PRESENT	0
336119	335740	19687N	PARTICIPANT	\N	PRESENT	0
336120	335740	19689Q	PARTICIPANT	\N	PRESENT	0
336121	335740	08011M	PARTICIPANT	\N	PRESENT	0
336122	335740	14034U	PARTICIPANT	\N	PRESENT	0
336123	335740	14159V	PARTICIPANT	\N	PRESENT	0
336124	335740	14173T	PARTICIPANT	\N	PRESENT	0
336125	335740	04086Q	PARTICIPANT	\N	PRESENT	0
336126	335740	11040E	PARTICIPANT	\N	PRESENT	0
336127	335740	14083S	PARTICIPANT	\N	PRESENT	0
336128	335740	14199E	PARTICIPANT	\N	PRESENT	0
336129	335740	11012A	PARTICIPANT	\N	PRESENT	0
336130	335740	08073C	PARTICIPANT	\N	PRESENT	0
336131	335740	14121F	PARTICIPANT	\N	PRESENT	0
336132	335740	19741B	PARTICIPANT	\N	PRESENT	0
336133	335740	99004R	PARTICIPANT	\N	PRESENT	0
336134	335732	08010L	PARTICIPANT	\N	PRESENT	0
336135	335732	19643A	PARTICIPANT	\N	PRESENT	0
336137	335732	11049P	PARTICIPANT	\N	PRESENT	0
336138	335732	14042U	PARTICIPANT	\N	PRESENT	0
336139	335732	14219Q	PARTICIPANT	\N	PRESENT	0
336140	335732	08031R	PARTICIPANT	\N	PRESENT	0
336141	335732	19569H	PARTICIPANT	\N	PRESENT	0
336142	335732	14034U	PARTICIPANT	\N	PRESENT	0
336143	335732	19531S	PARTICIPANT	\N	PRESENT	0
336144	335732	14151M	PARTICIPANT	\N	PRESENT	0
336145	335732	19583F	PARTICIPANT	\N	PRESENT	0
336146	335732	17637T	PARTICIPANT	\N	PRESENT	0
336148	335732	08060W	PARTICIPANT	\N	PRESENT	0
336149	335732	19659J	PARTICIPANT	\N	PRESENT	0
336150	335732	19713W	PARTICIPANT	\N	PRESENT	0
336151	335732	19441R	PARTICIPANT	\N	PRESENT	0
336471	321399	11027H	PARTICIPANT	\N	PRESENT	0
336472	321399	19766L	PARTICIPANT	\N	PRESENT	0
336473	321399	19703U	PARTICIPANT	\N	PRESENT	0
336474	321399	19573D	PARTICIPANT	\N	PRESENT	0
336475	321399	04088S	PARTICIPANT	\N	PRESENT	0
336476	321399	14038Y	PARTICIPANT	\N	PRESENT	0
336477	321399	14265W	PARTICIPANT	\N	PRESENT	0
336479	321399	19399H	PARTICIPANT	\N	PRESENT	0
336480	321399	19575F	PARTICIPANT	\N	PRESENT	0
336481	321399	14147R	PARTICIPANT	\N	PRESENT	0
336482	321399	95067Q	PARTICIPANT	\N	PRESENT	0
336483	321399	14055N	PARTICIPANT	\N	PRESENT	0
336484	321399	14059S	PARTICIPANT	\N	PRESENT	0
336485	321399	19507S	PARTICIPANT	\N	PRESENT	0
336486	321399	19383Y	PARTICIPANT	\N	PRESENT	0
336487	321399	97011G	PARTICIPANT	\N	PRESENT	0
336488	321399	95062K	PARTICIPANT	\N	PRESENT	0
336489	321399	17637T	PARTICIPANT	\N	PRESENT	0
336490	321399	08069G	PARTICIPANT	\N	PRESENT	0
336491	321399	08011M	PARTICIPANT	\N	PRESENT	0
336492	321399	14211G	PARTICIPANT	\N	PRESENT	0
336493	321399	04033B	PARTICIPANT	\N	PRESENT	0
336494	321399	14187A	PARTICIPANT	\N	PRESENT	0
336495	321399	11048N	PARTICIPANT	\N	PRESENT	0
336496	321399	19711U	PARTICIPANT	\N	PRESENT	0
336497	321399	19621T	PARTICIPANT	\N	PRESENT	0
336498	321399	11097X	PARTICIPANT	\N	PRESENT	0
336499	321399	19447X	PARTICIPANT	\N	PRESENT	0
336500	321399	14215L	PARTICIPANT	\N	PRESENT	0
336501	321399	14213J	PARTICIPANT	\N	PRESENT	0
336502	321399	04008A	PARTICIPANT	\N	PRESENT	0
336503	321399	14235Q	PARTICIPANT	\N	PRESENT	0
336504	321399	14111D	PARTICIPANT	\N	PRESENT	0
336505	321399	01028R	PARTICIPANT	\N	PRESENT	0
336506	321399	19695N	PARTICIPANT	\N	PRESENT	0
336507	321399	19760E	PARTICIPANT	\N	PRESENT	0
336508	321399	19593H	PARTICIPANT	\N	PRESENT	0
336509	321399	07004J	PARTICIPANT	\N	PRESENT	0
336510	321399	19565D	PARTICIPANT	\N	PRESENT	0
336511	321399	19553Y	PARTICIPANT	\N	PRESENT	0
336512	321399	19545Y	PARTICIPANT	\N	PRESENT	0
336513	321399	19629C	PARTICIPANT	\N	PRESENT	0
336514	321399	08051V	PARTICIPANT	\N	PRESENT	0
336515	321399	19533U	PARTICIPANT	\N	PRESENT	0
336516	321399	08031R	PARTICIPANT	\N	PRESENT	0
336517	321399	14231L	PARTICIPANT	\N	PRESENT	0
336518	321399	19713W	PARTICIPANT	\N	PRESENT	0
336519	321399	19733B	PARTICIPANT	\N	PRESENT	0
336520	321399	14239U	PARTICIPANT	\N	PRESENT	0
336521	321399	11080N	PARTICIPANT	\N	PRESENT	0
336522	321399	01024M	PARTICIPANT	\N	PRESENT	0
336523	321399	14063N	PARTICIPANT	\N	PRESENT	0
336524	321399	19521Q	PARTICIPANT	\N	PRESENT	0
336525	321399	99004R	PARTICIPANT	\N	PRESENT	0
336526	321399	11012A	PARTICIPANT	\N	PRESENT	0
336527	321399	14033T	PARTICIPANT	\N	PRESENT	0
336528	321399	11090Q	PARTICIPANT	\N	PRESENT	0
336529	321399	01048V	PARTICIPANT	\N	PRESENT	0
336530	321399	19663E	PARTICIPANT	\N	PRESENT	0
336531	321399	11103C	PARTICIPANT	\N	PRESENT	0
336532	321399	11101A	PARTICIPANT	\N	PRESENT	0
336533	321399	14115H	PARTICIPANT	\N	PRESENT	0
336534	321399	19747H	PARTICIPANT	\N	PRESENT	0
336535	321399	19569H	PARTICIPANT	\N	PRESENT	0
336536	321399	19749K	PARTICIPANT	\N	PRESENT	0
336537	321399	14053L	PARTICIPANT	\N	PRESENT	0
336538	321399	10006L	PARTICIPANT	\N	PRESENT	0
336539	321399	14217N	PARTICIPANT	\N	PRESENT	0
336540	321399	14119M	PARTICIPANT	\N	PRESENT	0
336543	321399	14029X	PARTICIPANT	\N	PRESENT	0
336546	321399	14071N	PARTICIPANT	\N	PRESENT	0
336547	321399	08039A	PARTICIPANT	\N	PRESENT	0
336548	321399	19679N	PARTICIPANT	\N	PRESENT	0
336549	321399	14179A	PARTICIPANT	\N	PRESENT	0
336550	321399	19715Y	PARTICIPANT	\N	PRESENT	0
336551	321399	19599P	PARTICIPANT	\N	PRESENT	0
336552	321399	18083K	PARTICIPANT	\N	PRESENT	0
336553	321399	19467C	PARTICIPANT	\N	PRESENT	0
336554	321399	19611R	PARTICIPANT	\N	PRESENT	0
336555	321399	19479G	PARTICIPANT	\N	PRESENT	0
336556	321399	95063L	PARTICIPANT	\N	PRESENT	0
336557	321399	11115U	PARTICIPANT	\N	PRESENT	0
336558	321399	14061L	PARTICIPANT	\N	PRESENT	0
336559	321399	14069U	PARTICIPANT	\N	PRESENT	0
336560	321399	11043H	PARTICIPANT	\N	PRESENT	0
336561	321399	19745F	PARTICIPANT	\N	PRESENT	0
336562	321399	19563B	PARTICIPANT	\N	PRESENT	0
336563	321399	19727D	PARTICIPANT	\N	PRESENT	0
336564	321399	08015R	PARTICIPANT	\N	PRESENT	0
336565	321399	14105F	PARTICIPANT	\N	PRESENT	0
336566	321399	19549D	PARTICIPANT	\N	PRESENT	0
336567	321399	11064N	PARTICIPANT	\N	PRESENT	0
336650	321403	14034U	PARTICIPANT	\N	PRESENT	0
336651	321403	14063N	PARTICIPANT	\N	PRESENT	0
336652	321403	19549D	PARTICIPANT	\N	PRESENT	0
336653	321403	19333N	PARTICIPANT	\N	PRESENT	0
336654	321403	19489J	PARTICIPANT	\N	PRESENT	0
336655	321403	14001X	PARTICIPANT	\N	PRESENT	0
336656	321403	05008E	PARTICIPANT	\N	PRESENT	0
336657	321403	14053L	PARTICIPANT	\N	PRESENT	0
336658	321403	19629C	PARTICIPANT	\N	PRESENT	0
336659	321403	19703U	PARTICIPANT	\N	PRESENT	0
336660	321403	19447X	PARTICIPANT	\N	PRESENT	0
336661	321403	19663E	PARTICIPANT	\N	PRESENT	0
336662	321403	04038G	PARTICIPANT	\N	PRESENT	0
336663	321403	19575F	PARTICIPANT	\N	PRESENT	0
336664	321403	14105F	PARTICIPANT	\N	PRESENT	0
336665	321403	19533U	PARTICIPANT	\N	PRESENT	0
336666	321403	14259Y	PARTICIPANT	\N	PRESENT	0
336667	321403	95030B	PARTICIPANT	\N	PRESENT	0
336668	321403	11101A	PARTICIPANT	\N	PRESENT	0
336669	321403	19543W	PARTICIPANT	\N	PRESENT	0
336670	321403	14231L	PARTICIPANT	\N	PRESENT	0
336671	321403	14179A	PARTICIPANT	\N	PRESENT	0
336672	321403	14215L	PARTICIPANT	\N	PRESENT	0
336673	321403	14111D	PARTICIPANT	\N	PRESENT	0
336674	321403	10006L	PARTICIPANT	\N	PRESENT	0
336675	321403	08051V	PARTICIPANT	\N	PRESENT	0
336676	321403	19565D	PARTICIPANT	\N	PRESENT	0
336677	321403	19719D	PARTICIPANT	\N	PRESENT	0
336678	321403	19735D	PARTICIPANT	\N	PRESENT	0
336679	321403	19762G	PARTICIPANT	\N	PRESENT	0
332705	321364	11072N	PARTICIPANT	\N	PRESENT	0
332706	321364	19569H	PARTICIPANT	\N	PRESENT	0
332707	321364	80013X	PARTICIPANT	\N	PRESENT	0
332708	321364	14030Q	PARTICIPANT	\N	PRESENT	0
332709	321364	14213J	PARTICIPANT	\N	PRESENT	0
332710	321364	11110B	PARTICIPANT	\N	PRESENT	0
332711	321364	19762G	PARTICIPANT	\N	PRESENT	0
332712	321364	14267Y	PARTICIPANT	\N	PRESENT	0
332713	321364	19657G	PARTICIPANT	\N	PRESENT	0
332714	321364	14001X	PARTICIPANT	\N	PRESENT	0
332715	321364	19721W	PARTICIPANT	\N	PRESENT	0
332716	321364	14265W	PARTICIPANT	\N	PRESENT	0
332717	321364	14073Q	PARTICIPANT	\N	PRESENT	0
332718	321364	19681G	PARTICIPANT	\N	PRESENT	0
332719	321364	14195A	PARTICIPANT	\N	PRESENT	0
332720	321364	19479G	PARTICIPANT	\N	PRESENT	0
332873	331620	19533U	PARTICIPANT	\N	PRESENT	0
332874	331620	14147R	PARTICIPANT	\N	PRESENT	0
332875	331620	14223L	PARTICIPANT	\N	PRESENT	0
332876	331620	19749K	PARTICIPANT	\N	PRESENT	0
332877	331620	19723Y	PARTICIPANT	\N	PRESENT	0
332878	321366	99004R	PARTICIPANT	\N	PRESENT	0
332879	321366	17583W	PARTICIPANT	\N	PRESENT	0
332880	331620	19295A	PARTICIPANT	\N	PRESENT	0
332881	331620	19553Y	PARTICIPANT	\N	EXCUSE	0
332882	331620	11043H	PARTICIPANT	\N	EXCUSE	0
332883	331620	19415P	PARTICIPANT	\N	PRESENT	0
332884	331620	01028R	PARTICIPANT	\N	PRESENT	0
332885	321366	14063N	PARTICIPANT	\N	PRESENT	0
332886	321366	14051J	PARTICIPANT	\N	PRESENT	0
332887	331620	14030Q	PARTICIPANT	\N	PRESENT	0
332888	321366	19727D	PARTICIPANT	\N	PRESENT	0
332889	321366	11026G	PARTICIPANT	\N	PRESENT	0
332890	321366	19583F	PARTICIPANT	\N	PRESENT	0
332891	321366	19715Y	PARTICIPANT	\N	PRESENT	0
332899	321366	98050T	PARTICIPANT	\N	PRESENT	0
332900	321366	14053L	PARTICIPANT	\N	PRESENT	0
332901	321366	08034U	PARTICIPANT	\N	PRESENT	0
332902	321366	11048N	PARTICIPANT	\N	PRESENT	0
332903	321366	01062T	PARTICIPANT	\N	PRESENT	0
332904	321366	19737F	PARTICIPANT	\N	PRESENT	0
332905	321366	19349W	PARTICIPANT	\N	PRESENT	0
332906	321366	16685X	PARTICIPANT	\N	PRESENT	0
332916	321366	19703U	PARTICIPANT	\N	PRESENT	0
332917	321366	14151M	PARTICIPANT	\N	PRESENT	0
332918	321366	19671E	PARTICIPANT	\N	PRESENT	0
332919	321366	14169X	PARTICIPANT	\N	PRESENT	0
332920	321366	19721W	PARTICIPANT	\N	PRESENT	0
332921	321366	19545Y	PARTICIPANT	\N	PRESENT	0
332922	321366	19619A	PARTICIPANT	\N	PRESENT	0
332923	321366	19413M	PARTICIPANT	\N	PRESENT	0
332924	321366	14028W	PARTICIPANT	\N	PRESENT	0
332925	321366	14265W	PARTICIPANT	\N	PRESENT	0
332926	321366	14026U	PARTICIPANT	\N	PRESENT	0
332927	321366	19573D	PARTICIPANT	\N	PRESENT	0
332928	321366	04088S	PARTICIPANT	\N	PRESENT	0
332929	321366	07029T	PARTICIPANT	\N	PRESENT	0
332930	321366	14213J	PARTICIPANT	\N	PRESENT	0
332931	321366	11012A	PARTICIPANT	\N	PRESENT	0
332932	321366	19747H	PARTICIPANT	\N	PRESENT	0
332933	321366	14207L	PARTICIPANT	\N	PRESENT	0
332934	321366	08028W	PARTICIPANT	\N	PRESENT	0
332935	321366	19679N	PARTICIPANT	\N	PRESENT	0
332936	321366	19782L	PARTICIPANT	\N	PRESENT	0
332937	321366	11103C	PARTICIPANT	\N	PRESENT	0
332938	321366	19749K	PARTICIPANT	\N	PRESENT	0
332939	321366	97011G	PARTICIPANT	\N	PRESENT	0
332940	332845	14111D	PARTICIPANT	\N	PRESENT	0
332941	332845	14065Q	PARTICIPANT	\N	PRESENT	0
332942	332845	01024M	PARTICIPANT	\N	PRESENT	0
332943	332845	19581D	PARTICIPANT	\N	PRESENT	0
332944	332845	04044E	PARTICIPANT	\N	PRESENT	0
332945	332845	19673G	PARTICIPANT	\N	PRESENT	0
332946	332845	19719D	PARTICIPANT	\N	PRESENT	0
332947	332845	11033F	PARTICIPANT	\N	PRESENT	0
332948	332845	05008E	PRESIDENT	0	PRESENT	0
332949	332845	19447X	PARTICIPANT	\N	PRESENT	0
332950	332845	14231L	PARTICIPANT	\N	PRESENT	0
332951	332845	19725B	PARTICIPANT	\N	PRESENT	0
332952	332845	14089Y	PARTICIPANT	\N	PRESENT	0
332953	332845	19729F	PARTICIPANT	\N	PRESENT	0
332954	332845	19629C	PARTICIPANT	\N	PRESENT	0
332955	332845	08044W	PARTICIPANT	\N	PRESENT	0
332956	332845	14147R	PARTICIPANT	\N	PRESENT	0
332957	332845	14069U	PARTICIPANT	\N	PRESENT	0
332958	332845	14215L	PARTICIPANT	\N	PRESENT	0
332959	332845	11049P	PARTICIPANT	\N	PRESENT	0
332960	332845	04008A	PARTICIPANT	\N	PRESENT	0
332961	332845	08051V	PARTICIPANT	\N	PRESENT	0
332962	321366	04071H	PARTICIPANT	\N	PRESENT	0
332963	321366	19723Y	PARTICIPANT	\N	PRESENT	0
332964	321366	87003B	PARTICIPANT	\N	PRESENT	0
332965	321366	14257W	PARTICIPANT	\N	PRESENT	0
332966	321366	19569H	PARTICIPANT	\N	PRESENT	0
332967	321366	14267Y	PARTICIPANT	\N	PRESENT	0
332968	321366	14179A	PARTICIPANT	\N	PRESENT	0
332969	321366	19521Q	PARTICIPANT	\N	PRESENT	0
332970	321366	14201E	PARTICIPANT	\N	PRESENT	0
332971	321366	19563B	PARTICIPANT	\N	PRESENT	0
332972	332845	14001X	PARTICIPANT	\N	PRESENT	0
332973	332845	01028R	PARTICIPANT	\N	PRESENT	0
332974	332845	19489J	PARTICIPANT	\N	PRESENT	0
332975	332845	14151M	PARTICIPANT	\N	PRESENT	0
332976	332845	14259Y	PARTICIPANT	\N	PRESENT	0
332977	332845	14053L	PARTICIPANT	\N	PRESENT	0
332978	332845	14059S	PARTICIPANT	\N	PRESENT	0
332979	332845	19649G	PARTICIPANT	\N	PRESENT	0
332980	332845	11026G	PARTICIPANT	\N	PRESENT	0
332981	332845	07034Q	PARTICIPANT	\N	PRESENT	0
332982	332845	04038G	PARTICIPANT	\N	PRESENT	0
332983	332845	95063L	PARTICIPANT	\N	PRESENT	0
332984	332845	04061F	PARTICIPANT	\N	PRESENT	0
332985	332845	19762G	PARTICIPANT	\N	PRESENT	0
332987	321366	14121F	PARTICIPANT	\N	PRESENT	0
332988	321366	14119M	PARTICIPANT	\N	PRESENT	0
332989	321366	14173T	PARTICIPANT	\N	PRESENT	0
332990	332845	04047H	PARTICIPANT	\N	PRESENT	0
332991	332845	14179A	PARTICIPANT	\N	PRESENT	0
332993	332845	11067R	PARTICIPANT	\N	PRESENT	0
332994	332845	01060R	PARTICIPANT	\N	PRESENT	0
332995	332845	14223L	PARTICIPANT	\N	PRESENT	0
332996	321366	19347U	PARTICIPANT	\N	PRESENT	0
332997	321366	08020N	PARTICIPANT	\N	PRESENT	0
332998	321366	14241N	PARTICIPANT	\N	PRESENT	0
332999	321366	80013X	PARTICIPANT	\N	PRESENT	0
333000	321366	14281W	PARTICIPANT	\N	PRESENT	0
333001	321366	10006L	PARTICIPANT	\N	PRESENT	0
333002	332845	19766L	PARTICIPANT	\N	PRESENT	0
333003	332845	19675J	PARTICIPANT	\N	PRESENT	0
333004	332845	08061X	PARTICIPANT	\N	PRESENT	0
333005	332845	14157T	PARTICIPANT	\N	PRESENT	0
333006	332845	19647E	PARTICIPANT	\N	PRESENT	0
333007	332845	19663E	PARTICIPANT	\N	PRESENT	0
333008	332845	08055A	PARTICIPANT	\N	PRESENT	0
333009	332845	14105F	PARTICIPANT	\N	PRESENT	0
333010	332845	14063N	PARTICIPANT	\N	PRESENT	0
333011	332845	14021P	PARTICIPANT	\N	PRESENT	0
333012	332845	19415P	PARTICIPANT	\N	PRESENT	0
333013	332845	19503N	PARTICIPANT	\N	PRESENT	0
333014	332845	19367Y	PARTICIPANT	\N	PRESENT	0
333015	332845	08028W	PARTICIPANT	\N	PRESENT	0
333016	332845	11072N	PARTICIPANT	\N	PRESENT	0
333017	332845	01034P	PARTICIPANT	\N	PRESENT	0
333018	332845	14103D	PARTICIPANT	\N	PRESENT	0
333019	332845	01062T	PARTICIPANT	\N	PRESENT	0
333020	332845	14034U	PARTICIPANT	\N	PRESENT	0
333021	321366	14225N	PARTICIPANT	\N	PRESENT	0
333022	321366	04086Q	PARTICIPANT	\N	PRESENT	0
333023	321366	19691J	PARTICIPANT	\N	PRESENT	0
333024	321366	19681G	PARTICIPANT	\N	PRESENT	0
333025	321366	08011M	PARTICIPANT	\N	PRESENT	0
333026	332845	14331P	PARTICIPANT	\N	PRESENT	0
333027	332845	95030B	PARTICIPANT	\N	PRESENT	0
333028	332845	19549D	PARTICIPANT	\N	PRESENT	0
333029	332845	11097X	PARTICIPANT	\N	PRESENT	0
333030	332845	11110B	PARTICIPANT	\N	PRESENT	0
333031	332845	07033P	PARTICIPANT	\N	PRESENT	0
333032	332845	19525U	PARTICIPANT	\N	PRESENT	0
333033	332845	10015M	PARTICIPANT	\N	PRESENT	0
333034	332845	87003B	PARTICIPANT	\N	PRESENT	0
333035	332845	98018T	PARTICIPANT	\N	PRESENT	0
333036	332845	19383Y	PARTICIPANT	\N	PRESENT	0
333037	332845	04071H	PARTICIPANT	\N	PRESENT	0
333038	332845	19413M	PARTICIPANT	\N	PRESENT	0
333040	332845	08015R	PARTICIPANT	\N	PRESENT	0
333041	332845	14213J	PARTICIPANT	\N	PRESENT	0
333042	332845	14265W	PARTICIPANT	\N	PRESENT	0
333043	332845	14097Y	PARTICIPANT	\N	PRESENT	0
352831	350939	14063N	PARTICIPANT	\N	PRESENT	0
352832	350939	14083S	PARTICIPANT	\N	PRESENT	0
352909	339594	19565D	PARTICIPANT	\N	PRESENT	0
352910	339594	19413M	PARTICIPANT	\N	PRESENT	0
352911	339594	19251M	PARTICIPANT	\N	PRESENT	0
352912	339594	14121F	PARTICIPANT	\N	PRESENT	0
352913	339594	14159V	PARTICIPANT	\N	PRESENT	0
352914	339594	19725B	PARTICIPANT	\N	PRESENT	0
352915	339594	14063N	PARTICIPANT	\N	PRESENT	0
352916	339594	19549D	PARTICIPANT	\N	PRESENT	0
352917	339594	11026G	PARTICIPANT	\N	PRESENT	0
352918	339594	19715Y	PARTICIPANT	\N	PRESENT	0
352919	339594	11033F	PARTICIPANT	\N	PRESENT	0
352920	339594	19329S	PARTICIPANT	\N	PRESENT	0
352921	339594	19349W	PARTICIPANT	\N	PRESENT	0
352922	339594	04057K	PARTICIPANT	\N	PRESENT	0
352923	339594	19585H	PARTICIPANT	\N	PRESENT	0
352924	339594	14097Y	PARTICIPANT	\N	PRESENT	0
352926	339594	98005N	PARTICIPANT	\N	PRESENT	0
352927	339594	19479G	PARTICIPANT	\N	PRESENT	0
352928	339594	19369B	PARTICIPANT	\N	PRESENT	0
352929	339594	14327T	PARTICIPANT	\N	PRESENT	0
352930	339594	14205J	PARTICIPANT	\N	PRESENT	0
352931	339594	95063L	PARTICIPANT	\N	PRESENT	0
352932	339594	14275Y	PARTICIPANT	\N	PRESENT	0
352933	339594	16685X	PARTICIPANT	\N	PRESENT	0
352934	339594	11012A	PARTICIPANT	\N	PRESENT	0
352935	339594	14261S	PARTICIPANT	\N	PRESENT	0
352936	339594	08056B	PARTICIPANT	\N	PRESENT	0
352938	339594	19691J	PARTICIPANT	\N	PRESENT	0
352939	339594	14089Y	PARTICIPANT	\N	PRESENT	0
352943	339594	14083S	PARTICIPANT	\N	PRESENT	0
352945	339594	14215L	PARTICIPANT	\N	PRESENT	0
352948	339594	19671E	PARTICIPANT	\N	PRESENT	0
352950	339594	01060R	PARTICIPANT	\N	PRESENT	0
352952	339594	97011G	PARTICIPANT	\N	PRESENT	0
352953	339594	14026U	PARTICIPANT	\N	PRESENT	0
352954	339594	19711U	PARTICIPANT	\N	PRESENT	0
352955	339594	19657G	PARTICIPANT	\N	PRESENT	0
352956	339594	19399H	PARTICIPANT	\N	PRESENT	0
352957	339594	11049P	PARTICIPANT	\N	PRESENT	0
352958	339594	99004R	PARTICIPANT	\N	PRESENT	0
352959	339594	19415P	PARTICIPANT	\N	PRESENT	0
352960	339594	19507S	PARTICIPANT	\N	PRESENT	0
352961	339594	19794Q	PARTICIPANT	\N	PRESENT	0
352962	339594	14191V	PARTICIPANT	\N	PRESENT	0
352963	339594	19679N	PARTICIPANT	\N	PRESENT	0
352964	339594	95062K	PARTICIPANT	\N	PRESENT	0
352965	339594	15447F	PARTICIPANT	\N	PRESENT	0
352966	339594	19629C	PARTICIPANT	\N	PRESENT	0
352967	339594	14069U	PARTICIPANT	\N	PRESENT	0
352968	339594	19695N	PARTICIPANT	\N	PRESENT	0
352969	350839	14030Q	PARTICIPANT	\N	PRESENT	0
352970	339594	14213J	PARTICIPANT	\N	PRESENT	0
352971	339594	19631V	PARTICIPANT	\N	PRESENT	0
352972	339594	19667J	PARTICIPANT	\N	PRESENT	0
352973	339594	19731Y	PARTICIPANT	\N	PRESENT	0
352974	339594	14259Y	PARTICIPANT	\N	PRESENT	0
352975	339594	05008E	PARTICIPANT	\N	PRESENT	0
352976	339594	01028R	PARTICIPANT	\N	PRESENT	0
352977	339594	11072N	PARTICIPANT	\N	PRESENT	0
352978	339594	14219Q	PARTICIPANT	\N	PRESENT	0
352989	339594	19611R	PARTICIPANT	\N	PRESENT	0
353016	348097	04040A	PRESIDENT	0	PRESENT	0
353017	350813	19697Q	PARTICIPANT	\N	PRESENT	0
353018	350813	11067R	PARTICIPANT	\N	PRESENT	0
352907	339594	11070L	PARTICIPANT	\N	PRESENT	0
352908	339594	11056N	PARTICIPANT	\N	PRESENT	0
353019	350813	19565D	PARTICIPANT	\N	PRESENT	0
353020	350813	11097X	PARTICIPANT	\N	PRESENT	0
353021	350813	19415P	PARTICIPANT	\N	PRESENT	0
353022	350813	04045F	PARTICIPANT	\N	PRESENT	0
353023	350813	14026U	PARTICIPANT	\N	PRESENT	0
353024	350813	19703U	PARTICIPANT	\N	PRESENT	0
353025	350813	11031D	PARTICIPANT	\N	PRESENT	0
353026	350813	19553Y	PARTICIPANT	\N	PRESENT	0
353027	350813	14239U	PARTICIPANT	\N	PRESENT	0
353028	350813	14281W	PARTICIPANT	\N	PRESENT	0
353029	350813	19679N	PARTICIPANT	\N	PRESENT	0
353007	350813	19727D	PARTICIPANT	\N	PRESENT	0
353008	350813	04092N	PRESIDENT	0	PRESENT	0
353009	350813	11103C	PARTICIPANT	\N	PRESENT	0
353010	350813	08052W	PARTICIPANT	\N	PRESENT	0
353011	350813	14217N	PARTICIPANT	\N	PRESENT	0
353012	350813	19683J	PARTICIPANT	\N	PRESENT	0
353013	350813	14355X	PARTICIPANT	\N	EXCUSE	0
353014	350813	08041T	PARTICIPANT	\N	EXCUSE	0
353030	350813	14042U	PARTICIPANT	\N	PRESENT	0
353031	350813	14195A	PARTICIPANT	\N	PRESENT	0
353032	350813	14213J	PARTICIPANT	\N	PRESENT	0
353033	350813	10006L	PARTICIPANT	\N	PRESENT	0
353034	350813	11045K	PARTICIPANT	\N	PRESENT	0
353035	350813	19691J	PARTICIPANT	\N	PRESENT	0
353036	350813	19723Y	PARTICIPANT	\N	PRESENT	0
353037	350813	14030Q	PARTICIPANT	\N	PRESENT	0
353038	350813	14119M	PARTICIPANT	\N	PRESENT	0
353039	350813	19731Y	PARTICIPANT	\N	PRESENT	0
353040	350813	14071N	PARTICIPANT	\N	PRESENT	0
353041	346534	19693L	PARTICIPANT	\N	PRESENT	0
353043	346534	19503N	PARTICIPANT	\N	PRESENT	0
353044	346534	19663E	PARTICIPANT	\N	PRESENT	0
353046	346534	01048V	PRESIDENT	0	PRESENT	0
353047	346534	04043D	PARTICIPANT	\N	PRESENT	0
353048	346534	01058X	PARTICIPANT	\N	PRESENT	0
353049	346534	19533U	PARTICIPANT	\N	PRESENT	0
353050	346534	08053X	PARTICIPANT	\N	EXCUSE	0
353051	346534	14093U	PARTICIPANT	\N	EXCUSE	0
353052	346534	19723Y	PARTICIPANT	\N	EXCUSE	0
353055	339595	95062K	PARTICIPANT	\N	PRESENT	0
353056	339595	19507S	PARTICIPANT	\N	PRESENT	0
353057	339595	14329V	PARTICIPANT	\N	PRESENT	0
353058	339595	14105F	PARTICIPANT	\N	PRESENT	0
353059	339595	04018C	PARTICIPANT	\N	PRESENT	0
353060	339595	14059S	PARTICIPANT	\N	PRESENT	0
353061	339595	19581D	PARTICIPANT	\N	PRESENT	0
353062	339595	19741B	PARTICIPANT	\N	PRESENT	0
353063	339595	19747H	PARTICIPANT	\N	PRESENT	0
353064	339595	19733B	PARTICIPANT	\N	PRESENT	0
353065	339595	14147R	PARTICIPANT	\N	PRESENT	0
353066	339595	04008A	PARTICIPANT	\N	PRESENT	0
353067	339595	14331P	PARTICIPANT	\N	PRESENT	0
353068	350813	01034P	PARTICIPANT	\N	PRESENT	0
353069	350813	19663E	PARTICIPANT	\N	PRESENT	0
353070	339595	96004D	PARTICIPANT	\N	PRESENT	0
353071	339595	14073Q	PARTICIPANT	\N	PRESENT	0
353072	339595	04035D	PARTICIPANT	\N	PRESENT	0
353073	339595	15447F	PARTICIPANT	\N	PRESENT	0
353074	339595	08056B	PARTICIPANT	\N	PRESENT	0
353075	339595	14267Y	PARTICIPANT	\N	PRESENT	0
353076	339595	19673G	PARTICIPANT	\N	PRESENT	0
353077	339595	19479G	PARTICIPANT	\N	PRESENT	0
353078	339595	04088S	PARTICIPANT	\N	PRESENT	0
353079	339595	14357A	PARTICIPANT	\N	PRESENT	0
353080	339595	14191V	PARTICIPANT	\N	PRESENT	0
353081	339595	17589D	PARTICIPANT	\N	PRESENT	0
353082	339595	01058X	PARTICIPANT	\N	PRESENT	0
353083	339595	14107H	PARTICIPANT	\N	PRESENT	0
353084	339595	07033P	PARTICIPANT	\N	PRESENT	0
353086	339595	14201E	PARTICIPANT	\N	PRESENT	0
353087	339595	17583W	PARTICIPANT	\N	PRESENT	0
353088	339595	19399H	PARTICIPANT	\N	PRESENT	0
353089	339595	19511N	PARTICIPANT	\N	PRESENT	0
353090	339595	14169X	PARTICIPANT	\N	PRESENT	0
353091	339595	87003B	PARTICIPANT	\N	PRESENT	0
353092	339595	14219Q	PARTICIPANT	\N	PRESENT	0
353093	339595	14253S	PARTICIPANT	\N	PRESENT	0
353094	339595	16685X	PARTICIPANT	\N	PRESENT	0
353095	339595	08034U	PARTICIPANT	\N	PRESENT	0
353096	339595	07034Q	PARTICIPANT	\N	PRESENT	0
353097	339595	19737F	PARTICIPANT	\N	PRESENT	0
353098	339595	14199E	PARTICIPANT	\N	PRESENT	0
353099	339595	99004R	PARTICIPANT	\N	PRESENT	0
353100	339595	14277B	PARTICIPANT	\N	PRESENT	0
353101	339595	04047H	PARTICIPANT	\N	PRESENT	0
353102	339595	04086Q	PARTICIPANT	\N	PRESENT	0
353103	339595	19709B	PARTICIPANT	\N	PRESENT	0
353104	339595	14029X	PARTICIPANT	\N	PRESENT	0
353105	339595	17637T	PARTICIPANT	\N	PRESENT	0
353106	339595	19585H	PARTICIPANT	\N	PRESENT	0
353107	339595	19515S	PARTICIPANT	\N	PRESENT	0
353108	339595	04097T	PARTICIPANT	\N	PRESENT	0
353109	339595	19369B	PARTICIPANT	\N	PRESENT	0
353110	339595	19387D	PARTICIPANT	\N	PRESENT	0
353111	339595	19703U	PARTICIPANT	\N	PRESENT	0
353112	339595	01057W	PARTICIPANT	\N	PRESENT	0
353113	339595	14231L	PARTICIPANT	\N	PRESENT	0
333587	333404	17589D	PARTICIPANT	\N	EXCUSE	0
337082	321406	19768N	PARTICIPANT	\N	PRESENT	0
337083	321406	04088S	PARTICIPANT	\N	PRESENT	0
337084	321406	19679N	PARTICIPANT	\N	PRESENT	0
337085	321406	19443T	PARTICIPANT	\N	PRESENT	0
337086	321406	08038Y	PARTICIPANT	\N	PRESENT	0
337087	321406	08061X	PARTICIPANT	\N	PRESENT	0
337088	321406	14030Q	PARTICIPANT	\N	PRESENT	0
337089	321406	14133K	PARTICIPANT	\N	PRESENT	0
337090	321406	08015R	PARTICIPANT	\N	PRESENT	0
337091	321406	14105F	PARTICIPANT	\N	PRESENT	0
337092	321406	19713W	PARTICIPANT	\N	PRESENT	0
337093	321406	19725B	PARTICIPANT	\N	PRESENT	0
337094	321406	19367Y	PARTICIPANT	\N	PRESENT	0
337097	321406	14229S	PARTICIPANT	\N	PRESENT	0
337098	321406	14051J	PARTICIPANT	\N	PRESENT	0
337099	321406	14109K	PARTICIPANT	\N	PRESENT	0
337100	321406	08068F	PARTICIPANT	\N	PRESENT	0
337101	321406	14121F	PARTICIPANT	\N	PRESENT	0
337102	321406	19681G	PARTICIPANT	\N	PRESENT	0
337103	321406	19703U	PARTICIPANT	\N	PRESENT	0
337104	321406	15447F	PARTICIPANT	\N	PRESENT	0
337105	321406	07004J	PARTICIPANT	\N	PRESENT	0
337106	321406	19611R	PARTICIPANT	\N	PRESENT	0
337107	321406	14071N	PARTICIPANT	\N	PRESENT	0
337108	321406	14029X	PARTICIPANT	\N	PRESENT	0
337109	321406	14042U	PARTICIPANT	\N	PRESENT	0
337110	321406	97011G	PARTICIPANT	\N	PRESENT	0
337111	321406	11056N	PARTICIPANT	\N	PRESENT	0
337112	321406	08060W	PARTICIPANT	\N	PRESENT	0
337113	321406	11010L	PARTICIPANT	\N	PRESENT	0
337114	321406	19551W	PARTICIPANT	\N	PRESENT	0
337115	321406	04045F	PARTICIPANT	\N	PRESENT	0
337229	321407	19782L	PARTICIPANT	\N	PRESENT	0
337230	321407	19725B	PARTICIPANT	\N	PRESENT	0
337231	321407	14097Y	PARTICIPANT	\N	PRESENT	0
337232	321407	14109K	PARTICIPANT	\N	PRESENT	0
337233	321407	14063N	PARTICIPANT	\N	PRESENT	0
337234	321407	19413M	PARTICIPANT	\N	PRESENT	0
337235	321407	08055A	PARTICIPANT	\N	PRESENT	0
337236	321407	08060W	PARTICIPANT	\N	PRESENT	0
337237	321407	14051J	PARTICIPANT	\N	PRESENT	0
337238	321407	11056N	PARTICIPANT	\N	PRESENT	0
337239	321407	17779H	PARTICIPANT	\N	PRESENT	0
337240	321407	14121F	PARTICIPANT	\N	PRESENT	0
337241	321407	19727D	PARTICIPANT	\N	PRESENT	0
337242	321407	14107H	PARTICIPANT	\N	PRESENT	0
337243	321407	19545Y	PARTICIPANT	\N	PRESENT	0
337244	321407	17589D	PARTICIPANT	\N	PRESENT	0
337245	321407	19681G	PARTICIPANT	\N	PRESENT	0
337246	321407	14042U	PARTICIPANT	\N	PRESENT	0
337247	321407	19691J	PARTICIPANT	\N	PRESENT	0
337248	321407	19479G	PARTICIPANT	\N	PRESENT	0
337249	321407	19441R	PARTICIPANT	\N	PRESENT	0
337250	321407	19367Y	PARTICIPANT	\N	PRESENT	0
337251	321407	14179A	PARTICIPANT	\N	PRESENT	0
337252	321407	19729F	PARTICIPANT	\N	PRESENT	0
337253	321407	19768N	PARTICIPANT	\N	PRESENT	0
337254	321407	97011G	PARTICIPANT	\N	PRESENT	0
337255	321407	14115H	PARTICIPANT	\N	PRESENT	0
337256	321407	19531S	PARTICIPANT	\N	PRESENT	0
337257	321407	14265W	PARTICIPANT	\N	PRESENT	0
337258	321407	19507S	PARTICIPANT	\N	PRESENT	0
337259	321407	14135M	PARTICIPANT	\N	PRESENT	0
337260	321407	04088S	PARTICIPANT	\N	PRESENT	0
337261	321407	14021P	PARTICIPANT	\N	PRESENT	0
337262	321407	19467C	PARTICIPANT	\N	PRESENT	0
337263	321407	19443T	PARTICIPANT	\N	PRESENT	0
337264	321407	14029X	PARTICIPANT	\N	PRESENT	0
337265	321407	11010L	PARTICIPANT	\N	PRESENT	0
337266	321407	19703U	PARTICIPANT	\N	PRESENT	0
337267	321407	14237S	PARTICIPANT	\N	PRESENT	0
337268	321407	14069U	PARTICIPANT	\N	PRESENT	0
337269	321407	15447F	PARTICIPANT	\N	PRESENT	0
337270	321407	19679N	PARTICIPANT	\N	PRESENT	0
337271	321407	01058X	PARTICIPANT	\N	PRESENT	0
337272	321407	11103C	PARTICIPANT	\N	PRESENT	0
337273	321407	19731Y	PARTICIPANT	\N	PRESENT	0
337274	321407	19701S	PARTICIPANT	\N	PRESENT	0
337275	321407	19629C	PARTICIPANT	\N	PRESENT	0
337276	321407	14241N	PARTICIPANT	\N	PRESENT	0
337277	321407	08049C	PARTICIPANT	\N	PRESENT	0
337278	321407	19762G	PARTICIPANT	\N	PRESENT	0
337279	321407	14281W	PARTICIPANT	\N	PRESENT	0
337280	321407	19333N	PARTICIPANT	\N	PRESENT	0
337281	321407	19549D	PARTICIPANT	\N	PRESENT	0
337282	321407	14207L	PARTICIPANT	\N	PRESENT	0
337283	321407	14257W	PARTICIPANT	\N	PRESENT	0
337284	321407	19387D	PARTICIPANT	\N	PRESENT	0
337285	321407	19573D	PARTICIPANT	\N	PRESENT	0
337286	321407	11099A	PARTICIPANT	\N	PRESENT	0
337287	321407	14159V	PARTICIPANT	\N	PRESENT	0
337288	321407	19713W	PARTICIPANT	\N	PRESENT	0
337289	321407	19719D	PARTICIPANT	\N	PRESENT	0
337290	321407	19563B	PARTICIPANT	\N	PRESENT	0
337291	321407	08051V	PARTICIPANT	\N	PRESENT	0
337292	321407	14103D	PARTICIPANT	\N	PRESENT	0
337293	321407	19565D	PARTICIPANT	\N	PRESENT	0
337294	321407	19760E	PARTICIPANT	\N	PRESENT	0
337295	334415	19697Q	PARTICIPANT	\N	PRESENT	0
337296	334415	11067R	PARTICIPANT	\N	PRESENT	0
337297	334415	19649G	PARTICIPANT	\N	PRESENT	0
337298	334415	19533U	PARTICIPANT	\N	PRESENT	0
337299	334415	19415P	PARTICIPANT	\N	PRESENT	0
337300	334415	08043V	PARTICIPANT	\N	PRESENT	0
337301	334415	04047H	PARTICIPANT	\N	PRESENT	0
337302	334415	19673G	PARTICIPANT	\N	PRESENT	0
337303	334415	19723Y	PARTICIPANT	\N	PRESENT	0
337304	334415	19447X	PARTICIPANT	\N	PRESENT	0
337305	334415	14030Q	PARTICIPANT	\N	PRESENT	0
337306	334415	14231L	PARTICIPANT	\N	PRESENT	0
337307	334415	19553Y	PARTICIPANT	\N	PRESENT	0
337308	334415	14147R	PARTICIPANT	\N	PRESENT	0
337309	334415	14213J	PARTICIPANT	\N	PRESENT	0
337310	334415	11043H	PARTICIPANT	\N	PRESENT	0
337311	334415	19749K	PARTICIPANT	\N	PRESENT	0
337312	334415	10006L	PRESIDENT	0	PRESENT	0
337313	334415	19621T	PARTICIPANT	\N	PRESENT	0
337314	334415	08031R	PARTICIPANT	\N	PRESENT	0
337315	321407	19399H	PARTICIPANT	\N	PRESENT	0
337316	321407	10015M	PARTICIPANT	\N	PRESENT	0
337317	321407	08045X	PARTICIPANT	\N	PRESENT	0
337318	321407	08038Y	PARTICIPANT	\N	PRESENT	0
337319	321407	04085P	PARTICIPANT	\N	PRESENT	0
337320	321407	14217N	PARTICIPANT	\N	PRESENT	0
337321	321407	11097X	PARTICIPANT	\N	PRESENT	0
337322	321407	14187A	PARTICIPANT	\N	PRESENT	0
337323	321407	08039A	PARTICIPANT	\N	PRESENT	0
337324	321407	14133K	PARTICIPANT	\N	PRESENT	0
337325	321407	14157T	PARTICIPANT	\N	PRESENT	0
337326	321407	11026G	PARTICIPANT	\N	PRESENT	0
337327	321407	19671E	PARTICIPANT	\N	PRESENT	0
337328	321407	19581D	PARTICIPANT	\N	PRESENT	0
337329	321407	11110B	PARTICIPANT	\N	PRESENT	0
337330	321407	04043D	PARTICIPANT	\N	PRESENT	0
337331	321407	19533U	PARTICIPANT	\N	PRESENT	0
337332	321407	08068F	PARTICIPANT	\N	PRESENT	0
337333	321407	14061L	PARTICIPANT	\N	PRESENT	0
337334	321407	05012A	PARTICIPANT	\N	PRESENT	0
337335	321407	01057W	PARTICIPANT	\N	PRESENT	0
337336	321407	14169X	PARTICIPANT	\N	PRESENT	0
337227	321407	04044E	PARTICIPANT	\N	PRESENT	0
337228	321407	04045F	PARTICIPANT	\N	PRESENT	0
336682	321403	19573D	PARTICIPANT	\N	PRESENT	0
336683	321403	14211G	PARTICIPANT	\N	PRESENT	0
336684	321403	11056N	PARTICIPANT	\N	PRESENT	0
336685	321403	14169X	PARTICIPANT	\N	PRESENT	0
336686	321403	19383Y	PARTICIPANT	\N	PRESENT	0
336687	321403	19507S	PARTICIPANT	\N	PRESENT	0
336688	321403	08015R	PARTICIPANT	\N	PRESENT	0
336689	321403	08009T	PARTICIPANT	\N	PRESENT	0
336690	321403	19691J	PARTICIPANT	\N	PRESENT	0
336691	321403	01057W	PARTICIPANT	\N	PRESENT	0
336692	321403	19545Y	PARTICIPANT	\N	PRESENT	0
336693	321403	01028R	PARTICIPANT	\N	PRESENT	0
336694	321403	19521Q	PARTICIPANT	\N	PRESENT	0
336695	321403	14033T	PARTICIPANT	\N	PRESENT	0
336696	321403	19563B	PARTICIPANT	\N	PRESENT	0
336697	321403	04040A	PARTICIPANT	\N	PRESENT	0
336701	321403	11064N	PARTICIPANT	\N	PRESENT	0
336699	321403	14265W	PARTICIPANT	\N	PRESENT	0
336700	321403	14061L	PARTICIPANT	\N	PRESENT	0
336702	321403	14147R	PARTICIPANT	\N	PRESENT	0
336703	321403	04088S	PARTICIPANT	\N	PRESENT	0
336704	321403	14083S	PARTICIPANT	\N	PRESENT	0
336705	321403	19737F	PARTICIPANT	\N	PRESENT	0
336706	321403	14042U	PARTICIPANT	\N	PRESENT	0
336707	321403	19441R	PARTICIPANT	\N	PRESENT	0
340722	340563	05008E	PARTICIPANT	\N	EXCUSE	0
340723	340563	19762G	PARTICIPANT	\N	EXCUSE	0
340724	339493	19507S	PARTICIPANT	\N	PRESENT	0
341937	341936	14331P	PARTICIPANT	\N	PRESENT	0
341938	341936	19711U	PARTICIPANT	\N	PRESENT	0
341939	341936	04034C	PARTICIPANT	\N	PRESENT	0
341940	341936	19441R	PARTICIPANT	\N	PRESENT	0
341941	341936	19695N	PARTICIPANT	\N	PRESENT	0
341942	341936	89017R	PARTICIPANT	\N	PRESENT	0
341943	341936	19667J	PARTICIPANT	\N	PRESENT	0
341944	341936	11090Q	PARTICIPANT	\N	PRESENT	0
341945	341936	14034U	PARTICIPANT	\N	PRESENT	0
341946	341936	14159V	PARTICIPANT	\N	PRESENT	0
341947	341936	14227Q	PARTICIPANT	\N	PRESENT	0
341948	341936	19631V	PARTICIPANT	\N	PRESENT	0
341949	341936	14083S	PARTICIPANT	\N	PRESENT	0
341950	341936	14051J	PARTICIPANT	\N	PRESENT	0
341951	341936	08068F	PARTICIPANT	\N	PRESENT	0
341952	341936	04049K	PARTICIPANT	\N	PRESENT	0
341953	341936	19521Q	PRESIDENT	0	PRESENT	0
341954	341936	11110B	PARTICIPANT	\N	EXCUSE	0
341959	341220	19697Q	PARTICIPANT	\N	PRESENT	0
341960	341220	11067R	PARTICIPANT	\N	PRESENT	0
336680	321403	08031R	PARTICIPANT	\N	PRESENT	0
336681	321403	14249W	PARTICIPANT	\N	PRESENT	0
341961	341220	19415P	PARTICIPANT	\N	PRESENT	0
341962	341220	14223L	PARTICIPANT	\N	PRESENT	0
341963	341220	04045F	PARTICIPANT	\N	PRESENT	0
341964	341220	17779H	PARTICIPANT	\N	PRESENT	0
341965	341220	19703U	PARTICIPANT	\N	PRESENT	0
341966	341220	14239U	PARTICIPANT	\N	PRESENT	0
341967	341220	19553Y	PARTICIPANT	\N	PRESENT	0
341968	341220	11031D	PARTICIPANT	\N	PRESENT	0
341969	341220	19679N	PARTICIPANT	\N	PRESENT	0
341970	341220	14042U	PARTICIPANT	\N	PRESENT	0
341971	341220	19575F	PARTICIPANT	\N	PRESENT	0
341972	341220	08048B	PARTICIPANT	\N	PRESENT	0
341973	341220	19367Y	PARTICIPANT	\N	PRESENT	0
341974	341220	14213J	PARTICIPANT	\N	PRESENT	0
341975	341220	14217N	PARTICIPANT	\N	PRESENT	0
341976	341220	10006L	PARTICIPANT	\N	PRESENT	0
341977	341220	19683J	PARTICIPANT	\N	PRESENT	0
341978	341220	98024R	PARTICIPANT	\N	PRESENT	0
341979	341220	01034P	PARTICIPANT	\N	PRESENT	0
340764	339494	04059M	PARTICIPANT	\N	PRESENT	0
341910	341909	04070G	PRESIDENT	0	PRESENT	0
341911	341909	14331P	PARTICIPANT	\N	PRESENT	0
341912	341909	19699S	PARTICIPANT	\N	PRESENT	0
341913	341909	14219Q	PARTICIPANT	\N	PRESENT	0
341914	341909	14229S	PARTICIPANT	\N	PRESENT	0
341915	341909	19703U	PARTICIPANT	\N	PRESENT	0
341916	341909	14241N	PARTICIPANT	\N	PRESENT	0
341917	341909	14039A	PARTICIPANT	\N	PRESENT	0
341918	341909	08019V	PARTICIPANT	\N	PRESENT	0
341919	341909	07033P	PARTICIPANT	\N	PRESENT	0
341920	341909	19335Q	PARTICIPANT	\N	PRESENT	0
341921	341909	14261S	PARTICIPANT	\N	PRESENT	0
341922	341909	08039A	PARTICIPANT	\N	PRESENT	0
341923	341909	11072N	PARTICIPANT	\N	PRESENT	0
341924	341909	14059S	PARTICIPANT	\N	PRESENT	0
341925	341909	04057K	PARTICIPANT	\N	PRESENT	0
341926	341909	08043V	PARTICIPANT	\N	PRESENT	0
341927	341909	19691J	PARTICIPANT	\N	PRESENT	0
341928	341909	19717B	PARTICIPANT	\N	PRESENT	0
341929	341909	08073C	PARTICIPANT	\N	PRESENT	0
341930	341909	04059M	PARTICIPANT	\N	PRESENT	0
341931	341909	19735D	PARTICIPANT	\N	PRESENT	0
341932	341909	11109J	PARTICIPANT	\N	PRESENT	0
341933	341909	11083R	PARTICIPANT	\N	PRESENT	0
341934	341909	19758L	PARTICIPANT	\N	PRESENT	0
341935	341909	19583F	PARTICIPANT	\N	PRESENT	0
341980	341220	04092N	PRESIDENT	0	PRESENT	0
341981	341220	08052W	PARTICIPANT	\N	PRESENT	0
341982	341220	19715Y	PARTICIPANT	\N	PRESENT	0
341983	341220	19727D	PARTICIPANT	\N	PRESENT	0
341984	341220	19657G	PARTICIPANT	\N	PRESENT	0
341985	341220	19577H	PARTICIPANT	\N	PRESENT	0
341986	341220	14355X	PARTICIPANT	\N	EXCUSE	0
341987	341220	08041T	PARTICIPANT	\N	EXCUSE	0
341988	341220	19675J	PARTICIPANT	\N	EXCUSE	0
341989	341220	19521Q	PARTICIPANT	\N	EXCUSE	0
341990	341220	11097X	PARTICIPANT	\N	PRESENT	0
341991	341220	14071N	PARTICIPANT	\N	PRESENT	0
341992	341220	14261S	PARTICIPANT	\N	PRESENT	0
341993	341220	19527W	PARTICIPANT	\N	PRESENT	0
341996	341909	19573D	PARTICIPANT	\N	PRESENT	0
341997	341909	14073Q	PARTICIPANT	\N	PRESENT	0
341998	341909	19693L	PARTICIPANT	\N	PRESENT	0
341999	341909	19729F	PARTICIPANT	\N	PRESENT	0
342000	341909	19657G	PARTICIPANT	\N	PRESENT	0
342002	341220	19663E	PARTICIPANT	\N	PRESENT	0
342003	341220	19691J	PARTICIPANT	\N	PRESENT	0
342015	341220	19717B	PARTICIPANT	\N	PRESENT	0
342396	339499	19521Q	PARTICIPANT	\N	PRESENT	0
342397	339499	11103C	PARTICIPANT	\N	PRESENT	0
342398	339499	14217N	PARTICIPANT	\N	PRESENT	0
342399	339499	07033P	PARTICIPANT	\N	PRESENT	0
342400	339499	14205J	PARTICIPANT	\N	PRESENT	0
342401	339499	04070G	PARTICIPANT	\N	PRESENT	0
342402	339499	14331P	PARTICIPANT	\N	PRESENT	0
342403	339499	04040A	PARTICIPANT	\N	PRESENT	0
342404	339499	01043Q	PARTICIPANT	\N	PRESENT	0
342405	339499	14079W	PARTICIPANT	\N	PRESENT	0
342406	339499	08009T	PARTICIPANT	\N	PRESENT	0
342407	339499	19671E	PARTICIPANT	\N	PRESENT	0
342408	339499	14030Q	PARTICIPANT	\N	PRESENT	0
342409	339499	19581D	PARTICIPANT	\N	PRESENT	0
342410	339499	14255U	PARTICIPANT	\N	PRESENT	0
342411	339499	89017R	PARTICIPANT	\N	PRESENT	0
342412	339499	16685X	PARTICIPANT	\N	PRESENT	0
342413	339499	08019V	PARTICIPANT	\N	PRESENT	0
342414	339499	19723Y	PARTICIPANT	\N	PRESENT	0
342415	339499	14059S	PARTICIPANT	\N	PRESENT	0
342416	339499	19729F	PARTICIPANT	\N	PRESENT	0
342417	339499	19507S	PARTICIPANT	\N	PRESENT	0
342418	339499	19467C	PARTICIPANT	\N	PRESENT	0
342419	339499	18083K	PARTICIPANT	\N	PRESENT	0
342420	339499	19705W	PARTICIPANT	\N	PRESENT	0
342421	339499	11099A	PARTICIPANT	\N	PRESENT	0
342422	339499	19553Y	PARTICIPANT	\N	PRESENT	0
342423	339499	19415P	PARTICIPANT	\N	PRESENT	0
342424	339499	19399H	PARTICIPANT	\N	PRESENT	0
342425	339499	19693L	PARTICIPANT	\N	PRESENT	0
342426	339499	14357A	PARTICIPANT	\N	PRESENT	0
342427	339499	08048B	PARTICIPANT	\N	PRESENT	0
342428	339499	14265W	PARTICIPANT	\N	PRESENT	0
342429	339499	19621T	PARTICIPANT	\N	PRESENT	0
342430	339499	14329V	PARTICIPANT	\N	PRESENT	0
342431	339499	19675J	PARTICIPANT	\N	PRESENT	0
342432	339499	14061L	PARTICIPANT	\N	PRESENT	0
342433	339499	04088S	PARTICIPANT	\N	PRESENT	0
342434	339499	19762G	PARTICIPANT	\N	PRESENT	0
342435	339499	04018C	PARTICIPANT	\N	PRESENT	0
342436	339499	19367Y	PARTICIPANT	\N	PRESENT	0
342437	339499	19347U	PARTICIPANT	\N	PRESENT	0
342438	339499	19741B	PARTICIPANT	\N	PRESENT	0
342439	339499	14029X	PARTICIPANT	\N	PRESENT	0
342440	339499	19709B	PARTICIPANT	\N	PRESENT	0
342441	339499	19701S	PARTICIPANT	\N	PRESENT	0
342442	339499	19663E	PARTICIPANT	\N	PRESENT	0
342443	339499	19269X	PARTICIPANT	\N	PRESENT	0
342444	339499	01060R	PARTICIPANT	\N	PRESENT	0
342445	339499	14041T	PARTICIPANT	\N	PRESENT	0
333044	332845	14033T	PARTICIPANT	\N	PRESENT	0
333045	332845	04085P	PARTICIPANT	\N	PRESENT	0
333046	332845	15447F	PARTICIPANT	\N	PRESENT	0
333047	332845	04088S	PARTICIPANT	\N	PRESENT	0
333048	332845	19727D	PARTICIPANT	\N	PRESENT	0
333049	332845	19733B	PARTICIPANT	\N	PRESENT	0
333050	332845	19507S	PARTICIPANT	\N	PRESENT	0
333051	321366	19745F	PARTICIPANT	\N	PRESENT	0
333052	321366	19631V	PARTICIPANT	\N	PRESENT	0
333053	321366	04018C	PARTICIPANT	\N	PRESENT	0
333054	321366	19527W	PARTICIPANT	\N	PRESENT	0
333057	321366	14187A	PARTICIPANT	\N	PRESENT	0
333058	321366	14251Q	PARTICIPANT	\N	PRESENT	0
333059	321366	01057W	PARTICIPANT	\N	PRESENT	0
333060	321366	19657G	PARTICIPANT	\N	PRESENT	0
333061	321366	14211G	PARTICIPANT	\N	PRESENT	0
333062	321366	19695N	PARTICIPANT	\N	PRESENT	0
333063	321366	95030B	PARTICIPANT	\N	PRESENT	0
333064	321366	04044E	PARTICIPANT	\N	PRESENT	0
333072	321366	14033T	PARTICIPANT	\N	PRESENT	0
333073	321366	01058X	PARTICIPANT	\N	PRESENT	0
333074	321366	11053K	PARTICIPANT	\N	PRESENT	0
333075	321366	14255U	PARTICIPANT	\N	PRESENT	0
333076	321366	04038G	PARTICIPANT	\N	PRESENT	0
333077	321366	19675J	PARTICIPANT	\N	PRESENT	0
333078	321366	14147R	PARTICIPANT	\N	PRESENT	0
333079	321366	11067R	PARTICIPANT	\N	PRESENT	0
333080	321366	14021P	PARTICIPANT	\N	PRESENT	0
333081	321366	95063L	PARTICIPANT	\N	PRESENT	0
333082	321366	14199E	PARTICIPANT	\N	PRESENT	0
333083	321366	19383Y	PARTICIPANT	\N	PRESENT	0
333084	321366	14083S	PARTICIPANT	\N	PRESENT	0
333085	321366	14089Y	PARTICIPANT	\N	PRESENT	0
333086	321366	11097X	PARTICIPANT	\N	PRESENT	0
333087	321366	14071N	PARTICIPANT	\N	PRESENT	0
333088	321366	14069U	PARTICIPANT	\N	PRESENT	0
333089	321366	11101A	PARTICIPANT	\N	PRESENT	0
333090	321366	14331P	PARTICIPANT	\N	PRESENT	0
333091	321366	19289C	PARTICIPANT	\N	PRESENT	0
333092	321366	14031R	PARTICIPANT	\N	PRESENT	0
333093	321366	19581D	PARTICIPANT	\N	PRESENT	0
333094	321366	01028R	PARTICIPANT	\N	PRESENT	0
333095	321366	19673G	PARTICIPANT	\N	PRESENT	0
333096	321366	05012A	PARTICIPANT	\N	PRESENT	0
333097	321366	11049P	PARTICIPANT	\N	PRESENT	0
333098	321366	19719D	PARTICIPANT	\N	PRESENT	0
333099	321366	14231L	PARTICIPANT	\N	PRESENT	0
333100	321366	08044W	PARTICIPANT	\N	PRESENT	0
333144	321367	19545Y	PARTICIPANT	\N	PRESENT	0
333145	321367	19689Q	PARTICIPANT	\N	PRESENT	0
333146	321367	14087W	PARTICIPANT	\N	PRESENT	0
333147	321367	19719D	PARTICIPANT	\N	PRESENT	0
333148	321367	14026U	PARTICIPANT	\N	PRESENT	0
333149	321367	19383Y	PARTICIPANT	\N	PRESENT	0
333150	321367	19507S	PARTICIPANT	\N	PRESENT	0
333151	321367	14281W	PARTICIPANT	\N	PRESENT	0
333152	321367	17779H	PARTICIPANT	\N	PRESENT	0
333153	321367	19782L	PARTICIPANT	\N	PRESENT	0
333154	321367	19715Y	PARTICIPANT	\N	PRESENT	0
333155	321367	04045F	PARTICIPANT	\N	PRESENT	0
333156	321367	19565D	PARTICIPANT	\N	PRESENT	0
333157	321367	19758L	PARTICIPANT	\N	PRESENT	0
333158	321367	19760E	PARTICIPANT	\N	PRESENT	0
333159	321367	14257W	PARTICIPANT	\N	PRESENT	0
333160	321367	19651A	PARTICIPANT	\N	PRESENT	0
333161	321367	11067R	PARTICIPANT	\N	PRESENT	0
333162	321367	14021P	PARTICIPANT	\N	PRESENT	0
333163	321367	19697Q	PARTICIPANT	\N	PRESENT	0
333164	321367	14151M	PARTICIPANT	\N	PRESENT	0
333165	321367	19727D	PARTICIPANT	\N	PRESENT	0
333166	321367	14042U	PARTICIPANT	\N	PRESENT	0
333167	321367	19569H	PARTICIPANT	\N	PRESENT	0
333168	321367	19737F	PARTICIPANT	\N	PRESENT	0
333169	321367	14083S	PARTICIPANT	\N	PRESENT	0
333170	321367	14030Q	PARTICIPANT	\N	PRESENT	0
333171	321367	19749K	PARTICIPANT	\N	PRESENT	0
333172	321367	14231L	PARTICIPANT	\N	PRESENT	0
333173	321367	19573D	PARTICIPANT	\N	PRESENT	0
333174	321367	07029T	PARTICIPANT	\N	PRESENT	0
333175	321367	19415P	PARTICIPANT	\N	PRESENT	0
333176	321367	14033T	PARTICIPANT	\N	PRESENT	0
333177	321367	18083K	PARTICIPANT	\N	PRESENT	0
333178	321367	19447X	PARTICIPANT	\N	PRESENT	0
333179	321367	14105F	PARTICIPANT	\N	PRESENT	0
333180	321367	14265W	PARTICIPANT	\N	PRESENT	0
333181	321367	95030B	PARTICIPANT	\N	PRESENT	0
333182	321367	08020N	PARTICIPANT	\N	PRESENT	0
333183	321367	02002K	PARTICIPANT	\N	PRESENT	0
333184	321367	14215L	PARTICIPANT	\N	PRESENT	0
333142	321367	04086Q	PARTICIPANT	\N	PRESENT	0
333143	321367	14097Y	PARTICIPANT	\N	PRESENT	0
333185	321367	14071N	PARTICIPANT	\N	PRESENT	0
333186	321367	17637T	PARTICIPANT	\N	PRESENT	0
333187	321367	08010L	PARTICIPANT	\N	PRESENT	0
333188	321367	19762G	PARTICIPANT	\N	PRESENT	0
333189	321367	19527W	PARTICIPANT	\N	PRESENT	0
333190	321367	14069U	PARTICIPANT	\N	PRESENT	0
333191	321367	19575F	PARTICIPANT	\N	PRESENT	0
333192	321367	19703U	PARTICIPANT	\N	PRESENT	0
333193	321367	14147R	PARTICIPANT	\N	PRESENT	0
333194	321367	19723Y	PARTICIPANT	\N	PRESENT	0
333195	321367	19679N	PARTICIPANT	\N	PRESENT	0
333196	321367	19479G	PARTICIPANT	\N	PRESENT	0
333197	321367	19349W	PARTICIPANT	\N	PRESENT	0
333198	321367	14213J	PARTICIPANT	\N	PRESENT	0
333199	321367	08051V	PARTICIPANT	\N	PRESENT	0
333200	321367	19531S	PARTICIPANT	\N	PRESENT	0
333201	321367	19733B	PARTICIPANT	\N	PRESENT	0
333202	321367	14034U	PARTICIPANT	\N	PRESENT	0
334360	332771	04071H	PARTICIPANT	\N	PRESENT	0
334361	332771	08011M	PARTICIPANT	\N	EXCUSE	0
334362	321375	19667J	PARTICIPANT	\N	PRESENT	0
334363	321375	11040E	PARTICIPANT	\N	PRESENT	0
334364	321375	14071N	PARTICIPANT	\N	PRESENT	0
334365	321375	11066Q	PARTICIPANT	\N	PRESENT	0
334366	321375	19683J	PARTICIPANT	\N	PRESENT	0
334367	321375	19727D	PARTICIPANT	\N	PRESENT	0
334368	321375	14227Q	PARTICIPANT	\N	PRESENT	0
334369	321375	19671E	PARTICIPANT	\N	PRESENT	0
334370	321375	04045F	PARTICIPANT	\N	PRESENT	0
334371	321375	14195A	PARTICIPANT	\N	PRESENT	0
334372	321375	07004J	PARTICIPANT	\N	PRESENT	0
334373	321375	07029T	PARTICIPANT	\N	PRESENT	0
334374	321375	14119M	PARTICIPANT	\N	PRESENT	0
334375	321375	04088S	PARTICIPANT	\N	PRESENT	0
334376	321375	14173T	PARTICIPANT	\N	PRESENT	0
334377	321375	11045K	PARTICIPANT	\N	PRESENT	0
334378	321375	19711U	PARTICIPANT	\N	PRESENT	0
334379	321375	19479G	PARTICIPANT	\N	PRESENT	0
334380	321375	04092N	PARTICIPANT	\N	PRESENT	0
334382	321375	14331P	PARTICIPANT	\N	PRESENT	0
334383	321375	11097X	PARTICIPANT	\N	PRESENT	0
334384	321375	14034U	PARTICIPANT	\N	PRESENT	0
334385	321375	14281W	PARTICIPANT	\N	PRESENT	0
334386	321375	14213J	PARTICIPANT	\N	PRESENT	0
334387	321375	01057W	PARTICIPANT	\N	PRESENT	0
334388	321375	19703U	PARTICIPANT	\N	PRESENT	0
334389	321375	11031D	PARTICIPANT	\N	PRESENT	0
334390	321375	17779H	PARTICIPANT	\N	PRESENT	0
334391	321375	14042U	PARTICIPANT	\N	PRESENT	0
334392	321375	14085U	PARTICIPANT	\N	PRESENT	0
334393	321375	14121F	PARTICIPANT	\N	PRESENT	0
334394	321375	19369B	PARTICIPANT	\N	PRESENT	0
334395	321375	19729F	PARTICIPANT	\N	PRESENT	0
334396	321375	19415P	PARTICIPANT	\N	PRESENT	0
334397	321375	15447F	PARTICIPANT	\N	PRESENT	0
334398	321375	19629C	PARTICIPANT	\N	PRESENT	0
334399	321375	19387D	PARTICIPANT	\N	PRESENT	0
334400	321375	11109J	PARTICIPANT	\N	PRESENT	0
334401	321375	14151M	PARTICIPANT	\N	PRESENT	0
334402	321375	14225N	PARTICIPANT	\N	PRESENT	0
334403	321375	19689Q	PARTICIPANT	\N	PRESENT	0
334404	321375	11043H	PARTICIPANT	\N	PRESENT	0
334405	321375	08047A	PARTICIPANT	\N	PRESENT	0
334408	321375	19782L	PARTICIPANT	\N	PRESENT	0
334409	321375	14105F	PARTICIPANT	\N	PRESENT	0
334411	321375	11026G	PARTICIPANT	\N	PRESENT	0
334413	321375	14237S	PARTICIPANT	\N	PRESENT	0
334414	321375	19525U	PARTICIPANT	\N	PRESENT	0
334416	321375	14033T	PARTICIPANT	\N	PRESENT	0
334417	321375	18083K	PARTICIPANT	\N	PRESENT	0
334418	321375	19583F	PARTICIPANT	\N	PRESENT	0
334419	321375	14061L	PARTICIPANT	\N	PRESENT	0
334420	321375	97011G	PARTICIPANT	\N	PRESENT	0
334421	321375	14157T	PARTICIPANT	\N	PRESENT	0
334422	321375	19467C	PARTICIPANT	\N	PRESENT	0
334423	321375	04059M	PARTICIPANT	\N	PRESENT	0
334424	321375	19697Q	PARTICIPANT	\N	PRESENT	0
334425	321375	19760E	PARTICIPANT	\N	PRESENT	0
353114	339595	05012A	PARTICIPANT	\N	PRESENT	0
353115	339595	08015R	PARTICIPANT	\N	PRESENT	0
353116	339595	04057K	PARTICIPANT	\N	PRESENT	0
353117	339595	11103C	PARTICIPANT	\N	PRESENT	0
353118	339595	14255U	PARTICIPANT	\N	PRESENT	0
353119	339595	14119M	PARTICIPANT	\N	PRESENT	0
353120	339595	19441R	PARTICIPANT	\N	PRESENT	0
353121	339595	14031R	PARTICIPANT	\N	PRESENT	0
353122	339595	08031R	PARTICIPANT	\N	PRESENT	0
353123	339595	14039A	PARTICIPANT	\N	PRESENT	0
353124	339595	14061L	PARTICIPANT	\N	PRESENT	0
353125	339595	19782L	PARTICIPANT	\N	PRESENT	0
353126	339595	14069U	PARTICIPANT	\N	PRESENT	0
353127	339595	04045F	PARTICIPANT	\N	PRESENT	0
353128	339595	19289C	PARTICIPANT	\N	PRESENT	0
353129	339595	19415P	PARTICIPANT	\N	PRESENT	0
353130	339595	14259Y	PARTICIPANT	\N	PRESENT	0
353131	339595	19697Q	PARTICIPANT	\N	PRESENT	0
353132	339595	14241N	PARTICIPANT	\N	PRESENT	0
353133	339595	14030Q	PARTICIPANT	\N	PRESENT	0
353134	339595	89017R	PARTICIPANT	\N	PRESENT	0
353135	339595	14055N	PARTICIPANT	\N	PRESENT	0
353136	339595	19731Y	PARTICIPANT	\N	PRESENT	0
353137	339595	19691J	PARTICIPANT	\N	PRESENT	0
353138	339595	14157T	PARTICIPANT	\N	PRESENT	0
353139	339595	14042U	PARTICIPANT	\N	PRESENT	0
353140	339595	14071N	PARTICIPANT	\N	PRESENT	0
353141	339595	19766L	PARTICIPANT	\N	PRESENT	0
353142	339595	14275Y	PARTICIPANT	\N	PRESENT	0
353143	339595	19739H	PARTICIPANT	\N	PRESENT	0
353144	339595	14038Y	PARTICIPANT	\N	PRESENT	0
353145	339595	19745F	PARTICIPANT	\N	PRESENT	0
353146	339595	19693L	PARTICIPANT	\N	PRESENT	0
353147	339595	19749K	PARTICIPANT	\N	PRESENT	0
353148	339595	11090Q	PARTICIPANT	\N	PRESENT	0
353149	339595	14187A	PARTICIPANT	\N	PRESENT	0
353150	339595	04049K	PARTICIPANT	\N	PRESENT	0
353151	339595	19667J	PARTICIPANT	\N	PRESENT	0
353152	339595	14193X	PARTICIPANT	\N	PRESENT	0
353153	339595	11056N	PARTICIPANT	\N	PRESENT	0
353154	339595	19711U	PARTICIPANT	\N	PRESENT	0
353155	339595	08011M	PARTICIPANT	\N	PRESENT	0
353156	339595	12041X	PARTICIPANT	\N	PRESENT	0
353157	339595	11033F	PARTICIPANT	\N	PRESENT	0
353158	339595	19679N	PARTICIPANT	\N	PRESENT	0
353159	339595	14123H	PARTICIPANT	\N	PRESENT	0
353160	339595	11040E	PARTICIPANT	\N	PRESENT	0
353161	339595	04085P	PARTICIPANT	\N	PRESENT	0
353162	339595	08069G	PARTICIPANT	\N	PRESENT	0
353163	339595	19687N	PARTICIPANT	\N	PRESENT	0
353164	339595	04042C	PARTICIPANT	\N	PRESENT	0
353165	339595	19593H	PARTICIPANT	\N	PRESENT	0
353166	339595	11043H	PARTICIPANT	\N	PRESENT	0
353167	339595	19695N	PARTICIPANT	\N	PRESENT	0
353168	339595	19760E	PARTICIPANT	\N	PRESENT	0
353169	339595	19758L	PARTICIPANT	\N	PRESENT	0
353170	339595	11048N	PARTICIPANT	\N	PRESENT	0
353171	339595	19447X	PARTICIPANT	\N	PRESENT	0
353172	339595	19794Q	PARTICIPANT	\N	PRESENT	0
353173	339595	19489J	PARTICIPANT	\N	PRESENT	0
353174	339595	19643A	PARTICIPANT	\N	PRESENT	0
353175	339595	17779H	PARTICIPANT	\N	PRESENT	0
353176	339595	04071H	PARTICIPANT	\N	PRESENT	0
353177	339595	19251M	PARTICIPANT	\N	PRESENT	0
353178	339595	19723Y	PARTICIPANT	\N	PRESENT	0
353179	339595	11054L	PARTICIPANT	\N	PRESENT	0
353180	339595	19503N	PARTICIPANT	\N	PRESENT	0
353181	339595	11067R	PARTICIPANT	\N	PRESENT	0
353182	339595	19467C	PARTICIPANT	\N	PRESENT	0
353183	339595	19413M	PARTICIPANT	\N	PRESENT	0
353184	339595	18083K	PARTICIPANT	\N	PRESENT	0
353185	339595	14135M	PARTICIPANT	\N	PRESENT	0
353186	339595	19527W	PARTICIPANT	\N	PRESENT	0
353187	339595	14063N	PARTICIPANT	\N	PRESENT	0
353188	339595	08019V	PARTICIPANT	\N	PRESENT	0
353189	339595	14227Q	PARTICIPANT	\N	PRESENT	0
353190	339595	14265W	PARTICIPANT	\N	PRESENT	0
353191	339595	14257W	PARTICIPANT	\N	PRESENT	0
353192	339595	14213J	PARTICIPANT	\N	PRESENT	0
353193	339595	14207L	PARTICIPANT	\N	PRESENT	0
353194	339595	19631V	PARTICIPANT	\N	PRESENT	0
353195	339595	14109K	PARTICIPANT	\N	PRESENT	0
353196	339595	11049P	PARTICIPANT	\N	PRESENT	0
353197	339595	11041F	PARTICIPANT	\N	PRESENT	0
353198	339595	19725B	PARTICIPANT	\N	PRESENT	0
353199	339595	14041T	PARTICIPANT	\N	PRESENT	0
353200	339595	19549D	PARTICIPANT	\N	PRESENT	0
353201	339595	07029T	PARTICIPANT	\N	PRESENT	0
353202	339595	95067Q	PARTICIPANT	\N	PRESENT	0
353203	339595	19347U	PARTICIPANT	\N	PRESENT	0
353204	339595	19657G	PARTICIPANT	\N	PRESENT	0
353205	339595	19683J	PARTICIPANT	\N	PRESENT	0
353206	339595	14121F	PARTICIPANT	\N	PRESENT	0
353207	339595	14085U	PARTICIPANT	\N	PRESENT	0
353208	339595	08035V	PARTICIPANT	\N	PRESENT	0
353209	339595	11101A	PARTICIPANT	\N	PRESENT	0
353210	339595	08012N	PARTICIPANT	\N	PRESENT	0
353211	339595	19727D	PARTICIPANT	\N	PRESENT	0
353212	339595	14026U	PARTICIPANT	\N	PRESENT	0
353213	339595	11045K	PARTICIPANT	\N	PRESENT	0
353214	339595	04092N	PARTICIPANT	\N	PRESENT	0
353215	339595	19649G	PARTICIPANT	\N	PRESENT	0
353216	339595	04044E	PARTICIPANT	\N	PRESENT	0
353217	339595	04033B	PARTICIPANT	\N	PRESENT	0
353218	339595	19647E	PARTICIPANT	\N	PRESENT	0
353219	339595	19333N	PARTICIPANT	\N	PRESENT	0
353220	339595	08058D	PARTICIPANT	\N	PRESENT	0
353221	339595	05008E	PARTICIPANT	\N	PRESENT	0
353222	339595	19525U	PARTICIPANT	\N	PRESENT	0
353223	339595	19421M	PARTICIPANT	\N	PRESENT	0
353224	339595	11097X	PARTICIPANT	\N	PRESENT	0
353225	339595	11110B	PARTICIPANT	\N	PRESENT	0
353226	339595	14081Q	PARTICIPANT	\N	PRESENT	0
353227	339595	04043D	PARTICIPANT	\N	PRESENT	0
353228	339595	19533U	PARTICIPANT	\N	PRESENT	0
353229	339595	14281W	PARTICIPANT	\N	PRESENT	0
353230	339595	08043V	PARTICIPANT	\N	PRESENT	0
353231	339595	10006L	PARTICIPANT	\N	PRESENT	0
353232	339595	01062T	PARTICIPANT	\N	PRESENT	0
353233	339595	08038Y	PARTICIPANT	\N	PRESENT	0
353234	339595	97011G	PARTICIPANT	\N	PRESENT	0
353235	339595	80013X	PARTICIPANT	\N	PRESENT	0
353236	339595	14021P	PARTICIPANT	\N	PRESENT	0
353237	339595	14217N	PARTICIPANT	\N	PRESENT	0
353238	339595	08045X	PARTICIPANT	\N	PRESENT	0
353239	339595	04061F	PARTICIPANT	\N	PRESENT	0
353240	339595	19565D	PARTICIPANT	\N	PRESENT	0
353241	339595	11031D	PARTICIPANT	\N	PRESENT	0
353242	339595	14079W	PARTICIPANT	\N	PRESENT	0
353243	339595	19671E	PARTICIPANT	\N	PRESENT	0
353244	339595	11080N	PARTICIPANT	\N	PRESENT	0
353253	339595	08068F	PARTICIPANT	\N	PRESENT	0
353246	339595	19768N	PARTICIPANT	\N	PRESENT	0
353247	339595	19705W	PARTICIPANT	\N	PRESENT	0
353249	339595	19669L	PARTICIPANT	\N	PRESENT	0
353250	339595	19715Y	PARTICIPANT	\N	PRESENT	0
353251	339595	19575F	PARTICIPANT	\N	PRESENT	0
353252	339595	19599P	PARTICIPANT	\N	PRESENT	0
353254	339595	14051J	PARTICIPANT	\N	PRESENT	0
353255	339595	01028R	PARTICIPANT	\N	PRESENT	0
353256	339595	08055A	PARTICIPANT	\N	PRESENT	0
353257	339595	14229S	PARTICIPANT	\N	PRESENT	0
353258	339595	08052W	PARTICIPANT	\N	PRESENT	0
353259	339595	98035U	PARTICIPANT	\N	PRESENT	0
353260	339595	14159V	PARTICIPANT	\N	PRESENT	0
353261	339595	11027H	PARTICIPANT	\N	PRESENT	0
353262	339595	19762G	PARTICIPANT	\N	PRESENT	0
353263	339595	11074Q	PARTICIPANT	\N	PRESENT	0
353264	339595	95037J	PARTICIPANT	\N	PRESENT	0
353265	339595	08061X	PARTICIPANT	\N	PRESENT	0
353266	339595	04034C	PARTICIPANT	\N	PRESENT	0
353267	339595	19651A	PARTICIPANT	\N	PRESENT	0
353268	339595	14239U	PARTICIPANT	\N	PRESENT	0
353269	339595	11083R	PARTICIPANT	\N	PRESENT	0
353270	339595	19349W	PARTICIPANT	\N	PRESENT	0
353271	339595	19637C	PARTICIPANT	\N	PRESENT	0
353272	339595	19269X	PARTICIPANT	\N	PRESENT	0
353273	339595	19543W	PARTICIPANT	\N	PRESENT	0
353274	339595	86034E	PARTICIPANT	\N	PRESENT	0
353275	339595	08021P	PARTICIPANT	\N	PRESENT	0
353276	339595	08073C	PARTICIPANT	\N	PRESENT	0
353277	339595	14249W	PARTICIPANT	\N	PRESENT	0
353278	339595	14093U	PARTICIPANT	\N	PRESENT	0
353279	339595	19545Y	PARTICIPANT	\N	PRESENT	0
353280	339595	14111D	PARTICIPANT	\N	PRESENT	0
353281	339595	98005N	PARTICIPANT	\N	PRESENT	0
353282	339595	08018U	PARTICIPANT	\N	PRESENT	0
353283	339595	14251Q	PARTICIPANT	\N	PRESENT	0
336709	336708	19717B	PARTICIPANT	\N	PRESENT	0
336710	336708	08043V	PARTICIPANT	\N	PRESENT	0
336711	336708	19565D	PARTICIPANT	\N	PRESENT	0
336712	336708	11067R	PARTICIPANT	\N	PRESENT	0
336713	336708	04070G	PARTICIPANT	\N	PRESENT	0
336714	336708	05012A	PARTICIPANT	\N	PRESENT	0
336715	336708	19766L	PARTICIPANT	\N	PRESENT	0
336716	336708	19693L	PARTICIPANT	\N	PRESENT	0
336829	336828	14073Q	PARTICIPANT	\N	PRESENT	0
336830	336828	11043H	PARTICIPANT	\N	PRESENT	0
336831	336828	14069U	PARTICIPANT	\N	PRESENT	0
336832	336828	14255U	PARTICIPANT	\N	PRESENT	0
336833	336828	11026G	PARTICIPANT	\N	PRESENT	0
336977	336976	14195A	PARTICIPANT	\N	PRESENT	0
336978	336976	04057K	PARTICIPANT	\N	PRESENT	0
336979	336976	04088S	PARTICIPANT	\N	PRESENT	0
337031	334410	11067R	PARTICIPANT	\N	PRESENT	0
337033	334410	14281W	PARTICIPANT	\N	PRESENT	0
337035	334410	19760E	PARTICIPANT	\N	PRESENT	0
337036	334410	08052W	PARTICIPANT	\N	PRESENT	0
337037	334410	14026U	PARTICIPANT	\N	EXCUSE	0
337038	334410	19553Y	PARTICIPANT	\N	PRESENT	0
337040	334410	10006L	PARTICIPANT	\N	EXCUSE	0
337041	334410	11097X	PARTICIPANT	\N	EXCUSE	0
337042	334410	01034P	PARTICIPANT	\N	EXCUSE	0
337043	334410	19415P	PARTICIPANT	\N	PRESENT	0
337053	334410	04092N	PARTICIPANT	\N	EXCUSE	0
337419	321408	04044E	PARTICIPANT	\N	PRESENT	0
337420	321408	02002K	PARTICIPANT	\N	PRESENT	0
337421	321408	08060W	PARTICIPANT	\N	PRESENT	0
337422	321408	19719D	PARTICIPANT	\N	PRESENT	0
337423	321408	19637C	PARTICIPANT	\N	PRESENT	0
337424	321408	11053K	PARTICIPANT	\N	PRESENT	0
337425	321408	17589D	PARTICIPANT	\N	PRESENT	0
337426	321408	19335Q	PARTICIPANT	\N	PRESENT	0
337427	321408	11064N	PARTICIPANT	\N	PRESENT	0
337428	321408	19581D	PARTICIPANT	\N	PRESENT	0
337429	321408	19671E	PARTICIPANT	\N	PRESENT	0
337430	321408	14237S	PARTICIPANT	\N	PRESENT	0
337431	321408	04057K	PARTICIPANT	\N	PRESENT	0
337432	321408	14251Q	PARTICIPANT	\N	PRESENT	0
337433	321408	19733B	PARTICIPANT	\N	PRESENT	0
337434	321408	14029X	PARTICIPANT	\N	PRESENT	0
337435	321408	19611R	PARTICIPANT	\N	PRESENT	0
337436	321408	19679N	PARTICIPANT	\N	PRESENT	0
337437	321408	11043H	PARTICIPANT	\N	PRESENT	0
337438	321408	08069G	PARTICIPANT	\N	PRESENT	0
337439	321408	04043D	PARTICIPANT	\N	PRESENT	0
337440	321408	19533U	PARTICIPANT	\N	PRESENT	0
337441	321408	04085P	PARTICIPANT	\N	PRESENT	0
337442	321408	08009T	PARTICIPANT	\N	PRESENT	0
337443	321408	19681G	PARTICIPANT	\N	PRESENT	0
337444	321408	14038Y	PARTICIPANT	\N	PRESENT	0
337445	321408	19703U	PARTICIPANT	\N	PRESENT	0
337446	321408	14195A	PARTICIPANT	\N	PRESENT	0
337448	321408	11067R	PARTICIPANT	\N	PRESENT	0
337449	321408	14030Q	PARTICIPANT	\N	PRESENT	0
337450	321408	97011G	PARTICIPANT	\N	PRESENT	0
337451	321408	04097T	PARTICIPANT	\N	PRESENT	0
337477	321408	14147R	PARTICIPANT	\N	PRESENT	0
337478	321408	14053L	PARTICIPANT	\N	PRESENT	0
337479	321408	14097Y	PARTICIPANT	\N	PRESENT	0
337480	321408	14281W	PARTICIPANT	\N	PRESENT	0
337481	321408	08031R	PARTICIPANT	\N	PRESENT	0
337482	321408	08055A	PARTICIPANT	\N	PRESENT	0
337483	321408	19760E	PARTICIPANT	\N	PRESENT	0
337484	321408	19565D	PARTICIPANT	\N	PRESENT	0
337485	321408	19553Y	PARTICIPANT	\N	PRESENT	0
337486	321408	19369B	PARTICIPANT	\N	PRESENT	0
337487	321408	08044W	PARTICIPANT	\N	PRESENT	0
337488	321408	19507S	PARTICIPANT	\N	PRESENT	0
337489	321408	04088S	PARTICIPANT	\N	PRESENT	0
337490	321408	08049C	PARTICIPANT	\N	PRESENT	0
337491	321408	01058X	PARTICIPANT	\N	PRESENT	0
337492	321408	19563B	PARTICIPANT	\N	PRESENT	0
337494	321408	19415P	PARTICIPANT	\N	PRESENT	0
337495	321408	19782L	PARTICIPANT	\N	PRESENT	0
337496	321408	14231L	PARTICIPANT	\N	PRESENT	0
337497	321408	88008L	PARTICIPANT	\N	PRESENT	0
337499	321408	19711U	PARTICIPANT	\N	PRESENT	0
337500	321408	19447X	PARTICIPANT	\N	PRESENT	0
337501	321408	15447F	PARTICIPANT	\N	PRESENT	0
337502	321408	99004R	PARTICIPANT	\N	PRESENT	0
337503	321408	11097X	PARTICIPANT	\N	PRESENT	0
337504	321408	14031R	PARTICIPANT	\N	PRESENT	0
337505	321408	14059S	PARTICIPANT	\N	PRESENT	0
337506	321408	19629C	PARTICIPANT	\N	PRESENT	0
337507	321408	11056N	PARTICIPANT	\N	PRESENT	0
337508	321408	19729F	PARTICIPANT	\N	PRESENT	0
337509	321408	19621T	PARTICIPANT	\N	PRESENT	0
337510	321408	08039A	PARTICIPANT	\N	PRESENT	0
337511	321408	11049P	PARTICIPANT	\N	PRESENT	0
337512	321408	14215L	PARTICIPANT	\N	PRESENT	0
337513	321408	14079W	PARTICIPANT	\N	PRESENT	0
337582	328643	11067R	PARTICIPANT	\N	PRESENT	0
337583	328643	19727D	PARTICIPANT	\N	PRESENT	0
337584	328643	14251Q	PARTICIPANT	\N	PRESENT	0
337585	328643	14103D	PARTICIPANT	\N	PRESENT	0
337586	328643	14267Y	PARTICIPANT	\N	PRESENT	0
337587	328643	19369B	PARTICIPANT	\N	PRESENT	0
337588	328643	19399H	PARTICIPANT	\N	PRESENT	0
337589	328643	19515S	PARTICIPANT	\N	PRESENT	0
337590	328643	19679N	PARTICIPANT	\N	PRESENT	0
337591	328643	19760E	PARTICIPANT	\N	PRESENT	0
337592	328643	19631V	PARTICIPANT	\N	PRESENT	0
337593	328643	19565D	PARTICIPANT	\N	PRESENT	0
337594	328643	17589D	PARTICIPANT	\N	PRESENT	0
337595	328643	14195A	PARTICIPANT	\N	PRESENT	0
337596	328643	11090Q	PARTICIPANT	\N	PRESENT	0
337597	328643	04045F	PARTICIPANT	\N	PRESENT	0
337598	328643	19747H	PARTICIPANT	\N	PRESENT	0
337599	328643	11064N	PARTICIPANT	\N	PRESENT	0
337600	328643	14083S	PARTICIPANT	\N	PRESENT	0
337601	328643	14265W	PARTICIPANT	\N	PRESENT	0
337602	328643	14147R	PARTICIPANT	\N	PRESENT	0
337603	328643	14187A	PARTICIPANT	\N	PRESENT	0
337604	328643	14069U	PARTICIPANT	\N	PRESENT	0
337605	328643	19545Y	PARTICIPANT	\N	PRESENT	0
337606	328643	14179A	PARTICIPANT	\N	PRESENT	0
337607	328643	14213J	PARTICIPANT	\N	PRESENT	0
337755	337754	19575F	PARTICIPANT	\N	PRESENT	0
337756	337754	89017R	PARTICIPANT	\N	EXCUSE	0
337757	337754	14030Q	PARTICIPANT	\N	EXCUSE	0
337758	337754	14105F	PARTICIPANT	\N	PRESENT	0
337764	337754	08068F	PARTICIPANT	\N	EXCUSE	0
337766	337754	14053L	PARTICIPANT	\N	EXCUSE	0
337772	337754	14083S	PARTICIPANT	\N	EXCUSE	0
337775	337754	14329V	PARTICIPANT	\N	PRESENT	0
337776	337754	14079W	PARTICIPANT	\N	EXCUSE	0
337778	337754	14041T	PARTICIPANT	\N	EXCUSE	0
337779	337754	14151M	PARTICIPANT	\N	EXCUSE	0
337780	337754	14187A	PARTICIPANT	\N	PRESENT	0
337785	337754	19521Q	PARTICIPANT	\N	EXCUSE	0
337789	337754	14034U	PARTICIPANT	\N	EXCUSE	0
337790	337754	19695N	PARTICIPANT	\N	EXCUSE	0
337835	337754	11103C	PARTICIPANT	\N	PRESENT	0
337792	337754	19591F	PARTICIPANT	\N	EXCUSE	0
337793	337754	14121F	PARTICIPANT	\N	EXCUSE	0
337794	337754	14061L	PARTICIPANT	\N	EXCUSE	0
337795	337754	04049K	PRESIDENT	0	PRESENT	0
337796	337754	08015R	PARTICIPANT	\N	PRESENT	0
337797	337754	14205J	PARTICIPANT	\N	PRESENT	0
337798	337754	19671E	PARTICIPANT	\N	PRESENT	0
337799	337754	14265W	PARTICIPANT	\N	EXCUSE	0
337800	337754	14253S	PARTICIPANT	\N	PRESENT	0
337801	337754	04088S	PARTICIPANT	\N	PRESENT	0
337806	337754	14051J	PARTICIPANT	\N	PRESENT	0
337818	337754	14227Q	PARTICIPANT	\N	PRESENT	0
337819	337754	14157T	PARTICIPANT	\N	PRESENT	0
337836	337754	14195A	PARTICIPANT	\N	PRESENT	0
337837	337754	19415P	PARTICIPANT	\N	PRESENT	0
337838	337754	11067R	PARTICIPANT	\N	PRESENT	0
337839	337754	19703U	PARTICIPANT	\N	PRESENT	0
337840	337754	14071N	PARTICIPANT	\N	PRESENT	0
337841	337754	14213J	PARTICIPANT	\N	PRESENT	0
337842	337754	04092N	PARTICIPANT	\N	PRESENT	0
337843	337754	19679N	PARTICIPANT	\N	PRESENT	0
337844	337754	11097X	PARTICIPANT	\N	PRESENT	0
337845	337754	14281W	PARTICIPANT	\N	PRESENT	0
337846	337754	19727D	PARTICIPANT	\N	PRESENT	0
337580	328643	04086Q	PARTICIPANT	\N	PRESENT	0
337581	328643	14281W	PARTICIPANT	\N	PRESENT	0
340432	340431	08017T	PARTICIPANT	\N	PRESENT	0
340443	340442	14255U	PARTICIPANT	\N	PRESENT	0
340444	340442	88008L	PARTICIPANT	\N	PRESENT	0
340445	340442	10006L	PARTICIPANT	\N	PRESENT	0
340446	340442	14097Y	PARTICIPANT	\N	PRESENT	0
340447	340442	16685X	PARTICIPANT	\N	PRESENT	0
340448	340442	19745F	PARTICIPANT	\N	PRESENT	0
342449	339499	08062Y	PARTICIPANT	\N	PRESENT	0
342450	339499	08015R	PARTICIPANT	\N	PRESENT	0
342451	339499	98050T	PARTICIPANT	\N	PRESENT	0
342452	339499	04035D	PARTICIPANT	\N	PRESENT	0
342453	339499	19551W	PARTICIPANT	\N	PRESENT	0
342454	339499	19768N	PARTICIPANT	\N	PRESENT	0
342455	339499	19733B	PARTICIPANT	\N	PRESENT	0
342456	339499	86034E	PARTICIPANT	\N	PRESENT	0
342457	339499	11026G	PARTICIPANT	\N	PRESENT	0
342458	339499	04038G	PARTICIPANT	\N	PRESENT	0
342758	339500	86034E	PARTICIPANT	\N	PRESENT	0
342460	339499	14038Y	PARTICIPANT	\N	PRESENT	0
342461	339499	04061F	PARTICIPANT	\N	PRESENT	0
342462	339499	19383Y	PARTICIPANT	\N	PRESENT	0
342463	339499	11043H	PARTICIPANT	\N	PRESENT	0
342465	339499	11085T	PARTICIPANT	\N	PRESENT	0
342467	339499	08034U	PARTICIPANT	\N	PRESENT	0
342468	339499	19531S	PARTICIPANT	\N	PRESENT	0
342469	339499	19301E	PARTICIPANT	\N	PRESENT	0
342470	339499	95067Q	PARTICIPANT	\N	PRESENT	0
342471	339499	04071H	PARTICIPANT	\N	PRESENT	0
342496	339499	08010L	PARTICIPANT	\N	PRESENT	0
342447	339499	08018U	PARTICIPANT	\N	PRESENT	0
342448	339499	19657G	PARTICIPANT	\N	PRESENT	0
342497	339499	08011M	PARTICIPANT	\N	PRESENT	0
342759	339500	19507S	PARTICIPANT	\N	PRESENT	0
342760	339500	19709B	PARTICIPANT	\N	PRESENT	0
342761	339500	01060R	PARTICIPANT	\N	PRESENT	0
342762	339500	11027H	PARTICIPANT	\N	PRESENT	0
342763	339500	98022P	PARTICIPANT	\N	PRESENT	0
342764	339500	04057K	PARTICIPANT	\N	PRESENT	0
342765	339500	19583F	PARTICIPANT	\N	PRESENT	0
342766	339500	19479G	PARTICIPANT	\N	PRESENT	0
342767	339500	19569H	PARTICIPANT	\N	PRESENT	0
342768	339500	14255U	PARTICIPANT	\N	PRESENT	0
342769	339500	19643A	PARTICIPANT	\N	PRESENT	0
342770	339500	14223L	PARTICIPANT	\N	PRESENT	0
342771	339500	11066Q	PARTICIPANT	\N	PRESENT	0
342772	339500	98029W	PARTICIPANT	\N	PRESENT	0
342773	339500	14205J	PARTICIPANT	\N	PRESENT	0
342774	339500	19794Q	PARTICIPANT	\N	PRESENT	0
342775	339500	01057W	PARTICIPANT	\N	PRESENT	0
342776	339500	01062T	PARTICIPANT	\N	PRESENT	0
342777	339500	19747H	PARTICIPANT	\N	PRESENT	0
342778	339500	01058X	PARTICIPANT	\N	PRESENT	0
342779	339500	04035D	PARTICIPANT	\N	PRESENT	0
342780	339500	18083K	PARTICIPANT	\N	PRESENT	0
342781	339500	96004D	PARTICIPANT	\N	PRESENT	0
342782	339500	04097T	PARTICIPANT	\N	PRESENT	0
342783	339500	19715Y	PARTICIPANT	\N	PRESENT	0
342784	339500	14237S	PARTICIPANT	\N	PRESENT	0
342785	339500	19671E	PARTICIPANT	\N	PRESENT	0
342786	339500	04061F	PARTICIPANT	\N	PRESENT	0
342787	339500	04088S	PARTICIPANT	\N	PRESENT	0
342788	339500	11103C	PARTICIPANT	\N	PRESENT	0
342789	339500	98050T	PARTICIPANT	\N	PRESENT	0
342790	339500	19533U	PARTICIPANT	\N	PRESENT	0
342792	339500	19467C	PARTICIPANT	\N	PRESENT	0
342793	339500	11040E	PARTICIPANT	\N	PRESENT	0
342794	339500	11083R	PARTICIPANT	\N	PRESENT	0
342800	339500	11067R	PARTICIPANT	\N	PRESENT	0
342801	339500	11026G	PARTICIPANT	\N	PRESENT	0
342802	339500	19399H	PARTICIPANT	\N	PRESENT	0
342805	339500	19441R	PARTICIPANT	\N	PRESENT	0
342806	339500	11070L	PARTICIPANT	\N	PRESENT	0
342807	339500	19741B	PARTICIPANT	\N	PRESENT	0
342809	339500	19549D	PARTICIPANT	\N	PRESENT	0
342815	339500	19543W	PARTICIPANT	\N	PRESENT	0
342816	339500	19577H	PARTICIPANT	\N	PRESENT	0
342819	339500	08069G	PARTICIPANT	\N	PRESENT	0
342820	339500	17637T	PARTICIPANT	\N	PRESENT	0
342821	339500	14083S	PARTICIPANT	\N	PRESENT	0
342822	339500	08051V	PARTICIPANT	\N	PRESENT	0
342852	339501	11027H	PARTICIPANT	\N	PRESENT	0
342853	339501	01062T	PARTICIPANT	\N	PRESENT	0
342854	339501	96004D	PARTICIPANT	\N	PRESENT	0
342855	339501	11083R	PARTICIPANT	\N	PRESENT	0
342856	339501	08051V	PARTICIPANT	\N	PRESENT	0
342857	339501	04057K	PARTICIPANT	\N	PRESENT	0
342858	339501	19569H	PARTICIPANT	\N	PRESENT	0
342859	339501	19747H	PARTICIPANT	\N	PRESENT	0
342860	339501	19671E	PARTICIPANT	\N	PRESENT	0
342861	339501	14255U	PARTICIPANT	\N	PRESENT	0
342862	339501	04061F	PARTICIPANT	\N	PRESENT	0
342863	339501	04035D	PARTICIPANT	\N	PRESENT	0
342864	339501	17637T	PARTICIPANT	\N	PRESENT	0
342865	339501	01057W	PARTICIPANT	\N	PRESENT	0
342866	339501	98050T	PARTICIPANT	\N	PRESENT	0
342867	339501	14261S	PARTICIPANT	\N	PRESENT	0
342869	339501	19709B	PARTICIPANT	\N	PRESENT	0
350392	350391	10015M	PARTICIPANT	\N	PRESENT	0
344714	341436	19629C	PARTICIPANT	\N	PRESENT	0
344764	342022	14107H	PARTICIPANT	\N	PRESENT	0
344818	344817	11065P	PARTICIPANT	\N	PRESENT	0
344819	344817	14107H	PARTICIPANT	\N	PRESENT	0
349890	349223	08012N	PARTICIPANT	\N	EXCUSE	0
350588	350586	19681G	PARTICIPANT	\N	PRESENT	0
350587	350586	14038Y	PARTICIPANT	\N	PRESENT	0
350589	350586	19525U	PARTICIPANT	\N	PRESENT	0
342850	339501	11070L	PARTICIPANT	\N	PRESENT	0
342851	339501	11040E	PARTICIPANT	\N	PRESENT	0
350590	350586	19713W	PARTICIPANT	\N	PRESENT	0
350591	350586	08009T	PARTICIPANT	\N	PRESENT	0
350706	341958	14093U	PARTICIPANT	\N	PRESENT	0
350708	341958	19663E	PARTICIPANT	\N	PRESENT	0
350710	341958	01048V	PARTICIPANT	\N	PRESENT	0
350711	341958	19593H	PARTICIPANT	\N	PRESENT	0
350712	341958	19533U	PARTICIPANT	\N	PRESENT	0
350713	341958	19503N	PARTICIPANT	\N	PRESENT	0
350714	341958	04043D	PARTICIPANT	\N	PRESENT	0
350719	341958	08053X	PARTICIPANT	\N	EXCUSE	0
350720	341958	01058X	PARTICIPANT	\N	EXCUSE	0
350721	341958	19693L	PARTICIPANT	\N	EXCUSE	0
350722	341958	14221J	PARTICIPANT	\N	EXCUSE	0
350731	341958	14299H	PARTICIPANT	\N	EXCUSE	0
350775	350774	11053K	PARTICIPANT	\N	PRESENT	0
350776	350774	14159V	PARTICIPANT	\N	PRESENT	0
350777	350774	05012A	PARTICIPANT	\N	PRESENT	0
350850	350849	14193X	PARTICIPANT	\N	PRESENT	0
350851	350849	98022P	PARTICIPANT	\N	PRESENT	0
350853	350852	14193X	PARTICIPANT	\N	PRESENT	0
350854	350852	98022P	PARTICIPANT	\N	PRESENT	0
350856	350855	14193X	PARTICIPANT	\N	PRESENT	0
350857	350855	98022P	PARTICIPANT	\N	PRESENT	0
353702	353701	14357A	PARTICIPANT	\N	PRESENT	0
353703	353701	11090Q	PARTICIPANT	\N	PRESENT	0
353704	353701	19511N	PARTICIPANT	\N	PRESENT	0
353729	353701	14033T	PARTICIPANT	\N	PRESENT	0
353757	351932	04018C	PARTICIPANT	\N	PRESENT	0
353761	352373	08068F	PARTICIPANT	\N	PRESENT	0
353762	352373	19782L	PARTICIPANT	\N	PRESENT	0
353763	352373	11101A	PARTICIPANT	\N	PRESENT	0
353877	353876	04044E	PARTICIPANT	\N	PRESENT	0
353765	352373	19599P	PARTICIPANT	\N	PRESENT	0
356670	345116	19415P	PARTICIPANT	\N	PRESENT	0
356671	345116	14109K	PARTICIPANT	\N	PRESENT	0
353768	352373	14073Q	PARTICIPANT	\N	PRESENT	0
353769	352373	07029T	PARTICIPANT	\N	PRESENT	0
353770	352373	04049K	PARTICIPANT	\N	PRESENT	0
353771	352373	19711U	PARTICIPANT	\N	PRESENT	0
353772	352373	01043Q	PARTICIPANT	\N	PRESENT	0
353773	352373	14205J	PARTICIPANT	\N	PRESENT	0
356672	345116	19762G	PARTICIPANT	\N	PRESENT	0
353775	352373	19637C	PARTICIPANT	\N	EXCUSE	0
353776	352373	14265W	PARTICIPANT	\N	EXCUSE	0
353777	352373	19768N	PARTICIPANT	\N	PRESENT	0
353778	352373	14237S	PARTICIPANT	\N	EXCUSE	0
353779	352373	19503N	PARTICIPANT	\N	PRESENT	0
353780	352373	19713W	PARTICIPANT	\N	PRESENT	0
356673	345116	19691J	PARTICIPANT	\N	PRESENT	0
353782	352373	01062T	PARTICIPANT	\N	PRESENT	0
353783	352373	19527W	PARTICIPANT	\N	PRESENT	0
353784	352373	95067Q	PARTICIPANT	\N	PRESENT	0
356662	345116	19563B	PARTICIPANT	\N	PRESENT	0
356665	345116	11067R	PARTICIPANT	\N	PRESENT	0
358124	345218	14097Y	PARTICIPANT	\N	PRESENT	0
358126	345218	14081Q	PARTICIPANT	\N	PRESENT	0
358134	345218	19387D	PARTICIPANT	\N	PRESENT	0
358135	345218	01025N	PARTICIPANT	\N	PRESENT	0
358137	345218	07004J	PARTICIPANT	\N	PRESENT	0
358138	345218	14267Y	PARTICIPANT	\N	PRESENT	0
358139	345218	19762G	PARTICIPANT	\N	PRESENT	0
334426	321375	98050T	PARTICIPANT	\N	PRESENT	0
334427	321375	11064N	PARTICIPANT	\N	PRESENT	0
334428	321375	11067R	PARTICIPANT	\N	PRESENT	0
334429	321375	19399H	PARTICIPANT	\N	PRESENT	0
334430	321375	19413M	PARTICIPANT	\N	PRESENT	0
334431	321375	14219Q	PARTICIPANT	\N	PRESENT	0
334432	321375	19569H	PARTICIPANT	\N	PRESENT	0
334433	321375	19725B	PARTICIPANT	\N	PRESENT	0
334434	321375	19717B	PARTICIPANT	\N	PRESENT	0
334435	321375	19699S	PARTICIPANT	\N	PRESENT	0
334436	321375	11070L	PARTICIPANT	\N	PRESENT	0
334437	321375	14249W	PARTICIPANT	\N	PRESENT	0
334439	321375	19637C	PARTICIPANT	\N	PRESENT	0
334440	321375	19591F	PARTICIPANT	\N	PRESENT	0
334441	321375	89017R	PARTICIPANT	\N	PRESENT	0
334442	321375	19739H	PARTICIPANT	\N	PRESENT	0
334443	321375	11012A	PARTICIPANT	\N	PRESENT	0
334444	321375	19367Y	PARTICIPANT	\N	PRESENT	0
334445	321375	08019V	PARTICIPANT	\N	PRESENT	0
334447	321375	19715Y	PARTICIPANT	\N	PRESENT	0
334448	321375	14030Q	PARTICIPANT	\N	PRESENT	0
334449	321375	19747H	PARTICIPANT	\N	PRESENT	0
334450	321375	19731Y	PARTICIPANT	\N	PRESENT	0
334451	321375	19733B	PARTICIPANT	\N	PRESENT	0
334452	321375	14187A	PARTICIPANT	\N	PRESENT	0
334453	321375	19657G	PARTICIPANT	\N	PRESENT	0
334454	321375	95041E	PARTICIPANT	\N	PRESENT	0
334455	321375	19741B	PARTICIPANT	\N	PRESENT	0
334456	321375	19573D	PARTICIPANT	\N	PRESENT	0
334457	321375	14073Q	PARTICIPANT	\N	PRESENT	0
334458	321375	14079W	PARTICIPANT	\N	PRESENT	0
334459	321375	14265W	PARTICIPANT	\N	PRESENT	0
334460	321375	14253S	PARTICIPANT	\N	PRESENT	0
334461	321375	11053K	PARTICIPANT	\N	PRESENT	0
334462	321375	19333N	PARTICIPANT	\N	PRESENT	0
334481	321375	08034U	PARTICIPANT	\N	PRESENT	0
334482	321375	19673G	PARTICIPANT	\N	PRESENT	0
334483	321375	95037J	PARTICIPANT	\N	PRESENT	0
334484	321375	04044E	PARTICIPANT	\N	PRESENT	0
334485	321375	19611R	PARTICIPANT	\N	PRESENT	0
334486	321375	11074Q	PARTICIPANT	\N	PRESENT	0
334487	321375	08015R	PARTICIPANT	\N	PRESENT	0
334488	321375	19531S	PARTICIPANT	\N	PRESENT	0
334548	332992	11066Q	PARTICIPANT	\N	PRESENT	0
334549	332992	11067R	PARTICIPANT	\N	PRESENT	0
334550	332992	14055N	PARTICIPANT	\N	PRESENT	0
334551	332992	19731Y	PARTICIPANT	\N	PRESENT	0
334552	332992	14259Y	PARTICIPANT	\N	PRESENT	0
334553	332992	14033T	PARTICIPANT	\N	PRESENT	0
334554	332992	19768N	PARTICIPANT	\N	PRESENT	0
334555	332992	14038Y	PARTICIPANT	\N	PRESENT	0
334567	332992	04088S	PARTICIPANT	\N	PRESENT	0
334557	332992	04045F	PARTICIPANT	\N	PRESENT	0
334568	332992	11048N	PARTICIPANT	\N	PRESENT	0
334559	332992	14133K	PARTICIPANT	\N	PRESENT	0
334560	332992	11041F	PARTICIPANT	\N	PRESENT	0
334561	332992	99004R	PARTICIPANT	\N	PRESENT	0
334562	332992	08024S	PARTICIPANT	\N	PRESENT	0
334573	332992	19637C	PARTICIPANT	\N	PRESENT	0
334564	332992	14253S	PARTICIPANT	\N	PRESENT	0
334565	332992	08019V	PARTICIPANT	\N	PRESENT	0
334566	332992	96004D	PARTICIPANT	\N	PRESENT	0
334569	332992	14071N	PARTICIPANT	\N	PRESENT	0
334570	332992	19467C	PARTICIPANT	\N	PRESENT	0
334571	332992	04042C	PARTICIPANT	\N	PRESENT	0
334572	332992	19673G	PARTICIPANT	\N	PRESENT	0
334574	332992	95037J	PARTICIPANT	\N	PRESENT	0
334575	332992	19599P	PARTICIPANT	\N	PRESENT	0
334576	332992	04057K	PARTICIPANT	\N	PRESENT	0
334577	332992	14265W	PARTICIPANT	\N	PRESENT	0
334578	332992	19717B	PARTICIPANT	\N	PRESENT	0
334579	332992	04033B	PARTICIPANT	\N	PRESENT	0
334580	332992	19739H	PARTICIPANT	\N	PRESENT	0
334581	332992	11043H	PARTICIPANT	\N	PRESENT	0
334582	332992	19447X	PARTICIPANT	\N	PRESENT	0
334583	332992	08010L	PARTICIPANT	\N	PRESENT	0
334584	332992	14157T	PARTICIPANT	\N	PRESENT	0
334585	332992	14225N	PARTICIPANT	\N	PRESENT	0
334586	332992	19667J	PARTICIPANT	\N	PRESENT	0
334587	332992	19583F	PARTICIPANT	\N	PRESENT	0
334588	332992	04049K	PARTICIPANT	\N	PRESENT	0
334589	332992	14229S	PARTICIPANT	\N	PRESENT	0
334590	332992	19413M	PARTICIPANT	\N	PRESENT	0
334591	332992	14079W	PARTICIPANT	\N	PRESENT	0
334592	332992	08055A	PARTICIPANT	\N	PRESENT	0
334593	332992	19621T	PARTICIPANT	\N	PRESENT	0
334594	332992	19533U	PARTICIPANT	\N	PRESENT	0
334595	332992	98029W	PARTICIPANT	\N	PRESENT	0
334596	332992	19573D	PARTICIPANT	\N	PRESENT	0
334597	332992	19503N	PARTICIPANT	\N	PRESENT	0
334598	332992	08043V	PARTICIPANT	\N	PRESENT	0
334599	332992	04018C	PARTICIPANT	\N	PRESENT	0
334600	332992	04086Q	PARTICIPANT	\N	PRESENT	0
334601	332992	08051V	PARTICIPANT	\N	PRESENT	0
334602	332992	19697Q	PARTICIPANT	\N	PRESENT	0
334603	332992	14355X	PARTICIPANT	\N	PRESENT	0
334604	332992	19669L	PARTICIPANT	\N	PRESENT	0
334605	332992	14331P	PARTICIPANT	\N	PRESENT	0
334606	332992	19543W	PARTICIPANT	\N	PRESENT	0
334607	332992	19782L	PARTICIPANT	\N	PRESENT	0
334546	332992	19721W	PARTICIPANT	\N	PRESENT	0
334547	332992	86034E	PARTICIPANT	\N	PRESENT	0
334608	332992	14031R	PARTICIPANT	\N	PRESENT	0
334609	332992	19683J	PARTICIPANT	\N	PRESENT	0
334610	332992	19421M	PARTICIPANT	\N	PRESENT	0
334611	332992	14042U	PARTICIPANT	\N	PRESENT	0
334612	332992	19699S	PARTICIPANT	\N	PRESENT	0
334613	332992	04047H	PARTICIPANT	\N	PRESENT	0
334614	332992	11085T	PARTICIPANT	\N	PRESENT	0
334615	332992	01058X	PARTICIPANT	\N	PRESENT	0
334616	332992	19525U	PARTICIPANT	\N	PRESENT	0
334617	332992	14021P	PARTICIPANT	\N	PRESENT	0
334618	332992	14187A	PARTICIPANT	\N	PRESENT	0
334619	332992	08009T	PARTICIPANT	\N	PRESENT	0
334620	332992	95063L	PARTICIPANT	\N	PRESENT	0
334621	332992	97011G	PARTICIPANT	\N	PRESENT	0
334622	332992	08060W	PARTICIPANT	\N	PRESENT	0
334623	332992	11012A	PARTICIPANT	\N	PRESENT	0
334624	332992	17637T	PARTICIPANT	\N	PRESENT	0
334625	332992	11074Q	PARTICIPANT	\N	PRESENT	0
334626	332992	16685X	PARTICIPANT	\N	PRESENT	0
334627	332992	04070G	PARTICIPANT	\N	PRESENT	0
334628	332992	11090Q	PARTICIPANT	\N	PRESENT	0
334629	332992	11056N	PARTICIPANT	\N	PRESENT	0
334630	332992	14173T	PARTICIPANT	\N	PRESENT	0
334631	332992	19687N	PARTICIPANT	\N	PRESENT	0
334632	332992	19760E	PARTICIPANT	\N	PRESENT	0
334633	332992	11045K	PARTICIPANT	\N	PRESENT	0
334634	332992	19737F	PARTICIPANT	\N	PRESENT	0
334635	332992	98018T	PARTICIPANT	\N	PRESENT	0
334636	332992	14327T	PARTICIPANT	\N	PRESENT	0
334637	332992	11040E	PARTICIPANT	\N	PRESENT	0
334638	332992	08017T	PARTICIPANT	\N	PRESENT	0
334639	332992	19289C	PARTICIPANT	\N	PRESENT	0
334641	332992	04059M	PARTICIPANT	\N	PRESENT	0
334643	332992	14151M	PARTICIPANT	\N	PRESENT	0
334644	332992	01057W	PARTICIPANT	\N	PRESENT	0
334646	332992	04040A	PARTICIPANT	\N	PRESENT	0
334647	332992	14105F	PARTICIPANT	\N	PRESENT	0
334648	332992	04089T	PARTICIPANT	\N	PRESENT	0
334650	332992	08015R	PARTICIPANT	\N	PRESENT	0
334651	332992	19369B	PARTICIPANT	\N	PRESENT	0
334653	332992	08034U	PARTICIPANT	\N	PRESENT	0
334655	332992	04092N	PARTICIPANT	\N	PRESENT	0
334658	332992	04044E	PARTICIPANT	\N	PRESENT	0
334661	332992	14053L	PARTICIPANT	\N	PRESENT	0
334662	332992	19671E	PARTICIPANT	\N	PRESENT	0
334668	332992	12041X	PARTICIPANT	\N	PRESENT	0
334669	332992	11033F	PARTICIPANT	\N	PRESENT	0
334670	332992	19758L	PARTICIPANT	\N	PRESENT	0
334671	332992	19593H	PARTICIPANT	\N	PRESENT	0
334672	332992	19565D	PARTICIPANT	\N	PRESENT	0
334673	332992	08020N	PARTICIPANT	\N	PRESENT	0
334674	332992	14051J	PARTICIPANT	\N	PRESENT	0
334675	332992	11077T	PARTICIPANT	\N	PRESENT	0
334676	332992	11027H	PARTICIPANT	\N	PRESENT	0
334677	332992	08052W	PARTICIPANT	\N	PRESENT	0
334678	332992	04085P	PARTICIPANT	\N	PRESENT	0
334679	332992	08045X	PARTICIPANT	\N	PRESENT	0
334680	332992	14249W	PARTICIPANT	\N	PRESENT	0
334681	332992	01062T	PARTICIPANT	\N	PRESENT	0
334682	332992	08038Y	PARTICIPANT	\N	PRESENT	0
334683	332992	14169X	PARTICIPANT	\N	PRESENT	0
334684	332992	19649G	PARTICIPANT	\N	PRESENT	0
334685	332992	19647E	PARTICIPANT	\N	PRESENT	0
334686	332992	19711U	PARTICIPANT	\N	PRESENT	0
334687	332992	14281W	PARTICIPANT	\N	PRESENT	0
334688	332992	19727D	PARTICIPANT	\N	PRESENT	0
353284	339595	14034U	PARTICIPANT	\N	PRESENT	0
353285	339595	08051V	PARTICIPANT	\N	PRESENT	0
353286	339595	19663E	PARTICIPANT	\N	PRESENT	0
353287	339595	88008L	PARTICIPANT	\N	PRESENT	0
353288	339595	14261S	PARTICIPANT	\N	PRESENT	0
353289	339595	08049C	PARTICIPANT	\N	PRESENT	0
353290	339595	19591F	PARTICIPANT	\N	PRESENT	0
353291	339595	11012A	PARTICIPANT	\N	PRESENT	0
353292	339595	19675J	PARTICIPANT	\N	PRESENT	0
353293	339595	11026G	PARTICIPANT	\N	PRESENT	0
353294	339595	14195A	PARTICIPANT	\N	PRESENT	0
353295	339595	11064N	PARTICIPANT	\N	PRESENT	0
353296	339595	11070L	PARTICIPANT	\N	PRESENT	0
353297	339595	14089Y	PARTICIPANT	\N	PRESENT	0
353298	339595	19335Q	PARTICIPANT	\N	PRESENT	0
353299	339595	14103D	PARTICIPANT	\N	PRESENT	0
353300	339595	14083S	PARTICIPANT	\N	PRESENT	0
353301	339595	14133K	PARTICIPANT	\N	PRESENT	0
353302	339595	19713W	PARTICIPANT	\N	PRESENT	0
353303	339595	14205J	PARTICIPANT	\N	PRESENT	0
353304	339595	19735D	PARTICIPANT	\N	PRESENT	0
353305	339595	11085T	PARTICIPANT	\N	PRESENT	0
353306	339595	19619A	PARTICIPANT	\N	PRESENT	0
353307	339595	19721W	PARTICIPANT	\N	PRESENT	0
353308	339595	19699S	PARTICIPANT	\N	PRESENT	0
353309	339595	11053K	PARTICIPANT	\N	PRESENT	0
353310	339595	01034P	PARTICIPANT	\N	PRESENT	0
353311	339595	19611R	PARTICIPANT	\N	PRESENT	0
353312	339595	01043Q	PARTICIPANT	\N	PRESENT	0
353313	339595	14327T	PARTICIPANT	\N	PRESENT	0
353314	339595	04040A	PARTICIPANT	\N	PRESENT	0
353315	339595	19577H	PARTICIPANT	\N	PRESENT	0
353316	339595	04070G	PARTICIPANT	\N	PRESENT	0
353317	339595	08044W	PARTICIPANT	\N	PRESENT	0
353318	339595	14179A	PARTICIPANT	\N	PRESENT	0
353319	339595	01024M	PARTICIPANT	\N	PRESENT	0
353320	339595	11077T	PARTICIPANT	\N	PRESENT	0
353321	339595	19701S	PARTICIPANT	\N	PRESENT	0
353322	339595	11010L	PARTICIPANT	\N	PRESENT	0
353323	339595	14053L	PARTICIPANT	\N	PRESENT	0
353324	339595	14115H	PARTICIPANT	\N	PRESENT	0
353325	339595	14151M	PARTICIPANT	\N	PRESENT	0
353326	339595	14097Y	PARTICIPANT	\N	PRESENT	0
353327	339595	08024S	PARTICIPANT	\N	PRESENT	0
353328	339595	11109J	PARTICIPANT	\N	PRESENT	0
353329	339595	19681G	PARTICIPANT	\N	PRESENT	0
353330	339595	19719D	PARTICIPANT	\N	PRESENT	0
353331	339595	19553Y	PARTICIPANT	\N	PRESENT	0
353332	339595	11099A	PARTICIPANT	\N	PRESENT	0
353333	339595	19563B	PARTICIPANT	\N	PRESENT	0
353334	339595	19531S	PARTICIPANT	\N	PRESENT	0
353335	339595	01060R	PARTICIPANT	\N	PRESENT	0
353336	339595	07004J	PARTICIPANT	\N	PRESENT	0
353337	339595	19329S	PARTICIPANT	\N	PRESENT	0
353338	339595	11072N	PARTICIPANT	\N	PRESENT	0
353339	339595	01048V	PARTICIPANT	\N	PRESENT	0
353340	339595	02002K	PARTICIPANT	\N	PRESENT	0
353341	339595	95063L	PARTICIPANT	\N	PRESENT	0
353347	350763	14041T	PARTICIPANT	\N	PRESENT	0
353348	350763	19553Y	PARTICIPANT	\N	PRESENT	0
353349	350763	19723Y	PARTICIPANT	\N	PRESENT	0
353350	350763	95062K	PARTICIPANT	\N	PRESENT	0
353633	339596	11027H	PARTICIPANT	\N	PRESENT	0
353634	339596	11033F	PARTICIPANT	\N	PRESENT	0
353801	353798	04040A	PARTICIPANT	\N	PRESENT	0
353802	353798	19709B	PARTICIPANT	\N	PRESENT	0
353637	339596	11012A	PARTICIPANT	\N	PRESENT	0
353638	339596	19585H	PARTICIPANT	\N	PRESENT	0
353803	353798	04035D	PARTICIPANT	\N	PRESENT	0
353804	353798	11027H	PARTICIPANT	\N	PRESENT	0
353641	339596	19711U	PARTICIPANT	\N	PRESENT	0
353848	353847	01057W	PARTICIPANT	\N	PRESENT	0
353849	353847	14225N	PARTICIPANT	\N	PRESENT	0
353644	339596	14121F	PARTICIPANT	\N	PRESENT	0
353645	339596	19329S	PARTICIPANT	\N	PRESENT	0
353646	339596	11026G	PARTICIPANT	\N	PRESENT	0
353647	339596	11072N	PARTICIPANT	\N	PRESENT	0
353648	339596	19667J	PARTICIPANT	\N	PRESENT	0
353649	339596	99004R	PARTICIPANT	\N	PRESENT	0
353650	339596	19673G	PARTICIPANT	\N	PRESENT	0
353651	339596	14191V	PARTICIPANT	\N	PRESENT	0
353851	353850	11074Q	PARTICIPANT	\N	PRESENT	0
353852	353850	08011M	PARTICIPANT	\N	PRESENT	0
353654	339596	19575F	PARTICIPANT	\N	PRESENT	0
353655	339596	05008E	PARTICIPANT	\N	PRESENT	0
353656	339596	19631V	PARTICIPANT	\N	PRESENT	0
353657	339596	14179A	PARTICIPANT	\N	PRESENT	0
353658	351932	19593H	PARTICIPANT	\N	PRESENT	0
353659	351932	19643A	PARTICIPANT	\N	PRESENT	0
353660	351932	04070G	PRESIDENT	0	PRESENT	0
353661	351932	04057K	PARTICIPANT	\N	PRESENT	0
353662	351932	19533U	PARTICIPANT	\N	PRESENT	0
353663	351932	19611R	PARTICIPANT	\N	PRESENT	0
353664	351932	19735D	PARTICIPANT	\N	PRESENT	0
353665	351932	11109J	PARTICIPANT	\N	PRESENT	0
353666	351932	08043V	PARTICIPANT	\N	PRESENT	0
353667	351932	19693L	PARTICIPANT	\N	PRESENT	0
353668	351932	19399H	PARTICIPANT	\N	PRESENT	0
353669	351932	14229S	PARTICIPANT	\N	PRESENT	0
353670	351932	14061L	PARTICIPANT	\N	EXCUSE	0
353671	351932	08017T	PARTICIPANT	\N	EXCUSE	0
353672	351932	08031R	PARTICIPANT	\N	EXCUSE	0
353673	339596	14030Q	PARTICIPANT	\N	PRESENT	0
353674	339596	19703U	PARTICIPANT	\N	PRESENT	0
353684	339596	19657G	PARTICIPANT	\N	PRESENT	0
353685	339596	19447X	PARTICIPANT	\N	PRESENT	0
353686	339596	11045K	PARTICIPANT	\N	PRESENT	0
353687	339596	14089Y	PARTICIPANT	\N	PRESENT	0
353688	339596	04088S	PARTICIPANT	\N	PRESENT	0
353705	350863	11027H	PARTICIPANT	\N	PRESENT	0
353706	350863	11033F	PARTICIPANT	\N	PRESENT	0
353707	350863	11012A	PARTICIPANT	\N	PRESENT	0
353708	350863	19585H	PARTICIPANT	\N	PRESENT	0
353709	350863	19711U	PARTICIPANT	\N	PRESENT	0
353710	350863	14121F	PARTICIPANT	\N	PRESENT	0
353711	350863	19329S	PARTICIPANT	\N	PRESENT	0
353712	350863	11026G	PARTICIPANT	\N	PRESENT	0
353713	350863	11072N	PARTICIPANT	\N	PRESENT	0
353714	350863	19667J	PARTICIPANT	\N	PRESENT	0
353715	350863	99004R	PARTICIPANT	\N	PRESENT	0
353716	350863	19673G	PARTICIPANT	\N	PRESENT	0
353717	350863	14191V	PARTICIPANT	\N	PRESENT	0
353718	350863	19575F	PARTICIPANT	\N	PRESENT	0
353719	350863	05008E	PARTICIPANT	\N	PRESENT	0
353720	350863	19631V	PARTICIPANT	\N	PRESENT	0
353721	350863	14179A	PARTICIPANT	\N	PRESENT	0
353722	350863	14030Q	PARTICIPANT	\N	PRESENT	0
353723	350863	19703U	PARTICIPANT	\N	PRESENT	0
353724	350863	19657G	PARTICIPANT	\N	PRESENT	0
353725	350863	19447X	PARTICIPANT	\N	PRESENT	0
353726	350863	11045K	PARTICIPANT	\N	PRESENT	0
353727	350863	14089Y	PARTICIPANT	\N	PRESENT	0
353728	350863	04088S	PARTICIPANT	\N	PRESENT	0
353799	353798	04042C	PARTICIPANT	\N	PRESENT	0
353800	353798	14193X	PARTICIPANT	\N	PRESENT	0
353853	353850	14331P	PARTICIPANT	\N	PRESENT	0
353855	353854	11090Q	PARTICIPANT	\N	PRESENT	0
353856	353854	14357A	PARTICIPANT	\N	PRESENT	0
353857	353854	19511N	PARTICIPANT	\N	PRESENT	0
353859	353858	11090Q	PARTICIPANT	\N	PRESENT	0
353860	353858	14357A	PARTICIPANT	\N	PRESENT	0
353861	353858	19511N	PARTICIPANT	\N	PRESENT	0
353862	353858	14033T	PARTICIPANT	\N	PRESENT	0
353863	348097	14063N	PARTICIPANT	\N	EXCUSE	0
353864	348097	08038Y	PARTICIPANT	\N	EXCUSE	0
353866	353865	14187A	PARTICIPANT	\N	PRESENT	0
353868	353867	08038Y	PARTICIPANT	\N	PRESENT	0
353869	353867	14187A	PARTICIPANT	\N	PRESENT	0
353871	353870	14187A	PARTICIPANT	\N	PRESENT	0
353873	353872	14187A	PARTICIPANT	\N	PRESENT	0
353875	353874	14187A	PARTICIPANT	\N	PRESENT	0
353879	353878	14231L	PARTICIPANT	\N	PRESENT	0
353896	353895	04044E	PARTICIPANT	\N	PRESENT	0
354819	339597	14249W	PARTICIPANT	\N	PRESENT	0
354820	339597	19647E	PARTICIPANT	\N	PRESENT	0
354821	339597	88008L	PARTICIPANT	\N	PRESENT	0
354822	339597	14277B	PARTICIPANT	\N	PRESENT	0
355518	355517	11053K	PARTICIPANT	\N	PRESENT	0
355519	355517	14159V	PARTICIPANT	\N	PRESENT	0
355520	355517	05012A	PARTICIPANT	\N	PRESENT	0
355645	353835	14231L	PARTICIPANT	\N	EXCUSE	0
355646	353835	19649G	PARTICIPANT	\N	EXCUSE	0
355647	353835	19447X	PARTICIPANT	\N	EXCUSE	0
355648	353835	01028R	PARTICIPANT	\N	EXCUSE	0
355684	354848	14053L	PARTICIPANT	\N	PRESENT	0
355710	354848	11033F	PARTICIPANT	\N	PRESENT	0
355711	354848	14089Y	PARTICIPANT	\N	PRESENT	0
355712	354848	14259Y	PARTICIPANT	\N	PRESENT	0
355713	354848	14231L	PARTICIPANT	\N	PRESENT	0
335278	332424	19737F	PARTICIPANT	\N	PRESENT	0
335292	332424	04038G	PARTICIPANT	\N	PRESENT	0
335369	332424	08012N	PARTICIPANT	\N	EXCUSE	0
335370	332424	01028R	PARTICIPANT	\N	EXCUSE	0
335371	332424	08024S	PARTICIPANT	\N	EXCUSE	0
335372	332424	19369B	PARTICIPANT	\N	PRESENT	0
335420	332424	19647E	PARTICIPANT	\N	EXCUSE	0
335456	332424	08045X	PARTICIPANT	\N	EXCUSE	0
340559	340397	11065P	PARTICIPANT	\N	PRESENT	0
340680	340397	19399H	PARTICIPANT	\N	PRESENT	0
340819	340469	14107H	PARTICIPANT	\N	PRESENT	0
340821	340467	14107H	PARTICIPANT	\N	PRESENT	0
340823	340468	14107H	PARTICIPANT	\N	PRESENT	0
340856	340397	02002K	PARTICIPANT	\N	EXCUSE	0
340950	340949	05008E	PARTICIPANT	\N	EXCUSE	0
341995	340397	19651A	PARTICIPANT	\N	PRESENT	0
344537	342189	19421M	PARTICIPANT	\N	PRESENT	0
340953	340949	14065Q	PARTICIPANT	\N	PRESENT	0
340954	340949	14069U	PARTICIPANT	\N	PRESENT	0
340955	340949	14089Y	PARTICIPANT	\N	PRESENT	0
340956	340949	04047H	PARTICIPANT	\N	PRESENT	0
342466	340395	14107H	PARTICIPANT	\N	PRESENT	0
344528	343404	11043H	PARTICIPANT	\N	PRESENT	0
340959	340949	04038G	PARTICIPANT	\N	PRESENT	0
340960	340949	14259Y	PARTICIPANT	\N	PRESENT	0
340961	340949	04008A	PARTICIPANT	\N	PRESENT	0
344529	343404	11104D	PARTICIPANT	\N	PRESENT	0
340963	340949	14041T	PARTICIPANT	\N	PRESENT	0
340964	340949	01024M	PARTICIPANT	\N	PRESENT	0
340965	340949	14215L	PARTICIPANT	\N	PRESENT	0
344530	343404	19749K	PARTICIPANT	\N	PRESENT	0
340967	340949	19673G	PARTICIPANT	\N	PRESENT	0
340968	340949	08045X	PARTICIPANT	\N	PRESENT	0
340969	340949	08018U	PARTICIPANT	\N	PRESENT	0
344531	343404	08039A	PARTICIPANT	\N	PRESENT	0
344532	343404	08031R	PARTICIPANT	\N	PRESENT	0
344533	343404	19621T	PARTICIPANT	\N	PRESENT	0
340973	340949	11049P	PARTICIPANT	\N	PRESENT	0
340974	340949	19725B	PARTICIPANT	\N	PRESENT	0
340975	340949	14179A	PARTICIPANT	\N	PRESENT	0
340976	340949	08044W	PARTICIPANT	\N	EXCUSE	0
340977	340949	19447X	PARTICIPANT	\N	PRESENT	0
340978	340949	14021P	PARTICIPANT	\N	PRESENT	0
340979	340949	19489J	PARTICIPANT	\N	PRESENT	0
340980	340949	11026G	PARTICIPANT	\N	PRESENT	0
340981	340949	19729F	PARTICIPANT	\N	PRESENT	0
340982	340949	19581D	PARTICIPANT	\N	PRESENT	0
340983	340949	14111D	PARTICIPANT	\N	PRESENT	0
344534	343404	19533U	PARTICIPANT	\N	PRESENT	0
344535	343404	14063N	PARTICIPANT	\N	PRESENT	0
344536	343404	19758L	PARTICIPANT	\N	PRESENT	0
340987	340949	14147R	PARTICIPANT	\N	PRESENT	0
340988	340949	08051V	PARTICIPANT	\N	PRESENT	0
344538	342127	01043Q	PARTICIPANT	\N	PRESENT	0
340990	340949	07034Q	PRESIDENT	0	PRESENT	0
340991	340949	10015M	PARTICIPANT	\N	PRESENT	0
344539	342127	80013X	PARTICIPANT	\N	PRESENT	0
340993	340949	19762G	PARTICIPANT	\N	EXCUSE	0
340994	340949	01028R	PARTICIPANT	\N	PRESENT	0
344540	342127	08019V	PARTICIPANT	\N	PRESENT	0
344541	342127	11056N	PARTICIPANT	\N	PRESENT	0
340997	340949	04044E	PARTICIPANT	\N	PRESENT	0
344542	342127	11101A	PARTICIPANT	\N	PRESENT	0
344543	340626	11031D	PARTICIPANT	\N	PRESENT	0
344544	342919	14069U	PARTICIPANT	\N	PRESENT	0
344545	342919	11085T	PARTICIPANT	\N	PRESENT	0
344546	342172	19289C	PARTICIPANT	\N	PRESENT	0
344547	342127	08038Y	PARTICIPANT	\N	PRESENT	0
344548	342919	14065Q	PARTICIPANT	\N	PRESENT	0
344549	343404	19573D	PARTICIPANT	\N	PRESENT	0
344550	343404	14109K	PARTICIPANT	\N	PRESENT	0
344551	343404	14123H	PARTICIPANT	\N	PRESENT	0
344552	343404	07033P	PARTICIPANT	\N	PRESENT	0
344553	342172	11065P	PARTICIPANT	\N	PRESENT	0
344554	343404	04057K	PARTICIPANT	\N	PRESENT	0
344555	342189	97011G	PARTICIPANT	\N	EXCUSE	0
344556	342189	11041F	PARTICIPANT	\N	EXCUSE	0
344560	344559	04040A	PARTICIPANT	\N	PRESENT	0
344561	344559	14079W	PARTICIPANT	\N	PRESENT	0
344563	344559	04092N	PARTICIPANT	\N	PRESENT	0
344564	344559	19503N	PARTICIPANT	\N	PRESENT	0
344565	344559	95067Q	PARTICIPANT	\N	PRESENT	0
344566	344559	14255U	PARTICIPANT	\N	PRESENT	0
344647	343407	04070G	PRESIDENT	0	PRESENT	0
344650	343407	08017T	PARTICIPANT	\N	PRESENT	0
344651	343407	04059M	PARTICIPANT	\N	PRESENT	0
345101	345003	19569H	PARTICIPANT	\N	EXCUSE	0
345102	345003	14033T	PARTICIPANT	\N	EXCUSE	0
345109	345108	08017T	PARTICIPANT	\N	PRESENT	0
345110	345108	14030Q	PARTICIPANT	\N	PRESENT	0
345270	345269	14231L	PARTICIPANT	\N	PRESENT	0
345272	345271	14259Y	PARTICIPANT	\N	PRESENT	0
345274	345273	14259Y	PARTICIPANT	\N	PRESENT	0
345276	345275	14259Y	PARTICIPANT	\N	PRESENT	0
345281	345280	14205J	PARTICIPANT	\N	PRESENT	0
345282	345280	14257W	PARTICIPANT	\N	PRESENT	0
345283	345280	04088S	PARTICIPANT	\N	PRESENT	0
345284	345280	14265W	PARTICIPANT	\N	PRESENT	0
345292	345291	14259Y	PARTICIPANT	\N	PRESENT	0
345294	345293	14259Y	PARTICIPANT	\N	PRESENT	0
346844	346843	14115H	PARTICIPANT	\N	PRESENT	0
346845	346843	14105F	PARTICIPANT	\N	PRESENT	0
346846	346843	08038Y	PARTICIPANT	\N	PRESENT	0
346847	346843	19333N	PARTICIPANT	\N	PRESENT	0
346848	346843	01043Q	PARTICIPANT	\N	PRESENT	0
346849	346843	14001X	PARTICIPANT	\N	PRESENT	0
346850	346843	05012A	PARTICIPANT	\N	PRESENT	0
346851	346843	14225N	PARTICIPANT	\N	PRESENT	0
346852	346843	11045K	PARTICIPANT	\N	PRESENT	0
346853	346843	19479G	PARTICIPANT	\N	PRESENT	0
347042	339515	87003B	PARTICIPANT	\N	PRESENT	0
347040	339515	19731Y	PARTICIPANT	\N	PRESENT	0
347041	339515	19719D	PARTICIPANT	\N	PRESENT	0
347043	339515	08068F	PARTICIPANT	\N	PRESENT	0
347068	346331	11109J	PARTICIPANT	\N	PRESENT	0
347069	346331	19659J	PARTICIPANT	\N	PRESENT	0
347070	346331	19691J	PARTICIPANT	\N	PRESENT	0
347071	346331	14097Y	PARTICIPANT	\N	EXCUSE	0
347072	346331	14021P	PARTICIPANT	\N	PRESENT	0
347073	346331	14059S	PARTICIPANT	\N	PRESENT	0
347074	346331	08019V	PRESIDENT	0	PRESENT	0
347075	346331	14229S	PARTICIPANT	\N	PRESENT	0
347076	339515	14053L	PARTICIPANT	\N	PRESENT	0
347077	339515	19715Y	PARTICIPANT	\N	PRESENT	0
347078	346296	11109J	PARTICIPANT	\N	PRESENT	0
347079	339515	19347U	PARTICIPANT	\N	PRESENT	0
347080	346296	19691J	PARTICIPANT	\N	PRESENT	0
347081	346296	14097Y	PARTICIPANT	\N	EXCUSE	0
347082	346296	08019V	PRESIDENT	0	PRESENT	0
347083	346296	14059S	PARTICIPANT	\N	PRESENT	0
347084	339515	19515S	PARTICIPANT	\N	PRESENT	0
347085	339515	04059M	PARTICIPANT	\N	PRESENT	0
347086	339515	19717B	PARTICIPANT	\N	PRESENT	0
347088	339515	14115H	PARTICIPANT	\N	PRESENT	0
347089	346331	19329S	PARTICIPANT	\N	EXCUSE	0
347090	346331	19583F	PARTICIPANT	\N	EXCUSE	0
347091	339515	04040A	PARTICIPANT	\N	PRESENT	0
347092	339515	14267Y	PARTICIPANT	\N	PRESENT	0
347093	339515	19383Y	PARTICIPANT	\N	PRESENT	0
347094	339515	19701S	PARTICIPANT	\N	PRESENT	0
347095	346296	95062K	PARTICIPANT	\N	PRESENT	0
347096	346296	19583F	PARTICIPANT	\N	EXCUSE	0
347097	346296	19329S	PARTICIPANT	\N	EXCUSE	0
347098	339515	08061X	PARTICIPANT	\N	PRESENT	0
347099	339515	04086Q	PARTICIPANT	\N	PRESENT	0
347100	345310	19553Y	PARTICIPANT	\N	PRESENT	0
347101	345310	11067R	PARTICIPANT	\N	PRESENT	0
347102	345310	14147R	PARTICIPANT	\N	PRESENT	0
347103	345310	19415P	PARTICIPANT	\N	PRESENT	0
347104	345310	14213J	PARTICIPANT	\N	PRESENT	0
347105	345310	11043H	PARTICIPANT	\N	PRESENT	0
347106	345310	19749K	PARTICIPANT	\N	PRESENT	0
347107	345310	10006L	PRESIDENT	0	PRESENT	0
347108	345310	01028R	PARTICIPANT	\N	PRESENT	0
347109	345310	08031R	PRESIDENT	1	PRESENT	0
347110	345310	08043V	PARTICIPANT	\N	EXCUSE	0
347111	339515	14123H	PARTICIPANT	\N	PRESENT	0
347112	339515	08044W	PARTICIPANT	\N	PRESENT	0
347113	339515	14329V	PARTICIPANT	\N	PRESENT	0
361395	345229	04045F	PARTICIPANT	\N	PRESENT	0
361396	345229	19747H	PARTICIPANT	\N	PRESENT	0
361397	345229	14041T	PARTICIPANT	\N	PRESENT	0
361398	345229	11012A	PARTICIPANT	\N	PRESENT	0
361401	345229	14205J	PARTICIPANT	\N	PRESENT	0
361402	345229	19577H	PARTICIPANT	\N	PRESENT	0
361403	345229	19691J	PARTICIPANT	\N	PRESENT	0
361404	345229	04018C	PARTICIPANT	\N	PRESENT	0
361405	345229	99004R	PARTICIPANT	\N	PRESENT	0
361406	345229	14249W	PARTICIPANT	\N	PRESENT	0
361408	345229	19683J	PARTICIPANT	\N	PRESENT	0
361409	345229	14169X	PARTICIPANT	\N	PRESENT	0
361410	345229	14069U	PARTICIPANT	\N	PRESENT	0
361411	345229	14030Q	PARTICIPANT	\N	PRESENT	0
361412	345229	19701S	PARTICIPANT	\N	PRESENT	0
361413	345229	14159V	PARTICIPANT	\N	PRESENT	0
361415	361414	14053L	PARTICIPANT	\N	PRESENT	0
361417	361416	14053L	PARTICIPANT	\N	PRESENT	0
361418	361177	11026G	PARTICIPANT	\N	PRESENT	0
361476	356290	04045F	PARTICIPANT	\N	PRESENT	0
361460	356290	19691J	PARTICIPANT	\N	PRESENT	0
361461	356290	19581D	PARTICIPANT	\N	PRESENT	0
361462	356290	14030Q	PARTICIPANT	\N	PRESENT	0
361463	356290	08031R	PARTICIPANT	\N	PRESENT	0
361464	356290	19701S	PARTICIPANT	\N	PRESENT	0
361465	356290	14217N	PARTICIPANT	\N	PRESENT	0
361466	356290	14249W	PARTICIPANT	\N	PRESENT	0
361467	356290	07029T	PARTICIPANT	\N	PRESENT	0
361468	356290	19762G	PARTICIPANT	\N	PRESENT	0
361469	356290	19657G	PARTICIPANT	\N	PRESENT	0
361470	356290	14041T	PARTICIPANT	\N	PRESENT	0
361471	356290	18083K	PARTICIPANT	\N	PRESENT	0
361472	356290	19593H	PARTICIPANT	\N	PRESENT	0
361473	356290	14038Y	PARTICIPANT	\N	PRESENT	0
361483	356290	14261S	PARTICIPANT	\N	PRESENT	0
361475	356290	19503N	PARTICIPANT	\N	PRESENT	0
361477	356290	19549D	PARTICIPANT	\N	PRESENT	0
361478	356290	04018C	PARTICIPANT	\N	PRESENT	0
361479	356290	19577H	PARTICIPANT	\N	PRESENT	0
361480	356290	19693L	PARTICIPANT	\N	PRESENT	0
361481	356290	11031D	PARTICIPANT	\N	PRESENT	0
361482	356290	08017T	PARTICIPANT	\N	PRESENT	0
361484	356290	14021P	PARTICIPANT	\N	PRESENT	0
361485	356290	04057K	PARTICIPANT	\N	PRESENT	0
361486	356290	19253P	PARTICIPANT	\N	PRESENT	0
361487	356290	11012A	PARTICIPANT	\N	PRESENT	0
361488	356290	14179A	PARTICIPANT	\N	PRESENT	0
361489	356290	14083S	PARTICIPANT	\N	PRESENT	0
361490	356290	04070G	PARTICIPANT	\N	PRESENT	0
361492	361491	14026U	PARTICIPANT	\N	PRESENT	0
361494	361493	14026U	PARTICIPANT	\N	PRESENT	0
361495	356290	14059S	PARTICIPANT	\N	PRESENT	0
361496	356290	19543W	PARTICIPANT	\N	PRESENT	0
361497	356290	11027H	PARTICIPANT	\N	PRESENT	0
361553	361551	08053X	PARTICIPANT	\N	PRESENT	0
361514	361512	96004D	PRESIDENT	0	PRESENT	0
361515	361512	14079W	PARTICIPANT	\N	PRESENT	0
361457	356290	11072N	PARTICIPANT	\N	PRESENT	0
361458	356290	08043V	PARTICIPANT	\N	PRESENT	0
361516	361512	11083R	PARTICIPANT	\N	PRESENT	0
361517	361512	14026U	PARTICIPANT	\N	PRESENT	0
361518	361512	04061F	PARTICIPANT	\N	PRESENT	0
361519	361512	12041X	PARTICIPANT	\N	PRESENT	0
361520	361512	11026G	PARTICIPANT	\N	PRESENT	0
361521	361512	04057K	PARTICIPANT	\N	PRESENT	0
361522	361512	19593H	PARTICIPANT	\N	PRESENT	0
361523	361512	14135M	PARTICIPANT	\N	PRESENT	0
361524	361512	10015M	PARTICIPANT	\N	PRESENT	0
361525	361512	98035U	PARTICIPANT	\N	PRESENT	0
361526	361512	11074Q	PARTICIPANT	\N	PRESENT	0
361527	361512	19711U	PARTICIPANT	\N	PRESENT	0
361528	361512	19647E	PARTICIPANT	\N	PRESENT	0
361529	361512	14179A	PARTICIPANT	\N	PRESENT	0
361530	361512	16685X	PARTICIPANT	\N	PRESENT	0
361531	361512	04034C	PARTICIPANT	\N	PRESENT	0
361532	361512	19333N	PARTICIPANT	\N	PRESENT	0
361533	361512	14255U	PARTICIPANT	\N	PRESENT	0
361534	361512	04070G	PARTICIPANT	\N	PRESENT	0
361535	361512	11012A	PARTICIPANT	\N	PRESENT	0
361536	361512	14133K	PARTICIPANT	\N	PRESENT	0
361552	361551	14255U	PARTICIPANT	\N	PRESENT	0
361555	361554	19709B	PARTICIPANT	\N	PRESENT	0
361556	361554	11027H	PARTICIPANT	\N	PRESENT	0
361558	361557	19709B	PARTICIPANT	\N	PRESENT	0
361559	361557	11027H	PARTICIPANT	\N	PRESENT	0
361561	361560	19709B	PARTICIPANT	\N	PRESENT	0
361562	361560	11027H	PARTICIPANT	\N	PRESENT	0
361564	361563	19709B	PARTICIPANT	\N	PRESENT	0
361565	361563	11027H	PARTICIPANT	\N	PRESENT	0
361567	361566	19709B	PARTICIPANT	\N	PRESENT	0
361568	361566	11027H	PARTICIPANT	\N	PRESENT	0
361570	361569	19709B	PARTICIPANT	\N	PRESENT	0
361571	361569	11027H	PARTICIPANT	\N	PRESENT	0
361573	361572	19709B	PARTICIPANT	\N	PRESENT	0
361574	361572	11027H	PARTICIPANT	\N	PRESENT	0
361577	361576	01028R	PARTICIPANT	\N	PRESENT	0
361579	361578	14253S	PARTICIPANT	\N	PRESENT	0
361580	361578	14085U	PARTICIPANT	\N	PRESENT	0
361582	361581	98022P	PARTICIPANT	\N	PRESENT	0
361583	361581	14193X	PARTICIPANT	\N	PRESENT	0
361585	361584	14193X	PARTICIPANT	\N	PRESENT	0
358140	345218	19383Y	PARTICIPANT	\N	PRESENT	0
361586	361584	98022P	PARTICIPANT	\N	PRESENT	0
361588	361587	98022P	PARTICIPANT	\N	PRESENT	0
361590	361589	14267Y	PARTICIPANT	\N	PRESENT	0
361591	361589	11054L	PARTICIPANT	\N	PRESENT	0
361592	361589	95067Q	PARTICIPANT	\N	PRESENT	0
361594	361593	14267Y	PARTICIPANT	\N	PRESENT	0
361595	361593	11054L	PARTICIPANT	\N	PRESENT	0
361596	361593	95067Q	PARTICIPANT	\N	PRESENT	0
361597	361593	14079W	PARTICIPANT	\N	PRESENT	0
361599	361598	14267Y	PARTICIPANT	\N	PRESENT	0
361600	361598	11054L	PARTICIPANT	\N	PRESENT	0
361601	361598	95067Q	PARTICIPANT	\N	PRESENT	0
361602	361598	14079W	PARTICIPANT	\N	PRESENT	0
361604	361603	14267Y	PARTICIPANT	\N	PRESENT	0
361605	361603	11027H	PARTICIPANT	\N	PRESENT	0
361615	361142	04044E	PARTICIPANT	\N	EXCUSE	0
361616	361142	04040A	PRESIDENT	0	PRESENT	0
361648	361647	14329V	PARTICIPANT	\N	PRESENT	0
361649	361647	14103D	PARTICIPANT	\N	PRESENT	0
361650	361647	17583W	PARTICIPANT	\N	PRESENT	0
361651	361647	14169X	PARTICIPANT	\N	PRESENT	0
361652	361647	19739H	PARTICIPANT	\N	PRESENT	0
361654	361653	14329V	PARTICIPANT	\N	PRESENT	0
361655	361653	14357A	PARTICIPANT	\N	PRESENT	0
361657	361656	14329V	PARTICIPANT	\N	PRESENT	0
361658	361656	14357A	PARTICIPANT	\N	PRESENT	0
361660	361659	14205J	PARTICIPANT	\N	PRESENT	0
361661	361659	14329V	PARTICIPANT	\N	PRESENT	0
361663	361662	14329V	PARTICIPANT	\N	PRESENT	0
361664	361662	14205J	PARTICIPANT	\N	PRESENT	0
361666	361665	14329V	PARTICIPANT	\N	PRESENT	0
361667	361665	14103D	PARTICIPANT	\N	PRESENT	0
361671	361670	14329V	PARTICIPANT	\N	PRESENT	0
361672	361670	14357A	PARTICIPANT	\N	PRESENT	0
361676	361674	08010L	PARTICIPANT	\N	PRESENT	0
361679	361678	14327T	PARTICIPANT	\N	PRESENT	0
361689	361688	14103D	PARTICIPANT	\N	PRESENT	0
361690	361688	14221J	PARTICIPANT	\N	PRESENT	0
361691	361688	19503N	PARTICIPANT	\N	PRESENT	0
361693	361692	14103D	PARTICIPANT	\N	PRESENT	0
361694	361692	14329V	PARTICIPANT	\N	PRESENT	0
361696	361695	14103D	PARTICIPANT	\N	PRESENT	0
361697	360226	14217N	PARTICIPANT	\N	PRESENT	0
361698	356166	19727D	PARTICIPANT	\N	PRESENT	0
361699	356167	19727D	PARTICIPANT	\N	PRESENT	0
361700	356168	19727D	PARTICIPANT	\N	PRESENT	0
361701	356169	19727D	PARTICIPANT	\N	PRESENT	0
361702	345230	11072N	PARTICIPANT	\N	PRESENT	0
361703	345230	19713W	PARTICIPANT	\N	PRESENT	0
361704	345230	19367Y	PARTICIPANT	\N	PRESENT	0
361705	345230	11031D	PARTICIPANT	\N	PRESENT	0
361706	345230	19599P	PARTICIPANT	\N	PRESENT	0
361707	345230	19629C	PARTICIPANT	\N	PRESENT	0
361708	345230	80013X	PARTICIPANT	\N	PRESENT	0
361709	345230	14105F	PARTICIPANT	\N	PRESENT	0
361724	345230	19585H	PARTICIPANT	\N	PRESENT	0
361726	345230	17583W	PARTICIPANT	\N	PRESENT	0
361727	345230	19782L	PARTICIPANT	\N	PRESENT	0
361728	345230	19527W	PARTICIPANT	\N	PRESENT	0
361729	345230	14187A	PARTICIPANT	\N	PRESENT	0
361730	361575	11065P	PARTICIPANT	\N	PRESENT	0
361731	345230	14001X	PARTICIPANT	\N	PRESENT	0
361732	345230	19533U	PARTICIPANT	\N	PRESENT	0
361733	345230	14219Q	PARTICIPANT	\N	PRESENT	0
361734	345230	14195A	PARTICIPANT	\N	PRESENT	0
361735	345230	11049P	PARTICIPANT	\N	PRESENT	0
361736	345230	07004J	PARTICIPANT	\N	PRESENT	0
334689	332992	14081Q	PARTICIPANT	\N	PRESENT	0
334690	332992	08011M	PARTICIPANT	\N	PRESENT	0
334691	332992	14121F	PARTICIPANT	\N	PRESENT	0
334692	332992	08058D	PARTICIPANT	\N	PRESENT	0
334693	332992	19347U	PARTICIPANT	\N	PRESENT	0
334694	332992	11110B	PARTICIPANT	\N	PRESENT	0
334695	332992	19333N	PARTICIPANT	\N	PRESENT	0
334696	332992	14227Q	PARTICIPANT	\N	PRESENT	0
334697	332992	11054L	PARTICIPANT	\N	PRESENT	0
334698	332992	19295A	PARTICIPANT	\N	PRESENT	0
334699	332992	19527W	PARTICIPANT	\N	PRESENT	0
334700	332992	14207L	PARTICIPANT	\N	PRESENT	0
334701	332992	14119M	PARTICIPANT	\N	PRESENT	0
334702	332992	11031D	PARTICIPANT	\N	PRESENT	0
334703	332992	11026G	PARTICIPANT	\N	PRESENT	0
334704	332992	14065Q	PARTICIPANT	\N	PRESENT	0
334705	332992	14063N	PARTICIPANT	\N	PRESENT	0
334706	332992	04071H	PARTICIPANT	\N	PRESENT	0
334707	332992	18083K	PARTICIPANT	\N	PRESENT	0
334708	332992	19399H	PARTICIPANT	\N	PRESENT	0
334709	332992	07029T	PARTICIPANT	\N	PRESENT	0
334710	332992	14085U	PARTICIPANT	\N	PRESENT	0
334711	332992	17779H	PARTICIPANT	\N	PRESENT	0
334712	332992	19415P	PARTICIPANT	\N	PRESENT	0
334713	332992	08061X	PARTICIPANT	\N	PRESENT	0
334714	332992	19766L	PARTICIPANT	\N	PRESENT	0
334715	332992	11083R	PARTICIPANT	\N	PRESENT	0
334716	332992	19651A	PARTICIPANT	\N	PRESENT	0
334717	332992	95067Q	PARTICIPANT	\N	PRESENT	0
334718	332992	14039A	PARTICIPANT	\N	PRESENT	0
334719	332992	08047A	PARTICIPANT	\N	PRESENT	0
334720	332992	11072N	PARTICIPANT	\N	PRESENT	0
334721	332992	19762G	PARTICIPANT	\N	PRESENT	0
334722	332992	14251Q	PARTICIPANT	\N	PRESENT	0
334723	332992	14357A	PARTICIPANT	\N	PRESENT	0
334724	332992	14034U	PARTICIPANT	\N	PRESENT	0
334725	332992	08031R	PARTICIPANT	\N	PRESENT	0
334726	332992	14261S	PARTICIPANT	\N	PRESENT	0
334727	332992	19581D	PARTICIPANT	\N	PRESENT	0
334728	332992	19387D	PARTICIPANT	\N	PRESENT	0
334729	332992	19489J	PARTICIPANT	\N	PRESENT	0
334730	332992	19553Y	PARTICIPANT	\N	PRESENT	0
334731	332992	11109J	PARTICIPANT	\N	PRESENT	0
334732	332992	08044W	PARTICIPANT	\N	PRESENT	0
334733	332992	19705W	PARTICIPANT	\N	PRESENT	0
334734	332992	01034P	PARTICIPANT	\N	PRESENT	0
334735	332992	19611R	PARTICIPANT	\N	PRESENT	0
334736	332992	14205J	PARTICIPANT	\N	PRESENT	0
334737	332992	19663E	PARTICIPANT	\N	PRESENT	0
334738	332992	19741B	PARTICIPANT	\N	PRESENT	0
334739	332992	19569H	PARTICIPANT	\N	PRESENT	0
334740	332992	19735D	PARTICIPANT	\N	PRESENT	0
334741	332992	19441R	PARTICIPANT	\N	PRESENT	0
334742	332992	19713W	PARTICIPANT	\N	PRESENT	0
334743	332992	19319Q	PARTICIPANT	\N	PRESENT	0
334744	332992	19723Y	PARTICIPANT	\N	PRESENT	0
334745	332992	19749K	PARTICIPANT	\N	PRESENT	0
334746	332992	14179A	PARTICIPANT	\N	PRESENT	0
334747	332992	19657G	PARTICIPANT	\N	PRESENT	0
334748	332992	01024M	PARTICIPANT	\N	PRESENT	0
334749	332992	01043Q	PARTICIPANT	\N	PRESENT	0
334750	332992	19689Q	PARTICIPANT	\N	PRESENT	0
334751	332992	19745F	PARTICIPANT	\N	PRESENT	0
334752	332992	89017R	PARTICIPANT	\N	PRESENT	0
334753	332992	19715Y	PARTICIPANT	\N	PRESENT	0
334757	332992	11053K	PARTICIPANT	\N	PRESENT	0
334755	332992	19479G	PARTICIPANT	\N	PRESENT	0
334756	332992	95041E	PARTICIPANT	\N	PRESENT	0
334758	332992	11097X	PARTICIPANT	\N	PRESENT	0
334759	332992	05008E	PARTICIPANT	\N	PRESENT	0
334760	332992	19747H	PARTICIPANT	\N	PRESENT	0
334761	332992	14237S	PARTICIPANT	\N	PRESENT	0
334762	332992	19269X	PARTICIPANT	\N	PRESENT	0
334766	332992	05012A	PARTICIPANT	\N	PRESENT	0
334764	332992	19549D	PARTICIPANT	\N	PRESENT	0
334765	332992	14219Q	PARTICIPANT	\N	PRESENT	0
334767	332992	07033P	PARTICIPANT	\N	PRESENT	0
334768	332992	14213J	PARTICIPANT	\N	PRESENT	0
334812	332992	19591F	PARTICIPANT	\N	PRESENT	0
334770	332992	04043D	PARTICIPANT	\N	PRESENT	0
334771	332992	19675J	PARTICIPANT	\N	PRESENT	0
334772	332992	19521Q	PARTICIPANT	\N	PRESENT	0
334773	332992	08039A	PARTICIPANT	\N	PRESENT	0
334774	332992	07004J	PARTICIPANT	\N	PRESENT	0
334775	332992	19531S	PARTICIPANT	\N	PRESENT	0
334776	332992	98050T	PARTICIPANT	\N	PRESENT	0
334777	332992	19515S	PARTICIPANT	\N	PRESENT	0
334809	332992	19695N	PARTICIPANT	\N	PRESENT	0
334813	332992	14083S	PARTICIPANT	\N	PRESENT	0
334823	332992	19729F	PARTICIPANT	\N	PRESENT	0
334825	332992	14061L	PARTICIPANT	\N	PRESENT	0
334833	332992	19643A	PARTICIPANT	\N	PRESENT	0
334836	332992	11049P	PARTICIPANT	\N	PRESENT	0
334846	332992	19585H	PARTICIPANT	\N	PRESENT	0
334847	332992	01028R	PARTICIPANT	\N	PRESENT	0
335068	321377	11027H	PARTICIPANT	\N	PRESENT	0
335070	321377	95041E	PARTICIPANT	\N	PRESENT	0
335071	321377	99004R	PARTICIPANT	\N	PRESENT	0
335072	321377	08052W	PARTICIPANT	\N	PRESENT	0
335073	321377	14261S	PARTICIPANT	\N	PRESENT	0
335074	321377	19717B	PARTICIPANT	\N	PRESENT	0
335075	321377	19569H	PARTICIPANT	\N	PRESENT	0
335076	321377	14331P	PARTICIPANT	\N	PRESENT	0
335077	321377	19711U	PARTICIPANT	\N	PRESENT	0
335078	321377	04043D	PARTICIPANT	\N	PRESENT	0
335079	321377	14121F	PARTICIPANT	\N	PRESENT	0
335080	321377	14187A	PARTICIPANT	\N	PRESENT	0
335081	321377	04044E	PARTICIPANT	\N	PRESENT	0
335082	321377	04057K	PARTICIPANT	\N	PRESENT	0
335083	321377	14133K	PARTICIPANT	\N	PRESENT	0
335084	321377	08047A	PARTICIPANT	\N	PRESENT	0
335085	321377	04088S	PARTICIPANT	\N	PRESENT	0
335086	321377	18083K	PARTICIPANT	\N	PRESENT	0
335087	321377	07004J	PARTICIPANT	\N	PRESENT	0
335088	321377	14253S	PARTICIPANT	\N	PRESENT	0
335089	321377	14085U	PARTICIPANT	\N	PRESENT	0
335090	321377	19683J	PARTICIPANT	\N	PRESENT	0
335091	321377	04092N	PARTICIPANT	\N	PRESENT	0
335092	321377	14213J	PARTICIPANT	\N	PRESENT	0
335093	321377	95037J	PARTICIPANT	\N	PRESENT	0
335094	321377	14219Q	PARTICIPANT	\N	PRESENT	0
335095	321377	19479G	PARTICIPANT	\N	PRESENT	0
335096	321377	19671E	PARTICIPANT	\N	PRESENT	0
335097	321377	11097X	PARTICIPANT	\N	PRESENT	0
335098	321377	14179A	PARTICIPANT	\N	PRESENT	0
335099	321377	19715Y	PARTICIPANT	\N	PRESENT	0
335100	321377	19697Q	PARTICIPANT	\N	PRESENT	0
335101	321377	11031D	PARTICIPANT	\N	PRESENT	0
335105	321377	11045K	PARTICIPANT	\N	PRESENT	0
335106	321377	19399H	PARTICIPANT	\N	PRESENT	0
335107	321377	19515S	PARTICIPANT	\N	PRESENT	0
335108	321377	19723Y	PARTICIPANT	\N	PRESENT	0
335109	321377	19782L	PARTICIPANT	\N	PRESENT	0
335110	321377	17779H	PARTICIPANT	\N	PRESENT	0
335111	321377	19689Q	PARTICIPANT	\N	PRESENT	0
335112	321377	14225N	PARTICIPANT	\N	PRESENT	0
335113	321377	11074Q	PARTICIPANT	\N	PRESENT	0
335114	321377	19729F	PARTICIPANT	\N	PRESENT	0
335115	321377	14173T	PARTICIPANT	\N	PRESENT	0
335116	321377	08015R	PARTICIPANT	\N	PRESENT	0
335117	321377	19747H	PARTICIPANT	\N	PRESENT	0
335118	321377	11066Q	PARTICIPANT	\N	PRESENT	0
335119	321377	14071N	PARTICIPANT	\N	PRESENT	0
335120	321377	04047H	PARTICIPANT	\N	PRESENT	0
335121	321377	19447X	PARTICIPANT	\N	PRESENT	0
335122	321377	19553Y	PARTICIPANT	\N	PRESENT	0
335123	321377	11012A	PARTICIPANT	\N	PRESENT	0
335124	321377	19649G	PARTICIPANT	\N	PRESENT	0
335125	321377	07029T	PARTICIPANT	\N	PRESENT	0
335126	321377	19657G	PARTICIPANT	\N	PRESENT	0
335127	321377	14030Q	PARTICIPANT	\N	PRESENT	0
335132	321377	11040E	PARTICIPANT	\N	PRESENT	0
335133	321377	11072N	PARTICIPANT	\N	PRESENT	0
335134	321377	01057W	PARTICIPANT	\N	PRESENT	0
335135	321377	19585H	PARTICIPANT	\N	PRESENT	0
335136	321377	08051V	PARTICIPANT	\N	PRESENT	0
335137	321377	19543W	PARTICIPANT	\N	PRESENT	0
335138	321377	19503N	PARTICIPANT	\N	PRESENT	0
335139	321377	14031R	PARTICIPANT	\N	PRESENT	0
335140	321377	19693L	PARTICIPANT	\N	PRESENT	0
335141	321377	08034U	PARTICIPANT	\N	PRESENT	0
335142	321377	08011M	PARTICIPANT	\N	PRESENT	0
335143	321377	08045X	PARTICIPANT	\N	PRESENT	0
335144	321377	11049P	PARTICIPANT	\N	PRESENT	0
335145	321377	14083S	PARTICIPANT	\N	PRESENT	0
335146	321377	14069U	PARTICIPANT	\N	PRESENT	0
355714	354848	14179A	PARTICIPANT	\N	PRESENT	0
355715	354848	19581D	PARTICIPANT	\N	PRESENT	0
355716	354848	05008E	PARTICIPANT	\N	EXCUSE	0
355717	354848	19729F	PARTICIPANT	\N	EXCUSE	0
355718	352738	08058D	PARTICIPANT	\N	EXCUSE	0
355719	352738	08056B	PARTICIPANT	\N	EXCUSE	0
355720	352738	14028W	PARTICIPANT	\N	EXCUSE	0
355721	352738	19319Q	PARTICIPANT	\N	EXCUSE	0
355817	355708	04044E	PARTICIPANT	\N	PRESENT	0
355818	355708	19585H	PARTICIPANT	\N	PRESENT	0
355819	355708	04047H	PARTICIPANT	\N	PRESENT	0
355820	355708	19673G	PARTICIPANT	\N	PRESENT	0
355821	355708	01028R	PARTICIPANT	\N	PRESENT	0
355822	355708	05008E	PRESIDENT	0	PRESENT	0
355823	355708	19447X	PARTICIPANT	\N	PRESENT	0
355824	355708	14231L	PARTICIPANT	\N	PRESENT	0
355825	355708	14041T	PARTICIPANT	\N	PRESENT	0
355826	355708	14147R	PARTICIPANT	\N	PRESENT	0
355827	355708	14179A	PARTICIPANT	\N	PRESENT	0
355828	355708	14215L	PARTICIPANT	\N	PRESENT	0
355829	355708	08051V	PARTICIPANT	\N	PRESENT	0
355830	355708	98035U	PARTICIPANT	\N	PRESENT	0
355831	355708	14053L	PARTICIPANT	\N	PRESENT	0
355832	355708	19649G	PARTICIPANT	\N	PRESENT	0
355833	355708	11010L	PARTICIPANT	\N	PRESENT	0
355834	355708	10015M	PARTICIPANT	\N	PRESENT	0
355835	355708	11026G	PARTICIPANT	\N	PRESENT	0
355836	355708	01024M	PARTICIPANT	\N	PRESENT	0
355837	355708	19719D	PARTICIPANT	\N	PRESENT	0
355838	355708	19725B	PARTICIPANT	\N	PRESENT	0
355839	355708	14089Y	PARTICIPANT	\N	PRESENT	0
355840	355708	95063L	PARTICIPANT	\N	PRESENT	0
355841	355708	19629C	PARTICIPANT	\N	PRESENT	0
355842	355708	07034Q	PARTICIPANT	\N	PRESENT	0
355843	355708	11049P	PARTICIPANT	\N	PRESENT	0
355844	355708	19729F	PARTICIPANT	\N	EXCUSE	0
355845	355708	14065Q	PARTICIPANT	\N	EXCUSE	0
355846	355708	08018U	PARTICIPANT	\N	EXCUSE	0
355849	345112	04059M	PARTICIPANT	\N	PRESENT	0
355850	345112	19691J	PARTICIPANT	\N	PRESENT	0
355851	345112	14195A	PARTICIPANT	\N	PRESENT	0
355852	345112	19553Y	PARTICIPANT	\N	PRESENT	0
355853	345112	19565D	PARTICIPANT	\N	PRESENT	0
355854	355709	98035U	PARTICIPANT	\N	PRESENT	0
355855	355709	11026G	PARTICIPANT	\N	PRESENT	0
355856	355709	01024M	PARTICIPANT	\N	PRESENT	0
355857	355709	19585H	PARTICIPANT	\N	PRESENT	0
355858	355709	04047H	PARTICIPANT	\N	PRESENT	0
355859	355709	19719D	PARTICIPANT	\N	PRESENT	0
355860	355709	19447X	PARTICIPANT	\N	PRESENT	0
355861	355709	05008E	PRESIDENT	0	PRESENT	0
355862	355709	19629C	PARTICIPANT	\N	PRESENT	0
355863	355709	14147R	PARTICIPANT	\N	PRESENT	0
355864	355709	14215L	PARTICIPANT	\N	PRESENT	0
355865	355709	08051V	PARTICIPANT	\N	PRESENT	0
355866	355709	14021P	PARTICIPANT	\N	PRESENT	0
355867	355709	14053L	PARTICIPANT	\N	PRESENT	0
355868	355709	10015M	PARTICIPANT	\N	PRESENT	0
355869	345112	04018C	PARTICIPANT	\N	PRESENT	0
355870	355709	01028R	PARTICIPANT	\N	PRESENT	0
355871	345112	19703U	PARTICIPANT	\N	PRESENT	0
355872	345112	19693L	PARTICIPANT	\N	PRESENT	0
355873	345112	19737F	PARTICIPANT	\N	PRESENT	0
355874	345112	14231L	PARTICIPANT	\N	PRESENT	0
355875	345112	11045K	PARTICIPANT	\N	PRESENT	0
355876	345112	19794Q	PARTICIPANT	\N	PRESENT	0
355877	345112	14042U	PARTICIPANT	\N	PRESENT	0
355878	345112	07029T	PARTICIPANT	\N	PRESENT	0
355879	345112	14217N	PARTICIPANT	\N	PRESENT	0
355880	345112	04092N	PARTICIPANT	\N	PRESENT	0
355881	355709	19649G	PARTICIPANT	\N	PRESENT	0
355882	345112	19697Q	PARTICIPANT	\N	PRESENT	0
355883	345112	11031D	PARTICIPANT	\N	PRESENT	0
355884	345112	11040E	PARTICIPANT	\N	PRESENT	0
355885	345112	19631V	PARTICIPANT	\N	PRESENT	0
355886	345112	01034P	PARTICIPANT	\N	PRESENT	0
355887	345112	08010L	PARTICIPANT	\N	PRESENT	0
355888	345112	99004R	PARTICIPANT	\N	PRESENT	0
355889	345112	14033T	PARTICIPANT	\N	PRESENT	0
355890	345112	14031R	PARTICIPANT	\N	PRESENT	0
355891	345112	14105F	PARTICIPANT	\N	PRESENT	0
355892	345112	14219Q	PARTICIPANT	\N	PRESENT	0
355893	345112	19577H	PARTICIPANT	\N	PRESENT	0
355894	345112	14205J	PARTICIPANT	\N	PRESENT	0
355895	345112	97011G	PARTICIPANT	\N	PRESENT	0
355896	345112	19657G	PARTICIPANT	\N	PRESENT	0
355897	345112	19701S	PARTICIPANT	\N	PRESENT	0
355909	345112	19717B	PARTICIPANT	\N	PRESENT	0
355910	345112	19713W	PARTICIPANT	\N	PRESENT	0
355914	345112	14071N	PARTICIPANT	\N	PRESENT	0
355917	345112	19711U	PARTICIPANT	\N	PRESENT	0
355924	345112	14327T	PARTICIPANT	\N	PRESENT	0
355925	355709	11010L	PARTICIPANT	\N	PRESENT	0
355926	355709	14089Y	PARTICIPANT	\N	PRESENT	0
355927	345112	14331P	PARTICIPANT	\N	PRESENT	0
355928	355709	19729F	PARTICIPANT	\N	EXCUSE	0
355929	355709	14065Q	PARTICIPANT	\N	EXCUSE	0
355930	355709	04044E	PARTICIPANT	\N	EXCUSE	0
355931	355709	08018U	PARTICIPANT	\N	EXCUSE	0
355932	345112	14147R	PARTICIPANT	\N	PRESENT	0
355934	345112	19585H	PARTICIPANT	\N	PRESENT	0
355937	345112	14089Y	PARTICIPANT	\N	PRESENT	0
355938	345112	19719D	PARTICIPANT	\N	PRESENT	0
355939	345112	19581D	PARTICIPANT	\N	PRESENT	0
355940	345112	14069U	PARTICIPANT	\N	PRESENT	0
355952	345112	14083S	PARTICIPANT	\N	PRESENT	0
355953	345112	19727D	PARTICIPANT	\N	PRESENT	0
355956	345112	08069G	PARTICIPANT	\N	PRESENT	0
355957	345112	19507S	PARTICIPANT	\N	PRESENT	0
355958	345112	19747H	PARTICIPANT	\N	PRESENT	0
355959	345112	19683J	PARTICIPANT	\N	PRESENT	0
355960	345112	14249W	PARTICIPANT	\N	PRESENT	0
355961	345112	04043D	PARTICIPANT	\N	PRESENT	0
355962	345112	19447X	PARTICIPANT	\N	PRESENT	0
355963	345112	08052W	PARTICIPANT	\N	PRESENT	0
356016	345111	11031D	PARTICIPANT	\N	PRESENT	0
356017	345111	19565D	PARTICIPANT	\N	PRESENT	0
356018	345111	08052W	PARTICIPANT	\N	PRESENT	0
356019	345111	07029T	PARTICIPANT	\N	PRESENT	0
356020	345111	19794Q	PARTICIPANT	\N	PRESENT	0
356021	345111	19703U	PARTICIPANT	\N	PRESENT	0
356022	345111	08069G	PARTICIPANT	\N	PRESENT	0
356023	345111	14147R	PARTICIPANT	\N	PRESENT	0
356079	345111	14033T	PARTICIPANT	\N	PRESENT	0
356025	345111	19585H	PARTICIPANT	\N	PRESENT	0
356026	345111	19717B	PARTICIPANT	\N	PRESENT	0
356027	345111	19581D	PARTICIPANT	\N	PRESENT	0
356028	345111	19713W	PARTICIPANT	\N	PRESENT	0
356029	345111	14219Q	PARTICIPANT	\N	PRESENT	0
356030	345111	19479G	PARTICIPANT	\N	PRESENT	0
356031	345111	19737F	PARTICIPANT	\N	PRESENT	0
356032	345111	19719D	PARTICIPANT	\N	PRESENT	0
356033	345111	19683J	PARTICIPANT	\N	PRESENT	0
356034	345111	19631V	PARTICIPANT	\N	PRESENT	0
356035	345111	19691J	PARTICIPANT	\N	PRESENT	0
356036	345111	14327T	PARTICIPANT	\N	PRESENT	0
356037	345111	11085T	PARTICIPANT	\N	PRESENT	0
356038	345111	19747H	PARTICIPANT	\N	PRESENT	0
356039	345111	19711U	PARTICIPANT	\N	PRESENT	0
356040	345111	04043D	PARTICIPANT	\N	PRESENT	0
356041	345111	08010L	PARTICIPANT	\N	PRESENT	0
356042	345111	14215L	PARTICIPANT	\N	PRESENT	0
356043	345111	04071H	PARTICIPANT	\N	PRESENT	0
356044	345111	11040E	PARTICIPANT	\N	PRESENT	0
356045	345111	05008E	PARTICIPANT	\N	PRESENT	0
356071	345111	19553Y	PARTICIPANT	\N	PRESENT	0
356047	345111	19701S	PARTICIPANT	\N	PRESENT	0
356048	345111	19447X	PARTICIPANT	\N	PRESENT	0
356049	345111	14231L	PARTICIPANT	\N	PRESENT	0
356050	345111	01024M	PARTICIPANT	\N	PRESENT	0
356051	345111	14042U	PARTICIPANT	\N	PRESENT	0
356057	345111	19543W	PARTICIPANT	\N	PRESENT	0
356062	356061	98050T	PARTICIPANT	\N	PRESENT	0
356063	345111	14105F	PARTICIPANT	\N	PRESENT	0
356064	345111	01028R	PARTICIPANT	\N	PRESENT	0
356065	345111	08061X	PARTICIPANT	\N	PRESENT	0
356066	345111	04086Q	PARTICIPANT	\N	PRESENT	0
356068	356067	01062T	PARTICIPANT	\N	PRESENT	0
356069	345111	08015R	PARTICIPANT	\N	PRESENT	0
356070	345111	19663E	PARTICIPANT	\N	PRESENT	0
356072	345111	14083S	PARTICIPANT	\N	PRESENT	0
356073	345111	19629C	PARTICIPANT	\N	PRESENT	0
356075	345111	19413M	PARTICIPANT	\N	PRESENT	0
356076	345111	07004J	PARTICIPANT	\N	PRESENT	0
356077	345111	14249W	PARTICIPANT	\N	PRESENT	0
356014	345111	04059M	PARTICIPANT	\N	PRESENT	0
356015	345111	10015M	PARTICIPANT	\N	PRESENT	0
356078	345111	19643A	PARTICIPANT	\N	PRESENT	0
356080	345111	19507S	PARTICIPANT	\N	PRESENT	0
339476	339475	11053K	PARTICIPANT	\N	PRESENT	0
339477	339475	14159V	PARTICIPANT	\N	PRESENT	0
339478	339475	05012A	PARTICIPANT	\N	PRESENT	0
340536	340397	19647E	PARTICIPANT	\N	EXCUSE	0
340556	339988	14041T	PARTICIPANT	\N	PRESENT	0
340557	339988	11026G	PARTICIPANT	\N	PRESENT	0
340558	339989	14041T	PARTICIPANT	\N	PRESENT	0
345249	345248	19701S	PARTICIPANT	\N	PRESENT	0
345250	345248	14255U	PARTICIPANT	\N	PRESENT	0
346573	346571	10006L	PARTICIPANT	\N	PRESENT	0
346574	346571	14042U	PARTICIPANT	\N	PRESENT	0
346575	346571	19691J	PARTICIPANT	\N	PRESENT	0
346576	346571	19723Y	PARTICIPANT	\N	PRESENT	0
346578	346577	10006L	PARTICIPANT	\N	PRESENT	0
346579	346577	14042U	PARTICIPANT	\N	PRESENT	0
346580	346577	19691J	PARTICIPANT	\N	PRESENT	0
346581	346577	19723Y	PARTICIPANT	\N	PRESENT	0
346590	346589	19691J	PARTICIPANT	\N	PRESENT	0
347114	339515	14034U	PARTICIPANT	\N	PRESENT	0
347115	345310	14223L	PARTICIPANT	\N	EXCUSE	0
347116	345310	19621T	PARTICIPANT	\N	EXCUSE	0
348299	348298	08055A	PARTICIPANT	\N	PRESENT	0
348302	348298	04047H	PARTICIPANT	\N	PRESENT	0
348303	348298	14085U	PARTICIPANT	\N	PRESENT	0
348304	348298	11083R	PARTICIPANT	\N	PRESENT	0
348305	348298	19611R	PARTICIPANT	\N	PRESENT	0
348306	348298	08049C	PARTICIPANT	\N	PRESENT	0
348307	348298	01057W	PARTICIPANT	\N	PRESENT	0
350218	350217	86034E	PARTICIPANT	\N	PRESENT	0
350219	348095	08010L	PARTICIPANT	\N	EXCUSE	0
350220	348095	04040A	PRESIDENT	0	PRESENT	0
350249	350217	14235Q	PARTICIPANT	\N	PRESENT	0
350250	350217	11040E	PARTICIPANT	\N	PRESENT	0
350251	350217	19687N	PARTICIPANT	\N	PRESENT	0
350252	350217	19715Y	PARTICIPANT	\N	PRESENT	0
350253	350217	14085U	PARTICIPANT	\N	PRESENT	0
350254	350217	19683J	PARTICIPANT	\N	PRESENT	0
350255	350217	14063N	PARTICIPANT	\N	PRESENT	0
350256	350217	08017T	PARTICIPANT	\N	PRESENT	0
350257	350217	14097Y	PARTICIPANT	\N	PRESENT	0
350258	350217	14109K	PARTICIPANT	\N	PRESENT	0
350259	350217	11066Q	PARTICIPANT	\N	PRESENT	0
350260	350217	19741B	PARTICIPANT	\N	PRESENT	0
350261	350217	14021P	PARTICIPANT	\N	PRESENT	0
350262	350217	19766L	PARTICIPANT	\N	PRESENT	0
350263	350217	14121F	PARTICIPANT	\N	PRESENT	0
350264	350217	11080N	PARTICIPANT	\N	PRESENT	0
350265	350217	04034C	PARTICIPANT	\N	PRESENT	0
350266	350217	11010L	PARTICIPANT	\N	PRESENT	0
350267	350217	19563B	PARTICIPANT	\N	PRESENT	0
350268	350217	14107H	PARTICIPANT	\N	PRESENT	0
350269	350217	19719D	PARTICIPANT	\N	PRESENT	0
350270	350217	19667J	PARTICIPANT	\N	PRESENT	0
350271	350217	01057W	PARTICIPANT	\N	PRESENT	0
350272	350217	04057K	PARTICIPANT	\N	PRESENT	0
350273	350217	04086Q	PARTICIPANT	\N	PRESENT	0
350274	350217	19681G	PARTICIPANT	\N	PRESENT	0
350275	350217	96004D	PARTICIPANT	\N	PRESENT	0
350276	350217	19583F	PARTICIPANT	\N	PRESENT	0
350277	350217	08011M	PARTICIPANT	\N	PRESENT	0
350278	350217	08069G	PARTICIPANT	\N	PRESENT	0
350279	350217	11074Q	PARTICIPANT	\N	PRESENT	0
350280	350217	04092N	PARTICIPANT	\N	PRESENT	0
350281	350217	19693L	PARTICIPANT	\N	PRESENT	0
350282	350217	19651A	PARTICIPANT	\N	PRESENT	0
350283	350217	19399H	PARTICIPANT	\N	PRESENT	0
350284	350217	98005N	PARTICIPANT	\N	PRESENT	0
350285	350217	07029T	PARTICIPANT	\N	PRESENT	0
350286	350217	19319Q	PARTICIPANT	\N	PRESENT	0
350287	350217	19569H	PARTICIPANT	\N	PRESENT	0
350288	350217	19737F	PARTICIPANT	\N	PRESENT	0
350289	350217	14041T	PARTICIPANT	\N	PRESENT	0
350290	350217	11070L	PARTICIPANT	\N	PRESENT	0
350291	350217	14135M	PARTICIPANT	\N	PRESENT	0
350292	350217	11012A	PARTICIPANT	\N	PRESENT	0
350293	350217	04088S	PARTICIPANT	\N	PRESENT	0
350294	350217	14261S	PARTICIPANT	\N	PRESENT	0
350295	350217	14083S	PARTICIPANT	\N	PRESENT	0
350296	350217	14089Y	PARTICIPANT	\N	PRESENT	0
350297	350217	19739H	PARTICIPANT	\N	PRESENT	0
350298	350217	19447X	PARTICIPANT	\N	PRESENT	0
350299	350217	19521Q	PARTICIPANT	\N	PRESENT	0
350300	350217	14255U	PARTICIPANT	\N	PRESENT	0
350301	350217	19573D	PARTICIPANT	\N	PRESENT	0
350302	350217	11085T	PARTICIPANT	\N	PRESENT	0
350303	350217	19794Q	PARTICIPANT	\N	PRESENT	0
350304	350217	19699S	PARTICIPANT	\N	PRESENT	0
350305	350217	08015R	PARTICIPANT	\N	PRESENT	0
350306	350217	19441R	PARTICIPANT	\N	PRESENT	0
350307	350217	14213J	PARTICIPANT	\N	PRESENT	0
350308	350217	14069U	PARTICIPANT	\N	PRESENT	0
350309	350217	14327T	PARTICIPANT	\N	PRESENT	0
350310	350217	14265W	PARTICIPANT	\N	PRESENT	0
350311	350217	19611R	PARTICIPANT	\N	PRESENT	0
350312	350217	05012A	PARTICIPANT	\N	PRESENT	0
350314	350217	08034U	PARTICIPANT	\N	PRESENT	0
350315	350217	14257W	PARTICIPANT	\N	PRESENT	0
350316	350217	14225N	PARTICIPANT	\N	PRESENT	0
350317	350217	14357A	PARTICIPANT	\N	PRESENT	0
350318	350217	19731Y	PARTICIPANT	\N	PRESENT	0
350319	350217	07033P	PARTICIPANT	\N	PRESENT	0
350320	350217	04018C	PARTICIPANT	\N	PRESENT	0
350321	350217	12041X	PARTICIPANT	\N	PRESENT	0
350322	350217	19701S	PARTICIPANT	\N	PRESENT	0
350323	350217	07034Q	PARTICIPANT	\N	PRESENT	0
350324	350217	19421M	PARTICIPANT	\N	PRESENT	0
350325	350217	14123H	PARTICIPANT	\N	PRESENT	0
350326	350217	11097X	PARTICIPANT	\N	PRESENT	0
350327	350217	04044E	PARTICIPANT	\N	PRESENT	0
350337	350217	14231L	PARTICIPANT	\N	PRESENT	0
350329	350217	19735D	PARTICIPANT	\N	PRESENT	0
350330	350217	14249W	PARTICIPANT	\N	PRESENT	0
350331	350217	14061L	PARTICIPANT	\N	PRESENT	0
350332	350217	08073C	PARTICIPANT	\N	PRESENT	0
350333	350217	14039A	PARTICIPANT	\N	PRESENT	0
350334	350217	19301E	PARTICIPANT	\N	PRESENT	0
350335	350217	14073Q	PARTICIPANT	\N	PRESENT	0
350336	350217	08019V	PARTICIPANT	\N	PRESENT	0
350338	350217	11053K	PARTICIPANT	\N	PRESENT	0
350339	350217	11048N	PARTICIPANT	\N	PRESENT	0
350341	344806	14030Q	PRESIDENT	0	PRESENT	0
350342	344806	08043V	PARTICIPANT	\N	PRESENT	0
350343	344806	19643A	PARTICIPANT	\N	PRESENT	0
350344	344806	19701S	PARTICIPANT	\N	PRESENT	0
350345	344806	11031D	PARTICIPANT	\N	PRESENT	0
350346	344806	19693L	PARTICIPANT	\N	EXCUSE	0
350347	344806	14217N	PARTICIPANT	\N	PRESENT	0
350348	344806	19599P	PARTICIPANT	\N	PRESENT	0
350349	344806	19715Y	PARTICIPANT	\N	PRESENT	0
350350	344806	08031R	PARTICIPANT	\N	EXCUSE	0
350351	344806	08017T	PARTICIPANT	\N	PRESENT	0
350352	344806	14251Q	PARTICIPANT	\N	EXCUSE	0
350354	344806	14109K	PARTICIPANT	\N	PRESENT	0
350355	344806	14235Q	PARTICIPANT	\N	PRESENT	0
350356	350217	14281W	PARTICIPANT	\N	PRESENT	0
350357	344806	11045K	PARTICIPANT	\N	PRESENT	0
350358	350217	11090Q	PARTICIPANT	\N	PRESENT	0
350359	350217	14229S	PARTICIPANT	\N	PRESENT	0
350360	350217	19515S	PARTICIPANT	\N	PRESENT	0
350361	350217	14217N	PARTICIPANT	\N	PRESENT	0
350362	350217	19747H	PARTICIPANT	\N	PRESENT	0
350364	350217	19671E	PARTICIPANT	\N	PRESENT	0
350368	350217	11083R	PARTICIPANT	\N	PRESENT	0
350369	350217	19631V	PARTICIPANT	\N	PRESENT	0
350370	350217	19691J	PARTICIPANT	\N	PRESENT	0
350371	350217	14219Q	PARTICIPANT	\N	PRESENT	0
350372	350217	14034U	PARTICIPANT	\N	PRESENT	0
350373	350217	04040A	PARTICIPANT	\N	PRESENT	0
350374	350217	14133K	PARTICIPANT	\N	PRESENT	0
350375	350217	19545Y	PARTICIPANT	\N	PRESENT	0
350376	350217	14227Q	PARTICIPANT	\N	PRESENT	0
350377	348035	11067R	PARTICIPANT	\N	PRESENT	0
350378	348035	19649G	PARTICIPANT	\N	PRESENT	0
350379	348035	11045K	PARTICIPANT	\N	PRESENT	0
350380	348035	19415P	PARTICIPANT	\N	PRESENT	0
350381	348035	08043V	PARTICIPANT	\N	PRESENT	0
350382	348035	04047H	PARTICIPANT	\N	PRESENT	0
350383	348035	10006L	PRESIDENT	0	PRESENT	0
350384	348035	19673G	PARTICIPANT	\N	PRESENT	0
350385	348035	01028R	PARTICIPANT	\N	PRESENT	0
350386	348035	11033F	PARTICIPANT	\N	PRESENT	0
350387	348035	19447X	PARTICIPANT	\N	PRESENT	0
350388	348035	08031R	PARTICIPANT	\N	PRESENT	0
350390	350217	19553Y	PARTICIPANT	\N	PRESENT	0
350394	350217	19511N	PARTICIPANT	\N	PRESENT	0
350395	350217	19695N	PARTICIPANT	\N	PRESENT	0
358341	345218	08073C	PARTICIPANT	\N	PRESENT	0
358342	345218	19467C	PARTICIPANT	\N	PRESENT	0
358343	345218	19531S	PARTICIPANT	\N	PRESENT	0
358345	345218	14135M	PARTICIPANT	\N	PRESENT	0
358347	345218	14103D	PARTICIPANT	\N	PRESENT	0
358349	345218	19399H	PARTICIPANT	\N	PRESENT	0
358351	345218	14073Q	PARTICIPANT	\N	PRESENT	0
358353	345218	14265W	PARTICIPANT	\N	PRESENT	0
358354	345218	19521Q	PARTICIPANT	\N	PRESENT	0
358355	345218	14213J	PARTICIPANT	\N	PRESENT	0
358356	345218	14277B	PARTICIPANT	\N	PRESENT	0
358357	345218	19443T	PARTICIPANT	\N	PRESENT	0
358358	345218	01024M	PARTICIPANT	\N	PRESENT	0
358359	345218	19741B	PARTICIPANT	\N	PRESENT	0
358360	345218	14030Q	PARTICIPANT	\N	PRESENT	0
358361	345218	18083K	PARTICIPANT	\N	PRESENT	0
358362	345218	14109K	PARTICIPANT	\N	PRESENT	0
358363	345218	04088S	PARTICIPANT	\N	PRESENT	0
358364	345218	17589D	PARTICIPANT	\N	PRESENT	0
358365	345218	19689Q	PARTICIPANT	\N	PRESENT	0
358366	345218	07029T	PARTICIPANT	\N	PRESENT	0
358367	345218	14355X	PARTICIPANT	\N	PRESENT	0
358368	345218	08062Y	PARTICIPANT	\N	PRESENT	0
358369	345218	08048B	PARTICIPANT	\N	PRESENT	0
358370	345218	98050T	PARTICIPANT	\N	PRESENT	0
358371	345218	14061L	PARTICIPANT	\N	PRESENT	0
358372	345218	19713W	PARTICIPANT	\N	PRESENT	0
358373	345218	95041E	PARTICIPANT	\N	PRESENT	0
358374	345218	11097X	PARTICIPANT	\N	PRESENT	0
358375	345218	04092N	PARTICIPANT	\N	PRESENT	0
358376	345218	14071N	PARTICIPANT	\N	PRESENT	0
358377	345218	05008E	PARTICIPANT	\N	PRESENT	0
358378	345218	19421M	PARTICIPANT	\N	PRESENT	0
358380	345218	04033B	PARTICIPANT	\N	PRESENT	0
358381	345218	14187A	PARTICIPANT	\N	PRESENT	0
358382	345218	04044E	PARTICIPANT	\N	PRESENT	0
358383	345218	10006L	PARTICIPANT	\N	PRESENT	0
358384	345218	05012A	PARTICIPANT	\N	PRESENT	0
358385	345218	97011G	PARTICIPANT	\N	PRESENT	0
358387	345218	14217N	PARTICIPANT	\N	PRESENT	0
358388	345218	14331P	PARTICIPANT	\N	PRESENT	0
358390	345218	14357A	PARTICIPANT	\N	PRESENT	0
358391	345218	04018C	PARTICIPANT	\N	PRESENT	0
358392	345218	19621T	PARTICIPANT	\N	PRESENT	0
358393	345218	19367Y	PARTICIPANT	\N	PRESENT	0
358394	345218	14079W	PARTICIPANT	\N	PRESENT	0
358395	345218	19671E	PARTICIPANT	\N	PRESENT	0
358396	345218	19747H	PARTICIPANT	\N	PRESENT	0
358397	345218	89017R	PARTICIPANT	\N	PRESENT	0
358398	345218	11043H	PARTICIPANT	\N	PRESENT	0
358399	345218	14087W	PARTICIPANT	\N	PRESENT	0
358400	345218	19657G	PARTICIPANT	\N	PRESENT	0
358401	345218	08034U	PARTICIPANT	\N	PRESENT	0
358402	345218	14249W	PARTICIPANT	\N	PRESENT	0
358403	345218	11070L	PARTICIPANT	\N	PRESENT	0
358404	345218	19591F	PARTICIPANT	\N	PRESENT	0
358405	345218	14157T	PARTICIPANT	\N	PRESENT	0
358406	345218	04061F	PARTICIPANT	\N	PRESENT	0
358407	345218	14089Y	PARTICIPANT	\N	PRESENT	0
358408	345218	11109J	PARTICIPANT	\N	PRESENT	0
358409	345218	19333N	PARTICIPANT	\N	PRESENT	0
358410	345218	08038Y	PARTICIPANT	\N	PRESENT	0
358411	345218	19525U	PARTICIPANT	\N	PRESENT	0
358412	345218	11045K	PARTICIPANT	\N	PRESENT	0
358413	345218	19489J	PARTICIPANT	\N	PRESENT	0
358414	345218	11080N	PARTICIPANT	\N	PRESENT	0
358659	345219	14034U	PARTICIPANT	\N	PRESENT	0
358660	345219	19347U	PARTICIPANT	\N	PRESENT	0
358668	345219	14235Q	PARTICIPANT	\N	PRESENT	0
358669	345219	11031D	PARTICIPANT	\N	PRESENT	0
358670	345219	04038G	PARTICIPANT	\N	PRESENT	0
358671	345219	11033F	PARTICIPANT	\N	PRESENT	0
358673	345219	14121F	PARTICIPANT	\N	PRESENT	0
358674	345219	14207L	PARTICIPANT	\N	PRESENT	0
358675	345219	19333N	PARTICIPANT	\N	PRESENT	0
358676	345219	19525U	PARTICIPANT	\N	PRESENT	0
358720	345219	14221J	PARTICIPANT	\N	PRESENT	0
358680	345219	14038Y	PARTICIPANT	\N	PRESENT	0
358682	345219	19637C	PARTICIPANT	\N	PRESENT	0
358685	345219	19289C	PARTICIPANT	\N	PRESENT	0
358686	345219	19585H	PARTICIPANT	\N	PRESENT	0
358687	345219	19794Q	PARTICIPANT	\N	PRESENT	0
358688	345219	19681G	PARTICIPANT	\N	PRESENT	0
358689	345219	11070L	PARTICIPANT	\N	PRESENT	0
358690	345219	19667J	PARTICIPANT	\N	PRESENT	0
358691	345219	19253P	PARTICIPANT	\N	PRESENT	0
358692	345219	14231L	PARTICIPANT	\N	PRESENT	0
358693	345219	07029T	PARTICIPANT	\N	PRESENT	0
358694	345219	19399H	PARTICIPANT	\N	PRESENT	0
358695	345219	95030B	PARTICIPANT	\N	PRESENT	0
358696	345219	14151M	PARTICIPANT	\N	PRESENT	0
358697	345219	98050T	PARTICIPANT	\N	PRESENT	0
358698	345219	11040E	PARTICIPANT	\N	PRESENT	0
358699	345219	19711U	PARTICIPANT	\N	PRESENT	0
358700	345219	19703U	PARTICIPANT	\N	PRESENT	0
358701	345219	14041T	PARTICIPANT	\N	PRESENT	0
358702	345219	19758L	PARTICIPANT	\N	PRESENT	0
358703	345219	19673G	PARTICIPANT	\N	PRESENT	0
358704	345219	19695N	PARTICIPANT	\N	PRESENT	0
358705	345219	11056N	PARTICIPANT	\N	PRESENT	0
358706	345219	19657G	PARTICIPANT	\N	PRESENT	0
358707	345219	19687N	PARTICIPANT	\N	PRESENT	0
358708	345219	19671E	PARTICIPANT	\N	PRESENT	0
358709	345219	19593H	PARTICIPANT	\N	PRESENT	0
358710	345219	11077T	PARTICIPANT	\N	PRESENT	0
358711	345219	08056B	PARTICIPANT	\N	PRESENT	0
358712	345219	19551W	PARTICIPANT	\N	PRESENT	0
358713	345219	19503N	PARTICIPANT	\N	PRESENT	0
358715	345219	19689Q	PARTICIPANT	\N	PRESENT	0
358716	345219	19467C	PARTICIPANT	\N	PRESENT	0
358718	345219	17637T	PARTICIPANT	\N	PRESENT	0
358719	345219	19631V	PARTICIPANT	\N	PRESENT	0
358721	345219	14205J	PARTICIPANT	\N	PRESENT	0
358722	345219	17589D	PARTICIPANT	\N	PRESENT	0
358723	345219	14267Y	PARTICIPANT	\N	PRESENT	0
358724	345219	19549D	PARTICIPANT	\N	PRESENT	0
358725	345219	19629C	PARTICIPANT	\N	PRESENT	0
358726	345219	04085P	PARTICIPANT	\N	PRESENT	0
358727	345219	14219Q	PARTICIPANT	\N	PRESENT	0
358728	345219	14031R	PARTICIPANT	\N	PRESENT	0
358732	345219	14135M	PARTICIPANT	\N	PRESENT	0
358733	345219	04088S	PARTICIPANT	\N	PRESENT	0
358735	345219	04047H	PARTICIPANT	\N	PRESENT	0
358738	345219	12041X	PARTICIPANT	\N	PRESENT	0
358762	358761	14221J	PARTICIPANT	\N	PRESENT	0
358763	358761	19503N	PARTICIPANT	\N	PRESENT	0
358764	358761	19723Y	PARTICIPANT	\N	PRESENT	0
358766	345219	14157T	PARTICIPANT	\N	PRESENT	0
358767	345219	19531S	PARTICIPANT	\N	PRESENT	0
358768	345219	14211G	PARTICIPANT	\N	PRESENT	0
358769	345219	19693L	PARTICIPANT	\N	PRESENT	0
358770	345219	19441R	PARTICIPANT	\N	PRESENT	0
358771	345219	07004J	PARTICIPANT	\N	PRESENT	0
358891	358890	01062T	PARTICIPANT	\N	PRESENT	0
358892	358890	95037J	PARTICIPANT	\N	PRESENT	0
358894	358893	98050T	PARTICIPANT	\N	PRESENT	0
358895	358893	01062T	PARTICIPANT	\N	PRESENT	0
358896	358893	95037J	PARTICIPANT	\N	PRESENT	0
358898	358897	98050T	PARTICIPANT	\N	PRESENT	0
358899	358897	01062T	PARTICIPANT	\N	PRESENT	0
358900	358897	95037J	PARTICIPANT	\N	PRESENT	0
358902	358901	14042U	PARTICIPANT	\N	PRESENT	0
361319	353832	01048V	PARTICIPANT	\N	PRESENT	0
361322	353832	19533U	PARTICIPANT	\N	PRESENT	0
361324	353832	14299H	PARTICIPANT	\N	PRESENT	0
361340	356666	11109J	PARTICIPANT	\N	PRESENT	0
361341	356666	14261S	PARTICIPANT	\N	PRESENT	0
361342	356666	19295A	PARTICIPANT	\N	PRESENT	0
361343	356666	19691J	PARTICIPANT	\N	PRESENT	0
361344	356666	14097Y	PARTICIPANT	\N	PRESENT	0
361345	356666	14059S	PARTICIPANT	\N	PRESENT	0
361346	356666	19729F	PARTICIPANT	\N	EXCUSE	0
361347	356666	08019V	PRESIDENT	0	PRESENT	0
361348	356666	19657G	PARTICIPANT	\N	PRESENT	0
361349	356666	96004D	PARTICIPANT	\N	EXCUSE	0
361350	356666	98005N	PARTICIPANT	\N	EXCUSE	0
361353	361352	14103D	PARTICIPANT	\N	PRESENT	0
361354	361352	14329V	PARTICIPANT	\N	PRESENT	0
361355	361352	08055A	PARTICIPANT	\N	PRESENT	0
361356	361352	19739H	PARTICIPANT	\N	PRESENT	0
334087	318810	11083R	PARTICIPANT	\N	PRESENT	0
334089	334088	14053L	PARTICIPANT	\N	PRESENT	0
335528	326855	19349W	PARTICIPANT	\N	PRESENT	0
335529	332424	19713W	PARTICIPANT	\N	PRESENT	0
336153	336152	11048N	PARTICIPANT	\N	PRESENT	0
336156	336155	08038Y	PARTICIPANT	\N	PRESENT	0
336157	336155	14051J	PARTICIPANT	\N	PRESENT	0
336158	336155	14227Q	PARTICIPANT	\N	PRESENT	0
338313	338312	19733B	PARTICIPANT	\N	PRESENT	0
338314	338312	19289C	PARTICIPANT	\N	PRESENT	0
338316	338315	19733B	PARTICIPANT	\N	PRESENT	0
338317	338315	19289C	PARTICIPANT	\N	PRESENT	0
338318	338315	19737F	PARTICIPANT	\N	PRESENT	0
338320	338319	19737F	PARTICIPANT	\N	PRESENT	0
338322	338321	19737F	PARTICIPANT	\N	PRESENT	0
338327	338326	19737F	PARTICIPANT	\N	PRESENT	0
338329	338328	19637C	PARTICIPANT	\N	PRESENT	0
335183	332770	14327T	PRESIDENT	0	PRESENT	0
335184	332770	14331P	PARTICIPANT	\N	PRESENT	0
335185	332770	04071H	PARTICIPANT	\N	PRESENT	0
335186	332770	19479G	PARTICIPANT	\N	PRESENT	0
335187	332770	19711U	PARTICIPANT	\N	PRESENT	0
335188	332770	08034U	PARTICIPANT	\N	PRESENT	0
335189	332770	01057W	PARTICIPANT	\N	PRESENT	0
335190	332770	08011M	PARTICIPANT	\N	PRESENT	0
335191	332770	19671E	PARTICIPANT	\N	PRESENT	0
335192	332770	14173T	PARTICIPANT	\N	PRESENT	0
335193	332770	04086Q	PARTICIPANT	\N	PRESENT	0
335194	332770	07029T	PARTICIPANT	\N	PRESENT	0
335195	332770	14083S	PARTICIPANT	\N	PRESENT	0
335196	332770	14085U	PARTICIPANT	\N	PRESENT	0
335197	332770	07004J	PARTICIPANT	\N	PRESENT	0
335198	332770	14253S	PARTICIPANT	\N	PRESENT	0
335199	332770	99004R	PARTICIPANT	\N	PRESENT	0
335527	332424	19467C	PARTICIPANT	\N	PRESENT	0
338330	338328	19737F	PARTICIPANT	\N	PRESENT	0
338332	338331	19737F	PARTICIPANT	\N	PRESENT	0
338333	338331	19637C	PARTICIPANT	\N	PRESENT	0
338334	338331	14231L	PARTICIPANT	\N	PRESENT	0
338336	338335	19347U	PARTICIPANT	\N	PRESENT	0
338337	338335	19637C	PARTICIPANT	\N	PRESENT	0
338338	338335	19737F	PARTICIPANT	\N	PRESENT	0
338342	338341	19737F	PARTICIPANT	\N	PRESENT	0
338345	338343	19733B	PARTICIPANT	\N	PRESENT	0
338346	338343	19737F	PARTICIPANT	\N	PRESENT	0
338349	338348	19333N	PARTICIPANT	\N	PRESENT	0
338350	338348	19737F	PARTICIPANT	\N	PRESENT	0
338351	338348	17583W	PARTICIPANT	\N	PRESENT	0
338353	338352	19333N	PARTICIPANT	\N	PRESENT	0
338354	338352	19737F	PARTICIPANT	\N	PRESENT	0
338358	338357	19333N	PARTICIPANT	\N	PRESENT	0
338359	338357	19737F	PARTICIPANT	\N	PRESENT	0
338360	338357	19551W	PARTICIPANT	\N	PRESENT	0
338363	338362	19737F	PARTICIPANT	\N	PRESENT	0
338365	338364	19551W	PARTICIPANT	\N	PRESENT	0
338366	338364	19737F	PARTICIPANT	\N	PRESENT	0
338368	338367	19737F	PARTICIPANT	\N	PRESENT	0
338370	338369	08055A	PARTICIPANT	\N	PRESENT	0
338371	338369	19737F	PARTICIPANT	\N	PRESENT	0
338373	338372	19737F	PARTICIPANT	\N	PRESENT	0
338375	338374	19737F	PARTICIPANT	\N	PRESENT	0
338380	338379	08055A	PARTICIPANT	\N	PRESENT	0
338381	338379	14105F	PARTICIPANT	\N	PRESENT	0
338382	338379	14207L	PARTICIPANT	\N	PRESENT	0
338383	338379	14085U	PARTICIPANT	\N	PRESENT	0
338384	338379	14038Y	PARTICIPANT	\N	PRESENT	0
338385	338379	11027H	PARTICIPANT	\N	PRESENT	0
338386	338379	14213J	PARTICIPANT	\N	PRESENT	0
338387	338379	16685X	PARTICIPANT	\N	PRESENT	0
338388	338379	19369B	PARTICIPANT	\N	PRESENT	0
338389	338379	14109K	PARTICIPANT	\N	PRESENT	0
338390	338379	14265W	PARTICIPANT	\N	PRESENT	0
338391	338379	14107H	PARTICIPANT	\N	PRESENT	0
338392	338379	11097X	PARTICIPANT	\N	PRESENT	0
338393	338379	19669L	PARTICIPANT	\N	PRESENT	0
338394	338379	19575F	PARTICIPANT	\N	PRESENT	0
340077	339473	14087W	PARTICIPANT	\N	EXCUSE	0
340078	339473	98024R	PARTICIPANT	\N	EXCUSE	0
340079	339473	19703U	PARTICIPANT	\N	EXCUSE	0
340080	339473	04045F	PARTICIPANT	\N	EXCUSE	0
341027	340388	04092N	PARTICIPANT	\N	PRESENT	0
341028	340388	14042U	PARTICIPANT	\N	PRESENT	0
341029	340388	19715Y	PARTICIPANT	\N	PRESENT	0
341030	340388	19717B	PARTICIPANT	\N	PRESENT	0
341031	340388	08041T	PARTICIPANT	\N	EXCUSE	0
341032	340388	08052W	PARTICIPANT	\N	PRESENT	0
341033	340388	14281W	PARTICIPANT	\N	PRESENT	0
341034	340388	11103C	PARTICIPANT	\N	PRESENT	0
341035	340388	14213J	PARTICIPANT	\N	PRESENT	0
341036	340388	19367Y	PARTICIPANT	\N	PRESENT	0
341037	340388	14071N	PARTICIPANT	\N	PRESENT	0
341038	340388	14217N	PARTICIPANT	\N	PRESENT	0
341039	340388	19577H	PARTICIPANT	\N	PRESENT	0
341040	340388	19683J	PARTICIPANT	\N	PRESENT	0
341041	340388	10006L	PARTICIPANT	\N	PRESENT	0
341042	340388	98024R	PARTICIPANT	\N	PRESENT	0
341043	340388	19521Q	PARTICIPANT	\N	PRESENT	0
341044	340388	19697Q	PARTICIPANT	\N	PRESENT	0
341045	340388	01034P	PARTICIPANT	\N	PRESENT	0
341046	340388	11067R	PARTICIPANT	\N	PRESENT	0
341047	340388	19569H	PARTICIPANT	\N	PRESENT	0
341048	340388	19703U	PARTICIPANT	\N	PRESENT	0
341049	340388	11097X	PARTICIPANT	\N	PRESENT	0
341050	340388	19415P	PARTICIPANT	\N	PRESENT	0
341051	340388	14223L	PARTICIPANT	\N	PRESENT	0
341052	340388	14227Q	PARTICIPANT	\N	PRESENT	0
341053	340388	17779H	PARTICIPANT	\N	PRESENT	0
341054	340388	19679N	PARTICIPANT	\N	PRESENT	0
341055	340388	19301E	PARTICIPANT	\N	PRESENT	0
341056	340388	19691J	PARTICIPANT	\N	PRESENT	0
341057	340388	19723Y	PARTICIPANT	\N	PRESENT	0
341058	340388	19727D	PARTICIPANT	\N	PRESENT	0
341059	340388	19760E	PARTICIPANT	\N	PRESENT	0
341065	340388	14026U	PARTICIPANT	\N	PRESENT	0
341066	340388	08048B	PARTICIPANT	\N	PRESENT	0
341067	340388	19657G	PARTICIPANT	\N	PRESENT	0
341068	340388	11031D	PARTICIPANT	\N	PRESENT	0
341069	340388	19527W	PARTICIPANT	\N	PRESENT	0
341070	340388	19575F	PARTICIPANT	\N	PRESENT	0
341071	340388	19553Y	PARTICIPANT	\N	PRESENT	0
341072	340388	19565D	PARTICIPANT	\N	PRESENT	0
341073	340388	19533U	PARTICIPANT	\N	PRESENT	0
341074	340388	14237S	PARTICIPANT	\N	PRESENT	0
341075	340388	08051V	PARTICIPANT	\N	PRESENT	0
341076	340388	14119M	PARTICIPANT	\N	PRESENT	0
341077	340388	11077T	PARTICIPANT	\N	PRESENT	0
341078	340388	14030Q	PARTICIPANT	\N	PRESENT	0
341080	341062	01060R	PARTICIPANT	\N	PRESENT	0
341081	341062	19543W	PARTICIPANT	\N	PRESENT	0
341082	341062	19581D	PARTICIPANT	\N	PRESENT	0
341083	341062	04044E	PARTICIPANT	\N	PRESENT	0
341084	341062	19585H	PARTICIPANT	\N	PRESENT	0
341085	341062	19673G	PARTICIPANT	\N	PRESENT	0
341086	341062	01028R	PARTICIPANT	\N	PRESENT	0
341087	341062	05008E	PRESIDENT	0	PRESENT	0
341088	341062	19447X	PARTICIPANT	\N	PRESENT	0
341089	341062	19489J	PARTICIPANT	\N	PRESENT	0
341090	341062	14041T	PARTICIPANT	\N	PRESENT	0
341091	341062	14147R	PARTICIPANT	\N	PRESENT	0
341092	341062	14179A	PARTICIPANT	\N	PRESENT	0
341093	341062	14151M	PARTICIPANT	\N	PRESENT	0
341094	341062	14215L	PARTICIPANT	\N	PRESENT	0
341095	341062	11072N	PARTICIPANT	\N	PRESENT	0
341096	341062	08051V	PARTICIPANT	\N	PRESENT	0
341097	341062	14053L	PARTICIPANT	\N	PRESENT	0
341098	341062	98035U	PARTICIPANT	\N	PRESENT	0
341099	341062	19649G	PARTICIPANT	\N	PRESENT	0
341100	341062	14065Q	PARTICIPANT	\N	PRESENT	0
341101	341062	14111D	PARTICIPANT	\N	PRESENT	0
341102	341062	07034Q	PARTICIPANT	\N	PRESENT	0
341103	341062	10015M	PARTICIPANT	\N	PRESENT	0
341104	341062	11026G	PARTICIPANT	\N	PRESENT	0
341105	341062	08045X	PARTICIPANT	\N	PRESENT	0
341106	341062	01024M	PARTICIPANT	\N	PRESENT	0
341107	341062	04038G	PARTICIPANT	\N	PRESENT	0
341108	341062	19719D	PARTICIPANT	\N	PRESENT	0
341109	341062	11033F	PARTICIPANT	\N	PRESENT	0
341110	341062	19725B	PARTICIPANT	\N	PRESENT	0
341111	341062	19729F	PARTICIPANT	\N	PRESENT	0
341112	341062	95063L	PARTICIPANT	\N	PRESENT	0
341113	341062	19629C	PARTICIPANT	\N	PRESENT	0
341114	341062	14069U	PARTICIPANT	\N	PRESENT	0
341115	341062	11085T	PARTICIPANT	\N	PRESENT	0
341116	341062	11049P	PARTICIPANT	\N	PRESENT	0
341117	341062	19762G	PARTICIPANT	\N	PRESENT	0
341118	341062	14021P	PARTICIPANT	\N	PRESENT	0
341119	341062	08044W	PARTICIPANT	\N	EXCUSE	0
341175	340488	08009T	PRESIDENT	0	PRESENT	0
341176	340488	14103D	PARTICIPANT	\N	EXCUSE	0
356137	356136	04044E	PARTICIPANT	\N	PRESENT	0
356144	356143	08024S	PARTICIPANT	\N	PRESENT	0
356145	356143	10006L	PARTICIPANT	\N	PRESENT	0
356146	356143	14219Q	PARTICIPANT	\N	PRESENT	0
356147	356143	01058X	PARTICIPANT	\N	PRESENT	0
356148	356143	04043D	PARTICIPANT	\N	PRESENT	0
356149	356143	98005N	PARTICIPANT	\N	PRESENT	0
356151	356150	11043H	PARTICIPANT	\N	PRESENT	0
356081	345111	14069U	PARTICIPANT	\N	PRESENT	0
356135	356134	04044E	PARTICIPANT	\N	PRESENT	0
356152	356150	19711U	PARTICIPANT	\N	PRESENT	0
356153	356150	08012N	PARTICIPANT	\N	PRESENT	0
356154	356150	14063N	PARTICIPANT	\N	PRESENT	0
356155	356150	19631V	PARTICIPANT	\N	PRESENT	0
356156	356150	14030Q	PARTICIPANT	\N	PRESENT	0
356157	356150	14105F	PARTICIPANT	\N	PRESENT	0
356158	356150	11048N	PARTICIPANT	\N	PRESENT	0
356159	356150	19699S	PARTICIPANT	\N	PRESENT	0
356160	356150	14169X	PARTICIPANT	\N	PRESENT	0
356161	356150	19349W	PARTICIPANT	\N	PRESENT	0
356162	356150	19533U	PARTICIPANT	\N	PRESENT	0
356257	356256	01034P	PARTICIPANT	\N	PRESENT	0
356349	351756	19647E	PARTICIPANT	\N	EXCUSE	0
356350	351756	08069G	PARTICIPANT	\N	EXCUSE	0
356351	351756	11066Q	PARTICIPANT	\N	PRESENT	0
356352	356267	96004D	PARTICIPANT	\N	EXCUSE	0
356353	356267	19295A	PARTICIPANT	\N	EXCUSE	0
356354	356267	14199E	PARTICIPANT	\N	EXCUSE	0
356355	356267	19715Y	PARTICIPANT	\N	EXCUSE	0
356356	356267	19729F	PARTICIPANT	\N	EXCUSE	0
356357	356267	14275Y	PARTICIPANT	\N	EXCUSE	0
356360	351756	11097X	PARTICIPANT	\N	PRESENT	0
356437	351756	08062Y	PARTICIPANT	\N	PRESENT	0
356667	351756	19569H	PARTICIPANT	\N	EXCUSE	0
356827	355955	19697Q	PARTICIPANT	\N	PRESENT	0
356828	355955	19569H	PARTICIPANT	\N	PRESENT	0
356829	355955	04045F	PARTICIPANT	\N	PRESENT	0
356830	355955	14026U	PARTICIPANT	\N	PRESENT	0
356831	355955	14227Q	PARTICIPANT	\N	PRESENT	0
356832	355955	19675J	PARTICIPANT	\N	PRESENT	0
356833	355955	14239U	PARTICIPANT	\N	PRESENT	0
356834	355955	19703U	PARTICIPANT	\N	PRESENT	0
356835	355955	11031D	PARTICIPANT	\N	PRESENT	0
356836	355955	14281W	PARTICIPANT	\N	PRESENT	0
356837	355955	19679N	PARTICIPANT	\N	PRESENT	0
356838	355955	14195A	PARTICIPANT	\N	PRESENT	0
356839	355955	19575F	PARTICIPANT	\N	PRESENT	0
356840	355955	19367Y	PARTICIPANT	\N	PRESENT	0
356841	355955	14213J	PARTICIPANT	\N	PRESENT	0
356842	355955	19683J	PARTICIPANT	\N	PRESENT	0
356843	355955	19521Q	PARTICIPANT	\N	PRESENT	0
356844	355955	01034P	PARTICIPANT	\N	PRESENT	0
356845	355955	04092N	PRESIDENT	0	PRESENT	0
356846	355955	08052W	PARTICIPANT	\N	PRESENT	0
356847	355955	19301E	PARTICIPANT	\N	PRESENT	0
356848	355955	19691J	PARTICIPANT	\N	PRESENT	0
356849	355955	19727D	PARTICIPANT	\N	PRESENT	0
356850	355955	11103C	PARTICIPANT	\N	PRESENT	0
356851	355955	14071N	PARTICIPANT	\N	PRESENT	0
356852	355955	08041T	PARTICIPANT	\N	EXCUSE	0
356856	355955	11097X	PARTICIPANT	\N	PRESENT	0
356857	355955	17779H	PARTICIPANT	\N	PRESENT	0
356858	355955	19553Y	PARTICIPANT	\N	PRESENT	0
356859	355955	14042U	PARTICIPANT	\N	PRESENT	0
356860	355955	14217N	PARTICIPANT	\N	PRESENT	0
356861	355955	98024R	PARTICIPANT	\N	PRESENT	0
356862	355955	19713W	PARTICIPANT	\N	PRESENT	0
356863	355955	19723Y	PARTICIPANT	\N	PRESENT	0
356864	355955	14119M	PARTICIPANT	\N	PRESENT	0
356866	356330	14111D	PARTICIPANT	\N	PRESENT	0
356867	356330	19649G	PARTICIPANT	\N	PRESENT	0
356868	356330	10015M	PARTICIPANT	\N	PRESENT	0
356869	356330	19253P	PARTICIPANT	\N	PRESENT	0
356870	356330	19543W	PARTICIPANT	\N	PRESENT	0
356871	356330	04038G	PARTICIPANT	\N	PRESENT	0
356872	356330	04044E	PARTICIPANT	\N	PRESENT	0
356873	356330	19585H	PARTICIPANT	\N	PRESENT	0
356874	356330	11033F	PARTICIPANT	\N	PRESENT	0
356875	356330	19447X	PARTICIPANT	\N	PRESENT	0
356876	356330	05008E	PRESIDENT	0	PRESENT	0
356877	356330	19629C	PARTICIPANT	\N	PRESENT	0
356878	356330	08044W	PARTICIPANT	\N	PRESENT	0
356879	356330	14179A	PARTICIPANT	\N	PRESENT	0
356880	356330	11072N	PARTICIPANT	\N	PRESENT	0
356881	356330	19729F	PARTICIPANT	\N	EXCUSE	0
356882	356330	08018U	PARTICIPANT	\N	EXCUSE	0
356883	356330	14001X	PARTICIPANT	\N	PRESENT	0
356884	356330	19673G	PARTICIPANT	\N	PRESENT	0
356885	356330	01028R	PARTICIPANT	\N	PRESENT	0
356886	356330	19489J	PARTICIPANT	\N	PRESENT	0
356887	356330	14151M	PARTICIPANT	\N	PRESENT	0
356888	356330	14053L	PARTICIPANT	\N	PRESENT	0
356889	356330	14065Q	PARTICIPANT	\N	PRESENT	0
356890	356330	01024M	PARTICIPANT	\N	PRESENT	0
356891	356330	14089Y	PARTICIPANT	\N	PRESENT	0
356892	356330	95063L	PARTICIPANT	\N	PRESENT	0
356893	356330	04008A	PARTICIPANT	\N	PRESENT	0
356894	356330	08045X	PARTICIPANT	\N	PRESENT	0
356895	355935	19443T	PARTICIPANT	\N	PRESENT	0
356896	355935	14133K	PARTICIPANT	\N	PRESENT	0
356897	355935	01062T	PARTICIPANT	\N	PRESENT	0
356898	355935	04034C	PARTICIPANT	\N	PRESENT	0
356899	355935	14235Q	PARTICIPANT	\N	PRESENT	0
356900	355935	14079W	PARTICIPANT	\N	PRESENT	0
356901	355935	01058X	PARTICIPANT	\N	PRESENT	0
356902	355935	16685X	PARTICIPANT	\N	PRESENT	0
356903	355935	08058D	PARTICIPANT	\N	PRESENT	0
356904	355935	04042C	PRESIDENT	0	PRESENT	0
356905	355935	14028W	PARTICIPANT	\N	PRESENT	0
356906	355935	19251M	PARTICIPANT	\N	PRESENT	0
356907	355935	11066Q	PARTICIPANT	\N	PRESENT	0
356908	355935	08056B	PARTICIPANT	\N	PRESENT	0
356909	355935	95037J	PARTICIPANT	\N	PRESENT	0
356910	355935	19421M	PARTICIPANT	\N	PRESENT	0
356911	355935	98022P	PARTICIPANT	\N	PRESENT	0
356912	355935	14267Y	PARTICIPANT	\N	PRESENT	0
356913	355935	98050T	PARTICIPANT	\N	PRESENT	0
356914	355935	08053X	PARTICIPANT	\N	PRESENT	0
356915	355935	97011G	PARTICIPANT	\N	PRESENT	0
356916	355935	08047A	PARTICIPANT	\N	PRESENT	0
356941	355935	95067Q	PARTICIPANT	\N	PRESENT	0
356942	356853	19697Q	PARTICIPANT	\N	PRESENT	0
356943	356853	19569H	PARTICIPANT	\N	PRESENT	0
356944	356853	11097X	PARTICIPANT	\N	PRESENT	0
356945	356853	04045F	PARTICIPANT	\N	PRESENT	0
356946	356853	14223L	PARTICIPANT	\N	PRESENT	0
356947	356853	14026U	PARTICIPANT	\N	PRESENT	0
356948	356853	14227Q	PARTICIPANT	\N	PRESENT	0
356949	356853	19675J	PARTICIPANT	\N	PRESENT	0
356950	356853	17779H	PARTICIPANT	\N	PRESENT	0
356951	356853	11031D	PARTICIPANT	\N	PRESENT	0
356952	356853	19553Y	PARTICIPANT	\N	PRESENT	0
356953	356853	14239U	PARTICIPANT	\N	PRESENT	0
356954	356853	19703U	PARTICIPANT	\N	PRESENT	0
356955	356853	14281W	PARTICIPANT	\N	PRESENT	0
356956	356853	14087W	PARTICIPANT	\N	PRESENT	0
356957	356853	19679N	PARTICIPANT	\N	PRESENT	0
356958	356853	14042U	PARTICIPANT	\N	PRESENT	0
356959	356853	14195A	PARTICIPANT	\N	PRESENT	0
356960	356853	19575F	PARTICIPANT	\N	PRESENT	0
356961	356853	08048B	PARTICIPANT	\N	PRESENT	0
356962	356853	19367Y	PARTICIPANT	\N	PRESENT	0
356963	356853	14213J	PARTICIPANT	\N	PRESENT	0
356964	356853	14217N	PARTICIPANT	\N	PRESENT	0
356965	356853	19683J	PARTICIPANT	\N	PRESENT	0
356966	356853	10006L	PARTICIPANT	\N	PRESENT	0
356967	356853	19521Q	PARTICIPANT	\N	PRESENT	0
356968	356853	98024R	PARTICIPANT	\N	PRESENT	0
356969	356853	01034P	PARTICIPANT	\N	PRESENT	0
356970	356853	04092N	PARTICIPANT	\N	PRESENT	0
356971	356853	11045K	PARTICIPANT	\N	PRESENT	0
356972	356853	08052W	PARTICIPANT	\N	PRESENT	0
356973	356853	19301E	PARTICIPANT	\N	PRESENT	0
356974	356853	19691J	PARTICIPANT	\N	PRESENT	0
356975	356853	19723Y	PARTICIPANT	\N	PRESENT	0
356976	356853	19727D	PARTICIPANT	\N	PRESENT	0
356977	356853	14119M	PARTICIPANT	\N	PRESENT	0
356978	356853	11103C	PARTICIPANT	\N	PRESENT	0
356979	356853	14071N	PARTICIPANT	\N	PRESENT	0
356981	355935	11027H	PARTICIPANT	\N	PRESENT	0
357187	357100	14327T	PARTICIPANT	\N	PRESENT	0
357188	357100	01048V	PARTICIPANT	\N	PRESENT	0
357189	357100	19545Y	PARTICIPANT	\N	PRESENT	0
357190	357100	11053K	PARTICIPANT	\N	PRESENT	0
357191	357100	89017R	PARTICIPANT	\N	PRESENT	0
357192	357100	19667J	PARTICIPANT	\N	PRESENT	0
357193	357100	11074Q	PRESIDENT	0	PRESENT	0
357194	357100	14225N	PARTICIPANT	\N	PRESENT	0
357195	357100	19671E	PARTICIPANT	\N	PRESENT	0
334412	334410	11103C	PRESIDENT	0	PRESENT	0
338470	338469	98035U	PARTICIPANT	\N	PRESENT	0
338471	338469	14111D	PARTICIPANT	\N	PRESENT	0
338472	338469	08045X	PARTICIPANT	\N	PRESENT	0
338473	338469	07034Q	PARTICIPANT	\N	PRESENT	0
338474	338469	01024M	PARTICIPANT	\N	PRESENT	0
338475	338469	04047H	PARTICIPANT	\N	PRESENT	0
338476	338469	01028R	PARTICIPANT	\N	PRESENT	0
338477	338469	05008E	PRESIDENT	0	PRESENT	0
338478	338469	19725B	PARTICIPANT	\N	PRESENT	0
338479	338469	19489J	PARTICIPANT	\N	PRESENT	0
338480	338469	14041T	PARTICIPANT	\N	PRESENT	0
338481	338469	14147R	PARTICIPANT	\N	PRESENT	0
338482	338469	14151M	PARTICIPANT	\N	PRESENT	0
338483	338469	14069U	PARTICIPANT	\N	PRESENT	0
338484	338469	11072N	PARTICIPANT	\N	PRESENT	0
338485	338469	19762G	PARTICIPANT	\N	PRESENT	0
338486	338469	19729F	PARTICIPANT	\N	EXCUSE	0
338487	338469	08044W	PARTICIPANT	\N	EXCUSE	0
338488	338469	04044E	PARTICIPANT	\N	EXCUSE	0
338490	337910	08041T	PARTICIPANT	\N	EXCUSE	0
338491	338217	04059M	PARTICIPANT	\N	PRESENT	0
338492	337910	19703U	PARTICIPANT	\N	PRESENT	0
338493	337910	04092N	PRESIDENT	0	PRESENT	0
338494	337910	11097X	PARTICIPANT	\N	PRESENT	0
338495	337910	19367Y	PARTICIPANT	\N	PRESENT	0
338496	337910	11067R	PARTICIPANT	\N	PRESENT	0
338497	337910	11045K	PARTICIPANT	\N	PRESENT	0
338498	337910	14239U	PARTICIPANT	\N	PRESENT	0
338499	337910	08052W	PARTICIPANT	\N	PRESENT	0
338500	337910	14042U	PARTICIPANT	\N	PRESENT	0
338501	337910	19575F	PARTICIPANT	\N	PRESENT	0
338502	337910	14223L	PARTICIPANT	\N	PRESENT	0
338503	337910	11031D	PARTICIPANT	\N	PRESENT	0
338504	337910	14217N	PARTICIPANT	\N	PRESENT	0
338505	337910	19697Q	PARTICIPANT	\N	PRESENT	0
338506	337910	01034P	PARTICIPANT	\N	PRESENT	0
338507	337910	19727D	PARTICIPANT	\N	PRESENT	0
338508	337910	19723Y	PARTICIPANT	\N	PRESENT	0
338509	337910	19760E	PARTICIPANT	\N	PRESENT	0
338510	337910	14026U	PARTICIPANT	\N	PRESENT	0
338511	337910	98024R	PARTICIPANT	\N	PRESENT	0
338512	337910	14213J	PARTICIPANT	\N	PRESENT	0
338513	337910	19679N	PARTICIPANT	\N	PRESENT	0
338514	337910	19663E	PARTICIPANT	\N	PRESENT	0
338515	337910	17779H	PARTICIPANT	\N	PRESENT	0
340150	338404	19697Q	PARTICIPANT	\N	PRESENT	0
340151	338404	01034P	PARTICIPANT	\N	PRESENT	0
340152	338404	11067R	PARTICIPANT	\N	PRESENT	0
340153	338404	04092N	PRESIDENT	0	PRESENT	0
340154	338404	11097X	PARTICIPANT	\N	PRESENT	0
340155	338404	11045K	PARTICIPANT	\N	PRESENT	0
340156	338404	08052W	PARTICIPANT	\N	PRESENT	0
340157	338404	14026U	PARTICIPANT	\N	PRESENT	0
340158	338404	17779H	PARTICIPANT	\N	PRESENT	0
340159	338404	19727D	PARTICIPANT	\N	PRESENT	0
340160	338404	14239U	PARTICIPANT	\N	PRESENT	0
340161	338404	19703U	PARTICIPANT	\N	PRESENT	0
340162	338404	11031D	PARTICIPANT	\N	PRESENT	0
340163	338404	14119M	PARTICIPANT	\N	PRESENT	0
340164	338404	14281W	PARTICIPANT	\N	PRESENT	0
340165	338404	19575F	PARTICIPANT	\N	PRESENT	0
340166	338404	14217N	PARTICIPANT	\N	PRESENT	0
340167	338404	19683J	PARTICIPANT	\N	PRESENT	0
340168	338404	10006L	PARTICIPANT	\N	PRESENT	0
340169	338404	19760E	PARTICIPANT	\N	PRESENT	0
340170	338404	19521Q	PARTICIPANT	\N	PRESENT	0
340171	338404	98024R	PARTICIPANT	\N	PRESENT	0
340172	338404	14087W	PARTICIPANT	\N	EXCUSE	0
340173	338404	14213J	PARTICIPANT	\N	EXCUSE	0
340174	338404	04045F	PARTICIPANT	\N	EXCUSE	0
340175	338404	08041T	PARTICIPANT	\N	EXCUSE	0
340298	338403	14087W	PARTICIPANT	\N	EXCUSE	0
340299	338403	04045F	PARTICIPANT	\N	EXCUSE	0
348105	346332	19329S	PARTICIPANT	\N	EXCUSE	0
348106	346332	19577H	PARTICIPANT	\N	EXCUSE	0
348107	346332	19729F	PARTICIPANT	\N	EXCUSE	0
350506	339552	04044E	PARTICIPANT	\N	PRESENT	0
350508	339552	19695N	PARTICIPANT	\N	PRESENT	0
350509	339552	12041X	PARTICIPANT	\N	PRESENT	0
350510	339552	19715Y	PARTICIPANT	\N	PRESENT	0
350511	339552	14121F	PARTICIPANT	\N	PRESENT	0
350512	339552	14063N	PARTICIPANT	\N	PRESENT	0
350513	339552	11066Q	PARTICIPANT	\N	PRESENT	0
350514	339552	04034C	PARTICIPANT	\N	PRESENT	0
350515	339552	14107H	PARTICIPANT	\N	PRESENT	0
350516	339552	19553Y	PARTICIPANT	\N	PRESENT	0
350517	339552	19441R	PARTICIPANT	\N	PRESENT	0
350518	339552	19583F	PARTICIPANT	\N	PRESENT	0
350519	339552	11040E	PARTICIPANT	\N	PRESENT	0
350520	339552	14261S	PARTICIPANT	\N	PRESENT	0
350521	339552	98005N	PARTICIPANT	\N	PRESENT	0
350522	339552	14157T	PARTICIPANT	\N	PRESENT	0
350523	339552	19319Q	PARTICIPANT	\N	PRESENT	0
350524	339552	07029T	PARTICIPANT	\N	PRESENT	0
350525	339552	14219Q	PARTICIPANT	\N	PRESENT	0
350526	339552	14041T	PARTICIPANT	\N	PRESENT	0
350527	339552	04018C	PARTICIPANT	\N	PRESENT	0
350528	339552	14083S	PARTICIPANT	\N	PRESENT	0
350529	339552	19731Y	PARTICIPANT	\N	PRESENT	0
350530	339552	19399H	PARTICIPANT	\N	PRESENT	0
350531	339552	14255U	PARTICIPANT	\N	PRESENT	0
350532	339552	19515S	PARTICIPANT	\N	PRESENT	0
350533	339552	19794Q	PARTICIPANT	\N	PRESENT	0
350534	339552	11097X	PARTICIPANT	\N	PRESENT	0
350535	339552	19741B	PARTICIPANT	\N	PRESENT	0
350536	339552	19697Q	PARTICIPANT	\N	PRESENT	0
350537	339552	08068F	PARTICIPANT	\N	PRESENT	0
350538	339552	14227Q	PARTICIPANT	\N	PRESENT	0
350539	339552	14133K	PARTICIPANT	\N	PRESENT	0
350543	339552	19701S	PARTICIPANT	\N	PRESENT	0
350541	339552	08049C	PARTICIPANT	\N	PRESENT	0
350542	339552	11012A	PARTICIPANT	\N	PRESENT	0
350544	339552	19369B	PARTICIPANT	\N	PRESENT	0
350545	339552	14038Y	PARTICIPANT	\N	PRESENT	0
350546	348035	14030Q	PARTICIPANT	\N	PRESENT	0
350547	346333	11109J	PARTICIPANT	\N	PRESENT	0
350548	346333	19691J	PARTICIPANT	\N	PRESENT	0
350549	346333	98005N	PARTICIPANT	\N	PRESENT	0
350550	346333	08019V	PRESIDENT	0	PRESENT	0
350551	346333	19301E	PARTICIPANT	\N	PRESENT	0
350552	346333	19319Q	PARTICIPANT	\N	PRESENT	0
350553	339552	19651A	PARTICIPANT	\N	PRESENT	0
350554	346333	14229S	PARTICIPANT	\N	PRESENT	0
350555	339552	19667J	PARTICIPANT	\N	PRESENT	0
350557	346333	04059M	PARTICIPANT	\N	PRESENT	0
350558	339552	19521Q	PARTICIPANT	\N	PRESENT	0
350559	339552	04092N	PARTICIPANT	\N	PRESENT	0
350575	339552	19681G	PARTICIPANT	\N	PRESENT	0
350576	339552	19711U	PARTICIPANT	\N	PRESENT	0
350577	339552	14215L	PARTICIPANT	\N	PRESENT	0
350582	339552	08034U	PARTICIPANT	\N	PRESENT	0
350583	339552	99004R	PARTICIPANT	\N	PRESENT	0
350594	339552	14034U	PARTICIPANT	\N	PRESENT	0
350596	339552	19563B	PARTICIPANT	\N	PRESENT	0
350597	339552	11090Q	PARTICIPANT	\N	PRESENT	0
350602	339552	01048V	PARTICIPANT	\N	PRESENT	0
350656	339553	11072N	PARTICIPANT	\N	PRESENT	0
350657	348095	14071N	PARTICIPANT	\N	PRESENT	0
350658	339553	14227Q	PARTICIPANT	\N	PRESENT	0
350659	339553	14041T	PARTICIPANT	\N	PRESENT	0
350660	339553	19731Y	PARTICIPANT	\N	PRESENT	0
350661	339553	19711U	PARTICIPANT	\N	PRESENT	0
350665	339553	14157T	PARTICIPANT	\N	PRESENT	0
350666	339553	19583F	PARTICIPANT	\N	PRESENT	0
350858	341994	14239U	PARTICIPANT	\N	PRESENT	0
350859	341994	01048V	PARTICIPANT	\N	PRESENT	0
350860	341994	04043D	PARTICIPANT	\N	PRESENT	0
350869	332565	19399H	PARTICIPANT	\N	EXCUSE	0
350870	332565	11066Q	PARTICIPANT	\N	EXCUSE	0
350890	332565	19467C	PARTICIPANT	\N	PRESENT	0
350891	332565	19349W	PARTICIPANT	\N	PRESENT	0
350977	350976	19649G	PARTICIPANT	\N	PRESENT	0
350973	350972	19649G	PARTICIPANT	\N	PRESENT	0
350975	350974	19649G	PARTICIPANT	\N	PRESENT	0
350979	350978	19649G	PARTICIPANT	\N	PRESENT	0
350987	350986	19621T	PARTICIPANT	\N	PRESENT	0
350988	350986	19611R	PARTICIPANT	\N	PRESENT	0
350989	350986	19533U	PARTICIPANT	\N	PRESENT	0
350990	350986	19693L	PARTICIPANT	\N	PRESENT	0
350991	350986	14229S	PARTICIPANT	\N	PRESENT	0
350993	350992	19621T	PARTICIPANT	\N	PRESENT	0
350994	350992	19611R	PARTICIPANT	\N	PRESENT	0
350995	350992	19533U	PARTICIPANT	\N	PRESENT	0
351252	350910	08009T	PARTICIPANT	\N	PRESENT	0
351253	350910	14061L	PARTICIPANT	\N	PRESENT	0
351254	350910	14059S	PARTICIPANT	\N	PRESENT	0
351255	350910	04040A	PARTICIPANT	\N	PRESENT	0
351256	350910	01043Q	PARTICIPANT	\N	PRESENT	0
358984	358983	14179A	PARTICIPANT	\N	PRESENT	0
358985	358983	08044W	PARTICIPANT	\N	PRESENT	0
358986	358983	14115H	PARTICIPANT	\N	PRESENT	0
358987	358983	14215L	PARTICIPANT	\N	PRESENT	0
358988	358983	19545Y	PARTICIPANT	\N	PRESENT	0
358989	358983	19741B	PARTICIPANT	\N	PRESENT	0
358990	358983	19367Y	PARTICIPANT	\N	PRESENT	0
358991	358983	10015M	PARTICIPANT	\N	PRESENT	0
358992	358983	04049K	PARTICIPANT	\N	PRESENT	0
358993	358983	19289C	PARTICIPANT	\N	PRESENT	0
358994	358983	19643A	PARTICIPANT	\N	PRESENT	0
358995	358983	18083K	PARTICIPANT	\N	PRESENT	0
358996	358983	08039A	PARTICIPANT	\N	PRESENT	0
358997	358983	04018C	PARTICIPANT	\N	PRESENT	0
358998	358983	04070G	PARTICIPANT	\N	PRESENT	0
358999	358983	19647E	PARTICIPANT	\N	PRESENT	0
359000	358983	14021P	PARTICIPANT	\N	PRESENT	0
359001	358983	14041T	PARTICIPANT	\N	PRESENT	0
359690	345222	19479G	PARTICIPANT	\N	PRESENT	0
359691	345222	19441R	PARTICIPANT	\N	PRESENT	0
359692	345222	19723Y	PARTICIPANT	\N	PRESENT	0
359693	345222	19713W	PARTICIPANT	\N	PRESENT	0
359694	345222	08056B	PARTICIPANT	\N	PRESENT	0
359695	345222	19467C	PARTICIPANT	\N	PRESENT	0
359696	345222	19749K	PARTICIPANT	\N	PRESENT	0
359697	345222	14267Y	PARTICIPANT	\N	PRESENT	0
359698	345222	19415P	PARTICIPANT	\N	PRESENT	0
359699	345222	14221J	PARTICIPANT	\N	PRESENT	0
359700	345222	19741B	PARTICIPANT	\N	PRESENT	0
359701	345222	19739H	PARTICIPANT	\N	PRESENT	0
359702	345222	19335Q	PARTICIPANT	\N	PRESENT	0
359703	345222	14073Q	PARTICIPANT	\N	PRESENT	0
359704	345222	14033T	PARTICIPANT	\N	PRESENT	0
359705	345222	14083S	PARTICIPANT	\N	PRESENT	0
359706	345222	14135M	PARTICIPANT	\N	PRESENT	0
359707	345222	19745F	PARTICIPANT	\N	PRESENT	0
359708	345222	14089Y	PARTICIPANT	\N	PRESENT	0
359709	345222	19521Q	PARTICIPANT	\N	PRESENT	0
359710	345222	08019V	PARTICIPANT	\N	PRESENT	0
359711	345222	07004J	PARTICIPANT	\N	PRESENT	0
359712	345222	14255U	PARTICIPANT	\N	PRESENT	0
359713	345222	11085T	PARTICIPANT	\N	PRESENT	0
359714	345222	19693L	PARTICIPANT	\N	PRESENT	0
359715	345222	11115U	PARTICIPANT	\N	PRESENT	0
359716	345222	19577H	PARTICIPANT	\N	PRESENT	0
359717	345222	18083K	PARTICIPANT	\N	PRESENT	0
359718	345222	04040A	PARTICIPANT	\N	PRESENT	0
359719	345222	04070G	PARTICIPANT	\N	PRESENT	0
359720	345222	11109J	PARTICIPANT	\N	PRESENT	0
359721	345222	14265W	PARTICIPANT	\N	PRESENT	0
359722	345222	11070L	PARTICIPANT	\N	PRESENT	0
359723	345222	01024M	PARTICIPANT	\N	PRESENT	0
359724	345222	14213J	PARTICIPANT	\N	PRESENT	0
359725	345222	01025N	PARTICIPANT	\N	PRESENT	0
359726	345222	14329V	PARTICIPANT	\N	PRESENT	0
359727	345222	14327T	PARTICIPANT	\N	PRESENT	0
359728	345222	19675J	PARTICIPANT	\N	PRESENT	0
359729	345222	14030Q	PARTICIPANT	\N	PRESENT	0
359730	345222	19383Y	PARTICIPANT	\N	PRESENT	0
359731	345222	01060R	PARTICIPANT	\N	PRESENT	0
359732	345222	08024S	PARTICIPANT	\N	PRESENT	0
359733	345222	19762G	PARTICIPANT	\N	PRESENT	0
359734	345222	04018C	PARTICIPANT	\N	PRESENT	0
359735	345222	19621T	PARTICIPANT	\N	PRESENT	0
359736	345222	19367Y	PARTICIPANT	\N	PRESENT	0
359737	345222	14237S	PARTICIPANT	\N	PRESENT	0
359738	345222	19443T	PARTICIPANT	\N	PRESENT	0
359739	345222	14029X	PARTICIPANT	\N	PRESENT	0
359740	345222	19663E	PARTICIPANT	\N	PRESENT	0
359741	345222	04088S	PARTICIPANT	\N	PRESENT	0
359742	345222	14041T	PARTICIPANT	\N	PRESENT	0
359743	345222	07029T	PARTICIPANT	\N	PRESENT	0
359744	345222	19657G	PARTICIPANT	\N	PRESENT	0
359745	345222	14355X	PARTICIPANT	\N	PRESENT	0
359746	345222	19729F	PARTICIPANT	\N	PRESENT	0
359747	345222	08015R	PARTICIPANT	\N	PRESENT	0
359748	345222	86034E	PARTICIPANT	\N	PRESENT	0
359749	345222	08048B	PARTICIPANT	\N	PRESENT	0
359750	345222	19705W	PARTICIPANT	\N	PRESENT	0
359751	345222	98050T	PARTICIPANT	\N	PRESENT	0
359752	345222	14061L	PARTICIPANT	\N	PRESENT	0
359753	345222	14059S	PARTICIPANT	\N	PRESENT	0
359754	345222	19733B	PARTICIPANT	\N	PRESENT	0
359755	345222	19503N	PARTICIPANT	\N	PRESENT	0
359756	345222	19701S	PARTICIPANT	\N	PRESENT	0
359760	345222	92040Q	PARTICIPANT	\N	PRESENT	0
359758	345222	14211G	PARTICIPANT	\N	PRESENT	0
359759	345222	14079W	PARTICIPANT	\N	PRESENT	0
359761	345222	11097X	PARTICIPANT	\N	PRESENT	0
359762	345222	04061F	PARTICIPANT	\N	PRESENT	0
360068	345223	04059M	PARTICIPANT	\N	PRESENT	0
360070	345223	04044E	PARTICIPANT	\N	PRESENT	0
360071	345223	19593H	PARTICIPANT	\N	PRESENT	0
360072	345223	19758L	PARTICIPANT	\N	PRESENT	0
360073	345223	19565D	PARTICIPANT	\N	PRESENT	0
360074	345223	14021P	PARTICIPANT	\N	PRESENT	0
360075	345223	08052W	PARTICIPANT	\N	PRESENT	0
360076	345223	19649G	PARTICIPANT	\N	PRESENT	0
360077	345223	80013X	PARTICIPANT	\N	PRESENT	0
360078	345223	11026G	PARTICIPANT	\N	PRESENT	0
360079	345223	14097Y	PARTICIPANT	\N	PRESENT	0
360080	345223	19329S	PARTICIPANT	\N	PRESENT	0
360081	345223	19585H	PARTICIPANT	\N	PRESENT	0
360082	345223	95063L	PARTICIPANT	\N	PRESENT	0
360083	345223	98029W	PARTICIPANT	\N	PRESENT	0
360084	345223	19563B	PARTICIPANT	\N	PRESENT	0
360085	345223	98022P	PARTICIPANT	\N	PRESENT	0
360086	345223	14241N	PARTICIPANT	\N	PRESENT	0
360087	345223	14239U	PARTICIPANT	\N	PRESENT	0
360088	345223	08031R	PARTICIPANT	\N	PRESENT	0
360089	345223	19253P	PARTICIPANT	\N	PRESENT	0
360090	345223	14089Y	PARTICIPANT	\N	PRESENT	0
360091	345223	14205J	PARTICIPANT	\N	PRESENT	0
360092	345223	05008E	PARTICIPANT	\N	PRESENT	0
360093	345223	88008L	PARTICIPANT	\N	PRESENT	0
360094	345223	11012A	PARTICIPANT	\N	PRESENT	0
360095	345223	19545Y	PARTICIPANT	\N	PRESENT	0
360096	345223	19747H	PARTICIPANT	\N	PRESENT	0
360097	345223	98050T	PARTICIPANT	\N	PRESENT	0
360098	345223	01048V	PARTICIPANT	\N	PRESENT	0
360099	345223	19711U	PARTICIPANT	\N	PRESENT	0
360100	345223	08034U	PARTICIPANT	\N	PRESENT	0
360102	345223	14217N	PARTICIPANT	\N	PRESENT	0
360103	345223	14331P	PARTICIPANT	\N	PRESENT	0
360104	345223	19762G	PARTICIPANT	\N	PRESENT	0
360105	345223	19383Y	PARTICIPANT	\N	PRESENT	0
360106	360101	14261S	PARTICIPANT	\N	PRESENT	0
360107	360101	14119M	PARTICIPANT	\N	PRESENT	0
360108	345223	19705W	PARTICIPANT	\N	PRESENT	0
360109	345223	19729F	PARTICIPANT	\N	PRESENT	0
360110	345223	19693L	PARTICIPANT	\N	PRESENT	0
360111	345223	07029T	PARTICIPANT	\N	PRESENT	0
360112	360101	04086Q	PARTICIPANT	\N	PRESENT	0
360113	345223	11083R	PARTICIPANT	\N	PRESENT	0
360114	345223	08019V	PARTICIPANT	\N	PRESENT	0
360115	345223	11049P	PARTICIPANT	\N	PRESENT	0
360116	345223	08047A	PARTICIPANT	\N	PRESENT	0
360117	345223	17583W	PARTICIPANT	\N	PRESENT	0
360118	345223	14213J	PARTICIPANT	\N	PRESENT	0
360119	345223	14265W	PARTICIPANT	\N	PRESENT	0
360120	345223	87003B	PARTICIPANT	\N	PRESENT	0
360121	345223	14157T	PARTICIPANT	\N	PRESENT	0
360123	345223	14119M	PARTICIPANT	\N	PRESENT	0
360124	345223	14033T	PARTICIPANT	\N	PRESENT	0
360125	360122	14261S	PARTICIPANT	\N	PRESENT	0
360126	345223	19415P	PARTICIPANT	\N	PRESENT	0
360127	360122	14119M	PARTICIPANT	\N	PRESENT	0
360128	345223	19467C	PARTICIPANT	\N	PRESENT	0
360129	345223	14029X	PARTICIPANT	\N	PRESENT	0
360130	345223	18083K	PARTICIPANT	\N	PRESENT	0
360131	345223	19443T	PARTICIPANT	\N	PRESENT	0
360133	360132	14261S	PARTICIPANT	\N	PRESENT	0
360134	360132	14119M	PARTICIPANT	\N	PRESENT	0
360135	345223	19447X	PARTICIPANT	\N	PRESENT	0
360136	345223	14173T	PARTICIPANT	\N	PRESENT	0
360137	345223	19794Q	PARTICIPANT	\N	PRESENT	0
360138	345223	19703U	PARTICIPANT	\N	PRESENT	0
360140	360139	14261S	PARTICIPANT	\N	PRESENT	0
360141	360139	14119M	PARTICIPANT	\N	PRESENT	0
360142	345223	19515S	PARTICIPANT	\N	PRESENT	0
360143	345223	11080N	PARTICIPANT	\N	PRESENT	0
360144	345223	19643A	PARTICIPANT	\N	PRESENT	0
360145	345223	08020N	PARTICIPANT	\N	PRESENT	0
360146	345223	11043H	PARTICIPANT	\N	PRESENT	0
360147	345223	14211G	PARTICIPANT	\N	PRESENT	0
360148	345223	95062K	PARTICIPANT	\N	PRESENT	0
360149	345223	99004R	PARTICIPANT	\N	PRESENT	0
360150	345223	96004D	PARTICIPANT	\N	PRESENT	0
335731	335703	19741B	PARTICIPANT	\N	PRESENT	0
341177	340488	19659J	PARTICIPANT	\N	EXCUSE	0
341178	341079	19766L	PARTICIPANT	\N	PRESENT	0
341179	341079	04070G	PRESIDENT	0	PRESENT	0
341180	341079	19699S	PARTICIPANT	\N	PRESENT	0
341181	341079	19533U	PARTICIPANT	\N	PRESENT	0
341182	341079	19329S	PARTICIPANT	\N	PRESENT	0
341183	341079	04033B	PARTICIPANT	\N	PRESENT	0
341184	341079	14229S	PARTICIPANT	\N	PRESENT	0
341185	341079	14039A	PARTICIPANT	\N	PRESENT	0
341186	341079	14107H	PARTICIPANT	\N	PRESENT	0
341187	341079	08017T	PARTICIPANT	\N	PRESENT	0
341188	341079	92040Q	PARTICIPANT	\N	PRESENT	0
341189	341079	07033P	PARTICIPANT	\N	PRESENT	0
341190	341079	19335Q	PARTICIPANT	\N	PRESENT	0
341191	341079	08039A	PARTICIPANT	\N	PRESENT	0
341192	341079	08031R	PARTICIPANT	\N	PRESENT	0
341193	341079	19593H	PARTICIPANT	\N	PRESENT	0
341194	341079	19643A	PARTICIPANT	\N	PRESENT	0
341195	341079	14059S	PARTICIPANT	\N	PRESENT	0
341196	341079	14061L	PARTICIPANT	\N	PRESENT	0
341197	341079	04057K	PARTICIPANT	\N	PRESENT	0
341198	341079	14073Q	PARTICIPANT	\N	PRESENT	0
341199	341079	19611R	PARTICIPANT	\N	PRESENT	0
341200	341079	19693L	PARTICIPANT	\N	PRESENT	0
341201	341079	19399H	PARTICIPANT	\N	PRESENT	0
341202	341079	87003B	PARTICIPANT	\N	PRESENT	0
341203	341079	14030Q	PARTICIPANT	\N	PRESENT	0
341204	341079	19731Y	PARTICIPANT	\N	PRESENT	0
341205	341079	04059M	PARTICIPANT	\N	PRESENT	0
341206	341079	11083R	PARTICIPANT	\N	PRESENT	0
341207	341079	14063N	PARTICIPANT	\N	PRESENT	0
341208	341079	11043H	PARTICIPANT	\N	PRESENT	0
341209	341079	19749K	PARTICIPANT	\N	PRESENT	0
341210	341079	04018C	PARTICIPANT	\N	PRESENT	0
341211	341079	19758L	PARTICIPANT	\N	PRESENT	0
341212	341079	19621T	PARTICIPANT	\N	PRESENT	0
341213	341079	14241N	PARTICIPANT	\N	PRESENT	0
341214	341079	19573D	PARTICIPANT	\N	PRESENT	0
341215	341079	08043V	PARTICIPANT	\N	PRESENT	0
341216	341079	14109K	PARTICIPANT	\N	PRESENT	0
341217	341079	14123H	PARTICIPANT	\N	PRESENT	0
341221	341079	08035V	PARTICIPANT	\N	PRESENT	0
341222	341079	14251Q	PARTICIPANT	\N	PRESENT	0
341223	341079	19735D	PARTICIPANT	\N	PRESENT	0
341224	341079	11109J	PARTICIPANT	\N	PRESENT	0
341225	341079	11104D	PARTICIPANT	\N	EXCUSE	0
341226	341062	04047H	PARTICIPANT	\N	PRESENT	0
341227	341062	14231L	PARTICIPANT	\N	PRESENT	0
341228	341062	08018U	PARTICIPANT	\N	PRESENT	0
341229	341062	14259Y	PARTICIPANT	\N	PRESENT	0
341230	341062	14089Y	PARTICIPANT	\N	PRESENT	0
341231	341062	04008A	PARTICIPANT	\N	PRESENT	0
341294	340488	05012A	PARTICIPANT	\N	PRESENT	0
341295	340488	11065P	PARTICIPANT	\N	PRESENT	0
341296	340488	14038Y	PARTICIPANT	\N	PRESENT	0
341297	340488	04097T	PARTICIPANT	\N	PRESENT	0
341298	340488	19745F	PARTICIPANT	\N	PRESENT	0
341299	340488	17583W	PARTICIPANT	\N	PRESENT	0
341300	340483	08049C	PARTICIPANT	\N	PRESENT	0
341301	340483	95067Q	PARTICIPANT	\N	PRESENT	0
341302	340488	19549D	PARTICIPANT	\N	PRESENT	0
341303	340488	19713W	PARTICIPANT	\N	PRESENT	0
341304	340483	11027H	PARTICIPANT	\N	PRESENT	0
341306	340488	19685L	PARTICIPANT	\N	EXCUSE	0
341353	340472	19269X	PARTICIPANT	\N	PRESENT	0
341354	340472	19619A	PARTICIPANT	\N	PRESENT	0
341355	340472	19563B	PARTICIPANT	\N	EXCUSE	0
341395	340484	08047A	PARTICIPANT	\N	PRESENT	0
341396	340488	19525U	PARTICIPANT	\N	PRESENT	0
341453	341450	19643A	PARTICIPANT	\N	PRESENT	0
341398	341079	14249W	PARTICIPANT	\N	PRESENT	0
341399	341079	08012N	PARTICIPANT	\N	EXCUSE	0
341451	341450	19667J	PARTICIPANT	\N	PRESENT	0
341452	341450	14069U	PARTICIPANT	\N	PRESENT	0
341454	341450	19467C	PARTICIPANT	\N	PRESENT	0
341456	341450	18083K	PARTICIPANT	\N	PRESENT	0
341458	341450	19507S	PARTICIPANT	\N	PRESENT	0
341459	341450	04097T	PARTICIPANT	\N	PRESENT	0
341460	341450	19447X	PARTICIPANT	\N	PRESENT	0
341461	341450	16685X	PARTICIPANT	\N	PRESENT	0
341462	341450	14205J	PARTICIPANT	\N	PRESENT	0
341463	341450	14265W	PARTICIPANT	\N	PRESENT	0
341464	341450	19745F	PARTICIPANT	\N	PRESENT	0
341465	341450	04088S	PARTICIPANT	\N	PRESENT	0
341466	341450	05012A	PARTICIPANT	\N	PRESENT	0
341467	341450	19735D	PARTICIPANT	\N	PRESENT	0
341468	341450	14135M	PARTICIPANT	\N	PRESENT	0
341469	340480	19565D	PARTICIPANT	\N	EXCUSE	0
341470	341450	19727D	PARTICIPANT	\N	PRESENT	0
341471	341450	14033T	PARTICIPANT	\N	PRESENT	0
341472	340488	19737F	PARTICIPANT	\N	PRESENT	0
341546	341545	12041X	PARTICIPANT	\N	PRESENT	0
341548	341547	12041X	PARTICIPANT	\N	PRESENT	0
341566	339496	95030B	PARTICIPANT	\N	PRESENT	0
341567	340564	19581D	PARTICIPANT	\N	PRESENT	0
341568	340564	04047H	PARTICIPANT	\N	PRESENT	0
341569	340564	19673G	PARTICIPANT	\N	PRESENT	0
341570	340564	01028R	PARTICIPANT	\N	PRESENT	0
341571	340564	05008E	PRESIDENT	0	PRESENT	0
341572	340564	19447X	PARTICIPANT	\N	PRESENT	0
341573	340564	14231L	PARTICIPANT	\N	PRESENT	0
341574	340564	19489J	PARTICIPANT	\N	PRESENT	0
341575	340564	14041T	PARTICIPANT	\N	PRESENT	0
341576	340564	14147R	PARTICIPANT	\N	PRESENT	0
341577	340564	14179A	PARTICIPANT	\N	PRESENT	0
341578	340564	14151M	PARTICIPANT	\N	PRESENT	0
341579	340564	14215L	PARTICIPANT	\N	PRESENT	0
341580	340564	14065Q	PARTICIPANT	\N	PRESENT	0
341581	340564	19649G	PARTICIPANT	\N	PRESENT	0
341582	340564	14111D	PARTICIPANT	\N	PRESENT	0
341583	340564	07034Q	PARTICIPANT	\N	PRESENT	0
341584	340564	08045X	PARTICIPANT	\N	PRESENT	0
341585	340564	01024M	PARTICIPANT	\N	PRESENT	0
341586	340564	19719D	PARTICIPANT	\N	PRESENT	0
341587	340564	11033F	PARTICIPANT	\N	PRESENT	0
341588	340564	19725B	PARTICIPANT	\N	PRESENT	0
341589	340564	14089Y	PARTICIPANT	\N	PRESENT	0
341590	340564	19729F	PARTICIPANT	\N	PRESENT	0
341591	340564	14069U	PARTICIPANT	\N	PRESENT	0
341592	340564	11049P	PARTICIPANT	\N	PRESENT	0
341593	340564	14021P	PARTICIPANT	\N	PRESENT	0
341605	339496	19301E	PARTICIPANT	\N	PRESENT	0
341606	339496	19735D	PARTICIPANT	\N	PRESENT	0
341607	339496	14028W	PARTICIPANT	\N	PRESENT	0
341608	339496	19758L	PARTICIPANT	\N	PRESENT	0
341610	339496	08012N	PARTICIPANT	\N	PRESENT	0
341611	339496	11067R	PARTICIPANT	\N	PRESENT	0
341612	339496	11027H	PARTICIPANT	\N	PRESENT	0
341613	339496	19747H	PARTICIPANT	\N	PRESENT	0
341614	339496	14267Y	PARTICIPANT	\N	PRESENT	0
341615	339496	80013X	PARTICIPANT	\N	PRESENT	0
341616	340480	14259Y	PARTICIPANT	\N	EXCUSE	0
341617	341473	89017R	PARTICIPANT	\N	PRESENT	0
341618	341473	14187A	PARTICIPANT	\N	PRESENT	0
341619	341473	11090Q	PARTICIPANT	\N	PRESENT	0
341620	339496	18083K	PARTICIPANT	\N	PRESENT	0
341621	339496	14265W	PARTICIPANT	\N	PRESENT	0
341622	339496	19507S	PARTICIPANT	\N	PRESENT	0
341623	340564	95062K	PARTICIPANT	\N	PRESENT	0
341624	340564	14223L	PARTICIPANT	\N	PRESENT	0
341625	340564	14237S	PARTICIPANT	\N	PRESENT	0
341626	340564	08061X	PARTICIPANT	\N	PRESENT	0
341627	340564	14259Y	PARTICIPANT	\N	PRESENT	0
341628	340564	17637T	PARTICIPANT	\N	PRESENT	0
341629	340564	08039A	PARTICIPANT	\N	PRESENT	0
341630	340564	08051V	PARTICIPANT	\N	PRESENT	0
341631	340564	14105F	PARTICIPANT	\N	PRESENT	0
341632	340564	14063N	PARTICIPANT	\N	PRESENT	0
341633	340564	08044W	PARTICIPANT	\N	EXCUSE	0
341634	339496	14042U	PARTICIPANT	\N	PRESENT	0
341635	339496	19701S	PARTICIPANT	\N	PRESENT	0
341636	339496	14195A	PARTICIPANT	\N	PRESENT	0
341640	339496	11031D	PARTICIPANT	\N	PRESENT	0
341645	339496	19415P	PARTICIPANT	\N	PRESENT	0
341646	339496	14069U	PARTICIPANT	\N	PRESENT	0
341647	339496	19553Y	PARTICIPANT	\N	PRESENT	0
357196	357100	11110B	PARTICIPANT	\N	PRESENT	0
357197	357100	07029T	PARTICIPANT	\N	PRESENT	0
357198	357100	14085U	PARTICIPANT	\N	PRESENT	0
357199	357100	14277B	PARTICIPANT	\N	PRESENT	0
357200	357100	19349W	PARTICIPANT	\N	PRESENT	0
357201	357100	08010L	PARTICIPANT	\N	PRESENT	0
357202	357100	14253S	PARTICIPANT	\N	PRESENT	0
357203	357100	19479G	PARTICIPANT	\N	PRESENT	0
357204	357100	19647E	PARTICIPANT	\N	PRESENT	0
357205	357100	19711U	PARTICIPANT	\N	PRESENT	0
357206	357100	08034U	PARTICIPANT	\N	PRESENT	0
357207	357100	08069G	PARTICIPANT	\N	PRESENT	0
357208	357100	14187A	RAPPORTEUR_AVIS	\N	PRESENT	0
357209	357100	19687N	PARTICIPANT	\N	PRESENT	0
357210	357100	19689Q	PARTICIPANT	\N	PRESENT	0
357211	357100	14034U	PARTICIPANT	\N	PRESENT	0
357212	357100	14159V	PARTICIPANT	\N	PRESENT	0
357213	357100	14173T	PARTICIPANT	\N	PRESENT	0
357214	357100	11040E	PARTICIPANT	\N	PRESENT	0
357215	357100	04086Q	PARTICIPANT	\N	PRESENT	0
357216	357100	14083S	PARTICIPANT	\N	PRESENT	0
357217	357100	11012A	PARTICIPANT	\N	PRESENT	0
357218	357100	14121F	PARTICIPANT	\N	PRESENT	0
357219	357100	19741B	PARTICIPANT	\N	PRESENT	0
357220	357100	99004R	PARTICIPANT	\N	PRESENT	0
357221	357100	14331P	PARTICIPANT	\N	EXCUSE	0
357408	345117	19553Y	PARTICIPANT	\N	PRESENT	0
357409	357271	02002K	PARTICIPANT	\N	PRESENT	0
357410	345117	95063L	PARTICIPANT	\N	PRESENT	0
357411	345117	11090Q	PARTICIPANT	\N	PRESENT	0
357412	345117	04086Q	PARTICIPANT	\N	PRESENT	0
357413	345117	14223L	PARTICIPANT	\N	PRESENT	0
357414	345117	14281W	PARTICIPANT	\N	PRESENT	0
357415	345117	14231L	PARTICIPANT	\N	PRESENT	0
357416	345117	08024S	PARTICIPANT	\N	PRESENT	0
357417	345117	14069U	PARTICIPANT	\N	PRESENT	0
357418	345117	14034U	PARTICIPANT	\N	PRESENT	0
357419	345117	17779H	PARTICIPANT	\N	PRESENT	0
357420	345117	19745F	PARTICIPANT	\N	PRESENT	0
357421	345117	01024M	PARTICIPANT	\N	PRESENT	0
357425	345117	08017T	PARTICIPANT	\N	PRESENT	0
357426	345117	14109K	PARTICIPANT	\N	PRESENT	0
357427	345117	08038Y	PARTICIPANT	\N	PRESENT	0
357428	345117	08031R	PARTICIPANT	\N	PRESENT	0
357429	345117	19593H	PARTICIPANT	\N	PRESENT	0
357430	345117	19741B	PARTICIPANT	\N	PRESENT	0
357431	345117	11045K	PARTICIPANT	\N	PRESENT	0
357432	345117	19569H	PARTICIPANT	\N	PRESENT	0
357433	345117	19649G	PARTICIPANT	\N	PRESENT	0
357434	345117	14028W	PARTICIPANT	\N	PRESENT	0
357435	345117	19768N	PARTICIPANT	\N	PRESENT	0
357436	345117	19251M	PARTICIPANT	\N	PRESENT	0
357437	345117	14079W	PARTICIPANT	\N	PRESENT	0
357438	345117	14065Q	PARTICIPANT	\N	PRESENT	0
357439	345117	14197C	PARTICIPANT	\N	PRESENT	0
357440	345117	19479G	PARTICIPANT	\N	PRESENT	0
357441	345117	14135M	PARTICIPANT	\N	PRESENT	0
357442	345117	14115H	PARTICIPANT	\N	PRESENT	0
357443	345117	14081Q	PARTICIPANT	\N	PRESENT	0
357445	345117	11085T	PARTICIPANT	\N	PRESENT	0
357446	345117	19669L	PARTICIPANT	\N	PRESENT	0
357447	345117	14257W	PARTICIPANT	\N	PRESENT	0
357448	345117	11104D	PARTICIPANT	\N	PRESENT	0
357449	345117	14237S	PARTICIPANT	\N	PRESENT	0
357461	345117	14157T	PARTICIPANT	\N	PRESENT	0
357462	345117	14119M	PARTICIPANT	\N	PRESENT	0
357463	345117	14225N	PARTICIPANT	\N	PRESENT	0
357464	345117	19725B	PARTICIPANT	\N	PRESENT	0
357465	345117	11066Q	PARTICIPANT	\N	PRESENT	0
357466	345117	18083K	PARTICIPANT	\N	PRESENT	0
357467	345117	04049K	PARTICIPANT	\N	PRESENT	0
357468	345117	14097Y	PARTICIPANT	\N	PRESENT	0
357469	345117	19333N	PARTICIPANT	\N	PRESENT	0
357470	345117	17583W	PARTICIPANT	\N	PRESENT	0
357471	345117	14205J	PARTICIPANT	\N	PRESENT	0
357472	345117	10015M	PARTICIPANT	\N	PRESENT	0
357473	345117	19695N	PARTICIPANT	\N	PRESENT	0
357474	345117	19737F	PARTICIPANT	\N	PRESENT	0
357475	345117	14029X	PARTICIPANT	\N	PRESENT	0
357476	345117	19794Q	PARTICIPANT	\N	PRESENT	0
357477	345117	19719D	PARTICIPANT	\N	PRESENT	0
357478	345117	11099A	PARTICIPANT	\N	PRESENT	0
357479	345117	95062K	PARTICIPANT	\N	PRESENT	0
357480	345117	19573D	PARTICIPANT	\N	PRESENT	0
357481	345117	19747H	PARTICIPANT	\N	PRESENT	0
357482	345117	19387D	PARTICIPANT	\N	PRESENT	0
357583	345118	01043Q	PARTICIPANT	\N	PRESENT	0
357584	345118	14033T	PARTICIPANT	\N	PRESENT	0
357585	345118	14235Q	PARTICIPANT	\N	PRESENT	0
357586	345118	08024S	PARTICIPANT	\N	PRESENT	0
357587	345118	11056N	PARTICIPANT	\N	PRESENT	0
357588	345118	19695N	PARTICIPANT	\N	PRESENT	0
357589	345118	14281W	PARTICIPANT	\N	PRESENT	0
357590	345118	14197C	PARTICIPANT	\N	PRESENT	0
357591	345118	19333N	PARTICIPANT	\N	PRESENT	0
357592	345118	19413M	PARTICIPANT	\N	PRESENT	0
357593	345118	19549D	PARTICIPANT	\N	PRESENT	0
357594	345118	19669L	PARTICIPANT	\N	PRESENT	0
357595	345118	14021P	PARTICIPANT	\N	PRESENT	0
357596	345118	14109K	PARTICIPANT	\N	PRESENT	0
357600	345118	14207L	PARTICIPANT	\N	PRESENT	0
357598	345118	14097Y	PARTICIPANT	\N	PRESENT	0
357599	345118	19725B	PARTICIPANT	\N	PRESENT	0
357601	345118	08060W	PARTICIPANT	\N	PRESENT	0
357602	345118	19593H	PARTICIPANT	\N	PRESENT	0
357603	345118	19782L	PARTICIPANT	\N	PRESENT	0
357604	345118	11099A	PARTICIPANT	\N	PRESENT	0
357605	345118	14241N	PARTICIPANT	\N	PRESENT	0
357606	345118	17589D	PARTICIPANT	\N	PRESENT	0
357607	345118	19521Q	PARTICIPANT	\N	PRESENT	0
357608	345118	19479G	PARTICIPANT	\N	PRESENT	0
357609	345118	19713W	PARTICIPANT	\N	PRESENT	0
357610	345118	14231L	PARTICIPANT	\N	PRESENT	0
357611	345118	16685X	PARTICIPANT	\N	PRESENT	0
357612	345118	14083S	PARTICIPANT	\N	PRESENT	0
357613	345118	19737F	PARTICIPANT	\N	PRESENT	0
357614	345118	19719D	PARTICIPANT	\N	PRESENT	0
357615	345118	11012A	PARTICIPANT	\N	PRESENT	0
357617	345118	19349W	PARTICIPANT	\N	PRESENT	0
357618	345118	08017T	PARTICIPANT	\N	PRESENT	0
357619	345118	14219Q	PARTICIPANT	\N	PRESENT	0
357620	345118	14030Q	PARTICIPANT	\N	PRESENT	0
357621	345118	14103D	PARTICIPANT	\N	PRESENT	0
357622	345118	14073Q	PARTICIPANT	\N	PRESENT	0
357623	345118	14042U	PARTICIPANT	\N	PRESENT	0
357624	345118	14205J	PARTICIPANT	\N	PRESENT	0
357625	345118	19747H	PARTICIPANT	\N	PRESENT	0
357626	345118	14079W	PARTICIPANT	\N	PRESENT	0
357627	345118	19335Q	PARTICIPANT	\N	PRESENT	0
357628	345118	05008E	PARTICIPANT	\N	PRESENT	0
357629	345118	14215L	PARTICIPANT	\N	PRESENT	0
357630	345118	01024M	PARTICIPANT	\N	PRESENT	0
357631	345118	14053L	PARTICIPANT	\N	PRESENT	0
357632	345118	14087W	PARTICIPANT	\N	PRESENT	0
357633	345118	14187A	PARTICIPANT	\N	PRESENT	0
357634	345118	14223L	PARTICIPANT	\N	PRESENT	0
357635	345118	14059S	PARTICIPANT	\N	PRESENT	0
357636	345118	14061L	PARTICIPANT	\N	PRESENT	0
357637	345118	19768N	PARTICIPANT	\N	PRESENT	0
357638	345118	08062Y	PARTICIPANT	\N	PRESENT	0
357639	345118	07029T	PARTICIPANT	\N	PRESENT	0
357640	345118	19693L	PARTICIPANT	\N	PRESENT	0
357641	345118	14029X	PARTICIPANT	\N	PRESENT	0
357642	345118	11081P	PARTICIPANT	\N	PRESENT	0
357643	345118	19575F	PARTICIPANT	\N	PRESENT	0
357644	345118	17583W	PARTICIPANT	\N	PRESENT	0
357645	345118	95062K	PARTICIPANT	\N	PRESENT	0
357646	345118	19679N	PARTICIPANT	\N	PRESENT	0
357647	345118	14191V	PARTICIPANT	\N	PRESENT	0
357648	345118	19673G	PARTICIPANT	\N	PRESENT	0
357649	345118	14157T	PARTICIPANT	\N	PRESENT	0
357650	345118	14119M	PARTICIPANT	\N	PRESENT	0
357651	345118	19447X	PARTICIPANT	\N	PRESENT	0
357652	345118	19794Q	PARTICIPANT	\N	PRESENT	0
357653	345118	19467C	PARTICIPANT	\N	PRESENT	0
357654	345118	19741B	PARTICIPANT	\N	PRESENT	0
357655	345118	14135M	PARTICIPANT	\N	PRESENT	0
357656	345118	14211G	PARTICIPANT	\N	PRESENT	0
357657	357616	14073Q	PARTICIPANT	\N	PRESENT	0
357658	357616	19533U	PARTICIPANT	\N	PRESENT	0
357659	345118	01025N	PARTICIPANT	\N	PRESENT	0
357660	357616	08017T	PARTICIPANT	\N	PRESENT	0
357661	357616	19593H	PARTICIPANT	\N	PRESENT	0
357662	345118	19563B	PARTICIPANT	\N	PRESENT	0
357663	357616	14123H	PARTICIPANT	\N	PRESENT	0
357664	345118	08038Y	PARTICIPANT	\N	PRESENT	0
357665	345118	19629C	PARTICIPANT	\N	PRESENT	0
357666	345118	11090Q	PARTICIPANT	\N	PRESENT	0
357667	345118	19758L	PARTICIPANT	\N	PRESENT	0
340507	340397	14107H	PARTICIPANT	\N	PRESENT	0
340509	340397	11097X	PARTICIPANT	\N	PRESENT	0
340510	340397	08012N	PARTICIPANT	\N	EXCUSE	0
340517	340397	08045X	PARTICIPANT	\N	PRESENT	0
350060	350058	19507S	PARTICIPANT	\N	PRESENT	0
350061	350058	96004D	PRESIDENT	0	PRESENT	0
350062	350058	14255U	PARTICIPANT	\N	PRESENT	0
350063	350058	04035D	PRESIDENT	1	PRESENT	0
350064	350058	98022P	PARTICIPANT	\N	EXCUSE	0
350065	350058	04097T	PARTICIPANT	\N	PRESENT	0
350066	350058	14073Q	PARTICIPANT	\N	PRESENT	0
350067	350058	04057K	PARTICIPANT	\N	EXCUSE	0
350068	350058	01062T	PARTICIPANT	\N	PRESENT	0
350069	350058	04042C	PARTICIPANT	\N	EXCUSE	0
350074	350058	98050T	PARTICIPANT	\N	EXCUSE	0
350076	350058	14133K	PARTICIPANT	\N	EXCUSE	0
351257	350910	14071N	PARTICIPANT	\N	PRESENT	0
351258	350910	14030Q	PARTICIPANT	\N	PRESENT	0
351259	350910	11097X	PARTICIPANT	\N	PRESENT	0
351260	350910	14327T	PARTICIPANT	\N	PRESENT	0
351261	350910	01025N	PARTICIPANT	\N	PRESENT	0
351262	350910	01024M	PARTICIPANT	\N	PRESENT	0
351263	350910	14255U	PARTICIPANT	\N	PRESENT	0
351264	350910	14193X	PARTICIPANT	\N	PRESENT	0
351265	350910	07004J	PARTICIPANT	\N	PRESENT	0
351266	350910	14277B	PARTICIPANT	\N	PRESENT	0
351267	350910	19735D	PARTICIPANT	\N	PRESENT	0
351268	350910	14073Q	PARTICIPANT	\N	PRESENT	0
351269	350910	19749K	PARTICIPANT	\N	PRESENT	0
351270	350910	19369B	PARTICIPANT	\N	PRESENT	0
351271	350910	14221J	PARTICIPANT	\N	PRESENT	0
351272	350910	19739H	PARTICIPANT	\N	PRESENT	0
351273	350910	19335Q	PARTICIPANT	\N	PRESENT	0
351274	350910	14103D	PARTICIPANT	\N	PRESENT	0
351275	350910	11053K	PARTICIPANT	\N	PRESENT	0
351276	350910	11110B	PARTICIPANT	\N	PRESENT	0
351277	350910	14089Y	PARTICIPANT	\N	PRESENT	0
351282	350910	01028R	PARTICIPANT	\N	PRESENT	0
351279	350910	19745F	PARTICIPANT	\N	PRESENT	0
351280	350910	19768N	PARTICIPANT	\N	PRESENT	0
351281	350910	19673G	PARTICIPANT	\N	PRESENT	0
351283	350910	11074Q	PARTICIPANT	\N	PRESENT	0
351284	350910	19581D	PARTICIPANT	\N	PRESENT	0
351285	350910	19687N	PARTICIPANT	\N	PRESENT	0
351286	350910	19441R	PARTICIPANT	\N	PRESENT	0
351287	350910	95037J	PARTICIPANT	\N	PRESENT	0
351288	350910	11072N	PARTICIPANT	\N	PRESENT	0
351289	350910	04038G	PARTICIPANT	\N	PRESENT	0
351290	350910	19681G	PARTICIPANT	\N	PRESENT	0
351303	350910	98022P	PARTICIPANT	\N	PRESENT	0
351292	350910	04008A	PARTICIPANT	\N	PRESENT	0
351293	350910	04057K	PARTICIPANT	\N	PRESENT	0
351294	350910	04097T	PARTICIPANT	\N	PRESENT	0
351295	350910	11064N	PARTICIPANT	\N	PRESENT	0
351296	350910	19333N	PARTICIPANT	\N	PRESENT	0
351308	350910	01062T	PARTICIPANT	\N	PRESENT	0
351298	350910	04049K	PARTICIPANT	\N	PRESENT	0
351299	350910	11048N	PARTICIPANT	\N	PRESENT	0
351300	350910	14001X	PARTICIPANT	\N	PRESENT	0
351301	350910	19701S	PARTICIPANT	\N	PRESENT	0
351302	350910	08060W	PARTICIPANT	\N	PRESENT	0
351304	350910	19521Q	PARTICIPANT	\N	PRESENT	0
351305	350910	14083S	PARTICIPANT	\N	PRESENT	0
351306	350910	08028W	PARTICIPANT	\N	PRESENT	0
351307	350910	11099A	PARTICIPANT	\N	PRESENT	0
351309	350910	14251Q	PARTICIPANT	\N	PRESENT	0
351310	350910	14205J	PARTICIPANT	\N	PRESENT	0
351311	350910	19611R	PARTICIPANT	\N	PRESENT	0
351315	350910	19489J	PARTICIPANT	\N	PRESENT	0
351313	350910	05008E	PARTICIPANT	\N	PRESENT	0
351314	350910	19713W	PARTICIPANT	\N	PRESENT	0
351316	350910	11085T	PARTICIPANT	\N	PRESENT	0
351317	350910	19699S	PARTICIPANT	\N	PRESENT	0
351318	350910	01034P	PARTICIPANT	\N	PRESENT	0
351319	350910	19782L	PARTICIPANT	\N	PRESENT	0
351320	350910	19347U	PARTICIPANT	\N	PRESENT	0
351321	350910	04070G	PARTICIPANT	\N	PRESENT	0
351322	350910	11070L	PARTICIPANT	\N	PRESENT	0
351323	350910	04071H	PARTICIPANT	\N	PRESENT	0
351324	350910	01048V	PARTICIPANT	\N	PRESENT	0
351325	350910	95067Q	PARTICIPANT	\N	PRESENT	0
351326	350910	08039A	PARTICIPANT	\N	PRESENT	0
351327	350910	88008L	PARTICIPANT	\N	PRESENT	0
351328	350910	98024R	PARTICIPANT	\N	PRESENT	0
351329	350910	08044W	PARTICIPANT	\N	PRESENT	0
351330	350910	14087W	PARTICIPANT	\N	PRESENT	0
351331	350910	19251M	PARTICIPANT	\N	PRESENT	0
351332	350910	19479G	PARTICIPANT	\N	PRESENT	0
351333	350910	11033F	PARTICIPANT	\N	PRESENT	0
351334	350910	19733B	PARTICIPANT	\N	PRESENT	0
351338	350910	11012A	PARTICIPANT	\N	PRESENT	0
351336	350910	11115U	PARTICIPANT	\N	PRESENT	0
351337	350910	19329S	PARTICIPANT	\N	PRESENT	0
351339	350910	04061F	PARTICIPANT	\N	PRESENT	0
351343	350910	14179A	PARTICIPANT	\N	PRESENT	0
351341	350910	08035V	PARTICIPANT	\N	PRESENT	0
351342	350910	14069U	PARTICIPANT	\N	PRESENT	0
351344	350910	02002K	PARTICIPANT	\N	PRESENT	0
351348	350910	14237S	PARTICIPANT	\N	PRESENT	0
351657	339556	04044E	PARTICIPANT	\N	PRESENT	0
351658	339556	05008E	PARTICIPANT	\N	PRESENT	0
351659	339556	01024M	PARTICIPANT	\N	PRESENT	0
351660	339556	04047H	PARTICIPANT	\N	PRESENT	0
351661	339556	80027E	PARTICIPANT	\N	PRESENT	0
351662	339556	14121F	PARTICIPANT	\N	PRESENT	0
351663	339556	80013X	PARTICIPANT	\N	PRESENT	0
351664	339556	01028R	PARTICIPANT	\N	PRESENT	0
351665	339556	08045X	PARTICIPANT	\N	PRESENT	0
351666	339556	14065Q	PARTICIPANT	\N	PRESENT	0
351667	339556	14081Q	PARTICIPANT	\N	PRESENT	0
351668	339556	19725B	PARTICIPANT	\N	PRESENT	0
351669	339556	19629C	PARTICIPANT	\N	PRESENT	0
351670	339556	14201E	PARTICIPANT	\N	PRESENT	0
351671	339556	98022P	PARTICIPANT	\N	PRESENT	0
351672	339556	11099A	PARTICIPANT	\N	PRESENT	0
351673	339556	02002K	PARTICIPANT	\N	PRESENT	0
351674	339556	19681G	PARTICIPANT	\N	PRESENT	0
351675	339556	19727D	PARTICIPANT	\N	PRESENT	0
351676	339556	17589D	PARTICIPANT	\N	PRESENT	0
351677	339556	19581D	PARTICIPANT	\N	PRESENT	0
351678	339556	14275Y	PARTICIPANT	\N	PRESENT	0
351679	339556	19319Q	PARTICIPANT	\N	PRESENT	0
351680	339556	19479G	PARTICIPANT	\N	PRESENT	0
351681	339556	11072N	PARTICIPANT	\N	PRESENT	0
351682	339556	19737F	PARTICIPANT	\N	PRESENT	0
351683	339556	14205J	PARTICIPANT	\N	PRESENT	0
351684	339556	04085P	PARTICIPANT	\N	PRESENT	0
351685	339556	19758L	PARTICIPANT	\N	PRESENT	0
351686	339556	11033F	PARTICIPANT	\N	PRESENT	0
351687	339556	19760E	PARTICIPANT	\N	PRESENT	0
351688	339556	95063L	PARTICIPANT	\N	PRESENT	0
351689	339556	19631V	PARTICIPANT	\N	PRESENT	0
351690	339556	14159V	PARTICIPANT	\N	PRESENT	0
351691	339556	14179A	PARTICIPANT	\N	PRESENT	0
351692	339556	08044W	PARTICIPANT	\N	PRESENT	0
351694	339556	14111D	PARTICIPANT	\N	PRESENT	0
351695	339556	14103D	PARTICIPANT	\N	PRESENT	0
351696	339556	14089Y	PARTICIPANT	\N	PRESENT	0
351697	339556	19745F	PARTICIPANT	\N	PRESENT	0
351698	339556	19747H	PARTICIPANT	\N	PRESENT	0
351699	339556	19301E	PARTICIPANT	\N	PRESENT	0
351700	339556	95030B	PARTICIPANT	\N	PRESENT	0
351701	339556	14069U	PARTICIPANT	\N	PRESENT	0
351702	339556	14237S	PARTICIPANT	\N	PRESENT	0
351703	339556	14223L	PARTICIPANT	\N	PRESENT	0
351704	339556	14265W	PARTICIPANT	\N	PRESENT	0
351705	339556	19768N	PARTICIPANT	\N	PRESENT	0
351706	339556	04049K	PARTICIPANT	\N	PRESENT	0
351707	339556	08062Y	PARTICIPANT	\N	PRESENT	0
351708	339556	19399H	PARTICIPANT	\N	PRESENT	0
351709	339556	19507S	PARTICIPANT	\N	PRESENT	0
351710	339556	14053L	PARTICIPANT	\N	PRESENT	0
351711	339556	19731Y	PARTICIPANT	\N	PRESENT	0
351712	339556	01060R	PARTICIPANT	\N	PRESENT	0
351713	339556	14041T	PARTICIPANT	\N	PRESENT	0
351714	339556	14029X	PARTICIPANT	\N	PRESENT	0
351715	339556	18083K	PARTICIPANT	\N	PRESENT	0
351716	339556	14038Y	PARTICIPANT	\N	PRESENT	0
351717	339556	14173T	PARTICIPANT	\N	PRESENT	0
351732	339556	04038G	PARTICIPANT	\N	PRESENT	0
351719	339556	01057W	PARTICIPANT	\N	PRESENT	0
351720	339556	14191V	PARTICIPANT	\N	PRESENT	0
351721	339556	19515S	PARTICIPANT	\N	PRESENT	0
351722	339556	15447F	PARTICIPANT	\N	PRESENT	0
351723	339556	08039A	PARTICIPANT	\N	PRESENT	0
351724	339556	19794Q	PARTICIPANT	\N	PRESENT	0
351733	339556	14267Y	PARTICIPANT	\N	PRESENT	0
351734	339556	19782L	PARTICIPANT	\N	PRESENT	0
357392	357391	14205J	PARTICIPANT	\N	PRESENT	0
357393	357391	14042U	PARTICIPANT	\N	PRESENT	0
357394	357391	14197C	PARTICIPANT	\N	PRESENT	0
357395	357391	97011G	PARTICIPANT	\N	PRESENT	0
357396	357391	14179A	PARTICIPANT	\N	PRESENT	0
357397	357391	19723Y	PARTICIPANT	\N	PRESENT	0
357399	357391	14265W	PARTICIPANT	\N	PRESENT	0
357400	357391	19745F	PARTICIPANT	\N	PRESENT	0
357401	357391	04088S	PARTICIPANT	\N	PRESENT	0
357402	357391	11097X	PARTICIPANT	\N	PRESENT	0
357423	357422	14205J	PARTICIPANT	\N	PRESENT	0
358927	356663	19717B	PARTICIPANT	\N	EXCUSE	0
358928	356663	19631V	PARTICIPANT	\N	EXCUSE	0
358929	356663	19659J	PARTICIPANT	\N	EXCUSE	0
358930	356663	19715Y	PARTICIPANT	\N	EXCUSE	0
358931	356663	19583F	PARTICIPANT	\N	EXCUSE	0
358932	356663	14275Y	PARTICIPANT	\N	EXCUSE	0
358933	356666	19717B	PARTICIPANT	\N	EXCUSE	0
358934	356666	19631V	PARTICIPANT	\N	EXCUSE	0
358935	356666	19715Y	PARTICIPANT	\N	EXCUSE	0
358936	356666	19659J	PARTICIPANT	\N	EXCUSE	0
358937	356666	14275Y	PARTICIPANT	\N	EXCUSE	0
358938	356666	19583F	PARTICIPANT	\N	EXCUSE	0
361508	356246	08062Y	PARTICIPANT	\N	EXCUSE	0
361509	356246	19421M	PARTICIPANT	\N	EXCUSE	0
361510	356246	19479G	PARTICIPANT	\N	PRESENT	0
361511	356246	19569H	PARTICIPANT	\N	EXCUSE	0
361547	356246	19467C	PARTICIPANT	\N	PRESENT	0
361548	356246	14147R	PARTICIPANT	\N	PRESENT	0
361549	356246	19369B	PARTICIPANT	\N	PRESENT	0
361606	356246	11066Q	PARTICIPANT	\N	PRESENT	0
361607	356246	08045X	PARTICIPANT	\N	EXCUSE	0
361628	356246	19647E	PARTICIPANT	\N	EXCUSE	0
361632	356246	11097X	PARTICIPANT	\N	EXCUSE	0
361684	361683	14026U	PARTICIPANT	\N	PRESENT	0
361685	361683	14053L	PARTICIPANT	\N	PRESENT	0
361686	361683	95063L	PARTICIPANT	\N	PRESENT	0
361737	345230	01024M	PARTICIPANT	\N	PRESENT	0
361738	345230	19667J	PARTICIPANT	\N	PRESENT	0
361739	345230	19758L	PARTICIPANT	\N	PRESENT	0
361740	345230	11066Q	PARTICIPANT	\N	PRESENT	0
361743	356246	04038G	PARTICIPANT	\N	PRESENT	0
361745	356246	19651A	PARTICIPANT	\N	EXCUSE	0
361744	356246	19713W	PARTICIPANT	\N	PRESENT	0
361746	356246	08069G	PARTICIPANT	\N	EXCUSE	0
361747	345230	14041T	PARTICIPANT	\N	PRESENT	0
361748	345230	14097Y	PARTICIPANT	\N	PRESENT	0
361749	345230	08052W	PARTICIPANT	\N	PRESENT	0
361750	345230	04034C	PARTICIPANT	\N	PRESENT	0
361751	345230	14179A	PARTICIPANT	\N	PRESENT	0
361752	345230	19631V	PARTICIPANT	\N	PRESENT	0
361755	345230	14169X	PARTICIPANT	\N	PRESENT	0
361756	345230	19711U	PARTICIPANT	\N	PRESENT	0
361757	361142	92040Q	PARTICIPANT	\N	EXCUSE	0
361758	345230	14030Q	PARTICIPANT	\N	PRESENT	0
361759	356246	19551W	PARTICIPANT	\N	EXCUSE	0
361760	345230	14239U	PARTICIPANT	\N	PRESENT	0
361761	345230	11115U	PARTICIPANT	\N	PRESENT	0
361763	345230	19581D	PARTICIPANT	\N	PRESENT	0
361765	361764	14329V	PARTICIPANT	\N	PRESENT	0
361766	361764	14103D	PARTICIPANT	\N	PRESENT	0
361768	361767	14329V	PARTICIPANT	\N	PRESENT	0
361769	361767	14103D	PARTICIPANT	\N	PRESENT	0
361773	361771	14103D	PARTICIPANT	\N	PRESENT	0
361774	361771	14329V	PARTICIPANT	\N	PRESENT	0
361775	345230	07033P	PARTICIPANT	\N	PRESENT	0
361777	345230	04043D	PARTICIPANT	\N	PRESENT	0
361778	361776	14103D	PARTICIPANT	\N	PRESENT	0
361779	361776	14329V	PARTICIPANT	\N	PRESENT	0
361780	345230	19719D	PARTICIPANT	\N	PRESENT	0
361781	345230	05008E	PARTICIPANT	\N	PRESENT	0
361782	345230	19721W	PARTICIPANT	\N	PRESENT	0
361821	361175	19713W	PARTICIPANT	\N	PRESENT	0
361822	361175	19383Y	PARTICIPANT	\N	PRESENT	0
361823	361175	02002K	PARTICIPANT	\N	PRESENT	0
361824	361175	19681G	PARTICIPANT	\N	PRESENT	0
361825	361175	17637T	PARTICIPANT	\N	PRESENT	0
361826	361175	14093U	PARTICIPANT	\N	PRESENT	0
361827	361175	04097T	PARTICIPANT	\N	PRESENT	0
361828	345231	86034E	PARTICIPANT	\N	PRESENT	0
361829	361175	80027E	PARTICIPANT	\N	PRESENT	0
361830	361175	14169X	PARTICIPANT	\N	PRESENT	0
361793	361175	19333N	PARTICIPANT	\N	PRESENT	0
361794	361175	17583W	PARTICIPANT	\N	PRESENT	0
361795	361175	19701S	PARTICIPANT	\N	PRESENT	0
361796	361175	19794Q	PARTICIPANT	\N	PRESENT	0
361797	361175	95062K	PARTICIPANT	\N	PRESENT	0
361798	361175	19549D	PARTICIPANT	\N	PRESENT	0
361799	361175	19387D	PARTICIPANT	\N	PRESENT	0
361800	361175	14219Q	PARTICIPANT	\N	PRESENT	0
361801	361175	19599P	PARTICIPANT	\N	PRESENT	0
361802	361175	19637C	PARTICIPANT	\N	PRESENT	0
361803	361175	18083K	PARTICIPANT	\N	PRESENT	0
361804	361175	14051J	PARTICIPANT	\N	PRESENT	0
361805	361175	08060W	PARTICIPANT	\N	PRESENT	0
361806	361175	08024S	PARTICIPANT	\N	PRESENT	0
361807	361175	11065P	PARTICIPANT	\N	PRESENT	0
361808	361175	19525U	PARTICIPANT	\N	PRESENT	0
361809	361175	14038Y	PRESIDENT	0	PRESENT	0
361810	361175	14103D	PARTICIPANT	\N	PRESENT	0
361811	361175	14031R	PARTICIPANT	\N	PRESENT	0
361812	361175	08055A	PARTICIPANT	\N	PRESENT	0
361813	361175	14029X	PARTICIPANT	\N	PRESENT	0
361814	361175	19737F	PARTICIPANT	\N	PRESENT	0
361815	361175	19739H	PARTICIPANT	\N	PRESENT	0
361816	361175	19745F	PARTICIPANT	\N	PRESENT	0
361817	361175	19659J	PARTICIPANT	\N	PRESENT	0
361818	361175	14237S	PARTICIPANT	\N	EXCUSE	0
361819	361175	19551W	PARTICIPANT	\N	PRESENT	0
361820	361175	19347U	PARTICIPANT	\N	PRESENT	0
361831	361175	08009T	PARTICIPANT	\N	EXCUSE	0
361832	361175	19685L	PARTICIPANT	\N	EXCUSE	0
361833	345231	19525U	PARTICIPANT	\N	PRESENT	0
361834	345231	14219Q	PARTICIPANT	\N	PRESENT	0
361835	345231	19681G	PARTICIPANT	\N	PRESENT	0
361836	345231	80027E	PARTICIPANT	\N	PRESENT	0
361837	345231	19581D	PARTICIPANT	\N	PRESENT	0
361838	345231	19367Y	PARTICIPANT	\N	PRESENT	0
361839	345231	95062K	PARTICIPANT	\N	PRESENT	0
361840	345231	14237S	PARTICIPANT	\N	PRESENT	0
361841	345231	19399H	PARTICIPANT	\N	PRESENT	0
361842	345231	19511N	PARTICIPANT	\N	PRESENT	0
361843	345231	19745F	PARTICIPANT	\N	PRESENT	0
361844	345231	14038Y	PARTICIPANT	\N	PRESENT	0
361845	345231	14031R	PARTICIPANT	\N	PRESENT	0
361846	345231	14261S	PARTICIPANT	\N	PRESENT	0
361847	345231	14079W	PARTICIPANT	\N	PRESENT	0
361848	345231	14217N	PARTICIPANT	\N	PRESENT	0
361849	345231	19383Y	PARTICIPANT	\N	PRESENT	0
361850	345231	14051J	PARTICIPANT	\N	PRESENT	0
361851	345231	04097T	PARTICIPANT	\N	PRESENT	0
361852	345231	19794Q	PARTICIPANT	\N	PRESENT	0
361853	345231	14041T	PARTICIPANT	\N	PRESENT	0
361854	345231	14169X	PARTICIPANT	\N	PRESENT	0
361855	345231	19737F	PARTICIPANT	\N	PRESENT	0
361856	345231	14105F	PARTICIPANT	\N	PRESENT	0
361857	345231	08052W	PARTICIPANT	\N	PRESENT	0
361858	345231	07033P	PARTICIPANT	\N	PRESENT	0
361865	345231	14211G	PARTICIPANT	\N	PRESENT	0
361867	345231	08020N	PARTICIPANT	\N	PRESENT	0
361868	345231	96004D	PARTICIPANT	\N	PRESENT	0
361869	345231	99004R	PARTICIPANT	\N	PRESENT	0
361870	345231	08010L	PARTICIPANT	\N	PRESENT	0
361871	345231	19643A	PARTICIPANT	\N	PRESENT	0
361872	345231	14259Y	PARTICIPANT	\N	PRESENT	0
361873	345231	10015M	PARTICIPANT	\N	PRESENT	0
361874	345231	08069G	PARTICIPANT	\N	PRESENT	0
361875	345231	04042C	PARTICIPANT	\N	PRESENT	0
361876	345231	08028W	PARTICIPANT	\N	PRESENT	0
361877	345231	87003B	PARTICIPANT	\N	PRESENT	0
361878	345231	01057W	PARTICIPANT	\N	PRESENT	0
361879	345231	19515S	PARTICIPANT	\N	PRESENT	0
361880	345231	19703U	PARTICIPANT	\N	PRESENT	0
361881	345231	19443T	PARTICIPANT	\N	PRESENT	0
361882	345231	14029X	PARTICIPANT	\N	PRESENT	0
361883	345231	04088S	PARTICIPANT	\N	PRESENT	0
361884	345231	07029T	PARTICIPANT	\N	PRESENT	0
361885	345231	08062Y	PARTICIPANT	\N	PRESENT	0
361886	345231	17637T	PARTICIPANT	\N	PRESENT	0
361887	345231	11048N	PARTICIPANT	\N	PRESENT	0
361888	345231	04049K	PARTICIPANT	\N	PRESENT	0
361889	345231	01043Q	PARTICIPANT	\N	PRESENT	0
361890	345231	04035D	PARTICIPANT	\N	PRESENT	0
340429	340428	14041T	PARTICIPANT	\N	PRESENT	0
340430	340428	98035U	PARTICIPANT	\N	PRESENT	0
341121	340388	19675J	PARTICIPANT	\N	EXCUSE	0
341122	340388	14355X	PARTICIPANT	\N	EXCUSE	0
341123	340388	04045F	PARTICIPANT	\N	PRESENT	0
341218	340388	14239U	PARTICIPANT	\N	PRESENT	0
341125	340391	19760E	PARTICIPANT	\N	PRESENT	0
341219	340391	14239U	PARTICIPANT	\N	PRESENT	0
341127	340391	19717B	PARTICIPANT	\N	PRESENT	0
341128	340391	19575F	PARTICIPANT	\N	PRESENT	0
341129	340391	19367Y	PARTICIPANT	\N	PRESENT	0
341130	340391	19415P	PARTICIPANT	\N	PRESENT	0
341131	340391	11103C	PARTICIPANT	\N	PRESENT	0
341132	340391	14195A	PARTICIPANT	\N	PRESENT	0
341133	340391	11031D	PARTICIPANT	\N	PRESENT	0
341134	340391	08052W	PARTICIPANT	\N	PRESENT	0
341135	340391	19663E	PARTICIPANT	\N	PRESENT	0
341136	340391	98024R	PARTICIPANT	\N	PRESENT	0
341137	340391	10006L	PARTICIPANT	\N	PRESENT	0
341138	340391	14217N	PARTICIPANT	\N	PRESENT	0
341139	340391	19577H	PARTICIPANT	\N	PRESENT	0
341140	340391	14042U	PARTICIPANT	\N	PRESENT	0
341141	340391	14281W	PARTICIPANT	\N	PRESENT	0
341142	340391	14087W	PARTICIPANT	\N	PRESENT	0
341143	340391	19521Q	PARTICIPANT	\N	PRESENT	0
341144	340391	14355X	PARTICIPANT	\N	EXCUSE	0
341145	340391	08048B	PARTICIPANT	\N	PRESENT	0
341146	340391	08041T	PARTICIPANT	\N	EXCUSE	0
341147	340391	19727D	PARTICIPANT	\N	PRESENT	0
341148	340391	14026U	PARTICIPANT	\N	PRESENT	0
341149	340391	19691J	PARTICIPANT	\N	PRESENT	0
341150	340391	19553Y	PARTICIPANT	\N	PRESENT	0
341151	340391	19569H	PARTICIPANT	\N	PRESENT	0
341152	340391	14213J	PARTICIPANT	\N	PRESENT	0
341153	340391	19715Y	PARTICIPANT	\N	PRESENT	0
341154	340391	19683J	PARTICIPANT	\N	PRESENT	0
341155	340391	19723Y	PARTICIPANT	\N	PRESENT	0
341156	340391	19697Q	PARTICIPANT	\N	PRESENT	0
341157	340391	11077T	PARTICIPANT	\N	PRESENT	0
341158	340391	17779H	PARTICIPANT	\N	PRESENT	0
341159	340391	19657G	PARTICIPANT	\N	PRESENT	0
341160	340391	11067R	PARTICIPANT	\N	PRESENT	0
341161	340391	14223L	PARTICIPANT	\N	PRESENT	0
341162	340391	04092N	PRESIDENT	0	PRESENT	0
341163	340391	14119M	PARTICIPANT	\N	PRESENT	0
341164	340391	14071N	PARTICIPANT	\N	PRESENT	0
341165	340391	19679N	PARTICIPANT	\N	PRESENT	0
341710	339497	11031D	PARTICIPANT	\N	PRESENT	0
341167	340391	11097X	PARTICIPANT	\N	PRESENT	0
341168	340391	04045F	PARTICIPANT	\N	PRESENT	0
341169	340391	19703U	PARTICIPANT	\N	PRESENT	0
341170	340391	19301E	PARTICIPANT	\N	PRESENT	0
341171	340391	19675J	PARTICIPANT	\N	EXCUSE	0
341172	340391	14227Q	PARTICIPANT	\N	PRESENT	0
341173	340391	19527W	PARTICIPANT	\N	PRESENT	0
341174	340391	01034P	PARTICIPANT	\N	PRESENT	0
341711	339497	19758L	PARTICIPANT	\N	PRESENT	0
341712	339497	08043V	PARTICIPANT	\N	PRESENT	0
341713	339497	19715Y	PARTICIPANT	\N	PRESENT	0
341717	339497	11066Q	PARTICIPANT	\N	PRESENT	0
341715	339497	08017T	PARTICIPANT	\N	PRESENT	0
341716	339497	80013X	PARTICIPANT	\N	PRESENT	0
341718	339497	19747H	PARTICIPANT	\N	PRESENT	0
341719	340564	19383Y	PARTICIPANT	\N	PRESENT	0
341720	340564	08018U	PARTICIPANT	\N	PRESENT	0
341721	340564	14097Y	PARTICIPANT	\N	PRESENT	0
341722	340564	11026G	PARTICIPANT	\N	PRESENT	0
341723	340564	11085T	PARTICIPANT	\N	PRESENT	0
341724	339497	19782L	PARTICIPANT	\N	PRESENT	0
341725	339497	14030Q	PARTICIPANT	\N	PRESENT	0
341726	339497	14039A	PARTICIPANT	\N	PRESENT	0
341727	339497	19701S	PARTICIPANT	\N	PRESENT	0
341728	339497	19301E	PARTICIPANT	\N	PRESENT	0
341729	339497	08024S	PARTICIPANT	\N	PRESENT	0
341730	339497	19731Y	PARTICIPANT	\N	PRESENT	0
341731	339497	19349W	PARTICIPANT	\N	PRESENT	0
341732	339497	19693L	PARTICIPANT	\N	PRESENT	0
341733	339497	19651A	PARTICIPANT	\N	PRESENT	0
341734	339497	14069U	PARTICIPANT	\N	PRESENT	0
341735	339497	08031R	PARTICIPANT	\N	PRESENT	0
341736	339497	18083K	PARTICIPANT	\N	PRESENT	0
341760	339497	19735D	PARTICIPANT	\N	PRESENT	0
341738	339497	04088S	PARTICIPANT	\N	PRESENT	0
341739	339497	19415P	PARTICIPANT	\N	PRESENT	0
341740	339497	19583F	PARTICIPANT	\N	PRESENT	0
341741	339497	14195A	PARTICIPANT	\N	PRESENT	0
341742	339497	19611R	PARTICIPANT	\N	PRESENT	0
341743	339497	14249W	PARTICIPANT	\N	PRESENT	0
341744	339497	19507S	PARTICIPANT	\N	PRESENT	0
341745	339497	14029X	PARTICIPANT	\N	PRESENT	0
341746	339497	04070G	PARTICIPANT	\N	PRESENT	0
341747	339497	19533U	PARTICIPANT	\N	PRESENT	0
341748	339497	14229S	PARTICIPANT	\N	PRESENT	0
341749	339497	14073Q	PARTICIPANT	\N	PRESENT	0
341750	339497	04057K	PARTICIPANT	\N	PRESENT	0
341751	339497	04038G	PARTICIPANT	\N	PRESENT	0
341752	339497	19621T	PARTICIPANT	\N	PRESENT	0
341706	339497	11072N	PARTICIPANT	\N	PRESENT	0
341709	339497	19593H	PARTICIPANT	\N	PRESENT	0
341753	339497	14109K	PARTICIPANT	\N	PRESENT	0
341756	339497	14123H	PARTICIPANT	\N	PRESENT	0
341757	339497	14042U	PARTICIPANT	\N	PRESENT	0
341758	339497	19553Y	PARTICIPANT	\N	PRESENT	0
341759	339497	11012A	PARTICIPANT	\N	PRESENT	0
341761	339497	14257W	PARTICIPANT	\N	PRESENT	0
341762	339497	01058X	PARTICIPANT	\N	PRESENT	0
341763	339497	88008L	PARTICIPANT	\N	PRESENT	0
341764	339497	19367Y	PARTICIPANT	\N	PRESENT	0
341765	339497	19643A	PARTICIPANT	\N	PRESENT	0
341766	339497	99004R	PARTICIPANT	\N	PRESENT	0
341767	339497	14105F	PARTICIPANT	\N	PRESENT	0
341768	339497	19369B	PARTICIPANT	\N	PRESENT	0
341769	339497	95030B	PARTICIPANT	\N	PRESENT	0
341770	339497	11067R	PARTICIPANT	\N	PRESENT	0
341771	339497	19727D	PARTICIPANT	\N	PRESENT	0
341772	339497	14213J	PARTICIPANT	\N	PRESENT	0
341773	339497	19575F	PARTICIPANT	\N	PRESENT	0
341774	339497	19577H	PARTICIPANT	\N	PRESENT	0
341775	339497	98022P	PARTICIPANT	\N	PRESENT	0
341776	339497	19713W	PARTICIPANT	\N	PRESENT	0
341777	339497	14115H	PARTICIPANT	\N	PRESENT	0
341778	339497	19723Y	PARTICIPANT	\N	PRESENT	0
341779	339497	11101A	PARTICIPANT	\N	PRESENT	0
341780	339497	19737F	PARTICIPANT	\N	PRESENT	0
341781	339497	14267Y	PARTICIPANT	\N	PRESENT	0
341782	339497	14031R	PARTICIPANT	\N	PRESENT	0
341783	339497	04045F	PARTICIPANT	\N	PRESENT	0
341784	339497	19717B	PARTICIPANT	\N	PRESENT	0
341786	339497	14265W	PARTICIPANT	\N	PRESENT	0
341844	339498	11072N	PARTICIPANT	\N	PRESENT	0
341845	339498	99004R	PARTICIPANT	\N	PRESENT	0
341846	339498	04045F	PARTICIPANT	\N	PRESENT	0
341847	339498	19651A	PARTICIPANT	\N	PRESENT	0
341848	339498	19349W	PARTICIPANT	\N	PRESENT	0
341849	339498	11066Q	PARTICIPANT	\N	PRESENT	0
341850	339498	19713W	PARTICIPANT	\N	PRESENT	0
341851	339498	14229S	PARTICIPANT	\N	PRESENT	0
341852	339498	11031D	PARTICIPANT	\N	PRESENT	0
341853	339498	19758L	PARTICIPANT	\N	PRESENT	0
341854	339498	19782L	PARTICIPANT	\N	PRESENT	0
341855	339498	14195A	PARTICIPANT	\N	PRESENT	0
341856	339498	19553Y	PARTICIPANT	\N	PRESENT	0
341857	339498	19717B	PARTICIPANT	\N	PRESENT	0
341858	339498	19737F	PARTICIPANT	\N	PRESENT	0
341859	339498	14267Y	PARTICIPANT	\N	PRESENT	0
341860	339498	19369B	PARTICIPANT	\N	PRESENT	0
341861	339498	19577H	PARTICIPANT	\N	PRESENT	0
341862	339498	19367Y	PARTICIPANT	\N	PRESENT	0
341863	339498	19621T	PARTICIPANT	\N	PRESENT	0
341864	339498	14249W	PARTICIPANT	\N	PRESENT	0
341865	339498	14265W	PARTICIPANT	\N	PRESENT	0
341866	339498	11067R	PARTICIPANT	\N	PRESENT	0
341867	339498	14109K	PARTICIPANT	\N	PRESENT	0
341868	339498	19507S	PARTICIPANT	\N	PRESENT	0
341869	339498	04088S	PARTICIPANT	\N	PRESENT	0
341870	339498	11101A	PARTICIPANT	\N	PRESENT	0
341871	339498	19415P	PARTICIPANT	\N	PRESENT	0
341872	339498	14029X	PARTICIPANT	\N	PRESENT	0
341873	339498	14115H	PARTICIPANT	\N	PRESENT	0
341874	339498	19575F	PARTICIPANT	\N	PRESENT	0
341875	339498	19727D	PARTICIPANT	\N	PRESENT	0
341876	339498	08024S	PARTICIPANT	\N	PRESENT	0
341877	339498	19467C	PARTICIPANT	\N	PRESENT	0
341878	339498	19479G	PARTICIPANT	\N	PRESENT	0
341879	339498	14187A	PARTICIPANT	\N	PRESENT	0
341880	339498	19383Y	PARTICIPANT	\N	PRESENT	0
341881	339498	14069U	PARTICIPANT	\N	PRESENT	0
341882	339498	14213J	PARTICIPANT	\N	PRESENT	0
341883	339498	04038G	PARTICIPANT	\N	PRESENT	0
357670	345118	08056B	PARTICIPANT	\N	PRESENT	0
357671	345118	19599P	PARTICIPANT	\N	PRESENT	0
357672	345118	19703U	PARTICIPANT	\N	PRESENT	0
357673	345118	19573D	PARTICIPANT	\N	PRESENT	0
357674	355936	19643A	PARTICIPANT	\N	PRESENT	0
357675	355936	95067Q	PARTICIPANT	\N	PRESENT	0
357676	355936	19443T	PARTICIPANT	\N	PRESENT	0
357677	355936	04034C	PARTICIPANT	\N	PRESENT	0
357678	355936	11041F	PARTICIPANT	\N	PRESENT	0
357679	355936	04033B	PARTICIPANT	\N	PRESENT	0
357680	355936	14079W	PARTICIPANT	\N	PRESENT	0
357681	355936	16685X	PARTICIPANT	\N	PRESENT	0
357682	355936	08058D	PARTICIPANT	\N	PRESENT	0
357683	355936	04042C	PRESIDENT	0	PRESENT	0
357684	355936	11066Q	PARTICIPANT	\N	PRESENT	0
357685	355936	95037J	PARTICIPANT	\N	PRESENT	0
357668	345118	19619A	PARTICIPANT	\N	PRESENT	0
357669	345118	19387D	PARTICIPANT	\N	PRESENT	0
357686	355936	14115H	PARTICIPANT	\N	PRESENT	0
357687	355936	19421M	PARTICIPANT	\N	PRESENT	0
357688	355936	14041T	PARTICIPANT	\N	PRESENT	0
357689	355936	98050T	PARTICIPANT	\N	PRESENT	0
357690	355936	97011G	PARTICIPANT	\N	PRESENT	0
357691	355936	14021P	PARTICIPANT	\N	PRESENT	0
357692	355936	19545Y	PARTICIPANT	\N	PRESENT	0
357693	345118	11045K	PARTICIPANT	\N	PRESENT	0
357694	355936	04070G	PARTICIPANT	\N	PRESENT	0
357695	355936	01058X	PARTICIPANT	\N	PRESENT	0
357696	355936	19647E	PARTICIPANT	\N	PRESENT	0
357697	355936	08044W	PARTICIPANT	\N	PRESENT	0
357698	355936	98022P	PARTICIPANT	\N	PRESENT	0
357699	355936	19741B	PARTICIPANT	\N	PRESENT	0
357700	355936	19367Y	PARTICIPANT	\N	PRESENT	0
357701	345118	14121F	PARTICIPANT	\N	PRESENT	0
357702	345118	11104D	PARTICIPANT	\N	PRESENT	0
357703	345118	19691J	PARTICIPANT	\N	PRESENT	0
357704	345118	14221J	PARTICIPANT	\N	PRESENT	0
357705	355936	14097Y	PARTICIPANT	\N	PRESENT	0
357706	355936	11048N	PARTICIPANT	\N	PRESENT	0
357707	355936	19251M	PARTICIPANT	\N	PRESENT	0
357712	351756	04038G	PARTICIPANT	\N	PRESENT	0
357714	351756	19711U	PARTICIPANT	\N	PRESENT	0
357715	351756	19349W	PARTICIPANT	\N	PRESENT	0
357716	351756	04061F	PARTICIPANT	\N	EXCUSE	0
358057	355936	11054L	PARTICIPANT	\N	EXCUSE	0
358055	355936	19583F	PARTICIPANT	\N	EXCUSE	0
358056	355936	19319Q	PARTICIPANT	\N	EXCUSE	0
358069	358068	14187A	PARTICIPANT	\N	PRESENT	0
358070	358068	89017R	PARTICIPANT	\N	PRESENT	0
358072	358068	19671E	PARTICIPANT	\N	PRESENT	0
358073	358068	14121F	PARTICIPANT	\N	PRESENT	0
358074	358068	08068F	PARTICIPANT	\N	PRESENT	0
358075	358068	14079W	PARTICIPANT	\N	PRESENT	0
358076	358068	14061L	PARTICIPANT	\N	PRESENT	0
358077	358068	14157T	PARTICIPANT	\N	PRESENT	0
358078	358068	14265W	PARTICIPANT	\N	PRESENT	0
358079	358068	19521Q	PARTICIPANT	\N	PRESENT	0
358080	358068	14083S	PARTICIPANT	\N	PRESENT	0
358081	358068	14227Q	PARTICIPANT	\N	PRESENT	0
358082	358068	08015R	PARTICIPANT	\N	PRESENT	0
358083	358068	16685X	PARTICIPANT	\N	PRESENT	0
358084	358068	04049K	PRESIDENT	0	PRESENT	0
358085	358068	14087W	PARTICIPANT	\N	PRESENT	0
358086	358068	19575F	PARTICIPANT	\N	PRESENT	0
358087	358068	14253S	PARTICIPANT	\N	PRESENT	0
358088	358068	14053L	PARTICIPANT	\N	PRESENT	0
358089	358068	04088S	PARTICIPANT	\N	PRESENT	0
358090	358068	14030Q	PARTICIPANT	\N	EXCUSE	0
358091	358068	08060W	PARTICIPANT	\N	EXCUSE	0
358092	358068	14105F	PARTICIPANT	\N	EXCUSE	0
358093	358068	14255U	PARTICIPANT	\N	EXCUSE	0
358094	358068	14329V	PARTICIPANT	\N	EXCUSE	0
358095	358068	14041T	PARTICIPANT	\N	EXCUSE	0
358096	358068	14026U	PARTICIPANT	\N	EXCUSE	0
358097	358068	11099A	PARTICIPANT	\N	EXCUSE	0
358098	358068	14205J	PARTICIPANT	\N	EXCUSE	0
358099	358068	08047A	PARTICIPANT	\N	EXCUSE	0
358100	358068	19669L	PARTICIPANT	\N	EXCUSE	0
358101	358068	14051J	PARTICIPANT	\N	EXCUSE	0
358102	358068	19527W	PARTICIPANT	\N	EXCUSE	0
358982	348020	11065P	PARTICIPANT	\N	PRESENT	0
360151	345223	14223L	PARTICIPANT	\N	PRESENT	0
360152	345223	01058X	PARTICIPANT	\N	PRESENT	0
360153	345223	04033B	PARTICIPANT	\N	PRESENT	0
360154	345223	14187A	PARTICIPANT	\N	PRESENT	0
360155	345223	14071N	PARTICIPANT	\N	PRESENT	0
360156	345223	14069U	PARTICIPANT	\N	PRESENT	0
360157	345223	11097X	PARTICIPANT	\N	PRESENT	0
360158	345223	14215L	PARTICIPANT	\N	PRESENT	0
360159	345223	01025N	PARTICIPANT	\N	PRESENT	0
360160	345223	14231L	PARTICIPANT	\N	PRESENT	0
360161	345223	14179A	PARTICIPANT	\N	PRESENT	0
360162	345223	19629C	PARTICIPANT	\N	PRESENT	0
360163	345223	14151M	PARTICIPANT	\N	PRESENT	0
360164	345223	14061L	PARTICIPANT	\N	PRESENT	0
360165	345223	19367Y	PARTICIPANT	\N	PRESENT	0
360166	345223	04088S	PARTICIPANT	\N	PRESENT	0
360167	345223	10006L	PARTICIPANT	\N	PRESENT	0
360168	345223	19687N	PARTICIPANT	\N	PRESENT	0
360169	345223	11031D	PARTICIPANT	\N	PRESENT	0
360170	345223	11033F	PARTICIPANT	\N	PRESENT	0
360171	345223	19760E	PARTICIPANT	\N	PRESENT	0
360172	345223	19611R	PARTICIPANT	\N	PRESENT	0
360173	345223	19679N	PARTICIPANT	\N	PRESENT	0
360174	345223	95030B	PARTICIPANT	\N	PRESENT	0
360175	345223	19681G	PARTICIPANT	\N	PRESENT	0
360176	345223	19553Y	PARTICIPANT	\N	PRESENT	0
360177	345223	14123H	PARTICIPANT	\N	PRESENT	0
360178	345223	14073Q	PARTICIPANT	\N	PRESENT	0
360179	345223	08038Y	PARTICIPANT	\N	PRESENT	0
360180	345223	19709B	PARTICIPANT	\N	PRESENT	0
360181	345223	19737F	PARTICIPANT	\N	PRESENT	0
360182	345223	14219Q	PARTICIPANT	\N	PRESENT	0
360183	345223	14147R	PARTICIPANT	\N	PRESENT	0
360184	345223	04049K	PARTICIPANT	\N	PRESENT	0
360185	345223	14053L	PARTICIPANT	\N	PRESENT	0
360187	360186	08052W	PARTICIPANT	\N	PRESENT	0
360188	360186	10006L	PARTICIPANT	\N	PRESENT	0
360189	360186	19553Y	PARTICIPANT	\N	PRESENT	0
360190	345223	02002K	PARTICIPANT	\N	PRESENT	0
360192	360191	08052W	PARTICIPANT	\N	PRESENT	0
360193	360191	10006L	PARTICIPANT	\N	PRESENT	0
360194	360191	19553Y	PARTICIPANT	\N	PRESENT	0
360196	360195	08052W	PARTICIPANT	\N	PRESENT	0
360197	360195	10006L	PARTICIPANT	\N	PRESENT	0
360198	360195	19553Y	PARTICIPANT	\N	PRESENT	0
360200	360199	08052W	PARTICIPANT	\N	PRESENT	0
360201	360199	10006L	PARTICIPANT	\N	PRESENT	0
360202	360199	19553Y	PARTICIPANT	\N	PRESENT	0
360203	345223	19782L	PARTICIPANT	\N	PRESENT	0
360204	345223	19349W	PARTICIPANT	\N	PRESENT	0
360206	360205	08052W	PARTICIPANT	\N	PRESENT	0
360207	360205	10006L	PARTICIPANT	\N	PRESENT	0
360208	360205	19553Y	PARTICIPANT	\N	PRESENT	0
360210	360209	08052W	PARTICIPANT	\N	PRESENT	0
360211	360209	10006L	PARTICIPANT	\N	PRESENT	0
360212	360209	19553Y	PARTICIPANT	\N	PRESENT	0
360213	345223	08045X	PARTICIPANT	\N	PRESENT	0
360214	345223	04085P	PARTICIPANT	\N	PRESENT	0
360216	360215	08052W	PARTICIPANT	\N	PRESENT	0
360217	360215	10006L	PARTICIPANT	\N	PRESENT	0
360218	360215	19553Y	PARTICIPANT	\N	PRESENT	0
360219	345223	14065Q	PARTICIPANT	\N	PRESENT	0
360220	345223	01028R	PARTICIPANT	\N	PRESENT	0
360221	345223	98024R	PARTICIPANT	\N	PRESENT	0
360222	345223	04018C	PARTICIPANT	\N	PRESENT	0
360223	345223	19399H	PARTICIPANT	\N	PRESENT	0
360224	345223	14031R	PARTICIPANT	\N	PRESENT	0
360225	345223	04097T	PARTICIPANT	\N	PRESENT	0
360227	360226	11097X	PARTICIPANT	\N	PRESENT	0
360228	345223	11072N	PARTICIPANT	\N	PRESENT	0
360230	360229	10006L	PARTICIPANT	\N	PRESENT	0
360231	360229	11097X	PARTICIPANT	\N	PRESENT	0
360232	345223	14135M	PARTICIPANT	\N	PRESENT	0
360233	345223	19549D	PARTICIPANT	\N	PRESENT	0
360234	345223	19651A	PARTICIPANT	\N	PRESENT	0
360235	345223	17779H	PARTICIPANT	\N	PRESENT	0
360236	345223	11077T	PARTICIPANT	\N	PRESENT	0
360237	345223	08069G	PARTICIPANT	\N	PRESENT	0
360238	345223	19657G	PARTICIPANT	\N	PRESENT	0
340387	332565	99004R	PRESIDENT	0	PRESENT	0
342904	342903	14235Q	PARTICIPANT	\N	PRESENT	0
347087	346842	19399H	PARTICIPANT	\N	PRESENT	0
347129	347128	98029W	PARTICIPANT	\N	PRESENT	0
347130	347128	14041T	PARTICIPANT	\N	PRESENT	0
347131	347128	14249W	PARTICIPANT	\N	PRESENT	0
347132	347128	19647E	PARTICIPANT	\N	PRESENT	0
347225	347224	98050T	PARTICIPANT	\N	PRESENT	0
347226	347224	01062T	PARTICIPANT	\N	PRESENT	0
347227	347224	14079W	PARTICIPANT	\N	PRESENT	0
347503	347501	10015M	PARTICIPANT	\N	PRESENT	0
347504	347502	10015M	PARTICIPANT	\N	PRESENT	0
347508	347507	10015M	PARTICIPANT	\N	PRESENT	0
350581	350579	14187A	PARTICIPANT	\N	PRESENT	0
350585	350584	14187A	PARTICIPANT	\N	PRESENT	0
350595	350593	14187A	PARTICIPANT	\N	PRESENT	0
351735	339556	19679N	PARTICIPANT	\N	PRESENT	0
351736	350838	11067R	PARTICIPANT	\N	PRESENT	0
351737	350838	19649G	PARTICIPANT	\N	PRESENT	0
351738	350838	11045K	PARTICIPANT	\N	PRESENT	0
351739	350838	14147R	PARTICIPANT	\N	PRESENT	0
351740	350838	19415P	PARTICIPANT	\N	PRESENT	0
351741	350838	08043V	PARTICIPANT	\N	PRESENT	0
351742	350838	19749K	PARTICIPANT	\N	PRESENT	0
351743	350838	10006L	PRESIDENT	0	PRESENT	0
351744	350838	19673G	PARTICIPANT	\N	PRESENT	0
351745	350838	04047H	PARTICIPANT	\N	EXCUSE	0
351746	350838	19295A	PARTICIPANT	\N	EXCUSE	0
351747	350838	08031R	PARTICIPANT	\N	EXCUSE	0
351748	339556	14215L	PARTICIPANT	\N	PRESENT	0
351749	339556	11109J	PARTICIPANT	\N	PRESENT	0
351750	339556	14119M	PARTICIPANT	\N	PRESENT	0
351751	339556	11056N	PARTICIPANT	\N	PRESENT	0
351752	339556	14217N	PARTICIPANT	\N	PRESENT	0
351753	339556	14219Q	PARTICIPANT	\N	PRESENT	0
351754	339556	11026G	PARTICIPANT	\N	PRESENT	0
351755	339556	19695N	PARTICIPANT	\N	PRESENT	0
351757	339556	19575F	PARTICIPANT	\N	PRESENT	0
351758	339556	11012A	PARTICIPANT	\N	PRESENT	0
351759	339556	04088S	PARTICIPANT	\N	PRESENT	0
351760	339556	14115H	PARTICIPANT	\N	PRESENT	0
351761	339556	19703U	PARTICIPANT	\N	PRESENT	0
351762	339556	11104D	PARTICIPANT	\N	PRESENT	0
351763	339556	11103C	PARTICIPANT	\N	PRESENT	0
351764	339556	97011G	PARTICIPANT	\N	PRESENT	0
351765	339556	19489J	PARTICIPANT	\N	PRESENT	0
351766	339556	11053K	PARTICIPANT	\N	PRESENT	0
351767	339556	14030Q	PARTICIPANT	\N	PRESENT	0
351768	339556	01025N	PARTICIPANT	\N	PRESENT	0
351769	339556	08056B	PARTICIPANT	\N	PRESENT	0
351811	339556	19593H	PARTICIPANT	\N	PRESENT	0
351771	350838	19553Y	PARTICIPANT	\N	PRESENT	0
351772	350838	19585H	PARTICIPANT	\N	PRESENT	0
351773	350838	14223L	PARTICIPANT	\N	PRESENT	0
351774	339556	08038Y	PARTICIPANT	\N	PRESENT	0
351775	339556	19527W	PARTICIPANT	\N	PRESENT	0
351776	339556	08051V	PARTICIPANT	\N	PRESENT	0
351777	339556	19563B	PARTICIPANT	\N	PRESENT	0
351778	339556	88008L	PARTICIPANT	\N	PRESENT	0
351779	339556	14157T	PARTICIPANT	\N	PRESENT	0
351780	339556	19467C	PARTICIPANT	\N	PRESENT	0
351781	339556	08068F	PARTICIPANT	\N	PRESENT	0
351782	339556	19335Q	PARTICIPANT	\N	PRESENT	0
351783	339556	14331P	PARTICIPANT	\N	PRESENT	0
351784	339556	14225N	PARTICIPANT	\N	PRESENT	0
351785	350838	01028R	PARTICIPANT	\N	PRESENT	0
351786	350838	19723Y	PARTICIPANT	\N	PRESENT	0
351787	339556	19383Y	PARTICIPANT	\N	PRESENT	0
351788	339556	14083S	PARTICIPANT	\N	PRESENT	0
351789	339556	01048V	PARTICIPANT	\N	PRESENT	0
351790	339556	08061X	PARTICIPANT	\N	PRESENT	0
351791	339556	19673G	PARTICIPANT	\N	PRESENT	0
351792	339556	19415P	PARTICIPANT	\N	PRESENT	0
351793	339556	11045K	PARTICIPANT	\N	PRESENT	0
351794	339556	14042U	PARTICIPANT	\N	PRESENT	0
351795	339556	14257W	PARTICIPANT	\N	PRESENT	0
351796	339556	08034U	PARTICIPANT	\N	PRESENT	0
351797	339556	14061L	PARTICIPANT	\N	PRESENT	0
351799	339556	10006L	PARTICIPANT	\N	PRESENT	0
351800	339556	14147R	PARTICIPANT	\N	PRESENT	0
351801	339556	14169X	PARTICIPANT	\N	PRESENT	0
351802	339556	01043Q	PARTICIPANT	\N	PRESENT	0
351803	339556	14109K	PARTICIPANT	\N	PRESENT	0
351804	339556	08049C	PARTICIPANT	\N	PRESENT	0
351805	339556	19441R	PARTICIPANT	\N	PRESENT	0
351806	339556	11067R	PARTICIPANT	\N	PRESENT	0
351807	339556	19649G	PARTICIPANT	\N	PRESENT	0
351808	339556	14059S	PARTICIPANT	\N	PRESENT	0
351809	339556	19675J	PARTICIPANT	\N	PRESENT	0
351810	339556	11101A	PARTICIPANT	\N	PRESENT	0
351812	339556	11048N	PARTICIPANT	\N	PRESENT	0
351813	339556	14097Y	PARTICIPANT	\N	PRESENT	0
351814	339556	19701S	PARTICIPANT	\N	PRESENT	0
351815	339556	11097X	PARTICIPANT	\N	PRESENT	0
351816	339556	19713W	PARTICIPANT	\N	PRESENT	0
351817	339556	14199E	PARTICIPANT	\N	PRESENT	0
351818	339556	19553Y	PARTICIPANT	\N	PRESENT	0
351819	339556	08019V	PARTICIPANT	\N	PRESENT	0
351820	339556	19733B	PARTICIPANT	\N	PRESENT	0
351821	339556	89017R	PARTICIPANT	\N	PRESENT	0
351822	339556	11064N	PARTICIPANT	\N	PRESENT	0
351823	339556	19721W	PARTICIPANT	\N	PRESENT	0
351824	339556	19503N	PARTICIPANT	\N	PRESENT	0
351825	339556	19719D	PARTICIPANT	\N	PRESENT	0
351826	339556	14213J	PARTICIPANT	\N	PRESENT	0
351827	339556	08055A	PARTICIPANT	\N	PRESENT	0
351876	345285	04085P	PARTICIPANT	\N	PRESENT	0
351877	345285	11033F	PARTICIPANT	\N	PRESENT	0
351878	345285	05008E	PARTICIPANT	\N	PRESENT	0
351879	345285	04047H	PARTICIPANT	\N	PRESENT	0
351880	345285	01024M	PARTICIPANT	\N	PRESENT	0
351881	345285	01028R	PARTICIPANT	\N	PRESENT	0
351882	345285	14065Q	PARTICIPANT	\N	PRESENT	0
351883	345285	08068F	PARTICIPANT	\N	PRESENT	0
351884	345285	11072N	PARTICIPANT	\N	PRESENT	0
351885	345285	11109J	PARTICIPANT	\N	PRESENT	0
351886	345285	02002K	PARTICIPANT	\N	PRESENT	0
351887	345285	19681G	PARTICIPANT	\N	PRESENT	0
351888	345285	19719D	PARTICIPANT	\N	PRESENT	0
351889	345285	19553Y	PARTICIPANT	\N	PRESENT	0
351890	345285	01025N	PARTICIPANT	\N	PRESENT	0
351891	345285	95030B	PARTICIPANT	\N	PRESENT	0
351892	345285	14053L	PARTICIPANT	\N	PRESENT	0
351893	345285	14115H	PARTICIPANT	\N	PRESENT	0
351894	345285	18083K	PARTICIPANT	\N	PRESENT	0
351895	345285	14029X	PARTICIPANT	\N	PRESENT	0
351896	345285	14038Y	PARTICIPANT	\N	PRESENT	0
351897	345285	17637T	PARTICIPANT	\N	PRESENT	0
351898	345285	19794Q	PARTICIPANT	\N	PRESENT	0
351899	345285	19673G	PARTICIPANT	\N	PRESENT	0
351900	345285	14213J	PARTICIPANT	\N	PRESENT	0
351901	345285	14265W	PARTICIPANT	\N	PRESENT	0
351902	345285	14147R	PARTICIPANT	\N	PRESENT	0
351903	345285	08044W	PARTICIPANT	\N	PRESENT	0
351904	345285	19383Y	PARTICIPANT	\N	PRESENT	0
351905	345285	14071N	PARTICIPANT	\N	PRESENT	0
351906	345285	14215L	PARTICIPANT	\N	PRESENT	0
351907	345285	19768N	PARTICIPANT	\N	PRESENT	0
351908	345285	19703U	PARTICIPANT	\N	PRESENT	0
351909	345285	19565D	PARTICIPANT	\N	PRESENT	0
351910	345285	08039A	PARTICIPANT	\N	PRESENT	0
351911	345285	19629C	PARTICIPANT	\N	PRESENT	0
351912	345285	19758L	PARTICIPANT	\N	PRESENT	0
351913	345285	14111D	PARTICIPANT	\N	PRESENT	0
351914	345285	14357A	PARTICIPANT	\N	PRESENT	0
351915	345285	14021P	PARTICIPANT	\N	PRESENT	0
351916	345285	11056N	PARTICIPANT	\N	PRESENT	0
351917	345285	19760E	PARTICIPANT	\N	PRESENT	0
351918	345285	11097X	PARTICIPANT	\N	PRESENT	0
351919	345285	14026U	PARTICIPANT	\N	PRESENT	0
351920	345285	14109K	PARTICIPANT	\N	PRESENT	0
351921	345285	14034U	PARTICIPANT	\N	PRESENT	0
351874	345285	01043Q	PARTICIPANT	\N	PRESENT	0
351875	345285	14231L	PARTICIPANT	\N	PRESENT	0
351922	345285	14089Y	PARTICIPANT	\N	PRESENT	0
351923	345285	14033T	PARTICIPANT	\N	PRESENT	0
351924	345285	14069U	PARTICIPANT	\N	PRESENT	0
351925	345285	14133K	PARTICIPANT	\N	PRESENT	0
351926	345285	89017R	PARTICIPANT	\N	PRESENT	0
352248	332565	19569H	PARTICIPANT	\N	EXCUSE	0
352428	352426	11049P	PARTICIPANT	\N	PRESENT	0
352390	332565	19629C	PARTICIPANT	\N	EXCUSE	0
352427	352426	19673G	PARTICIPANT	\N	PRESENT	0
352429	352426	95063L	PARTICIPANT	\N	PRESENT	0
352431	352430	11049P	PARTICIPANT	\N	PRESENT	0
352432	352430	19673G	PARTICIPANT	\N	PRESENT	0
352456	352455	19673G	PARTICIPANT	\N	PRESENT	0
352526	332565	04038G	PARTICIPANT	\N	PRESENT	0
352532	345318	11065P	PARTICIPANT	\N	PRESENT	0
358125	356267	11109J	PARTICIPANT	\N	PRESENT	0
358127	356267	14039A	PARTICIPANT	\N	PRESENT	0
358128	356267	14059S	PRESIDENT	0	PRESENT	0
358129	356267	19703U	PARTICIPANT	\N	PRESENT	0
358130	356267	14331P	PARTICIPANT	\N	PRESENT	0
358131	356267	11072N	PARTICIPANT	\N	PRESENT	0
359584	359568	11026G	PARTICIPANT	\N	PRESENT	0
358133	356267	95062K	PARTICIPANT	\N	PRESENT	0
358136	356267	19691J	PARTICIPANT	\N	PRESENT	0
360432	358942	19575F	PARTICIPANT	\N	PRESENT	0
360433	358942	11101A	PARTICIPANT	\N	PRESENT	0
360434	358942	19599P	PARTICIPANT	\N	PRESENT	0
360435	358942	19695N	PARTICIPANT	\N	PRESENT	0
360436	358942	11049P	PARTICIPANT	\N	PRESENT	0
360437	358942	04049K	PARTICIPANT	\N	PRESENT	0
360438	358942	01043Q	PARTICIPANT	\N	PRESENT	0
360439	358942	19563B	PRESIDENT	0	PRESENT	0
360440	358942	19503N	PARTICIPANT	\N	PRESENT	0
360446	358942	19713W	PARTICIPANT	\N	PRESENT	0
360450	358942	19413M	PARTICIPANT	\N	PRESENT	0
360451	358942	95067Q	PARTICIPANT	\N	PRESENT	0
360494	358942	08068F	PARTICIPANT	\N	EXCUSE	0
360495	358942	07029T	PARTICIPANT	\N	EXCUSE	0
360496	358942	19637C	PARTICIPANT	\N	EXCUSE	0
360497	358942	14265W	PARTICIPANT	\N	EXCUSE	0
361358	361357	14103D	PARTICIPANT	\N	PRESENT	0
361363	361362	14103D	PARTICIPANT	\N	PRESENT	0
361360	361357	14329V	PARTICIPANT	\N	PRESENT	0
361361	361357	19739H	PARTICIPANT	\N	PRESENT	0
361364	361362	14329V	PARTICIPANT	\N	PRESENT	0
361365	361362	19739H	PARTICIPANT	\N	PRESENT	0
361366	361362	17583W	PARTICIPANT	\N	PRESENT	0
361372	361367	14103D	PARTICIPANT	\N	PRESENT	0
361375	361367	14329V	PARTICIPANT	\N	PRESENT	0
361378	361367	17583W	PARTICIPANT	\N	PRESENT	0
361380	361367	19739H	PARTICIPANT	\N	PRESENT	0
361383	361367	14169X	PARTICIPANT	\N	PRESENT	0
361399	358911	10006L	PARTICIPANT	\N	PRESENT	0
361400	358911	14213J	PARTICIPANT	\N	PRESENT	0
361668	356246	19629C	PARTICIPANT	\N	EXCUSE	0
361669	356246	01028R	PARTICIPANT	\N	EXCUSE	0
361673	356246	19349W	PARTICIPANT	\N	PRESENT	0
361677	356246	19399H	PARTICIPANT	\N	PRESENT	0
362023	356246	08012N	PARTICIPANT	\N	EXCUSE	0
362029	358979	14147R	PARTICIPANT	\N	PRESENT	0
362041	362038	95037J	PARTICIPANT	\N	PRESENT	0
362042	362038	11083R	PARTICIPANT	\N	PRESENT	0
362043	362038	14097Y	PARTICIPANT	\N	PRESENT	0
362044	362038	14357A	PARTICIPANT	\N	PRESENT	0
362045	362038	19593H	PARTICIPANT	\N	PRESENT	0
362046	362038	14237S	PARTICIPANT	\N	PRESENT	0
362047	362038	14135M	PARTICIPANT	\N	PRESENT	0
362048	362038	19563B	PARTICIPANT	\N	PRESENT	0
362049	362038	14331P	PARTICIPANT	\N	PRESENT	0
362050	362038	14073Q	PARTICIPANT	\N	PRESENT	0
362051	362038	11026G	PARTICIPANT	\N	PRESENT	0
362052	362038	04044E	PARTICIPANT	\N	PRESENT	0
362053	362038	04045F	PARTICIPANT	\N	PRESENT	0
362054	362038	04040A	PARTICIPANT	\N	PRESENT	0
362055	362038	19533U	PARTICIPANT	\N	PRESENT	0
362056	362038	19565D	PARTICIPANT	\N	PRESENT	0
362057	362038	19515S	PARTICIPANT	\N	PRESENT	0
362058	362038	14179A	PARTICIPANT	\N	PRESENT	0
362059	362038	08017T	PARTICIPANT	\N	PRESENT	0
362060	362038	14061L	PARTICIPANT	\N	EXCUSE	0
362065	362064	01028R	PARTICIPANT	\N	PRESENT	0
362182	362181	14179A	PARTICIPANT	\N	PRESENT	0
362183	362181	11085T	PARTICIPANT	\N	PRESENT	0
362186	362185	14179A	PARTICIPANT	\N	PRESENT	0
362190	362189	14026U	PARTICIPANT	\N	PRESENT	0
362192	362191	14026U	PARTICIPANT	\N	PRESENT	0
362194	362193	14026U	PARTICIPANT	\N	PRESENT	0
362198	362033	11077T	PARTICIPANT	\N	PRESENT	0
362199	362033	19782L	PARTICIPANT	\N	PRESENT	0
362200	362033	80013X	PARTICIPANT	\N	PRESENT	0
362201	362033	11110B	PARTICIPANT	\N	PRESENT	0
362202	362033	14041T	PARTICIPANT	\N	PRESENT	0
362203	362033	14147R	PARTICIPANT	\N	PRESENT	0
362204	362033	14151M	PARTICIPANT	\N	PRESENT	0
362206	362033	11048N	PARTICIPANT	\N	PRESENT	0
362207	362033	14065Q	PARTICIPANT	\N	PRESENT	0
362208	362033	14187A	PARTICIPANT	\N	PRESENT	0
362209	362033	01024M	PARTICIPANT	\N	PRESENT	0
362210	362033	01025N	PARTICIPANT	\N	PRESENT	0
362211	362033	87003B	PARTICIPANT	\N	PRESENT	0
362212	362033	04059M	PARTICIPANT	\N	PRESENT	0
362213	362033	14109K	PARTICIPANT	\N	PRESENT	0
362214	362033	14207L	PARTICIPANT	\N	PRESENT	0
362215	362033	14255U	PARTICIPANT	\N	PRESENT	0
362216	362033	14257W	PARTICIPANT	\N	PRESENT	0
362217	362033	14001X	PARTICIPANT	\N	PRESENT	0
362218	362033	04044E	PARTICIPANT	\N	PRESENT	0
362219	362033	04045F	PARTICIPANT	\N	PRESENT	0
362220	362033	05008E	PRESIDENT	0	PRESENT	0
362221	362033	14237S	PARTICIPANT	\N	PRESENT	0
362222	362033	05012A	PARTICIPANT	\N	PRESENT	0
362223	362033	04049K	PARTICIPANT	\N	PRESENT	0
362224	362033	08019V	PARTICIPANT	\N	PRESENT	0
362225	362033	14179A	PARTICIPANT	\N	PRESENT	0
362226	362033	14215L	PARTICIPANT	\N	PRESENT	0
362227	362033	14259Y	PARTICIPANT	\N	PRESENT	0
362228	362033	08028W	PARTICIPANT	\N	PRESENT	0
362229	362033	14265W	PARTICIPANT	\N	PRESENT	0
362230	362033	14329V	PARTICIPANT	\N	PRESENT	0
362231	362033	14135M	PARTICIPANT	\N	PRESENT	0
362232	362033	08034U	PARTICIPANT	\N	PRESENT	0
362233	362033	19269X	PARTICIPANT	\N	PRESENT	0
362234	362033	04088S	PARTICIPANT	\N	PRESENT	0
362235	362033	04089T	PARTICIPANT	\N	PRESENT	0
362236	362033	14115H	PARTICIPANT	\N	PRESENT	0
362237	362033	19629C	PARTICIPANT	\N	PRESENT	0
362238	362033	19507S	PARTICIPANT	\N	PRESENT	0
362239	362033	14267Y	PARTICIPANT	\N	PRESENT	0
362240	362033	19583F	PARTICIPANT	\N	PRESENT	0
362241	362033	19515S	PARTICIPANT	\N	PRESENT	0
362242	362033	19443T	PARTICIPANT	\N	PRESENT	0
362243	362033	19533U	PARTICIPANT	\N	PRESENT	0
362244	362033	19545Y	PARTICIPANT	\N	PRESENT	0
362245	362033	01057W	PARTICIPANT	\N	PRESENT	0
362246	362033	19441R	PARTICIPANT	\N	PRESENT	0
362247	362033	19543W	PARTICIPANT	\N	PRESENT	0
362248	362033	19673G	PARTICIPANT	\N	PRESENT	0
362249	362033	19675J	PARTICIPANT	\N	PRESENT	0
362250	362033	01028R	PARTICIPANT	\N	PRESENT	0
362251	362033	19447X	PARTICIPANT	\N	PRESENT	0
362252	362033	08056B	PARTICIPANT	\N	PRESENT	0
362253	362033	07029T	PARTICIPANT	\N	PRESENT	0
362254	362033	08068F	PARTICIPANT	\N	PRESENT	0
362255	362033	07033P	PARTICIPANT	\N	PRESENT	0
362256	362033	08061X	PARTICIPANT	\N	PRESENT	0
362257	362033	19521Q	PARTICIPANT	\N	PRESENT	0
362258	362033	19643A	PARTICIPANT	\N	PRESENT	0
362259	362033	19649G	PARTICIPANT	\N	PRESENT	0
362260	362033	10015M	PARTICIPANT	\N	PRESENT	0
362261	362033	19695N	PARTICIPANT	\N	PRESENT	0
362262	362033	08062Y	PARTICIPANT	\N	PRESENT	0
362263	362033	04038G	PARTICIPANT	\N	PRESENT	0
362264	362033	19399H	PARTICIPANT	\N	PRESENT	0
362265	362033	11033F	PARTICIPANT	\N	PRESENT	0
362266	362033	14089Y	PARTICIPANT	\N	PRESENT	0
362267	362033	08044W	PARTICIPANT	\N	PRESENT	0
362268	362033	14069U	PARTICIPANT	\N	PRESENT	0
362269	362033	11049P	PARTICIPANT	\N	PRESENT	0
362270	362033	17589D	PARTICIPANT	\N	PRESENT	0
362271	362033	14021P	PARTICIPANT	\N	PRESENT	0
362272	362033	19699S	PARTICIPANT	\N	PRESENT	0
362273	362033	14357A	PARTICIPANT	\N	PRESENT	0
359579	359568	04047H	PARTICIPANT	\N	PRESENT	0
359581	359568	14041T	PARTICIPANT	\N	PRESENT	0
362274	362033	14081Q	PARTICIPANT	\N	PRESENT	0
362275	362033	19581D	PARTICIPANT	\N	PRESENT	0
362276	362033	19585H	PARTICIPANT	\N	PRESENT	0
362277	362033	19631V	PARTICIPANT	\N	PRESENT	0
362278	362033	19705W	PARTICIPANT	\N	PRESENT	0
362279	362033	14197C	PARTICIPANT	\N	PRESENT	0
362280	362033	19369B	PARTICIPANT	\N	PRESENT	0
362281	362033	19511N	PARTICIPANT	\N	PRESENT	0
362282	362033	19563B	PARTICIPANT	\N	PRESENT	0
362283	362033	17637T	PARTICIPANT	\N	PRESENT	0
362284	362033	11072N	PARTICIPANT	\N	PRESENT	0
362285	362033	19467C	PARTICIPANT	\N	PRESENT	0
362286	362033	14111D	PARTICIPANT	\N	PRESENT	0
362287	362033	08045X	PARTICIPANT	\N	PRESENT	0
362288	362033	11026G	PARTICIPANT	\N	PRESENT	0
362289	362033	14033T	PARTICIPANT	\N	PRESENT	0
362290	362033	14034U	PARTICIPANT	\N	PRESENT	0
362291	362033	14173T	PARTICIPANT	\N	PRESENT	0
362292	362033	14205J	PARTICIPANT	\N	PRESENT	0
337670	332424	19551W	PARTICIPANT	\N	EXCUSE	0
337671	332424	19349W	PARTICIPANT	\N	EXCUSE	0
338177	332424	19515S	PARTICIPANT	\N	PRESENT	0
338178	332424	14107H	PARTICIPANT	\N	PRESENT	0
338194	335128	14107H	PARTICIPANT	\N	PRESENT	0
338195	329064	14107H	PARTICIPANT	\N	PRESENT	0
338196	335730	14107H	PARTICIPANT	\N	PRESENT	0
338197	333448	14107H	PARTICIPANT	\N	PRESENT	0
340394	340392	14107H	PARTICIPANT	\N	PRESENT	0
340396	340395	11065P	PARTICIPANT	\N	PRESENT	0
340398	340397	99004R	PRESIDENT	0	PRESENT	0
340401	340400	04038G	PARTICIPANT	\N	PRESENT	0
340402	340399	04038G	PARTICIPANT	\N	PRESENT	0
341886	339498	11097X	PARTICIPANT	\N	PRESENT	0
341887	339498	19657G	PARTICIPANT	\N	PRESENT	0
341888	339498	17779H	PARTICIPANT	\N	PRESENT	0
341889	339498	14079W	PARTICIPANT	\N	PRESENT	0
341890	339498	11043H	PARTICIPANT	\N	PRESENT	0
341891	339498	14199E	PARTICIPANT	\N	PRESENT	0
341892	340438	14259Y	PARTICIPANT	\N	EXCUSE	0
341893	339498	04061F	PARTICIPANT	\N	PRESENT	0
341894	339498	97011G	PARTICIPANT	\N	PRESENT	0
341895	339498	11012A	PARTICIPANT	\N	PRESENT	0
341896	340564	19701S	PARTICIPANT	\N	PRESENT	0
341897	340564	10006L	PARTICIPANT	\N	PRESENT	0
341898	340564	19525U	PARTICIPANT	\N	PRESENT	0
341899	340564	15447F	PARTICIPANT	\N	PRESENT	0
341900	340564	04044E	PARTICIPANT	\N	PRESENT	0
341901	340564	14357A	PARTICIPANT	\N	PRESENT	0
341902	340564	08055A	PARTICIPANT	\N	PRESENT	0
341884	339498	87003B	PARTICIPANT	\N	PRESENT	0
341885	339498	19399H	PARTICIPANT	\N	PRESENT	0
341903	340564	19629C	PARTICIPANT	\N	PRESENT	0
341904	339498	14219Q	PARTICIPANT	\N	PRESENT	0
341905	339498	01048V	PARTICIPANT	\N	PRESENT	0
341906	339498	08051V	PARTICIPANT	\N	PRESENT	0
341907	339498	14237S	PARTICIPANT	\N	PRESENT	0
341908	339498	08015R	PARTICIPANT	\N	PRESENT	0
342174	340438	19583F	PARTICIPANT	\N	EXCUSE	0
342175	340438	19691J	PARTICIPANT	\N	PRESENT	0
342176	340438	11109J	PARTICIPANT	\N	PRESENT	0
342177	340438	08019V	PRESIDENT	0	PRESENT	0
342180	340438	08073C	PARTICIPANT	\N	EXCUSE	0
342185	340438	14261S	PARTICIPANT	\N	PRESENT	0
342795	341604	08031R	PARTICIPANT	\N	EXCUSE	0
342796	339495	14147R	PARTICIPANT	\N	PRESENT	0
342797	339499	19335Q	PARTICIPANT	\N	PRESENT	0
342798	339499	14115H	PARTICIPANT	\N	PRESENT	0
342799	339499	14147R	PARTICIPANT	\N	PRESENT	0
342804	342803	08010L	PARTICIPANT	\N	PRESENT	0
342810	342808	14207L	PARTICIPANT	\N	PRESENT	0
342811	342808	19369B	PARTICIPANT	\N	PRESENT	0
342812	342808	14265W	PARTICIPANT	\N	PRESENT	0
342813	342808	19383Y	PARTICIPANT	\N	PRESENT	0
342814	342808	14109K	PARTICIPANT	\N	PRESENT	0
342871	342870	11083R	PARTICIPANT	\N	PRESENT	0
342872	342870	14073Q	PARTICIPANT	\N	PRESENT	0
342873	342870	14237S	PARTICIPANT	\N	PRESENT	0
342902	342817	08048B	PARTICIPANT	\N	EXCUSE	0
342905	342817	11101A	PARTICIPANT	\N	EXCUSE	0
342959	342915	14053L	PARTICIPANT	\N	PRESENT	0
342960	342915	19649G	PARTICIPANT	\N	PRESENT	0
342961	342915	08045X	PARTICIPANT	\N	PRESENT	0
342962	342915	19581D	PARTICIPANT	\N	PRESENT	0
342963	342915	04044E	PARTICIPANT	\N	PRESENT	0
342964	342915	19673G	PARTICIPANT	\N	PRESENT	0
342965	342915	05008E	PRESIDENT	0	PRESENT	0
342966	342915	19447X	PARTICIPANT	\N	PRESENT	0
342967	342915	19725B	PARTICIPANT	\N	PRESENT	0
342968	342915	19489J	PARTICIPANT	\N	PRESENT	0
342969	342915	19629C	PARTICIPANT	\N	PRESENT	0
342970	342915	14041T	PARTICIPANT	\N	PRESENT	0
342971	342915	14069U	PARTICIPANT	\N	PRESENT	0
342972	342915	14151M	PARTICIPANT	\N	PRESENT	0
342973	342915	14215L	PARTICIPANT	\N	PRESENT	0
342974	342915	14259Y	PARTICIPANT	\N	PRESENT	0
342975	342915	04008A	PARTICIPANT	\N	PRESENT	0
342976	342915	19585H	PARTICIPANT	\N	PRESENT	0
342977	342915	01028R	PARTICIPANT	\N	PRESENT	0
342978	342915	14147R	PARTICIPANT	\N	PRESENT	0
342979	342915	08018U	PARTICIPANT	\N	PRESENT	0
342980	342915	14111D	PARTICIPANT	\N	PRESENT	0
342981	342915	07034Q	PARTICIPANT	\N	PRESENT	0
342982	342915	04038G	PARTICIPANT	\N	PRESENT	0
342983	342915	08044W	PARTICIPANT	\N	PRESENT	0
342984	342915	14021P	PARTICIPANT	\N	PRESENT	0
342985	342915	14179A	PARTICIPANT	\N	PRESENT	0
342986	342915	11026G	PARTICIPANT	\N	PRESENT	0
342987	342915	11033F	PARTICIPANT	\N	PRESENT	0
342988	342915	11085T	PARTICIPANT	\N	PRESENT	0
342989	342915	19543W	PARTICIPANT	\N	PRESENT	0
342990	342915	04047H	PARTICIPANT	\N	PRESENT	0
342991	342915	14231L	PARTICIPANT	\N	PRESENT	0
342992	342915	11049P	PARTICIPANT	\N	PRESENT	0
342993	342915	14193X	PARTICIPANT	\N	PRESENT	0
342994	342915	19681G	PARTICIPANT	\N	PRESENT	0
342995	342915	19611R	PARTICIPANT	\N	PRESENT	0
342996	342915	19693L	PARTICIPANT	\N	PRESENT	0
342997	342915	04085P	PARTICIPANT	\N	PRESENT	0
342998	342915	04059M	PARTICIPANT	\N	PRESENT	0
343000	342915	04035D	PARTICIPANT	\N	PRESENT	0
343001	342915	14065Q	PARTICIPANT	\N	PRESENT	0
343002	342915	19766L	PARTICIPANT	\N	PRESENT	0
343006	342915	11027H	PARTICIPANT	\N	PRESENT	0
343007	342915	14329V	PARTICIPANT	\N	PRESENT	0
343008	342958	19581D	PARTICIPANT	\N	PRESENT	0
343009	342958	04044E	PARTICIPANT	\N	PRESENT	0
343010	342958	19585H	PARTICIPANT	\N	PRESENT	0
343011	342958	04047H	PARTICIPANT	\N	PRESENT	0
343012	342958	19673G	PARTICIPANT	\N	PRESENT	0
343013	342958	01028R	PARTICIPANT	\N	PRESENT	0
343014	342958	05008E	PRESIDENT	0	PRESENT	0
343015	342958	19447X	PARTICIPANT	\N	PRESENT	0
343016	342958	14231L	PARTICIPANT	\N	PRESENT	0
343017	342958	19489J	PARTICIPANT	\N	PRESENT	0
343018	342958	14041T	PARTICIPANT	\N	PRESENT	0
343019	342958	14147R	PARTICIPANT	\N	PRESENT	0
343020	342958	14151M	PARTICIPANT	\N	PRESENT	0
343021	342958	14215L	PARTICIPANT	\N	PRESENT	0
343022	342958	08018U	PARTICIPANT	\N	PRESENT	0
343023	342958	14053L	PARTICIPANT	\N	PRESENT	0
343024	342958	19649G	PARTICIPANT	\N	PRESENT	0
343025	342958	14111D	PARTICIPANT	\N	PRESENT	0
343026	342958	14065Q	PARTICIPANT	\N	PRESENT	0
343027	342958	08045X	PARTICIPANT	\N	PRESENT	0
343028	342958	07034Q	PARTICIPANT	\N	PRESENT	0
343029	342958	11026G	PARTICIPANT	\N	PRESENT	0
343030	342958	11033F	PARTICIPANT	\N	PRESENT	0
343031	342958	19725B	PARTICIPANT	\N	PRESENT	0
343032	342958	19629C	PARTICIPANT	\N	PRESENT	0
343033	342958	08044W	PARTICIPANT	\N	PRESENT	0
343034	342958	11085T	PARTICIPANT	\N	PRESENT	0
343035	342958	11049P	PARTICIPANT	\N	PRESENT	0
343036	342958	04008A	PARTICIPANT	\N	PRESENT	0
343037	342958	14021P	PARTICIPANT	\N	PRESENT	0
343064	343003	14179A	PARTICIPANT	\N	PRESENT	0
343286	343285	11109J	PARTICIPANT	\N	PRESENT	0
343287	343285	08024S	PARTICIPANT	\N	PRESENT	0
343288	343285	19295A	PARTICIPANT	\N	PRESENT	0
343289	343285	11027H	PARTICIPANT	\N	PRESENT	0
343290	343285	19301E	PARTICIPANT	\N	PRESENT	0
343291	343285	08019V	PARTICIPANT	\N	PRESENT	0
343711	340473	11109J	PARTICIPANT	\N	PRESENT	0
343712	340473	19717B	PARTICIPANT	\N	PRESENT	0
343713	340473	14039A	PARTICIPANT	\N	PRESENT	0
343714	340473	98005N	PARTICIPANT	\N	EXCUSE	0
343716	340473	19729F	PARTICIPANT	\N	PRESENT	0
343717	340473	14059S	PARTICIPANT	\N	PRESENT	0
343718	340473	12016W	PARTICIPANT	\N	PRESENT	0
343719	340473	08019V	PRESIDENT	0	PRESENT	0
343720	340473	11072N	PARTICIPANT	\N	PRESENT	0
343721	340473	19301E	PARTICIPANT	\N	PRESENT	0
343722	340473	14275Y	PARTICIPANT	\N	EXCUSE	0
343723	340473	14038Y	PARTICIPANT	\N	EXCUSE	0
343725	340473	19691J	PARTICIPANT	\N	PRESENT	0
343726	340473	08039A	PARTICIPANT	\N	PRESENT	0
343727	340473	14229S	PARTICIPANT	\N	PRESENT	0
343728	340473	14261S	PARTICIPANT	\N	EXCUSE	0
344110	343680	14030Q	PRESIDENT	0	PRESENT	0
344111	343680	19643A	PARTICIPANT	\N	PRESENT	0
344112	343680	19701S	PARTICIPANT	\N	PRESENT	0
344113	343680	19599P	PARTICIPANT	\N	PRESENT	0
344114	343680	14179A	PARTICIPANT	\N	PRESENT	0
344115	343680	08031R	PARTICIPANT	\N	PRESENT	0
344116	343680	07029T	PARTICIPANT	\N	PRESENT	0
344117	343680	11067R	PARTICIPANT	\N	PRESENT	0
344118	343680	14109K	PARTICIPANT	\N	PRESENT	0
344119	343680	14235Q	PARTICIPANT	\N	PRESENT	0
344120	343680	19749K	PARTICIPANT	\N	PRESENT	0
361499	361498	19421M	PARTICIPANT	\N	PRESENT	0
361500	361498	19251M	PARTICIPANT	\N	PRESENT	0
361501	361498	04040A	PARTICIPANT	\N	PRESENT	0
361502	361498	11064N	PARTICIPANT	\N	PRESENT	0
361505	361504	98050T	PARTICIPANT	\N	PRESENT	0
361506	361504	01062T	PARTICIPANT	\N	PRESENT	0
361507	361504	95037J	PARTICIPANT	\N	PRESENT	0
361891	345231	11040E	PARTICIPANT	\N	PRESENT	0
362293	362033	11056N	PARTICIPANT	\N	PRESENT	0
362294	362033	19729F	PARTICIPANT	\N	PRESENT	0
362295	362033	19741B	PARTICIPANT	\N	PRESENT	0
362296	362033	11085T	PARTICIPANT	\N	PRESENT	0
362297	362033	19745F	PARTICIPANT	\N	PRESENT	0
362298	362033	19762G	PARTICIPANT	\N	PRESENT	0
362299	362033	04047H	PARTICIPANT	\N	EXCUSE	0
362300	345231	14069U	PARTICIPANT	\N	PRESENT	0
362301	345231	01060R	PARTICIPANT	\N	PRESENT	0
362304	361687	08058D	PARTICIPANT	\N	PRESENT	0
362310	345231	14187A	PARTICIPANT	\N	PRESENT	0
362311	345231	19591F	PARTICIPANT	\N	PRESENT	0
362312	345231	14331P	PARTICIPANT	\N	PRESENT	0
362418	345232	14231L	PARTICIPANT	\N	PRESENT	0
362419	345232	14031R	PARTICIPANT	\N	PRESENT	0
362420	345232	19687N	PARTICIPANT	\N	PRESENT	0
362421	345232	19347U	PARTICIPANT	\N	PRESENT	0
362422	345232	19503N	PARTICIPANT	\N	PRESENT	0
362423	345232	19794Q	PARTICIPANT	\N	PRESENT	0
362424	345232	19413M	PARTICIPANT	\N	PRESENT	0
362425	345232	19575F	PARTICIPANT	\N	PRESENT	0
362426	345232	19251M	PARTICIPANT	\N	PRESENT	0
362427	345232	19507S	PARTICIPANT	\N	PRESENT	0
362428	345232	14257W	PARTICIPANT	\N	PRESENT	0
362429	345232	19551W	PARTICIPANT	\N	PRESENT	0
362430	345232	14029X	PARTICIPANT	\N	PRESENT	0
362431	345232	19631V	PARTICIPANT	\N	PRESENT	0
362432	345232	14038Y	PARTICIPANT	\N	PRESENT	0
362433	345232	19525U	PARTICIPANT	\N	PRESENT	0
362434	345232	19703U	PARTICIPANT	\N	PRESENT	0
362435	345232	19333N	PARTICIPANT	\N	PRESENT	0
362436	345232	14105F	PARTICIPANT	\N	PRESENT	0
362437	345232	19549D	PARTICIPANT	\N	PRESENT	0
362438	345232	14259Y	PARTICIPANT	\N	PRESENT	0
362439	345232	14065Q	PARTICIPANT	\N	PRESENT	0
362440	345232	08060W	PARTICIPANT	\N	PRESENT	0
362441	345232	19467C	PARTICIPANT	\N	PRESENT	0
362442	345232	01025N	PARTICIPANT	\N	PRESENT	0
362443	345232	08055A	PARTICIPANT	\N	PRESENT	0
362444	345232	19737F	PARTICIPANT	\N	PRESENT	0
362445	345232	19637C	PARTICIPANT	\N	PRESENT	0
362446	345232	11065P	PARTICIPANT	\N	PRESENT	0
362447	345232	19782L	PARTICIPANT	\N	PRESENT	0
362448	345232	14051J	PARTICIPANT	\N	PRESENT	0
362449	345232	19599P	PARTICIPANT	\N	PRESENT	0
362450	345232	19719D	PARTICIPANT	\N	PRESENT	0
362451	345232	19289C	PARTICIPANT	\N	PRESENT	0
362452	345232	19387D	PARTICIPANT	\N	PRESENT	0
362453	345232	08049C	PARTICIPANT	\N	PRESENT	0
362454	345232	19749K	PARTICIPANT	\N	PRESENT	0
362455	345232	19533U	PARTICIPANT	\N	PRESENT	0
362456	345232	19701S	PARTICIPANT	\N	PRESENT	0
362457	345232	19747H	PARTICIPANT	\N	PRESENT	0
362458	345232	19621T	PARTICIPANT	\N	PRESENT	0
362459	345232	14195A	PARTICIPANT	\N	PRESENT	0
362460	345232	19593H	PARTICIPANT	\N	PRESENT	0
362461	345232	08031R	PARTICIPANT	\N	PRESENT	0
362462	345232	14103D	PARTICIPANT	\N	PRESENT	0
362463	345232	19349W	PARTICIPANT	\N	PRESENT	0
362464	345232	04085P	PARTICIPANT	\N	PRESENT	0
362465	345232	14211G	PARTICIPANT	\N	PRESENT	0
362466	345232	14219Q	PARTICIPANT	\N	PRESENT	0
362467	345232	08068F	PARTICIPANT	\N	PRESENT	0
362468	345232	14093U	PARTICIPANT	\N	PRESENT	0
362469	345232	11043H	PARTICIPANT	\N	PRESENT	0
362470	345232	14053L	PARTICIPANT	\N	PRESENT	0
362471	345232	14169X	PARTICIPANT	\N	PRESENT	0
362477	345232	19760E	PARTICIPANT	\N	PRESENT	0
362473	345232	19415P	PARTICIPANT	\N	PRESENT	0
362474	345232	14197C	PARTICIPANT	\N	PRESENT	0
362475	345232	19383Y	PARTICIPANT	\N	PRESENT	0
362476	345232	14034U	PARTICIPANT	\N	PRESENT	0
362478	345232	14237S	PARTICIPANT	\N	PRESENT	0
362479	345232	19647E	PARTICIPANT	\N	PRESENT	0
362480	345232	19629C	PARTICIPANT	\N	PRESENT	0
362481	345232	95067Q	PARTICIPANT	\N	PRESENT	0
362482	345232	19709B	PARTICIPANT	\N	PRESENT	0
362483	345232	08015R	PARTICIPANT	\N	PRESENT	0
362484	345232	04097T	PARTICIPANT	\N	PRESENT	0
362485	345232	14331P	PARTICIPANT	\N	PRESENT	0
362486	345232	14187A	PARTICIPANT	\N	PRESENT	0
362487	345232	04047H	PARTICIPANT	\N	PRESENT	0
362488	345232	08020N	PARTICIPANT	\N	PRESENT	0
362489	345232	19447X	PARTICIPANT	\N	PRESENT	0
362490	345232	19569H	PARTICIPANT	\N	PRESENT	0
362491	345232	19695N	PARTICIPANT	\N	PRESENT	0
362492	345232	19489J	PARTICIPANT	\N	PRESENT	0
362493	345232	19733B	PARTICIPANT	\N	PRESENT	0
362494	345232	05012A	PARTICIPANT	\N	PRESENT	0
362495	345232	14327T	PARTICIPANT	\N	PRESENT	0
362496	345232	14087W	PARTICIPANT	\N	PRESENT	0
362497	345232	14215L	PARTICIPANT	\N	PRESENT	0
362498	345232	14147R	PARTICIPANT	\N	PRESENT	0
362499	345232	19713W	PARTICIPANT	\N	PRESENT	0
362500	345232	19727D	PARTICIPANT	\N	PRESENT	0
362501	345232	14261S	PARTICIPANT	\N	PRESENT	0
362502	345232	17589D	PARTICIPANT	\N	PRESENT	0
362503	345232	14111D	PARTICIPANT	\N	PRESENT	0
362504	345232	19573D	PARTICIPANT	\N	PRESENT	0
362505	345232	14083S	PARTICIPANT	\N	PRESENT	0
362506	345232	16685X	PARTICIPANT	\N	PRESENT	0
362507	345232	12016W	PARTICIPANT	\N	PRESENT	0
362508	345232	19715Y	PARTICIPANT	\N	PRESENT	0
362509	345232	14071N	PARTICIPANT	\N	PRESENT	0
362510	345232	14357A	PARTICIPANT	\N	PRESENT	0
362511	345232	14033T	PARTICIPANT	\N	PRESENT	0
362512	345232	04088S	PARTICIPANT	\N	PRESENT	0
362513	345232	95041E	PARTICIPANT	\N	PRESENT	0
362514	345232	14089Y	PARTICIPANT	\N	PRESENT	0
362515	345232	14026U	PARTICIPANT	\N	PRESENT	0
362516	345232	14059S	PARTICIPANT	\N	PRESENT	0
362517	345232	19545Y	PARTICIPANT	\N	PRESENT	0
362518	345232	04061F	PARTICIPANT	\N	PRESENT	0
362519	345232	88008L	PARTICIPANT	\N	PRESENT	0
362520	345232	14069U	PARTICIPANT	\N	PRESENT	0
362521	345232	14213J	PARTICIPANT	\N	PRESENT	0
362416	345232	04086Q	PARTICIPANT	\N	PRESENT	0
362417	345232	08009T	PARTICIPANT	\N	PRESENT	0
362522	345232	14123H	PARTICIPANT	\N	PRESENT	0
362561	362033	14053L	PARTICIPANT	\N	PRESENT	0
362600	361174	19383Y	PARTICIPANT	\N	PRESENT	0
362601	361174	19333N	PARTICIPANT	\N	PRESENT	0
362602	361174	17583W	PARTICIPANT	\N	PRESENT	0
362603	361174	19701S	PARTICIPANT	\N	PRESENT	0
362604	361174	19794Q	PARTICIPANT	\N	PRESENT	0
362605	361174	95062K	PARTICIPANT	\N	PRESENT	0
362606	361174	19549D	PARTICIPANT	\N	PRESENT	0
362607	361174	19387D	PARTICIPANT	\N	PRESENT	0
362608	361174	14219Q	PARTICIPANT	\N	PRESENT	0
362609	361174	19599P	PARTICIPANT	\N	PRESENT	0
362610	361174	19637C	PARTICIPANT	\N	PRESENT	0
362611	361174	02002K	PARTICIPANT	\N	PRESENT	0
362612	361174	14237S	PARTICIPANT	\N	PRESENT	0
362613	361174	19551W	PARTICIPANT	\N	PRESENT	0
362614	361174	80027E	PARTICIPANT	\N	PRESENT	0
362615	361174	14051J	PARTICIPANT	\N	PRESENT	0
362616	361174	19503N	PARTICIPANT	\N	PRESENT	0
362617	361174	14038Y	PARTICIPANT	\N	PRESENT	0
362618	361174	14103D	PARTICIPANT	\N	PRESENT	0
362619	361174	14031R	PARTICIPANT	\N	PRESENT	0
362620	361174	08055A	PARTICIPANT	\N	PRESENT	0
362621	361174	14169X	PARTICIPANT	\N	PRESENT	0
362622	361174	14029X	PARTICIPANT	\N	PRESENT	0
362623	361174	19733B	PARTICIPANT	\N	PRESENT	0
362624	361174	08009T	PRESIDENT	0	PRESENT	0
362625	361174	19737F	PARTICIPANT	\N	PRESENT	0
362626	361174	04097T	PARTICIPANT	\N	PRESENT	0
362627	361174	19739H	PARTICIPANT	\N	PRESENT	0
362628	361174	19745F	PARTICIPANT	\N	PRESENT	0
362629	361174	19685L	PARTICIPANT	\N	EXCUSE	0
362630	361687	11081P	PARTICIPANT	\N	EXCUSE	0
362631	361687	11101A	PARTICIPANT	\N	EXCUSE	0
362632	361687	08038Y	PARTICIPANT	\N	EXCUSE	0
362633	361687	08021P	PARTICIPANT	\N	EXCUSE	0
362634	361169	08038Y	PARTICIPANT	\N	EXCUSE	0
362635	361169	19295A	PARTICIPANT	\N	EXCUSE	0
362636	361169	11081P	PARTICIPANT	\N	EXCUSE	0
362637	361271	11064N	PARTICIPANT	\N	PRESENT	0
362638	361271	01062T	PARTICIPANT	\N	PRESENT	0
362641	362033	19489J	PARTICIPANT	\N	PRESENT	0
362645	362644	19721W	PARTICIPANT	\N	PRESENT	0
350878	350877	04061F	PARTICIPANT	\N	PRESENT	0
350879	350877	14001X	PARTICIPANT	\N	PRESENT	0
350881	350880	04061F	PARTICIPANT	\N	PRESENT	0
350882	350880	14001X	PARTICIPANT	\N	PRESENT	0
352552	352551	96004D	PRESIDENT	0	PRESENT	0
352554	352551	14357A	PARTICIPANT	\N	PRESENT	0
352555	352551	14249W	PARTICIPANT	\N	PRESENT	0
352556	352551	14033T	PARTICIPANT	\N	PRESENT	0
352557	352551	14026U	PARTICIPANT	\N	PRESENT	0
352558	352551	19725B	PARTICIPANT	\N	PRESENT	0
352559	352551	19569H	PARTICIPANT	\N	PRESENT	0
352560	352551	95037J	PARTICIPANT	\N	PRESENT	0
352561	352551	04097T	PARTICIPANT	\N	PRESENT	0
352562	352551	14097Y	PARTICIPANT	\N	PRESENT	0
352563	352551	14061L	PARTICIPANT	\N	PRESENT	0
352564	352551	14073Q	PARTICIPANT	\N	PRESENT	0
352565	352551	14001X	PARTICIPANT	\N	PRESENT	0
352566	352551	19563B	PARTICIPANT	\N	PRESENT	0
352567	352551	14237S	PARTICIPANT	\N	PRESENT	0
352568	352551	19593H	PARTICIPANT	\N	PRESENT	0
352569	352551	14135M	PARTICIPANT	\N	PRESENT	0
352570	352551	98035U	PARTICIPANT	\N	PRESENT	0
352571	352551	19747H	PARTICIPANT	\N	PRESENT	0
352572	352551	14115H	PARTICIPANT	\N	PRESENT	0
352573	352551	19507S	PARTICIPANT	\N	PRESENT	0
352574	352551	14205J	PARTICIPANT	\N	PRESENT	0
352575	352551	08015R	PARTICIPANT	\N	PRESENT	0
352576	352551	11099A	PARTICIPANT	\N	PRESENT	0
352577	352551	19782L	PARTICIPANT	\N	PRESENT	0
352578	352551	11056N	PARTICIPANT	\N	PRESENT	0
352579	352551	04088S	PARTICIPANT	\N	PRESENT	0
352580	352551	14265W	PARTICIPANT	\N	PRESENT	0
352581	352551	11090Q	PARTICIPANT	\N	PRESENT	0
352582	352551	14329V	PARTICIPANT	\N	PRESENT	0
352583	352551	19413M	PARTICIPANT	\N	PRESENT	0
352584	352551	14187A	PARTICIPANT	\N	PRESENT	0
352585	352551	14257W	PARTICIPANT	\N	PRESENT	0
352586	352551	08068F	PARTICIPANT	\N	PRESENT	0
352587	352551	19631V	PARTICIPANT	\N	PRESENT	0
352588	352551	14207L	PARTICIPANT	\N	PRESENT	0
352589	352551	19441R	PARTICIPANT	\N	PRESENT	0
352590	352551	19511N	PARTICIPANT	\N	PRESENT	0
352591	352551	04057K	PARTICIPANT	\N	PRESENT	0
352592	352551	19467C	PARTICIPANT	\N	PRESENT	0
352593	352551	19768N	PARTICIPANT	\N	PRESENT	0
352594	352551	08038Y	PARTICIPANT	\N	PRESENT	0
352595	352551	19695N	PARTICIPANT	\N	PRESENT	0
352596	352551	19269X	PARTICIPANT	\N	PRESENT	0
352597	352551	14089Y	PARTICIPANT	\N	PRESENT	0
352598	352551	14079W	PARTICIPANT	\N	PRESENT	0
352600	352551	14065Q	PARTICIPANT	\N	EXCUSE	0
352724	352712	19621T	PARTICIPANT	\N	PRESENT	0
352725	352712	19758L	PARTICIPANT	\N	PRESENT	0
352726	352712	14241N	PARTICIPANT	\N	PRESENT	0
352727	352712	08043V	PARTICIPANT	\N	PRESENT	0
352728	352712	14229S	PARTICIPANT	\N	PRESENT	0
352733	352729	19621T	PARTICIPANT	\N	PRESENT	0
353787	353786	18083K	PARTICIPANT	\N	PRESENT	0
353788	353786	19599P	PARTICIPANT	\N	PRESENT	0
353789	353786	19673G	PARTICIPANT	\N	PRESENT	0
353790	353786	19447X	PARTICIPANT	\N	PRESENT	0
353791	353786	14157T	PARTICIPANT	\N	PRESENT	0
353894	348355	19703U	PARTICIPANT	\N	PRESENT	0
353889	348355	10006L	PARTICIPANT	\N	PRESENT	0
353890	348355	11097X	PARTICIPANT	\N	PRESENT	0
353892	348355	14213J	PARTICIPANT	\N	PRESENT	0
353893	348355	98024R	PARTICIPANT	\N	PRESENT	0
353898	353833	19533U	PARTICIPANT	\N	PRESENT	0
353899	353833	08031R	PARTICIPANT	\N	PRESENT	0
353900	353833	10006L	PARTICIPANT	\N	EXCUSE	0
353901	353833	19621T	PARTICIPANT	\N	EXCUSE	0
353902	353833	14213J	PARTICIPANT	\N	EXCUSE	0
353903	353833	14147R	PARTICIPANT	\N	PRESENT	0
353904	353833	11067R	PARTICIPANT	\N	PRESENT	0
353905	353833	19749K	PARTICIPANT	\N	PRESENT	0
353906	353833	11043H	PARTICIPANT	\N	PRESENT	0
353907	353833	19415P	PARTICIPANT	\N	PRESENT	0
353908	353833	04047H	PARTICIPANT	\N	PRESENT	0
353909	353833	19553Y	PARTICIPANT	\N	PRESENT	0
353910	353833	14231L	PARTICIPANT	\N	PRESENT	0
355030	355024	04042C	PARTICIPANT	\N	PRESENT	0
355031	355024	07033P	PARTICIPANT	\N	PRESENT	0
355032	355024	14187A	PARTICIPANT	\N	PRESENT	0
355033	355024	14281W	PARTICIPANT	\N	PRESENT	0
355036	355024	19583F	PARTICIPANT	\N	PRESENT	0
355037	355024	11085T	PARTICIPANT	\N	PRESENT	0
355039	355024	04088S	PARTICIPANT	\N	PRESENT	0
355043	355024	11049P	PARTICIPANT	\N	PRESENT	0
355187	350873	14042U	PARTICIPANT	\N	PRESENT	0
355189	350840	19723Y	PARTICIPANT	\N	PRESENT	0
352533	345318	14107H	PARTICIPANT	\N	PRESENT	0
352534	332565	14107H	PARTICIPANT	\N	PRESENT	0
355190	350840	11097X	PARTICIPANT	\N	PRESENT	0
355191	350840	19703U	PARTICIPANT	\N	PRESENT	0
355207	350871	14042U	PARTICIPANT	\N	PRESENT	0
355208	350871	19727D	PARTICIPANT	\N	PRESENT	0
355209	350871	14026U	PARTICIPANT	\N	PRESENT	0
355210	350871	11097X	PARTICIPANT	\N	PRESENT	0
355211	350872	14042U	PARTICIPANT	\N	PRESENT	0
355508	350842	14239U	PARTICIPANT	\N	PRESENT	0
355509	350842	14042U	PARTICIPANT	\N	PRESENT	0
355511	350842	14195A	PARTICIPANT	\N	PRESENT	0
355513	350842	11097X	PARTICIPANT	\N	PRESENT	0
355514	350842	19703U	PARTICIPANT	\N	PRESENT	0
355558	355557	14065Q	PARTICIPANT	\N	EXCUSE	0
355559	355557	96004D	PRESIDENT	0	PRESENT	0
355560	355557	14089Y	PARTICIPANT	\N	PRESENT	0
355561	355557	14357A	PARTICIPANT	\N	PRESENT	0
355562	355557	14079W	PARTICIPANT	\N	PRESENT	0
355563	355557	14249W	PARTICIPANT	\N	PRESENT	0
355564	355557	04035D	PARTICIPANT	\N	PRESENT	0
355565	355557	11083R	PARTICIPANT	\N	PRESENT	0
355566	355557	14033T	PARTICIPANT	\N	PRESENT	0
355567	355557	14026U	PARTICIPANT	\N	PRESENT	0
355568	355557	19725B	PARTICIPANT	\N	PRESENT	0
355569	355557	95037J	PARTICIPANT	\N	PRESENT	0
355570	355557	04097T	PARTICIPANT	\N	PRESENT	0
355571	355557	14097Y	PARTICIPANT	\N	PRESENT	0
355572	355557	04061F	PARTICIPANT	\N	PRESENT	0
355573	355557	14073Q	PARTICIPANT	\N	PRESENT	0
355574	355557	08039A	PARTICIPANT	\N	PRESENT	0
355575	355557	14205J	PARTICIPANT	\N	PRESENT	0
355576	355557	14221J	PARTICIPANT	\N	PRESENT	0
355577	355557	19593H	PARTICIPANT	\N	PRESENT	0
355578	355557	14237S	PARTICIPANT	\N	PRESENT	0
355579	355557	14135M	PARTICIPANT	\N	PRESENT	0
355580	355557	14331P	PARTICIPANT	\N	PRESENT	0
355581	355557	10015M	PARTICIPANT	\N	PRESENT	0
355583	355557	08018U	PARTICIPANT	\N	EXCUSE	0
355584	355557	19569H	PARTICIPANT	\N	EXCUSE	0
355585	355557	14061L	PARTICIPANT	\N	EXCUSE	0
355586	355557	04057K	PARTICIPANT	\N	EXCUSE	0
355587	355557	14001X	PARTICIPANT	\N	EXCUSE	0
355588	355557	14133K	PARTICIPANT	\N	EXCUSE	0
355642	355640	04092N	PARTICIPANT	\N	PRESENT	0
355643	355641	04092N	PARTICIPANT	\N	PRESENT	0
355726	355707	19443T	PARTICIPANT	\N	PRESENT	0
355727	355707	19543W	PARTICIPANT	\N	PRESENT	0
355728	355707	11066Q	PARTICIPANT	\N	PRESENT	0
355729	355707	19585H	PARTICIPANT	\N	PRESENT	0
355730	355707	04047H	PARTICIPANT	\N	PRESENT	0
355731	355707	19673G	PARTICIPANT	\N	PRESENT	0
355732	355707	05008E	PRESIDENT	0	PRESENT	0
355733	355707	19447X	PARTICIPANT	\N	PRESENT	0
355734	355707	14231L	PARTICIPANT	\N	PRESENT	0
355735	355707	14237S	PARTICIPANT	\N	PRESENT	0
355736	355707	14041T	PARTICIPANT	\N	PRESENT	0
355737	355707	14179A	PARTICIPANT	\N	PRESENT	0
355738	355707	14147R	PARTICIPANT	\N	PRESENT	0
355739	355707	14217N	PARTICIPANT	\N	PRESENT	0
355740	355707	14259Y	PARTICIPANT	\N	PRESENT	0
355741	355707	14053L	PARTICIPANT	\N	PRESENT	0
355742	355707	07034Q	PARTICIPANT	\N	PRESENT	0
355743	355707	10015M	PARTICIPANT	\N	PRESENT	0
355744	355707	01024M	PARTICIPANT	\N	PRESENT	0
355745	355707	19691J	PARTICIPANT	\N	PRESENT	0
355746	355707	19719D	PARTICIPANT	\N	PRESENT	0
355747	355707	14089Y	PARTICIPANT	\N	PRESENT	0
355748	355707	19725B	PARTICIPANT	\N	PRESENT	0
355749	355707	04088S	PARTICIPANT	\N	PRESENT	0
355750	355707	19629C	PARTICIPANT	\N	PRESENT	0
355751	355707	14069U	PARTICIPANT	\N	PRESENT	0
355752	355707	11049P	PARTICIPANT	\N	PRESENT	0
355753	355707	14021P	PARTICIPANT	\N	PRESENT	0
355754	355707	01028R	PARTICIPANT	\N	PRESENT	0
355755	355707	19729F	PARTICIPANT	\N	EXCUSE	0
355756	355707	04044E	PARTICIPANT	\N	EXCUSE	0
355757	353812	14327T	PARTICIPANT	\N	PRESENT	0
355758	353812	14331P	PARTICIPANT	\N	PRESENT	0
360345	345224	14215L	PARTICIPANT	\N	PRESENT	0
360346	345224	04059M	PARTICIPANT	\N	PRESENT	0
360347	345224	14151M	PARTICIPANT	\N	PRESENT	0
360348	345224	19649G	PARTICIPANT	\N	PRESENT	0
360349	345224	11033F	PARTICIPANT	\N	PRESENT	0
360350	345224	19565D	PARTICIPANT	\N	PRESENT	0
360351	345224	19593H	PARTICIPANT	\N	PRESENT	0
360352	345224	14001X	PARTICIPANT	\N	PRESENT	0
360353	345224	19629C	PARTICIPANT	\N	PRESENT	0
360354	345224	19349W	PARTICIPANT	\N	PRESENT	0
360355	345224	19782L	PARTICIPANT	\N	PRESENT	0
360356	345224	14021P	PARTICIPANT	\N	PRESENT	0
360357	345224	95063L	PARTICIPANT	\N	PRESENT	0
360358	345224	11026G	PARTICIPANT	\N	PRESENT	0
360359	345224	19599P	PARTICIPANT	\N	PRESENT	0
360360	345224	19713W	PARTICIPANT	\N	PRESENT	0
360361	345224	19253P	PARTICIPANT	\N	PRESENT	0
360362	345224	19681G	PARTICIPANT	\N	PRESENT	0
360363	345224	01025N	PARTICIPANT	\N	PRESENT	0
360364	345224	19687N	PARTICIPANT	\N	PRESENT	0
360365	345224	14157T	PARTICIPANT	\N	PRESENT	0
360366	345224	08069G	PARTICIPANT	\N	PRESENT	0
360367	345224	11080N	PARTICIPANT	\N	PRESENT	0
360368	345224	19794Q	PARTICIPANT	\N	PRESENT	0
360369	345224	19703U	PARTICIPANT	\N	PRESENT	0
360370	345224	14029X	PARTICIPANT	\N	PRESENT	0
360371	345224	19733B	PARTICIPANT	\N	PRESENT	0
360372	345224	19443T	PARTICIPANT	\N	PRESENT	0
360373	345224	19447X	PARTICIPANT	\N	PRESENT	0
360374	345224	19729F	PARTICIPANT	\N	PRESENT	0
360375	345224	19693L	PARTICIPANT	\N	PRESENT	0
360376	345224	08047A	PARTICIPANT	\N	PRESENT	0
360377	345224	19679N	PARTICIPANT	\N	PRESENT	0
360378	345224	95030B	PARTICIPANT	\N	PRESENT	0
360379	345224	14069U	PARTICIPANT	\N	PRESENT	0
360380	345224	04033B	PARTICIPANT	\N	PRESENT	0
360381	345224	17637T	PARTICIPANT	\N	PRESENT	0
360382	345224	96004D	PARTICIPANT	\N	PRESENT	0
360383	345224	04018C	PARTICIPANT	\N	PRESENT	0
360384	345224	19762G	PARTICIPANT	\N	PRESENT	0
360385	345224	14079W	PARTICIPANT	\N	PRESENT	0
360386	345224	19551W	PARTICIPANT	\N	PRESENT	0
360387	345224	19747H	PARTICIPANT	\N	PRESENT	0
360388	345224	11077T	PARTICIPANT	\N	PRESENT	0
360389	345224	14235Q	PARTICIPANT	\N	PRESENT	0
360390	345224	95041E	PARTICIPANT	\N	PRESENT	0
360391	345224	19575F	PARTICIPANT	\N	PRESENT	0
360392	345224	14087W	PARTICIPANT	\N	PRESENT	0
360393	345224	08031R	PARTICIPANT	\N	PRESENT	0
360394	345224	07029T	PARTICIPANT	\N	PRESENT	0
360395	345224	04097T	PARTICIPANT	\N	PRESENT	0
360396	345224	08015R	PARTICIPANT	\N	PRESENT	0
360397	345224	14147R	PARTICIPANT	\N	PRESENT	0
360398	345224	14213J	PARTICIPANT	\N	PRESENT	0
360399	345224	19383Y	PARTICIPANT	\N	PRESENT	0
360400	345224	04049K	PARTICIPANT	\N	PRESENT	0
360401	345224	11043H	PARTICIPANT	\N	PRESENT	0
360402	345224	14179A	PARTICIPANT	\N	PRESENT	0
360403	345224	14331P	PARTICIPANT	\N	PRESENT	0
360404	345224	14105F	PARTICIPANT	\N	PRESENT	0
360405	345224	11048N	PARTICIPANT	\N	PRESENT	0
360406	345224	10006L	PARTICIPANT	\N	PRESENT	0
360407	345224	14187A	PARTICIPANT	\N	PRESENT	0
360408	345224	14071N	PARTICIPANT	\N	PRESENT	0
360409	345224	05008E	PARTICIPANT	\N	PRESENT	0
360410	345224	04085P	PARTICIPANT	\N	PRESENT	0
360343	345224	14034U	PARTICIPANT	\N	PRESENT	0
360344	345224	04044E	PARTICIPANT	\N	PRESENT	0
360411	345224	14217N	PARTICIPANT	\N	PRESENT	0
360412	345224	08034U	PARTICIPANT	\N	PRESENT	0
360413	345224	19413M	PARTICIPANT	\N	PRESENT	0
360414	345224	19503N	PARTICIPANT	\N	PRESENT	0
360415	345224	19585H	PARTICIPANT	\N	PRESENT	0
360416	345224	14026U	PARTICIPANT	\N	PRESENT	0
360417	345224	14265W	PARTICIPANT	\N	PRESENT	0
360418	345224	14089Y	PARTICIPANT	\N	PRESENT	0
360419	345224	14231L	PARTICIPANT	\N	PRESENT	0
360420	345224	19531S	PARTICIPANT	\N	PRESENT	0
360421	345224	19467C	PARTICIPANT	\N	PRESENT	0
360422	345224	08045X	PARTICIPANT	\N	PRESENT	0
360423	345224	11097X	PARTICIPANT	\N	PRESENT	0
360424	345224	14357A	PARTICIPANT	\N	PRESENT	0
360425	345224	04035D	PARTICIPANT	\N	PRESENT	0
360427	358103	14133K	PRESIDENT	0	PRESENT	0
360428	358103	95030B	PARTICIPANT	\N	PRESENT	0
360429	358103	14235Q	PARTICIPANT	\N	PRESENT	0
360430	358103	14267Y	PARTICIPANT	\N	PRESENT	0
360431	358103	19721W	PARTICIPANT	\N	PRESENT	0
360441	358958	95041E	PARTICIPANT	\N	PRESENT	0
360442	358958	19711U	PARTICIPANT	\N	PRESENT	0
360443	358958	07004J	PARTICIPANT	\N	PRESENT	0
360444	358958	14121F	PARTICIPANT	\N	PRESENT	0
360445	358958	99004R	PARTICIPANT	\N	PRESENT	0
360447	358958	19667J	PARTICIPANT	\N	PRESENT	0
360448	358958	11074Q	PRESIDENT	0	PRESENT	0
360449	358958	14173T	PARTICIPANT	\N	PRESENT	0
360452	358103	19443T	PARTICIPANT	\N	PRESENT	0
360453	358103	04034C	PARTICIPANT	\N	PRESENT	0
360454	358103	11041F	PARTICIPANT	\N	PRESENT	0
360455	358103	01058X	PARTICIPANT	\N	PRESENT	0
360456	358103	16685X	PARTICIPANT	\N	PRESENT	0
360457	358103	08058D	PARTICIPANT	\N	PRESENT	0
360458	358103	14028W	PARTICIPANT	\N	PRESENT	0
360459	358103	11054L	PARTICIPANT	\N	PRESENT	0
360460	358103	11066Q	PARTICIPANT	\N	PRESENT	0
360461	358103	98022P	PARTICIPANT	\N	PRESENT	0
360462	358103	98050T	PARTICIPANT	\N	PRESENT	0
360463	358103	97011G	PARTICIPANT	\N	PRESENT	0
360464	358103	14211G	PARTICIPANT	\N	PRESENT	0
360465	358103	08047A	PARTICIPANT	\N	PRESENT	0
360466	358103	11064N	PARTICIPANT	\N	PRESENT	0
360467	358103	19421M	PARTICIPANT	\N	PRESENT	0
360468	358103	14105F	PARTICIPANT	\N	PRESENT	0
360469	358103	95037J	PARTICIPANT	\N	PRESENT	0
360470	358103	04035D	PARTICIPANT	\N	PRESENT	0
360471	358103	95067Q	PARTICIPANT	\N	PRESENT	0
360472	358103	98018T	PARTICIPANT	\N	EXCUSE	0
360473	358103	04042C	PARTICIPANT	\N	EXCUSE	0
360554	357037	14227Q	PARTICIPANT	\N	PRESENT	0
360559	357037	19760E	PARTICIPANT	\N	PRESENT	0
360560	357037	14261S	PARTICIPANT	\N	PRESENT	0
360561	357037	19575F	PARTICIPANT	\N	PRESENT	0
360562	357037	19367Y	PARTICIPANT	\N	PRESENT	0
360563	357037	19415P	PARTICIPANT	\N	EXCUSE	0
360564	357037	14195A	PARTICIPANT	\N	PRESENT	0
360565	357037	11031D	PARTICIPANT	\N	PRESENT	0
360566	357037	08052W	PARTICIPANT	\N	PRESENT	0
360568	357037	19663E	PARTICIPANT	\N	PRESENT	0
360569	357037	19577H	PARTICIPANT	\N	PRESENT	0
360570	357037	14042U	PARTICIPANT	\N	PRESENT	0
360571	357037	14217N	PARTICIPANT	\N	PRESENT	0
360572	357037	10006L	PARTICIPANT	\N	PRESENT	0
360573	357037	98024R	PARTICIPANT	\N	PRESENT	0
360574	357037	14087W	PARTICIPANT	\N	PRESENT	0
360575	357037	19521Q	PARTICIPANT	\N	PRESENT	0
360576	357037	08048B	PARTICIPANT	\N	PRESENT	0
360577	357037	08041T	PARTICIPANT	\N	EXCUSE	0
360578	357037	19565D	PARTICIPANT	\N	PRESENT	0
360579	357037	19727D	PARTICIPANT	\N	PRESENT	0
360580	357037	14026U	PARTICIPANT	\N	PRESENT	0
360581	357037	19691J	PARTICIPANT	\N	PRESENT	0
360582	357037	19553Y	PARTICIPANT	\N	PRESENT	0
360583	357037	14213J	PARTICIPANT	\N	PRESENT	0
360584	357037	19723Y	PARTICIPANT	\N	PRESENT	0
360585	357037	19697Q	PARTICIPANT	\N	PRESENT	0
360586	357037	19683J	PARTICIPANT	\N	PRESENT	0
360587	357037	17779H	PARTICIPANT	\N	PRESENT	0
360588	357037	14223L	PARTICIPANT	\N	PRESENT	0
360589	357037	04092N	PRESIDENT	0	PRESENT	0
360590	357037	14119M	PARTICIPANT	\N	PRESENT	0
360591	357037	19679N	PARTICIPANT	\N	PRESENT	0
360592	357037	19798U	PARTICIPANT	\N	PRESENT	0
360594	357037	11045K	PARTICIPANT	\N	PRESENT	0
360595	357037	04045F	PARTICIPANT	\N	PRESENT	0
360596	357037	19703U	PARTICIPANT	\N	PRESENT	0
360597	357037	19527W	PARTICIPANT	\N	PRESENT	0
360598	357037	01034P	PARTICIPANT	\N	PRESENT	0
360599	357037	11097X	PARTICIPANT	\N	PRESENT	0
360600	357037	11067R	PARTICIPANT	\N	EXCUSE	0
360601	357037	19657G	PARTICIPANT	\N	PRESENT	0
360604	360603	07033P	PARTICIPANT	\N	PRESENT	0
360605	360603	97011G	PARTICIPANT	\N	PRESENT	0
360606	360603	04049K	PARTICIPANT	\N	PRESENT	0
360607	360603	14059S	PARTICIPANT	\N	PRESENT	0
360608	360603	19762G	PARTICIPANT	\N	PRESENT	0
360609	360603	08020N	PARTICIPANT	\N	PRESENT	0
360612	358889	19515S	PARTICIPANT	\N	PRESENT	0
360613	358889	19782L	PARTICIPANT	\N	PRESENT	0
360614	358889	14357A	PARTICIPANT	\N	PRESENT	0
334407	334406	14065Q	PARTICIPANT	\N	PRESENT	0
340456	340455	04059M	PARTICIPANT	\N	PRESENT	0
340458	340457	04059M	PARTICIPANT	\N	PRESENT	0
340459	340457	14229S	PARTICIPANT	\N	PRESENT	0
344121	343680	08043V	PARTICIPANT	\N	EXCUSE	0
344122	343680	19621T	PARTICIPANT	\N	EXCUSE	0
344123	343680	11031D	PARTICIPANT	\N	EXCUSE	0
344124	343680	19693L	PARTICIPANT	\N	EXCUSE	0
344125	343680	19577H	PARTICIPANT	\N	EXCUSE	0
344126	343680	14249W	PARTICIPANT	\N	EXCUSE	0
344127	343680	01043Q	PARTICIPANT	\N	EXCUSE	0
344567	342817	04045F	PARTICIPANT	\N	EXCUSE	0
344665	344664	11048N	PARTICIPANT	\N	PRESENT	0
344666	344664	14083S	PARTICIPANT	\N	PRESENT	0
344667	344664	04049K	PARTICIPANT	\N	PRESENT	0
344668	344664	11090Q	PARTICIPANT	\N	PRESENT	0
344669	344664	14329V	PARTICIPANT	\N	PRESENT	0
344670	344664	04071H	PARTICIPANT	\N	PRESENT	0
344671	344664	11053K	PARTICIPANT	\N	PRESENT	0
344672	344664	19695N	PARTICIPANT	\N	PRESENT	0
344673	344664	19667J	PARTICIPANT	\N	PRESENT	0
345034	341436	99004R	PARTICIPANT	\N	PRESENT	0
345129	341436	19369B	PARTICIPANT	\N	PRESENT	0
345209	345208	14079W	PARTICIPANT	\N	PRESENT	0
345211	345210	14193X	PARTICIPANT	\N	PRESENT	0
345212	345210	98022P	PARTICIPANT	\N	PRESENT	0
345214	345213	14193X	PARTICIPANT	\N	PRESENT	0
345215	345213	98022P	PARTICIPANT	\N	PRESENT	0
345217	345216	14193X	PARTICIPANT	\N	PRESENT	0
345603	345600	14255U	PARTICIPANT	\N	PRESENT	0
345604	345600	14195A	PARTICIPANT	\N	PRESENT	0
345605	345600	97011G	PARTICIPANT	\N	PRESENT	0
345606	345600	01057W	PARTICIPANT	\N	PRESENT	0
345607	345600	19531S	PARTICIPANT	\N	PRESENT	0
345608	345600	11026G	PARTICIPANT	\N	PRESENT	0
346502	346501	04038G	PARTICIPANT	\N	PRESENT	0
346504	346501	19575F	PARTICIPANT	\N	PRESENT	0
346505	346501	11027H	PARTICIPANT	\N	PRESENT	0
346506	346501	14065Q	PARTICIPANT	\N	PRESENT	0
346507	346501	04086Q	PARTICIPANT	\N	PRESENT	0
346508	346501	05012A	PARTICIPANT	\N	PRESENT	0
346509	346501	97011G	PARTICIPANT	\N	PRESENT	0
346510	346501	19565D	PARTICIPANT	\N	PRESENT	0
346511	346501	08012N	PARTICIPANT	\N	PRESENT	0
346512	346501	08018U	PARTICIPANT	\N	PRESENT	0
346513	346501	14071N	PARTICIPANT	\N	PRESENT	0
346514	346501	08017T	PARTICIPANT	\N	PRESENT	0
347230	339516	14105F	PARTICIPANT	\N	PRESENT	0
347231	339516	11049P	PARTICIPANT	\N	PRESENT	0
347232	339516	08019V	PARTICIPANT	\N	PRESENT	0
347233	339516	11010L	PARTICIPANT	\N	PRESENT	0
347234	339516	14041T	PARTICIPANT	\N	PRESENT	0
347235	339516	19681G	PARTICIPANT	\N	PRESENT	0
347236	339516	98022P	PARTICIPANT	\N	PRESENT	0
347237	339516	14157T	PARTICIPANT	\N	PRESENT	0
347238	339516	14231L	PARTICIPANT	\N	PRESENT	0
347239	339516	11103C	PARTICIPANT	\N	PRESENT	0
347240	339516	19629C	PARTICIPANT	\N	PRESENT	0
347241	339516	19525U	PARTICIPANT	\N	PRESENT	0
347242	339516	11077T	PARTICIPANT	\N	PRESENT	0
347243	339516	14147R	PARTICIPANT	\N	PRESENT	0
347244	339516	17779H	PARTICIPANT	\N	PRESENT	0
347245	339516	80013X	PARTICIPANT	\N	PRESENT	0
347246	339516	19745F	PARTICIPANT	\N	PRESENT	0
347247	339516	19619A	PARTICIPANT	\N	PRESENT	0
347248	339516	95062K	PARTICIPANT	\N	PRESENT	0
347249	339516	11101A	PARTICIPANT	\N	PRESENT	0
347250	339516	19415P	PARTICIPANT	\N	PRESENT	0
347251	339516	07034Q	PARTICIPANT	\N	PRESENT	0
347252	339516	14207L	PARTICIPANT	\N	PRESENT	0
347253	339516	14201E	PARTICIPANT	\N	PRESENT	0
347254	339516	19319Q	PARTICIPANT	\N	PRESENT	0
347255	339516	11041F	PARTICIPANT	\N	PRESENT	0
347256	339516	08055A	PARTICIPANT	\N	PRESENT	0
347257	339516	14133K	PARTICIPANT	\N	PRESENT	0
347258	339516	19721W	PARTICIPANT	\N	PRESENT	0
347259	339516	19383Y	PARTICIPANT	\N	PRESENT	0
347260	339516	17589D	PARTICIPANT	\N	PRESENT	0
347261	339516	08051V	PARTICIPANT	\N	PRESENT	0
347262	339516	14042U	PARTICIPANT	\N	PRESENT	0
347263	339516	19611R	PARTICIPANT	\N	PRESENT	0
347264	339516	11033F	PARTICIPANT	\N	PRESENT	0
347265	339516	04097T	PARTICIPANT	\N	PRESENT	0
347266	339516	19723Y	PARTICIPANT	\N	PRESENT	0
347267	339516	10006L	PARTICIPANT	\N	PRESENT	0
347268	339516	19701S	PARTICIPANT	\N	PRESENT	0
347269	339516	19347U	PARTICIPANT	\N	PRESENT	0
347270	339516	08035V	PARTICIPANT	\N	PRESENT	0
347271	339516	01048V	PARTICIPANT	\N	PRESENT	0
347272	339516	08034U	PARTICIPANT	\N	PRESENT	0
347273	339516	11056N	PARTICIPANT	\N	PRESENT	0
347274	339516	19467C	PARTICIPANT	\N	PRESENT	0
347275	339516	19591F	PARTICIPANT	\N	PRESENT	0
347276	339516	19766L	PARTICIPANT	\N	PRESENT	0
347277	339516	11054L	PARTICIPANT	\N	PRESENT	0
347278	339516	08015R	PARTICIPANT	\N	PRESENT	0
347279	339516	19295A	PARTICIPANT	\N	PRESENT	0
347280	339516	11104D	PARTICIPANT	\N	PRESENT	0
347281	339516	11066Q	PARTICIPANT	\N	PRESENT	0
347282	339516	14253S	PARTICIPANT	\N	PRESENT	0
347283	339516	19507S	PARTICIPANT	\N	PRESENT	0
347284	339516	08039A	PARTICIPANT	\N	PRESENT	0
347285	339516	19697Q	PARTICIPANT	\N	PRESENT	0
347286	339516	19349W	PARTICIPANT	\N	PRESENT	0
347287	339516	14199E	PARTICIPANT	\N	PRESENT	0
347288	339516	08061X	PARTICIPANT	\N	PRESENT	0
347289	339516	95037J	PARTICIPANT	\N	PRESENT	0
347290	339516	18083K	PARTICIPANT	\N	PRESENT	0
347291	339516	04059M	PARTICIPANT	\N	PRESENT	0
347292	339516	92040Q	PARTICIPANT	\N	PRESENT	0
347293	339516	87003B	PARTICIPANT	\N	PRESENT	0
347294	339516	17583W	PARTICIPANT	\N	PRESENT	0
347299	339516	19768N	PARTICIPANT	\N	PRESENT	0
347296	339516	08010L	PARTICIPANT	\N	PRESENT	0
347297	339516	04035D	PARTICIPANT	\N	PRESENT	0
347298	339516	17637T	PARTICIPANT	\N	PRESENT	0
347300	339516	14031R	PARTICIPANT	\N	PRESENT	0
347301	339516	04088S	PARTICIPANT	\N	PRESENT	0
347302	339516	19683J	PARTICIPANT	\N	PRESENT	0
347303	339516	19515S	PARTICIPANT	\N	PRESENT	0
347304	339516	08011M	PARTICIPANT	\N	PRESENT	0
347305	339516	19711U	PARTICIPANT	\N	PRESENT	0
347306	339516	14135M	PARTICIPANT	\N	PRESENT	0
347307	339516	19533U	PARTICIPANT	\N	PRESENT	0
347308	339516	11097X	PARTICIPANT	\N	PRESENT	0
347228	339516	19675J	PARTICIPANT	\N	PRESENT	0
347229	339516	14329V	PARTICIPANT	\N	PRESENT	0
347309	339516	01058X	PARTICIPANT	\N	PRESENT	0
347310	339516	19703U	PARTICIPANT	\N	PRESENT	0
347311	339516	19741B	PARTICIPANT	\N	PRESENT	0
347312	339516	96004D	PARTICIPANT	\N	PRESENT	0
347313	339516	11090Q	PARTICIPANT	\N	PRESENT	0
347314	339516	19762G	PARTICIPANT	\N	PRESENT	0
347315	339516	97011G	PARTICIPANT	\N	PRESENT	0
347316	339516	14187A	PARTICIPANT	\N	PRESENT	0
347317	339516	04085P	PARTICIPANT	\N	PRESENT	0
347318	339516	11040E	PARTICIPANT	\N	PRESENT	0
347319	339516	12041X	PARTICIPANT	\N	PRESENT	0
347320	339516	14235Q	PARTICIPANT	\N	PRESENT	0
347321	339516	11115U	PARTICIPANT	\N	PRESENT	0
347322	339516	99004R	PARTICIPANT	\N	PRESENT	0
347323	339516	19695N	PARTICIPANT	\N	PRESENT	0
347324	339516	19593H	PARTICIPANT	\N	PRESENT	0
347325	339516	19760E	PARTICIPANT	\N	PRESENT	0
347326	339516	04034C	PARTICIPANT	\N	PRESENT	0
347327	339516	19565D	PARTICIPANT	\N	PRESENT	0
347328	339516	19637C	PARTICIPANT	\N	PRESENT	0
347329	339516	98024R	PARTICIPANT	\N	PRESENT	0
347330	339516	95063L	PARTICIPANT	\N	PRESENT	0
347331	339516	04047H	PARTICIPANT	\N	PRESENT	0
347332	339516	08021P	PARTICIPANT	\N	PRESENT	0
347333	339516	14026U	PARTICIPANT	\N	PRESENT	0
347334	339516	19301E	PARTICIPANT	\N	PRESENT	0
347335	339516	19679N	PARTICIPANT	\N	PRESENT	0
347336	339516	11012A	PARTICIPANT	\N	PRESENT	0
347337	339516	19643A	PARTICIPANT	\N	PRESENT	0
347338	339516	08031R	PARTICIPANT	\N	PRESENT	0
347339	339516	88008L	PARTICIPANT	\N	PRESENT	0
347340	339516	08069G	PARTICIPANT	\N	PRESENT	0
347341	339516	11083R	PARTICIPANT	\N	PRESENT	0
347342	339516	19563B	PARTICIPANT	\N	PRESENT	0
347343	339516	14241N	PARTICIPANT	\N	PRESENT	0
347344	339516	19387D	PARTICIPANT	\N	PRESENT	0
347345	339516	04044E	PARTICIPANT	\N	PRESENT	0
347346	339516	19782L	PARTICIPANT	\N	PRESENT	0
347347	339516	14069U	PARTICIPANT	\N	PRESENT	0
347348	339516	04057K	PARTICIPANT	\N	PRESENT	0
347349	339516	14249W	PARTICIPANT	\N	PRESENT	0
347350	339516	14251Q	PARTICIPANT	\N	PRESENT	0
358173	356272	14065Q	PARTICIPANT	\N	PRESENT	0
358174	356272	96004D	PRESIDENT	0	PRESENT	0
358176	356272	14089Y	PARTICIPANT	\N	PRESENT	0
358177	356272	14357A	PARTICIPANT	\N	PRESENT	0
358178	356272	14079W	PARTICIPANT	\N	PRESENT	0
358180	356272	11083R	PARTICIPANT	\N	PRESENT	0
358183	356272	19553Y	PARTICIPANT	\N	PRESENT	0
358184	356272	19725B	PARTICIPANT	\N	PRESENT	0
358186	356272	95037J	PARTICIPANT	\N	PRESENT	0
358187	356272	04097T	PARTICIPANT	\N	PRESENT	0
358189	356272	14097Y	PARTICIPANT	\N	PRESENT	0
358192	356272	04061F	PARTICIPANT	\N	PRESENT	0
358194	356272	14073Q	PARTICIPANT	\N	PRESENT	0
358195	356272	11026G	PARTICIPANT	\N	PRESENT	0
358197	356272	08039A	PARTICIPANT	\N	PRESENT	0
358200	356272	14001X	PARTICIPANT	\N	PRESENT	0
358201	356272	04057K	PARTICIPANT	\N	PRESENT	0
358202	356272	19563B	PARTICIPANT	\N	PRESENT	0
358204	356272	14135M	PARTICIPANT	\N	PRESENT	0
358205	356272	14331P	PARTICIPANT	\N	PRESENT	0
358207	356272	14225N	PARTICIPANT	\N	PRESENT	0
358209	356272	10015M	PARTICIPANT	\N	PRESENT	0
358224	356272	14033T	PARTICIPANT	\N	EXCUSE	0
358318	358313	19631V	PARTICIPANT	\N	PRESENT	0
358324	358313	19667J	PARTICIPANT	\N	PRESENT	0
358327	358313	14115H	PARTICIPANT	\N	PRESENT	0
358329	358313	19747H	PARTICIPANT	\N	PRESENT	0
358333	358313	19295A	PARTICIPANT	\N	PRESENT	0
358337	358313	14357A	PARTICIPANT	\N	PRESENT	0
358340	358313	14033T	PARTICIPANT	\N	PRESENT	0
358344	358313	19563B	PARTICIPANT	\N	PRESENT	0
358346	358313	14257W	PARTICIPANT	\N	PRESENT	0
358348	358313	14265W	PARTICIPANT	\N	PRESENT	0
358350	358313	11090Q	PARTICIPANT	\N	PRESENT	0
358352	358313	19269X	PARTICIPANT	\N	PRESENT	0
358379	358313	11027H	PARTICIPANT	\N	PRESENT	0
358386	358313	19507S	PARTICIPANT	\N	PRESENT	0
358389	358313	14187A	PARTICIPANT	\N	PRESENT	0
358415	356164	19727D	PARTICIPANT	\N	PRESENT	0
358416	356181	19727D	PARTICIPANT	\N	PRESENT	0
358858	355640	11097X	PARTICIPANT	\N	PRESENT	0
358859	355640	10006L	PARTICIPANT	\N	PRESENT	0
358860	355640	19575F	PARTICIPANT	\N	PRESENT	0
358861	355640	19691J	PARTICIPANT	\N	PRESENT	0
358862	355640	08052W	PARTICIPANT	\N	PRESENT	0
358863	355640	14239U	PARTICIPANT	\N	PRESENT	0
358864	355641	11097X	PARTICIPANT	\N	PRESENT	0
358865	355641	10006L	PARTICIPANT	\N	PRESENT	0
358866	355641	19575F	PARTICIPANT	\N	PRESENT	0
358867	355641	19691J	PARTICIPANT	\N	PRESENT	0
358868	355641	08052W	PARTICIPANT	\N	PRESENT	0
358869	355641	14239U	PARTICIPANT	\N	PRESENT	0
360474	358958	14327T	PARTICIPANT	\N	PRESENT	0
360475	358958	19479G	PARTICIPANT	\N	PRESENT	0
360476	358958	01057W	PARTICIPANT	\N	PRESENT	0
360477	358958	19689Q	PARTICIPANT	\N	PRESENT	0
360478	358958	11053K	PARTICIPANT	\N	PRESENT	0
360479	358958	08011M	PARTICIPANT	\N	PRESENT	0
360480	358958	89017R	PARTICIPANT	\N	PRESENT	0
360481	358958	08014Q	PARTICIPANT	\N	PRESENT	0
360482	358958	14159V	PARTICIPANT	\N	PRESENT	0
360483	358958	88008L	PARTICIPANT	\N	PRESENT	0
360484	358958	11040E	PARTICIPANT	\N	PRESENT	0
360485	358958	04086Q	PARTICIPANT	\N	PRESENT	0
360486	358958	14085U	PARTICIPANT	\N	PRESENT	0
360487	358958	19741B	PARTICIPANT	\N	PRESENT	0
360488	358958	04061F	PARTICIPANT	\N	PRESENT	0
360489	358103	98029W	PARTICIPANT	\N	PRESENT	0
360490	358103	04040A	PARTICIPANT	\N	PRESENT	0
360491	358103	14193X	PARTICIPANT	\N	PRESENT	0
360492	358103	14097Y	PARTICIPANT	\N	PRESENT	0
360493	358103	19251M	PARTICIPANT	\N	PRESENT	0
360500	358103	12041X	PARTICIPANT	\N	PRESENT	0
360503	358053	14038Y	PRESIDENT	0	PRESENT	0
360504	358053	19383Y	PARTICIPANT	\N	PRESENT	0
360505	358053	17583W	PARTICIPANT	\N	PRESENT	0
360506	358053	14103D	PARTICIPANT	\N	PRESENT	0
360507	358053	19701S	PARTICIPANT	\N	PRESENT	0
360508	358053	14031R	PARTICIPANT	\N	PRESENT	0
360509	358053	95062K	PARTICIPANT	\N	PRESENT	0
360510	358053	19387D	PARTICIPANT	\N	PRESENT	0
360511	358053	14221J	PARTICIPANT	\N	PRESENT	0
360512	358053	08055A	PARTICIPANT	\N	PRESENT	0
360513	358053	19599P	PARTICIPANT	\N	PRESENT	0
360514	358053	14237S	PARTICIPANT	\N	PRESENT	0
360515	358053	18083K	PARTICIPANT	\N	PRESENT	0
360516	358053	14051J	PARTICIPANT	\N	PRESENT	0
360517	358053	19739H	PARTICIPANT	\N	PRESENT	0
360518	358053	14157T	PARTICIPANT	\N	PRESENT	0
360519	358053	19745F	PARTICIPANT	\N	PRESENT	0
360520	358053	11065P	PARTICIPANT	\N	PRESENT	0
360521	358053	08009T	PARTICIPANT	\N	EXCUSE	0
360522	358053	19347U	PARTICIPANT	\N	EXCUSE	0
360523	358053	19737F	PARTICIPANT	\N	PRESENT	0
360524	358053	19685L	PARTICIPANT	\N	EXCUSE	0
360525	358053	19659J	PARTICIPANT	\N	EXCUSE	0
360526	358053	19637C	PARTICIPANT	\N	EXCUSE	0
360527	358958	04071H	PARTICIPANT	\N	PRESENT	0
360528	358958	01048V	PARTICIPANT	\N	PRESENT	0
360529	358958	11110B	PARTICIPANT	\N	PRESENT	0
360530	358958	07029T	PARTICIPANT	\N	PRESENT	0
360531	358958	08010L	PARTICIPANT	\N	PRESENT	0
360532	358958	11048N	PARTICIPANT	\N	PRESENT	0
360533	358958	08034U	PARTICIPANT	\N	PRESENT	0
360534	358958	08069G	PARTICIPANT	\N	PRESENT	0
360535	358958	14083S	PARTICIPANT	\N	PRESENT	0
360536	358958	14331P	PARTICIPANT	\N	EXCUSE	0
360537	358958	14199E	PARTICIPANT	\N	EXCUSE	0
360538	358958	19671E	PARTICIPANT	\N	EXCUSE	0
360539	358053	19333N	PARTICIPANT	\N	PRESENT	0
360540	358053	08060W	PARTICIPANT	\N	PRESENT	0
360541	358053	19794Q	PARTICIPANT	\N	PRESENT	0
360542	358053	19549D	PARTICIPANT	\N	PRESENT	0
360543	358053	14219Q	PARTICIPANT	\N	PRESENT	0
360544	358053	19503N	PARTICIPANT	\N	PRESENT	0
360545	358053	08024S	PARTICIPANT	\N	PRESENT	0
360548	358053	14169X	PARTICIPANT	\N	PRESENT	0
360555	358958	19349W	PARTICIPANT	\N	PRESENT	0
360556	358958	19531S	PARTICIPANT	\N	PRESENT	0
360935	345226	19629C	PARTICIPANT	\N	PRESENT	0
360558	358958	11012A	PARTICIPANT	\N	PRESENT	0
360567	358053	19681G	PARTICIPANT	\N	PRESENT	0
360593	358053	19551W	PARTICIPANT	\N	PRESENT	0
360602	358053	19733B	PARTICIPANT	\N	PRESENT	0
360610	358958	14225N	PARTICIPANT	\N	PRESENT	0
360611	358053	19713W	PARTICIPANT	\N	PRESENT	0
360658	359466	19766L	PARTICIPANT	\N	PRESENT	0
360659	359466	04070G	PRESIDENT	0	PRESENT	0
360660	359466	19699S	PARTICIPANT	\N	PRESENT	0
360661	359466	19533U	PARTICIPANT	\N	PRESENT	0
360662	359466	14229S	PARTICIPANT	\N	PRESENT	0
360663	359466	14241N	PARTICIPANT	\N	PRESENT	0
360664	359466	19573D	PARTICIPANT	\N	PRESENT	0
360665	359466	14039A	PARTICIPANT	\N	PRESENT	0
360666	359466	08017T	PARTICIPANT	\N	PRESENT	0
360667	359466	92040Q	PARTICIPANT	\N	PRESENT	0
360668	359466	14179A	PARTICIPANT	\N	PRESENT	0
360669	359466	07033P	PARTICIPANT	\N	PRESENT	0
360670	359466	14249W	PARTICIPANT	\N	PRESENT	0
360671	359466	08039A	PARTICIPANT	\N	PRESENT	0
360672	359466	08031R	PARTICIPANT	\N	PRESENT	0
360673	359466	19593H	PARTICIPANT	\N	PRESENT	0
360674	359466	19643A	PARTICIPANT	\N	PRESENT	0
360675	359466	14059S	PARTICIPANT	\N	PRESENT	0
360676	359466	14061L	PARTICIPANT	\N	PRESENT	0
360677	359466	04057K	PARTICIPANT	\N	PRESENT	0
360678	359466	14073Q	PARTICIPANT	\N	PRESENT	0
360679	359466	19611R	PARTICIPANT	\N	PRESENT	0
360680	359466	08035V	PARTICIPANT	\N	PRESENT	0
360681	359466	08043V	PARTICIPANT	\N	PRESENT	0
360682	359466	87003B	PARTICIPANT	\N	PRESENT	0
360683	359466	14030Q	PARTICIPANT	\N	PRESENT	0
360684	359466	19731Y	PARTICIPANT	\N	PRESENT	0
360685	359466	08020N	PARTICIPANT	\N	PRESENT	0
360686	359466	04059M	PARTICIPANT	\N	PRESENT	0
360687	359466	19735D	PARTICIPANT	\N	PRESENT	0
360688	359466	14063N	PARTICIPANT	\N	PRESENT	0
360689	359466	14109K	PARTICIPANT	\N	PRESENT	0
360690	359466	11083R	PARTICIPANT	\N	PRESENT	0
360691	359466	14123H	PARTICIPANT	\N	PRESENT	0
360692	359466	11104D	PARTICIPANT	\N	PRESENT	0
360693	359466	11043H	PARTICIPANT	\N	PRESENT	0
360694	359466	04018C	PARTICIPANT	\N	PRESENT	0
360695	359466	19758L	PARTICIPANT	\N	PRESENT	0
360696	359466	19621T	PARTICIPANT	\N	PRESENT	0
360697	359466	19693L	PARTICIPANT	\N	EXCUSE	0
360936	345226	19441R	PARTICIPANT	\N	PRESENT	0
360937	345226	19713W	PARTICIPANT	\N	PRESENT	0
360938	345226	14042U	PARTICIPANT	\N	PRESENT	0
335623	335622	14038Y	PARTICIPANT	\N	PRESENT	0
335624	335622	19333N	PARTICIPANT	\N	PRESENT	0
335625	335622	19713W	PARTICIPANT	\N	PRESENT	0
335626	335622	14029X	PARTICIPANT	\N	PRESENT	0
335627	335622	08009T	PARTICIPANT	\N	PRESENT	0
338291	321415	86034E	PARTICIPANT	\N	PRESENT	0
338292	321415	12041X	PARTICIPANT	\N	PRESENT	0
338293	321415	14085U	PARTICIPANT	\N	PRESENT	0
338294	321415	11026G	PARTICIPANT	\N	PRESENT	0
338295	321415	11048N	PARTICIPANT	\N	PRESENT	0
338296	321415	98035U	PARTICIPANT	\N	PRESENT	0
338297	321415	96004D	PARTICIPANT	\N	PRESENT	0
338298	321415	04042C	PARTICIPANT	\N	PRESENT	0
338299	321415	11083R	PARTICIPANT	\N	PRESENT	0
338300	321415	04034C	PARTICIPANT	\N	PRESENT	0
338301	321415	04057K	PARTICIPANT	\N	PRESENT	0
338302	321415	19553Y	PARTICIPANT	\N	PRESENT	0
338303	321415	07004J	PARTICIPANT	\N	PRESENT	0
338304	321415	19369B	PARTICIPANT	\N	PRESENT	0
338305	321415	19711U	PARTICIPANT	\N	PRESENT	0
338306	321415	10015M	PARTICIPANT	\N	PRESENT	0
338307	321415	19563B	PARTICIPANT	\N	PRESENT	0
338309	321415	14237S	PARTICIPANT	\N	PRESENT	0
338310	321415	11040E	PARTICIPANT	\N	PRESENT	0
338323	321415	19669L	PARTICIPANT	\N	PRESENT	0
338324	321415	14121F	PARTICIPANT	\N	PRESENT	0
338325	321415	19443T	PARTICIPANT	\N	PRESENT	0
338340	321415	01048V	PARTICIPANT	\N	PRESENT	0
338344	321415	98050T	PARTICIPANT	\N	PRESENT	0
338355	321415	19747H	PARTICIPANT	\N	PRESENT	0
338361	321415	04059M	PARTICIPANT	\N	PRESENT	0
338376	321415	80013X	PARTICIPANT	\N	PRESENT	0
338377	321415	19583F	PARTICIPANT	\N	PRESENT	0
338398	321415	19335Q	PARTICIPANT	\N	PRESENT	0
338401	321415	11070L	PARTICIPANT	\N	PRESENT	0
338402	321415	14031R	PARTICIPANT	\N	PRESENT	0
338405	321415	08073C	PARTICIPANT	\N	PRESENT	0
338438	321419	14121F	PARTICIPANT	\N	PRESENT	0
338439	321419	14085U	PARTICIPANT	\N	PRESENT	0
338440	321419	08073C	PARTICIPANT	\N	PRESENT	0
338441	321419	19553Y	PARTICIPANT	\N	PRESENT	0
338442	321419	07004J	PARTICIPANT	\N	PRESENT	0
338443	321419	11048N	PARTICIPANT	\N	PRESENT	0
338444	321419	11070L	PARTICIPANT	\N	PRESENT	0
338445	321419	99004R	PARTICIPANT	\N	PRESENT	0
338446	321419	04057K	PARTICIPANT	\N	PRESENT	0
338447	321419	19335Q	PARTICIPANT	\N	PRESENT	0
338448	321419	14031R	PARTICIPANT	\N	PRESENT	0
338449	321419	14073Q	PARTICIPANT	\N	PRESENT	0
338450	321419	19747H	PARTICIPANT	\N	PRESENT	0
338451	321419	17583W	PARTICIPANT	\N	PRESENT	0
338452	321419	04085P	PARTICIPANT	\N	PRESENT	0
338453	321419	04086Q	PARTICIPANT	\N	PRESENT	0
338454	321419	19301E	PARTICIPANT	\N	PRESENT	0
338455	321419	80013X	PARTICIPANT	\N	PRESENT	0
338489	338469	14053L	PARTICIPANT	\N	PRESENT	0
340527	340397	04038G	PARTICIPANT	\N	EXCUSE	0
340528	340397	14147R	PARTICIPANT	\N	PRESENT	0
340529	340397	19737F	PARTICIPANT	\N	PRESENT	0
340530	340397	19551W	PARTICIPANT	\N	EXCUSE	0
340531	340397	01028R	PARTICIPANT	\N	EXCUSE	0
340532	340397	17637T	PARTICIPANT	\N	EXCUSE	0
340533	340397	19629C	PARTICIPANT	\N	EXCUSE	0
342105	341909	14061L	PARTICIPANT	\N	EXCUSE	0
342473	341604	14030Q	PRESIDENT	0	PRESENT	0
342474	341604	11031D	PARTICIPANT	\N	PRESENT	0
342475	341604	19599P	PARTICIPANT	\N	PRESENT	0
338436	321419	04059M	PARTICIPANT	\N	PRESENT	0
338437	321419	11040E	PARTICIPANT	\N	PRESENT	0
342476	341604	14179A	PARTICIPANT	\N	PRESENT	0
342477	341604	19715Y	PARTICIPANT	\N	PRESENT	0
342478	341604	19731Y	PARTICIPANT	\N	PRESENT	0
342479	341604	11067R	PARTICIPANT	\N	PRESENT	0
342480	341604	14109K	PARTICIPANT	\N	PRESENT	0
342481	341604	14235Q	PARTICIPANT	\N	PRESENT	0
342482	341604	19679N	PARTICIPANT	\N	PRESENT	0
342483	341604	19749K	PARTICIPANT	\N	PRESENT	0
342484	341604	19701S	PARTICIPANT	\N	EXCUSE	0
342486	341604	19693L	PARTICIPANT	\N	EXCUSE	0
342488	341604	07029T	PARTICIPANT	\N	EXCUSE	0
342490	341604	08017T	PARTICIPANT	\N	EXCUSE	0
349773	348042	19565D	PARTICIPANT	\N	PRESENT	0
353805	348097	14028W	PARTICIPANT	\N	EXCUSE	0
353813	348097	08048B	PARTICIPANT	\N	EXCUSE	0
355759	353812	04071H	PARTICIPANT	\N	PRESENT	0
355760	353812	95041E	PARTICIPANT	\N	PRESENT	0
355761	353812	01057W	PARTICIPANT	\N	PRESENT	0
355762	353812	11053K	PARTICIPANT	\N	PRESENT	0
355763	353812	89017R	PARTICIPANT	\N	PRESENT	0
355764	353812	11074Q	PRESIDENT	0	PRESENT	0
355765	353812	07029T	PARTICIPANT	\N	PRESENT	0
355766	353812	14085U	PARTICIPANT	\N	PRESENT	0
355767	353812	07004J	PARTICIPANT	\N	PRESENT	0
355768	353812	14253S	PARTICIPANT	\N	PRESENT	0
355769	353812	11048N	PARTICIPANT	\N	PRESENT	0
355770	353812	19479G	PARTICIPANT	\N	PRESENT	0
355771	353812	19647E	PARTICIPANT	\N	PRESENT	0
355772	353812	19711U	PARTICIPANT	\N	PRESENT	0
355773	353812	19651A	PARTICIPANT	\N	PRESENT	0
355774	353812	19531S	PARTICIPANT	\N	PRESENT	0
355775	353812	19687N	PARTICIPANT	\N	PRESENT	0
355776	353812	19689Q	PARTICIPANT	\N	PRESENT	0
355777	353812	08011M	PARTICIPANT	\N	PRESENT	0
355778	353812	14159V	PARTICIPANT	\N	PRESENT	0
355779	353812	11040E	PARTICIPANT	\N	PRESENT	0
355780	353812	04086Q	PARTICIPANT	\N	PRESENT	0
355781	353812	14083S	PARTICIPANT	\N	PRESENT	0
355782	353812	11012A	PARTICIPANT	\N	PRESENT	0
355783	353812	14121F	PARTICIPANT	\N	PRESENT	0
355784	353812	99004R	PARTICIPANT	\N	PRESENT	0
355785	353812	04061F	PARTICIPANT	\N	PRESENT	0
355786	353812	19545Y	PARTICIPANT	\N	EXCUSE	0
355787	353812	14034U	PARTICIPANT	\N	EXCUSE	0
355788	355707	98035U	PARTICIPANT	\N	PRESENT	0
355898	348088	19663E	PARTICIPANT	\N	PRESENT	0
355899	348088	19553Y	PARTICIPANT	\N	PRESENT	0
355900	348088	01048V	PRESIDENT	0	PRESENT	0
355901	348088	19503N	PARTICIPANT	\N	PRESENT	0
355904	348088	19723Y	PARTICIPANT	\N	EXCUSE	0
355903	348088	01058X	PARTICIPANT	\N	PRESENT	0
355905	348088	19533U	PARTICIPANT	\N	EXCUSE	0
355906	348088	19511N	PARTICIPANT	\N	EXCUSE	0
355907	348088	19709B	PARTICIPANT	\N	EXCUSE	0
355908	348088	19693L	PARTICIPANT	\N	EXCUSE	0
355911	348088	14299H	PARTICIPANT	\N	PRESENT	0
356088	356087	14123H	PARTICIPANT	\N	PRESENT	0
356089	356087	08043V	PARTICIPANT	\N	PRESENT	0
356090	356087	14109K	PARTICIPANT	\N	PRESENT	0
356094	356091	19611R	PARTICIPANT	\N	PRESENT	0
356095	356091	19593H	PARTICIPANT	\N	PRESENT	0
356096	356091	08043V	PARTICIPANT	\N	PRESENT	0
356097	356091	19693L	PARTICIPANT	\N	PRESENT	0
356098	356091	19621T	PARTICIPANT	\N	PRESENT	0
356099	356087	19621T	PARTICIPANT	\N	PRESENT	0
356100	356092	19621T	PARTICIPANT	\N	PRESENT	0
356101	356092	08043V	PARTICIPANT	\N	PRESENT	0
356102	356092	19611R	PARTICIPANT	\N	PRESENT	0
356103	356092	19693L	PARTICIPANT	\N	PRESENT	0
356104	356092	14229S	PARTICIPANT	\N	PRESENT	0
356105	356093	19621T	PARTICIPANT	\N	PRESENT	0
356106	356093	08043V	PARTICIPANT	\N	PRESENT	0
356107	356093	19611R	PARTICIPANT	\N	PRESENT	0
356108	356093	19693L	PARTICIPANT	\N	PRESENT	0
356110	356109	19621T	PARTICIPANT	\N	PRESENT	0
356111	356109	19611R	PARTICIPANT	\N	PRESENT	0
356112	356109	08043V	PARTICIPANT	\N	PRESENT	0
356113	356109	19693L	PARTICIPANT	\N	PRESENT	0
356115	356114	19621T	PARTICIPANT	\N	PRESENT	0
356116	356114	19693L	PARTICIPANT	\N	PRESENT	0
356117	356114	19611R	PARTICIPANT	\N	PRESENT	0
356118	356114	19573D	PARTICIPANT	\N	PRESENT	0
356983	356982	11027H	PARTICIPANT	\N	PRESENT	0
356984	356982	19709B	PARTICIPANT	\N	PRESENT	0
357451	357450	14133K	PARTICIPANT	\N	PRESENT	0
357452	357450	96004D	PRESIDENT	0	PRESENT	0
357453	357450	04042C	PARTICIPANT	\N	EXCUSE	0
357454	357450	19251M	PARTICIPANT	\N	PRESENT	0
357455	357450	04097T	PARTICIPANT	\N	EXCUSE	0
357456	357450	14097Y	PARTICIPANT	\N	PRESENT	0
361754	361753	14179A	PARTICIPANT	\N	PRESENT	0
361772	361770	98005N	PARTICIPANT	\N	EXCUSE	0
361860	361859	10006L	PARTICIPANT	\N	PRESENT	0
359447	359446	14073Q	PARTICIPANT	\N	PRESENT	0
359448	359446	14063N	PARTICIPANT	\N	PRESENT	0
359450	359446	87003B	PARTICIPANT	\N	PRESENT	0
359451	359446	14241N	PARTICIPANT	\N	PRESENT	0
359452	359446	08012N	PARTICIPANT	\N	PRESENT	0
359453	359446	11043H	PARTICIPANT	\N	PRESENT	0
359455	359446	19329S	PARTICIPANT	\N	PRESENT	0
359457	359446	19699S	PARTICIPANT	\N	PRESENT	0
359472	355723	19565D	PARTICIPANT	\N	PRESENT	0
359593	358901	11097X	PARTICIPANT	\N	PRESENT	0
361861	361859	14147R	PARTICIPANT	\N	PRESENT	0
361862	361859	11067R	PARTICIPANT	\N	PRESENT	0
361863	361859	14223L	PARTICIPANT	\N	PRESENT	0
361864	361859	04047H	PARTICIPANT	\N	PRESENT	0
361866	361859	19749K	PARTICIPANT	\N	PRESENT	0
362034	345231	14109K	PARTICIPANT	\N	PRESENT	0
362035	345231	88008L	PARTICIPANT	\N	PRESENT	0
362036	345231	19593H	PARTICIPANT	\N	PRESENT	0
362037	345231	11103C	PARTICIPANT	\N	PRESENT	0
362061	345231	19479G	PARTICIPANT	\N	PRESENT	0
362062	345231	19691J	PARTICIPANT	\N	PRESENT	0
362063	345231	11115U	PARTICIPANT	\N	PRESENT	0
362066	345231	14225N	PARTICIPANT	\N	PRESENT	0
362067	345231	01048V	PARTICIPANT	\N	PRESENT	0
362068	361687	19515S	PARTICIPANT	\N	PRESENT	0
362069	361687	19782L	PARTICIPANT	\N	PRESENT	0
362070	361687	11077T	PARTICIPANT	\N	PRESENT	0
362071	361687	14357A	PARTICIPANT	\N	PRESENT	0
362072	361687	19441R	PARTICIPANT	\N	PRESENT	0
362073	361687	80013X	PARTICIPANT	\N	PRESENT	0
362074	361687	19631V	PARTICIPANT	\N	PRESENT	0
362075	361687	08068F	PARTICIPANT	\N	PRESENT	0
362076	361687	04049K	PARTICIPANT	\N	PRESENT	0
362077	361687	19705W	PARTICIPANT	\N	PRESENT	0
362078	361687	08019V	PARTICIPANT	\N	PRESENT	0
362079	361687	14197C	PARTICIPANT	\N	PRESENT	0
362080	361687	19369B	PARTICIPANT	\N	PRESENT	0
362081	361687	19511N	PARTICIPANT	\N	PRESENT	0
362082	361687	08028W	PARTICIPANT	\N	PRESENT	0
362083	361687	19563B	PARTICIPANT	\N	PRESENT	0
362084	361687	14265W	PARTICIPANT	\N	PRESENT	0
362085	361687	14329V	PARTICIPANT	\N	PRESENT	0
362086	361687	14135M	PARTICIPANT	\N	PRESENT	0
362087	361687	19467C	PARTICIPANT	\N	PRESENT	0
362088	361687	14187A	PARTICIPANT	\N	PRESENT	0
362089	361687	08062Y	PARTICIPANT	\N	PRESENT	0
362090	361687	19695N	PARTICIPANT	\N	PRESENT	0
362091	361687	14033T	PARTICIPANT	\N	PRESENT	0
362092	361687	11090Q	PRESIDENT	0	PRESENT	0
362093	361687	01025N	PARTICIPANT	\N	PRESENT	0
362094	361687	19269X	PARTICIPANT	\N	PRESENT	0
362095	361687	14205J	PARTICIPANT	\N	PRESENT	0
362096	361687	04088S	PARTICIPANT	\N	PRESENT	0
362097	361687	11056N	PARTICIPANT	\N	PRESENT	0
362098	361687	04089T	PARTICIPANT	\N	PRESENT	0
362099	361687	14115H	PARTICIPANT	\N	PRESENT	0
362100	361687	19507S	PARTICIPANT	\N	PRESENT	0
362101	361687	14207L	PARTICIPANT	\N	PRESENT	0
362102	361687	17589D	PARTICIPANT	\N	PRESENT	0
362103	361687	14257W	PARTICIPANT	\N	PRESENT	0
362104	361687	19543W	PARTICIPANT	\N	PRESENT	0
362105	361687	19673G	PARTICIPANT	\N	PRESENT	0
362106	361687	01028R	PARTICIPANT	\N	PRESENT	0
362107	361687	19675J	PARTICIPANT	\N	PRESENT	0
362108	361687	19447X	PARTICIPANT	\N	PRESENT	0
362109	361687	14041T	PARTICIPANT	\N	PRESENT	0
362110	361687	14147R	PARTICIPANT	\N	PRESENT	0
362111	361687	14151M	PARTICIPANT	\N	PRESENT	0
362112	361687	14065Q	PARTICIPANT	\N	PRESENT	0
362113	361687	19649G	PARTICIPANT	\N	PRESENT	0
362114	361687	10015M	PARTICIPANT	\N	PRESENT	0
362115	361687	01024M	PARTICIPANT	\N	PRESENT	0
362116	361687	04038G	PARTICIPANT	\N	PRESENT	0
362117	361687	11033F	PARTICIPANT	\N	PRESENT	0
362118	361687	14089Y	PARTICIPANT	\N	PRESENT	0
362119	361687	08044W	PARTICIPANT	\N	PRESENT	0
362120	361687	14069U	PARTICIPANT	\N	PRESENT	0
362121	361687	11049P	PARTICIPANT	\N	PRESENT	0
362122	361687	14021P	PARTICIPANT	\N	PRESENT	0
362123	361687	14001X	PARTICIPANT	\N	PRESENT	0
362124	361687	19581D	PARTICIPANT	\N	PRESENT	0
362125	361687	04044E	PARTICIPANT	\N	PRESENT	0
362126	361687	19585H	PARTICIPANT	\N	PRESENT	0
362127	361687	05008E	PARTICIPANT	\N	PRESENT	0
362128	361687	19489J	PARTICIPANT	\N	PRESENT	0
362129	361687	14179A	PARTICIPANT	\N	PRESENT	0
362130	361687	14215L	PARTICIPANT	\N	PRESENT	0
362131	361687	14259Y	PARTICIPANT	\N	PRESENT	0
362132	361687	11072N	PARTICIPANT	\N	PRESENT	0
362133	361687	14053L	PARTICIPANT	\N	PRESENT	0
362134	361687	14111D	PARTICIPANT	\N	PRESENT	0
362135	361687	08045X	PARTICIPANT	\N	PRESENT	0
362136	361687	11026G	PARTICIPANT	\N	PRESENT	0
362137	361687	19729F	PARTICIPANT	\N	PRESENT	0
362138	361687	19629C	PARTICIPANT	\N	PRESENT	0
362139	361687	11085T	PARTICIPANT	\N	PRESENT	0
362140	361687	19762G	PARTICIPANT	\N	PRESENT	0
362141	361687	19443T	PARTICIPANT	\N	PRESENT	0
362142	361687	19545Y	PARTICIPANT	\N	PRESENT	0
362143	361687	11066Q	PARTICIPANT	\N	PRESENT	0
362144	361687	11110B	PARTICIPANT	\N	PRESENT	0
362145	361687	08056B	PARTICIPANT	\N	PRESENT	0
362146	361687	07029T	PARTICIPANT	\N	PRESENT	0
362147	361687	08061X	PARTICIPANT	\N	PRESENT	0
362148	361687	04059M	PARTICIPANT	\N	PRESENT	0
362149	361687	14109K	PARTICIPANT	\N	PRESENT	0
362150	361687	14255U	PARTICIPANT	\N	PRESENT	0
362151	361687	19383Y	PARTICIPANT	\N	PRESENT	0
362152	361687	14221J	PARTICIPANT	\N	PRESENT	0
362153	361687	04045F	PARTICIPANT	\N	PRESENT	0
362154	361687	14237S	PARTICIPANT	\N	PRESENT	0
362155	361687	19575F	PARTICIPANT	\N	PRESENT	0
362156	361687	17637T	PARTICIPANT	\N	PRESENT	0
362157	361687	14081Q	PARTICIPANT	\N	PRESENT	0
362158	361687	05012A	PARTICIPANT	\N	PRESENT	0
362159	361687	11048N	PARTICIPANT	\N	PRESENT	0
362160	361687	87003B	PARTICIPANT	\N	PRESENT	0
362161	361687	14105F	PARTICIPANT	\N	PRESENT	0
362162	361687	14267Y	PARTICIPANT	\N	PRESENT	0
362163	361687	19583F	PARTICIPANT	\N	PRESENT	0
362164	361687	19533U	PARTICIPANT	\N	PRESENT	0
362165	361687	01057W	PARTICIPANT	\N	PRESENT	0
362166	361687	07033P	PARTICIPANT	\N	PRESENT	0
362167	361687	19643A	PARTICIPANT	\N	PRESENT	0
362168	361687	19399H	PARTICIPANT	\N	PRESENT	0
362169	361687	19699S	PARTICIPANT	\N	PRESENT	0
362170	361687	14079W	PARTICIPANT	\N	PRESENT	0
362171	361687	14034U	PARTICIPANT	\N	PRESENT	0
362172	361687	14173T	PARTICIPANT	\N	PRESENT	0
362173	361687	19741B	PARTICIPANT	\N	PRESENT	0
362174	361687	08034U	PARTICIPANT	\N	PRESENT	0
362175	361687	19521Q	PARTICIPANT	\N	PRESENT	0
362176	345231	14195A	PARTICIPANT	\N	PRESENT	0
362177	345231	19253P	PARTICIPANT	\N	PRESENT	0
362178	345231	19553Y	PARTICIPANT	\N	PRESENT	0
362179	345231	08039A	PARTICIPANT	\N	PRESENT	0
362180	345231	14026U	PARTICIPANT	\N	PRESENT	0
362184	345231	19723Y	PARTICIPANT	\N	PRESENT	0
362187	345231	14071N	PARTICIPANT	\N	PRESENT	0
362188	345231	17589D	PARTICIPANT	\N	PRESENT	0
362195	345231	14083S	PARTICIPANT	\N	PRESENT	0
362196	345231	01025N	PARTICIPANT	\N	PRESENT	0
362197	345231	08068F	PARTICIPANT	\N	PRESENT	0
362523	361169	19768N	PARTICIPANT	\N	PRESENT	0
362524	361169	19515S	PARTICIPANT	\N	PRESENT	0
362525	361169	19782L	PARTICIPANT	\N	PRESENT	0
362526	361169	14357A	PARTICIPANT	\N	PRESENT	0
362527	361169	19413M	PARTICIPANT	\N	PRESENT	0
362528	361169	80013X	PARTICIPANT	\N	PRESENT	0
362529	361169	08021P	PARTICIPANT	\N	PRESENT	0
362530	361169	11099A	PARTICIPANT	\N	PRESENT	0
362531	361169	08068F	PARTICIPANT	\N	PRESENT	0
362532	361169	04049K	PARTICIPANT	\N	PRESENT	0
362533	361169	19705W	PARTICIPANT	\N	PRESENT	0
362534	361169	08015R	PARTICIPANT	\N	PRESENT	0
362535	361169	08019V	PARTICIPANT	\N	PRESENT	0
362536	361169	14197C	PARTICIPANT	\N	PRESENT	0
362537	361169	19369B	PARTICIPANT	\N	PRESENT	0
362538	361169	19511N	PARTICIPANT	\N	PRESENT	0
362539	361169	08028W	PARTICIPANT	\N	PRESENT	0
362540	361169	19563B	PARTICIPANT	\N	PRESENT	0
362541	361169	14265W	PARTICIPANT	\N	PRESENT	0
362542	361169	14135M	PARTICIPANT	\N	PRESENT	0
362543	361169	19467C	PARTICIPANT	\N	PRESENT	0
334438	323965	11031D	PARTICIPANT	\N	PRESENT	0
335102	332424	99004R	PRESIDENT	0	PRESENT	0
335103	332424	11097X	PARTICIPANT	\N	PRESENT	0
335104	332424	11066Q	PARTICIPANT	\N	PRESENT	0
335129	332424	08062Y	PARTICIPANT	\N	EXCUSE	0
339521	339520	11048N	PARTICIPANT	\N	PRESENT	0
339551	339549	11048N	PARTICIPANT	\N	PRESENT	0
339758	337743	08056B	PARTICIPANT	\N	EXCUSE	0
339759	337743	19583F	PARTICIPANT	\N	EXCUSE	0
339760	337743	14235Q	PARTICIPANT	\N	EXCUSE	0
340308	340307	14261S	PARTICIPANT	\N	PRESENT	0
339692	339691	11053K	PARTICIPANT	\N	PRESENT	0
339693	339691	14159V	PARTICIPANT	\N	PRESENT	0
339694	339691	05012A	PARTICIPANT	\N	PRESENT	0
339757	337743	95030B	PARTICIPANT	\N	EXCUSE	0
340309	340307	08031R	PARTICIPANT	\N	PRESENT	0
340310	340307	14081Q	PARTICIPANT	\N	PRESENT	0
340311	340307	19629C	PARTICIPANT	\N	PRESENT	0
340312	340307	19681G	PARTICIPANT	\N	PRESENT	0
342927	340438	19329S	PARTICIPANT	\N	PRESENT	0
342928	340427	14093U	PARTICIPANT	\N	PRESENT	0
342929	340427	19723Y	PARTICIPANT	\N	PRESENT	0
342930	340427	19503N	PARTICIPANT	\N	PRESENT	0
342931	340427	04043D	PARTICIPANT	\N	PRESENT	0
342939	340427	80013X	PARTICIPANT	\N	PRESENT	0
342941	342940	04038G	PARTICIPANT	\N	PRESENT	0
344981	342817	14259Y	PARTICIPANT	\N	EXCUSE	0
344983	344982	96004D	PARTICIPANT	\N	PRESENT	0
344984	344982	14357A	PARTICIPANT	\N	PRESENT	0
344985	344982	04097T	PARTICIPANT	\N	PRESENT	0
344986	344982	19563B	PARTICIPANT	\N	PRESENT	0
344988	344987	96004D	PARTICIPANT	\N	PRESENT	0
344989	344987	14357A	PARTICIPANT	\N	PRESENT	0
344990	344987	04097T	PARTICIPANT	\N	PRESENT	0
345132	345131	14001X	PARTICIPANT	\N	PRESENT	0
345134	345131	14215L	PARTICIPANT	\N	PRESENT	0
345197	345196	14255U	PARTICIPANT	\N	PRESENT	0
345198	345196	08053X	PARTICIPANT	\N	PRESENT	0
345200	345199	01062T	PARTICIPANT	\N	PRESENT	0
345201	345199	14079W	PARTICIPANT	\N	PRESENT	0
345204	345203	01062T	PARTICIPANT	\N	PRESENT	0
345205	345203	14079W	PARTICIPANT	\N	PRESENT	0
347351	339516	14093U	PARTICIPANT	\N	PRESENT	0
347352	339516	01057W	PARTICIPANT	\N	PRESENT	0
347353	339516	19583F	PARTICIPANT	\N	PRESENT	0
347354	339516	98005N	PARTICIPANT	\N	PRESENT	0
347355	339516	14111D	PARTICIPANT	\N	PRESENT	0
347356	339516	04033B	PARTICIPANT	\N	PRESENT	0
347357	339516	19545Y	PARTICIPANT	\N	PRESENT	0
347358	339516	19667J	PARTICIPANT	\N	PRESENT	0
347359	339516	19573D	PARTICIPANT	\N	PRESENT	0
347360	339516	11027H	PARTICIPANT	\N	PRESENT	0
347362	339516	98035U	PARTICIPANT	\N	PRESENT	0
347363	339516	14159V	PARTICIPANT	\N	PRESENT	0
347364	339516	14229S	PARTICIPANT	\N	PRESENT	0
347365	339516	08052W	PARTICIPANT	\N	PRESENT	0
347366	339516	01028R	PARTICIPANT	\N	PRESENT	0
347367	339516	08068F	PARTICIPANT	\N	PRESENT	0
347368	339516	14051J	PARTICIPANT	\N	PRESENT	0
347369	339516	14115H	PARTICIPANT	\N	PRESENT	0
347370	339516	04038G	PARTICIPANT	\N	PRESENT	0
347371	339516	14038Y	PARTICIPANT	\N	PRESENT	0
347372	339516	19715Y	PARTICIPANT	\N	PRESENT	0
347373	339516	14021P	PARTICIPANT	\N	PRESENT	0
347374	339516	19599P	PARTICIPANT	\N	PRESENT	0
347375	339516	14079W	PARTICIPANT	\N	PRESENT	0
347376	339516	14225N	PARTICIPANT	\N	PRESENT	0
347377	339516	14109K	PARTICIPANT	\N	PRESENT	0
347378	339516	01062T	PARTICIPANT	\N	PRESENT	0
347379	339516	14227Q	PARTICIPANT	\N	PRESENT	0
347380	339516	14033T	PARTICIPANT	\N	PRESENT	0
347381	339516	08038Y	PARTICIPANT	\N	PRESENT	0
347382	339516	14029X	PARTICIPANT	\N	PRESENT	0
347383	339516	10015M	PARTICIPANT	\N	PRESENT	0
347384	339516	11043H	PARTICIPANT	\N	PRESENT	0
347385	339516	14028W	PARTICIPANT	\N	PRESENT	0
347386	339516	19657G	PARTICIPANT	\N	PRESENT	0
347387	339516	11045K	PARTICIPANT	\N	PRESENT	0
347388	339516	19647E	PARTICIPANT	\N	PRESENT	0
347389	339516	19399H	PARTICIPANT	\N	PRESENT	0
347390	339516	19649G	PARTICIPANT	\N	PRESENT	0
347391	339516	19729F	PARTICIPANT	\N	PRESENT	0
347392	339516	08012N	PARTICIPANT	\N	PRESENT	0
347393	339516	19693L	PARTICIPANT	\N	PRESENT	0
347394	339516	19727D	PARTICIPANT	\N	PRESENT	0
347395	339516	14085U	PARTICIPANT	\N	PRESENT	0
347396	339516	14121F	PARTICIPANT	\N	PRESENT	0
347397	339516	14217N	PARTICIPANT	\N	PRESENT	0
347398	339516	08058D	PARTICIPANT	\N	PRESENT	0
347399	339516	07033P	PARTICIPANT	\N	PRESENT	0
347400	339516	19581D	PARTICIPANT	\N	PRESENT	0
347401	339516	04018C	PARTICIPANT	\N	PRESENT	0
347402	339516	19503N	PARTICIPANT	\N	PRESENT	0
347403	339516	14193X	PARTICIPANT	\N	PRESENT	0
347404	339516	11067R	PARTICIPANT	\N	PRESENT	0
347405	339516	19251M	PARTICIPANT	\N	PRESENT	0
347406	339516	19413M	PARTICIPANT	\N	PRESENT	0
347407	339516	04049K	PARTICIPANT	\N	PRESENT	0
347408	339516	19527W	PARTICIPANT	\N	PRESENT	0
347409	339516	11109J	PARTICIPANT	\N	PRESENT	0
347410	339516	14063N	PARTICIPANT	\N	PRESENT	0
347411	339516	19631V	PARTICIPANT	\N	PRESENT	0
347412	339516	19733B	PARTICIPANT	\N	PRESENT	0
347413	339516	14097Y	PARTICIPANT	\N	PRESENT	0
347414	339516	19705W	PARTICIPANT	\N	PRESENT	0
347415	339516	19549D	PARTICIPANT	\N	PRESENT	0
347416	339516	14087W	PARTICIPANT	\N	PRESENT	0
347417	339516	08053X	PARTICIPANT	\N	PRESENT	0
347418	339516	19671E	PARTICIPANT	\N	PRESENT	0
347419	339516	14213J	PARTICIPANT	\N	PRESENT	0
347420	339516	19719D	PARTICIPANT	\N	PRESENT	0
347421	339516	02002K	PARTICIPANT	\N	PRESENT	0
347422	339516	04061F	PARTICIPANT	\N	PRESENT	0
347423	339516	05008E	PARTICIPANT	\N	PRESENT	0
347425	339516	19553Y	PARTICIPANT	\N	PRESENT	0
347426	339516	08048B	PARTICIPANT	\N	PRESENT	0
347428	339516	14061L	PARTICIPANT	\N	PRESENT	0
347430	339516	19687N	PARTICIPANT	\N	PRESENT	0
347432	339516	14265W	PARTICIPANT	\N	PRESENT	0
347433	339516	11064N	PARTICIPANT	\N	PRESENT	0
347434	339516	11110B	PARTICIPANT	\N	PRESENT	0
347435	339516	14034U	PARTICIPANT	\N	PRESENT	0
347436	339516	08044W	PARTICIPANT	\N	PRESENT	0
347437	339516	14357A	PARTICIPANT	\N	PRESENT	0
347438	339516	19369B	PARTICIPANT	\N	PRESENT	0
347439	339516	19691J	PARTICIPANT	\N	PRESENT	0
347440	339516	19699S	PARTICIPANT	\N	PRESENT	0
347441	339516	19747H	PARTICIPANT	\N	PRESENT	0
347442	339516	14205J	PARTICIPANT	\N	PRESENT	0
347443	339516	19737F	PARTICIPANT	\N	PRESENT	0
347444	339516	11070L	PARTICIPANT	\N	PRESENT	0
347445	339516	04086Q	PARTICIPANT	\N	PRESENT	0
347446	339516	16685X	PARTICIPANT	\N	PRESENT	0
347447	339516	19479G	PARTICIPANT	\N	PRESENT	0
347448	339516	04070G	PARTICIPANT	\N	PRESENT	0
347449	339516	01024M	PARTICIPANT	\N	PRESENT	0
347450	339516	14123H	PARTICIPANT	\N	PRESENT	0
347451	339516	11085T	PARTICIPANT	\N	PRESENT	0
347453	339516	14275Y	PARTICIPANT	\N	PRESENT	0
347454	339516	19569H	PARTICIPANT	\N	PRESENT	0
347455	339516	14267Y	PARTICIPANT	\N	PRESENT	0
347456	339516	14053L	PARTICIPANT	\N	PRESENT	0
347461	339516	04089T	PARTICIPANT	\N	PRESENT	0
347459	339516	19739H	PARTICIPANT	\N	PRESENT	0
347460	339516	14221J	PARTICIPANT	\N	PRESENT	0
347463	339516	14083S	PARTICIPANT	\N	PRESENT	0
347464	339516	19749K	PARTICIPANT	\N	PRESENT	0
347465	339516	19521Q	PARTICIPANT	\N	PRESENT	0
347466	339516	07004J	PARTICIPANT	\N	PRESENT	0
347467	339516	04040A	PARTICIPANT	\N	PRESENT	0
347468	339516	11080N	PARTICIPANT	\N	PRESENT	0
347469	339516	01025N	PARTICIPANT	\N	PRESENT	0
347470	339516	14327T	PARTICIPANT	\N	PRESENT	0
347471	339516	19663E	PARTICIPANT	\N	PRESENT	0
347472	339516	19659J	PARTICIPANT	\N	PRESENT	0
347473	339516	19651A	PARTICIPANT	\N	PRESENT	0
347474	339516	98029W	PARTICIPANT	\N	PRESENT	0
347475	339516	89017R	PARTICIPANT	\N	PRESENT	0
347476	339516	11048N	PARTICIPANT	\N	PRESENT	0
347477	339516	19447X	PARTICIPANT	\N	PRESENT	0
358729	357152	14071N	PARTICIPANT	\N	EXCUSE	0
358730	357152	14028W	PARTICIPANT	\N	EXCUSE	0
358731	357152	19565D	PARTICIPANT	\N	EXCUSE	0
360646	358889	08021P	PARTICIPANT	\N	EXCUSE	0
360647	358889	11081P	PARTICIPANT	\N	EXCUSE	0
360648	358889	19631V	PARTICIPANT	\N	EXCUSE	0
360649	358889	19619A	PARTICIPANT	\N	EXCUSE	0
360650	358734	08014Q	PARTICIPANT	\N	EXCUSE	0
360651	358103	19583F	PARTICIPANT	\N	EXCUSE	0
360652	358103	08061X	PARTICIPANT	\N	EXCUSE	0
360653	358889	14187A	PARTICIPANT	\N	PRESENT	0
360654	358889	01043Q	PARTICIPANT	\N	EXCUSE	0
360655	358958	14034U	PARTICIPANT	\N	PRESENT	0
360712	360711	14053L	PARTICIPANT	\N	PRESENT	0
360714	358915	14147R	PARTICIPANT	\N	PRESENT	0
360715	358915	10006L	PRESIDENT	0	PRESENT	0
360716	358915	14030Q	PARTICIPANT	\N	PRESENT	0
360717	358915	11067R	PARTICIPANT	\N	EXCUSE	0
360718	358915	19569H	PARTICIPANT	\N	EXCUSE	0
360719	358915	19749K	PARTICIPANT	\N	EXCUSE	0
360720	345225	04086Q	PARTICIPANT	\N	PRESENT	0
360721	345225	19585H	PARTICIPANT	\N	PRESENT	0
360722	345225	14195A	PARTICIPANT	\N	PRESENT	0
360723	345225	14223L	PARTICIPANT	\N	PRESENT	0
360724	345225	14105F	PARTICIPANT	\N	PRESENT	0
360725	345225	04088S	PARTICIPANT	\N	PRESENT	0
360726	345225	19731Y	PARTICIPANT	\N	PRESENT	0
360727	345225	19727D	PARTICIPANT	\N	PRESENT	0
360728	345225	19760E	PARTICIPANT	\N	PRESENT	0
360729	345225	14235Q	PARTICIPANT	\N	PRESENT	0
360730	345225	11040E	PARTICIPANT	\N	PRESENT	0
360731	345225	04092N	PARTICIPANT	\N	PRESENT	0
360732	345225	01034P	PARTICIPANT	\N	PRESENT	0
360733	345225	19593H	PARTICIPANT	\N	PRESENT	0
360734	345225	19719D	PARTICIPANT	\N	PRESENT	0
359046	345221	04059M	PARTICIPANT	\N	PRESENT	0
360615	358889	19441R	PARTICIPANT	\N	PRESENT	0
360616	358889	19413M	PARTICIPANT	\N	PRESENT	0
360617	358889	80013X	PARTICIPANT	\N	PRESENT	0
360618	358889	11099A	PARTICIPANT	\N	PRESENT	0
360619	358889	08068F	PARTICIPANT	\N	PRESENT	0
360620	358889	04049K	PARTICIPANT	\N	PRESENT	0
360621	358889	19705W	PARTICIPANT	\N	PRESENT	0
360622	358889	08015R	PARTICIPANT	\N	PRESENT	0
360623	358889	08019V	PARTICIPANT	\N	PRESENT	0
360624	358889	14197C	PARTICIPANT	\N	PRESENT	0
360625	358889	19369B	PARTICIPANT	\N	PRESENT	0
360626	358889	08028W	PARTICIPANT	\N	PRESENT	0
360627	358889	19563B	PARTICIPANT	\N	PRESENT	0
360628	358889	14265W	PARTICIPANT	\N	PRESENT	0
360629	358889	14329V	PARTICIPANT	\N	PRESENT	0
360630	358889	14135M	PARTICIPANT	\N	PRESENT	0
360631	358889	19467C	PARTICIPANT	\N	PRESENT	0
360632	358889	08038Y	PARTICIPANT	\N	PRESENT	0
360633	358889	14033T	PARTICIPANT	\N	PRESENT	0
360634	358889	11090Q	PRESIDENT	0	PRESENT	0
360635	358889	01025N	PARTICIPANT	\N	PRESENT	0
360636	358889	19269X	PARTICIPANT	\N	PRESENT	0
360637	358889	14205J	PARTICIPANT	\N	PRESENT	0
360638	358889	04088S	PARTICIPANT	\N	PRESENT	0
360639	358889	11056N	PARTICIPANT	\N	PRESENT	0
360640	358889	04089T	PARTICIPANT	\N	PRESENT	0
360641	358889	14115H	PARTICIPANT	\N	PRESENT	0
360642	358889	19747H	PARTICIPANT	\N	PRESENT	0
360643	358889	14207L	PARTICIPANT	\N	PRESENT	0
360644	358889	04043D	PARTICIPANT	\N	PRESENT	0
360645	358889	14257W	PARTICIPANT	\N	PRESENT	0
360735	345225	11072N	PARTICIPANT	\N	PRESENT	0
360736	345225	08043V	PARTICIPANT	\N	PRESENT	0
360737	345225	19691J	PARTICIPANT	\N	PRESENT	0
360738	345225	19367Y	PARTICIPANT	\N	PRESENT	0
360739	345225	19581D	PARTICIPANT	\N	PRESENT	0
360740	345225	99004R	PARTICIPANT	\N	PRESENT	0
360741	345225	08019V	PARTICIPANT	\N	PRESENT	0
360742	345225	19667J	PARTICIPANT	\N	PRESENT	0
360743	345225	19794Q	PARTICIPANT	\N	PRESENT	0
360744	345225	98024R	PARTICIPANT	\N	PRESENT	0
360745	345225	19553Y	PARTICIPANT	\N	PRESENT	0
360746	345225	11070L	PARTICIPANT	\N	PRESENT	0
360747	345225	19295A	PARTICIPANT	\N	PRESENT	0
360748	345225	19629C	PARTICIPANT	\N	PRESENT	0
360749	345225	19387D	PARTICIPANT	\N	PRESENT	0
360750	345225	14089Y	PARTICIPANT	\N	PRESENT	0
360751	345225	19575F	PARTICIPANT	\N	PRESENT	0
360752	345225	19467C	PARTICIPANT	\N	PRESENT	0
360753	345225	19383Y	PARTICIPANT	\N	PRESENT	0
360754	345225	08028W	PARTICIPANT	\N	PRESENT	0
360755	345225	19399H	PARTICIPANT	\N	PRESENT	0
360756	345225	04045F	PARTICIPANT	\N	PRESENT	0
360757	345225	97011G	PARTICIPANT	\N	PRESENT	0
360758	345225	14097Y	PARTICIPANT	\N	PRESENT	0
360759	345225	14207L	PARTICIPANT	\N	PRESENT	0
360760	345225	14109K	PARTICIPANT	\N	PRESENT	0
360764	345225	14031R	PARTICIPANT	\N	PRESENT	0
360768	345225	19703U	PARTICIPANT	\N	PRESENT	0
360769	345225	19447X	PARTICIPANT	\N	PRESENT	0
360770	345225	14217N	PARTICIPANT	\N	PRESENT	0
360771	345225	11097X	PARTICIPANT	\N	PRESENT	0
360772	345225	11045K	PARTICIPANT	\N	PRESENT	0
360773	345225	08015R	PARTICIPANT	\N	PRESENT	0
360774	345225	08039A	PARTICIPANT	\N	PRESENT	0
360775	358915	14213J	PARTICIPANT	\N	PRESENT	0
360776	358915	11033F	PARTICIPANT	\N	PRESENT	0
360777	358915	08031R	PARTICIPANT	\N	PRESENT	0
360778	345225	14033T	PARTICIPANT	\N	PRESENT	0
360779	345225	08048B	PARTICIPANT	\N	PRESENT	0
360780	345225	18083K	PARTICIPANT	\N	PRESENT	0
360781	345225	19441R	PARTICIPANT	\N	PRESENT	0
360782	345225	19713W	PARTICIPANT	\N	PRESENT	0
360783	345225	19565D	PARTICIPANT	\N	PRESENT	0
360784	345225	14029X	PARTICIPANT	\N	PRESENT	0
360785	345225	14063N	PARTICIPANT	\N	PRESENT	0
360786	345225	19527W	PARTICIPANT	\N	PRESENT	0
360787	345225	19443T	PARTICIPANT	\N	PRESENT	0
360788	345225	17779H	PARTICIPANT	\N	PRESENT	0
360789	345225	14121F	PARTICIPANT	\N	PRESENT	0
360790	345225	14239U	PARTICIPANT	\N	PRESENT	0
360791	345225	14038Y	PARTICIPANT	\N	PRESENT	0
360792	345225	19737F	PARTICIPANT	\N	PRESENT	0
360793	345225	19289C	PARTICIPANT	\N	PRESENT	0
360794	345225	14267Y	PARTICIPANT	\N	PRESENT	0
360795	345225	14157T	PARTICIPANT	\N	PRESENT	0
360796	345225	19697Q	PARTICIPANT	\N	PRESENT	0
360797	345225	19663E	PARTICIPANT	\N	PRESENT	0
360798	345225	14237S	PARTICIPANT	\N	PRESENT	0
360799	345225	19657G	PARTICIPANT	\N	PRESENT	0
360800	345225	14042U	PARTICIPANT	\N	PRESENT	0
360801	345225	01024M	PARTICIPANT	\N	PRESENT	0
360802	345225	14041T	PARTICIPANT	\N	PRESENT	0
360804	360803	14187A	PARTICIPANT	\N	PRESENT	0
360805	345225	19725B	PARTICIPANT	\N	PRESENT	0
360806	345225	08052W	PARTICIPANT	\N	PRESENT	0
360807	345225	19413M	PARTICIPANT	\N	PRESENT	0
360808	345225	11104D	PARTICIPANT	\N	PRESENT	0
360809	345225	14051J	PARTICIPANT	\N	PRESENT	0
360810	345225	14071N	PARTICIPANT	\N	PRESENT	0
360811	345225	19741B	PARTICIPANT	\N	PRESENT	0
360812	345225	17583W	PARTICIPANT	\N	PRESENT	0
360813	345225	19673G	PARTICIPANT	\N	PRESENT	0
360814	345225	19758L	PARTICIPANT	\N	PRESENT	0
360815	345225	89017R	PARTICIPANT	\N	PRESENT	0
360816	345225	19782L	PARTICIPANT	\N	PRESENT	0
360818	345225	14115H	PARTICIPANT	\N	PRESENT	0
360819	360817	07004J	PARTICIPANT	\N	PRESENT	0
360820	360817	19713W	PARTICIPANT	\N	PRESENT	0
360821	360817	10015M	PARTICIPANT	\N	PRESENT	0
360822	360817	14085U	PARTICIPANT	\N	PRESENT	0
360823	360817	19739H	PARTICIPANT	\N	PRESENT	0
360824	360817	04040A	PARTICIPANT	\N	PRESENT	0
360825	360817	14083S	PARTICIPANT	\N	PRESENT	0
360826	360817	14079W	PARTICIPANT	\N	PRESENT	0
334778	331358	14259Y	PARTICIPANT	\N	PRESENT	0
334779	331358	08038Y	PARTICIPANT	\N	PRESENT	0
334780	331358	19565D	PARTICIPANT	\N	PRESENT	0
334781	331358	08010L	PARTICIPANT	\N	PRESENT	0
334782	331358	08051V	PARTICIPANT	\N	PRESENT	0
334783	331358	08049C	PARTICIPANT	\N	PRESENT	0
334784	331358	19735D	PARTICIPANT	\N	PRESENT	0
334785	331358	01057W	PARTICIPANT	\N	PRESENT	0
334805	331358	04040A	PRESIDENT	0	PRESENT	0
334808	331358	05012A	PARTICIPANT	\N	PRESENT	0
334810	331358	14327T	PARTICIPANT	\N	PRESENT	0
334811	331358	19525U	PARTICIPANT	\N	PRESENT	0
334815	334814	12041X	PARTICIPANT	\N	PRESENT	0
334816	334814	95067Q	PARTICIPANT	\N	PRESENT	0
334817	334814	08058D	PARTICIPANT	\N	PRESENT	0
334818	334814	11066Q	PARTICIPANT	\N	PRESENT	0
334829	334828	04049K	PARTICIPANT	\N	PRESENT	0
334820	334814	14079W	PARTICIPANT	\N	PRESENT	0
334821	334814	19421M	PARTICIPANT	\N	PRESENT	0
334822	334814	14267Y	PARTICIPANT	\N	PRESENT	0
334824	334814	08047A	PARTICIPANT	\N	PRESENT	0
334827	334826	04049K	PARTICIPANT	\N	PRESENT	0
334830	334828	14083S	PARTICIPANT	\N	PRESENT	0
337862	317432	14030Q	PRESIDENT	0	PRESENT	0
337863	317432	19701S	PARTICIPANT	\N	PRESENT	0
337864	317432	19715Y	PARTICIPANT	\N	PRESENT	0
337865	317432	19643A	PARTICIPANT	\N	PRESENT	0
337866	317432	19599P	PARTICIPANT	\N	PRESENT	0
337867	317432	14235Q	PARTICIPANT	\N	PRESENT	0
337868	317432	08031R	PARTICIPANT	\N	PRESENT	0
337869	317432	08043V	PARTICIPANT	\N	PRESENT	0
337870	317432	08012N	PARTICIPANT	\N	PRESENT	0
337871	317432	19399H	PARTICIPANT	\N	PRESENT	0
337872	317432	19699S	PARTICIPANT	\N	PRESENT	0
337873	317432	14039A	PARTICIPANT	\N	PRESENT	0
337874	317432	14073Q	PARTICIPANT	\N	PRESENT	0
337875	317432	11043H	PARTICIPANT	\N	PRESENT	0
337876	317432	08017T	PARTICIPANT	\N	PRESENT	0
337878	317432	08020N	PARTICIPANT	\N	EXCUSE	0
337879	317432	07029T	PARTICIPANT	\N	EXCUSE	0
337880	317432	01043Q	PARTICIPANT	\N	EXCUSE	0
350363	340403	04038G	PARTICIPANT	\N	PRESENT	0
350365	340404	04038G	PARTICIPANT	\N	PRESENT	0
350366	340405	04038G	PARTICIPANT	\N	PRESENT	0
350780	332565	11097X	PARTICIPANT	\N	PRESENT	0
350781	332565	19647E	PARTICIPANT	\N	EXCUSE	0
350782	332565	19421M	PARTICIPANT	\N	EXCUSE	0
350783	332565	19651A	PARTICIPANT	\N	EXCUSE	0
350784	332565	19711U	PARTICIPANT	\N	PRESENT	0
350786	332565	19737F	PARTICIPANT	\N	PRESENT	0
350789	332565	19479G	PARTICIPANT	\N	PRESENT	0
350792	350791	10006L	PARTICIPANT	\N	PRESENT	0
350793	350791	11067R	PARTICIPANT	\N	PRESENT	0
350794	350791	19533U	PARTICIPANT	\N	PRESENT	0
350795	350791	19749K	PARTICIPANT	\N	PRESENT	0
353690	353689	14105F	PARTICIPANT	\N	PRESENT	0
353691	353689	14207L	PARTICIPANT	\N	PRESENT	0
353692	353689	11101A	PARTICIPANT	\N	PRESENT	0
353693	353689	08024S	PARTICIPANT	\N	PRESENT	0
353694	353689	14329V	PARTICIPANT	\N	PRESENT	0
353695	353689	11027H	PARTICIPANT	\N	PRESENT	0
353696	353689	19725B	PARTICIPANT	\N	PRESENT	0
353697	353689	14061L	PARTICIPANT	\N	PRESENT	0
353698	353689	19611R	PARTICIPANT	\N	PRESENT	0
353699	353689	08015R	PARTICIPANT	\N	PRESENT	0
353700	353689	05012A	PARTICIPANT	\N	PRESENT	0
357457	357450	04061F	PARTICIPANT	\N	PRESENT	0
357458	357450	04057K	PARTICIPANT	\N	EXCUSE	0
357459	357450	98050T	PRESIDENT	1	PRESENT	0
357460	357450	04034C	PARTICIPANT	\N	PRESENT	0
357483	357271	19737F	PARTICIPANT	\N	PRESENT	0
358059	358058	04047H	PARTICIPANT	\N	PRESENT	0
358060	358058	08055A	PARTICIPANT	\N	PRESENT	0
358061	358058	08049C	PARTICIPANT	\N	PRESENT	0
358062	358058	01057W	PARTICIPANT	\N	PRESENT	0
358063	358058	14085U	PARTICIPANT	\N	PRESENT	0
358065	358064	11053K	PARTICIPANT	\N	PRESENT	0
358066	358064	05012A	PARTICIPANT	\N	PRESENT	0
358067	358064	14159V	PARTICIPANT	\N	PRESENT	0
358071	351756	19399H	PARTICIPANT	\N	PRESENT	0
358104	344820	14030Q	PRESIDENT	0	PRESENT	0
358105	344820	08043V	PARTICIPANT	\N	PRESENT	0
358106	344820	19367Y	PARTICIPANT	\N	PRESENT	0
358107	344820	19643A	PARTICIPANT	\N	PRESENT	0
358108	344820	19701S	PARTICIPANT	\N	PRESENT	0
358109	344820	11031D	PARTICIPANT	\N	PRESENT	0
358110	344820	80013X	PARTICIPANT	\N	EXCUSE	0
358111	344820	14217N	PARTICIPANT	\N	PRESENT	0
358112	344820	19599P	PARTICIPANT	\N	PRESENT	0
358113	344820	04035D	PARTICIPANT	\N	PRESENT	0
358114	344820	14179A	PARTICIPANT	\N	EXCUSE	0
358115	344820	19731Y	PARTICIPANT	\N	PRESENT	0
358116	344820	08031R	PARTICIPANT	\N	PRESENT	0
358117	344820	07029T	PARTICIPANT	\N	PRESENT	0
358118	344820	14109K	PARTICIPANT	\N	PRESENT	0
358119	344820	19679N	PARTICIPANT	\N	PRESENT	0
358120	344820	11045K	PARTICIPANT	\N	PRESENT	0
358121	344820	11067R	PARTICIPANT	\N	EXCUSE	0
358980	358979	11097X	PARTICIPANT	\N	PRESENT	0
361618	361617	14329V	PARTICIPANT	\N	PRESENT	0
361620	361619	14329V	PARTICIPANT	\N	PRESENT	0
361621	361619	04089T	PARTICIPANT	\N	PRESENT	0
361622	361619	14205J	PARTICIPANT	\N	PRESENT	0
361624	361623	14329V	PARTICIPANT	\N	PRESENT	0
361625	361623	04089T	PARTICIPANT	\N	PRESENT	0
361626	361623	14205J	PARTICIPANT	\N	PRESENT	0
361629	361357	19549D	PARTICIPANT	\N	PRESENT	0
361630	361362	19549D	PARTICIPANT	\N	PRESENT	0
361634	361633	14329V	PARTICIPANT	\N	PRESENT	0
361635	361633	14103D	PARTICIPANT	\N	PRESENT	0
361636	361633	19739H	PARTICIPANT	\N	PRESENT	0
361637	361633	19549D	PARTICIPANT	\N	PRESENT	0
361639	361638	14329V	PARTICIPANT	\N	PRESENT	0
361640	361638	14103D	PARTICIPANT	\N	PRESENT	0
361641	361638	19739H	PARTICIPANT	\N	PRESENT	0
361642	361638	17583W	PARTICIPANT	\N	PRESENT	0
361643	361638	19549D	PARTICIPANT	\N	PRESENT	0
361980	345231	19577H	PARTICIPANT	\N	PRESENT	0
361981	345231	14215L	PARTICIPANT	\N	PRESENT	0
361982	345231	19421M	PARTICIPANT	\N	PRESENT	0
361983	345231	11031D	PARTICIPANT	\N	PRESENT	0
361984	345231	14030Q	PARTICIPANT	\N	PRESENT	0
361985	345231	14327T	PARTICIPANT	\N	PRESENT	0
361986	345231	19507S	PARTICIPANT	\N	PRESENT	0
361987	345231	04061F	PARTICIPANT	\N	PRESENT	0
361988	345231	08044W	PARTICIPANT	\N	PRESENT	0
361989	345231	14207L	PARTICIPANT	\N	PRESENT	0
361990	345231	14257W	PARTICIPANT	\N	PRESENT	0
361991	345231	14087W	PARTICIPANT	\N	PRESENT	0
361992	345231	19467C	PARTICIPANT	\N	PRESENT	0
361993	345231	11033F	PARTICIPANT	\N	PRESENT	0
361994	345231	11072N	PARTICIPANT	\N	PRESENT	0
361995	345231	97011G	PARTICIPANT	\N	PRESENT	0
361996	345231	05012A	PARTICIPANT	\N	PRESENT	0
361997	345231	11043H	PARTICIPANT	\N	PRESENT	0
361998	345231	19583F	PARTICIPANT	\N	PRESENT	0
362002	345231	11097X	PARTICIPANT	\N	PRESENT	0
362000	345231	14089Y	PARTICIPANT	\N	PRESENT	0
362001	345231	19713W	PARTICIPANT	\N	PRESENT	0
362003	345231	19711U	PARTICIPANT	\N	PRESENT	0
362004	345231	19549D	PARTICIPANT	\N	PRESENT	0
362005	345231	98022P	PARTICIPANT	\N	PRESENT	0
362006	345231	19289C	PARTICIPANT	\N	PRESENT	0
362007	345231	04089T	PARTICIPANT	\N	PRESENT	0
362008	345231	19413M	PARTICIPANT	\N	PRESENT	0
362009	345231	19760E	PARTICIPANT	\N	PRESENT	0
362010	345231	19687N	PARTICIPANT	\N	PRESENT	0
362012	362011	10006L	PARTICIPANT	\N	PRESENT	0
362013	362011	08052W	PARTICIPANT	\N	PRESENT	0
362014	362011	19553Y	PARTICIPANT	\N	PRESENT	0
362015	345231	14053L	PARTICIPANT	\N	PRESENT	0
362016	345231	19719D	PARTICIPANT	\N	PRESENT	0
362017	345231	11110B	PARTICIPANT	\N	PRESENT	0
362018	345231	14028W	PARTICIPANT	\N	PRESENT	0
362019	345231	19715Y	PARTICIPANT	\N	PRESENT	0
362020	345231	14147R	PARTICIPANT	\N	PRESENT	0
362021	345231	14281W	PARTICIPANT	\N	PRESENT	0
362022	345231	80013X	PARTICIPANT	\N	PRESENT	0
362024	345231	19697Q	PARTICIPANT	\N	PRESENT	0
362025	345231	19269X	PARTICIPANT	\N	PRESENT	0
362026	345231	01024M	PARTICIPANT	\N	PRESENT	0
362027	345231	14097Y	PARTICIPANT	\N	PRESENT	0
362028	345231	19693L	PARTICIPANT	\N	PRESENT	0
362030	345231	19701S	PARTICIPANT	\N	PRESENT	0
362031	345231	14059S	PARTICIPANT	\N	PRESENT	0
362032	345231	19251M	PARTICIPANT	\N	PRESENT	0
362039	362038	96004D	PRESIDENT	0	PRESENT	0
362040	362038	14065Q	PARTICIPANT	\N	PRESENT	0
358148	356267	19573D	PARTICIPANT	\N	PRESENT	0
358944	358939	19711U	PARTICIPANT	\N	PRESENT	0
358945	358939	01048V	PARTICIPANT	\N	PRESENT	0
358947	358946	14327T	PARTICIPANT	\N	PRESENT	0
358949	358948	14327T	PARTICIPANT	\N	PRESENT	0
358951	358950	19667J	PARTICIPANT	\N	PRESENT	0
358952	358950	11040E	PARTICIPANT	\N	PRESENT	0
358954	358953	01057W	PARTICIPANT	\N	PRESENT	0
358955	358953	14225N	PARTICIPANT	\N	PRESENT	0
358957	358956	14331P	PARTICIPANT	\N	PRESENT	0
359047	358123	10015M	PARTICIPANT	\N	PRESENT	0
359048	358123	19253P	PARTICIPANT	\N	PRESENT	0
359049	358123	14001X	PARTICIPANT	\N	PRESENT	0
359050	358123	19543W	PARTICIPANT	\N	PRESENT	0
359051	358123	01024M	PARTICIPANT	\N	PRESENT	0
359052	358123	04044E	PARTICIPANT	\N	PRESENT	0
359053	358123	04047H	PRESIDENT	0	PRESENT	0
359054	358123	19673G	PARTICIPANT	\N	PRESENT	0
359055	358123	19719D	PARTICIPANT	\N	PRESENT	0
359056	358123	19675J	PARTICIPANT	\N	PRESENT	0
359057	358123	01028R	PARTICIPANT	\N	PRESENT	0
359058	358123	19447X	PARTICIPANT	\N	PRESENT	0
359059	358123	19725B	PARTICIPANT	\N	PRESENT	0
359060	358123	14089Y	PARTICIPANT	\N	PRESENT	0
359061	358123	19729F	PARTICIPANT	\N	PRESENT	0
359062	358123	95063L	PARTICIPANT	\N	PRESENT	0
359063	358123	19629C	PARTICIPANT	\N	PRESENT	0
359064	358123	14179A	PARTICIPANT	\N	PRESENT	0
359065	358123	14147R	PARTICIPANT	\N	PRESENT	0
359066	358123	14069U	PARTICIPANT	\N	PRESENT	0
359067	358123	14215L	PARTICIPANT	\N	PRESENT	0
359068	345221	14151M	PARTICIPANT	\N	PRESENT	0
359069	345221	19649G	PARTICIPANT	\N	PRESENT	0
359070	345221	04038G	PARTICIPANT	\N	PRESENT	0
359071	345221	19593H	PARTICIPANT	\N	PRESENT	0
359072	345221	04085P	PARTICIPANT	\N	PRESENT	0
359073	345221	11040E	PARTICIPANT	\N	PRESENT	0
359074	345221	11066Q	PARTICIPANT	\N	PRESENT	0
359075	345221	04044E	PARTICIPANT	\N	PRESENT	0
359076	345221	14001X	PARTICIPANT	\N	PRESENT	0
359077	345221	19585H	PARTICIPANT	\N	PRESENT	0
359078	345221	19689Q	PARTICIPANT	\N	PRESENT	0
359079	345221	95063L	PARTICIPANT	\N	PRESENT	0
359080	345221	19543W	PARTICIPANT	\N	PRESENT	0
359081	345221	19629C	PARTICIPANT	\N	PRESENT	0
359082	345221	14159V	PARTICIPANT	\N	PRESENT	0
359083	345221	14179A	PARTICIPANT	\N	PRESENT	0
359084	345221	14089Y	PARTICIPANT	\N	PRESENT	0
359085	345221	07004J	PARTICIPANT	\N	PRESENT	0
359086	345221	01024M	PARTICIPANT	\N	PRESENT	0
359087	345221	19747H	PARTICIPANT	\N	PRESENT	0
359088	345221	01028R	PARTICIPANT	\N	PRESENT	0
359089	345221	19725B	PARTICIPANT	\N	PRESENT	0
359090	345221	05008E	PARTICIPANT	\N	PRESENT	0
359091	345221	19621T	PARTICIPANT	\N	PRESENT	0
359092	345221	14021P	PARTICIPANT	\N	PRESENT	0
359093	345221	19647E	PARTICIPANT	\N	PRESENT	0
359094	345221	14215L	PARTICIPANT	\N	PRESENT	0
359095	345221	14087W	PARTICIPANT	\N	PRESENT	0
359096	345221	14217N	PARTICIPANT	\N	PRESENT	0
359097	345221	14187A	PARTICIPANT	\N	PRESENT	0
359098	345221	04033B	PARTICIPANT	\N	PRESENT	0
359099	345221	14259Y	PARTICIPANT	\N	PRESENT	0
359100	345221	99004R	PARTICIPANT	\N	PRESENT	0
359101	345221	14223L	PARTICIPANT	\N	PRESENT	0
359102	345221	08028W	PARTICIPANT	\N	PRESENT	0
359103	345221	01048V	PARTICIPANT	\N	PRESENT	0
359104	345221	96004D	PARTICIPANT	\N	PRESENT	0
359105	345221	14147R	PARTICIPANT	\N	PRESENT	0
359106	345221	17583W	PARTICIPANT	\N	PRESENT	0
359107	345221	18083K	PARTICIPANT	\N	PRESENT	0
359108	345221	19575F	PARTICIPANT	\N	PRESENT	0
359109	345221	08048B	PARTICIPANT	\N	PRESENT	0
359110	345221	19729F	PARTICIPANT	\N	PRESENT	0
359111	345221	19693L	PARTICIPANT	\N	PRESENT	0
359112	345221	19399H	PARTICIPANT	\N	PRESENT	0
359113	345221	08019V	PARTICIPANT	\N	PRESENT	0
359114	345221	14033T	PARTICIPANT	\N	PRESENT	0
359115	345221	04088S	PARTICIPANT	\N	PRESENT	0
359116	345221	14029X	PARTICIPANT	\N	PRESENT	0
359117	345221	19794Q	PARTICIPANT	\N	PRESENT	0
359118	345221	10015M	PARTICIPANT	\N	PRESENT	0
359119	345221	11080N	PARTICIPANT	\N	PRESENT	0
359120	345221	95062K	PARTICIPANT	\N	PRESENT	0
359121	345221	98024R	PARTICIPANT	\N	PRESENT	0
359122	345221	01058X	PARTICIPANT	\N	PRESENT	0
359123	345221	14030Q	PARTICIPANT	\N	PRESENT	0
359124	345221	08056B	PARTICIPANT	\N	PRESENT	0
359125	345221	14231L	PARTICIPANT	\N	PRESENT	0
359126	345221	19253P	PARTICIPANT	\N	PRESENT	0
359127	345221	19333N	PARTICIPANT	\N	PRESENT	0
359128	345221	14115H	PARTICIPANT	\N	PRESENT	0
359129	345221	04097T	PARTICIPANT	\N	PRESENT	0
359130	345221	11049P	PARTICIPANT	\N	PRESENT	0
359131	345221	19731Y	PARTICIPANT	\N	PRESENT	0
359132	345221	04018C	PARTICIPANT	\N	PRESENT	0
359133	345221	19383Y	PARTICIPANT	\N	PRESENT	0
359134	345221	19631V	PARTICIPANT	\N	PRESENT	0
359135	345221	97011G	PARTICIPANT	\N	PRESENT	0
359136	345221	08058D	PARTICIPANT	\N	PRESENT	0
359137	345221	19443T	PARTICIPANT	\N	PRESENT	0
359138	345221	19295A	PARTICIPANT	\N	PRESENT	0
359139	345221	11031D	PARTICIPANT	\N	PRESENT	0
359140	345221	11033F	PARTICIPANT	\N	PRESENT	0
359141	345221	08045X	PARTICIPANT	\N	PRESENT	0
359142	345221	14097Y	PARTICIPANT	\N	PRESENT	0
359143	345221	14028W	PARTICIPANT	\N	PRESENT	0
359144	345221	14257W	PARTICIPANT	\N	PRESENT	0
359145	345221	08053X	PARTICIPANT	\N	PRESENT	0
359146	345221	14219Q	PARTICIPANT	\N	PRESENT	0
359147	345221	14221J	PARTICIPANT	\N	PRESENT	0
359148	345221	14267Y	PARTICIPANT	\N	PRESENT	0
359149	345221	08031R	PARTICIPANT	\N	PRESENT	0
359150	345221	19367Y	PARTICIPANT	\N	PRESENT	0
359151	345221	14157T	PARTICIPANT	\N	PRESENT	0
359152	345221	14026U	PARTICIPANT	\N	PRESENT	0
359153	345221	14211G	PARTICIPANT	\N	PRESENT	0
359154	345221	19611R	PARTICIPANT	\N	PRESENT	0
359155	345221	01025N	PARTICIPANT	\N	PRESENT	0
359156	345221	98029W	PARTICIPANT	\N	PRESENT	0
359157	345221	19581D	PARTICIPANT	\N	PRESENT	0
359158	345221	19651A	PARTICIPANT	\N	PRESENT	0
359159	345221	08061X	PARTICIPANT	\N	PRESENT	0
359160	345221	14079W	PARTICIPANT	\N	PRESENT	0
359161	345221	19347U	PARTICIPANT	\N	PRESENT	0
359162	345221	19782L	PARTICIPANT	\N	PRESENT	0
359163	345221	14249W	PARTICIPANT	\N	PRESENT	0
359164	345221	98050T	PARTICIPANT	\N	PRESENT	0
359165	345221	11083R	PARTICIPANT	\N	PRESENT	0
359166	345221	19301E	PARTICIPANT	\N	PRESENT	0
359167	345221	14061L	PARTICIPANT	\N	PRESENT	0
359168	345221	19745F	PARTICIPANT	\N	PRESENT	0
359169	345221	19723Y	PARTICIPANT	\N	PRESENT	0
359170	345221	14119M	PARTICIPANT	\N	PRESENT	0
359171	345221	19673G	PARTICIPANT	\N	PRESENT	0
359172	345221	19643A	PARTICIPANT	\N	PRESENT	0
359173	345221	05012A	PARTICIPANT	\N	PRESENT	0
359174	345221	19762G	PARTICIPANT	\N	PRESENT	0
359175	345221	14071N	PARTICIPANT	\N	PRESENT	0
359176	345221	14197C	PARTICIPANT	\N	PRESENT	0
359177	345221	19447X	PARTICIPANT	\N	PRESENT	0
359178	345221	14207L	PARTICIPANT	\N	PRESENT	0
359179	345221	14041T	PARTICIPANT	\N	PRESENT	0
359180	345221	19533U	PARTICIPANT	\N	PRESENT	0
359181	345221	19679N	PARTICIPANT	\N	PRESENT	0
359182	345221	19663E	PARTICIPANT	\N	PRESENT	0
359183	345221	19683J	PARTICIPANT	\N	PRESENT	0
359184	345221	08024S	PARTICIPANT	\N	PRESENT	0
359185	345221	19697Q	PARTICIPANT	\N	PRESENT	0
359186	345221	08060W	PARTICIPANT	\N	PRESENT	0
359187	345221	14105F	PARTICIPANT	\N	PRESENT	0
359188	345221	19760E	PARTICIPANT	\N	PRESENT	0
359189	345221	11085T	PARTICIPANT	\N	PRESENT	0
359190	345221	19527W	PARTICIPANT	\N	PRESENT	0
359191	345221	11072N	PARTICIPANT	\N	PRESENT	0
359192	345221	11104D	PARTICIPANT	\N	PRESENT	0
359208	345221	16685X	PARTICIPANT	\N	PRESENT	0
359212	345221	11041F	PARTICIPANT	\N	PRESENT	0
359213	345221	19735D	PARTICIPANT	\N	PRESENT	0
359214	345221	14229S	PARTICIPANT	\N	PRESENT	0
359215	345221	19719D	PARTICIPANT	\N	PRESENT	0
359216	345221	14213J	PARTICIPANT	\N	PRESENT	0
359217	345221	08015R	PARTICIPANT	\N	PRESENT	0
359220	345221	14121F	PARTICIPANT	\N	PRESENT	0
359223	345221	19699S	PARTICIPANT	\N	PRESENT	0
359224	345221	17589D	PARTICIPANT	\N	PRESENT	0
359225	345221	19441R	PARTICIPANT	\N	PRESENT	0
359226	345221	19713W	PARTICIPANT	\N	PRESENT	0
345759	345123	19735D	PARTICIPANT	\N	EXCUSE	0
345774	345252	17583W	PARTICIPANT	\N	EXCUSE	0
347478	339516	86034E	PARTICIPANT	\N	PRESENT	0
347479	339516	14059S	PARTICIPANT	\N	PRESENT	0
347480	339516	14081Q	PARTICIPANT	\N	PRESENT	0
347481	339516	19333N	PARTICIPANT	\N	PRESENT	0
347482	339516	14001X	PARTICIPANT	\N	PRESENT	0
347483	339516	19575F	PARTICIPANT	\N	PRESENT	0
347484	339516	19543W	PARTICIPANT	\N	PRESENT	0
347485	339516	14089Y	PARTICIPANT	\N	PRESENT	0
347486	339516	19713W	PARTICIPANT	\N	PRESENT	0
347487	339516	14255U	PARTICIPANT	\N	PRESENT	0
347492	339516	19689Q	PARTICIPANT	\N	PRESENT	0
347489	339516	19731Y	PARTICIPANT	\N	PRESENT	0
347490	339516	14103D	PARTICIPANT	\N	PRESENT	0
347491	339516	19551W	PARTICIPANT	\N	PRESENT	0
347493	339516	14151M	PARTICIPANT	\N	PRESENT	0
347494	339516	11031D	PARTICIPANT	\N	PRESENT	0
347500	339516	04071H	PARTICIPANT	\N	PRESENT	0
347506	347505	14031R	PARTICIPANT	\N	PRESENT	0
347510	347509	19681G	PARTICIPANT	\N	PRESENT	0
347511	347509	14031R	PARTICIPANT	\N	PRESENT	0
347512	347509	19737F	PARTICIPANT	\N	PRESENT	0
347514	347513	19681G	PARTICIPANT	\N	PRESENT	0
347515	347513	14031R	PARTICIPANT	\N	PRESENT	0
347516	347513	19737F	PARTICIPANT	\N	PRESENT	0
347518	347517	14031R	PARTICIPANT	\N	PRESENT	0
347519	347517	19737F	PARTICIPANT	\N	PRESENT	0
347521	347520	19551W	PARTICIPANT	\N	PRESENT	0
347522	347520	14031R	PARTICIPANT	\N	PRESENT	0
347523	347520	19737F	PARTICIPANT	\N	PRESENT	0
347525	347524	14031R	PARTICIPANT	\N	PRESENT	0
347527	347526	14031R	PARTICIPANT	\N	PRESENT	0
347528	347526	19737F	PARTICIPANT	\N	PRESENT	0
347530	347529	14031R	PARTICIPANT	\N	PRESENT	0
347531	347529	19737F	PARTICIPANT	\N	PRESENT	0
347536	347535	19347U	PARTICIPANT	\N	PRESENT	0
347537	347535	19551W	PARTICIPANT	\N	PRESENT	0
347538	347535	19737F	PARTICIPANT	\N	PRESENT	0
347539	347535	14031R	PARTICIPANT	\N	PRESENT	0
347558	347557	19681G	PARTICIPANT	\N	PRESENT	0
347559	347557	19551W	PARTICIPANT	\N	PRESENT	0
347560	347557	15447F	PARTICIPANT	\N	PRESENT	0
347561	347557	19737F	PARTICIPANT	\N	PRESENT	0
347562	347557	17637T	PARTICIPANT	\N	PRESENT	0
347563	347557	14031R	PARTICIPANT	\N	PRESENT	0
347822	339517	04059M	PARTICIPANT	\N	PRESENT	0
347823	339517	19521Q	PARTICIPANT	\N	PRESENT	0
347865	339517	19695N	PARTICIPANT	\N	PRESENT	0
347825	339517	19715Y	PARTICIPANT	\N	PRESENT	0
347826	339517	19631V	PARTICIPANT	\N	PRESENT	0
347876	339517	04088S	PARTICIPANT	\N	PRESENT	0
347867	339517	01058X	PARTICIPANT	\N	PRESENT	0
347829	339517	14083S	PARTICIPANT	\N	PRESENT	0
347830	339517	07004J	PARTICIPANT	\N	PRESENT	0
347831	339517	19737F	PARTICIPANT	\N	PRESENT	0
347832	339517	19619A	PARTICIPANT	\N	PRESENT	0
347833	339517	14227Q	PARTICIPANT	\N	PRESENT	0
347834	339517	19569H	PARTICIPANT	\N	PRESENT	0
347835	339517	14041T	PARTICIPANT	\N	PRESENT	0
347836	339517	19467C	PARTICIPANT	\N	PRESENT	0
347837	339517	17589D	PARTICIPANT	\N	PRESENT	0
347839	339517	14207L	PARTICIPANT	\N	PRESENT	0
347840	339517	11031D	PARTICIPANT	\N	PRESENT	0
347841	347838	19681G	PARTICIPANT	\N	PRESENT	0
347842	347838	14031R	PARTICIPANT	\N	PRESENT	0
347843	339517	11040E	PARTICIPANT	\N	PRESENT	0
347844	347838	19737F	PARTICIPANT	\N	PRESENT	0
347846	347845	19681G	PARTICIPANT	\N	PRESENT	0
347847	347845	14031R	PARTICIPANT	\N	PRESENT	0
347848	347845	17637T	PARTICIPANT	\N	PRESENT	0
347849	347845	19737F	PARTICIPANT	\N	PRESENT	0
347850	339517	19717B	PARTICIPANT	\N	PRESENT	0
347851	339517	19693L	PARTICIPANT	\N	PRESENT	0
347852	339517	14033T	PARTICIPANT	\N	PRESENT	0
347853	339517	11070L	PARTICIPANT	\N	PRESENT	0
347855	339517	14251Q	PARTICIPANT	\N	PRESENT	0
347856	339517	04034C	PARTICIPANT	\N	PRESENT	0
347857	347854	19383Y	PARTICIPANT	\N	PRESENT	0
347858	347854	19387D	PARTICIPANT	\N	PRESENT	0
347859	339517	11110B	PARTICIPANT	\N	PRESENT	0
347860	347854	14031R	PARTICIPANT	\N	PRESENT	0
347861	339517	04018C	PARTICIPANT	\N	PRESENT	0
347862	339517	19545Y	PARTICIPANT	\N	PRESENT	0
347863	339517	11010L	PARTICIPANT	\N	PRESENT	0
347864	339517	11048N	PARTICIPANT	\N	PRESENT	0
347866	339517	14111D	PARTICIPANT	\N	PRESENT	0
347868	339517	08039A	PARTICIPANT	\N	PRESENT	0
347869	339517	89017R	PARTICIPANT	\N	PRESENT	0
347870	339517	11090Q	PARTICIPANT	\N	PRESENT	0
347871	339517	19515S	PARTICIPANT	\N	PRESENT	0
347872	339517	19711U	PARTICIPANT	\N	PRESENT	0
347873	339517	14051J	PARTICIPANT	\N	PRESENT	0
347874	339517	01048V	PARTICIPANT	\N	PRESENT	0
347875	339517	19507S	PARTICIPANT	\N	PRESENT	0
347877	339517	19629C	PARTICIPANT	\N	PRESENT	0
347879	339517	11012A	PARTICIPANT	\N	PRESENT	0
347880	339517	88008L	PARTICIPANT	\N	PRESENT	0
347881	339517	14157T	PARTICIPANT	\N	PRESENT	0
347882	339517	11097X	PARTICIPANT	\N	PRESENT	0
347883	339517	14034U	PARTICIPANT	\N	PRESENT	0
347884	339517	19689Q	PARTICIPANT	\N	PRESENT	0
347885	339517	04057K	PARTICIPANT	\N	PRESENT	0
347886	339517	19671E	PARTICIPANT	\N	PRESENT	0
347887	339517	19663E	PARTICIPANT	\N	PRESENT	0
347888	339517	19667J	PARTICIPANT	\N	PRESENT	0
347889	347878	14207L	PARTICIPANT	\N	PRESENT	0
347890	347878	14357A	PARTICIPANT	\N	PRESENT	0
347891	347878	01025N	PARTICIPANT	\N	PRESENT	0
347892	347878	14033T	PARTICIPANT	\N	PRESENT	0
347893	347878	14205J	PARTICIPANT	\N	PRESENT	0
347894	347878	14257W	PARTICIPANT	\N	PRESENT	0
347895	347878	14265W	PARTICIPANT	\N	PRESENT	0
347896	347878	14135M	PARTICIPANT	\N	PRESENT	0
347897	347878	19619A	PARTICIPANT	\N	PRESENT	0
347898	347878	19507S	PARTICIPANT	\N	PRESENT	0
347899	339517	19553Y	PARTICIPANT	\N	PRESENT	0
347900	339517	19651A	PARTICIPANT	\N	PRESENT	0
347901	339517	14135M	PARTICIPANT	\N	PRESENT	0
347902	339517	19533U	PARTICIPANT	\N	PRESENT	0
347904	347903	14033T	PARTICIPANT	\N	PRESENT	0
347905	347903	14207L	PARTICIPANT	\N	PRESENT	0
347906	347903	19507S	PARTICIPANT	\N	PRESENT	0
347907	347903	14205J	PARTICIPANT	\N	PRESENT	0
347908	347903	14257W	PARTICIPANT	\N	PRESENT	0
347909	347903	01025N	PARTICIPANT	\N	PRESENT	0
347910	347903	14135M	PARTICIPANT	\N	PRESENT	0
347911	347903	14265W	PARTICIPANT	\N	PRESENT	0
347912	339517	08068F	PARTICIPANT	\N	PRESENT	0
347913	339517	14103D	PARTICIPANT	\N	PRESENT	0
347914	339517	19687N	PARTICIPANT	\N	PRESENT	0
347915	339517	19611R	PARTICIPANT	\N	PRESENT	0
347916	339517	11067R	PARTICIPANT	\N	PRESENT	0
347923	339517	11101A	PARTICIPANT	\N	PRESENT	0
347924	339517	19701S	PARTICIPANT	\N	PRESENT	0
347925	339517	14042U	PARTICIPANT	\N	PRESENT	0
347926	339517	08034U	PARTICIPANT	\N	PRESENT	0
347927	339517	19762G	PARTICIPANT	\N	PRESENT	0
347928	339517	19399H	PARTICIPANT	\N	PRESENT	0
347931	339517	04049K	PARTICIPANT	\N	PRESENT	0
347932	339517	87003B	PARTICIPANT	\N	PRESENT	0
347933	339517	08051V	PARTICIPANT	\N	PRESENT	0
347934	339517	14133K	PARTICIPANT	\N	PRESENT	0
347936	339517	04085P	PARTICIPANT	\N	PRESENT	0
347937	339517	11033F	PARTICIPANT	\N	PRESENT	0
347938	339517	18083K	PARTICIPANT	\N	PRESENT	0
358772	345219	04059M	PARTICIPANT	\N	PRESENT	0
358773	345219	19649G	PARTICIPANT	\N	PRESENT	0
358779	345219	01028R	PARTICIPANT	\N	PRESENT	0
358831	345220	19673G	PARTICIPANT	\N	PRESENT	0
358832	345220	04059M	PARTICIPANT	\N	PRESENT	0
358833	345220	04085P	PARTICIPANT	\N	PRESENT	0
358834	345220	12041X	PARTICIPANT	\N	PRESENT	0
358835	345220	11031D	PARTICIPANT	\N	PRESENT	0
358836	345220	19649G	PARTICIPANT	\N	PRESENT	0
358837	345220	04038G	PARTICIPANT	\N	PRESENT	0
358838	345220	11033F	PARTICIPANT	\N	PRESENT	0
358839	345220	19531S	PARTICIPANT	\N	PRESENT	0
358840	345220	19593H	PARTICIPANT	\N	PRESENT	0
358841	345220	11077T	PARTICIPANT	\N	PRESENT	0
358842	345220	19758L	PARTICIPANT	\N	PRESENT	0
358843	345220	11012A	PARTICIPANT	\N	PRESENT	0
358844	345220	17589D	PARTICIPANT	\N	PRESENT	0
358845	345220	19585H	PARTICIPANT	\N	PRESENT	0
358846	345220	19441R	PARTICIPANT	\N	PRESENT	0
358847	345220	11049P	PARTICIPANT	\N	PRESENT	0
358848	345220	14038Y	PARTICIPANT	\N	PRESENT	0
358849	345220	14231L	PARTICIPANT	\N	PRESENT	0
358850	345220	19671E	PARTICIPANT	\N	PRESENT	0
358851	345220	19399H	PARTICIPANT	\N	PRESENT	0
358852	345220	19693L	PARTICIPANT	\N	PRESENT	0
358853	345220	19689Q	PARTICIPANT	\N	PRESENT	0
358854	345220	19657G	PARTICIPANT	\N	PRESENT	0
358855	345220	19687N	PARTICIPANT	\N	PRESENT	0
358856	345220	19695N	PARTICIPANT	\N	PRESENT	0
358857	345220	14235Q	PARTICIPANT	\N	PRESENT	0
358870	345220	19629C	PARTICIPANT	\N	PRESENT	0
358871	345220	95063L	PARTICIPANT	\N	PRESENT	0
358872	345220	11115U	PARTICIPANT	\N	PRESENT	0
361247	361242	08014Q	PARTICIPANT	\N	PRESENT	0
361248	361242	08069G	PARTICIPANT	\N	PRESENT	0
361256	357152	04040A	PARTICIPANT	\N	EXCUSE	0
361257	357152	19253P	PARTICIPANT	\N	PRESENT	0
361258	357152	14259Y	PRESIDENT	0	PRESENT	0
361259	357152	04086Q	PARTICIPANT	\N	PRESENT	0
361260	357152	14231L	PARTICIPANT	\N	PRESENT	0
361261	357152	11049P	PARTICIPANT	\N	PRESENT	0
361262	357152	01057W	PARTICIPANT	\N	PRESENT	0
361263	357152	08010L	PARTICIPANT	\N	PRESENT	0
361267	357152	14257W	PARTICIPANT	\N	PRESENT	0
361265	357152	08034U	PARTICIPANT	\N	PRESENT	0
361266	357152	14063N	PARTICIPANT	\N	PRESENT	0
361268	357152	19735D	PARTICIPANT	\N	PRESENT	0
361269	357152	95063L	PARTICIPANT	\N	PRESENT	0
361270	357152	04045F	PARTICIPANT	\N	PRESENT	0
362305	362033	08058D	PARTICIPANT	\N	PRESENT	0
362306	345231	19762G	PARTICIPANT	\N	PRESENT	0
362307	345231	14179A	PARTICIPANT	\N	PRESENT	0
358829	345220	14034U	PARTICIPANT	\N	PRESENT	0
358830	345220	04047H	PARTICIPANT	\N	PRESENT	0
362308	345231	14042U	PARTICIPANT	\N	PRESENT	0
362309	345231	19441R	PARTICIPANT	\N	PRESENT	0
362544	361169	14187A	PARTICIPANT	\N	PRESENT	0
362545	361169	08062Y	PARTICIPANT	\N	PRESENT	0
362546	361169	19695N	PARTICIPANT	\N	PRESENT	0
362547	361169	11090Q	PRESIDENT	0	PRESENT	0
362548	361169	14033T	PARTICIPANT	\N	PRESENT	0
362549	361169	01025N	PARTICIPANT	\N	PRESENT	0
362550	361169	14205J	PARTICIPANT	\N	PRESENT	0
362551	361169	11056N	PARTICIPANT	\N	PRESENT	0
362552	361169	04088S	PARTICIPANT	\N	PRESENT	0
362553	361169	04089T	PARTICIPANT	\N	PRESENT	0
362554	361169	14115H	PARTICIPANT	\N	PRESENT	0
362555	361169	19507S	PARTICIPANT	\N	PRESENT	0
362556	361169	14207L	PARTICIPANT	\N	PRESENT	0
362557	361169	19747H	PARTICIPANT	\N	PRESENT	0
362558	361169	04043D	PARTICIPANT	\N	PRESENT	0
362559	361169	17589D	PARTICIPANT	\N	PRESENT	0
362560	361169	14257W	PARTICIPANT	\N	PRESENT	0
362562	361271	04035D	PARTICIPANT	\N	PRESENT	0
362563	361271	19443T	PARTICIPANT	\N	PRESENT	0
362564	361271	12041X	PARTICIPANT	\N	PRESENT	0
362565	361271	04034C	PARTICIPANT	\N	PRESENT	0
362566	361271	14235Q	PARTICIPANT	\N	PRESENT	0
362567	361271	14079W	PARTICIPANT	\N	PRESENT	0
362568	361271	01058X	PARTICIPANT	\N	PRESENT	0
362569	361271	16685X	PARTICIPANT	\N	PRESENT	0
362570	361271	08058D	PARTICIPANT	\N	PRESENT	0
362571	361271	04042C	PRESIDENT	0	PRESENT	0
362572	361271	11054L	PARTICIPANT	\N	PRESENT	0
362573	361271	11066Q	PARTICIPANT	\N	PRESENT	0
362574	361271	08056B	PARTICIPANT	\N	PRESENT	0
362575	361271	11115U	PARTICIPANT	\N	PRESENT	0
362576	361271	14105F	PARTICIPANT	\N	PRESENT	0
362577	361271	19709B	PARTICIPANT	\N	PRESENT	0
362578	361271	08049C	PARTICIPANT	\N	PRESENT	0
362579	361271	14267Y	PARTICIPANT	\N	PRESENT	0
362580	361271	98050T	PARTICIPANT	\N	PRESENT	0
362581	361271	08061X	PARTICIPANT	\N	PRESENT	0
362582	361271	14211G	PARTICIPANT	\N	PRESENT	0
362583	361271	19583F	PARTICIPANT	\N	PRESENT	0
362584	361271	08047A	PARTICIPANT	\N	PRESENT	0
362585	361271	98029W	PARTICIPANT	\N	PRESENT	0
362586	361271	08053X	PARTICIPANT	\N	PRESENT	0
362587	361271	19251M	PARTICIPANT	\N	PRESENT	0
362588	361271	19721W	PARTICIPANT	\N	PRESENT	0
362589	361271	98022P	PARTICIPANT	\N	PRESENT	0
362590	361271	11041F	PARTICIPANT	\N	PRESENT	0
362591	361271	95037J	PARTICIPANT	\N	PRESENT	0
362592	361271	19421M	PARTICIPANT	\N	PRESENT	0
362593	361271	97011G	PARTICIPANT	\N	PRESENT	0
362594	361271	14097Y	PARTICIPANT	\N	PRESENT	0
362595	361271	04040A	PARTICIPANT	\N	PRESENT	0
362596	361271	14055N	PARTICIPANT	\N	PRESENT	0
362597	361271	95067Q	PARTICIPANT	\N	PRESENT	0
362598	361271	14028W	PARTICIPANT	\N	PRESENT	0
362599	361271	14255U	PARTICIPANT	\N	PRESENT	0
362639	361169	19269X	PARTICIPANT	\N	PRESENT	0
362640	361271	19669L	PARTICIPANT	\N	PRESENT	0
362642	361271	11027H	PARTICIPANT	\N	PRESENT	0
362643	361271	98018T	PARTICIPANT	\N	EXCUSE	0
362646	362644	19715Y	PARTICIPANT	\N	PRESENT	0
362647	362644	14097Y	PARTICIPANT	\N	PRESENT	0
362648	362644	19745F	PARTICIPANT	\N	PRESENT	0
362649	362644	19629C	PARTICIPANT	\N	PRESENT	0
362650	362644	19369B	PARTICIPANT	\N	PRESENT	0
362651	362644	14187A	PARTICIPANT	\N	PRESENT	0
362652	362644	08019V	PARTICIPANT	\N	PRESENT	0
362653	362644	08038Y	PARTICIPANT	\N	PRESENT	0
362654	362644	08060W	PARTICIPANT	\N	PRESENT	0
362655	361142	14028W	PARTICIPANT	\N	EXCUSE	0
362656	362644	08024S	PARTICIPANT	\N	PRESENT	0
362659	362658	08024S	PARTICIPANT	\N	PRESENT	0
362660	362658	19721W	PARTICIPANT	\N	PRESENT	0
362661	362658	19369B	PARTICIPANT	\N	PRESENT	0
362662	362658	19715Y	PARTICIPANT	\N	PRESENT	0
362663	362658	08060W	PARTICIPANT	\N	PRESENT	0
362664	362658	08038Y	PARTICIPANT	\N	PRESENT	0
362665	362658	14097Y	PARTICIPANT	\N	PRESENT	0
362666	362658	14187A	PARTICIPANT	\N	PRESENT	0
362667	362658	19745F	PARTICIPANT	\N	PRESENT	0
362668	362658	08019V	PARTICIPANT	\N	PRESENT	0
362669	362658	19629C	PARTICIPANT	\N	PRESENT	0
362670	361174	14221J	PARTICIPANT	\N	PRESENT	0
362671	361174	05012A	PARTICIPANT	\N	PRESENT	0
362672	361174	96004D	PARTICIPANT	\N	PRESENT	0
362673	361174	08024S	PARTICIPANT	\N	PRESENT	0
362674	361174	17637T	PARTICIPANT	\N	PRESENT	0
362675	361174	11065P	PARTICIPANT	\N	PRESENT	0
362676	361174	19525U	PARTICIPANT	\N	PRESENT	0
362677	361174	19659J	PARTICIPANT	\N	PRESENT	0
362679	361174	19347U	PARTICIPANT	\N	PRESENT	0
362681	362680	11074Q	PARTICIPANT	\N	PRESENT	0
362682	362680	01057W	PARTICIPANT	\N	PRESENT	0
362683	362680	19723Y	PARTICIPANT	\N	PRESENT	0
362684	362680	14079W	PARTICIPANT	\N	PRESENT	0
362685	362680	14147R	PARTICIPANT	\N	PRESENT	0
362686	361550	11074Q	PRESIDENT	0	PRESENT	0
362688	361550	14199E	PARTICIPANT	\N	EXCUSE	0
362689	361550	08011M	PARTICIPANT	\N	EXCUSE	0
362690	360656	19697Q	PARTICIPANT	\N	PRESENT	0
362691	360656	11067R	PARTICIPANT	\N	PRESENT	0
362692	360656	19565D	PARTICIPANT	\N	PRESENT	0
362693	360656	14355X	PARTICIPANT	\N	PRESENT	0
362694	360656	19798U	PARTICIPANT	\N	PRESENT	0
362695	360656	19569H	PARTICIPANT	\N	PRESENT	0
362696	360656	11097X	PARTICIPANT	\N	PRESENT	0
362697	360656	19415P	PARTICIPANT	\N	PRESENT	0
362698	360656	14223L	PARTICIPANT	\N	PRESENT	0
362699	360656	04045F	PARTICIPANT	\N	PRESENT	0
362700	360656	14026U	PARTICIPANT	\N	PRESENT	0
362701	360656	17779H	PARTICIPANT	\N	PRESENT	0
362702	360656	19703U	PARTICIPANT	\N	PRESENT	0
362703	360656	19553Y	PARTICIPANT	\N	PRESENT	0
337452	337447	89017R	PARTICIPANT	\N	PRESENT	0
337453	337447	19717B	PARTICIPANT	\N	PRESENT	0
337454	337447	19515S	PARTICIPANT	\N	PRESENT	0
337455	337447	19667J	PARTICIPANT	\N	PRESENT	0
337456	337447	08068F	PARTICIPANT	\N	PRESENT	0
337457	337447	14083S	PARTICIPANT	\N	PRESENT	0
337458	337447	14329V	PARTICIPANT	\N	PRESENT	0
337459	337447	04071H	PARTICIPANT	\N	PRESENT	0
337460	337447	11110B	PARTICIPANT	\N	PRESENT	0
337461	337447	14187A	PARTICIPANT	\N	PRESENT	0
337462	337447	19521Q	PRESIDENT	0	PRESENT	0
337463	337447	19695N	PARTICIPANT	\N	PRESENT	0
337464	337447	14199E	PARTICIPANT	\N	PRESENT	0
337465	337447	19399H	PARTICIPANT	\N	PRESENT	0
337466	337447	11048N	PARTICIPANT	\N	PRESENT	0
337467	337447	04049K	PARTICIPANT	\N	PRESENT	0
337468	337447	19711U	PARTICIPANT	\N	PRESENT	0
337469	337447	08034U	PARTICIPANT	\N	PRESENT	0
337470	337447	19441R	PARTICIPANT	\N	PRESENT	0
337471	337447	08073C	PARTICIPANT	\N	PRESENT	0
337472	337447	19762G	PARTICIPANT	\N	PRESENT	0
337473	337447	11090Q	PARTICIPANT	\N	PRESENT	0
337474	337447	14051J	PARTICIPANT	\N	PRESENT	0
337475	337447	04034C	PARTICIPANT	\N	PRESENT	0
337476	337447	14157T	PARTICIPANT	\N	PRESENT	0
337493	337447	11070L	PARTICIPANT	\N	EXCUSE	0
337498	337447	14034U	PARTICIPANT	\N	PRESENT	0
338229	338228	04049K	PARTICIPANT	\N	PRESENT	0
338231	338230	04049K	PARTICIPANT	\N	PRESENT	0
338232	338230	11048N	PARTICIPANT	\N	PRESENT	0
338233	338230	19711U	PARTICIPANT	\N	PRESENT	0
338235	338234	04049K	PARTICIPANT	\N	PRESENT	0
338236	338234	14083S	PARTICIPANT	\N	PRESENT	0
338237	338234	19711U	PARTICIPANT	\N	PRESENT	0
338238	338234	08034U	PARTICIPANT	\N	PRESENT	0
338240	338239	14083S	PARTICIPANT	\N	PRESENT	0
338241	338239	04049K	PARTICIPANT	\N	PRESENT	0
338242	338239	19711U	PARTICIPANT	\N	PRESENT	0
338243	338239	08034U	PARTICIPANT	\N	PRESENT	0
338244	338239	19515S	PARTICIPANT	\N	PRESENT	0
338246	338245	04049K	PARTICIPANT	\N	PRESENT	0
338247	338245	19711U	PARTICIPANT	\N	PRESENT	0
338249	338248	14083S	PARTICIPANT	\N	PRESENT	0
338251	338250	11048N	PARTICIPANT	\N	PRESENT	0
338252	338250	14083S	PARTICIPANT	\N	PRESENT	0
338253	338250	19711U	PARTICIPANT	\N	PRESENT	0
338254	338250	08034U	PARTICIPANT	\N	PRESENT	0
338256	338255	11048N	PARTICIPANT	\N	PRESENT	0
338257	338255	19711U	PARTICIPANT	\N	PRESENT	0
338258	338255	14083S	PARTICIPANT	\N	PRESENT	0
338259	338255	08034U	PARTICIPANT	\N	PRESENT	0
338260	338255	14173T	PARTICIPANT	\N	PRESENT	0
338262	338261	14083S	PARTICIPANT	\N	PRESENT	0
338263	338261	08034U	PARTICIPANT	\N	PRESENT	0
339735	339734	14207L	PARTICIPANT	\N	PRESENT	0
339736	339734	14195A	PARTICIPANT	\N	PRESENT	0
339737	339734	19467C	PARTICIPANT	\N	PRESENT	0
339738	339734	18083K	PARTICIPANT	\N	PRESENT	0
339739	339734	14357A	PARTICIPANT	\N	PRESENT	0
339740	339734	17589D	PARTICIPANT	\N	PRESENT	0
339741	339734	19507S	PARTICIPANT	\N	PRESENT	0
339742	339734	14187A	PARTICIPANT	\N	PRESENT	0
339743	339734	19511N	PARTICIPANT	\N	PRESENT	0
339744	339734	08015R	PARTICIPANT	\N	PRESENT	0
339745	339734	19441R	PARTICIPANT	\N	PRESENT	0
339746	339734	14221J	PARTICIPANT	\N	PRESENT	0
339747	339734	19369B	PARTICIPANT	\N	PRESENT	0
339748	339734	14257W	PARTICIPANT	\N	PRESENT	0
339749	339734	14265W	PARTICIPANT	\N	PRESENT	0
339750	339734	19745F	PARTICIPANT	\N	PRESENT	0
339751	339734	04088S	PARTICIPANT	\N	PRESENT	0
339752	339734	14135M	PARTICIPANT	\N	PRESENT	0
339753	339734	11012A	PARTICIPANT	\N	PRESENT	0
339754	339734	11097X	PARTICIPANT	\N	PRESENT	0
340083	340081	14219Q	PARTICIPANT	\N	PRESENT	0
339756	339734	19619A	PARTICIPANT	\N	PRESENT	0
340082	340081	08009T	PARTICIPANT	\N	PRESENT	0
340084	340081	14221J	PARTICIPANT	\N	PRESENT	0
340085	340081	19713W	PARTICIPANT	\N	PRESENT	0
340092	340090	14042U	PARTICIPANT	\N	PRESENT	0
340093	340091	14042U	PARTICIPANT	\N	PRESENT	0
346451	339512	19479G	PARTICIPANT	\N	PRESENT	0
348049	348048	19251M	PARTICIPANT	\N	PRESENT	0
348050	348048	14087W	PARTICIPANT	\N	PRESENT	0
348051	348048	19593H	PARTICIPANT	\N	PRESENT	0
356362	345115	04044E	PARTICIPANT	\N	PRESENT	0
356363	345115	19723Y	PARTICIPANT	\N	PRESENT	0
356364	345115	19511N	PARTICIPANT	\N	PRESENT	0
356365	345115	14195A	PARTICIPANT	\N	PRESENT	0
356366	345115	14087W	PARTICIPANT	\N	PRESENT	0
356367	345115	19533U	PARTICIPANT	\N	PRESENT	0
356368	345115	19731Y	PARTICIPANT	\N	PRESENT	0
356369	345115	19691J	PARTICIPANT	\N	PRESENT	0
356370	345115	19443T	PARTICIPANT	\N	PRESENT	0
356371	345115	19399H	PARTICIPANT	\N	PRESENT	0
356372	345115	87003B	PARTICIPANT	\N	PRESENT	0
356373	345115	04092N	PARTICIPANT	\N	PRESENT	0
356374	345115	08028W	PARTICIPANT	\N	PRESENT	0
356375	345115	08031R	PARTICIPANT	\N	PRESENT	0
356376	345115	14147R	PARTICIPANT	\N	PRESENT	0
356377	345115	14215L	PARTICIPANT	\N	PRESENT	0
356378	345115	19703U	PARTICIPANT	\N	PRESENT	0
356379	345115	11040E	PARTICIPANT	\N	PRESENT	0
356380	345115	19760E	PARTICIPANT	\N	PRESENT	0
356381	345115	04045F	PARTICIPANT	\N	PRESENT	0
356382	345115	14241N	PARTICIPANT	\N	PRESENT	0
356383	345115	14327T	PARTICIPANT	\N	PRESENT	0
356384	345115	19727D	PARTICIPANT	\N	PRESENT	0
356385	345115	10006L	PARTICIPANT	\N	PRESENT	0
356386	345115	89017R	PARTICIPANT	\N	PRESENT	0
356387	345115	19745F	PARTICIPANT	\N	PRESENT	0
356388	345115	14042U	PARTICIPANT	\N	PRESENT	0
356389	345115	04088S	PARTICIPANT	\N	PRESENT	0
356390	345115	14157T	PARTICIPANT	\N	PRESENT	0
356391	345115	18083K	PARTICIPANT	\N	PRESENT	0
356392	345115	19794Q	PARTICIPANT	\N	PRESENT	0
356393	345115	14239U	PARTICIPANT	\N	PRESENT	0
356394	345115	98050T	PARTICIPANT	\N	PRESENT	0
356395	345115	11031D	PARTICIPANT	\N	PRESENT	0
356396	345115	19479G	PARTICIPANT	\N	PRESENT	0
356397	345115	14217N	PARTICIPANT	\N	PRESENT	0
356398	345115	14223L	PARTICIPANT	\N	PRESENT	0
356399	345115	19575F	PARTICIPANT	\N	PRESENT	0
356400	345115	19629C	PARTICIPANT	\N	PRESENT	0
356401	345115	19693L	PARTICIPANT	\N	PRESENT	0
356402	345115	14119M	PARTICIPANT	\N	PRESENT	0
356403	345115	11097X	PARTICIPANT	\N	PRESENT	0
356404	345115	19387D	PARTICIPANT	\N	PRESENT	0
356405	345115	98024R	PARTICIPANT	\N	PRESENT	0
356406	345115	19679N	PARTICIPANT	\N	PRESENT	0
356408	345115	14213J	PARTICIPANT	\N	PRESENT	0
356409	345115	08052W	PARTICIPANT	\N	PRESENT	0
356410	345115	19741B	PARTICIPANT	\N	PRESENT	0
356411	345115	19447X	PARTICIPANT	\N	PRESENT	0
356412	345115	11101A	PARTICIPANT	\N	PRESENT	0
356413	345115	08062Y	PARTICIPANT	\N	PRESENT	0
356414	345115	97011G	PARTICIPANT	\N	PRESENT	0
356415	345115	08056B	PARTICIPANT	\N	PRESENT	0
356416	345115	04033B	PARTICIPANT	\N	PRESENT	0
356417	345115	08010L	PARTICIPANT	\N	PRESENT	0
356418	345115	11067R	PARTICIPANT	\N	PRESENT	0
356419	345115	17779H	PARTICIPANT	\N	PRESENT	0
356420	345115	14281W	PARTICIPANT	\N	PRESENT	0
356421	345115	14225N	PARTICIPANT	\N	PRESENT	0
356422	345115	14041T	PARTICIPANT	\N	PRESENT	0
356423	345115	19683J	PARTICIPANT	\N	PRESENT	0
356424	345115	15447F	PARTICIPANT	\N	PRESENT	0
356425	345115	14187A	PARTICIPANT	\N	PRESENT	0
356426	345115	04086Q	PARTICIPANT	\N	PRESENT	0
356427	345115	14085U	PARTICIPANT	\N	PRESENT	0
356428	345115	19599P	PARTICIPANT	\N	PRESENT	0
356429	345115	14135M	PARTICIPANT	\N	PRESENT	0
356430	345115	11109J	PARTICIPANT	\N	PRESENT	0
356431	345115	08048B	PARTICIPANT	\N	PRESENT	0
356432	345115	01024M	PARTICIPANT	\N	PRESENT	0
356433	345115	14026U	PARTICIPANT	\N	PRESENT	0
356434	345115	14357A	PARTICIPANT	\N	PRESENT	0
356435	345115	19467C	PARTICIPANT	\N	PRESENT	0
356436	345115	17589D	PARTICIPANT	\N	PRESENT	0
356438	345115	19619A	PARTICIPANT	\N	PRESENT	0
356439	345115	19367Y	PARTICIPANT	\N	PRESENT	0
356440	345115	19758L	PARTICIPANT	\N	PRESENT	0
356441	345115	14038Y	PARTICIPANT	\N	PRESENT	0
356442	345115	11048N	PARTICIPANT	\N	PRESENT	0
356443	345115	11066Q	PARTICIPANT	\N	PRESENT	0
356444	345115	14055N	PARTICIPANT	\N	PRESENT	0
356445	345115	19681G	PARTICIPANT	\N	PRESENT	0
356446	345115	08020N	PARTICIPANT	\N	PRESENT	0
357351	345117	08056B	PARTICIPANT	\N	PRESENT	0
357352	345117	07029T	PARTICIPANT	\N	PRESENT	0
357353	345117	08012N	PARTICIPANT	\N	PRESENT	0
357354	357271	17637T	PARTICIPANT	\N	PRESENT	0
357355	357271	19713W	PARTICIPANT	\N	PRESENT	0
357356	345117	98029W	PARTICIPANT	\N	PRESENT	0
357357	345117	19447X	PARTICIPANT	\N	PRESENT	0
357358	345117	19621T	PARTICIPANT	\N	PRESENT	0
357359	345117	19369B	PARTICIPANT	\N	PRESENT	0
357360	345117	87003B	PARTICIPANT	\N	PRESENT	0
357361	345117	14083S	PARTICIPANT	\N	PRESENT	0
357362	357271	14157T	PARTICIPANT	\N	PRESENT	0
357363	345117	19782L	PARTICIPANT	\N	PRESENT	0
357364	345117	14030Q	PARTICIPANT	\N	PRESENT	0
357365	345117	19413M	PARTICIPANT	\N	PRESENT	0
357366	345117	19643A	PARTICIPANT	\N	PRESENT	0
357367	345117	14041T	PARTICIPANT	\N	PRESENT	0
357368	345117	19679N	PARTICIPANT	\N	PRESENT	0
357369	345117	19507S	PARTICIPANT	\N	PRESENT	0
357370	345117	04088S	PARTICIPANT	\N	PRESENT	0
357371	345117	19329S	PARTICIPANT	\N	PRESENT	0
357372	345117	11083R	PARTICIPANT	\N	PRESENT	0
357373	357271	19347U	PARTICIPANT	\N	PRESENT	0
357374	357271	11065P	PARTICIPANT	\N	PRESENT	0
357375	345117	19521Q	PARTICIPANT	\N	PRESENT	0
357376	345117	14026U	PARTICIPANT	\N	PRESENT	0
357377	345117	19441R	PARTICIPANT	\N	PRESENT	0
357378	345117	08020N	PARTICIPANT	\N	PRESENT	0
357379	357271	80027E	PARTICIPANT	\N	PRESENT	0
357380	357271	04097T	PARTICIPANT	\N	PRESENT	0
357381	345117	08039A	PARTICIPANT	\N	PRESENT	0
357382	345117	14235Q	PARTICIPANT	\N	PRESENT	0
357383	345117	08062Y	PARTICIPANT	\N	PRESENT	0
357384	345117	11056N	PARTICIPANT	\N	PRESENT	0
357385	345117	14121F	PARTICIPANT	\N	PRESENT	0
357386	345117	19693L	PARTICIPANT	\N	PRESENT	0
357387	345117	19647E	PARTICIPANT	\N	PRESENT	0
357388	357271	95062K	PARTICIPANT	\N	PRESENT	0
357389	357271	14093U	PARTICIPANT	\N	PRESENT	0
357390	345117	14267Y	PARTICIPANT	\N	PRESENT	0
357398	345117	19467C	PARTICIPANT	\N	PRESENT	0
357403	345117	16685X	PARTICIPANT	\N	PRESENT	0
357404	345117	14053L	PARTICIPANT	\N	PRESENT	0
357405	345117	19697Q	PARTICIPANT	\N	PRESENT	0
357406	345117	19683J	PARTICIPANT	\N	PRESENT	0
357407	345117	08045X	PARTICIPANT	\N	PRESENT	0
357708	345118	14038Y	PARTICIPANT	\N	PRESENT	0
357709	345118	01062T	PARTICIPANT	\N	PRESENT	0
357710	345118	14081Q	PARTICIPANT	\N	PRESENT	0
357711	355936	04018C	PARTICIPANT	\N	PRESENT	0
357713	355936	04049K	PARTICIPANT	\N	PRESENT	0
357717	345118	19637C	PARTICIPANT	\N	PRESENT	0
357718	355936	14215L	PARTICIPANT	\N	PRESENT	0
357719	355936	19289C	PARTICIPANT	\N	PRESENT	0
357720	355936	08039A	PARTICIPANT	\N	PRESENT	0
357721	355936	18083K	PARTICIPANT	\N	PRESENT	0
357722	355936	10015M	PARTICIPANT	\N	PRESENT	0
357723	345118	19657G	PARTICIPANT	\N	PRESENT	0
357724	345118	19369B	PARTICIPANT	\N	PRESENT	0
357725	355936	14179A	PARTICIPANT	\N	PRESENT	0
357726	345118	19253P	PARTICIPANT	\N	PRESENT	0
357727	345118	08068F	PARTICIPANT	\N	PRESENT	0
357728	345118	14111D	PARTICIPANT	\N	PRESENT	0
357729	345118	14331P	PARTICIPANT	\N	PRESENT	0
357730	345118	19441R	PARTICIPANT	\N	PRESENT	0
357731	345118	14031R	PARTICIPANT	\N	PRESENT	0
357732	345118	17779H	PARTICIPANT	\N	PRESENT	0
357813	345119	14179A	PARTICIPANT	\N	PRESENT	0
357814	345119	04038G	PARTICIPANT	\N	PRESENT	0
357815	345119	17779H	PARTICIPANT	\N	PRESENT	0
357816	345119	14281W	PARTICIPANT	\N	PRESENT	0
357817	345119	19333N	PARTICIPANT	\N	PRESENT	0
357818	345119	19549D	PARTICIPANT	\N	PRESENT	0
357819	345119	14021P	PARTICIPANT	\N	PRESENT	0
357820	345119	14081Q	PARTICIPANT	\N	PRESENT	0
357821	345119	19725B	PARTICIPANT	\N	PRESENT	0
357822	345119	11045K	PARTICIPANT	\N	PRESENT	0
357823	345119	19599P	PARTICIPANT	\N	PRESENT	0
357824	345119	19543W	PARTICIPANT	\N	PRESENT	0
357825	345119	19253P	PARTICIPANT	\N	PRESENT	0
357826	345119	19629C	PARTICIPANT	\N	PRESENT	0
357827	345119	98022P	PARTICIPANT	\N	PRESENT	0
357828	345119	17589D	PARTICIPANT	\N	PRESENT	0
357829	345119	19551W	PARTICIPANT	\N	PRESENT	0
357830	345119	19413M	PARTICIPANT	\N	PRESENT	0
357831	345119	19719D	PARTICIPANT	\N	PRESENT	0
357832	345119	11012A	PARTICIPANT	\N	PRESENT	0
357833	345119	14089Y	PARTICIPANT	\N	PRESENT	0
357834	345119	14267Y	PARTICIPANT	\N	PRESENT	0
357835	345119	19747H	PARTICIPANT	\N	PRESENT	0
357836	345119	19251M	PARTICIPANT	\N	PRESENT	0
357837	345119	14219Q	PARTICIPANT	\N	PRESENT	0
357838	345119	14042U	PARTICIPANT	\N	PRESENT	0
357839	345119	19691J	PARTICIPANT	\N	PRESENT	0
357840	345119	19369B	PARTICIPANT	\N	PRESENT	0
357841	345119	14073Q	PARTICIPANT	\N	PRESENT	0
357842	345119	14215L	PARTICIPANT	\N	PRESENT	0
357843	345119	01024M	PARTICIPANT	\N	PRESENT	0
357844	345119	01025N	PARTICIPANT	\N	PRESENT	0
357845	345119	04044E	PARTICIPANT	\N	PRESENT	0
357846	345119	14087W	PARTICIPANT	\N	PRESENT	0
357847	345119	14053L	PARTICIPANT	\N	PRESENT	0
357848	345119	14061L	PARTICIPANT	\N	PRESENT	0
357849	345119	19503N	PARTICIPANT	\N	PRESENT	0
357850	345119	08062Y	PARTICIPANT	\N	PRESENT	0
357851	345119	07029T	PARTICIPANT	\N	PRESENT	0
357852	345119	08038Y	PARTICIPANT	\N	PRESENT	0
357853	345119	14065Q	PARTICIPANT	\N	PRESENT	0
357854	345119	14031R	PARTICIPANT	\N	PRESENT	0
357855	345119	14135M	PARTICIPANT	\N	PRESENT	0
357856	345119	19447X	PARTICIPANT	\N	PRESENT	0
357857	345119	04088S	PARTICIPANT	\N	PRESENT	0
357858	345119	14029X	PARTICIPANT	\N	PRESENT	0
357859	345119	01028R	PARTICIPANT	\N	PRESENT	0
357860	345119	19467C	PARTICIPANT	\N	PRESENT	0
357861	345119	19794Q	PARTICIPANT	\N	PRESENT	0
357862	345119	19673G	PARTICIPANT	\N	PRESENT	0
357863	345119	11109J	PARTICIPANT	\N	PRESENT	0
357864	345119	19703U	PARTICIPANT	\N	PRESENT	0
357865	345119	95062K	PARTICIPANT	\N	PRESENT	0
357866	345119	19679N	PARTICIPANT	\N	PRESENT	0
357867	345119	08045X	PARTICIPANT	\N	PRESENT	0
357868	345119	14207L	PARTICIPANT	\N	PRESENT	0
357869	345119	04045F	PARTICIPANT	\N	PRESENT	0
357870	345119	89017R	PARTICIPANT	\N	PRESENT	0
357871	345119	14241N	PARTICIPANT	\N	PRESENT	0
357872	345119	14079W	PARTICIPANT	\N	PRESENT	0
357873	345119	17583W	PARTICIPANT	\N	PRESENT	0
357874	345119	19573D	PARTICIPANT	\N	PRESENT	0
357875	345119	19441R	PARTICIPANT	\N	PRESENT	0
357876	345119	19649G	PARTICIPANT	\N	PRESENT	0
357877	345119	14327T	PARTICIPANT	\N	PRESENT	0
357878	345119	19575F	PARTICIPANT	\N	PRESENT	0
357879	345119	05012A	PARTICIPANT	\N	PRESENT	0
357880	345119	14109K	PARTICIPANT	\N	PRESENT	0
357884	345119	19631V	PARTICIPANT	\N	PRESENT	0
357882	345119	14033T	PARTICIPANT	\N	PRESENT	0
357883	345119	14151M	PARTICIPANT	\N	PRESENT	0
357885	345119	14257W	PARTICIPANT	\N	PRESENT	0
357886	345119	08044W	PARTICIPANT	\N	PRESENT	0
357887	345119	19713W	PARTICIPANT	\N	PRESENT	0
357888	345119	08055A	PARTICIPANT	\N	PRESENT	0
357889	345119	08043V	PARTICIPANT	\N	PRESENT	0
357890	345119	14159V	PARTICIPANT	\N	PRESENT	0
357891	345119	14221J	PARTICIPANT	\N	PRESENT	0
357811	345119	01043Q	PARTICIPANT	\N	PRESENT	0
357812	345119	05008E	PARTICIPANT	\N	PRESENT	0
357892	345119	19643A	PARTICIPANT	\N	PRESENT	0
357893	355936	98018T	PARTICIPANT	\N	EXCUSE	0
357894	355936	19709B	PARTICIPANT	\N	EXCUSE	0
357895	355936	04040A	PARTICIPANT	\N	EXCUSE	0
357896	355936	14193X	PARTICIPANT	\N	EXCUSE	0
357897	355936	11064N	PARTICIPANT	\N	EXCUSE	0
357898	355936	11027H	PARTICIPANT	\N	EXCUSE	0
357899	345119	01062T	PARTICIPANT	\N	PRESENT	0
357900	345119	14001X	PARTICIPANT	\N	PRESENT	0
357901	345119	14197C	PARTICIPANT	\N	PRESENT	0
357902	345119	19647E	PARTICIPANT	\N	PRESENT	0
357903	345119	16685X	PARTICIPANT	\N	PRESENT	0
332721	332348	11048N	PARTICIPANT	\N	PRESENT	0
332722	332348	19479G	PARTICIPANT	\N	PRESENT	0
332723	332348	19711U	PARTICIPANT	\N	PRESENT	0
332724	332348	08034U	PARTICIPANT	\N	PRESENT	0
332725	332348	19545Y	PARTICIPANT	\N	PRESENT	0
332726	332348	01057W	PARTICIPANT	\N	PRESENT	0
332727	332348	19689Q	PARTICIPANT	\N	PRESENT	0
332728	332348	19667J	PARTICIPANT	\N	PRESENT	0
332729	332348	08011M	PARTICIPANT	\N	PRESENT	0
332730	332348	19671E	PARTICIPANT	\N	PRESENT	0
332731	332348	88008L	PARTICIPANT	\N	PRESENT	0
332732	332348	14159V	PARTICIPANT	\N	PRESENT	0
332733	332348	04086Q	PARTICIPANT	\N	PRESENT	0
332734	332348	07029T	PARTICIPANT	\N	PRESENT	0
332735	332348	14085U	PARTICIPANT	\N	PRESENT	0
332736	332348	14331P	PARTICIPANT	\N	PRESENT	0
332737	332348	14199E	PARTICIPANT	\N	PRESENT	0
332738	332348	95041E	PARTICIPANT	\N	PRESENT	0
332739	332348	08069G	PARTICIPANT	\N	PRESENT	0
332740	332348	08010L	PARTICIPANT	\N	PRESENT	0
332741	332348	19741B	PARTICIPANT	\N	PRESENT	0
332742	332348	04061F	PARTICIPANT	\N	PRESENT	0
332743	321364	19741B	PARTICIPANT	\N	PRESENT	0
332744	321364	14089Y	PARTICIPANT	\N	PRESENT	0
332745	321364	14053L	PARTICIPANT	\N	PRESENT	0
332746	321364	05008E	PARTICIPANT	\N	PRESENT	0
332747	321364	08010L	PARTICIPANT	\N	PRESENT	0
332748	321364	19545Y	PARTICIPANT	\N	PRESENT	0
332749	321364	19782L	PARTICIPANT	\N	PRESENT	0
332750	321364	07033P	PARTICIPANT	\N	PRESENT	0
332751	321364	11027H	PARTICIPANT	\N	PRESENT	0
332752	321364	19719D	PARTICIPANT	\N	PRESENT	0
332753	321364	14105F	PARTICIPANT	\N	PRESENT	0
332754	321364	11054L	PARTICIPANT	\N	PRESENT	0
332755	321364	11031D	PARTICIPANT	\N	PRESENT	0
332756	321364	19515S	PARTICIPANT	\N	PRESENT	0
332757	321364	14147R	PARTICIPANT	\N	PRESENT	0
332758	321364	14042U	PARTICIPANT	\N	PRESENT	0
332760	321364	19667J	PARTICIPANT	\N	PRESENT	0
332762	321364	10006L	PARTICIPANT	\N	PRESENT	0
332763	321364	95067Q	PARTICIPANT	\N	PRESENT	0
332764	321364	14028W	PARTICIPANT	\N	PRESENT	0
332765	321364	08031R	PARTICIPANT	\N	PRESENT	0
332766	321364	19621T	PARTICIPANT	\N	PRESENT	0
332767	321364	04045F	PARTICIPANT	\N	PRESENT	0
332768	321364	14169X	PARTICIPANT	\N	PRESENT	0
332769	321364	19695N	PARTICIPANT	\N	PRESENT	0
332772	321364	14083S	PARTICIPANT	\N	PRESENT	0
332773	321364	04085P	PARTICIPANT	\N	PRESENT	0
332790	321366	19593H	PARTICIPANT	\N	PRESENT	0
332791	321366	19651A	PARTICIPANT	\N	PRESENT	0
332792	321366	19507S	PARTICIPANT	\N	PRESENT	0
332793	321366	19643A	PARTICIPANT	\N	PRESENT	0
332794	321366	14109K	PARTICIPANT	\N	PRESENT	0
332795	321366	14229S	PARTICIPANT	\N	PRESENT	0
332796	321366	19731Y	PARTICIPANT	\N	PRESENT	0
332797	321366	04057K	PARTICIPANT	\N	PRESENT	0
332798	321366	11074Q	PARTICIPANT	\N	PRESENT	0
332799	321366	04070G	PARTICIPANT	\N	PRESENT	0
332800	321366	11083R	PARTICIPANT	\N	PRESENT	0
332801	321366	08060W	PARTICIPANT	\N	PRESENT	0
332802	321366	08031R	PARTICIPANT	\N	PRESENT	0
332787	321366	01043Q	PARTICIPANT	\N	PRESENT	0
332789	321366	19711U	PARTICIPANT	\N	PRESENT	0
332803	321366	19369B	PARTICIPANT	\N	PRESENT	0
332804	321366	14042U	PARTICIPANT	\N	PRESENT	0
332805	321366	14223L	PARTICIPANT	\N	PRESENT	0
332806	321366	19735D	PARTICIPANT	\N	PRESENT	0
332807	321366	08043V	PARTICIPANT	\N	PRESENT	0
332808	321366	14217N	PARTICIPANT	\N	PRESENT	0
332809	321366	19399H	PARTICIPANT	\N	PRESENT	0
332810	321366	19693L	PARTICIPANT	\N	PRESENT	0
332811	321366	92040Q	PARTICIPANT	\N	PRESENT	0
332812	321366	19667J	PARTICIPANT	\N	PRESENT	0
332813	321366	08039A	PARTICIPANT	\N	PRESENT	0
332814	321366	19515S	PARTICIPANT	\N	PRESENT	0
332815	321366	19717B	PARTICIPANT	\N	PRESENT	0
332816	321366	19699S	PARTICIPANT	\N	PRESENT	0
332817	321366	14073Q	PARTICIPANT	\N	PRESENT	0
332818	321366	19758L	PARTICIPANT	\N	PRESENT	0
332819	321366	19687N	PARTICIPANT	\N	PRESENT	0
332820	321366	07004J	PARTICIPANT	\N	PRESENT	0
332821	321366	14079W	PARTICIPANT	\N	PRESENT	0
332822	321366	19729F	PARTICIPANT	\N	PRESENT	0
332823	321366	14105F	PARTICIPANT	\N	PRESENT	0
332824	321366	04035D	PARTICIPANT	\N	PRESENT	0
332825	321366	19611R	PARTICIPANT	\N	PRESENT	0
332826	321366	01024M	PARTICIPANT	\N	PRESENT	0
332827	321366	14249W	PARTICIPANT	\N	PRESENT	0
332828	321366	04092N	PARTICIPANT	\N	PRESENT	0
332829	321366	95062K	PARTICIPANT	\N	PRESENT	0
332830	321366	14030Q	PARTICIPANT	\N	PRESENT	0
332831	321366	19741B	PARTICIPANT	\N	PRESENT	0
332832	321366	14085U	PARTICIPANT	\N	PRESENT	0
332833	321366	19441R	PARTICIPANT	\N	PRESENT	0
332834	321366	19725B	PARTICIPANT	\N	PRESENT	0
332835	321366	19599P	PARTICIPANT	\N	PRESENT	0
332836	321366	08049C	PARTICIPANT	\N	PRESENT	0
332837	321366	14219Q	PARTICIPANT	\N	PRESENT	0
332838	321366	19387D	PARTICIPANT	\N	PRESENT	0
332839	321366	19689Q	PARTICIPANT	\N	PRESENT	0
332840	321366	11040E	PARTICIPANT	\N	PRESENT	0
332841	321366	18083K	PARTICIPANT	\N	PRESENT	0
332842	321366	19629C	PARTICIPANT	\N	PRESENT	0
332843	321366	14275Y	PARTICIPANT	\N	PRESENT	0
332844	321366	08053X	PARTICIPANT	\N	PRESENT	0
332846	321366	19533U	PARTICIPANT	\N	PRESENT	0
332847	321366	14235Q	PARTICIPANT	\N	PRESENT	0
332848	321366	19565D	PARTICIPANT	\N	PRESENT	0
332849	321366	14159V	PARTICIPANT	\N	PRESENT	0
332850	321366	15447F	PARTICIPANT	\N	PRESENT	0
332851	321366	14087W	PARTICIPANT	\N	PRESENT	0
332852	321366	19531S	PARTICIPANT	\N	PRESENT	0
332853	321366	19415P	PARTICIPANT	\N	PRESENT	0
332854	321366	01025N	PARTICIPANT	\N	PRESENT	0
332855	321366	19479G	PARTICIPANT	\N	PRESENT	0
332856	321366	04059M	PARTICIPANT	\N	PRESENT	0
332857	321366	08010L	PARTICIPANT	\N	PRESENT	0
332858	321366	80027E	PARTICIPANT	\N	PRESENT	0
332859	321366	08038Y	PARTICIPANT	\N	PRESENT	0
332860	321366	08017T	PARTICIPANT	\N	PRESENT	0
332861	321366	11110B	PARTICIPANT	\N	PRESENT	0
332862	321366	07033P	PARTICIPANT	\N	PRESENT	0
332863	321366	19683J	PARTICIPANT	\N	PRESENT	0
332864	321366	19760E	PARTICIPANT	\N	PRESENT	0
332865	331620	11067R	PARTICIPANT	\N	PRESENT	0
332866	331620	10006L	PRESIDENT	0	PRESENT	0
332867	331620	19447X	PARTICIPANT	\N	PRESENT	0
332868	331620	19621T	PARTICIPANT	\N	EXCUSE	0
338269	338267	14133K	PARTICIPANT	\N	PRESENT	0
335580	332424	11065P	PARTICIPANT	\N	EXCUSE	0
335705	332424	19421M	PARTICIPANT	\N	EXCUSE	0
335706	332424	14147R	PARTICIPANT	\N	PRESENT	0
336542	336541	19503N	PARTICIPANT	\N	PRESENT	0
336545	336544	19503N	PARTICIPANT	\N	PRESENT	0
338265	338264	11026G	PARTICIPANT	\N	PRESENT	0
338268	338267	01048V	PARTICIPANT	\N	PRESENT	0
338270	338267	04042C	PARTICIPANT	\N	PRESENT	0
338271	338267	11026G	PARTICIPANT	\N	PRESENT	0
338272	338267	08051V	PARTICIPANT	\N	PRESENT	0
338273	338267	95067Q	PARTICIPANT	\N	PRESENT	0
358777	358776	11083R	PARTICIPANT	\N	PRESENT	0
358778	358776	14331P	PARTICIPANT	\N	PRESENT	0
358874	358873	08009T	PARTICIPANT	\N	PRESENT	0
358875	358873	11026G	PARTICIPANT	\N	PRESENT	0
358876	358873	14249W	PARTICIPANT	\N	PRESENT	0
358878	358877	08009T	PARTICIPANT	\N	PRESENT	0
358879	358877	19713W	PARTICIPANT	\N	PRESENT	0
358880	358877	11026G	PARTICIPANT	\N	PRESENT	0
358881	358877	19737F	PARTICIPANT	\N	PRESENT	0
358910	358909	14053L	PARTICIPANT	\N	PRESENT	0
358917	358916	14187A	PARTICIPANT	\N	PRESENT	0
358943	345220	14211G	PARTICIPANT	\N	PRESENT	0
359227	345221	14109K	PARTICIPANT	\N	PRESENT	0
359228	345221	19705W	PARTICIPANT	\N	PRESENT	0
359229	345221	14237S	PARTICIPANT	\N	PRESENT	0
359230	345221	19599P	PARTICIPANT	\N	PRESENT	0
359231	345221	19737F	PARTICIPANT	\N	PRESENT	0
359232	345221	19577H	PARTICIPANT	\N	PRESENT	0
359233	345221	11053K	PARTICIPANT	\N	PRESENT	0
359234	345221	14042U	PARTICIPANT	\N	PRESENT	0
359235	345221	11101A	PARTICIPANT	\N	PRESENT	0
359236	345221	04070G	PARTICIPANT	\N	PRESENT	0
359237	345221	07033P	PARTICIPANT	\N	PRESENT	0
359238	345221	04049K	PARTICIPANT	\N	PRESENT	0
359239	345221	11048N	PARTICIPANT	\N	PRESENT	0
359240	345221	04047H	PARTICIPANT	\N	PRESENT	0
359241	345221	19758L	PARTICIPANT	\N	PRESENT	0
359242	345221	14235Q	PARTICIPANT	\N	PRESENT	0
359243	345221	04034C	PARTICIPANT	\N	PRESENT	0
359244	358734	14327T	PARTICIPANT	\N	PRESENT	0
359245	358734	14331P	PARTICIPANT	\N	PRESENT	0
359246	358734	19545Y	PARTICIPANT	\N	PRESENT	0
359247	358734	01057W	PARTICIPANT	\N	PRESENT	0
359248	358734	11053K	PARTICIPANT	\N	PRESENT	0
359249	358734	19667J	PARTICIPANT	\N	PRESENT	0
359250	358734	11074Q	PRESIDENT	0	PRESENT	0
359251	358734	89017R	PARTICIPANT	\N	PRESENT	0
359252	358734	14225N	PARTICIPANT	\N	PRESENT	0
359253	358734	07029T	PARTICIPANT	\N	PRESENT	0
359254	358734	14085U	PARTICIPANT	\N	PRESENT	0
359255	358734	19349W	PARTICIPANT	\N	PRESENT	0
359256	358734	08010L	PARTICIPANT	\N	PRESENT	0
359257	358734	14253S	PARTICIPANT	\N	PRESENT	0
359258	358734	19479G	PARTICIPANT	\N	PRESENT	0
359259	358734	11048N	PARTICIPANT	\N	PRESENT	0
359260	358734	19711U	PARTICIPANT	\N	PRESENT	0
359261	358734	08034U	PARTICIPANT	\N	PRESENT	0
359262	358734	08011M	PARTICIPANT	\N	PRESENT	0
359263	358734	14034U	PARTICIPANT	\N	PRESENT	0
359264	358734	14173T	PARTICIPANT	\N	PRESENT	0
359265	358734	04086Q	PARTICIPANT	\N	PRESENT	0
359266	358734	14083S	PARTICIPANT	\N	PRESENT	0
359267	358734	11012A	PARTICIPANT	\N	PRESENT	0
359268	358734	04061F	PARTICIPANT	\N	PRESENT	0
359269	358734	08069G	PARTICIPANT	\N	EXCUSE	0
359270	358734	19741B	PARTICIPANT	\N	PRESENT	0
359271	345221	80013X	PARTICIPANT	\N	PRESENT	0
359272	358734	14199E	PARTICIPANT	\N	EXCUSE	0
359273	358734	19671E	PARTICIPANT	\N	EXCUSE	0
359274	345221	19515S	PARTICIPANT	\N	PRESENT	0
359275	345221	11067R	PARTICIPANT	\N	PRESENT	0
359276	345221	04035D	PARTICIPANT	\N	PRESENT	0
359277	345221	11043H	PARTICIPANT	\N	PRESENT	0
359278	345221	19369B	PARTICIPANT	\N	PRESENT	0
359279	345221	14265W	PARTICIPANT	\N	PRESENT	0
359280	345221	14031R	PARTICIPANT	\N	PRESENT	0
359281	345221	04089T	PARTICIPANT	\N	PRESENT	0
359282	345221	19739H	PARTICIPANT	\N	PRESENT	0
359283	345221	14055N	PARTICIPANT	\N	PRESENT	0
359284	345221	19657G	PARTICIPANT	\N	PRESENT	0
359434	358734	88008L	PARTICIPANT	\N	PRESENT	0
359438	345222	04038G	PARTICIPANT	\N	PRESENT	0
359439	345222	19527W	PARTICIPANT	\N	PRESENT	0
359456	345222	11104D	PARTICIPANT	\N	PRESENT	0
359441	345222	14207L	PARTICIPANT	\N	PRESENT	0
359445	345222	19689Q	PARTICIPANT	\N	PRESENT	0
359443	345222	14197C	PARTICIPANT	\N	PRESENT	0
359444	345222	14121F	PARTICIPANT	\N	PRESENT	0
359449	345222	80013X	PARTICIPANT	\N	PRESENT	0
359454	345222	14225N	PARTICIPANT	\N	PRESENT	0
359458	345222	19333N	PARTICIPANT	\N	PRESENT	0
359459	345222	14063N	PARTICIPANT	\N	PRESENT	0
359460	345222	08052W	PARTICIPANT	\N	PRESENT	0
359461	345222	14229S	PARTICIPANT	\N	PRESENT	0
359462	345222	19593H	PARTICIPANT	\N	PRESENT	0
359463	345222	08060W	PARTICIPANT	\N	PRESENT	0
359464	345222	19651A	PARTICIPANT	\N	PRESENT	0
359465	345222	04034C	PARTICIPANT	\N	PRESENT	0
359467	345222	11041F	PARTICIPANT	\N	PRESENT	0
359468	345222	14065Q	PARTICIPANT	\N	PRESENT	0
359469	345222	04045F	PARTICIPANT	\N	PRESENT	0
359470	345222	19679N	PARTICIPANT	\N	PRESENT	0
359471	345222	11043H	PARTICIPANT	\N	PRESENT	0
359473	345222	17637T	PARTICIPANT	\N	PRESENT	0
359474	345222	14259Y	PARTICIPANT	\N	PRESENT	0
359475	345222	01057W	PARTICIPANT	\N	PRESENT	0
359476	345222	04008A	PARTICIPANT	\N	PRESENT	0
359477	345222	01058X	PARTICIPANT	\N	PRESENT	0
359478	345222	98024R	PARTICIPANT	\N	PRESENT	0
359479	345222	04035D	PARTICIPANT	\N	PRESENT	0
359480	345222	95030B	PARTICIPANT	\N	PRESENT	0
359481	345222	99004R	PARTICIPANT	\N	PRESENT	0
359482	345222	11056N	PARTICIPANT	\N	PRESENT	0
359484	345222	11031D	PARTICIPANT	\N	PRESENT	0
359485	345222	12041X	PARTICIPANT	\N	PRESENT	0
359486	345222	14235Q	PARTICIPANT	\N	PRESENT	0
359487	345222	19758L	PARTICIPANT	\N	PRESENT	0
359488	345222	19565D	PARTICIPANT	\N	PRESENT	0
359489	345222	11077T	PARTICIPANT	\N	PRESENT	0
359490	345222	19760E	PARTICIPANT	\N	PRESENT	0
359491	345222	19687N	PARTICIPANT	\N	PRESENT	0
359492	345222	10006L	PARTICIPANT	\N	PRESENT	0
359493	345222	08061X	PARTICIPANT	\N	PRESENT	0
359494	345222	95037J	PARTICIPANT	\N	PRESENT	0
359495	345222	87003B	PARTICIPANT	\N	PRESENT	0
359496	345222	14239U	PARTICIPANT	\N	PRESENT	0
359497	345222	19711U	PARTICIPANT	\N	PRESENT	0
359498	345222	11083R	PARTICIPANT	\N	PRESENT	0
359499	345222	19543W	PARTICIPANT	\N	PRESENT	0
359500	345222	14157T	PARTICIPANT	\N	PRESENT	0
359501	345222	19349W	PARTICIPANT	\N	PRESENT	0
359502	345222	19637C	PARTICIPANT	\N	PRESENT	0
359503	345222	19697Q	PARTICIPANT	\N	PRESENT	0
359504	345222	14039A	PARTICIPANT	\N	PRESENT	0
359505	345222	14026U	PARTICIPANT	\N	PRESENT	0
359506	345222	19301E	PARTICIPANT	\N	PRESENT	0
359507	345222	19329S	PARTICIPANT	\N	PRESENT	0
359508	345222	04047H	PARTICIPANT	\N	PRESENT	0
359509	345222	19782L	PARTICIPANT	\N	PRESENT	0
359510	345222	88008L	PARTICIPANT	\N	PRESENT	0
359511	345222	14034U	PARTICIPANT	\N	PRESENT	0
359512	345222	08039A	PARTICIPANT	\N	PRESENT	0
359513	345222	08020N	PARTICIPANT	\N	PRESENT	0
359514	345222	08010L	PARTICIPANT	\N	PRESENT	0
359515	345222	11012A	PARTICIPANT	\N	PRESENT	0
359516	345222	08069G	PARTICIPANT	\N	PRESENT	0
359517	345222	14223L	PARTICIPANT	\N	PRESENT	0
359518	345222	04086Q	PARTICIPANT	\N	PRESENT	0
359519	345222	08031R	PARTICIPANT	\N	PRESENT	0
359520	345222	04092N	PARTICIPANT	\N	PRESENT	0
359521	345222	14261S	PARTICIPANT	\N	PRESENT	0
359522	345222	98029W	PARTICIPANT	\N	PRESENT	0
359523	345222	04044E	PARTICIPANT	\N	PRESENT	0
359524	345222	19643A	PARTICIPANT	\N	PRESENT	0
359525	345222	19253P	PARTICIPANT	\N	PRESENT	0
359526	345222	19629C	PARTICIPANT	\N	PRESENT	0
359527	345222	04071H	PARTICIPANT	\N	PRESENT	0
359528	345222	19563B	PARTICIPANT	\N	PRESENT	0
359529	345222	14241N	PARTICIPANT	\N	PRESENT	0
359530	345222	98022P	PARTICIPANT	\N	PRESENT	0
359531	345222	14169X	PARTICIPANT	\N	PRESENT	0
359532	345222	19719D	PARTICIPANT	\N	PRESENT	0
359533	345222	11065P	PARTICIPANT	\N	PRESENT	0
359534	345222	04097T	PARTICIPANT	\N	PRESENT	0
359535	345222	19289C	PARTICIPANT	\N	PRESENT	0
359536	345222	95062K	PARTICIPANT	\N	PRESENT	0
359537	345222	19545Y	PARTICIPANT	\N	PRESENT	0
359538	345222	11101A	PARTICIPANT	\N	PRESENT	0
359539	345222	04057K	PARTICIPANT	\N	PRESENT	0
359540	345222	02002K	PARTICIPANT	\N	PRESENT	0
359541	345222	01048V	PARTICIPANT	\N	PRESENT	0
359542	345222	19585H	PARTICIPANT	\N	PRESENT	0
359543	345222	17589D	PARTICIPANT	\N	PRESENT	0
359544	345222	08011M	PARTICIPANT	\N	PRESENT	0
359545	345222	08028W	PARTICIPANT	\N	PRESENT	0
359546	345222	14251Q	PARTICIPANT	\N	PRESENT	0
359547	345222	14195A	PARTICIPANT	\N	PRESENT	0
359548	345222	11064N	PARTICIPANT	\N	PRESENT	0
332761	325382	19675J	PARTICIPANT	\N	PRESENT	0
346930	345123	14069U	PARTICIPANT	\N	PRESENT	0
346931	345123	11101A	PARTICIPANT	\N	PRESENT	0
346932	345123	14259Y	PARTICIPANT	\N	PRESENT	0
346933	345123	08038Y	PARTICIPANT	\N	PRESENT	0
346934	345123	19565D	PARTICIPANT	\N	PRESENT	0
346935	345123	08010L	PARTICIPANT	\N	PRESENT	0
346936	345123	95063L	PARTICIPANT	\N	PRESENT	0
346937	345123	04045F	PARTICIPANT	\N	PRESENT	0
346953	345123	14103D	PARTICIPANT	\N	PRESENT	0
346955	345123	14028W	PARTICIPANT	\N	PRESENT	0
351018	351017	14227Q	PARTICIPANT	\N	PRESENT	0
351020	351019	98029W	PARTICIPANT	\N	PRESENT	0
355945	355944	14063N	PARTICIPANT	\N	PRESENT	0
355946	355944	08012N	PARTICIPANT	\N	PRESENT	0
355947	355944	14073Q	PARTICIPANT	\N	PRESENT	0
355948	355944	14241N	PARTICIPANT	\N	PRESENT	0
355949	355944	04070G	PARTICIPANT	\N	PRESENT	0
355950	355944	11043H	PARTICIPANT	\N	PRESENT	0
355951	355944	19329S	PARTICIPANT	\N	PRESENT	0
356177	356163	17779H	PARTICIPANT	\N	PRESENT	0
356178	356163	11097X	PARTICIPANT	\N	PRESENT	0
356179	356164	17779H	PARTICIPANT	\N	PRESENT	0
356180	356164	11097X	PARTICIPANT	\N	PRESENT	0
356182	356181	17779H	PARTICIPANT	\N	PRESENT	0
356183	356181	11097X	PARTICIPANT	\N	PRESENT	0
356185	356165	17779H	PARTICIPANT	\N	PRESENT	0
356186	356165	11097X	PARTICIPANT	\N	PRESENT	0
356187	356184	17779H	PARTICIPANT	\N	PRESENT	0
356188	356184	11097X	PARTICIPANT	\N	PRESENT	0
356189	356166	17779H	PARTICIPANT	\N	PRESENT	0
356190	356166	11097X	PARTICIPANT	\N	PRESENT	0
356191	356167	17779H	PARTICIPANT	\N	PRESENT	0
356192	356167	11097X	PARTICIPANT	\N	PRESENT	0
356193	356168	17779H	PARTICIPANT	\N	PRESENT	0
356194	356168	11097X	PARTICIPANT	\N	PRESENT	0
356195	356169	17779H	PARTICIPANT	\N	PRESENT	0
356196	356169	11097X	PARTICIPANT	\N	PRESENT	0
356198	356170	17779H	PARTICIPANT	\N	PRESENT	0
356199	356170	11097X	PARTICIPANT	\N	PRESENT	0
356200	356197	17779H	PARTICIPANT	\N	PRESENT	0
356201	356197	11097X	PARTICIPANT	\N	PRESENT	0
356202	356171	17779H	PARTICIPANT	\N	PRESENT	0
356203	356171	11097X	PARTICIPANT	\N	PRESENT	0
356204	356172	17779H	PARTICIPANT	\N	PRESENT	0
356205	356172	11097X	PARTICIPANT	\N	PRESENT	0
356206	356173	17779H	PARTICIPANT	\N	PRESENT	0
356207	356173	11097X	PARTICIPANT	\N	PRESENT	0
356208	356174	17779H	PARTICIPANT	\N	PRESENT	0
356209	356174	11097X	PARTICIPANT	\N	PRESENT	0
356210	356176	17779H	PARTICIPANT	\N	PRESENT	0
356211	356176	11097X	PARTICIPANT	\N	PRESENT	0
356212	356175	17779H	PARTICIPANT	\N	PRESENT	0
356213	356175	11097X	PARTICIPANT	\N	PRESENT	0
356447	345115	14083S	PARTICIPANT	\N	PRESENT	0
356448	345115	19413M	PARTICIPANT	\N	PRESENT	0
356449	345115	14121F	PARTICIPANT	\N	PRESENT	0
356450	345115	14061L	PARTICIPANT	\N	PRESENT	0
356451	345115	14081Q	PARTICIPANT	\N	PRESENT	0
356452	345115	19657G	PARTICIPANT	\N	PRESENT	0
356453	345115	14197C	PARTICIPANT	\N	PRESENT	0
356454	345115	95062K	PARTICIPANT	\N	PRESENT	0
356455	345115	14207L	PARTICIPANT	\N	PRESENT	0
356456	345115	08068F	PARTICIPANT	\N	PRESENT	0
356457	345115	08038Y	PARTICIPANT	\N	PRESENT	0
356458	345115	19747H	PARTICIPANT	\N	PRESENT	0
356459	345115	19695N	PARTICIPANT	\N	PRESENT	0
356460	345115	14179A	PARTICIPANT	\N	PRESENT	0
356461	345115	14069U	PARTICIPANT	\N	PRESENT	0
356462	345115	11056N	PARTICIPANT	\N	PRESENT	0
356463	345115	14031R	PARTICIPANT	\N	PRESENT	0
356464	345115	19507S	PARTICIPANT	\N	PRESENT	0
356563	345116	04044E	PARTICIPANT	\N	PRESENT	0
356564	345116	14187A	PARTICIPANT	\N	PRESENT	0
356569	345116	17779H	PARTICIPANT	\N	PRESENT	0
356566	345116	14197C	PARTICIPANT	\N	PRESENT	0
356567	345116	14281W	PARTICIPANT	\N	PRESENT	0
356568	345116	19727D	PARTICIPANT	\N	PRESENT	0
356570	345116	19683J	PARTICIPANT	\N	PRESENT	0
356571	345116	19413M	PARTICIPANT	\N	PRESENT	0
356572	345116	14121F	PARTICIPANT	\N	PRESENT	0
356573	345116	11109J	PARTICIPANT	\N	PRESENT	0
356574	345116	19599P	PARTICIPANT	\N	PRESENT	0
356575	345116	14207L	PARTICIPANT	\N	PRESENT	0
356576	345116	08068F	PARTICIPANT	\N	PRESENT	0
356577	345116	14225N	PARTICIPANT	\N	PRESENT	0
356578	345116	19349W	PARTICIPANT	\N	PRESENT	0
356579	345116	19387D	PARTICIPANT	\N	PRESENT	0
356580	345116	17589D	PARTICIPANT	\N	PRESENT	0
356581	345116	14195A	PARTICIPANT	\N	PRESENT	0
356582	345116	19441R	PARTICIPANT	\N	PRESENT	0
356583	345116	19479G	PARTICIPANT	\N	PRESENT	0
356584	345116	01024M	PARTICIPANT	\N	PRESENT	0
356585	345116	14239U	PARTICIPANT	\N	PRESENT	0
356586	345116	11090Q	PARTICIPANT	\N	PRESENT	0
356587	345116	19713W	PARTICIPANT	\N	PRESENT	0
356588	345116	14179A	PARTICIPANT	\N	PRESENT	0
356589	345116	19747H	PARTICIPANT	\N	PRESENT	0
356590	345116	19367Y	PARTICIPANT	\N	PRESENT	0
356591	345116	19581D	PARTICIPANT	\N	PRESENT	0
356592	345116	14087W	PARTICIPANT	\N	PRESENT	0
356593	345116	14215L	PARTICIPANT	\N	PRESENT	0
356594	345116	98050T	PARTICIPANT	\N	PRESENT	0
356595	345116	14055N	PARTICIPANT	\N	PRESENT	0
356596	345116	19731Y	PARTICIPANT	\N	PRESENT	0
356597	345116	14357A	PARTICIPANT	\N	PRESENT	0
356598	345116	14217N	PARTICIPANT	\N	PRESENT	0
356599	345116	08048B	PARTICIPANT	\N	PRESENT	0
356600	345116	14026U	PARTICIPANT	\N	PRESENT	0
356601	345116	14213J	PARTICIPANT	\N	PRESENT	0
356602	345116	08062Y	PARTICIPANT	\N	PRESENT	0
356603	345116	19657G	PARTICIPANT	\N	PRESENT	0
356604	345116	19399H	PARTICIPANT	\N	PRESENT	0
356605	345116	87003B	PARTICIPANT	\N	PRESENT	0
356606	345116	14223L	PARTICIPANT	\N	PRESENT	0
356607	345116	08028W	PARTICIPANT	\N	PRESENT	0
356608	345116	99004R	PARTICIPANT	\N	PRESENT	0
356609	345116	08020N	PARTICIPANT	\N	PRESENT	0
356610	345116	95062K	PARTICIPANT	\N	PRESENT	0
356611	345116	15447F	PARTICIPANT	\N	PRESENT	0
356612	345116	19703U	PARTICIPANT	\N	PRESENT	0
356613	345116	19794Q	PARTICIPANT	\N	PRESENT	0
356614	345116	19723Y	PARTICIPANT	\N	PRESENT	0
356615	345116	19507S	PARTICIPANT	\N	PRESENT	0
356616	345116	04088S	PARTICIPANT	\N	PRESENT	0
356617	345116	19467C	PARTICIPANT	\N	PRESENT	0
356619	345116	08056B	PARTICIPANT	\N	PRESENT	0
356621	345116	01058X	PARTICIPANT	\N	PRESENT	0
356622	345116	11101A	PARTICIPANT	\N	PRESENT	0
356623	345116	04086Q	PARTICIPANT	\N	PRESENT	0
356624	345116	14069U	PARTICIPANT	\N	PRESENT	0
356625	345116	19679N	PARTICIPANT	\N	PRESENT	0
356626	345116	97011G	PARTICIPANT	\N	PRESENT	0
356627	345116	14115H	PARTICIPANT	\N	PRESENT	0
356628	345116	18083K	PARTICIPANT	\N	PRESENT	0
356629	345116	14241N	PARTICIPANT	\N	PRESENT	0
356630	345116	98022P	PARTICIPANT	\N	PRESENT	0
356631	345116	08031R	PARTICIPANT	\N	PRESENT	0
356632	345116	11040E	PARTICIPANT	\N	PRESENT	0
356633	345116	19695N	PARTICIPANT	\N	PRESENT	0
356634	345116	19333N	PARTICIPANT	\N	PRESENT	0
356635	345116	14081Q	PARTICIPANT	\N	PRESENT	0
356636	345116	14073Q	PARTICIPANT	\N	PRESENT	0
356637	345116	14038Y	PARTICIPANT	\N	PRESENT	0
356639	345116	14259Y	PARTICIPANT	\N	PRESENT	0
356640	345116	19741B	PARTICIPANT	\N	PRESENT	0
356641	345116	19515S	PARTICIPANT	\N	PRESENT	0
356642	345116	19447X	PARTICIPANT	\N	PRESENT	0
356643	345116	14061L	PARTICIPANT	\N	PRESENT	0
356645	345116	19545Y	PARTICIPANT	\N	PRESENT	0
356646	345116	11099A	PARTICIPANT	\N	PRESENT	0
356650	345116	11056N	PARTICIPANT	\N	PRESENT	0
356648	345116	08038Y	PARTICIPANT	\N	PRESENT	0
356649	345116	08035V	PARTICIPANT	\N	PRESENT	0
356651	345116	19629C	PARTICIPANT	\N	PRESENT	0
356652	345116	14031R	PARTICIPANT	\N	PRESENT	0
356653	345116	14133K	PARTICIPANT	\N	PRESENT	0
356654	345116	08053X	PARTICIPANT	\N	PRESENT	0
356655	345116	14157T	PARTICIPANT	\N	PRESENT	0
356656	345116	19619A	PARTICIPANT	\N	PRESENT	0
356657	345116	14211G	PARTICIPANT	\N	PRESENT	0
356658	345116	14123H	PARTICIPANT	\N	PRESENT	0
356659	345116	14267Y	PARTICIPANT	\N	PRESENT	0
356660	345116	08039A	PARTICIPANT	\N	PRESENT	0
356661	345116	08017T	PARTICIPANT	\N	PRESENT	0
357990	345120	05008E	PARTICIPANT	\N	PRESENT	0
357991	345120	11045K	PARTICIPANT	\N	PRESENT	0
357992	345120	19649G	PARTICIPANT	\N	PRESENT	0
357993	345120	14109K	PARTICIPANT	\N	PRESENT	0
357994	345120	14065Q	PARTICIPANT	\N	PRESENT	0
357995	345120	19631V	PARTICIPANT	\N	PRESENT	0
357996	345120	14081Q	PARTICIPANT	\N	PRESENT	0
357997	345120	01028R	PARTICIPANT	\N	PRESENT	0
357998	345120	08055A	PARTICIPANT	\N	PRESENT	0
357999	345120	19599P	PARTICIPANT	\N	PRESENT	0
358000	345120	19647E	PARTICIPANT	\N	PRESENT	0
358001	345120	19551W	PARTICIPANT	\N	PRESENT	0
358002	345120	11033F	PARTICIPANT	\N	PRESENT	0
358003	345120	04045F	PARTICIPANT	\N	PRESENT	0
358004	345120	19253P	PARTICIPANT	\N	PRESENT	0
358005	345120	19629C	PARTICIPANT	\N	PRESENT	0
358006	345120	14111D	PARTICIPANT	\N	PRESENT	0
358007	345120	17589D	PARTICIPANT	\N	PRESENT	0
358008	345120	19737F	PARTICIPANT	\N	PRESENT	0
358009	345120	14042U	PARTICIPANT	\N	PRESENT	0
358010	345120	19713W	PARTICIPANT	\N	PRESENT	0
358011	345120	19691J	PARTICIPANT	\N	PRESENT	0
358012	345120	07029T	PARTICIPANT	\N	PRESENT	0
358013	345120	08044W	PARTICIPANT	\N	PRESENT	0
358014	345120	01024M	PARTICIPANT	\N	PRESENT	0
358015	345120	14061L	PARTICIPANT	\N	PRESENT	0
358016	345120	04088S	PARTICIPANT	\N	PRESENT	0
358017	345120	19467C	PARTICIPANT	\N	PRESENT	0
358018	345120	19758L	PARTICIPANT	\N	PRESENT	0
358019	345120	19741B	PARTICIPANT	\N	PRESENT	0
358020	345120	14026U	PARTICIPANT	\N	PRESENT	0
358021	345120	05012A	PARTICIPANT	\N	PRESENT	0
358022	345120	04044E	PARTICIPANT	\N	PRESENT	0
358023	345120	14215L	PARTICIPANT	\N	PRESENT	0
358024	345120	19643A	PARTICIPANT	\N	PRESENT	0
358025	345120	19703U	PARTICIPANT	\N	PRESENT	0
358026	345120	14087W	PARTICIPANT	\N	PRESENT	0
358027	345120	19679N	PARTICIPANT	\N	PRESENT	0
358028	345120	19503N	PARTICIPANT	\N	PRESENT	0
358029	345120	19413M	PARTICIPANT	\N	PRESENT	0
358030	345120	19725B	PARTICIPANT	\N	PRESENT	0
358031	345120	08043V	PARTICIPANT	\N	PRESENT	0
358032	345120	14079W	PARTICIPANT	\N	PRESENT	0
358033	345120	19673G	PARTICIPANT	\N	PRESENT	0
358034	345120	14235Q	PARTICIPANT	\N	PRESENT	0
358035	345120	11012A	PARTICIPANT	\N	PRESENT	0
358036	345120	11072N	PARTICIPANT	\N	PRESENT	0
358037	345120	08056B	PARTICIPANT	\N	PRESENT	0
358038	345120	19543W	PARTICIPANT	\N	PRESENT	0
358039	345120	14249W	PARTICIPANT	\N	PRESENT	0
358040	345120	14021P	PARTICIPANT	\N	PRESENT	0
358041	345120	14207L	PARTICIPANT	\N	PRESENT	0
358042	345120	08038Y	PARTICIPANT	\N	PRESENT	0
358043	345120	19383Y	PARTICIPANT	\N	PRESENT	0
358044	345120	14217N	PARTICIPANT	\N	PRESENT	0
358045	345120	14265W	PARTICIPANT	\N	PRESENT	0
358046	345120	01025N	PARTICIPANT	\N	PRESENT	0
358047	345120	19723Y	PARTICIPANT	\N	PRESENT	0
358048	345120	19447X	PARTICIPANT	\N	PRESENT	0
358049	345120	04049K	PARTICIPANT	\N	PRESENT	0
358051	345120	19531S	PARTICIPANT	\N	PRESENT	0
358052	345120	14073Q	PARTICIPANT	\N	PRESENT	0
360498	356165	19727D	PARTICIPANT	\N	PRESENT	0
360499	356165	01034P	PARTICIPANT	\N	PRESENT	0
360501	356184	19727D	PARTICIPANT	\N	PRESENT	0
360502	356184	01034P	PARTICIPANT	\N	PRESENT	0
361711	361710	08043V	PARTICIPANT	\N	PRESENT	0
361712	361710	14053L	PARTICIPANT	\N	PRESENT	0
361713	361710	14083S	PARTICIPANT	\N	PRESENT	0
361714	361710	08045X	PARTICIPANT	\N	PRESENT	0
361715	361710	14213J	PARTICIPANT	\N	PRESENT	0
361716	361710	19723Y	PARTICIPANT	\N	PRESENT	0
361717	361710	08015R	PARTICIPANT	\N	PRESENT	0
361718	361710	14031R	PARTICIPANT	\N	PRESENT	0
357988	345120	01043Q	PARTICIPANT	\N	PRESENT	0
357989	345120	11109J	PARTICIPANT	\N	PRESENT	0
361719	361710	19745F	PARTICIPANT	\N	PRESENT	0
361720	361710	17583W	PARTICIPANT	\N	PRESENT	0
361721	361710	95062K	PARTICIPANT	\N	PRESENT	0
361722	361710	14051J	PARTICIPANT	\N	PRESENT	0
361723	361710	14157T	PARTICIPANT	\N	PRESENT	0
361892	345231	04085P	PARTICIPANT	\N	PRESENT	0
361893	345231	14231L	PARTICIPANT	\N	PRESENT	0
361894	345231	14265W	PARTICIPANT	\N	PRESENT	0
361895	345231	98050T	PARTICIPANT	\N	PRESENT	0
361896	345231	14357A	PARTICIPANT	\N	PRESENT	0
361897	345231	08009T	PARTICIPANT	\N	PRESENT	0
361898	345231	14033T	PARTICIPANT	\N	PRESENT	0
361899	345231	19758L	PARTICIPANT	\N	PRESENT	0
361900	345231	19347U	PARTICIPANT	\N	PRESENT	0
361901	345231	19695N	PARTICIPANT	\N	PRESENT	0
361902	345231	19565D	PARTICIPANT	\N	PRESENT	0
361903	345231	19551W	PARTICIPANT	\N	PRESENT	0
361904	345231	19503N	PARTICIPANT	\N	PRESENT	0
361905	345231	14227Q	PARTICIPANT	\N	PRESENT	0
361912	345231	14121F	PARTICIPANT	\N	PRESENT	0
361907	345231	08012N	PARTICIPANT	\N	PRESENT	0
361908	345231	12016W	PARTICIPANT	\N	PRESENT	0
361909	345231	08058D	PARTICIPANT	\N	PRESENT	0
361910	345231	14253S	PARTICIPANT	\N	PRESENT	0
361911	345231	14197C	PARTICIPANT	\N	PRESENT	0
361913	345231	19727D	PARTICIPANT	\N	PRESENT	0
361914	345231	19631V	PARTICIPANT	\N	PRESENT	0
361915	345231	04071H	PARTICIPANT	\N	PRESENT	0
361916	345231	19333N	PARTICIPANT	\N	PRESENT	0
361917	345231	08017T	PARTICIPANT	\N	PRESENT	0
361918	345231	08043V	PARTICIPANT	\N	PRESENT	0
361919	345231	19575F	PARTICIPANT	\N	PRESENT	0
361920	345231	19599P	PARTICIPANT	\N	PRESENT	0
361921	345231	11104D	PARTICIPANT	\N	PRESENT	0
361922	345231	14065Q	PARTICIPANT	\N	PRESENT	0
361923	345231	11066Q	PARTICIPANT	\N	PRESENT	0
361924	345231	08060W	PARTICIPANT	\N	PRESENT	0
361925	345231	19729F	PARTICIPANT	\N	PRESENT	0
361926	345231	08055A	PARTICIPANT	\N	PRESENT	0
361927	345231	19709B	PARTICIPANT	\N	PRESENT	0
361928	345231	14151M	PARTICIPANT	\N	PRESENT	0
361929	345231	19782L	PARTICIPANT	\N	PRESENT	0
361930	345231	08024S	PARTICIPANT	\N	PRESENT	0
361931	345231	19301E	PARTICIPANT	\N	PRESENT	0
361932	345231	95067Q	PARTICIPANT	\N	PRESENT	0
361933	345231	19659J	PARTICIPANT	\N	PRESENT	0
361934	345231	19585H	PARTICIPANT	\N	PRESENT	0
361935	345231	14111D	PARTICIPANT	\N	PRESENT	0
361936	345231	04057K	PARTICIPANT	\N	PRESENT	0
361937	345231	17583W	PARTICIPANT	\N	PRESENT	0
361938	345231	02002K	PARTICIPANT	\N	PRESENT	0
361939	345231	19387D	PARTICIPANT	\N	PRESENT	0
361940	345231	14107H	PARTICIPANT	\N	PRESENT	0
361941	345231	19629C	PARTICIPANT	\N	PRESENT	0
361942	345231	14115H	PARTICIPANT	\N	PRESENT	0
361943	345231	11065P	PARTICIPANT	\N	PRESENT	0
361944	345231	19563B	PARTICIPANT	\N	PRESENT	0
361945	345231	19637C	PARTICIPANT	\N	PRESENT	0
361946	345231	14119M	PARTICIPANT	\N	PRESENT	0
361947	345231	19349W	PARTICIPANT	\N	PRESENT	0
361948	345231	19543W	PARTICIPANT	\N	PRESENT	0
361949	345231	95037J	PARTICIPANT	\N	PRESENT	0
361950	345231	19447X	PARTICIPANT	\N	PRESENT	0
361951	345231	08061X	PARTICIPANT	\N	PRESENT	0
361952	345231	19741B	PARTICIPANT	\N	PRESENT	0
361953	345231	14034U	PARTICIPANT	\N	PRESENT	0
361954	345231	08049C	PARTICIPANT	\N	PRESENT	0
361955	345231	18083K	PARTICIPANT	\N	PRESENT	0
361956	345231	11012A	PARTICIPANT	\N	PRESENT	0
361957	345231	19611R	PARTICIPANT	\N	PRESENT	0
361958	345231	08056B	PARTICIPANT	\N	PRESENT	0
361959	345231	19731Y	PARTICIPANT	\N	PRESENT	0
361960	345231	16685X	PARTICIPANT	\N	PRESENT	0
361961	345231	19717B	PARTICIPANT	\N	PRESENT	0
361962	345231	14093U	PARTICIPANT	\N	PRESENT	0
361963	345231	19733B	PARTICIPANT	\N	PRESENT	0
361964	345231	19619A	PARTICIPANT	\N	PRESENT	0
361965	345231	19533U	PARTICIPANT	\N	PRESENT	0
361966	345231	19798U	PARTICIPANT	\N	PRESENT	0
361967	345231	14267Y	PARTICIPANT	\N	PRESENT	0
361968	345231	14103D	PARTICIPANT	\N	PRESENT	0
361969	345231	19739H	PARTICIPANT	\N	PRESENT	0
361970	345231	14073Q	PARTICIPANT	\N	PRESENT	0
361971	345231	19335Q	PARTICIPANT	\N	PRESENT	0
361972	345231	14249W	PARTICIPANT	\N	PRESENT	0
361973	345231	19369B	PARTICIPANT	\N	PRESENT	0
361974	345231	01058X	PARTICIPANT	\N	PRESENT	0
361975	345231	19521Q	PARTICIPANT	\N	PRESENT	0
361976	345231	04086Q	PARTICIPANT	\N	PRESENT	0
361977	345231	19747H	PARTICIPANT	\N	PRESENT	0
361978	345231	19671E	PARTICIPANT	\N	PRESENT	0
361979	345231	98024R	PARTICIPANT	\N	PRESENT	0
340087	329064	11065P	PARTICIPANT	\N	PRESENT	0
340088	333448	11065P	PARTICIPANT	\N	PRESENT	0
333669	332845	19531S	PARTICIPANT	\N	PRESENT	0
340086	335730	11065P	PARTICIPANT	\N	PRESENT	0
340089	335128	11065P	PARTICIPANT	\N	PRESENT	0
344568	342127	08021P	PARTICIPANT	\N	EXCUSE	0
347969	339518	19521Q	PARTICIPANT	\N	PRESENT	0
347970	339518	11048N	PARTICIPANT	\N	PRESENT	0
347971	339518	19631V	PARTICIPANT	\N	PRESENT	0
347972	339518	14051J	PARTICIPANT	\N	PRESENT	0
347973	339518	14227Q	PARTICIPANT	\N	PRESENT	0
347974	339518	04034C	PARTICIPANT	\N	PRESENT	0
347975	339518	19695N	PARTICIPANT	\N	PRESENT	0
347976	339518	19687N	PARTICIPANT	\N	PRESENT	0
347977	339518	11012A	PARTICIPANT	\N	PRESENT	0
347978	339518	14042U	PARTICIPANT	\N	PRESENT	0
347979	339518	14157T	PARTICIPANT	\N	PRESENT	0
347980	339518	19667J	PARTICIPANT	\N	PRESENT	0
347981	339518	18083K	PARTICIPANT	\N	PRESENT	0
347982	339518	19711U	PARTICIPANT	\N	PRESENT	0
347983	339518	11070L	PARTICIPANT	\N	PRESENT	0
347984	339518	95063L	PARTICIPANT	\N	PRESENT	0
347985	339518	08068F	PARTICIPANT	\N	PRESENT	0
347986	339518	11110B	PARTICIPANT	\N	PRESENT	0
347987	339518	11090Q	PARTICIPANT	\N	PRESENT	0
347991	339518	04085P	PARTICIPANT	\N	PRESENT	0
347989	339518	04049K	PARTICIPANT	\N	PRESENT	0
347990	339518	11031D	PARTICIPANT	\N	PRESENT	0
347992	339518	14034U	PARTICIPANT	\N	PRESENT	0
347993	339518	02002K	PARTICIPANT	\N	PRESENT	0
347994	339518	19693L	PARTICIPANT	\N	PRESENT	0
347995	339518	19717B	PARTICIPANT	\N	PRESENT	0
348010	348008	14205J	PARTICIPANT	\N	PRESENT	0
348011	348008	14033T	PARTICIPANT	\N	PRESENT	0
348012	348008	97011G	PARTICIPANT	\N	PRESENT	0
348013	348008	19727D	PARTICIPANT	\N	PRESENT	0
348014	348008	19723Y	PARTICIPANT	\N	PRESENT	0
348015	348008	14169X	PARTICIPANT	\N	PRESENT	0
348016	348008	14265W	PARTICIPANT	\N	PRESENT	0
348017	348008	04088S	PARTICIPANT	\N	PRESENT	0
348018	348008	08049C	PARTICIPANT	\N	PRESENT	0
348019	348009	14205J	PARTICIPANT	\N	PRESENT	0
348026	348025	14215L	PARTICIPANT	\N	PRESENT	0
348033	348032	14231L	PARTICIPANT	\N	PRESENT	0
348037	348036	19691J	PARTICIPANT	\N	PRESENT	0
348039	348038	19691J	PARTICIPANT	\N	PRESENT	0
348043	348042	19415P	PARTICIPANT	\N	PRESENT	0
348044	348042	11067R	PARTICIPANT	\N	PRESENT	0
348046	348045	19415P	PARTICIPANT	\N	PRESENT	0
348047	348045	11067R	PARTICIPANT	\N	PRESENT	0
348200	342791	04040A	PARTICIPANT	\N	PRESENT	0
348201	342791	19565D	PARTICIPANT	\N	PRESENT	0
348202	342791	11048N	PARTICIPANT	\N	PRESENT	0
348203	342791	08049C	PARTICIPANT	\N	PRESENT	0
348204	342791	14231L	PARTICIPANT	\N	PRESENT	0
348205	342791	14327T	PARTICIPANT	\N	PRESENT	0
348206	342791	11110B	PARTICIPANT	\N	PRESENT	0
348207	342791	01057W	PARTICIPANT	\N	PRESENT	0
348208	342791	14257W	PARTICIPANT	\N	PRESENT	0
348313	346157	14147R	PARTICIPANT	\N	PRESENT	0
348341	346332	11109J	PARTICIPANT	\N	PRESENT	0
348342	346332	19715Y	PARTICIPANT	\N	PRESENT	0
348343	346332	19691J	PARTICIPANT	\N	PRESENT	0
348344	346332	14097Y	PARTICIPANT	\N	PRESENT	0
348346	346332	08019V	PRESIDENT	0	PRESENT	0
348348	346332	14135M	PARTICIPANT	\N	PRESENT	0
348349	346332	19319Q	PARTICIPANT	\N	PRESENT	0
348350	346332	98005N	PARTICIPANT	\N	PRESENT	0
349178	346333	19703U	PARTICIPANT	\N	EXCUSE	0
349262	344805	14030Q	PRESIDENT	0	PRESENT	0
349263	344805	19643A	PARTICIPANT	\N	PRESENT	0
349264	344805	19599P	PARTICIPANT	\N	PRESENT	0
349265	344805	19715Y	PARTICIPANT	\N	PRESENT	0
349266	344805	19731Y	PARTICIPANT	\N	PRESENT	0
349267	344805	14235Q	PARTICIPANT	\N	PRESENT	0
349268	344805	11031D	PARTICIPANT	\N	EXCUSE	0
349269	344805	07029T	PARTICIPANT	\N	EXCUSE	0
349271	344805	11067R	PARTICIPANT	\N	EXCUSE	0
349655	346613	01043Q	PARTICIPANT	\N	PRESENT	0
349656	346613	11077T	PARTICIPANT	\N	PRESENT	0
349668	346613	80013X	PARTICIPANT	\N	PRESENT	0
349669	346613	04049K	PARTICIPANT	\N	PRESENT	0
349670	346613	19269X	PARTICIPANT	\N	PRESENT	0
349671	346480	19697Q	PARTICIPANT	\N	PRESENT	0
349672	346480	11067R	PARTICIPANT	\N	PRESENT	0
349673	346480	19565D	PARTICIPANT	\N	PRESENT	0
349674	346480	19569H	PARTICIPANT	\N	PRESENT	0
349675	346480	11097X	PARTICIPANT	\N	PRESENT	0
349676	346480	19415P	PARTICIPANT	\N	PRESENT	0
349677	346480	14223L	PARTICIPANT	\N	PRESENT	0
349678	346480	04045F	PARTICIPANT	\N	PRESENT	0
349679	346480	14026U	PARTICIPANT	\N	PRESENT	0
349680	346480	17779H	PARTICIPANT	\N	PRESENT	0
349681	346480	19703U	PARTICIPANT	\N	PRESENT	0
349682	346480	19553Y	PARTICIPANT	\N	PRESENT	0
349683	346480	14087W	PARTICIPANT	\N	PRESENT	0
349684	346480	19679N	PARTICIPANT	\N	PRESENT	0
349685	346480	14042U	PARTICIPANT	\N	PRESENT	0
349686	346480	08048B	PARTICIPANT	\N	PRESENT	0
349687	346480	14195A	PARTICIPANT	\N	PRESENT	0
349688	346480	19575F	PARTICIPANT	\N	PRESENT	0
349689	346480	14213J	PARTICIPANT	\N	PRESENT	0
349690	346480	14217N	PARTICIPANT	\N	PRESENT	0
349691	346480	10006L	PARTICIPANT	\N	PRESENT	0
349692	346480	19521Q	PARTICIPANT	\N	PRESENT	0
349693	346480	19527W	PARTICIPANT	\N	PRESENT	0
349694	346480	04092N	PRESIDENT	0	PRESENT	0
349695	346480	08052W	PARTICIPANT	\N	PRESENT	0
349696	346480	19663E	PARTICIPANT	\N	PRESENT	0
349697	346480	19715Y	PARTICIPANT	\N	PRESENT	0
349698	346480	19723Y	PARTICIPANT	\N	PRESENT	0
349699	346480	14119M	PARTICIPANT	\N	PRESENT	0
349700	346480	11103C	PARTICIPANT	\N	PRESENT	0
349701	346480	19760E	PARTICIPANT	\N	PRESENT	0
349702	346480	01034P	PARTICIPANT	\N	EXCUSE	0
349703	346480	14355X	PARTICIPANT	\N	EXCUSE	0
349704	346480	19367Y	PARTICIPANT	\N	EXCUSE	0
349705	346480	08041T	PARTICIPANT	\N	EXCUSE	0
349706	347017	14105F	PARTICIPANT	\N	PRESENT	0
349707	347017	14267Y	PARTICIPANT	\N	PRESENT	0
349708	347020	98005N	PARTICIPANT	\N	PRESENT	0
349709	347020	95030B	PARTICIPANT	\N	PRESENT	0
349710	347020	04034C	PARTICIPANT	\N	PRESENT	0
349711	347020	01058X	PARTICIPANT	\N	PRESENT	0
349712	347020	14079W	PARTICIPANT	\N	PRESENT	0
349776	347119	04071H	PARTICIPANT	\N	PRESENT	0
349714	347020	16685X	PARTICIPANT	\N	PRESENT	0
349715	347020	04042C	PRESIDENT	0	PRESENT	0
349716	347020	11054L	PARTICIPANT	\N	PRESENT	0
349717	347020	11066Q	PARTICIPANT	\N	PRESENT	0
349718	347020	08056B	PARTICIPANT	\N	PRESENT	0
349719	347020	95037J	PARTICIPANT	\N	PRESENT	0
349720	347020	11115U	PARTICIPANT	\N	PRESENT	0
349721	347020	14055N	PARTICIPANT	\N	PRESENT	0
349722	347020	19421M	PARTICIPANT	\N	PRESENT	0
349723	347020	19709B	PARTICIPANT	\N	PRESENT	0
349724	347020	08049C	PARTICIPANT	\N	PRESENT	0
349725	347020	14193X	PRESIDENT	1	PRESENT	0
349726	347020	08053X	PARTICIPANT	\N	PRESENT	0
349727	347020	97011G	PARTICIPANT	\N	PRESENT	0
349728	347020	08061X	PARTICIPANT	\N	PRESENT	0
349729	347020	08047A	PARTICIPANT	\N	PRESENT	0
349730	347020	98029W	PARTICIPANT	\N	PRESENT	0
349731	347020	14097Y	PARTICIPANT	\N	PRESENT	0
349732	347020	04035D	PARTICIPANT	\N	PRESENT	0
349733	347020	95067Q	PARTICIPANT	\N	PRESENT	0
349734	347020	01062T	PARTICIPANT	\N	PRESENT	0
349735	347020	11041F	PARTICIPANT	\N	PRESENT	0
349736	347020	14235Q	PARTICIPANT	\N	PRESENT	0
349737	347020	19251M	PARTICIPANT	\N	PRESENT	0
349738	347020	19721W	PARTICIPANT	\N	PRESENT	0
349739	347020	19319Q	PARTICIPANT	\N	PRESENT	0
349740	347020	14105F	PARTICIPANT	\N	PRESENT	0
349741	347020	98022P	PARTICIPANT	\N	PRESENT	0
349742	347020	11064N	PARTICIPANT	\N	PRESENT	0
349743	347020	14267Y	PARTICIPANT	\N	PRESENT	0
349744	347020	14211G	PARTICIPANT	\N	PRESENT	0
349745	347020	19583F	PARTICIPANT	\N	PRESENT	0
349746	347020	14255U	PARTICIPANT	\N	PRESENT	0
349747	347020	98018T	PARTICIPANT	\N	EXCUSE	0
349772	347119	11012A	PARTICIPANT	\N	PRESENT	0
349774	347119	14034U	PARTICIPANT	\N	PRESENT	0
349775	347119	11070L	PARTICIPANT	\N	PRESENT	0
349788	347020	04040A	PARTICIPANT	\N	PRESENT	0
349791	349223	19533U	PARTICIPANT	\N	PRESENT	0
349792	349223	04033B	PARTICIPANT	\N	PRESENT	0
349793	349223	14229S	PARTICIPANT	\N	PRESENT	0
349794	349223	08031R	PARTICIPANT	\N	PRESENT	0
349795	349223	19731Y	PARTICIPANT	\N	PRESENT	0
358737	358736	89017R	PARTICIPANT	\N	PRESENT	0
358742	358736	04047H	PARTICIPANT	\N	PRESENT	0
358740	358736	04085P	PARTICIPANT	\N	PRESENT	0
358741	358736	96004D	PARTICIPANT	\N	PRESENT	0
358743	358736	04042C	PARTICIPANT	\N	PRESENT	0
358744	358736	11053K	PARTICIPANT	\N	PRESENT	0
358745	358736	14038Y	PARTICIPANT	\N	PRESENT	0
358746	358736	14079W	PARTICIPANT	\N	PRESENT	0
358747	358736	11070L	PARTICIPANT	\N	PRESENT	0
358751	358736	14021P	PARTICIPANT	\N	PRESENT	0
358749	358736	11074Q	PARTICIPANT	\N	PRESENT	0
358750	358736	19521Q	PARTICIPANT	\N	PRESENT	0
358752	358736	08031R	PARTICIPANT	\N	PRESENT	0
358753	358736	01043Q	PARTICIPANT	\N	PRESENT	0
358754	358736	14251Q	PARTICIPANT	\N	PRESENT	0
358755	358736	04092N	PARTICIPANT	\N	PRESENT	0
358756	358736	08011M	PARTICIPANT	\N	PRESENT	0
358757	358736	04070G	PARTICIPANT	\N	PRESENT	0
358758	358736	14071N	PARTICIPANT	\N	PRESENT	0
358759	358736	08061X	PARTICIPANT	\N	PRESENT	0
358760	358736	11090Q	PARTICIPANT	\N	PRESENT	0
358904	357422	14033T	PARTICIPANT	\N	PRESENT	0
358905	357422	04088S	PARTICIPANT	\N	PRESENT	0
358906	357422	19725B	PARTICIPANT	\N	PRESENT	0
358907	357422	95067Q	PARTICIPANT	\N	PRESENT	0
359002	356663	11109J	PARTICIPANT	\N	PRESENT	0
359003	356663	19577H	PARTICIPANT	\N	PRESENT	0
359004	356663	14039A	PARTICIPANT	\N	PRESENT	0
359005	356663	19729F	PARTICIPANT	\N	EXCUSE	0
359006	356663	08019V	PRESIDENT	0	PRESENT	0
359007	356663	19657G	PARTICIPANT	\N	PRESENT	0
359008	356663	08073C	PARTICIPANT	\N	PRESENT	0
359009	356663	19691J	PARTICIPANT	\N	PRESENT	0
359010	356663	14229S	PARTICIPANT	\N	PRESENT	0
360761	353832	19511N	PARTICIPANT	\N	EXCUSE	0
360762	353832	08053X	PARTICIPANT	\N	EXCUSE	0
360763	353832	19723Y	PARTICIPANT	\N	EXCUSE	0
360765	353832	01058X	PARTICIPANT	\N	EXCUSE	0
360766	353832	19693L	PARTICIPANT	\N	EXCUSE	0
360767	353832	80013X	PARTICIPANT	\N	EXCUSE	0
360916	360915	07004J	PARTICIPANT	\N	PRESENT	0
360917	360915	19713W	PARTICIPANT	\N	PRESENT	0
360918	360915	10015M	PARTICIPANT	\N	PRESENT	0
360919	360915	14085U	PARTICIPANT	\N	PRESENT	0
360920	360915	19739H	PARTICIPANT	\N	PRESENT	0
360921	360915	04040A	PARTICIPANT	\N	PRESENT	0
360922	360915	14083S	PARTICIPANT	\N	PRESENT	0
360923	360915	14079W	PARTICIPANT	\N	PRESENT	0
360924	345226	14063N	PARTICIPANT	\N	PRESENT	0
360925	345226	19725B	PARTICIPANT	\N	PRESENT	0
360926	345226	14121F	PARTICIPANT	\N	PRESENT	0
360927	345226	19295A	PARTICIPANT	\N	PRESENT	0
360928	345226	19758L	PARTICIPANT	\N	PRESENT	0
360929	345226	19760E	PARTICIPANT	\N	PRESENT	0
360930	345226	14235Q	PARTICIPANT	\N	PRESENT	0
360931	345226	11072N	PARTICIPANT	\N	PRESENT	0
360932	345226	19387D	PARTICIPANT	\N	PRESENT	0
360933	345226	19563B	PARTICIPANT	\N	PRESENT	0
360934	345226	19585H	PARTICIPANT	\N	PRESENT	0
360939	345226	19737F	PARTICIPANT	\N	PRESENT	0
360940	345226	19289C	PARTICIPANT	\N	PRESENT	0
360941	345226	19691J	PARTICIPANT	\N	PRESENT	0
360942	345226	14267Y	PARTICIPANT	\N	PRESENT	0
360943	345226	14073Q	PARTICIPANT	\N	PRESENT	0
360944	345226	11070L	PARTICIPANT	\N	PRESENT	0
360945	345226	14051J	PARTICIPANT	\N	PRESENT	0
360946	345226	19577H	PARTICIPANT	\N	PRESENT	0
360947	345226	89017R	PARTICIPANT	\N	PRESENT	0
360948	345226	19367Y	PARTICIPANT	\N	PRESENT	0
360949	345226	19581D	PARTICIPANT	\N	PRESENT	0
360950	345226	01024M	PARTICIPANT	\N	PRESENT	0
360951	345226	08048B	PARTICIPANT	\N	PRESENT	0
360952	345226	08015R	PARTICIPANT	\N	PRESENT	0
360953	345226	19399H	PARTICIPANT	\N	PRESENT	0
360954	345226	08028W	PARTICIPANT	\N	PRESENT	0
360955	345226	97011G	PARTICIPANT	\N	PRESENT	0
360956	345226	04092N	PARTICIPANT	\N	PRESENT	0
360957	345226	19663E	PARTICIPANT	\N	PRESENT	0
360958	345226	18083K	PARTICIPANT	\N	PRESENT	0
360959	345226	14041T	PARTICIPANT	\N	PRESENT	0
360960	345226	04088S	PARTICIPANT	\N	PRESENT	0
360961	345226	14115H	PARTICIPANT	\N	PRESENT	0
360962	345226	14029X	PARTICIPANT	\N	PRESENT	0
360963	345226	19443T	PARTICIPANT	\N	PRESENT	0
360964	345226	19741B	PARTICIPANT	\N	PRESENT	0
360965	345226	14038Y	PARTICIPANT	\N	PRESENT	0
360966	345226	19467C	PARTICIPANT	\N	PRESENT	0
360967	345226	14033T	PARTICIPANT	\N	PRESENT	0
360968	345226	14157T	PARTICIPANT	\N	PRESENT	0
360969	345226	19667J	PARTICIPANT	\N	PRESENT	0
360970	345226	19794Q	PARTICIPANT	\N	PRESENT	0
360971	345226	19703U	PARTICIPANT	\N	PRESENT	0
360972	345226	19573D	PARTICIPANT	\N	PRESENT	0
360973	345226	19673G	PARTICIPANT	\N	PRESENT	0
360974	345226	14083S	PARTICIPANT	\N	PRESENT	0
360975	345226	04038G	PARTICIPANT	\N	PRESENT	0
360976	345226	19731Y	PARTICIPANT	\N	PRESENT	0
360977	345226	19762G	PARTICIPANT	\N	PRESENT	0
360978	345226	19593H	PARTICIPANT	\N	PRESENT	0
360979	345226	19657G	PARTICIPANT	\N	PRESENT	0
360980	345226	19553Y	PARTICIPANT	\N	PRESENT	0
360981	345226	19253P	PARTICIPANT	\N	PRESENT	0
360982	345226	08038Y	PARTICIPANT	\N	PRESENT	0
360983	345226	14065Q	PARTICIPANT	\N	PRESENT	0
360984	345226	95030B	PARTICIPANT	\N	PRESENT	0
360985	345226	14133K	PARTICIPANT	\N	PRESENT	0
360986	345226	14069U	PARTICIPANT	\N	PRESENT	0
360987	345226	11064N	PARTICIPANT	\N	PRESENT	0
360913	345226	04086Q	PARTICIPANT	\N	PRESENT	0
360914	345226	19719D	PARTICIPANT	\N	PRESENT	0
360988	345226	19479G	PARTICIPANT	\N	PRESENT	0
360989	345226	19745F	PARTICIPANT	\N	PRESENT	0
360990	345226	08068F	PARTICIPANT	\N	PRESENT	0
360991	345226	14237S	PARTICIPANT	\N	PRESENT	0
360992	345226	01028R	PARTICIPANT	\N	PRESENT	0
360993	345226	11110B	PARTICIPANT	\N	PRESENT	0
360994	345226	07029T	PARTICIPANT	\N	PRESENT	0
360995	345226	14265W	PARTICIPANT	\N	PRESENT	0
360996	345226	14123H	PARTICIPANT	\N	PRESENT	0
360997	345226	14219Q	PARTICIPANT	\N	PRESENT	0
360998	345226	19782L	PARTICIPANT	\N	PRESENT	0
360999	345226	19543W	PARTICIPANT	\N	PRESENT	0
361000	345226	14135M	PARTICIPANT	\N	PRESENT	0
361001	345226	11040E	PARTICIPANT	\N	PRESENT	0
361002	345226	14105F	PARTICIPANT	\N	PRESENT	0
361003	345226	14221J	PARTICIPANT	\N	PRESENT	0
361004	345226	14193X	PARTICIPANT	\N	PRESENT	0
361005	345226	08039A	PARTICIPANT	\N	PRESENT	0
361087	345227	04086Q	PARTICIPANT	\N	PRESENT	0
361088	345227	19713W	PARTICIPANT	\N	PRESENT	0
361089	345227	19479G	PARTICIPANT	\N	PRESENT	0
361090	345227	14042U	PARTICIPANT	\N	PRESENT	0
361091	345227	14219Q	PARTICIPANT	\N	PRESENT	0
361092	345227	19441R	PARTICIPANT	\N	PRESENT	0
361093	345227	19737F	PARTICIPANT	\N	PRESENT	0
361094	345227	19387D	PARTICIPANT	\N	PRESENT	0
361095	345227	19253P	PARTICIPANT	\N	PRESENT	0
361096	345227	19782L	PARTICIPANT	\N	PRESENT	0
361097	345227	14121F	PARTICIPANT	\N	PRESENT	0
361120	345227	14221J	PARTICIPANT	\N	PRESENT	0
361127	345227	08012N	PARTICIPANT	\N	PRESENT	0
361100	345227	14073Q	PARTICIPANT	\N	PRESENT	0
361101	345227	01024M	PARTICIPANT	\N	PRESENT	0
361102	345227	19731Y	PARTICIPANT	\N	PRESENT	0
361103	345227	08039A	PARTICIPANT	\N	PRESENT	0
361104	345227	14265W	PARTICIPANT	\N	PRESENT	0
361105	345227	14041T	PARTICIPANT	\N	PRESENT	0
361106	345227	04088S	PARTICIPANT	\N	PRESENT	0
361107	345227	19467C	PARTICIPANT	\N	PRESENT	0
361108	345227	14135M	PARTICIPANT	\N	PRESENT	0
361109	345227	14157T	PARTICIPANT	\N	PRESENT	0
361121	345227	14069U	PARTICIPANT	\N	PRESENT	0
361111	345227	19762G	PARTICIPANT	\N	PRESENT	0
361112	345227	19657G	PARTICIPANT	\N	PRESENT	0
361113	345227	14115H	PARTICIPANT	\N	PRESENT	0
361114	345227	19667J	PARTICIPANT	\N	PRESENT	0
361115	345227	97011G	PARTICIPANT	\N	PRESENT	0
361116	345227	19758L	PARTICIPANT	\N	PRESENT	0
361117	345227	11043H	PARTICIPANT	\N	PRESENT	0
361118	345227	11097X	PARTICIPANT	\N	PRESENT	0
361119	345227	14267Y	PARTICIPANT	\N	PRESENT	0
361122	345227	14237S	PARTICIPANT	\N	PRESENT	0
361123	345227	08043V	PARTICIPANT	\N	PRESENT	0
361124	345227	19747H	PARTICIPANT	\N	PRESENT	0
361125	345227	14215L	PARTICIPANT	\N	PRESENT	0
361129	345227	19593H	PARTICIPANT	\N	PRESENT	0
361128	345227	11109J	PARTICIPANT	\N	PRESENT	0
334640	322214	04043D	PARTICIPANT	\N	PRESENT	0
334642	322214	01058X	PARTICIPANT	\N	PRESENT	0
334649	322214	19503N	PARTICIPANT	\N	PRESENT	0
334652	322214	19663E	PARTICIPANT	\N	PRESENT	0
334654	322214	19723Y	PARTICIPANT	\N	PRESENT	0
334656	322214	19533U	PARTICIPANT	\N	PRESENT	0
334663	322214	14221J	PARTICIPANT	\N	EXCUSE	0
334664	322214	19709B	PARTICIPANT	\N	EXCUSE	0
334665	322214	14093U	PARTICIPANT	\N	EXCUSE	0
334666	322214	01048V	PARTICIPANT	\N	EXCUSE	0
334667	322214	19553Y	PARTICIPANT	\N	EXCUSE	0
334787	334786	96004D	PARTICIPANT	\N	PRESENT	0
334788	334786	95037J	PARTICIPANT	\N	PRESENT	0
334789	334786	14026U	PARTICIPANT	\N	PRESENT	0
334790	334786	14033T	PARTICIPANT	\N	PRESENT	0
334791	334786	14097Y	PARTICIPANT	\N	PRESENT	0
334792	334786	11090Q	PARTICIPANT	\N	PRESENT	0
334793	334786	19441R	PARTICIPANT	\N	PRESENT	0
334794	334786	14207L	PARTICIPANT	\N	PRESENT	0
334795	334786	14257W	PARTICIPANT	\N	PRESENT	0
334797	334796	96004D	PARTICIPANT	\N	PRESENT	0
334798	334796	95037J	PARTICIPANT	\N	PRESENT	0
334799	334796	14026U	PARTICIPANT	\N	PRESENT	0
334800	334796	14033T	PARTICIPANT	\N	PRESENT	0
334801	334796	14097Y	PARTICIPANT	\N	PRESENT	0
334802	334796	11090Q	PARTICIPANT	\N	PRESENT	0
334803	334796	19441R	PARTICIPANT	\N	PRESENT	0
334804	334796	14207L	PARTICIPANT	\N	PRESENT	0
334806	334796	14257W	PARTICIPANT	\N	PRESENT	0
334807	334796	19507S	PARTICIPANT	\N	PRESENT	0
335661	335660	19667J	PARTICIPANT	\N	PRESENT	0
335662	335660	14069U	PARTICIPANT	\N	PRESENT	0
335663	335660	19643A	PARTICIPANT	\N	PRESENT	0
335664	335660	19467C	PARTICIPANT	\N	PRESENT	0
335665	335660	18083K	PARTICIPANT	\N	PRESENT	0
335666	335660	19507S	PARTICIPANT	\N	PRESENT	0
335667	335660	19347U	PARTICIPANT	\N	PRESENT	0
335668	335660	19511N	PARTICIPANT	\N	PRESENT	0
335669	335660	16685X	PARTICIPANT	\N	PRESENT	0
335670	335660	14103D	PARTICIPANT	\N	PRESENT	0
335671	335660	14265W	PARTICIPANT	\N	PRESENT	0
335672	335660	19745F	PARTICIPANT	\N	PRESENT	0
335673	335660	04088S	PARTICIPANT	\N	PRESENT	0
335674	335660	05012A	PARTICIPANT	\N	PRESENT	0
335675	335660	11045K	PARTICIPANT	\N	PRESENT	0
335676	335660	14107H	PARTICIPANT	\N	PRESENT	0
335677	335660	14173T	PARTICIPANT	\N	PRESENT	0
335688	335660	19383Y	PARTICIPANT	\N	PRESENT	0
338181	338180	08039A	PARTICIPANT	\N	PRESENT	0
340482	340481	14259Y	PARTICIPANT	\N	PRESENT	0
340565	339493	04059M	PARTICIPANT	\N	PRESENT	0
340566	339493	01060R	PARTICIPANT	\N	PRESENT	0
340567	339493	19583F	PARTICIPANT	\N	PRESENT	0
340568	339493	08060W	PARTICIPANT	\N	PRESENT	0
340569	339493	08073C	PARTICIPANT	\N	PRESENT	0
340570	339493	19739H	PARTICIPANT	\N	PRESENT	0
340571	339493	19683J	PARTICIPANT	\N	PRESENT	0
340572	339493	01048V	PARTICIPANT	\N	PRESENT	0
340573	339493	14033T	PARTICIPANT	\N	PRESENT	0
340574	339493	19515S	PARTICIPANT	\N	PRESENT	0
340575	339493	19629C	PARTICIPANT	\N	PRESENT	0
340576	339493	19713W	PARTICIPANT	\N	PRESENT	0
340577	339493	14063N	PARTICIPANT	\N	PRESENT	0
340578	339493	14207L	PARTICIPANT	\N	PRESENT	0
340579	339493	80013X	PARTICIPANT	\N	PRESENT	0
340580	339493	19711U	PARTICIPANT	\N	PRESENT	0
340581	339493	11065P	PARTICIPANT	\N	PRESENT	0
340582	339493	18083K	PARTICIPANT	\N	PRESENT	0
340583	339493	19563B	PARTICIPANT	\N	PRESENT	0
340584	339493	08068F	PARTICIPANT	\N	PRESENT	0
340585	339493	11090Q	PARTICIPANT	\N	PRESENT	0
340586	339493	14093U	PARTICIPANT	\N	PRESENT	0
340587	339493	14081Q	PARTICIPANT	\N	PRESENT	0
340588	339493	14219Q	PARTICIPANT	\N	PRESENT	0
340589	339493	11048N	PARTICIPANT	\N	PRESENT	0
340590	339493	19503N	PARTICIPANT	\N	PRESENT	0
340591	339493	95067Q	PARTICIPANT	\N	PRESENT	0
340592	339493	14119M	PARTICIPANT	\N	PRESENT	0
340593	339493	19549D	PARTICIPANT	\N	PRESENT	0
340594	339493	95062K	PARTICIPANT	\N	PRESENT	0
340595	339493	08038Y	PARTICIPANT	\N	PRESENT	0
340596	339493	14121F	PARTICIPANT	\N	PRESENT	0
340597	339493	19301E	PARTICIPANT	\N	PRESENT	0
340598	339493	14038Y	PARTICIPANT	\N	PRESENT	0
340599	339493	14267Y	PARTICIPANT	\N	PRESENT	0
340600	339493	19695N	PARTICIPANT	\N	PRESENT	0
340601	339493	19347U	PARTICIPANT	\N	PRESENT	0
340602	339493	11077T	PARTICIPANT	\N	PRESENT	0
340603	339493	01058X	PARTICIPANT	\N	PRESENT	0
340604	339493	19671E	PARTICIPANT	\N	PRESENT	0
340605	339493	19599P	PARTICIPANT	\N	PRESENT	0
340606	339493	19719D	PARTICIPANT	\N	PRESENT	0
340607	339493	19733B	PARTICIPANT	\N	PRESENT	0
340608	339493	11103C	PARTICIPANT	\N	PRESENT	0
340609	339493	16685X	PARTICIPANT	\N	PRESENT	0
340610	339493	14257W	PARTICIPANT	\N	PRESENT	0
340611	339493	19479G	PARTICIPANT	\N	PRESENT	0
340612	339493	19715Y	PARTICIPANT	\N	PRESENT	0
340613	339493	14069U	PARTICIPANT	\N	PRESENT	0
340614	339493	14073Q	PARTICIPANT	\N	PRESENT	0
340615	339493	19745F	PARTICIPANT	\N	PRESENT	0
340616	339493	14205J	PARTICIPANT	\N	PRESENT	0
340617	339493	14265W	PARTICIPANT	\N	PRESENT	0
340618	339493	14221J	PARTICIPANT	\N	PRESENT	0
340619	339493	14237S	PARTICIPANT	\N	PRESENT	0
340620	339493	19681G	PARTICIPANT	\N	PRESENT	0
340621	339493	14357A	PARTICIPANT	\N	PRESENT	0
340622	339493	14039A	PARTICIPANT	\N	PRESENT	0
340623	339493	01025N	PARTICIPANT	\N	PRESENT	0
340624	339493	08056B	PARTICIPANT	\N	PRESENT	0
340625	339493	14089Y	PARTICIPANT	\N	PRESENT	0
340627	339493	14157T	PARTICIPANT	\N	PRESENT	0
340628	339493	04061F	PARTICIPANT	\N	PRESENT	0
340634	339493	17583W	PARTICIPANT	\N	PRESENT	0
340642	339493	14147R	PARTICIPANT	\N	PRESENT	0
340647	339493	08028W	PARTICIPANT	\N	PRESENT	0
340650	339493	11097X	PARTICIPANT	\N	PRESENT	0
340671	339493	11056N	PARTICIPANT	\N	PRESENT	0
340672	339493	14169X	PARTICIPANT	\N	PRESENT	0
340673	339493	14071N	PARTICIPANT	\N	PRESENT	0
340674	339493	14105F	PARTICIPANT	\N	PRESENT	0
340675	339493	11043H	PARTICIPANT	\N	PRESENT	0
340676	339493	19533U	PARTICIPANT	\N	PRESENT	0
340677	339493	95030B	PARTICIPANT	\N	PRESENT	0
340678	339493	15447F	PARTICIPANT	\N	PRESENT	0
340679	339493	04088S	PARTICIPANT	\N	PRESENT	0
340681	339493	19611R	PARTICIPANT	\N	PRESENT	0
340682	339493	19737F	PARTICIPANT	\N	PRESENT	0
340683	339493	19441R	PARTICIPANT	\N	PRESENT	0
340684	339493	08031R	PARTICIPANT	\N	PRESENT	0
340685	339493	08052W	PARTICIPANT	\N	PRESENT	0
340686	339493	11067R	PARTICIPANT	\N	PRESENT	0
340687	339493	01057W	PARTICIPANT	\N	PRESENT	0
340688	339493	08015R	PARTICIPANT	\N	PRESENT	0
340689	339493	04089T	PARTICIPANT	\N	PRESENT	0
340691	339493	19731Y	PARTICIPANT	\N	PRESENT	0
340693	339493	14109K	PARTICIPANT	\N	PRESENT	0
340694	340563	14111D	PARTICIPANT	\N	PRESENT	0
340695	340563	14065Q	PARTICIPANT	\N	PRESENT	0
340696	340563	07034Q	PRESIDENT	0	PRESENT	0
340697	340563	11026G	PARTICIPANT	\N	PRESENT	0
340698	340563	08045X	PARTICIPANT	\N	PRESENT	0
340699	340563	10015M	PARTICIPANT	\N	PRESENT	0
340700	340563	01024M	PARTICIPANT	\N	PRESENT	0
340701	340563	04044E	PARTICIPANT	\N	PRESENT	0
340702	340563	04038G	PARTICIPANT	\N	PRESENT	0
340703	340563	19581D	PARTICIPANT	\N	PRESENT	0
340704	340563	04047H	PARTICIPANT	\N	PRESENT	0
340705	340563	01028R	PARTICIPANT	\N	PRESENT	0
340706	340563	19447X	PARTICIPANT	\N	PRESENT	0
340707	340563	19725B	PARTICIPANT	\N	PRESENT	0
340708	340563	19729F	PARTICIPANT	\N	PRESENT	0
340709	340563	14041T	PARTICIPANT	\N	PRESENT	0
340710	340563	14215L	PARTICIPANT	\N	PRESENT	0
340711	340563	11049P	PARTICIPANT	\N	PRESENT	0
340712	340563	08051V	PARTICIPANT	\N	PRESENT	0
340713	340563	14089Y	PARTICIPANT	\N	PRESENT	0
340714	340563	19649G	PARTICIPANT	\N	PRESENT	0
340715	340563	95063L	PARTICIPANT	\N	PRESENT	0
340716	340563	14147R	PARTICIPANT	\N	PRESENT	0
340717	340563	14151M	PARTICIPANT	\N	PRESENT	0
340718	340563	14069U	PARTICIPANT	\N	PRESENT	0
340719	340563	08018U	PARTICIPANT	\N	PRESENT	0
340720	340563	14021P	PARTICIPANT	\N	PRESENT	0
340721	340563	08044W	PARTICIPANT	\N	EXCUSE	0
358908	351756	08045X	PARTICIPANT	\N	PRESENT	0
358960	358959	14173T	PARTICIPANT	\N	PRESENT	0
358962	358961	07033P	PARTICIPANT	\N	PRESENT	0
358963	358961	14109K	PARTICIPANT	\N	PRESENT	0
358964	358961	92040Q	PARTICIPANT	\N	PRESENT	0
358965	358961	19593H	PARTICIPANT	\N	PRESENT	0
358966	358961	19735D	PARTICIPANT	\N	PRESENT	0
358968	358967	19735D	PARTICIPANT	\N	PRESENT	0
358969	358967	11109J	PARTICIPANT	\N	PRESENT	0
358971	358970	19621T	PARTICIPANT	\N	PRESENT	0
358972	358970	14109K	PARTICIPANT	\N	PRESENT	0
358973	358970	08043V	PARTICIPANT	\N	PRESENT	0
358975	358974	14109K	PARTICIPANT	\N	PRESENT	0
358976	358974	14241N	PARTICIPANT	\N	PRESENT	0
358977	358974	19611R	PARTICIPANT	\N	PRESENT	0
358978	358974	19621T	PARTICIPANT	\N	PRESENT	0
359012	359011	14053L	PARTICIPANT	\N	PRESENT	0
359200	359198	19515S	PARTICIPANT	\N	PRESENT	0
359194	359193	95063L	PARTICIPANT	\N	PRESENT	0
359199	359198	19631V	PARTICIPANT	\N	PRESENT	0
359201	359198	19747H	PARTICIPANT	\N	PRESENT	0
359202	359198	11056N	PARTICIPANT	\N	PRESENT	0
359203	359198	19369B	PARTICIPANT	\N	PRESENT	0
359204	359198	14257W	PARTICIPANT	\N	PRESENT	0
359205	359198	14265W	PARTICIPANT	\N	PRESENT	0
359206	359198	04088S	PARTICIPANT	\N	PRESENT	0
359207	359198	14135M	PARTICIPANT	\N	PRESENT	0
359209	359198	19269X	PARTICIPANT	\N	PRESENT	0
359210	359198	19705W	PARTICIPANT	\N	PRESENT	0
359211	359198	11090Q	PARTICIPANT	\N	PRESENT	0
359219	359218	19741B	PARTICIPANT	\N	PRESENT	0
359222	359221	11074Q	PARTICIPANT	\N	PRESENT	0
359551	345222	14187A	PARTICIPANT	\N	PRESENT	0
359552	345222	05008E	PARTICIPANT	\N	PRESENT	0
359553	345222	19421M	PARTICIPANT	\N	PRESENT	0
359554	345222	14055N	PARTICIPANT	\N	PRESENT	0
359555	345222	19731Y	PARTICIPANT	\N	PRESENT	0
359556	345222	89017R	PARTICIPANT	\N	PRESENT	0
359557	345222	95063L	PARTICIPANT	\N	PRESENT	0
359558	345222	19515S	PARTICIPANT	\N	PRESENT	0
359559	345222	11080N	PARTICIPANT	\N	PRESENT	0
359560	345222	11074Q	PARTICIPANT	\N	PRESENT	0
359561	345222	19766L	PARTICIPANT	\N	PRESENT	0
359562	345222	04059M	PARTICIPANT	\N	PRESENT	0
359563	345222	11072N	PARTICIPANT	\N	PRESENT	0
359564	345222	11027H	PARTICIPANT	\N	PRESENT	0
359565	345222	14159V	PARTICIPANT	\N	PRESENT	0
359566	345222	08055A	PARTICIPANT	\N	PRESENT	0
359567	345222	01028R	PARTICIPANT	\N	PRESENT	0
359569	345222	14093U	PARTICIPANT	\N	PRESENT	0
359570	345222	96004D	PARTICIPANT	\N	PRESENT	0
359571	345222	08068F	PARTICIPANT	\N	PRESENT	0
359572	345222	14051J	PARTICIPANT	\N	PRESENT	0
359573	345222	14069U	PARTICIPANT	\N	PRESENT	0
359574	345222	14249W	PARTICIPANT	\N	PRESENT	0
359575	345222	14021P	PARTICIPANT	\N	PRESENT	0
359576	345222	08045X	PARTICIPANT	\N	PRESENT	0
359577	345222	14053L	PARTICIPANT	\N	PRESENT	0
359578	345222	19669L	PARTICIPANT	\N	PRESENT	0
359580	345222	14215L	PARTICIPANT	\N	PRESENT	0
359582	345222	19599P	PARTICIPANT	\N	PRESENT	0
359583	345222	14151M	PARTICIPANT	\N	PRESENT	0
359585	345222	19649G	PARTICIPANT	\N	PRESENT	0
359586	345222	11045K	PARTICIPANT	\N	PRESENT	0
359587	345222	14028W	PARTICIPANT	\N	PRESENT	0
359588	345222	19399H	PARTICIPANT	\N	PRESENT	0
359589	345222	08047A	PARTICIPANT	\N	PRESENT	0
359590	345222	08038Y	PARTICIPANT	\N	PRESENT	0
359591	345222	19703U	PARTICIPANT	\N	PRESENT	0
359592	345222	11066Q	PARTICIPANT	\N	PRESENT	0
359594	345222	11090Q	PARTICIPANT	\N	PRESENT	0
359595	345222	19673G	PARTICIPANT	\N	PRESENT	0
359596	345222	08043V	PARTICIPANT	\N	PRESENT	0
359597	345222	19727D	PARTICIPANT	\N	PRESENT	0
359598	345222	14031R	PARTICIPANT	\N	PRESENT	0
359599	345222	08035V	PARTICIPANT	\N	PRESENT	0
359600	345222	19667J	PARTICIPANT	\N	PRESENT	0
359601	345222	19575F	PARTICIPANT	\N	PRESENT	0
359602	345222	08012N	PARTICIPANT	\N	PRESENT	0
359603	345222	10015M	PARTICIPANT	\N	PRESENT	0
359604	345222	80027E	PARTICIPANT	\N	PRESENT	0
359605	345222	19531S	PARTICIPANT	\N	PRESENT	0
359549	345222	19553Y	PARTICIPANT	\N	PRESENT	0
359550	345222	19681G	PARTICIPANT	\N	PRESENT	0
359606	345222	14253S	PARTICIPANT	\N	PRESENT	0
359607	345222	19525U	PARTICIPANT	\N	PRESENT	0
359608	345222	11110B	PARTICIPANT	\N	PRESENT	0
359609	345222	14081Q	PARTICIPANT	\N	PRESENT	0
359610	345222	11048N	PARTICIPANT	\N	PRESENT	0
359611	345222	08053X	PARTICIPANT	\N	PRESENT	0
359612	345222	04049K	PARTICIPANT	\N	PRESENT	0
359613	345222	08017T	PARTICIPANT	\N	PRESENT	0
359614	345222	95067Q	PARTICIPANT	\N	PRESENT	0
359615	345222	14071N	PARTICIPANT	\N	PRESENT	0
359616	345222	08058D	PARTICIPANT	\N	PRESENT	0
359617	345222	04033B	PARTICIPANT	\N	PRESENT	0
359618	345222	17779H	PARTICIPANT	\N	PRESENT	0
359619	345222	11033F	PARTICIPANT	\N	PRESENT	0
359620	345222	19347U	PARTICIPANT	\N	PRESENT	0
359621	345222	04085P	PARTICIPANT	\N	PRESENT	0
359622	345222	19695N	PARTICIPANT	\N	PRESENT	0
359623	345222	05012A	PARTICIPANT	\N	PRESENT	0
359624	345222	19269X	PARTICIPANT	\N	PRESENT	0
359625	345222	19549D	PARTICIPANT	\N	PRESENT	0
359626	345222	14123H	PARTICIPANT	\N	PRESENT	0
359627	345222	19533U	PARTICIPANT	\N	PRESENT	0
359628	345222	08073C	PARTICIPANT	\N	PRESENT	0
359629	345222	08034U	PARTICIPANT	\N	PRESENT	0
359630	345222	08014Q	PARTICIPANT	\N	PRESENT	0
359631	345222	14087W	PARTICIPANT	\N	PRESENT	0
359632	345222	14001X	PARTICIPANT	\N	PRESENT	0
359633	345222	19551W	PARTICIPANT	\N	PRESENT	0
359634	345222	19798U	PARTICIPANT	\N	PRESENT	0
359635	345222	19683J	PARTICIPANT	\N	PRESENT	0
359636	345222	19295A	PARTICIPANT	\N	PRESENT	0
359637	345222	11054L	PARTICIPANT	\N	PRESENT	0
359638	345222	19725B	PARTICIPANT	\N	PRESENT	0
359639	345222	14097Y	PARTICIPANT	\N	PRESENT	0
359640	345222	14257W	PARTICIPANT	\N	PRESENT	0
359641	345222	14109K	PARTICIPANT	\N	PRESENT	0
359642	345222	14193X	PARTICIPANT	\N	PRESENT	0
359643	345222	19631V	PARTICIPANT	\N	PRESENT	0
359644	345222	01062T	PARTICIPANT	\N	PRESENT	0
359645	345222	19591F	PARTICIPANT	\N	PRESENT	0
359646	345222	14173T	PARTICIPANT	\N	PRESENT	0
359647	345222	11067R	PARTICIPANT	\N	PRESENT	0
359648	345222	19447X	PARTICIPANT	\N	PRESENT	0
359649	345222	11026G	PARTICIPANT	\N	PRESENT	0
359650	345222	19573D	PARTICIPANT	\N	PRESENT	0
359651	345222	19251M	PARTICIPANT	\N	PRESENT	0
359652	345222	19794Q	PARTICIPANT	\N	PRESENT	0
359653	345222	19413M	PARTICIPANT	\N	PRESENT	0
359654	345222	95041E	PARTICIPANT	\N	PRESENT	0
359655	345222	14133K	PARTICIPANT	\N	PRESENT	0
359656	345222	14119M	PARTICIPANT	\N	PRESENT	0
359657	345222	11049P	PARTICIPANT	\N	PRESENT	0
359658	345222	14115H	PARTICIPANT	\N	PRESENT	0
359659	345222	14085U	PARTICIPANT	\N	PRESENT	0
359660	345222	14105F	PARTICIPANT	\N	PRESENT	0
359661	345222	17583W	PARTICIPANT	\N	PRESENT	0
359662	345222	04089T	PARTICIPANT	\N	PRESENT	0
359663	345222	14231L	PARTICIPANT	\N	PRESENT	0
359664	345222	14147R	PARTICIPANT	\N	PRESENT	0
359665	345222	14179A	PARTICIPANT	\N	PRESENT	0
359666	345222	97011G	PARTICIPANT	\N	PRESENT	0
359667	345222	01034P	PARTICIPANT	\N	PRESENT	0
359668	345222	19369B	PARTICIPANT	\N	PRESENT	0
359669	345222	07033P	PARTICIPANT	\N	PRESENT	0
359670	345222	19691J	PARTICIPANT	\N	PRESENT	0
359671	345222	14217N	PARTICIPANT	\N	PRESENT	0
359672	345222	11053K	PARTICIPANT	\N	PRESENT	0
359673	345222	14331P	PARTICIPANT	\N	PRESENT	0
359674	345222	19611R	PARTICIPANT	\N	PRESENT	0
359675	345222	19581D	PARTICIPANT	\N	PRESENT	0
359676	345222	19511N	PARTICIPANT	\N	PRESENT	0
359677	345222	08018U	PARTICIPANT	\N	PRESENT	0
359678	345222	19737F	PARTICIPANT	\N	PRESENT	0
359679	345222	14205J	PARTICIPANT	\N	PRESENT	0
359680	345222	19699S	PARTICIPANT	\N	PRESENT	0
359681	345222	19747H	PARTICIPANT	\N	PRESENT	0
359682	345222	19721W	PARTICIPANT	\N	PRESENT	0
359683	345222	19619A	PARTICIPANT	\N	PRESENT	0
359684	345222	16685X	PARTICIPANT	\N	PRESENT	0
359685	345222	19735D	PARTICIPANT	\N	PRESENT	0
359686	345222	01043Q	PARTICIPANT	\N	PRESENT	0
359687	345222	14042U	PARTICIPANT	\N	PRESENT	0
359688	345222	14219Q	PARTICIPANT	\N	PRESENT	0
359689	345222	19647E	PARTICIPANT	\N	PRESENT	0
333826	333825	19575F	PARTICIPANT	\N	PRESENT	0
333827	333825	14030Q	PARTICIPANT	\N	PRESENT	0
333829	333825	14105F	PARTICIPANT	\N	PRESENT	0
333830	333825	14053L	PARTICIPANT	\N	PRESENT	0
333831	333825	14083S	PARTICIPANT	\N	PRESENT	0
333832	333825	14079W	PARTICIPANT	\N	PRESENT	0
333834	333825	14087W	PARTICIPANT	\N	PRESENT	0
333835	333825	19521Q	PARTICIPANT	\N	PRESENT	0
333867	333825	14026U	PARTICIPANT	\N	PRESENT	0
333868	333825	14121F	PARTICIPANT	\N	PRESENT	0
333870	333825	14061L	PARTICIPANT	\N	PRESENT	0
333871	333825	04049K	PRESIDENT	0	PRESENT	0
333872	333825	16685X	PARTICIPANT	\N	PRESENT	0
333874	333825	14205J	PARTICIPANT	\N	PRESENT	0
333875	333825	19671E	PARTICIPANT	\N	PRESENT	0
333876	333825	14265W	PARTICIPANT	\N	PRESENT	0
333877	333825	14227Q	PARTICIPANT	\N	PRESENT	0
333880	333825	89017R	PARTICIPANT	\N	EXCUSE	0
333881	333825	14261S	PARTICIPANT	\N	EXCUSE	0
333887	333825	08060W	PARTICIPANT	\N	EXCUSE	0
333888	333825	08068F	PARTICIPANT	\N	EXCUSE	0
333889	333825	14255U	PARTICIPANT	\N	EXCUSE	0
333891	333825	14329V	PARTICIPANT	\N	EXCUSE	0
333892	333825	11031D	PARTICIPANT	\N	EXCUSE	0
333893	333825	14041T	PARTICIPANT	\N	EXCUSE	0
333894	333825	14187A	PARTICIPANT	\N	EXCUSE	0
333895	333825	14034U	PARTICIPANT	\N	EXCUSE	0
333896	333825	19695N	PARTICIPANT	\N	EXCUSE	0
333897	333825	19591F	PARTICIPANT	\N	EXCUSE	0
333898	333825	14039A	PARTICIPANT	\N	EXCUSE	0
333899	333825	11099A	PARTICIPANT	\N	EXCUSE	0
333900	333825	08015R	PARTICIPANT	\N	EXCUSE	0
333901	333825	14253S	PARTICIPANT	\N	EXCUSE	0
333902	333825	08047A	PARTICIPANT	\N	EXCUSE	0
333903	333825	19669L	PARTICIPANT	\N	EXCUSE	0
333904	333825	14051J	PARTICIPANT	\N	EXCUSE	0
333905	333825	14157T	PARTICIPANT	\N	EXCUSE	0
333911	333910	14255U	PARTICIPANT	\N	PRESENT	0
333912	333910	04049K	PARTICIPANT	\N	PRESENT	0
333913	333910	14265W	PARTICIPANT	\N	PRESENT	0
333914	333910	14053L	PARTICIPANT	\N	PRESENT	0
333917	333915	14026U	PARTICIPANT	\N	PRESENT	0
333918	333915	14205J	PARTICIPANT	\N	PRESENT	0
333923	333921	14026U	PARTICIPANT	\N	PRESENT	0
333924	333921	19591F	PARTICIPANT	\N	PRESENT	0
333927	333926	04049K	PARTICIPANT	\N	PRESENT	0
333928	333926	08068F	PARTICIPANT	\N	PRESENT	0
333929	333926	14261S	PARTICIPANT	\N	PRESENT	0
333930	333926	14083S	PARTICIPANT	\N	PRESENT	0
333931	333926	14151M	PARTICIPANT	\N	PRESENT	0
333932	333926	04088S	PARTICIPANT	\N	PRESENT	0
333948	333946	14261S	PARTICIPANT	\N	PRESENT	0
333949	333946	14053L	PARTICIPANT	\N	PRESENT	0
333950	333946	14083S	PARTICIPANT	\N	PRESENT	0
333951	333946	14041T	PARTICIPANT	\N	PRESENT	0
333952	333946	19671E	PARTICIPANT	\N	PRESENT	0
333953	333946	14051J	PARTICIPANT	\N	PRESENT	0
333954	333946	04088S	PARTICIPANT	\N	PRESENT	0
333955	333946	04049K	PARTICIPANT	\N	PRESENT	0
333957	333956	14261S	PARTICIPANT	\N	PRESENT	0
333958	333956	14083S	PARTICIPANT	\N	PRESENT	0
333960	333956	14034U	PARTICIPANT	\N	PRESENT	0
333961	333956	04049K	PARTICIPANT	\N	PRESENT	0
333962	333956	19671E	PARTICIPANT	\N	PRESENT	0
333963	333956	14253S	PARTICIPANT	\N	PRESENT	0
333965	333956	14051J	PARTICIPANT	\N	PRESENT	0
333966	333956	14121F	PARTICIPANT	\N	PRESENT	0
333968	333967	14261S	PARTICIPANT	\N	PRESENT	0
333969	333967	19575F	PARTICIPANT	\N	PRESENT	0
333970	333967	14083S	PARTICIPANT	\N	PRESENT	0
333971	333967	04049K	PARTICIPANT	\N	PRESENT	0
333972	333967	19671E	PARTICIPANT	\N	PRESENT	0
333973	333967	14265W	PARTICIPANT	\N	PRESENT	0
333974	333967	04088S	PARTICIPANT	\N	PRESENT	0
333980	333975	14083S	PARTICIPANT	\N	PRESENT	0
333982	333975	14187A	PARTICIPANT	\N	PRESENT	0
333983	333975	04049K	PARTICIPANT	\N	PRESENT	0
333984	333975	14205J	PARTICIPANT	\N	PRESENT	0
333985	333975	19671E	PARTICIPANT	\N	PRESENT	0
333986	333975	14265W	PARTICIPANT	\N	PRESENT	0
337673	337672	08044W	PARTICIPANT	\N	PRESENT	0
337694	337676	05008E	PRESIDENT	0	PRESENT	0
337695	337676	04047H	PARTICIPANT	\N	PRESENT	0
337696	337676	01024M	PARTICIPANT	\N	PRESENT	0
337697	337676	19447X	PARTICIPANT	\N	PRESENT	0
337698	337676	01028R	PARTICIPANT	\N	PRESENT	0
337699	337676	11072N	PARTICIPANT	\N	PRESENT	0
337700	337676	19629C	PARTICIPANT	\N	PRESENT	0
337702	337676	14215L	PARTICIPANT	\N	PRESENT	0
337703	337676	19649G	PARTICIPANT	\N	PRESENT	0
337717	337680	05008E	PRESIDENT	0	PRESENT	0
337718	337680	04047H	PARTICIPANT	\N	PRESENT	0
337719	337680	01024M	PARTICIPANT	\N	PRESENT	0
337720	337680	19447X	PARTICIPANT	\N	PRESENT	0
337721	337680	01028R	PARTICIPANT	\N	PRESENT	0
337722	337680	11072N	PARTICIPANT	\N	PRESENT	0
337723	337680	19629C	PARTICIPANT	\N	PRESENT	0
337724	337680	14215L	PARTICIPANT	\N	PRESENT	0
337726	337680	19649G	PARTICIPANT	\N	PRESENT	0
337746	337745	04035D	PARTICIPANT	\N	PRESENT	0
337747	337745	14087W	PARTICIPANT	\N	PRESENT	0
337748	337745	11026G	PARTICIPANT	\N	PRESENT	0
337749	337745	14241N	PARTICIPANT	\N	PRESENT	0
337750	337745	07033P	PARTICIPANT	\N	PRESENT	0
340176	338404	19553Y	PARTICIPANT	\N	PRESENT	0
340181	338395	86034E	PARTICIPANT	\N	PRESENT	0
340182	338395	04092N	PARTICIPANT	\N	PRESENT	0
340183	338395	01034P	PARTICIPANT	\N	PRESENT	0
340186	338395	14331P	PARTICIPANT	\N	PRESENT	0
340187	338395	08034U	PARTICIPANT	\N	PRESENT	0
340188	338395	14081Q	PARTICIPANT	\N	PRESENT	0
340189	338395	12041X	PARTICIPANT	\N	PRESENT	0
340190	338395	96004D	PARTICIPANT	\N	PRESENT	0
340191	338395	01057W	PARTICIPANT	\N	PRESENT	0
340192	338395	14217N	PARTICIPANT	\N	PRESENT	0
340193	338395	19399H	PARTICIPANT	\N	PRESENT	0
340194	338395	99004R	PARTICIPANT	\N	PRESENT	0
340195	338395	19593H	PARTICIPANT	\N	PRESENT	0
340196	338395	19719D	PARTICIPANT	\N	PRESENT	0
340197	338395	14219Q	PARTICIPANT	\N	PRESENT	0
340198	338395	11040E	PARTICIPANT	\N	PRESENT	0
340199	338395	14357A	PARTICIPANT	\N	PRESENT	0
340200	338395	19711U	PARTICIPANT	\N	PRESENT	0
340201	338395	19421M	PARTICIPANT	\N	PRESENT	0
340202	338395	11097X	PARTICIPANT	\N	PRESENT	0
340203	338395	14055N	PARTICIPANT	\N	PRESENT	0
340204	338395	19703U	PARTICIPANT	\N	PRESENT	0
340205	338395	19762G	PARTICIPANT	\N	PRESENT	0
340206	338395	11070L	PARTICIPANT	\N	PRESENT	0
340207	338395	19695N	PARTICIPANT	\N	PRESENT	0
340208	338395	19515S	PARTICIPANT	\N	PRESENT	0
340209	338395	11083R	PARTICIPANT	\N	PRESENT	0
340210	338395	04034C	PARTICIPANT	\N	PRESENT	0
340211	338395	08052W	PARTICIPANT	\N	PRESENT	0
340212	338395	14281W	PARTICIPANT	\N	PRESENT	0
340213	338395	19727D	PARTICIPANT	\N	PRESENT	0
340214	338395	11067R	PARTICIPANT	\N	PRESENT	0
340215	338395	14033T	PARTICIPANT	\N	PRESENT	0
340216	338395	19441R	PARTICIPANT	\N	PRESENT	0
340217	338395	19521Q	PARTICIPANT	\N	PRESENT	0
340218	338395	19747H	PARTICIPANT	\N	PRESENT	0
340219	338395	19697Q	PARTICIPANT	\N	PRESENT	0
340220	338395	11031D	PARTICIPANT	\N	PRESENT	0
340221	338395	19758L	PARTICIPANT	\N	PRESENT	0
340222	338395	19760E	PARTICIPANT	\N	PRESENT	0
340223	338395	19689Q	PARTICIPANT	\N	PRESENT	0
340224	338395	19649G	PARTICIPANT	\N	PRESENT	0
340225	338395	19289C	PARTICIPANT	\N	PRESENT	0
340226	338395	11012A	PARTICIPANT	\N	PRESENT	0
340227	338395	88008L	PARTICIPANT	\N	PRESENT	0
340228	338395	11085T	PARTICIPANT	\N	PRESENT	0
340229	338395	19569H	PARTICIPANT	\N	PRESENT	0
340230	338395	19503N	PARTICIPANT	\N	PRESENT	0
340231	338395	14119M	PARTICIPANT	\N	PRESENT	0
340232	338395	18083K	PARTICIPANT	\N	PRESENT	0
340233	338395	19693L	PARTICIPANT	\N	PRESENT	0
340234	338395	04097T	PARTICIPANT	\N	PRESENT	0
340235	338395	98024R	PARTICIPANT	\N	PRESENT	0
340236	338395	04033B	PARTICIPANT	\N	PRESENT	0
340237	338395	11074Q	PARTICIPANT	\N	PRESENT	0
340238	338395	14329V	PARTICIPANT	\N	PRESENT	0
340239	338395	11045K	PARTICIPANT	\N	PRESENT	0
340240	338395	08011M	PARTICIPANT	\N	PRESENT	0
340241	338395	14026U	PARTICIPANT	\N	PRESENT	0
340242	338395	07004J	PARTICIPANT	\N	PRESENT	0
340243	338395	10006L	PARTICIPANT	\N	PRESENT	0
340244	338395	19647E	PARTICIPANT	\N	PRESENT	0
340245	338395	04085P	PARTICIPANT	\N	PRESENT	0
340246	338395	14239U	PARTICIPANT	\N	PRESENT	0
358141	345218	95030B	PARTICIPANT	\N	PRESENT	0
358142	345218	14211G	PARTICIPANT	\N	PRESENT	0
358143	345218	14259Y	PARTICIPANT	\N	PRESENT	0
358144	345218	14041T	PARTICIPANT	\N	PRESENT	0
358145	345218	14191V	PARTICIPANT	\N	PRESENT	0
358146	345218	19768N	PARTICIPANT	\N	PRESENT	0
358147	345218	19593H	PARTICIPANT	\N	PRESENT	0
358149	345218	19731Y	PARTICIPANT	\N	PRESENT	0
358150	345218	19611R	PARTICIPANT	\N	PRESENT	0
358151	345218	17583W	PARTICIPANT	\N	PRESENT	0
358152	345218	19693L	PARTICIPANT	\N	PRESENT	0
358153	345218	19335Q	PARTICIPANT	\N	PRESENT	0
358154	345218	19683J	PARTICIPANT	\N	PRESENT	0
358155	345218	19479G	PARTICIPANT	\N	PRESENT	0
358156	345218	14053L	PARTICIPANT	\N	PRESENT	0
358157	345218	19643A	PARTICIPANT	\N	PRESENT	0
358158	345218	14221J	PARTICIPANT	\N	PRESENT	0
358159	345218	11104D	PARTICIPANT	\N	PRESENT	0
358160	345218	19347U	PARTICIPANT	\N	PRESENT	0
358161	345218	19701S	PARTICIPANT	\N	PRESENT	0
358162	345218	87003B	PARTICIPANT	\N	PRESENT	0
358163	345218	15447F	PARTICIPANT	\N	PRESENT	0
358164	345218	19794Q	PARTICIPANT	\N	PRESENT	0
358165	345218	19503N	PARTICIPANT	\N	PRESENT	0
358166	345218	04049K	PARTICIPANT	\N	PRESENT	0
358167	345218	07033P	PARTICIPANT	\N	PRESENT	0
358168	345218	11072N	PARTICIPANT	\N	PRESENT	0
358169	345218	14207L	PARTICIPANT	\N	PRESENT	0
358170	345218	98022P	PARTICIPANT	\N	PRESENT	0
358171	345218	19581D	PARTICIPANT	\N	PRESENT	0
358172	345218	14029X	PARTICIPANT	\N	PRESENT	0
358175	345218	19515S	PARTICIPANT	\N	PRESENT	0
358179	345218	11103C	PARTICIPANT	\N	PRESENT	0
358181	345218	01043Q	PARTICIPANT	\N	PRESENT	0
358182	345218	19533U	PARTICIPANT	\N	PRESENT	0
358185	345218	14219Q	PARTICIPANT	\N	PRESENT	0
358188	345218	14201E	PARTICIPANT	\N	PRESENT	0
358190	345218	14059S	PARTICIPANT	\N	PRESENT	0
358191	345218	11066Q	PARTICIPANT	\N	PRESENT	0
358193	345218	14227Q	PARTICIPANT	\N	PRESENT	0
358196	345218	08031R	PARTICIPANT	\N	PRESENT	0
358198	345218	19619A	PARTICIPANT	\N	PRESENT	0
358199	345218	14159V	PARTICIPANT	\N	PRESENT	0
358203	345218	04059M	PARTICIPANT	\N	PRESENT	0
358206	345218	14028W	PARTICIPANT	\N	PRESENT	0
358208	345218	04038G	PARTICIPANT	\N	PRESENT	0
358210	345218	19637C	PARTICIPANT	\N	PRESENT	0
358211	345218	19691J	PARTICIPANT	\N	PRESENT	0
358212	345218	16685X	PARTICIPANT	\N	PRESENT	0
358213	345218	19563B	PARTICIPANT	\N	PRESENT	0
358214	345218	08055A	PARTICIPANT	\N	PRESENT	0
358215	345218	10015M	PARTICIPANT	\N	PRESENT	0
358216	345218	14253S	PARTICIPANT	\N	PRESENT	0
358217	345218	08061X	PARTICIPANT	\N	PRESENT	0
358218	345218	19369B	PARTICIPANT	\N	PRESENT	0
358219	345218	14231L	PARTICIPANT	\N	PRESENT	0
358220	345218	19725B	PARTICIPANT	\N	PRESENT	0
358221	345218	19599P	PARTICIPANT	\N	PRESENT	0
358222	345218	11031D	PARTICIPANT	\N	PRESENT	0
358223	345218	14281W	PARTICIPANT	\N	PRESENT	0
358225	345218	19760E	PARTICIPANT	\N	PRESENT	0
358226	345218	04085P	PARTICIPANT	\N	PRESENT	0
358227	345218	14235Q	PARTICIPANT	\N	PRESENT	0
358228	345218	04045F	PARTICIPANT	\N	PRESENT	0
358229	345218	11085T	PARTICIPANT	\N	PRESENT	0
358230	345218	19723Y	PARTICIPANT	\N	PRESENT	0
358231	345218	19739H	PARTICIPANT	\N	PRESENT	0
358232	345218	95037J	PARTICIPANT	\N	PRESENT	0
358233	345218	08045X	PARTICIPANT	\N	PRESENT	0
358234	345218	17779H	PARTICIPANT	\N	PRESENT	0
358235	345218	19687N	PARTICIPANT	\N	PRESENT	0
358236	345218	19695N	PARTICIPANT	\N	PRESENT	0
358237	345218	01028R	PARTICIPANT	\N	PRESENT	0
358238	345218	14257W	PARTICIPANT	\N	PRESENT	0
358239	345218	19349W	PARTICIPANT	\N	PRESENT	0
358240	345218	19329S	PARTICIPANT	\N	PRESENT	0
358241	345218	04034C	PARTICIPANT	\N	PRESENT	0
358242	345218	98029W	PARTICIPANT	\N	PRESENT	0
358243	345218	19253P	PARTICIPANT	\N	PRESENT	0
358244	345218	19629C	PARTICIPANT	\N	PRESENT	0
358245	345218	11040E	PARTICIPANT	\N	PRESENT	0
358246	345218	14021P	PARTICIPANT	\N	PRESENT	0
358247	345218	14111D	PARTICIPANT	\N	PRESENT	0
358248	345218	14151M	PARTICIPANT	\N	PRESENT	0
358249	345218	12041X	PARTICIPANT	\N	PRESENT	0
358250	345218	19758L	PARTICIPANT	\N	PRESENT	0
358251	345218	11033F	PARTICIPANT	\N	PRESENT	0
358252	345218	11077T	PARTICIPANT	\N	PRESENT	0
358253	345218	95063L	PARTICIPANT	\N	PRESENT	0
358254	345218	08024S	PARTICIPANT	\N	PRESENT	0
358255	345218	19301E	PARTICIPANT	\N	PRESENT	0
358256	345218	14039A	PARTICIPANT	\N	PRESENT	0
358257	345218	11012A	PARTICIPANT	\N	PRESENT	0
358258	345218	14034U	PARTICIPANT	\N	PRESENT	0
358259	345218	08049C	PARTICIPANT	\N	PRESENT	0
358260	345218	14241N	PARTICIPANT	\N	PRESENT	0
358261	345218	11099A	PARTICIPANT	\N	PRESENT	0
358262	345218	19553Y	PARTICIPANT	\N	PRESENT	0
358263	345218	14251Q	PARTICIPANT	\N	PRESENT	0
358264	345218	19585H	PARTICIPANT	\N	PRESENT	0
358265	345218	19545Y	PARTICIPANT	\N	PRESENT	0
358266	345218	04057K	PARTICIPANT	\N	PRESENT	0
358267	345218	19681G	PARTICIPANT	\N	PRESENT	0
358268	345218	14055N	PARTICIPANT	\N	PRESENT	0
358269	345218	19511N	PARTICIPANT	\N	PRESENT	0
358270	345218	08052W	PARTICIPANT	\N	PRESENT	0
358271	345218	11074Q	PARTICIPANT	\N	PRESENT	0
358272	345218	14225N	PARTICIPANT	\N	PRESENT	0
358273	345218	17637T	PARTICIPANT	\N	PRESENT	0
358274	345218	19649G	PARTICIPANT	\N	PRESENT	0
358275	345218	19711U	PARTICIPANT	\N	PRESENT	0
358276	345218	19647E	PARTICIPANT	\N	PRESENT	0
358277	345218	86034E	PARTICIPANT	\N	PRESENT	0
358278	345218	08043V	PARTICIPANT	\N	PRESENT	0
358279	345218	08012N	PARTICIPANT	\N	PRESENT	0
358280	345218	19727D	PARTICIPANT	\N	PRESENT	0
358281	345218	14121F	PARTICIPANT	\N	PRESENT	0
358282	345218	04035D	PARTICIPANT	\N	PRESENT	0
358283	345218	08017T	PARTICIPANT	\N	PRESENT	0
358284	345218	95062K	PARTICIPANT	\N	PRESENT	0
358285	345218	19251M	PARTICIPANT	\N	PRESENT	0
358286	345218	19413M	PARTICIPANT	\N	PRESENT	0
358287	345218	96004D	PARTICIPANT	\N	PRESENT	0
358288	345218	01058X	PARTICIPANT	\N	PRESENT	0
358289	345218	08058D	PARTICIPANT	\N	PRESENT	0
358290	345218	99004R	PARTICIPANT	\N	PRESENT	0
358291	345218	19551W	PARTICIPANT	\N	PRESENT	0
358292	345218	08035V	PARTICIPANT	\N	PRESENT	0
358293	345218	04047H	PARTICIPANT	\N	PRESENT	0
358294	345218	19679N	PARTICIPANT	\N	PRESENT	0
358295	345218	11110B	PARTICIPANT	\N	PRESENT	0
358296	345218	04097T	PARTICIPANT	\N	PRESENT	0
358297	345218	19631V	PARTICIPANT	\N	PRESENT	0
358298	345218	08039A	PARTICIPANT	\N	PRESENT	0
358299	345218	08010L	PARTICIPANT	\N	PRESENT	0
358300	345218	08020N	PARTICIPANT	\N	PRESENT	0
358301	345218	04042C	PARTICIPANT	\N	PRESENT	0
358302	345218	11041F	PARTICIPANT	\N	PRESENT	0
358303	345218	19549D	PARTICIPANT	\N	PRESENT	0
358304	345218	14223L	PARTICIPANT	\N	PRESENT	0
358305	345218	14065Q	PARTICIPANT	\N	PRESENT	0
358306	345218	19766L	PARTICIPANT	\N	PRESENT	0
358307	345218	11054L	PARTICIPANT	\N	PRESENT	0
358308	345218	01057W	PARTICIPANT	\N	PRESENT	0
358309	345218	01062T	PARTICIPANT	\N	PRESENT	0
358310	345218	11090Q	PARTICIPANT	\N	PRESENT	0
358311	345218	19289C	PARTICIPANT	\N	PRESENT	0
358312	345218	19703U	PARTICIPANT	\N	PRESENT	0
358314	345218	11056N	PARTICIPANT	\N	PRESENT	0
358315	345218	19673G	PARTICIPANT	\N	PRESENT	0
358316	345218	14031R	PARTICIPANT	\N	PRESENT	0
358317	345218	19667J	PARTICIPANT	\N	PRESENT	0
358319	345218	19575F	PARTICIPANT	\N	PRESENT	0
358320	345218	14093U	PARTICIPANT	\N	PRESENT	0
358321	345218	19447X	PARTICIPANT	\N	PRESENT	0
358322	345218	04089T	PARTICIPANT	\N	PRESENT	0
358323	345218	19573D	PARTICIPANT	\N	PRESENT	0
358325	345218	08056B	PARTICIPANT	\N	PRESENT	0
358326	345218	19669L	PARTICIPANT	\N	PRESENT	0
358328	345218	11049P	PARTICIPANT	\N	PRESENT	0
358330	345218	11053K	PARTICIPANT	\N	PRESENT	0
358331	345218	14115H	PARTICIPANT	\N	PRESENT	0
358332	345218	14205J	PARTICIPANT	\N	PRESENT	0
358334	345218	95067Q	PARTICIPANT	\N	PRESENT	0
358335	345218	19569H	PARTICIPANT	\N	PRESENT	0
358336	345218	19441R	PARTICIPANT	\N	PRESENT	0
358338	345218	14042U	PARTICIPANT	\N	PRESENT	0
358339	345218	14038Y	PARTICIPANT	\N	PRESENT	0
335742	335739	14089Y	PARTICIPANT	\N	PRESENT	0
335743	335739	04035D	PARTICIPANT	\N	PRESENT	0
335744	335739	04057K	PARTICIPANT	\N	PRESENT	0
335745	335739	14073Q	PARTICIPANT	\N	PRESENT	0
335746	335739	19507S	PARTICIPANT	\N	PRESENT	0
335747	335739	98022P	PARTICIPANT	\N	PRESENT	0
335748	335739	01057W	PARTICIPANT	\N	PRESENT	0
335749	335739	96004D	PRESIDENT	0	PRESENT	0
335750	335739	11083R	PARTICIPANT	\N	PRESENT	0
335751	335739	98050T	PARTICIPANT	\N	PRESENT	0
335752	335739	08043V	PARTICIPANT	\N	EXCUSE	0
335753	335739	14205J	PARTICIPANT	\N	PRESENT	0
335754	335739	14053L	PARTICIPANT	\N	EXCUSE	0
335755	335739	14331P	PARTICIPANT	\N	EXCUSE	0
335756	335739	04061F	PARTICIPANT	\N	EXCUSE	0
335772	335732	14073Q	PARTICIPANT	\N	PRESENT	0
335773	335069	14053L	PARTICIPANT	\N	PRESENT	0
335774	335069	14065Q	PARTICIPANT	\N	PRESENT	0
335775	335069	08045X	PARTICIPANT	\N	PRESENT	0
335776	335069	10015M	PARTICIPANT	\N	PRESENT	0
335777	335069	11026G	PARTICIPANT	\N	PRESENT	0
335778	335069	14001X	PARTICIPANT	\N	PRESENT	0
335779	335069	19543W	PARTICIPANT	\N	PRESENT	0
335780	335069	01024M	PARTICIPANT	\N	PRESENT	0
335781	335069	04044E	PARTICIPANT	\N	PRESENT	0
335782	335069	04038G	PARTICIPANT	\N	PRESENT	0
335783	335069	01028R	PARTICIPANT	\N	PRESENT	0
335784	335069	14231L	PARTICIPANT	\N	PRESENT	0
335785	335069	19447X	PARTICIPANT	\N	PRESENT	0
335786	335069	05008E	PRESIDENT	0	PRESENT	0
335787	335069	14089Y	PARTICIPANT	\N	PRESENT	0
335788	335069	19489J	PARTICIPANT	\N	PRESENT	0
335789	335069	19729F	PARTICIPANT	\N	PRESENT	0
335790	335069	95063L	PARTICIPANT	\N	PRESENT	0
335791	335069	19629C	PARTICIPANT	\N	PRESENT	0
335792	335069	14041T	PARTICIPANT	\N	PRESENT	0
335793	335069	14179A	PARTICIPANT	\N	PRESENT	0
335794	335069	14147R	PARTICIPANT	\N	PRESENT	0
335795	335069	14215L	PARTICIPANT	\N	PRESENT	0
335796	335069	08051V	PARTICIPANT	\N	PRESENT	0
335797	335069	08018U	PARTICIPANT	\N	PRESENT	0
335798	335069	04047H	PARTICIPANT	\N	PRESENT	0
335799	335069	11072N	PARTICIPANT	\N	PRESENT	0
335800	335732	04085P	PARTICIPANT	\N	PRESENT	0
335801	335732	11074Q	PARTICIPANT	\N	PRESENT	0
335802	335732	19631V	PARTICIPANT	\N	PRESENT	0
335803	335732	11067R	PARTICIPANT	\N	PRESENT	0
335804	335732	08052W	PARTICIPANT	\N	PRESENT	0
335805	335732	19525U	PARTICIPANT	\N	PRESENT	0
335806	335732	19782L	PARTICIPANT	\N	PRESENT	0
335807	335732	19651A	PARTICIPANT	\N	PRESENT	0
335808	335732	14001X	PARTICIPANT	\N	PRESENT	0
335809	335732	19611R	PARTICIPANT	\N	PRESENT	0
335810	335732	14201E	PARTICIPANT	\N	PRESENT	0
335811	335732	14231L	PARTICIPANT	\N	PRESENT	0
335812	335732	16685X	PARTICIPANT	\N	PRESENT	0
335813	335732	14221J	PARTICIPANT	\N	PRESENT	0
335814	335732	19649G	PARTICIPANT	\N	PRESENT	0
335815	335732	19545Y	PARTICIPANT	\N	PRESENT	0
335816	335732	04057K	PARTICIPANT	\N	PRESENT	0
335817	335732	14103D	PARTICIPANT	\N	PRESENT	0
335818	335732	14055N	PARTICIPANT	\N	PRESENT	0
335819	335732	19629C	PARTICIPANT	\N	PRESENT	0
335820	335732	98035U	PARTICIPANT	\N	PRESENT	0
335821	335732	01028R	PARTICIPANT	\N	PRESENT	0
335822	335732	08045X	PARTICIPANT	\N	PRESENT	0
335823	335732	14065Q	PARTICIPANT	\N	PRESENT	0
335824	335732	08068F	PARTICIPANT	\N	PRESENT	0
335825	335732	19489J	PARTICIPANT	\N	PRESENT	0
335826	335732	11072N	PARTICIPANT	\N	PRESENT	0
335827	335732	19689Q	PARTICIPANT	\N	PRESENT	0
335828	335732	95037J	PARTICIPANT	\N	PRESENT	0
335829	335732	14235Q	PARTICIPANT	\N	PRESENT	0
335830	335732	11056N	PARTICIPANT	\N	PRESENT	0
335831	335732	04038G	PARTICIPANT	\N	PRESENT	0
335832	335732	12041X	PARTICIPANT	\N	PRESENT	0
335833	335732	11083R	PARTICIPANT	\N	PRESENT	0
335834	335732	95063L	PARTICIPANT	\N	PRESENT	0
335835	335732	19725B	PARTICIPANT	\N	PRESENT	0
335836	335732	14207L	PARTICIPANT	\N	PRESENT	0
335837	335732	19695N	PARTICIPANT	\N	PRESENT	0
335838	335732	19349W	PARTICIPANT	\N	PRESENT	0
335839	335732	11027H	PARTICIPANT	\N	PRESENT	0
335840	335732	19717B	PARTICIPANT	\N	PRESENT	0
335841	335732	08049C	PARTICIPANT	\N	PRESENT	0
335842	335732	19691J	PARTICIPANT	\N	PRESENT	0
335843	335732	08056B	PARTICIPANT	\N	PRESENT	0
335844	335732	88008L	PARTICIPANT	\N	PRESENT	0
335845	335732	11012A	PARTICIPANT	\N	PRESENT	0
335846	335732	11066Q	PARTICIPANT	\N	PRESENT	0
335847	335732	19591F	PARTICIPANT	\N	PRESENT	0
335848	335732	19319Q	PARTICIPANT	\N	PRESENT	0
335849	335732	14159V	PARTICIPANT	\N	PRESENT	0
335850	335732	19329S	PARTICIPANT	\N	PRESENT	0
335851	335732	08012N	PARTICIPANT	\N	PRESENT	0
335852	335732	11040E	PARTICIPANT	\N	PRESENT	0
335853	335732	11033F	PARTICIPANT	\N	PRESENT	0
335854	335732	19593H	PARTICIPANT	\N	PRESENT	0
335855	335732	11064N	PARTICIPANT	\N	PRESENT	0
335856	335732	19347U	PARTICIPANT	\N	PRESENT	0
335857	335732	19565D	PARTICIPANT	\N	PRESENT	0
335858	335732	19697Q	PARTICIPANT	\N	PRESENT	0
335859	335732	19687N	PARTICIPANT	\N	PRESENT	0
335860	335732	14261S	PARTICIPANT	\N	PRESENT	0
335861	335732	19719D	PARTICIPANT	\N	PRESENT	0
335862	335732	08061X	PARTICIPANT	\N	PRESENT	0
335863	335732	14239U	PARTICIPANT	\N	PRESENT	0
335864	335732	08073C	PARTICIPANT	\N	PRESENT	0
335865	335732	11077T	PARTICIPANT	\N	PRESENT	0
335866	335732	19289C	PARTICIPANT	\N	PRESENT	0
335867	335732	14251Q	PARTICIPANT	\N	PRESENT	0
335868	335732	08055A	PARTICIPANT	\N	PRESENT	0
335869	335732	01062T	PARTICIPANT	\N	PRESENT	0
335870	335732	14211G	PARTICIPANT	\N	PRESENT	0
335871	335732	14039A	PARTICIPANT	\N	PRESENT	0
335872	335732	14109K	PARTICIPANT	\N	PRESENT	0
335873	335732	11041F	PARTICIPANT	\N	PRESENT	0
335874	335732	19711U	PARTICIPANT	\N	PRESENT	0
335875	335732	14030Q	PARTICIPANT	\N	PRESENT	0
335876	335732	98024R	PARTICIPANT	\N	PRESENT	0
335877	335732	14157T	PARTICIPANT	\N	PRESENT	0
335878	335732	04097T	PARTICIPANT	\N	PRESENT	0
335879	335732	14229S	PARTICIPANT	\N	PRESENT	0
335880	335732	08053X	PARTICIPANT	\N	PRESENT	0
335881	335732	96004D	PARTICIPANT	\N	PRESENT	0
335883	335732	19669L	PARTICIPANT	\N	PRESENT	0
335884	335732	08058D	PARTICIPANT	\N	PRESENT	0
335885	335732	14121F	PARTICIPANT	\N	PRESENT	0
335886	335732	19599P	PARTICIPANT	\N	PRESENT	0
335887	335732	99004R	PARTICIPANT	\N	PRESENT	0
335888	335732	19551W	PARTICIPANT	\N	PRESENT	0
335889	335732	14227Q	PARTICIPANT	\N	PRESENT	0
335890	335732	95030B	PARTICIPANT	\N	PRESENT	0
335891	335732	19503N	PARTICIPANT	\N	PRESENT	0
335892	335732	19721W	PARTICIPANT	\N	PRESENT	0
335893	335732	08039A	PARTICIPANT	\N	PRESENT	0
335894	335732	19251M	PARTICIPANT	\N	PRESENT	0
335895	335732	08069G	PARTICIPANT	\N	PRESENT	0
335896	335732	11045K	PARTICIPANT	\N	PRESENT	0
335897	335732	04086Q	PARTICIPANT	\N	PRESENT	0
335898	335732	04092N	PARTICIPANT	\N	PRESENT	0
335899	335732	19301E	PARTICIPANT	\N	PRESENT	0
335900	335732	14051J	PARTICIPANT	\N	PRESENT	0
335901	335732	19527W	PARTICIPANT	\N	PRESENT	0
335902	335732	04044E	PARTICIPANT	\N	PRESENT	0
335903	335732	14063N	PARTICIPANT	\N	PRESENT	0
335904	335732	15447F	PARTICIPANT	\N	PRESENT	0
335905	335732	11104D	PARTICIPANT	\N	PRESENT	0
335906	335732	14169X	PARTICIPANT	\N	PRESENT	0
335907	335732	14225N	PARTICIPANT	\N	PRESENT	0
335908	335732	19679N	PARTICIPANT	\N	PRESENT	0
335909	335732	19549D	PARTICIPANT	\N	PRESENT	0
335910	335732	10015M	PARTICIPANT	\N	PRESENT	0
335911	335732	04071H	PARTICIPANT	\N	PRESENT	0
335912	335732	11043H	PARTICIPANT	\N	PRESENT	0
335913	335732	19333N	PARTICIPANT	\N	PRESENT	0
335914	335732	08028W	PARTICIPANT	\N	PRESENT	0
335915	335732	08017T	PARTICIPANT	\N	PRESENT	0
335916	335732	04033B	PARTICIPANT	\N	PRESENT	0
335917	335732	14187A	PARTICIPANT	\N	PRESENT	0
335918	335732	14081Q	PARTICIPANT	\N	PRESENT	0
335919	335732	14071N	PARTICIPANT	\N	PRESENT	0
335920	335732	11097X	PARTICIPANT	\N	PRESENT	0
335921	335732	08043V	PARTICIPANT	\N	PRESENT	0
335922	335732	19515S	PARTICIPANT	\N	PRESENT	0
335923	335732	11080N	PARTICIPANT	\N	PRESENT	0
335924	335732	19766L	PARTICIPANT	\N	PRESENT	0
335925	335732	14259Y	PARTICIPANT	\N	PRESENT	0
358662	358661	19621T	PARTICIPANT	\N	PRESENT	0
358663	358661	08043V	PARTICIPANT	\N	PRESENT	0
358665	358664	14073Q	PARTICIPANT	\N	PRESENT	0
358666	358664	19533U	PARTICIPANT	\N	PRESENT	0
358667	358664	19593H	PARTICIPANT	\N	PRESENT	0
358678	358672	14073Q	PARTICIPANT	\N	PRESENT	0
358679	358672	19533U	PARTICIPANT	\N	PRESENT	0
358681	358672	19593H	PARTICIPANT	\N	PRESENT	0
358683	358672	08017T	PARTICIPANT	\N	PRESENT	0
358684	358672	14123H	PARTICIPANT	\N	PRESENT	0
358717	358714	14073Q	PARTICIPANT	\N	PRESENT	0
360547	360546	14053L	PARTICIPANT	\N	PRESENT	0
360550	360549	14065Q	PARTICIPANT	\N	PRESENT	0
360551	360549	14053L	PARTICIPANT	\N	PRESENT	0
360553	360552	14053L	PARTICIPANT	\N	PRESENT	0
360699	360698	08043V	PARTICIPANT	\N	PRESENT	0
360700	360698	14053L	PARTICIPANT	\N	PRESENT	0
360701	360698	14083S	PARTICIPANT	\N	PRESENT	0
360702	360698	14213J	PARTICIPANT	\N	PRESENT	0
360703	360698	19723Y	PARTICIPANT	\N	PRESENT	0
360704	360698	08015R	PARTICIPANT	\N	PRESENT	0
360705	360698	14031R	PARTICIPANT	\N	PRESENT	0
360706	360698	19745F	PARTICIPANT	\N	PRESENT	0
360707	360698	17583W	PARTICIPANT	\N	PRESENT	0
360708	360698	95062K	PARTICIPANT	\N	PRESENT	0
360709	360698	14051J	PARTICIPANT	\N	PRESENT	0
360710	360698	14157T	PARTICIPANT	\N	PRESENT	0
361132	345227	80013X	PARTICIPANT	\N	PRESENT	0
361133	345227	19794Q	PARTICIPANT	\N	PRESENT	0
361134	345227	19631V	PARTICIPANT	\N	PRESENT	0
361135	345227	14093U	PARTICIPANT	\N	PRESENT	0
361136	345227	19703U	PARTICIPANT	\N	PRESENT	0
361137	345227	19399H	PARTICIPANT	\N	PRESENT	0
361138	358915	19673G	PARTICIPANT	\N	PRESENT	0
361139	358915	14231L	PARTICIPANT	\N	PRESENT	0
361140	358915	08043V	PARTICIPANT	\N	PRESENT	0
361141	345227	17583W	PARTICIPANT	\N	PRESENT	0
361143	345227	19691J	PARTICIPANT	\N	PRESENT	0
361145	361144	11070L	PARTICIPANT	\N	PRESENT	0
361146	361144	19647E	PARTICIPANT	\N	PRESENT	0
361148	361147	11070L	PARTICIPANT	\N	PRESENT	0
361149	361147	19647E	PARTICIPANT	\N	PRESENT	0
361151	361150	14327T	PARTICIPANT	\N	PRESENT	0
361152	345227	19413M	PARTICIPANT	\N	PRESENT	0
361153	345227	14327T	PARTICIPANT	\N	PRESENT	0
361155	361154	04040A	PARTICIPANT	\N	PRESENT	0
361156	361154	14069U	PARTICIPANT	\N	PRESENT	0
361157	361154	19643A	PARTICIPANT	\N	PRESENT	0
361158	361154	92040Q	PARTICIPANT	\N	PRESENT	0
361159	361154	04044E	PARTICIPANT	\N	PRESENT	0
361160	345227	04057K	PARTICIPANT	\N	PRESENT	0
361161	345227	98050T	PARTICIPANT	\N	PRESENT	0
361163	361162	19621T	PARTICIPANT	\N	PRESENT	0
361165	361164	19621T	PARTICIPANT	\N	PRESENT	0
361167	361166	19621T	PARTICIPANT	\N	PRESENT	0
361168	345227	14257W	PARTICIPANT	\N	PRESENT	0
361171	356663	11010L	PARTICIPANT	\N	EXCUSE	0
361172	356666	11010L	PARTICIPANT	\N	EXCUSE	0
361173	357152	11048N	PARTICIPANT	\N	EXCUSE	0
361178	361177	14065Q	PARTICIPANT	\N	PRESENT	0
361179	361177	14089Y	PARTICIPANT	\N	PRESENT	0
361180	361177	14357A	PARTICIPANT	\N	PRESENT	0
361181	361177	11083R	PARTICIPANT	\N	PRESENT	0
361182	361177	14026U	PARTICIPANT	\N	PRESENT	0
361183	361177	19725B	PARTICIPANT	\N	PRESENT	0
361184	361177	14061L	PARTICIPANT	\N	PRESENT	0
361185	361177	14073Q	PARTICIPANT	\N	PRESENT	0
361186	361177	19563B	PARTICIPANT	\N	PRESENT	0
361187	361177	04057K	PARTICIPANT	\N	PRESENT	0
361130	345227	95030B	PARTICIPANT	\N	PRESENT	0
361131	345227	11012A	PARTICIPANT	\N	PRESENT	0
361188	361177	14135M	PARTICIPANT	\N	PRESENT	0
361189	361177	10015M	PRESIDENT	0	PRESENT	0
361190	361177	14229S	PARTICIPANT	\N	PRESENT	0
361191	361177	98035U	PARTICIPANT	\N	PRESENT	0
361192	361177	14237S	PARTICIPANT	\N	PRESENT	0
361241	345228	19441R	PARTICIPANT	\N	PRESENT	0
361194	344794	14030Q	PRESIDENT	0	PRESENT	0
361195	344794	08043V	PARTICIPANT	\N	PRESENT	0
361196	344794	19701S	PARTICIPANT	\N	PRESENT	0
361197	344794	80013X	PARTICIPANT	\N	PRESENT	0
361198	344794	19693L	PARTICIPANT	\N	PRESENT	0
361199	344794	14217N	PARTICIPANT	\N	PRESENT	0
361200	344794	19731Y	PARTICIPANT	\N	PRESENT	0
361201	344794	08031R	PARTICIPANT	\N	PRESENT	0
361202	344794	19749K	PARTICIPANT	\N	PRESENT	0
361203	344794	07029T	PARTICIPANT	\N	EXCUSE	0
361204	344794	14179A	PARTICIPANT	\N	EXCUSE	0
361205	344794	19643A	PARTICIPANT	\N	EXCUSE	0
361206	361177	14331P	PARTICIPANT	\N	EXCUSE	0
361207	345228	11027H	PARTICIPANT	\N	PRESENT	0
361208	345228	14051J	PARTICIPANT	\N	PRESENT	0
361209	345228	11056N	PARTICIPANT	\N	PRESENT	0
361210	345228	14089Y	PARTICIPANT	\N	PRESENT	0
361211	345228	14327T	PARTICIPANT	\N	PRESENT	0
361212	345228	11012A	PARTICIPANT	\N	PRESENT	0
361213	345228	14195A	PARTICIPANT	\N	PRESENT	0
361214	345228	19387D	PARTICIPANT	\N	PRESENT	0
361215	345228	19629C	PARTICIPANT	\N	PRESENT	0
361216	345228	08031R	PARTICIPANT	\N	PRESENT	0
361217	345228	14103D	PARTICIPANT	\N	PRESENT	0
361218	345228	19335Q	PARTICIPANT	\N	PRESENT	0
361219	345228	19731Y	PARTICIPANT	\N	PRESENT	0
361220	345228	97011G	PARTICIPANT	\N	PRESENT	0
361221	345228	19711U	PARTICIPANT	\N	PRESENT	0
361222	345228	14061L	PARTICIPANT	\N	PRESENT	0
361223	345228	01057W	PARTICIPANT	\N	PRESENT	0
361224	345228	19794Q	PARTICIPANT	\N	PRESENT	0
361225	345228	19333N	PARTICIPANT	\N	PRESENT	0
361226	345228	14115H	PARTICIPANT	\N	PRESENT	0
361227	345228	95030B	PARTICIPANT	\N	PRESENT	0
361228	345228	19575F	PARTICIPANT	\N	PRESENT	0
361229	345228	19543W	PARTICIPANT	\N	PRESENT	0
361230	345228	14073Q	PARTICIPANT	\N	PRESENT	0
361231	345228	14157T	PARTICIPANT	\N	PRESENT	0
361232	345228	14159V	PARTICIPANT	\N	PRESENT	0
361233	345228	14237S	PARTICIPANT	\N	PRESENT	0
361234	345228	14257W	PARTICIPANT	\N	PRESENT	0
361235	345228	11065P	PARTICIPANT	\N	PRESENT	0
361236	345228	14221J	PARTICIPANT	\N	PRESENT	0
361237	345228	11053K	PARTICIPANT	\N	PRESENT	0
361238	345228	19525U	PARTICIPANT	\N	PRESENT	0
361239	361177	96004D	PARTICIPANT	\N	EXCUSE	0
361243	345228	14021P	PARTICIPANT	\N	PRESENT	0
361244	345228	08015R	PARTICIPANT	\N	PRESENT	0
361245	345228	14041T	PARTICIPANT	\N	PRESENT	0
361246	345228	11049P	PARTICIPANT	\N	PRESENT	0
361249	345228	80013X	PARTICIPANT	\N	PRESENT	0
361250	345228	14207L	PARTICIPANT	\N	PRESENT	0
361251	345228	19269X	PARTICIPANT	\N	PRESENT	0
361252	345228	10015M	PARTICIPANT	\N	PRESENT	0
361253	345228	11040E	PARTICIPANT	\N	PRESENT	0
361254	345228	19735D	PARTICIPANT	\N	PRESENT	0
361255	345228	04018C	PARTICIPANT	\N	PRESENT	0
361273	345228	14069U	PARTICIPANT	\N	PRESENT	0
361274	345228	14261S	PARTICIPANT	\N	PRESENT	0
361275	345228	19725B	PARTICIPANT	\N	PRESENT	0
361276	345228	14229S	PARTICIPANT	\N	PRESENT	0
361327	361318	14205J	PARTICIPANT	\N	PRESENT	0
361328	361318	14207L	PARTICIPANT	\N	PRESENT	0
361329	361318	19413M	PARTICIPANT	\N	PRESENT	0
361334	361333	14207L	PARTICIPANT	\N	PRESENT	0
361336	361335	14205J	PARTICIPANT	\N	PRESENT	0
361337	361335	14207L	PARTICIPANT	\N	PRESENT	0
361338	361335	14105F	PARTICIPANT	\N	PRESENT	0
361339	361335	14109K	PARTICIPANT	\N	PRESENT	0
361351	345229	11072N	PARTICIPANT	\N	PRESENT	0
361368	345229	80013X	PARTICIPANT	\N	PRESENT	0
361369	345229	19503N	PARTICIPANT	\N	PRESENT	0
361370	345229	08024S	PARTICIPANT	\N	PRESENT	0
361371	345229	04057K	PARTICIPANT	\N	PRESENT	0
361373	345229	11056N	PARTICIPANT	\N	PRESENT	0
361374	345229	04085P	PARTICIPANT	\N	PRESENT	0
361376	345229	19695N	PARTICIPANT	\N	PRESENT	0
361377	345229	19593H	PARTICIPANT	\N	PRESENT	0
361379	345229	08031R	PARTICIPANT	\N	PRESENT	0
361381	345229	19739H	PARTICIPANT	\N	PRESENT	0
361382	345229	19619A	PARTICIPANT	\N	PRESENT	0
361384	345229	14071N	PARTICIPANT	\N	PRESENT	0
361385	345229	08069G	PARTICIPANT	\N	PRESENT	0
361386	345229	19549D	PARTICIPANT	\N	PRESENT	0
361387	345229	19687N	PARTICIPANT	\N	PRESENT	0
361388	345229	18083K	PARTICIPANT	\N	PRESENT	0
361389	345229	11033F	PARTICIPANT	\N	PRESENT	0
361390	345229	14267Y	PARTICIPANT	\N	PRESENT	0
361391	345229	19581D	PARTICIPANT	\N	PRESENT	0
361392	345229	07029T	PARTICIPANT	\N	PRESENT	0
361393	345229	19762G	PARTICIPANT	\N	PRESENT	0
361394	345229	14038Y	PARTICIPANT	\N	PRESENT	0
337803	337802	19651A	PARTICIPANT	\N	PRESENT	0
337804	337802	14085U	PARTICIPANT	\N	PRESENT	0
337805	337802	04086Q	PARTICIPANT	\N	PRESENT	0
340247	338395	14079W	PARTICIPANT	\N	PRESENT	0
337808	337802	14327T	PARTICIPANT	\N	PRESENT	0
337809	337802	11074Q	PARTICIPANT	\N	PRESENT	0
337810	337802	11048N	PARTICIPANT	\N	PRESENT	0
337822	337820	05008E	PRESIDENT	0	PRESENT	0
337812	337802	01048V	PARTICIPANT	\N	PRESENT	0
337813	337802	19671E	PARTICIPANT	\N	PRESENT	0
337814	337802	08011M	PARTICIPANT	\N	PRESENT	0
337849	337847	05008E	PRESIDENT	0	PRESENT	0
337824	337820	04047H	PARTICIPANT	\N	PRESENT	0
340248	338395	19553Y	PARTICIPANT	\N	PRESENT	0
337825	337820	19629C	PARTICIPANT	\N	PRESENT	0
337826	337820	01024M	PARTICIPANT	\N	PRESENT	0
337827	337820	14215L	PARTICIPANT	\N	PRESENT	0
337828	337820	19649G	PARTICIPANT	\N	PRESENT	0
337829	337820	19447X	PARTICIPANT	\N	PRESENT	0
337851	337847	04047H	PARTICIPANT	\N	PRESENT	0
337852	337847	19629C	PARTICIPANT	\N	PRESENT	0
337832	337820	11072N	PARTICIPANT	\N	PRESENT	0
337833	337820	01028R	PARTICIPANT	\N	PRESENT	0
337853	337847	01024M	PARTICIPANT	\N	PRESENT	0
337854	337847	14215L	PARTICIPANT	\N	PRESENT	0
337855	337847	19649G	PARTICIPANT	\N	PRESENT	0
337856	337847	19447X	PARTICIPANT	\N	PRESENT	0
340249	338395	19669L	PARTICIPANT	\N	PRESENT	0
340250	338395	19383Y	PARTICIPANT	\N	PRESENT	0
337859	337847	11072N	PARTICIPANT	\N	PRESENT	0
337860	337847	01028R	PARTICIPANT	\N	PRESENT	0
340251	338395	17779H	PARTICIPANT	\N	PRESENT	0
340252	338395	19347U	PARTICIPANT	\N	PRESENT	0
340253	338395	19575F	PARTICIPANT	\N	PRESENT	0
340254	338395	04042C	PARTICIPANT	\N	PRESENT	0
340255	338395	14083S	PARTICIPANT	\N	PRESENT	0
340256	338395	19691J	PARTICIPANT	\N	PRESENT	0
340257	338395	02002K	PARTICIPANT	\N	PRESENT	0
340258	338395	19705W	PARTICIPANT	\N	PRESENT	0
340259	338395	19671E	PARTICIPANT	\N	PRESENT	0
340260	338395	14021P	PARTICIPANT	\N	PRESENT	0
340261	338395	11033F	PARTICIPANT	\N	PRESENT	0
340262	338395	19551W	PARTICIPANT	\N	PRESENT	0
340263	338395	11053K	PARTICIPANT	\N	PRESENT	0
340264	338395	11065P	PARTICIPANT	\N	PRESENT	0
340265	338395	14251Q	PARTICIPANT	\N	PRESENT	0
340266	338395	19611R	PARTICIPANT	\N	PRESENT	0
340267	338395	14205J	PARTICIPANT	\N	PRESENT	0
340268	338395	95067Q	PARTICIPANT	\N	PRESENT	0
340269	338395	08069G	PARTICIPANT	\N	PRESENT	0
340270	338395	19543W	PARTICIPANT	\N	PRESENT	0
340271	338395	11027H	PARTICIPANT	\N	PRESENT	0
340272	338395	14213J	PARTICIPANT	\N	PRESENT	0
340273	338395	14259Y	PARTICIPANT	\N	PRESENT	0
340274	338395	01048V	PARTICIPANT	\N	PRESENT	0
340275	338395	04088S	PARTICIPANT	\N	PRESENT	0
340276	338403	19697Q	PARTICIPANT	\N	PRESENT	0
340277	338403	01034P	PARTICIPANT	\N	PRESENT	0
340278	338403	11067R	PARTICIPANT	\N	PRESENT	0
340279	338403	04092N	PRESIDENT	0	PRESENT	0
340280	338403	19569H	PARTICIPANT	\N	PRESENT	0
340281	338403	11097X	PARTICIPANT	\N	PRESENT	0
340282	338403	11045K	PARTICIPANT	\N	PRESENT	0
340283	338403	08052W	PARTICIPANT	\N	PRESENT	0
340284	338403	19691J	PARTICIPANT	\N	PRESENT	0
340285	338403	14026U	PARTICIPANT	\N	PRESENT	0
340286	338403	14239U	PARTICIPANT	\N	PRESENT	0
340287	338403	19703U	PARTICIPANT	\N	PRESENT	0
340288	338403	19727D	PARTICIPANT	\N	PRESENT	0
340289	338403	11031D	PARTICIPANT	\N	PRESENT	0
340290	338403	19553Y	PARTICIPANT	\N	PRESENT	0
340291	338403	14281W	PARTICIPANT	\N	PRESENT	0
340292	338403	14213J	PARTICIPANT	\N	PRESENT	0
340293	338403	14217N	PARTICIPANT	\N	PRESENT	0
340294	338403	10006L	PARTICIPANT	\N	PRESENT	0
340295	338403	98024R	PARTICIPANT	\N	PRESENT	0
340296	338403	19760E	PARTICIPANT	\N	PRESENT	0
340297	338403	08041T	PARTICIPANT	\N	EXCUSE	0
340300	338395	14211G	PARTICIPANT	\N	PRESENT	0
340301	338395	95041E	PARTICIPANT	\N	PRESENT	0
340797	340501	08043V	PARTICIPANT	\N	PRESENT	0
340798	340501	10006L	PRESIDENT	0	PRESENT	0
340799	340501	11083R	PARTICIPANT	\N	PRESENT	0
340800	340501	14213J	PARTICIPANT	\N	PRESENT	0
340801	340501	08031R	PARTICIPANT	\N	PRESENT	0
340802	340501	14147R	PARTICIPANT	\N	PRESENT	0
340803	340501	11067R	PARTICIPANT	\N	PRESENT	0
340804	340501	14223L	PARTICIPANT	\N	PRESENT	0
340805	340501	19749K	PARTICIPANT	\N	PRESENT	0
340806	340501	19533U	PARTICIPANT	\N	PRESENT	0
340807	340501	19723Y	PARTICIPANT	\N	PRESENT	0
340810	340501	14030Q	PARTICIPANT	\N	EXCUSE	0
340811	340501	19553Y	PARTICIPANT	\N	PRESENT	0
340827	340501	11043H	PARTICIPANT	\N	PRESENT	0
340837	340501	19415P	PARTICIPANT	\N	PRESENT	0
341955	340480	04045F	PARTICIPANT	\N	EXCUSE	0
342818	342817	04040A	PRESIDENT	0	PRESENT	0
342938	342817	04044E	PARTICIPANT	\N	EXCUSE	0
342999	342817	08038Y	PARTICIPANT	\N	EXCUSE	0
343004	342817	19735D	PARTICIPANT	\N	EXCUSE	0
345783	345782	04085P	PARTICIPANT	\N	PRESENT	0
345784	345782	04059M	PARTICIPANT	\N	PRESENT	0
345785	345782	96004D	PARTICIPANT	\N	PRESENT	0
345786	345782	11053K	PARTICIPANT	\N	PRESENT	0
345787	345782	11027H	PARTICIPANT	\N	PRESENT	0
345788	345782	14215L	PARTICIPANT	\N	PRESENT	0
345789	345782	19521Q	PARTICIPANT	\N	PRESENT	0
345790	345782	14034U	PARTICIPANT	\N	PRESENT	0
345791	345782	14251Q	PARTICIPANT	\N	PRESENT	0
345792	345782	11085T	PARTICIPANT	\N	PRESENT	0
345793	345782	08009T	PARTICIPANT	\N	PRESENT	0
345794	345782	11072N	PARTICIPANT	\N	PRESENT	0
345795	345782	08011M	PARTICIPANT	\N	PRESENT	0
345796	345782	04070G	PARTICIPANT	\N	PRESENT	0
345797	345782	08061X	PARTICIPANT	\N	PRESENT	0
345798	345782	08047A	PARTICIPANT	\N	PRESENT	0
345799	345782	11090Q	PARTICIPANT	\N	PRESENT	0
345800	345782	11012A	PARTICIPANT	\N	PRESENT	0
345801	345782	04033B	PARTICIPANT	\N	PRESENT	0
345802	345782	01028R	PARTICIPANT	\N	PRESENT	0
346270	345251	19551W	PARTICIPANT	\N	PRESENT	0
346530	346252	14251Q	PARTICIPANT	\N	EXCUSE	0
346269	345251	19737F	PARTICIPANT	\N	PRESENT	0
347427	347424	14267Y	PARTICIPANT	\N	PRESENT	0
347429	347424	11054L	PARTICIPANT	\N	PRESENT	0
347431	347424	95067Q	PARTICIPANT	\N	PRESENT	0
347495	346259	14327T	PARTICIPANT	\N	PRESENT	0
347496	346259	11048N	PARTICIPANT	\N	PRESENT	0
347497	346259	14063N	PARTICIPANT	\N	PRESENT	0
347533	347532	11053K	PARTICIPANT	\N	PRESENT	0
347534	347532	14159V	PARTICIPANT	\N	PRESENT	0
347541	347540	08044W	PARTICIPANT	\N	PRESENT	0
347542	347540	14205J	PARTICIPANT	\N	PRESENT	0
347543	347540	14133K	PRESIDENT	1	PRESENT	0
347544	347540	96004D	PRESIDENT	0	PRESENT	0
347545	347540	04042C	PARTICIPANT	\N	EXCUSE	0
347546	347540	19251M	PARTICIPANT	\N	PRESENT	0
347547	347540	04035D	PARTICIPANT	\N	PRESENT	0
347548	347540	98022P	PARTICIPANT	\N	EXCUSE	0
347550	347540	04097T	PARTICIPANT	\N	PRESENT	0
347551	347540	14097Y	PARTICIPANT	\N	PRESENT	0
347552	347540	04061F	PARTICIPANT	\N	PRESENT	0
347553	347540	04057K	PARTICIPANT	\N	PRESENT	0
347554	347540	98050T	PARTICIPANT	\N	EXCUSE	0
347555	347540	98035U	PARTICIPANT	\N	PRESENT	0
347556	347540	12041X	PARTICIPANT	\N	PRESENT	0
347918	347917	14193X	PARTICIPANT	\N	PRESENT	0
347919	347917	98022P	PARTICIPANT	\N	PRESENT	0
347921	347920	14193X	PARTICIPANT	\N	PRESENT	0
347922	347920	98022P	PARTICIPANT	\N	PRESENT	0
349796	349223	08020N	PARTICIPANT	\N	EXCUSE	0
349797	349223	11109J	PARTICIPANT	\N	PRESENT	0
349798	349223	11083R	PARTICIPANT	\N	PRESENT	0
349799	349223	14123H	PARTICIPANT	\N	PRESENT	0
349800	349223	19621T	PARTICIPANT	\N	PRESENT	0
349801	349223	14061L	PARTICIPANT	\N	EXCUSE	0
349803	349223	08035V	PARTICIPANT	\N	PRESENT	0
349807	347119	04061F	PARTICIPANT	\N	PRESENT	0
350017	350016	08049C	PARTICIPANT	\N	PRESENT	0
350021	350020	08049C	PARTICIPANT	\N	PRESENT	0
350071	350070	11053K	PARTICIPANT	\N	PRESENT	0
350072	350070	05012A	PARTICIPANT	\N	PRESENT	0
350089	339548	04045F	PARTICIPANT	\N	PRESENT	0
350090	339548	11067R	PARTICIPANT	\N	PRESENT	0
350091	339548	19553Y	PARTICIPANT	\N	PRESENT	0
350092	339548	08031R	PARTICIPANT	\N	PRESENT	0
367062	357444	14093U	PARTICIPANT	\N	PRESENT	0
367063	357444	19693L	PARTICIPANT	\N	PRESENT	0
367064	357444	19683J	PARTICIPANT	\N	PRESENT	0
367066	357444	01048V	PRESIDENT	0	PRESENT	0
367067	357444	19503N	PARTICIPANT	\N	PRESENT	0
367068	357444	04043D	PARTICIPANT	\N	PRESENT	0
367069	357444	01058X	PARTICIPANT	\N	PRESENT	0
367073	357444	19723Y	PARTICIPANT	\N	EXCUSE	0
368567	367353	05008E	PRESIDENT	0	PRESENT	0
368568	367353	14111D	PARTICIPANT	\N	PRESENT	0
368569	367353	11026G	PARTICIPANT	\N	PRESENT	0
368570	367353	08045X	PARTICIPANT	\N	PRESENT	0
368571	367353	04038G	PARTICIPANT	\N	PRESENT	0
368572	367353	04047H	PARTICIPANT	\N	PRESENT	0
368573	367353	19673G	PARTICIPANT	\N	PRESENT	0
368574	367353	01028R	PARTICIPANT	\N	PRESENT	0
368575	367353	19447X	PARTICIPANT	\N	PRESENT	0
368576	367353	19489J	PARTICIPANT	\N	PRESENT	0
368577	367353	95063L	PARTICIPANT	\N	PRESENT	0
368578	367353	14041T	PARTICIPANT	\N	PRESENT	0
368579	367353	14215L	PARTICIPANT	\N	PRESENT	0
368580	367353	14021P	PARTICIPANT	\N	PRESENT	0
368581	367353	19729F	PARTICIPANT	\N	EXCUSE	0
368582	367353	08018U	PARTICIPANT	\N	EXCUSE	0
368583	367353	14231L	PARTICIPANT	\N	EXCUSE	0
368584	367007	11041F	PARTICIPANT	\N	PRESENT	0
368585	367007	14235Q	PARTICIPANT	\N	PRESENT	0
368586	367007	01058X	PARTICIPANT	\N	PRESENT	0
368587	367007	14079W	PARTICIPANT	\N	PRESENT	0
368588	367007	04042C	PRESIDENT	0	PRESENT	0
368589	367007	11066Q	PARTICIPANT	\N	PRESENT	0
368590	367007	19709B	PARTICIPANT	\N	PRESENT	0
368591	367007	98022P	PARTICIPANT	\N	PRESENT	0
368592	367007	98050T	PARTICIPANT	\N	PRESENT	0
368593	367007	97011G	PARTICIPANT	\N	PRESENT	0
368594	367007	08061X	PARTICIPANT	\N	PRESENT	0
368595	367007	14211G	PARTICIPANT	\N	PRESENT	0
368596	367007	98029W	PARTICIPANT	\N	PRESENT	0
368597	367353	14001X	PARTICIPANT	\N	PRESENT	0
368598	367353	19725B	PARTICIPANT	\N	PRESENT	0
368599	367353	14089Y	PARTICIPANT	\N	PRESENT	0
368600	367353	14065Q	PARTICIPANT	\N	PRESENT	0
368601	367353	04044E	PARTICIPANT	\N	PRESENT	0
368602	367007	98005N	PARTICIPANT	\N	PRESENT	0
368603	367353	14053L	PARTICIPANT	\N	PRESENT	0
368604	367353	11033F	PARTICIPANT	\N	PRESENT	0
368605	367353	14147R	PARTICIPANT	\N	PRESENT	0
368606	367353	14151M	PARTICIPANT	\N	PRESENT	0
368607	367007	08058D	PARTICIPANT	\N	PRESENT	0
368610	367007	04035D	PARTICIPANT	\N	PRESENT	0
368611	367007	95030B	PARTICIPANT	\N	PRESENT	0
368612	367007	19721W	PARTICIPANT	\N	PRESENT	0
368613	367007	08047A	PARTICIPANT	\N	PRESENT	0
368616	367007	95067Q	PARTICIPANT	\N	EXCUSE	0
368617	367007	19443T	PARTICIPANT	\N	EXCUSE	0
368618	367007	98018T	PARTICIPANT	\N	EXCUSE	0
368619	367007	19421M	PARTICIPANT	\N	EXCUSE	0
368620	367007	04040A	PARTICIPANT	\N	EXCUSE	0
368621	367007	14267Y	PARTICIPANT	\N	EXCUSE	0
368622	367007	11064N	PARTICIPANT	\N	EXCUSE	0
368623	367007	11054L	PARTICIPANT	\N	EXCUSE	0
368624	367007	19251M	PARTICIPANT	\N	EXCUSE	0
368625	367007	16685X	PARTICIPANT	\N	PRESENT	0
368626	367353	11072N	PARTICIPANT	\N	PRESENT	0
368627	367353	10015M	PARTICIPANT	\N	PRESENT	0
368628	367353	01024M	PARTICIPANT	\N	PRESENT	0
368629	367007	14255U	PARTICIPANT	\N	PRESENT	0
368630	367007	04034C	PARTICIPANT	\N	PRESENT	0
368637	367007	08056B	PARTICIPANT	\N	PRESENT	0
368638	367007	14097Y	PARTICIPANT	\N	PRESENT	0
368639	367007	14105F	PARTICIPANT	\N	PRESENT	0
368640	367210	08009T	PRESIDENT	0	PRESENT	0
368641	367210	11090Q	PARTICIPANT	\N	PRESENT	0
368679	367210	19383Y	PARTICIPANT	\N	PRESENT	0
368680	367210	19701S	PARTICIPANT	\N	PRESENT	0
368644	367210	19685L	PARTICIPANT	\N	EXCUSE	0
368681	367210	95062K	PARTICIPANT	\N	PRESENT	0
368682	367210	17637T	PARTICIPANT	\N	PRESENT	0
368647	367007	19583F	PARTICIPANT	\N	PRESENT	0
368648	367210	04097T	PARTICIPANT	\N	EXCUSE	0
368649	367210	19681G	PARTICIPANT	\N	EXCUSE	0
368650	367210	19333N	PARTICIPANT	\N	PRESENT	0
368651	367210	17583W	PARTICIPANT	\N	PRESENT	0
368652	367210	19794Q	PARTICIPANT	\N	PRESENT	0
368653	367210	19387D	PARTICIPANT	\N	PRESENT	0
368654	367210	14219Q	PARTICIPANT	\N	PRESENT	0
368655	367210	14221J	PARTICIPANT	\N	PRESENT	0
368656	367210	19599P	PARTICIPANT	\N	PRESENT	0
368657	367210	05012A	PARTICIPANT	\N	PRESENT	0
368658	367210	80027E	PARTICIPANT	\N	PRESENT	0
368659	367210	14051J	PARTICIPANT	\N	PRESENT	0
368660	367210	08060W	PARTICIPANT	\N	PRESENT	0
368661	367210	19503N	PARTICIPANT	\N	PRESENT	0
368662	367210	19347U	PARTICIPANT	\N	PRESENT	0
368663	367210	96004D	PARTICIPANT	\N	PRESENT	0
368664	367210	14157T	PARTICIPANT	\N	PRESENT	0
368665	367210	11065P	PARTICIPANT	\N	PRESENT	0
368666	367210	14103D	PARTICIPANT	\N	PRESENT	0
368667	367210	14031R	PARTICIPANT	\N	PRESENT	0
368668	367210	14191V	PARTICIPANT	\N	PRESENT	0
368669	367210	04085P	PARTICIPANT	\N	PRESENT	0
368670	367210	14093U	PARTICIPANT	\N	PRESENT	0
368671	367210	14029X	PARTICIPANT	\N	PRESENT	0
368672	367210	19737F	PARTICIPANT	\N	PRESENT	0
368673	367210	19739H	PARTICIPANT	\N	PRESENT	0
368674	367210	19745F	PARTICIPANT	\N	PRESENT	0
368675	367210	19659J	PARTICIPANT	\N	PRESENT	0
368676	367210	18083K	PARTICIPANT	\N	PRESENT	0
368677	367210	08024S	PARTICIPANT	\N	PRESENT	0
368678	367210	15447F	PARTICIPANT	\N	PRESENT	0
368683	367371	14327T	PARTICIPANT	\N	PRESENT	0
368684	367371	14331P	PARTICIPANT	\N	PRESENT	0
368685	367371	95041E	PARTICIPANT	\N	PRESENT	0
368686	367371	01057W	PARTICIPANT	\N	PRESENT	0
368687	367371	11053K	PARTICIPANT	\N	PRESENT	0
368688	367371	11074Q	PRESIDENT	0	PRESENT	0
368689	367371	19667J	PARTICIPANT	\N	PRESENT	0
368690	367371	19671E	PARTICIPANT	\N	PRESENT	0
368691	367371	11070L	PARTICIPANT	\N	PRESENT	0
368692	367371	88008L	PARTICIPANT	\N	PRESENT	0
368693	367371	14277B	PARTICIPANT	\N	PRESENT	0
368694	367371	07004J	PARTICIPANT	\N	PRESENT	0
368695	367371	19349W	PARTICIPANT	\N	PRESENT	0
368696	367371	08010L	PARTICIPANT	\N	PRESENT	0
368697	367371	14253S	PARTICIPANT	\N	PRESENT	0
368698	367371	19479G	PARTICIPANT	\N	PRESENT	0
368699	367371	19651A	PARTICIPANT	\N	PRESENT	0
368700	367371	08069G	PARTICIPANT	\N	PRESENT	0
368701	367371	19687N	PARTICIPANT	\N	PRESENT	0
368702	367371	08011M	PARTICIPANT	\N	PRESENT	0
368703	367371	08014Q	PARTICIPANT	\N	PRESENT	0
368704	367371	14173T	PARTICIPANT	\N	PRESENT	0
368705	367371	04086Q	PARTICIPANT	\N	PRESENT	0
368706	367371	11040E	PARTICIPANT	\N	PRESENT	0
368707	367371	14083S	PARTICIPANT	\N	PRESENT	0
368708	367371	14199E	PARTICIPANT	\N	PRESENT	0
368709	367371	11012A	PARTICIPANT	\N	PRESENT	0
368710	367371	08073C	PARTICIPANT	\N	PRESENT	0
368711	367371	19741B	PARTICIPANT	\N	PRESENT	0
368712	367371	14121F	PARTICIPANT	\N	PRESENT	0
368713	367371	99004R	PARTICIPANT	\N	PRESENT	0
368714	367210	14169X	PARTICIPANT	\N	PRESENT	0
368715	367371	14225N	PARTICIPANT	\N	PRESENT	0
368716	367371	07029T	PARTICIPANT	\N	PRESENT	0
368717	367371	14085U	PARTICIPANT	\N	PRESENT	0
368718	367371	11048N	PARTICIPANT	\N	PRESENT	0
368719	367371	19711U	PARTICIPANT	\N	PRESENT	0
368720	367371	19689Q	PARTICIPANT	\N	PRESENT	0
368721	367371	12016W	PARTICIPANT	\N	PRESENT	0
368722	367371	14159V	PARTICIPANT	\N	PRESENT	0
368723	367371	04061F	PARTICIPANT	\N	PRESENT	0
368724	367371	89017R	PARTICIPANT	\N	PRESENT	0
368725	367371	19647E	PARTICIPANT	\N	PRESENT	0
368726	367210	19549D	PARTICIPANT	\N	PRESENT	0
368727	367210	14237S	PARTICIPANT	\N	PRESENT	0
368728	367210	19713W	PARTICIPANT	\N	PRESENT	0
368729	367353	01060R	PARTICIPANT	\N	PRESENT	0
368730	367353	14275Y	PARTICIPANT	\N	PRESENT	0
368731	367353	14179A	PARTICIPANT	\N	PRESENT	0
368732	367353	98035U	PARTICIPANT	\N	PRESENT	0
368733	367353	08044W	PARTICIPANT	\N	PRESENT	0
368734	367353	14069U	PARTICIPANT	\N	PRESENT	0
368735	367353	19762G	PARTICIPANT	\N	PRESENT	0
368736	367371	04071H	PARTICIPANT	\N	PRESENT	0
368737	367371	14034U	PARTICIPANT	\N	PRESENT	0
368738	367372	14327T	PARTICIPANT	\N	PRESENT	0
366706	363151	19415P	PARTICIPANT	\N	PRESENT	0
366707	363151	14213J	PARTICIPANT	\N	PRESENT	0
367414	367351	14053L	PARTICIPANT	\N	PRESENT	0
367415	367351	14065Q	PARTICIPANT	\N	PRESENT	0
367416	367351	14111D	PARTICIPANT	\N	PRESENT	0
367417	367351	11010L	PARTICIPANT	\N	PRESENT	0
366720	364269	14083S	PARTICIPANT	\N	PRESENT	0
366721	364269	19647E	PARTICIPANT	\N	PRESENT	0
366722	364269	14121F	PARTICIPANT	\N	PRESENT	0
366723	364269	01048V	PARTICIPANT	\N	PRESENT	0
366724	364269	14173T	PARTICIPANT	\N	PRESENT	0
369862	366780	11067R	PARTICIPANT	\N	PRESENT	0
369863	366780	04092N	PRESIDENT	0	PRESENT	0
369864	366780	19565D	PARTICIPANT	\N	PRESENT	0
369865	366780	19798U	PARTICIPANT	\N	PRESENT	0
369866	366780	11097X	PARTICIPANT	\N	PRESENT	0
369867	366780	19415P	PARTICIPANT	\N	PRESENT	0
369868	366780	14223L	PARTICIPANT	\N	PRESENT	0
369869	366780	19703U	PARTICIPANT	\N	PRESENT	0
369870	366780	19727D	PARTICIPANT	\N	PRESENT	0
369871	366780	11031D	PARTICIPANT	\N	PRESENT	0
369872	366780	14239U	PARTICIPANT	\N	PRESENT	0
369873	366780	14119M	PARTICIPANT	\N	PRESENT	0
369874	366780	14281W	PARTICIPANT	\N	PRESENT	0
369875	366780	14042U	PARTICIPANT	\N	PRESENT	0
369876	366780	19367Y	PARTICIPANT	\N	PRESENT	0
369877	366780	14213J	PARTICIPANT	\N	PRESENT	0
369878	366780	19657G	PARTICIPANT	\N	PRESENT	0
369879	366780	19577H	PARTICIPANT	\N	PRESENT	0
369880	366780	98024R	PARTICIPANT	\N	PRESENT	0
369881	366780	19521Q	PARTICIPANT	\N	PRESENT	0
369882	366780	19760E	PARTICIPANT	\N	PRESENT	0
369883	366780	08041T	PARTICIPANT	\N	EXCUSE	0
369884	366780	19715Y	PARTICIPANT	\N	EXCUSE	0
370062	356301	08058D	PARTICIPANT	\N	PRESENT	0
370063	356301	14331P	PARTICIPANT	\N	PRESENT	0
370064	356301	14121F	PARTICIPANT	\N	PRESENT	0
370065	356301	08035V	PARTICIPANT	\N	PRESENT	0
370066	356301	19367Y	PARTICIPANT	\N	PRESENT	0
370067	356301	19727D	PARTICIPANT	\N	PRESENT	0
370068	356301	19621T	PARTICIPANT	\N	PRESENT	0
370069	356301	11045K	PARTICIPANT	\N	PRESENT	0
370070	356301	19649G	PARTICIPANT	\N	PRESENT	0
370071	356301	14079W	PARTICIPANT	\N	PRESENT	0
370072	356301	12016W	PARTICIPANT	\N	PRESENT	0
370073	356301	14231L	PARTICIPANT	\N	PRESENT	0
370074	356301	14038Y	PARTICIPANT	\N	PRESENT	0
370075	356301	08031R	PARTICIPANT	\N	PRESENT	0
370076	356301	19671E	PARTICIPANT	\N	PRESENT	0
370077	356301	11033F	PARTICIPANT	\N	PRESENT	0
370078	356301	19581D	PARTICIPANT	\N	PRESENT	0
370079	356301	19543W	PARTICIPANT	\N	PRESENT	0
370080	356301	19747H	PARTICIPANT	\N	PRESENT	0
370081	356301	11083R	PARTICIPANT	\N	PRESENT	0
370082	356301	05012A	PARTICIPANT	\N	PRESENT	0
370083	356301	19533U	PARTICIPANT	\N	PRESENT	0
370084	356301	14179A	PARTICIPANT	\N	PRESENT	0
370085	356301	08044W	PARTICIPANT	\N	PRESENT	0
370086	356301	10006L	PARTICIPANT	\N	PRESENT	0
370087	356301	08009T	PARTICIPANT	\N	PRESENT	0
370088	356301	19369B	PARTICIPANT	\N	PRESENT	0
370089	356301	19691J	PARTICIPANT	\N	PRESENT	0
370090	356301	19798U	PARTICIPANT	\N	PRESENT	0
370091	356301	19511N	PARTICIPANT	\N	PRESENT	0
370092	356301	19611R	PARTICIPANT	\N	PRESENT	0
370093	356301	14193X	PARTICIPANT	\N	PRESENT	0
370094	356301	11053K	PARTICIPANT	\N	PRESENT	0
370095	356301	19721W	PARTICIPANT	\N	PRESENT	0
370096	356301	14053L	PARTICIPANT	\N	PRESENT	0
370097	356301	19619A	PARTICIPANT	\N	PRESENT	0
370098	356301	14215L	PARTICIPANT	\N	PRESENT	0
370099	356301	19737F	PARTICIPANT	\N	PRESENT	0
370100	356301	19735D	PARTICIPANT	\N	PRESENT	0
370101	356301	04033B	PARTICIPANT	\N	PRESENT	0
370102	356301	08056B	PARTICIPANT	\N	PRESENT	0
370103	356301	14187A	PARTICIPANT	\N	PRESENT	0
370104	356301	16685X	PARTICIPANT	\N	PRESENT	0
370105	356301	14071N	PARTICIPANT	\N	PRESENT	0
370106	356301	05008E	PARTICIPANT	\N	PRESENT	0
370107	356301	19479G	PARTICIPANT	\N	PRESENT	0
370108	356301	04043D	PARTICIPANT	\N	PRESENT	0
370109	356301	11097X	PARTICIPANT	\N	PRESENT	0
370110	356301	19441R	PARTICIPANT	\N	PRESENT	0
370111	356301	14219Q	PARTICIPANT	\N	PRESENT	0
370112	356301	04092N	PARTICIPANT	\N	PRESENT	0
370113	356301	19713W	PARTICIPANT	\N	PRESENT	0
370114	356301	14277B	PARTICIPANT	\N	PRESENT	0
370115	356301	04044E	PARTICIPANT	\N	PRESENT	0
370116	356301	14026U	PARTICIPANT	\N	PRESENT	0
370117	356301	14221J	PARTICIPANT	\N	PRESENT	0
370118	356301	19739H	PARTICIPANT	\N	PRESENT	0
370119	356301	04089T	PARTICIPANT	\N	PRESENT	0
370120	356301	98024R	PARTICIPANT	\N	PRESENT	0
370121	356301	14103D	PARTICIPANT	\N	PRESENT	0
370122	356301	01062T	PARTICIPANT	\N	PRESENT	0
370123	356301	19335Q	PARTICIPANT	\N	PRESENT	0
370124	356301	14073Q	PARTICIPANT	\N	PRESENT	0
370125	356301	14083S	PARTICIPANT	\N	PRESENT	0
370126	356301	11070L	PARTICIPANT	\N	PRESENT	0
370127	356301	19521Q	PARTICIPANT	\N	PRESENT	0
370128	356301	14205J	PARTICIPANT	\N	PRESENT	0
370129	356301	14255U	PARTICIPANT	\N	PRESENT	0
370130	356301	11085T	PARTICIPANT	\N	PRESENT	0
370131	356301	08011M	PARTICIPANT	\N	PRESENT	0
370467	356303	11070L	PARTICIPANT	\N	PRESENT	0
370133	356301	04040A	PARTICIPANT	\N	PRESENT	0
370134	356301	04070G	PARTICIPANT	\N	PRESENT	0
370135	356301	01024M	PARTICIPANT	\N	PRESENT	0
370136	356301	01025N	PARTICIPANT	\N	PRESENT	0
370137	356301	19577H	PARTICIPANT	\N	PRESENT	0
370138	356301	14327T	PARTICIPANT	\N	PRESENT	0
370139	356301	14042U	PARTICIPANT	\N	PRESENT	0
370140	356301	01043Q	PARTICIPANT	\N	PRESENT	0
370141	356301	19289C	PARTICIPANT	\N	PRESENT	0
370142	356301	19749K	PARTICIPANT	\N	PRESENT	0
370143	356301	19745F	PARTICIPANT	\N	PRESENT	0
370144	356301	19683J	PARTICIPANT	\N	PRESENT	0
370145	356301	07029T	PARTICIPANT	\N	PRESENT	0
370146	356301	14119M	PARTICIPANT	\N	PRESENT	0
370147	356301	95041E	PARTICIPANT	\N	PRESENT	0
370148	356301	11099A	PARTICIPANT	\N	PRESENT	0
370149	356301	14197C	PARTICIPANT	\N	PRESENT	0
370150	356301	19681G	PARTICIPANT	\N	PRESENT	0
370151	356301	19387D	PARTICIPANT	\N	PRESENT	0
370152	356301	08017T	PARTICIPANT	\N	PRESENT	0
370153	356301	14069U	PARTICIPANT	\N	PRESENT	0
370154	356301	19659J	PARTICIPANT	\N	PRESENT	0
370155	356301	14151M	PARTICIPANT	\N	PRESENT	0
370159	356301	11090Q	PARTICIPANT	\N	PRESENT	0
370157	356301	08010L	PARTICIPANT	\N	PRESENT	0
370162	356301	19531S	PARTICIPANT	\N	PRESENT	0
370160	356301	14211G	PARTICIPANT	\N	PRESENT	0
370161	356301	04061F	PARTICIPANT	\N	PRESENT	0
370196	356301	11026G	PARTICIPANT	\N	PRESENT	0
370469	356303	14151M	PARTICIPANT	\N	PRESENT	0
370470	356303	04038G	PARTICIPANT	\N	PRESENT	0
370471	356303	19301E	PARTICIPANT	\N	PRESENT	0
370472	356303	14179A	PARTICIPANT	\N	PRESENT	0
370473	356303	17589D	PARTICIPANT	\N	PRESENT	0
370474	356303	19583F	PARTICIPANT	\N	PRESENT	0
370475	356303	14277B	PARTICIPANT	\N	PRESENT	0
370476	356303	19479G	PARTICIPANT	\N	PRESENT	0
370477	356303	19737F	PARTICIPANT	\N	PRESENT	0
370478	356303	14065Q	PARTICIPANT	\N	PRESENT	0
370479	356303	19577H	PARTICIPANT	\N	PRESENT	0
370480	356303	14231L	PARTICIPANT	\N	PRESENT	0
370481	356303	14215L	PARTICIPANT	\N	PRESENT	0
370482	356303	14229S	PARTICIPANT	\N	PRESENT	0
370483	356303	14205J	PARTICIPANT	\N	PRESENT	0
370484	356303	14103D	PARTICIPANT	\N	PRESENT	0
370485	356303	19721W	PARTICIPANT	\N	PRESENT	0
370486	356303	14121F	PARTICIPANT	\N	PRESENT	0
370487	356303	05008E	PARTICIPANT	\N	PRESENT	0
370488	356303	19629C	PARTICIPANT	\N	PRESENT	0
370489	356303	19387D	PARTICIPANT	\N	PRESENT	0
370490	356303	14107H	PARTICIPANT	\N	PRESENT	0
370491	356303	14219Q	PARTICIPANT	\N	PRESENT	0
370492	356303	14042U	PARTICIPANT	\N	PRESENT	0
370493	356303	14281W	PARTICIPANT	\N	PRESENT	0
370494	356303	19760E	PARTICIPANT	\N	PRESENT	0
370495	356303	14041T	PARTICIPANT	\N	PRESENT	0
370496	356303	19711U	PARTICIPANT	\N	PRESENT	0
370497	356303	14223L	PARTICIPANT	\N	PRESENT	0
370498	356303	19575F	PARTICIPANT	\N	PRESENT	0
370499	356303	19675J	PARTICIPANT	\N	PRESENT	0
370500	356303	19794Q	PARTICIPANT	\N	PRESENT	0
370501	356303	01025N	PARTICIPANT	\N	PRESENT	0
370502	356303	19657G	PARTICIPANT	\N	PRESENT	0
370503	356303	19735D	PARTICIPANT	\N	PRESENT	0
370504	356303	11053K	PARTICIPANT	\N	PRESENT	0
370510	356303	19703U	PARTICIPANT	\N	PRESENT	0
370506	356303	18083K	PARTICIPANT	\N	PRESENT	0
370507	356303	11085T	PARTICIPANT	\N	PRESENT	0
370508	356303	02002K	PARTICIPANT	\N	PRESENT	0
370509	356303	19671E	PARTICIPANT	\N	PRESENT	0
382941	382934	19637C	PARTICIPANT	\N	PRESENT	0
382943	382942	08009T	PARTICIPANT	\N	PRESENT	0
382944	382942	14038Y	PARTICIPANT	\N	PRESENT	0
382945	382942	19525U	PARTICIPANT	\N	PRESENT	0
384488	384485	18083K	PARTICIPANT	\N	PRESENT	0
384489	384485	14259Y	PARTICIPANT	\N	PRESENT	0
384490	384485	14041T	PARTICIPANT	\N	PRESENT	0
384491	384485	14151M	PARTICIPANT	\N	PRESENT	0
384492	384485	19647E	PARTICIPANT	\N	PRESENT	0
384493	384485	14087W	PARTICIPANT	\N	PRESENT	0
384494	384485	02002K	PARTICIPANT	\N	PRESENT	0
384495	384485	04035D	PARTICIPANT	\N	PRESENT	0
384496	384485	14081Q	PARTICIPANT	\N	PRESENT	0
384497	384485	04097T	PARTICIPANT	\N	PRESENT	0
384498	384485	12041X	PARTICIPANT	\N	PRESENT	0
384499	384485	11026G	PARTICIPANT	\N	PRESENT	0
384500	384485	14193X	PARTICIPANT	\N	PRESENT	0
384501	384485	14225N	PARTICIPANT	\N	PRESENT	0
384502	384485	14051J	PARTICIPANT	\N	PRESENT	0
384604	380333	11097X	PARTICIPANT	\N	EXCUSE	0
384655	380333	19467C	PARTICIPANT	\N	EXCUSE	0
385339	385336	14157T	PARTICIPANT	\N	PRESENT	0
385353	385352	14157T	PARTICIPANT	\N	PRESENT	0
385354	385352	08060W	PARTICIPANT	\N	PRESENT	0
385355	385352	14097Y	PARTICIPANT	\N	PRESENT	0
385356	385352	19715Y	PARTICIPANT	\N	PRESENT	0
385357	385352	14031R	PARTICIPANT	\N	PRESENT	0
385358	385352	19347U	PARTICIPANT	\N	PRESENT	0
385360	385352	19745F	PARTICIPANT	\N	PRESENT	0
385361	385352	11048N	PARTICIPANT	\N	PRESENT	0
385370	385369	14157T	PARTICIPANT	\N	PRESENT	0
385371	385369	08060W	PARTICIPANT	\N	PRESENT	0
385372	385369	19629C	PARTICIPANT	\N	PRESENT	0
384486	384485	04040A	PARTICIPANT	\N	PRESENT	0
384487	384485	14053L	PARTICIPANT	\N	PRESENT	0
385373	385369	14097Y	PARTICIPANT	\N	PRESENT	0
385374	385369	08019V	PARTICIPANT	\N	PRESENT	0
386724	386718	19269X	PARTICIPANT	\N	PRESENT	0
386725	384208	19489J	PARTICIPANT	\N	PRESENT	0
386726	386719	14033T	PARTICIPANT	\N	PRESENT	0
386727	386719	01025N	PARTICIPANT	\N	PRESENT	0
386728	384208	08034U	PARTICIPANT	\N	PRESENT	0
386729	384208	08010L	PARTICIPANT	\N	PRESENT	0
386730	377925	19467C	PARTICIPANT	\N	PRESENT	0
386731	377925	08049C	PARTICIPANT	\N	PRESENT	0
386732	384208	08038Y	PARTICIPANT	\N	PRESENT	0
386733	377925	80013X	PARTICIPANT	\N	PRESENT	0
386735	386734	14033T	PARTICIPANT	\N	PRESENT	0
386736	377925	08053X	PARTICIPANT	\N	PRESENT	0
386737	377925	14213J	PARTICIPANT	\N	PRESENT	0
386738	377925	12041X	PARTICIPANT	\N	PRESENT	0
386739	377925	99004R	PARTICIPANT	\N	PRESENT	0
386740	377925	01028R	PARTICIPANT	\N	PRESENT	0
386741	377925	19611R	PARTICIPANT	\N	PRESENT	0
386742	377925	19745F	PARTICIPANT	\N	PRESENT	0
386743	377925	04045F	PARTICIPANT	\N	PRESENT	0
386744	377925	19521Q	PARTICIPANT	\N	PRESENT	0
386746	377925	14329V	PARTICIPANT	\N	PRESENT	0
386747	377925	14031R	PARTICIPANT	\N	PRESENT	0
386748	377925	14063N	PARTICIPANT	\N	PRESENT	0
386749	377925	19479G	PARTICIPANT	\N	PRESENT	0
386750	386607	19729F	PARTICIPANT	\N	PRESENT	0
386751	377925	19741B	PARTICIPANT	\N	PRESENT	0
386752	377925	14241N	PARTICIPANT	\N	PRESENT	0
386754	386753	96004D	PRESIDENT	0	PRESENT	0
386755	377925	19295A	PARTICIPANT	\N	PRESENT	0
386756	386753	04097T	PARTICIPANT	\N	PRESENT	0
386757	386753	14073Q	PARTICIPANT	\N	PRESENT	0
386758	386753	04042C	PRESIDENT	1	PRESENT	0
386759	386753	98050T	PARTICIPANT	\N	PRESENT	0
386760	386753	01062T	PARTICIPANT	\N	PRESENT	0
386761	386753	04034C	PARTICIPANT	\N	PRESENT	0
386762	377925	97011G	PARTICIPANT	\N	PRESENT	0
386763	377925	19581D	PARTICIPANT	\N	PRESENT	0
386764	386753	04035D	PARTICIPANT	\N	EXCUSE	0
386765	386753	11083R	PARTICIPANT	\N	PRESENT	0
386766	386753	11026G	PARTICIPANT	\N	PRESENT	0
386768	377925	08038Y	PARTICIPANT	\N	PRESENT	0
386769	377925	19719D	PARTICIPANT	\N	PRESENT	0
386772	377925	11026G	PARTICIPANT	\N	PRESENT	0
386773	377925	19675J	PARTICIPANT	\N	PRESENT	0
386774	377925	19531S	PARTICIPANT	\N	PRESENT	0
386781	377925	18083K	PARTICIPANT	\N	PRESENT	0
386782	377925	19629C	PARTICIPANT	\N	PRESENT	0
386783	377925	19715Y	PARTICIPANT	\N	PRESENT	0
386784	377925	19758L	PARTICIPANT	\N	PRESENT	0
386785	377925	14235Q	PARTICIPANT	\N	PRESENT	0
386786	377925	14259Y	PARTICIPANT	\N	PRESENT	0
386789	377925	14179A	PARTICIPANT	\N	PRESENT	0
386790	377925	19669L	PARTICIPANT	\N	PRESENT	0
386791	377925	95067Q	PARTICIPANT	\N	PRESENT	0
386792	377925	19729F	PARTICIPANT	\N	PRESENT	0
386796	386795	19575F	PARTICIPANT	\N	PRESENT	0
386797	386795	14030Q	PARTICIPANT	\N	PRESENT	0
386798	386795	08060W	PARTICIPANT	\N	PRESENT	0
386799	386795	14053L	PARTICIPANT	\N	PRESENT	0
386800	386795	14087W	PARTICIPANT	\N	PRESENT	0
386801	386795	19521Q	PARTICIPANT	\N	PRESENT	0
386802	386795	14034U	PARTICIPANT	\N	PRESENT	0
386803	386795	14026U	PARTICIPANT	\N	PRESENT	0
386804	386795	14061L	PARTICIPANT	\N	PRESENT	0
386805	386795	04049K	PRESIDENT	0	PRESENT	0
386806	386795	08015R	PARTICIPANT	\N	PRESENT	0
386807	386795	16685X	PARTICIPANT	\N	PRESENT	0
386808	386795	19671E	PARTICIPANT	\N	PRESENT	0
386809	386795	14265W	PARTICIPANT	\N	PRESENT	0
386810	386795	04088S	PARTICIPANT	\N	PRESENT	0
386811	386795	89017R	PARTICIPANT	\N	EXCUSE	0
386812	386795	14105F	PARTICIPANT	\N	EXCUSE	0
386813	386795	14255U	PARTICIPANT	\N	EXCUSE	0
386814	386795	14083S	PARTICIPANT	\N	EXCUSE	0
386815	386795	14079W	PARTICIPANT	\N	EXCUSE	0
386816	386795	14041T	PARTICIPANT	\N	EXCUSE	0
386817	386795	19695N	PARTICIPANT	\N	EXCUSE	0
386818	386795	14039A	PARTICIPANT	\N	EXCUSE	0
386819	386795	11099A	PARTICIPANT	\N	EXCUSE	0
386820	386795	14253S	PARTICIPANT	\N	EXCUSE	0
386821	386795	14051J	PARTICIPANT	\N	EXCUSE	0
386822	386795	14157T	PARTICIPANT	\N	EXCUSE	0
386829	386828	04049K	PARTICIPANT	\N	PRESENT	0
386830	386828	14026U	PARTICIPANT	\N	PRESENT	0
386840	386838	04049K	PARTICIPANT	\N	PRESENT	0
386842	386838	14026U	PARTICIPANT	\N	PRESENT	0
386844	386838	14187A	PARTICIPANT	\N	PRESENT	0
386845	386838	14205J	PARTICIPANT	\N	PRESENT	0
386922	377926	98022P	PARTICIPANT	\N	PRESENT	0
386927	377926	04038G	PARTICIPANT	\N	PRESENT	0
386928	377926	11041F	PARTICIPANT	\N	PRESENT	0
386929	377926	11077T	PARTICIPANT	\N	PRESENT	0
386930	377926	19687N	PARTICIPANT	\N	PRESENT	0
386931	377926	11040E	PARTICIPANT	\N	PRESENT	0
386932	377926	19758L	PARTICIPANT	\N	PRESENT	0
386933	377926	19593H	PARTICIPANT	\N	PRESENT	0
386934	377926	11056N	PARTICIPANT	\N	PRESENT	0
386935	377926	14235Q	PARTICIPANT	\N	PRESENT	0
386936	386607	19549D	PARTICIPANT	\N	EXCUSE	0
386937	386607	19671E	PARTICIPANT	\N	EXCUSE	0
386939	377926	86034E	PARTICIPANT	\N	PRESENT	0
386940	377926	17637T	PARTICIPANT	\N	PRESENT	0
386941	377926	19711U	PARTICIPANT	\N	PRESENT	0
386942	377926	95062K	PARTICIPANT	\N	PRESENT	0
386953	377926	11033F	PARTICIPANT	\N	PRESENT	0
386954	377926	19760E	PARTICIPANT	\N	PRESENT	0
386955	377926	04085P	PARTICIPANT	\N	PRESENT	0
386956	377926	95063L	PARTICIPANT	\N	PRESENT	0
386957	377926	14157T	PARTICIPANT	\N	PRESENT	0
386958	377926	08061X	PARTICIPANT	\N	PRESENT	0
386959	377926	01058X	PARTICIPANT	\N	PRESENT	0
386960	377926	04045F	PARTICIPANT	\N	PRESENT	0
386961	377926	95037J	PARTICIPANT	\N	PRESENT	0
386962	377926	99004R	PARTICIPANT	\N	PRESENT	0
386963	377926	14239U	PARTICIPANT	\N	PRESENT	0
386964	377926	19679N	PARTICIPANT	\N	PRESENT	0
386965	377926	04034C	PARTICIPANT	\N	PRESENT	0
386966	377926	08039A	PARTICIPANT	\N	PRESENT	0
386967	377926	19651A	PARTICIPANT	\N	PRESENT	0
386968	377926	19349W	PARTICIPANT	\N	PRESENT	0
386969	377926	08020N	PARTICIPANT	\N	PRESENT	0
386970	377926	19543W	PARTICIPANT	\N	PRESENT	0
386971	377926	19782L	PARTICIPANT	\N	PRESENT	0
386972	377926	08010L	PARTICIPANT	\N	PRESENT	0
386973	377926	19269X	PARTICIPANT	\N	PRESENT	0
386974	377926	19697Q	PARTICIPANT	\N	PRESENT	0
386975	377926	08069G	PARTICIPANT	\N	PRESENT	0
386976	377926	11072N	PARTICIPANT	\N	PRESENT	0
386977	377926	04042C	PARTICIPANT	\N	PRESENT	0
386978	377926	98029W	PARTICIPANT	\N	PRESENT	0
364582	364581	14103D	PARTICIPANT	\N	PRESENT	0
364583	364581	19739H	PARTICIPANT	\N	PRESENT	0
368739	367372	14331P	PARTICIPANT	\N	PRESENT	0
368740	367372	04071H	PARTICIPANT	\N	PRESENT	0
368741	367372	95041E	PARTICIPANT	\N	PRESENT	0
368742	367372	01057W	PARTICIPANT	\N	PRESENT	0
368743	367372	11053K	PARTICIPANT	\N	PRESENT	0
368744	367372	11074Q	PRESIDENT	0	PRESENT	0
368745	367372	19667J	PARTICIPANT	\N	PRESENT	0
368746	367372	89017R	PARTICIPANT	\N	PRESENT	0
368747	367372	19671E	PARTICIPANT	\N	PRESENT	0
368748	367372	11070L	PARTICIPANT	\N	PRESENT	0
368749	367372	88008L	PARTICIPANT	\N	PRESENT	0
368750	367372	14225N	PARTICIPANT	\N	PRESENT	0
368751	367372	07029T	PARTICIPANT	\N	PRESENT	0
368752	367372	14277B	PARTICIPANT	\N	PRESENT	0
368753	367372	14085U	PARTICIPANT	\N	PRESENT	0
368754	367372	07004J	PARTICIPANT	\N	PRESENT	0
368755	367372	19349W	PARTICIPANT	\N	PRESENT	0
368756	367372	08010L	PARTICIPANT	\N	PRESENT	0
368757	367372	14253S	PARTICIPANT	\N	PRESENT	0
368758	367372	19479G	PARTICIPANT	\N	PRESENT	0
368759	367372	11048N	PARTICIPANT	\N	PRESENT	0
368760	367372	19647E	PARTICIPANT	\N	PRESENT	0
368761	367372	19711U	PARTICIPANT	\N	PRESENT	0
368762	367372	19651A	PARTICIPANT	\N	PRESENT	0
368763	367372	08069G	PARTICIPANT	\N	PRESENT	0
368764	367372	19687N	PARTICIPANT	\N	PRESENT	0
368765	367372	19689Q	PARTICIPANT	\N	PRESENT	0
368766	367372	12016W	PARTICIPANT	\N	PRESENT	0
368767	367372	08011M	PARTICIPANT	\N	PRESENT	0
368768	367372	08014Q	PARTICIPANT	\N	PRESENT	0
368769	367372	14034U	PARTICIPANT	\N	PRESENT	0
368770	367372	14159V	PARTICIPANT	\N	PRESENT	0
368771	367372	14173T	PARTICIPANT	\N	PRESENT	0
368772	367372	04086Q	PARTICIPANT	\N	PRESENT	0
368773	367372	11040E	PARTICIPANT	\N	PRESENT	0
368774	367372	14083S	PARTICIPANT	\N	PRESENT	0
368775	367372	14199E	PARTICIPANT	\N	PRESENT	0
368776	367372	11012A	PARTICIPANT	\N	PRESENT	0
368777	367372	08073C	PARTICIPANT	\N	PRESENT	0
368778	367372	19741B	PARTICIPANT	\N	PRESENT	0
368779	367372	14121F	PARTICIPANT	\N	PRESENT	0
368780	367372	99004R	PARTICIPANT	\N	PRESENT	0
368781	367372	04061F	PARTICIPANT	\N	PRESENT	0
368784	367210	14038Y	PARTICIPANT	\N	PRESENT	0
368794	367087	19768N	PARTICIPANT	\N	PRESENT	0
368795	367087	19515S	PARTICIPANT	\N	PRESENT	0
368796	367087	11077T	PARTICIPANT	\N	PRESENT	0
368797	367087	19782L	PARTICIPANT	\N	PRESENT	0
368798	367087	01043Q	PARTICIPANT	\N	PRESENT	0
368799	367087	19441R	PARTICIPANT	\N	PRESENT	0
368800	367087	19413M	PARTICIPANT	\N	PRESENT	0
368801	367087	14081Q	PARTICIPANT	\N	PRESENT	0
368802	367087	80013X	PARTICIPANT	\N	PRESENT	0
368803	367087	19631V	PARTICIPANT	\N	PRESENT	0
368804	367087	08021P	PARTICIPANT	\N	PRESENT	0
368805	367087	11099A	PARTICIPANT	\N	PRESENT	0
368806	367087	08068F	PARTICIPANT	\N	PRESENT	0
368807	367087	04049K	PARTICIPANT	\N	PRESENT	0
368808	367087	19705W	PARTICIPANT	\N	PRESENT	0
368809	367087	08015R	PARTICIPANT	\N	PRESENT	0
368810	367087	08019V	PARTICIPANT	\N	PRESENT	0
368811	367087	14197C	PARTICIPANT	\N	PRESENT	0
368812	367087	19369B	PARTICIPANT	\N	PRESENT	0
368813	367087	08028W	PARTICIPANT	\N	PRESENT	0
368814	367087	19563B	PARTICIPANT	\N	PRESENT	0
368815	367087	14265W	PARTICIPANT	\N	PRESENT	0
368816	367087	14135M	PARTICIPANT	\N	PRESENT	0
368817	367087	14187A	PARTICIPANT	\N	PRESENT	0
368818	367087	08062Y	PARTICIPANT	\N	PRESENT	0
368819	367087	19695N	PARTICIPANT	\N	PRESENT	0
368820	367087	11090Q	PARTICIPANT	\N	PRESENT	0
368821	367087	14033T	PARTICIPANT	\N	PRESENT	0
368822	367087	01025N	PARTICIPANT	\N	PRESENT	0
368823	367087	19269X	PARTICIPANT	\N	PRESENT	0
368824	367087	14205J	PARTICIPANT	\N	PRESENT	0
368825	367087	11056N	PARTICIPANT	\N	PRESENT	0
368826	367087	04088S	PARTICIPANT	\N	PRESENT	0
368827	367087	04089T	PARTICIPANT	\N	PRESENT	0
368828	367087	19507S	PARTICIPANT	\N	PRESENT	0
368829	367087	14109K	PARTICIPANT	\N	PRESENT	0
368830	367087	14207L	PARTICIPANT	\N	PRESENT	0
368831	367087	19747H	PARTICIPANT	\N	PRESENT	0
368832	367087	04043D	PARTICIPANT	\N	PRESENT	0
368833	367087	17589D	PARTICIPANT	\N	PRESENT	0
368834	367087	19619A	PARTICIPANT	\N	PRESENT	0
368835	367087	14257W	PARTICIPANT	\N	PRESENT	0
368836	366777	11067R	PARTICIPANT	\N	PRESENT	0
368837	366777	19565D	PARTICIPANT	\N	PRESENT	0
368838	366777	19798U	PARTICIPANT	\N	PRESENT	0
368839	366777	19569H	PARTICIPANT	\N	PRESENT	0
368840	366777	11097X	PARTICIPANT	\N	PRESENT	0
368841	366777	04045F	PARTICIPANT	\N	PRESENT	0
368842	366777	14223L	PARTICIPANT	\N	PRESENT	0
368843	366777	14026U	PARTICIPANT	\N	PRESENT	0
368844	366777	14227Q	PARTICIPANT	\N	PRESENT	0
368845	366777	14239U	PARTICIPANT	\N	PRESENT	0
368846	366777	11031D	PARTICIPANT	\N	PRESENT	0
368847	366777	19553Y	PARTICIPANT	\N	PRESENT	0
368848	366777	14087W	PARTICIPANT	\N	PRESENT	0
368849	366777	14281W	PARTICIPANT	\N	PRESENT	0
368850	366777	19679N	PARTICIPANT	\N	PRESENT	0
368851	366777	14042U	PARTICIPANT	\N	PRESENT	0
368852	366777	19575F	PARTICIPANT	\N	PRESENT	0
368853	366777	08048B	PARTICIPANT	\N	PRESENT	0
368854	366777	14195A	PARTICIPANT	\N	PRESENT	0
368855	366777	14213J	PARTICIPANT	\N	PRESENT	0
368856	366777	10006L	PARTICIPANT	\N	PRESENT	0
368857	366777	98024R	PARTICIPANT	\N	PRESENT	0
368858	366777	04092N	PRESIDENT	0	PRESENT	0
368859	366777	08052W	PARTICIPANT	\N	PRESENT	0
368860	366777	19691J	PARTICIPANT	\N	PRESENT	0
368861	366777	19717B	PARTICIPANT	\N	PRESENT	0
368862	366777	19727D	PARTICIPANT	\N	PRESENT	0
368863	366777	14119M	PARTICIPANT	\N	PRESENT	0
368864	366777	11103C	PARTICIPANT	\N	PRESENT	0
368865	366777	19657G	PARTICIPANT	\N	PRESENT	0
368866	366777	14071N	PARTICIPANT	\N	PRESENT	0
368867	366777	19577H	PARTICIPANT	\N	PRESENT	0
368868	366777	19760E	PARTICIPANT	\N	PRESENT	0
368869	366777	08041T	PARTICIPANT	\N	EXCUSE	0
368954	366779	19697Q	PARTICIPANT	\N	PRESENT	0
368955	366779	17779H	PARTICIPANT	\N	PRESENT	0
368958	366779	19521Q	PARTICIPANT	\N	PRESENT	0
368966	366779	19715Y	PARTICIPANT	\N	EXCUSE	0
369151	369150	14133K	PARTICIPANT	\N	PRESENT	0
369152	369150	96004D	PRESIDENT	0	PRESENT	0
369153	369150	14255U	PARTICIPANT	\N	PRESENT	0
369154	369150	04042C	PRESIDENT	1	PRESENT	0
369155	369150	14097Y	PARTICIPANT	\N	PRESENT	0
369156	369150	04057K	PARTICIPANT	\N	PRESENT	0
369157	369150	04034C	PARTICIPANT	\N	PRESENT	0
369158	369150	08011M	PARTICIPANT	\N	PRESENT	0
369283	356297	14221J	PARTICIPANT	\N	PRESENT	0
369284	367354	11033F	PARTICIPANT	\N	PRESENT	0
369285	367354	08045X	PARTICIPANT	\N	PRESENT	0
369286	367354	19719D	PARTICIPANT	\N	PRESENT	0
369287	367354	95063L	PARTICIPANT	\N	PRESENT	0
369288	367354	11085T	PARTICIPANT	\N	PRESENT	0
369289	367354	14259Y	PARTICIPANT	\N	PRESENT	0
369290	367354	14021P	PARTICIPANT	\N	PRESENT	0
369291	356297	19581D	PARTICIPANT	\N	PRESENT	0
369292	356297	19673G	PARTICIPANT	\N	PRESENT	0
369293	356297	14041T	PARTICIPANT	\N	PRESENT	0
369294	356297	19758L	PARTICIPANT	\N	PRESENT	0
369295	356297	19687N	PARTICIPANT	\N	PRESENT	0
369297	356297	14151M	PARTICIPANT	\N	PRESENT	0
369298	356297	19717B	PARTICIPANT	\N	PRESENT	0
369299	356297	19691J	PARTICIPANT	\N	PRESENT	0
369301	356297	14123H	PARTICIPANT	\N	PRESENT	0
369302	356297	14357A	PARTICIPANT	\N	PRESENT	0
369304	356297	08052W	PARTICIPANT	\N	PRESENT	0
369305	356297	08044W	PARTICIPANT	\N	PRESENT	0
369312	356297	19760E	PARTICIPANT	\N	PRESENT	0
369313	356297	14329V	PARTICIPANT	\N	PRESENT	0
369314	356297	19679N	PARTICIPANT	\N	PRESENT	0
369315	356297	14079W	PARTICIPANT	\N	PRESENT	0
369316	356297	11067R	PARTICIPANT	\N	PRESENT	0
369317	356297	04034C	PARTICIPANT	\N	PRESENT	0
367418	367351	10015M	PARTICIPANT	\N	PRESENT	0
367419	367351	19543W	PARTICIPANT	\N	PRESENT	0
367420	367351	01024M	PARTICIPANT	\N	PRESENT	0
367421	367351	01028R	PARTICIPANT	\N	PRESENT	0
367422	367351	19447X	PARTICIPANT	\N	PRESENT	0
367423	367351	05008E	PRESIDENT	0	PRESENT	0
367424	367351	19725B	PARTICIPANT	\N	PRESENT	0
367425	367351	14041T	PARTICIPANT	\N	PRESENT	0
367426	367351	14179A	PARTICIPANT	\N	PRESENT	0
367427	367351	14147R	PARTICIPANT	\N	PRESENT	0
367428	367351	14215L	PARTICIPANT	\N	PRESENT	0
367429	367351	19762G	PARTICIPANT	\N	PRESENT	0
367430	367351	98035U	PARTICIPANT	\N	PRESENT	0
367431	367351	14069U	PARTICIPANT	\N	PRESENT	0
367432	367351	14151M	PARTICIPANT	\N	PRESENT	0
367433	367351	04044E	PARTICIPANT	\N	PRESENT	0
367434	367351	14021P	PARTICIPANT	\N	PRESENT	0
367435	367351	11072N	PARTICIPANT	\N	PRESENT	0
367436	367351	19729F	PARTICIPANT	\N	EXCUSE	0
367437	367351	08018U	PARTICIPANT	\N	EXCUSE	0
367438	367351	14231L	PARTICIPANT	\N	EXCUSE	0
367439	366416	19383Y	PARTICIPANT	\N	PRESENT	0
367440	366416	19333N	PARTICIPANT	\N	PRESENT	0
367441	366416	17583W	PARTICIPANT	\N	PRESENT	0
367442	366416	19794Q	PARTICIPANT	\N	PRESENT	0
367443	366416	19549D	PARTICIPANT	\N	PRESENT	0
367444	366416	14219Q	PARTICIPANT	\N	PRESENT	0
367445	366416	19599P	PARTICIPANT	\N	PRESENT	0
367446	366416	19637C	PARTICIPANT	\N	PRESENT	0
367447	366416	18083K	PARTICIPANT	\N	PRESENT	0
367448	366416	14237S	PARTICIPANT	\N	PRESENT	0
367449	366416	19551W	PARTICIPANT	\N	PRESENT	0
367450	366416	05012A	PARTICIPANT	\N	PRESENT	0
367451	366416	14051J	PARTICIPANT	\N	PRESENT	0
367452	366416	19503N	PARTICIPANT	\N	PRESENT	0
367453	366416	19347U	PARTICIPANT	\N	PRESENT	0
367454	366416	14157T	PARTICIPANT	\N	PRESENT	0
367455	366416	17637T	PARTICIPANT	\N	PRESENT	0
367456	366416	14329V	PARTICIPANT	\N	PRESENT	0
367457	366416	14103D	PARTICIPANT	\N	PRESENT	0
367458	366416	14031R	PARTICIPANT	\N	PRESENT	0
367459	366416	19713W	PARTICIPANT	\N	PRESENT	0
367460	366416	08055A	PARTICIPANT	\N	PRESENT	0
367461	366416	14191V	PARTICIPANT	\N	PRESENT	0
367462	366416	14169X	PARTICIPANT	\N	PRESENT	0
367463	366416	19739H	PARTICIPANT	\N	PRESENT	0
367464	366416	19745F	PARTICIPANT	\N	PRESENT	0
367468	366416	19387D	PARTICIPANT	\N	PRESENT	0
367469	366416	14093U	PARTICIPANT	\N	PRESENT	0
367474	367466	86034E	PARTICIPANT	\N	PRESENT	0
367475	367466	98022P	PARTICIPANT	\N	PRESENT	0
367476	367466	19659J	PARTICIPANT	\N	PRESENT	0
367477	367466	14277B	PARTICIPANT	\N	PRESENT	0
367478	367466	14105F	PARTICIPANT	\N	PRESENT	0
367479	367466	14041T	PARTICIPANT	\N	PRESENT	0
367480	367466	14191V	PARTICIPANT	\N	PRESENT	0
367481	367466	92040Q	PARTICIPANT	\N	PRESENT	0
367482	367466	14073Q	PARTICIPANT	\N	PRESENT	0
367483	367466	14133K	PARTICIPANT	\N	PRESENT	0
367484	367466	19467C	PARTICIPANT	\N	PRESENT	0
367485	367466	15447F	PARTICIPANT	\N	PRESENT	0
367486	367466	11010L	PARTICIPANT	\N	PRESENT	0
367487	367466	14219Q	PARTICIPANT	\N	PRESENT	0
367488	367466	08055A	PARTICIPANT	\N	PRESENT	0
367489	367466	19629C	PARTICIPANT	\N	PRESENT	0
367490	367466	08049C	PARTICIPANT	\N	PRESENT	0
367491	367466	19565D	PARTICIPANT	\N	PRESENT	0
367492	367466	11103C	PARTICIPANT	\N	PRESENT	0
367493	367466	11101A	PARTICIPANT	\N	PRESENT	0
367494	367466	98029W	PARTICIPANT	\N	PRESENT	0
367495	367466	19525U	PARTICIPANT	\N	PRESENT	0
367496	367466	19703U	PARTICIPANT	\N	PRESENT	0
367497	367466	19798U	PARTICIPANT	\N	PRESENT	0
367498	367466	98035U	PARTICIPANT	\N	PRESENT	0
367499	367466	19511N	PARTICIPANT	\N	PRESENT	0
367500	367466	01058X	PARTICIPANT	\N	PRESENT	0
367501	367466	80027E	PARTICIPANT	\N	PRESENT	0
367502	367466	08060W	PARTICIPANT	\N	PRESENT	0
367503	367466	19387D	PARTICIPANT	\N	PRESENT	0
367504	367466	11077T	PARTICIPANT	\N	PRESENT	0
367505	367466	14235Q	PARTICIPANT	\N	PRESENT	0
367506	367466	19691J	PARTICIPANT	\N	PRESENT	0
367507	367466	19737F	PARTICIPANT	\N	PRESENT	0
367508	367466	11066Q	PARTICIPANT	\N	PRESENT	0
367509	367466	14029X	PARTICIPANT	\N	PRESENT	0
367510	367466	08047A	PARTICIPANT	\N	PRESENT	0
367511	367466	19489J	PARTICIPANT	\N	PRESENT	0
367512	367466	19637C	PARTICIPANT	\N	PRESENT	0
367513	367466	14039A	PARTICIPANT	\N	PRESENT	0
367514	367466	19782L	PARTICIPANT	\N	PRESENT	0
367515	367466	19725B	PARTICIPANT	\N	PRESENT	0
367516	367466	80013X	PARTICIPANT	\N	PRESENT	0
367517	367466	14063N	PARTICIPANT	\N	PRESENT	0
367524	367466	04045F	PARTICIPANT	\N	PRESENT	0
367519	367466	11031D	PARTICIPANT	\N	PRESENT	0
367520	367466	19760E	PARTICIPANT	\N	PRESENT	0
367521	367466	11056N	PARTICIPANT	\N	PRESENT	0
367522	367466	19347U	PARTICIPANT	\N	PRESENT	0
367523	367466	04085P	PARTICIPANT	\N	PRESENT	0
367525	367466	19697Q	PARTICIPANT	\N	PRESENT	0
367526	367466	14239U	PARTICIPANT	\N	PRESENT	0
367527	367466	14241N	PARTICIPANT	\N	PRESENT	0
367528	367466	11012A	PARTICIPANT	\N	PRESENT	0
367529	367466	01060R	PARTICIPANT	\N	PRESENT	0
367530	367466	14195A	PARTICIPANT	\N	PRESENT	0
367531	367466	14093U	PARTICIPANT	\N	PRESENT	0
367532	367466	14201E	PARTICIPANT	\N	PRESENT	0
367533	367466	14211G	PARTICIPANT	\N	PRESENT	0
367534	367466	14159V	PARTICIPANT	\N	PRESENT	0
367535	367466	11074Q	PARTICIPANT	\N	PRESENT	0
367536	367466	14051J	PARTICIPANT	\N	PRESENT	0
367537	367466	01028R	PARTICIPANT	\N	PRESENT	0
367538	367466	14225N	PARTICIPANT	\N	PRESENT	0
367539	367466	14169X	PARTICIPANT	\N	PRESENT	0
367540	367466	14197C	PARTICIPANT	\N	PRESENT	0
367541	367466	08035V	PARTICIPANT	\N	PRESENT	0
367542	367466	19515S	PARTICIPANT	\N	PRESENT	0
367543	367466	19649G	PARTICIPANT	\N	PRESENT	0
367544	367466	14028W	PARTICIPANT	\N	PRESENT	0
367545	367466	19679N	PARTICIPANT	\N	PRESENT	0
367546	367466	04008A	PARTICIPANT	\N	PRESENT	0
367547	367466	11104D	PARTICIPANT	\N	PRESENT	0
367548	367466	99004R	PARTICIPANT	\N	PRESENT	0
367549	367466	19333N	PARTICIPANT	\N	PRESENT	0
367550	367466	12016W	PARTICIPANT	\N	PRESENT	0
367551	367466	01057W	PARTICIPANT	\N	PRESENT	0
367552	367466	08052W	PARTICIPANT	\N	PRESENT	0
367553	367466	19669L	PARTICIPANT	\N	PRESENT	0
367554	367466	14109K	PARTICIPANT	\N	PRESENT	0
367555	367466	19667J	PARTICIPANT	\N	PRESENT	0
367556	367466	19575F	PARTICIPANT	\N	PRESENT	0
367557	367466	19551W	PARTICIPANT	\N	PRESENT	0
367558	367466	19687N	PARTICIPANT	\N	PRESENT	0
367559	367466	14253S	PARTICIPANT	\N	PRESENT	0
367560	367466	19695N	PARTICIPANT	\N	PRESENT	0
367561	367466	08069G	PARTICIPANT	\N	PRESENT	0
367562	367466	08028W	PARTICIPANT	\N	PRESENT	0
367563	367466	14173T	PARTICIPANT	\N	PRESENT	0
367564	367466	14223L	PARTICIPANT	\N	PRESENT	0
367565	367466	14119M	PARTICIPANT	\N	PRESENT	0
367566	367466	11049P	PARTICIPANT	\N	PRESENT	0
367567	367466	11083R	PARTICIPANT	\N	PRESENT	0
367568	367466	14147R	PARTICIPANT	\N	PRESENT	0
367569	367466	17779H	PARTICIPANT	\N	PRESENT	0
367570	367466	14227Q	PARTICIPANT	\N	PRESENT	0
367571	367466	14038Y	PARTICIPANT	\N	PRESENT	0
367572	367466	08043V	PARTICIPANT	\N	PRESENT	0
367573	367466	19723Y	PARTICIPANT	\N	PRESENT	0
367574	367466	14281W	PARTICIPANT	\N	PRESENT	0
367575	367466	08012N	PARTICIPANT	\N	PRESENT	0
367576	367466	08014Q	PARTICIPANT	\N	PRESENT	0
367577	367466	18083K	PARTICIPANT	\N	PRESENT	0
367578	367466	14033T	PARTICIPANT	\N	PRESENT	0
367579	367466	08045X	PARTICIPANT	\N	PRESENT	0
367580	367466	19415P	PARTICIPANT	\N	PRESENT	0
367581	367466	08038Y	PARTICIPANT	\N	PRESENT	0
367582	367466	19399H	PARTICIPANT	\N	PRESENT	0
367583	367466	19531S	PARTICIPANT	\N	PRESENT	0
367584	367466	19683J	PARTICIPANT	\N	PRESENT	0
367585	367466	08011M	PARTICIPANT	\N	PRESENT	0
367586	367466	19447X	PARTICIPANT	\N	PRESENT	0
367587	367466	19741B	PARTICIPANT	\N	PRESENT	0
367588	367466	11072N	PARTICIPANT	\N	PRESENT	0
367589	367466	04042C	PARTICIPANT	\N	PRESENT	0
367590	367466	19503N	PARTICIPANT	\N	PRESENT	0
367591	367466	19689Q	PARTICIPANT	\N	PRESENT	0
367592	367466	19709B	PARTICIPANT	\N	PRESENT	0
367593	367466	04088S	PARTICIPANT	\N	PRESENT	0
367594	367466	04059M	PARTICIPANT	\N	PRESENT	0
366790	366789	14123H	PARTICIPANT	\N	PRESENT	0
366791	366789	19593H	PARTICIPANT	\N	PRESENT	0
366793	366792	14123H	PARTICIPANT	\N	PRESENT	0
366794	366792	19593H	PARTICIPANT	\N	PRESENT	0
366795	366792	19611R	PARTICIPANT	\N	PRESENT	0
366796	366792	14229S	PARTICIPANT	\N	PRESENT	0
371084	371078	14038Y	PARTICIPANT	\N	PRESENT	0
371131	367799	92040Q	PARTICIPANT	\N	EXCUSE	0
382631	382627	14151M	PARTICIPANT	\N	PRESENT	0
382653	379985	14093U	PARTICIPANT	\N	PRESENT	0
382655	379985	80013X	PARTICIPANT	\N	PRESENT	0
382657	379985	19693L	PARTICIPANT	\N	PRESENT	0
382660	379985	01048V	PRESIDENT	0	PRESENT	0
382662	379985	19593H	PARTICIPANT	\N	PRESENT	0
382664	379985	19533U	PARTICIPANT	\N	PRESENT	0
382671	379985	19723Y	PARTICIPANT	\N	EXCUSE	0
382669	379985	04043D	PARTICIPANT	\N	PRESENT	0
382670	379985	01058X	PARTICIPANT	\N	EXCUSE	0
382673	379985	19511N	PARTICIPANT	\N	EXCUSE	0
382676	378391	14327T	PARTICIPANT	\N	PRESENT	0
382677	378391	14231L	PARTICIPANT	\N	PRESENT	0
382678	378391	08010L	PARTICIPANT	\N	PRESENT	0
382679	378391	08034U	PARTICIPANT	\N	PRESENT	0
382680	378391	08049C	PARTICIPANT	\N	PRESENT	0
382681	378391	14063N	PARTICIPANT	\N	PRESENT	0
382682	378391	05012A	PARTICIPANT	\N	PRESENT	0
382751	382750	14085U	PARTICIPANT	\N	PRESENT	0
382752	382750	14253S	PARTICIPANT	\N	PRESENT	0
382753	380301	88008L	PARTICIPANT	\N	PRESENT	0
382755	382754	19531S	PARTICIPANT	\N	PRESENT	0
382757	382756	19531S	PARTICIPANT	\N	PRESENT	0
382759	382758	08034U	PARTICIPANT	\N	PRESENT	0
382761	382760	08034U	PARTICIPANT	\N	PRESENT	0
382763	382762	19711U	PARTICIPANT	\N	PRESENT	0
382768	376926	19631V	PARTICIPANT	\N	EXCUSE	0
382769	376926	19715Y	PARTICIPANT	\N	EXCUSE	0
382770	376926	19583F	PARTICIPANT	\N	EXCUSE	0
382771	382505	19631V	PARTICIPANT	\N	EXCUSE	0
382772	382505	19715Y	PARTICIPANT	\N	EXCUSE	0
382773	382505	19583F	PARTICIPANT	\N	EXCUSE	0
382774	382505	11054L	PARTICIPANT	\N	EXCUSE	0
382776	382775	14065Q	PARTICIPANT	\N	PRESENT	0
382777	382775	10015M	PARTICIPANT	\N	PRESENT	0
382867	382835	04057K	PARTICIPANT	\N	EXCUSE	0
382830	382828	14179A	PARTICIPANT	\N	PRESENT	0
382868	382835	19766L	PARTICIPANT	\N	EXCUSE	0
382833	382831	14179A	PARTICIPANT	\N	PRESENT	0
382866	382835	92040Q	PARTICIPANT	\N	EXCUSE	0
382869	382835	14107H	PARTICIPANT	\N	EXCUSE	0
382870	382835	14073Q	PARTICIPANT	\N	EXCUSE	0
383056	383055	08060W	PARTICIPANT	\N	PRESENT	0
383057	383055	14157T	PARTICIPANT	\N	PRESENT	0
383058	383055	14031R	PARTICIPANT	\N	PRESENT	0
383059	383055	14051J	PARTICIPANT	\N	PRESENT	0
383060	383055	19629C	PARTICIPANT	\N	PRESENT	0
383061	383055	19721W	PARTICIPANT	\N	PRESENT	0
383062	383055	14097Y	PARTICIPANT	\N	PRESENT	0
383063	383055	19762G	PARTICIPANT	\N	PRESENT	0
383064	383055	08024S	PARTICIPANT	\N	PRESENT	0
383067	383065	08060W	PARTICIPANT	\N	PRESENT	0
383068	383065	14157T	PARTICIPANT	\N	PRESENT	0
383069	383065	11048N	PARTICIPANT	\N	PRESENT	0
383070	383065	19762G	PARTICIPANT	\N	PRESENT	0
383071	383065	14097Y	PARTICIPANT	\N	PRESENT	0
382629	382627	14179A	PARTICIPANT	\N	PRESENT	0
382630	382627	14001X	PARTICIPANT	\N	PRESENT	0
383072	383065	08024S	PARTICIPANT	\N	PRESENT	0
383073	383065	19629C	PARTICIPANT	\N	PRESENT	0
383074	383065	14051J	PARTICIPANT	\N	PRESENT	0
383135	383134	04043D	PARTICIPANT	\N	PRESENT	0
383138	383137	04043D	PARTICIPANT	\N	PRESENT	0
383139	383137	19441R	PARTICIPANT	\N	PRESENT	0
384148	384147	96004D	PARTICIPANT	\N	PRESENT	0
384218	384217	14205J	PARTICIPANT	\N	PRESENT	0
384219	384217	14173T	PARTICIPANT	\N	PRESENT	0
384220	384217	08034U	PARTICIPANT	\N	PRESENT	0
384221	384217	18083K	PARTICIPANT	\N	PRESENT	0
384417	382637	08056B	PARTICIPANT	\N	EXCUSE	0
384418	382637	14097Y	PARTICIPANT	\N	EXCUSE	0
384419	382637	19583F	PARTICIPANT	\N	EXCUSE	0
384420	382637	16685X	PARTICIPANT	\N	EXCUSE	0
384421	382637	14028W	PARTICIPANT	\N	EXCUSE	0
384422	382637	14235Q	PARTICIPANT	\N	EXCUSE	0
384423	382637	19669L	PARTICIPANT	\N	EXCUSE	0
384424	382637	08049C	PARTICIPANT	\N	EXCUSE	0
384429	382637	95067Q	PARTICIPANT	\N	PRESENT	0
384614	384613	11074Q	PARTICIPANT	\N	PRESENT	0
384615	384613	08011M	PARTICIPANT	\N	PRESENT	0
384616	384613	08058D	PARTICIPANT	\N	PRESENT	0
384633	384632	08034U	PARTICIPANT	\N	PRESENT	0
384635	384634	14173T	PARTICIPANT	\N	PRESENT	0
384711	384710	19575F	PARTICIPANT	\N	PRESENT	0
384712	384710	14255U	PARTICIPANT	\N	PRESENT	0
384713	384710	19467C	PARTICIPANT	\N	PRESENT	0
384714	384710	19701S	PARTICIPANT	\N	PRESENT	0
384715	384710	14357A	PARTICIPANT	\N	PRESENT	0
384716	384710	19709B	PARTICIPANT	\N	PRESENT	0
384717	384710	14193X	PARTICIPANT	\N	PRESENT	0
384718	384710	11012A	PARTICIPANT	\N	PRESENT	0
384719	384710	04045F	PARTICIPANT	\N	PRESENT	0
384720	384710	04044E	PARTICIPANT	\N	PRESENT	0
384723	384721	14261S	PARTICIPANT	\N	PRESENT	0
384724	384721	14119M	PARTICIPANT	\N	PRESENT	0
384725	384722	14261S	PARTICIPANT	\N	PRESENT	0
384726	384722	14119M	PARTICIPANT	\N	PRESENT	0
384822	384109	19649G	PARTICIPANT	\N	PRESENT	0
384978	377916	19611R	PARTICIPANT	\N	PRESENT	0
384979	377916	04092N	PARTICIPANT	\N	PRESENT	0
384980	377916	11031D	PARTICIPANT	\N	PRESENT	0
384981	377916	19503N	PARTICIPANT	\N	PRESENT	0
384982	377916	19683J	PARTICIPANT	\N	PRESENT	0
384983	377916	08052W	PARTICIPANT	\N	PRESENT	0
384984	377916	14030Q	PARTICIPANT	\N	PRESENT	0
384985	377916	19739H	PARTICIPANT	\N	PRESENT	0
384986	377916	19762G	PARTICIPANT	\N	PRESENT	0
384987	377916	19701S	PARTICIPANT	\N	PRESENT	0
384988	377916	19798U	PARTICIPANT	\N	PRESENT	0
384989	377916	19533U	PARTICIPANT	\N	PRESENT	0
384990	377916	19794Q	PARTICIPANT	\N	PRESENT	0
384991	377916	19553Y	PARTICIPANT	\N	PRESENT	0
384992	377916	14107H	PARTICIPANT	\N	PRESENT	0
384993	377916	19713W	PARTICIPANT	\N	PRESENT	0
384994	377916	14042U	PARTICIPANT	\N	PRESENT	0
384995	377916	14215L	PARTICIPANT	\N	PRESENT	0
384996	377916	19760E	PARTICIPANT	\N	PRESENT	0
384997	377916	19367Y	PARTICIPANT	\N	PRESENT	0
384998	377916	19565D	PARTICIPANT	\N	PRESENT	0
384999	377916	14261S	PARTICIPANT	\N	PRESENT	0
385000	377916	14257W	PARTICIPANT	\N	PRESENT	0
385001	377916	19301E	PARTICIPANT	\N	PRESENT	0
385002	377916	14239U	PARTICIPANT	\N	PRESENT	0
385003	377916	11097X	PARTICIPANT	\N	PRESENT	0
385004	377916	11103C	PARTICIPANT	\N	PRESENT	0
385005	377916	19413M	PARTICIPANT	\N	PRESENT	0
385006	377916	14195A	PARTICIPANT	\N	PRESENT	0
385007	377916	19703U	PARTICIPANT	\N	PRESENT	0
385008	377916	19715Y	PARTICIPANT	\N	PRESENT	0
385009	377916	10006L	PARTICIPANT	\N	PRESENT	0
385010	377916	14281W	PARTICIPANT	\N	PRESENT	0
385011	377916	19549D	PARTICIPANT	\N	PRESENT	0
385012	377916	11045K	PARTICIPANT	\N	PRESENT	0
385013	377916	19415P	PARTICIPANT	\N	PRESENT	0
385014	377916	14217N	PARTICIPANT	\N	PRESENT	0
385015	377916	14213J	PARTICIPANT	\N	PRESENT	0
385016	377916	11043H	PARTICIPANT	\N	PRESENT	0
385017	377916	17779H	PARTICIPANT	\N	PRESENT	0
385018	377916	19693L	PARTICIPANT	\N	PRESENT	0
385019	377916	19663E	PARTICIPANT	\N	PRESENT	0
385020	377916	19727D	PARTICIPANT	\N	PRESENT	0
384976	377916	04044E	PARTICIPANT	\N	PRESENT	0
384977	377916	14219Q	PARTICIPANT	\N	PRESENT	0
385021	377916	19295A	PARTICIPANT	\N	PRESENT	0
385022	377916	19479G	PARTICIPANT	\N	PRESENT	0
385023	377916	08009T	PARTICIPANT	\N	PRESENT	0
385024	377916	14071N	PARTICIPANT	\N	PRESENT	0
385025	377916	14249W	PARTICIPANT	\N	PRESENT	0
371200	371199	11053K	PARTICIPANT	\N	PRESENT	0
371201	371199	14159V	PARTICIPANT	\N	PRESENT	0
371202	371199	05012A	PARTICIPANT	\N	PRESENT	0
371204	371203	11027H	PARTICIPANT	\N	PRESENT	0
371205	371203	19709B	PARTICIPANT	\N	PRESENT	0
386697	385939	14030Q	PRESIDENT	0	PRESENT	0
379291	378391	04040A	PRESIDENT	0	PRESENT	0
386699	385939	19643A	PARTICIPANT	\N	PRESENT	0
386700	385939	19715Y	PARTICIPANT	\N	PRESENT	0
386701	385939	08031R	PARTICIPANT	\N	PRESENT	0
386702	385939	14235Q	PARTICIPANT	\N	PRESENT	0
386703	385939	11045K	PARTICIPANT	\N	PRESENT	0
386704	385939	19749K	PARTICIPANT	\N	PRESENT	0
386714	385939	04035D	PARTICIPANT	\N	EXCUSE	0
386775	385939	08043V	PARTICIPANT	\N	EXCUSE	0
386776	385939	08024S	PARTICIPANT	\N	EXCUSE	0
386777	385939	19693L	PARTICIPANT	\N	EXCUSE	0
386778	385939	14179A	PARTICIPANT	\N	EXCUSE	0
386779	385939	07029T	PARTICIPANT	\N	EXCUSE	0
386780	385939	01043Q	PARTICIPANT	\N	EXCUSE	0
386981	377926	19685L	PARTICIPANT	\N	PRESENT	0
386982	377926	89017R	PARTICIPANT	\N	PRESENT	0
386983	377926	14055N	PARTICIPANT	\N	PRESENT	0
386984	377926	19643A	PARTICIPANT	\N	PRESENT	0
386985	377926	14169X	PARTICIPANT	\N	PRESENT	0
386986	377926	11043H	PARTICIPANT	\N	PRESENT	0
386987	377926	08031R	PARTICIPANT	\N	PRESENT	0
386988	377926	14034U	PARTICIPANT	\N	PRESENT	0
386989	377926	11080N	PARTICIPANT	\N	PRESENT	0
386990	377926	88008L	PARTICIPANT	\N	PRESENT	0
386991	377926	14259Y	PARTICIPANT	\N	PRESENT	0
386992	377926	14261S	PARTICIPANT	\N	PRESENT	0
386993	377926	19253P	PARTICIPANT	\N	PRESENT	0
386994	377926	01057W	PARTICIPANT	\N	PRESENT	0
386995	377926	19629C	PARTICIPANT	\N	PRESENT	0
386996	377926	14107H	PARTICIPANT	\N	PRESENT	0
386997	377926	11010L	PARTICIPANT	\N	PRESENT	0
386998	377926	14201E	PARTICIPANT	\N	PRESENT	0
386999	377926	14241N	PARTICIPANT	\N	PRESENT	0
387000	377926	87003B	PARTICIPANT	\N	PRESENT	0
387001	377926	19719D	PARTICIPANT	\N	PRESENT	0
387002	377926	95067Q	PARTICIPANT	\N	PRESENT	0
387003	377926	11099A	PARTICIPANT	\N	PRESENT	0
387004	377926	19387D	PARTICIPANT	\N	PRESENT	0
387005	377926	11090Q	PARTICIPANT	\N	PRESENT	0
387006	377926	19563B	PARTICIPANT	\N	PRESENT	0
387007	377926	19703U	PARTICIPANT	\N	PRESENT	0
387008	377926	14121F	PARTICIPANT	\N	PRESENT	0
387009	377926	14207L	PARTICIPANT	\N	PRESENT	0
387010	377926	19289C	PARTICIPANT	\N	PRESENT	0
387011	377926	14031R	PARTICIPANT	\N	PRESENT	0
387012	377926	19545Y	PARTICIPANT	\N	PRESENT	0
386979	377926	19731Y	PARTICIPANT	\N	PRESENT	0
386980	377926	15447F	PARTICIPANT	\N	PRESENT	0
387013	377926	19667J	PARTICIPANT	\N	PRESENT	0
387014	377926	14111D	PARTICIPANT	\N	PRESENT	0
387015	377926	19673G	PARTICIPANT	\N	PRESENT	0
387016	377926	02002K	PARTICIPANT	\N	PRESENT	0
387017	377926	14251Q	PARTICIPANT	\N	PRESENT	0
387018	377926	04057K	PARTICIPANT	\N	PRESENT	0
387019	377926	11064N	PARTICIPANT	\N	PRESENT	0
387020	377926	14199E	PARTICIPANT	\N	PRESENT	0
387021	377926	17589D	PARTICIPANT	\N	PRESENT	0
387022	377926	14093U	PARTICIPANT	\N	PRESENT	0
387068	377926	11066Q	PARTICIPANT	\N	PRESENT	0
387024	377926	19585H	PARTICIPANT	\N	PRESENT	0
387025	377926	14229S	PARTICIPANT	\N	PRESENT	0
387026	377926	11048N	PARTICIPANT	\N	PRESENT	0
387027	377926	04059M	PARTICIPANT	\N	PRESENT	0
387028	377926	04049K	PARTICIPANT	\N	PRESENT	0
387029	377926	14159V	PARTICIPANT	\N	PRESENT	0
387030	377926	08055A	PARTICIPANT	\N	PRESENT	0
387031	377926	19447X	PARTICIPANT	\N	PRESENT	0
387032	377926	08052W	PARTICIPANT	\N	PRESENT	0
387033	377926	19573D	PARTICIPANT	\N	PRESENT	0
387034	377926	01028R	PARTICIPANT	\N	PRESENT	0
387035	377926	19669L	PARTICIPANT	\N	PRESENT	0
387036	377926	19794Q	PARTICIPANT	\N	PRESENT	0
387037	377926	08045X	PARTICIPANT	\N	PRESENT	0
387038	377926	14119M	PARTICIPANT	\N	PRESENT	0
387039	377926	14225N	PARTICIPANT	\N	PRESENT	0
387040	377926	08047A	PARTICIPANT	\N	PRESENT	0
387041	377926	19599P	PARTICIPANT	\N	PRESENT	0
387042	377926	14105F	PARTICIPANT	\N	PRESENT	0
387043	377926	12016W	PARTICIPANT	\N	PRESENT	0
387044	377926	14115H	PARTICIPANT	\N	PRESENT	0
387045	377926	19715Y	PARTICIPANT	\N	PRESENT	0
387046	377926	11083R	PARTICIPANT	\N	PRESENT	0
387047	377926	14038Y	PARTICIPANT	\N	PRESENT	0
387048	377926	11101A	PARTICIPANT	\N	PRESENT	0
387049	377926	01062T	PARTICIPANT	\N	PRESENT	0
387050	377926	19467C	PARTICIPANT	\N	PRESENT	0
387051	377926	08038Y	PARTICIPANT	\N	PRESENT	0
387052	377926	08053X	PARTICIPANT	\N	PRESENT	0
387053	377926	18083K	PARTICIPANT	\N	PRESENT	0
387054	377926	11045K	PARTICIPANT	\N	PRESENT	0
387055	377926	19415P	PARTICIPANT	\N	PRESENT	0
387056	377926	14033T	PARTICIPANT	\N	PRESENT	0
387057	377926	14135M	PARTICIPANT	\N	PRESENT	0
387058	377926	14021P	PARTICIPANT	\N	PRESENT	0
387059	377926	19399H	PARTICIPANT	\N	PRESENT	0
387060	377926	19649G	PARTICIPANT	\N	PRESENT	0
387061	377926	08048B	PARTICIPANT	\N	PRESENT	0
387062	377926	19647E	PARTICIPANT	\N	PRESENT	0
387063	377926	14265W	PARTICIPANT	\N	PRESENT	0
387064	377926	14213J	PARTICIPANT	\N	PRESENT	0
387065	377926	14065Q	PARTICIPANT	\N	PRESENT	0
387066	377926	19575F	PARTICIPANT	\N	PRESENT	0
387067	377926	19443T	PARTICIPANT	\N	PRESENT	0
387069	377926	19741B	PARTICIPANT	\N	PRESENT	0
387070	377926	14029X	PARTICIPANT	\N	PRESENT	0
387071	377926	96004D	PARTICIPANT	\N	PRESENT	0
387072	377926	08017T	PARTICIPANT	\N	PRESENT	0
387073	377926	19507S	PARTICIPANT	\N	PRESENT	0
387074	377926	11104D	PARTICIPANT	\N	PRESENT	0
387075	377926	19663E	PARTICIPANT	\N	PRESENT	0
387076	377926	19531S	PARTICIPANT	\N	PRESENT	0
387077	377926	04088S	PARTICIPANT	\N	PRESENT	0
387078	377926	08012N	PARTICIPANT	\N	PRESENT	0
387079	377926	19727D	PARTICIPANT	\N	PRESENT	0
387080	377926	14041T	PARTICIPANT	\N	PRESENT	0
387081	377926	14081Q	PARTICIPANT	\N	PRESENT	0
387082	377926	11110B	PARTICIPANT	\N	PRESENT	0
387083	377926	07029T	PARTICIPANT	\N	PRESENT	0
387084	377926	19525U	PARTICIPANT	\N	PRESENT	0
387085	377926	14257W	PARTICIPANT	\N	PRESENT	0
387086	377926	14085U	PARTICIPANT	\N	PRESENT	0
387087	377926	08058D	PARTICIPANT	\N	PRESENT	0
387088	377926	11026G	PARTICIPANT	\N	PRESENT	0
387089	377926	19489J	PARTICIPANT	\N	PRESENT	0
387090	377926	19657G	PARTICIPANT	\N	PRESENT	0
387091	377926	08014Q	PARTICIPANT	\N	PRESENT	0
387092	377926	14227Q	PARTICIPANT	\N	PRESENT	0
387093	377926	08062Y	PARTICIPANT	\N	PRESENT	0
387094	377926	11109J	PARTICIPANT	\N	PRESENT	0
387095	377926	19295A	PARTICIPANT	\N	PRESENT	0
387096	377926	14079W	PARTICIPANT	\N	PRESENT	0
387097	377926	11054L	PARTICIPANT	\N	PRESENT	0
387098	377926	19725B	PARTICIPANT	\N	PRESENT	0
387099	377926	08015R	PARTICIPANT	\N	PRESENT	0
387100	377926	14097Y	PARTICIPANT	\N	PRESENT	0
387101	377926	19729F	PARTICIPANT	\N	PRESENT	0
387102	377926	19553Y	PARTICIPANT	\N	PRESENT	0
387103	377926	19631V	PARTICIPANT	\N	PRESENT	0
387104	377926	14063N	PARTICIPANT	\N	PRESENT	0
387105	377926	19527W	PARTICIPANT	\N	PRESENT	0
387106	377926	19705W	PARTICIPANT	\N	PRESENT	0
387107	377926	19551W	PARTICIPANT	\N	PRESENT	0
387108	377926	10015M	PARTICIPANT	\N	PRESENT	0
387109	377926	11067R	PARTICIPANT	\N	PRESENT	0
387110	377926	19503N	PARTICIPANT	\N	PRESENT	0
387111	377926	19689Q	PARTICIPANT	\N	PRESENT	0
387112	377926	19251M	PARTICIPANT	\N	PRESENT	0
387113	377926	98024R	PARTICIPANT	\N	PRESENT	0
387114	377926	17779H	PARTICIPANT	\N	PRESENT	0
387115	377926	19347U	PARTICIPANT	\N	PRESENT	0
387116	377926	14026U	PARTICIPANT	\N	PRESENT	0
387117	377926	04086Q	PARTICIPANT	\N	PRESENT	0
387118	377926	19565D	PARTICIPANT	\N	PRESENT	0
387119	377926	04092N	PARTICIPANT	\N	PRESENT	0
387120	377926	04044E	PARTICIPANT	\N	PRESENT	0
387121	377926	19695N	PARTICIPANT	\N	PRESENT	0
387122	377926	04033B	PARTICIPANT	\N	PRESENT	0
387123	377926	14187A	PARTICIPANT	\N	PRESENT	0
387124	377926	08044W	PARTICIPANT	\N	PRESENT	0
387125	377926	11097X	PARTICIPANT	\N	PRESENT	0
387126	377926	14179A	PARTICIPANT	\N	PRESENT	0
387127	377926	19421M	PARTICIPANT	\N	PRESENT	0
387128	377926	14275Y	PARTICIPANT	\N	PRESENT	0
363145	361142	14195A	PARTICIPANT	\N	EXCUSE	0
363173	363172	98022P	PARTICIPANT	\N	PRESENT	0
368990	367007	14028W	PARTICIPANT	\N	EXCUSE	0
369417	356298	14081Q	PARTICIPANT	\N	PRESENT	0
369418	356298	11026G	PARTICIPANT	\N	PRESENT	0
369419	356298	19631V	PARTICIPANT	\N	PRESENT	0
369420	356298	19565D	PARTICIPANT	\N	PRESENT	0
369422	356298	19758L	PARTICIPANT	\N	PRESENT	0
369423	356298	19760E	PARTICIPANT	\N	PRESENT	0
369424	356298	11077T	PARTICIPANT	\N	PRESENT	0
369425	356298	04034C	PARTICIPANT	\N	PRESENT	0
369426	356298	16685X	PARTICIPANT	\N	PRESENT	0
369427	356298	14083S	PARTICIPANT	\N	PRESENT	0
369428	356298	08068F	PARTICIPANT	\N	PRESENT	0
369429	356298	14073Q	PARTICIPANT	\N	PRESENT	0
369430	356298	19745F	PARTICIPANT	\N	PRESENT	0
369432	356298	19747H	PARTICIPANT	\N	PRESENT	0
369435	356298	14329V	PARTICIPANT	\N	PRESENT	0
369437	356298	14079W	PARTICIPANT	\N	PRESENT	0
369439	356298	14026U	PARTICIPANT	\N	PRESENT	0
369441	356298	14265W	PARTICIPANT	\N	PRESENT	0
369444	356298	08062Y	PARTICIPANT	\N	PRESENT	0
369446	356298	07029T	PARTICIPANT	\N	PRESENT	0
369449	356298	19507S	PARTICIPANT	\N	PRESENT	0
369450	356298	19794Q	PARTICIPANT	\N	PRESENT	0
369453	356298	19413M	PARTICIPANT	\N	PRESENT	0
369455	356298	19515S	PARTICIPANT	\N	PRESENT	0
369456	356298	17583W	PARTICIPANT	\N	PRESENT	0
369457	356298	14105F	PARTICIPANT	\N	PRESENT	0
369458	356298	04049K	PARTICIPANT	\N	PRESENT	0
369459	356298	14223L	PARTICIPANT	\N	PRESENT	0
369460	356298	19575F	PARTICIPANT	\N	PRESENT	0
369461	356298	95062K	PARTICIPANT	\N	PRESENT	0
369462	356298	19679N	PARTICIPANT	\N	PRESENT	0
369463	356298	19723Y	PARTICIPANT	\N	PRESENT	0
369464	356298	01024M	PARTICIPANT	\N	PRESENT	0
369465	356298	01058X	PARTICIPANT	\N	PRESENT	0
369466	356298	19479G	PARTICIPANT	\N	PRESENT	0
369467	356298	14087W	PARTICIPANT	\N	PRESENT	0
369468	356298	19681G	PARTICIPANT	\N	PRESENT	0
369469	356298	14219Q	PARTICIPANT	\N	PRESENT	0
369470	356298	19585H	PARTICIPANT	\N	PRESENT	0
369471	356298	96004D	PARTICIPANT	\N	PRESENT	0
369472	356298	08020N	PARTICIPANT	\N	PRESENT	0
369473	356298	80013X	PARTICIPANT	\N	PRESENT	0
369474	356298	14221J	PARTICIPANT	\N	PRESENT	0
369475	356298	14357A	PARTICIPANT	\N	PRESENT	0
369476	356298	19762G	PARTICIPANT	\N	PRESENT	0
369477	356298	19563B	PARTICIPANT	\N	PRESENT	0
369478	356298	14157T	PARTICIPANT	\N	PRESENT	0
369479	356298	14147R	PARTICIPANT	\N	PRESENT	0
369480	356298	14033T	PARTICIPANT	\N	PRESENT	0
369481	356298	11048N	PARTICIPANT	\N	PRESENT	0
369482	356298	19441R	PARTICIPANT	\N	PRESENT	0
369483	356298	08031R	PARTICIPANT	\N	PRESENT	0
369484	356298	14217N	PARTICIPANT	\N	PRESENT	0
369485	356298	14327T	PARTICIPANT	\N	PRESENT	0
369486	356298	14053L	PARTICIPANT	\N	PRESENT	0
369487	356298	14069U	PARTICIPANT	\N	PRESENT	0
369488	356298	19551W	PARTICIPANT	\N	PRESENT	0
369489	356298	14030Q	PARTICIPANT	\N	PRESENT	0
369490	356298	19467C	PARTICIPANT	\N	PRESENT	0
369491	356298	08056B	PARTICIPANT	\N	PRESENT	0
369492	356298	14207L	PARTICIPANT	\N	PRESENT	0
369493	356298	01025N	PARTICIPANT	\N	PRESENT	0
369494	356298	11012A	PARTICIPANT	\N	PRESENT	0
369495	356298	19691J	PARTICIPANT	\N	PRESENT	0
369496	356298	04088S	PARTICIPANT	\N	PRESENT	0
369497	356298	04040A	PARTICIPANT	\N	PRESENT	0
369506	356298	11090Q	PARTICIPANT	\N	PRESENT	0
369504	356298	19701S	PARTICIPANT	\N	PRESENT	0
369505	356298	11097X	PARTICIPANT	\N	PRESENT	0
369507	356298	19349W	PARTICIPANT	\N	PRESENT	0
369508	356298	19782L	PARTICIPANT	\N	PRESENT	0
369509	356298	14061L	PARTICIPANT	\N	PRESENT	0
369580	356299	14065Q	PARTICIPANT	\N	PRESENT	0
369581	356299	19725B	PARTICIPANT	\N	PRESENT	0
369582	356299	19551W	PARTICIPANT	\N	PRESENT	0
369583	356299	19565D	PARTICIPANT	\N	PRESENT	0
369584	356299	19563B	PARTICIPANT	\N	PRESENT	0
369585	356299	19629C	PARTICIPANT	\N	PRESENT	0
369586	356299	04045F	PARTICIPANT	\N	PRESENT	0
369587	356299	14073Q	PARTICIPANT	\N	PRESENT	0
369588	356299	19747H	PARTICIPANT	\N	PRESENT	0
369589	356299	04040A	PARTICIPANT	\N	PRESENT	0
369590	356299	19737F	PARTICIPANT	\N	PRESENT	0
369591	356299	19760E	PARTICIPANT	\N	PRESENT	0
369592	356299	19758L	PARTICIPANT	\N	PRESENT	0
369593	356299	19553Y	PARTICIPANT	\N	PRESENT	0
369594	356299	14061L	PARTICIPANT	\N	PRESENT	0
369595	356299	05012A	PARTICIPANT	\N	PRESENT	0
369415	356298	14034U	PARTICIPANT	\N	PRESENT	0
369416	356298	17589D	PARTICIPANT	\N	PRESENT	0
369596	356299	14179A	PARTICIPANT	\N	PRESENT	0
369597	356299	14079W	PARTICIPANT	\N	PRESENT	0
369598	356299	14215L	PARTICIPANT	\N	PRESENT	0
369599	356299	14217N	PARTICIPANT	\N	PRESENT	0
369600	356299	01060R	PARTICIPANT	\N	PRESENT	0
369601	356299	19335Q	PARTICIPANT	\N	PRESENT	0
369602	356299	19621T	PARTICIPANT	\N	PRESENT	0
369603	356299	07029T	PARTICIPANT	\N	PRESENT	0
369604	356299	14033T	PARTICIPANT	\N	PRESENT	0
369605	356299	04088S	PARTICIPANT	\N	PRESENT	0
369606	356299	04038G	PARTICIPANT	\N	PRESENT	0
369607	356299	14029X	PARTICIPANT	\N	PRESENT	0
369608	356299	19794Q	PARTICIPANT	\N	PRESENT	0
369609	356299	14157T	PARTICIPANT	\N	PRESENT	0
369610	356299	92040Q	PARTICIPANT	\N	PRESENT	0
369611	356299	14107H	PARTICIPANT	\N	PRESENT	0
369612	356299	19681G	PARTICIPANT	\N	PRESENT	0
369613	356299	11097X	PARTICIPANT	\N	PRESENT	0
369614	356299	10015M	PARTICIPANT	\N	PRESENT	0
369615	356299	05008E	PARTICIPANT	\N	PRESENT	0
369616	356299	04061F	PARTICIPANT	\N	PRESENT	0
369617	356299	04044E	PARTICIPANT	\N	PRESENT	0
369618	356299	19762G	PARTICIPANT	\N	PRESENT	0
369619	356299	14265W	PARTICIPANT	\N	PRESENT	0
369620	356299	19447X	PARTICIPANT	\N	PRESENT	0
369621	356299	14187A	PARTICIPANT	\N	PRESENT	0
369622	356299	04033B	PARTICIPANT	\N	PRESENT	0
369623	356299	19507S	PARTICIPANT	\N	PRESENT	0
369624	356299	14241N	PARTICIPANT	\N	PRESENT	0
369625	356299	14071N	PARTICIPANT	\N	PRESENT	0
369626	356299	14034U	PARTICIPANT	\N	PRESENT	0
369627	356299	11056N	PARTICIPANT	\N	PRESENT	0
369628	356299	14147R	PARTICIPANT	\N	PRESENT	0
369629	356299	14026U	PARTICIPANT	\N	PRESENT	0
369630	356299	14213J	PARTICIPANT	\N	PRESENT	0
369631	356299	14357A	PARTICIPANT	\N	PRESENT	0
369632	356299	14231L	PARTICIPANT	\N	PRESENT	0
369633	356299	19741B	PARTICIPANT	\N	PRESENT	0
369634	356299	08031R	PARTICIPANT	\N	PRESENT	0
369635	356299	01024M	PARTICIPANT	\N	PRESENT	0
369636	356299	14083S	PARTICIPANT	\N	PRESENT	0
369637	356299	01062T	PARTICIPANT	\N	PRESENT	0
369638	356299	14069U	PARTICIPANT	\N	PRESENT	0
369639	356299	18083K	PARTICIPANT	\N	PRESENT	0
369640	356299	14089Y	PARTICIPANT	\N	PRESENT	0
369641	356299	08015R	PARTICIPANT	\N	PRESENT	0
369642	356299	01028R	PARTICIPANT	\N	PRESENT	0
369679	369678	14053L	PARTICIPANT	\N	PRESENT	0
369680	369678	19719D	PARTICIPANT	\N	PRESENT	0
369681	369678	14026U	PARTICIPANT	\N	PRESENT	0
369683	369682	14053L	PARTICIPANT	\N	PRESENT	0
369684	369682	19719D	PARTICIPANT	\N	PRESENT	0
369578	356299	04086Q	PARTICIPANT	\N	PRESENT	0
369579	356299	14053L	PARTICIPANT	\N	PRESENT	0
369686	369685	14053L	PARTICIPANT	\N	PRESENT	0
369687	369685	19719D	PARTICIPANT	\N	PRESENT	0
367595	367466	19253P	PARTICIPANT	\N	PRESENT	0
367596	367466	08031R	PARTICIPANT	\N	PRESENT	0
367597	367466	08061X	PARTICIPANT	\N	PRESENT	0
367598	367466	08058D	PARTICIPANT	\N	PRESENT	0
367599	367466	11067R	PARTICIPANT	\N	PRESENT	0
367600	367466	14199E	PARTICIPANT	\N	PRESENT	0
367601	367466	19507S	PARTICIPANT	\N	PRESENT	0
367602	367466	10015M	PARTICIPANT	\N	PRESENT	0
367603	367466	19631V	PARTICIPANT	\N	PRESENT	0
367604	367466	04049K	PARTICIPANT	\N	PRESENT	0
367615	367466	19349W	PARTICIPANT	\N	PRESENT	0
367606	367466	19673G	PARTICIPANT	\N	PRESENT	0
367607	367466	07029T	PARTICIPANT	\N	PRESENT	0
367608	367466	19543W	PARTICIPANT	\N	PRESENT	0
367609	367466	19533U	PARTICIPANT	\N	PRESENT	0
367610	367466	08024S	PARTICIPANT	\N	PRESENT	0
367611	367466	98024R	PARTICIPANT	\N	PRESENT	0
367612	367466	19329S	PARTICIPANT	\N	PRESENT	0
367613	367466	04044E	PARTICIPANT	\N	PRESENT	0
367614	367466	08073C	PARTICIPANT	\N	PRESENT	0
367616	367466	95041E	PARTICIPANT	\N	PRESENT	0
367617	367466	19269X	PARTICIPANT	\N	PRESENT	0
367618	367466	95063L	PARTICIPANT	\N	PRESENT	0
367619	367466	04092N	PARTICIPANT	\N	PRESENT	0
367620	367466	14071N	PARTICIPANT	\N	PRESENT	0
367621	367466	11097X	PARTICIPANT	\N	PRESENT	0
367622	367466	14021P	PARTICIPANT	\N	PRESENT	0
367623	367466	14151M	PARTICIPANT	\N	PRESENT	0
367624	367466	11090Q	PARTICIPANT	\N	PRESENT	0
367625	367466	04043D	PARTICIPANT	\N	PRESENT	0
367626	367466	14001X	PARTICIPANT	\N	PRESENT	0
367627	367466	14187A	PARTICIPANT	\N	PRESENT	0
367628	367466	14207L	PARTICIPANT	\N	PRESENT	0
367629	367466	14087W	PARTICIPANT	\N	PRESENT	0
367630	367466	14085U	PARTICIPANT	\N	PRESENT	0
367631	367466	05012A	PARTICIPANT	\N	PRESENT	0
367632	367466	14065Q	PARTICIPANT	\N	PRESENT	0
367633	367466	08034U	PARTICIPANT	\N	PRESENT	0
367634	367466	01062T	PARTICIPANT	\N	PRESENT	0
367635	367466	07033P	PARTICIPANT	\N	PRESENT	0
367636	367466	14229S	PARTICIPANT	\N	PRESENT	0
367637	367466	14217N	PARTICIPANT	\N	PRESENT	0
367638	367466	14331P	PARTICIPANT	\N	PRESENT	0
367639	367466	95062K	PARTICIPANT	\N	PRESENT	0
367640	367466	14079W	PARTICIPANT	\N	PRESENT	0
367641	367466	11027H	PARTICIPANT	\N	PRESENT	0
367642	367466	19581D	PARTICIPANT	\N	PRESENT	0
367643	367466	19671E	PARTICIPANT	\N	PRESENT	0
367644	367466	19599P	PARTICIPANT	\N	PRESENT	0
367645	367466	19747H	PARTICIPANT	\N	PRESENT	0
367646	367466	08019V	PARTICIPANT	\N	PRESENT	0
367647	367466	19693L	PARTICIPANT	\N	PRESENT	0
367648	367466	14213J	PARTICIPANT	\N	PRESENT	0
367649	367466	14357A	PARTICIPANT	\N	PRESENT	0
367650	367466	04033B	PARTICIPANT	\N	PRESENT	0
367651	367466	19675J	PARTICIPANT	\N	PRESENT	0
367652	367466	19383Y	PARTICIPANT	\N	PRESENT	0
367653	367466	19758L	PARTICIPANT	\N	PRESENT	0
367654	367466	04018C	PARTICIPANT	\N	PRESENT	0
367655	367466	11033F	PARTICIPANT	\N	PRESENT	0
367656	367466	04034C	PARTICIPANT	\N	PRESENT	0
367657	367466	19621T	PARTICIPANT	\N	PRESENT	0
367658	367466	14026U	PARTICIPANT	\N	PRESENT	0
367659	367466	95037J	PARTICIPANT	\N	PRESENT	0
367660	367466	11048N	PARTICIPANT	\N	PRESENT	0
367661	367466	89017R	PARTICIPANT	\N	PRESENT	0
367662	367466	14055N	PARTICIPANT	\N	PRESENT	0
367663	367466	88008L	PARTICIPANT	\N	PRESENT	0
367664	367466	19367Y	PARTICIPANT	\N	PRESENT	0
367665	367466	11065P	PARTICIPANT	\N	PRESENT	0
367666	367466	14069U	PARTICIPANT	\N	PRESENT	0
367667	367466	19719D	PARTICIPANT	\N	PRESENT	0
367668	367466	19657G	PARTICIPANT	\N	PRESENT	0
367669	367466	08021P	PARTICIPANT	\N	PRESENT	0
367670	367466	14107H	PARTICIPANT	\N	PRESENT	0
367671	367466	08010L	PARTICIPANT	\N	PRESENT	0
367672	367466	19705W	PARTICIPANT	\N	PRESENT	0
367673	367466	98050T	PARTICIPANT	\N	PRESENT	0
367674	367466	14257W	PARTICIPANT	\N	PRESENT	0
367675	367466	14061L	PARTICIPANT	\N	PRESENT	0
367676	367466	14059S	PARTICIPANT	\N	PRESENT	0
367677	367466	19413M	PARTICIPANT	\N	PRESENT	0
367678	367466	11041F	PARTICIPANT	\N	PRESENT	0
367679	367466	19768N	PARTICIPANT	\N	PRESENT	0
367680	367466	11045K	PARTICIPANT	\N	PRESENT	0
367681	367466	04061F	PARTICIPANT	\N	PRESENT	0
367682	367466	04035D	PARTICIPANT	\N	PRESENT	0
367683	367466	17637T	PARTICIPANT	\N	PRESENT	0
367684	367466	14123H	PARTICIPANT	\N	PRESENT	0
367685	367466	19663E	PARTICIPANT	\N	PRESENT	0
367686	367466	19713W	PARTICIPANT	\N	PRESENT	0
367687	367466	14275Y	PARTICIPANT	\N	PRESENT	0
367688	367466	19611R	PARTICIPANT	\N	PRESENT	0
367689	367466	08044W	PARTICIPANT	\N	PRESENT	0
367690	367466	19441R	PARTICIPANT	\N	PRESENT	0
367691	367466	19794Q	PARTICIPANT	\N	PRESENT	0
367692	367466	16685X	PARTICIPANT	\N	PRESENT	0
367693	367466	19619A	PARTICIPANT	\N	PRESENT	0
367694	367466	19721W	PARTICIPANT	\N	PRESENT	0
367695	367466	14179A	PARTICIPANT	\N	PRESENT	0
367696	367466	04089T	PARTICIPANT	\N	PRESENT	0
367697	367466	14231L	PARTICIPANT	\N	PRESENT	0
367698	367466	14135M	PARTICIPANT	\N	PRESENT	0
367699	367466	07004J	PARTICIPANT	\N	PRESENT	0
367700	367466	19569H	PARTICIPANT	\N	PRESENT	0
367701	367466	19735D	PARTICIPANT	\N	PRESENT	0
367702	367466	14221J	PARTICIPANT	\N	PRESENT	0
367703	367466	14103D	PARTICIPANT	\N	PRESENT	0
367704	367466	19739H	PARTICIPANT	\N	PRESENT	0
367705	367466	19335Q	PARTICIPANT	\N	PRESENT	0
367706	367466	14215L	PARTICIPANT	\N	PRESENT	0
367707	367466	19749K	PARTICIPANT	\N	PRESENT	0
367708	367466	19745F	PARTICIPANT	\N	PRESENT	0
367709	367466	14089Y	PARTICIPANT	\N	PRESENT	0
367710	367466	04071H	PARTICIPANT	\N	PRESENT	0
367711	367466	11070L	PARTICIPANT	\N	PRESENT	0
367712	367466	14255U	PARTICIPANT	\N	PRESENT	0
367713	367466	19577H	PARTICIPANT	\N	PRESENT	0
367714	367466	14205J	PARTICIPANT	\N	PRESENT	0
367715	367466	01025N	PARTICIPANT	\N	PRESENT	0
367716	367466	04070G	PARTICIPANT	\N	PRESENT	0
367717	367466	14030Q	PARTICIPANT	\N	PRESENT	0
367718	367466	14327T	PARTICIPANT	\N	PRESENT	0
367719	367466	01024M	PARTICIPANT	\N	PRESENT	0
367720	367466	01043Q	PARTICIPANT	\N	PRESENT	0
367721	367466	97011G	PARTICIPANT	\N	PRESENT	0
367722	367466	19727D	PARTICIPANT	\N	PRESENT	0
367723	367466	19369B	PARTICIPANT	\N	PRESENT	0
367724	367466	87003B	PARTICIPANT	\N	PRESENT	0
367725	367466	95030B	PARTICIPANT	\N	PRESENT	0
367726	367466	19573D	PARTICIPANT	\N	PRESENT	0
367727	367466	19717B	PARTICIPANT	\N	PRESENT	0
367728	367466	19563B	PARTICIPANT	\N	PRESENT	0
367729	367466	14265W	PARTICIPANT	\N	PRESENT	0
367730	367466	08068F	PARTICIPANT	\N	PRESENT	0
367731	367466	19643A	PARTICIPANT	\N	PRESENT	0
367732	367466	14157T	PARTICIPANT	\N	PRESENT	0
367733	367466	19549D	PARTICIPANT	\N	PRESENT	0
367734	367466	14121F	PARTICIPANT	\N	PRESENT	0
367735	367466	17583W	PARTICIPANT	\N	PRESENT	0
367736	367466	19733B	PARTICIPANT	\N	PRESENT	0
367737	367466	08015R	PARTICIPANT	\N	PRESENT	0
367738	367466	19711U	PARTICIPANT	\N	PRESENT	0
367750	367466	14249W	PARTICIPANT	\N	PRESENT	0
367740	367466	14031R	PARTICIPANT	\N	PRESENT	0
367741	367466	08009T	PARTICIPANT	\N	PRESENT	0
367742	367466	14053L	PARTICIPANT	\N	PRESENT	0
367743	367466	14042U	PARTICIPANT	\N	PRESENT	0
367744	367466	14081Q	PARTICIPANT	\N	PRESENT	0
367745	367466	04038G	PARTICIPANT	\N	PRESENT	0
367746	367466	19289C	PARTICIPANT	\N	PRESENT	0
367747	367466	14329V	PARTICIPANT	\N	PRESENT	0
367748	367466	05008E	PARTICIPANT	\N	PRESENT	0
367749	367466	14259Y	PARTICIPANT	\N	PRESENT	0
367751	367466	11026G	PARTICIPANT	\N	PRESENT	0
367752	367466	19591F	PARTICIPANT	\N	PRESENT	0
367753	367466	14237S	PARTICIPANT	\N	PRESENT	0
367755	367466	11080N	PARTICIPANT	\N	PRESENT	0
367756	367466	14251Q	PARTICIPANT	\N	PRESENT	0
367757	367466	19545Y	PARTICIPANT	\N	PRESENT	0
367758	367466	14111D	PARTICIPANT	\N	PRESENT	0
367759	367466	19585H	PARTICIPANT	\N	PRESENT	0
367760	367466	19583F	PARTICIPANT	\N	PRESENT	0
367761	367466	14034U	PARTICIPANT	\N	PRESENT	0
367762	367466	98005N	PARTICIPANT	\N	PRESENT	0
367766	367466	02002K	PARTICIPANT	\N	PRESENT	0
367764	367466	08039A	PARTICIPANT	\N	PRESENT	0
367765	367466	11115U	PARTICIPANT	\N	PRESENT	0
365867	363174	04092N	PRESIDENT	0	PRESENT	0
365868	363174	19798U	PARTICIPANT	\N	PRESENT	0
365869	363174	08052W	PARTICIPANT	\N	PRESENT	0
365870	363174	19415P	PARTICIPANT	\N	PRESENT	0
365871	363174	19301E	PARTICIPANT	\N	PRESENT	0
365872	363174	19691J	PARTICIPANT	\N	PRESENT	0
365873	363174	19715Y	PARTICIPANT	\N	PRESENT	0
365874	363174	14223L	PARTICIPANT	\N	PRESENT	0
365894	363174	11031D	PARTICIPANT	\N	PRESENT	0
365876	363174	19703U	PARTICIPANT	\N	PRESENT	0
365877	363174	14239U	PARTICIPANT	\N	PRESENT	0
365895	363174	19553Y	PARTICIPANT	\N	PRESENT	0
365879	363174	11103C	PARTICIPANT	\N	PRESENT	0
365880	363174	14042U	PARTICIPANT	\N	PRESENT	0
365881	363174	14195A	PARTICIPANT	\N	PRESENT	0
365882	363174	19367Y	PARTICIPANT	\N	PRESENT	0
365896	363174	19575F	PARTICIPANT	\N	PRESENT	0
365884	363174	98024R	PARTICIPANT	\N	PRESENT	0
365885	363174	08041T	PARTICIPANT	\N	EXCUSE	0
365886	363174	19565D	PARTICIPANT	\N	PRESENT	0
365887	363174	19727D	PARTICIPANT	\N	PRESENT	0
365888	363174	14213J	PARTICIPANT	\N	PRESENT	0
365889	363174	14071N	PARTICIPANT	\N	PRESENT	0
365890	363174	14119M	PARTICIPANT	\N	PRESENT	0
365891	363174	19679N	PARTICIPANT	\N	PRESENT	0
365892	363174	14261S	PARTICIPANT	\N	PRESENT	0
365893	363174	14227Q	PARTICIPANT	\N	PRESENT	0
365897	363174	01034P	PARTICIPANT	\N	PRESENT	0
365898	363174	19697Q	PARTICIPANT	\N	EXCUSE	0
365899	363174	11067R	PARTICIPANT	\N	EXCUSE	0
365900	363174	10006L	PARTICIPANT	\N	EXCUSE	0
365901	363174	19760E	PARTICIPANT	\N	PRESENT	0
366023	362302	19591F	PARTICIPANT	\N	PRESENT	0
366024	362302	11056N	PARTICIPANT	\N	PRESENT	0
366418	364282	14225N	PARTICIPANT	\N	PRESENT	0
366419	364282	19651A	PARTICIPANT	\N	PRESENT	0
366420	364282	19689Q	PARTICIPANT	\N	PRESENT	0
366421	364282	11012A	PARTICIPANT	\N	PRESENT	0
366422	364282	19711U	PARTICIPANT	\N	PRESENT	0
366423	364282	14034U	PARTICIPANT	\N	PRESENT	0
366487	365637	04070G	PRESIDENT	0	PRESENT	0
366488	365637	19533U	PARTICIPANT	\N	PRESENT	0
366489	365637	14229S	PARTICIPANT	\N	PRESENT	0
366490	365637	14241N	PARTICIPANT	\N	PRESENT	0
366491	365637	19573D	PARTICIPANT	\N	PRESENT	0
366492	365637	14039A	PARTICIPANT	\N	PRESENT	0
366493	365637	08017T	PARTICIPANT	\N	PRESENT	0
366494	365637	07033P	PARTICIPANT	\N	PRESENT	0
366495	365637	19335Q	PARTICIPANT	\N	PRESENT	0
366496	365637	14249W	PARTICIPANT	\N	PRESENT	0
366497	365637	08039A	PARTICIPANT	\N	PRESENT	0
366498	365637	08031R	PARTICIPANT	\N	PRESENT	0
366499	365637	19593H	PARTICIPANT	\N	PRESENT	0
366500	365637	14059S	PARTICIPANT	\N	PRESENT	0
366501	365637	14061L	PARTICIPANT	\N	PRESENT	0
366502	365637	04057K	PARTICIPANT	\N	PRESENT	0
366503	365637	14073Q	PARTICIPANT	\N	PRESENT	0
366504	365637	08035V	PARTICIPANT	\N	PRESENT	0
366505	365637	19611R	PARTICIPANT	\N	PRESENT	0
366506	365637	08043V	PARTICIPANT	\N	PRESENT	0
366507	365637	19693L	PARTICIPANT	\N	PRESENT	0
366508	365637	87003B	PARTICIPANT	\N	PRESENT	0
366509	365637	19399H	PARTICIPANT	\N	PRESENT	0
366510	365637	14030Q	PARTICIPANT	\N	PRESENT	0
366511	365637	08020N	PARTICIPANT	\N	PRESENT	0
366512	365637	04059M	PARTICIPANT	\N	PRESENT	0
366513	365637	19735D	PARTICIPANT	\N	PRESENT	0
366514	365637	11083R	PARTICIPANT	\N	PRESENT	0
366515	365637	14109K	PARTICIPANT	\N	PRESENT	0
366516	365637	14063N	PARTICIPANT	\N	PRESENT	0
366517	365637	14123H	PARTICIPANT	\N	PRESENT	0
366518	365637	11043H	PARTICIPANT	\N	PRESENT	0
366519	365637	04018C	PARTICIPANT	\N	PRESENT	0
366520	365637	19758L	PARTICIPANT	\N	PRESENT	0
366521	365637	19766L	PARTICIPANT	\N	EXCUSE	0
366522	365637	19643A	PARTICIPANT	\N	EXCUSE	0
366523	365637	19699S	PARTICIPANT	\N	EXCUSE	0
366524	365637	19731Y	PARTICIPANT	\N	EXCUSE	0
366525	365637	11104D	PARTICIPANT	\N	EXCUSE	0
366526	363174	19569H	PARTICIPANT	\N	PRESENT	0
366527	363174	11097X	PARTICIPANT	\N	PRESENT	0
366528	363174	08048B	PARTICIPANT	\N	PRESENT	0
366529	363174	19521Q	PARTICIPANT	\N	PRESENT	0
366530	363174	19663E	PARTICIPANT	\N	PRESENT	0
366531	363174	17779H	PARTICIPANT	\N	EXCUSE	0
366617	345243	08009T	PARTICIPANT	\N	PRESENT	0
366618	345243	19333N	PARTICIPANT	\N	PRESENT	0
366619	345243	19551W	PARTICIPANT	\N	PRESENT	0
366620	345243	19637C	PARTICIPANT	\N	PRESENT	0
366621	345243	19525U	PARTICIPANT	\N	PRESENT	0
366623	345243	19599P	PARTICIPANT	\N	PRESENT	0
366624	345243	19585H	PARTICIPANT	\N	PRESENT	0
366625	345243	04085P	PARTICIPANT	\N	PRESENT	0
366626	345243	14089Y	PARTICIPANT	\N	PRESENT	0
366627	345243	19467C	PARTICIPANT	\N	PRESENT	0
366628	345243	14033T	PARTICIPANT	\N	PRESENT	0
366629	345243	08015R	PARTICIPANT	\N	PRESENT	0
366630	345243	14105F	PARTICIPANT	\N	PRESENT	0
366631	345243	95030B	PARTICIPANT	\N	PRESENT	0
366632	345243	19387D	PARTICIPANT	\N	PRESENT	0
366633	345243	19737F	PARTICIPANT	\N	PRESENT	0
366634	345243	14237S	PARTICIPANT	\N	PRESENT	0
366635	345243	14071N	PARTICIPANT	\N	PRESENT	0
366636	345243	19794Q	PARTICIPANT	\N	PRESENT	0
366637	345243	14029X	PARTICIPANT	\N	PRESENT	0
366655	345243	19629C	PARTICIPANT	\N	PRESENT	0
366656	345243	14107H	PARTICIPANT	\N	PRESENT	0
366657	345243	14223L	PARTICIPANT	\N	PRESENT	0
366658	345243	14157T	PARTICIPANT	\N	PRESENT	0
366659	345243	14051J	PARTICIPANT	\N	PRESENT	0
366660	345243	19503N	PARTICIPANT	\N	PRESENT	0
366661	345243	19741B	PARTICIPANT	\N	PRESENT	0
366662	345243	19723Y	PARTICIPANT	\N	PRESENT	0
366663	345243	19689Q	PARTICIPANT	\N	PRESENT	0
366664	345243	19347U	PARTICIPANT	\N	PRESENT	0
366665	345243	11101A	PARTICIPANT	\N	PRESENT	0
366666	345243	01048V	PARTICIPANT	\N	PRESENT	0
366667	345243	19703U	PARTICIPANT	\N	PRESENT	0
366668	345243	08019V	PARTICIPANT	\N	PRESENT	0
366669	345243	97011G	PARTICIPANT	\N	PRESENT	0
366670	345243	19713W	PARTICIPANT	\N	PRESENT	0
366671	345243	08060W	PARTICIPANT	\N	PRESENT	0
366672	345243	01060R	PARTICIPANT	\N	PRESENT	0
366857	345243	01024M	PARTICIPANT	\N	PRESENT	0
366858	345243	14187A	PARTICIPANT	\N	PRESENT	0
366859	345243	14197C	PARTICIPANT	\N	PRESENT	0
366860	345243	14179A	PARTICIPANT	\N	PRESENT	0
366861	345243	04070G	PARTICIPANT	\N	PRESENT	0
366862	345243	14034U	PARTICIPANT	\N	PRESENT	0
366863	345243	19701S	PARTICIPANT	\N	PRESENT	0
366919	345289	04086Q	PARTICIPANT	\N	PRESENT	0
366920	345289	14031R	PARTICIPANT	\N	PRESENT	0
366921	345289	12016W	PARTICIPANT	\N	PRESENT	0
366922	345289	19551W	PARTICIPANT	\N	PRESENT	0
366923	345289	08060W	PARTICIPANT	\N	PRESENT	0
366924	345289	19599P	PARTICIPANT	\N	PRESENT	0
366925	345289	19525U	PARTICIPANT	\N	PRESENT	0
366926	345289	08055A	PARTICIPANT	\N	PRESENT	0
366927	345289	08019V	PARTICIPANT	\N	PRESENT	0
366928	345289	14187A	PARTICIPANT	\N	PRESENT	0
366929	345289	19629C	PARTICIPANT	\N	PRESENT	0
366930	345289	14034U	PARTICIPANT	\N	PRESENT	0
366931	345289	99004R	PARTICIPANT	\N	PRESENT	0
366932	345289	19569H	PARTICIPANT	\N	PRESENT	0
366933	345289	14147R	PARTICIPANT	\N	PRESENT	0
366934	345289	14231L	PARTICIPANT	\N	PRESENT	0
366935	345289	14059S	PARTICIPANT	\N	PRESENT	0
366936	345289	19737F	PARTICIPANT	\N	PRESENT	0
366937	345289	01024M	PARTICIPANT	\N	PRESENT	0
366938	345289	19269X	PARTICIPANT	\N	PRESENT	0
366939	345289	14038Y	PARTICIPANT	\N	PRESENT	0
366940	345289	19333N	PARTICIPANT	\N	PRESENT	0
366941	345289	19447X	PARTICIPANT	\N	PRESENT	0
366942	345289	04085P	PARTICIPANT	\N	PRESENT	0
366943	345289	19719D	PARTICIPANT	\N	PRESENT	0
366944	345289	14211G	PARTICIPANT	\N	PRESENT	0
366945	345289	19387D	PARTICIPANT	\N	PRESENT	0
366946	345289	95062K	PARTICIPANT	\N	PRESENT	0
366947	345289	19687N	PARTICIPANT	\N	PRESENT	0
366948	345289	19349W	PARTICIPANT	\N	PRESENT	0
366949	345289	19503N	PARTICIPANT	\N	PRESENT	0
366950	345289	14073Q	PARTICIPANT	\N	PRESENT	0
366951	345289	14219Q	PARTICIPANT	\N	PRESENT	0
366952	345289	19717B	PARTICIPANT	\N	PRESENT	0
367094	367093	14199E	PARTICIPANT	\N	PRESENT	0
367100	367098	14083S	PARTICIPANT	\N	PRESENT	0
367105	367103	14327T	PARTICIPANT	\N	PRESENT	0
367110	367109	14121F	PARTICIPANT	\N	PRESENT	0
370878	356305	04059M	PARTICIPANT	\N	PRESENT	0
372851	356669	11072N	PARTICIPANT	\N	EXCUSE	0
373183	373182	08055A	PARTICIPANT	\N	EXCUSE	0
373184	373182	04047H	PARTICIPANT	\N	EXCUSE	0
373185	373182	14085U	PARTICIPANT	\N	PRESENT	0
373186	373182	11083R	PARTICIPANT	\N	PRESENT	0
373187	373182	01057W	PARTICIPANT	\N	PRESENT	0
373188	373182	08049C	PARTICIPANT	\N	PRESENT	0
373467	373465	11053K	PARTICIPANT	\N	PRESENT	0
373468	373465	14159V	PARTICIPANT	\N	PRESENT	0
373469	373465	05012A	PARTICIPANT	\N	PRESENT	0
373477	373476	11101A	PARTICIPANT	\N	PRESENT	0
373478	373476	19599P	PARTICIPANT	\N	PRESENT	0
373479	373476	11049P	PARTICIPANT	\N	PRESENT	0
373480	373476	04049K	PARTICIPANT	\N	PRESENT	0
373481	373476	19711U	PARTICIPANT	\N	PRESENT	0
373482	373476	01043Q	PARTICIPANT	\N	PRESENT	0
373483	373476	01048V	PARTICIPANT	\N	PRESENT	0
373484	373476	19563B	PRESIDENT	0	PRESENT	0
373485	373476	95067Q	PARTICIPANT	\N	PRESENT	0
373486	373476	19575F	PARTICIPANT	\N	EXCUSE	0
373487	373476	19782L	PARTICIPANT	\N	EXCUSE	0
373488	373476	14073Q	PARTICIPANT	\N	EXCUSE	0
373489	373476	07029T	PARTICIPANT	\N	EXCUSE	0
373490	373476	19637C	PARTICIPANT	\N	EXCUSE	0
373491	373476	14265W	PARTICIPANT	\N	EXCUSE	0
373492	373476	14237S	PARTICIPANT	\N	EXCUSE	0
373493	373476	19713W	PARTICIPANT	\N	EXCUSE	0
373494	373476	19413M	PARTICIPANT	\N	EXCUSE	0
373495	373476	01062T	PARTICIPANT	\N	EXCUSE	0
373496	373476	19527W	PARTICIPANT	\N	EXCUSE	0
384919	384597	14213J	PARTICIPANT	\N	PRESENT	0
384920	384597	19703U	PARTICIPANT	\N	PRESENT	0
386070	386069	14215L	PARTICIPANT	\N	PRESENT	0
386071	386069	14179A	PARTICIPANT	\N	PRESENT	0
386072	386069	14001X	PARTICIPANT	\N	PRESENT	0
386074	386073	14215L	PARTICIPANT	\N	PRESENT	0
386075	386073	14179A	PARTICIPANT	\N	PRESENT	0
386080	386079	14215L	PARTICIPANT	\N	PRESENT	0
386081	386079	14179A	PARTICIPANT	\N	PRESENT	0
386358	386357	19782L	PARTICIPANT	\N	PRESENT	0
386360	386357	11101A	PARTICIPANT	\N	PRESENT	0
386361	386357	19681G	PARTICIPANT	\N	EXCUSE	0
386362	386357	19599P	PARTICIPANT	\N	PRESENT	0
386364	386357	19695N	PARTICIPANT	\N	PRESENT	0
386365	386357	07029T	PARTICIPANT	\N	PRESENT	0
386366	386357	01043Q	PARTICIPANT	\N	PRESENT	0
386368	386357	19563B	PRESIDENT	0	PRESENT	0
386369	386357	14237S	PARTICIPANT	\N	PRESENT	0
386370	386357	19503N	PARTICIPANT	\N	PRESENT	0
386371	386357	19413M	PARTICIPANT	\N	PRESENT	0
386372	386357	19527W	PARTICIPANT	\N	PRESENT	0
386373	386357	19585H	PARTICIPANT	\N	PRESENT	0
386376	384448	08011M	PARTICIPANT	\N	EXCUSE	0
387129	377926	19369B	PARTICIPANT	\N	PRESENT	0
387130	377926	14042U	PARTICIPANT	\N	PRESENT	0
387131	377926	04043D	PARTICIPANT	\N	PRESENT	0
387132	377926	19691J	PARTICIPANT	\N	PRESENT	0
387133	377926	11053K	PARTICIPANT	\N	PRESENT	0
387134	377926	14069U	PARTICIPANT	\N	PRESENT	0
387135	377926	19611R	PARTICIPANT	\N	PRESENT	0
387136	377926	19737F	PARTICIPANT	\N	PRESENT	0
387137	377926	14087W	PARTICIPANT	\N	PRESENT	0
387138	377926	14205J	PARTICIPANT	\N	PRESENT	0
387139	377926	14215L	PARTICIPANT	\N	PRESENT	0
387140	377926	19699S	PARTICIPANT	\N	PRESENT	0
387141	377926	05012A	PARTICIPANT	\N	PRESENT	0
387142	377926	19721W	PARTICIPANT	\N	PRESENT	0
387143	377926	08034U	PARTICIPANT	\N	PRESENT	0
387144	377926	19569H	PARTICIPANT	\N	PRESENT	0
387145	377926	16685X	PARTICIPANT	\N	PRESENT	0
387146	377926	10006L	PARTICIPANT	\N	PRESENT	0
387147	377926	19479G	PARTICIPANT	\N	PRESENT	0
387148	377926	19798U	PARTICIPANT	\N	PRESENT	0
387149	377926	19441R	PARTICIPANT	\N	PRESENT	0
387150	377926	19713W	PARTICIPANT	\N	PRESENT	0
387151	377926	95041E	PARTICIPANT	\N	PRESENT	0
387152	377926	19581D	PARTICIPANT	\N	PRESENT	0
387153	377926	14277B	PARTICIPANT	\N	PRESENT	0
387154	377926	11012A	PARTICIPANT	\N	PRESENT	0
387155	377926	19747H	PARTICIPANT	\N	PRESENT	0
387156	377926	97011G	PARTICIPANT	\N	PRESENT	0
387157	377926	11103C	PARTICIPANT	\N	PRESENT	0
387158	377926	07033P	PARTICIPANT	\N	PRESENT	0
387159	377926	14217N	PARTICIPANT	\N	PRESENT	0
387160	377926	14331P	PARTICIPANT	\N	PRESENT	0
387161	377926	14193X	PARTICIPANT	\N	PRESENT	0
387162	377926	14073Q	PARTICIPANT	\N	PRESENT	0
387163	377926	19671E	PARTICIPANT	\N	PRESENT	0
387164	377926	01043Q	PARTICIPANT	\N	PRESENT	0
387165	377926	14030Q	PARTICIPANT	\N	PRESENT	0
387166	377926	14327T	PARTICIPANT	\N	PRESENT	0
387167	377926	01025N	PARTICIPANT	\N	PRESENT	0
387168	377926	01024M	PARTICIPANT	\N	PRESENT	0
387169	377926	04040A	PARTICIPANT	\N	PRESENT	0
387170	377926	07004J	PARTICIPANT	\N	PRESENT	0
387171	377926	04089T	PARTICIPANT	\N	PRESENT	0
387172	377926	19521Q	PARTICIPANT	\N	PRESENT	0
387173	377926	08056B	PARTICIPANT	\N	PRESENT	0
387174	377926	14329V	PARTICIPANT	\N	PRESENT	0
387175	377926	14357A	PARTICIPANT	\N	PRESENT	0
387176	377926	19749K	PARTICIPANT	\N	PRESENT	0
387177	377926	14219Q	PARTICIPANT	\N	PRESENT	0
387178	377926	14221J	PARTICIPANT	\N	PRESENT	0
387179	377926	19675J	PARTICIPANT	\N	PRESENT	0
387180	377926	19739H	PARTICIPANT	\N	PRESENT	0
387181	377926	19745F	PARTICIPANT	\N	PRESENT	0
387182	377926	19621T	PARTICIPANT	\N	PRESENT	0
387183	377926	98050T	PARTICIPANT	\N	PRESENT	0
387184	377926	14061L	PARTICIPANT	\N	PRESENT	0
387185	377926	11070L	PARTICIPANT	\N	PRESENT	0
387186	377926	11085T	PARTICIPANT	\N	PRESENT	0
387187	377926	14089Y	PARTICIPANT	\N	PRESENT	0
387188	377926	11031D	PARTICIPANT	\N	PRESENT	0
387189	377926	19367Y	PARTICIPANT	\N	PRESENT	0
387190	377926	04047H	PARTICIPANT	\N	PRESENT	0
387191	377926	04018C	PARTICIPANT	\N	PRESENT	0
387192	377926	11074Q	PARTICIPANT	\N	PRESENT	0
387193	377926	19693L	PARTICIPANT	\N	PRESENT	0
387194	377926	04071H	PARTICIPANT	\N	PRESENT	0
387201	387200	14038Y	PARTICIPANT	\N	PRESENT	0
387202	387200	19525U	PARTICIPANT	\N	PRESENT	0
387203	387200	08009T	PARTICIPANT	\N	PRESENT	0
387475	377927	04059M	PARTICIPANT	\N	PRESENT	0
387476	377927	19551W	PARTICIPANT	\N	PRESENT	0
387477	377927	14227Q	PARTICIPANT	\N	PRESENT	0
387479	377927	19683J	PARTICIPANT	\N	PRESENT	0
387480	387478	14215L	PARTICIPANT	\N	PRESENT	0
387481	377927	08052W	PARTICIPANT	\N	PRESENT	0
387482	387478	14179A	PARTICIPANT	\N	PRESENT	0
387506	377927	19507S	PARTICIPANT	\N	PRESENT	0
387484	377927	19565D	PARTICIPANT	\N	PRESENT	0
387485	377927	11031D	PARTICIPANT	\N	PRESENT	0
387486	377927	04057K	PARTICIPANT	\N	PRESENT	0
387487	377927	17589D	PARTICIPANT	\N	PRESENT	0
387488	377927	14251Q	PARTICIPANT	\N	PRESENT	0
387489	377927	04092N	PARTICIPANT	\N	PRESENT	0
387490	377927	14073Q	PARTICIPANT	\N	PRESENT	0
387491	377927	14030Q	PARTICIPANT	\N	PRESENT	0
387492	377927	19711U	PARTICIPANT	\N	PRESENT	0
387493	377927	19575F	PARTICIPANT	\N	PRESENT	0
387494	377927	19415P	PARTICIPANT	\N	PRESENT	0
387495	377927	19367Y	PARTICIPANT	\N	PRESENT	0
387496	377927	19794Q	PARTICIPANT	\N	PRESENT	0
387497	377927	04045F	PARTICIPANT	\N	PRESENT	0
387498	377927	19715Y	PARTICIPANT	\N	PRESENT	0
387499	386949	14069U	PARTICIPANT	\N	PRESENT	0
387500	386949	14083S	PARTICIPANT	\N	PRESENT	0
387501	386949	14081Q	PARTICIPANT	\N	PRESENT	0
387502	386949	19739H	PARTICIPANT	\N	PRESENT	0
387503	386949	19349W	PARTICIPANT	\N	PRESENT	0
387504	386949	14225N	PARTICIPANT	\N	PRESENT	0
387505	377927	08056B	PARTICIPANT	\N	PRESENT	0
387507	377927	08031R	PARTICIPANT	\N	PRESENT	0
387508	377927	99004R	PARTICIPANT	\N	PRESENT	0
387509	377927	19679N	PARTICIPANT	\N	PRESENT	0
387510	377927	19798U	PARTICIPANT	\N	PRESENT	0
387511	377927	14239U	PARTICIPANT	\N	PRESENT	0
387512	377927	19697Q	PARTICIPANT	\N	PRESENT	0
387513	377927	19737F	PARTICIPANT	\N	PRESENT	0
387514	377927	19760E	PARTICIPANT	\N	PRESENT	0
387515	377927	11045K	PARTICIPANT	\N	PRESENT	0
387516	377927	08055A	PARTICIPANT	\N	PRESENT	0
387517	377927	01028R	PARTICIPANT	\N	PRESENT	0
387518	377927	19553Y	PARTICIPANT	\N	PRESENT	0
387519	377927	14213J	PARTICIPANT	\N	PRESENT	0
387520	377927	11097X	PARTICIPANT	\N	PRESENT	0
387521	377927	10006L	PARTICIPANT	\N	PRESENT	0
387522	377927	14033T	PARTICIPANT	\N	PRESENT	0
387523	377927	19703U	PARTICIPANT	\N	PRESENT	0
371087	371078	19489J	PARTICIPANT	\N	PRESENT	0
371092	356308	11066Q	PARTICIPANT	\N	PRESENT	0
371093	356308	19701S	PARTICIPANT	\N	PRESENT	0
371094	356308	19583F	PARTICIPANT	\N	PRESENT	0
371095	356308	19383Y	PARTICIPANT	\N	PRESENT	0
371096	356308	04045F	PARTICIPANT	\N	PRESENT	0
371098	356308	08068F	PARTICIPANT	\N	PRESENT	0
371099	356308	11031D	PARTICIPANT	\N	PRESENT	0
371100	356308	19551W	PARTICIPANT	\N	PRESENT	0
371102	356308	19747H	PARTICIPANT	\N	PRESENT	0
371106	356308	14205J	PARTICIPANT	\N	PRESENT	0
371108	356308	08038Y	PARTICIPANT	\N	PRESENT	0
371109	356308	19679N	PARTICIPANT	\N	PRESENT	0
371110	356308	19719D	PARTICIPANT	\N	PRESENT	0
371111	356308	14135M	PARTICIPANT	\N	PRESENT	0
371112	356308	95030B	PARTICIPANT	\N	PRESENT	0
371113	356308	01024M	PARTICIPANT	\N	PRESENT	0
371114	356308	11027H	PARTICIPANT	\N	PRESENT	0
371115	356308	14034U	PARTICIPANT	\N	PRESENT	0
371116	356308	19503N	PARTICIPANT	\N	PRESENT	0
371117	356308	19681G	PARTICIPANT	\N	PRESENT	0
371118	356308	19333N	PARTICIPANT	\N	PRESENT	0
371119	356308	19525U	PARTICIPANT	\N	PRESENT	0
371120	356308	19543W	PARTICIPANT	\N	PRESENT	0
371121	356308	14173T	PARTICIPANT	\N	PRESENT	0
371122	356308	19733B	PARTICIPANT	\N	PRESENT	0
371123	356308	14051J	PARTICIPANT	\N	PRESENT	0
371124	356308	08053X	PARTICIPANT	\N	PRESENT	0
371125	356308	14033T	PARTICIPANT	\N	PRESENT	0
371126	356308	14265W	PARTICIPANT	\N	PRESENT	0
371127	356308	08034U	PARTICIPANT	\N	PRESENT	0
371128	356308	19479G	PARTICIPANT	\N	PRESENT	0
371129	356308	19415P	PARTICIPANT	\N	PRESENT	0
371130	356308	18083K	PARTICIPANT	\N	PRESENT	0
371132	356308	19671E	PARTICIPANT	\N	PRESENT	0
371133	356308	19511N	PARTICIPANT	\N	PRESENT	0
371134	356308	11067R	PARTICIPANT	\N	PRESENT	0
371135	356308	19553Y	PARTICIPANT	\N	PRESENT	0
371136	356308	95063L	PARTICIPANT	\N	PRESENT	0
371137	356308	19643A	PARTICIPANT	\N	PRESENT	0
371138	356308	19713W	PARTICIPANT	\N	PRESENT	0
371139	356308	11085T	PARTICIPANT	\N	PRESENT	0
370969	367799	08048B	PARTICIPANT	\N	EXCUSE	0
371086	371078	19701S	PARTICIPANT	\N	PRESENT	0
371143	356308	11099A	PARTICIPANT	\N	PRESENT	0
371144	356308	08020N	PARTICIPANT	\N	PRESENT	0
371145	356308	14211G	PARTICIPANT	\N	PRESENT	0
371147	356308	88008L	PARTICIPANT	\N	PRESENT	0
371148	356308	11012A	PARTICIPANT	\N	PRESENT	0
371153	356308	14133K	PARTICIPANT	\N	PRESENT	0
371154	356308	14169X	PARTICIPANT	\N	PRESENT	0
371155	356308	01058X	PARTICIPANT	\N	PRESENT	0
371156	356308	14225N	PARTICIPANT	\N	PRESENT	0
371157	356308	14115H	PARTICIPANT	\N	PRESENT	0
371158	356308	14105F	PARTICIPANT	\N	PRESENT	0
373689	373665	11097X	PARTICIPANT	\N	PRESENT	0
373690	373651	11097X	PARTICIPANT	\N	PRESENT	0
373692	373691	99004R	PRESIDENT	0	PRESENT	0
373696	373695	14147R	PARTICIPANT	\N	PRESENT	0
373707	373691	19467C	PARTICIPANT	\N	PRESENT	0
373708	373691	19711U	PARTICIPANT	\N	EXCUSE	0
373709	373691	08062Y	PARTICIPANT	\N	PRESENT	0
373710	373691	08012N	PARTICIPANT	\N	EXCUSE	0
376058	371425	10015M	PARTICIPANT	\N	PRESENT	0
376059	371425	14223L	PARTICIPANT	\N	PRESENT	0
376060	371425	04097T	PARTICIPANT	\N	PRESENT	0
376061	371425	98024R	PARTICIPANT	\N	PRESENT	0
376062	371425	19667J	PARTICIPANT	\N	PRESENT	0
376063	371425	19447X	PARTICIPANT	\N	PRESENT	0
376064	371425	95041E	PARTICIPANT	\N	PRESENT	0
376065	371425	01048V	PARTICIPANT	\N	PRESENT	0
376066	371425	14173T	PARTICIPANT	\N	PRESENT	0
376067	371425	08034U	PARTICIPANT	\N	PRESENT	0
376068	371425	01058X	PARTICIPANT	\N	PRESENT	0
376069	371425	04008A	PARTICIPANT	\N	PRESENT	0
376070	371425	08020N	PARTICIPANT	\N	PRESENT	0
376071	371425	14133K	PARTICIPANT	\N	PRESENT	0
376072	371425	04038G	PARTICIPANT	\N	PRESENT	0
376073	371425	11031D	PARTICIPANT	\N	PRESENT	0
376074	371425	11040E	PARTICIPANT	\N	PRESENT	0
376075	371425	86034E	PARTICIPANT	\N	PRESENT	0
376076	371425	12041X	PARTICIPANT	\N	PRESENT	0
376077	371425	19760E	PARTICIPANT	\N	PRESENT	0
376078	371425	19695N	PARTICIPANT	\N	PRESENT	0
376079	371425	19565D	PARTICIPANT	\N	PRESENT	0
376974	376972	08011M	PARTICIPANT	\N	PRESENT	0
376975	376972	19667J	PARTICIPANT	\N	PRESENT	0
376977	376976	08034U	PARTICIPANT	\N	PRESENT	0
376979	376978	14085U	PARTICIPANT	\N	PRESENT	0
376980	376978	14253S	PARTICIPANT	\N	PRESENT	0
376982	376981	19741B	PARTICIPANT	\N	PRESENT	0
376984	376983	14331P	PARTICIPANT	\N	PRESENT	0
376991	376990	11074Q	PARTICIPANT	\N	PRESENT	0
376992	376990	08011M	PARTICIPANT	\N	PRESENT	0
376993	376990	88008L	PARTICIPANT	\N	PRESENT	0
376994	376990	14327T	PARTICIPANT	\N	PRESENT	0
376995	376990	11048N	PARTICIPANT	\N	PRESENT	0
376996	376990	14225N	PARTICIPANT	\N	PRESENT	0
376998	376997	11074Q	PARTICIPANT	\N	PRESENT	0
376999	376997	08011M	PARTICIPANT	\N	PRESENT	0
377000	376997	88008L	PARTICIPANT	\N	PRESENT	0
376056	371425	19573D	PARTICIPANT	\N	PRESENT	0
376057	371425	19673G	PARTICIPANT	\N	PRESENT	0
377001	376997	14327T	PARTICIPANT	\N	PRESENT	0
377002	376997	11048N	PARTICIPANT	\N	PRESENT	0
377003	376997	14225N	PARTICIPANT	\N	PRESENT	0
377005	377004	11074Q	PARTICIPANT	\N	PRESENT	0
377006	377004	08011M	PARTICIPANT	\N	PRESENT	0
377007	377004	88008L	PARTICIPANT	\N	PRESENT	0
377008	377004	14327T	PARTICIPANT	\N	PRESENT	0
377009	377004	11048N	PARTICIPANT	\N	PRESENT	0
377010	377004	14225N	PARTICIPANT	\N	PRESENT	0
377413	377412	11070L	PARTICIPANT	\N	PRESENT	0
378656	371478	04044E	PARTICIPANT	\N	PRESENT	0
378661	371478	95063L	PARTICIPANT	\N	PRESENT	0
378662	371478	19651A	PARTICIPANT	\N	PRESENT	0
378663	371478	19629C	PARTICIPANT	\N	PRESENT	0
378664	371478	11026G	PARTICIPANT	\N	PRESENT	0
378665	371478	12041X	PARTICIPANT	\N	PRESENT	0
378666	371478	19747H	PARTICIPANT	\N	PRESENT	0
378667	371478	14255U	PARTICIPANT	\N	PRESENT	0
378668	371478	05008E	PARTICIPANT	\N	PRESENT	0
378669	371478	04057K	PARTICIPANT	\N	PRESENT	0
378670	371478	17589D	PARTICIPANT	\N	PRESENT	0
378671	371478	14079W	PARTICIPANT	\N	PRESENT	0
378672	371478	01060R	PARTICIPANT	\N	PRESENT	0
378673	371478	11083R	PARTICIPANT	\N	PRESENT	0
378674	371478	19729F	PARTICIPANT	\N	PRESENT	0
378675	371478	17583W	PARTICIPANT	\N	PRESENT	0
378676	371478	08020N	PARTICIPANT	\N	PRESENT	0
378677	371478	14169X	PARTICIPANT	\N	PRESENT	0
378678	371478	14259Y	PARTICIPANT	\N	PRESENT	0
378679	371478	19443T	PARTICIPANT	\N	PRESENT	0
378680	371478	19507S	PARTICIPANT	\N	PRESENT	0
378681	371478	04088S	PARTICIPANT	\N	PRESENT	0
378682	371478	14031R	PARTICIPANT	\N	PRESENT	0
378683	371478	19794Q	PARTICIPANT	\N	PRESENT	0
378684	371478	19447X	PARTICIPANT	\N	PRESENT	0
378685	371478	14157T	PARTICIPANT	\N	PRESENT	0
378686	371478	98050T	PARTICIPANT	\N	PRESENT	0
378687	371478	11103C	PARTICIPANT	\N	PRESENT	0
378688	371478	14053L	PARTICIPANT	\N	PRESENT	0
378689	371478	19798U	PARTICIPANT	\N	PRESENT	0
378690	371478	19479G	PARTICIPANT	\N	PRESENT	0
378691	371478	08056B	PARTICIPANT	\N	PRESENT	0
378692	371478	19301E	PARTICIPANT	\N	PRESENT	0
378693	371478	11104D	PARTICIPANT	\N	PRESENT	0
378694	371478	96004D	PARTICIPANT	\N	PRESENT	0
378695	371478	14197C	PARTICIPANT	\N	PRESENT	0
378704	371478	19253P	PARTICIPANT	\N	PRESENT	0
378707	371478	14073Q	PARTICIPANT	\N	PRESENT	0
378709	371478	14267Y	PARTICIPANT	\N	PRESENT	0
378715	371478	14251Q	PARTICIPANT	\N	PRESENT	0
378722	371478	19699S	PARTICIPANT	\N	PRESENT	0
378724	371478	19762G	PARTICIPANT	\N	PRESENT	0
378725	371478	19543W	PARTICIPANT	\N	PRESENT	0
378726	371478	97011G	PARTICIPANT	\N	PRESENT	0
378732	371478	08062Y	PARTICIPANT	\N	PRESENT	0
378735	371478	01024M	PARTICIPANT	\N	PRESENT	0
378736	371478	11012A	PARTICIPANT	\N	PRESENT	0
378737	371478	19725B	PARTICIPANT	\N	PRESENT	0
378738	371478	19691J	PARTICIPANT	\N	PRESENT	0
378739	371478	19673G	PARTICIPANT	\N	PRESENT	0
378740	371478	19441R	PARTICIPANT	\N	PRESENT	0
378741	371478	01025N	PARTICIPANT	\N	PRESENT	0
378742	371478	19415P	PARTICIPANT	\N	PRESENT	0
378743	371478	14111D	PARTICIPANT	\N	PRESENT	0
378744	371478	19701S	PARTICIPANT	\N	PRESENT	0
378745	371478	14061L	PARTICIPANT	\N	PRESENT	0
367767	367466	19521Q	PARTICIPANT	\N	PRESENT	0
367768	367466	04057K	PARTICIPANT	\N	PRESENT	0
367769	367466	17589D	PARTICIPANT	\N	PRESENT	0
367770	367466	19762G	PARTICIPANT	\N	PRESENT	0
367771	367466	08020N	PARTICIPANT	\N	PRESENT	0
367775	367466	19593H	PARTICIPANT	\N	PRESENT	0
367773	367466	19766L	PARTICIPANT	\N	PRESENT	0
367774	367466	11110B	PARTICIPANT	\N	PRESENT	0
367776	367466	19479G	PARTICIPANT	\N	PRESENT	0
367777	367466	14083S	PARTICIPANT	\N	PRESENT	0
367779	367778	08060W	PARTICIPANT	\N	PRESENT	0
367780	367778	14157T	PARTICIPANT	\N	PRESENT	0
367781	367778	08019V	PARTICIPANT	\N	PRESENT	0
367782	367778	19745F	PARTICIPANT	\N	PRESENT	0
367783	367778	19762G	PARTICIPANT	\N	PRESENT	0
367785	367466	11085T	PARTICIPANT	\N	PRESENT	0
367800	367466	08062Y	PARTICIPANT	\N	PRESENT	0
368102	356293	11072N	PARTICIPANT	\N	PRESENT	0
368103	356293	96004D	PARTICIPANT	\N	PRESENT	0
368104	356293	04085P	PARTICIPANT	\N	PRESENT	0
368105	356293	19593H	PARTICIPANT	\N	PRESENT	0
368106	356293	14235Q	PARTICIPANT	\N	PRESENT	0
368107	356293	19565D	PARTICIPANT	\N	PRESENT	0
368108	356293	19760E	PARTICIPANT	\N	PRESENT	0
368109	356293	11026G	PARTICIPANT	\N	PRESENT	0
368110	356293	19695N	PARTICIPANT	\N	PRESENT	0
368111	356293	19758L	PARTICIPANT	\N	PRESENT	0
368112	356293	14121F	PARTICIPANT	\N	PRESENT	0
368113	356293	12016W	PARTICIPANT	\N	PRESENT	0
368114	356293	19599P	PARTICIPANT	\N	PRESENT	0
368115	356293	80013X	PARTICIPANT	\N	PRESENT	0
368116	356293	14065Q	PARTICIPANT	\N	PRESENT	0
368117	356293	14081Q	PARTICIPANT	\N	PRESENT	0
368118	356293	14225N	PARTICIPANT	\N	PRESENT	0
368119	356293	19782L	PARTICIPANT	\N	PRESENT	0
368120	356293	04034C	PARTICIPANT	\N	PRESENT	0
368121	356293	19349W	PARTICIPANT	\N	PRESENT	0
368122	356293	19637C	PARTICIPANT	\N	PRESENT	0
368123	356293	19553Y	PARTICIPANT	\N	PRESENT	0
368124	356293	04057K	PARTICIPANT	\N	PRESENT	0
368125	356293	19387D	PARTICIPANT	\N	PRESENT	0
368126	356293	11083R	PARTICIPANT	\N	PRESENT	0
368127	356293	95037J	PARTICIPANT	\N	PRESENT	0
368128	356293	88008L	PARTICIPANT	\N	PRESENT	0
368129	356293	19563B	PARTICIPANT	\N	PRESENT	0
368130	356293	95063L	PARTICIPANT	\N	PRESENT	0
368131	356293	19629C	PARTICIPANT	\N	PRESENT	0
368132	356293	14107H	PARTICIPANT	\N	PRESENT	0
368133	356293	14205J	PARTICIPANT	\N	PRESENT	0
368134	356293	14083S	PARTICIPANT	\N	PRESENT	0
368135	356293	19479G	PARTICIPANT	\N	PRESENT	0
368136	356293	19441R	PARTICIPANT	\N	PRESENT	0
368137	356293	07004J	PARTICIPANT	\N	PRESENT	0
368138	356293	14089Y	PARTICIPANT	\N	PRESENT	0
368139	356293	14179A	PARTICIPANT	\N	PRESENT	0
368140	356293	19745F	PARTICIPANT	\N	PRESENT	0
368141	356293	01024M	PARTICIPANT	\N	PRESENT	0
368142	356293	98035U	PARTICIPANT	\N	PRESENT	0
368143	356293	19711U	PARTICIPANT	\N	PRESENT	0
368144	356293	11048N	PARTICIPANT	\N	PRESENT	0
368146	356293	17583W	PARTICIPANT	\N	PRESENT	0
368147	356293	19575F	PARTICIPANT	\N	PRESENT	0
368148	356293	14087W	PARTICIPANT	\N	PRESENT	0
368149	356293	97011G	PARTICIPANT	\N	PRESENT	0
368151	356293	11103C	PARTICIPANT	\N	PRESENT	0
368152	356293	14053L	PARTICIPANT	\N	PRESENT	0
368153	356293	14061L	PARTICIPANT	\N	PRESENT	0
368154	356293	04018C	PARTICIPANT	\N	PRESENT	0
368155	356293	14041T	PARTICIPANT	\N	PRESENT	0
368156	356293	04088S	PARTICIPANT	\N	PRESENT	0
368157	356293	19709B	PARTICIPANT	\N	PRESENT	0
368158	356293	18083K	PARTICIPANT	\N	PRESENT	0
368159	356293	14135M	PARTICIPANT	\N	PRESENT	0
368160	356293	08039A	PARTICIPANT	\N	PRESENT	0
368161	356293	98005N	PARTICIPANT	\N	PRESENT	0
368162	356293	14029X	PARTICIPANT	\N	PRESENT	0
368163	356293	14038Y	PARTICIPANT	\N	PRESENT	0
368164	356293	14173T	PARTICIPANT	\N	PRESENT	0
368165	356293	14157T	PARTICIPANT	\N	PRESENT	0
368166	356293	14191V	PARTICIPANT	\N	PRESENT	0
368167	356293	08011M	PARTICIPANT	\N	PRESENT	0
368168	356293	98022P	PARTICIPANT	\N	PRESENT	0
368169	356293	19725B	PARTICIPANT	\N	PRESENT	0
368170	356293	04042C	PARTICIPANT	\N	PRESENT	0
368171	356293	10015M	PARTICIPANT	\N	PRESENT	0
368172	356293	14133K	PARTICIPANT	\N	PRESENT	0
368173	356293	14063N	PARTICIPANT	\N	PRESENT	0
368177	356293	19671E	PARTICIPANT	\N	PRESENT	0
368185	356293	14033T	PARTICIPANT	\N	PRESENT	0
368186	356293	19521Q	PARTICIPANT	\N	PRESENT	0
368190	356293	19581D	PARTICIPANT	\N	PRESENT	0
368191	356293	08045X	PARTICIPANT	\N	PRESENT	0
368192	367754	19794Q	PARTICIPANT	\N	PRESENT	0
368193	367754	14031R	PARTICIPANT	\N	PRESENT	0
368194	367754	19549D	PARTICIPANT	\N	PRESENT	0
368195	367754	14079W	PARTICIPANT	\N	PRESENT	0
368196	367754	14081Q	PARTICIPANT	\N	PRESENT	0
368197	367754	19585H	PARTICIPANT	\N	PRESENT	0
368198	367754	19637C	PARTICIPANT	\N	PRESENT	0
368199	367754	14237S	PARTICIPANT	\N	PRESENT	0
368200	367754	14241N	PARTICIPANT	\N	PRESENT	0
368201	367754	19737F	PARTICIPANT	\N	PRESENT	0
368202	367754	19347U	PARTICIPANT	\N	PRESENT	0
368203	367754	14179A	PARTICIPANT	\N	PRESENT	0
368204	367754	19349W	PARTICIPANT	\N	PRESENT	0
368205	367754	17637T	PARTICIPANT	\N	PRESENT	0
368206	367754	19525U	PARTICIPANT	\N	PRESENT	0
368207	356293	01060R	PARTICIPANT	\N	PRESENT	0
368208	356293	19619A	PARTICIPANT	\N	PRESENT	0
368209	356293	11049P	PARTICIPANT	\N	PRESENT	0
368210	356293	14159V	PARTICIPANT	\N	PRESENT	0
368211	356293	11110B	PARTICIPANT	\N	PRESENT	0
368212	356293	11053K	PARTICIPANT	\N	PRESENT	0
368213	356293	80027E	PARTICIPANT	\N	PRESENT	0
368214	356293	15447F	PARTICIPANT	\N	PRESENT	0
368215	356293	19335Q	PARTICIPANT	\N	PRESENT	0
368216	356293	19747H	PARTICIPANT	\N	PRESENT	0
368219	356293	19253P	PARTICIPANT	\N	PRESENT	0
368220	356293	14079W	PARTICIPANT	\N	PRESENT	0
368221	356293	14031R	PARTICIPANT	\N	PRESENT	0
368222	356293	11101A	PARTICIPANT	\N	PRESENT	0
368223	356293	11115U	PARTICIPANT	\N	PRESENT	0
368224	356293	08069G	PARTICIPANT	\N	PRESENT	0
368225	356293	19794Q	PARTICIPANT	\N	PRESENT	0
368226	356293	14073Q	PARTICIPANT	\N	PRESENT	0
368227	356293	11012A	PARTICIPANT	\N	PRESENT	0
368228	356293	14249W	PARTICIPANT	\N	PRESENT	0
368229	356293	14223L	PARTICIPANT	\N	PRESENT	0
368230	356293	14241N	PARTICIPANT	\N	PRESENT	0
368231	356293	19413M	PARTICIPANT	\N	PRESENT	0
368232	356293	11097X	PARTICIPANT	\N	PRESENT	0
368233	356293	19399H	PARTICIPANT	\N	PRESENT	0
368234	356293	14215L	PARTICIPANT	\N	PRESENT	0
368235	356293	95030B	PARTICIPANT	\N	PRESENT	0
368236	356293	19367Y	PARTICIPANT	\N	PRESENT	0
368237	367754	19551W	PARTICIPANT	\N	EXCUSE	0
368238	356293	19383Y	PARTICIPANT	\N	PRESENT	0
368239	356293	19679N	PARTICIPANT	\N	PRESENT	0
368240	356293	14259Y	PARTICIPANT	\N	PRESENT	0
368241	356293	11067R	PARTICIPANT	\N	PRESENT	0
368242	356293	04038G	PARTICIPANT	\N	PRESENT	0
370880	356305	19515S	PARTICIPANT	\N	PRESENT	0
370881	356305	14213J	PARTICIPANT	\N	PRESENT	0
370882	356305	19657G	PARTICIPANT	\N	PRESENT	0
370883	356305	19709B	PARTICIPANT	\N	PRESENT	0
370884	356305	19335Q	PARTICIPANT	\N	PRESENT	0
370885	356305	19507S	PARTICIPANT	\N	PRESENT	0
370886	356305	14199E	PARTICIPANT	\N	PRESENT	0
370902	367012	19515S	PARTICIPANT	\N	PRESENT	0
370903	367012	04071H	PARTICIPANT	\N	PRESENT	0
370904	367012	08068F	PARTICIPANT	\N	PRESENT	0
370905	367012	14151M	PARTICIPANT	\N	PRESENT	0
370906	356305	11027H	PARTICIPANT	\N	PRESENT	0
370907	356305	14031R	PARTICIPANT	\N	PRESENT	0
370908	356305	08045X	PARTICIPANT	\N	PRESENT	0
370923	356305	11054L	PARTICIPANT	\N	PRESENT	0
370932	356305	98005N	PARTICIPANT	\N	PRESENT	0
369668	369643	95063L	PARTICIPANT	\N	PRESENT	0
370879	356305	14225N	PARTICIPANT	\N	PRESENT	0
370933	356305	19681G	PARTICIPANT	\N	PRESENT	0
370934	356305	19583F	PARTICIPANT	\N	PRESENT	0
370935	356305	01043Q	PARTICIPANT	\N	PRESENT	0
370936	356305	08009T	PARTICIPANT	\N	PRESENT	0
370937	356305	19413M	PARTICIPANT	\N	PRESENT	0
370938	356305	14147R	PARTICIPANT	\N	PRESENT	0
370939	356305	04049K	PARTICIPANT	\N	PRESENT	0
370940	356305	19545Y	PARTICIPANT	\N	PRESENT	0
370941	356305	14071N	PARTICIPANT	\N	PRESENT	0
370942	356305	19569H	PARTICIPANT	\N	PRESENT	0
370943	356305	19575F	PARTICIPANT	\N	PRESENT	0
370944	356305	19705W	PARTICIPANT	\N	PRESENT	0
370945	356305	19585H	PARTICIPANT	\N	PRESENT	0
370946	356305	14028W	PARTICIPANT	\N	PRESENT	0
370947	356305	19301E	PARTICIPANT	\N	PRESENT	0
370948	356305	11049P	PARTICIPANT	\N	PRESENT	0
370949	356305	14251Q	PARTICIPANT	\N	PRESENT	0
370950	356305	14093U	PARTICIPANT	\N	PRESENT	0
370951	356305	02002K	PARTICIPANT	\N	PRESENT	0
370952	356305	14195A	PARTICIPANT	\N	PRESENT	0
370953	356305	17589D	PARTICIPANT	\N	PRESENT	0
370954	356305	11064N	PARTICIPANT	\N	PRESENT	0
370955	356305	04057K	PARTICIPANT	\N	PRESENT	0
370956	356305	14157T	PARTICIPANT	\N	PRESENT	0
370957	356305	14193X	PARTICIPANT	\N	PRESENT	0
370958	356305	19565D	PARTICIPANT	\N	PRESENT	0
370962	356305	11056N	PARTICIPANT	\N	PRESENT	0
370963	356305	14241N	PARTICIPANT	\N	PRESENT	0
370964	356305	14103D	PARTICIPANT	\N	PRESENT	0
370967	356305	19553Y	PARTICIPANT	\N	PRESENT	0
370968	356305	14089Y	PARTICIPANT	\N	PRESENT	0
370970	356305	08052W	PARTICIPANT	\N	PRESENT	0
370971	356305	11043H	PARTICIPANT	\N	PRESENT	0
370972	356305	14159V	PARTICIPANT	\N	PRESENT	0
370973	356305	11045K	PARTICIPANT	\N	PRESENT	0
370974	356305	14119M	PARTICIPANT	\N	PRESENT	0
382639	382638	14147R	PARTICIPANT	\N	PRESENT	0
383089	382613	19333N	PARTICIPANT	\N	PRESENT	0
383090	382613	19383Y	PARTICIPANT	\N	PRESENT	0
383091	382613	17583W	PARTICIPANT	\N	PRESENT	0
383092	382613	19701S	PARTICIPANT	\N	PRESENT	0
383093	382613	19794Q	PARTICIPANT	\N	PRESENT	0
383094	382613	19713W	PARTICIPANT	\N	PRESENT	0
383095	382613	95062K	PARTICIPANT	\N	PRESENT	0
383096	382613	19549D	PARTICIPANT	\N	PRESENT	0
383097	382613	14219Q	PARTICIPANT	\N	PRESENT	0
370985	356308	11070L	PARTICIPANT	\N	PRESENT	0
376933	376932	19794Q	PARTICIPANT	\N	PRESENT	0
383098	382613	08055A	PARTICIPANT	\N	PRESENT	0
383099	382613	14169X	PARTICIPANT	\N	PRESENT	0
383100	382613	18083K	PARTICIPANT	\N	PRESENT	0
383101	382613	15447F	PARTICIPANT	\N	PRESENT	0
383102	382613	14051J	PARTICIPANT	\N	PRESENT	0
383103	382613	08060W	PARTICIPANT	\N	PRESENT	0
383104	382613	08009T	PRESIDENT	0	PRESENT	0
383105	382613	14157T	PARTICIPANT	\N	PRESENT	0
383106	382613	19745F	PARTICIPANT	\N	PRESENT	0
383107	382613	19525U	PARTICIPANT	\N	PRESENT	0
383108	382613	19685L	PARTICIPANT	\N	EXCUSE	0
383109	382613	14031R	PARTICIPANT	\N	PRESENT	0
383110	382613	19503N	PARTICIPANT	\N	PRESENT	0
383111	382613	19681G	PARTICIPANT	\N	PRESENT	0
383112	382613	02002K	PARTICIPANT	\N	PRESENT	0
383113	382613	19637C	PARTICIPANT	\N	PRESENT	0
383114	382613	19347U	PARTICIPANT	\N	PRESENT	0
383116	382613	19387D	PARTICIPANT	\N	PRESENT	0
383117	382613	04097T	PARTICIPANT	\N	PRESENT	0
383121	382613	19739H	PARTICIPANT	\N	PRESENT	0
383122	382613	14103D	PARTICIPANT	\N	PRESENT	0
383123	382613	11065P	PARTICIPANT	\N	PRESENT	0
383145	371540	01043Q	PARTICIPANT	\N	PRESENT	0
383146	383140	11067R	PARTICIPANT	\N	PRESENT	0
383147	383140	14147R	PARTICIPANT	\N	PRESENT	0
383148	383140	19749K	PARTICIPANT	\N	PRESENT	0
383149	383140	10006L	PRESIDENT	0	PRESENT	0
383150	383140	04047H	PARTICIPANT	\N	PRESENT	0
383151	383140	19621T	PARTICIPANT	\N	PRESENT	0
383156	371540	04059M	PARTICIPANT	\N	PRESENT	0
383157	371540	14229S	PARTICIPANT	\N	PRESENT	0
383158	371540	19651A	PARTICIPANT	\N	PRESENT	0
383159	371540	14063N	PARTICIPANT	\N	PRESENT	0
383160	371540	14055N	PARTICIPANT	\N	PRESENT	0
383161	371540	08039A	PARTICIPANT	\N	PRESENT	0
383162	371540	14105F	PARTICIPANT	\N	PRESENT	0
383163	371540	14041T	PARTICIPANT	\N	PRESENT	0
383164	371540	19731Y	PARTICIPANT	\N	PRESENT	0
383165	382179	14135M	PARTICIPANT	\N	PRESENT	0
383166	382179	19515S	PARTICIPANT	\N	PRESENT	0
383167	382179	19782L	PARTICIPANT	\N	PRESENT	0
383168	382179	14357A	PARTICIPANT	\N	PRESENT	0
383169	382179	08038Y	PARTICIPANT	\N	PRESENT	0
383170	382179	19441R	PARTICIPANT	\N	PRESENT	0
383171	382179	14081Q	PARTICIPANT	\N	PRESENT	0
383172	382179	19413M	PARTICIPANT	\N	PRESENT	0
383173	382179	01025N	PARTICIPANT	\N	PRESENT	0
383174	382179	14033T	PARTICIPANT	\N	PRESENT	0
383175	382179	11090Q	PRESIDENT	0	PRESENT	0
383176	382179	80013X	PARTICIPANT	\N	PRESENT	0
383177	382179	19631V	PARTICIPANT	\N	PRESENT	0
383178	382179	19269X	PARTICIPANT	\N	PRESENT	0
383179	382179	14205J	PARTICIPANT	\N	PRESENT	0
383180	382179	11056N	PARTICIPANT	\N	PRESENT	0
383181	382179	11101A	PARTICIPANT	\N	PRESENT	0
383182	382179	19507S	PARTICIPANT	\N	PRESENT	0
383183	382179	14197C	PARTICIPANT	\N	PRESENT	0
383184	382179	19369B	PARTICIPANT	\N	PRESENT	0
383185	382179	19747H	PARTICIPANT	\N	PRESENT	0
383186	382179	19511N	PARTICIPANT	\N	PRESENT	0
383187	382179	14257W	PARTICIPANT	\N	PRESENT	0
383188	371540	19758L	PARTICIPANT	\N	PRESENT	0
383189	371540	19289C	PARTICIPANT	\N	PRESENT	0
383192	371540	04057K	PARTICIPANT	\N	PRESENT	0
383193	371540	04070G	PARTICIPANT	\N	PRESENT	0
383194	371540	19703U	PARTICIPANT	\N	PRESENT	0
383195	371540	14038Y	PARTICIPANT	\N	PRESENT	0
383196	371540	19729F	PARTICIPANT	\N	PRESENT	0
383197	371540	19693L	PARTICIPANT	\N	PRESENT	0
383198	371540	99004R	PARTICIPANT	\N	PRESENT	0
383199	371540	18083K	PARTICIPANT	\N	PRESENT	0
383200	371540	19443T	PARTICIPANT	\N	PRESENT	0
383201	371540	19643A	PARTICIPANT	\N	PRESENT	0
383202	371540	11103C	PARTICIPANT	\N	PRESENT	0
383203	371540	14219Q	PARTICIPANT	\N	PRESENT	0
383204	371540	14042U	PARTICIPANT	\N	PRESENT	0
383205	371540	19611R	PARTICIPANT	\N	PRESENT	0
383206	371540	19721W	PARTICIPANT	\N	PRESENT	0
383262	382614	14038Y	PARTICIPANT	\N	PRESENT	0
383263	382614	19333N	PARTICIPANT	\N	PRESENT	0
383264	382614	14103D	PARTICIPANT	\N	PRESENT	0
383265	382614	19701S	PARTICIPANT	\N	PRESENT	0
383266	382614	19713W	PARTICIPANT	\N	PRESENT	0
383267	382614	95062K	PARTICIPANT	\N	PRESENT	0
383268	382614	19549D	PARTICIPANT	\N	PRESENT	0
383269	382614	19387D	PARTICIPANT	\N	PRESENT	0
383270	382614	15447F	PARTICIPANT	\N	PRESENT	0
383271	382614	18083K	PARTICIPANT	\N	PRESENT	0
383272	382614	14051J	PARTICIPANT	\N	PRESENT	0
383273	382614	08009T	PRESIDENT	0	PRESENT	0
383274	382614	19503N	PARTICIPANT	\N	PRESENT	0
383275	382614	04097T	PARTICIPANT	\N	PRESENT	0
383276	382614	19739H	PARTICIPANT	\N	PRESENT	0
383277	382614	19685L	PARTICIPANT	\N	EXCUSE	0
383278	371540	19521Q	PARTICIPANT	\N	PRESENT	0
383279	371540	04088S	PARTICIPANT	\N	PRESENT	0
383280	382614	19768N	PARTICIPANT	\N	PRESENT	0
383281	382614	19515S	PARTICIPANT	\N	PRESENT	0
383282	382614	19782L	PARTICIPANT	\N	PRESENT	0
383283	382614	14357A	PARTICIPANT	\N	PRESENT	0
383284	382614	19441R	PARTICIPANT	\N	PRESENT	0
383285	382614	19413M	PARTICIPANT	\N	PRESENT	0
383286	382614	14219Q	PARTICIPANT	\N	PRESENT	0
371141	371140	14089Y	PARTICIPANT	\N	PRESENT	0
371142	371140	95063L	PARTICIPANT	\N	PRESENT	0
371150	371149	11103C	PARTICIPANT	\N	PRESENT	0
371151	371149	14329V	PARTICIPANT	\N	PRESENT	0
371152	371149	14103D	PARTICIPANT	\N	PRESENT	0
371824	371823	14261S	PARTICIPANT	\N	PRESENT	0
371825	371823	14119M	PARTICIPANT	\N	PRESENT	0
372864	372863	19699S	PARTICIPANT	\N	PRESENT	0
372865	372861	19699S	PARTICIPANT	\N	PRESENT	0
372866	372861	19611R	PARTICIPANT	\N	PRESENT	0
372867	372859	19699S	PARTICIPANT	\N	PRESENT	0
372872	372871	08039A	PARTICIPANT	\N	PRESENT	0
372874	372873	14241N	PARTICIPANT	\N	PRESENT	0
372875	372873	19621T	PARTICIPANT	\N	PRESENT	0
372876	372873	14109K	PARTICIPANT	\N	PRESENT	0
372877	372873	08031R	PARTICIPANT	\N	PRESENT	0
372878	372873	19693L	PARTICIPANT	\N	PRESENT	0
372879	372873	14123H	PARTICIPANT	\N	PRESENT	0
372880	372873	19533U	PARTICIPANT	\N	PRESENT	0
372881	372873	19758L	PARTICIPANT	\N	PRESENT	0
372882	372873	19611R	PARTICIPANT	\N	PRESENT	0
373549	372868	11083R	PARTICIPANT	\N	PRESENT	0
373550	372868	19699S	PARTICIPANT	\N	PRESENT	0
373551	372869	19699S	PARTICIPANT	\N	PRESENT	0
373552	372869	14229S	PARTICIPANT	\N	PRESENT	0
373554	373553	19699S	PARTICIPANT	\N	PRESENT	0
373555	373553	11083R	PARTICIPANT	\N	PRESENT	0
373557	373556	19699S	PARTICIPANT	\N	PRESENT	0
373558	373556	19611R	PARTICIPANT	\N	PRESENT	0
373559	373556	11083R	PARTICIPANT	\N	PRESENT	0
380180	380179	14215L	PARTICIPANT	\N	PRESENT	0
380181	380179	14179A	PARTICIPANT	\N	PRESENT	0
380182	380179	19725B	PARTICIPANT	\N	PRESENT	0
380183	380179	14001X	PARTICIPANT	\N	PRESENT	0
380185	380184	14215L	PARTICIPANT	\N	PRESENT	0
380186	380184	14179A	PARTICIPANT	\N	PRESENT	0
380187	380184	19725B	PARTICIPANT	\N	PRESENT	0
380189	380188	14215L	PARTICIPANT	\N	PRESENT	0
380190	380188	14179A	PARTICIPANT	\N	PRESENT	0
387524	377927	19441R	PARTICIPANT	\N	PRESENT	0
387534	382859	14299H	PARTICIPANT	\N	EXCUSE	0
389609	387797	14239U	PARTICIPANT	\N	PRESENT	0
389610	387797	19760E	PARTICIPANT	\N	PRESENT	0
389611	387797	14261S	PARTICIPANT	\N	PRESENT	0
389612	387797	19575F	PARTICIPANT	\N	PRESENT	0
389613	387797	19367Y	PARTICIPANT	\N	PRESENT	0
389614	387797	14213J	PARTICIPANT	\N	PRESENT	0
389615	387797	19715Y	PARTICIPANT	\N	PRESENT	0
389616	387797	19569H	PARTICIPANT	\N	PRESENT	0
389617	387797	19553Y	PARTICIPANT	\N	PRESENT	0
389618	387797	01034P	PARTICIPANT	\N	PRESENT	0
389619	387797	19527W	PARTICIPANT	\N	PRESENT	0
389620	387797	19703U	PARTICIPANT	\N	PRESENT	0
389621	387797	04045F	PARTICIPANT	\N	PRESENT	0
389622	387797	11097X	PARTICIPANT	\N	PRESENT	0
389623	387797	11045K	PARTICIPANT	\N	PRESENT	0
389624	387797	19798U	PARTICIPANT	\N	PRESENT	0
389625	387797	19679N	PARTICIPANT	\N	PRESENT	0
389626	387797	14071N	PARTICIPANT	\N	PRESENT	0
389627	387797	04092N	PARTICIPANT	\N	PRESENT	0
389628	387797	14223L	PARTICIPANT	\N	PRESENT	0
389629	387797	17779H	PARTICIPANT	\N	PRESENT	0
389630	387797	19657G	PARTICIPANT	\N	PRESENT	0
389631	387797	11067R	PARTICIPANT	\N	PRESENT	0
389632	387797	19697Q	PARTICIPANT	\N	PRESENT	0
389633	387797	19691J	PARTICIPANT	\N	PRESENT	0
389634	387797	14026U	PARTICIPANT	\N	PRESENT	0
389635	387797	19727D	PARTICIPANT	\N	PRESENT	0
389636	387797	19565D	PARTICIPANT	\N	PRESENT	0
389637	387797	08041T	PARTICIPANT	\N	EXCUSE	0
389638	387797	08048B	PARTICIPANT	\N	PRESENT	0
389639	387797	14355X	PARTICIPANT	\N	PRESENT	0
389640	387797	19521Q	PARTICIPANT	\N	PRESENT	0
389641	387797	14281W	PARTICIPANT	\N	PRESENT	0
389642	387797	14042U	PARTICIPANT	\N	PRESENT	0
389643	387797	19577H	PARTICIPANT	\N	PRESENT	0
389644	387797	10006L	PARTICIPANT	\N	PRESENT	0
389645	387797	14217N	PARTICIPANT	\N	PRESENT	0
389668	387797	19663E	PARTICIPANT	\N	PRESENT	0
389669	387797	14087W	PARTICIPANT	\N	PRESENT	0
389670	387797	98024R	PRESIDENT	0	PRESENT	0
389671	387797	08052W	PARTICIPANT	\N	PRESENT	0
389672	387797	11031D	PARTICIPANT	\N	PRESENT	0
389673	387797	14195A	PARTICIPANT	\N	PRESENT	0
389674	387797	11103C	PARTICIPANT	\N	PRESENT	0
389675	387797	19415P	PARTICIPANT	\N	PRESENT	0
389719	385959	14227Q	PARTICIPANT	\N	PRESENT	0
389720	385959	19415P	PARTICIPANT	\N	PRESENT	0
389721	385959	11103C	PRESIDENT	0	PRESENT	0
389722	385959	08052W	PARTICIPANT	\N	PRESENT	0
389723	385959	11067R	PARTICIPANT	\N	PRESENT	0
389724	385959	04092N	PARTICIPANT	\N	PRESENT	0
389725	385959	11097X	PARTICIPANT	\N	PRESENT	0
389726	385959	17779H	PARTICIPANT	\N	PRESENT	0
389727	385959	19565D	PARTICIPANT	\N	PRESENT	0
389728	385959	14119M	PARTICIPANT	\N	PRESENT	0
389729	385959	19521Q	PARTICIPANT	\N	PRESENT	0
389730	385959	19691J	PARTICIPANT	\N	PRESENT	0
389731	385959	19575F	PARTICIPANT	\N	PRESENT	0
389732	385959	19798U	PARTICIPANT	\N	PRESENT	0
389733	385959	19367Y	PARTICIPANT	\N	PRESENT	0
389734	385959	19679N	PARTICIPANT	\N	PRESENT	0
389735	385959	14087W	PARTICIPANT	\N	PRESENT	0
389736	385959	14071N	PARTICIPANT	\N	PRESENT	0
389737	385959	14217N	PARTICIPANT	\N	PRESENT	0
389739	385959	14213J	PARTICIPANT	\N	PRESENT	0
389740	385959	14223L	PARTICIPANT	\N	PRESENT	0
389741	385959	08048B	PARTICIPANT	\N	PRESENT	0
389754	385959	14026U	PARTICIPANT	\N	PRESENT	0
389885	385959	19569H	PARTICIPANT	\N	PRESENT	0
389966	389964	01024M	PARTICIPANT	\N	PRESENT	0
389969	389964	01043Q	PARTICIPANT	\N	PRESENT	0
389970	389964	04070G	PARTICIPANT	\N	PRESENT	0
389971	389964	19745F	PARTICIPANT	\N	PRESENT	0
389972	389964	14133K	PARTICIPANT	\N	PRESENT	0
389973	389964	05008E	PARTICIPANT	\N	PRESENT	0
389974	389964	96004D	PARTICIPANT	\N	PRESENT	0
389975	389964	14069U	PARTICIPANT	\N	PRESENT	0
389976	389964	04047H	PARTICIPANT	\N	PRESENT	0
389982	389964	04042C	PARTICIPANT	\N	PRESENT	0
389983	389964	14038Y	PARTICIPANT	\N	PRESENT	0
389984	389964	08028W	PARTICIPANT	\N	PRESENT	0
389985	389964	18083K	PARTICIPANT	\N	PRESENT	0
389986	389964	14041T	PARTICIPANT	\N	PRESENT	0
389987	389964	19507S	PARTICIPANT	\N	PRESENT	0
389988	389964	08018U	PARTICIPANT	\N	PRESENT	0
389989	389964	19447X	PARTICIPANT	\N	PRESENT	0
389990	389964	86034E	PARTICIPANT	\N	PRESENT	0
389991	389964	19711U	PARTICIPANT	\N	PRESENT	0
389992	389964	19709B	PARTICIPANT	\N	PRESENT	0
389993	389964	14147R	PARTICIPANT	\N	PRESENT	0
389994	389964	19671E	PARTICIPANT	\N	PRESENT	0
389995	389964	14265W	PARTICIPANT	\N	PRESENT	0
389996	389964	14191V	PARTICIPANT	\N	PRESENT	0
389997	389964	11090Q	PARTICIPANT	\N	PRESENT	0
389998	389964	11097X	PARTICIPANT	\N	PRESENT	0
389999	389964	14157T	PARTICIPANT	\N	PRESENT	0
390000	389964	19593H	PARTICIPANT	\N	PRESENT	0
390001	389964	11074Q	PARTICIPANT	\N	PRESENT	0
390002	389964	08045X	PARTICIPANT	\N	PRESENT	0
390003	389964	14257W	PARTICIPANT	\N	PRESENT	0
390004	389964	01028R	PARTICIPANT	\N	PRESENT	0
390005	389964	95063L	PARTICIPANT	\N	PRESENT	0
390006	389964	19629C	PARTICIPANT	\N	PRESENT	0
390007	389964	88008L	PARTICIPANT	\N	PRESENT	0
390008	389964	19253P	PARTICIPANT	\N	PRESENT	0
390009	389964	19563B	PARTICIPANT	\N	PRESENT	0
390010	389964	08056B	PARTICIPANT	\N	PRESENT	0
390011	389964	14179A	PARTICIPANT	\N	PRESENT	0
390012	389964	14219Q	PARTICIPANT	\N	PRESENT	0
390013	389964	08009T	PARTICIPANT	\N	PRESENT	0
390014	389964	19713W	PARTICIPANT	\N	PRESENT	0
390015	389964	19737F	PARTICIPANT	\N	PRESENT	0
363920	363918	14133K	PARTICIPANT	\N	PRESENT	0
363921	363918	04088S	PARTICIPANT	\N	PRESENT	0
363922	363918	19443T	PARTICIPANT	\N	PRESENT	0
364304	364303	14069U	PARTICIPANT	\N	PRESENT	0
364305	364303	14255U	PARTICIPANT	\N	PRESENT	0
364306	364303	19467C	PARTICIPANT	\N	PRESENT	0
364307	364303	19649G	PARTICIPANT	\N	PRESENT	0
364308	364303	14041T	PARTICIPANT	\N	PRESENT	0
364309	364303	19647E	PARTICIPANT	\N	PRESENT	0
364310	364303	14081Q	PARTICIPANT	\N	PRESENT	0
364311	364303	04057K	PARTICIPANT	\N	PRESENT	0
364312	364303	19573D	PARTICIPANT	\N	PRESENT	0
364313	364303	17637T	PARTICIPANT	\N	PRESENT	0
364314	364303	05012A	PARTICIPANT	\N	PRESENT	0
364315	364303	04043D	PARTICIPANT	\N	PRESENT	0
364316	364303	19687N	PARTICIPANT	\N	PRESENT	0
364317	364303	08010L	PARTICIPANT	\N	PRESENT	0
364319	364318	19565D	PARTICIPANT	\N	PRESENT	0
364320	364318	19503N	PARTICIPANT	\N	PRESENT	0
364321	364318	04045F	PARTICIPANT	\N	PRESENT	0
364322	364318	04044E	PARTICIPANT	\N	PRESENT	0
364426	364425	19631V	PARTICIPANT	\N	PRESENT	0
364427	364425	14255U	PARTICIPANT	\N	PRESENT	0
364428	364425	11065P	PARTICIPANT	\N	PRESENT	0
364429	364425	19577H	PARTICIPANT	\N	PRESENT	0
364430	364425	19531S	PARTICIPANT	\N	PRESENT	0
364431	364425	14059S	PARTICIPANT	\N	PRESENT	0
364432	364425	11072N	PARTICIPANT	\N	PRESENT	0
364433	364425	14028W	PARTICIPANT	\N	PRESENT	0
364434	364425	19421M	PARTICIPANT	\N	PRESENT	0
364435	364425	19749K	PARTICIPANT	\N	PRESENT	0
375505	375504	11097X	PARTICIPANT	\N	PRESENT	0
375507	375506	11097X	PARTICIPANT	\N	PRESENT	0
375724	375049	08043V	PARTICIPANT	\N	EXCUSE	0
375726	375049	19295A	PARTICIPANT	\N	EXCUSE	0
375727	375049	14231L	PARTICIPANT	\N	EXCUSE	0
375729	375049	14213J	PARTICIPANT	\N	EXCUSE	0
375820	375049	19649G	PARTICIPANT	\N	PRESENT	0
375899	375049	01028R	PARTICIPANT	\N	PRESENT	0
376286	376285	19717B	PARTICIPANT	\N	PRESENT	0
376287	376285	14026U	PARTICIPANT	\N	PRESENT	0
378746	371478	14069U	PARTICIPANT	\N	PRESENT	0
378759	371478	19347U	PARTICIPANT	\N	PRESENT	0
378760	371478	19563B	PARTICIPANT	\N	PRESENT	0
378761	371478	19581D	PARTICIPANT	\N	PRESENT	0
378762	371478	11048N	PARTICIPANT	\N	PRESENT	0
378763	371478	11053K	PARTICIPANT	\N	PRESENT	0
378764	371478	14119M	PARTICIPANT	\N	PRESENT	0
378765	371478	04085P	PARTICIPANT	\N	PRESENT	0
378766	371478	14121F	PARTICIPANT	\N	PRESENT	0
378767	371478	14231L	PARTICIPANT	\N	PRESENT	0
378768	371478	14021P	PARTICIPANT	\N	PRESENT	0
378769	371478	04086Q	PARTICIPANT	\N	PRESENT	0
378770	371478	14261S	PARTICIPANT	\N	PRESENT	0
378771	371478	14357A	PARTICIPANT	\N	PRESENT	0
378772	376987	04070G	PRESIDENT	0	PRESENT	0
378773	376987	19699S	PARTICIPANT	\N	PRESENT	0
378774	376987	19533U	PARTICIPANT	\N	PRESENT	0
378775	376987	11074Q	PARTICIPANT	\N	PRESENT	0
378776	376987	14229S	PARTICIPANT	\N	PRESENT	0
378777	376987	14241N	PARTICIPANT	\N	PRESENT	0
378778	376987	19573D	PARTICIPANT	\N	PRESENT	0
378779	376987	08017T	PARTICIPANT	\N	PRESENT	0
378780	376987	92040Q	PARTICIPANT	\N	PRESENT	0
378781	376987	07033P	PARTICIPANT	\N	PRESENT	0
378782	376987	08012N	PARTICIPANT	\N	PRESENT	0
378783	376987	08031R	PARTICIPANT	\N	PRESENT	0
378784	376987	19593H	PARTICIPANT	\N	PRESENT	0
378785	376987	19643A	PARTICIPANT	\N	PRESENT	0
378786	376987	14073Q	PARTICIPANT	\N	PRESENT	0
378787	376987	19651A	PARTICIPANT	\N	PRESENT	0
378788	376987	19611R	PARTICIPANT	\N	PRESENT	0
378789	376987	19693L	PARTICIPANT	\N	PRESENT	0
378790	376987	87003B	PARTICIPANT	\N	PRESENT	0
378791	376987	19731Y	PARTICIPANT	\N	PRESENT	0
378792	376987	08020N	PARTICIPANT	\N	PRESENT	0
378793	376987	14251Q	PARTICIPANT	\N	PRESENT	0
378794	376987	04059M	PARTICIPANT	\N	PRESENT	0
378795	376987	19735D	PARTICIPANT	\N	PRESENT	0
378796	376987	14109K	PARTICIPANT	\N	PRESENT	0
378797	376987	14123H	PARTICIPANT	\N	PRESENT	0
378798	376987	11104D	PARTICIPANT	\N	PRESENT	0
378799	376987	19749K	PARTICIPANT	\N	PRESENT	0
378800	376987	04018C	PARTICIPANT	\N	PRESENT	0
378801	376987	19766L	PARTICIPANT	\N	EXCUSE	0
378802	371478	19631V	PARTICIPANT	\N	PRESENT	0
378803	371478	11054L	PARTICIPANT	\N	PRESENT	0
378804	371478	14087W	PARTICIPANT	\N	PRESENT	0
378805	376987	08011M	PARTICIPANT	\N	PRESENT	0
378806	371478	19659J	PARTICIPANT	\N	PRESENT	0
378807	371478	19349W	PARTICIPANT	\N	PRESENT	0
378816	371478	14033T	PARTICIPANT	\N	PRESENT	0
378817	371478	19511N	PARTICIPANT	\N	PRESENT	0
378818	371478	14029X	PARTICIPANT	\N	PRESENT	0
378828	371478	07029T	PARTICIPANT	\N	PRESENT	0
378856	371478	14105F	PARTICIPANT	\N	PRESENT	0
378857	371478	08045X	PARTICIPANT	\N	PRESENT	0
378858	378423	14053L	PARTICIPANT	\N	PRESENT	0
378859	378423	11026G	PARTICIPANT	\N	PRESENT	0
378860	378423	19253P	PARTICIPANT	\N	PRESENT	0
378861	378423	01060R	PARTICIPANT	\N	PRESENT	0
378862	378423	19543W	PARTICIPANT	\N	PRESENT	0
378863	378423	01024M	PARTICIPANT	\N	PRESENT	0
378864	378423	19581D	PARTICIPANT	\N	PRESENT	0
378865	378423	04044E	PARTICIPANT	\N	PRESENT	0
378866	378423	19673G	PARTICIPANT	\N	PRESENT	0
378867	378423	05008E	PRESIDENT	0	PRESENT	0
378868	378423	14231L	PARTICIPANT	\N	PRESENT	0
378869	378423	19447X	PARTICIPANT	\N	PRESENT	0
378870	378423	19725B	PARTICIPANT	\N	PRESENT	0
378871	378423	95063L	PARTICIPANT	\N	PRESENT	0
378872	378423	14069U	PARTICIPANT	\N	PRESENT	0
378873	378423	19762G	PARTICIPANT	\N	PRESENT	0
378874	371478	14115H	PARTICIPANT	\N	PRESENT	0
378875	371478	14331P	PARTICIPANT	\N	PRESENT	0
378876	371478	11097X	PARTICIPANT	\N	PRESENT	0
378895	371478	14042U	PARTICIPANT	\N	PRESENT	0
379342	379341	19631V	PARTICIPANT	\N	PRESENT	0
379343	379341	19747H	PARTICIPANT	\N	PRESENT	0
379344	379341	14207L	PARTICIPANT	\N	PRESENT	0
379345	379341	14197C	PARTICIPANT	\N	PRESENT	0
379346	379341	19441R	PARTICIPANT	\N	PRESENT	0
379347	379341	19369B	PARTICIPANT	\N	PRESENT	0
379348	379341	14265W	PARTICIPANT	\N	PRESENT	0
379349	379341	19383Y	PARTICIPANT	\N	PRESENT	0
379652	376284	11054L	PARTICIPANT	\N	EXCUSE	0
382641	382640	14069U	PARTICIPANT	\N	PRESENT	0
382642	382640	19719D	PARTICIPANT	\N	PRESENT	0
382644	382643	14069U	PARTICIPANT	\N	PRESENT	0
382675	382674	05008E	PARTICIPANT	\N	PRESENT	0
382683	376284	14261S	PARTICIPANT	\N	PRESENT	0
382684	376284	19691J	PARTICIPANT	\N	PRESENT	0
382685	376284	19715Y	PARTICIPANT	\N	PRESENT	0
382686	376284	08019V	PARTICIPANT	\N	PRESENT	0
382687	376284	11072N	PARTICIPANT	\N	EXCUSE	0
382688	376284	04043D	PARTICIPANT	\N	PRESENT	0
382689	376284	14331P	PARTICIPANT	\N	PRESENT	0
382694	376284	11010L	PARTICIPANT	\N	EXCUSE	0
382695	376284	19729F	PARTICIPANT	\N	EXCUSE	0
382696	376284	14038Y	PARTICIPANT	\N	EXCUSE	0
382697	376284	14097Y	PARTICIPANT	\N	EXCUSE	0
382785	382784	14255U	PARTICIPANT	\N	PRESENT	0
382786	382784	04042C	PARTICIPANT	\N	PRESENT	0
382787	382784	14267Y	PARTICIPANT	\N	PRESENT	0
382788	382784	14079W	PARTICIPANT	\N	PRESENT	0
382789	382784	95037J	PARTICIPANT	\N	PRESENT	0
382790	382784	12041X	PARTICIPANT	\N	PRESENT	0
382791	382784	16685X	PARTICIPANT	\N	PRESENT	0
382792	382784	08047A	PARTICIPANT	\N	PRESENT	0
382793	382784	11054L	PARTICIPANT	\N	PRESENT	0
382794	382784	01058X	PARTICIPANT	\N	PRESENT	0
382795	382784	01062T	PARTICIPANT	\N	PRESENT	0
382796	382784	95067Q	PARTICIPANT	\N	PRESENT	0
382797	382784	04034C	PARTICIPANT	\N	PRESENT	0
386091	385893	08018U	PARTICIPANT	\N	EXCUSE	0
386096	385893	14151M	PARTICIPANT	\N	PRESENT	0
386136	386130	05008E	PARTICIPANT	\N	PRESENT	0
386137	386130	19543W	PARTICIPANT	\N	PRESENT	0
386139	386130	11033F	PARTICIPANT	\N	PRESENT	0
386140	386130	14065Q	PARTICIPANT	\N	PRESENT	0
386141	386130	04047H	PARTICIPANT	\N	PRESENT	0
386143	386130	14053L	PARTICIPANT	\N	PRESENT	0
386144	386130	19629C	PARTICIPANT	\N	PRESENT	0
386145	386130	04038G	PARTICIPANT	\N	PRESENT	0
386146	386130	19253P	PARTICIPANT	\N	PRESENT	0
386147	386130	04008A	PARTICIPANT	\N	PRESENT	0
386149	386130	14041T	PARTICIPANT	\N	PRESENT	0
368311	356295	14041T	PARTICIPANT	\N	PRESENT	0
368312	356295	04088S	PARTICIPANT	\N	PRESENT	0
368313	356295	14029X	PARTICIPANT	\N	PRESENT	0
368314	356295	14135M	PARTICIPANT	\N	PRESENT	0
368315	356295	14121F	PARTICIPANT	\N	PRESENT	0
368316	356295	19725B	PARTICIPANT	\N	PRESENT	0
368324	356295	01028R	PARTICIPANT	\N	PRESENT	0
368318	356295	14225N	PARTICIPANT	\N	PRESENT	0
368319	356295	04038G	PARTICIPANT	\N	PRESENT	0
368320	356295	19565D	PARTICIPANT	\N	PRESENT	0
368321	356295	19758L	PARTICIPANT	\N	PRESENT	0
368322	356295	14065Q	PARTICIPANT	\N	PRESENT	0
368323	356295	01062T	PARTICIPANT	\N	PRESENT	0
368325	356295	19782L	PARTICIPANT	\N	PRESENT	0
368326	356295	14111D	PARTICIPANT	\N	PRESENT	0
368327	356295	05008E	PARTICIPANT	\N	PRESENT	0
368328	356295	88008L	PARTICIPANT	\N	PRESENT	0
368329	356295	11012A	PARTICIPANT	\N	PRESENT	0
368330	356295	19253P	PARTICIPANT	\N	PRESENT	0
368331	356295	19611R	PARTICIPANT	\N	PRESENT	0
368309	356295	11072N	PARTICIPANT	\N	PRESENT	0
368310	356295	14053L	PARTICIPANT	\N	PRESENT	0
368332	356295	14073Q	PARTICIPANT	\N	PRESENT	0
368333	356295	07004J	PARTICIPANT	\N	PRESENT	0
368334	356295	14215L	PARTICIPANT	\N	PRESENT	0
368335	356295	14087W	PARTICIPANT	\N	PRESENT	0
368336	356295	01024M	PARTICIPANT	\N	PRESENT	0
368337	356295	11110B	PARTICIPANT	\N	PRESENT	0
368338	356295	04044E	PARTICIPANT	\N	PRESENT	0
368339	356295	19335Q	PARTICIPANT	\N	PRESENT	0
368340	356295	19745F	PARTICIPANT	\N	PRESENT	0
368341	356295	19367Y	PARTICIPANT	\N	PRESENT	0
368342	356295	19581D	PARTICIPANT	\N	PRESENT	0
368343	356295	14079W	PARTICIPANT	\N	PRESENT	0
368344	356295	19762G	PARTICIPANT	\N	PRESENT	0
368345	356295	19383Y	PARTICIPANT	\N	PRESENT	0
368346	356295	97011G	PARTICIPANT	\N	PRESENT	0
368347	356295	14061L	PARTICIPANT	\N	PRESENT	0
368348	356295	14265W	PARTICIPANT	\N	PRESENT	0
368349	356295	11048N	PARTICIPANT	\N	PRESENT	0
368350	356295	14033T	PARTICIPANT	\N	PRESENT	0
368351	356295	11049P	PARTICIPANT	\N	PRESENT	0
368352	356295	87003B	PARTICIPANT	\N	PRESENT	0
368353	356295	10015M	PARTICIPANT	\N	PRESENT	0
368354	356295	14259Y	PARTICIPANT	\N	PRESENT	0
368355	356295	14157T	PARTICIPANT	\N	PRESENT	0
368356	356295	19467C	PARTICIPANT	\N	PRESENT	0
368357	356295	19679N	PARTICIPANT	\N	PRESENT	0
368358	356295	95030B	PARTICIPANT	\N	PRESENT	0
368359	356295	14211G	PARTICIPANT	\N	PRESENT	0
368360	356295	19739H	PARTICIPANT	\N	PRESENT	0
368361	356295	19551W	PARTICIPANT	\N	PRESENT	0
368362	356295	19794Q	PARTICIPANT	\N	PRESENT	0
368363	356295	14223L	PARTICIPANT	\N	PRESENT	0
368364	356295	19553Y	PARTICIPANT	\N	PRESENT	0
368365	356295	08031R	PARTICIPANT	\N	PRESENT	0
368366	356295	14241N	PARTICIPANT	\N	PRESENT	0
368367	356295	14331P	PARTICIPANT	\N	PRESENT	0
368368	356295	11085T	PARTICIPANT	\N	PRESENT	0
368369	356295	04045F	PARTICIPANT	\N	PRESENT	0
368370	356295	19687N	PARTICIPANT	\N	PRESENT	0
368371	356295	80013X	PARTICIPANT	\N	PRESENT	0
368372	356295	14217N	PARTICIPANT	\N	PRESENT	0
368373	356295	11053K	PARTICIPANT	\N	PRESENT	0
368374	356295	04047H	PARTICIPANT	\N	PRESENT	0
368375	356295	92040Q	PARTICIPANT	\N	PRESENT	0
368376	356295	19447X	PARTICIPANT	\N	PRESENT	0
368377	356295	19760E	PARTICIPANT	\N	PRESENT	0
368378	356295	14109K	PARTICIPANT	\N	PRESENT	0
368379	356295	14207L	PARTICIPANT	\N	PRESENT	0
368380	356295	14357A	PARTICIPANT	\N	PRESENT	0
368381	356295	19533U	PARTICIPANT	\N	PRESENT	0
368382	356295	14199E	PARTICIPANT	\N	PRESENT	0
368383	356295	14069U	PARTICIPANT	\N	PRESENT	0
368384	356295	08020N	PARTICIPANT	\N	PRESENT	0
368385	356295	01060R	PARTICIPANT	\N	PRESENT	0
368386	356295	01057W	PARTICIPANT	\N	PRESENT	0
368387	356295	14031R	PARTICIPANT	\N	PRESENT	0
368388	356295	01058X	PARTICIPANT	\N	PRESENT	0
368389	356295	11097X	PARTICIPANT	\N	PRESENT	0
368390	356295	14042U	PARTICIPANT	\N	PRESENT	0
368391	356295	19563B	PARTICIPANT	\N	PRESENT	0
368392	356295	89017R	PARTICIPANT	\N	PRESENT	0
368393	356295	19713W	PARTICIPANT	\N	PRESENT	0
368394	356295	19737F	PARTICIPANT	\N	PRESENT	0
368395	356295	98035U	PARTICIPANT	\N	PRESENT	0
368396	356295	19415P	PARTICIPANT	\N	PRESENT	0
368397	356295	14147R	PARTICIPANT	\N	PRESENT	0
368398	356295	14021P	PARTICIPANT	\N	PRESENT	0
368399	356295	04049K	PARTICIPANT	\N	PRESENT	0
368400	356295	19621T	PARTICIPANT	\N	PRESENT	0
368401	356295	14179A	PARTICIPANT	\N	PRESENT	0
368402	356295	14187A	PARTICIPANT	\N	PRESENT	0
368403	356295	14083S	PARTICIPANT	\N	PRESENT	0
368404	356295	14026U	PARTICIPANT	\N	PRESENT	0
368405	356295	19507S	PARTICIPANT	\N	PRESENT	0
368406	356295	14257W	PARTICIPANT	\N	PRESENT	0
368407	356295	08015R	PARTICIPANT	\N	PRESENT	0
368408	356295	18083K	PARTICIPANT	\N	PRESENT	0
368409	356295	95063L	PARTICIPANT	\N	PRESENT	0
368410	356295	08061X	PARTICIPANT	\N	PRESENT	0
368411	356295	05012A	PARTICIPANT	\N	PRESENT	0
368498	356296	11027H	PARTICIPANT	\N	PRESENT	0
368499	356296	05008E	PARTICIPANT	\N	PRESENT	0
368500	356296	14053L	PARTICIPANT	\N	PRESENT	0
368501	356296	19565D	PARTICIPANT	\N	PRESENT	0
368502	356296	19687N	PARTICIPANT	\N	PRESENT	0
368503	356296	19551W	PARTICIPANT	\N	PRESENT	0
368504	356296	01062T	PARTICIPANT	\N	PRESENT	0
368505	356296	19725B	PARTICIPANT	\N	PRESENT	0
368506	356296	04045F	PARTICIPANT	\N	PRESENT	0
368507	356296	14065Q	PARTICIPANT	\N	PRESENT	0
368508	356296	14073Q	PARTICIPANT	\N	PRESENT	0
368509	356296	14031R	PARTICIPANT	\N	PRESENT	0
368510	356296	19447X	PARTICIPANT	\N	PRESENT	0
368511	356296	92040Q	PARTICIPANT	\N	PRESENT	0
368512	356296	14061L	PARTICIPANT	\N	PRESENT	0
368513	356296	19762G	PARTICIPANT	\N	PRESENT	0
368514	356296	19621T	PARTICIPANT	\N	PRESENT	0
368515	356296	14079W	PARTICIPANT	\N	PRESENT	0
368516	356296	11110B	PARTICIPANT	\N	PRESENT	0
368517	356296	10015M	PARTICIPANT	\N	PRESENT	0
368518	356296	14223L	PARTICIPANT	\N	PRESENT	0
368519	356296	14069U	PARTICIPANT	\N	PRESENT	0
368520	356296	01024M	PARTICIPANT	\N	PRESENT	0
368521	356296	07004J	PARTICIPANT	\N	PRESENT	0
368522	356296	14029X	PARTICIPANT	\N	PRESENT	0
368523	356296	01060R	PARTICIPANT	\N	PRESENT	0
368524	356296	04061F	PARTICIPANT	\N	PRESENT	0
368525	356296	14030Q	PARTICIPANT	\N	PRESENT	0
368526	356296	08019V	PARTICIPANT	\N	PRESENT	0
368527	356296	05012A	PARTICIPANT	\N	PRESENT	0
368528	356296	14147R	PARTICIPANT	\N	PRESENT	0
368529	356296	04044E	PARTICIPANT	\N	PRESENT	0
368530	356296	08044W	PARTICIPANT	\N	PRESENT	0
368531	356296	04038G	PARTICIPANT	\N	PRESENT	0
368532	356296	11049P	PARTICIPANT	\N	PRESENT	0
368533	356296	14033T	PARTICIPANT	\N	PRESENT	0
368534	356296	19467C	PARTICIPANT	\N	PRESENT	0
368535	356296	14265W	PARTICIPANT	\N	PRESENT	0
368536	356296	95030B	PARTICIPANT	\N	PRESENT	0
368537	356296	19335Q	PARTICIPANT	\N	PRESENT	0
368538	356296	19760E	PARTICIPANT	\N	PRESENT	0
368539	356296	19758L	PARTICIPANT	\N	PRESENT	0
368540	356296	19553Y	PARTICIPANT	\N	PRESENT	0
368541	356296	11097X	PARTICIPANT	\N	PRESENT	0
368542	356296	14259Y	PARTICIPANT	\N	PRESENT	0
368543	356296	14215L	PARTICIPANT	\N	PRESENT	0
368544	356296	14133K	PARTICIPANT	\N	PRESENT	0
368545	356296	14217N	PARTICIPANT	\N	PRESENT	0
368546	356296	11048N	PARTICIPANT	\N	PRESENT	0
368547	356296	04018C	PARTICIPANT	\N	PRESENT	0
368548	356296	19253P	PARTICIPANT	\N	PRESENT	0
368549	356296	17637T	PARTICIPANT	\N	PRESENT	0
368550	356296	19507S	PARTICIPANT	\N	PRESENT	0
368551	356296	18083K	PARTICIPANT	\N	PRESENT	0
368552	356296	19383Y	PARTICIPANT	\N	PRESENT	0
368553	356296	11012A	PARTICIPANT	\N	PRESENT	0
368554	356296	01028R	PARTICIPANT	\N	PRESENT	0
368555	356296	01057W	PARTICIPANT	\N	PRESENT	0
368556	356296	07029T	PARTICIPANT	\N	PRESENT	0
368557	356296	11085T	PARTICIPANT	\N	PRESENT	0
368558	356296	14026U	PARTICIPANT	\N	PRESENT	0
368559	356296	14187A	PARTICIPANT	\N	PRESENT	0
368560	356296	14179A	PARTICIPANT	\N	PRESENT	0
368561	356296	14034U	PARTICIPANT	\N	PRESENT	0
368562	356296	19563B	PARTICIPANT	\N	PRESENT	0
368563	356296	14083S	PARTICIPANT	\N	PRESENT	0
366991	366990	19782L	PARTICIPANT	\N	PRESENT	0
366992	366990	11101A	PARTICIPANT	\N	PRESENT	0
366993	366990	01043Q	PARTICIPANT	\N	PRESENT	0
366994	366990	14205J	PARTICIPANT	\N	PRESENT	0
366995	366990	19563B	PRESIDENT	0	PRESENT	0
366996	366990	14237S	PARTICIPANT	\N	PRESENT	0
366997	366990	19413M	PARTICIPANT	\N	PRESENT	0
366998	366990	95067Q	PARTICIPANT	\N	PRESENT	0
366999	366990	19575F	PARTICIPANT	\N	EXCUSE	0
367000	366990	08068F	PARTICIPANT	\N	EXCUSE	0
367001	366990	11049P	PARTICIPANT	\N	EXCUSE	0
367002	366990	07029T	PARTICIPANT	\N	EXCUSE	0
367003	366990	19637C	PARTICIPANT	\N	EXCUSE	0
367004	366990	14265W	PARTICIPANT	\N	EXCUSE	0
367005	366990	19527W	PARTICIPANT	\N	EXCUSE	0
367006	366474	14205J	PARTICIPANT	\N	PRESENT	0
367801	367799	04040A	PRESIDENT	0	PRESENT	0
383287	382614	08015R	PARTICIPANT	\N	PRESENT	0
383288	382614	14197C	PARTICIPANT	\N	PRESENT	0
383289	382614	19511N	PARTICIPANT	\N	PRESENT	0
383290	382614	08038Y	PARTICIPANT	\N	PRESENT	0
383291	382614	11090Q	PARTICIPANT	\N	PRESENT	0
383292	382614	14033T	PARTICIPANT	\N	PRESENT	0
383293	382614	01025N	PARTICIPANT	\N	PRESENT	0
383294	382614	14205J	PARTICIPANT	\N	PRESENT	0
383295	382614	11056N	PARTICIPANT	\N	PRESENT	0
383296	382614	19747H	PARTICIPANT	\N	PRESENT	0
383297	382614	04043D	PARTICIPANT	\N	PRESENT	0
383298	371540	14111D	PARTICIPANT	\N	PRESENT	0
383299	371540	19681G	PARTICIPANT	\N	PRESENT	0
383300	371540	14197C	PARTICIPANT	\N	PRESENT	0
383301	382180	19383Y	PARTICIPANT	\N	PRESENT	0
383302	382180	19333N	PARTICIPANT	\N	PRESENT	0
383303	382180	19701S	PARTICIPANT	\N	PRESENT	0
383304	382180	19533U	PARTICIPANT	\N	PRESENT	0
383305	382180	95062K	PARTICIPANT	\N	PRESENT	0
383306	382180	19549D	PARTICIPANT	\N	PRESENT	0
383307	382180	19387D	PARTICIPANT	\N	PRESENT	0
383308	382180	14219Q	PARTICIPANT	\N	PRESENT	0
383309	382180	18083K	PARTICIPANT	\N	PRESENT	0
383310	382180	14051J	PARTICIPANT	\N	PRESENT	0
383311	382180	19503N	PARTICIPANT	\N	PRESENT	0
383312	382180	11065P	PARTICIPANT	\N	PRESENT	0
383313	382180	14038Y	PARTICIPANT	\N	PRESENT	0
383314	382180	14103D	PARTICIPANT	\N	PRESENT	0
383315	382180	19713W	PARTICIPANT	\N	PRESENT	0
383316	382180	15447F	PARTICIPANT	\N	PRESENT	0
383317	382180	08009T	PARTICIPANT	\N	PRESENT	0
383318	382180	04097T	PARTICIPANT	\N	PRESENT	0
383319	382180	19739H	PARTICIPANT	\N	PRESENT	0
383320	382180	14031R	PARTICIPANT	\N	PRESENT	0
383410	371541	19758L	PARTICIPANT	\N	PRESENT	0
383411	371541	12041X	PARTICIPANT	\N	PRESENT	0
383412	371541	11040E	PARTICIPANT	\N	PRESENT	0
383413	371541	04085P	PARTICIPANT	\N	PRESENT	0
383414	371541	11056N	PARTICIPANT	\N	PRESENT	0
383415	371541	19687N	PARTICIPANT	\N	PRESENT	0
383416	371541	11031D	PARTICIPANT	\N	PRESENT	0
383417	371541	14235Q	PARTICIPANT	\N	PRESENT	0
383419	371541	19347U	PARTICIPANT	\N	PRESENT	0
383420	371541	19695N	PARTICIPANT	\N	PRESENT	0
383421	371541	19760E	PARTICIPANT	\N	PRESENT	0
383422	371541	19593H	PARTICIPANT	\N	PRESENT	0
383423	371541	14211G	PARTICIPANT	\N	PRESENT	0
383424	371541	04045F	PARTICIPANT	\N	PRESENT	0
383425	371541	08061X	PARTICIPANT	\N	PRESENT	0
383426	371541	17637T	PARTICIPANT	\N	PRESENT	0
383427	371541	95037J	PARTICIPANT	\N	PRESENT	0
383428	371541	11083R	PARTICIPANT	\N	PRESENT	0
383429	371541	19711U	PARTICIPANT	\N	PRESENT	0
383430	371541	19637C	PARTICIPANT	\N	PRESENT	0
383431	371541	19349W	PARTICIPANT	\N	PRESENT	0
383432	371541	95062K	PARTICIPANT	\N	PRESENT	0
383433	371541	08024S	PARTICIPANT	\N	PRESENT	0
383434	371541	19782L	PARTICIPANT	\N	PRESENT	0
383435	371541	08011M	PARTICIPANT	\N	PRESENT	0
383436	371541	95063L	PARTICIPANT	\N	PRESENT	0
383437	371541	14157T	PARTICIPANT	\N	PRESENT	0
383438	371541	11072N	PARTICIPANT	\N	PRESENT	0
383439	371541	04071H	PARTICIPANT	\N	PRESENT	0
383440	371541	19731Y	PARTICIPANT	\N	PRESENT	0
383441	371541	14055N	PARTICIPANT	\N	PRESENT	0
383442	371541	89017R	PARTICIPANT	\N	PRESENT	0
383444	371541	99004R	PARTICIPANT	\N	PRESENT	0
383446	371541	19697Q	PARTICIPANT	\N	PRESENT	0
383449	371541	96004D	PARTICIPANT	\N	PRESENT	0
383450	371541	04038G	PARTICIPANT	\N	PRESENT	0
383451	371541	88008L	PARTICIPANT	\N	PRESENT	0
383452	371541	08031R	PARTICIPANT	\N	PRESENT	0
383453	371541	14261S	PARTICIPANT	\N	PRESENT	0
383454	371541	08049C	PARTICIPANT	\N	PRESENT	0
383455	371541	19679N	PARTICIPANT	\N	PRESENT	0
383456	371541	19253P	PARTICIPANT	\N	PRESENT	0
383457	371541	04097T	PARTICIPANT	\N	PRESENT	0
383458	371541	19629C	PARTICIPANT	\N	PRESENT	0
383459	371541	14201E	PARTICIPANT	\N	PRESENT	0
383460	371541	08039A	PARTICIPANT	\N	PRESENT	0
383461	371541	19681G	PARTICIPANT	\N	PRESENT	0
383462	371541	08010L	PARTICIPANT	\N	PRESENT	0
383463	371541	98022P	PARTICIPANT	\N	PRESENT	0
383464	371541	08069G	PARTICIPANT	\N	PRESENT	0
383465	371541	14241N	PARTICIPANT	\N	PRESENT	0
383466	371541	14107H	PARTICIPANT	\N	PRESENT	0
383467	371541	04042C	PARTICIPANT	\N	PRESENT	0
383468	371541	19387D	PARTICIPANT	\N	PRESENT	0
383469	371541	19289C	PARTICIPANT	\N	PRESENT	0
383470	371541	11065P	PARTICIPANT	\N	PRESENT	0
383471	371541	15447F	PARTICIPANT	\N	PRESENT	0
383472	371541	19643A	PARTICIPANT	\N	PRESENT	0
383473	371541	19553Y	PARTICIPANT	\N	PRESENT	0
383474	371541	14207L	PARTICIPANT	\N	PRESENT	0
383475	371541	14169X	PARTICIPANT	\N	PRESENT	0
383476	371541	11043H	PARTICIPANT	\N	PRESENT	0
383477	371541	01048V	PARTICIPANT	\N	PRESENT	0
383478	371541	08028W	PARTICIPANT	\N	PRESENT	0
383479	371541	19563B	PARTICIPANT	\N	PRESENT	0
383480	371541	19515S	PARTICIPANT	\N	PRESENT	0
383481	371541	01057W	PARTICIPANT	\N	PRESENT	0
383482	371541	08073C	PARTICIPANT	\N	PRESENT	0
383483	371541	87003B	PARTICIPANT	\N	PRESENT	0
383484	371541	19719D	PARTICIPANT	\N	PRESENT	0
383485	371541	14223L	PARTICIPANT	\N	PRESENT	0
383486	371541	11090Q	PARTICIPANT	\N	PRESENT	0
383487	371541	19545Y	PARTICIPANT	\N	PRESENT	0
383488	371541	95067Q	PARTICIPANT	\N	PRESENT	0
383489	371541	14251Q	PARTICIPANT	\N	PRESENT	0
383490	371541	14093U	PARTICIPANT	\N	PRESENT	0
383491	371541	17589D	PARTICIPANT	\N	PRESENT	0
383492	371541	19703U	PARTICIPANT	\N	PRESENT	0
383493	371541	14111D	PARTICIPANT	\N	PRESENT	0
383494	371541	04057K	PARTICIPANT	\N	PRESENT	0
383495	371541	19673G	PARTICIPANT	\N	PRESENT	0
383496	371541	19585H	PARTICIPANT	\N	PRESENT	0
383497	371541	14031R	PARTICIPANT	\N	PRESENT	0
383498	371541	11099A	PARTICIPANT	\N	PRESENT	0
383499	371541	11115U	PARTICIPANT	\N	PRESENT	0
383500	371541	01060R	PARTICIPANT	\N	PRESENT	0
383502	371541	98035U	PARTICIPANT	\N	PRESENT	0
383503	371541	11074Q	PARTICIPANT	\N	PRESENT	0
383504	371541	14253S	PARTICIPANT	\N	PRESENT	0
383505	371541	11027H	PARTICIPANT	\N	PRESENT	0
383506	371541	14159V	PARTICIPANT	\N	PRESENT	0
383507	371541	11048N	PARTICIPANT	\N	PRESENT	0
383508	371541	04049K	PARTICIPANT	\N	PRESENT	0
383509	371541	08055A	PARTICIPANT	\N	PRESENT	0
383510	371541	14229S	PARTICIPANT	\N	PRESENT	0
383511	371541	19269X	PARTICIPANT	\N	PRESENT	0
383512	371541	05008E	PARTICIPANT	\N	PRESENT	0
383513	371541	14199E	PARTICIPANT	\N	PRESENT	0
383514	371541	08052W	PARTICIPANT	\N	PRESENT	0
383515	371541	08020N	PARTICIPANT	\N	PRESENT	0
383516	371541	01028R	PARTICIPANT	\N	PRESENT	0
383517	371541	19447X	PARTICIPANT	\N	PRESENT	0
383518	371541	14051J	PARTICIPANT	\N	PRESENT	0
383519	371541	14021P	PARTICIPANT	\N	PRESENT	0
383520	371541	19573D	PARTICIPANT	\N	PRESENT	0
383521	371541	19669L	PARTICIPANT	\N	PRESENT	0
383522	371541	14225N	PARTICIPANT	\N	PRESENT	0
383523	371541	19794Q	PARTICIPANT	\N	PRESENT	0
383524	371541	14151M	PARTICIPANT	\N	PRESENT	0
383525	371541	14133K	PARTICIPANT	\N	PRESENT	0
383526	371541	19647E	PARTICIPANT	\N	PRESENT	0
383527	371541	92040Q	PARTICIPANT	\N	PRESENT	0
383528	371541	19649G	PARTICIPANT	\N	PRESENT	0
383529	371541	11045K	PARTICIPANT	\N	PRESENT	0
387584	387583	14081Q	PARTICIPANT	\N	PRESENT	0
388242	377975	19593H	PARTICIPANT	\N	PRESENT	0
388243	377975	14201E	PARTICIPANT	\N	PRESENT	0
388244	377975	98022P	PARTICIPANT	\N	PRESENT	0
388245	377975	14241N	PARTICIPANT	\N	PRESENT	0
388246	377975	14107H	PARTICIPANT	\N	PRESENT	0
388247	377975	11099A	PARTICIPANT	\N	PRESENT	0
388248	377975	19387D	PARTICIPANT	\N	PRESENT	0
388249	377975	19553Y	PARTICIPANT	\N	PRESENT	0
388250	377975	14207L	PARTICIPANT	\N	PRESENT	0
388251	377975	08061X	PARTICIPANT	\N	PRESENT	0
388252	377975	08021P	PARTICIPANT	\N	PRESENT	0
388253	377975	95037J	PARTICIPANT	\N	PRESENT	0
388254	377975	11072N	PARTICIPANT	\N	PRESENT	0
388255	377975	98029W	PARTICIPANT	\N	PRESENT	0
388256	377975	14039A	PARTICIPANT	\N	PRESENT	0
388257	377975	19711U	PARTICIPANT	\N	PRESENT	0
388258	377975	14211G	PARTICIPANT	\N	PRESENT	0
388259	377975	19679N	PARTICIPANT	\N	PRESENT	0
388260	377975	19731Y	PARTICIPANT	\N	PRESENT	0
388261	377975	19329S	PARTICIPANT	\N	PRESENT	0
388262	377975	08039A	PARTICIPANT	\N	PRESENT	0
388263	377975	01058X	PARTICIPANT	\N	PRESENT	0
388264	377975	04057K	PARTICIPANT	\N	PRESENT	0
388265	377975	11064N	PARTICIPANT	\N	PRESENT	0
388266	377975	11110B	PARTICIPANT	\N	PRESENT	0
388267	377975	99004R	PARTICIPANT	\N	PRESENT	0
388268	377975	19591F	PARTICIPANT	\N	PRESENT	0
388269	377975	08045X	PARTICIPANT	\N	PRESENT	0
388270	377975	08010L	PARTICIPANT	\N	PRESENT	0
388271	377975	01062T	PARTICIPANT	\N	PRESENT	0
388272	377975	19599P	PARTICIPANT	\N	PRESENT	0
388273	377975	14123H	PARTICIPANT	\N	PRESENT	0
388274	377975	14109K	PARTICIPANT	\N	PRESENT	0
388275	377975	08069G	PARTICIPANT	\N	PRESENT	0
388276	377975	04042C	PARTICIPANT	\N	PRESENT	0
388277	377975	15447F	PARTICIPANT	\N	PRESENT	0
388278	377975	14169X	PARTICIPANT	\N	PRESENT	0
388279	377975	14081Q	PARTICIPANT	\N	PRESENT	0
388280	377975	11109J	PARTICIPANT	\N	PRESENT	0
388281	377975	10015M	PARTICIPANT	\N	PRESENT	0
388282	377975	14001X	PARTICIPANT	\N	PRESENT	0
388283	377975	08035V	PARTICIPANT	\N	PRESENT	0
388284	377975	17779H	PARTICIPANT	\N	PRESENT	0
388285	377975	19715Y	PARTICIPANT	\N	PRESENT	0
388286	377975	14197C	PARTICIPANT	\N	PRESENT	0
388287	377975	11043H	PARTICIPANT	\N	PRESENT	0
388288	377975	14195A	PARTICIPANT	\N	PRESENT	0
388289	377975	14093U	PARTICIPANT	\N	PRESENT	0
388290	377975	01048V	PARTICIPANT	\N	PRESENT	0
388291	377975	04045F	PARTICIPANT	\N	PRESENT	0
388292	377975	08028W	PARTICIPANT	\N	PRESENT	0
388293	377975	08043V	PARTICIPANT	\N	PRESENT	0
388294	377975	14191V	PARTICIPANT	\N	PRESENT	0
388295	377975	04034C	PARTICIPANT	\N	PRESENT	0
388296	377975	19766L	PARTICIPANT	\N	PRESENT	0
388297	377975	14231L	PARTICIPANT	\N	PRESENT	0
388298	377975	14179A	PARTICIPANT	\N	PRESENT	0
388299	377975	01034P	PARTICIPANT	\N	PRESENT	0
388300	377975	19691J	PARTICIPANT	\N	PRESENT	0
388301	377975	87003B	PARTICIPANT	\N	PRESENT	0
388302	377975	19511N	PARTICIPANT	\N	PRESENT	0
388303	377975	19619A	PARTICIPANT	\N	PRESENT	0
388304	377975	11083R	PARTICIPANT	\N	PRESENT	0
388305	377975	14223L	PARTICIPANT	\N	PRESENT	0
388306	377975	11053K	PARTICIPANT	\N	PRESENT	0
388307	377975	19721W	PARTICIPANT	\N	PRESENT	0
388308	377975	19737F	PARTICIPANT	\N	PRESENT	0
388309	377975	19727D	PARTICIPANT	\N	PRESENT	0
388310	377975	19569H	PARTICIPANT	\N	PRESENT	0
388311	377975	08056B	PARTICIPANT	\N	PRESENT	0
388312	377975	14227Q	PARTICIPANT	\N	PRESENT	0
388313	377975	19713W	PARTICIPANT	\N	PRESENT	0
388314	377975	19735D	PARTICIPANT	\N	PRESENT	0
388315	377975	01043Q	PARTICIPANT	\N	PRESENT	0
388316	377975	16685X	PARTICIPANT	\N	PRESENT	0
388317	377975	19479G	PARTICIPANT	\N	PRESENT	0
388318	377975	14219Q	PARTICIPANT	\N	PRESENT	0
388319	377975	14028W	PARTICIPANT	\N	PRESENT	0
388320	377975	19543W	PARTICIPANT	\N	PRESENT	0
388321	377975	19521Q	PARTICIPANT	\N	PRESENT	0
388322	377975	11085T	PARTICIPANT	\N	PRESENT	0
388323	377975	14089Y	PARTICIPANT	\N	PRESENT	0
388324	377975	14255U	PARTICIPANT	\N	PRESENT	0
388325	377975	14073Q	PARTICIPANT	\N	PRESENT	0
388326	377975	14275Y	PARTICIPANT	\N	PRESENT	0
388327	377975	14042U	PARTICIPANT	\N	PRESENT	0
388328	377975	14327T	PARTICIPANT	\N	PRESENT	0
388329	377975	11070L	PARTICIPANT	\N	PRESENT	0
388330	377975	14267Y	PARTICIPANT	\N	PRESENT	0
388331	377975	14103D	PARTICIPANT	\N	PRESENT	0
388333	377975	19335Q	PARTICIPANT	\N	PRESENT	0
388334	377975	14221J	PARTICIPANT	\N	PRESENT	0
388335	377975	04070G	PARTICIPANT	\N	PRESENT	0
388336	377975	14030Q	PARTICIPANT	\N	PRESENT	0
388337	377975	01024M	PARTICIPANT	\N	PRESENT	0
388338	377975	19745F	PARTICIPANT	\N	PRESENT	0
388339	377975	08068F	PARTICIPANT	\N	PRESENT	0
388340	377975	01057W	PARTICIPANT	\N	PRESENT	0
388341	377975	11090Q	PARTICIPANT	\N	PRESENT	0
388342	377975	14031R	PARTICIPANT	\N	PRESENT	0
388343	377975	14157T	PARTICIPANT	\N	PRESENT	0
388344	377975	14199E	PARTICIPANT	\N	PRESENT	0
388345	377975	19575F	PARTICIPANT	\N	PRESENT	0
388346	377975	14253S	PARTICIPANT	\N	PRESENT	0
388347	377975	19768N	PARTICIPANT	\N	PRESENT	0
388348	377975	19667J	PARTICIPANT	\N	PRESENT	0
388349	377975	14029X	PARTICIPANT	\N	PRESENT	0
388350	377975	17637T	PARTICIPANT	\N	PRESENT	0
388351	377975	04049K	PARTICIPANT	\N	PRESENT	0
388352	377975	19583F	PARTICIPANT	\N	PRESENT	0
388353	377975	19563B	PARTICIPANT	\N	PRESENT	0
388354	377975	14026U	PARTICIPANT	\N	PRESENT	0
388355	377975	08049C	PARTICIPANT	\N	PRESENT	0
388356	377975	08044W	PARTICIPANT	\N	PRESENT	0
388357	377975	04047H	PARTICIPANT	\N	PRESENT	0
388358	377975	11027H	PARTICIPANT	\N	PRESENT	0
388359	377975	04097T	PARTICIPANT	\N	PRESENT	0
388360	377975	19741B	PARTICIPANT	\N	PRESENT	0
388362	377975	14357A	PARTICIPANT	\N	PRESENT	0
388363	377975	14038Y	PARTICIPANT	\N	PRESENT	0
388364	377975	19747H	PARTICIPANT	\N	PRESENT	0
388365	377975	96004D	PARTICIPANT	\N	PRESENT	0
388366	377975	14187A	PARTICIPANT	\N	PRESENT	0
388367	377975	08047A	PARTICIPANT	\N	PRESENT	0
388368	377975	11049P	PARTICIPANT	\N	PRESENT	0
388369	377975	07029T	PARTICIPANT	\N	PRESENT	0
388370	377975	14041T	PARTICIPANT	\N	PRESENT	0
388371	377975	19447X	PARTICIPANT	\N	PRESENT	0
388372	377975	04086Q	PARTICIPANT	\N	PRESENT	0
388373	377975	19533U	PARTICIPANT	\N	PRESENT	0
388374	377975	08018U	PARTICIPANT	\N	PRESENT	0
388375	377975	14205J	PARTICIPANT	\N	PRESENT	0
388376	377975	19794Q	PARTICIPANT	\N	PRESENT	0
388377	377975	14135M	PARTICIPANT	\N	PRESENT	0
388378	377975	14173T	PARTICIPANT	\N	PRESENT	0
388379	377975	08062Y	PARTICIPANT	\N	PRESENT	0
388380	377975	19685L	PARTICIPANT	\N	PRESENT	0
388381	377975	14147R	PARTICIPANT	\N	PRESENT	0
388382	377975	17589D	PARTICIPANT	\N	PRESENT	0
388383	377975	14265W	PARTICIPANT	\N	PRESENT	0
388384	377975	02002K	PARTICIPANT	\N	PRESENT	0
388385	377975	14121F	PARTICIPANT	\N	PRESENT	0
388386	377975	04035D	PARTICIPANT	\N	PRESENT	0
388387	377975	14079W	PARTICIPANT	\N	PRESENT	0
388388	377975	19693L	PARTICIPANT	\N	PRESENT	0
388389	377975	19251M	PARTICIPANT	\N	PRESENT	0
388390	377975	11074Q	PARTICIPANT	\N	PRESENT	0
388391	377975	08017T	PARTICIPANT	\N	PRESENT	0
388392	377975	19705W	PARTICIPANT	\N	PRESENT	0
388393	377975	04033B	PARTICIPANT	\N	PRESENT	0
388394	377975	19507S	PARTICIPANT	\N	PRESENT	0
388395	377975	01025N	PARTICIPANT	\N	PRESENT	0
388396	377975	95030B	PARTICIPANT	\N	PRESENT	0
388397	377975	98050T	PARTICIPANT	\N	PRESENT	0
388398	377975	05012A	PARTICIPANT	\N	PRESENT	0
388400	377975	08034U	PARTICIPANT	\N	PRESENT	0
388401	377975	19729F	PARTICIPANT	\N	PRESENT	0
388402	377975	14069U	PARTICIPANT	\N	PRESENT	0
388403	377975	19733B	PARTICIPANT	\N	PRESENT	0
388404	377975	07033P	PARTICIPANT	\N	PRESENT	0
388405	377975	14217N	PARTICIPANT	\N	PRESENT	0
388406	377975	14115H	PARTICIPANT	\N	PRESENT	0
388407	377975	19399H	PARTICIPANT	\N	PRESENT	0
388408	377975	19675J	PARTICIPANT	\N	PRESENT	0
367120	367118	14030Q	PARTICIPANT	\N	EXCUSE	0
367121	367118	19701S	PARTICIPANT	\N	EXCUSE	0
367122	367118	80013X	PARTICIPANT	\N	EXCUSE	0
367123	367118	19693L	PARTICIPANT	\N	EXCUSE	0
367124	367118	19731Y	PARTICIPANT	\N	EXCUSE	0
367125	367118	08031R	PARTICIPANT	\N	EXCUSE	0
367126	367118	07029T	PARTICIPANT	\N	EXCUSE	0
367127	367118	19715Y	PARTICIPANT	\N	PRESENT	0
367128	367118	11031D	PARTICIPANT	\N	PRESENT	0
367129	367118	14073Q	PARTICIPANT	\N	PRESENT	0
367130	367118	19399H	PARTICIPANT	\N	PRESENT	0
367276	367274	11027H	PARTICIPANT	\N	PRESENT	0
367277	367274	19709B	PARTICIPANT	\N	PRESENT	0
367303	367302	95030B	PARTICIPANT	\N	PRESENT	0
367304	367302	12041X	PARTICIPANT	\N	PRESENT	0
367305	367302	19583F	PARTICIPANT	\N	PRESENT	0
367409	366416	08009T	PRESIDENT	0	PRESENT	0
367410	366416	19701S	PARTICIPANT	\N	EXCUSE	0
367411	366416	96004D	PARTICIPANT	\N	EXCUSE	0
367412	366416	19685L	PARTICIPANT	\N	EXCUSE	0
367413	366416	19681G	PARTICIPANT	\N	EXCUSE	0
368217	356293	01028R	PARTICIPANT	\N	PRESENT	0
368218	356293	11066Q	PARTICIPANT	\N	PRESENT	0
374957	363545	11070L	PARTICIPANT	\N	PRESENT	0
376952	373784	14103D	PARTICIPANT	\N	EXCUSE	0
385044	377917	08012N	PARTICIPANT	\N	PRESENT	0
376951	373784	08034U	PARTICIPANT	\N	EXCUSE	0
376953	373784	14063N	PARTICIPANT	\N	EXCUSE	0
377679	373784	08049C	PARTICIPANT	\N	EXCUSE	0
378649	373784	01057W	PARTICIPANT	\N	EXCUSE	0
385037	377917	11027H	PARTICIPANT	\N	PRESENT	0
385038	377917	19525U	PARTICIPANT	\N	PRESENT	0
385039	377917	04034C	PARTICIPANT	\N	PRESENT	0
385040	377917	11072N	PARTICIPANT	\N	PRESENT	0
385041	377917	19621T	PARTICIPANT	\N	PRESENT	0
385042	377917	14253S	PARTICIPANT	\N	PRESENT	0
385043	377917	80027E	PARTICIPANT	\N	PRESENT	0
385045	377917	11043H	PARTICIPANT	\N	PRESENT	0
385046	377917	04085P	PARTICIPANT	\N	PRESENT	0
385048	377917	14227Q	PARTICIPANT	\N	PRESENT	0
385049	377917	19415P	PARTICIPANT	\N	PRESENT	0
385050	377917	10006L	PARTICIPANT	\N	PRESENT	0
385051	377917	19251M	PARTICIPANT	\N	PRESENT	0
385052	377917	19760E	PARTICIPANT	\N	PRESENT	0
385054	377917	14195A	PARTICIPANT	\N	PRESENT	0
385055	377917	18083K	PARTICIPANT	\N	PRESENT	0
385056	377917	19479G	PARTICIPANT	\N	PRESENT	0
385057	377917	17779H	PARTICIPANT	\N	PRESENT	0
385058	377917	14107H	PARTICIPANT	\N	PRESENT	0
385059	377917	19689Q	PARTICIPANT	\N	PRESENT	0
385060	377917	19383Y	PARTICIPANT	\N	PRESENT	0
385061	377917	19507S	PARTICIPANT	\N	PRESENT	0
385062	377917	07029T	PARTICIPANT	\N	PRESENT	0
385063	377917	14281W	PARTICIPANT	\N	PRESENT	0
385064	377917	14265W	PARTICIPANT	\N	PRESENT	0
385065	377917	19521Q	PARTICIPANT	\N	PRESENT	0
385073	377917	19611R	PARTICIPANT	\N	PRESENT	0
385075	377917	14083S	PARTICIPANT	\N	PRESENT	0
385076	377917	14187A	PARTICIPANT	\N	PRESENT	0
385078	377917	14259Y	PARTICIPANT	\N	PRESENT	0
385079	377917	19387D	PARTICIPANT	\N	PRESENT	0
385080	377917	14053L	PARTICIPANT	\N	PRESENT	0
385083	377917	14205J	PARTICIPANT	\N	PRESENT	0
385084	377917	19723Y	PARTICIPANT	\N	PRESENT	0
385085	377917	04070G	PARTICIPANT	\N	PRESENT	0
385103	384598	01034P	PARTICIPANT	\N	PRESENT	0
385104	384598	04092N	PARTICIPANT	\N	PRESENT	0
385105	384598	11097X	PARTICIPANT	0	PRESENT	0
385106	384598	08052W	PARTICIPANT	\N	PRESENT	0
385091	377918	04059M	PARTICIPANT	\N	PRESENT	0
385094	384598	19727D	PARTICIPANT	\N	PRESENT	0
385095	384598	19798U	PARTICIPANT	\N	PRESENT	0
385096	384598	19679N	PARTICIPANT	\N	PRESENT	0
385097	384598	11103C	PARTICIPANT	\N	PRESENT	0
385098	384598	14042U	PARTICIPANT	\N	PRESENT	0
385099	384598	14195A	PARTICIPANT	\N	PRESENT	0
385100	384598	19683J	PARTICIPANT	\N	PRESENT	0
385101	384598	98024R	PRESIDENT	0	PRESENT	0
385102	384598	08041T	PARTICIPANT	\N	EXCUSE	0
385107	384598	14119M	PARTICIPANT	\N	PRESENT	0
385108	384598	14213J	PARTICIPANT	\N	PRESENT	0
385109	384598	19367Y	PARTICIPANT	\N	PRESENT	0
385110	384598	19521Q	PARTICIPANT	\N	PRESENT	0
385111	384598	14026U	PARTICIPANT	\N	PRESENT	0
385112	384598	14087W	PARTICIPANT	\N	PRESENT	0
385113	384598	19575F	PARTICIPANT	\N	PRESENT	0
385114	384598	14071N	PARTICIPANT	\N	PRESENT	0
385115	384598	14217N	PARTICIPANT	\N	PRESENT	0
385116	384598	11067R	PARTICIPANT	\N	PRESENT	0
385117	384598	19723Y	PARTICIPANT	\N	PRESENT	0
385118	384598	19703U	PARTICIPANT	\N	PRESENT	0
385119	384598	19565D	PARTICIPANT	\N	PRESENT	0
385120	384598	14223L	PARTICIPANT	\N	PRESENT	0
385121	384598	19657G	PARTICIPANT	\N	PRESENT	0
385122	384598	19760E	PARTICIPANT	\N	PRESENT	0
385123	384598	14239U	PARTICIPANT	\N	PRESENT	0
385124	384598	19553Y	PARTICIPANT	\N	PRESENT	0
385125	384598	19697Q	PARTICIPANT	\N	PRESENT	0
385126	384598	19715Y	PARTICIPANT	\N	PRESENT	0
385127	384598	19663E	PARTICIPANT	\N	PRESENT	0
385128	385053	19725B	PRESIDENT	0	PRESENT	0
385129	385053	11056N	PARTICIPANT	\N	PRESENT	0
385130	385053	04057K	PARTICIPANT	\N	PRESENT	0
385131	385053	19441R	PARTICIPANT	\N	PRESENT	0
385132	385053	14071N	PARTICIPANT	\N	PRESENT	0
385133	385053	19295A	PARTICIPANT	\N	PRESENT	0
385134	385053	08073C	PARTICIPANT	\N	EXCUSE	0
385135	385053	14107H	PARTICIPANT	\N	EXCUSE	0
385136	385053	14033T	PARTICIPANT	\N	EXCUSE	0
385137	377918	14219Q	PARTICIPANT	\N	PRESENT	0
385138	377918	19611R	PARTICIPANT	\N	PRESENT	0
385139	377918	04092N	PARTICIPANT	\N	PRESENT	0
385292	377918	11077T	PARTICIPANT	\N	PRESENT	0
385294	377918	19521Q	PARTICIPANT	\N	PRESENT	0
385295	377918	04040A	PARTICIPANT	\N	PRESENT	0
385296	377918	14201E	PARTICIPANT	\N	PRESENT	0
385297	377918	14259Y	PARTICIPANT	\N	PRESENT	0
385298	377918	08045X	PARTICIPANT	\N	PRESENT	0
385299	377918	19563B	PARTICIPANT	\N	PRESENT	0
385300	377918	04057K	PARTICIPANT	\N	PRESENT	0
385301	377918	19741B	PARTICIPANT	\N	PRESENT	0
385302	384104	19782L	PARTICIPANT	\N	PRESENT	0
385303	384104	14357A	PARTICIPANT	\N	PRESENT	0
385304	384104	19413M	PARTICIPANT	\N	PRESENT	0
385305	384104	14081Q	PARTICIPANT	\N	PRESENT	0
385306	384104	80013X	PARTICIPANT	\N	PRESENT	0
385307	384104	19631V	PARTICIPANT	\N	PRESENT	0
385308	384104	08068F	PARTICIPANT	\N	PRESENT	0
385309	384104	04049K	PARTICIPANT	\N	PRESENT	0
385310	384104	08015R	PARTICIPANT	\N	PRESENT	0
385311	384104	14197C	PARTICIPANT	\N	PRESENT	0
385312	384104	19369B	PARTICIPANT	\N	PRESENT	0
385313	384104	19511N	PARTICIPANT	\N	PRESENT	0
385314	384104	08028W	PARTICIPANT	\N	PRESENT	0
385315	384104	14265W	PARTICIPANT	\N	PRESENT	0
385316	384104	19591F	PARTICIPANT	\N	PRESENT	0
385317	384104	08062Y	PARTICIPANT	\N	PRESENT	0
385318	384104	19695N	PARTICIPANT	\N	PRESENT	0
385319	384104	11090Q	PRESIDENT	0	PRESENT	0
385320	384104	14033T	PARTICIPANT	\N	PRESENT	0
385321	384104	14205J	PARTICIPANT	\N	PRESENT	0
385322	384104	04088S	PARTICIPANT	\N	PRESENT	0
385323	384104	14115H	PARTICIPANT	\N	PRESENT	0
385324	384104	11101A	PARTICIPANT	\N	PRESENT	0
385325	384104	19747H	PARTICIPANT	\N	PRESENT	0
385326	384104	04043D	PARTICIPANT	\N	PRESENT	0
385327	384104	14135M	PARTICIPANT	\N	EXCUSE	0
385328	384104	19467C	PARTICIPANT	\N	EXCUSE	0
385329	384104	19515S	PARTICIPANT	\N	EXCUSE	0
385330	384104	08021P	PARTICIPANT	\N	EXCUSE	0
385331	384104	11081P	PARTICIPANT	\N	EXCUSE	0
385332	377918	87003B	PARTICIPANT	\N	PRESENT	0
385333	377918	14029X	PARTICIPANT	\N	PRESENT	0
385334	377918	14069U	PARTICIPANT	\N	PRESENT	0
385335	377918	14249W	PARTICIPANT	\N	PRESENT	0
385337	377918	19637C	PARTICIPANT	\N	PRESENT	0
385338	377918	11012A	PARTICIPANT	\N	PRESENT	0
385340	377918	19673G	PARTICIPANT	\N	PRESENT	0
385341	377918	19569H	PARTICIPANT	\N	PRESENT	0
386150	386130	01024M	PARTICIPANT	\N	PRESENT	0
386151	386130	14215L	PARTICIPANT	\N	PRESENT	0
386152	386130	19673G	PARTICIPANT	\N	PRESENT	0
386153	386130	08045X	PARTICIPANT	\N	PRESENT	0
386154	386130	19649G	PARTICIPANT	\N	PRESENT	0
386155	386130	19725B	PARTICIPANT	\N	PRESENT	0
386156	386130	14179A	PARTICIPANT	\N	PRESENT	0
386157	386130	08044W	PARTICIPANT	\N	PRESENT	0
386159	386130	19447X	PARTICIPANT	\N	PRESENT	0
386160	386130	14021P	PARTICIPANT	\N	PRESENT	0
368566	356296	14089Y	PARTICIPANT	\N	PRESENT	0
368609	368608	14123H	PARTICIPANT	\N	PRESENT	0
368614	368608	19611R	PARTICIPANT	\N	PRESENT	0
368615	368608	19593H	PARTICIPANT	\N	PRESENT	0
369161	369160	14147R	PARTICIPANT	\N	PRESENT	0
369170	369169	05008E	PRESIDENT	0	PRESENT	0
369171	369169	19543W	PARTICIPANT	\N	PRESENT	0
369172	369169	11033F	PARTICIPANT	\N	PRESENT	0
369173	369169	14065Q	PARTICIPANT	\N	PRESENT	0
369174	369169	14069U	PARTICIPANT	\N	PRESENT	0
369175	369169	14089Y	PARTICIPANT	\N	PRESENT	0
369176	369169	04047H	PARTICIPANT	\N	PRESENT	0
369177	369169	14053L	PARTICIPANT	\N	PRESENT	0
369178	369169	19629C	PARTICIPANT	\N	PRESENT	0
369179	369169	04038G	PARTICIPANT	\N	PRESENT	0
369180	369169	19253P	PARTICIPANT	\N	PRESENT	0
369181	369169	14259Y	PARTICIPANT	\N	PRESENT	0
369182	369169	14041T	PARTICIPANT	\N	PRESENT	0
369183	369169	01024M	PARTICIPANT	\N	PRESENT	0
369184	369169	14215L	PARTICIPANT	\N	PRESENT	0
368564	356296	04088S	PARTICIPANT	\N	PRESENT	0
368565	356296	14213J	PARTICIPANT	\N	PRESENT	0
369185	369169	14151M	PARTICIPANT	\N	PRESENT	0
369186	369169	19673G	PARTICIPANT	\N	PRESENT	0
369187	369169	08045X	PARTICIPANT	\N	PRESENT	0
369188	369169	08018U	PARTICIPANT	\N	EXCUSE	0
369189	369169	11010L	PARTICIPANT	\N	PRESENT	0
369190	369169	14231L	PARTICIPANT	\N	EXCUSE	0
369191	369169	19725B	PARTICIPANT	\N	PRESENT	0
369192	369169	14179A	PARTICIPANT	\N	PRESENT	0
369193	369169	08044W	PARTICIPANT	\N	PRESENT	0
369194	369169	19447X	PARTICIPANT	\N	PRESENT	0
369195	369169	14021P	PARTICIPANT	\N	PRESENT	0
369196	369169	19489J	PARTICIPANT	\N	PRESENT	0
369197	369169	11026G	PARTICIPANT	\N	PRESENT	0
369198	369169	19729F	PARTICIPANT	\N	EXCUSE	0
369199	369169	19581D	PARTICIPANT	\N	PRESENT	0
369200	369169	14111D	PARTICIPANT	\N	PRESENT	0
369201	369169	14001X	PARTICIPANT	\N	PRESENT	0
369202	369169	11085T	PARTICIPANT	\N	PRESENT	0
369203	369169	01060R	PARTICIPANT	\N	PRESENT	0
369204	369169	14147R	PARTICIPANT	\N	PRESENT	0
369205	369169	11072N	PARTICIPANT	\N	PRESENT	0
369206	369169	10015M	PARTICIPANT	\N	PRESENT	0
369207	369169	95063L	PARTICIPANT	\N	PRESENT	0
369208	369169	19762G	PARTICIPANT	\N	PRESENT	0
369209	369169	01028R	PARTICIPANT	\N	PRESENT	0
369210	369169	98035U	PARTICIPANT	\N	PRESENT	0
369211	369169	14275Y	PARTICIPANT	\N	PRESENT	0
369212	369169	19675J	PARTICIPANT	\N	EXCUSE	0
369213	369169	04044E	PARTICIPANT	\N	PRESENT	0
369215	369214	05008E	PRESIDENT	0	PRESENT	0
369216	369214	19543W	PARTICIPANT	\N	PRESENT	0
369217	369214	11033F	PARTICIPANT	\N	PRESENT	0
369218	369214	14065Q	PARTICIPANT	\N	PRESENT	0
369219	369214	14069U	PARTICIPANT	\N	PRESENT	0
369220	369214	14089Y	PARTICIPANT	\N	PRESENT	0
369221	369214	04047H	PARTICIPANT	\N	PRESENT	0
369222	369214	14053L	PARTICIPANT	\N	PRESENT	0
369223	369214	19629C	PARTICIPANT	\N	PRESENT	0
369224	369214	04038G	PARTICIPANT	\N	PRESENT	0
369225	369214	19253P	PARTICIPANT	\N	PRESENT	0
369226	369214	14259Y	PARTICIPANT	\N	PRESENT	0
369227	369214	14041T	PARTICIPANT	\N	PRESENT	0
369229	369214	01024M	PARTICIPANT	\N	PRESENT	0
369244	369214	14215L	PARTICIPANT	\N	PRESENT	0
369245	369214	14151M	PARTICIPANT	\N	PRESENT	0
369246	369214	19673G	PARTICIPANT	\N	PRESENT	0
369247	369214	08045X	PARTICIPANT	\N	PRESENT	0
369248	369214	08018U	PARTICIPANT	\N	EXCUSE	0
369249	369214	11010L	PARTICIPANT	\N	PRESENT	0
369250	369214	14231L	PARTICIPANT	\N	EXCUSE	0
369254	369214	19725B	PARTICIPANT	\N	PRESENT	0
369255	369214	14179A	PARTICIPANT	\N	PRESENT	0
369256	369214	08044W	PARTICIPANT	\N	PRESENT	0
369258	369214	19447X	PARTICIPANT	\N	PRESENT	0
369261	369214	14021P	PARTICIPANT	\N	PRESENT	0
369262	369214	19489J	PARTICIPANT	\N	PRESENT	0
369263	369214	11026G	PARTICIPANT	\N	PRESENT	0
369264	369214	19729F	PARTICIPANT	\N	EXCUSE	0
369265	369214	19581D	PARTICIPANT	\N	PRESENT	0
369266	369214	14111D	PARTICIPANT	\N	PRESENT	0
369267	369214	14001X	PARTICIPANT	\N	PRESENT	0
369268	369214	11085T	PARTICIPANT	\N	PRESENT	0
369269	369214	01060R	PARTICIPANT	\N	PRESENT	0
369270	369214	14147R	PARTICIPANT	\N	PRESENT	0
369271	369214	11072N	PARTICIPANT	\N	PRESENT	0
369272	369214	10015M	PARTICIPANT	\N	PRESENT	0
369274	369214	95063L	PARTICIPANT	\N	PRESENT	0
369275	369214	19762G	PARTICIPANT	\N	PRESENT	0
369277	369214	01028R	PARTICIPANT	\N	PRESENT	0
369278	369214	98035U	PARTICIPANT	\N	PRESENT	0
369279	369214	14275Y	PARTICIPANT	\N	PRESENT	0
369280	369214	19675J	PARTICIPANT	\N	EXCUSE	0
369281	369214	04044E	PARTICIPANT	\N	PRESENT	0
369431	369421	04070G	PARTICIPANT	\N	PRESENT	0
369433	369421	08031R	PARTICIPANT	\N	PRESENT	0
369434	369421	08039A	PARTICIPANT	\N	PRESENT	0
369436	369421	14229S	PARTICIPANT	\N	PRESENT	0
369438	369421	08043V	PARTICIPANT	\N	PRESENT	0
369440	369421	19693L	PARTICIPANT	\N	PRESENT	0
369442	369421	19329S	PARTICIPANT	\N	PRESENT	0
369443	369421	14241N	PARTICIPANT	\N	PRESENT	0
369445	369421	19611R	PARTICIPANT	\N	PRESENT	0
369447	369421	14063N	PARTICIPANT	\N	PRESENT	0
369448	369421	19573D	PARTICIPANT	\N	PRESENT	0
369451	369421	19533U	PARTICIPANT	\N	PRESENT	0
369452	369421	19735D	PARTICIPANT	\N	PRESENT	0
369454	369421	04018C	PARTICIPANT	\N	PRESENT	0
369499	369160	14151M	PARTICIPANT	\N	PRESENT	0
369501	369500	14147R	PARTICIPANT	\N	PRESENT	0
369844	356668	19717B	PARTICIPANT	\N	PRESENT	0
369503	369500	14151M	PARTICIPANT	\N	PRESENT	0
369843	356668	14261S	PARTICIPANT	\N	PRESENT	0
369845	356668	19659J	PARTICIPANT	\N	PRESENT	0
369846	356668	19577H	PARTICIPANT	\N	PRESENT	0
369847	356668	11010L	PARTICIPANT	\N	EXCUSE	0
369848	356668	19715Y	PARTICIPANT	\N	EXCUSE	0
369849	356668	19329S	PARTICIPANT	\N	PRESENT	0
369850	356668	98005N	PARTICIPANT	\N	PRESENT	0
369851	356668	14059S	PARTICIPANT	\N	PRESENT	0
369852	356668	08019V	PRESIDENT	0	PRESENT	0
369853	356668	19657G	PARTICIPANT	\N	PRESENT	0
369854	356668	14331P	PARTICIPANT	\N	PRESENT	0
369855	356668	14157T	PARTICIPANT	\N	PRESENT	0
369856	356668	95062K	PARTICIPANT	\N	EXCUSE	0
369857	356668	14275Y	PARTICIPANT	\N	EXCUSE	0
370742	370741	19575F	PARTICIPANT	\N	PRESENT	0
370743	370741	14083S	PARTICIPANT	\N	PRESENT	0
370744	370741	19681G	PARTICIPANT	\N	PRESENT	0
370745	370741	80013X	PARTICIPANT	\N	PRESENT	0
370746	370741	14357A	PARTICIPANT	\N	PRESENT	0
370747	370741	01024M	PARTICIPANT	\N	PRESENT	0
370748	370741	04089T	PARTICIPANT	\N	PRESENT	0
370749	370741	14033T	PARTICIPANT	\N	PRESENT	0
370750	370741	19533U	PARTICIPANT	\N	PRESENT	0
370751	370741	04088S	PARTICIPANT	\N	PRESENT	0
370752	370741	19503N	PARTICIPANT	\N	PRESENT	0
370753	370741	01058X	PARTICIPANT	\N	PRESENT	0
370754	370741	14051J	PARTICIPANT	\N	PRESENT	0
371101	371097	08019V	PARTICIPANT	\N	PRESENT	0
371103	371097	12016W	PARTICIPANT	\N	PRESENT	0
371104	371097	19715Y	PARTICIPANT	\N	PRESENT	0
371105	371097	19691J	PARTICIPANT	\N	PRESENT	0
371107	371097	11109J	PARTICIPANT	\N	PRESENT	0
371163	365231	19629C	PARTICIPANT	\N	PRESENT	0
371164	365231	19467C	PARTICIPANT	\N	PRESENT	0
371165	365231	14147R	PARTICIPANT	\N	PRESENT	0
371166	365231	11097X	PARTICIPANT	\N	PRESENT	0
371167	365231	11066Q	PARTICIPANT	\N	PRESENT	0
371168	365231	19737F	PARTICIPANT	\N	EXCUSE	0
371169	365231	19711U	PARTICIPANT	\N	EXCUSE	0
371170	365231	19651A	PARTICIPANT	\N	EXCUSE	0
371176	370719	11065P	PARTICIPANT	\N	PRESENT	0
371177	370719	14107H	PARTICIPANT	\N	PRESENT	0
371182	370562	11065P	PARTICIPANT	\N	PRESENT	0
371183	370562	14107H	PARTICIPANT	\N	PRESENT	0
371186	371185	14105F	PARTICIPANT	\N	PRESENT	0
371188	371187	14157T	PRESIDENT	0	PRESENT	0
371189	371187	08060W	PARTICIPANT	\N	PRESENT	0
371190	371187	19733B	PARTICIPANT	\N	PRESENT	0
371191	371187	14033T	PARTICIPANT	\N	PRESENT	0
371192	371187	19745F	PARTICIPANT	\N	PRESENT	0
371193	371187	19629C	PARTICIPANT	\N	PRESENT	0
371194	371187	14031R	PARTICIPANT	\N	PRESENT	0
371195	371187	95067Q	PARTICIPANT	\N	PRESENT	0
371196	371187	19762G	PARTICIPANT	0	PRESENT	0
371197	371187	19747H	PARTICIPANT	\N	PRESENT	0
371198	371187	19347U	PARTICIPANT	\N	PRESENT	0
369121	367087	19511N	PARTICIPANT	\N	EXCUSE	0
373902	373688	19479G	PARTICIPANT	\N	PRESENT	0
373903	373688	95041E	PARTICIPANT	\N	PRESENT	0
373904	373688	19711U	PARTICIPANT	\N	PRESENT	0
373905	373688	19531S	PARTICIPANT	\N	PRESENT	0
373906	373688	01057W	PARTICIPANT	\N	PRESENT	0
373907	373688	11053K	PARTICIPANT	\N	PRESENT	0
373908	373688	11074Q	PRESIDENT	0	PRESENT	0
373909	373688	14225N	PARTICIPANT	\N	PRESENT	0
373910	373688	88008L	PARTICIPANT	\N	PRESENT	0
373911	373688	19671E	PARTICIPANT	\N	PRESENT	0
373912	373688	14173T	PARTICIPANT	\N	PRESENT	0
373913	373688	11040E	PARTICIPANT	\N	PRESENT	0
373914	373688	04086Q	PARTICIPANT	\N	PRESENT	0
373915	373688	14083S	PARTICIPANT	\N	PRESENT	0
373916	373688	14085U	PARTICIPANT	\N	PRESENT	0
373917	373688	19349W	PARTICIPANT	\N	PRESENT	0
373918	373688	19741B	PARTICIPANT	\N	PRESENT	0
373919	373688	08010L	PARTICIPANT	\N	PRESENT	0
373920	373688	99004R	PARTICIPANT	\N	PRESENT	0
373921	373688	14253S	PARTICIPANT	\N	PRESENT	0
374164	363531	08062Y	PARTICIPANT	\N	PRESENT	0
374165	363531	19383Y	PARTICIPANT	\N	PRESENT	0
374166	363531	98050T	PARTICIPANT	\N	PRESENT	0
374167	363531	19798U	PARTICIPANT	\N	PRESENT	0
374168	373900	19766L	PARTICIPANT	\N	PRESENT	0
374169	373900	19533U	PARTICIPANT	\N	PRESENT	0
374170	373900	19329S	PARTICIPANT	\N	PRESENT	0
374171	373900	14107H	PARTICIPANT	\N	PRESENT	0
374172	373900	92040Q	PARTICIPANT	\N	PRESENT	0
374173	373900	19335Q	PARTICIPANT	\N	PRESENT	0
374174	373900	08039A	PARTICIPANT	\N	PRESENT	0
374175	373900	14059S	PARTICIPANT	\N	PRESENT	0
374176	373900	19643A	PARTICIPANT	\N	PRESENT	0
374177	373900	11043H	PARTICIPANT	\N	PRESENT	0
374178	373900	14061L	PARTICIPANT	\N	EXCUSE	0
374179	373900	04057K	PARTICIPANT	\N	EXCUSE	0
374180	373900	14201E	PARTICIPANT	\N	EXCUSE	0
374242	363532	14237S	PARTICIPANT	\N	PRESENT	0
374243	363532	18083K	PARTICIPANT	\N	PRESENT	0
374244	363532	11103C	PARTICIPANT	\N	PRESENT	0
374245	363532	17583W	PARTICIPANT	\N	PRESENT	0
374246	363532	19507S	PARTICIPANT	\N	PRESENT	0
374247	363532	14029X	PARTICIPANT	\N	PRESENT	0
374248	363532	14253S	PARTICIPANT	\N	PRESENT	0
374249	363532	08062Y	PARTICIPANT	\N	PRESENT	0
374250	363532	15447F	PARTICIPANT	\N	PRESENT	0
374251	363532	87003B	PARTICIPANT	\N	PRESENT	0
374252	363532	19383Y	PARTICIPANT	\N	PRESENT	0
374253	363532	11080N	PARTICIPANT	\N	PRESENT	0
374254	363532	14115H	PARTICIPANT	\N	PRESENT	0
374255	363532	19673G	PARTICIPANT	\N	PRESENT	0
374256	363532	04097T	PARTICIPANT	\N	PRESENT	0
378211	378191	14026U	PARTICIPANT	\N	PRESENT	0
378213	378191	19717B	PARTICIPANT	\N	PRESENT	0
380296	378919	14103D	PARTICIPANT	\N	PRESENT	0
380299	380225	08017T	PARTICIPANT	\N	PRESENT	0
380300	380225	14030Q	PARTICIPANT	\N	PRESENT	0
380305	378921	14327T	PARTICIPANT	\N	PRESENT	0
380306	378921	14331P	PARTICIPANT	\N	PRESENT	0
380307	378921	11048N	PARTICIPANT	\N	PRESENT	0
380308	378921	19711U	PARTICIPANT	\N	PRESENT	0
380309	378921	95041E	PARTICIPANT	\N	PRESENT	0
380310	378921	19651A	PARTICIPANT	\N	PRESENT	0
380311	378921	19687N	PARTICIPANT	\N	PRESENT	0
380312	378921	01057W	PARTICIPANT	\N	PRESENT	0
380313	378921	89017R	PARTICIPANT	\N	PRESENT	0
380314	378921	08011M	PARTICIPANT	\N	PRESENT	0
380315	378921	19667J	PARTICIPANT	\N	PRESENT	0
380316	378921	11074Q	PRESIDENT	0	PRESENT	0
380317	378921	19671E	PARTICIPANT	\N	PRESENT	0
380318	378921	14159V	PARTICIPANT	\N	PRESENT	0
380319	378921	11040E	PARTICIPANT	\N	PRESENT	0
380320	378921	04086Q	PARTICIPANT	\N	PRESENT	0
380321	378921	14085U	PARTICIPANT	\N	PRESENT	0
380322	378921	19741B	PARTICIPANT	\N	PRESENT	0
380323	378921	99004R	PARTICIPANT	\N	PRESENT	0
381283	371528	14111D	PARTICIPANT	\N	PRESENT	0
381284	371528	19585H	PARTICIPANT	\N	PRESENT	0
381285	371528	19525U	PARTICIPANT	\N	PRESENT	0
381286	371528	19413M	PARTICIPANT	\N	PRESENT	0
381287	371528	19511N	PARTICIPANT	\N	PRESENT	0
381288	371528	19479G	PARTICIPANT	\N	PRESENT	0
381289	371528	19591F	PARTICIPANT	\N	PRESENT	0
381290	371528	08068F	PARTICIPANT	\N	PRESENT	0
381597	371530	04044E	PARTICIPANT	\N	PRESENT	0
381598	371530	04034C	PARTICIPANT	\N	PRESENT	0
381600	371530	08011M	PARTICIPANT	\N	PRESENT	0
381601	371530	11074Q	PARTICIPANT	\N	PRESENT	0
381602	371530	11026G	PARTICIPANT	\N	PRESENT	0
381603	371530	14197C	PARTICIPANT	\N	PRESENT	0
381604	371530	80013X	PARTICIPANT	\N	PRESENT	0
381605	371530	14257W	PARTICIPANT	\N	PRESENT	0
381606	371530	19647E	PARTICIPANT	\N	PRESENT	0
381607	371530	14121F	PARTICIPANT	\N	PRESENT	0
381608	371530	14085U	PARTICIPANT	\N	PRESENT	0
381609	371530	19687N	PARTICIPANT	\N	PRESENT	0
374240	363532	19794Q	PARTICIPANT	\N	PRESENT	0
374241	363532	95041E	PARTICIPANT	\N	PRESENT	0
381610	371530	19651A	PARTICIPANT	\N	PRESENT	0
381611	371530	19349W	PARTICIPANT	\N	PRESENT	0
381612	371530	19545Y	PARTICIPANT	\N	PRESENT	0
381613	371530	04057K	PARTICIPANT	\N	PRESENT	0
381614	371530	14083S	PARTICIPANT	\N	PRESENT	0
381615	371530	19747H	PARTICIPANT	\N	PRESENT	0
381616	371530	14261S	PARTICIPANT	\N	PRESENT	0
381617	371530	88008L	PARTICIPANT	\N	PRESENT	0
381618	371530	14327T	PARTICIPANT	\N	PRESENT	0
381619	371530	08044W	PARTICIPANT	\N	PRESENT	0
381620	371530	19631V	PARTICIPANT	\N	PRESENT	0
381621	371530	14265W	PARTICIPANT	\N	PRESENT	0
381622	371530	11049P	PARTICIPANT	\N	PRESENT	0
381623	371530	14115H	PARTICIPANT	\N	PRESENT	0
381624	371530	14041T	PARTICIPANT	\N	PRESENT	0
381625	371530	04088S	PARTICIPANT	\N	PRESENT	0
381626	371530	19507S	PARTICIPANT	\N	PRESENT	0
381627	371530	14033T	PARTICIPANT	\N	PRESENT	0
381628	371530	19667J	PARTICIPANT	\N	PRESENT	0
381629	371530	01057W	PARTICIPANT	\N	PRESENT	0
381630	371530	19673G	PARTICIPANT	\N	PRESENT	0
381631	371530	19515S	PARTICIPANT	\N	PRESENT	0
381632	371530	14191V	PARTICIPANT	\N	PRESENT	0
381633	371530	04071H	PARTICIPANT	\N	PRESENT	0
381634	371530	08020N	PARTICIPANT	\N	PRESENT	0
381635	371530	04097T	PARTICIPANT	\N	PRESENT	0
381636	371530	01048V	PARTICIPANT	\N	PRESENT	0
381637	371530	14223L	PARTICIPANT	\N	PRESENT	0
381638	371530	19711U	PARTICIPANT	\N	PRESENT	0
381639	371530	97011G	PARTICIPANT	\N	PRESENT	0
381640	371530	99004R	PARTICIPANT	\N	PRESENT	0
381641	371530	01058X	PARTICIPANT	\N	PRESENT	0
381696	371530	08017T	PARTICIPANT	\N	PRESENT	0
381697	381599	14219Q	PARTICIPANT	\N	PRESENT	0
381698	381599	19739H	PARTICIPANT	\N	PRESENT	0
381699	371530	19681G	PARTICIPANT	\N	PRESENT	0
381700	381599	17637T	PARTICIPANT	\N	PRESENT	0
381701	371530	08028W	PARTICIPANT	\N	PRESENT	0
381702	371530	19729F	PARTICIPANT	\N	PRESENT	0
381703	378924	04040A	PARTICIPANT	\N	PRESENT	0
381704	371530	12016W	PARTICIPANT	\N	PRESENT	0
381705	371530	19715Y	PARTICIPANT	\N	PRESENT	0
381706	371530	14357A	PARTICIPANT	\N	PRESENT	0
381709	371530	08069G	PARTICIPANT	\N	PRESENT	0
381711	371530	19703U	PARTICIPANT	\N	PRESENT	0
381712	371530	08039A	PARTICIPANT	\N	PRESENT	0
381713	381599	14169X	PARTICIPANT	\N	PRESENT	0
381714	371530	11077T	PARTICIPANT	\N	PRESENT	0
381715	371530	14034U	PARTICIPANT	\N	PRESENT	0
381716	381599	05012A	PARTICIPANT	\N	PRESENT	0
381717	381599	04097T	PARTICIPANT	\N	PRESENT	0
381718	381599	14103D	PARTICIPANT	\N	PRESENT	0
381719	378924	97011G	PARTICIPANT	\N	PRESENT	0
381720	371530	14225N	PARTICIPANT	\N	PRESENT	0
381721	371530	19369B	PARTICIPANT	\N	PRESENT	0
381722	371530	19717B	PARTICIPANT	\N	PRESENT	0
381723	371530	19563B	PARTICIPANT	\N	PRESENT	0
381724	371530	19758L	PARTICIPANT	\N	PRESENT	0
381725	371530	19593H	PARTICIPANT	\N	PRESENT	0
381726	371530	14038Y	PARTICIPANT	\N	PRESENT	0
381727	371530	01043Q	PARTICIPANT	\N	PRESENT	0
381728	371530	14255U	PARTICIPANT	\N	PRESENT	0
381729	371530	19701S	PARTICIPANT	\N	PRESENT	0
381730	371530	19447X	PARTICIPANT	\N	PRESENT	0
381731	371530	14199E	PARTICIPANT	\N	PRESENT	0
381732	371530	11067R	PARTICIPANT	\N	PRESENT	0
381738	371530	19467C	PARTICIPANT	\N	PRESENT	0
381739	371530	19741B	PARTICIPANT	\N	PRESENT	0
381740	378924	98022P	PARTICIPANT	\N	EXCUSE	0
381741	378924	14193X	PARTICIPANT	\N	EXCUSE	0
372291	365231	04061F	PARTICIPANT	\N	EXCUSE	0
386794	386793	14121F	PARTICIPANT	\N	PRESENT	0
386835	386833	14327T	PARTICIPANT	\N	PRESENT	0
386836	386833	11110B	PARTICIPANT	\N	PRESENT	0
386839	386833	05012A	PARTICIPANT	\N	PRESENT	0
386924	386923	08034U	PARTICIPANT	\N	PRESENT	0
386926	386925	07029T	PARTICIPANT	\N	PRESENT	0
386952	386949	11053K	PARTICIPANT	\N	PRESENT	0
387462	387434	14215L	PARTICIPANT	\N	PRESENT	0
387463	387434	14179A	PARTICIPANT	\N	PRESENT	0
387532	386949	14257W	PARTICIPANT	\N	PRESENT	0
387705	385077	96004D	PRESIDENT	0	PRESENT	0
387706	385077	14065Q	PARTICIPANT	\N	PRESENT	0
387707	385077	14079W	PARTICIPANT	\N	PRESENT	0
387708	385077	11083R	PARTICIPANT	\N	PRESENT	0
387709	385077	14097Y	PARTICIPANT	\N	PRESENT	0
387710	385077	14089Y	PARTICIPANT	\N	PRESENT	0
387711	385077	08014Q	PARTICIPANT	\N	PRESENT	0
387712	385077	19725B	PARTICIPANT	\N	PRESENT	0
387713	385077	95037J	PARTICIPANT	\N	PRESENT	0
387715	385077	14073Q	PARTICIPANT	\N	PRESENT	0
387716	385077	14241N	PARTICIPANT	\N	PRESENT	0
387717	385077	11026G	PARTICIPANT	\N	PRESENT	0
387718	385077	19563B	PARTICIPANT	\N	PRESENT	0
387721	385077	14135M	PARTICIPANT	\N	PRESENT	0
387723	385077	14237S	PARTICIPANT	\N	PRESENT	0
387724	385077	10015M	PARTICIPANT	\N	PRESENT	0
387727	385077	14331P	PARTICIPANT	\N	EXCUSE	0
387729	385077	08018U	PARTICIPANT	\N	EXCUSE	0
387730	385077	98035U	PARTICIPANT	\N	EXCUSE	0
388995	388515	19525U	PARTICIPANT	\N	PRESENT	0
388996	388515	08052W	PARTICIPANT	\N	PRESENT	0
388997	388515	08018U	PARTICIPANT	\N	PRESENT	0
388998	388515	14069U	PARTICIPANT	\N	PRESENT	0
388999	388515	14051J	PARTICIPANT	\N	PRESENT	0
389000	388515	19782L	PARTICIPANT	\N	PRESENT	0
389001	388515	14231L	PARTICIPANT	\N	PRESENT	0
389002	388515	19569H	PARTICIPANT	\N	PRESENT	0
389003	388515	08034U	PARTICIPANT	\N	PRESENT	0
389004	388515	14111D	PARTICIPANT	\N	PRESENT	0
389005	388515	01048V	PARTICIPANT	\N	PRESENT	0
389006	388515	14211G	PARTICIPANT	\N	PRESENT	0
389007	388515	01034P	PARTICIPANT	\N	PRESENT	0
389008	388515	14219Q	PARTICIPANT	\N	PRESENT	0
389044	388515	04042C	PARTICIPANT	\N	PRESENT	0
389010	388515	19733B	PARTICIPANT	\N	PRESENT	0
389011	388515	14355X	PARTICIPANT	\N	PRESENT	0
389012	388515	19367Y	PARTICIPANT	\N	PRESENT	0
389013	388515	08049C	PARTICIPANT	\N	PRESENT	0
389014	388515	14227Q	PARTICIPANT	\N	PRESENT	0
389015	388515	11080N	PARTICIPANT	\N	PRESENT	0
389016	388515	11101A	PARTICIPANT	\N	PRESENT	0
389017	388515	04038G	PARTICIPANT	\N	PRESENT	0
389018	388515	19347U	PARTICIPANT	\N	PRESENT	0
389019	388515	08048B	PARTICIPANT	\N	PRESENT	0
389020	388515	19687N	PARTICIPANT	\N	PRESENT	0
389021	388515	19531S	PARTICIPANT	\N	PRESENT	0
389022	388515	14225N	PARTICIPANT	\N	PRESENT	0
389023	388515	19573D	PARTICIPANT	\N	PRESENT	0
389024	388515	19675J	PARTICIPANT	\N	PRESENT	0
389025	388515	19647E	PARTICIPANT	\N	PRESENT	0
389026	388515	14053L	PARTICIPANT	\N	PRESENT	0
389027	388515	19413M	PARTICIPANT	\N	PRESENT	0
389028	388515	04059M	PARTICIPANT	\N	PRESENT	0
389029	388515	14159V	PARTICIPANT	\N	PRESENT	0
389030	388515	19731Y	PARTICIPANT	\N	PRESENT	0
389031	388515	19621T	PARTICIPANT	\N	PRESENT	0
389032	388515	11065P	PARTICIPANT	\N	PRESENT	0
389033	388515	19583F	PARTICIPANT	\N	PRESENT	0
389035	388515	19369B	PARTICIPANT	\N	PRESENT	0
389036	388515	19335Q	PARTICIPANT	\N	PRESENT	0
389037	388515	08056B	PARTICIPANT	\N	PRESENT	0
389038	388515	19741B	PARTICIPANT	\N	PRESENT	0
389039	388515	19705W	PARTICIPANT	\N	PRESENT	0
389040	388515	16685X	PARTICIPANT	\N	PRESENT	0
389041	388515	08062Y	PARTICIPANT	\N	PRESENT	0
389042	388515	10015M	PARTICIPANT	\N	PRESENT	0
389043	388515	08028W	PARTICIPANT	\N	PRESENT	0
389045	388515	14030Q	PARTICIPANT	\N	PRESENT	0
389046	388515	14193X	PARTICIPANT	\N	PRESENT	0
389047	388515	14038Y	PARTICIPANT	\N	PRESENT	0
389048	388515	17583W	PARTICIPANT	\N	PRESENT	0
389049	388515	01043Q	PARTICIPANT	\N	PRESENT	0
389050	388515	19651A	PARTICIPANT	\N	PRESENT	0
389051	388515	14034U	PARTICIPANT	\N	PRESENT	0
389052	388515	14031R	PARTICIPANT	\N	PRESENT	0
389053	388515	98022P	PARTICIPANT	\N	PRESENT	0
389054	388515	11090Q	PARTICIPANT	\N	PRESENT	0
389055	388515	19563B	PARTICIPANT	\N	PRESENT	0
389056	388515	14357A	PARTICIPANT	\N	PRESENT	0
389057	388515	14071N	PARTICIPANT	\N	PRESENT	0
389058	388515	19701S	PARTICIPANT	\N	PRESENT	0
389059	388515	14135M	PARTICIPANT	\N	PRESENT	0
389060	388515	14093U	PARTICIPANT	\N	PRESENT	0
389061	388515	11064N	PARTICIPANT	\N	PRESENT	0
389062	388515	14089Y	PARTICIPANT	\N	PRESENT	0
389063	388515	14073Q	PARTICIPANT	\N	PRESENT	0
389064	388515	04097T	PARTICIPANT	\N	PRESENT	0
389065	388515	14079W	PARTICIPANT	\N	PRESENT	0
389066	388515	05012A	PARTICIPANT	\N	PRESENT	0
389070	388515	08031R	PARTICIPANT	\N	PRESENT	0
389068	388515	19709B	PARTICIPANT	\N	PRESENT	0
389069	388515	17589D	PARTICIPANT	\N	PRESENT	0
389071	388515	11049P	PARTICIPANT	\N	PRESENT	0
389072	388515	19581D	PARTICIPANT	\N	PRESENT	0
389073	388515	04086Q	PARTICIPANT	\N	PRESENT	0
389074	388515	14251Q	PARTICIPANT	\N	PRESENT	0
389075	388515	14033T	PARTICIPANT	\N	PRESENT	0
389076	388515	04071H	PARTICIPANT	\N	PRESENT	0
389077	388515	19719D	PARTICIPANT	\N	PRESENT	0
389078	388515	14107H	PARTICIPANT	\N	PRESENT	0
389079	388515	19747H	PARTICIPANT	\N	PRESENT	0
389080	388515	19599P	PARTICIPANT	\N	PRESENT	0
389081	388515	14327T	PARTICIPANT	\N	PRESENT	0
389082	388515	14237S	PARTICIPANT	\N	PRESENT	0
389083	385092	14327T	PARTICIPANT	\N	PRESENT	0
389084	385092	14107H	PARTICIPANT	\N	PRESENT	0
389085	385092	19441R	PARTICIPANT	\N	PRESENT	0
389086	385092	04097T	PARTICIPANT	\N	PRESENT	0
389087	385092	19581D	PARTICIPANT	\N	PRESENT	0
389088	385092	19747H	PARTICIPANT	\N	PRESENT	0
389089	385092	14030Q	PARTICIPANT	\N	PRESENT	0
389090	385092	08073C	PARTICIPANT	\N	EXCUSE	0
389091	385092	08015R	PARTICIPANT	\N	EXCUSE	0
389092	385092	08014Q	PARTICIPANT	\N	EXCUSE	0
389093	388515	08045X	PARTICIPANT	\N	PRESENT	0
389094	388515	11053K	PARTICIPANT	\N	PRESENT	0
389095	388515	19725B	PARTICIPANT	\N	PRESENT	0
389096	388515	04057K	PARTICIPANT	\N	PRESENT	0
389097	388515	19441R	PARTICIPANT	\N	PRESENT	0
389098	388515	04033B	PARTICIPANT	\N	PRESENT	0
389099	388515	01062T	PARTICIPANT	\N	PRESENT	0
389100	388515	14061L	PARTICIPANT	\N	PRESENT	0
389361	377976	11072N	PARTICIPANT	\N	PRESENT	0
389362	377976	05008E	PARTICIPANT	\N	PRESENT	0
389363	377976	19675J	PARTICIPANT	\N	PRESENT	0
389364	377976	14083S	PARTICIPANT	\N	PRESENT	0
389365	377976	14107H	PARTICIPANT	\N	PRESENT	0
389366	377976	19387D	PARTICIPANT	\N	PRESENT	0
389367	377976	14241N	PARTICIPANT	\N	PRESENT	0
389368	377976	11056N	PARTICIPANT	\N	PRESENT	0
389369	377976	14041T	PARTICIPANT	\N	PRESENT	0
389370	377976	14033T	PARTICIPANT	\N	PRESENT	0
389371	377976	04088S	PARTICIPANT	\N	PRESENT	0
389372	377976	19507S	PARTICIPANT	\N	PRESENT	0
389377	377976	19768N	PARTICIPANT	\N	PRESENT	0
389374	377976	19479G	PARTICIPANT	\N	PRESENT	0
389375	377976	19737F	PARTICIPANT	\N	PRESENT	0
389376	377976	19673G	PARTICIPANT	\N	PRESENT	0
389378	377976	11031D	PARTICIPANT	\N	PRESENT	0
389379	377976	19251M	PARTICIPANT	\N	PRESENT	0
389380	377976	11067R	PARTICIPANT	\N	PRESENT	0
389381	377976	14097Y	PARTICIPANT	\N	PRESENT	0
389382	377976	19631V	PARTICIPANT	\N	PRESENT	0
389383	377976	11109J	PARTICIPANT	\N	PRESENT	0
389384	377976	14329V	PARTICIPANT	\N	PRESENT	0
389385	377976	14059S	PARTICIPANT	\N	PRESENT	0
389386	377976	14029X	PARTICIPANT	\N	PRESENT	0
389387	387772	14151M	PARTICIPANT	\N	PRESENT	0
389388	387772	04044E	PARTICIPANT	\N	PRESENT	0
389389	387772	14231L	PARTICIPANT	\N	PRESENT	0
389390	377976	19349W	PARTICIPANT	\N	PRESENT	0
389391	377976	19782L	PARTICIPANT	\N	PRESENT	0
389392	377976	19599P	PARTICIPANT	\N	PRESENT	0
389393	377976	80013X	PARTICIPANT	\N	PRESENT	0
389394	377976	14195A	PARTICIPANT	\N	PRESENT	0
389395	377976	19691J	PARTICIPANT	\N	PRESENT	0
389396	377976	97011G	PARTICIPANT	\N	PRESENT	0
389397	377976	19703U	PARTICIPANT	\N	PRESENT	0
370722	367799	14257W	PARTICIPANT	\N	EXCUSE	0
370832	356669	96004D	PARTICIPANT	\N	EXCUSE	0
370833	356669	19631V	PARTICIPANT	\N	EXCUSE	0
370834	356669	19583F	PARTICIPANT	\N	EXCUSE	0
370836	370835	96004D	PARTICIPANT	\N	EXCUSE	0
370837	370835	19631V	PARTICIPANT	\N	EXCUSE	0
370838	370835	19583F	PARTICIPANT	\N	EXCUSE	0
370839	370835	95062K	PARTICIPANT	\N	EXCUSE	0
370845	370843	19631V	PARTICIPANT	\N	EXCUSE	0
370846	370843	96004D	PARTICIPANT	\N	EXCUSE	0
370847	370843	19583F	PARTICIPANT	\N	EXCUSE	0
373662	370550	19673G	PARTICIPANT	\N	PRESENT	0
373663	370550	14135M	PARTICIPANT	\N	PRESENT	0
373664	370550	14265W	PARTICIPANT	\N	PRESENT	0
373771	373770	11053K	PARTICIPANT	\N	PRESENT	0
373772	373770	14159V	PARTICIPANT	\N	PRESENT	0
373773	373770	05012A	PARTICIPANT	\N	PRESENT	0
373775	373774	11065P	PARTICIPANT	\N	PRESENT	0
373776	373774	19683J	PARTICIPANT	\N	PRESENT	0
373778	373777	19762G	PARTICIPANT	\N	PRESENT	0
374934	374933	19699S	PARTICIPANT	\N	PRESENT	0
374935	374933	11083R	PARTICIPANT	\N	PRESENT	0
374937	374936	19699S	PARTICIPANT	\N	PRESENT	0
375491	375490	14038Y	PARTICIPANT	\N	PRESENT	0
375492	375490	19333N	PARTICIPANT	\N	PRESENT	0
375493	375490	19289C	PARTICIPANT	\N	PRESENT	0
375494	375490	19681G	PARTICIPANT	\N	PRESENT	0
375495	375490	08009T	PARTICIPANT	\N	PRESENT	0
375496	375490	19637C	PARTICIPANT	\N	PRESENT	0
375497	375490	14029X	PARTICIPANT	\N	PRESENT	0
375543	375542	95063L	PARTICIPANT	\N	PRESENT	0
380209	380208	04057K	PARTICIPANT	\N	PRESENT	0
380211	380210	04057K	PARTICIPANT	\N	PRESENT	0
380212	378391	19687N	PARTICIPANT	\N	EXCUSE	0
380220	378391	19565D	PARTICIPANT	\N	EXCUSE	0
380224	378391	14028W	PARTICIPANT	\N	EXCUSE	0
384772	377905	11027H	PARTICIPANT	\N	PRESENT	0
384784	377905	14042U	PARTICIPANT	\N	PRESENT	0
384785	377905	08052W	PARTICIPANT	\N	PRESENT	0
384786	377905	19333N	PARTICIPANT	\N	PRESENT	0
384787	377905	19611R	PARTICIPANT	\N	PRESENT	0
384788	377905	14219Q	PARTICIPANT	\N	PRESENT	0
384789	377905	04092N	PARTICIPANT	\N	PRESENT	0
384790	377905	19565D	PARTICIPANT	\N	PRESENT	0
384791	377905	11031D	PARTICIPANT	\N	PRESENT	0
384792	377905	19593H	PARTICIPANT	\N	PRESENT	0
384793	377905	19760E	PARTICIPANT	\N	PRESENT	0
384794	377905	19367Y	PARTICIPANT	\N	PRESENT	0
384795	377905	19798U	PARTICIPANT	\N	PRESENT	0
384796	377905	19301E	PARTICIPANT	\N	PRESENT	0
384797	377905	14213J	PARTICIPANT	\N	PRESENT	0
384798	377905	19683J	PARTICIPANT	\N	PRESENT	0
384799	377905	14281W	PARTICIPANT	\N	PRESENT	0
384800	377905	19715Y	PARTICIPANT	\N	PRESENT	0
384801	377905	19727D	PARTICIPANT	\N	PRESENT	0
384802	377905	19651A	PARTICIPANT	\N	PRESENT	0
384803	377905	08061X	PARTICIPANT	\N	PRESENT	0
384804	377905	14261S	PARTICIPANT	\N	PRESENT	0
384805	377905	11097X	PARTICIPANT	\N	PRESENT	0
384806	377905	19415P	PARTICIPANT	\N	PRESENT	0
384807	377905	19575F	PARTICIPANT	\N	PRESENT	0
384808	377905	19643A	PARTICIPANT	\N	PRESENT	0
384809	377905	19503N	PARTICIPANT	\N	PRESENT	0
384810	377905	19657G	PARTICIPANT	\N	PRESENT	0
384811	377905	08049C	PARTICIPANT	\N	PRESENT	0
384812	377905	19533U	PARTICIPANT	\N	PRESENT	0
384813	377905	14119M	PARTICIPANT	\N	PRESENT	0
384814	377905	14239U	PARTICIPANT	\N	PRESENT	0
384815	377905	19697Q	PARTICIPANT	\N	PRESENT	0
384816	377905	11045K	PARTICIPANT	\N	PRESENT	0
384817	377905	19693L	PARTICIPANT	\N	PRESENT	0
384818	377905	11103C	PARTICIPANT	\N	PRESENT	0
384819	377905	19553Y	PARTICIPANT	\N	PRESENT	0
384820	377905	14195A	PARTICIPANT	\N	PRESENT	0
384823	377905	17779H	PARTICIPANT	\N	PRESENT	0
384824	377905	14251Q	PARTICIPANT	\N	PRESENT	0
384825	377905	11072N	PARTICIPANT	\N	PRESENT	0
384826	377905	19735D	PARTICIPANT	\N	PRESENT	0
384827	377905	10006L	PARTICIPANT	\N	PRESENT	0
384828	377905	19563B	PARTICIPANT	\N	PRESENT	0
384831	377905	19525U	PARTICIPANT	\N	PRESENT	0
384841	377905	11012A	PARTICIPANT	\N	PRESENT	0
384842	377905	14257W	PARTICIPANT	\N	PRESENT	0
384843	377905	19413M	PARTICIPANT	\N	PRESENT	0
384844	377905	19663E	PARTICIPANT	\N	PRESENT	0
384845	377905	19713W	PARTICIPANT	\N	PRESENT	0
384846	377905	14107H	PARTICIPANT	\N	PRESENT	0
384848	377905	08043V	PARTICIPANT	\N	PRESENT	0
384849	377905	14331P	PARTICIPANT	\N	PRESENT	0
384850	377905	19703U	PARTICIPANT	\N	PRESENT	0
384851	384596	19697Q	PARTICIPANT	\N	PRESENT	0
384852	384596	04092N	PARTICIPANT	\N	PRESENT	0
384853	384596	19565D	PARTICIPANT	\N	PRESENT	0
384854	384596	19798U	PARTICIPANT	\N	PRESENT	0
384855	384596	11045K	PARTICIPANT	\N	PRESENT	0
384856	384596	11097X	PRESIDENT	0	PRESENT	0
384857	384596	08052W	PARTICIPANT	\N	PRESENT	0
384858	384596	19663E	PARTICIPANT	\N	PRESENT	0
384859	384596	19415P	PARTICIPANT	\N	PRESENT	0
384860	384596	19301E	PARTICIPANT	\N	PRESENT	0
384861	384596	19727D	PARTICIPANT	\N	PRESENT	0
384862	384596	14239U	PARTICIPANT	\N	PRESENT	0
384863	384596	19553Y	PARTICIPANT	\N	PRESENT	0
384864	384596	11031D	PARTICIPANT	\N	PRESENT	0
384865	384596	14281W	PARTICIPANT	\N	PRESENT	0
384866	384596	11103C	PARTICIPANT	\N	PRESENT	0
384867	384596	14042U	PARTICIPANT	\N	PRESENT	0
384868	384596	19575F	PARTICIPANT	\N	PRESENT	0
384869	384596	14195A	PARTICIPANT	\N	PRESENT	0
384870	384596	19367Y	PARTICIPANT	\N	PRESENT	0
384871	384596	19657G	PARTICIPANT	\N	PRESENT	0
384872	384596	19683J	PARTICIPANT	\N	PRESENT	0
384873	384596	11067R	PARTICIPANT	\N	EXCUSE	0
384874	384596	08041T	PARTICIPANT	\N	EXCUSE	0
384875	377905	19549D	PARTICIPANT	\N	PRESENT	0
384876	377905	19739H	PARTICIPANT	\N	PRESENT	0
384877	377905	04059M	PARTICIPANT	\N	PRESENT	0
384878	377905	19794Q	PARTICIPANT	\N	PRESENT	0
384879	377905	14217N	PARTICIPANT	\N	PRESENT	0
384881	377905	19762G	PARTICIPANT	\N	PRESENT	0
384882	377905	19689Q	PARTICIPANT	\N	PRESENT	0
384883	377905	04085P	PARTICIPANT	\N	PRESENT	0
384884	377905	14021P	PARTICIPANT	\N	PRESENT	0
384885	377905	14179A	PARTICIPANT	\N	PRESENT	0
384886	377905	12016W	PARTICIPANT	\N	PRESENT	0
384887	377905	14249W	PARTICIPANT	\N	PRESENT	0
384888	377905	19295A	PARTICIPANT	\N	PRESENT	0
384889	377905	19441R	PARTICIPANT	\N	PRESENT	0
384890	377905	19479G	PARTICIPANT	\N	PRESENT	0
384891	384597	19565D	PARTICIPANT	\N	PRESENT	0
384892	384597	19798U	PARTICIPANT	\N	PRESENT	0
384893	384597	11097X	PRESIDENT	0	PRESENT	0
384894	384597	19415P	PARTICIPANT	\N	PRESENT	0
384895	384597	17779H	PARTICIPANT	\N	PRESENT	0
384896	384597	14239U	PARTICIPANT	\N	PRESENT	0
384897	384597	19553Y	PARTICIPANT	\N	PRESENT	0
384898	384597	11031D	PARTICIPANT	\N	PRESENT	0
384899	384597	14281W	PARTICIPANT	\N	PRESENT	0
384900	384597	14042U	PARTICIPANT	\N	PRESENT	0
384901	384597	19575F	PARTICIPANT	\N	PRESENT	0
384902	384597	14195A	PARTICIPANT	\N	PRESENT	0
384903	384597	19367Y	PARTICIPANT	\N	PRESENT	0
384904	384597	14217N	PARTICIPANT	\N	PRESENT	0
384905	384597	19683J	PARTICIPANT	\N	PRESENT	0
384906	384597	10006L	PARTICIPANT	\N	PRESENT	0
384907	384597	04092N	PARTICIPANT	\N	PRESENT	0
384908	384597	11045K	PARTICIPANT	\N	PRESENT	0
384909	384597	08052W	PARTICIPANT	\N	PRESENT	0
384910	384597	19663E	PARTICIPANT	\N	PRESENT	0
384911	384597	19301E	PARTICIPANT	\N	PRESENT	0
384912	384597	19715Y	PARTICIPANT	\N	PRESENT	0
384913	384597	19727D	PARTICIPANT	\N	PRESENT	0
384914	384597	11103C	PARTICIPANT	\N	PRESENT	0
384915	384597	19657G	PARTICIPANT	\N	PRESENT	0
384916	384597	19760E	PARTICIPANT	\N	PRESENT	0
384917	384597	11067R	PARTICIPANT	\N	EXCUSE	0
384918	384597	08041T	PARTICIPANT	\N	EXCUSE	0
371206	371187	11048N	PARTICIPANT	\N	PRESENT	0
371207	371187	08038Y	PARTICIPANT	\N	PRESENT	0
371208	371187	19715Y	PARTICIPANT	\N	EXCUSE	0
371209	371187	08019V	PARTICIPANT	\N	EXCUSE	0
371210	371187	14051J	PARTICIPANT	\N	EXCUSE	0
371211	371187	08049C	PARTICIPANT	\N	EXCUSE	0
371215	365231	08062Y	PARTICIPANT	\N	PRESENT	0
371760	367384	14042U	PARTICIPANT	\N	PRESENT	0
371773	367384	14213J	PARTICIPANT	\N	PRESENT	0
371774	367384	11097X	PARTICIPANT	\N	PRESENT	0
371775	367384	10006L	PARTICIPANT	\N	PRESENT	0
371776	367384	14239U	PARTICIPANT	\N	PRESENT	0
371777	367384	08052W	PARTICIPANT	\N	PRESENT	0
371778	367384	19727D	PARTICIPANT	\N	PRESENT	0
371782	367384	14195A	PARTICIPANT	\N	PRESENT	0
371783	367384	14281W	PARTICIPANT	\N	PRESENT	0
371784	367384	19367Y	PARTICIPANT	\N	PRESENT	0
371785	367384	19723Y	PARTICIPANT	\N	PRESENT	0
371786	367384	14087W	PARTICIPANT	\N	PRESENT	0
371787	367384	19703U	PARTICIPANT	\N	PRESENT	0
371788	367384	19663E	PARTICIPANT	\N	PRESENT	0
371789	367384	98024R	PARTICIPANT	\N	PRESENT	0
371790	367384	19575F	PARTICIPANT	\N	PRESENT	0
371791	367384	19683J	PARTICIPANT	\N	PRESENT	0
371793	367384	19679N	PARTICIPANT	\N	PRESENT	0
372233	372232	14133K	PRESIDENT	1	PRESENT	0
372234	372232	96004D	PRESIDENT	0	PRESENT	0
372235	372232	04042C	PARTICIPANT	\N	EXCUSE	0
372236	372232	19251M	PARTICIPANT	\N	PRESENT	0
372237	372232	04035D	PARTICIPANT	\N	PRESENT	0
372238	372232	04097T	PARTICIPANT	\N	PRESENT	0
372239	372232	19709B	PARTICIPANT	\N	PRESENT	0
372240	372232	04057K	PARTICIPANT	\N	EXCUSE	0
372241	372232	98035U	PARTICIPANT	\N	PRESENT	0
373505	373504	11027H	PARTICIPANT	\N	PRESENT	0
373506	373504	19709B	PARTICIPANT	\N	PRESENT	0
373512	367388	10006L	PARTICIPANT	\N	PRESENT	0
373513	367388	19553Y	PARTICIPANT	\N	PRESENT	0
373514	367388	14217N	PARTICIPANT	\N	PRESENT	0
373515	367388	19683J	PARTICIPANT	\N	PRESENT	0
373516	367388	19575F	PARTICIPANT	\N	PRESENT	0
373517	367388	14071N	PARTICIPANT	\N	PRESENT	0
373518	367388	14213J	PARTICIPANT	\N	PRESENT	0
373519	367388	19727D	PARTICIPANT	\N	PRESENT	0
373520	367388	19723Y	PARTICIPANT	\N	PRESENT	0
373521	367388	19367Y	PARTICIPANT	\N	PRESENT	0
373522	367388	19663E	PARTICIPANT	\N	PRESENT	0
373523	367388	14042U	PARTICIPANT	\N	PRESENT	0
373579	373578	19717B	PARTICIPANT	\N	PRESENT	0
373580	373578	14026U	PARTICIPANT	\N	PRESENT	0
373581	373578	19565D	PARTICIPANT	\N	PRESENT	0
373584	373583	19717B	PARTICIPANT	\N	PRESENT	0
373585	373583	14026U	PARTICIPANT	\N	PRESENT	0
373586	373583	19565D	PARTICIPANT	\N	PRESENT	0
373588	373587	19717B	PARTICIPANT	\N	PRESENT	0
373589	373587	14026U	PARTICIPANT	\N	PRESENT	0
373591	373590	19421M	PARTICIPANT	\N	PRESENT	0
373592	373590	19251M	PARTICIPANT	\N	PRESENT	0
373593	373590	04040A	PARTICIPANT	\N	PRESENT	0
373595	373594	14193X	PARTICIPANT	\N	PRESENT	0
373602	373601	11053K	PARTICIPANT	\N	PRESENT	0
373603	373601	14159V	PARTICIPANT	\N	PRESENT	0
373604	373601	05012A	PARTICIPANT	\N	PRESENT	0
373606	373605	19711U	PARTICIPANT	\N	PRESENT	0
373607	373605	01048V	PARTICIPANT	\N	PRESENT	0
373609	373608	08034U	PARTICIPANT	\N	PRESENT	0
373611	373610	08034U	PARTICIPANT	\N	PRESENT	0
373613	373612	11074Q	PARTICIPANT	\N	PRESENT	0
373614	373612	08011M	PARTICIPANT	\N	PRESENT	0
373616	373615	11074Q	PARTICIPANT	\N	PRESENT	0
373617	373615	08011M	PARTICIPANT	\N	PRESENT	0
373619	373618	88008L	PARTICIPANT	\N	PRESENT	0
373620	373618	11012A	PARTICIPANT	\N	PRESENT	0
373621	365632	18003S	PARTICIPANT	\N	PRESENT	0
373622	365632	19693L	PARTICIPANT	\N	PRESENT	0
373623	365632	19511N	PARTICIPANT	\N	PRESENT	0
373624	365632	19709B	PARTICIPANT	\N	PRESENT	0
373625	365632	01048V	PARTICIPANT	\N	PRESENT	0
373626	365632	04043D	PARTICIPANT	\N	PRESENT	0
373627	365632	01058X	PARTICIPANT	\N	PRESENT	0
373628	365632	19503N	PARTICIPANT	\N	PRESENT	0
373895	373894	19741B	PARTICIPANT	\N	PRESENT	0
373896	373894	10006L	PARTICIPANT	\N	PRESENT	0
373897	373894	08031R	PARTICIPANT	\N	PRESENT	0
376821	376820	19611R	PARTICIPANT	\N	PRESENT	0
377291	371474	19301E	PARTICIPANT	\N	PRESENT	0
377292	371474	19699S	PARTICIPANT	\N	PRESENT	0
377293	371474	19295A	PARTICIPANT	\N	PRESENT	0
377294	371474	19643A	PARTICIPANT	\N	PRESENT	0
377296	371474	19253P	PARTICIPANT	\N	PRESENT	0
377297	371474	08049C	PARTICIPANT	\N	PRESENT	0
377298	371474	14034U	PARTICIPANT	\N	PRESENT	0
377299	371474	11027H	PARTICIPANT	\N	PRESENT	0
377300	371474	19551W	PARTICIPANT	\N	PRESENT	0
377301	371474	19629C	PARTICIPANT	\N	PRESENT	0
377302	371474	14061L	PARTICIPANT	\N	PRESENT	0
377303	371474	04059M	PARTICIPANT	\N	PRESENT	0
377304	371474	19553Y	PARTICIPANT	\N	PRESENT	0
377305	371474	19573D	PARTICIPANT	\N	PRESENT	0
377306	371474	14173T	PARTICIPANT	\N	PRESENT	0
377307	371474	14073Q	PARTICIPANT	\N	PRESENT	0
377308	371474	04089T	PARTICIPANT	\N	PRESENT	0
377310	371474	19637C	PARTICIPANT	\N	PRESENT	0
377311	371474	14211G	PARTICIPANT	\N	PRESENT	0
377312	371474	15447F	PARTICIPANT	\N	PRESENT	0
377313	371474	19269X	PARTICIPANT	\N	PRESENT	0
377314	371474	19251M	PARTICIPANT	\N	PRESENT	0
377315	376798	19333N	PARTICIPANT	\N	PRESENT	0
377316	376798	14357A	PARTICIPANT	\N	PRESENT	0
377317	376798	19549D	PARTICIPANT	\N	PRESENT	0
377318	376798	11053K	PRESIDENT	0	PRESENT	0
377319	376798	19253P	PARTICIPANT	\N	PRESENT	0
377320	376798	19301E	PARTICIPANT	\N	PRESENT	0
377321	376798	19715Y	PARTICIPANT	\N	PRESENT	0
377322	376798	15447F	PARTICIPANT	0	PRESENT	0
377323	376798	14237S	PARTICIPANT	\N	PRESENT	0
377324	376798	19703U	PARTICIPANT	\N	PRESENT	0
377325	376798	14083S	PARTICIPANT	\N	PRESENT	0
377326	376798	19729F	PARTICIPANT	\N	PRESENT	0
377327	376798	14199E	PARTICIPANT	\N	PRESENT	0
377328	376798	04097T	PARTICIPANT	\N	PRESENT	0
377329	376798	19349W	PARTICIPANT	\N	PRESENT	0
377330	376798	11077T	PARTICIPANT	\N	EXCUSE	0
377331	376798	08045X	PARTICIPANT	\N	EXCUSE	0
377332	376798	19735D	PARTICIPANT	\N	EXCUSE	0
377333	376798	14225N	PARTICIPANT	\N	EXCUSE	0
377334	376798	19671E	PARTICIPANT	\N	EXCUSE	0
377335	371474	19631V	PARTICIPANT	\N	PRESENT	0
377336	376798	19669L	PARTICIPANT	\N	PRESENT	0
377337	376798	19383Y	PARTICIPANT	\N	PRESENT	0
377338	376798	14031R	PARTICIPANT	\N	PRESENT	0
377340	371474	14079W	PARTICIPANT	\N	PRESENT	0
377341	371474	19467C	PARTICIPANT	\N	PRESENT	0
377342	371474	19663E	PARTICIPANT	\N	PRESENT	0
377343	371474	14207L	PARTICIPANT	\N	PRESENT	0
377344	371474	08009T	PARTICIPANT	\N	PRESENT	0
377345	371474	14081Q	PARTICIPANT	\N	PRESENT	0
377346	371474	19399H	PARTICIPANT	\N	PRESENT	0
377347	371474	08015R	PARTICIPANT	\N	PRESENT	0
377348	371474	14001X	PARTICIPANT	\N	PRESENT	0
377349	371474	11012A	PARTICIPANT	\N	PRESENT	0
377350	371474	14053L	PARTICIPANT	\N	PRESENT	0
377352	375455	19697Q	PARTICIPANT	\N	PRESENT	0
377353	375455	11067R	PARTICIPANT	\N	PRESENT	0
377354	375455	14355X	PARTICIPANT	\N	PRESENT	0
377355	375455	19798U	PARTICIPANT	\N	PRESENT	0
377356	375455	19415P	PARTICIPANT	\N	PRESENT	0
377357	375455	04045F	PARTICIPANT	\N	PRESENT	0
377358	375455	14227Q	PARTICIPANT	\N	PRESENT	0
377359	375455	17779H	PARTICIPANT	\N	PRESENT	0
377360	375455	14239U	PARTICIPANT	\N	PRESENT	0
377361	375455	19553Y	PARTICIPANT	\N	PRESENT	0
377362	375455	11031D	PARTICIPANT	\N	PRESENT	0
377363	375455	19679N	PARTICIPANT	\N	PRESENT	0
377364	375455	14042U	PARTICIPANT	\N	PRESENT	0
377365	375455	19575F	PARTICIPANT	\N	PRESENT	0
377366	375455	14195A	PARTICIPANT	\N	PRESENT	0
377367	375455	19367Y	PARTICIPANT	\N	PRESENT	0
377368	375455	19683J	PARTICIPANT	\N	PRESENT	0
377369	375455	19521Q	PARTICIPANT	\N	PRESENT	0
377370	375455	98024R	PARTICIPANT	\N	PRESENT	0
377371	375455	01034P	PARTICIPANT	\N	PRESENT	0
377372	375455	04092N	PRESIDENT	0	PRESENT	0
377373	375455	11045K	PARTICIPANT	\N	PRESENT	0
377374	375455	08052W	PARTICIPANT	\N	PRESENT	0
377375	375455	19663E	PARTICIPANT	\N	PRESENT	0
377376	375455	19691J	PARTICIPANT	\N	PRESENT	0
377377	375455	19727D	PARTICIPANT	\N	PRESENT	0
377378	375455	14119M	PARTICIPANT	\N	PRESENT	0
364270	344821	11031D	PARTICIPANT	\N	EXCUSE	0
364271	344821	07029T	PARTICIPANT	\N	EXCUSE	0
364272	344821	11067R	PARTICIPANT	\N	EXCUSE	0
364281	364280	98029W	PARTICIPANT	\N	PRESENT	0
379010	378893	08055A	PARTICIPANT	\N	PRESENT	0
379011	378893	04047H	PARTICIPANT	\N	PRESENT	0
379026	379025	08055A	PARTICIPANT	\N	PRESENT	0
379013	378893	14085U	PARTICIPANT	\N	PRESENT	0
379014	378893	11080N	PARTICIPANT	\N	PRESENT	0
379015	378893	11083R	PARTICIPANT	\N	PRESENT	0
379016	378893	01057W	PARTICIPANT	\N	PRESENT	0
379027	379025	04047H	PARTICIPANT	\N	PRESENT	0
381742	371530	14029X	PARTICIPANT	\N	PRESENT	0
381743	371530	14079W	PARTICIPANT	\N	PRESENT	0
379020	378893	14157T	PARTICIPANT	\N	PRESENT	0
381744	371530	89017R	PARTICIPANT	\N	PRESENT	0
379029	379025	14085U	PARTICIPANT	\N	PRESENT	0
381745	371530	11056N	PARTICIPANT	\N	PRESENT	0
381793	371531	11074Q	PARTICIPANT	\N	PRESENT	0
379032	379025	01057W	PARTICIPANT	\N	PRESENT	0
379033	379025	19611R	PARTICIPANT	\N	PRESENT	0
381794	371531	14085U	PARTICIPANT	\N	PRESENT	0
379035	379025	08049C	PARTICIPANT	\N	PRESENT	0
379036	379025	14157T	PARTICIPANT	\N	PRESENT	0
381795	371531	19687N	PARTICIPANT	\N	PRESENT	0
381796	371531	11056N	PARTICIPANT	\N	PRESENT	0
381797	371531	19695N	PARTICIPANT	\N	PRESENT	0
381798	371531	11077T	PARTICIPANT	\N	PRESENT	0
381799	371531	19593H	PARTICIPANT	\N	PRESENT	0
381800	371531	14030Q	PARTICIPANT	\N	PRESENT	0
381801	371531	19651A	PARTICIPANT	\N	PRESENT	0
381802	371531	14225N	PARTICIPANT	\N	PRESENT	0
381803	371531	07004J	PARTICIPANT	\N	PRESENT	0
381804	371531	14255U	PARTICIPANT	\N	PRESENT	0
381805	371531	14327T	PARTICIPANT	\N	PRESENT	0
381806	371531	19711U	PARTICIPANT	\N	PRESENT	0
381807	371531	14331P	PARTICIPANT	\N	PRESENT	0
381808	371531	14265W	PARTICIPANT	\N	PRESENT	0
381809	371531	14029X	PARTICIPANT	\N	PRESENT	0
381810	371531	19467C	PARTICIPANT	\N	PRESENT	0
381811	371531	19531S	PARTICIPANT	\N	PRESENT	0
381812	371531	12016W	PARTICIPANT	\N	PRESENT	0
381813	371531	19794Q	PARTICIPANT	\N	PRESENT	0
381814	371531	19667J	PARTICIPANT	\N	PRESENT	0
381815	371531	19679N	PARTICIPANT	\N	PRESENT	0
381816	371531	04097T	PARTICIPANT	\N	PRESENT	0
381817	371531	17637T	PARTICIPANT	\N	PRESENT	0
381818	371531	14187A	PARTICIPANT	\N	PRESENT	0
381819	371531	19647E	PARTICIPANT	\N	PRESENT	0
381820	371531	88008L	PARTICIPANT	\N	PRESENT	0
381821	371531	14031R	PARTICIPANT	\N	PRESENT	0
381822	371531	14034U	PARTICIPANT	\N	PRESENT	0
381823	371531	19349W	PARTICIPANT	\N	PRESENT	0
381824	371531	19782L	PARTICIPANT	\N	PRESENT	0
381825	371531	19545Y	PARTICIPANT	\N	PRESENT	0
381826	371531	14169X	PARTICIPANT	\N	PRESENT	0
381827	371531	14357A	PARTICIPANT	\N	PRESENT	0
381828	371531	11070L	PARTICIPANT	\N	PRESENT	0
381829	371531	95030B	PARTICIPANT	\N	PRESENT	0
381830	371531	08034U	PARTICIPANT	\N	PRESENT	0
381831	371531	19747H	PARTICIPANT	\N	PRESENT	0
381832	371531	14197C	PARTICIPANT	\N	PRESENT	0
381833	371531	08015R	PARTICIPANT	\N	PRESENT	0
381834	371531	14065Q	PARTICIPANT	\N	PRESENT	0
381835	371531	11048N	PARTICIPANT	\N	PRESENT	0
381836	371531	05012A	PARTICIPANT	\N	PRESENT	0
381837	371531	14119M	PARTICIPANT	\N	PRESENT	0
381791	371531	11072N	PARTICIPANT	\N	PRESENT	0
381792	371531	08011M	PARTICIPANT	\N	PRESENT	0
381838	371531	19447X	PARTICIPANT	\N	PRESENT	0
381839	371531	19621T	PARTICIPANT	\N	PRESENT	0
381840	371531	14069U	PARTICIPANT	\N	PRESENT	0
381841	371531	14147R	PARTICIPANT	\N	PRESENT	0
381842	371531	08069G	PARTICIPANT	\N	PRESENT	0
381843	371531	14089Y	PARTICIPANT	\N	PRESENT	0
381844	371531	08039A	PARTICIPANT	\N	PRESENT	0
381845	371531	19691J	PARTICIPANT	\N	PRESENT	0
381846	371531	19693L	PARTICIPANT	\N	PRESENT	0
381847	371531	08061X	PARTICIPANT	\N	PRESENT	0
381848	371531	01028R	PARTICIPANT	\N	PRESENT	0
381849	371531	19551W	PARTICIPANT	\N	PRESENT	0
381850	371531	14026U	PARTICIPANT	\N	PRESENT	0
381851	371531	14083S	PARTICIPANT	\N	PRESENT	0
381852	371531	19507S	PARTICIPANT	\N	PRESENT	0
381853	371531	18083K	PARTICIPANT	\N	PRESENT	0
381854	371531	14213J	PARTICIPANT	\N	PRESENT	0
381855	371531	19383Y	PARTICIPANT	\N	PRESENT	0
381856	371531	14133K	PARTICIPANT	\N	PRESENT	0
381857	371531	07029T	PARTICIPANT	\N	PRESENT	0
382154	378922	14253S	PARTICIPANT	\N	PRESENT	0
382612	378391	11048N	PARTICIPANT	\N	PRESENT	0
383530	371541	08047A	PARTICIPANT	\N	PRESENT	0
383531	371541	14028W	PARTICIPANT	\N	PRESENT	0
383532	371541	14105F	PARTICIPANT	\N	PRESENT	0
383533	371541	19591F	PARTICIPANT	\N	PRESENT	0
383534	371541	17583W	PARTICIPANT	\N	PRESENT	0
383535	371541	08038Y	PARTICIPANT	\N	PRESENT	0
383536	371541	14197C	PARTICIPANT	\N	PRESENT	0
383537	371541	14147R	PARTICIPANT	\N	PRESENT	0
383538	371541	08060W	PARTICIPANT	\N	PRESENT	0
383539	371541	01062T	PARTICIPANT	\N	PRESENT	0
383540	371541	11066Q	PARTICIPANT	\N	PRESENT	0
383541	371541	08043V	PARTICIPANT	\N	PRESENT	0
383542	371541	14115H	PARTICIPANT	\N	PRESENT	0
383543	371541	14281W	PARTICIPANT	\N	PRESENT	0
383544	371541	08035V	PARTICIPANT	\N	PRESENT	0
383545	371541	14038Y	PARTICIPANT	\N	PRESENT	0
383546	371541	08012N	PARTICIPANT	\N	PRESENT	0
383547	371541	19531S	PARTICIPANT	\N	PRESENT	0
383548	371541	19723Y	PARTICIPANT	\N	PRESENT	0
383549	371541	19727D	PARTICIPANT	\N	PRESENT	0
383550	371541	08058D	PARTICIPANT	\N	PRESENT	0
383551	371541	19543W	PARTICIPANT	\N	PRESENT	0
383552	371541	19467C	PARTICIPANT	\N	PRESENT	0
383553	371541	18083K	PARTICIPANT	\N	PRESENT	0
383554	371541	19689Q	PARTICIPANT	\N	PRESENT	0
383555	371541	08017T	PARTICIPANT	\N	PRESENT	0
383556	371541	08053X	PARTICIPANT	\N	PRESENT	0
383557	371541	19415P	PARTICIPANT	\N	PRESENT	0
383558	371541	19525U	PARTICIPANT	\N	PRESENT	0
383559	371541	08019V	PARTICIPANT	\N	PRESENT	0
383560	371541	14257W	PARTICIPANT	\N	PRESENT	0
383561	371541	19399H	PARTICIPANT	\N	PRESENT	0
383562	371541	19693L	PARTICIPANT	\N	PRESENT	0
383563	371541	14081Q	PARTICIPANT	\N	PRESENT	0
383564	371541	11041F	PARTICIPANT	\N	PRESENT	0
383565	371541	11110B	PARTICIPANT	\N	PRESENT	0
383566	371541	04035D	PARTICIPANT	\N	PRESENT	0
383567	371541	19599P	PARTICIPANT	\N	PRESENT	0
383568	371541	19729F	PARTICIPANT	\N	PRESENT	0
383569	371541	19549D	PARTICIPANT	\N	PRESENT	0
383570	371541	08014Q	PARTICIPANT	\N	PRESENT	0
383571	371541	10015M	PARTICIPANT	\N	PRESENT	0
383572	371541	19333N	PARTICIPANT	\N	PRESENT	0
383573	371541	08048B	PARTICIPANT	\N	PRESENT	0
383574	371541	14001X	PARTICIPANT	\N	PRESENT	0
383575	371541	14065Q	PARTICIPANT	\N	PRESENT	0
383577	371541	14227Q	PARTICIPANT	\N	PRESENT	0
383578	371541	19683J	PARTICIPANT	\N	PRESENT	0
383579	371541	19413M	PARTICIPANT	\N	PRESENT	0
383580	371541	11054L	PARTICIPANT	\N	PRESENT	0
383581	371541	11026G	PARTICIPANT	\N	PRESENT	0
383582	371541	14213J	PARTICIPANT	\N	PRESENT	0
383583	371541	19489J	PARTICIPANT	\N	PRESENT	0
383584	371541	19503N	PARTICIPANT	\N	PRESENT	0
383585	371541	19443T	PARTICIPANT	\N	PRESENT	0
383586	371541	19709B	PARTICIPANT	\N	PRESENT	0
383587	371541	11067R	PARTICIPANT	\N	PRESENT	0
383588	371541	19527W	PARTICIPANT	\N	PRESENT	0
383589	371541	19507S	PARTICIPANT	\N	PRESENT	0
383590	371541	14063N	PARTICIPANT	\N	PRESENT	0
383591	371541	19663E	PARTICIPANT	\N	PRESENT	0
383592	371541	19631V	PARTICIPANT	\N	PRESENT	0
383593	371541	04088S	PARTICIPANT	\N	PRESENT	0
383594	371541	14109K	PARTICIPANT	\N	PRESENT	0
383595	371541	14041T	PARTICIPANT	\N	PRESENT	0
383596	371541	08018U	PARTICIPANT	\N	PRESENT	0
383597	371541	07029T	PARTICIPANT	\N	PRESENT	0
383598	371541	14355X	PARTICIPANT	\N	PRESENT	0
383599	371541	08062Y	PARTICIPANT	\N	PRESENT	0
383600	371541	19713W	PARTICIPANT	\N	PRESENT	0
383601	371541	14033T	PARTICIPANT	\N	PRESENT	0
383602	371541	04089T	PARTICIPANT	\N	PRESENT	0
383603	371541	08015R	PARTICIPANT	\N	PRESENT	0
383604	371541	19691J	PARTICIPANT	\N	PRESENT	0
383605	371541	19768N	PARTICIPANT	\N	PRESENT	0
383606	371541	19369B	PARTICIPANT	\N	PRESENT	0
383607	371541	08009T	PARTICIPANT	\N	PRESENT	0
387776	387767	14053L	PARTICIPANT	\N	PRESENT	0
387777	387767	19489J	PARTICIPANT	\N	PRESENT	0
387778	387767	10015M	PARTICIPANT	\N	PRESENT	0
387779	387767	14147R	PARTICIPANT	\N	PRESENT	0
387780	387767	01024M	PARTICIPANT	\N	PRESENT	0
387781	387767	14069U	PARTICIPANT	\N	PRESENT	0
387782	387767	04038G	PARTICIPANT	\N	PRESENT	0
387783	387767	19585H	PARTICIPANT	\N	PRESENT	0
387784	387767	14259Y	PARTICIPANT	\N	PRESENT	0
387785	387767	05008E	PRESIDENT	0	PRESENT	0
387786	387767	19762G	PARTICIPANT	\N	PRESENT	0
387787	387767	14111D	PARTICIPANT	\N	PRESENT	0
387788	387767	11049P	PARTICIPANT	\N	PRESENT	0
387789	387767	14231L	PARTICIPANT	\N	PRESENT	0
387790	387767	11072N	PARTICIPANT	\N	PRESENT	0
387791	387767	19729F	PARTICIPANT	\N	EXCUSE	0
387792	387767	04044E	PARTICIPANT	\N	EXCUSE	0
387798	387793	86034E	PARTICIPANT	\N	PRESENT	0
387801	387793	11045K	PARTICIPANT	\N	PRESENT	0
387802	387793	14151M	PARTICIPANT	\N	PRESENT	0
387803	387793	14281W	PARTICIPANT	\N	PRESENT	0
387804	387793	19333N	PARTICIPANT	\N	PRESENT	0
387805	387793	14159V	PARTICIPANT	\N	PRESENT	0
387806	387793	19760E	PARTICIPANT	\N	PRESENT	0
387807	387793	12041X	PARTICIPANT	\N	PRESENT	0
387808	387793	11031D	PARTICIPANT	\N	PRESENT	0
387809	387793	14063N	PARTICIPANT	\N	PRESENT	0
387810	387793	19525U	PARTICIPANT	\N	PRESENT	0
387811	387793	19782L	PARTICIPANT	\N	PRESENT	0
387812	387793	19637C	PARTICIPANT	\N	PRESENT	0
387813	387793	11066Q	PARTICIPANT	\N	PRESENT	0
387814	387793	14085U	PARTICIPANT	\N	PRESENT	0
387815	387793	19489J	PARTICIPANT	\N	PRESENT	0
387816	387793	11040E	PARTICIPANT	\N	PRESENT	0
387817	387793	08052W	PARTICIPANT	\N	PRESENT	0
387818	387793	19527W	PARTICIPANT	\N	PRESENT	0
387819	387793	08053X	PARTICIPANT	\N	PRESENT	0
387820	387793	04059M	PARTICIPANT	\N	PRESENT	0
387821	387793	14229S	PARTICIPANT	\N	PRESENT	0
387822	387793	19659J	PARTICIPANT	\N	PRESENT	0
387823	387793	11067R	PARTICIPANT	\N	PRESENT	0
387824	387793	04085P	PARTICIPANT	\N	PRESENT	0
387825	387793	19695N	PARTICIPANT	\N	PRESENT	0
387826	387793	19758L	PARTICIPANT	\N	PRESENT	0
387827	387793	14235Q	PARTICIPANT	\N	PRESENT	0
387828	387793	14051J	PARTICIPANT	\N	PRESENT	0
387829	387793	19503N	PARTICIPANT	\N	PRESENT	0
387830	387793	14021P	PARTICIPANT	\N	PRESENT	0
387831	387793	19531S	PARTICIPANT	\N	PRESENT	0
387832	387793	19347U	PARTICIPANT	\N	PRESENT	0
387833	387793	19565D	PARTICIPANT	\N	PRESENT	0
387834	387793	04038G	PARTICIPANT	\N	PRESENT	0
387835	387793	19669L	PARTICIPANT	\N	PRESENT	0
387836	387793	98035U	PARTICIPANT	\N	PRESENT	0
387837	387793	08014Q	PARTICIPANT	\N	PRESENT	0
387838	387793	11033F	PARTICIPANT	\N	PRESENT	0
387839	387793	14239U	PARTICIPANT	\N	PRESENT	0
387840	387793	19697Q	PARTICIPANT	\N	PRESENT	0
387841	387793	19725B	PARTICIPANT	\N	PRESENT	0
387842	387793	19651A	PARTICIPANT	\N	PRESENT	0
387850	387793	19649G	PARTICIPANT	\N	PRESENT	0
387851	387793	80013X	PARTICIPANT	\N	PRESENT	0
387852	387793	19349W	PARTICIPANT	\N	PRESENT	0
387853	387793	95063L	PARTICIPANT	\N	PRESENT	0
387854	387793	11012A	PARTICIPANT	\N	PRESENT	0
387855	387793	08031R	PARTICIPANT	\N	PRESENT	0
387856	387793	88008L	PARTICIPANT	\N	PRESENT	0
387857	387793	14261S	PARTICIPANT	\N	PRESENT	0
387858	387793	19629C	PARTICIPANT	\N	PRESENT	0
387859	387793	19253P	PARTICIPANT	\N	PRESENT	0
387860	387793	19593H	PARTICIPANT	\N	PRESENT	0
387861	387793	14201E	PARTICIPANT	\N	PRESENT	0
387862	387793	98022P	PARTICIPANT	\N	PRESENT	0
387863	387793	14241N	PARTICIPANT	\N	PRESENT	0
387864	387793	14107H	PARTICIPANT	\N	PRESENT	0
387865	387793	11099A	PARTICIPANT	\N	PRESENT	0
387866	387793	19387D	PARTICIPANT	\N	PRESENT	0
387867	387793	19553Y	PARTICIPANT	\N	PRESENT	0
387868	387793	14207L	PARTICIPANT	\N	PRESENT	0
387869	387793	08061X	PARTICIPANT	\N	PRESENT	0
387870	387793	08021P	PARTICIPANT	\N	PRESENT	0
387871	387793	95037J	PARTICIPANT	\N	PRESENT	0
387872	387793	11072N	PARTICIPANT	\N	PRESENT	0
387873	387793	98029W	PARTICIPANT	\N	PRESENT	0
387874	387793	14039A	PARTICIPANT	\N	PRESENT	0
387875	387793	19711U	PARTICIPANT	\N	PRESENT	0
387876	387793	14211G	PARTICIPANT	\N	PRESENT	0
387877	387793	19679N	PARTICIPANT	\N	PRESENT	0
387878	387793	19731Y	PARTICIPANT	\N	PRESENT	0
387879	387793	19329S	PARTICIPANT	\N	PRESENT	0
387880	387793	08039A	PARTICIPANT	\N	PRESENT	0
387881	387793	01058X	PARTICIPANT	\N	PRESENT	0
387882	387793	04057K	PARTICIPANT	\N	PRESENT	0
387883	387793	11064N	PARTICIPANT	\N	PRESENT	0
387884	387793	11110B	PARTICIPANT	\N	PRESENT	0
387885	387793	99004R	PARTICIPANT	\N	PRESENT	0
387886	387793	19591F	PARTICIPANT	\N	PRESENT	0
387887	387793	08045X	PARTICIPANT	\N	PRESENT	0
387888	387793	08010L	PARTICIPANT	\N	PRESENT	0
387889	387793	01062T	PARTICIPANT	\N	PRESENT	0
387890	387793	19599P	PARTICIPANT	\N	PRESENT	0
387891	387793	14123H	PARTICIPANT	\N	PRESENT	0
387892	387793	14109K	PARTICIPANT	\N	PRESENT	0
387893	387793	08069G	PARTICIPANT	\N	PRESENT	0
387899	387793	11109J	PARTICIPANT	\N	PRESENT	0
387895	387793	04042C	PARTICIPANT	\N	PRESENT	0
387896	387793	15447F	PARTICIPANT	\N	PRESENT	0
387897	387793	14169X	PARTICIPANT	\N	PRESENT	0
387898	387793	14081Q	PARTICIPANT	\N	PRESENT	0
387900	387793	10015M	PARTICIPANT	\N	PRESENT	0
387901	387793	14001X	PARTICIPANT	\N	PRESENT	0
387902	387793	08035V	PARTICIPANT	\N	PRESENT	0
387903	387793	17779H	PARTICIPANT	\N	PRESENT	0
387904	387793	19715Y	PARTICIPANT	\N	PRESENT	0
387905	387793	14197C	PARTICIPANT	\N	PRESENT	0
387906	387793	11043H	PARTICIPANT	\N	PRESENT	0
387907	387793	14195A	PARTICIPANT	\N	PRESENT	0
387908	387793	14093U	PARTICIPANT	\N	PRESENT	0
387909	387793	01048V	PARTICIPANT	\N	PRESENT	0
387910	387793	04045F	PARTICIPANT	\N	PRESENT	0
387911	387793	08028W	PARTICIPANT	\N	PRESENT	0
387912	387793	08043V	PARTICIPANT	\N	PRESENT	0
387913	387793	14191V	PARTICIPANT	\N	PRESENT	0
387914	387793	04034C	PARTICIPANT	\N	PRESENT	0
387915	387793	19766L	PARTICIPANT	\N	PRESENT	0
387916	387793	14231L	PARTICIPANT	\N	PRESENT	0
387917	387793	14179A	PARTICIPANT	\N	PRESENT	0
387918	387793	01034P	PARTICIPANT	\N	PRESENT	0
387919	387793	19691J	PARTICIPANT	\N	PRESENT	0
387920	387793	87003B	PARTICIPANT	\N	PRESENT	0
387921	387793	19511N	PARTICIPANT	\N	PRESENT	0
387922	387793	19619A	PARTICIPANT	\N	PRESENT	0
387923	387793	11083R	PARTICIPANT	\N	PRESENT	0
387924	387793	14223L	PARTICIPANT	\N	PRESENT	0
387925	387793	11053K	PARTICIPANT	\N	PRESENT	0
387926	387793	19721W	PARTICIPANT	\N	PRESENT	0
387927	387793	19737F	PARTICIPANT	\N	PRESENT	0
387928	387793	19727D	PARTICIPANT	\N	PRESENT	0
387929	387793	19569H	PARTICIPANT	\N	PRESENT	0
387930	387793	08056B	PARTICIPANT	\N	PRESENT	0
387931	387793	14227Q	PARTICIPANT	\N	PRESENT	0
387932	387793	19713W	PARTICIPANT	\N	PRESENT	0
387933	387793	19735D	PARTICIPANT	\N	PRESENT	0
387934	387793	01043Q	PARTICIPANT	\N	PRESENT	0
387935	387793	16685X	PARTICIPANT	\N	PRESENT	0
387936	387793	19479G	PARTICIPANT	\N	PRESENT	0
387937	387793	14219Q	PARTICIPANT	\N	PRESENT	0
387938	387793	14028W	PARTICIPANT	\N	PRESENT	0
387939	387793	19543W	PARTICIPANT	\N	PRESENT	0
387940	387793	19521Q	PARTICIPANT	\N	PRESENT	0
387941	387793	11085T	PARTICIPANT	\N	PRESENT	0
387942	387793	14089Y	PARTICIPANT	\N	PRESENT	0
387943	387793	14255U	PARTICIPANT	\N	PRESENT	0
387944	387793	14073Q	PARTICIPANT	\N	PRESENT	0
387945	387793	14275Y	PARTICIPANT	\N	PRESENT	0
387946	387793	14042U	PARTICIPANT	\N	PRESENT	0
387947	387793	14327T	PARTICIPANT	\N	PRESENT	0
387948	387793	11070L	PARTICIPANT	\N	PRESENT	0
387949	387793	14267Y	PARTICIPANT	\N	PRESENT	0
387950	387793	14103D	PARTICIPANT	\N	PRESENT	0
387951	387793	04089T	PARTICIPANT	\N	PRESENT	0
387952	387793	19335Q	PARTICIPANT	\N	PRESENT	0
387953	387793	14221J	PARTICIPANT	\N	PRESENT	0
387954	387793	04070G	PARTICIPANT	\N	PRESENT	0
387955	387793	14030Q	PARTICIPANT	\N	PRESENT	0
387956	387793	01024M	PARTICIPANT	\N	PRESENT	0
387957	387793	19745F	PARTICIPANT	\N	PRESENT	0
387958	387793	08068F	PARTICIPANT	\N	PRESENT	0
362791	361550	11048N	PARTICIPANT	\N	PRESENT	0
362792	361550	89017R	PARTICIPANT	\N	PRESENT	0
362799	361550	19741B	PARTICIPANT	\N	PRESENT	0
362800	361550	14253S	PARTICIPANT	\N	PRESENT	0
362801	361550	19545Y	PARTICIPANT	\N	PRESENT	0
362802	361550	08010L	PARTICIPANT	\N	PRESENT	0
362810	361170	19768N	PARTICIPANT	\N	PRESENT	0
362811	361170	19515S	PARTICIPANT	\N	PRESENT	0
362812	361170	19782L	PARTICIPANT	\N	PRESENT	0
362813	361170	14357A	PARTICIPANT	\N	PRESENT	0
362814	361170	19441R	PARTICIPANT	\N	PRESENT	0
362815	361170	19413M	PARTICIPANT	\N	PRESENT	0
362816	361170	14081Q	PARTICIPANT	\N	PRESENT	0
362817	361170	80013X	PARTICIPANT	\N	PRESENT	0
362818	361170	08021P	PARTICIPANT	\N	PRESENT	0
362819	361170	19631V	PARTICIPANT	\N	PRESENT	0
362820	361170	11099A	PARTICIPANT	\N	PRESENT	0
362821	361170	08068F	PARTICIPANT	\N	PRESENT	0
362822	361170	04049K	PARTICIPANT	\N	PRESENT	0
362823	361170	19705W	PARTICIPANT	\N	PRESENT	0
362824	361170	08015R	PARTICIPANT	\N	PRESENT	0
362825	361170	08019V	PARTICIPANT	\N	PRESENT	0
362826	361170	14197C	PARTICIPANT	\N	PRESENT	0
362827	361170	19369B	PARTICIPANT	\N	PRESENT	0
362828	361170	19511N	PARTICIPANT	\N	PRESENT	0
362829	361170	08028W	PARTICIPANT	\N	PRESENT	0
362830	361170	19563B	PARTICIPANT	\N	PRESENT	0
362831	361170	14265W	PARTICIPANT	\N	PRESENT	0
362832	361170	14135M	PARTICIPANT	\N	PRESENT	0
362833	361170	19467C	PARTICIPANT	\N	PRESENT	0
362834	361170	14187A	PARTICIPANT	\N	PRESENT	0
362835	361170	08062Y	PARTICIPANT	\N	PRESENT	0
362836	361170	19695N	PARTICIPANT	\N	PRESENT	0
362837	361170	11090Q	PRESIDENT	0	PRESENT	0
362838	361170	14033T	PARTICIPANT	\N	PRESENT	0
362839	361170	01025N	PARTICIPANT	\N	PRESENT	0
362840	361170	19269X	PARTICIPANT	\N	PRESENT	0
362841	361170	14205J	PARTICIPANT	\N	PRESENT	0
362842	361170	11056N	PARTICIPANT	\N	PRESENT	0
362843	361170	04088S	PARTICIPANT	\N	PRESENT	0
362844	361170	04089T	PARTICIPANT	\N	PRESENT	0
362845	361170	14105F	PARTICIPANT	\N	PRESENT	0
362846	361170	14115H	PARTICIPANT	\N	PRESENT	0
362847	361170	19507S	PARTICIPANT	\N	PRESENT	0
362848	361170	14207L	PARTICIPANT	\N	PRESENT	0
362849	361170	19747H	PARTICIPANT	\N	PRESENT	0
362850	361170	04043D	PARTICIPANT	\N	PRESENT	0
362851	361170	17589D	PARTICIPANT	\N	PRESENT	0
362852	361170	14257W	PARTICIPANT	\N	PRESENT	0
362853	361170	08038Y	PARTICIPANT	\N	EXCUSE	0
362854	361170	19295A	PARTICIPANT	\N	EXCUSE	0
362855	361170	11081P	PARTICIPANT	\N	EXCUSE	0
362856	361170	14109K	PARTICIPANT	\N	PRESENT	0
362871	360657	19697Q	PARTICIPANT	\N	PRESENT	0
362872	360657	11067R	PARTICIPANT	\N	PRESENT	0
362873	360657	19565D	PARTICIPANT	\N	PRESENT	0
362874	360657	14355X	PARTICIPANT	\N	PRESENT	0
362875	360657	19798U	PARTICIPANT	\N	PRESENT	0
362876	360657	19569H	PARTICIPANT	\N	PRESENT	0
362877	360657	11097X	PARTICIPANT	\N	PRESENT	0
362878	360657	19415P	PARTICIPANT	\N	PRESENT	0
362879	360657	14223L	PARTICIPANT	\N	PRESENT	0
362880	360657	04045F	PARTICIPANT	\N	PRESENT	0
362881	360657	14026U	PARTICIPANT	\N	PRESENT	0
362882	360657	14227Q	PARTICIPANT	\N	PRESENT	0
362883	360657	17779H	PARTICIPANT	\N	PRESENT	0
362884	360657	19703U	PARTICIPANT	\N	PRESENT	0
362885	360657	19553Y	PARTICIPANT	\N	PRESENT	0
362886	360657	11031D	PARTICIPANT	\N	PRESENT	0
362887	360657	14239U	PARTICIPANT	\N	PRESENT	0
362888	360657	14281W	PARTICIPANT	\N	PRESENT	0
362889	360657	14087W	PARTICIPANT	\N	PRESENT	0
362890	360657	19679N	PARTICIPANT	\N	PRESENT	0
362891	360657	14042U	PARTICIPANT	\N	PRESENT	0
362892	360657	14195A	PARTICIPANT	\N	PRESENT	0
362893	360657	19575F	PARTICIPANT	\N	PRESENT	0
362894	360657	08048B	PARTICIPANT	\N	PRESENT	0
362895	360657	19367Y	PARTICIPANT	\N	PRESENT	0
362896	360657	14213J	PARTICIPANT	\N	PRESENT	0
362897	360657	14261S	PARTICIPANT	\N	PRESENT	0
362898	360657	19683J	PARTICIPANT	\N	PRESENT	0
362899	360657	98024R	PARTICIPANT	\N	PRESENT	0
362900	360657	19527W	PARTICIPANT	\N	PRESENT	0
362901	360657	01034P	PARTICIPANT	\N	PRESENT	0
362902	360657	04092N	PRESIDENT	0	PRESENT	0
362903	360657	11045K	PARTICIPANT	\N	PRESENT	0
362904	360657	08052W	PARTICIPANT	\N	PRESENT	0
362905	360657	19663E	PARTICIPANT	\N	PRESENT	0
362906	360657	19301E	PARTICIPANT	\N	PRESENT	0
362907	360657	19715Y	PARTICIPANT	\N	PRESENT	0
362908	360657	19691J	PARTICIPANT	\N	PRESENT	0
362909	360657	19717B	PARTICIPANT	\N	PRESENT	0
362910	360657	19723Y	PARTICIPANT	\N	PRESENT	0
362911	360657	19727D	PARTICIPANT	\N	PRESENT	0
362912	360657	14119M	PARTICIPANT	\N	PRESENT	0
362913	360657	11103C	PARTICIPANT	\N	PRESENT	0
362914	360657	14071N	PARTICIPANT	\N	PRESENT	0
362915	360657	19577H	PARTICIPANT	\N	PRESENT	0
362916	360657	19760E	PARTICIPANT	\N	PRESENT	0
362917	360657	08041T	PARTICIPANT	\N	EXCUSE	0
362918	360657	14217N	PARTICIPANT	\N	PRESENT	0
362919	360657	19521Q	PARTICIPANT	\N	PRESENT	0
362978	345233	04059M	PARTICIPANT	\N	PRESENT	0
362979	345233	19681G	PARTICIPANT	\N	PRESENT	0
362980	345233	19629C	PARTICIPANT	\N	PRESENT	0
362981	345233	14231L	PARTICIPANT	\N	PRESENT	0
362982	345233	14031R	PARTICIPANT	\N	PRESENT	0
362983	345233	08060W	PARTICIPANT	\N	PRESENT	0
362984	345233	14211G	PARTICIPANT	\N	PRESENT	0
362985	345233	19703U	PARTICIPANT	\N	PRESENT	0
362986	345233	14257W	PARTICIPANT	\N	PRESENT	0
362987	345233	08055A	PARTICIPANT	\N	PRESENT	0
362988	345233	19525U	PARTICIPANT	\N	PRESENT	0
362989	345233	19794Q	PARTICIPANT	\N	PRESENT	0
362990	345233	11043H	PARTICIPANT	\N	PRESENT	0
362991	345233	80013X	PARTICIPANT	\N	PRESENT	0
362992	345233	19599P	PARTICIPANT	\N	PRESENT	0
362993	345233	14087W	PARTICIPANT	\N	PRESENT	0
362994	345233	01060R	PARTICIPANT	\N	PRESENT	0
362995	345233	19503N	PARTICIPANT	\N	PRESENT	0
362996	345233	19593H	PARTICIPANT	\N	PRESENT	0
362997	345233	04085P	PARTICIPANT	\N	PRESENT	0
362998	345233	08009T	PARTICIPANT	\N	PRESENT	0
362999	345233	14051J	PARTICIPANT	\N	PRESENT	0
363000	345233	19489J	PARTICIPANT	\N	PRESENT	0
363001	345233	19637C	PARTICIPANT	\N	PRESENT	0
363002	345233	19349W	PARTICIPANT	\N	PRESENT	0
363003	345233	80027E	PARTICIPANT	\N	PRESENT	0
363004	345233	19347U	PARTICIPANT	\N	PRESENT	0
363005	345233	14089Y	PARTICIPANT	\N	PRESENT	0
363006	345233	19737F	PARTICIPANT	\N	PRESENT	0
363007	345233	04018C	PARTICIPANT	\N	PRESENT	0
363008	345233	19551W	PARTICIPANT	\N	PRESENT	0
363009	345233	08068F	PARTICIPANT	\N	PRESENT	0
363010	345233	19749K	PARTICIPANT	\N	PRESENT	0
363011	345233	19387D	PARTICIPANT	\N	PRESENT	0
363013	345233	19335Q	PARTICIPANT	\N	PRESENT	0
363014	345233	19659J	PARTICIPANT	\N	PRESENT	0
363015	345233	04088S	PARTICIPANT	\N	PRESENT	0
363016	345233	14033T	PARTICIPANT	\N	PRESENT	0
363017	345233	19415P	PARTICIPANT	\N	PRESENT	0
363018	345233	19467C	PARTICIPANT	\N	PRESENT	0
363019	345233	14029X	PARTICIPANT	\N	PRESENT	0
363020	345233	14041T	PARTICIPANT	\N	PRESENT	0
363021	345233	19447X	PARTICIPANT	\N	PRESENT	0
363022	345233	08048B	PARTICIPANT	\N	PRESENT	0
363023	345233	14265W	PARTICIPANT	\N	PRESENT	0
363024	345233	14147R	PARTICIPANT	\N	PRESENT	0
363025	345233	11048N	PARTICIPANT	\N	PRESENT	0
363026	345233	08020N	PARTICIPANT	\N	PRESENT	0
363027	345233	19782L	PARTICIPANT	\N	PRESENT	0
363028	345233	11065P	PARTICIPANT	\N	PRESENT	0
363029	345233	19695N	PARTICIPANT	\N	PRESENT	0
363030	345233	14223L	PARTICIPANT	\N	PRESENT	0
363031	345233	19515S	PARTICIPANT	\N	PRESENT	0
363032	345233	19301E	PARTICIPANT	\N	PRESENT	0
363033	345233	19383Y	PARTICIPANT	\N	PRESENT	0
363034	345233	11067R	PARTICIPANT	\N	PRESENT	0
363035	345233	14109K	PARTICIPANT	\N	PRESENT	0
363036	345233	14065Q	PARTICIPANT	\N	PRESENT	0
363037	345233	14225N	PARTICIPANT	\N	PRESENT	0
363038	345233	02002K	PARTICIPANT	\N	PRESENT	0
363039	345233	14197C	PARTICIPANT	\N	PRESENT	0
363040	345233	19631V	PARTICIPANT	\N	PRESENT	0
363041	345233	19253P	PARTICIPANT	\N	PRESENT	0
363042	345233	19479G	PARTICIPANT	\N	PRESENT	0
363043	345233	14219Q	PARTICIPANT	\N	PRESENT	0
363044	345233	14249W	PARTICIPANT	\N	PRESENT	0
377379	375455	11103C	PARTICIPANT	\N	PRESENT	0
377380	375455	19577H	PARTICIPANT	\N	PRESENT	0
377381	375455	19760E	PARTICIPANT	\N	PRESENT	0
377382	375455	08041T	PARTICIPANT	\N	EXCUSE	0
377383	375455	11097X	PARTICIPANT	\N	PRESENT	0
377384	375455	14219Q	PARTICIPANT	\N	PRESENT	0
377385	375455	14281W	PARTICIPANT	\N	PRESENT	0
377386	375455	19527W	PARTICIPANT	\N	PRESENT	0
377394	371474	19581D	PARTICIPANT	\N	PRESENT	0
377395	371474	19531S	PARTICIPANT	\N	PRESENT	0
377397	371474	08055A	PARTICIPANT	\N	PRESENT	0
377398	371474	08060W	PARTICIPANT	\N	PRESENT	0
377399	371474	08035V	PARTICIPANT	\N	PRESENT	0
377400	375455	19565D	PARTICIPANT	\N	PRESENT	0
377401	375455	14223L	PARTICIPANT	\N	PRESENT	0
377402	375455	19703U	PARTICIPANT	\N	PRESENT	0
377403	375455	14217N	PARTICIPANT	\N	PRESENT	0
377404	375455	19301E	PARTICIPANT	\N	PRESENT	0
377405	375455	19715Y	PARTICIPANT	\N	PRESENT	0
377406	375455	14071N	PARTICIPANT	\N	PRESENT	0
377407	375455	19657G	PARTICIPANT	\N	PRESENT	0
377408	371474	10015M	PARTICIPANT	\N	PRESENT	0
377409	371474	11056N	PARTICIPANT	\N	PRESENT	0
377410	371474	01048V	PARTICIPANT	\N	PRESENT	0
377411	371474	19719D	PARTICIPANT	\N	PRESENT	0
377416	376798	14103D	PARTICIPANT	\N	PRESENT	0
377417	371474	08053X	PARTICIPANT	\N	PRESENT	0
377418	371474	14083S	PARTICIPANT	\N	PRESENT	0
377419	371474	19713W	PARTICIPANT	\N	PRESENT	0
377442	371474	11067R	PARTICIPANT	\N	PRESENT	0
377443	371474	14065Q	PARTICIPANT	\N	PRESENT	0
377565	371475	19621T	PARTICIPANT	\N	PRESENT	0
377566	371475	19593H	PARTICIPANT	\N	PRESENT	0
377567	371475	19758L	PARTICIPANT	\N	PRESENT	0
377568	371475	11067R	PARTICIPANT	\N	PRESENT	0
377569	371475	08053X	PARTICIPANT	\N	PRESENT	0
377570	371475	19503N	PARTICIPANT	\N	PRESENT	0
377571	371475	19673G	PARTICIPANT	\N	PRESENT	0
377572	371475	08017T	PARTICIPANT	\N	PRESENT	0
377573	371475	08043V	PARTICIPANT	\N	PRESENT	0
377574	371475	14109K	PARTICIPANT	\N	PRESENT	0
377575	371475	14229S	PARTICIPANT	\N	PRESENT	0
377576	371475	19349W	PARTICIPANT	\N	PRESENT	0
377577	371475	04045F	PARTICIPANT	\N	PRESENT	0
377578	371475	19782L	PARTICIPANT	\N	PRESENT	0
377579	371475	98005N	PARTICIPANT	\N	PRESENT	0
377580	371475	19553Y	PARTICIPANT	\N	PRESENT	0
377581	371475	04057K	PARTICIPANT	\N	PRESENT	0
377582	371475	14195A	PARTICIPANT	\N	PRESENT	0
377583	371475	14039A	PARTICIPANT	\N	PRESENT	0
377584	371475	08056B	PARTICIPANT	\N	PRESENT	0
377585	371475	14042U	PARTICIPANT	\N	PRESENT	0
377586	371475	19749K	PARTICIPANT	\N	PRESENT	0
377587	371475	08009T	PARTICIPANT	\N	PRESENT	0
377588	371475	19747H	PARTICIPANT	\N	PRESENT	0
377589	371475	19367Y	PARTICIPANT	\N	PRESENT	0
377590	371475	14079W	PARTICIPANT	\N	PRESENT	0
377591	371475	14061L	PARTICIPANT	\N	PRESENT	0
377592	371475	19733B	PARTICIPANT	\N	PRESENT	0
377593	371475	95030B	PARTICIPANT	\N	PRESENT	0
377594	371475	14147R	PARTICIPANT	\N	PRESENT	0
377595	371475	14265W	PARTICIPANT	\N	PRESENT	0
377596	371475	14105F	PARTICIPANT	\N	PRESENT	0
377597	371475	08019V	PARTICIPANT	\N	PRESENT	0
377598	371475	14115H	PARTICIPANT	\N	PRESENT	0
377599	371475	14157T	PARTICIPANT	\N	PRESENT	0
377600	371475	19467C	PARTICIPANT	\N	PRESENT	0
377601	371475	19447X	PARTICIPANT	\N	PRESENT	0
377602	371475	14029X	PARTICIPANT	\N	PRESENT	0
377603	371475	19703U	PARTICIPANT	\N	PRESENT	0
377604	371475	11043H	PARTICIPANT	\N	PRESENT	0
377605	371475	14123H	PARTICIPANT	\N	PRESENT	0
377606	371475	04086Q	PARTICIPANT	\N	PRESENT	0
377607	371475	14071N	PARTICIPANT	\N	PRESENT	0
377608	371475	19611R	PARTICIPANT	\N	PRESENT	0
377609	371475	19735D	PARTICIPANT	\N	PRESENT	0
377610	371475	08024S	PARTICIPANT	\N	PRESENT	0
377611	371475	19549D	PARTICIPANT	\N	PRESENT	0
377612	371475	14257W	PARTICIPANT	\N	PRESENT	0
377613	371475	19599P	PARTICIPANT	\N	PRESENT	0
377614	371475	19727D	PARTICIPANT	\N	PRESENT	0
377615	371475	14235Q	PARTICIPANT	\N	PRESENT	0
377616	371475	14053L	PARTICIPANT	\N	PRESENT	0
377617	371475	19798U	PARTICIPANT	\N	PRESENT	0
377618	371475	19335Q	PARTICIPANT	\N	PRESENT	0
377619	371475	14241N	PARTICIPANT	\N	PRESENT	0
377620	371475	08031R	PARTICIPANT	\N	PRESENT	0
377621	371475	19253P	PARTICIPANT	\N	PRESENT	0
377622	371475	08039A	PARTICIPANT	\N	PRESENT	0
377623	371475	14231L	PARTICIPANT	\N	PRESENT	0
377624	371475	14215L	PARTICIPANT	\N	PRESENT	0
377625	371475	19573D	PARTICIPANT	\N	PRESENT	0
377626	371475	97011G	PARTICIPANT	\N	PRESENT	0
377627	371475	14081Q	PARTICIPANT	\N	PRESENT	0
377628	371475	19551W	PARTICIPANT	\N	PRESENT	0
377629	371475	17589D	PARTICIPANT	\N	PRESENT	0
377630	371475	19713W	PARTICIPANT	\N	PRESENT	0
377631	371475	11109J	PARTICIPANT	\N	PRESENT	0
377632	371475	14111D	PARTICIPANT	\N	PRESENT	0
377633	371475	17637T	PARTICIPANT	\N	PRESENT	0
377634	371475	19719D	PARTICIPANT	\N	PRESENT	0
377635	371475	88008L	PARTICIPANT	\N	PRESENT	0
377636	371475	19383Y	PARTICIPANT	\N	PRESENT	0
377637	371475	14187A	PARTICIPANT	\N	PRESENT	0
377638	371475	19693L	PARTICIPANT	\N	PRESENT	0
377639	371475	14197C	PARTICIPANT	\N	PRESENT	0
377640	371475	19629C	PARTICIPANT	\N	PRESENT	0
377641	371475	14211G	PARTICIPANT	\N	PRESENT	0
377642	371475	19507S	PARTICIPANT	\N	PRESENT	0
377643	371475	14033T	PARTICIPANT	\N	PRESENT	0
377644	371475	19575F	PARTICIPANT	\N	PRESENT	0
377645	371475	08035V	PARTICIPANT	\N	PRESENT	0
377646	371475	14119M	PARTICIPANT	\N	PRESENT	0
377647	371475	04088S	PARTICIPANT	\N	PRESENT	0
377648	371475	14135M	PARTICIPANT	\N	PRESENT	0
377649	371475	11097X	PARTICIPANT	\N	PRESENT	0
377650	371475	08069G	PARTICIPANT	\N	PRESENT	0
377651	371475	11099A	PARTICIPANT	\N	PRESENT	0
377652	371475	14026U	PARTICIPANT	\N	PRESENT	0
377653	371475	19643A	PARTICIPANT	\N	PRESENT	0
377654	371475	14065Q	PARTICIPANT	\N	PRESENT	0
377655	371475	14217N	PARTICIPANT	\N	PRESENT	0
377656	371475	16685X	PARTICIPANT	\N	PRESENT	0
377657	371475	14249W	PARTICIPANT	\N	PRESENT	0
377658	371475	14073Q	PARTICIPANT	\N	PRESENT	0
377659	371475	08061X	PARTICIPANT	\N	PRESENT	0
377660	371475	11104D	PARTICIPANT	\N	PRESENT	0
377661	371475	11026G	PARTICIPANT	\N	PRESENT	0
377662	371475	14069U	PARTICIPANT	\N	PRESENT	0
377663	371475	19715Y	PARTICIPANT	\N	PRESENT	0
377664	371475	14281W	PARTICIPANT	\N	PRESENT	0
377665	371475	19631V	PARTICIPANT	\N	PRESENT	0
377666	371475	14083S	PARTICIPANT	\N	PRESENT	0
377667	371475	19768N	PARTICIPANT	\N	PRESENT	0
377668	371475	14357A	PARTICIPANT	\N	PRESENT	0
377669	371475	19565D	PARTICIPANT	\N	PRESENT	0
377670	371475	11077T	PARTICIPANT	\N	PRESENT	0
377671	371475	14034U	PARTICIPANT	\N	PRESENT	0
377672	371475	19760E	PARTICIPANT	\N	PRESENT	0
377673	371475	19695N	PARTICIPANT	\N	PRESENT	0
377674	371475	14089Y	PARTICIPANT	\N	PRESENT	0
377675	371475	14205J	PARTICIPANT	\N	PRESENT	0
377676	371475	14259Y	PARTICIPANT	\N	PRESENT	0
377677	371475	11056N	PARTICIPANT	\N	PRESENT	0
377678	371475	14213J	PARTICIPANT	\N	PRESENT	0
377691	377013	14327T	PARTICIPANT	\N	PRESENT	0
377692	377013	14331P	PARTICIPANT	\N	PRESENT	0
377693	377013	04071H	PARTICIPANT	\N	PRESENT	0
377694	377013	01048V	PARTICIPANT	\N	PRESENT	0
377695	377013	11053K	PARTICIPANT	\N	PRESENT	0
377563	371475	04044E	PARTICIPANT	\N	PRESENT	0
377564	371475	04070G	PARTICIPANT	\N	PRESENT	0
377696	377013	11074Q	PRESIDENT	0	PRESENT	0
377697	377013	19667J	PARTICIPANT	\N	PRESENT	0
377698	377013	19671E	PARTICIPANT	\N	PRESENT	0
377699	377013	14225N	PARTICIPANT	\N	PRESENT	0
377700	377013	88008L	PARTICIPANT	\N	PRESENT	0
377701	377013	07029T	PARTICIPANT	\N	PRESENT	0
377702	377013	14085U	PARTICIPANT	\N	PRESENT	0
377703	377013	14277B	PARTICIPANT	\N	PRESENT	0
377704	377013	07004J	PARTICIPANT	\N	PRESENT	0
377705	377013	19349W	PARTICIPANT	\N	PRESENT	0
377706	377013	14253S	PARTICIPANT	\N	PRESENT	0
377707	377013	11048N	PARTICIPANT	\N	PRESENT	0
377708	377013	19479G	PARTICIPANT	\N	PRESENT	0
377709	377013	19711U	PARTICIPANT	\N	PRESENT	0
377710	377013	08034U	PARTICIPANT	\N	PRESENT	0
377711	377013	19531S	PARTICIPANT	\N	PRESENT	0
377712	377013	08069G	PARTICIPANT	\N	PRESENT	0
366010	364580	19760E	PARTICIPANT	\N	PRESENT	0
366011	364580	08055A	PARTICIPANT	\N	PRESENT	0
366012	364580	19575F	PARTICIPANT	\N	PRESENT	0
366013	364580	14105F	PARTICIPANT	\N	PRESENT	0
366014	364580	19383Y	PARTICIPANT	\N	PRESENT	0
366015	364580	08020N	PARTICIPANT	\N	PRESENT	0
366016	364580	14207L	PARTICIPANT	\N	PRESENT	0
366017	364580	11103C	PARTICIPANT	\N	PRESENT	0
366018	364580	14329V	PARTICIPANT	\N	PRESENT	0
366019	364580	19467C	PARTICIPANT	\N	PRESENT	0
366020	364580	18083K	PARTICIPANT	\N	PRESENT	0
366021	364580	14357A	PARTICIPANT	\N	PRESENT	0
366022	364580	04089T	PARTICIPANT	\N	PRESENT	0
366025	364580	14187A	PARTICIPANT	\N	PRESENT	0
366026	364580	14033T	PARTICIPANT	\N	PRESENT	0
366027	364580	01057W	PARTICIPANT	\N	PRESENT	0
366028	364580	14179A	PARTICIPANT	\N	PRESENT	0
366029	364580	08034U	PARTICIPANT	\N	PRESENT	0
366030	364580	16685X	PARTICIPANT	\N	PRESENT	0
366031	364580	17779H	PARTICIPANT	\N	PRESENT	0
366032	364580	14221J	PARTICIPANT	\N	PRESENT	0
366033	364580	19563B	PARTICIPANT	\N	PRESENT	0
366034	364580	14265W	PARTICIPANT	\N	PRESENT	0
366035	364580	14169X	PARTICIPANT	\N	PRESENT	0
366036	364580	08061X	PARTICIPANT	\N	PRESENT	0
366037	364580	05012A	PARTICIPANT	\N	PRESENT	0
366039	364580	98050T	PARTICIPANT	\N	PRESENT	0
366040	364580	19739H	PARTICIPANT	\N	PRESENT	0
366041	364580	17583W	PARTICIPANT	\N	PRESENT	0
366042	364580	14135M	PARTICIPANT	\N	PRESENT	0
366043	364580	14331P	PARTICIPANT	\N	PRESENT	0
366044	364580	95067Q	PARTICIPANT	\N	PRESENT	0
366045	364580	14173T	PARTICIPANT	\N	PRESENT	0
369644	369643	19543W	PARTICIPANT	\N	PRESENT	0
369645	369643	19489J	PARTICIPANT	\N	PRESENT	0
369647	369646	96004D	PARTICIPANT	\N	PRESENT	0
369648	369646	01057W	PARTICIPANT	\N	PRESENT	0
369649	369646	11074Q	PARTICIPANT	\N	PRESENT	0
369651	369650	08015R	PARTICIPANT	\N	PRESENT	0
369652	369650	14225N	PARTICIPANT	\N	PRESENT	0
369653	369650	89017R	PARTICIPANT	\N	PRESENT	0
373825	373691	14107H	PARTICIPANT	\N	EXCUSE	0
373826	373691	19399H	PARTICIPANT	\N	PRESENT	0
375452	373665	14147R	PARTICIPANT	\N	PRESENT	0
375453	373651	14147R	PARTICIPANT	\N	PRESENT	0
383610	371541	19511N	PARTICIPANT	\N	PRESENT	0
383611	371541	04033B	PARTICIPANT	\N	PRESENT	0
383612	371541	19619A	PARTICIPANT	\N	PRESENT	0
383613	371541	11101A	PARTICIPANT	\N	PRESENT	0
383614	371541	19551W	PARTICIPANT	\N	PRESENT	0
383615	371541	19721W	PARTICIPANT	\N	PRESENT	0
383616	371541	98024R	PARTICIPANT	\N	PRESENT	0
383617	371541	19699S	PARTICIPANT	\N	PRESENT	0
383618	371541	04047H	PARTICIPANT	\N	PRESENT	0
383619	371541	19737F	PARTICIPANT	\N	PRESENT	0
383620	371541	19569H	PARTICIPANT	\N	PRESENT	0
383621	371541	04092N	PARTICIPANT	\N	PRESENT	0
383622	371541	14042U	PARTICIPANT	\N	PRESENT	0
383623	371541	19479G	PARTICIPANT	\N	PRESENT	0
383624	371541	19441R	PARTICIPANT	\N	PRESENT	0
383625	371541	14026U	PARTICIPANT	\N	PRESENT	0
383626	371541	14275Y	PARTICIPANT	\N	PRESENT	0
383627	371541	14267Y	PARTICIPANT	\N	PRESENT	0
383628	371541	95030B	PARTICIPANT	\N	PRESENT	0
383629	371541	14103D	PARTICIPANT	\N	PRESENT	0
383630	371541	04044E	PARTICIPANT	\N	PRESENT	0
383631	371541	19739H	PARTICIPANT	\N	PRESENT	0
383632	371541	11012A	PARTICIPANT	\N	PRESENT	0
383633	371541	14187A	PARTICIPANT	\N	PRESENT	0
383634	371541	14073Q	PARTICIPANT	\N	PRESENT	0
383635	371541	19749K	PARTICIPANT	\N	PRESENT	0
383636	371541	14205J	PARTICIPANT	\N	PRESENT	0
383637	371541	19521Q	PARTICIPANT	\N	PRESENT	0
383638	371541	07004J	PARTICIPANT	\N	PRESENT	0
383639	371541	14255U	PARTICIPANT	\N	PRESENT	0
383640	371541	11097X	PARTICIPANT	\N	PRESENT	0
383641	371541	11085T	PARTICIPANT	\N	PRESENT	0
383642	371541	19577H	PARTICIPANT	\N	PRESENT	0
383643	371541	04040A	PARTICIPANT	\N	PRESENT	0
383644	371541	19421M	PARTICIPANT	\N	PRESENT	0
383645	371541	14085U	PARTICIPANT	\N	PRESENT	0
383646	371541	04070G	PARTICIPANT	\N	PRESENT	0
383647	371541	14069U	PARTICIPANT	\N	PRESENT	0
383648	371541	14061L	PARTICIPANT	\N	PRESENT	0
383649	371541	01024M	PARTICIPANT	\N	PRESENT	0
383650	371541	04043D	PARTICIPANT	\N	PRESENT	0
383651	371541	14030Q	PARTICIPANT	\N	PRESENT	0
383652	371541	14249W	PARTICIPANT	\N	PRESENT	0
383653	371541	14327T	PARTICIPANT	\N	PRESENT	0
383654	371541	14053L	PARTICIPANT	\N	PRESENT	0
383655	371541	01043Q	PARTICIPANT	\N	PRESENT	0
383656	371541	14089Y	PARTICIPANT	\N	PRESENT	0
383657	371541	14087W	PARTICIPANT	\N	PRESENT	0
383658	371541	14215L	PARTICIPANT	\N	PRESENT	0
383659	371541	05012A	PARTICIPANT	\N	PRESENT	0
383660	371541	08034U	PARTICIPANT	\N	PRESENT	0
383661	371541	19533U	PARTICIPANT	\N	PRESENT	0
383662	371541	10006L	PARTICIPANT	\N	PRESENT	0
383663	371541	14231L	PARTICIPANT	\N	PRESENT	0
383664	371541	19798U	PARTICIPANT	\N	PRESENT	0
383665	371541	14193X	PARTICIPANT	\N	PRESENT	0
383666	371541	86034E	PARTICIPANT	\N	PRESENT	0
383667	371541	97011G	PARTICIPANT	\N	PRESENT	0
383670	371541	11103C	PARTICIPANT	\N	PRESENT	0
383672	371541	07033P	PARTICIPANT	\N	PRESENT	0
383673	371541	14217N	PARTICIPANT	\N	PRESENT	0
383674	371541	14331P	PARTICIPANT	\N	PRESENT	0
383675	371541	19671E	PARTICIPANT	\N	PRESENT	0
383676	371541	19733B	PARTICIPANT	\N	PRESENT	0
383677	371541	14079W	PARTICIPANT	\N	PRESENT	0
383678	371541	19581D	PARTICIPANT	\N	PRESENT	0
383679	371541	19747H	PARTICIPANT	\N	PRESENT	0
383680	371541	14123H	PARTICIPANT	\N	PRESENT	0
383681	371541	14329V	PARTICIPANT	\N	PRESENT	0
383682	371541	14357A	PARTICIPANT	\N	PRESENT	0
383683	371541	19675J	PARTICIPANT	\N	PRESENT	0
383684	371541	19762G	PARTICIPANT	\N	PRESENT	0
383685	371541	19383Y	PARTICIPANT	\N	PRESENT	0
383608	371541	19611R	PARTICIPANT	\N	PRESENT	0
383609	371541	19705W	PARTICIPANT	\N	PRESENT	0
383686	371541	04018C	PARTICIPANT	\N	PRESENT	0
383687	371541	19701S	PARTICIPANT	\N	PRESENT	0
383688	371541	19621T	PARTICIPANT	\N	PRESENT	0
383689	371541	98050T	PARTICIPANT	\N	PRESENT	0
383690	371541	14059S	PARTICIPANT	\N	PRESENT	0
383691	371541	19251M	PARTICIPANT	\N	PRESENT	0
383692	371541	19575F	PARTICIPANT	\N	PRESENT	0
383693	371541	14195A	PARTICIPANT	\N	PRESENT	0
383694	371541	19367Y	PARTICIPANT	\N	PRESENT	0
383695	371541	14135M	PARTICIPANT	\N	PRESENT	0
383696	371541	19741B	PARTICIPANT	\N	PRESENT	0
383697	371541	19725B	PARTICIPANT	\N	PRESENT	0
383698	371541	19735D	PARTICIPANT	\N	PRESENT	0
383699	371541	19745F	PARTICIPANT	\N	PRESENT	0
383700	371541	14173T	PARTICIPANT	\N	PRESENT	0
383701	371541	14034U	PARTICIPANT	\N	PRESENT	0
383702	371541	80013X	PARTICIPANT	\N	PRESENT	0
383703	371541	11033F	PARTICIPANT	\N	PRESENT	0
383704	371541	14219Q	PARTICIPANT	\N	PRESENT	0
383705	371541	02002K	PARTICIPANT	\N	PRESENT	0
383706	371541	04034C	PARTICIPANT	\N	PRESENT	0
388409	377975	14329V	PARTICIPANT	\N	PRESENT	0
388410	377975	04044E	PARTICIPANT	\N	PRESENT	0
388411	377975	14053L	PARTICIPANT	\N	PRESENT	0
388412	377975	14215L	PARTICIPANT	\N	PRESENT	0
388413	377975	19383Y	PARTICIPANT	\N	PRESENT	0
388414	377975	19762G	PARTICIPANT	\N	PRESENT	0
388415	377975	11048N	PARTICIPANT	\N	PRESENT	0
388416	377975	11010L	PARTICIPANT	\N	PRESENT	0
388417	377975	14033T	PARTICIPANT	\N	PRESENT	0
388418	377975	19701S	PARTICIPANT	\N	PRESENT	0
388419	377975	95041E	PARTICIPANT	\N	PRESENT	0
388420	377975	14061L	PARTICIPANT	\N	PRESENT	0
388421	377975	14059S	PARTICIPANT	\N	PRESENT	0
388422	377975	04092N	PARTICIPANT	\N	PRESENT	0
388423	377975	08020N	PARTICIPANT	\N	PRESENT	0
388424	377975	98024R	PARTICIPANT	\N	PRESENT	0
388425	377975	04008A	PARTICIPANT	\N	PRESENT	0
388426	377975	19421M	PARTICIPANT	\N	PRESENT	0
388427	377975	19671E	PARTICIPANT	\N	PRESENT	0
388428	377975	97011G	PARTICIPANT	\N	PRESENT	0
388429	377975	04088S	PARTICIPANT	\N	PRESENT	0
388430	377975	18083K	PARTICIPANT	\N	PRESENT	0
388431	377975	19687N	PARTICIPANT	\N	PRESENT	0
388432	377975	19631V	PARTICIPANT	\N	PRESENT	0
388433	377975	11041F	PARTICIPANT	\N	PRESENT	0
388434	377975	95067Q	PARTICIPANT	\N	PRESENT	0
388435	377975	14257W	PARTICIPANT	\N	PRESENT	0
388436	377975	19585H	PARTICIPANT	\N	PRESENT	0
388437	377975	11104D	PARTICIPANT	\N	PRESENT	0
388438	377975	19709B	PARTICIPANT	\N	PRESENT	0
388439	377975	19699S	PARTICIPANT	\N	PRESENT	0
388440	377975	19611R	PARTICIPANT	\N	PRESENT	0
388441	377975	14133K	PARTICIPANT	\N	PRESENT	0
388442	377975	14111D	PARTICIPANT	\N	PRESENT	0
388443	377975	14225N	PARTICIPANT	\N	PRESENT	0
388444	377975	08038Y	PARTICIPANT	\N	PRESENT	0
388445	377975	11101A	PARTICIPANT	\N	PRESENT	0
388446	377975	14105F	PARTICIPANT	\N	PRESENT	0
388447	377975	08015R	PARTICIPANT	\N	PRESENT	0
388448	377975	14193X	PARTICIPANT	\N	PRESENT	0
388449	377975	19749K	PARTICIPANT	\N	PRESENT	0
388450	377975	14237S	PARTICIPANT	\N	PRESENT	0
388451	377975	14331P	PARTICIPANT	\N	PRESENT	0
388452	377975	19673G	PARTICIPANT	\N	PRESENT	0
388453	377975	11103C	PARTICIPANT	\N	PRESENT	0
388454	377975	19415P	PARTICIPANT	\N	PRESENT	0
388455	377975	19798U	PARTICIPANT	\N	PRESENT	0
388456	377975	19663E	PARTICIPANT	\N	PRESENT	0
388457	377975	19657G	PARTICIPANT	\N	PRESENT	0
388458	377975	08048B	PARTICIPANT	\N	PRESENT	0
388459	377975	19441R	PARTICIPANT	\N	PRESENT	0
388460	377975	08058D	PARTICIPANT	\N	PRESENT	0
388461	377975	19703U	PARTICIPANT	\N	PRESENT	0
388462	377975	11080N	PARTICIPANT	\N	PRESENT	0
388463	377975	14213J	PARTICIPANT	\N	PRESENT	0
388464	377975	19577H	PARTICIPANT	\N	PRESENT	0
388465	377975	19413M	PARTICIPANT	\N	PRESENT	0
388466	377975	14065Q	PARTICIPANT	\N	PRESENT	0
388467	377975	92040Q	PARTICIPANT	\N	PRESENT	0
388468	377975	19689Q	PARTICIPANT	\N	PRESENT	0
388469	377975	14355X	PARTICIPANT	\N	PRESENT	0
388470	377975	11097X	PARTICIPANT	\N	PRESENT	0
388471	377975	10006L	PARTICIPANT	\N	PRESENT	0
388472	377975	19367Y	PARTICIPANT	\N	PRESENT	0
388473	377975	01028R	PARTICIPANT	\N	PRESENT	0
388474	377975	14097Y	PARTICIPANT	\N	PRESENT	0
388475	377975	17583W	PARTICIPANT	\N	PRESENT	0
388476	377975	08055A	PARTICIPANT	\N	PRESENT	0
388477	377975	19549D	PARTICIPANT	\N	PRESENT	0
388478	377975	14083S	PARTICIPANT	\N	PRESENT	0
388479	377975	11077T	PARTICIPANT	\N	PRESENT	0
388480	377975	04043D	PARTICIPANT	\N	PRESENT	0
388481	377975	19621T	PARTICIPANT	\N	PRESENT	0
388482	377975	14251Q	PARTICIPANT	\N	PRESENT	0
388483	377975	19545Y	PARTICIPANT	\N	PRESENT	0
388484	377975	19319Q	PARTICIPANT	\N	PRESENT	0
388485	377975	14249W	PARTICIPANT	\N	PRESENT	0
388486	377975	14071N	PARTICIPANT	\N	PRESENT	0
388487	377975	14087W	PARTICIPANT	\N	PRESENT	0
388488	377975	11065P	PARTICIPANT	\N	PRESENT	0
388489	377975	07004J	PARTICIPANT	\N	PRESENT	0
388490	377975	11056N	PARTICIPANT	\N	PRESENT	0
388491	377975	08060W	PARTICIPANT	\N	PRESENT	0
388511	385092	19725B	PRESIDENT	0	PRESENT	0
388493	377975	19581D	PARTICIPANT	\N	PRESENT	0
388494	377975	08011M	PARTICIPANT	\N	PRESENT	0
388495	377975	95062K	PARTICIPANT	\N	PRESENT	0
388496	377975	04071H	PARTICIPANT	\N	PRESENT	0
388497	377975	19643A	PARTICIPANT	\N	PRESENT	0
388498	377975	19515S	PARTICIPANT	\N	PRESENT	0
388499	377975	14034U	PARTICIPANT	\N	PRESENT	0
388500	377975	89017R	PARTICIPANT	\N	PRESENT	0
388501	377975	08009T	PARTICIPANT	\N	PRESENT	0
388502	377975	19369B	PARTICIPANT	\N	PRESENT	0
388503	377975	08012N	PARTICIPANT	\N	PRESENT	0
388509	377975	05008E	PARTICIPANT	\N	PRESENT	0
388510	377975	19719D	PARTICIPANT	\N	PRESENT	0
388512	385092	04057K	PARTICIPANT	\N	PRESENT	0
388514	385092	14071N	PARTICIPANT	\N	PRESENT	0
388826	388515	14235Q	PARTICIPANT	\N	PRESENT	0
388827	388515	19758L	PARTICIPANT	\N	PRESENT	0
388828	388515	19760E	PARTICIPANT	\N	PRESENT	0
388829	388515	11031D	PARTICIPANT	\N	PRESENT	0
388830	388515	19565D	PARTICIPANT	\N	PRESENT	0
388831	388515	17779H	PARTICIPANT	\N	PRESENT	0
388832	388515	19715Y	PARTICIPANT	\N	PRESENT	0
388833	388515	19295A	PARTICIPANT	\N	PRESENT	0
388834	388515	11067R	PARTICIPANT	\N	PRESENT	0
388835	388515	14085U	PARTICIPANT	\N	PRESENT	0
388836	388515	14197C	PARTICIPANT	\N	PRESENT	0
388837	388515	14151M	PARTICIPANT	\N	PRESENT	0
388838	388515	19711U	PARTICIPANT	\N	PRESENT	0
388839	388515	01058X	PARTICIPANT	\N	PRESENT	0
388840	388515	01028R	PARTICIPANT	\N	PRESENT	0
388842	388515	08055A	PARTICIPANT	\N	PRESENT	0
388843	388515	80013X	PARTICIPANT	\N	PRESENT	0
388844	388515	15447F	PARTICIPANT	\N	PRESENT	0
388845	388515	11104D	PARTICIPANT	\N	PRESENT	0
388846	388515	19515S	PARTICIPANT	\N	PRESENT	0
388847	388515	19766L	PARTICIPANT	\N	PRESENT	0
388848	388515	08043V	PARTICIPANT	\N	PRESENT	0
388849	388515	14065Q	PARTICIPANT	\N	PRESENT	0
388850	388515	14028W	PARTICIPANT	\N	PRESENT	0
388851	388515	19649G	PARTICIPANT	\N	PRESENT	0
388852	388515	14001X	PARTICIPANT	\N	PRESENT	0
388853	388515	01057W	PARTICIPANT	\N	PRESENT	0
388854	388515	87003B	PARTICIPANT	\N	PRESENT	0
388855	388515	14223L	PARTICIPANT	\N	PRESENT	0
388856	388515	19333N	PARTICIPANT	\N	PRESENT	0
388857	388515	08014Q	PARTICIPANT	\N	PRESENT	0
388858	388515	14157T	PARTICIPANT	\N	PRESENT	0
388859	388515	14063N	PARTICIPANT	\N	PRESENT	0
388860	388515	14249W	PARTICIPANT	\N	PRESENT	0
388861	388515	14109K	PARTICIPANT	\N	PRESENT	0
388865	388515	14257W	PARTICIPANT	\N	PRESENT	0
388863	388515	14097Y	PARTICIPANT	\N	PRESENT	0
388864	388515	14199E	PARTICIPANT	\N	PRESENT	0
388866	388515	11048N	PARTICIPANT	\N	PRESENT	0
388867	388515	08010L	PARTICIPANT	\N	PRESENT	0
388868	388515	19703U	PARTICIPANT	\N	PRESENT	0
388869	388515	95063L	PARTICIPANT	\N	PRESENT	0
388870	388515	98029W	PARTICIPANT	\N	PRESENT	0
388871	388515	92040Q	PARTICIPANT	\N	PRESENT	0
388872	388515	04045F	PARTICIPANT	\N	PRESENT	0
388873	388515	14133K	PARTICIPANT	\N	PRESENT	0
388874	388515	95037J	PARTICIPANT	\N	PRESENT	0
388875	388515	98024R	PARTICIPANT	\N	PRESENT	0
388876	388515	08061X	PARTICIPANT	\N	PRESENT	0
388877	388515	19349W	PARTICIPANT	\N	PRESENT	0
388878	388515	14115H	PARTICIPANT	\N	PRESENT	0
388879	388515	19794Q	PARTICIPANT	\N	PRESENT	0
388880	388515	18083K	PARTICIPANT	\N	PRESENT	0
388881	388515	19415P	PARTICIPANT	\N	PRESENT	0
388882	388515	19399H	PARTICIPANT	\N	PRESENT	0
388883	388515	08047A	PARTICIPANT	\N	PRESENT	0
388884	388515	08053X	PARTICIPANT	\N	PRESENT	0
388885	388515	19693L	PARTICIPANT	\N	PRESENT	0
388886	388515	08058D	PARTICIPANT	\N	PRESENT	0
388887	388515	14029X	PARTICIPANT	\N	PRESENT	0
388888	388515	11045K	PARTICIPANT	\N	PRESENT	0
388889	388515	04088S	PARTICIPANT	\N	PRESENT	0
388890	388515	19549D	PARTICIPANT	\N	PRESENT	0
388891	388515	14041T	PARTICIPANT	\N	PRESENT	0
388892	388515	14081Q	PARTICIPANT	\N	PRESENT	0
388893	388515	97011G	PARTICIPANT	\N	PRESENT	0
388894	388515	07029T	PARTICIPANT	\N	PRESENT	0
388895	388515	19657G	PARTICIPANT	\N	PRESENT	0
363045	345233	19739H	PARTICIPANT	\N	PRESENT	0
363046	345233	14081Q	PARTICIPANT	\N	PRESENT	0
363047	345233	98050T	PARTICIPANT	\N	PRESENT	0
363048	345233	12016W	PARTICIPANT	\N	PRESENT	0
363049	345233	14213J	PARTICIPANT	\N	PRESENT	0
363050	345233	14207L	PARTICIPANT	\N	PRESENT	0
363051	345233	95030B	PARTICIPANT	\N	PRESENT	0
363052	345233	19575F	PARTICIPANT	\N	PRESENT	0
363053	345233	19679N	PARTICIPANT	\N	PRESENT	0
363054	345233	08010L	PARTICIPANT	\N	PRESENT	0
363055	345233	08015R	PARTICIPANT	\N	PRESENT	0
363056	345233	11085T	PARTICIPANT	\N	PRESENT	0
363057	345233	14038Y	PARTICIPANT	\N	PRESENT	0
363058	345233	95062K	PARTICIPANT	\N	PRESENT	0
363059	345233	11104D	PARTICIPANT	\N	PRESENT	0
363060	345233	14235Q	PARTICIPANT	\N	PRESENT	0
363061	345233	19741B	PARTICIPANT	\N	PRESENT	0
363062	345233	14073Q	PARTICIPANT	\N	PRESENT	0
363063	345233	19711U	PARTICIPANT	\N	PRESENT	0
363064	345233	11031D	PARTICIPANT	\N	PRESENT	0
363065	345233	19399H	PARTICIPANT	\N	PRESENT	0
363066	345233	14115H	PARTICIPANT	\N	PRESENT	0
363067	345233	19733B	PARTICIPANT	\N	PRESENT	0
363068	345233	14103D	PARTICIPANT	\N	PRESENT	0
363069	345233	08056B	PARTICIPANT	\N	PRESENT	0
363070	345233	11072N	PARTICIPANT	\N	PRESENT	0
363071	345233	01043Q	PARTICIPANT	\N	PRESENT	0
363072	345233	08044W	PARTICIPANT	\N	PRESENT	0
363073	345233	19367Y	PARTICIPANT	\N	PRESENT	0
363074	345233	14237S	PARTICIPANT	\N	PRESENT	0
363075	345233	08031R	PARTICIPANT	\N	PRESENT	0
363076	345233	14217N	PARTICIPANT	\N	PRESENT	0
363077	345233	08061X	PARTICIPANT	\N	PRESENT	0
363078	345233	04045F	PARTICIPANT	\N	PRESENT	0
363079	345233	14105F	PARTICIPANT	\N	PRESENT	0
363080	345233	19673G	PARTICIPANT	\N	PRESENT	0
363081	345233	19543W	PARTICIPANT	\N	PRESENT	0
363082	345233	95037J	PARTICIPANT	\N	PRESENT	0
363083	345233	19723Y	PARTICIPANT	\N	PRESENT	0
363084	345233	14034U	PARTICIPANT	\N	PRESENT	0
363085	345233	19697Q	PARTICIPANT	\N	PRESENT	0
363086	345233	19671E	PARTICIPANT	\N	PRESENT	0
363087	345233	01025N	PARTICIPANT	\N	PRESENT	0
363088	345233	99004R	PARTICIPANT	\N	PRESENT	0
363089	345233	19507S	PARTICIPANT	\N	PRESENT	0
363090	345233	08034U	PARTICIPANT	\N	PRESENT	0
363091	345233	14259Y	PARTICIPANT	\N	PRESENT	0
363092	345233	14205J	PARTICIPANT	\N	PRESENT	0
363093	345233	97011G	PARTICIPANT	\N	PRESENT	0
363094	345233	14059S	PARTICIPANT	\N	PRESENT	0
363095	345233	19545Y	PARTICIPANT	\N	PRESENT	0
363096	345233	14021P	PARTICIPANT	\N	PRESENT	0
363097	345233	19729F	PARTICIPANT	\N	PRESENT	0
363098	345233	19553Y	PARTICIPANT	\N	PRESENT	0
363099	345233	19531S	PARTICIPANT	\N	PRESENT	0
363100	345233	19667J	PARTICIPANT	\N	PRESENT	0
363101	345233	19573D	PARTICIPANT	\N	PRESENT	0
363102	345233	14169X	PARTICIPANT	\N	PRESENT	0
363103	345233	98022P	PARTICIPANT	\N	PRESENT	0
363104	345233	08024S	PARTICIPANT	\N	PRESENT	0
363105	345233	19699S	PARTICIPANT	\N	PRESENT	0
363106	345233	04034C	PARTICIPANT	\N	PRESENT	0
363107	345233	14107H	PARTICIPANT	\N	PRESENT	0
363108	345233	19687N	PARTICIPANT	\N	PRESENT	0
363109	345233	98024R	PARTICIPANT	\N	PRESENT	0
363110	345233	14083S	PARTICIPANT	\N	PRESENT	0
363111	345233	16685X	PARTICIPANT	\N	PRESENT	0
363112	345233	14069U	PARTICIPANT	\N	PRESENT	0
363113	345233	11054L	PARTICIPANT	\N	PRESENT	0
363114	345233	11077T	PARTICIPANT	\N	PRESENT	0
363115	345233	19760E	PARTICIPANT	\N	PRESENT	0
363116	345233	14135M	PARTICIPANT	\N	PRESENT	0
363117	345233	08019V	PARTICIPANT	\N	PRESENT	0
363118	345233	19583F	PARTICIPANT	\N	PRESENT	0
363119	345233	17637T	PARTICIPANT	\N	PRESENT	0
363120	345233	19701S	PARTICIPANT	\N	PRESENT	0
363136	345233	19715Y	PARTICIPANT	\N	PRESENT	0
363131	345233	19745F	PARTICIPANT	\N	PRESENT	0
363135	345233	19581D	PARTICIPANT	\N	PRESENT	0
363137	345233	19533U	PARTICIPANT	\N	PRESENT	0
363138	345233	14253S	PARTICIPANT	\N	PRESENT	0
363140	345233	04043D	PARTICIPANT	\N	PRESENT	0
363141	345233	19369B	PARTICIPANT	\N	PRESENT	0
363150	345233	88008L	PARTICIPANT	\N	PRESENT	0
363153	345233	14267Y	PARTICIPANT	\N	PRESENT	0
363154	345233	04040A	PARTICIPANT	\N	PRESENT	0
363156	345233	19333N	PARTICIPANT	\N	PRESENT	0
363157	345233	19549D	PARTICIPANT	\N	PRESENT	0
363160	345233	14187A	PARTICIPANT	\N	PRESENT	0
363163	345233	01058X	PARTICIPANT	\N	PRESENT	0
363164	345233	11012A	PARTICIPANT	\N	PRESENT	0
363911	357424	14299H	PARTICIPANT	\N	EXCUSE	0
369975	369926	14207L	PARTICIPANT	\N	PRESENT	0
369977	369926	19441R	PARTICIPANT	\N	PRESENT	0
369978	369926	19369B	PARTICIPANT	\N	PRESENT	0
369980	369926	14265W	PARTICIPANT	\N	PRESENT	0
369984	369926	19413M	PARTICIPANT	\N	PRESENT	0
369993	369926	19629C	PARTICIPANT	\N	PRESENT	0
369996	369926	19347U	PARTICIPANT	\N	PRESENT	0
370876	370800	19717B	PARTICIPANT	\N	PRESENT	0
371406	371405	14197C	PARTICIPANT	\N	PRESENT	0
371407	371405	19727D	PARTICIPANT	\N	PRESENT	0
371408	371405	14033T	PARTICIPANT	\N	PRESENT	0
371409	371405	19725B	PARTICIPANT	\N	PRESENT	0
371410	371405	19551W	PARTICIPANT	\N	PRESENT	0
371411	371405	19723Y	PARTICIPANT	\N	PRESENT	0
371412	371405	14265W	PARTICIPANT	\N	PRESENT	0
371413	371405	17583W	PARTICIPANT	\N	PRESENT	0
371414	371405	11043H	PARTICIPANT	\N	PRESENT	0
371415	371405	95067Q	PARTICIPANT	\N	PRESENT	0
371675	371674	11053K	PARTICIPANT	\N	PRESENT	0
371676	371674	14159V	PARTICIPANT	\N	PRESENT	0
376948	373666	14107H	PARTICIPANT	\N	PRESENT	0
372288	367799	04045F	PARTICIPANT	\N	EXCUSE	0
376947	373666	11065P	PARTICIPANT	\N	PRESENT	0
376970	373666	19399H	PARTICIPANT	\N	EXCUSE	0
376971	373666	19737F	PARTICIPANT	\N	PRESENT	0
376973	373666	19479G	PARTICIPANT	\N	PRESENT	0
377011	373666	19515S	PARTICIPANT	\N	PRESENT	0
377012	373666	19349W	PARTICIPANT	\N	PRESENT	0
377017	371473	11072N	PARTICIPANT	\N	PRESENT	0
377018	376985	04070G	PRESIDENT	0	PRESENT	0
377019	376985	19699S	PARTICIPANT	\N	PRESENT	0
377020	376985	19533U	PARTICIPANT	\N	PRESENT	0
377021	376985	14229S	PARTICIPANT	\N	PRESENT	0
377022	376985	14241N	PARTICIPANT	\N	PRESENT	0
377023	376985	19573D	PARTICIPANT	\N	PRESENT	0
377024	376985	14039A	PARTICIPANT	\N	PRESENT	0
377025	376985	14107H	PARTICIPANT	\N	PRESENT	0
377026	376985	08017T	PARTICIPANT	\N	PRESENT	0
377027	376985	19335Q	PARTICIPANT	\N	PRESENT	0
377028	376985	14249W	PARTICIPANT	\N	PRESENT	0
377029	376985	08039A	PARTICIPANT	\N	PRESENT	0
377030	376985	08031R	PARTICIPANT	\N	PRESENT	0
377031	376985	19593H	PARTICIPANT	\N	PRESENT	0
377032	376985	19643A	PARTICIPANT	\N	PRESENT	0
377033	376985	19611R	PARTICIPANT	\N	PRESENT	0
377034	376985	08043V	PARTICIPANT	\N	PRESENT	0
377035	376985	19693L	PARTICIPANT	\N	PRESENT	0
377036	376985	19399H	PARTICIPANT	\N	PRESENT	0
377037	376985	14030Q	PARTICIPANT	\N	PRESENT	0
377038	376985	04059M	PARTICIPANT	\N	PRESENT	0
377039	376985	19735D	PARTICIPANT	\N	PRESENT	0
377040	376985	14109K	PARTICIPANT	\N	PRESENT	0
377041	376985	14123H	PARTICIPANT	\N	PRESENT	0
377042	376985	19749K	PARTICIPANT	\N	PRESENT	0
377043	376985	04018C	PARTICIPANT	\N	PRESENT	0
377044	376985	19621T	PARTICIPANT	\N	PRESENT	0
377045	371473	17589D	PARTICIPANT	\N	PRESENT	0
377046	371473	01025N	PARTICIPANT	\N	PRESENT	0
377047	371473	19701S	PARTICIPANT	\N	PRESENT	0
377048	371473	14261S	PARTICIPANT	\N	PRESENT	0
377049	371473	08044W	PARTICIPANT	\N	PRESENT	0
377050	371473	14327T	PARTICIPANT	\N	PRESENT	0
377051	376985	14059S	PARTICIPANT	\N	PRESENT	0
377052	376985	04057K	PARTICIPANT	\N	PRESENT	0
377053	376985	08035V	PARTICIPANT	\N	PRESENT	0
377054	376985	08020N	PARTICIPANT	\N	PRESENT	0
377055	371473	14211G	PARTICIPANT	\N	PRESENT	0
377056	371473	80013X	PARTICIPANT	\N	PRESENT	0
377057	371473	19593H	PARTICIPANT	\N	PRESENT	0
377058	371473	19679N	PARTICIPANT	\N	PRESENT	0
374907	373671	04088S	PARTICIPANT	\N	PRESENT	0
374908	373671	19782L	PARTICIPANT	\N	PRESENT	0
374909	373671	19705W	PARTICIPANT	\N	PRESENT	0
374910	373671	14357A	PARTICIPANT	\N	PRESENT	0
374911	373671	08015R	PARTICIPANT	\N	PRESENT	0
374912	373671	19695N	PARTICIPANT	\N	PRESENT	0
374913	373671	11090Q	PRESIDENT	0	PRESENT	0
374914	373671	14033T	PARTICIPANT	\N	PRESENT	0
374915	373671	19747H	PARTICIPANT	\N	PRESENT	0
374916	373671	14207L	PARTICIPANT	\N	PRESENT	0
374917	373671	80013X	PARTICIPANT	\N	PRESENT	0
374918	373671	14257W	PARTICIPANT	\N	PRESENT	0
374919	373671	19467C	PARTICIPANT	\N	EXCUSE	0
374920	373671	08068F	PARTICIPANT	\N	EXCUSE	0
374921	373671	19413M	PARTICIPANT	\N	EXCUSE	0
374922	373671	14197C	PARTICIPANT	\N	EXCUSE	0
374923	373671	01025N	PARTICIPANT	\N	EXCUSE	0
374924	373671	19369B	PARTICIPANT	\N	EXCUSE	0
374925	373671	19295A	PARTICIPANT	\N	EXCUSE	0
374926	373671	11081P	PARTICIPANT	\N	EXCUSE	0
374927	373671	19631V	PARTICIPANT	\N	EXCUSE	0
374928	373671	14265W	PARTICIPANT	\N	EXCUSE	0
374929	373671	14329V	PARTICIPANT	\N	EXCUSE	0
374930	373671	08038Y	PARTICIPANT	\N	PRESENT	0
374931	373671	14081Q	PARTICIPANT	\N	PRESENT	0
374932	373671	19515S	PARTICIPANT	\N	EXCUSE	0
374938	374856	14053L	PARTICIPANT	\N	PRESENT	0
374939	374856	08045X	PARTICIPANT	\N	PRESENT	0
374940	374856	01024M	PARTICIPANT	\N	PRESENT	0
374941	374856	19543W	PARTICIPANT	\N	PRESENT	0
374942	374856	01028R	PARTICIPANT	\N	PRESENT	0
374943	374856	11033F	PARTICIPANT	\N	PRESENT	0
374944	374856	05008E	PRESIDENT	0	PRESENT	0
374945	374856	19447X	PARTICIPANT	\N	PRESENT	0
374946	374856	14231L	PARTICIPANT	\N	PRESENT	0
374947	374856	14147R	PARTICIPANT	\N	PRESENT	0
374948	374856	11085T	PARTICIPANT	\N	PRESENT	0
374949	374856	14215L	PARTICIPANT	\N	PRESENT	0
374950	374856	19762G	PARTICIPANT	\N	PRESENT	0
374951	374856	11072N	PARTICIPANT	\N	PRESENT	0
374952	374856	14089Y	PARTICIPANT	\N	PRESENT	0
374953	374856	14111D	PARTICIPANT	\N	PRESENT	0
374954	374856	04038G	PARTICIPANT	\N	PRESENT	0
374955	374856	19729F	PARTICIPANT	\N	EXCUSE	0
374956	374856	19585H	PARTICIPANT	\N	EXCUSE	0
374958	371837	19697Q	PARTICIPANT	\N	PRESENT	0
374959	371837	04092N	PRESIDENT	0	PRESENT	0
374960	371837	19565D	PARTICIPANT	\N	PRESENT	0
374961	371837	19569H	PARTICIPANT	\N	PRESENT	0
374962	371837	11097X	PARTICIPANT	\N	PRESENT	0
374963	371837	08052W	PARTICIPANT	\N	PRESENT	0
374964	371837	19717B	PARTICIPANT	\N	PRESENT	0
374965	371837	14239U	PARTICIPANT	\N	PRESENT	0
374966	371837	11031D	PARTICIPANT	\N	PRESENT	0
374967	371837	14119M	PARTICIPANT	\N	PRESENT	0
374968	371837	19679N	PARTICIPANT	\N	PRESENT	0
374969	371837	14042U	PARTICIPANT	\N	PRESENT	0
374970	371837	14195A	PARTICIPANT	\N	PRESENT	0
374971	371837	14071N	PARTICIPANT	\N	PRESENT	0
374972	371837	14217N	PARTICIPANT	\N	PRESENT	0
374973	371837	10006L	PARTICIPANT	\N	PRESENT	0
374974	371837	19683J	PARTICIPANT	\N	PRESENT	0
374975	371837	98024R	PARTICIPANT	\N	PRESENT	0
374976	371837	19703U	PARTICIPANT	\N	EXCUSE	0
374977	371837	11067R	PARTICIPANT	\N	EXCUSE	0
374978	371837	14355X	PARTICIPANT	\N	EXCUSE	0
374979	371837	19715Y	PARTICIPANT	\N	EXCUSE	0
374980	371837	04045F	PARTICIPANT	\N	EXCUSE	0
374981	371837	08041T	PARTICIPANT	\N	EXCUSE	0
374982	371837	17779H	PARTICIPANT	\N	EXCUSE	0
374983	363545	19717B	PARTICIPANT	\N	PRESENT	0
374984	363545	19569H	PARTICIPANT	\N	PRESENT	0
374985	363545	14195A	PARTICIPANT	\N	PRESENT	0
374986	363545	19683J	PARTICIPANT	\N	PRESENT	0
374987	363545	19671E	PARTICIPANT	\N	PRESENT	0
374988	363545	19697Q	PARTICIPANT	\N	PRESENT	0
374989	363545	14071N	PARTICIPANT	\N	PRESENT	0
374990	363545	19387D	PARTICIPANT	\N	PRESENT	0
374991	363545	19794Q	PARTICIPANT	\N	PRESENT	0
374992	363545	04088S	PARTICIPANT	\N	PRESENT	0
374993	363545	14042U	PARTICIPANT	\N	PRESENT	0
374994	363545	08052W	PARTICIPANT	\N	PRESENT	0
374995	363545	19760E	PARTICIPANT	\N	PRESENT	0
374996	363545	04092N	PARTICIPANT	\N	PRESENT	0
374997	363545	19585H	PARTICIPANT	\N	PRESENT	0
374998	363545	19782L	PARTICIPANT	\N	PRESENT	0
374999	363545	11031D	PARTICIPANT	\N	PRESENT	0
375000	363545	19637C	PARTICIPANT	\N	PRESENT	0
375001	363545	07029T	PARTICIPANT	\N	PRESENT	0
375002	363545	19667J	PARTICIPANT	\N	PRESENT	0
375003	363545	19679N	PARTICIPANT	\N	PRESENT	0
375004	363545	19762G	PARTICIPANT	\N	PRESENT	0
375005	363545	14217N	PARTICIPANT	\N	PRESENT	0
375006	363545	10006L	PARTICIPANT	\N	PRESENT	0
375007	363545	11097X	PARTICIPANT	\N	PRESENT	0
375008	363545	19565D	PARTICIPANT	\N	PRESENT	0
375009	363545	19301E	PARTICIPANT	\N	PRESENT	0
375010	363545	14227Q	PARTICIPANT	\N	PRESENT	0
375011	363545	14111D	PARTICIPANT	\N	PRESENT	0
375012	363545	11083R	PARTICIPANT	\N	PRESENT	0
375013	363545	14239U	PARTICIPANT	\N	PRESENT	0
375014	363545	11045K	PARTICIPANT	\N	PRESENT	0
375015	363545	19447X	PARTICIPANT	\N	PRESENT	0
375016	363545	04086Q	PARTICIPANT	\N	PRESENT	0
375017	363545	98024R	PARTICIPANT	\N	PRESENT	0
375018	363545	11040E	PARTICIPANT	\N	PRESENT	0
375019	363545	19543W	PARTICIPANT	\N	PRESENT	0
375020	363545	19651A	PARTICIPANT	\N	PRESENT	0
375021	363545	11012A	PARTICIPANT	\N	PRESENT	0
375022	363545	14147R	PARTICIPANT	\N	PRESENT	0
375023	363545	04047H	PARTICIPANT	\N	PRESENT	0
375024	363545	14033T	PARTICIPANT	\N	PRESENT	0
375025	363545	14039A	PARTICIPANT	\N	PRESENT	0
375026	363545	14081Q	PARTICIPANT	\N	PRESENT	0
375027	363545	14281W	PARTICIPANT	\N	PRESENT	0
375028	363545	14219Q	PARTICIPANT	\N	PRESENT	0
375029	363545	14179A	PARTICIPANT	\N	PRESENT	0
375030	363545	14119M	PARTICIPANT	\N	PRESENT	0
375031	363545	08015R	PARTICIPANT	\N	PRESENT	0
375032	363545	11072N	PARTICIPANT	\N	PRESENT	0
375033	363545	14053L	PARTICIPANT	\N	PRESENT	0
375034	363545	14021P	PARTICIPANT	\N	PRESENT	0
375035	363545	19741B	PARTICIPANT	\N	PRESENT	0
375036	363545	19553Y	PARTICIPANT	\N	PRESENT	0
375037	363545	17637T	PARTICIPANT	\N	PRESENT	0
375038	363545	14089Y	PARTICIPANT	\N	PRESENT	0
375039	363545	19701S	PARTICIPANT	\N	PRESENT	0
375040	363545	04034C	PARTICIPANT	\N	PRESENT	0
375041	363545	08031R	PARTICIPANT	\N	PRESENT	0
375042	363545	01024M	PARTICIPANT	\N	PRESENT	0
375043	363545	14083S	PARTICIPANT	\N	PRESENT	0
375044	363545	11033F	PARTICIPANT	\N	PRESENT	0
375045	363545	19399H	PARTICIPANT	\N	PRESENT	0
375046	363545	11090Q	PARTICIPANT	\N	PRESENT	0
375047	363545	14215L	PARTICIPANT	\N	PRESENT	0
375048	363545	14231L	PARTICIPANT	\N	PRESENT	0
375050	363545	19489J	PARTICIPANT	\N	PRESENT	0
375109	363550	11070L	PARTICIPANT	\N	PRESENT	0
375110	363550	05008E	PARTICIPANT	\N	PRESENT	0
375111	363550	95063L	PARTICIPANT	\N	PRESENT	0
375112	363550	19349W	PARTICIPANT	\N	PRESENT	0
375113	363550	14039A	PARTICIPANT	\N	PRESENT	0
375114	363550	14081Q	PARTICIPANT	\N	PRESENT	0
375115	363550	14111D	PARTICIPANT	\N	PRESENT	0
375116	363550	04038G	PARTICIPANT	\N	PRESENT	0
375117	363550	04085P	PARTICIPANT	\N	PRESENT	0
375118	363550	19695N	PARTICIPANT	\N	PRESENT	0
375119	363550	19399H	PARTICIPANT	\N	PRESENT	0
375120	363550	14231L	PARTICIPANT	\N	PRESENT	0
375121	363550	19489J	PARTICIPANT	\N	PRESENT	0
375122	363550	19782L	PARTICIPANT	\N	PRESENT	0
375123	363550	19611R	PARTICIPANT	\N	PRESENT	0
375124	363550	14357A	PARTICIPANT	\N	PRESENT	0
375125	363550	19762G	PARTICIPANT	\N	PRESENT	0
375126	363550	19701S	PARTICIPANT	\N	PRESENT	0
375127	363550	14071N	PARTICIPANT	\N	PRESENT	0
375128	363550	17637T	PARTICIPANT	\N	PRESENT	0
375129	363550	99004R	PARTICIPANT	\N	PRESENT	0
375130	363550	14215L	PARTICIPANT	\N	PRESENT	0
375131	363550	19671E	PARTICIPANT	\N	PRESENT	0
375132	363550	14065Q	PARTICIPANT	\N	PRESENT	0
375133	363550	19543W	PARTICIPANT	\N	PRESENT	0
375134	363550	19667J	PARTICIPANT	\N	PRESENT	0
375138	363550	19387D	PARTICIPANT	\N	PRESENT	0
375136	363550	08031R	PARTICIPANT	\N	PRESENT	0
375137	363550	01028R	PARTICIPANT	\N	PRESENT	0
375139	363550	14089Y	PARTICIPANT	\N	PRESENT	0
375140	363550	19503N	PARTICIPANT	\N	PRESENT	0
375141	363550	19301E	PARTICIPANT	\N	PRESENT	0
383125	383124	19525U	PARTICIPANT	\N	PRESENT	0
383126	383124	14038Y	PARTICIPANT	\N	PRESENT	0
383127	383124	02002K	PARTICIPANT	\N	PRESENT	0
383128	383124	19713W	PARTICIPANT	\N	PRESENT	0
383129	383124	19637C	PARTICIPANT	\N	PRESENT	0
383994	371542	01043Q	PARTICIPANT	\N	PRESENT	0
384077	371542	19549D	PARTICIPANT	\N	PRESENT	0
384078	371542	14241N	PARTICIPANT	\N	PRESENT	0
384079	371542	14033T	PARTICIPANT	\N	PRESENT	0
384080	371542	14107H	PARTICIPANT	\N	PRESENT	0
384081	371542	19387D	PARTICIPANT	\N	PRESENT	0
384082	371542	01060R	PARTICIPANT	\N	PRESENT	0
384083	371542	14121F	PARTICIPANT	\N	PRESENT	0
384084	371542	11053K	PARTICIPANT	\N	PRESENT	0
384085	382778	14030Q	PARTICIPANT	\N	EXCUSE	0
384086	371542	08062Y	PARTICIPANT	\N	PRESENT	0
384087	371542	11067R	PARTICIPANT	\N	PRESENT	0
384088	371542	04088S	PARTICIPANT	\N	PRESENT	0
384089	371542	08035V	PARTICIPANT	\N	PRESENT	0
384090	371542	19703U	PARTICIPANT	\N	PRESENT	0
384091	371542	14197C	PARTICIPANT	\N	PRESENT	0
384092	371542	14038Y	PARTICIPANT	\N	PRESENT	0
384093	371542	14213J	PARTICIPANT	\N	PRESENT	0
384094	371542	19467C	PARTICIPANT	\N	PRESENT	0
384095	371542	19701S	PARTICIPANT	\N	PRESENT	0
384096	371542	14235Q	PARTICIPANT	\N	PRESENT	0
384097	371542	88008L	PARTICIPANT	\N	PRESENT	0
384098	371542	10015M	PARTICIPANT	\N	PRESENT	0
384099	371542	97011G	PARTICIPANT	\N	PRESENT	0
384100	371542	11043H	PARTICIPANT	\N	PRESENT	0
384101	371542	14195A	PARTICIPANT	\N	PRESENT	0
384102	371542	19747H	PARTICIPANT	\N	PRESENT	0
384103	371542	14217N	PARTICIPANT	\N	PRESENT	0
384594	384593	19675J	PARTICIPANT	\N	PRESENT	0
384595	384593	04047H	PARTICIPANT	\N	PRESENT	0
385026	377916	14083S	PARTICIPANT	\N	PRESENT	0
385027	377916	14021P	PARTICIPANT	\N	PRESENT	0
385028	377916	14265W	PARTICIPANT	\N	PRESENT	0
385029	377916	19723Y	PARTICIPANT	\N	PRESENT	0
385030	377916	19441R	PARTICIPANT	\N	PRESENT	0
385031	377916	19349W	PARTICIPANT	\N	PRESENT	0
385032	377916	95041E	PARTICIPANT	\N	PRESENT	0
385033	377916	14211G	PARTICIPANT	\N	PRESENT	0
385034	377916	19691J	PARTICIPANT	\N	PRESENT	0
385035	377916	19575F	PARTICIPANT	\N	PRESENT	0
385036	377916	14069U	PARTICIPANT	\N	PRESENT	0
385047	380333	19515S	PARTICIPANT	\N	EXCUSE	0
385074	380333	08069G	PARTICIPANT	\N	EXCUSE	0
385082	385081	99004R	PRESIDENT	0	PRESENT	0
385090	371540	19479G	PARTICIPANT	\N	PRESENT	0
385591	385590	19631V	PARTICIPANT	\N	PRESENT	0
385239	380333	01028R	PARTICIPANT	\N	EXCUSE	0
385293	380333	11065P	PARTICIPANT	\N	EXCUSE	0
385592	385590	11083R	PARTICIPANT	\N	PRESENT	0
385593	385590	01048V	PARTICIPANT	\N	PRESENT	0
385594	385590	08053X	PARTICIPANT	\N	PRESENT	0
385595	385590	14257W	PRESIDENT	0	PRESENT	0
385596	385590	19593H	PARTICIPANT	\N	PRESENT	0
385597	385590	14229S	PARTICIPANT	\N	PRESENT	0
385598	385590	19421M	PARTICIPANT	\N	PRESENT	0
385599	385590	19679N	PARTICIPANT	\N	EXCUSE	0
385603	385602	14093U	PARTICIPANT	\N	PRESENT	0
385601	385590	14038Y	PARTICIPANT	\N	EXCUSE	0
385604	385602	14038Y	PARTICIPANT	\N	EXCUSE	0
385605	385602	11083R	PARTICIPANT	\N	EXCUSE	0
385606	385602	08053X	PARTICIPANT	\N	PRESENT	0
385607	385602	01048V	PARTICIPANT	\N	PRESENT	0
385608	385602	14257W	PRESIDENT	0	PRESENT	0
385609	385602	19593H	PARTICIPANT	\N	EXCUSE	0
385610	385602	19679N	PARTICIPANT	\N	EXCUSE	0
385611	385602	14229S	PARTICIPANT	\N	PRESENT	0
385612	385602	19421M	PARTICIPANT	\N	PRESENT	0
385847	384600	11031D	PARTICIPANT	\N	PRESENT	0
385848	384600	98024R	PRESIDENT	0	PRESENT	0
385849	384600	19663E	PARTICIPANT	\N	EXCUSE	0
385857	384600	14026U	PARTICIPANT	\N	PRESENT	0
385858	384600	01034P	PARTICIPANT	\N	PRESENT	0
385859	384600	19703U	PARTICIPANT	\N	PRESENT	0
385860	384600	19798U	PARTICIPANT	\N	PRESENT	0
385861	384600	19723Y	PARTICIPANT	\N	PRESENT	0
385862	384600	10006L	PARTICIPANT	\N	PRESENT	0
385864	384602	19663E	PARTICIPANT	\N	EXCUSE	0
385865	384602	98024R	PRESIDENT	0	PRESENT	0
385867	384602	10006L	PARTICIPANT	\N	PRESENT	0
385868	384602	14026U	PARTICIPANT	\N	PRESENT	0
385869	384602	19723Y	PARTICIPANT	\N	PRESENT	0
385884	384602	19703U	PARTICIPANT	\N	PRESENT	0
385885	384602	01034P	PARTICIPANT	\N	PRESENT	0
385886	384602	19798U	PARTICIPANT	\N	PRESENT	0
385887	384602	11031D	PARTICIPANT	\N	PRESENT	0
385935	380333	19551W	PARTICIPANT	\N	PRESENT	0
385980	385979	19253P	PARTICIPANT	\N	PRESENT	0
385981	385979	11026G	PARTICIPANT	\N	PRESENT	0
385982	385979	95067Q	PARTICIPANT	\N	PRESENT	0
385983	385979	14081Q	PARTICIPANT	\N	PRESENT	0
386161	386130	19489J	PARTICIPANT	\N	PRESENT	0
386162	386130	11026G	PARTICIPANT	\N	PRESENT	0
386163	386130	19729F	PARTICIPANT	\N	PRESENT	0
386165	386130	14147R	PARTICIPANT	\N	PRESENT	0
386166	386130	11072N	PARTICIPANT	\N	PRESENT	0
386168	386130	01028R	PARTICIPANT	\N	PRESENT	0
386169	386130	19675J	PARTICIPANT	\N	PRESENT	0
386170	386130	19585H	PARTICIPANT	\N	PRESENT	0
386171	386130	08018U	PARTICIPANT	\N	EXCUSE	0
386251	386250	88008L	PARTICIPANT	\N	PRESENT	0
386252	386250	11012A	PARTICIPANT	\N	PRESENT	0
386292	386291	11043H	PARTICIPANT	\N	PRESENT	0
386293	386291	08012N	PARTICIPANT	\N	PRESENT	0
386294	386291	14073Q	PARTICIPANT	\N	PRESENT	0
386295	386291	19533U	PARTICIPANT	\N	PRESENT	0
386296	386291	14241N	PARTICIPANT	\N	PRESENT	0
386614	377925	14034U	PARTICIPANT	\N	PRESENT	0
386616	377925	14239U	PARTICIPANT	\N	PRESENT	0
386617	377925	08052W	PARTICIPANT	\N	PRESENT	0
386618	377925	19683J	PARTICIPANT	\N	PRESENT	0
386619	386607	15447F	PARTICIPANT	\N	PRESENT	0
386620	386607	14237S	PARTICIPANT	\N	PRESENT	0
386621	386607	19703U	PARTICIPANT	\N	PRESENT	0
386622	386607	14031R	PARTICIPANT	\N	PRESENT	0
386623	386607	08045X	PARTICIPANT	\N	PRESENT	0
386624	386607	19387D	PARTICIPANT	\N	PRESENT	0
386625	386607	11064N	PARTICIPANT	\N	PRESENT	0
386626	386607	11053K	PRESIDENT	0	PRESENT	0
386627	386607	19253P	PARTICIPANT	\N	PRESENT	0
386628	386607	14069U	PARTICIPANT	\N	PRESENT	0
386629	386607	14225N	PARTICIPANT	\N	PRESENT	0
386630	386607	19333N	PARTICIPANT	\N	EXCUSE	0
386631	386607	19735D	PARTICIPANT	\N	EXCUSE	0
386632	377925	08055A	PARTICIPANT	\N	PRESENT	0
386633	377925	11104D	PARTICIPANT	\N	PRESENT	0
386634	377925	14257W	PARTICIPANT	\N	PRESENT	0
386635	377925	14097Y	PARTICIPANT	\N	PRESENT	0
386636	377925	19527W	PARTICIPANT	\N	PRESENT	0
386637	377925	11045K	PARTICIPANT	\N	PRESENT	0
386638	377925	19727D	PARTICIPANT	\N	PRESENT	0
386639	377925	11040E	PARTICIPANT	\N	PRESENT	0
386640	377925	11031D	PARTICIPANT	\N	PRESENT	0
386641	377925	19565D	PARTICIPANT	\N	PRESENT	0
386642	377925	19553Y	PARTICIPANT	\N	PRESENT	0
386643	377925	14261S	PARTICIPANT	\N	PRESENT	0
386644	377925	17589D	PARTICIPANT	\N	PRESENT	0
386645	377925	14042U	PARTICIPANT	\N	PRESENT	0
386646	377925	19699S	PARTICIPANT	\N	PRESENT	0
386647	377925	19737F	PARTICIPANT	\N	PRESENT	0
386648	377925	08056B	PARTICIPANT	\N	PRESENT	0
386649	377925	11067R	PARTICIPANT	\N	PRESENT	0
386650	377925	12016W	PARTICIPANT	\N	PRESENT	0
386651	377925	11070L	PARTICIPANT	\N	PRESENT	0
386652	377925	14073Q	PARTICIPANT	\N	PRESENT	0
386653	377925	01024M	PARTICIPANT	\N	PRESENT	0
386654	377925	01025N	PARTICIPANT	\N	PRESENT	0
386655	377925	07004J	PARTICIPANT	\N	PRESENT	0
386656	377925	19367Y	PARTICIPANT	\N	PRESENT	0
386657	377925	14207L	PARTICIPANT	\N	PRESENT	0
386658	377925	19687N	PARTICIPANT	\N	PRESENT	0
386659	377925	19731Y	PARTICIPANT	\N	PRESENT	0
386660	377925	98050T	PARTICIPANT	\N	PRESENT	0
386661	377925	19507S	PARTICIPANT	\N	PRESENT	0
386662	377925	04088S	PARTICIPANT	\N	PRESENT	0
386663	377925	19663E	PARTICIPANT	\N	PRESENT	0
387592	387591	08012N	PARTICIPANT	\N	PRESENT	0
389398	377976	19581D	PARTICIPANT	\N	PRESENT	0
389399	377976	19798U	PARTICIPANT	\N	PRESENT	0
389400	377976	19367Y	PARTICIPANT	\N	PRESENT	0
389401	377976	19745F	PARTICIPANT	\N	PRESENT	0
389402	377976	14079W	PARTICIPANT	\N	PRESENT	0
389403	377976	19679N	PARTICIPANT	\N	PRESENT	0
389404	377976	95030B	PARTICIPANT	\N	PRESENT	0
389405	377976	19715Y	PARTICIPANT	\N	PRESENT	0
389406	377976	08052W	PARTICIPANT	\N	PRESENT	0
389407	377976	14157T	PARTICIPANT	\N	PRESENT	0
389427	377976	19575F	PARTICIPANT	\N	PRESENT	0
389409	377976	19733B	PARTICIPANT	\N	PRESENT	0
389410	377976	19731Y	PARTICIPANT	\N	PRESENT	0
389412	377976	14087W	PARTICIPANT	\N	PRESENT	0
389411	387772	14147R	PARTICIPANT	\N	PRESENT	0
389413	387772	01024M	PARTICIPANT	\N	PRESENT	0
389414	377976	17589D	PARTICIPANT	\N	PRESENT	0
389415	377976	14053L	PARTICIPANT	\N	PRESENT	0
389416	377976	19577H	PARTICIPANT	\N	PRESENT	0
389417	377976	19709B	PARTICIPANT	\N	PRESENT	0
389418	377976	19657G	PARTICIPANT	\N	PRESENT	0
389419	387772	14179A	PARTICIPANT	\N	PRESENT	0
389420	387772	14215L	PARTICIPANT	\N	PRESENT	0
389421	387772	05008E	PRESIDENT	0	PRESENT	0
389422	377976	08020N	PARTICIPANT	\N	PRESENT	0
389423	377976	19515S	PARTICIPANT	\N	PRESENT	0
389424	377976	04092N	PARTICIPANT	\N	PRESENT	0
389425	377976	19651A	PARTICIPANT	\N	PRESENT	0
389426	387772	01028R	PARTICIPANT	\N	PRESENT	0
389428	377976	14133K	PARTICIPANT	\N	PRESENT	0
389429	377976	08048B	PARTICIPANT	\N	PRESENT	0
389430	377976	14187A	PARTICIPANT	\N	PRESENT	0
389431	377976	11077T	PARTICIPANT	\N	PRESENT	0
389432	377976	14357A	PARTICIPANT	\N	PRESENT	0
389433	377976	04047H	PARTICIPANT	\N	PRESENT	0
389434	377976	11097X	PARTICIPANT	\N	PRESENT	0
389435	377976	19347U	PARTICIPANT	\N	PRESENT	0
389436	377976	14327T	PARTICIPANT	\N	PRESENT	0
389437	377976	19713W	PARTICIPANT	\N	PRESENT	0
389438	377976	19335Q	PARTICIPANT	\N	PRESENT	0
389439	377976	19383Y	PARTICIPANT	\N	PRESENT	0
389440	377976	14103D	PARTICIPANT	\N	PRESENT	0
389441	377976	01048V	PARTICIPANT	\N	PRESENT	0
389442	387772	19762G	PARTICIPANT	\N	PRESENT	0
389443	377976	14213J	PARTICIPANT	\N	PRESENT	0
389444	387772	14001X	PARTICIPANT	\N	PRESENT	0
389445	377976	88008L	PARTICIPANT	\N	PRESENT	0
389446	377976	14261S	PARTICIPANT	\N	PRESENT	0
389447	377976	19747H	PARTICIPANT	\N	PRESENT	0
389448	377976	14121F	PARTICIPANT	\N	PRESENT	0
389449	377976	14111D	PARTICIPANT	\N	PRESENT	0
389450	377976	17583W	PARTICIPANT	\N	PRESENT	0
389451	377976	07029T	PARTICIPANT	\N	PRESENT	0
389452	377976	14038Y	PARTICIPANT	\N	PRESENT	0
389453	377976	19447X	PARTICIPANT	\N	PRESENT	0
389454	377976	19503N	PARTICIPANT	\N	PRESENT	0
389455	377976	14061L	PARTICIPANT	\N	PRESENT	0
389456	377976	18083K	PARTICIPANT	\N	PRESENT	0
389457	386221	19768N	PARTICIPANT	\N	PRESENT	0
389458	386221	19782L	PARTICIPANT	\N	PRESENT	0
389459	386221	14357A	PARTICIPANT	\N	PRESENT	0
389460	386221	14187A	PARTICIPANT	\N	PRESENT	0
389461	386221	19441R	PARTICIPANT	\N	PRESENT	0
389462	386221	08038Y	PARTICIPANT	\N	PRESENT	0
389463	386221	19413M	PARTICIPANT	\N	PRESENT	0
389464	386221	14033T	PARTICIPANT	\N	PRESENT	0
389465	386221	11090Q	PRESIDENT	0	PRESENT	0
389466	386221	80013X	PARTICIPANT	\N	PRESENT	0
389467	386221	19295A	PARTICIPANT	\N	PRESENT	0
389468	386221	14205J	PARTICIPANT	\N	PRESENT	0
389469	386221	04088S	PARTICIPANT	\N	PRESENT	0
389470	386221	14115H	PARTICIPANT	\N	PRESENT	0
389471	386221	19705W	PARTICIPANT	\N	PRESENT	0
389472	386221	19507S	PARTICIPANT	\N	PRESENT	0
389473	386221	11101A	PARTICIPANT	\N	PRESENT	0
389474	386221	08015R	PARTICIPANT	\N	PRESENT	0
389475	386221	19747H	PARTICIPANT	\N	PRESENT	0
389476	386221	19511N	PARTICIPANT	\N	PRESENT	0
389477	386221	19563B	PARTICIPANT	\N	PRESENT	0
389478	386221	14265W	PARTICIPANT	\N	PRESENT	0
389479	386221	14329V	PARTICIPANT	\N	PRESENT	0
389480	386221	14257W	PARTICIPANT	\N	PRESENT	0
389481	377976	11043H	PARTICIPANT	\N	PRESENT	0
389482	377976	14026U	PARTICIPANT	\N	PRESENT	0
389483	386221	19467C	PARTICIPANT	\N	EXCUSE	0
389484	386221	08019V	PARTICIPANT	\N	EXCUSE	0
389485	386221	11081P	PARTICIPANT	\N	EXCUSE	0
389486	377976	16685X	PARTICIPANT	\N	PRESENT	0
389487	377976	14105F	PARTICIPANT	\N	PRESENT	0
389488	377976	19701S	PARTICIPANT	\N	PRESENT	0
389489	377976	95063L	PARTICIPANT	\N	PRESENT	0
389490	377976	14237S	PARTICIPANT	\N	PRESENT	0
389491	377976	14265W	PARTICIPANT	\N	PRESENT	0
389492	377976	14115H	PARTICIPANT	\N	PRESENT	0
389493	377976	14081Q	PARTICIPANT	\N	PRESENT	0
389494	377976	19729F	PARTICIPANT	\N	PRESENT	0
389496	387772	14041T	PARTICIPANT	\N	PRESENT	0
389556	377978	11090Q	PARTICIPANT	\N	PRESENT	0
389557	377978	08035V	PARTICIPANT	\N	PRESENT	0
389558	377978	14081Q	PARTICIPANT	\N	PRESENT	0
389559	377978	19713W	PARTICIPANT	\N	PRESENT	0
389560	377978	19349W	PARTICIPANT	\N	PRESENT	0
389561	377978	19387D	PARTICIPANT	\N	PRESENT	0
389562	377978	17589D	PARTICIPANT	\N	PRESENT	0
389563	377978	14195A	PARTICIPANT	\N	PRESENT	0
389564	377978	19737F	PARTICIPANT	\N	PRESENT	0
389565	377978	19675J	PARTICIPANT	\N	PRESENT	0
389566	377978	19733B	PARTICIPANT	\N	PRESENT	0
389567	377978	14105F	PARTICIPANT	\N	PRESENT	0
389568	377978	14115H	PARTICIPANT	\N	PRESENT	0
389569	377978	11056N	PARTICIPANT	\N	PRESENT	0
389570	377978	14329V	PARTICIPANT	\N	PRESENT	0
389571	377978	08048B	PARTICIPANT	\N	PRESENT	0
389572	377978	19695N	PARTICIPANT	\N	PRESENT	0
389573	377978	19479G	PARTICIPANT	\N	PRESENT	0
389574	377978	19507S	PARTICIPANT	\N	PRESENT	0
389575	377978	14029X	PARTICIPANT	\N	PRESENT	0
389576	377978	11049P	PARTICIPANT	\N	PRESENT	0
389577	377978	19383Y	PARTICIPANT	\N	PRESENT	0
389578	377978	18083K	PARTICIPANT	\N	PRESENT	0
389579	377978	04088S	PARTICIPANT	\N	PRESENT	0
389580	377978	95030B	PARTICIPANT	\N	PRESENT	0
389581	377978	14147R	PARTICIPANT	\N	PRESENT	0
389582	377978	14030Q	PARTICIPANT	\N	PRESENT	0
389583	377978	19747H	PARTICIPANT	\N	PRESENT	0
389584	377978	80013X	PARTICIPANT	\N	PRESENT	0
389585	377978	01025N	PARTICIPANT	\N	PRESENT	0
389586	377978	14231L	PARTICIPANT	\N	PRESENT	0
389587	377978	14357A	PARTICIPANT	\N	PRESENT	0
389588	377978	11077T	PARTICIPANT	\N	PRESENT	0
389589	377978	07029T	PARTICIPANT	\N	PRESENT	0
389590	377978	14053L	PARTICIPANT	\N	PRESENT	0
389591	377978	19768N	PARTICIPANT	\N	PRESENT	0
389592	377978	01043Q	PARTICIPANT	\N	PRESENT	0
389593	377978	14069U	PARTICIPANT	\N	PRESENT	0
389594	377978	19295A	PARTICIPANT	\N	PRESENT	0
389595	377978	14026U	PARTICIPANT	\N	PRESENT	0
389596	377978	04045F	PARTICIPANT	\N	PRESENT	0
389597	377978	19545Y	PARTICIPANT	\N	PRESENT	0
389598	377978	14265W	PARTICIPANT	\N	PRESENT	0
389599	377978	04033B	PARTICIPANT	\N	PRESENT	0
389600	377978	19631V	PARTICIPANT	\N	PRESENT	0
389601	377978	14213J	PARTICIPANT	\N	PRESENT	0
389602	377978	19715Y	PARTICIPANT	\N	PRESENT	0
389603	377978	11109J	PARTICIPANT	\N	PRESENT	0
389604	377978	14033T	PARTICIPANT	\N	PRESENT	0
389605	377978	14034U	PARTICIPANT	\N	PRESENT	0
389926	377975	11054L	PARTICIPANT	\N	PRESENT	0
389930	388515	86034E	PARTICIPANT	\N	PRESENT	0
390176	388106	14201E	PARTICIPANT	\N	PRESENT	0
389552	377978	04044E	PARTICIPANT	\N	PRESENT	0
389553	377978	14187A	PARTICIPANT	\N	PRESENT	0
390177	388106	19621T	PARTICIPANT	\N	PRESENT	0
390178	388106	11010L	PARTICIPANT	\N	PRESENT	0
390179	388106	19545Y	PARTICIPANT	\N	PRESENT	0
390180	388106	14179A	PARTICIPANT	\N	PRESENT	0
390181	388106	19369B	PARTICIPANT	\N	PRESENT	0
390182	388106	19691J	PARTICIPANT	\N	PRESENT	0
390183	388106	08009T	PARTICIPANT	\N	PRESENT	0
390184	388106	11053K	PARTICIPANT	\N	PRESENT	0
390185	388106	19611R	PARTICIPANT	\N	PRESENT	0
390186	388106	19511N	PARTICIPANT	\N	PRESENT	0
390187	388106	19737F	PARTICIPANT	\N	PRESENT	0
390188	388106	19699S	PARTICIPANT	\N	PRESENT	0
390189	388106	19619A	PARTICIPANT	\N	PRESENT	0
390190	388106	19569H	PARTICIPANT	\N	PRESENT	0
367008	345245	14034U	PARTICIPANT	\N	PRESENT	0
367009	345245	14031R	PARTICIPANT	\N	PRESENT	0
367010	345245	08009T	PARTICIPANT	\N	PRESENT	0
367014	345245	11040E	PARTICIPANT	\N	PRESENT	0
367015	345245	04085P	PARTICIPANT	\N	PRESENT	0
367016	345245	19347U	PARTICIPANT	\N	PRESENT	0
367017	345245	19695N	PARTICIPANT	\N	PRESENT	0
367018	345245	19251M	PARTICIPANT	\N	PRESENT	0
367019	345245	08058D	PARTICIPANT	\N	PRESENT	0
367020	345245	14051J	PARTICIPANT	\N	PRESENT	0
367021	345245	19503N	PARTICIPANT	\N	PRESENT	0
367022	345245	19599P	PARTICIPANT	\N	PRESENT	0
367023	345245	19525U	PARTICIPANT	\N	PRESENT	0
367024	345245	19333N	PARTICIPANT	\N	PRESENT	0
367025	345245	08055A	PARTICIPANT	\N	PRESENT	0
367026	345245	19551W	PARTICIPANT	\N	PRESENT	0
367027	345245	04057K	PARTICIPANT	\N	PRESENT	0
367028	345245	19583F	PARTICIPANT	\N	PRESENT	0
367029	345245	11065P	PARTICIPANT	\N	PRESENT	0
367030	345245	19387D	PARTICIPANT	\N	PRESENT	0
367031	345245	08061X	PARTICIPANT	\N	PRESENT	0
367032	345245	08060W	PARTICIPANT	\N	PRESENT	0
367033	345245	14147R	PARTICIPANT	\N	PRESENT	0
367034	345245	14089Y	PARTICIPANT	\N	PRESENT	0
367035	345245	19737F	PARTICIPANT	\N	PRESENT	0
367036	345245	19611R	PARTICIPANT	\N	PRESENT	0
367037	345245	99004R	PARTICIPANT	\N	PRESENT	0
367038	345245	14169X	PARTICIPANT	\N	PRESENT	0
367039	345245	14038Y	PARTICIPANT	\N	PRESENT	0
367040	345245	11012A	PARTICIPANT	\N	PRESENT	0
367041	345245	19289C	PARTICIPANT	\N	PRESENT	0
367042	345245	19637C	PARTICIPANT	\N	PRESENT	0
367043	345245	14093U	PARTICIPANT	\N	PRESENT	0
367044	345245	14219Q	PARTICIPANT	\N	PRESENT	0
367045	345245	11031D	PARTICIPANT	\N	PRESENT	0
367046	345245	11085T	PARTICIPANT	\N	PRESENT	0
367047	345245	95062K	PARTICIPANT	\N	PRESENT	0
367048	345245	14211G	PARTICIPANT	\N	PRESENT	0
367049	367013	11010L	PARTICIPANT	\N	PRESENT	0
367050	367013	14041T	PARTICIPANT	\N	PRESENT	0
367051	367013	19581D	PARTICIPANT	\N	PRESENT	0
367052	367013	19729F	PARTICIPANT	\N	EXCUSE	0
367053	345245	14231L	PARTICIPANT	\N	PRESENT	0
367054	345245	19629C	PARTICIPANT	\N	PRESENT	0
367055	345245	19741B	PARTICIPANT	\N	PRESENT	0
367056	345245	19687N	PARTICIPANT	\N	PRESENT	0
367057	345245	98050T	PARTICIPANT	\N	PRESENT	0
367058	345245	14133K	PARTICIPANT	\N	PRESENT	0
367059	345245	19715Y	PARTICIPANT	\N	PRESENT	0
367060	345245	01048V	PARTICIPANT	\N	PRESENT	0
367061	345245	07004J	PARTICIPANT	\N	PRESENT	0
367065	345245	19733B	PARTICIPANT	\N	PRESENT	0
367074	345245	19693L	PARTICIPANT	\N	PRESENT	0
367075	367013	19649G	PARTICIPANT	\N	PRESENT	0
367076	367013	14147R	PARTICIPANT	\N	PRESENT	0
367077	367013	01024M	PARTICIPANT	\N	PRESENT	0
367078	367013	19447X	PARTICIPANT	\N	PRESENT	0
367079	367013	19762G	PARTICIPANT	\N	PRESENT	0
367080	367013	05008E	PRESIDENT	0	PRESENT	0
367081	345245	14157T	PARTICIPANT	\N	PRESENT	0
367082	345245	19794Q	PARTICIPANT	\N	PRESENT	0
367083	345245	04086Q	PARTICIPANT	\N	PRESENT	0
367084	345245	19711U	PARTICIPANT	\N	PRESENT	0
367085	345245	14073Q	PARTICIPANT	\N	PRESENT	0
367086	345245	14103D	PARTICIPANT	\N	PRESENT	0
367089	345245	80013X	PARTICIPANT	\N	PRESENT	0
367090	345245	04043D	PARTICIPANT	\N	PRESENT	0
367091	345245	14063N	PARTICIPANT	\N	PRESENT	0
367092	345245	19349W	PARTICIPANT	\N	PRESENT	0
367095	345245	19669L	PARTICIPANT	\N	PRESENT	0
367096	345245	19399H	PARTICIPANT	\N	PRESENT	0
367097	345245	19747H	PARTICIPANT	\N	PRESENT	0
367099	345245	19683J	PARTICIPANT	\N	PRESENT	0
367101	345245	19253P	PARTICIPANT	\N	PRESENT	0
367102	345245	18083K	PARTICIPANT	\N	PRESENT	0
367104	345245	14259Y	PARTICIPANT	\N	PRESENT	0
367107	345245	19269X	PARTICIPANT	\N	PRESENT	0
367108	345245	11097X	PARTICIPANT	\N	PRESENT	0
367111	345245	14135M	PARTICIPANT	\N	PRESENT	0
367112	345245	19701S	PARTICIPANT	\N	PRESENT	0
367113	367013	11026G	PARTICIPANT	\N	PRESENT	0
367212	356291	08009T	PARTICIPANT	\N	PRESENT	0
367213	356291	04085P	PARTICIPANT	\N	PRESENT	0
367214	356291	19637C	PARTICIPANT	\N	PRESENT	0
367215	356291	19629C	PARTICIPANT	\N	PRESENT	0
367216	356291	19289C	PARTICIPANT	\N	PRESENT	0
367217	356291	11065P	PARTICIPANT	\N	PRESENT	0
367218	356291	19583F	PARTICIPANT	\N	PRESENT	0
367219	356291	14231L	PARTICIPANT	\N	PRESENT	0
367220	356291	19737F	PARTICIPANT	\N	PRESENT	0
367221	356291	19671E	PARTICIPANT	\N	PRESENT	0
367222	356291	19701S	PARTICIPANT	\N	PRESENT	0
367223	356291	19711U	PARTICIPANT	\N	PRESENT	0
367224	356291	99004R	PARTICIPANT	\N	PRESENT	0
367225	356291	19643A	PARTICIPANT	\N	PRESENT	0
367226	356291	95062K	PARTICIPANT	\N	PRESENT	0
367227	356291	14211G	PARTICIPANT	\N	PRESENT	0
367228	356291	14157T	PARTICIPANT	\N	PRESENT	0
367229	356291	18083K	PARTICIPANT	\N	PRESENT	0
367230	356291	14041T	PARTICIPANT	\N	PRESENT	0
367231	356291	14038Y	PARTICIPANT	\N	PRESENT	0
367232	356291	19387D	PARTICIPANT	\N	PRESENT	0
367233	356291	19333N	PARTICIPANT	\N	PRESENT	0
367234	356291	11031D	PARTICIPANT	\N	PRESENT	0
367235	356291	19663E	PARTICIPANT	\N	PRESENT	0
367236	356291	19479G	PARTICIPANT	\N	PRESENT	0
367237	356291	08069G	PARTICIPANT	\N	PRESENT	0
367238	356291	19467C	PARTICIPANT	\N	PRESENT	0
367239	356291	14261S	PARTICIPANT	\N	PRESENT	0
367240	356291	08060W	PARTICIPANT	\N	PRESENT	0
367241	356291	19525U	PARTICIPANT	\N	PRESENT	0
367242	356291	19651A	PARTICIPANT	\N	PRESENT	0
367243	356291	98050T	PARTICIPANT	\N	PRESENT	0
367244	356291	14147R	PARTICIPANT	\N	PRESENT	0
367245	356291	19762G	PARTICIPANT	\N	PRESENT	0
367246	356291	08055A	PARTICIPANT	\N	PRESENT	0
367247	356291	14051J	PARTICIPANT	\N	PRESENT	0
367248	356291	19503N	PARTICIPANT	\N	PRESENT	0
367249	356291	19599P	PARTICIPANT	\N	PRESENT	0
367250	356291	11012A	PARTICIPANT	\N	PRESENT	0
367251	356291	14259Y	PARTICIPANT	\N	PRESENT	0
367252	356291	19447X	PARTICIPANT	\N	PRESENT	0
367253	356291	08019V	PARTICIPANT	\N	PRESENT	0
367254	356291	14159V	PARTICIPANT	\N	PRESENT	0
367255	356291	14063N	PARTICIPANT	\N	PRESENT	0
367256	356291	11010L	PARTICIPANT	\N	PRESENT	0
367257	356291	19741B	PARTICIPANT	\N	PRESENT	0
367259	356291	19747H	PARTICIPANT	\N	PRESENT	0
367260	356291	19551W	PARTICIPANT	\N	PRESENT	0
367261	356291	95030B	PARTICIPANT	\N	PRESENT	0
367262	356291	19347U	PARTICIPANT	\N	PRESENT	0
367263	356291	19369B	PARTICIPANT	\N	PRESENT	0
367264	356291	19611R	PARTICIPANT	\N	PRESENT	0
367268	356291	19253P	PARTICIPANT	\N	PRESENT	0
367269	356291	14079W	PARTICIPANT	\N	PRESENT	0
367275	356291	19693L	PARTICIPANT	\N	PRESENT	0
367278	356291	14073Q	PARTICIPANT	\N	PRESENT	0
367281	356291	19739H	PARTICIPANT	\N	PRESENT	0
367282	356291	07029T	PARTICIPANT	\N	PRESENT	0
367285	356291	14135M	PARTICIPANT	\N	PRESENT	0
367288	356291	07004J	PARTICIPANT	\N	PRESENT	0
367290	356291	19669L	PARTICIPANT	\N	PRESENT	0
367291	356291	11085T	PARTICIPANT	\N	PRESENT	0
367292	356291	19687N	PARTICIPANT	\N	PRESENT	0
367294	356291	04057K	PARTICIPANT	\N	PRESENT	0
367295	356291	14219Q	PARTICIPANT	\N	PRESENT	0
367205	356291	04086Q	PARTICIPANT	\N	PRESENT	0
367211	356291	14031R	PARTICIPANT	\N	PRESENT	0
367296	356291	08034U	PARTICIPANT	\N	PRESENT	0
367297	356291	11033F	PARTICIPANT	\N	PRESENT	0
367298	356291	19593H	PARTICIPANT	\N	PRESENT	0
367299	356291	19715Y	PARTICIPANT	\N	PRESENT	0
367300	356291	19697Q	PARTICIPANT	\N	PRESENT	0
367301	356291	04043D	PARTICIPANT	\N	PRESENT	0
367306	356291	04071H	PARTICIPANT	\N	PRESENT	0
367307	356291	19543W	PARTICIPANT	\N	PRESENT	0
367308	356291	19695N	PARTICIPANT	\N	PRESENT	0
367309	356291	14030Q	PARTICIPANT	\N	PRESENT	0
373808	373691	19515S	PARTICIPANT	\N	EXCUSE	0
373809	373691	11066Q	PARTICIPANT	\N	PRESENT	0
373810	373691	19369B	PARTICIPANT	\N	PRESENT	0
373811	373691	11097X	PARTICIPANT	\N	PRESENT	0
373812	373691	19629C	PARTICIPANT	\N	EXCUSE	0
373813	373691	89017R	PARTICIPANT	\N	EXCUSE	0
373814	373691	01028R	PARTICIPANT	\N	EXCUSE	0
373815	373691	08024S	PARTICIPANT	\N	PRESENT	0
373816	373691	19713W	PARTICIPANT	\N	EXCUSE	0
373817	373691	11056N	PARTICIPANT	\N	EXCUSE	0
373818	373691	19651A	PARTICIPANT	\N	PRESENT	0
375144	363550	11072N	PARTICIPANT	\N	PRESENT	0
375145	363550	08010L	PARTICIPANT	\N	PRESENT	0
375146	363550	14083S	PARTICIPANT	\N	PRESENT	0
375147	363550	11083R	PARTICIPANT	\N	PRESENT	0
375148	363550	14219Q	PARTICIPANT	\N	PRESENT	0
375149	363550	19447X	PARTICIPANT	\N	PRESENT	0
375150	363550	19741B	PARTICIPANT	\N	PRESENT	0
375151	363550	19713W	PARTICIPANT	\N	PRESENT	0
375162	363550	14021P	PARTICIPANT	\N	PRESENT	0
375163	363550	08069G	PARTICIPANT	\N	PRESENT	0
375170	363550	08038Y	PARTICIPANT	\N	PRESENT	0
375171	363550	11053K	PARTICIPANT	\N	PRESENT	0
375172	363550	19527W	PARTICIPANT	\N	PRESENT	0
375173	363550	19689Q	PARTICIPANT	\N	PRESENT	0
375174	363550	11074Q	PARTICIPANT	\N	PRESENT	0
375175	363550	19687N	PARTICIPANT	\N	PRESENT	0
375222	371421	11074Q	PARTICIPANT	\N	PRESENT	0
375223	371421	14021P	PARTICIPANT	\N	PRESENT	0
375224	371421	19503N	PARTICIPANT	\N	PRESENT	0
375225	371421	08038Y	PARTICIPANT	\N	PRESENT	0
375142	363550	14147R	PARTICIPANT	\N	PRESENT	0
375143	363550	11012A	PARTICIPANT	\N	PRESENT	0
375226	371421	14227Q	PARTICIPANT	\N	PRESENT	0
375227	371421	19527W	PARTICIPANT	\N	PRESENT	0
375228	371421	19349W	PARTICIPANT	\N	PRESENT	0
375229	371421	01028R	PARTICIPANT	\N	PRESENT	0
375230	371421	19667J	PARTICIPANT	\N	PRESENT	0
375231	371421	19447X	PARTICIPANT	\N	PRESENT	0
375232	371421	04086Q	PARTICIPANT	\N	PRESENT	0
375233	371421	19741B	PARTICIPANT	\N	PRESENT	0
375234	371421	14215L	PARTICIPANT	\N	PRESENT	0
375235	371421	19701S	PARTICIPANT	\N	PRESENT	0
375236	371421	11045K	PARTICIPANT	\N	PRESENT	0
375237	371421	19689Q	PARTICIPANT	\N	PRESENT	0
375238	371421	14081Q	PARTICIPANT	\N	PRESENT	0
375239	371421	11072N	PARTICIPANT	\N	PRESENT	0
375240	371421	11012A	PARTICIPANT	\N	PRESENT	0
375247	371421	14083S	PARTICIPANT	\N	PRESENT	0
375242	371421	19762G	PARTICIPANT	\N	PRESENT	0
375243	371421	19687N	PARTICIPANT	\N	PRESENT	0
375244	371421	04085P	PARTICIPANT	\N	PRESENT	0
375245	371421	14151M	PARTICIPANT	\N	PRESENT	0
375246	371421	99004R	PARTICIPANT	\N	PRESENT	0
375248	371421	14231L	PARTICIPANT	\N	PRESENT	0
375249	371421	11033F	PARTICIPANT	\N	PRESENT	0
375250	371421	14111D	PARTICIPANT	\N	PRESENT	0
375251	371421	19399H	PARTICIPANT	\N	PRESENT	0
375252	371421	19593H	PARTICIPANT	\N	PRESENT	0
375253	371421	14147R	PARTICIPANT	\N	PRESENT	0
375254	371421	19647E	PARTICIPANT	\N	PRESENT	0
375255	371421	19387D	PARTICIPANT	\N	PRESENT	0
375256	371421	11099A	PARTICIPANT	\N	PRESENT	0
375257	371421	08031R	PARTICIPANT	\N	PRESENT	0
375296	363548	11033F	PARTICIPANT	\N	PRESENT	0
375297	363548	19593H	PARTICIPANT	\N	PRESENT	0
375298	363548	11045K	PARTICIPANT	\N	PRESENT	0
375299	363548	19647E	PARTICIPANT	\N	PRESENT	0
375300	363548	14151M	PARTICIPANT	\N	PRESENT	0
375301	363548	19689Q	PARTICIPANT	\N	PRESENT	0
375302	363548	14081Q	PARTICIPANT	\N	PRESENT	0
375303	363548	01028R	PARTICIPANT	\N	PRESENT	0
375304	363548	05008E	PARTICIPANT	\N	PRESENT	0
375220	371421	11070L	PARTICIPANT	\N	PRESENT	0
375221	371421	08010L	PARTICIPANT	\N	PRESENT	0
375305	363548	14083S	PARTICIPANT	\N	PRESENT	0
375306	363548	17637T	PARTICIPANT	\N	PRESENT	0
375307	363548	19667J	PARTICIPANT	\N	PRESENT	0
375308	363548	19762G	PARTICIPANT	\N	PRESENT	0
375309	363548	19701S	PARTICIPANT	\N	PRESENT	0
375310	363548	11072N	PARTICIPANT	\N	PRESENT	0
375311	363548	14215L	PARTICIPANT	\N	PRESENT	0
375312	363548	14021P	PARTICIPANT	\N	PRESENT	0
375313	363548	19503N	PARTICIPANT	\N	PRESENT	0
375314	363548	14111D	PARTICIPANT	\N	PRESENT	0
375315	363548	19551W	PARTICIPANT	\N	PRESENT	0
375316	363548	19447X	PARTICIPANT	\N	PRESENT	0
375317	363548	11099A	PARTICIPANT	\N	PRESENT	0
375318	363548	08031R	PARTICIPANT	\N	PRESENT	0
375319	363548	11012A	PARTICIPANT	\N	PRESENT	0
375320	363548	19387D	PARTICIPANT	\N	PRESENT	0
377072	376985	87003B	PARTICIPANT	\N	EXCUSE	0
377073	376985	19766L	PARTICIPANT	\N	EXCUSE	0
377074	376985	14201E	PARTICIPANT	\N	EXCUSE	0
377090	373784	04044E	PARTICIPANT	\N	EXCUSE	0
377097	373784	14028W	PARTICIPANT	\N	EXCUSE	0
377339	373784	08038Y	PARTICIPANT	\N	EXCUSE	0
377713	377013	19689Q	PARTICIPANT	\N	PRESENT	0
377714	377013	08011M	PARTICIPANT	\N	PRESENT	0
377715	377013	14159V	PARTICIPANT	\N	PRESENT	0
377716	377013	14173T	PARTICIPANT	\N	PRESENT	0
377717	377013	04086Q	PARTICIPANT	\N	PRESENT	0
375294	363548	04086Q	PARTICIPANT	\N	PRESENT	0
375295	363548	14147R	PARTICIPANT	\N	PRESENT	0
377718	377013	11040E	PARTICIPANT	\N	PRESENT	0
377719	377013	14083S	PARTICIPANT	\N	PRESENT	0
377720	377013	11012A	PARTICIPANT	\N	PRESENT	0
377721	377013	14199E	PARTICIPANT	\N	PRESENT	0
377722	377013	08073C	PARTICIPANT	\N	PRESENT	0
377723	377013	14121F	PARTICIPANT	\N	PRESENT	0
377724	377013	99004R	PARTICIPANT	\N	PRESENT	0
377725	375457	19798U	PARTICIPANT	\N	PRESENT	0
377726	375457	11097X	PARTICIPANT	\N	PRESENT	0
377727	375457	19415P	PARTICIPANT	\N	PRESENT	0
377728	375457	14223L	PARTICIPANT	\N	PRESENT	0
377729	375457	19703U	PARTICIPANT	\N	PRESENT	0
377730	375457	14087W	PARTICIPANT	\N	PRESENT	0
377731	375457	11103C	PARTICIPANT	\N	PRESENT	0
377732	375457	19367Y	PARTICIPANT	\N	PRESENT	0
377733	375457	14213J	PARTICIPANT	\N	PRESENT	0
377734	375457	14071N	PARTICIPANT	\N	PRESENT	0
377735	375457	14217N	PARTICIPANT	\N	PRESENT	0
377736	375457	10006L	PARTICIPANT	\N	PRESENT	0
377737	375457	98024R	PARTICIPANT	\N	PRESENT	0
377738	375457	19565D	PARTICIPANT	\N	PRESENT	0
377739	375457	14042U	PARTICIPANT	\N	PRESENT	0
377740	375457	19691J	PARTICIPANT	\N	PRESENT	0
377741	375457	14026U	PARTICIPANT	\N	PRESENT	0
377742	375457	14119M	PARTICIPANT	\N	PRESENT	0
377743	375457	19575F	PARTICIPANT	\N	PRESENT	0
377744	375457	19760E	PARTICIPANT	\N	PRESENT	0
377929	376741	98005N	PARTICIPANT	\N	PRESENT	0
377930	376741	19443T	PARTICIPANT	\N	PRESENT	0
377931	376741	12041X	PARTICIPANT	\N	PRESENT	0
377932	376741	95030B	PARTICIPANT	\N	PRESENT	0
377933	376741	04034C	PARTICIPANT	\N	PRESENT	0
377934	376741	04040A	PARTICIPANT	\N	PRESENT	0
377935	376741	01058X	PARTICIPANT	\N	PRESENT	0
377936	376741	14079W	PARTICIPANT	\N	PRESENT	0
377937	376741	16685X	PARTICIPANT	\N	PRESENT	0
377938	376741	11027H	PARTICIPANT	\N	PRESENT	0
377939	376741	04042C	PRESIDENT	0	PRESENT	0
377940	376741	11054L	PARTICIPANT	\N	PRESENT	0
377941	376741	11066Q	PARTICIPANT	\N	PRESENT	0
377942	376741	19669L	PARTICIPANT	\N	PRESENT	0
377943	376741	08056B	PARTICIPANT	\N	PRESENT	0
377944	376741	95037J	PARTICIPANT	\N	PRESENT	0
377945	376741	14055N	PARTICIPANT	\N	PRESENT	0
377946	376741	19421M	PARTICIPANT	\N	PRESENT	0
377947	376741	19709B	PARTICIPANT	\N	PRESENT	0
377948	376741	14193X	PARTICIPANT	\N	PRESENT	0
377949	376741	08049C	PARTICIPANT	\N	PRESENT	0
377950	376741	08053X	PARTICIPANT	\N	PRESENT	0
377951	376741	97011G	PARTICIPANT	\N	PRESENT	0
377952	376741	08061X	PARTICIPANT	\N	PRESENT	0
377953	376741	08047A	PARTICIPANT	\N	PRESENT	0
377954	376741	98029W	PARTICIPANT	\N	PRESENT	0
377955	376741	14097Y	PARTICIPANT	\N	PRESENT	0
377956	376741	95067Q	PARTICIPANT	\N	PRESENT	0
377957	376741	01062T	PARTICIPANT	\N	PRESENT	0
377958	376741	14133K	PARTICIPANT	\N	PRESENT	0
377959	376741	11041F	PARTICIPANT	\N	PRESENT	0
377960	376741	14235Q	PARTICIPANT	\N	PRESENT	0
377961	376741	08058D	PARTICIPANT	\N	PRESENT	0
377962	376741	19251M	PARTICIPANT	\N	PRESENT	0
377963	376741	19721W	PARTICIPANT	\N	PRESENT	0
377964	376741	14105F	PARTICIPANT	\N	PRESENT	0
377965	376741	98022P	PARTICIPANT	\N	PRESENT	0
377966	376741	14267Y	PARTICIPANT	\N	PRESENT	0
377967	376741	11064N	PARTICIPANT	\N	PRESENT	0
377968	376741	98050T	PARTICIPANT	\N	PRESENT	0
377969	376741	19583F	PARTICIPANT	\N	PRESENT	0
377970	376741	14211G	PARTICIPANT	\N	PRESENT	0
377971	376741	14255U	PARTICIPANT	\N	PRESENT	0
378073	377015	19479G	PARTICIPANT	\N	PRESENT	0
378074	377015	19711U	PARTICIPANT	\N	PRESENT	0
378075	377015	01057W	PARTICIPANT	\N	PRESENT	0
378076	377015	11053K	PARTICIPANT	\N	PRESENT	0
378077	377015	11074Q	PRESIDENT	0	PRESENT	0
378078	377015	89017R	PARTICIPANT	\N	PRESENT	0
363167	345233	14030Q	PARTICIPANT	\N	PRESENT	0
363169	345233	19269X	PARTICIPANT	\N	PRESENT	0
363170	345233	19693L	PARTICIPANT	\N	PRESENT	0
363171	345233	14357A	PARTICIPANT	\N	PRESENT	0
363177	345233	14121F	PARTICIPANT	\N	PRESENT	0
363179	345233	19621T	PARTICIPANT	\N	PRESENT	0
363178	345233	04033B	PARTICIPANT	\N	PRESENT	0
363180	345233	19565D	PARTICIPANT	\N	PRESENT	0
363181	345233	19289C	PARTICIPANT	\N	PRESENT	0
363182	345233	19611R	PARTICIPANT	\N	PRESENT	0
363206	345233	04071H	PARTICIPANT	\N	PRESENT	0
363207	345233	14071N	PARTICIPANT	\N	PRESENT	0
363208	345233	04061F	PARTICIPANT	\N	PRESENT	0
363209	345233	14042U	PARTICIPANT	\N	PRESENT	0
363210	345233	19563B	PARTICIPANT	\N	PRESENT	0
363211	345233	19717B	PARTICIPANT	\N	PRESENT	0
363212	345233	04086Q	PARTICIPANT	\N	PRESENT	0
363213	345233	14079W	PARTICIPANT	\N	PRESENT	0
363214	345233	10015M	PARTICIPANT	\N	PRESENT	0
363215	345233	19747H	PARTICIPANT	\N	PRESENT	0
363216	345233	01024M	PARTICIPANT	\N	PRESENT	0
363217	345233	19413M	PARTICIPANT	\N	PRESENT	0
363312	345234	14105F	PARTICIPANT	\N	PRESENT	0
363313	345234	12016W	PARTICIPANT	\N	PRESENT	0
363314	345234	19737F	PARTICIPANT	\N	PRESENT	0
363315	345234	19729F	PARTICIPANT	\N	PRESENT	0
363316	345234	19794Q	PARTICIPANT	\N	PRESENT	0
363317	345234	08060W	PARTICIPANT	\N	PRESENT	0
363318	345234	19599P	PARTICIPANT	\N	PRESENT	0
363319	345234	19549D	PARTICIPANT	\N	PRESENT	0
363320	345234	19333N	PARTICIPANT	\N	PRESENT	0
363321	345234	19413M	PARTICIPANT	\N	PRESENT	0
363322	345234	14051J	PARTICIPANT	\N	PRESENT	0
363323	345234	08055A	PARTICIPANT	\N	PRESENT	0
363324	345234	19415P	PARTICIPANT	\N	PRESENT	0
363325	345234	19503N	PARTICIPANT	\N	PRESENT	0
363326	345234	08009T	PARTICIPANT	\N	PRESENT	0
363327	345234	14031R	PARTICIPANT	\N	PRESENT	0
363328	345234	19747H	PARTICIPANT	\N	PRESENT	0
363329	345234	14053L	PARTICIPANT	\N	PRESENT	0
363330	345234	14237S	PARTICIPANT	\N	PRESENT	0
363331	345234	19709B	PARTICIPANT	\N	PRESENT	0
363332	345234	19703U	PARTICIPANT	\N	PRESENT	0
363333	345234	11043H	PARTICIPANT	\N	PRESENT	0
363334	345234	19679N	PARTICIPANT	\N	PRESENT	0
363335	345234	19758L	PARTICIPANT	\N	PRESENT	0
363336	345234	19525U	PARTICIPANT	\N	PRESENT	0
363337	345234	14231L	PARTICIPANT	\N	PRESENT	0
363338	345234	11090Q	PARTICIPANT	\N	PRESENT	0
363339	345234	19347U	PARTICIPANT	\N	PRESENT	0
363340	345234	19749K	PARTICIPANT	\N	PRESENT	0
363341	345234	19289C	PARTICIPANT	\N	PRESENT	0
363342	345234	19575F	PARTICIPANT	\N	PRESENT	0
363343	345234	19631V	PARTICIPANT	\N	PRESENT	0
363344	345234	08031R	PARTICIPANT	\N	PRESENT	0
363345	345234	19637C	PARTICIPANT	\N	PRESENT	0
363346	345234	08019V	PARTICIPANT	\N	PRESENT	0
363347	345234	14081Q	PARTICIPANT	\N	PRESENT	0
363348	345234	11031D	PARTICIPANT	\N	PRESENT	0
363349	345234	19531S	PARTICIPANT	\N	PRESENT	0
363350	345234	17589D	PARTICIPANT	\N	PRESENT	0
363351	345234	19565D	PARTICIPANT	\N	PRESENT	0
363352	345234	11077T	PARTICIPANT	\N	PRESENT	0
363353	345234	19521Q	PARTICIPANT	\N	PRESENT	0
363354	345234	14235Q	PARTICIPANT	\N	PRESENT	0
363355	345234	95063L	PARTICIPANT	\N	PRESENT	0
363356	345234	08020N	PARTICIPANT	\N	PRESENT	0
363357	345234	14033T	PARTICIPANT	\N	PRESENT	0
363358	345234	19733B	PARTICIPANT	\N	PRESENT	0
363359	345234	14038Y	PARTICIPANT	\N	PRESENT	0
363360	345234	14029X	PARTICIPANT	\N	PRESENT	0
363361	345234	19551W	PARTICIPANT	\N	PRESENT	0
363362	345234	19533U	PARTICIPANT	\N	PRESENT	0
363363	345234	95067Q	PARTICIPANT	\N	PRESENT	0
363364	345234	14253S	PARTICIPANT	\N	PRESENT	0
363365	345234	19701S	PARTICIPANT	\N	PRESENT	0
363366	345234	10006L	PARTICIPANT	\N	PRESENT	0
363367	345234	19681G	PARTICIPANT	\N	PRESENT	0
363368	345234	14059S	PARTICIPANT	\N	PRESENT	0
363369	345234	14061L	PARTICIPANT	\N	PRESENT	0
363370	345234	19768N	PARTICIPANT	\N	PRESENT	0
363371	345234	14213J	PARTICIPANT	\N	PRESENT	0
363372	345234	04088S	PARTICIPANT	\N	PRESENT	0
363373	345234	19467C	PARTICIPANT	\N	PRESENT	0
363374	345234	19723Y	PARTICIPANT	\N	PRESENT	0
363375	345234	19349W	PARTICIPANT	\N	PRESENT	0
363376	345234	19383Y	PARTICIPANT	\N	PRESENT	0
363377	345234	14197C	PARTICIPANT	\N	PRESENT	0
363378	345234	19715Y	PARTICIPANT	\N	PRESENT	0
363379	345234	14215L	PARTICIPANT	\N	PRESENT	0
363380	345234	08015R	PARTICIPANT	\N	PRESENT	0
363381	345234	19719D	PARTICIPANT	\N	PRESENT	0
363382	345234	19387D	PARTICIPANT	\N	PRESENT	0
363383	345234	14169X	PARTICIPANT	\N	PRESENT	0
363384	345234	19507S	PARTICIPANT	\N	PRESENT	0
363385	345234	19573D	PARTICIPANT	\N	PRESENT	0
363386	345234	14083S	PARTICIPANT	\N	PRESENT	0
363387	345234	14107H	PARTICIPANT	\N	PRESENT	0
363388	345234	19629C	PARTICIPANT	\N	PRESENT	0
363389	345234	14259Y	PARTICIPANT	\N	PRESENT	0
363390	345234	14187A	PARTICIPANT	\N	PRESENT	0
363391	345234	14069U	PARTICIPANT	\N	PRESENT	0
363392	345234	14071N	PARTICIPANT	\N	PRESENT	0
363393	345234	19713W	PARTICIPANT	\N	PRESENT	0
363394	345234	19253P	PARTICIPANT	\N	PRESENT	0
363395	345234	14021P	PARTICIPANT	\N	PRESENT	0
363396	345234	11064N	PARTICIPANT	\N	PRESENT	0
363397	345234	11048N	PARTICIPANT	\N	PRESENT	0
363398	345234	11065P	PARTICIPANT	\N	PRESENT	0
363399	345234	14219Q	PARTICIPANT	\N	PRESENT	0
363400	345234	19739H	PARTICIPANT	\N	PRESENT	0
363401	345234	14257W	PARTICIPANT	\N	PRESENT	0
363402	345234	14089Y	PARTICIPANT	\N	PRESENT	0
363403	345234	19447X	PARTICIPANT	\N	PRESENT	0
363310	345234	14034U	PARTICIPANT	\N	PRESENT	0
363311	345234	99004R	PARTICIPANT	\N	PRESENT	0
363404	345234	01024M	PARTICIPANT	\N	PRESENT	0
374340	373764	11033F	PARTICIPANT	\N	PRESENT	0
374343	373764	04047H	PARTICIPANT	\N	PRESENT	0
374346	373764	19649G	PARTICIPANT	\N	PRESENT	0
374348	373764	11045K	PARTICIPANT	\N	PRESENT	0
374351	373764	14231L	PARTICIPANT	\N	PRESENT	0
374352	373764	19447X	PARTICIPANT	\N	PRESENT	0
374354	373764	01028R	PARTICIPANT	\N	PRESENT	0
374357	373764	10006L	PRESIDENT	0	PRESENT	0
374361	373764	14147R	PARTICIPANT	\N	PRESENT	0
374364	373764	19749K	PARTICIPANT	\N	PRESENT	0
374366	373764	11067R	PARTICIPANT	\N	PRESENT	0
382863	376746	11070L	PARTICIPANT	\N	PRESENT	0
382864	376746	04018C	PARTICIPANT	\N	PRESENT	0
382865	376746	14041T	PARTICIPANT	\N	PRESENT	0
382871	382747	14331P	PARTICIPANT	\N	PRESENT	0
382872	382747	19647E	PARTICIPANT	\N	PRESENT	0
382873	382747	19711U	PARTICIPANT	\N	PRESENT	0
382874	382747	19687N	PARTICIPANT	\N	PRESENT	0
382875	382747	11053K	PARTICIPANT	\N	PRESENT	0
382876	382747	19667J	PARTICIPANT	\N	PRESENT	0
382877	382747	08011M	PARTICIPANT	\N	PRESENT	0
382878	382747	11074Q	PRESIDENT	0	PRESENT	0
382879	382747	14034U	PARTICIPANT	\N	PRESENT	0
382880	382747	14159V	PARTICIPANT	\N	PRESENT	0
382881	382747	11070L	PARTICIPANT	\N	PRESENT	0
382882	382747	19671E	PARTICIPANT	\N	PRESENT	0
382883	382747	07004J	PARTICIPANT	\N	PRESENT	0
382884	382747	19741B	PARTICIPANT	\N	PRESENT	0
382885	382747	14121F	PARTICIPANT	\N	PRESENT	0
382886	382747	99004R	PARTICIPANT	\N	PRESENT	0
382887	376746	19593H	PARTICIPANT	\N	PRESENT	0
382888	376746	19413M	PARTICIPANT	\N	PRESENT	0
382889	376746	08017T	PARTICIPANT	\N	PRESENT	0
382890	376746	04070G	PARTICIPANT	\N	PRESENT	0
382891	376746	14229S	PARTICIPANT	\N	PRESENT	0
382892	376746	08039A	PARTICIPANT	\N	PRESENT	0
382893	376746	19611R	PARTICIPANT	\N	PRESENT	0
382894	376746	19741B	PARTICIPANT	\N	PRESENT	0
382895	376746	07004J	PARTICIPANT	\N	PRESENT	0
382896	376746	08043V	PARTICIPANT	\N	PRESENT	0
382897	376746	11012A	PARTICIPANT	\N	PRESENT	0
382898	376746	14241N	PARTICIPANT	\N	PRESENT	0
382899	376746	14093U	PARTICIPANT	\N	PRESENT	0
382900	376746	19687N	PARTICIPANT	\N	PRESENT	0
382901	376746	11074Q	PARTICIPANT	\N	PRESENT	0
382902	376746	19758L	PARTICIPANT	\N	PRESENT	0
382903	376746	19647E	PARTICIPANT	\N	PRESENT	0
382904	376746	14121F	PARTICIPANT	\N	PRESENT	0
382905	376746	04059M	PARTICIPANT	\N	PRESENT	0
382906	376746	14159V	PARTICIPANT	\N	PRESENT	0
382907	376746	11027H	PARTICIPANT	\N	PRESENT	0
382908	376746	19739H	PARTICIPANT	\N	PRESENT	0
387959	387793	01057W	PARTICIPANT	\N	PRESENT	0
387960	387793	11090Q	PARTICIPANT	\N	PRESENT	0
387961	387793	14031R	PARTICIPANT	\N	PRESENT	0
387962	387793	14157T	PARTICIPANT	\N	PRESENT	0
387963	387793	14199E	PARTICIPANT	\N	PRESENT	0
387964	387793	19575F	PARTICIPANT	\N	PRESENT	0
387965	387793	14253S	PARTICIPANT	\N	PRESENT	0
387966	387793	19768N	PARTICIPANT	\N	PRESENT	0
387967	387793	19667J	PARTICIPANT	\N	PRESENT	0
387968	387793	14029X	PARTICIPANT	\N	PRESENT	0
387969	387793	17637T	PARTICIPANT	\N	PRESENT	0
387970	387793	04049K	PARTICIPANT	\N	PRESENT	0
387971	387793	19583F	PARTICIPANT	\N	PRESENT	0
387972	387793	19563B	PARTICIPANT	\N	PRESENT	0
387973	387793	14026U	PARTICIPANT	\N	PRESENT	0
387974	387793	08049C	PARTICIPANT	\N	PRESENT	0
387975	387793	08044W	PARTICIPANT	\N	PRESENT	0
387976	387793	04047H	PARTICIPANT	\N	PRESENT	0
387977	387793	11027H	PARTICIPANT	\N	PRESENT	0
387978	387793	04097T	PARTICIPANT	\N	PRESENT	0
387979	387793	19741B	PARTICIPANT	\N	PRESENT	0
387980	387793	05008E	PARTICIPANT	\N	PRESENT	0
387981	387793	14357A	PARTICIPANT	\N	PRESENT	0
387982	387793	14038Y	PARTICIPANT	\N	PRESENT	0
387983	387793	19747H	PARTICIPANT	\N	PRESENT	0
387984	387793	96004D	PARTICIPANT	\N	PRESENT	0
387985	387793	14187A	PARTICIPANT	\N	PRESENT	0
387986	387793	08047A	PARTICIPANT	\N	PRESENT	0
387987	387793	11049P	PARTICIPANT	\N	PRESENT	0
387988	387793	07029T	PARTICIPANT	\N	PRESENT	0
387989	387793	14041T	PARTICIPANT	\N	PRESENT	0
387990	387793	19447X	PARTICIPANT	\N	PRESENT	0
387991	387793	04086Q	PARTICIPANT	\N	PRESENT	0
387992	387793	19533U	PARTICIPANT	\N	PRESENT	0
387993	387793	08018U	PARTICIPANT	\N	PRESENT	0
387994	387793	14205J	PARTICIPANT	\N	PRESENT	0
387995	387793	19794Q	PARTICIPANT	\N	PRESENT	0
387996	387793	14135M	PARTICIPANT	\N	PRESENT	0
387997	387793	14173T	PARTICIPANT	\N	PRESENT	0
387998	387793	08062Y	PARTICIPANT	\N	PRESENT	0
387999	387793	19685L	PARTICIPANT	\N	PRESENT	0
388000	387793	14147R	PARTICIPANT	\N	PRESENT	0
388001	387793	17589D	PARTICIPANT	\N	PRESENT	0
388002	387793	14265W	PARTICIPANT	\N	PRESENT	0
388003	387793	02002K	PARTICIPANT	\N	PRESENT	0
388004	387793	14121F	PARTICIPANT	\N	PRESENT	0
388005	387793	04035D	PARTICIPANT	\N	PRESENT	0
388006	387793	14079W	PARTICIPANT	\N	PRESENT	0
388007	387793	19693L	PARTICIPANT	\N	PRESENT	0
388008	387793	19251M	PARTICIPANT	\N	PRESENT	0
388009	387793	11074Q	PARTICIPANT	\N	PRESENT	0
388010	387793	08017T	PARTICIPANT	\N	PRESENT	0
388011	387793	19705W	PARTICIPANT	\N	PRESENT	0
388012	387793	04033B	PARTICIPANT	\N	PRESENT	0
388013	387793	19507S	PARTICIPANT	\N	PRESENT	0
388014	387793	01025N	PARTICIPANT	\N	PRESENT	0
388015	387793	95030B	PARTICIPANT	\N	PRESENT	0
388016	387793	98050T	PARTICIPANT	\N	PRESENT	0
388017	387793	05012A	PARTICIPANT	\N	PRESENT	0
388018	387793	19467C	PARTICIPANT	\N	PRESENT	0
388019	387793	08034U	PARTICIPANT	\N	PRESENT	0
388020	387793	19729F	PARTICIPANT	\N	PRESENT	0
388021	387793	14069U	PARTICIPANT	\N	PRESENT	0
388022	387793	19733B	PARTICIPANT	\N	PRESENT	0
388023	387793	07033P	PARTICIPANT	\N	PRESENT	0
388024	387793	14217N	PARTICIPANT	\N	PRESENT	0
388025	387793	14115H	PARTICIPANT	\N	PRESENT	0
388026	387793	19399H	PARTICIPANT	\N	PRESENT	0
388027	387793	19675J	PARTICIPANT	\N	PRESENT	0
388028	387793	14329V	PARTICIPANT	\N	PRESENT	0
388029	387793	04044E	PARTICIPANT	\N	PRESENT	0
388030	387793	14053L	PARTICIPANT	\N	PRESENT	0
388031	387793	14215L	PARTICIPANT	\N	PRESENT	0
388077	387793	19383Y	PARTICIPANT	\N	PRESENT	0
388078	387793	19762G	PARTICIPANT	\N	PRESENT	0
388079	387793	11048N	PARTICIPANT	\N	PRESENT	0
388080	387793	11010L	PARTICIPANT	\N	PRESENT	0
388081	387793	14033T	PARTICIPANT	\N	PRESENT	0
388082	387793	19701S	PARTICIPANT	\N	PRESENT	0
388083	387793	95041E	PARTICIPANT	\N	PRESENT	0
388084	387793	14061L	PARTICIPANT	\N	PRESENT	0
388085	387793	14059S	PARTICIPANT	\N	PRESENT	0
388086	387793	04092N	PARTICIPANT	\N	PRESENT	0
388087	387793	08020N	PARTICIPANT	\N	PRESENT	0
388088	387793	98024R	PARTICIPANT	\N	PRESENT	0
388089	387793	04008A	PARTICIPANT	\N	PRESENT	0
388090	387793	19421M	PARTICIPANT	\N	PRESENT	0
388091	387793	19671E	PARTICIPANT	\N	PRESENT	0
388092	387793	97011G	PARTICIPANT	\N	PRESENT	0
388093	387793	04088S	PARTICIPANT	\N	PRESENT	0
388094	387793	18083K	PARTICIPANT	\N	PRESENT	0
388095	387793	19687N	PARTICIPANT	\N	PRESENT	0
388096	387793	19631V	PARTICIPANT	\N	PRESENT	0
388097	387793	11041F	PARTICIPANT	\N	PRESENT	0
388098	387793	95067Q	PARTICIPANT	\N	PRESENT	0
388099	387793	14257W	PARTICIPANT	\N	PRESENT	0
388100	387793	19585H	PARTICIPANT	\N	PRESENT	0
388101	387793	11104D	PARTICIPANT	\N	PRESENT	0
388102	387793	19709B	PARTICIPANT	\N	PRESENT	0
388103	387793	19699S	PARTICIPANT	\N	PRESENT	0
388104	387793	19611R	PARTICIPANT	\N	PRESENT	0
388105	387793	14133K	PARTICIPANT	\N	PRESENT	0
388107	387793	14111D	PARTICIPANT	\N	PRESENT	0
388108	387793	14225N	PARTICIPANT	\N	PRESENT	0
388109	387793	08038Y	PARTICIPANT	\N	PRESENT	0
388110	387793	11101A	PARTICIPANT	\N	PRESENT	0
388111	387793	14105F	PARTICIPANT	\N	PRESENT	0
388112	387793	08015R	PARTICIPANT	\N	PRESENT	0
388116	387793	19749K	PARTICIPANT	\N	PRESENT	0
388114	387793	14193X	PARTICIPANT	\N	PRESENT	0
388120	387793	19673G	PARTICIPANT	\N	PRESENT	0
388117	387793	14237S	PARTICIPANT	\N	PRESENT	0
388118	387793	14331P	PARTICIPANT	\N	PRESENT	0
388122	387793	11103C	PARTICIPANT	\N	PRESENT	0
388123	387793	19415P	PARTICIPANT	\N	PRESENT	0
388124	387793	19798U	PARTICIPANT	\N	PRESENT	0
388125	387793	19663E	PARTICIPANT	\N	PRESENT	0
388126	387793	19657G	PARTICIPANT	\N	PRESENT	0
388134	387793	14213J	PARTICIPANT	\N	PRESENT	0
388128	387793	08048B	PARTICIPANT	\N	PRESENT	0
388129	387793	19441R	PARTICIPANT	\N	PRESENT	0
388131	387793	08058D	PARTICIPANT	\N	PRESENT	0
388132	387793	19703U	PARTICIPANT	\N	PRESENT	0
388133	387793	11080N	PARTICIPANT	\N	PRESENT	0
363428	363427	19709B	PARTICIPANT	\N	PRESENT	0
369693	369692	14053L	PARTICIPANT	\N	PRESENT	0
369694	369692	14026U	PARTICIPANT	\N	PRESENT	0
369696	369695	14053L	PARTICIPANT	\N	PRESENT	0
369698	369697	14053L	PARTICIPANT	\N	PRESENT	0
369699	369697	14026U	PARTICIPANT	\N	PRESENT	0
369701	369700	14053L	PARTICIPANT	\N	PRESENT	0
369702	369700	14026U	PARTICIPANT	\N	PRESENT	0
369705	369704	14053L	PARTICIPANT	\N	PRESENT	0
369706	369704	14026U	PARTICIPANT	\N	PRESENT	0
369708	369707	14053L	PARTICIPANT	\N	PRESENT	0
369710	369709	14053L	PARTICIPANT	\N	PRESENT	0
369714	369713	14053L	PARTICIPANT	\N	PRESENT	0
369715	369713	14281W	PARTICIPANT	\N	PRESENT	0
373819	373691	19479G	PARTICIPANT	\N	EXCUSE	0
373820	373691	19349W	PARTICIPANT	\N	PRESENT	0
373821	373691	19667J	PARTICIPANT	\N	PRESENT	0
373822	373691	14147R	PARTICIPANT	\N	PRESENT	0
373823	373691	19737F	PARTICIPANT	\N	PRESENT	0
373958	373691	04038G	PARTICIPANT	\N	PRESENT	0
373960	373691	19569H	PARTICIPANT	\N	PRESENT	0
373961	373691	08069G	PARTICIPANT	\N	PRESENT	0
373994	373691	08045X	PARTICIPANT	\N	PRESENT	0
373995	373688	19687N	PARTICIPANT	\N	EXCUSE	0
373996	373688	01048V	PARTICIPANT	\N	EXCUSE	0
373997	373688	14121F	PARTICIPANT	\N	EXCUSE	0
373998	373688	07004J	PARTICIPANT	\N	EXCUSE	0
375350	375349	14219Q	PARTICIPANT	\N	PRESENT	0
375352	375351	14219Q	PARTICIPANT	\N	PRESENT	0
375354	375353	14219Q	PARTICIPANT	\N	PRESENT	0
375356	375355	14219Q	PARTICIPANT	\N	PRESENT	0
375357	375355	19794Q	PARTICIPANT	\N	PRESENT	0
375359	375358	14219Q	PARTICIPANT	\N	PRESENT	0
375360	375358	19713W	PARTICIPANT	\N	PRESENT	0
375371	375363	19794Q	PARTICIPANT	\N	PRESENT	0
375372	375363	19713W	PARTICIPANT	\N	PRESENT	0
375373	375363	14219Q	PARTICIPANT	\N	PRESENT	0
375387	375377	14219Q	PARTICIPANT	\N	PRESENT	0
375388	375377	19794Q	PARTICIPANT	\N	PRESENT	0
375389	375377	19713W	PARTICIPANT	\N	PRESENT	0
375403	375395	14219Q	PARTICIPANT	\N	PRESENT	0
375404	375395	19794Q	PARTICIPANT	\N	PRESENT	0
375405	375395	19713W	PARTICIPANT	\N	PRESENT	0
375406	375395	14157T	PARTICIPANT	\N	PRESENT	0
375427	375423	14219Q	PARTICIPANT	\N	PRESENT	0
375428	375423	19794Q	PARTICIPANT	\N	PRESENT	0
375429	375423	19713W	PARTICIPANT	\N	PRESENT	0
375430	375423	14157T	PARTICIPANT	\N	PRESENT	0
377060	371473	97011G	PARTICIPANT	\N	PRESENT	0
377061	371473	19573D	PARTICIPANT	\N	PRESENT	0
377062	376985	14061L	PARTICIPANT	\N	PRESENT	0
377063	376985	14073Q	PARTICIPANT	\N	PRESENT	0
377064	376985	14251Q	PARTICIPANT	\N	PRESENT	0
377065	376985	11109J	PARTICIPANT	\N	PRESENT	0
377066	376985	11043H	PARTICIPANT	\N	PRESENT	0
377067	371473	19527W	PARTICIPANT	\N	PRESENT	0
377068	371473	11066Q	PARTICIPANT	\N	PRESENT	0
377069	371473	11109J	PARTICIPANT	\N	PRESENT	0
377070	371473	19693L	PARTICIPANT	\N	PRESENT	0
377071	371473	14001X	PARTICIPANT	\N	PRESENT	0
377075	371473	14115H	PARTICIPANT	\N	PRESENT	0
377076	371473	14221J	PARTICIPANT	\N	PRESENT	0
377077	371473	14073Q	PARTICIPANT	\N	PRESENT	0
377078	371473	19749K	PARTICIPANT	\N	PRESENT	0
377079	371473	14029X	PARTICIPANT	\N	PRESENT	0
377080	371473	14097Y	PARTICIPANT	\N	PRESENT	0
377081	371473	14173T	PARTICIPANT	\N	PRESENT	0
377082	371473	14038Y	PARTICIPANT	\N	PRESENT	0
377084	371473	15447F	PARTICIPANT	\N	PRESENT	0
377085	371473	10015M	PARTICIPANT	\N	PRESENT	0
377086	371473	14223L	PARTICIPANT	\N	PRESENT	0
377087	371473	14217N	PARTICIPANT	\N	PRESENT	0
377088	371473	19691J	PARTICIPANT	\N	PRESENT	0
377089	371473	14135M	PARTICIPANT	\N	PRESENT	0
377091	371473	19695N	PARTICIPANT	\N	PRESENT	0
377092	371473	87003B	PARTICIPANT	\N	PRESENT	0
377093	371473	19719D	PARTICIPANT	\N	PRESENT	0
377094	371473	96004D	PARTICIPANT	\N	PRESENT	0
377095	371473	19551W	PARTICIPANT	\N	PRESENT	0
377096	371473	19782L	PARTICIPANT	\N	PRESENT	0
377098	371473	14031R	PARTICIPANT	\N	PRESENT	0
377099	371473	08043V	PARTICIPANT	\N	PRESENT	0
377100	371473	19715Y	PARTICIPANT	\N	PRESENT	0
377101	371473	98029W	PARTICIPANT	\N	PRESENT	0
377118	371474	14235Q	PARTICIPANT	\N	PRESENT	0
377119	371474	14151M	PARTICIPANT	\N	PRESENT	0
377120	371474	19593H	PARTICIPANT	\N	PRESENT	0
377121	371474	19758L	PARTICIPANT	\N	PRESENT	0
377122	371474	11040E	PARTICIPANT	\N	PRESENT	0
377123	371474	11031D	PARTICIPANT	\N	PRESENT	0
377124	371474	12041X	PARTICIPANT	\N	PRESENT	0
377125	371474	14039A	PARTICIPANT	\N	PRESENT	0
377126	371474	04045F	PARTICIPANT	\N	PRESENT	0
377127	371474	04034C	PARTICIPANT	\N	PRESENT	0
377128	371474	19697Q	PARTICIPANT	\N	PRESENT	0
377129	371474	14239U	PARTICIPANT	\N	PRESENT	0
377130	371474	19651A	PARTICIPANT	\N	PRESENT	0
377115	371474	86034E	PARTICIPANT	\N	PRESENT	0
377117	377116	98029W	PARTICIPANT	\N	PRESENT	0
377131	371474	19782L	PARTICIPANT	\N	PRESENT	0
377132	371474	95063L	PARTICIPANT	\N	PRESENT	0
377133	371474	98029W	PARTICIPANT	\N	PRESENT	0
377134	371474	08024S	PARTICIPANT	\N	PRESENT	0
377135	371474	11083R	PARTICIPANT	\N	PRESENT	0
377136	371474	14241N	PARTICIPANT	\N	PRESENT	0
377137	371474	08031R	PARTICIPANT	\N	PRESENT	0
377138	371474	14055N	PARTICIPANT	\N	PRESENT	0
377139	371474	19731Y	PARTICIPANT	\N	PRESENT	0
377140	371474	14107H	PARTICIPANT	\N	PRESENT	0
377141	371474	14021P	PARTICIPANT	\N	PRESENT	0
377142	371474	19333N	PARTICIPANT	\N	PRESENT	0
377143	371474	19591F	PARTICIPANT	\N	PRESENT	0
377144	371474	19413M	PARTICIPANT	\N	PRESENT	0
377145	371474	11074Q	PARTICIPANT	\N	PRESENT	0
377146	371474	01028R	PARTICIPANT	\N	PRESENT	0
377147	371474	08043V	PARTICIPANT	\N	PRESENT	0
377148	371474	19727D	PARTICIPANT	\N	PRESENT	0
377149	371474	19715Y	PARTICIPANT	\N	PRESENT	0
377150	371474	19649G	PARTICIPANT	\N	PRESENT	0
378079	377015	14225N	PARTICIPANT	\N	PRESENT	0
378080	377015	14173T	PARTICIPANT	\N	PRESENT	0
378081	377015	04086Q	PARTICIPANT	\N	PRESENT	0
378082	377015	14083S	PARTICIPANT	\N	PRESENT	0
378083	377015	07029T	PARTICIPANT	\N	PRESENT	0
378084	377015	14085U	PARTICIPANT	\N	PRESENT	0
378085	377015	07004J	PARTICIPANT	\N	PRESENT	0
378086	377015	19349W	PARTICIPANT	\N	PRESENT	0
378087	377015	08010L	PARTICIPANT	\N	PRESENT	0
378088	377015	14121F	PARTICIPANT	\N	PRESENT	0
378089	377015	19687N	PARTICIPANT	\N	EXCUSE	0
378090	377015	12016W	PARTICIPANT	\N	PRESENT	0
378094	377015	19671E	PARTICIPANT	\N	PRESENT	0
378112	378111	14173T	PARTICIPANT	\N	PRESENT	0
378116	378111	19447X	PARTICIPANT	\N	PRESENT	0
378117	378111	08045X	PARTICIPANT	\N	PRESENT	0
378151	371476	04086Q	PARTICIPANT	\N	PRESENT	0
378152	371476	14123H	PARTICIPANT	\N	PRESENT	0
378157	371476	08017T	PARTICIPANT	\N	PRESENT	0
378158	371476	11043H	PARTICIPANT	\N	PRESENT	0
378159	371476	14157T	PARTICIPANT	\N	PRESENT	0
378160	371476	19749K	PARTICIPANT	\N	PRESENT	0
378161	371476	14219Q	PARTICIPANT	\N	PRESENT	0
378162	371476	19735D	PARTICIPANT	\N	PRESENT	0
378163	371476	08043V	PARTICIPANT	\N	PRESENT	0
378164	371476	19593H	PARTICIPANT	\N	PRESENT	0
378165	371476	19621T	PARTICIPANT	\N	PRESENT	0
378166	371476	19563B	PARTICIPANT	\N	PRESENT	0
378167	371476	19758L	PARTICIPANT	\N	PRESENT	0
378168	371476	19251M	PARTICIPANT	\N	PRESENT	0
378169	371476	19737F	PARTICIPANT	\N	PRESENT	0
378170	371476	08035V	PARTICIPANT	\N	PRESENT	0
378171	371476	19387D	PARTICIPANT	\N	PRESENT	0
378172	371476	14229S	PARTICIPANT	\N	PRESENT	0
378173	371476	14227Q	PARTICIPANT	\N	PRESENT	0
378175	371476	19747H	PARTICIPANT	\N	PRESENT	0
378176	371476	04045F	PARTICIPANT	\N	PRESENT	0
378177	371476	14039A	PARTICIPANT	\N	PRESENT	0
378178	371476	14061L	PARTICIPANT	\N	PRESENT	0
378179	371476	19794Q	PARTICIPANT	\N	PRESENT	0
378180	371476	19673G	PARTICIPANT	\N	PRESENT	0
378181	371476	14063N	PARTICIPANT	\N	PRESENT	0
378182	371476	08061X	PARTICIPANT	\N	PRESENT	0
378183	371476	08056B	PARTICIPANT	\N	PRESENT	0
378184	371476	19569H	PARTICIPANT	\N	PRESENT	0
378185	371476	19739H	PARTICIPANT	\N	PRESENT	0
378186	371476	14109K	PARTICIPANT	\N	PRESENT	0
378187	371476	95030B	PARTICIPANT	\N	PRESENT	0
378188	371476	14033T	PARTICIPANT	\N	PRESENT	0
378189	371476	08028W	PARTICIPANT	\N	PRESENT	0
378215	371476	14105F	PARTICIPANT	\N	PRESENT	0
378192	371476	14042U	PARTICIPANT	\N	PRESENT	0
378193	371476	19329S	PARTICIPANT	\N	PRESENT	0
378194	371476	19697Q	PARTICIPANT	\N	PRESENT	0
378195	371476	11065P	PARTICIPANT	\N	PRESENT	0
378196	371476	98005N	PARTICIPANT	\N	PRESENT	0
378197	371476	11109J	PARTICIPANT	\N	PRESENT	0
378198	371476	19503N	PARTICIPANT	\N	PRESENT	0
378199	371476	19253P	PARTICIPANT	\N	PRESENT	0
378200	371476	19760E	PARTICIPANT	\N	PRESENT	0
378201	371476	14107H	PARTICIPANT	\N	PRESENT	0
378202	371476	14089Y	PARTICIPANT	\N	PRESENT	0
378203	371476	08024S	PARTICIPANT	\N	PRESENT	0
378204	371476	01048V	PARTICIPANT	\N	PRESENT	0
378205	371476	04070G	PARTICIPANT	\N	PRESENT	0
378206	371476	11077T	PARTICIPANT	\N	PRESENT	0
378207	371476	11099A	PARTICIPANT	\N	PRESENT	0
378208	371476	19443T	PARTICIPANT	\N	PRESENT	0
378209	371476	19577H	PARTICIPANT	\N	PRESENT	0
378210	371476	19441R	PARTICIPANT	\N	PRESENT	0
378212	371476	14211G	PARTICIPANT	\N	PRESENT	0
378214	371476	19647E	PARTICIPANT	\N	PRESENT	0
378216	371476	19399H	PARTICIPANT	\N	PRESENT	0
378217	371476	04057K	PARTICIPANT	\N	PRESENT	0
378218	371476	11033F	PARTICIPANT	\N	PRESENT	0
378219	371476	19701S	PARTICIPANT	\N	PRESENT	0
378220	371476	04018C	PARTICIPANT	\N	PRESENT	0
378221	371476	14231L	PARTICIPANT	\N	PRESENT	0
378222	371476	19583F	PARTICIPANT	\N	PRESENT	0
378223	371476	11104D	PARTICIPANT	\N	PRESENT	0
378224	371476	11067R	PARTICIPANT	\N	PRESENT	0
378225	371476	14111D	PARTICIPANT	\N	PRESENT	0
378226	371476	14265W	PARTICIPANT	\N	PRESENT	0
378227	371476	14083S	PARTICIPANT	\N	PRESENT	0
378276	371476	14021P	PARTICIPANT	\N	PRESENT	0
378229	371476	01025N	PARTICIPANT	\N	PRESENT	0
378230	371476	04089T	PARTICIPANT	\N	PRESENT	0
378232	371476	19631V	PARTICIPANT	\N	PRESENT	0
378233	371476	08060W	PARTICIPANT	\N	PRESENT	0
378235	371476	14241N	PARTICIPANT	\N	PRESENT	0
378236	371476	14041T	PARTICIPANT	\N	PRESENT	0
378237	371476	14051J	PARTICIPANT	\N	PRESENT	0
378238	371476	14147R	PARTICIPANT	\N	PRESENT	0
378239	371476	19447X	PARTICIPANT	\N	PRESENT	0
378240	371476	15447F	PARTICIPANT	\N	PRESENT	0
378241	371476	14115H	PARTICIPANT	\N	PRESENT	0
378242	371476	08020N	PARTICIPANT	\N	PRESENT	0
378243	371476	14069U	PARTICIPANT	\N	PRESENT	0
378244	371476	19383Y	PARTICIPANT	\N	PRESENT	0
378245	371476	14073Q	PARTICIPANT	\N	PRESENT	0
378246	371476	14235Q	PARTICIPANT	\N	PRESENT	0
378247	371476	04043D	PARTICIPANT	\N	PRESENT	0
378248	371476	19729F	PARTICIPANT	\N	PRESENT	0
378249	371476	14173T	PARTICIPANT	\N	PRESENT	0
378250	371476	14029X	PARTICIPANT	\N	PRESENT	0
378251	371476	19335Q	PARTICIPANT	\N	PRESENT	0
378252	371476	19367Y	PARTICIPANT	\N	PRESENT	0
378253	371476	14030Q	PARTICIPANT	\N	PRESENT	0
378254	371476	19507S	PARTICIPANT	\N	PRESENT	0
378255	371476	08039A	PARTICIPANT	\N	PRESENT	0
378261	371476	97011G	PARTICIPANT	\N	PRESENT	0
378262	371476	14187A	PARTICIPANT	\N	PRESENT	0
378263	371476	19669L	PARTICIPANT	\N	PRESENT	0
378264	371476	11026G	PARTICIPANT	\N	PRESENT	0
378265	371476	19671E	PARTICIPANT	\N	PRESENT	0
378266	371476	08034U	PARTICIPANT	\N	PRESENT	0
378267	371476	14169X	PARTICIPANT	\N	PRESENT	0
378268	371476	19768N	PARTICIPANT	\N	PRESENT	0
378269	371476	19693L	PARTICIPANT	\N	PRESENT	0
378270	371476	80013X	PARTICIPANT	\N	PRESENT	0
378271	371476	19599P	PARTICIPANT	\N	PRESENT	0
378272	371476	11101A	PARTICIPANT	\N	PRESENT	0
378273	371476	19533U	PARTICIPANT	\N	PRESENT	0
378274	371476	19719D	PARTICIPANT	\N	PRESENT	0
378275	371476	19467C	PARTICIPANT	\N	PRESENT	0
378277	371476	19521Q	PARTICIPANT	\N	PRESENT	0
378278	371476	08010L	PARTICIPANT	\N	PRESENT	0
378279	371476	11064N	PARTICIPANT	\N	PRESENT	0
378280	371476	19725B	PARTICIPANT	\N	PRESENT	0
378281	371476	04059M	PARTICIPANT	\N	PRESENT	0
378282	371476	19301E	PARTICIPANT	\N	PRESENT	0
378283	371476	19782L	PARTICIPANT	\N	PRESENT	0
378284	371476	04088S	PARTICIPANT	\N	PRESENT	0
378285	371476	19585H	PARTICIPANT	\N	PRESENT	0
378286	371476	14259Y	PARTICIPANT	\N	PRESENT	0
378287	371476	04040A	PARTICIPANT	\N	PRESENT	0
378288	377016	19711U	PARTICIPANT	\N	PRESENT	0
378289	377016	11074Q	PRESIDENT	0	PRESENT	0
378290	377016	14253S	PARTICIPANT	\N	PRESENT	0
378291	377016	08011M	PARTICIPANT	\N	PRESENT	0
378292	377016	11070L	PARTICIPANT	\N	PRESENT	0
378293	377016	88008L	PARTICIPANT	\N	PRESENT	0
378295	377016	19687N	PARTICIPANT	\N	EXCUSE	0
378296	371476	01024M	PARTICIPANT	\N	PRESENT	0
378297	371476	14093U	PARTICIPANT	\N	PRESENT	0
378298	371476	07033P	PARTICIPANT	\N	PRESENT	0
378299	371476	19637C	PARTICIPANT	\N	PRESENT	0
378300	371476	14197C	PARTICIPANT	\N	PRESENT	0
378301	371476	19295A	PARTICIPANT	\N	PRESENT	0
378302	371476	17583W	PARTICIPANT	\N	PRESENT	0
378303	371476	19573D	PARTICIPANT	\N	PRESENT	0
378304	371476	14251Q	PARTICIPANT	\N	PRESENT	0
378305	371476	11085T	PARTICIPANT	\N	PRESENT	0
378306	371476	19611R	PARTICIPANT	\N	PRESENT	0
378307	371476	17779H	PARTICIPANT	\N	PRESENT	0
378308	371476	19525U	PARTICIPANT	\N	PRESENT	0
378309	371476	01062T	PARTICIPANT	\N	PRESENT	0
378310	371476	14103D	PARTICIPANT	\N	PRESENT	0
378311	371476	08044W	PARTICIPANT	\N	PRESENT	0
378312	371476	19643A	PARTICIPANT	\N	PRESENT	0
378313	371476	08015R	PARTICIPANT	\N	PRESENT	0
378314	371476	04044E	PARTICIPANT	\N	PRESENT	0
378315	371476	19695N	PARTICIPANT	\N	PRESENT	0
368971	368970	14255U	PARTICIPANT	\N	PRESENT	0
368972	368970	18083K	PARTICIPANT	\N	PRESENT	0
368973	368970	19701S	PARTICIPANT	\N	PRESENT	0
368974	368970	14281W	PARTICIPANT	\N	PRESENT	0
368975	368970	19671E	PARTICIPANT	\N	PRESENT	0
368976	368970	19762G	PARTICIPANT	\N	PRESENT	0
373574	370780	04043D	PARTICIPANT	\N	PRESENT	0
373575	370795	04043D	PARTICIPANT	\N	PRESENT	0
373576	371078	04043D	PARTICIPANT	\N	PRESENT	0
373779	370768	08034U	PARTICIPANT	\N	PRESENT	0
373781	373780	14327T	PARTICIPANT	\N	PRESENT	0
373782	369716	08034U	PARTICIPANT	\N	PRESENT	0
373789	373788	19647E	PARTICIPANT	\N	PRESENT	0
373785	373784	04040A	PRESIDENT	0	PRESENT	0
382909	376746	14034U	PARTICIPANT	\N	PRESENT	0
382910	376746	11083R	PARTICIPANT	\N	PRESENT	0
382911	376746	19651A	PARTICIPANT	\N	PRESENT	0
382912	376746	11053K	PARTICIPANT	\N	PRESENT	0
382913	376746	19671E	PARTICIPANT	\N	PRESENT	0
382914	376746	99004R	PARTICIPANT	\N	PRESENT	0
382915	376746	19693L	PARTICIPANT	\N	PRESENT	0
382916	376746	19533U	PARTICIPANT	\N	PRESENT	0
382917	376746	19711U	PARTICIPANT	\N	PRESENT	0
382918	376746	19399H	PARTICIPANT	\N	PRESENT	0
382919	376746	19667J	PARTICIPANT	\N	PRESENT	0
382920	376746	04071H	PARTICIPANT	\N	PRESENT	0
382921	376746	19643A	PARTICIPANT	\N	PRESENT	0
382922	376746	08034U	PARTICIPANT	\N	PRESENT	0
382923	376746	19745F	PARTICIPANT	\N	PRESENT	0
382924	376746	19749K	PARTICIPANT	\N	PRESENT	0
382925	376746	19701S	PARTICIPANT	\N	PRESENT	0
382926	376746	08011M	PARTICIPANT	\N	PRESENT	0
382927	376746	11097X	PARTICIPANT	\N	PRESENT	0
382928	376746	11103C	PARTICIPANT	\N	PRESENT	0
382929	376746	04033B	PARTICIPANT	\N	PRESENT	0
382930	376746	14109K	PARTICIPANT	\N	PRESENT	0
382931	376746	14021P	PARTICIPANT	\N	PRESENT	0
382932	376746	19691J	PARTICIPANT	\N	PRESENT	0
382933	376746	14329V	PARTICIPANT	\N	PRESENT	0
382946	376746	04043D	PARTICIPANT	\N	PRESENT	0
382947	376746	19735D	PARTICIPANT	\N	PRESENT	0
382948	376746	07033P	PARTICIPANT	\N	PRESENT	0
382949	376746	14179A	PARTICIPANT	\N	PRESENT	0
382950	376746	14249W	PARTICIPANT	\N	PRESENT	0
382951	376746	04085P	PARTICIPANT	\N	PRESENT	0
382952	376746	14085U	PARTICIPANT	\N	PRESENT	0
382953	376746	17637T	PARTICIPANT	\N	PRESENT	0
382954	376746	14071N	PARTICIPANT	\N	PRESENT	0
382955	376746	95041E	PARTICIPANT	\N	PRESENT	0
382956	376746	14069U	PARTICIPANT	\N	PRESENT	0
382957	376746	14331P	PARTICIPANT	\N	PRESENT	0
382958	376746	14030Q	PARTICIPANT	\N	PRESENT	0
382959	376746	19713W	PARTICIPANT	\N	PRESENT	0
382960	376746	11048N	PARTICIPANT	\N	PRESENT	0
382961	376746	14083S	PARTICIPANT	\N	PRESENT	0
383012	376747	04059M	PARTICIPANT	\N	PRESENT	0
383013	376747	14229S	PARTICIPANT	\N	PRESENT	0
383014	376747	08043V	PARTICIPANT	\N	PRESENT	0
383015	376747	19503N	PARTICIPANT	\N	PRESENT	0
383016	376747	14241N	PARTICIPANT	\N	PRESENT	0
383017	376747	14030Q	PARTICIPANT	\N	PRESENT	0
383018	376747	14089Y	PARTICIPANT	\N	PRESENT	0
383019	376747	19593H	PARTICIPANT	\N	PRESENT	0
383020	376747	14329V	PARTICIPANT	\N	PRESENT	0
383021	376747	07033P	PARTICIPANT	\N	PRESENT	0
383022	376747	14041T	PARTICIPANT	\N	PRESENT	0
383023	376747	19399H	PARTICIPANT	\N	PRESENT	0
383024	376747	04071H	PARTICIPANT	\N	PRESENT	0
383025	376747	08039A	PARTICIPANT	\N	PRESENT	0
383026	376747	04035D	PARTICIPANT	\N	PRESENT	0
383027	376747	14109K	PARTICIPANT	\N	PRESENT	0
383028	376747	04070G	PARTICIPANT	\N	PRESENT	0
383029	376747	19739H	PARTICIPANT	\N	PRESENT	0
383030	376747	11083R	PARTICIPANT	\N	PRESENT	0
383031	376747	19533U	PARTICIPANT	\N	PRESENT	0
383032	376747	19735D	PARTICIPANT	\N	PRESENT	0
383033	376747	11012A	PARTICIPANT	\N	PRESENT	0
383034	376747	19758L	PARTICIPANT	\N	PRESENT	0
383035	376747	19573D	PARTICIPANT	\N	PRESENT	0
383036	376747	19643A	PARTICIPANT	\N	PRESENT	0
383037	376747	14093U	PARTICIPANT	\N	PRESENT	0
383038	376747	19749K	PARTICIPANT	\N	PRESENT	0
383039	376747	19693L	PARTICIPANT	\N	PRESENT	0
383040	376747	14073Q	PARTICIPANT	\N	PRESENT	0
383041	376747	14249W	PARTICIPANT	\N	PRESENT	0
383042	376747	19713W	PARTICIPANT	\N	PRESENT	0
383043	376747	11048N	PARTICIPANT	\N	PRESENT	0
383044	376747	08020N	PARTICIPANT	\N	PRESENT	0
383045	376747	19741B	PARTICIPANT	\N	PRESENT	0
383046	376747	08011M	PARTICIPANT	\N	PRESENT	0
383047	376747	08034U	PARTICIPANT	\N	PRESENT	0
383048	376747	19611R	PARTICIPANT	\N	PRESENT	0
383049	376747	11097X	PARTICIPANT	\N	PRESENT	0
383050	376747	14069U	PARTICIPANT	\N	PRESENT	0
383051	376747	14213J	PARTICIPANT	\N	PRESENT	0
383052	376747	14331P	PARTICIPANT	\N	PRESENT	0
383053	376747	11085T	PARTICIPANT	\N	PRESENT	0
383054	376747	02002K	PARTICIPANT	\N	PRESENT	0
384668	384667	04043D	PARTICIPANT	\N	PRESENT	0
384669	384667	19441R	PARTICIPANT	\N	PRESENT	0
384670	384667	14205J	PARTICIPANT	\N	PRESENT	0
384672	384671	14157T	PRESIDENT	0	PRESENT	0
384673	384671	19762G	PARTICIPANT	\N	PRESENT	0
383010	376747	14034U	PARTICIPANT	\N	PRESENT	0
383011	376747	04018C	PARTICIPANT	\N	PRESENT	0
384674	384671	19745F	PARTICIPANT	\N	PRESENT	0
384675	384671	14207L	PARTICIPANT	\N	PRESENT	0
384676	384671	08060W	PARTICIPANT	\N	PRESENT	0
384677	384671	19733B	PARTICIPANT	\N	PRESENT	0
384678	384671	19715Y	PARTICIPANT	\N	EXCUSE	0
384682	384671	08024S	PARTICIPANT	\N	PRESENT	0
384680	384671	08049C	PARTICIPANT	\N	EXCUSE	0
384681	384671	14097Y	PARTICIPANT	\N	EXCUSE	0
384685	384684	14133K	PARTICIPANT	\N	PRESENT	0
384688	384687	11053K	PARTICIPANT	\N	PRESENT	0
384689	384687	14159V	PARTICIPANT	\N	PRESENT	0
384690	384687	05012A	PARTICIPANT	\N	PRESENT	0
384692	384691	19705W	PARTICIPANT	\N	PRESENT	0
384693	384691	19515S	PARTICIPANT	\N	PRESENT	0
384694	384691	19269X	PARTICIPANT	\N	PRESENT	0
384695	384691	19369B	PARTICIPANT	\N	PRESENT	0
386664	377925	14033T	PARTICIPANT	\N	PRESENT	0
386665	377925	19415P	PARTICIPANT	\N	PRESENT	0
386666	377925	19794Q	PARTICIPANT	\N	PRESENT	0
386667	377925	14147R	PARTICIPANT	\N	PRESENT	0
386668	377925	11097X	PARTICIPANT	\N	PRESENT	0
386669	377925	14223L	PARTICIPANT	\N	PRESENT	0
386670	377925	11103C	PARTICIPANT	\N	PRESENT	0
386671	377925	10006L	PARTICIPANT	\N	PRESENT	0
386672	377925	19798U	PARTICIPANT	\N	PRESENT	0
386673	377925	04057K	PARTICIPANT	\N	PRESENT	0
386674	377925	14157T	PARTICIPANT	\N	PRESENT	0
386675	377925	87003B	PARTICIPANT	\N	PRESENT	0
386676	377925	19575F	PARTICIPANT	\N	PRESENT	0
386677	377925	19679N	PARTICIPANT	\N	PRESENT	0
386678	377925	19713W	PARTICIPANT	\N	PRESENT	0
386679	377925	98024R	PARTICIPANT	\N	PRESENT	0
386680	377925	04092N	PARTICIPANT	\N	PRESENT	0
386681	377925	19725B	PARTICIPANT	\N	PRESENT	0
386682	377925	19657G	PARTICIPANT	\N	PRESENT	0
386683	377925	14107H	PARTICIPANT	\N	PRESENT	0
386684	377925	14030Q	PARTICIPANT	\N	PRESENT	0
386685	377925	14219Q	PARTICIPANT	\N	PRESENT	0
386686	377925	19760E	PARTICIPANT	\N	PRESENT	0
386687	377925	19599P	PARTICIPANT	\N	PRESENT	0
386688	377925	19301E	PARTICIPANT	\N	PRESENT	0
386689	377925	04018C	PARTICIPANT	\N	PRESENT	0
386690	377925	14087W	PARTICIPANT	\N	PRESENT	0
386691	377925	14105F	PARTICIPANT	\N	PRESENT	0
386692	377925	08020N	PARTICIPANT	\N	PRESENT	0
386694	386693	19705W	PARTICIPANT	\N	PRESENT	0
386695	386607	14357A	PARTICIPANT	\N	PRESENT	0
386696	386607	19715Y	PARTICIPANT	\N	PRESENT	0
386698	386693	08062Y	PARTICIPANT	\N	PRESENT	0
386706	386705	19705W	PARTICIPANT	\N	PRESENT	0
386707	384208	14069U	PARTICIPANT	\N	PRESENT	0
386708	386705	08062Y	PARTICIPANT	\N	PRESENT	0
386709	386705	19369B	PARTICIPANT	\N	PRESENT	0
386710	384208	11101A	PARTICIPANT	\N	PRESENT	0
386711	384208	19253P	PARTICIPANT	\N	PRESENT	0
386712	386705	19269X	PARTICIPANT	\N	PRESENT	0
386713	384208	19525U	PARTICIPANT	\N	PRESENT	0
386715	377925	19691J	PARTICIPANT	\N	PRESENT	0
386716	384208	14259Y	PARTICIPANT	\N	PRESENT	0
386717	384208	14257W	PARTICIPANT	\N	PRESENT	0
386720	377925	14159V	PARTICIPANT	\N	PRESENT	0
386721	384208	95067Q	PARTICIPANT	\N	PRESENT	0
386722	386718	19705W	PARTICIPANT	\N	PRESENT	0
386723	384208	11048N	PARTICIPANT	\N	PRESENT	0
378425	378424	19575F	PARTICIPANT	\N	PRESENT	0
378426	378424	14197C	PARTICIPANT	\N	PRESENT	0
378427	378424	19727D	PARTICIPANT	\N	PRESENT	0
378428	378424	14033T	PARTICIPANT	\N	PRESENT	0
378429	378424	14205J	PARTICIPANT	\N	PRESENT	0
378430	378424	16685X	PARTICIPANT	\N	PRESENT	0
378431	378424	19563B	PARTICIPANT	\N	PRESENT	0
378432	378424	14169X	PARTICIPANT	\N	PRESENT	0
378433	378424	11097X	PARTICIPANT	\N	PRESENT	0
378434	378424	11043H	PARTICIPANT	\N	PRESENT	0
387464	387434	19581D	PARTICIPANT	\N	PRESENT	0
387469	387468	14215L	PARTICIPANT	\N	PRESENT	0
387470	387468	14179A	PARTICIPANT	\N	PRESENT	0
387472	387471	14215L	PARTICIPANT	\N	PRESENT	0
387473	387471	14179A	PARTICIPANT	\N	PRESENT	0
387474	387471	14275Y	PARTICIPANT	\N	PRESENT	0
387677	386389	04059M	PARTICIPANT	\N	PRESENT	0
387678	386389	19565D	PARTICIPANT	\N	PRESENT	0
387679	386389	11045K	PARTICIPANT	\N	PRESENT	0
387680	386389	19715Y	PARTICIPANT	\N	PRESENT	0
387681	386389	19683J	PARTICIPANT	\N	PRESENT	0
387682	386389	08052W	PARTICIPANT	\N	PRESENT	0
387683	386389	14213J	PARTICIPANT	\N	PRESENT	0
387684	386389	11031D	PARTICIPANT	\N	PRESENT	0
387685	386389	19593H	PARTICIPANT	\N	PRESENT	0
387686	386389	98024R	PARTICIPANT	\N	PRESENT	0
387687	386389	07029T	PARTICIPANT	\N	PRESENT	0
387688	386389	04092N	PARTICIPANT	\N	PRESENT	0
387689	386389	19301E	PARTICIPANT	\N	PRESENT	0
387690	386389	11072N	PARTICIPANT	\N	PRESENT	0
387691	386389	14261S	PARTICIPANT	\N	PRESENT	0
387692	386389	14042U	PARTICIPANT	\N	PRESENT	0
387693	386389	07004J	PARTICIPANT	\N	PRESENT	0
387694	386389	11070L	PARTICIPANT	\N	PRESENT	0
387695	386389	19657G	PARTICIPANT	\N	PRESENT	0
387696	386389	19711U	PARTICIPANT	\N	PRESENT	0
387697	386389	19695N	PARTICIPANT	\N	PRESENT	0
387698	386389	08019V	PARTICIPANT	\N	PRESENT	0
387699	386389	14105F	PARTICIPANT	\N	PRESENT	0
387700	386389	19629C	PARTICIPANT	\N	PRESENT	0
387701	386389	14251Q	PARTICIPANT	\N	PRESENT	0
387702	386389	01048V	PARTICIPANT	\N	PRESENT	0
387703	386389	19295A	PARTICIPANT	\N	PRESENT	0
387704	386389	14327T	PARTICIPANT	\N	PRESENT	0
387719	387714	19737F	PARTICIPANT	\N	PRESENT	0
387720	387714	19347U	PARTICIPANT	\N	PRESENT	0
387722	387714	14031R	PARTICIPANT	\N	PRESENT	0
387725	387714	19585H	PARTICIPANT	\N	PRESENT	0
387726	387714	14241N	PARTICIPANT	\N	PRESENT	0
387728	387714	19551W	PARTICIPANT	\N	PRESENT	0
387731	386389	19611R	PARTICIPANT	\N	PRESENT	0
387732	386389	99004R	PARTICIPANT	\N	PRESENT	0
387733	387714	19637C	PARTICIPANT	\N	EXCUSE	0
387734	387714	14237S	PARTICIPANT	\N	EXCUSE	0
387735	387714	19549D	PARTICIPANT	\N	EXCUSE	0
387737	386389	04035D	PARTICIPANT	\N	PRESENT	0
387738	386389	19649G	PARTICIPANT	\N	PRESENT	0
387739	386389	04034C	PARTICIPANT	\N	PRESENT	0
387740	386389	98050T	PARTICIPANT	\N	PRESENT	0
387741	386389	19766L	PARTICIPANT	\N	PRESENT	0
387742	386389	12041X	PARTICIPANT	\N	PRESENT	0
387743	386389	19669L	PARTICIPANT	\N	PRESENT	0
387744	386389	04085P	PARTICIPANT	\N	PRESENT	0
387843	383088	11109J	PARTICIPANT	\N	PRESENT	0
387844	383088	19715Y	PARTICIPANT	\N	PRESENT	0
387845	383088	12016W	PARTICIPANT	\N	PRESENT	0
387846	383088	08019V	PARTICIPANT	\N	PRESENT	0
387847	383088	11072N	PARTICIPANT	\N	PRESENT	0
387848	383088	14157T	PARTICIPANT	\N	PRESENT	0
387849	383088	19301E	PARTICIPANT	\N	PRESENT	0
388896	388515	11072N	PARTICIPANT	\N	PRESENT	0
388897	388515	08015R	PARTICIPANT	\N	PRESENT	0
388898	388515	19768N	PARTICIPANT	\N	PRESENT	0
388899	388515	19543W	PARTICIPANT	\N	PRESENT	0
388900	388515	14105F	PARTICIPANT	\N	PRESENT	0
388901	388515	14265W	PARTICIPANT	\N	PRESENT	0
388902	388515	11066Q	PARTICIPANT	\N	PRESENT	0
388903	388515	14213J	PARTICIPANT	\N	PRESENT	0
388904	388515	19659J	PARTICIPANT	\N	PRESENT	0
388905	388515	19251M	PARTICIPANT	\N	PRESENT	0
388906	388515	14217N	PARTICIPANT	\N	PRESENT	0
388907	388515	10006L	PARTICIPANT	\N	PRESENT	0
388908	388515	11033F	PARTICIPANT	\N	PRESENT	0
388909	388515	19798U	PARTICIPANT	\N	PRESENT	0
388910	388515	19593H	PARTICIPANT	\N	PRESENT	0
388911	388515	19667J	PARTICIPANT	\N	PRESENT	0
388912	388515	89017R	PARTICIPANT	\N	PRESENT	0
388913	388515	99004R	PARTICIPANT	\N	PRESENT	0
388914	388515	19685L	PARTICIPANT	\N	PRESENT	0
388915	388515	88008L	PARTICIPANT	\N	PRESENT	0
388916	388515	14261S	PARTICIPANT	\N	PRESENT	0
388917	388515	14087W	PARTICIPANT	\N	PRESENT	0
388918	388515	19253P	PARTICIPANT	\N	PRESENT	0
388919	388515	11097X	PARTICIPANT	\N	PRESENT	0
388920	388515	11012A	PARTICIPANT	\N	PRESENT	0
388921	388515	19421M	PARTICIPANT	\N	PRESENT	0
388922	388515	04044E	PARTICIPANT	\N	PRESENT	0
388923	388515	14207L	PARTICIPANT	\N	PRESENT	0
388924	388515	95030B	PARTICIPANT	\N	PRESENT	0
388925	388515	14201E	PARTICIPANT	\N	PRESENT	0
388926	388515	04047H	PARTICIPANT	\N	PRESENT	0
388927	388515	14241N	PARTICIPANT	\N	PRESENT	0
388928	388515	14026U	PARTICIPANT	\N	PRESENT	0
388929	388515	11099A	PARTICIPANT	\N	PRESENT	0
388930	388515	04035D	PARTICIPANT	\N	PRESENT	0
388931	388515	14121F	PARTICIPANT	\N	PRESENT	0
388932	388515	19387D	PARTICIPANT	\N	PRESENT	0
388933	388515	19545Y	PARTICIPANT	\N	PRESENT	0
388934	388515	02002K	PARTICIPANT	\N	PRESENT	0
388935	388515	19553Y	PARTICIPANT	\N	PRESENT	0
388936	388515	14281W	PARTICIPANT	\N	PRESENT	0
388937	388515	19521Q	PARTICIPANT	\N	PRESENT	0
388938	388515	19679N	PARTICIPANT	\N	PRESENT	0
388939	388515	14205J	PARTICIPANT	\N	PRESENT	0
388940	388515	04092N	PARTICIPANT	\N	PRESENT	0
388941	388515	08044W	PARTICIPANT	\N	PRESENT	0
388942	388515	19762G	PARTICIPANT	\N	PRESENT	0
388943	388515	19737F	PARTICIPANT	\N	PRESENT	0
388944	388515	19383Y	PARTICIPANT	\N	PRESENT	0
388945	388515	19735D	PARTICIPANT	\N	PRESENT	0
388946	388515	19713W	PARTICIPANT	\N	PRESENT	0
388947	388515	19319Q	PARTICIPANT	\N	PRESENT	0
388948	388515	14275Y	PARTICIPANT	\N	PRESENT	0
388949	388515	19479G	PARTICIPANT	\N	PRESENT	0
388950	388515	08020N	PARTICIPANT	\N	PRESENT	0
388951	388515	19691J	PARTICIPANT	\N	PRESENT	0
388952	388515	19699S	PARTICIPANT	\N	PRESENT	0
388953	388515	14195A	PARTICIPANT	\N	PRESENT	0
388954	388515	11010L	PARTICIPANT	\N	PRESENT	0
388955	388515	19721W	PARTICIPANT	\N	PRESENT	0
388956	388515	19511N	PARTICIPANT	\N	PRESENT	0
388957	388515	19575F	PARTICIPANT	\N	PRESENT	0
388958	388515	19577H	PARTICIPANT	\N	PRESENT	0
388959	388515	19533U	PARTICIPANT	\N	PRESENT	0
388960	388515	14255U	PARTICIPANT	\N	PRESENT	0
388961	388515	04049K	PARTICIPANT	\N	PRESENT	0
388962	388515	14083S	PARTICIPANT	\N	PRESENT	0
388963	388515	14267Y	PARTICIPANT	\N	PRESENT	0
388964	388515	14221J	PARTICIPANT	\N	PRESENT	0
388965	388515	04089T	PARTICIPANT	\N	PRESENT	0
388966	388515	19745F	PARTICIPANT	\N	PRESENT	0
388967	388515	14147R	PARTICIPANT	\N	PRESENT	0
388968	388515	14103D	PARTICIPANT	\N	PRESENT	0
388969	388515	19507S	PARTICIPANT	\N	PRESENT	0
388970	388515	08009T	PARTICIPANT	\N	PRESENT	0
388971	388515	14187A	PARTICIPANT	\N	PRESENT	0
388972	388515	01025N	PARTICIPANT	\N	PRESENT	0
388973	388515	01024M	PARTICIPANT	\N	PRESENT	0
388974	388515	14329V	PARTICIPANT	\N	PRESENT	0
388975	388515	11103C	PARTICIPANT	\N	PRESENT	0
388976	388515	14059S	PARTICIPANT	\N	PRESENT	0
388977	388515	08069G	PARTICIPANT	\N	PRESENT	0
388978	388515	19749K	PARTICIPANT	\N	PRESENT	0
388979	388515	14039A	PARTICIPANT	\N	PRESENT	0
388980	388515	19697Q	PARTICIPANT	\N	PRESENT	0
388981	388515	19637C	PARTICIPANT	\N	PRESENT	0
388982	388515	19329S	PARTICIPANT	\N	PRESENT	0
388983	388515	19673G	PARTICIPANT	\N	PRESENT	0
388984	388515	04008A	PARTICIPANT	\N	PRESENT	0
388985	388515	14239U	PARTICIPANT	\N	PRESENT	0
388986	388515	19629C	PARTICIPANT	\N	PRESENT	0
388987	388515	19527W	PARTICIPANT	\N	PRESENT	0
388988	388515	11041F	PARTICIPANT	\N	PRESENT	0
388989	388515	19729F	PARTICIPANT	\N	PRESENT	0
388990	388515	08060W	PARTICIPANT	\N	PRESENT	0
388991	388515	11109J	PARTICIPANT	\N	PRESENT	0
388992	388515	19631V	PARTICIPANT	\N	PRESENT	0
388993	388515	04043D	PARTICIPANT	\N	PRESENT	0
388994	388515	19447X	PARTICIPANT	\N	PRESENT	0
363752	345234	14147R	PARTICIPANT	\N	PRESENT	0
363925	363924	01048V	PARTICIPANT	\N	PRESENT	0
363926	363924	04042C	PARTICIPANT	\N	PRESENT	0
363927	363924	19721W	PARTICIPANT	\N	PRESENT	0
363928	363924	08052W	PARTICIPANT	\N	PRESENT	0
363929	363924	19521Q	PARTICIPANT	\N	PRESENT	0
363930	363924	04035D	PARTICIPANT	\N	PRESENT	0
368175	368174	14261S	PARTICIPANT	\N	PRESENT	0
363932	363924	08015R	PARTICIPANT	\N	PRESENT	0
363933	363924	11026G	PARTICIPANT	\N	PRESENT	0
363934	363924	98050T	PARTICIPANT	\N	PRESENT	0
363935	363924	04088S	PARTICIPANT	\N	PRESENT	0
363936	363924	19619A	PARTICIPANT	\N	PRESENT	0
363937	363924	04044E	PARTICIPANT	\N	PRESENT	0
363938	363924	95067Q	PARTICIPANT	\N	PRESENT	0
363939	363924	98035U	PARTICIPANT	\N	PRESENT	0
363940	363924	19503N	PARTICIPANT	\N	PRESENT	0
363941	363924	04097T	PARTICIPANT	\N	PRESENT	0
363943	363924	02002K	PARTICIPANT	\N	PRESENT	0
367473	366416	04097T	PARTICIPANT	\N	EXCUSE	0
368176	368174	14119M	PARTICIPANT	\N	PRESENT	0
368179	368178	14261S	PARTICIPANT	\N	PRESENT	0
368180	368178	14119M	PARTICIPANT	\N	PRESENT	0
368182	368181	14261S	PARTICIPANT	\N	PRESENT	0
368183	368181	14119M	PARTICIPANT	\N	PRESENT	0
373999	373691	02002K	PARTICIPANT	\N	PRESENT	0
374080	373691	04044E	PARTICIPANT	\N	PRESENT	0
374823	367788	14093U	PARTICIPANT	\N	PRESENT	0
374824	367788	01058X	PARTICIPANT	\N	EXCUSE	0
377151	371474	19549D	PARTICIPANT	\N	PRESENT	0
377152	371474	08045X	PARTICIPANT	\N	PRESENT	0
377153	371474	19489J	PARTICIPANT	\N	PRESENT	0
377154	371474	08058D	PARTICIPANT	\N	PRESENT	0
377155	371474	11104D	PARTICIPANT	\N	PRESENT	0
377156	371474	19760E	PARTICIPANT	\N	PRESENT	0
377157	371474	98005N	PARTICIPANT	\N	PRESENT	0
377158	371474	19737F	PARTICIPANT	\N	PRESENT	0
377159	371474	19441R	PARTICIPANT	\N	PRESENT	0
377160	371474	19611R	PARTICIPANT	\N	PRESENT	0
377161	371474	14103D	PARTICIPANT	\N	PRESENT	0
377162	371474	19739H	PARTICIPANT	\N	PRESENT	0
377163	371474	14219Q	PARTICIPANT	\N	PRESENT	0
377164	371474	19749K	PARTICIPANT	\N	PRESENT	0
377165	371474	14089Y	PARTICIPANT	\N	PRESENT	0
377166	371474	14030Q	PARTICIPANT	\N	PRESENT	0
377167	371474	99004R	PARTICIPANT	\N	PRESENT	0
377168	371474	08039A	PARTICIPANT	\N	PRESENT	0
377169	371474	14123H	PARTICIPANT	\N	PRESENT	0
377170	371474	08020N	PARTICIPANT	\N	PRESENT	0
377171	371474	08069G	PARTICIPANT	\N	PRESENT	0
377172	371474	08010L	PARTICIPANT	\N	PRESENT	0
377173	371474	95067Q	PARTICIPANT	\N	PRESENT	0
377174	371474	11043H	PARTICIPANT	\N	PRESENT	0
377175	371474	19679N	PARTICIPANT	\N	PRESENT	0
377176	371474	14169X	PARTICIPANT	\N	PRESENT	0
377177	371474	01057W	PARTICIPANT	\N	PRESENT	0
377178	371474	11077T	PARTICIPANT	\N	PRESENT	0
377179	371474	19349W	PARTICIPANT	\N	PRESENT	0
377180	371474	14031R	PARTICIPANT	\N	PRESENT	0
377181	371474	14119M	PARTICIPANT	\N	PRESENT	0
377182	371474	14215L	PARTICIPANT	\N	PRESENT	0
377183	371474	14041T	PARTICIPANT	\N	PRESENT	0
377184	371474	14259Y	PARTICIPANT	\N	PRESENT	0
377185	371474	19507S	PARTICIPANT	\N	PRESENT	0
377186	371474	14029X	PARTICIPANT	\N	PRESENT	0
377187	371474	11049P	PARTICIPANT	\N	PRESENT	0
377188	371474	19693L	PARTICIPANT	\N	PRESENT	0
377189	371474	19575F	PARTICIPANT	\N	PRESENT	0
377190	371474	11048N	PARTICIPANT	\N	PRESENT	0
377191	371474	04086Q	PARTICIPANT	\N	PRESENT	0
377192	371474	14249W	PARTICIPANT	\N	PRESENT	0
377193	371474	04043D	PARTICIPANT	\N	PRESENT	0
377194	371474	14069U	PARTICIPANT	\N	PRESENT	0
377195	371474	19747H	PARTICIPANT	\N	PRESENT	0
377196	371474	19421M	PARTICIPANT	\N	PRESENT	0
377197	371474	19533U	PARTICIPANT	\N	PRESENT	0
377198	371474	19762G	PARTICIPANT	\N	PRESENT	0
377199	371474	19701S	PARTICIPANT	\N	PRESENT	0
377200	371474	14071N	PARTICIPANT	\N	PRESENT	0
377201	371474	19729F	PARTICIPANT	\N	PRESENT	0
377202	371474	14115H	PARTICIPANT	\N	PRESENT	0
377203	371474	19415P	PARTICIPANT	\N	PRESENT	0
377204	371474	19671E	PARTICIPANT	\N	PRESENT	0
377205	371474	04033B	PARTICIPANT	\N	PRESENT	0
377206	371474	19673G	PARTICIPANT	\N	PRESENT	0
377207	371474	14157T	PARTICIPANT	\N	PRESENT	0
377208	371474	19329S	PARTICIPANT	\N	PRESENT	0
377209	371474	04057K	PARTICIPANT	\N	PRESENT	0
377210	371474	11033F	PARTICIPANT	\N	PRESENT	0
377211	371474	14197C	PARTICIPANT	\N	PRESENT	0
377212	371474	19687N	PARTICIPANT	\N	PRESENT	0
377213	371474	19695N	PARTICIPANT	\N	PRESENT	0
377214	371474	14257W	PARTICIPANT	\N	PRESENT	0
377215	371474	04085P	PARTICIPANT	\N	PRESENT	0
377216	371474	14121F	PARTICIPANT	\N	PRESENT	0
377217	371474	19794Q	PARTICIPANT	\N	PRESENT	0
377218	371474	08028W	PARTICIPANT	\N	PRESENT	0
377219	371474	04088S	PARTICIPANT	\N	PRESENT	0
377220	371474	19798U	PARTICIPANT	\N	PRESENT	0
377221	371474	01024M	PARTICIPANT	\N	PRESENT	0
377222	371474	14205J	PARTICIPANT	\N	PRESENT	0
377223	371474	19511N	PARTICIPANT	\N	PRESENT	0
377224	371474	08019V	PARTICIPANT	\N	PRESENT	0
377225	371474	19335Q	PARTICIPANT	\N	PRESENT	0
377226	371474	19721W	PARTICIPANT	\N	PRESENT	0
377227	371474	04044E	PARTICIPANT	\N	PRESENT	0
377228	371474	14251Q	PARTICIPANT	\N	PRESENT	0
377229	371474	14357A	PARTICIPANT	\N	PRESENT	0
377230	371474	11066Q	PARTICIPANT	\N	PRESENT	0
377231	371474	19503N	PARTICIPANT	\N	PRESENT	0
377232	371474	19621T	PARTICIPANT	\N	PRESENT	0
377233	371474	04070G	PARTICIPANT	\N	PRESENT	0
377234	371474	19703U	PARTICIPANT	\N	PRESENT	0
377235	371474	19515S	PARTICIPANT	\N	PRESENT	0
377236	371474	14105F	PARTICIPANT	\N	PRESENT	0
377237	371474	19709B	PARTICIPANT	\N	PRESENT	0
377238	371474	14187A	PARTICIPANT	\N	PRESENT	0
377240	371474	87003B	PARTICIPANT	\N	PRESENT	0
377241	371474	14227Q	PARTICIPANT	\N	PRESENT	0
377242	371474	19521Q	PARTICIPANT	\N	PRESENT	0
377243	371474	08017T	PARTICIPANT	\N	PRESENT	0
377244	371474	14229S	PARTICIPANT	\N	PRESENT	0
377245	371474	14051J	PARTICIPANT	\N	PRESENT	0
377246	371474	19383Y	PARTICIPANT	\N	PRESENT	0
377247	371474	14059S	PARTICIPANT	\N	PRESENT	0
377248	371474	04018C	PARTICIPANT	\N	PRESENT	0
377249	371474	14231L	PARTICIPANT	\N	PRESENT	0
377250	371474	14038Y	PARTICIPANT	\N	PRESENT	0
377251	377239	14227Q	PARTICIPANT	\N	PRESENT	0
377252	371474	01025N	PARTICIPANT	\N	PRESENT	0
377253	371474	19583F	PARTICIPANT	\N	PRESENT	0
377254	371474	19599P	PARTICIPANT	\N	PRESENT	0
377255	371474	08073C	PARTICIPANT	\N	PRESENT	0
377256	371474	19689Q	PARTICIPANT	\N	PRESENT	0
377257	371474	19369B	PARTICIPANT	\N	PRESENT	0
377258	371474	17583W	PARTICIPANT	\N	PRESENT	0
377259	371474	19367Y	PARTICIPANT	\N	PRESENT	0
377260	371474	14237S	PARTICIPANT	\N	PRESENT	0
377261	371474	11109J	PARTICIPANT	\N	PRESENT	0
377262	371474	11065P	PARTICIPANT	\N	PRESENT	0
377263	371474	19545Y	PARTICIPANT	\N	PRESENT	0
377264	371474	19669L	PARTICIPANT	\N	PRESENT	0
377265	371474	19479G	PARTICIPANT	\N	PRESENT	0
377266	371474	08061X	PARTICIPANT	\N	PRESENT	0
377267	371474	11026G	PARTICIPANT	\N	PRESENT	0
377268	371474	14147R	PARTICIPANT	\N	PRESENT	0
377269	371474	19447X	PARTICIPANT	\N	PRESENT	0
377270	371474	04049K	PARTICIPANT	\N	PRESENT	0
377271	371474	14265W	PARTICIPANT	\N	PRESENT	0
377272	371474	14327T	PARTICIPANT	\N	PRESENT	0
377273	371474	14261S	PARTICIPANT	\N	PRESENT	0
377274	371474	08056B	PARTICIPANT	\N	PRESENT	0
377275	371474	89017R	PARTICIPANT	\N	PRESENT	0
377276	371474	14097Y	PARTICIPANT	\N	PRESENT	0
377277	371474	19563B	PARTICIPANT	\N	PRESENT	0
377278	371474	14063N	PARTICIPANT	\N	PRESENT	0
377279	371474	14111D	PARTICIPANT	\N	PRESENT	0
377280	371474	08044W	PARTICIPANT	\N	PRESENT	0
377281	371474	11103C	PARTICIPANT	\N	PRESENT	0
377282	371474	97011G	PARTICIPANT	\N	PRESENT	0
377283	371474	14329V	PARTICIPANT	\N	PRESENT	0
377284	371474	14223L	PARTICIPANT	\N	PRESENT	0
377285	371474	11054L	PARTICIPANT	\N	PRESENT	0
377286	371474	19735D	PARTICIPANT	\N	PRESENT	0
377287	371474	19569H	PARTICIPANT	\N	PRESENT	0
377288	371474	14109K	PARTICIPANT	\N	PRESENT	0
377289	371474	11099A	PARTICIPANT	\N	PRESENT	0
377290	371474	08062Y	PARTICIPANT	\N	PRESENT	0
373854	373691	19551W	PARTICIPANT	\N	PRESENT	0
373855	373691	11065P	PARTICIPANT	\N	PRESENT	0
373892	373691	19647E	PARTICIPANT	\N	EXCUSE	0
378316	371476	19553Y	PARTICIPANT	\N	PRESENT	0
378317	371476	08031R	PARTICIPANT	\N	PRESENT	0
378318	371476	14055N	PARTICIPANT	\N	PRESENT	0
378319	371476	14031R	PARTICIPANT	\N	PRESENT	0
378320	371476	19421M	PARTICIPANT	\N	PRESENT	0
378321	371476	11103C	PARTICIPANT	\N	PRESENT	0
378322	371476	11066Q	PARTICIPANT	\N	PRESENT	0
378323	371476	14201E	PARTICIPANT	\N	PRESENT	0
378324	371476	87003B	PARTICIPANT	\N	PRESENT	0
378325	371476	19798U	PARTICIPANT	\N	PRESENT	0
378326	371476	14223L	PARTICIPANT	\N	PRESENT	0
378327	371476	14267Y	PARTICIPANT	\N	PRESENT	0
378329	371476	14281W	PARTICIPANT	\N	PRESENT	0
378330	371476	14087W	PARTICIPANT	\N	PRESENT	0
378331	377016	14327T	PARTICIPANT	\N	PRESENT	0
378332	377016	14331P	PARTICIPANT	\N	PRESENT	0
378333	377016	04071H	PARTICIPANT	\N	PRESENT	0
378334	377016	11048N	PARTICIPANT	\N	PRESENT	0
378335	377016	19479G	PARTICIPANT	\N	PRESENT	0
378336	377016	19651A	PARTICIPANT	\N	PRESENT	0
378337	377016	01057W	PARTICIPANT	\N	PRESENT	0
378338	377016	12016W	PARTICIPANT	\N	PRESENT	0
378339	377016	19667J	PARTICIPANT	\N	PRESENT	0
378340	377016	19671E	PARTICIPANT	\N	PRESENT	0
378341	377016	07029T	PARTICIPANT	\N	PRESENT	0
378342	377016	14083S	PARTICIPANT	\N	PRESENT	0
378343	377016	11012A	PARTICIPANT	\N	PRESENT	0
378344	377016	14085U	PARTICIPANT	\N	PRESENT	0
378345	377016	19349W	PARTICIPANT	\N	PRESENT	0
378346	377016	08010L	PARTICIPANT	\N	PRESENT	0
378348	377016	99004R	PARTICIPANT	\N	PRESENT	0
378349	371476	19575F	PARTICIPANT	\N	PRESENT	0
378354	371476	14329V	PARTICIPANT	\N	PRESENT	0
378355	371476	14053L	PARTICIPANT	\N	PRESENT	0
378356	371476	19703U	PARTICIPANT	\N	PRESENT	0
378357	371476	11056N	PARTICIPANT	\N	PRESENT	0
378358	371476	95063L	PARTICIPANT	\N	PRESENT	0
378359	371476	11072N	PARTICIPANT	\N	PRESENT	0
378362	371476	19733B	PARTICIPANT	\N	PRESENT	0
378364	377016	89017R	PARTICIPANT	\N	PRESENT	0
378365	376743	04035D	PARTICIPANT	\N	PRESENT	0
378366	376743	19443T	PARTICIPANT	\N	PRESENT	0
378367	376743	95030B	PARTICIPANT	\N	PRESENT	0
378368	376743	11041F	PARTICIPANT	\N	PRESENT	0
378369	376743	14235Q	PARTICIPANT	\N	PRESENT	0
378370	376743	04040A	PARTICIPANT	\N	PRESENT	0
378371	376743	16685X	PARTICIPANT	\N	PRESENT	0
378372	376743	08058D	PARTICIPANT	\N	PRESENT	0
378373	376743	11027H	PARTICIPANT	\N	PRESENT	0
378374	376743	04042C	PRESIDENT	0	PRESENT	0
378375	376743	11066Q	PARTICIPANT	\N	PRESENT	0
378376	376743	95037J	PARTICIPANT	\N	PRESENT	0
378377	376743	19421M	PARTICIPANT	\N	PRESENT	0
378378	376743	11064N	PARTICIPANT	\N	PRESENT	0
378379	376743	98050T	PARTICIPANT	\N	PRESENT	0
378380	376743	97011G	PARTICIPANT	\N	PRESENT	0
378381	376743	08061X	PARTICIPANT	\N	PRESENT	0
378382	376743	14255U	PARTICIPANT	\N	PRESENT	0
378383	376743	98029W	PARTICIPANT	\N	PRESENT	0
378384	371476	11097X	PARTICIPANT	\N	PRESENT	0
378385	371476	19549D	PARTICIPANT	\N	PRESENT	0
378386	376743	01062T	PARTICIPANT	\N	PRESENT	0
378387	376743	14193X	PRESIDENT	1	PRESENT	0
378388	376743	19583F	PARTICIPANT	\N	PRESENT	0
378389	376743	08047A	PARTICIPANT	\N	PRESENT	0
378390	376743	11054L	PARTICIPANT	\N	PRESENT	0
378392	376743	98022P	PARTICIPANT	\N	PRESENT	0
378393	376743	04034C	PARTICIPANT	\N	PRESENT	0
378394	371476	14071N	PARTICIPANT	\N	PRESENT	0
378395	371476	14217N	PARTICIPANT	\N	PRESENT	0
378396	371476	14059S	PARTICIPANT	\N	PRESENT	0
378397	371476	19581D	PARTICIPANT	\N	PRESENT	0
378398	371476	19731Y	PARTICIPANT	\N	PRESENT	0
378399	371476	14179A	PARTICIPANT	\N	PRESENT	0
378400	373784	11048N	PARTICIPANT	\N	PRESENT	0
378401	371476	08055A	PARTICIPANT	\N	PRESENT	0
378402	376743	98018T	PARTICIPANT	\N	EXCUSE	0
378418	376743	12041X	PARTICIPANT	\N	PRESENT	0
378419	371476	14135M	PARTICIPANT	\N	PRESENT	0
378420	371476	19689Q	PARTICIPANT	\N	PRESENT	0
378421	371476	19679N	PARTICIPANT	\N	PRESENT	0
378422	371476	19591F	PARTICIPANT	\N	PRESENT	0
378436	378435	14026U	PARTICIPANT	\N	PRESENT	0
378437	378435	19717B	PARTICIPANT	\N	PRESENT	0
378438	371476	19369B	PARTICIPANT	\N	PRESENT	0
378439	371476	04033B	PARTICIPANT	\N	PRESENT	0
378440	371476	19415P	PARTICIPANT	\N	PRESENT	0
378441	371476	14199E	PARTICIPANT	\N	PRESENT	0
378442	371476	19629C	PARTICIPANT	\N	PRESENT	0
378463	378460	14026U	PARTICIPANT	\N	PRESENT	0
378464	378460	19717B	PARTICIPANT	\N	PRESENT	0
378472	371476	14205J	PARTICIPANT	\N	PRESENT	0
378473	371476	08019V	PARTICIPANT	\N	PRESENT	0
378474	371476	19727D	PARTICIPANT	\N	PRESENT	0
378475	371476	19691J	PARTICIPANT	\N	PRESENT	0
378476	371476	01057W	PARTICIPANT	\N	PRESENT	0
378477	371476	19333N	PARTICIPANT	\N	PRESENT	0
378549	371477	11072N	PARTICIPANT	\N	PRESENT	0
378550	371477	19621T	PARTICIPANT	\N	PRESENT	0
378551	371477	08043V	PARTICIPANT	\N	PRESENT	0
378552	371477	14229S	PARTICIPANT	\N	PRESENT	0
378553	371477	14281W	PARTICIPANT	\N	PRESENT	0
378554	371477	19251M	PARTICIPANT	\N	PRESENT	0
378555	371477	19503N	PARTICIPANT	\N	PRESENT	0
378556	371477	11109J	PARTICIPANT	\N	PRESENT	0
378557	371477	11067R	PARTICIPANT	\N	PRESENT	0
378558	371477	19727D	PARTICIPANT	\N	PRESENT	0
378559	371477	19565D	PARTICIPANT	\N	PRESENT	0
378560	371477	19758L	PARTICIPANT	\N	PRESENT	0
378561	371477	19591F	PARTICIPANT	\N	PRESENT	0
378562	371477	14097Y	PARTICIPANT	\N	PRESENT	0
378563	371477	19782L	PARTICIPANT	\N	PRESENT	0
378564	371477	14207L	PARTICIPANT	\N	PRESENT	0
378565	371477	08024S	PARTICIPANT	\N	PRESENT	0
378566	371477	14039A	PARTICIPANT	\N	PRESENT	0
378567	371477	14107H	PARTICIPANT	\N	PRESENT	0
378568	371477	17589D	PARTICIPANT	\N	PRESENT	0
378569	371477	98005N	PARTICIPANT	\N	PRESENT	0
378570	371477	11031D	PARTICIPANT	\N	PRESENT	0
378571	371477	19333N	PARTICIPANT	\N	PRESENT	0
378572	371477	04045F	PARTICIPANT	\N	PRESENT	0
378573	371477	19611R	PARTICIPANT	\N	PRESENT	0
378574	371477	19737F	PARTICIPANT	\N	PRESENT	0
378575	371477	14030Q	PARTICIPANT	\N	PRESENT	0
378576	371477	19619A	PARTICIPANT	\N	PRESENT	0
378577	371477	14103D	PARTICIPANT	\N	PRESENT	0
378578	371477	19749K	PARTICIPANT	\N	PRESENT	0
378579	371477	19735D	PARTICIPANT	\N	PRESENT	0
378580	371477	01025N	PARTICIPANT	\N	PRESENT	0
378581	371477	08017T	PARTICIPANT	\N	PRESENT	0
378582	371477	11097X	PARTICIPANT	\N	PRESENT	0
378583	371477	14217N	PARTICIPANT	\N	PRESENT	0
378584	371477	19798U	PARTICIPANT	\N	PRESENT	0
378585	371477	19533U	PARTICIPANT	\N	PRESENT	0
378586	371477	14071N	PARTICIPANT	\N	PRESENT	0
378587	371477	14061L	PARTICIPANT	\N	PRESENT	0
378588	371477	07029T	PARTICIPANT	\N	PRESENT	0
378589	371477	19693L	PARTICIPANT	\N	PRESENT	0
378590	371477	19794Q	PARTICIPANT	\N	PRESENT	0
378591	371477	19673G	PARTICIPANT	\N	PRESENT	0
378592	371477	19573D	PARTICIPANT	\N	PRESENT	0
378593	371477	14223L	PARTICIPANT	\N	PRESENT	0
378594	371477	11043H	PARTICIPANT	\N	PRESENT	0
378595	371477	14123H	PARTICIPANT	\N	PRESENT	0
378596	371477	08020N	PARTICIPANT	\N	PRESENT	0
378597	371477	08039A	PARTICIPANT	\N	PRESENT	0
378598	371477	14211G	PARTICIPANT	\N	PRESENT	0
378599	371477	11104D	PARTICIPANT	\N	PRESENT	0
378600	371477	04059M	PARTICIPANT	\N	PRESENT	0
378601	371477	14109K	PARTICIPANT	\N	PRESENT	0
378602	371477	11077T	PARTICIPANT	\N	PRESENT	0
378603	371477	19347U	PARTICIPANT	\N	PRESENT	0
378604	371477	19695N	PARTICIPANT	\N	PRESENT	0
378605	371477	11056N	PARTICIPANT	\N	PRESENT	0
378606	371477	14235Q	PARTICIPANT	\N	PRESENT	0
378607	371477	19593H	PARTICIPANT	\N	PRESENT	0
378608	371477	19441R	PARTICIPANT	\N	PRESENT	0
378609	371477	19715Y	PARTICIPANT	\N	PRESENT	0
378610	371477	14205J	PARTICIPANT	\N	PRESENT	0
378611	371477	14197C	PARTICIPANT	\N	PRESENT	0
378612	371477	14065Q	PARTICIPANT	\N	PRESENT	0
378613	371477	14021P	PARTICIPANT	\N	PRESENT	0
378614	371477	14059S	PARTICIPANT	\N	PRESENT	0
378615	371477	08019V	PARTICIPANT	\N	PRESENT	0
378616	371477	04070G	PARTICIPANT	\N	PRESENT	0
363558	363528	08019V	PARTICIPANT	\N	PRESENT	0
363864	357424	14093U	PARTICIPANT	\N	PRESENT	0
363868	357424	80013X	PARTICIPANT	\N	PRESENT	0
363872	357424	19693L	PARTICIPANT	\N	PRESENT	0
363876	357424	19723Y	PARTICIPANT	\N	PRESENT	0
363879	357424	19593H	PARTICIPANT	\N	PRESENT	0
363880	357424	19533U	PARTICIPANT	\N	PRESENT	0
363883	357424	04043D	PRESIDENT	0	PRESENT	0
363884	357424	01058X	PARTICIPANT	\N	PRESENT	0
363886	357424	19709B	PARTICIPANT	\N	EXCUSE	0
363888	357424	01048V	PARTICIPANT	\N	EXCUSE	0
363891	357424	14239U	PARTICIPANT	\N	EXCUSE	0
364476	364475	08039A	PARTICIPANT	\N	PRESENT	0
364477	364475	14030Q	PARTICIPANT	\N	PRESENT	0
364478	364475	08043V	PARTICIPANT	\N	PRESENT	0
364479	364475	08020N	PARTICIPANT	\N	PRESENT	0
364480	364475	19731Y	PARTICIPANT	\N	PRESENT	0
364481	364475	08017T	PARTICIPANT	\N	PRESENT	0
364482	364475	19335Q	PARTICIPANT	\N	PRESENT	0
364483	364475	04018C	PARTICIPANT	\N	PRESENT	0
364488	364484	05008E	PARTICIPANT	\N	PRESENT	0
364486	364484	04085P	PARTICIPANT	\N	PRESENT	0
364487	364484	04059M	PARTICIPANT	\N	PRESENT	0
364489	364484	96004D	PARTICIPANT	\N	PRESENT	0
364490	364484	11053K	PARTICIPANT	\N	PRESENT	0
364491	364484	11027H	PARTICIPANT	\N	PRESENT	0
364492	364484	04086Q	PARTICIPANT	\N	PRESENT	0
364493	364484	14079W	PARTICIPANT	\N	PRESENT	0
364494	364484	11074Q	PARTICIPANT	\N	PRESENT	0
364495	364484	14187A	PARTICIPANT	\N	PRESENT	0
364496	364484	19521Q	PARTICIPANT	\N	PRESENT	0
364497	364484	14034U	PARTICIPANT	\N	PRESENT	0
364498	364484	14231L	PARTICIPANT	\N	PRESENT	0
364499	364484	08056B	PARTICIPANT	\N	PRESENT	0
364500	364484	14021P	PARTICIPANT	\N	PRESENT	0
364501	364484	08039A	PARTICIPANT	\N	PRESENT	0
364502	364484	01043Q	PARTICIPANT	\N	PRESENT	0
364503	364484	14251Q	PARTICIPANT	\N	PRESENT	0
364504	364484	08009T	PARTICIPANT	\N	PRESENT	0
364505	364484	04092N	PARTICIPANT	\N	PRESENT	0
364506	364484	11072N	PARTICIPANT	\N	PRESENT	0
364507	364484	08061X	PARTICIPANT	\N	PRESENT	0
364508	364484	11012A	PARTICIPANT	\N	PRESENT	0
364509	364484	04044E	PARTICIPANT	\N	PRESENT	0
364510	364484	11090Q	PARTICIPANT	\N	PRESENT	0
364512	364511	04059M	PARTICIPANT	\N	PRESENT	0
364513	364511	11040E	PARTICIPANT	\N	PRESENT	0
364514	364511	14053L	PARTICIPANT	\N	PRESENT	0
364515	364511	11053K	PARTICIPANT	\N	PRESENT	0
364516	364511	11027H	PARTICIPANT	\N	PRESENT	0
364517	364511	04086Q	PARTICIPANT	\N	PRESENT	0
364518	364511	08052W	PARTICIPANT	\N	PRESENT	0
364519	364511	11070L	PARTICIPANT	\N	PRESENT	0
364520	364511	10006L	PARTICIPANT	\N	PRESENT	0
364521	364511	14041T	PARTICIPANT	\N	PRESENT	0
364522	364511	04089T	PARTICIPANT	\N	PRESENT	0
364523	364511	14034U	PARTICIPANT	\N	PRESENT	0
364524	364511	14231L	PARTICIPANT	\N	PRESENT	0
364525	364511	11064N	PARTICIPANT	\N	PRESENT	0
364526	364511	14081Q	PARTICIPANT	\N	PRESENT	0
369886	366780	17779H	PARTICIPANT	\N	PRESENT	0
364528	364511	14061L	PARTICIPANT	\N	PRESENT	0
364529	364511	14159V	PARTICIPANT	\N	PRESENT	0
364530	364511	86034E	PARTICIPANT	\N	PRESENT	0
364531	364511	08034U	PARTICIPANT	\N	PRESENT	0
364532	364511	01043Q	PARTICIPANT	\N	PRESENT	0
364533	364511	12016W	PARTICIPANT	\N	PRESENT	0
364534	364511	11072N	PARTICIPANT	\N	PRESENT	0
364535	364511	05012A	PARTICIPANT	\N	PRESENT	0
364536	364511	14135M	PARTICIPANT	\N	PRESENT	0
364537	364511	04044E	PARTICIPANT	\N	PRESENT	0
368988	366779	14087W	PARTICIPANT	\N	PRESENT	0
368989	366778	14087W	PARTICIPANT	\N	PRESENT	0
369887	356301	86034E	PARTICIPANT	\N	PRESENT	0
369888	356301	19643A	PARTICIPANT	\N	PRESENT	0
369889	356301	08053X	PARTICIPANT	\N	PRESENT	0
369890	356301	08021P	PARTICIPANT	\N	PRESENT	0
369891	356301	98022P	PARTICIPANT	\N	PRESENT	0
369892	356301	19717B	PARTICIPANT	\N	PRESENT	0
369893	356301	19583F	PARTICIPANT	\N	PRESENT	0
369894	356301	17589D	PARTICIPANT	\N	PRESENT	0
369895	356301	14107H	PARTICIPANT	\N	PRESENT	0
369896	356301	17637T	PARTICIPANT	\N	PRESENT	0
369897	356301	19711U	PARTICIPANT	\N	PRESENT	0
369898	356301	04008A	PARTICIPANT	\N	PRESENT	0
369899	356301	95062K	PARTICIPANT	\N	PRESENT	0
369900	356301	14157T	PARTICIPANT	\N	PRESENT	0
369901	356301	01058X	PARTICIPANT	\N	PRESENT	0
369902	356301	99004R	PARTICIPANT	\N	PRESENT	0
369903	356301	15447F	PARTICIPANT	\N	PRESENT	0
369904	356301	19515S	PARTICIPANT	\N	PRESENT	0
369905	356301	11080N	PARTICIPANT	\N	PRESENT	0
369906	356301	04085P	PARTICIPANT	\N	PRESENT	0
369907	356301	04071H	PARTICIPANT	\N	PRESENT	0
369908	356301	11031D	PARTICIPANT	\N	PRESENT	0
369909	356301	12041X	PARTICIPANT	\N	PRESENT	0
369910	356301	19695N	PARTICIPANT	\N	PRESENT	0
369911	356301	08069G	PARTICIPANT	\N	PRESENT	0
369912	356301	11056N	PARTICIPANT	\N	PRESENT	0
369913	356301	14235Q	PARTICIPANT	\N	PRESENT	0
369914	356301	04042C	PARTICIPANT	\N	PRESENT	0
369915	356301	19760E	PARTICIPANT	\N	PRESENT	0
369916	356301	19758L	PARTICIPANT	\N	PRESENT	0
369917	356301	19565D	PARTICIPANT	\N	PRESENT	0
369918	356301	08020N	PARTICIPANT	\N	PRESENT	0
369919	356301	19347U	PARTICIPANT	\N	PRESENT	0
369920	356301	19687N	PARTICIPANT	\N	PRESENT	0
369921	356301	11077T	PARTICIPANT	\N	PRESENT	0
369922	356301	19766L	PARTICIPANT	\N	PRESENT	0
369923	356301	08061X	PARTICIPANT	\N	PRESENT	0
369924	356301	14259Y	PARTICIPANT	\N	PRESENT	0
369925	356301	95063L	PARTICIPANT	\N	PRESENT	0
369927	356301	95037J	PARTICIPANT	\N	PRESENT	0
369928	356301	98029W	PARTICIPANT	\N	PRESENT	0
369929	356301	04045F	PARTICIPANT	\N	PRESENT	0
369930	356301	04034C	PARTICIPANT	\N	PRESENT	0
369931	356301	14239U	PARTICIPANT	\N	PRESENT	0
369932	356301	19651A	PARTICIPANT	\N	PRESENT	0
369933	356301	19349W	PARTICIPANT	\N	PRESENT	0
369934	356301	01057W	PARTICIPANT	\N	PRESENT	0
369935	356301	08024S	PARTICIPANT	\N	PRESENT	0
369936	356301	19301E	PARTICIPANT	\N	PRESENT	0
369937	356301	14039A	PARTICIPANT	\N	PRESENT	0
369938	356301	19782L	PARTICIPANT	\N	PRESENT	0
369939	356301	88008L	PARTICIPANT	\N	PRESENT	0
369940	356301	19679N	PARTICIPANT	\N	PRESENT	0
369941	356301	14034U	PARTICIPANT	\N	PRESENT	0
369942	356301	14261S	PARTICIPANT	\N	PRESENT	0
369943	356301	19629C	PARTICIPANT	\N	PRESENT	0
369944	356301	19253P	PARTICIPANT	\N	PRESENT	0
369945	356301	19563B	PARTICIPANT	\N	PRESENT	0
369946	356301	14241N	PARTICIPANT	\N	PRESENT	0
369947	356301	11065P	PARTICIPANT	\N	PRESENT	0
369948	356301	10015M	PARTICIPANT	\N	PRESENT	0
369949	356301	08073C	PARTICIPANT	\N	PRESENT	0
369950	356301	14251Q	PARTICIPANT	\N	PRESENT	0
369951	356301	14195A	PARTICIPANT	\N	PRESENT	0
369952	356301	14223L	PARTICIPANT	\N	PRESENT	0
369953	356301	98005N	PARTICIPANT	\N	PRESENT	0
369954	356301	19703U	PARTICIPANT	\N	PRESENT	0
369955	356301	11010L	PARTICIPANT	\N	PRESENT	0
369956	356301	14111D	PARTICIPANT	\N	PRESENT	0
369957	356301	19269X	PARTICIPANT	\N	PRESENT	0
369958	356301	19667J	PARTICIPANT	\N	PRESENT	0
369959	356301	14031R	PARTICIPANT	\N	PRESENT	0
369960	356301	14093U	PARTICIPANT	\N	PRESENT	0
369961	356301	19585H	PARTICIPANT	\N	PRESENT	0
369962	356301	14199E	PARTICIPANT	\N	PRESENT	0
369963	356301	04057K	PARTICIPANT	\N	PRESENT	0
369964	356301	14253S	PARTICIPANT	\N	PRESENT	0
369965	356301	01060R	PARTICIPANT	\N	PRESENT	0
369966	356301	14055N	PARTICIPANT	\N	PRESENT	0
369967	356301	04049K	PARTICIPANT	\N	PRESENT	0
369968	356301	89017R	PARTICIPANT	\N	PRESENT	0
369969	356301	19573D	PARTICIPANT	\N	PRESENT	0
369970	356301	19794Q	PARTICIPANT	\N	PRESENT	0
369971	356301	02002K	PARTICIPANT	\N	PRESENT	0
369972	356301	14133K	PARTICIPANT	\N	PRESENT	0
369973	356301	92040Q	PARTICIPANT	\N	PRESENT	0
369974	356301	04038G	PARTICIPANT	\N	PRESENT	0
369976	356301	14169X	PARTICIPANT	\N	PRESENT	0
369979	356301	19447X	PARTICIPANT	\N	PRESENT	0
369981	356301	98035U	PARTICIPANT	\N	PRESENT	0
369983	356301	14159V	PARTICIPANT	\N	PRESENT	0
369985	356301	11027H	PARTICIPANT	\N	PRESENT	0
369986	356301	11049P	PARTICIPANT	\N	PRESENT	0
369987	356301	04059M	PARTICIPANT	\N	PRESENT	0
387466	387465	11074Q	PARTICIPANT	\N	PRESENT	0
387467	387465	08011M	PARTICIPANT	\N	PRESENT	0
390192	388106	14257W	PARTICIPANT	\N	PRESENT	0
390193	388106	19719D	PARTICIPANT	\N	PRESENT	0
390194	388106	16685X	PARTICIPANT	\N	PRESENT	0
390195	388106	14219Q	PARTICIPANT	\N	PRESENT	0
390196	388106	14205J	PARTICIPANT	\N	PRESENT	0
390197	388106	19441R	PARTICIPANT	\N	PRESENT	0
390198	388106	19479G	PARTICIPANT	\N	PRESENT	0
390199	388106	08056B	PARTICIPANT	\N	PRESENT	0
390200	388106	14267Y	PARTICIPANT	\N	PRESENT	0
390201	388106	14030Q	PARTICIPANT	\N	PRESENT	0
390202	388106	14327T	PARTICIPANT	\N	PRESENT	0
390203	388106	01025N	PARTICIPANT	\N	PRESENT	0
390204	388106	01024M	PARTICIPANT	\N	PRESENT	0
390205	388106	11085T	PARTICIPANT	\N	PRESENT	0
390206	388106	19577H	PARTICIPANT	\N	PRESENT	0
390207	388106	14255U	PARTICIPANT	\N	PRESENT	0
390208	388106	14083S	PARTICIPANT	\N	PRESENT	0
390209	388106	19521Q	PARTICIPANT	\N	PRESENT	0
390210	388106	14073Q	PARTICIPANT	\N	PRESENT	0
390211	388106	19749K	PARTICIPANT	\N	PRESENT	0
390212	388106	14089Y	PARTICIPANT	\N	PRESENT	0
390213	388106	14103D	PARTICIPANT	\N	PRESENT	0
390214	388106	04088S	PARTICIPANT	\N	PRESENT	0
390215	388106	18083K	PARTICIPANT	\N	PRESENT	0
390216	388106	19711U	PARTICIPANT	\N	PRESENT	0
390217	388106	14211G	PARTICIPANT	\N	PRESENT	0
390218	388106	99004R	PARTICIPANT	\N	PRESENT	0
390219	388106	96004D	PARTICIPANT	\N	PRESENT	0
390220	388106	14157T	PARTICIPANT	\N	PRESENT	0
390221	388106	95062K	PARTICIPANT	\N	PRESENT	0
390222	388106	11064N	PARTICIPANT	\N	PRESENT	0
390223	388106	04097T	PARTICIPANT	\N	PRESENT	0
390224	388106	08020N	PARTICIPANT	\N	PRESENT	0
390225	388106	08010L	PARTICIPANT	\N	PRESENT	0
390226	388106	04042C	PARTICIPANT	\N	PRESENT	0
390227	388106	04071H	PARTICIPANT	\N	PRESENT	0
390228	388106	19643A	PARTICIPANT	\N	PRESENT	0
390229	388106	14169X	PARTICIPANT	\N	PRESENT	0
390230	388106	10015M	PARTICIPANT	\N	PRESENT	0
390231	388106	11043H	PARTICIPANT	\N	PRESENT	0
390232	388106	01048V	PARTICIPANT	\N	PRESENT	0
390233	388106	19649G	PARTICIPANT	\N	PRESENT	0
390234	388106	08028W	PARTICIPANT	\N	PRESENT	0
390235	388106	11090Q	PARTICIPANT	\N	PRESENT	0
390236	388106	95067Q	PARTICIPANT	\N	PRESENT	0
390237	388106	14223L	PARTICIPANT	\N	PRESENT	0
390238	388106	14259Y	PARTICIPANT	\N	PRESENT	0
390239	388106	11080N	PARTICIPANT	\N	PRESENT	0
390240	388106	14191V	PARTICIPANT	\N	PRESENT	0
390241	388106	19515S	PARTICIPANT	\N	PRESENT	0
390242	388106	14199E	PARTICIPANT	\N	PRESENT	0
390243	388106	14031R	PARTICIPANT	\N	PRESENT	0
390244	388106	19575F	PARTICIPANT	\N	PRESENT	0
390245	388106	19721W	PARTICIPANT	\N	PRESENT	0
390246	388106	11048N	PARTICIPANT	\N	PRESENT	0
390247	388106	14041T	PARTICIPANT	\N	PRESENT	0
390248	388106	17583W	PARTICIPANT	\N	PRESENT	0
389495	386221	14081Q	PARTICIPANT	\N	EXCUSE	0
390191	388106	19735D	PARTICIPANT	\N	PRESENT	0
390249	388106	14105F	PARTICIPANT	\N	PRESENT	0
390250	388106	14115H	PARTICIPANT	\N	PRESENT	0
390251	388106	08047A	PARTICIPANT	\N	PRESENT	0
390252	388106	19794Q	PARTICIPANT	\N	PRESENT	0
390253	388106	19447X	PARTICIPANT	\N	PRESENT	0
390254	388106	19507S	PARTICIPANT	\N	PRESENT	0
390255	388106	14038Y	PARTICIPANT	\N	PRESENT	0
390256	388106	14119M	PARTICIPANT	\N	PRESENT	0
390257	388106	14135M	PARTICIPANT	\N	PRESENT	0
390258	388106	14133K	PARTICIPANT	\N	PRESENT	0
390259	388106	19399H	PARTICIPANT	\N	PRESENT	0
390260	388106	04086Q	PARTICIPANT	\N	PRESENT	0
390261	388106	04033B	PARTICIPANT	\N	PRESENT	0
390262	388106	08048B	PARTICIPANT	\N	PRESENT	0
390263	388106	19693L	PARTICIPANT	\N	PRESENT	0
390264	388106	14265W	PARTICIPANT	\N	PRESENT	0
390265	388106	14213J	PARTICIPANT	\N	PRESENT	0
390266	388106	19729F	PARTICIPANT	\N	PRESENT	0
390267	388106	14355X	PARTICIPANT	\N	PRESENT	0
390268	388106	19657G	PARTICIPANT	\N	PRESENT	0
390269	388106	19741B	PARTICIPANT	\N	PRESENT	0
390270	388106	19443T	PARTICIPANT	\N	PRESENT	0
390271	388106	14061L	PARTICIPANT	\N	PRESENT	0
390272	388106	19733B	PARTICIPANT	\N	PRESENT	0
390273	388106	14329V	PARTICIPANT	\N	PRESENT	0
390274	388106	14357A	PARTICIPANT	\N	PRESENT	0
390275	388106	19675J	PARTICIPANT	\N	PRESENT	0
390276	388106	19383Y	PARTICIPANT	\N	PRESENT	0
390277	388106	19701S	PARTICIPANT	\N	PRESENT	0
390278	388106	19762G	PARTICIPANT	\N	PRESENT	0
390279	388106	19581D	PARTICIPANT	\N	PRESENT	0
390280	388106	19367Y	PARTICIPANT	\N	PRESENT	0
390281	388106	19671E	PARTICIPANT	\N	PRESENT	0
390282	388106	14079W	PARTICIPANT	\N	PRESENT	0
390283	388106	14217N	PARTICIPANT	\N	PRESENT	0
390284	388106	07033P	PARTICIPANT	\N	PRESENT	0
390285	388106	11103C	PARTICIPANT	\N	PRESENT	0
390286	388106	97011G	PARTICIPANT	\N	PRESENT	0
390287	388106	05012A	PARTICIPANT	\N	PRESENT	0
390288	388106	14026U	PARTICIPANT	\N	PRESENT	0
390289	388106	08034U	PARTICIPANT	\N	PRESENT	0
390290	388106	19533U	PARTICIPANT	\N	PRESENT	0
390291	388106	10006L	PARTICIPANT	\N	PRESENT	0
390292	388106	19798U	PARTICIPANT	\N	PRESENT	0
390293	388106	14237S	PARTICIPANT	\N	PRESENT	0
390294	388106	14193X	PARTICIPANT	\N	PRESENT	0
390295	388106	14215L	PARTICIPANT	\N	PRESENT	0
390296	388106	14087W	PARTICIPANT	\N	PRESENT	0
390297	388106	14053L	PARTICIPANT	\N	PRESENT	0
390298	388106	14249W	PARTICIPANT	\N	PRESENT	0
390299	388106	14069U	PARTICIPANT	\N	PRESENT	0
390300	388106	04043D	PARTICIPANT	\N	PRESENT	0
390301	388106	14071N	PARTICIPANT	\N	PRESENT	0
390302	388106	14187A	PARTICIPANT	\N	PRESENT	0
390303	388106	05008E	PARTICIPANT	\N	PRESENT	0
390304	388106	11097X	PARTICIPANT	\N	PRESENT	0
390305	388106	19421M	PARTICIPANT	\N	PRESENT	0
390306	388106	95041E	PARTICIPANT	\N	PRESENT	0
390307	388106	04044E	PARTICIPANT	\N	PRESENT	0
390308	388106	04092N	PARTICIPANT	\N	PRESENT	0
390309	388106	95030B	PARTICIPANT	\N	PRESENT	0
390310	388106	04047H	PARTICIPANT	\N	PRESENT	0
390311	388106	11101A	PARTICIPANT	\N	PRESENT	0
390312	388106	98024R	PARTICIPANT	\N	PRESENT	0
390313	388106	08039A	PARTICIPANT	\N	PRESENT	0
390314	388106	14039A	PARTICIPANT	\N	PRESENT	0
390315	388106	19745F	PARTICIPANT	\N	PRESENT	0
390316	388106	19335Q	PARTICIPANT	\N	PRESENT	0
390318	385093	19725B	PRESIDENT	0	PRESENT	0
390319	385093	04057K	PARTICIPANT	\N	PRESENT	0
390320	385093	14026U	PARTICIPANT	\N	PRESENT	0
390321	385093	08073C	PARTICIPANT	\N	EXCUSE	0
390322	385093	08015R	PARTICIPANT	\N	EXCUSE	0
390323	385093	14107H	PARTICIPANT	\N	EXCUSE	0
390324	385093	08014Q	PARTICIPANT	\N	EXCUSE	0
390572	377979	04086Q	PARTICIPANT	\N	PRESENT	0
390573	377979	14259Y	PARTICIPANT	\N	PRESENT	0
390574	377979	04038G	PARTICIPANT	\N	PRESENT	0
390575	377979	11040E	PARTICIPANT	\N	PRESENT	0
390576	377979	11056N	PARTICIPANT	\N	PRESENT	0
390577	377979	04085P	PARTICIPANT	\N	PRESENT	0
390578	377979	19758L	PARTICIPANT	\N	PRESENT	0
390579	377979	19489J	PARTICIPANT	\N	PRESENT	0
390580	377979	14205J	PARTICIPANT	\N	PRESENT	0
390581	377979	19479G	PARTICIPANT	\N	PRESENT	0
390582	377979	19737F	PARTICIPANT	\N	PRESENT	0
390600	377979	14079W	PARTICIPANT	\N	PRESENT	0
390584	377979	19335Q	PARTICIPANT	\N	PRESENT	0
390605	377979	14179A	PARTICIPANT	\N	PRESENT	0
390586	377979	19533U	PARTICIPANT	\N	PRESENT	0
390587	377979	19565D	PARTICIPANT	\N	PRESENT	0
390588	377979	80013X	PARTICIPANT	\N	PRESENT	0
390589	377979	11110B	PARTICIPANT	\N	PRESENT	0
390590	377979	11104D	PARTICIPANT	\N	PRESENT	0
390591	377979	07004J	PARTICIPANT	\N	PRESENT	0
390592	377979	14219Q	PARTICIPANT	\N	PRESENT	0
390593	377979	14107H	PARTICIPANT	\N	PRESENT	0
390594	377979	14053L	PARTICIPANT	\N	PRESENT	0
390595	377979	19619A	PARTICIPANT	\N	PRESENT	0
390596	377979	14207L	PARTICIPANT	\N	PRESENT	0
390597	377979	08056B	PARTICIPANT	\N	PRESENT	0
390598	377979	14089Y	PARTICIPANT	\N	PRESENT	0
390599	377979	19745F	PARTICIPANT	\N	PRESENT	0
390601	377979	19585H	PARTICIPANT	\N	PRESENT	0
390602	377979	19695N	PARTICIPANT	\N	PRESENT	0
390603	377979	19687N	PARTICIPANT	\N	PRESENT	0
390604	377979	19543W	PARTICIPANT	\N	PRESENT	0
390606	377979	11109J	PARTICIPANT	\N	PRESENT	0
363453	345235	11064N	PARTICIPANT	\N	PRESENT	0
363454	345235	14219Q	PARTICIPANT	\N	PRESENT	0
363455	345235	19369B	PARTICIPANT	\N	PRESENT	0
363456	345235	08056B	PARTICIPANT	\N	PRESENT	0
363457	345235	19737F	PARTICIPANT	\N	PRESENT	0
363458	345235	19525U	PARTICIPANT	\N	PRESENT	0
363459	345235	14029X	PARTICIPANT	\N	PRESENT	0
363460	345235	19741B	PARTICIPANT	\N	PRESENT	0
363461	345235	19507S	PARTICIPANT	\N	PRESENT	0
363462	345235	14033T	PARTICIPANT	\N	PRESENT	0
363463	345235	19794Q	PARTICIPANT	\N	PRESENT	0
363464	345235	19573D	PARTICIPANT	\N	PRESENT	0
363465	345235	19515S	PARTICIPANT	\N	PRESENT	0
363466	345235	04071H	PARTICIPANT	\N	PRESENT	0
363467	345235	95062K	PARTICIPANT	\N	PRESENT	0
363468	345235	19703U	PARTICIPANT	\N	PRESENT	0
363469	345235	14115H	PARTICIPANT	\N	PRESENT	0
363470	345235	19415P	PARTICIPANT	\N	PRESENT	0
363471	345235	08015R	PARTICIPANT	\N	PRESENT	0
363472	345235	19711U	PARTICIPANT	\N	PRESENT	0
363473	345235	11048N	PARTICIPANT	\N	PRESENT	0
363474	345235	11103C	PARTICIPANT	\N	PRESENT	0
363475	345235	19383Y	PARTICIPANT	\N	PRESENT	0
363476	345235	04018C	PARTICIPANT	\N	PRESENT	0
363477	345235	19798U	PARTICIPANT	\N	PRESENT	0
363478	345235	14249W	PARTICIPANT	\N	PRESENT	0
363479	345235	14223L	PARTICIPANT	\N	PRESENT	0
363480	345235	14187A	PARTICIPANT	\N	PRESENT	0
363481	345235	14071N	PARTICIPANT	\N	PRESENT	0
363482	345235	19671E	PARTICIPANT	\N	PRESENT	0
363483	345235	19701S	PARTICIPANT	\N	PRESENT	0
363484	345235	19747H	PARTICIPANT	\N	PRESENT	0
363485	345235	14087W	PARTICIPANT	\N	PRESENT	0
363486	345235	04097T	PARTICIPANT	\N	PRESENT	0
363487	345235	14265W	PARTICIPANT	\N	PRESENT	0
363488	345235	19467C	PARTICIPANT	\N	PRESENT	0
363489	345235	14225N	PARTICIPANT	\N	PRESENT	0
363490	345235	14063N	PARTICIPANT	\N	PRESENT	0
363491	345235	14051J	PARTICIPANT	\N	PRESENT	0
363492	345235	11066Q	PARTICIPANT	\N	PRESENT	0
363493	345235	19687N	PARTICIPANT	\N	PRESENT	0
363494	345235	11077T	PARTICIPANT	\N	PRESENT	0
363495	345235	19413M	PARTICIPANT	\N	PRESENT	0
363496	345235	14111D	PARTICIPANT	\N	PRESENT	0
363497	345235	16685X	PARTICIPANT	\N	PRESENT	0
363498	345235	19611R	PARTICIPANT	\N	PRESENT	0
363499	345235	01024M	PARTICIPANT	\N	PRESENT	0
363500	345235	08020N	PARTICIPANT	\N	PRESENT	0
363501	345235	04088S	PARTICIPANT	\N	PRESENT	0
363502	345235	14079W	PARTICIPANT	\N	PRESENT	0
363503	345235	14267Y	PARTICIPANT	\N	PRESENT	0
363504	345235	14103D	PARTICIPANT	\N	PRESENT	0
363505	345235	08060W	PARTICIPANT	\N	PRESENT	0
363506	345235	19689Q	PARTICIPANT	\N	PRESENT	0
363507	345235	19479G	PARTICIPANT	\N	PRESENT	0
363508	345235	08031R	PARTICIPANT	\N	PRESENT	0
363509	345235	10015M	PARTICIPANT	\N	PRESENT	0
363510	345235	19347U	PARTICIPANT	\N	PRESENT	0
363511	345235	19758L	PARTICIPANT	\N	PRESENT	0
363512	345235	97011G	PARTICIPANT	\N	PRESENT	0
363513	345235	17637T	PARTICIPANT	\N	PRESENT	0
363514	345235	14133K	PARTICIPANT	\N	PRESENT	0
363515	345235	12016W	PARTICIPANT	\N	PRESENT	0
363516	345235	14105F	PARTICIPANT	\N	PRESENT	0
363517	345235	14357A	PARTICIPANT	\N	PRESENT	0
363518	345235	19733B	PARTICIPANT	\N	PRESENT	0
363519	345235	19731Y	PARTICIPANT	\N	PRESENT	0
363520	345235	14217N	PARTICIPANT	\N	PRESENT	0
363521	345235	19768N	PARTICIPANT	\N	PRESENT	0
363522	345235	14135M	PARTICIPANT	\N	PRESENT	0
363523	345235	08010L	PARTICIPANT	\N	PRESENT	0
363524	345235	14038Y	PARTICIPANT	\N	PRESENT	0
363525	345235	08034U	PARTICIPANT	\N	PRESENT	0
363526	345235	01057W	PARTICIPANT	\N	PRESENT	0
363551	345235	01060R	PARTICIPANT	\N	PRESENT	0
363553	345235	01025N	PARTICIPANT	\N	PRESENT	0
363554	345235	19782L	PARTICIPANT	\N	PRESENT	0
363571	345235	14083S	PARTICIPANT	\N	PRESENT	0
363572	345235	19349W	PARTICIPANT	\N	PRESENT	0
363573	345235	19575F	PARTICIPANT	\N	PRESENT	0
363574	345235	88008L	PARTICIPANT	\N	PRESENT	0
363575	345235	11097X	PARTICIPANT	\N	PRESENT	0
363576	345235	19253P	PARTICIPANT	\N	PRESENT	0
363649	345290	19715Y	PARTICIPANT	\N	PRESENT	0
363650	345290	19798U	PARTICIPANT	\N	PRESENT	0
363651	345290	08018U	PARTICIPANT	\N	PRESENT	0
363652	345290	95037J	PARTICIPANT	\N	PRESENT	0
363653	345290	19383Y	PARTICIPANT	\N	PRESENT	0
363654	345290	98022P	PARTICIPANT	\N	PRESENT	0
363655	345290	14081Q	PARTICIPANT	\N	PRESENT	0
363656	345290	04038G	PARTICIPANT	\N	PRESENT	0
363657	345290	14159V	PARTICIPANT	\N	PRESENT	0
363658	345290	17779H	PARTICIPANT	\N	PRESENT	0
363659	345290	19583F	PARTICIPANT	\N	PRESENT	0
363660	345290	19569H	PARTICIPANT	\N	PRESENT	0
363661	345290	14063N	PARTICIPANT	\N	PRESENT	0
363662	345290	19467C	PARTICIPANT	\N	PRESENT	0
363663	345290	98024R	PARTICIPANT	\N	PRESENT	0
363664	345290	19631V	PARTICIPANT	\N	PRESENT	0
363665	345290	14217N	PARTICIPANT	\N	PRESENT	0
363666	345290	19737F	PARTICIPANT	\N	PRESENT	0
363667	345290	14061L	PARTICIPANT	\N	PRESENT	0
363668	345290	19507S	PARTICIPANT	\N	PRESENT	0
363669	345290	14355X	PARTICIPANT	\N	PRESENT	0
363670	345290	14041T	PARTICIPANT	\N	PRESENT	0
363671	345290	19581D	PARTICIPANT	\N	PRESENT	0
363673	345290	19367Y	PARTICIPANT	\N	PRESENT	0
363674	345290	96004D	PARTICIPANT	\N	PRESENT	0
363675	345290	19711U	PARTICIPANT	\N	PRESENT	0
363676	345290	04035D	PARTICIPANT	\N	PRESENT	0
363677	345290	14038Y	PARTICIPANT	\N	PRESENT	0
363678	345290	14223L	PARTICIPANT	\N	PRESENT	0
363679	345290	88008L	PARTICIPANT	\N	PRESENT	0
363680	345290	19701S	PARTICIPANT	\N	PRESENT	0
363681	345290	80013X	PARTICIPANT	\N	PRESENT	0
363682	345290	08060W	PARTICIPANT	\N	PRESENT	0
363683	345290	19747H	PARTICIPANT	\N	PRESENT	0
363684	345290	19525U	PARTICIPANT	\N	PRESENT	0
363685	345290	14265W	PARTICIPANT	\N	PRESENT	0
363686	345290	19679N	PARTICIPANT	\N	PRESENT	0
363687	345290	14169X	PARTICIPANT	\N	PRESENT	0
363688	345290	19511N	PARTICIPANT	\N	PRESENT	0
363689	345290	19515S	PARTICIPANT	\N	PRESENT	0
363690	345290	07033P	PARTICIPANT	\N	PRESENT	0
363691	345290	08069G	PARTICIPANT	\N	PRESENT	0
363692	345290	04071H	PARTICIPANT	\N	PRESENT	0
363693	345290	01028R	PARTICIPANT	\N	PRESENT	0
363694	345290	14253S	PARTICIPANT	\N	PRESENT	0
363695	345290	10015M	PARTICIPANT	\N	PRESENT	0
363696	345290	14031R	PARTICIPANT	\N	PRESENT	0
363697	345290	11066Q	PARTICIPANT	\N	PRESENT	0
363698	345290	08043V	PARTICIPANT	\N	PRESENT	0
363699	345290	14105F	PARTICIPANT	\N	PRESENT	0
363700	345290	10006L	PARTICIPANT	\N	PRESENT	0
363701	345290	17637T	PARTICIPANT	\N	PRESENT	0
363702	345290	99004R	PARTICIPANT	\N	PRESENT	0
363703	345290	19794Q	PARTICIPANT	\N	PRESENT	0
363704	345290	08015R	PARTICIPANT	\N	PRESENT	0
363705	345290	14059S	PARTICIPANT	\N	PRESENT	0
363706	345290	19673G	PARTICIPANT	\N	PRESENT	0
363707	345290	14071N	PARTICIPANT	\N	PRESENT	0
363708	345290	19533U	PARTICIPANT	\N	PRESENT	0
363709	345290	98050T	PARTICIPANT	\N	PRESENT	0
363710	345290	14087W	PARTICIPANT	\N	PRESENT	0
363711	345290	04018C	PARTICIPANT	\N	PRESENT	0
363712	345290	19705W	PARTICIPANT	\N	PRESENT	0
363713	345290	95062K	PARTICIPANT	\N	PRESENT	0
363714	345290	04092N	PARTICIPANT	\N	PRESENT	0
363715	345290	19729F	PARTICIPANT	\N	PRESENT	0
363716	345290	14357A	PARTICIPANT	\N	PRESENT	0
363717	345290	19671E	PARTICIPANT	\N	PRESENT	0
363647	345290	86034E	PARTICIPANT	\N	PRESENT	0
363648	345290	19731Y	PARTICIPANT	\N	PRESENT	0
363718	345290	01058X	PARTICIPANT	\N	PRESENT	0
363719	345290	08062Y	PARTICIPANT	\N	PRESENT	0
363720	345290	05012A	PARTICIPANT	\N	PRESENT	0
363721	345290	04097T	PARTICIPANT	\N	PRESENT	0
363722	345290	19415P	PARTICIPANT	\N	PRESENT	0
363723	345290	14053L	PARTICIPANT	\N	PRESENT	0
363724	345290	19667J	PARTICIPANT	\N	PRESENT	0
363725	345290	19703U	PARTICIPANT	\N	PRESENT	0
363726	345290	11048N	PARTICIPANT	\N	PRESENT	0
363727	345290	19766L	PARTICIPANT	\N	PRESENT	0
363728	345290	19723Y	PARTICIPANT	\N	PRESENT	0
363729	345290	19741B	PARTICIPANT	\N	PRESENT	0
363730	345290	19421M	PARTICIPANT	\N	PRESENT	0
363731	345290	08020N	PARTICIPANT	\N	PRESENT	0
373762	367788	01048V	PARTICIPANT	\N	EXCUSE	0
376765	371471	19251M	PARTICIPANT	\N	PRESENT	0
376766	371471	04047H	PARTICIPANT	\N	PRESENT	0
376767	371471	19585H	PARTICIPANT	\N	PRESENT	0
376768	371471	14001X	PARTICIPANT	\N	PRESENT	0
376769	371471	04057K	PARTICIPANT	\N	PRESENT	0
376770	371471	14251Q	PARTICIPANT	\N	PRESENT	0
376771	371471	19717B	PARTICIPANT	\N	PRESENT	0
376772	371471	14041T	PARTICIPANT	\N	PRESENT	0
376773	371471	19711U	PARTICIPANT	\N	PRESENT	0
376774	371471	14081Q	PARTICIPANT	\N	PRESENT	0
376775	371471	14111D	PARTICIPANT	\N	PRESENT	0
376776	371471	19713W	PARTICIPANT	\N	PRESENT	0
376778	371471	14093U	PARTICIPANT	\N	PRESENT	0
376779	371471	14069U	PARTICIPANT	\N	PRESENT	0
376780	371471	14217N	PARTICIPANT	\N	PRESENT	0
376781	371471	11056N	PARTICIPANT	\N	PRESENT	0
376782	371471	19681G	PARTICIPANT	\N	PRESENT	0
376783	371471	08010L	PARTICIPANT	\N	PRESENT	0
376784	371471	19441R	PARTICIPANT	\N	PRESENT	0
376785	371471	14147R	PARTICIPANT	\N	PRESENT	0
376786	371471	14259Y	PARTICIPANT	\N	PRESENT	0
376787	371471	19762G	PARTICIPANT	\N	PRESENT	0
376788	371471	01028R	PARTICIPANT	\N	PRESENT	0
376789	371471	19543W	PARTICIPANT	\N	PRESENT	0
376790	371471	19581D	PARTICIPANT	\N	PRESENT	0
376791	371471	19701S	PARTICIPANT	\N	PRESENT	0
376792	371471	11049P	PARTICIPANT	\N	PRESENT	0
376793	371471	19691J	PARTICIPANT	\N	PRESENT	0
376794	371471	19669L	PARTICIPANT	\N	PRESENT	0
376795	371471	99004R	PARTICIPANT	\N	PRESENT	0
376796	371471	10015M	PARTICIPANT	\N	PRESENT	0
376799	371471	19573D	PARTICIPANT	\N	PRESENT	0
376800	371471	04038G	PARTICIPANT	\N	PRESENT	0
376801	371471	14231L	PARTICIPANT	\N	PRESENT	0
376802	371471	04085P	PARTICIPANT	\N	PRESENT	0
376803	371471	14331P	PARTICIPANT	\N	PRESENT	0
376806	371471	14281W	PARTICIPANT	\N	PRESENT	0
376807	371471	07004J	PARTICIPANT	\N	PRESENT	0
376808	371471	19575F	PARTICIPANT	\N	PRESENT	0
376809	371471	19549D	PARTICIPANT	\N	PRESENT	0
376810	371471	19695N	PARTICIPANT	\N	PRESENT	0
376811	371471	19663E	PARTICIPANT	\N	PRESENT	0
376812	371471	19794Q	PARTICIPANT	\N	PRESENT	0
376813	371471	14219Q	PARTICIPANT	\N	PRESENT	0
376814	371471	11026G	PARTICIPANT	\N	PRESENT	0
376815	371471	08069G	PARTICIPANT	\N	PRESENT	0
376879	371472	04057K	PARTICIPANT	\N	PRESENT	0
376880	371472	19717B	PARTICIPANT	\N	PRESENT	0
376881	371472	19691J	PARTICIPANT	\N	PRESENT	0
376882	371472	07004J	PARTICIPANT	\N	PRESENT	0
376883	371472	19701S	PARTICIPANT	\N	PRESENT	0
376884	371472	19794Q	PARTICIPANT	\N	PRESENT	0
376886	371472	19711U	PARTICIPANT	\N	PRESENT	0
376887	371472	08010L	PARTICIPANT	\N	PRESENT	0
376888	371472	14281W	PARTICIPANT	\N	PRESENT	0
376891	371472	11043H	PARTICIPANT	\N	PRESENT	0
376892	371472	19581D	PARTICIPANT	\N	PRESENT	0
376893	371472	14081Q	PARTICIPANT	\N	PRESENT	0
376894	371472	14069U	PARTICIPANT	\N	PRESENT	0
376895	371472	14251Q	PARTICIPANT	\N	PRESENT	0
376896	371472	04085P	PARTICIPANT	\N	PRESENT	0
378619	371477	19691J	PARTICIPANT	\N	PRESENT	0
378620	371477	14159V	PARTICIPANT	\N	PRESENT	0
378621	371477	14231L	PARTICIPANT	\N	PRESENT	0
378617	371477	14083S	PARTICIPANT	\N	PRESENT	0
378618	371477	19521Q	PARTICIPANT	\N	PRESENT	0
378622	371477	11064N	PARTICIPANT	\N	PRESENT	0
378623	371477	19349W	PARTICIPANT	\N	PRESENT	0
378624	371477	11099A	PARTICIPANT	\N	PRESENT	0
378625	371477	19387D	PARTICIPANT	\N	PRESENT	0
378626	371477	19629C	PARTICIPANT	\N	PRESENT	0
378627	371477	14251Q	PARTICIPANT	\N	PRESENT	0
378628	371477	14151M	PARTICIPANT	\N	PRESENT	0
378629	371477	19631V	PARTICIPANT	\N	PRESENT	0
378630	371477	19713W	PARTICIPANT	\N	PRESENT	0
378631	371477	14241N	PARTICIPANT	\N	PRESENT	0
378632	371477	19768N	PARTICIPANT	\N	PRESENT	0
376875	371472	14034U	PARTICIPANT	\N	PRESENT	0
376876	371472	19713W	PARTICIPANT	\N	PRESENT	0
378633	371477	04033B	PARTICIPANT	\N	PRESENT	0
378634	371477	14187A	PARTICIPANT	\N	PRESENT	0
378635	371477	19367Y	PARTICIPANT	\N	PRESENT	0
378636	371477	14042U	PARTICIPANT	\N	PRESENT	0
378637	371477	14079W	PARTICIPANT	\N	PRESENT	0
378638	371477	19747H	PARTICIPANT	\N	PRESENT	0
378639	371477	19447X	PARTICIPANT	\N	PRESENT	0
378640	371477	14265W	PARTICIPANT	\N	PRESENT	0
378641	371477	19733B	PARTICIPANT	\N	PRESENT	0
378642	371477	14105F	PARTICIPANT	\N	PRESENT	0
378643	371477	19581D	PARTICIPANT	\N	PRESENT	0
378644	371477	14034U	PARTICIPANT	\N	PRESENT	0
378645	371477	08031R	PARTICIPANT	\N	PRESENT	0
378646	371477	14073Q	PARTICIPANT	\N	PRESENT	0
378647	371477	14213J	PARTICIPANT	\N	PRESENT	0
378648	371477	14026U	PARTICIPANT	\N	PRESENT	0
378655	376743	14028W	PARTICIPANT	\N	EXCUSE	0
378697	378696	14065Q	PARTICIPANT	\N	PRESENT	0
378698	378696	96004D	PARTICIPANT	\N	PRESENT	0
378699	378696	14089Y	PARTICIPANT	\N	PRESENT	0
378700	378696	14357A	PARTICIPANT	\N	PRESENT	0
378701	378696	14079W	PARTICIPANT	\N	PRESENT	0
378702	378696	14249W	PARTICIPANT	\N	PRESENT	0
378703	378696	11083R	PARTICIPANT	\N	PRESENT	0
378705	378696	19725B	PARTICIPANT	\N	PRESENT	0
378706	378696	08044W	PARTICIPANT	\N	PRESENT	0
378708	378696	14097Y	PARTICIPANT	\N	PRESENT	0
378710	378696	12041X	PARTICIPANT	\N	PRESENT	0
378711	378696	11026G	PARTICIPANT	\N	PRESENT	0
378712	378696	19563B	PARTICIPANT	\N	PRESENT	0
378713	378696	14225N	PARTICIPANT	\N	PRESENT	0
378714	378696	98035U	PARTICIPANT	\N	PRESENT	0
378716	378696	14237S	PARTICIPANT	\N	PRESENT	0
378717	378696	14331P	PARTICIPANT	\N	PRESENT	0
378718	378696	14073Q	PARTICIPANT	\N	PRESENT	0
378719	378696	10015M	PARTICIPANT	\N	EXCUSE	0
378720	378696	04057K	PARTICIPANT	\N	EXCUSE	0
378721	378696	14061L	PARTICIPANT	\N	EXCUSE	0
378723	378696	04097T	PARTICIPANT	\N	PRESENT	0
378896	378894	04086Q	PARTICIPANT	\N	PRESENT	0
379003	371479	14026U	PARTICIPANT	\N	PRESENT	0
379004	371479	14223L	PARTICIPANT	\N	PRESENT	0
379005	371479	19399H	PARTICIPANT	\N	PRESENT	0
379006	371479	19679N	PARTICIPANT	\N	PRESENT	0
379007	371479	11043H	PARTICIPANT	\N	PRESENT	0
379008	371479	14105F	PARTICIPANT	\N	PRESENT	0
379009	371479	19443T	PARTICIPANT	\N	PRESENT	0
379021	371479	14157T	PARTICIPANT	\N	PRESENT	0
379022	371479	19798U	PARTICIPANT	\N	PRESENT	0
379023	371479	08020N	PARTICIPANT	\N	PRESENT	0
379024	371479	04035D	PARTICIPANT	\N	PRESENT	0
379037	371479	19507S	PARTICIPANT	\N	PRESENT	0
379038	371479	14169X	PARTICIPANT	\N	PRESENT	0
379040	379039	14065Q	PARTICIPANT	\N	PRESENT	0
379041	379039	10015M	PARTICIPANT	\N	PRESENT	0
379042	379039	19762G	PARTICIPANT	\N	PRESENT	0
379043	371479	19573D	PARTICIPANT	\N	PRESENT	0
379048	371479	19794Q	PARTICIPANT	\N	PRESENT	0
379046	371479	19693L	PARTICIPANT	\N	PRESENT	0
379047	371479	14331P	PARTICIPANT	\N	PRESENT	0
379049	371479	08015R	PARTICIPANT	\N	PRESENT	0
379050	371479	04042C	PARTICIPANT	\N	PRESENT	0
379051	371479	87003B	PARTICIPANT	\N	PRESENT	0
379052	371479	97011G	PARTICIPANT	\N	PRESENT	0
379053	371479	14357A	PARTICIPANT	\N	PRESENT	0
379054	371479	96004D	PARTICIPANT	\N	PRESENT	0
379055	371479	11101A	PARTICIPANT	\N	PRESENT	0
379058	371479	19701S	PARTICIPANT	\N	PRESENT	0
379059	371479	04088S	PARTICIPANT	\N	PRESENT	0
379060	371479	14053L	PARTICIPANT	\N	PRESENT	0
379061	371479	11103C	PARTICIPANT	\N	PRESENT	0
379062	371479	19711U	PARTICIPANT	\N	PRESENT	0
379063	371479	99004R	PARTICIPANT	\N	PRESENT	0
379064	371479	14133K	PARTICIPANT	\N	PRESENT	0
379065	371479	07033P	PARTICIPANT	\N	PRESENT	0
379066	371479	14135M	PARTICIPANT	\N	PRESENT	0
379067	371479	19581D	PARTICIPANT	\N	PRESENT	0
379068	371479	08010L	PARTICIPANT	\N	PRESENT	0
379069	371479	11048N	PARTICIPANT	\N	PRESENT	0
379070	371479	19703U	PARTICIPANT	\N	PRESENT	0
379071	371479	19747H	PARTICIPANT	\N	PRESENT	0
379072	371479	04097T	PARTICIPANT	\N	PRESENT	0
379073	371479	14259Y	PARTICIPANT	\N	PRESENT	0
379074	371479	14187A	PARTICIPANT	\N	PRESENT	0
379076	371479	19671E	PARTICIPANT	\N	PRESENT	0
379080	371479	19383Y	PARTICIPANT	\N	PRESENT	0
379082	371479	11049P	PARTICIPANT	\N	PRESENT	0
363165	358050	08012N	PARTICIPANT	\N	PRESENT	0
363166	358050	11083R	PARTICIPANT	\N	PRESENT	0
363168	339597	04043D	PARTICIPANT	\N	PRESENT	0
363185	363184	19611R	PARTICIPANT	\N	PRESENT	0
363186	363184	14107H	PARTICIPANT	\N	PRESENT	0
363190	363189	19611R	PARTICIPANT	\N	PRESENT	0
363192	363189	14107H	PARTICIPANT	\N	PRESENT	0
363193	363189	19693L	PARTICIPANT	\N	PRESENT	0
363195	363189	19758L	PARTICIPANT	\N	PRESENT	0
363197	363189	19621T	PARTICIPANT	\N	PRESENT	0
363199	363189	08017T	PARTICIPANT	\N	PRESENT	0
364414	364413	14001X	PARTICIPANT	\N	PRESENT	0
364415	364413	14215L	PARTICIPANT	\N	PRESENT	0
364417	364416	08052W	PARTICIPANT	\N	PRESENT	0
364418	364416	10006L	PARTICIPANT	\N	PRESENT	0
364419	364416	19553Y	PARTICIPANT	\N	PRESENT	0
369988	356301	11074Q	PARTICIPANT	\N	PRESENT	0
369989	356301	14105F	PARTICIPANT	\N	PRESENT	0
369990	356301	17583W	PARTICIPANT	\N	PRESENT	0
369991	356301	19723Y	PARTICIPANT	\N	PRESENT	0
369992	356301	14051J	PARTICIPANT	\N	PRESENT	0
369994	356301	08068F	PARTICIPANT	\N	PRESENT	0
369995	356301	19467C	PARTICIPANT	\N	PRESENT	0
369997	356301	01028R	PARTICIPANT	\N	PRESENT	0
369998	356301	18083K	PARTICIPANT	\N	PRESENT	0
369999	356301	14229S	PARTICIPANT	\N	PRESENT	0
370000	356301	08052W	PARTICIPANT	\N	PRESENT	0
370001	356301	19415P	PARTICIPANT	\N	PRESENT	0
370002	356301	08045X	PARTICIPANT	\N	PRESENT	0
370003	356301	19669L	PARTICIPANT	\N	PRESENT	0
370004	356301	08019V	PARTICIPANT	\N	PRESENT	0
370005	356301	14225N	PARTICIPANT	\N	PRESENT	0
370006	356301	14033T	PARTICIPANT	\N	PRESENT	0
370007	356301	19399H	PARTICIPANT	\N	PRESENT	0
370008	356301	80013X	PARTICIPANT	\N	PRESENT	0
370009	356301	08060W	PARTICIPANT	\N	PRESENT	0
370010	356301	19575F	PARTICIPANT	\N	PRESENT	0
370011	356301	11066Q	PARTICIPANT	\N	PRESENT	0
370012	356301	14265W	PARTICIPANT	\N	PRESENT	0
370013	356301	14065Q	PARTICIPANT	\N	PRESENT	0
370014	356301	08043V	PARTICIPANT	\N	PRESENT	0
370015	356301	14213J	PARTICIPANT	\N	PRESENT	0
370016	356301	14029X	PARTICIPANT	\N	PRESENT	0
370017	356301	11104D	PARTICIPANT	\N	PRESENT	0
370018	356301	08012N	PARTICIPANT	\N	PRESENT	0
370019	356301	19663E	PARTICIPANT	\N	PRESENT	0
370020	356301	14135M	PARTICIPANT	\N	PRESENT	0
370021	356301	14281W	PARTICIPANT	\N	PRESENT	0
370022	356301	04088S	PARTICIPANT	\N	PRESENT	0
370023	356301	14063N	PARTICIPANT	\N	PRESENT	0
370024	356301	19507S	PARTICIPANT	\N	PRESENT	0
370025	356301	14041T	PARTICIPANT	\N	PRESENT	0
370026	356301	11110B	PARTICIPANT	\N	PRESENT	0
370027	356301	14081Q	PARTICIPANT	\N	PRESENT	0
370028	356301	11041F	PARTICIPANT	\N	PRESENT	0
370029	356301	19657G	PARTICIPANT	\N	PRESENT	0
370030	356301	08048B	PARTICIPANT	\N	PRESENT	0
370031	356301	19549D	PARTICIPANT	\N	PRESENT	0
370032	356301	14207L	PARTICIPANT	\N	PRESENT	0
370033	356301	08062Y	PARTICIPANT	\N	PRESENT	0
370034	356301	14085U	PARTICIPANT	\N	PRESENT	0
370035	356301	08015R	PARTICIPANT	\N	PRESENT	0
370036	356301	19333N	PARTICIPANT	\N	PRESENT	0
370037	356301	19768N	PARTICIPANT	\N	PRESENT	0
370038	356301	14257W	PARTICIPANT	\N	PRESENT	0
370039	356301	19631V	PARTICIPANT	\N	PRESENT	0
370040	356301	98050T	PARTICIPANT	\N	PRESENT	0
370041	356301	14109K	PARTICIPANT	\N	PRESENT	0
370042	356301	14061L	PARTICIPANT	\N	PRESENT	0
370043	356301	14059S	PARTICIPANT	\N	PRESENT	0
370044	356301	19725B	PARTICIPANT	\N	PRESENT	0
370045	356301	19329S	PARTICIPANT	\N	PRESENT	0
370046	356301	19733B	PARTICIPANT	\N	PRESENT	0
370047	356301	14329V	PARTICIPANT	\N	PRESENT	0
370048	356301	19591F	PARTICIPANT	\N	PRESENT	0
370049	356301	11067R	PARTICIPANT	\N	PRESENT	0
370050	356301	14357A	PARTICIPANT	\N	PRESENT	0
370051	356301	19503N	PARTICIPANT	\N	PRESENT	0
370052	356301	19675J	PARTICIPANT	\N	PRESENT	0
370053	356301	19689Q	PARTICIPANT	\N	PRESENT	0
370054	356301	19413M	PARTICIPANT	\N	PRESENT	0
370055	356301	04018C	PARTICIPANT	\N	PRESENT	0
370056	356301	19701S	PARTICIPANT	\N	PRESENT	0
370057	356301	19647E	PARTICIPANT	\N	PRESENT	0
370058	356301	11103C	PARTICIPANT	\N	PRESENT	0
370059	356301	19489J	PARTICIPANT	\N	PRESENT	0
370060	356301	17779H	PARTICIPANT	\N	PRESENT	0
370061	356301	14217N	PARTICIPANT	\N	PRESENT	0
370511	367088	14135M	PARTICIPANT	\N	PRESENT	0
370512	367088	19467C	PARTICIPANT	\N	PRESENT	0
370513	367088	19515S	PARTICIPANT	\N	PRESENT	0
370514	367088	14187A	PARTICIPANT	\N	PRESENT	0
370515	367088	19441R	PARTICIPANT	\N	PRESENT	0
370516	367088	19413M	PARTICIPANT	\N	PRESENT	0
370517	367088	11090Q	PRESIDENT	0	PRESENT	0
370518	367088	14033T	PARTICIPANT	\N	PRESENT	0
370519	367088	19631V	PARTICIPANT	\N	PRESENT	0
370520	367088	14205J	PARTICIPANT	\N	PRESENT	0
370521	367088	19507S	PARTICIPANT	\N	PRESENT	0
370522	367088	08015R	PARTICIPANT	\N	PRESENT	0
370523	367088	14197C	PARTICIPANT	\N	PRESENT	0
370524	367088	19369B	PARTICIPANT	\N	PRESENT	0
370525	367088	19747H	PARTICIPANT	\N	PRESENT	0
370526	367088	14207L	PARTICIPANT	\N	PRESENT	0
370527	367088	19511N	PARTICIPANT	\N	PRESENT	0
370528	367088	14265W	PARTICIPANT	\N	PRESENT	0
370529	367088	14257W	PARTICIPANT	\N	PRESENT	0
370530	367088	11101A	PARTICIPANT	\N	EXCUSE	0
370531	367088	11081P	PARTICIPANT	\N	EXCUSE	0
370532	356303	19543W	PARTICIPANT	\N	PRESENT	0
370533	356303	19563B	PARTICIPANT	\N	PRESENT	0
370537	356303	08010L	PARTICIPANT	\N	PRESENT	0
370542	356303	19651A	PARTICIPANT	\N	PRESENT	0
370543	356303	14083S	PARTICIPANT	\N	PRESENT	0
370544	356303	14073Q	PARTICIPANT	\N	PRESENT	0
370551	356303	19691J	PARTICIPANT	\N	PRESENT	0
370552	356303	19447X	PARTICIPANT	\N	PRESENT	0
370561	367088	19782L	PARTICIPANT	\N	PRESENT	0
370563	356303	19782L	PARTICIPANT	\N	PRESENT	0
370564	356303	14197C	PARTICIPANT	\N	PRESENT	0
370565	356303	14053L	PARTICIPANT	\N	PRESENT	0
370568	356303	14033T	PARTICIPANT	\N	PRESENT	0
370582	356303	19503N	PARTICIPANT	\N	PRESENT	0
370583	356303	19253P	PARTICIPANT	\N	PRESENT	0
370584	356303	04045F	PARTICIPANT	\N	PRESENT	0
370585	356303	11049P	PARTICIPANT	\N	PRESENT	0
370586	356303	19719D	PARTICIPANT	\N	PRESENT	0
370587	356303	07029T	PARTICIPANT	\N	PRESENT	0
370588	356303	19549D	PARTICIPANT	\N	PRESENT	0
370636	356304	11070L	PARTICIPANT	\N	PRESENT	0
370637	356304	04038G	PARTICIPANT	\N	PRESENT	0
370638	356304	14065Q	PARTICIPANT	\N	PRESENT	0
370661	356304	14281W	PARTICIPANT	\N	PRESENT	0
370640	356304	04045F	PARTICIPANT	\N	PRESENT	0
370641	356304	19629C	PARTICIPANT	\N	PRESENT	0
370642	356304	19719D	PARTICIPANT	\N	PRESENT	0
370643	356304	19583F	PARTICIPANT	\N	PRESENT	0
370644	356304	02002K	PARTICIPANT	\N	PRESENT	0
370645	356304	14073Q	PARTICIPANT	\N	PRESENT	0
370646	356304	14083S	PARTICIPANT	\N	PRESENT	0
370647	356304	14042U	PARTICIPANT	\N	PRESENT	0
370648	356304	19577H	PARTICIPANT	\N	PRESENT	0
370649	356304	14179A	PARTICIPANT	\N	PRESENT	0
370650	356304	19691J	PARTICIPANT	\N	PRESENT	0
370651	356304	01025N	PARTICIPANT	\N	PRESENT	0
370652	356304	19657G	PARTICIPANT	\N	PRESENT	0
370653	356304	19399H	PARTICIPANT	\N	PRESENT	0
370654	356304	11049P	PARTICIPANT	\N	PRESENT	0
370655	356304	14041T	PARTICIPANT	\N	PRESENT	0
370656	356304	14215L	PARTICIPANT	\N	PRESENT	0
370657	356304	19760E	PARTICIPANT	\N	PRESENT	0
370658	356304	19711U	PARTICIPANT	\N	PRESENT	0
370662	356304	14053L	PARTICIPANT	\N	PRESENT	0
370660	356304	07029T	PARTICIPANT	\N	PRESENT	0
370663	356304	19671E	PARTICIPANT	\N	PRESENT	0
370664	356304	14069U	PARTICIPANT	\N	PRESENT	0
370665	356304	11031D	PARTICIPANT	\N	PRESENT	0
370668	356304	14071N	PARTICIPANT	\N	PRESENT	0
370693	363527	04044E	PARTICIPANT	\N	PRESENT	0
370694	363527	11031D	PARTICIPANT	\N	PRESENT	0
370695	363527	19593H	PARTICIPANT	\N	PRESENT	0
370696	363527	19551W	PARTICIPANT	\N	PRESENT	0
370697	363527	05008E	PARTICIPANT	\N	PRESENT	0
370698	363527	14053L	PARTICIPANT	\N	PRESENT	0
370699	363527	19629C	PARTICIPANT	\N	PRESENT	0
370700	363527	04045F	PARTICIPANT	\N	PRESENT	0
370701	363527	14073Q	PARTICIPANT	\N	PRESENT	0
370702	363527	14215L	PARTICIPANT	\N	PRESENT	0
370703	363527	14079W	PARTICIPANT	\N	PRESENT	0
387527	377927	14026U	PARTICIPANT	\N	PRESENT	0
387528	377927	19443T	PARTICIPANT	\N	PRESENT	0
387529	377927	14135M	PARTICIPANT	\N	PRESENT	0
387530	377927	19253P	PARTICIPANT	\N	PRESENT	0
387531	377927	19631V	PARTICIPANT	\N	PRESENT	0
387536	377927	04043D	PARTICIPANT	\N	PRESENT	0
387541	377927	07004J	PARTICIPANT	\N	PRESENT	0
387542	377927	19727D	PARTICIPANT	\N	PRESENT	0
387543	377927	14331P	PARTICIPANT	\N	PRESENT	0
387544	377927	14217N	PARTICIPANT	\N	PRESENT	0
387545	377927	14357A	PARTICIPANT	\N	PRESENT	0
387546	377927	19667J	PARTICIPANT	\N	PRESENT	0
387547	377927	14327T	PARTICIPANT	\N	PRESENT	0
387548	377927	11067R	PARTICIPANT	\N	PRESENT	0
387549	377927	98050T	PARTICIPANT	\N	PRESENT	0
387550	377927	08010L	PARTICIPANT	\N	PRESENT	0
387557	377927	19301E	PARTICIPANT	\N	PRESENT	0
387558	377927	19629C	PARTICIPANT	\N	PRESENT	0
387559	377927	01024M	PARTICIPANT	\N	PRESENT	0
387564	377927	19657G	PARTICIPANT	\N	PRESENT	0
387565	377927	19691J	PARTICIPANT	\N	PRESENT	0
387567	377927	04088S	PARTICIPANT	\N	PRESENT	0
387578	377927	19503N	PARTICIPANT	\N	PRESENT	0
387579	377927	11012A	PARTICIPANT	\N	PRESENT	0
387580	377927	08015R	PARTICIPANT	\N	PRESENT	0
387581	377927	19663E	PARTICIPANT	\N	PRESENT	0
387582	377927	19467C	PARTICIPANT	\N	PRESENT	0
387585	377927	19687N	PARTICIPANT	\N	PRESENT	0
387586	377927	01058X	PARTICIPANT	\N	PRESENT	0
387587	377927	97011G	PARTICIPANT	\N	PRESENT	0
387588	377927	98024R	PARTICIPANT	\N	PRESENT	0
387589	377927	17779H	PARTICIPANT	\N	PRESENT	0
387590	377927	14215L	PARTICIPANT	\N	PRESENT	0
387593	377927	14179A	PARTICIPANT	\N	PRESENT	0
387594	377927	14219Q	PARTICIPANT	\N	PRESENT	0
387595	377927	07029T	PARTICIPANT	\N	PRESENT	0
387596	377927	08039A	PARTICIPANT	\N	PRESENT	0
387597	377927	11090Q	PARTICIPANT	\N	PRESENT	0
387598	377927	19295A	PARTICIPANT	\N	PRESENT	0
387639	377928	04092N	PARTICIPANT	\N	PRESENT	0
387640	377928	08052W	PARTICIPANT	\N	PRESENT	0
387641	377928	11067R	PARTICIPANT	\N	PRESENT	0
387642	377928	19727D	PARTICIPANT	\N	PRESENT	0
387643	377928	11031D	PARTICIPANT	\N	PRESENT	0
387644	377928	19760E	PARTICIPANT	\N	PRESENT	0
387645	377928	14239U	PARTICIPANT	\N	PRESENT	0
387646	377928	14073Q	PARTICIPANT	\N	PRESENT	0
387647	377928	14219Q	PARTICIPANT	\N	PRESENT	0
387648	377928	14251Q	PARTICIPANT	\N	PRESENT	0
387649	377928	14217N	PARTICIPANT	\N	PRESENT	0
387650	377928	19657G	PARTICIPANT	\N	PRESENT	0
387651	377928	19667J	PARTICIPANT	\N	PRESENT	0
387652	377928	19711U	PARTICIPANT	\N	PRESENT	0
387653	377928	11090Q	PARTICIPANT	\N	PRESENT	0
387654	377928	11045K	PARTICIPANT	\N	PRESENT	0
387655	377928	19575F	PARTICIPANT	\N	PRESENT	0
387656	377928	04043D	PARTICIPANT	\N	PRESENT	0
387657	377928	19631V	PARTICIPANT	\N	PRESENT	0
387658	377928	19295A	PARTICIPANT	\N	PRESENT	0
387659	377928	14215L	PARTICIPANT	\N	PRESENT	0
387660	377928	19629C	PARTICIPANT	\N	PRESENT	0
387661	377928	19553Y	PARTICIPANT	\N	PRESENT	0
387662	377928	19565D	PARTICIPANT	\N	PRESENT	0
387663	377928	14042U	PARTICIPANT	\N	PRESENT	0
387664	377928	14213J	PARTICIPANT	\N	PRESENT	0
387665	377928	07029T	PARTICIPANT	\N	PRESENT	0
387666	377928	19663E	PARTICIPANT	\N	PRESENT	0
387667	377928	19301E	PARTICIPANT	\N	PRESENT	0
387668	377928	14119M	PARTICIPANT	\N	PRESENT	0
387669	377928	19687N	PARTICIPANT	\N	PRESENT	0
387670	377928	19715Y	PARTICIPANT	\N	PRESENT	0
387671	377928	11012A	PARTICIPANT	\N	PRESENT	0
387672	377928	19697Q	PARTICIPANT	\N	PRESENT	0
387673	377928	14021P	PARTICIPANT	\N	PRESENT	0
387674	377928	14105F	PARTICIPANT	\N	PRESENT	0
387675	377928	08010L	PARTICIPANT	\N	PRESENT	0
387676	377928	08019V	PARTICIPANT	\N	PRESENT	0
387637	377928	04086Q	PARTICIPANT	\N	PRESENT	0
387638	377928	98024R	PARTICIPANT	\N	PRESENT	0
387525	377927	14042U	PARTICIPANT	\N	PRESENT	0
387526	377927	19569H	PARTICIPANT	\N	PRESENT	0
388135	387793	19577H	PARTICIPANT	\N	PRESENT	0
388136	387793	19413M	PARTICIPANT	\N	PRESENT	0
388137	387793	14065Q	PARTICIPANT	\N	PRESENT	0
388138	387793	92040Q	PARTICIPANT	\N	PRESENT	0
388139	387793	19689Q	PARTICIPANT	\N	PRESENT	0
388140	387793	14355X	PARTICIPANT	\N	PRESENT	0
388141	387793	11097X	PARTICIPANT	\N	PRESENT	0
388142	387793	10006L	PARTICIPANT	\N	PRESENT	0
388143	387793	19367Y	PARTICIPANT	\N	PRESENT	0
388144	387793	01028R	PARTICIPANT	\N	PRESENT	0
388145	387793	14097Y	PARTICIPANT	\N	PRESENT	0
388146	387793	17583W	PARTICIPANT	\N	PRESENT	0
388147	387793	08055A	PARTICIPANT	\N	PRESENT	0
388148	387793	19549D	PARTICIPANT	\N	PRESENT	0
388149	387793	14083S	PARTICIPANT	\N	PRESENT	0
388150	387793	11077T	PARTICIPANT	\N	PRESENT	0
388151	387793	04043D	PARTICIPANT	\N	PRESENT	0
388155	387793	19545Y	PARTICIPANT	\N	PRESENT	0
388153	387793	19621T	PARTICIPANT	\N	PRESENT	0
388154	387793	14251Q	PARTICIPANT	\N	PRESENT	0
388156	387793	19319Q	PARTICIPANT	\N	PRESENT	0
388160	387793	14087W	PARTICIPANT	\N	PRESENT	0
388158	387793	14249W	PARTICIPANT	\N	PRESENT	0
388159	387793	14071N	PARTICIPANT	\N	PRESENT	0
388161	387793	11065P	PARTICIPANT	\N	PRESENT	0
388162	387793	07004J	PARTICIPANT	\N	PRESENT	0
388163	387793	11056N	PARTICIPANT	\N	PRESENT	0
388164	387793	08060W	PARTICIPANT	\N	PRESENT	0
388165	387793	19551W	PARTICIPANT	\N	PRESENT	0
388166	387793	19581D	PARTICIPANT	\N	PRESENT	0
388167	387793	08011M	PARTICIPANT	\N	PRESENT	0
388168	387793	95062K	PARTICIPANT	\N	PRESENT	0
388187	387793	04071H	PARTICIPANT	\N	PRESENT	0
388188	387793	19643A	PARTICIPANT	\N	PRESENT	0
388189	377975	86034E	PARTICIPANT	\N	PRESENT	0
388190	377975	11045K	PARTICIPANT	\N	PRESENT	0
388191	377975	14151M	PARTICIPANT	\N	PRESENT	0
388192	377975	14281W	PARTICIPANT	\N	PRESENT	0
388193	377975	19333N	PARTICIPANT	\N	PRESENT	0
388194	377975	14159V	PARTICIPANT	\N	PRESENT	0
388195	377975	19760E	PARTICIPANT	\N	PRESENT	0
388196	377975	12041X	PARTICIPANT	\N	PRESENT	0
388197	377975	11031D	PARTICIPANT	\N	PRESENT	0
388198	377975	14063N	PARTICIPANT	\N	PRESENT	0
388199	377975	19525U	PARTICIPANT	\N	PRESENT	0
388200	377975	19782L	PARTICIPANT	\N	PRESENT	0
388201	377975	19637C	PARTICIPANT	\N	PRESENT	0
388202	377975	11066Q	PARTICIPANT	\N	PRESENT	0
388203	377975	14085U	PARTICIPANT	\N	PRESENT	0
388204	377975	19489J	PARTICIPANT	\N	PRESENT	0
388205	377975	11040E	PARTICIPANT	\N	PRESENT	0
388206	377975	08052W	PARTICIPANT	\N	PRESENT	0
388207	377975	19527W	PARTICIPANT	\N	PRESENT	0
388208	377975	08053X	PARTICIPANT	\N	PRESENT	0
388209	377975	04059M	PARTICIPANT	\N	PRESENT	0
388211	377975	19659J	PARTICIPANT	\N	PRESENT	0
388212	377975	11067R	PARTICIPANT	\N	PRESENT	0
388213	377975	04085P	PARTICIPANT	\N	PRESENT	0
388214	377975	19695N	PARTICIPANT	\N	PRESENT	0
388215	377975	19758L	PARTICIPANT	\N	PRESENT	0
388216	377975	14235Q	PARTICIPANT	\N	PRESENT	0
388217	377975	14051J	PARTICIPANT	\N	PRESENT	0
388218	377975	19503N	PARTICIPANT	\N	PRESENT	0
388219	377975	14021P	PARTICIPANT	\N	PRESENT	0
388221	377975	19347U	PARTICIPANT	\N	PRESENT	0
388222	377975	19565D	PARTICIPANT	\N	PRESENT	0
388223	377975	04038G	PARTICIPANT	\N	PRESENT	0
388224	377975	19669L	PARTICIPANT	\N	PRESENT	0
388226	377975	08014Q	PARTICIPANT	\N	PRESENT	0
388227	377975	11033F	PARTICIPANT	\N	PRESENT	0
388228	377975	14239U	PARTICIPANT	\N	PRESENT	0
388229	377975	19697Q	PARTICIPANT	\N	PRESENT	0
388230	377975	19725B	PARTICIPANT	\N	PRESENT	0
388231	377975	19651A	PARTICIPANT	\N	PRESENT	0
388232	377975	19649G	PARTICIPANT	\N	PRESENT	0
388233	377975	80013X	PARTICIPANT	\N	PRESENT	0
388234	377975	19349W	PARTICIPANT	\N	PRESENT	0
388235	377975	95063L	PARTICIPANT	\N	PRESENT	0
388236	377975	11012A	PARTICIPANT	\N	PRESENT	0
388237	377975	08031R	PARTICIPANT	\N	PRESENT	0
388238	377975	88008L	PARTICIPANT	\N	PRESENT	0
388239	377975	14261S	PARTICIPANT	\N	PRESENT	0
388240	377975	19629C	PARTICIPANT	\N	PRESENT	0
388241	377975	19253P	PARTICIPANT	\N	PRESENT	0
363732	345290	19575F	PARTICIPANT	\N	PRESENT	0
363733	345290	19663E	PARTICIPANT	\N	PRESENT	0
363734	345290	19693L	PARTICIPANT	\N	PRESENT	0
363735	345290	08010L	PARTICIPANT	\N	PRESENT	0
363736	345290	01057W	PARTICIPANT	\N	PRESENT	0
363737	345290	14133K	PARTICIPANT	\N	PRESENT	0
363738	345290	07029T	PARTICIPANT	\N	PRESENT	0
363739	345290	14135M	PARTICIPANT	\N	PRESENT	0
363740	345290	14187A	PARTICIPANT	\N	PRESENT	0
363741	345290	04008A	PARTICIPANT	\N	PRESENT	0
363742	345290	11040E	PARTICIPANT	\N	PRESENT	0
363743	345290	04085P	PARTICIPANT	\N	PRESENT	0
363744	345290	11031D	PARTICIPANT	\N	PRESENT	0
363745	345290	11033F	PARTICIPANT	\N	PRESENT	0
363746	345290	12041X	PARTICIPANT	\N	PRESENT	0
363747	345290	19758L	PARTICIPANT	\N	PRESENT	0
363748	345290	19695N	PARTICIPANT	\N	PRESENT	0
363749	345290	19593H	PARTICIPANT	\N	PRESENT	0
363750	345290	19347U	PARTICIPANT	\N	PRESENT	0
363751	345290	08061X	PARTICIPANT	\N	PRESENT	0
363753	345290	11043H	PARTICIPANT	\N	PRESENT	0
363754	345290	04034C	PARTICIPANT	\N	PRESENT	0
363755	345290	98029W	PARTICIPANT	\N	PRESENT	0
363756	345290	01048V	PARTICIPANT	\N	PRESENT	0
363757	345290	14239U	PARTICIPANT	\N	PRESENT	0
363758	345290	19697Q	PARTICIPANT	\N	PRESENT	0
363759	345290	19637C	PARTICIPANT	\N	PRESENT	0
363760	345290	11072N	PARTICIPANT	\N	PRESENT	0
363761	345290	19659J	PARTICIPANT	\N	PRESENT	0
363762	345290	19782L	PARTICIPANT	\N	PRESENT	0
363763	345290	11083R	PARTICIPANT	\N	PRESENT	0
363764	345290	92040Q	PARTICIPANT	\N	PRESENT	0
363765	345290	19585H	PARTICIPANT	\N	PRESENT	0
363766	345290	19545Y	PARTICIPANT	\N	PRESENT	0
363767	345290	11049P	PARTICIPANT	\N	PRESENT	0
363768	345290	14111D	PARTICIPANT	\N	PRESENT	0
363769	345290	17589D	PARTICIPANT	\N	PRESENT	0
363770	345290	14251Q	PARTICIPANT	\N	PRESENT	0
363771	345290	11064N	PARTICIPANT	\N	PRESENT	0
363772	345290	14115H	PARTICIPANT	\N	PRESENT	0
363773	345290	14034U	PARTICIPANT	\N	PRESENT	0
363774	345290	11012A	PARTICIPANT	\N	PRESENT	0
363775	345290	08031R	PARTICIPANT	\N	PRESENT	0
363776	345290	19629C	PARTICIPANT	\N	PRESENT	0
363777	345290	19253P	PARTICIPANT	\N	PRESENT	0
363778	345290	19387D	PARTICIPANT	\N	PRESENT	0
363779	345290	19719D	PARTICIPANT	\N	PRESENT	0
363780	345290	14107H	PARTICIPANT	\N	PRESENT	0
363781	345290	11065P	PARTICIPANT	\N	PRESENT	0
363782	345290	08019V	PARTICIPANT	\N	PRESENT	0
363783	345290	19553Y	PARTICIPANT	\N	PRESENT	0
363784	345290	08048B	PARTICIPANT	\N	PRESENT	0
363785	345290	04057K	PARTICIPANT	\N	PRESENT	0
363786	345290	14055N	PARTICIPANT	\N	PRESENT	0
363787	345290	14029X	PARTICIPANT	\N	PRESENT	0
363788	345290	11074Q	PARTICIPANT	\N	PRESENT	0
363789	345290	04088S	PARTICIPANT	\N	PRESENT	0
363790	345290	14051J	PARTICIPANT	\N	PRESENT	0
363791	345290	14229S	PARTICIPANT	\N	PRESENT	0
363792	345290	08055A	PARTICIPANT	\N	PRESENT	0
363793	345290	14021P	PARTICIPANT	\N	PRESENT	0
363794	345290	14225N	PARTICIPANT	\N	PRESENT	0
363795	345290	19599P	PARTICIPANT	\N	PRESENT	0
363796	345290	19647E	PARTICIPANT	\N	PRESENT	0
363797	345290	19649G	PARTICIPANT	\N	PRESENT	0
363798	345290	11045K	PARTICIPANT	\N	PRESENT	0
363799	345290	19591F	PARTICIPANT	\N	PRESENT	0
363800	345290	19727D	PARTICIPANT	\N	PRESENT	0
363801	345290	19489J	PARTICIPANT	\N	PRESENT	0
363802	345290	08058D	PARTICIPANT	\N	PRESENT	0
363803	345290	14227Q	PARTICIPANT	\N	PRESENT	0
363804	345290	19733B	PARTICIPANT	\N	PRESENT	0
363805	345290	14329V	PARTICIPANT	\N	PRESENT	0
363806	345290	19675J	PARTICIPANT	\N	PRESENT	0
363807	345290	14109K	PARTICIPANT	\N	PRESENT	0
363808	345290	14001X	PARTICIPANT	\N	PRESENT	0
363809	345290	19333N	PARTICIPANT	\N	PRESENT	0
363810	345290	97011G	PARTICIPANT	\N	PRESENT	0
363811	345290	19531S	PARTICIPANT	\N	PRESENT	0
363812	345290	08053X	PARTICIPANT	\N	PRESENT	0
363813	345290	11103C	PARTICIPANT	\N	PRESENT	0
363814	345290	14257W	PARTICIPANT	\N	PRESENT	0
363815	345290	19551W	PARTICIPANT	\N	PRESENT	0
363816	345290	14079W	PARTICIPANT	\N	PRESENT	0
363817	345290	19687N	PARTICIPANT	\N	PRESENT	0
363818	345290	19689Q	PARTICIPANT	\N	PRESENT	0
363819	345290	14065Q	PARTICIPANT	\N	PRESENT	0
363820	345290	14281W	PARTICIPANT	\N	PRESENT	0
363821	345290	01062T	PARTICIPANT	\N	PRESENT	0
363822	345290	08017T	PARTICIPANT	\N	PRESENT	0
363823	345290	19651A	PARTICIPANT	\N	PRESENT	0
363824	345290	04043D	PARTICIPANT	\N	PRESENT	0
363825	345290	14249W	PARTICIPANT	\N	PRESENT	0
363826	345290	11041F	PARTICIPANT	\N	PRESENT	0
363827	345290	08039A	PARTICIPANT	\N	PRESENT	0
363828	345290	19289C	PARTICIPANT	\N	PRESENT	0
363829	345290	08034U	PARTICIPANT	\N	PRESENT	0
363830	345290	04089T	PARTICIPANT	\N	PRESENT	0
363831	345290	14231L	PARTICIPANT	\N	PRESENT	0
363832	345290	08044W	PARTICIPANT	\N	PRESENT	0
363833	345290	19369B	PARTICIPANT	\N	PRESENT	0
363834	345290	19399H	PARTICIPANT	\N	PRESENT	0
363835	345290	19691J	PARTICIPANT	\N	PRESENT	0
363836	345290	14255U	PARTICIPANT	\N	PRESENT	0
363837	345290	19611R	PARTICIPANT	\N	PRESENT	0
363838	345290	19441R	PARTICIPANT	\N	PRESENT	0
363839	345290	19721W	PARTICIPANT	\N	PRESENT	0
363840	345290	05008E	PARTICIPANT	\N	PRESENT	0
363841	345290	08056B	PARTICIPANT	\N	PRESENT	0
363842	345290	16685X	PARTICIPANT	\N	PRESENT	0
363917	345290	95067Q	PARTICIPANT	\N	PRESENT	0
363844	345290	19479G	PARTICIPANT	\N	PRESENT	0
363845	345290	14219Q	PARTICIPANT	\N	PRESENT	0
363846	345290	14042U	PARTICIPANT	\N	PRESENT	0
363847	345290	19713W	PARTICIPANT	\N	PRESENT	0
363848	345290	12016W	PARTICIPANT	\N	PRESENT	0
363849	345290	14267Y	PARTICIPANT	\N	PRESENT	0
363850	345290	19527W	PARTICIPANT	\N	PRESENT	0
363851	345290	14103D	PARTICIPANT	\N	PRESENT	0
363852	345290	04086Q	PARTICIPANT	\N	PRESENT	0
363853	345290	19739H	PARTICIPANT	\N	PRESENT	0
363854	345290	19335Q	PARTICIPANT	\N	PRESENT	0
363855	345290	89017R	PARTICIPANT	\N	PRESENT	0
363856	345290	19683J	PARTICIPANT	\N	PRESENT	0
363857	345290	04042C	PARTICIPANT	\N	PRESENT	0
363858	345290	14073Q	PARTICIPANT	\N	PRESENT	0
363859	345290	14089Y	PARTICIPANT	\N	PRESENT	0
363861	345290	14275Y	PARTICIPANT	\N	PRESENT	0
363862	345290	19749K	PARTICIPANT	\N	PRESENT	0
363863	345290	19521Q	PARTICIPANT	\N	PRESENT	0
363865	345290	07004J	PARTICIPANT	\N	PRESENT	0
363866	345290	14083S	PARTICIPANT	\N	PRESENT	0
363867	345290	11085T	PARTICIPANT	\N	PRESENT	0
363869	345290	19577H	PARTICIPANT	\N	PRESENT	0
363870	345290	04040A	PARTICIPANT	\N	PRESENT	0
363871	345290	11090Q	PARTICIPANT	\N	PRESENT	0
363873	345290	01025N	PARTICIPANT	\N	PRESENT	0
363874	345290	01024M	PARTICIPANT	\N	PRESENT	0
363875	345290	14327T	PARTICIPANT	\N	PRESENT	0
363877	345290	14093U	PARTICIPANT	\N	PRESENT	0
363878	345290	14205J	PARTICIPANT	\N	PRESENT	0
363881	345290	11077T	PARTICIPANT	\N	PRESENT	0
363882	345290	01060R	PARTICIPANT	\N	PRESENT	0
363885	345290	19503N	PARTICIPANT	\N	PRESENT	0
363887	345290	19413M	PARTICIPANT	\N	PRESENT	0
363889	345290	19669L	PARTICIPANT	\N	PRESENT	0
363890	345290	11054L	PARTICIPANT	\N	PRESENT	0
363892	345290	19573D	PARTICIPANT	\N	PRESENT	0
363893	345290	19349W	PARTICIPANT	\N	PRESENT	0
363894	345290	19269X	PARTICIPANT	\N	PRESENT	0
363895	345290	19543W	PARTICIPANT	\N	PRESENT	0
363896	345290	19447X	PARTICIPANT	\N	PRESENT	0
363897	345290	19699S	PARTICIPANT	\N	PRESENT	0
363898	345290	19745F	PARTICIPANT	\N	PRESENT	0
363899	345290	19565D	PARTICIPANT	\N	PRESENT	0
363900	345290	95063L	PARTICIPANT	\N	PRESENT	0
363901	345290	04061F	PARTICIPANT	\N	PRESENT	0
363902	345290	11027H	PARTICIPANT	\N	PRESENT	0
363903	345290	11053K	PARTICIPANT	\N	PRESENT	0
363904	345290	04044E	PARTICIPANT	\N	PRESENT	0
363905	345290	19301E	PARTICIPANT	\N	PRESENT	0
363906	345290	11026G	PARTICIPANT	\N	PRESENT	0
363907	345290	14069U	PARTICIPANT	\N	PRESENT	0
363916	345290	04049K	PARTICIPANT	\N	PRESENT	0
363919	345290	01043Q	PARTICIPANT	\N	PRESENT	0
363923	345290	08009T	PARTICIPANT	\N	PRESENT	0
363944	345290	14261S	PARTICIPANT	\N	PRESENT	0
376804	373760	08053X	PARTICIPANT	\N	EXCUSE	0
376805	373760	19693L	PARTICIPANT	\N	EXCUSE	0
378849	373666	19629C	PARTICIPANT	\N	PRESENT	0
378850	373666	19467C	PARTICIPANT	\N	PRESENT	0
378851	373666	08045X	PARTICIPANT	\N	PRESENT	0
378852	373666	19711U	PARTICIPANT	\N	PRESENT	0
378853	373666	08062Y	PARTICIPANT	\N	PRESENT	0
378854	373666	11097X	PARTICIPANT	\N	PRESENT	0
378855	373666	19713W	PARTICIPANT	\N	PRESENT	0
379087	371479	11080N	PARTICIPANT	\N	PRESENT	0
379088	371479	15447F	PARTICIPANT	\N	PRESENT	0
379089	371479	19768N	PARTICIPANT	\N	PRESENT	0
379090	371479	04044E	PARTICIPANT	\N	PRESENT	0
379091	371479	17583W	PARTICIPANT	\N	PRESENT	0
379092	371479	08019V	PARTICIPANT	\N	PRESENT	0
379093	371479	14211G	PARTICIPANT	\N	PRESENT	0
379094	371479	19673G	PARTICIPANT	\N	PRESENT	0
379095	371479	12041X	PARTICIPANT	\N	PRESENT	0
379096	371479	01058X	PARTICIPANT	\N	PRESENT	0
379097	371479	11056N	PARTICIPANT	\N	PRESENT	0
379083	371479	08069G	PARTICIPANT	\N	PRESENT	0
379086	371479	19667J	PARTICIPANT	\N	PRESENT	0
379098	371479	14235Q	PARTICIPANT	\N	PRESENT	0
379100	371479	08011M	PARTICIPANT	\N	PRESENT	0
379101	371479	11040E	PARTICIPANT	\N	PRESENT	0
379102	371479	04085P	PARTICIPANT	\N	PRESENT	0
379104	371479	19758L	PARTICIPANT	\N	PRESENT	0
379105	371479	11033F	PARTICIPANT	\N	PRESENT	0
379106	371479	19687N	PARTICIPANT	\N	PRESENT	0
379109	371479	08061X	PARTICIPANT	\N	PRESENT	0
379110	371479	95037J	PARTICIPANT	\N	PRESENT	0
379111	371479	04034C	PARTICIPANT	\N	PRESENT	0
379112	371479	04045F	PARTICIPANT	\N	PRESENT	0
379113	371479	98029W	PARTICIPANT	\N	PRESENT	0
379114	371479	95067Q	PARTICIPANT	\N	PRESENT	0
379115	371479	19349W	PARTICIPANT	\N	PRESENT	0
379117	371479	19651A	PARTICIPANT	\N	PRESENT	0
379118	371479	14239U	PARTICIPANT	\N	PRESENT	0
379119	371479	11083R	PARTICIPANT	\N	PRESENT	0
379120	371479	19543W	PARTICIPANT	\N	PRESENT	0
379121	371479	19697Q	PARTICIPANT	\N	PRESENT	0
379122	371479	14253S	PARTICIPANT	\N	PRESENT	0
379123	371479	08073C	PARTICIPANT	\N	PRESENT	0
379124	371479	14199E	PARTICIPANT	\N	PRESENT	0
379125	371479	14039A	PARTICIPANT	\N	PRESENT	0
379126	371479	19301E	PARTICIPANT	\N	PRESENT	0
379127	371479	08024S	PARTICIPANT	\N	PRESENT	0
379128	371479	11072N	PARTICIPANT	\N	PRESENT	0
379129	371479	19269X	PARTICIPANT	\N	PRESENT	0
379130	371479	01057W	PARTICIPANT	\N	PRESENT	0
379131	371479	19329S	PARTICIPANT	\N	PRESENT	0
379132	371479	19563B	PARTICIPANT	\N	PRESENT	0
379133	371479	19585H	PARTICIPANT	\N	PRESENT	0
379134	371479	14119M	PARTICIPANT	\N	PRESENT	0
379135	371479	14111D	PARTICIPANT	\N	PRESENT	0
379136	371479	14031R	PARTICIPANT	\N	PRESENT	0
379137	371479	17589D	PARTICIPANT	\N	PRESENT	0
379138	371479	14251Q	PARTICIPANT	\N	PRESENT	0
379139	371479	14115H	PARTICIPANT	\N	PRESENT	0
379140	371479	11064N	PARTICIPANT	\N	PRESENT	0
379141	371479	19583F	PARTICIPANT	\N	PRESENT	0
379142	371479	98005N	PARTICIPANT	\N	PRESENT	0
379143	371479	08018U	PARTICIPANT	\N	PRESENT	0
379144	371479	11109J	PARTICIPANT	\N	PRESENT	0
379145	371479	08048B	PARTICIPANT	\N	PRESENT	0
379146	371479	08038Y	PARTICIPANT	\N	PRESENT	0
379147	371479	14051J	PARTICIPANT	\N	PRESENT	0
379148	371479	04059M	PARTICIPANT	\N	PRESENT	0
379149	371479	98035U	PARTICIPANT	\N	PRESENT	0
379150	371479	01028R	PARTICIPANT	\N	PRESENT	0
379151	371479	11012A	PARTICIPANT	\N	PRESENT	0
379152	371479	88008L	PARTICIPANT	\N	PRESENT	0
379153	371479	19629C	PARTICIPANT	\N	PRESENT	0
379154	371479	19253P	PARTICIPANT	\N	PRESENT	0
379155	371479	14033T	PARTICIPANT	\N	PRESENT	0
379156	371479	14107H	PARTICIPANT	\N	PRESENT	0
379157	371479	19415P	PARTICIPANT	\N	PRESENT	0
379158	371479	14201E	PARTICIPANT	\N	PRESENT	0
379159	371479	98022P	PARTICIPANT	\N	PRESENT	0
379160	371479	14241N	PARTICIPANT	\N	PRESENT	0
379161	371479	19467C	PARTICIPANT	\N	PRESENT	0
379162	371479	14207L	PARTICIPANT	\N	PRESENT	0
379163	371479	11099A	PARTICIPANT	\N	PRESENT	0
379164	371479	11065P	PARTICIPANT	\N	PRESENT	0
379165	371479	14029X	PARTICIPANT	\N	PRESENT	0
379166	371479	19663E	PARTICIPANT	\N	PRESENT	0
379167	371479	08021P	PARTICIPANT	\N	PRESENT	0
379168	371479	19387D	PARTICIPANT	\N	PRESENT	0
379169	371479	14038Y	PARTICIPANT	\N	PRESENT	0
379170	371479	19289C	PARTICIPANT	\N	PRESENT	0
379171	371479	19553Y	PARTICIPANT	\N	PRESENT	0
379172	371479	14055N	PARTICIPANT	\N	PRESENT	0
379173	371479	01060R	PARTICIPANT	\N	PRESENT	0
379174	371479	89017R	PARTICIPANT	\N	PRESENT	0
379175	371479	19731Y	PARTICIPANT	\N	PRESENT	0
379176	371479	04061F	PARTICIPANT	\N	PRESENT	0
379177	371479	07029T	PARTICIPANT	\N	PRESENT	0
379178	371479	19489J	PARTICIPANT	\N	PRESENT	0
379179	371479	19657G	PARTICIPANT	\N	PRESENT	0
379180	371479	14061L	PARTICIPANT	\N	PRESENT	0
379181	371479	14159V	PARTICIPANT	\N	PRESENT	0
379182	371479	14355X	PARTICIPANT	\N	PRESENT	0
379183	371479	11074Q	PARTICIPANT	\N	PRESENT	0
379184	371479	08062Y	PARTICIPANT	\N	PRESENT	0
379185	371479	19689Q	PARTICIPANT	\N	PRESENT	0
379186	371479	19705W	PARTICIPANT	\N	PRESENT	0
379187	371479	08052W	PARTICIPANT	\N	PRESENT	0
379188	371479	14229S	PARTICIPANT	\N	PRESENT	0
379189	371479	08055A	PARTICIPANT	\N	PRESENT	0
379190	371479	14265W	PARTICIPANT	\N	PRESENT	0
379191	371479	14021P	PARTICIPANT	\N	PRESENT	0
379192	371479	98050T	PARTICIPANT	\N	PRESENT	0
379193	371479	08045X	PARTICIPANT	\N	PRESENT	0
379194	371479	14225N	PARTICIPANT	\N	PRESENT	0
379195	371479	19599P	PARTICIPANT	\N	PRESENT	0
379196	371479	14121F	PARTICIPANT	\N	PRESENT	0
379197	371479	14059S	PARTICIPANT	\N	PRESENT	0
379198	371479	19715Y	PARTICIPANT	\N	PRESENT	0
379199	371479	19647E	PARTICIPANT	\N	PRESENT	0
379200	371479	19367Y	PARTICIPANT	\N	PRESENT	0
379201	371479	19649G	PARTICIPANT	\N	PRESENT	0
379202	371479	05008E	PARTICIPANT	\N	PRESENT	0
379203	371479	11045K	PARTICIPANT	\N	PRESENT	0
379204	371479	19621T	PARTICIPANT	\N	PRESENT	0
379205	371479	04018C	PARTICIPANT	\N	PRESENT	0
379206	371479	08012N	PARTICIPANT	\N	PRESENT	0
379207	371479	19727D	PARTICIPANT	\N	PRESENT	0
379208	371479	14085U	PARTICIPANT	\N	PRESENT	0
379209	371479	19631V	PARTICIPANT	\N	PRESENT	0
379210	371479	08058D	PARTICIPANT	\N	PRESENT	0
379211	371479	11054L	PARTICIPANT	\N	PRESENT	0
379212	371479	19251M	PARTICIPANT	\N	PRESENT	0
379213	371479	14217N	PARTICIPANT	\N	PRESENT	0
379214	371479	11104D	PARTICIPANT	\N	PRESENT	0
379215	371479	19683J	PARTICIPANT	\N	PRESENT	0
379216	371479	14227Q	PARTICIPANT	\N	PRESENT	0
379217	371479	19591F	PARTICIPANT	\N	PRESENT	0
379218	371479	19503N	PARTICIPANT	\N	PRESENT	0
379219	371479	11067R	PARTICIPANT	\N	PRESENT	0
379231	371479	11110B	PARTICIPANT	\N	PRESENT	0
379221	371479	19295A	PARTICIPANT	\N	PRESENT	0
379222	371479	14193X	PARTICIPANT	\N	PRESENT	0
379223	371479	14063N	PARTICIPANT	\N	PRESENT	0
379224	371479	14109K	PARTICIPANT	\N	PRESENT	0
379225	371479	08047A	PARTICIPANT	\N	PRESENT	0
379226	371479	14097Y	PARTICIPANT	\N	PRESENT	0
379227	371479	14001X	PARTICIPANT	\N	PRESENT	0
379228	371479	19333N	PARTICIPANT	\N	PRESENT	0
379229	371479	19549D	PARTICIPANT	\N	PRESENT	0
379230	371479	11041F	PARTICIPANT	\N	PRESENT	0
379232	371479	14257W	PARTICIPANT	\N	PRESENT	0
379233	371479	10006L	PARTICIPANT	\N	PRESENT	0
379235	371479	14197C	PARTICIPANT	\N	PRESENT	0
379236	371479	08053X	PARTICIPANT	\N	PRESENT	0
379237	371479	08034U	PARTICIPANT	\N	PRESENT	0
379238	371479	08017T	PARTICIPANT	\N	PRESENT	0
379239	371479	05012A	PARTICIPANT	\N	PRESENT	0
379240	371479	14281W	PARTICIPANT	\N	PRESENT	0
379241	371479	80013X	PARTICIPANT	\N	PRESENT	0
379242	371479	01062T	PARTICIPANT	\N	PRESENT	0
379243	371479	04047H	PARTICIPANT	\N	PRESENT	0
379244	371479	19695N	PARTICIPANT	\N	PRESENT	0
379245	371479	19347U	PARTICIPANT	\N	PRESENT	0
379246	371479	14069U	PARTICIPANT	\N	PRESENT	0
379247	371479	14093U	PARTICIPANT	\N	PRESENT	0
379248	371479	19533U	PARTICIPANT	\N	PRESENT	0
379249	371479	08031R	PARTICIPANT	\N	PRESENT	0
379250	371479	14087W	PARTICIPANT	\N	PRESENT	0
364569	361770	19295A	PARTICIPANT	\N	EXCUSE	0
364570	361770	96004D	PARTICIPANT	\N	EXCUSE	0
364571	361770	14225N	PARTICIPANT	\N	EXCUSE	0
365991	365989	14265W	PARTICIPANT	\N	PRESENT	0
365992	365989	14197C	PARTICIPANT	\N	PRESENT	0
365993	365989	14107H	PARTICIPANT	\N	PRESENT	0
365995	365989	14207L	PARTICIPANT	\N	PRESENT	0
365998	365989	04088S	PARTICIPANT	\N	PRESENT	0
366000	365989	19575F	PARTICIPANT	\N	PRESENT	0
366002	365989	19747H	PARTICIPANT	\N	PRESENT	0
366003	365989	19369B	PARTICIPANT	\N	PRESENT	0
366388	364282	14327T	PARTICIPANT	\N	PRESENT	0
366389	364282	14331P	PARTICIPANT	\N	PRESENT	0
366390	364282	01048V	PARTICIPANT	\N	PRESENT	0
366391	364282	19545Y	PARTICIPANT	\N	PRESENT	0
366392	364282	11053K	PARTICIPANT	\N	PRESENT	0
366393	364282	89017R	PARTICIPANT	\N	PRESENT	0
366394	364282	19671E	PARTICIPANT	\N	PRESENT	0
366395	364282	88008L	PARTICIPANT	\N	PRESENT	0
366396	364282	07029T	PARTICIPANT	\N	PRESENT	0
366397	364282	14277B	PARTICIPANT	\N	PRESENT	0
366398	364282	14085U	PARTICIPANT	\N	PRESENT	0
366399	364282	07004J	PARTICIPANT	\N	PRESENT	0
366400	364282	08010L	PARTICIPANT	\N	PRESENT	0
366401	364282	14253S	PARTICIPANT	\N	PRESENT	0
366402	364282	11048N	PARTICIPANT	\N	PRESENT	0
366403	364282	19479G	PARTICIPANT	\N	PRESENT	0
366404	364282	08034U	PARTICIPANT	\N	PRESENT	0
366405	364282	08069G	PARTICIPANT	\N	PRESENT	0
366406	364282	12016W	PARTICIPANT	\N	PRESENT	0
366407	364282	08011M	PARTICIPANT	\N	PRESENT	0
366408	364282	14173T	PARTICIPANT	\N	PRESENT	0
366409	364282	04086Q	PARTICIPANT	\N	PRESENT	0
366410	364282	11040E	PARTICIPANT	\N	PRESENT	0
366411	364282	14083S	PARTICIPANT	\N	PRESENT	0
366412	364282	14199E	PARTICIPANT	\N	PRESENT	0
366413	364282	19741B	PARTICIPANT	\N	PRESENT	0
366414	364282	14121F	PARTICIPANT	\N	PRESENT	0
366415	364282	01057W	PARTICIPANT	\N	PRESENT	0
366562	356170	19727D	PARTICIPANT	\N	PRESENT	0
366563	356171	19727D	PARTICIPANT	\N	PRESENT	0
366564	356197	19727D	PARTICIPANT	\N	PRESENT	0
366565	356172	19727D	PARTICIPANT	\N	PRESENT	0
367471	367470	96004D	PARTICIPANT	\N	PRESENT	0
368960	367313	11074Q	PARTICIPANT	\N	PRESENT	0
368961	367313	88008L	PARTICIPANT	\N	PRESENT	0
368962	367313	19745F	PARTICIPANT	\N	PRESENT	0
368963	367313	11049P	PARTICIPANT	\N	PRESENT	0
370706	363527	07029T	PARTICIPANT	\N	PRESENT	0
370707	363527	19663E	PARTICIPANT	\N	PRESENT	0
370708	363527	10015M	PARTICIPANT	\N	PRESENT	0
370709	363527	19335Q	PARTICIPANT	\N	PRESENT	0
370710	363527	08019V	PARTICIPANT	\N	PRESENT	0
370711	363527	07004J	PARTICIPANT	\N	PRESENT	0
370712	363527	04040A	PARTICIPANT	\N	PRESENT	0
370704	363527	14061L	PARTICIPANT	\N	PRESENT	0
370705	363527	11049P	PARTICIPANT	\N	PRESENT	0
370713	363527	14065Q	PARTICIPANT	\N	PRESENT	0
370714	363527	18083K	PARTICIPANT	\N	PRESENT	0
370715	363527	08069G	PARTICIPANT	\N	PRESENT	0
370716	363527	14231L	PARTICIPANT	\N	PRESENT	0
370724	370723	19782L	PARTICIPANT	\N	PRESENT	0
370725	370723	19681G	PARTICIPANT	\N	PRESENT	0
370726	370723	01043Q	PARTICIPANT	\N	PRESENT	0
370727	370723	19563B	PARTICIPANT	\N	PRESENT	0
370728	370723	19503N	PARTICIPANT	\N	PRESENT	0
370729	370723	19585H	PARTICIPANT	\N	PRESENT	0
370730	370723	19575F	PARTICIPANT	\N	EXCUSE	0
370731	370723	08068F	PARTICIPANT	\N	EXCUSE	0
370732	370723	11101A	PARTICIPANT	\N	EXCUSE	0
370733	370723	04049K	PARTICIPANT	\N	EXCUSE	0
370734	370723	01048V	PARTICIPANT	\N	EXCUSE	0
370735	370723	19637C	PARTICIPANT	\N	EXCUSE	0
370736	370723	14265W	PARTICIPANT	\N	EXCUSE	0
370737	370723	14237S	PARTICIPANT	\N	EXCUSE	0
370738	370723	95067Q	PARTICIPANT	\N	EXCUSE	0
370740	370739	11074Q	PARTICIPANT	\N	PRESENT	0
370770	370769	08019V	PARTICIPANT	\N	PRESENT	0
370771	370769	14261S	PARTICIPANT	\N	PRESENT	0
370772	370769	19717B	PARTICIPANT	\N	PRESENT	0
370773	370769	19691J	PARTICIPANT	\N	PRESENT	0
370774	370769	19659J	PARTICIPANT	\N	PRESENT	0
370775	370769	14039A	PARTICIPANT	\N	PRESENT	0
370776	370769	14059S	PARTICIPANT	\N	PRESENT	0
370777	370769	98005N	PARTICIPANT	\N	PRESENT	0
370802	370801	08010L	PARTICIPANT	\N	PRESENT	0
370803	370801	04045F	PARTICIPANT	\N	PRESENT	0
370805	370804	04045F	PARTICIPANT	\N	PRESENT	0
370811	370807	04045F	PARTICIPANT	\N	PRESENT	0
370812	370810	04045F	PARTICIPANT	\N	PRESENT	0
370814	370813	08010L	PARTICIPANT	\N	PRESENT	0
370817	370816	08010L	PARTICIPANT	\N	PRESENT	0
370909	370835	11109J	PARTICIPANT	\N	PRESENT	0
370910	370835	14261S	PARTICIPANT	\N	PRESENT	0
370911	370835	14038Y	PARTICIPANT	\N	PRESENT	0
370912	370835	19659J	PARTICIPANT	\N	PRESENT	0
370913	370835	19691J	PARTICIPANT	\N	PRESENT	0
370914	370835	98005N	PARTICIPANT	\N	PRESENT	0
370915	370835	12016W	PARTICIPANT	\N	PRESENT	0
370916	370835	08019V	PRESIDENT	0	PRESENT	0
370917	370835	11072N	PARTICIPANT	\N	PRESENT	0
370918	370835	14059S	PARTICIPANT	\N	EXCUSE	0
370919	370835	19657G	PARTICIPANT	\N	EXCUSE	0
370920	370835	14275Y	PARTICIPANT	\N	EXCUSE	0
370922	370835	14199E	PARTICIPANT	\N	EXCUSE	0
370930	370835	19715Y	PARTICIPANT	\N	PRESENT	0
370931	370835	19729F	PARTICIPANT	\N	EXCUSE	0
372821	344822	14030Q	PRESIDENT	0	PRESENT	0
372822	344822	19643A	PARTICIPANT	\N	PRESENT	0
372823	344822	14109K	PARTICIPANT	\N	PRESENT	0
372824	344822	14235Q	PARTICIPANT	\N	PRESENT	0
372826	344822	19679N	PARTICIPANT	\N	PRESENT	0
372827	344822	08024S	PARTICIPANT	\N	EXCUSE	0
372828	344822	19701S	PARTICIPANT	\N	EXCUSE	0
372829	344822	19693L	PARTICIPANT	\N	EXCUSE	0
372830	344822	14179A	PARTICIPANT	\N	EXCUSE	0
372831	344822	08031R	PARTICIPANT	\N	EXCUSE	0
372832	344822	01043Q	PARTICIPANT	\N	EXCUSE	0
372833	344822	14231L	PARTICIPANT	\N	PRESENT	0
372834	344822	14063N	PARTICIPANT	\N	PRESENT	0
373474	356317	19699S	PARTICIPANT	\N	PRESENT	0
373856	373687	19647E	PARTICIPANT	\N	PRESENT	0
373857	373687	19741B	PARTICIPANT	\N	PRESENT	0
373858	373687	14225N	PARTICIPANT	\N	PRESENT	0
373859	363530	14034U	PARTICIPANT	\N	PRESENT	0
373860	363530	14225N	PARTICIPANT	\N	PRESENT	0
373861	363530	19711U	PARTICIPANT	\N	PRESENT	0
373862	363530	04086Q	PARTICIPANT	\N	PRESENT	0
373863	363530	19693L	PARTICIPANT	\N	PRESENT	0
373864	363530	19479G	PARTICIPANT	\N	PRESENT	0
373865	363530	19593H	PARTICIPANT	\N	PRESENT	0
373866	363530	08011M	PARTICIPANT	\N	PRESENT	0
373867	363530	07029T	PARTICIPANT	\N	PRESENT	0
373868	363530	19575F	PARTICIPANT	\N	PRESENT	0
373869	363530	11053K	PARTICIPANT	\N	PRESENT	0
373870	363530	19631V	PARTICIPANT	\N	PRESENT	0
373871	363530	14085U	PARTICIPANT	\N	PRESENT	0
373872	363530	11040E	PARTICIPANT	\N	PRESENT	0
373873	363530	11074Q	PARTICIPANT	\N	PRESENT	0
373874	363530	11064N	PARTICIPANT	\N	PRESENT	0
373875	363530	19349W	PARTICIPANT	\N	PRESENT	0
373876	363530	19671E	PARTICIPANT	\N	PRESENT	0
373877	363530	19667J	PARTICIPANT	\N	PRESENT	0
373878	363530	11103C	PARTICIPANT	\N	PRESENT	0
373879	363530	19741B	PARTICIPANT	\N	PRESENT	0
373880	363530	99004R	PARTICIPANT	\N	PRESENT	0
373881	363530	11097X	PARTICIPANT	\N	PRESENT	0
373882	363530	01057W	PARTICIPANT	\N	PRESENT	0
373883	363530	19611R	PARTICIPANT	\N	PRESENT	0
373884	363530	14327T	PARTICIPANT	\N	PRESENT	0
373885	363530	11012A	PARTICIPANT	\N	PRESENT	0
373886	363530	14083S	PARTICIPANT	\N	PRESENT	0
373887	363530	11031D	PARTICIPANT	\N	PRESENT	0
373888	363530	19629C	PARTICIPANT	\N	PRESENT	0
373889	363530	14159V	PARTICIPANT	\N	PRESENT	0
373890	363530	19647E	PARTICIPANT	\N	PRESENT	0
373891	363530	14038Y	PARTICIPANT	\N	PRESENT	0
373893	363530	14157T	PARTICIPANT	\N	PRESENT	0
373898	363530	08038Y	PARTICIPANT	\N	PRESENT	0
376703	376702	08053X	PARTICIPANT	\N	PRESENT	0
376704	376702	14079W	PARTICIPANT	\N	PRESENT	0
376705	376702	08012N	PARTICIPANT	\N	PRESENT	0
376706	376702	19794Q	PARTICIPANT	\N	PRESENT	0
376710	376709	04047H	PARTICIPANT	\N	PRESENT	0
376711	376709	11072N	PARTICIPANT	\N	PRESENT	0
376713	376712	04047H	PARTICIPANT	\N	PRESENT	0
376738	373666	14147R	PARTICIPANT	\N	EXCUSE	0
375461	375459	04070G	PRESIDENT	0	PRESENT	0
375462	375459	19699S	PARTICIPANT	\N	PRESENT	0
375463	375459	19533U	PARTICIPANT	\N	PRESENT	0
375464	375459	14229S	PARTICIPANT	\N	PRESENT	0
375465	375459	14241N	PARTICIPANT	\N	PRESENT	0
375466	375459	14039A	PARTICIPANT	\N	PRESENT	0
375467	375459	08017T	PARTICIPANT	\N	PRESENT	0
375468	375459	92040Q	PARTICIPANT	\N	PRESENT	0
375469	375459	19335Q	PARTICIPANT	\N	PRESENT	0
375470	375459	08039A	PARTICIPANT	\N	PRESENT	0
375471	375459	08031R	PARTICIPANT	\N	PRESENT	0
375472	375459	14059S	PARTICIPANT	\N	PRESENT	0
375473	375459	14061L	PARTICIPANT	\N	PRESENT	0
375474	375459	04057K	PARTICIPANT	\N	PRESENT	0
375475	375459	14073Q	PARTICIPANT	\N	PRESENT	0
375476	375459	19611R	PARTICIPANT	\N	PRESENT	0
375477	375459	08043V	PARTICIPANT	\N	PRESENT	0
375478	375459	19693L	PARTICIPANT	\N	PRESENT	0
375479	375459	14030Q	PARTICIPANT	\N	PRESENT	0
375480	375459	14251Q	PARTICIPANT	\N	PRESENT	0
375481	375459	04059M	PARTICIPANT	\N	PRESENT	0
375482	375459	11109J	PARTICIPANT	\N	PRESENT	0
375483	375459	11083R	PARTICIPANT	\N	PRESENT	0
375484	375459	19749K	PARTICIPANT	\N	PRESENT	0
375485	375459	04018C	PARTICIPANT	\N	PRESENT	0
375486	375459	19758L	PARTICIPANT	\N	PRESENT	0
375487	375459	19766L	PARTICIPANT	\N	EXCUSE	0
375488	375459	19399H	PARTICIPANT	\N	EXCUSE	0
375502	375459	14249W	PARTICIPANT	\N	PRESENT	0
375503	375459	19735D	PARTICIPANT	\N	PRESENT	0
375561	375049	19533U	PARTICIPANT	\N	PRESENT	0
375565	371423	14265W	PARTICIPANT	\N	PRESENT	0
375570	371423	14105F	PARTICIPANT	\N	PRESENT	0
375571	371423	14033T	PARTICIPANT	\N	PRESENT	0
375682	375458	19782L	PARTICIPANT	\N	PRESENT	0
375573	371423	19731Y	PARTICIPANT	\N	PRESENT	0
375574	371423	19762G	PARTICIPANT	\N	PRESENT	0
375575	375545	10015M	PARTICIPANT	\N	PRESENT	0
375576	375545	14001X	PARTICIPANT	\N	PRESENT	0
375577	375545	01024M	PARTICIPANT	\N	PRESENT	0
375578	375545	19673G	PARTICIPANT	\N	PRESENT	0
375579	375545	19675J	PARTICIPANT	\N	PRESENT	0
375580	375545	01028R	PARTICIPANT	\N	PRESENT	0
375581	375545	11033F	PARTICIPANT	\N	PRESENT	0
375582	375545	19447X	PARTICIPANT	\N	PRESENT	0
375583	375545	05008E	PRESIDENT	0	PRESENT	0
375584	375545	14089Y	PARTICIPANT	\N	PRESENT	0
375585	375545	19725B	PARTICIPANT	\N	PRESENT	0
375586	375545	19489J	PARTICIPANT	\N	PRESENT	0
375587	375545	95063L	PARTICIPANT	\N	PRESENT	0
375588	375545	14041T	PARTICIPANT	\N	PRESENT	0
375589	375545	14179A	PARTICIPANT	\N	PRESENT	0
375590	375545	14069U	PARTICIPANT	\N	PRESENT	0
375591	375545	14151M	PARTICIPANT	\N	PRESENT	0
375592	375545	14215L	PARTICIPANT	\N	PRESENT	0
375593	375545	19762G	PARTICIPANT	\N	PRESENT	0
375594	375545	14147R	PARTICIPANT	\N	PRESENT	0
375595	375545	04038G	PARTICIPANT	\N	PRESENT	0
375596	375545	19729F	PARTICIPANT	\N	EXCUSE	0
375597	375545	04044E	PARTICIPANT	\N	EXCUSE	0
375598	371423	14041T	PARTICIPANT	\N	PRESENT	0
375599	371423	19387D	PARTICIPANT	\N	PRESENT	0
375600	371423	11066Q	PARTICIPANT	\N	PRESENT	0
375601	371423	01025N	PARTICIPANT	\N	PRESENT	0
375602	371423	04038G	PARTICIPANT	\N	PRESENT	0
375603	371423	19599P	PARTICIPANT	\N	PRESENT	0
375604	371423	14001X	PARTICIPANT	\N	PRESENT	0
375605	371423	01028R	PARTICIPANT	\N	PRESENT	0
375606	371423	19725B	PARTICIPANT	\N	PRESENT	0
375607	371423	11072N	PARTICIPANT	\N	PRESENT	0
375608	371423	19681G	PARTICIPANT	\N	PRESENT	0
375609	371423	08045X	PARTICIPANT	\N	PRESENT	0
375610	371423	14063N	PARTICIPANT	\N	PRESENT	0
375611	371423	14089Y	PARTICIPANT	\N	PRESENT	0
375612	371423	08056B	PARTICIPANT	\N	PRESENT	0
375613	371423	11012A	PARTICIPANT	\N	PRESENT	0
375614	371423	01024M	PARTICIPANT	\N	PRESENT	0
375615	371423	05008E	PARTICIPANT	\N	PRESENT	0
375616	371423	14071N	PARTICIPANT	\N	PRESENT	0
375617	375460	04070G	PRESIDENT	0	PRESENT	0
375618	375460	19699S	PARTICIPANT	\N	PRESENT	0
375619	375460	04057K	PARTICIPANT	\N	PRESENT	0
375620	375460	19611R	PARTICIPANT	\N	PRESENT	0
375621	375460	19693L	PARTICIPANT	\N	PRESENT	0
375622	375460	08020N	PARTICIPANT	\N	PRESENT	0
375623	375460	19573D	PARTICIPANT	\N	PRESENT	0
375624	375460	14039A	PARTICIPANT	\N	PRESENT	0
375625	375460	19735D	PARTICIPANT	\N	PRESENT	0
375626	375460	08012N	PARTICIPANT	\N	PRESENT	0
375627	375460	11104D	PARTICIPANT	\N	PRESENT	0
375628	375460	04018C	PARTICIPANT	\N	PRESENT	0
375629	375460	19758L	PARTICIPANT	\N	PRESENT	0
375630	375460	08031R	PARTICIPANT	\N	PRESENT	0
375631	375460	19766L	PARTICIPANT	\N	EXCUSE	0
375632	375460	08043V	PARTICIPANT	\N	EXCUSE	0
375633	375460	19399H	PARTICIPANT	\N	EXCUSE	0
375634	371423	14053L	PARTICIPANT	\N	PRESENT	0
375635	371423	14151M	PARTICIPANT	\N	PRESENT	0
375636	371423	19585H	PARTICIPANT	\N	PRESENT	0
375637	371423	14191V	PARTICIPANT	\N	PRESENT	0
375638	371423	19447X	PARTICIPANT	\N	PRESENT	0
375639	371423	19443T	PARTICIPANT	\N	PRESENT	0
375640	371423	18083K	PARTICIPANT	\N	PRESENT	0
375641	371423	19675J	PARTICIPANT	\N	PRESENT	0
375642	371423	08034U	PARTICIPANT	\N	PRESENT	0
375643	371423	04042C	PARTICIPANT	\N	PRESENT	0
375644	371423	19703U	PARTICIPANT	\N	PRESENT	0
375645	371423	19521Q	PARTICIPANT	\N	PRESENT	0
375646	371423	97011G	PARTICIPANT	\N	PRESENT	0
375647	371423	14267Y	PARTICIPANT	\N	PRESENT	0
375648	371423	19253P	PARTICIPANT	\N	PRESENT	0
375649	371423	14217N	PARTICIPANT	\N	PRESENT	0
375650	375458	14135M	PARTICIPANT	\N	PRESENT	0
375651	375458	19467C	PARTICIPANT	\N	PRESENT	0
375652	375458	19768N	PARTICIPANT	\N	PRESENT	0
375653	375458	19515S	PARTICIPANT	\N	PRESENT	0
375654	375458	14357A	PARTICIPANT	\N	PRESENT	0
375655	375458	08062Y	PARTICIPANT	\N	PRESENT	0
375656	375458	14033T	PARTICIPANT	\N	PRESENT	0
375657	375458	11090Q	PRESIDENT	0	PRESENT	0
375658	375458	04049K	PARTICIPANT	\N	PRESENT	0
375659	375458	19705W	PARTICIPANT	\N	PRESENT	0
375660	375458	19507S	PARTICIPANT	\N	PRESENT	0
375661	375458	08015R	PARTICIPANT	\N	PRESENT	0
375662	375458	14265W	PARTICIPANT	\N	PRESENT	0
375663	371423	14073Q	PARTICIPANT	\N	PRESENT	0
375664	371423	14107H	PARTICIPANT	\N	PRESENT	0
375665	371423	19782L	PARTICIPANT	\N	PRESENT	0
375666	375458	19413M	PARTICIPANT	\N	PRESENT	0
375667	375458	19695N	PARTICIPANT	\N	PRESENT	0
375668	375458	11099A	PARTICIPANT	\N	PRESENT	0
375669	375458	04089T	PARTICIPANT	\N	PRESENT	0
375670	375458	14197C	PARTICIPANT	\N	PRESENT	0
375671	375458	14207L	PARTICIPANT	\N	PRESENT	0
375672	375458	19511N	PARTICIPANT	\N	PRESENT	0
375673	375458	19563B	PARTICIPANT	\N	PRESENT	0
375674	375458	17589D	PARTICIPANT	\N	PRESENT	0
375675	375458	14257W	PARTICIPANT	\N	PRESENT	0
375676	371423	14223L	PARTICIPANT	\N	PRESENT	0
375677	371423	19733B	PARTICIPANT	\N	PRESENT	0
375678	371423	19745F	PARTICIPANT	\N	PRESENT	0
375679	375049	19415P	PARTICIPANT	\N	PRESENT	0
375680	371423	19719D	PARTICIPANT	\N	PRESENT	0
375681	371423	19543W	PARTICIPANT	\N	PRESENT	0
375683	375458	19441R	PARTICIPANT	\N	PRESENT	0
375684	375458	14187A	PARTICIPANT	\N	PRESENT	0
375685	375458	19269X	PARTICIPANT	\N	PRESENT	0
375686	375458	04043D	PARTICIPANT	\N	PRESENT	0
375687	371423	19479G	PARTICIPANT	\N	PRESENT	0
375688	371423	14215L	PARTICIPANT	\N	PRESENT	0
375689	371423	19631V	PARTICIPANT	\N	PRESENT	0
375690	371423	14069U	PARTICIPANT	\N	PRESENT	0
375691	371423	14042U	PARTICIPANT	\N	PRESENT	0
375692	371423	19798U	PARTICIPANT	\N	PRESENT	0
375693	375458	14081Q	PARTICIPANT	\N	PRESENT	0
375694	375458	14115H	PARTICIPANT	\N	PRESENT	0
375695	375458	11101A	PARTICIPANT	\N	PRESENT	0
375696	371423	19581D	PARTICIPANT	\N	PRESENT	0
375697	371423	11040E	PARTICIPANT	\N	PRESENT	0
375698	375458	08038Y	PARTICIPANT	\N	EXCUSE	0
375699	375458	19369B	PARTICIPANT	\N	EXCUSE	0
375700	375458	19295A	PARTICIPANT	\N	EXCUSE	0
375701	375458	08021P	PARTICIPANT	\N	EXCUSE	0
375702	375458	11081P	PARTICIPANT	\N	EXCUSE	0
375703	371423	04097T	PARTICIPANT	\N	PRESENT	0
375704	371423	95030B	PARTICIPANT	\N	PRESENT	0
375705	375458	08068F	PARTICIPANT	\N	PRESENT	0
375706	371423	14026U	PARTICIPANT	\N	PRESENT	0
375707	371423	17583W	PARTICIPANT	\N	PRESENT	0
363139	362033	11090Q	PARTICIPANT	\N	PRESENT	0
363142	362033	19619A	PARTICIPANT	\N	PRESENT	0
363143	362033	19575F	PARTICIPANT	\N	PRESENT	0
363144	362033	14105F	PARTICIPANT	\N	PRESENT	0
363146	362033	19383Y	PARTICIPANT	\N	PRESENT	0
363147	362033	14079W	PARTICIPANT	\N	PRESENT	0
363148	362033	14221J	PARTICIPANT	\N	PRESENT	0
363149	362033	11066Q	PARTICIPANT	\N	PRESENT	0
363945	345290	14097Y	PARTICIPANT	\N	PRESENT	0
364199	345237	04044E	PARTICIPANT	\N	PRESENT	0
364200	345237	14231L	PARTICIPANT	\N	PRESENT	0
364201	345237	08009T	PARTICIPANT	\N	PRESENT	0
364202	345237	14031R	PARTICIPANT	\N	PRESENT	0
364204	345237	19715Y	PARTICIPANT	\N	PRESENT	0
364205	345237	12016W	PARTICIPANT	\N	PRESENT	0
364206	345237	04085P	PARTICIPANT	\N	PRESENT	0
364207	345237	19525U	PARTICIPANT	\N	PRESENT	0
364208	345237	01028R	PARTICIPANT	\N	PRESENT	0
364209	345237	07029T	PARTICIPANT	\N	PRESENT	0
364210	345237	19507S	PARTICIPANT	\N	PRESENT	0
364211	345237	04088S	PARTICIPANT	\N	PRESENT	0
364212	345237	14051J	PARTICIPANT	\N	PRESENT	0
364213	345237	19599P	PARTICIPANT	\N	PRESENT	0
364214	345237	99004R	PARTICIPANT	\N	PRESENT	0
364215	345237	08017T	PARTICIPANT	\N	PRESENT	0
364216	345237	08043V	PARTICIPANT	\N	PRESENT	0
364217	345237	19503N	PARTICIPANT	\N	PRESENT	0
364218	345237	14229S	PARTICIPANT	\N	PRESENT	0
364219	345237	19349W	PARTICIPANT	\N	PRESENT	0
364220	345237	19637C	PARTICIPANT	\N	PRESENT	0
364221	345237	19543W	PARTICIPANT	\N	PRESENT	0
364222	345237	19583F	PARTICIPANT	\N	PRESENT	0
364223	345237	19611R	PARTICIPANT	\N	PRESENT	0
364224	345237	19479G	PARTICIPANT	\N	PRESENT	0
364225	345237	19671E	PARTICIPANT	\N	PRESENT	0
364226	345237	14089Y	PARTICIPANT	\N	PRESENT	0
364227	345237	19333N	PARTICIPANT	\N	PRESENT	0
364228	345237	11031D	PARTICIPANT	\N	PRESENT	0
364229	345237	19253P	PARTICIPANT	\N	PRESENT	0
364230	345237	11012A	PARTICIPANT	\N	PRESENT	0
364231	345237	04061F	PARTICIPANT	\N	PRESENT	0
364232	345237	19711U	PARTICIPANT	\N	PRESENT	0
364233	345237	08060W	PARTICIPANT	\N	PRESENT	0
364234	345237	19689Q	PARTICIPANT	\N	PRESENT	0
364235	345237	19347U	PARTICIPANT	\N	PRESENT	0
364236	345237	11065P	PARTICIPANT	\N	PRESENT	0
364237	345237	19737F	PARTICIPANT	\N	PRESENT	0
364238	345237	14042U	PARTICIPANT	\N	PRESENT	0
364239	345237	01062T	PARTICIPANT	\N	PRESENT	0
364240	345237	19533U	PARTICIPANT	\N	PRESENT	0
364241	345237	19683J	PARTICIPANT	\N	PRESENT	0
364242	345237	19289C	PARTICIPANT	\N	PRESENT	0
364243	345237	19687N	PARTICIPANT	\N	PRESENT	0
364244	345237	05008E	PARTICIPANT	\N	PRESENT	0
364245	345237	08034U	PARTICIPANT	\N	PRESENT	0
364246	345237	08020N	PARTICIPANT	\N	PRESENT	0
364247	345237	19551W	PARTICIPANT	\N	PRESENT	0
364248	345237	19399H	PARTICIPANT	\N	PRESENT	0
364249	345237	14038Y	PARTICIPANT	\N	PRESENT	0
364250	345237	19693L	PARTICIPANT	\N	PRESENT	0
364251	345237	19413M	PARTICIPANT	\N	PRESENT	0
364252	345237	19441R	PARTICIPANT	\N	PRESENT	0
364253	345237	14219Q	PARTICIPANT	\N	PRESENT	0
364254	345237	01048V	PARTICIPANT	\N	PRESENT	0
364255	345237	14225N	PARTICIPANT	\N	PRESENT	0
364256	345237	19651A	PARTICIPANT	\N	PRESENT	0
364257	345237	19695N	PARTICIPANT	\N	PRESENT	0
364258	345237	19703U	PARTICIPANT	\N	PRESENT	0
364259	345237	19447X	PARTICIPANT	\N	PRESENT	0
364260	345237	19301E	PARTICIPANT	\N	PRESENT	0
364261	345237	14327T	PARTICIPANT	\N	PRESENT	0
364262	345237	19467C	PARTICIPANT	\N	PRESENT	0
364265	345237	08056B	PARTICIPANT	\N	PRESENT	0
364266	345237	19733B	PARTICIPANT	\N	PRESENT	0
364267	345237	19741B	PARTICIPANT	\N	PRESENT	0
364268	345237	08015R	PARTICIPANT	\N	PRESENT	0
364273	345237	14169X	PARTICIPANT	\N	PRESENT	0
364274	345237	19667J	PARTICIPANT	\N	PRESENT	0
364275	345237	19673G	PARTICIPANT	\N	PRESENT	0
364276	345237	11048N	PARTICIPANT	\N	PRESENT	0
364277	345237	08069G	PARTICIPANT	\N	PRESENT	0
364278	345237	19631V	PARTICIPANT	\N	PRESENT	0
364279	345237	14093U	PARTICIPANT	\N	PRESENT	0
364283	345237	19647E	PARTICIPANT	\N	PRESENT	0
364284	345237	04035D	PARTICIPANT	\N	PRESENT	0
364285	345237	19629C	PARTICIPANT	\N	PRESENT	0
364286	345237	14133K	PARTICIPANT	\N	PRESENT	0
364287	345237	19701S	PARTICIPANT	\N	PRESENT	0
364288	345237	14053L	PARTICIPANT	\N	PRESENT	0
364289	345237	11043H	PARTICIPANT	\N	PRESENT	0
364290	345237	14083S	PARTICIPANT	\N	PRESENT	0
364291	345237	19669L	PARTICIPANT	\N	PRESENT	0
364300	345237	19691J	PARTICIPANT	\N	PRESENT	0
364301	345237	14261S	PARTICIPANT	\N	PRESENT	0
364302	345237	04018C	PARTICIPANT	\N	PRESENT	0
364323	345237	05012A	PARTICIPANT	\N	PRESENT	0
364324	345237	08010L	PARTICIPANT	\N	PRESENT	0
364373	345238	14031R	PARTICIPANT	\N	PRESENT	0
364374	345238	08009T	PARTICIPANT	\N	PRESENT	0
364375	345238	14051J	PARTICIPANT	\N	PRESENT	0
364376	345238	19333N	PARTICIPANT	\N	PRESENT	0
364377	345238	19551W	PARTICIPANT	\N	PRESENT	0
364378	345238	08060W	PARTICIPANT	\N	PRESENT	0
364379	345238	19637C	PARTICIPANT	\N	PRESENT	0
364380	345238	19301E	PARTICIPANT	\N	PRESENT	0
364381	345238	04085P	PARTICIPANT	\N	PRESENT	0
364382	345238	19695N	PARTICIPANT	\N	PRESENT	0
364383	345238	12016W	PARTICIPANT	\N	PRESENT	0
364384	345238	19667J	PARTICIPANT	\N	PRESENT	0
364385	345238	19253P	PARTICIPANT	\N	PRESENT	0
364386	345238	07029T	PARTICIPANT	\N	PRESENT	0
364387	345238	11012A	PARTICIPANT	\N	PRESENT	0
364388	345238	19611R	PARTICIPANT	\N	PRESENT	0
364389	345238	19691J	PARTICIPANT	\N	PRESENT	0
364390	345238	19711U	PARTICIPANT	\N	PRESENT	0
364391	345238	19737F	PARTICIPANT	\N	PRESENT	0
364392	345238	14261S	PARTICIPANT	\N	PRESENT	0
364393	345238	99004R	PARTICIPANT	\N	PRESENT	0
364394	345238	08019V	PARTICIPANT	\N	PRESENT	0
364395	345238	19715Y	PARTICIPANT	\N	PRESENT	0
364396	345238	14219Q	PARTICIPANT	\N	PRESENT	0
364397	345238	19503N	PARTICIPANT	\N	PRESENT	0
364398	345238	14093U	PARTICIPANT	\N	PRESENT	0
364399	345238	19701S	PARTICIPANT	\N	PRESENT	0
364400	345238	19669L	PARTICIPANT	\N	PRESENT	0
364401	345238	14083S	PARTICIPANT	\N	PRESENT	0
364402	345238	89017R	PARTICIPANT	\N	PRESENT	0
364403	345238	14034U	PARTICIPANT	\N	PRESENT	0
364404	345238	19693L	PARTICIPANT	\N	PRESENT	0
364563	364562	14133K	PARTICIPANT	\N	PRESENT	0
364564	364562	14217N	PARTICIPANT	\N	PRESENT	0
364565	364562	14265W	PARTICIPANT	\N	PRESENT	0
364566	364562	14097Y	PARTICIPANT	\N	PRESENT	0
364567	364562	11026G	PARTICIPANT	\N	PRESENT	0
364568	364562	14281W	PARTICIPANT	\N	PRESENT	0
364371	345238	11070L	PARTICIPANT	\N	PRESENT	0
364372	345238	14231L	PARTICIPANT	\N	PRESENT	0
378660	373666	19651A	PARTICIPANT	\N	PRESENT	0
378727	376954	19637C	PARTICIPANT	\N	PRESENT	0
378728	376954	19737F	PARTICIPANT	\N	PRESENT	0
378729	376954	19347U	PARTICIPANT	\N	PRESENT	0
378730	376954	19551W	PARTICIPANT	\N	PRESENT	0
378731	376954	19335Q	PARTICIPANT	\N	PRESENT	0
378733	376954	14237S	PARTICIPANT	\N	PRESENT	0
378734	376954	14031R	PARTICIPANT	\N	PRESENT	0
379251	371479	19421M	PARTICIPANT	\N	PRESENT	0
379252	371479	08043V	PARTICIPANT	\N	PRESENT	0
379253	371479	11097X	PARTICIPANT	\N	PRESENT	0
379254	371479	11066Q	PARTICIPANT	\N	PRESENT	0
379255	371479	14071N	PARTICIPANT	\N	PRESENT	0
379256	371479	14065Q	PARTICIPANT	\N	PRESENT	0
379257	371479	19669L	PARTICIPANT	\N	PRESENT	0
379258	371479	04033B	PARTICIPANT	\N	PRESENT	0
379259	371479	04086Q	PARTICIPANT	\N	PRESENT	0
379260	371479	04092N	PARTICIPANT	\N	PRESENT	0
379261	371479	14151M	PARTICIPANT	\N	PRESENT	0
379262	371479	08044W	PARTICIPANT	\N	PRESENT	0
379263	371479	14179A	PARTICIPANT	\N	PRESENT	0
379264	371479	04043D	PARTICIPANT	\N	PRESENT	0
379265	371479	04070G	PARTICIPANT	\N	PRESENT	0
379266	371479	19369B	PARTICIPANT	\N	PRESENT	0
379267	371479	19691J	PARTICIPANT	\N	PRESENT	0
379268	371479	19511N	PARTICIPANT	\N	PRESENT	0
379269	371479	14213J	PARTICIPANT	\N	PRESENT	0
379270	371479	19611R	PARTICIPANT	\N	PRESENT	0
379271	371479	11070L	PARTICIPANT	\N	PRESENT	0
379272	371479	19515S	PARTICIPANT	\N	PRESENT	0
379273	371479	11053K	PARTICIPANT	\N	PRESENT	0
379274	371479	19737F	PARTICIPANT	\N	PRESENT	0
379275	371479	19699S	PARTICIPANT	\N	PRESENT	0
379276	371479	19619A	PARTICIPANT	\N	PRESENT	0
379277	371479	16685X	PARTICIPANT	\N	PRESENT	0
379278	371479	14249W	PARTICIPANT	\N	PRESENT	0
379279	371479	08056B	PARTICIPANT	\N	PRESENT	0
379280	371479	08009T	PARTICIPANT	\N	PRESENT	0
379281	371479	14219Q	PARTICIPANT	\N	PRESENT	0
379282	371479	11031D	PARTICIPANT	\N	PRESENT	0
379283	371479	19713W	PARTICIPANT	\N	PRESENT	0
379284	371479	19479G	PARTICIPANT	\N	PRESENT	0
379285	371479	14277B	PARTICIPANT	\N	PRESENT	0
379286	371479	04071H	PARTICIPANT	\N	PRESENT	0
379287	371479	19441R	PARTICIPANT	\N	PRESENT	0
379288	371479	14205J	PARTICIPANT	\N	PRESENT	0
379289	371479	19643A	PARTICIPANT	\N	PRESENT	0
379290	371479	14073Q	PARTICIPANT	\N	PRESENT	0
379292	371479	14103D	PARTICIPANT	\N	PRESENT	0
379293	371479	04089T	PARTICIPANT	\N	PRESENT	0
379294	371479	19521Q	PARTICIPANT	\N	PRESENT	0
379295	371479	19739H	PARTICIPANT	\N	PRESENT	0
379296	371479	19335Q	PARTICIPANT	\N	PRESENT	0
379297	371479	01048V	PARTICIPANT	\N	PRESENT	0
379298	371479	19749K	PARTICIPANT	\N	PRESENT	0
379299	371479	19745F	PARTICIPANT	\N	PRESENT	0
379300	371479	14267Y	PARTICIPANT	\N	PRESENT	0
379301	371479	07004J	PARTICIPANT	\N	PRESENT	0
379302	371479	14255U	PARTICIPANT	\N	PRESENT	0
379303	371479	04040A	PARTICIPANT	\N	PRESENT	0
379304	371479	11085T	PARTICIPANT	\N	PRESENT	0
379305	371479	19577H	PARTICIPANT	\N	PRESENT	0
379306	371479	01024M	PARTICIPANT	\N	PRESENT	0
379307	371479	14327T	PARTICIPANT	\N	PRESENT	0
379308	371479	01025N	PARTICIPANT	\N	PRESENT	0
379309	371479	19593H	PARTICIPANT	\N	PRESENT	0
379310	371479	19760E	PARTICIPANT	\N	PRESENT	0
379311	371479	19659J	PARTICIPANT	\N	PRESENT	0
379312	371479	14261S	PARTICIPANT	\N	PRESENT	0
379313	371479	19717B	PARTICIPANT	\N	PRESENT	0
379314	371479	11090Q	PARTICIPANT	\N	PRESENT	0
379315	371479	86034E	PARTICIPANT	\N	PRESENT	0
379316	371479	14034U	PARTICIPANT	\N	PRESENT	0
379317	371479	19447X	PARTICIPANT	\N	PRESENT	0
379318	371479	04057K	PARTICIPANT	\N	PRESENT	0
379319	371479	19525U	PARTICIPANT	\N	PRESENT	0
379320	371479	19575F	PARTICIPANT	\N	PRESENT	0
379321	371479	19729F	PARTICIPANT	\N	PRESENT	0
379322	371479	19675J	PARTICIPANT	\N	PRESENT	0
379324	371479	11115U	PARTICIPANT	\N	PRESENT	0
379327	371479	14231L	PARTICIPANT	\N	PRESENT	0
379328	371479	04008A	PARTICIPANT	\N	PRESENT	0
379329	371479	92040Q	PARTICIPANT	\N	PRESENT	0
379330	371479	19565D	PARTICIPANT	\N	PRESENT	0
379331	371479	19762G	PARTICIPANT	\N	PRESENT	0
379332	371479	19725B	PARTICIPANT	\N	PRESENT	0
379339	371479	14089Y	PARTICIPANT	\N	PRESENT	0
379363	371479	14221J	PARTICIPANT	\N	PRESENT	0
379651	371484	11070L	PARTICIPANT	\N	PRESENT	0
379653	371484	19758L	PARTICIPANT	\N	PRESENT	0
379654	371484	14235Q	PARTICIPANT	\N	PRESENT	0
379655	371484	11045K	PARTICIPANT	\N	PRESENT	0
379656	371484	08043V	PARTICIPANT	\N	PRESENT	0
379657	371484	14229S	PARTICIPANT	\N	PRESENT	0
379658	371484	14065Q	PARTICIPANT	\N	PRESENT	0
379659	371484	08024S	PARTICIPANT	\N	PRESENT	0
379660	371484	11064N	PARTICIPANT	\N	PRESENT	0
379661	371484	19611R	PARTICIPANT	\N	PRESENT	0
379662	371484	19621T	PARTICIPANT	\N	PRESENT	0
379663	371484	04070G	PARTICIPANT	\N	PRESENT	0
379664	371484	14071N	PARTICIPANT	\N	PRESENT	0
379665	371484	14123H	PARTICIPANT	\N	PRESENT	0
379666	371484	19693L	PARTICIPANT	\N	PRESENT	0
379667	371484	14033T	PARTICIPANT	\N	PRESENT	0
379668	371484	19507S	PARTICIPANT	\N	PRESENT	0
379669	371484	98005N	PARTICIPANT	\N	PRESENT	0
379670	371484	19713W	PARTICIPANT	\N	PRESENT	0
379671	371484	19651A	PARTICIPANT	\N	PRESENT	0
379672	371484	19349W	PARTICIPANT	\N	PRESENT	0
379673	371484	14107H	PARTICIPANT	\N	PRESENT	0
379674	371484	14241N	PARTICIPANT	\N	PRESENT	0
379675	371484	19575F	PARTICIPANT	\N	PRESENT	0
379676	371484	14331P	PARTICIPANT	\N	PRESENT	0
379677	371484	19673G	PARTICIPANT	\N	PRESENT	0
379678	371484	14031R	PARTICIPANT	\N	PRESENT	0
379679	371484	04088S	PARTICIPANT	\N	PRESENT	0
379680	371484	14029X	PARTICIPANT	\N	PRESENT	0
379681	371484	14061L	PARTICIPANT	\N	PRESENT	0
379682	371484	14109K	PARTICIPANT	\N	PRESENT	0
379683	371484	14249W	PARTICIPANT	\N	PRESENT	0
379684	371484	08017T	PARTICIPANT	\N	PRESENT	0
379685	371484	19794Q	PARTICIPANT	\N	PRESENT	0
379686	371484	04085P	PARTICIPANT	\N	PRESENT	0
379687	371484	11026G	PARTICIPANT	\N	PRESENT	0
379688	371484	19631V	PARTICIPANT	\N	PRESENT	0
379689	371484	04059M	PARTICIPANT	\N	PRESENT	0
379690	371484	19629C	PARTICIPANT	\N	PRESENT	0
379691	371484	19715Y	PARTICIPANT	\N	PRESENT	0
379692	371484	19467C	PARTICIPANT	\N	PRESENT	0
379693	371484	14059S	PARTICIPANT	\N	PRESENT	0
379694	371484	19711U	PARTICIPANT	\N	PRESENT	0
379695	371484	01058X	PARTICIPANT	\N	PRESENT	0
379696	371484	19447X	PARTICIPANT	\N	PRESENT	0
379697	371484	19573D	PARTICIPANT	\N	PRESENT	0
379698	371484	19583F	PARTICIPANT	\N	PRESENT	0
379699	371484	19295A	PARTICIPANT	\N	PRESENT	0
379700	371484	19301E	PARTICIPANT	\N	PRESENT	0
379701	371484	19703U	PARTICIPANT	\N	PRESENT	0
379702	371484	19667J	PARTICIPANT	\N	PRESENT	0
379703	371484	19691J	PARTICIPANT	\N	PRESENT	0
379704	371484	14231L	PARTICIPANT	\N	PRESENT	0
379705	371484	14157T	PARTICIPANT	\N	PRESENT	0
379706	371484	14357A	PARTICIPANT	\N	PRESENT	0
379707	371484	04043D	PARTICIPANT	\N	PRESENT	0
379708	371484	19533U	PARTICIPANT	\N	PRESENT	0
379709	371484	19479G	PARTICIPANT	\N	PRESENT	0
379710	371484	08015R	PARTICIPANT	\N	PRESENT	0
379711	371484	11097X	PARTICIPANT	\N	PRESENT	0
379712	371484	08031R	PARTICIPANT	\N	PRESENT	0
379713	371484	19647E	PARTICIPANT	\N	PRESENT	0
379714	371484	11067R	PARTICIPANT	\N	PRESENT	0
379715	371484	11043H	PARTICIPANT	\N	PRESENT	0
379716	371484	19649G	PARTICIPANT	\N	PRESENT	0
379717	371484	11012A	PARTICIPANT	\N	PRESENT	0
379718	371484	04033B	PARTICIPANT	\N	PRESENT	0
379719	371484	08069G	PARTICIPANT	\N	PRESENT	0
379720	371484	07033P	PARTICIPANT	\N	PRESENT	0
379721	371484	14135M	PARTICIPANT	\N	PRESENT	0
379725	371484	14053L	PARTICIPANT	\N	PRESENT	0
379726	371484	14111D	PARTICIPANT	\N	PRESENT	0
379727	371484	19593H	PARTICIPANT	\N	PRESENT	0
379728	371484	14219Q	PARTICIPANT	\N	PRESENT	0
379729	371484	08056B	PARTICIPANT	\N	PRESENT	0
379730	371484	14179A	PARTICIPANT	\N	PRESENT	0
379731	371484	19543W	PARTICIPANT	\N	PRESENT	0
379732	371484	19689Q	PARTICIPANT	\N	PRESENT	0
379733	371484	19669L	PARTICIPANT	\N	PRESENT	0
379734	371484	19253P	PARTICIPANT	\N	PRESENT	0
364548	364547	14079W	PARTICIPANT	\N	PRESENT	0
364549	364547	19794Q	PARTICIPANT	\N	PRESENT	0
364550	364547	19413M	PARTICIPANT	\N	PRESENT	0
364551	364547	08053X	PARTICIPANT	\N	PRESENT	0
369712	369711	01028R	PARTICIPANT	\N	PRESENT	0
369860	365231	19667J	PARTICIPANT	\N	EXCUSE	0
369861	365231	19369B	PARTICIPANT	\N	PRESENT	0
370468	356821	11097X	PARTICIPANT	\N	PRESENT	0
370781	370780	19631V	PARTICIPANT	\N	PRESENT	0
370782	370780	19549D	PARTICIPANT	\N	PRESENT	0
370783	370780	14038Y	PARTICIPANT	\N	PRESENT	0
370784	370780	19701S	PARTICIPANT	\N	PRESENT	0
370785	370780	11083R	PARTICIPANT	\N	PRESENT	0
370786	370780	19333N	PARTICIPANT	\N	PRESENT	0
370787	370780	19489J	PARTICIPANT	\N	PRESENT	0
370788	370780	19611R	PARTICIPANT	\N	PRESENT	0
370789	370780	04049K	PARTICIPANT	\N	PRESENT	0
370790	370780	19723Y	PARTICIPANT	\N	PRESENT	0
370791	370780	14031R	PARTICIPANT	\N	PRESENT	0
370792	370780	14169X	PARTICIPANT	\N	PRESENT	0
370793	370780	19349W	PARTICIPANT	\N	PRESENT	0
370794	370780	19749K	PARTICIPANT	\N	PRESENT	0
370796	370795	14169X	PARTICIPANT	\N	PRESENT	0
370797	370795	14038Y	PARTICIPANT	\N	PRESENT	0
370798	370795	19489J	PARTICIPANT	\N	PRESENT	0
370799	370795	19701S	PARTICIPANT	\N	PRESENT	0
370808	370806	11074Q	PARTICIPANT	\N	PRESENT	0
370809	370806	08011M	PARTICIPANT	\N	PRESENT	0
370818	370815	11074Q	PARTICIPANT	\N	PRESENT	0
370819	370815	08011M	PARTICIPANT	\N	PRESENT	0
370831	370830	08011M	PARTICIPANT	\N	PRESENT	0
370841	370840	08011M	PARTICIPANT	\N	PRESENT	0
370842	370840	14083S	PARTICIPANT	\N	PRESENT	0
370844	370840	19479G	PARTICIPANT	\N	PRESENT	0
370849	370848	08011M	PARTICIPANT	\N	PRESENT	0
370854	370853	14089Y	PARTICIPANT	\N	PRESENT	0
370856	370855	14089Y	PARTICIPANT	\N	PRESENT	0
370857	370855	14257W	PARTICIPANT	\N	PRESENT	0
370859	370858	14089Y	PARTICIPANT	\N	PRESENT	0
370861	370860	14089Y	PARTICIPANT	\N	PRESENT	0
370862	370860	14257W	PARTICIPANT	\N	PRESENT	0
370864	370863	14089Y	PARTICIPANT	\N	PRESENT	0
370865	370863	14257W	PARTICIPANT	\N	PRESENT	0
370867	370866	14089Y	PARTICIPANT	\N	PRESENT	0
370868	370866	14257W	PARTICIPANT	\N	PRESENT	0
370870	370869	14089Y	PARTICIPANT	\N	PRESENT	0
370872	370871	14089Y	PARTICIPANT	\N	PRESENT	0
370873	370871	14257W	PARTICIPANT	\N	PRESENT	0
370875	370874	14089Y	PARTICIPANT	\N	PRESENT	0
370921	365231	08024S	PARTICIPANT	\N	EXCUSE	0
370959	365231	19515S	PARTICIPANT	\N	PRESENT	0
370960	365231	11065P	PARTICIPANT	\N	PRESENT	0
370961	365231	14107H	PARTICIPANT	\N	PRESENT	0
376739	373666	19551W	PARTICIPANT	\N	EXCUSE	0
376797	373666	11066Q	PARTICIPANT	\N	EXCUSE	0
376897	373666	19647E	PARTICIPANT	\N	EXCUSE	0
376902	376901	19631V	PARTICIPANT	\N	PRESENT	0
376903	376901	19741B	PARTICIPANT	\N	PRESENT	0
376904	376901	14093U	PARTICIPANT	\N	PRESENT	0
376905	376901	19415P	PARTICIPANT	\N	PRESENT	0
376906	376901	14038Y	PARTICIPANT	\N	PRESENT	0
376907	376901	88008L	PARTICIPANT	\N	EXCUSE	0
376908	376901	19599P	PARTICIPANT	\N	PRESENT	0
376923	373666	08069G	PARTICIPANT	\N	EXCUSE	0
376910	376901	11083R	PARTICIPANT	\N	PRESENT	0
376911	376901	14179A	PARTICIPANT	\N	PRESENT	0
376912	376901	19611R	PARTICIPANT	\N	PRESENT	0
376913	376901	01048V	PARTICIPANT	\N	PRESENT	0
376914	376901	08053X	PARTICIPANT	\N	EXCUSE	0
376915	376901	14257W	PRESIDENT	0	PRESENT	0
376916	376901	04070G	PARTICIPANT	\N	PRESENT	0
376917	376901	19593H	PARTICIPANT	\N	PRESENT	0
376918	376901	19533U	PARTICIPANT	\N	PRESENT	0
376919	376901	11090Q	PARTICIPANT	\N	PRESENT	0
376924	373666	19569H	PARTICIPANT	\N	EXCUSE	0
376921	376901	14229S	PARTICIPANT	\N	PRESENT	0
376922	376901	19421M	PARTICIPANT	\N	PRESENT	0
376925	373666	19369B	PARTICIPANT	\N	PRESENT	0
376928	376927	14261S	PARTICIPANT	\N	PRESENT	0
376929	376927	14119M	PARTICIPANT	\N	PRESENT	0
376931	376930	01034P	PARTICIPANT	\N	PRESENT	0
378106	378105	11053K	PARTICIPANT	\N	PRESENT	0
378107	378105	14159V	PARTICIPANT	\N	PRESENT	0
378108	378105	05012A	PARTICIPANT	\N	PRESENT	0
378113	378110	11053K	PARTICIPANT	\N	PRESENT	0
378114	378110	14159V	PARTICIPANT	\N	PRESENT	0
378115	378110	05012A	PARTICIPANT	\N	PRESENT	0
378351	378350	14026U	PARTICIPANT	\N	PRESENT	0
378352	378350	19717B	PARTICIPANT	\N	PRESENT	0
378360	378353	14026U	PARTICIPANT	\N	PRESENT	0
378361	378353	19717B	PARTICIPANT	\N	PRESENT	0
378363	375457	19663E	PARTICIPANT	\N	EXCUSE	0
378747	373784	11101A	PARTICIPANT	\N	PRESENT	0
378748	373784	04086Q	PARTICIPANT	\N	PRESENT	0
378749	373784	19525U	PARTICIPANT	\N	PRESENT	0
378750	373784	14231L	PARTICIPANT	\N	PRESENT	0
378751	373784	19565D	PARTICIPANT	\N	PRESENT	0
378752	373784	19489J	PARTICIPANT	\N	PRESENT	0
378753	373784	08010L	PARTICIPANT	\N	PRESENT	0
378754	373784	19735D	PARTICIPANT	\N	PRESENT	0
378755	373784	04045F	PARTICIPANT	\N	PRESENT	0
378756	373784	95067Q	PARTICIPANT	\N	PRESENT	0
378757	373784	19253P	PARTICIPANT	\N	PRESENT	0
378758	373784	14281W	PARTICIPANT	\N	PRESENT	0
378809	378808	04092N	PARTICIPANT	\N	PRESENT	0
378810	378808	14239U	PARTICIPANT	\N	PRESENT	0
378811	378808	11097X	PARTICIPANT	\N	PRESENT	0
378812	378808	08052W	PARTICIPANT	\N	PRESENT	0
378813	378808	19569H	PARTICIPANT	\N	PRESENT	0
378814	378808	14217N	PARTICIPANT	\N	PRESENT	0
378815	378808	14281W	PARTICIPANT	\N	PRESENT	0
378820	378819	19507S	PARTICIPANT	\N	PRESENT	0
378821	378819	14257W	PARTICIPANT	\N	PRESENT	0
378822	378819	14207L	PARTICIPANT	\N	PRESENT	0
378823	378819	01025N	PARTICIPANT	\N	PRESENT	0
378824	378819	14033T	PARTICIPANT	\N	PRESENT	0
378825	378819	14265W	PARTICIPANT	\N	PRESENT	0
378826	378819	19467C	PARTICIPANT	\N	PRESENT	0
378829	378827	19631V	PARTICIPANT	\N	PRESENT	0
378830	378827	19383Y	PARTICIPANT	\N	PRESENT	0
378831	378827	19467C	PARTICIPANT	\N	PRESENT	0
378832	378827	19507S	PARTICIPANT	\N	PRESENT	0
378833	378827	01025N	PARTICIPANT	\N	PRESENT	0
378834	378827	14033T	PARTICIPANT	\N	PRESENT	0
378835	378827	11048N	PARTICIPANT	\N	PRESENT	0
378836	378827	14213J	PARTICIPANT	\N	PRESENT	0
378837	378827	19511N	PARTICIPANT	\N	PRESENT	0
378838	378827	08015R	PARTICIPANT	\N	PRESENT	0
378839	378827	19441R	PARTICIPANT	\N	PRESENT	0
378840	378827	08012N	PARTICIPANT	\N	PRESENT	0
378841	378827	19563B	PARTICIPANT	\N	PRESENT	0
378842	378827	14257W	PARTICIPANT	\N	PRESENT	0
378843	378827	14265W	PARTICIPANT	\N	PRESENT	0
378844	378827	04088S	PARTICIPANT	\N	PRESENT	0
378845	378827	14135M	PARTICIPANT	\N	PRESENT	0
378846	378827	19269X	PARTICIPANT	\N	PRESENT	0
378847	378827	11097X	PARTICIPANT	\N	PRESENT	0
378848	378827	19762G	PARTICIPANT	\N	PRESENT	0
378935	378933	11090Q	PARTICIPANT	\N	PRESENT	0
378934	378933	14187A	PARTICIPANT	\N	PRESENT	0
378937	378936	19295A	PARTICIPANT	\N	PRESENT	0
378938	378936	14187A	PARTICIPANT	\N	PRESENT	0
378940	378936	11090Q	PARTICIPANT	\N	PRESENT	0
379075	379056	19515S	PARTICIPANT	\N	PRESENT	0
379077	379056	11056N	PARTICIPANT	\N	PRESENT	0
379078	379056	19369B	PARTICIPANT	\N	PRESENT	0
379079	379056	19269X	PARTICIPANT	\N	PRESENT	0
379081	379056	19705W	PARTICIPANT	\N	PRESENT	0
379084	379056	08062Y	PARTICIPANT	\N	PRESENT	0
379085	379056	11090Q	PARTICIPANT	\N	PRESENT	0
379103	379099	19515S	PARTICIPANT	\N	PRESENT	0
379107	379099	19369B	PARTICIPANT	\N	PRESENT	0
379108	379099	08062Y	PARTICIPANT	\N	PRESENT	0
379116	379099	19705W	PARTICIPANT	\N	PRESENT	0
382286	382285	14205J	PARTICIPANT	\N	PRESENT	0
382293	378929	19709B	PARTICIPANT	\N	EXCUSE	0
382294	378929	19669L	PARTICIPANT	\N	EXCUSE	0
382295	378929	11066Q	PARTICIPANT	\N	EXCUSE	0
382780	382779	11053K	PARTICIPANT	\N	PRESENT	0
382782	382781	11053K	PARTICIPANT	\N	PRESENT	0
382783	376926	19729F	PARTICIPANT	\N	EXCUSE	0
382935	382934	08009T	PARTICIPANT	\N	PRESENT	0
382936	382934	14038Y	PARTICIPANT	\N	PRESENT	0
382937	382934	04085P	PARTICIPANT	\N	PRESENT	0
382938	382934	19713W	PARTICIPANT	\N	PRESENT	0
382940	382934	19333N	PARTICIPANT	\N	PRESENT	0
375713	371423	08028W	PARTICIPANT	\N	PRESENT	0
375714	371423	14257W	PARTICIPANT	\N	PRESENT	0
375715	371423	14197C	PARTICIPANT	\N	PRESENT	0
375716	371423	19611R	PARTICIPANT	\N	PRESENT	0
375717	371423	19691J	PARTICIPANT	\N	PRESENT	0
375718	371423	14207L	PARTICIPANT	\N	PRESENT	0
375719	371423	11099A	PARTICIPANT	\N	PRESENT	0
375720	371423	95037J	PARTICIPANT	\N	PRESENT	0
375721	371423	19413M	PARTICIPANT	\N	PRESENT	0
375722	371423	14083S	PARTICIPANT	\N	PRESENT	0
375728	371423	19507S	PARTICIPANT	\N	PRESENT	0
375730	371423	19467C	PARTICIPANT	\N	PRESENT	0
375731	371423	08020N	PARTICIPANT	\N	PRESENT	0
375732	371423	11101A	PARTICIPANT	\N	PRESENT	0
375733	371423	11083R	PARTICIPANT	\N	PRESENT	0
375734	371423	04088S	PARTICIPANT	\N	PRESENT	0
375735	371423	19695N	PARTICIPANT	\N	PRESENT	0
375736	371423	14135M	PARTICIPANT	\N	PRESENT	0
375737	371423	11090Q	PARTICIPANT	\N	PRESENT	0
375739	371423	14237S	PARTICIPANT	\N	PRESENT	0
375822	371424	19413M	PARTICIPANT	\N	PRESENT	0
375823	371424	14197C	PARTICIPANT	\N	PRESENT	0
375824	371424	14028W	PARTICIPANT	\N	PRESENT	0
375825	371424	14063N	PARTICIPANT	\N	PRESENT	0
375826	371424	19631V	PARTICIPANT	\N	PRESENT	0
375827	371424	11104D	PARTICIPANT	\N	PRESENT	0
375828	371424	19725B	PARTICIPANT	\N	PRESENT	0
375829	371424	14257W	PARTICIPANT	\N	PRESENT	0
375830	371424	08045X	PARTICIPANT	\N	PRESENT	0
375831	371424	11090Q	PARTICIPANT	\N	PRESENT	0
375832	371424	14026U	PARTICIPANT	\N	PRESENT	0
375833	371424	14033T	PARTICIPANT	\N	PRESENT	0
375834	371424	19782L	PARTICIPANT	\N	PRESENT	0
375835	371424	19387D	PARTICIPANT	\N	PRESENT	0
375836	371424	14207L	PARTICIPANT	\N	PRESENT	0
375837	371424	11099A	PARTICIPANT	\N	PRESENT	0
375838	371424	19563B	PARTICIPANT	\N	PRESENT	0
375839	371424	14107H	PARTICIPANT	\N	PRESENT	0
375840	371424	14201E	PARTICIPANT	\N	PRESENT	0
375841	371424	19629C	PARTICIPANT	\N	PRESENT	0
375842	371424	19719D	PARTICIPANT	\N	PRESENT	0
375843	371424	11083R	PARTICIPANT	\N	PRESENT	0
375844	371424	11072N	PARTICIPANT	\N	PRESENT	0
375845	371424	19691J	PARTICIPANT	\N	PRESENT	0
375846	371424	14042U	PARTICIPANT	\N	PRESENT	0
375847	371424	19479G	PARTICIPANT	\N	PRESENT	0
375848	371424	19441R	PARTICIPANT	\N	PRESENT	0
375849	371424	14083S	PARTICIPANT	\N	PRESENT	0
375850	371424	19745F	PARTICIPANT	\N	PRESENT	0
375851	371424	14215L	PARTICIPANT	\N	PRESENT	0
375852	371424	19798U	PARTICIPANT	\N	PRESENT	0
375853	371424	08034U	PARTICIPANT	\N	PRESENT	0
375854	371424	97011G	PARTICIPANT	\N	PRESENT	0
375855	371424	19675J	PARTICIPANT	\N	PRESENT	0
375856	371424	19762G	PARTICIPANT	\N	PRESENT	0
375857	371424	19733B	PARTICIPANT	\N	PRESENT	0
375858	371424	14237S	PARTICIPANT	\N	PRESENT	0
375859	371424	19768N	PARTICIPANT	\N	PRESENT	0
375860	371424	08015R	PARTICIPANT	\N	PRESENT	0
375861	371424	14265W	PARTICIPANT	\N	PRESENT	0
375862	371424	14357A	PARTICIPANT	\N	PRESENT	0
375863	371424	14223L	PARTICIPANT	\N	PRESENT	0
375864	371424	08028W	PARTICIPANT	\N	PRESENT	0
375865	371424	08056B	PARTICIPANT	\N	PRESENT	0
375866	371424	08069G	PARTICIPANT	\N	PRESENT	0
375867	371424	99004R	PARTICIPANT	\N	PRESENT	0
375868	371424	96004D	PARTICIPANT	\N	PRESENT	0
375869	371424	19731Y	PARTICIPANT	\N	PRESENT	0
375870	371424	14135M	PARTICIPANT	\N	PRESENT	0
375871	371424	14115H	PARTICIPANT	\N	PRESENT	0
375872	371424	14041T	PARTICIPANT	\N	PRESENT	0
375873	371424	19507S	PARTICIPANT	\N	PRESENT	0
375874	371424	04088S	PARTICIPANT	\N	PRESENT	0
375875	371424	14133K	PARTICIPANT	\N	PRESENT	0
375876	371424	14029X	PARTICIPANT	\N	PRESENT	0
375877	371424	14173T	PARTICIPANT	\N	PRESENT	0
375878	371424	19467C	PARTICIPANT	\N	PRESENT	0
375879	371424	11101A	PARTICIPANT	\N	PRESENT	0
375880	371424	19447X	PARTICIPANT	\N	PRESENT	0
375881	371424	19703U	PARTICIPANT	\N	PRESENT	0
375882	371424	19515S	PARTICIPANT	\N	PRESENT	0
375883	371424	14191V	PARTICIPANT	\N	PRESENT	0
375884	371424	04097T	PARTICIPANT	\N	PRESENT	0
375885	371424	95030B	PARTICIPANT	\N	PRESENT	0
375886	371424	19671E	PARTICIPANT	\N	PRESENT	0
375887	371424	19695N	PARTICIPANT	\N	PRESENT	0
375888	371424	19569H	PARTICIPANT	\N	PRESENT	0
375890	371424	01025N	PARTICIPANT	\N	PRESENT	0
375891	371424	08049C	PARTICIPANT	\N	PRESENT	0
375892	371424	14205J	PARTICIPANT	\N	PRESENT	0
375893	371424	19511N	PARTICIPANT	\N	PRESENT	0
375894	371424	14097Y	PARTICIPANT	\N	PRESENT	0
375895	371424	08068F	PARTICIPANT	\N	PRESENT	0
375896	371424	01057W	PARTICIPANT	\N	PRESENT	0
375897	371424	14219Q	PARTICIPANT	\N	PRESENT	0
375898	371424	14121F	PARTICIPANT	\N	PRESENT	0
375900	371424	08020N	PARTICIPANT	\N	PRESENT	0
375901	371424	01024M	PARTICIPANT	\N	PRESENT	0
375902	371424	04057K	PARTICIPANT	\N	PRESENT	0
375819	371424	04059M	PARTICIPANT	\N	PRESENT	0
375821	371424	11040E	PARTICIPANT	\N	PRESENT	0
375903	371424	14079W	PARTICIPANT	\N	PRESENT	0
375904	371424	19549D	PARTICIPANT	\N	PRESENT	0
375905	371424	14217N	PARTICIPANT	\N	PRESENT	0
375906	371424	14031R	PARTICIPANT	\N	PRESENT	0
375907	371424	14211G	PARTICIPANT	\N	PRESENT	0
375908	371424	14193X	PARTICIPANT	\N	PRESENT	0
375909	371424	14087W	PARTICIPANT	\N	PRESENT	0
375910	371424	08053X	PARTICIPANT	\N	PRESENT	0
375911	371424	11110B	PARTICIPANT	\N	PRESENT	0
375912	371424	19758L	PARTICIPANT	\N	PRESENT	0
375913	371424	95037J	PARTICIPANT	\N	PRESENT	0
375914	371424	14038Y	PARTICIPANT	\N	PRESENT	0
375915	371424	19443T	PARTICIPANT	\N	PRESENT	0
375916	371424	19794Q	PARTICIPANT	\N	PRESENT	0
375917	371424	19681G	PARTICIPANT	\N	PRESENT	0
375918	371424	19593H	PARTICIPANT	\N	PRESENT	0
375919	371424	14259Y	PARTICIPANT	\N	PRESENT	0
375920	371424	19349W	PARTICIPANT	\N	PRESENT	0
375921	371424	14275Y	PARTICIPANT	\N	PRESENT	0
375922	371424	14221J	PARTICIPANT	\N	PRESENT	0
376009	371425	19758L	PARTICIPANT	\N	PRESENT	0
376010	371425	14121F	PARTICIPANT	\N	PRESENT	0
376011	371425	14063N	PARTICIPANT	\N	PRESENT	0
376012	371425	19549D	PARTICIPANT	\N	PRESENT	0
376013	371425	11041F	PARTICIPANT	\N	PRESENT	0
376014	371425	95030B	PARTICIPANT	\N	PRESENT	0
376015	371425	04086Q	PARTICIPANT	\N	PRESENT	0
376016	371425	14191V	PARTICIPANT	\N	PRESENT	0
376017	371425	14259Y	PARTICIPANT	\N	PRESENT	0
376018	371425	14069U	PARTICIPANT	\N	PRESENT	0
376019	371425	19741B	PARTICIPANT	\N	PRESENT	0
376020	371425	14038Y	PARTICIPANT	\N	PRESENT	0
376021	371425	19467C	PARTICIPANT	\N	PRESENT	0
376022	371425	14031R	PARTICIPANT	\N	PRESENT	0
376023	371425	14041T	PARTICIPANT	\N	PRESENT	0
376024	371425	08062Y	PARTICIPANT	\N	PRESENT	0
376025	371425	19768N	PARTICIPANT	\N	PRESENT	0
376026	371425	14265W	PARTICIPANT	\N	PRESENT	0
376027	371425	19705W	PARTICIPANT	\N	PRESENT	0
376028	371425	08010L	PARTICIPANT	\N	PRESENT	0
376029	371425	14331P	PARTICIPANT	\N	PRESENT	0
376030	371425	14123H	PARTICIPANT	\N	PRESENT	0
376031	371425	14237S	PARTICIPANT	\N	PRESENT	0
376032	371425	18083K	PARTICIPANT	\N	PRESENT	0
376033	371425	08028W	PARTICIPANT	\N	PRESENT	0
376034	371425	11090Q	PARTICIPANT	\N	PRESENT	0
376035	371425	99004R	PARTICIPANT	\N	PRESENT	0
376036	371425	19679N	PARTICIPANT	\N	PRESENT	0
376037	371425	92040Q	PARTICIPANT	\N	PRESENT	0
376038	371425	14253S	PARTICIPANT	\N	PRESENT	0
376039	371425	11101A	PARTICIPANT	\N	PRESENT	0
376040	371425	19581D	PARTICIPANT	\N	PRESENT	0
376041	371425	19671E	PARTICIPANT	\N	PRESENT	0
376042	371425	04088S	PARTICIPANT	\N	PRESENT	0
376043	371425	11049P	PARTICIPANT	\N	PRESENT	0
376044	371425	19794Q	PARTICIPANT	\N	PRESENT	0
376045	371425	04047H	PARTICIPANT	\N	PRESENT	0
376046	371425	14357A	PARTICIPANT	\N	PRESENT	0
376047	371425	14211G	PARTICIPANT	\N	PRESENT	0
376048	371425	19693L	PARTICIPANT	\N	PRESENT	0
376049	371425	14087W	PARTICIPANT	\N	PRESENT	0
376050	371425	14355X	PARTICIPANT	\N	PRESENT	0
376051	371425	14053L	PARTICIPANT	\N	PRESENT	0
376052	371425	19507S	PARTICIPANT	\N	PRESENT	0
376053	371425	96004D	PARTICIPANT	\N	PRESENT	0
376054	371425	19663E	PARTICIPANT	\N	PRESENT	0
376055	371425	14029X	PARTICIPANT	\N	PRESENT	0
365630	345240	19727D	PARTICIPANT	\N	PRESENT	0
365641	365640	19758L	PARTICIPANT	\N	PRESENT	0
365642	365640	14241N	PARTICIPANT	\N	PRESENT	0
365643	365640	14073Q	PARTICIPANT	\N	PRESENT	0
365644	365640	14063N	PARTICIPANT	\N	PRESENT	0
365627	345240	19745F	PARTICIPANT	\N	PRESENT	0
365629	345240	19269X	PARTICIPANT	\N	PRESENT	0
373463	373462	19647E	PARTICIPANT	\N	PRESENT	0
373498	373497	11070L	PARTICIPANT	\N	PRESENT	0
373499	373497	19647E	PARTICIPANT	\N	PRESENT	0
373502	373500	11070L	PARTICIPANT	\N	PRESENT	0
373503	373500	19647E	PARTICIPANT	\N	PRESENT	0
373525	373524	14173T	PARTICIPANT	\N	PRESENT	0
373537	370843	11109J	PARTICIPANT	\N	EXCUSE	0
373538	370843	14261S	PARTICIPANT	\N	PRESENT	0
373539	370843	19577H	PARTICIPANT	\N	EXCUSE	0
373540	370843	14259Y	PARTICIPANT	\N	EXCUSE	0
373541	370843	19329S	PARTICIPANT	\N	EXCUSE	0
373542	370843	08019V	PRESIDENT	0	PRESENT	0
373543	370843	19657G	PARTICIPANT	\N	EXCUSE	0
373544	370843	14331P	PARTICIPANT	\N	PRESENT	0
373546	370843	19729F	PARTICIPANT	\N	EXCUSE	0
373547	356669	14259Y	PARTICIPANT	\N	EXCUSE	0
373563	373562	08069G	PARTICIPANT	\N	PRESENT	0
373565	373564	14199E	PARTICIPANT	\N	PRESENT	0
373567	373566	14331P	PARTICIPANT	\N	PRESENT	0
373569	373568	14331P	PARTICIPANT	\N	PRESENT	0
373571	373570	14253S	PARTICIPANT	\N	PRESENT	0
373572	373570	14085U	PARTICIPANT	\N	PRESENT	0
379735	371484	19701S	PARTICIPANT	\N	PRESENT	0
379736	371484	98050T	PARTICIPANT	\N	PRESENT	0
379737	371484	14281W	PARTICIPANT	\N	PRESENT	0
379738	371484	11101A	PARTICIPANT	\N	PRESENT	0
379739	371484	08034U	PARTICIPANT	\N	PRESENT	0
379740	371484	08035V	PARTICIPANT	\N	PRESENT	0
379741	371484	14039A	PARTICIPANT	\N	PRESENT	0
379742	371484	19663E	PARTICIPANT	\N	PRESENT	0
379743	371484	19335Q	PARTICIPANT	\N	PRESENT	0
379747	371484	19399H	PARTICIPANT	\N	PRESENT	0
379748	371484	19347U	PARTICIPANT	\N	PRESENT	0
379749	371484	19695N	PARTICIPANT	\N	PRESENT	0
379750	371484	11033F	PARTICIPANT	\N	PRESENT	0
379751	371484	14089Y	PARTICIPANT	\N	PRESENT	0
379752	371484	11099A	PARTICIPANT	\N	PRESENT	0
379753	371484	07029T	PARTICIPANT	\N	PRESENT	0
379754	371484	19657G	PARTICIPANT	\N	PRESENT	0
379757	371484	14119M	PARTICIPANT	\N	PRESENT	0
379758	371484	11031D	PARTICIPANT	\N	PRESENT	0
379759	371484	04057K	PARTICIPANT	\N	PRESENT	0
379760	371484	11109J	PARTICIPANT	\N	PRESENT	0
379761	371484	04086Q	PARTICIPANT	\N	PRESENT	0
379762	371484	01048V	PARTICIPANT	\N	PRESENT	0
379764	371484	11048N	PARTICIPANT	\N	PRESENT	0
379769	371484	19762G	PARTICIPANT	\N	PRESENT	0
379770	371484	19503N	PARTICIPANT	\N	PRESENT	0
379840	371485	04070G	PARTICIPANT	\N	PRESENT	0
379841	371485	19347U	PARTICIPANT	\N	PRESENT	0
379842	371485	19758L	PARTICIPANT	\N	PRESENT	0
379843	371485	14229S	PARTICIPANT	\N	PRESENT	0
379844	371485	08043V	PARTICIPANT	\N	PRESENT	0
379845	371485	19301E	PARTICIPANT	\N	PRESENT	0
379846	371485	11099A	PARTICIPANT	\N	PRESENT	0
379847	371485	14251Q	PARTICIPANT	\N	PRESENT	0
379848	371485	98005N	PARTICIPANT	\N	PRESENT	0
379849	371485	08031R	PARTICIPANT	\N	PRESENT	0
379850	371485	14281W	PARTICIPANT	\N	PRESENT	0
379851	371485	19611R	PARTICIPANT	\N	PRESENT	0
379852	371485	14039A	PARTICIPANT	\N	PRESENT	0
379853	371485	19335Q	PARTICIPANT	\N	PRESENT	0
379854	371485	14061L	PARTICIPANT	\N	PRESENT	0
379855	371485	07029T	PARTICIPANT	\N	PRESENT	0
379856	371485	19657G	PARTICIPANT	\N	PRESENT	0
379857	371485	19663E	PARTICIPANT	\N	PRESENT	0
379858	371485	19667J	PARTICIPANT	\N	PRESENT	0
379859	371485	19693L	PARTICIPANT	\N	PRESENT	0
379860	371485	14071N	PARTICIPANT	\N	PRESENT	0
379861	371485	19711U	PARTICIPANT	\N	PRESENT	0
379862	371485	19593H	PARTICIPANT	\N	PRESENT	0
379863	371485	11043H	PARTICIPANT	\N	PRESENT	0
379864	371485	14123H	PARTICIPANT	\N	PRESENT	0
379865	371485	14231L	PARTICIPANT	\N	PRESENT	0
379866	371485	04086Q	PARTICIPANT	\N	PRESENT	0
379867	371485	08024S	PARTICIPANT	\N	PRESENT	0
379868	371485	19573D	PARTICIPANT	\N	PRESENT	0
379869	371485	19577H	PARTICIPANT	\N	PRESENT	0
379870	371485	19647E	PARTICIPANT	\N	PRESENT	0
379871	371485	19503N	PARTICIPANT	\N	PRESENT	0
379872	371485	14109K	PARTICIPANT	\N	PRESENT	0
379873	371485	08017T	PARTICIPANT	\N	PRESENT	0
379874	371485	19715Y	PARTICIPANT	\N	PRESENT	0
379875	371485	11048N	PARTICIPANT	\N	PRESENT	0
379876	371485	19629C	PARTICIPANT	\N	PRESENT	0
379877	371485	08019V	PARTICIPANT	\N	PRESENT	0
379878	371485	14119M	PARTICIPANT	\N	PRESENT	0
379879	371485	11109J	PARTICIPANT	\N	PRESENT	0
379880	371485	19669L	PARTICIPANT	\N	PRESENT	0
379881	371485	14241N	PARTICIPANT	\N	PRESENT	0
379882	371485	19399H	PARTICIPANT	\N	PRESENT	0
379883	371485	11012A	PARTICIPANT	\N	PRESENT	0
379884	371485	19735D	PARTICIPANT	\N	PRESENT	0
379838	371485	14034U	PARTICIPANT	\N	PRESENT	0
379839	371485	19621T	PARTICIPANT	\N	PRESENT	0
379885	371485	14219Q	PARTICIPANT	\N	PRESENT	0
379920	373760	14093U	PARTICIPANT	\N	PRESENT	0
379921	373760	80013X	PARTICIPANT	\N	PRESENT	0
379922	373760	19723Y	PARTICIPANT	\N	EXCUSE	0
379923	373760	01048V	PRESIDENT	0	PRESENT	0
379924	373760	19533U	PARTICIPANT	\N	PRESENT	0
379925	373760	19503N	PARTICIPANT	\N	PRESENT	0
379926	373760	04043D	PARTICIPANT	\N	EXCUSE	0
379927	373760	01058X	PARTICIPANT	\N	PRESENT	0
379932	373760	14299H	PARTICIPANT	\N	EXCUSE	0
379962	379961	11065P	PARTICIPANT	\N	PRESENT	0
379963	379961	14107H	PARTICIPANT	\N	PRESENT	0
379992	379991	89017R	PARTICIPANT	\N	PRESENT	0
379993	379991	04085P	PARTICIPANT	\N	PRESENT	0
379994	379991	04059M	PARTICIPANT	\N	PRESENT	0
379995	379991	05008E	PARTICIPANT	\N	PRESENT	0
379996	379991	96004D	PARTICIPANT	\N	PRESENT	0
379997	379991	04042C	PARTICIPANT	\N	PRESENT	0
379998	379991	11027H	PARTICIPANT	\N	PRESENT	0
379999	379991	04086Q	PARTICIPANT	\N	PRESENT	0
380000	379991	14079W	PARTICIPANT	\N	PRESENT	0
380001	379991	11074Q	PARTICIPANT	\N	PRESENT	0
380002	379991	14034U	PARTICIPANT	\N	PRESENT	0
380003	379991	14021P	PARTICIPANT	\N	PRESENT	0
380004	379991	14073Q	PARTICIPANT	\N	PRESENT	0
380005	379991	14251Q	PARTICIPANT	\N	PRESENT	0
380006	379991	08009T	PARTICIPANT	\N	PRESENT	0
380007	379991	04092N	PARTICIPANT	\N	PRESENT	0
380008	379991	11072N	PARTICIPANT	\N	PRESENT	0
380009	379991	08011M	PARTICIPANT	\N	PRESENT	0
380010	379991	04070G	PARTICIPANT	\N	PRESENT	0
380011	379991	14071N	PARTICIPANT	\N	PRESENT	0
380012	379991	08061X	PARTICIPANT	\N	PRESENT	0
380013	379991	05012A	PARTICIPANT	\N	PRESENT	0
380014	379991	11090Q	PARTICIPANT	\N	PRESENT	0
380015	379991	11012A	PARTICIPANT	\N	PRESENT	0
380017	379991	04044E	PARTICIPANT	\N	PRESENT	0
380165	380164	96004D	PRESIDENT	0	PRESENT	0
380166	380164	14255U	PARTICIPANT	\N	PRESENT	0
380167	380164	04097T	PARTICIPANT	\N	PRESENT	0
380168	380164	14073Q	PARTICIPANT	\N	PRESENT	0
380169	380164	14001X	PARTICIPANT	\N	PRESENT	0
380170	380164	98050T	PRESIDENT	1	PRESENT	0
380171	380164	14097Y	PARTICIPANT	\N	PRESENT	0
380172	380164	14053L	PARTICIPANT	\N	PRESENT	0
380334	380333	04038G	PARTICIPANT	\N	PRESENT	0
380335	380333	99004R	PRESIDENT	0	PRESENT	0
381734	381733	14030Q	PARTICIPANT	\N	PRESENT	0
381735	381733	19701S	PARTICIPANT	\N	PRESENT	0
381736	381733	08031R	PARTICIPANT	\N	PRESENT	0
381737	381733	11045K	PARTICIPANT	\N	PRESENT	0
381977	378924	19709B	PARTICIPANT	\N	EXCUSE	0
381978	378924	19669L	PARTICIPANT	\N	EXCUSE	0
381979	378924	08049C	PARTICIPANT	\N	EXCUSE	0
381980	378924	11066Q	PARTICIPANT	\N	EXCUSE	0
382617	382616	14215L	PARTICIPANT	\N	PRESENT	0
382618	382616	14179A	PARTICIPANT	\N	PRESENT	0
382619	382616	14001X	PARTICIPANT	\N	PRESENT	0
382620	382616	19543W	PARTICIPANT	\N	PRESENT	0
382621	382616	14151M	PARTICIPANT	\N	PRESENT	0
382623	382622	14215L	PARTICIPANT	\N	PRESENT	0
382624	382622	14179A	PARTICIPANT	\N	PRESENT	0
382625	382622	14001X	PARTICIPANT	\N	PRESENT	0
382626	382622	14151M	PARTICIPANT	\N	PRESENT	0
382628	382627	14215L	PARTICIPANT	\N	PRESENT	0
377858	377745	02002K	PARTICIPANT	\N	PRESENT	0
377859	377745	14237S	PARTICIPANT	\N	PRESENT	0
377860	377745	05012A	PARTICIPANT	\N	PRESENT	0
377861	377745	14029X	PARTICIPANT	\N	PRESENT	0
377862	377745	14051J	PARTICIPANT	\N	PRESENT	0
377863	377745	08060W	PARTICIPANT	\N	PRESENT	0
377864	377745	19733B	PARTICIPANT	\N	PRESENT	0
377865	377745	08009T	PRESIDENT	0	PRESENT	0
377866	377745	19503N	PARTICIPANT	\N	PRESENT	0
377867	377745	19347U	PARTICIPANT	\N	PRESENT	0
377868	377745	14157T	PARTICIPANT	\N	PRESENT	0
377869	377745	19659J	PARTICIPANT	\N	PRESENT	0
377870	377745	11065P	PARTICIPANT	\N	PRESENT	0
377871	377745	19525U	PARTICIPANT	\N	PRESENT	0
377872	377745	95062K	PARTICIPANT	\N	EXCUSE	0
377873	377745	19745F	PARTICIPANT	\N	EXCUSE	0
377874	377745	19681G	PARTICIPANT	\N	EXCUSE	0
377875	376605	19705W	PARTICIPANT	\N	PRESENT	0
377876	376605	08015R	PARTICIPANT	\N	PRESENT	0
377877	376605	19369B	PARTICIPANT	\N	PRESENT	0
377878	376605	19563B	PARTICIPANT	\N	PRESENT	0
377879	376605	14265W	PARTICIPANT	\N	PRESENT	0
377880	376605	14207L	PARTICIPANT	\N	PRESENT	0
377881	376605	19747H	PARTICIPANT	\N	PRESENT	0
377882	376605	17589D	PARTICIPANT	\N	PRESENT	0
377883	377745	19794Q	PARTICIPANT	\N	PRESENT	0
377884	377745	14219Q	PARTICIPANT	\N	PRESENT	0
377885	377745	14221J	PARTICIPANT	\N	PRESENT	0
377886	377745	19713W	PARTICIPANT	\N	PRESENT	0
377887	377745	19737F	PARTICIPANT	\N	PRESENT	0
377888	377745	19739H	PARTICIPANT	\N	PRESENT	0
377889	377745	04097T	PARTICIPANT	\N	PRESENT	0
377890	377745	17637T	PARTICIPANT	\N	PRESENT	0
377891	377745	14093U	PARTICIPANT	\N	PRESENT	0
377892	377745	19685L	PARTICIPANT	\N	EXCUSE	0
377893	376605	08028W	PARTICIPANT	\N	PRESENT	0
377894	376605	14135M	PARTICIPANT	\N	PRESENT	0
377895	376605	19507S	PARTICIPANT	\N	PRESENT	0
377896	376605	04043D	PARTICIPANT	\N	PRESENT	0
377897	376740	98022P	PARTICIPANT	\N	PRESENT	0
377898	376605	19782L	PARTICIPANT	\N	PRESENT	0
377899	377745	14031R	PARTICIPANT	\N	PRESENT	0
377900	376740	11027H	PARTICIPANT	\N	PRESENT	0
377901	376740	14133K	PARTICIPANT	\N	PRESENT	0
377902	376605	14257W	PARTICIPANT	\N	PRESENT	0
377903	376605	11099A	PARTICIPANT	\N	PRESENT	0
377906	376986	19573D	PARTICIPANT	\N	PRESENT	0
377907	376986	08017T	PARTICIPANT	\N	PRESENT	0
377908	376986	07033P	PARTICIPANT	\N	PRESENT	0
377909	376986	19335Q	PARTICIPANT	\N	PRESENT	0
377910	376986	14249W	PARTICIPANT	\N	PRESENT	0
377911	376986	14059S	PARTICIPANT	\N	PRESENT	0
377912	376986	14251Q	PARTICIPANT	\N	PRESENT	0
377913	376986	11109J	PARTICIPANT	\N	PRESENT	0
377914	376986	11043H	PARTICIPANT	\N	PRESENT	0
377915	376986	19766L	PARTICIPANT	\N	EXCUSE	0
377921	376740	19669L	PARTICIPANT	\N	PRESENT	0
377923	376605	19695N	PARTICIPANT	\N	PRESENT	0
377924	376605	11056N	PARTICIPANT	\N	PRESENT	0
377972	376986	19533U	PARTICIPANT	\N	PRESENT	0
377973	376986	08035V	PARTICIPANT	\N	PRESENT	0
377974	376986	14109K	PARTICIPANT	\N	PRESENT	0
377985	377745	19551W	PARTICIPANT	\N	PRESENT	0
377986	377745	80027E	PARTICIPANT	\N	PRESENT	0
377987	377745	08024S	PARTICIPANT	\N	PRESENT	0
377988	377745	14103D	PARTICIPANT	\N	PRESENT	0
377989	377745	08055A	PARTICIPANT	\N	PRESENT	0
377990	377745	15447F	PARTICIPANT	\N	PRESENT	0
377991	376605	14357A	PARTICIPANT	\N	PRESENT	0
378007	377784	01060R	PARTICIPANT	\N	PRESENT	0
378008	377784	14001X	PARTICIPANT	\N	PRESENT	0
378009	377784	19543W	PARTICIPANT	\N	PRESENT	0
378010	377784	04044E	PARTICIPANT	\N	PRESENT	0
378011	377784	19581D	PARTICIPANT	\N	PRESENT	0
378012	377784	04047H	PARTICIPANT	\N	PRESENT	0
378013	377784	19673G	PARTICIPANT	\N	PRESENT	0
378014	377784	19675J	PARTICIPANT	\N	PRESENT	0
378015	377784	01028R	PARTICIPANT	\N	PRESENT	0
378016	377784	19447X	PARTICIPANT	\N	PRESENT	0
378017	377784	05008E	PRESIDENT	0	PRESENT	0
378018	377784	14231L	PARTICIPANT	\N	PRESENT	0
378019	377784	19489J	PARTICIPANT	\N	PRESENT	0
378020	377784	14041T	PARTICIPANT	\N	PRESENT	0
378021	377784	14147R	PARTICIPANT	\N	PRESENT	0
378022	377784	14179A	PARTICIPANT	\N	PRESENT	0
378023	377784	14151M	PARTICIPANT	\N	PRESENT	0
378024	377784	14215L	PARTICIPANT	\N	PRESENT	0
378025	377784	08018U	PARTICIPANT	\N	PRESENT	0
378026	377784	14259Y	PARTICIPANT	\N	PRESENT	0
378027	377784	11072N	PARTICIPANT	\N	PRESENT	0
378028	377784	98035U	PARTICIPANT	\N	PRESENT	0
378029	377784	14053L	PARTICIPANT	\N	PRESENT	0
378030	377784	14111D	PARTICIPANT	\N	PRESENT	0
378031	377784	14065Q	PARTICIPANT	\N	PRESENT	0
378032	377784	10015M	PARTICIPANT	\N	PRESENT	0
378033	377784	11026G	PARTICIPANT	\N	PRESENT	0
378034	377784	08045X	PARTICIPANT	\N	PRESENT	0
378035	377784	19253P	PARTICIPANT	\N	PRESENT	0
378036	377784	01024M	PARTICIPANT	\N	PRESENT	0
378037	377784	19719D	PARTICIPANT	\N	PRESENT	0
378038	377784	11033F	PARTICIPANT	\N	PRESENT	0
378039	377784	19725B	PARTICIPANT	\N	PRESENT	0
378040	377784	14089Y	PARTICIPANT	\N	PRESENT	0
378041	377784	19729F	PARTICIPANT	\N	PRESENT	0
378042	377784	95063L	PARTICIPANT	\N	PRESENT	0
378043	377784	19629C	PARTICIPANT	\N	PRESENT	0
378044	377784	08044W	PARTICIPANT	\N	PRESENT	0
378045	377784	14069U	PARTICIPANT	\N	PRESENT	0
378046	377784	11085T	PARTICIPANT	\N	PRESENT	0
378047	377784	11049P	PARTICIPANT	\N	PRESENT	0
378048	377784	04008A	PARTICIPANT	\N	PRESENT	0
378049	377784	14021P	PARTICIPANT	\N	PRESENT	0
378050	377784	19762G	PARTICIPANT	\N	PRESENT	0
378056	377013	19545Y	PARTICIPANT	\N	PRESENT	0
378057	377013	01057W	PARTICIPANT	\N	PRESENT	0
378058	377013	89017R	PARTICIPANT	\N	PRESENT	0
378059	377013	11070L	PARTICIPANT	\N	PRESENT	0
378060	377013	08010L	PARTICIPANT	\N	PRESENT	0
378061	377013	19647E	PARTICIPANT	\N	PRESENT	0
378062	377013	19651A	PARTICIPANT	\N	PRESENT	0
378063	377013	12016W	PARTICIPANT	\N	PRESENT	0
378064	377013	14034U	PARTICIPANT	\N	PRESENT	0
378065	377013	04061F	PARTICIPANT	\N	PRESENT	0
378066	377013	19687N	PARTICIPANT	\N	EXCUSE	0
378067	375457	04045F	PARTICIPANT	\N	PRESENT	0
378068	375457	19521Q	PARTICIPANT	\N	PRESENT	0
378069	375457	19527W	PARTICIPANT	\N	PRESENT	0
378070	375457	19301E	PARTICIPANT	\N	PRESENT	0
378071	375457	19715Y	PARTICIPANT	\N	PRESENT	0
378072	375457	19717B	PARTICIPANT	\N	PRESENT	0
378118	377015	08011M	PARTICIPANT	\N	PRESENT	0
378119	377785	19543W	PARTICIPANT	\N	PRESENT	0
378120	377785	04044E	PARTICIPANT	\N	PRESENT	0
378121	377785	19581D	PARTICIPANT	\N	PRESENT	0
378122	377785	04047H	PARTICIPANT	\N	PRESENT	0
378123	377785	19675J	PARTICIPANT	\N	PRESENT	0
378124	377785	01028R	PARTICIPANT	\N	PRESENT	0
378125	377785	05008E	PRESIDENT	0	PRESENT	0
378126	377785	19447X	PARTICIPANT	\N	PRESENT	0
378127	377785	14231L	PARTICIPANT	\N	PRESENT	0
378128	377785	14041T	PARTICIPANT	\N	PRESENT	0
378129	377785	14179A	PARTICIPANT	\N	PRESENT	0
378130	377785	14147R	PARTICIPANT	\N	PRESENT	0
378131	377785	14215L	PARTICIPANT	\N	PRESENT	0
378132	377785	08018U	PARTICIPANT	\N	PRESENT	0
378133	377785	14259Y	PARTICIPANT	\N	PRESENT	0
378134	377785	14053L	PARTICIPANT	\N	PRESENT	0
378135	377785	14111D	PARTICIPANT	\N	PRESENT	0
378136	377785	08045X	PARTICIPANT	\N	PRESENT	0
378137	377785	10015M	PARTICIPANT	\N	PRESENT	0
378138	377785	01024M	PARTICIPANT	\N	PRESENT	0
378139	377785	19719D	PARTICIPANT	\N	PRESENT	0
378140	377785	19725B	PARTICIPANT	\N	PRESENT	0
378141	377785	19729F	PARTICIPANT	\N	PRESENT	0
378142	377785	08044W	PARTICIPANT	\N	PRESENT	0
378143	377785	14069U	PARTICIPANT	\N	PRESENT	0
378144	377785	11049P	PARTICIPANT	\N	PRESENT	0
378145	377785	14021P	PARTICIPANT	\N	PRESENT	0
378146	377785	19762G	PARTICIPANT	\N	PRESENT	0
378147	377785	98035U	PARTICIPANT	\N	PRESENT	0
378148	377785	19489J	PARTICIPANT	\N	PRESENT	0
378149	377785	95063L	PARTICIPANT	\N	PRESENT	0
378150	377785	11072N	PARTICIPANT	\N	PRESENT	0
378443	377016	01048V	PARTICIPANT	\N	PRESENT	0
378444	377016	19545Y	PARTICIPANT	\N	PRESENT	0
378447	377016	07004J	PARTICIPANT	\N	PRESENT	0
369307	357139	11097X	PARTICIPANT	\N	PRESENT	0
369300	366781	11097X	PARTICIPANT	\N	PRESENT	0
369306	357139	14147R	PARTICIPANT	\N	PRESENT	0
369308	356820	14147R	PARTICIPANT	\N	PRESENT	0
369309	356820	11097X	PARTICIPANT	\N	PRESENT	0
369310	361725	14147R	PARTICIPANT	\N	PRESENT	0
369311	361725	11097X	PARTICIPANT	\N	PRESENT	0
379940	378657	14241N	PARTICIPANT	\N	PRESENT	0
378461	371476	19479G	PARTICIPANT	\N	PRESENT	0
378462	371476	19711U	PARTICIPANT	\N	PRESENT	0
378465	371476	88008L	PARTICIPANT	\N	PRESENT	0
378466	371476	11012A	PARTICIPANT	\N	PRESENT	0
378467	371476	19489J	PARTICIPANT	\N	PRESENT	0
378468	371476	08062Y	PARTICIPANT	\N	PRESENT	0
378469	371476	19349W	PARTICIPANT	\N	PRESENT	0
378470	371476	11031D	PARTICIPANT	\N	PRESENT	0
378471	371476	07029T	PARTICIPANT	\N	PRESENT	0
379351	379350	14030Q	PRESIDENT	0	PRESENT	0
379352	379350	19701S	PARTICIPANT	\N	PRESENT	0
379353	379350	11031D	PARTICIPANT	\N	PRESENT	0
379354	379350	80013X	PARTICIPANT	\N	PRESENT	0
379355	379350	19715Y	PARTICIPANT	\N	PRESENT	0
379356	379350	07029T	PARTICIPANT	\N	PRESENT	0
379357	379350	11067R	PARTICIPANT	\N	PRESENT	0
379358	379350	14235Q	PARTICIPANT	\N	PRESENT	0
379359	379350	01043Q	PARTICIPANT	\N	EXCUSE	0
379360	379350	14109K	PARTICIPANT	\N	EXCUSE	0
379361	379350	11043H	PARTICIPANT	\N	PRESENT	0
379362	379350	14073Q	PARTICIPANT	\N	PRESENT	0
379886	378657	11072N	PARTICIPANT	\N	PRESENT	0
379897	378657	19621T	PARTICIPANT	\N	PRESENT	0
379898	378657	08043V	PARTICIPANT	\N	PRESENT	0
379899	378657	14229S	PARTICIPANT	\N	PRESENT	0
379900	378657	19593H	PARTICIPANT	\N	PRESENT	0
379901	378657	19758L	PARTICIPANT	\N	PRESENT	0
379902	378657	14039A	PARTICIPANT	\N	PRESENT	0
379903	378657	11065P	PARTICIPANT	\N	PRESENT	0
379904	378657	14281W	PARTICIPANT	\N	PRESENT	0
379905	378657	19749K	PARTICIPANT	\N	PRESENT	0
379906	378657	19335Q	PARTICIPANT	\N	PRESENT	0
379907	378657	19611R	PARTICIPANT	\N	PRESENT	0
379908	378657	14219Q	PARTICIPANT	\N	PRESENT	0
379909	378657	19693L	PARTICIPANT	\N	PRESENT	0
379910	378657	14123H	PARTICIPANT	\N	PRESENT	0
379911	378657	19399H	PARTICIPANT	\N	PRESENT	0
379912	378657	04086Q	PARTICIPANT	\N	PRESENT	0
379913	378657	98005N	PARTICIPANT	\N	PRESENT	0
379914	378657	08031R	PARTICIPANT	\N	PRESENT	0
379915	378657	14109K	PARTICIPANT	\N	PRESENT	0
379939	378657	11109J	PARTICIPANT	\N	PRESENT	0
379919	378657	19735D	PARTICIPANT	\N	PRESENT	0
379928	378657	19689Q	PARTICIPANT	\N	PRESENT	0
379956	378657	01028R	PARTICIPANT	\N	PRESENT	0
379959	378657	19711U	PARTICIPANT	\N	PRESENT	0
379960	378657	19533U	PARTICIPANT	\N	PRESENT	0
379964	378657	19651A	PARTICIPANT	\N	PRESENT	0
379965	378657	11031D	PARTICIPANT	\N	PRESENT	0
379974	378657	08035V	PARTICIPANT	\N	PRESENT	0
379975	378657	19695N	PARTICIPANT	\N	PRESENT	0
379976	378657	14251Q	PARTICIPANT	\N	PRESENT	0
379977	378657	19583F	PARTICIPANT	\N	PRESENT	0
379978	378657	04035D	PARTICIPANT	\N	PRESENT	0
379979	378657	19657G	PARTICIPANT	\N	PRESENT	0
379980	378657	19301E	PARTICIPANT	\N	PRESENT	0
379983	378657	14231L	PARTICIPANT	\N	PRESENT	0
379984	378657	08024S	PARTICIPANT	\N	PRESENT	0
379986	378657	19503N	PARTICIPANT	\N	PRESENT	0
379987	378657	19669L	PARTICIPANT	\N	PRESENT	0
379988	378657	14119M	PARTICIPANT	\N	PRESENT	0
379989	378657	17637T	PARTICIPANT	\N	PRESENT	0
379990	378657	19715Y	PARTICIPANT	\N	PRESENT	0
380016	378657	19782L	PARTICIPANT	\N	PRESENT	0
380018	378657	99004R	PARTICIPANT	\N	PRESENT	0
380019	378657	04085P	PARTICIPANT	\N	PRESENT	0
380039	378657	19649G	PARTICIPANT	\N	PRESENT	0
380093	378658	04070G	PARTICIPANT	\N	PRESENT	0
380108	378658	14109K	PARTICIPANT	\N	PRESENT	0
380109	378658	14041T	PARTICIPANT	\N	PRESENT	0
380110	378658	08024S	PARTICIPANT	\N	PRESENT	0
380111	378658	14219Q	PARTICIPANT	\N	PRESENT	0
380112	378658	19758L	PARTICIPANT	\N	PRESENT	0
380113	378658	19611R	PARTICIPANT	\N	PRESENT	0
380114	378658	08031R	PARTICIPANT	\N	PRESENT	0
380115	378658	11109J	PARTICIPANT	\N	PRESENT	0
380116	378658	14259Y	PARTICIPANT	\N	PRESENT	0
380117	378658	19711U	PARTICIPANT	\N	PRESENT	0
380118	378658	14039A	PARTICIPANT	\N	PRESENT	0
380119	378658	19593H	PARTICIPANT	\N	PRESENT	0
380124	378658	14241N	PARTICIPANT	\N	PRESENT	0
380127	378658	14123H	PARTICIPANT	\N	PRESENT	0
380131	378658	98005N	PARTICIPANT	\N	PRESENT	0
380135	378658	14229S	PARTICIPANT	\N	PRESENT	0
380136	378658	19533U	PARTICIPANT	\N	PRESENT	0
380137	378658	19335Q	PARTICIPANT	\N	PRESENT	0
380138	378658	14251Q	PARTICIPANT	\N	PRESENT	0
380139	378658	19503N	PARTICIPANT	\N	PRESENT	0
380140	378658	19583F	PARTICIPANT	\N	PRESENT	0
380141	378658	01028R	PARTICIPANT	\N	PRESENT	0
380146	378658	19301E	PARTICIPANT	\N	PRESENT	0
380147	378658	04085P	PARTICIPANT	\N	PRESENT	0
380148	378658	19649G	PARTICIPANT	\N	PRESENT	0
380151	378658	19669L	PARTICIPANT	\N	PRESENT	0
380152	378658	19577H	PARTICIPANT	\N	PRESENT	0
380153	378658	08019V	PARTICIPANT	\N	PRESENT	0
380160	378658	19663E	PARTICIPANT	\N	PRESENT	0
380161	378658	08035V	PARTICIPANT	\N	PRESENT	0
380162	378658	19691J	PARTICIPANT	\N	PRESENT	0
380163	378658	08017T	PARTICIPANT	\N	PRESENT	0
380173	378658	08047A	PARTICIPANT	\N	PRESENT	0
380174	378658	19631V	PARTICIPANT	\N	PRESENT	0
380175	378658	19573D	PARTICIPANT	\N	PRESENT	0
380176	378658	19295A	PARTICIPANT	\N	PRESENT	0
380177	378658	99004R	PARTICIPANT	\N	PRESENT	0
380178	378658	11065P	PARTICIPANT	\N	PRESENT	0
380191	378658	19693L	PARTICIPANT	\N	PRESENT	0
392677	389738	19569H	PARTICIPANT	\N	PRESENT	0
392678	389738	11040E	PARTICIPANT	\N	PRESENT	0
380091	378658	04086Q	PARTICIPANT	\N	PRESENT	0
380092	378658	19621T	PARTICIPANT	\N	PRESENT	0
392679	389738	11074Q	PARTICIPANT	\N	PRESENT	0
392680	389738	19507S	PARTICIPANT	\N	PRESENT	0
392681	389738	98050T	PARTICIPANT	\N	PRESENT	0
392683	392682	19569H	PARTICIPANT	\N	PRESENT	0
392684	378005	05012A	PARTICIPANT	\N	PRESENT	0
392685	392682	08028W	PARTICIPANT	\N	PRESENT	0
392686	378005	14031R	PARTICIPANT	\N	PRESENT	0
392687	378005	19563B	PARTICIPANT	\N	PRESENT	0
392689	392688	11053K	PARTICIPANT	\N	PRESENT	0
392690	392688	14159V	PARTICIPANT	\N	PRESENT	0
392691	392688	05012A	PARTICIPANT	\N	PRESENT	0
392692	391360	14327T	PARTICIPANT	\N	PRESENT	0
392693	391360	19479G	PARTICIPANT	\N	PRESENT	0
392694	391360	11048N	PARTICIPANT	\N	PRESENT	0
392695	391360	19545Y	PARTICIPANT	\N	PRESENT	0
392696	391360	01057W	PARTICIPANT	\N	PRESENT	0
392697	391360	89017R	PARTICIPANT	\N	PRESENT	0
392698	391360	19667J	PARTICIPANT	\N	PRESENT	0
392699	391360	11074Q	PRESIDENT	0	PRESENT	0
392700	391360	08011M	PARTICIPANT	\N	PRESENT	0
392701	391360	11070L	PARTICIPANT	\N	PRESENT	0
392702	391360	88008L	PARTICIPANT	\N	PRESENT	0
392703	391360	04086Q	PARTICIPANT	\N	PRESENT	0
392704	391360	11012A	PARTICIPANT	\N	PRESENT	0
392705	391360	14085U	PARTICIPANT	\N	PRESENT	0
392706	391360	08010L	PARTICIPANT	\N	PRESENT	0
392707	391360	14121F	PARTICIPANT	\N	PRESENT	0
392708	391360	99004R	PARTICIPANT	\N	PRESENT	0
392709	378005	14199E	PARTICIPANT	\N	PRESENT	0
392710	378005	14069U	PARTICIPANT	\N	PRESENT	0
392711	378005	11048N	PARTICIPANT	\N	PRESENT	0
392712	390061	19725B	PRESIDENT	0	PRESENT	0
392713	390061	14327T	PARTICIPANT	\N	PRESENT	0
392714	390061	11056N	PARTICIPANT	\N	PRESENT	0
392715	390061	04057K	PARTICIPANT	\N	PRESENT	0
392716	390061	14030Q	PARTICIPANT	\N	PRESENT	0
392717	390061	08073C	PARTICIPANT	\N	EXCUSE	0
392718	390061	08015R	PARTICIPANT	\N	EXCUSE	0
392719	390061	19295A	PARTICIPANT	\N	EXCUSE	0
392720	391360	07029T	PARTICIPANT	\N	EXCUSE	0
392721	378005	19631V	PARTICIPANT	\N	PRESENT	0
392722	378005	14107H	PARTICIPANT	\N	PRESENT	0
392723	378005	01058X	PARTICIPANT	\N	PRESENT	0
392724	378005	19747H	PARTICIPANT	\N	PRESENT	0
392725	378005	08009T	PARTICIPANT	\N	PRESENT	0
392727	392726	08068F	PARTICIPANT	\N	PRESENT	0
392728	392726	19782L	PARTICIPANT	\N	PRESENT	0
392729	392726	19681G	PARTICIPANT	\N	EXCUSE	0
392730	392726	07029T	PARTICIPANT	\N	EXCUSE	0
392731	392726	01043Q	PARTICIPANT	\N	PRESENT	0
366768	365638	14123H	PARTICIPANT	\N	PRESENT	0
366769	365638	19758L	PARTICIPANT	\N	PRESENT	0
366770	365638	08039A	PARTICIPANT	\N	PRESENT	0
366771	365638	19766L	PARTICIPANT	\N	EXCUSE	0
366772	365638	19643A	PARTICIPANT	\N	EXCUSE	0
366773	365638	19699S	PARTICIPANT	\N	EXCUSE	0
366774	365638	19731Y	PARTICIPANT	\N	EXCUSE	0
366775	365638	11104D	PARTICIPANT	\N	EXCUSE	0
366776	345243	08024S	PARTICIPANT	\N	PRESENT	0
366782	345243	19619A	PARTICIPANT	\N	PRESENT	0
366783	345243	19479G	PARTICIPANT	\N	PRESENT	0
366784	345243	14093U	PARTICIPANT	\N	PRESENT	0
366785	345243	14211G	PARTICIPANT	\N	PRESENT	0
366786	345243	19717B	PARTICIPANT	\N	PRESENT	0
366787	345243	14083S	PARTICIPANT	\N	PRESENT	0
366788	345243	11040E	PARTICIPANT	\N	PRESENT	0
366797	345243	08068F	PARTICIPANT	\N	PRESENT	0
366798	345243	19413M	PARTICIPANT	\N	PRESENT	0
366799	345243	19719D	PARTICIPANT	\N	PRESENT	0
366800	345243	14103D	PARTICIPANT	\N	PRESENT	0
366801	345243	11048N	PARTICIPANT	\N	PRESENT	0
366802	345243	14026U	PARTICIPANT	\N	PRESENT	0
366803	345243	14147R	PARTICIPANT	\N	PRESENT	0
366804	345243	19727D	PARTICIPANT	\N	PRESENT	0
366805	345243	19760E	PARTICIPANT	\N	PRESENT	0
366806	345243	19695N	PARTICIPANT	\N	PRESENT	0
366807	345243	19563B	PARTICIPANT	\N	PRESENT	0
366808	345243	19581D	PARTICIPANT	\N	PRESENT	0
366809	345243	19269X	PARTICIPANT	\N	PRESENT	0
366810	345243	11110B	PARTICIPANT	\N	PRESENT	0
366811	345243	14213J	PARTICIPANT	\N	PRESENT	0
366812	345243	04086Q	PARTICIPANT	\N	PRESENT	0
366829	345243	19521Q	PARTICIPANT	\N	PRESENT	0
366816	345243	19583F	PARTICIPANT	\N	PRESENT	0
366823	345243	19399H	PARTICIPANT	\N	PRESENT	0
366830	345243	11099A	PARTICIPANT	\N	PRESENT	0
366831	345243	14357A	PARTICIPANT	\N	PRESENT	0
366832	345243	14169X	PARTICIPANT	\N	PRESENT	0
366833	366622	11026G	PARTICIPANT	\N	PRESENT	0
366834	366622	14147R	PARTICIPANT	\N	PRESENT	0
366835	366622	01024M	PARTICIPANT	\N	PRESENT	0
366836	366622	14215L	PRESIDENT	0	PRESENT	0
366837	366622	04047H	PARTICIPANT	\N	PRESENT	0
366838	366622	05008E	PRESIDENT	1	PRESENT	0
366839	366622	19729F	PARTICIPANT	\N	PRESENT	0
366840	366622	19649G	PARTICIPANT	\N	PRESENT	0
366841	366622	14111D	PARTICIPANT	\N	PRESENT	0
366842	366622	11010L	PARTICIPANT	\N	PRESENT	0
366843	366622	14041T	PARTICIPANT	\N	PRESENT	0
366844	366622	14069U	PARTICIPANT	\N	PRESENT	0
366845	366622	19581D	PARTICIPANT	\N	PRESENT	0
366846	366622	08018U	PARTICIPANT	\N	PRESENT	0
366847	366622	11049P	PARTICIPANT	\N	PRESENT	0
366848	366622	19447X	PARTICIPANT	\N	PRESENT	0
366849	345243	08061X	PARTICIPANT	\N	PRESENT	0
366850	345243	11085T	PARTICIPANT	\N	PRESENT	0
366851	345243	05012A	PARTICIPANT	\N	PRESENT	0
366852	345243	19687N	PARTICIPANT	\N	PRESENT	0
366853	365638	11043H	PARTICIPANT	\N	PRESENT	0
366854	345243	14217N	PARTICIPANT	\N	PRESENT	0
366855	345243	14079W	PARTICIPANT	\N	PRESENT	0
366953	345289	14261S	PARTICIPANT	\N	PRESENT	0
366954	345289	19347U	PARTICIPANT	\N	PRESENT	0
366955	345289	19647E	PARTICIPANT	\N	PRESENT	0
366956	345289	19703U	PARTICIPANT	\N	PRESENT	0
366957	345289	02002K	PARTICIPANT	\N	PRESENT	0
366958	345289	14215L	PARTICIPANT	\N	PRESENT	0
366959	345289	08009T	PARTICIPANT	\N	PRESENT	0
366960	345289	14069U	PARTICIPANT	\N	PRESENT	0
366961	345289	14083S	PARTICIPANT	\N	PRESENT	0
366962	345289	14157T	PARTICIPANT	\N	PRESENT	0
366963	345289	14237S	PARTICIPANT	\N	PRESENT	0
366964	345289	14030Q	PARTICIPANT	\N	PRESENT	0
366965	345289	19733B	PARTICIPANT	\N	PRESENT	0
366966	345289	19794Q	PARTICIPANT	\N	PRESENT	0
366967	345289	18083K	PARTICIPANT	\N	PRESENT	0
366968	345289	19575F	PARTICIPANT	\N	PRESENT	0
366969	345289	19741B	PARTICIPANT	\N	PRESENT	0
366970	345289	14265W	PARTICIPANT	\N	PRESENT	0
366971	345289	14033T	PARTICIPANT	\N	PRESENT	0
366972	345289	14217N	PARTICIPANT	\N	PRESENT	0
366973	345289	05012A	PARTICIPANT	\N	PRESENT	0
366974	345289	04088S	PARTICIPANT	\N	PRESENT	0
366975	345289	14021P	PARTICIPANT	\N	PRESENT	0
366976	345289	11097X	PARTICIPANT	\N	PRESENT	0
366977	345289	14213J	PARTICIPANT	\N	PRESENT	0
366978	345289	14026U	PARTICIPANT	\N	PRESENT	0
366979	345289	08061X	PARTICIPANT	\N	PRESENT	0
366980	345289	19637C	PARTICIPANT	\N	PRESENT	0
366981	345289	14089Y	PARTICIPANT	\N	PRESENT	0
366982	345289	19715Y	PARTICIPANT	\N	PRESENT	0
366983	345289	11099A	PARTICIPANT	\N	PRESENT	0
366984	345289	14169X	PARTICIPANT	\N	PRESENT	0
366985	345289	08010L	PARTICIPANT	\N	PRESENT	0
366986	345289	95030B	PARTICIPANT	\N	PRESENT	0
366987	345289	14179A	PARTICIPANT	\N	PRESENT	0
367280	367273	01028R	PARTICIPANT	\N	PRESENT	0
367790	367789	14239U	PARTICIPANT	\N	PRESENT	0
367791	367789	08052W	PARTICIPANT	\N	PRESENT	0
367793	367792	14239U	PARTICIPANT	\N	PRESENT	0
367795	367794	14239U	PARTICIPANT	\N	PRESENT	0
369839	369838	01034P	PARTICIPANT	\N	PRESENT	0
370174	370171	14030Q	PARTICIPANT	\N	PRESENT	0
370176	370171	19643A	PARTICIPANT	\N	PRESENT	0
370177	370171	08024S	PARTICIPANT	\N	PRESENT	0
370178	370171	19701S	PARTICIPANT	\N	PRESENT	0
370179	370171	11031D	PARTICIPANT	\N	PRESENT	0
370180	370171	14179A	PARTICIPANT	\N	PRESENT	0
370181	370171	14109K	PARTICIPANT	\N	PRESENT	0
370182	370171	14235Q	PARTICIPANT	\N	PRESENT	0
370183	370171	19693L	PARTICIPANT	\N	EXCUSE	0
370184	370171	19715Y	PARTICIPANT	\N	EXCUSE	0
370186	370171	08031R	PARTICIPANT	\N	EXCUSE	0
370189	370171	01043Q	PARTICIPANT	\N	EXCUSE	0
370190	370171	14251Q	PARTICIPANT	\N	EXCUSE	0
370191	370171	11067R	PARTICIPANT	\N	EXCUSE	0
370192	370171	19269X	PARTICIPANT	\N	EXCUSE	0
370193	370171	19731Y	PARTICIPANT	\N	EXCUSE	0
370194	370171	19711U	PARTICIPANT	\N	PRESENT	0
370195	370171	19611R	PARTICIPANT	\N	PRESENT	0
370197	370171	19725B	PARTICIPANT	\N	PRESENT	0
370198	370171	14213J	PARTICIPANT	\N	PRESENT	0
370553	367258	14261S	PARTICIPANT	\N	PRESENT	0
370554	367258	08019V	PARTICIPANT	\N	PRESENT	0
370669	370163	04061F	PARTICIPANT	\N	PRESENT	0
370556	367258	19659J	PARTICIPANT	\N	EXCUSE	0
370557	367258	19715Y	PARTICIPANT	\N	EXCUSE	0
370558	367258	98005N	PARTICIPANT	\N	EXCUSE	0
370559	367258	95062K	PARTICIPANT	\N	EXCUSE	0
370560	367258	04044E	PARTICIPANT	\N	PRESENT	0
370666	370163	96004D	PRESIDENT	0	PRESENT	0
370667	370163	19725B	PARTICIPANT	\N	PRESENT	0
370670	370163	14073Q	PARTICIPANT	\N	PRESENT	0
370671	370163	14001X	PARTICIPANT	\N	PRESENT	0
370672	370163	14221J	PARTICIPANT	\N	PRESENT	0
370673	370163	19563B	PARTICIPANT	\N	PRESENT	0
370674	370163	14237S	PARTICIPANT	\N	PRESENT	0
370675	370163	10015M	PARTICIPANT	\N	PRESENT	0
370676	370163	14065Q	PARTICIPANT	\N	PRESENT	0
370677	370163	14133K	PARTICIPANT	\N	PRESENT	0
370678	370163	04044E	PARTICIPANT	\N	PRESENT	0
370679	370163	14357A	PARTICIPANT	\N	EXCUSE	0
370680	370163	14079W	PARTICIPANT	\N	EXCUSE	0
370681	370163	04057K	PARTICIPANT	\N	EXCUSE	0
371480	369086	10006L	PARTICIPANT	\N	PRESENT	0
371481	369086	19723Y	PARTICIPANT	\N	PRESENT	0
371482	369086	11097X	PARTICIPANT	\N	PRESENT	0
371483	369086	11067R	PARTICIPANT	\N	PRESENT	0
371547	369090	11067R	PARTICIPANT	\N	PRESENT	0
371548	369090	11097X	PARTICIPANT	\N	PRESENT	0
371549	369090	19723Y	PARTICIPANT	\N	PRESENT	0
371550	369090	10006L	PARTICIPANT	\N	PRESENT	0
372204	372190	14038Y	PARTICIPANT	\N	PRESENT	0
372205	372190	04043D	PARTICIPANT	\N	PRESENT	0
372206	372190	14265W	PARTICIPANT	\N	PRESENT	0
372207	372190	19333N	PARTICIPANT	\N	PRESENT	0
372208	372190	19599P	PARTICIPANT	\N	PRESENT	0
372209	372190	19349W	PARTICIPANT	\N	PRESENT	0
372210	372190	14026U	PARTICIPANT	\N	PRESENT	0
372211	372190	19489J	PARTICIPANT	\N	PRESENT	0
364584	363577	14038Y	PRESIDENT	0	PRESENT	0
364585	363577	08009T	PARTICIPANT	\N	EXCUSE	0
364586	363577	19685L	PARTICIPANT	\N	EXCUSE	0
364587	363577	19333N	PARTICIPANT	\N	PRESENT	0
364588	363577	17583W	PARTICIPANT	\N	PRESENT	0
364589	363577	19794Q	PARTICIPANT	\N	PRESENT	0
364590	363577	14031R	PARTICIPANT	\N	PRESENT	0
364591	363577	95062K	PARTICIPANT	\N	PRESENT	0
364592	363577	19549D	PARTICIPANT	\N	PRESENT	0
364593	363577	19387D	PARTICIPANT	\N	PRESENT	0
364594	363577	14219Q	PARTICIPANT	\N	PRESENT	0
364595	363577	08055A	PARTICIPANT	\N	PRESENT	0
364596	363577	18083K	PARTICIPANT	\N	PRESENT	0
364597	363577	14237S	PARTICIPANT	\N	PRESENT	0
364598	363577	19551W	PARTICIPANT	\N	PRESENT	0
364599	363577	14051J	PARTICIPANT	\N	PRESENT	0
364600	363577	14029X	PARTICIPANT	\N	PRESENT	0
364601	363577	08060W	PARTICIPANT	\N	PRESENT	0
364602	363577	19733B	PARTICIPANT	\N	PRESENT	0
364603	363577	19737F	PARTICIPANT	\N	PRESENT	0
364604	363577	19503N	PARTICIPANT	\N	PRESENT	0
364605	363577	19745F	PARTICIPANT	\N	PRESENT	0
364606	363577	11065P	PARTICIPANT	\N	PRESENT	0
364607	363577	19525U	PARTICIPANT	\N	PRESENT	0
364608	363577	15447F	PARTICIPANT	\N	PRESENT	0
364609	363577	04097T	PARTICIPANT	\N	PRESENT	0
364610	363577	19599P	PARTICIPANT	\N	PRESENT	0
364611	363577	02002K	PARTICIPANT	\N	PRESENT	0
364612	363577	08024S	PARTICIPANT	\N	PRESENT	0
364613	363577	14221J	PARTICIPANT	\N	PRESENT	0
364614	363577	14169X	PARTICIPANT	\N	PRESENT	0
364615	363577	17637T	PARTICIPANT	\N	PRESENT	0
364616	363577	19289C	PARTICIPANT	\N	PRESENT	0
364617	363577	19347U	PARTICIPANT	\N	PRESENT	0
364618	345239	04059M	PARTICIPANT	\N	PRESENT	0
364619	345239	19745F	PARTICIPANT	\N	PRESENT	0
364620	345239	95062K	PARTICIPANT	\N	PRESENT	0
364621	345239	19335Q	PARTICIPANT	\N	PRESENT	0
364622	345239	14038Y	PARTICIPANT	\N	PRESENT	0
364623	345239	14031R	PARTICIPANT	\N	PRESENT	0
364624	345239	08009T	PARTICIPANT	\N	PRESENT	0
364625	345239	14231L	PARTICIPANT	\N	PRESENT	0
364626	345239	19347U	PARTICIPANT	\N	PRESENT	0
364627	345239	19794Q	PARTICIPANT	\N	PRESENT	0
364628	345239	14029X	PARTICIPANT	\N	PRESENT	0
364629	345239	19387D	PARTICIPANT	\N	PRESENT	0
364630	345239	19503N	PARTICIPANT	\N	PRESENT	0
364631	345239	19637C	PARTICIPANT	\N	PRESENT	0
364632	345239	14237S	PARTICIPANT	\N	PRESENT	0
364633	345239	14147R	PARTICIPANT	\N	PRESENT	0
364634	345239	17583W	PARTICIPANT	\N	PRESENT	0
364635	345239	14169X	PARTICIPANT	\N	PRESENT	0
364636	345239	19671E	PARTICIPANT	\N	PRESENT	0
364637	345239	14051J	PARTICIPANT	\N	PRESENT	0
364638	345239	19551W	PARTICIPANT	\N	PRESENT	0
364639	345239	08055A	PARTICIPANT	\N	PRESENT	0
364640	345239	19737F	PARTICIPANT	\N	PRESENT	0
364641	345239	11048N	PARTICIPANT	\N	PRESENT	0
364642	345239	08031R	PARTICIPANT	\N	PRESENT	0
364643	345239	14105F	PARTICIPANT	\N	PRESENT	0
364644	345239	19289C	PARTICIPANT	\N	PRESENT	0
364645	345239	14041T	PARTICIPANT	\N	PRESENT	0
364646	345239	19731Y	PARTICIPANT	\N	PRESENT	0
364647	345239	04018C	PARTICIPANT	\N	PRESENT	0
364648	345239	14089Y	PARTICIPANT	\N	PRESENT	0
364649	345239	19733B	PARTICIPANT	\N	PRESENT	0
364650	345239	19647E	PARTICIPANT	\N	PRESENT	0
364651	345239	17637T	PARTICIPANT	\N	PRESENT	0
364652	345239	15447F	PARTICIPANT	\N	PRESENT	0
364653	345239	14259Y	PARTICIPANT	\N	PRESENT	0
364654	345239	14223L	PARTICIPANT	\N	PRESENT	0
364655	345239	08024S	PARTICIPANT	\N	PRESENT	0
364656	345239	08015R	PARTICIPANT	\N	PRESENT	0
364657	345239	01060R	PARTICIPANT	\N	PRESENT	0
364658	345239	01058X	PARTICIPANT	\N	PRESENT	0
364659	345239	14331P	PARTICIPANT	\N	PRESENT	0
364660	345239	19711U	PARTICIPANT	\N	PRESENT	0
364661	345239	08028W	PARTICIPANT	\N	PRESENT	0
364662	345239	11065P	PARTICIPANT	\N	PRESENT	0
364663	345239	19760E	PARTICIPANT	\N	PRESENT	0
364664	345239	04097T	PARTICIPANT	\N	PRESENT	0
364665	345239	14267Y	PARTICIPANT	\N	PRESENT	0
364669	345239	19599P	PARTICIPANT	\N	PRESENT	0
364667	345239	19739H	PARTICIPANT	\N	PRESENT	0
364668	345239	19333N	PARTICIPANT	\N	PRESENT	0
364670	345239	19525U	PARTICIPANT	\N	PRESENT	0
364671	345239	11110B	PARTICIPANT	\N	PRESENT	0
364672	345239	19629C	PARTICIPANT	\N	PRESENT	0
364673	345239	14107H	PARTICIPANT	\N	PRESENT	0
364674	345239	19798U	PARTICIPANT	\N	PRESENT	0
364675	345239	04085P	PARTICIPANT	\N	PRESENT	0
364676	345239	08039A	PARTICIPANT	\N	PRESENT	0
364677	345239	97011G	PARTICIPANT	\N	PRESENT	0
364678	345239	99004R	PARTICIPANT	\N	PRESENT	0
364684	345239	08017T	PARTICIPANT	\N	PRESENT	0
364687	345239	08049C	PARTICIPANT	\N	PRESENT	0
364689	345239	08060W	PARTICIPANT	\N	PRESENT	0
364690	345239	19515S	PARTICIPANT	\N	PRESENT	0
364692	345239	19443T	PARTICIPANT	\N	PRESENT	0
364694	345239	01024M	PARTICIPANT	\N	PRESENT	0
364696	345239	19583F	PARTICIPANT	\N	PRESENT	0
364698	345239	14179A	PARTICIPANT	\N	PRESENT	0
364701	345239	19543W	PARTICIPANT	\N	PRESENT	0
364702	345239	19782L	PARTICIPANT	\N	PRESENT	0
364703	345239	98050T	PARTICIPANT	\N	PRESENT	0
364707	345239	19762G	PARTICIPANT	\N	PRESENT	0
364708	345239	14219Q	PARTICIPANT	\N	PRESENT	0
364709	345239	14087W	PARTICIPANT	\N	PRESENT	0
364710	345239	19251M	PARTICIPANT	\N	PRESENT	0
364711	345239	11054L	PARTICIPANT	\N	PRESENT	0
364712	345239	19723Y	PARTICIPANT	\N	PRESENT	0
364713	345239	04047H	PARTICIPANT	\N	PRESENT	0
364714	345239	19399H	PARTICIPANT	\N	PRESENT	0
364715	345239	19768N	PARTICIPANT	\N	PRESENT	0
364716	345239	08062Y	PARTICIPANT	\N	PRESENT	0
364717	345239	14265W	PARTICIPANT	\N	PRESENT	0
364718	345239	14197C	PARTICIPANT	\N	PRESENT	0
364719	345239	19741B	PARTICIPANT	\N	PRESENT	0
364720	345239	19701S	PARTICIPANT	\N	PRESENT	0
364721	345239	04088S	PARTICIPANT	\N	PRESENT	0
364722	345239	04049K	PARTICIPANT	\N	PRESENT	0
364723	345239	12016W	PARTICIPANT	\N	PRESENT	0
364724	345239	19563B	PARTICIPANT	\N	PRESENT	0
364725	345239	07029T	PARTICIPANT	\N	PRESENT	0
364726	345239	01025N	PARTICIPANT	\N	PRESENT	0
364727	345239	14191V	PARTICIPANT	\N	PRESENT	0
364729	345239	08069G	PARTICIPANT	\N	PRESENT	0
364730	345239	11033F	PARTICIPANT	\N	PRESENT	0
364731	345239	08061X	PARTICIPANT	\N	PRESENT	0
364732	345239	88008L	PARTICIPANT	\N	PRESENT	0
364733	345239	11066Q	PARTICIPANT	\N	PRESENT	0
364734	345239	14241N	PARTICIPANT	\N	PRESENT	0
364735	345239	19369B	PARTICIPANT	\N	PRESENT	0
364736	345239	14073Q	PARTICIPANT	\N	PRESENT	0
364737	345239	19747H	PARTICIPANT	\N	PRESENT	0
364738	345239	14215L	PARTICIPANT	\N	PRESENT	0
364746	345239	19413M	PARTICIPANT	\N	PRESENT	0
364747	345239	14121F	PARTICIPANT	\N	PRESENT	0
364748	345239	14061L	PARTICIPANT	\N	PRESENT	0
364749	345239	18083K	PARTICIPANT	\N	PRESENT	0
364753	345239	87003B	PARTICIPANT	\N	PRESENT	0
364757	345239	19295A	PARTICIPANT	\N	PRESENT	0
364758	345239	11012A	PARTICIPANT	\N	PRESENT	0
364759	345239	02002K	PARTICIPANT	\N	PRESENT	0
364760	345239	11040E	PARTICIPANT	\N	PRESENT	0
364761	345239	14063N	PARTICIPANT	\N	PRESENT	0
364762	345239	14081Q	PARTICIPANT	\N	PRESENT	0
364763	345239	14281W	PARTICIPANT	\N	PRESENT	0
364764	345239	19301E	PARTICIPANT	\N	PRESENT	0
364765	345239	08038Y	PARTICIPANT	\N	PRESENT	0
364766	345239	14173T	PARTICIPANT	\N	PRESENT	0
364767	345239	19725B	PARTICIPANT	\N	PRESENT	0
364768	345239	14135M	PARTICIPANT	\N	PRESENT	0
364769	345239	14221J	PARTICIPANT	\N	PRESENT	0
364771	345239	95030B	PARTICIPANT	\N	PRESENT	0
364772	345239	11053K	PARTICIPANT	\N	PRESENT	0
364773	345239	19507S	PARTICIPANT	\N	PRESENT	0
364774	345239	14211G	PARTICIPANT	\N	PRESENT	0
364775	345239	08020N	PARTICIPANT	\N	PRESENT	0
364776	345239	14257W	PARTICIPANT	\N	PRESENT	0
364777	345239	14187A	PARTICIPANT	\N	PRESENT	0
364778	345239	19479G	PARTICIPANT	\N	PRESENT	0
364779	345239	19533U	PARTICIPANT	\N	PRESENT	0
364780	345239	19695N	PARTICIPANT	\N	PRESENT	0
364781	345239	19467C	PARTICIPANT	\N	PRESENT	0
364782	345239	19758L	PARTICIPANT	\N	PRESENT	0
364783	345239	14195A	PARTICIPANT	\N	PRESENT	0
364784	345239	19383Y	PARTICIPANT	\N	PRESENT	0
364785	345239	14033T	PARTICIPANT	\N	PRESENT	0
385219	377918	19441R	PARTICIPANT	\N	PRESENT	0
378450	377016	08034U	PARTICIPANT	\N	PRESENT	0
385220	377918	19739H	PARTICIPANT	\N	PRESENT	0
378452	377016	14034U	PARTICIPANT	\N	PRESENT	0
385221	377918	08056B	PARTICIPANT	\N	PRESENT	0
385222	377918	14207L	PARTICIPANT	\N	PRESENT	0
385223	377918	98024R	PARTICIPANT	\N	PRESENT	0
378456	377016	08073C	PARTICIPANT	\N	PRESENT	0
385224	377918	14107H	PARTICIPANT	\N	PRESENT	0
378458	377016	04061F	PARTICIPANT	\N	PRESENT	0
378459	377016	08014Q	PARTICIPANT	\N	EXCUSE	0
379763	377016	14173T	PARTICIPANT	\N	PRESENT	0
379772	379771	19631V	PARTICIPANT	\N	PRESENT	0
379773	379771	14093U	PARTICIPANT	\N	PRESENT	0
379774	379771	14038Y	PARTICIPANT	\N	PRESENT	0
379775	379771	19599P	PARTICIPANT	\N	PRESENT	0
379776	379771	14179A	PARTICIPANT	\N	PRESENT	0
379777	379771	01048V	PARTICIPANT	\N	PRESENT	0
379778	379771	08053X	PARTICIPANT	\N	PRESENT	0
379779	379771	14257W	PRESIDENT	0	PRESENT	0
379780	379771	19533U	PARTICIPANT	\N	PRESENT	0
379781	379771	19679N	PARTICIPANT	\N	PRESENT	0
379782	379771	14229S	PARTICIPANT	\N	PRESENT	0
379783	379771	19421M	PARTICIPANT	\N	PRESENT	0
379784	379771	19741B	PARTICIPANT	\N	EXCUSE	0
379785	379771	19415P	PARTICIPANT	\N	EXCUSE	0
379786	379771	88008L	PARTICIPANT	\N	EXCUSE	0
379787	379771	08018U	PARTICIPANT	\N	EXCUSE	0
379788	379771	11083R	PARTICIPANT	\N	EXCUSE	0
379789	379771	19611R	PARTICIPANT	\N	EXCUSE	0
379790	379771	04070G	PARTICIPANT	\N	EXCUSE	0
379791	379771	19593H	PARTICIPANT	\N	EXCUSE	0
379792	379771	11090Q	PARTICIPANT	\N	EXCUSE	0
385225	377918	08015R	PARTICIPANT	\N	PRESENT	0
385226	377918	19715Y	PARTICIPANT	\N	PRESENT	0
385227	377918	14197C	PARTICIPANT	\N	PRESENT	0
385228	377918	19447X	PARTICIPANT	\N	PRESENT	0
385229	377918	14235Q	PARTICIPANT	\N	PRESENT	0
385230	377918	14071N	PARTICIPANT	\N	PRESENT	0
385231	377918	14031R	PARTICIPANT	\N	PRESENT	0
385232	377918	17779H	PARTICIPANT	\N	PRESENT	0
385233	377918	14109K	PARTICIPANT	\N	PRESENT	0
385234	377918	14257W	PARTICIPANT	\N	PRESENT	0
385235	377918	08061X	PARTICIPANT	\N	PRESENT	0
385236	377918	19631V	PARTICIPANT	\N	PRESENT	0
385238	377918	19527W	PARTICIPANT	\N	PRESENT	0
385240	377918	14229S	PARTICIPANT	\N	PRESENT	0
385241	377918	11070L	PARTICIPANT	\N	PRESENT	0
385242	377918	14157T	PARTICIPANT	\N	PRESENT	0
385243	377918	19745F	PARTICIPANT	\N	PRESENT	0
385244	377918	19737F	PARTICIPANT	\N	PRESENT	0
385245	377918	19749K	PARTICIPANT	\N	PRESENT	0
385246	377918	12016W	PARTICIPANT	\N	PRESENT	0
385247	377918	14073Q	PARTICIPANT	\N	PRESENT	0
385248	377918	01028R	PARTICIPANT	\N	PRESENT	0
385249	377918	98022P	PARTICIPANT	\N	PRESENT	0
385250	377918	19663E	PARTICIPANT	\N	PRESENT	0
385251	377918	19383Y	PARTICIPANT	\N	PRESENT	0
385252	377918	01048V	PARTICIPANT	\N	PRESENT	0
385253	377918	14205J	PARTICIPANT	\N	PRESENT	0
385254	377918	88008L	PARTICIPANT	\N	PRESENT	0
385255	377918	99004R	PARTICIPANT	\N	PRESENT	0
385256	377918	14151M	PARTICIPANT	\N	PRESENT	0
385257	377918	19691J	PARTICIPANT	\N	PRESENT	0
385263	377918	80013X	PARTICIPANT	\N	PRESENT	0
385264	377918	14063N	PARTICIPANT	\N	PRESENT	0
385265	377918	19581D	PARTICIPANT	\N	PRESENT	0
385266	377918	14159V	PARTICIPANT	\N	PRESENT	0
385267	377918	11048N	PARTICIPANT	\N	PRESENT	0
385268	377918	14173T	PARTICIPANT	\N	PRESENT	0
385269	377918	11101A	PARTICIPANT	\N	PRESENT	0
385270	377918	08020N	PARTICIPANT	\N	PRESENT	0
385271	377918	11010L	PARTICIPANT	\N	PRESENT	0
385272	377918	15447F	PARTICIPANT	\N	PRESENT	0
385273	377918	08062Y	PARTICIPANT	\N	PRESENT	0
385274	377918	19369B	PARTICIPANT	\N	PRESENT	0
385275	377918	14111D	PARTICIPANT	\N	PRESENT	0
385276	377918	14135M	PARTICIPANT	\N	PRESENT	0
385277	377918	98029W	PARTICIPANT	\N	PRESENT	0
385278	377918	19533U	PARTICIPANT	\N	PRESENT	0
385279	377918	19725B	PARTICIPANT	\N	PRESENT	0
385280	377918	11064N	PARTICIPANT	\N	PRESENT	0
385281	377918	14121F	PARTICIPANT	\N	PRESENT	0
385282	377918	08024S	PARTICIPANT	\N	PRESENT	0
385283	377918	14115H	PARTICIPANT	\N	PRESENT	0
385284	377918	19599P	PARTICIPANT	\N	PRESENT	0
385285	377918	19782L	PARTICIPANT	\N	PRESENT	0
385286	377918	14083S	PARTICIPANT	\N	PRESENT	0
385287	377918	01043Q	PARTICIPANT	\N	PRESENT	0
385288	377918	14199E	PARTICIPANT	\N	PRESENT	0
385289	377918	14033T	PARTICIPANT	\N	PRESENT	0
385290	377918	14039A	PARTICIPANT	\N	PRESENT	0
385291	377918	08010L	PARTICIPANT	\N	PRESENT	0
385342	377918	14053L	PARTICIPANT	\N	PRESENT	0
385343	377918	19507S	PARTICIPANT	\N	PRESENT	0
385344	377918	04049K	PARTICIPANT	\N	PRESENT	0
385345	377918	19747H	PARTICIPANT	\N	PRESENT	0
385346	377918	14097Y	PARTICIPANT	\N	PRESENT	0
385347	377918	08068F	PARTICIPANT	\N	PRESENT	0
385348	377918	19695N	PARTICIPANT	\N	PRESENT	0
385349	377918	14221J	PARTICIPANT	\N	PRESENT	0
385351	377918	08028W	PARTICIPANT	\N	PRESENT	0
385359	377918	08009T	PARTICIPANT	\N	PRESENT	0
385362	377918	19413M	PARTICIPANT	\N	PRESENT	0
385378	377918	19295A	PARTICIPANT	\N	PRESENT	0
385376	377918	95067Q	PARTICIPANT	\N	PRESENT	0
385377	377918	14079W	PARTICIPANT	\N	PRESENT	0
385379	377918	11109J	PARTICIPANT	\N	PRESENT	0
385380	377918	04047H	PARTICIPANT	\N	PRESENT	0
385381	377918	14169X	PARTICIPANT	\N	PRESENT	0
385471	377919	14034U	PARTICIPANT	\N	PRESENT	0
385472	377919	14219Q	PARTICIPANT	\N	PRESENT	0
385473	377919	98024R	PARTICIPANT	\N	PRESENT	0
385474	377919	04092N	PARTICIPANT	\N	PRESENT	0
385475	377919	19565D	PARTICIPANT	\N	PRESENT	0
385476	377919	12016W	PARTICIPANT	\N	PRESENT	0
385477	377919	19727D	PARTICIPANT	\N	PRESENT	0
385478	377919	08055A	PARTICIPANT	\N	PRESENT	0
385479	377919	17779H	PARTICIPANT	\N	PRESENT	0
385480	377919	14097Y	PARTICIPANT	\N	PRESENT	0
385481	377919	01028R	PARTICIPANT	\N	PRESENT	0
385482	377919	08060W	PARTICIPANT	\N	PRESENT	0
385483	377919	19683J	PARTICIPANT	\N	PRESENT	0
385484	377919	19295A	PARTICIPANT	\N	PRESENT	0
385485	377919	19503N	PARTICIPANT	\N	PRESENT	0
385486	377919	19413M	PARTICIPANT	\N	PRESENT	0
385487	377919	11067R	PARTICIPANT	\N	PRESENT	0
385488	377919	11045K	PARTICIPANT	\N	PRESENT	0
385489	377919	14239U	PARTICIPANT	\N	PRESENT	0
385490	377919	04045F	PARTICIPANT	\N	PRESENT	0
385491	377919	19301E	PARTICIPANT	\N	PRESENT	0
385492	377919	19253P	PARTICIPANT	\N	PRESENT	0
385493	377919	19782L	PARTICIPANT	\N	PRESENT	0
385494	377919	08052W	PARTICIPANT	\N	PRESENT	0
385495	377919	19563B	PARTICIPANT	\N	PRESENT	0
385496	377919	19739H	PARTICIPANT	\N	PRESENT	0
385497	377919	19713W	PARTICIPANT	\N	PRESENT	0
385498	377919	19749K	PARTICIPANT	\N	PRESENT	0
385499	377919	14179A	PARTICIPANT	\N	PRESENT	0
385500	377919	19691J	PARTICIPANT	\N	PRESENT	0
385501	377919	14042U	PARTICIPANT	\N	PRESENT	0
385502	377919	14030Q	PARTICIPANT	\N	PRESENT	0
385503	377919	14109K	PARTICIPANT	\N	PRESENT	0
385504	377919	19737F	PARTICIPANT	\N	PRESENT	0
385505	377919	08009T	PARTICIPANT	\N	PRESENT	0
385506	377919	19553Y	PARTICIPANT	\N	PRESENT	0
385507	377919	14261S	PARTICIPANT	\N	PRESENT	0
385508	377919	08049C	PARTICIPANT	\N	PRESENT	0
385509	377919	19521Q	PARTICIPANT	\N	PRESENT	0
385510	377919	19657G	PARTICIPANT	\N	PRESENT	0
385511	377919	19663E	PARTICIPANT	\N	PRESENT	0
385512	377919	14029X	PARTICIPANT	\N	PRESENT	0
385513	377919	14038Y	PARTICIPANT	\N	PRESENT	0
385514	377919	14135M	PARTICIPANT	\N	PRESENT	0
385515	377919	19415P	PARTICIPANT	\N	PRESENT	0
385516	377919	14157T	PARTICIPANT	\N	PRESENT	0
385517	377919	18083K	PARTICIPANT	\N	PRESENT	0
385518	377919	14031R	PARTICIPANT	\N	PRESENT	0
385519	377919	19703U	PARTICIPANT	\N	PRESENT	0
385520	377919	14169X	PARTICIPANT	\N	PRESENT	0
385521	377919	11097X	PARTICIPANT	\N	PRESENT	0
385522	377919	14213J	PARTICIPANT	\N	PRESENT	0
385523	377919	08034U	PARTICIPANT	\N	PRESENT	0
385524	377919	05012A	PARTICIPANT	\N	PRESENT	0
385525	377919	19383Y	PARTICIPANT	\N	PRESENT	0
385526	377919	14217N	PARTICIPANT	\N	PRESENT	0
385527	377919	10006L	PARTICIPANT	\N	PRESENT	0
385528	377919	14327T	PARTICIPANT	\N	PRESENT	0
385529	377919	19798U	PARTICIPANT	\N	PRESENT	0
385870	385866	04059M	PARTICIPANT	\N	PRESENT	0
385871	385866	11083R	PARTICIPANT	\N	PRESENT	0
385872	385866	19399H	PARTICIPANT	\N	PRESENT	0
385873	385866	14241N	PARTICIPANT	\N	PRESENT	0
385874	385866	08039A	PARTICIPANT	\N	PRESENT	0
385875	385866	14109K	PARTICIPANT	\N	PRESENT	0
385876	385866	08011M	PARTICIPANT	\N	PRESENT	0
385877	385866	04070G	PARTICIPANT	\N	PRESENT	0
385878	385866	19593H	PARTICIPANT	\N	PRESENT	0
385879	385866	19573D	PARTICIPANT	\N	PRESENT	0
385880	385866	14229S	PARTICIPANT	\N	PRESENT	0
385949	385941	19507S	PARTICIPANT	\N	PRESENT	0
385882	385866	04018C	PARTICIPANT	\N	PRESENT	0
385883	385866	19749K	PARTICIPANT	\N	PRESENT	0
385953	385941	14205J	PARTICIPANT	\N	PRESENT	0
385955	385954	14033T	PARTICIPANT	\N	PRESENT	0
385956	385954	14135M	PARTICIPANT	\N	PRESENT	0
385947	385941	14033T	PARTICIPANT	\N	PRESENT	0
385948	385941	14135M	PARTICIPANT	\N	PRESENT	0
385957	385954	19507S	PARTICIPANT	\N	PRESENT	0
385958	385954	14205J	PARTICIPANT	\N	PRESENT	0
386195	386194	19631V	PARTICIPANT	\N	PRESENT	0
386196	386194	19575F	PARTICIPANT	\N	PRESENT	0
386197	386194	19383Y	PARTICIPANT	\N	PRESENT	0
386198	386194	19782L	PARTICIPANT	\N	PRESENT	0
386199	386194	14207L	PARTICIPANT	\N	PRESENT	0
386200	386194	18083K	PARTICIPANT	\N	PRESENT	0
386201	386194	01024M	PARTICIPANT	\N	PRESENT	0
386202	386194	19507S	PARTICIPANT	\N	PRESENT	0
386203	386194	14199E	PARTICIPANT	\N	PRESENT	0
386204	386194	14033T	PARTICIPANT	\N	PRESENT	0
386205	386194	04097T	PARTICIPANT	\N	PRESENT	0
386206	386194	14213J	PARTICIPANT	\N	PRESENT	0
386207	386194	19511N	PARTICIPANT	\N	PRESENT	0
386208	386194	14061L	PARTICIPANT	\N	PRESENT	0
386209	386194	08015R	PARTICIPANT	\N	PRESENT	0
386210	386194	19369B	PARTICIPANT	\N	PRESENT	0
386211	386194	14265W	PARTICIPANT	\N	PRESENT	0
386212	386194	19745F	PARTICIPANT	\N	PRESENT	0
386213	386194	04088S	PARTICIPANT	\N	PRESENT	0
386214	386194	19503N	PARTICIPANT	\N	PRESENT	0
386215	386194	11097X	PARTICIPANT	\N	PRESENT	0
391677	377992	11099A	PARTICIPANT	\N	PRESENT	0
391678	391356	19479G	PARTICIPANT	\N	PRESENT	0
391679	391356	14121F	PARTICIPANT	\N	PRESENT	0
391708	377992	14257W	PARTICIPANT	\N	PRESENT	0
391716	377992	14227Q	PARTICIPANT	\N	PRESENT	0
391717	377992	01043Q	PARTICIPANT	\N	PRESENT	0
391806	378003	19543W	PARTICIPANT	\N	PRESENT	0
391807	378003	19349W	PARTICIPANT	\N	PRESENT	0
391808	378003	19782L	PARTICIPANT	\N	PRESENT	0
391809	378003	05008E	PARTICIPANT	\N	PRESENT	0
391810	378003	14215L	PARTICIPANT	\N	PRESENT	0
391811	378003	14179A	PARTICIPANT	\N	PRESENT	0
391812	378003	19713W	PARTICIPANT	\N	PRESENT	0
391813	378003	19737F	PARTICIPANT	\N	PRESENT	0
391814	378003	14109K	PARTICIPANT	\N	PRESENT	0
391815	378003	14083S	PARTICIPANT	\N	PRESENT	0
391816	378003	19745F	PARTICIPANT	\N	PRESENT	0
391817	378003	01024M	PARTICIPANT	\N	PRESENT	0
391818	378003	14213J	PARTICIPANT	\N	PRESENT	0
391819	378003	14061L	PARTICIPANT	\N	PRESENT	0
391820	378003	14059S	PARTICIPANT	\N	PRESENT	0
391821	378003	19762G	PARTICIPANT	\N	PRESENT	0
391822	378003	11103C	PARTICIPANT	\N	PRESENT	0
391823	378003	14331P	PARTICIPANT	\N	PRESENT	0
391824	378003	11097X	PARTICIPANT	\N	PRESENT	0
391825	378003	14265W	PARTICIPANT	\N	PRESENT	0
391826	378003	14105F	PARTICIPANT	\N	PRESENT	0
391827	378003	19711U	PARTICIPANT	\N	PRESENT	0
391828	378003	14038Y	PARTICIPANT	\N	PRESENT	0
391829	378003	14187A	PARTICIPANT	\N	PRESENT	0
391830	378003	14217N	PARTICIPANT	\N	PRESENT	0
391831	378003	19693L	PARTICIPANT	\N	PRESENT	0
391832	378003	14157T	PARTICIPANT	\N	PRESENT	0
391833	378003	19507S	PARTICIPANT	\N	PRESENT	0
391834	378003	14135M	PARTICIPANT	\N	PRESENT	0
391835	378003	04088S	PARTICIPANT	\N	PRESENT	0
391836	378003	14199E	PARTICIPANT	\N	PRESENT	0
391837	378003	19467C	PARTICIPANT	\N	PRESENT	0
391838	378003	19703U	PARTICIPANT	\N	PRESENT	0
391839	378003	14053L	PARTICIPANT	\N	PRESENT	0
391840	378003	08020N	PARTICIPANT	\N	PRESENT	0
391841	378003	01058X	PARTICIPANT	\N	PRESENT	0
391842	378003	11012A	PARTICIPANT	\N	PRESENT	0
391843	390060	19725B	PRESIDENT	0	PRESENT	0
391844	390060	11056N	PARTICIPANT	\N	PRESENT	0
391845	390060	04057K	PARTICIPANT	\N	PRESENT	0
391846	390060	19441R	PARTICIPANT	\N	PRESENT	0
391847	390060	04097T	PARTICIPANT	\N	PRESENT	0
391848	390060	14026U	PARTICIPANT	\N	PRESENT	0
391849	390060	08015R	PARTICIPANT	\N	PRESENT	0
391850	390060	14107H	PARTICIPANT	\N	PRESENT	0
391851	390060	14071N	PARTICIPANT	\N	PRESENT	0
391852	390060	19747H	PARTICIPANT	\N	PRESENT	0
391853	390060	14030Q	PARTICIPANT	\N	PRESENT	0
391854	390060	14327T	PARTICIPANT	\N	EXCUSE	0
391855	390060	08073C	PARTICIPANT	\N	EXCUSE	0
391856	390060	19295A	PARTICIPANT	\N	EXCUSE	0
391862	378003	08031R	PARTICIPANT	\N	PRESENT	0
391863	378003	14021P	PARTICIPANT	\N	PRESENT	0
391864	378003	01028R	PARTICIPANT	\N	PRESENT	0
391865	378003	19631V	PARTICIPANT	\N	PRESENT	0
391866	378003	19725B	PARTICIPANT	\N	PRESENT	0
391867	378003	14231L	PARTICIPANT	\N	PRESENT	0
391868	378003	19335Q	PARTICIPANT	\N	PRESENT	0
391869	378003	08015R	PARTICIPANT	\N	PRESENT	0
391870	378003	14026U	PARTICIPANT	\N	PRESENT	0
391871	378003	19621T	PARTICIPANT	\N	PRESENT	0
391872	378003	14042U	PARTICIPANT	\N	PRESENT	0
391873	378003	19563B	PARTICIPANT	\N	PRESENT	0
391874	378003	19719D	PARTICIPANT	\N	PRESENT	0
391875	378003	04047H	PARTICIPANT	\N	PRESENT	0
391876	378003	19679N	PARTICIPANT	\N	PRESENT	0
391877	378003	11056N	PARTICIPANT	\N	PRESENT	0
391878	378003	19760E	PARTICIPANT	\N	PRESENT	0
391879	378003	14197C	PARTICIPANT	\N	PRESENT	0
391880	378003	19415P	PARTICIPANT	\N	PRESENT	0
391881	378003	19689Q	PARTICIPANT	\N	PRESENT	0
391882	378003	14123H	PARTICIPANT	\N	PRESENT	0
391953	378004	04086Q	PARTICIPANT	\N	PRESENT	0
391954	378004	11031D	PARTICIPANT	\N	PRESENT	0
391955	378004	11109J	PARTICIPANT	\N	PRESENT	0
391956	378004	14151M	PARTICIPANT	\N	PRESENT	0
391957	378004	14281W	PARTICIPANT	\N	PRESENT	0
391958	378004	14001X	PARTICIPANT	\N	PRESENT	0
391959	378004	14215L	PARTICIPANT	\N	PRESENT	0
391960	378004	19737F	PARTICIPANT	\N	PRESENT	0
391961	378004	19782L	PARTICIPANT	\N	PRESENT	0
391962	378004	14083S	PARTICIPANT	\N	PRESENT	0
391963	378004	01024M	PARTICIPANT	\N	PRESENT	0
391964	378004	14231L	PARTICIPANT	\N	PRESENT	0
391965	378004	19533U	PARTICIPANT	\N	PRESENT	0
391966	378004	14253S	PARTICIPANT	\N	PRESENT	0
391967	378004	08020N	PARTICIPANT	\N	PRESENT	0
391968	378004	19794Q	PARTICIPANT	\N	PRESENT	0
391969	378004	14195A	PARTICIPANT	\N	PRESENT	0
391970	378004	14038Y	PARTICIPANT	\N	PRESENT	0
391971	378004	19719D	PARTICIPANT	\N	PRESENT	0
391972	378004	19335Q	PARTICIPANT	\N	PRESENT	0
391973	378004	19798U	PARTICIPANT	\N	PRESENT	0
391974	378004	19758L	PARTICIPANT	\N	PRESENT	0
391975	378004	19689Q	PARTICIPANT	\N	PRESENT	0
391976	378004	19413M	PARTICIPANT	\N	PRESENT	0
391977	378004	14179A	PARTICIPANT	\N	PRESENT	0
391978	378004	01028R	PARTICIPANT	\N	PRESENT	0
391979	378004	19479G	PARTICIPANT	\N	PRESENT	0
391980	378004	14042U	PARTICIPANT	\N	PRESENT	0
391981	378004	19760E	PARTICIPANT	\N	PRESENT	0
391982	378004	04085P	PARTICIPANT	\N	PRESENT	0
391983	378004	17583W	PARTICIPANT	\N	PRESENT	0
391984	378004	19631V	PARTICIPANT	\N	PRESENT	0
391985	378004	14021P	PARTICIPANT	\N	PRESENT	0
391986	378004	14053L	PARTICIPANT	\N	PRESENT	0
391987	378004	19543W	PARTICIPANT	\N	PRESENT	0
391988	378004	19253P	PARTICIPANT	\N	PRESENT	0
391989	378004	14259Y	PARTICIPANT	\N	PRESENT	0
391990	378004	19695N	PARTICIPANT	\N	PRESENT	0
391991	378004	19679N	PARTICIPANT	\N	PRESENT	0
391992	378004	08039A	PARTICIPANT	\N	PRESENT	0
391993	378004	14235Q	PARTICIPANT	\N	PRESENT	0
391994	378004	14111D	PARTICIPANT	\N	PRESENT	0
391995	378004	14073Q	PARTICIPANT	\N	PRESENT	0
391996	378004	14249W	PARTICIPANT	\N	PRESENT	0
391997	378004	19709B	PARTICIPANT	\N	PRESENT	0
391998	378004	19545Y	PARTICIPANT	\N	PRESENT	0
391999	378004	14109K	PARTICIPANT	\N	PRESENT	0
392000	378004	14105F	PARTICIPANT	\N	PRESENT	0
392001	378004	14030Q	PARTICIPANT	\N	PRESENT	0
372212	372190	19611R	PARTICIPANT	\N	PRESENT	0
372213	372190	14169X	PARTICIPANT	\N	PRESENT	0
372214	372190	19711U	PARTICIPANT	\N	PRESENT	0
372215	372190	19741B	PARTICIPANT	\N	PRESENT	0
372217	372216	14038Y	PARTICIPANT	\N	PRESENT	0
372218	372216	14265W	PARTICIPANT	\N	PRESENT	0
372220	372216	19333N	PARTICIPANT	\N	PRESENT	0
372221	372216	19599P	PARTICIPANT	\N	PRESENT	0
372222	372216	19349W	PARTICIPANT	\N	PRESENT	0
372223	372216	14026U	PARTICIPANT	\N	PRESENT	0
372224	372216	19611R	PARTICIPANT	\N	PRESENT	0
372225	372216	14169X	PARTICIPANT	\N	PRESENT	0
372227	372216	19711U	PARTICIPANT	\N	PRESENT	0
372228	372216	19741B	PARTICIPANT	\N	PRESENT	0
372294	370851	01028R	PARTICIPANT	\N	PRESENT	0
372732	370820	89017R	PARTICIPANT	\N	EXCUSE	0
372736	370820	14261S	PARTICIPANT	\N	EXCUSE	0
372737	370820	19575F	PARTICIPANT	\N	EXCUSE	0
372739	370820	14030Q	PARTICIPANT	\N	EXCUSE	0
372740	370820	08060W	PARTICIPANT	\N	EXCUSE	0
372741	370820	14105F	PARTICIPANT	\N	PRESENT	0
372742	370820	08068F	PARTICIPANT	\N	EXCUSE	0
372743	370820	14255U	PARTICIPANT	\N	EXCUSE	0
372745	370820	14053L	PARTICIPANT	\N	PRESENT	0
372746	370820	14083S	PARTICIPANT	\N	PRESENT	0
372748	370820	19545Y	PARTICIPANT	\N	EXCUSE	0
372749	370820	14329V	PARTICIPANT	\N	PRESENT	0
372750	370820	14079W	PARTICIPANT	\N	EXCUSE	0
372751	370820	14041T	PARTICIPANT	\N	EXCUSE	0
372752	370820	14187A	PARTICIPANT	\N	PRESENT	0
372753	370820	14087W	PARTICIPANT	\N	PRESENT	0
372766	370820	14026U	PARTICIPANT	\N	EXCUSE	0
372755	370820	19521Q	PARTICIPANT	\N	PRESENT	0
372762	370820	14034U	PARTICIPANT	\N	EXCUSE	0
372769	370820	19591F	PARTICIPANT	\N	PRESENT	0
372771	370820	14121F	PARTICIPANT	\N	PRESENT	0
372775	370820	14061L	PARTICIPANT	\N	EXCUSE	0
372778	370820	11099A	PARTICIPANT	\N	EXCUSE	0
372783	370820	04049K	PRESIDENT	0	PRESENT	0
372786	370820	08015R	PARTICIPANT	\N	PRESENT	0
372791	370820	16685X	PARTICIPANT	\N	EXCUSE	0
372792	370820	19671E	PARTICIPANT	\N	PRESENT	0
372793	370820	14265W	PARTICIPANT	\N	EXCUSE	0
372794	370820	14253S	PARTICIPANT	\N	EXCUSE	0
372795	370820	08047A	PARTICIPANT	\N	EXCUSE	0
372796	370820	04088S	PARTICIPANT	\N	PRESENT	0
372797	370820	14051J	PARTICIPANT	\N	PRESENT	0
372798	370820	19527W	PARTICIPANT	\N	EXCUSE	0
372799	370820	14157T	PARTICIPANT	\N	PRESENT	0
372809	372808	96004D	PRESIDENT	0	PRESENT	0
372810	372808	19725B	PARTICIPANT	\N	PRESENT	0
372811	372808	04097T	PARTICIPANT	\N	PRESENT	0
372812	372808	14073Q	PARTICIPANT	\N	EXCUSE	0
372813	372808	10015M	PARTICIPANT	\N	PRESENT	0
372814	372808	98035U	PARTICIPANT	\N	PRESENT	0
372815	372808	19593H	PARTICIPANT	\N	PRESENT	0
372816	372808	19563B	PARTICIPANT	\N	PRESENT	0
372817	372808	14133K	PARTICIPANT	\N	PRESENT	0
372818	372808	14089Y	PARTICIPANT	\N	PRESENT	0
372819	372808	14061L	PARTICIPANT	\N	EXCUSE	0
372820	372808	14097Y	PARTICIPANT	\N	EXCUSE	0
372825	372808	14241N	PARTICIPANT	\N	EXCUSE	0
372836	367799	14231L	PARTICIPANT	\N	PRESENT	0
372837	367799	11049P	PARTICIPANT	\N	PRESENT	0
372839	367799	19565D	PARTICIPANT	\N	PRESENT	0
372840	367799	01057W	PARTICIPANT	\N	PRESENT	0
372841	367799	14063N	PARTICIPANT	\N	PRESENT	0
372842	367799	14071N	PARTICIPANT	\N	PRESENT	0
372844	367799	14028W	PARTICIPANT	\N	PRESENT	0
372845	367799	19735D	PARTICIPANT	\N	PRESENT	0
372846	367799	08049C	PARTICIPANT	\N	PRESENT	0
372847	367799	95067Q	PARTICIPANT	\N	PRESENT	0
372848	367799	19687N	PARTICIPANT	\N	PRESENT	0
372930	372898	19585H	PARTICIPANT	\N	PRESENT	0
372931	367784	01048V	PARTICIPANT	\N	PRESENT	0
372932	367784	04043D	PARTICIPANT	\N	PRESENT	0
372933	367784	19709B	PARTICIPANT	\N	PRESENT	0
372934	367784	01058X	PARTICIPANT	\N	PRESENT	0
373175	373174	19621T	PARTICIPANT	\N	PRESENT	0
373176	373174	19611R	PARTICIPANT	\N	PRESENT	0
373177	373174	19758L	PARTICIPANT	\N	PRESENT	0
373178	373174	14109K	PARTICIPANT	\N	PRESENT	0
373179	373174	08031R	PARTICIPANT	\N	PRESENT	0
373180	373174	11043H	PARTICIPANT	\N	PRESENT	0
373942	373899	19399H	PARTICIPANT	\N	PRESENT	0
373943	373899	14030Q	PARTICIPANT	\N	PRESENT	0
373944	373899	14251Q	PARTICIPANT	\N	PRESENT	0
373945	373899	08020N	PARTICIPANT	\N	PRESENT	0
373946	373899	04059M	PARTICIPANT	\N	PRESENT	0
373947	373899	14109K	PARTICIPANT	\N	PRESENT	0
373948	373899	11083R	PARTICIPANT	\N	PRESENT	0
373949	373899	14123H	PARTICIPANT	\N	PRESENT	0
373950	373899	11104D	PARTICIPANT	\N	PRESENT	0
373951	373899	19749K	PARTICIPANT	\N	PRESENT	0
373952	373899	19758L	PARTICIPANT	\N	PRESENT	0
373953	373899	19621T	PARTICIPANT	\N	PRESENT	0
373954	373688	08011M	PARTICIPANT	\N	PRESENT	0
373955	373688	89017R	PARTICIPANT	\N	PRESENT	0
373956	373688	19667J	PARTICIPANT	\N	PRESENT	0
373957	373688	07029T	PARTICIPANT	\N	PRESENT	0
373959	373688	14034U	PARTICIPANT	\N	PRESENT	0
373962	373688	19647E	PARTICIPANT	\N	PRESENT	0
373965	373922	14053L	PARTICIPANT	\N	PRESENT	0
373966	373922	14111D	PARTICIPANT	\N	PRESENT	0
373967	373922	19253P	PARTICIPANT	\N	PRESENT	0
373968	373922	19543W	PARTICIPANT	\N	PRESENT	0
373969	373922	04044E	PARTICIPANT	\N	PRESENT	0
373970	373922	04038G	PARTICIPANT	\N	PRESENT	0
373971	373922	04047H	PRESIDENT	1	PRESENT	0
373972	373922	01028R	PARTICIPANT	\N	PRESENT	0
373973	373922	19675J	PARTICIPANT	\N	PRESENT	0
373974	373922	19447X	PARTICIPANT	\N	PRESENT	0
373975	373922	05008E	PRESIDENT	0	PRESENT	0
373976	373922	14231L	PARTICIPANT	\N	PRESENT	0
373977	373922	14089Y	PARTICIPANT	\N	PRESENT	0
373978	373922	19729F	PARTICIPANT	\N	PRESENT	0
373979	373922	19489J	PARTICIPANT	\N	PRESENT	0
373980	373922	14275Y	PARTICIPANT	\N	PRESENT	0
373981	373922	95063L	PARTICIPANT	\N	PRESENT	0
373982	373922	19629C	PARTICIPANT	\N	PRESENT	0
373983	373922	11085T	PARTICIPANT	\N	PRESENT	0
373984	373922	14215L	PARTICIPANT	\N	PRESENT	0
373985	373922	11049P	PARTICIPANT	\N	PRESENT	0
373986	373922	14259Y	PARTICIPANT	\N	PRESENT	0
373987	373922	11072N	PARTICIPANT	\N	PRESENT	0
373988	373922	19762G	PARTICIPANT	\N	PRESENT	0
373989	373922	98035U	PARTICIPANT	\N	PRESENT	0
373990	373922	14147R	PARTICIPANT	\N	PRESENT	0
373991	373922	14065Q	PARTICIPANT	\N	EXCUSE	0
373992	373922	19585H	PARTICIPANT	\N	EXCUSE	0
374001	371820	98024R	PRESIDENT	0	PRESENT	0
374002	371820	04092N	PARTICIPANT	0	PRESENT	0
374003	371820	14355X	PARTICIPANT	\N	EXCUSE	0
374004	371820	14195A	PARTICIPANT	\N	EXCUSE	0
374005	371820	08041T	PARTICIPANT	\N	EXCUSE	0
374006	373899	19766L	PARTICIPANT	\N	PRESENT	0
374007	373899	19699S	PARTICIPANT	\N	PRESENT	0
374008	373899	14249W	PARTICIPANT	\N	PRESENT	0
374009	373899	19643A	PARTICIPANT	\N	PRESENT	0
374010	373899	08035V	PARTICIPANT	\N	PRESENT	0
374011	373899	19735D	PARTICIPANT	\N	PRESENT	0
374012	373899	11043H	PARTICIPANT	\N	PRESENT	0
374013	373899	92040Q	PARTICIPANT	\N	EXCUSE	0
374014	373899	14061L	PARTICIPANT	\N	EXCUSE	0
374015	373899	04018C	PARTICIPANT	\N	EXCUSE	0
374016	373899	04057K	PARTICIPANT	\N	EXCUSE	0
374017	373899	14201E	PARTICIPANT	\N	EXCUSE	0
374018	373899	14059S	PARTICIPANT	\N	PRESENT	0
374019	371820	19697Q	PARTICIPANT	\N	PRESENT	0
374020	371820	11067R	PARTICIPANT	\N	PRESENT	0
374021	371820	01034P	PARTICIPANT	\N	PRESENT	0
374022	371820	19569H	PARTICIPANT	\N	PRESENT	0
374023	371820	11097X	PARTICIPANT	\N	PRESENT	0
374024	371820	08052W	PARTICIPANT	\N	PRESENT	0
374025	371820	19301E	PARTICIPANT	\N	PRESENT	0
374026	371820	19415P	PARTICIPANT	\N	PRESENT	0
374027	371820	19723Y	PARTICIPANT	\N	PRESENT	0
374028	371820	17779H	PARTICIPANT	\N	PRESENT	0
374029	371820	19703U	PARTICIPANT	\N	PRESENT	0
374030	371820	14239U	PARTICIPANT	\N	PRESENT	0
374031	371820	19553Y	PARTICIPANT	\N	PRESENT	0
374032	371820	14119M	PARTICIPANT	\N	PRESENT	0
374033	371820	11103C	PARTICIPANT	\N	PRESENT	0
374034	371820	19679N	PARTICIPANT	\N	PRESENT	0
374035	371820	14042U	PARTICIPANT	\N	PRESENT	0
374036	371820	14071N	PARTICIPANT	\N	PRESENT	0
374037	371820	14217N	PARTICIPANT	\N	PRESENT	0
374038	371820	19683J	PARTICIPANT	\N	PRESENT	0
374039	371820	19565D	PARTICIPANT	\N	PRESENT	0
364786	345239	14085U	PARTICIPANT	\N	PRESENT	0
364787	345239	19253P	PARTICIPANT	\N	PRESENT	0
364788	345239	19565D	PARTICIPANT	\N	PRESENT	0
364789	345239	14229S	PARTICIPANT	\N	PRESENT	0
364790	345239	19549D	PARTICIPANT	\N	PRESENT	0
364915	345240	19695N	PARTICIPANT	\N	PRESENT	0
364920	345240	12041X	PARTICIPANT	\N	PRESENT	0
364921	345240	11031D	PARTICIPANT	\N	PRESENT	0
364922	345240	04038G	PARTICIPANT	\N	PRESENT	0
364923	345240	19758L	PARTICIPANT	\N	PRESENT	0
364924	345240	19565D	PARTICIPANT	\N	PRESENT	0
364925	345240	11056N	PARTICIPANT	\N	PRESENT	0
364926	345240	19593H	PARTICIPANT	\N	PRESENT	0
364927	345240	19760E	PARTICIPANT	\N	PRESENT	0
364928	345240	14211G	PARTICIPANT	\N	PRESENT	0
364929	345240	08061X	PARTICIPANT	\N	PRESENT	0
364930	345240	95037J	PARTICIPANT	\N	PRESENT	0
364931	345240	17637T	PARTICIPANT	\N	PRESENT	0
364932	345240	04045F	PARTICIPANT	\N	PRESENT	0
364933	345240	98029W	PARTICIPANT	\N	PRESENT	0
364934	345240	19711U	PARTICIPANT	\N	PRESENT	0
364935	345240	14239U	PARTICIPANT	\N	PRESENT	0
364936	345240	19651A	PARTICIPANT	\N	PRESENT	0
364937	345240	19637C	PARTICIPANT	\N	PRESENT	0
364938	345240	19543W	PARTICIPANT	\N	PRESENT	0
364939	345240	04008A	PARTICIPANT	\N	PRESENT	0
364940	345240	19697Q	PARTICIPANT	\N	PRESENT	0
364941	345240	19782L	PARTICIPANT	\N	PRESENT	0
364942	345240	14039A	PARTICIPANT	\N	PRESENT	0
364943	345240	08024S	PARTICIPANT	\N	PRESENT	0
364944	345240	19301E	PARTICIPANT	\N	PRESENT	0
364945	345240	11101A	PARTICIPANT	\N	PRESENT	0
364946	345240	08031R	PARTICIPANT	\N	PRESENT	0
364947	345240	04035D	PARTICIPANT	\N	PRESENT	0
364948	345240	14034U	PARTICIPANT	\N	PRESENT	0
364949	345240	88008L	PARTICIPANT	\N	PRESENT	0
364950	345240	08049C	PARTICIPANT	\N	PRESENT	0
364951	345240	14261S	PARTICIPANT	\N	PRESENT	0
364952	345240	98024R	PARTICIPANT	\N	PRESENT	0
364953	345240	19629C	PARTICIPANT	\N	PRESENT	0
364954	345240	19253P	PARTICIPANT	\N	PRESENT	0
364955	345240	11083R	PARTICIPANT	\N	PRESENT	0
364956	345240	95062K	PARTICIPANT	\N	PRESENT	0
364957	345240	19563B	PARTICIPANT	\N	PRESENT	0
364958	345240	14201E	PARTICIPANT	\N	PRESENT	0
364959	345240	19387D	PARTICIPANT	\N	PRESENT	0
364960	345240	14241N	PARTICIPANT	\N	PRESENT	0
364961	345240	14107H	PARTICIPANT	\N	PRESENT	0
364962	345240	19719D	PARTICIPANT	\N	PRESENT	0
364963	345240	11099A	PARTICIPANT	\N	PRESENT	0
364964	345240	19289C	PARTICIPANT	\N	PRESENT	0
364965	345240	19681G	PARTICIPANT	\N	PRESENT	0
364966	345240	14055N	PARTICIPANT	\N	PRESENT	0
364967	345240	08010L	PARTICIPANT	\N	PRESENT	0
364968	345240	19731Y	PARTICIPANT	\N	PRESENT	0
364969	345240	89017R	PARTICIPANT	\N	PRESENT	0
364970	345240	01058X	PARTICIPANT	\N	PRESENT	0
364971	345240	19545Y	PARTICIPANT	\N	PRESENT	0
364972	345240	19585H	PARTICIPANT	\N	PRESENT	0
364973	345240	04057K	PARTICIPANT	\N	PRESENT	0
364974	345240	99004R	PARTICIPANT	\N	PRESENT	0
364975	345240	14195A	PARTICIPANT	\N	PRESENT	0
364976	345240	14251Q	PARTICIPANT	\N	PRESENT	0
364977	345240	95030B	PARTICIPANT	\N	PRESENT	0
364978	345240	11065P	PARTICIPANT	\N	PRESENT	0
364979	345240	04047H	PARTICIPANT	\N	PRESENT	0
364980	345240	19583F	PARTICIPANT	\N	PRESENT	0
364981	345240	11064N	PARTICIPANT	\N	PRESENT	0
364982	345240	02002K	PARTICIPANT	\N	PRESENT	0
364983	345240	19679N	PARTICIPANT	\N	PRESENT	0
364984	345240	04097T	PARTICIPANT	\N	PRESENT	0
364985	345240	14159V	PARTICIPANT	\N	PRESENT	0
364986	345240	08039A	PARTICIPANT	\N	PRESENT	0
364987	345240	11074Q	PARTICIPANT	\N	PRESENT	0
364988	345240	04059M	PARTICIPANT	\N	PRESENT	0
364989	345240	04085P	PARTICIPANT	\N	PRESENT	0
364990	345240	08020N	PARTICIPANT	\N	PRESENT	0
364991	345240	14229S	PARTICIPANT	\N	PRESENT	0
364992	345240	08055A	PARTICIPANT	\N	PRESENT	0
364993	345240	14123H	PARTICIPANT	\N	PRESENT	0
364994	345240	08052W	PARTICIPANT	\N	PRESENT	0
364995	345240	19689Q	PARTICIPANT	\N	PRESENT	0
364996	345240	08069G	PARTICIPANT	\N	PRESENT	0
364997	345240	08068F	PARTICIPANT	\N	PRESENT	0
364998	345240	14051J	PARTICIPANT	\N	PRESENT	0
364999	345240	04092N	PARTICIPANT	\N	PRESENT	0
365000	345240	11033F	PARTICIPANT	\N	PRESENT	0
365001	345240	95041E	PARTICIPANT	\N	PRESENT	0
365002	345240	14151M	PARTICIPANT	\N	PRESENT	0
365003	345240	12016W	PARTICIPANT	\N	PRESENT	0
365004	345240	15447F	PARTICIPANT	\N	PRESENT	0
365005	345240	19715Y	PARTICIPANT	\N	PRESENT	0
365006	345240	04071H	PARTICIPANT	\N	PRESENT	0
365007	345240	19599P	PARTICIPANT	\N	PRESENT	0
365008	345240	08045X	PARTICIPANT	\N	PRESENT	0
365009	345240	10015M	PARTICIPANT	\N	PRESENT	0
365010	345240	14021P	PARTICIPANT	\N	PRESENT	0
365011	345240	19687N	PARTICIPANT	\N	PRESENT	0
365012	345240	01062T	PARTICIPANT	\N	PRESENT	0
365013	345240	08060W	PARTICIPANT	\N	PRESENT	0
365014	345240	01048V	PARTICIPANT	\N	PRESENT	0
365015	345240	08038Y	PARTICIPANT	\N	PRESENT	0
365016	345240	80013X	PARTICIPANT	\N	PRESENT	0
365017	345240	11043H	PARTICIPANT	\N	PRESENT	0
365018	345240	11045K	PARTICIPANT	\N	PRESENT	0
365019	345240	14197C	PARTICIPANT	\N	PRESENT	0
365020	345240	08028W	PARTICIPANT	\N	PRESENT	0
365021	345240	19647E	PARTICIPANT	\N	PRESENT	0
365022	345240	19553Y	PARTICIPANT	\N	PRESENT	0
365023	345240	04033B	PARTICIPANT	\N	PRESENT	0
365024	345240	14187A	PARTICIPANT	\N	PRESENT	0
365025	345240	14065Q	PARTICIPANT	\N	PRESENT	0
365026	345240	19549D	PARTICIPANT	\N	PRESENT	0
365027	345240	11066Q	PARTICIPANT	\N	PRESENT	0
365028	345240	14071N	PARTICIPANT	\N	PRESENT	0
365029	345240	19421M	PARTICIPANT	\N	PRESENT	0
365030	345240	08043V	PARTICIPANT	\N	PRESENT	0
365031	345240	14281W	PARTICIPANT	\N	PRESENT	0
365032	345240	08035V	PARTICIPANT	\N	PRESENT	0
365033	345240	19515S	PARTICIPANT	\N	PRESENT	0
365034	345240	14081Q	PARTICIPANT	\N	PRESENT	0
365035	345240	11110B	PARTICIPANT	\N	PRESENT	0
365036	345240	14191V	PARTICIPANT	\N	PRESENT	0
365037	345240	14257W	PARTICIPANT	\N	PRESENT	0
365038	345240	11080N	PARTICIPANT	\N	PRESENT	0
365039	345240	19525U	PARTICIPANT	\N	PRESENT	0
365040	345240	08053X	PARTICIPANT	\N	PRESENT	0
364913	345240	11040E	PARTICIPANT	\N	PRESENT	0
364914	345240	19347U	PARTICIPANT	\N	PRESENT	0
365042	345240	08017T	PARTICIPANT	\N	PRESENT	0
365043	345240	14085U	PARTICIPANT	\N	PRESENT	0
365044	345240	14121F	PARTICIPANT	\N	PRESENT	0
365045	345240	01057W	PARTICIPANT	\N	PRESENT	0
365046	345240	87003B	PARTICIPANT	\N	PRESENT	0
365047	345240	08058D	PARTICIPANT	\N	PRESENT	0
365048	345240	19489J	PARTICIPANT	\N	PRESENT	0
365049	345240	14223L	PARTICIPANT	\N	PRESENT	0
365050	345240	80027E	PARTICIPANT	\N	PRESENT	0
365051	345240	95067Q	PARTICIPANT	\N	PRESENT	0
365052	345240	19683J	PARTICIPANT	\N	PRESENT	0
365053	345240	14227Q	PARTICIPANT	\N	PRESENT	0
365054	345240	08011M	PARTICIPANT	\N	PRESENT	0
365055	345240	14001X	PARTICIPANT	\N	PRESENT	0
365056	345240	11041F	PARTICIPANT	\N	PRESENT	0
365057	345240	14249W	PARTICIPANT	\N	PRESENT	0
365058	345240	19333N	PARTICIPANT	\N	PRESENT	0
365059	345240	19725B	PARTICIPANT	\N	PRESENT	0
365060	345240	14207L	PARTICIPANT	\N	PRESENT	0
365061	345240	05008E	PARTICIPANT	\N	PRESENT	0
365062	345240	08073C	PARTICIPANT	\N	PRESENT	0
365063	345240	14109K	PARTICIPANT	\N	PRESENT	0
365064	345240	14053L	PARTICIPANT	\N	PRESENT	0
365065	345240	19631V	PARTICIPANT	\N	PRESENT	0
365066	345240	14063N	PARTICIPANT	\N	PRESENT	0
365067	345240	19591F	PARTICIPANT	\N	PRESENT	0
365068	345240	14087W	PARTICIPANT	\N	PRESENT	0
365069	345240	11067R	PARTICIPANT	\N	PRESENT	0
365070	345240	14215L	PARTICIPANT	\N	PRESENT	0
365071	345240	19503N	PARTICIPANT	\N	PRESENT	0
365072	345240	19413M	PARTICIPANT	\N	PRESENT	0
365073	345240	19703U	PARTICIPANT	\N	PRESENT	0
365074	345240	19251M	PARTICIPANT	\N	PRESENT	0
365075	345240	19673G	PARTICIPANT	\N	PRESENT	0
365076	345240	11012A	PARTICIPANT	\N	PRESENT	0
365077	345240	11010L	PARTICIPANT	\N	PRESENT	0
365078	345240	14093U	PARTICIPANT	\N	PRESENT	0
365079	345240	14031R	PARTICIPANT	\N	PRESENT	0
382544	371535	14069U	PARTICIPANT	\N	PRESENT	0
382545	371535	99004R	PARTICIPANT	\N	PRESENT	0
382546	371535	14051J	PARTICIPANT	\N	PRESENT	0
382547	371535	14205J	PARTICIPANT	\N	PRESENT	0
382548	371535	14109K	PARTICIPANT	\N	PRESENT	0
382549	371535	11049P	PARTICIPANT	\N	PRESENT	0
382550	371535	19713W	PARTICIPANT	\N	PRESENT	0
382551	371535	08015R	PARTICIPANT	\N	PRESENT	0
382552	371535	14061L	PARTICIPANT	\N	PRESENT	0
382553	371535	19737F	PARTICIPANT	\N	PRESENT	0
382554	371535	80013X	PARTICIPANT	\N	PRESENT	0
382555	371535	14081Q	PARTICIPANT	\N	PRESENT	0
382556	371535	07029T	PARTICIPANT	\N	PRESENT	0
382557	371535	19533U	PARTICIPANT	\N	PRESENT	0
382562	371535	08062Y	PARTICIPANT	\N	PRESENT	0
382567	371535	19251M	PARTICIPANT	\N	PRESENT	0
382568	371535	88008L	PARTICIPANT	\N	PRESENT	0
382571	378930	14255U	PARTICIPANT	\N	PRESENT	0
382572	371535	08010L	PARTICIPANT	\N	PRESENT	0
382573	371535	14079W	PARTICIPANT	\N	PRESENT	0
382574	371535	14042U	PARTICIPANT	\N	PRESENT	0
382580	371535	14038Y	PARTICIPANT	\N	PRESENT	0
382581	371535	19687N	PARTICIPANT	\N	PRESENT	0
382582	371535	08034U	PARTICIPANT	\N	PRESENT	0
382583	371535	19593H	PARTICIPANT	\N	PRESENT	0
382584	371535	19695N	PARTICIPANT	\N	PRESENT	0
382585	371535	01062T	PARTICIPANT	\N	PRESENT	0
382586	371535	16685X	PARTICIPANT	\N	PRESENT	0
382587	371535	19563B	PARTICIPANT	\N	PRESENT	0
382588	371535	11066Q	PARTICIPANT	\N	PRESENT	0
382589	371535	19691J	PARTICIPANT	\N	PRESENT	0
382590	371535	14107H	PARTICIPANT	\N	PRESENT	0
382591	371535	14031R	PARTICIPANT	\N	PRESENT	0
382592	371535	14179A	PARTICIPANT	\N	PRESENT	0
382593	371535	14034U	PARTICIPANT	\N	PRESENT	0
382600	371535	89017R	PARTICIPANT	\N	PRESENT	0
382609	371535	14021P	PARTICIPANT	\N	PRESENT	0
382610	371535	08011M	PARTICIPANT	\N	PRESENT	0
382611	371535	14093U	PARTICIPANT	\N	PRESENT	0
385532	377919	14187A	PARTICIPANT	\N	PRESENT	0
385533	377919	19421M	PARTICIPANT	\N	PRESENT	0
385534	377919	14215L	PARTICIPANT	\N	PRESENT	0
385535	377919	14223L	PARTICIPANT	\N	PRESENT	0
385536	377919	95030B	PARTICIPANT	\N	PRESENT	0
385537	377919	19760E	PARTICIPANT	\N	PRESENT	0
385538	377919	19758L	PARTICIPANT	\N	PRESENT	0
385539	377919	11031D	PARTICIPANT	\N	PRESENT	0
385540	377919	19387D	PARTICIPANT	\N	PRESENT	0
385541	377919	19531S	PARTICIPANT	\N	PRESENT	0
385542	377919	19723Y	PARTICIPANT	\N	PRESENT	0
385543	377919	08062Y	PARTICIPANT	\N	PRESENT	0
385544	377919	19715Y	PARTICIPANT	\N	PRESENT	0
385545	377919	04088S	PARTICIPANT	\N	PRESENT	0
385546	377919	19575F	PARTICIPANT	\N	PRESENT	0
385547	377919	14259Y	PARTICIPANT	\N	PRESENT	0
385548	377919	04033B	PARTICIPANT	\N	PRESENT	0
385549	377919	11109J	PARTICIPANT	\N	PRESENT	0
385550	377919	14195A	PARTICIPANT	\N	PRESENT	0
385551	377919	14083S	PARTICIPANT	\N	PRESENT	0
385552	377919	11048N	PARTICIPANT	\N	PRESENT	0
385553	377919	14265W	PARTICIPANT	\N	PRESENT	0
385554	377919	14026U	PARTICIPANT	\N	PRESENT	0
385555	377919	14205J	PARTICIPANT	\N	PRESENT	0
385556	377919	19349W	PARTICIPANT	\N	PRESENT	0
385557	377919	08031R	PARTICIPANT	\N	PRESENT	0
385558	377919	19697Q	PARTICIPANT	\N	PRESENT	0
385559	377919	19762G	PARTICIPANT	\N	PRESENT	0
385560	377919	19747H	PARTICIPANT	\N	PRESENT	0
385561	377919	19621T	PARTICIPANT	\N	PRESENT	0
385530	377919	19533U	PARTICIPANT	\N	PRESENT	0
385531	377919	14071N	PARTICIPANT	\N	PRESENT	0
385562	377919	19507S	PARTICIPANT	\N	PRESENT	0
385563	377919	11077T	PARTICIPANT	\N	PRESENT	0
385564	377919	14061L	PARTICIPANT	\N	PRESENT	0
385565	377919	19369B	PARTICIPANT	\N	PRESENT	0
385566	377919	14257W	PARTICIPANT	\N	PRESENT	0
385567	377919	19441R	PARTICIPANT	\N	PRESENT	0
385568	377919	04097T	PARTICIPANT	\N	PRESENT	0
385569	377919	19679N	PARTICIPANT	\N	PRESENT	0
385570	377919	08015R	PARTICIPANT	\N	PRESENT	0
385571	377919	04047H	PARTICIPANT	\N	PRESENT	0
385572	377919	14207L	PARTICIPANT	\N	PRESENT	0
385573	377919	14197C	PARTICIPANT	\N	PRESENT	0
385574	377919	14069U	PARTICIPANT	\N	PRESENT	0
385575	377919	11099A	PARTICIPANT	\N	PRESENT	0
385576	377919	08061X	PARTICIPANT	\N	PRESENT	0
385577	377919	14033T	PARTICIPANT	\N	PRESENT	0
385578	377919	19768N	PARTICIPANT	\N	PRESENT	0
385579	377919	19573D	PARTICIPANT	\N	PRESENT	0
385580	377919	14231L	PARTICIPANT	\N	PRESENT	0
385581	377919	19347U	PARTICIPANT	\N	PRESENT	0
385582	377919	14147R	PARTICIPANT	\N	PRESENT	0
385583	377919	19569H	PARTICIPANT	\N	PRESENT	0
385584	377919	07029T	PARTICIPANT	\N	PRESENT	0
386116	377920	19565D	PARTICIPANT	\N	PRESENT	0
386117	377920	14235Q	PARTICIPANT	\N	PRESENT	0
386118	377920	19369B	PARTICIPANT	\N	PRESENT	0
386119	377920	14089Y	PARTICIPANT	\N	PRESENT	0
386120	377920	19701S	PARTICIPANT	\N	PRESENT	0
386121	377920	14223L	PARTICIPANT	\N	PRESENT	0
386122	377920	01058X	PARTICIPANT	\N	PRESENT	0
386123	377920	19758L	PARTICIPANT	\N	PRESENT	0
386124	377920	17589D	PARTICIPANT	\N	PRESENT	0
386125	377920	19581D	PARTICIPANT	\N	PRESENT	0
386126	377920	19387D	PARTICIPANT	\N	PRESENT	0
386127	377920	14225N	PARTICIPANT	\N	PRESENT	0
386128	377920	14327T	PARTICIPANT	\N	PRESENT	0
386129	377920	14213J	PARTICIPANT	\N	PRESENT	0
386131	377920	19367Y	PARTICIPANT	\N	PRESENT	0
386132	377920	95030B	PARTICIPANT	\N	PRESENT	0
386133	377920	19703U	PARTICIPANT	\N	PRESENT	0
386134	377920	14119M	PARTICIPANT	\N	PRESENT	0
386135	377920	08056B	PARTICIPANT	\N	PRESENT	0
386138	377920	14219Q	PARTICIPANT	\N	PRESENT	0
386142	377920	19727D	PARTICIPANT	\N	PRESENT	0
386148	377920	10006L	PARTICIPANT	\N	PRESENT	0
386158	377920	19760E	PARTICIPANT	\N	PRESENT	0
386164	377920	19525U	PARTICIPANT	\N	PRESENT	0
386167	377920	14097Y	PARTICIPANT	\N	PRESENT	0
386172	377920	04088S	PARTICIPANT	\N	PRESENT	0
386173	377920	19723Y	PARTICIPANT	\N	PRESENT	0
386174	377920	19533U	PARTICIPANT	\N	PRESENT	0
386175	377920	11103C	PARTICIPANT	\N	PRESENT	0
386176	377920	14031R	PARTICIPANT	\N	PRESENT	0
386177	377920	08028W	PARTICIPANT	\N	PRESENT	0
386178	377920	19798U	PARTICIPANT	\N	PRESENT	0
386179	377920	14227Q	PARTICIPANT	\N	PRESENT	0
386180	377920	19689Q	PARTICIPANT	\N	PRESENT	0
386181	377920	11031D	PARTICIPANT	\N	PRESENT	0
386182	377920	97011G	PARTICIPANT	\N	PRESENT	0
386183	377920	19549D	PARTICIPANT	\N	PRESENT	0
386184	377920	14029X	PARTICIPANT	\N	PRESENT	0
386185	377920	08014Q	PARTICIPANT	\N	PRESENT	0
386186	377920	19679N	PARTICIPANT	\N	PRESENT	0
386187	377920	14187A	PARTICIPANT	\N	PRESENT	0
386188	377920	98050T	PARTICIPANT	\N	PRESENT	0
386189	377920	14265W	PARTICIPANT	\N	PRESENT	0
386190	377920	14179A	PARTICIPANT	\N	PRESENT	0
386191	377920	14107H	PARTICIPANT	\N	PRESENT	0
386192	377920	19511N	PARTICIPANT	\N	PRESENT	0
386193	377920	11033F	PARTICIPANT	\N	PRESENT	0
386216	377920	15447F	PARTICIPANT	\N	PRESENT	0
386217	377920	19663E	PARTICIPANT	\N	PRESENT	0
386218	377920	19745F	PARTICIPANT	\N	PRESENT	0
386219	377920	14241N	PARTICIPANT	\N	PRESENT	0
386220	377920	19253P	PARTICIPANT	\N	PRESENT	0
386222	377920	19657G	PARTICIPANT	\N	PRESENT	0
386223	377920	19768N	PARTICIPANT	\N	PRESENT	0
386224	377920	19713W	PARTICIPANT	\N	PRESENT	0
386225	377920	04045F	PARTICIPANT	\N	PRESENT	0
386226	377920	14123H	PARTICIPANT	\N	PRESENT	0
386227	377920	99004R	PARTICIPANT	\N	PRESENT	0
386228	377920	08020N	PARTICIPANT	\N	PRESENT	0
386229	377920	04043D	PARTICIPANT	\N	PRESENT	0
386230	377920	11104D	PARTICIPANT	\N	PRESENT	0
386232	377920	14079W	PARTICIPANT	\N	PRESENT	0
386233	377920	14217N	PARTICIPANT	\N	PRESENT	0
386237	377920	19543W	PARTICIPANT	\N	PRESENT	0
386238	377920	19749K	PARTICIPANT	\N	PRESENT	0
386239	377920	19697Q	PARTICIPANT	\N	PRESENT	0
386241	377920	02002K	PARTICIPANT	\N	PRESENT	0
386242	377920	14071N	PARTICIPANT	\N	PRESENT	0
386243	377920	08010L	PARTICIPANT	\N	PRESENT	0
386244	377920	19507S	PARTICIPANT	\N	PRESENT	0
386245	377920	18083K	PARTICIPANT	\N	PRESENT	0
386246	377920	98022P	PARTICIPANT	\N	PRESENT	0
386247	377920	14147R	PARTICIPANT	\N	PRESENT	0
386248	377920	80027E	PARTICIPANT	\N	PRESENT	0
371230	369086	08041T	PARTICIPANT	\N	EXCUSE	0
371231	369086	19697Q	PARTICIPANT	\N	PRESENT	0
371232	369086	14355X	PARTICIPANT	\N	PRESENT	0
371233	369086	04092N	PRESIDENT	0	PRESENT	0
371234	369086	08052W	PARTICIPANT	\N	PRESENT	0
371235	369086	19657G	PARTICIPANT	\N	PRESENT	0
371236	369086	11103C	PARTICIPANT	\N	PRESENT	0
371237	369086	19798U	PARTICIPANT	\N	PRESENT	0
371238	369086	14227Q	PARTICIPANT	\N	PRESENT	0
371239	369086	19301E	PARTICIPANT	\N	PRESENT	0
371240	369086	19715Y	PARTICIPANT	\N	PRESENT	0
371241	369086	14217N	PARTICIPANT	\N	PRESENT	0
371242	369086	14261S	PARTICIPANT	\N	PRESENT	0
371243	369086	19569H	PARTICIPANT	\N	PRESENT	0
371244	369086	19415P	PARTICIPANT	\N	PRESENT	0
371245	369086	19691J	PARTICIPANT	\N	PRESENT	0
371246	369086	19717B	PARTICIPANT	\N	PRESENT	0
371247	369086	17779H	PARTICIPANT	\N	PRESENT	0
371248	369086	19679N	PARTICIPANT	\N	PRESENT	0
371249	369086	14195A	PARTICIPANT	\N	PRESENT	0
371250	369086	14071N	PARTICIPANT	\N	PRESENT	0
371251	369086	19683J	PARTICIPANT	\N	PRESENT	0
371252	369086	98024R	PARTICIPANT	\N	PRESENT	0
371253	369086	19521Q	PARTICIPANT	\N	PRESENT	0
371271	370534	19383Y	PARTICIPANT	\N	PRESENT	0
371272	370534	19333N	PARTICIPANT	\N	PRESENT	0
371273	370534	17583W	PARTICIPANT	\N	PRESENT	0
371274	370534	19794Q	PARTICIPANT	\N	PRESENT	0
371275	370534	19549D	PARTICIPANT	\N	PRESENT	0
371276	370534	19387D	PARTICIPANT	\N	PRESENT	0
371277	370534	14219Q	PARTICIPANT	\N	PRESENT	0
371278	370534	14221J	PARTICIPANT	\N	PRESENT	0
371279	370534	19551W	PARTICIPANT	\N	PRESENT	0
371280	370534	80027E	PARTICIPANT	\N	PRESENT	0
371281	370534	05012A	PARTICIPANT	\N	PRESENT	0
371282	370534	14051J	PARTICIPANT	\N	PRESENT	0
371283	370534	08060W	PARTICIPANT	\N	PRESENT	0
371284	370534	19347U	PARTICIPANT	\N	PRESENT	0
371285	370534	19503N	PARTICIPANT	\N	PRESENT	0
371286	370534	14157T	PARTICIPANT	\N	PRESENT	0
371287	370534	14038Y	PARTICIPANT	\N	PRESENT	0
371288	370534	14103D	PARTICIPANT	\N	PRESENT	0
371289	370534	14031R	PARTICIPANT	\N	PRESENT	0
371290	370534	19713W	PARTICIPANT	\N	PRESENT	0
371291	370534	14191V	PARTICIPANT	\N	PRESENT	0
371292	370534	15447F	PARTICIPANT	\N	PRESENT	0
371293	370534	08009T	PRESIDENT	0	PRESENT	0
371294	370534	19739H	PARTICIPANT	\N	PRESENT	0
371295	370534	04097T	PARTICIPANT	\N	PRESENT	0
371296	370534	19745F	PARTICIPANT	\N	PRESENT	0
371297	370534	19659J	PARTICIPANT	\N	PRESENT	0
371298	370534	19685L	PARTICIPANT	\N	EXCUSE	0
371299	370534	08055A	PARTICIPANT	\N	EXCUSE	0
371300	370534	08024S	PARTICIPANT	\N	EXCUSE	0
371301	370534	19525U	PARTICIPANT	\N	EXCUSE	0
371302	370534	18083K	PARTICIPANT	\N	PRESENT	0
371303	370534	19737F	PARTICIPANT	\N	PRESENT	0
371304	369086	19553Y	PARTICIPANT	\N	PRESENT	0
371305	370534	19599P	PARTICIPANT	\N	PRESENT	0
371306	370534	17637T	PARTICIPANT	\N	PRESENT	0
371307	370534	96004D	PARTICIPANT	\N	PRESENT	0
371308	369086	19663E	PARTICIPANT	\N	PRESENT	0
371309	369691	95030B	PARTICIPANT	\N	PRESENT	0
371310	369691	14133K	PARTICIPANT	\N	PRESENT	0
371311	369691	11041F	PARTICIPANT	\N	PRESENT	0
371312	369691	04034C	PARTICIPANT	\N	PRESENT	0
371313	369691	14235Q	PARTICIPANT	\N	PRESENT	0
371314	369691	04042C	PRESIDENT	0	PRESENT	0
371315	369691	14028W	PARTICIPANT	\N	PRESENT	0
371316	369691	11066Q	PARTICIPANT	\N	PRESENT	0
371317	369691	19709B	PARTICIPANT	\N	PRESENT	0
371318	369691	14267Y	PARTICIPANT	\N	PRESENT	0
371319	369691	14211G	PARTICIPANT	\N	PRESENT	0
371320	369691	19583F	PARTICIPANT	\N	PRESENT	0
371321	369691	08047A	PARTICIPANT	\N	PRESENT	0
371322	370534	19701S	PARTICIPANT	\N	PRESENT	0
371323	370534	95062K	PARTICIPANT	\N	PRESENT	0
371324	370534	11065P	PARTICIPANT	\N	PRESENT	0
371325	370534	14169X	PARTICIPANT	\N	PRESENT	0
371326	370534	04085P	PARTICIPANT	\N	PRESENT	0
371327	369691	04040A	PARTICIPANT	\N	PRESENT	0
371328	369691	11054L	PARTICIPANT	\N	PRESENT	0
371329	369691	08061X	PARTICIPANT	\N	PRESENT	0
371330	369691	98018T	PARTICIPANT	\N	EXCUSE	0
371331	369691	01062T	PARTICIPANT	\N	EXCUSE	0
371332	369691	14079W	PARTICIPANT	\N	EXCUSE	0
371333	369691	98050T	PARTICIPANT	\N	EXCUSE	0
371334	369691	98029W	PARTICIPANT	\N	EXCUSE	0
371335	369691	11064N	PARTICIPANT	\N	PRESENT	0
371336	369691	08058D	PARTICIPANT	\N	PRESENT	0
371338	369842	14327T	PARTICIPANT	\N	PRESENT	0
371339	369842	14331P	PARTICIPANT	\N	PRESENT	0
371340	369842	04071H	PARTICIPANT	\N	PRESENT	0
371341	369842	19545Y	PARTICIPANT	\N	PRESENT	0
371342	369842	01057W	PARTICIPANT	\N	PRESENT	0
371343	369842	89017R	PARTICIPANT	\N	PRESENT	0
371344	369842	11074Q	PRESIDENT	0	PRESENT	0
371345	369842	14225N	PARTICIPANT	\N	PRESENT	0
371346	369842	88008L	PARTICIPANT	\N	PRESENT	0
371347	369842	19671E	PARTICIPANT	\N	PRESENT	0
371348	369842	11070L	PARTICIPANT	\N	PRESENT	0
371349	369842	14277B	PARTICIPANT	\N	PRESENT	0
371350	369842	14085U	PARTICIPANT	\N	PRESENT	0
371351	369842	19349W	PARTICIPANT	\N	PRESENT	0
371352	369842	19479G	PARTICIPANT	\N	PRESENT	0
371355	369842	11048N	PARTICIPANT	\N	PRESENT	0
371357	369842	19711U	PARTICIPANT	\N	PRESENT	0
371360	369842	08034U	PARTICIPANT	\N	PRESENT	0
371362	369842	19531S	PARTICIPANT	\N	PRESENT	0
371363	369842	08069G	PARTICIPANT	\N	PRESENT	0
371365	369842	19687N	PARTICIPANT	\N	PRESENT	0
371366	369842	08011M	PARTICIPANT	\N	PRESENT	0
371368	369842	11040E	PARTICIPANT	\N	PRESENT	0
371370	369842	14083S	PARTICIPANT	\N	PRESENT	0
371374	369842	14121F	PARTICIPANT	\N	PRESENT	0
371376	369842	19741B	PARTICIPANT	\N	PRESENT	0
371378	369842	99004R	PARTICIPANT	\N	PRESENT	0
371381	369842	04086Q	PARTICIPANT	\N	EXCUSE	0
371383	369842	07029T	PARTICIPANT	\N	EXCUSE	0
371387	369842	08010L	PARTICIPANT	\N	EXCUSE	0
371429	369090	19697Q	PARTICIPANT	\N	PRESENT	0
371430	369090	14355X	PARTICIPANT	\N	PRESENT	0
371431	369090	19565D	PARTICIPANT	\N	PRESENT	0
371432	369090	19798U	PARTICIPANT	\N	PRESENT	0
371433	369090	19569H	PARTICIPANT	\N	PRESENT	0
371434	369090	19415P	PARTICIPANT	\N	PRESENT	0
371435	369090	14223L	PARTICIPANT	\N	PRESENT	0
371436	369090	04045F	PARTICIPANT	\N	PRESENT	0
371437	369090	14026U	PARTICIPANT	\N	PRESENT	0
371438	369090	14227Q	PARTICIPANT	\N	PRESENT	0
371439	369090	17779H	PARTICIPANT	\N	PRESENT	0
371440	369090	14239U	PARTICIPANT	\N	PRESENT	0
371441	369090	11031D	PARTICIPANT	\N	PRESENT	0
371442	369090	19703U	PARTICIPANT	\N	PRESENT	0
371443	369090	19553Y	PARTICIPANT	\N	PRESENT	0
371444	369090	14087W	PARTICIPANT	\N	PRESENT	0
371445	369090	14281W	PARTICIPANT	\N	PRESENT	0
371446	369090	19679N	PARTICIPANT	\N	PRESENT	0
371447	369090	14042U	PARTICIPANT	\N	PRESENT	0
371448	369090	14195A	PARTICIPANT	\N	PRESENT	0
371449	369090	19367Y	PARTICIPANT	\N	PRESENT	0
371450	369090	14213J	PARTICIPANT	\N	PRESENT	0
371451	369090	14217N	PARTICIPANT	\N	PRESENT	0
371452	369090	14261S	PARTICIPANT	\N	PRESENT	0
371453	369090	19683J	PARTICIPANT	\N	PRESENT	0
371454	369090	98024R	PARTICIPANT	\N	PRESENT	0
371455	369090	19521Q	PARTICIPANT	\N	PRESENT	0
371456	369090	04092N	PARTICIPANT	\N	PRESENT	0
371457	369090	08052W	PARTICIPANT	\N	PRESENT	0
371458	369090	19663E	PARTICIPANT	\N	PRESENT	0
371459	369090	19301E	PARTICIPANT	\N	PRESENT	0
371460	369090	19715Y	PARTICIPANT	\N	PRESENT	0
371461	369090	19691J	PARTICIPANT	\N	PRESENT	0
371462	369090	19717B	PARTICIPANT	\N	PRESENT	0
371463	369090	19727D	PARTICIPANT	\N	PRESENT	0
371464	369090	14119M	PARTICIPANT	\N	PRESENT	0
371465	369090	11103C	PARTICIPANT	\N	PRESENT	0
371466	369090	19657G	PARTICIPANT	\N	PRESENT	0
371467	369090	14071N	PARTICIPANT	\N	PRESENT	0
371468	369090	19577H	PARTICIPANT	\N	PRESENT	0
371469	369090	19760E	PARTICIPANT	\N	PRESENT	0
371470	369090	08041T	PARTICIPANT	\N	EXCUSE	0
374074	373900	04033B	PARTICIPANT	\N	PRESENT	0
374075	373900	14249W	PARTICIPANT	\N	PRESENT	0
374076	373900	14073Q	PARTICIPANT	\N	PRESENT	0
374077	373900	19735D	PARTICIPANT	\N	PRESENT	0
374078	373900	19621T	PARTICIPANT	\N	PRESENT	0
374081	363531	04044E	PARTICIPANT	\N	PRESENT	0
374082	363531	08014Q	PARTICIPANT	\N	PRESENT	0
374083	363531	12041X	PARTICIPANT	\N	PRESENT	0
374084	363531	14235Q	PARTICIPANT	\N	PRESENT	0
374085	363531	19333N	PARTICIPANT	\N	PRESENT	0
374086	363531	04034C	PARTICIPANT	\N	PRESENT	0
374087	363531	11083R	PARTICIPANT	\N	PRESENT	0
374088	363531	88008L	PARTICIPANT	\N	PRESENT	0
374089	363531	19721W	PARTICIPANT	\N	PRESENT	0
374090	363531	14079W	PARTICIPANT	\N	PRESENT	0
374091	363531	14237S	PARTICIPANT	\N	PRESENT	0
374092	363531	14331P	PARTICIPANT	\N	PRESENT	0
374093	363531	19711U	PARTICIPANT	\N	PRESENT	0
374094	363531	08028W	PARTICIPANT	\N	PRESENT	0
374095	363531	08069G	PARTICIPANT	\N	PRESENT	0
374096	363531	99004R	PARTICIPANT	\N	PRESENT	0
374097	363531	01057W	PARTICIPANT	\N	PRESENT	0
374098	363531	19507S	PARTICIPANT	\N	PRESENT	0
374099	363531	19415P	PARTICIPANT	\N	PRESENT	0
374100	363531	19515S	PARTICIPANT	\N	PRESENT	0
374101	363531	04097T	PARTICIPANT	\N	PRESENT	0
374102	363531	14249W	PARTICIPANT	\N	PRESENT	0
374103	363531	95030B	PARTICIPANT	\N	PRESENT	0
374104	363531	11103C	PARTICIPANT	\N	PRESENT	0
374105	363531	97011G	PARTICIPANT	\N	PRESENT	0
374106	363531	14026U	PARTICIPANT	\N	PRESENT	0
374107	363531	19637C	PARTICIPANT	\N	PRESENT	0
374108	363531	14223L	PARTICIPANT	\N	PRESENT	0
374109	363531	14219Q	PARTICIPANT	\N	PRESENT	0
374110	363531	19479G	PARTICIPANT	\N	PRESENT	0
374111	363531	14029X	PARTICIPANT	\N	PRESENT	0
374112	363531	19747H	PARTICIPANT	\N	PRESENT	0
374113	363531	14053L	PARTICIPANT	\N	PRESENT	0
374114	363531	11064N	PARTICIPANT	\N	PRESENT	0
374115	363531	11066Q	PARTICIPANT	\N	PRESENT	0
374116	363531	11049P	PARTICIPANT	\N	PRESENT	0
374117	363531	96004D	PARTICIPANT	\N	PRESENT	0
374118	363531	01060R	PARTICIPANT	\N	PRESENT	0
374119	363531	19679N	PARTICIPANT	\N	PRESENT	0
374120	363531	14211G	PARTICIPANT	\N	PRESENT	0
374121	363531	19731Y	PARTICIPANT	\N	PRESENT	0
374122	363531	19737F	PARTICIPANT	\N	PRESENT	0
374123	363531	08056B	PARTICIPANT	\N	PRESENT	0
374124	363531	14083S	PARTICIPANT	\N	PRESENT	0
374125	363531	19387D	PARTICIPANT	\N	PRESENT	0
374126	363531	19563B	PARTICIPANT	\N	PRESENT	0
374127	363531	19703U	PARTICIPANT	\N	PRESENT	0
374128	363531	08018U	PARTICIPANT	\N	PRESENT	0
374129	363531	19443T	PARTICIPANT	\N	PRESENT	0
374130	363531	14357A	PARTICIPANT	\N	PRESENT	0
374131	363531	19741B	PARTICIPANT	\N	PRESENT	0
374132	363531	19599P	PARTICIPANT	\N	PRESENT	0
374133	363531	18083K	PARTICIPANT	\N	PRESENT	0
374134	363531	95037J	PARTICIPANT	\N	PRESENT	0
374135	363531	19794Q	PARTICIPANT	\N	PRESENT	0
374040	371820	19798U	PARTICIPANT	\N	PRESENT	0
374041	371820	14227Q	PARTICIPANT	\N	PRESENT	0
374042	371820	11031D	PARTICIPANT	\N	PRESENT	0
374043	371820	14281W	PARTICIPANT	\N	PRESENT	0
374044	371820	19527W	PARTICIPANT	\N	PRESENT	0
374045	371820	19727D	PARTICIPANT	\N	PRESENT	0
374046	371820	19760E	PARTICIPANT	\N	PRESENT	0
374047	373900	04070G	PRESIDENT	0	PRESENT	0
374048	373900	19699S	PARTICIPANT	\N	PRESENT	0
374049	373900	14229S	PARTICIPANT	\N	PRESENT	0
374050	373900	14241N	PARTICIPANT	\N	PRESENT	0
374051	373900	19573D	PARTICIPANT	\N	PRESENT	0
374052	373900	14039A	PARTICIPANT	\N	PRESENT	0
374053	373900	08017T	PARTICIPANT	\N	PRESENT	0
374054	373900	07033P	PARTICIPANT	\N	PRESENT	0
374055	373900	08031R	PARTICIPANT	\N	PRESENT	0
374056	373900	19593H	PARTICIPANT	\N	PRESENT	0
374057	373900	19611R	PARTICIPANT	\N	PRESENT	0
374058	373900	08035V	PARTICIPANT	\N	PRESENT	0
374059	373900	08043V	PARTICIPANT	\N	PRESENT	0
374060	373900	19693L	PARTICIPANT	\N	PRESENT	0
374061	373900	87003B	PARTICIPANT	\N	PRESENT	0
374062	373900	19399H	PARTICIPANT	\N	PRESENT	0
374063	373900	14030Q	PARTICIPANT	\N	PRESENT	0
374064	373900	08020N	PARTICIPANT	\N	PRESENT	0
374065	373900	14251Q	PARTICIPANT	\N	PRESENT	0
374066	373900	04059M	PARTICIPANT	\N	PRESENT	0
374067	373900	14063N	PARTICIPANT	\N	PRESENT	0
374068	373900	14109K	PARTICIPANT	\N	PRESENT	0
374069	373900	14123H	PARTICIPANT	\N	PRESENT	0
374070	373900	11104D	PARTICIPANT	\N	PRESENT	0
374071	373900	19749K	PARTICIPANT	\N	PRESENT	0
374072	373900	04018C	PARTICIPANT	\N	PRESENT	0
374073	373900	19758L	PARTICIPANT	\N	PRESENT	0
374136	363531	14267Y	PARTICIPANT	\N	PRESENT	0
374137	363531	01025N	PARTICIPANT	\N	PRESENT	0
374138	363531	14042U	PARTICIPANT	\N	PRESENT	0
374139	363531	14257W	PARTICIPANT	\N	PRESENT	0
374140	363531	14197C	PARTICIPANT	\N	PRESENT	0
374141	363531	19413M	PARTICIPANT	\N	PRESENT	0
374142	363531	08015R	PARTICIPANT	\N	PRESENT	0
374143	363531	19629C	PARTICIPANT	\N	PRESENT	0
374144	363531	19669L	PARTICIPANT	\N	PRESENT	0
374145	363531	14173T	PARTICIPANT	\N	PRESENT	0
374146	363531	19549D	PARTICIPANT	\N	PRESENT	0
374147	363531	19663E	PARTICIPANT	\N	PRESENT	0
374148	363531	19569H	PARTICIPANT	\N	PRESENT	0
374150	363531	17583W	PARTICIPANT	\N	PRESENT	0
374151	363531	15447F	PARTICIPANT	\N	PRESENT	0
374152	363531	14028W	PARTICIPANT	\N	PRESENT	0
374153	363531	19441R	PARTICIPANT	\N	PRESENT	0
374154	363531	14115H	PARTICIPANT	\N	PRESENT	0
374155	363531	19631V	PARTICIPANT	\N	PRESENT	0
374156	363531	11072N	PARTICIPANT	\N	PRESENT	0
374157	363531	80013X	PARTICIPANT	\N	PRESENT	0
374158	363531	04088S	PARTICIPANT	\N	PRESENT	0
374159	363531	14033T	PARTICIPANT	\N	PRESENT	0
374160	363531	08021P	PARTICIPANT	\N	PRESENT	0
374161	363531	19349W	PARTICIPANT	\N	PRESENT	0
374162	363531	19467C	PARTICIPANT	\N	PRESENT	0
374163	363531	14265W	PARTICIPANT	\N	PRESENT	0
374257	373993	14053L	PARTICIPANT	\N	PRESENT	0
374258	373993	19253P	PARTICIPANT	\N	PRESENT	0
374259	373993	19543W	PARTICIPANT	\N	PRESENT	0
374260	373993	19581D	PARTICIPANT	\N	PRESENT	0
374261	373993	04047H	PARTICIPANT	\N	PRESENT	0
374262	373993	19675J	PARTICIPANT	\N	PRESENT	0
374263	373993	11033F	PARTICIPANT	\N	PRESENT	0
374264	373993	05008E	PRESIDENT	0	PRESENT	0
374265	373993	19447X	PARTICIPANT	\N	PRESENT	0
374266	373993	14231L	PARTICIPANT	\N	PRESENT	0
374267	373993	14089Y	PARTICIPANT	\N	PRESENT	0
374268	373993	19489J	PARTICIPANT	\N	PRESENT	0
374269	373993	19729F	PARTICIPANT	\N	PRESENT	0
374270	373993	95063L	PARTICIPANT	\N	PRESENT	0
374271	373993	14147R	PARTICIPANT	\N	PRESENT	0
374272	373993	14215L	PARTICIPANT	\N	PRESENT	0
374273	373993	11085T	PARTICIPANT	\N	PRESENT	0
374274	373993	11049P	PARTICIPANT	\N	PRESENT	0
374275	373993	11072N	PARTICIPANT	\N	PRESENT	0
374276	373993	19762G	PARTICIPANT	\N	PRESENT	0
374277	373993	98035U	PARTICIPANT	\N	PRESENT	0
374278	373993	19725B	PARTICIPANT	\N	PRESENT	0
374279	373993	08045X	PARTICIPANT	\N	PRESENT	0
374280	373993	01060R	PARTICIPANT	\N	PRESENT	0
374281	373993	01028R	PARTICIPANT	\N	PRESENT	0
374282	373993	14065Q	PARTICIPANT	\N	EXCUSE	0
374283	373993	19585H	PARTICIPANT	\N	EXCUSE	0
374284	363532	19443T	PARTICIPANT	\N	PRESENT	0
374285	363532	19768N	PARTICIPANT	\N	PRESENT	0
374286	363532	14357A	PARTICIPANT	\N	PRESENT	0
374287	363532	98050T	PARTICIPANT	\N	PRESENT	0
374288	363532	14157T	PARTICIPANT	\N	PRESENT	0
374289	363532	95030B	PARTICIPANT	\N	PRESENT	0
374290	363532	14223L	PARTICIPANT	\N	PRESENT	0
374291	363532	14169X	PARTICIPANT	\N	PRESENT	0
374292	363532	08069G	PARTICIPANT	\N	PRESENT	0
374293	363532	19533U	PARTICIPANT	\N	PRESENT	0
374294	363532	01058X	PARTICIPANT	\N	PRESENT	0
374295	363532	19693L	PARTICIPANT	\N	PRESENT	0
374296	363532	99004R	PARTICIPANT	\N	PRESENT	0
374297	363532	19679N	PARTICIPANT	\N	PRESENT	0
374298	363532	08028W	PARTICIPANT	\N	PRESENT	0
374299	363532	08020N	PARTICIPANT	\N	PRESENT	0
374300	363532	14123H	PARTICIPANT	\N	PRESENT	0
374301	363532	19729F	PARTICIPANT	\N	PRESENT	0
374302	363532	19711U	PARTICIPANT	\N	PRESENT	0
374303	363532	98024R	PARTICIPANT	\N	PRESENT	0
374304	363532	19766L	PARTICIPANT	\N	PRESENT	0
362939	361687	19619A	PARTICIPANT	\N	PRESENT	0
362940	361687	19745F	PARTICIPANT	\N	PRESENT	0
365080	345240	04089T	PARTICIPANT	\N	PRESENT	0
365081	345240	11115U	PARTICIPANT	\N	PRESENT	0
365082	345240	14231L	PARTICIPANT	\N	PRESENT	0
365083	345240	14179A	PARTICIPANT	\N	PRESENT	0
365084	345240	14199E	PARTICIPANT	\N	PRESENT	0
365085	345240	19369B	PARTICIPANT	\N	PRESENT	0
365086	345240	19575F	PARTICIPANT	\N	PRESENT	0
365087	345240	11053K	PARTICIPANT	\N	PRESENT	0
365088	345240	14253S	PARTICIPANT	\N	PRESENT	0
365089	345240	19691J	PARTICIPANT	\N	PRESENT	0
365090	345240	19611R	PARTICIPANT	\N	PRESENT	0
365091	345240	19511N	PARTICIPANT	\N	PRESENT	0
365092	345240	11048N	PARTICIPANT	\N	PRESENT	0
365093	345240	05012A	PARTICIPANT	\N	PRESENT	0
365094	345240	19551W	PARTICIPANT	\N	PRESENT	0
365095	345240	19721W	PARTICIPANT	\N	PRESENT	0
365096	345240	14205J	PARTICIPANT	\N	PRESENT	0
365097	345240	19737F	PARTICIPANT	\N	PRESENT	0
365098	345240	19569H	PARTICIPANT	\N	PRESENT	0
365099	345240	08034U	PARTICIPANT	\N	PRESENT	0
365100	345240	08056B	PARTICIPANT	\N	PRESENT	0
365101	345240	19735D	PARTICIPANT	\N	PRESENT	0
365102	345240	19533U	PARTICIPANT	\N	PRESENT	0
365103	345240	16685X	PARTICIPANT	\N	PRESENT	0
365104	345240	14042U	PARTICIPANT	\N	PRESENT	0
365105	345240	14219Q	PARTICIPANT	\N	PRESENT	0
365106	345240	19479G	PARTICIPANT	\N	PRESENT	0
365107	345240	19713W	PARTICIPANT	\N	PRESENT	0
365108	345240	08009T	PARTICIPANT	\N	PRESENT	0
365109	345240	04086Q	PARTICIPANT	\N	PRESENT	0
365110	345240	19441R	PARTICIPANT	\N	PRESENT	0
365111	345240	14267Y	PARTICIPANT	\N	PRESENT	0
365112	345240	14221J	PARTICIPANT	\N	PRESENT	0
365113	345240	19335Q	PARTICIPANT	\N	PRESENT	0
365114	345240	11090Q	PARTICIPANT	\N	PRESENT	0
365115	345240	19739H	PARTICIPANT	\N	PRESENT	0
365116	345240	01034P	PARTICIPANT	\N	PRESENT	0
365117	345240	14089Y	PARTICIPANT	\N	PRESENT	0
365118	345240	14073Q	PARTICIPANT	\N	PRESENT	0
365119	345240	96004D	PARTICIPANT	\N	PRESENT	0
365120	345240	19749K	PARTICIPANT	\N	PRESENT	0
365121	345240	19521Q	PARTICIPANT	\N	PRESENT	0
365122	345240	14169X	PARTICIPANT	\N	PRESENT	0
365123	345240	14255U	PARTICIPANT	\N	PRESENT	0
365124	345240	04049K	PARTICIPANT	\N	PRESENT	0
365125	345240	11085T	PARTICIPANT	\N	PRESENT	0
365126	345240	04040A	PARTICIPANT	\N	PRESENT	0
365127	345240	04070G	PARTICIPANT	\N	PRESENT	0
365128	345240	01025N	PARTICIPANT	\N	PRESENT	0
365129	345240	01024M	PARTICIPANT	\N	PRESENT	0
365130	345240	10006L	PARTICIPANT	\N	PRESENT	0
365131	345240	14030Q	PARTICIPANT	\N	PRESENT	0
365132	345240	14327T	PARTICIPANT	\N	PRESENT	0
365133	345240	19798U	PARTICIPANT	\N	PRESENT	0
365134	345240	14237S	PARTICIPANT	\N	PRESENT	0
365135	345240	14173T	PARTICIPANT	\N	PRESENT	0
365136	345240	04042C	PARTICIPANT	\N	PRESENT	0
365137	345240	19447X	PARTICIPANT	\N	PRESENT	0
365138	345240	86034E	PARTICIPANT	\N	PRESENT	0
365139	345240	14225N	PARTICIPANT	\N	PRESENT	0
365140	345240	19573D	PARTICIPANT	\N	PRESENT	0
365141	345240	11077T	PARTICIPANT	\N	PRESENT	0
365142	345240	11027H	PARTICIPANT	\N	PRESENT	0
365143	345240	11049P	PARTICIPANT	\N	PRESENT	0
365144	345240	14105F	PARTICIPANT	\N	PRESENT	0
365145	345240	14097Y	PARTICIPANT	\N	PRESENT	0
365146	345240	19794Q	PARTICIPANT	\N	PRESENT	0
365147	345240	14133K	PARTICIPANT	\N	PRESENT	0
365148	345240	92040Q	PARTICIPANT	\N	PRESENT	0
365149	345240	14119M	PARTICIPANT	\N	PRESENT	0
365150	345240	08047A	PARTICIPANT	\N	PRESENT	0
365151	345240	14083S	PARTICIPANT	\N	PRESENT	0
365152	345240	17589D	PARTICIPANT	\N	PRESENT	0
365153	345240	17583W	PARTICIPANT	\N	PRESENT	0
365154	345240	14147R	PARTICIPANT	\N	PRESENT	0
365155	345240	97011G	PARTICIPANT	\N	PRESENT	0
365156	345240	11103C	PARTICIPANT	\N	PRESENT	0
365157	345240	07033P	PARTICIPANT	\N	PRESENT	0
365158	345240	14217N	PARTICIPANT	\N	PRESENT	0
365159	345240	14331P	PARTICIPANT	\N	PRESENT	0
365160	345240	19581D	PARTICIPANT	\N	PRESENT	0
365161	345240	19671E	PARTICIPANT	\N	PRESENT	0
365162	345240	19747H	PARTICIPANT	\N	PRESENT	0
365163	345240	19723Y	PARTICIPANT	\N	PRESENT	0
365164	345240	19467C	PARTICIPANT	\N	PRESENT	0
365165	345240	18083K	PARTICIPANT	\N	PRESENT	0
365166	345240	19415P	PARTICIPANT	\N	PRESENT	0
365167	345240	14033T	PARTICIPANT	\N	PRESENT	0
365168	345240	14135M	PARTICIPANT	\N	PRESENT	0
365169	345240	01043Q	PARTICIPANT	\N	PRESENT	0
365170	345240	08019V	PARTICIPANT	\N	PRESENT	0
365171	345240	19399H	PARTICIPANT	\N	PRESENT	0
365172	345240	19693L	PARTICIPANT	\N	PRESENT	0
365173	345240	14265W	PARTICIPANT	\N	PRESENT	0
365174	345240	08048B	PARTICIPANT	\N	PRESENT	0
365175	345240	14329V	PARTICIPANT	\N	PRESENT	0
365176	345240	17779H	PARTICIPANT	\N	PRESENT	0
365177	345240	14259Y	PARTICIPANT	\N	PRESENT	0
365178	345240	14357A	PARTICIPANT	\N	PRESENT	0
365179	345240	19675J	PARTICIPANT	\N	PRESENT	0
365180	345240	19383Y	PARTICIPANT	\N	PRESENT	0
365181	345240	19762G	PARTICIPANT	\N	PRESENT	0
365182	345240	19701S	PARTICIPANT	\N	PRESENT	0
365183	345240	19717B	PARTICIPANT	\N	PRESENT	0
365184	345240	04018C	PARTICIPANT	\N	PRESENT	0
365185	345240	19621T	PARTICIPANT	\N	PRESENT	0
365186	345240	19443T	PARTICIPANT	\N	PRESENT	0
365187	345240	19741B	PARTICIPANT	\N	PRESENT	0
365188	345240	19768N	PARTICIPANT	\N	PRESENT	0
365189	345240	14029X	PARTICIPANT	\N	PRESENT	0
365190	345240	19507S	PARTICIPANT	\N	PRESENT	0
365191	345240	14213J	PARTICIPANT	\N	PRESENT	0
365192	345240	19663E	PARTICIPANT	\N	PRESENT	0
365193	345240	04088S	PARTICIPANT	\N	PRESENT	0
365194	345240	14041T	PARTICIPANT	\N	PRESENT	0
365195	345240	08018U	PARTICIPANT	\N	PRESENT	0
365196	345240	07029T	PARTICIPANT	\N	PRESENT	0
365197	345240	19705W	PARTICIPANT	\N	PRESENT	0
365204	345240	14061L	PARTICIPANT	\N	PRESENT	0
365199	345240	08062Y	PARTICIPANT	\N	PRESENT	0
365200	345240	14059S	PARTICIPANT	\N	PRESENT	0
365201	345240	08015R	PARTICIPANT	\N	PRESENT	0
365207	345240	19367Y	PARTICIPANT	\N	PRESENT	0
365203	345240	98050T	PARTICIPANT	\N	PRESENT	0
365205	345240	19733B	PARTICIPANT	\N	PRESENT	0
365206	345240	14355X	PARTICIPANT	\N	PRESENT	0
365208	345240	14069U	PARTICIPANT	\N	PRESENT	0
365209	345240	14038Y	PARTICIPANT	\N	PRESENT	0
365210	345240	14026U	PARTICIPANT	\N	PRESENT	0
365211	345240	11097X	PARTICIPANT	\N	PRESENT	0
365212	345240	19709B	PARTICIPANT	\N	PRESENT	0
365213	345240	11109J	PARTICIPANT	\N	PRESENT	0
365226	345240	08044W	PARTICIPANT	\N	PRESENT	0
365227	345240	95063L	PARTICIPANT	\N	PRESENT	0
365778	345242	14029X	PARTICIPANT	\N	PRESENT	0
365779	345242	14038Y	PARTICIPANT	\N	PRESENT	0
365780	345242	19794Q	PARTICIPANT	\N	PRESENT	0
365781	345242	14033T	PARTICIPANT	\N	PRESENT	0
365782	345242	08019V	PARTICIPANT	\N	PRESENT	0
365783	345242	19741B	PARTICIPANT	\N	PRESENT	0
365784	345242	19733B	PARTICIPANT	\N	PRESENT	0
365785	345242	19551W	PARTICIPANT	\N	PRESENT	0
365786	345242	08062Y	PARTICIPANT	\N	PRESENT	0
365787	345242	14231L	PARTICIPANT	\N	PRESENT	0
365788	345242	19723Y	PARTICIPANT	\N	PRESENT	0
365789	345242	19758L	PARTICIPANT	\N	PRESENT	0
365790	345242	19760E	PARTICIPANT	\N	PRESENT	0
365791	345242	08060W	PARTICIPANT	\N	PRESENT	0
365792	345242	19387D	PARTICIPANT	\N	PRESENT	0
365793	345242	14053L	PARTICIPANT	\N	PRESENT	0
365794	345242	14215L	PARTICIPANT	\N	PRESENT	0
365795	345242	04049K	PARTICIPANT	\N	PRESENT	0
365796	345242	19349W	PARTICIPANT	\N	PRESENT	0
365797	345242	14105F	PARTICIPANT	\N	PRESENT	0
365798	345242	14059S	PARTICIPANT	\N	PRESENT	0
365799	345242	19573D	PARTICIPANT	\N	PRESENT	0
365800	345242	19701S	PARTICIPANT	\N	PRESENT	0
365801	345242	19681G	PARTICIPANT	\N	PRESENT	0
365802	345242	14187A	PARTICIPANT	\N	PRESENT	0
365803	345242	14069U	PARTICIPANT	\N	PRESENT	0
365804	345242	14265W	PARTICIPANT	\N	PRESENT	0
365805	345242	08015R	PARTICIPANT	\N	PRESENT	0
365806	345242	11043H	PARTICIPANT	\N	PRESENT	0
365807	345242	17583W	PARTICIPANT	\N	PRESENT	0
365808	345242	05012A	PARTICIPANT	\N	PRESENT	0
365809	345242	11048N	PARTICIPANT	\N	PRESENT	0
386249	377920	14197C	PARTICIPANT	\N	PRESENT	0
386253	377920	19691J	PARTICIPANT	\N	PRESENT	0
386254	377920	19441R	PARTICIPANT	\N	PRESENT	0
386255	377920	19737F	PARTICIPANT	\N	PRESENT	0
386256	377920	19715Y	PARTICIPANT	\N	PRESENT	0
386257	377920	08055A	PARTICIPANT	\N	PRESENT	0
386258	377920	01057W	PARTICIPANT	\N	PRESENT	0
386259	377920	19447X	PARTICIPANT	\N	PRESENT	0
386260	377920	14083S	PARTICIPANT	\N	PRESENT	0
386261	377920	14205J	PARTICIPANT	\N	PRESENT	0
386262	377920	14061L	PARTICIPANT	\N	PRESENT	0
386263	377920	11043H	PARTICIPANT	\N	PRESENT	0
386264	377920	80013X	PARTICIPANT	\N	PRESENT	0
386265	377920	12016W	PARTICIPANT	\N	PRESENT	0
386266	377920	14039A	PARTICIPANT	\N	PRESENT	0
386267	377920	08034U	PARTICIPANT	\N	PRESENT	0
386268	385964	19575F	PARTICIPANT	\N	EXCUSE	0
386269	377920	14135M	PARTICIPANT	\N	PRESENT	0
386270	377920	14030Q	PARTICIPANT	\N	PRESENT	0
386271	377920	14257W	PARTICIPANT	\N	PRESENT	0
386272	377920	08045X	PARTICIPANT	\N	PRESENT	0
386273	377920	01024M	PARTICIPANT	\N	PRESENT	0
386274	377920	19747H	PARTICIPANT	\N	PRESENT	0
386275	377920	14026U	PARTICIPANT	\N	PRESENT	0
386276	377920	14237S	PARTICIPANT	\N	PRESENT	0
386277	377920	14259Y	PARTICIPANT	\N	PRESENT	0
386278	377920	19573D	PARTICIPANT	\N	PRESENT	0
386279	377920	08031R	PARTICIPANT	\N	PRESENT	0
386280	377920	08015R	PARTICIPANT	\N	PRESENT	0
386281	377920	19527W	PARTICIPANT	\N	PRESENT	0
386282	377920	17779H	PARTICIPANT	\N	PRESENT	0
386283	377920	19349W	PARTICIPANT	\N	PRESENT	0
386284	377920	08061X	PARTICIPANT	\N	PRESENT	0
386285	377920	14207L	PARTICIPANT	\N	PRESENT	0
386286	377920	14249W	PARTICIPANT	\N	PRESENT	0
386287	377920	19667J	PARTICIPANT	\N	PRESENT	0
386288	377920	14191V	PARTICIPANT	\N	PRESENT	0
386289	377920	11048N	PARTICIPANT	\N	PRESENT	0
386290	377920	11054L	PARTICIPANT	\N	PRESENT	0
386297	377920	01025N	PARTICIPANT	\N	PRESENT	0
386298	377920	19725B	PARTICIPANT	\N	PRESENT	0
386299	377920	19695N	PARTICIPANT	\N	PRESENT	0
386300	377920	04085P	PARTICIPANT	\N	PRESENT	0
386301	377920	19413M	PARTICIPANT	\N	PRESENT	0
386302	377920	08038Y	PARTICIPANT	\N	PRESENT	0
386303	377920	14115H	PARTICIPANT	\N	PRESENT	0
386304	377920	11066Q	PARTICIPANT	\N	PRESENT	0
386308	384448	14327T	PARTICIPANT	\N	PRESENT	0
386306	377920	08044W	PARTICIPANT	\N	PRESENT	0
386307	377920	19521Q	PARTICIPANT	\N	PRESENT	0
386309	384448	01048V	PARTICIPANT	\N	PRESENT	0
386310	384448	14081Q	PARTICIPANT	\N	PRESENT	0
386311	384448	19667J	PARTICIPANT	\N	PRESENT	0
386312	384448	11074Q	PRESIDENT	0	PRESENT	0
386313	384448	89017R	PARTICIPANT	\N	PRESENT	0
386314	384448	19671E	PARTICIPANT	\N	PRESENT	0
386315	384448	88008L	PARTICIPANT	\N	PRESENT	0
386316	384448	14225N	PARTICIPANT	\N	PRESENT	0
386317	384448	14085U	PARTICIPANT	\N	PRESENT	0
386318	384448	19349W	PARTICIPANT	\N	PRESENT	0
386319	384448	08010L	PARTICIPANT	\N	PRESENT	0
386320	384448	11048N	PARTICIPANT	\N	PRESENT	0
386321	384448	19479G	PARTICIPANT	\N	PRESENT	0
386322	384448	19711U	PARTICIPANT	\N	PRESENT	0
386323	384448	19651A	PARTICIPANT	\N	PRESENT	0
386324	384448	08034U	PARTICIPANT	\N	PRESENT	0
386325	384448	14187A	PARTICIPANT	\N	PRESENT	0
386326	384448	19689Q	PARTICIPANT	\N	PRESENT	0
386327	384448	12016W	PARTICIPANT	\N	PRESENT	0
386328	384448	08014Q	PARTICIPANT	\N	PRESENT	0
386329	384448	04086Q	PARTICIPANT	\N	PRESENT	0
386330	384448	11040E	PARTICIPANT	\N	PRESENT	0
386331	384448	14083S	PARTICIPANT	\N	PRESENT	0
386332	384448	14119M	PARTICIPANT	\N	PRESENT	0
386333	384448	11012A	PARTICIPANT	\N	PRESENT	0
386334	384448	19741B	PARTICIPANT	\N	PRESENT	0
386335	384448	99004R	PARTICIPANT	\N	PRESENT	0
386336	377920	14199E	PARTICIPANT	\N	PRESENT	0
386337	377920	11010L	PARTICIPANT	\N	PRESENT	0
386338	377920	87003B	PARTICIPANT	\N	PRESENT	0
386339	377920	19782L	PARTICIPANT	\N	PRESENT	0
386340	377920	08019V	PARTICIPANT	\N	PRESENT	0
386341	377920	04033B	PARTICIPANT	\N	PRESENT	0
386342	377920	14038Y	PARTICIPANT	\N	PRESENT	0
386344	386343	19667J	PARTICIPANT	\N	PRESENT	0
386345	386343	19701S	PARTICIPANT	\N	PRESENT	0
386346	377920	19599P	PARTICIPANT	\N	PRESENT	0
386347	377920	08049C	PARTICIPANT	\N	PRESENT	0
386348	377920	19531S	PARTICIPANT	\N	PRESENT	0
386349	377920	19563B	PARTICIPANT	\N	PRESENT	0
386350	377920	04057K	PARTICIPANT	\N	PRESENT	0
386351	384448	11053K	PARTICIPANT	\N	PRESENT	0
386352	384448	07029T	PARTICIPANT	\N	EXCUSE	0
386353	377920	19729F	PARTICIPANT	\N	PRESENT	0
386354	377920	04047H	PARTICIPANT	\N	PRESENT	0
386355	377920	19719D	PARTICIPANT	\N	PRESENT	0
386356	377920	08062Y	PARTICIPANT	\N	PRESENT	0
386359	377920	12041X	PARTICIPANT	\N	PRESENT	0
386363	377920	14069U	PARTICIPANT	\N	PRESENT	0
386367	377920	11012A	PARTICIPANT	\N	PRESENT	0
386374	377920	14231L	PARTICIPANT	\N	PRESENT	0
386502	377922	04044E	PARTICIPANT	\N	PRESENT	0
386377	377920	19631V	PARTICIPANT	\N	PRESENT	0
386378	377920	11109J	PARTICIPANT	\N	PRESENT	0
386379	377920	19503N	PARTICIPANT	\N	PRESENT	0
386380	377920	19479G	PARTICIPANT	\N	PRESENT	0
386381	377920	19347U	PARTICIPANT	\N	PRESENT	0
386382	377920	08012N	PARTICIPANT	\N	PRESENT	0
386383	377920	08053X	PARTICIPANT	\N	PRESENT	0
386384	377920	14221J	PARTICIPANT	\N	PRESENT	0
386385	377920	19295A	PARTICIPANT	\N	PRESENT	0
386386	377920	19335Q	PARTICIPANT	\N	PRESENT	0
386387	377920	19421M	PARTICIPANT	\N	PRESENT	0
386388	377920	05012A	PARTICIPANT	\N	PRESENT	0
386503	377922	04092N	PARTICIPANT	\N	PRESENT	0
386504	377922	11031D	PARTICIPANT	\N	PRESENT	0
386505	377922	19715Y	PARTICIPANT	\N	PRESENT	0
386506	377922	11109J	PARTICIPANT	\N	PRESENT	0
386507	377922	19503N	PARTICIPANT	\N	PRESENT	0
386508	377922	17779H	PARTICIPANT	\N	PRESENT	0
386509	377922	19599P	PARTICIPANT	\N	PRESENT	0
386510	377922	08055A	PARTICIPANT	\N	PRESENT	0
386511	377922	14223L	PARTICIPANT	\N	PRESENT	0
386512	377922	19683J	PARTICIPANT	\N	PRESENT	0
386513	377922	99004R	PARTICIPANT	\N	PRESENT	0
386514	377922	08052W	PARTICIPANT	\N	PRESENT	0
386515	377922	08012N	PARTICIPANT	\N	PRESENT	0
386516	377922	19703U	PARTICIPANT	\N	PRESENT	0
386517	377922	14097Y	PARTICIPANT	\N	PRESENT	0
386518	377922	19295A	PARTICIPANT	\N	PRESENT	0
386519	377922	19798U	PARTICIPANT	\N	PRESENT	0
386520	377922	19782L	PARTICIPANT	\N	PRESENT	0
386521	377922	19367Y	PARTICIPANT	\N	PRESENT	0
386522	377922	04045F	PARTICIPANT	\N	PRESENT	0
386523	377922	14239U	PARTICIPANT	\N	PRESENT	0
386524	377922	01025N	PARTICIPANT	\N	PRESENT	0
386525	377922	14195A	PARTICIPANT	\N	PRESENT	0
386526	377922	19629C	PARTICIPANT	\N	PRESENT	0
386527	377922	19657G	PARTICIPANT	\N	PRESENT	0
386528	377922	19553Y	PARTICIPANT	\N	PRESENT	0
386529	377922	19713W	PARTICIPANT	\N	PRESENT	0
386530	377922	19719D	PARTICIPANT	\N	PRESENT	0
386531	377922	19691J	PARTICIPANT	\N	PRESENT	0
386532	377922	14042U	PARTICIPANT	\N	PRESENT	0
386533	377922	19663E	PARTICIPANT	\N	PRESENT	0
386534	377922	19347U	PARTICIPANT	\N	PRESENT	0
386535	377922	19737F	PARTICIPANT	\N	PRESENT	0
386536	377922	19758L	PARTICIPANT	\N	PRESENT	0
386537	377922	12016W	PARTICIPANT	\N	PRESENT	0
386538	377922	19760E	PARTICIPANT	\N	PRESENT	0
386539	377922	19565D	PARTICIPANT	\N	PRESENT	0
386540	377922	19415P	PARTICIPANT	\N	PRESENT	0
386541	377922	14157T	PARTICIPANT	\N	PRESENT	0
386542	377922	19549D	PARTICIPANT	\N	PRESENT	0
386543	377922	14030Q	PARTICIPANT	\N	PRESENT	0
386544	377922	14147R	PARTICIPANT	\N	PRESENT	0
386545	377922	19794Q	PARTICIPANT	\N	PRESENT	0
386546	377922	08056B	PARTICIPANT	\N	PRESENT	0
386547	377922	14207L	PARTICIPANT	\N	PRESENT	0
386552	377922	98024R	PARTICIPANT	\N	PRESENT	0
386549	377922	14213J	PARTICIPANT	\N	PRESENT	0
386550	377922	14029X	PARTICIPANT	\N	PRESENT	0
386551	377922	14089Y	PARTICIPANT	\N	PRESENT	0
386553	377922	19421M	PARTICIPANT	\N	PRESENT	0
386554	377922	14187A	PARTICIPANT	\N	PRESENT	0
386555	377922	11043H	PARTICIPANT	\N	PRESENT	0
386556	377922	11097X	PARTICIPANT	\N	PRESENT	0
386557	377922	19531S	PARTICIPANT	\N	PRESENT	0
386558	377922	11067R	PARTICIPANT	\N	PRESENT	0
371551	369842	14253S	PARTICIPANT	\N	PRESENT	0
371552	369842	12016W	PARTICIPANT	\N	PRESENT	0
371553	369842	11012A	PARTICIPANT	\N	PRESENT	0
371554	368991	19768N	PARTICIPANT	\N	PRESENT	0
371555	368991	19515S	PARTICIPANT	\N	PRESENT	0
371556	368991	19782L	PARTICIPANT	\N	PRESENT	0
371557	368991	14357A	PARTICIPANT	\N	PRESENT	0
371558	368991	19441R	PARTICIPANT	\N	PRESENT	0
371559	368991	19413M	PARTICIPANT	\N	PRESENT	0
371560	368991	80013X	PARTICIPANT	\N	PRESENT	0
371561	368991	08068F	PARTICIPANT	\N	PRESENT	0
371562	368991	04049K	PARTICIPANT	\N	PRESENT	0
371563	368991	19705W	PARTICIPANT	\N	PRESENT	0
371564	368991	08019V	PARTICIPANT	\N	PRESENT	0
371565	368991	14197C	PARTICIPANT	\N	PRESENT	0
371566	368991	19563B	PARTICIPANT	\N	PRESENT	0
371567	368991	14265W	PARTICIPANT	\N	PRESENT	0
371568	368991	14135M	PARTICIPANT	\N	PRESENT	0
371569	368991	14038Y	PARTICIPANT	\N	PRESENT	0
371570	368991	19467C	PARTICIPANT	\N	PRESENT	0
371571	368991	14187A	PARTICIPANT	\N	PRESENT	0
371572	368991	08038Y	PARTICIPANT	\N	PRESENT	0
371573	368991	19695N	PARTICIPANT	\N	PRESENT	0
371574	368991	11090Q	PRESIDENT	0	PRESENT	0
371575	368991	01025N	PARTICIPANT	\N	PRESENT	0
371576	368991	19269X	PARTICIPANT	\N	PRESENT	0
371577	368991	14205J	PARTICIPANT	\N	PRESENT	0
371578	368991	11056N	PARTICIPANT	\N	PRESENT	0
371579	368991	19507S	PARTICIPANT	\N	PRESENT	0
371580	368991	11101A	PARTICIPANT	\N	PRESENT	0
371581	368991	14207L	PARTICIPANT	\N	PRESENT	0
371582	368991	04043D	PARTICIPANT	\N	PRESENT	0
371583	368991	14257W	PARTICIPANT	\N	PRESENT	0
371584	368991	19369B	PARTICIPANT	\N	PRESENT	0
371585	368991	14033T	PARTICIPANT	\N	PRESENT	0
371586	368991	11099A	PARTICIPANT	\N	PRESENT	0
371587	368991	08021P	PARTICIPANT	\N	EXCUSE	0
371588	368991	11081P	PARTICIPANT	\N	EXCUSE	0
371589	368991	19631V	PARTICIPANT	\N	EXCUSE	0
371590	370966	04070G	PRESIDENT	0	PRESENT	0
371591	370966	19699S	PARTICIPANT	\N	PRESENT	0
371592	370966	19533U	PARTICIPANT	\N	PRESENT	0
371593	370966	14229S	PARTICIPANT	\N	PRESENT	0
371594	370966	14241N	PARTICIPANT	\N	PRESENT	0
371595	370966	19573D	PARTICIPANT	\N	PRESENT	0
371596	370966	14039A	PARTICIPANT	\N	PRESENT	0
371597	370966	14107H	PARTICIPANT	\N	PRESENT	0
371598	370966	08017T	PARTICIPANT	\N	PRESENT	0
371599	370966	92040Q	PARTICIPANT	\N	PRESENT	0
371600	370966	07033P	PARTICIPANT	\N	PRESENT	0
371601	370966	08012N	PARTICIPANT	\N	PRESENT	0
371602	370966	08039A	PARTICIPANT	\N	PRESENT	0
371603	370966	08031R	PARTICIPANT	\N	PRESENT	0
371604	370966	19593H	PARTICIPANT	\N	PRESENT	0
371605	370966	14059S	PARTICIPANT	\N	PRESENT	0
371606	370966	19643A	PARTICIPANT	\N	PRESENT	0
371607	370966	04057K	PARTICIPANT	\N	PRESENT	0
371608	370966	19611R	PARTICIPANT	\N	PRESENT	0
371609	370966	87003B	PARTICIPANT	\N	PRESENT	0
371610	370966	19399H	PARTICIPANT	\N	PRESENT	0
371611	370966	14030Q	PARTICIPANT	\N	PRESENT	0
371612	370966	08020N	PARTICIPANT	\N	PRESENT	0
371613	370966	04059M	PARTICIPANT	\N	PRESENT	0
371614	370966	11109J	PARTICIPANT	\N	PRESENT	0
371615	370966	14063N	PARTICIPANT	\N	PRESENT	0
371616	370966	11083R	PARTICIPANT	\N	PRESENT	0
371617	370966	14123H	PARTICIPANT	\N	PRESENT	0
371618	370966	11043H	PARTICIPANT	\N	PRESENT	0
371619	370966	11104D	PARTICIPANT	\N	PRESENT	0
371620	370966	19749K	PARTICIPANT	\N	PRESENT	0
371621	370966	04018C	PARTICIPANT	\N	PRESENT	0
371622	370966	19758L	PARTICIPANT	\N	PRESENT	0
371623	370966	19621T	PARTICIPANT	\N	PRESENT	0
371624	370966	14061L	PARTICIPANT	\N	EXCUSE	0
371625	370966	14073Q	PARTICIPANT	\N	EXCUSE	0
371626	370966	08043V	PARTICIPANT	\N	EXCUSE	0
371627	370966	19693L	PARTICIPANT	\N	EXCUSE	0
371628	370966	14249W	PARTICIPANT	\N	EXCUSE	0
373712	373711	14147R	PARTICIPANT	\N	PRESENT	0
373733	373732	17779H	PARTICIPANT	\N	PRESENT	0
373734	373732	11097X	PARTICIPANT	\N	PRESENT	0
373735	373731	17779H	PARTICIPANT	\N	PRESENT	0
373736	373731	11097X	PARTICIPANT	\N	PRESENT	0
373737	373730	17779H	PARTICIPANT	\N	PRESENT	0
373738	373730	11097X	PARTICIPANT	\N	PRESENT	0
385706	384105	19768N	PARTICIPANT	\N	PRESENT	0
373740	373729	11097X	PARTICIPANT	\N	PRESENT	0
373741	373727	17779H	PARTICIPANT	\N	PRESENT	0
373742	373727	11097X	PARTICIPANT	\N	PRESENT	0
376604	376603	14187A	PARTICIPANT	\N	PRESENT	0
379887	378391	08048B	PARTICIPANT	\N	EXCUSE	0
380097	378391	08038Y	PARTICIPANT	\N	EXCUSE	0
385707	384105	19782L	PARTICIPANT	\N	PRESENT	0
385708	384105	01043Q	PARTICIPANT	\N	PRESENT	0
385709	384105	19441R	PARTICIPANT	\N	PRESENT	0
385710	384105	19413M	PARTICIPANT	\N	PRESENT	0
385711	384105	80013X	PARTICIPANT	\N	PRESENT	0
385712	384105	11099A	PARTICIPANT	\N	PRESENT	0
385713	384105	04049K	PARTICIPANT	\N	PRESENT	0
385714	384105	08015R	PARTICIPANT	\N	PRESENT	0
385715	384105	08019V	PARTICIPANT	\N	PRESENT	0
385716	384105	14197C	PARTICIPANT	\N	PRESENT	0
385717	384105	19369B	PARTICIPANT	\N	PRESENT	0
385718	384105	19511N	PARTICIPANT	\N	PRESENT	0
385719	384105	08028W	PARTICIPANT	\N	PRESENT	0
385720	384105	19563B	PARTICIPANT	\N	PRESENT	0
385721	384105	14265W	PARTICIPANT	\N	PRESENT	0
385722	384105	14329V	PARTICIPANT	\N	PRESENT	0
385723	384105	19591F	PARTICIPANT	\N	PRESENT	0
385724	384105	14135M	PARTICIPANT	\N	PRESENT	0
385725	384105	14187A	PARTICIPANT	\N	PRESENT	0
385726	384105	08062Y	PARTICIPANT	\N	PRESENT	0
385727	384105	19695N	PARTICIPANT	\N	PRESENT	0
385728	384105	14033T	PARTICIPANT	\N	PRESENT	0
385729	384105	11090Q	PRESIDENT	0	PRESENT	0
385730	384105	01025N	PARTICIPANT	\N	PRESENT	0
385731	384105	19269X	PARTICIPANT	\N	PRESENT	0
385732	384105	14205J	PARTICIPANT	\N	PRESENT	0
385733	384105	04088S	PARTICIPANT	\N	PRESENT	0
385734	384105	11056N	PARTICIPANT	\N	PRESENT	0
385735	384105	04089T	PARTICIPANT	\N	PRESENT	0
385736	384105	14115H	PARTICIPANT	\N	PRESENT	0
385737	384105	11101A	PARTICIPANT	\N	PRESENT	0
385738	384105	19507S	PARTICIPANT	\N	PRESENT	0
385739	384105	19747H	PARTICIPANT	\N	PRESENT	0
385740	384105	14207L	PARTICIPANT	\N	PRESENT	0
385741	384105	19619A	PARTICIPANT	\N	PRESENT	0
385742	384105	14257W	PARTICIPANT	\N	PRESENT	0
385743	384105	19467C	PARTICIPANT	\N	EXCUSE	0
385744	384105	19515S	PARTICIPANT	\N	EXCUSE	0
385745	384105	14357A	PARTICIPANT	\N	EXCUSE	0
385746	384105	08021P	PARTICIPANT	\N	EXCUSE	0
374305	363532	08010L	PARTICIPANT	\N	PRESENT	0
374306	363532	14038Y	PARTICIPANT	\N	PRESENT	0
374307	363532	14187A	PARTICIPANT	\N	PRESENT	0
374308	363532	04047H	PARTICIPANT	\N	PRESENT	0
374309	363532	04033B	PARTICIPANT	\N	PRESENT	0
374310	363532	04085P	PARTICIPANT	\N	PRESENT	0
374311	363532	11040E	PARTICIPANT	\N	PRESENT	0
374312	363532	14235Q	PARTICIPANT	\N	PRESENT	0
374313	363532	19758L	PARTICIPANT	\N	PRESENT	0
374314	363532	19347U	PARTICIPANT	\N	PRESENT	0
374315	363532	12041X	PARTICIPANT	\N	PRESENT	0
374316	363532	11033F	PARTICIPANT	\N	PRESENT	0
374317	363532	11077T	PARTICIPANT	\N	PRESENT	0
374318	363532	19593H	PARTICIPANT	\N	PRESENT	0
374319	363532	19695N	PARTICIPANT	\N	PRESENT	0
374320	363532	19687N	PARTICIPANT	\N	PRESENT	0
374321	363532	04038G	PARTICIPANT	\N	PRESENT	0
374322	363532	08061X	PARTICIPANT	\N	PRESENT	0
374323	363532	17637T	PARTICIPANT	\N	PRESENT	0
374324	363532	95063L	PARTICIPANT	\N	PRESENT	0
374325	363532	95037J	PARTICIPANT	\N	PRESENT	0
374326	363532	14239U	PARTICIPANT	\N	PRESENT	0
374327	363532	14059S	PARTICIPANT	\N	PRESENT	0
374328	363532	19651A	PARTICIPANT	\N	PRESENT	0
374329	363532	08039A	PARTICIPANT	\N	PRESENT	0
374330	363532	19349W	PARTICIPANT	\N	PRESENT	0
374331	363532	19637C	PARTICIPANT	\N	PRESENT	0
374332	363532	96004D	PARTICIPANT	\N	PRESENT	0
374333	363532	19269X	PARTICIPANT	\N	PRESENT	0
374334	363532	08021P	PARTICIPANT	\N	PRESENT	0
374335	363532	19697Q	PARTICIPANT	\N	PRESENT	0
374336	363532	14039A	PARTICIPANT	\N	PRESENT	0
374337	363532	08024S	PARTICIPANT	\N	PRESENT	0
374338	363532	19782L	PARTICIPANT	\N	PRESENT	0
374339	363532	19301E	PARTICIPANT	\N	PRESENT	0
374341	363532	19329S	PARTICIPANT	\N	PRESENT	0
374342	363532	14026U	PARTICIPANT	\N	PRESENT	0
374344	363532	11012A	PARTICIPANT	\N	PRESENT	0
374345	363532	88008L	PARTICIPANT	\N	PRESENT	0
374347	363532	08049C	PARTICIPANT	\N	PRESENT	0
374349	363532	19629C	PARTICIPANT	\N	PRESENT	0
374350	363532	19643A	PARTICIPANT	\N	PRESENT	0
374353	363532	19515S	PARTICIPANT	\N	PRESENT	0
374355	363532	19563B	PARTICIPANT	\N	PRESENT	0
374356	363532	98022P	PARTICIPANT	\N	PRESENT	0
374358	363532	14241N	PARTICIPANT	\N	PRESENT	0
374359	363532	01057W	PARTICIPANT	\N	PRESENT	0
374360	363532	14107H	PARTICIPANT	\N	PRESENT	0
374362	363532	19703U	PARTICIPANT	\N	PRESENT	0
374363	363532	19719D	PARTICIPANT	\N	PRESENT	0
374365	363532	14207L	PARTICIPANT	\N	PRESENT	0
374367	363532	19387D	PARTICIPANT	\N	PRESENT	0
374368	363532	14031R	PARTICIPANT	\N	PRESENT	0
374369	363532	19553Y	PARTICIPANT	\N	PRESENT	0
374370	363532	11115U	PARTICIPANT	\N	PRESENT	0
374372	363532	08031R	PARTICIPANT	\N	PRESENT	0
374373	363532	14173T	PARTICIPANT	\N	PRESENT	0
374374	363532	19447X	PARTICIPANT	\N	PRESENT	0
374375	363532	19573D	PARTICIPANT	\N	PRESENT	0
374376	363532	14093U	PARTICIPANT	\N	PRESENT	0
374377	363532	17589D	PARTICIPANT	\N	PRESENT	0
374378	363532	92040Q	PARTICIPANT	\N	PRESENT	0
374379	363532	11064N	PARTICIPANT	\N	PRESENT	0
374380	363532	14119M	PARTICIPANT	\N	PRESENT	0
374381	363532	11049P	PARTICIPANT	\N	PRESENT	0
374382	363532	14089Y	PARTICIPANT	\N	PRESENT	0
374383	363532	14147R	PARTICIPANT	\N	PRESENT	0
374384	363532	14251Q	PARTICIPANT	\N	PRESENT	0
374385	363532	19467C	PARTICIPANT	\N	PRESENT	0
374386	363532	19415P	PARTICIPANT	\N	PRESENT	0
374387	363532	98035U	PARTICIPANT	\N	PRESENT	0
374388	363532	14033T	PARTICIPANT	\N	PRESENT	0
374389	363532	14159V	PARTICIPANT	\N	PRESENT	0
374390	363532	04059M	PARTICIPANT	\N	PRESENT	0
374391	363532	11074Q	PARTICIPANT	\N	PRESENT	0
374392	363532	14051J	PARTICIPANT	\N	PRESENT	0
374393	363532	19399H	PARTICIPANT	\N	PRESENT	0
374394	363532	08068F	PARTICIPANT	\N	PRESENT	0
374395	363532	01028R	PARTICIPANT	\N	PRESENT	0
374396	363532	08048B	PARTICIPANT	\N	PRESENT	0
374397	363532	08052W	PARTICIPANT	\N	PRESENT	0
374398	363532	14229S	PARTICIPANT	\N	PRESENT	0
374399	363532	14265W	PARTICIPANT	\N	PRESENT	0
374400	363532	14021P	PARTICIPANT	\N	PRESENT	0
374401	363532	19741B	PARTICIPANT	\N	PRESENT	0
374402	363532	19669L	PARTICIPANT	\N	PRESENT	0
374403	363532	08045X	PARTICIPANT	\N	PRESENT	0
374404	363532	01062T	PARTICIPANT	\N	PRESENT	0
374405	363532	19709B	PARTICIPANT	\N	PRESENT	0
374406	363532	08060W	PARTICIPANT	\N	PRESENT	0
374407	363532	08038Y	PARTICIPANT	\N	PRESENT	0
374408	363532	80013X	PARTICIPANT	\N	PRESENT	0
374409	363532	19723Y	PARTICIPANT	\N	PRESENT	0
374410	363532	04088S	PARTICIPANT	\N	PRESENT	0
374411	363532	07029T	PARTICIPANT	\N	PRESENT	0
374412	363532	08015R	PARTICIPANT	\N	PRESENT	0
374413	363532	19551W	PARTICIPANT	\N	PRESENT	0
374414	363532	14281W	PARTICIPANT	\N	PRESENT	0
374415	363532	11104D	PARTICIPANT	\N	PRESENT	0
374416	363532	08043V	PARTICIPANT	\N	PRESENT	0
374417	363532	11066Q	PARTICIPANT	\N	PRESENT	0
374418	363532	19733B	PARTICIPANT	\N	PRESENT	0
374419	363532	19675J	PARTICIPANT	\N	PRESENT	0
374420	363532	11110B	PARTICIPANT	\N	PRESENT	0
374421	363532	19725B	PARTICIPANT	\N	PRESENT	0
374422	363532	19762G	PARTICIPANT	\N	PRESENT	0
374423	363532	08017T	PARTICIPANT	\N	PRESENT	0
374424	363532	08035V	PARTICIPANT	\N	PRESENT	0
374425	363532	19333N	PARTICIPANT	\N	PRESENT	0
374426	363532	19549D	PARTICIPANT	\N	PRESENT	0
374427	363532	19701S	PARTICIPANT	\N	PRESENT	0
374428	363532	04018C	PARTICIPANT	\N	PRESENT	0
374429	363532	11041F	PARTICIPANT	\N	PRESENT	0
374430	363532	11072N	PARTICIPANT	\N	PRESENT	0
374431	363532	19621T	PARTICIPANT	\N	PRESENT	0
374432	363532	14257W	PARTICIPANT	\N	PRESENT	0
374433	363532	19631V	PARTICIPANT	\N	PRESENT	0
374434	363532	19367Y	PARTICIPANT	\N	PRESENT	0
374435	363532	14109K	PARTICIPANT	\N	PRESENT	0
374436	363532	04071H	PARTICIPANT	\N	PRESENT	0
374437	363532	19527W	PARTICIPANT	\N	PRESENT	0
374438	363532	14063N	PARTICIPANT	\N	PRESENT	0
374439	363532	97011G	PARTICIPANT	\N	PRESENT	0
374440	363532	14227Q	PARTICIPANT	\N	PRESENT	0
374441	363532	11067R	PARTICIPANT	\N	PRESENT	0
374442	363532	19503N	PARTICIPANT	\N	PRESENT	0
374443	363532	08011M	PARTICIPANT	\N	PRESENT	0
374444	363532	19489J	PARTICIPANT	\N	PRESENT	0
374445	363532	19251M	PARTICIPANT	\N	PRESENT	0
374446	363532	07033P	PARTICIPANT	\N	PRESENT	0
374447	363532	19413M	PARTICIPANT	\N	PRESENT	0
374448	363532	14217N	PARTICIPANT	\N	PRESENT	0
374449	363532	11054L	PARTICIPANT	\N	PRESENT	0
374450	363532	11045K	PARTICIPANT	\N	PRESENT	0
374451	363532	14331P	PARTICIPANT	\N	PRESENT	0
374452	363532	17779H	PARTICIPANT	\N	PRESENT	0
374453	363532	14079W	PARTICIPANT	\N	PRESENT	0
374454	363532	19581D	PARTICIPANT	\N	PRESENT	0
374455	363532	14085U	PARTICIPANT	\N	PRESENT	0
374456	363532	19747H	PARTICIPANT	\N	PRESENT	0
374457	363532	19591F	PARTICIPANT	\N	PRESENT	0
374458	363532	19531S	PARTICIPANT	\N	PRESENT	0
374459	363532	05012A	PARTICIPANT	\N	PRESENT	0
374460	363532	08034U	PARTICIPANT	\N	PRESENT	0
374461	363532	08012N	PARTICIPANT	\N	PRESENT	0
374462	363532	08058D	PARTICIPANT	\N	PRESENT	0
374463	363532	14028W	PARTICIPANT	\N	PRESENT	0
374464	363532	10006L	PARTICIPANT	\N	PRESENT	0
374465	363532	14197C	PARTICIPANT	\N	PRESENT	0
374466	363532	19798U	PARTICIPANT	\N	PRESENT	0
374467	363532	14193X	PARTICIPANT	\N	PRESENT	0
374468	363532	19649G	PARTICIPANT	\N	PRESENT	0
374469	363532	14151M	PARTICIPANT	\N	PRESENT	0
374470	363532	14053L	PARTICIPANT	\N	PRESENT	0
374471	363532	19599P	PARTICIPANT	\N	PRESENT	0
374472	363532	14087W	PARTICIPANT	\N	PRESENT	0
374473	363532	11056N	PARTICIPANT	\N	PRESENT	0
374474	363532	14215L	PARTICIPANT	\N	PRESENT	0
374475	363532	08018U	PARTICIPANT	\N	PRESENT	0
374476	363532	19727D	PARTICIPANT	\N	PRESENT	0
374477	363532	19543W	PARTICIPANT	\N	PRESENT	0
374478	363532	11083R	PARTICIPANT	\N	PRESENT	0
374479	363532	19545Y	PARTICIPANT	\N	PRESENT	0
374480	363532	14071N	PARTICIPANT	\N	PRESENT	0
374481	363532	05008E	PARTICIPANT	\N	PRESENT	0
374482	363532	11097X	PARTICIPANT	\N	PRESENT	0
374483	363532	14231L	PARTICIPANT	\N	PRESENT	0
365810	345242	19447X	PARTICIPANT	\N	PRESENT	0
365811	345242	14147R	PARTICIPANT	\N	PRESENT	0
365812	345242	19421M	PARTICIPANT	\N	PRESENT	0
365813	345242	19768N	PARTICIPANT	\N	PRESENT	0
365814	345242	04088S	PARTICIPANT	\N	PRESENT	0
365815	345242	19521Q	PARTICIPANT	\N	PRESENT	0
365816	345242	19727D	PARTICIPANT	\N	PRESENT	0
365817	345242	95030B	PARTICIPANT	\N	PRESENT	0
365818	345242	02002K	PARTICIPANT	\N	PRESENT	0
365819	345242	19687N	PARTICIPANT	\N	PRESENT	0
365820	345242	19533U	PARTICIPANT	\N	PRESENT	0
365821	345242	19289C	PARTICIPANT	\N	PRESENT	0
365822	345242	07029T	PARTICIPANT	\N	PRESENT	0
365823	345242	14026U	PARTICIPANT	\N	PRESENT	0
365824	345242	19629C	PARTICIPANT	\N	PRESENT	0
365825	345242	14107H	PARTICIPANT	\N	PRESENT	0
365826	345242	19545Y	PARTICIPANT	\N	PRESENT	0
365827	345242	19563B	PARTICIPANT	\N	PRESENT	0
365828	345242	11097X	PARTICIPANT	\N	PRESENT	0
365829	345242	19383Y	PARTICIPANT	\N	PRESENT	0
365830	345242	19507S	PARTICIPANT	\N	PRESENT	0
365831	345242	14213J	PARTICIPANT	\N	PRESENT	0
365832	345242	19719D	PARTICIPANT	\N	PRESENT	0
365833	345242	19479G	PARTICIPANT	\N	PRESENT	0
365834	345242	19553Y	PARTICIPANT	\N	PRESENT	0
365835	345242	14071N	PARTICIPANT	\N	PRESENT	0
365836	345242	11012A	PARTICIPANT	\N	PRESENT	0
365837	345242	14089Y	PARTICIPANT	\N	PRESENT	0
365838	345242	08031R	PARTICIPANT	\N	PRESENT	0
365839	345242	14119M	PARTICIPANT	\N	PRESENT	0
365840	345242	14169X	PARTICIPANT	\N	PRESENT	0
365841	345242	19713W	PARTICIPANT	\N	PRESENT	0
365842	345242	04047H	PARTICIPANT	\N	PRESENT	0
365843	345242	14219Q	PARTICIPANT	\N	PRESENT	0
365844	345242	14249W	PARTICIPANT	\N	PRESENT	0
365845	345242	14237S	PARTICIPANT	\N	PRESENT	0
365846	345242	19467C	PARTICIPANT	\N	PRESENT	0
365847	345242	14073Q	PARTICIPANT	\N	PRESENT	0
365848	345242	19549D	PARTICIPANT	\N	PRESENT	0
365849	345242	19253P	PARTICIPANT	\N	PRESENT	0
365850	345242	14211G	PARTICIPANT	\N	PRESENT	0
365851	345242	19703U	PARTICIPANT	\N	PRESENT	0
365852	345242	18083K	PARTICIPANT	\N	PRESENT	0
365853	345242	14241N	PARTICIPANT	\N	PRESENT	0
365854	345242	19599P	PARTICIPANT	\N	PRESENT	0
365855	345242	14034U	PARTICIPANT	\N	PRESENT	0
365987	362936	14042U	PARTICIPANT	\N	PRESENT	0
365988	362936	19521Q	PARTICIPANT	\N	PRESENT	0
367207	367206	19421M	PARTICIPANT	\N	PRESENT	0
367208	367206	19251M	PARTICIPANT	\N	PRESENT	0
367209	367206	11064N	PARTICIPANT	\N	PRESENT	0
367266	367265	04035D	PARTICIPANT	\N	PRESENT	0
367267	367265	08049C	PARTICIPANT	\N	PRESENT	0
369885	367799	04044E	PARTICIPANT	\N	EXCUSE	0
370717	365231	19399H	PARTICIPANT	\N	EXCUSE	0
370718	365231	19349W	PARTICIPANT	\N	PRESENT	0
370756	365231	01028R	PARTICIPANT	\N	EXCUSE	0
373673	373672	11097X	PARTICIPANT	\N	PRESENT	0
373827	373687	04086Q	PARTICIPANT	\N	PRESENT	0
373828	373687	14327T	PARTICIPANT	\N	PRESENT	0
373829	373687	19479G	PARTICIPANT	\N	PRESENT	0
373830	373687	19711U	PARTICIPANT	\N	PRESENT	0
373831	373687	11012A	PARTICIPANT	\N	PRESENT	0
373832	373687	14085U	PARTICIPANT	\N	PRESENT	0
373833	373687	19349W	PARTICIPANT	\N	PRESENT	0
373834	373687	11053K	PARTICIPANT	\N	PRESENT	0
373835	373687	14253S	PARTICIPANT	\N	PRESENT	0
373836	373687	99004R	PARTICIPANT	\N	PRESENT	0
373837	373687	11074Q	PRESIDENT	0	PRESENT	0
373838	373687	19667J	PARTICIPANT	\N	PRESENT	0
373839	373687	01048V	PARTICIPANT	\N	EXCUSE	0
373840	373687	07004J	PARTICIPANT	\N	EXCUSE	0
373841	373687	19687N	PARTICIPANT	\N	EXCUSE	0
373842	373687	14121F	PARTICIPANT	\N	EXCUSE	0
373843	373687	04071H	PARTICIPANT	\N	PRESENT	0
373844	373687	01057W	PARTICIPANT	\N	PRESENT	0
373845	373687	19689Q	PARTICIPANT	\N	PRESENT	0
373846	373687	08011M	PARTICIPANT	\N	PRESENT	0
373847	373687	14034U	PARTICIPANT	\N	PRESENT	0
373848	373687	19671E	PARTICIPANT	\N	PRESENT	0
373849	373687	14159V	PARTICIPANT	\N	PRESENT	0
373850	373687	11040E	PARTICIPANT	\N	PRESENT	0
373851	373687	07029T	PARTICIPANT	\N	PRESENT	0
373852	373687	14083S	PARTICIPANT	\N	PRESENT	0
376683	371428	11026G	PARTICIPANT	\N	PRESENT	0
376684	371428	04085P	PARTICIPANT	\N	PRESENT	0
376685	371428	12041X	PARTICIPANT	\N	PRESENT	0
376686	371428	11040E	PARTICIPANT	\N	PRESENT	0
376687	371428	19695N	PARTICIPANT	\N	PRESENT	0
376688	371428	19711U	PARTICIPANT	\N	PRESENT	0
376689	371428	14063N	PARTICIPANT	\N	PRESENT	0
376690	371428	04057K	PARTICIPANT	\N	PRESENT	0
376691	371428	19671E	PARTICIPANT	\N	PRESENT	0
376692	371428	14041T	PARTICIPANT	\N	PRESENT	0
376693	371428	19760E	PARTICIPANT	\N	PRESENT	0
376694	371428	19681G	PARTICIPANT	\N	PRESENT	0
376695	371428	19569H	PARTICIPANT	\N	PRESENT	0
376696	371428	19441R	PARTICIPANT	\N	PRESENT	0
376681	371428	04086Q	PARTICIPANT	\N	PRESENT	0
376697	371428	14259Y	PARTICIPANT	\N	PRESENT	0
376698	371428	14034U	PARTICIPANT	\N	PRESENT	0
376699	371428	04034C	PARTICIPANT	\N	PRESENT	0
376700	371428	11031D	PARTICIPANT	\N	PRESENT	0
376701	371428	14069U	PARTICIPANT	\N	PRESENT	0
376707	371428	11067R	PARTICIPANT	\N	PRESENT	0
376708	371428	11033F	PARTICIPANT	\N	PRESENT	0
376714	371428	19663E	PARTICIPANT	\N	PRESENT	0
376715	371428	19573D	PARTICIPANT	\N	PRESENT	0
376716	371428	99004R	PARTICIPANT	\N	PRESENT	0
377387	377351	08009T	PARTICIPANT	\N	PRESENT	0
377388	377351	14219Q	PARTICIPANT	\N	PRESENT	0
377415	377414	04086Q	PARTICIPANT	\N	PRESENT	0
378174	373666	08024S	PARTICIPANT	\N	PRESENT	0
378328	373666	02002K	PARTICIPANT	\N	PRESENT	0
384037	371542	08024S	PARTICIPANT	\N	PRESENT	0
384038	382778	14053L	PARTICIPANT	\N	PRESENT	0
384039	371542	11033F	PARTICIPANT	\N	PRESENT	0
384040	371542	19347U	PARTICIPANT	\N	PRESENT	0
384041	371542	19413M	PARTICIPANT	\N	PRESENT	0
384042	371542	04044E	PARTICIPANT	\N	PRESENT	0
384043	371542	14111D	PARTICIPANT	\N	PRESENT	0
384044	371542	14157T	PARTICIPANT	\N	PRESENT	0
384045	371542	14123H	PARTICIPANT	\N	PRESENT	0
384046	371542	19593H	PARTICIPANT	\N	PRESENT	0
384047	371542	19695N	PARTICIPANT	\N	PRESENT	0
384048	371542	19679N	PARTICIPANT	\N	PRESENT	0
384049	371542	19713W	PARTICIPANT	\N	PRESENT	0
384050	376926	14059S	PARTICIPANT	\N	PRESENT	0
384051	376926	08019V	PRESIDENT	0	PRESENT	0
384052	376926	11072N	PARTICIPANT	\N	PRESENT	0
376745	371471	14034U	PARTICIPANT	\N	PRESENT	0
376750	376744	14111D	PARTICIPANT	\N	PRESENT	0
376751	376744	14041T	PARTICIPANT	\N	PRESENT	0
376752	376744	14001X	PARTICIPANT	\N	PRESENT	0
376753	376744	14147R	PARTICIPANT	\N	PRESENT	0
376754	376744	19543W	PARTICIPANT	\N	PRESENT	0
376755	376744	14069U	PARTICIPANT	\N	PRESENT	0
376756	376744	19581D	PARTICIPANT	\N	PRESENT	0
376757	376744	19585H	PARTICIPANT	\N	PRESENT	0
376758	376744	04047H	PRESIDENT	0	PRESENT	0
376759	376744	01028R	PARTICIPANT	\N	PRESENT	0
376760	376744	14231L	PARTICIPANT	\N	PRESENT	0
376761	376744	19762G	PARTICIPANT	\N	PRESENT	0
376762	376744	19729F	PARTICIPANT	\N	EXCUSE	0
376763	376744	14065Q	PARTICIPANT	\N	EXCUSE	0
376764	376744	04044E	PARTICIPANT	\N	EXCUSE	0
384053	376926	14331P	PARTICIPANT	\N	PRESENT	0
384054	376926	19329S	PARTICIPANT	\N	EXCUSE	0
384035	371542	19383Y	PARTICIPANT	\N	PRESENT	0
384036	371542	14069U	PARTICIPANT	\N	PRESENT	0
384055	376926	19691J	PARTICIPANT	\N	PRESENT	0
384056	371542	19697Q	PARTICIPANT	\N	PRESENT	0
384057	371542	19629C	PARTICIPANT	\N	PRESENT	0
384058	371542	19253P	PARTICIPANT	\N	PRESENT	0
384059	371542	19367Y	PARTICIPANT	\N	PRESENT	0
384060	380297	11085T	PARTICIPANT	\N	PRESENT	0
384061	371542	08043V	PARTICIPANT	\N	PRESENT	0
384062	371542	08017T	PARTICIPANT	\N	PRESENT	0
384063	371542	11012A	PARTICIPANT	\N	PRESENT	0
384064	371542	14105F	PARTICIPANT	\N	PRESENT	0
384065	371542	14147R	PARTICIPANT	\N	PRESENT	0
384066	371542	87003B	PARTICIPANT	\N	PRESENT	0
384067	371542	19415P	PARTICIPANT	\N	PRESENT	0
384068	371542	19798U	PARTICIPANT	\N	PRESENT	0
384069	371542	19533U	PARTICIPANT	\N	PRESENT	0
384070	371542	01024M	PARTICIPANT	\N	PRESENT	0
386561	377922	19527W	PARTICIPANT	\N	PRESENT	0
386562	377922	19301E	PARTICIPANT	\N	PRESENT	0
386563	377922	14081Q	PARTICIPANT	\N	PRESENT	0
386564	377922	14197C	PARTICIPANT	\N	PRESENT	0
386565	377922	19747H	PARTICIPANT	\N	PRESENT	0
386566	377922	14217N	PARTICIPANT	\N	PRESENT	0
386567	377922	05012A	PARTICIPANT	\N	PRESENT	0
386568	377922	19479G	PARTICIPANT	\N	PRESENT	0
386569	377922	04040A	PARTICIPANT	\N	PRESENT	0
386570	377922	17589D	PARTICIPANT	\N	PRESENT	0
386571	377922	08019V	PARTICIPANT	\N	PRESENT	0
386572	377922	14033T	PARTICIPANT	\N	PRESENT	0
386573	377922	08069G	PARTICIPANT	\N	PRESENT	0
386574	377922	14265W	PARTICIPANT	\N	PRESENT	0
386575	377922	19521Q	PARTICIPANT	\N	PRESENT	0
386576	377922	19575F	PARTICIPANT	\N	PRESENT	0
386577	377922	19573D	PARTICIPANT	\N	PRESENT	0
386578	377922	14257W	PARTICIPANT	\N	PRESENT	0
386579	377922	19741B	PARTICIPANT	\N	PRESENT	0
386580	377922	11048N	PARTICIPANT	\N	PRESENT	0
386581	377922	08015R	PARTICIPANT	\N	PRESENT	0
386582	377922	19697Q	PARTICIPANT	\N	PRESENT	0
386583	377922	10006L	PARTICIPANT	\N	PRESENT	0
386584	377922	04033B	PARTICIPANT	\N	PRESENT	0
386585	377922	14071N	PARTICIPANT	\N	PRESENT	0
386586	377922	19621T	PARTICIPANT	\N	PRESENT	0
386587	377922	14231L	PARTICIPANT	\N	PRESENT	0
386588	377922	14219Q	PARTICIPANT	\N	PRESENT	0
386589	377922	08061X	PARTICIPANT	\N	PRESENT	0
386590	377922	19679N	PARTICIPANT	\N	PRESENT	0
386591	377922	19387D	PARTICIPANT	\N	PRESENT	0
386592	377922	14179A	PARTICIPANT	\N	PRESENT	0
386593	377922	14215L	PARTICIPANT	\N	PRESENT	0
386594	377922	14021P	PARTICIPANT	\N	PRESENT	0
386595	377922	14083S	PARTICIPANT	\N	PRESENT	0
386596	377922	14026U	PARTICIPANT	\N	PRESENT	0
386597	377922	19507S	PARTICIPANT	\N	PRESENT	0
386598	377922	19447X	PARTICIPANT	\N	PRESENT	0
386599	377922	18083K	PARTICIPANT	\N	PRESENT	0
386600	377922	14259Y	PARTICIPANT	\N	PRESENT	0
386601	377922	14031R	PARTICIPANT	\N	PRESENT	0
386602	377922	19643A	PARTICIPANT	\N	PRESENT	0
386603	377922	14241N	PARTICIPANT	\N	PRESENT	0
386604	377922	14034U	PARTICIPANT	\N	PRESENT	0
386605	377922	14069U	PARTICIPANT	\N	PRESENT	0
386608	380333	19629C	PARTICIPANT	\N	PRESENT	0
386609	380333	19711U	PARTICIPANT	\N	PRESENT	0
386610	380333	14147R	PARTICIPANT	\N	PRESENT	0
386611	380333	14107H	PARTICIPANT	\N	PRESENT	0
386612	380333	11066Q	PARTICIPANT	\N	PRESENT	0
387552	387551	19253P	PARTICIPANT	\N	PRESENT	0
387553	387551	08045X	PARTICIPANT	\N	PRESENT	0
387554	387551	19715Y	PARTICIPANT	\N	PRESENT	0
387555	387551	19349W	PARTICIPANT	\N	PRESENT	0
386559	377922	14107H	PARTICIPANT	\N	PRESENT	0
386560	377922	19727D	PARTICIPANT	\N	PRESENT	0
387556	387551	14083S	PARTICIPANT	\N	PRESENT	0
387561	387560	19253P	PARTICIPANT	\N	PRESENT	0
387562	387560	19715Y	PARTICIPANT	\N	PRESENT	0
387563	387560	14083S	PARTICIPANT	\N	PRESENT	0
387568	387566	19253P	PARTICIPANT	\N	PRESENT	0
387569	387566	11053K	PARTICIPANT	\N	PRESENT	0
387570	387566	14237S	PARTICIPANT	\N	PRESENT	0
387571	387566	14031R	PARTICIPANT	\N	PRESENT	0
387572	387566	19715Y	PARTICIPANT	\N	PRESENT	0
387573	387566	19549D	PARTICIPANT	\N	PRESENT	0
387574	387566	11064N	PARTICIPANT	\N	PRESENT	0
387575	387566	08045X	PARTICIPANT	\N	PRESENT	0
387576	387566	19301E	PARTICIPANT	\N	PRESENT	0
387577	387566	19671E	PARTICIPANT	\N	PRESENT	0
387748	387747	04042C	PARTICIPANT	\N	PRESENT	0
387749	387747	98050T	PARTICIPANT	\N	PRESENT	0
387750	387747	19669L	PARTICIPANT	\N	PRESENT	0
387751	387747	04035D	PARTICIPANT	\N	PRESENT	0
387752	387747	04034C	PARTICIPANT	\N	PRESENT	0
387753	387747	12041X	PARTICIPANT	\N	PRESENT	0
387754	387747	19649G	PARTICIPANT	\N	PRESENT	0
387755	387747	08010L	PARTICIPANT	\N	PRESENT	0
387756	387747	19766L	PARTICIPANT	\N	PRESENT	0
387774	387773	14193X	PARTICIPANT	\N	PRESENT	0
387775	387773	98022P	PARTICIPANT	\N	PRESENT	0
387800	387799	19711U	PARTICIPANT	\N	PRESENT	0
388169	386240	04040A	PRESIDENT	0	PRESENT	0
388170	386240	14195A	PARTICIPANT	\N	EXCUSE	0
388171	386240	19253P	PARTICIPANT	\N	EXCUSE	0
388172	386240	04086Q	PARTICIPANT	\N	EXCUSE	0
388173	386240	14259Y	PARTICIPANT	\N	EXCUSE	0
388174	386240	08038Y	PARTICIPANT	\N	EXCUSE	0
388175	386240	08034U	PARTICIPANT	\N	EXCUSE	0
388176	386240	19735D	PARTICIPANT	\N	EXCUSE	0
388177	386240	14281W	PARTICIPANT	\N	EXCUSE	0
388178	386240	08048B	PARTICIPANT	\N	EXCUSE	0
388179	386240	01057W	PARTICIPANT	\N	EXCUSE	0
388180	386240	08010L	PARTICIPANT	\N	EXCUSE	0
388181	386240	14071N	PARTICIPANT	\N	EXCUSE	0
388182	386240	92040Q	PARTICIPANT	\N	EXCUSE	0
388183	386240	14028W	PARTICIPANT	\N	EXCUSE	0
388184	386240	95063L	PARTICIPANT	\N	EXCUSE	0
388185	386240	04044E	PARTICIPANT	\N	EXCUSE	0
388186	386240	95067Q	PARTICIPANT	\N	EXCUSE	0
388505	388504	19253P	PARTICIPANT	\N	PRESENT	0
388506	388504	11053K	PARTICIPANT	\N	PRESENT	0
388507	388504	19715Y	PARTICIPANT	\N	PRESENT	0
388508	388504	14069U	PARTICIPANT	\N	PRESENT	0
388513	386240	11101A	PARTICIPANT	\N	EXCUSE	0
389554	388515	14253S	PARTICIPANT	\N	PRESENT	0
389555	388515	98050T	PARTICIPANT	\N	PRESENT	0
389646	386613	14097Y	PARTICIPANT	\N	PRESENT	0
389647	386613	04035D	PARTICIPANT	\N	PRESENT	0
389648	386613	19443T	PARTICIPANT	\N	PRESENT	0
389649	386613	11080N	PARTICIPANT	\N	PRESENT	0
389650	386613	01058X	PARTICIPANT	\N	PRESENT	0
389651	386613	14079W	PARTICIPANT	\N	PRESENT	0
389652	386613	16685X	PARTICIPANT	\N	PRESENT	0
389653	386613	11027H	PARTICIPANT	\N	PRESENT	0
389654	386613	04042C	PRESIDENT	0	PRESENT	0
389655	386613	14028W	PARTICIPANT	\N	PRESENT	0
389656	386613	11066Q	PARTICIPANT	\N	PRESENT	0
389657	386613	19721W	PARTICIPANT	\N	PRESENT	0
389658	386613	14105F	PARTICIPANT	\N	PRESENT	0
389659	386613	19709B	PARTICIPANT	\N	PRESENT	0
389660	386613	14267Y	PARTICIPANT	\N	PRESENT	0
389661	386613	08049C	PARTICIPANT	\N	PRESENT	0
389662	386613	98050T	PARTICIPANT	\N	PRESENT	0
389663	386613	08053X	PARTICIPANT	\N	PRESENT	0
389664	386613	14211G	PARTICIPANT	\N	PRESENT	0
389665	386613	08047A	PARTICIPANT	\N	PRESENT	0
389666	386613	14255U	PARTICIPANT	\N	PRESENT	0
389667	386613	98018T	PARTICIPANT	\N	EXCUSE	0
389677	389676	14227Q	PARTICIPANT	\N	PRESENT	0
389678	389676	14079W	PARTICIPANT	\N	PRESENT	0
389679	386613	12041X	PARTICIPANT	\N	PRESENT	0
389680	386613	19669L	PARTICIPANT	\N	PRESENT	0
389681	386613	08056B	PARTICIPANT	\N	PRESENT	0
389682	386613	95037J	PARTICIPANT	\N	PRESENT	0
389683	386613	14193X	PARTICIPANT	\N	PRESENT	0
389684	386613	08061X	PARTICIPANT	\N	PRESENT	0
389685	386613	97011G	PARTICIPANT	\N	PRESENT	0
389686	386613	95067Q	PARTICIPANT	\N	PRESENT	0
389687	386613	14133K	PARTICIPANT	\N	PRESENT	0
389688	386613	14235Q	PARTICIPANT	\N	PRESENT	0
389689	386613	08058D	PARTICIPANT	\N	PRESENT	0
389690	386613	19319Q	PARTICIPANT	\N	PRESENT	0
389691	386613	11064N	PARTICIPANT	\N	PRESENT	0
389692	386613	19583F	PARTICIPANT	\N	PRESENT	0
389693	386613	98022P	PARTICIPANT	\N	PRESENT	0
389694	389034	04070G	PRESIDENT	0	PRESENT	0
389695	389034	19699S	PARTICIPANT	\N	PRESENT	0
389696	389034	14229S	PARTICIPANT	\N	PRESENT	0
389697	389034	14241N	PARTICIPANT	\N	PRESENT	0
389698	389034	19573D	PARTICIPANT	\N	PRESENT	0
389699	389034	08039A	PARTICIPANT	\N	PRESENT	0
389700	389034	08031R	PARTICIPANT	\N	PRESENT	0
389701	389034	19643A	PARTICIPANT	\N	PRESENT	0
389702	389034	14061L	PARTICIPANT	\N	PRESENT	0
389703	389034	14073Q	PARTICIPANT	\N	PRESENT	0
389704	389034	19611R	PARTICIPANT	\N	PRESENT	0
389705	389034	08043V	PARTICIPANT	\N	PRESENT	0
389706	389034	19693L	PARTICIPANT	\N	PRESENT	0
389707	389034	19399H	PARTICIPANT	\N	PRESENT	0
389708	389034	87003B	PARTICIPANT	\N	PRESENT	0
389709	389034	14030Q	PARTICIPANT	\N	PRESENT	0
389710	389034	19731Y	PARTICIPANT	\N	PRESENT	0
389711	389034	04059M	PARTICIPANT	\N	PRESENT	0
389712	389034	14063N	PARTICIPANT	\N	PRESENT	0
389713	389034	11043H	PARTICIPANT	\N	PRESENT	0
389714	389034	11104D	PARTICIPANT	\N	PRESENT	0
389715	389034	19749K	PARTICIPANT	\N	PRESENT	0
389716	389034	04018C	PARTICIPANT	\N	PRESENT	0
366813	357444	19511N	PARTICIPANT	\N	EXCUSE	0
366814	357444	14221J	PARTICIPANT	\N	EXCUSE	0
370887	367012	14083S	PARTICIPANT	\N	PRESENT	0
370888	367012	11048N	PARTICIPANT	\N	PRESENT	0
370889	367012	19711U	PARTICIPANT	\N	PRESENT	0
370890	367012	04049K	PARTICIPANT	\N	PRESENT	0
370891	367012	04034C	PARTICIPANT	\N	PRESENT	0
370892	367012	19441R	PARTICIPANT	\N	PRESENT	0
370893	367012	19695N	PARTICIPANT	\N	PRESENT	0
370894	367012	19399H	PARTICIPANT	\N	PRESENT	0
370895	367012	14026U	PARTICIPANT	\N	PRESENT	0
370896	367012	19521Q	PRESIDENT	0	PRESENT	0
370897	367012	14329V	PARTICIPANT	\N	PRESENT	0
370898	356305	19741B	PARTICIPANT	\N	PRESENT	0
370899	356305	08073C	PARTICIPANT	\N	PRESENT	0
370900	356305	14237S	PARTICIPANT	\N	PRESENT	0
370901	356305	14179A	PARTICIPANT	\N	PRESENT	0
370986	370965	04070G	PRESIDENT	0	PRESENT	0
370987	370965	19699S	PARTICIPANT	\N	PRESENT	0
370988	370965	19533U	PARTICIPANT	\N	PRESENT	0
370989	370965	14229S	PARTICIPANT	\N	PRESENT	0
370990	370965	14241N	PARTICIPANT	\N	PRESENT	0
370991	370965	19573D	PARTICIPANT	\N	PRESENT	0
370992	370965	14039A	PARTICIPANT	\N	PRESENT	0
370993	370965	14107H	PARTICIPANT	\N	PRESENT	0
370994	370965	19335Q	PARTICIPANT	\N	PRESENT	0
370995	370965	08039A	PARTICIPANT	\N	PRESENT	0
370996	370965	08031R	PARTICIPANT	\N	PRESENT	0
370997	370965	19593H	PARTICIPANT	\N	PRESENT	0
370998	370965	19643A	PARTICIPANT	\N	PRESENT	0
370999	370965	14059S	PARTICIPANT	\N	PRESENT	0
371000	370965	14061L	PARTICIPANT	\N	PRESENT	0
371001	370965	19611R	PARTICIPANT	\N	PRESENT	0
371002	370965	14030Q	PARTICIPANT	\N	PRESENT	0
371003	370965	04059M	PARTICIPANT	\N	PRESENT	0
371004	370965	19735D	PARTICIPANT	\N	PRESENT	0
371005	370965	14063N	PARTICIPANT	\N	PRESENT	0
371006	370965	14109K	PARTICIPANT	\N	PRESENT	0
371007	370965	14123H	PARTICIPANT	\N	PRESENT	0
371008	370965	19749K	PARTICIPANT	\N	PRESENT	0
371009	370965	04018C	PARTICIPANT	\N	PRESENT	0
371010	370965	19758L	PARTICIPANT	\N	PRESENT	0
371011	370965	19621T	PARTICIPANT	\N	PRESENT	0
371012	370965	14073Q	PARTICIPANT	\N	EXCUSE	0
371013	370965	08043V	PARTICIPANT	\N	EXCUSE	0
371014	370965	19693L	PARTICIPANT	\N	PRESENT	0
371015	370965	14249W	PARTICIPANT	\N	EXCUSE	0
371016	370965	08017T	PARTICIPANT	\N	PRESENT	0
371017	370965	04057K	PARTICIPANT	\N	PRESENT	0
371018	370965	08035V	PARTICIPANT	\N	PRESENT	0
371019	356308	19347U	PARTICIPANT	\N	PRESENT	0
371020	356308	19711U	PARTICIPANT	\N	PRESENT	0
371021	356308	19253P	PARTICIPANT	\N	PRESENT	0
371022	356308	19629C	PARTICIPANT	\N	PRESENT	0
371023	356308	19798U	PARTICIPANT	\N	PRESENT	0
371024	356308	04034C	PARTICIPANT	\N	PRESENT	0
371025	356308	19697Q	PARTICIPANT	\N	PRESENT	0
371026	356308	19349W	PARTICIPANT	\N	PRESENT	0
371027	356308	14227Q	PARTICIPANT	\N	PRESENT	0
371028	356308	11056N	PARTICIPANT	\N	PRESENT	0
371029	356308	04085P	PARTICIPANT	\N	PRESENT	0
371030	356308	11053K	PARTICIPANT	\N	PRESENT	0
371031	356308	14179A	PARTICIPANT	\N	PRESENT	0
371032	356308	14327T	PARTICIPANT	\N	PRESENT	0
371033	356308	19369B	PARTICIPANT	\N	PRESENT	0
371034	356308	19545Y	PARTICIPANT	\N	PRESENT	0
371035	356308	14201E	PARTICIPANT	\N	PRESENT	0
371036	356308	19387D	PARTICIPANT	\N	PRESENT	0
371037	356308	19563B	PARTICIPANT	\N	PRESENT	0
371038	356308	14147R	PARTICIPANT	\N	PRESENT	0
371039	356308	14329V	PARTICIPANT	\N	PRESENT	0
371040	356308	19741B	PARTICIPANT	\N	PRESENT	0
371041	356308	19399H	PARTICIPANT	\N	PRESENT	0
371042	356308	19521Q	PARTICIPANT	\N	PRESENT	0
371043	356308	04049K	PARTICIPANT	\N	PRESENT	0
371044	356308	11048N	PARTICIPANT	\N	PRESENT	0
371045	356308	14083S	PARTICIPANT	\N	PRESENT	0
371046	356308	19782L	PARTICIPANT	\N	PRESENT	0
371047	356308	04071H	PARTICIPANT	\N	PRESENT	0
371048	356308	08028W	PARTICIPANT	\N	PRESENT	0
371049	356308	19794Q	PARTICIPANT	\N	PRESENT	0
371050	356308	19515S	PARTICIPANT	\N	PRESENT	0
371051	356308	19575F	PARTICIPANT	\N	PRESENT	0
371052	356308	14031R	PARTICIPANT	\N	PRESENT	0
371053	356308	14089Y	PARTICIPANT	\N	PRESENT	0
371054	356308	07004J	PARTICIPANT	\N	PRESENT	0
371055	356308	14111D	PARTICIPANT	\N	PRESENT	0
371056	356308	14235Q	PARTICIPANT	\N	PRESENT	0
371057	356308	11040E	PARTICIPANT	\N	PRESENT	0
371058	356308	19695N	PARTICIPANT	\N	PRESENT	0
371059	356308	19687N	PARTICIPANT	\N	PRESENT	0
371060	356308	19725B	PARTICIPANT	\N	PRESENT	0
371061	356308	04042C	PARTICIPANT	\N	PRESENT	0
371062	356308	99004R	PARTICIPANT	\N	PRESENT	0
371063	356308	14231L	PARTICIPANT	\N	PRESENT	0
371064	356308	19739H	PARTICIPANT	\N	PRESENT	0
371065	356308	19737F	PARTICIPANT	\N	PRESENT	0
371066	356308	14197C	PARTICIPANT	\N	PRESENT	0
371067	356308	17583W	PARTICIPANT	\N	PRESENT	0
371068	356308	01057W	PARTICIPANT	\N	PRESENT	0
371069	356308	08015R	PARTICIPANT	\N	PRESENT	0
371070	356308	19729F	PARTICIPANT	\N	PRESENT	0
371071	356308	89017R	PARTICIPANT	\N	PRESENT	0
371072	356308	14219Q	PARTICIPANT	\N	PRESENT	0
371073	356308	19441R	PARTICIPANT	\N	PRESENT	0
371074	356308	19689Q	PARTICIPANT	\N	PRESENT	0
371075	356308	14215L	PARTICIPANT	\N	PRESENT	0
371076	356308	14038Y	PARTICIPANT	\N	PRESENT	0
371077	356308	19467C	PARTICIPANT	\N	PRESENT	0
371079	370965	08012N	PARTICIPANT	\N	PRESENT	0
371080	370965	14251Q	PARTICIPANT	\N	PRESENT	0
371081	370965	08020N	PARTICIPANT	\N	PRESENT	0
371082	370965	11043H	PARTICIPANT	\N	PRESENT	0
371083	370965	11104D	PARTICIPANT	\N	EXCUSE	0
371085	370965	07033P	PARTICIPANT	\N	PRESENT	0
371088	356308	14223L	PARTICIPANT	\N	PRESENT	0
371089	356308	19507S	PARTICIPANT	\N	PRESENT	0
371090	356308	08061X	PARTICIPANT	\N	PRESENT	0
371091	356308	95037J	PARTICIPANT	\N	PRESENT	0
371159	370965	87003B	PARTICIPANT	\N	PRESENT	0
371160	356308	14267Y	PARTICIPANT	\N	PRESENT	0
371161	356308	11043H	PARTICIPANT	\N	PRESENT	0
371162	356308	11049P	PARTICIPANT	\N	PRESENT	0
371171	370536	11067R	PARTICIPANT	\N	PRESENT	0
371172	370536	14147R	PARTICIPANT	\N	PRESENT	0
371173	370536	19749K	PARTICIPANT	\N	PRESENT	0
371174	370536	10006L	PRESIDENT	0	PRESENT	0
371175	370536	14030Q	PARTICIPANT	\N	PRESENT	0
371178	370536	19447X	PARTICIPANT	\N	PRESENT	0
371179	370536	14231L	PARTICIPANT	\N	PRESENT	0
371180	370536	04047H	PARTICIPANT	\N	EXCUSE	0
371181	370536	08031R	PARTICIPANT	\N	EXCUSE	0
371184	370536	01028R	PARTICIPANT	\N	PRESENT	0
376956	376955	19611R	PARTICIPANT	\N	PRESENT	0
376959	376958	04018C	PARTICIPANT	\N	PRESENT	0
376960	376958	14229S	PARTICIPANT	\N	PRESENT	0
376961	376958	07033P	PARTICIPANT	\N	PRESENT	0
376963	376962	07033P	PARTICIPANT	\N	PRESENT	0
376964	376962	19693L	PARTICIPANT	\N	PRESENT	0
376965	376962	14229S	PARTICIPANT	\N	PRESENT	0
376966	376962	04018C	PARTICIPANT	\N	PRESENT	0
376968	376967	14229S	PARTICIPANT	\N	PRESENT	0
376969	376967	04018C	PARTICIPANT	\N	PRESENT	0
380227	380225	19766L	PARTICIPANT	\N	PRESENT	0
380228	380225	19593H	PARTICIPANT	\N	PRESENT	0
380229	380225	04070G	PRESIDENT	0	PRESENT	0
380230	380225	19699S	PARTICIPANT	\N	PRESENT	0
380231	380225	19533U	PARTICIPANT	\N	PRESENT	0
380232	380225	14073Q	PARTICIPANT	\N	PRESENT	0
380233	380225	08035V	PARTICIPANT	\N	PRESENT	0
380234	380225	08043V	PARTICIPANT	\N	PRESENT	0
380235	380225	19693L	PARTICIPANT	\N	PRESENT	0
380236	380225	14229S	PARTICIPANT	\N	PRESENT	0
380237	380225	14241N	PARTICIPANT	\N	PRESENT	0
380238	380225	14039A	PARTICIPANT	\N	PRESENT	0
380239	380225	14107H	PARTICIPANT	\N	PRESENT	0
380240	380225	19735D	PARTICIPANT	\N	PRESENT	0
380241	380225	11083R	PARTICIPANT	\N	PRESENT	0
380242	380225	19749K	PARTICIPANT	\N	PRESENT	0
380243	380225	04018C	PARTICIPANT	\N	PRESENT	0
380244	380225	14249W	PARTICIPANT	\N	PRESENT	0
380245	380225	08039A	PARTICIPANT	\N	PRESENT	0
380246	380225	14061L	PARTICIPANT	\N	EXCUSE	0
380247	380225	87003B	PARTICIPANT	\N	EXCUSE	0
380248	380225	19399H	PARTICIPANT	\N	EXCUSE	0
380249	380225	08031R	PARTICIPANT	\N	EXCUSE	0
380250	380225	19573D	PARTICIPANT	\N	PRESENT	0
380251	380225	19335Q	PARTICIPANT	\N	PRESENT	0
380252	380225	04057K	PARTICIPANT	\N	PRESENT	0
374484	363532	19421M	PARTICIPANT	\N	PRESENT	0
374485	363532	14034U	PARTICIPANT	\N	PRESENT	0
374486	363532	04086Q	PARTICIPANT	\N	PRESENT	0
374487	363532	01034P	PARTICIPANT	\N	PRESENT	0
374488	363532	19369B	PARTICIPANT	\N	PRESENT	0
374489	363532	11053K	PARTICIPANT	\N	PRESENT	0
374490	363532	19611R	PARTICIPANT	\N	PRESENT	0
374491	363532	19699S	PARTICIPANT	\N	PRESENT	0
374492	363532	14249W	PARTICIPANT	\N	PRESENT	0
374493	363532	19721W	PARTICIPANT	\N	PRESENT	0
374494	363532	19619A	PARTICIPANT	\N	PRESENT	0
374495	363532	19737F	PARTICIPANT	\N	PRESENT	0
374496	363532	04035D	PARTICIPANT	\N	PRESENT	0
374497	363532	08056B	PARTICIPANT	\N	PRESENT	0
374498	363532	19569H	PARTICIPANT	\N	PRESENT	0
374499	363532	19735D	PARTICIPANT	\N	PRESENT	0
374500	363532	19663E	PARTICIPANT	\N	PRESENT	0
374501	363532	16685X	PARTICIPANT	\N	PRESENT	0
374502	363532	19441R	PARTICIPANT	\N	PRESENT	0
374503	363532	14219Q	PARTICIPANT	\N	PRESENT	0
374504	363532	14042U	PARTICIPANT	\N	PRESENT	0
374505	363532	14211G	PARTICIPANT	\N	PRESENT	0
374506	363532	19713W	PARTICIPANT	\N	PRESENT	0
374507	363532	19479G	PARTICIPANT	\N	PRESENT	0
374508	363532	04008A	PARTICIPANT	\N	PRESENT	0
374509	363532	14255U	PARTICIPANT	\N	PRESENT	0
374510	363532	14275Y	PARTICIPANT	\N	PRESENT	0
374511	363532	11043H	PARTICIPANT	\N	PRESENT	0
374512	363532	19667J	PARTICIPANT	\N	PRESENT	0
374513	363532	14205J	PARTICIPANT	\N	PRESENT	0
374514	363532	14267Y	PARTICIPANT	\N	PRESENT	0
374515	363532	14225N	PARTICIPANT	\N	PRESENT	0
374516	363532	14103D	PARTICIPANT	\N	PRESENT	0
374517	363532	14221J	PARTICIPANT	\N	PRESENT	0
374518	363532	14073Q	PARTICIPANT	\N	PRESENT	0
374519	363532	14083S	PARTICIPANT	\N	PRESENT	0
374520	363532	19335Q	PARTICIPANT	\N	PRESENT	0
374521	363532	19745F	PARTICIPANT	\N	PRESENT	0
374522	363532	19749K	PARTICIPANT	\N	PRESENT	0
374523	363532	11085T	PARTICIPANT	\N	PRESENT	0
374524	363532	04070G	PARTICIPANT	\N	PRESENT	0
374525	363532	01025N	PARTICIPANT	\N	PRESENT	0
374526	363532	14030Q	PARTICIPANT	\N	PRESENT	0
374527	363532	14327T	PARTICIPANT	\N	PRESENT	0
374528	363532	19671E	PARTICIPANT	\N	PRESENT	0
374529	363532	19760E	PARTICIPANT	\N	PRESENT	0
374530	363532	11031D	PARTICIPANT	\N	PRESENT	0
374531	363532	19565D	PARTICIPANT	\N	PRESENT	0
374532	363532	04034C	PARTICIPANT	\N	PRESENT	0
374533	363532	01060R	PARTICIPANT	\N	PRESENT	0
374534	363532	89017R	PARTICIPANT	\N	PRESENT	0
374535	363532	19731Y	PARTICIPANT	\N	PRESENT	0
374536	363532	04061F	PARTICIPANT	\N	PRESENT	0
374537	363532	11065P	PARTICIPANT	\N	PRESENT	0
374538	363532	11099A	PARTICIPANT	\N	PRESENT	0
374539	363532	04044E	PARTICIPANT	\N	PRESENT	0
374540	363532	19683J	PARTICIPANT	\N	PRESENT	0
374541	363532	19525U	PARTICIPANT	\N	PRESENT	0
374542	363532	19647E	PARTICIPANT	\N	PRESENT	0
374543	363532	19689Q	PARTICIPANT	\N	PRESENT	0
374544	363532	19253P	PARTICIPANT	\N	PRESENT	0
374545	363532	14195A	PARTICIPANT	\N	PRESENT	0
374546	363532	14135M	PARTICIPANT	\N	PRESENT	0
374547	363532	02002K	PARTICIPANT	\N	PRESENT	0
374548	363532	14259Y	PARTICIPANT	\N	PRESENT	0
374550	374549	10006L	PARTICIPANT	\N	PRESENT	0
374551	374549	14147R	PARTICIPANT	\N	PRESENT	0
374552	374549	11067R	PARTICIPANT	\N	PRESENT	0
374825	363541	04086Q	PARTICIPANT	\N	PRESENT	0
374826	363541	19551W	PARTICIPANT	\N	PRESENT	0
374827	363541	11077T	PARTICIPANT	\N	PRESENT	0
374828	363541	19549D	PARTICIPANT	\N	PRESENT	0
374829	363541	14257W	PARTICIPANT	\N	PRESENT	0
374830	363541	11110B	PARTICIPANT	\N	PRESENT	0
374831	363541	19683J	PARTICIPANT	\N	PRESENT	0
374832	363541	19637C	PARTICIPANT	\N	PRESENT	0
374833	363541	19651A	PARTICIPANT	\N	PRESENT	0
374834	363541	14083S	PARTICIPANT	\N	PRESENT	0
374835	363541	14205J	PARTICIPANT	\N	PRESENT	0
374836	363541	14073Q	PARTICIPANT	\N	PRESENT	0
374837	363541	01025N	PARTICIPANT	\N	PRESENT	0
374838	363541	19383Y	PARTICIPANT	\N	PRESENT	0
374839	363541	08009T	PARTICIPANT	\N	PRESENT	0
374840	363541	18083K	PARTICIPANT	\N	PRESENT	0
374841	363541	14093U	PARTICIPANT	\N	PRESENT	0
374842	363541	14147R	PARTICIPANT	\N	PRESENT	0
374843	363541	14357A	PARTICIPANT	\N	PRESENT	0
374844	363541	14237S	PARTICIPANT	\N	PRESENT	0
374845	363541	19347U	PARTICIPANT	\N	PRESENT	0
374846	363541	19671E	PARTICIPANT	\N	PRESENT	0
374847	363541	80013X	PARTICIPANT	\N	PRESENT	0
374848	363541	14038Y	PARTICIPANT	\N	PRESENT	0
374849	363541	19333N	PARTICIPANT	\N	PRESENT	0
374850	363541	19689Q	PARTICIPANT	\N	PRESENT	0
374851	363541	14115H	PARTICIPANT	\N	PRESENT	0
374852	363541	19703U	PARTICIPANT	\N	PRESENT	0
374853	363541	19387D	PARTICIPANT	\N	PRESENT	0
374854	363541	11012A	PARTICIPANT	\N	PRESENT	0
374855	363541	19503N	PARTICIPANT	\N	PRESENT	0
374857	363541	19794Q	PARTICIPANT	\N	PRESENT	0
374858	363541	14089Y	PARTICIPANT	\N	PRESENT	0
374859	363541	14219Q	PARTICIPANT	\N	PRESENT	0
374860	373901	19593H	PARTICIPANT	\N	PRESENT	0
374861	373901	04070G	PRESIDENT	0	PRESENT	0
374862	373901	19533U	PARTICIPANT	\N	PRESENT	0
374863	373901	19611R	PARTICIPANT	\N	PRESENT	0
374864	373901	08043V	PARTICIPANT	\N	PRESENT	0
374865	373901	19693L	PARTICIPANT	\N	PRESENT	0
374866	373901	19399H	PARTICIPANT	\N	PRESENT	0
374867	373901	14229S	PARTICIPANT	\N	PRESENT	0
374868	373901	19573D	PARTICIPANT	\N	PRESENT	0
374869	373901	19735D	PARTICIPANT	\N	PRESENT	0
374870	373901	14109K	PARTICIPANT	\N	PRESENT	0
374871	373901	14123H	PARTICIPANT	\N	PRESENT	0
374872	373901	19335Q	PARTICIPANT	\N	PRESENT	0
374873	373901	19749K	PARTICIPANT	\N	PRESENT	0
374874	373901	04018C	PARTICIPANT	\N	PRESENT	0
374875	373901	19758L	PARTICIPANT	\N	PRESENT	0
374876	373901	08039A	PARTICIPANT	\N	PRESENT	0
374877	373901	08031R	PARTICIPANT	\N	PRESENT	0
374878	373901	19621T	PARTICIPANT	\N	PRESENT	0
374879	373901	19643A	PARTICIPANT	\N	PRESENT	0
374880	373901	14241N	PARTICIPANT	\N	PRESENT	0
374881	373901	08020N	PARTICIPANT	\N	PRESENT	0
374882	373901	14073Q	PARTICIPANT	\N	PRESENT	0
374883	373901	04059M	PARTICIPANT	\N	PRESENT	0
374884	373901	04033B	PARTICIPANT	\N	PRESENT	0
374885	373901	14107H	PARTICIPANT	\N	PRESENT	0
374886	373901	08017T	PARTICIPANT	\N	PRESENT	0
374887	373901	11104D	PARTICIPANT	\N	PRESENT	0
374888	373901	14249W	PARTICIPANT	\N	PRESENT	0
374889	373901	14061L	PARTICIPANT	\N	EXCUSE	0
374890	373901	04057K	PARTICIPANT	\N	EXCUSE	0
374891	373901	14201E	PARTICIPANT	\N	EXCUSE	0
375324	375323	14053L	PARTICIPANT	\N	PRESENT	0
375327	375326	14053L	PARTICIPANT	\N	PRESENT	0
375328	375326	19719D	PARTICIPANT	\N	PRESENT	0
375332	375330	08060W	PARTICIPANT	\N	PRESENT	0
375333	375330	14157T	PARTICIPANT	\N	PRESENT	0
375334	375330	19629C	PARTICIPANT	\N	PRESENT	0
375335	375330	14038Y	PARTICIPANT	\N	PRESENT	0
375336	375330	19733B	PARTICIPANT	\N	PRESENT	0
375337	375331	14157T	PARTICIPANT	\N	PRESENT	0
375338	375331	08060W	PARTICIPANT	\N	PRESENT	0
375339	375331	08038Y	PARTICIPANT	\N	PRESENT	0
375340	375331	14038Y	PARTICIPANT	\N	PRESENT	0
375341	375331	19629C	PARTICIPANT	\N	PRESENT	0
375342	375329	14157T	PARTICIPANT	\N	PRESENT	0
375343	375329	08060W	PARTICIPANT	\N	PRESENT	0
375344	375329	19347U	PARTICIPANT	\N	PRESENT	0
375345	375329	19762G	PARTICIPANT	\N	PRESENT	0
375346	375329	19629C	PARTICIPANT	\N	PRESENT	0
375347	375329	19745F	PARTICIPANT	\N	PRESENT	0
375348	375329	14187A	PARTICIPANT	\N	PRESENT	0
375513	375512	05008E	PARTICIPANT	\N	PRESENT	0
375528	375527	05008E	PARTICIPANT	\N	PRESENT	0
375515	375512	19629C	PARTICIPANT	\N	PRESENT	0
375516	375512	14259Y	PARTICIPANT	\N	PRESENT	0
375518	375512	14151M	PARTICIPANT	\N	PRESENT	0
375530	375527	19629C	PARTICIPANT	\N	PRESENT	0
375531	375527	14259Y	PARTICIPANT	\N	PRESENT	0
375521	375512	19447X	PARTICIPANT	\N	PRESENT	0
375523	375512	11072N	PARTICIPANT	\N	PRESENT	0
375524	375512	19762G	PARTICIPANT	\N	PRESENT	0
375525	375512	01028R	PARTICIPANT	\N	PRESENT	0
375526	375512	14275Y	PARTICIPANT	\N	PRESENT	0
367472	365231	99004R	PRESIDENT	0	PRESENT	0
369130	369128	14063N	PARTICIPANT	\N	PRESENT	0
369131	369128	14073Q	PARTICIPANT	\N	PRESENT	0
369133	369128	14249W	PARTICIPANT	\N	PRESENT	0
369134	369128	08012N	PARTICIPANT	\N	PRESENT	0
369135	369128	19329S	PARTICIPANT	\N	PRESENT	0
373697	367788	04043D	PARTICIPANT	\N	EXCUSE	0
380027	380024	04018C	PARTICIPANT	\N	PRESENT	0
380028	380024	04059M	PARTICIPANT	\N	PRESENT	0
380029	380024	14229S	PARTICIPANT	\N	PRESENT	0
380030	380024	19749K	PARTICIPANT	\N	PRESENT	0
380031	380024	04070G	PARTICIPANT	\N	PRESENT	0
380032	380024	19611R	PARTICIPANT	\N	PRESENT	0
380033	380023	19749K	PARTICIPANT	\N	PRESENT	0
380034	380023	04059M	PARTICIPANT	\N	PRESENT	0
380035	380023	04018C	PARTICIPANT	\N	PRESENT	0
380036	380023	14229S	PARTICIPANT	\N	PRESENT	0
380038	380037	04018C	PARTICIPANT	\N	PRESENT	0
384071	371542	19599P	PARTICIPANT	\N	PRESENT	0
384072	371542	19691J	PARTICIPANT	\N	PRESENT	0
384073	371542	07033P	PARTICIPANT	\N	PRESENT	0
384074	371542	14061L	PARTICIPANT	\N	PRESENT	0
384075	371542	11097X	PARTICIPANT	\N	PRESENT	0
384076	371542	08028W	PARTICIPANT	\N	PRESENT	0
384110	375323	14026U	PARTICIPANT	\N	PRESENT	0
384111	375323	14281W	PARTICIPANT	\N	PRESENT	0
384112	384107	01060R	PARTICIPANT	\N	PRESENT	0
384113	384107	14001X	PARTICIPANT	\N	PRESENT	0
384114	384107	04047H	PARTICIPANT	\N	PRESENT	0
384115	384107	19673G	PARTICIPANT	\N	PRESENT	0
384116	384107	19675J	PARTICIPANT	\N	PRESENT	0
384117	384107	01028R	PARTICIPANT	\N	PRESENT	0
384118	384107	19447X	PARTICIPANT	\N	PRESENT	0
384119	384107	14231L	PARTICIPANT	\N	PRESENT	0
384120	384107	05008E	PRESIDENT	0	PRESENT	0
384121	384107	19489J	PARTICIPANT	\N	PRESENT	0
384122	384107	14275Y	PARTICIPANT	\N	PRESENT	0
384123	384107	14041T	PARTICIPANT	\N	PRESENT	0
384124	384107	14147R	PARTICIPANT	\N	PRESENT	0
384125	384107	14151M	PARTICIPANT	\N	PRESENT	0
384126	384107	08018U	PARTICIPANT	\N	PRESENT	0
384127	384107	14259Y	PARTICIPANT	\N	PRESENT	0
384128	384107	11072N	PARTICIPANT	\N	PRESENT	0
384129	384107	14053L	PARTICIPANT	\N	PRESENT	0
384130	384107	98035U	PARTICIPANT	\N	PRESENT	0
384131	384107	14111D	PARTICIPANT	\N	PRESENT	0
384132	384107	14065Q	PARTICIPANT	\N	EXCUSE	0
384133	384107	10015M	PARTICIPANT	\N	PRESENT	0
384134	384107	19253P	PARTICIPANT	\N	PRESENT	0
384135	384107	01024M	PARTICIPANT	\N	PRESENT	0
384136	384107	04038G	PARTICIPANT	\N	PRESENT	0
384137	384107	19719D	PARTICIPANT	\N	PRESENT	0
384138	384107	14089Y	PARTICIPANT	\N	PRESENT	0
384139	384107	19725B	PARTICIPANT	\N	PRESENT	0
384140	384107	19729F	PARTICIPANT	\N	PRESENT	0
384141	384107	95063L	PARTICIPANT	\N	PRESENT	0
384142	384107	19629C	PARTICIPANT	\N	PRESENT	0
384143	384107	14069U	PARTICIPANT	\N	PRESENT	0
384144	384107	11049P	PARTICIPANT	\N	PRESENT	0
384145	384107	14021P	PARTICIPANT	\N	PRESENT	0
384146	384107	14215L	PARTICIPANT	\N	PRESENT	0
384151	382637	19443T	PARTICIPANT	\N	PRESENT	0
384152	382637	95030B	PARTICIPANT	\N	PRESENT	0
384153	382637	01058X	PARTICIPANT	\N	PRESENT	0
384154	382637	08058D	PARTICIPANT	\N	PRESENT	0
384155	382637	04042C	PRESIDENT	0	PRESENT	0
384156	382637	11066Q	PARTICIPANT	\N	PRESENT	0
384157	382637	14105F	PARTICIPANT	\N	PRESENT	0
384158	382637	19421M	PARTICIPANT	\N	PRESENT	0
384159	382637	14267Y	PARTICIPANT	\N	PRESENT	0
384160	382637	14193X	PARTICIPANT	\N	PRESENT	0
384161	382637	11064N	PARTICIPANT	\N	PRESENT	0
384162	382637	98050T	PARTICIPANT	\N	PRESENT	0
384163	382637	97011G	PARTICIPANT	\N	PRESENT	0
384164	382637	08061X	PARTICIPANT	\N	PRESENT	0
384165	382637	08047A	PARTICIPANT	\N	PRESENT	0
384166	382637	01062T	PARTICIPANT	\N	PRESENT	0
384167	384149	14065Q	PARTICIPANT	\N	PRESENT	0
384168	384149	10015M	PARTICIPANT	\N	PRESENT	0
384169	384150	14065Q	PARTICIPANT	\N	PRESENT	0
384170	384150	19581D	PARTICIPANT	\N	PRESENT	0
384171	384150	10015M	PARTICIPANT	\N	PRESENT	0
384172	382637	04034C	PARTICIPANT	\N	PRESENT	0
384173	382637	04040A	PARTICIPANT	\N	PRESENT	0
384174	382637	11054L	PARTICIPANT	\N	PRESENT	0
384175	382637	19709B	PARTICIPANT	\N	PRESENT	0
384176	382637	04035D	PARTICIPANT	\N	PRESENT	0
384177	382637	11041F	PARTICIPANT	\N	PRESENT	0
384178	382637	19251M	PARTICIPANT	\N	PRESENT	0
384179	382637	98022P	PARTICIPANT	\N	PRESENT	0
384180	382637	14255U	PARTICIPANT	\N	PRESENT	0
384181	382615	08009T	PRESIDENT	0	PRESENT	0
384182	382615	14031R	PARTICIPANT	\N	EXCUSE	0
384183	382615	19685L	PARTICIPANT	\N	EXCUSE	0
384184	382615	19333N	PARTICIPANT	\N	PRESENT	0
384185	382615	14038Y	PARTICIPANT	\N	PRESENT	0
384186	382615	17583W	PARTICIPANT	\N	PRESENT	0
384187	382615	14051J	PARTICIPANT	\N	PRESENT	0
384188	382615	08060W	PARTICIPANT	\N	PRESENT	0
384189	382615	19701S	PARTICIPANT	\N	PRESENT	0
384190	382615	19794Q	PARTICIPANT	\N	PRESENT	0
384191	382615	19549D	PARTICIPANT	\N	PRESENT	0
384192	382615	19503N	PARTICIPANT	\N	PRESENT	0
384193	382615	14219Q	PARTICIPANT	\N	PRESENT	0
384194	382615	19681G	PARTICIPANT	\N	PRESENT	0
384195	382615	19713W	PARTICIPANT	\N	PRESENT	0
384196	382615	15447F	PARTICIPANT	\N	PRESENT	0
384197	382615	14157T	PARTICIPANT	\N	PRESENT	0
384198	382615	19737F	PARTICIPANT	\N	PRESENT	0
384199	382615	19525U	PARTICIPANT	\N	PRESENT	0
384200	382615	19387D	PARTICIPANT	\N	PRESENT	0
384201	382615	18083K	PARTICIPANT	\N	PRESENT	0
384202	382615	05012A	PARTICIPANT	\N	PRESENT	0
384203	382615	04097T	PARTICIPANT	\N	PRESENT	0
384204	382615	17637T	PARTICIPANT	\N	PRESENT	0
384205	382615	19347U	PARTICIPANT	\N	PRESENT	0
384206	382615	19383Y	PARTICIPANT	\N	PRESENT	0
384207	382615	14103D	PARTICIPANT	\N	PRESENT	0
384209	382615	02002K	PARTICIPANT	\N	PRESENT	0
384215	382615	19733B	PARTICIPANT	\N	PRESENT	0
384216	384208	04040A	PRESIDENT	0	PRESENT	0
384222	384108	01060R	PARTICIPANT	\N	PRESENT	0
384223	384108	19543W	PARTICIPANT	\N	PRESENT	0
384224	384108	04044E	PARTICIPANT	\N	PRESENT	0
384225	384108	04047H	PARTICIPANT	\N	PRESENT	0
384226	384108	19673G	PARTICIPANT	\N	PRESENT	0
384227	384108	19675J	PARTICIPANT	\N	PRESENT	0
384228	384108	01028R	PARTICIPANT	\N	PRESENT	0
384229	384108	05008E	PRESIDENT	0	PRESENT	0
384230	384108	19447X	PARTICIPANT	\N	PRESENT	0
384231	384108	19489J	PARTICIPANT	\N	PRESENT	0
384232	384108	14275Y	PARTICIPANT	\N	PRESENT	0
384233	384108	14041T	PARTICIPANT	\N	PRESENT	0
384234	384108	14215L	PARTICIPANT	\N	PRESENT	0
384235	384108	08018U	PARTICIPANT	\N	PRESENT	0
384236	384108	14259Y	PARTICIPANT	\N	PRESENT	0
384237	384108	14053L	PARTICIPANT	\N	PRESENT	0
384238	384108	98035U	PARTICIPANT	\N	PRESENT	0
384239	384108	14111D	PARTICIPANT	\N	PRESENT	0
384240	384108	19649G	PARTICIPANT	\N	PRESENT	0
384241	384108	11026G	PARTICIPANT	\N	PRESENT	0
384242	384108	01024M	PARTICIPANT	\N	PRESENT	0
384243	384108	04038G	PARTICIPANT	\N	PRESENT	0
384244	384108	19719D	PARTICIPANT	\N	PRESENT	0
384245	384108	19725B	PARTICIPANT	\N	PRESENT	0
384246	384108	95063L	PARTICIPANT	\N	PRESENT	0
384247	384108	19629C	PARTICIPANT	\N	PRESENT	0
384248	384108	14069U	PARTICIPANT	\N	PRESENT	0
384249	384108	11049P	PARTICIPANT	\N	PRESENT	0
384250	384108	14089Y	PARTICIPANT	\N	PRESENT	0
384251	384108	19729F	PARTICIPANT	\N	PRESENT	0
384252	384108	10015M	PARTICIPANT	\N	PRESENT	0
384253	384108	14147R	PARTICIPANT	\N	PRESENT	0
384254	384108	11085T	PARTICIPANT	\N	PRESENT	0
384255	384108	14021P	PARTICIPANT	\N	PRESENT	0
384256	384108	14231L	PARTICIPANT	\N	PRESENT	0
384257	384108	11072N	PARTICIPANT	\N	PRESENT	0
384262	382001	19697Q	PARTICIPANT	\N	PRESENT	0
384263	382001	11067R	PARTICIPANT	\N	PRESENT	0
384264	382001	14355X	PARTICIPANT	\N	PRESENT	0
384265	382001	19798U	PARTICIPANT	\N	PRESENT	0
384266	382001	19569H	PARTICIPANT	\N	PRESENT	0
384267	382001	11097X	PARTICIPANT	\N	PRESENT	0
384268	382001	19415P	PARTICIPANT	\N	PRESENT	0
384269	382001	14223L	PARTICIPANT	\N	PRESENT	0
384270	382001	04045F	PARTICIPANT	\N	PRESENT	0
384271	382001	14026U	PARTICIPANT	\N	PRESENT	0
384272	382001	14227Q	PARTICIPANT	\N	PRESENT	0
389717	389034	19758L	PARTICIPANT	\N	PRESENT	0
389718	389034	19621T	PARTICIPANT	\N	PRESENT	0
389742	389034	14039A	PARTICIPANT	\N	PRESENT	0
389743	389034	14107H	PARTICIPANT	\N	PRESENT	0
389744	389034	19593H	PARTICIPANT	\N	PRESENT	0
389745	389034	14059S	PARTICIPANT	\N	PRESENT	0
389746	389034	04057K	PARTICIPANT	\N	PRESENT	0
389747	389034	11083R	PARTICIPANT	\N	PRESENT	0
389748	389034	19735D	PARTICIPANT	\N	PRESENT	0
389749	386613	95030B	PARTICIPANT	\N	PRESENT	0
389750	386613	04034C	PARTICIPANT	\N	PRESENT	0
389751	386613	11054L	PARTICIPANT	\N	PRESENT	0
389752	386613	98029W	PARTICIPANT	\N	PRESENT	0
389753	386613	01062T	PARTICIPANT	\N	PRESENT	0
389755	386613	19421M	PARTICIPANT	\N	PRESENT	0
389756	386613	11041F	PARTICIPANT	\N	PRESENT	0
389757	386606	14029X	PARTICIPANT	\N	PRESENT	0
389758	386606	08009T	PRESIDENT	0	PRESENT	0
389759	386606	95062K	PARTICIPANT	\N	PRESENT	0
389760	386606	96004D	PARTICIPANT	\N	PRESENT	0
389761	386606	14191V	PARTICIPANT	\N	PRESENT	0
389762	389034	08012N	PARTICIPANT	\N	PRESENT	0
389763	389034	14249W	PARTICIPANT	\N	PRESENT	0
389764	389034	08035V	PARTICIPANT	\N	PRESENT	0
389765	389034	14123H	PARTICIPANT	\N	PRESENT	0
389766	386606	14038Y	PARTICIPANT	\N	PRESENT	0
389767	386606	19794Q	PARTICIPANT	\N	PRESENT	0
389768	386606	19387D	PARTICIPANT	\N	PRESENT	0
389769	386606	08055A	PARTICIPANT	\N	PRESENT	0
389770	386606	14169X	PARTICIPANT	\N	PRESENT	0
389771	386606	18083K	PARTICIPANT	\N	PRESENT	0
389772	386606	15447F	PARTICIPANT	\N	PRESENT	0
389773	386606	14157T	PARTICIPANT	\N	PRESENT	0
389774	386234	19768N	PARTICIPANT	\N	PRESENT	0
389775	386234	19515S	PARTICIPANT	\N	PRESENT	0
389776	386234	11077T	PARTICIPANT	\N	PRESENT	0
389777	386234	01043Q	PARTICIPANT	\N	PRESENT	0
389778	386234	14357A	PARTICIPANT	\N	PRESENT	0
389779	386234	19441R	PARTICIPANT	\N	PRESENT	0
389780	386234	19413M	PARTICIPANT	\N	PRESENT	0
389781	386234	14081Q	PARTICIPANT	\N	PRESENT	0
389782	386234	80013X	PARTICIPANT	\N	PRESENT	0
389783	386234	08021P	PARTICIPANT	\N	PRESENT	0
389784	386234	19631V	PARTICIPANT	\N	PRESENT	0
389785	386234	08068F	PARTICIPANT	\N	PRESENT	0
389786	386234	19705W	PARTICIPANT	\N	PRESENT	0
389787	386234	08015R	PARTICIPANT	\N	PRESENT	0
389788	386234	14197C	PARTICIPANT	\N	PRESENT	0
389789	386234	19369B	PARTICIPANT	\N	PRESENT	0
389790	386234	19511N	PARTICIPANT	\N	PRESENT	0
389791	386234	08028W	PARTICIPANT	\N	PRESENT	0
389792	386234	19563B	PARTICIPANT	\N	PRESENT	0
389793	386234	14265W	PARTICIPANT	\N	PRESENT	0
389794	386234	14329V	PARTICIPANT	\N	PRESENT	0
389795	386234	19591F	PARTICIPANT	\N	PRESENT	0
389796	386234	14135M	PARTICIPANT	\N	PRESENT	0
389797	386234	14187A	PARTICIPANT	\N	PRESENT	0
389798	386234	08038Y	PARTICIPANT	\N	PRESENT	0
389799	386234	19695N	PARTICIPANT	\N	PRESENT	0
389800	386234	11090Q	PRESIDENT	0	PRESENT	0
389801	386234	14033T	PARTICIPANT	\N	PRESENT	0
389802	386234	01025N	PARTICIPANT	\N	PRESENT	0
389803	386234	19295A	PARTICIPANT	\N	PRESENT	0
389804	386234	14205J	PARTICIPANT	\N	PRESENT	0
389805	386234	04088S	PARTICIPANT	\N	PRESENT	0
389806	386234	11056N	PARTICIPANT	\N	PRESENT	0
389807	386234	14115H	PARTICIPANT	\N	PRESENT	0
389808	386234	11101A	PARTICIPANT	\N	PRESENT	0
389809	386234	19507S	PARTICIPANT	\N	PRESENT	0
389810	386234	19747H	PARTICIPANT	\N	PRESENT	0
389811	386234	14207L	PARTICIPANT	\N	PRESENT	0
389812	386234	04043D	PARTICIPANT	\N	PRESENT	0
389813	386234	19619A	PARTICIPANT	\N	PRESENT	0
389814	386234	17589D	PARTICIPANT	\N	PRESENT	0
389815	386234	14257W	PARTICIPANT	\N	PRESENT	0
389816	386234	19467C	PARTICIPANT	\N	EXCUSE	0
389817	386234	19782L	PARTICIPANT	\N	EXCUSE	0
389818	386234	08019V	PARTICIPANT	\N	EXCUSE	0
389819	386234	11081P	PARTICIPANT	\N	EXCUSE	0
389820	386236	19768N	PARTICIPANT	\N	PRESENT	0
389821	386236	19515S	PARTICIPANT	\N	PRESENT	0
389822	386236	11077T	PARTICIPANT	\N	PRESENT	0
389823	386236	01043Q	PARTICIPANT	\N	PRESENT	0
389824	386236	14357A	PARTICIPANT	\N	PRESENT	0
389825	386236	19441R	PARTICIPANT	\N	PRESENT	0
389826	386236	19413M	PARTICIPANT	\N	PRESENT	0
389827	386236	14081Q	PARTICIPANT	\N	PRESENT	0
389828	386236	80013X	PARTICIPANT	\N	PRESENT	0
389829	386236	08021P	PARTICIPANT	\N	PRESENT	0
389830	386236	19631V	PARTICIPANT	\N	PRESENT	0
389831	386236	08068F	PARTICIPANT	\N	PRESENT	0
389832	386236	19705W	PARTICIPANT	\N	PRESENT	0
389833	386236	08015R	PARTICIPANT	\N	PRESENT	0
389834	386236	14197C	PARTICIPANT	\N	PRESENT	0
389835	386236	19369B	PARTICIPANT	\N	PRESENT	0
389836	386236	19511N	PARTICIPANT	\N	PRESENT	0
389837	386236	08028W	PARTICIPANT	\N	PRESENT	0
389838	386236	19563B	PARTICIPANT	\N	PRESENT	0
389839	386236	14265W	PARTICIPANT	\N	PRESENT	0
389840	386236	14329V	PARTICIPANT	\N	PRESENT	0
389841	386236	19591F	PARTICIPANT	\N	PRESENT	0
389842	386236	14135M	PARTICIPANT	\N	PRESENT	0
389843	386236	14187A	PARTICIPANT	\N	PRESENT	0
389844	386236	08038Y	PARTICIPANT	\N	PRESENT	0
389845	386236	19695N	PARTICIPANT	\N	PRESENT	0
389846	386236	11090Q	PRESIDENT	0	PRESENT	0
389847	386236	14033T	PARTICIPANT	\N	PRESENT	0
389848	386236	01025N	PARTICIPANT	\N	PRESENT	0
389849	386236	19295A	PARTICIPANT	\N	PRESENT	0
389850	386236	14205J	PARTICIPANT	\N	PRESENT	0
389851	386236	04088S	PARTICIPANT	\N	PRESENT	0
389852	386236	11056N	PARTICIPANT	\N	PRESENT	0
389853	386236	14115H	PARTICIPANT	\N	PRESENT	0
389854	386236	11101A	PARTICIPANT	\N	PRESENT	0
389855	386236	19507S	PARTICIPANT	\N	PRESENT	0
389856	386236	19747H	PARTICIPANT	\N	PRESENT	0
389857	386236	14207L	PARTICIPANT	\N	PRESENT	0
389858	386236	04043D	PARTICIPANT	\N	PRESENT	0
389859	386236	19619A	PARTICIPANT	\N	PRESENT	0
389860	386236	17589D	PARTICIPANT	\N	PRESENT	0
389861	386236	14257W	PARTICIPANT	\N	PRESENT	0
389862	386236	19467C	PARTICIPANT	\N	EXCUSE	0
389863	386236	19782L	PARTICIPANT	\N	EXCUSE	0
389864	386236	08019V	PARTICIPANT	\N	EXCUSE	0
389865	386236	11081P	PARTICIPANT	\N	EXCUSE	0
389866	386606	19333N	PARTICIPANT	\N	PRESENT	0
389867	386606	19383Y	PARTICIPANT	\N	PRESENT	0
389868	386606	17583W	PARTICIPANT	\N	PRESENT	0
389869	386606	14219Q	PARTICIPANT	\N	PRESENT	0
389870	386606	19637C	PARTICIPANT	\N	PRESENT	0
389871	386606	02002K	PARTICIPANT	\N	PRESENT	0
389872	386606	04085P	PARTICIPANT	\N	PRESENT	0
389873	386606	19503N	PARTICIPANT	\N	PRESENT	0
389874	386606	19347U	PARTICIPANT	\N	PRESENT	0
389875	386606	19745F	PARTICIPANT	\N	PRESENT	0
389876	386606	19525U	PARTICIPANT	\N	PRESENT	0
389877	386606	19549D	PARTICIPANT	\N	PRESENT	0
389878	386606	14237S	PARTICIPANT	\N	PRESENT	0
389879	386606	14031R	PARTICIPANT	\N	PRESENT	0
389880	386606	19551W	PARTICIPANT	\N	PRESENT	0
389881	386606	14093U	PARTICIPANT	\N	PRESENT	0
389882	386606	19737F	PARTICIPANT	\N	PRESENT	0
389883	386606	19733B	PARTICIPANT	\N	PRESENT	0
389884	386606	19713W	PARTICIPANT	\N	PRESENT	0
389886	386606	19701S	PARTICIPANT	\N	PRESENT	0
389887	386606	04097T	PARTICIPANT	\N	PRESENT	0
389888	386606	19599P	PARTICIPANT	\N	PRESENT	0
389889	386606	19685L	PARTICIPANT	\N	PRESENT	0
389890	386606	14103D	PARTICIPANT	\N	PRESENT	0
389891	386606	05012A	PARTICIPANT	\N	PRESENT	0
389893	386615	19443T	PARTICIPANT	\N	PRESENT	0
389894	386615	12041X	PARTICIPANT	\N	PRESENT	0
389895	386615	95030B	PARTICIPANT	\N	PRESENT	0
389896	386615	01058X	PARTICIPANT	\N	PRESENT	0
389897	386615	14079W	PARTICIPANT	\N	PRESENT	0
389898	386615	16685X	PARTICIPANT	\N	PRESENT	0
389899	386615	04042C	PRESIDENT	0	PRESENT	0
389900	386615	11054L	PARTICIPANT	\N	PRESENT	0
389901	386615	11066Q	PARTICIPANT	\N	PRESENT	0
389902	386615	08056B	PARTICIPANT	\N	PRESENT	0
389903	386615	19421M	PARTICIPANT	\N	PRESENT	0
389904	386615	19709B	PARTICIPANT	\N	PRESENT	0
389905	386615	14193X	PRESIDENT	1	PRESENT	0
389906	386615	08053X	PARTICIPANT	\N	PRESENT	0
389907	386615	97011G	PARTICIPANT	\N	PRESENT	0
389908	386615	08047A	PARTICIPANT	\N	PRESENT	0
389909	386615	98029W	PARTICIPANT	\N	PRESENT	0
389910	386615	14097Y	PARTICIPANT	\N	PRESENT	0
389911	386615	04035D	PARTICIPANT	\N	PRESENT	0
374079	371820	19663E	PARTICIPANT	\N	PRESENT	0
375547	371423	04059M	PARTICIPANT	\N	PRESENT	0
375551	375049	11067R	PARTICIPANT	\N	PRESENT	0
375552	375049	19749K	PARTICIPANT	\N	PRESENT	0
375553	375049	04047H	PARTICIPANT	\N	EXCUSE	0
375554	375049	10006L	PRESIDENT	0	PRESENT	0
375555	375049	19621T	PARTICIPANT	\N	EXCUSE	0
375708	375460	08039A	PARTICIPANT	\N	PRESENT	0
375709	371423	14109K	PARTICIPANT	\N	PRESENT	0
375710	371423	08069G	PARTICIPANT	\N	PRESENT	0
375711	371423	11104D	PARTICIPANT	\N	PRESENT	0
375712	371423	14201E	PARTICIPANT	\N	PRESENT	0
376080	376000	14237S	PARTICIPANT	\N	PRESENT	0
376081	376000	19551W	PARTICIPANT	\N	PRESENT	0
376082	376000	19794Q	PARTICIPANT	\N	PRESENT	0
376083	376000	14087W	PARTICIPANT	\N	PRESENT	0
376084	376000	14031R	PARTICIPANT	\N	PRESENT	0
376085	376000	19737F	PARTICIPANT	\N	PRESENT	0
376086	376000	19347U	PARTICIPANT	\N	PRESENT	0
376087	376000	14081Q	PARTICIPANT	\N	PRESENT	0
376088	376000	19251M	PARTICIPANT	\N	PRESENT	0
376089	376000	19585H	PARTICIPANT	\N	PRESENT	0
376090	376000	17637T	PARTICIPANT	\N	PRESENT	0
376091	376000	19637C	PARTICIPANT	\N	PRESENT	0
376092	376000	14241N	PARTICIPANT	\N	EXCUSE	0
376093	376000	14169X	PARTICIPANT	\N	EXCUSE	0
376094	371425	19347U	PARTICIPANT	\N	PRESENT	0
376095	371425	19593H	PARTICIPANT	\N	PRESENT	0
376096	371425	08061X	PARTICIPANT	\N	PRESENT	0
376097	371425	95037J	PARTICIPANT	\N	PRESENT	0
376098	371425	19651A	PARTICIPANT	\N	PRESENT	0
376099	371425	98029W	PARTICIPANT	\N	PRESENT	0
376100	371425	11083R	PARTICIPANT	\N	PRESENT	0
376101	371425	19637C	PARTICIPANT	\N	PRESENT	0
376102	371425	19349W	PARTICIPANT	\N	PRESENT	0
376103	371425	19697Q	PARTICIPANT	\N	PRESENT	0
376104	371425	14039A	PARTICIPANT	\N	PRESENT	0
376105	371425	08073C	PARTICIPANT	\N	PRESENT	0
376106	371425	19782L	PARTICIPANT	\N	PRESENT	0
376107	371425	08024S	PARTICIPANT	\N	PRESENT	0
376108	371425	11072N	PARTICIPANT	\N	PRESENT	0
376109	371425	14055N	PARTICIPANT	\N	PRESENT	0
376110	371425	19731Y	PARTICIPANT	\N	PRESENT	0
376111	371425	19515S	PARTICIPANT	\N	PRESENT	0
376112	371425	11043H	PARTICIPANT	\N	PRESENT	0
376113	371425	04085P	PARTICIPANT	\N	PRESENT	0
376114	371425	08069G	PARTICIPANT	\N	PRESENT	0
376115	371425	05008E	PARTICIPANT	\N	PRESENT	0
376116	371425	11012A	PARTICIPANT	\N	PRESENT	0
376117	371425	19629C	PARTICIPANT	\N	PRESENT	0
376118	371425	14187A	PARTICIPANT	\N	PRESENT	0
376119	371425	19253P	PARTICIPANT	\N	PRESENT	0
376120	371425	14107H	PARTICIPANT	\N	PRESENT	0
376121	371425	14071N	PARTICIPANT	\N	PRESENT	0
376122	371425	14241N	PARTICIPANT	\N	PRESENT	0
376123	371425	19533U	PARTICIPANT	\N	PRESENT	0
376124	371425	19719D	PARTICIPANT	\N	PRESENT	0
376125	371425	04043D	PARTICIPANT	\N	PRESENT	0
376126	371425	08031R	PARTICIPANT	\N	PRESENT	0
376127	371425	19289C	PARTICIPANT	\N	PRESENT	0
376128	371425	14193X	PARTICIPANT	\N	PRESENT	0
376129	371425	14207L	PARTICIPANT	\N	PRESENT	0
376130	371425	14079W	PARTICIPANT	\N	PRESENT	0
376131	371425	11099A	PARTICIPANT	\N	PRESENT	0
376132	371425	14215L	PARTICIPANT	\N	PRESENT	0
376133	371425	11065P	PARTICIPANT	\N	PRESENT	0
376134	371425	19762G	PARTICIPANT	\N	PRESENT	0
376135	371425	19387D	PARTICIPANT	\N	PRESENT	0
376136	371425	19681G	PARTICIPANT	\N	PRESENT	0
376137	371425	19563B	PARTICIPANT	\N	PRESENT	0
376138	371425	08049C	PARTICIPANT	\N	PRESENT	0
376139	371425	19733B	PARTICIPANT	\N	PRESENT	0
376140	371425	19717B	PARTICIPANT	\N	PRESENT	0
376141	371425	19675J	PARTICIPANT	\N	PRESENT	0
376142	371425	14251Q	PARTICIPANT	\N	PRESENT	0
376143	371425	14195A	PARTICIPANT	\N	PRESENT	0
376144	371425	17589D	PARTICIPANT	\N	PRESENT	0
376145	371425	11064N	PARTICIPANT	\N	PRESENT	0
376146	371425	14147R	PARTICIPANT	\N	PRESENT	0
376147	371425	14093U	PARTICIPANT	\N	PRESENT	0
376148	371425	19545Y	PARTICIPANT	\N	PRESENT	0
376149	371425	14329V	PARTICIPANT	\N	PRESENT	0
376150	371425	04057K	PARTICIPANT	\N	PRESENT	0
376151	371425	95063L	PARTICIPANT	\N	PRESENT	0
376152	371425	04059M	PARTICIPANT	\N	PRESENT	0
376153	371425	14159V	PARTICIPANT	\N	PRESENT	0
376154	371425	08055A	PARTICIPANT	\N	PRESENT	0
376155	371425	19701S	PARTICIPANT	\N	PRESENT	0
376156	371425	08052W	PARTICIPANT	\N	PRESENT	0
376157	371425	10006L	PARTICIPANT	\N	PRESENT	0
376158	371425	14229S	PARTICIPANT	\N	PRESENT	0
376159	371425	01028R	PARTICIPANT	\N	PRESENT	0
376160	371425	14061L	PARTICIPANT	\N	PRESENT	0
376161	371425	14059S	PARTICIPANT	\N	PRESENT	0
376162	371425	08015R	PARTICIPANT	\N	PRESENT	0
376163	371425	08045X	PARTICIPANT	\N	PRESENT	0
376164	371425	19621T	PARTICIPANT	\N	PRESENT	0
376165	371425	12016W	PARTICIPANT	\N	PRESENT	0
376166	371425	14151M	PARTICIPANT	\N	PRESENT	0
376167	371425	01062T	PARTICIPANT	\N	PRESENT	0
376168	371425	08060W	PARTICIPANT	\N	PRESENT	0
376169	371425	14028W	PARTICIPANT	\N	PRESENT	0
376170	371425	19649G	PARTICIPANT	\N	PRESENT	0
376171	371425	17583W	PARTICIPANT	\N	PRESENT	0
376172	371425	14197C	PARTICIPANT	\N	PRESENT	0
376173	371425	08047A	PARTICIPANT	\N	PRESENT	0
376174	371425	11066Q	PARTICIPANT	\N	PRESENT	0
376175	371425	11104D	PARTICIPANT	\N	PRESENT	0
376176	371425	14281W	PARTICIPANT	\N	PRESENT	0
376177	371425	19531S	PARTICIPANT	\N	PRESENT	0
376178	371425	08012N	PARTICIPANT	\N	PRESENT	0
376179	371425	14081Q	PARTICIPANT	\N	PRESENT	0
376180	371425	11110B	PARTICIPANT	\N	PRESENT	0
376181	371425	14257W	PARTICIPANT	\N	PRESENT	0
376182	371425	19525U	PARTICIPANT	\N	PRESENT	0
376183	371425	08053X	PARTICIPANT	\N	PRESENT	0
376184	371425	14085U	PARTICIPANT	\N	PRESENT	0
376185	371425	17779H	PARTICIPANT	\N	PRESENT	0
376186	371425	19727D	PARTICIPANT	\N	PRESENT	0
376187	371425	08017T	PARTICIPANT	\N	PRESENT	0
376188	371425	19798U	PARTICIPANT	\N	PRESENT	0
376189	371425	04045F	PARTICIPANT	\N	PRESENT	0
376190	371425	19269X	PARTICIPANT	\N	PRESENT	0
376191	371425	19715Y	PARTICIPANT	\N	PRESENT	0
376192	371425	11080N	PARTICIPANT	\N	PRESENT	0
376193	371425	19703U	PARTICIPANT	\N	PRESENT	0
376194	371425	14001X	PARTICIPANT	\N	PRESENT	0
376195	371425	17637T	PARTICIPANT	\N	PRESENT	0
376196	371425	19711U	PARTICIPANT	\N	PRESENT	0
376197	371425	14227Q	PARTICIPANT	\N	PRESENT	0
376198	371425	19413M	PARTICIPANT	\N	PRESENT	0
376199	371425	19251M	PARTICIPANT	\N	PRESENT	0
376200	371425	04071H	PARTICIPANT	\N	PRESENT	0
376201	371425	19503N	PARTICIPANT	\N	PRESENT	0
376202	371425	19489J	PARTICIPANT	\N	PRESENT	0
376203	371425	19643A	PARTICIPANT	\N	PRESENT	0
376204	371425	14021P	PARTICIPANT	\N	PRESENT	0
376205	371425	11067R	PARTICIPANT	\N	PRESENT	0
376206	371425	19591F	PARTICIPANT	\N	PRESENT	0
376207	371425	08035V	PARTICIPANT	\N	PRESENT	0
376208	371425	14115H	PARTICIPANT	\N	PRESENT	0
376209	371425	19631V	PARTICIPANT	\N	PRESENT	0
376210	371425	95067Q	PARTICIPANT	\N	PRESENT	0
376211	371425	14097Y	PARTICIPANT	\N	PRESENT	0
376212	371425	19725B	PARTICIPANT	\N	PRESENT	0
376213	371425	19415P	PARTICIPANT	\N	PRESENT	0
376214	371425	05012A	PARTICIPANT	\N	PRESENT	0
376215	371425	04092N	PARTICIPANT	\N	PRESENT	0
376216	371425	04034C	PARTICIPANT	\N	PRESENT	0
376217	371425	19443T	PARTICIPANT	\N	PRESENT	0
376218	371425	14217N	PARTICIPANT	\N	PRESENT	0
376219	371425	14033T	PARTICIPANT	\N	PRESENT	0
376220	371425	19599P	PARTICIPANT	\N	PRESENT	0
376221	371425	14135M	PARTICIPANT	\N	PRESENT	0
376222	371425	19689Q	PARTICIPANT	\N	PRESENT	0
376223	371425	97011G	PARTICIPANT	\N	PRESENT	0
376224	371425	08018U	PARTICIPANT	\N	PRESENT	0
376225	371425	19691J	PARTICIPANT	\N	PRESENT	0
376226	371425	01034P	PARTICIPANT	\N	PRESENT	0
376227	371425	04089T	PARTICIPANT	\N	PRESENT	0
376228	371425	11045K	PARTICIPANT	\N	PRESENT	0
376229	371425	14026U	PARTICIPANT	\N	PRESENT	0
376230	371425	11053K	PARTICIPANT	\N	PRESENT	0
376231	371425	19511N	PARTICIPANT	\N	PRESENT	0
376232	371425	19611R	PARTICIPANT	\N	PRESENT	0
376233	371425	19683J	PARTICIPANT	\N	PRESENT	0
376234	371425	19737F	PARTICIPANT	\N	PRESENT	0
376235	371425	14205J	PARTICIPANT	\N	PRESENT	0
376236	371425	19699S	PARTICIPANT	\N	PRESENT	0
375533	375527	14151M	PARTICIPANT	\N	PRESENT	0
375544	373666	99004R	PRESIDENT	0	PRESENT	0
375889	375458	19619A	PARTICIPANT	\N	EXCUSE	0
375536	375527	19447X	PARTICIPANT	\N	PRESENT	0
376237	371425	19721W	PARTICIPANT	\N	PRESENT	0
375538	375527	11072N	PARTICIPANT	\N	PRESENT	0
375539	375527	19762G	PARTICIPANT	\N	PRESENT	0
375540	375527	01028R	PARTICIPANT	\N	PRESENT	0
375541	375527	14275Y	PARTICIPANT	\N	PRESENT	0
376238	371425	19569H	PARTICIPANT	\N	PRESENT	0
376239	371425	08056B	PARTICIPANT	\N	PRESENT	0
376240	371425	19723Y	PARTICIPANT	\N	PRESENT	0
376241	371425	14042U	PARTICIPANT	\N	PRESENT	0
376242	371425	14219Q	PARTICIPANT	\N	PRESENT	0
376243	371425	19441R	PARTICIPANT	\N	PRESENT	0
376244	371425	19713W	PARTICIPANT	\N	PRESENT	0
376245	371425	19479G	PARTICIPANT	\N	PRESENT	0
376246	371425	14275Y	PARTICIPANT	\N	PRESENT	0
376260	371425	14083S	PARTICIPANT	\N	PRESENT	0
376248	371425	14030Q	PARTICIPANT	\N	PRESENT	0
376249	371425	04070G	PARTICIPANT	\N	PRESENT	0
376250	371425	01024M	PARTICIPANT	\N	PRESENT	0
376251	371425	19521Q	PARTICIPANT	\N	PRESENT	0
376252	371425	04040A	PARTICIPANT	\N	PRESENT	0
376253	371425	11085T	PARTICIPANT	\N	PRESENT	0
376254	371425	16685X	PARTICIPANT	\N	PRESENT	0
376255	371425	19383Y	PARTICIPANT	\N	PRESENT	0
376256	371425	19735D	PARTICIPANT	\N	PRESENT	0
376257	371425	14109K	PARTICIPANT	\N	PRESENT	0
376258	371425	19543W	PARTICIPANT	\N	PRESENT	0
376259	371425	04042C	PARTICIPANT	\N	PRESENT	0
376261	371425	14267Y	PARTICIPANT	\N	PRESENT	0
376262	371425	19745F	PARTICIPANT	\N	PRESENT	0
376263	371425	19749K	PARTICIPANT	\N	PRESENT	0
376264	371425	14073Q	PARTICIPANT	\N	PRESENT	0
376265	371425	14089Y	PARTICIPANT	\N	PRESENT	0
376266	371425	08039A	PARTICIPANT	\N	PRESENT	0
376267	371425	11033F	PARTICIPANT	\N	PRESENT	0
376268	371425	04018C	PARTICIPANT	\N	PRESENT	0
376269	371425	19551W	PARTICIPANT	\N	PRESENT	0
376270	371425	14221J	PARTICIPANT	\N	PRESENT	0
376271	371425	11097X	PARTICIPANT	\N	PRESENT	0
376272	371425	01057W	PARTICIPANT	\N	PRESENT	0
376273	371425	04061F	PARTICIPANT	\N	PRESENT	0
376274	371425	01060R	PARTICIPANT	\N	PRESENT	0
376275	371425	04033B	PARTICIPANT	\N	PRESENT	0
376276	371425	07004J	PARTICIPANT	\N	PRESENT	0
376277	371425	14119M	PARTICIPANT	\N	PRESENT	0
376278	371425	19647E	PARTICIPANT	\N	PRESENT	0
376279	371425	08068F	PARTICIPANT	\N	PRESENT	0
376280	371425	11109J	PARTICIPANT	\N	PRESENT	0
376281	371425	11070L	PARTICIPANT	\N	PRESENT	0
376288	371425	98050T	PARTICIPANT	\N	PRESENT	0
376289	371425	19585H	PARTICIPANT	\N	PRESENT	0
376550	371426	04059M	PARTICIPANT	\N	PRESENT	0
376566	371426	19715Y	PARTICIPANT	\N	PRESENT	0
376567	371426	19631V	PARTICIPANT	\N	PRESENT	0
376568	371426	14097Y	PARTICIPANT	\N	PRESENT	0
376569	371426	11041F	PARTICIPANT	\N	PRESENT	0
376570	371426	19782L	PARTICIPANT	\N	PRESENT	0
376571	371426	19719D	PARTICIPANT	\N	PRESENT	0
376572	371426	19441R	PARTICIPANT	\N	PRESENT	0
376573	371426	19713W	PARTICIPANT	\N	PRESENT	0
376574	371426	14089Y	PARTICIPANT	\N	PRESENT	0
376575	371426	14205J	PARTICIPANT	\N	PRESENT	0
376576	371426	07004J	PARTICIPANT	\N	PRESENT	0
376577	371426	01024M	PARTICIPANT	\N	PRESENT	0
376578	371426	19762G	PARTICIPANT	\N	PRESENT	0
376579	371426	19383Y	PARTICIPANT	\N	PRESENT	0
376580	371426	19794Q	PARTICIPANT	\N	PRESENT	0
376581	371426	19447X	PARTICIPANT	\N	PRESENT	0
376582	371426	11090Q	PARTICIPANT	\N	PRESENT	0
376583	371426	04088S	PARTICIPANT	\N	PRESENT	0
376585	371426	14135M	PARTICIPANT	\N	PRESENT	0
376586	371426	19413M	PARTICIPANT	\N	PRESENT	0
376588	371426	96004D	PARTICIPANT	\N	PRESENT	0
376589	371426	14033T	PARTICIPANT	\N	PRESENT	0
376590	371426	14257W	PARTICIPANT	\N	PRESENT	0
376592	371426	01028R	PARTICIPANT	\N	PRESENT	0
376593	371426	19347U	PARTICIPANT	\N	PRESENT	0
376594	371426	14215L	PARTICIPANT	\N	PRESENT	0
376595	371426	14187A	PARTICIPANT	\N	PRESENT	0
376596	371426	14191V	PARTICIPANT	\N	PRESENT	0
376597	371426	14207L	PARTICIPANT	\N	PRESENT	0
376598	371426	11099A	PARTICIPANT	\N	PRESENT	0
376599	371426	04057K	PARTICIPANT	\N	PRESENT	0
376600	371426	19585H	PARTICIPANT	\N	PRESENT	0
376601	371426	14147R	PARTICIPANT	\N	PRESENT	0
376602	371426	19599P	PARTICIPANT	\N	PRESENT	0
376637	371427	01028R	PARTICIPANT	\N	PRESENT	0
376638	371427	19715Y	PARTICIPANT	\N	PRESENT	0
376639	371427	95063L	PARTICIPANT	\N	PRESENT	0
376640	371427	19585H	PARTICIPANT	\N	PRESENT	0
376641	371427	19719D	PARTICIPANT	\N	PRESENT	0
376642	371427	07004J	PARTICIPANT	\N	PRESENT	0
376651	371427	14033T	PARTICIPANT	\N	PRESENT	0
376644	371427	11090Q	PARTICIPANT	\N	PRESENT	0
376645	371427	19762G	PARTICIPANT	\N	PRESENT	0
376817	376816	14219Q	PARTICIPANT	\N	PRESENT	0
376647	371427	05008E	PARTICIPANT	\N	PRESENT	0
376648	371427	04085P	PARTICIPANT	\N	PRESENT	0
376649	371427	04038G	PARTICIPANT	\N	PRESENT	0
376650	371427	04088S	PARTICIPANT	\N	PRESENT	0
376818	376816	19794Q	PARTICIPANT	\N	PRESENT	0
376819	376816	19713W	PARTICIPANT	\N	PRESENT	0
376823	376822	14219Q	PARTICIPANT	\N	PRESENT	0
376824	376822	19794Q	PARTICIPANT	\N	PRESENT	0
376825	376822	19713W	PARTICIPANT	\N	PRESENT	0
376827	376826	14219Q	PARTICIPANT	\N	PRESENT	0
376828	376826	19794Q	PARTICIPANT	\N	PRESENT	0
376829	376826	19713W	PARTICIPANT	\N	PRESENT	0
376831	376830	19794Q	PARTICIPANT	\N	PRESENT	0
376836	376835	14219Q	PARTICIPANT	\N	PRESENT	0
376833	376830	14219Q	PARTICIPANT	\N	PRESENT	0
376834	376830	19713W	PARTICIPANT	\N	PRESENT	0
376837	376835	19794Q	PARTICIPANT	\N	PRESENT	0
376838	376835	19713W	PARTICIPANT	\N	PRESENT	0
376840	376839	14219Q	PARTICIPANT	\N	PRESENT	0
376635	371427	04059M	PARTICIPANT	\N	PRESENT	0
376636	371427	14089Y	PARTICIPANT	\N	PRESENT	0
376841	376839	19794Q	PARTICIPANT	\N	PRESENT	0
376842	376839	19713W	PARTICIPANT	\N	PRESENT	0
376877	376843	14219Q	PARTICIPANT	\N	PRESENT	0
376878	376843	19794Q	PARTICIPANT	\N	PRESENT	0
376889	376885	14219Q	PARTICIPANT	\N	PRESENT	0
376890	376885	19794Q	PARTICIPANT	\N	PRESENT	0
376899	376898	04049K	PARTICIPANT	\N	PRESENT	0
376900	376898	14026U	PARTICIPANT	\N	PRESENT	0
376934	373666	19667J	PARTICIPANT	\N	EXCUSE	0
377389	375455	14213J	PARTICIPANT	\N	PRESENT	0
377390	371474	11070L	PARTICIPANT	\N	PRESENT	0
377391	371474	14135M	PARTICIPANT	\N	PRESENT	0
377392	371474	14201E	PARTICIPANT	\N	PRESENT	0
377393	371474	95030B	PARTICIPANT	\N	PRESENT	0
378407	378405	08055A	PARTICIPANT	\N	PRESENT	0
378408	378405	04047H	PARTICIPANT	\N	PRESENT	0
379958	379957	04086Q	PARTICIPANT	\N	PRESENT	0
378410	378405	14085U	PARTICIPANT	\N	PRESENT	0
378411	378405	11080N	PARTICIPANT	\N	PRESENT	0
378412	378405	11083R	PARTICIPANT	\N	PRESENT	0
378413	378405	01057W	PARTICIPANT	\N	PRESENT	0
379968	379966	04086Q	PARTICIPANT	\N	PRESENT	0
378415	378405	19687N	PARTICIPANT	\N	PRESENT	0
378416	378405	08049C	PARTICIPANT	\N	PRESENT	0
378417	378405	14157T	PARTICIPANT	\N	PRESENT	0
379953	379951	04086Q	PARTICIPANT	\N	PRESENT	0
379969	376986	04057K	PARTICIPANT	\N	PRESENT	0
379971	379970	10015M	PARTICIPANT	\N	PRESENT	0
379973	379972	10015M	PARTICIPANT	\N	PRESENT	0
380041	380040	14193X	PARTICIPANT	\N	PRESENT	0
380042	380040	98022P	PARTICIPANT	\N	PRESENT	0
380044	380043	14193X	PARTICIPANT	\N	PRESENT	0
380045	380043	98022P	PARTICIPANT	\N	PRESENT	0
380047	380046	14193X	PARTICIPANT	\N	PRESENT	0
380048	380046	98022P	PARTICIPANT	\N	PRESENT	0
380095	380094	19709B	PARTICIPANT	\N	PRESENT	0
380096	380094	11027H	PARTICIPANT	\N	PRESENT	0
380099	380098	19709B	PARTICIPANT	\N	PRESENT	0
380100	380098	11027H	PARTICIPANT	\N	PRESENT	0
380102	380101	08011M	PARTICIPANT	\N	PRESENT	0
380103	380101	19711U	PARTICIPANT	\N	PRESENT	0
380105	380104	11074Q	PARTICIPANT	\N	PRESENT	0
380107	380106	11074Q	PARTICIPANT	\N	PRESENT	0
380121	380120	08011M	PARTICIPANT	\N	PRESENT	0
380122	380120	11074Q	PARTICIPANT	\N	PRESENT	0
380125	380123	11074Q	PARTICIPANT	\N	PRESENT	0
380126	380123	08011M	PARTICIPANT	\N	PRESENT	0
380129	380128	08011M	PARTICIPANT	\N	PRESENT	0
380130	380128	11074Q	PARTICIPANT	\N	PRESENT	0
369703	367799	04086Q	PARTICIPANT	\N	EXCUSE	0
370877	367799	11101A	PARTICIPANT	\N	EXCUSE	0
372661	372660	14187A	PARTICIPANT	\N	PRESENT	0
375723	375545	19581D	PARTICIPANT	\N	PRESENT	0
375725	375545	14065Q	PARTICIPANT	\N	EXCUSE	0
382595	382594	96004D	PRESIDENT	0	PRESENT	0
382596	382594	14089Y	PARTICIPANT	\N	EXCUSE	0
382597	382594	14357A	PARTICIPANT	\N	PRESENT	0
382598	382594	14079W	PARTICIPANT	\N	PRESENT	0
382599	382594	14249W	PARTICIPANT	\N	PRESENT	0
382601	382594	19569H	PARTICIPANT	\N	PRESENT	0
382602	382594	95037J	PARTICIPANT	\N	PRESENT	0
382603	382594	04097T	PARTICIPANT	\N	PRESENT	0
382604	382594	14205J	PARTICIPANT	\N	PRESENT	0
382605	382594	04057K	PARTICIPANT	\N	PRESENT	0
382606	382594	14237S	PARTICIPANT	\N	PRESENT	0
382607	382594	14135M	PARTICIPANT	\N	PRESENT	0
382608	382594	14073Q	PARTICIPANT	\N	EXCUSE	0
384273	382001	19553Y	PARTICIPANT	\N	PRESENT	0
384274	382001	19703U	PARTICIPANT	\N	PRESENT	0
384275	382001	11031D	PARTICIPANT	\N	PRESENT	0
384276	382001	14281W	PARTICIPANT	\N	PRESENT	0
384277	382001	14087W	PARTICIPANT	\N	PRESENT	0
384278	382001	19679N	PARTICIPANT	\N	PRESENT	0
384279	382001	14042U	PARTICIPANT	\N	PRESENT	0
384280	382001	14195A	PARTICIPANT	\N	PRESENT	0
384281	382001	19575F	PARTICIPANT	\N	PRESENT	0
384282	382001	14213J	PARTICIPANT	\N	PRESENT	0
384283	382001	19367Y	PARTICIPANT	\N	PRESENT	0
384284	382001	14261S	PARTICIPANT	\N	PRESENT	0
384285	382001	14217N	PARTICIPANT	\N	PRESENT	0
384286	382001	19683J	PARTICIPANT	\N	PRESENT	0
384287	382001	10006L	PARTICIPANT	\N	PRESENT	0
384288	382001	98024R	PARTICIPANT	\N	PRESENT	0
384289	382001	19521Q	PARTICIPANT	\N	PRESENT	0
384290	382001	19527W	PARTICIPANT	\N	PRESENT	0
384291	382001	01034P	PARTICIPANT	\N	PRESENT	0
384292	382001	04092N	PRESIDENT	0	PRESENT	0
384293	382001	11045K	PARTICIPANT	\N	PRESENT	0
384294	382001	08052W	PARTICIPANT	\N	PRESENT	0
384295	382001	19663E	PARTICIPANT	\N	PRESENT	0
384296	382001	19691J	PARTICIPANT	\N	PRESENT	0
384297	382001	19723Y	PARTICIPANT	\N	PRESENT	0
384298	382001	11103C	PARTICIPANT	\N	PRESENT	0
384299	382001	19577H	PARTICIPANT	\N	PRESENT	0
384300	382001	19760E	PARTICIPANT	\N	PRESENT	0
384301	382001	08041T	PARTICIPANT	\N	EXCUSE	0
384308	382748	14331P	PARTICIPANT	\N	PRESENT	0
384309	382748	19545Y	PARTICIPANT	\N	PRESENT	0
384310	382748	01057W	PARTICIPANT	\N	PRESENT	0
384311	382748	11053K	PARTICIPANT	\N	PRESENT	0
384312	382748	19667J	PARTICIPANT	\N	PRESENT	0
384313	382748	11074Q	PRESIDENT	0	PRESENT	0
384314	382748	89017R	PARTICIPANT	\N	PRESENT	0
384315	382748	19671E	PARTICIPANT	\N	PRESENT	0
384316	382748	14225N	PARTICIPANT	\N	PRESENT	0
384317	382748	11070L	PARTICIPANT	\N	PRESENT	0
384318	382748	88008L	PARTICIPANT	\N	PRESENT	0
384319	382748	07029T	PARTICIPANT	\N	PRESENT	0
384320	382748	08010L	PARTICIPANT	\N	PRESENT	0
384321	382748	19479G	PARTICIPANT	\N	PRESENT	0
384322	382748	19711U	PARTICIPANT	\N	PRESENT	0
384323	382748	08034U	PARTICIPANT	\N	PRESENT	0
384324	382748	19689Q	PARTICIPANT	\N	PRESENT	0
384325	382748	08011M	PARTICIPANT	\N	PRESENT	0
384326	382748	14034U	PARTICIPANT	\N	PRESENT	0
384327	382748	08014Q	PARTICIPANT	\N	PRESENT	0
384328	382748	14159V	PARTICIPANT	\N	PRESENT	0
384329	382748	14173T	PARTICIPANT	\N	PRESENT	0
384330	382748	11040E	PARTICIPANT	\N	PRESENT	0
384331	382748	14083S	PARTICIPANT	\N	PRESENT	0
384332	382748	11012A	PARTICIPANT	\N	PRESENT	0
384333	382748	14327T	PARTICIPANT	\N	EXCUSE	0
384339	384208	19735D	PARTICIPANT	\N	EXCUSE	0
384340	382177	19768N	PARTICIPANT	\N	PRESENT	0
384341	382177	19515S	PARTICIPANT	\N	PRESENT	0
384342	382177	19782L	PARTICIPANT	\N	PRESENT	0
384343	382177	01043Q	PARTICIPANT	\N	PRESENT	0
384344	382177	14357A	PARTICIPANT	\N	PRESENT	0
384345	382177	19441R	PARTICIPANT	\N	PRESENT	0
384346	382177	14081Q	PARTICIPANT	\N	PRESENT	0
384347	382177	19413M	PARTICIPANT	\N	PRESENT	0
384348	382177	80013X	PARTICIPANT	\N	PRESENT	0
384349	382177	11099A	PARTICIPANT	\N	PRESENT	0
384350	382177	04049K	PARTICIPANT	\N	PRESENT	0
384351	382177	19705W	PARTICIPANT	\N	PRESENT	0
384352	382177	08015R	PARTICIPANT	\N	PRESENT	0
384353	382177	08019V	PARTICIPANT	\N	PRESENT	0
384354	382177	14197C	PARTICIPANT	\N	PRESENT	0
384355	382177	19369B	PARTICIPANT	\N	PRESENT	0
384356	382177	19511N	PARTICIPANT	\N	PRESENT	0
384357	382177	08028W	PARTICIPANT	\N	PRESENT	0
384358	382177	19563B	PARTICIPANT	\N	PRESENT	0
384359	382177	14329V	PARTICIPANT	\N	PRESENT	0
384360	382177	19591F	PARTICIPANT	\N	PRESENT	0
384361	382177	14135M	PARTICIPANT	\N	PRESENT	0
384362	382177	19467C	PARTICIPANT	\N	PRESENT	0
384363	382177	14187A	PARTICIPANT	\N	PRESENT	0
384364	382177	08038Y	PARTICIPANT	\N	PRESENT	0
384365	382177	08062Y	PARTICIPANT	\N	PRESENT	0
384366	382177	19695N	PARTICIPANT	\N	PRESENT	0
384367	382177	14033T	PARTICIPANT	\N	PRESENT	0
384368	382177	11090Q	PRESIDENT	0	PRESENT	0
384369	382177	19269X	PARTICIPANT	\N	PRESENT	0
384370	382177	14205J	PARTICIPANT	\N	PRESENT	0
384371	382177	04088S	PARTICIPANT	\N	PRESENT	0
384372	382177	11056N	PARTICIPANT	\N	PRESENT	0
384373	382177	04089T	PARTICIPANT	\N	PRESENT	0
384374	382177	14115H	PARTICIPANT	\N	PRESENT	0
384375	382177	11101A	PARTICIPANT	\N	PRESENT	0
384376	382177	19747H	PARTICIPANT	\N	PRESENT	0
384377	382177	04043D	PARTICIPANT	\N	PRESENT	0
384378	382177	17589D	PARTICIPANT	\N	PRESENT	0
384379	382177	19619A	PARTICIPANT	\N	PRESENT	0
384380	382177	19507S	PARTICIPANT	\N	EXCUSE	0
384381	382177	14207L	PARTICIPANT	\N	EXCUSE	0
384382	382177	19295A	PARTICIPANT	\N	EXCUSE	0
384383	382177	08021P	PARTICIPANT	\N	EXCUSE	0
384384	382177	11081P	PARTICIPANT	\N	EXCUSE	0
384385	382177	19631V	PARTICIPANT	\N	EXCUSE	0
384386	382615	14237S	PARTICIPANT	\N	PRESENT	0
384387	384109	14053L	PARTICIPANT	\N	PRESENT	0
384388	384109	14111D	PARTICIPANT	\N	PRESENT	0
384389	384109	14001X	PARTICIPANT	\N	PRESENT	0
384390	384109	01024M	PARTICIPANT	\N	PRESENT	0
384391	384109	04044E	PARTICIPANT	\N	PRESENT	0
384392	384109	04038G	PARTICIPANT	\N	PRESENT	0
384393	384109	04047H	PARTICIPANT	\N	PRESENT	0
384394	384109	19675J	PARTICIPANT	\N	PRESENT	0
384395	384109	01028R	PARTICIPANT	\N	PRESENT	0
384396	384109	05008E	PRESIDENT	0	PRESENT	0
384397	384109	19447X	PARTICIPANT	\N	PRESENT	0
384398	384109	14231L	PARTICIPANT	\N	PRESENT	0
384399	384109	19725B	PARTICIPANT	\N	PRESENT	0
384400	384109	19489J	PARTICIPANT	\N	PRESENT	0
384401	384109	14041T	PARTICIPANT	\N	PRESENT	0
384402	384109	14147R	PARTICIPANT	\N	PRESENT	0
384403	384109	14151M	PARTICIPANT	\N	PRESENT	0
384404	384109	14069U	PARTICIPANT	\N	PRESENT	0
384405	384109	08018U	PARTICIPANT	\N	PRESENT	0
384406	384109	11049P	PARTICIPANT	\N	PRESENT	0
384407	384109	98035U	PARTICIPANT	\N	PRESENT	0
384408	384109	19729F	PARTICIPANT	\N	PRESENT	0
384409	384109	14275Y	PARTICIPANT	\N	PRESENT	0
384410	384109	95063L	PARTICIPANT	\N	PRESENT	0
384411	384109	19629C	PARTICIPANT	\N	PRESENT	0
384412	384109	11026G	PARTICIPANT	\N	PRESENT	0
384413	384109	19543W	PARTICIPANT	\N	PRESENT	0
384414	384109	14215L	PRESIDENT	1	PRESENT	0
384415	384109	19719D	PARTICIPANT	\N	PRESENT	0
384416	384109	19673G	PARTICIPANT	\N	PRESENT	0
384425	382001	14071N	PARTICIPANT	\N	PRESENT	0
384426	382001	19727D	PARTICIPANT	\N	PRESENT	0
384427	382001	19565D	PARTICIPANT	\N	EXCUSE	0
384428	382001	17779H	PARTICIPANT	\N	EXCUSE	0
384430	384107	19581D	PARTICIPANT	\N	EXCUSE	0
384431	382748	11048N	PARTICIPANT	\N	EXCUSE	0
384432	384108	14065Q	PARTICIPANT	\N	EXCUSE	0
384433	384108	19581D	PARTICIPANT	\N	EXCUSE	0
384435	384109	14065Q	PARTICIPANT	\N	EXCUSE	0
384436	384109	19581D	PARTICIPANT	\N	EXCUSE	0
384437	384109	14259Y	PARTICIPANT	\N	PRESENT	0
384440	384439	08010L	PARTICIPANT	\N	PRESENT	0
384441	384439	14041T	PARTICIPANT	\N	PRESENT	0
384442	384439	19693L	PARTICIPANT	\N	PRESENT	0
384443	384439	04043D	PARTICIPANT	\N	PRESENT	0
384444	384439	04045F	PARTICIPANT	\N	PRESENT	0
384446	384439	19467C	PARTICIPANT	\N	PRESENT	0
384449	371543	11027H	PARTICIPANT	\N	PRESENT	0
389912	386615	95067Q	PARTICIPANT	\N	PRESENT	0
389913	386615	14133K	PARTICIPANT	\N	PRESENT	0
389914	386615	01062T	PARTICIPANT	\N	PRESENT	0
389915	386615	11041F	PARTICIPANT	\N	PRESENT	0
389916	386615	08058D	PARTICIPANT	\N	PRESENT	0
389917	386615	19721W	PARTICIPANT	\N	PRESENT	0
389918	386615	19319Q	PARTICIPANT	\N	PRESENT	0
389919	386615	14105F	PARTICIPANT	\N	PRESENT	0
389920	386615	98022P	PARTICIPANT	\N	PRESENT	0
389921	386615	14267Y	PARTICIPANT	\N	PRESENT	0
389922	386615	98050T	PARTICIPANT	\N	PRESENT	0
389923	386615	19583F	PARTICIPANT	\N	PRESENT	0
389924	386615	14255U	PARTICIPANT	\N	PRESENT	0
389925	386615	98018T	PARTICIPANT	\N	EXCUSE	0
389927	386613	04040A	PARTICIPANT	\N	EXCUSE	0
389928	386613	11115U	PARTICIPANT	\N	EXCUSE	0
389929	389034	11109J	PARTICIPANT	\N	PRESENT	0
389931	386613	14055N	PARTICIPANT	\N	EXCUSE	0
389932	386615	04040A	PARTICIPANT	\N	EXCUSE	0
389933	386615	11115U	PARTICIPANT	\N	EXCUSE	0
389934	386615	14055N	PARTICIPANT	\N	EXCUSE	0
389935	387199	14327T	PARTICIPANT	\N	PRESENT	0
389936	387199	95041E	PARTICIPANT	\N	PRESENT	0
389937	387199	01048V	PARTICIPANT	\N	PRESENT	0
389938	387199	19545Y	PARTICIPANT	\N	PRESENT	0
389939	387199	11053K	PARTICIPANT	\N	PRESENT	0
389940	387199	19667J	PARTICIPANT	\N	PRESENT	0
389941	387199	89017R	PARTICIPANT	\N	PRESENT	0
389942	387199	11074Q	PRESIDENT	0	PRESENT	0
389943	387199	14225N	PARTICIPANT	\N	PRESENT	0
389944	387199	88008L	PARTICIPANT	\N	PRESENT	0
390070	388106	17779H	PARTICIPANT	\N	PRESENT	0
389946	387199	14085U	PARTICIPANT	\N	PRESENT	0
389947	387199	19349W	PARTICIPANT	\N	PRESENT	0
389948	387199	08010L	PARTICIPANT	\N	PRESENT	0
389949	387199	14253S	PARTICIPANT	\N	PRESENT	0
389950	387199	19479G	PARTICIPANT	\N	PRESENT	0
389951	387199	11048N	PARTICIPANT	\N	PRESENT	0
389952	387199	19711U	PARTICIPANT	\N	PRESENT	0
389953	387199	19689Q	PARTICIPANT	\N	PRESENT	0
389954	387199	11040E	PARTICIPANT	\N	PRESENT	0
389955	387199	14083S	PARTICIPANT	\N	PRESENT	0
389956	387199	11012A	PARTICIPANT	\N	PRESENT	0
389957	387199	19741B	PARTICIPANT	\N	PRESENT	0
389958	387199	14121F	PARTICIPANT	\N	PRESENT	0
389959	387199	99004R	PARTICIPANT	\N	PRESENT	0
389960	387199	07029T	PARTICIPANT	\N	EXCUSE	0
389961	387199	08011M	PARTICIPANT	\N	EXCUSE	0
389962	387199	08014Q	PARTICIPANT	\N	EXCUSE	0
389963	387199	19651A	PARTICIPANT	\N	EXCUSE	0
389967	389965	14147R	PARTICIPANT	\N	PRESENT	0
389968	389965	11097X	PARTICIPANT	\N	PRESENT	0
389978	389977	14147R	PARTICIPANT	\N	PRESENT	0
389979	389977	11097X	PARTICIPANT	\N	PRESENT	0
390016	389606	14053L	PARTICIPANT	\N	PRESENT	0
390017	389606	14001X	PARTICIPANT	\N	PRESENT	0
390018	389606	14179A	PARTICIPANT	\N	PRESENT	0
390019	389606	14151M	PARTICIPANT	\N	PRESENT	0
390020	389606	19585H	PARTICIPANT	\N	PRESENT	0
390021	389606	08018U	PARTICIPANT	\N	PRESENT	0
390022	389606	04047H	PARTICIPANT	\N	PRESENT	0
390023	389606	01028R	PARTICIPANT	\N	PRESENT	0
390024	389606	19447X	PARTICIPANT	\N	PRESENT	0
390025	389606	05008E	PRESIDENT	0	PRESENT	0
390026	389606	11072N	PARTICIPANT	\N	PRESENT	0
390027	389606	19543W	PARTICIPANT	\N	PRESENT	0
390028	389606	19581D	PARTICIPANT	\N	PRESENT	0
390029	389606	04044E	PARTICIPANT	\N	PRESENT	0
390030	389606	19675J	PARTICIPANT	\N	PRESENT	0
390031	389606	14231L	PARTICIPANT	\N	PRESENT	0
390032	389606	19489J	PARTICIPANT	\N	PRESENT	0
390033	389606	14275Y	PARTICIPANT	\N	PRESENT	0
390034	389606	14041T	PARTICIPANT	\N	PRESENT	0
390035	389606	14147R	PARTICIPANT	\N	PRESENT	0
390036	389606	14215L	PARTICIPANT	\N	PRESENT	0
390037	389606	14259Y	PARTICIPANT	\N	PRESENT	0
390038	389606	98035U	PARTICIPANT	\N	PRESENT	0
390039	389606	14111D	PARTICIPANT	\N	PRESENT	0
390040	389606	19649G	PARTICIPANT	\N	PRESENT	0
390041	389606	14065Q	PARTICIPANT	\N	PRESENT	0
390042	389606	11010L	PARTICIPANT	\N	PRESENT	0
390043	389606	08045X	PARTICIPANT	\N	PRESENT	0
390044	389606	10015M	PARTICIPANT	\N	PRESENT	0
390045	389606	19253P	PARTICIPANT	\N	PRESENT	0
390046	389606	01024M	PARTICIPANT	\N	PRESENT	0
390047	389606	04038G	PARTICIPANT	\N	PRESENT	0
390048	389606	19719D	PARTICIPANT	\N	PRESENT	0
390049	389606	11033F	PARTICIPANT	\N	PRESENT	0
390050	389606	14089Y	PARTICIPANT	\N	PRESENT	0
390051	389606	19725B	PARTICIPANT	\N	PRESENT	0
390052	389606	19729F	PARTICIPANT	\N	PRESENT	0
390053	389606	95063L	PARTICIPANT	\N	PRESENT	0
390054	389606	19629C	PARTICIPANT	\N	PRESENT	0
390055	389606	08044W	PARTICIPANT	\N	PRESENT	0
390056	389606	14069U	PARTICIPANT	\N	PRESENT	0
390057	389606	11085T	PARTICIPANT	\N	PRESENT	0
390058	389606	11049P	PARTICIPANT	\N	PRESENT	0
390059	389606	04008A	PARTICIPANT	\N	PRESENT	0
390063	388106	86034E	PARTICIPANT	\N	PRESENT	0
390065	387199	19671E	PARTICIPANT	\N	PRESENT	0
390066	387199	14159V	PARTICIPANT	\N	PRESENT	0
390067	387199	08069G	PARTICIPANT	\N	PRESENT	0
390069	388106	19295A	PARTICIPANT	\N	PRESENT	0
390071	388106	19503N	PARTICIPANT	\N	PRESENT	0
390072	388106	19333N	PARTICIPANT	\N	PRESENT	0
390073	388106	19525U	PARTICIPANT	\N	PRESENT	0
390074	388106	08045X	PARTICIPANT	\N	PRESENT	0
390075	388106	19349W	PARTICIPANT	\N	PRESENT	0
390076	388106	19651A	PARTICIPANT	\N	PRESENT	0
390077	388106	04045F	PARTICIPANT	\N	PRESENT	0
390078	388106	98022P	PARTICIPANT	\N	PRESENT	0
390079	388106	19585H	PARTICIPANT	\N	PRESENT	0
390080	388106	17589D	PARTICIPANT	\N	PRESENT	0
390081	388106	19583F	PARTICIPANT	\N	PRESENT	0
390082	388106	98029W	PARTICIPANT	\N	PRESENT	0
390083	388106	19629C	PARTICIPANT	\N	PRESENT	0
390084	388106	19253P	PARTICIPANT	\N	PRESENT	0
390085	388106	11054L	PARTICIPANT	\N	PRESENT	0
390086	388106	19659J	PARTICIPANT	\N	PRESENT	0
390087	388106	14229S	PARTICIPANT	\N	PRESENT	0
390088	388106	19637C	PARTICIPANT	\N	PRESENT	0
390089	388106	11066Q	PARTICIPANT	\N	PRESENT	0
390090	388106	14235Q	PARTICIPANT	\N	PRESENT	0
390091	388106	19695N	PARTICIPANT	\N	PRESENT	0
390092	388106	11040E	PARTICIPANT	\N	PRESENT	0
390093	388106	19669L	PARTICIPANT	\N	PRESENT	0
390094	388106	19565D	PARTICIPANT	\N	PRESENT	0
390095	388106	14225N	PARTICIPANT	\N	PRESENT	0
390096	388106	11041F	PARTICIPANT	\N	PRESENT	0
390097	388106	19347U	PARTICIPANT	\N	PRESENT	0
390098	388106	19725B	PARTICIPANT	\N	PRESENT	0
390099	388106	11072N	PARTICIPANT	\N	PRESENT	0
390100	388106	08024S	PARTICIPANT	\N	PRESENT	0
390101	388106	14085U	PARTICIPANT	\N	PRESENT	0
390102	388106	14111D	PARTICIPANT	\N	PRESENT	0
390103	388106	04057K	PARTICIPANT	\N	PRESENT	0
390104	388106	14034U	PARTICIPANT	\N	PRESENT	0
390105	388106	08061X	PARTICIPANT	\N	PRESENT	0
390106	388106	04059M	PARTICIPANT	\N	PRESENT	0
390107	388106	08068F	PARTICIPANT	\N	PRESENT	0
390108	388106	14197C	PARTICIPANT	\N	PRESENT	0
390109	388106	04085P	PARTICIPANT	\N	PRESENT	0
390110	388106	11031D	PARTICIPANT	\N	PRESENT	0
390111	388106	11056N	PARTICIPANT	\N	PRESENT	0
390112	388106	19758L	PARTICIPANT	\N	PRESENT	0
390113	388106	95037J	PARTICIPANT	\N	PRESENT	0
390114	388106	19543W	PARTICIPANT	\N	PRESENT	0
390115	388106	19697Q	PARTICIPANT	\N	PRESENT	0
390116	388106	19563B	PARTICIPANT	\N	PRESENT	0
390117	388106	02002K	PARTICIPANT	\N	PRESENT	0
390118	388106	14195A	PARTICIPANT	\N	PRESENT	0
390119	388106	88008L	PARTICIPANT	\N	PRESENT	0
390120	388106	08031R	PARTICIPANT	\N	PRESENT	0
390121	388106	08049C	PARTICIPANT	\N	PRESENT	0
390122	388106	14261S	PARTICIPANT	\N	PRESENT	0
390123	388106	11083R	PARTICIPANT	\N	PRESENT	0
390124	388106	14241N	PARTICIPANT	\N	PRESENT	0
390125	388106	14121F	PARTICIPANT	\N	PRESENT	0
390126	388106	14207L	PARTICIPANT	\N	PRESENT	0
390127	388106	19387D	PARTICIPANT	\N	PRESENT	0
390128	388106	19289C	PARTICIPANT	\N	PRESENT	0
390129	388106	11065P	PARTICIPANT	\N	PRESENT	0
390130	388106	19731Y	PARTICIPANT	\N	PRESENT	0
390131	388106	19685L	PARTICIPANT	\N	PRESENT	0
390132	388106	89017R	PARTICIPANT	\N	PRESENT	0
390133	388106	19329S	PARTICIPANT	\N	PRESENT	0
390134	388106	14159V	PARTICIPANT	\N	PRESENT	0
390135	388106	11074Q	PARTICIPANT	\N	PRESENT	0
368874	366778	11067R	PARTICIPANT	\N	PRESENT	0
368875	366778	19565D	PARTICIPANT	\N	PRESENT	0
368876	366778	19798U	PARTICIPANT	\N	PRESENT	0
368877	366778	19569H	PARTICIPANT	\N	PRESENT	0
368878	366778	11097X	PARTICIPANT	\N	PRESENT	0
368879	366778	19415P	PARTICIPANT	\N	PRESENT	0
368880	366778	14223L	PARTICIPANT	\N	PRESENT	0
368881	366778	04045F	PARTICIPANT	\N	PRESENT	0
368882	366778	14026U	PARTICIPANT	\N	PRESENT	0
368883	366778	14227Q	PARTICIPANT	\N	PRESENT	0
368884	366778	14239U	PARTICIPANT	\N	PRESENT	0
368885	366778	19553Y	PARTICIPANT	\N	PRESENT	0
368886	366778	11031D	PARTICIPANT	\N	PRESENT	0
368887	366778	14281W	PARTICIPANT	\N	PRESENT	0
368888	366778	19679N	PARTICIPANT	\N	PRESENT	0
368889	366778	14042U	PARTICIPANT	\N	PRESENT	0
368890	366778	19575F	PARTICIPANT	\N	PRESENT	0
368891	366778	08048B	PARTICIPANT	\N	PRESENT	0
368892	366778	14195A	PARTICIPANT	\N	PRESENT	0
368893	366778	14213J	PARTICIPANT	\N	PRESENT	0
368894	366778	10006L	PARTICIPANT	\N	PRESENT	0
368895	366778	19683J	PARTICIPANT	\N	PRESENT	0
368896	366778	98024R	PARTICIPANT	\N	PRESENT	0
368897	366778	04092N	PRESIDENT	0	PRESENT	0
368898	366778	08052W	PARTICIPANT	\N	PRESENT	0
368899	366778	19717B	PARTICIPANT	\N	PRESENT	0
368900	366778	19727D	PARTICIPANT	\N	PRESENT	0
368901	366778	14119M	PARTICIPANT	\N	PRESENT	0
368902	366778	11103C	PARTICIPANT	\N	PRESENT	0
368903	366778	19657G	PARTICIPANT	\N	PRESENT	0
368904	366778	14071N	PARTICIPANT	\N	PRESENT	0
368905	366778	19760E	PARTICIPANT	\N	PRESENT	0
368906	366778	08041T	PARTICIPANT	\N	EXCUSE	0
368907	366779	11067R	PARTICIPANT	\N	PRESENT	0
368908	366779	19565D	PARTICIPANT	\N	PRESENT	0
368909	366779	14355X	PARTICIPANT	\N	PRESENT	0
368910	366779	19569H	PARTICIPANT	\N	PRESENT	0
368911	366779	19798U	PARTICIPANT	\N	PRESENT	0
368912	366779	11097X	PARTICIPANT	\N	PRESENT	0
368913	366779	19415P	PARTICIPANT	\N	PRESENT	0
368914	366779	04045F	PARTICIPANT	\N	PRESENT	0
368915	366779	14223L	PARTICIPANT	\N	PRESENT	0
368916	366779	14026U	PARTICIPANT	\N	PRESENT	0
368917	366779	14227Q	PARTICIPANT	\N	PRESENT	0
368918	366779	11031D	PARTICIPANT	\N	PRESENT	0
368919	366779	19553Y	PARTICIPANT	\N	PRESENT	0
368920	366779	14239U	PARTICIPANT	\N	PRESENT	0
368921	366779	14281W	PARTICIPANT	\N	PRESENT	0
368922	366779	19679N	PARTICIPANT	\N	PRESENT	0
368923	366779	14042U	PARTICIPANT	\N	PRESENT	0
368924	366779	19575F	PARTICIPANT	\N	PRESENT	0
368925	366779	14195A	PARTICIPANT	\N	PRESENT	0
368926	366779	08048B	PARTICIPANT	\N	PRESENT	0
368927	366779	14213J	PARTICIPANT	\N	PRESENT	0
368928	366779	19367Y	PARTICIPANT	\N	PRESENT	0
368929	366779	10006L	PARTICIPANT	\N	PRESENT	0
368930	366779	19683J	PARTICIPANT	\N	PRESENT	0
368931	366779	98024R	PRESIDENT	1	PRESENT	0
368932	366779	04092N	PRESIDENT	0	PRESENT	0
368933	366779	08052W	PARTICIPANT	\N	PRESENT	0
368934	366779	19691J	PARTICIPANT	\N	PRESENT	0
368935	366779	19717B	PARTICIPANT	\N	PRESENT	0
368936	366779	19723Y	PARTICIPANT	\N	PRESENT	0
368937	366779	19727D	PARTICIPANT	\N	PRESENT	0
368938	366779	14119M	PARTICIPANT	\N	PRESENT	0
368939	366779	11103C	PARTICIPANT	\N	PRESENT	0
368940	366779	19657G	PARTICIPANT	\N	PRESENT	0
368941	366779	14071N	PARTICIPANT	\N	PRESENT	0
368942	366779	19577H	PARTICIPANT	\N	PRESENT	0
368943	366779	19760E	PARTICIPANT	\N	PRESENT	0
368944	367210	19551W	PARTICIPANT	\N	PRESENT	0
368945	367210	08055A	PARTICIPANT	\N	EXCUSE	0
368977	367007	14133K	PARTICIPANT	\N	PRESENT	0
368980	367353	11010L	PARTICIPANT	\N	PRESENT	0
368981	367353	19253P	PARTICIPANT	\N	PRESENT	0
368982	367353	19581D	PARTICIPANT	\N	PRESENT	0
368983	367353	19629C	PARTICIPANT	\N	PRESENT	0
368984	367353	14259Y	PARTICIPANT	\N	PRESENT	0
368985	367353	19543W	PARTICIPANT	\N	PRESENT	0
368986	367353	11085T	PARTICIPANT	\N	PRESENT	0
368987	367353	19675J	PARTICIPANT	\N	EXCUSE	0
368992	367087	19467C	PARTICIPANT	\N	PRESENT	0
368996	356297	14034U	PARTICIPANT	\N	PRESENT	0
368997	356297	14237S	PARTICIPANT	\N	PRESENT	0
368998	356297	14191V	PARTICIPANT	\N	PRESENT	0
368999	356297	14033T	PARTICIPANT	\N	PRESENT	0
369000	356297	19671E	PARTICIPANT	\N	PRESENT	0
369001	356297	14205J	PARTICIPANT	\N	PRESENT	0
369002	356297	08068F	PARTICIPANT	\N	PRESENT	0
369003	356297	17589D	PARTICIPANT	\N	PRESENT	0
369004	356297	08056B	PARTICIPANT	\N	PRESENT	0
369005	356297	08028W	PARTICIPANT	\N	PRESENT	0
369006	356297	19782L	PARTICIPANT	\N	PRESENT	0
369007	356297	11045K	PARTICIPANT	\N	PRESENT	0
369008	356297	14073Q	PARTICIPANT	\N	PRESENT	0
369009	356297	19798U	PARTICIPANT	\N	PRESENT	0
369010	356297	14109K	PARTICIPANT	\N	PRESENT	0
369011	356297	11090Q	PARTICIPANT	\N	PRESENT	0
369012	356297	14207L	PARTICIPANT	\N	PRESENT	0
369013	356297	19413M	PARTICIPANT	\N	PRESENT	0
369014	356297	14235Q	PARTICIPANT	\N	PRESENT	0
369015	356297	19565D	PARTICIPANT	\N	PRESENT	0
369016	356297	19507S	PARTICIPANT	\N	PRESENT	0
369017	356297	18083K	PARTICIPANT	\N	PRESENT	0
369018	356297	80013X	PARTICIPANT	\N	PRESENT	0
369019	356297	19599P	PARTICIPANT	\N	PRESENT	0
369020	356297	11056N	PARTICIPANT	\N	PRESENT	0
369021	356297	11040E	PARTICIPANT	\N	PRESENT	0
369022	356297	19441R	PARTICIPANT	\N	PRESENT	0
369023	356297	19551W	PARTICIPANT	\N	PRESENT	0
369024	356297	14257W	PARTICIPANT	\N	PRESENT	0
369025	356297	08043V	PARTICIPANT	\N	PRESENT	0
369026	356297	14157T	PARTICIPANT	\N	PRESENT	0
369027	356297	19667J	PARTICIPANT	\N	PRESENT	0
369028	356297	19515S	PARTICIPANT	\N	PRESENT	0
369029	356297	14119M	PARTICIPANT	\N	PRESENT	0
369030	356297	08015R	PARTICIPANT	\N	PRESENT	0
369031	356297	14105F	PARTICIPANT	\N	PRESENT	0
369032	356297	04049K	PARTICIPANT	\N	PRESENT	0
369033	356297	95030B	PARTICIPANT	\N	PRESENT	0
369034	356297	11099A	PARTICIPANT	\N	PRESENT	0
369035	356297	19269X	PARTICIPANT	\N	PRESENT	0
369036	356297	97011G	PARTICIPANT	\N	PRESENT	0
369037	356297	14327T	PARTICIPANT	\N	PRESENT	0
369038	356297	14083S	PARTICIPANT	\N	PRESENT	0
369039	356297	14179A	PARTICIPANT	\N	PRESENT	0
369040	356297	17583W	PARTICIPANT	\N	PRESENT	0
369041	356297	15447F	PARTICIPANT	\N	PRESENT	0
369042	356297	14211G	PARTICIPANT	\N	PRESENT	0
369043	356297	14087W	PARTICIPANT	\N	PRESENT	0
369044	356297	08062Y	PARTICIPANT	\N	PRESENT	0
369045	356297	14265W	PARTICIPANT	\N	PRESENT	0
369046	356297	14259Y	PARTICIPANT	\N	PRESENT	0
369047	356297	19695N	PARTICIPANT	\N	PRESENT	0
369048	356297	19631V	PARTICIPANT	\N	PRESENT	0
369049	356297	19467C	PARTICIPANT	\N	PRESENT	0
369050	356297	14173T	PARTICIPANT	\N	PRESENT	0
369051	356297	08031R	PARTICIPANT	\N	PRESENT	0
369052	356297	19479G	PARTICIPANT	\N	PRESENT	0
369053	356297	14038Y	PARTICIPANT	\N	PRESENT	0
369054	356297	14051J	PARTICIPANT	\N	PRESENT	0
369055	356297	12016W	PARTICIPANT	\N	PRESENT	0
369056	356297	14217N	PARTICIPANT	\N	PRESENT	0
369057	356297	87003B	PARTICIPANT	\N	PRESENT	0
369058	356297	04089T	PARTICIPANT	\N	PRESENT	0
369059	356297	14107H	PARTICIPANT	\N	PRESENT	0
369060	356297	19794Q	PARTICIPANT	\N	PRESENT	0
369061	356297	14223L	PARTICIPANT	\N	PRESENT	0
369062	356297	01025N	PARTICIPANT	\N	PRESENT	0
369063	356297	19549D	PARTICIPANT	\N	PRESENT	0
369064	356297	19399H	PARTICIPANT	\N	PRESENT	0
369065	356297	07033P	PARTICIPANT	\N	PRESENT	0
369066	356297	19711U	PARTICIPANT	\N	PRESENT	0
369067	356297	14187A	PARTICIPANT	\N	PRESENT	0
369068	356297	08048B	PARTICIPANT	\N	PRESENT	0
369069	356297	19737F	PARTICIPANT	\N	PRESENT	0
369070	356297	07004J	PARTICIPANT	\N	PRESENT	0
369071	356297	88008L	PARTICIPANT	\N	PRESENT	0
369072	356297	14081Q	PARTICIPANT	\N	PRESENT	0
369073	356297	11104D	PARTICIPANT	\N	PRESENT	0
369074	356297	14135M	PARTICIPANT	\N	PRESENT	0
369075	356297	19521Q	PARTICIPANT	\N	PRESENT	0
369076	356297	14103D	PARTICIPANT	\N	PRESENT	0
369077	356297	14029X	PARTICIPANT	\N	PRESENT	0
369078	356297	01058X	PARTICIPANT	\N	PRESENT	0
369079	356297	19383Y	PARTICIPANT	\N	PRESENT	0
369080	356297	19347U	PARTICIPANT	\N	PRESENT	0
369081	356297	14031R	PARTICIPANT	\N	PRESENT	0
369082	356297	04088S	PARTICIPANT	\N	PRESENT	0
362704	360656	11031D	PARTICIPANT	\N	PRESENT	0
362705	360656	14281W	PARTICIPANT	\N	PRESENT	0
362706	360656	14087W	PARTICIPANT	\N	PRESENT	0
362707	360656	19679N	PARTICIPANT	\N	PRESENT	0
362708	360656	14042U	PARTICIPANT	\N	PRESENT	0
362709	360656	14195A	PARTICIPANT	\N	PRESENT	0
362710	360656	19575F	PARTICIPANT	\N	PRESENT	0
362711	360656	19367Y	PARTICIPANT	\N	PRESENT	0
362712	360656	14213J	PARTICIPANT	\N	PRESENT	0
362713	360656	14261S	PARTICIPANT	\N	PRESENT	0
362714	360656	19683J	PARTICIPANT	\N	PRESENT	0
362715	360656	98024R	PARTICIPANT	\N	PRESENT	0
362716	360656	01034P	PARTICIPANT	\N	PRESENT	0
362717	360656	04092N	PRESIDENT	0	PRESENT	0
362718	360656	11045K	PARTICIPANT	\N	PRESENT	0
362719	360656	08052W	PARTICIPANT	\N	PRESENT	0
362720	360656	19663E	PARTICIPANT	\N	PRESENT	0
362721	360656	19301E	PARTICIPANT	\N	PRESENT	0
362722	360656	19715Y	PARTICIPANT	\N	PRESENT	0
362723	360656	19691J	PARTICIPANT	\N	PRESENT	0
362724	360656	19717B	PARTICIPANT	\N	PRESENT	0
362725	360656	19723Y	PARTICIPANT	\N	PRESENT	0
362726	360656	19727D	PARTICIPANT	\N	PRESENT	0
362727	360656	14119M	PARTICIPANT	\N	PRESENT	0
362728	360656	11103C	PARTICIPANT	\N	PRESENT	0
362729	360656	14071N	PARTICIPANT	\N	PRESENT	0
362730	360656	19760E	PARTICIPANT	\N	PRESENT	0
362731	360656	08041T	PARTICIPANT	\N	EXCUSE	0
380133	380132	11074Q	PARTICIPANT	\N	PRESENT	0
380134	380132	08011M	PARTICIPANT	\N	PRESENT	0
380143	380142	95030B	PARTICIPANT	\N	PRESENT	0
380144	380142	01058X	PARTICIPANT	\N	PRESENT	0
380145	380142	14079W	PARTICIPANT	\N	PRESENT	0
380157	380156	19671E	PARTICIPANT	\N	PRESENT	0
380159	380158	04071H	PARTICIPANT	\N	PRESENT	0
380214	380213	08052W	PARTICIPANT	\N	PRESENT	0
380215	380213	10006L	PARTICIPANT	\N	PRESENT	0
380216	380213	19553Y	PARTICIPANT	\N	PRESENT	0
380218	380217	14026U	PARTICIPANT	\N	PRESENT	0
380219	380217	19717B	PARTICIPANT	\N	PRESENT	0
380222	380221	14026U	PARTICIPANT	\N	PRESENT	0
380223	380221	19717B	PARTICIPANT	\N	PRESENT	0
380253	380225	19611R	PARTICIPANT	\N	PRESENT	0
380254	380225	08020N	PARTICIPANT	\N	PRESENT	0
380255	380225	14123H	PARTICIPANT	\N	PRESENT	0
380256	380225	11043H	PARTICIPANT	\N	PRESENT	0
380257	380225	19758L	PARTICIPANT	\N	PRESENT	0
380258	380225	19621T	PARTICIPANT	\N	PRESENT	0
380259	378919	19333N	PARTICIPANT	\N	PRESENT	0
380260	378919	19701S	PARTICIPANT	\N	PRESENT	0
380261	378919	19794Q	PARTICIPANT	\N	PRESENT	0
380262	378919	19549D	PARTICIPANT	\N	PRESENT	0
380263	378919	14219Q	PARTICIPANT	\N	PRESENT	0
380264	378919	14221J	PARTICIPANT	\N	PRESENT	0
380265	378919	19599P	PARTICIPANT	\N	PRESENT	0
380266	378919	19637C	PARTICIPANT	\N	PRESENT	0
380267	378919	18083K	PARTICIPANT	\N	PRESENT	0
380268	378919	14237S	PARTICIPANT	\N	PRESENT	0
380269	378919	80027E	PARTICIPANT	\N	PRESENT	0
380270	378919	14051J	PARTICIPANT	\N	PRESENT	0
380271	378919	08060W	PARTICIPANT	\N	PRESENT	0
380272	378919	19503N	PARTICIPANT	\N	PRESENT	0
380273	378919	19347U	PARTICIPANT	\N	PRESENT	0
380274	378919	96004D	PARTICIPANT	\N	PRESENT	0
380275	378919	14157T	PARTICIPANT	\N	PRESENT	0
380276	378919	08024S	PARTICIPANT	\N	PRESENT	0
380277	378919	19681G	PARTICIPANT	\N	PRESENT	0
380278	378919	17637T	PARTICIPANT	\N	PRESENT	0
380279	378919	19525U	PARTICIPANT	\N	PRESENT	0
380280	378919	19713W	PARTICIPANT	\N	PRESENT	0
380281	378919	14031R	PARTICIPANT	\N	PRESENT	0
380282	378919	08055A	PARTICIPANT	\N	PRESENT	0
380283	378919	14191V	PARTICIPANT	\N	PRESENT	0
380284	378919	14169X	PARTICIPANT	\N	PRESENT	0
380285	378919	15447F	PARTICIPANT	\N	PRESENT	0
380286	378919	14093U	PARTICIPANT	\N	PRESENT	0
380287	378919	14029X	PARTICIPANT	\N	PRESENT	0
380288	378919	19733B	PARTICIPANT	\N	PRESENT	0
380289	378919	08009T	PRESIDENT	0	PRESENT	0
380290	378919	19737F	PARTICIPANT	\N	PRESENT	0
380291	378919	19739H	PARTICIPANT	\N	PRESENT	0
380292	378919	04097T	PARTICIPANT	\N	PRESENT	0
380293	378919	19745F	PARTICIPANT	\N	PRESENT	0
380294	378919	19659J	PARTICIPANT	\N	PRESENT	0
380295	378919	19685L	PARTICIPANT	\N	EXCUSE	0
380302	380301	11074Q	PARTICIPANT	\N	PRESENT	0
380303	380301	11048N	PARTICIPANT	\N	PRESENT	0
380304	380301	08011M	PARTICIPANT	\N	PRESENT	0
380324	378921	11070L	PARTICIPANT	\N	PRESENT	0
380325	378921	14083S	PARTICIPANT	\N	PRESENT	0
380326	378921	14225N	PARTICIPANT	\N	PRESENT	0
380327	378921	07004J	PARTICIPANT	\N	PRESENT	0
380328	378921	08010L	PARTICIPANT	\N	PRESENT	0
380329	378921	19479G	PARTICIPANT	\N	PRESENT	0
380330	378921	14034U	PARTICIPANT	\N	PRESENT	0
380331	378921	01048V	PARTICIPANT	\N	PRESENT	0
380332	380297	86034E	PARTICIPANT	\N	PRESENT	0
380336	380297	14235Q	PARTICIPANT	\N	PRESENT	0
380337	380297	11033F	PARTICIPANT	\N	PRESENT	0
380338	380297	04085P	PARTICIPANT	\N	PRESENT	0
380339	380297	11040E	PARTICIPANT	\N	PRESENT	0
380340	380297	04038G	PARTICIPANT	\N	PRESENT	0
380341	380297	12041X	PARTICIPANT	\N	PRESENT	0
380342	380297	19695N	PARTICIPANT	\N	PRESENT	0
380343	380297	19758L	PARTICIPANT	\N	PRESENT	0
380344	380297	19593H	PARTICIPANT	\N	PRESENT	0
380345	380297	95063L	PARTICIPANT	\N	PRESENT	0
380346	380297	95037J	PARTICIPANT	\N	PRESENT	0
380347	380297	04045F	PARTICIPANT	\N	PRESENT	0
380348	380297	98029W	PARTICIPANT	\N	PRESENT	0
380349	380297	19651A	PARTICIPANT	\N	PRESENT	0
380350	380297	11083R	PARTICIPANT	\N	PRESENT	0
380351	380297	19637C	PARTICIPANT	\N	PRESENT	0
380352	380297	19697Q	PARTICIPANT	\N	PRESENT	0
380353	380297	14039A	PARTICIPANT	\N	PRESENT	0
380354	380297	19659J	PARTICIPANT	\N	PRESENT	0
380355	380297	19782L	PARTICIPANT	\N	PRESENT	0
380356	380297	08024S	PARTICIPANT	\N	PRESENT	0
380357	380297	89017R	PARTICIPANT	\N	PRESENT	0
380358	380297	11012A	PARTICIPANT	\N	PRESENT	0
380359	380297	08031R	PARTICIPANT	\N	PRESENT	0
380360	380297	08049C	PARTICIPANT	\N	PRESENT	0
380361	380297	88008L	PARTICIPANT	\N	PRESENT	0
380365	380297	11072N	PARTICIPANT	\N	PRESENT	0
380363	380297	19301E	PARTICIPANT	\N	PRESENT	0
380364	380297	19711U	PARTICIPANT	\N	PRESENT	0
380366	380297	04008A	PARTICIPANT	\N	PRESENT	0
380367	380297	19349W	PARTICIPANT	\N	PRESENT	0
380368	380297	11101A	PARTICIPANT	\N	PRESENT	0
380369	380297	98024R	PARTICIPANT	\N	PRESENT	0
380370	380297	14261S	PARTICIPANT	\N	PRESENT	0
380371	380297	19629C	PARTICIPANT	\N	PRESENT	0
380372	380297	14201E	PARTICIPANT	\N	PRESENT	0
380373	380297	14107H	PARTICIPANT	\N	PRESENT	0
380374	380297	14207L	PARTICIPANT	\N	PRESENT	0
380375	380297	14241N	PARTICIPANT	\N	PRESENT	0
380376	380297	19543W	PARTICIPANT	\N	PRESENT	0
380377	380297	11099A	PARTICIPANT	\N	PRESENT	0
380378	380297	19717B	PARTICIPANT	\N	PRESENT	0
380379	380297	19719D	PARTICIPANT	\N	PRESENT	0
380380	380297	99004R	PARTICIPANT	\N	PRESENT	0
380381	380297	19563B	PARTICIPANT	\N	PRESENT	0
380382	380297	01058X	PARTICIPANT	\N	PRESENT	0
380383	380297	04057K	PARTICIPANT	\N	PRESENT	0
380384	380297	96004D	PARTICIPANT	\N	PRESENT	0
380385	380297	14157T	PARTICIPANT	\N	PRESENT	0
380386	380297	19681G	PARTICIPANT	\N	PRESENT	0
380387	380297	19585H	PARTICIPANT	\N	PRESENT	0
380388	380297	14111D	PARTICIPANT	\N	PRESENT	0
380389	380297	98005N	PARTICIPANT	\N	PRESENT	0
380390	380297	08073C	PARTICIPANT	\N	PRESENT	0
380391	380297	08011M	PARTICIPANT	\N	PRESENT	0
380392	380297	08039A	PARTICIPANT	\N	PRESENT	0
380393	380297	14195A	PARTICIPANT	\N	PRESENT	0
380394	380297	08020N	PARTICIPANT	\N	PRESENT	0
380395	380297	08061X	PARTICIPANT	\N	PRESENT	0
380396	380297	08069G	PARTICIPANT	\N	PRESENT	0
380397	380297	14123H	PARTICIPANT	\N	PRESENT	0
380398	380297	01048V	PARTICIPANT	\N	PRESENT	0
380399	380297	11043H	PARTICIPANT	\N	PRESENT	0
380400	380297	10015M	PARTICIPANT	\N	PRESENT	0
380401	380297	19545Y	PARTICIPANT	\N	PRESENT	0
380402	380297	08010L	PARTICIPANT	\N	PRESENT	0
380403	380297	04059M	PARTICIPANT	\N	PRESENT	0
380404	380297	11074Q	PARTICIPANT	\N	PRESENT	0
380405	380297	19643A	PARTICIPANT	\N	PRESENT	0
380406	380297	14159V	PARTICIPANT	\N	PRESENT	0
380407	380297	15447F	PARTICIPANT	\N	PRESENT	0
380408	380297	98035U	PARTICIPANT	\N	PRESENT	0
362934	361271	11080N	PARTICIPANT	\N	EXCUSE	0
364576	364573	11083R	PARTICIPANT	\N	PRESENT	0
364574	364572	11083R	PARTICIPANT	\N	PRESENT	0
364575	364572	14331P	PARTICIPANT	\N	PRESENT	0
364577	364573	14331P	PARTICIPANT	\N	PRESENT	0
373753	373752	14261S	PARTICIPANT	\N	PRESENT	0
373754	373752	08031R	PARTICIPANT	\N	PRESENT	0
373755	373752	19629C	PARTICIPANT	\N	PRESENT	0
373756	373752	11027H	PARTICIPANT	\N	PRESENT	0
373757	373752	14241N	PARTICIPANT	\N	PRESENT	0
373758	373752	14135M	PARTICIPANT	\N	PRESENT	0
373759	373752	95067Q	PARTICIPANT	\N	PRESENT	0
375053	375051	04092N	PARTICIPANT	\N	PRESENT	0
375054	375052	04092N	PARTICIPANT	\N	PRESENT	0
375056	375055	14193X	PARTICIPANT	\N	PRESENT	0
375154	367788	19663E	PARTICIPANT	\N	PRESENT	0
375156	367788	14221J	PARTICIPANT	\N	PRESENT	0
375157	367788	19593H	PARTICIPANT	\N	PRESENT	0
375158	367788	19503N	PARTICIPANT	\N	PRESENT	0
375160	367788	19693L	PARTICIPANT	\N	EXCUSE	0
375161	367788	08053X	PARTICIPANT	\N	EXCUSE	0
375165	367788	14299H	PARTICIPANT	\N	EXCUSE	0
375444	375443	19611R	PARTICIPANT	\N	PRESENT	0
375445	375443	19533U	PARTICIPANT	\N	PRESENT	0
375548	375546	19794Q	PARTICIPANT	\N	PRESENT	0
375549	375546	14157T	PARTICIPANT	\N	PRESENT	0
375550	375546	14219Q	PARTICIPANT	\N	PRESENT	0
375557	375556	14219Q	PARTICIPANT	\N	PRESENT	0
375558	375556	19794Q	PARTICIPANT	\N	PRESENT	0
375559	375556	14157T	PARTICIPANT	\N	PRESENT	0
375562	375560	14219Q	PARTICIPANT	\N	PRESENT	0
375563	375560	19794Q	PARTICIPANT	\N	PRESENT	0
375564	375560	14157T	PARTICIPANT	\N	PRESENT	0
375738	375460	04059M	PARTICIPANT	\N	EXCUSE	0
375568	375566	19794Q	PARTICIPANT	\N	PRESENT	0
375569	375566	14157T	PARTICIPANT	\N	PRESENT	0
376560	376559	19705W	PARTICIPANT	\N	PRESENT	0
376561	376559	19515S	PARTICIPANT	\N	PRESENT	0
376562	376559	08062Y	PARTICIPANT	\N	PRESENT	0
376563	376559	08068F	PARTICIPANT	\N	PRESENT	0
376564	376559	19413M	PARTICIPANT	\N	PRESENT	0
376565	376559	19269X	PARTICIPANT	\N	PRESENT	0
376587	376584	08028W	PARTICIPANT	\N	PRESENT	0
376591	376584	19569H	PARTICIPANT	\N	PRESENT	0
376653	376652	14030Q	PRESIDENT	0	PRESENT	0
376654	376652	19643A	PARTICIPANT	\N	PRESENT	0
376655	376652	08024S	PARTICIPANT	\N	PRESENT	0
376656	376652	19701S	PARTICIPANT	\N	PRESENT	0
376657	376652	19715Y	PARTICIPANT	\N	PRESENT	0
376658	376652	08043V	PARTICIPANT	\N	EXCUSE	0
376659	376652	19693L	PARTICIPANT	\N	EXCUSE	0
376660	376652	14249W	PARTICIPANT	\N	EXCUSE	0
376661	376652	07029T	PARTICIPANT	\N	EXCUSE	0
376662	376652	01043Q	PARTICIPANT	\N	EXCUSE	0
376663	376652	11067R	PARTICIPANT	\N	EXCUSE	0
376664	376652	14235Q	PARTICIPANT	\N	EXCUSE	0
376665	376652	11043H	PARTICIPANT	\N	PRESENT	0
377059	373666	01028R	PARTICIPANT	\N	EXCUSE	0
377083	373666	08012N	PARTICIPANT	\N	PRESENT	0
377295	373666	89017R	PARTICIPANT	\N	EXCUSE	0
377309	373666	04038G	PARTICIPANT	\N	EXCUSE	0
377421	377420	04033B	PARTICIPANT	\N	PRESENT	0
377422	377420	14041T	PARTICIPANT	\N	PRESENT	0
377423	377420	14105F	PARTICIPANT	\N	PRESENT	0
377424	377420	04097T	PARTICIPANT	\N	PRESENT	0
377425	377420	87003B	PARTICIPANT	\N	PRESENT	0
377426	377420	04044E	PARTICIPANT	\N	PRESENT	0
377427	377420	14097Y	PARTICIPANT	\N	PRESENT	0
377428	377420	19545Y	PARTICIPANT	\N	PRESENT	0
377429	377420	14237S	PARTICIPANT	\N	PRESENT	0
377430	377420	95067Q	PARTICIPANT	\N	PRESENT	0
377431	377420	14115H	PARTICIPANT	\N	PRESENT	0
377435	377420	08058D	PARTICIPANT	\N	PRESENT	0
377433	377420	14265W	PARTICIPANT	\N	PRESENT	0
377434	377420	14215L	PARTICIPANT	\N	PRESENT	0
377436	377420	19647E	PARTICIPANT	\N	PRESENT	0
377437	377420	11048N	PARTICIPANT	\N	PRESENT	0
377438	377420	08048B	PARTICIPANT	\N	PRESENT	0
377439	377420	04049K	PARTICIPANT	\N	PRESENT	0
377440	377420	19611R	PARTICIPANT	\N	PRESENT	0
377441	377420	01058X	PARTICIPANT	\N	PRESENT	0
378153	376740	04035D	PARTICIPANT	\N	EXCUSE	0
378154	376740	14028W	PARTICIPANT	\N	EXCUSE	0
378155	376741	04035D	PARTICIPANT	\N	EXCUSE	0
378156	376741	14028W	PARTICIPANT	\N	EXCUSE	0
382701	382700	14021P	PARTICIPANT	\N	PRESENT	0
382702	382700	14179A	PARTICIPANT	\N	PRESENT	0
382703	382700	04044E	PARTICIPANT	\N	PRESENT	0
382714	382713	19563B	PRESIDENT	0	PRESENT	0
382715	382713	08068F	PARTICIPANT	\N	PRESENT	0
382716	382713	19695N	PARTICIPANT	\N	PRESENT	0
382717	382713	07029T	PARTICIPANT	\N	PRESENT	0
382718	382713	19711U	PARTICIPANT	\N	PRESENT	0
382719	382713	01043Q	PARTICIPANT	\N	PRESENT	0
382720	382713	14265W	PARTICIPANT	\N	PRESENT	0
382721	382713	14237S	PARTICIPANT	\N	PRESENT	0
382722	382713	19503N	PARTICIPANT	\N	PRESENT	0
382723	382713	19713W	PARTICIPANT	\N	PRESENT	0
382724	382713	19413M	PARTICIPANT	\N	PRESENT	0
382725	382713	95067Q	PARTICIPANT	\N	PRESENT	0
382726	382713	19782L	PARTICIPANT	\N	EXCUSE	0
382727	382713	19599P	PARTICIPANT	\N	EXCUSE	0
382728	382713	14073Q	PARTICIPANT	\N	EXCUSE	0
382729	382713	04049K	PARTICIPANT	\N	EXCUSE	0
384450	371543	88008L	PARTICIPANT	\N	PRESENT	0
384451	371543	19629C	PARTICIPANT	\N	PRESENT	0
384452	371543	19415P	PARTICIPANT	\N	PRESENT	0
384453	371543	07004J	PARTICIPANT	\N	PRESENT	0
384454	371543	11040E	PARTICIPANT	\N	PRESENT	0
384455	371543	11012A	PARTICIPANT	\N	PRESENT	0
384456	371543	11074Q	PARTICIPANT	\N	PRESENT	0
384457	371543	19333N	PARTICIPANT	\N	PRESENT	0
384458	371543	14026U	PARTICIPANT	\N	PRESENT	0
384459	371543	19467C	PARTICIPANT	\N	PRESENT	0
384460	371543	19711U	PARTICIPANT	\N	PRESENT	0
384461	371543	19667J	PARTICIPANT	\N	PRESENT	0
384462	371543	19399H	PARTICIPANT	\N	PRESENT	0
384463	371543	19687N	PARTICIPANT	\N	PRESENT	0
384464	371543	07029T	PARTICIPANT	\N	PRESENT	0
384465	371543	19689Q	PARTICIPANT	\N	PRESENT	0
384466	371543	08073C	PARTICIPANT	\N	PRESENT	0
384467	371543	96004D	PARTICIPANT	\N	PRESENT	0
384468	371543	19545Y	PARTICIPANT	\N	PRESENT	0
384469	371543	14107H	PARTICIPANT	\N	PRESENT	0
384470	371543	01057W	PARTICIPANT	\N	PRESENT	0
384471	371543	11048N	PARTICIPANT	\N	PRESENT	0
384472	371543	14331P	PARTICIPANT	\N	PRESENT	0
384473	371543	19479G	PARTICIPANT	\N	PRESENT	0
384474	371543	14083S	PARTICIPANT	\N	PRESENT	0
384475	371543	19681G	PARTICIPANT	\N	PRESENT	0
384476	371543	14034U	PARTICIPANT	\N	PRESENT	0
384477	371543	19747H	PARTICIPANT	\N	PRESENT	0
384478	371543	18083K	PARTICIPANT	\N	PRESENT	0
384479	371543	01024M	PARTICIPANT	\N	PRESENT	0
384480	371543	14251Q	PARTICIPANT	\N	PRESENT	0
384481	371543	19543W	PARTICIPANT	\N	PRESENT	0
384482	371543	97011G	PARTICIPANT	\N	PRESENT	0
384483	371543	19521Q	PARTICIPANT	\N	PRESENT	0
384484	371543	19671E	PARTICIPANT	\N	PRESENT	0
384503	371543	19387D	PARTICIPANT	\N	PRESENT	0
384504	371543	19719D	PARTICIPANT	\N	PRESENT	0
384505	371543	14197C	PARTICIPANT	\N	PRESENT	0
384506	371543	19551W	PARTICIPANT	\N	PRESENT	0
384507	371543	11097X	PARTICIPANT	\N	PRESENT	0
384508	371543	14033T	PARTICIPANT	\N	PRESENT	0
384509	371543	19794Q	PARTICIPANT	\N	PRESENT	0
384510	371543	19701S	PARTICIPANT	\N	PRESENT	0
384511	382857	19549D	PARTICIPANT	\N	EXCUSE	0
384512	382857	14079W	PARTICIPANT	\N	PRESENT	0
384513	382857	14087W	PARTICIPANT	\N	PRESENT	0
384514	382857	19347U	PARTICIPANT	\N	PRESENT	0
384515	382857	14081Q	PARTICIPANT	\N	PRESENT	0
384516	382857	19569H	PARTICIPANT	\N	PRESENT	0
384517	382857	19551W	PARTICIPANT	\N	PRESENT	0
384518	382857	14241N	PARTICIPANT	\N	PRESENT	0
384519	382857	14031R	PARTICIPANT	\N	PRESENT	0
384520	382857	19637C	PARTICIPANT	\N	PRESENT	0
384521	382857	19794Q	PARTICIPANT	\N	PRESENT	0
384522	382857	19689Q	PARTICIPANT	\N	PRESENT	0
384523	382857	19737F	PARTICIPANT	\N	PRESENT	0
384524	382857	19585H	PARTICIPANT	\N	PRESENT	0
385067	385066	14033T	PARTICIPANT	\N	PRESENT	0
390136	388106	08055A	PARTICIPANT	\N	PRESENT	0
390137	388106	01028R	PARTICIPANT	\N	PRESENT	0
390138	388106	14021P	PARTICIPANT	\N	PRESENT	0
390139	388106	19599P	PARTICIPANT	\N	PRESENT	0
390140	388106	08038Y	PARTICIPANT	\N	PRESENT	0
390141	388106	08060W	PARTICIPANT	\N	PRESENT	0
390142	388106	80013X	PARTICIPANT	\N	PRESENT	0
390143	388106	19727D	PARTICIPANT	\N	PRESENT	0
390144	388106	14001X	PARTICIPANT	\N	PRESENT	0
390145	388106	19591F	PARTICIPANT	\N	PRESENT	0
390146	388106	08052W	PARTICIPANT	\N	PRESENT	0
390147	388106	19715Y	PARTICIPANT	\N	PRESENT	0
390148	388106	14151M	PARTICIPANT	\N	PRESENT	0
390149	388106	01062T	PARTICIPANT	\N	PRESENT	0
390150	388106	08043V	PARTICIPANT	\N	PRESENT	0
390151	388106	14251Q	PARTICIPANT	\N	PRESENT	0
390152	388106	11104D	PARTICIPANT	\N	PRESENT	0
390153	388106	08053X	PARTICIPANT	\N	PRESENT	0
390154	388106	08012N	PARTICIPANT	\N	PRESENT	0
390155	388106	14081Q	PARTICIPANT	\N	PRESENT	0
390156	388106	11110B	PARTICIPANT	\N	PRESENT	0
390157	388106	08058D	PARTICIPANT	\N	PRESENT	0
390158	388106	19549D	PARTICIPANT	\N	PRESENT	0
390159	388106	11045K	PARTICIPANT	\N	PRESENT	0
390160	388106	19631V	PARTICIPANT	\N	PRESENT	0
390161	388106	19551W	PARTICIPANT	\N	PRESENT	0
390162	388106	11067R	PARTICIPANT	\N	PRESENT	0
390163	388106	11109J	PARTICIPANT	\N	PRESENT	0
390164	388106	19593H	PARTICIPANT	\N	PRESENT	0
390165	388106	19687N	PARTICIPANT	\N	PRESENT	0
390166	388106	08035V	PARTICIPANT	\N	PRESENT	0
390167	388106	14275Y	PARTICIPANT	\N	PRESENT	0
390168	388106	19413M	PARTICIPANT	\N	PRESENT	0
390169	388106	14097Y	PARTICIPANT	\N	PRESENT	0
390170	388106	95063L	PARTICIPANT	\N	PRESENT	0
390171	388106	11012A	PARTICIPANT	\N	PRESENT	0
390172	388106	19553Y	PARTICIPANT	\N	PRESENT	0
390173	388106	14239U	PARTICIPANT	\N	PRESENT	0
390607	377979	11064N	PARTICIPANT	\N	PRESENT	0
390608	377979	19503N	PARTICIPANT	\N	PRESENT	0
390609	377979	14073Q	PARTICIPANT	\N	PRESENT	0
390610	377979	08024S	PARTICIPANT	\N	PRESENT	0
390611	377979	11031D	PARTICIPANT	\N	PRESENT	0
390612	377979	08045X	PARTICIPANT	\N	PRESENT	0
390613	377979	19629C	PARTICIPANT	\N	PRESENT	0
390614	377979	14133K	PARTICIPANT	\N	PRESENT	0
390615	377979	19563B	PARTICIPANT	\N	PRESENT	0
390616	385093	14327T	PARTICIPANT	\N	PRESENT	0
390617	385093	19441R	PARTICIPANT	\N	PRESENT	0
390618	385093	14001X	PARTICIPANT	\N	PRESENT	0
390619	385093	14030Q	PARTICIPANT	\N	PRESENT	0
390620	377979	01028R	PARTICIPANT	\N	PRESENT	0
390621	377979	14211G	PARTICIPANT	\N	PRESENT	0
390622	377979	19549D	PARTICIPANT	\N	PRESENT	0
390623	377979	19413M	PARTICIPANT	\N	PRESENT	0
390627	377979	19387D	PARTICIPANT	\N	PRESENT	0
390625	377979	19545Y	PARTICIPANT	\N	PRESENT	0
390626	377979	14103D	PARTICIPANT	\N	PRESENT	0
390628	377979	08010L	PARTICIPANT	\N	PRESENT	0
390629	377979	10015M	PARTICIPANT	\N	PRESENT	0
390630	377979	14223L	PARTICIPANT	\N	PRESENT	0
390631	377979	19747H	PARTICIPANT	\N	PRESENT	0
390632	377979	14119M	PARTICIPANT	\N	PRESENT	0
390633	377979	19725B	PARTICIPANT	\N	PRESENT	0
390634	377979	98022P	PARTICIPANT	\N	PRESENT	0
390635	377979	19715Y	PARTICIPANT	\N	PRESENT	0
390636	377979	19798U	PARTICIPANT	\N	PRESENT	0
390637	377979	19762G	PARTICIPANT	\N	PRESENT	0
390638	377979	11048N	PARTICIPANT	\N	PRESENT	0
390639	377979	14157T	PARTICIPANT	\N	PRESENT	0
390640	377979	14031R	PARTICIPANT	\N	PRESENT	0
390641	377979	19794Q	PARTICIPANT	\N	PRESENT	0
390642	377979	19515S	PARTICIPANT	\N	PRESENT	0
390643	377979	19443T	PARTICIPANT	\N	PRESENT	0
390644	377979	14069U	PARTICIPANT	\N	PRESENT	0
390645	377979	08020N	PARTICIPANT	\N	PRESENT	0
390646	377979	19383Y	PARTICIPANT	\N	PRESENT	0
390647	377979	14115H	PARTICIPANT	\N	PRESENT	0
390648	377979	19621T	PARTICIPANT	\N	PRESENT	0
390649	377979	14237S	PARTICIPANT	\N	PRESENT	0
390650	377979	14357A	PARTICIPANT	\N	PRESENT	0
390651	377979	19711U	PARTICIPANT	\N	PRESENT	0
390652	377979	14329V	PARTICIPANT	\N	PRESENT	0
390653	377979	14111D	PARTICIPANT	\N	PRESENT	0
390654	377979	05008E	PARTICIPANT	\N	PRESENT	0
390655	377979	14087W	PARTICIPANT	\N	PRESENT	0
390656	377979	19369B	PARTICIPANT	\N	PRESENT	0
390657	377979	19441R	PARTICIPANT	\N	PRESENT	0
390658	377979	19713W	PARTICIPANT	\N	PRESENT	0
390659	377979	14265W	PARTICIPANT	\N	PRESENT	0
390660	377979	14249W	PARTICIPANT	\N	PRESENT	0
390661	377979	14213J	PARTICIPANT	\N	PRESENT	0
390662	377979	14215L	PARTICIPANT	\N	PRESENT	0
390663	377979	11012A	PARTICIPANT	\N	PRESENT	0
390664	377979	04088S	PARTICIPANT	\N	PRESENT	0
390665	377979	18083K	PARTICIPANT	\N	PRESENT	0
390666	377979	08034U	PARTICIPANT	\N	PRESENT	0
390667	377979	14217N	PARTICIPANT	\N	PRESENT	0
390668	377979	11067R	PARTICIPANT	\N	PRESENT	0
390669	377979	14231L	PARTICIPANT	\N	PRESENT	0
390670	377979	12041X	PARTICIPANT	\N	PRESENT	0
390671	377979	19347U	PARTICIPANT	\N	PRESENT	0
390672	377979	11033F	PARTICIPANT	\N	PRESENT	0
390673	377979	19701S	PARTICIPANT	\N	PRESENT	0
390674	377979	11090Q	PARTICIPANT	\N	PRESENT	0
390675	377979	19521Q	PARTICIPANT	\N	PRESENT	0
390676	377979	14241N	PARTICIPANT	\N	PRESENT	0
390677	377979	08031R	PARTICIPANT	\N	PRESENT	0
390678	377979	01057W	PARTICIPANT	\N	PRESENT	0
390679	377979	11097X	PARTICIPANT	\N	PRESENT	0
390680	377979	14331P	PARTICIPANT	\N	PRESENT	0
390681	377979	19709B	PARTICIPANT	\N	PRESENT	0
390682	377979	19637C	PARTICIPANT	\N	PRESENT	0
390683	377979	14135M	PARTICIPANT	\N	PRESENT	0
390684	377979	19447X	PARTICIPANT	\N	PRESENT	0
390685	377979	11083R	PARTICIPANT	\N	PRESENT	0
390686	377979	14001X	PARTICIPANT	\N	PRESENT	0
390687	377979	14159V	PARTICIPANT	\N	PRESENT	0
390688	377979	14097Y	PARTICIPANT	\N	PRESENT	0
390689	377979	19253P	PARTICIPANT	\N	PRESENT	0
390690	377979	19631V	PARTICIPANT	\N	PRESENT	0
390691	377979	14071N	PARTICIPANT	\N	PRESENT	0
390707	388119	86034E	PARTICIPANT	\N	PRESENT	0
390708	388119	19721W	PARTICIPANT	\N	PRESENT	0
390709	388119	04085P	PARTICIPANT	\N	PRESENT	0
390710	388119	11033F	PARTICIPANT	\N	PRESENT	0
390711	388119	12041X	PARTICIPANT	\N	PRESENT	0
390712	388119	11040E	PARTICIPANT	\N	PRESENT	0
390713	388119	19593H	PARTICIPANT	\N	PRESENT	0
390714	388119	19347U	PARTICIPANT	\N	PRESENT	0
390715	388119	95063L	PARTICIPANT	\N	PRESENT	0
390716	388119	08061X	PARTICIPANT	\N	PRESENT	0
390717	388119	95037J	PARTICIPANT	\N	PRESENT	0
390718	388119	19758L	PARTICIPANT	\N	PRESENT	0
390719	388119	14211G	PARTICIPANT	\N	PRESENT	0
390720	388119	19711U	PARTICIPANT	\N	PRESENT	0
390721	388119	08011M	PARTICIPANT	\N	PRESENT	0
390722	388119	04045F	PARTICIPANT	\N	PRESENT	0
390723	388119	04034C	PARTICIPANT	\N	PRESENT	0
390724	388119	14157T	PARTICIPANT	\N	PRESENT	0
390725	388119	14239U	PARTICIPANT	\N	PRESENT	0
390726	388119	96004D	PARTICIPANT	\N	PRESENT	0
390727	388119	19651A	PARTICIPANT	\N	PRESENT	0
390728	388119	19349W	PARTICIPANT	\N	PRESENT	0
390729	388119	99004R	PARTICIPANT	\N	PRESENT	0
390730	388119	08024S	PARTICIPANT	\N	PRESENT	0
390731	388119	19782L	PARTICIPANT	\N	PRESENT	0
390732	388119	04097T	PARTICIPANT	\N	PRESENT	0
390733	388119	11072N	PARTICIPANT	\N	PRESENT	0
390734	388119	08039A	PARTICIPANT	\N	PRESENT	0
390735	388119	08020N	PARTICIPANT	\N	PRESENT	0
390737	388119	04061F	PARTICIPANT	\N	PRESENT	0
390738	388119	08010L	PARTICIPANT	\N	PRESENT	0
390739	388119	11012A	PARTICIPANT	\N	PRESENT	0
390740	388119	14123H	PARTICIPANT	\N	PRESENT	0
390741	388119	14034U	PARTICIPANT	\N	PRESENT	0
390742	388119	08069G	PARTICIPANT	\N	PRESENT	0
390743	388119	08031R	PARTICIPANT	\N	PRESENT	0
390744	388119	04071H	PARTICIPANT	\N	PRESENT	0
390745	388119	19629C	PARTICIPANT	\N	PRESENT	0
390746	388119	19253P	PARTICIPANT	\N	PRESENT	0
390747	388119	19643A	PARTICIPANT	\N	PRESENT	0
390748	388119	14207L	PARTICIPANT	\N	PRESENT	0
390749	388119	14201E	PARTICIPANT	\N	PRESENT	0
390750	388119	10015M	PARTICIPANT	\N	PRESENT	0
390751	388119	19697Q	PARTICIPANT	\N	PRESENT	0
364438	364436	08011M	PARTICIPANT	\N	PRESENT	0
364440	364439	11048N	PARTICIPANT	\N	PRESENT	0
364442	364441	19647E	PARTICIPANT	\N	PRESENT	0
364443	364441	11070L	PARTICIPANT	\N	PRESENT	0
364445	364444	08010L	PARTICIPANT	\N	PRESENT	0
364447	364446	08010L	PARTICIPANT	\N	PRESENT	0
364449	364448	08010L	PARTICIPANT	\N	PRESENT	0
364452	364451	19531S	PARTICIPANT	\N	PRESENT	0
369083	356297	11066Q	PARTICIPANT	\N	PRESENT	0
369084	356297	14021P	PARTICIPANT	\N	PRESENT	0
369085	356297	98022P	PARTICIPANT	\N	PRESENT	0
369087	356297	19503N	PARTICIPANT	\N	PRESENT	0
369088	356297	14241N	PARTICIPANT	\N	PRESENT	0
369091	367354	14065Q	PARTICIPANT	\N	PRESENT	0
369092	367354	19649G	PARTICIPANT	\N	PRESENT	0
369093	367354	19253P	PARTICIPANT	\N	PRESENT	0
369094	367354	01024M	PARTICIPANT	\N	PRESENT	0
369095	367354	04044E	PARTICIPANT	\N	PRESENT	0
369096	367354	19581D	PARTICIPANT	\N	PRESENT	0
369097	367354	08014Q	PARTICIPANT	\N	PRESENT	0
369098	367354	04047H	PRESIDENT	1	PRESENT	0
369099	367354	19673G	PARTICIPANT	\N	PRESENT	0
369100	367354	01028R	PARTICIPANT	\N	PRESENT	0
369101	367354	05008E	PRESIDENT	0	PRESENT	0
369102	367354	19725B	PARTICIPANT	\N	PRESENT	0
369103	367354	14041T	PARTICIPANT	\N	PRESENT	0
369104	367354	08044W	PARTICIPANT	\N	PRESENT	0
369105	367354	14215L	PARTICIPANT	\N	PRESENT	0
369106	367354	14053L	PARTICIPANT	\N	PRESENT	0
369107	367354	14147R	PARTICIPANT	\N	PRESENT	0
369108	367354	14179A	PARTICIPANT	\N	PRESENT	0
369109	367354	14069U	PARTICIPANT	\N	PRESENT	0
369110	367354	14151M	PARTICIPANT	\N	PRESENT	0
369111	367354	11066Q	PARTICIPANT	\N	PRESENT	0
369112	367354	19447X	PARTICIPANT	\N	PRESENT	0
369113	367354	19762G	PARTICIPANT	\N	PRESENT	0
369114	367354	19729F	PARTICIPANT	\N	EXCUSE	0
369115	367354	08018U	PARTICIPANT	\N	EXCUSE	0
369116	356297	14063N	PARTICIPANT	\N	PRESENT	0
369117	356297	19725B	PARTICIPANT	\N	PRESENT	0
369118	356297	19762G	PARTICIPANT	\N	PRESENT	0
369119	356297	11103C	PARTICIPANT	\N	PRESENT	0
369120	356297	99004R	PARTICIPANT	\N	PRESENT	0
369122	356297	19713W	PARTICIPANT	\N	PRESENT	0
369123	356297	19553Y	PARTICIPANT	\N	PRESENT	0
369124	356297	19349W	PARTICIPANT	\N	PRESENT	0
369125	356297	19611R	PARTICIPANT	\N	PRESENT	0
369126	356297	19768N	PARTICIPANT	\N	PRESENT	0
369127	356297	14197C	PARTICIPANT	\N	PRESENT	0
369129	356297	08014Q	PARTICIPANT	\N	PRESENT	0
369132	356297	14219Q	PARTICIPANT	\N	PRESENT	0
369136	356297	14030Q	PARTICIPANT	\N	PRESENT	0
369137	356297	01024M	PARTICIPANT	\N	PRESENT	0
369138	356297	11077T	PARTICIPANT	\N	PRESENT	0
369139	356297	19683J	PARTICIPANT	\N	PRESENT	0
369140	356297	19563B	PARTICIPANT	\N	PRESENT	0
369141	356297	14199E	PARTICIPANT	\N	PRESENT	0
369142	356297	08010L	PARTICIPANT	\N	PRESENT	0
369143	356297	19659J	PARTICIPANT	\N	PRESENT	0
369144	356297	19369B	PARTICIPANT	\N	PRESENT	0
369145	356297	08020N	PARTICIPANT	\N	PRESENT	0
369146	356297	95062K	PARTICIPANT	\N	PRESENT	0
369147	356297	14249W	PARTICIPANT	\N	PRESENT	0
369148	356297	14061L	PARTICIPANT	\N	PRESENT	0
369149	356297	01028R	PARTICIPANT	\N	PRESENT	0
369159	356297	01057W	PARTICIPANT	\N	PRESENT	0
369162	356297	14026U	PARTICIPANT	\N	PRESENT	0
369163	356297	14133K	PARTICIPANT	\N	PRESENT	0
369164	356297	19253P	PARTICIPANT	\N	PRESENT	0
369165	356297	19545Y	PARTICIPANT	\N	PRESENT	0
369166	356297	11027H	PARTICIPANT	\N	PRESENT	0
369167	356297	14065Q	PARTICIPANT	\N	PRESENT	0
369168	356297	08061X	PARTICIPANT	\N	PRESENT	0
369228	366781	01034P	PARTICIPANT	\N	PRESENT	0
369230	366781	19565D	PARTICIPANT	\N	PRESENT	0
369231	366781	19798U	PARTICIPANT	\N	PRESENT	0
369232	366781	08052W	PARTICIPANT	\N	PRESENT	0
369233	366781	19663E	PARTICIPANT	\N	PRESENT	0
369234	366781	14026U	PARTICIPANT	\N	PRESENT	0
369235	366781	11031D	PARTICIPANT	\N	PRESENT	0
369236	366781	19727D	PARTICIPANT	\N	PRESENT	0
369237	366781	19679N	PARTICIPANT	\N	PRESENT	0
369238	366781	14042U	PARTICIPANT	\N	PRESENT	0
369239	366781	19575F	PARTICIPANT	\N	PRESENT	0
369240	366781	14213J	PARTICIPANT	\N	PRESENT	0
369241	366781	14217N	PARTICIPANT	\N	PRESENT	0
369242	366781	19760E	PARTICIPANT	\N	PRESENT	0
369243	366781	98024R	PARTICIPANT	\N	PRESENT	0
369251	366781	04092N	PARTICIPANT	\N	PRESENT	0
369252	366781	19715Y	PARTICIPANT	\N	EXCUSE	0
369253	366781	08041T	PARTICIPANT	\N	EXCUSE	0
369257	356297	14121F	PARTICIPANT	\N	PRESENT	0
369259	366781	19657G	PARTICIPANT	\N	PRESENT	0
369260	366781	19577H	PARTICIPANT	\N	PRESENT	0
369273	356297	07029T	PARTICIPANT	\N	PRESENT	0
369276	356297	11083R	PARTICIPANT	\N	PRESENT	0
369282	356297	19747H	PARTICIPANT	\N	PRESENT	0
370767	365231	11056N	PARTICIPANT	\N	EXCUSE	0
370778	365231	08012N	PARTICIPANT	\N	EXCUSE	0
371213	370852	01028R	PARTICIPANT	\N	PRESENT	0
372659	356314	11072N	PARTICIPANT	\N	PRESENT	0
372662	356314	08009T	PARTICIPANT	\N	PRESENT	0
372663	356314	14329V	PARTICIPANT	\N	PRESENT	0
372664	356314	14103D	PARTICIPANT	\N	PRESENT	0
372665	356314	19543W	PARTICIPANT	\N	PRESENT	0
372666	356314	14207L	PARTICIPANT	\N	PRESENT	0
372667	356314	19503N	PARTICIPANT	\N	PRESENT	0
372668	356314	19333N	PARTICIPANT	\N	PRESENT	0
372669	356314	11065P	PARTICIPANT	\N	PRESENT	0
372670	356314	19387D	PARTICIPANT	\N	PRESENT	0
372671	356314	14093U	PARTICIPANT	\N	PRESENT	0
372672	356314	14107H	PARTICIPANT	\N	PRESENT	0
372673	356314	19681G	PARTICIPANT	\N	PRESENT	0
372674	356314	04089T	PARTICIPANT	\N	PRESENT	0
372675	356314	19739H	PARTICIPANT	\N	PRESENT	0
372676	356314	19737F	PARTICIPANT	\N	PRESENT	0
372677	356314	11012A	PARTICIPANT	\N	PRESENT	0
372678	356314	19629C	PARTICIPANT	\N	PRESENT	0
372679	356314	08061X	PARTICIPANT	\N	PRESENT	0
372680	356314	14089Y	PARTICIPANT	\N	PRESENT	0
372681	356314	14061L	PARTICIPANT	\N	PRESENT	0
372682	356314	19675J	PARTICIPANT	\N	PRESENT	0
372683	356314	14111D	PARTICIPANT	\N	PRESENT	0
372684	356314	14147R	PARTICIPANT	\N	PRESENT	0
372685	356314	19768N	PARTICIPANT	\N	PRESENT	0
372686	356314	11103C	PARTICIPANT	\N	PRESENT	0
372687	356314	19383Y	PARTICIPANT	\N	PRESENT	0
372688	356314	19507S	PARTICIPANT	\N	PRESENT	0
372689	356314	18083K	PARTICIPANT	\N	PRESENT	0
372690	356314	19515S	PARTICIPANT	\N	PRESENT	0
372691	356314	87003B	PARTICIPANT	\N	PRESENT	0
372692	356314	19679N	PARTICIPANT	\N	PRESENT	0
372693	356314	17583W	PARTICIPANT	\N	PRESENT	0
372694	356314	14219Q	PARTICIPANT	\N	PRESENT	0
372695	356314	19347U	PARTICIPANT	\N	PRESENT	0
372696	356314	11090Q	PARTICIPANT	\N	PRESENT	0
372697	356314	14031R	PARTICIPANT	\N	PRESENT	0
372698	356314	19563B	PARTICIPANT	\N	PRESENT	0
372699	356314	08015R	PARTICIPANT	\N	PRESENT	0
372700	356314	08062Y	PARTICIPANT	\N	PRESENT	0
372701	356314	19441R	PARTICIPANT	\N	PRESENT	0
372702	356314	16685X	PARTICIPANT	\N	PRESENT	0
372703	356314	14157T	PARTICIPANT	\N	PRESENT	0
372704	356314	19415P	PARTICIPANT	\N	PRESENT	0
372705	356314	14191V	PARTICIPANT	\N	PRESENT	0
372706	356314	19798U	PARTICIPANT	\N	PRESENT	0
372707	356314	04085P	PARTICIPANT	\N	PRESENT	0
372708	356314	80013X	PARTICIPANT	\N	PRESENT	0
372709	356314	14357A	PARTICIPANT	\N	PRESENT	0
372710	356314	80027E	PARTICIPANT	\N	PRESENT	0
372711	356314	14105F	PARTICIPANT	\N	PRESENT	0
372712	356314	19745F	PARTICIPANT	\N	PRESENT	0
372713	356314	19741B	PARTICIPANT	\N	PRESENT	0
372714	356314	08053X	PARTICIPANT	\N	PRESENT	0
372715	356314	95062K	PARTICIPANT	\N	PRESENT	0
372716	356314	11043H	PARTICIPANT	\N	PRESENT	0
372717	356314	19399H	PARTICIPANT	\N	PRESENT	0
372718	356314	19719D	PARTICIPANT	\N	PRESENT	0
372719	369858	14083S	PARTICIPANT	\N	PRESENT	0
372720	369858	19479G	PARTICIPANT	\N	PRESENT	0
372721	369858	14085U	PARTICIPANT	\N	PRESENT	0
372722	369858	07004J	PARTICIPANT	\N	PRESENT	0
372723	369858	14121F	PARTICIPANT	\N	PRESENT	0
372724	369858	19741B	PARTICIPANT	\N	PRESENT	0
372725	369858	11074Q	PRESIDENT	0	PRESENT	0
372726	369858	88008L	PARTICIPANT	\N	PRESENT	0
372727	369858	14159V	PARTICIPANT	\N	PRESENT	0
372728	369858	04086Q	PARTICIPANT	\N	EXCUSE	0
372729	369858	07029T	PARTICIPANT	\N	EXCUSE	0
380410	380297	08055A	PARTICIPANT	\N	PRESENT	0
380411	380297	14229S	PARTICIPANT	\N	PRESENT	0
380412	380297	14191V	PARTICIPANT	\N	PRESENT	0
380413	380297	19591F	PARTICIPANT	\N	PRESENT	0
380414	380297	11077T	PARTICIPANT	\N	PRESENT	0
380415	380297	19766L	PARTICIPANT	\N	PRESENT	0
380409	380297	19515S	PARTICIPANT	\N	PRESENT	0
380416	380297	19253P	PARTICIPANT	\N	PRESENT	0
380417	380297	01057W	PARTICIPANT	\N	PRESENT	0
380418	380297	08052W	PARTICIPANT	\N	PRESENT	0
380419	380297	87003B	PARTICIPANT	\N	PRESENT	0
380420	380297	14051J	PARTICIPANT	\N	PRESENT	0
380421	380297	14223L	PARTICIPANT	\N	PRESENT	0
380422	380297	14021P	PARTICIPANT	\N	PRESENT	0
380423	380297	95067Q	PARTICIPANT	\N	PRESENT	0
380424	380297	14225N	PARTICIPANT	\N	PRESENT	0
380425	380297	11090Q	PARTICIPANT	\N	PRESENT	0
380426	380297	11048N	PARTICIPANT	\N	PRESENT	0
380427	380297	12016W	PARTICIPANT	\N	PRESENT	0
380428	380297	19599P	PARTICIPANT	\N	PRESENT	0
380429	380297	14031R	PARTICIPANT	\N	PRESENT	0
380430	380297	14151M	PARTICIPANT	\N	PRESENT	0
380431	380297	19647E	PARTICIPANT	\N	PRESENT	0
380432	380297	19667J	PARTICIPANT	\N	PRESENT	0
380433	380297	19649G	PARTICIPANT	\N	PRESENT	0
380434	380297	11045K	PARTICIPANT	\N	PRESENT	0
380435	380297	14259Y	PARTICIPANT	\N	PRESENT	0
380436	380297	19289C	PARTICIPANT	\N	PRESENT	0
380437	380297	19269X	PARTICIPANT	\N	PRESENT	0
380438	380297	19673G	PARTICIPANT	\N	PRESENT	0
380439	380297	19703U	PARTICIPANT	\N	PRESENT	0
380440	380297	14173T	PARTICIPANT	\N	PRESENT	0
380441	380297	14028W	PARTICIPANT	\N	PRESENT	0
380442	380297	11041F	PARTICIPANT	\N	PRESENT	0
380443	380297	19573D	PARTICIPANT	\N	PRESENT	0
380444	380297	19794Q	PARTICIPANT	\N	PRESENT	0
380445	380297	08043V	PARTICIPANT	\N	PRESENT	0
380446	380297	08045X	PARTICIPANT	\N	PRESENT	0
380447	380297	14119M	PARTICIPANT	\N	PRESENT	0
380448	380297	14115H	PARTICIPANT	\N	PRESENT	0
380449	380297	11104D	PARTICIPANT	\N	PRESENT	0
380450	380297	08012N	PARTICIPANT	\N	PRESENT	0
380451	380297	08047A	PARTICIPANT	\N	PRESENT	0
380452	380297	08060W	PARTICIPANT	\N	PRESENT	0
380453	380297	19715Y	PARTICIPANT	\N	PRESENT	0
380454	380297	14093U	PARTICIPANT	\N	PRESENT	0
380455	380297	14147R	PARTICIPANT	\N	PRESENT	0
380456	380297	14105F	PARTICIPANT	\N	PRESENT	0
380457	380297	17583W	PARTICIPANT	\N	PRESENT	0
380458	380297	19525U	PARTICIPANT	\N	PRESENT	0
380459	380297	17637T	PARTICIPANT	\N	PRESENT	0
380460	380297	08053X	PARTICIPANT	\N	PRESENT	0
380461	380297	14213J	PARTICIPANT	\N	PRESENT	0
380462	380297	08017T	PARTICIPANT	\N	PRESENT	0
380463	380297	14085U	PARTICIPANT	\N	PRESENT	0
380464	380297	14265W	PARTICIPANT	\N	PRESENT	0
380465	380297	14121F	PARTICIPANT	\N	PRESENT	0
380466	380297	08058D	PARTICIPANT	\N	PRESENT	0
380467	380297	19693L	PARTICIPANT	\N	PRESENT	0
380468	380297	19489J	PARTICIPANT	\N	PRESENT	0
380469	380297	17779H	PARTICIPANT	\N	PRESENT	0
380470	380297	19399H	PARTICIPANT	\N	PRESENT	0
380471	380297	11031D	PARTICIPANT	\N	PRESENT	0
380472	380297	08019V	PARTICIPANT	\N	PRESENT	0
380473	380297	19329S	PARTICIPANT	\N	PRESENT	0
380474	380297	11065P	PARTICIPANT	\N	PRESENT	0
380475	380297	01062T	PARTICIPANT	\N	PRESENT	0
380476	380297	14033T	PARTICIPANT	\N	PRESENT	0
380477	380297	11054L	PARTICIPANT	\N	PRESENT	0
380478	380297	19295A	PARTICIPANT	\N	PRESENT	0
380479	380297	19415P	PARTICIPANT	\N	PRESENT	0
380480	380297	18083K	PARTICIPANT	\N	PRESENT	0
380481	380297	19683J	PARTICIPANT	\N	PRESENT	0
380482	380297	19467C	PARTICIPANT	\N	PRESENT	0
380483	380297	19551W	PARTICIPANT	\N	PRESENT	0
380484	380297	19723Y	PARTICIPANT	\N	PRESENT	0
380485	380297	14001X	PARTICIPANT	\N	PRESENT	0
380486	380297	19333N	PARTICIPANT	\N	PRESENT	0
380487	380297	19443T	PARTICIPANT	\N	PRESENT	0
380488	380297	14251Q	PARTICIPANT	\N	PRESENT	0
380489	380297	19741B	PARTICIPANT	\N	PRESENT	0
380490	380297	08014Q	PARTICIPANT	\N	PRESENT	0
380491	380297	14029X	PARTICIPANT	\N	PRESENT	0
380492	380297	19725B	PARTICIPANT	\N	PRESENT	0
380493	380297	19507S	PARTICIPANT	\N	PRESENT	0
380494	380297	11110B	PARTICIPANT	\N	PRESENT	0
380495	380297	19663E	PARTICIPANT	\N	PRESENT	0
380496	380297	04088S	PARTICIPANT	\N	PRESENT	0
380497	380297	14041T	PARTICIPANT	\N	PRESENT	0
380498	380297	14109K	PARTICIPANT	\N	PRESENT	0
380499	380297	14063N	PARTICIPANT	\N	PRESENT	0
380500	380297	19527W	PARTICIPANT	\N	PRESENT	0
380501	380297	08018U	PARTICIPANT	\N	PRESENT	0
380502	380297	80027E	PARTICIPANT	\N	PRESENT	0
380503	380297	19657G	PARTICIPANT	\N	PRESENT	0
380504	380297	14097Y	PARTICIPANT	\N	PRESENT	0
380505	380297	11027H	PARTICIPANT	\N	PRESENT	0
380506	380297	11067R	PARTICIPANT	\N	PRESENT	0
380507	380297	19503N	PARTICIPANT	\N	PRESENT	0
380508	380297	98050T	PARTICIPANT	\N	PRESENT	0
380509	380297	14061L	PARTICIPANT	\N	PRESENT	0
380510	380297	11056N	PARTICIPANT	\N	PRESENT	0
380511	380297	14059S	PARTICIPANT	\N	PRESENT	0
380512	380297	01024M	PARTICIPANT	\N	PRESENT	0
380513	380297	14231L	PARTICIPANT	\N	PRESENT	0
380514	380297	01034P	PARTICIPANT	\N	PRESENT	0
380515	380297	19369B	PARTICIPANT	\N	PRESENT	0
380516	380297	04070G	PARTICIPANT	\N	PRESENT	0
380517	380297	19611R	PARTICIPANT	\N	PRESENT	0
380524	380297	19383Y	PARTICIPANT	\N	PRESENT	0
380519	380297	11109J	PARTICIPANT	\N	PRESENT	0
380520	380297	14329V	PARTICIPANT	\N	PRESENT	0
380521	380297	08035V	PARTICIPANT	\N	PRESENT	0
380522	380297	14357A	PARTICIPANT	\N	PRESENT	0
380523	380297	19675J	PARTICIPANT	\N	PRESENT	0
380525	380297	19691J	PARTICIPANT	\N	PRESENT	0
380526	380297	11053K	PARTICIPANT	\N	PRESENT	0
380527	380297	19762G	PARTICIPANT	\N	PRESENT	0
380528	380297	19737F	PARTICIPANT	\N	PRESENT	0
380529	380297	14205J	PARTICIPANT	\N	PRESENT	0
380530	380297	19701S	PARTICIPANT	\N	PRESENT	0
380531	380297	19721W	PARTICIPANT	\N	PRESENT	0
380532	380297	04018C	PARTICIPANT	\N	PRESENT	0
380533	380297	19569H	PARTICIPANT	\N	PRESENT	0
380534	380297	19367Y	PARTICIPANT	\N	PRESENT	0
380535	380297	14219Q	PARTICIPANT	\N	PRESENT	0
380536	380297	19747H	PARTICIPANT	\N	PRESENT	0
380537	380297	19553Y	PARTICIPANT	\N	PRESENT	0
380538	380297	19581D	PARTICIPANT	\N	PRESENT	0
380539	380297	14257W	PARTICIPANT	\N	PRESENT	0
380540	380297	14281W	PARTICIPANT	\N	PRESENT	0
380541	380297	19671E	PARTICIPANT	\N	PRESENT	0
380542	380297	14197C	PARTICIPANT	\N	PRESENT	0
380543	380297	08068F	PARTICIPANT	\N	PRESENT	0
380544	380297	10006L	PARTICIPANT	\N	PRESENT	0
380545	380297	14079W	PARTICIPANT	\N	PRESENT	0
380546	380297	19511N	PARTICIPANT	\N	PRESENT	0
380547	380297	04071H	PARTICIPANT	\N	PRESENT	0
380548	380297	19479G	PARTICIPANT	\N	PRESENT	0
380549	380297	19713W	PARTICIPANT	\N	PRESENT	0
380553	380297	19441R	PARTICIPANT	\N	PRESENT	0
380551	380297	14275Y	PARTICIPANT	\N	PRESENT	0
380552	380297	11097X	PARTICIPANT	\N	PRESENT	0
380554	380297	05008E	PARTICIPANT	\N	PRESENT	0
380555	380297	01025N	PARTICIPANT	\N	PRESENT	0
380556	380297	16685X	PARTICIPANT	\N	PRESENT	0
380557	380297	04043D	PARTICIPANT	\N	PRESENT	0
380558	380297	07029T	PARTICIPANT	\N	PRESENT	0
380559	380297	14267Y	PARTICIPANT	\N	PRESENT	0
380560	380297	14042U	PARTICIPANT	\N	PRESENT	0
380561	380297	14169X	PARTICIPANT	\N	PRESENT	0
380562	380297	19705W	PARTICIPANT	\N	PRESENT	0
380563	380297	08056B	PARTICIPANT	\N	PRESENT	0
380564	380297	19729F	PARTICIPANT	\N	PRESENT	0
380565	380297	14179A	PARTICIPANT	\N	PRESENT	0
380566	380297	14103D	PARTICIPANT	\N	PRESENT	0
380567	380297	14221J	PARTICIPANT	\N	PRESENT	0
380568	380297	19739H	PARTICIPANT	\N	PRESENT	0
380569	380297	04044E	PARTICIPANT	\N	PRESENT	0
380570	380297	19335Q	PARTICIPANT	\N	PRESENT	0
380571	380297	14083S	PARTICIPANT	\N	PRESENT	0
380572	380297	19745F	PARTICIPANT	\N	PRESENT	0
380573	380297	95030B	PARTICIPANT	\N	PRESENT	0
380574	380297	19521Q	PARTICIPANT	\N	PRESENT	0
380575	380297	14026U	PARTICIPANT	\N	PRESENT	0
380576	380297	19727D	PARTICIPANT	\N	PRESENT	0
380577	380297	14081Q	PARTICIPANT	\N	PRESENT	0
380578	380297	04086Q	PARTICIPANT	\N	PRESENT	0
363533	361142	14069U	PARTICIPANT	\N	PRESENT	0
363534	361142	19253P	PARTICIPANT	\N	PRESENT	0
363535	361142	14259Y	PARTICIPANT	\N	PRESENT	0
363536	361142	14327T	PARTICIPANT	\N	PRESENT	0
363537	361142	14281W	PARTICIPANT	\N	PRESENT	0
363538	361142	19565D	PARTICIPANT	\N	PRESENT	0
363539	361142	19489J	PARTICIPANT	\N	PRESENT	0
363540	361142	14103D	PARTICIPANT	\N	PRESENT	0
363542	361142	08010L	PARTICIPANT	\N	PRESENT	0
363543	361142	14257W	PARTICIPANT	\N	PRESENT	0
363544	361142	14063N	PARTICIPANT	\N	PRESENT	0
363555	344821	14030Q	PRESIDENT	0	PRESENT	0
363557	344821	19731Y	PARTICIPANT	\N	PRESENT	0
363559	344821	14109K	PARTICIPANT	\N	PRESENT	0
363560	344821	08043V	PARTICIPANT	\N	PRESENT	0
363561	344821	19269X	PARTICIPANT	\N	PRESENT	0
363562	344821	14235Q	PARTICIPANT	\N	PRESENT	0
363563	344821	19749K	PARTICIPANT	\N	PRESENT	0
363564	344821	19715Y	PARTICIPANT	\N	PRESENT	0
363565	344821	08031R	PARTICIPANT	\N	EXCUSE	0
363566	344821	19643A	PARTICIPANT	\N	EXCUSE	0
363567	344821	01043Q	PARTICIPANT	\N	EXCUSE	0
363568	344821	19575F	PARTICIPANT	\N	PRESENT	0
363569	344821	14073Q	PARTICIPANT	\N	PRESENT	0
363570	344821	11043H	PARTICIPANT	\N	PRESENT	0
365228	345240	01060R	PARTICIPANT	\N	PRESENT	0
365229	345240	04043D	PARTICIPANT	\N	PRESENT	0
365230	345240	19295A	PARTICIPANT	\N	PRESENT	0
365531	345241	01043Q	PARTICIPANT	\N	PRESENT	0
365532	345241	14031R	PARTICIPANT	\N	PRESENT	0
365607	345241	19695N	PARTICIPANT	\N	PRESENT	0
365534	345241	19715Y	PARTICIPANT	\N	PRESENT	0
365535	345241	19758L	PARTICIPANT	\N	PRESENT	0
365536	345241	19760E	PARTICIPANT	\N	PRESENT	0
365537	345241	08060W	PARTICIPANT	\N	PRESENT	0
365538	345241	04038G	PARTICIPANT	\N	PRESENT	0
365539	345241	11077T	PARTICIPANT	\N	PRESENT	0
365540	345241	19333N	PARTICIPANT	\N	PRESENT	0
365541	345241	19551W	PARTICIPANT	\N	PRESENT	0
365542	345241	88008L	PARTICIPANT	\N	PRESENT	0
365543	345241	19629C	PARTICIPANT	\N	PRESENT	0
365544	345241	19681G	PARTICIPANT	\N	PRESENT	0
365545	345241	02002K	PARTICIPANT	\N	PRESENT	0
365546	345241	17589D	PARTICIPANT	\N	PRESENT	0
365547	345241	14051J	PARTICIPANT	\N	PRESENT	0
365548	345241	19503N	PARTICIPANT	\N	PRESENT	0
365549	345241	14197C	PARTICIPANT	\N	PRESENT	0
365550	345241	08009T	PARTICIPANT	\N	PRESENT	0
365551	345241	19719D	PARTICIPANT	\N	PRESENT	0
365552	345241	19717B	PARTICIPANT	\N	PRESENT	0
365553	345241	19479G	PARTICIPANT	\N	PRESENT	0
365554	345241	14219Q	PARTICIPANT	\N	PRESENT	0
365555	345241	19737F	PARTICIPANT	\N	PRESENT	0
365556	345241	14089Y	PARTICIPANT	\N	PRESENT	0
365557	345241	19747H	PARTICIPANT	\N	PRESENT	0
365558	345241	14237S	PARTICIPANT	\N	PRESENT	0
365559	345241	14179A	PARTICIPANT	\N	PRESENT	0
365560	345241	14087W	PARTICIPANT	\N	PRESENT	0
365561	345241	14215L	PARTICIPANT	\N	PRESENT	0
365562	345241	19421M	PARTICIPANT	\N	PRESENT	0
365563	345241	19599P	PARTICIPANT	\N	PRESENT	0
365564	345241	19637C	PARTICIPANT	\N	PRESENT	0
365565	345241	08024S	PARTICIPANT	\N	PRESENT	0
365566	345241	14249W	PARTICIPANT	\N	PRESENT	0
365567	345241	14187A	PARTICIPANT	\N	PRESENT	0
365568	345241	01058X	PARTICIPANT	\N	PRESENT	0
365569	345241	95030B	PARTICIPANT	\N	PRESENT	0
365570	345241	04043D	PARTICIPANT	\N	PRESENT	0
365571	345241	05012A	PARTICIPANT	\N	PRESENT	0
365572	345241	80013X	PARTICIPANT	\N	PRESENT	0
365573	345241	07033P	PARTICIPANT	\N	PRESENT	0
365574	345241	14069U	PARTICIPANT	\N	PRESENT	0
365575	345241	19711U	PARTICIPANT	\N	PRESENT	0
365576	345241	99004R	PARTICIPANT	\N	PRESENT	0
365577	345241	04018C	PARTICIPANT	\N	PRESENT	0
365578	345241	19701S	PARTICIPANT	\N	PRESENT	0
365579	345241	14105F	PARTICIPANT	\N	PRESENT	0
365580	345241	07029T	PARTICIPANT	\N	PRESENT	0
365581	345241	01057W	PARTICIPANT	\N	PRESENT	0
365582	345241	19515S	PARTICIPANT	\N	PRESENT	0
365583	345241	19794Q	PARTICIPANT	\N	PRESENT	0
365584	345241	14119M	PARTICIPANT	\N	PRESENT	0
365585	345241	18083K	PARTICIPANT	\N	PRESENT	0
365586	345241	19467C	PARTICIPANT	\N	PRESENT	0
365587	345241	14173T	PARTICIPANT	\N	PRESENT	0
365588	345241	14029X	PARTICIPANT	\N	PRESENT	0
365589	345241	14059S	PARTICIPANT	\N	PRESENT	0
365590	345241	14061L	PARTICIPANT	\N	PRESENT	0
365591	345241	11065P	PARTICIPANT	\N	PRESENT	0
365592	345241	19289C	PARTICIPANT	\N	PRESENT	0
365593	345241	19253P	PARTICIPANT	\N	PRESENT	0
365594	345241	19671E	PARTICIPANT	\N	PRESENT	0
365595	345241	08044W	PARTICIPANT	\N	PRESENT	0
365596	345241	19565D	PARTICIPANT	\N	PRESENT	0
365597	345241	19525U	PARTICIPANT	\N	PRESENT	0
365598	345241	17583W	PARTICIPANT	\N	PRESENT	0
365599	345241	19383Y	PARTICIPANT	\N	PRESENT	0
365600	345241	14357A	PARTICIPANT	\N	PRESENT	0
365601	345241	97011G	PARTICIPANT	\N	PRESENT	0
365602	345241	08020N	PARTICIPANT	\N	PRESENT	0
365603	345241	95062K	PARTICIPANT	\N	PRESENT	0
365604	345241	14038Y	PARTICIPANT	\N	PRESENT	0
365605	345241	04088S	PARTICIPANT	\N	PRESENT	0
365606	345241	19443T	PARTICIPANT	\N	PRESENT	0
365608	345241	19347U	PARTICIPANT	\N	PRESENT	0
365609	363151	11067R	PARTICIPANT	\N	PRESENT	0
365610	363151	14147R	PARTICIPANT	\N	PRESENT	0
365611	363151	19749K	PARTICIPANT	\N	PRESENT	0
365612	363151	10006L	PRESIDENT	0	PRESENT	0
365613	363151	19673G	PARTICIPANT	\N	PRESENT	0
365614	345241	04085P	PARTICIPANT	\N	PRESENT	0
365615	345241	14331P	PARTICIPANT	\N	PRESENT	0
365616	345241	11048N	PARTICIPANT	\N	PRESENT	0
365617	345241	14123H	PARTICIPANT	\N	PRESENT	0
365618	345241	14053L	PARTICIPANT	\N	PRESENT	0
365619	345241	14231L	PARTICIPANT	\N	PRESENT	0
365620	345241	08056B	PARTICIPANT	\N	PRESENT	0
365621	345241	14109K	PARTICIPANT	\N	PRESENT	0
365622	345241	19507S	PARTICIPANT	\N	PRESENT	0
365623	345241	19703U	PARTICIPANT	\N	PRESENT	0
365624	345241	08015R	PARTICIPANT	\N	PRESENT	0
365625	345241	14083S	PARTICIPANT	\N	PRESENT	0
365626	345241	04071H	PARTICIPANT	\N	PRESENT	0
365628	345241	19713W	PARTICIPANT	\N	PRESENT	0
365631	345241	14265W	PARTICIPANT	\N	PRESENT	0
365633	345241	14135M	PARTICIPANT	\N	PRESENT	0
365634	345241	19697Q	PARTICIPANT	\N	PRESENT	0
365635	345241	19413M	PARTICIPANT	\N	PRESENT	0
365639	345241	19768N	PARTICIPANT	\N	PRESENT	0
365645	345241	14191V	PARTICIPANT	\N	PRESENT	0
365646	345241	14071N	PARTICIPANT	\N	PRESENT	0
365647	345241	19647E	PARTICIPANT	\N	PRESENT	0
365648	345241	19563B	PARTICIPANT	\N	PRESENT	0
365649	345241	14034U	PARTICIPANT	\N	PRESENT	0
365650	345241	01024M	PARTICIPANT	\N	PRESENT	0
365651	345241	11043H	PARTICIPANT	\N	PRESENT	0
365652	345241	19679N	PARTICIPANT	\N	PRESENT	0
365653	345241	11033F	PARTICIPANT	\N	PRESENT	0
365654	345241	11056N	PARTICIPANT	\N	PRESENT	0
365655	345241	11012A	PARTICIPANT	\N	PRESENT	0
365656	345241	14223L	PARTICIPANT	\N	PRESENT	0
365657	345241	04057K	PARTICIPANT	\N	PRESENT	0
365658	345241	19691J	PARTICIPANT	\N	PRESENT	0
365659	345241	19521Q	PARTICIPANT	\N	PRESENT	0
365660	345241	14107H	PARTICIPANT	\N	PRESENT	0
365661	345241	14042U	PARTICIPANT	\N	PRESENT	0
365662	345241	01048V	PARTICIPANT	\N	PRESENT	0
365663	345241	11053K	PARTICIPANT	\N	PRESENT	0
365664	345241	19251M	PARTICIPANT	\N	PRESENT	0
365665	345241	01025N	PARTICIPANT	\N	PRESENT	0
365666	345241	08039A	PARTICIPANT	\N	PRESENT	0
365667	345241	19387D	PARTICIPANT	\N	PRESENT	0
365668	345241	19549D	PARTICIPANT	\N	PRESENT	0
365669	345241	08055A	PARTICIPANT	\N	PRESENT	0
365670	345241	10015M	PARTICIPANT	\N	PRESENT	0
365671	345241	19441R	PARTICIPANT	\N	PRESENT	0
365672	345241	19631V	PARTICIPANT	\N	PRESENT	0
365673	345241	19782L	PARTICIPANT	\N	PRESENT	0
365674	345241	19687N	PARTICIPANT	\N	PRESENT	0
390754	388119	14241N	PARTICIPANT	\N	PRESENT	0
390755	388119	14223L	PARTICIPANT	\N	PRESENT	0
390756	388119	19719D	PARTICIPANT	\N	PRESENT	0
390757	388119	14107H	PARTICIPANT	\N	PRESENT	0
390758	388119	19289C	PARTICIPANT	\N	PRESENT	0
390759	388119	19515S	PARTICIPANT	\N	PRESENT	0
390760	388119	14191V	PARTICIPANT	\N	PRESENT	0
390761	388119	14093U	PARTICIPANT	\N	PRESENT	0
390762	388119	11080N	PARTICIPANT	\N	PRESENT	0
390763	388119	19583F	PARTICIPANT	\N	PRESENT	0
390764	388119	19563B	PARTICIPANT	\N	PRESENT	0
390765	388119	19545Y	PARTICIPANT	\N	PRESENT	0
390766	388119	19766L	PARTICIPANT	\N	PRESENT	0
390767	388119	14251Q	PARTICIPANT	\N	PRESENT	0
390768	388119	01057W	PARTICIPANT	\N	PRESENT	0
390769	388119	04057K	PARTICIPANT	\N	PRESENT	0
390770	388119	11010L	PARTICIPANT	\N	PRESENT	0
390771	388119	98035U	PARTICIPANT	\N	PRESENT	0
390772	388119	14159V	PARTICIPANT	\N	PRESENT	0
390773	388119	19667J	PARTICIPANT	\N	PRESENT	0
390774	388119	11027H	PARTICIPANT	\N	PRESENT	0
390775	388119	14259Y	PARTICIPANT	\N	PRESENT	0
390776	388119	04059M	PARTICIPANT	\N	PRESENT	0
390777	388119	11074Q	PARTICIPANT	\N	PRESENT	0
390778	388119	14199E	PARTICIPANT	\N	PRESENT	0
390779	388119	14229S	PARTICIPANT	\N	PRESENT	0
390780	388119	08052W	PARTICIPANT	\N	PRESENT	0
390781	388119	04042C	PARTICIPANT	\N	PRESENT	0
390782	388119	01028R	PARTICIPANT	\N	PRESENT	0
390783	388119	19575F	PARTICIPANT	\N	PRESENT	0
390784	388119	08068F	PARTICIPANT	\N	PRESENT	0
390785	388119	14051J	PARTICIPANT	\N	PRESENT	0
390786	388119	19447X	PARTICIPANT	\N	PRESENT	0
390787	388119	14151M	PARTICIPANT	\N	PRESENT	0
390788	388119	19573D	PARTICIPANT	\N	PRESENT	0
390789	388119	19551W	PARTICIPANT	\N	PRESENT	0
390790	388119	19794Q	PARTICIPANT	\N	PRESENT	0
390791	388119	19669L	PARTICIPANT	\N	PRESENT	0
390792	388119	14225N	PARTICIPANT	\N	PRESENT	0
390793	388119	14133K	PARTICIPANT	\N	PRESENT	0
390794	388119	08045X	PARTICIPANT	\N	PRESENT	0
390795	388119	14119M	PARTICIPANT	\N	PRESENT	0
390796	388119	14021P	PARTICIPANT	\N	PRESENT	0
390797	388119	01062T	PARTICIPANT	\N	PRESENT	0
390798	388119	08060W	PARTICIPANT	\N	PRESENT	0
390799	388119	08047A	PARTICIPANT	\N	PRESENT	0
390800	388119	80013X	PARTICIPANT	\N	PRESENT	0
390801	388119	14115H	PARTICIPANT	\N	PRESENT	0
390802	388119	19649G	PARTICIPANT	\N	PRESENT	0
390803	388119	14105F	PARTICIPANT	\N	PRESENT	0
390804	388119	17779H	PARTICIPANT	\N	PRESENT	0
390805	388119	11048N	PARTICIPANT	\N	PRESENT	0
390806	388119	08012N	PARTICIPANT	\N	PRESENT	0
390807	388119	08058D	PARTICIPANT	\N	PRESENT	0
390808	388119	17583W	PARTICIPANT	\N	PRESENT	0
390809	388119	14085U	PARTICIPANT	\N	PRESENT	0
390810	388119	19727D	PARTICIPANT	\N	PRESENT	0
390811	388119	19673G	PARTICIPANT	\N	PRESENT	0
390812	388119	14257W	PARTICIPANT	\N	PRESENT	0
390813	388119	11045K	PARTICIPANT	\N	PRESENT	0
390814	388119	11110B	PARTICIPANT	\N	PRESENT	0
390815	388119	19467C	PARTICIPANT	\N	PRESENT	0
390816	388119	18083K	PARTICIPANT	\N	PRESENT	0
390817	388119	14081Q	PARTICIPANT	\N	PRESENT	0
390818	388119	11041F	PARTICIPANT	\N	PRESENT	0
390819	388119	14135M	PARTICIPANT	\N	PRESENT	0
390820	388119	19333N	PARTICIPANT	\N	PRESENT	0
390821	388119	14001X	PARTICIPANT	\N	PRESENT	0
390822	388119	14033T	PARTICIPANT	\N	PRESENT	0
390823	388119	11054L	PARTICIPANT	\N	PRESENT	0
390824	388119	19399H	PARTICIPANT	\N	PRESENT	0
390825	388119	19251M	PARTICIPANT	\N	PRESENT	0
390826	388119	19693L	PARTICIPANT	\N	PRESENT	0
390827	388119	19413M	PARTICIPANT	\N	PRESENT	0
390828	388119	19689Q	PARTICIPANT	\N	PRESENT	0
390752	388119	01048V	PARTICIPANT	\N	PRESENT	0
390753	388119	98022P	PARTICIPANT	\N	PRESENT	0
390829	388119	14265W	PARTICIPANT	\N	PRESENT	0
390830	388119	19503N	PARTICIPANT	\N	PRESENT	0
390831	388119	11104D	PARTICIPANT	\N	PRESENT	0
390832	388119	14213J	PARTICIPANT	\N	PRESENT	0
390833	388119	19549D	PARTICIPANT	\N	PRESENT	0
390834	388119	19443T	PARTICIPANT	\N	PRESENT	0
390835	388119	19741B	PARTICIPANT	\N	PRESENT	0
390836	388119	19725B	PARTICIPANT	\N	PRESENT	0
390837	388119	19631V	PARTICIPANT	\N	PRESENT	0
390838	388119	19709B	PARTICIPANT	\N	PRESENT	0
390839	388119	14097Y	PARTICIPANT	\N	PRESENT	0
390840	388119	19329S	PARTICIPANT	\N	PRESENT	0
390841	388119	04088S	PARTICIPANT	\N	PRESENT	0
390842	388119	14041T	PARTICIPANT	\N	PRESENT	0
390843	388119	19657G	PARTICIPANT	\N	PRESENT	0
390844	388119	19713W	PARTICIPANT	\N	PRESENT	0
390845	388119	04089T	PARTICIPANT	\N	PRESENT	0
390846	388119	14231L	PARTICIPANT	\N	PRESENT	0
390847	388119	08015R	PARTICIPANT	\N	PRESENT	0
390848	388119	14179A	PARTICIPANT	\N	PRESENT	0
390849	388119	19369B	PARTICIPANT	\N	PRESENT	0
390850	388119	98024R	PARTICIPANT	\N	PRESENT	0
390851	388119	04035D	PARTICIPANT	\N	PRESENT	0
390852	388119	19691J	PARTICIPANT	\N	PRESENT	0
390853	388119	04086Q	PARTICIPANT	\N	PRESENT	0
390854	388119	08009T	PARTICIPANT	\N	PRESENT	0
390855	388119	14187A	PARTICIPANT	\N	PRESENT	0
390856	388119	19611R	PARTICIPANT	\N	PRESENT	0
390857	388119	11053K	PARTICIPANT	\N	PRESENT	0
390858	388119	14071N	PARTICIPANT	\N	PRESENT	0
390859	388119	19569H	PARTICIPANT	\N	PRESENT	0
390860	388119	19619A	PARTICIPANT	\N	PRESENT	0
390861	388119	05008E	PARTICIPANT	\N	PRESENT	0
390862	388119	14205J	PARTICIPANT	\N	PRESENT	0
390863	388119	11097X	PARTICIPANT	\N	PRESENT	0
390864	388119	19737F	PARTICIPANT	\N	PRESENT	0
390865	388119	19421M	PARTICIPANT	\N	PRESENT	0
390866	388119	19699S	PARTICIPANT	\N	PRESENT	0
390867	388119	16685X	PARTICIPANT	\N	PRESENT	0
390868	388119	14249W	PARTICIPANT	\N	PRESENT	0
390869	388119	08056B	PARTICIPANT	\N	PRESENT	0
390870	388119	14053L	PARTICIPANT	\N	PRESENT	0
390871	388119	14087W	PARTICIPANT	\N	PRESENT	0
390872	388119	19715Y	PARTICIPANT	\N	PRESENT	0
390873	388119	14215L	PARTICIPANT	\N	PRESENT	0
390874	388119	14219Q	PARTICIPANT	\N	PRESENT	0
390875	388119	05012A	PARTICIPANT	\N	PRESENT	0
390876	388119	19479G	PARTICIPANT	\N	PRESENT	0
390877	388119	19441R	PARTICIPANT	\N	PRESENT	0
390878	388119	08034U	PARTICIPANT	\N	PRESENT	0
390879	388119	19533U	PARTICIPANT	\N	PRESENT	0
390880	388119	11065P	PARTICIPANT	\N	PRESENT	0
390881	388119	10006L	PARTICIPANT	\N	PRESENT	0
390882	388119	14227Q	PARTICIPANT	\N	PRESENT	0
390883	388119	19319Q	PARTICIPANT	\N	PRESENT	0
390884	388119	14275Y	PARTICIPANT	\N	PRESENT	0
390885	388119	14267Y	PARTICIPANT	\N	PRESENT	0
390886	388119	14103D	PARTICIPANT	\N	PRESENT	0
390887	388119	19798U	PARTICIPANT	\N	PRESENT	0
390888	388119	19335Q	PARTICIPANT	\N	PRESENT	0
390889	388119	14221J	PARTICIPANT	\N	PRESENT	0
390890	388119	07033P	PARTICIPANT	\N	PRESENT	0
390891	388119	14073Q	PARTICIPANT	\N	PRESENT	0
390892	388119	14083S	PARTICIPANT	\N	PRESENT	0
390893	388119	14217N	PARTICIPANT	\N	PRESENT	0
390894	388119	14089Y	PARTICIPANT	\N	PRESENT	0
390895	388119	19745F	PARTICIPANT	\N	PRESENT	0
390896	388119	14331P	PARTICIPANT	\N	PRESENT	0
390897	388119	11070L	PARTICIPANT	\N	PRESENT	0
390898	388119	14079W	PARTICIPANT	\N	PRESENT	0
390899	388119	19521Q	PARTICIPANT	\N	PRESENT	0
390900	388119	19671E	PARTICIPANT	\N	PRESENT	0
390901	388119	11085T	PARTICIPANT	\N	PRESENT	0
390902	388119	14329V	PARTICIPANT	\N	PRESENT	0
390903	388119	07004J	PARTICIPANT	\N	PRESENT	0
390904	388119	19577H	PARTICIPANT	\N	PRESENT	0
390905	388119	14357A	PARTICIPANT	\N	PRESENT	0
390906	388119	04070G	PARTICIPANT	\N	PRESENT	0
390907	388119	19675J	PARTICIPANT	\N	PRESENT	0
390908	388119	01024M	PARTICIPANT	\N	PRESENT	0
390909	388119	19383Y	PARTICIPANT	\N	PRESENT	0
390910	388119	14327T	PARTICIPANT	\N	PRESENT	0
390911	388119	19762G	PARTICIPANT	\N	PRESENT	0
390912	388119	01043Q	PARTICIPANT	\N	PRESENT	0
390913	388119	19701S	PARTICIPANT	\N	PRESENT	0
390914	388119	04018C	PARTICIPANT	\N	PRESENT	0
390915	388119	19621T	PARTICIPANT	\N	PRESENT	0
390916	388119	19768N	PARTICIPANT	\N	PRESENT	0
390917	388119	19637C	PARTICIPANT	\N	PRESENT	0
390918	388119	98050T	PARTICIPANT	\N	PRESENT	0
390919	388119	14061L	PARTICIPANT	\N	PRESENT	0
362863	362862	89017R	PARTICIPANT	\N	PRESENT	0
370755	370567	14038Y	PARTICIPANT	\N	EXCUSE	0
372647	356669	14261S	PARTICIPANT	\N	PRESENT	0
372648	356669	19577H	PARTICIPANT	\N	EXCUSE	0
372649	356669	19329S	PARTICIPANT	\N	PRESENT	0
372650	356669	19715Y	PARTICIPANT	\N	EXCUSE	0
372651	356669	19729F	PARTICIPANT	\N	PRESENT	0
372652	356669	14059S	PARTICIPANT	\N	PRESENT	0
372653	356669	08019V	PRESIDENT	0	PRESENT	0
372654	356669	14331P	PARTICIPANT	\N	PRESENT	0
372655	356669	11109J	PARTICIPANT	\N	EXCUSE	0
372656	356669	19657G	PARTICIPANT	\N	EXCUSE	0
372730	369858	08010L	PARTICIPANT	\N	EXCUSE	0
372731	356314	11104D	PARTICIPANT	\N	PRESENT	0
372733	369858	04071H	PARTICIPANT	\N	PRESENT	0
372734	369858	19711U	PARTICIPANT	\N	PRESENT	0
372735	369858	19545Y	PARTICIPANT	\N	PRESENT	0
372738	369858	11053K	PARTICIPANT	\N	PRESENT	0
372744	356314	14051J	PARTICIPANT	\N	PRESENT	0
372747	356314	14205J	PARTICIPANT	\N	PRESENT	0
372760	369858	08011M	PARTICIPANT	\N	PRESENT	0
372764	356314	19489J	PARTICIPANT	\N	PRESENT	0
372781	369858	01057W	PARTICIPANT	\N	PRESENT	0
372800	369858	11012A	PARTICIPANT	\N	PRESENT	0
372801	356314	14331P	PARTICIPANT	\N	PRESENT	0
372802	356314	14187A	PARTICIPANT	\N	PRESENT	0
372803	356314	14221J	PARTICIPANT	\N	PRESENT	0
372804	356314	08056B	PARTICIPANT	\N	PRESENT	0
372805	365231	19479G	PARTICIPANT	\N	EXCUSE	0
372806	356314	14039A	PARTICIPANT	\N	PRESENT	0
372807	356314	19747H	PARTICIPANT	\N	PRESENT	0
372835	356314	08034U	PARTICIPANT	\N	PRESENT	0
372838	356314	19511N	PARTICIPANT	\N	PRESENT	0
372843	356314	19467C	PARTICIPANT	\N	PRESENT	0
372870	356314	11097X	PARTICIPANT	\N	PRESENT	0
372883	356314	14042U	PARTICIPANT	\N	PRESENT	0
372884	356314	14213J	PARTICIPANT	\N	PRESENT	0
372885	356314	08020N	PARTICIPANT	\N	PRESENT	0
372886	356314	14199E	PARTICIPANT	\N	PRESENT	0
372937	356317	14195A	PARTICIPANT	\N	PRESENT	0
372938	356317	19583F	PARTICIPANT	\N	PRESENT	0
372939	356317	19593H	PARTICIPANT	\N	PRESENT	0
372940	356317	08021P	PARTICIPANT	\N	PRESENT	0
372941	356317	19725B	PARTICIPANT	\N	PRESENT	0
372942	356317	08049C	PARTICIPANT	\N	PRESENT	0
372943	356317	19329S	PARTICIPANT	\N	PRESENT	0
372944	356317	14063N	PARTICIPANT	\N	PRESENT	0
372945	356317	11066Q	PARTICIPANT	\N	PRESENT	0
372946	356317	14051J	PARTICIPANT	\N	PRESENT	0
372947	356317	11104D	PARTICIPANT	\N	PRESENT	0
372948	356317	08052W	PARTICIPANT	\N	PRESENT	0
372949	356317	14191V	PARTICIPANT	\N	PRESENT	0
372950	356317	19693L	PARTICIPANT	\N	PRESENT	0
372951	356317	14105F	PARTICIPANT	\N	PRESENT	0
372952	356317	19383Y	PARTICIPANT	\N	PRESENT	0
372953	356317	95062K	PARTICIPANT	\N	PRESENT	0
372954	356317	19369B	PARTICIPANT	\N	PRESENT	0
372955	356317	19479G	PARTICIPANT	\N	PRESENT	0
372956	356317	14331P	PARTICIPANT	\N	PRESENT	0
372957	356317	11027H	PARTICIPANT	\N	PRESENT	0
372958	356317	19399H	PARTICIPANT	\N	PRESENT	0
372959	356317	11041F	PARTICIPANT	\N	PRESENT	0
372960	356317	08068F	PARTICIPANT	\N	PRESENT	0
372961	356317	99004R	PARTICIPANT	\N	PRESENT	0
372962	356317	14227Q	PARTICIPANT	\N	PRESENT	0
372963	356317	14275Y	PARTICIPANT	\N	PRESENT	0
372964	356317	14205J	PARTICIPANT	\N	PRESENT	0
372965	356317	19719D	PARTICIPANT	\N	PRESENT	0
372966	356317	11080N	PARTICIPANT	\N	PRESENT	0
372967	356317	17779H	PARTICIPANT	\N	PRESENT	0
372968	356317	08031R	PARTICIPANT	\N	PRESENT	0
372969	356317	19649G	PARTICIPANT	\N	PRESENT	0
372970	356317	19671E	PARTICIPANT	\N	PRESENT	0
372971	356317	19657G	PARTICIPANT	\N	PRESENT	0
372972	356317	19611R	PARTICIPANT	\N	PRESENT	0
372973	356317	10006L	PARTICIPANT	\N	PRESENT	0
372974	356317	14215L	PARTICIPANT	\N	PRESENT	0
372975	356317	98035U	PARTICIPANT	\N	PRESENT	0
372976	356317	14249W	PARTICIPANT	\N	PRESENT	0
372977	356317	19741B	PARTICIPANT	\N	PRESENT	0
372978	356317	11103C	PARTICIPANT	\N	PRESENT	0
372935	356317	19511N	PARTICIPANT	\N	PRESENT	0
372936	356317	19569H	PARTICIPANT	\N	PRESENT	0
372979	356317	14197C	PARTICIPANT	\N	PRESENT	0
372980	356317	19585H	PARTICIPANT	\N	PRESENT	0
372981	356317	14061L	PARTICIPANT	\N	PRESENT	0
372982	356317	14059S	PARTICIPANT	\N	PRESENT	0
372983	356317	19659J	PARTICIPANT	\N	PRESENT	0
372984	356317	14107H	PARTICIPANT	\N	PRESENT	0
372985	356317	08069G	PARTICIPANT	\N	PRESENT	0
372986	356317	08034U	PARTICIPANT	\N	PRESENT	0
372987	356317	17637T	PARTICIPANT	\N	PRESENT	0
372988	356317	11049P	PARTICIPANT	\N	PRESENT	0
372989	356317	14121F	PARTICIPANT	\N	PRESENT	0
372990	356317	19711U	PARTICIPANT	\N	PRESENT	0
372991	356317	11054L	PARTICIPANT	\N	PRESENT	0
372992	356317	19768N	PARTICIPANT	\N	PRESENT	0
372993	356317	14231L	PARTICIPANT	\N	PRESENT	0
372994	356317	14211G	PARTICIPANT	\N	PRESENT	0
372995	356317	19563B	PARTICIPANT	\N	PRESENT	0
372996	356317	01048V	PARTICIPANT	\N	PRESENT	0
372997	356317	14159V	PARTICIPANT	\N	PRESENT	0
372998	356317	96004D	PARTICIPANT	\N	PRESENT	0
372999	356317	19551W	PARTICIPANT	\N	PRESENT	0
373000	356317	19549D	PARTICIPANT	\N	PRESENT	0
373001	356317	14187A	PARTICIPANT	\N	PRESENT	0
373002	356317	19295A	PARTICIPANT	\N	PRESENT	0
373003	356317	80013X	PARTICIPANT	\N	PRESENT	0
373004	356317	19533U	PARTICIPANT	\N	PRESENT	0
373005	356317	19333N	PARTICIPANT	\N	PRESENT	0
373006	356317	17583W	PARTICIPANT	\N	PRESENT	0
373007	356317	08053X	PARTICIPANT	\N	PRESENT	0
373008	356317	19253P	PARTICIPANT	\N	PRESENT	0
373009	356317	14261S	PARTICIPANT	\N	PRESENT	0
373010	356317	14357A	PARTICIPANT	\N	PRESENT	0
373011	356317	14053L	PARTICIPANT	\N	PRESENT	0
373012	356317	10015M	PARTICIPANT	\N	PRESENT	0
373013	356317	87003B	PARTICIPANT	\N	PRESENT	0
373014	356317	11101A	PARTICIPANT	\N	PRESENT	0
373015	356317	19766L	PARTICIPANT	\N	PRESENT	0
373016	356317	14259Y	PARTICIPANT	\N	PRESENT	0
373017	356317	04044E	PARTICIPANT	\N	PRESENT	0
373018	356317	19447X	PARTICIPANT	\N	PRESENT	0
373019	356317	14235Q	PARTICIPANT	\N	PRESENT	0
373020	356317	04085P	PARTICIPANT	\N	PRESENT	0
373021	356317	12041X	PARTICIPANT	\N	PRESENT	0
373022	356317	11056N	PARTICIPANT	\N	PRESENT	0
373023	356317	04047H	PARTICIPANT	\N	PRESENT	0
373024	356317	19695N	PARTICIPANT	\N	PRESENT	0
373025	356317	19679N	PARTICIPANT	\N	PRESENT	0
373026	356317	01060R	PARTICIPANT	\N	PRESENT	0
373027	356317	04088S	PARTICIPANT	\N	PRESENT	0
373028	356317	11048N	PARTICIPANT	\N	PRESENT	0
373029	356317	95037J	PARTICIPANT	\N	PRESENT	0
373030	356317	08061X	PARTICIPANT	\N	PRESENT	0
373031	356317	19269X	PARTICIPANT	\N	PRESENT	0
373032	356317	19697Q	PARTICIPANT	\N	PRESENT	0
373033	356317	14039A	PARTICIPANT	\N	PRESENT	0
373034	356317	19301E	PARTICIPANT	\N	PRESENT	0
373035	356317	14157T	PARTICIPANT	\N	PRESENT	0
373036	356317	11083R	PARTICIPANT	\N	PRESENT	0
373037	356317	01058X	PARTICIPANT	\N	PRESENT	0
373038	356317	19758L	PARTICIPANT	\N	PRESENT	0
373039	356317	08020N	PARTICIPANT	\N	PRESENT	0
373040	356317	11074Q	PARTICIPANT	\N	PRESENT	0
373041	356317	19565D	PARTICIPANT	\N	PRESENT	0
373042	356317	14038Y	PARTICIPANT	\N	PRESENT	0
373043	356317	04034C	PARTICIPANT	\N	PRESENT	0
373044	356317	08073C	PARTICIPANT	\N	PRESENT	0
373045	356317	11043H	PARTICIPANT	\N	PRESENT	0
373046	356317	01028R	PARTICIPANT	\N	PRESENT	0
373047	356317	19515S	PARTICIPANT	\N	PRESENT	0
373048	356317	19669L	PARTICIPANT	\N	PRESENT	0
373049	356317	19599P	PARTICIPANT	\N	PRESENT	0
373050	356317	19651A	PARTICIPANT	\N	PRESENT	0
373051	356317	14028W	PARTICIPANT	\N	PRESENT	0
373052	356317	01057W	PARTICIPANT	\N	PRESENT	0
373053	356317	95067Q	PARTICIPANT	\N	PRESENT	0
373054	356317	86034E	PARTICIPANT	\N	PRESENT	0
373055	356317	08043V	PARTICIPANT	\N	PRESENT	0
373056	356317	19703U	PARTICIPANT	\N	PRESENT	0
373057	356317	08058D	PARTICIPANT	\N	PRESENT	0
373058	356317	08012N	PARTICIPANT	\N	PRESENT	0
373059	356317	19727D	PARTICIPANT	\N	PRESENT	0
373060	356317	14031R	PARTICIPANT	\N	PRESENT	0
373061	356317	19489J	PARTICIPANT	\N	PRESENT	0
373062	356317	14123H	PARTICIPANT	\N	PRESENT	0
373063	356317	14199E	PARTICIPANT	\N	PRESENT	0
373064	356317	04049K	PARTICIPANT	\N	PRESENT	0
380579	380297	04033B	PARTICIPANT	\N	PRESENT	0
380580	380297	14187A	PARTICIPANT	\N	PRESENT	0
380581	380297	08009T	PARTICIPANT	\N	PRESENT	0
380582	380297	19577H	PARTICIPANT	\N	PRESENT	0
380583	380297	14071N	PARTICIPANT	\N	PRESENT	0
380584	380297	14053L	PARTICIPANT	\N	PRESENT	0
380585	380297	04040A	PARTICIPANT	\N	PRESENT	0
380586	380297	14030Q	PARTICIPANT	\N	PRESENT	0
380587	380297	14249W	PARTICIPANT	\N	PRESENT	0
380588	380297	14327T	PARTICIPANT	\N	PRESENT	0
380589	380297	19533U	PARTICIPANT	\N	PRESENT	0
380590	380297	19798U	PARTICIPANT	\N	PRESENT	0
380591	380297	11103C	PARTICIPANT	\N	PRESENT	0
380592	380297	01060R	PARTICIPANT	\N	PRESENT	0
380593	380297	97011G	PARTICIPANT	\N	PRESENT	0
380594	380297	14055N	PARTICIPANT	\N	PRESENT	0
380595	380297	07033P	PARTICIPANT	\N	PRESENT	0
380596	380297	14331P	PARTICIPANT	\N	PRESENT	0
380597	380297	08038Y	PARTICIPANT	\N	PRESENT	0
380598	380297	14237S	PARTICIPANT	\N	PRESENT	0
380599	380297	04034C	PARTICIPANT	\N	PRESENT	0
380600	380297	19347U	PARTICIPANT	\N	PRESENT	0
380601	380297	07004J	PARTICIPANT	\N	PRESENT	0
380602	380297	11115U	PARTICIPANT	\N	PRESENT	0
380603	380297	80013X	PARTICIPANT	\N	PRESENT	0
380604	380297	14065Q	PARTICIPANT	\N	PRESENT	0
380605	380297	08028W	PARTICIPANT	\N	PRESENT	0
380606	380297	11026G	PARTICIPANT	\N	PRESENT	0
380607	380297	08015R	PARTICIPANT	\N	PRESENT	0
380608	380297	19413M	PARTICIPANT	\N	PRESENT	0
380609	380297	14217N	PARTICIPANT	\N	PRESENT	0
380610	380297	08044W	PARTICIPANT	\N	PRESENT	0
380611	380297	14133K	PARTICIPANT	\N	PRESENT	0
380612	380297	14135M	PARTICIPANT	\N	PRESENT	0
380613	380297	95041E	PARTICIPANT	\N	PRESENT	0
380614	380297	08048B	PARTICIPANT	\N	PRESENT	0
380615	380297	14199E	PARTICIPANT	\N	PRESENT	0
380622	380297	14227Q	PARTICIPANT	\N	PRESENT	0
380617	380297	04089T	PARTICIPANT	\N	PRESENT	0
380618	380297	19631V	PARTICIPANT	\N	PRESENT	0
380619	380297	04042C	PARTICIPANT	\N	PRESENT	0
380620	380297	19699S	PARTICIPANT	\N	PRESENT	0
380621	380297	19679N	PARTICIPANT	\N	PRESENT	0
380623	380297	02002K	PARTICIPANT	\N	PRESENT	0
380624	380297	19575F	PARTICIPANT	\N	PRESENT	0
380625	380297	19619A	PARTICIPANT	\N	PRESENT	0
380627	380297	14073Q	PARTICIPANT	\N	PRESENT	0
380628	380297	01028R	PARTICIPANT	\N	PRESENT	0
380629	380297	11049P	PARTICIPANT	\N	PRESENT	0
380630	380297	14089Y	PARTICIPANT	\N	PRESENT	0
380631	380626	19515S	PARTICIPANT	\N	PRESENT	0
380632	380626	19549D	PARTICIPANT	\N	PRESENT	0
380633	380626	14079W	PARTICIPANT	\N	PRESENT	0
380634	380297	19549D	PARTICIPANT	\N	PRESENT	0
380635	380626	19551W	PARTICIPANT	\N	PRESENT	0
380636	380297	19531S	PARTICIPANT	\N	PRESENT	0
380637	380626	14241N	PARTICIPANT	\N	PRESENT	0
380638	380626	14031R	PARTICIPANT	\N	PRESENT	0
380639	380626	19637C	PARTICIPANT	\N	PRESENT	0
380640	380626	19335Q	PARTICIPANT	\N	PRESENT	0
380641	380626	14237S	PARTICIPANT	\N	PRESENT	0
380642	380297	08034U	PARTICIPANT	\N	PRESENT	0
380643	380626	19349W	PARTICIPANT	\N	PRESENT	0
380644	380297	19621T	PARTICIPANT	\N	PRESENT	0
380645	380626	19794Q	PARTICIPANT	\N	PRESENT	0
380646	380626	19737F	PARTICIPANT	\N	PRESENT	0
380647	380297	19583F	PARTICIPANT	\N	PRESENT	0
380648	380297	14034U	PARTICIPANT	\N	PRESENT	0
380649	380297	04061F	PARTICIPANT	\N	PRESENT	0
380650	380297	11070L	PARTICIPANT	\N	PRESENT	0
380651	380297	17589D	PARTICIPANT	\N	PRESENT	0
380652	380626	19347U	PARTICIPANT	\N	PRESENT	0
380653	380297	04097T	PARTICIPANT	\N	PRESENT	0
380654	380297	04035D	PARTICIPANT	\N	PRESENT	0
380655	380297	19687N	PARTICIPANT	\N	PRESENT	0
380656	380297	14239U	PARTICIPANT	\N	PRESENT	0
380665	380663	19543W	PARTICIPANT	\N	PRESENT	0
380658	380297	14038Y	PARTICIPANT	\N	PRESENT	0
380659	380297	19735D	PARTICIPANT	\N	PRESENT	0
380660	380297	04092N	PARTICIPANT	\N	PRESENT	0
380661	380297	05012A	PARTICIPANT	\N	PRESENT	0
380662	380297	19251M	PARTICIPANT	\N	PRESENT	0
380664	380663	14259Y	PARTICIPANT	\N	PRESENT	0
380666	380663	19585H	PARTICIPANT	\N	PRESENT	0
380668	380667	10015M	PARTICIPANT	\N	PRESENT	0
380978	371528	19679N	PARTICIPANT	\N	PRESENT	0
380979	371528	14235Q	PARTICIPANT	\N	PRESENT	0
380980	371528	95030B	PARTICIPANT	\N	PRESENT	0
380981	371528	11101A	PARTICIPANT	\N	PRESENT	0
380982	371528	04035D	PARTICIPANT	\N	PRESENT	0
380983	371528	98024R	PARTICIPANT	\N	PRESENT	0
380984	371528	15447F	PARTICIPANT	\N	PRESENT	0
380985	371528	04071H	PARTICIPANT	\N	PRESENT	0
380986	371528	19515S	PARTICIPANT	\N	PRESENT	0
380987	371528	14026U	PARTICIPANT	\N	PRESENT	0
380988	371528	04033B	PARTICIPANT	\N	PRESENT	0
380989	371528	04044E	PARTICIPANT	\N	PRESENT	0
380990	371528	14053L	PARTICIPANT	\N	PRESENT	0
380991	371528	87003B	PARTICIPANT	\N	PRESENT	0
380992	371528	04092N	PARTICIPANT	\N	PRESENT	0
380993	371528	08010L	PARTICIPANT	\N	PRESENT	0
380994	371528	14105F	PARTICIPANT	\N	PRESENT	0
380995	371528	14187A	PARTICIPANT	\N	PRESENT	0
380996	371528	08018U	PARTICIPANT	\N	PRESENT	0
380997	371528	19741B	PARTICIPANT	\N	PRESENT	0
380998	371528	14169X	PARTICIPANT	\N	PRESENT	0
380999	371528	19794Q	PARTICIPANT	\N	PRESENT	0
381000	371528	19667J	PARTICIPANT	\N	PRESENT	0
381001	371528	14071N	PARTICIPANT	\N	PRESENT	0
381002	371528	19573D	PARTICIPANT	\N	PRESENT	0
381003	371528	14191V	PARTICIPANT	\N	PRESENT	0
381004	371528	19762G	PARTICIPANT	\N	PRESENT	0
381005	371528	14331P	PARTICIPANT	\N	PRESENT	0
381007	371528	04085P	PARTICIPANT	\N	PRESENT	0
381008	371528	10006L	PARTICIPANT	\N	PRESENT	0
381009	371528	19798U	PARTICIPANT	\N	PRESENT	0
381010	371528	11056N	PARTICIPANT	\N	PRESENT	0
381011	371528	11031D	PARTICIPANT	\N	PRESENT	0
381012	371528	19593H	PARTICIPANT	\N	PRESENT	0
381013	371528	95067Q	PARTICIPANT	\N	PRESENT	0
381014	371528	19758L	PARTICIPANT	\N	PRESENT	0
381015	371528	19695N	PARTICIPANT	\N	PRESENT	0
381016	371528	11033F	PARTICIPANT	\N	PRESENT	0
381017	371528	11077T	PARTICIPANT	\N	PRESENT	0
381018	371528	08015R	PARTICIPANT	\N	PRESENT	0
381019	371528	19711U	PARTICIPANT	\N	PRESENT	0
381020	371528	17637T	PARTICIPANT	\N	PRESENT	0
381021	371528	08061X	PARTICIPANT	\N	PRESENT	0
381022	371528	04008A	PARTICIPANT	\N	PRESENT	0
381023	371528	19301E	PARTICIPANT	\N	PRESENT	0
381024	371528	08024S	PARTICIPANT	\N	PRESENT	0
381025	371528	86034E	PARTICIPANT	\N	PRESENT	0
381026	371528	19782L	PARTICIPANT	\N	PRESENT	0
381027	371528	14039A	PARTICIPANT	\N	PRESENT	0
381028	371528	19659J	PARTICIPANT	\N	PRESENT	0
381029	371528	99004R	PARTICIPANT	\N	PRESENT	0
381030	371528	01058X	PARTICIPANT	\N	PRESENT	0
381031	371528	19269X	PARTICIPANT	\N	PRESENT	0
381032	371528	14157T	PARTICIPANT	\N	PRESENT	0
381033	371528	19637C	PARTICIPANT	\N	PRESENT	0
381034	371528	19349W	PARTICIPANT	\N	PRESENT	0
381035	371528	08011M	PARTICIPANT	\N	PRESENT	0
381036	371528	19651A	PARTICIPANT	\N	PRESENT	0
381037	371528	04034C	PARTICIPANT	\N	PRESENT	0
381038	371528	04045F	PARTICIPANT	\N	PRESENT	0
381039	371528	98029W	PARTICIPANT	\N	PRESENT	0
381040	371528	04097T	PARTICIPANT	\N	PRESENT	0
381041	371528	11083R	PARTICIPANT	\N	PRESENT	0
381042	371528	11072N	PARTICIPANT	\N	PRESENT	0
381043	371528	96004D	PARTICIPANT	\N	PRESENT	0
381044	371528	08039A	PARTICIPANT	\N	PRESENT	0
381045	371528	19545Y	PARTICIPANT	\N	PRESENT	0
381046	371528	08020N	PARTICIPANT	\N	PRESENT	0
381047	371528	17589D	PARTICIPANT	\N	PRESENT	0
381048	371528	19583F	PARTICIPANT	\N	PRESENT	0
381049	371528	14195A	PARTICIPANT	\N	PRESENT	0
381050	371528	14123H	PARTICIPANT	\N	PRESENT	0
381051	371528	14251Q	PARTICIPANT	\N	PRESENT	0
381052	371528	04057K	PARTICIPANT	\N	PRESENT	0
381053	371528	08069G	PARTICIPANT	\N	PRESENT	0
381054	371528	19563B	PARTICIPANT	\N	PRESENT	0
381055	371528	08028W	PARTICIPANT	\N	PRESENT	0
381056	371528	01048V	PARTICIPANT	\N	PRESENT	0
381057	371528	14239U	PARTICIPANT	\N	PRESENT	0
381058	371528	11043H	PARTICIPANT	\N	PRESENT	0
381059	371528	02002K	PARTICIPANT	\N	PRESENT	0
381060	371528	14055N	PARTICIPANT	\N	PRESENT	0
381061	371528	01060R	PARTICIPANT	\N	PRESENT	0
363155	356246	89017R	PARTICIPANT	\N	EXCUSE	0
365757	345242	08009T	PARTICIPANT	\N	PRESENT	0
365758	345242	19715Y	PARTICIPANT	\N	PRESENT	0
365759	345242	19503N	PARTICIPANT	\N	PRESENT	0
365760	345242	08068F	PARTICIPANT	\N	PRESENT	0
365761	345242	19333N	PARTICIPANT	\N	PRESENT	0
365762	345242	14051J	PARTICIPANT	\N	PRESENT	0
365763	345242	12016W	PARTICIPANT	\N	PRESENT	0
365764	345242	19525U	PARTICIPANT	\N	PRESENT	0
365765	345242	08055A	PARTICIPANT	\N	PRESENT	0
365766	345242	14063N	PARTICIPANT	\N	PRESENT	0
365767	345242	19637C	PARTICIPANT	\N	PRESENT	0
365768	345242	08024S	PARTICIPANT	\N	PRESENT	0
365769	345242	19782L	PARTICIPANT	\N	PRESENT	0
365770	345242	11065P	PARTICIPANT	\N	PRESENT	0
365771	345242	17589D	PARTICIPANT	\N	PRESENT	0
365772	345242	19251M	PARTICIPANT	\N	PRESENT	0
365773	345242	14042U	PARTICIPANT	\N	PRESENT	0
365774	345242	19737F	PARTICIPANT	\N	PRESENT	0
365775	345242	19611R	PARTICIPANT	\N	PRESENT	0
365776	345242	19347U	PARTICIPANT	\N	PRESENT	0
365777	345242	01025N	PARTICIPANT	\N	PRESENT	0
366989	361770	14038Y	PARTICIPANT	\N	EXCUSE	0
367115	367114	19621T	PARTICIPANT	\N	PRESENT	0
367116	367114	14109K	PARTICIPANT	\N	PRESENT	0
367117	367114	19611R	PARTICIPANT	\N	PRESENT	0
367131	367119	19621T	PARTICIPANT	\N	PRESENT	0
367132	367119	08043V	PARTICIPANT	\N	PRESENT	0
367133	367119	19611R	PARTICIPANT	\N	PRESENT	0
367134	367119	14061L	PARTICIPANT	\N	PRESENT	0
367136	367135	19621T	PARTICIPANT	\N	PRESENT	0
367137	367135	08043V	PARTICIPANT	\N	PRESENT	0
367139	367138	19621T	PARTICIPANT	\N	PRESENT	0
367287	356668	96004D	PARTICIPANT	\N	EXCUSE	0
367289	367258	96004D	PARTICIPANT	\N	EXCUSE	0
367370	367293	08034U	PARTICIPANT	\N	PRESENT	0
367373	358888	04092N	PARTICIPANT	\N	PRESENT	0
367375	367374	04092N	PARTICIPANT	\N	PRESENT	0
367377	367376	04092N	PARTICIPANT	\N	PRESENT	0
367379	367378	04092N	PARTICIPANT	\N	PRESENT	0
367381	367380	04092N	PARTICIPANT	\N	PRESENT	0
367383	367382	04092N	PARTICIPANT	\N	PRESENT	0
367385	367384	04092N	PARTICIPANT	\N	PRESENT	0
367387	367386	04092N	PARTICIPANT	\N	PRESENT	0
367389	367388	04092N	PARTICIPANT	\N	PRESENT	0
367395	367374	14239U	PARTICIPANT	\N	PRESENT	0
367396	367374	19663E	PARTICIPANT	\N	PRESENT	0
367397	367374	19727D	PARTICIPANT	\N	PRESENT	0
367398	367374	19723Y	PARTICIPANT	\N	PRESENT	0
367399	367374	08052W	PARTICIPANT	\N	PRESENT	0
367400	367376	19553Y	PARTICIPANT	\N	PRESENT	0
367401	367376	19663E	PARTICIPANT	\N	PRESENT	0
367402	367376	14042U	PARTICIPANT	\N	PRESENT	0
367403	367376	19691J	PARTICIPANT	\N	PRESENT	0
367404	367376	08052W	PARTICIPANT	\N	PRESENT	0
367405	367376	19723Y	PARTICIPANT	\N	PRESENT	0
370569	370567	14157T	PRESIDENT	0	PRESENT	0
370570	370567	08060W	PARTICIPANT	\N	PRESENT	0
370571	370567	19733B	PARTICIPANT	\N	PRESENT	0
370572	370567	19347U	PARTICIPANT	\N	PRESENT	0
370573	370567	14031R	PARTICIPANT	\N	PRESENT	0
370574	370567	14051J	PARTICIPANT	\N	PRESENT	0
365755	345242	04044E	PARTICIPANT	\N	PRESENT	0
365756	345242	14031R	PARTICIPANT	\N	PRESENT	0
370575	370567	19369B	PARTICIPANT	\N	EXCUSE	0
370576	370567	19762G	PARTICIPANT	\N	EXCUSE	0
370577	370567	14097Y	PARTICIPANT	\N	EXCUSE	0
370578	370567	19715Y	PARTICIPANT	\N	EXCUSE	0
370579	370567	11048N	PARTICIPANT	\N	EXCUSE	0
370580	370567	19745F	PARTICIPANT	\N	EXCUSE	0
370581	370567	19629C	PARTICIPANT	\N	EXCUSE	0
373648	373647	14121F	PARTICIPANT	\N	PRESENT	0
373650	373649	08011M	PARTICIPANT	\N	PRESENT	0
373653	373652	08011M	PARTICIPANT	\N	PRESENT	0
373654	373652	19711U	PARTICIPANT	\N	PRESENT	0
373655	373652	19479G	PARTICIPANT	\N	PRESENT	0
373657	373656	08011M	PARTICIPANT	\N	PRESENT	0
373658	373656	19711U	PARTICIPANT	\N	PRESENT	0
373659	373656	19479G	PARTICIPANT	\N	PRESENT	0
373661	373660	14121F	PARTICIPANT	\N	PRESENT	0
383136	373731	11067R	PARTICIPANT	\N	PRESENT	0
384525	382857	19349W	PARTICIPANT	\N	PRESENT	0
384526	371543	11031D	PARTICIPANT	\N	PRESENT	0
384527	382858	19347U	PARTICIPANT	\N	PRESENT	0
384528	382858	19794Q	PARTICIPANT	\N	PRESENT	0
384529	382858	19737F	PARTICIPANT	\N	PRESENT	0
384530	371543	14205J	PARTICIPANT	\N	PRESENT	0
384531	371543	14147R	PARTICIPANT	\N	PRESENT	0
384532	371543	14087W	PARTICIPANT	\N	PRESENT	0
384533	371543	14217N	PARTICIPANT	\N	PRESENT	0
384569	377904	14195A	PARTICIPANT	\N	PRESENT	0
384570	377904	14083S	PARTICIPANT	\N	PRESENT	0
384571	377904	14089Y	PARTICIPANT	\N	PRESENT	0
384572	377904	01024M	PARTICIPANT	\N	PRESENT	0
384573	377904	14087W	PARTICIPANT	\N	PRESENT	0
384574	377904	14026U	PARTICIPANT	\N	PRESENT	0
384575	377904	14217N	PARTICIPANT	\N	PRESENT	0
384576	377904	95030B	PARTICIPANT	\N	PRESENT	0
384577	377904	19701S	PARTICIPANT	\N	PRESENT	0
384578	377904	11033F	PARTICIPANT	\N	PRESENT	0
384579	377904	11099A	PARTICIPANT	\N	PRESENT	0
384580	377904	11031D	PARTICIPANT	\N	PRESENT	0
384582	377904	19399H	PARTICIPANT	\N	PRESENT	0
384583	377904	11045K	PARTICIPANT	\N	PRESENT	0
384587	377904	11067R	PARTICIPANT	\N	PRESENT	0
384599	377904	14237S	PARTICIPANT	\N	PRESENT	0
384605	377904	19253P	PARTICIPANT	\N	PRESENT	0
384606	377904	19629C	PARTICIPANT	\N	PRESENT	0
384607	377904	19647E	PARTICIPANT	\N	PRESENT	0
384608	377904	98050T	PARTICIPANT	\N	PRESENT	0
384609	377904	19794Q	PARTICIPANT	\N	PRESENT	0
384610	377904	08031R	PARTICIPANT	\N	PRESENT	0
384611	377904	19691J	PARTICIPANT	\N	PRESENT	0
384612	377904	14255U	PARTICIPANT	\N	PRESENT	0
384617	377904	11064N	PARTICIPANT	\N	PRESENT	0
384624	377904	14033T	PARTICIPANT	\N	PRESENT	0
384683	380333	19369B	PARTICIPANT	\N	EXCUSE	0
384686	380333	19647E	PARTICIPANT	\N	EXCUSE	0
384707	384208	14195A	PARTICIPANT	\N	EXCUSE	0
384708	380333	19399H	PARTICIPANT	\N	EXCUSE	0
384709	380333	19479G	PARTICIPANT	\N	PRESENT	0
384728	384727	19575F	PARTICIPANT	\N	EXCUSE	0
384729	384727	08068F	PARTICIPANT	\N	EXCUSE	0
384567	377904	11027H	PARTICIPANT	\N	PRESENT	0
384568	377904	08017T	PARTICIPANT	\N	PRESENT	0
384730	384727	19782L	PARTICIPANT	\N	EXCUSE	0
384731	384727	19599P	PARTICIPANT	\N	EXCUSE	0
384732	384727	14073Q	PARTICIPANT	\N	EXCUSE	0
384733	384727	07029T	PARTICIPANT	\N	EXCUSE	0
384734	384727	14265W	PARTICIPANT	\N	EXCUSE	0
384735	384727	19713W	PARTICIPANT	\N	EXCUSE	0
384736	384727	01043Q	PARTICIPANT	\N	PRESENT	0
384737	384727	19563B	PRESIDENT	0	PRESENT	0
384738	384727	14237S	PARTICIPANT	\N	PRESENT	0
384739	384727	19503N	PARTICIPANT	\N	PRESENT	0
384740	384727	95067Q	PARTICIPANT	\N	PRESENT	0
384741	380333	19349W	PARTICIPANT	\N	EXCUSE	0
384742	380333	19667J	PARTICIPANT	\N	EXCUSE	0
384743	380333	19713W	PARTICIPANT	\N	EXCUSE	0
384771	384770	14331P	PARTICIPANT	\N	PRESENT	0
384774	384773	04049K	PARTICIPANT	\N	PRESENT	0
384775	384773	08015R	PARTICIPANT	\N	PRESENT	0
384776	384773	14105F	PARTICIPANT	\N	PRESENT	0
384777	384773	14083S	PARTICIPANT	\N	PRESENT	0
384778	384773	19521Q	PARTICIPANT	\N	PRESENT	0
384779	384773	19591F	PARTICIPANT	\N	PRESENT	0
384780	384773	19671E	PARTICIPANT	\N	PRESENT	0
384781	384773	04088S	PARTICIPANT	\N	PRESENT	0
384782	384773	14213J	PARTICIPANT	\N	PRESENT	0
384783	384773	14159V	PARTICIPANT	\N	PRESENT	0
384821	380333	08012N	PARTICIPANT	\N	PRESENT	0
384830	384829	04049K	PARTICIPANT	\N	PRESENT	0
384832	384829	08015R	PARTICIPANT	\N	PRESENT	0
384833	384829	14105F	PARTICIPANT	\N	PRESENT	0
384834	384829	14083S	PARTICIPANT	\N	PRESENT	0
384835	384829	19521Q	PARTICIPANT	\N	PRESENT	0
384836	384829	19591F	PARTICIPANT	\N	PRESENT	0
384837	384829	19671E	PARTICIPANT	\N	PRESENT	0
384838	384829	04088S	PARTICIPANT	\N	PRESENT	0
384839	384829	08060W	PARTICIPANT	\N	PRESENT	0
384840	384829	08058D	PARTICIPANT	\N	PRESENT	0
384880	384208	19565D	PARTICIPANT	\N	EXCUSE	0
385259	385258	14227Q	PARTICIPANT	\N	PRESENT	0
385261	385260	98029W	PARTICIPANT	\N	PRESENT	0
385262	385260	04040A	PARTICIPANT	\N	PRESENT	0
385364	385363	11043H	PARTICIPANT	\N	PRESENT	0
385365	385363	08012N	PARTICIPANT	\N	PRESENT	0
385366	385363	14073Q	PARTICIPANT	\N	PRESENT	0
385367	385363	19758L	PARTICIPANT	\N	PRESENT	0
386831	382859	14093U	PARTICIPANT	\N	PRESENT	0
386832	382859	80013X	PARTICIPANT	\N	PRESENT	0
386834	382859	01048V	PRESIDENT	0	PRESENT	0
386837	382859	19503N	PARTICIPANT	\N	PRESENT	0
386841	382859	04043D	PARTICIPANT	\N	PRESENT	0
386843	382859	01058X	PARTICIPANT	\N	PRESENT	0
386846	382859	19693L	PARTICIPANT	\N	EXCUSE	0
386847	382859	19723Y	PARTICIPANT	\N	EXCUSE	0
386944	386943	19782L	PARTICIPANT	\N	PRESENT	0
386945	386943	19711U	PARTICIPANT	\N	PRESENT	0
386946	386943	01043Q	PARTICIPANT	\N	PRESENT	0
386947	386943	19563B	PRESIDENT	0	PRESENT	0
386948	386943	19585H	PARTICIPANT	\N	PRESENT	0
386950	386943	19681G	PARTICIPANT	\N	EXCUSE	0
386951	386943	07029T	PARTICIPANT	\N	EXCUSE	0
387196	387195	19667J	PARTICIPANT	\N	PRESENT	0
387198	387195	19467C	PARTICIPANT	\N	PRESENT	0
390920	388119	19731Y	PARTICIPANT	\N	PRESENT	0
390921	388119	19747H	PARTICIPANT	\N	PRESENT	0
390922	388119	17637T	PARTICIPANT	\N	PRESENT	0
390923	388119	04043D	PARTICIPANT	\N	PRESENT	0
390924	388119	14065Q	PARTICIPANT	\N	PRESENT	0
390925	388119	19543W	PARTICIPANT	\N	PRESENT	0
390926	388119	19295A	PARTICIPANT	\N	PRESENT	0
390927	388119	19553Y	PARTICIPANT	\N	PRESENT	0
390928	388119	11067R	PARTICIPANT	\N	PRESENT	0
390929	388119	19527W	PARTICIPANT	\N	PRESENT	0
390930	388119	19705W	PARTICIPANT	\N	PRESENT	0
390931	388119	14121F	PARTICIPANT	\N	PRESENT	0
390932	388119	98029W	PARTICIPANT	\N	PRESENT	0
390933	388119	02002K	PARTICIPANT	\N	PRESENT	0
390934	388119	95041E	PARTICIPANT	\N	PRESENT	0
390935	388119	14197C	PARTICIPANT	\N	PRESENT	0
390936	388119	19687N	PARTICIPANT	\N	PRESENT	0
390937	388119	14069U	PARTICIPANT	\N	PRESENT	0
390938	388119	08035V	PARTICIPANT	\N	PRESENT	0
390939	388119	14281W	PARTICIPANT	\N	PRESENT	0
390940	388119	08043V	PARTICIPANT	\N	PRESENT	0
390941	388119	11066Q	PARTICIPANT	\N	PRESENT	0
390942	388119	19387D	PARTICIPANT	\N	PRESENT	0
390943	388119	14355X	PARTICIPANT	\N	PRESENT	0
390944	388119	11056N	PARTICIPANT	\N	PRESENT	0
390945	388119	19591F	PARTICIPANT	\N	PRESENT	0
390946	388119	19269X	PARTICIPANT	\N	PRESENT	0
390947	388119	11083R	PARTICIPANT	\N	PRESENT	0
390949	390948	96004D	PRESIDENT	0	PRESENT	0
390950	390948	14089Y	PARTICIPANT	\N	PRESENT	0
390951	390948	14357A	PARTICIPANT	\N	PRESENT	0
390952	390948	04035D	PARTICIPANT	\N	PRESENT	0
390953	390948	19569H	PARTICIPANT	\N	PRESENT	0
390954	390948	04097T	PARTICIPANT	\N	PRESENT	0
390955	390948	14097Y	PARTICIPANT	\N	PRESENT	0
390956	390948	04057K	PARTICIPANT	\N	EXCUSE	0
390957	390948	98035U	PARTICIPANT	\N	PRESENT	0
390958	390948	10015M	PARTICIPANT	\N	EXCUSE	0
390959	390948	14331P	PARTICIPANT	\N	PRESENT	0
390960	390948	19563B	PARTICIPANT	\N	PRESENT	0
390961	390948	14249W	PARTICIPANT	\N	PRESENT	0
390962	390948	14241N	PARTICIPANT	\N	PRESENT	0
390963	390948	14073Q	PARTICIPANT	\N	PRESENT	0
390964	388119	14109K	PARTICIPANT	\N	PRESENT	0
390965	388119	08018U	PARTICIPANT	\N	PRESENT	0
390966	388119	04038G	PARTICIPANT	\N	PRESENT	0
390968	388119	14038Y	PARTICIPANT	\N	PRESENT	0
390970	388119	19511N	PARTICIPANT	\N	PRESENT	0
390971	388119	19695N	PARTICIPANT	\N	PRESENT	0
390973	390972	19545Y	PARTICIPANT	\N	PRESENT	0
390974	390972	19689Q	PARTICIPANT	\N	PRESENT	0
390976	390975	19531S	PARTICIPANT	\N	PRESENT	0
390978	390977	19531S	PARTICIPANT	\N	PRESENT	0
390983	390982	19531S	PARTICIPANT	\N	PRESENT	0
390985	390984	11074Q	PARTICIPANT	\N	PRESENT	0
390986	390984	08011M	PARTICIPANT	\N	PRESENT	0
390988	390987	14121F	PARTICIPANT	\N	PRESENT	0
390990	390989	14121F	PARTICIPANT	\N	PRESENT	0
391241	377995	11070L	PARTICIPANT	\N	PRESENT	0
391242	390979	19725B	PARTICIPANT	\N	PRESENT	0
391243	390979	10015M	PARTICIPANT	\N	PRESENT	0
391244	390979	14069U	PARTICIPANT	\N	PRESENT	0
391245	390979	01024M	PARTICIPANT	\N	PRESENT	0
391246	390979	14215L	PRESIDENT	0	PRESENT	0
391247	390979	19719D	PARTICIPANT	\N	PRESENT	0
391248	390979	19447X	PARTICIPANT	\N	PRESENT	0
391249	390979	19729F	PARTICIPANT	\N	EXCUSE	0
391250	390979	04044E	PARTICIPANT	\N	EXCUSE	0
391252	377995	14215L	PARTICIPANT	\N	PRESENT	0
391253	377995	14069U	PARTICIPANT	\N	PRESENT	0
391254	377995	04038G	PARTICIPANT	\N	PRESENT	0
391255	377995	19725B	PARTICIPANT	\N	PRESENT	0
391256	377995	19543W	PARTICIPANT	\N	PRESENT	0
391257	377995	19545Y	PARTICIPANT	\N	PRESENT	0
391258	377995	19253P	PARTICIPANT	\N	PRESENT	0
391259	377995	11012A	PARTICIPANT	\N	PRESENT	0
391260	377995	14231L	PARTICIPANT	\N	PRESENT	0
391261	377995	14267Y	PARTICIPANT	\N	PRESENT	0
391262	377995	19719D	PARTICIPANT	\N	PRESENT	0
391263	377995	19731Y	PARTICIPANT	\N	PRESENT	0
391264	377995	14265W	PARTICIPANT	\N	PRESENT	0
391265	377995	14133K	PARTICIPANT	\N	PRESENT	0
391266	377995	19794Q	PARTICIPANT	\N	PRESENT	0
391267	377995	19447X	PARTICIPANT	\N	PRESENT	0
391268	377995	19673G	PARTICIPANT	\N	PRESENT	0
391269	377995	14034U	PARTICIPANT	\N	PRESENT	0
391270	377995	19629C	PARTICIPANT	\N	PRESENT	0
391271	377995	19399H	PARTICIPANT	\N	PRESENT	0
391272	377995	19527W	PARTICIPANT	\N	PRESENT	0
391273	377995	01024M	PARTICIPANT	\N	PRESENT	0
391274	377995	19467C	PARTICIPANT	\N	PRESENT	0
391275	377995	11031D	PARTICIPANT	\N	PRESENT	0
391276	377995	19737F	PARTICIPANT	\N	PRESENT	0
391277	377995	14053L	PARTICIPANT	\N	PRESENT	0
391278	377995	19747H	PARTICIPANT	\N	PRESENT	0
391279	377995	19387D	PARTICIPANT	\N	PRESENT	0
391280	377995	19762G	PARTICIPANT	\N	PRESENT	0
391281	377995	19741B	PARTICIPANT	\N	PRESENT	0
391282	377995	11040E	PARTICIPANT	\N	PRESENT	0
391283	377995	01028R	PARTICIPANT	\N	PRESENT	0
391284	377995	98050T	PARTICIPANT	\N	PRESENT	0
391285	377995	19713W	PARTICIPANT	\N	PRESENT	0
391289	377995	19691J	PARTICIPANT	\N	PRESENT	0
391292	391291	96004D	PARTICIPANT	\N	PRESENT	0
391293	391291	14255U	PARTICIPANT	\N	PRESENT	0
391294	391291	04042C	PARTICIPANT	\N	PRESENT	0
391295	391291	04035D	PARTICIPANT	\N	PRESENT	0
391305	391304	14215L	PARTICIPANT	\N	PRESENT	0
391306	391304	14179A	PARTICIPANT	\N	PRESENT	0
391310	391309	19705W	PARTICIPANT	\N	PRESENT	0
391311	391309	19369B	PARTICIPANT	\N	PRESENT	0
391312	391309	19515S	PARTICIPANT	\N	PRESENT	0
391318	391317	08043V	PARTICIPANT	\N	PRESENT	0
391319	391317	19621T	PARTICIPANT	\N	PRESENT	0
391320	391317	19758L	PARTICIPANT	\N	PRESENT	0
391321	391317	19693L	PARTICIPANT	\N	PRESENT	0
391322	391317	14123H	PARTICIPANT	\N	PRESENT	0
391336	391334	19735D	PARTICIPANT	\N	PRESENT	0
391324	391317	08031R	PARTICIPANT	\N	PRESENT	0
391325	391317	19611R	PARTICIPANT	\N	PRESENT	0
391326	391317	14109K	PARTICIPANT	\N	PRESENT	0
391327	391317	04070G	PRESIDENT	0	PRESENT	0
391328	391317	14071N	PARTICIPANT	\N	PRESENT	0
391329	391317	19573D	PARTICIPANT	\N	PRESENT	0
391330	391317	19533U	PARTICIPANT	\N	PRESENT	0
391331	391317	14229S	PARTICIPANT	\N	PRESENT	0
391335	391334	14039A	PARTICIPANT	\N	PRESENT	0
391337	391334	19749K	PARTICIPANT	\N	PRESENT	0
391339	391338	14039A	PARTICIPANT	\N	PRESENT	0
391340	391338	19735D	PARTICIPANT	\N	PRESENT	0
391342	391341	14038Y	PARTICIPANT	\N	PRESENT	0
391343	391341	19333N	PARTICIPANT	\N	PRESENT	0
391344	391341	14169X	PARTICIPANT	\N	PRESENT	0
391345	391341	08039A	PARTICIPANT	\N	PRESENT	0
391346	391341	04043D	PARTICIPANT	\N	PRESENT	0
391347	391341	14229S	PARTICIPANT	\N	PRESENT	0
391348	391341	19749K	PARTICIPANT	\N	PRESENT	0
391350	391349	11053K	PARTICIPANT	\N	PRESENT	0
391352	391351	19399H	PARTICIPANT	\N	PRESENT	0
391353	391351	11109J	PARTICIPANT	\N	PRESENT	0
391387	385081	04038G	PARTICIPANT	\N	EXCUSE	0
391389	391388	14261S	PARTICIPANT	\N	EXCUSE	0
391390	391388	19329S	PARTICIPANT	\N	EXCUSE	0
391391	391388	14331P	PARTICIPANT	\N	EXCUSE	0
391392	385081	19647E	PARTICIPANT	\N	EXCUSE	0
391394	391393	11053K	PARTICIPANT	\N	PRESENT	0
366856	357444	80013X	PARTICIPANT	\N	EXCUSE	0
367328	361762	96004D	PRESIDENT	0	PRESENT	0
367329	361762	14079W	PARTICIPANT	\N	PRESENT	0
367330	361762	19569H	PARTICIPANT	\N	PRESENT	0
367331	361762	14097Y	PARTICIPANT	\N	PRESENT	0
367332	361762	14089Y	PARTICIPANT	\N	PRESENT	0
367333	361762	14073Q	PARTICIPANT	\N	PRESENT	0
367334	361762	04057K	PARTICIPANT	\N	PRESENT	0
367335	361762	19593H	PARTICIPANT	\N	PRESENT	0
367336	361762	14135M	PARTICIPANT	\N	PRESENT	0
367337	361762	14331P	PARTICIPANT	\N	PRESENT	0
367338	361762	14225N	PARTICIPANT	\N	PRESENT	0
367339	361762	10015M	PARTICIPANT	\N	PRESENT	0
367340	361762	11026G	PARTICIPANT	\N	PRESENT	0
367341	361762	14065Q	PARTICIPANT	\N	EXCUSE	0
367342	361762	14357A	PARTICIPANT	\N	EXCUSE	0
367343	361762	04097T	PARTICIPANT	\N	EXCUSE	0
371265	369086	11031D	PARTICIPANT	\N	PRESENT	0
371255	369086	19565D	PARTICIPANT	\N	PRESENT	0
371256	369086	14026U	PARTICIPANT	\N	PRESENT	0
371257	369086	14239U	PARTICIPANT	\N	PRESENT	0
371258	369086	14087W	PARTICIPANT	\N	PRESENT	0
371259	369086	19367Y	PARTICIPANT	\N	PRESENT	0
371260	369086	14213J	PARTICIPANT	\N	PRESENT	0
371261	369086	19577H	PARTICIPANT	\N	PRESENT	0
371262	369086	14223L	PARTICIPANT	\N	PRESENT	0
371263	369086	14119M	PARTICIPANT	\N	PRESENT	0
371264	369086	19727D	PARTICIPANT	\N	PRESENT	0
371266	369086	14042U	PARTICIPANT	\N	PRESENT	0
371267	369086	14281W	PARTICIPANT	\N	PRESENT	0
371268	369086	04045F	PARTICIPANT	\N	PRESENT	0
371269	369086	19703U	PARTICIPANT	\N	PRESENT	0
371270	369086	19760E	PARTICIPANT	\N	PRESENT	0
371337	370534	19681G	PARTICIPANT	\N	PRESENT	0
371398	370534	14093U	PARTICIPANT	\N	PRESENT	0
371399	369691	04035D	PARTICIPANT	\N	PRESENT	0
371400	369691	95067Q	PARTICIPANT	\N	PRESENT	0
371401	369691	12041X	PARTICIPANT	\N	PRESENT	0
371402	369691	95037J	PARTICIPANT	\N	PRESENT	0
371403	369691	14105F	PARTICIPANT	\N	PRESENT	0
371404	369691	19421M	PARTICIPANT	\N	PRESENT	0
371416	369691	11027H	PARTICIPANT	\N	PRESENT	0
371417	369691	98022P	PARTICIPANT	\N	PRESENT	0
371418	369842	11053K	PARTICIPANT	\N	PRESENT	0
371419	369842	19689Q	PARTICIPANT	\N	PRESENT	0
371420	369842	14173T	PARTICIPANT	\N	PRESENT	0
371629	371214	19581D	PARTICIPANT	\N	PRESENT	0
371630	371214	04047H	PARTICIPANT	0	PRESENT	0
371631	371214	19673G	PARTICIPANT	\N	PRESENT	0
371632	371214	19675J	PARTICIPANT	\N	PRESENT	0
371633	371214	01028R	PARTICIPANT	\N	PRESENT	0
371634	371214	19447X	PARTICIPANT	\N	PRESENT	0
371635	371214	05008E	PRESIDENT	0	PRESENT	0
371636	371214	14231L	PARTICIPANT	\N	PRESENT	0
371637	371214	19489J	PARTICIPANT	\N	PRESENT	0
371638	371214	14275Y	PARTICIPANT	\N	PRESENT	0
371639	371214	14151M	PARTICIPANT	\N	PRESENT	0
371640	371214	14215L	PARTICIPANT	\N	PRESENT	0
371641	371214	11072N	PARTICIPANT	\N	PRESENT	0
371642	371214	14053L	PARTICIPANT	\N	PRESENT	0
371643	371214	19649G	PARTICIPANT	\N	PRESENT	0
371644	371214	14111D	PARTICIPANT	\N	PRESENT	0
371645	371214	01024M	PARTICIPANT	\N	PRESENT	0
371646	371214	19719D	PARTICIPANT	\N	PRESENT	0
371647	371214	11033F	PARTICIPANT	\N	PRESENT	0
371648	371214	14089Y	PARTICIPANT	\N	PRESENT	0
371649	371214	19725B	PARTICIPANT	\N	PRESENT	0
371650	371214	95063L	PARTICIPANT	\N	PRESENT	0
371651	371214	19629C	PARTICIPANT	\N	PRESENT	0
371652	371214	11049P	PARTICIPANT	\N	PRESENT	0
371653	371214	19762G	PARTICIPANT	\N	PRESENT	0
371654	371214	98035U	PARTICIPANT	\N	PRESENT	0
371655	371214	08045X	PARTICIPANT	\N	PRESENT	0
371656	371214	19253P	PARTICIPANT	\N	PRESENT	0
371657	371214	01060R	PARTICIPANT	\N	PRESENT	0
371658	371214	19543W	PARTICIPANT	\N	PRESENT	0
371659	371214	19585H	PARTICIPANT	\N	PRESENT	0
371660	371214	19729F	PARTICIPANT	\N	PRESENT	0
371661	371214	14147R	PARTICIPANT	\N	PRESENT	0
371662	371214	14069U	PARTICIPANT	\N	PRESENT	0
371663	371214	11085T	PARTICIPANT	\N	PRESENT	0
371664	371214	08018U	PARTICIPANT	\N	PRESENT	0
371665	371214	04008A	PARTICIPANT	\N	PRESENT	0
371666	371214	14259Y	PARTICIPANT	\N	PRESENT	0
371667	371214	14021P	PARTICIPANT	\N	PRESENT	0
371668	371214	14065Q	PARTICIPANT	\N	EXCUSE	0
371669	371214	04044E	PARTICIPANT	\N	EXCUSE	0
371678	369842	14034U	PARTICIPANT	\N	PRESENT	0
371682	356312	11027H	PARTICIPANT	\N	PRESENT	0
371683	356312	14191V	PARTICIPANT	\N	PRESENT	0
371684	356312	19447X	PARTICIPANT	\N	PRESENT	0
371685	356312	11065P	PARTICIPANT	\N	PRESENT	0
371686	356312	19333N	PARTICIPANT	\N	PRESENT	0
371687	356312	14223L	PARTICIPANT	\N	PRESENT	0
371688	356312	19701S	PARTICIPANT	\N	PRESENT	0
371689	356312	19583F	PARTICIPANT	\N	PRESENT	0
371690	356312	19399H	PARTICIPANT	\N	PRESENT	0
371691	356312	11041F	PARTICIPANT	\N	PRESENT	0
371692	356312	19549D	PARTICIPANT	\N	PRESENT	0
371723	356312	80027E	PARTICIPANT	\N	PRESENT	0
371694	356312	08009T	PARTICIPANT	\N	PRESENT	0
371695	356312	14103D	PARTICIPANT	\N	PRESENT	0
371696	356312	14329V	PARTICIPANT	\N	PRESENT	0
371697	356312	08061X	PARTICIPANT	\N	PRESENT	0
371698	356312	04089T	PARTICIPANT	\N	PRESENT	0
371699	356312	19387D	PARTICIPANT	\N	PRESENT	0
371700	356312	14093U	PARTICIPANT	\N	PRESENT	0
371701	356312	19737F	PARTICIPANT	\N	PRESENT	0
371702	356312	14089Y	PARTICIPANT	\N	PRESENT	0
371703	356312	19739H	PARTICIPANT	\N	PRESENT	0
371704	356312	08062Y	PARTICIPANT	\N	PRESENT	0
371705	356312	14111D	PARTICIPANT	\N	PRESENT	0
371706	356312	14207L	PARTICIPANT	\N	PRESENT	0
371707	356312	19515S	PARTICIPANT	\N	PRESENT	0
371708	356312	19794Q	PARTICIPANT	\N	PRESENT	0
371709	356312	18083K	PARTICIPANT	\N	PRESENT	0
371710	356312	87003B	PARTICIPANT	\N	PRESENT	0
371711	356312	01057W	PARTICIPANT	\N	PRESENT	0
371712	356312	14211G	PARTICIPANT	\N	PRESENT	0
371720	356312	19503N	PARTICIPANT	\N	PRESENT	0
371714	356312	04018C	PARTICIPANT	\N	PRESENT	0
371715	356312	11103C	PARTICIPANT	\N	PRESENT	0
371716	356312	14157T	PARTICIPANT	\N	PRESENT	0
371717	356312	19675J	PARTICIPANT	\N	PRESENT	0
371718	356312	14357A	PARTICIPANT	\N	PRESENT	0
371719	356312	95030B	PARTICIPANT	\N	PRESENT	0
371721	356312	19599P	PARTICIPANT	\N	PRESENT	0
371722	356312	14039A	PARTICIPANT	\N	PRESENT	0
371724	356312	19659J	PARTICIPANT	\N	PRESENT	0
371725	356312	14083S	PARTICIPANT	\N	PRESENT	0
371726	356312	14119M	PARTICIPANT	\N	PRESENT	0
371727	356312	14205J	PARTICIPANT	\N	PRESENT	0
371728	356312	14197C	PARTICIPANT	\N	PRESENT	0
371729	356312	19347U	PARTICIPANT	\N	PRESENT	0
371730	356312	14169X	PARTICIPANT	\N	PRESENT	0
371731	356312	14051J	PARTICIPANT	\N	PRESENT	0
371732	356312	14261S	PARTICIPANT	\N	PRESENT	0
371733	356312	19681G	PARTICIPANT	\N	PRESENT	0
371734	356312	19441R	PARTICIPANT	\N	PRESENT	0
371735	356312	19585H	PARTICIPANT	\N	PRESENT	0
371736	356312	14123H	PARTICIPANT	\N	PRESENT	0
371737	356312	98005N	PARTICIPANT	\N	PRESENT	0
371738	356312	11066Q	PARTICIPANT	\N	PRESENT	0
371739	356312	11056N	PARTICIPANT	\N	PRESENT	0
371740	356312	08028W	PARTICIPANT	\N	PRESENT	0
371741	356312	01025N	PARTICIPANT	\N	PRESENT	0
371742	356312	19679N	PARTICIPANT	\N	PRESENT	0
371743	356312	14033T	PARTICIPANT	\N	PRESENT	0
371744	356312	14069U	PARTICIPANT	\N	PRESENT	0
371745	356312	95063L	PARTICIPANT	\N	PRESENT	0
371746	356312	14215L	PARTICIPANT	\N	PRESENT	0
371747	356312	19768N	PARTICIPANT	\N	PRESENT	0
371751	356312	19415P	PARTICIPANT	\N	PRESENT	0
371749	356312	19467C	PARTICIPANT	\N	PRESENT	0
371750	356312	08060W	PARTICIPANT	\N	PRESENT	0
371752	356312	95062K	PARTICIPANT	\N	PRESENT	0
371753	356312	19563B	PARTICIPANT	\N	PRESENT	0
371754	356312	19719D	PARTICIPANT	\N	PRESENT	0
371755	356312	14038Y	PARTICIPANT	\N	PRESENT	0
371756	356312	14221J	PARTICIPANT	\N	PRESENT	0
371757	356312	19253P	PARTICIPANT	\N	PRESENT	0
371758	356312	08038Y	PARTICIPANT	\N	PRESENT	0
371759	356312	19569H	PARTICIPANT	\N	PRESENT	0
371761	369841	14327T	PARTICIPANT	\N	PRESENT	0
371762	369841	11040E	PARTICIPANT	\N	PRESENT	0
371763	369841	19479G	PARTICIPANT	\N	PRESENT	0
381062	371528	14223L	PARTICIPANT	\N	PRESENT	0
381063	371528	14261S	PARTICIPANT	\N	PRESENT	0
381064	371528	14207L	PARTICIPANT	\N	PRESENT	0
381065	371528	19643A	PARTICIPANT	\N	PRESENT	0
381066	371528	19553Y	PARTICIPANT	\N	PRESENT	0
381067	371528	04042C	PARTICIPANT	\N	PRESENT	0
381068	371528	08019V	PARTICIPANT	\N	PRESENT	0
381069	371528	14241N	PARTICIPANT	\N	PRESENT	0
381070	371528	14107H	PARTICIPANT	\N	PRESENT	0
381071	371528	11099A	PARTICIPANT	\N	PRESENT	0
381072	371528	14259Y	PARTICIPANT	\N	PRESENT	0
381073	371528	19717B	PARTICIPANT	\N	PRESENT	0
381074	371528	01057W	PARTICIPANT	\N	PRESENT	0
381075	371528	19253P	PARTICIPANT	\N	PRESENT	0
381076	371528	14135M	PARTICIPANT	\N	PRESENT	0
381077	371528	14201E	PARTICIPANT	\N	PRESENT	0
381078	371528	19719D	PARTICIPANT	\N	PRESENT	0
381079	371528	11049P	PARTICIPANT	\N	PRESENT	0
381080	371528	19681G	PARTICIPANT	\N	PRESENT	0
381081	371528	19629C	PARTICIPANT	\N	PRESENT	0
381082	371528	08049C	PARTICIPANT	\N	PRESENT	0
381083	371528	88008L	PARTICIPANT	\N	PRESENT	0
381084	371528	11090Q	PARTICIPANT	\N	PRESENT	0
381085	371528	14034U	PARTICIPANT	\N	PRESENT	0
381086	371528	04043D	PARTICIPANT	\N	PRESENT	0
381087	371528	08031R	PARTICIPANT	\N	PRESENT	0
381088	371528	11012A	PARTICIPANT	\N	PRESENT	0
381089	371528	11048N	PARTICIPANT	\N	PRESENT	0
381090	371528	95037J	PARTICIPANT	\N	PRESENT	0
381091	371528	14253S	PARTICIPANT	\N	PRESENT	0
381092	371528	19329S	PARTICIPANT	\N	PRESENT	0
381093	371528	19575F	PARTICIPANT	\N	PRESENT	0
381094	371528	14199E	PARTICIPANT	\N	PRESENT	0
381095	371528	14031R	PARTICIPANT	\N	PRESENT	0
381096	371528	04059M	PARTICIPANT	\N	PRESENT	0
381097	371528	14173T	PARTICIPANT	\N	PRESENT	0
381098	371528	19703U	PARTICIPANT	\N	PRESENT	0
381099	371528	11074Q	PARTICIPANT	\N	PRESENT	0
381100	371528	19251M	PARTICIPANT	\N	PRESENT	0
381101	371528	14133K	PARTICIPANT	\N	PRESENT	0
381102	371528	19551W	PARTICIPANT	\N	PRESENT	0
381103	371528	11109J	PARTICIPANT	\N	PRESENT	0
381104	371528	14115H	PARTICIPANT	\N	PRESENT	0
381105	371528	19503N	PARTICIPANT	\N	PRESENT	0
381106	371528	11067R	PARTICIPANT	\N	PRESENT	0
381107	371528	08047A	PARTICIPANT	\N	PRESENT	0
381108	371528	08053X	PARTICIPANT	\N	PRESENT	0
381109	371528	17583W	PARTICIPANT	\N	PRESENT	0
381110	371528	19527W	PARTICIPANT	\N	PRESENT	0
381111	371528	14063N	PARTICIPANT	\N	PRESENT	0
381112	371528	95041E	PARTICIPANT	\N	PRESENT	0
381113	371528	19631V	PARTICIPANT	\N	PRESENT	0
381114	371528	14147R	PARTICIPANT	\N	PRESENT	0
381115	371528	14159V	PARTICIPANT	\N	PRESENT	0
381116	371528	14265W	PARTICIPANT	\N	PRESENT	0
381117	371528	19549D	PARTICIPANT	\N	PRESENT	0
381118	371528	19725B	PARTICIPANT	\N	PRESENT	0
381119	371528	08048B	PARTICIPANT	\N	PRESENT	0
381120	371528	08014Q	PARTICIPANT	\N	PRESENT	0
381121	371528	19399H	PARTICIPANT	\N	PRESENT	0
381122	371528	19333N	PARTICIPANT	\N	PRESENT	0
381123	371528	14001X	PARTICIPANT	\N	PRESENT	0
381124	371528	14033T	PARTICIPANT	\N	PRESENT	0
381125	371528	14227Q	PARTICIPANT	\N	PRESENT	0
381126	371528	19683J	PARTICIPANT	\N	PRESENT	0
381127	371528	19415P	PARTICIPANT	\N	PRESENT	0
381128	371528	19295A	PARTICIPANT	\N	PRESENT	0
381129	371528	18083K	PARTICIPANT	\N	PRESENT	0
381130	371528	19467C	PARTICIPANT	\N	PRESENT	0
381131	371528	11054L	PARTICIPANT	\N	PRESENT	0
381132	371528	19507S	PARTICIPANT	\N	PRESENT	0
381133	371528	19489J	PARTICIPANT	\N	PRESENT	0
381134	371528	11097X	PARTICIPANT	\N	PRESENT	0
381135	371528	17779H	PARTICIPANT	\N	PRESENT	0
381136	371528	19723Y	PARTICIPANT	\N	PRESENT	0
381137	371528	08058D	PARTICIPANT	\N	PRESENT	0
381138	371528	11026G	PARTICIPANT	\N	PRESENT	0
381139	371528	14038Y	PARTICIPANT	\N	PRESENT	0
381140	371528	19443T	PARTICIPANT	\N	PRESENT	0
381141	371528	14121F	PARTICIPANT	\N	PRESENT	0
381142	371528	14085U	PARTICIPANT	\N	PRESENT	0
381143	371528	14029X	PARTICIPANT	\N	PRESENT	0
381144	371528	80027E	PARTICIPANT	\N	PRESENT	0
381145	371528	19663E	PARTICIPANT	\N	PRESENT	0
381146	371528	08017T	PARTICIPANT	\N	PRESENT	0
381147	371528	04088S	PARTICIPANT	\N	PRESENT	0
381148	371528	14257W	PARTICIPANT	\N	PRESENT	0
381149	371528	11110B	PARTICIPANT	\N	PRESENT	0
381150	371528	11080N	PARTICIPANT	\N	PRESENT	0
381151	371528	14081Q	PARTICIPANT	\N	PRESENT	0
381152	371528	14041T	PARTICIPANT	\N	PRESENT	0
381153	371528	14065Q	PARTICIPANT	\N	PRESENT	0
381154	371528	89017R	PARTICIPANT	\N	PRESENT	0
381155	371528	07029T	PARTICIPANT	\N	PRESENT	0
381156	371528	08043V	PARTICIPANT	\N	PRESENT	0
381157	371528	19657G	PARTICIPANT	\N	PRESENT	0
381159	371528	11104D	PARTICIPANT	\N	PRESENT	0
381160	371528	14281W	PARTICIPANT	\N	PRESENT	0
381161	371528	19766L	PARTICIPANT	\N	PRESENT	0
381162	371528	19649G	PARTICIPANT	\N	PRESENT	0
381163	371528	08012N	PARTICIPANT	\N	PRESENT	0
381164	371528	19531S	PARTICIPANT	\N	PRESENT	0
381165	371528	19727D	PARTICIPANT	\N	PRESENT	0
381166	371528	19647E	PARTICIPANT	\N	PRESENT	0
381167	371528	19673G	PARTICIPANT	\N	PRESENT	0
381168	371528	11045K	PARTICIPANT	\N	PRESENT	0
381169	371528	19705W	PARTICIPANT	\N	PRESENT	0
381170	371528	14197C	PARTICIPANT	\N	PRESENT	0
381171	371528	19729F	PARTICIPANT	\N	PRESENT	0
381172	371528	14028W	PARTICIPANT	\N	PRESENT	0
381173	371528	14213J	PARTICIPANT	\N	PRESENT	0
381174	371528	80013X	PARTICIPANT	\N	PRESENT	0
381175	371528	08038Y	PARTICIPANT	\N	PRESENT	0
381176	371528	98050T	PARTICIPANT	\N	PRESENT	0
381177	371528	01062T	PARTICIPANT	\N	PRESENT	0
381178	371528	19697Q	PARTICIPANT	\N	PRESENT	0
381179	371528	14061L	PARTICIPANT	\N	PRESENT	0
381180	371528	08073C	PARTICIPANT	\N	PRESENT	0
381181	371528	14059S	PARTICIPANT	\N	PRESENT	0
381182	371528	08060W	PARTICIPANT	\N	PRESENT	0
381183	371528	19733B	PARTICIPANT	\N	PRESENT	0
381184	371528	08045X	PARTICIPANT	\N	PRESENT	0
381185	371528	19367Y	PARTICIPANT	\N	PRESENT	0
381186	371528	19621T	PARTICIPANT	\N	PRESENT	0
381187	371528	19715Y	PARTICIPANT	\N	PRESENT	0
381188	371528	04018C	PARTICIPANT	\N	PRESENT	0
381189	371528	12016W	PARTICIPANT	\N	PRESENT	0
381190	371528	14151M	PARTICIPANT	\N	PRESENT	0
381191	371528	19701S	PARTICIPANT	\N	PRESENT	0
381192	371528	19383Y	PARTICIPANT	\N	PRESENT	0
381193	371528	14051J	PARTICIPANT	\N	PRESENT	0
381194	371528	19675J	PARTICIPANT	\N	PRESENT	0
381195	371528	14109K	PARTICIPANT	\N	PRESENT	0
381196	371528	14357A	PARTICIPANT	\N	PRESENT	0
381197	371528	08052W	PARTICIPANT	\N	PRESENT	0
381198	371528	14329V	PARTICIPANT	\N	PRESENT	0
381199	371528	14229S	PARTICIPANT	\N	PRESENT	0
381200	371528	97011G	PARTICIPANT	\N	PRESENT	0
381201	371528	11103C	PARTICIPANT	\N	PRESENT	0
381202	371528	14097Y	PARTICIPANT	\N	PRESENT	0
381203	371528	11041F	PARTICIPANT	\N	PRESENT	0
381204	371528	07033P	PARTICIPANT	\N	PRESENT	0
381205	371528	98035U	PARTICIPANT	\N	PRESENT	0
381206	371528	14217N	PARTICIPANT	\N	PRESENT	0
381207	371528	08055A	PARTICIPANT	\N	PRESENT	0
381208	371528	14079W	PARTICIPANT	\N	PRESENT	0
381209	371528	19671E	PARTICIPANT	\N	PRESENT	0
381210	371528	01034P	PARTICIPANT	\N	PRESENT	0
381211	371528	19581D	PARTICIPANT	\N	PRESENT	0
381212	371528	04070G	PARTICIPANT	\N	PRESENT	0
381213	371528	19747H	PARTICIPANT	\N	PRESENT	0
381214	371528	14237S	PARTICIPANT	\N	PRESENT	0
381215	371528	14179A	PARTICIPANT	\N	PRESENT	0
381216	371528	14231L	PARTICIPANT	\N	PRESENT	0
381217	371528	14249W	PARTICIPANT	\N	PRESENT	0
381218	371528	08044W	PARTICIPANT	\N	PRESENT	0
381219	371528	14069U	PARTICIPANT	\N	PRESENT	0
381220	371528	05012A	PARTICIPANT	\N	PRESENT	0
381221	371528	19369B	PARTICIPANT	\N	PRESENT	0
381222	371528	19691J	PARTICIPANT	\N	PRESENT	0
381223	371528	19421M	PARTICIPANT	\N	PRESENT	0
381224	371528	19611R	PARTICIPANT	\N	PRESENT	0
381225	371528	11053K	PARTICIPANT	\N	PRESENT	0
381226	371528	05008E	PARTICIPANT	\N	PRESENT	0
381227	371528	19737F	PARTICIPANT	\N	PRESENT	0
381228	371528	11070L	PARTICIPANT	\N	PRESENT	0
381229	371528	04086Q	PARTICIPANT	\N	PRESENT	0
362868	362867	11109J	PARTICIPANT	\N	PRESENT	0
362869	362867	19691J	PARTICIPANT	\N	PRESENT	0
362870	362867	08019V	PARTICIPANT	\N	PRESENT	0
370822	370821	04049K	PARTICIPANT	\N	PRESENT	0
370823	370821	19671E	PARTICIPANT	\N	PRESENT	0
370824	370821	19669L	PARTICIPANT	\N	PRESENT	0
370825	370821	14265W	PARTICIPANT	\N	PRESENT	0
370826	370821	04088S	PARTICIPANT	\N	PRESENT	0
370827	370821	14083S	PARTICIPANT	\N	PRESENT	0
370828	370821	14121F	PARTICIPANT	\N	PRESENT	0
370829	370821	19667J	PARTICIPANT	\N	PRESENT	0
375449	373694	14093U	PARTICIPANT	\N	PRESENT	0
375451	373694	19503N	PARTICIPANT	\N	PRESENT	0
383118	383115	08060W	PARTICIPANT	\N	PRESENT	0
383119	383115	14157T	PARTICIPANT	\N	PRESENT	0
383120	383115	19347U	PARTICIPANT	\N	PRESENT	0
384619	384618	14030Q	PARTICIPANT	\N	PRESENT	0
384620	384618	14147R	PARTICIPANT	\N	PRESENT	0
384621	384618	11067R	PARTICIPANT	\N	PRESENT	0
384622	384618	19749K	PARTICIPANT	\N	PRESENT	0
384623	384618	10006L	PARTICIPANT	\N	PRESENT	0
384626	384625	14030Q	PARTICIPANT	\N	PRESENT	0
384627	384625	19673G	PARTICIPANT	\N	PRESENT	0
384628	384625	19649G	PARTICIPANT	\N	PRESENT	0
384629	384625	14147R	PARTICIPANT	\N	PRESENT	0
384630	384625	11067R	PARTICIPANT	\N	PRESENT	0
384631	384625	19749K	PARTICIPANT	\N	PRESENT	0
384639	384637	04018C	PARTICIPANT	\N	PRESENT	0
384640	384637	04070G	PARTICIPANT	\N	PRESENT	0
384641	384637	04059M	PARTICIPANT	\N	PRESENT	0
384642	384637	19693L	PARTICIPANT	\N	PRESENT	0
384643	384637	19643A	PARTICIPANT	\N	PRESENT	0
384644	384637	14123H	PARTICIPANT	\N	PRESENT	0
384645	384637	19731Y	PARTICIPANT	\N	PRESENT	0
384646	384637	14109K	PARTICIPANT	\N	PRESENT	0
384647	384637	19749K	PARTICIPANT	\N	PRESENT	0
384648	384637	14229S	PARTICIPANT	\N	PRESENT	0
384649	384638	04018C	PARTICIPANT	\N	PRESENT	0
384650	384638	04070G	PARTICIPANT	\N	PRESENT	0
384651	384638	19611R	PARTICIPANT	\N	PRESENT	0
384652	384638	19731Y	PARTICIPANT	\N	PRESENT	0
384653	384638	14109K	PARTICIPANT	\N	PRESENT	0
384654	384638	19693L	PARTICIPANT	\N	PRESENT	0
384656	382505	14261S	PARTICIPANT	\N	PRESENT	0
384657	382505	19329S	PARTICIPANT	\N	EXCUSE	0
384658	382505	08019V	PRESIDENT	0	PRESENT	0
384659	382505	14331P	PARTICIPANT	\N	PRESENT	0
385368	385363	14039A	PARTICIPANT	\N	PRESENT	0
385614	384434	19443T	PARTICIPANT	\N	PRESENT	0
385615	384434	12041X	PARTICIPANT	\N	PRESENT	0
385616	384434	01062T	PARTICIPANT	\N	PRESENT	0
385617	384434	04034C	PARTICIPANT	\N	PRESENT	0
385618	384434	11041F	PARTICIPANT	\N	PRESENT	0
385619	384434	14235Q	PARTICIPANT	\N	PRESENT	0
385620	384434	04040A	PARTICIPANT	\N	PRESENT	0
385621	384434	16685X	PARTICIPANT	\N	PRESENT	0
385622	384434	08058D	PARTICIPANT	\N	PRESENT	0
385623	384434	04042C	PRESIDENT	0	PRESENT	0
385624	384434	19251M	PARTICIPANT	\N	PRESENT	0
385625	384434	14028W	PARTICIPANT	\N	PRESENT	0
385626	384434	11054L	PARTICIPANT	\N	PRESENT	0
385627	384434	11066Q	PARTICIPANT	\N	PRESENT	0
385628	384434	08056B	PARTICIPANT	\N	PRESENT	0
385629	384434	14055N	PARTICIPANT	\N	PRESENT	0
385630	384434	19421M	PARTICIPANT	\N	PRESENT	0
385631	384434	08049C	PARTICIPANT	\N	PRESENT	0
385632	384434	98050T	PARTICIPANT	\N	PRESENT	0
385633	384434	97011G	PARTICIPANT	\N	PRESENT	0
385634	384434	08047A	PARTICIPANT	\N	PRESENT	0
385635	384434	98022P	PARTICIPANT	\N	PRESENT	0
385636	384434	11064N	PARTICIPANT	\N	PRESENT	0
385637	384434	98029W	PARTICIPANT	\N	PRESENT	0
385638	384600	11067R	PARTICIPANT	\N	PRESENT	0
385639	384600	04092N	PARTICIPANT	\N	PRESENT	0
385640	384600	19565D	PARTICIPANT	\N	PRESENT	0
385641	384600	14355X	PARTICIPANT	\N	PRESENT	0
385642	384600	11045K	PARTICIPANT	\N	PRESENT	0
385643	384600	11097X	PARTICIPANT	0	PRESENT	0
385644	384600	08052W	PARTICIPANT	\N	PRESENT	0
385645	384600	19415P	PARTICIPANT	\N	PRESENT	0
385646	384600	19301E	PARTICIPANT	\N	PRESENT	0
385647	384600	19691J	PARTICIPANT	\N	PRESENT	0
385648	384600	14223L	PARTICIPANT	\N	PRESENT	0
385649	384600	04045F	PARTICIPANT	\N	PRESENT	0
385650	384600	14119M	PARTICIPANT	\N	PRESENT	0
385651	384600	14087W	PARTICIPANT	\N	PRESENT	0
385652	384600	11103C	PARTICIPANT	\N	PRESENT	0
385653	384600	14195A	PARTICIPANT	\N	PRESENT	0
385654	384600	19575F	PARTICIPANT	\N	PRESENT	0
385655	384600	19367Y	PARTICIPANT	\N	PRESENT	0
385656	384600	14213J	PARTICIPANT	\N	PRESENT	0
385657	384600	19657G	PARTICIPANT	\N	PRESENT	0
385658	384600	14217N	PARTICIPANT	\N	PRESENT	0
385659	384600	08041T	PARTICIPANT	\N	EXCUSE	0
385660	384600	19697Q	PARTICIPANT	\N	PRESENT	0
385661	384600	14227Q	PARTICIPANT	\N	PRESENT	0
385662	384600	19679N	PARTICIPANT	\N	PRESENT	0
385663	384600	19521Q	PARTICIPANT	\N	PRESENT	0
385664	384600	19527W	PARTICIPANT	\N	PRESENT	0
385665	384600	19715Y	PARTICIPANT	\N	PRESENT	0
385666	384600	14071N	PARTICIPANT	\N	PRESENT	0
385667	384600	19760E	PARTICIPANT	\N	PRESENT	0
385668	385613	19699S	PARTICIPANT	\N	PRESENT	0
385669	385613	19533U	PARTICIPANT	\N	PRESENT	0
385670	385613	14229S	PARTICIPANT	\N	PRESENT	0
385671	385613	14241N	PARTICIPANT	\N	PRESENT	0
385672	385613	19573D	PARTICIPANT	\N	PRESENT	0
385673	385613	14039A	PARTICIPANT	\N	PRESENT	0
385674	385613	07033P	PARTICIPANT	\N	PRESENT	0
385675	385613	08012N	PARTICIPANT	\N	PRESENT	0
385676	385613	19335Q	PARTICIPANT	\N	PRESENT	0
385677	385613	08039A	PRESIDENT	0	PRESENT	0
385678	385613	08031R	PARTICIPANT	\N	PRESENT	0
385679	385613	19593H	PARTICIPANT	\N	PRESENT	0
385680	385613	14061L	PARTICIPANT	\N	PRESENT	0
385681	385613	14073Q	PARTICIPANT	\N	PRESENT	0
385682	385613	19611R	PARTICIPANT	\N	PRESENT	0
385683	385613	19399H	PARTICIPANT	\N	PRESENT	0
385684	385613	87003B	PARTICIPANT	\N	PRESENT	0
385685	385613	14030Q	PARTICIPANT	\N	PRESENT	0
385686	385613	19731Y	PARTICIPANT	\N	PRESENT	0
385687	385613	14251Q	PARTICIPANT	\N	PRESENT	0
385688	385613	04059M	PARTICIPANT	\N	PRESENT	0
385689	385613	11083R	PARTICIPANT	\N	PRESENT	0
385690	385613	14063N	PARTICIPANT	\N	PRESENT	0
385691	385613	14109K	PARTICIPANT	\N	PRESENT	0
385692	385613	14123H	PARTICIPANT	\N	PRESENT	0
385693	385613	11043H	PARTICIPANT	\N	PRESENT	0
385694	385613	19749K	PARTICIPANT	\N	PRESENT	0
385695	385613	04018C	PARTICIPANT	\N	PRESENT	0
385696	385613	19758L	PARTICIPANT	\N	PRESENT	0
385697	385613	19766L	PARTICIPANT	\N	EXCUSE	0
385698	385613	04070G	PARTICIPANT	\N	EXCUSE	0
385699	385613	14107H	PARTICIPANT	\N	EXCUSE	0
385700	385613	19735D	PARTICIPANT	\N	EXCUSE	0
385701	385613	08043V	PARTICIPANT	\N	EXCUSE	0
385702	384434	95030B	PARTICIPANT	\N	PRESENT	0
385703	384434	01058X	PARTICIPANT	\N	PRESENT	0
385704	384434	14079W	PARTICIPANT	\N	PRESENT	0
385705	384434	14193X	PARTICIPANT	\N	PRESENT	0
385747	384105	11081P	PARTICIPANT	\N	EXCUSE	0
385748	382827	17583W	PARTICIPANT	\N	PRESENT	0
385749	382827	19794Q	PARTICIPANT	\N	PRESENT	0
385750	382827	14031R	PARTICIPANT	\N	PRESENT	0
385751	382827	08055A	PARTICIPANT	\N	PRESENT	0
385752	382827	19599P	PARTICIPANT	\N	PRESENT	0
385753	382827	14191V	PARTICIPANT	\N	PRESENT	0
385754	382827	18083K	PARTICIPANT	\N	PRESENT	0
385755	382827	15447F	PARTICIPANT	\N	PRESENT	0
385756	382827	05012A	PARTICIPANT	\N	PRESENT	0
385757	382827	08009T	PRESIDENT	0	PRESENT	0
385758	382827	19503N	PARTICIPANT	\N	PRESENT	0
385759	382827	19745F	PARTICIPANT	\N	PRESENT	0
385760	382827	14157T	PARTICIPANT	\N	PRESENT	0
385761	382827	19333N	PARTICIPANT	\N	EXCUSE	0
385762	382827	19685L	PARTICIPANT	\N	EXCUSE	0
385763	384600	19569H	PARTICIPANT	\N	PRESENT	0
385764	384600	17779H	PARTICIPANT	\N	PRESENT	0
385765	384600	19553Y	PARTICIPANT	\N	PRESENT	0
385766	384600	19727D	PARTICIPANT	\N	PRESENT	0
391396	385081	19349W	PARTICIPANT	\N	EXCUSE	0
391397	385081	19667J	PARTICIPANT	\N	EXCUSE	0
391399	391398	89017R	PARTICIPANT	\N	PRESENT	0
391400	391398	04085P	PARTICIPANT	\N	PRESENT	0
391401	391398	04059M	PARTICIPANT	\N	PRESENT	0
391402	391398	04047H	PARTICIPANT	\N	PRESENT	0
391403	391398	04042C	PARTICIPANT	\N	PRESENT	0
391404	391398	14038Y	PARTICIPANT	\N	PRESENT	0
391405	391398	11027H	PARTICIPANT	\N	PRESENT	0
391406	391398	04086Q	PARTICIPANT	\N	PRESENT	0
391407	391398	14079W	PARTICIPANT	\N	PRESENT	0
391431	391388	19691J	PARTICIPANT	\N	EXCUSE	0
391409	391398	11074Q	PARTICIPANT	\N	PRESENT	0
391410	391398	14034U	PARTICIPANT	\N	PRESENT	0
391411	391398	14021P	PARTICIPANT	\N	PRESENT	0
391412	391398	14073Q	PARTICIPANT	\N	PRESENT	0
391413	391398	14251Q	PARTICIPANT	\N	PRESENT	0
391414	391398	04092N	PARTICIPANT	\N	PRESENT	0
391415	391398	11072N	PARTICIPANT	\N	PRESENT	0
391416	391398	08011M	PARTICIPANT	\N	PRESENT	0
391417	391398	04070G	PARTICIPANT	\N	PRESENT	0
391418	391398	08061X	PARTICIPANT	\N	PRESENT	0
391419	391398	11090Q	PARTICIPANT	\N	PRESENT	0
391420	391398	11012A	PARTICIPANT	\N	PRESENT	0
391421	391398	04044E	PARTICIPANT	\N	PRESENT	0
391429	391428	14026U	PARTICIPANT	\N	PRESENT	0
391423	391398	01043Q	PARTICIPANT	\N	PRESENT	0
391427	391398	11070L	PARTICIPANT	\N	PRESENT	0
391425	391398	04033B	PARTICIPANT	\N	PRESENT	0
391426	391398	01034P	PARTICIPANT	\N	PRESENT	0
391430	391388	19659J	PARTICIPANT	\N	EXCUSE	0
391432	391388	98005N	PARTICIPANT	\N	EXCUSE	0
391433	391388	96004D	PARTICIPANT	\N	EXCUSE	0
391434	391388	19577H	PARTICIPANT	\N	EXCUSE	0
391435	385081	08045X	PARTICIPANT	\N	EXCUSE	0
391437	391436	04059M	PARTICIPANT	\N	PRESENT	0
391439	391438	04059M	PARTICIPANT	\N	PRESENT	0
391441	391440	14257W	PRESIDENT	0	PRESENT	0
391442	391440	19593H	PARTICIPANT	\N	PRESENT	0
391443	391440	19533U	PARTICIPANT	\N	PRESENT	0
391444	391440	19599P	PARTICIPANT	\N	PRESENT	0
391445	391440	11083R	PARTICIPANT	\N	PRESENT	0
391446	391440	01048V	PARTICIPANT	\N	PRESENT	0
391447	391440	19631V	PARTICIPANT	\N	PRESENT	0
391448	391440	08053X	PARTICIPANT	\N	PRESENT	0
391450	391449	01048V	PARTICIPANT	\N	PRESENT	0
391451	391449	14257W	PARTICIPANT	\N	PRESENT	0
391452	391449	19593H	PARTICIPANT	\N	PRESENT	0
391453	391449	19533U	PARTICIPANT	\N	PRESENT	0
391454	391300	14111D	PARTICIPANT	\N	PRESENT	0
391455	391300	10015M	PARTICIPANT	\N	PRESENT	0
391456	391300	14001X	PARTICIPANT	\N	PRESENT	0
391457	391300	01024M	PARTICIPANT	\N	PRESENT	0
391458	391300	19543W	PARTICIPANT	\N	PRESENT	0
391459	391300	04044E	PARTICIPANT	\N	PRESENT	0
391460	391300	19585H	PARTICIPANT	\N	PRESENT	0
391461	391300	04047H	PRESIDENT	0	PRESENT	0
391462	391300	01028R	PARTICIPANT	\N	PRESENT	0
391463	391300	19447X	PARTICIPANT	\N	PRESENT	0
391464	391300	14231L	PARTICIPANT	\N	PRESENT	0
391465	391300	05008E	PRESIDENT	1	PRESENT	0
391466	391300	19629C	PARTICIPANT	\N	PRESENT	0
391467	391300	14179A	PARTICIPANT	\N	PRESENT	0
391468	391300	14215L	PARTICIPANT	\N	PRESENT	0
391469	391300	11072N	PARTICIPANT	\N	PRESENT	0
391470	391300	08045X	PARTICIPANT	\N	PRESENT	0
391471	391300	19729F	PARTICIPANT	\N	EXCUSE	0
391474	385081	19569H	PARTICIPANT	\N	EXCUSE	0
391477	391476	14053L	PARTICIPANT	\N	PRESENT	0
391478	391388	19583F	PARTICIPANT	\N	EXCUSE	0
391482	391481	11097X	PARTICIPANT	\N	PRESENT	0
391486	377992	86034E	PARTICIPANT	\N	PRESENT	0
391487	377992	88008L	PARTICIPANT	\N	PRESENT	0
391488	377992	04088S	PARTICIPANT	\N	PRESENT	0
391489	377992	04018C	PARTICIPANT	\N	PRESENT	0
391490	377992	19745F	PARTICIPANT	\N	PRESENT	0
391491	377992	19782L	PARTICIPANT	\N	PRESENT	0
391492	377992	05008E	PARTICIPANT	\N	PRESENT	0
391493	377992	14331P	PARTICIPANT	\N	PRESENT	0
391494	377992	14219Q	PARTICIPANT	\N	PRESENT	0
391495	377992	99004R	PARTICIPANT	\N	PRESENT	0
391496	377992	19695N	PARTICIPANT	\N	PRESENT	0
391497	377992	11031D	PARTICIPANT	\N	PRESENT	0
391498	377992	04085P	PARTICIPANT	\N	PRESENT	0
391499	377992	11056N	PARTICIPANT	\N	PRESENT	0
391500	377992	14079W	PARTICIPANT	\N	PRESENT	0
391501	377992	01028R	PARTICIPANT	\N	PRESENT	0
391502	377992	14231L	PARTICIPANT	\N	PRESENT	0
391503	377992	19703U	PARTICIPANT	\N	PRESENT	0
391504	377992	19467C	PARTICIPANT	\N	PRESENT	0
391505	377992	14235Q	PARTICIPANT	\N	PRESENT	0
391506	377992	14207L	PARTICIPANT	\N	PRESENT	0
391507	377992	19667J	PARTICIPANT	\N	PRESENT	0
391509	377992	11012A	PARTICIPANT	\N	PRESENT	0
391510	377992	11097X	PARTICIPANT	\N	PRESENT	0
391511	377992	04059M	PARTICIPANT	\N	PRESENT	0
391512	377992	95062K	PARTICIPANT	\N	PRESENT	0
391513	377992	14159V	PARTICIPANT	\N	PRESENT	0
391517	377992	08056B	PARTICIPANT	\N	PRESENT	0
391515	377992	19527W	PARTICIPANT	\N	PRESENT	0
391516	377992	08015R	PARTICIPANT	\N	PRESENT	0
391518	377992	14267Y	PARTICIPANT	\N	PRESENT	0
391519	391388	11054L	PARTICIPANT	\N	EXCUSE	0
391520	391388	95062K	PARTICIPANT	\N	EXCUSE	0
391521	377992	19741B	PARTICIPANT	\N	PRESENT	0
391522	377992	11103C	PARTICIPANT	\N	PRESENT	0
391523	377992	08020N	PARTICIPANT	\N	PRESENT	0
391524	377992	08028W	PARTICIPANT	\N	PRESENT	0
391525	377992	97011G	PARTICIPANT	\N	PRESENT	0
391526	377992	19729F	PARTICIPANT	\N	PRESENT	0
391527	377992	19563B	PARTICIPANT	\N	PRESENT	0
391528	377992	08044W	PARTICIPANT	\N	PRESENT	0
391529	377992	10015M	PARTICIPANT	\N	PRESENT	0
391530	377992	11072N	PARTICIPANT	\N	PRESENT	0
391531	377992	08024S	PARTICIPANT	\N	PRESENT	0
391532	377992	19447X	PARTICIPANT	\N	PRESENT	0
391533	377992	14061L	PARTICIPANT	\N	PRESENT	0
391534	377992	19758L	PARTICIPANT	\N	PRESENT	0
391535	377992	19739H	PARTICIPANT	\N	PRESENT	0
391536	377992	19369B	PARTICIPANT	\N	PRESENT	0
391537	377992	19766L	PARTICIPANT	\N	PRESENT	0
391538	377992	14105F	PARTICIPANT	\N	PRESENT	0
391539	377992	19387D	PARTICIPANT	\N	PRESENT	0
391540	377992	19673G	PARTICIPANT	\N	PRESENT	0
391541	377992	14123H	PARTICIPANT	\N	PRESENT	0
391542	377992	19762G	PARTICIPANT	\N	PRESENT	0
391543	377992	18083K	PARTICIPANT	\N	PRESENT	0
391544	391508	19369B	PARTICIPANT	\N	PRESENT	0
391545	377992	19289C	PARTICIPANT	\N	PRESENT	0
391546	377992	19731Y	PARTICIPANT	\N	PRESENT	0
391547	377992	01024M	PARTICIPANT	\N	PRESENT	0
391548	377992	19415P	PARTICIPANT	\N	PRESENT	0
391549	377992	19725B	PARTICIPANT	\N	PRESENT	0
391550	377992	14265W	PARTICIPANT	\N	PRESENT	0
391551	377992	14179A	PARTICIPANT	\N	PRESENT	0
391552	377992	14197C	PARTICIPANT	\N	PRESENT	0
391553	377992	19543W	PARTICIPANT	\N	PRESENT	0
391554	377992	14157T	PARTICIPANT	\N	PRESENT	0
391555	377992	19479G	PARTICIPANT	\N	PRESENT	0
391556	377992	01025N	PARTICIPANT	\N	PRESENT	0
391557	377992	19565D	PARTICIPANT	\N	PRESENT	0
391558	377992	04044E	PARTICIPANT	\N	PRESENT	0
391559	377992	14223L	PARTICIPANT	\N	PRESENT	0
391560	377992	17637T	PARTICIPANT	\N	PRESENT	0
391561	377992	19629C	PARTICIPANT	\N	PRESENT	0
391562	377992	11040E	PARTICIPANT	\N	PRESENT	0
391563	377992	08017T	PARTICIPANT	\N	PRESENT	0
391564	377992	14097Y	PARTICIPANT	\N	PRESENT	0
391565	377992	14173T	PARTICIPANT	\N	PRESENT	0
391566	377992	19441R	PARTICIPANT	\N	PRESENT	0
391567	377992	14087W	PARTICIPANT	\N	PRESENT	0
391568	377992	14199E	PARTICIPANT	\N	PRESENT	0
391569	377992	08039A	PARTICIPANT	\N	PRESENT	0
391570	377992	14107H	PARTICIPANT	\N	PRESENT	0
391571	377992	19507S	PARTICIPANT	\N	PRESENT	0
391572	377992	19760E	PARTICIPANT	\N	PRESENT	0
391573	377992	19747H	PARTICIPANT	\N	PRESENT	0
391239	391238	08009T	PARTICIPANT	\N	PRESENT	0
391240	391238	14169X	PARTICIPANT	\N	PRESENT	0
391395	391393	19253P	PARTICIPANT	\N	PRESENT	0
391574	377992	14251Q	PARTICIPANT	\N	PRESENT	0
391575	377992	11083R	PARTICIPANT	\N	PRESENT	0
391576	377992	19657G	PARTICIPANT	\N	PRESENT	0
391580	377992	14083S	PARTICIPANT	\N	PRESENT	0
391581	377992	14069U	PARTICIPANT	\N	PRESENT	0
391582	377992	14111D	PARTICIPANT	\N	PRESENT	0
391584	391583	14071N	PARTICIPANT	\N	PRESENT	0
391585	391583	19766L	PARTICIPANT	\N	PRESENT	0
364699	364697	14261S	PARTICIPANT	\N	PRESENT	0
364700	364697	14119M	PARTICIPANT	\N	PRESENT	0
364705	364704	14261S	PARTICIPANT	\N	PRESENT	0
364706	364704	14119M	PARTICIPANT	\N	PRESENT	0
364750	361770	11109J	PARTICIPANT	\N	PRESENT	0
364751	361770	19717B	PARTICIPANT	\N	PRESENT	0
364752	361770	19631V	PARTICIPANT	\N	PRESENT	0
364754	361770	19691J	PARTICIPANT	\N	PRESENT	0
364755	361770	12016W	PARTICIPANT	\N	PRESENT	0
364756	361770	08019V	PRESIDENT	0	PRESENT	0
364918	364917	19415P	PARTICIPANT	\N	PRESENT	0
364919	364917	11067R	PARTICIPANT	\N	PRESENT	0
365215	365214	08055A	PARTICIPANT	\N	PRESENT	0
365216	365214	04047H	PARTICIPANT	0	PRESENT	0
365217	365214	19545Y	PARTICIPANT	\N	PRESENT	0
365218	365214	14085U	PARTICIPANT	\N	PRESENT	0
365219	365214	11080N	PARTICIPANT	\N	PRESENT	0
365220	365214	11083R	PARTICIPANT	\N	PRESENT	0
365221	365214	01057W	PARTICIPANT	\N	PRESENT	0
371764	369841	19711U	PARTICIPANT	\N	PRESENT	0
371765	369841	14085U	PARTICIPANT	\N	PRESENT	0
365224	365214	08049C	PARTICIPANT	\N	PRESENT	0
371766	369841	19349W	PARTICIPANT	\N	PRESENT	0
371767	369841	99004R	PARTICIPANT	\N	PRESENT	0
371768	369841	88008L	PRESIDENT	0	PRESENT	0
371769	369841	19671E	PARTICIPANT	\N	PRESENT	0
371770	369841	14173T	PARTICIPANT	\N	PRESENT	0
371771	369841	04086Q	PARTICIPANT	\N	EXCUSE	0
371772	369841	08010L	PARTICIPANT	\N	EXCUSE	0
371779	369841	01057W	PARTICIPANT	\N	PRESENT	0
371780	369841	12016W	PARTICIPANT	\N	PRESENT	0
371781	369841	14083S	PARTICIPANT	\N	PRESENT	0
371792	356312	08020N	PARTICIPANT	\N	PRESENT	0
371794	356312	08019V	PARTICIPANT	\N	PRESENT	0
371795	356312	11054L	PARTICIPANT	\N	PRESENT	0
371796	356312	19289C	PARTICIPANT	\N	PRESENT	0
371797	356312	19507S	PARTICIPANT	\N	PRESENT	0
371798	356312	11067R	PARTICIPANT	\N	PRESENT	0
371799	369841	11048N	PARTICIPANT	\N	PRESENT	0
371800	369841	08011M	PARTICIPANT	\N	PRESENT	0
371801	369841	89017R	PARTICIPANT	\N	PRESENT	0
371802	369841	11070L	PARTICIPANT	\N	PRESENT	0
371803	369841	19741B	PARTICIPANT	\N	PRESENT	0
371804	369841	14253S	PARTICIPANT	\N	PRESENT	0
371805	356312	17583W	PARTICIPANT	\N	PRESENT	0
371806	356312	14267Y	PARTICIPANT	\N	PRESENT	0
371807	356312	19383Y	PARTICIPANT	\N	PRESENT	0
371808	356312	14087W	PARTICIPANT	\N	PRESENT	0
371809	356312	19553Y	PARTICIPANT	\N	PRESENT	0
371810	356312	19798U	PARTICIPANT	\N	PRESENT	0
371811	356312	14147R	PARTICIPANT	\N	PRESENT	0
371812	356312	19581D	PARTICIPANT	\N	PRESENT	0
371813	356312	04085P	PARTICIPANT	\N	PRESENT	0
371814	369841	11012A	PARTICIPANT	\N	PRESENT	0
371815	369841	14121F	PARTICIPANT	\N	PRESENT	0
371816	356312	14055N	PARTICIPANT	\N	PRESENT	0
371817	356312	19725B	PARTICIPANT	\N	PRESENT	0
371819	356312	11101A	PARTICIPANT	\N	PRESENT	0
371821	356312	14026U	PARTICIPANT	\N	PRESENT	0
371826	356312	14115H	PARTICIPANT	\N	PRESENT	0
371828	356312	08068F	PARTICIPANT	\N	PRESENT	0
371829	356312	14257W	PARTICIPANT	\N	PRESENT	0
371830	356312	19729F	PARTICIPANT	\N	PRESENT	0
371831	356312	19573D	PARTICIPANT	\N	PRESENT	0
371832	356312	19717B	PARTICIPANT	\N	PRESENT	0
371833	356312	19367Y	PARTICIPANT	\N	PRESENT	0
371834	356312	08073C	PARTICIPANT	\N	PRESENT	0
371835	356312	80013X	PARTICIPANT	\N	PRESENT	0
371836	356312	19745F	PARTICIPANT	\N	PRESENT	0
371838	356312	14135M	PARTICIPANT	\N	PRESENT	0
371839	356312	14173T	PARTICIPANT	\N	PRESENT	0
371840	356312	14219Q	PARTICIPANT	\N	PRESENT	0
371841	356312	19715Y	PARTICIPANT	\N	PRESENT	0
371842	356312	08045X	PARTICIPANT	\N	PRESENT	0
371843	356312	17637T	PARTICIPANT	\N	PRESENT	0
371844	356312	19533U	PARTICIPANT	\N	PRESENT	0
371845	356312	14265W	PARTICIPANT	\N	PRESENT	0
371846	369841	19545Y	PARTICIPANT	\N	PRESENT	0
371847	369841	14225N	PARTICIPANT	\N	PRESENT	0
371848	369841	07029T	PARTICIPANT	\N	PRESENT	0
371949	363529	11056N	PARTICIPANT	\N	PRESENT	0
371950	363529	19593H	PARTICIPANT	\N	PRESENT	0
371951	363529	14235Q	PARTICIPANT	\N	PRESENT	0
371952	363529	19695N	PARTICIPANT	\N	PRESENT	0
371953	363529	19760E	PARTICIPANT	\N	PRESENT	0
371954	363529	04085P	PARTICIPANT	\N	PRESENT	0
371956	363529	19347U	PARTICIPANT	\N	PRESENT	0
371957	363529	19565D	PARTICIPANT	\N	PRESENT	0
371958	363529	19758L	PARTICIPANT	\N	PRESENT	0
371959	363529	11031D	PARTICIPANT	\N	PRESENT	0
371960	363529	89017R	PARTICIPANT	\N	PRESENT	0
371961	363529	08061X	PARTICIPANT	\N	PRESENT	0
371962	363529	95037J	PARTICIPANT	\N	PRESENT	0
371963	363529	95063L	PARTICIPANT	\N	PRESENT	0
371964	363529	14055N	PARTICIPANT	\N	PRESENT	0
371965	363529	04034C	PARTICIPANT	\N	PRESENT	0
371966	363529	04045F	PARTICIPANT	\N	PRESENT	0
371967	363529	19651A	PARTICIPANT	\N	PRESENT	0
371968	363529	14239U	PARTICIPANT	\N	PRESENT	0
371969	363529	14211G	PARTICIPANT	\N	PRESENT	0
371970	363529	19349W	PARTICIPANT	\N	PRESENT	0
371971	363529	17637T	PARTICIPANT	\N	PRESENT	0
371972	363529	14093U	PARTICIPANT	\N	PRESENT	0
371973	363529	19711U	PARTICIPANT	\N	PRESENT	0
371974	363529	08073C	PARTICIPANT	\N	PRESENT	0
371975	363529	95062K	PARTICIPANT	\N	PRESENT	0
371976	363529	14039A	PARTICIPANT	\N	PRESENT	0
371977	363529	19301E	PARTICIPANT	\N	PRESENT	0
371978	363529	14157T	PARTICIPANT	\N	PRESENT	0
371979	363529	19782L	PARTICIPANT	\N	PRESENT	0
371980	363529	11072N	PARTICIPANT	\N	PRESENT	0
371981	363529	01058X	PARTICIPANT	\N	PRESENT	0
371982	363529	19659J	PARTICIPANT	\N	PRESENT	0
371983	363529	99004R	PARTICIPANT	\N	PRESENT	0
371984	363529	19585H	PARTICIPANT	\N	PRESENT	0
371985	363529	19679N	PARTICIPANT	\N	PRESENT	0
371986	363529	11064N	PARTICIPANT	\N	PRESENT	0
371987	363529	08039A	PARTICIPANT	\N	PRESENT	0
371988	363529	14111D	PARTICIPANT	\N	PRESENT	0
371989	363529	19545Y	PARTICIPANT	\N	PRESENT	0
371990	363529	08020N	PARTICIPANT	\N	PRESENT	0
371991	363529	14251Q	PARTICIPANT	\N	PRESENT	0
371992	363529	14123H	PARTICIPANT	\N	PRESENT	0
371993	363529	04047H	PARTICIPANT	\N	PRESENT	0
371994	363529	19643A	PARTICIPANT	\N	PRESENT	0
371995	363529	19583F	PARTICIPANT	\N	PRESENT	0
371996	363529	14223L	PARTICIPANT	\N	PRESENT	0
371997	363529	98005N	PARTICIPANT	\N	PRESENT	0
371998	363529	14195A	PARTICIPANT	\N	PRESENT	0
371999	363529	11043H	PARTICIPANT	\N	PRESENT	0
372000	363529	04057K	PARTICIPANT	\N	PRESENT	0
372001	363529	08028W	PARTICIPANT	\N	PRESENT	0
372002	363529	19515S	PARTICIPANT	\N	PRESENT	0
372003	363529	19719D	PARTICIPANT	\N	PRESENT	0
372004	363529	14107H	PARTICIPANT	\N	PRESENT	0
372005	363529	19387D	PARTICIPANT	\N	PRESENT	0
372006	363529	14191V	PARTICIPANT	\N	PRESENT	0
372007	363529	98022P	PARTICIPANT	\N	PRESENT	0
372008	363529	11080N	PARTICIPANT	\N	PRESENT	0
372009	363529	19766L	PARTICIPANT	\N	PRESENT	0
372010	363529	14259Y	PARTICIPANT	\N	PRESENT	0
372011	363529	01057W	PARTICIPANT	\N	PRESENT	0
372012	363529	19553Y	PARTICIPANT	\N	PRESENT	0
372013	363529	19717B	PARTICIPANT	\N	PRESENT	0
372014	363529	87003B	PARTICIPANT	\N	PRESENT	0
372015	363529	14241N	PARTICIPANT	\N	PRESENT	0
372016	363529	14201E	PARTICIPANT	\N	PRESENT	0
372017	363529	11090Q	PARTICIPANT	\N	PRESENT	0
372018	363529	19629C	PARTICIPANT	\N	PRESENT	0
372019	363529	19703U	PARTICIPANT	\N	PRESENT	0
372020	363529	11065P	PARTICIPANT	\N	PRESENT	0
372021	363529	08049C	PARTICIPANT	\N	PRESENT	0
372022	363529	14031R	PARTICIPANT	\N	PRESENT	0
372023	363529	14199E	PARTICIPANT	\N	PRESENT	0
372024	363529	14261S	PARTICIPANT	\N	PRESENT	0
372025	363529	88008L	PARTICIPANT	\N	PRESENT	0
372026	363529	11048N	PARTICIPANT	\N	PRESENT	0
372027	363529	11012A	PARTICIPANT	\N	PRESENT	0
372028	363529	08031R	PARTICIPANT	\N	PRESENT	0
372029	363529	19289C	PARTICIPANT	\N	PRESENT	0
372030	363529	19253P	PARTICIPANT	\N	PRESENT	0
372031	363529	19681G	PARTICIPANT	\N	PRESENT	0
372032	363529	19581D	PARTICIPANT	\N	PRESENT	0
372033	363529	14173T	PARTICIPANT	\N	PRESENT	0
372034	363529	19447X	PARTICIPANT	\N	PRESENT	0
372035	363529	19563B	PARTICIPANT	\N	PRESENT	0
372036	363529	19573D	PARTICIPANT	\N	PRESENT	0
372037	363529	14119M	PARTICIPANT	\N	PRESENT	0
378877	376282	14261S	PARTICIPANT	\N	EXCUSE	0
378878	376282	19329S	PARTICIPANT	\N	PRESENT	0
378879	376282	19691J	PARTICIPANT	\N	PRESENT	0
378880	376282	14219Q	PARTICIPANT	\N	PRESENT	0
378881	376282	08019V	PARTICIPANT	\N	PRESENT	0
378882	376282	04043D	PARTICIPANT	\N	PRESENT	0
378883	376282	14331P	PARTICIPANT	\N	PRESENT	0
378884	376282	11072N	PARTICIPANT	\N	PRESENT	0
378885	376282	19295A	PARTICIPANT	\N	EXCUSE	0
378886	376282	11010L	PARTICIPANT	\N	EXCUSE	0
378887	376282	14038Y	PARTICIPANT	\N	EXCUSE	0
378888	376282	96004D	PARTICIPANT	\N	EXCUSE	0
378889	376282	14059S	PARTICIPANT	\N	EXCUSE	0
378890	376282	11054L	PARTICIPANT	\N	EXCUSE	0
378891	376282	95062K	PARTICIPANT	\N	EXCUSE	0
378892	376282	14275Y	PARTICIPANT	\N	EXCUSE	0
378897	376283	14261S	PARTICIPANT	\N	PRESENT	0
378898	376283	96004D	PARTICIPANT	\N	EXCUSE	0
378899	376283	19295A	PARTICIPANT	\N	EXCUSE	0
378900	376283	19659J	PARTICIPANT	\N	PRESENT	0
378901	376283	11010L	PARTICIPANT	\N	EXCUSE	0
378902	376283	19691J	PARTICIPANT	\N	EXCUSE	0
378903	376283	19729F	PARTICIPANT	\N	PRESENT	0
378904	376283	14059S	PARTICIPANT	\N	PRESENT	0
378905	376283	08019V	PARTICIPANT	\N	PRESENT	0
378906	376283	04043D	PARTICIPANT	\N	PRESENT	0
378907	376283	14331P	PARTICIPANT	\N	PRESENT	0
378908	376283	14275Y	PARTICIPANT	\N	EXCUSE	0
378909	376283	11054L	PARTICIPANT	\N	EXCUSE	0
378910	376283	95062K	PARTICIPANT	\N	EXCUSE	0
378911	376283	14038Y	PARTICIPANT	\N	EXCUSE	0
378912	376283	19329S	PARTICIPANT	\N	PRESENT	0
381232	371528	19569H	PARTICIPANT	\N	PRESENT	0
381233	371528	19735D	PARTICIPANT	\N	PRESENT	0
381234	371528	16685X	PARTICIPANT	\N	PRESENT	0
381235	371528	08056B	PARTICIPANT	\N	PRESENT	0
381236	371528	14219Q	PARTICIPANT	\N	PRESENT	0
381237	371528	19441R	PARTICIPANT	\N	PRESENT	0
381238	371528	04089T	PARTICIPANT	\N	PRESENT	0
381239	371528	98005N	PARTICIPANT	\N	PRESENT	0
381240	371528	14073Q	PARTICIPANT	\N	PRESENT	0
381241	371528	14103D	PARTICIPANT	\N	PRESENT	0
381243	371528	14221J	PARTICIPANT	\N	PRESENT	0
381244	371528	19739H	PARTICIPANT	\N	PRESENT	0
381245	371528	19619A	PARTICIPANT	\N	PRESENT	0
381246	371528	19521Q	PARTICIPANT	\N	PRESENT	0
381247	371528	14205J	PARTICIPANT	\N	PRESENT	0
381248	371528	10015M	PARTICIPANT	\N	PRESENT	0
381249	371528	19713W	PARTICIPANT	\N	PRESENT	0
381250	371528	14275Y	PARTICIPANT	\N	PRESENT	0
381251	371528	07004J	PARTICIPANT	\N	PRESENT	0
381252	371528	14267Y	PARTICIPANT	\N	PRESENT	0
381253	371528	01025N	PARTICIPANT	\N	PRESENT	0
381254	371528	19749K	PARTICIPANT	\N	PRESENT	0
381255	371528	19745F	PARTICIPANT	\N	PRESENT	0
381256	371528	01024M	PARTICIPANT	\N	PRESENT	0
381257	371528	14083S	PARTICIPANT	\N	PRESENT	0
381258	371528	04040A	PARTICIPANT	\N	PRESENT	0
381259	371528	14030Q	PARTICIPANT	\N	PRESENT	0
381260	371528	11085T	PARTICIPANT	\N	PRESENT	0
381261	371528	19577H	PARTICIPANT	\N	PRESENT	0
381262	371528	14042U	PARTICIPANT	\N	PRESENT	0
381263	371528	14327T	PARTICIPANT	\N	PRESENT	0
381264	371528	19335Q	PARTICIPANT	\N	PRESENT	0
381265	371528	01043Q	PARTICIPANT	\N	PRESENT	0
381266	381242	14187A	PARTICIPANT	\N	PRESENT	0
381267	381242	04089T	PARTICIPANT	\N	PRESENT	0
381268	381242	11090Q	PARTICIPANT	\N	PRESENT	0
381269	371528	19693L	PARTICIPANT	\N	PRESENT	0
381270	371528	14225N	PARTICIPANT	\N	PRESENT	0
381271	371528	11065P	PARTICIPANT	\N	PRESENT	0
381272	371528	19687N	PARTICIPANT	\N	PRESENT	0
381273	371528	04038G	PARTICIPANT	\N	PRESENT	0
381274	371528	01028R	PARTICIPANT	\N	PRESENT	0
381275	371528	14089Y	PARTICIPANT	\N	PRESENT	0
381276	371528	11027H	PARTICIPANT	\N	PRESENT	0
381282	371528	14093U	PARTICIPANT	\N	PRESENT	0
381278	371528	19347U	PARTICIPANT	\N	PRESENT	0
381279	371528	04061F	PARTICIPANT	\N	PRESENT	0
381280	371528	08035V	PARTICIPANT	\N	PRESENT	0
381281	371528	08009T	PARTICIPANT	\N	PRESENT	0
381642	371530	19367Y	PARTICIPANT	\N	PRESENT	0
381643	371530	19581D	PARTICIPANT	\N	PRESENT	0
381644	371530	19671E	PARTICIPANT	\N	PRESENT	0
381645	371530	08061X	PARTICIPANT	\N	PRESENT	0
381646	378924	14097Y	PARTICIPANT	\N	PRESENT	0
381647	378924	19443T	PARTICIPANT	\N	PRESENT	0
381648	378924	12041X	PARTICIPANT	\N	PRESENT	0
381649	378924	01062T	PARTICIPANT	\N	PRESENT	0
381650	378924	95030B	PARTICIPANT	\N	PRESENT	0
381230	371528	19721W	PARTICIPANT	\N	PRESENT	0
381231	371528	19699S	PARTICIPANT	\N	PRESENT	0
381651	378924	14235Q	PARTICIPANT	\N	PRESENT	0
381652	378924	14079W	PARTICIPANT	\N	PRESENT	0
381653	378924	16685X	PARTICIPANT	\N	PRESENT	0
381654	378924	08058D	PARTICIPANT	\N	PRESENT	0
381655	378924	04042C	PRESIDENT	0	PRESENT	0
381656	378924	14028W	PARTICIPANT	\N	PRESENT	0
381657	378924	14267Y	PARTICIPANT	\N	PRESENT	0
381658	378924	98050T	PARTICIPANT	\N	PRESENT	0
381659	378924	08047A	PARTICIPANT	\N	PRESENT	0
381660	378924	98029W	PARTICIPANT	\N	PRESENT	0
381661	378924	98018T	PARTICIPANT	\N	EXCUSE	0
381662	381599	19333N	PARTICIPANT	\N	PRESENT	0
381663	381599	14031R	PARTICIPANT	\N	PRESENT	0
381664	381599	19713W	PARTICIPANT	\N	PRESENT	0
381665	381599	08055A	PARTICIPANT	\N	PRESENT	0
381666	381599	18083K	PARTICIPANT	\N	PRESENT	0
381667	381599	14029X	PARTICIPANT	\N	PRESENT	0
381668	381599	08060W	PARTICIPANT	\N	PRESENT	0
381669	381599	19733B	PARTICIPANT	\N	PRESENT	0
381670	381599	08009T	PRESIDENT	0	PRESENT	0
381671	381599	19503N	PARTICIPANT	\N	PRESENT	0
381672	381599	19737F	PARTICIPANT	\N	PRESENT	0
381673	381599	19347U	PARTICIPANT	\N	PRESENT	0
381674	381599	14157T	PARTICIPANT	\N	PRESENT	0
381675	381599	19745F	PARTICIPANT	\N	PRESENT	0
381676	381599	08024S	PARTICIPANT	\N	PRESENT	0
381677	381599	19685L	PARTICIPANT	\N	EXCUSE	0
381678	371530	19695N	PARTICIPANT	\N	PRESENT	0
381679	371530	14089Y	PARTICIPANT	\N	PRESENT	0
381680	371530	04043D	PARTICIPANT	\N	PRESENT	0
381681	371530	19798U	PARTICIPANT	\N	PRESENT	0
381682	371530	19399H	PARTICIPANT	\N	PRESENT	0
381683	371530	19679N	PARTICIPANT	\N	PRESENT	0
381684	371530	11048N	PARTICIPANT	\N	PRESENT	0
381685	371530	19415P	PARTICIPANT	\N	PRESENT	0
381686	381599	19383Y	PARTICIPANT	\N	PRESENT	0
381687	381599	19701S	PARTICIPANT	\N	PRESENT	0
381688	381599	19794Q	PARTICIPANT	\N	PRESENT	0
381689	381599	19549D	PARTICIPANT	\N	PRESENT	0
381690	381599	15447F	PARTICIPANT	\N	PRESENT	0
381691	381599	14237S	PARTICIPANT	\N	PRESENT	0
381692	378924	04035D	PARTICIPANT	\N	PRESENT	0
381693	378924	19251M	PARTICIPANT	\N	PRESENT	0
381694	378924	08056B	PARTICIPANT	\N	PRESENT	0
381695	378924	19421M	PARTICIPANT	\N	PRESENT	0
381707	380297	19749K	PARTICIPANT	\N	PRESENT	0
381708	380297	19733B	PARTICIPANT	\N	PRESENT	0
381710	371528	08034U	PARTICIPANT	\N	PRESENT	0
381867	378922	14327T	PARTICIPANT	\N	PRESENT	0
381868	378922	14331P	PARTICIPANT	\N	PRESENT	0
381869	378922	95041E	PARTICIPANT	\N	PRESENT	0
381870	378922	19545Y	PARTICIPANT	\N	PRESENT	0
381871	378922	01057W	PARTICIPANT	\N	PRESENT	0
381872	378922	11074Q	PRESIDENT	0	PRESENT	0
381873	378922	89017R	PARTICIPANT	\N	PRESENT	0
381874	378922	88008L	PARTICIPANT	\N	PRESENT	0
381875	378922	19671E	PARTICIPANT	\N	PRESENT	0
381876	378922	07029T	PARTICIPANT	\N	PRESENT	0
381877	378922	14085U	PARTICIPANT	\N	PRESENT	0
381878	378922	19349W	PARTICIPANT	\N	PRESENT	0
381879	378922	08010L	PARTICIPANT	\N	PRESENT	0
381880	378922	19711U	PARTICIPANT	\N	PRESENT	0
381881	378922	19531S	PARTICIPANT	\N	PRESENT	0
381882	378922	08069G	PARTICIPANT	\N	PRESENT	0
381883	378922	19689Q	PARTICIPANT	\N	PRESENT	0
381884	378922	08014Q	PARTICIPANT	\N	PRESENT	0
381885	378922	14173T	PARTICIPANT	\N	PRESENT	0
381886	378922	11012A	PARTICIPANT	\N	PRESENT	0
381887	378922	14199E	PARTICIPANT	\N	PRESENT	0
381888	378922	08073C	PARTICIPANT	\N	PRESENT	0
381889	378922	14121F	PARTICIPANT	\N	PRESENT	0
381890	378922	19741B	PARTICIPANT	\N	PRESENT	0
381891	378922	99004R	PARTICIPANT	\N	PRESENT	0
381892	378922	04018C	PARTICIPANT	\N	PRESENT	0
381893	378922	04061F	PARTICIPANT	\N	PRESENT	0
381894	378920	18083K	PARTICIPANT	\N	PRESENT	0
381895	378920	15447F	PARTICIPANT	\N	PRESENT	0
364293	364292	14329V	PARTICIPANT	\N	PRESENT	0
364294	364292	14103D	PARTICIPANT	\N	PRESENT	0
364295	364292	11103C	PARTICIPANT	\N	PRESENT	0
364297	364296	11103C	PARTICIPANT	\N	PRESENT	0
364298	364296	14103D	PARTICIPANT	\N	PRESENT	0
364299	364296	14329V	PARTICIPANT	\N	PRESENT	0
365902	364269	14327T	PARTICIPANT	\N	PRESENT	0
365903	364269	14331P	PARTICIPANT	\N	PRESENT	0
365904	364269	04071H	PARTICIPANT	\N	PRESENT	0
365905	364269	19545Y	PARTICIPANT	\N	PRESENT	0
365906	364269	01057W	PARTICIPANT	\N	PRESENT	0
365907	364269	11053K	PARTICIPANT	\N	PRESENT	0
365908	364269	11074Q	PRESIDENT	0	PRESENT	0
365909	364269	89017R	PARTICIPANT	\N	PRESENT	0
365910	364269	19671E	PARTICIPANT	\N	PRESENT	0
365911	364269	88008L	PARTICIPANT	\N	PRESENT	0
365912	364269	14225N	PARTICIPANT	\N	PRESENT	0
365913	364269	01028R	PARTICIPANT	\N	PRESENT	0
365914	364269	07029T	PARTICIPANT	\N	PRESENT	0
365915	364269	14277B	PARTICIPANT	\N	PRESENT	0
365916	364269	14085U	PARTICIPANT	\N	PRESENT	0
365917	364269	07004J	PARTICIPANT	\N	PRESENT	0
365918	364269	19349W	PARTICIPANT	\N	PRESENT	0
365919	364269	08010L	PARTICIPANT	\N	PRESENT	0
365920	364269	14253S	PARTICIPANT	\N	PRESENT	0
365921	364269	11048N	PARTICIPANT	\N	PRESENT	0
365922	364269	19479G	PARTICIPANT	\N	PRESENT	0
365923	364269	08034U	PARTICIPANT	\N	PRESENT	0
365924	364269	08069G	PARTICIPANT	\N	PRESENT	0
365925	364269	19687N	PARTICIPANT	\N	PRESENT	0
365926	364269	12016W	PARTICIPANT	\N	PRESENT	0
365927	364269	08011M	PARTICIPANT	\N	PRESENT	0
365928	364269	14159V	PARTICIPANT	\N	PRESENT	0
365929	364269	04086Q	PARTICIPANT	\N	PRESENT	0
365930	364269	14199E	PARTICIPANT	\N	PRESENT	0
365931	364269	11012A	PARTICIPANT	\N	PRESENT	0
365932	364269	08073C	PARTICIPANT	\N	PRESENT	0
365933	364269	19741B	PARTICIPANT	\N	PRESENT	0
365934	364269	99004R	PARTICIPANT	\N	PRESENT	0
365935	362302	19768N	PARTICIPANT	\N	PRESENT	0
365936	362302	19515S	PARTICIPANT	\N	PRESENT	0
365937	362302	11077T	PARTICIPANT	\N	PRESENT	0
365938	362302	19782L	PARTICIPANT	\N	PRESENT	0
365939	362302	14357A	PARTICIPANT	\N	PRESENT	0
365940	362302	19441R	PARTICIPANT	\N	PRESENT	0
365941	362302	19413M	PARTICIPANT	\N	PRESENT	0
365942	362302	80013X	PARTICIPANT	\N	PRESENT	0
365943	362302	11099A	PARTICIPANT	\N	PRESENT	0
365944	362302	08068F	PARTICIPANT	\N	PRESENT	0
365945	362302	04049K	PARTICIPANT	\N	PRESENT	0
365946	362302	19705W	PARTICIPANT	\N	PRESENT	0
365947	362302	08015R	PARTICIPANT	\N	PRESENT	0
365948	362302	08019V	PARTICIPANT	\N	PRESENT	0
365949	362302	14197C	PARTICIPANT	\N	PRESENT	0
365950	362302	19369B	PARTICIPANT	\N	PRESENT	0
365951	362302	19511N	PARTICIPANT	\N	PRESENT	0
365952	362302	08028W	PARTICIPANT	\N	PRESENT	0
365953	362302	19563B	PARTICIPANT	\N	PRESENT	0
365954	362302	14265W	PARTICIPANT	\N	PRESENT	0
365955	362302	14329V	PARTICIPANT	\N	PRESENT	0
365956	362302	14135M	PARTICIPANT	\N	PRESENT	0
365957	362302	14103D	PARTICIPANT	\N	PRESENT	0
365958	362302	14187A	PARTICIPANT	\N	PRESENT	0
365959	362302	19695N	PARTICIPANT	\N	PRESENT	0
365960	362302	01025N	PARTICIPANT	\N	PRESENT	0
365961	362302	11090Q	PRESIDENT	0	PRESENT	0
365962	362302	14033T	PARTICIPANT	\N	PRESENT	0
365963	362302	19295A	PARTICIPANT	\N	PRESENT	0
365964	362302	19269X	PARTICIPANT	\N	PRESENT	0
365965	362302	14205J	PARTICIPANT	\N	PRESENT	0
365966	362302	04088S	PARTICIPANT	\N	PRESENT	0
365967	362302	04089T	PARTICIPANT	\N	PRESENT	0
365968	362302	14115H	PARTICIPANT	\N	PRESENT	0
365969	362302	11101A	PARTICIPANT	\N	PRESENT	0
365970	362302	19747H	PARTICIPANT	\N	PRESENT	0
365971	362302	14207L	PARTICIPANT	\N	PRESENT	0
365972	362302	04043D	PARTICIPANT	\N	PRESENT	0
365973	362302	19619A	PARTICIPANT	\N	PRESENT	0
365974	362302	17589D	PARTICIPANT	\N	PRESENT	0
365975	362302	14257W	PARTICIPANT	\N	PRESENT	0
365976	362302	08021P	PARTICIPANT	\N	EXCUSE	0
365977	362302	11081P	PARTICIPANT	\N	EXCUSE	0
365980	363174	14026U	PARTICIPANT	\N	PRESENT	0
365981	362302	14081Q	PARTICIPANT	\N	PRESENT	0
365982	362302	19631V	PARTICIPANT	\N	PRESENT	0
365983	362302	19467C	PARTICIPANT	\N	PRESENT	0
365984	362302	08038Y	PARTICIPANT	\N	PRESENT	0
365985	362302	08062Y	PARTICIPANT	\N	PRESENT	0
365986	364282	11074Q	PRESIDENT	0	PRESENT	0
370165	370164	95037J	PARTICIPANT	\N	PRESENT	0
370166	370164	98029W	PARTICIPANT	\N	PRESENT	0
370168	370167	98050T	PARTICIPANT	\N	PRESENT	0
370169	370167	01062T	PARTICIPANT	\N	PRESENT	0
370170	370167	98029W	PARTICIPANT	\N	PRESENT	0
370173	370172	98050T	PARTICIPANT	\N	PRESENT	0
370175	370172	01062T	PARTICIPANT	\N	PRESENT	0
370187	370185	98050T	PARTICIPANT	\N	PRESENT	0
370188	370185	01062T	PARTICIPANT	\N	PRESENT	0
370200	370199	14253S	PARTICIPANT	\N	PRESENT	0
370201	370199	14085U	PARTICIPANT	\N	PRESENT	0
370540	370539	08014Q	PARTICIPANT	\N	PRESENT	0
370541	370539	08069G	PARTICIPANT	\N	PRESENT	0
370546	370545	19479G	PARTICIPANT	\N	PRESENT	0
370548	370547	08014Q	PARTICIPANT	\N	PRESENT	0
370549	370547	08069G	PARTICIPANT	\N	PRESENT	0
372757	372756	89017R	PARTICIPANT	\N	PRESENT	0
372758	372756	04085P	PARTICIPANT	\N	PRESENT	0
372759	372756	04059M	PARTICIPANT	\N	PRESENT	0
372761	372756	05008E	PARTICIPANT	\N	PRESENT	0
372763	372756	96004D	PARTICIPANT	\N	PRESENT	0
372765	372756	04040A	PARTICIPANT	\N	PRESENT	0
372767	372756	04042C	PARTICIPANT	\N	PRESENT	0
372768	372756	11027H	PARTICIPANT	\N	PRESENT	0
372770	372756	19521Q	PARTICIPANT	\N	PRESENT	0
372772	372756	14034U	PARTICIPANT	\N	PRESENT	0
372773	372756	01043Q	PARTICIPANT	\N	PRESENT	0
372774	372756	14251Q	PARTICIPANT	\N	PRESENT	0
372776	372756	08009T	PARTICIPANT	\N	PRESENT	0
372777	372756	04092N	PARTICIPANT	\N	PRESENT	0
372779	372756	11072N	PARTICIPANT	\N	PRESENT	0
372780	372756	08011M	PARTICIPANT	\N	PRESENT	0
372782	372756	04070G	PARTICIPANT	\N	PRESENT	0
372784	372756	14071N	PARTICIPANT	\N	PRESENT	0
372785	372756	08061X	PARTICIPANT	\N	PRESENT	0
372787	372756	05012A	PARTICIPANT	\N	PRESENT	0
372788	372756	11090Q	PARTICIPANT	\N	PRESENT	0
372789	372756	11012A	PARTICIPANT	\N	PRESENT	0
372790	372756	01028R	PARTICIPANT	\N	PRESENT	0
373787	373786	04049K	PARTICIPANT	\N	PRESENT	0
373791	373790	14026U	PARTICIPANT	\N	PRESENT	0
373793	373792	14026U	PARTICIPANT	\N	PRESENT	0
376777	375049	14147R	PARTICIPANT	\N	PRESENT	0
384259	384258	80013X	PARTICIPANT	\N	PRESENT	0
385801	384602	19697Q	PARTICIPANT	\N	PRESENT	0
385802	384602	11067R	PARTICIPANT	\N	PRESENT	0
385803	384602	19565D	PARTICIPANT	\N	PRESENT	0
385804	384602	14355X	PARTICIPANT	\N	PRESENT	0
385805	384602	19569H	PARTICIPANT	\N	PRESENT	0
385806	384602	11097X	PARTICIPANT	0	PRESENT	0
385807	384602	19415P	PARTICIPANT	\N	PRESENT	0
385808	384602	14223L	PARTICIPANT	\N	PRESENT	0
391286	385081	19629C	PARTICIPANT	\N	EXCUSE	0
391287	385081	19737F	PARTICIPANT	\N	EXCUSE	0
391288	385081	19711U	PARTICIPANT	\N	EXCUSE	0
391290	385081	08069G	PARTICIPANT	\N	EXCUSE	0
391296	385081	11097X	PARTICIPANT	\N	PRESENT	0
391297	385081	08062Y	PARTICIPANT	\N	EXCUSE	0
391298	385081	19479G	PARTICIPANT	\N	EXCUSE	0
391299	385081	19399H	PARTICIPANT	\N	PRESENT	0
391313	385081	19467C	PARTICIPANT	\N	PRESENT	0
391314	385081	01028R	PARTICIPANT	\N	EXCUSE	0
391315	385081	19551W	PARTICIPANT	\N	EXCUSE	0
391316	385081	19369B	PARTICIPANT	\N	EXCUSE	0
391332	385081	14147R	PARTICIPANT	\N	PRESENT	0
391361	385081	19515S	PARTICIPANT	\N	EXCUSE	0
391362	385081	19421M	PARTICIPANT	\N	EXCUSE	0
391366	385081	11066Q	PARTICIPANT	\N	PRESENT	0
391586	391583	14217N	PARTICIPANT	\N	PRESENT	0
391587	391583	11083R	PARTICIPANT	\N	PRESENT	0
391588	391583	19798U	PARTICIPANT	\N	PRESENT	0
391589	377992	17583W	PARTICIPANT	\N	PRESENT	0
391590	377992	11067R	PARTICIPANT	\N	PRESENT	0
391591	377992	14215L	PARTICIPANT	\N	PRESENT	0
391592	386240	19565D	PARTICIPANT	\N	PRESENT	0
391593	386240	14231L	PARTICIPANT	\N	PRESENT	0
391594	386240	11048N	PARTICIPANT	\N	EXCUSE	0
391595	386240	14257W	PARTICIPANT	\N	EXCUSE	0
391596	377992	19737F	PARTICIPANT	\N	PRESENT	0
391597	386240	04045F	PARTICIPANT	\N	PRESENT	0
391598	386240	14151M	PARTICIPANT	\N	PRESENT	0
391599	386240	14147R	PARTICIPANT	\N	PRESENT	0
391600	377992	19621T	PARTICIPANT	\N	PRESENT	0
391601	377992	14121F	PARTICIPANT	\N	PRESENT	0
391602	377992	19593H	PARTICIPANT	\N	PRESENT	0
391603	377992	14038Y	PARTICIPANT	\N	PRESENT	0
391604	377992	11048N	PARTICIPANT	\N	PRESENT	0
391605	377992	19798U	PARTICIPANT	\N	PRESENT	0
391606	377992	11043H	PARTICIPANT	\N	PRESENT	0
391607	377992	11101A	PARTICIPANT	\N	PRESENT	0
391608	377992	14059S	PARTICIPANT	\N	PRESENT	0
391609	377992	14026U	PARTICIPANT	\N	PRESENT	0
391610	377992	04043D	PARTICIPANT	\N	PRESENT	0
391611	377992	04033B	PARTICIPANT	\N	PRESENT	0
391612	377992	14053L	PARTICIPANT	\N	PRESENT	0
391613	377992	19533U	PARTICIPANT	\N	PRESENT	0
391614	377992	08043V	PARTICIPANT	\N	PRESENT	0
391615	377992	08045X	PARTICIPANT	\N	PRESENT	0
391616	377992	14187A	PARTICIPANT	\N	PRESENT	0
391617	377992	11104D	PARTICIPANT	\N	PRESENT	0
391618	377992	08055A	PARTICIPANT	\N	PRESENT	0
391619	377992	14065Q	PARTICIPANT	\N	PRESENT	0
391620	377992	19794Q	PARTICIPANT	\N	PRESENT	0
391621	377992	14253S	PARTICIPANT	\N	PRESENT	0
391622	377992	19719D	PARTICIPANT	\N	PRESENT	0
391623	377992	19721W	PARTICIPANT	\N	PRESENT	0
391624	377992	80013X	PARTICIPANT	\N	PRESENT	0
391625	377992	14021P	PARTICIPANT	\N	PRESENT	0
391627	377992	14135M	PARTICIPANT	\N	PRESENT	0
391628	377992	19649G	PARTICIPANT	\N	PRESENT	0
391629	377992	08018U	PARTICIPANT	\N	PRESENT	0
391630	377992	19679N	PARTICIPANT	\N	PRESENT	0
391631	377992	19631V	PARTICIPANT	\N	PRESENT	0
391632	391356	07029T	PARTICIPANT	\N	EXCUSE	0
391633	391356	08010L	PARTICIPANT	\N	EXCUSE	0
391634	391356	11074Q	PARTICIPANT	\N	EXCUSE	0
391637	377992	14151M	PARTICIPANT	\N	PRESENT	0
391638	391356	14331P	PARTICIPANT	\N	PRESENT	0
391639	391356	11048N	PRESIDENT	0	PRESENT	0
391640	391356	19711U	PARTICIPANT	\N	PRESENT	0
391641	391356	19349W	PARTICIPANT	\N	PRESENT	0
391642	391356	19741B	PARTICIPANT	\N	PRESENT	0
391643	391356	14173T	PARTICIPANT	\N	PRESENT	0
391644	391356	04086Q	PARTICIPANT	\N	PRESENT	0
391645	391356	14327T	PARTICIPANT	\N	PRESENT	0
391646	391356	14159V	PARTICIPANT	\N	PRESENT	0
391647	377992	14147R	PARTICIPANT	\N	PRESENT	0
391648	377992	19693L	PARTICIPANT	\N	PRESENT	0
391649	377992	14217N	PARTICIPANT	\N	PRESENT	0
391650	391626	14053L	PARTICIPANT	\N	PRESENT	0
391651	391626	14065Q	PARTICIPANT	\N	PRESENT	0
391652	391626	14111D	PARTICIPANT	\N	PRESENT	0
391653	391626	08045X	PARTICIPANT	\N	PRESENT	0
391654	391626	01024M	PARTICIPANT	\N	PRESENT	0
391655	391626	04044E	PARTICIPANT	\N	PRESENT	0
391656	391626	19719D	PARTICIPANT	\N	PRESENT	0
391657	391626	01028R	PARTICIPANT	\N	PRESENT	0
391658	391626	05008E	PRESIDENT	0	PRESENT	0
391659	391626	19725B	PARTICIPANT	\N	PRESENT	0
391660	391626	19729F	PARTICIPANT	\N	PRESENT	0
391661	391626	08044W	PARTICIPANT	\N	PRESENT	0
391662	391626	14179A	PARTICIPANT	\N	PRESENT	0
391663	391626	14215L	PARTICIPANT	\N	PRESENT	0
391664	391626	14021P	PARTICIPANT	\N	PRESENT	0
391665	391626	11072N	PARTICIPANT	\N	PRESENT	0
391666	391626	19762G	PARTICIPANT	\N	PRESENT	0
391667	377992	04049K	PARTICIPANT	\N	PRESENT	0
391668	391356	08034U	PARTICIPANT	\N	PRESENT	0
391669	391356	01057W	PARTICIPANT	\N	PRESENT	0
391670	391356	14034U	PARTICIPANT	\N	PRESENT	0
391671	391356	14225N	PARTICIPANT	\N	PRESENT	0
391672	391356	14085U	PARTICIPANT	\N	PRESENT	0
391673	391356	19667J	PARTICIPANT	\N	PRESENT	0
391676	391356	08011M	PARTICIPANT	\N	PRESENT	0
391680	377992	19713W	PARTICIPANT	\N	PRESENT	0
391681	377992	15447F	PARTICIPANT	\N	PRESENT	0
391682	391356	14199E	PARTICIPANT	\N	PRESENT	0
391683	391356	19689Q	PARTICIPANT	\N	PRESENT	0
391684	377992	04045F	PARTICIPANT	\N	PRESENT	0
391685	377992	14001X	PARTICIPANT	\N	PRESENT	0
391686	377992	11049P	PARTICIPANT	\N	PRESENT	0
391687	391356	19671E	PARTICIPANT	\N	PRESENT	0
391688	391356	14083S	PARTICIPANT	\N	PRESENT	0
391689	377992	19521Q	PARTICIPANT	\N	PRESENT	0
391690	385081	08012N	PARTICIPANT	\N	EXCUSE	0
391692	391691	14073Q	PARTICIPANT	\N	PRESENT	0
391693	391691	08012N	PARTICIPANT	\N	PRESENT	0
391694	377992	19335Q	PARTICIPANT	\N	PRESENT	0
391695	377992	89017R	PARTICIPANT	\N	PRESENT	0
391696	377992	14213J	PARTICIPANT	\N	PRESENT	0
391697	377992	17779H	PARTICIPANT	\N	PRESENT	0
391698	377992	19413M	PARTICIPANT	\N	PRESENT	0
391699	377992	14169X	PARTICIPANT	\N	PRESENT	0
391700	377992	98022P	PARTICIPANT	\N	PRESENT	0
391701	377992	14205J	PARTICIPANT	\N	PRESENT	0
391702	377992	14073Q	PARTICIPANT	\N	PRESENT	0
391703	391356	19545Y	PARTICIPANT	\N	PRESENT	0
391704	391356	88008L	PARTICIPANT	\N	PRESENT	0
391705	377992	14030Q	PARTICIPANT	\N	PRESENT	0
391706	377992	19503N	PARTICIPANT	\N	PRESENT	0
391711	391709	19399H	PARTICIPANT	\N	PRESENT	0
391712	391709	19593H	PARTICIPANT	\N	PRESENT	0
391713	391710	19399H	PARTICIPANT	\N	PRESENT	0
391714	391710	19593H	PARTICIPANT	\N	PRESENT	0
391715	391710	14229S	PARTICIPANT	\N	PRESENT	0
391718	377992	14071N	PARTICIPANT	\N	PRESENT	0
391719	377992	14259Y	PARTICIPANT	\N	PRESENT	0
391720	377992	08034U	PARTICIPANT	\N	PRESENT	0
391793	378003	04044E	PARTICIPANT	\N	PRESENT	0
391794	378003	19758L	PARTICIPANT	\N	PRESENT	0
391795	378003	11031D	PARTICIPANT	\N	PRESENT	0
391796	378003	19695N	PARTICIPANT	\N	PRESENT	0
391797	378003	04085P	PARTICIPANT	\N	PRESENT	0
391798	378003	14235Q	PARTICIPANT	\N	PRESENT	0
391799	378003	14151M	PARTICIPANT	\N	PRESENT	0
391800	378003	14001X	PARTICIPANT	\N	PRESENT	0
391801	378003	14281W	PARTICIPANT	\N	PRESENT	0
391802	378003	19413M	PARTICIPANT	\N	PRESENT	0
391803	378003	11033F	PARTICIPANT	\N	PRESENT	0
391804	378003	19565D	PARTICIPANT	\N	PRESENT	0
391805	378003	01062T	PARTICIPANT	\N	PRESENT	0
363410	363409	19575F	PARTICIPANT	\N	PRESENT	0
363411	363409	19747H	PARTICIPANT	\N	PRESENT	0
363412	363409	19782L	PARTICIPANT	\N	PRESENT	0
363413	363409	14083S	PARTICIPANT	\N	PRESENT	0
363414	363409	19681G	PARTICIPANT	\N	PRESENT	0
363415	363409	80013X	PARTICIPANT	\N	PRESENT	0
363416	363409	14357A	PARTICIPANT	\N	PRESENT	0
363417	363409	17589D	PARTICIPANT	\N	PRESENT	0
363418	363409	01024M	PARTICIPANT	\N	PRESENT	0
363419	363409	14033T	PARTICIPANT	\N	PRESENT	0
363420	363409	19333N	PARTICIPANT	\N	PRESENT	0
363421	363409	14257W	PARTICIPANT	\N	PRESENT	0
363422	363409	14071N	PARTICIPANT	\N	PRESENT	0
363424	363423	14187A	PARTICIPANT	\N	PRESENT	0
364421	364420	11065P	PARTICIPANT	\N	PRESENT	0
364422	364420	19683J	PARTICIPANT	\N	PRESENT	0
364423	364420	14083S	PARTICIPANT	\N	PRESENT	0
364424	364420	14237S	PARTICIPANT	\N	PRESENT	0
368632	368631	14085U	PARTICIPANT	\N	PRESENT	0
368633	368631	04035D	PARTICIPANT	\N	PRESENT	0
368634	368631	07004J	PARTICIPANT	\N	PRESENT	0
368635	368631	10015M	PARTICIPANT	\N	PRESENT	0
368636	368631	19713W	PARTICIPANT	\N	PRESENT	0
368785	356668	19631V	PARTICIPANT	\N	EXCUSE	0
368786	356668	11109J	PARTICIPANT	\N	EXCUSE	0
368787	356668	19295A	PARTICIPANT	\N	EXCUSE	0
368788	356668	19729F	PARTICIPANT	\N	EXCUSE	0
368789	367258	19631V	PARTICIPANT	\N	EXCUSE	0
368790	367258	11109J	PARTICIPANT	\N	EXCUSE	0
368791	367258	19295A	PARTICIPANT	\N	EXCUSE	0
368792	367258	19691J	PARTICIPANT	\N	EXCUSE	0
368793	367258	19729F	PARTICIPANT	\N	EXCUSE	0
370721	370720	14147R	PARTICIPANT	\N	PRESENT	0
372040	363529	11074Q	PARTICIPANT	\N	PRESENT	0
372041	363529	95067Q	PARTICIPANT	\N	PRESENT	0
372042	363529	04049K	PARTICIPANT	\N	PRESENT	0
372043	363529	14159V	PARTICIPANT	\N	PRESENT	0
372044	363529	08052W	PARTICIPANT	\N	PRESENT	0
372045	363529	14115H	PARTICIPANT	\N	PRESENT	0
372046	363529	17583W	PARTICIPANT	\N	PRESENT	0
372047	363529	14147R	PARTICIPANT	\N	PRESENT	0
372048	363529	19689Q	PARTICIPANT	\N	PRESENT	0
372049	363529	08068F	PARTICIPANT	\N	PRESENT	0
372050	363529	14038Y	PARTICIPANT	\N	PRESENT	0
372038	363529	11049P	PARTICIPANT	\N	PRESENT	0
372039	363529	11027H	PARTICIPANT	\N	PRESENT	0
372051	363529	19467C	PARTICIPANT	\N	PRESENT	0
372052	363529	14151M	PARTICIPANT	\N	PRESENT	0
372053	363529	18083K	PARTICIPANT	\N	PRESENT	0
372055	363529	12016W	PARTICIPANT	\N	PRESENT	0
372056	363529	19794Q	PARTICIPANT	\N	PRESENT	0
372057	363529	19715Y	PARTICIPANT	\N	PRESENT	0
372058	363529	19669L	PARTICIPANT	\N	PRESENT	0
372059	363529	14033T	PARTICIPANT	\N	PRESENT	0
372060	363529	08045X	PARTICIPANT	\N	PRESENT	0
372061	363529	14135M	PARTICIPANT	\N	PRESENT	0
372062	363529	08060W	PARTICIPANT	\N	PRESENT	0
372063	363529	08019V	PARTICIPANT	\N	PRESENT	0
372064	363529	19399H	PARTICIPANT	\N	PRESENT	0
372065	363529	19693L	PARTICIPANT	\N	PRESENT	0
372066	363529	14021P	PARTICIPANT	\N	PRESENT	0
372067	363529	14265W	PARTICIPANT	\N	PRESENT	0
372068	363529	14213J	PARTICIPANT	\N	PRESENT	0
372069	363529	19599P	PARTICIPANT	\N	PRESENT	0
372070	363529	19663E	PARTICIPANT	\N	PRESENT	0
372071	363529	19415P	PARTICIPANT	\N	PRESENT	0
372072	363529	19507S	PARTICIPANT	\N	PRESENT	0
372073	363529	80013X	PARTICIPANT	\N	PRESENT	0
372074	363529	07029T	PARTICIPANT	\N	PRESENT	0
372075	363529	08038Y	PARTICIPANT	\N	PRESENT	0
372076	363529	19657G	PARTICIPANT	\N	PRESENT	0
372077	363529	19269X	PARTICIPANT	\N	PRESENT	0
372078	363529	14355X	PARTICIPANT	\N	PRESENT	0
372079	363529	08062Y	PARTICIPANT	\N	PRESENT	0
372080	363529	14229S	PARTICIPANT	\N	PRESENT	0
372081	363529	14028W	PARTICIPANT	\N	PRESENT	0
372082	363529	19649G	PARTICIPANT	\N	PRESENT	0
372083	363529	19647E	PARTICIPANT	\N	PRESENT	0
372084	363529	08015R	PARTICIPANT	\N	PRESENT	0
372085	363529	11066Q	PARTICIPANT	\N	PRESENT	0
372086	363529	14061L	PARTICIPANT	\N	PRESENT	0
372087	363529	08043V	PARTICIPANT	\N	PRESENT	0
372088	363529	04097T	PARTICIPANT	\N	PRESENT	0
372089	363529	14026U	PARTICIPANT	\N	PRESENT	0
372090	363529	11104D	PARTICIPANT	\N	PRESENT	0
372091	363529	80027E	PARTICIPANT	\N	PRESENT	0
372092	363529	08017T	PARTICIPANT	\N	PRESENT	0
372093	363529	04043D	PARTICIPANT	\N	PRESENT	0
372094	363529	14121F	PARTICIPANT	\N	PRESENT	0
372095	363529	14329V	PARTICIPANT	\N	PRESENT	0
372096	363529	14085U	PARTICIPANT	\N	PRESENT	0
372097	363529	14357A	PARTICIPANT	\N	PRESENT	0
372098	363529	19675J	PARTICIPANT	\N	PRESENT	0
372099	363529	11099A	PARTICIPANT	\N	PRESENT	0
372100	363529	19383Y	PARTICIPANT	\N	PRESENT	0
372101	363529	19295A	PARTICIPANT	\N	PRESENT	0
372102	363529	19762G	PARTICIPANT	\N	PRESENT	0
372103	363529	19683J	PARTICIPANT	\N	PRESENT	0
372104	363529	14051J	PARTICIPANT	\N	PRESENT	0
372105	363529	19701S	PARTICIPANT	\N	PRESENT	0
372106	363529	14281W	PARTICIPANT	\N	PRESENT	0
372107	363529	04018C	PARTICIPANT	\N	PRESENT	0
372108	363529	19621T	PARTICIPANT	\N	PRESENT	0
372109	363529	14207L	PARTICIPANT	\N	PRESENT	0
372110	363529	19333N	PARTICIPANT	\N	PRESENT	0
372111	363529	19367Y	PARTICIPANT	\N	PRESENT	0
372112	363529	11077T	PARTICIPANT	\N	PRESENT	0
372113	363529	19725B	PARTICIPANT	\N	PRESENT	0
372114	363529	11103C	PARTICIPANT	\N	PRESENT	0
372115	363529	14257W	PARTICIPANT	\N	PRESENT	0
372116	363529	07033P	PARTICIPANT	\N	PRESENT	0
372117	363529	14063N	PARTICIPANT	\N	PRESENT	0
372118	363529	14109K	PARTICIPANT	\N	PRESENT	0
372119	363529	14217N	PARTICIPANT	\N	PRESENT	0
372120	363529	11067R	PARTICIPANT	\N	PRESENT	0
372121	363529	14331P	PARTICIPANT	\N	PRESENT	0
372122	363529	19503N	PARTICIPANT	\N	PRESENT	0
372123	363529	04061F	PARTICIPANT	\N	PRESENT	0
372124	363529	19551W	PARTICIPANT	\N	PRESENT	0
372125	363529	19671E	PARTICIPANT	\N	PRESENT	0
372126	363529	19369B	PARTICIPANT	\N	PRESENT	0
372127	363529	19691J	PARTICIPANT	\N	PRESENT	0
372128	363529	08009T	PARTICIPANT	\N	PRESENT	0
372129	363529	05012A	PARTICIPANT	\N	PRESENT	0
372130	363529	11053K	PARTICIPANT	\N	PRESENT	0
372131	363529	19611R	PARTICIPANT	\N	PRESENT	0
372132	363529	19511N	PARTICIPANT	\N	PRESENT	0
372133	363529	08034U	PARTICIPANT	\N	PRESENT	0
372134	363529	19737F	PARTICIPANT	\N	PRESENT	0
372135	363529	19533U	PARTICIPANT	\N	PRESENT	0
372136	363529	14205J	PARTICIPANT	\N	PRESENT	0
372137	363529	10006L	PARTICIPANT	\N	PRESENT	0
372138	363529	19721W	PARTICIPANT	\N	PRESENT	0
372139	363529	19798U	PARTICIPANT	\N	PRESENT	0
372140	363529	19569H	PARTICIPANT	\N	PRESENT	0
372141	363529	14069U	PARTICIPANT	\N	PRESENT	0
372142	363529	19735D	PARTICIPANT	\N	PRESENT	0
372143	363529	14249W	PARTICIPANT	\N	PRESENT	0
372144	363529	14219Q	PARTICIPANT	\N	PRESENT	0
372145	363529	14053L	PARTICIPANT	\N	PRESENT	0
372150	363529	19543W	PARTICIPANT	\N	PRESENT	0
372147	363529	14087W	PARTICIPANT	\N	PRESENT	0
372148	363529	19479G	PARTICIPANT	\N	PRESENT	0
372149	363529	14215L	PARTICIPANT	\N	PRESENT	0
372151	363529	04033B	PARTICIPANT	\N	PRESENT	0
372152	363529	19441R	PARTICIPANT	\N	PRESENT	0
372153	363529	14187A	PARTICIPANT	\N	PRESENT	0
372154	363529	14071N	PARTICIPANT	\N	PRESENT	0
372155	363529	05008E	PARTICIPANT	\N	PRESENT	0
372156	363529	19727D	PARTICIPANT	\N	PRESENT	0
372157	363529	11097X	PARTICIPANT	\N	PRESENT	0
372158	363529	14275Y	PARTICIPANT	\N	PRESENT	0
372159	363529	19421M	PARTICIPANT	\N	PRESENT	0
372160	363529	14277B	PARTICIPANT	\N	PRESENT	0
372161	363529	14267Y	PARTICIPANT	\N	PRESENT	0
372162	363529	04092N	PARTICIPANT	\N	PRESENT	0
372163	363529	14103D	PARTICIPANT	\N	PRESENT	0
372164	363529	14221J	PARTICIPANT	\N	PRESENT	0
372165	363529	95030B	PARTICIPANT	\N	PRESENT	0
372166	363529	19739H	PARTICIPANT	\N	PRESENT	0
372167	363529	11101A	PARTICIPANT	\N	PRESENT	0
372168	363529	14042U	PARTICIPANT	\N	PRESENT	0
372169	363529	14073Q	PARTICIPANT	\N	PRESENT	0
372170	363529	14089Y	PARTICIPANT	\N	PRESENT	0
372171	363529	14083S	PARTICIPANT	\N	PRESENT	0
372172	363529	08018U	PARTICIPANT	\N	PRESENT	0
372173	363529	19521Q	PARTICIPANT	\N	PRESENT	0
372174	363529	14231L	PARTICIPANT	\N	PRESENT	0
372175	363529	19723Y	PARTICIPANT	\N	PRESENT	0
381896	378920	14051J	PARTICIPANT	\N	PRESENT	0
381897	378920	19794Q	PARTICIPANT	\N	PRESENT	0
381898	378920	14031R	PARTICIPANT	\N	PRESENT	0
381899	378920	08009T	PRESIDENT	0	PRESENT	0
381900	378920	19549D	PARTICIPANT	\N	PRESENT	0
381989	378920	14219Q	PARTICIPANT	\N	PRESENT	0
381902	378920	19745F	PARTICIPANT	\N	PRESENT	0
381903	378920	17637T	PARTICIPANT	\N	PRESENT	0
381904	378920	19685L	PARTICIPANT	\N	EXCUSE	0
381905	378920	19383Y	PARTICIPANT	\N	PRESENT	0
381906	378920	17583W	PARTICIPANT	\N	PRESENT	0
381907	378920	19551W	PARTICIPANT	\N	PRESENT	0
381908	378920	19333N	PARTICIPANT	\N	PRESENT	0
381909	378920	96004D	PARTICIPANT	\N	PRESENT	0
381910	378920	19503N	PARTICIPANT	\N	PRESENT	0
381911	378920	19739H	PARTICIPANT	\N	PRESENT	0
381912	378920	14157T	PARTICIPANT	\N	PRESENT	0
381913	378234	19697Q	PARTICIPANT	\N	PRESENT	0
381914	378234	11067R	PARTICIPANT	\N	PRESENT	0
381915	378234	19565D	PARTICIPANT	\N	PRESENT	0
381916	378234	19798U	PARTICIPANT	\N	PRESENT	0
381917	378234	19569H	PARTICIPANT	\N	PRESENT	0
381918	378234	11097X	PARTICIPANT	\N	PRESENT	0
381919	378234	14219Q	PARTICIPANT	\N	PRESENT	0
381920	378234	19415P	PARTICIPANT	\N	PRESENT	0
381921	378234	14223L	PARTICIPANT	\N	PRESENT	0
381922	378234	14026U	PARTICIPANT	\N	PRESENT	0
381923	378234	14227Q	PARTICIPANT	\N	PRESENT	0
381924	378234	17779H	PARTICIPANT	\N	PRESENT	0
381925	378234	14239U	PARTICIPANT	\N	PRESENT	0
381926	378234	19553Y	PARTICIPANT	\N	PRESENT	0
381927	378234	19703U	PARTICIPANT	\N	PRESENT	0
381928	378234	11031D	PARTICIPANT	\N	PRESENT	0
381929	378234	14281W	PARTICIPANT	\N	PRESENT	0
381930	378234	19679N	PARTICIPANT	\N	PRESENT	0
381931	378234	14042U	PARTICIPANT	\N	PRESENT	0
381932	378234	19575F	PARTICIPANT	\N	PRESENT	0
381933	378234	08048B	PARTICIPANT	\N	PRESENT	0
381934	378234	14195A	PARTICIPANT	\N	PRESENT	0
381935	378234	19367Y	PARTICIPANT	\N	PRESENT	0
381936	378234	14213J	PARTICIPANT	\N	PRESENT	0
381937	378234	14217N	PARTICIPANT	\N	PRESENT	0
381938	378234	14261S	PARTICIPANT	\N	PRESENT	0
381939	378234	19683J	PARTICIPANT	\N	PRESENT	0
381940	378234	10006L	PARTICIPANT	\N	PRESENT	0
381941	378234	98024R	PRESIDENT	0	PRESENT	0
381942	378234	19521Q	PARTICIPANT	\N	PRESENT	0
381943	378234	19527W	PARTICIPANT	\N	PRESENT	0
381944	378234	01034P	PARTICIPANT	\N	PRESENT	0
381945	378234	04092N	PARTICIPANT	\N	PRESENT	0
381946	378234	11045K	PARTICIPANT	\N	PRESENT	0
381947	378234	08052W	PARTICIPANT	\N	PRESENT	0
381948	378234	19301E	PARTICIPANT	\N	PRESENT	0
381949	378234	19691J	PARTICIPANT	\N	PRESENT	0
381950	378234	19717B	PARTICIPANT	\N	PRESENT	0
381951	378234	19727D	PARTICIPANT	\N	PRESENT	0
381952	378234	14119M	PARTICIPANT	\N	PRESENT	0
381953	378234	11103C	PARTICIPANT	\N	PRESENT	0
381954	378234	19657G	PARTICIPANT	\N	PRESENT	0
381955	378234	14071N	PARTICIPANT	\N	PRESENT	0
381956	378234	19760E	PARTICIPANT	\N	PRESENT	0
381957	378234	08041T	PARTICIPANT	\N	EXCUSE	0
381958	378920	19347U	PARTICIPANT	\N	PRESENT	0
381959	378920	04097T	PARTICIPANT	\N	PRESENT	0
381960	378920	08024S	PARTICIPANT	\N	PRESENT	0
381961	378922	01048V	PARTICIPANT	\N	PRESENT	0
381962	378922	14225N	PARTICIPANT	\N	PRESENT	0
381963	378922	11110B	PARTICIPANT	\N	PRESENT	0
381964	378922	11048N	PARTICIPANT	\N	PRESENT	0
381965	378922	19647E	PARTICIPANT	\N	PRESENT	0
381966	378922	19651A	PARTICIPANT	\N	PRESENT	0
381967	378922	08011M	PARTICIPANT	\N	PRESENT	0
381968	378922	14083S	PARTICIPANT	\N	PRESENT	0
381969	378922	11040E	PARTICIPANT	\N	EXCUSE	0
381970	378922	04086Q	PARTICIPANT	\N	EXCUSE	0
381971	378922	08034U	PARTICIPANT	\N	EXCUSE	0
381972	378922	11053K	PARTICIPANT	\N	EXCUSE	0
381973	378922	12016W	PARTICIPANT	\N	EXCUSE	0
381974	378922	14034U	PARTICIPANT	\N	EXCUSE	0
381975	378922	14159V	PARTICIPANT	\N	EXCUSE	0
381976	378922	11070L	PARTICIPANT	\N	EXCUSE	0
381981	378920	14103D	PARTICIPANT	\N	PRESENT	0
381982	378920	08060W	PARTICIPANT	\N	PRESENT	0
381983	378920	19681G	PARTICIPANT	\N	PRESENT	0
381984	378920	08055A	PARTICIPANT	\N	PRESENT	0
381985	378920	19737F	PARTICIPANT	\N	PRESENT	0
381986	378920	19701S	PARTICIPANT	\N	PRESENT	0
381987	378920	14169X	PARTICIPANT	\N	PRESENT	0
381990	378929	19443T	PARTICIPANT	\N	PRESENT	0
381991	378929	12041X	PARTICIPANT	\N	PRESENT	0
381992	378929	95030B	PARTICIPANT	\N	PRESENT	0
381993	378929	14133K	PARTICIPANT	\N	PRESENT	0
381994	378929	08049C	PARTICIPANT	\N	PRESENT	0
381995	378929	04040A	PARTICIPANT	\N	PRESENT	0
381996	378929	14267Y	PARTICIPANT	\N	PRESENT	0
381997	378929	08058D	PARTICIPANT	\N	PRESENT	0
381998	378929	04042C	PRESIDENT	0	PRESENT	0
381999	378929	11054L	PARTICIPANT	\N	PRESENT	0
382000	378929	19721W	PARTICIPANT	\N	PRESENT	0
382002	378920	14237S	PARTICIPANT	\N	PRESENT	0
382003	378929	04034C	PARTICIPANT	\N	PRESENT	0
382004	378929	01058X	PARTICIPANT	\N	PRESENT	0
382005	378929	16685X	PARTICIPANT	\N	PRESENT	0
382006	378929	08056B	PARTICIPANT	\N	PRESENT	0
382007	378929	97011G	PARTICIPANT	\N	PRESENT	0
382008	378929	08047A	PARTICIPANT	\N	PRESENT	0
382009	378929	98029W	PARTICIPANT	\N	PRESENT	0
382010	378929	19591F	PARTICIPANT	\N	PRESENT	0
382011	378929	14097Y	PARTICIPANT	\N	PRESENT	0
382012	378929	95067Q	PARTICIPANT	\N	PRESENT	0
382013	378929	19251M	PARTICIPANT	\N	PRESENT	0
382014	378929	14105F	PARTICIPANT	\N	PRESENT	0
382015	378929	19507S	PARTICIPANT	\N	PRESENT	0
382016	378929	98050T	PARTICIPANT	\N	PRESENT	0
382017	378929	04043D	PARTICIPANT	\N	PRESENT	0
382018	378929	19583F	PARTICIPANT	\N	PRESENT	0
382019	378929	14255U	PARTICIPANT	\N	PRESENT	0
382020	378929	17589D	PARTICIPANT	\N	PRESENT	0
382021	378929	11041F	PARTICIPANT	\N	PRESENT	0
382022	378929	98018T	PARTICIPANT	\N	EXCUSE	0
382023	378929	98022P	PARTICIPANT	\N	EXCUSE	0
382024	378929	14193X	PARTICIPANT	\N	EXCUSE	0
382025	378929	08068F	PARTICIPANT	\N	PRESENT	0
382026	378920	04085P	PARTICIPANT	\N	PRESENT	0
382027	378929	19515S	PARTICIPANT	\N	PRESENT	0
382028	378929	80013X	PARTICIPANT	\N	PRESENT	0
382029	378929	14187A	PARTICIPANT	\N	PRESENT	0
382030	378929	01025N	PARTICIPANT	\N	PRESENT	0
382031	378929	11090Q	PARTICIPANT	\N	PRESENT	0
382032	378929	14207L	PARTICIPANT	\N	PRESENT	0
382033	378929	14257W	PARTICIPANT	\N	PRESENT	0
382034	378929	14357A	PARTICIPANT	\N	PRESENT	0
382035	378929	14079W	PARTICIPANT	\N	PRESENT	0
382036	378929	19631V	PARTICIPANT	\N	PRESENT	0
382037	378929	08019V	PARTICIPANT	\N	PRESENT	0
382038	378929	14197C	PARTICIPANT	\N	PRESENT	0
382039	378929	19511N	PARTICIPANT	\N	PRESENT	0
382040	378929	19563B	PARTICIPANT	\N	PRESENT	0
382041	378929	11081P	PARTICIPANT	\N	PRESENT	0
382042	378929	08028W	PARTICIPANT	\N	PRESENT	0
382043	378929	14265W	PARTICIPANT	\N	PRESENT	0
382044	378929	14329V	PARTICIPANT	\N	PRESENT	0
382045	378929	19467C	PARTICIPANT	\N	PRESENT	0
382046	378929	14033T	PARTICIPANT	\N	PRESENT	0
382047	378929	14205J	PARTICIPANT	\N	PRESENT	0
382048	378929	04088S	PARTICIPANT	\N	PRESENT	0
382049	378929	19747H	PARTICIPANT	\N	PRESENT	0
382050	378929	19619A	PARTICIPANT	\N	PRESENT	0
382051	378929	19705W	PARTICIPANT	\N	PRESENT	0
382052	380226	19766L	PARTICIPANT	\N	PRESENT	0
382053	380226	04070G	PRESIDENT	0	PRESENT	0
382054	380226	04033B	PARTICIPANT	\N	PRESENT	0
382055	380226	14229S	PARTICIPANT	\N	PRESENT	0
382056	380226	14241N	PARTICIPANT	\N	PRESENT	0
382057	380226	19573D	PARTICIPANT	\N	PRESENT	0
382058	380226	14107H	PARTICIPANT	\N	PRESENT	0
382059	380226	08017T	PARTICIPANT	\N	PRESENT	0
382060	380226	07033P	PARTICIPANT	\N	PRESENT	0
382061	380226	08012N	PARTICIPANT	\N	PRESENT	0
382062	380226	14249W	PARTICIPANT	\N	PRESENT	0
382063	380226	08039A	PARTICIPANT	\N	PRESENT	0
382064	380226	08031R	PARTICIPANT	\N	PRESENT	0
382065	380226	19593H	PARTICIPANT	\N	PRESENT	0
382066	380226	19643A	PARTICIPANT	\N	PRESENT	0
382067	380226	14059S	PARTICIPANT	\N	PRESENT	0
382068	380226	04057K	PARTICIPANT	\N	PRESENT	0
382069	380226	14073Q	PARTICIPANT	\N	PRESENT	0
382070	380226	08043V	PARTICIPANT	\N	PRESENT	0
382071	380226	19693L	PARTICIPANT	\N	PRESENT	0
362804	362803	19713W	PARTICIPANT	\N	PRESENT	0
362805	362803	07004J	PARTICIPANT	\N	PRESENT	0
362806	362803	10015M	PARTICIPANT	\N	PRESENT	0
362807	362803	14079W	PARTICIPANT	\N	PRESENT	0
362808	362803	14085U	PARTICIPANT	\N	PRESENT	0
362809	362803	04040A	PARTICIPANT	\N	PRESENT	0
364553	364552	14239U	PARTICIPANT	\N	PRESENT	0
364554	364552	19251M	PARTICIPANT	\N	PRESENT	0
364555	364552	14087W	PARTICIPANT	\N	PRESENT	0
364556	364552	97011G	PARTICIPANT	\N	PRESENT	0
364557	364552	98022P	PARTICIPANT	\N	PRESENT	0
364558	364552	19593H	PARTICIPANT	\N	PRESENT	0
364559	364552	11026G	PARTICIPANT	\N	PRESENT	0
364560	364552	14179A	PARTICIPANT	\N	PRESENT	0
364561	364552	19647E	PARTICIPANT	\N	PRESENT	0
368783	368782	14187A	PARTICIPANT	\N	PRESENT	0
368995	367087	14329V	PARTICIPANT	\N	EXCUSE	0
378917	378915	14199E	PARTICIPANT	\N	PRESENT	0
378918	378916	14199E	PARTICIPANT	\N	PRESENT	0
379325	379323	14253S	PARTICIPANT	\N	PRESENT	0
368993	367087	11081P	PARTICIPANT	\N	EXCUSE	0
368994	367087	14357A	PARTICIPANT	\N	EXCUSE	0
379326	379323	14085U	PARTICIPANT	\N	PRESENT	0
385809	384602	04045F	PARTICIPANT	\N	PRESENT	0
385810	384602	14227Q	PARTICIPANT	\N	PRESENT	0
385811	384602	17779H	PARTICIPANT	\N	PRESENT	0
385812	384602	19553Y	PARTICIPANT	\N	PRESENT	0
385813	384602	14087W	PARTICIPANT	\N	PRESENT	0
385814	384602	19679N	PARTICIPANT	\N	PRESENT	0
385815	384602	14195A	PARTICIPANT	\N	PRESENT	0
385816	384602	19575F	PARTICIPANT	\N	PRESENT	0
385817	384602	19367Y	PARTICIPANT	\N	PRESENT	0
385818	384602	14213J	PARTICIPANT	\N	PRESENT	0
385819	384602	14217N	PARTICIPANT	\N	PRESENT	0
385820	384602	19521Q	PARTICIPANT	\N	PRESENT	0
385821	384602	19527W	PARTICIPANT	\N	PRESENT	0
385822	384602	04092N	PARTICIPANT	\N	PRESENT	0
385823	384602	11045K	PARTICIPANT	\N	PRESENT	0
385824	384602	08052W	PARTICIPANT	\N	PRESENT	0
385825	384602	19301E	PARTICIPANT	\N	PRESENT	0
385826	384602	19691J	PARTICIPANT	\N	PRESENT	0
385827	384602	19715Y	PARTICIPANT	\N	PRESENT	0
385828	384602	19727D	PARTICIPANT	\N	PRESENT	0
385829	384602	14119M	PARTICIPANT	\N	PRESENT	0
385830	384602	11103C	PARTICIPANT	\N	PRESENT	0
385831	384602	19657G	PARTICIPANT	\N	PRESENT	0
385832	384602	14071N	PARTICIPANT	\N	PRESENT	0
385833	384602	19760E	PARTICIPANT	\N	PRESENT	0
385834	384602	08041T	PARTICIPANT	\N	EXCUSE	0
385835	382827	14038Y	PARTICIPANT	\N	PRESENT	0
385836	382827	19387D	PARTICIPANT	\N	PRESENT	0
385837	382827	14221J	PARTICIPANT	\N	PRESENT	0
385838	382827	80027E	PARTICIPANT	\N	PRESENT	0
385839	382827	08060W	PARTICIPANT	\N	PRESENT	0
385840	382827	19347U	PARTICIPANT	\N	PRESENT	0
385841	382827	19739H	PARTICIPANT	\N	PRESENT	0
385842	382827	19383Y	PARTICIPANT	\N	PRESENT	0
385843	382827	14029X	PARTICIPANT	\N	PRESENT	0
385844	382827	14237S	PARTICIPANT	\N	PRESENT	0
385863	382827	04097T	PARTICIPANT	\N	PRESENT	0
385888	382827	19549D	PARTICIPANT	\N	PRESENT	0
385889	382827	02002K	PARTICIPANT	\N	PRESENT	0
385890	384434	11115U	PARTICIPANT	\N	PRESENT	0
385891	384434	14097Y	PARTICIPANT	\N	PRESENT	0
385892	384434	95067Q	PARTICIPANT	\N	PRESENT	0
385895	385587	14001X	PARTICIPANT	\N	PRESENT	0
385896	385587	01060R	PARTICIPANT	\N	PRESENT	0
385897	385587	19581D	PARTICIPANT	\N	PRESENT	0
385898	385587	04044E	PARTICIPANT	\N	PRESENT	0
385899	385587	19585H	PARTICIPANT	\N	PRESENT	0
385900	385587	04047H	PARTICIPANT	\N	PRESENT	0
385901	385587	19673G	PARTICIPANT	\N	PRESENT	0
385902	385587	19675J	PARTICIPANT	\N	PRESENT	0
385903	385587	01028R	PARTICIPANT	\N	PRESENT	0
385904	385587	19447X	PARTICIPANT	\N	PRESENT	0
385905	385587	05008E	PRESIDENT	1	PRESENT	0
385906	385587	14231L	PARTICIPANT	\N	PRESENT	0
385907	385587	19489J	PARTICIPANT	\N	PRESENT	0
385908	385587	14041T	PARTICIPANT	\N	PRESENT	0
385909	385587	14147R	PARTICIPANT	\N	PRESENT	0
385910	385587	14179A	PARTICIPANT	\N	PRESENT	0
385911	385587	14151M	PARTICIPANT	\N	PRESENT	0
385912	385587	14215L	PRESIDENT	0	PRESENT	0
385913	385587	14259Y	PARTICIPANT	\N	PRESENT	0
385914	385587	11072N	PARTICIPANT	\N	PRESENT	0
385915	385587	14065Q	PARTICIPANT	\N	PRESENT	0
385916	385587	19649G	PARTICIPANT	\N	PRESENT	0
385917	385587	11010L	PARTICIPANT	\N	PRESENT	0
385918	385587	10015M	PARTICIPANT	\N	PRESENT	0
385919	385587	08045X	PARTICIPANT	\N	PRESENT	0
385920	385587	11026G	PARTICIPANT	\N	PRESENT	0
385921	385587	01024M	PARTICIPANT	\N	PRESENT	0
385922	385587	04038G	PARTICIPANT	\N	PRESENT	0
385923	385587	19719D	PARTICIPANT	\N	PRESENT	0
385924	385587	11033F	PARTICIPANT	\N	PRESENT	0
385925	385587	19725B	PARTICIPANT	\N	PRESENT	0
385926	385587	14089Y	PARTICIPANT	\N	PRESENT	0
385927	385587	19729F	PARTICIPANT	\N	PRESENT	0
385928	385587	95063L	PARTICIPANT	\N	PRESENT	0
385929	385587	08044W	PARTICIPANT	\N	PRESENT	0
385930	385587	14069U	PARTICIPANT	\N	PRESENT	0
385931	385587	11085T	PARTICIPANT	\N	PRESENT	0
385932	385587	04008A	PARTICIPANT	\N	PRESENT	0
385933	385587	19762G	PARTICIPANT	\N	PRESENT	0
385934	385587	08018U	PARTICIPANT	\N	EXCUSE	0
385936	382827	19701S	PARTICIPANT	\N	PRESENT	0
385937	382827	08024S	PARTICIPANT	\N	PRESENT	0
385938	382827	19737F	PARTICIPANT	\N	PRESENT	0
385950	384434	98018T	PARTICIPANT	\N	EXCUSE	0
385951	384434	19709B	PARTICIPANT	\N	EXCUSE	0
385952	384434	11027H	PARTICIPANT	\N	EXCUSE	0
385961	385960	14033T	PARTICIPANT	\N	PRESENT	0
385962	385960	14265W	PARTICIPANT	\N	PRESENT	0
385963	385960	19733B	PARTICIPANT	\N	PRESENT	0
385965	385964	19681G	PARTICIPANT	\N	EXCUSE	0
385966	385964	19599P	PARTICIPANT	\N	PRESENT	0
385967	385964	19695N	PARTICIPANT	\N	PRESENT	0
385968	385964	04049K	PARTICIPANT	\N	PRESENT	0
385969	385964	01043Q	PARTICIPANT	\N	PRESENT	0
385970	385964	19637C	PARTICIPANT	\N	PRESENT	0
385971	385964	19563B	PRESIDENT	0	PRESENT	0
385972	385964	19503N	PARTICIPANT	\N	PRESENT	0
385973	385964	19413M	PARTICIPANT	\N	PRESENT	0
385974	385964	95067Q	PARTICIPANT	\N	PRESENT	0
385975	385964	19585H	PARTICIPANT	\N	PRESENT	0
385976	384105	14081Q	PARTICIPANT	\N	PRESENT	0
385977	384105	08038Y	PARTICIPANT	\N	PRESENT	0
385978	384105	17589D	PARTICIPANT	\N	PRESENT	0
385984	385893	19533U	PARTICIPANT	\N	PRESENT	0
385985	385893	14001X	PARTICIPANT	\N	PRESENT	0
385986	385893	19543W	PARTICIPANT	\N	PRESENT	0
385987	385893	19581D	PARTICIPANT	\N	PRESENT	0
385988	385893	04044E	PARTICIPANT	\N	PRESENT	0
385989	385893	19585H	PARTICIPANT	\N	PRESENT	0
385990	385893	19671E	PARTICIPANT	\N	PRESENT	0
385991	385893	04047H	PARTICIPANT	\N	PRESENT	0
385992	385893	19673G	PARTICIPANT	\N	PRESENT	0
385993	385893	19675J	PARTICIPANT	\N	PRESENT	0
385994	385893	01028R	PARTICIPANT	\N	PRESENT	0
385995	385893	19447X	PARTICIPANT	\N	PRESENT	0
385996	385893	05008E	PRESIDENT	0	PRESENT	0
385997	385893	14231L	PARTICIPANT	\N	PRESENT	0
385998	385893	14237S	PARTICIPANT	\N	PRESENT	0
385999	385893	19489J	PARTICIPANT	\N	PRESENT	0
386000	385893	14041T	PARTICIPANT	\N	PRESENT	0
386001	385893	96004D	PARTICIPANT	\N	PRESENT	0
386002	385893	14147R	PARTICIPANT	\N	PRESENT	0
386003	385893	14215L	PARTICIPANT	\N	PRESENT	0
386004	385893	11072N	PARTICIPANT	\N	PRESENT	0
386005	385893	19649G	PARTICIPANT	\N	PRESENT	0
386006	385893	14065Q	PARTICIPANT	\N	PRESENT	0
386007	385893	10015M	PARTICIPANT	\N	PRESENT	0
386008	385893	11026G	PARTICIPANT	\N	PRESENT	0
386009	385893	08045X	PARTICIPANT	\N	PRESENT	0
386010	385893	19253P	PARTICIPANT	\N	PRESENT	0
386011	385893	01024M	PARTICIPANT	\N	PRESENT	0
386012	385893	04038G	PARTICIPANT	\N	PRESENT	0
386013	385893	11033F	PARTICIPANT	\N	PRESENT	0
386014	385893	14173T	PARTICIPANT	\N	PRESENT	0
386015	385893	19725B	PARTICIPANT	\N	PRESENT	0
386016	385893	19729F	PARTICIPANT	\N	PRESENT	0
386017	385893	19629C	PARTICIPANT	\N	PRESENT	0
386018	385893	04059M	PARTICIPANT	\N	PRESENT	0
386019	385893	08044W	PARTICIPANT	\N	PRESENT	0
386020	385893	11083R	PARTICIPANT	\N	PRESENT	0
386021	385893	04008A	PARTICIPANT	\N	PRESENT	0
386022	385893	14021P	PARTICIPANT	\N	PRESENT	0
386023	385893	14089Y	PARTICIPANT	\N	PRESENT	0
386024	385893	14053L	PARTICIPANT	\N	PRESENT	0
391364	391363	17779H	PARTICIPANT	\N	PRESENT	0
391365	391363	11097X	PARTICIPANT	\N	PRESENT	0
392002	378004	08044W	PARTICIPANT	\N	PRESENT	0
392003	378004	19703U	PARTICIPANT	\N	PRESENT	0
392004	378004	14147R	PARTICIPANT	\N	PRESENT	0
392005	378004	04049K	PARTICIPANT	\N	PRESENT	0
392006	378004	14069U	PARTICIPANT	\N	PRESENT	0
392007	378004	14357A	PARTICIPANT	\N	PRESENT	0
392008	378004	11056N	PARTICIPANT	\N	PRESENT	0
392009	378004	04088S	PARTICIPANT	\N	PRESENT	0
392010	378004	19507S	PARTICIPANT	\N	PRESENT	0
392011	378004	14265W	PARTICIPANT	\N	PRESENT	0
392012	378004	14026U	PARTICIPANT	\N	PRESENT	0
392013	378004	19762G	PARTICIPANT	\N	PRESENT	0
392014	378004	14034U	PARTICIPANT	\N	PRESENT	0
392015	378004	14219Q	PARTICIPANT	\N	PRESENT	0
392016	378004	19621T	PARTICIPANT	\N	PRESENT	0
392017	378004	08045X	PARTICIPANT	\N	PRESENT	0
392018	378004	19741B	PARTICIPANT	\N	PRESENT	0
392019	378004	14213J	PARTICIPANT	\N	PRESENT	0
392020	378004	19565D	PARTICIPANT	\N	PRESENT	0
392021	378004	14071N	PARTICIPANT	\N	PRESENT	0
392022	378004	14031R	PARTICIPANT	\N	PRESENT	0
392023	391307	14133K	PARTICIPANT	\N	PRESENT	0
392024	391307	04043D	PARTICIPANT	\N	PRESENT	0
392025	391307	19768N	PARTICIPANT	\N	PRESENT	0
392026	391307	11077T	PARTICIPANT	\N	PRESENT	0
392027	391307	19782L	PARTICIPANT	\N	PRESENT	0
392028	391307	14357A	PARTICIPANT	\N	PRESENT	0
392029	391307	19441R	PARTICIPANT	\N	PRESENT	0
392030	391307	19413M	PARTICIPANT	\N	PRESENT	0
392031	391307	80013X	PARTICIPANT	\N	PRESENT	0
392032	391307	19631V	PARTICIPANT	\N	PRESENT	0
392033	391307	04049K	PARTICIPANT	\N	PRESENT	0
392034	391307	19705W	PARTICIPANT	\N	PRESENT	0
392035	391307	08015R	PARTICIPANT	\N	PRESENT	0
392036	391307	14197C	PARTICIPANT	\N	PRESENT	0
392037	391307	19369B	PARTICIPANT	\N	PRESENT	0
392038	391307	14265W	PARTICIPANT	\N	PRESENT	0
392039	391307	14329V	PARTICIPANT	\N	PRESENT	0
392040	391307	19591F	PARTICIPANT	\N	PRESENT	0
392041	391307	19467C	PARTICIPANT	\N	PRESENT	0
392042	391307	14187A	PARTICIPANT	\N	PRESENT	0
392043	391307	19695N	PARTICIPANT	\N	PRESENT	0
392044	391307	11090Q	PRESIDENT	0	PRESENT	0
392045	391307	14033T	PARTICIPANT	\N	PRESENT	0
392046	391307	19269X	PARTICIPANT	\N	PRESENT	0
392047	391307	14205J	PARTICIPANT	\N	PRESENT	0
392048	391307	04088S	PARTICIPANT	\N	PRESENT	0
392049	391307	11056N	PARTICIPANT	\N	PRESENT	0
392050	391307	04089T	PARTICIPANT	\N	PRESENT	0
392051	391307	11101A	PARTICIPANT	\N	PRESENT	0
392052	391307	19507S	PARTICIPANT	\N	PRESENT	0
392053	391307	14207L	PARTICIPANT	\N	PRESENT	0
392054	391307	19747H	PARTICIPANT	\N	PRESENT	0
392055	391307	19619A	PARTICIPANT	\N	PRESENT	0
392056	391307	14257W	PARTICIPANT	\N	PRESENT	0
392057	391307	08062Y	PARTICIPANT	\N	EXCUSE	0
392058	391307	08021P	PARTICIPANT	\N	EXCUSE	0
392059	391307	08028W	PARTICIPANT	\N	PRESENT	0
392060	391307	11081P	PARTICIPANT	\N	EXCUSE	0
392061	391307	17589D	PARTICIPANT	\N	PRESENT	0
392062	391674	19766L	PARTICIPANT	\N	PRESENT	0
392063	391674	04070G	PRESIDENT	0	PRESENT	0
392064	391674	19699S	PARTICIPANT	\N	PRESENT	0
392065	391674	14229S	PARTICIPANT	\N	PRESENT	0
392066	391674	08017T	PARTICIPANT	\N	PRESENT	0
392067	391674	92040Q	PARTICIPANT	\N	PRESENT	0
392068	391674	19335Q	PARTICIPANT	\N	PRESENT	0
392069	391674	08039A	PARTICIPANT	\N	PRESENT	0
392070	391674	08031R	PARTICIPANT	\N	PRESENT	0
392071	391674	19593H	PARTICIPANT	\N	PRESENT	0
392072	391674	14059S	PARTICIPANT	\N	PRESENT	0
392073	391674	14061L	PARTICIPANT	\N	PRESENT	0
392074	391674	04057K	PARTICIPANT	\N	PRESENT	0
392075	391674	19611R	PARTICIPANT	\N	PRESENT	0
392076	391674	08043V	PARTICIPANT	\N	PRESENT	0
392077	391674	19693L	PARTICIPANT	\N	PRESENT	0
392078	391674	19399H	PARTICIPANT	\N	PRESENT	0
392079	391674	14201E	PARTICIPANT	\N	PRESENT	0
392080	391674	14030Q	PARTICIPANT	\N	PRESENT	0
392081	391674	19731Y	PARTICIPANT	\N	PRESENT	0
392082	391674	08020N	PARTICIPANT	\N	PRESENT	0
392083	391674	04059M	PARTICIPANT	\N	PRESENT	0
392084	391674	14063N	PARTICIPANT	\N	PRESENT	0
392085	391674	14123H	PARTICIPANT	\N	PRESENT	0
392086	391674	11104D	PARTICIPANT	\N	PRESENT	0
392087	391674	19749K	PARTICIPANT	\N	PRESENT	0
392088	391674	04018C	PARTICIPANT	\N	PRESENT	0
392089	391358	14327T	PARTICIPANT	\N	PRESENT	0
392090	391358	14331P	PARTICIPANT	\N	PRESENT	0
392091	391358	19479G	PARTICIPANT	\N	PRESENT	0
392092	391358	11048N	PARTICIPANT	\N	PRESENT	0
392093	391358	19711U	PARTICIPANT	\N	PRESENT	0
392094	391358	08034U	PARTICIPANT	\N	PRESENT	0
392095	391358	08069G	PARTICIPANT	\N	PRESENT	0
392096	391358	01057W	PARTICIPANT	\N	PRESENT	0
392097	391358	11074Q	PRESIDENT	0	PRESENT	0
392098	391358	08011M	PARTICIPANT	\N	PRESENT	0
392099	391358	89017R	PARTICIPANT	\N	PRESENT	0
392100	391358	14225N	PARTICIPANT	\N	PRESENT	0
392101	391358	19671E	PARTICIPANT	\N	PRESENT	0
392102	391358	88008L	PARTICIPANT	\N	PRESENT	0
392103	391358	11070L	PARTICIPANT	\N	PRESENT	0
392104	391358	14173T	PARTICIPANT	\N	PRESENT	0
392105	391358	11040E	PARTICIPANT	\N	PRESENT	0
392106	391358	14083S	PARTICIPANT	\N	PRESENT	0
392107	391358	11012A	PARTICIPANT	\N	PRESENT	0
392108	391358	14085U	PARTICIPANT	\N	PRESENT	0
392109	391358	19741B	PARTICIPANT	\N	PRESENT	0
392110	391358	99004R	PARTICIPANT	\N	PRESENT	0
392111	391358	14253S	PARTICIPANT	\N	PRESENT	0
392112	391358	07029T	PARTICIPANT	\N	EXCUSE	0
392113	391307	01043Q	PARTICIPANT	\N	PRESENT	0
392114	391307	08068F	PARTICIPANT	\N	PRESENT	0
392115	391307	08019V	PARTICIPANT	\N	PRESENT	0
392116	391307	19563B	PARTICIPANT	\N	PRESENT	0
392117	391307	14135M	PARTICIPANT	\N	PRESENT	0
392119	392118	11070L	PARTICIPANT	\N	PRESENT	0
392120	392118	19647E	PARTICIPANT	\N	PRESENT	0
392121	391674	19533U	PARTICIPANT	\N	PRESENT	0
392122	391674	04033B	PARTICIPANT	\N	PRESENT	0
392123	391674	19573D	PARTICIPANT	\N	PRESENT	0
392124	391674	14249W	PARTICIPANT	\N	PRESENT	0
392125	391674	19643A	PARTICIPANT	\N	PRESENT	0
392126	391674	14251Q	PARTICIPANT	\N	PRESENT	0
392127	391674	11083R	PARTICIPANT	\N	PRESENT	0
392128	391674	19621T	PARTICIPANT	\N	PRESENT	0
392129	391674	14039A	PARTICIPANT	\N	EXCUSE	0
392130	391674	87003B	PARTICIPANT	\N	EXCUSE	0
392131	391674	14241N	PARTICIPANT	\N	PRESENT	0
392132	391356	11070L	PARTICIPANT	\N	EXCUSE	0
392133	391356	19647E	PARTICIPANT	\N	EXCUSE	0
392134	391674	19758L	PARTICIPANT	\N	PRESENT	0
392135	391307	01025N	PARTICIPANT	\N	PRESENT	0
392137	392136	19667J	PARTICIPANT	\N	PRESENT	0
392138	392136	11040E	PARTICIPANT	\N	PRESENT	0
392139	389892	19760E	PARTICIPANT	\N	PRESENT	0
392140	389892	19727D	PARTICIPANT	\N	PRESENT	0
392141	389892	19565D	PARTICIPANT	\N	PRESENT	0
392142	389892	14227Q	PARTICIPANT	\N	PRESENT	0
392143	389892	17779H	PARTICIPANT	\N	PRESENT	0
392144	389892	11067R	PARTICIPANT	\N	PRESENT	0
392145	389892	14281W	PARTICIPANT	\N	PRESENT	0
392146	389892	08052W	PARTICIPANT	\N	PRESENT	0
392147	389892	19415P	PARTICIPANT	\N	PRESENT	0
392148	389892	14087W	PARTICIPANT	\N	PRESENT	0
392149	389892	14217N	PARTICIPANT	\N	PRESENT	0
392150	389892	14195A	PARTICIPANT	\N	PRESENT	0
392151	389892	19575F	PARTICIPANT	\N	PRESENT	0
392152	389892	19521Q	PARTICIPANT	\N	PRESENT	0
392153	389892	14042U	PARTICIPANT	\N	PRESENT	0
392157	389892	14213J	PARTICIPANT	\N	PRESENT	0
392155	389892	98024R	PARTICIPANT	\N	PRESENT	0
392156	389892	11103C	PARTICIPANT	\N	PRESENT	0
392158	389892	04092N	PRESIDENT	0	PRESENT	0
392159	389892	11097X	PARTICIPANT	\N	PRESENT	0
392160	389892	19703U	PARTICIPANT	\N	PRESENT	0
392161	389892	19798U	PARTICIPANT	\N	PRESENT	0
392162	389892	14026U	PARTICIPANT	\N	PRESENT	0
392163	389892	14223L	PARTICIPANT	\N	PRESENT	0
392164	391358	01048V	PARTICIPANT	\N	PRESENT	0
392165	391358	19545Y	PARTICIPANT	\N	PRESENT	0
392166	391358	08010L	PARTICIPANT	\N	PRESENT	0
392167	391358	19687N	PARTICIPANT	\N	PRESENT	0
392168	391307	11099A	PARTICIPANT	\N	PRESENT	0
392170	391674	14107H	PARTICIPANT	\N	PRESENT	0
392171	391674	14073Q	PARTICIPANT	\N	PRESENT	0
392172	391674	08035V	PARTICIPANT	\N	PRESENT	0
372176	363529	11085T	PARTICIPANT	\N	PRESENT	0
372177	363529	19673G	PARTICIPANT	\N	PRESENT	0
372178	363529	14059S	PARTICIPANT	\N	PRESENT	0
372179	363529	19549D	PARTICIPANT	\N	PRESENT	0
372180	363529	19577H	PARTICIPANT	\N	PRESENT	0
372181	363529	04040A	PARTICIPANT	\N	PRESENT	0
372182	363529	14030Q	PARTICIPANT	\N	PRESENT	0
372183	363529	01025N	PARTICIPANT	\N	PRESENT	0
372184	363529	86034E	PARTICIPANT	\N	PRESENT	0
372185	363529	14327T	PARTICIPANT	\N	PRESENT	0
372186	363529	19745F	PARTICIPANT	\N	PRESENT	0
372187	363529	19251M	PARTICIPANT	\N	PRESENT	0
372188	363529	19729F	PARTICIPANT	\N	PRESENT	0
372189	363529	14105F	PARTICIPANT	\N	PRESENT	0
372191	363529	98024R	PARTICIPANT	\N	PRESENT	0
372192	363529	19709B	PARTICIPANT	\N	PRESENT	0
372193	363529	19768N	PARTICIPANT	\N	PRESENT	0
372194	363529	04089T	PARTICIPANT	\N	PRESENT	0
372195	363529	11109J	PARTICIPANT	\N	PRESENT	0
372196	363529	08058D	PARTICIPANT	\N	PRESENT	0
372197	363529	19489J	PARTICIPANT	\N	PRESENT	0
372198	363529	11054L	PARTICIPANT	\N	PRESENT	0
372199	363529	04035D	PARTICIPANT	\N	PRESENT	0
372200	363529	11070L	PARTICIPANT	\N	PRESENT	0
372201	363529	17779H	PARTICIPANT	\N	PRESENT	0
372202	363529	19687N	PARTICIPANT	\N	PRESENT	0
372203	363529	96004D	PARTICIPANT	\N	PRESENT	0
372289	363529	04088S	PARTICIPANT	\N	PRESENT	0
372226	363529	19575F	PARTICIPANT	\N	PRESENT	0
372229	363529	01028R	PARTICIPANT	\N	PRESENT	0
372231	363529	01048V	PARTICIPANT	\N	PRESENT	0
372283	363529	19749K	PARTICIPANT	\N	PRESENT	0
372290	363529	19747H	PARTICIPANT	\N	PRESENT	0
372292	363529	14034U	PARTICIPANT	\N	PRESENT	0
372293	363529	19335Q	PARTICIPANT	\N	PRESENT	0
372295	363529	01024M	PARTICIPANT	\N	PRESENT	0
372296	363529	11040E	PARTICIPANT	\N	PRESENT	0
372297	363529	19741B	PARTICIPANT	\N	PRESENT	0
372560	356313	14034U	PARTICIPANT	\N	PRESENT	0
372561	356313	08009T	PARTICIPANT	\N	PRESENT	0
372562	356313	14329V	PARTICIPANT	\N	PRESENT	0
372563	356313	14103D	PARTICIPANT	\N	PRESENT	0
372564	356313	19503N	PARTICIPANT	\N	PRESENT	0
372565	356313	19333N	PARTICIPANT	\N	PRESENT	0
372566	356313	19549D	PARTICIPANT	\N	PRESENT	0
372567	356313	14257W	PARTICIPANT	\N	PRESENT	0
372568	356313	14207L	PARTICIPANT	\N	PRESENT	0
372569	356313	14195A	PARTICIPANT	\N	PRESENT	0
372570	356313	14111D	PARTICIPANT	\N	PRESENT	0
372571	356313	19717B	PARTICIPANT	\N	PRESENT	0
372572	356313	19737F	PARTICIPANT	\N	PRESENT	0
372573	356313	14205J	PARTICIPANT	\N	PRESENT	0
372574	356313	19739H	PARTICIPANT	\N	PRESENT	0
372575	356313	14093U	PARTICIPANT	\N	PRESENT	0
372576	356313	19347U	PARTICIPANT	\N	PRESENT	0
372577	356313	19687N	PARTICIPANT	\N	PRESENT	0
372578	356313	19565D	PARTICIPANT	\N	PRESENT	0
372579	356313	19301E	PARTICIPANT	\N	PRESENT	0
372580	356313	11065P	PARTICIPANT	\N	PRESENT	0
372581	356313	19629C	PARTICIPANT	\N	PRESENT	0
372582	356313	19782L	PARTICIPANT	\N	PRESENT	0
372583	356313	11103C	PARTICIPANT	\N	PRESENT	0
372584	356313	14147R	PARTICIPANT	\N	PRESENT	0
372585	356313	19768N	PARTICIPANT	\N	PRESENT	0
372586	356313	19794Q	PARTICIPANT	\N	PRESENT	0
372587	356313	14038Y	PARTICIPANT	\N	PRESENT	0
372588	356313	14033T	PARTICIPANT	\N	PRESENT	0
372589	356313	18083K	PARTICIPANT	\N	PRESENT	0
372590	356313	14211G	PARTICIPANT	\N	PRESENT	0
372591	356313	19679N	PARTICIPANT	\N	PRESENT	0
372592	356313	14241N	PARTICIPANT	\N	PRESENT	0
372593	356313	17583W	PARTICIPANT	\N	PRESENT	0
372594	356313	04089T	PARTICIPANT	\N	PRESENT	0
372595	356313	08061X	PARTICIPANT	\N	PRESENT	0
372596	356313	14169X	PARTICIPANT	\N	PRESENT	0
372597	356313	11090Q	PARTICIPANT	\N	PRESENT	0
372598	356313	14031R	PARTICIPANT	\N	PRESENT	0
372599	356313	19551W	PARTICIPANT	\N	PRESENT	0
372600	356313	07029T	PARTICIPANT	\N	PRESENT	0
372601	356313	19349W	PARTICIPANT	\N	PRESENT	0
372602	356313	14357A	PARTICIPANT	\N	PRESENT	0
372603	356313	11048N	PARTICIPANT	\N	PRESENT	0
372604	356313	19741B	PARTICIPANT	\N	PRESENT	0
372605	356313	14265W	PARTICIPANT	\N	PRESENT	0
372606	356313	14135M	PARTICIPANT	\N	PRESENT	0
372607	356313	19762G	PARTICIPANT	\N	PRESENT	0
372608	356313	19253P	PARTICIPANT	\N	PRESENT	0
372609	356313	19599P	PARTICIPANT	\N	PRESENT	0
372610	356313	19563B	PARTICIPANT	\N	PRESENT	0
372611	356313	19715Y	PARTICIPANT	\N	PRESENT	0
372612	356313	19387D	PARTICIPANT	\N	PRESENT	0
372613	356313	14221J	PARTICIPANT	\N	PRESENT	0
372614	356313	19383Y	PARTICIPANT	\N	PRESENT	0
372615	356313	14215L	PARTICIPANT	\N	PRESENT	0
372616	356313	05012A	PARTICIPANT	\N	PRESENT	0
372617	356313	14021P	PARTICIPANT	\N	PRESENT	0
372618	356313	19447X	PARTICIPANT	\N	PRESENT	0
372619	356313	19573D	PARTICIPANT	\N	PRESENT	0
372620	356313	14187A	PARTICIPANT	\N	PRESENT	0
372621	356313	11097X	PARTICIPANT	\N	PRESENT	0
372622	356313	08034U	PARTICIPANT	\N	PRESENT	0
372623	356313	14053L	PARTICIPANT	\N	PRESENT	0
372624	356313	14071N	PARTICIPANT	\N	PRESENT	0
372625	356313	14061L	PARTICIPANT	\N	PRESENT	0
372626	356313	14261S	PARTICIPANT	\N	PRESENT	0
372627	356313	80013X	PARTICIPANT	\N	PRESENT	0
372628	356313	11099A	PARTICIPANT	\N	PRESENT	0
372629	356313	14231L	PARTICIPANT	\N	PRESENT	0
372630	356313	19719D	PARTICIPANT	\N	PRESENT	0
372631	356313	14235Q	PARTICIPANT	\N	PRESENT	0
372632	356313	19507S	PARTICIPANT	\N	PRESENT	0
372633	356313	14213J	PARTICIPANT	\N	PRESENT	0
372634	356313	14069U	PARTICIPANT	\N	PRESENT	0
372635	356313	19760E	PARTICIPANT	\N	PRESENT	0
372636	356313	14331P	PARTICIPANT	\N	PRESENT	0
372637	356313	14083S	PARTICIPANT	\N	PRESENT	0
372638	356313	14089Y	PARTICIPANT	\N	PRESENT	0
372639	356313	19747H	PARTICIPANT	\N	PRESENT	0
372658	372657	19762G	PARTICIPANT	\N	PRESENT	0
372849	356314	19533U	PARTICIPANT	\N	PRESENT	0
372850	356314	05012A	PARTICIPANT	\N	PRESENT	0
372852	356314	19701S	PARTICIPANT	\N	PRESENT	0
372853	356314	04088S	PARTICIPANT	\N	PRESENT	0
372854	356314	19760E	PARTICIPANT	\N	PRESENT	0
372855	356314	19565D	PARTICIPANT	\N	PRESENT	0
372856	356314	19253P	PARTICIPANT	\N	PRESENT	0
372857	356314	14211G	PARTICIPANT	\N	PRESENT	0
372858	356314	14169X	PARTICIPANT	\N	PRESENT	0
372860	356314	19447X	PARTICIPANT	\N	PRESENT	0
372862	356314	14038Y	PARTICIPANT	\N	PRESENT	0
373065	356317	19503N	PARTICIPANT	\N	PRESENT	0
373066	356317	11067R	PARTICIPANT	\N	PRESENT	0
373067	356317	19573D	PARTICIPANT	\N	PRESENT	0
373068	356317	80027E	PARTICIPANT	\N	PRESENT	0
373069	356317	19794Q	PARTICIPANT	\N	PRESENT	0
373070	356317	19681G	PARTICIPANT	\N	PRESENT	0
373071	356317	88008L	PARTICIPANT	\N	PRESENT	0
373072	356317	14034U	PARTICIPANT	\N	PRESENT	0
373073	356317	14147R	PARTICIPANT	\N	PRESENT	0
373074	356317	14201E	PARTICIPANT	\N	PRESENT	0
373075	356317	19289C	PARTICIPANT	\N	PRESENT	0
373076	356317	19723Y	PARTICIPANT	\N	PRESENT	0
373077	356317	11099A	PARTICIPANT	\N	PRESENT	0
373078	356317	19467C	PARTICIPANT	\N	PRESENT	0
373079	356317	11065P	PARTICIPANT	\N	PRESENT	0
373080	356317	18083K	PARTICIPANT	\N	PRESENT	0
373081	356317	19387D	PARTICIPANT	\N	PRESENT	0
373082	356317	19415P	PARTICIPANT	\N	PRESENT	0
373083	356317	14135M	PARTICIPANT	\N	PRESENT	0
373084	356317	04057K	PARTICIPANT	\N	PRESENT	0
373085	356317	08019V	PARTICIPANT	\N	PRESENT	0
373086	356317	19717B	PARTICIPANT	\N	PRESENT	0
373087	356317	14213J	PARTICIPANT	\N	PRESENT	0
373088	356317	11033F	PARTICIPANT	\N	PRESENT	0
373089	356317	19709B	PARTICIPANT	\N	PRESENT	0
373090	356317	19687N	PARTICIPANT	\N	PRESENT	0
373091	356317	19663E	PARTICIPANT	\N	PRESENT	0
373092	356317	11072N	PARTICIPANT	\N	PRESENT	0
373093	356317	14207L	PARTICIPANT	\N	PRESENT	0
373094	356317	19507S	PARTICIPANT	\N	PRESENT	0
373095	356317	08018U	PARTICIPANT	\N	PRESENT	0
373096	356317	08062Y	PARTICIPANT	\N	PRESENT	0
373097	356317	19553Y	PARTICIPANT	\N	PRESENT	0
373098	356317	19729F	PARTICIPANT	\N	PRESENT	0
373099	356317	14111D	PARTICIPANT	\N	PRESENT	0
373100	356317	08015R	PARTICIPANT	\N	PRESENT	0
373101	356317	19705W	PARTICIPANT	\N	PRESENT	0
373102	356317	11053K	PARTICIPANT	\N	PRESENT	0
379889	379888	05008E	PARTICIPANT	\N	PRESENT	0
379891	379890	05008E	PARTICIPANT	\N	PRESENT	0
379893	379892	05008E	PARTICIPANT	\N	PRESENT	0
379894	379892	19489J	PARTICIPANT	\N	PRESENT	0
379896	379895	05008E	PARTICIPANT	\N	PRESENT	0
382072	380226	87003B	PARTICIPANT	\N	PRESENT	0
382073	380226	14201E	PARTICIPANT	\N	PRESENT	0
382074	380226	14030Q	PARTICIPANT	\N	PRESENT	0
382075	380226	08020N	PARTICIPANT	\N	PRESENT	0
382076	380226	14251Q	PARTICIPANT	\N	PRESENT	0
382077	380226	04059M	PARTICIPANT	\N	PRESENT	0
382078	380226	11109J	PARTICIPANT	\N	PRESENT	0
382079	380226	14063N	PARTICIPANT	\N	PRESENT	0
382080	380226	14109K	PARTICIPANT	\N	PRESENT	0
382081	380226	11083R	PARTICIPANT	\N	PRESENT	0
382082	380226	11104D	PARTICIPANT	\N	PRESENT	0
382083	380226	19749K	PARTICIPANT	\N	PRESENT	0
382084	380226	19758L	PARTICIPANT	\N	PRESENT	0
382085	378929	11099A	PARTICIPANT	\N	PRESENT	0
382086	378929	19695N	PARTICIPANT	\N	PRESENT	0
382087	378929	19413M	PARTICIPANT	\N	PRESENT	0
382088	378929	11101A	PARTICIPANT	\N	PRESENT	0
382089	378929	14331P	PARTICIPANT	\N	PRESENT	0
382090	379044	19515S	PARTICIPANT	\N	PRESENT	0
382091	379044	14357A	PARTICIPANT	\N	PRESENT	0
382092	379044	19441R	PARTICIPANT	\N	PRESENT	0
382093	379044	19413M	PARTICIPANT	\N	PRESENT	0
382094	379044	80013X	PARTICIPANT	\N	PRESENT	0
382095	379044	19631V	PARTICIPANT	\N	PRESENT	0
382096	379044	11099A	PARTICIPANT	\N	PRESENT	0
382097	379044	08068F	PARTICIPANT	\N	PRESENT	0
382098	379044	19705W	PARTICIPANT	\N	PRESENT	0
382099	379044	08019V	PARTICIPANT	\N	PRESENT	0
382100	379044	14197C	PARTICIPANT	\N	PRESENT	0
382101	379044	19369B	PARTICIPANT	\N	PRESENT	0
382102	379044	19511N	PARTICIPANT	\N	PRESENT	0
382103	379044	08028W	PARTICIPANT	\N	PRESENT	0
382104	379044	19563B	PARTICIPANT	\N	PRESENT	0
382105	379044	14265W	PARTICIPANT	\N	PRESENT	0
382106	379044	19591F	PARTICIPANT	\N	PRESENT	0
382107	379044	14329V	PARTICIPANT	\N	PRESENT	0
382108	379044	19467C	PARTICIPANT	\N	PRESENT	0
382109	379044	14187A	PARTICIPANT	\N	PRESENT	0
382110	379044	19695N	PARTICIPANT	\N	PRESENT	0
382111	379044	11090Q	PRESIDENT	0	PRESENT	0
382112	379044	14033T	PARTICIPANT	\N	PRESENT	0
382113	379044	01025N	PARTICIPANT	\N	PRESENT	0
382114	379044	14205J	PARTICIPANT	\N	PRESENT	0
382115	379044	04088S	PARTICIPANT	\N	PRESENT	0
382116	379044	14115H	PARTICIPANT	\N	PRESENT	0
382117	379044	19507S	PARTICIPANT	\N	PRESENT	0
382118	379044	11101A	PARTICIPANT	\N	PRESENT	0
382119	379044	14207L	PARTICIPANT	\N	PRESENT	0
382120	379044	19747H	PARTICIPANT	\N	PRESENT	0
382121	379044	04043D	PARTICIPANT	\N	PRESENT	0
382122	379044	19619A	PARTICIPANT	\N	PRESENT	0
382123	379044	17589D	PARTICIPANT	\N	PRESENT	0
382124	379044	14257W	PARTICIPANT	\N	PRESENT	0
382197	378923	08069G	PARTICIPANT	\N	PRESENT	0
382199	382198	19575F	PARTICIPANT	\N	PRESENT	0
382200	382198	14105F	PARTICIPANT	\N	PRESENT	0
382201	382198	19383Y	PARTICIPANT	\N	PRESENT	0
382202	382198	19782L	PARTICIPANT	\N	PRESENT	0
382203	382198	14207L	PARTICIPANT	\N	PRESENT	0
382204	382198	08028W	PARTICIPANT	\N	PRESENT	0
382205	382198	19467C	PARTICIPANT	\N	PRESENT	0
382206	382198	18083K	PARTICIPANT	\N	PRESENT	0
382207	382198	14357A	PARTICIPANT	\N	PRESENT	0
382208	382198	14217N	PARTICIPANT	\N	PRESENT	0
382209	382198	19507S	PARTICIPANT	\N	PRESENT	0
382210	382198	14033T	PARTICIPANT	\N	PRESENT	0
382211	382198	14026U	PARTICIPANT	\N	PRESENT	0
382212	382198	19725B	PARTICIPANT	\N	PRESENT	0
382213	382198	04097T	PARTICIPANT	\N	PRESENT	0
382214	382198	19511N	PARTICIPANT	\N	PRESENT	0
382215	382198	19441R	PARTICIPANT	\N	PRESENT	0
382216	382198	19369B	PARTICIPANT	\N	PRESENT	0
382217	382198	14265W	PARTICIPANT	\N	PRESENT	0
382218	382198	19762G	PARTICIPANT	\N	PRESENT	0
382219	382198	08049C	PARTICIPANT	\N	PRESENT	0
382220	378923	11110B	PARTICIPANT	\N	PRESENT	0
382221	378929	11027H	PARTICIPANT	\N	PRESENT	0
382222	378929	19421M	PARTICIPANT	\N	PRESENT	0
382223	378929	08061X	PARTICIPANT	\N	PRESENT	0
382224	378929	04035D	PARTICIPANT	\N	PRESENT	0
382225	378929	14235Q	PARTICIPANT	\N	PRESENT	0
382226	378929	14211G	PARTICIPANT	\N	PRESENT	0
382227	378929	95037J	PARTICIPANT	\N	PRESENT	0
382228	378929	19369B	PARTICIPANT	\N	PRESENT	0
382229	378929	01062T	PARTICIPANT	\N	PRESENT	0
382230	378929	14028W	PARTICIPANT	\N	PRESENT	0
382235	382234	14069U	PARTICIPANT	\N	PRESENT	0
382236	382234	19747H	PARTICIPANT	\N	PRESENT	0
382237	382234	19681G	PARTICIPANT	\N	PRESENT	0
382238	382234	80013X	PARTICIPANT	\N	PRESENT	0
382239	382234	14357A	PARTICIPANT	\N	PRESENT	0
382240	382234	17589D	PARTICIPANT	\N	PRESENT	0
382241	382234	01024M	PARTICIPANT	\N	PRESENT	0
382242	382234	14197C	PARTICIPANT	\N	PRESENT	0
382243	382234	14033T	PARTICIPANT	\N	PRESENT	0
382244	382234	04097T	PARTICIPANT	\N	PRESENT	0
382245	382234	04088S	PARTICIPANT	\N	PRESENT	0
382246	382234	98050T	PARTICIPANT	\N	PRESENT	0
382247	382234	19503N	PARTICIPANT	\N	PRESENT	0
382248	382234	19619A	PARTICIPANT	\N	PRESENT	0
382249	382234	01058X	PARTICIPANT	\N	PRESENT	0
382250	382234	95067Q	PARTICIPANT	\N	PRESENT	0
382252	381988	14001X	PARTICIPANT	\N	PRESENT	0
382253	381988	14147R	PARTICIPANT	\N	PRESENT	0
382254	381988	19253P	PARTICIPANT	\N	PRESENT	0
382255	381988	01024M	PARTICIPANT	\N	PRESENT	0
382256	381988	19581D	PARTICIPANT	\N	PRESENT	0
382257	381988	11049P	PARTICIPANT	\N	PRESENT	0
382258	381988	19675J	PARTICIPANT	\N	PRESENT	0
382259	381988	01028R	PARTICIPANT	\N	PRESENT	0
382260	381988	19447X	PARTICIPANT	\N	PRESENT	0
382261	381988	05008E	PRESIDENT	0	PRESENT	0
382262	381988	19762G	PARTICIPANT	\N	PRESENT	0
382263	381988	98035U	PARTICIPANT	\N	PRESENT	0
382264	381988	14065Q	PARTICIPANT	\N	PRESENT	0
382265	381988	08045X	PARTICIPANT	\N	PRESENT	0
382266	381988	19543W	PARTICIPANT	\N	PRESENT	0
382267	381988	04038G	PARTICIPANT	\N	PRESENT	0
382268	381988	19585H	PARTICIPANT	\N	PRESENT	0
382269	381988	04047H	PARTICIPANT	\N	PRESENT	0
382270	381988	19673G	PARTICIPANT	\N	PRESENT	0
382271	381988	14089Y	PARTICIPANT	\N	PRESENT	0
382272	381988	19725B	PARTICIPANT	\N	PRESENT	0
382273	381988	19489J	PARTICIPANT	\N	PRESENT	0
382274	381988	19729F	PARTICIPANT	\N	PRESENT	0
382275	381988	08044W	PARTICIPANT	\N	PRESENT	0
382276	381988	14179A	PARTICIPANT	\N	PRESENT	0
382277	381988	14069U	PARTICIPANT	\N	PRESENT	0
382278	381988	14151M	PARTICIPANT	\N	PRESENT	0
382279	381988	14215L	PARTICIPANT	\N	PRESENT	0
382280	381988	08018U	PARTICIPANT	\N	PRESENT	0
382281	381988	14259Y	PARTICIPANT	\N	PRESENT	0
382282	380226	08011M	PARTICIPANT	\N	PRESENT	0
382284	382283	14259Y	PARTICIPANT	\N	PRESENT	0
382307	371532	14107H	PARTICIPANT	\N	PRESENT	0
382340	382339	04059M	PARTICIPANT	\N	PRESENT	0
382341	382339	11040E	PARTICIPANT	\N	PRESENT	0
382342	382339	14053L	PARTICIPANT	\N	PRESENT	0
382343	382339	11053K	PARTICIPANT	\N	PRESENT	0
382344	382339	11027H	PARTICIPANT	\N	PRESENT	0
382345	382339	11070L	PARTICIPANT	\N	PRESENT	0
382346	382339	14041T	PARTICIPANT	\N	PRESENT	0
382347	382339	14034U	PARTICIPANT	\N	PRESENT	0
382348	382339	14231L	PARTICIPANT	\N	PRESENT	0
382349	382339	14081Q	PARTICIPANT	\N	PRESENT	0
382350	382339	14061L	PARTICIPANT	\N	PRESENT	0
382351	382339	14159V	PARTICIPANT	\N	PRESENT	0
382352	382339	86034E	PARTICIPANT	\N	PRESENT	0
382353	382339	08034U	PARTICIPANT	\N	PRESENT	0
382354	382339	12016W	PARTICIPANT	\N	PRESENT	0
382355	382339	01043Q	PARTICIPANT	\N	PRESENT	0
382356	382339	11072N	PARTICIPANT	\N	PRESENT	0
382357	382339	05012A	PARTICIPANT	\N	PRESENT	0
382358	382339	14135M	PARTICIPANT	\N	PRESENT	0
382359	382339	04045F	PARTICIPANT	\N	PRESENT	0
382360	382339	04044E	PARTICIPANT	\N	PRESENT	0
382490	382489	14069U	PARTICIPANT	\N	PRESENT	0
382491	382489	19719D	PARTICIPANT	\N	PRESENT	0
382500	371535	14241N	PARTICIPANT	\N	PRESENT	0
382501	371535	14235Q	PARTICIPANT	\N	PRESENT	0
382502	371535	08048B	PARTICIPANT	\N	PRESENT	0
382503	371535	08017T	PARTICIPANT	\N	PRESENT	0
382504	371535	14251Q	PARTICIPANT	\N	PRESENT	0
382506	371535	19611R	PARTICIPANT	\N	PRESENT	0
364453	364450	14133K	PARTICIPANT	\N	PRESENT	0
364454	364450	14065Q	PARTICIPANT	\N	PRESENT	0
364455	364450	96004D	PRESIDENT	0	PRESENT	0
364456	364450	14089Y	PARTICIPANT	\N	PRESENT	0
364457	364450	14357A	PARTICIPANT	\N	PRESENT	0
364458	364450	14079W	PARTICIPANT	\N	PRESENT	0
364459	364450	11083R	PARTICIPANT	\N	PRESENT	0
364460	364450	19553Y	PARTICIPANT	\N	PRESENT	0
364461	364450	95037J	PARTICIPANT	\N	PRESENT	0
364462	364450	04097T	PARTICIPANT	\N	PRESENT	0
364463	364450	08044W	PARTICIPANT	\N	PRESENT	0
364464	364450	14097Y	PARTICIPANT	\N	PRESENT	0
364465	364450	11026G	PARTICIPANT	\N	PRESENT	0
364466	364450	08039A	PARTICIPANT	\N	PRESENT	0
364467	364450	14225N	PARTICIPANT	\N	PRESENT	0
364468	364450	10015M	PARTICIPANT	\N	PRESENT	0
364469	364450	14331P	PARTICIPANT	\N	EXCUSE	0
364470	364450	14135M	PARTICIPANT	\N	EXCUSE	0
364471	364450	14061L	PARTICIPANT	\N	EXCUSE	0
364473	364472	98050T	PARTICIPANT	\N	PRESENT	0
364474	364472	01062T	PARTICIPANT	\N	PRESENT	0
366818	366817	14063N	PARTICIPANT	\N	PRESENT	0
366819	366817	14073Q	PARTICIPANT	\N	PRESENT	0
366820	366817	11043H	PARTICIPANT	\N	PRESENT	0
366821	366817	14061L	PARTICIPANT	\N	PRESENT	0
366824	366822	19735D	PARTICIPANT	\N	PRESENT	0
366825	366822	14039A	PARTICIPANT	\N	PRESENT	0
366826	366822	14229S	PARTICIPANT	\N	PRESENT	0
366827	366822	08031R	PARTICIPANT	\N	PRESENT	0
366828	366822	04057K	PARTICIPANT	\N	PRESENT	0
367392	367391	14147R	PARTICIPANT	\N	PRESENT	0
367393	367391	11067R	PARTICIPANT	\N	PRESENT	0
367394	367391	19749K	PARTICIPANT	\N	PRESENT	0
368946	366778	19723Y	PARTICIPANT	\N	PRESENT	0
368947	366778	14355X	PARTICIPANT	\N	PRESENT	0
368948	366778	19367Y	PARTICIPANT	\N	PRESENT	0
368949	366778	19577H	PARTICIPANT	\N	PRESENT	0
368950	366778	14217N	PARTICIPANT	\N	PRESENT	0
368951	366779	14217N	PARTICIPANT	\N	PRESENT	0
368952	366777	19415P	PARTICIPANT	\N	PRESENT	0
368953	366778	19697Q	PARTICIPANT	\N	PRESENT	0
368956	366778	17779H	PARTICIPANT	\N	PRESENT	0
368957	366778	19521Q	PARTICIPANT	\N	PRESENT	0
368959	366778	19691J	PARTICIPANT	\N	PRESENT	0
368964	366778	11045K	PARTICIPANT	\N	PRESENT	0
368965	366778	19715Y	PARTICIPANT	\N	EXCUSE	0
368967	366777	19715Y	PARTICIPANT	\N	EXCUSE	0
368968	366779	11045K	PARTICIPANT	\N	PRESENT	0
368969	366779	08041T	PARTICIPANT	\N	EXCUSE	0
368978	366779	19663E	PARTICIPANT	\N	PRESENT	0
368979	366778	19663E	PARTICIPANT	\N	PRESENT	0
369717	368184	19760E	PARTICIPANT	\N	PRESENT	0
369718	368184	19631V	PARTICIPANT	\N	PRESENT	0
369719	368184	04085P	PARTICIPANT	\N	PRESENT	0
369720	368184	19515S	PARTICIPANT	\N	PRESENT	0
369721	368184	05008E	PARTICIPANT	\N	PRESENT	0
369722	368184	14030Q	PARTICIPANT	\N	PRESENT	0
369723	368184	08043V	PARTICIPANT	\N	PRESENT	0
369724	368184	19367Y	PARTICIPANT	\N	PRESENT	0
369725	368184	14069U	PARTICIPANT	\N	PRESENT	0
369726	368184	14089Y	PARTICIPANT	\N	PRESENT	0
369727	368184	19643A	PARTICIPANT	\N	PRESENT	0
369728	368184	19747H	PARTICIPANT	\N	PRESENT	0
369729	368184	08020N	PARTICIPANT	\N	PRESENT	0
369730	368184	19782L	PARTICIPANT	\N	PRESENT	0
369731	368184	14207L	PARTICIPANT	\N	PRESENT	0
369732	368184	11053K	PARTICIPANT	\N	PRESENT	0
369733	368184	14329V	PARTICIPANT	\N	PRESENT	0
369734	368184	14038Y	PARTICIPANT	\N	PRESENT	0
369735	368184	14195A	PARTICIPANT	\N	PRESENT	0
369736	368184	19467C	PARTICIPANT	\N	PRESENT	0
369737	368184	19701S	PARTICIPANT	\N	PRESENT	0
369738	368184	88008L	PARTICIPANT	\N	PRESENT	0
369739	368184	19681G	PARTICIPANT	\N	PRESENT	0
369740	368184	19253P	PARTICIPANT	\N	PRESENT	0
369741	368184	11056N	PARTICIPANT	\N	PRESENT	0
369742	368184	14357A	PARTICIPANT	\N	PRESENT	0
369743	368184	11065P	PARTICIPANT	\N	PRESENT	0
369744	368184	19719D	PARTICIPANT	\N	PRESENT	0
369745	368184	14327T	PARTICIPANT	\N	PRESENT	0
369746	368184	19659J	PARTICIPANT	\N	PRESENT	0
369747	368184	14041T	PARTICIPANT	\N	PRESENT	0
369748	368184	14217N	PARTICIPANT	\N	PRESENT	0
369749	368184	19577H	PARTICIPANT	\N	PRESENT	0
369750	368184	04071H	PARTICIPANT	\N	PRESENT	0
369751	368184	14249W	PARTICIPANT	\N	PRESENT	0
369752	368184	14187A	PARTICIPANT	\N	PRESENT	0
369753	368184	01025N	PARTICIPANT	\N	PRESENT	0
369754	368184	14087W	PARTICIPANT	\N	PRESENT	0
369755	368184	19521Q	PARTICIPANT	\N	PRESENT	0
369756	368184	11010L	PARTICIPANT	\N	PRESENT	0
369757	368184	08048B	PARTICIPANT	\N	PRESENT	0
369758	368184	19387D	PARTICIPANT	\N	PRESENT	0
369759	368184	19347U	PARTICIPANT	\N	PRESENT	0
369760	368184	19565D	PARTICIPANT	\N	PRESENT	0
369761	368184	14123H	PARTICIPANT	\N	PRESENT	0
369762	368184	01057W	PARTICIPANT	\N	PRESENT	0
369763	368184	98022P	PARTICIPANT	\N	PRESENT	0
369764	368184	19691J	PARTICIPANT	\N	PRESENT	0
369765	368184	19725B	PARTICIPANT	\N	PRESENT	0
369766	368184	95037J	PARTICIPANT	\N	PRESENT	0
369767	368184	19333N	PARTICIPANT	\N	PRESENT	0
369768	368184	14213J	PARTICIPANT	\N	PRESENT	0
369769	368184	19511N	PARTICIPANT	\N	PRESENT	0
369770	368184	19531S	PARTICIPANT	\N	PRESENT	0
369771	368184	19447X	PARTICIPANT	\N	PRESENT	0
369772	368184	14021P	PARTICIPANT	\N	PRESENT	0
369773	368184	14073Q	PARTICIPANT	\N	PRESENT	0
369774	368184	19489J	PARTICIPANT	\N	PRESENT	0
369775	368184	08031R	PARTICIPANT	\N	PRESENT	0
369776	368184	04049K	PARTICIPANT	\N	PRESENT	0
369777	368184	86034E	PARTICIPANT	\N	PRESENT	0
369778	368184	98005N	PARTICIPANT	\N	PRESENT	0
369779	368184	08015R	PARTICIPANT	\N	PRESENT	0
369780	368184	19711U	PARTICIPANT	\N	PRESENT	0
369781	368184	08039A	PARTICIPANT	\N	PRESENT	0
369782	368184	19697Q	PARTICIPANT	\N	PRESENT	0
369783	368184	19581D	PARTICIPANT	\N	PRESENT	0
369784	368184	14219Q	PARTICIPANT	\N	PRESENT	0
369785	368184	19441R	PARTICIPANT	\N	PRESENT	0
369786	368184	14103D	PARTICIPANT	\N	PRESENT	0
369787	368184	12016W	PARTICIPANT	\N	PRESENT	0
369788	368184	08019V	PARTICIPANT	\N	PRESENT	0
369789	368184	19657G	PARTICIPANT	\N	PRESENT	0
369790	368184	14251Q	PARTICIPANT	\N	PRESENT	0
369791	368184	14031R	PARTICIPANT	\N	PRESENT	0
369792	368184	14111D	PARTICIPANT	\N	PRESENT	0
369793	368184	11085T	PARTICIPANT	\N	PRESENT	0
369794	368184	08009T	PARTICIPANT	\N	PRESENT	0
369795	368184	04057K	PARTICIPANT	\N	PRESENT	0
369796	368184	19563B	PARTICIPANT	\N	PRESENT	0
369797	368184	14147R	PARTICIPANT	\N	PRESENT	0
369798	368184	11067R	PARTICIPANT	\N	PRESENT	0
369799	368184	19335Q	PARTICIPANT	\N	PRESENT	0
369800	368184	19369B	PARTICIPANT	\N	PRESENT	0
369801	368184	14257W	PARTICIPANT	\N	PRESENT	0
369802	368184	14265W	PARTICIPANT	\N	PRESENT	0
369803	368184	14119M	PARTICIPANT	\N	PRESENT	0
369804	368184	14071N	PARTICIPANT	\N	PRESENT	0
369805	368184	08061X	PARTICIPANT	\N	PRESENT	0
369806	368184	17637T	PARTICIPANT	\N	PRESENT	0
369807	368184	14193X	PARTICIPANT	\N	PRESENT	0
369808	368184	19745F	PARTICIPANT	\N	PRESENT	0
369809	368184	19533U	PARTICIPANT	\N	PRESENT	0
369810	368184	04088S	PARTICIPANT	\N	PRESENT	0
369811	368184	05012A	PARTICIPANT	\N	PRESENT	0
369812	368184	98050T	PARTICIPANT	\N	PRESENT	0
369813	368184	19503N	PARTICIPANT	\N	PRESENT	0
369814	368184	11090Q	PARTICIPANT	\N	PRESENT	0
369815	368184	19739H	PARTICIPANT	\N	PRESENT	0
369816	368184	17583W	PARTICIPANT	\N	PRESENT	0
369817	368184	19679N	PARTICIPANT	\N	PRESENT	0
369818	368184	14135M	PARTICIPANT	\N	PRESENT	0
369819	368184	19349W	PARTICIPANT	\N	PRESENT	0
369820	368184	19794Q	PARTICIPANT	\N	PRESENT	0
369821	368184	19269X	PARTICIPANT	\N	PRESENT	0
369822	368184	11012A	PARTICIPANT	\N	PRESENT	0
369823	368184	19798U	PARTICIPANT	\N	PRESENT	0
369824	368184	14229S	PARTICIPANT	\N	PRESENT	0
369825	368184	14107H	PARTICIPANT	\N	PRESENT	0
369826	368184	11097X	PARTICIPANT	\N	PRESENT	0
369827	368184	04045F	PARTICIPANT	\N	PRESENT	0
369828	368184	01058X	PARTICIPANT	\N	PRESENT	0
369829	368184	19713W	PARTICIPANT	\N	PRESENT	0
369830	368184	19669L	PARTICIPANT	\N	PRESENT	0
369831	368184	14051J	PARTICIPANT	\N	PRESENT	0
369832	368184	04044E	PARTICIPANT	\N	PRESENT	0
369833	368184	14157T	PARTICIPANT	\N	PRESENT	0
369834	368184	19749K	PARTICIPANT	\N	PRESENT	0
384302	384261	14205J	PARTICIPANT	\N	PRESENT	0
384303	384261	19575F	PARTICIPANT	\N	PRESENT	0
384304	384261	14197C	PARTICIPANT	\N	PRESENT	0
384305	384261	14034U	PARTICIPANT	\N	PRESENT	0
384306	384261	14033T	PARTICIPANT	\N	PRESENT	0
384307	384261	19563B	PARTICIPANT	\N	PRESENT	0
384334	384261	19533U	PARTICIPANT	\N	PRESENT	0
384335	384261	04088S	PARTICIPANT	\N	PRESENT	0
384336	384261	17583W	PARTICIPANT	\N	PRESENT	0
384337	384261	11097X	PARTICIPANT	\N	PRESENT	0
384338	384261	11043H	PARTICIPANT	\N	PRESENT	0
385069	385068	14215L	PARTICIPANT	\N	PRESENT	0
385070	385068	14179A	PARTICIPANT	\N	PRESENT	0
385071	384208	14327T	PARTICIPANT	\N	EXCUSE	0
385072	384208	14103D	PARTICIPANT	\N	EXCUSE	0
392173	391674	11109J	PARTICIPANT	\N	PRESENT	0
392174	391674	14109K	PARTICIPANT	\N	PRESENT	0
392175	391674	11043H	PARTICIPANT	\N	PRESENT	0
392176	392169	14071N	PARTICIPANT	\N	PRESENT	0
392178	391508	14033T	PARTICIPANT	\N	PRESENT	0
392179	392177	14033T	PARTICIPANT	\N	PRESENT	0
392180	392177	04089T	PARTICIPANT	\N	PRESENT	0
392181	391674	07033P	PARTICIPANT	\N	EXCUSE	0
392182	390980	19333N	PARTICIPANT	\N	PRESENT	0
392183	390980	14038Y	PARTICIPANT	\N	PRESENT	0
392184	390980	17583W	PARTICIPANT	\N	PRESENT	0
392185	390980	19701S	PARTICIPANT	\N	PRESENT	0
392186	390980	19794Q	PARTICIPANT	\N	PRESENT	0
392187	390980	19387D	PARTICIPANT	\N	PRESENT	0
392188	390980	14219Q	PARTICIPANT	\N	PRESENT	0
392189	390980	14221J	PARTICIPANT	\N	PRESENT	0
392190	390980	08055A	PARTICIPANT	\N	PRESENT	0
392191	390980	19599P	PARTICIPANT	\N	PRESENT	0
392192	390980	14169X	PARTICIPANT	\N	PRESENT	0
392193	390980	19637C	PARTICIPANT	\N	PRESENT	0
392194	390980	02002K	PARTICIPANT	\N	PRESENT	0
392195	390980	15447F	PARTICIPANT	\N	PRESENT	0
392196	390980	05012A	PARTICIPANT	\N	PRESENT	0
392197	390980	14051J	PARTICIPANT	\N	PRESENT	0
392198	390980	08009T	PRESIDENT	0	PRESENT	0
392199	390980	19737F	PARTICIPANT	\N	PRESENT	0
392200	390980	14157T	PARTICIPANT	\N	PRESENT	0
392201	390980	19745F	PARTICIPANT	\N	PRESENT	0
392202	390980	08024S	PARTICIPANT	\N	PRESENT	0
392203	390980	19525U	PARTICIPANT	\N	PRESENT	0
392204	390980	19551W	PARTICIPANT	\N	PRESENT	0
392205	390980	18083K	PARTICIPANT	\N	PRESENT	0
392206	390980	17637T	PARTICIPANT	\N	PRESENT	0
392207	390980	14031R	PARTICIPANT	\N	PRESENT	0
392208	390980	14029X	PARTICIPANT	\N	PRESENT	0
392209	390980	14093U	PARTICIPANT	\N	PRESENT	0
392210	390980	19549D	PARTICIPANT	\N	PRESENT	0
392211	390980	19347U	PARTICIPANT	\N	PRESENT	0
392212	390980	19733B	PARTICIPANT	\N	PRESENT	0
392213	390980	19739H	PARTICIPANT	\N	PRESENT	0
392214	390980	08060W	PARTICIPANT	\N	PRESENT	0
392215	390980	19383Y	PARTICIPANT	\N	PRESENT	0
392216	390980	14237S	PARTICIPANT	\N	PRESENT	0
392217	390980	04097T	PARTICIPANT	\N	PRESENT	0
392218	391307	14081Q	PARTICIPANT	\N	PRESENT	0
392220	391308	19768N	PARTICIPANT	\N	PRESENT	0
392221	391308	14331P	PARTICIPANT	\N	PRESENT	0
392222	391308	19782L	PARTICIPANT	\N	PRESENT	0
392223	391308	11077T	PARTICIPANT	\N	PRESENT	0
392224	391308	19545Y	PARTICIPANT	\N	PRESENT	0
392225	391308	01057W	PARTICIPANT	\N	PRESENT	0
392226	391308	19441R	PARTICIPANT	\N	PRESENT	0
392227	391308	89017R	PARTICIPANT	\N	PRESENT	0
392228	391308	80013X	PARTICIPANT	\N	PRESENT	0
392229	391308	88008L	PARTICIPANT	\N	PRESENT	0
392230	391308	19671E	PARTICIPANT	\N	PRESENT	0
392231	391308	11099A	PARTICIPANT	\N	PRESENT	0
392232	391308	08068F	PARTICIPANT	\N	PRESENT	0
392233	391308	19349W	PARTICIPANT	\N	PRESENT	0
392234	391308	11048N	PARTICIPANT	\N	PRESENT	0
392235	391308	19651A	PARTICIPANT	\N	PRESENT	0
392236	391308	14187A	PARTICIPANT	\N	PRESENT	0
392237	391308	19687N	PARTICIPANT	\N	PRESENT	0
392238	391308	19689Q	PARTICIPANT	\N	PRESENT	0
392239	391308	19695N	PARTICIPANT	\N	PRESENT	0
392240	391308	11090Q	PRESIDENT	0	PRESENT	0
392241	391308	01025N	PARTICIPANT	\N	PRESENT	0
392242	391308	11040E	PARTICIPANT	\N	PRESENT	0
392243	391308	14083S	PARTICIPANT	\N	PRESENT	0
392244	391308	11012A	PARTICIPANT	\N	PRESENT	0
392245	391308	14121F	PARTICIPANT	\N	PRESENT	0
392246	391308	99004R	PARTICIPANT	\N	PRESENT	0
392247	391308	14207L	PARTICIPANT	\N	PRESENT	0
392248	391308	17589D	PARTICIPANT	\N	PRESENT	0
392249	391308	14257W	PARTICIPANT	\N	PRESENT	0
392250	391308	01043Q	PARTICIPANT	\N	PRESENT	0
392251	391308	14357A	PARTICIPANT	\N	PRESENT	0
392252	391308	14081Q	PARTICIPANT	\N	PRESENT	0
392253	391308	11074Q	PARTICIPANT	\N	PRESENT	0
392254	391308	14225N	PARTICIPANT	\N	PRESENT	0
392255	391308	19631V	PARTICIPANT	\N	PRESENT	0
392256	391308	19705W	PARTICIPANT	\N	PRESENT	0
392257	391308	14085U	PARTICIPANT	\N	PRESENT	0
392258	391308	08015R	PARTICIPANT	\N	PRESENT	0
392259	391308	08019V	PARTICIPANT	\N	PRESENT	0
392260	391308	08010L	PARTICIPANT	\N	PRESENT	0
392261	391308	19369B	PARTICIPANT	\N	PRESENT	0
392262	391308	19563B	PARTICIPANT	\N	PRESENT	0
392263	391308	08028W	PARTICIPANT	\N	PRESENT	0
392264	391308	14265W	PARTICIPANT	\N	PRESENT	0
392265	391308	14329V	PARTICIPANT	\N	PRESENT	0
392266	391308	14135M	PARTICIPANT	\N	PRESENT	0
392267	391308	19467C	PARTICIPANT	\N	PRESENT	0
392268	391308	19479G	PARTICIPANT	\N	PRESENT	0
392269	391308	19711U	PARTICIPANT	\N	PRESENT	0
392270	391308	14033T	PARTICIPANT	\N	PRESENT	0
392271	391308	08011M	PARTICIPANT	\N	PRESENT	0
392272	391308	14159V	PARTICIPANT	\N	PRESENT	0
392273	391308	19269X	PARTICIPANT	\N	PRESENT	0
392274	391308	14173T	PARTICIPANT	\N	PRESENT	0
392275	391308	04086Q	PARTICIPANT	\N	PRESENT	0
392276	391308	14205J	PARTICIPANT	\N	PRESENT	0
392277	391308	04088S	PARTICIPANT	\N	PRESENT	0
392278	391308	11056N	PARTICIPANT	\N	PRESENT	0
392279	391308	19507S	PARTICIPANT	\N	PRESENT	0
392280	391308	19741B	PARTICIPANT	\N	PRESENT	0
392281	391308	19747H	PARTICIPANT	\N	PRESENT	0
392282	391308	04043D	PARTICIPANT	\N	PRESENT	0
392283	391308	08062Y	PARTICIPANT	\N	EXCUSE	0
392284	391308	08021P	PARTICIPANT	\N	EXCUSE	0
392285	391308	11081P	PARTICIPANT	\N	EXCUSE	0
392286	391308	08034U	PARTICIPANT	\N	PRESENT	0
392287	391359	14331P	PARTICIPANT	\N	PRESENT	0
392288	391359	19545Y	PARTICIPANT	\N	PRESENT	0
392289	391359	01057W	PARTICIPANT	\N	PRESENT	0
392290	391359	11074Q	PRESIDENT	0	PRESENT	0
392291	391359	19671E	PARTICIPANT	\N	PRESENT	0
392292	391359	14225N	PARTICIPANT	\N	PRESENT	0
392293	391359	88008L	PARTICIPANT	\N	PRESENT	0
392294	391359	14085U	PARTICIPANT	\N	PRESENT	0
392295	391359	19349W	PARTICIPANT	\N	PRESENT	0
392296	391359	08010L	PARTICIPANT	\N	PRESENT	0
392297	391359	11048N	PARTICIPANT	\N	PRESENT	0
392298	391359	19479G	PARTICIPANT	\N	PRESENT	0
392299	391359	19711U	PARTICIPANT	\N	PRESENT	0
392300	391359	08034U	PARTICIPANT	\N	PRESENT	0
392301	391359	19651A	PARTICIPANT	\N	PRESENT	0
392302	391359	19687N	PARTICIPANT	\N	PRESENT	0
392303	391359	19689Q	PARTICIPANT	\N	PRESENT	0
392304	391359	08011M	PARTICIPANT	\N	PRESENT	0
392305	391359	14159V	PARTICIPANT	\N	PRESENT	0
392306	391359	14173T	PARTICIPANT	\N	PRESENT	0
392307	391359	04086Q	PARTICIPANT	\N	PRESENT	0
392308	391359	11040E	PARTICIPANT	\N	PRESENT	0
392309	391359	14083S	PARTICIPANT	\N	PRESENT	0
392310	391359	11012A	PARTICIPANT	\N	PRESENT	0
392311	391359	19741B	PARTICIPANT	\N	PRESENT	0
392312	391359	14121F	PARTICIPANT	\N	PRESENT	0
392313	391359	99004R	PARTICIPANT	\N	PRESENT	0
392316	390980	19503N	PARTICIPANT	\N	PRESENT	0
392317	391359	19768N	PARTICIPANT	\N	PRESENT	0
392318	391359	19782L	PARTICIPANT	\N	PRESENT	0
392319	391359	11077T	PARTICIPANT	\N	PRESENT	0
392320	391359	80013X	PARTICIPANT	\N	PRESENT	0
392321	391359	11099A	PARTICIPANT	\N	PRESENT	0
392322	391359	08068F	PARTICIPANT	\N	PRESENT	0
392323	391359	14187A	PARTICIPANT	\N	PRESENT	0
392324	391359	19695N	PARTICIPANT	\N	PRESENT	0
392325	391359	01025N	PARTICIPANT	\N	PRESENT	0
392326	391359	11090Q	PARTICIPANT	\N	PRESENT	0
392327	391359	14207L	PARTICIPANT	\N	PRESENT	0
392328	391359	17589D	PARTICIPANT	\N	PRESENT	0
364264	364263	14053L	PARTICIPANT	\N	PRESENT	0
367106	356173	19727D	PARTICIPANT	\N	PRESENT	0
371212	370536	11083R	PARTICIPANT	\N	EXCUSE	0
373105	356317	19619A	PARTICIPANT	\N	PRESENT	0
373106	356317	07004J	PARTICIPANT	\N	PRESENT	0
373107	356317	16685X	PARTICIPANT	\N	PRESENT	0
373108	356317	89017R	PARTICIPANT	\N	PRESENT	0
373109	356317	14329V	PARTICIPANT	\N	PRESENT	0
373110	356317	14042U	PARTICIPANT	\N	PRESENT	0
373111	356317	08056B	PARTICIPANT	\N	PRESENT	0
373112	356317	14219Q	PARTICIPANT	\N	PRESENT	0
373113	356317	14277B	PARTICIPANT	\N	PRESENT	0
373114	356317	19675J	PARTICIPANT	\N	PRESENT	0
373115	356317	11085T	PARTICIPANT	\N	PRESENT	0
373116	356317	19643A	PARTICIPANT	\N	PRESENT	0
373117	356317	98005N	PARTICIPANT	\N	PRESENT	0
373118	356317	14103D	PARTICIPANT	\N	PRESENT	0
373119	356317	19762G	PARTICIPANT	\N	PRESENT	0
373120	356317	19739H	PARTICIPANT	\N	PRESENT	0
373121	356317	19335Q	PARTICIPANT	\N	PRESENT	0
373122	356317	19749K	PARTICIPANT	\N	PRESENT	0
373123	356317	19745F	PARTICIPANT	\N	PRESENT	0
373124	356317	11109J	PARTICIPANT	\N	PRESENT	0
373125	356317	14089Y	PARTICIPANT	\N	PRESENT	0
373126	356317	19521Q	PARTICIPANT	\N	PRESENT	0
373127	356317	19701S	PARTICIPANT	\N	PRESENT	0
373128	356317	04018C	PARTICIPANT	\N	PRESENT	0
373129	356317	19577H	PARTICIPANT	\N	PRESENT	0
373130	356317	19621T	PARTICIPANT	\N	PRESENT	0
373131	356317	04040A	PARTICIPANT	\N	PRESENT	0
373132	356317	19367Y	PARTICIPANT	\N	PRESENT	0
373133	356317	14030Q	PARTICIPANT	\N	PRESENT	0
373134	356317	14327T	PARTICIPANT	\N	PRESENT	0
373135	356317	14217N	PARTICIPANT	\N	PRESENT	0
373136	356317	01043Q	PARTICIPANT	\N	PRESENT	0
373137	356317	04089T	PARTICIPANT	\N	PRESENT	0
373138	356317	19581D	PARTICIPANT	\N	PRESENT	0
373139	356317	14281W	PARTICIPANT	\N	PRESENT	0
373140	356317	19747H	PARTICIPANT	\N	PRESENT	0
373141	356317	07033P	PARTICIPANT	\N	PRESENT	0
373142	356317	14093U	PARTICIPANT	\N	PRESENT	0
373143	356317	04071H	PARTICIPANT	\N	PRESENT	0
373144	356317	11031D	PARTICIPANT	\N	PRESENT	0
373145	356317	19798U	PARTICIPANT	\N	PRESENT	0
373146	356317	04043D	PARTICIPANT	\N	PRESENT	0
373147	356317	14087W	PARTICIPANT	\N	PRESENT	0
373148	356317	04033B	PARTICIPANT	\N	PRESENT	0
373149	356317	11097X	PARTICIPANT	\N	PRESENT	0
373150	356317	19421M	PARTICIPANT	\N	PRESENT	0
373151	356317	04092N	PARTICIPANT	\N	PRESENT	0
373152	356317	14251Q	PARTICIPANT	\N	PRESENT	0
373153	356317	14229S	PARTICIPANT	\N	PRESENT	0
373154	356317	11090Q	PARTICIPANT	\N	PRESENT	0
373155	356317	14169X	PARTICIPANT	\N	PRESENT	0
373156	356317	19737F	PARTICIPANT	\N	PRESENT	0
373157	356317	19347U	PARTICIPANT	\N	PRESENT	0
373158	356317	11077T	PARTICIPANT	\N	PRESENT	0
373159	356317	11064N	PARTICIPANT	\N	PRESENT	0
373160	356317	01024M	PARTICIPANT	\N	PRESENT	0
373161	356317	11115U	PARTICIPANT	\N	PRESENT	0
373162	356317	05008E	PARTICIPANT	\N	PRESENT	0
373163	356317	05012A	PARTICIPANT	\N	PRESENT	0
373164	356317	14033T	PARTICIPANT	\N	PRESENT	0
373165	356317	19760E	PARTICIPANT	\N	PRESENT	0
373166	356317	95063L	PARTICIPANT	\N	PRESENT	0
373167	356317	11012A	PARTICIPANT	\N	PRESENT	0
373168	356317	14151M	PARTICIPANT	\N	PRESENT	0
373169	356317	14021P	PARTICIPANT	\N	PRESENT	0
373170	356317	11070L	PARTICIPANT	\N	PRESENT	0
373171	356317	08045X	PARTICIPANT	\N	PRESENT	0
373428	356315	04044E	PARTICIPANT	\N	PRESENT	0
373173	356317	14133K	PARTICIPANT	\N	PRESENT	0
373181	356317	19545Y	PARTICIPANT	\N	PRESENT	0
373429	356315	11067R	PARTICIPANT	\N	PRESENT	0
373430	356315	19737F	PARTICIPANT	\N	PRESENT	0
373431	356315	11090Q	PARTICIPANT	\N	PRESENT	0
373432	356315	14169X	PARTICIPANT	\N	PRESENT	0
373433	356315	14147R	PARTICIPANT	\N	PRESENT	0
373434	356315	11103C	PARTICIPANT	\N	PRESENT	0
373435	356315	14329V	PARTICIPANT	\N	PRESENT	0
373436	356315	14135M	PARTICIPANT	\N	PRESENT	0
373437	356315	04088S	PARTICIPANT	\N	PRESENT	0
373438	356315	19333N	PARTICIPANT	\N	PRESENT	0
373439	356315	19675J	PARTICIPANT	\N	PRESENT	0
373440	356315	11049P	PARTICIPANT	\N	PRESENT	0
373441	356315	08009T	PARTICIPANT	\N	PRESENT	0
373442	356315	14103D	PARTICIPANT	\N	PRESENT	0
373443	356315	11065P	PARTICIPANT	\N	PRESENT	0
373444	356315	14093U	PARTICIPANT	\N	PRESENT	0
373445	356315	14031R	PARTICIPANT	\N	PRESENT	0
373446	356315	19739H	PARTICIPANT	\N	PRESENT	0
373447	356315	14205J	PARTICIPANT	\N	PRESENT	0
373448	356315	17583W	PARTICIPANT	\N	PRESENT	0
373449	356315	19347U	PARTICIPANT	\N	PRESENT	0
373450	356315	19563B	PARTICIPANT	\N	PRESENT	0
373451	356315	08061X	PARTICIPANT	\N	PRESENT	0
373452	356315	80013X	PARTICIPANT	\N	PRESENT	0
373453	356315	19503N	PARTICIPANT	\N	PRESENT	0
373454	356315	14033T	PARTICIPANT	\N	PRESENT	0
373455	356315	19447X	PARTICIPANT	\N	PRESENT	0
373456	356315	19399H	PARTICIPANT	\N	PRESENT	0
373457	356315	14357A	PARTICIPANT	\N	PRESENT	0
373458	356315	19533U	PARTICIPANT	\N	PRESENT	0
373459	356315	11056N	PARTICIPANT	\N	PRESENT	0
373460	356315	19593H	PARTICIPANT	\N	PRESENT	0
373461	356315	19507S	PARTICIPANT	\N	PRESENT	0
373464	356315	19619A	PARTICIPANT	\N	PRESENT	0
373466	356315	14038Y	PARTICIPANT	\N	PRESENT	0
373470	356315	19657G	PARTICIPANT	\N	PRESENT	0
373471	356315	14079W	PARTICIPANT	\N	PRESENT	0
373472	356315	14207L	PARTICIPANT	\N	PRESENT	0
373473	356315	14249W	PARTICIPANT	\N	PRESENT	0
373475	356315	98005N	PARTICIPANT	\N	PRESENT	0
373501	356315	08034U	PARTICIPANT	\N	PRESENT	0
373507	356315	11101A	PARTICIPANT	\N	PRESENT	0
373508	356315	19703U	PARTICIPANT	\N	PRESENT	0
373509	356315	19549D	PARTICIPANT	\N	PRESENT	0
373510	356315	16685X	PARTICIPANT	\N	PRESENT	0
373511	356315	19441R	PARTICIPANT	\N	PRESENT	0
373526	356315	14083S	PARTICIPANT	\N	PRESENT	0
373527	356315	19335Q	PARTICIPANT	\N	PRESENT	0
373528	356315	11012A	PARTICIPANT	\N	PRESENT	0
373529	356315	19253P	PARTICIPANT	\N	PRESENT	0
373530	356315	08020N	PARTICIPANT	\N	PRESENT	0
373531	356315	14034U	PARTICIPANT	\N	PRESENT	0
373532	356315	14039A	PARTICIPANT	\N	PRESENT	0
373533	356315	19543W	PARTICIPANT	\N	PRESENT	0
373534	356315	18083K	PARTICIPANT	\N	PRESENT	0
373535	356315	14157T	PARTICIPANT	\N	PRESENT	0
373536	356315	05012A	PARTICIPANT	\N	PRESENT	0
373545	356315	19709B	PARTICIPANT	\N	PRESENT	0
373548	356315	19551W	PARTICIPANT	\N	PRESENT	0
373560	356315	19669L	PARTICIPANT	\N	PRESENT	0
373561	356315	19553Y	PARTICIPANT	\N	PRESENT	0
373573	356315	04085P	PARTICIPANT	\N	PRESENT	0
373103	356317	19441R	PARTICIPANT	\N	PRESENT	0
373104	356317	19721W	PARTICIPANT	\N	PRESENT	0
373597	373596	19762G	PARTICIPANT	\N	PRESENT	0
373599	373598	19762G	PARTICIPANT	\N	PRESENT	0
373600	370843	19691J	PARTICIPANT	\N	EXCUSE	0
373668	373667	10006L	PARTICIPANT	\N	PRESENT	0
373669	373667	08052W	PARTICIPANT	\N	PRESENT	0
373670	373667	19553Y	PARTICIPANT	\N	PRESENT	0
373699	373698	10015M	PARTICIPANT	\N	PRESENT	0
373700	373698	11026G	PARTICIPANT	\N	PRESENT	0
373702	373701	08010L	PARTICIPANT	\N	PRESENT	0
373704	373703	11045K	PARTICIPANT	\N	PRESENT	0
373706	373705	04033B	PARTICIPANT	\N	PRESENT	0
373767	373766	10006L	PARTICIPANT	\N	PRESENT	0
373923	373899	04070G	PRESIDENT	0	PRESENT	0
373924	373899	19533U	PARTICIPANT	\N	PRESENT	0
373925	373899	04033B	PARTICIPANT	\N	PRESENT	0
373926	373899	19329S	PARTICIPANT	\N	PRESENT	0
373927	373899	14229S	PARTICIPANT	\N	PRESENT	0
373928	373899	14241N	PARTICIPANT	\N	PRESENT	0
373929	373899	19573D	PARTICIPANT	\N	PRESENT	0
373930	373899	14039A	PARTICIPANT	\N	PRESENT	0
373931	373899	14107H	PARTICIPANT	\N	PRESENT	0
373932	373899	08017T	PARTICIPANT	\N	PRESENT	0
373933	373899	07033P	PARTICIPANT	\N	PRESENT	0
373934	373899	19335Q	PARTICIPANT	\N	PRESENT	0
373935	373899	08039A	PARTICIPANT	\N	PRESENT	0
373936	373899	08031R	PARTICIPANT	\N	PRESENT	0
373937	373899	19593H	PARTICIPANT	\N	PRESENT	0
373938	373899	14073Q	PARTICIPANT	\N	PRESENT	0
373939	373899	19611R	PARTICIPANT	\N	PRESENT	0
373940	373899	08043V	PARTICIPANT	\N	PRESENT	0
373941	373899	19693L	PARTICIPANT	\N	PRESENT	0
382507	371535	19747H	PARTICIPANT	\N	PRESENT	0
382508	371535	19794Q	PARTICIPANT	\N	PRESENT	0
382509	378930	19443T	PARTICIPANT	\N	PRESENT	0
382510	378930	95030B	PARTICIPANT	\N	PRESENT	0
382511	378930	04034C	PARTICIPANT	\N	PRESENT	0
382512	378930	01058X	PARTICIPANT	\N	PRESENT	0
382513	378930	14079W	PARTICIPANT	\N	PRESENT	0
382514	378930	16685X	PARTICIPANT	\N	PRESENT	0
382515	378930	04042C	PRESIDENT	0	PRESENT	0
382516	378930	11054L	PARTICIPANT	\N	PRESENT	0
382517	378930	95037J	PARTICIPANT	\N	PRESENT	0
382518	378930	19421M	PARTICIPANT	\N	PRESENT	0
382519	378930	08061X	PARTICIPANT	\N	PRESENT	0
382520	378930	97011G	PARTICIPANT	\N	PRESENT	0
382521	378930	08047A	PARTICIPANT	\N	PRESENT	0
382522	378930	98029W	PARTICIPANT	\N	PRESENT	0
382523	378930	14097Y	PARTICIPANT	\N	PRESENT	0
382524	378930	01062T	PARTICIPANT	\N	PRESENT	0
382525	378930	14133K	PARTICIPANT	\N	PRESENT	0
382526	378930	11041F	PARTICIPANT	\N	PRESENT	0
382527	378930	14235Q	PARTICIPANT	\N	PRESENT	0
382528	378930	08058D	PARTICIPANT	\N	PRESENT	0
382529	378930	19251M	PARTICIPANT	\N	PRESENT	0
382530	378930	14105F	PARTICIPANT	\N	PRESENT	0
382531	378930	14267Y	PARTICIPANT	\N	PRESENT	0
382532	378930	98050T	PARTICIPANT	\N	PRESENT	0
382533	378930	14211G	PARTICIPANT	\N	PRESENT	0
382535	371535	19647E	PARTICIPANT	\N	PRESENT	0
382536	371535	04018C	PARTICIPANT	\N	PRESENT	0
382537	378930	08049C	PARTICIPANT	\N	PRESENT	0
382538	371535	14357A	PARTICIPANT	\N	PRESENT	0
382539	378930	98018T	PARTICIPANT	\N	EXCUSE	0
382540	378930	98022P	PARTICIPANT	\N	EXCUSE	0
382541	378930	14193X	PARTICIPANT	\N	EXCUSE	0
382542	378930	04040A	PARTICIPANT	\N	PRESENT	0
382543	371535	14157T	PARTICIPANT	\N	PRESENT	0
382559	382558	11053K	PARTICIPANT	\N	PRESENT	0
382560	382558	14159V	PARTICIPANT	\N	PRESENT	0
382561	382558	05012A	PARTICIPANT	\N	PRESENT	0
382564	382563	19619A	PARTICIPANT	\N	PRESENT	0
382565	382563	14033T	PARTICIPANT	\N	PRESENT	0
382566	382563	80013X	PARTICIPANT	\N	PRESENT	0
382570	382569	04043D	PARTICIPANT	\N	PRESENT	0
382575	378930	04035D	PARTICIPANT	\N	EXCUSE	0
382576	378930	19709B	PARTICIPANT	\N	EXCUSE	0
382577	378930	14028W	PARTICIPANT	\N	EXCUSE	0
382578	378930	19669L	PARTICIPANT	\N	EXCUSE	0
382579	378930	11066Q	PARTICIPANT	\N	EXCUSE	0
382633	382632	96004D	PRESIDENT	0	PRESENT	0
382634	382632	14357A	PARTICIPANT	\N	PRESENT	0
382635	382632	14073Q	PARTICIPANT	\N	PRESENT	0
382636	382632	19563B	PARTICIPANT	\N	PRESENT	0
382648	382645	19737F	PARTICIPANT	\N	PRESENT	0
382649	382645	19347U	PARTICIPANT	\N	PRESENT	0
382654	382646	19515S	PARTICIPANT	\N	PRESENT	0
382656	382646	19549D	PARTICIPANT	\N	PRESENT	0
382658	382646	19347U	PARTICIPANT	\N	PRESENT	0
382659	382646	14081Q	PARTICIPANT	\N	PRESENT	0
382661	382646	14241N	PARTICIPANT	\N	PRESENT	0
382663	382646	14031R	PARTICIPANT	\N	PRESENT	0
382665	382646	17637T	PARTICIPANT	\N	PRESENT	0
382667	382646	19794Q	PARTICIPANT	\N	PRESENT	0
382668	382646	19737F	PARTICIPANT	\N	PRESENT	0
382672	382646	14079W	PARTICIPANT	\N	EXCUSE	0
382691	382690	14133K	PARTICIPANT	\N	PRESENT	0
382693	382692	14133K	PARTICIPANT	\N	PRESENT	0
382699	382698	04047H	PARTICIPANT	\N	PRESENT	0
382705	382704	19253P	PARTICIPANT	\N	PRESENT	0
382706	382704	11053K	PARTICIPANT	\N	PRESENT	0
382707	382704	14031R	PARTICIPANT	\N	PRESENT	0
382708	382704	19349W	PARTICIPANT	\N	PRESENT	0
382709	382704	19735D	PARTICIPANT	\N	PRESENT	0
382710	382704	19549D	PARTICIPANT	\N	PRESENT	0
382711	382704	14357A	PARTICIPANT	\N	PRESENT	0
382736	382735	19705W	PARTICIPANT	\N	PRESENT	0
382737	382735	19269X	PARTICIPANT	\N	PRESENT	0
382738	382735	08062Y	PARTICIPANT	\N	PRESENT	0
382739	382735	19369B	PARTICIPANT	\N	PRESENT	0
382740	382735	19515S	PARTICIPANT	\N	PRESENT	0
382742	382741	19705W	PARTICIPANT	\N	PRESENT	0
382743	382741	19269X	PARTICIPANT	\N	PRESENT	0
382744	382741	19515S	PARTICIPANT	\N	PRESENT	0
382745	382741	08062Y	PARTICIPANT	\N	PRESENT	0
382766	382765	11074Q	PARTICIPANT	\N	PRESENT	0
382767	382765	08011M	PARTICIPANT	\N	PRESENT	0
382800	382798	19741B	PARTICIPANT	\N	PRESENT	0
382801	382798	14093U	PARTICIPANT	\N	PRESENT	0
382802	382798	19611R	PARTICIPANT	\N	PRESENT	0
382803	382798	01048V	PARTICIPANT	\N	PRESENT	0
382804	382798	08053X	PARTICIPANT	\N	PRESENT	0
382805	382798	14257W	PRESIDENT	0	PRESENT	0
382806	382798	19533U	PARTICIPANT	\N	PRESENT	0
382807	382798	14229S	PARTICIPANT	\N	PRESENT	0
382808	382798	19421M	PARTICIPANT	\N	PRESENT	0
382809	382798	19679N	PARTICIPANT	\N	EXCUSE	0
382810	382799	19741B	PARTICIPANT	\N	PRESENT	0
382811	382799	14093U	PARTICIPANT	\N	PRESENT	0
382812	382799	01048V	PARTICIPANT	\N	PRESENT	0
382813	382799	08053X	PARTICIPANT	\N	PRESENT	0
382814	382799	04070G	PARTICIPANT	\N	PRESENT	0
382815	382799	19533U	PARTICIPANT	\N	PRESENT	0
382816	382799	14229S	PARTICIPANT	\N	PRESENT	0
382817	382799	19679N	PARTICIPANT	\N	EXCUSE	0
382818	382799	14257W	PRESIDENT	0	PRESENT	0
382819	382799	19421M	PARTICIPANT	\N	PRESENT	0
382834	382646	19637C	PARTICIPANT	\N	EXCUSE	0
382862	382861	04038G	PARTICIPANT	\N	PRESENT	0
383130	376926	14097Y	PARTICIPANT	\N	EXCUSE	0
383131	376926	11054L	PARTICIPANT	\N	EXCUSE	0
383132	382505	19729F	PARTICIPANT	\N	EXCUSE	0
383133	382505	14097Y	PARTICIPANT	\N	EXCUSE	0
383207	371540	19399H	PARTICIPANT	\N	PRESENT	0
383208	371540	19629C	PARTICIPANT	\N	PRESENT	0
383209	382179	19768N	PARTICIPANT	\N	PRESENT	0
383210	382179	08028W	PARTICIPANT	\N	PRESENT	0
383211	382179	14207L	PARTICIPANT	\N	EXCUSE	0
383212	382179	19295A	PARTICIPANT	\N	EXCUSE	0
383213	382179	08021P	PARTICIPANT	\N	EXCUSE	0
383214	382179	11081P	PARTICIPANT	\N	EXCUSE	0
383215	382179	14329V	PARTICIPANT	\N	EXCUSE	0
383216	371540	19581D	PARTICIPANT	\N	PRESENT	0
383217	371540	11040E	PARTICIPANT	\N	PRESENT	0
383218	383140	19569H	PARTICIPANT	\N	PRESENT	0
383219	383140	08043V	PARTICIPANT	\N	PRESENT	0
383220	383140	14213J	PARTICIPANT	\N	PRESENT	0
383221	383140	14223L	PARTICIPANT	\N	PRESENT	0
383222	383140	19585H	PARTICIPANT	\N	PRESENT	0
383223	383140	19673G	PARTICIPANT	\N	PRESENT	0
383224	383140	14030Q	PARTICIPANT	\N	PRESENT	0
383225	371540	14089Y	PARTICIPANT	\N	PRESENT	0
383226	371540	19671E	PARTICIPANT	\N	PRESENT	0
383227	383140	19649G	PARTICIPANT	\N	PRESENT	0
383228	383140	19447X	PARTICIPANT	\N	PRESENT	0
383229	383140	19723Y	PARTICIPANT	\N	PRESENT	0
383230	371540	14249W	PARTICIPANT	\N	PRESENT	0
383231	383140	11045K	PARTICIPANT	\N	PRESENT	0
383232	371540	19387D	PARTICIPANT	\N	PRESENT	0
383233	371540	98050T	PARTICIPANT	\N	PRESENT	0
383234	371540	11049P	PARTICIPANT	\N	PRESENT	0
383235	383140	19415P	PARTICIPANT	\N	PRESENT	0
383236	371540	17583W	PARTICIPANT	\N	PRESENT	0
383237	371540	97011G	PARTICIPANT	\N	PRESENT	0
383238	371540	14069U	PARTICIPANT	\N	PRESENT	0
383239	371540	19760E	PARTICIPANT	\N	PRESENT	0
383240	383140	08031R	PARTICIPANT	\N	PRESENT	0
383241	371540	19735D	PARTICIPANT	\N	PRESENT	0
383242	371540	87003B	PARTICIPANT	\N	PRESENT	0
383243	371540	19699S	PARTICIPANT	\N	PRESENT	0
383244	382180	19768N	PARTICIPANT	\N	PRESENT	0
383245	382180	19515S	PARTICIPANT	\N	PRESENT	0
383246	382180	19782L	PARTICIPANT	\N	PRESENT	0
383247	382180	14357A	PARTICIPANT	\N	PRESENT	0
383248	382180	08038Y	PARTICIPANT	\N	PRESENT	0
383249	382180	19441R	PARTICIPANT	\N	PRESENT	0
383250	382180	19413M	PARTICIPANT	\N	PRESENT	0
383251	382180	14033T	PARTICIPANT	\N	PRESENT	0
383252	382180	01025N	PARTICIPANT	\N	PRESENT	0
383253	382180	11090Q	PRESIDENT	0	PRESENT	0
383254	382180	14205J	PARTICIPANT	\N	PRESENT	0
383255	382180	11056N	PARTICIPANT	\N	PRESENT	0
383256	382180	08015R	PARTICIPANT	\N	PRESENT	0
383257	382180	14197C	PARTICIPANT	\N	PRESENT	0
383258	382180	19747H	PARTICIPANT	\N	PRESENT	0
383259	382180	04043D	PARTICIPANT	\N	PRESENT	0
383260	382180	19511N	PARTICIPANT	\N	PRESENT	0
383261	382180	08028W	PARTICIPANT	\N	PRESENT	0
383321	382614	14031R	PARTICIPANT	\N	PRESENT	0
383322	382614	19383Y	PARTICIPANT	\N	PRESENT	0
383323	382614	19533U	PARTICIPANT	\N	PRESENT	0
366533	366532	14329V	PARTICIPANT	\N	PRESENT	0
366534	364578	14069U	PARTICIPANT	\N	PRESENT	0
366535	364578	19467C	PARTICIPANT	\N	PRESENT	0
366536	364578	18083K	PARTICIPANT	\N	PRESENT	0
366537	364578	08045X	PARTICIPANT	\N	PRESENT	0
366538	364578	19727D	PARTICIPANT	\N	PRESENT	0
366539	364578	14033T	PARTICIPANT	\N	PRESENT	0
366540	364578	04097T	PARTICIPANT	\N	PRESENT	0
366541	364578	19511N	PARTICIPANT	\N	PRESENT	0
366542	364578	19723Y	PARTICIPANT	\N	PRESENT	0
366543	364578	19441R	PARTICIPANT	\N	PRESENT	0
366544	364578	14265W	PARTICIPANT	\N	PRESENT	0
366545	364578	19735D	PARTICIPANT	\N	PRESENT	0
366546	364578	14135M	PARTICIPANT	\N	PRESENT	0
366547	364578	14173T	PARTICIPANT	\N	PRESENT	0
366548	364579	19631V	PARTICIPANT	\N	PRESENT	0
366549	364579	19575F	PARTICIPANT	\N	PRESENT	0
366550	364579	19383Y	PARTICIPANT	\N	PRESENT	0
366551	364579	11101A	PARTICIPANT	\N	PRESENT	0
366552	364579	14187A	PARTICIPANT	\N	PRESENT	0
366553	364579	14179A	PARTICIPANT	\N	PRESENT	0
366554	364579	14237S	PARTICIPANT	\N	PRESENT	0
366555	364579	04088S	PARTICIPANT	\N	PRESENT	0
366556	364579	19679N	PARTICIPANT	\N	PRESENT	0
366557	364579	14107H	PARTICIPANT	\N	PRESENT	0
366558	364579	95067Q	PARTICIPANT	\N	PRESENT	0
366560	366559	14329V	PARTICIPANT	\N	PRESENT	0
366561	366559	11090Q	PARTICIPANT	\N	PRESENT	0
369658	369657	08009T	PARTICIPANT	\N	PRESENT	0
369659	369657	14169X	PARTICIPANT	\N	PRESENT	0
369660	369657	14051J	PARTICIPANT	\N	PRESENT	0
369661	369657	19549D	PARTICIPANT	\N	PRESENT	0
369662	369657	08024S	PARTICIPANT	\N	PRESENT	0
369663	369657	19701S	PARTICIPANT	\N	PRESENT	0
369664	369657	14219Q	PARTICIPANT	\N	PRESENT	0
369665	369657	19503N	PARTICIPANT	\N	PRESENT	0
369666	369657	11012A	PARTICIPANT	\N	PRESENT	0
369669	369667	08009T	PARTICIPANT	\N	PRESENT	0
369670	369667	14169X	PARTICIPANT	\N	PRESENT	0
369671	369667	14051J	PARTICIPANT	\N	PRESENT	0
369672	369667	19549D	PARTICIPANT	\N	PRESENT	0
369673	369667	08024S	PARTICIPANT	\N	PRESENT	0
369674	369667	19701S	PARTICIPANT	\N	PRESENT	0
369675	369667	14219Q	PARTICIPANT	\N	PRESENT	0
369676	369667	19503N	PARTICIPANT	\N	PRESENT	0
369677	369667	11012A	PARTICIPANT	\N	PRESENT	0
369835	368184	19479G	PARTICIPANT	\N	PRESENT	0
369836	368184	19737F	PARTICIPANT	\N	PRESENT	0
369837	368184	19585H	PARTICIPANT	\N	PRESENT	0
370927	370926	08009T	PARTICIPANT	\N	PRESENT	0
370928	370926	14038Y	PARTICIPANT	\N	PRESENT	0
370929	370926	19525U	PARTICIPANT	\N	PRESENT	0
372284	370835	14097Y	PARTICIPANT	\N	EXCUSE	0
372285	356669	14097Y	PARTICIPANT	\N	EXCUSE	0
372286	370843	19715Y	PARTICIPANT	\N	EXCUSE	0
372287	370843	14097Y	PARTICIPANT	\N	EXCUSE	0
373749	373748	14026U	PARTICIPANT	\N	PRESENT	0
373751	373750	14026U	PARTICIPANT	\N	PRESENT	0
379333	376957	19737F	PARTICIPANT	\N	PRESENT	0
379334	376957	19347U	PARTICIPANT	\N	PRESENT	0
379335	376957	14241N	PARTICIPANT	\N	PRESENT	0
379336	376957	19349W	PARTICIPANT	\N	PRESENT	0
379337	376957	19335Q	PARTICIPANT	\N	PRESENT	0
379338	376957	14087W	PARTICIPANT	\N	PRESENT	0
379340	376957	19794Q	PARTICIPANT	\N	PRESENT	0
379723	379722	19667J	PARTICIPANT	\N	PRESENT	0
379724	379722	11040E	PARTICIPANT	\N	PRESENT	0
379756	379755	01048V	PARTICIPANT	\N	PRESENT	0
379981	376957	19551W	PARTICIPANT	\N	EXCUSE	0
379982	376957	14081Q	PARTICIPANT	\N	EXCUSE	0
384585	384584	19421M	PARTICIPANT	\N	PRESENT	0
384586	384584	19251M	PARTICIPANT	\N	PRESENT	0
384589	384588	19421M	PARTICIPANT	\N	PRESENT	0
384590	384588	19251M	PARTICIPANT	\N	PRESENT	0
384591	384588	11064N	PARTICIPANT	\N	PRESENT	0
384592	384588	04040A	PARTICIPANT	\N	PRESENT	0
384745	384744	14253S	PARTICIPANT	\N	PRESENT	0
384746	384744	14085U	PARTICIPANT	\N	PRESENT	0
384747	384636	89017R	PARTICIPANT	\N	PRESENT	0
384749	384748	19647E	PARTICIPANT	\N	PRESENT	0
384750	384748	11070L	PARTICIPANT	\N	PRESENT	0
384752	384751	19647E	PARTICIPANT	\N	PRESENT	0
384754	384753	14327T	PARTICIPANT	\N	PRESENT	0
384755	384753	11110B	PARTICIPANT	\N	PRESENT	0
384756	384753	05012A	PARTICIPANT	\N	PRESENT	0
384758	384757	14327T	PARTICIPANT	\N	PRESENT	0
384759	384757	11110B	PARTICIPANT	\N	PRESENT	0
384760	384757	05012A	PARTICIPANT	\N	PRESENT	0
384762	384761	08014Q	PARTICIPANT	\N	PRESENT	0
384763	384761	08069G	PARTICIPANT	\N	PRESENT	0
384765	384764	19531S	PARTICIPANT	\N	PRESENT	0
386025	385893	95063L	PARTICIPANT	\N	PRESENT	0
386026	385893	11010L	PARTICIPANT	\N	PRESENT	0
386027	385893	01057W	PARTICIPANT	\N	PRESENT	0
386028	385893	14179A	PARTICIPANT	\N	PRESENT	0
386029	385893	11085T	PARTICIPANT	\N	PRESENT	0
386030	385893	14259Y	PARTICIPANT	\N	PRESENT	0
386031	385893	19719D	PARTICIPANT	\N	PRESENT	0
386032	385893	04085P	PARTICIPANT	\N	PRESENT	0
386033	385893	19762G	PARTICIPANT	\N	PRESENT	0
386034	384434	14255U	PARTICIPANT	\N	EXCUSE	0
386035	384434	04035D	PARTICIPANT	\N	EXCUSE	0
386036	384434	19583F	PARTICIPANT	\N	EXCUSE	0
386037	384434	08053X	PARTICIPANT	\N	PRESENT	0
386038	385894	14065Q	PARTICIPANT	\N	PRESENT	0
386039	385894	19649G	PARTICIPANT	\N	PRESENT	0
386040	385894	14001X	PARTICIPANT	\N	PRESENT	0
386041	385894	14081Q	PARTICIPANT	\N	PRESENT	0
386042	385894	01024M	PARTICIPANT	\N	PRESENT	0
386043	385894	04044E	PARTICIPANT	\N	PRESENT	0
386044	385894	04038G	PARTICIPANT	\N	PRESENT	0
386045	385894	04047H	PARTICIPANT	\N	PRESENT	0
386046	385894	19673G	PARTICIPANT	\N	PRESENT	0
386047	385894	19675J	PARTICIPANT	\N	PRESENT	0
386048	385894	01028R	PARTICIPANT	\N	PRESENT	0
386049	385894	19447X	PARTICIPANT	\N	PRESENT	0
386050	385894	05008E	PRESIDENT	1	PRESENT	0
386051	385894	19725B	PARTICIPANT	\N	PRESENT	0
386052	385894	19489J	PARTICIPANT	\N	PRESENT	0
386053	385894	14087W	PARTICIPANT	\N	PRESENT	0
386054	385894	08044W	PARTICIPANT	\N	PRESENT	0
386055	385894	19737F	PARTICIPANT	\N	PRESENT	0
386056	385894	14151M	PARTICIPANT	\N	PRESENT	0
386057	385894	14215L	PRESIDENT	0	PRESENT	0
386058	385894	14053L	PARTICIPANT	\N	PRESENT	0
386059	385894	95063L	PARTICIPANT	\N	PRESENT	0
386060	385894	19629C	PARTICIPANT	\N	PRESENT	0
386061	385894	14041T	PARTICIPANT	\N	PRESENT	0
386062	385894	10015M	PARTICIPANT	\N	PRESENT	0
386063	385894	14179A	PARTICIPANT	\N	PRESENT	0
386064	385894	14147R	PARTICIPANT	\N	PRESENT	0
386065	385894	19253P	PARTICIPANT	\N	PRESENT	0
386066	385894	19543W	PARTICIPANT	\N	PRESENT	0
386067	385894	08018U	PARTICIPANT	\N	EXCUSE	0
386068	377920	11070L	PARTICIPANT	\N	PRESENT	0
386077	386076	14065Q	PARTICIPANT	\N	PRESENT	0
386078	386076	10015M	PARTICIPANT	\N	PRESENT	0
386082	377920	19683J	PARTICIPANT	\N	PRESENT	0
386083	377920	11045K	PARTICIPANT	\N	PRESENT	0
386084	377920	14053L	PARTICIPANT	\N	PRESENT	0
386085	377920	19399H	PARTICIPANT	\N	PRESENT	0
386086	377920	19415P	PARTICIPANT	\N	PRESENT	0
386087	377920	19553Y	PARTICIPANT	\N	PRESENT	0
386088	377920	19794Q	PARTICIPANT	\N	PRESENT	0
386089	377920	19575F	PARTICIPANT	\N	PRESENT	0
386090	377920	08009T	PARTICIPANT	\N	PRESENT	0
386092	377920	14157T	PARTICIPANT	\N	PRESENT	0
386093	377920	19301E	PARTICIPANT	\N	PRESENT	0
386094	377920	14081Q	PARTICIPANT	\N	PRESENT	0
386095	377920	14195A	PARTICIPANT	\N	PRESENT	0
386097	377920	04092N	PARTICIPANT	\N	PRESENT	0
386098	377920	98024R	PARTICIPANT	\N	PRESENT	0
386099	377920	14063N	PARTICIPANT	\N	PRESENT	0
386100	377920	14073Q	PARTICIPANT	\N	PRESENT	0
386101	377920	11097X	PARTICIPANT	\N	PRESENT	0
386102	377920	19762G	PARTICIPANT	\N	PRESENT	0
386103	377920	19383Y	PARTICIPANT	\N	PRESENT	0
386104	377920	19731Y	PARTICIPANT	\N	PRESENT	0
386105	377920	14193X	PARTICIPANT	\N	PRESENT	0
386106	377920	14042U	PARTICIPANT	\N	PRESENT	0
386107	377920	14355X	PARTICIPANT	\N	PRESENT	0
386108	377920	08052W	PARTICIPANT	\N	PRESENT	0
386109	377920	14239U	PARTICIPANT	\N	PRESENT	0
386110	377920	11067R	PARTICIPANT	\N	PRESENT	0
386111	377920	88008L	PARTICIPANT	\N	PRESENT	0
386112	377920	14261S	PARTICIPANT	\N	PRESENT	0
386113	377920	11072N	PARTICIPANT	\N	PRESENT	0
386114	377920	19629C	PARTICIPANT	\N	PRESENT	0
386115	377920	19739H	PARTICIPANT	\N	PRESENT	0
384211	384210	14215L	PARTICIPANT	\N	PRESENT	0
384213	384212	14215L	PARTICIPANT	\N	PRESENT	0
384214	384212	14001X	PARTICIPANT	\N	PRESENT	0
392329	391359	14257W	PARTICIPANT	\N	PRESENT	0
392330	391359	14357A	PARTICIPANT	\N	PRESENT	0
392331	391359	14081Q	PARTICIPANT	\N	PRESENT	0
392332	391359	19631V	PARTICIPANT	\N	PRESENT	0
392396	392395	19575F	PARTICIPANT	\N	EXCUSE	0
392334	391359	19705W	PARTICIPANT	\N	PRESENT	0
392335	391359	08015R	PARTICIPANT	\N	PRESENT	0
392336	391359	19369B	PARTICIPANT	\N	PRESENT	0
392337	391359	19563B	PARTICIPANT	\N	PRESENT	0
392338	391359	08028W	PARTICIPANT	\N	PRESENT	0
392339	391359	14265W	PARTICIPANT	\N	PRESENT	0
392340	391359	14329V	PARTICIPANT	\N	PRESENT	0
392341	391359	14053L	PARTICIPANT	\N	PRESENT	0
392342	391359	19467C	PARTICIPANT	\N	PRESENT	0
392343	391359	14033T	PARTICIPANT	\N	PRESENT	0
392344	391359	14205J	PARTICIPANT	\N	PRESENT	0
392345	391359	11056N	PARTICIPANT	\N	PRESENT	0
392346	391359	04088S	PARTICIPANT	\N	PRESENT	0
392347	391359	19507S	PARTICIPANT	\N	PRESENT	0
392348	391359	19747H	PARTICIPANT	\N	PRESENT	0
392349	391359	04043D	PARTICIPANT	\N	PRESENT	0
392390	391359	14135M	PARTICIPANT	\N	PRESENT	0
392391	391359	19269X	PARTICIPANT	\N	PRESENT	0
392392	391359	07029T	PARTICIPANT	\N	EXCUSE	0
392393	391308	14197C	PARTICIPANT	\N	PRESENT	0
392397	392395	08068F	PARTICIPANT	\N	EXCUSE	0
392398	392395	19681G	PARTICIPANT	\N	EXCUSE	0
392399	392395	07029T	PARTICIPANT	\N	EXCUSE	0
392400	392395	14265W	PARTICIPANT	\N	EXCUSE	0
392401	392395	19599P	PARTICIPANT	\N	PRESENT	0
392402	392395	19695N	PARTICIPANT	\N	PRESENT	0
392403	392395	04049K	PARTICIPANT	\N	PRESENT	0
392404	392395	19711U	PARTICIPANT	\N	PRESENT	0
392405	392395	01043Q	PARTICIPANT	\N	PRESENT	0
392406	392395	14205J	PARTICIPANT	\N	PRESENT	0
392407	392395	19563B	PRESIDENT	0	PRESENT	0
392408	392395	19503N	PARTICIPANT	\N	PRESENT	0
392409	392395	19713W	PARTICIPANT	\N	PRESENT	0
392410	392395	01062T	PARTICIPANT	\N	PRESENT	0
392411	392395	95067Q	PARTICIPANT	\N	PRESENT	0
392415	392414	04042C	PARTICIPANT	\N	PRESENT	0
392416	392414	14255U	PARTICIPANT	\N	PRESENT	0
392417	392414	11066Q	PARTICIPANT	\N	PRESENT	0
392418	392414	14193X	PARTICIPANT	\N	PRESENT	0
392419	392414	98050T	PARTICIPANT	\N	PRESENT	0
392422	392420	04040A	PARTICIPANT	\N	PRESENT	0
392423	392420	14105F	PARTICIPANT	\N	PRESENT	0
392424	392420	08058D	PARTICIPANT	\N	PRESENT	0
392425	392420	14255U	PARTICIPANT	\N	PRESENT	0
392426	392420	04042C	PARTICIPANT	\N	PRESENT	0
392427	392420	98029W	PARTICIPANT	\N	PRESENT	0
392428	392420	14267Y	PARTICIPANT	\N	PRESENT	0
392429	392420	14079W	PARTICIPANT	\N	PRESENT	0
392430	392420	04035D	PARTICIPANT	\N	PRESENT	0
392432	392420	11064N	PARTICIPANT	\N	PRESENT	0
392433	392420	95037J	PARTICIPANT	\N	PRESENT	0
392434	392420	14097Y	PARTICIPANT	\N	PRESENT	0
392435	392420	08047A	PARTICIPANT	\N	PRESENT	0
392436	392420	14193X	PARTICIPANT	\N	PRESENT	0
392437	392420	98050T	PARTICIPANT	\N	PRESENT	0
392438	392420	11054L	PARTICIPANT	\N	PRESENT	0
392439	392420	19421M	PARTICIPANT	\N	PRESENT	0
392440	392420	01058X	PARTICIPANT	\N	PRESENT	0
392442	392420	11066Q	PARTICIPANT	\N	PRESENT	0
392444	391303	14147R	PARTICIPANT	\N	PRESENT	0
392445	391303	01024M	PARTICIPANT	\N	PRESENT	0
392446	391303	04044E	PARTICIPANT	\N	PRESENT	0
392447	391303	19581D	PARTICIPANT	\N	PRESENT	0
392448	391303	14215L	PRESIDENT	1	PRESENT	0
392449	391303	04047H	PARTICIPANT	\N	PRESENT	0
392450	391303	19675J	PARTICIPANT	\N	PRESENT	0
392451	391303	11033F	PARTICIPANT	\N	PRESENT	0
392452	391303	19447X	PARTICIPANT	\N	PRESENT	0
392453	391303	05008E	PRESIDENT	0	PRESENT	0
392454	391303	19762G	PARTICIPANT	\N	PRESENT	0
392455	391303	14001X	PARTICIPANT	\N	PRESENT	0
392456	391303	19543W	PARTICIPANT	\N	PRESENT	0
392457	391303	19585H	PARTICIPANT	\N	PRESENT	0
392458	391303	19673G	PARTICIPANT	\N	PRESENT	0
392459	391303	01028R	PARTICIPANT	\N	PRESENT	0
392460	391303	14231L	PARTICIPANT	\N	PRESENT	0
392461	391303	19489J	PARTICIPANT	\N	PRESENT	0
392462	391303	14275Y	PARTICIPANT	\N	PRESENT	0
392463	391303	14179A	PARTICIPANT	\N	PRESENT	0
392464	391303	14151M	PARTICIPANT	\N	PRESENT	0
392465	391303	08018U	PARTICIPANT	\N	PRESENT	0
392466	391303	14259Y	PARTICIPANT	\N	PRESENT	0
392467	391303	11072N	PARTICIPANT	\N	PRESENT	0
392468	391303	98035U	PARTICIPANT	\N	PRESENT	0
392469	391303	14053L	PARTICIPANT	\N	PRESENT	0
392470	391303	14111D	PARTICIPANT	\N	PRESENT	0
392471	391303	19649G	PARTICIPANT	\N	PRESENT	0
392472	391303	11010L	PARTICIPANT	\N	PRESENT	0
392473	391303	11026G	PARTICIPANT	\N	PRESENT	0
392474	391303	10015M	PARTICIPANT	\N	PRESENT	0
392475	391303	08045X	PARTICIPANT	\N	PRESENT	0
392476	391303	19253P	PARTICIPANT	\N	PRESENT	0
392477	391303	19719D	PARTICIPANT	\N	PRESENT	0
392478	391303	14089Y	PARTICIPANT	\N	PRESENT	0
392479	391303	19725B	PARTICIPANT	\N	PRESENT	0
392480	391303	19729F	PARTICIPANT	\N	PRESENT	0
392481	391303	95063L	PARTICIPANT	\N	PRESENT	0
392482	391303	08044W	PARTICIPANT	\N	PRESENT	0
392483	391303	14069U	PARTICIPANT	\N	PRESENT	0
392484	391303	11085T	PARTICIPANT	\N	PRESENT	0
392485	391303	14021P	PARTICIPANT	\N	PRESENT	0
392488	378005	04059M	PARTICIPANT	\N	PRESENT	0
392489	378005	95030B	PARTICIPANT	\N	PRESENT	0
392490	378005	14219Q	PARTICIPANT	\N	PRESENT	0
392491	378005	11074Q	PARTICIPANT	\N	PRESENT	0
392492	378005	19731Y	PARTICIPANT	\N	PRESENT	0
392493	378005	19629C	PARTICIPANT	\N	PRESENT	0
392494	378005	11026G	PARTICIPANT	\N	PRESENT	0
392495	378005	01025N	PARTICIPANT	\N	PRESENT	0
392496	378005	08020N	PARTICIPANT	\N	PRESENT	0
392497	378005	19758L	PARTICIPANT	\N	PRESENT	0
392498	378005	19573D	PARTICIPANT	\N	PRESENT	0
392499	378005	14093U	PARTICIPANT	\N	PRESENT	0
392500	378005	19794Q	PARTICIPANT	\N	PRESENT	0
362922	362921	11043H	PARTICIPANT	\N	PRESENT	0
362923	362921	14073Q	PARTICIPANT	\N	PRESENT	0
362924	362921	08012N	PARTICIPANT	\N	PRESENT	0
362925	362921	14105F	PARTICIPANT	\N	PRESENT	0
362926	362921	98022P	PARTICIPANT	\N	PRESENT	0
362927	362921	14213J	PARTICIPANT	\N	PRESENT	0
362928	362921	19699S	PARTICIPANT	\N	PRESENT	0
362929	362921	19349W	PARTICIPANT	\N	PRESENT	0
362930	362921	19301E	PARTICIPANT	\N	PRESENT	0
362931	362921	87003B	PARTICIPANT	\N	PRESENT	0
362932	362921	14249W	PARTICIPANT	\N	PRESENT	0
362937	362936	01034P	PARTICIPANT	\N	PRESENT	0
363123	363122	04092N	PARTICIPANT	\N	PRESENT	0
363124	363122	14239U	PARTICIPANT	\N	PRESENT	0
363125	363122	14071N	PARTICIPANT	\N	PRESENT	0
363126	363122	19553Y	PARTICIPANT	\N	PRESENT	0
363127	363122	08052W	PARTICIPANT	\N	PRESENT	0
363128	363122	19663E	PARTICIPANT	\N	PRESENT	0
363129	363122	19723Y	PARTICIPANT	\N	PRESENT	0
363130	363122	14217N	PARTICIPANT	\N	PRESENT	0
363132	363122	19683J	PARTICIPANT	\N	PRESENT	0
363133	363122	11097X	PARTICIPANT	\N	PRESENT	0
363134	363122	14195A	PARTICIPANT	\N	PRESENT	0
363159	363158	11053K	PARTICIPANT	\N	PRESENT	0
363161	363158	14159V	PARTICIPANT	\N	PRESENT	0
363162	363158	05012A	PARTICIPANT	\N	PRESENT	0
364408	364407	14053L	PARTICIPANT	\N	PRESENT	0
364410	364409	14147R	PARTICIPANT	\N	PRESENT	0
364411	364409	11067R	PARTICIPANT	\N	PRESENT	0
364412	364409	19749K	PARTICIPANT	\N	PRESENT	0
366424	362303	19768N	PARTICIPANT	\N	PRESENT	0
366425	362303	19515S	PARTICIPANT	\N	PRESENT	0
366611	345243	14041T	PARTICIPANT	\N	PRESENT	0
366427	362303	19782L	PARTICIPANT	\N	PRESENT	0
366428	362303	14357A	PARTICIPANT	\N	PRESENT	0
366429	362303	19441R	PARTICIPANT	\N	PRESENT	0
366430	362303	19413M	PARTICIPANT	\N	PRESENT	0
366431	362303	14081Q	PARTICIPANT	\N	PRESENT	0
366432	362303	80013X	PARTICIPANT	\N	PRESENT	0
366433	362303	19631V	PARTICIPANT	\N	PRESENT	0
366434	362303	11099A	PARTICIPANT	\N	PRESENT	0
366435	362303	08068F	PARTICIPANT	\N	PRESENT	0
366612	345243	99004R	PARTICIPANT	\N	PRESENT	0
366437	362303	19705W	PARTICIPANT	\N	PRESENT	0
366438	362303	08015R	PARTICIPANT	\N	PRESENT	0
366439	362303	08019V	PARTICIPANT	\N	PRESENT	0
366440	362303	14197C	PARTICIPANT	\N	PRESENT	0
366441	362303	19369B	PARTICIPANT	\N	PRESENT	0
366442	362303	19511N	PARTICIPANT	\N	PRESENT	0
366443	362303	08028W	PARTICIPANT	\N	PRESENT	0
366444	362303	19563B	PARTICIPANT	\N	PRESENT	0
366445	362303	14265W	PARTICIPANT	\N	PRESENT	0
366613	345243	19533U	PARTICIPANT	\N	PRESENT	0
366614	345243	14031R	PARTICIPANT	\N	PRESENT	0
366448	362303	14135M	PARTICIPANT	\N	PRESENT	0
366449	362303	19467C	PARTICIPANT	\N	PRESENT	0
366615	345243	11012A	PARTICIPANT	\N	PRESENT	0
366451	362303	14187A	PARTICIPANT	\N	PRESENT	0
366616	345243	08055A	PARTICIPANT	\N	PRESENT	0
366453	362303	19695N	PARTICIPANT	\N	PRESENT	0
366454	362303	08062Y	PARTICIPANT	\N	PRESENT	0
366455	362303	01025N	PARTICIPANT	\N	PRESENT	0
366456	362303	11090Q	PRESIDENT	0	PRESENT	0
366457	362303	14033T	PARTICIPANT	\N	PRESENT	0
366638	364203	14083S	PARTICIPANT	\N	PRESENT	0
366639	364203	08068F	PARTICIPANT	\N	PRESENT	0
366460	362303	14205J	PARTICIPANT	\N	PRESENT	0
366461	362303	04088S	PARTICIPANT	\N	PRESENT	0
366640	364203	19515S	PARTICIPANT	\N	PRESENT	0
366641	364203	14199E	PARTICIPANT	\N	PRESENT	0
366464	362303	14115H	PARTICIPANT	\N	PRESENT	0
366465	362303	11101A	PARTICIPANT	\N	PRESENT	0
366466	362303	19747H	PARTICIPANT	\N	PRESENT	0
366467	362303	14207L	PARTICIPANT	\N	PRESENT	0
366468	362303	04043D	PARTICIPANT	\N	PRESENT	0
366642	364203	04049K	PARTICIPANT	\N	PRESENT	0
366470	362303	17589D	PARTICIPANT	\N	PRESENT	0
366471	362303	14257W	PARTICIPANT	\N	PRESENT	0
366472	362303	08021P	PARTICIPANT	\N	EXCUSE	0
366473	362303	11081P	PARTICIPANT	\N	EXCUSE	0
366486	362303	01043Q	PARTICIPANT	\N	PRESENT	0
366566	365979	14053L	PARTICIPANT	\N	PRESENT	0
366567	365979	14065Q	PARTICIPANT	\N	PRESENT	0
366568	365979	10015M	PARTICIPANT	\N	PRESENT	0
366569	365979	19253P	PARTICIPANT	\N	PRESENT	0
366570	365979	01024M	PARTICIPANT	\N	PRESENT	0
366571	365979	04047H	PARTICIPANT	\N	PRESENT	0
366572	365979	19673G	PARTICIPANT	\N	PRESENT	0
366573	365979	01028R	PARTICIPANT	\N	PRESENT	0
366574	365979	19447X	PARTICIPANT	\N	PRESENT	0
366575	365979	05008E	PRESIDENT	0	PRESENT	0
366576	365979	95063L	PARTICIPANT	\N	PRESENT	0
366577	365979	19629C	PARTICIPANT	\N	PRESENT	0
366578	365979	14147R	PARTICIPANT	\N	PRESENT	0
366579	365979	14001X	PARTICIPANT	\N	PRESENT	0
366580	365979	01060R	PARTICIPANT	\N	PRESENT	0
366581	365979	19543W	PARTICIPANT	\N	PRESENT	0
366582	365979	04044E	PARTICIPANT	\N	PRESENT	0
366583	365979	19581D	PARTICIPANT	\N	PRESENT	0
366584	365979	19585H	PARTICIPANT	\N	PRESENT	0
366585	365979	19675J	PARTICIPANT	\N	PRESENT	0
366586	365979	14231L	PARTICIPANT	\N	PRESENT	0
366587	365979	19489J	PARTICIPANT	\N	PRESENT	0
366588	365979	14275Y	PARTICIPANT	\N	PRESENT	0
366589	365979	14041T	PARTICIPANT	\N	PRESENT	0
366590	365979	14179A	PARTICIPANT	\N	PRESENT	0
366591	365979	14151M	PARTICIPANT	\N	PRESENT	0
366592	365979	08018U	PARTICIPANT	\N	PRESENT	0
366593	365979	14259Y	PARTICIPANT	\N	PRESENT	0
366594	365979	14111D	PARTICIPANT	\N	PRESENT	0
366595	365979	11010L	PARTICIPANT	\N	PRESENT	0
366596	365979	11026G	PARTICIPANT	\N	PRESENT	0
366597	365979	08045X	PARTICIPANT	\N	PRESENT	0
366598	365979	04038G	PARTICIPANT	\N	PRESENT	0
366599	365979	19719D	PARTICIPANT	\N	PRESENT	0
366600	365979	11033F	PARTICIPANT	\N	PRESENT	0
366601	365979	14089Y	PARTICIPANT	\N	PRESENT	0
366602	365979	19725B	PARTICIPANT	\N	PRESENT	0
366603	365979	19729F	PARTICIPANT	\N	PRESENT	0
366604	365979	08044W	PARTICIPANT	\N	PRESENT	0
366605	365979	14069U	PARTICIPANT	\N	PRESENT	0
366606	365979	11085T	PARTICIPANT	\N	PRESENT	0
366607	365979	11049P	PARTICIPANT	\N	PRESENT	0
366608	365979	04008A	PARTICIPANT	\N	PRESENT	0
366609	365979	19762G	PARTICIPANT	\N	PRESENT	0
366610	345243	11027H	PARTICIPANT	\N	PRESENT	0
366643	364203	14151M	PARTICIPANT	\N	PRESENT	0
366644	364203	19399H	PARTICIPANT	\N	PRESENT	0
366645	364203	11110B	PARTICIPANT	\N	PRESENT	0
366646	364203	14227Q	PARTICIPANT	\N	PRESENT	0
366647	364203	19521Q	PRESIDENT	0	PRESENT	0
366648	364203	14329V	PARTICIPANT	\N	PRESENT	0
366649	364203	14051J	PARTICIPANT	\N	EXCUSE	0
366650	345243	19415P	PARTICIPANT	\N	PRESENT	0
366651	345243	08018U	PARTICIPANT	\N	PRESENT	0
366652	345243	14215L	PARTICIPANT	\N	PRESENT	0
366653	345243	11065P	PARTICIPANT	\N	PRESENT	0
366654	345243	19725B	PARTICIPANT	\N	PRESENT	0
366673	364203	11048N	PARTICIPANT	\N	PRESENT	0
366674	364203	04071H	PARTICIPANT	\N	PRESENT	0
366675	364203	19711U	PARTICIPANT	\N	PRESENT	0
366676	364203	08034U	PARTICIPANT	\N	PRESENT	0
366677	364203	14187A	PARTICIPANT	\N	PRESENT	0
366678	364203	19545Y	PARTICIPANT	\N	PRESENT	0
366679	364203	19695N	PARTICIPANT	\N	PRESENT	0
366680	364203	11090Q	PARTICIPANT	\N	PRESENT	0
366681	364203	14026U	PARTICIPANT	\N	PRESENT	0
366682	364203	19631V	PARTICIPANT	\N	PRESENT	0
366683	364203	19760E	PARTICIPANT	\N	PRESENT	0
366684	364203	19762G	PARTICIPANT	\N	PRESENT	0
366685	364203	14159V	PARTICIPANT	\N	PRESENT	0
366686	345243	11097X	PARTICIPANT	\N	PRESENT	0
366687	345243	14331P	PARTICIPANT	\N	PRESENT	0
366688	345243	19383Y	PARTICIPANT	\N	PRESENT	0
366689	345243	01058X	PARTICIPANT	\N	PRESENT	0
366690	345243	14241N	PARTICIPANT	\N	PRESENT	0
366691	345243	19349W	PARTICIPANT	\N	PRESENT	0
366692	345243	02002K	PARTICIPANT	\N	PRESENT	0
366693	345243	11064N	PARTICIPANT	\N	PRESENT	0
366694	345243	18083K	PARTICIPANT	\N	PRESENT	0
366695	345243	19673G	PARTICIPANT	\N	PRESENT	0
366696	345243	95062K	PARTICIPANT	\N	PRESENT	0
366697	345243	08020N	PARTICIPANT	\N	PRESENT	0
366698	345243	14257W	PARTICIPANT	\N	PRESENT	0
366699	345243	19671E	PARTICIPANT	\N	PRESENT	0
366700	345243	19691J	PARTICIPANT	\N	PRESENT	0
366701	345243	19301E	PARTICIPANT	\N	PRESENT	0
366702	345243	19289C	PARTICIPANT	\N	PRESENT	0
366703	345243	04088S	PARTICIPANT	\N	PRESENT	0
378939	378932	14026U	PARTICIPANT	\N	PRESENT	0
378941	378932	19717B	PARTICIPANT	\N	PRESENT	0
378943	378942	19717B	PARTICIPANT	\N	PRESENT	0
382125	378929	08038Y	PARTICIPANT	\N	PRESENT	0
382126	379044	19443T	PARTICIPANT	\N	PRESENT	0
382127	379044	95030B	PARTICIPANT	\N	PRESENT	0
382128	379044	01058X	PARTICIPANT	\N	PRESENT	0
382129	379044	16685X	PARTICIPANT	\N	PRESENT	0
382130	379044	11054L	PARTICIPANT	\N	PRESENT	0
382131	379044	08056B	PARTICIPANT	\N	PRESENT	0
382132	379044	08049C	PARTICIPANT	\N	PRESENT	0
382133	379044	97011G	PARTICIPANT	\N	PRESENT	0
382134	379044	08047A	PARTICIPANT	\N	PRESENT	0
382135	379044	98029W	PARTICIPANT	\N	PRESENT	0
382136	379044	95067Q	PARTICIPANT	\N	PRESENT	0
382137	379044	08058D	PARTICIPANT	\N	PRESENT	0
382138	379044	14105F	PARTICIPANT	\N	PRESENT	0
382139	379044	98050T	PARTICIPANT	\N	PRESENT	0
382140	379044	14255U	PARTICIPANT	\N	PRESENT	0
382141	379044	04034C	PARTICIPANT	\N	PRESENT	0
382142	379044	04040A	PARTICIPANT	\N	PRESENT	0
382143	379044	14079W	PARTICIPANT	\N	PRESENT	0
382144	379044	04042C	PARTICIPANT	\N	PRESENT	0
382145	379044	14097Y	PARTICIPANT	\N	PRESENT	0
382146	379044	14133K	PARTICIPANT	\N	PRESENT	0
382147	379044	11041F	PARTICIPANT	\N	PRESENT	0
382148	379044	19251M	PARTICIPANT	\N	PRESENT	0
382149	379044	19721W	PARTICIPANT	\N	PRESENT	0
382150	379044	14267Y	PARTICIPANT	\N	PRESENT	0
382151	379044	19583F	PARTICIPANT	\N	PRESENT	0
382152	379044	08038Y	PARTICIPANT	\N	PRESENT	0
382153	379044	14331P	PARTICIPANT	\N	PRESENT	0
382155	378923	11074Q	PRESIDENT	0	PRESENT	0
382156	378923	14034U	PARTICIPANT	\N	EXCUSE	0
382157	378923	14083S	PARTICIPANT	\N	PRESENT	0
382158	378923	07029T	PARTICIPANT	\N	PRESENT	0
382159	378923	11048N	PARTICIPANT	\N	PRESENT	0
382160	378923	19647E	PARTICIPANT	\N	PRESENT	0
382161	378923	19711U	PARTICIPANT	\N	PRESENT	0
382162	378923	14085U	PARTICIPANT	\N	PRESENT	0
382163	378923	19651A	PARTICIPANT	\N	PRESENT	0
382164	378923	01057W	PARTICIPANT	\N	PRESENT	0
382165	378923	19741B	PARTICIPANT	\N	PRESENT	0
382166	378923	14253S	PARTICIPANT	\N	PRESENT	0
382167	378923	19671E	PARTICIPANT	\N	PRESENT	0
382168	378923	11040E	PARTICIPANT	\N	EXCUSE	0
382169	378929	19441R	PARTICIPANT	\N	PRESENT	0
382170	378923	08011M	PARTICIPANT	\N	EXCUSE	0
382171	378923	14121F	PARTICIPANT	\N	PRESENT	0
382172	378234	14087W	PARTICIPANT	\N	PRESENT	0
382173	378234	19611R	PARTICIPANT	\N	PRESENT	0
382174	378234	19663E	PARTICIPANT	\N	PRESENT	0
382175	378234	19715Y	PARTICIPANT	\N	PRESENT	0
382176	378234	14355X	PARTICIPANT	\N	EXCUSE	0
382181	378923	14225N	PARTICIPANT	\N	PRESENT	0
382182	378920	14221J	PARTICIPANT	\N	PRESENT	0
382183	378234	04045F	PARTICIPANT	\N	EXCUSE	0
382184	378923	08014Q	PARTICIPANT	\N	PRESENT	0
382185	378923	88008L	PARTICIPANT	\N	PRESENT	0
382186	380226	19699S	PARTICIPANT	\N	PRESENT	0
382187	380226	19533U	PARTICIPANT	\N	PRESENT	0
382188	380226	08035V	PARTICIPANT	\N	PRESENT	0
382189	380226	19399H	PARTICIPANT	\N	PRESENT	0
382190	380226	19735D	PARTICIPANT	\N	PRESENT	0
382191	380226	14123H	PARTICIPANT	\N	PRESENT	0
382192	380226	11043H	PARTICIPANT	\N	PRESENT	0
382193	380226	04018C	PARTICIPANT	\N	PRESENT	0
382194	378923	11012A	PARTICIPANT	\N	PRESENT	0
382195	380226	14061L	PARTICIPANT	\N	EXCUSE	0
382196	380226	19611R	PARTICIPANT	\N	PRESENT	0
382290	371532	11070L	PARTICIPANT	\N	PRESENT	0
382291	371532	14259Y	PARTICIPANT	\N	PRESENT	0
382296	371532	01028R	PARTICIPANT	\N	PRESENT	0
382297	371532	19349W	PARTICIPANT	\N	PRESENT	0
382298	371532	11072N	PARTICIPANT	\N	PRESENT	0
382299	382289	14239U	PARTICIPANT	\N	PRESENT	0
382300	382289	04092N	PARTICIPANT	\N	PRESENT	0
382301	382289	19565D	PARTICIPANT	\N	PRESENT	0
382302	382289	14042U	PARTICIPANT	\N	PRESENT	0
382303	382289	08052W	PARTICIPANT	\N	PRESENT	0
382304	382289	14195A	PARTICIPANT	\N	PRESENT	0
382305	382289	98024R	PRESIDENT	0	PRESENT	0
382306	382289	11067R	PARTICIPANT	\N	PRESENT	0
382308	382289	08041T	PARTICIPANT	\N	EXCUSE	0
382309	371532	19729F	PARTICIPANT	\N	PRESENT	0
382310	371532	08015R	PARTICIPANT	\N	PRESENT	0
382311	371532	08019V	PARTICIPANT	\N	PRESENT	0
382312	371532	14105F	PARTICIPANT	\N	PRESENT	0
382313	371532	14235Q	PARTICIPANT	\N	PRESENT	0
382314	382289	19415P	PARTICIPANT	\N	PRESENT	0
382315	371532	14030Q	PARTICIPANT	\N	PRESENT	0
382316	371532	14219Q	PARTICIPANT	\N	PRESENT	0
382317	371532	19611R	PARTICIPANT	\N	PRESENT	0
382318	371532	19671E	PARTICIPANT	\N	PRESENT	0
382319	371532	18083K	PARTICIPANT	\N	PRESENT	0
382320	371532	19413M	PARTICIPANT	\N	PRESENT	0
382321	371532	19699S	PARTICIPANT	\N	PRESENT	0
382322	371532	14327T	PARTICIPANT	\N	PRESENT	0
382323	371532	19533U	PARTICIPANT	\N	PRESENT	0
382324	382289	19301E	PARTICIPANT	\N	PRESENT	0
382325	382289	19715Y	PARTICIPANT	\N	PRESENT	0
382326	382289	17779H	PARTICIPANT	\N	PRESENT	0
382327	371532	99004R	PARTICIPANT	\N	PRESENT	0
382328	371532	14069U	PARTICIPANT	\N	PRESENT	0
382329	371532	19443T	PARTICIPANT	\N	PRESENT	0
382330	382289	11031D	PARTICIPANT	\N	PRESENT	0
382331	382289	11097X	PARTICIPANT	\N	PRESENT	0
382332	382289	19727D	PARTICIPANT	\N	PRESENT	0
382333	382289	14281W	PARTICIPANT	\N	PRESENT	0
382334	382289	19521Q	PARTICIPANT	\N	PRESENT	0
382335	371532	04088S	PARTICIPANT	\N	PRESENT	0
382336	371532	11056N	PARTICIPANT	\N	PRESENT	0
382337	371532	98005N	PARTICIPANT	\N	PRESENT	0
382338	382289	19575F	PARTICIPANT	\N	PRESENT	0
382361	371532	08056B	PARTICIPANT	\N	PRESENT	0
382362	371532	14029X	PARTICIPANT	\N	PRESENT	0
382363	382289	19663E	PARTICIPANT	\N	PRESENT	0
382364	371532	19581D	PARTICIPANT	\N	PRESENT	0
382365	382289	10006L	PARTICIPANT	\N	EXCUSE	0
382366	382289	08048B	PARTICIPANT	\N	PRESENT	0
382367	371532	11033F	PARTICIPANT	\N	PRESENT	0
382368	371532	14261S	PARTICIPANT	\N	PRESENT	0
382369	382289	19683J	PARTICIPANT	\N	PRESENT	0
382370	382289	04045F	PARTICIPANT	\N	EXCUSE	0
382371	382289	14026U	PARTICIPANT	\N	PRESENT	0
382372	382289	14213J	PARTICIPANT	\N	PRESENT	0
382373	382289	19553Y	PARTICIPANT	\N	PRESENT	0
382374	371532	19399H	PARTICIPANT	\N	PRESENT	0
382375	371532	19573D	PARTICIPANT	\N	PRESENT	0
382376	371532	01057W	PARTICIPANT	\N	PRESENT	0
382377	371532	19251M	PARTICIPANT	\N	PRESENT	0
382378	371532	12041X	PARTICIPANT	\N	PRESENT	0
382379	371532	19585H	PARTICIPANT	\N	PRESENT	0
382380	371532	19441R	PARTICIPANT	\N	PRESENT	0
382381	371532	19739H	PARTICIPANT	\N	PRESENT	0
382382	371532	14053L	PARTICIPANT	\N	PRESENT	0
382383	371532	14197C	PARTICIPANT	\N	PRESENT	0
382384	371532	14267Y	PARTICIPANT	\N	PRESENT	0
382385	371532	19758L	PARTICIPANT	\N	PRESENT	0
382386	371532	19741B	PARTICIPANT	\N	PRESENT	0
382387	371532	14121F	PARTICIPANT	\N	PRESENT	0
382388	371532	19549D	PARTICIPANT	\N	PRESENT	0
382389	371532	14031R	PARTICIPANT	\N	PRESENT	0
382390	371532	19467C	PARTICIPANT	\N	PRESENT	0
382391	371532	19701S	PARTICIPANT	\N	PRESENT	0
382392	371532	19651A	PARTICIPANT	\N	PRESENT	0
382393	371532	01024M	PARTICIPANT	\N	PRESENT	0
382394	371532	19447X	PARTICIPANT	\N	PRESENT	0
382395	371532	14265W	PARTICIPANT	\N	PRESENT	0
382396	371532	14083S	PARTICIPANT	\N	PRESENT	0
382397	371532	97011G	PARTICIPANT	\N	PRESENT	0
382398	382289	19527W	PARTICIPANT	\N	PRESENT	0
382399	382289	14355X	PARTICIPANT	\N	EXCUSE	0
363407	345235	11027H	PARTICIPANT	\N	PRESENT	0
363429	345235	19565D	PARTICIPANT	\N	PRESENT	0
363430	345235	04085P	PARTICIPANT	\N	PRESENT	0
363431	345235	19715Y	PARTICIPANT	\N	PRESENT	0
363432	345235	19503N	PARTICIPANT	\N	PRESENT	0
363433	345235	80013X	PARTICIPANT	\N	PRESENT	0
363434	345235	19599P	PARTICIPANT	\N	PRESENT	0
363435	345235	19333N	PARTICIPANT	\N	PRESENT	0
363436	345235	19551W	PARTICIPANT	\N	PRESENT	0
363437	345235	14257W	PARTICIPANT	\N	PRESENT	0
363438	345235	08055A	PARTICIPANT	\N	PRESENT	0
363439	345235	19659J	PARTICIPANT	\N	PRESENT	0
363440	345235	19289C	PARTICIPANT	\N	PRESENT	0
363441	345235	04057K	PARTICIPANT	\N	PRESENT	0
363442	345235	14107H	PARTICIPANT	\N	PRESENT	0
363443	345235	19637C	PARTICIPANT	\N	PRESENT	0
363444	345235	19543W	PARTICIPANT	\N	PRESENT	0
363445	345235	11065P	PARTICIPANT	\N	PRESENT	0
363446	345235	11012A	PARTICIPANT	\N	PRESENT	0
363447	345235	19695N	PARTICIPANT	\N	PRESENT	0
363448	345235	14231L	PARTICIPANT	\N	PRESENT	0
363449	345235	08009T	PARTICIPANT	\N	PRESENT	0
363450	345235	14031R	PARTICIPANT	\N	PRESENT	0
363451	345235	19387D	PARTICIPANT	\N	PRESENT	0
363452	345235	19583F	PARTICIPANT	\N	PRESENT	0
366475	366474	96004D	PARTICIPANT	\N	PRESENT	0
366476	366474	95037J	PARTICIPANT	\N	PRESENT	0
366477	366474	14026U	PARTICIPANT	\N	PRESENT	0
366478	366474	14033T	PARTICIPANT	\N	PRESENT	0
366479	366474	14097Y	PARTICIPANT	\N	PRESENT	0
366480	366474	11090Q	PARTICIPANT	\N	PRESENT	0
366481	366474	19441R	PARTICIPANT	\N	PRESENT	0
366482	366474	11099A	PARTICIPANT	\N	PRESENT	0
366483	366474	14257W	PARTICIPANT	\N	PRESENT	0
366484	366474	14357A	PARTICIPANT	\N	PRESENT	0
366485	362302	01043Q	PARTICIPANT	\N	PRESENT	0
368188	368187	14261S	PARTICIPANT	\N	PRESENT	0
368189	368187	14119M	PARTICIPANT	\N	PRESENT	0
371670	369691	14255U	PARTICIPANT	\N	EXCUSE	0
371671	369691	14097Y	PARTICIPANT	\N	EXCUSE	0
371672	369691	19443T	PARTICIPANT	\N	EXCUSE	0
371673	369691	01058X	PARTICIPANT	\N	EXCUSE	0
372054	369841	11074Q	PARTICIPANT	\N	EXCUSE	0
372242	371681	05008E	PRESIDENT	0	PRESENT	0
372243	371681	19543W	PARTICIPANT	\N	PRESENT	0
372244	371681	11033F	PARTICIPANT	\N	PRESENT	0
372245	371681	14065Q	PARTICIPANT	\N	EXCUSE	0
372246	371681	14069U	PARTICIPANT	\N	PRESENT	0
372247	371681	14089Y	PARTICIPANT	\N	PRESENT	0
372248	371681	04047H	PRESIDENT	1	PRESENT	0
372249	371681	14053L	PARTICIPANT	\N	PRESENT	0
372250	371681	19629C	PARTICIPANT	\N	PRESENT	0
372251	371681	19253P	PARTICIPANT	\N	PRESENT	0
372252	371681	14259Y	PARTICIPANT	\N	PRESENT	0
372253	371681	04008A	PARTICIPANT	\N	PRESENT	0
372254	371681	19719D	PARTICIPANT	\N	PRESENT	0
372255	371681	01024M	PARTICIPANT	\N	PRESENT	0
372256	371681	14215L	PARTICIPANT	\N	PRESENT	0
372257	371681	14151M	PARTICIPANT	\N	PRESENT	0
372258	371681	19673G	PARTICIPANT	\N	PRESENT	0
372259	371681	08045X	PARTICIPANT	\N	PRESENT	0
372260	371681	08018U	PARTICIPANT	\N	PRESENT	0
372261	371681	14231L	PARTICIPANT	\N	PRESENT	0
372262	371681	19649G	PARTICIPANT	\N	PRESENT	0
372263	371681	11049P	PARTICIPANT	\N	PRESENT	0
372264	371681	19725B	PARTICIPANT	\N	PRESENT	0
372265	371681	19447X	PARTICIPANT	\N	PRESENT	0
372266	371681	14021P	PARTICIPANT	\N	PRESENT	0
372267	371681	19489J	PARTICIPANT	\N	PRESENT	0
372268	371681	19729F	PARTICIPANT	\N	PRESENT	0
372269	371681	19581D	PARTICIPANT	\N	PRESENT	0
372270	371681	14111D	PARTICIPANT	\N	PRESENT	0
372271	371681	11085T	PARTICIPANT	\N	PRESENT	0
372272	371681	01060R	PARTICIPANT	\N	PRESENT	0
372273	371681	14147R	PARTICIPANT	\N	PRESENT	0
372274	371681	11072N	PARTICIPANT	\N	PRESENT	0
372275	371681	95063L	PARTICIPANT	\N	PRESENT	0
372276	371681	19762G	PARTICIPANT	\N	PRESENT	0
372277	371681	01028R	PARTICIPANT	\N	PRESENT	0
372278	371681	98035U	PARTICIPANT	\N	PRESENT	0
372279	371681	14275Y	PARTICIPANT	\N	PRESENT	0
372280	371681	19675J	PARTICIPANT	\N	PRESENT	0
372281	371681	04044E	PARTICIPANT	\N	EXCUSE	0
372282	371681	19585H	PARTICIPANT	\N	PRESENT	0
382231	379044	11081P	PARTICIPANT	\N	EXCUSE	0
382232	379044	19782L	PARTICIPANT	\N	EXCUSE	0
382233	379044	08021P	PARTICIPANT	\N	EXCUSE	0
382251	378391	14195A	PARTICIPANT	\N	EXCUSE	0
382292	378391	14259Y	PARTICIPANT	\N	EXCUSE	0
382534	378391	14103D	PARTICIPANT	\N	EXCUSE	0
385140	377918	08052W	PARTICIPANT	\N	PRESENT	0
385141	377918	19651A	PARTICIPANT	\N	PRESENT	0
385142	377918	11031D	PARTICIPANT	\N	PRESENT	0
385143	377918	19565D	PARTICIPANT	\N	PRESENT	0
385144	377918	11067R	PARTICIPANT	\N	PRESENT	0
385145	377918	14227Q	PARTICIPANT	\N	PRESENT	0
385146	377918	19683J	PARTICIPANT	\N	PRESENT	0
385147	377918	14239U	PARTICIPANT	\N	PRESENT	0
385148	377918	19697Q	PARTICIPANT	\N	PRESENT	0
385149	377918	19387D	PARTICIPANT	\N	PRESENT	0
385150	377918	19553Y	PARTICIPANT	\N	PRESENT	0
385151	377918	14261S	PARTICIPANT	\N	PRESENT	0
385152	377918	11045K	PARTICIPANT	\N	PRESENT	0
385153	377918	19549D	PARTICIPANT	\N	PRESENT	0
385154	377918	14051J	PARTICIPANT	\N	PRESENT	0
385155	377918	14042U	PARTICIPANT	\N	PRESENT	0
385156	377918	14327T	PARTICIPANT	\N	PRESENT	0
385157	377918	04045F	PARTICIPANT	\N	PRESENT	0
385158	377918	14030Q	PARTICIPANT	\N	PRESENT	0
385159	377918	07004J	PARTICIPANT	\N	PRESENT	0
385160	377918	19367Y	PARTICIPANT	\N	PRESENT	0
385161	377918	14087W	PARTICIPANT	\N	PRESENT	0
385162	377918	19731Y	PARTICIPANT	\N	PRESENT	0
385163	377918	14061L	PARTICIPANT	\N	PRESENT	0
385164	377918	11097X	PARTICIPANT	\N	PRESENT	0
385165	377918	95030B	PARTICIPANT	\N	PRESENT	0
385166	377918	11103C	PARTICIPANT	\N	PRESENT	0
385167	377918	19762G	PARTICIPANT	\N	PRESENT	0
385168	377918	19798U	PARTICIPANT	\N	PRESENT	0
385169	377918	08034U	PARTICIPANT	\N	PRESENT	0
385170	377918	14223L	PARTICIPANT	\N	PRESENT	0
385171	377918	14213J	PARTICIPANT	\N	PRESENT	0
385172	377918	14105F	PARTICIPANT	\N	PRESENT	0
385173	377918	19575F	PARTICIPANT	\N	PRESENT	0
385174	377918	18083K	PARTICIPANT	\N	PRESENT	0
385175	377918	19415P	PARTICIPANT	\N	PRESENT	0
385176	377918	14119M	PARTICIPANT	\N	PRESENT	0
385177	377918	19794Q	PARTICIPANT	\N	PRESENT	0
385178	377918	19703U	PARTICIPANT	\N	PRESENT	0
385179	377918	19723Y	PARTICIPANT	\N	PRESENT	0
385180	377918	01058X	PARTICIPANT	\N	PRESENT	0
385181	377918	19689Q	PARTICIPANT	\N	PRESENT	0
385182	377918	19758L	PARTICIPANT	\N	PRESENT	0
385183	377918	14195A	PARTICIPANT	\N	PRESENT	0
385184	377918	11110B	PARTICIPANT	\N	PRESENT	0
385185	377918	08031R	PARTICIPANT	\N	PRESENT	0
385186	377918	08019V	PARTICIPANT	\N	PRESENT	0
385187	377918	95062K	PARTICIPANT	\N	PRESENT	0
385188	377918	01034P	PARTICIPANT	\N	PRESENT	0
385189	377918	19679N	PARTICIPANT	\N	PRESENT	0
385190	377918	04097T	PARTICIPANT	\N	PRESENT	0
385191	377918	19467C	PARTICIPANT	\N	PRESENT	0
385192	377918	19573D	PARTICIPANT	\N	PRESENT	0
385193	377918	19301E	PARTICIPANT	\N	PRESENT	0
385194	377918	14231L	PARTICIPANT	\N	PRESENT	0
385195	377918	19621T	PARTICIPANT	\N	PRESENT	0
385196	377918	08014Q	PARTICIPANT	\N	PRESENT	0
385197	377918	14217N	PARTICIPANT	\N	PRESENT	0
385198	377918	19657G	PARTICIPANT	\N	PRESENT	0
385199	377918	14026U	PARTICIPANT	\N	PRESENT	0
385200	377918	19543W	PARTICIPANT	\N	PRESENT	0
385201	377918	19760E	PARTICIPANT	\N	PRESENT	0
385202	377918	01057W	PARTICIPANT	\N	PRESENT	0
385203	377918	01024M	PARTICIPANT	\N	PRESENT	0
385204	377918	19701S	PARTICIPANT	\N	PRESENT	0
385205	377918	14191V	PARTICIPANT	\N	PRESENT	0
385206	377918	19503N	PARTICIPANT	\N	PRESENT	0
385207	377918	08055A	PARTICIPANT	\N	PRESENT	0
385208	377918	04034C	PARTICIPANT	\N	PRESENT	0
385209	377918	19713W	PARTICIPANT	\N	PRESENT	0
385210	377918	11099A	PARTICIPANT	\N	PRESENT	0
385211	377918	10006L	PARTICIPANT	\N	PRESENT	0
385212	377918	11040E	PARTICIPANT	\N	PRESENT	0
385213	377918	19253P	PARTICIPANT	\N	PRESENT	0
385214	377918	97011G	PARTICIPANT	\N	PRESENT	0
385215	377918	14265W	PARTICIPANT	\N	PRESENT	0
385216	377918	17583W	PARTICIPANT	\N	PRESENT	0
385217	377918	19727D	PARTICIPANT	\N	PRESENT	0
385218	377918	04088S	PARTICIPANT	\N	PRESENT	0
382731	382730	19619A	PARTICIPANT	\N	PRESENT	0
382732	382730	19369B	PARTICIPANT	\N	PRESENT	0
392501	378005	14215L	PARTICIPANT	\N	PRESENT	0
392502	378005	14225N	PARTICIPANT	\N	PRESENT	0
392503	378005	19687N	PARTICIPANT	\N	PRESENT	0
392504	378005	14235Q	PARTICIPANT	\N	PRESENT	0
392505	378005	04086Q	PARTICIPANT	\N	PRESENT	0
392506	378005	11012A	PARTICIPANT	\N	PRESENT	0
392507	378005	19467C	PARTICIPANT	\N	PRESENT	0
392508	378005	19695N	PARTICIPANT	\N	PRESENT	0
392509	378005	14151M	PARTICIPANT	\N	PRESENT	0
392510	378005	19413M	PARTICIPANT	\N	PRESENT	0
392511	378005	19689Q	PARTICIPANT	\N	PRESENT	0
392512	378005	14257W	PARTICIPANT	\N	PRESENT	0
392513	378005	14207L	PARTICIPANT	\N	PRESENT	0
392514	378005	19719D	PARTICIPANT	\N	PRESENT	0
392515	378005	19581D	PARTICIPANT	\N	PRESENT	0
392516	378005	19711U	PARTICIPANT	\N	PRESENT	0
392517	378005	14119M	PARTICIPANT	\N	PRESENT	0
392518	378005	19415P	PARTICIPANT	\N	PRESENT	0
392519	378005	11072N	PARTICIPANT	\N	PRESENT	0
392520	378005	04047H	PARTICIPANT	\N	PRESENT	0
392522	378005	08045X	PARTICIPANT	\N	PRESENT	0
392523	378005	15447F	PARTICIPANT	\N	PRESENT	0
392524	378005	05008E	PARTICIPANT	\N	PRESENT	0
392525	378005	14281W	PARTICIPANT	\N	PRESENT	0
392526	378005	11104D	PARTICIPANT	\N	PRESENT	0
392527	378005	11070L	PARTICIPANT	\N	PRESENT	0
392528	378005	14173T	PARTICIPANT	\N	PRESENT	0
392529	378005	14001X	PARTICIPANT	\N	PRESENT	0
392530	378005	11010L	PARTICIPANT	\N	PRESENT	0
392531	378005	19591F	PARTICIPANT	\N	PRESENT	0
392532	378005	14231L	PARTICIPANT	\N	PRESENT	0
392533	378005	14029X	PARTICIPANT	\N	PRESENT	0
392534	378005	14038Y	PARTICIPANT	\N	PRESENT	0
392535	378005	19575F	PARTICIPANT	\N	PRESENT	0
392536	378005	14259Y	PARTICIPANT	\N	PRESENT	0
392537	378005	97011G	PARTICIPANT	\N	PRESENT	0
392538	378005	19768N	PARTICIPANT	\N	PRESENT	0
392539	378005	08017T	PARTICIPANT	\N	PRESENT	0
392540	378005	14327T	PARTICIPANT	\N	PRESENT	0
392541	378005	14042U	PARTICIPANT	\N	PRESENT	0
392542	378005	19739H	PARTICIPANT	\N	PRESENT	0
392543	378005	19387D	PARTICIPANT	\N	PRESENT	0
392544	378005	98022P	PARTICIPANT	\N	PRESENT	0
392545	378005	19621T	PARTICIPANT	\N	PRESENT	0
392546	378005	19729F	PARTICIPANT	\N	PRESENT	0
392547	378005	04045F	PARTICIPANT	\N	PRESENT	0
392548	378005	19543W	PARTICIPANT	\N	PRESENT	0
392549	378005	19699S	PARTICIPANT	\N	PRESENT	0
392550	378005	19533U	PARTICIPANT	\N	PRESENT	0
392551	378005	19585H	PARTICIPANT	\N	PRESENT	0
392552	378005	19599P	PARTICIPANT	\N	PRESENT	0
392553	378005	19760E	PARTICIPANT	\N	PRESENT	0
392554	378005	14121F	PARTICIPANT	\N	PRESENT	0
392555	378005	14187A	PARTICIPANT	\N	PRESENT	0
392556	390317	19725B	PRESIDENT	0	PRESENT	0
392557	390317	11056N	PARTICIPANT	\N	PRESENT	0
392558	390317	04057K	PARTICIPANT	\N	PRESENT	0
392559	390317	19441R	PARTICIPANT	\N	PRESENT	0
392560	390317	14030Q	PARTICIPANT	\N	PRESENT	0
392561	390317	08015R	PARTICIPANT	\N	EXCUSE	0
392562	390317	19295A	PARTICIPANT	\N	EXCUSE	0
392564	378005	17583W	PARTICIPANT	\N	PRESENT	0
392565	378005	01057W	PARTICIPANT	\N	PRESENT	0
392566	378005	19447X	PARTICIPANT	\N	PRESENT	0
392567	378005	19383Y	PARTICIPANT	\N	PRESENT	0
392568	378005	14147R	PARTICIPANT	\N	PRESENT	0
392569	392563	04047H	PARTICIPANT	\N	PRESENT	0
392570	392563	11026G	PARTICIPANT	\N	PRESENT	0
392571	392563	08012N	PARTICIPANT	\N	PRESENT	0
392572	392563	14147R	PARTICIPANT	\N	PRESENT	0
392573	392563	04043D	PARTICIPANT	\N	PRESENT	0
392574	378005	14073Q	PARTICIPANT	\N	PRESENT	0
392575	378005	08043V	PARTICIPANT	\N	PRESENT	0
392576	378005	19565D	PARTICIPANT	\N	PRESENT	0
392577	378005	19651A	PARTICIPANT	\N	PRESENT	0
392578	378005	19715Y	PARTICIPANT	\N	PRESENT	0
392579	378005	19489J	PARTICIPANT	\N	PRESENT	0
392580	378005	19611R	PARTICIPANT	\N	PRESENT	0
392581	378005	08039A	PARTICIPANT	\N	PRESENT	0
392582	378005	08044W	PARTICIPANT	\N	PRESENT	0
392583	387736	19693L	PARTICIPANT	\N	PRESENT	0
392584	387736	01048V	PRESIDENT	0	PRESENT	0
392585	387736	19593H	PARTICIPANT	\N	PRESENT	0
392586	387736	14093U	PARTICIPANT	\N	PRESENT	0
392587	387736	19503N	PARTICIPANT	\N	PRESENT	0
392588	387736	01058X	PARTICIPANT	\N	EXCUSE	0
392589	378005	10015M	PARTICIPANT	\N	PRESENT	0
392590	387736	19553Y	PARTICIPANT	\N	EXCUSE	0
392591	387736	19723Y	PARTICIPANT	\N	EXCUSE	0
392592	387736	19511N	PARTICIPANT	\N	EXCUSE	0
392597	378005	08010L	PARTICIPANT	\N	PRESENT	0
392598	378005	19479G	PARTICIPANT	\N	PRESENT	0
392599	378005	14205J	PARTICIPANT	\N	PRESENT	0
392600	378005	19507S	PARTICIPANT	\N	PRESENT	0
392601	378005	19549D	PARTICIPANT	\N	PRESENT	0
392602	378005	19333N	PARTICIPANT	\N	PRESENT	0
392603	378005	11067R	PARTICIPANT	\N	PRESENT	0
392604	378005	14237S	PARTICIPANT	\N	PRESENT	0
392605	378005	19798U	PARTICIPANT	\N	PRESENT	0
392611	378005	14217N	PARTICIPANT	\N	PRESENT	0
392612	390317	14107H	PARTICIPANT	\N	PRESENT	0
392613	390317	14026U	PARTICIPANT	\N	PRESENT	0
392614	390317	08073C	PARTICIPANT	\N	EXCUSE	0
392616	378005	19667J	PARTICIPANT	\N	PRESENT	0
392617	378005	14213J	PARTICIPANT	\N	PRESENT	0
392618	378005	19745F	PARTICIPANT	\N	PRESENT	0
392619	378005	08024S	PARTICIPANT	\N	PRESENT	0
392620	378005	14249W	PARTICIPANT	\N	PRESENT	0
392621	378005	14135M	PARTICIPANT	\N	PRESENT	0
392622	378005	11109J	PARTICIPANT	\N	PRESENT	0
392624	378005	14071N	PARTICIPANT	\N	PRESENT	0
392625	378005	14109K	PARTICIPANT	\N	PRESENT	0
392626	378005	11056N	PARTICIPANT	\N	PRESENT	0
392627	378005	19679N	PARTICIPANT	\N	PRESENT	0
392628	378005	14059S	PARTICIPANT	\N	PRESENT	0
392629	378005	14097Y	PARTICIPANT	\N	PRESENT	0
392630	378005	19737F	PARTICIPANT	\N	PRESENT	0
392632	392631	11070L	PARTICIPANT	\N	PRESENT	0
392633	392631	08034U	PARTICIPANT	\N	PRESENT	0
392634	378005	08068F	PARTICIPANT	\N	PRESENT	0
392635	378005	19569H	PARTICIPANT	\N	PRESENT	0
392636	378005	80013X	PARTICIPANT	\N	PRESENT	0
392637	378005	14267Y	PARTICIPANT	\N	PRESENT	0
392639	392638	14071N	PARTICIPANT	\N	PRESENT	0
392640	378005	08061X	PARTICIPANT	\N	PRESENT	0
392642	392641	08020N	PARTICIPANT	\N	PRESENT	0
392643	385081	08024S	PARTICIPANT	\N	EXCUSE	0
392644	392641	14073Q	PARTICIPANT	\N	PRESENT	0
392645	392641	14237S	PARTICIPANT	\N	PRESENT	0
392646	392641	04057K	PARTICIPANT	\N	PRESENT	0
392647	392641	19585H	PARTICIPANT	\N	PRESENT	0
392648	378005	19503N	PARTICIPANT	\N	PRESENT	0
392649	378005	14089Y	PARTICIPANT	\N	PRESENT	0
392650	378005	14201E	PARTICIPANT	\N	PRESENT	0
392654	378005	19701S	PARTICIPANT	\N	PRESENT	0
392656	391388	11109J	PARTICIPANT	\N	PRESENT	0
392657	378005	11049P	PARTICIPANT	\N	PRESENT	0
392658	391388	11010L	PARTICIPANT	\N	PRESENT	0
392659	391388	14059S	PARTICIPANT	\N	PRESENT	0
392660	391388	08019V	PRESIDENT	0	PRESENT	0
392661	391388	14275Y	PARTICIPANT	\N	PRESENT	0
392662	378005	14133K	PARTICIPANT	\N	PRESENT	0
392663	378005	16685X	PARTICIPANT	\N	PRESENT	0
392664	389738	14133K	PARTICIPANT	\N	PRESENT	0
392665	389738	96004D	PRESIDENT	0	PRESENT	0
392666	389738	14089Y	PARTICIPANT	\N	PRESENT	0
392667	389738	14249W	PARTICIPANT	\N	PRESENT	0
392668	389738	11083R	PARTICIPANT	\N	PRESENT	0
392669	389738	04097T	PARTICIPANT	\N	PRESENT	0
392670	389738	14241N	PARTICIPANT	\N	PRESENT	0
392671	389738	14073Q	PARTICIPANT	\N	PRESENT	0
392672	389738	11026G	PARTICIPANT	\N	PRESENT	0
392673	389738	19563B	PARTICIPANT	\N	PRESENT	0
392674	389738	14237S	PARTICIPANT	\N	PRESENT	0
392675	389738	98035U	PARTICIPANT	\N	PRESENT	0
392676	389738	14357A	PARTICIPANT	\N	PRESENT	0
362732	361272	19443T	PARTICIPANT	\N	PRESENT	0
362733	361272	12041X	PARTICIPANT	\N	PRESENT	0
362734	361272	04034C	PARTICIPANT	\N	PRESENT	0
362735	361272	14079W	PARTICIPANT	\N	PRESENT	0
362736	361272	01058X	PARTICIPANT	\N	PRESENT	0
362737	361272	04040A	PARTICIPANT	\N	PRESENT	0
362738	361272	16685X	PARTICIPANT	\N	PRESENT	0
362739	361272	11027H	PARTICIPANT	\N	PRESENT	0
362740	361272	04042C	PRESIDENT	0	PRESENT	0
362741	361272	11054L	PARTICIPANT	\N	PRESENT	0
362742	361272	11066Q	PARTICIPANT	\N	PRESENT	0
362743	361272	19669L	PARTICIPANT	\N	PRESENT	0
362744	361272	08056B	PARTICIPANT	\N	PRESENT	0
362745	361272	11115U	PARTICIPANT	\N	PRESENT	0
362746	361272	95037J	PARTICIPANT	\N	PRESENT	0
362747	361272	14055N	PARTICIPANT	\N	PRESENT	0
362748	361272	19421M	PARTICIPANT	\N	PRESENT	0
362749	361272	19709B	PARTICIPANT	\N	PRESENT	0
362750	361272	08049C	PARTICIPANT	\N	PRESENT	0
362751	361272	08053X	PARTICIPANT	\N	PRESENT	0
362752	361272	08061X	PARTICIPANT	\N	PRESENT	0
362753	361272	97011G	PARTICIPANT	\N	PRESENT	0
362754	361272	08047A	PARTICIPANT	\N	PRESENT	0
362755	361272	98029W	PARTICIPANT	\N	PRESENT	0
362756	361272	14097Y	PARTICIPANT	\N	PRESENT	0
362757	361272	04035D	PARTICIPANT	\N	PRESENT	0
362758	361272	95067Q	PARTICIPANT	\N	PRESENT	0
362759	361272	01062T	PARTICIPANT	\N	PRESENT	0
362760	361272	11041F	PARTICIPANT	\N	PRESENT	0
362761	361272	14235Q	PARTICIPANT	\N	PRESENT	0
362762	361272	08058D	PARTICIPANT	\N	PRESENT	0
362763	361272	19251M	PARTICIPANT	\N	PRESENT	0
362764	361272	14028W	PARTICIPANT	\N	PRESENT	0
362765	361272	19721W	PARTICIPANT	\N	PRESENT	0
362766	361272	14105F	PARTICIPANT	\N	PRESENT	0
362767	361272	98022P	PARTICIPANT	\N	PRESENT	0
362768	361272	14267Y	PARTICIPANT	\N	PRESENT	0
362769	361272	11064N	PARTICIPANT	\N	PRESENT	0
362770	361272	98050T	PARTICIPANT	\N	PRESENT	0
362771	361272	14211G	PARTICIPANT	\N	PRESENT	0
362772	361272	19583F	PARTICIPANT	\N	PRESENT	0
362773	361272	14255U	PARTICIPANT	\N	PRESENT	0
362774	361272	98018T	PARTICIPANT	\N	EXCUSE	0
362775	361550	95041E	PARTICIPANT	\N	PRESENT	0
362776	361550	19711U	PARTICIPANT	\N	PRESENT	0
362777	361550	07004J	PARTICIPANT	\N	PRESENT	0
362778	361550	99004R	PARTICIPANT	\N	PRESENT	0
362779	361550	14173T	PARTICIPANT	\N	PRESENT	0
362780	361550	08034U	PARTICIPANT	\N	PRESENT	0
362781	361550	12016W	PARTICIPANT	\N	PRESENT	0
362782	361550	11053K	PARTICIPANT	\N	PRESENT	0
362783	361550	19667J	PARTICIPANT	\N	PRESENT	0
362784	361550	14225N	PRESIDENT	1	PRESENT	0
362785	361550	11070L	PARTICIPANT	\N	PRESENT	0
362786	361550	14159V	PARTICIPANT	\N	PRESENT	0
362787	361550	11040E	PARTICIPANT	\N	PRESENT	0
362788	361550	04086Q	PARTICIPANT	\N	PRESENT	0
362789	361550	14085U	PARTICIPANT	\N	PRESENT	0
362790	361550	14121F	PARTICIPANT	\N	PRESENT	0
362793	361550	19479G	PARTICIPANT	\N	PRESENT	0
362794	361550	01057W	PARTICIPANT	\N	PRESENT	0
362795	361169	19441R	PARTICIPANT	\N	PRESENT	0
362796	361169	14081Q	PARTICIPANT	\N	PRESENT	0
362797	361169	19631V	PARTICIPANT	\N	PRESENT	0
362860	360656	14227Q	PARTICIPANT	\N	PRESENT	0
362857	361550	14331P	PARTICIPANT	\N	PRESENT	0
362858	360656	19527W	PARTICIPANT	\N	PRESENT	0
362859	360656	19577H	PARTICIPANT	\N	PRESENT	0
362861	360656	14239U	PARTICIPANT	\N	PRESENT	0
362864	361272	95030B	PARTICIPANT	\N	PRESENT	0
362865	361550	01034P	PARTICIPANT	\N	PRESENT	0
362866	360656	08048B	PARTICIPANT	\N	PRESENT	0
362920	360657	10006L	PARTICIPANT	\N	PRESENT	0
362933	361550	14034U	PARTICIPANT	\N	PRESENT	0
362938	361550	19531S	PARTICIPANT	\N	PRESENT	0
362941	362657	08044W	PARTICIPANT	\N	PRESENT	0
362942	362657	19253P	PARTICIPANT	\N	PRESENT	0
362943	362657	01024M	PARTICIPANT	\N	PRESENT	0
362944	362657	04044E	PARTICIPANT	\N	PRESENT	0
362945	362657	19585H	PARTICIPANT	\N	PRESENT	0
362946	362657	19675J	PARTICIPANT	\N	PRESENT	0
362947	362657	01028R	PARTICIPANT	\N	PRESENT	0
362948	362657	05008E	PRESIDENT	0	PRESENT	0
362949	362657	14001X	PARTICIPANT	\N	PRESENT	0
362950	362657	19543W	PARTICIPANT	\N	PRESENT	0
362951	362657	19581D	PARTICIPANT	\N	PRESENT	0
362952	362657	04047H	PARTICIPANT	\N	PRESENT	0
362953	362657	19447X	PARTICIPANT	\N	PRESENT	0
362954	362657	14231L	PARTICIPANT	\N	PRESENT	0
362955	362657	19489J	PARTICIPANT	\N	PRESENT	0
362956	362657	14041T	PARTICIPANT	\N	PRESENT	0
362957	362657	14147R	PARTICIPANT	\N	PRESENT	0
362958	362657	14179A	PARTICIPANT	\N	PRESENT	0
362959	362657	14151M	PARTICIPANT	\N	PRESENT	0
362960	362657	14215L	PARTICIPANT	\N	PRESENT	0
362961	362657	14259Y	PARTICIPANT	\N	PRESENT	0
362962	362657	11072N	PARTICIPANT	\N	PRESENT	0
362963	362657	98035U	PARTICIPANT	\N	PRESENT	0
362964	362657	14053L	PARTICIPANT	\N	PRESENT	0
362965	362657	14065Q	PARTICIPANT	\N	PRESENT	0
362966	362657	14111D	PARTICIPANT	\N	PRESENT	0
362967	362657	08045X	PARTICIPANT	\N	PRESENT	0
362968	362657	10015M	PARTICIPANT	\N	PRESENT	0
362969	362657	11026G	PARTICIPANT	\N	PRESENT	0
362970	362657	04038G	PARTICIPANT	\N	PRESENT	0
362971	362657	11033F	PARTICIPANT	\N	PRESENT	0
362972	362657	14089Y	PARTICIPANT	\N	PRESENT	0
362973	362657	19729F	PARTICIPANT	\N	PRESENT	0
362974	362657	19629C	PARTICIPANT	\N	PRESENT	0
362975	362657	14069U	PARTICIPANT	\N	PRESENT	0
362976	362657	11049P	PARTICIPANT	\N	PRESENT	0
362977	362657	14021P	PARTICIPANT	\N	PRESENT	0
366704	345243	14038Y	PARTICIPANT	\N	PRESENT	0
366705	345243	19443T	PARTICIPANT	\N	PRESENT	0
366708	345243	12016W	PARTICIPANT	\N	PRESENT	0
366709	345243	01057W	PARTICIPANT	\N	PRESENT	0
366710	345243	19747H	PARTICIPANT	\N	PRESENT	0
366711	345243	14219Q	PARTICIPANT	\N	PRESENT	0
366712	345243	14097Y	PARTICIPANT	\N	PRESENT	0
366713	345243	14225N	PARTICIPANT	\N	PRESENT	0
366714	345243	07004J	PARTICIPANT	\N	PRESENT	0
366715	345243	14030Q	PARTICIPANT	\N	PRESENT	0
366716	345243	19549D	PARTICIPANT	\N	PRESENT	0
366717	345243	14265W	PARTICIPANT	\N	PRESENT	0
366718	345243	19611R	PARTICIPANT	\N	PRESENT	0
366719	345243	14207L	PARTICIPANT	\N	PRESENT	0
366725	345243	14059S	PARTICIPANT	\N	PRESENT	0
366726	345243	19733B	PARTICIPANT	\N	PRESENT	0
366727	345243	14115H	PARTICIPANT	\N	PRESENT	0
366728	345243	01025N	PARTICIPANT	\N	PRESENT	0
366729	345243	19631V	PARTICIPANT	\N	PRESENT	0
366730	345243	19711U	PARTICIPANT	\N	PRESENT	0
366731	345243	14259Y	PARTICIPANT	\N	PRESENT	0
366732	345243	19253P	PARTICIPANT	\N	PRESENT	0
366733	345243	19745F	PARTICIPANT	\N	PRESENT	0
366745	345243	14069U	PARTICIPANT	\N	PRESENT	0
366735	345243	88008L	PARTICIPANT	\N	PRESENT	0
366736	345243	14121F	PARTICIPANT	\N	PRESENT	0
366737	345243	14073Q	PARTICIPANT	\N	PRESENT	0
366738	345243	14063N	PARTICIPANT	\N	PRESENT	0
366739	345243	11026G	PARTICIPANT	\N	PRESENT	0
366740	345243	14231L	PARTICIPANT	\N	PRESENT	0
366741	345243	19543W	PARTICIPANT	\N	PRESENT	0
366742	345243	19693L	PARTICIPANT	\N	PRESENT	0
366743	345243	14061L	PARTICIPANT	\N	PRESENT	0
366744	345243	08034U	PARTICIPANT	\N	PRESENT	0
366746	345243	19782L	PARTICIPANT	\N	PRESENT	0
366747	345243	19515S	PARTICIPANT	\N	PRESENT	0
366748	345243	19369B	PARTICIPANT	\N	PRESENT	0
366749	345243	04049K	PARTICIPANT	\N	PRESENT	0
366750	345243	08062Y	PARTICIPANT	\N	PRESENT	0
366751	345243	19575F	PARTICIPANT	\N	PRESENT	0
366752	345243	80013X	PARTICIPANT	\N	PRESENT	0
366753	345243	14109K	PARTICIPANT	\N	PRESENT	0
366754	365638	19593H	PARTICIPANT	\N	PRESENT	0
366755	365638	04070G	PRESIDENT	0	PRESENT	0
366756	365638	04057K	PARTICIPANT	\N	PRESENT	0
366757	365638	14073Q	PARTICIPANT	\N	PRESENT	0
366758	365638	19533U	PARTICIPANT	\N	PRESENT	0
366759	365638	19611R	PARTICIPANT	\N	PRESENT	0
366760	365638	08043V	PARTICIPANT	\N	PRESENT	0
366761	365638	19399H	PARTICIPANT	\N	PRESENT	0
366762	365638	14030Q	PARTICIPANT	\N	PRESENT	0
366763	365638	14241N	PARTICIPANT	\N	PRESENT	0
366764	365638	19573D	PARTICIPANT	\N	PRESENT	0
366765	365638	14039A	PARTICIPANT	\N	PRESENT	0
366766	365638	19735D	PARTICIPANT	\N	PRESENT	0
366767	365638	14063N	PARTICIPANT	\N	PRESENT	0
379745	379744	14255U	PARTICIPANT	\N	PRESENT	0
379746	379744	08053X	PARTICIPANT	\N	PRESENT	0
379765	371479	98024R	PARTICIPANT	\N	PRESENT	0
379766	371479	08035V	PARTICIPANT	\N	PRESENT	0
379767	371479	14123H	PARTICIPANT	\N	PRESENT	0
379768	371479	11026G	PARTICIPANT	\N	PRESENT	0
379941	379917	08060W	PARTICIPANT	\N	PRESENT	0
379942	379917	14097Y	PARTICIPANT	\N	PRESENT	0
379943	379917	19762G	PARTICIPANT	\N	PRESENT	0
379944	379917	14051J	PARTICIPANT	\N	PRESENT	0
379945	379917	14207L	PARTICIPANT	\N	PRESENT	0
379946	379917	14033T	PARTICIPANT	\N	PRESENT	0
379947	379917	95067Q	PARTICIPANT	\N	PRESENT	0
379948	379917	14031R	PARTICIPANT	\N	PRESENT	0
379949	379917	14038Y	PARTICIPANT	\N	PRESENT	0
379950	379917	14157T	PRESIDENT	0	PRESENT	0
379952	379917	08038Y	PARTICIPANT	\N	EXCUSE	0
379954	379917	19745F	PARTICIPANT	\N	EXCUSE	0
379955	379917	19629C	PARTICIPANT	\N	PRESENT	0
379967	377016	14121F	PARTICIPANT	\N	PRESENT	0
380021	380020	19619A	PARTICIPANT	\N	PRESENT	0
380022	380020	14033T	PARTICIPANT	\N	PRESENT	0
380026	380025	19619A	PARTICIPANT	\N	PRESENT	0
380154	380150	14261S	PARTICIPANT	\N	PRESENT	0
380155	380150	14119M	PARTICIPANT	\N	PRESENT	0
382443	371535	04059M	PARTICIPANT	\N	PRESENT	0
382444	371535	19758L	PARTICIPANT	\N	PRESENT	0
382445	371535	11033F	PARTICIPANT	\N	PRESENT	0
382446	371535	04085P	PARTICIPANT	\N	PRESENT	0
382447	371535	14121F	PARTICIPANT	\N	PRESENT	0
382448	371535	14197C	PARTICIPANT	\N	PRESENT	0
382449	371535	19651A	PARTICIPANT	\N	PRESENT	0
382450	371535	11083R	PARTICIPANT	\N	PRESENT	0
382451	371535	19441R	PARTICIPANT	\N	PRESENT	0
382452	371535	01024M	PARTICIPANT	\N	PRESENT	0
382453	371535	14083S	PARTICIPANT	\N	PRESENT	0
382454	371535	04070G	PARTICIPANT	\N	PRESENT	0
382455	371535	07004J	PARTICIPANT	\N	PRESENT	0
382456	371535	14231L	PARTICIPANT	\N	PRESENT	0
382457	371535	97011G	PARTICIPANT	\N	PRESENT	0
382458	371535	08031R	PARTICIPANT	\N	PRESENT	0
382459	371535	14261S	PARTICIPANT	\N	PRESENT	0
382460	371535	14105F	PARTICIPANT	\N	PRESENT	0
382461	371535	14265W	PARTICIPANT	\N	PRESENT	0
382462	371535	04049K	PARTICIPANT	\N	PRESENT	0
382463	371535	19399H	PARTICIPANT	\N	PRESENT	0
382464	371535	19507S	PARTICIPANT	\N	PRESENT	0
382465	371535	04088S	PARTICIPANT	\N	PRESENT	0
382466	371535	14029X	PARTICIPANT	\N	PRESENT	0
382467	371535	19467C	PARTICIPANT	\N	PRESENT	0
382441	371535	11070L	PARTICIPANT	\N	PRESENT	0
382442	371535	19699S	PARTICIPANT	\N	PRESENT	0
382468	371535	19667J	PARTICIPANT	\N	PRESENT	0
382469	371535	01057W	PARTICIPANT	\N	PRESENT	0
382470	371535	08039A	PARTICIPANT	\N	PRESENT	0
382471	371535	01048V	PARTICIPANT	\N	PRESENT	0
382472	371535	14030Q	PARTICIPANT	\N	PRESENT	0
382473	371535	19693L	PARTICIPANT	\N	PRESENT	0
382474	371535	19447X	PARTICIPANT	\N	PRESENT	0
382475	371535	12041X	PARTICIPANT	\N	PRESENT	0
382476	371535	14053L	PARTICIPANT	\N	PRESENT	0
382477	371535	19671E	PARTICIPANT	\N	PRESENT	0
382478	371535	19581D	PARTICIPANT	\N	PRESENT	0
382479	371535	14229S	PARTICIPANT	\N	PRESENT	0
382480	371535	19745F	PARTICIPANT	\N	PRESENT	0
382481	371535	14219Q	PARTICIPANT	\N	PRESENT	0
382482	371535	19673G	PARTICIPANT	\N	PRESENT	0
382483	371535	04057K	PARTICIPANT	\N	PRESENT	0
382484	371535	95030B	PARTICIPANT	\N	PRESENT	0
382485	371535	19543W	PARTICIPANT	\N	PRESENT	0
382486	371535	08043V	PARTICIPANT	\N	PRESENT	0
382487	371535	14063N	PARTICIPANT	\N	PRESENT	0
382488	371535	14249W	PARTICIPANT	\N	PRESENT	0
382492	371535	08061X	PARTICIPANT	\N	PRESENT	0
382493	371535	19701S	PARTICIPANT	\N	PRESENT	0
382494	371535	14147R	PARTICIPANT	\N	PRESENT	0
382495	371535	19749K	PARTICIPANT	\N	PRESENT	0
382496	371535	11012A	PARTICIPANT	\N	PRESENT	0
382497	382289	14217N	PARTICIPANT	\N	PRESENT	0
382498	382289	19691J	PARTICIPANT	\N	PRESENT	0
382499	382289	14071N	PARTICIPANT	\N	PRESENT	0
382836	382835	19593H	PARTICIPANT	\N	PRESENT	0
382837	382835	04070G	PRESIDENT	0	PRESENT	0
382838	382835	19643A	PARTICIPANT	\N	PRESENT	0
382839	382835	19533U	PARTICIPANT	\N	PRESENT	0
382840	382835	04033B	PARTICIPANT	\N	PRESENT	0
382841	382835	08043V	PARTICIPANT	\N	PRESENT	0
382842	382835	19693L	PARTICIPANT	\N	PRESENT	0
382843	382835	19399H	PARTICIPANT	\N	PRESENT	0
382844	382835	14229S	PARTICIPANT	\N	PRESENT	0
382845	382835	14241N	PARTICIPANT	\N	PRESENT	0
382846	382835	14251Q	PARTICIPANT	\N	PRESENT	0
382847	382835	04059M	PARTICIPANT	\N	PRESENT	0
382848	382835	19735D	PARTICIPANT	\N	PRESENT	0
382849	382835	08017T	PARTICIPANT	\N	PRESENT	0
382850	382835	14109K	PARTICIPANT	\N	PRESENT	0
382851	382835	11083R	PARTICIPANT	\N	PRESENT	0
382852	382835	11043H	PARTICIPANT	\N	PRESENT	0
382853	382835	19749K	PARTICIPANT	\N	PRESENT	0
382854	382835	04018C	PARTICIPANT	\N	PRESENT	0
382855	382835	14249W	PARTICIPANT	\N	PRESENT	0
382856	382835	08039A	PARTICIPANT	\N	PRESENT	0
383324	382614	08028W	PARTICIPANT	\N	PRESENT	0
383325	371540	14201E	PARTICIPANT	\N	PRESENT	0
383326	371540	19725B	PARTICIPANT	\N	PRESENT	0
383327	371540	19591F	PARTICIPANT	\N	PRESENT	0
383328	382614	11065P	PARTICIPANT	\N	PRESENT	0
383329	371540	08043V	PARTICIPANT	\N	PRESENT	0
383330	371540	14235Q	PARTICIPANT	\N	PRESENT	0
383331	371540	01025N	PARTICIPANT	\N	PRESENT	0
383332	371540	01024M	PARTICIPANT	\N	PRESENT	0
383333	371540	19563B	PARTICIPANT	\N	PRESENT	0
383334	371540	19507S	PARTICIPANT	\N	PRESENT	0
383335	382180	19637C	PARTICIPANT	\N	PRESENT	0
383336	382614	19637C	PARTICIPANT	\N	PRESENT	0
383337	371540	08055A	PARTICIPANT	\N	PRESENT	0
383338	371540	19253P	PARTICIPANT	\N	PRESENT	0
383339	371540	08020N	PARTICIPANT	\N	PRESENT	0
383340	371540	19367Y	PARTICIPANT	\N	PRESENT	0
383341	382614	19733B	PARTICIPANT	\N	PRESENT	0
383342	371540	14207L	PARTICIPANT	\N	PRESENT	0
383343	371540	08012N	PARTICIPANT	\N	PRESENT	0
383344	382614	14169X	PARTICIPANT	\N	PRESENT	0
383345	382614	19347U	PARTICIPANT	\N	PRESENT	0
383409	382614	19737F	PARTICIPANT	\N	PRESENT	0
383443	382180	19733B	PARTICIPANT	\N	PRESENT	0
383445	382180	14169X	PARTICIPANT	\N	PRESENT	0
383447	382180	19347U	PARTICIPANT	\N	PRESENT	0
383448	382180	19737F	PARTICIPANT	\N	PRESENT	0
383669	383668	14069U	PARTICIPANT	\N	PRESENT	0
383671	383668	19719D	PARTICIPANT	\N	PRESENT	0
383995	376926	14261S	PARTICIPANT	\N	PRESENT	0
383999	371542	14051J	PARTICIPANT	\N	PRESENT	0
383997	371542	80013X	PARTICIPANT	\N	PRESENT	0
383998	371542	14281W	PARTICIPANT	\N	PRESENT	0
384000	371542	19551W	PARTICIPANT	\N	PRESENT	0
384001	371542	19758L	PARTICIPANT	\N	PRESENT	0
384002	371542	19563B	PARTICIPANT	\N	PRESENT	0
384003	382778	04057K	PARTICIPANT	\N	PRESENT	0
384004	382778	19531S	PARTICIPANT	\N	PRESENT	0
384005	382778	08069G	PARTICIPANT	\N	PRESENT	0
384006	382778	19441R	PARTICIPANT	\N	PRESENT	0
384007	382778	14001X	PARTICIPANT	\N	PRESENT	0
384008	382778	19581D	PARTICIPANT	\N	PRESENT	0
384009	382778	14033T	PARTICIPANT	\N	PRESENT	0
384010	382778	08014Q	PARTICIPANT	\N	PRESENT	0
384011	382778	14026U	PARTICIPANT	\N	PRESENT	0
384012	382778	19725B	PRESIDENT	0	PRESENT	0
384013	382778	08073C	PARTICIPANT	\N	PRESENT	0
384014	382778	14107H	PARTICIPANT	\N	PRESENT	0
384015	382778	08015R	PARTICIPANT	\N	PRESENT	0
384016	382778	04097T	PARTICIPANT	\N	PRESENT	0
384017	382778	19747H	PARTICIPANT	\N	PRESENT	0
384018	382778	19295A	PARTICIPANT	\N	EXCUSE	0
384019	371542	14219Q	PARTICIPANT	\N	PRESENT	0
384020	371542	19479G	PARTICIPANT	\N	PRESENT	0
384021	371542	14073Q	PARTICIPANT	\N	PRESENT	0
384022	371542	14089Y	PARTICIPANT	\N	PRESENT	0
384023	371542	14030Q	PARTICIPANT	\N	PRESENT	0
384024	371542	19760E	PARTICIPANT	\N	PRESENT	0
384034	371542	19733B	PARTICIPANT	\N	PRESENT	0
384026	371542	19515S	PARTICIPANT	\N	PRESENT	0
384027	371542	14169X	PARTICIPANT	\N	PRESENT	0
384028	371542	08039A	PARTICIPANT	\N	PRESENT	0
384029	371542	10006L	PARTICIPANT	\N	PRESENT	0
384030	371542	14223L	PARTICIPANT	\N	PRESENT	0
384031	371542	14187A	PARTICIPANT	\N	PRESENT	0
384032	371542	19794Q	PARTICIPANT	\N	PRESENT	0
384033	371542	14087W	PARTICIPANT	\N	PRESENT	0
363187	363183	04092N	PARTICIPANT	\N	PRESENT	0
363188	363183	19723Y	PARTICIPANT	\N	PRESENT	0
363191	363183	14042U	PARTICIPANT	\N	PRESENT	0
363194	363183	14213J	PARTICIPANT	\N	PRESENT	0
363196	363183	10006L	PARTICIPANT	\N	PRESENT	0
363198	363183	14239U	PARTICIPANT	\N	PRESENT	0
363200	363183	08052W	PARTICIPANT	\N	PRESENT	0
363201	363183	19683J	PARTICIPANT	\N	PRESENT	0
363202	363183	19663E	PARTICIPANT	\N	PRESENT	0
363203	363183	19553Y	PARTICIPANT	\N	PRESENT	0
363204	363183	19691J	PARTICIPANT	\N	PRESENT	0
363205	363183	11097X	PARTICIPANT	\N	PRESENT	0
363405	356246	19515S	PARTICIPANT	\N	PRESENT	0
363406	356246	19711U	PARTICIPANT	\N	PRESENT	0
363425	356246	14107H	PARTICIPANT	\N	PRESENT	0
363426	356246	19383Y	PARTICIPANT	\N	PRESENT	0
364679	363152	10006L	PRESIDENT	0	PRESENT	0
364680	363152	11067R	PARTICIPANT	\N	PRESENT	0
364681	363152	14147R	PARTICIPANT	\N	PRESENT	0
364682	363152	19749K	PARTICIPANT	\N	PRESENT	0
364683	363152	14223L	PARTICIPANT	\N	PRESENT	0
364685	363152	19415P	PARTICIPANT	\N	PRESENT	0
364686	363152	19447X	PARTICIPANT	\N	PRESENT	0
364688	363152	14030Q	PARTICIPANT	\N	PRESENT	0
364691	363152	11043H	PARTICIPANT	\N	PRESENT	0
364693	363152	19569H	PARTICIPANT	\N	PRESENT	0
364695	363152	04047H	PARTICIPANT	\N	EXCUSE	0
364728	363152	19723Y	PARTICIPANT	\N	PRESENT	0
364770	363152	14213J	PARTICIPANT	\N	PRESENT	0
371218	371216	14031R	PARTICIPANT	\N	PRESENT	0
371219	371216	19762G	PARTICIPANT	\N	PRESENT	0
371220	371216	19733B	PARTICIPANT	\N	PRESENT	0
371221	371216	14157T	PARTICIPANT	\N	PRESENT	0
371222	371216	08060W	PARTICIPANT	\N	PRESENT	0
371223	371216	95067Q	PARTICIPANT	\N	PRESENT	0
371224	371217	14157T	PARTICIPANT	\N	PRESENT	0
371225	371217	19733B	PARTICIPANT	\N	PRESENT	0
371226	371217	08060W	PARTICIPANT	\N	PRESENT	0
371227	371217	19762G	PARTICIPANT	\N	PRESENT	0
371228	371217	95067Q	PARTICIPANT	\N	PRESENT	0
371229	371217	14031R	PARTICIPANT	\N	PRESENT	0
376552	376551	08055A	PARTICIPANT	\N	PRESENT	0
376553	376551	04047H	PARTICIPANT	\N	PRESENT	0
376554	376551	19545Y	PARTICIPANT	\N	PRESENT	0
376555	376551	14085U	PARTICIPANT	\N	PRESENT	0
376556	376551	11080N	PARTICIPANT	\N	PRESENT	0
376557	376551	01057W	PARTICIPANT	\N	PRESENT	0
376558	376551	14157T	PARTICIPANT	\N	PRESENT	0
377680	375457	19553Y	PARTICIPANT	\N	PRESENT	0
377681	375457	19727D	PARTICIPANT	\N	PRESENT	0
377682	375457	04092N	PRESIDENT	0	PRESENT	0
377683	375457	14281W	PARTICIPANT	\N	PRESENT	0
377684	375457	19679N	PARTICIPANT	\N	PRESENT	0
377685	375457	08052W	PARTICIPANT	\N	PRESENT	0
377686	375457	14195A	PARTICIPANT	\N	PRESENT	0
377687	375457	14261S	PARTICIPANT	\N	PRESENT	0
377688	375457	14227Q	PARTICIPANT	\N	PRESENT	0
377689	375457	08041T	PARTICIPANT	\N	EXCUSE	0
377690	375457	11067R	PARTICIPANT	\N	PRESENT	0
377746	376986	04070G	PRESIDENT	0	PRESENT	0
377747	376986	19699S	PARTICIPANT	\N	PRESENT	0
377748	376986	19329S	PARTICIPANT	\N	PRESENT	0
377749	376986	04033B	PARTICIPANT	\N	PRESENT	0
377750	376986	14229S	PARTICIPANT	\N	PRESENT	0
377751	376986	14241N	PARTICIPANT	\N	PRESENT	0
377752	376986	14039A	PARTICIPANT	\N	PRESENT	0
377753	376986	14107H	PARTICIPANT	\N	PRESENT	0
377754	376986	92040Q	PARTICIPANT	\N	PRESENT	0
377755	376986	08012N	PARTICIPANT	\N	PRESENT	0
377756	376986	08039A	PARTICIPANT	\N	PRESENT	0
377757	376986	08031R	PARTICIPANT	\N	PRESENT	0
377758	376986	19593H	PARTICIPANT	\N	PRESENT	0
377759	376986	19643A	PARTICIPANT	\N	PRESENT	0
377760	376986	14061L	PARTICIPANT	\N	PRESENT	0
377761	376986	14073Q	PARTICIPANT	\N	PRESENT	0
377762	376986	19611R	PARTICIPANT	\N	PRESENT	0
377763	376986	08043V	PARTICIPANT	\N	PRESENT	0
377764	376986	19693L	PARTICIPANT	\N	PRESENT	0
377765	376986	87003B	PARTICIPANT	\N	PRESENT	0
377766	376986	19399H	PARTICIPANT	\N	PRESENT	0
377767	376986	14201E	PARTICIPANT	\N	PRESENT	0
377768	376986	14030Q	PARTICIPANT	\N	PRESENT	0
377769	376986	19731Y	PARTICIPANT	\N	PRESENT	0
377770	376986	08020N	PARTICIPANT	\N	PRESENT	0
377771	376986	04059M	PARTICIPANT	\N	PRESENT	0
377772	376986	19735D	PARTICIPANT	\N	PRESENT	0
377773	376986	14063N	PARTICIPANT	\N	PRESENT	0
377774	376986	11083R	PARTICIPANT	\N	PRESENT	0
377775	376986	14123H	PARTICIPANT	\N	PRESENT	0
377776	376986	11104D	PARTICIPANT	\N	PRESENT	0
377777	376986	19749K	PARTICIPANT	\N	PRESENT	0
377778	376986	04018C	PARTICIPANT	\N	PRESENT	0
377779	376986	19758L	PARTICIPANT	\N	PRESENT	0
377780	376986	19621T	PARTICIPANT	\N	PRESENT	0
377781	376605	08019V	PARTICIPANT	\N	PRESENT	0
377782	376605	08062Y	PARTICIPANT	\N	PRESENT	0
377783	376605	01025N	PARTICIPANT	\N	PRESENT	0
377786	376605	08068F	PARTICIPANT	\N	EXCUSE	0
377787	376605	01043Q	PARTICIPANT	\N	EXCUSE	0
377788	376605	08038Y	PARTICIPANT	\N	EXCUSE	0
377789	376605	19413M	PARTICIPANT	\N	EXCUSE	0
377790	376605	19511N	PARTICIPANT	\N	EXCUSE	0
377791	376605	08021P	PARTICIPANT	\N	EXCUSE	0
377792	376605	11081P	PARTICIPANT	\N	EXCUSE	0
377793	376605	19591F	PARTICIPANT	\N	EXCUSE	0
377794	376605	14205J	PARTICIPANT	\N	PRESENT	0
377795	376605	19467C	PARTICIPANT	\N	PRESENT	0
377796	376605	04088S	PARTICIPANT	\N	PRESENT	0
377797	376605	14115H	PARTICIPANT	\N	PRESENT	0
377798	376605	11101A	PARTICIPANT	\N	PRESENT	0
377799	376605	14187A	PARTICIPANT	\N	PRESENT	0
377800	376605	19441R	PARTICIPANT	\N	PRESENT	0
377801	376605	14197C	PARTICIPANT	\N	PRESENT	0
377802	376605	14033T	PARTICIPANT	\N	PRESENT	0
377803	376605	19631V	PARTICIPANT	\N	PRESENT	0
377804	376605	19768N	PARTICIPANT	\N	PRESENT	0
377805	376605	19515S	PARTICIPANT	\N	PRESENT	0
377806	376605	04049K	PARTICIPANT	\N	PRESENT	0
377807	376605	11090Q	PRESIDENT	0	PRESENT	0
377808	376605	19619A	PARTICIPANT	\N	PRESENT	0
377809	376740	98005N	PARTICIPANT	\N	PRESENT	0
377810	376740	19443T	PARTICIPANT	\N	PRESENT	0
377811	376740	12041X	PARTICIPANT	\N	PRESENT	0
377812	376740	95030B	PARTICIPANT	\N	PRESENT	0
377813	376740	04034C	PARTICIPANT	\N	PRESENT	0
377814	376740	04040A	PARTICIPANT	\N	PRESENT	0
377815	376740	01058X	PARTICIPANT	\N	PRESENT	0
377816	376740	14079W	PARTICIPANT	\N	PRESENT	0
377817	376740	16685X	PARTICIPANT	\N	PRESENT	0
377818	376740	04042C	PRESIDENT	0	PRESENT	0
377819	376740	11054L	PARTICIPANT	\N	PRESENT	0
377820	376740	11066Q	PARTICIPANT	\N	PRESENT	0
377821	376740	08056B	PARTICIPANT	\N	PRESENT	0
377822	376740	95037J	PARTICIPANT	\N	PRESENT	0
377823	376740	14055N	PARTICIPANT	\N	PRESENT	0
377824	376740	19421M	PARTICIPANT	\N	PRESENT	0
377825	376740	19709B	PARTICIPANT	\N	PRESENT	0
377826	376740	14193X	PARTICIPANT	\N	PRESENT	0
377827	376740	08049C	PARTICIPANT	\N	PRESENT	0
377828	376740	08053X	PARTICIPANT	\N	PRESENT	0
377829	376740	97011G	PARTICIPANT	\N	PRESENT	0
377830	376740	08061X	PARTICIPANT	\N	PRESENT	0
377831	376740	08047A	PARTICIPANT	\N	PRESENT	0
377832	376740	98029W	PARTICIPANT	\N	PRESENT	0
377833	376740	14097Y	PARTICIPANT	\N	PRESENT	0
377834	376740	95067Q	PARTICIPANT	\N	PRESENT	0
377835	376740	01062T	PARTICIPANT	\N	PRESENT	0
377836	376740	11041F	PARTICIPANT	\N	PRESENT	0
377837	376740	14235Q	PARTICIPANT	\N	PRESENT	0
377838	376740	08058D	PARTICIPANT	\N	PRESENT	0
377839	376740	19251M	PARTICIPANT	\N	PRESENT	0
377840	376740	19721W	PARTICIPANT	\N	PRESENT	0
377841	376740	14105F	PARTICIPANT	\N	PRESENT	0
377842	376740	14267Y	PARTICIPANT	\N	PRESENT	0
377843	376740	11064N	PARTICIPANT	\N	PRESENT	0
377844	376740	98050T	PARTICIPANT	\N	PRESENT	0
377845	376740	19583F	PARTICIPANT	\N	PRESENT	0
377846	376740	14211G	PARTICIPANT	\N	PRESENT	0
377847	376740	14255U	PARTICIPANT	\N	PRESENT	0
377848	376605	80013X	PARTICIPANT	\N	PRESENT	0
377849	377745	19333N	PARTICIPANT	\N	PRESENT	0
377850	377745	14038Y	PARTICIPANT	\N	PRESENT	0
377851	377745	19383Y	PARTICIPANT	\N	PRESENT	0
377852	377745	17583W	PARTICIPANT	\N	PRESENT	0
377853	377745	19701S	PARTICIPANT	\N	PRESENT	0
377854	377745	19549D	PARTICIPANT	\N	PRESENT	0
377855	377745	19387D	PARTICIPANT	\N	PRESENT	0
377856	377745	19599P	PARTICIPANT	\N	PRESENT	0
377857	377745	14169X	PARTICIPANT	\N	PRESENT	0
392755	391359	89017R	PARTICIPANT	\N	PRESENT	0
392880	392879	19563B	PARTICIPANT	\N	PRESENT	0
392881	392879	08043V	PARTICIPANT	\N	PRESENT	0
396089	391707	19553Y	PARTICIPANT	\N	PRESENT	0
396087	391707	14079W	PARTICIPANT	\N	PRESENT	0
396088	391707	04035D	PARTICIPANT	\N	PRESENT	0
396090	391707	14241N	PARTICIPANT	\N	PRESENT	0
396091	391707	08014Q	PARTICIPANT	\N	PRESENT	0
396092	391707	10015M	PARTICIPANT	\N	PRESENT	0
396093	391707	96004D	PRESIDENT	0	PRESENT	0
396094	391707	04057K	PARTICIPANT	\N	EXCUSE	0
396095	391707	14357A	PARTICIPANT	\N	EXCUSE	0
396096	391707	14065Q	PARTICIPANT	\N	EXCUSE	0
396098	391707	14133K	PARTICIPANT	\N	EXCUSE	0
396099	391707	14061L	PARTICIPANT	\N	EXCUSE	0
396100	391707	11083R	PARTICIPANT	\N	EXCUSE	0
396110	391707	14331P	PARTICIPANT	\N	EXCUSE	0
396124	396123	14033T	PARTICIPANT	\N	PRESENT	0
396126	396125	14033T	PARTICIPANT	\N	PRESENT	0
396127	396125	04049K	PARTICIPANT	\N	PRESENT	0
396170	396169	19733B	PARTICIPANT	\N	PRESENT	0
396172	396171	19733B	PARTICIPANT	\N	PRESENT	0
396194	396191	08055A	PARTICIPANT	\N	PRESENT	0
396195	396191	14207L	PARTICIPANT	\N	PRESENT	0
396196	396191	14197C	PARTICIPANT	\N	PRESENT	0
396197	396191	14187A	PARTICIPANT	\N	PRESENT	0
396198	396191	14061L	PARTICIPANT	\N	PRESENT	0
396199	396191	08053X	PARTICIPANT	\N	PRESENT	0
396200	396191	14109K	PARTICIPANT	\N	PRESENT	0
396201	396191	11012A	PARTICIPANT	\N	PRESENT	0
396202	396191	11097X	PARTICIPANT	\N	PRESENT	0
397113	396243	14225N	PARTICIPANT	\N	EXCUSE	0
400463	400462	19631V	PARTICIPANT	\N	PRESENT	0
400464	400462	14257W	PARTICIPANT	\N	PRESENT	0
400466	400465	01048V	PARTICIPANT	\N	PRESENT	0
400467	400465	14257W	PARTICIPANT	\N	PRESENT	0
400468	400465	19631V	PARTICIPANT	\N	PRESENT	0
400470	400469	19631V	PARTICIPANT	\N	PRESENT	0
400471	400469	01048V	PARTICIPANT	\N	PRESENT	0
400472	400469	14257W	PARTICIPANT	\N	PRESENT	0
400473	400469	19421M	PARTICIPANT	\N	PRESENT	0
400475	400474	14257W	PARTICIPANT	\N	PRESENT	0
400476	400474	01048V	PARTICIPANT	\N	PRESENT	0
400477	400474	14093U	PARTICIPANT	\N	PRESENT	0
400478	400474	19631V	PARTICIPANT	\N	PRESENT	0
400479	400474	11083R	PARTICIPANT	\N	PRESENT	0
400480	400474	19611R	PARTICIPANT	\N	PRESENT	0
400481	400474	19741B	PARTICIPANT	\N	PRESENT	0
400491	400489	14257W	PARTICIPANT	\N	PRESENT	0
400484	400482	01048V	PARTICIPANT	\N	PRESENT	0
400485	400482	14229S	PARTICIPANT	\N	PRESENT	0
400486	400482	14093U	PARTICIPANT	\N	PRESENT	0
400487	400482	19741B	PARTICIPANT	\N	PRESENT	0
400488	400482	19631V	PARTICIPANT	\N	PRESENT	0
400490	400489	01048V	PARTICIPANT	\N	PRESENT	0
400492	400489	14093U	PARTICIPANT	\N	PRESENT	0
400569	400567	05008E	PARTICIPANT	\N	PRESENT	0
400570	400567	14053L	PARTICIPANT	\N	PRESENT	0
400571	400567	04044E	PARTICIPANT	\N	PRESENT	0
400572	400567	14231L	PARTICIPANT	\N	PRESENT	0
400573	400567	14065Q	PARTICIPANT	\N	PRESENT	0
400575	400567	04045F	PARTICIPANT	\N	PRESENT	0
400576	400567	14179A	PARTICIPANT	\N	PRESENT	0
400577	400567	01028R	PARTICIPANT	\N	PRESENT	0
400579	400578	08055A	PARTICIPANT	\N	PRESENT	0
400580	400578	14038Y	PARTICIPANT	\N	PRESENT	0
401847	401846	14039A	PARTICIPANT	\N	PRESENT	0
400582	400578	19599P	PARTICIPANT	\N	PRESENT	0
400583	400578	19387D	PARTICIPANT	\N	PRESENT	0
401848	401846	19735D	PARTICIPANT	\N	PRESENT	0
400585	400578	04097T	PARTICIPANT	\N	PRESENT	0
400586	400578	19551W	PARTICIPANT	\N	PRESENT	0
400587	400578	14031R	PARTICIPANT	\N	PRESENT	0
400588	400578	19637C	PARTICIPANT	\N	PRESENT	0
400589	400578	08009T	PARTICIPANT	\N	PRESENT	0
400590	400578	14169X	PARTICIPANT	\N	PRESENT	0
401849	401846	14229S	PARTICIPANT	\N	PRESENT	0
400592	400578	19737F	PARTICIPANT	\N	PRESENT	0
401850	401846	04018C	PARTICIPANT	\N	PRESENT	0
401851	401846	19749K	PARTICIPANT	\N	PRESENT	0
410106	405448	11109J	PARTICIPANT	\N	PRESENT	0
410107	405448	14261S	PARTICIPANT	\N	PRESENT	0
410108	405448	19717B	PARTICIPANT	\N	PRESENT	0
410109	405448	19631V	PARTICIPANT	\N	PRESENT	0
410110	405448	19659J	PARTICIPANT	\N	PRESENT	0
410111	405448	19577H	PARTICIPANT	\N	PRESENT	0
410112	405448	19691J	PARTICIPANT	\N	PRESENT	0
410113	405448	19329S	PARTICIPANT	\N	PRESENT	0
410114	405448	19715Y	PARTICIPANT	\N	PRESENT	0
410115	405448	14097Y	PARTICIPANT	\N	PRESENT	0
410116	405448	19583F	PARTICIPANT	\N	PRESENT	0
410117	405448	08019V	PRESIDENT	0	PRESENT	0
410118	405448	19319Q	PARTICIPANT	\N	PRESENT	0
410119	405448	19657G	PARTICIPANT	\N	PRESENT	0
410120	405448	11054L	PARTICIPANT	\N	PRESENT	0
410121	405448	19301E	PARTICIPANT	\N	PRESENT	0
410122	405448	80013X	PARTICIPANT	\N	PRESENT	0
410123	405448	19731Y	PARTICIPANT	\N	PRESENT	0
410124	405448	14179A	PARTICIPANT	\N	PRESENT	0
410125	405448	04035D	PARTICIPANT	\N	PRESENT	0
410126	405448	14030Q	PARTICIPANT	\N	PRESENT	0
410127	405448	19599P	PARTICIPANT	\N	PRESENT	0
410231	402305	89017R	PARTICIPANT	\N	PRESENT	0
410232	402305	14133K	PARTICIPANT	\N	PRESENT	0
410233	402305	14239U	PARTICIPANT	\N	PRESENT	0
410234	402305	11109J	PARTICIPANT	\N	PRESENT	0
410235	402305	19760E	PARTICIPANT	\N	PRESENT	0
410236	402305	14261S	PARTICIPANT	\N	PRESENT	0
410237	402305	19717B	PARTICIPANT	\N	PRESENT	0
410239	402305	04085P	PARTICIPANT	\N	PRESENT	0
410241	402305	19515S	PARTICIPANT	\N	PRESENT	0
410243	402305	19741B	PARTICIPANT	\N	PRESENT	0
410244	402305	05008E	PARTICIPANT	\N	PRESENT	0
410245	402305	19667J	PARTICIPANT	\N	PRESENT	0
410246	402305	19543W	PARTICIPANT	\N	PRESENT	0
410247	402305	11033F	PARTICIPANT	\N	PRESENT	0
410248	402305	08055A	PARTICIPANT	\N	PRESENT	0
410251	402305	14115H	PARTICIPANT	\N	PRESENT	0
410253	402305	14065Q	PARTICIPANT	\N	PRESENT	0
410254	402305	19549D	PARTICIPANT	\N	PRESENT	0
410255	402305	14030Q	PARTICIPANT	\N	PRESENT	0
410256	402305	96004D	PARTICIPANT	\N	PRESENT	0
410258	402305	04040A	PARTICIPANT	\N	PRESENT	0
410259	402305	11040E	PARTICIPANT	\N	PRESENT	0
410260	402305	19367Y	PARTICIPANT	\N	PRESENT	0
410261	402305	14069U	PARTICIPANT	\N	PRESENT	0
410262	402305	19415P	PARTICIPANT	\N	PRESENT	0
410263	402305	14089Y	PARTICIPANT	\N	PRESENT	0
410264	402305	08060W	PARTICIPANT	\N	PRESENT	0
410266	402305	08014Q	PARTICIPANT	\N	PRESENT	0
410267	402305	14105F	PARTICIPANT	\N	PRESENT	0
410268	402305	19643A	PARTICIPANT	\N	PRESENT	0
410269	402305	19747H	PARTICIPANT	\N	PRESENT	0
410270	402305	08068F	PARTICIPANT	\N	PRESENT	0
410271	402305	08058D	PARTICIPANT	\N	PRESENT	0
410273	402305	19621T	PARTICIPANT	\N	PRESENT	0
410274	402305	08020N	PARTICIPANT	\N	PRESENT	0
410275	402305	19758L	PARTICIPANT	\N	PRESENT	0
410276	402305	04047H	PARTICIPANT	\N	PRESENT	0
410277	402305	19782L	PARTICIPANT	\N	PRESENT	0
410278	402305	14207L	PARTICIPANT	\N	PRESENT	0
410279	402305	14255U	PARTICIPANT	\N	PRESENT	0
410280	402305	11101A	PARTICIPANT	\N	PRESENT	0
410281	402305	04042C	PARTICIPANT	\N	PRESENT	0
410282	402305	14053L	PARTICIPANT	\N	PRESENT	0
410283	402305	14083S	PARTICIPANT	\N	PRESENT	0
410284	402305	11053K	PARTICIPANT	\N	PRESENT	0
410286	402305	14085U	PARTICIPANT	\N	PRESENT	0
410287	402305	11103C	PARTICIPANT	\N	PRESENT	0
410288	402305	19629C	PARTICIPANT	\N	PRESENT	0
410289	402305	08024S	PARTICIPANT	\N	PRESENT	0
410290	402305	14201E	PARTICIPANT	\N	PRESENT	0
410291	402305	19721W	PARTICIPANT	\N	PRESENT	0
410293	402305	14329V	PARTICIPANT	\N	PRESENT	0
410294	402305	14038Y	PARTICIPANT	\N	PRESENT	0
410295	402305	11080N	PARTICIPANT	\N	PRESENT	0
396716	393390	01024M	PARTICIPANT	\N	PRESENT	0
396717	393390	14026U	PARTICIPANT	\N	PRESENT	0
396718	393390	19693L	PARTICIPANT	\N	PRESENT	0
396719	393390	14053L	PARTICIPANT	\N	PRESENT	0
396720	393390	11103C	PARTICIPANT	\N	PRESENT	0
396721	393390	19737F	PARTICIPANT	\N	PRESENT	0
396722	393390	14028W	PARTICIPANT	\N	PRESENT	0
396723	393390	19629C	PARTICIPANT	\N	PRESENT	0
396724	393390	14235Q	PARTICIPANT	\N	PRESENT	0
396791	393390	11064N	PARTICIPANT	\N	PRESENT	0
396792	393390	08056B	PARTICIPANT	\N	PRESENT	0
396793	395720	17583W	PARTICIPANT	\N	PRESENT	0
396794	395720	19515S	PARTICIPANT	\N	PRESENT	0
396795	395720	11077T	PARTICIPANT	\N	PRESENT	0
396796	395720	19782L	PARTICIPANT	\N	PRESENT	0
396797	395720	19549D	PARTICIPANT	\N	PRESENT	0
396798	395720	02002K	PARTICIPANT	\N	PRESENT	0
396799	395720	11099A	PARTICIPANT	\N	PRESENT	0
396800	395720	80027E	PARTICIPANT	\N	PRESENT	0
396801	395720	08068F	PARTICIPANT	\N	PRESENT	0
396802	395720	19347U	PARTICIPANT	\N	PRESENT	0
396803	395720	14157T	PARTICIPANT	\N	PRESENT	0
396804	395720	19681G	PARTICIPANT	\N	PRESENT	0
396805	395720	11065P	PARTICIPANT	\N	PRESENT	0
396806	395720	19525U	PARTICIPANT	\N	PRESENT	0
396807	395720	14187A	PARTICIPANT	\N	PRESENT	0
396808	395720	11090Q	PRESIDENT	0	PRESENT	0
396809	395720	08055A	PARTICIPANT	\N	PRESENT	0
396810	395720	14207L	PARTICIPANT	\N	PRESENT	0
396811	395720	19383Y	PARTICIPANT	\N	PRESENT	0
396812	395720	19701S	PARTICIPANT	\N	PRESENT	0
396813	395720	14357A	PARTICIPANT	\N	PRESENT	0
396814	395720	19413M	PARTICIPANT	\N	PRESENT	0
396815	395720	14219Q	PARTICIPANT	\N	PRESENT	0
396816	395720	14221J	PARTICIPANT	\N	PRESENT	0
396817	395720	19599P	PARTICIPANT	\N	PRESENT	0
396818	395720	19637C	PARTICIPANT	\N	PRESENT	0
396819	395720	18083K	PARTICIPANT	\N	PRESENT	0
396820	395720	14237S	PARTICIPANT	\N	PRESENT	0
396821	395720	05012A	PARTICIPANT	\N	PRESENT	0
396822	395720	14051J	PARTICIPANT	\N	PRESENT	0
396823	395720	08015R	PARTICIPANT	\N	PRESENT	0
396824	395720	19503N	PARTICIPANT	\N	PRESENT	0
396825	395720	19369B	PARTICIPANT	\N	PRESENT	0
396826	395720	08024S	PARTICIPANT	\N	PRESENT	0
396827	395720	19563B	PARTICIPANT	\N	PRESENT	0
396828	395720	14265W	PARTICIPANT	\N	PRESENT	0
396829	395720	17637T	PARTICIPANT	\N	PRESENT	0
396830	395720	14329V	PARTICIPANT	\N	PRESENT	0
396831	395720	14031R	PARTICIPANT	\N	PRESENT	0
396832	395720	19713W	PARTICIPANT	\N	PRESENT	0
396833	395720	08038Y	PARTICIPANT	\N	PRESENT	0
396834	395720	14033T	PARTICIPANT	\N	PRESENT	0
396835	395720	14169X	PARTICIPANT	\N	PRESENT	0
396836	395720	15447F	PARTICIPANT	\N	PRESENT	0
396837	395720	14205J	PARTICIPANT	\N	PRESENT	0
396838	395720	04088S	PARTICIPANT	\N	PRESENT	0
396839	395720	14115H	PARTICIPANT	\N	PRESENT	0
396840	395720	19507S	PARTICIPANT	\N	PRESENT	0
396841	395720	19733B	PARTICIPANT	\N	PRESENT	0
396842	395720	19737F	PARTICIPANT	\N	PRESENT	0
396843	395720	19739H	PARTICIPANT	\N	PRESENT	0
396844	395720	04097T	PARTICIPANT	\N	PRESENT	0
396845	395720	19745F	PARTICIPANT	\N	PRESENT	0
396846	395720	19747H	PARTICIPANT	\N	PRESENT	0
396858	393390	01034P	PARTICIPANT	\N	PRESENT	0
396859	393390	11053K	PARTICIPANT	\N	PRESENT	0
396860	396852	17583W	PARTICIPANT	\N	PRESENT	0
396861	396852	19768N	PARTICIPANT	\N	PRESENT	0
396862	396852	19515S	PARTICIPANT	\N	PRESENT	0
396863	396852	19782L	PARTICIPANT	\N	PRESENT	0
396864	396852	11077T	PARTICIPANT	\N	PRESENT	0
396865	396852	19549D	PARTICIPANT	\N	PRESENT	0
396866	396852	19441R	PARTICIPANT	\N	PRESENT	0
396867	396852	02002K	PARTICIPANT	\N	PRESENT	0
396868	396852	80027E	PARTICIPANT	\N	PRESENT	0
396869	396852	11099A	PARTICIPANT	\N	PRESENT	0
396870	396852	08068F	PARTICIPANT	\N	PRESENT	0
396871	396852	19347U	PARTICIPANT	\N	PRESENT	0
396872	396852	14157T	PARTICIPANT	\N	PRESENT	0
396873	396852	19681G	PARTICIPANT	\N	PRESENT	0
396874	396852	11065P	PARTICIPANT	\N	PRESENT	0
396875	396852	19525U	PARTICIPANT	\N	PRESENT	0
396876	396852	14187A	PARTICIPANT	\N	PRESENT	0
396877	396852	11090Q	PARTICIPANT	\N	PRESENT	0
396878	396852	08055A	PARTICIPANT	\N	PRESENT	0
396879	396852	14207L	PARTICIPANT	\N	PRESENT	0
396880	396852	19383Y	PARTICIPANT	\N	PRESENT	0
396881	396852	19701S	PARTICIPANT	\N	PRESENT	0
396882	396852	14357A	PARTICIPANT	\N	PRESENT	0
396883	396852	19387D	PARTICIPANT	\N	PRESENT	0
396884	396852	19413M	PARTICIPANT	\N	PRESENT	0
396885	396852	14219Q	PARTICIPANT	\N	PRESENT	0
396886	396852	14221J	PARTICIPANT	\N	PRESENT	0
396887	396852	19599P	PARTICIPANT	\N	PRESENT	0
396888	396852	19631V	PARTICIPANT	\N	PRESENT	0
396889	396852	19637C	PARTICIPANT	\N	PRESENT	0
396890	396852	18083K	PARTICIPANT	\N	PRESENT	0
396891	396852	14237S	PARTICIPANT	\N	PRESENT	0
396892	396852	05012A	PARTICIPANT	\N	PRESENT	0
396893	396852	14051J	PARTICIPANT	\N	PRESENT	0
396894	396852	08015R	PARTICIPANT	\N	PRESENT	0
396895	396852	19503N	PARTICIPANT	\N	PRESENT	0
396896	396852	14197C	PARTICIPANT	\N	PRESENT	0
396897	396852	19369B	PARTICIPANT	\N	PRESENT	0
396898	396852	08024S	PARTICIPANT	\N	PRESENT	0
396899	396852	19563B	PARTICIPANT	\N	PRESENT	0
396900	396852	17637T	PARTICIPANT	\N	PRESENT	0
396901	396852	14265W	PARTICIPANT	\N	PRESENT	0
396902	396852	14329V	PARTICIPANT	\N	PRESENT	0
396903	396852	14031R	PRESIDENT	0	PRESENT	0
396904	396852	19713W	PARTICIPANT	\N	PRESENT	0
396905	396852	08038Y	PARTICIPANT	\N	PRESENT	0
396906	396852	14033T	PARTICIPANT	\N	PRESENT	0
396907	396852	19269X	PARTICIPANT	\N	PRESENT	0
396908	396852	14169X	PARTICIPANT	\N	PRESENT	0
396909	396852	15447F	PARTICIPANT	\N	PRESENT	0
396910	396852	14205J	PARTICIPANT	\N	PRESENT	0
396911	396852	04088S	PARTICIPANT	\N	PRESENT	0
396912	396852	11056N	PARTICIPANT	\N	PRESENT	0
396913	396852	14115H	PARTICIPANT	\N	PRESENT	0
396914	396852	19733B	PARTICIPANT	\N	PRESENT	0
396915	396852	19507S	PARTICIPANT	\N	PRESENT	0
396916	396852	19737F	PARTICIPANT	\N	PRESENT	0
396917	396852	04097T	PARTICIPANT	\N	PRESENT	0
396918	396852	19739H	PARTICIPANT	\N	PRESENT	0
396919	396852	19745F	PARTICIPANT	\N	PRESENT	0
396920	396852	19747H	PARTICIPANT	\N	PRESENT	0
396921	396852	19619A	PARTICIPANT	\N	PRESENT	0
396922	396852	08060W	PARTICIPANT	\N	EXCUSE	0
396923	395720	19768N	PARTICIPANT	\N	PRESENT	0
396924	395720	19441R	PARTICIPANT	\N	PRESENT	0
396925	395720	19387D	PARTICIPANT	\N	PRESENT	0
396926	395720	19631V	PARTICIPANT	\N	PRESENT	0
396927	395720	14197C	PARTICIPANT	\N	PRESENT	0
396928	395720	19269X	PARTICIPANT	\N	PRESENT	0
396929	395720	11056N	PARTICIPANT	\N	PRESENT	0
396930	395720	19619A	PARTICIPANT	\N	PRESENT	0
396931	395720	80013X	PARTICIPANT	\N	EXCUSE	0
396932	395720	19295A	PARTICIPANT	\N	EXCUSE	0
396933	395720	08028W	PARTICIPANT	\N	EXCUSE	0
396934	395720	11081P	PARTICIPANT	\N	EXCUSE	0
396935	395720	17589D	PARTICIPANT	\N	EXCUSE	0
396940	393390	19569H	PARTICIPANT	\N	PRESENT	0
396941	393390	04045F	PARTICIPANT	\N	PRESENT	0
396949	395720	19467C	PARTICIPANT	\N	PRESENT	0
396651	395202	11103C	PRESIDENT	0	PRESENT	0
396652	395202	14087W	PARTICIPANT	\N	PRESENT	0
396656	395202	08052W	PARTICIPANT	\N	PRESENT	0
396662	395202	14281W	PARTICIPANT	\N	PRESENT	0
396663	395202	11067R	PARTICIPANT	\N	PRESENT	0
396665	395202	19727D	PARTICIPANT	\N	PRESENT	0
396667	395202	14119M	PARTICIPANT	\N	PRESENT	0
396668	395202	01034P	PARTICIPANT	\N	PRESENT	0
396689	395202	10006L	PARTICIPANT	\N	PRESENT	0
396708	395202	11097X	PARTICIPANT	\N	EXCUSE	0
397652	396128	14239U	PARTICIPANT	\N	PRESENT	0
397653	393776	14239U	PARTICIPANT	\N	PRESENT	0
397654	393575	14239U	PARTICIPANT	\N	PRESENT	0
401854	393617	11099A	PARTICIPANT	\N	PRESENT	0
401855	393617	08031R	PARTICIPANT	\N	PRESENT	0
401856	393617	08048B	PARTICIPANT	\N	PRESENT	0
401857	393617	01028R	PARTICIPANT	\N	PRESENT	0
401858	393617	19713W	PARTICIPANT	\N	PRESENT	0
401859	393617	14327T	PARTICIPANT	\N	PRESENT	0
401860	393617	10015M	PARTICIPANT	\N	PRESENT	0
401861	393617	19413M	PARTICIPANT	\N	PRESENT	0
401862	393617	08035V	PARTICIPANT	\N	PRESENT	0
401863	393617	14109K	PARTICIPANT	\N	PRESENT	0
401864	393617	19479G	PARTICIPANT	\N	PRESENT	0
401865	393617	14073Q	PARTICIPANT	\N	PRESENT	0
401866	393617	19719D	PARTICIPANT	\N	PRESENT	0
401867	393617	19758L	PARTICIPANT	\N	PRESENT	0
401871	393617	19489J	PARTICIPANT	\N	PRESENT	0
401874	393617	01062T	PARTICIPANT	\N	PRESENT	0
401899	393617	14042U	PARTICIPANT	\N	PRESENT	0
401902	393617	14147R	PARTICIPANT	\N	PRESENT	0
401903	393617	14038Y	PARTICIPANT	\N	PRESENT	0
401904	393617	11077T	PARTICIPANT	\N	PRESENT	0
401905	393617	11012A	PARTICIPANT	\N	PRESENT	0
401907	393617	14329V	PARTICIPANT	\N	PRESENT	0
401908	393617	19675J	PARTICIPANT	\N	PRESENT	0
401909	393617	04044E	PARTICIPANT	\N	PRESENT	0
401910	393617	14257W	PARTICIPANT	\N	PRESENT	0
401911	393617	11027H	PARTICIPANT	\N	PRESENT	0
401912	393617	19693L	PARTICIPANT	\N	PRESENT	0
401913	393617	19621T	PARTICIPANT	\N	PRESENT	0
401914	393617	04040A	PARTICIPANT	\N	PRESENT	0
401915	393617	14079W	PARTICIPANT	\N	PRESENT	0
401916	393617	19794Q	PARTICIPANT	\N	PRESENT	0
401917	393617	14097Y	PARTICIPANT	\N	PRESENT	0
401918	393617	19549D	PARTICIPANT	\N	PRESENT	0
401922	393617	04097T	PARTICIPANT	\N	PRESENT	0
401923	393617	11053K	PARTICIPANT	\N	PRESENT	0
401924	393617	14083S	PARTICIPANT	\N	PRESENT	0
401925	393617	08044W	PARTICIPANT	\N	PRESENT	0
401926	393617	88008L	PARTICIPANT	\N	PRESENT	0
402018	393618	11090Q	PARTICIPANT	\N	PRESENT	0
402019	393618	11033F	PARTICIPANT	\N	PRESENT	0
402020	393618	80013X	PARTICIPANT	\N	PRESENT	0
402021	393618	19695N	PARTICIPANT	\N	PRESENT	0
402022	393618	11065P	PARTICIPANT	\N	PRESENT	0
402023	393618	17589D	PARTICIPANT	\N	PRESENT	0
402024	393618	14257W	PARTICIPANT	\N	PRESENT	0
402025	393618	19782L	PARTICIPANT	\N	PRESENT	0
402026	393618	14033T	PARTICIPANT	\N	PRESENT	0
402027	393618	19794Q	PARTICIPANT	\N	PRESENT	0
402028	393618	18083K	PARTICIPANT	\N	PRESENT	0
402029	393618	19768N	PARTICIPANT	\N	PRESENT	0
402030	393618	14265W	PARTICIPANT	\N	PRESENT	0
402031	393618	14231L	PARTICIPANT	\N	PRESENT	0
402032	393618	19319Q	PARTICIPANT	\N	PRESENT	0
402033	393618	14215L	PARTICIPANT	\N	PRESENT	0
402034	393618	11066Q	PARTICIPANT	\N	PRESENT	0
402035	393618	14053L	PARTICIPANT	\N	PRESENT	0
402036	393618	04085P	PARTICIPANT	\N	PRESENT	0
402037	393618	14147R	PARTICIPANT	\N	PRESENT	0
402038	393618	14038Y	PARTICIPANT	\N	PRESENT	0
402039	393618	08035V	PARTICIPANT	\N	PRESENT	0
402040	393618	19503N	PARTICIPANT	\N	PRESENT	0
402041	393618	19269X	PARTICIPANT	\N	PRESENT	0
402042	393618	19515S	PARTICIPANT	\N	PRESENT	0
402043	393618	19443T	PARTICIPANT	\N	PRESENT	0
402044	393618	19399H	PARTICIPANT	\N	PRESENT	0
402045	393618	19335Q	PARTICIPANT	\N	PRESENT	0
402046	393618	08044W	PARTICIPANT	\N	PRESENT	0
402047	393618	19758L	PARTICIPANT	\N	PRESENT	0
402048	393618	05012A	PARTICIPANT	\N	PRESENT	0
402049	393618	19533U	PARTICIPANT	\N	PRESENT	0
402050	393618	14357A	PARTICIPANT	\N	PRESENT	0
402051	393618	19387D	PARTICIPANT	\N	PRESENT	0
402052	393618	19369B	PARTICIPANT	\N	PRESENT	0
402053	393618	19798U	PARTICIPANT	\N	PRESENT	0
402054	393618	19347U	PARTICIPANT	\N	PRESENT	0
402055	393618	19711U	PARTICIPANT	\N	PRESENT	0
402056	393618	04088S	PARTICIPANT	\N	PRESENT	0
402057	393618	14217N	PARTICIPANT	\N	PRESENT	0
402058	393618	11048N	PARTICIPANT	\N	PRESENT	0
402059	393618	14331P	PARTICIPANT	\N	PRESENT	0
402060	393618	14135M	PARTICIPANT	\N	PRESENT	0
402061	393618	19621T	PARTICIPANT	\N	PRESENT	0
402062	393618	14187A	PARTICIPANT	\N	PRESENT	0
402063	393618	19741B	PARTICIPANT	\N	PRESENT	0
402064	393618	19441R	PARTICIPANT	\N	PRESENT	0
402065	393618	19563B	PARTICIPANT	\N	PRESENT	0
402066	393618	04033B	PARTICIPANT	\N	PRESENT	0
402067	393618	14219Q	PARTICIPANT	\N	PRESENT	0
402068	393618	14073Q	PARTICIPANT	\N	PRESENT	0
402069	393618	19447X	PARTICIPANT	\N	PRESENT	0
402070	393618	11077T	PARTICIPANT	\N	PRESENT	0
402071	393618	08020N	PARTICIPANT	\N	PRESENT	0
402072	393618	17637T	PARTICIPANT	\N	PRESENT	0
402073	393618	19747H	PARTICIPANT	\N	PRESENT	0
402074	393618	14030Q	PARTICIPANT	\N	PRESENT	0
402075	393618	11056N	PARTICIPANT	\N	PRESENT	0
402076	393618	19737F	PARTICIPANT	\N	PRESENT	0
402077	393618	04049K	PARTICIPANT	\N	PRESENT	0
402078	393618	11097X	PARTICIPANT	\N	PRESENT	0
402079	393618	19762G	PARTICIPANT	\N	PRESENT	0
402080	393618	14115H	PARTICIPANT	\N	PRESENT	0
402081	393618	19333N	PARTICIPANT	\N	PRESENT	0
402082	393618	14197C	PARTICIPANT	\N	PRESENT	0
402083	393618	19467C	PARTICIPANT	\N	PRESENT	0
402084	393618	14083S	PARTICIPANT	\N	PRESENT	0
402085	393618	10006L	PARTICIPANT	\N	PRESENT	0
402086	393618	19521Q	PARTICIPANT	\N	PRESENT	0
402087	393618	14157T	PARTICIPANT	\N	PRESENT	0
402088	393618	14031R	PARTICIPANT	\N	PRESENT	0
402089	393618	19349W	PARTICIPANT	\N	PRESENT	0
402090	393618	14069U	PARTICIPANT	\N	PRESENT	0
402091	393618	19551W	PARTICIPANT	\N	PRESENT	0
402092	393618	19413M	PARTICIPANT	\N	PRESENT	0
402093	393618	08068F	PARTICIPANT	\N	PRESENT	0
409991	405277	11065P	PARTICIPANT	\N	PRESENT	0
409993	408325	99004R	PRESIDENT	0	PRESENT	0
409994	405277	19551W	PARTICIPANT	\N	PRESENT	0
409995	405277	19711U	PARTICIPANT	\N	PRESENT	0
412777	405447	14331P	PARTICIPANT	\N	PRESENT	0
412778	405447	14225N	PARTICIPANT	\N	EXCUSE	0
402016	393618	04044E	PARTICIPANT	\N	PRESENT	0
402017	393618	19733B	PARTICIPANT	\N	PRESENT	0
412779	405447	14135M	PARTICIPANT	\N	EXCUSE	0
412780	405447	19329S	PARTICIPANT	\N	EXCUSE	0
412781	405447	19583F	PARTICIPANT	\N	EXCUSE	0
412782	405447	14097Y	PARTICIPANT	\N	EXCUSE	0
420877	407833	19531S	PARTICIPANT	\N	PRESENT	0
420873	407833	14105F	PARTICIPANT	\N	PRESENT	0
420874	407833	14123H	PARTICIPANT	\N	PRESENT	0
420875	407833	11026G	PARTICIPANT	\N	PRESENT	0
420876	407833	14041T	PARTICIPANT	\N	PRESENT	0
420878	407833	08045X	PARTICIPANT	\N	PRESENT	0
420879	407833	19687N	PARTICIPANT	\N	PRESENT	0
420880	407833	11031D	PARTICIPANT	\N	PRESENT	0
420881	407833	11033F	PARTICIPANT	\N	PRESENT	0
420882	407833	19631V	PARTICIPANT	\N	PRESENT	0
420883	407833	14097Y	PARTICIPANT	\N	PRESENT	0
420884	407833	98022P	PARTICIPANT	\N	PRESENT	0
420885	407833	98050T	PARTICIPANT	\N	PRESENT	0
420886	407833	14042U	PARTICIPANT	\N	PRESENT	0
420887	407833	19335Q	PARTICIPANT	\N	PRESENT	0
420888	419131	08034U	PARTICIPANT	\N	EXCUSE	0
420889	407833	08018U	PARTICIPANT	\N	PRESENT	0
420890	407833	14249W	PARTICIPANT	\N	PRESENT	0
420891	407833	19689Q	PARTICIPANT	\N	PRESENT	0
420892	407833	19647E	PARTICIPANT	\N	PRESENT	0
420893	407833	19697Q	PARTICIPANT	\N	PRESENT	0
420894	407833	19735D	PARTICIPANT	\N	PRESENT	0
420895	407833	08010L	PARTICIPANT	\N	PRESENT	0
420896	407833	87003B	PARTICIPANT	\N	PRESENT	0
420897	407833	08015R	PARTICIPANT	\N	PRESENT	0
420898	407833	11012A	PARTICIPANT	\N	PRESENT	0
420899	407833	19507S	PARTICIPANT	\N	PRESENT	0
420900	407833	04088S	PARTICIPANT	\N	PRESENT	0
420901	407833	19525U	PARTICIPANT	\N	PRESENT	0
420902	407833	14159V	PARTICIPANT	\N	PRESENT	0
405032	404987	18083K	PARTICIPANT	\N	PRESENT	0
405033	404987	19387D	PARTICIPANT	\N	PRESENT	0
405135	405120	14187A	PARTICIPANT	\N	PRESENT	0
405137	405136	14187A	PARTICIPANT	\N	PRESENT	0
405155	405154	19543W	PARTICIPANT	\N	PRESENT	0
405156	405154	14259Y	PARTICIPANT	\N	PRESENT	0
405157	405154	19719D	PARTICIPANT	\N	PRESENT	0
405158	405154	14231L	PARTICIPANT	\N	PRESENT	0
405160	405159	19543W	PARTICIPANT	\N	PRESENT	0
405161	405159	14259Y	PARTICIPANT	\N	PRESENT	0
405162	405159	19719D	PARTICIPANT	\N	PRESENT	0
405163	405159	14231L	PARTICIPANT	\N	PRESENT	0
405165	405164	14259Y	PARTICIPANT	\N	PRESENT	0
405166	405164	14231L	PARTICIPANT	\N	PRESENT	0
405210	405059	14281W	PRESIDENT	0	PRESENT	0
405211	405059	14331P	PARTICIPANT	\N	PRESENT	0
405212	405059	14031R	PARTICIPANT	\N	PRESENT	0
405213	405059	08043V	PARTICIPANT	\N	PRESENT	0
405214	405059	11066Q	PARTICIPANT	\N	PRESENT	0
405215	405059	19729F	PARTICIPANT	\N	EXCUSE	0
405216	405059	14275Y	PARTICIPANT	\N	EXCUSE	0
405217	405059	14235Q	PARTICIPANT	\N	EXCUSE	0
405218	405059	04044E	PARTICIPANT	\N	EXCUSE	0
405219	405059	19681G	PARTICIPANT	\N	EXCUSE	0
405220	405059	98029W	PARTICIPANT	\N	EXCUSE	0
405221	405059	14030Q	PARTICIPANT	\N	EXCUSE	0
405228	405111	14205J	PARTICIPANT	\N	PRESENT	0
405229	405111	18083K	PARTICIPANT	\N	PRESENT	0
405230	405111	14237S	PARTICIPANT	\N	PRESENT	0
405231	405111	19701S	PARTICIPANT	\N	PRESENT	0
405232	405111	19794Q	PARTICIPANT	\N	PRESENT	0
405233	405111	08009T	PRESIDENT	0	PRESENT	0
405234	405111	14169X	PARTICIPANT	\N	PRESENT	0
405235	405111	19333N	PARTICIPANT	\N	EXCUSE	0
405236	405111	05012A	PARTICIPANT	\N	EXCUSE	0
405237	405111	14051J	PARTICIPANT	\N	EXCUSE	0
405238	405111	19681G	PARTICIPANT	\N	EXCUSE	0
405239	405111	14031R	PARTICIPANT	\N	PRESENT	0
405240	405111	19549D	PARTICIPANT	\N	PRESENT	0
405241	405111	19387D	PARTICIPANT	\N	PRESENT	0
405242	405111	14219Q	PARTICIPANT	\N	PRESENT	0
405243	405111	19637C	PARTICIPANT	\N	PRESENT	0
405244	405111	14093U	PARTICIPANT	\N	PRESENT	0
405245	405111	08060W	PARTICIPANT	\N	PRESENT	0
405246	405111	19733B	PARTICIPANT	\N	PRESENT	0
405247	405111	19347U	PARTICIPANT	\N	PRESENT	0
405248	405111	19503N	PARTICIPANT	\N	PRESENT	0
405249	405111	08024S	PARTICIPANT	\N	PRESENT	0
405250	405111	19599P	PARTICIPANT	\N	PRESENT	0
405251	405111	02002K	PARTICIPANT	\N	PRESENT	0
405252	405111	17583W	PARTICIPANT	\N	PRESENT	0
405253	405111	19713W	PARTICIPANT	\N	PRESENT	0
405254	405111	19551W	PARTICIPANT	\N	PRESENT	0
405255	405111	11065P	PARTICIPANT	\N	PRESENT	0
405256	404924	19631V	PARTICIPANT	\N	PRESENT	0
405257	404924	19747H	PARTICIPANT	\N	PRESENT	0
405258	404924	08068F	PARTICIPANT	\N	PRESENT	0
405259	404924	08028W	PARTICIPANT	\N	PRESENT	0
405260	404924	08038Y	PARTICIPANT	\N	PRESENT	0
405261	404924	14197C	PARTICIPANT	\N	PRESENT	0
405262	404924	01025N	PARTICIPANT	\N	PRESENT	0
405263	404924	19695N	PARTICIPANT	\N	PRESENT	0
405264	404924	14081Q	PARTICIPANT	\N	PRESENT	0
405265	404924	11099A	PARTICIPANT	\N	PRESENT	0
405266	404924	04049K	PARTICIPANT	\N	PRESENT	0
405267	404924	08015R	PARTICIPANT	\N	PRESENT	0
405268	404924	14205J	PARTICIPANT	\N	PRESENT	0
405269	404924	19563B	PARTICIPANT	\N	PRESENT	0
405270	404924	19369B	PARTICIPANT	\N	PRESENT	0
405271	404924	14265W	PARTICIPANT	\N	PRESENT	0
405272	404924	19705W	PARTICIPANT	\N	PRESENT	0
405273	404924	19619A	PARTICIPANT	\N	PRESENT	0
405274	404924	19413M	PARTICIPANT	\N	PRESENT	0
405275	404924	11090Q	PRESIDENT	0	PRESENT	0
405279	404924	11081P	PARTICIPANT	\N	EXCUSE	0
405280	404924	19768N	PARTICIPANT	\N	EXCUSE	0
405281	404924	01043Q	PARTICIPANT	\N	EXCUSE	0
405282	404924	14207L	PARTICIPANT	\N	EXCUSE	0
405283	404924	17589D	PARTICIPANT	\N	EXCUSE	0
405284	404924	19511N	PARTICIPANT	\N	EXCUSE	0
405285	404924	19782L	PARTICIPANT	\N	EXCUSE	0
405286	404924	80013X	PARTICIPANT	\N	EXCUSE	0
405328	404767	19347U	PARTICIPANT	\N	PRESENT	0
405329	404767	19591F	PARTICIPANT	\N	PRESENT	0
405330	404767	19689Q	PARTICIPANT	\N	PRESENT	0
405331	404767	19413M	PARTICIPANT	\N	PRESENT	0
405332	404767	14227Q	PARTICIPANT	\N	PRESENT	0
407477	405277	19399H	PARTICIPANT	\N	PRESENT	0
407478	405277	19737F	PARTICIPANT	\N	EXCUSE	0
407479	405277	11097X	PARTICIPANT	\N	PRESENT	0
407480	405277	14147R	PARTICIPANT	\N	PRESENT	0
407481	405277	19479G	PARTICIPANT	\N	PRESENT	0
407482	405277	19629C	PARTICIPANT	\N	PRESENT	0
407718	405277	11066Q	PARTICIPANT	\N	PRESENT	0
407719	405277	19667J	PARTICIPANT	\N	EXCUSE	0
407847	405277	19467C	PARTICIPANT	\N	PRESENT	0
407848	405277	19713W	PARTICIPANT	\N	EXCUSE	0
409071	408829	19329S	PARTICIPANT	\N	PRESENT	0
409072	408829	08035V	PARTICIPANT	\N	PRESENT	0
409073	408829	14123H	PARTICIPANT	\N	PRESENT	0
409074	408829	19533U	PARTICIPANT	\N	PRESENT	0
409075	408829	07033P	PARTICIPANT	\N	PRESENT	0
409076	408829	19735D	PARTICIPANT	\N	PRESENT	0
409077	408829	08031R	PARTICIPANT	\N	PRESENT	0
409079	409078	14123H	PARTICIPANT	\N	PRESENT	0
409080	409078	19593H	PARTICIPANT	\N	PRESENT	0
409081	409078	19533U	PARTICIPANT	\N	PRESENT	0
409082	409078	14229S	PARTICIPANT	\N	PRESENT	0
409083	405449	14195A	PARTICIPANT	\N	EXCUSE	0
410605	410604	19747H	PARTICIPANT	\N	PRESENT	0
410606	410604	14197C	PARTICIPANT	\N	PRESENT	0
410607	410604	04049K	PARTICIPANT	\N	PRESENT	0
410608	410604	19441R	PARTICIPANT	\N	PRESENT	0
410609	410604	19369B	PARTICIPANT	\N	PRESENT	0
410610	410604	14265W	PARTICIPANT	\N	PRESENT	0
410611	410604	19347U	PARTICIPANT	\N	PRESENT	0
410630	410629	04044E	PARTICIPANT	\N	PRESENT	0
410677	410675	04044E	PARTICIPANT	\N	PRESENT	0
410693	410691	04044E	PARTICIPANT	\N	PRESENT	0
410902	410887	19719D	PARTICIPANT	\N	PRESENT	0
410903	410887	14147R	PARTICIPANT	\N	PRESENT	0
413302	413301	05008E	PRESIDENT	0	PRESENT	0
413303	413301	04047H	PARTICIPANT	\N	PRESENT	0
413304	413301	14179A	PARTICIPANT	\N	PRESENT	0
413305	413301	14065Q	PARTICIPANT	\N	PRESENT	0
413306	413301	19447X	PARTICIPANT	\N	PRESENT	0
413307	413301	14215L	PARTICIPANT	\N	PRESENT	0
413308	413301	19489J	PARTICIPANT	\N	PRESENT	0
413309	413301	14053L	PARTICIPANT	\N	PRESENT	0
413310	413301	19719D	PARTICIPANT	\N	PRESENT	0
413311	413301	19543W	PARTICIPANT	\N	PRESENT	0
413312	413301	14151M	PARTICIPANT	\N	PRESENT	0
413313	413301	14231L	PARTICIPANT	\N	PRESENT	0
413314	413301	14259Y	PARTICIPANT	\N	PRESENT	0
413315	413301	14001X	PARTICIPANT	\N	PRESENT	0
413316	413301	14147R	PARTICIPANT	\N	PRESENT	0
413318	413301	01028R	PARTICIPANT	\N	PRESENT	0
413319	413301	19762G	PARTICIPANT	\N	PRESENT	0
413519	408325	19711U	PARTICIPANT	\N	PRESENT	0
413530	408325	11097X	PARTICIPANT	\N	PRESENT	0
413687	408325	19479G	PARTICIPANT	\N	PRESENT	0
413689	408325	19737F	PARTICIPANT	\N	EXCUSE	0
413692	408325	11065P	PARTICIPANT	\N	EXCUSE	0
414433	414432	14073Q	PARTICIPANT	\N	PRESENT	0
414434	414432	14063N	PARTICIPANT	\N	PRESENT	0
414435	414432	19758L	PARTICIPANT	\N	PRESENT	0
414436	414432	87003B	PARTICIPANT	\N	PRESENT	0
414437	414432	14241N	PARTICIPANT	\N	PRESENT	0
414439	414438	11104D	PARTICIPANT	\N	PRESENT	0
414440	414438	14241N	PARTICIPANT	\N	PRESENT	0
415522	406854	19749K	PARTICIPANT	\N	PRESENT	0
415524	406854	08019V	PARTICIPANT	\N	PRESENT	0
415525	406854	14083S	PARTICIPANT	\N	PRESENT	0
415526	406854	19521Q	PARTICIPANT	\N	PRESENT	0
415527	406854	14255U	PARTICIPANT	\N	PRESENT	0
415528	406854	11085T	PARTICIPANT	\N	PRESENT	0
415529	406854	04040A	PARTICIPANT	\N	PRESENT	0
415530	406854	01024M	PARTICIPANT	\N	PRESENT	0
415531	406854	14030Q	PARTICIPANT	\N	PRESENT	0
415532	406854	14327T	PARTICIPANT	\N	PRESENT	0
415533	406854	01043Q	PARTICIPANT	\N	PRESENT	0
415535	406854	19545Y	PARTICIPANT	\N	PRESENT	0
393576	393395	05008E	PARTICIPANT	\N	PRESENT	0
393577	393395	11033F	PARTICIPANT	\N	PRESENT	0
393579	393395	19543W	PARTICIPANT	\N	PRESENT	0
393580	393395	14069U	PARTICIPANT	\N	PRESENT	0
393581	393395	14089Y	PARTICIPANT	\N	PRESENT	0
393582	393395	04047H	PARTICIPANT	\N	PRESENT	0
393583	393395	14053L	PARTICIPANT	\N	PRESENT	0
393584	393395	19253P	PARTICIPANT	\N	PRESENT	0
393585	393395	14259Y	PARTICIPANT	\N	PRESENT	0
393586	393395	04008A	PARTICIPANT	\N	EXCUSE	0
393587	393395	19719D	PARTICIPANT	\N	PRESENT	0
393588	393395	01024M	PARTICIPANT	\N	PRESENT	0
393589	393395	14215L	PARTICIPANT	\N	PRESENT	0
393623	393395	08045X	PARTICIPANT	\N	PRESENT	0
393621	393395	14151M	PARTICIPANT	\N	PRESENT	0
393622	393395	19673G	PARTICIPANT	\N	PRESENT	0
393624	393395	08018U	PARTICIPANT	\N	PRESENT	0
393626	393395	11010L	PARTICIPANT	\N	PRESENT	0
393627	393395	14231L	PARTICIPANT	\N	PRESENT	0
393629	393395	19649G	PARTICIPANT	\N	PRESENT	0
393630	393395	19725B	PARTICIPANT	\N	PRESENT	0
393631	393395	14179A	PARTICIPANT	\N	PRESENT	0
393632	393395	08044W	PARTICIPANT	\N	PRESENT	0
393633	393395	19447X	PARTICIPANT	\N	PRESENT	0
393634	393395	14021P	PARTICIPANT	\N	PRESENT	0
393636	393395	19489J	PARTICIPANT	\N	PRESENT	0
393637	393395	11026G	PARTICIPANT	\N	PRESENT	0
393638	393395	19729F	PARTICIPANT	\N	PRESENT	0
393639	393395	19581D	PARTICIPANT	\N	PRESENT	0
393640	393395	14111D	PARTICIPANT	\N	PRESENT	0
393641	393395	14001X	PARTICIPANT	\N	PRESENT	0
393642	393395	11085T	PARTICIPANT	\N	PRESENT	0
393643	393395	14147R	PARTICIPANT	\N	PRESENT	0
393644	393395	11072N	PARTICIPANT	\N	PRESENT	0
393645	393395	10015M	PARTICIPANT	\N	PRESENT	0
393646	393395	95063L	PARTICIPANT	\N	PRESENT	0
393647	393395	19762G	PARTICIPANT	\N	PRESENT	0
393648	393395	01028R	PARTICIPANT	\N	PRESENT	0
393649	393395	98035U	PARTICIPANT	\N	PRESENT	0
393650	393395	14275Y	PARTICIPANT	\N	PRESENT	0
393651	393395	19675J	PARTICIPANT	\N	PRESENT	0
393652	393395	04044E	PARTICIPANT	\N	PRESENT	0
393653	393395	19585H	PARTICIPANT	\N	PRESENT	0
393745	393744	11048N	PARTICIPANT	\N	PRESENT	0
393746	393744	08048B	PARTICIPANT	\N	EXCUSE	0
393747	393744	04040A	PRESIDENT	0	PRESENT	0
393771	393744	14257W	PARTICIPANT	\N	EXCUSE	0
393817	393816	11074Q	PARTICIPANT	\N	PRESENT	0
393818	393816	08011M	PARTICIPANT	\N	PRESENT	0
393820	393819	11074Q	PARTICIPANT	\N	PRESENT	0
393821	393819	08011M	PARTICIPANT	\N	PRESENT	0
396049	378100	14034U	PARTICIPANT	\N	PRESENT	0
396051	378100	14179A	PARTICIPANT	\N	PRESENT	0
396052	378100	08012N	PARTICIPANT	\N	PRESENT	0
396053	378100	14001X	PARTICIPANT	\N	PRESENT	0
396054	378100	19758L	PARTICIPANT	\N	PRESENT	0
396055	378100	14021P	PARTICIPANT	\N	PRESENT	0
396056	378100	19719D	PARTICIPANT	\N	PRESENT	0
396057	378100	19543W	PARTICIPANT	\N	PRESENT	0
396058	378100	11012A	PARTICIPANT	\N	PRESENT	0
396059	378100	19695N	PARTICIPANT	\N	PRESENT	0
396060	378100	11033F	PARTICIPANT	\N	PRESENT	0
396061	378100	11045K	PARTICIPANT	\N	PRESENT	0
396062	378100	19479G	PARTICIPANT	\N	PRESENT	0
396063	378100	08014Q	PARTICIPANT	\N	PRESENT	0
396064	378100	08015R	PARTICIPANT	\N	PRESENT	0
396065	378100	14061L	PARTICIPANT	\N	PRESENT	0
396066	378100	14041T	PARTICIPANT	\N	PRESENT	0
396067	378100	19399H	PARTICIPANT	\N	PRESENT	0
396068	378100	19447X	PARTICIPANT	\N	PRESENT	0
396069	378100	14157T	PARTICIPANT	\N	PRESENT	0
396070	378100	19581D	PARTICIPANT	\N	PRESENT	0
396071	378100	19711U	PARTICIPANT	\N	PRESENT	0
396072	378100	11043H	PARTICIPANT	\N	PRESENT	0
396073	378100	05008E	PARTICIPANT	\N	PRESENT	0
396074	378100	19691J	PARTICIPANT	\N	PRESENT	0
396075	378100	14219Q	PARTICIPANT	\N	PRESENT	0
396076	378100	14215L	PARTICIPANT	\N	PRESENT	0
396077	378100	19687N	PARTICIPANT	\N	PRESENT	0
396078	378100	14217N	PARTICIPANT	\N	PRESENT	0
396080	378100	19573D	PARTICIPANT	\N	PRESENT	0
396081	378100	01028R	PARTICIPANT	\N	PRESENT	0
396082	378100	04085P	PARTICIPANT	\N	PRESENT	0
396083	378100	10015M	PARTICIPANT	\N	PRESENT	0
396084	378100	14083S	PARTICIPANT	\N	PRESENT	0
396085	378100	19713W	PARTICIPANT	\N	PRESENT	0
396086	378100	14135M	PARTICIPANT	\N	PRESENT	0
396116	378100	11048N	PARTICIPANT	\N	PRESENT	0
396117	378100	04035D	PARTICIPANT	\N	PRESENT	0
396118	378100	11067R	PARTICIPANT	\N	PRESENT	0
396119	378100	14071N	PARTICIPANT	\N	PRESENT	0
396120	378100	08031R	PARTICIPANT	\N	PRESENT	0
396121	378100	11031D	PARTICIPANT	\N	PRESENT	0
396122	378100	19611R	PARTICIPANT	\N	PRESENT	0
396132	378100	14030Q	PARTICIPANT	\N	PRESENT	0
396133	378100	80013X	PARTICIPANT	\N	PRESENT	0
396135	378100	14079W	PARTICIPANT	\N	PRESENT	0
396136	378100	14261S	PARTICIPANT	\N	PRESENT	0
396174	378109	04085P	PARTICIPANT	\N	PRESENT	0
396175	378109	14001X	PARTICIPANT	\N	PRESENT	0
396176	378109	11045K	PARTICIPANT	\N	PRESENT	0
396177	378109	11012A	PARTICIPANT	\N	PRESENT	0
396178	378109	14275Y	PARTICIPANT	\N	PRESENT	0
396179	378109	19711U	PARTICIPANT	\N	PRESENT	0
396180	378109	19543W	PARTICIPANT	\N	PRESENT	0
396181	378109	14041T	PARTICIPANT	\N	PRESENT	0
396182	378109	19741B	PARTICIPANT	\N	PRESENT	0
396183	378109	14071N	PARTICIPANT	\N	PRESENT	0
396184	378109	19447X	PARTICIPANT	\N	PRESENT	0
396185	378109	11067R	PARTICIPANT	\N	PRESENT	0
396186	378109	14251Q	PARTICIPANT	\N	PRESENT	0
396187	378109	19593H	PARTICIPANT	\N	PRESENT	0
396188	378109	19611R	PARTICIPANT	\N	PRESENT	0
396189	378109	05008E	PARTICIPANT	\N	PRESENT	0
396190	378109	14061L	PARTICIPANT	\N	PRESENT	0
396192	378109	14157T	PARTICIPANT	\N	PRESENT	0
396193	378109	01028R	PARTICIPANT	\N	PRESENT	0
396203	378109	19657G	PARTICIPANT	\N	PRESENT	0
396204	378109	19399H	PARTICIPANT	\N	PRESENT	0
396205	378109	08010L	PARTICIPANT	\N	PRESENT	0
396206	378109	14215L	PARTICIPANT	\N	PRESENT	0
396207	378109	19581D	PARTICIPANT	\N	PRESENT	0
396168	378109	11070L	PARTICIPANT	\N	PRESENT	0
396173	378109	14179A	PARTICIPANT	\N	PRESENT	0
396208	378109	14083S	PARTICIPANT	\N	PRESENT	0
396217	378109	14261S	PARTICIPANT	\N	PRESENT	0
396218	378109	19691J	PARTICIPANT	\N	PRESENT	0
396226	378109	14159V	PARTICIPANT	\N	PRESENT	0
404708	404707	04044E	PARTICIPANT	\N	PRESENT	0
404709	404707	04057K	PARTICIPANT	\N	PRESENT	0
404710	404707	19565D	PARTICIPANT	\N	PRESENT	0
404711	404707	19709B	PARTICIPANT	\N	PRESENT	0
404712	404707	19503N	PARTICIPANT	\N	PRESENT	0
404713	404707	19515S	PARTICIPANT	\N	PRESENT	0
404714	404707	19575F	PARTICIPANT	\N	PRESENT	0
404715	404707	19747H	PARTICIPANT	\N	PRESENT	0
404716	404707	19533U	PARTICIPANT	\N	PRESENT	0
404717	404707	14051J	PARTICIPANT	\N	PRESENT	0
404719	404718	04044E	PARTICIPANT	\N	PRESENT	0
404720	404718	04057K	PARTICIPANT	\N	PRESENT	0
404721	404718	19503N	PARTICIPANT	\N	PRESENT	0
404722	404718	19747H	PARTICIPANT	\N	PRESENT	0
404723	404718	19533U	PARTICIPANT	\N	PRESENT	0
404724	404718	19749K	PARTICIPANT	\N	PRESENT	0
404726	404725	04044E	PARTICIPANT	\N	PRESENT	0
404727	404725	04057K	PARTICIPANT	\N	PRESENT	0
404728	404725	19503N	PARTICIPANT	\N	PRESENT	0
404730	404729	04044E	PARTICIPANT	\N	PRESENT	0
404731	404729	04057K	PARTICIPANT	\N	PRESENT	0
404732	404729	19503N	PARTICIPANT	\N	PRESENT	0
404734	404733	04044E	PARTICIPANT	\N	PRESENT	0
404735	404733	19503N	PARTICIPANT	\N	PRESENT	0
404736	404733	04057K	PARTICIPANT	\N	PRESENT	0
406947	406861	19515S	PARTICIPANT	\N	PRESENT	0
406948	406861	14207L	PARTICIPANT	\N	PRESENT	0
406949	406861	14038Y	PARTICIPANT	\N	PRESENT	0
406950	406861	19812Y	PARTICIPANT	\N	PRESENT	0
406951	406861	19725B	PARTICIPANT	\N	PRESENT	0
406952	406861	04049K	PARTICIPANT	\N	PRESENT	0
406953	406861	19723Y	PARTICIPANT	\N	PRESENT	0
406954	406861	08015R	PARTICIPANT	\N	PRESENT	0
406955	406861	14109K	PARTICIPANT	\N	PRESENT	0
406956	406861	14257W	PARTICIPANT	\N	PRESENT	0
406957	406861	11097X	PARTICIPANT	\N	PRESENT	0
408966	408953	08009T	PARTICIPANT	\N	PRESENT	0
408969	408953	18083K	PARTICIPANT	\N	PRESENT	0
408970	408953	19525U	PARTICIPANT	\N	PRESENT	0
408971	408953	19637C	PARTICIPANT	\N	PRESENT	0
408972	408953	14221J	PARTICIPANT	\N	PRESENT	0
408973	408953	14157T	PARTICIPANT	\N	PRESENT	0
397009	393392	19715Y	PARTICIPANT	\N	PRESENT	0
397010	393392	04045F	PARTICIPANT	\N	PRESENT	0
397011	393392	19301E	PARTICIPANT	\N	PRESENT	0
397012	393392	14229S	PARTICIPANT	\N	PRESENT	0
397013	393392	14109K	PARTICIPANT	\N	PRESENT	0
397014	393392	11067R	PARTICIPANT	\N	PRESENT	0
397015	393392	14021P	PARTICIPANT	\N	PRESENT	0
397016	393392	11045K	PARTICIPANT	\N	PRESENT	0
397017	393392	19585H	PARTICIPANT	\N	PRESENT	0
397018	393392	04057K	PARTICIPANT	\N	PRESENT	0
397019	393392	14107H	PARTICIPANT	\N	PRESENT	0
397020	393392	19629C	PARTICIPANT	\N	PRESENT	0
397021	393392	11064N	PARTICIPANT	\N	PRESENT	0
397022	393392	14231L	PARTICIPANT	\N	PRESENT	0
397023	393392	14042U	PARTICIPANT	\N	PRESENT	0
397024	393392	97011G	PARTICIPANT	\N	PRESENT	0
397025	393392	19581D	PARTICIPANT	\N	PRESENT	0
397026	393392	19367Y	PARTICIPANT	\N	PRESENT	0
397027	393392	14215L	PARTICIPANT	\N	PRESENT	0
397028	393392	14026U	PARTICIPANT	\N	PRESENT	0
397029	393392	08062Y	PARTICIPANT	\N	PRESENT	0
397030	393392	07029T	PARTICIPANT	\N	PRESENT	0
397031	393392	19447X	PARTICIPANT	\N	PRESENT	0
397032	393392	19399H	PARTICIPANT	\N	PRESENT	0
397033	393392	19573D	PARTICIPANT	\N	PRESENT	0
397034	393392	15447F	PARTICIPANT	\N	PRESENT	0
397035	393392	19643A	PARTICIPANT	\N	PRESENT	0
397036	393392	19673G	PARTICIPANT	\N	PRESENT	0
397037	393392	05008E	PARTICIPANT	\N	PRESENT	0
397038	393392	19649G	PARTICIPANT	\N	PRESENT	0
397039	393392	11097X	PARTICIPANT	\N	PRESENT	0
397040	393392	01028R	PARTICIPANT	\N	PRESENT	0
397041	393392	19758L	PARTICIPANT	\N	PRESENT	0
397042	393392	14331P	PARTICIPANT	\N	PRESENT	0
397043	393392	19798U	PARTICIPANT	\N	PRESENT	0
397007	393392	04044E	PARTICIPANT	\N	PRESENT	0
397008	393392	11033F	PARTICIPANT	\N	PRESENT	0
397044	393392	11103C	PARTICIPANT	\N	PRESENT	0
397045	393392	14281W	PARTICIPANT	\N	PRESENT	0
397046	396852	19467C	PARTICIPANT	\N	PRESENT	0
397047	393392	19689Q	PARTICIPANT	\N	PRESENT	0
397048	393392	08010L	PARTICIPANT	\N	PRESENT	0
397049	393392	19703U	PARTICIPANT	\N	PRESENT	0
397050	393392	14179A	PARTICIPANT	\N	PRESENT	0
397051	395720	04049K	PARTICIPANT	\N	PRESENT	0
397052	395720	14257W	PARTICIPANT	\N	PRESENT	0
397053	396852	14257W	PARTICIPANT	\N	PRESENT	0
397054	396852	04049K	PARTICIPANT	\N	PRESENT	0
397182	397181	01048V	PARTICIPANT	\N	PRESENT	0
397183	397181	14257W	PARTICIPANT	\N	PRESENT	0
397184	397181	19679N	PARTICIPANT	\N	PRESENT	0
397265	396219	17637T	PARTICIPANT	\N	EXCUSE	0
397453	389980	14147R	PARTICIPANT	\N	PRESENT	0
397454	389980	11097X	PARTICIPANT	\N	PRESENT	0
397455	389981	14147R	PARTICIPANT	\N	PRESENT	0
397456	389981	11097X	PARTICIPANT	\N	PRESENT	0
397687	396219	19629C	PARTICIPANT	\N	PRESENT	0
397688	396219	04038G	PARTICIPANT	\N	PRESENT	0
397689	396219	02002K	PARTICIPANT	\N	PRESENT	0
397691	396219	19551W	PARTICIPANT	\N	PRESENT	0
397692	396219	19713W	PARTICIPANT	\N	PRESENT	0
402733	402731	19737F	PRESIDENT	0	PRESENT	0
402735	402731	19347U	PARTICIPANT	\N	PRESENT	0
402737	402731	19585H	PARTICIPANT	\N	PRESENT	0
402738	402731	19551W	PARTICIPANT	\N	PRESENT	0
402741	402731	14079W	PARTICIPANT	\N	PRESENT	0
402742	402731	11049P	PARTICIPANT	\N	PRESENT	0
402744	402731	14031R	PARTICIPANT	\N	PRESENT	0
402745	402731	19515S	PARTICIPANT	\N	PRESENT	0
402746	402731	19794Q	PARTICIPANT	\N	PRESENT	0
402747	402731	14081Q	PARTICIPANT	\N	PRESENT	0
402748	402731	19689Q	PARTICIPANT	\N	PRESENT	0
402749	402731	19335Q	PARTICIPANT	\N	PRESENT	0
402750	402731	19349W	PARTICIPANT	\N	PRESENT	0
402773	402731	19251M	PARTICIPANT	\N	EXCUSE	0
402774	402731	19637C	PARTICIPANT	\N	EXCUSE	0
402775	402731	14169X	PARTICIPANT	\N	EXCUSE	0
402776	402731	14087W	PARTICIPANT	\N	EXCUSE	0
402777	402731	14241N	PARTICIPANT	\N	EXCUSE	0
404850	404849	14259Y	PARTICIPANT	\N	PRESENT	0
404851	404849	14231L	PARTICIPANT	\N	PRESENT	0
404852	404849	19543W	PARTICIPANT	\N	PRESENT	0
404853	404849	19719D	PARTICIPANT	\N	PRESENT	0
404854	404849	11085T	PARTICIPANT	\N	PRESENT	0
404856	404855	14259Y	PARTICIPANT	\N	PRESENT	0
404857	404855	14231L	PARTICIPANT	\N	PRESENT	0
404858	404855	19543W	PARTICIPANT	\N	PRESENT	0
405349	405347	19735D	PARTICIPANT	\N	PRESENT	0
405351	405350	14039A	PARTICIPANT	\N	PRESENT	0
405352	405350	19735D	PARTICIPANT	\N	PRESENT	0
405353	405350	14229S	PARTICIPANT	\N	PRESENT	0
405348	405347	14039A	PARTICIPANT	\N	PRESENT	0
405354	405350	19749K	PARTICIPANT	\N	PRESENT	0
405356	405355	19735D	PARTICIPANT	\N	PRESENT	0
405357	405355	14039A	PARTICIPANT	\N	PRESENT	0
405359	405358	14039A	PARTICIPANT	\N	PRESENT	0
405360	405358	19735D	PARTICIPANT	\N	PRESENT	0
405361	405358	19749K	PARTICIPANT	\N	PRESENT	0
405362	405358	14229S	PARTICIPANT	\N	PRESENT	0
405364	405363	14039A	PARTICIPANT	\N	PRESENT	0
405365	405363	19735D	PARTICIPANT	\N	PRESENT	0
405412	405411	14039A	PARTICIPANT	\N	PRESENT	0
405413	405411	19735D	PARTICIPANT	\N	PRESENT	0
406809	406662	19573D	PARTICIPANT	\N	PRESENT	0
406810	406662	14039A	PARTICIPANT	\N	PRESENT	0
406811	406662	92040Q	PARTICIPANT	\N	PRESENT	0
406812	406662	07033P	PARTICIPANT	\N	PRESENT	0
406813	406662	08012N	PARTICIPANT	\N	PRESENT	0
406814	406662	19335Q	PARTICIPANT	\N	PRESENT	0
406815	406662	14249W	PARTICIPANT	\N	PRESENT	0
406816	406662	08039A	PARTICIPANT	\N	PRESENT	0
406817	406662	19593H	PARTICIPANT	\N	PRESENT	0
406818	406662	14059S	PARTICIPANT	\N	PRESENT	0
406819	406662	14061L	PARTICIPANT	\N	PRESENT	0
406820	406662	14073Q	PARTICIPANT	\N	PRESENT	0
406821	406662	19611R	PARTICIPANT	\N	PRESENT	0
406822	406662	08043V	PARTICIPANT	\N	PRESENT	0
406823	406662	19693L	PARTICIPANT	\N	PRESENT	0
406824	406662	19399H	PARTICIPANT	\N	PRESENT	0
406825	406662	87003B	PARTICIPANT	\N	PRESENT	0
406826	406662	14030Q	PARTICIPANT	\N	PRESENT	0
406827	406662	19731Y	PARTICIPANT	\N	PRESENT	0
406828	406662	08020N	PARTICIPANT	\N	PRESENT	0
406829	406662	04059M	PARTICIPANT	\N	PRESENT	0
406830	406662	19735D	PARTICIPANT	\N	PRESENT	0
406831	406662	11109J	PARTICIPANT	\N	PRESENT	0
406832	406662	11083R	PARTICIPANT	\N	PRESENT	0
406833	406662	14063N	PARTICIPANT	\N	PRESENT	0
406834	406662	14109K	PARTICIPANT	\N	PRESENT	0
406835	406662	14123H	PARTICIPANT	\N	PRESENT	0
406836	406662	11104D	PARTICIPANT	\N	PRESENT	0
406837	406662	19749K	PARTICIPANT	\N	PRESENT	0
406838	406662	04018C	PARTICIPANT	\N	PRESENT	0
406839	406662	19758L	PARTICIPANT	\N	PRESENT	0
406840	406662	19621T	PARTICIPANT	\N	PRESENT	0
406841	404870	04047H	PARTICIPANT	\N	PRESENT	0
406939	406938	04070G	PRESIDENT	0	PRESENT	0
406940	406938	19699S	PARTICIPANT	\N	PRESENT	0
406941	406938	08039A	PARTICIPANT	\N	PRESENT	0
406942	406938	04059M	PARTICIPANT	\N	PRESENT	0
406943	406938	11083R	PARTICIPANT	\N	PRESENT	0
406944	406938	08043V	PARTICIPANT	\N	PRESENT	0
406945	406938	19758L	PARTICIPANT	\N	PRESENT	0
406946	406938	19533U	PARTICIPANT	\N	PRESENT	0
407196	402268	04033B	PARTICIPANT	\N	PRESENT	0
407200	402268	08068F	PARTICIPANT	\N	PRESENT	0
407201	402268	11085T	PARTICIPANT	\N	PRESENT	0
407202	402268	14034U	PARTICIPANT	\N	PRESENT	0
407203	402268	19551W	PARTICIPANT	\N	PRESENT	0
407204	402268	14089Y	PARTICIPANT	\N	PRESENT	0
407205	402268	14083S	PARTICIPANT	\N	PRESENT	0
407206	402268	14329V	PARTICIPANT	\N	PRESENT	0
407207	402268	14357A	PARTICIPANT	\N	PRESENT	0
407208	402268	19253P	PARTICIPANT	\N	PRESENT	0
407209	402268	19563B	PARTICIPANT	\N	PRESENT	0
407210	402268	14059S	PARTICIPANT	\N	PRESENT	0
407211	402268	14231L	PARTICIPANT	\N	PRESENT	0
407212	402268	01025N	PARTICIPANT	\N	PRESENT	0
407213	402268	14030Q	PARTICIPANT	\N	PRESENT	0
407214	406928	19701S	PARTICIPANT	\N	PRESENT	0
407215	406928	08009T	PRESIDENT	0	PRESENT	0
407216	406928	14051J	PARTICIPANT	\N	EXCUSE	0
407217	406928	02002K	PARTICIPANT	\N	EXCUSE	0
407218	406928	14038Y	PARTICIPANT	\N	PRESENT	0
396522	393383	11072N	PARTICIPANT	\N	PRESENT	0
396726	393390	19673G	PARTICIPANT	\N	PRESENT	0
396727	393390	14115H	PARTICIPANT	\N	PRESENT	0
396728	393390	19349W	PARTICIPANT	\N	PRESENT	0
396729	393390	19251M	PARTICIPANT	\N	PRESENT	0
396730	393390	11104D	PARTICIPANT	\N	PRESENT	0
396731	393390	08068F	PARTICIPANT	\N	PRESENT	0
396732	393390	19527W	PARTICIPANT	\N	PRESENT	0
396733	393390	19383Y	PARTICIPANT	\N	PRESENT	0
396734	393390	19367Y	PARTICIPANT	\N	PRESENT	0
396735	393390	08039A	PARTICIPANT	\N	PRESENT	0
396736	393390	14267Y	PARTICIPANT	\N	PRESENT	0
396737	393390	14221J	PARTICIPANT	\N	PRESENT	0
396738	393390	19691J	PARTICIPANT	\N	PRESENT	0
396536	396521	14041T	PARTICIPANT	\N	PRESENT	0
396537	396521	19585H	PARTICIPANT	\N	PRESENT	0
396538	396521	04047H	PARTICIPANT	\N	PRESENT	0
396739	393390	04057K	PARTICIPANT	\N	PRESENT	0
396540	396519	19643A	PARTICIPANT	\N	PRESENT	0
396541	396519	04070G	PRESIDENT	0	PRESENT	0
396542	396519	19699S	PARTICIPANT	\N	PRESENT	0
396543	396519	04057K	PARTICIPANT	\N	PRESENT	0
396544	396519	14073Q	PARTICIPANT	\N	PRESENT	0
396545	396519	19611R	PARTICIPANT	\N	PRESENT	0
396546	396519	08043V	PARTICIPANT	\N	PRESENT	0
396547	396519	19693L	PARTICIPANT	\N	PRESENT	0
396548	396519	14229S	PARTICIPANT	\N	PRESENT	0
396549	396519	14030Q	PARTICIPANT	\N	PRESENT	0
396550	396519	14251Q	PARTICIPANT	\N	PRESENT	0
396551	396519	14039A	PARTICIPANT	\N	PRESENT	0
396552	396519	14107H	PARTICIPANT	\N	PRESENT	0
396553	396519	19735D	PARTICIPANT	\N	PRESENT	0
396554	396519	08017T	PARTICIPANT	\N	PRESENT	0
396555	396519	11083R	PARTICIPANT	\N	PRESENT	0
396556	396519	08012N	PARTICIPANT	\N	PRESENT	0
396557	396519	19335Q	PARTICIPANT	\N	PRESENT	0
396558	396519	19758L	PARTICIPANT	\N	PRESENT	0
396559	396521	14053L	PARTICIPANT	\N	PRESENT	0
396560	396521	14089Y	PARTICIPANT	\N	PRESENT	0
396561	396521	14147R	PARTICIPANT	\N	PRESENT	0
396562	396521	14069U	PARTICIPANT	\N	PRESENT	0
396563	396521	19447X	PARTICIPANT	\N	PRESENT	0
396564	396521	05008E	PARTICIPANT	\N	PRESENT	0
396725	393390	14157T	PARTICIPANT	\N	PRESENT	0
396740	393390	04059M	PARTICIPANT	\N	PRESENT	0
396741	393390	08038Y	PARTICIPANT	\N	PRESENT	0
396742	393390	14213J	PARTICIPANT	\N	PRESENT	0
396743	393390	14109K	PARTICIPANT	\N	PRESENT	0
396744	393390	19713W	PARTICIPANT	\N	PRESENT	0
396745	393390	14223L	PARTICIPANT	\N	PRESENT	0
396746	393390	19643A	PARTICIPANT	\N	PRESENT	0
396747	393390	98022P	PARTICIPANT	\N	PRESENT	0
396748	393390	14249W	PARTICIPANT	\N	PRESENT	0
396749	393390	19467C	PARTICIPANT	\N	PRESENT	0
396750	396243	14237S	PARTICIPANT	\N	PRESENT	0
396751	396243	08073C	PARTICIPANT	\N	PRESENT	0
396784	393390	14031R	PARTICIPANT	\N	PRESENT	0
396753	396243	08045X	PARTICIPANT	\N	PRESENT	0
396754	396243	19549D	PARTICIPANT	\N	PRESENT	0
396755	396243	19735D	PARTICIPANT	\N	PRESENT	0
396756	396243	11064N	PARTICIPANT	\N	PRESENT	0
396757	396243	19253P	PARTICIPANT	\N	PRESENT	0
396758	396243	11053K	PRESIDENT	0	PRESENT	0
396759	396243	04097T	PARTICIPANT	\N	PRESENT	0
396760	396243	19349W	PARTICIPANT	\N	PRESENT	0
396761	396243	19671E	PARTICIPANT	\N	PRESENT	0
396762	393390	08062Y	PARTICIPANT	\N	PRESENT	0
396763	393390	08069G	PARTICIPANT	\N	PRESENT	0
396764	393390	14119M	PARTICIPANT	\N	PRESENT	0
396765	393390	14147R	PARTICIPANT	\N	PRESENT	0
396766	393390	19573D	PARTICIPANT	\N	PRESENT	0
396767	393390	19715Y	PARTICIPANT	\N	PRESENT	0
396768	393390	19649G	PARTICIPANT	\N	PRESENT	0
396769	393390	11045K	PARTICIPANT	\N	PRESENT	0
396770	393390	19503N	PARTICIPANT	\N	PRESENT	0
396771	393390	07029T	PARTICIPANT	\N	PRESENT	0
396772	393390	14051J	PARTICIPANT	\N	PRESENT	0
396773	396243	19703U	PARTICIPANT	\N	PRESENT	0
396774	393390	05012A	PARTICIPANT	\N	PRESENT	0
396788	393390	14211G	PARTICIPANT	\N	PRESENT	0
396789	393390	19782L	PARTICIPANT	\N	PRESENT	0
396790	393390	19521Q	PARTICIPANT	\N	PRESENT	0
396854	393390	14083S	PARTICIPANT	\N	PRESENT	0
396855	393390	19575F	PARTICIPANT	\N	PRESENT	0
396856	393390	19415P	PARTICIPANT	\N	PRESENT	0
396857	393390	14231L	PARTICIPANT	\N	PRESENT	0
397055	393392	14069U	PARTICIPANT	\N	PRESENT	0
397056	393392	14147R	PARTICIPANT	\N	PRESENT	0
397057	393392	19681G	PARTICIPANT	\N	PRESENT	0
398248	398247	19531S	PARTICIPANT	\N	PRESENT	0
398262	398260	19741B	PARTICIPANT	\N	PRESENT	0
398264	398263	19647E	PARTICIPANT	\N	PRESENT	0
398267	398265	19545Y	PARTICIPANT	\N	PRESENT	0
398268	398265	19689Q	PARTICIPANT	\N	PRESENT	0
398271	398270	11074Q	PARTICIPANT	\N	PRESENT	0
398272	398270	08011M	PARTICIPANT	\N	PRESENT	0
408147	405277	19369B	PARTICIPANT	\N	PRESENT	0
408148	405277	19421M	PARTICIPANT	\N	EXCUSE	0
408150	405277	01028R	PARTICIPANT	\N	PRESENT	0
408177	405277	19647E	PARTICIPANT	\N	EXCUSE	0
408178	405277	08045X	PARTICIPANT	\N	EXCUSE	0
410427	402305	19583F	PARTICIPANT	\N	PRESENT	0
410429	402305	07029T	PARTICIPANT	\N	PRESENT	0
410430	402305	04049K	PARTICIPANT	\N	PRESENT	0
410431	402305	14029X	PARTICIPANT	\N	PRESENT	0
410432	402305	86034E	PARTICIPANT	\N	PRESENT	0
410433	402305	19723Y	PARTICIPANT	\N	PRESENT	0
410434	402305	98005N	PARTICIPANT	\N	PRESENT	0
410435	402305	19699S	PARTICIPANT	\N	PRESENT	0
410437	402305	12041X	PARTICIPANT	\N	PRESENT	0
410438	402305	14277B	PARTICIPANT	\N	PRESENT	0
410439	402305	19711U	PARTICIPANT	\N	PRESENT	0
410440	402305	19709B	PARTICIPANT	\N	PRESENT	0
410441	402305	16685X	PARTICIPANT	\N	PRESENT	0
410442	402305	11026G	PARTICIPANT	\N	PRESENT	0
410443	402305	08010L	PARTICIPANT	\N	PRESENT	0
410444	402305	08034U	PARTICIPANT	\N	PRESENT	0
410445	402305	08039A	PARTICIPANT	\N	PRESENT	0
410447	402305	08017T	PARTICIPANT	\N	PRESENT	0
410448	402305	19729F	PARTICIPANT	\N	PRESENT	0
410449	402305	01043Q	PARTICIPANT	\N	PRESENT	0
410451	402305	19581D	PARTICIPANT	\N	PRESENT	0
410452	402305	11077T	PARTICIPANT	\N	PRESENT	0
410453	402305	14205J	PARTICIPANT	\N	PRESENT	0
410454	402305	14219Q	PARTICIPANT	\N	PRESENT	0
410458	402305	08012N	PARTICIPANT	\N	PRESENT	0
410459	402305	17779H	PARTICIPANT	\N	PRESENT	0
410460	402305	14103D	PARTICIPANT	\N	PRESENT	0
410461	402305	12016W	PARTICIPANT	\N	PRESENT	0
410462	402305	11104D	PARTICIPANT	\N	PRESENT	0
410463	402305	08019V	PARTICIPANT	\N	PRESENT	0
410464	402305	19657G	PARTICIPANT	\N	PRESENT	0
410465	402305	14251Q	PARTICIPANT	\N	PRESENT	0
410466	402305	14063N	PARTICIPANT	\N	PRESENT	0
410467	402305	14031R	PARTICIPANT	\N	PRESENT	0
410468	402305	14111D	PARTICIPANT	\N	PRESENT	0
410469	402305	19637C	PARTICIPANT	\N	PRESENT	0
410470	402305	14001X	PARTICIPANT	\N	PRESENT	0
410471	402305	11085T	PARTICIPANT	\N	PRESENT	0
410472	402305	19826F	PARTICIPANT	\N	PRESENT	0
410473	402305	01060R	PARTICIPANT	\N	PRESENT	0
410474	402305	08009T	PARTICIPANT	\N	PRESENT	0
410476	402305	08053X	PARTICIPANT	\N	PRESENT	0
410478	402305	04057K	PARTICIPANT	\N	PRESENT	0
410479	402305	19563B	PARTICIPANT	\N	PRESENT	0
410480	402305	14147R	PARTICIPANT	\N	PRESENT	0
410481	402305	11067R	PARTICIPANT	\N	PRESENT	0
410482	402305	19671E	PARTICIPANT	\N	PRESENT	0
410484	402305	04092N	PARTICIPANT	\N	PRESENT	0
410485	402305	19335Q	PARTICIPANT	\N	PRESENT	0
410486	402305	19369B	PARTICIPANT	\N	PRESENT	0
410487	402305	11072N	PARTICIPANT	\N	PRESENT	0
410488	402305	14109K	PARTICIPANT	\N	PRESENT	0
410489	402305	14257W	PARTICIPANT	\N	PRESENT	0
410490	402305	08011M	PARTICIPANT	\N	PRESENT	0
410491	402305	14265W	PARTICIPANT	\N	PRESENT	0
410492	402305	04070G	PARTICIPANT	\N	PRESENT	0
410493	402305	14119M	PARTICIPANT	\N	PRESENT	0
415536	406854	01060R	PARTICIPANT	\N	PRESENT	0
415537	406854	08015R	PARTICIPANT	\N	PRESENT	0
415538	406854	14193X	PARTICIPANT	\N	PRESENT	0
415539	406854	14109K	PARTICIPANT	\N	PRESENT	0
415554	410795	14093U	PARTICIPANT	\N	EXCUSE	0
416427	406865	01043Q	PARTICIPANT	\N	PRESENT	0
416569	406927	10015M	PARTICIPANT	\N	PRESENT	0
416433	416429	14033T	PARTICIPANT	\N	PRESENT	0
416440	416439	18083K	PARTICIPANT	\N	PRESENT	0
416441	416439	08053X	PARTICIPANT	\N	PRESENT	0
416570	406927	14147R	PARTICIPANT	\N	PRESENT	0
416571	406927	14121F	PARTICIPANT	\N	PRESENT	0
416572	406927	19629C	PARTICIPANT	\N	PRESENT	0
416573	406927	19563B	PARTICIPANT	\N	PRESENT	0
416574	406927	19441R	PARTICIPANT	\N	PRESENT	0
416575	406927	04040A	PARTICIPANT	\N	PRESENT	0
416576	406927	07004J	PARTICIPANT	\N	PRESENT	0
416577	406927	14215L	PARTICIPANT	\N	PRESENT	0
416578	406927	01028R	PARTICIPANT	\N	PRESENT	0
416579	406927	19599P	PARTICIPANT	\N	PRESENT	0
416580	406927	14281W	PARTICIPANT	\N	PRESENT	0
416581	406927	19333N	PARTICIPANT	\N	PRESENT	0
416582	406927	05008E	PARTICIPANT	\N	PRESENT	0
416583	406927	14231L	PARTICIPANT	\N	PRESENT	0
416584	406927	14259Y	PARTICIPANT	\N	PRESENT	0
416585	406927	19503N	PARTICIPANT	\N	PRESENT	0
416586	406927	11056N	PARTICIPANT	\N	PRESENT	0
416587	406927	14207L	PARTICIPANT	\N	PRESENT	0
416588	406927	19511N	PARTICIPANT	\N	PRESENT	0
416589	406927	19745F	PARTICIPANT	\N	PRESENT	0
416590	406927	19543W	PARTICIPANT	\N	PRESENT	0
416591	406927	14033T	PARTICIPANT	\N	PRESENT	0
416592	406927	14157T	PARTICIPANT	\N	PRESENT	0
416593	406927	07029T	PARTICIPANT	\N	PRESENT	0
416594	406927	19762G	PARTICIPANT	\N	PRESENT	0
416595	406927	19701S	PARTICIPANT	\N	PRESENT	0
416596	406927	14053L	PARTICIPANT	\N	PRESENT	0
416597	406927	14071N	PARTICIPANT	\N	PRESENT	0
416598	406927	19335Q	PARTICIPANT	\N	PRESENT	0
416599	406927	19826F	PARTICIPANT	\N	PRESENT	0
416600	406927	99004R	PARTICIPANT	\N	PRESENT	0
416601	406927	14257W	PARTICIPANT	\N	PRESENT	0
416504	416431	04070G	PRESIDENT	1	PRESENT	0
416505	416431	19699S	PARTICIPANT	\N	PRESENT	0
416506	416431	14219Q	PARTICIPANT	\N	PRESENT	0
416507	416431	14229S	PARTICIPANT	\N	PRESENT	0
416508	416431	14241N	PARTICIPANT	\N	PRESENT	0
416509	416431	19573D	PARTICIPANT	\N	PRESENT	0
416510	416431	08017T	PARTICIPANT	\N	PRESENT	0
416511	416431	14179A	PARTICIPANT	\N	PRESENT	0
416512	416431	07033P	PRESIDENT	0	PRESENT	0
416513	416431	08012N	PARTICIPANT	\N	PRESENT	0
416514	416431	19335Q	PARTICIPANT	\N	PRESENT	0
416515	416431	14249W	PARTICIPANT	\N	PRESENT	0
416516	416431	08039A	PARTICIPANT	\N	PRESENT	0
416517	416431	19593H	PARTICIPANT	\N	PRESENT	0
416518	416431	19643A	PARTICIPANT	\N	PRESENT	0
416519	416431	14061L	PARTICIPANT	\N	PRESENT	0
416520	416431	04057K	PARTICIPANT	\N	PRESENT	0
416521	416431	14073Q	PARTICIPANT	\N	PRESENT	0
416522	416431	19713W	PARTICIPANT	\N	PRESENT	0
416523	416431	10015M	PARTICIPANT	\N	PRESENT	0
416524	416431	08043V	PARTICIPANT	\N	PRESENT	0
416525	416431	19693L	PARTICIPANT	\N	PRESENT	0
416526	416431	14030Q	PARTICIPANT	\N	PRESENT	0
416527	416431	08020N	PARTICIPANT	\N	PRESENT	0
416528	416431	14251Q	PARTICIPANT	\N	PRESENT	0
416529	416431	14063N	PARTICIPANT	\N	PRESENT	0
416530	416431	11083R	PARTICIPANT	\N	PRESENT	0
416531	416431	11104D	PARTICIPANT	\N	PRESENT	0
416532	416431	19749K	PARTICIPANT	\N	PRESENT	0
416533	416431	04018C	PARTICIPANT	\N	PRESENT	0
416534	416431	14107H	PARTICIPANT	\N	EXCUSE	0
416535	416431	14109K	PARTICIPANT	\N	EXCUSE	0
416536	416431	08031R	PARTICIPANT	\N	EXCUSE	0
416602	406927	04085P	PARTICIPANT	\N	PRESENT	0
416603	406927	19719D	PARTICIPANT	\N	PRESENT	0
416604	406927	14227Q	PARTICIPANT	\N	PRESENT	0
416605	406927	19725B	PARTICIPANT	\N	PRESENT	0
416606	406927	97011G	PARTICIPANT	\N	PRESENT	0
416607	406927	19693L	PARTICIPANT	\N	PRESENT	0
416608	406927	19575F	PARTICIPANT	\N	PRESENT	0
416609	406927	19711U	PARTICIPANT	\N	PRESENT	0
416610	406927	14249W	PARTICIPANT	\N	PRESENT	0
416611	406927	19565D	PARTICIPANT	\N	PRESENT	0
416612	406927	08020N	PARTICIPANT	\N	PRESENT	0
416613	406927	19415P	PARTICIPANT	\N	PRESENT	0
416614	406927	14211G	PARTICIPANT	\N	PRESENT	0
416615	406927	19683J	PARTICIPANT	\N	PRESENT	0
416616	406927	19387D	PARTICIPANT	\N	PRESENT	0
416617	406927	11012A	PARTICIPANT	\N	PRESENT	0
416618	406927	08034U	PARTICIPANT	\N	PRESENT	0
416619	406927	08024S	PARTICIPANT	\N	PRESENT	0
416620	406927	98050T	PARTICIPANT	\N	PRESENT	0
416621	406927	14261S	PARTICIPANT	\N	PRESENT	0
416622	406927	19713W	PARTICIPANT	\N	PRESENT	0
416567	406927	01043Q	PARTICIPANT	\N	PRESENT	0
416568	406927	19489J	PARTICIPANT	\N	PRESENT	0
416623	406927	11085T	PARTICIPANT	\N	PRESENT	0
416624	406927	16685X	PARTICIPANT	\N	PRESENT	0
416625	406927	14329V	PARTICIPANT	\N	PRESENT	0
416626	406927	01024M	PARTICIPANT	\N	PRESENT	0
416627	406927	14331P	PARTICIPANT	\N	PRESENT	0
416628	406927	08009T	PARTICIPANT	\N	PRESENT	0
416644	406927	14061L	PARTICIPANT	\N	PRESENT	0
416645	406927	08010L	PARTICIPANT	\N	PRESENT	0
416646	406927	01048V	PARTICIPANT	\N	PRESENT	0
416647	406927	14031R	PARTICIPANT	\N	PRESENT	0
416648	406927	14111D	PARTICIPANT	\N	PRESENT	0
416652	406927	19447X	PARTICIPANT	\N	PRESENT	0
416653	406927	19573D	PARTICIPANT	\N	PRESENT	0
416654	406927	18083K	PARTICIPANT	\N	PRESENT	0
416655	406927	19347U	PARTICIPANT	\N	PRESENT	0
416656	406927	14275Y	PARTICIPANT	\N	PRESENT	0
416657	406927	14083S	PARTICIPANT	\N	PRESENT	0
416658	406927	14073Q	PARTICIPANT	\N	PRESENT	0
416659	406927	11097X	PARTICIPANT	\N	PRESENT	0
416660	406927	14069U	PARTICIPANT	\N	PRESENT	0
416661	406927	08049C	PARTICIPANT	\N	PRESENT	0
416662	406927	14179A	PARTICIPANT	\N	PRESENT	0
416663	406927	95063L	PARTICIPANT	\N	PRESENT	0
416664	416431	04059M	PARTICIPANT	\N	PRESENT	0
416665	416431	08049C	PARTICIPANT	\N	PRESENT	0
416666	416431	19758L	PARTICIPANT	\N	PRESENT	0
416667	416431	14059S	PARTICIPANT	\N	PRESENT	0
416763	416760	19521Q	PARTICIPANT	\N	PRESENT	0
416767	416760	19679N	PARTICIPANT	\N	PRESENT	0
416781	405447	11109J	PARTICIPANT	\N	PRESENT	0
416782	405447	14261S	PARTICIPANT	\N	PRESENT	0
416783	416780	19521Q	PARTICIPANT	\N	PRESENT	0
416784	405447	19631V	PARTICIPANT	\N	PRESENT	0
416785	416780	19679N	PARTICIPANT	\N	PRESENT	0
416786	405447	19691J	PARTICIPANT	\N	PRESENT	0
416787	405447	19715Y	PARTICIPANT	\N	PRESENT	0
416788	405447	14039A	PARTICIPANT	\N	PRESENT	0
416789	405447	14059S	PARTICIPANT	\N	PRESENT	0
416790	405447	12016W	PARTICIPANT	\N	PRESENT	0
416791	405447	14219Q	PARTICIPANT	\N	EXCUSE	0
416792	405447	14277B	PARTICIPANT	\N	EXCUSE	0
416793	405447	19577H	PARTICIPANT	\N	EXCUSE	0
416794	405447	08019V	PRESIDENT	0	PRESENT	0
416796	405447	19657G	PARTICIPANT	\N	PRESENT	0
416797	405447	08073C	PARTICIPANT	\N	PRESENT	0
416798	405447	11054L	PARTICIPANT	\N	PRESENT	0
416799	405447	14275Y	PARTICIPANT	\N	PRESENT	0
416800	405447	19301E	PARTICIPANT	\N	PRESENT	0
416801	405447	14157T	PARTICIPANT	\N	PRESENT	0
417116	417113	01028R	PARTICIPANT	\N	PRESENT	0
417120	417119	01028R	PARTICIPANT	\N	PRESENT	0
417124	417123	08018U	PARTICIPANT	\N	PRESENT	0
417351	417350	08019V	PARTICIPANT	\N	PRESENT	0
417353	417352	08019V	PARTICIPANT	\N	PRESENT	0
417355	417354	08019V	PARTICIPANT	\N	PRESENT	0
417357	417356	08019V	PARTICIPANT	\N	PRESENT	0
417359	417358	08019V	PARTICIPANT	\N	PRESENT	0
417361	417360	08019V	PARTICIPANT	\N	PRESENT	0
417363	417362	08019V	PARTICIPANT	\N	PRESENT	0
417365	417364	08019V	PARTICIPANT	\N	PRESENT	0
417367	417366	08019V	PARTICIPANT	\N	PRESENT	0
417369	417368	08019V	PARTICIPANT	\N	PRESENT	0
417372	417371	08019V	PARTICIPANT	\N	PRESENT	0
417373	417370	08019V	PARTICIPANT	\N	PRESENT	0
417375	417374	11109J	PARTICIPANT	\N	PRESENT	0
417376	417374	19691J	PARTICIPANT	\N	PRESENT	0
417377	417374	08019V	PARTICIPANT	\N	PRESENT	0
417449	417448	08019V	PARTICIPANT	\N	PRESENT	0
417452	417450	08019V	PARTICIPANT	\N	PRESENT	0
417453	417451	08019V	PARTICIPANT	\N	PRESENT	0
394462	394458	19701S	PARTICIPANT	\N	PRESENT	0
400547	400546	19611R	PARTICIPANT	\N	PRESENT	0
400548	400546	14107H	PARTICIPANT	\N	PRESENT	0
400550	400549	19611R	PARTICIPANT	\N	PRESENT	0
400551	400549	19693L	PARTICIPANT	\N	PRESENT	0
400607	400606	19701S	PARTICIPANT	\N	PRESENT	0
400608	400606	19794Q	PARTICIPANT	\N	PRESENT	0
400610	400609	19701S	PARTICIPANT	\N	PRESENT	0
400611	400609	14083S	PARTICIPANT	\N	PRESENT	0
400613	400612	19701S	PARTICIPANT	\N	PRESENT	0
400617	400616	19701S	PARTICIPANT	\N	PRESENT	0
400618	400616	19637C	PARTICIPANT	\N	PRESENT	0
400619	400616	19794Q	PARTICIPANT	\N	PRESENT	0
400620	400616	19549D	PARTICIPANT	\N	PRESENT	0
400621	400616	14083S	PARTICIPANT	\N	PRESENT	0
400622	400616	14051J	PARTICIPANT	\N	PRESENT	0
400624	400623	19637C	PARTICIPANT	\N	PRESENT	0
400625	400623	19794Q	PARTICIPANT	\N	PRESENT	0
400626	400623	19701S	PARTICIPANT	\N	PRESENT	0
400627	400623	19549D	PARTICIPANT	\N	PRESENT	0
400628	400623	14051J	PARTICIPANT	\N	PRESENT	0
400630	400629	19701S	PARTICIPANT	\N	PRESENT	0
400631	400629	19794Q	PARTICIPANT	\N	PRESENT	0
400632	400629	19549D	PARTICIPANT	\N	PRESENT	0
400633	400629	14051J	PARTICIPANT	\N	PRESENT	0
400635	400634	19701S	PARTICIPANT	\N	PRESENT	0
400636	400634	19794Q	PARTICIPANT	\N	PRESENT	0
400637	400634	19549D	PARTICIPANT	\N	PRESENT	0
400639	400638	19701S	PARTICIPANT	\N	PRESENT	0
401139	397111	19691J	PARTICIPANT	\N	PRESENT	0
401140	397111	14265W	PARTICIPANT	\N	PRESENT	0
401141	397111	14119M	PARTICIPANT	\N	PRESENT	0
401142	397111	19349W	PARTICIPANT	\N	PRESENT	0
401853	401846	08031R	PARTICIPANT	\N	PRESENT	0
407143	405333	19820Y	PARTICIPANT	\N	PRESENT	0
407144	405335	19820Y	PARTICIPANT	\N	PRESENT	0
407145	405336	19820Y	PARTICIPANT	\N	PRESENT	0
410296	402305	14195A	PARTICIPANT	\N	PRESENT	0
410297	402305	08028W	PARTICIPANT	\N	PRESENT	0
410298	402305	19467C	PARTICIPANT	\N	PRESENT	0
410299	402305	18083K	PARTICIPANT	\N	PRESENT	0
410300	402305	19701S	PARTICIPANT	\N	PRESENT	0
410301	402305	14267Y	PARTICIPANT	\N	PRESENT	0
410302	402305	11031D	PARTICIPANT	\N	PRESENT	0
410303	402305	88008L	PARTICIPANT	\N	PRESENT	0
410304	402305	04038G	PARTICIPANT	\N	PRESENT	0
410305	402305	19295A	PARTICIPANT	\N	PRESENT	0
410306	402305	19812Y	PARTICIPANT	\N	PRESENT	0
410307	402305	11027H	PARTICIPANT	\N	PRESENT	0
410308	402305	19681G	PARTICIPANT	\N	PRESENT	0
410309	402305	19253P	PARTICIPANT	\N	PRESENT	0
410310	402305	80013X	PARTICIPANT	\N	PRESENT	0
420384	420382	14033T	PARTICIPANT	\N	PRESENT	0
410312	402305	11056N	PARTICIPANT	\N	PRESENT	0
410313	402305	14357A	PARTICIPANT	\N	PRESENT	0
410314	402305	19525U	PARTICIPANT	\N	PRESENT	0
410315	402305	04086Q	PARTICIPANT	\N	PRESENT	0
420386	420382	14205J	PARTICIPANT	\N	PRESENT	0
410317	402305	11065P	PARTICIPANT	\N	PRESENT	0
420387	420382	14135M	PARTICIPANT	\N	PRESENT	0
410319	402305	14259Y	PARTICIPANT	\N	PRESENT	0
420388	420382	08038Y	PARTICIPANT	\N	PRESENT	0
410321	402305	08052W	PARTICIPANT	\N	PRESENT	0
410322	402305	08038Y	PARTICIPANT	\N	PRESENT	0
420389	420382	19413M	PARTICIPANT	\N	PRESENT	0
410324	402305	11070L	PARTICIPANT	\N	PRESENT	0
410325	402305	19719D	PARTICIPANT	\N	PRESENT	0
410326	402305	14327T	PARTICIPANT	\N	PRESENT	0
410327	402305	19663E	PARTICIPANT	\N	PRESENT	0
410328	402305	98018T	PARTICIPANT	\N	PRESENT	0
410329	402305	19659J	PARTICIPANT	\N	PRESENT	0
410330	402305	98024R	PARTICIPANT	\N	PRESENT	0
410331	402305	10006L	PARTICIPANT	\N	PRESENT	0
410332	402305	14041T	PARTICIPANT	\N	PRESENT	0
410333	402305	14217N	PARTICIPANT	\N	PRESENT	0
410334	402305	01024M	PARTICIPANT	\N	PRESENT	0
410335	402305	19251M	PARTICIPANT	\N	PRESENT	0
410336	402305	14215L	PARTICIPANT	\N	PRESENT	0
410337	402305	19577H	PARTICIPANT	\N	PRESENT	0
410338	402305	14042U	PARTICIPANT	\N	PRESENT	0
410339	402305	04071H	PARTICIPANT	\N	PRESENT	0
410340	402305	04089T	PARTICIPANT	\N	PRESENT	0
410341	402305	87003B	PARTICIPANT	\N	PRESENT	0
410342	402305	07033P	PARTICIPANT	\N	PRESENT	0
420390	420382	19269X	PARTICIPANT	\N	PRESENT	0
410344	402305	14151M	PARTICIPANT	\N	PRESENT	0
410345	402305	14197C	PARTICIPANT	\N	PRESENT	0
420391	420382	19511N	PARTICIPANT	\N	PRESENT	0
410347	402305	11074Q	PARTICIPANT	\N	PRESENT	0
410348	402305	95030B	PARTICIPANT	\N	PRESENT	0
410349	402305	11110B	PARTICIPANT	\N	PRESENT	0
410350	402305	14187A	PARTICIPANT	\N	PRESENT	0
410351	402305	19673G	PARTICIPANT	\N	PRESENT	0
420392	420382	19441R	PARTICIPANT	\N	PRESENT	0
420393	420382	01025N	PARTICIPANT	\N	PRESENT	0
410354	402305	14281W	PARTICIPANT	\N	PRESENT	0
420394	420382	19515S	PARTICIPANT	\N	PRESENT	0
410356	402305	19599P	PARTICIPANT	\N	PRESENT	0
410357	402305	14087W	PARTICIPANT	\N	PRESENT	0
410358	402305	02002K	PARTICIPANT	\N	PRESENT	0
410359	402305	19521Q	PARTICIPANT	\N	PRESENT	0
420395	420382	11099A	PARTICIPANT	\N	PRESENT	0
410361	402305	08018U	PARTICIPANT	\N	PRESENT	0
410362	402305	11010L	PARTICIPANT	\N	PRESENT	0
410363	402305	14034U	PARTICIPANT	\N	PRESENT	0
410364	402305	04035D	PARTICIPANT	\N	PRESENT	0
410365	402305	14231L	PARTICIPANT	\N	PRESENT	0
420416	420415	14033T	PARTICIPANT	\N	PRESENT	0
410367	402305	19695N	PARTICIPANT	\N	PRESENT	0
420417	420415	14135M	PARTICIPANT	\N	PRESENT	0
410369	402305	14355X	PARTICIPANT	\N	PRESENT	0
410370	402305	08035V	PARTICIPANT	\N	PRESENT	0
420418	420415	14205J	PARTICIPANT	\N	PRESENT	0
410372	402305	08048B	PARTICIPANT	\N	PRESENT	0
410373	402305	15447F	PARTICIPANT	\N	PRESENT	0
420687	417145	14327T	PARTICIPANT	\N	PRESENT	0
420688	417145	14028W	PARTICIPANT	\N	PRESENT	0
410376	402305	19347U	PARTICIPANT	\N	PRESENT	0
420690	420555	04071H	PARTICIPANT	\N	PRESENT	0
410378	402305	07004J	PARTICIPANT	\N	PRESENT	0
410379	402305	08056B	PARTICIPANT	\N	PRESENT	0
410380	402305	14211G	PARTICIPANT	\N	PRESENT	0
410381	402305	19565D	PARTICIPANT	\N	PRESENT	0
410382	402305	19727D	PARTICIPANT	\N	PRESENT	0
410383	402305	14033T	PARTICIPANT	\N	PRESENT	0
410384	402305	11049P	PARTICIPANT	\N	PRESENT	0
410385	402305	14123H	PARTICIPANT	\N	PRESENT	0
410386	402305	14026U	PARTICIPANT	\N	PRESENT	0
410387	402305	01057W	PARTICIPANT	\N	PRESENT	0
410388	402305	98022P	PARTICIPANT	\N	PRESENT	0
410389	402305	11064N	PARTICIPANT	\N	PRESENT	0
410390	402305	19691J	PARTICIPANT	\N	PRESENT	0
410391	402305	14081Q	PARTICIPANT	\N	PRESENT	0
410392	402305	19553Y	PARTICIPANT	\N	PRESENT	0
410393	402305	19725B	PARTICIPANT	\N	PRESENT	0
410394	402305	19329S	PARTICIPANT	\N	PRESENT	0
410395	402305	95037J	PARTICIPANT	\N	PRESENT	0
410396	402305	19569H	PARTICIPANT	\N	PRESENT	0
410397	402305	14179A	PARTICIPANT	\N	PRESENT	0
410398	402305	19685L	PARTICIPANT	\N	PRESENT	0
410399	402305	19333N	PARTICIPANT	\N	PRESENT	0
410401	402305	19399H	PARTICIPANT	\N	PRESENT	0
410402	402305	04097T	PARTICIPANT	\N	PRESENT	0
410403	402305	11048N	PARTICIPANT	\N	PRESENT	0
410404	402305	19591F	PARTICIPANT	\N	PRESENT	0
410405	402305	14213J	PARTICIPANT	\N	PRESENT	0
410406	402305	19551W	PARTICIPANT	\N	PRESENT	0
410407	402305	19511N	PARTICIPANT	\N	PRESENT	0
410408	402305	19715Y	PARTICIPANT	\N	PRESENT	0
410409	402305	14121F	PARTICIPANT	\N	PRESENT	0
410410	402305	08044W	PARTICIPANT	\N	PRESENT	0
410412	402305	19683J	PARTICIPANT	\N	PRESENT	0
410413	402305	14097Y	PARTICIPANT	\N	PRESENT	0
410414	402305	19447X	PARTICIPANT	\N	PRESENT	0
410415	402305	14241N	PARTICIPANT	\N	PRESENT	0
410417	402305	14021P	PARTICIPANT	\N	PRESENT	0
410418	402305	14039A	PARTICIPANT	\N	PRESENT	0
410419	402305	99004R	PARTICIPANT	\N	PRESENT	0
410420	402305	19731Y	PARTICIPANT	\N	PRESENT	0
410421	402305	14061L	PARTICIPANT	\N	PRESENT	0
410422	402305	14073Q	PARTICIPANT	\N	PRESENT	0
410423	402305	19489J	PARTICIPANT	\N	PRESENT	0
410424	402305	11099A	PARTICIPANT	\N	PRESENT	0
410425	402305	08031R	PARTICIPANT	\N	PRESENT	0
410426	402305	19611R	PARTICIPANT	\N	PRESENT	0
407219	406928	19333N	PARTICIPANT	\N	PRESENT	0
407220	406928	14031R	PARTICIPANT	\N	PRESENT	0
407221	406928	19713W	PARTICIPANT	\N	PRESENT	0
407222	406928	19387D	PARTICIPANT	\N	PRESENT	0
407223	406928	08055A	PARTICIPANT	\N	PRESENT	0
407224	406928	19599P	PARTICIPANT	\N	PRESENT	0
407225	406928	14169X	PARTICIPANT	\N	PRESENT	0
407226	406928	19637C	PARTICIPANT	\N	PRESENT	0
407227	406928	14237S	PARTICIPANT	\N	PRESENT	0
407228	406928	19733B	PARTICIPANT	\N	PRESENT	0
407229	406928	19503N	PARTICIPANT	\N	PRESENT	0
407230	406928	19737F	PARTICIPANT	\N	PRESENT	0
407231	406928	19739H	PARTICIPANT	\N	PRESENT	0
407232	406928	14157T	PARTICIPANT	\N	PRESENT	0
407233	406928	08024S	PARTICIPANT	\N	PRESENT	0
407988	405277	08024S	PARTICIPANT	\N	PRESENT	0
407990	405277	08012N	PARTICIPANT	\N	EXCUSE	0
408044	405277	19515S	PARTICIPANT	\N	EXCUSE	0
408088	408086	04085P	PARTICIPANT	\N	PRESENT	0
408089	408086	14093U	PARTICIPANT	\N	EXCUSE	0
408090	408086	19549D	PARTICIPANT	\N	PRESENT	0
408094	408086	19333N	PARTICIPANT	\N	PRESENT	0
408092	408086	19701S	PARTICIPANT	\N	PRESENT	0
408093	408086	19347U	PARTICIPANT	\N	PRESENT	0
408095	408086	19551W	PARTICIPANT	\N	PRESENT	0
408096	408086	14219Q	PARTICIPANT	\N	PRESENT	0
408097	408086	14031R	PARTICIPANT	\N	PRESENT	0
408098	408086	19637C	PARTICIPANT	\N	PRESENT	0
408099	408086	08009T	PRESIDENT	0	PRESENT	0
408100	408086	19503N	PARTICIPANT	\N	PRESENT	0
408101	408086	19794Q	PARTICIPANT	\N	EXCUSE	0
408102	408086	19713W	PARTICIPANT	\N	PRESENT	0
408137	408087	19701S	PARTICIPANT	\N	PRESENT	0
408104	408086	14157T	PARTICIPANT	\N	EXCUSE	0
408136	408087	08009T	PRESIDENT	0	PRESENT	0
408138	408087	04085P	PARTICIPANT	\N	PRESENT	0
408139	408087	19347U	PARTICIPANT	\N	PRESENT	0
408140	408087	19637C	PARTICIPANT	\N	PRESENT	0
408141	408087	19549D	PARTICIPANT	\N	PRESENT	0
408142	408087	19333N	PARTICIPANT	\N	PRESENT	0
408143	408087	19713W	PARTICIPANT	\N	PRESENT	0
408171	408170	14199E	PARTICIPANT	\N	PRESENT	0
408173	408172	14199E	PARTICIPANT	\N	PRESENT	0
408175	408174	14199E	PARTICIPANT	\N	PRESENT	0
408187	405448	14038Y	PARTICIPANT	\N	EXCUSE	0
408188	405448	14135M	PARTICIPANT	\N	EXCUSE	0
408190	405277	08062Y	PARTICIPANT	\N	EXCUSE	0
408849	408829	08039A	PARTICIPANT	\N	PRESENT	0
408850	408829	04057K	PARTICIPANT	\N	EXCUSE	0
408851	408829	19699S	PARTICIPANT	\N	PRESENT	0
408852	408829	08017T	PARTICIPANT	\N	PRESENT	0
408853	408829	92040Q	PARTICIPANT	\N	PRESENT	0
408854	408829	14061L	PARTICIPANT	\N	PRESENT	0
408855	408829	08020N	PARTICIPANT	\N	PRESENT	0
408856	408829	14109K	PARTICIPANT	\N	PRESENT	0
408857	408829	19749K	PARTICIPANT	\N	PRESENT	0
408898	407544	19443T	PARTICIPANT	\N	PRESENT	0
408899	407544	12041X	PARTICIPANT	\N	PRESENT	0
408900	407544	95030B	PARTICIPANT	\N	PRESENT	0
408901	407544	04034C	PARTICIPANT	\N	PRESENT	0
408902	407544	04040A	PARTICIPANT	\N	PRESENT	0
408903	407544	16685X	PARTICIPANT	\N	PRESENT	0
408904	407544	11027H	PARTICIPANT	\N	PRESENT	0
408905	407544	04042C	PRESIDENT	0	PRESENT	0
408906	407544	11054L	PARTICIPANT	\N	PRESENT	0
408907	407544	11066Q	PARTICIPANT	\N	PRESENT	0
408908	407544	08056B	PARTICIPANT	\N	PRESENT	0
408909	407544	95037J	PARTICIPANT	\N	PRESENT	0
408910	407544	19709B	PARTICIPANT	\N	PRESENT	0
408911	407544	08049C	PARTICIPANT	\N	PRESENT	0
408912	407544	14193X	PARTICIPANT	\N	PRESENT	0
408913	407544	08053X	PARTICIPANT	\N	PRESENT	0
408914	407544	08047A	PARTICIPANT	\N	PRESENT	0
408915	407544	95067Q	PARTICIPANT	\N	PRESENT	0
408916	407544	14133K	PARTICIPANT	\N	PRESENT	0
408917	407544	01062T	PARTICIPANT	\N	PRESENT	0
408918	407544	14235Q	PARTICIPANT	\N	PRESENT	0
408919	407544	08058D	PARTICIPANT	\N	PRESENT	0
408920	407544	19251M	PARTICIPANT	\N	PRESENT	0
408921	407544	14028W	PARTICIPANT	\N	PRESENT	0
408922	407544	19721W	PARTICIPANT	\N	PRESENT	0
408923	407544	19319Q	PARTICIPANT	\N	PRESENT	0
408924	407544	98022P	PARTICIPANT	\N	PRESENT	0
408925	407544	14267Y	PARTICIPANT	\N	PRESENT	0
408926	407544	11064N	PARTICIPANT	\N	PRESENT	0
408927	407544	19583F	PARTICIPANT	\N	PRESENT	0
408928	407544	14211G	PARTICIPANT	\N	PRESENT	0
408929	407544	14255U	PARTICIPANT	\N	PRESENT	0
408930	407544	14097Y	PARTICIPANT	\N	PRESENT	0
408931	407544	04035D	PARTICIPANT	\N	PRESENT	0
408935	408155	19581D	PARTICIPANT	\N	PRESENT	0
408943	407378	04097T	PARTICIPANT	\N	PRESENT	0
408951	407378	19549D	PARTICIPANT	\N	PRESENT	0
408963	407544	08061X	PARTICIPANT	\N	PRESENT	0
408964	407544	98018T	PARTICIPANT	\N	PRESENT	0
408965	407544	98029W	PARTICIPANT	\N	EXCUSE	0
408967	408815	11010L	PARTICIPANT	\N	PRESENT	0
408968	408829	19611R	PARTICIPANT	\N	PRESENT	0
409025	407544	14105F	PARTICIPANT	\N	PRESENT	0
409026	407544	98050T	PARTICIPANT	\N	PRESENT	0
409027	406862	11067R	PARTICIPANT	\N	PRESENT	0
409028	406862	14355X	PARTICIPANT	\N	PRESENT	0
409029	406862	19565D	PARTICIPANT	\N	PRESENT	0
409030	406862	19569H	PARTICIPANT	\N	PRESENT	0
409031	406862	19798U	PARTICIPANT	\N	PRESENT	0
409032	406862	11097X	PARTICIPANT	\N	PRESENT	0
409033	406862	14223L	PARTICIPANT	\N	PRESENT	0
409034	406862	04045F	PARTICIPANT	\N	PRESENT	0
409035	406862	14026U	PARTICIPANT	\N	PRESENT	0
409036	406862	14227Q	PARTICIPANT	\N	PRESENT	0
409037	406862	17779H	PARTICIPANT	\N	PRESENT	0
409038	406862	11031D	PARTICIPANT	\N	PRESENT	0
409039	406862	19703U	PARTICIPANT	\N	PRESENT	0
409040	406862	19553Y	PARTICIPANT	\N	PRESENT	0
409041	406862	14281W	PARTICIPANT	\N	PRESENT	0
409042	406862	19679N	PARTICIPANT	\N	PRESENT	0
409043	406862	14042U	PARTICIPANT	\N	PRESENT	0
409044	406862	14195A	PARTICIPANT	\N	PRESENT	0
409045	406862	19367Y	PARTICIPANT	\N	PRESENT	0
409046	406862	14213J	PARTICIPANT	\N	PRESENT	0
409047	406862	14261S	PARTICIPANT	\N	PRESENT	0
409048	406862	14217N	PARTICIPANT	\N	PRESENT	0
409049	406862	19683J	PARTICIPANT	\N	PRESENT	0
409050	406862	10006L	PARTICIPANT	\N	PRESENT	0
409051	406862	98024R	PRESIDENT	1	PRESENT	0
409052	406862	19521Q	PARTICIPANT	\N	PRESENT	0
409053	406862	19527W	PARTICIPANT	\N	PRESENT	0
409054	406862	04092N	PRESIDENT	0	PRESENT	0
409055	406862	08052W	PARTICIPANT	\N	PRESENT	0
409056	406862	19301E	PARTICIPANT	\N	PRESENT	0
409057	406862	19715Y	PARTICIPANT	\N	PRESENT	0
409058	406862	19691J	PARTICIPANT	\N	PRESENT	0
409059	406862	19717B	PARTICIPANT	\N	PRESENT	0
409060	406862	19723Y	PARTICIPANT	\N	PRESENT	0
409061	406862	19727D	PARTICIPANT	\N	PRESENT	0
409062	406862	14119M	PARTICIPANT	\N	PRESENT	0
409063	406862	11103C	PARTICIPANT	\N	PRESENT	0
409064	406862	19657G	PARTICIPANT	\N	PRESENT	0
409065	406862	19760E	PARTICIPANT	\N	PRESENT	0
409066	406862	19575F	PARTICIPANT	\N	EXCUSE	0
409067	406862	14071N	PARTICIPANT	\N	EXCUSE	0
409068	406862	08041T	PARTICIPANT	\N	EXCUSE	0
409181	408286	19415P	PARTICIPANT	\N	PRESENT	0
409182	408286	19301E	PARTICIPANT	\N	PRESENT	0
409183	408286	14033T	PARTICIPANT	\N	PRESENT	0
409184	408286	19659J	PARTICIPANT	\N	PRESENT	0
409185	408286	08019V	PARTICIPANT	\N	PRESENT	0
409186	408286	19399H	PARTICIPANT	\N	PRESENT	0
409187	408286	11012A	PARTICIPANT	\N	PRESENT	0
409188	408286	19729F	PARTICIPANT	\N	PRESENT	0
409189	408286	08031R	PARTICIPANT	\N	PRESENT	0
409190	408286	08048B	PARTICIPANT	\N	PRESENT	0
409191	408286	88008L	PARTICIPANT	\N	PRESENT	0
409192	408286	14034U	PARTICIPANT	\N	PRESENT	0
409193	408286	08049C	PARTICIPANT	\N	PRESENT	0
409194	408286	14261S	PARTICIPANT	\N	PRESENT	0
409195	408286	19629C	PARTICIPANT	\N	PRESENT	0
409196	408286	14213J	PARTICIPANT	\N	PRESENT	0
409197	408286	19253P	PARTICIPANT	\N	PRESENT	0
409198	408286	14329V	PARTICIPANT	\N	PRESENT	0
409199	408286	14107H	PARTICIPANT	\N	PRESENT	0
409200	408286	14357A	PARTICIPANT	\N	PRESENT	0
409201	408286	14201E	PARTICIPANT	\N	PRESENT	0
409202	408286	98022P	PARTICIPANT	\N	PRESENT	0
409203	408286	14241N	PARTICIPANT	\N	PRESENT	0
409204	408286	19719D	PARTICIPANT	\N	PRESENT	0
409205	408286	11099A	PARTICIPANT	\N	PRESENT	0
409206	408286	11065P	PARTICIPANT	\N	PRESENT	0
409207	408286	14207L	PARTICIPANT	\N	PRESENT	0
405202	405201	04070G	PARTICIPANT	\N	PRESENT	0
405203	405201	19399H	PARTICIPANT	\N	PRESENT	0
405204	405201	08039A	PARTICIPANT	\N	PRESENT	0
405205	405201	14249W	PARTICIPANT	\N	PRESENT	0
405206	405201	14229S	PARTICIPANT	\N	PRESENT	0
405207	405201	08043V	PARTICIPANT	\N	PRESENT	0
405208	405201	11083R	PARTICIPANT	\N	PRESENT	0
405209	405201	19621T	PARTICIPANT	\N	PRESENT	0
410495	402305	92040Q	PARTICIPANT	\N	PRESENT	0
413242	410230	14031R	PARTICIPANT	\N	PRESENT	0
410497	402305	19768N	PARTICIPANT	\N	PRESENT	0
410498	402305	14253S	PARTICIPANT	\N	PRESENT	0
410499	402305	19593H	PARTICIPANT	\N	PRESENT	0
410500	402305	19573D	PARTICIPANT	\N	PRESENT	0
410501	402305	14191V	PARTICIPANT	\N	PRESENT	0
410502	402305	08073C	PARTICIPANT	\N	PRESENT	0
410503	402305	08061X	PARTICIPANT	\N	PRESENT	0
410504	402305	08047A	PARTICIPANT	\N	PRESENT	0
410505	402305	14237S	PARTICIPANT	\N	PRESENT	0
410506	402305	17637T	PARTICIPANT	\N	PRESENT	0
410507	402305	14028W	PARTICIPANT	\N	PRESENT	0
410508	402305	14193X	PARTICIPANT	\N	PRESENT	0
410509	402305	19745F	PARTICIPANT	\N	PRESENT	0
410510	402305	19533U	PARTICIPANT	\N	PRESENT	0
410511	402305	04088S	PARTICIPANT	\N	PRESENT	0
410512	402305	19319Q	PARTICIPANT	\N	PRESENT	0
410513	402305	05012A	PARTICIPANT	\N	PRESENT	0
410514	402305	98050T	PARTICIPANT	\N	PRESENT	0
413243	410230	14157T	PARTICIPANT	\N	PRESENT	0
410516	402305	11090Q	PARTICIPANT	\N	PRESENT	0
410517	402305	19739H	PARTICIPANT	\N	PRESENT	0
410518	402305	17583W	PARTICIPANT	\N	PRESENT	0
413244	410230	14281W	PRESIDENT	0	PRESENT	0
413251	410230	14187A	PARTICIPANT	\N	PRESENT	0
410521	402305	14235Q	PARTICIPANT	\N	PRESENT	0
410522	402305	19679N	PARTICIPANT	\N	PRESENT	0
410523	402305	19443T	PARTICIPANT	\N	PRESENT	0
410524	402305	14135M	PARTICIPANT	\N	PRESENT	0
410525	402305	19349W	PARTICIPANT	\N	PRESENT	0
410526	402305	19794Q	PARTICIPANT	\N	PRESENT	0
410527	402305	14331P	PARTICIPANT	\N	PRESENT	0
410528	402305	19269X	PARTICIPANT	\N	PRESENT	0
410529	402305	14055N	PARTICIPANT	\N	PRESENT	0
410530	402305	14225N	PARTICIPANT	\N	PRESENT	0
410531	402305	19766L	PARTICIPANT	\N	PRESENT	0
410532	402305	10015M	PARTICIPANT	\N	PRESENT	0
410533	402305	19705W	PARTICIPANT	\N	PRESENT	0
410534	402305	11012A	PARTICIPANT	\N	PRESENT	0
410535	402305	04033B	PARTICIPANT	\N	PRESENT	0
410536	402305	95063L	PARTICIPANT	\N	PRESENT	0
410537	402305	19798U	PARTICIPANT	\N	PRESENT	0
410538	402305	14229S	PARTICIPANT	\N	PRESENT	0
410539	402305	11054L	PARTICIPANT	\N	PRESENT	0
410540	402305	11045K	PARTICIPANT	\N	PRESENT	0
410541	402305	14107H	PARTICIPANT	\N	PRESENT	0
413252	410230	98029W	PARTICIPANT	\N	EXCUSE	0
410543	402305	19421M	PARTICIPANT	\N	PRESENT	0
410544	402305	11097X	PARTICIPANT	\N	PRESENT	0
410545	402305	11043H	PARTICIPANT	\N	PRESENT	0
410546	402305	19687N	PARTICIPANT	\N	PRESENT	0
410547	402305	04045F	PARTICIPANT	\N	PRESENT	0
410548	402305	04018C	PARTICIPANT	\N	PRESENT	0
410549	402305	19762G	PARTICIPANT	\N	PRESENT	0
410550	402305	01058X	PARTICIPANT	\N	PRESENT	0
410551	402305	04069P	PARTICIPANT	\N	PRESENT	0
410552	402305	19703U	PARTICIPANT	\N	PRESENT	0
410553	402305	19713W	PARTICIPANT	\N	PRESENT	0
410554	402305	01028R	PARTICIPANT	\N	PRESENT	0
410555	402305	98035U	PARTICIPANT	\N	PRESENT	0
410556	402305	19689Q	PARTICIPANT	\N	PRESENT	0
413253	410230	14275Y	PARTICIPANT	\N	EXCUSE	0
410558	402305	14275Y	PARTICIPANT	\N	PRESENT	0
410559	402305	19301E	PARTICIPANT	\N	PRESENT	0
413254	410230	08043V	PARTICIPANT	\N	EXCUSE	0
413255	410230	08045X	PARTICIPANT	\N	EXCUSE	0
413262	410230	19729F	PARTICIPANT	\N	EXCUSE	0
410563	402305	01062T	PARTICIPANT	\N	PRESENT	0
410564	402305	14227Q	PARTICIPANT	\N	PRESENT	0
410565	402305	04044E	PARTICIPANT	\N	PRESENT	0
410566	402305	11041F	PARTICIPANT	\N	PRESENT	0
410567	402305	08049C	PARTICIPANT	\N	PRESENT	0
410568	402305	19527W	PARTICIPANT	\N	PRESENT	0
413263	410230	14331P	PARTICIPANT	\N	EXCUSE	0
410570	402305	14157T	PARTICIPANT	\N	PRESENT	0
410571	402305	11066Q	PARTICIPANT	\N	PRESENT	0
410572	402305	19749K	PARTICIPANT	\N	PRESENT	0
410573	402305	19479G	PARTICIPANT	\N	PRESENT	0
410574	402305	95067Q	PARTICIPANT	\N	PRESENT	0
410575	402305	14173T	PARTICIPANT	\N	PRESENT	0
413266	410230	08034U	PARTICIPANT	\N	PRESENT	0
410577	402305	19585H	PARTICIPANT	\N	PRESENT	0
410578	402305	04034C	PARTICIPANT	\N	PRESENT	0
410584	402305	04059M	PARTICIPANT	\N	PRESENT	0
410585	402305	19820Y	PARTICIPANT	\N	PRESENT	0
413272	410230	11064N	PARTICIPANT	\N	PRESENT	0
413298	410230	04044E	PARTICIPANT	\N	PRESENT	0
413299	410230	14083S	PARTICIPANT	\N	PRESENT	0
413951	413950	14199E	PARTICIPANT	\N	PRESENT	0
414032	412265	05012A	PARTICIPANT	\N	EXCUSE	0
414034	412265	14327T	PARTICIPANT	\N	EXCUSE	0
414061	408325	19349W	PARTICIPANT	\N	EXCUSE	0
414063	408325	19515S	PARTICIPANT	\N	PRESENT	0
414064	408325	14147R	PARTICIPANT	\N	PRESENT	0
414065	408325	19713W	PARTICIPANT	\N	PRESENT	0
416436	416434	19521Q	PARTICIPANT	\N	PRESENT	0
414069	411907	11067R	PARTICIPANT	\N	PRESENT	0
414070	411907	14147R	PARTICIPANT	\N	PRESENT	0
414071	411907	19629C	PARTICIPANT	\N	PRESENT	0
414072	411919	10006L	PARTICIPANT	\N	PRESENT	0
414073	411919	11067R	PARTICIPANT	\N	PRESENT	0
414074	411919	14147R	PARTICIPANT	\N	PRESENT	0
414075	411919	19629C	PARTICIPANT	\N	PRESENT	0
416435	416434	14087W	PARTICIPANT	\N	PRESENT	0
416437	416434	19679N	PARTICIPANT	\N	PRESENT	0
416466	416464	14087W	PARTICIPANT	\N	PRESENT	0
416467	416464	19521Q	PARTICIPANT	\N	PRESENT	0
416468	416464	19679N	PARTICIPANT	\N	PRESENT	0
416470	416469	14087W	PARTICIPANT	\N	PRESENT	0
416471	416469	19521Q	PARTICIPANT	\N	PRESENT	0
416472	416469	19679N	PARTICIPANT	\N	PRESENT	0
416479	416477	10006L	PARTICIPANT	\N	PRESENT	0
416480	416477	08052W	PARTICIPANT	\N	PRESENT	0
417347	417145	11101A	PARTICIPANT	\N	PRESENT	0
417387	417145	14063N	PARTICIPANT	\N	PRESENT	0
417390	417145	14281W	PARTICIPANT	\N	PRESENT	0
417412	417145	04044E	PARTICIPANT	\N	EXCUSE	0
417438	417145	04045F	PARTICIPANT	\N	PRESENT	0
417439	417145	19565D	PARTICIPANT	\N	EXCUSE	0
417537	417536	14030Q	PARTICIPANT	\N	PRESENT	0
417538	417536	11109J	PARTICIPANT	\N	PRESENT	0
417539	417536	14219Q	PARTICIPANT	\N	PRESENT	0
417540	417536	11083R	PARTICIPANT	\N	PRESENT	0
417541	417536	14239U	PARTICIPANT	\N	PRESENT	0
417542	417536	04070G	PARTICIPANT	\N	PRESENT	0
417544	417536	14135M	PARTICIPANT	\N	PRESENT	0
417545	417536	19673G	PARTICIPANT	\N	PRESENT	0
417547	417536	14265W	PARTICIPANT	\N	PRESENT	0
417548	417536	19768N	PARTICIPANT	\N	PRESENT	0
417551	417536	14063N	PARTICIPANT	\N	PRESENT	0
418401	418273	11026G	PARTICIPANT	\N	PRESENT	0
419348	419341	14147R	PARTICIPANT	\N	PRESENT	0
420712	420711	04086Q	PARTICIPANT	\N	PRESENT	0
420714	420713	04086Q	PARTICIPANT	\N	PRESENT	0
420716	420715	99004R	PARTICIPANT	\N	PRESENT	0
420718	420717	11026G	PARTICIPANT	\N	PRESENT	0
420903	407833	07029T	PARTICIPANT	\N	PRESENT	0
420904	407833	04043D	PARTICIPANT	\N	PRESENT	0
420905	407833	19667J	PARTICIPANT	\N	PRESENT	0
420906	407833	14147R	PARTICIPANT	\N	PRESENT	0
420907	407833	07033P	PARTICIPANT	\N	PRESENT	0
420908	407833	14033T	PARTICIPANT	\N	PRESENT	0
420909	407833	19467C	PARTICIPANT	\N	PRESENT	0
420910	407833	08048B	PARTICIPANT	\N	PRESENT	0
420911	407833	15447F	PARTICIPANT	\N	PRESENT	0
420912	407833	19673G	PARTICIPANT	\N	PRESENT	0
420913	407833	08058D	PARTICIPANT	\N	PRESENT	0
420914	407833	19768N	PARTICIPANT	\N	PRESENT	0
420915	407833	14085U	PARTICIPANT	\N	PRESENT	0
420916	407833	14087W	PARTICIPANT	\N	PRESENT	0
420917	407833	19441R	PARTICIPANT	\N	PRESENT	0
420918	407833	16685X	PARTICIPANT	\N	PRESENT	0
420919	407833	14115H	PARTICIPANT	\N	PRESENT	0
420920	407833	95063L	PARTICIPANT	\N	PRESENT	0
420921	407833	04044E	PARTICIPANT	\N	PRESENT	0
420922	407833	04047H	PARTICIPANT	\N	PRESENT	0
420923	419131	01048V	PARTICIPANT	\N	PRESENT	0
420924	419131	14277B	PARTICIPANT	\N	PRESENT	0
420925	407833	01043Q	PARTICIPANT	\N	PRESENT	0
420926	407833	14030Q	PARTICIPANT	\N	PRESENT	0
417480	413971	14281W	PARTICIPANT	\N	PRESENT	0
418402	418302	08012N	PARTICIPANT	\N	PRESENT	0
418403	418302	11043H	PARTICIPANT	\N	PRESENT	0
418408	418303	08012N	PARTICIPANT	\N	PRESENT	0
418410	418303	11043H	PARTICIPANT	\N	PRESENT	0
418411	418303	14241N	PARTICIPANT	\N	PRESENT	0
419115	416167	11081P	PARTICIPANT	\N	EXCUSE	0
419116	416167	17589D	PARTICIPANT	\N	EXCUSE	0
419117	416167	19295A	PARTICIPANT	\N	EXCUSE	0
419118	416167	19563B	PARTICIPANT	\N	EXCUSE	0
419119	416166	11081P	PARTICIPANT	\N	EXCUSE	0
419120	416166	17589D	PARTICIPANT	\N	EXCUSE	0
419121	416166	19295A	PARTICIPANT	\N	EXCUSE	0
419122	416166	19563B	PARTICIPANT	\N	EXCUSE	0
419136	405416	14030Q	PRESIDENT	0	PRESENT	0
419138	405416	19367Y	PARTICIPANT	\N	PRESENT	0
419139	405416	08024S	PARTICIPANT	\N	PRESENT	0
419141	405416	19693L	PARTICIPANT	\N	PRESENT	0
419142	405416	14217N	PARTICIPANT	\N	PRESENT	0
419143	405416	19599P	PARTICIPANT	\N	PRESENT	0
419144	405416	14179A	PARTICIPANT	\N	PRESENT	0
419145	405416	19715Y	PARTICIPANT	\N	PRESENT	0
419146	405416	08031R	PARTICIPANT	\N	PRESENT	0
419147	405416	08017T	PARTICIPANT	\N	PRESENT	0
419148	405416	19269X	PARTICIPANT	\N	PRESENT	0
419227	410920	14030Q	PRESIDENT	0	PRESENT	0
419229	410920	08043V	PARTICIPANT	\N	PRESENT	0
419231	410920	08024S	PARTICIPANT	\N	PRESENT	0
419234	410920	19701S	PARTICIPANT	\N	PRESENT	0
419236	410920	11031D	PARTICIPANT	\N	EXCUSE	0
419238	410920	80013X	PARTICIPANT	\N	PRESENT	0
419242	410920	19693L	PARTICIPANT	\N	PRESENT	0
419244	410920	14217N	PARTICIPANT	\N	PRESENT	0
419247	410920	19599P	PARTICIPANT	\N	PRESENT	0
419251	410920	19715Y	PARTICIPANT	\N	PRESENT	0
419256	410920	08031R	PARTICIPANT	\N	PRESENT	0
419261	410920	19749K	PARTICIPANT	\N	PRESENT	0
419414	415093	14133K	PARTICIPANT	\N	PRESENT	0
419415	415093	96004D	PRESIDENT	0	PRESENT	0
419417	415093	14089Y	PARTICIPANT	\N	PRESENT	0
419418	415093	14079W	PARTICIPANT	\N	PRESENT	0
419420	415093	14249W	PARTICIPANT	\N	PRESENT	0
419422	415093	11083R	PARTICIPANT	\N	PRESENT	0
419424	415093	14026U	PARTICIPANT	\N	PRESENT	0
419425	415093	19553Y	PARTICIPANT	\N	PRESENT	0
419427	415093	19569H	PARTICIPANT	\N	PRESENT	0
419429	415093	95037J	PARTICIPANT	\N	PRESENT	0
419430	415093	14097Y	PARTICIPANT	\N	PRESENT	0
419431	415093	14241N	PARTICIPANT	\N	PRESENT	0
419433	415093	14061L	PARTICIPANT	\N	EXCUSE	0
419435	415093	14001X	PARTICIPANT	\N	PRESENT	0
419437	415093	04057K	PARTICIPANT	\N	EXCUSE	0
419438	415093	19563B	PARTICIPANT	\N	EXCUSE	0
419440	415093	14237S	PARTICIPANT	\N	PRESENT	0
419443	415093	10015M	PARTICIPANT	\N	PRESENT	0
419452	415093	08043V	PARTICIPANT	\N	PRESENT	0
419455	415093	97011G	PARTICIPANT	\N	PRESENT	0
419496	419493	19699S	PARTICIPANT	\N	PRESENT	0
419497	419493	08031R	PARTICIPANT	\N	PRESENT	0
419498	419494	08031R	PARTICIPANT	\N	PRESENT	0
419500	419495	08031R	PARTICIPANT	\N	PRESENT	0
419502	419501	14039A	PARTICIPANT	\N	PRESENT	0
419505	419503	11104D	PARTICIPANT	\N	PRESENT	0
419508	419507	14229S	PARTICIPANT	\N	PRESENT	0
419509	419507	19735D	PARTICIPANT	\N	PRESENT	0
419510	419507	08043V	PARTICIPANT	\N	PRESENT	0
419808	419807	04047H	PARTICIPANT	\N	PRESENT	0
419810	419809	04047H	PARTICIPANT	\N	PRESENT	0
419811	419809	11026G	PARTICIPANT	\N	PRESENT	0
419892	419891	11064N	PARTICIPANT	\N	PRESENT	0
419893	419891	11054L	PARTICIPANT	\N	PRESENT	0
420024	407722	11099A	PARTICIPANT	\N	PRESENT	0
420025	407722	14251Q	PARTICIPANT	\N	PRESENT	0
420026	407722	11012A	PARTICIPANT	\N	PRESENT	0
420027	407722	19253P	PARTICIPANT	\N	PRESENT	0
420028	407722	19269X	PARTICIPANT	\N	PRESENT	0
420029	407722	19737F	PARTICIPANT	\N	PRESENT	0
420030	407722	01024M	PARTICIPANT	\N	PRESENT	0
420031	407722	19479G	PARTICIPANT	\N	PRESENT	0
420032	407722	19691J	PARTICIPANT	\N	PRESENT	0
420033	407722	16685X	PARTICIPANT	\N	PRESENT	0
420034	407722	19369B	PARTICIPANT	\N	PRESENT	0
420035	407722	19521Q	PARTICIPANT	\N	PRESENT	0
420036	407722	19762G	PARTICIPANT	\N	PRESENT	0
420037	407722	14357A	PARTICIPANT	\N	PRESENT	0
420038	407722	04043D	PARTICIPANT	\N	PRESENT	0
420039	407722	19711U	PARTICIPANT	\N	PRESENT	0
420040	407722	08069G	PARTICIPANT	\N	PRESENT	0
420054	407722	14085U	PARTICIPANT	\N	PRESENT	0
420055	407722	19631V	PARTICIPANT	\N	PRESENT	0
420056	407722	08056B	PARTICIPANT	\N	PRESENT	0
420057	407722	14217N	PARTICIPANT	\N	PRESENT	0
420058	407722	14147R	PARTICIPANT	\N	PRESENT	0
420059	407722	14041T	PARTICIPANT	\N	PRESENT	0
420060	407722	04085P	PARTICIPANT	\N	PRESENT	0
420061	407722	19441R	PARTICIPANT	\N	PRESENT	0
420062	407722	11097X	PARTICIPANT	\N	PRESENT	0
420227	407808	11027H	PARTICIPANT	\N	PRESENT	0
420228	417482	11067R	PARTICIPANT	\N	PRESENT	0
420229	417482	19649G	PARTICIPANT	\N	PRESENT	0
420230	417482	08034U	PARTICIPANT	\N	PRESENT	0
420231	417482	19569H	PARTICIPANT	\N	PRESENT	0
420232	417482	11045K	PARTICIPANT	\N	PRESENT	0
420233	417482	08052W	PARTICIPANT	\N	PRESENT	0
420234	417482	04045F	PARTICIPANT	\N	PRESENT	0
420235	417482	19447X	PARTICIPANT	\N	PRESENT	0
420236	417482	19553Y	PARTICIPANT	\N	PRESENT	0
420237	417482	14195A	PARTICIPANT	\N	PRESENT	0
420238	417482	14147R	PARTICIPANT	\N	PRESENT	0
420239	417482	11085T	PARTICIPANT	\N	PRESENT	0
420240	417482	99004R	PARTICIPANT	\N	PRESENT	0
420241	417482	10006L	PARTICIPANT	\N	PRESENT	0
420242	417482	14065Q	PARTICIPANT	\N	EXCUSE	0
420243	417482	14041T	PARTICIPANT	\N	EXCUSE	0
420244	417482	19685L	PARTICIPANT	\N	EXCUSE	0
420245	417482	04092N	PRESIDENT	0	PRESENT	0
420246	417482	14215L	PARTICIPANT	\N	PRESENT	0
420247	417482	04085P	PARTICIPANT	\N	PRESENT	0
420248	417482	19683J	PARTICIPANT	\N	PRESENT	0
420252	407808	04038G	PARTICIPANT	\N	PRESENT	0
420253	407808	19333N	PARTICIPANT	\N	PRESENT	0
420254	407808	04040A	PARTICIPANT	\N	PRESENT	0
420255	407808	14231L	PARTICIPANT	\N	PRESENT	0
420256	407808	11012A	PARTICIPANT	\N	PRESENT	0
420258	420257	14147R	PARTICIPANT	\N	PRESENT	0
420259	407808	11101A	PARTICIPANT	\N	PRESENT	0
420261	420260	14147R	PARTICIPANT	\N	PRESENT	0
420262	417482	05008E	PARTICIPANT	\N	PRESENT	0
420263	417482	11031D	PARTICIPANT	\N	PRESENT	0
420264	417482	14239U	PARTICIPANT	\N	PRESENT	0
420265	417482	19575F	PARTICIPANT	\N	PRESENT	0
420266	417482	14213J	PARTICIPANT	\N	PRESENT	0
420267	417482	14217N	PARTICIPANT	\N	PRESENT	0
420268	417482	19335Q	PARTICIPANT	\N	PRESENT	0
420269	407808	01028R	PARTICIPANT	\N	PRESENT	0
420270	407808	98050T	PARTICIPANT	\N	PRESENT	0
420271	407808	95063L	PARTICIPANT	\N	PRESENT	0
420272	407808	14021P	PARTICIPANT	\N	PRESENT	0
420277	407808	19479G	PARTICIPANT	\N	PRESENT	0
420278	407808	11064N	PARTICIPANT	\N	PRESENT	0
420279	407808	14219Q	PARTICIPANT	\N	PRESENT	0
420280	407808	19387D	PARTICIPANT	\N	PRESENT	0
420281	407808	19711U	PARTICIPANT	\N	PRESENT	0
420282	407808	08010L	PARTICIPANT	\N	PRESENT	0
420283	407808	08045X	PARTICIPANT	\N	PRESENT	0
420293	407808	14195A	PARTICIPANT	\N	PRESENT	0
420287	407808	14041T	PARTICIPANT	\N	PRESENT	0
420288	407808	11099A	PARTICIPANT	\N	PRESENT	0
420289	407808	01024M	PARTICIPANT	\N	PRESENT	0
420290	407808	19253P	PARTICIPANT	\N	PRESENT	0
420291	407808	08056B	PARTICIPANT	\N	PRESENT	0
420292	407808	08020N	PARTICIPANT	\N	PRESENT	0
420294	407808	80013X	PARTICIPANT	\N	PRESENT	0
420295	407808	14215L	PARTICIPANT	\N	PRESENT	0
420296	407808	19727D	PARTICIPANT	\N	PRESENT	0
420297	407808	19683J	PARTICIPANT	\N	PRESENT	0
420298	407808	04044E	PARTICIPANT	\N	PRESENT	0
420299	407808	19697Q	PARTICIPANT	\N	PRESENT	0
420300	407808	08061X	PARTICIPANT	\N	PRESENT	0
420301	407808	08052W	PARTICIPANT	\N	PRESENT	0
420302	407808	14213J	PARTICIPANT	\N	PRESENT	0
420304	407808	19511N	PARTICIPANT	\N	PRESENT	0
420307	407808	14239U	PARTICIPANT	\N	PRESENT	0
420309	407808	11067R	PARTICIPANT	\N	PRESENT	0
420311	407808	19649G	PARTICIPANT	\N	PRESENT	0
420314	407808	19663E	PARTICIPANT	\N	PRESENT	0
420315	407808	97011G	PARTICIPANT	\N	PRESENT	0
420317	420316	04049K	PRESIDENT	0	PRESENT	0
397059	395159	19565D	PARTICIPANT	\N	PRESENT	0
397060	395159	04092N	PRESIDENT	0	PRESENT	0
397061	395159	19798U	PARTICIPANT	\N	PRESENT	0
397062	395159	11097X	PARTICIPANT	\N	PRESENT	0
397063	395159	08052W	PARTICIPANT	\N	PRESENT	0
397064	395159	19415P	PARTICIPANT	\N	PRESENT	0
397065	395159	14223L	PARTICIPANT	\N	PRESENT	0
397066	395159	11031D	PARTICIPANT	\N	PRESENT	0
397067	395159	19727D	PARTICIPANT	\N	PRESENT	0
397068	395159	14119M	PARTICIPANT	\N	PRESENT	0
397069	395159	19679N	PARTICIPANT	\N	PRESENT	0
397070	395159	11103C	PARTICIPANT	\N	PRESENT	0
397071	395159	14042U	PARTICIPANT	\N	PRESENT	0
397072	395159	19575F	PARTICIPANT	\N	PRESENT	0
397073	395159	19367Y	PARTICIPANT	\N	PRESENT	0
397074	395159	14213J	PARTICIPANT	\N	PRESENT	0
397075	395159	14261S	PARTICIPANT	\N	PRESENT	0
397076	395159	98024R	PARTICIPANT	\N	PRESENT	0
397077	395159	08041T	PARTICIPANT	\N	EXCUSE	0
397078	395159	17779H	PARTICIPANT	\N	EXCUSE	0
397080	396311	14331P	PARTICIPANT	\N	PRESENT	0
397081	396311	01048V	PARTICIPANT	\N	PRESENT	0
397082	396311	19545Y	PARTICIPANT	\N	PRESENT	0
397083	396311	11053K	PARTICIPANT	\N	PRESENT	0
397084	396311	11074Q	PRESIDENT	0	PRESENT	0
397085	396311	89017R	PARTICIPANT	\N	PRESENT	0
397086	396311	19671E	PARTICIPANT	\N	PRESENT	0
397087	396311	14225N	PARTICIPANT	\N	PRESENT	0
397088	396311	11070L	PARTICIPANT	\N	PRESENT	0
397089	396311	88008L	PARTICIPANT	\N	PRESENT	0
397090	396311	07029T	PARTICIPANT	\N	PRESENT	0
397091	396311	14277B	PARTICIPANT	\N	PRESENT	0
397092	396311	07004J	PARTICIPANT	\N	PRESENT	0
397093	396311	96004D	PARTICIPANT	\N	PRESENT	0
397094	396311	19349W	PARTICIPANT	\N	PRESENT	0
397095	396311	08010L	PARTICIPANT	\N	PRESENT	0
397096	396311	14253S	PARTICIPANT	\N	PRESENT	0
397097	396311	19479G	PARTICIPANT	\N	PRESENT	0
397098	396311	11048N	PARTICIPANT	\N	PRESENT	0
397099	396311	19711U	PARTICIPANT	\N	PRESENT	0
397100	396311	19531S	PARTICIPANT	\N	PRESENT	0
397101	396311	08069G	PARTICIPANT	\N	PRESENT	0
397102	396311	19687N	PARTICIPANT	\N	PRESENT	0
397103	396311	08011M	PARTICIPANT	\N	PRESENT	0
397104	396311	14159V	PARTICIPANT	\N	PRESENT	0
397105	396311	11040E	PARTICIPANT	\N	PRESENT	0
397106	396311	14083S	PARTICIPANT	\N	PRESENT	0
397107	396311	14199E	PARTICIPANT	\N	PRESENT	0
397108	396311	19741B	PARTICIPANT	\N	PRESENT	0
397109	396311	99004R	PARTICIPANT	\N	PRESENT	0
397114	396050	04040A	PARTICIPANT	\N	PRESENT	0
397115	396050	14079W	PARTICIPANT	\N	PRESENT	0
397116	396050	01058X	PARTICIPANT	\N	PRESENT	0
397117	396050	11027H	PARTICIPANT	\N	PRESENT	0
397118	396050	16685X	PARTICIPANT	\N	PRESENT	0
397119	396050	04042C	PRESIDENT	0	PRESENT	0
397120	396050	11066Q	PARTICIPANT	\N	PRESENT	0
397121	396050	08056B	PARTICIPANT	\N	PRESENT	0
397122	396050	95037J	PARTICIPANT	\N	PRESENT	0
397123	396050	19421M	PARTICIPANT	\N	PRESENT	0
397124	396050	19709B	PARTICIPANT	\N	PRESENT	0
397125	396050	08053X	PARTICIPANT	\N	PRESENT	0
397126	396050	97011G	PARTICIPANT	\N	PRESENT	0
397127	396050	08061X	PARTICIPANT	\N	PRESENT	0
397128	396050	08047A	PARTICIPANT	\N	PRESENT	0
397129	396050	98029W	PARTICIPANT	\N	PRESENT	0
397130	396050	04035D	PARTICIPANT	\N	PRESENT	0
397131	396050	14133K	PARTICIPANT	\N	PRESENT	0
397132	396050	01062T	PARTICIPANT	\N	PRESENT	0
397133	396050	11041F	PARTICIPANT	\N	PRESENT	0
397134	396050	14235Q	PARTICIPANT	\N	PRESENT	0
397135	396050	19251M	PARTICIPANT	\N	PRESENT	0
397136	396050	14028W	PARTICIPANT	\N	PRESENT	0
397137	396050	14105F	PARTICIPANT	\N	PRESENT	0
397138	396050	98018T	PARTICIPANT	\N	PRESENT	0
397139	396050	98022P	PARTICIPANT	\N	PRESENT	0
397140	396050	14267Y	PARTICIPANT	\N	PRESENT	0
397141	396050	11064N	PARTICIPANT	\N	PRESENT	0
397142	396050	98050T	PARTICIPANT	\N	PRESENT	0
397143	396050	14211G	PARTICIPANT	\N	PRESENT	0
397144	396050	95030B	PARTICIPANT	\N	PRESENT	0
397145	396050	11054L	PARTICIPANT	\N	PRESENT	0
397146	396050	14097Y	PARTICIPANT	\N	PRESENT	0
397147	396518	19515S	PARTICIPANT	\N	PRESENT	0
397148	396518	19782L	PARTICIPANT	\N	PRESENT	0
397149	396518	14357A	PARTICIPANT	\N	PRESENT	0
397150	396518	14081Q	PARTICIPANT	\N	PRESENT	0
397151	396518	19413M	PARTICIPANT	\N	PRESENT	0
397152	396518	19705W	PARTICIPANT	\N	PRESENT	0
397153	396518	08015R	PARTICIPANT	\N	PRESENT	0
397154	396518	08019V	PARTICIPANT	\N	PRESENT	0
397155	396518	14197C	PARTICIPANT	\N	PRESENT	0
397156	396518	19369B	PARTICIPANT	\N	PRESENT	0
397157	396518	19563B	PARTICIPANT	\N	PRESENT	0
397158	396518	14265W	PARTICIPANT	\N	PRESENT	0
397159	396518	14329V	PARTICIPANT	\N	PRESENT	0
397160	396518	14135M	PARTICIPANT	\N	PRESENT	0
397161	396518	19467C	PARTICIPANT	\N	PRESENT	0
397162	396518	14187A	PARTICIPANT	\N	PRESENT	0
397163	396518	08062Y	PARTICIPANT	\N	PRESENT	0
397164	396518	19695N	PARTICIPANT	\N	PRESENT	0
397165	396518	14033T	PARTICIPANT	\N	PRESENT	0
397166	396518	11090Q	PRESIDENT	0	PRESENT	0
397167	396518	19269X	PARTICIPANT	\N	PRESENT	0
397168	396518	14205J	PARTICIPANT	\N	PRESENT	0
397169	396518	04088S	PARTICIPANT	\N	PRESENT	0
397170	396518	11056N	PARTICIPANT	\N	PRESENT	0
397171	396518	14115H	PARTICIPANT	\N	PRESENT	0
397172	396518	19507S	PARTICIPANT	\N	PRESENT	0
397173	396518	19747H	PARTICIPANT	\N	PRESENT	0
397174	396518	14207L	PARTICIPANT	\N	PRESENT	0
397175	396518	14257W	PARTICIPANT	\N	PRESENT	0
397176	396518	80013X	PARTICIPANT	\N	EXCUSE	0
397177	396518	19295A	PARTICIPANT	\N	EXCUSE	0
397178	396518	08028W	PARTICIPANT	\N	EXCUSE	0
397179	396518	11081P	PARTICIPANT	\N	EXCUSE	0
397180	396518	17589D	PARTICIPANT	\N	EXCUSE	0
397185	396050	08058D	PARTICIPANT	\N	PRESENT	0
397186	396050	14193X	PARTICIPANT	\N	PRESENT	0
397187	396050	95067Q	PARTICIPANT	\N	PRESENT	0
397188	396050	04034C	PARTICIPANT	\N	PRESENT	0
397284	396435	01057W	PARTICIPANT	\N	PRESENT	0
397285	396435	19689Q	PARTICIPANT	\N	PRESENT	0
397305	393394	19251M	PARTICIPANT	\N	PRESENT	0
397306	393394	14105F	PARTICIPANT	\N	PRESENT	0
397307	393394	11077T	PARTICIPANT	\N	PRESENT	0
397308	393394	04034C	PARTICIPANT	\N	PRESENT	0
397309	397297	14097Y	PARTICIPANT	\N	PRESENT	0
397310	397297	95067Q	PARTICIPANT	\N	EXCUSE	0
397311	397297	08038Y	PARTICIPANT	\N	PRESENT	0
397312	397297	14033T	PARTICIPANT	\N	PRESENT	0
397313	397297	14051J	PARTICIPANT	\N	PRESENT	0
397314	397297	08060W	PARTICIPANT	\N	PRESENT	0
397315	397297	19629C	PARTICIPANT	\N	PRESENT	0
397316	397297	08049C	PARTICIPANT	\N	PRESENT	0
397317	397297	19347U	PARTICIPANT	\N	PRESENT	0
397318	397297	08019V	PARTICIPANT	\N	PRESENT	0
397319	397297	14157T	PRESIDENT	0	PRESENT	0
397320	397297	19745F	PARTICIPANT	\N	PRESENT	0
397321	397297	19369B	PARTICIPANT	\N	PRESENT	0
397322	397297	14207L	PARTICIPANT	\N	PRESENT	0
397323	397297	19747H	PARTICIPANT	\N	PRESENT	0
397324	397297	08024S	PARTICIPANT	\N	PRESENT	0
397325	397297	19762G	PARTICIPANT	\N	PRESENT	0
397326	397297	19715Y	PARTICIPANT	\N	EXCUSE	0
397327	397297	19721W	PARTICIPANT	\N	EXCUSE	0
397328	393394	19709B	PARTICIPANT	\N	PRESENT	0
397329	393394	96004D	PARTICIPANT	\N	PRESENT	0
397330	393394	98022P	PARTICIPANT	\N	PRESENT	0
397331	393394	07029T	PARTICIPANT	\N	PRESENT	0
397332	393394	19711U	PARTICIPANT	\N	PRESENT	0
397333	393394	11064N	PARTICIPANT	\N	PRESENT	0
397334	393394	11026G	PARTICIPANT	\N	PRESENT	0
397335	393394	14061L	PARTICIPANT	\N	PRESENT	0
397336	393394	08017T	PARTICIPANT	\N	PRESENT	0
397337	393394	19399H	PARTICIPANT	\N	PRESENT	0
397338	393394	14259Y	PARTICIPANT	\N	PRESENT	0
397339	393394	04042C	PARTICIPANT	\N	PRESENT	0
397340	393394	08047A	PARTICIPANT	\N	PRESENT	0
397341	393394	19349W	PARTICIPANT	\N	PRESENT	0
397342	393394	15447F	PARTICIPANT	\N	PRESENT	0
397343	393394	19467C	PARTICIPANT	\N	PRESENT	0
397344	393394	14241N	PARTICIPANT	\N	PRESENT	0
397345	393394	16685X	PARTICIPANT	\N	PRESENT	0
397346	393394	08010L	PARTICIPANT	\N	PRESENT	0
397347	393394	01058X	PARTICIPANT	\N	PRESENT	0
397348	393394	14069U	PARTICIPANT	\N	PRESENT	0
397349	393394	97011G	PARTICIPANT	\N	PRESENT	0
397350	393394	19575F	PARTICIPANT	\N	PRESENT	0
409208	408286	14121F	PARTICIPANT	\N	PRESENT	0
409210	408286	19681G	PARTICIPANT	\N	PRESENT	0
409211	408286	19762G	PARTICIPANT	\N	PRESENT	0
409212	408286	19717B	PARTICIPANT	\N	PRESENT	0
409213	408286	19553Y	PARTICIPANT	\N	PRESENT	0
409214	408286	04057K	PARTICIPANT	\N	PRESENT	0
409215	408286	02002K	PARTICIPANT	\N	PRESENT	0
409216	408286	14111D	PARTICIPANT	\N	PRESENT	0
409217	408286	19585H	PARTICIPANT	\N	PRESENT	0
409218	408286	14195A	PARTICIPANT	\N	PRESENT	0
409219	408286	19701S	PARTICIPANT	\N	PRESENT	0
409220	408286	11064N	PARTICIPANT	\N	PRESENT	0
409221	408286	19621T	PARTICIPANT	\N	PRESENT	0
409222	408286	98005N	PARTICIPANT	\N	PRESENT	0
409223	408286	19367Y	PARTICIPANT	\N	PRESENT	0
409224	408286	19583F	PARTICIPANT	\N	PRESENT	0
409225	408286	14251Q	PARTICIPANT	\N	PRESENT	0
409226	408286	14173T	PARTICIPANT	\N	PRESENT	0
409227	408286	19447X	PARTICIPANT	\N	PRESENT	0
409228	408286	19563B	PARTICIPANT	\N	PRESENT	0
409229	408286	19573D	PARTICIPANT	\N	PRESENT	0
409230	408286	19794Q	PARTICIPANT	\N	PRESENT	0
409231	408286	14133K	PARTICIPANT	\N	PRESENT	0
409232	408286	92040Q	PARTICIPANT	\N	PRESENT	0
409233	408286	14119M	PARTICIPANT	\N	PRESENT	0
409234	408286	11049P	PARTICIPANT	\N	PRESENT	0
409235	408286	89017R	PARTICIPANT	\N	PRESENT	0
409236	408286	19685L	PARTICIPANT	\N	PRESENT	0
409237	408286	14115H	PARTICIPANT	\N	PRESENT	0
409238	408286	19731Y	PARTICIPANT	\N	PRESENT	0
409239	408286	01060R	PARTICIPANT	\N	PRESENT	0
409240	408286	08047A	PARTICIPANT	\N	PRESENT	0
409241	408286	08056B	PARTICIPANT	\N	PRESENT	0
409242	408286	14105F	PARTICIPANT	\N	PRESENT	0
409243	408286	14055N	PARTICIPANT	\N	PRESENT	0
409245	408286	14147R	PARTICIPANT	\N	PRESENT	0
409246	408286	19826F	PARTICIPANT	\N	PRESENT	0
409247	408286	11103C	PARTICIPANT	\N	PRESENT	0
409248	408286	07033P	PARTICIPANT	\N	PRESENT	0
409249	408286	14217N	PARTICIPANT	\N	PRESENT	0
409250	408286	04059M	PARTICIPANT	\N	PRESENT	0
409251	408286	11074Q	PARTICIPANT	\N	PRESENT	0
409252	408286	04069P	PARTICIPANT	\N	PRESENT	0
409253	408286	14331P	PARTICIPANT	\N	PRESENT	0
409254	408286	19671E	PARTICIPANT	\N	PRESENT	0
409255	408286	19581D	PARTICIPANT	\N	PRESENT	0
409256	408286	19747H	PARTICIPANT	\N	PRESENT	0
409257	408286	19703U	PARTICIPANT	\N	PRESENT	0
409258	408286	19673G	PARTICIPANT	\N	PRESENT	0
409259	408286	11010L	PARTICIPANT	\N	PRESENT	0
409260	408286	14031R	PARTICIPANT	\N	PRESENT	0
409261	408286	19667J	PARTICIPANT	\N	PRESENT	0
409262	408286	14253S	PARTICIPANT	\N	PRESENT	0
409263	408286	11048N	PARTICIPANT	\N	PRESENT	0
409264	408286	04049K	PARTICIPANT	\N	PRESENT	0
409265	408286	05012A	PARTICIPANT	\N	PRESENT	0
409266	408286	08034U	PARTICIPANT	\N	PRESENT	0
409267	408286	19533U	PARTICIPANT	\N	PRESENT	0
409268	408286	11027H	PARTICIPANT	\N	PRESENT	0
409269	408286	10006L	PARTICIPANT	\N	PRESENT	0
409270	408286	19798U	PARTICIPANT	\N	PRESENT	0
409271	408286	98035U	PARTICIPANT	\N	PRESENT	0
409272	408286	08052W	PARTICIPANT	\N	PRESENT	0
409273	408286	14193X	PARTICIPANT	\N	PRESENT	0
409274	408286	14237S	PARTICIPANT	\N	PRESENT	0
409275	408286	08055A	PARTICIPANT	\N	PRESENT	0
409276	408286	19515S	PARTICIPANT	\N	PRESENT	0
409277	408286	14191V	PARTICIPANT	\N	PRESENT	0
409278	408286	14229S	PARTICIPANT	\N	PRESENT	0
409279	408286	01028R	PARTICIPANT	\N	PRESENT	0
409280	408286	11080N	PARTICIPANT	\N	PRESENT	0
409281	408286	08068F	PARTICIPANT	\N	PRESENT	0
409282	408286	19766L	PARTICIPANT	\N	PRESENT	0
409283	408286	14021P	PARTICIPANT	\N	PRESENT	0
409284	408286	14259Y	PARTICIPANT	\N	PRESENT	0
409285	408286	14225N	PARTICIPANT	\N	PRESENT	0
409286	408286	01057W	PARTICIPANT	\N	PRESENT	0
409287	408286	19599P	PARTICIPANT	\N	PRESENT	0
409288	408286	95067Q	PARTICIPANT	\N	PRESENT	0
409289	408286	19715Y	PARTICIPANT	\N	PRESENT	0
409290	408286	14069U	PARTICIPANT	\N	PRESENT	0
409291	408286	12016W	PARTICIPANT	\N	PRESENT	0
409292	408286	14053L	PARTICIPANT	\N	PRESENT	0
409293	408286	14151M	PARTICIPANT	\N	PRESENT	0
409294	408286	01062T	PARTICIPANT	\N	PRESENT	0
409295	408286	14087W	PARTICIPANT	\N	PRESENT	0
409296	408286	08014Q	PARTICIPANT	\N	PRESENT	0
409297	408286	08060W	PARTICIPANT	\N	PRESENT	0
409298	408286	14215L	PARTICIPANT	\N	PRESENT	0
409299	408286	08038Y	PARTICIPANT	\N	PRESENT	0
409300	408286	15447F	PARTICIPANT	\N	PRESENT	0
409301	408286	80013X	PARTICIPANT	\N	PRESENT	0
409302	408286	14028W	PARTICIPANT	\N	PRESENT	0
409303	408286	11045K	PARTICIPANT	\N	PRESENT	0
409304	408286	19643A	PARTICIPANT	\N	PRESENT	0
409305	408286	11041F	PARTICIPANT	\N	PRESENT	0
409306	408286	11066Q	PARTICIPANT	\N	PRESENT	0
409307	408286	04071H	PARTICIPANT	\N	PRESENT	0
409308	408286	14281W	PARTICIPANT	\N	PRESENT	0
409309	408286	10015M	PARTICIPANT	\N	PRESENT	0
409310	408286	08012N	PARTICIPANT	\N	PRESENT	0
409311	408286	11043H	PARTICIPANT	\N	PRESENT	0
409312	408286	19727D	PARTICIPANT	\N	PRESENT	0
409313	408286	14081Q	PARTICIPANT	\N	PRESENT	0
409314	408286	11110B	PARTICIPANT	\N	PRESENT	0
409315	408286	14257W	PARTICIPANT	\N	PRESENT	0
409316	408286	08028W	PARTICIPANT	\N	PRESENT	0
409317	408286	19525U	PARTICIPANT	\N	PRESENT	0
409318	408286	08017T	PARTICIPANT	\N	PRESENT	0
409319	408286	14085U	PARTICIPANT	\N	PRESENT	0
409320	408286	17583W	PARTICIPANT	\N	PRESENT	0
409321	408286	08058D	PARTICIPANT	\N	PRESENT	0
409322	408286	14065Q	PARTICIPANT	\N	PRESENT	0
409323	408286	19549D	PARTICIPANT	\N	PRESENT	0
409324	408286	04033B	PARTICIPANT	\N	PRESENT	0
409325	408286	14187A	PARTICIPANT	\N	PRESENT	0
409326	408286	17779H	PARTICIPANT	\N	PRESENT	0
409327	408286	05008E	PARTICIPANT	\N	PRESENT	0
409328	408286	19489J	PARTICIPANT	\N	PRESENT	0
409329	408286	19725B	PARTICIPANT	\N	PRESENT	0
409330	408286	11097X	PARTICIPANT	\N	PRESENT	0
409331	408286	19333N	PARTICIPANT	\N	PRESENT	0
409332	408286	19421M	PARTICIPANT	\N	PRESENT	0
409333	408286	14001X	PARTICIPANT	\N	PRESENT	0
409334	408286	14227Q	PARTICIPANT	\N	PRESENT	0
409335	408286	19679N	PARTICIPANT	\N	PRESENT	0
409336	408286	11109J	PARTICIPANT	\N	PRESENT	0
409337	408286	19295A	PARTICIPANT	\N	PRESENT	0
409338	408286	04097T	PARTICIPANT	\N	PRESENT	0
409339	408286	08039A	PARTICIPANT	\N	PRESENT	0
409340	408286	11054L	PARTICIPANT	\N	PRESENT	0
409341	408286	08020N	PARTICIPANT	\N	PRESENT	0
409342	408286	14097Y	PARTICIPANT	\N	PRESENT	0
409343	408286	14063N	PARTICIPANT	\N	PRESENT	0
409344	408286	08010L	PARTICIPANT	\N	PRESENT	0
409345	408286	14109K	PARTICIPANT	\N	PRESENT	0
409346	408286	14123H	PARTICIPANT	\N	PRESENT	0
409347	408286	19527W	PARTICIPANT	\N	PRESENT	0
409348	408286	04042C	PARTICIPANT	\N	PRESENT	0
409349	408286	19551W	PARTICIPANT	\N	PRESENT	0
409350	408286	04086Q	PARTICIPANT	\N	PRESENT	0
409351	408286	11067R	PARTICIPANT	\N	PRESENT	0
409352	408286	19820Y	PARTICIPANT	\N	PRESENT	0
409353	408286	04092N	PARTICIPANT	\N	PRESENT	0
409354	408286	19591F	PARTICIPANT	\N	PRESENT	0
409355	408286	11026G	PARTICIPANT	\N	PRESENT	0
409356	408286	98018T	PARTICIPANT	\N	PRESENT	0
409357	408286	19251M	PARTICIPANT	\N	PRESENT	0
409358	408286	04044E	PARTICIPANT	\N	PRESENT	0
409359	408286	19689Q	PARTICIPANT	\N	PRESENT	0
409360	408286	19713W	PARTICIPANT	\N	PRESENT	0
409361	408286	08011M	PARTICIPANT	\N	PRESENT	0
409362	408286	14157T	PARTICIPANT	\N	PRESENT	0
409363	408286	14231L	PARTICIPANT	\N	PRESENT	0
409364	408286	96004D	PARTICIPANT	\N	PRESENT	0
409365	408286	04089T	PARTICIPANT	\N	PRESENT	0
409366	408286	99004R	PARTICIPANT	\N	PRESENT	0
409367	408286	95030B	PARTICIPANT	\N	PRESENT	0
409368	408286	08044W	PARTICIPANT	\N	PRESENT	0
409369	408286	04047H	PARTICIPANT	\N	PRESENT	0
409370	408286	14179A	PARTICIPANT	\N	PRESENT	0
409371	408286	14026U	PARTICIPANT	\N	PRESENT	0
409372	408286	19369B	PARTICIPANT	\N	PRESENT	0
409373	408286	19691J	PARTICIPANT	\N	PRESENT	0
409374	408286	11101A	PARTICIPANT	\N	PRESENT	0
409375	408286	11053K	PARTICIPANT	\N	PRESENT	0
409376	408286	04035D	PARTICIPANT	\N	PRESENT	0
409377	408286	19611R	PARTICIPANT	\N	PRESENT	0
405684	405683	14063N	PARTICIPANT	\N	PRESENT	0
405685	405683	14073Q	PARTICIPANT	\N	PRESENT	0
405687	405686	14073Q	PARTICIPANT	\N	PRESENT	0
405688	405686	14063N	PARTICIPANT	\N	PRESENT	0
405689	405686	14229S	PARTICIPANT	\N	PRESENT	0
413264	412265	11048N	PARTICIPANT	\N	EXCUSE	0
413265	412265	04086Q	PARTICIPANT	\N	EXCUSE	0
413317	412265	14195A	PARTICIPANT	\N	EXCUSE	0
413954	413952	14065Q	PARTICIPANT	\N	PRESENT	0
413955	413952	10015M	PARTICIPANT	\N	PRESENT	0
413956	413953	14065Q	PARTICIPANT	\N	PRESENT	0
413957	413953	10015M	PARTICIPANT	\N	PRESENT	0
413961	413960	19729F	PARTICIPANT	\N	PRESENT	0
413963	413962	08014Q	PARTICIPANT	\N	PRESENT	0
413964	413962	08069G	PARTICIPANT	\N	PRESENT	0
413966	413965	19479G	PARTICIPANT	\N	PRESENT	0
413968	413967	08011M	PARTICIPANT	\N	PRESENT	0
413974	413973	08010L	PARTICIPANT	\N	PRESENT	0
413976	413975	11048N	PARTICIPANT	\N	PRESENT	0
413978	413977	14083S	PARTICIPANT	\N	PRESENT	0
413980	413979	19647E	PARTICIPANT	\N	PRESENT	0
413981	413979	11070L	PARTICIPANT	\N	PRESENT	0
413983	413982	11070L	PARTICIPANT	\N	PRESENT	0
413984	413982	19647E	PARTICIPANT	\N	PRESENT	0
413987	413986	19647E	PARTICIPANT	\N	PRESENT	0
413993	413992	14121F	PARTICIPANT	\N	PRESENT	0
414003	414002	19711U	PARTICIPANT	\N	PRESENT	0
414005	414004	19711U	PARTICIPANT	\N	PRESENT	0
414007	414006	19711U	PARTICIPANT	\N	PRESENT	0
414009	414008	08011M	PARTICIPANT	\N	PRESENT	0
414011	414010	07004J	PARTICIPANT	\N	PRESENT	0
414013	414012	07004J	PARTICIPANT	\N	PRESENT	0
414735	413507	11097X	PARTICIPANT	\N	EXCUSE	0
414736	413507	14042U	PARTICIPANT	\N	EXCUSE	0
414841	414835	19515S	PARTICIPANT	\N	PRESENT	0
414842	414835	08055A	PARTICIPANT	\N	PRESENT	0
414843	414835	14105F	PARTICIPANT	\N	PRESENT	0
414844	414835	07033P	PARTICIPANT	\N	PRESENT	0
414845	414835	14026U	PARTICIPANT	\N	PRESENT	0
414846	414835	14213J	PARTICIPANT	\N	PRESENT	0
414847	414835	14061L	PARTICIPANT	\N	PRESENT	0
414848	414835	04049K	PARTICIPANT	\N	PRESENT	0
414849	414835	19723Y	PARTICIPANT	\N	PRESENT	0
414850	414835	08015R	PARTICIPANT	\N	PRESENT	0
414851	414835	19441R	PARTICIPANT	\N	PRESENT	0
414852	414835	14257W	PARTICIPANT	\N	PRESENT	0
414853	414835	19745F	PARTICIPANT	\N	PRESENT	0
414854	414835	11097X	PARTICIPANT	\N	PRESENT	0
414884	408325	19421M	PARTICIPANT	\N	EXCUSE	0
415565	408325	02002K	PARTICIPANT	\N	EXCUSE	0
420928	419131	14121F	PARTICIPANT	\N	PRESENT	0
419008	418965	01034P	PARTICIPANT	\N	PRESENT	0
420927	407833	01025N	PARTICIPANT	\N	PRESENT	0
420929	407833	19745F	PARTICIPANT	\N	PRESENT	0
420930	407833	01060R	PARTICIPANT	\N	PRESENT	0
420931	407833	19599P	PARTICIPANT	\N	PRESENT	0
420932	407833	14255U	PARTICIPANT	\N	PRESENT	0
420933	407833	14031R	PARTICIPANT	\N	PRESENT	0
420934	407833	08069G	PARTICIPANT	\N	PRESENT	0
420935	407833	04049K	PARTICIPANT	\N	PRESENT	0
420936	407833	11080N	PARTICIPANT	\N	PRESENT	0
420937	419131	07029T	PARTICIPANT	\N	PRESENT	0
420938	419131	14331P	PARTICIPANT	\N	PRESENT	0
420939	419131	14083S	PARTICIPANT	\N	PRESENT	0
420940	419131	14085U	PARTICIPANT	\N	PRESENT	0
420941	419131	07004J	PARTICIPANT	\N	PRESENT	0
420942	419131	08010L	PARTICIPANT	\N	PRESENT	0
420943	419131	14253S	PARTICIPANT	\N	PRESENT	0
420944	419131	89017R	PARTICIPANT	\N	PRESENT	0
420945	419131	19671E	PARTICIPANT	\N	PRESENT	0
420946	419131	19531S	PARTICIPANT	\N	PRESENT	0
420947	407833	08035V	PARTICIPANT	\N	PRESENT	0
420948	407833	14199E	PARTICIPANT	\N	PRESENT	0
420949	407833	19747H	PARTICIPANT	\N	PRESENT	0
420950	407833	19369B	PARTICIPANT	\N	PRESENT	0
420951	419131	14327T	PARTICIPANT	\N	PRESENT	0
420952	419131	11048N	PARTICIPANT	\N	PRESENT	0
420964	419131	01057W	PARTICIPANT	\N	PRESENT	0
420965	407833	11010L	PARTICIPANT	\N	PRESENT	0
420966	419131	19741B	PARTICIPANT	\N	PRESENT	0
420967	407833	14257W	PARTICIPANT	\N	PRESENT	0
420974	407833	14133K	PARTICIPANT	\N	PRESENT	0
420975	407833	17583W	PARTICIPANT	\N	PRESENT	0
420976	407833	11090Q	PARTICIPANT	\N	PRESENT	0
420977	419131	99004R	PARTICIPANT	\N	PRESENT	0
420978	407833	14221J	PARTICIPANT	\N	PRESENT	0
420979	407833	19820Y	PARTICIPANT	\N	PRESENT	0
420980	419131	08069G	PARTICIPANT	\N	PRESENT	0
420982	420981	14053L	PARTICIPANT	\N	PRESENT	0
420983	420981	11048N	PRESIDENT	0	PRESENT	0
420984	420981	08060W	PARTICIPANT	\N	PRESENT	0
420985	420981	19367Y	PARTICIPANT	\N	PRESENT	0
420986	420981	19826F	PARTICIPANT	\N	PRESENT	0
420987	407833	19387D	PARTICIPANT	\N	PRESENT	0
420988	407833	05008E	PARTICIPANT	\N	PRESENT	0
420989	407833	19683J	PARTICIPANT	\N	PRESENT	0
420990	419131	19711U	PARTICIPANT	\N	PRESENT	0
420991	419131	19479G	PARTICIPANT	\N	PRESENT	0
420992	407833	19563B	PARTICIPANT	\N	PRESENT	0
420993	407833	19725B	PARTICIPANT	\N	PRESENT	0
420994	407833	14063N	PARTICIPANT	\N	PRESENT	0
420995	407833	80013X	PARTICIPANT	\N	PRESENT	0
420996	407833	14069U	PARTICIPANT	\N	PRESENT	0
420997	407833	01028R	PARTICIPANT	\N	PRESENT	0
422895	422894	11048N	PARTICIPANT	\N	PRESENT	0
422897	422896	19711U	PARTICIPANT	\N	PRESENT	0
422899	422898	11048N	PARTICIPANT	\N	PRESENT	0
422948	414079	19723Y	PARTICIPANT	\N	PRESENT	0
422957	421729	04045F	PARTICIPANT	\N	EXCUSE	0
422958	414079	08053X	PARTICIPANT	\N	EXCUSE	0
422990	422989	19820Y	PARTICIPANT	\N	PRESENT	0
422991	422989	14093U	PARTICIPANT	\N	PRESENT	0
422997	422995	19729F	PARTICIPANT	\N	EXCUSE	0
422998	422995	11010L	PARTICIPANT	\N	EXCUSE	0
422999	422995	14021P	PARTICIPANT	\N	EXCUSE	0
423000	422995	14135M	PARTICIPANT	\N	EXCUSE	0
423001	421729	19253P	PARTICIPANT	\N	EXCUSE	0
423008	422451	19697Q	PARTICIPANT	\N	PRESENT	0
423009	422451	11067R	PARTICIPANT	\N	PRESENT	0
423010	422451	04092N	PRESIDENT	0	PRESENT	0
423011	422451	19569H	PARTICIPANT	\N	PRESENT	0
423012	422451	19798U	PARTICIPANT	\N	PRESENT	0
423013	422451	19663E	PARTICIPANT	\N	PRESENT	0
423014	422451	19715Y	PARTICIPANT	\N	PRESENT	0
423015	422451	04045F	PARTICIPANT	\N	PRESENT	0
423016	422451	19723Y	PARTICIPANT	\N	PRESENT	0
423017	422451	19727D	PARTICIPANT	\N	PRESENT	0
423018	422451	19703U	PARTICIPANT	\N	PRESENT	0
423019	422451	14239U	PARTICIPANT	\N	PRESENT	0
423020	422451	14119M	PARTICIPANT	\N	PRESENT	0
423021	422451	14087W	PARTICIPANT	\N	PRESENT	0
423022	422451	14042U	PARTICIPANT	\N	PRESENT	0
423023	422451	08048B	PARTICIPANT	\N	PRESENT	0
423024	422451	14213J	PARTICIPANT	\N	PRESENT	0
423025	422451	14071N	PARTICIPANT	\N	PRESENT	0
423026	422451	14217N	PARTICIPANT	\N	PRESENT	0
423027	422451	19521Q	PARTICIPANT	\N	PRESENT	0
423028	422451	19565D	PARTICIPANT	\N	EXCUSE	0
423029	422451	14195A	PARTICIPANT	\N	EXCUSE	0
423030	422451	08041T	PARTICIPANT	\N	EXCUSE	0
423053	423007	11067R	PARTICIPANT	\N	PRESENT	0
423054	423007	19649G	PARTICIPANT	\N	PRESENT	0
423055	423007	04092N	PRESIDENT	0	PRESENT	0
423056	423007	19569H	PARTICIPANT	\N	PRESENT	0
423057	423007	11045K	PARTICIPANT	\N	PRESENT	0
423058	423007	08052W	PARTICIPANT	\N	PRESENT	0
423059	423007	08043V	PARTICIPANT	\N	PRESENT	0
423060	423007	19415P	PARTICIPANT	\N	PRESENT	0
423061	423007	04045F	PARTICIPANT	\N	PRESENT	0
423062	423007	11066Q	PARTICIPANT	\N	PRESENT	0
423063	423007	19447X	PARTICIPANT	\N	PRESENT	0
423064	423007	14239U	PARTICIPANT	\N	PRESENT	0
423065	423007	11031D	PARTICIPANT	\N	PRESENT	0
423066	423007	14041T	PARTICIPANT	\N	PRESENT	0
423067	423007	14042U	PARTICIPANT	\N	PRESENT	0
423068	423007	19575F	PARTICIPANT	\N	PRESENT	0
423069	423007	14213J	PARTICIPANT	\N	PRESENT	0
423070	423007	14215L	PARTICIPANT	\N	PRESENT	0
423071	423007	99004R	PARTICIPANT	\N	PRESENT	0
423072	423007	14217N	PARTICIPANT	\N	PRESENT	0
423073	423007	19681G	PARTICIPANT	\N	PRESENT	0
423074	423007	10006L	PARTICIPANT	\N	PRESENT	0
423075	423007	19683J	PARTICIPANT	\N	PRESENT	0
423076	423007	14195A	PARTICIPANT	\N	EXCUSE	0
423077	423007	14147R	PARTICIPANT	\N	PRESENT	0
423078	416129	14237S	PARTICIPANT	\N	PRESENT	0
423079	416129	14063N	PARTICIPANT	\N	PRESENT	0
423080	416129	19599P	PARTICIPANT	\N	PRESENT	0
423081	416129	19737F	PARTICIPANT	\N	PRESENT	0
419890	419889	08019V	PARTICIPANT	\N	PRESENT	0
420139	407723	14215L	PARTICIPANT	\N	PRESENT	0
420318	420316	14038Y	PARTICIPANT	\N	PRESENT	0
420319	420316	14169X	PARTICIPANT	\N	PRESENT	0
420320	420316	14107H	PARTICIPANT	\N	PRESENT	0
420321	420316	08049C	PARTICIPANT	\N	PRESENT	0
420322	420316	19631V	PARTICIPANT	\N	PRESENT	0
420323	407808	19441R	PARTICIPANT	\N	PRESENT	0
420324	420316	08060W	PARTICIPANT	\N	EXCUSE	0
420325	420316	14105F	PARTICIPANT	\N	EXCUSE	0
420326	420316	14255U	PARTICIPANT	\N	EXCUSE	0
420327	420316	14053L	PARTICIPANT	\N	EXCUSE	0
420328	420316	19545Y	PARTICIPANT	\N	EXCUSE	0
420329	420316	14041T	PARTICIPANT	\N	EXCUSE	0
420330	420316	14034U	PARTICIPANT	\N	EXCUSE	0
420331	420316	14121F	PARTICIPANT	\N	EXCUSE	0
420333	420316	14061L	PARTICIPANT	\N	EXCUSE	0
420335	420316	08015R	PARTICIPANT	\N	EXCUSE	0
420336	420316	19697Q	PARTICIPANT	\N	EXCUSE	0
420337	420316	14051J	PARTICIPANT	\N	EXCUSE	0
420339	420338	04049K	PRESIDENT	0	PRESENT	0
420340	420338	14038Y	PARTICIPANT	\N	PRESENT	0
420341	420338	19575F	PARTICIPANT	\N	EXCUSE	0
420342	420338	14105F	PARTICIPANT	\N	EXCUSE	0
420343	420338	14053L	PARTICIPANT	\N	EXCUSE	0
420344	420338	19545Y	PARTICIPANT	\N	EXCUSE	0
420345	420338	14041T	PARTICIPANT	\N	EXCUSE	0
420380	420338	08015R	PARTICIPANT	\N	EXCUSE	0
420381	420338	19697Q	PARTICIPANT	\N	EXCUSE	0
420383	420338	14051J	PARTICIPANT	\N	EXCUSE	0
420385	420338	14157T	PARTICIPANT	\N	EXCUSE	0
420396	420338	14034U	PARTICIPANT	\N	EXCUSE	0
420424	420423	04035D	PARTICIPANT	\N	PRESENT	0
420425	407829	95063L	PARTICIPANT	\N	PRESENT	0
420426	407829	19333N	PARTICIPANT	\N	PRESENT	0
420427	407829	19543W	PARTICIPANT	\N	PRESENT	0
420428	407829	19545Y	PARTICIPANT	\N	PRESENT	0
420429	407829	08031R	PARTICIPANT	\N	PRESENT	0
420430	407829	14215L	PARTICIPANT	\N	PRESENT	0
420431	407829	04038G	PARTICIPANT	\N	PRESENT	0
420432	407829	04034C	PARTICIPANT	\N	PRESENT	0
420434	407829	08061X	PARTICIPANT	\N	PRESENT	0
420435	420433	95041E	PARTICIPANT	\N	PRESENT	0
420436	407829	01028R	PARTICIPANT	\N	PRESENT	0
420437	407829	99004R	PARTICIPANT	\N	PRESENT	0
420438	407829	08045X	PARTICIPANT	\N	PRESENT	0
420439	407829	19335Q	PARTICIPANT	\N	PRESENT	0
420440	407829	01024M	PARTICIPANT	\N	PRESENT	0
420441	407829	07004J	PARTICIPANT	\N	PRESENT	0
420442	407829	04044E	PARTICIPANT	\N	PRESENT	0
420443	407829	05008E	PARTICIPANT	\N	PRESENT	0
420444	407829	04085P	PARTICIPANT	\N	PRESENT	0
420445	407829	08020N	PARTICIPANT	\N	PRESENT	0
420446	407829	19447X	PARTICIPANT	\N	PRESENT	0
420447	407829	19651A	PARTICIPANT	\N	PRESENT	0
420449	420448	95067Q	PARTICIPANT	\N	PRESENT	0
420450	420448	01048V	PARTICIPANT	\N	PRESENT	0
420451	420448	11026G	PARTICIPANT	\N	PRESENT	0
420452	420448	19253P	PARTICIPANT	\N	PRESENT	0
420378	420338	14061L	PARTICIPANT	\N	EXCUSE	0
420379	407829	04086Q	PARTICIPANT	\N	PRESENT	0
420453	420448	16685X	PARTICIPANT	\N	PRESENT	0
420454	407829	19711U	PARTICIPANT	\N	PRESENT	0
420455	420448	19647E	PARTICIPANT	\N	PRESENT	0
420456	407829	14219Q	PARTICIPANT	\N	PRESENT	0
420457	407829	98050T	PARTICIPANT	\N	PRESENT	0
420485	420483	19651A	PARTICIPANT	\N	PRESENT	0
420486	407810	19333N	PARTICIPANT	\N	PRESENT	0
420487	407810	08045X	PARTICIPANT	\N	PRESENT	0
420488	407810	19545Y	PARTICIPANT	\N	PRESENT	0
420489	407810	14215L	PARTICIPANT	\N	PRESENT	0
420490	407810	07004J	PARTICIPANT	\N	PRESENT	0
420491	407810	05008E	PARTICIPANT	\N	PRESENT	0
420492	407810	01024M	PARTICIPANT	\N	PRESENT	0
420493	407810	04044E	PARTICIPANT	\N	PRESENT	0
420494	407810	04085P	PARTICIPANT	\N	PRESENT	0
420495	407810	08031R	PARTICIPANT	\N	PRESENT	0
420496	407810	19651A	PARTICIPANT	\N	PRESENT	0
420497	407810	19543W	PARTICIPANT	\N	PRESENT	0
420498	407810	08061X	PARTICIPANT	\N	PRESENT	0
420500	407810	11115U	PARTICIPANT	\N	PRESENT	0
420501	420499	95041E	PARTICIPANT	\N	PRESENT	0
420502	407810	19447X	PARTICIPANT	\N	PRESENT	0
420507	407810	19253P	PARTICIPANT	\N	PRESENT	0
420510	407810	98050T	PARTICIPANT	\N	PRESENT	0
420511	420509	95041E	PARTICIPANT	\N	PRESENT	0
420512	407810	11085T	PARTICIPANT	\N	PRESENT	0
420513	407810	19269X	PARTICIPANT	\N	PRESENT	0
420515	420514	19349W	PARTICIPANT	\N	PRESENT	0
420516	407810	19441R	PARTICIPANT	\N	PRESENT	0
420482	407810	04086Q	PARTICIPANT	\N	PRESENT	0
420484	420483	11074Q	PARTICIPANT	\N	PRESENT	0
420517	407810	19691J	PARTICIPANT	\N	PRESENT	0
420519	420518	89017R	PARTICIPANT	\N	PRESENT	0
420521	420520	14083S	PARTICIPANT	\N	PRESENT	0
420525	420524	14083S	PARTICIPANT	\N	PRESENT	0
420532	420531	19711U	PARTICIPANT	\N	PRESENT	0
420534	420533	11053K	PARTICIPANT	\N	PRESENT	0
420536	420535	11053K	PARTICIPANT	\N	PRESENT	0
420538	420537	11053K	PARTICIPANT	\N	PRESENT	0
420540	420539	11053K	PARTICIPANT	\N	PRESENT	0
420542	420541	11053K	PARTICIPANT	\N	PRESENT	0
420544	420543	08034U	PARTICIPANT	\N	PRESENT	0
420549	420545	08034U	PARTICIPANT	\N	PRESENT	0
420552	420551	04071H	PARTICIPANT	\N	PRESENT	0
420554	420553	04071H	PARTICIPANT	\N	PRESENT	0
420557	420556	19667J	PARTICIPANT	\N	PRESENT	0
420558	420556	11040E	PARTICIPANT	\N	PRESENT	0
420560	420559	19667J	PARTICIPANT	\N	PRESENT	0
420561	420559	11040E	PARTICIPANT	\N	PRESENT	0
420563	420562	19667J	PARTICIPANT	\N	PRESENT	0
420564	420562	11040E	PARTICIPANT	\N	PRESENT	0
420566	420565	08010L	PARTICIPANT	\N	PRESENT	0
420568	420567	08010L	PARTICIPANT	\N	PRESENT	0
420570	420569	14159V	PARTICIPANT	\N	PRESENT	0
420572	420571	96004D	PARTICIPANT	\N	PRESENT	0
420574	420573	19545Y	PARTICIPANT	\N	PRESENT	0
420575	420573	19689Q	PARTICIPANT	\N	PRESENT	0
420577	420576	19545Y	PARTICIPANT	\N	PRESENT	0
420578	420576	19689Q	PARTICIPANT	\N	PRESENT	0
420580	420579	12016W	PARTICIPANT	\N	PRESENT	0
420582	420581	14173T	PARTICIPANT	\N	PRESENT	0
420587	417145	11048N	PARTICIPANT	\N	PRESENT	0
420588	417145	19525U	PARTICIPANT	\N	PRESENT	0
420603	420601	19503N	PARTICIPANT	\N	PRESENT	0
420610	420608	19503N	PARTICIPANT	\N	PRESENT	0
420617	420615	19503N	PARTICIPANT	\N	PRESENT	0
420622	420618	19503N	PARTICIPANT	\N	PRESENT	0
420625	420623	19503N	PARTICIPANT	\N	PRESENT	0
420628	420626	19503N	PARTICIPANT	\N	PRESENT	0
420654	417145	19489J	PARTICIPANT	\N	EXCUSE	0
420659	417145	08038Y	PARTICIPANT	\N	PRESENT	0
420764	420763	14034U	PARTICIPANT	\N	PRESENT	0
421893	407837	14281W	PARTICIPANT	\N	PRESENT	0
421894	407837	19253P	PARTICIPANT	\N	PRESENT	0
421895	407837	11077T	PARTICIPANT	\N	PRESENT	0
421896	407837	19629C	PARTICIPANT	\N	PRESENT	0
421897	407837	01028R	PARTICIPANT	\N	PRESENT	0
421898	407837	08058D	PARTICIPANT	\N	PRESENT	0
421899	407837	14259Y	PARTICIPANT	\N	PRESENT	0
421900	407837	14195A	PARTICIPANT	\N	PRESENT	0
421901	407837	99004R	PARTICIPANT	\N	PRESENT	0
421902	407837	19585H	PARTICIPANT	\N	PRESENT	0
421903	407837	08049C	PARTICIPANT	\N	PRESENT	0
421904	407837	19703U	PARTICIPANT	\N	PRESENT	0
421905	407837	87003B	PARTICIPANT	\N	PRESENT	0
421906	407837	08012N	PARTICIPANT	\N	PRESENT	0
421907	407837	11103C	PARTICIPANT	\N	PRESENT	0
421908	407837	19717B	PARTICIPANT	\N	PRESENT	0
421909	407837	19794Q	PARTICIPANT	\N	PRESENT	0
421910	407837	14197C	PARTICIPANT	\N	PRESENT	0
421911	407837	14059S	PARTICIPANT	\N	PRESENT	0
421912	407837	11066Q	PARTICIPANT	\N	PRESENT	0
421913	407837	19621T	PARTICIPANT	\N	PRESENT	0
421914	407837	14241N	PARTICIPANT	\N	PRESENT	0
421916	407837	19335Q	PARTICIPANT	\N	PRESENT	0
421917	407837	04018C	PARTICIPANT	\N	PRESENT	0
421919	407837	04059M	PARTICIPANT	\N	PRESENT	0
421921	407837	19515S	PARTICIPANT	\N	PRESENT	0
421922	407837	14223L	PARTICIPANT	\N	PRESENT	0
397351	393394	14029X	PARTICIPANT	\N	PRESENT	0
397352	393394	98050T	PARTICIPANT	\N	PRESENT	0
397353	393394	04044E	PARTICIPANT	\N	PRESENT	0
397354	393394	19749K	PARTICIPANT	\N	PRESENT	0
397355	393394	14257W	PARTICIPANT	\N	PRESENT	0
397356	393394	14109K	PARTICIPANT	\N	PRESENT	0
397357	393394	11104D	PARTICIPANT	\N	PRESENT	0
397358	393394	19253P	PARTICIPANT	\N	PRESENT	0
397359	393394	19691J	PARTICIPANT	\N	PRESENT	0
397360	397297	14031R	PARTICIPANT	\N	PRESENT	0
397361	397297	11048N	PARTICIPANT	\N	EXCUSE	0
397368	393394	19533U	PARTICIPANT	\N	PRESENT	0
397370	393394	01062T	PARTICIPANT	\N	PRESENT	0
397371	393394	95030B	PARTICIPANT	\N	PRESENT	0
397392	393394	19441R	PARTICIPANT	\N	PRESENT	0
397393	393394	14179A	PARTICIPANT	\N	PRESENT	0
397394	393394	19739H	PARTICIPANT	\N	PRESENT	0
397395	393394	11054L	PARTICIPANT	\N	PRESENT	0
397396	393394	14235Q	PARTICIPANT	\N	PRESENT	0
397397	393394	19593H	PARTICIPANT	\N	PRESENT	0
397398	393394	19563B	PARTICIPANT	\N	PRESENT	0
397399	393394	19387D	PARTICIPANT	\N	PRESENT	0
397400	393394	08039A	PARTICIPANT	\N	PRESENT	0
397401	393394	08020N	PARTICIPANT	\N	PRESENT	0
397402	393394	14123H	PARTICIPANT	\N	PRESENT	0
397403	393394	14147R	PARTICIPANT	\N	PRESENT	0
397404	393394	19760E	PARTICIPANT	\N	PRESENT	0
397405	393394	14265W	PARTICIPANT	\N	PRESENT	0
397406	393394	08015R	PARTICIPANT	\N	PRESENT	0
397407	393394	18083K	PARTICIPANT	\N	PRESENT	0
397408	393394	08056B	PARTICIPANT	\N	PRESENT	0
397409	393394	19599P	PARTICIPANT	\N	PRESENT	0
397410	393394	08053X	PARTICIPANT	\N	PRESENT	0
397411	393394	01024M	PARTICIPANT	\N	PRESENT	0
397412	393394	14237S	PARTICIPANT	\N	PRESENT	0
397413	393394	19543W	PARTICIPANT	\N	PRESENT	0
397414	393394	88008L	PARTICIPANT	\N	PRESENT	0
397415	393394	04057K	PARTICIPANT	\N	PRESENT	0
397416	393394	14026U	PARTICIPANT	\N	PRESENT	0
397417	393394	19762G	PARTICIPANT	\N	PRESENT	0
397437	393394	19699S	PARTICIPANT	\N	PRESENT	0
397438	393394	11099A	PARTICIPANT	\N	PRESENT	0
397439	393394	14207L	PARTICIPANT	\N	PRESENT	0
397440	393394	14197C	PARTICIPANT	\N	PRESENT	0
397441	393394	19413M	PARTICIPANT	\N	PRESENT	0
397442	393394	08068F	PARTICIPANT	\N	PRESENT	0
397443	393394	14021P	PARTICIPANT	\N	PRESENT	0
397444	393394	19629C	PARTICIPANT	\N	PRESENT	0
397445	393394	19611R	PARTICIPANT	\N	PRESENT	0
397446	393394	11066Q	PARTICIPANT	\N	PRESENT	0
397447	393394	14253S	PARTICIPANT	\N	PRESENT	0
397448	393394	14249W	PARTICIPANT	\N	PRESENT	0
397449	393394	14193X	PARTICIPANT	\N	PRESENT	0
397451	393394	19479G	PARTICIPANT	\N	PRESENT	0
397452	393394	04049K	PARTICIPANT	\N	PRESENT	0
397532	393396	04070G	PARTICIPANT	\N	PRESENT	0
397533	393396	14229S	PARTICIPANT	\N	PRESENT	0
397534	393396	08017T	PARTICIPANT	\N	PRESENT	0
397535	393396	11067R	PARTICIPANT	\N	PRESENT	0
397536	393396	19758L	PARTICIPANT	\N	PRESENT	0
397537	393396	19593H	PARTICIPANT	\N	PRESENT	0
397538	393396	11083R	PARTICIPANT	\N	PRESENT	0
397539	393396	19543W	PARTICIPANT	\N	PRESENT	0
397540	393396	14079W	PARTICIPANT	\N	PRESENT	0
397541	393396	14219Q	PARTICIPANT	\N	PRESENT	0
397542	393396	14073Q	PARTICIPANT	\N	PRESENT	0
397543	393396	19479G	PARTICIPANT	\N	PRESENT	0
397544	393396	19691J	PARTICIPANT	\N	PRESENT	0
397545	393396	19699S	PARTICIPANT	\N	PRESENT	0
397546	393396	98050T	PARTICIPANT	\N	PRESENT	0
397547	393396	07029T	PARTICIPANT	\N	PRESENT	0
397548	393396	04049K	PARTICIPANT	\N	PRESENT	0
397549	393396	95030B	PARTICIPANT	\N	PRESENT	0
397550	393396	19762G	PARTICIPANT	\N	PRESENT	0
397551	393396	97011G	PARTICIPANT	\N	PRESENT	0
397552	393396	14253S	PARTICIPANT	\N	PRESENT	0
397553	393396	14249W	PARTICIPANT	\N	PRESENT	0
397554	393396	14193X	PARTICIPANT	\N	PRESENT	0
397555	393396	01058X	PARTICIPANT	\N	PRESENT	0
397556	393396	15447F	PARTICIPANT	\N	PRESENT	0
397557	393396	08039A	PARTICIPANT	\N	PRESENT	0
397558	393396	19673G	PARTICIPANT	\N	PRESENT	0
397559	393396	14029X	PARTICIPANT	\N	PRESENT	0
397560	393396	19611R	PARTICIPANT	\N	PRESENT	0
397561	393396	08031R	PARTICIPANT	\N	PRESENT	0
397562	393396	19798U	PARTICIPANT	\N	PRESENT	0
397563	393396	01024M	PARTICIPANT	\N	PRESENT	0
397564	393396	19575F	PARTICIPANT	\N	PRESENT	0
397565	393396	19447X	PARTICIPANT	\N	PRESENT	0
397566	393396	14265W	PARTICIPANT	\N	PRESENT	0
397567	393396	14123H	PARTICIPANT	\N	PRESENT	0
397568	393396	14061L	PARTICIPANT	\N	PRESENT	0
397569	393396	14331P	PARTICIPANT	\N	PRESENT	0
397573	393396	19399H	PARTICIPANT	\N	PRESENT	0
397574	393396	14251Q	PARTICIPANT	\N	PRESENT	0
397575	393396	14109K	PARTICIPANT	\N	PRESENT	0
397576	393396	19563B	PARTICIPANT	\N	PRESENT	0
397577	393396	14083S	PARTICIPANT	\N	PRESENT	0
397578	393396	08056B	PARTICIPANT	\N	PRESENT	0
397579	393396	19749K	PARTICIPANT	\N	PRESENT	0
397580	393396	14031R	PARTICIPANT	\N	PRESENT	0
397585	393396	08020N	PARTICIPANT	\N	PRESENT	0
397586	393396	14087W	PARTICIPANT	\N	PRESENT	0
397587	393396	14215L	PARTICIPANT	\N	PRESENT	0
397590	393396	08012N	PARTICIPANT	\N	PRESENT	0
397591	393396	19533U	PARTICIPANT	\N	PRESENT	0
397592	393396	14221J	PARTICIPANT	\N	PRESENT	0
397593	393396	19467C	PARTICIPANT	\N	PRESENT	0
397594	393396	14069U	PARTICIPANT	\N	PRESENT	0
397601	393396	08061X	PARTICIPANT	\N	PRESENT	0
397602	393396	19387D	PARTICIPANT	\N	PRESENT	0
397603	393396	04057K	PARTICIPANT	\N	PRESENT	0
397604	393396	08055A	PARTICIPANT	\N	PRESENT	0
397605	393396	14071N	PARTICIPANT	\N	PRESENT	0
397606	393396	11101A	PARTICIPANT	\N	PRESENT	0
397611	393396	11097X	PARTICIPANT	\N	PRESENT	0
397615	393396	04047H	PARTICIPANT	\N	PRESENT	0
397643	393396	19747H	PARTICIPANT	\N	PRESENT	0
397656	397651	04040A	PRESIDENT	0	PRESENT	0
397681	397651	04044E	PARTICIPANT	\N	EXCUSE	0
397926	397651	14071N	PARTICIPANT	\N	EXCUSE	0
397934	397651	08048B	PARTICIPANT	\N	EXCUSE	0
398016	397651	19565D	PARTICIPANT	\N	EXCUSE	0
398230	396238	19703U	PARTICIPANT	\N	EXCUSE	0
398231	396242	19703U	PARTICIPANT	\N	EXCUSE	0
399913	399900	04035D	PARTICIPANT	\N	PRESENT	0
397528	393396	11027H	PARTICIPANT	\N	PRESENT	0
397529	393396	04059M	PARTICIPANT	\N	PRESENT	0
399902	399900	19515S	PARTICIPANT	\N	PRESENT	0
399903	399900	04040A	PARTICIPANT	\N	PRESENT	0
399917	399900	11090Q	PARTICIPANT	\N	PRESENT	0
399905	399900	19747H	PARTICIPANT	\N	PRESENT	0
400685	393611	11072N	PARTICIPANT	\N	PRESENT	0
399915	399900	14179A	PARTICIPANT	\N	PRESENT	0
399918	399900	04043D	PARTICIPANT	\N	PRESENT	0
399919	399900	14225N	PARTICIPANT	\N	PRESENT	0
399920	399900	19479G	PARTICIPANT	\N	PRESENT	0
399923	399900	14097Y	PARTICIPANT	\N	PRESENT	0
400686	393611	19531S	PARTICIPANT	\N	PRESENT	0
400687	393611	11070L	PARTICIPANT	\N	PRESENT	0
400688	393611	14071N	PARTICIPANT	\N	PRESENT	0
400689	393611	99004R	PARTICIPANT	\N	PRESENT	0
400690	393611	19367Y	PARTICIPANT	\N	PRESENT	0
400691	393611	08060W	PARTICIPANT	\N	PRESENT	0
400692	393611	14223L	PARTICIPANT	\N	PRESENT	0
400693	393611	19575F	PARTICIPANT	\N	PRESENT	0
400694	393611	14267Y	PARTICIPANT	\N	PRESENT	0
400695	393611	14031R	PARTICIPANT	\N	PRESENT	0
400696	393611	14219Q	PARTICIPANT	\N	PRESENT	0
400697	393611	17583W	PARTICIPANT	\N	PRESENT	0
400698	393611	14237S	PARTICIPANT	\N	PRESENT	0
400699	393611	19369B	PARTICIPANT	\N	PRESENT	0
400700	393611	14231L	PARTICIPANT	\N	PRESENT	0
400701	393611	19507S	PARTICIPANT	\N	PRESENT	0
400702	393611	14179A	PARTICIPANT	\N	PRESENT	0
400703	393611	14038Y	PARTICIPANT	\N	PRESENT	0
400704	393611	08073C	PARTICIPANT	\N	PRESENT	0
400705	393611	19782L	PARTICIPANT	\N	PRESENT	0
400708	393611	14105F	PARTICIPANT	\N	PRESENT	0
400715	400709	96004D	PARTICIPANT	\N	PRESENT	0
400716	393611	14197C	PARTICIPANT	\N	PRESENT	0
400717	400709	11090Q	PARTICIPANT	\N	PRESENT	0
400718	400709	14207L	PARTICIPANT	\N	PRESENT	0
400714	393611	14083S	PARTICIPANT	\N	PRESENT	0
400719	393611	11066Q	PARTICIPANT	\N	PRESENT	0
400720	400709	14033T	PARTICIPANT	\N	PRESENT	0
400721	393611	19553Y	PARTICIPANT	\N	PRESENT	0
400722	400709	14357A	PARTICIPANT	\N	PRESENT	0
400723	400709	14026U	PARTICIPANT	\N	PRESENT	0
409378	408286	07004J	PARTICIPANT	\N	PRESENT	0
409379	408286	19511N	PARTICIPANT	\N	PRESENT	0
409380	408286	19699S	PARTICIPANT	\N	PRESENT	0
409381	408286	19711U	PARTICIPANT	\N	PRESENT	0
409382	408286	14205J	PARTICIPANT	\N	PRESENT	0
409383	408286	19721W	PARTICIPANT	\N	PRESENT	0
409384	408286	19569H	PARTICIPANT	\N	PRESENT	0
409385	408286	17637T	PARTICIPANT	\N	PRESENT	0
409386	408286	19739H	PARTICIPANT	\N	PRESENT	0
409387	408286	14211G	PARTICIPANT	\N	PRESENT	0
409388	408286	16685X	PARTICIPANT	\N	PRESENT	0
409389	408286	14042U	PARTICIPANT	\N	PRESENT	0
409390	408286	14219Q	PARTICIPANT	\N	PRESENT	0
409391	408286	19479G	PARTICIPANT	\N	PRESENT	0
409392	408286	19319Q	PARTICIPANT	\N	PRESENT	0
409393	408286	14275Y	PARTICIPANT	\N	PRESENT	0
409394	408286	14073Q	PARTICIPANT	\N	PRESENT	0
409395	408286	14103D	PARTICIPANT	\N	PRESENT	0
409396	408286	19335Q	PARTICIPANT	\N	PRESENT	0
409397	408286	14267Y	PARTICIPANT	\N	PRESENT	0
409398	408286	14083S	PARTICIPANT	\N	PRESENT	0
409399	408286	19749K	PARTICIPANT	\N	PRESENT	0
409400	408286	19745F	PARTICIPANT	\N	PRESENT	0
409401	408286	11070L	PARTICIPANT	\N	PRESENT	0
409402	408286	19521Q	PARTICIPANT	\N	PRESENT	0
409403	408286	14255U	PARTICIPANT	\N	PRESENT	0
409404	408286	08009T	PARTICIPANT	\N	PRESENT	0
409405	408286	14277B	PARTICIPANT	\N	PRESENT	0
409406	408286	11085T	PARTICIPANT	\N	PRESENT	0
409407	408286	98024R	PARTICIPANT	\N	PRESENT	0
409408	408286	19577H	PARTICIPANT	\N	PRESENT	0
409409	408286	04070G	PARTICIPANT	\N	PRESENT	0
409410	408286	04040A	PARTICIPANT	\N	PRESENT	0
409411	408286	01024M	PARTICIPANT	\N	PRESENT	0
409412	408286	14327T	PARTICIPANT	\N	PRESENT	0
409413	408286	14030Q	PARTICIPANT	\N	PRESENT	0
409414	408286	01043Q	PARTICIPANT	\N	PRESENT	0
409415	408286	95037J	PARTICIPANT	\N	PRESENT	0
409416	408286	19709B	PARTICIPANT	\N	PRESENT	0
409417	408286	87003B	PARTICIPANT	\N	PRESENT	0
409418	408286	04088S	PARTICIPANT	\N	PRESENT	0
409419	408286	04018C	PARTICIPANT	\N	PRESENT	0
409420	408286	14089Y	PARTICIPANT	\N	PRESENT	0
409421	408286	14265W	PARTICIPANT	\N	PRESENT	0
409422	408286	14197C	PARTICIPANT	\N	PRESENT	0
409423	408286	19683J	PARTICIPANT	\N	PRESENT	0
409424	408286	19467C	PARTICIPANT	\N	PRESENT	0
409425	408286	11090Q	PARTICIPANT	\N	PRESENT	0
409426	408286	08053X	PARTICIPANT	\N	PRESENT	0
409427	408286	11104D	PARTICIPANT	\N	PRESENT	0
409428	408286	14135M	PARTICIPANT	\N	PRESENT	0
409429	408286	08035V	PARTICIPANT	\N	PRESENT	0
409430	408286	01058X	PARTICIPANT	\N	PRESENT	0
409434	409433	14205J	PARTICIPANT	\N	PRESENT	0
409435	409433	08055A	PARTICIPANT	\N	PRESENT	0
409436	409433	08014Q	PARTICIPANT	\N	PRESENT	0
409437	409433	88008L	PARTICIPANT	\N	PRESENT	0
409438	409433	14034U	PARTICIPANT	\N	PRESENT	0
409439	409433	19727D	PARTICIPANT	\N	PRESENT	0
409440	409433	14179A	PARTICIPANT	\N	PRESENT	0
409441	409433	14097Y	PARTICIPANT	\N	PRESENT	0
409442	409433	19723Y	PARTICIPANT	\N	PRESENT	0
409443	409433	19563B	PARTICIPANT	\N	PRESENT	0
409444	409433	19745F	PARTICIPANT	\N	PRESENT	0
409445	409433	19533U	PARTICIPANT	\N	PRESENT	0
409446	409433	04088S	PARTICIPANT	\N	PRESENT	0
409447	409433	11097X	PARTICIPANT	\N	PRESENT	0
409448	409433	11043H	PARTICIPANT	\N	PRESENT	0
409449	409433	95067Q	PARTICIPANT	\N	PRESENT	0
409450	409433	14033T	PARTICIPANT	\N	PRESENT	0
409749	402300	04086Q	PARTICIPANT	\N	PRESENT	0
409750	402300	14038Y	PARTICIPANT	\N	PRESENT	0
409751	402300	01028R	PARTICIPANT	\N	PRESENT	0
409752	402300	08052W	PARTICIPANT	\N	PRESENT	0
409753	402300	80013X	PARTICIPANT	\N	PRESENT	0
409788	402300	14105F	PARTICIPANT	\N	PRESENT	0
409755	402300	02002K	PARTICIPANT	\N	PRESENT	0
409756	402300	98022P	PARTICIPANT	\N	PRESENT	0
409775	402300	19333N	PARTICIPANT	\N	PRESENT	0
409758	402300	19479G	PARTICIPANT	\N	PRESENT	0
409759	402300	19745F	PARTICIPANT	\N	PRESENT	0
409760	402300	19525U	PARTICIPANT	\N	PRESENT	0
409761	402300	19713W	PARTICIPANT	\N	PRESENT	0
409762	402300	14255U	PARTICIPANT	\N	PRESENT	0
409763	402300	10006L	PARTICIPANT	\N	PRESENT	0
409764	402300	11043H	PARTICIPANT	\N	PRESENT	0
409765	402300	17583W	PARTICIPANT	\N	PRESENT	0
409805	409125	19543W	PARTICIPANT	\N	PRESENT	0
409767	402300	08048B	PARTICIPANT	\N	PRESENT	0
409768	402300	88008L	PARTICIPANT	\N	PRESENT	0
409769	402300	14261S	PARTICIPANT	\N	PRESENT	0
409770	402300	19747H	PARTICIPANT	\N	PRESENT	0
409771	402300	19820Y	PARTICIPANT	\N	PRESENT	0
409772	402300	14205J	PARTICIPANT	\N	PRESENT	0
409773	402300	14173T	PARTICIPANT	\N	PRESENT	0
409774	402300	19549D	PARTICIPANT	\N	PRESENT	0
409776	402300	08024S	PARTICIPANT	\N	PRESENT	0
409777	402300	08061X	PARTICIPANT	\N	PRESENT	0
409778	402300	11012A	PARTICIPANT	\N	PRESENT	0
409779	402300	19701S	PARTICIPANT	\N	PRESENT	0
409780	402300	19335Q	PARTICIPANT	\N	PRESENT	0
409781	402300	14031R	PARTICIPANT	\N	PRESENT	0
409782	402300	19679N	PARTICIPANT	\N	PRESENT	0
409783	402300	19399H	PARTICIPANT	\N	PRESENT	0
409784	402300	08010L	PARTICIPANT	\N	PRESENT	0
409785	402300	08055A	PARTICIPANT	\N	PRESENT	0
409786	402300	95030B	PARTICIPANT	\N	PRESENT	0
409787	402300	14257W	PARTICIPANT	\N	PRESENT	0
409789	402300	08009T	PARTICIPANT	\N	PRESENT	0
409790	402300	19553Y	PARTICIPANT	\N	PRESENT	0
409791	402300	19681G	PARTICIPANT	\N	PRESENT	0
409792	402300	19794Q	PARTICIPANT	\N	PRESENT	0
409793	402300	04085P	PARTICIPANT	\N	PRESENT	0
409794	402300	14121F	PARTICIPANT	\N	PRESENT	0
409795	402300	14119M	PARTICIPANT	\N	PRESENT	0
409796	402300	19551W	PARTICIPANT	\N	PRESENT	0
409797	402300	19369B	PARTICIPANT	\N	PRESENT	0
409798	402300	08053X	PARTICIPANT	\N	PRESENT	0
409799	402300	19415P	PARTICIPANT	\N	PRESENT	0
409800	402300	18083K	PARTICIPANT	\N	PRESENT	0
409801	402300	01058X	PARTICIPANT	\N	PRESENT	0
409802	402300	08056B	PARTICIPANT	\N	PRESENT	0
409803	402300	19593H	PARTICIPANT	\N	PRESENT	0
409804	402300	14157T	PARTICIPANT	\N	PRESENT	0
409806	409125	01028R	PARTICIPANT	\N	PRESENT	0
409807	409125	14231L	PARTICIPANT	\N	PRESENT	0
409808	409125	19447X	PARTICIPANT	\N	PRESENT	0
409809	409125	05008E	PRESIDENT	0	PRESENT	0
409810	409125	19489J	PARTICIPANT	\N	PRESENT	0
409811	409125	14275Y	PARTICIPANT	\N	PRESENT	0
409812	409125	14179A	PARTICIPANT	\N	PRESENT	0
409813	409125	14151M	PARTICIPANT	\N	PRESENT	0
409814	409125	14215L	PRESIDENT	1	PRESENT	0
409815	409125	14259Y	PARTICIPANT	\N	PRESENT	0
409816	409125	14053L	PARTICIPANT	\N	PRESENT	0
409817	409125	14111D	PARTICIPANT	\N	PRESENT	0
409818	409125	19649G	PARTICIPANT	\N	PRESENT	0
409819	409125	14065Q	PARTICIPANT	\N	PRESENT	0
409820	409125	10015M	PARTICIPANT	\N	PRESENT	0
409821	409125	01024M	PARTICIPANT	\N	PRESENT	0
409822	409125	19719D	PARTICIPANT	\N	PRESENT	0
409823	409125	19725B	PARTICIPANT	\N	PRESENT	0
409824	409125	14089Y	PARTICIPANT	\N	PRESENT	0
409825	409125	19729F	PARTICIPANT	\N	PRESENT	0
409826	409125	19629C	PARTICIPANT	\N	PRESENT	0
409827	409125	08044W	PARTICIPANT	\N	PRESENT	0
409828	409125	14069U	PARTICIPANT	\N	PRESENT	0
409829	409125	19762G	PARTICIPANT	\N	PRESENT	0
409830	409125	04047H	PARTICIPANT	\N	PRESENT	0
409831	402300	04018C	PARTICIPANT	\N	PRESENT	0
409832	402300	08060W	PARTICIPANT	\N	PRESENT	0
409833	402300	19782L	PARTICIPANT	\N	PRESENT	0
409834	402300	19599P	PARTICIPANT	\N	PRESENT	0
409835	402300	08031R	PARTICIPANT	\N	PRESENT	0
409836	402300	14107H	PARTICIPANT	\N	PRESENT	0
409837	402300	19691J	PARTICIPANT	\N	PRESENT	0
409838	402300	08020N	PARTICIPANT	\N	PRESENT	0
409839	402300	11103C	PARTICIPANT	\N	PRESENT	0
409840	402300	08014Q	PARTICIPANT	\N	PRESENT	0
409841	402300	19347U	PARTICIPANT	\N	PRESENT	0
409842	402300	11077T	PARTICIPANT	\N	PRESENT	0
409843	402300	19703U	PARTICIPANT	\N	PRESENT	0
409844	402300	14207L	PARTICIPANT	\N	PRESENT	0
409845	402300	14197C	PARTICIPANT	\N	PRESENT	0
409846	402300	14267Y	PARTICIPANT	\N	PRESENT	0
409847	402300	11097X	PARTICIPANT	\N	PRESENT	0
409848	402300	19723Y	PARTICIPANT	\N	PRESENT	0
409849	402300	14021P	PARTICIPANT	\N	PRESENT	0
409850	402300	11067R	PARTICIPANT	\N	PRESENT	0
409851	402300	19798U	PARTICIPANT	\N	PRESENT	0
393958	393957	14111D	PARTICIPANT	\N	PRESENT	0
393959	393957	19629C	PARTICIPANT	\N	PRESENT	0
393960	393957	04038G	PARTICIPANT	\N	PRESENT	0
393961	393957	19585H	PARTICIPANT	\N	PRESENT	0
393962	393957	19447X	PARTICIPANT	\N	PRESENT	0
393963	393957	04044E	PARTICIPANT	\N	EXCUSE	0
393964	393957	95063L	PARTICIPANT	\N	PRESENT	0
393965	393957	05008E	PRESIDENT	0	PRESENT	0
393976	393957	14065Q	PARTICIPANT	\N	PRESENT	0
393977	393957	01024M	PARTICIPANT	\N	PRESENT	0
393978	393957	19581D	PARTICIPANT	\N	PRESENT	0
393979	393957	01028R	PARTICIPANT	\N	PRESENT	0
393980	393957	19762G	PARTICIPANT	\N	PRESENT	0
398429	398366	19766L	PARTICIPANT	\N	EXCUSE	0
398430	398366	04057K	PARTICIPANT	\N	EXCUSE	0
398431	398300	04097T	PARTICIPANT	\N	PRESENT	0
398432	397999	14053L	PARTICIPANT	\N	PRESENT	0
398433	397999	98035U	PARTICIPANT	\N	PRESENT	0
398434	397999	19729F	PARTICIPANT	\N	PRESENT	0
398435	397999	14111D	PARTICIPANT	\N	PRESENT	0
398436	397999	04047H	PRESIDENT	0	PRESENT	0
398437	397999	19673G	PARTICIPANT	\N	PRESENT	0
398438	397999	01028R	PARTICIPANT	\N	PRESENT	0
398439	397999	19447X	PARTICIPANT	\N	PRESENT	0
398440	397999	19585H	PARTICIPANT	\N	EXCUSE	0
398555	398367	14241N	PARTICIPANT	\N	PRESENT	0
398556	398367	19399H	PARTICIPANT	\N	PRESENT	0
398557	393595	19489J	PARTICIPANT	\N	PRESENT	0
398558	393595	14063N	PARTICIPANT	\N	PRESENT	0
398559	393595	18083K	PARTICIPANT	\N	PRESENT	0
398560	393595	19447X	PARTICIPANT	\N	PRESENT	0
398561	393595	14217N	PARTICIPANT	\N	PRESENT	0
398562	398301	19733B	PARTICIPANT	\N	PRESENT	0
398613	393595	14089Y	PARTICIPANT	\N	PRESENT	0
398614	393595	98022P	PARTICIPANT	\N	PRESENT	0
398615	393595	11041F	PARTICIPANT	\N	PRESENT	0
398616	393595	19525U	PARTICIPANT	\N	PRESENT	0
398617	393595	08060W	PARTICIPANT	\N	PRESENT	0
398619	393595	14201E	PARTICIPANT	\N	PRESENT	0
398696	393596	17637T	PARTICIPANT	\N	PRESENT	0
398697	393596	14211G	PARTICIPANT	\N	PRESENT	0
398698	393596	19711U	PARTICIPANT	\N	PRESENT	0
399339	393597	02002K	PARTICIPANT	\N	PRESENT	0
399340	393597	14061L	PARTICIPANT	\N	PRESENT	0
399341	393597	14030Q	PARTICIPANT	\N	PRESENT	0
399342	393597	19687N	PARTICIPANT	\N	PRESENT	0
399343	393597	14235Q	PARTICIPANT	\N	PRESENT	0
399344	393597	11109J	PARTICIPANT	\N	PRESENT	0
399345	393597	14097Y	PARTICIPANT	\N	PRESENT	0
399346	393597	19599P	PARTICIPANT	\N	PRESENT	0
399347	393597	19713W	PARTICIPANT	\N	PRESENT	0
399406	393600	04070G	PARTICIPANT	\N	PRESENT	0
399407	393600	14229S	PARTICIPANT	\N	PRESENT	0
399408	393600	08043V	PARTICIPANT	\N	PRESENT	0
399409	393600	02002K	PARTICIPANT	\N	PRESENT	0
399410	393600	19593H	PARTICIPANT	\N	PRESENT	0
399411	393600	01025N	PARTICIPANT	\N	PRESENT	0
399412	393600	19735D	PARTICIPANT	\N	PRESENT	0
399413	393600	19533U	PARTICIPANT	\N	PRESENT	0
399414	393600	11012A	PARTICIPANT	\N	PRESENT	0
399415	393600	08031R	PARTICIPANT	\N	PRESENT	0
399416	393600	04018C	PARTICIPANT	\N	PRESENT	0
399417	393600	08039A	PARTICIPANT	\N	PRESENT	0
399418	393600	19295A	PARTICIPANT	\N	PRESENT	0
399419	393600	14249W	PARTICIPANT	\N	PRESENT	0
399420	393600	14147R	PARTICIPANT	\N	PRESENT	0
399421	393600	14265W	PARTICIPANT	\N	PRESENT	0
399422	393600	19479G	PARTICIPANT	\N	PRESENT	0
399423	393600	08020N	PARTICIPANT	\N	PRESENT	0
399424	393600	14061L	PARTICIPANT	\N	PRESENT	0
399425	393600	14021P	PARTICIPANT	\N	PRESENT	0
399426	393600	19717B	PARTICIPANT	\N	PRESENT	0
399427	393600	19758L	PARTICIPANT	\N	PRESENT	0
399428	393600	11083R	PARTICIPANT	\N	PRESENT	0
399429	393600	19621T	PARTICIPANT	\N	PRESENT	0
399430	393600	11043H	PARTICIPANT	\N	PRESENT	0
398409	398366	19593H	PARTICIPANT	\N	PRESENT	0
398410	398366	04070G	PRESIDENT	0	PRESENT	0
398411	398366	19699S	PARTICIPANT	\N	PRESENT	0
398412	398366	08043V	PARTICIPANT	\N	PRESENT	0
398413	398366	19693L	PARTICIPANT	\N	PRESENT	0
398414	398366	19399H	PARTICIPANT	\N	PRESENT	0
398415	398366	14229S	PARTICIPANT	\N	PRESENT	0
398416	398366	14241N	PARTICIPANT	\N	PRESENT	0
398417	398366	19573D	PARTICIPANT	\N	PRESENT	0
398418	398366	14251Q	PARTICIPANT	\N	PRESENT	0
398419	398366	14107H	PARTICIPANT	\N	PRESENT	0
398420	398366	19735D	PARTICIPANT	\N	PRESENT	0
398421	398366	11109J	PARTICIPANT	\N	PRESENT	0
398422	398366	14123H	PARTICIPANT	\N	PRESENT	0
398423	398366	04018C	PARTICIPANT	\N	PRESENT	0
398424	398366	19758L	PARTICIPANT	\N	PRESENT	0
398425	398366	14249W	PARTICIPANT	\N	PRESENT	0
398426	398366	08039A	PARTICIPANT	\N	PRESENT	0
398427	398366	08031R	PARTICIPANT	\N	PRESENT	0
398428	398366	19621T	PARTICIPANT	\N	PRESENT	0
399431	393600	19693L	PARTICIPANT	\N	PRESENT	0
399432	393600	14033T	PARTICIPANT	\N	PRESENT	0
399433	393600	19794Q	PARTICIPANT	\N	PRESENT	0
399434	393600	14083S	PARTICIPANT	\N	PRESENT	0
399435	393600	19531S	PARTICIPANT	\N	PRESENT	0
399436	393600	14223L	PARTICIPANT	\N	PRESENT	0
399437	393600	19703U	PARTICIPANT	\N	PRESENT	0
399438	393600	14105F	PARTICIPANT	\N	PRESENT	0
399439	393600	11090Q	PARTICIPANT	\N	PRESENT	0
399440	393600	19447X	PARTICIPANT	\N	PRESENT	0
399441	393600	95030B	PARTICIPANT	\N	PRESENT	0
399442	393600	19573D	PARTICIPANT	\N	PRESENT	0
399443	393600	19383Y	PARTICIPANT	\N	PRESENT	0
399444	393600	08068F	PARTICIPANT	\N	PRESENT	0
399445	393600	19741B	PARTICIPANT	\N	PRESENT	0
399678	399677	19701S	PARTICIPANT	\N	PRESENT	0
399679	399677	19637C	PARTICIPANT	\N	PRESENT	0
399680	399677	19549D	PARTICIPANT	\N	PRESENT	0
399681	399677	14083S	PARTICIPANT	\N	PRESENT	0
399683	399682	19701S	PARTICIPANT	\N	PRESENT	0
399684	399682	19637C	PARTICIPANT	\N	PRESENT	0
399685	399682	19549D	PARTICIPANT	\N	PRESENT	0
399688	399686	19701S	PARTICIPANT	\N	PRESENT	0
399689	399686	19637C	PARTICIPANT	\N	PRESENT	0
399690	399687	19701S	PARTICIPANT	\N	PRESENT	0
400153	400152	11074Q	PARTICIPANT	\N	PRESENT	0
399692	399687	19637C	PARTICIPANT	\N	PRESENT	0
400151	400150	99004R	PARTICIPANT	\N	PRESENT	0
400185	400184	19667J	PARTICIPANT	\N	PRESENT	0
400186	400184	11040E	PARTICIPANT	\N	PRESENT	0
400188	400187	19667J	PARTICIPANT	\N	PRESENT	0
399404	393600	11027H	PARTICIPANT	\N	PRESENT	0
399405	393600	19399H	PARTICIPANT	\N	PRESENT	0
400189	400187	11040E	PARTICIPANT	\N	PRESENT	0
400226	400225	14173T	PARTICIPANT	\N	PRESENT	0
413742	408325	04038G	PARTICIPANT	\N	PRESENT	0
398694	393596	86034E	PARTICIPANT	\N	PRESENT	0
398695	393596	98018T	PARTICIPANT	\N	PRESENT	0
413743	408325	11066Q	PARTICIPANT	\N	PRESENT	0
413989	413988	11053K	PARTICIPANT	\N	PRESENT	0
413990	413988	14159V	PARTICIPANT	\N	PRESENT	0
413991	413988	05012A	PARTICIPANT	\N	PRESENT	0
413995	413994	11053K	PARTICIPANT	\N	PRESENT	0
413996	413994	14159V	PARTICIPANT	\N	PRESENT	0
413997	413994	05012A	PARTICIPANT	\N	PRESENT	0
414302	413405	11040E	PARTICIPANT	\N	PRESENT	0
414303	413405	11048N	PARTICIPANT	\N	PRESENT	0
414304	413405	19711U	PARTICIPANT	\N	PRESENT	0
414305	413405	01048V	PARTICIPANT	\N	PRESENT	0
414306	413405	14085U	PARTICIPANT	\N	PRESENT	0
414307	413405	08069G	PARTICIPANT	\N	PRESENT	0
414308	413405	96004D	PARTICIPANT	\N	PRESENT	0
414309	413405	11074Q	PRESIDENT	0	PRESENT	0
414310	413405	99004R	PARTICIPANT	\N	PRESENT	0
414311	413405	19671E	PARTICIPANT	\N	PRESENT	0
414312	406851	19651A	PARTICIPANT	\N	PRESENT	0
414313	414028	01058X	PARTICIPANT	\N	PRESENT	0
414314	414028	11027H	PARTICIPANT	\N	PRESENT	0
414315	414028	08053X	PARTICIPANT	\N	PRESENT	0
414316	414028	98022P	PARTICIPANT	\N	PRESENT	0
414317	406851	19657G	PARTICIPANT	\N	PRESENT	0
414318	406851	19699S	PARTICIPANT	\N	PRESENT	0
414319	406851	01024M	PARTICIPANT	\N	PRESENT	0
414320	414028	04035D	PARTICIPANT	\N	PRESENT	0
414321	406851	11072N	PARTICIPANT	\N	PRESENT	0
414322	406851	19631V	PARTICIPANT	\N	PRESENT	0
414323	406851	19367Y	PARTICIPANT	\N	PRESENT	0
414324	406851	08062Y	PARTICIPANT	\N	PRESENT	0
414325	406851	11070L	PARTICIPANT	\N	PRESENT	0
414326	406851	19820Y	PARTICIPANT	\N	PRESENT	0
414327	406851	04045F	PARTICIPANT	\N	PRESENT	0
414328	406851	19649G	PARTICIPANT	\N	PRESENT	0
414329	406851	19735D	PARTICIPANT	\N	PRESENT	0
414330	413405	19333N	PARTICIPANT	\N	PRESENT	0
419865	407721	11070L	PARTICIPANT	\N	PRESENT	0
419866	415938	11031D	PARTICIPANT	\N	PRESENT	0
419867	415938	19703U	PARTICIPANT	\N	PRESENT	0
419868	415938	19565D	PARTICIPANT	\N	PRESENT	0
419869	415938	04092N	PRESIDENT	0	PRESENT	0
419870	415938	19569H	PARTICIPANT	\N	PRESENT	0
419871	415938	14042U	PARTICIPANT	\N	PRESENT	0
419872	415938	19575F	PARTICIPANT	\N	PRESENT	0
419873	415938	14195A	PARTICIPANT	\N	PRESENT	0
419874	415938	14213J	PARTICIPANT	\N	PRESENT	0
419875	415938	19683J	PARTICIPANT	\N	PRESENT	0
419876	415938	19760E	PARTICIPANT	\N	PRESENT	0
419877	415938	98024R	PARTICIPANT	\N	PRESENT	0
419878	415938	01034P	PARTICIPANT	\N	EXCUSE	0
419879	415938	11103C	PARTICIPANT	\N	EXCUSE	0
419880	415938	19691J	PARTICIPANT	\N	EXCUSE	0
419881	415938	08041T	PARTICIPANT	\N	EXCUSE	0
419882	415938	19577H	PARTICIPANT	\N	EXCUSE	0
419883	407721	14225N	PARTICIPANT	\N	PRESENT	0
419884	407721	11012A	PARTICIPANT	\N	PRESENT	0
419885	407721	19647E	PARTICIPANT	\N	PRESENT	0
419886	407721	14111D	PARTICIPANT	\N	PRESENT	0
419887	407721	04018C	PARTICIPANT	\N	PRESENT	0
419888	407721	14267Y	PARTICIPANT	\N	PRESENT	0
419894	407721	14251Q	PARTICIPANT	\N	PRESENT	0
419895	407721	19399H	PARTICIPANT	\N	PRESENT	0
419896	407721	11053K	PARTICIPANT	\N	PRESENT	0
419897	407721	19369B	PARTICIPANT	\N	PRESENT	0
419898	407721	14151M	PARTICIPANT	\N	PRESENT	0
419899	407721	08056B	PARTICIPANT	\N	PRESENT	0
419900	407721	08020N	PARTICIPANT	\N	PRESENT	0
419901	407721	19741B	PARTICIPANT	\N	PRESENT	0
419902	407721	19413M	PARTICIPANT	\N	PRESENT	0
419903	407721	19521Q	PARTICIPANT	\N	PRESENT	0
419904	407721	14327T	PARTICIPANT	\N	PRESENT	0
419905	407721	19673G	PARTICIPANT	\N	PRESENT	0
419906	407721	19695N	PARTICIPANT	\N	PRESENT	0
420249	415987	98024R	PARTICIPANT	\N	PRESENT	0
420250	415987	11067R	PARTICIPANT	\N	PRESENT	0
420653	420652	14071N	PARTICIPANT	\N	PRESENT	0
420656	420655	08052W	PARTICIPANT	\N	PRESENT	0
420657	420655	01034P	PARTICIPANT	\N	PRESENT	0
420658	420655	11097X	PARTICIPANT	\N	PRESENT	0
420661	420660	04049K	PARTICIPANT	\N	PRESENT	0
420662	420660	14038Y	PARTICIPANT	\N	PRESENT	0
420663	420660	14107H	PARTICIPANT	\N	PRESENT	0
420664	420660	19631V	PARTICIPANT	\N	PRESENT	0
420665	420660	08049C	PARTICIPANT	\N	PRESENT	0
420666	420660	14169X	PARTICIPANT	\N	PRESENT	0
420668	420667	04049K	PARTICIPANT	\N	PRESENT	0
420669	420667	14038Y	PARTICIPANT	\N	PRESENT	0
421478	417145	05012A	PARTICIPANT	\N	PRESENT	0
422732	422730	11041F	PARTICIPANT	\N	PRESENT	0
422734	422733	98018T	PARTICIPANT	\N	PRESENT	0
422735	422733	11041F	PARTICIPANT	\N	PRESENT	0
422739	422738	96004D	PRESIDENT	0	PRESENT	0
422740	422738	14089Y	PARTICIPANT	\N	PRESENT	0
422741	422738	14357A	PARTICIPANT	\N	PRESENT	0
422742	422738	14249W	PARTICIPANT	\N	PRESENT	0
422743	422738	14033T	PARTICIPANT	\N	PRESENT	0
422744	422738	14026U	PARTICIPANT	\N	PRESENT	0
422745	422738	04097T	PARTICIPANT	\N	PRESENT	0
422746	422738	14135M	PARTICIPANT	\N	PRESENT	0
422765	422764	92040Q	PARTICIPANT	\N	PRESENT	0
422766	422764	08039A	PARTICIPANT	\N	PRESENT	0
422767	422764	19735D	PARTICIPANT	\N	PRESENT	0
422768	422764	14109K	PARTICIPANT	\N	PRESENT	0
422769	422764	04018C	PARTICIPANT	\N	PRESENT	0
422781	422776	19533U	PARTICIPANT	\N	PRESENT	0
422782	422776	19593H	PARTICIPANT	\N	PRESENT	0
422729	422728	95067Q	PARTICIPANT	\N	PRESENT	0
422731	422730	98018T	PARTICIPANT	\N	PRESENT	0
422785	422777	14123H	PARTICIPANT	\N	PRESENT	0
422786	422777	19593H	PARTICIPANT	\N	PRESENT	0
422787	422777	19533U	PARTICIPANT	\N	PRESENT	0
422788	422777	19611R	PARTICIPANT	\N	PRESENT	0
422790	422778	14123H	PARTICIPANT	\N	PRESENT	0
422791	422778	19611R	PARTICIPANT	\N	PRESENT	0
422792	422778	19593H	PARTICIPANT	\N	PRESENT	0
422793	422778	19533U	PARTICIPANT	\N	PRESENT	0
422794	422789	80013X	PARTICIPANT	\N	PRESENT	0
422795	422789	14083S	PARTICIPANT	\N	PRESENT	0
422796	422789	19575F	PARTICIPANT	\N	PRESENT	0
422797	422789	14033T	PARTICIPANT	\N	PRESENT	0
422798	422789	19333N	PARTICIPANT	\N	PRESENT	0
422799	422789	19503N	PARTICIPANT	\N	PRESENT	0
422800	422789	95067Q	PARTICIPANT	\N	PRESENT	0
422805	422801	14033T	PARTICIPANT	\N	PRESENT	0
422806	422802	14033T	PARTICIPANT	\N	PRESENT	0
422807	422803	14033T	PARTICIPANT	\N	PRESENT	0
422808	422804	14033T	PARTICIPANT	\N	PRESENT	0
422821	422817	14123H	PARTICIPANT	\N	PRESENT	0
422822	422817	19758L	PARTICIPANT	\N	PRESENT	0
422824	422815	14123H	PARTICIPANT	\N	PRESENT	0
422825	422815	19611R	PARTICIPANT	\N	PRESENT	0
422829	422828	14033T	PARTICIPANT	\N	PRESENT	0
422963	422962	14255U	PARTICIPANT	\N	PRESENT	0
422964	422962	19251M	PARTICIPANT	\N	PRESENT	0
422965	422962	14087W	PARTICIPANT	\N	PRESENT	0
422966	422962	08044W	PARTICIPANT	\N	PRESENT	0
422967	422962	11026G	PARTICIPANT	\N	PRESENT	0
422968	422962	19593H	PARTICIPANT	\N	PRESENT	0
422970	422969	19251M	PARTICIPANT	\N	PRESENT	0
422971	422969	14087W	PARTICIPANT	\N	PRESENT	0
422972	422969	97011G	PARTICIPANT	\N	PRESENT	0
422973	422969	14179A	PARTICIPANT	\N	PRESENT	0
422974	422969	11085T	PARTICIPANT	\N	PRESENT	0
422975	422969	08053X	PARTICIPANT	\N	PRESENT	0
422976	422969	19593H	PARTICIPANT	\N	PRESENT	0
422977	422969	19687N	PARTICIPANT	\N	PRESENT	0
422978	422969	19689Q	PARTICIPANT	\N	PRESENT	0
422979	422969	95067Q	PARTICIPANT	\N	PRESENT	0
423031	416129	11070L	PARTICIPANT	\N	PRESENT	0
423032	420720	19333N	PARTICIPANT	\N	PRESENT	0
423033	420720	17583W	PARTICIPANT	\N	PRESENT	0
423034	420720	14031R	PARTICIPANT	\N	PRESENT	0
423035	420720	19549D	PARTICIPANT	\N	PRESENT	0
423036	420720	19387D	PARTICIPANT	\N	PRESENT	0
423037	420720	14219Q	PARTICIPANT	\N	PRESENT	0
423038	420720	19820Y	PARTICIPANT	\N	PRESENT	0
423039	420720	08055A	PARTICIPANT	\N	PRESENT	0
423040	420720	19599P	PARTICIPANT	\N	PRESENT	0
423041	420720	15447F	PARTICIPANT	\N	PRESENT	0
423042	420720	08060W	PARTICIPANT	\N	PRESENT	0
423043	420720	19503N	PARTICIPANT	\N	PRESENT	0
423044	420720	14157T	PRESIDENT	0	PRESENT	0
423045	420720	19525U	PARTICIPANT	\N	PRESENT	0
423046	420720	14051J	PARTICIPANT	\N	EXCUSE	0
423047	420720	19637C	PARTICIPANT	\N	PRESENT	0
423048	420720	19737F	PARTICIPANT	\N	PRESENT	0
423049	420720	19347U	PARTICIPANT	\N	PRESENT	0
423050	420720	19745F	PARTICIPANT	\N	PRESENT	0
423051	420720	19681G	PARTICIPANT	\N	PRESENT	0
423052	420720	08024S	PARTICIPANT	\N	PRESENT	0
423183	422485	89017R	PARTICIPANT	\N	PRESENT	0
423184	422485	14173T	PARTICIPANT	\N	PRESENT	0
423185	422485	19349W	PARTICIPANT	\N	PRESENT	0
423186	422485	19741B	PARTICIPANT	\N	PRESENT	0
423187	416129	19717B	PARTICIPANT	\N	PRESENT	0
423188	422485	19647E	PARTICIPANT	\N	PRESENT	0
423189	422485	19711U	PARTICIPANT	\N	PRESENT	0
423190	422485	19531S	PARTICIPANT	\N	PRESENT	0
423191	422485	08010L	PARTICIPANT	\N	PRESENT	0
423192	416129	19681G	PARTICIPANT	\N	PRESENT	0
423193	416129	87003B	PARTICIPANT	\N	PRESENT	0
423194	416129	14061L	PARTICIPANT	\N	PRESENT	0
423195	422485	08069G	PARTICIPANT	\N	PRESENT	0
423196	422485	14121F	PARTICIPANT	\N	PRESENT	0
423197	416129	14197C	PARTICIPANT	\N	PRESENT	0
423198	416129	14147R	PARTICIPANT	\N	PRESENT	0
423199	416129	14215L	PARTICIPANT	\N	PRESENT	0
423200	416129	14115H	PARTICIPANT	\N	PRESENT	0
423201	416129	19467C	PARTICIPANT	\N	PRESENT	0
423202	416129	14073Q	PARTICIPANT	\N	PRESENT	0
423203	416129	19747H	PARTICIPANT	\N	PRESENT	0
423204	416129	14111D	PARTICIPANT	\N	PRESENT	0
423205	416129	08015R	PARTICIPANT	\N	PRESENT	0
423206	416129	14249W	PARTICIPANT	\N	PRESENT	0
423207	416129	98022P	PARTICIPANT	\N	PRESENT	0
423208	416129	19441R	PARTICIPANT	\N	PRESENT	0
423209	416129	19573D	PARTICIPANT	\N	PRESENT	0
423218	416129	19713W	PARTICIPANT	\N	PRESENT	0
423219	416129	08062Y	PARTICIPANT	\N	PRESENT	0
423220	416129	14241N	PARTICIPANT	\N	PRESENT	0
423221	416129	80013X	PARTICIPANT	\N	PRESENT	0
423222	416129	14223L	PARTICIPANT	\N	PRESENT	0
423224	416129	19723Y	PARTICIPANT	\N	PRESENT	0
423225	416129	19762G	PARTICIPANT	\N	PRESENT	0
393135	389738	14061L	PARTICIPANT	\N	EXCUSE	0
396297	396296	14026U	PARTICIPANT	\N	PRESENT	0
396298	396296	19717B	PARTICIPANT	\N	PRESENT	0
397450	396311	01057W	PARTICIPANT	\N	PRESENT	0
400726	393611	19758L	PARTICIPANT	\N	PRESENT	0
400727	393611	17637T	PARTICIPANT	\N	PRESENT	0
400728	393611	14229S	PARTICIPANT	\N	PRESENT	0
400729	393611	19685L	PARTICIPANT	\N	PRESENT	0
400730	393611	19739H	PARTICIPANT	\N	PRESENT	0
400724	400709	14205J	PARTICIPANT	\N	PRESENT	0
400725	400709	14097Y	PARTICIPANT	\N	PRESENT	0
400731	393611	14193X	PARTICIPANT	\N	PRESENT	0
400732	393611	14331P	PARTICIPANT	\N	PRESENT	0
400733	393611	80013X	PARTICIPANT	\N	PRESENT	0
400734	393611	14042U	PARTICIPANT	\N	PRESENT	0
400735	393611	14241N	PARTICIPANT	\N	PRESENT	0
400736	393611	11031D	PARTICIPANT	\N	PRESENT	0
400737	393611	19573D	PARTICIPANT	\N	PRESENT	0
400738	393611	19711U	PARTICIPANT	\N	PRESENT	0
400739	393611	14069U	PARTICIPANT	\N	PRESENT	0
400744	396565	19367Y	PARTICIPANT	\N	PRESENT	0
400745	396565	04092N	PARTICIPANT	\N	PRESENT	0
400742	396565	14034U	PARTICIPANT	\N	PRESENT	0
400743	396565	14105F	PARTICIPANT	\N	PRESENT	0
400746	396565	11103C	PARTICIPANT	\N	PRESENT	0
400747	400603	19333N	PARTICIPANT	\N	PRESENT	0
400748	400603	19383Y	PARTICIPANT	\N	PRESENT	0
400749	400603	17583W	PARTICIPANT	\N	PRESENT	0
400750	400603	19794Q	PARTICIPANT	\N	PRESENT	0
400751	400603	95062K	PARTICIPANT	\N	PRESENT	0
400752	400603	19549D	PARTICIPANT	\N	PRESENT	0
400753	400603	19387D	PARTICIPANT	\N	PRESENT	0
400754	400603	14219Q	PARTICIPANT	\N	PRESENT	0
400755	400603	19599P	PARTICIPANT	\N	PRESENT	0
400756	400603	18083K	PARTICIPANT	\N	PRESENT	0
400757	400603	14237S	PARTICIPANT	\N	PRESENT	0
400758	400603	19551W	PARTICIPANT	\N	PRESENT	0
400759	400603	14051J	PARTICIPANT	\N	PRESENT	0
400760	400603	08060W	PARTICIPANT	\N	PRESENT	0
400761	400603	19503N	PARTICIPANT	\N	PRESENT	0
400762	400603	19685L	PARTICIPANT	\N	PRESENT	0
400763	400603	08024S	PARTICIPANT	\N	PRESENT	0
400764	400603	11065P	PARTICIPANT	\N	PRESENT	0
400765	400603	19525U	PARTICIPANT	\N	PRESENT	0
400766	400603	14038Y	PRESIDENT	0	PRESENT	0
400767	400603	14103D	PARTICIPANT	\N	PRESENT	0
400768	400603	14031R	PARTICIPANT	\N	PRESENT	0
400769	400603	08055A	PARTICIPANT	\N	PRESENT	0
400770	400603	14169X	PARTICIPANT	\N	PRESENT	0
400771	400603	19733B	PARTICIPANT	\N	PRESENT	0
400772	400603	19737F	PARTICIPANT	\N	PRESENT	0
400773	400603	04097T	PARTICIPANT	\N	PRESENT	0
400774	400603	19739H	PARTICIPANT	\N	PRESENT	0
400775	400603	19745F	PARTICIPANT	\N	PRESENT	0
400776	396565	19415P	PARTICIPANT	\N	PRESENT	0
400777	396565	11066Q	PARTICIPANT	\N	PRESENT	0
400778	396565	11031D	PARTICIPANT	\N	PRESENT	0
400779	396565	19798U	PARTICIPANT	\N	PRESENT	0
400780	400273	19467C	PARTICIPANT	\N	PRESENT	0
400781	400273	19515S	PARTICIPANT	\N	PRESENT	0
400782	400273	19782L	PARTICIPANT	\N	PRESENT	0
400783	400273	19441R	PARTICIPANT	\N	PRESENT	0
400784	400273	08062Y	PARTICIPANT	\N	PRESENT	0
400785	400273	19695N	PARTICIPANT	\N	PRESENT	0
400786	400273	14033T	PARTICIPANT	\N	PRESENT	0
400787	400273	11090Q	PRESIDENT	0	PRESENT	0
400788	400273	01025N	PARTICIPANT	\N	PRESENT	0
400789	400273	80013X	PARTICIPANT	\N	PRESENT	0
400790	400273	19269X	PARTICIPANT	\N	PRESENT	0
400791	400273	14205J	PARTICIPANT	\N	PRESENT	0
400792	400273	11056N	PARTICIPANT	\N	PRESENT	0
400793	400273	11099A	PARTICIPANT	\N	PRESENT	0
400794	400273	08068F	PARTICIPANT	\N	PRESENT	0
400795	400273	04049K	PARTICIPANT	\N	PRESENT	0
400796	400273	19507S	PARTICIPANT	\N	PRESENT	0
400797	400273	08015R	PARTICIPANT	\N	PRESENT	0
400798	400273	14197C	PARTICIPANT	\N	PRESENT	0
400799	400273	19511N	PARTICIPANT	\N	PRESENT	0
400800	400273	08028W	PARTICIPANT	\N	PRESENT	0
400801	400273	14265W	PARTICIPANT	\N	PRESENT	0
400802	400273	17589D	PARTICIPANT	\N	PRESENT	0
400803	400273	14257W	PARTICIPANT	\N	PRESENT	0
400804	400273	19812Y	PARTICIPANT	\N	EXCUSE	0
400805	400273	19295A	PARTICIPANT	\N	EXCUSE	0
400806	400273	11081P	PARTICIPANT	\N	EXCUSE	0
400810	396565	08052W	PARTICIPANT	\N	PRESENT	0
400811	396565	08017T	PARTICIPANT	\N	PRESENT	0
400812	396565	08043V	PARTICIPANT	\N	PRESENT	0
400813	396565	19593H	PARTICIPANT	\N	PRESENT	0
400814	396565	19758L	PARTICIPANT	\N	PRESENT	0
400815	396565	19551W	PARTICIPANT	\N	PRESENT	0
400816	396565	19727D	PARTICIPANT	\N	PRESENT	0
400817	396565	14239U	PARTICIPANT	\N	PRESENT	0
400818	396565	19697Q	PARTICIPANT	\N	PRESENT	0
400819	400273	04088S	PARTICIPANT	\N	PRESENT	0
400820	400273	19747H	PARTICIPANT	\N	PRESENT	0
400821	396565	19333N	PARTICIPANT	\N	PRESENT	0
400822	396565	14121F	PARTICIPANT	\N	PRESENT	0
400823	396565	19387D	PARTICIPANT	\N	PRESENT	0
400824	396565	08049C	PARTICIPANT	\N	PRESENT	0
400825	396565	19553Y	PARTICIPANT	\N	PRESENT	0
400826	396565	14195A	PARTICIPANT	\N	PRESENT	0
400827	396565	14042U	PARTICIPANT	\N	PRESENT	0
400828	396565	19611R	PARTICIPANT	\N	PRESENT	0
400829	396565	14089Y	PARTICIPANT	\N	PRESENT	0
400830	396565	14051J	PARTICIPANT	\N	PRESENT	0
400831	396565	14237S	PARTICIPANT	\N	PRESENT	0
400832	396565	11097X	PARTICIPANT	\N	PRESENT	0
400833	396565	04018C	PARTICIPANT	\N	PRESENT	0
400834	396565	19383Y	PARTICIPANT	\N	PRESENT	0
400835	396565	14217N	PARTICIPANT	\N	PRESENT	0
400836	396565	14063N	PARTICIPANT	\N	PRESENT	0
400837	396565	14223L	PARTICIPANT	\N	PRESENT	0
400838	396565	19575F	PARTICIPANT	\N	PRESENT	0
400839	396565	14041T	PARTICIPANT	\N	PRESENT	0
400840	396565	18083K	PARTICIPANT	\N	PRESENT	0
400841	396565	14119M	PARTICIPANT	\N	PRESENT	0
400842	396565	19549D	PARTICIPANT	\N	PRESENT	0
400843	396565	04035D	PARTICIPANT	\N	PRESENT	0
400844	396565	08024S	PARTICIPANT	\N	PRESENT	0
400845	396565	14169X	PARTICIPANT	\N	PRESENT	0
400846	396565	14123H	PARTICIPANT	\N	PRESENT	0
400847	396565	14207L	PARTICIPANT	\N	PRESENT	0
400848	396565	97011G	PARTICIPANT	\N	PRESENT	0
400849	396565	17637T	PARTICIPANT	\N	PRESENT	0
400850	396565	19794Q	PARTICIPANT	\N	PRESENT	0
400851	396565	95062K	PARTICIPANT	\N	PRESENT	0
400852	396565	14257W	PARTICIPANT	\N	PRESENT	0
400853	396565	14205J	PARTICIPANT	\N	PRESENT	0
400854	396565	17583W	PARTICIPANT	\N	PRESENT	0
400855	396565	04088S	PARTICIPANT	\N	PRESENT	0
400856	396565	19515S	PARTICIPANT	\N	PRESENT	0
400857	396565	01024M	PARTICIPANT	\N	PRESENT	0
400858	396565	10006L	PARTICIPANT	\N	PRESENT	0
400859	396565	95030B	PARTICIPANT	\N	PRESENT	0
400860	396565	14038Y	PARTICIPANT	\N	PRESENT	0
400861	396565	19563B	PARTICIPANT	\N	PRESENT	0
400862	396565	19503N	PARTICIPANT	\N	PRESENT	0
400863	396565	14261S	PARTICIPANT	\N	PRESENT	0
400864	396565	19782L	PARTICIPANT	\N	PRESENT	0
400865	396565	19591F	PARTICIPANT	\N	PRESENT	0
400866	396565	14197C	PARTICIPANT	\N	PRESENT	0
400867	396565	19347U	PARTICIPANT	\N	PRESENT	0
400868	396565	01025N	PARTICIPANT	\N	PRESENT	0
400869	396565	19507S	PARTICIPANT	\N	PRESENT	0
400870	396565	19447X	PARTICIPANT	\N	PRESENT	0
400871	396565	14157T	PARTICIPANT	\N	PRESENT	0
400872	396565	14357A	PARTICIPANT	\N	PRESENT	0
400873	396565	19745F	PARTICIPANT	\N	PRESENT	0
400874	396565	14211G	PARTICIPANT	\N	PRESENT	0
400875	396565	14073Q	PARTICIPANT	\N	PRESENT	0
400876	396565	14219Q	PARTICIPANT	\N	PRESENT	0
400877	396565	19685L	PARTICIPANT	\N	PRESENT	0
400878	396565	19511N	PARTICIPANT	\N	PRESENT	0
400879	396565	19762G	PARTICIPANT	\N	PRESENT	0
400880	396565	14103D	PARTICIPANT	\N	PRESENT	0
400881	396565	14107H	PARTICIPANT	\N	PRESENT	0
400882	396565	14033T	PARTICIPANT	\N	PRESENT	0
400883	396565	19421M	PARTICIPANT	\N	PRESENT	0
400884	396565	14259Y	PARTICIPANT	\N	PRESENT	0
400885	396565	19693L	PARTICIPANT	\N	PRESENT	0
400886	396565	14147R	PARTICIPANT	\N	PRESENT	0
400887	396565	19651A	PARTICIPANT	\N	PRESENT	0
400888	396565	08062Y	PARTICIPANT	\N	PRESENT	0
400904	396565	87003B	PARTICIPANT	\N	PRESENT	0
400906	396565	14109K	PARTICIPANT	\N	PRESENT	0
400910	396565	98029W	PARTICIPANT	\N	PRESENT	0
400911	396565	88008L	PARTICIPANT	\N	PRESENT	0
400912	396565	19719D	PARTICIPANT	\N	PRESENT	0
409857	402300	19758L	PARTICIPANT	\N	PRESENT	0
409924	402303	14207L	PARTICIPANT	\N	PRESENT	0
409925	402303	08031R	PARTICIPANT	\N	PRESENT	0
409926	402303	11012A	PARTICIPANT	\N	PRESENT	0
409927	402303	14257W	PARTICIPANT	\N	PRESENT	0
409954	402303	08053X	PARTICIPANT	\N	PRESENT	0
409956	402303	14255U	PARTICIPANT	\N	PRESENT	0
409930	402303	19551W	PARTICIPANT	\N	PRESENT	0
409931	402303	04085P	PARTICIPANT	\N	PRESENT	0
409932	402303	19758L	PARTICIPANT	\N	PRESENT	0
409933	402303	08020N	PARTICIPANT	\N	PRESENT	0
409934	402303	19679N	PARTICIPANT	\N	PRESENT	0
409935	402303	14261S	PARTICIPANT	\N	PRESENT	0
409936	402303	04018C	PARTICIPANT	\N	PRESENT	0
409937	402303	10006L	PARTICIPANT	\N	PRESENT	0
409938	402303	14157T	PARTICIPANT	\N	PRESENT	0
409939	402303	19798U	PARTICIPANT	\N	PRESENT	0
409940	402303	19703U	PARTICIPANT	\N	PRESENT	0
409941	402303	14069U	PARTICIPANT	\N	PRESENT	0
409942	402303	19794Q	PARTICIPANT	\N	PRESENT	0
409943	402303	19723Y	PARTICIPANT	\N	PRESENT	0
409944	402303	88008L	PARTICIPANT	\N	PRESENT	0
409945	402303	11097X	PARTICIPANT	\N	PRESENT	0
409946	402303	19581D	PARTICIPANT	\N	PRESENT	0
409947	402303	11077T	PARTICIPANT	\N	PRESENT	0
409948	402303	14038Y	PARTICIPANT	\N	PRESENT	0
409949	402303	19347U	PARTICIPANT	\N	PRESENT	0
409950	402303	14105F	PARTICIPANT	\N	PRESENT	0
409951	402303	14121F	PARTICIPANT	\N	PRESENT	0
409952	402303	19593H	PARTICIPANT	\N	PRESENT	0
409953	402303	11064N	PARTICIPANT	\N	PRESENT	0
409955	402303	96004D	PARTICIPANT	\N	PRESENT	0
409957	409125	04044E	PARTICIPANT	\N	PRESENT	0
409958	409125	11072N	PARTICIPANT	\N	PRESENT	0
409959	402303	19727D	PARTICIPANT	\N	PRESENT	0
409960	402303	11067R	PARTICIPANT	\N	PRESENT	0
409961	402303	19335Q	PARTICIPANT	\N	PRESENT	0
409962	402303	08039A	PARTICIPANT	\N	PRESENT	0
409963	409125	14147R	PARTICIPANT	\N	PRESENT	0
409964	402303	19269X	PARTICIPANT	\N	PRESENT	0
409965	402303	14109K	PARTICIPANT	\N	PRESENT	0
409966	409125	14001X	PARTICIPANT	\N	PRESENT	0
409967	409125	14021P	PARTICIPANT	\N	PRESENT	0
409968	402303	19701S	PARTICIPANT	\N	PRESENT	0
409969	402303	19369B	PARTICIPANT	\N	PRESENT	0
409970	402303	14205J	PARTICIPANT	\N	PRESENT	0
409999	409997	14241N	PARTICIPANT	\N	EXCUSE	0
410000	409997	14065Q	PARTICIPANT	\N	PRESENT	0
410001	409997	96004D	PARTICIPANT	\N	EXCUSE	0
410002	409997	11083R	PARTICIPANT	\N	PRESENT	0
410003	409997	19725B	PARTICIPANT	\N	PRESENT	0
410004	409997	95037J	PARTICIPANT	\N	PRESENT	0
410005	409997	19569H	PARTICIPANT	\N	PRESENT	0
410006	409997	14097Y	PARTICIPANT	\N	PRESENT	0
410007	409997	14061L	PARTICIPANT	\N	EXCUSE	0
410008	409997	04057K	PARTICIPANT	\N	EXCUSE	0
410009	409997	19563B	PARTICIPANT	\N	PRESENT	0
410010	409997	14237S	PARTICIPANT	\N	EXCUSE	0
410011	409997	14135M	PARTICIPANT	\N	PRESENT	0
410012	409997	14331P	PARTICIPANT	\N	EXCUSE	0
410013	409997	14225N	PARTICIPANT	\N	EXCUSE	0
410014	409997	10015M	PRESIDENT	0	PRESENT	0
409922	402303	04086Q	PARTICIPANT	\N	PRESENT	0
409923	402303	14107H	PARTICIPANT	\N	PRESENT	0
410015	409997	14205J	PARTICIPANT	\N	PRESENT	0
410075	407151	11067R	PARTICIPANT	\N	PRESENT	0
410076	407151	04092N	PRESIDENT	0	PRESENT	0
410077	407151	19565D	PARTICIPANT	\N	PRESENT	0
410078	407151	19798U	PARTICIPANT	\N	PRESENT	0
410079	407151	11097X	PARTICIPANT	\N	PRESENT	0
410080	407151	08052W	PARTICIPANT	\N	PRESENT	0
410081	407151	19415P	PARTICIPANT	\N	PRESENT	0
410082	407151	14026U	PARTICIPANT	\N	PRESENT	0
410083	407151	19723Y	PARTICIPANT	\N	PRESENT	0
410084	407151	11031D	PARTICIPANT	\N	PRESENT	0
410085	407151	19727D	PARTICIPANT	\N	PRESENT	0
410086	407151	14119M	PARTICIPANT	\N	PRESENT	0
410087	407151	11103C	PARTICIPANT	\N	PRESENT	0
410088	407151	19679N	PARTICIPANT	\N	PRESENT	0
410089	407151	08048B	PARTICIPANT	\N	PRESENT	0
410090	407151	14213J	PARTICIPANT	\N	PRESENT	0
410091	407151	14071N	PARTICIPANT	\N	PRESENT	0
410092	407151	14217N	PARTICIPANT	\N	PRESENT	0
410093	407151	19683J	PARTICIPANT	\N	PRESENT	0
410094	407151	98024R	PRESIDENT	1	PRESENT	0
410095	407151	19575F	PARTICIPANT	\N	EXCUSE	0
410096	407151	08041T	PARTICIPANT	\N	EXCUSE	0
410103	402304	19583F	PARTICIPANT	\N	PRESENT	0
410104	402304	80013X	PARTICIPANT	\N	PRESENT	0
410105	402304	14179A	PARTICIPANT	\N	PRESENT	0
410207	402306	10006L	PARTICIPANT	\N	PRESENT	0
410208	402306	19583F	PARTICIPANT	\N	PRESENT	0
410209	402306	19319Q	PARTICIPANT	\N	PRESENT	0
410210	402306	19731Y	PARTICIPANT	\N	PRESENT	0
410211	402306	19415P	PARTICIPANT	\N	PRESENT	0
410212	402306	14105F	PARTICIPANT	\N	PRESENT	0
410213	402306	19533U	PARTICIPANT	\N	PRESENT	0
410214	402306	19711U	PARTICIPANT	\N	PRESENT	0
410215	402306	14042U	PARTICIPANT	\N	PRESENT	0
410216	402306	08031R	PARTICIPANT	\N	PRESENT	0
410217	402306	14147R	PARTICIPANT	\N	PRESENT	0
410218	402306	11067R	PARTICIPANT	\N	PRESENT	0
410219	402306	19649G	PARTICIPANT	\N	PRESENT	0
410220	402306	14021P	PARTICIPANT	\N	PRESENT	0
410221	402306	19591F	PARTICIPANT	\N	PRESENT	0
410222	402306	11072N	PARTICIPANT	\N	PRESENT	0
410223	402306	14030Q	PARTICIPANT	\N	PRESENT	0
410224	402306	19794Q	PARTICIPANT	\N	PRESENT	0
410225	402306	14217N	PARTICIPANT	\N	PRESENT	0
410226	402306	19467C	PARTICIPANT	\N	PRESENT	0
410227	402306	19715Y	PARTICIPANT	\N	PRESENT	0
410228	402306	14073Q	PARTICIPANT	\N	PRESENT	0
410229	402306	08010L	PARTICIPANT	\N	PRESENT	0
410579	402306	11097X	PARTICIPANT	\N	PRESENT	0
410580	402306	18083K	PARTICIPANT	\N	PRESENT	0
410581	402306	19329S	PARTICIPANT	\N	PRESENT	0
410582	402306	19631V	PARTICIPANT	\N	PRESENT	0
410583	402306	99004R	PARTICIPANT	\N	PRESENT	0
410586	402306	01028R	PARTICIPANT	\N	PRESENT	0
410587	402306	11033F	PARTICIPANT	\N	PRESENT	0
410588	402306	11012A	PARTICIPANT	\N	PRESENT	0
410589	402306	19701S	PARTICIPANT	\N	PRESENT	0
410590	402306	14211G	PARTICIPANT	\N	PRESENT	0
410205	402306	04044E	PARTICIPANT	\N	PRESENT	0
410206	402306	19749K	PARTICIPANT	\N	PRESENT	0
410592	402306	14249W	PARTICIPANT	\N	PRESENT	0
410593	402306	19347U	PARTICIPANT	\N	PRESENT	0
410594	402306	14197C	PARTICIPANT	\N	PRESENT	0
410595	402306	14039A	PARTICIPANT	\N	PRESENT	0
410597	402306	14265W	PARTICIPANT	\N	PRESENT	0
410598	402306	11043H	PARTICIPANT	\N	PRESENT	0
410599	402306	11031D	PARTICIPANT	\N	PRESENT	0
410600	402306	08019V	PARTICIPANT	\N	PRESENT	0
410601	402306	14065Q	PARTICIPANT	\N	PRESENT	0
410602	402306	19611R	PARTICIPANT	\N	PRESENT	0
410603	402306	11010L	PARTICIPANT	\N	PRESENT	0
410616	402306	19577H	PARTICIPANT	\N	PRESENT	0
410626	402306	19683J	PARTICIPANT	\N	PRESENT	0
410627	402306	08020N	PARTICIPANT	\N	PRESENT	0
410628	402306	04092N	PARTICIPANT	\N	PRESENT	0
501258	498247	19399H	PARTICIPANT	\N	PRESENT	0
501259	498247	20052X	PARTICIPANT	\N	PRESENT	0
501260	498247	19699S	PARTICIPANT	\N	PRESENT	0
501261	498247	04059M	PARTICIPANT	\N	PRESENT	0
501262	498247	19651A	PARTICIPANT	\N	PRESENT	0
501263	498247	20142Y	PARTICIPANT	\N	PRESENT	0
501264	498247	04070G	PARTICIPANT	\N	PRESENT	0
501265	498243	19399H	PARTICIPANT	\N	PRESENT	0
501266	498243	19699S	PARTICIPANT	\N	PRESENT	0
501267	498243	20142Y	PARTICIPANT	\N	PRESENT	0
501268	498243	04070G	PARTICIPANT	\N	PRESENT	0
501269	498243	20052X	PARTICIPANT	\N	PRESENT	0
501270	498243	04059M	PARTICIPANT	\N	PRESENT	0
501274	498255	11043H	PARTICIPANT	\N	PRESENT	0
501275	498255	19527W	PARTICIPANT	\N	PRESENT	0
501276	498256	19527W	PARTICIPANT	\N	PRESENT	0
501277	498256	11043H	PARTICIPANT	\N	PRESENT	0
501278	498257	11043H	PARTICIPANT	\N	PRESENT	0
501380	501342	14329V	PARTICIPANT	\N	PRESENT	0
501386	501385	14329V	PARTICIPANT	\N	PRESENT	0
501797	500282	19347U	PARTICIPANT	\N	PRESENT	0
501798	500477	11026G	PARTICIPANT	\N	PRESENT	0
501799	500477	20050V	PARTICIPANT	\N	EXCUSE	0
501800	500282	14259Y	PARTICIPANT	\N	PRESENT	0
501801	500282	17367Q	PARTICIPANT	\N	PRESENT	0
501802	500282	14083S	PARTICIPANT	\N	PRESENT	0
501803	500282	08009T	PARTICIPANT	\N	PRESENT	0
501804	500282	19705W	PARTICIPANT	\N	PRESENT	0
501805	500282	19553Y	PARTICIPANT	\N	PRESENT	0
399888	399887	14173T	PARTICIPANT	\N	PRESENT	0
399889	399887	19762G	PARTICIPANT	\N	PRESENT	0
399890	399887	19447X	PARTICIPANT	\N	PRESENT	0
401555	400285	11012A	PARTICIPANT	\N	PRESENT	0
401556	400285	07029T	PARTICIPANT	\N	PRESENT	0
401558	400285	11074Q	PRESIDENT	0	PRESENT	0
401559	400285	19349W	PARTICIPANT	\N	PRESENT	0
401560	400285	14199E	PARTICIPANT	\N	PRESENT	0
401561	400285	01048V	PARTICIPANT	\N	PRESENT	0
401562	400285	14083S	PARTICIPANT	\N	PRESENT	0
401566	401557	19766L	PARTICIPANT	\N	PRESENT	0
401567	401557	04070G	PRESIDENT	0	PRESENT	0
401568	401557	19533U	PARTICIPANT	\N	PRESENT	0
401569	401557	14229S	PARTICIPANT	\N	PRESENT	0
401570	401557	14241N	PARTICIPANT	\N	PRESENT	0
401571	401557	19573D	PARTICIPANT	\N	PRESENT	0
401572	401557	14039A	PARTICIPANT	\N	PRESENT	0
401573	401557	08017T	PARTICIPANT	\N	PRESENT	0
401574	401557	14179A	PARTICIPANT	\N	PRESENT	0
401575	401557	14249W	PARTICIPANT	\N	PRESENT	0
401576	401557	08039A	PARTICIPANT	\N	PRESENT	0
401577	401557	08031R	PARTICIPANT	\N	PRESENT	0
401578	401557	19593H	PARTICIPANT	\N	PRESENT	0
401579	401557	14073Q	PARTICIPANT	\N	PRESENT	0
401580	401557	19611R	PARTICIPANT	\N	PRESENT	0
401581	401557	08043V	PARTICIPANT	\N	PRESENT	0
401582	401557	19693L	PARTICIPANT	\N	PRESENT	0
401583	401557	87003B	PARTICIPANT	\N	PRESENT	0
401584	401557	14030Q	PARTICIPANT	\N	PRESENT	0
401585	401557	04059M	PARTICIPANT	\N	PRESENT	0
401586	401557	14063N	PARTICIPANT	\N	PRESENT	0
401587	401557	11083R	PARTICIPANT	\N	PRESENT	0
401588	401557	14123H	PARTICIPANT	\N	PRESENT	0
401589	401557	11043H	PARTICIPANT	\N	PRESENT	0
401590	401557	19749K	PARTICIPANT	\N	PRESENT	0
401591	401557	04018C	PARTICIPANT	\N	PRESENT	0
401592	401557	19758L	PARTICIPANT	\N	PRESENT	0
401593	400285	11048N	PARTICIPANT	\N	PRESENT	0
401601	401557	14061L	PARTICIPANT	\N	PRESENT	0
401602	401557	08020N	PARTICIPANT	\N	PRESENT	0
401603	401557	14109K	PARTICIPANT	\N	PRESENT	0
401604	401557	14059S	PARTICIPANT	\N	EXCUSE	0
401605	401557	04057K	PARTICIPANT	\N	EXCUSE	0
401606	401557	14107H	PARTICIPANT	\N	EXCUSE	0
401607	401557	19735D	PARTICIPANT	\N	EXCUSE	0
401608	401557	14201E	PARTICIPANT	\N	EXCUSE	0
401614	400285	11053K	PARTICIPANT	\N	PRESENT	0
401615	400285	14085U	PARTICIPANT	\N	PRESENT	0
401616	400285	14121F	PARTICIPANT	\N	PRESENT	0
401617	400285	19687N	PARTICIPANT	\N	PRESENT	0
401618	400285	96004D	PARTICIPANT	\N	PRESENT	0
401621	400285	14034U	PARTICIPANT	\N	PRESENT	0
401622	400285	08011M	PARTICIPANT	\N	PRESENT	0
401623	400276	19768N	PARTICIPANT	\N	PRESENT	0
401624	400276	19515S	PARTICIPANT	\N	PRESENT	0
401625	400276	19782L	PARTICIPANT	\N	PRESENT	0
401626	400276	80013X	PARTICIPANT	\N	PRESENT	0
401627	400276	11099A	PARTICIPANT	\N	PRESENT	0
401628	400276	08068F	PARTICIPANT	\N	PRESENT	0
401629	400276	04049K	PARTICIPANT	\N	PRESENT	0
401630	400276	19705W	PARTICIPANT	\N	PRESENT	0
401631	400276	08015R	PARTICIPANT	\N	PRESENT	0
401632	400276	14197C	PARTICIPANT	\N	PRESENT	0
401633	400276	19511N	PARTICIPANT	\N	PRESENT	0
401634	400276	08028W	PARTICIPANT	\N	PRESENT	0
401635	400276	14265W	PARTICIPANT	\N	PRESENT	0
401636	400276	14329V	PARTICIPANT	\N	PRESENT	0
401637	400276	14135M	PARTICIPANT	\N	PRESENT	0
401638	400276	19467C	PARTICIPANT	\N	PRESENT	0
401639	400276	14187A	PARTICIPANT	\N	PRESENT	0
401640	400276	08062Y	PARTICIPANT	\N	PRESENT	0
401641	400276	19695N	PARTICIPANT	\N	PRESENT	0
401642	400276	14033T	PARTICIPANT	\N	PRESENT	0
401643	400276	01025N	PARTICIPANT	\N	PRESENT	0
401644	400276	11090Q	PRESIDENT	0	PRESENT	0
401645	400276	19269X	PARTICIPANT	\N	PRESENT	0
401646	400276	14205J	PARTICIPANT	\N	PRESENT	0
401647	400276	04088S	PARTICIPANT	\N	PRESENT	0
401648	400276	11056N	PARTICIPANT	\N	PRESENT	0
401649	400276	19507S	PARTICIPANT	\N	PRESENT	0
401650	400276	14207L	PARTICIPANT	\N	PRESENT	0
401651	400276	19747H	PARTICIPANT	\N	PRESENT	0
401652	400276	04043D	PARTICIPANT	\N	PRESENT	0
401653	400276	17589D	PARTICIPANT	\N	PRESENT	0
401654	400276	14257W	PARTICIPANT	\N	PRESENT	0
401655	400276	08038Y	PARTICIPANT	\N	PRESENT	0
402963	402962	14207L	PARTICIPANT	\N	PRESENT	0
402964	402962	14197C	PARTICIPANT	\N	PRESENT	0
402965	402962	14187A	PARTICIPANT	\N	PRESENT	0
402966	402962	14265W	PARTICIPANT	\N	PRESENT	0
402967	402962	08039A	PARTICIPANT	\N	PRESENT	0
402968	402962	14107H	PARTICIPANT	\N	PRESENT	0
405015	404987	17583W	PARTICIPANT	\N	PRESENT	0
405016	404987	08009T	PRESIDENT	0	PRESENT	0
405017	404987	05012A	PARTICIPANT	\N	EXCUSE	0
405018	404987	14051J	PARTICIPANT	\N	EXCUSE	0
405019	404987	19681G	PARTICIPANT	\N	EXCUSE	0
405025	404987	08060W	PARTICIPANT	\N	PRESENT	0
405026	404987	19794Q	PARTICIPANT	\N	PRESENT	0
405027	404987	95062K	PARTICIPANT	\N	PRESENT	0
405028	404987	14038Y	PARTICIPANT	\N	PRESENT	0
405029	404987	19333N	PARTICIPANT	\N	PRESENT	0
405030	404987	19549D	PARTICIPANT	\N	PRESENT	0
405031	404987	14219Q	PARTICIPANT	\N	PRESENT	0
405034	404987	19737F	PARTICIPANT	\N	PRESENT	0
405035	404987	08024S	PARTICIPANT	\N	PRESENT	0
405036	404987	14237S	PARTICIPANT	\N	PRESENT	0
409109	407544	11041F	PARTICIPANT	\N	EXCUSE	0
410052	405449	19253P	PARTICIPANT	\N	PRESENT	0
405039	404987	14093U	PARTICIPANT	\N	PRESENT	0
405040	404987	19503N	PARTICIPANT	\N	PRESENT	0
405041	404987	19701S	PARTICIPANT	\N	PRESENT	0
410051	405449	14069U	PARTICIPANT	\N	PRESENT	0
410053	405449	19525U	PARTICIPANT	\N	PRESENT	0
410054	405449	04086Q	PARTICIPANT	\N	PRESENT	0
410055	405449	14281W	PARTICIPANT	\N	PRESENT	0
410056	405449	14231L	PARTICIPANT	\N	PRESENT	0
410057	405449	01057W	PARTICIPANT	\N	PRESENT	0
410058	405449	08010L	PARTICIPANT	\N	PRESENT	0
410060	405449	08034U	PARTICIPANT	\N	PRESENT	0
410061	405449	14063N	PARTICIPANT	\N	PRESENT	0
410062	405449	05012A	PARTICIPANT	\N	PRESENT	0
410063	405449	95063L	PARTICIPANT	\N	PRESENT	0
410064	405449	19687N	PARTICIPANT	\N	PRESENT	0
410065	405449	04045F	PARTICIPANT	\N	PRESENT	0
410788	410787	19693L	PARTICIPANT	\N	PRESENT	0
410791	410787	01048V	PARTICIPANT	\N	PRESENT	0
410792	410787	14221J	PARTICIPANT	\N	PRESENT	0
410793	410787	19503N	PARTICIPANT	\N	PRESENT	0
410794	410787	04043D	PARTICIPANT	\N	PRESENT	0
414331	413405	08010L	PARTICIPANT	\N	PRESENT	0
414332	413405	07029T	PARTICIPANT	\N	EXCUSE	0
414333	413405	14159V	PARTICIPANT	\N	EXCUSE	0
414334	406851	19687N	PARTICIPANT	\N	PRESENT	0
414335	406851	19387D	PARTICIPANT	\N	PRESENT	0
414337	406851	19693L	PARTICIPANT	\N	PRESENT	0
414338	406851	19733B	PARTICIPANT	\N	PRESENT	0
414339	414028	11080N	PARTICIPANT	\N	PRESENT	0
414340	406851	15447F	PARTICIPANT	\N	PRESENT	0
414341	406851	01028R	PARTICIPANT	\N	PRESENT	0
414342	406851	19383Y	PARTICIPANT	\N	PRESENT	0
414343	406851	04069P	PARTICIPANT	\N	PRESENT	0
414344	414028	14133K	PARTICIPANT	\N	PRESENT	0
414345	406851	14026U	PARTICIPANT	\N	PRESENT	0
414346	406851	14065Q	PARTICIPANT	\N	PRESENT	0
414347	406851	14109K	PARTICIPANT	\N	PRESENT	0
414351	406851	14281W	PARTICIPANT	\N	PRESENT	0
414349	406851	19415P	PARTICIPANT	\N	PRESENT	0
414350	406851	08015R	PARTICIPANT	\N	PRESENT	0
414352	406851	08039A	PARTICIPANT	\N	PRESENT	0
414353	406851	14229S	PARTICIPANT	\N	PRESENT	0
414354	406851	14199E	PARTICIPANT	\N	PRESENT	0
414355	406851	19575F	PARTICIPANT	\N	PRESENT	0
414356	406851	19703U	PARTICIPANT	\N	PRESENT	0
414357	406851	08045X	PARTICIPANT	\N	PRESENT	0
414358	406851	14030Q	PARTICIPANT	\N	PRESENT	0
414359	406851	19760E	PARTICIPANT	\N	PRESENT	0
414360	413405	19689Q	PARTICIPANT	\N	PRESENT	0
414361	413405	12016W	PARTICIPANT	\N	PRESENT	0
414362	413405	89017R	PARTICIPANT	\N	PRESENT	0
414363	413405	14083S	PARTICIPANT	\N	PRESENT	0
414364	413405	08011M	PARTICIPANT	\N	PRESENT	0
414365	406851	19349W	PARTICIPANT	\N	PRESENT	0
414366	406851	04018C	PARTICIPANT	\N	PRESENT	0
414367	406851	19727D	PARTICIPANT	\N	PRESENT	0
414368	406851	19768N	PARTICIPANT	\N	PRESENT	0
414369	406851	14107H	PARTICIPANT	\N	PRESENT	0
421261	421260	14083S	PARTICIPANT	\N	PRESENT	0
421262	421260	14061L	PARTICIPANT	\N	PRESENT	0
421263	421260	19671E	PARTICIPANT	\N	PRESENT	0
421265	421264	04049K	PARTICIPANT	\N	PRESENT	0
421266	421264	14026U	PARTICIPANT	\N	PRESENT	0
421267	421264	14261S	PARTICIPANT	\N	PRESENT	0
421268	421264	14083S	PARTICIPANT	\N	PRESENT	0
421269	421264	19521Q	PARTICIPANT	\N	PRESENT	0
421270	421264	04088S	PARTICIPANT	\N	PRESENT	0
421273	421272	14083S	PARTICIPANT	\N	PRESENT	0
421274	421272	14061L	PARTICIPANT	\N	PRESENT	0
422901	422900	08011M	PARTICIPANT	\N	PRESENT	0
422902	422900	14225N	PARTICIPANT	\N	PRESENT	0
422903	422900	01057W	PARTICIPANT	\N	PRESENT	0
422904	422900	14199E	PARTICIPANT	\N	PRESENT	0
422905	422900	14327T	PARTICIPANT	\N	PRESENT	0
423082	421729	92040Q	PARTICIPANT	\N	EXCUSE	0
423213	423210	14063N	PARTICIPANT	\N	PRESENT	0
423211	423210	11048N	PARTICIPANT	\N	PRESENT	0
423212	423210	19711U	PARTICIPANT	\N	PRESENT	0
423214	423210	15447F	PARTICIPANT	\N	PRESENT	0
423215	423210	19553Y	PARTICIPANT	\N	PRESENT	0
423216	423210	14255U	PARTICIPANT	\N	PRESENT	0
423223	421729	08038Y	PARTICIPANT	\N	EXCUSE	0
423405	416296	14217N	PARTICIPANT	\N	PRESENT	0
423406	416296	19798U	PARTICIPANT	\N	PRESENT	0
423407	416296	14173T	PARTICIPANT	\N	PRESENT	0
423470	416297	14071N	PARTICIPANT	\N	PRESENT	0
423471	416297	14063N	PARTICIPANT	\N	PRESENT	0
423472	416297	19251M	PARTICIPANT	\N	PRESENT	0
423473	416297	19725B	PARTICIPANT	\N	PRESENT	0
423474	416297	01028R	PARTICIPANT	\N	PRESENT	0
423537	416297	14237S	PARTICIPANT	\N	PRESENT	0
423476	416297	14121F	PARTICIPANT	\N	PRESENT	0
423477	416297	19681G	PARTICIPANT	\N	PRESENT	0
423478	416297	14111D	PARTICIPANT	\N	PRESENT	0
423479	416297	19563B	PARTICIPANT	\N	PRESENT	0
423480	416297	04057K	PARTICIPANT	\N	PRESENT	0
423481	416297	19253P	PARTICIPANT	\N	PRESENT	0
423482	416297	19717B	PARTICIPANT	\N	PRESENT	0
423483	416297	14107H	PARTICIPANT	\N	PRESENT	0
423484	416297	14261S	PARTICIPANT	\N	PRESENT	0
423485	416297	19691J	PARTICIPANT	\N	PRESENT	0
423486	416297	19713W	PARTICIPANT	\N	PRESENT	0
423487	416297	19737F	PARTICIPANT	\N	PRESENT	0
423488	416297	14028W	PARTICIPANT	\N	PRESENT	0
423489	416297	14059S	PARTICIPANT	\N	PRESENT	0
423490	416297	97011G	PARTICIPANT	\N	PRESENT	0
423491	416297	14026U	PARTICIPANT	\N	PRESENT	0
423492	416297	14123H	PARTICIPANT	\N	PRESENT	0
423493	416297	14217N	PARTICIPANT	\N	PRESENT	0
423494	416297	19798U	PARTICIPANT	\N	PRESENT	0
423495	416297	08028W	PARTICIPANT	\N	PRESENT	0
423496	416297	14069U	PARTICIPANT	\N	PRESENT	0
423497	416297	87003B	PARTICIPANT	\N	PRESENT	0
423498	416297	14157T	PARTICIPANT	\N	PRESENT	0
423499	416297	08062Y	PARTICIPANT	\N	PRESENT	0
423500	416297	11101A	PARTICIPANT	\N	PRESENT	0
423501	416297	19415P	PARTICIPANT	\N	PRESENT	0
423502	416297	19794Q	PARTICIPANT	\N	PRESENT	0
423503	416297	19703U	PARTICIPANT	\N	PRESENT	0
423504	416297	14187A	PARTICIPANT	\N	PRESENT	0
423505	416297	14041T	PARTICIPANT	\N	PRESENT	0
423506	416297	14073Q	PARTICIPANT	\N	PRESENT	0
423507	416297	11103C	PARTICIPANT	\N	PRESENT	0
423508	416297	04018C	PARTICIPANT	\N	PRESENT	0
423509	416297	19701S	PARTICIPANT	\N	PRESENT	0
423512	416297	14147R	PARTICIPANT	\N	PRESENT	0
423513	416297	95030B	PARTICIPANT	\N	PRESENT	0
423514	416297	14249W	PARTICIPANT	\N	PRESENT	0
423515	416297	04088S	PARTICIPANT	\N	PRESENT	0
423516	416297	19723Y	PARTICIPANT	\N	PRESENT	0
423517	416297	14173T	PARTICIPANT	\N	PRESENT	0
423518	416297	19467C	PARTICIPANT	\N	PRESENT	0
423519	416297	14053L	PARTICIPANT	\N	PRESENT	0
423520	416297	19762G	PARTICIPANT	\N	PRESENT	0
423521	416297	11012A	PARTICIPANT	\N	PRESENT	0
421009	418884	08024S	PARTICIPANT	\N	PRESENT	0
423522	416297	14042U	PARTICIPANT	\N	PRESENT	0
423523	416297	11077T	PARTICIPANT	\N	PRESENT	0
423467	416297	11070L	PARTICIPANT	\N	PRESENT	0
423469	416297	04092N	PARTICIPANT	\N	PRESENT	0
423524	416297	11031D	PARTICIPANT	\N	PRESENT	0
423525	416297	19760E	PARTICIPANT	\N	PRESENT	0
423526	416297	04045F	PARTICIPANT	\N	PRESENT	0
423527	416297	19599P	PARTICIPANT	\N	PRESENT	0
423528	416297	14135M	PARTICIPANT	\N	PRESENT	0
423529	416297	19741B	PARTICIPANT	\N	PRESENT	0
423530	416297	14119M	PARTICIPANT	\N	PRESENT	0
423531	416297	19697Q	PARTICIPANT	\N	PRESENT	0
423532	416297	19527W	PARTICIPANT	\N	PRESENT	0
423533	416297	14105F	PARTICIPANT	\N	PRESENT	0
423534	416297	14235Q	PARTICIPANT	\N	PRESENT	0
423535	416297	19443T	PARTICIPANT	\N	PRESENT	0
423536	416297	11067R	PARTICIPANT	\N	PRESENT	0
423538	416297	19521Q	PARTICIPANT	\N	PRESENT	0
423539	423510	19333N	PARTICIPANT	\N	PRESENT	0
423540	423510	04070G	PRESIDENT	0	PRESENT	0
423541	423510	19533U	PARTICIPANT	\N	PRESENT	0
423542	423510	14229S	PARTICIPANT	\N	PRESENT	0
423543	423510	14241N	PARTICIPANT	\N	PRESENT	0
423544	423510	19573D	PARTICIPANT	\N	PRESENT	0
423545	423510	14107H	PARTICIPANT	\N	PRESENT	0
423546	423510	08017T	PARTICIPANT	\N	PRESENT	0
423547	423510	19369B	PARTICIPANT	\N	PRESENT	0
423548	423510	14249W	PARTICIPANT	\N	PRESENT	0
423549	423510	08039A	PARTICIPANT	\N	PRESENT	0
423550	423510	14061L	PARTICIPANT	\N	PRESENT	0
423551	423510	04057K	PARTICIPANT	\N	PRESENT	0
423552	423510	14073Q	PARTICIPANT	\N	PRESENT	0
423553	423510	19611R	PARTICIPANT	\N	PRESENT	0
423554	423510	08043V	PARTICIPANT	\N	PRESENT	0
423555	423510	19693L	PARTICIPANT	\N	PRESENT	0
423556	423510	87003B	PARTICIPANT	\N	PRESENT	0
423557	423510	14030Q	PARTICIPANT	\N	PRESENT	0
423558	423510	08020N	PARTICIPANT	\N	PRESENT	0
423559	423510	19735D	PARTICIPANT	\N	PRESENT	0
423560	423510	14063N	PARTICIPANT	\N	PRESENT	0
423561	423510	14123H	PARTICIPANT	\N	PRESENT	0
423562	423510	11104D	PARTICIPANT	\N	PRESENT	0
423563	423510	19758L	PARTICIPANT	\N	PRESENT	0
423564	423510	19621T	PARTICIPANT	\N	PRESENT	0
423565	416297	19479G	PARTICIPANT	\N	PRESENT	0
423566	416297	19387D	PARTICIPANT	\N	PRESENT	0
423567	416297	14265W	PARTICIPANT	\N	PRESENT	0
423568	416297	19631V	PARTICIPANT	\N	PRESENT	0
423569	416297	17779H	PARTICIPANT	\N	PRESENT	0
423570	416297	14199E	PARTICIPANT	\N	PRESENT	0
423571	416297	19727D	PARTICIPANT	\N	PRESENT	0
423572	416297	19507S	PARTICIPANT	\N	PRESENT	0
423573	416297	19782L	PARTICIPANT	\N	PRESENT	0
423574	416297	19349W	PARTICIPANT	\N	PRESENT	0
423575	416297	08056B	PARTICIPANT	\N	PRESENT	0
423576	416297	19413M	PARTICIPANT	\N	PRESENT	0
423577	416297	01024M	PARTICIPANT	\N	PRESENT	0
423578	416297	14223L	PARTICIPANT	\N	PRESENT	0
423579	416297	01025N	PARTICIPANT	\N	PRESENT	0
423580	416297	04069P	PARTICIPANT	\N	PRESENT	0
423581	416297	14033T	PARTICIPANT	\N	PRESENT	0
423582	416297	14081Q	PARTICIPANT	\N	PRESENT	0
423583	416297	17583W	PARTICIPANT	\N	PRESENT	0
423584	416297	19826F	PARTICIPANT	\N	PRESENT	0
423585	416297	19747H	PARTICIPANT	\N	PRESENT	0
423586	416297	08048B	PARTICIPANT	\N	PRESENT	0
423587	416297	11048N	PARTICIPANT	\N	PRESENT	0
423591	423589	14123H	PARTICIPANT	\N	PRESENT	0
423592	423590	11104D	PARTICIPANT	\N	PRESENT	0
423593	423588	14123H	PARTICIPANT	\N	PRESENT	0
423594	423589	19611R	PARTICIPANT	\N	PRESENT	0
423595	423589	14241N	PARTICIPANT	\N	PRESENT	0
423618	423510	89017R	PARTICIPANT	\N	PRESENT	0
423619	423510	14251Q	PARTICIPANT	\N	PRESENT	0
423620	423510	14059S	PARTICIPANT	\N	EXCUSE	0
423845	423843	10006L	PARTICIPANT	\N	PRESENT	0
423846	423843	14071N	PARTICIPANT	\N	PRESENT	0
423847	423844	10006L	PARTICIPANT	\N	PRESENT	0
423848	423844	01034P	PARTICIPANT	\N	PRESENT	0
423893	423843	07004J	PARTICIPANT	\N	PRESENT	0
423896	423895	14213J	PARTICIPANT	\N	PRESENT	0
423899	420722	19701S	PARTICIPANT	\N	PRESENT	0
423900	422488	11053K	PARTICIPANT	\N	PRESENT	0
423903	422488	19515S	PARTICIPANT	\N	PRESENT	0
423904	422488	08068F	PARTICIPANT	\N	PRESENT	0
423906	423901	08039A	PARTICIPANT	\N	PRESENT	0
423907	423901	11083R	PARTICIPANT	\N	PRESENT	0
423908	423901	19758L	PARTICIPANT	\N	PRESENT	0
423909	423901	19399H	PARTICIPANT	\N	PRESENT	0
423910	423901	14229S	PARTICIPANT	\N	PRESENT	0
392895	385081	14107H	PARTICIPANT	\N	PRESENT	0
393358	390068	14147R	PARTICIPANT	\N	PRESENT	0
393674	393673	95063L	PARTICIPANT	\N	PRESENT	0
393675	393673	04034C	PARTICIPANT	\N	PRESENT	0
393676	393673	08015R	PARTICIPANT	\N	PRESENT	0
393677	393673	11072N	PARTICIPANT	\N	PRESENT	0
393678	393673	04049K	PARTICIPANT	\N	PRESENT	0
393679	393673	04040A	PARTICIPANT	\N	PRESENT	0
393680	393673	17589D	PARTICIPANT	\N	PRESENT	0
393682	393681	95063L	PARTICIPANT	\N	PRESENT	0
394512	384447	19659J	PARTICIPANT	\N	EXCUSE	0
394515	384447	19729F	PARTICIPANT	\N	EXCUSE	0
394516	384447	19329S	PARTICIPANT	\N	PRESENT	0
394517	384447	14261S	PARTICIPANT	\N	PRESENT	0
394518	384447	14219Q	PARTICIPANT	\N	EXCUSE	0
394519	384447	19583F	PARTICIPANT	\N	EXCUSE	0
394520	384447	04043D	PARTICIPANT	\N	PRESENT	0
394521	384447	14331P	PARTICIPANT	\N	PRESENT	0
394522	384447	08019V	PARTICIPANT	\N	PRESENT	0
394523	384447	14059S	PARTICIPANT	\N	PRESENT	0
394525	384447	14093U	PARTICIPANT	\N	PRESENT	0
394873	384447	19319Q	PARTICIPANT	\N	EXCUSE	0
396429	396428	19741B	PARTICIPANT	\N	PRESENT	0
396431	396430	19741B	PARTICIPANT	\N	PRESENT	0
397058	396852	08009T	PARTICIPANT	\N	EXCUSE	0
399938	399937	19253P	PARTICIPANT	\N	PRESENT	0
399939	399937	11053K	PARTICIPANT	\N	PRESENT	0
399940	399937	19729F	PARTICIPANT	\N	PRESENT	0
400526	396241	19693L	PARTICIPANT	\N	EXCUSE	0
400527	393777	19693L	PARTICIPANT	\N	EXCUSE	0
400913	396565	19768N	PARTICIPANT	\N	PRESENT	0
400923	396565	19619A	PARTICIPANT	\N	PRESENT	0
400915	398618	19725B	PRESIDENT	0	PRESENT	0
400916	398618	04057K	PARTICIPANT	\N	PRESENT	0
400917	398618	12016W	PARTICIPANT	\N	PRESENT	0
400918	398618	08019V	PARTICIPANT	\N	PRESENT	0
400919	398618	14053L	PARTICIPANT	\N	EXCUSE	0
400920	398618	08015R	PARTICIPANT	\N	EXCUSE	0
400921	398618	14327T	PARTICIPANT	\N	PRESENT	0
400922	398618	08069G	PARTICIPANT	\N	EXCUSE	0
400924	396565	11067R	PARTICIPANT	\N	PRESENT	0
400925	396565	11083R	PARTICIPANT	\N	PRESENT	0
400926	396565	19479G	PARTICIPANT	\N	PRESENT	0
400927	396565	98022P	PARTICIPANT	\N	PRESENT	0
400928	396565	19443T	PARTICIPANT	\N	PRESENT	0
400929	396565	19319Q	PARTICIPANT	\N	PRESENT	0
400930	396565	08028W	PARTICIPANT	\N	PRESENT	0
400931	396565	19413M	PARTICIPANT	\N	PRESENT	0
400932	396565	08038Y	PARTICIPANT	\N	PRESENT	0
400933	396565	08055A	PARTICIPANT	\N	PRESENT	0
400934	400603	19701S	PARTICIPANT	\N	EXCUSE	0
400935	400603	08009T	PARTICIPANT	\N	EXCUSE	0
400936	400603	19681G	PARTICIPANT	\N	EXCUSE	0
400937	396565	14021P	PARTICIPANT	\N	PRESENT	0
400938	396565	14029X	PARTICIPANT	\N	PRESENT	0
400939	396565	19467C	PARTICIPANT	\N	PRESENT	0
400940	396565	19673G	PARTICIPANT	\N	PRESENT	0
400941	396565	08061X	PARTICIPANT	\N	PRESENT	0
400942	396565	08053X	PARTICIPANT	\N	PRESENT	0
401186	393612	14034U	PARTICIPANT	\N	PRESENT	0
401187	393612	14033T	PARTICIPANT	\N	PRESENT	0
401188	393612	19733B	PARTICIPANT	\N	PRESENT	0
401189	393612	12016W	PARTICIPANT	\N	PRESENT	0
401190	393612	14197C	PARTICIPANT	\N	PRESENT	0
401191	393612	08060W	PARTICIPANT	\N	PRESENT	0
401110	401107	04057K	PARTICIPANT	\N	PRESENT	0
401192	393612	80013X	PARTICIPANT	\N	PRESENT	0
401193	393612	11066Q	PARTICIPANT	\N	PRESENT	0
401194	393612	11045K	PARTICIPANT	\N	PRESENT	0
401195	393612	14109K	PARTICIPANT	\N	PRESENT	0
401196	393612	19782L	PARTICIPANT	\N	PRESENT	0
401197	393612	19349W	PARTICIPANT	\N	PRESENT	0
401198	393612	11065P	PARTICIPANT	\N	PRESENT	0
401199	393612	14121F	PARTICIPANT	\N	PRESENT	0
401200	393612	17589D	PARTICIPANT	\N	PRESENT	0
401201	393612	14073Q	PARTICIPANT	\N	PRESENT	0
401202	393612	14205J	PARTICIPANT	\N	PRESENT	0
401203	393612	19747H	PARTICIPANT	\N	PRESENT	0
401204	393612	19745F	PARTICIPANT	\N	PRESENT	0
401205	393612	19685L	PARTICIPANT	\N	PRESENT	0
401206	393612	14215L	PARTICIPANT	\N	PRESENT	0
401207	393612	11090Q	PARTICIPANT	\N	PRESENT	0
401208	393612	08062Y	PARTICIPANT	\N	PRESENT	0
401209	393612	14053L	PARTICIPANT	\N	PRESENT	0
401210	393612	19693L	PARTICIPANT	\N	PRESENT	0
401211	393612	14041T	PARTICIPANT	\N	PRESENT	0
401212	393612	19794Q	PARTICIPANT	\N	PRESENT	0
401213	393612	14157T	PARTICIPANT	\N	PRESENT	0
401214	393612	08039A	PARTICIPANT	\N	PRESENT	0
401215	393612	19413M	PARTICIPANT	\N	PRESENT	0
401216	393612	14241N	PARTICIPANT	\N	PRESENT	0
401217	393612	14051J	PARTICIPANT	\N	PRESENT	0
401218	393612	14257W	PARTICIPANT	\N	PRESENT	0
401219	393612	11033F	PARTICIPANT	\N	PRESENT	0
401220	393612	19591F	PARTICIPANT	\N	PRESENT	0
401221	393612	19758L	PARTICIPANT	\N	PRESENT	0
401222	393612	04049K	PARTICIPANT	\N	PRESENT	0
401223	393612	19367Y	PARTICIPANT	\N	PRESENT	0
401224	393612	19533U	PARTICIPANT	\N	PRESENT	0
401225	393612	19515S	PARTICIPANT	\N	PRESENT	0
401226	393612	11067R	PARTICIPANT	\N	PRESENT	0
401227	393612	19503N	PARTICIPANT	\N	PRESENT	0
401228	393612	19711U	PARTICIPANT	\N	PRESENT	0
401229	393612	14187A	PARTICIPANT	\N	PRESENT	0
401230	393612	19695N	PARTICIPANT	\N	PRESENT	0
401231	393612	14030Q	PARTICIPANT	\N	PRESENT	0
401091	398618	14107H	PARTICIPANT	\N	PRESENT	0
401092	398618	19441R	PARTICIPANT	\N	PRESENT	0
401093	398618	14030Q	PARTICIPANT	\N	PRESENT	0
401232	393612	19421M	PARTICIPANT	\N	PRESENT	0
401233	393612	04033B	PARTICIPANT	\N	PRESENT	0
401234	393612	19369B	PARTICIPANT	\N	PRESENT	0
401235	393612	19713W	PARTICIPANT	\N	PRESENT	0
401236	393612	11097X	PARTICIPANT	\N	PRESENT	0
401237	393612	01025N	PARTICIPANT	\N	PRESENT	0
401238	393612	14331P	PARTICIPANT	\N	PRESENT	0
401239	393612	19741B	PARTICIPANT	\N	PRESENT	0
401240	393612	19289C	PARTICIPANT	\N	PRESENT	0
401241	393612	19705W	PARTICIPANT	\N	PRESENT	0
401242	393612	10015M	PARTICIPANT	\N	PRESENT	0
401243	393612	19593H	PARTICIPANT	\N	PRESENT	0
401244	393612	19269X	PARTICIPANT	\N	PRESENT	0
401245	393612	01024M	PARTICIPANT	\N	PRESENT	0
401109	401107	04044E	PARTICIPANT	\N	PRESENT	0
401111	401107	08010L	PARTICIPANT	\N	PRESENT	0
401112	401107	14051J	PARTICIPANT	\N	PRESENT	0
401113	401107	08017T	PARTICIPANT	\N	PRESENT	0
401114	401107	19503N	PARTICIPANT	\N	PRESENT	0
401115	401107	14081Q	PARTICIPANT	\N	PRESENT	0
401116	401107	04045F	PARTICIPANT	\N	PRESENT	0
401117	401107	19575F	PARTICIPANT	\N	PRESENT	0
401118	401107	14105F	PARTICIPANT	\N	PRESENT	0
401119	401107	19709B	PARTICIPANT	\N	PRESENT	0
401120	401107	95067Q	PARTICIPANT	\N	PRESENT	0
401121	401107	19533U	PARTICIPANT	\N	PRESENT	0
401122	401107	14357A	PARTICIPANT	\N	PRESENT	0
401123	401107	04097T	PARTICIPANT	\N	PRESENT	0
401124	401107	19747H	PARTICIPANT	\N	PRESENT	0
401246	393614	14034U	PARTICIPANT	\N	PRESENT	0
401247	393614	14033T	PARTICIPANT	\N	PRESENT	0
401248	393614	19733B	PARTICIPANT	\N	PRESENT	0
401249	393614	14197C	PARTICIPANT	\N	PRESENT	0
401250	393614	08060W	PARTICIPANT	\N	PRESENT	0
401251	393614	80013X	PARTICIPANT	\N	PRESENT	0
401252	393614	11066Q	PARTICIPANT	\N	PRESENT	0
401253	393614	11045K	PARTICIPANT	\N	PRESENT	0
401254	393614	14109K	PARTICIPANT	\N	PRESENT	0
401255	393614	19782L	PARTICIPANT	\N	PRESENT	0
401256	393614	11065P	PARTICIPANT	\N	PRESENT	0
401257	393614	14121F	PARTICIPANT	\N	PRESENT	0
401258	393614	17589D	PARTICIPANT	\N	PRESENT	0
401259	393614	14205J	PARTICIPANT	\N	PRESENT	0
401260	393614	19747H	PARTICIPANT	\N	PRESENT	0
401261	393614	19745F	PARTICIPANT	\N	PRESENT	0
401262	393614	19685L	PARTICIPANT	\N	PRESENT	0
401263	393614	14215L	PARTICIPANT	\N	PRESENT	0
401264	393614	11090Q	PARTICIPANT	\N	PRESENT	0
401265	393614	08062Y	PARTICIPANT	\N	PRESENT	0
401266	393614	14053L	PARTICIPANT	\N	PRESENT	0
401267	393614	19693L	PARTICIPANT	\N	PRESENT	0
401268	393614	14041T	PARTICIPANT	\N	PRESENT	0
401269	393614	19794Q	PARTICIPANT	\N	PRESENT	0
401270	393614	14157T	PARTICIPANT	\N	PRESENT	0
401271	393614	08039A	PARTICIPANT	\N	PRESENT	0
401272	393614	19413M	PARTICIPANT	\N	PRESENT	0
401273	393614	14241N	PARTICIPANT	\N	PRESENT	0
401274	393614	14051J	PARTICIPANT	\N	PRESENT	0
401275	393614	14257W	PARTICIPANT	\N	PRESENT	0
401276	393614	11033F	PARTICIPANT	\N	PRESENT	0
410674	402307	04044E	PARTICIPANT	\N	PRESENT	0
410676	402307	04092N	PARTICIPANT	\N	PRESENT	0
410678	402307	19577H	PARTICIPANT	\N	PRESENT	0
410679	402307	19683J	PARTICIPANT	\N	PRESENT	0
410680	402307	14261S	PARTICIPANT	\N	PRESENT	0
410681	402307	14039A	PARTICIPANT	\N	PRESENT	0
410682	402307	11031D	PARTICIPANT	\N	PRESENT	0
410683	402307	19583F	PARTICIPANT	\N	PRESENT	0
410684	402307	11097X	PARTICIPANT	\N	PRESENT	0
410685	402307	19319Q	PARTICIPANT	\N	PRESENT	0
410686	402307	08019V	PARTICIPANT	\N	PRESENT	0
410687	402307	19715Y	PARTICIPANT	\N	PRESENT	0
410688	402307	11109J	PARTICIPANT	\N	PRESENT	0
410689	402307	14217N	PARTICIPANT	\N	PRESENT	0
410807	410805	19515S	PARTICIPANT	\N	PRESENT	0
410692	400646	14030Q	PRESIDENT	0	PRESENT	0
410694	400646	18083K	PARTICIPANT	\N	PRESENT	0
410695	400646	11031D	PARTICIPANT	\N	PRESENT	0
410696	400646	80013X	PARTICIPANT	\N	PRESENT	0
410697	400646	19693L	PARTICIPANT	\N	EXCUSE	0
410698	400646	14217N	PARTICIPANT	\N	PRESENT	0
410699	400646	19599P	PARTICIPANT	\N	PRESENT	0
410700	400646	19715Y	PARTICIPANT	\N	EXCUSE	0
410701	400646	08031R	PARTICIPANT	\N	PRESENT	0
410702	400646	07029T	PARTICIPANT	\N	EXCUSE	0
410703	400646	08017T	PARTICIPANT	\N	PRESENT	0
410704	400646	11067R	PARTICIPANT	\N	PRESENT	0
410705	400646	14109K	PARTICIPANT	\N	PRESENT	0
410706	400646	19679N	PARTICIPANT	\N	PRESENT	0
410707	400646	19269X	PARTICIPANT	\N	PRESENT	0
410708	400646	19749K	PARTICIPANT	\N	PRESENT	0
410709	402307	19329S	PARTICIPANT	\N	PRESENT	0
410710	402307	14030Q	PARTICIPANT	\N	PRESENT	0
410711	402307	19701S	PARTICIPANT	\N	PRESENT	0
410712	402307	08020N	PARTICIPANT	\N	PRESENT	0
410713	402307	11010L	PARTICIPANT	\N	PRESENT	0
410714	402307	19794Q	PARTICIPANT	\N	PRESENT	0
410715	402307	19467C	PARTICIPANT	\N	PRESENT	0
410716	402307	11067R	PARTICIPANT	\N	PRESENT	0
410717	402307	14147R	PARTICIPANT	\N	PRESENT	0
410718	407449	14261S	PARTICIPANT	\N	PRESENT	0
410719	407449	14030Q	PRESIDENT	0	PRESENT	0
410720	407449	80013X	PARTICIPANT	\N	PRESENT	0
410721	407449	19577H	PARTICIPANT	\N	PRESENT	0
410722	407449	19599P	PARTICIPANT	\N	PRESENT	0
410723	407449	04035D	PARTICIPANT	\N	PRESENT	0
410724	407449	14179A	PARTICIPANT	\N	PRESENT	0
410725	407449	19715Y	PARTICIPANT	\N	PRESENT	0
410726	407449	19731Y	PARTICIPANT	\N	PRESENT	0
410727	407449	19657G	PARTICIPANT	\N	PRESENT	0
410728	407449	19693L	PARTICIPANT	\N	EXCUSE	0
410729	407449	07029T	PARTICIPANT	\N	EXCUSE	0
410730	407449	11067R	PARTICIPANT	\N	EXCUSE	0
410731	407449	11109J	PARTICIPANT	\N	PRESENT	0
410732	407449	19717B	PARTICIPANT	\N	PRESENT	0
410733	407449	19631V	PARTICIPANT	\N	PRESENT	0
410734	407449	19659J	PARTICIPANT	\N	PRESENT	0
410735	407449	19691J	PARTICIPANT	\N	PRESENT	0
410736	407449	19329S	PARTICIPANT	\N	PRESENT	0
410737	407449	14097Y	PARTICIPANT	\N	PRESENT	0
410738	402307	19657G	PARTICIPANT	\N	PRESENT	0
410739	407449	19583F	PARTICIPANT	\N	PRESENT	0
410740	407449	08019V	PARTICIPANT	\N	PRESENT	0
410741	407449	19319Q	PARTICIPANT	\N	PRESENT	0
410742	407449	11054L	PARTICIPANT	\N	PRESENT	0
410743	407449	19301E	PARTICIPANT	\N	PRESENT	0
410744	402307	19301E	PARTICIPANT	\N	PRESENT	0
410745	402307	19711U	PARTICIPANT	\N	PRESENT	0
410746	402307	11012A	PARTICIPANT	\N	PRESENT	0
410747	402307	19667J	PARTICIPANT	\N	PRESENT	0
410749	402307	04085P	PARTICIPANT	\N	PRESENT	0
410750	402307	10015M	PARTICIPANT	\N	PRESENT	0
410806	410805	11090Q	PARTICIPANT	\N	PRESENT	0
410808	410805	19782L	PARTICIPANT	\N	PRESENT	0
410809	410805	19747H	PARTICIPANT	\N	PRESENT	0
410810	410805	14205J	PARTICIPANT	\N	PRESENT	0
410811	410805	04040A	PARTICIPANT	\N	PRESENT	0
410812	410805	14097Y	PARTICIPANT	\N	PRESENT	0
410814	410813	19515S	PARTICIPANT	\N	PRESENT	0
410815	410813	19782L	PARTICIPANT	\N	PRESENT	0
410816	410813	14205J	PARTICIPANT	\N	PRESENT	0
410817	410813	11090Q	PARTICIPANT	\N	PRESENT	0
410818	410813	04040A	PARTICIPANT	\N	PRESENT	0
410819	410813	14097Y	PARTICIPANT	\N	PRESENT	0
410834	410833	19621T	PARTICIPANT	\N	PRESENT	0
410836	410835	19631V	PARTICIPANT	\N	EXCUSE	0
410837	410835	19741B	PARTICIPANT	\N	PRESENT	0
410838	410835	14038Y	PARTICIPANT	\N	PRESENT	0
410839	410835	19599P	PARTICIPANT	\N	PRESENT	0
410840	410835	08018U	PARTICIPANT	\N	PRESENT	0
410841	410835	11083R	PARTICIPANT	\N	EXCUSE	0
410842	410835	01048V	PARTICIPANT	\N	PRESENT	0
410843	410835	08053X	PARTICIPANT	\N	PRESENT	0
410844	410835	14257W	PARTICIPANT	\N	PRESENT	0
410845	410835	04070G	PARTICIPANT	\N	PRESENT	0
410846	410835	19593H	PARTICIPANT	\N	PRESENT	0
410847	410835	19533U	PARTICIPANT	\N	PRESENT	0
410848	410835	19679N	PARTICIPANT	\N	PRESENT	0
410849	410835	14229S	PARTICIPANT	\N	PRESENT	0
410850	410835	19421M	PARTICIPANT	\N	EXCUSE	0
410911	410910	08018U	PARTICIPANT	\N	PRESENT	0
410917	410916	14357A	PARTICIPANT	\N	PRESENT	0
410919	410918	14357A	PARTICIPANT	\N	PRESENT	0
410927	410921	19415P	PARTICIPANT	\N	PRESENT	0
410928	410922	19415P	PARTICIPANT	\N	PRESENT	0
410929	410923	19415P	PARTICIPANT	\N	PRESENT	0
410930	410924	19415P	PARTICIPANT	\N	PRESENT	0
410931	410925	19415P	PARTICIPANT	\N	PRESENT	0
410932	410926	19415P	PARTICIPANT	\N	PRESENT	0
411175	408229	08055A	PARTICIPANT	\N	PRESENT	0
411176	408229	19549D	PARTICIPANT	\N	PRESENT	0
411182	408229	08024S	PARTICIPANT	\N	PRESENT	0
411179	408229	08060W	PARTICIPANT	\N	PRESENT	0
411184	408229	19701S	PARTICIPANT	\N	PRESENT	0
411183	408229	18083K	PARTICIPANT	\N	PRESENT	0
411185	408229	19525U	PARTICIPANT	\N	PRESENT	0
411186	408229	11065P	PARTICIPANT	\N	PRESENT	0
411187	408229	19599P	PARTICIPANT	\N	PRESENT	0
411188	408229	19820Y	PARTICIPANT	\N	PRESENT	0
411189	408229	15447F	PARTICIPANT	\N	PRESENT	0
411190	408229	19387D	PARTICIPANT	\N	PRESENT	0
411191	408229	19347U	PARTICIPANT	\N	PRESENT	0
411192	408229	19685L	PARTICIPANT	\N	PRESENT	0
411193	408229	19333N	PARTICIPANT	\N	PRESENT	0
411194	408229	19289C	PARTICIPANT	\N	PRESENT	0
411195	408229	14219Q	PARTICIPANT	\N	PRESENT	0
411196	408229	14031R	PARTICIPANT	\N	PRESENT	0
411197	408229	08009T	PARTICIPANT	\N	PRESENT	0
411198	408229	19637C	PARTICIPANT	\N	PRESENT	0
411199	408229	19826F	PARTICIPANT	\N	PRESENT	0
411200	408229	14221J	PARTICIPANT	\N	PRESENT	0
411201	408229	14237S	PARTICIPANT	\N	PRESENT	0
411202	408229	19745F	PARTICIPANT	\N	PRESENT	0
411203	408229	05012A	PARTICIPANT	\N	PRESENT	0
411204	408229	19503N	PARTICIPANT	\N	PRESENT	0
411205	408229	19739H	PARTICIPANT	\N	PRESENT	0
411206	408229	17583W	PARTICIPANT	\N	PRESENT	0
411207	408229	19794Q	PARTICIPANT	\N	PRESENT	0
411208	408229	19737F	PARTICIPANT	\N	PRESENT	0
411693	411209	19699S	PARTICIPANT	\N	PRESENT	0
411694	411209	19573D	PARTICIPANT	\N	PRESENT	0
411695	409988	11074Q	PRESIDENT	1	PRESENT	0
411697	411209	04057K	PARTICIPANT	\N	PRESENT	0
411698	411209	11043H	PARTICIPANT	\N	PRESENT	0
411704	411209	08020N	PARTICIPANT	\N	PRESENT	0
411705	409431	19697Q	PARTICIPANT	\N	PRESENT	0
411706	409431	19565D	PARTICIPANT	\N	PRESENT	0
411707	409431	14355X	PARTICIPANT	\N	PRESENT	0
411708	409431	19569H	PARTICIPANT	\N	PRESENT	0
411709	409431	19798U	PARTICIPANT	\N	PRESENT	0
411710	409431	11097X	PARTICIPANT	\N	PRESENT	0
411711	409431	19415P	PARTICIPANT	\N	PRESENT	0
411712	409431	14223L	PARTICIPANT	\N	PRESENT	0
411713	409431	04045F	PARTICIPANT	\N	PRESENT	0
411714	409431	14227Q	PARTICIPANT	\N	PRESENT	0
411715	409431	17779H	PARTICIPANT	\N	PRESENT	0
411716	409431	11031D	PARTICIPANT	\N	PRESENT	0
411717	409431	19703U	PARTICIPANT	\N	PRESENT	0
411718	409431	19553Y	PARTICIPANT	\N	PRESENT	0
411719	409431	14239U	PARTICIPANT	\N	PRESENT	0
411720	409431	14087W	PARTICIPANT	\N	PRESENT	0
411721	409431	14281W	PARTICIPANT	\N	PRESENT	0
411722	409431	19679N	PARTICIPANT	\N	PRESENT	0
411723	409431	14042U	PARTICIPANT	\N	PRESENT	0
411724	409431	14195A	PARTICIPANT	\N	PRESENT	0
411725	409431	08048B	PARTICIPANT	\N	PRESENT	0
411726	409431	14213J	PARTICIPANT	\N	PRESENT	0
411727	409431	19367Y	PARTICIPANT	\N	PRESENT	0
411728	409431	14217N	PARTICIPANT	\N	PRESENT	0
414370	406851	19798U	PARTICIPANT	\N	PRESENT	0
414371	406851	19533U	PARTICIPANT	\N	PRESENT	0
414372	406851	14028W	PARTICIPANT	\N	PRESENT	0
414373	406851	08061X	PARTICIPANT	\N	PRESENT	0
414374	406851	19527W	PARTICIPANT	\N	PRESENT	0
414375	406851	11085T	PARTICIPANT	\N	PRESENT	0
414376	406851	19549D	PARTICIPANT	\N	PRESENT	0
414377	406851	95030B	PARTICIPANT	\N	PRESENT	0
414378	406851	08068F	PARTICIPANT	\N	PRESENT	0
414379	406851	19611R	PARTICIPANT	\N	PRESENT	0
414380	406851	14059S	PARTICIPANT	\N	PRESENT	0
414381	406851	19691J	PARTICIPANT	\N	PRESENT	0
414382	406851	80013X	PARTICIPANT	\N	PRESENT	0
414383	406851	08043V	PARTICIPANT	\N	PRESENT	0
414384	406851	19681G	PARTICIPANT	\N	PRESENT	0
414385	406851	19749K	PARTICIPANT	\N	PRESENT	0
414387	406851	14249W	PARTICIPANT	\N	PRESENT	0
414388	406851	07004J	PARTICIPANT	\N	PRESENT	0
414389	406851	14173T	PARTICIPANT	\N	PRESENT	0
414390	413405	04071H	PARTICIPANT	\N	PRESENT	0
414391	406851	08010L	PARTICIPANT	\N	PRESENT	0
414392	406851	98022P	PARTICIPANT	\N	PRESENT	0
414393	406851	14089Y	PARTICIPANT	\N	PRESENT	0
414394	406851	11101A	PARTICIPANT	\N	PRESENT	0
414395	406851	19679N	PARTICIPANT	\N	PRESENT	0
414396	406851	14169X	PARTICIPANT	\N	PRESENT	0
414397	406851	01057W	PARTICIPANT	\N	PRESENT	0
414398	406851	19647E	PARTICIPANT	\N	PRESENT	0
414406	406851	98050T	PARTICIPANT	\N	PRESENT	0
414407	406851	11064N	PARTICIPANT	\N	PRESENT	0
414408	406851	14071N	PARTICIPANT	\N	PRESENT	0
414409	406851	11054L	PARTICIPANT	\N	PRESENT	0
414410	406851	11104D	PARTICIPANT	\N	PRESENT	0
414411	406851	04092N	PARTICIPANT	\N	PRESENT	0
414412	406851	14083S	PARTICIPANT	\N	PRESENT	0
414413	406851	19711U	PARTICIPANT	\N	PRESENT	0
414414	406851	14221J	PARTICIPANT	\N	PRESENT	0
414415	406851	14069U	PARTICIPANT	\N	PRESENT	0
414416	406851	14331P	PARTICIPANT	\N	PRESENT	0
414417	406851	19569H	PARTICIPANT	\N	PRESENT	0
414418	406851	04097T	PARTICIPANT	\N	PRESENT	0
414421	406851	04085P	PARTICIPANT	\N	PRESENT	0
414422	406851	14201E	PARTICIPANT	\N	PRESENT	0
414423	406851	11066Q	PARTICIPANT	\N	PRESENT	0
414424	406851	14121F	PARTICIPANT	\N	PRESENT	0
414425	406851	11053K	PARTICIPANT	\N	PRESENT	0
414426	406851	01043Q	PARTICIPANT	\N	PRESENT	0
414427	406851	14038Y	PARTICIPANT	\N	PRESENT	0
414428	406851	10015M	PARTICIPANT	\N	PRESENT	0
414430	406851	14123H	PARTICIPANT	\N	PRESENT	0
414441	406851	19758L	PARTICIPANT	\N	PRESENT	0
414442	406851	19551W	PARTICIPANT	\N	PRESENT	0
414443	406851	08044W	PARTICIPANT	\N	PRESENT	0
414445	406851	14357A	PARTICIPANT	\N	PRESENT	0
414446	406851	14021P	PARTICIPANT	\N	PRESENT	0
414447	406851	19663E	PARTICIPANT	\N	PRESENT	0
414448	406851	14133K	PARTICIPANT	\N	PRESENT	0
414449	406851	11067R	PARTICIPANT	\N	PRESENT	0
414450	406851	04070G	PARTICIPANT	\N	PRESENT	0
414451	406851	01062T	PARTICIPANT	\N	PRESENT	0
414452	406851	14061L	PARTICIPANT	\N	PRESENT	0
414579	406852	01043Q	PARTICIPANT	\N	PRESENT	0
414580	406852	05008E	PARTICIPANT	\N	PRESENT	0
414581	406852	14231L	PARTICIPANT	\N	PRESENT	0
414582	406852	14259Y	PARTICIPANT	\N	PRESENT	0
414583	406852	19551W	PARTICIPANT	\N	PRESENT	0
414584	406852	14151M	PARTICIPANT	\N	PRESENT	0
414585	406852	19413M	PARTICIPANT	\N	PRESENT	0
414586	406852	11054L	PARTICIPANT	\N	PRESENT	0
414587	406852	19782L	PARTICIPANT	\N	PRESENT	0
414588	406852	19489J	PARTICIPANT	\N	PRESENT	0
414589	406852	11056N	PARTICIPANT	\N	PRESENT	0
414590	406852	19758L	PARTICIPANT	\N	PRESENT	0
414591	406852	19695N	PARTICIPANT	\N	PRESENT	0
414592	406852	19565D	PARTICIPANT	\N	PRESENT	0
414593	406852	80013X	PARTICIPANT	\N	PRESENT	0
414594	406852	19543W	PARTICIPANT	\N	PRESENT	0
414595	406852	14207L	PARTICIPANT	\N	PRESENT	0
414596	406852	19387D	PARTICIPANT	\N	PRESENT	0
414597	406852	19441R	PARTICIPANT	\N	PRESENT	0
414598	406852	14275Y	PARTICIPANT	\N	PRESENT	0
414599	406852	19739H	PARTICIPANT	\N	PRESENT	0
414600	406852	19737F	PARTICIPANT	\N	PRESENT	0
414601	406852	14030Q	PARTICIPANT	\N	PRESENT	0
414602	406852	08009T	PARTICIPANT	\N	PRESENT	0
414603	406852	19335Q	PARTICIPANT	\N	PRESENT	0
414604	406852	19826F	PARTICIPANT	\N	PRESENT	0
414605	406852	14079W	PARTICIPANT	\N	PRESENT	0
414606	406852	14215L	PARTICIPANT	\N	PRESENT	0
414607	406852	14053L	PARTICIPANT	\N	PRESENT	0
414608	406852	14331P	PARTICIPANT	\N	PRESENT	0
414609	406852	14217N	PARTICIPANT	\N	PRESENT	0
414610	406852	14357A	PARTICIPANT	\N	PRESENT	0
414611	406852	19762G	PARTICIPANT	\N	PRESENT	0
414612	406852	14061L	PARTICIPANT	\N	PRESENT	0
414613	406852	05012A	PARTICIPANT	\N	PRESENT	0
414614	406852	19747H	PARTICIPANT	\N	PRESENT	0
414615	406852	01025N	PARTICIPANT	\N	PRESENT	0
414616	406852	14103D	PARTICIPANT	\N	PRESENT	0
414617	406852	04070G	PARTICIPANT	\N	PRESENT	0
414618	406852	08068F	PARTICIPANT	\N	PRESENT	0
414619	406852	19549D	PARTICIPANT	\N	PRESENT	0
414620	406852	14257W	PARTICIPANT	\N	PRESENT	0
414621	406852	14021P	PARTICIPANT	\N	PRESENT	0
414622	406852	14187A	PARTICIPANT	\N	PRESENT	0
414623	406852	19399H	PARTICIPANT	\N	PRESENT	0
414624	406852	14115H	PARTICIPANT	\N	PRESENT	0
414625	406852	14135M	PARTICIPANT	\N	PRESENT	0
414626	406852	14033T	PARTICIPANT	\N	PRESENT	0
414627	406852	19794Q	PARTICIPANT	\N	PRESENT	0
414628	406852	19673G	PARTICIPANT	\N	PRESENT	0
414629	406852	14029X	PARTICIPANT	\N	PRESENT	0
414630	406852	19573D	PARTICIPANT	\N	PRESENT	0
414631	406852	19575F	PARTICIPANT	\N	PRESENT	0
414632	406852	11048N	PARTICIPANT	\N	PRESENT	0
414633	406852	14038Y	PARTICIPANT	\N	PRESENT	0
414634	406852	19443T	PARTICIPANT	\N	PRESENT	0
414635	406852	95030B	PARTICIPANT	\N	PRESENT	0
414636	406852	10015M	PARTICIPANT	\N	PRESENT	0
414637	406852	14265W	PARTICIPANT	\N	PRESENT	0
414638	406852	19768N	PARTICIPANT	\N	PRESENT	0
414639	406852	14105F	PARTICIPANT	\N	PRESENT	0
414640	406852	19749K	PARTICIPANT	\N	PRESENT	0
414641	406852	08034U	PARTICIPANT	\N	PRESENT	0
414642	406852	19629C	PARTICIPANT	\N	PRESENT	0
414643	406852	08015R	PARTICIPANT	\N	PRESENT	0
414644	406852	19729F	PARTICIPANT	\N	PRESENT	0
414645	406852	04040A	PARTICIPANT	\N	PRESENT	0
414646	406852	14065Q	PARTICIPANT	\N	PRESENT	0
414647	406852	01024M	PARTICIPANT	\N	PRESENT	0
414648	406852	14107H	PARTICIPANT	\N	PRESENT	0
414649	406852	19631V	PARTICIPANT	\N	PRESENT	0
414650	406852	19725B	PARTICIPANT	\N	PRESENT	0
414651	406852	01028R	PARTICIPANT	\N	PRESENT	0
414652	406852	14147R	PARTICIPANT	\N	PRESENT	0
414653	406852	95063L	PARTICIPANT	\N	PRESENT	0
414654	406852	19349W	PARTICIPANT	\N	PRESENT	0
414655	406852	19585H	PARTICIPANT	\N	PRESENT	0
414656	406852	19467C	PARTICIPANT	\N	PRESENT	0
414657	406852	14193X	PARTICIPANT	\N	PRESENT	0
414658	406852	14081Q	PARTICIPANT	\N	PRESENT	0
414659	406852	19611R	PARTICIPANT	\N	PRESENT	0
414660	406852	14179A	PARTICIPANT	\N	PRESENT	0
414661	406852	08056B	PARTICIPANT	\N	PRESENT	0
414662	406852	19563B	PARTICIPANT	\N	PRESENT	0
414663	406852	14089Y	PARTICIPANT	\N	PRESENT	0
414664	406852	04085P	PARTICIPANT	\N	PRESENT	0
414665	406852	04088S	PARTICIPANT	\N	PRESENT	0
414666	406852	19621T	PARTICIPANT	\N	PRESENT	0
414667	406852	04045F	PARTICIPANT	\N	PRESENT	0
414668	406852	08069G	PARTICIPANT	\N	PRESENT	0
414669	406852	11043H	PARTICIPANT	\N	PRESENT	0
414670	406852	14133K	PARTICIPANT	\N	PRESENT	0
414671	406852	14069U	PARTICIPANT	\N	PRESENT	0
414672	406852	19503N	PARTICIPANT	\N	PRESENT	0
414673	406852	19383Y	PARTICIPANT	\N	PRESENT	0
414674	406852	14059S	PARTICIPANT	\N	PRESENT	0
414675	406852	14211G	PARTICIPANT	\N	PRESENT	0
414676	406852	17637T	PARTICIPANT	\N	PRESENT	0
414677	406852	14083S	PARTICIPANT	\N	PRESENT	0
414678	406852	14073Q	PARTICIPANT	\N	PRESENT	0
414679	406852	19711U	PARTICIPANT	\N	PRESENT	0
414680	406852	19733B	PARTICIPANT	\N	PRESENT	0
414681	406852	18083K	PARTICIPANT	\N	PRESENT	0
414682	406852	19681G	PARTICIPANT	\N	PRESENT	0
414683	406852	14249W	PARTICIPANT	\N	PRESENT	0
414684	406852	14205J	PARTICIPANT	\N	PRESENT	0
414685	406852	11099A	PARTICIPANT	\N	PRESENT	0
421831	421664	19399H	PARTICIPANT	\N	PRESENT	0
422002	407837	19681G	PARTICIPANT	\N	PRESENT	0
421924	407837	19369B	PARTICIPANT	\N	PRESENT	0
421925	407837	14085U	PARTICIPANT	\N	PRESENT	0
421926	407837	04070G	PARTICIPANT	\N	PRESENT	0
421927	407837	19447X	PARTICIPANT	\N	PRESENT	0
421928	407837	14231L	PARTICIPANT	\N	PRESENT	0
421929	407837	19349W	PARTICIPANT	\N	PRESENT	0
421930	407837	11010L	PARTICIPANT	\N	PRESENT	0
421931	407837	98029W	PARTICIPANT	\N	PRESENT	0
421932	407837	14277B	PARTICIPANT	\N	PRESENT	0
421933	407837	04088S	PARTICIPANT	\N	PRESENT	0
421934	407837	19563B	PARTICIPANT	\N	PRESENT	0
421935	407837	14105F	PARTICIPANT	\N	PRESENT	0
421936	407837	19333N	PARTICIPANT	\N	PRESENT	0
421937	407837	08047A	PARTICIPANT	\N	PRESENT	0
421938	407837	04092N	PARTICIPANT	\N	PRESENT	0
421939	407837	14205J	PARTICIPANT	\N	PRESENT	0
421940	407837	11054L	PARTICIPANT	\N	PRESENT	0
421941	407837	14039A	PARTICIPANT	\N	PRESENT	0
421942	407837	19695N	PARTICIPANT	\N	PRESENT	0
421943	407837	08035V	PARTICIPANT	\N	PRESENT	0
421944	407837	14201E	PARTICIPANT	\N	PRESENT	0
421945	407837	04033B	PARTICIPANT	\N	PRESENT	0
421946	407837	11043H	PARTICIPANT	\N	PRESENT	0
421947	407837	01025N	PARTICIPANT	\N	PRESENT	0
421948	407837	07033P	PARTICIPANT	\N	PRESENT	0
421949	407837	08045X	PARTICIPANT	\N	PRESENT	0
421950	407837	14221J	PARTICIPANT	\N	PRESENT	0
421951	407837	01048V	PARTICIPANT	\N	PRESENT	0
421952	407837	14107H	PARTICIPANT	\N	PRESENT	0
421953	407837	98035U	PARTICIPANT	\N	PRESENT	0
421954	407837	04097T	PARTICIPANT	\N	PRESENT	0
421955	407837	19741B	PARTICIPANT	\N	PRESENT	0
421956	407837	14157T	PARTICIPANT	\N	PRESENT	0
421957	407837	08061X	PARTICIPANT	\N	PRESENT	0
421958	407837	08069G	PARTICIPANT	\N	PRESENT	0
421959	407837	11104D	PARTICIPANT	\N	PRESENT	0
421960	407837	19413M	PARTICIPANT	\N	PRESENT	0
421961	407837	08010L	PARTICIPANT	\N	PRESENT	0
421962	407837	08073C	PARTICIPANT	\N	PRESENT	0
421963	407837	14135M	PARTICIPANT	\N	PRESENT	0
421964	407837	14028W	PARTICIPANT	\N	PRESENT	0
421965	407837	01058X	PARTICIPANT	\N	PRESENT	0
421966	407837	14225N	PARTICIPANT	\N	PRESENT	0
421967	407837	19673G	PARTICIPANT	\N	PRESENT	0
421968	407837	02002K	PARTICIPANT	\N	PRESENT	0
421969	407837	11048N	PARTICIPANT	\N	PRESENT	0
421970	407837	19611R	PARTICIPANT	\N	PRESENT	0
421971	407837	86034E	PARTICIPANT	\N	PRESENT	0
421972	407837	04049K	PARTICIPANT	\N	PRESENT	0
421973	407837	14207L	PARTICIPANT	\N	PRESENT	0
421974	407837	14021P	PARTICIPANT	\N	PRESENT	0
421975	407837	11080N	PARTICIPANT	\N	PRESENT	0
421976	407837	19533U	PARTICIPANT	\N	PRESENT	0
421977	407837	19747H	PARTICIPANT	\N	PRESENT	0
421978	407837	11090Q	PARTICIPANT	\N	PRESENT	0
421979	407837	19723Y	PARTICIPANT	\N	PRESENT	0
421980	407837	19671E	PARTICIPANT	\N	PRESENT	0
421981	407837	11056N	PARTICIPANT	\N	PRESENT	0
421982	407837	08018U	PARTICIPANT	\N	PRESENT	0
421983	407837	19760E	PARTICIPANT	\N	PRESENT	0
421984	407837	19709B	PARTICIPANT	\N	PRESENT	0
421985	407837	19687N	PARTICIPANT	\N	PRESENT	0
421986	407837	05008E	PARTICIPANT	\N	PRESENT	0
421987	407837	14069U	PARTICIPANT	\N	PRESENT	0
421988	407837	19415P	PARTICIPANT	\N	PRESENT	0
421989	407837	14239U	PARTICIPANT	\N	PRESENT	0
421990	407837	19651A	PARTICIPANT	\N	PRESENT	0
421991	407837	19269X	PARTICIPANT	\N	PRESENT	0
421992	407837	19697Q	PARTICIPANT	\N	PRESENT	0
421993	407837	19543W	PARTICIPANT	\N	PRESENT	0
421994	407837	19782L	PARTICIPANT	\N	PRESENT	0
421995	407837	08024S	PARTICIPANT	\N	PRESENT	0
421996	407837	11072N	PARTICIPANT	\N	PRESENT	0
421997	407837	11012A	PARTICIPANT	\N	PRESENT	0
421998	407837	08031R	PARTICIPANT	\N	PRESENT	0
421999	407837	14261S	PARTICIPANT	\N	PRESENT	0
422000	407837	01057W	PARTICIPANT	\N	PRESENT	0
422001	407837	19679N	PARTICIPANT	\N	PRESENT	0
422003	407837	19545Y	PARTICIPANT	\N	PRESENT	0
422004	407837	04057K	PARTICIPANT	\N	PRESENT	0
422005	407837	95063L	PARTICIPANT	\N	PRESENT	0
422006	407837	19667J	PARTICIPANT	\N	PRESENT	0
422007	407837	14199E	PARTICIPANT	\N	PRESENT	0
422008	407837	14159V	PARTICIPANT	\N	PRESENT	0
422009	407837	98018T	PARTICIPANT	\N	PRESENT	0
422010	407837	12041X	PARTICIPANT	\N	PRESENT	0
422011	407837	19758L	PARTICIPANT	\N	PRESENT	0
422012	407837	96004D	PARTICIPANT	\N	PRESENT	0
422013	407837	19573D	PARTICIPANT	\N	PRESENT	0
422014	407837	08052W	PARTICIPANT	\N	PRESENT	0
422015	407837	04042C	PARTICIPANT	\N	PRESENT	0
422016	407837	04045F	PARTICIPANT	\N	PRESENT	0
422017	407837	14133K	PARTICIPANT	\N	PRESENT	0
422018	407837	14151M	PARTICIPANT	\N	PRESENT	0
422019	407837	04047H	PARTICIPANT	\N	PRESENT	0
422020	407837	19647E	PARTICIPANT	\N	PRESENT	0
422021	407837	19649G	PARTICIPANT	\N	PRESENT	0
422022	407837	92040Q	PARTICIPANT	\N	PRESENT	0
422023	407837	11049P	PARTICIPANT	\N	PRESENT	0
422024	407837	08038Y	PARTICIPANT	\N	PRESENT	0
422025	407837	14115H	PARTICIPANT	\N	PRESENT	0
422026	407837	19820Y	PARTICIPANT	\N	PRESENT	0
422027	407837	19727D	PARTICIPANT	\N	PRESENT	0
422028	407837	14147R	PARTICIPANT	\N	PRESENT	0
422029	407837	19553Y	PARTICIPANT	\N	PRESENT	0
422030	407837	14061L	PARTICIPANT	\N	PRESENT	0
422031	407837	14038Y	PARTICIPANT	\N	PRESENT	0
422032	407837	19669L	PARTICIPANT	\N	PRESENT	0
422033	407837	19467C	PARTICIPANT	\N	PRESENT	0
422034	407837	18083K	PARTICIPANT	\N	PRESENT	0
422035	407837	08017T	PARTICIPANT	\N	PRESENT	0
422036	407837	19399H	PARTICIPANT	\N	PRESENT	0
422037	407837	17779H	PARTICIPANT	\N	PRESENT	0
422038	407837	19725B	PARTICIPANT	\N	PRESENT	0
422039	407837	19659J	PARTICIPANT	\N	PRESENT	0
422040	407837	14265W	PARTICIPANT	\N	PRESENT	0
422041	407837	14001X	PARTICIPANT	\N	PRESENT	0
422042	407837	14093U	PARTICIPANT	\N	PRESENT	0
422043	407837	19705W	PARTICIPANT	\N	PRESENT	0
422044	407837	14227Q	PARTICIPANT	\N	PRESENT	0
422045	407837	14119M	PARTICIPANT	\N	PRESENT	0
422046	407837	19503N	PARTICIPANT	\N	PRESENT	0
422047	407837	19683J	PARTICIPANT	\N	PRESENT	0
422048	407837	14097Y	PARTICIPANT	\N	PRESENT	0
422049	407837	19631V	PARTICIPANT	\N	PRESENT	0
422050	407837	19575F	PARTICIPANT	\N	PRESENT	0
422051	407837	14029X	PARTICIPANT	\N	PRESENT	0
422052	407837	07029T	PARTICIPANT	\N	PRESENT	0
422053	407837	19565D	PARTICIPANT	\N	PRESENT	0
422054	407837	19663E	PARTICIPANT	\N	PRESENT	0
422055	407837	14034U	PARTICIPANT	\N	PRESENT	0
422056	407837	04038G	PARTICIPANT	\N	PRESENT	0
422057	407837	08062Y	PARTICIPANT	\N	PRESENT	0
422058	407837	19689Q	PARTICIPANT	\N	PRESENT	0
422059	407837	08015R	PARTICIPANT	\N	PRESENT	0
422060	407837	14087W	PARTICIPANT	\N	PRESENT	0
422061	407837	19729F	PARTICIPANT	\N	PRESENT	0
422062	407837	14179A	PARTICIPANT	\N	PRESENT	0
422063	407837	19768N	PARTICIPANT	\N	PRESENT	0
422064	407837	19691J	PARTICIPANT	\N	PRESENT	0
422065	407837	01034P	PARTICIPANT	\N	PRESENT	0
422066	407837	11053K	PARTICIPANT	\N	PRESENT	0
422067	407837	19737F	PARTICIPANT	\N	PRESENT	0
422068	407837	14357A	PARTICIPANT	\N	PRESENT	0
422069	407837	19347U	PARTICIPANT	\N	PRESENT	0
422070	407837	04043D	PARTICIPANT	\N	PRESENT	0
422071	407837	14109K	PARTICIPANT	\N	PRESENT	0
422072	407837	19762G	PARTICIPANT	\N	PRESENT	0
422073	407837	19699S	PARTICIPANT	\N	PRESENT	0
422074	407837	19735D	PARTICIPANT	\N	PRESENT	0
422075	407837	19701S	PARTICIPANT	\N	PRESENT	0
422076	407837	14219Q	PARTICIPANT	\N	PRESENT	0
422077	407837	17637T	PARTICIPANT	\N	PRESENT	0
422078	407837	11065P	PARTICIPANT	\N	PRESENT	0
422079	407837	19479G	PARTICIPANT	\N	PRESENT	0
422080	407837	95067Q	PARTICIPANT	\N	PRESENT	0
422081	407837	19441R	PARTICIPANT	\N	PRESENT	0
422082	407837	19713W	PARTICIPANT	\N	PRESENT	0
422083	407837	19367Y	PARTICIPANT	\N	PRESENT	0
422084	407837	14121F	PARTICIPANT	\N	PRESENT	0
422085	407837	89017R	PARTICIPANT	\N	PRESENT	0
422086	407837	14055N	PARTICIPANT	\N	PRESENT	0
422087	407837	14217N	PARTICIPANT	\N	PRESENT	0
422088	407837	14331P	PARTICIPANT	\N	PRESENT	0
422089	407837	14079W	PARTICIPANT	\N	PRESENT	0
422090	407837	19521Q	PARTICIPANT	\N	PRESENT	0
397079	396239	10006L	PARTICIPANT	\N	PRESENT	0
397112	397111	95062K	PARTICIPANT	\N	PRESENT	0
398305	398304	19611R	PARTICIPANT	\N	PRESENT	0
400099	397651	14069U	PARTICIPANT	\N	PRESENT	0
400101	397651	04086Q	PARTICIPANT	\N	PRESENT	0
400102	397651	14259Y	PARTICIPANT	\N	PRESENT	0
400103	397651	14281W	PARTICIPANT	\N	PRESENT	0
400104	397651	14231L	PARTICIPANT	\N	PRESENT	0
400105	397651	01057W	PARTICIPANT	\N	PRESENT	0
400106	397651	11048N	PARTICIPANT	\N	PRESENT	0
400107	397651	08010L	PARTICIPANT	\N	PRESENT	0
400108	397651	08034U	PARTICIPANT	\N	PRESENT	0
400109	397651	05012A	PARTICIPANT	\N	PRESENT	0
400110	397651	19735D	PARTICIPANT	\N	PRESENT	0
400111	397651	19687N	PARTICIPANT	\N	PRESENT	0
400112	397651	04045F	PARTICIPANT	\N	PRESENT	0
400113	397651	95067Q	PARTICIPANT	\N	PRESENT	0
400114	397651	19525U	PARTICIPANT	\N	PRESENT	0
401304	393614	11026G	PARTICIPANT	\N	PRESENT	0
401305	393614	08068F	PARTICIPANT	\N	PRESENT	0
401306	393614	14029X	PARTICIPANT	\N	PRESENT	0
401176	398618	04097T	PARTICIPANT	\N	PRESENT	0
401177	398618	14026U	PARTICIPANT	\N	PRESENT	0
401308	393614	14119M	PARTICIPANT	\N	PRESENT	0
401312	393614	14199E	PARTICIPANT	\N	PRESENT	0
401318	393614	19737F	PARTICIPANT	\N	PRESENT	0
401319	393614	19319Q	PARTICIPANT	\N	PRESENT	0
401320	393614	14265W	PARTICIPANT	\N	PRESENT	0
401321	393614	14173T	PARTICIPANT	\N	PRESENT	0
401322	393614	14038Y	PARTICIPANT	\N	PRESENT	0
401323	393614	11048N	PARTICIPANT	\N	PRESENT	0
401277	393614	19591F	PARTICIPANT	\N	PRESENT	0
401278	393614	19758L	PARTICIPANT	\N	PRESENT	0
401279	393614	04049K	PARTICIPANT	\N	PRESENT	0
401280	393614	19367Y	PARTICIPANT	\N	PRESENT	0
401281	393614	19533U	PARTICIPANT	\N	PRESENT	0
401282	393614	19515S	PARTICIPANT	\N	PRESENT	0
401283	393614	11067R	PARTICIPANT	\N	PRESENT	0
401284	393614	19503N	PARTICIPANT	\N	PRESENT	0
401285	393614	19711U	PARTICIPANT	\N	PRESENT	0
401286	393614	14187A	PARTICIPANT	\N	PRESENT	0
401287	393614	19695N	PARTICIPANT	\N	PRESENT	0
401288	393614	14030Q	PARTICIPANT	\N	PRESENT	0
401289	393614	19421M	PARTICIPANT	\N	PRESENT	0
401290	393614	04033B	PARTICIPANT	\N	PRESENT	0
401291	393614	19369B	PARTICIPANT	\N	PRESENT	0
401292	393614	19713W	PARTICIPANT	\N	PRESENT	0
401293	393614	11097X	PARTICIPANT	\N	PRESENT	0
401294	393614	01025N	PARTICIPANT	\N	PRESENT	0
401295	393614	14331P	PARTICIPANT	\N	PRESENT	0
401296	393614	19741B	PARTICIPANT	\N	PRESENT	0
401297	393614	19289C	PARTICIPANT	\N	PRESENT	0
401298	393614	19705W	PARTICIPANT	\N	PRESENT	0
401299	393614	10015M	PARTICIPANT	\N	PRESENT	0
401300	393614	19593H	PARTICIPANT	\N	PRESENT	0
401301	393614	19269X	PARTICIPANT	\N	PRESENT	0
401302	393614	01024M	PARTICIPANT	\N	PRESENT	0
401303	393614	01028R	PARTICIPANT	\N	PRESENT	0
401324	393614	11056N	PARTICIPANT	\N	PRESENT	0
401325	393614	19551W	PARTICIPANT	\N	PRESENT	0
401326	393614	19333N	PARTICIPANT	\N	PRESENT	0
401327	393614	14073Q	PARTICIPANT	\N	PRESENT	0
401328	393614	04088S	PARTICIPANT	\N	PRESENT	0
401329	393614	18083K	PARTICIPANT	\N	PRESENT	0
401330	393614	14031R	PARTICIPANT	\N	PRESENT	0
401331	393614	19553Y	PARTICIPANT	\N	PRESENT	0
401332	393614	19563B	PARTICIPANT	\N	PRESENT	0
401333	393614	19691J	PARTICIPANT	\N	PRESENT	0
401334	393614	19335Q	PARTICIPANT	\N	PRESENT	0
401335	393614	11053K	PARTICIPANT	\N	PRESENT	0
401336	393614	19441R	PARTICIPANT	\N	PRESENT	0
401337	393614	19387D	PARTICIPANT	\N	PRESENT	0
401338	393614	08038Y	PARTICIPANT	\N	PRESENT	0
401339	393614	14357A	PARTICIPANT	\N	PRESENT	0
401340	393614	19507S	PARTICIPANT	\N	PRESENT	0
401341	393614	11101A	PARTICIPANT	\N	PRESENT	0
401342	393614	19447X	PARTICIPANT	\N	PRESENT	0
401343	393614	87003B	PARTICIPANT	\N	PRESENT	0
401344	393614	88008L	PARTICIPANT	\N	PRESENT	0
401345	393614	08044W	PARTICIPANT	\N	PRESENT	0
401346	393614	19611R	PARTICIPANT	\N	PRESENT	0
401347	393614	14107H	PARTICIPANT	\N	PRESENT	0
401348	393614	14093U	PARTICIPANT	\N	PRESENT	0
401349	393614	14251Q	PARTICIPANT	\N	PRESENT	0
401350	393614	11072N	PARTICIPANT	\N	PRESENT	0
401351	393614	04092N	PARTICIPANT	\N	PRESENT	0
401352	393614	10006L	PARTICIPANT	\N	PRESENT	0
401353	393614	97011G	PARTICIPANT	\N	PRESENT	0
401354	393614	14026U	PARTICIPANT	\N	PRESENT	0
401355	393614	14329V	PARTICIPANT	\N	PRESENT	0
401356	393614	14135M	PARTICIPANT	\N	PRESENT	0
401357	393614	19719D	PARTICIPANT	\N	PRESENT	0
401358	393614	14195A	PARTICIPANT	\N	PRESENT	0
401359	393614	11109J	PARTICIPANT	\N	PRESENT	0
401360	393614	19531S	PARTICIPANT	\N	PRESENT	0
401361	393614	19253P	PARTICIPANT	\N	PRESENT	0
401362	393614	11099A	PARTICIPANT	\N	PRESENT	0
401363	393614	04085P	PARTICIPANT	\N	PRESENT	0
401364	393614	19347U	PARTICIPANT	\N	PRESENT	0
401465	393615	11027H	PARTICIPANT	\N	PRESENT	0
401466	393615	14033T	PARTICIPANT	\N	PRESENT	0
401467	393615	19733B	PARTICIPANT	\N	PRESENT	0
401468	393615	08060W	PARTICIPANT	\N	PRESENT	0
401469	393615	14051J	PARTICIPANT	\N	PRESENT	0
401470	393615	80013X	PARTICIPANT	\N	PRESENT	0
401471	393615	14197C	PARTICIPANT	\N	PRESENT	0
401472	393615	19551W	PARTICIPANT	\N	PRESENT	0
401473	393615	17589D	PARTICIPANT	\N	PRESENT	0
401474	393615	19713W	PARTICIPANT	\N	PRESENT	0
401475	393615	19319Q	PARTICIPANT	\N	PRESENT	0
401476	393615	19479G	PARTICIPANT	\N	PRESENT	0
401477	393615	19413M	PARTICIPANT	\N	PRESENT	0
401478	393615	11109J	PARTICIPANT	\N	PRESENT	0
401479	393615	01025N	PARTICIPANT	\N	PRESENT	0
401480	393615	19533U	PARTICIPANT	\N	PRESENT	0
401481	393615	11048N	PARTICIPANT	\N	PRESENT	0
401482	393615	14265W	PARTICIPANT	\N	PRESENT	0
401483	393615	14357A	PARTICIPANT	\N	PRESENT	0
401484	393615	19467C	PARTICIPANT	\N	PRESENT	0
401485	393615	11090Q	PARTICIPANT	\N	PRESENT	0
401486	393615	14257W	PARTICIPANT	\N	PRESENT	0
401487	393615	14187A	PARTICIPANT	\N	PRESENT	0
401488	393615	19782L	PARTICIPANT	\N	PRESENT	0
401489	393615	11033F	PARTICIPANT	\N	PRESENT	0
401490	393615	19503N	PARTICIPANT	\N	PRESENT	0
401491	393615	08068F	PARTICIPANT	\N	PRESENT	0
401492	393615	19695N	PARTICIPANT	\N	PRESENT	0
401493	393615	14205J	PARTICIPANT	\N	PRESENT	0
401494	393615	14329V	PARTICIPANT	\N	PRESENT	0
401495	393615	19531S	PARTICIPANT	\N	PRESENT	0
401496	393615	10006L	PARTICIPANT	\N	PRESENT	0
401497	393615	18083K	PARTICIPANT	\N	PRESENT	0
401498	393615	04088S	PARTICIPANT	\N	PRESENT	0
401499	393615	19593H	PARTICIPANT	\N	PRESENT	0
401500	393615	11077T	PARTICIPANT	\N	PRESENT	0
401501	393615	19347U	PARTICIPANT	\N	PRESENT	0
401502	393615	19575F	PARTICIPANT	\N	PRESENT	0
401503	393615	14021P	PARTICIPANT	\N	PRESENT	0
401504	393615	19747H	PARTICIPANT	\N	PRESENT	0
401505	393615	19549D	PARTICIPANT	\N	PRESENT	0
401506	393615	14093U	PARTICIPANT	\N	PRESENT	0
401507	393615	11066Q	PARTICIPANT	\N	PRESENT	0
401508	393615	14219Q	PARTICIPANT	\N	PRESENT	0
401509	393615	19387D	PARTICIPANT	\N	PRESENT	0
401510	393615	19573D	PARTICIPANT	\N	PRESENT	0
401511	393615	14031R	PARTICIPANT	\N	PRESENT	0
401512	393615	14135M	PARTICIPANT	\N	PRESENT	0
401513	393615	08015R	PARTICIPANT	\N	PRESENT	0
401514	393615	19768N	PARTICIPANT	\N	PRESENT	0
401515	393615	08062Y	PARTICIPANT	\N	PRESENT	0
401516	393615	14215L	PARTICIPANT	\N	PRESENT	0
401517	393615	19333N	PARTICIPANT	\N	PRESENT	0
401518	393615	19709B	PARTICIPANT	\N	PRESENT	0
401519	393615	04049K	PARTICIPANT	\N	PRESENT	0
401520	393615	11099A	PARTICIPANT	\N	PRESENT	0
401521	393615	19369B	PARTICIPANT	\N	PRESENT	0
401522	393615	19507S	PARTICIPANT	\N	PRESENT	0
401523	393615	14029X	PARTICIPANT	\N	PRESENT	0
401524	393615	19443T	PARTICIPANT	\N	PRESENT	0
401525	393615	19693L	PARTICIPANT	\N	PRESENT	0
401526	393615	14157T	PARTICIPANT	\N	PRESENT	0
401527	393615	19515S	PARTICIPANT	\N	PRESENT	0
401528	393615	19335Q	PARTICIPANT	\N	PRESENT	0
401529	393615	19447X	PARTICIPANT	\N	PRESENT	0
401530	393615	14169X	PARTICIPANT	\N	PRESENT	0
401531	393615	19383Y	PARTICIPANT	\N	PRESENT	0
401532	393615	04033B	PARTICIPANT	\N	PRESENT	0
401533	393615	14026U	PARTICIPANT	\N	PRESENT	0
411729	409431	19683J	PARTICIPANT	\N	PRESENT	0
411730	409431	19521Q	PARTICIPANT	\N	PRESENT	0
411731	409431	01034P	PARTICIPANT	\N	PRESENT	0
411732	409431	04092N	PRESIDENT	0	PRESENT	0
411733	409431	08052W	PARTICIPANT	\N	PRESENT	0
411734	409431	19663E	PARTICIPANT	\N	PRESENT	0
411735	409431	19715Y	PARTICIPANT	\N	PRESENT	0
411736	409431	19691J	PARTICIPANT	\N	PRESENT	0
411737	409431	19723Y	PARTICIPANT	\N	PRESENT	0
411738	409431	19727D	PARTICIPANT	\N	PRESENT	0
411739	409431	14119M	PARTICIPANT	\N	PRESENT	0
411740	409431	11103C	PARTICIPANT	\N	PRESENT	0
411741	409431	14071N	PARTICIPANT	\N	PRESENT	0
411742	409431	19657G	PARTICIPANT	\N	PRESENT	0
411743	409431	08041T	PARTICIPANT	\N	EXCUSE	0
411744	409431	19575F	PARTICIPANT	\N	PRESENT	0
411871	411100	11074Q	PRESIDENT	0	PRESENT	0
411872	411100	14327T	PARTICIPANT	\N	PRESENT	0
411873	411100	19647E	PARTICIPANT	\N	PRESENT	0
411874	411100	19479G	PARTICIPANT	\N	PRESENT	0
411875	411100	04071H	PARTICIPANT	\N	PRESENT	0
411876	411100	11048N	PARTICIPANT	\N	PRESENT	0
411877	411100	19711U	PARTICIPANT	\N	PRESENT	0
411878	411100	01048V	PARTICIPANT	\N	PRESENT	0
411879	411100	08034U	PARTICIPANT	\N	PRESENT	0
411880	411100	01057W	PARTICIPANT	\N	PRESENT	0
411881	411100	19689Q	PARTICIPANT	\N	PRESENT	0
411882	411100	08011M	PARTICIPANT	\N	PRESENT	0
411883	411100	08014Q	PARTICIPANT	\N	PRESENT	0
411884	411100	14225N	PARTICIPANT	\N	PRESENT	0
411885	411100	11070L	PARTICIPANT	\N	PRESENT	0
411886	411100	11110B	PARTICIPANT	\N	PRESENT	0
411887	411100	11040E	PARTICIPANT	\N	PRESENT	0
411888	411100	04086Q	PARTICIPANT	\N	PRESENT	0
411889	411100	14083S	PARTICIPANT	\N	PRESENT	0
411890	411100	14085U	PARTICIPANT	\N	PRESENT	0
411891	411100	19349W	PARTICIPANT	\N	PRESENT	0
411892	411100	14121F	PARTICIPANT	\N	PRESENT	0
411893	411100	14253S	PARTICIPANT	\N	PRESENT	0
411894	411100	07029T	PARTICIPANT	\N	EXCUSE	0
411895	411100	99004R	PARTICIPANT	\N	EXCUSE	0
411896	411100	14034U	PARTICIPANT	\N	PRESENT	0
411904	411100	89017R	PARTICIPANT	\N	PRESENT	0
411927	411925	19747H	PARTICIPANT	\N	PRESENT	0
411928	411926	19747H	PARTICIPANT	\N	PRESENT	0
411930	411929	19747H	PARTICIPANT	\N	PRESENT	0
411969	406844	86034E	PARTICIPANT	\N	PRESENT	0
411970	406844	12041X	PARTICIPANT	\N	PRESENT	0
411971	406844	11056N	PARTICIPANT	\N	PRESENT	0
411972	406844	19758L	PARTICIPANT	\N	PRESENT	0
411973	406844	11040E	PARTICIPANT	\N	PRESENT	0
411974	406844	19760E	PARTICIPANT	\N	PRESENT	0
411975	406844	19565D	PARTICIPANT	\N	PRESENT	0
411976	406844	14235Q	PARTICIPANT	\N	PRESENT	0
411977	406844	19347U	PARTICIPANT	\N	PRESENT	0
411978	406844	19593H	PARTICIPANT	\N	PRESENT	0
411979	406844	14211G	PARTICIPANT	\N	PRESENT	0
411980	406844	08061X	PARTICIPANT	\N	PRESENT	0
411981	406844	19711U	PARTICIPANT	\N	PRESENT	0
411982	406844	95037J	PARTICIPANT	\N	PRESENT	0
411983	406844	04045F	PARTICIPANT	\N	PRESENT	0
411984	406844	04008A	PARTICIPANT	\N	PRESENT	0
411985	406844	98029W	PARTICIPANT	\N	PRESENT	0
411986	406844	19651A	PARTICIPANT	\N	PRESENT	0
411987	406844	11083R	PARTICIPANT	\N	PRESENT	0
411988	406844	14157T	PARTICIPANT	\N	PRESENT	0
411989	406844	19349W	PARTICIPANT	\N	PRESENT	0
411990	406844	19637C	PARTICIPANT	\N	PRESENT	0
411991	406844	19269X	PARTICIPANT	\N	PRESENT	0
411992	406844	19543W	PARTICIPANT	\N	PRESENT	0
411993	406844	01058X	PARTICIPANT	\N	PRESENT	0
411994	406844	19697Q	PARTICIPANT	\N	PRESENT	0
411995	406844	08024S	PARTICIPANT	\N	PRESENT	0
411996	406844	08010L	PARTICIPANT	\N	PRESENT	0
411997	406844	08073C	PARTICIPANT	\N	PRESENT	0
411998	406844	08020N	PARTICIPANT	\N	PRESENT	0
411999	406844	19812Y	PARTICIPANT	\N	PRESENT	0
412000	406844	15447F	PARTICIPANT	\N	PRESENT	0
412001	406844	04034C	PARTICIPANT	\N	PRESENT	0
412002	406844	19643A	PARTICIPANT	\N	PRESENT	0
412003	406844	14239U	PARTICIPANT	\N	PRESENT	0
412004	406844	19731Y	PARTICIPANT	\N	PRESENT	0
412005	406844	89017R	PARTICIPANT	\N	PRESENT	0
412006	406844	19685L	PARTICIPANT	\N	PRESENT	0
412007	406844	14223L	PARTICIPANT	\N	PRESENT	0
412008	406844	08056B	PARTICIPANT	\N	PRESENT	0
412009	406844	14055N	PARTICIPANT	\N	PRESENT	0
412010	406844	19629C	PARTICIPANT	\N	PRESENT	0
412011	406844	14169X	PARTICIPANT	\N	PRESENT	0
412012	406844	88008L	PARTICIPANT	\N	PRESENT	0
412013	406844	11012A	PARTICIPANT	\N	PRESENT	0
412014	406844	14034U	PARTICIPANT	\N	PRESENT	0
412015	406844	08031R	PARTICIPANT	\N	PRESENT	0
412016	406844	08049C	PARTICIPANT	\N	PRESENT	0
412017	406844	14207L	PARTICIPANT	\N	PRESENT	0
412018	406844	98022P	PARTICIPANT	\N	PRESENT	0
412019	406844	19443T	PARTICIPANT	\N	PRESENT	0
412020	406844	14241N	PARTICIPANT	\N	PRESENT	0
412021	406844	19741B	PARTICIPANT	\N	PRESENT	0
412022	406844	19719D	PARTICIPANT	\N	PRESENT	0
412023	406844	14029X	PARTICIPANT	\N	PRESENT	0
412024	406844	14107H	PARTICIPANT	\N	PRESENT	0
412025	406844	19709B	PARTICIPANT	\N	PRESENT	0
412026	406844	19289C	PARTICIPANT	\N	PRESENT	0
412027	406844	19681G	PARTICIPANT	\N	PRESENT	0
412028	406844	14121F	PARTICIPANT	\N	PRESENT	0
412029	406844	19663E	PARTICIPANT	\N	PRESENT	0
412030	406844	11065P	PARTICIPANT	\N	PRESENT	0
412031	406844	04088S	PARTICIPANT	\N	PRESENT	0
412032	406844	19387D	PARTICIPANT	\N	PRESENT	0
412033	406844	08018U	PARTICIPANT	\N	PRESENT	0
412034	406844	11077T	PARTICIPANT	\N	PRESENT	0
412035	406844	07029T	PARTICIPANT	\N	PRESENT	0
412036	406844	14195A	PARTICIPANT	\N	PRESENT	0
412037	406844	19585H	PARTICIPANT	\N	PRESENT	0
412038	406844	19545Y	PARTICIPANT	\N	PRESENT	0
412039	406844	19657G	PARTICIPANT	\N	PRESENT	0
412040	406844	14111D	PARTICIPANT	\N	PRESENT	0
412041	406844	19563B	PARTICIPANT	\N	PRESENT	0
412042	406844	14355X	PARTICIPANT	\N	PRESENT	0
412043	406844	19583F	PARTICIPANT	\N	PRESENT	0
412044	406844	98005N	PARTICIPANT	\N	PRESENT	0
412045	406844	08062Y	PARTICIPANT	\N	PRESENT	0
412046	406844	11064N	PARTICIPANT	\N	PRESENT	0
412047	406844	08015R	PARTICIPANT	\N	PRESENT	0
412048	406844	19553Y	PARTICIPANT	\N	PRESENT	0
412049	406844	19768N	PARTICIPANT	\N	PRESENT	0
412050	406844	98050T	PARTICIPANT	\N	PRESENT	0
412051	406844	98035U	PARTICIPANT	\N	PRESENT	0
412052	406844	14159V	PARTICIPANT	\N	PRESENT	0
412053	406844	14061L	PARTICIPANT	\N	PRESENT	0
412054	406844	11027H	PARTICIPANT	\N	PRESENT	0
412055	406844	14059S	PARTICIPANT	\N	PRESENT	0
412056	406844	11074Q	PARTICIPANT	\N	PRESENT	0
412057	406844	04085P	PARTICIPANT	\N	PRESENT	0
412058	406844	14038Y	PARTICIPANT	\N	PRESENT	0
412059	406844	11033F	PARTICIPANT	\N	PRESENT	0
412060	406844	19507S	PARTICIPANT	\N	PRESENT	0
412061	406844	08052W	PARTICIPANT	\N	PRESENT	0
412062	406844	19467C	PARTICIPANT	\N	PRESENT	0
412063	406844	08068F	PARTICIPANT	\N	PRESENT	0
412064	406844	18083K	PARTICIPANT	\N	PRESENT	0
412065	406844	19415P	PARTICIPANT	\N	PRESENT	0
412066	406844	14229S	PARTICIPANT	\N	PRESENT	0
412067	406844	08055A	PARTICIPANT	\N	PRESENT	0
412068	406844	14033T	PARTICIPANT	\N	PRESENT	0
412069	406844	14021P	PARTICIPANT	\N	PRESENT	0
412070	406844	14135M	PARTICIPANT	\N	PRESENT	0
412071	406844	08045X	PARTICIPANT	\N	PRESENT	0
412072	406844	19669L	PARTICIPANT	\N	PRESENT	0
412073	406844	08019V	PARTICIPANT	\N	PRESENT	0
412074	406844	14225N	PARTICIPANT	\N	PRESENT	0
412075	406844	19399H	PARTICIPANT	\N	PRESENT	0
412076	406844	19689Q	PARTICIPANT	\N	PRESENT	0
412077	406844	19693L	PARTICIPANT	\N	PRESENT	0
412078	406844	19729F	PARTICIPANT	\N	PRESENT	0
412079	406844	14197C	PARTICIPANT	\N	PRESENT	0
412080	406844	08048B	PARTICIPANT	\N	PRESENT	0
412081	406844	19715Y	PARTICIPANT	\N	PRESENT	0
412082	406844	14265W	PARTICIPANT	\N	PRESENT	0
412083	406844	19599P	PARTICIPANT	\N	PRESENT	0
412084	406844	14213J	PARTICIPANT	\N	PRESENT	0
412085	406844	11041F	PARTICIPANT	\N	PRESENT	0
412086	406844	14329V	PARTICIPANT	\N	PRESENT	0
412087	406844	19649G	PARTICIPANT	\N	PRESENT	0
412088	406844	19705W	PARTICIPANT	\N	PRESENT	0
412089	406844	19647E	PARTICIPANT	\N	PRESENT	0
412090	406844	19383Y	PARTICIPANT	\N	PRESENT	0
412091	406844	14151M	PARTICIPANT	\N	PRESENT	0
404249	404247	11053K	PARTICIPANT	\N	PRESENT	0
404250	404247	19253P	PARTICIPANT	\N	PRESENT	0
404251	404247	19387D	PARTICIPANT	\N	PRESENT	0
404252	404247	14327T	PARTICIPANT	\N	PRESENT	0
404253	404247	19671E	PARTICIPANT	\N	PRESENT	0
404269	404248	11053K	PARTICIPANT	\N	PRESENT	0
404270	404248	19253P	PARTICIPANT	\N	PRESENT	0
404271	404248	14103D	PARTICIPANT	\N	PRESENT	0
404272	404248	14111D	PARTICIPANT	\N	PRESENT	0
404606	404605	19441R	PARTICIPANT	\N	PRESENT	0
404607	404605	04057K	PARTICIPANT	\N	PRESENT	0
404608	404605	04097T	PARTICIPANT	\N	PRESENT	0
404609	404605	14026U	PARTICIPANT	\N	PRESENT	0
404610	404605	08015R	PARTICIPANT	\N	PRESENT	0
405506	405449	04040A	PRESIDENT	0	PRESENT	0
407814	404749	14299H	PARTICIPANT	\N	PRESENT	0
407822	404749	19683J	PARTICIPANT	\N	PRESENT	0
407823	404749	01048V	PARTICIPANT	\N	PRESENT	0
407824	404749	19533U	PARTICIPANT	\N	PRESENT	0
407825	404749	04043D	PARTICIPANT	\N	PRESENT	0
407826	404749	19693L	PARTICIPANT	\N	EXCUSE	0
407827	404749	80013X	PARTICIPANT	\N	EXCUSE	0
407828	404749	14093U	PARTICIPANT	\N	EXCUSE	0
407832	407831	14123H	PARTICIPANT	\N	PRESENT	0
409126	405277	02002K	PARTICIPANT	\N	PRESENT	0
409127	405277	19349W	PARTICIPANT	\N	PRESENT	0
409451	405277	11056N	PARTICIPANT	\N	EXCUSE	0
414691	406852	14241N	PARTICIPANT	\N	PRESENT	0
414692	406852	19719D	PARTICIPANT	\N	PRESENT	0
414693	406852	14123H	PARTICIPANT	\N	PRESENT	0
414694	406852	08039A	PARTICIPANT	\N	PRESENT	0
414695	406852	14026U	PARTICIPANT	\N	PRESENT	0
414696	406852	19691J	PARTICIPANT	\N	PRESENT	0
414697	406852	19741B	PARTICIPANT	\N	PRESENT	0
414698	406852	14034U	PARTICIPANT	\N	PRESENT	0
414699	406852	19507S	PARTICIPANT	\N	PRESENT	0
414700	413507	19697Q	PARTICIPANT	\N	PRESENT	0
414701	413507	11067R	PARTICIPANT	\N	PRESENT	0
414702	413507	19565D	PARTICIPANT	\N	PRESENT	0
414703	413507	19798U	PARTICIPANT	\N	PRESENT	0
414704	413507	19415P	PARTICIPANT	\N	PRESENT	0
414705	413507	14223L	PARTICIPANT	\N	PRESENT	0
414706	413507	04045F	PARTICIPANT	\N	PRESENT	0
414707	413507	14026U	PARTICIPANT	\N	PRESENT	0
414708	413507	17779H	PARTICIPANT	\N	PRESENT	0
414709	413507	11031D	PARTICIPANT	\N	PRESENT	0
414689	406852	19447X	PARTICIPANT	\N	PRESENT	0
414690	406852	14111D	PARTICIPANT	\N	PRESENT	0
414710	413507	19703U	PARTICIPANT	\N	PRESENT	0
414711	413507	19553Y	PARTICIPANT	\N	PRESENT	0
414712	413507	14239U	PARTICIPANT	\N	PRESENT	0
414713	413507	14281W	PARTICIPANT	\N	PRESENT	0
414714	413507	14087W	PARTICIPANT	\N	PRESENT	0
414715	413507	19679N	PARTICIPANT	\N	PRESENT	0
414716	413507	14195A	PARTICIPANT	\N	PRESENT	0
414717	413507	19575F	PARTICIPANT	\N	PRESENT	0
414718	413507	19367Y	PARTICIPANT	\N	PRESENT	0
414719	413507	14213J	PARTICIPANT	\N	PRESENT	0
414720	413507	98024R	PARTICIPANT	\N	PRESENT	0
414721	413507	01034P	PARTICIPANT	\N	PRESENT	0
414722	413507	04092N	PRESIDENT	0	PRESENT	0
414723	413507	08052W	PARTICIPANT	\N	PRESENT	0
414724	413507	19663E	PARTICIPANT	\N	PRESENT	0
414725	413507	19301E	PARTICIPANT	\N	PRESENT	0
414726	413507	19691J	PARTICIPANT	\N	PRESENT	0
414727	413507	19715Y	PARTICIPANT	\N	PRESENT	0
414728	413507	19723Y	PARTICIPANT	\N	PRESENT	0
414729	413507	19727D	PARTICIPANT	\N	PRESENT	0
414730	413507	14119M	PARTICIPANT	\N	PRESENT	0
414731	413507	11103C	PARTICIPANT	\N	PRESENT	0
414732	413507	19760E	PARTICIPANT	\N	PRESENT	0
414733	413507	08041T	PARTICIPANT	\N	EXCUSE	0
414734	406852	04033B	PARTICIPANT	\N	PRESENT	0
414737	406852	19760E	PARTICIPANT	\N	PRESENT	0
414738	406852	19647E	PARTICIPANT	\N	PRESENT	0
414739	406852	14213J	PARTICIPANT	\N	PRESENT	0
415008	410851	19691J	PARTICIPANT	\N	PRESENT	0
415046	413425	14327T	PARTICIPANT	\N	PRESENT	0
415047	413425	14331P	PARTICIPANT	\N	PRESENT	0
415048	413425	11053K	PARTICIPANT	\N	PRESENT	0
415049	413425	89017R	PARTICIPANT	\N	PRESENT	0
415050	413425	14225N	PARTICIPANT	\N	PRESENT	0
415051	413425	88008L	PARTICIPANT	\N	PRESENT	0
415052	413425	19671E	PARTICIPANT	\N	PRESENT	0
415053	413425	07029T	PARTICIPANT	\N	PRESENT	0
415054	413425	14085U	PARTICIPANT	\N	PRESENT	0
415055	413425	07004J	PARTICIPANT	\N	PRESENT	0
415056	413425	19349W	PARTICIPANT	\N	PRESENT	0
415057	413425	19647E	PARTICIPANT	\N	PRESENT	0
415058	413425	11048N	PARTICIPANT	\N	PRESENT	0
415059	413425	19711U	PARTICIPANT	\N	PRESENT	0
415060	413425	08034U	PARTICIPANT	\N	PRESENT	0
415061	413425	19689Q	PARTICIPANT	\N	PRESENT	0
415062	413425	12016W	PARTICIPANT	\N	PRESENT	0
415063	413425	08011M	PARTICIPANT	\N	PRESENT	0
415064	413425	08014Q	PARTICIPANT	\N	PRESENT	0
415065	413425	14034U	PARTICIPANT	\N	PRESENT	0
415066	413425	14173T	PARTICIPANT	\N	PRESENT	0
415067	413425	11040E	PARTICIPANT	\N	PRESENT	0
415068	413425	14083S	PARTICIPANT	\N	PRESENT	0
415069	413425	14121F	PARTICIPANT	\N	PRESENT	0
415070	413425	19741B	PARTICIPANT	\N	PRESENT	0
415071	413425	99004R	PARTICIPANT	\N	PRESENT	0
415074	413425	01057W	PARTICIPANT	\N	EXCUSE	0
415075	413425	14159V	PARTICIPANT	\N	EXCUSE	0
415076	413425	11074Q	PRESIDENT	0	PRESENT	0
415077	413425	19687N	PARTICIPANT	\N	PRESENT	0
415078	413425	14199E	PARTICIPANT	\N	PRESENT	0
415079	413425	08010L	PARTICIPANT	\N	PRESENT	0
415080	413425	08069G	PARTICIPANT	\N	PRESENT	0
415081	413425	11110B	PARTICIPANT	\N	PRESENT	0
415082	413425	19479G	PARTICIPANT	\N	PRESENT	0
415083	413425	19651A	PARTICIPANT	\N	PRESENT	0
415089	414444	04059M	PARTICIPANT	\N	PRESENT	0
415096	413425	11012A	PARTICIPANT	\N	PRESENT	0
415097	413425	19545Y	PARTICIPANT	\N	PRESENT	0
415104	414444	08035V	PARTICIPANT	\N	PRESENT	0
415223	413451	08012N	PARTICIPANT	\N	PRESENT	0
415224	413451	11104D	PARTICIPANT	\N	PRESENT	0
415252	415251	14042U	PARTICIPANT	\N	PRESENT	0
415253	406854	19651A	PARTICIPANT	\N	PRESENT	0
415254	406854	19543W	PARTICIPANT	\N	PRESENT	0
415255	406854	98022P	PARTICIPANT	\N	PRESENT	0
415256	406854	80013X	PARTICIPANT	\N	PRESENT	0
415257	406854	14227Q	PARTICIPANT	\N	PRESENT	0
415258	406854	19563B	PARTICIPANT	\N	PRESENT	0
415259	406854	19826F	PARTICIPANT	\N	PRESENT	0
415260	406854	11041F	PARTICIPANT	\N	PRESENT	0
415261	406854	19443T	PARTICIPANT	\N	PRESENT	0
415262	406854	14237S	PARTICIPANT	\N	PRESENT	0
415263	406854	19762G	PARTICIPANT	\N	PRESENT	0
415264	406854	04097T	PARTICIPANT	\N	PRESENT	0
415265	406854	14191V	PARTICIPANT	\N	PRESENT	0
415266	406854	04089T	PARTICIPANT	\N	PRESENT	0
415267	406854	96004D	PARTICIPANT	\N	PRESENT	0
415268	406854	14267Y	PARTICIPANT	\N	PRESENT	0
415269	406854	01025N	PARTICIPANT	\N	PRESENT	0
415270	406854	19333N	PARTICIPANT	\N	PRESENT	0
415271	406854	19703U	PARTICIPANT	\N	PRESENT	0
415272	406854	11056N	PARTICIPANT	\N	PRESENT	0
415273	406854	04049K	PARTICIPANT	\N	PRESENT	0
415274	406854	14223L	PARTICIPANT	\N	PRESENT	0
415275	406854	14073Q	PARTICIPANT	\N	PRESENT	0
415276	406854	04092N	PARTICIPANT	\N	PRESENT	0
415277	406854	14121F	PARTICIPANT	\N	PRESENT	0
415278	406854	14133K	PARTICIPANT	\N	PRESENT	0
415279	406854	15447F	PARTICIPANT	\N	PRESENT	0
415280	406854	14229S	PARTICIPANT	\N	PRESENT	0
415281	406854	14115H	PARTICIPANT	\N	PRESENT	0
415282	406854	19812Y	PARTICIPANT	\N	PRESENT	0
415283	406854	08028W	PARTICIPANT	\N	PRESENT	0
415284	406854	98029W	PARTICIPANT	\N	PRESENT	0
415285	406854	08043V	PARTICIPANT	\N	PRESENT	0
415286	406854	98035U	PARTICIPANT	\N	PRESENT	0
415287	406854	19719D	PARTICIPANT	\N	PRESENT	0
415288	406854	19387D	PARTICIPANT	\N	PRESENT	0
415289	406854	14261S	PARTICIPANT	\N	PRESENT	0
415290	406854	08055A	PARTICIPANT	\N	PRESENT	0
415291	406854	19253P	PARTICIPANT	\N	PRESENT	0
421480	421479	07004J	PARTICIPANT	\N	PRESENT	0
421660	414078	19693L	PARTICIPANT	\N	EXCUSE	0
421661	414078	08053X	PARTICIPANT	\N	EXCUSE	0
422747	422687	19533U	PARTICIPANT	\N	PRESENT	0
421663	414078	04043D	PARTICIPANT	\N	PRESENT	0
422701	422687	19593H	PARTICIPANT	\N	PRESENT	0
422702	422687	04070G	PRESIDENT	0	PRESENT	0
422703	422687	19699S	PARTICIPANT	\N	PRESENT	0
422704	422687	04057K	PARTICIPANT	\N	PRESENT	0
422705	422687	19611R	PARTICIPANT	\N	PRESENT	0
422706	422687	19399H	PARTICIPANT	\N	PRESENT	0
422707	422687	14030Q	PARTICIPANT	\N	PRESENT	0
422708	422687	14241N	PARTICIPANT	\N	PRESENT	0
422709	422687	19731Y	PARTICIPANT	\N	PRESENT	0
422710	422687	04059M	PARTICIPANT	\N	PRESENT	0
422711	422687	92040Q	PARTICIPANT	\N	PRESENT	0
422712	422687	14063N	PARTICIPANT	\N	PRESENT	0
422713	422687	99004R	PARTICIPANT	\N	PRESENT	0
422714	422687	19335Q	PARTICIPANT	\N	PRESENT	0
422715	422687	19749K	PARTICIPANT	\N	PRESENT	0
422716	422687	04018C	PARTICIPANT	\N	PRESENT	0
422717	422687	19758L	PARTICIPANT	\N	PRESENT	0
422718	422687	08039A	PRESIDENT	1	PRESENT	0
422719	422687	08031R	PARTICIPANT	\N	PRESENT	0
422720	422687	14061L	PARTICIPANT	\N	EXCUSE	0
422721	422687	14107H	PARTICIPANT	\N	EXCUSE	0
422722	422687	19693L	PARTICIPANT	\N	EXCUSE	0
422748	422687	19651A	PARTICIPANT	\N	PRESENT	0
422749	422687	19573D	PARTICIPANT	\N	PRESENT	0
422750	422687	19735D	PARTICIPANT	\N	PRESENT	0
423340	416296	19820Y	PARTICIPANT	\N	PRESENT	0
423334	416296	80013X	PARTICIPANT	\N	PRESENT	0
423335	416296	12016W	PARTICIPANT	\N	PRESENT	0
423336	416296	04085P	PARTICIPANT	\N	PRESENT	0
423337	416296	19551W	PARTICIPANT	\N	PRESENT	0
423338	416296	14197C	PARTICIPANT	\N	PRESENT	0
423339	416296	14223L	PARTICIPANT	\N	PRESENT	0
423382	416296	08015R	PARTICIPANT	\N	PRESENT	0
423342	416296	04018C	PARTICIPANT	\N	PRESENT	0
423343	416296	14215L	PARTICIPANT	\N	PRESENT	0
423344	416296	19762G	PARTICIPANT	\N	PRESENT	0
423345	416296	19717B	PARTICIPANT	\N	PRESENT	0
423346	416296	15447F	PARTICIPANT	\N	PRESENT	0
423347	416296	19725B	PARTICIPANT	\N	PRESENT	0
423348	416296	98022P	PARTICIPANT	\N	PRESENT	0
423349	416296	19703U	PARTICIPANT	\N	PRESENT	0
423350	416296	14241N	PARTICIPANT	\N	PRESENT	0
423351	416296	14041T	PARTICIPANT	\N	PRESENT	0
423352	416296	19681G	PARTICIPANT	\N	PRESENT	0
423353	416296	14219Q	PARTICIPANT	\N	PRESENT	0
423354	416296	14030Q	PARTICIPANT	\N	PRESENT	0
423355	416296	01024M	PARTICIPANT	\N	PRESENT	0
423356	416296	14257W	PARTICIPANT	\N	PRESENT	0
423357	416296	19739H	PARTICIPANT	\N	PRESENT	0
423358	416296	19737F	PARTICIPANT	\N	PRESENT	0
423359	416296	19826F	PARTICIPANT	\N	PRESENT	0
423360	416296	19253P	PARTICIPANT	\N	PRESENT	0
423379	416296	14147R	PARTICIPANT	\N	PRESENT	0
423362	416296	14231L	PARTICIPANT	\N	PRESENT	0
423363	416296	14265W	PARTICIPANT	\N	PRESENT	0
423364	416296	14061L	PARTICIPANT	\N	PRESENT	0
423365	416296	97011G	PARTICIPANT	\N	PRESENT	0
423366	416296	95030B	PARTICIPANT	\N	PRESENT	0
423367	416296	08062Y	PARTICIPANT	\N	PRESENT	0
423368	416296	19731Y	PARTICIPANT	\N	PRESENT	0
423369	416296	04043D	PARTICIPANT	\N	PRESENT	0
423370	416296	14071N	PARTICIPANT	\N	PRESENT	0
423371	416296	14261S	PARTICIPANT	\N	PRESENT	0
423372	416296	19467C	PARTICIPANT	\N	PRESENT	0
423373	416296	19301E	PARTICIPANT	\N	PRESENT	0
423374	416296	19443T	PARTICIPANT	\N	PRESENT	0
423375	416296	19723Y	PARTICIPANT	\N	PRESENT	0
423376	416296	19794Q	PARTICIPANT	\N	PRESENT	0
423377	416296	14059S	PARTICIPANT	\N	PRESENT	0
423378	416296	14026U	PARTICIPANT	\N	PRESENT	0
423380	416296	14157T	PARTICIPANT	\N	PRESENT	0
423381	416296	14249W	PARTICIPANT	\N	PRESENT	0
423383	416296	04088S	PARTICIPANT	\N	PRESENT	0
423384	416296	08068F	PARTICIPANT	\N	PRESENT	0
423385	416296	19760E	PARTICIPANT	\N	PRESENT	0
423386	416296	14053L	PARTICIPANT	\N	PRESENT	0
423387	416296	14237S	PARTICIPANT	\N	PRESENT	0
423388	416296	19563B	PARTICIPANT	\N	PRESENT	0
423389	416296	19631V	PARTICIPANT	\N	PRESENT	0
423390	416296	19387D	PARTICIPANT	\N	PRESENT	0
423391	416296	19629C	PARTICIPANT	\N	PRESENT	0
423392	416296	19691J	PARTICIPANT	\N	PRESENT	0
423393	416296	11077T	PARTICIPANT	\N	PRESENT	0
423394	416296	14031R	PARTICIPANT	\N	PRESENT	0
423395	416296	19599P	PARTICIPANT	\N	PRESENT	0
423396	423007	05008E	PARTICIPANT	\N	EXCUSE	0
423397	423007	11072N	PARTICIPANT	\N	EXCUSE	0
423398	416296	11097X	PARTICIPANT	\N	PRESENT	0
423399	416296	19251M	PARTICIPANT	\N	PRESENT	0
423400	416296	14033T	PARTICIPANT	\N	PRESENT	0
423401	416296	14111D	PARTICIPANT	\N	PRESENT	0
423402	416296	11012A	PARTICIPANT	\N	PRESENT	0
423403	416296	14121F	PARTICIPANT	\N	PRESENT	0
423404	416296	14069U	PARTICIPANT	\N	PRESENT	0
423409	423408	14229S	PARTICIPANT	\N	PRESENT	0
423463	423462	14229S	PARTICIPANT	\N	PRESENT	0
423464	423462	08043V	PARTICIPANT	\N	PRESENT	0
423466	423465	14229S	PARTICIPANT	\N	PRESENT	0
423468	423465	08043V	PARTICIPANT	\N	PRESENT	0
423597	423596	14051J	PARTICIPANT	\N	PRESENT	0
423599	423598	14051J	PARTICIPANT	\N	PRESENT	0
423601	423600	14051J	PARTICIPANT	\N	PRESENT	0
423602	423600	04059M	PARTICIPANT	\N	PRESENT	0
423604	423603	14051J	PARTICIPANT	\N	PRESENT	0
423612	423610	14109K	PARTICIPANT	\N	PRESENT	0
423607	423605	04059M	PARTICIPANT	\N	PRESENT	0
423608	423605	12041X	PARTICIPANT	\N	PRESENT	0
423609	423605	14051J	PARTICIPANT	\N	PRESENT	0
423611	423610	14051J	PARTICIPANT	\N	PRESENT	0
423613	423610	14026U	PARTICIPANT	\N	PRESENT	0
423615	423614	14051J	PARTICIPANT	\N	PRESENT	0
423617	423616	14001X	PARTICIPANT	\N	PRESENT	0
423627	422488	14327T	PARTICIPANT	\N	PRESENT	0
423628	422488	14331P	PARTICIPANT	\N	PRESENT	0
423629	422488	95041E	PARTICIPANT	\N	PRESENT	0
423630	422488	01048V	PARTICIPANT	\N	PRESENT	0
423631	422488	19545Y	PARTICIPANT	\N	PRESENT	0
423632	422488	01057W	PARTICIPANT	\N	PRESENT	0
423633	422488	19667J	PARTICIPANT	\N	PRESENT	0
423634	422488	11074Q	PRESIDENT	0	PRESENT	0
423635	422488	89017R	PARTICIPANT	\N	PRESENT	0
423636	422488	19671E	PARTICIPANT	\N	PRESENT	0
423637	422488	11070L	PARTICIPANT	\N	PRESENT	0
423638	422488	88008L	PARTICIPANT	\N	PRESENT	0
423639	422488	07029T	PARTICIPANT	\N	PRESENT	0
423640	422488	14085U	PARTICIPANT	\N	PRESENT	0
423641	422488	07004J	PARTICIPANT	\N	PRESENT	0
423642	422488	96004D	PARTICIPANT	\N	PRESENT	0
423643	422488	19349W	PARTICIPANT	\N	PRESENT	0
423331	416296	11070L	PARTICIPANT	\N	PRESENT	0
423332	416296	01028R	PARTICIPANT	\N	PRESENT	0
423644	422488	14253S	PARTICIPANT	\N	PRESENT	0
423645	422488	19647E	PARTICIPANT	\N	PRESENT	0
423646	422488	19479G	PARTICIPANT	\N	PRESENT	0
423647	422488	19711U	PRESIDENT	1	PRESENT	0
423648	422488	19531S	PARTICIPANT	\N	PRESENT	0
423649	422488	08069G	PARTICIPANT	\N	PRESENT	0
423650	422488	19687N	PARTICIPANT	\N	PRESENT	0
423651	422488	19689Q	PARTICIPANT	\N	PRESENT	0
423652	422488	08011M	PARTICIPANT	\N	PRESENT	0
423653	422488	08014Q	PARTICIPANT	\N	PRESENT	0
423654	422488	14159V	PARTICIPANT	\N	PRESENT	0
423655	422488	14173T	PARTICIPANT	\N	PRESENT	0
423656	422488	14199E	PARTICIPANT	\N	PRESENT	0
423657	422488	11012A	PARTICIPANT	\N	PRESENT	0
423658	422488	99004R	PARTICIPANT	\N	PRESENT	0
423659	422488	19651A	PARTICIPANT	\N	PRESENT	0
423660	422488	14121F	PARTICIPANT	\N	PRESENT	0
423661	422488	19741B	PARTICIPANT	\N	PRESENT	0
423662	422488	08034U	PARTICIPANT	\N	PRESENT	0
423663	422452	19697Q	PARTICIPANT	\N	PRESENT	0
423664	422452	11067R	PARTICIPANT	\N	PRESENT	0
423665	422452	19798U	PARTICIPANT	\N	PRESENT	0
423666	422452	19569H	PARTICIPANT	\N	PRESENT	0
423667	422452	11097X	PARTICIPANT	\N	PRESENT	0
423668	422452	19415P	PARTICIPANT	\N	PRESENT	0
423669	422452	14223L	PARTICIPANT	\N	PRESENT	0
423670	422452	04045F	PARTICIPANT	\N	PRESENT	0
423671	422452	14026U	PARTICIPANT	\N	PRESENT	0
423672	422452	17779H	PARTICIPANT	\N	PRESENT	0
423673	422452	14239U	PARTICIPANT	\N	PRESENT	0
423674	422452	19553Y	PARTICIPANT	\N	PRESENT	0
423675	422452	19703U	PARTICIPANT	\N	PRESENT	0
423676	422452	14281W	PARTICIPANT	\N	PRESENT	0
401536	393615	19269X	PARTICIPANT	\N	PRESENT	0
401537	393615	19563B	PARTICIPANT	\N	PRESENT	0
401538	393615	19737F	PARTICIPANT	\N	PRESENT	0
401539	393615	04047H	PARTICIPANT	\N	PRESENT	0
401540	393615	14213J	PARTICIPANT	\N	PRESENT	0
401541	393615	14069U	PARTICIPANT	\N	PRESENT	0
401542	393615	14083S	PARTICIPANT	\N	PRESENT	0
401564	401563	11053K	PARTICIPANT	\N	PRESENT	0
401565	401563	19253P	PARTICIPANT	\N	PRESENT	0
401595	401594	11053K	PARTICIPANT	\N	PRESENT	0
401596	401594	19253P	PARTICIPANT	\N	PRESENT	0
401597	401594	19671E	PARTICIPANT	\N	PRESENT	0
401599	401598	11053K	PARTICIPANT	\N	PRESENT	0
401600	401598	19253P	PARTICIPANT	\N	PRESENT	0
401610	401609	11053K	PARTICIPANT	\N	PRESENT	0
401534	393615	14217N	PARTICIPANT	\N	PRESENT	0
401535	393615	11097X	PARTICIPANT	\N	PRESENT	0
401611	401609	19253P	PARTICIPANT	\N	PRESENT	0
401613	401612	19253P	PARTICIPANT	\N	PRESENT	0
401620	401619	19253P	PARTICIPANT	\N	PRESENT	0
401737	400276	11081P	PARTICIPANT	\N	EXCUSE	0
401743	400276	19295A	PARTICIPANT	\N	EXCUSE	0
401744	400276	19812Y	PARTICIPANT	\N	EXCUSE	0
403015	403014	14031R	PARTICIPANT	\N	PRESENT	0
403016	403014	14030Q	PARTICIPANT	\N	PRESENT	0
403017	403014	14281W	PARTICIPANT	\N	PRESENT	0
403018	403014	17583W	PARTICIPANT	\N	PRESENT	0
403019	403014	14275Y	PARTICIPANT	\N	PRESENT	0
403020	403014	04044E	PARTICIPANT	\N	PRESENT	0
403021	403014	14157T	PARTICIPANT	\N	PRESENT	0
403022	403014	11066Q	PARTICIPANT	\N	PRESENT	0
403024	403023	10015M	PARTICIPANT	\N	PRESENT	0
404559	404558	19701S	PARTICIPANT	\N	PRESENT	0
404560	404558	19794Q	PARTICIPANT	\N	PRESENT	0
404562	404561	07004J	PARTICIPANT	\N	PRESENT	0
404564	404563	19701S	PARTICIPANT	\N	PRESENT	0
404565	404563	11085T	PARTICIPANT	\N	PRESENT	0
404567	404566	19701S	PARTICIPANT	\N	PRESENT	0
404569	404568	19701S	PARTICIPANT	\N	PRESENT	0
404571	404570	14083S	PARTICIPANT	\N	PRESENT	0
404572	404570	19701S	PARTICIPANT	\N	PRESENT	0
404575	404573	19701S	PARTICIPANT	\N	PRESENT	0
404577	404576	14083S	PARTICIPANT	\N	PRESENT	0
404578	404576	14205J	PARTICIPANT	\N	PRESENT	0
404579	404576	19701S	PARTICIPANT	\N	PRESENT	0
404580	404574	19794Q	PARTICIPANT	\N	PRESENT	0
404581	404574	14205J	PARTICIPANT	\N	PRESENT	0
404582	404574	19701S	PARTICIPANT	\N	PRESENT	0
404584	404583	19701S	PARTICIPANT	\N	PRESENT	0
404585	404583	19794Q	PARTICIPANT	\N	PRESENT	0
404587	404586	19631V	PARTICIPANT	\N	PRESENT	0
404588	404586	19733B	PARTICIPANT	\N	PRESENT	0
404589	404586	19782L	PARTICIPANT	\N	PRESENT	0
404590	404586	14357A	PARTICIPANT	\N	PRESENT	0
404591	404586	11065P	PARTICIPANT	\N	PRESENT	0
404602	404601	08031R	PARTICIPANT	\N	PRESENT	0
404603	404601	08043V	PARTICIPANT	\N	PRESENT	0
404594	404586	14033T	PARTICIPANT	\N	PRESENT	0
405344	405343	04040A	PARTICIPANT	\N	PRESENT	0
405345	405343	14257W	PARTICIPANT	\N	PRESENT	0
404597	404586	14219Q	PARTICIPANT	\N	PRESENT	0
404598	404586	19369B	PARTICIPANT	\N	PRESENT	0
404599	404586	19503N	PARTICIPANT	\N	PRESENT	0
404600	404586	11090Q	PRESIDENT	0	PRESENT	0
405346	405343	08049C	PARTICIPANT	\N	PRESENT	0
406958	405335	19733B	PARTICIPANT	\N	PRESENT	0
406959	405335	14029X	PARTICIPANT	\N	PRESENT	0
406960	405336	19549D	PARTICIPANT	\N	PRESENT	0
406961	405336	19737F	PARTICIPANT	\N	PRESENT	0
407577	405393	08038Y	PARTICIPANT	\N	EXCUSE	0
407574	405393	11081P	PARTICIPANT	\N	EXCUSE	0
407575	405393	01025N	PARTICIPANT	\N	EXCUSE	0
407576	405393	19369B	PARTICIPANT	\N	EXCUSE	0
407578	405393	17589D	PARTICIPANT	\N	EXCUSE	0
407579	405393	08028W	PARTICIPANT	\N	EXCUSE	0
407580	405393	19782L	PARTICIPANT	\N	EXCUSE	0
407581	405393	19812Y	PARTICIPANT	\N	EXCUSE	0
407582	405393	14205J	PARTICIPANT	\N	EXCUSE	0
407583	405392	11081P	PARTICIPANT	\N	EXCUSE	0
407584	405392	01025N	PARTICIPANT	\N	EXCUSE	0
407585	405392	19369B	PARTICIPANT	\N	EXCUSE	0
407586	405392	08038Y	PARTICIPANT	\N	EXCUSE	0
407587	405392	17589D	PARTICIPANT	\N	EXCUSE	0
407588	405392	19782L	PARTICIPANT	\N	EXCUSE	0
407589	405392	08028W	PARTICIPANT	\N	EXCUSE	0
407590	405392	19812Y	PARTICIPANT	\N	EXCUSE	0
407591	405392	14205J	PARTICIPANT	\N	EXCUSE	0
407599	405449	14028W	PARTICIPANT	\N	EXCUSE	0
407600	405449	19735D	PARTICIPANT	\N	EXCUSE	0
407838	405449	14071N	PARTICIPANT	\N	EXCUSE	0
407849	405448	14259Y	PARTICIPANT	\N	EXCUSE	0
407850	405448	14225N	PARTICIPANT	\N	EXCUSE	0
407851	405448	14059S	PARTICIPANT	\N	EXCUSE	0
407852	405448	14331P	PARTICIPANT	\N	EXCUSE	0
407853	405448	96004D	PARTICIPANT	\N	EXCUSE	0
407857	407856	19479G	PARTICIPANT	\N	PRESENT	0
408076	408075	14069U	PARTICIPANT	\N	PRESENT	0
408079	408078	14041T	PARTICIPANT	\N	PRESENT	0
408081	408080	14041T	PARTICIPANT	\N	PRESENT	0
408083	408082	14041T	PARTICIPANT	\N	PRESENT	0
408085	408084	14041T	PARTICIPANT	\N	PRESENT	0
408107	408106	89017R	PARTICIPANT	\N	PRESENT	0
408108	408106	04085P	PARTICIPANT	\N	PRESENT	0
408109	408106	04059M	PARTICIPANT	\N	PRESENT	0
408110	408106	05008E	PARTICIPANT	\N	PRESENT	0
408111	408106	96004D	PARTICIPANT	\N	PRESENT	0
408112	408106	04042C	PARTICIPANT	\N	PRESENT	0
408113	408106	11053K	PARTICIPANT	\N	PRESENT	0
408114	408106	11027H	PARTICIPANT	\N	PRESENT	0
408115	408106	04086Q	PARTICIPANT	\N	PRESENT	0
408116	408106	14079W	PARTICIPANT	\N	PRESENT	0
408117	408106	11070L	PARTICIPANT	\N	PRESENT	0
408118	408106	14034U	PARTICIPANT	\N	PRESENT	0
408119	408106	14021P	PARTICIPANT	\N	PRESENT	0
408120	408106	19711U	PARTICIPANT	\N	PRESENT	0
408121	408106	01043Q	PARTICIPANT	\N	PRESENT	0
408122	408106	14251Q	PARTICIPANT	\N	PRESENT	0
408123	408106	11085T	PARTICIPANT	\N	PRESENT	0
408124	408106	08009T	PARTICIPANT	\N	PRESENT	0
408125	408106	04092N	PARTICIPANT	\N	PRESENT	0
408126	408106	04070G	PARTICIPANT	\N	PRESENT	0
408127	408106	11090Q	PARTICIPANT	\N	PRESENT	0
408128	408106	11012A	PARTICIPANT	\N	PRESENT	0
408129	408106	04033B	PARTICIPANT	\N	PRESENT	0
408130	408106	95063L	PARTICIPANT	\N	PRESENT	0
408131	408106	04044E	PARTICIPANT	\N	PRESENT	0
408752	405449	14327T	PARTICIPANT	\N	EXCUSE	0
408816	408815	14053L	PARTICIPANT	\N	PRESENT	0
408817	408815	14111D	PARTICIPANT	\N	PRESENT	0
408818	408815	10015M	PARTICIPANT	\N	PRESENT	0
408819	408815	19543W	PARTICIPANT	\N	PRESENT	0
408820	408815	04038G	PARTICIPANT	\N	PRESENT	0
408821	408815	19673G	PARTICIPANT	\N	PRESENT	0
408822	408815	01028R	PARTICIPANT	\N	PRESENT	0
408823	408815	14231L	PARTICIPANT	\N	PRESENT	0
408824	408815	05008E	PRESIDENT	0	PRESENT	0
408825	408815	95063L	PARTICIPANT	\N	PRESENT	0
408826	408815	19629C	PARTICIPANT	\N	PRESENT	0
408827	408815	14179A	PARTICIPANT	\N	PRESENT	0
408828	408815	14259Y	PARTICIPANT	\N	PRESENT	0
408830	408829	19593H	PARTICIPANT	\N	PRESENT	0
408831	408829	19766L	PARTICIPANT	\N	PRESENT	0
408832	408829	04070G	PRESIDENT	0	PRESENT	0
408833	408829	14073Q	PARTICIPANT	\N	PRESENT	0
408834	408829	87003B	PARTICIPANT	\N	PRESENT	0
408835	408829	19399H	PARTICIPANT	\N	PRESENT	0
408836	408829	14030Q	PARTICIPANT	\N	PRESENT	0
408837	408829	14241N	PARTICIPANT	\N	PRESENT	0
408838	408829	19731Y	PARTICIPANT	\N	PRESENT	0
408839	408829	19573D	PARTICIPANT	\N	PRESENT	0
408840	408829	14039A	PARTICIPANT	\N	PRESENT	0
408841	408829	14107H	PARTICIPANT	\N	PRESENT	0
408842	408829	14063N	PARTICIPANT	\N	PRESENT	0
408843	408829	08012N	PARTICIPANT	\N	PRESENT	0
408844	408829	11104D	PARTICIPANT	\N	PRESENT	0
408845	408829	19335Q	PARTICIPANT	\N	PRESENT	0
408846	408829	11043H	PARTICIPANT	\N	PRESENT	0
408847	408829	04018C	PARTICIPANT	\N	PRESENT	0
408848	408829	19758L	PARTICIPANT	\N	PRESENT	0
412092	406844	19762G	PARTICIPANT	\N	PRESENT	0
412093	406844	11045K	PARTICIPANT	\N	PRESENT	0
412094	406844	04018C	PARTICIPANT	\N	PRESENT	0
412095	406844	11054L	PARTICIPANT	\N	PRESENT	0
412096	406844	14028W	PARTICIPANT	\N	PRESENT	0
412097	406844	80013X	PARTICIPANT	\N	PRESENT	0
412098	406844	08038Y	PARTICIPANT	\N	PRESENT	0
412099	406844	14173T	PARTICIPANT	\N	PRESENT	0
412100	406844	08060W	PARTICIPANT	\N	PRESENT	0
412101	406844	19447X	PARTICIPANT	\N	PRESENT	0
412102	406844	19820Y	PARTICIPANT	\N	PRESENT	0
412103	406844	19573D	PARTICIPANT	\N	PRESENT	0
412104	406844	11066Q	PARTICIPANT	\N	PRESENT	0
412105	406844	19794Q	PARTICIPANT	\N	PRESENT	0
412106	406844	19527W	PARTICIPANT	\N	PRESENT	0
412107	406844	14133K	PARTICIPANT	\N	PRESENT	0
412108	406844	08043V	PARTICIPANT	\N	PRESENT	0
412109	406844	92040Q	PARTICIPANT	\N	PRESENT	0
412110	406844	19525U	PARTICIPANT	\N	PRESENT	0
412111	406844	14119M	PARTICIPANT	\N	PRESENT	0
412112	406844	01062T	PARTICIPANT	\N	PRESENT	0
412113	406844	14115H	PARTICIPANT	\N	PRESENT	0
412114	406844	14081Q	PARTICIPANT	\N	PRESENT	0
412115	406844	08047A	PARTICIPANT	\N	PRESENT	0
412116	406844	14257W	PARTICIPANT	\N	PRESENT	0
412117	406844	97011G	PARTICIPANT	\N	PRESENT	0
412118	406844	19549D	PARTICIPANT	\N	PRESENT	0
412119	406844	19333N	PARTICIPANT	\N	PRESENT	0
412120	406844	14105F	PARTICIPANT	\N	PRESENT	0
412121	406844	19725B	PARTICIPANT	\N	PRESENT	0
412122	406844	08014Q	PARTICIPANT	\N	PRESENT	0
412123	406844	11103C	PARTICIPANT	\N	PRESENT	0
412124	406844	14001X	PARTICIPANT	\N	PRESENT	0
412125	406844	14063N	PARTICIPANT	\N	PRESENT	0
412126	406844	07033P	PARTICIPANT	\N	PRESENT	0
412127	406844	19489J	PARTICIPANT	\N	PRESENT	0
412128	406844	14217N	PARTICIPANT	\N	PRESENT	0
412129	406844	19631V	PARTICIPANT	\N	PRESENT	0
412130	406844	14281W	PARTICIPANT	\N	PRESENT	0
412131	406844	04069P	PARTICIPANT	\N	PRESENT	0
412132	406844	14331P	PARTICIPANT	\N	PRESENT	0
412133	406844	14109K	PARTICIPANT	\N	PRESENT	0
412134	406844	19367Y	PARTICIPANT	\N	PRESENT	0
412135	406844	11072N	PARTICIPANT	\N	PRESENT	0
412136	406844	19329S	PARTICIPANT	\N	PRESENT	0
412137	406844	19551W	PARTICIPANT	\N	PRESENT	0
412138	406844	19671E	PARTICIPANT	\N	PRESENT	0
412139	406844	11067R	PARTICIPANT	\N	PRESENT	0
412140	406844	19503N	PARTICIPANT	\N	PRESENT	0
412141	406844	19701S	PARTICIPANT	\N	PRESENT	0
412142	406844	19591F	PARTICIPANT	\N	PRESENT	0
412143	406844	19703U	PARTICIPANT	\N	PRESENT	0
412144	406844	19413M	PARTICIPANT	\N	PRESENT	0
412145	406844	19673G	PARTICIPANT	\N	PRESENT	0
412146	406844	11010L	PARTICIPANT	\N	PRESENT	0
412147	406844	19295A	PARTICIPANT	\N	PRESENT	0
412148	406844	11109J	PARTICIPANT	\N	PRESENT	0
412149	406844	14251Q	PARTICIPANT	\N	PRESENT	0
412150	406844	19733B	PARTICIPANT	\N	PRESENT	0
412151	406844	19683J	PARTICIPANT	\N	PRESENT	0
412152	406844	14031R	PARTICIPANT	\N	PRESENT	0
412153	406844	14227Q	PARTICIPANT	\N	PRESENT	0
412154	406844	14085U	PARTICIPANT	\N	PRESENT	0
412155	406844	11115U	PARTICIPANT	\N	PRESENT	0
412156	406844	14065Q	PARTICIPANT	\N	PRESENT	0
412157	406844	19667J	PARTICIPANT	\N	PRESENT	0
412158	406844	08058D	PARTICIPANT	\N	PRESENT	0
412159	406844	14199E	PARTICIPANT	\N	PRESENT	0
412160	406844	17779H	PARTICIPANT	\N	PRESENT	0
412161	406844	19575F	PARTICIPANT	\N	PRESENT	0
412162	406844	14253S	PARTICIPANT	\N	PRESENT	0
412163	406844	19723Y	PARTICIPANT	\N	PRESENT	0
412164	406844	11048N	PARTICIPANT	\N	PRESENT	0
412165	406844	19251M	PARTICIPANT	\N	PRESENT	0
412166	406844	04049K	PARTICIPANT	\N	PRESENT	0
412167	406844	05012A	PARTICIPANT	\N	PRESENT	0
412168	406844	19695N	PARTICIPANT	\N	PRESENT	0
412169	406844	08034U	PARTICIPANT	\N	PRESENT	0
412170	406844	19533U	PARTICIPANT	\N	PRESENT	0
412171	406844	04038G	PARTICIPANT	\N	PRESENT	0
412172	406844	19798U	PARTICIPANT	\N	PRESENT	0
412173	406844	14193X	PARTICIPANT	\N	PRESENT	0
412174	406844	19515S	PARTICIPANT	\N	PRESENT	0
412175	406844	14191V	PARTICIPANT	\N	PRESENT	0
412176	406844	11080N	PARTICIPANT	\N	PRESENT	0
412177	406844	14259Y	PARTICIPANT	\N	PRESENT	0
412178	406844	19727D	PARTICIPANT	\N	PRESENT	0
412179	406844	01057W	PARTICIPANT	\N	PRESENT	0
412180	406844	87003B	PARTICIPANT	\N	PRESENT	0
412181	406844	14231L	PARTICIPANT	\N	PRESENT	0
412182	406844	04043D	PARTICIPANT	\N	PRESENT	0
412183	406844	08044W	PARTICIPANT	\N	PRESENT	0
412184	406844	14179A	PARTICIPANT	\N	PRESENT	0
412185	406844	14249W	PARTICIPANT	\N	PRESENT	0
412186	406844	19691J	PARTICIPANT	\N	PRESENT	0
412187	406844	14053L	PARTICIPANT	\N	PRESENT	0
412188	406844	19369B	PARTICIPANT	\N	PRESENT	0
412189	406844	14215L	PARTICIPANT	\N	PRESENT	0
412190	406844	01034P	PARTICIPANT	\N	PRESENT	0
412191	406844	11053K	PARTICIPANT	\N	PRESENT	0
412192	406844	14205J	PARTICIPANT	\N	PRESENT	0
412193	406844	14219Q	PARTICIPANT	\N	PRESENT	0
412194	406844	19611R	PARTICIPANT	\N	PRESENT	0
412195	406844	19511N	PARTICIPANT	\N	PRESENT	0
412196	406844	10015M	PARTICIPANT	\N	PRESENT	0
412197	406844	04040A	PARTICIPANT	\N	PRESENT	0
412198	406844	01048V	PARTICIPANT	\N	PRESENT	0
412199	406844	19619A	PARTICIPANT	\N	PRESENT	0
412200	406844	19721W	PARTICIPANT	\N	PRESENT	0
412201	406844	04033B	PARTICIPANT	\N	PRESENT	0
412202	406844	19699S	PARTICIPANT	\N	PRESENT	0
412203	406844	14187A	PARTICIPANT	\N	PRESENT	0
412204	406844	19737F	PARTICIPANT	\N	PRESENT	0
412205	406844	19569H	PARTICIPANT	\N	PRESENT	0
412206	406844	14071N	PARTICIPANT	\N	PRESENT	0
412207	406844	19739H	PARTICIPANT	\N	PRESENT	0
412208	406844	05008E	PARTICIPANT	\N	PRESENT	0
412209	406844	16685X	PARTICIPANT	\N	PRESENT	0
412210	406844	11097X	PARTICIPANT	\N	PRESENT	0
412211	406844	19421M	PARTICIPANT	\N	PRESENT	0
412212	406844	19479G	PARTICIPANT	\N	PRESENT	0
412213	406844	14042U	PARTICIPANT	\N	PRESENT	0
412214	406844	04071H	PARTICIPANT	\N	PRESENT	0
412215	406844	14255U	PARTICIPANT	\N	PRESENT	0
412216	406844	19679N	PARTICIPANT	\N	PRESENT	0
412217	406844	19441R	PARTICIPANT	\N	PRESENT	0
412218	406844	19319Q	PARTICIPANT	\N	PRESENT	0
412219	406844	19713W	PARTICIPANT	\N	PRESENT	0
412220	406844	14123H	PARTICIPANT	\N	PRESENT	0
412221	406844	14267Y	PARTICIPANT	\N	PRESENT	0
412222	406844	14221J	PARTICIPANT	\N	PRESENT	0
412223	406844	14073Q	PARTICIPANT	\N	PRESENT	0
412224	406844	08069G	PARTICIPANT	\N	PRESENT	0
412225	406844	14083S	PARTICIPANT	\N	PRESENT	0
412226	406844	19335Q	PARTICIPANT	\N	PRESENT	0
412227	406844	04042C	PARTICIPANT	\N	PRESENT	0
412228	406844	19521Q	PARTICIPANT	\N	PRESENT	0
412229	406844	04092N	PARTICIPANT	\N	PRESENT	0
412230	406844	11070L	PARTICIPANT	\N	PRESENT	0
412231	406844	04044E	PARTICIPANT	\N	PRESENT	0
412232	406844	11085T	PARTICIPANT	\N	PRESENT	0
412233	406844	95041E	PARTICIPANT	\N	PRESENT	0
412234	406844	01025N	PARTICIPANT	\N	PRESENT	0
412235	406844	19826F	PARTICIPANT	\N	PRESENT	0
412236	406844	08011M	PARTICIPANT	\N	PRESENT	0
412237	406844	01024M	PARTICIPANT	\N	PRESENT	0
412238	406844	14327T	PARTICIPANT	\N	PRESENT	0
412239	406844	14030Q	PARTICIPANT	\N	PRESENT	0
412240	406844	14026U	PARTICIPANT	\N	PRESENT	0
412241	406844	01043Q	PARTICIPANT	\N	PRESENT	0
412242	406844	95030B	PARTICIPANT	\N	PRESENT	0
412243	406844	11101A	PARTICIPANT	\N	PRESENT	0
412244	406844	04035D	PARTICIPANT	\N	PRESENT	0
412245	406844	19745F	PARTICIPANT	\N	PRESENT	0
412246	406844	14069U	PARTICIPANT	\N	PRESENT	0
412247	406844	08028W	PARTICIPANT	\N	PRESENT	0
412248	406844	08017T	PARTICIPANT	\N	PRESENT	0
412249	406844	19581D	PARTICIPANT	\N	PRESENT	0
412250	406844	10006L	PARTICIPANT	\N	PRESENT	0
412251	406844	11110B	PARTICIPANT	\N	PRESENT	0
412252	406844	14147R	PARTICIPANT	\N	PRESENT	0
412253	406844	96004D	PARTICIPANT	\N	PRESENT	0
412254	406844	11090Q	PARTICIPANT	\N	PRESENT	0
412255	406844	14079W	PARTICIPANT	\N	PRESENT	0
412256	406844	11031D	PARTICIPANT	\N	PRESENT	0
412257	406844	95063L	PARTICIPANT	\N	PRESENT	0
412258	406844	14093U	PARTICIPANT	\N	PRESENT	0
412259	406844	02002K	PARTICIPANT	\N	PRESENT	0
396230	396229	11053K	PARTICIPANT	\N	PRESENT	0
396231	396229	14159V	PARTICIPANT	\N	PRESENT	0
396232	396229	05012A	PARTICIPANT	\N	PRESENT	0
396234	396233	11053K	PARTICIPANT	\N	PRESENT	0
396235	396233	14159V	PARTICIPANT	\N	PRESENT	0
396236	396233	05012A	PARTICIPANT	\N	PRESENT	0
396248	396247	19713W	PARTICIPANT	\N	PRESENT	0
396249	396247	14029X	PARTICIPANT	\N	PRESENT	0
396250	396247	19637C	PARTICIPANT	\N	PRESENT	0
396251	396247	19681G	PARTICIPANT	\N	PRESENT	0
396252	396247	19333N	PARTICIPANT	\N	PRESENT	0
396253	396247	19525U	PARTICIPANT	\N	PRESENT	0
396254	396247	08009T	PARTICIPANT	\N	PRESENT	0
396255	396247	14038Y	PARTICIPANT	\N	PRESENT	0
396257	396256	04008A	PARTICIPANT	\N	PRESENT	0
396261	391473	14299H	PARTICIPANT	\N	EXCUSE	0
396270	391473	80013X	PARTICIPANT	\N	PRESENT	0
396271	391473	19693L	PARTICIPANT	\N	PRESENT	0
396272	391473	19709B	PARTICIPANT	\N	PRESENT	0
396273	391473	01048V	PRESIDENT	0	PRESENT	0
396274	391473	19533U	PARTICIPANT	\N	PRESENT	0
396275	391473	19503N	PARTICIPANT	\N	PRESENT	0
396276	391473	01058X	PARTICIPANT	\N	PRESENT	0
396277	391473	19723Y	PARTICIPANT	\N	EXCUSE	0
396278	391473	19553Y	PARTICIPANT	\N	EXCUSE	0
396279	391473	04043D	PARTICIPANT	\N	EXCUSE	0
398274	398273	14205J	PARTICIPANT	\N	PRESENT	0
398275	398273	08055A	PARTICIPANT	\N	PRESENT	0
398276	398273	14042U	PARTICIPANT	\N	PRESENT	0
398277	398273	14197C	PARTICIPANT	\N	PRESENT	0
398278	398273	19347U	PARTICIPANT	\N	PRESENT	0
398279	398273	19727D	PARTICIPANT	\N	PRESENT	0
398280	398273	14033T	PARTICIPANT	\N	PRESENT	0
398281	398273	19725B	PARTICIPANT	\N	PRESENT	0
398282	398273	16685X	PARTICIPANT	\N	PRESENT	0
398283	398273	14265W	PARTICIPANT	\N	PRESENT	0
398284	398273	92040Q	PARTICIPANT	\N	PRESENT	0
398285	398273	14169X	PARTICIPANT	\N	PRESENT	0
398286	398273	19745F	PARTICIPANT	\N	PRESENT	0
398287	398273	19533U	PARTICIPANT	\N	PRESENT	0
400037	400036	19347U	PARTICIPANT	\N	PRESENT	0
410016	402304	14034U	PARTICIPANT	\N	PRESENT	0
410017	402304	19669L	PARTICIPANT	\N	PRESENT	0
410018	402304	08060W	PARTICIPANT	\N	PRESENT	0
410019	402304	19591F	PARTICIPANT	\N	PRESENT	0
410020	402304	19333N	PARTICIPANT	\N	PRESENT	0
410021	402304	14039A	PARTICIPANT	\N	PRESENT	0
410022	402304	19369B	PARTICIPANT	\N	PRESENT	0
410023	402304	14267Y	PARTICIPANT	\N	PRESENT	0
410024	402304	11065P	PARTICIPANT	\N	PRESENT	0
410025	402304	99004R	PARTICIPANT	\N	PRESENT	0
410026	402304	04038G	PARTICIPANT	\N	PRESENT	0
410027	402304	19820Y	PARTICIPANT	\N	PRESENT	0
410028	402304	19387D	PARTICIPANT	\N	PRESENT	0
410029	402304	19479G	PARTICIPANT	\N	PRESENT	0
410030	402304	19758L	PARTICIPANT	\N	PRESENT	0
410031	402304	19399H	PARTICIPANT	\N	PRESENT	0
410032	402304	19467C	PARTICIPANT	\N	PRESENT	0
410033	402304	19794Q	PARTICIPANT	\N	PRESENT	0
410034	402304	18083K	PARTICIPANT	\N	PRESENT	0
410035	402304	11043H	PARTICIPANT	\N	PRESENT	0
410036	402304	19643A	PARTICIPANT	\N	PRESENT	0
410037	402304	11048N	PARTICIPANT	\N	PRESENT	0
410038	402304	19711U	PARTICIPANT	\N	PRESENT	0
410039	402304	19533U	PARTICIPANT	\N	PRESENT	0
410040	402304	04018C	PARTICIPANT	\N	PRESENT	0
410041	402304	14093U	PARTICIPANT	\N	PRESENT	0
410042	402304	14197C	PARTICIPANT	\N	PRESENT	0
410043	402304	08069G	PARTICIPANT	\N	PRESENT	0
410044	402304	01058X	PARTICIPANT	\N	PRESENT	0
410045	402304	19347U	PARTICIPANT	\N	PRESENT	0
410046	402304	11077T	PARTICIPANT	\N	PRESENT	0
410047	402304	14219Q	PARTICIPANT	\N	PRESENT	0
410048	402304	14107H	PARTICIPANT	\N	PRESENT	0
410049	402304	08031R	PARTICIPANT	\N	PRESENT	0
410050	402304	11012A	PARTICIPANT	\N	PRESENT	0
410059	402304	19768N	PARTICIPANT	\N	PRESENT	0
410066	402304	14105F	PARTICIPANT	\N	PRESENT	0
410067	402304	14265W	PARTICIPANT	\N	PRESENT	0
410068	402304	19725B	PARTICIPANT	\N	PRESENT	0
410069	402304	14121F	PARTICIPANT	\N	PRESENT	0
410070	402304	11099A	PARTICIPANT	\N	PRESENT	0
410071	402304	19747H	PARTICIPANT	\N	PRESENT	0
410072	402304	19745F	PARTICIPANT	\N	PRESENT	0
410073	402304	14069U	PARTICIPANT	\N	PRESENT	0
410074	402304	08056B	PARTICIPANT	\N	PRESENT	0
411699	411696	14123H	PARTICIPANT	\N	PRESENT	0
411700	411696	08031R	PARTICIPANT	\N	PRESENT	0
411701	411696	19593H	PARTICIPANT	\N	PRESENT	0
411702	411696	19533U	PARTICIPANT	\N	PRESENT	0
411703	411696	14229S	PARTICIPANT	\N	PRESENT	0
411748	411747	08039A	PARTICIPANT	\N	PRESENT	0
414031	408325	01028R	PARTICIPANT	\N	EXCUSE	0
414033	408325	19399H	PARTICIPANT	\N	PRESENT	0
414035	408325	08024S	PARTICIPANT	\N	PRESENT	0
414036	408325	08045X	PARTICIPANT	\N	PRESENT	0
414040	414039	14073Q	PARTICIPANT	\N	PRESENT	0
414041	414039	14063N	PARTICIPANT	\N	PRESENT	0
414043	414042	19533U	PARTICIPANT	\N	PRESENT	0
414044	414042	19611R	PARTICIPANT	\N	PRESENT	0
414045	414042	19593H	PARTICIPANT	\N	PRESENT	0
414047	414046	19533U	PARTICIPANT	\N	PRESENT	0
414048	414046	19593H	PARTICIPANT	\N	PRESENT	0
414051	414050	08039A	PARTICIPANT	\N	PRESENT	0
414052	414050	14109K	PARTICIPANT	\N	PRESENT	0
414053	414050	19749K	PARTICIPANT	\N	PRESENT	0
414054	414049	08039A	PARTICIPANT	\N	PRESENT	0
414055	414049	14109K	PARTICIPANT	\N	PRESENT	0
414056	414049	19749K	PARTICIPANT	\N	PRESENT	0
414059	414058	08031R	PARTICIPANT	\N	PRESENT	0
414060	414057	08031R	PARTICIPANT	\N	PRESENT	0
415292	406854	08045X	PARTICIPANT	\N	PRESENT	0
415293	406854	19593H	PARTICIPANT	\N	PRESENT	0
415294	406854	14151M	PARTICIPANT	\N	PRESENT	0
415295	406854	95030B	PARTICIPANT	\N	PRESENT	0
415296	406854	19619A	PARTICIPANT	\N	PRESENT	0
415297	406854	11066Q	PARTICIPANT	\N	PRESENT	0
415298	406854	14157T	PARTICIPANT	\N	PRESENT	0
415299	406854	19782L	PARTICIPANT	\N	PRESENT	0
415300	406854	04008A	PARTICIPANT	\N	PRESENT	0
415301	406854	19295A	PARTICIPANT	\N	PRESENT	0
415302	406854	19715Y	PARTICIPANT	\N	PRESENT	0
415303	406854	14081Q	PARTICIPANT	\N	PRESENT	0
415304	406854	19585H	PARTICIPANT	\N	PRESENT	0
415305	406854	14201E	PARTICIPANT	\N	PRESENT	0
415306	406854	04069P	PARTICIPANT	\N	PRESENT	0
415307	406854	14063N	PARTICIPANT	\N	PRESENT	0
415308	406854	19301E	PARTICIPANT	\N	PRESENT	0
415309	406854	19533U	PARTICIPANT	\N	PRESENT	0
415310	406854	19798U	PARTICIPANT	\N	PRESENT	0
415311	406854	07033P	PARTICIPANT	\N	PRESENT	0
415312	406854	04047H	PARTICIPANT	\N	PRESENT	0
415313	406854	97011G	PARTICIPANT	\N	PRESENT	0
415314	406854	11103C	PARTICIPANT	\N	PRESENT	0
415315	406854	01028R	PARTICIPANT	\N	PRESENT	0
415316	406854	04035D	PARTICIPANT	\N	PRESENT	0
415317	406854	14281W	PARTICIPANT	\N	PRESENT	0
415318	406854	08014Q	PARTICIPANT	\N	PRESENT	0
415319	406854	08068F	PARTICIPANT	\N	PRESENT	0
415320	406854	19421M	PARTICIPANT	\N	PRESENT	0
415321	406854	11104D	PARTICIPANT	\N	PRESENT	0
415322	406854	14215L	PARTICIPANT	\N	PRESENT	0
415323	406854	14235Q	PARTICIPANT	\N	PRESENT	0
415324	406854	19671E	PARTICIPANT	\N	PRESENT	0
415325	406854	19760E	PARTICIPANT	\N	PRESENT	0
415326	406854	19695N	PARTICIPANT	\N	PRESENT	0
415327	406854	14211G	PARTICIPANT	\N	PRESENT	0
415328	406854	14259Y	PARTICIPANT	\N	PRESENT	0
415329	406854	10015M	PARTICIPANT	\N	PRESENT	0
415330	406854	11080N	PARTICIPANT	\N	PRESENT	0
415331	406854	19599P	PARTICIPANT	\N	PRESENT	0
415332	406854	14031R	PARTICIPANT	\N	PRESENT	0
415333	406854	19565D	PARTICIPANT	\N	PRESENT	0
415334	406854	14217N	PARTICIPANT	\N	PRESENT	0
415335	406854	14265W	PARTICIPANT	\N	PRESENT	0
415336	406854	14257W	PARTICIPANT	\N	PRESENT	0
420140	407723	19693L	PARTICIPANT	\N	PRESENT	0
420141	407723	08068F	PARTICIPANT	\N	PRESENT	0
420142	407723	19413M	PARTICIPANT	\N	PRESENT	0
420143	407723	14021P	PARTICIPANT	\N	PRESENT	0
420144	407723	14197C	PARTICIPANT	\N	PRESENT	0
420145	407723	08031R	PARTICIPANT	\N	PRESENT	0
420146	407723	11033F	PARTICIPANT	\N	PRESENT	0
420147	407723	19551W	PARTICIPANT	\N	PRESENT	0
421229	407834	04086Q	PARTICIPANT	\N	PRESENT	0
421230	407834	19399H	PARTICIPANT	\N	PRESENT	0
421257	407834	19333N	PARTICIPANT	\N	PRESENT	0
421232	407834	11012A	PARTICIPANT	\N	PRESENT	0
421233	407834	11033F	PARTICIPANT	\N	PRESENT	0
421234	407834	04057K	PARTICIPANT	\N	PRESENT	0
421276	407834	19762G	PARTICIPANT	\N	PRESENT	0
421236	407834	19515S	PARTICIPANT	\N	PRESENT	0
421237	407834	11026G	PARTICIPANT	\N	PRESENT	0
421258	407834	19741B	PARTICIPANT	\N	PRESENT	0
421239	407834	19599P	PARTICIPANT	\N	PRESENT	0
421240	407834	19649G	PARTICIPANT	\N	PRESENT	0
421241	407834	19479G	PARTICIPANT	\N	PRESENT	0
421242	407834	08060W	PARTICIPANT	\N	PRESENT	0
421243	407834	11031D	PARTICIPANT	\N	PRESENT	0
421244	407834	14179A	PARTICIPANT	\N	PRESENT	0
421245	407834	19711U	PARTICIPANT	\N	PRESENT	0
421246	407834	17583W	PARTICIPANT	\N	PRESENT	0
421247	407834	18083K	PARTICIPANT	\N	PRESENT	0
421248	407834	01024M	PARTICIPANT	\N	PRESENT	0
421249	407834	19745F	PARTICIPANT	\N	PRESENT	0
421250	407834	14229S	PARTICIPANT	\N	PRESENT	0
421251	407834	19689Q	PARTICIPANT	\N	PRESENT	0
421252	407834	11043H	PARTICIPANT	\N	PRESENT	0
421253	407834	19631V	PARTICIPANT	\N	PRESENT	0
421254	407834	14001X	PARTICIPANT	\N	PRESENT	0
421255	407834	14083S	PARTICIPANT	\N	PRESENT	0
421256	407834	14021P	PARTICIPANT	\N	PRESENT	0
421259	407834	14357A	PARTICIPANT	\N	PRESENT	0
421271	407834	19533U	PARTICIPANT	\N	PRESENT	0
421275	407834	14219Q	PARTICIPANT	\N	PRESENT	0
421277	407834	07029T	PARTICIPANT	\N	PRESENT	0
421278	407834	19525U	PARTICIPANT	\N	PRESENT	0
421279	407834	14069U	PARTICIPANT	\N	PRESENT	0
421280	407834	14033T	PARTICIPANT	\N	PRESENT	0
421281	407834	19585H	PARTICIPANT	\N	PRESENT	0
421313	407835	19503N	PARTICIPANT	\N	PRESENT	0
421314	407835	19333N	PARTICIPANT	\N	PRESENT	0
421315	407835	14063N	PARTICIPANT	\N	PRESENT	0
421316	407835	08060W	PARTICIPANT	\N	PRESENT	0
421317	407835	14021P	PARTICIPANT	\N	PRESENT	0
421318	407835	08012N	PARTICIPANT	\N	PRESENT	0
421319	407835	19349W	PARTICIPANT	\N	PRESENT	0
421320	407835	14241N	PARTICIPANT	\N	PRESENT	0
421321	407835	19585H	PARTICIPANT	\N	PRESENT	0
421322	407835	19479G	PARTICIPANT	\N	PRESENT	0
421323	407835	19525U	PARTICIPANT	\N	PRESENT	0
421324	407835	14231L	PARTICIPANT	\N	PRESENT	0
421325	407835	14073Q	PARTICIPANT	\N	PRESENT	0
421326	407835	19745F	PARTICIPANT	\N	PRESENT	0
421327	407835	19826F	PARTICIPANT	\N	PRESENT	0
421328	407835	07029T	PARTICIPANT	\N	PRESENT	0
421329	407835	19399H	PARTICIPANT	\N	PRESENT	0
421330	407835	87003B	PARTICIPANT	\N	PRESENT	0
421331	407835	19723Y	PARTICIPANT	\N	PRESENT	0
421332	407835	18083K	PARTICIPANT	\N	PRESENT	0
421333	407835	14147R	PARTICIPANT	\N	PRESENT	0
421334	407835	19760E	PARTICIPANT	\N	PRESENT	0
421335	407835	19533U	PARTICIPANT	\N	PRESENT	0
421336	407835	19701S	PARTICIPANT	\N	PRESENT	0
421337	407835	19762G	PARTICIPANT	\N	PRESENT	0
421338	407835	14053L	PARTICIPANT	\N	PRESENT	0
421339	407835	19383Y	PARTICIPANT	\N	PRESENT	0
421340	407835	14213J	PARTICIPANT	\N	PRESENT	0
421341	407835	14026U	PARTICIPANT	\N	PRESENT	0
421311	407835	14034U	PARTICIPANT	\N	PRESENT	0
421312	407835	19758L	PARTICIPANT	\N	PRESENT	0
421342	407835	14265W	PARTICIPANT	\N	PRESENT	0
421343	407835	14097Y	PARTICIPANT	\N	PRESENT	0
421344	407835	19782L	PARTICIPANT	\N	PRESENT	0
421345	407835	14229S	PARTICIPANT	\N	PRESENT	0
421346	407835	14038Y	PARTICIPANT	\N	PRESENT	0
421347	407835	11043H	PARTICIPANT	\N	PRESENT	0
421348	407835	19629C	PARTICIPANT	\N	PRESENT	0
421349	407835	19573D	PARTICIPANT	\N	PRESENT	0
421350	407835	08055A	PARTICIPANT	\N	PRESENT	0
421351	407835	14249W	PARTICIPANT	\N	PRESENT	0
421352	407835	14157T	PARTICIPANT	\N	PRESENT	0
421353	407835	14031R	PARTICIPANT	\N	PRESENT	0
421354	407835	14197C	PARTICIPANT	\N	PRESENT	0
421355	407835	19507S	PARTICIPANT	\N	PRESENT	0
421356	407835	19531S	PARTICIPANT	\N	PRESENT	0
421357	407835	11048N	PARTICIPANT	\N	PRESENT	0
421358	407835	02002K	PARTICIPANT	\N	PRESENT	0
421359	407835	19713W	PARTICIPANT	\N	PRESENT	0
421360	407835	19387D	PARTICIPANT	\N	PRESENT	0
421361	407835	14123H	PARTICIPANT	\N	PRESENT	0
421362	407835	19747H	PARTICIPANT	\N	PRESENT	0
421363	407835	11077T	PARTICIPANT	\N	PRESENT	0
421418	407836	08055A	PARTICIPANT	\N	PRESENT	0
421419	407836	19525U	PARTICIPANT	\N	PRESENT	0
421420	407836	19333N	PARTICIPANT	\N	PRESENT	0
421421	407836	19503N	PARTICIPANT	\N	PRESENT	0
421422	407836	02002K	PARTICIPANT	\N	PRESENT	0
421423	407836	19629C	PARTICIPANT	\N	PRESENT	0
421424	407836	19713W	PARTICIPANT	\N	PRESENT	0
421425	407836	19745F	PARTICIPANT	\N	PRESENT	0
421426	407836	19479G	PARTICIPANT	\N	PRESENT	0
421427	407836	19573D	PARTICIPANT	\N	PRESENT	0
421428	407836	11048N	PARTICIPANT	\N	PRESENT	0
421429	407836	19701S	PARTICIPANT	\N	PRESENT	0
421430	407836	19762G	PARTICIPANT	\N	PRESENT	0
421431	407836	19383Y	PARTICIPANT	\N	PRESENT	0
421432	407836	11043H	PARTICIPANT	\N	PRESENT	0
421433	407836	14031R	PARTICIPANT	\N	PRESENT	0
421434	407836	14097Y	PARTICIPANT	\N	PRESENT	0
421435	407836	14038Y	PARTICIPANT	\N	PRESENT	0
421436	407836	14123H	PARTICIPANT	\N	PRESENT	0
421437	407836	19747H	PARTICIPANT	\N	PRESENT	0
421438	407836	19347U	PARTICIPANT	\N	PRESENT	0
421439	407836	11077T	PARTICIPANT	\N	PRESENT	0
421440	407836	14157T	PARTICIPANT	\N	PRESENT	0
421441	407836	19387D	PARTICIPANT	\N	PRESENT	0
421442	407836	19551W	PARTICIPANT	\N	PRESENT	0
421443	407836	08060W	PARTICIPANT	\N	PRESENT	0
421832	419820	14021P	PARTICIPANT	\N	PRESENT	0
422826	414419	11065P	PARTICIPANT	\N	EXCUSE	0
422906	422441	19725B	PARTICIPANT	\N	PRESENT	0
422907	422441	19569H	PARTICIPANT	\N	PRESENT	0
423710	422672	12041X	PARTICIPANT	\N	PRESENT	0
423711	422672	11080N	PARTICIPANT	\N	PRESENT	0
423712	422672	01062T	PARTICIPANT	\N	PRESENT	0
423713	422672	11041F	PARTICIPANT	\N	PRESENT	0
423714	422672	14235Q	PARTICIPANT	\N	PRESENT	0
423715	422672	04040A	PARTICIPANT	\N	PRESENT	0
423716	422672	11027H	PARTICIPANT	\N	PRESENT	0
423717	422672	08058D	PARTICIPANT	\N	PRESENT	0
423719	422672	11054L	PARTICIPANT	\N	PRESENT	0
423720	422672	11066Q	PARTICIPANT	\N	PRESENT	0
423721	422672	19669L	PARTICIPANT	\N	PRESENT	0
423722	422672	08056B	PARTICIPANT	\N	PRESENT	0
423723	422672	14105F	PARTICIPANT	\N	PRESENT	0
423724	422672	19709B	PARTICIPANT	\N	PRESENT	0
423725	422672	98022P	PARTICIPANT	\N	PRESENT	0
423726	422672	14267Y	PARTICIPANT	\N	PRESENT	0
423727	422672	98050T	PARTICIPANT	\N	PRESENT	0
423728	422672	08053X	PARTICIPANT	\N	PRESENT	0
423729	422672	97011G	PARTICIPANT	\N	PRESENT	0
423730	422672	14211G	PARTICIPANT	\N	PRESENT	0
421416	407836	14034U	PARTICIPANT	\N	PRESENT	0
421417	407836	19782L	PARTICIPANT	\N	PRESENT	0
423731	422672	08047A	PRESIDENT	0	PRESENT	0
423732	422672	98029W	PARTICIPANT	\N	PRESENT	0
423733	422672	19443T	PARTICIPANT	\N	PRESENT	0
423734	422672	04034C	PARTICIPANT	\N	PRESENT	0
423735	422672	14079W	PARTICIPANT	\N	PRESENT	0
423736	422672	95037J	PARTICIPANT	\N	PRESENT	0
423737	422672	14055N	PARTICIPANT	\N	PRESENT	0
423738	422672	08049C	PARTICIPANT	\N	PRESENT	0
423739	422672	14193X	PARTICIPANT	\N	PRESENT	0
423740	422672	08061X	PARTICIPANT	\N	PRESENT	0
423741	422672	14097Y	PARTICIPANT	\N	PRESENT	0
423742	422672	19251M	PARTICIPANT	\N	PRESENT	0
423743	422672	14028W	PARTICIPANT	\N	PRESENT	0
423744	422672	11064N	PARTICIPANT	\N	PRESENT	0
423745	422672	95030B	PARTICIPANT	\N	PRESENT	0
423746	422672	19721W	PARTICIPANT	\N	PRESENT	0
423747	422672	01058X	PARTICIPANT	\N	PRESENT	0
423748	422672	16685X	PARTICIPANT	\N	PRESENT	0
395753	393744	19565D	PARTICIPANT	\N	EXCUSE	0
398368	398365	19593H	PARTICIPANT	\N	PRESENT	0
398369	398365	19766L	PARTICIPANT	\N	PRESENT	0
398370	398365	19643A	PARTICIPANT	\N	PRESENT	0
398371	398365	04070G	PRESIDENT	0	PRESENT	0
398372	398365	14073Q	PARTICIPANT	\N	PRESENT	0
398373	398365	19611R	PARTICIPANT	\N	PRESENT	0
398374	398365	19693L	PARTICIPANT	\N	PRESENT	0
398375	398365	19399H	PARTICIPANT	\N	PRESENT	0
398376	398365	14229S	PARTICIPANT	\N	PRESENT	0
398377	398365	14241N	PARTICIPANT	\N	PRESENT	0
398378	398365	14251Q	PARTICIPANT	\N	PRESENT	0
398379	398365	04059M	PARTICIPANT	\N	PRESENT	0
398380	398365	11083R	PARTICIPANT	\N	PRESENT	0
398381	398365	19749K	PARTICIPANT	\N	PRESENT	0
398382	398365	04018C	PARTICIPANT	\N	PRESENT	0
398383	398365	04057K	PARTICIPANT	\N	EXCUSE	0
398384	398365	08043V	PARTICIPANT	\N	EXCUSE	0
398385	398365	19758L	PARTICIPANT	\N	EXCUSE	0
400908	400907	19737F	PARTICIPANT	\N	PRESENT	0
400909	400907	19347U	PARTICIPANT	\N	PRESENT	0
405200	404747	19503N	PARTICIPANT	\N	PRESENT	0
405278	405277	99004R	PRESIDENT	0	PRESENT	0
405498	405333	19549D	PARTICIPANT	\N	PRESENT	0
405499	405333	14221J	PARTICIPANT	\N	PRESENT	0
405500	405333	14237S	PARTICIPANT	\N	PRESENT	0
405501	405333	11065P	PARTICIPANT	\N	PRESENT	0
405502	405333	15447F	PARTICIPANT	\N	PRESENT	0
405503	405333	14029X	PARTICIPANT	\N	PRESENT	0
405504	405333	19737F	PARTICIPANT	\N	PRESENT	0
405505	405333	04097T	PARTICIPANT	\N	PRESENT	0
405508	402265	08009T	PARTICIPANT	\N	PRESENT	0
405509	402265	19701S	PARTICIPANT	\N	PRESENT	0
405510	402265	04059M	PARTICIPANT	\N	PRESENT	0
405511	402265	12041X	PARTICIPANT	\N	PRESENT	0
405512	402265	19347U	PARTICIPANT	\N	PRESENT	0
405513	402265	19695N	PARTICIPANT	\N	PRESENT	0
405514	402265	19593H	PARTICIPANT	\N	PRESENT	0
405515	402265	19565D	PARTICIPANT	\N	PRESENT	0
405516	402265	11040E	PARTICIPANT	\N	PRESENT	0
405517	402265	04085P	PARTICIPANT	\N	PRESENT	0
405518	402265	11012A	PARTICIPANT	\N	PRESENT	0
405519	402265	08049C	PARTICIPANT	\N	PRESENT	0
405520	402265	14034U	PARTICIPANT	\N	PRESENT	0
405521	402265	14261S	PARTICIPANT	\N	PRESENT	0
405522	402265	14241N	PARTICIPANT	\N	PRESENT	0
405523	402265	14107H	PARTICIPANT	\N	PRESENT	0
405524	402265	19681G	PARTICIPANT	\N	PRESENT	0
405525	402265	19387D	PARTICIPANT	\N	PRESENT	0
405526	402265	19629C	PARTICIPANT	\N	PRESENT	0
405527	402265	19563B	PARTICIPANT	\N	PRESENT	0
405528	402265	19687N	PARTICIPANT	\N	PRESENT	0
405529	402265	14251Q	PARTICIPANT	\N	PRESENT	0
405530	402265	19583F	PARTICIPANT	\N	PRESENT	0
405531	402265	14093U	PARTICIPANT	\N	PRESENT	0
405532	402265	04057K	PARTICIPANT	\N	PRESENT	0
405533	402265	14121F	PARTICIPANT	\N	PRESENT	0
405534	402265	11065P	PARTICIPANT	\N	PRESENT	0
405535	402265	08024S	PARTICIPANT	\N	PRESENT	0
405536	402265	14039A	PARTICIPANT	\N	PRESENT	0
405537	402265	19782L	PARTICIPANT	\N	PRESENT	0
405538	402265	19812Y	PARTICIPANT	\N	PRESENT	0
405539	402265	19637C	PARTICIPANT	\N	PRESENT	0
405540	402265	19651A	PARTICIPANT	\N	PRESENT	0
405541	402265	95063L	PARTICIPANT	\N	PRESENT	0
405542	402265	95037J	PARTICIPANT	\N	PRESENT	0
405543	402265	08061X	PARTICIPANT	\N	PRESENT	0
405544	402265	19369B	PARTICIPANT	\N	PRESENT	0
405545	402265	19319Q	PARTICIPANT	\N	PRESENT	0
405546	402265	14042U	PARTICIPANT	\N	PRESENT	0
405547	402265	14219Q	PARTICIPANT	\N	PRESENT	0
405548	402265	19479G	PARTICIPANT	\N	PRESENT	0
405549	402265	19739H	PARTICIPANT	\N	PRESENT	0
405550	402265	19441R	PARTICIPANT	\N	PRESENT	0
405551	402265	19735D	PARTICIPANT	\N	PRESENT	0
405552	402265	19737F	PARTICIPANT	\N	PRESENT	0
405553	402265	11053K	PARTICIPANT	\N	PRESENT	0
405554	402265	14073Q	PARTICIPANT	\N	PRESENT	0
405555	402265	11033F	PARTICIPANT	\N	PRESENT	0
405556	402265	14083S	PARTICIPANT	\N	PRESENT	0
405557	402265	01043Q	PARTICIPANT	\N	PRESENT	0
405558	402265	04089T	PARTICIPANT	\N	PRESENT	0
405559	402265	14267Y	PARTICIPANT	\N	PRESENT	0
405560	402265	14103D	PARTICIPANT	\N	PRESENT	0
405561	402265	14221J	PARTICIPANT	\N	PRESENT	0
405562	402265	14089Y	PARTICIPANT	\N	PRESENT	0
405563	402265	08055A	PARTICIPANT	\N	PRESENT	0
405564	402265	08052W	PARTICIPANT	\N	PRESENT	0
405565	402265	14021P	PARTICIPANT	\N	PRESENT	0
405566	402265	14225N	PARTICIPANT	\N	PRESENT	0
405567	402265	19599P	PARTICIPANT	\N	PRESENT	0
405568	402265	19715Y	PARTICIPANT	\N	PRESENT	0
405569	402265	19647E	PARTICIPANT	\N	PRESENT	0
405570	402265	19531S	PARTICIPANT	\N	PRESENT	0
405571	402265	19727D	PARTICIPANT	\N	PRESENT	0
405572	402265	11066Q	PARTICIPANT	\N	PRESENT	0
405573	402265	08060W	PARTICIPANT	\N	PRESENT	0
405574	402265	08043V	PARTICIPANT	\N	PRESENT	0
405575	402265	19820Y	PARTICIPANT	\N	PRESENT	0
405576	402265	19591F	PARTICIPANT	\N	PRESENT	0
405577	402265	14085U	PARTICIPANT	\N	PRESENT	0
405578	402265	19683J	PARTICIPANT	\N	PRESENT	0
405579	402265	19295A	PARTICIPANT	\N	PRESENT	0
405580	402265	19549D	PARTICIPANT	\N	PRESENT	0
405581	402265	19301E	PARTICIPANT	\N	PRESENT	0
405582	402265	19333N	PARTICIPANT	\N	PRESENT	0
405583	402265	11067R	PARTICIPANT	\N	PRESENT	0
405584	402265	19503N	PARTICIPANT	\N	PRESENT	0
405585	402265	11054L	PARTICIPANT	\N	PRESENT	0
405586	402265	14197C	PARTICIPANT	\N	PRESENT	0
405587	402265	89017R	PARTICIPANT	\N	PRESENT	0
405588	402265	08056B	PARTICIPANT	\N	PRESENT	0
405589	402265	19731Y	PARTICIPANT	\N	PRESENT	0
405590	402265	19679N	PARTICIPANT	\N	PRESENT	0
405591	402265	19515S	PARTICIPANT	\N	PRESENT	0
405592	402265	15447F	PARTICIPANT	\N	PRESENT	0
405593	402265	19703U	PARTICIPANT	\N	PRESENT	0
405594	402265	19443T	PARTICIPANT	\N	PRESENT	0
405595	402265	14038Y	PARTICIPANT	\N	PRESENT	0
405596	402265	19711U	PARTICIPANT	\N	PRESENT	0
405597	402265	14157T	PARTICIPANT	\N	PRESENT	0
405598	402265	96004D	PARTICIPANT	\N	PRESENT	0
405599	402265	99004R	PARTICIPANT	\N	PRESENT	0
405600	402265	04042C	PARTICIPANT	\N	PRESENT	0
405601	402265	08069G	PARTICIPANT	\N	PRESENT	0
405602	402265	08010L	PARTICIPANT	\N	PRESENT	0
405603	402265	19611R	PARTICIPANT	\N	PRESENT	0
405604	402265	01057W	PARTICIPANT	\N	PRESENT	0
405605	402265	14169X	PARTICIPANT	\N	PRESENT	0
405606	402265	14223L	PARTICIPANT	\N	PRESENT	0
405607	402265	01048V	PARTICIPANT	\N	PRESENT	0
405608	402265	11048N	PARTICIPANT	\N	PRESENT	0
405609	402265	11090Q	PARTICIPANT	\N	PRESENT	0
405610	402265	87003B	PARTICIPANT	\N	PRESENT	0
405611	402265	05012A	PARTICIPANT	\N	PRESENT	0
405612	402265	08034U	PARTICIPANT	\N	PRESENT	0
405613	402265	19766L	PARTICIPANT	\N	PRESENT	0
405614	402265	14031R	PARTICIPANT	\N	PRESENT	0
405616	402265	19575F	PARTICIPANT	\N	PRESENT	0
405617	402265	14253S	PARTICIPANT	\N	PRESENT	0
405618	402265	14179A	PARTICIPANT	\N	PRESENT	0
405619	402265	04049K	PARTICIPANT	\N	PRESENT	0
405620	402265	14147R	PARTICIPANT	\N	PRESENT	0
405621	402265	14105F	PARTICIPANT	\N	PRESENT	0
405622	402265	14069U	PARTICIPANT	\N	PRESENT	0
405623	402265	14119M	PARTICIPANT	\N	PRESENT	0
405624	402265	19794Q	PARTICIPANT	\N	PRESENT	0
405625	402265	04097T	PARTICIPANT	\N	PRESENT	0
405626	402265	14249W	PARTICIPANT	\N	PRESENT	0
405627	402265	19467C	PARTICIPANT	\N	PRESENT	0
405628	402265	14029X	PARTICIPANT	\N	PRESENT	0
405629	402265	04088S	PARTICIPANT	\N	PRESENT	0
405630	402265	14033T	PARTICIPANT	\N	PRESENT	0
405631	402265	14135M	PARTICIPANT	\N	PRESENT	0
405632	402265	19399H	PARTICIPANT	\N	PRESENT	0
405633	402265	19693L	PARTICIPANT	\N	PRESENT	0
405634	402265	17583W	PARTICIPANT	\N	PRESENT	0
405635	402265	14217N	PARTICIPANT	\N	PRESENT	0
405636	402265	08019V	PARTICIPANT	\N	PRESENT	0
405637	402265	14265W	PARTICIPANT	\N	PRESENT	0
405638	402265	08062Y	PARTICIPANT	\N	PRESENT	0
405639	402265	19709B	PARTICIPANT	\N	PRESENT	0
405640	402265	04018C	PARTICIPANT	\N	PRESENT	0
405641	402265	19762G	PARTICIPANT	\N	PRESENT	0
405642	402265	04047H	PARTICIPANT	\N	PRESENT	0
405643	402265	08020N	PARTICIPANT	\N	PRESENT	0
405644	402265	19621T	PARTICIPANT	\N	PRESENT	0
405645	402265	98050T	PARTICIPANT	\N	PRESENT	0
412260	406844	04057K	PARTICIPANT	\N	PRESENT	0
412261	406844	08012N	PARTICIPANT	\N	PRESENT	0
412262	406844	08009T	PARTICIPANT	\N	PRESENT	0
412263	406844	19735D	PARTICIPANT	\N	PRESENT	0
412264	406844	14097Y	PARTICIPANT	\N	PRESENT	0
412266	406844	14089Y	PARTICIPANT	\N	PRESENT	0
412267	412265	04040A	PRESIDENT	0	PRESENT	0
412268	406844	19747H	PARTICIPANT	\N	PRESENT	0
412269	406844	14237S	PARTICIPANT	\N	PRESENT	0
412270	406844	14087W	PARTICIPANT	\N	PRESENT	0
412271	406844	11099A	PARTICIPANT	\N	PRESENT	0
412272	406844	19749K	PARTICIPANT	\N	PRESENT	0
412273	406844	08039A	PARTICIPANT	\N	PRESENT	0
412274	406844	17637T	PARTICIPANT	\N	PRESENT	0
412276	412275	19747H	PARTICIPANT	\N	PRESENT	0
412277	412265	95063L	PARTICIPANT	\N	EXCUSE	0
412279	412278	19701S	PARTICIPANT	\N	PRESENT	0
412280	412278	19667J	PARTICIPANT	\N	PRESENT	0
412281	412278	19693L	PARTICIPANT	\N	PRESENT	0
412282	412278	14281W	PARTICIPANT	\N	PRESENT	0
412283	412278	14255U	PARTICIPANT	\N	PRESENT	0
412284	412278	11026G	PARTICIPANT	\N	PRESENT	0
412285	412278	04057K	PARTICIPANT	\N	PRESENT	0
412286	412278	18083K	PARTICIPANT	\N	PRESENT	0
412287	412278	19762G	PARTICIPANT	\N	PRESENT	0
412288	412278	19733B	PARTICIPANT	\N	PRESENT	0
412593	402297	86034E	PARTICIPANT	\N	PRESENT	0
412594	402297	95063L	PARTICIPANT	\N	PRESENT	0
412595	402297	80013X	PARTICIPANT	\N	PRESENT	0
412596	402297	08060W	PARTICIPANT	\N	PRESENT	0
412597	402297	08017T	PARTICIPANT	\N	PRESENT	0
412598	402297	14063N	PARTICIPANT	\N	PRESENT	0
412599	402297	19585H	PARTICIPANT	\N	PRESENT	0
412600	402297	19545Y	PARTICIPANT	\N	PRESENT	0
412601	402297	04057K	PARTICIPANT	\N	PRESENT	0
412602	402297	14195A	PARTICIPANT	\N	PRESENT	0
412603	402297	19319Q	PARTICIPANT	\N	PRESENT	0
412604	402297	19691J	PARTICIPANT	\N	PRESENT	0
412605	402297	01025N	PARTICIPANT	\N	PRESENT	0
412606	402297	19745F	PARTICIPANT	\N	PRESENT	0
412607	402297	19671E	PARTICIPANT	\N	PRESENT	0
412662	402297	14107H	PARTICIPANT	\N	PRESENT	0
412609	402297	19768N	PARTICIPANT	\N	PRESENT	0
412610	402297	14265W	PARTICIPANT	\N	PRESENT	0
412611	402297	19507S	PARTICIPANT	\N	PRESENT	0
412612	402297	14215L	PARTICIPANT	\N	PRESENT	0
412613	402297	01024M	PARTICIPANT	\N	PRESENT	0
412614	402297	08052W	PARTICIPANT	\N	PRESENT	0
412615	402297	19737F	PARTICIPANT	\N	PRESENT	0
412616	402297	11010L	PARTICIPANT	\N	PRESENT	0
412617	402297	19467C	PARTICIPANT	\N	PRESENT	0
412645	402297	08061X	PARTICIPANT	\N	PRESENT	0
412619	402297	19820Y	PARTICIPANT	\N	PRESENT	0
412620	402297	19421M	PARTICIPANT	\N	PRESENT	0
412621	402297	14257W	PARTICIPANT	\N	PRESENT	0
412622	402297	19683J	PARTICIPANT	\N	PRESENT	0
412623	402297	19758L	PARTICIPANT	\N	PRESENT	0
412624	402297	12041X	PARTICIPANT	\N	PRESENT	0
412625	402297	04085P	PARTICIPANT	\N	PRESENT	0
412626	402297	11031D	PARTICIPANT	\N	PRESENT	0
412627	402297	17779H	PARTICIPANT	\N	PRESENT	0
412628	402297	11026G	PARTICIPANT	\N	PRESENT	0
412629	402297	14197C	PARTICIPANT	\N	PRESENT	0
412630	402297	19631V	PARTICIPANT	\N	PRESENT	0
412631	402297	14081Q	PARTICIPANT	\N	PRESENT	0
412632	402297	08073C	PARTICIPANT	\N	PRESENT	0
412633	402297	14021P	PARTICIPANT	\N	PRESENT	0
412634	402297	19651A	PARTICIPANT	\N	PRESENT	0
412635	402297	19349W	PARTICIPANT	\N	PRESENT	0
412636	402297	98029W	PARTICIPANT	\N	PRESENT	0
412637	402297	14065Q	PARTICIPANT	\N	PRESENT	0
412638	402297	11067R	PARTICIPANT	\N	PRESENT	0
412639	402297	14227Q	PARTICIPANT	\N	PRESENT	0
412640	402297	11033F	PARTICIPANT	\N	PRESENT	0
412641	402297	19503N	PARTICIPANT	\N	PRESENT	0
412642	402297	19599P	PARTICIPANT	\N	PRESENT	0
412643	402297	14229S	PARTICIPANT	\N	PRESENT	0
412644	402297	08045X	PARTICIPANT	\N	PRESENT	0
412646	402297	04034C	PARTICIPANT	\N	PRESENT	0
412647	402297	88008L	PARTICIPANT	\N	PRESENT	0
412648	402297	11012A	PARTICIPANT	\N	PRESENT	0
412649	402297	19549D	PARTICIPANT	\N	PRESENT	0
412650	402297	19713W	PARTICIPANT	\N	PRESENT	0
412651	402297	14207L	PARTICIPANT	\N	PRESENT	0
412652	402297	19725B	PARTICIPANT	\N	PRESENT	0
412653	402297	14205J	PARTICIPANT	\N	PRESENT	0
412654	402297	19739H	PARTICIPANT	\N	PRESENT	0
412655	402297	14073Q	PARTICIPANT	\N	PRESENT	0
412656	402297	11070L	PARTICIPANT	\N	PRESENT	0
412657	402297	14089Y	PARTICIPANT	\N	PRESENT	0
412658	402297	19826F	PARTICIPANT	\N	PRESENT	0
412659	402297	04040A	PARTICIPANT	\N	PRESENT	0
412660	402297	19553Y	PARTICIPANT	\N	PRESENT	0
412661	402297	19441R	PARTICIPANT	\N	PRESENT	0
412663	402297	98022P	PARTICIPANT	\N	PRESENT	0
412664	402297	19629C	PARTICIPANT	\N	PRESENT	0
412665	402297	19347U	PARTICIPANT	\N	PRESENT	0
412666	402297	19760E	PARTICIPANT	\N	PRESENT	0
412667	402297	19695N	PARTICIPANT	\N	PRESENT	0
412668	402297	11065P	PARTICIPANT	\N	PRESENT	0
412669	402297	19649G	PARTICIPANT	\N	PRESENT	0
412670	402297	14097Y	PARTICIPANT	\N	PRESENT	0
412671	402297	19747H	PARTICIPANT	\N	PRESENT	0
412672	402297	11097X	PARTICIPANT	\N	PRESENT	0
412673	402297	19711U	PARTICIPANT	\N	PRESENT	0
412674	402297	19581D	PARTICIPANT	\N	PRESENT	0
412675	402297	19335Q	PARTICIPANT	\N	PRESENT	0
412676	402297	17637T	PARTICIPANT	\N	PRESENT	0
412677	402297	01043Q	PARTICIPANT	\N	PRESENT	0
412678	402297	14211G	PARTICIPANT	\N	PRESENT	0
412679	402297	19525U	PARTICIPANT	\N	PRESENT	0
412680	402297	01058X	PARTICIPANT	\N	PRESENT	0
412681	402297	19637C	PARTICIPANT	\N	PRESENT	0
412682	402297	08010L	PARTICIPANT	\N	PRESENT	0
412683	402297	19387D	PARTICIPANT	\N	PRESENT	0
412684	402297	04042C	PARTICIPANT	\N	PRESENT	0
412685	402297	11056N	PARTICIPANT	\N	PRESENT	0
412686	402297	04033B	PARTICIPANT	\N	PRESENT	0
412687	402297	05008E	PARTICIPANT	\N	PRESENT	0
412688	402297	19731Y	PARTICIPANT	\N	PRESENT	0
412689	402297	95030B	PARTICIPANT	\N	PRESENT	0
412690	402297	14059S	PARTICIPANT	\N	PRESENT	0
412691	402297	04044E	PARTICIPANT	\N	PRESENT	0
412692	402297	04018C	PARTICIPANT	\N	PRESENT	0
412693	402297	19701S	PARTICIPANT	\N	PRESENT	0
412694	402297	04047H	PARTICIPANT	\N	PRESENT	0
412695	402297	19383Y	PARTICIPANT	\N	PRESENT	0
412696	402297	04069P	PARTICIPANT	\N	PRESENT	0
412697	402297	19533U	PARTICIPANT	\N	PRESENT	0
412698	402297	14217N	PARTICIPANT	\N	PRESENT	0
412699	402297	10015M	PARTICIPANT	\N	PRESENT	0
412700	402297	04043D	PARTICIPANT	\N	PRESENT	0
412701	402297	97011G	PARTICIPANT	\N	PRESENT	0
412702	402297	04071H	PARTICIPANT	\N	PRESENT	0
412703	402297	19685L	PARTICIPANT	\N	PRESENT	0
412704	402297	19643A	PARTICIPANT	\N	PRESENT	0
412705	402297	14033T	PARTICIPANT	\N	PRESENT	0
412706	402297	01057W	PARTICIPANT	\N	PRESENT	0
412707	402297	14119M	PARTICIPANT	\N	PRESENT	0
412708	402297	19415P	PARTICIPANT	\N	PRESENT	0
412709	402297	19515S	PARTICIPANT	\N	PRESENT	0
412710	402297	18083K	PARTICIPANT	\N	PRESENT	0
412711	402297	04088S	PARTICIPANT	\N	PRESENT	0
412712	402297	19443T	PARTICIPANT	\N	PRESENT	0
412713	402297	19794Q	PARTICIPANT	\N	PRESENT	0
412714	402297	87003B	PARTICIPANT	\N	PRESENT	0
412715	402297	14031R	PARTICIPANT	\N	PRESENT	0
412716	402297	19673G	PARTICIPANT	\N	PRESENT	0
412717	402297	14115H	PARTICIPANT	\N	PRESENT	0
412718	402297	19447X	PARTICIPANT	\N	PRESENT	0
412719	402297	19693L	PARTICIPANT	\N	PRESENT	0
412720	402297	07029T	PARTICIPANT	\N	PRESENT	0
412721	402297	19657G	PARTICIPANT	\N	PRESENT	0
412722	402297	14147R	PARTICIPANT	\N	PRESENT	0
412723	402297	14038Y	PARTICIPANT	\N	PRESENT	0
412724	402297	11048N	PARTICIPANT	\N	PRESENT	0
412725	402297	14071N	PARTICIPANT	\N	PRESENT	0
412726	402297	11064N	PARTICIPANT	\N	PRESENT	0
412727	402297	19697Q	PARTICIPANT	\N	PRESENT	0
412728	402297	14235Q	PARTICIPANT	\N	PRESENT	0
412729	402297	19611R	PARTICIPANT	\N	PRESENT	0
412730	402297	19715Y	PARTICIPANT	\N	PRESENT	0
412731	402297	14151M	PARTICIPANT	\N	PRESENT	0
412732	402297	95037J	PARTICIPANT	\N	PRESENT	0
412733	402297	14251Q	PARTICIPANT	\N	PRESENT	0
412734	402297	19269X	PARTICIPANT	\N	PRESENT	0
412735	402297	08031R	PARTICIPANT	\N	PRESENT	0
412736	402297	19531S	PARTICIPANT	\N	PRESENT	0
412737	402297	14187A	PARTICIPANT	\N	PRESENT	0
392919	384447	19715Y	PARTICIPANT	\N	EXCUSE	0
395443	395442	04008A	PARTICIPANT	\N	PRESENT	0
395444	395442	19585H	PARTICIPANT	\N	PRESENT	0
395446	395445	14071N	PARTICIPANT	\N	PRESENT	0
395447	395445	19575F	PARTICIPANT	\N	PRESENT	0
396513	396219	08012N	PARTICIPANT	\N	EXCUSE	0
396514	396219	19349W	PARTICIPANT	\N	PRESENT	0
396515	396219	01028R	PARTICIPANT	\N	EXCUSE	0
396569	396129	19659J	PARTICIPANT	\N	EXCUSE	0
396570	396129	14059S	PARTICIPANT	\N	EXCUSE	0
396572	396129	19583F	PARTICIPANT	\N	EXCUSE	0
396573	396129	14225N	PARTICIPANT	\N	EXCUSE	0
396574	396130	19659J	PARTICIPANT	\N	EXCUSE	0
396575	396130	19583F	PARTICIPANT	\N	EXCUSE	0
396576	396130	14331P	PARTICIPANT	\N	EXCUSE	0
396577	396130	14059S	PARTICIPANT	\N	EXCUSE	0
396578	396130	14225N	PARTICIPANT	\N	EXCUSE	0
396579	396131	19659J	PARTICIPANT	\N	EXCUSE	0
396580	396131	19583F	PARTICIPANT	\N	EXCUSE	0
396581	396131	14225N	PARTICIPANT	\N	EXCUSE	0
396582	396131	14059S	PARTICIPANT	\N	EXCUSE	0
400228	398234	14135M	PARTICIPANT	\N	PRESENT	0
400229	398234	19515S	PARTICIPANT	\N	PRESENT	0
400230	398234	08068F	PARTICIPANT	\N	PRESENT	0
400231	398234	19705W	PARTICIPANT	\N	PRESENT	0
400232	398234	14357A	PARTICIPANT	\N	PRESENT	0
400233	398234	19413M	PARTICIPANT	\N	PRESENT	0
400234	398234	14033T	PARTICIPANT	\N	PRESENT	0
400235	398234	11090Q	PRESIDENT	0	PRESENT	0
400236	398234	19747H	PARTICIPANT	\N	PRESENT	0
400237	398234	14207L	PARTICIPANT	\N	PRESENT	0
400238	398234	19631V	PARTICIPANT	\N	PRESENT	0
400239	398234	11081P	PARTICIPANT	\N	EXCUSE	0
400240	398234	14329V	PARTICIPANT	\N	EXCUSE	0
400245	393609	14225N	PARTICIPANT	\N	PRESENT	0
400246	393609	11074Q	PARTICIPANT	\N	PRESENT	0
400247	393609	19711U	PARTICIPANT	\N	PRESENT	0
400248	393609	19543W	PARTICIPANT	\N	PRESENT	0
400249	393609	14083S	PARTICIPANT	\N	PRESENT	0
400250	393609	14331P	PARTICIPANT	\N	PRESENT	0
400251	393609	11040E	PARTICIPANT	\N	PRESENT	0
400252	393609	07029T	PARTICIPANT	\N	PRESENT	0
400253	393609	19333N	PARTICIPANT	\N	PRESENT	0
400254	393609	19545Y	PARTICIPANT	\N	PRESENT	0
400255	393609	14121F	PARTICIPANT	\N	PRESENT	0
400256	393609	14021P	PARTICIPANT	\N	PRESENT	0
400257	393609	19737F	PARTICIPANT	\N	PRESENT	0
400258	393609	11070L	PARTICIPANT	\N	PRESENT	0
400259	393609	01057W	PARTICIPANT	\N	PRESENT	0
400260	393609	19741B	PARTICIPANT	\N	PRESENT	0
400261	393609	08014Q	PARTICIPANT	\N	PRESENT	0
400262	393609	19515S	PARTICIPANT	\N	PRESENT	0
400263	393609	19794Q	PARTICIPANT	\N	PRESENT	0
400264	393609	98024R	PARTICIPANT	\N	PRESENT	0
400265	393609	99004R	PARTICIPANT	\N	PRESENT	0
400266	393609	96004D	PARTICIPANT	\N	PRESENT	0
400268	393609	11048N	PARTICIPANT	\N	PRESENT	0
400269	393609	01034P	PARTICIPANT	\N	PRESENT	0
400270	393609	04071H	PARTICIPANT	\N	PRESENT	0
400271	393609	14259Y	PARTICIPANT	\N	PRESENT	0
400274	393609	14157T	PARTICIPANT	\N	PRESENT	0
400275	393609	14133K	PARTICIPANT	\N	PRESENT	0
400280	393609	11049P	PARTICIPANT	\N	PRESENT	0
400281	393609	14041T	PARTICIPANT	\N	PRESENT	0
400286	393609	95063L	PARTICIPANT	\N	PRESENT	0
400287	393609	11067R	PARTICIPANT	\N	PRESENT	0
400288	400244	19725B	PRESIDENT	0	PRESENT	0
400289	400244	19441R	PRESIDENT	1	PRESENT	0
400290	400244	19747H	PARTICIPANT	\N	PRESENT	0
400291	400244	19295A	PARTICIPANT	\N	PRESENT	0
400292	400244	14030Q	PARTICIPANT	\N	PRESENT	0
400293	400244	11056N	PARTICIPANT	\N	EXCUSE	0
400294	400244	04057K	PARTICIPANT	\N	EXCUSE	0
400295	400244	08015R	PARTICIPANT	\N	EXCUSE	0
400296	400244	14071N	PARTICIPANT	\N	EXCUSE	0
400297	393609	19713W	PARTICIPANT	\N	PRESENT	0
400298	393609	14033T	PARTICIPANT	\N	PRESENT	0
400299	393609	19691J	PARTICIPANT	\N	PRESENT	0
400300	393609	19739H	PARTICIPANT	\N	PRESENT	0
400301	393609	04086Q	PARTICIPANT	\N	PRESENT	0
400302	393609	14135M	PARTICIPANT	\N	PRESENT	0
400303	393609	14061L	PARTICIPANT	\N	PRESENT	0
400304	393609	19693L	PARTICIPANT	\N	PRESENT	0
400305	393609	08010L	PARTICIPANT	\N	PRESENT	0
400306	393609	08034U	PARTICIPANT	\N	PRESENT	0
400307	393609	98050T	PARTICIPANT	\N	PRESENT	0
400308	393609	14219Q	PARTICIPANT	\N	PRESENT	0
400309	393609	14179A	PARTICIPANT	\N	PRESENT	0
400310	393609	19747H	PARTICIPANT	\N	PRESENT	0
400311	393609	14038Y	PARTICIPANT	\N	PRESENT	0
400312	393609	19441R	PARTICIPANT	\N	PRESENT	0
400333	393609	14159V	PARTICIPANT	\N	PRESENT	0
400334	393609	19549D	PARTICIPANT	\N	PRESENT	0
400335	393609	04085P	PARTICIPANT	\N	PRESENT	0
400461	393609	14030Q	PARTICIPANT	\N	PRESENT	0
410613	410612	04070G	PARTICIPANT	\N	PRESENT	0
410614	410612	95067Q	PARTICIPANT	\N	PRESENT	0
410615	410612	08009T	PARTICIPANT	\N	PRESENT	0
410617	410612	14237S	PARTICIPANT	\N	PRESENT	0
410618	410612	08020N	PARTICIPANT	\N	PRESENT	0
410619	410612	14217N	PARTICIPANT	\N	PRESENT	0
410620	410612	14097Y	PARTICIPANT	\N	PRESENT	0
410621	410612	19637C	PARTICIPANT	\N	PRESENT	0
410622	410612	08031R	PARTICIPANT	\N	PRESENT	0
410624	410623	19667J	PARTICIPANT	\N	PRESENT	0
410625	410623	19701S	PARTICIPANT	\N	PRESENT	0
413947	413495	12041X	PARTICIPANT	\N	PRESENT	0
415337	406854	19489J	PARTICIPANT	\N	PRESENT	0
415338	406854	19647E	PARTICIPANT	\N	PRESENT	0
415339	406854	11027H	PARTICIPANT	\N	PRESENT	0
415340	406854	11031D	PARTICIPANT	\N	PRESENT	0
415341	406854	19649G	PARTICIPANT	\N	PRESENT	0
415342	406854	19711U	PARTICIPANT	\N	PRESENT	0
415343	406854	11101A	PARTICIPANT	\N	PRESENT	0
415345	406854	08039A	PARTICIPANT	\N	PRESENT	0
415346	406854	08069G	PARTICIPANT	\N	PRESENT	0
415347	406854	04071H	PARTICIPANT	\N	PRESENT	0
415348	406854	12041X	PARTICIPANT	\N	PRESENT	0
415349	406854	04038G	PARTICIPANT	\N	PRESENT	0
415350	406854	19758L	PARTICIPANT	\N	PRESENT	0
415351	406854	19687N	PARTICIPANT	\N	PRESENT	0
415352	406854	04085P	PARTICIPANT	\N	PRESENT	0
415353	406854	08061X	PARTICIPANT	\N	PRESENT	0
415354	406854	95037J	PARTICIPANT	\N	PRESENT	0
415355	406854	11083R	PARTICIPANT	\N	PRESENT	0
415356	406854	17637T	PARTICIPANT	\N	PRESENT	0
415357	406854	04045F	PARTICIPANT	\N	PRESENT	0
415358	406854	19349W	PARTICIPANT	\N	PRESENT	0
415359	406854	19269X	PARTICIPANT	\N	PRESENT	0
415360	406854	14039A	PARTICIPANT	\N	PRESENT	0
415361	406854	08024S	PARTICIPANT	\N	PRESENT	0
415362	406854	01058X	PARTICIPANT	\N	PRESENT	0
415363	406854	99004R	PARTICIPANT	\N	PRESENT	0
415364	406854	11077T	PARTICIPANT	\N	PRESENT	0
415365	406854	19679N	PARTICIPANT	\N	PRESENT	0
415366	406854	14123H	PARTICIPANT	\N	PRESENT	0
415367	406854	11040E	PARTICIPANT	\N	PRESENT	0
415368	406854	11012A	PARTICIPANT	\N	PRESENT	0
415369	406854	19643A	PARTICIPANT	\N	PRESENT	0
415370	406854	14034U	PARTICIPANT	\N	PRESENT	0
415371	406854	08049C	PARTICIPANT	\N	PRESENT	0
415372	406854	88008L	PARTICIPANT	\N	PRESENT	0
415373	406854	14169X	PARTICIPANT	\N	PRESENT	0
415374	406854	19629C	PARTICIPANT	\N	PRESENT	0
415375	406854	14207L	PARTICIPANT	\N	PRESENT	0
415376	406854	14241N	PARTICIPANT	\N	PRESENT	0
415377	406854	01048V	PARTICIPANT	\N	PRESENT	0
415378	406854	04042C	PARTICIPANT	\N	PRESENT	0
415379	406854	08011M	PARTICIPANT	\N	PRESENT	0
415380	406854	14111D	PARTICIPANT	\N	PRESENT	0
415381	406854	04057K	PARTICIPANT	\N	PRESENT	0
415382	406854	14195A	PARTICIPANT	\N	PRESENT	0
415383	406854	19515S	PARTICIPANT	\N	PRESENT	0
415384	406854	11064N	PARTICIPANT	\N	PRESENT	0
415385	406854	14239U	PARTICIPANT	\N	PRESENT	0
415386	406854	14107H	PARTICIPANT	\N	PRESENT	0
415387	406854	87003B	PARTICIPANT	\N	PRESENT	0
415388	406854	19685L	PARTICIPANT	\N	PRESENT	0
415389	406854	08056B	PARTICIPANT	\N	PRESENT	0
415390	406854	19673G	PARTICIPANT	\N	PRESENT	0
415391	406854	11010L	PARTICIPANT	\N	PRESENT	0
415392	406854	11074Q	PARTICIPANT	\N	PRESENT	0
415393	406854	14199E	PARTICIPANT	\N	PRESENT	0
415394	406854	04059M	PARTICIPANT	\N	PRESENT	0
415395	406854	02002K	PARTICIPANT	\N	PRESENT	0
415396	406854	19575F	PARTICIPANT	\N	PRESENT	0
415397	406854	14253S	PARTICIPANT	\N	PRESENT	0
415398	406854	11048N	PARTICIPANT	\N	PRESENT	0
415399	406854	08052W	PARTICIPANT	\N	PRESENT	0
421691	414078	14299H	PARTICIPANT	\N	EXCUSE	0
421697	414078	01048V	PRESIDENT	0	PRESENT	0
421710	421702	14087W	PARTICIPANT	\N	PRESENT	0
421711	421705	14087W	PARTICIPANT	\N	PRESENT	0
421712	421705	19679N	PARTICIPANT	\N	PRESENT	0
421717	421713	08048B	PARTICIPANT	\N	PRESENT	0
421731	421730	14087W	PARTICIPANT	\N	PRESENT	0
421732	421730	19521Q	PARTICIPANT	\N	PRESENT	0
421733	421730	19679N	PARTICIPANT	\N	PRESENT	0
421734	421728	14087W	PARTICIPANT	\N	PRESENT	0
421735	421728	19521Q	PARTICIPANT	\N	PRESENT	0
421736	421728	19679N	PARTICIPANT	\N	PRESENT	0
421739	421738	10006L	PARTICIPANT	\N	PRESENT	0
421856	420251	19583F	PARTICIPANT	\N	EXCUSE	0
421857	420251	08053X	PARTICIPANT	\N	EXCUSE	0
421858	420251	19319Q	PARTICIPANT	\N	EXCUSE	0
421860	421859	08011M	PARTICIPANT	\N	PRESENT	0
421862	421861	11074Q	PARTICIPANT	\N	PRESENT	0
421884	421882	14085U	PARTICIPANT	\N	PRESENT	0
421885	421882	14253S	PARTICIPANT	\N	PRESENT	0
421918	421915	14085U	PARTICIPANT	\N	PRESENT	0
421920	421915	14253S	PARTICIPANT	\N	PRESENT	0
422091	407837	08048B	PARTICIPANT	\N	PRESENT	0
422092	407837	14031R	PARTICIPANT	\N	PRESENT	0
422093	407837	14249W	PARTICIPANT	\N	PRESENT	0
422094	407837	05012A	PARTICIPANT	\N	PRESENT	0
422095	407837	11040E	PARTICIPANT	\N	PRESENT	0
422096	407837	14083S	PARTICIPANT	\N	PRESENT	0
422097	407837	19749K	PARTICIPANT	\N	PRESENT	0
422098	407837	19826F	PARTICIPANT	\N	PRESENT	0
422099	407837	07004J	PARTICIPANT	\N	PRESENT	0
422100	407837	19798U	PARTICIPANT	\N	PRESENT	0
422101	407837	14255U	PARTICIPANT	\N	PRESENT	0
422102	407837	19577H	PARTICIPANT	\N	PRESENT	0
422103	407837	04040A	PARTICIPANT	\N	PRESENT	0
422104	407837	14237S	PARTICIPANT	\N	PRESENT	0
422105	407837	01024M	PARTICIPANT	\N	PRESENT	0
422106	407837	14030Q	PARTICIPANT	\N	PRESENT	0
422107	407837	19531S	PARTICIPANT	\N	PRESENT	0
422108	407837	95041E	PARTICIPANT	\N	PRESENT	0
422109	407837	14327T	PARTICIPANT	\N	PRESENT	0
422110	407837	01043Q	PARTICIPANT	\N	PRESENT	0
422111	407837	14053L	PARTICIPANT	\N	PRESENT	0
422112	407837	19745F	PARTICIPANT	\N	PRESENT	0
422113	407837	14071N	PARTICIPANT	\N	PRESENT	0
422114	407837	19421M	PARTICIPANT	\N	PRESENT	0
422115	407837	04086Q	PARTICIPANT	\N	PRESENT	0
422116	407837	04044E	PARTICIPANT	\N	PRESENT	0
422117	407837	95030B	PARTICIPANT	\N	PRESENT	0
422118	407837	98024R	PARTICIPANT	\N	PRESENT	0
422119	407837	04035D	PARTICIPANT	\N	PRESENT	0
422120	407837	11031D	PARTICIPANT	\N	PRESENT	0
422121	407837	11033F	PARTICIPANT	\N	PRESENT	0
422122	407837	14033T	PARTICIPANT	\N	PRESENT	0
422123	407837	19593H	PARTICIPANT	\N	PRESENT	0
422124	407837	16685X	PARTICIPANT	\N	PRESENT	0
422125	407837	08039A	PARTICIPANT	\N	PRESENT	0
422126	407837	11099A	PARTICIPANT	\N	PRESENT	0
422127	407837	14111D	PARTICIPANT	\N	PRESENT	0
422128	407837	01062T	PARTICIPANT	\N	PRESENT	0
422129	407837	11070L	PARTICIPANT	\N	PRESENT	0
422130	407837	04071H	PARTICIPANT	\N	PRESENT	0
422131	407837	11074Q	PARTICIPANT	\N	PRESENT	0
422132	407837	11101A	PARTICIPANT	\N	PRESENT	0
422133	407837	14253S	PARTICIPANT	\N	PRESENT	0
422134	407837	01060R	PARTICIPANT	\N	PRESENT	0
422135	407837	19591F	PARTICIPANT	\N	PRESENT	0
422136	407837	11026G	PARTICIPANT	\N	PRESENT	0
422137	407837	14089Y	PARTICIPANT	\N	PRESENT	0
422138	407837	14123H	PARTICIPANT	\N	PRESENT	0
422139	407837	88008L	PARTICIPANT	\N	PRESENT	0
422414	407839	04044E	PARTICIPANT	\N	PRESENT	0
422415	407839	19782L	PARTICIPANT	\N	PRESENT	0
422416	407839	19681G	PARTICIPANT	\N	PRESENT	0
422417	407839	19585H	PARTICIPANT	\N	PRESENT	0
422418	407839	19713W	PARTICIPANT	\N	PRESENT	0
422419	407839	19737F	PARTICIPANT	\N	PRESENT	0
422420	407839	14079W	PARTICIPANT	\N	PRESENT	0
422421	407839	19747H	PARTICIPANT	\N	PRESENT	0
422422	407839	11031D	PARTICIPANT	\N	PRESENT	0
422423	407839	11090Q	PARTICIPANT	\N	PRESENT	0
422424	407839	19711U	PARTICIPANT	\N	PRESENT	0
422425	407839	14237S	PARTICIPANT	\N	PRESENT	0
422426	407839	08062Y	PARTICIPANT	\N	PRESENT	0
422427	407839	19507S	PARTICIPANT	\N	PRESENT	0
422428	407839	04088S	PARTICIPANT	\N	PRESENT	0
422429	407839	14109K	PARTICIPANT	\N	PRESENT	0
422430	407839	01043Q	PARTICIPANT	\N	PRESENT	0
422431	407839	19563B	PARTICIPANT	\N	PRESENT	0
422432	407839	19553Y	PARTICIPANT	\N	PRESENT	0
422433	407839	11077T	PARTICIPANT	\N	PRESENT	0
422434	407839	19599P	PARTICIPANT	\N	PRESENT	0
422435	407839	14157T	PARTICIPANT	\N	PRESENT	0
422436	407839	19383Y	PARTICIPANT	\N	PRESENT	0
422437	407839	14069U	PARTICIPANT	\N	PRESENT	0
422438	407839	14053L	PARTICIPANT	\N	PRESENT	0
422439	407839	95030B	PARTICIPANT	\N	PRESENT	0
422440	407839	14261S	PARTICIPANT	\N	PRESENT	0
422442	407839	88008L	PARTICIPANT	\N	PRESENT	0
422443	407839	08061X	PARTICIPANT	\N	PRESENT	0
422444	407839	01062T	PARTICIPANT	\N	PRESENT	0
422445	407839	04018C	PARTICIPANT	\N	PRESENT	0
422446	407839	19575F	PARTICIPANT	\N	PRESENT	0
422447	407839	14205J	PARTICIPANT	\N	PRESENT	0
422449	422441	19369B	PARTICIPANT	\N	PRESENT	0
422450	422441	08028W	PARTICIPANT	\N	PRESENT	0
422455	422441	19782L	PARTICIPANT	\N	PRESENT	0
422497	422486	19367Y	PARTICIPANT	\N	PRESENT	0
422498	422486	08060W	PARTICIPANT	\N	PRESENT	0
422499	422486	19758L	PARTICIPANT	\N	PRESENT	0
422500	422486	14053L	PARTICIPANT	\N	PRESENT	0
422501	422486	14033T	PARTICIPANT	\N	PRESENT	0
422502	422486	11048N	PARTICIPANT	\N	PRESENT	0
422503	422486	08009T	PARTICIPANT	\N	PRESENT	0
422504	422486	19826F	PARTICIPANT	\N	PRESENT	0
422505	422486	04070G	PARTICIPANT	\N	PRESENT	0
422506	422486	19413M	PARTICIPANT	\N	PRESENT	0
422507	422486	11065P	PARTICIPANT	\N	PRESENT	0
422508	422486	19733B	PARTICIPANT	\N	PRESENT	0
422510	422509	19515S	PARTICIPANT	\N	PRESENT	0
422511	422509	14105F	PARTICIPANT	\N	PRESENT	0
422512	422509	19782L	PARTICIPANT	\N	PRESENT	0
422513	422509	01025N	PARTICIPANT	\N	PRESENT	0
422514	422509	19820Y	PARTICIPANT	\N	PRESENT	0
422515	422509	14061L	PARTICIPANT	\N	PRESENT	0
422516	422509	04049K	PARTICIPANT	\N	PRESENT	0
422517	422509	08015R	PARTICIPANT	\N	PRESENT	0
422518	422509	14257W	PARTICIPANT	\N	PRESENT	0
422519	422509	19745F	PARTICIPANT	\N	PRESENT	0
422520	422509	19713W	PARTICIPANT	\N	PRESENT	0
422591	422589	14229S	PARTICIPANT	\N	PRESENT	0
422592	422589	19735D	PARTICIPANT	\N	PRESENT	0
422593	420689	19699S	PARTICIPANT	\N	PRESENT	0
422668	422667	08049C	PARTICIPANT	\N	PRESENT	0
422670	422669	08049C	PARTICIPANT	\N	PRESENT	0
422671	422669	04035D	PARTICIPANT	\N	PRESENT	0
422674	422673	88008L	PARTICIPANT	\N	PRESENT	0
422675	422673	11012A	PARTICIPANT	\N	PRESENT	0
422677	422676	14087W	PARTICIPANT	\N	PRESENT	0
422679	422678	19531S	PARTICIPANT	\N	PRESENT	0
422681	422680	19479G	PARTICIPANT	\N	PRESENT	0
422683	422682	19545Y	PARTICIPANT	\N	PRESENT	0
422684	422682	19689Q	PARTICIPANT	\N	PRESENT	0
422686	422685	11074Q	PARTICIPANT	\N	PRESENT	0
422691	422689	18083K	PARTICIPANT	\N	PRESENT	0
422692	422690	08011M	PARTICIPANT	\N	PRESENT	0
422694	422693	14121F	PARTICIPANT	\N	PRESENT	0
422695	422688	14093U	PARTICIPANT	\N	PRESENT	0
422696	422688	19820Y	PARTICIPANT	\N	PRESENT	0
422698	422697	14093U	PARTICIPANT	\N	PRESENT	0
422699	422697	19820Y	PARTICIPANT	\N	PRESENT	0
422700	422697	19387D	PARTICIPANT	\N	PRESENT	0
422724	422723	89017R	PARTICIPANT	\N	PRESENT	0
422725	422723	14331P	PARTICIPANT	\N	PRESENT	0
422727	422726	89017R	PARTICIPANT	\N	PRESENT	0
422737	422736	04086Q	PARTICIPANT	\N	PRESENT	0
422752	422751	19667J	PARTICIPANT	\N	PRESENT	0
422754	422751	11040E	PARTICIPANT	\N	PRESENT	0
422770	422763	19667J	PARTICIPANT	\N	PRESENT	0
422771	422763	11040E	PARTICIPANT	\N	PRESENT	0
422773	422772	19667J	PARTICIPANT	\N	PRESENT	0
422774	422772	11040E	PARTICIPANT	\N	PRESENT	0
402219	402123	19575F	PARTICIPANT	\N	EXCUSE	0
402220	402123	14030Q	PARTICIPANT	\N	EXCUSE	0
402221	402123	14105F	PARTICIPANT	\N	EXCUSE	0
402222	402123	08068F	PARTICIPANT	\N	EXCUSE	0
402223	402123	14053L	PARTICIPANT	\N	EXCUSE	0
402224	402123	14083S	PARTICIPANT	\N	PRESENT	0
402225	402123	19545Y	PARTICIPANT	\N	EXCUSE	0
402226	402123	14329V	PARTICIPANT	\N	PRESENT	0
402227	402123	14079W	PARTICIPANT	\N	EXCUSE	0
402228	402123	14041T	PARTICIPANT	\N	EXCUSE	0
402229	402123	14087W	PARTICIPANT	\N	EXCUSE	0
402230	402123	19521Q	PARTICIPANT	\N	EXCUSE	0
402231	402123	14034U	PARTICIPANT	\N	EXCUSE	0
402232	402123	14026U	PARTICIPANT	\N	EXCUSE	0
402234	402123	14121F	PARTICIPANT	\N	EXCUSE	0
402235	402123	14061L	PARTICIPANT	\N	EXCUSE	0
402237	402123	08015R	PARTICIPANT	\N	EXCUSE	0
402238	402123	19671E	PARTICIPANT	\N	PRESENT	0
402239	402123	14265W	PARTICIPANT	\N	PRESENT	0
402241	402123	04088S	PARTICIPANT	\N	PRESENT	0
402243	402123	14051J	PARTICIPANT	\N	PRESENT	0
402244	402123	14227Q	PARTICIPANT	\N	EXCUSE	0
402245	402123	14157T	PARTICIPANT	\N	EXCUSE	0
405476	405333	17583W	PARTICIPANT	\N	PRESENT	0
405473	402265	86034E	PARTICIPANT	\N	PRESENT	0
405474	405333	08009T	PARTICIPANT	\N	EXCUSE	0
405475	405333	14051J	PARTICIPANT	\N	EXCUSE	0
405477	405333	19701S	PARTICIPANT	\N	PRESENT	0
405478	405333	19713W	PARTICIPANT	\N	PRESENT	0
405479	405333	08024S	PARTICIPANT	\N	PRESENT	0
405480	405333	19794Q	PARTICIPANT	\N	PRESENT	0
405481	405333	19333N	PARTICIPANT	\N	PRESENT	0
405482	405333	19503N	PARTICIPANT	\N	PRESENT	0
405483	405333	19525U	PARTICIPANT	\N	PRESENT	0
405484	405333	08055A	PARTICIPANT	\N	PRESENT	0
405485	405333	14038Y	PRESIDENT	0	PRESENT	0
405486	405333	19637C	PARTICIPANT	\N	PRESENT	0
405487	405333	14103D	PARTICIPANT	\N	PRESENT	0
405488	405333	14031R	PARTICIPANT	\N	PRESENT	0
405489	405333	19387D	PARTICIPANT	\N	PRESENT	0
405490	405333	19599P	PARTICIPANT	\N	PRESENT	0
405491	405333	19551W	PARTICIPANT	\N	PRESENT	0
405492	405333	08060W	PARTICIPANT	\N	PRESENT	0
405493	405333	19733B	PARTICIPANT	\N	PRESENT	0
405494	405333	19347U	PARTICIPANT	\N	PRESENT	0
405495	405333	19739H	PARTICIPANT	\N	PRESENT	0
405496	405333	14157T	PARTICIPANT	\N	PRESENT	0
405497	405333	19681G	PARTICIPANT	\N	PRESENT	0
405646	402265	19798U	PARTICIPANT	\N	PRESENT	0
405647	402265	14071N	PARTICIPANT	\N	PRESENT	0
405648	402265	04092N	PARTICIPANT	\N	PRESENT	0
405649	402265	04086Q	PARTICIPANT	\N	PRESENT	0
405650	402265	14213J	PARTICIPANT	\N	PRESENT	0
405651	402265	19689Q	PARTICIPANT	\N	PRESENT	0
405652	402265	19421M	PARTICIPANT	\N	PRESENT	0
405653	402265	14026U	PARTICIPANT	\N	PRESENT	0
405654	402265	14237S	PARTICIPANT	\N	PRESENT	0
405655	402265	14193X	PARTICIPANT	\N	PRESENT	0
405656	402265	19367Y	PARTICIPANT	\N	PRESENT	0
405657	402265	19747H	PARTICIPANT	\N	PRESENT	0
405658	402265	19671E	PARTICIPANT	\N	PRESENT	0
405659	402265	11103C	PARTICIPANT	\N	PRESENT	0
405660	402265	08014Q	PARTICIPANT	\N	PRESENT	0
405661	402265	11085T	PARTICIPANT	\N	PRESENT	0
405662	402265	11099A	PARTICIPANT	\N	PRESENT	0
405663	402265	14231L	PARTICIPANT	\N	PRESENT	0
405664	402265	07033P	PARTICIPANT	\N	PRESENT	0
405665	402265	14079W	PARTICIPANT	\N	PRESENT	0
405666	402265	11104D	PARTICIPANT	\N	PRESENT	0
405667	402265	07029T	PARTICIPANT	\N	PRESENT	0
405668	402265	19507S	PARTICIPANT	\N	PRESENT	0
405669	402265	19553Y	PARTICIPANT	\N	PRESENT	0
405670	402265	19713W	PARTICIPANT	\N	PRESENT	0
405671	402265	04045F	PARTICIPANT	\N	PRESENT	0
405672	402265	19413M	PARTICIPANT	\N	PRESENT	0
405673	402265	80013X	PARTICIPANT	\N	PRESENT	0
405674	402265	11049P	PARTICIPANT	\N	PRESENT	0
405675	402265	14173T	PARTICIPANT	\N	PRESENT	0
405676	402265	19329S	PARTICIPANT	\N	PRESENT	0
405677	402265	19545Y	PARTICIPANT	\N	PRESENT	0
405678	402265	14111D	PARTICIPANT	\N	PRESENT	0
405679	402265	19415P	PARTICIPANT	\N	PRESENT	0
405680	402265	11041F	PARTICIPANT	\N	PRESENT	0
405804	405690	11033F	PARTICIPANT	\N	PRESENT	0
405805	405690	14235Q	PARTICIPANT	\N	PRESENT	0
405806	405690	19760E	PARTICIPANT	\N	PRESENT	0
405807	405690	19347U	PARTICIPANT	\N	PRESENT	0
405808	405690	14211G	PARTICIPANT	\N	PRESENT	0
405809	405690	19565D	PARTICIPANT	\N	PRESENT	0
405810	405690	14038Y	PARTICIPANT	\N	PRESENT	0
405811	405690	19695N	PARTICIPANT	\N	PRESENT	0
405812	405690	19593H	PARTICIPANT	\N	PRESENT	0
405813	405690	95063L	PARTICIPANT	\N	PRESENT	0
405814	405690	19443T	PARTICIPANT	\N	PRESENT	0
405815	405690	08061X	PARTICIPANT	\N	PRESENT	0
405816	405690	04034C	PARTICIPANT	\N	PRESENT	0
405817	405690	04045F	PARTICIPANT	\N	PRESENT	0
405818	405690	14029X	PARTICIPANT	\N	PRESENT	0
405819	405690	19651A	PARTICIPANT	\N	PRESENT	0
405820	405690	11083R	PARTICIPANT	\N	PRESENT	0
405821	405690	19637C	PARTICIPANT	\N	PRESENT	0
405822	405690	19663E	PARTICIPANT	\N	PRESENT	0
405823	405690	19349W	PARTICIPANT	\N	PRESENT	0
405824	405690	19269X	PARTICIPANT	\N	PRESENT	0
405825	405690	04088S	PARTICIPANT	\N	PRESENT	0
405826	405690	19812Y	PARTICIPANT	\N	PRESENT	0
405827	405690	14041T	PARTICIPANT	\N	PRESENT	0
405828	405690	19782L	PARTICIPANT	\N	PRESENT	0
405829	405690	08024S	PARTICIPANT	\N	PRESENT	0
405830	405690	07029T	PARTICIPANT	\N	PRESENT	0
405831	405690	19301E	PARTICIPANT	\N	PRESENT	0
405832	405690	19329S	PARTICIPANT	\N	PRESENT	0
405833	405690	19729F	PARTICIPANT	\N	PRESENT	0
405834	405690	19585H	PARTICIPANT	\N	PRESENT	0
405835	405690	14111D	PARTICIPANT	\N	PRESENT	0
405836	405690	08062Y	PARTICIPANT	\N	PRESENT	0
405837	405690	08015R	PARTICIPANT	\N	PRESENT	0
405838	405690	19697Q	PARTICIPANT	\N	PRESENT	0
405839	405690	19768N	PARTICIPANT	\N	PRESENT	0
405840	405690	19705W	PARTICIPANT	\N	PRESENT	0
405841	405690	98050T	PARTICIPANT	\N	PRESENT	0
405842	405690	14093U	PARTICIPANT	\N	PRESENT	0
405843	405690	19545Y	PARTICIPANT	\N	PRESENT	0
405844	405690	14195A	PARTICIPANT	\N	PRESENT	0
405845	405690	19733B	PARTICIPANT	\N	PRESENT	0
405846	405690	14251Q	PARTICIPANT	\N	PRESENT	0
405847	405690	19583F	PARTICIPANT	\N	PRESENT	0
405848	405690	19723Y	PARTICIPANT	\N	PRESENT	0
405849	405690	19507S	PARTICIPANT	\N	PRESENT	0
405850	405690	19563B	PARTICIPANT	\N	PRESENT	0
405851	405690	19467C	PARTICIPANT	\N	PRESENT	0
405852	405690	14135M	PARTICIPANT	\N	PRESENT	0
405853	405690	14261S	PARTICIPANT	\N	PRESENT	0
405854	405690	14033T	PARTICIPANT	\N	PRESENT	0
405855	405690	19415P	PARTICIPANT	\N	PRESENT	0
405856	405690	08019V	PARTICIPANT	\N	PRESENT	0
405857	405690	14034U	PARTICIPANT	\N	PRESENT	0
405858	405690	19399H	PARTICIPANT	\N	PRESENT	0
405859	405690	19693L	PARTICIPANT	\N	PRESENT	0
405860	405690	95037J	PARTICIPANT	\N	PRESENT	0
405861	405690	08048B	PARTICIPANT	\N	PRESENT	0
405862	405690	14265W	PARTICIPANT	\N	PRESENT	0
405863	405690	08049C	PARTICIPANT	\N	PRESENT	0
405864	405690	19253P	PARTICIPANT	\N	PRESENT	0
405865	405690	14329V	PARTICIPANT	\N	PRESENT	0
405866	405690	19629C	PARTICIPANT	\N	PRESENT	0
405867	405690	14201E	PARTICIPANT	\N	PRESENT	0
405868	405690	14213J	PARTICIPANT	\N	PRESENT	0
405869	405690	19387D	PARTICIPANT	\N	PRESENT	0
405870	405690	14357A	PARTICIPANT	\N	PRESENT	0
405871	405690	14241N	PARTICIPANT	\N	PRESENT	0
405872	405690	11065P	PARTICIPANT	\N	PRESENT	0
405873	405690	19383Y	PARTICIPANT	\N	PRESENT	0
405874	405690	19719D	PARTICIPANT	\N	PRESENT	0
405875	405690	14107H	PARTICIPANT	\N	PRESENT	0
405876	405690	19762G	PARTICIPANT	\N	PRESENT	0
405877	405690	19289C	PARTICIPANT	\N	PRESENT	0
405878	405690	04018C	PARTICIPANT	\N	PRESENT	0
405879	405690	14121F	PARTICIPANT	\N	PRESENT	0
405880	405690	19681G	PARTICIPANT	\N	PRESENT	0
405881	405690	19621T	PARTICIPANT	\N	PRESENT	0
405882	405690	04085P	PARTICIPANT	\N	PRESENT	0
405883	405690	11040E	PARTICIPANT	\N	PRESENT	0
405884	405690	19367Y	PARTICIPANT	\N	PRESENT	0
405885	405690	19573D	PARTICIPANT	\N	PRESENT	0
405886	405690	19794Q	PARTICIPANT	\N	PRESENT	0
405887	405690	12041X	PARTICIPANT	\N	PRESENT	0
405888	405690	92040Q	PARTICIPANT	\N	PRESENT	0
405889	405690	14119M	PARTICIPANT	\N	PRESENT	0
412740	402297	19543W	PARTICIPANT	\N	PRESENT	0
412741	402297	98050T	PARTICIPANT	\N	PRESENT	0
412742	402297	08034U	PARTICIPANT	\N	PRESENT	0
412743	402297	19573D	PARTICIPANT	\N	PRESENT	0
412744	402297	04049K	PARTICIPANT	\N	PRESENT	0
412745	402297	14069U	PARTICIPANT	\N	PRESENT	0
412746	402297	08068F	PARTICIPANT	\N	PRESENT	0
412747	402297	11101A	PARTICIPANT	\N	PRESENT	0
412748	402297	01048V	PARTICIPANT	\N	PRESENT	0
412753	402297	19521Q	PARTICIPANT	\N	PRESENT	0
412754	402297	19295A	PARTICIPANT	\N	PRESENT	0
412755	402297	19563B	PARTICIPANT	\N	PRESENT	0
412756	402297	08020N	PARTICIPANT	\N	PRESENT	0
412757	402297	11109J	PARTICIPANT	\N	PRESENT	0
412758	402297	19399H	PARTICIPANT	\N	PRESENT	0
412759	402297	19798U	PARTICIPANT	\N	PRESENT	0
412760	402297	10006L	PARTICIPANT	\N	PRESENT	0
412761	402297	14121F	PARTICIPANT	\N	PRESENT	0
412762	402297	19413M	PARTICIPANT	\N	PRESENT	0
412763	402297	14055N	PARTICIPANT	\N	PRESENT	0
412764	402297	19703U	PARTICIPANT	\N	PRESENT	0
412765	402297	11083R	PARTICIPANT	\N	PRESENT	0
412766	402297	14061L	PARTICIPANT	\N	PRESENT	0
412767	402297	08024S	PARTICIPANT	\N	PRESENT	0
412768	402297	15447F	PARTICIPANT	\N	PRESENT	0
412769	402297	19647E	PARTICIPANT	\N	PRESENT	0
412770	402297	16685X	PARTICIPANT	\N	PRESENT	0
412771	402297	19735D	PARTICIPANT	\N	PRESENT	0
412772	402297	08069G	PARTICIPANT	\N	PRESENT	0
412773	402297	14030Q	PARTICIPANT	\N	PRESENT	0
412774	402297	19489J	PARTICIPANT	\N	PRESENT	0
412775	402297	08043V	PARTICIPANT	\N	PRESENT	0
412776	402297	14331P	PARTICIPANT	\N	PRESENT	0
412783	411905	10006L	PARTICIPANT	\N	PRESENT	0
412784	411905	14147R	PARTICIPANT	\N	PRESENT	0
412785	411905	19629C	PARTICIPANT	\N	PRESENT	0
412786	402297	11072N	PARTICIPANT	\N	PRESENT	0
412787	402297	14179A	PARTICIPANT	\N	PRESENT	0
412788	402297	08049C	PARTICIPANT	\N	PRESENT	0
412789	402297	14133K	PARTICIPANT	\N	PRESENT	0
412793	402297	14199E	PARTICIPANT	\N	PRESENT	0
412794	402297	14259Y	PARTICIPANT	\N	PRESENT	0
412795	402297	14123H	PARTICIPANT	\N	PRESENT	0
412796	402297	14213J	PARTICIPANT	\N	PRESENT	0
412797	402297	14241N	PARTICIPANT	\N	PRESENT	0
412798	402297	11099A	PARTICIPANT	\N	PRESENT	0
412799	402297	19719D	PARTICIPANT	\N	PRESENT	0
412800	402297	14083S	PARTICIPANT	\N	PRESENT	0
412801	402297	14231L	PARTICIPANT	\N	PRESENT	0
412802	402297	19687N	PARTICIPANT	\N	PRESENT	0
412920	406845	04044E	PARTICIPANT	\N	PRESENT	0
412921	406845	11077T	PARTICIPANT	\N	PRESENT	0
412922	406845	11056N	PARTICIPANT	\N	PRESENT	0
412923	406845	19295A	PARTICIPANT	\N	PRESENT	0
412924	406845	11109J	PARTICIPANT	\N	PRESENT	0
412925	406845	08024S	PARTICIPANT	\N	PRESENT	0
412926	406845	88008L	PARTICIPANT	\N	PRESENT	0
412927	406845	19629C	PARTICIPANT	\N	PRESENT	0
412928	406845	14107H	PARTICIPANT	\N	PRESENT	0
412929	406845	19545Y	PARTICIPANT	\N	PRESENT	0
412930	406845	14241N	PARTICIPANT	\N	PRESENT	0
412931	406845	14195A	PARTICIPANT	\N	PRESENT	0
412932	406845	14001X	PARTICIPANT	\N	PRESENT	0
412933	406845	19347U	PARTICIPANT	\N	PRESENT	0
412934	406845	14231L	PARTICIPANT	\N	PRESENT	0
412935	406845	05008E	PARTICIPANT	\N	PRESENT	0
412936	406845	07029T	PARTICIPANT	\N	PRESENT	0
412937	406845	14033T	PARTICIPANT	\N	PRESENT	0
412938	406845	14031R	PARTICIPANT	\N	PRESENT	0
412939	406845	19768N	PARTICIPANT	\N	PRESENT	0
412940	406845	19599P	PARTICIPANT	\N	PRESENT	0
412941	406845	19719D	PARTICIPANT	\N	PRESENT	0
412942	406845	11012A	PARTICIPANT	\N	PRESENT	0
412943	406845	14215L	PARTICIPANT	\N	PRESENT	0
412944	406845	19737F	PARTICIPANT	\N	PRESENT	0
412945	406845	14083S	PARTICIPANT	\N	PRESENT	0
412946	406845	14331P	PARTICIPANT	\N	PRESENT	0
412947	406845	04069P	PARTICIPANT	\N	PRESENT	0
412948	406845	14061L	PARTICIPANT	\N	PRESENT	0
412949	406845	98050T	PARTICIPANT	\N	PRESENT	0
412950	406845	14059S	PARTICIPANT	\N	PRESENT	0
412951	406845	14147R	PARTICIPANT	\N	PRESENT	0
412952	406845	19575F	PARTICIPANT	\N	PRESENT	0
412953	406845	14135M	PARTICIPANT	\N	PRESENT	0
412954	406845	08019V	PARTICIPANT	\N	PRESENT	0
412955	406845	18083K	PARTICIPANT	\N	PRESENT	0
412956	406845	19794Q	PARTICIPANT	\N	PRESENT	0
412957	406845	19515S	PARTICIPANT	\N	PRESENT	0
412958	406845	15447F	PARTICIPANT	\N	PRESENT	0
412959	406845	19489J	PARTICIPANT	\N	PRESENT	0
412960	406845	19687N	PARTICIPANT	\N	PRESENT	0
412961	406845	19565D	PARTICIPANT	\N	PRESENT	0
412962	406845	19503N	PARTICIPANT	\N	PRESENT	0
412963	406845	14065Q	PARTICIPANT	\N	PRESENT	0
412964	406845	14207L	PARTICIPANT	\N	PRESENT	0
412965	406845	19543W	PARTICIPANT	\N	PRESENT	0
412966	406845	19549D	PARTICIPANT	\N	PRESENT	0
412967	406845	19479G	PARTICIPANT	\N	PRESENT	0
412968	406845	19335Q	PARTICIPANT	\N	PRESENT	0
412969	406845	14053L	PARTICIPANT	\N	PRESENT	0
412970	406845	19826F	PARTICIPANT	\N	PRESENT	0
412971	406845	14081Q	PARTICIPANT	\N	PRESENT	0
412972	406845	19725B	PARTICIPANT	\N	PRESENT	0
412973	406845	08061X	PARTICIPANT	\N	PRESENT	0
412974	406845	14121F	PARTICIPANT	\N	PRESENT	0
412975	406845	14219Q	PARTICIPANT	\N	PRESENT	0
412976	406845	11053K	PARTICIPANT	\N	PRESENT	0
412977	406845	04040A	PARTICIPANT	\N	PRESENT	0
412978	406845	11097X	PARTICIPANT	\N	PRESENT	0
412979	406845	19747H	PARTICIPANT	\N	PRESENT	0
412980	406845	01057W	PARTICIPANT	\N	PRESENT	0
412981	406845	14265W	PARTICIPANT	\N	PRESENT	0
412982	406845	11090Q	PARTICIPANT	\N	PRESENT	0
412983	406845	08034U	PARTICIPANT	\N	PRESENT	0
412984	406845	19533U	PARTICIPANT	\N	PRESENT	0
412985	406845	08010L	PARTICIPANT	\N	PRESENT	0
412986	406845	14259Y	PARTICIPANT	\N	PRESENT	0
412987	406845	14073Q	PARTICIPANT	\N	PRESENT	0
412988	406845	04088S	PARTICIPANT	\N	PRESENT	0
412989	406845	08069G	PARTICIPANT	\N	PRESENT	0
412990	406845	14123H	PARTICIPANT	\N	PRESENT	0
412991	406845	17637T	PARTICIPANT	\N	PRESENT	0
412992	406845	14211G	PARTICIPANT	\N	PRESENT	0
412993	406845	14038Y	PARTICIPANT	\N	PRESENT	0
412994	406845	19762G	PARTICIPANT	\N	PRESENT	0
412995	406845	14327T	PARTICIPANT	\N	PRESENT	0
412996	406845	19251M	PARTICIPANT	\N	PRESENT	0
412997	406845	14151M	PARTICIPANT	\N	PRESENT	0
412998	406845	14217N	PARTICIPANT	\N	PRESENT	0
412999	406845	14069U	PARTICIPANT	\N	PRESENT	0
413000	406845	11048N	PARTICIPANT	\N	PRESENT	0
413001	406845	14187A	PARTICIPANT	\N	PRESENT	0
413002	406845	04047H	PARTICIPANT	\N	PRESENT	0
413003	406845	19631V	PARTICIPANT	\N	PRESENT	0
413004	406845	14026U	PARTICIPANT	\N	PRESENT	0
413005	406845	14249W	PARTICIPANT	\N	PRESENT	0
413006	406845	19447X	PARTICIPANT	\N	PRESENT	0
413007	406845	19441R	PARTICIPANT	\N	PRESENT	0
413008	406845	11064N	PARTICIPANT	\N	PRESENT	0
413009	406845	08068F	PARTICIPANT	\N	PRESENT	0
413010	406845	19553Y	PARTICIPANT	\N	PRESENT	0
413011	406845	14251Q	PARTICIPANT	\N	PRESENT	0
413012	406845	14157T	PARTICIPANT	\N	PRESENT	0
413013	406845	19758L	PARTICIPANT	\N	PRESENT	0
413014	406845	14213J	PARTICIPANT	\N	PRESENT	0
412738	402297	08044W	PARTICIPANT	\N	PRESENT	0
412739	402297	11077T	PARTICIPANT	\N	PRESENT	0
394815	394813	14267Y	PARTICIPANT	\N	PRESENT	0
394872	394871	08010L	PARTICIPANT	\N	PRESENT	0
394876	394875	08053X	PARTICIPANT	\N	PRESENT	0
395776	391636	19569H	PARTICIPANT	\N	PRESENT	0
397608	397607	14239U	PARTICIPANT	\N	PRESENT	0
397609	397607	04040A	PARTICIPANT	\N	PRESENT	0
397610	397607	19647E	PARTICIPANT	\N	PRESENT	0
397613	397612	07033P	PARTICIPANT	\N	PRESENT	0
397614	397612	19651A	PARTICIPANT	\N	PRESENT	0
397616	397612	14179A	PARTICIPANT	\N	PRESENT	0
397617	397612	19551W	PARTICIPANT	\N	PRESENT	0
397618	397612	97011G	PARTICIPANT	\N	PRESENT	0
397619	397612	04086Q	PARTICIPANT	\N	PRESENT	0
397620	397612	11026G	PARTICIPANT	\N	PRESENT	0
397621	397612	14071N	PARTICIPANT	\N	PRESENT	0
397622	397612	19762G	PARTICIPANT	\N	PRESENT	0
397624	397623	07033P	PARTICIPANT	\N	PRESENT	0
397625	397623	18083K	PARTICIPANT	\N	PRESENT	0
397626	397623	14221J	PARTICIPANT	\N	PRESENT	0
401440	401365	04033B	PARTICIPANT	\N	PRESENT	0
397629	397628	07033P	PARTICIPANT	\N	PRESENT	0
397630	397628	04086Q	PARTICIPANT	\N	PRESENT	0
397631	397628	14179A	PARTICIPANT	\N	PRESENT	0
401451	401365	14041T	PARTICIPANT	\N	PRESENT	0
397634	397633	07033P	PARTICIPANT	\N	PRESENT	0
397635	397633	04042C	PARTICIPANT	\N	PRESENT	0
397636	397633	14179A	PARTICIPANT	\N	PRESENT	0
401452	401365	19647E	PARTICIPANT	\N	PRESENT	0
397639	397638	07033P	PARTICIPANT	\N	PRESENT	0
397640	397638	04043D	PARTICIPANT	\N	PRESENT	0
401453	401365	16685X	PARTICIPANT	\N	PRESENT	0
401454	401365	08039A	PARTICIPANT	\N	PRESENT	0
401455	401365	04035D	PARTICIPANT	\N	PRESENT	0
401456	401365	14187A	PARTICIPANT	\N	PRESENT	0
401457	401365	11026G	PARTICIPANT	\N	PRESENT	0
401458	401365	87003B	PARTICIPANT	\N	PRESENT	0
401459	401365	01058X	PARTICIPANT	\N	PRESENT	0
401460	401365	14031R	PARTICIPANT	\N	PRESENT	0
401461	401365	04040A	PARTICIPANT	\N	PRESENT	0
401462	401365	19545Y	PARTICIPANT	\N	PRESENT	0
401463	401365	98029W	PARTICIPANT	\N	PRESENT	0
401464	401365	19447X	PARTICIPANT	\N	PRESENT	0
404950	404949	08009T	PRESIDENT	0	PRESENT	0
404951	404949	05012A	PARTICIPANT	\N	EXCUSE	0
404952	404949	14051J	PARTICIPANT	\N	EXCUSE	0
404953	404949	19681G	PARTICIPANT	\N	EXCUSE	0
410832	410831	19415P	PARTICIPANT	\N	PRESENT	0
415400	406854	11072N	PARTICIPANT	\N	PRESENT	0
415401	406854	14021P	PARTICIPANT	\N	PRESENT	0
415402	406854	19573D	PARTICIPANT	\N	PRESENT	0
415403	406854	14225N	PARTICIPANT	\N	PRESENT	0
415404	406854	14173T	PARTICIPANT	\N	PRESENT	0
415405	406854	19794Q	PARTICIPANT	\N	PRESENT	0
415406	406854	08010L	PARTICIPANT	\N	PRESENT	0
415407	406854	92040Q	PARTICIPANT	\N	PRESENT	0
415408	406854	14119M	PARTICIPANT	\N	PRESENT	0
415409	406854	11049P	PARTICIPANT	\N	PRESENT	0
415410	406854	08047A	PARTICIPANT	\N	PRESENT	0
415411	406854	14105F	PARTICIPANT	\N	PRESENT	0
415412	406854	14147R	PARTICIPANT	\N	PRESENT	0
415413	406854	17583W	PARTICIPANT	\N	PRESENT	0
415414	406854	19723Y	PARTICIPANT	\N	PRESENT	0
415415	406854	19467C	PARTICIPANT	\N	PRESENT	0
415416	406854	18083K	PARTICIPANT	\N	PRESENT	0
415417	406854	19415P	PARTICIPANT	\N	PRESENT	0
415418	406854	19399H	PARTICIPANT	\N	PRESENT	0
415419	406854	19693L	PARTICIPANT	\N	PRESENT	0
415420	406854	14213J	PARTICIPANT	\N	PRESENT	0
415421	406854	08038Y	PARTICIPANT	\N	PRESENT	0
415422	406854	19741B	PARTICIPANT	\N	PRESENT	0
415423	406854	14029X	PARTICIPANT	\N	PRESENT	0
415424	406854	19709B	PARTICIPANT	\N	PRESENT	0
415425	406854	19669L	PARTICIPANT	\N	PRESENT	0
415426	406854	01062T	PARTICIPANT	\N	PRESENT	0
415427	406854	19663E	PARTICIPANT	\N	PRESENT	0
415428	406854	08060W	PARTICIPANT	\N	PRESENT	0
415429	406854	04088S	PARTICIPANT	\N	PRESENT	0
415430	406854	12016W	PARTICIPANT	\N	PRESENT	0
415431	406854	14041T	PARTICIPANT	\N	PRESENT	0
415432	406854	19507S	PARTICIPANT	\N	PRESENT	0
415433	406854	14028W	PARTICIPANT	\N	PRESENT	0
415434	406854	07029T	PARTICIPANT	\N	PRESENT	0
415435	406854	11045K	PARTICIPANT	\N	PRESENT	0
415436	406854	19657G	PARTICIPANT	\N	PRESENT	0
415437	406854	08062Y	PARTICIPANT	\N	PRESENT	0
415438	406854	19768N	PARTICIPANT	\N	PRESENT	0
415439	406854	08035V	PARTICIPANT	\N	PRESENT	0
415440	406854	19705W	PARTICIPANT	\N	PRESENT	0
415441	406854	19347U	PARTICIPANT	\N	PRESENT	0
415442	406854	08012N	PARTICIPANT	\N	PRESENT	0
415443	406854	98050T	PARTICIPANT	\N	PRESENT	0
415444	406854	19729F	PARTICIPANT	\N	PRESENT	0
415445	406854	19820Y	PARTICIPANT	\N	PRESENT	0
415446	406854	19689Q	PARTICIPANT	\N	PRESENT	0
415447	406854	14061L	PARTICIPANT	\N	PRESENT	0
415448	406854	14059S	PARTICIPANT	\N	PRESENT	0
415449	406854	11110B	PARTICIPANT	\N	PRESENT	0
415450	406854	19525U	PARTICIPANT	\N	PRESENT	0
415451	406854	14329V	PARTICIPANT	\N	PRESENT	0
415452	406854	08053X	PARTICIPANT	\N	PRESENT	0
415453	406854	14357A	PARTICIPANT	\N	PRESENT	0
415454	406854	08017T	PARTICIPANT	\N	PRESENT	0
415455	406854	14085U	PARTICIPANT	\N	PRESENT	0
415456	406854	19383Y	PARTICIPANT	\N	PRESENT	0
415457	406854	14065Q	PARTICIPANT	\N	PRESENT	0
415458	406854	08058D	PARTICIPANT	\N	PRESENT	0
415459	406854	17779H	PARTICIPANT	\N	PRESENT	0
415460	406854	19549D	PARTICIPANT	\N	PRESENT	0
415461	406854	19725B	PARTICIPANT	\N	PRESENT	0
415462	406854	14331P	PARTICIPANT	\N	PRESENT	0
415463	406854	14079W	PARTICIPANT	\N	PRESENT	0
415464	406854	19581D	PARTICIPANT	\N	PRESENT	0
415465	406854	11067R	PARTICIPANT	\N	PRESENT	0
415466	406854	11109J	PARTICIPANT	\N	PRESENT	0
415467	406854	11026G	PARTICIPANT	\N	PRESENT	0
415468	406854	19631V	PARTICIPANT	\N	PRESENT	0
415469	406854	19527W	PARTICIPANT	\N	PRESENT	0
415470	406854	19503N	PARTICIPANT	\N	PRESENT	0
415471	406854	19591F	PARTICIPANT	\N	PRESENT	0
415472	406854	05012A	PARTICIPANT	\N	PRESENT	0
415473	406854	11054L	PARTICIPANT	\N	PRESENT	0
415474	406854	08034U	PARTICIPANT	\N	PRESENT	0
415475	406854	19251M	PARTICIPANT	\N	PRESENT	0
415476	406854	19413M	PARTICIPANT	\N	PRESENT	0
415477	406854	10006L	PARTICIPANT	\N	PRESENT	0
415478	406854	19569H	PARTICIPANT	\N	PRESENT	0
415479	406854	14179A	PARTICIPANT	\N	PRESENT	0
415480	406854	14231L	PARTICIPANT	\N	PRESENT	0
415481	406854	11043H	PARTICIPANT	\N	PRESENT	0
415482	406854	11099A	PARTICIPANT	\N	PRESENT	0
415483	406854	01034P	PARTICIPANT	\N	PRESENT	0
415484	406854	04043D	PARTICIPANT	\N	PRESENT	0
415485	406854	19369B	PARTICIPANT	\N	PRESENT	0
415486	406854	19691J	PARTICIPANT	\N	PRESENT	0
415487	406854	14069U	PARTICIPANT	\N	PRESENT	0
415488	406854	14053L	PARTICIPANT	\N	PRESENT	0
415489	406854	19611R	PARTICIPANT	\N	PRESENT	0
415490	406854	11053K	PARTICIPANT	\N	PRESENT	0
415491	406854	14087W	PARTICIPANT	\N	PRESENT	0
415492	406854	19511N	PARTICIPANT	\N	PRESENT	0
415493	406854	08044W	PARTICIPANT	\N	PRESENT	0
415494	406854	19721W	PARTICIPANT	\N	PRESENT	0
415495	406854	04033B	PARTICIPANT	\N	PRESENT	0
415496	406854	14187A	PARTICIPANT	\N	PRESENT	0
415497	406854	14071N	PARTICIPANT	\N	PRESENT	0
415498	406854	07004J	PARTICIPANT	\N	PRESENT	0
415499	406854	11097X	PARTICIPANT	\N	PRESENT	0
415500	406854	19739H	PARTICIPANT	\N	PRESENT	0
415501	406854	19735D	PARTICIPANT	\N	PRESENT	0
415502	406854	16685X	PARTICIPANT	\N	PRESENT	0
415503	406854	95041E	PARTICIPANT	\N	PRESENT	0
415504	406854	19553Y	PARTICIPANT	\N	PRESENT	0
415505	406854	14251Q	PARTICIPANT	\N	PRESENT	0
415506	406854	04044E	PARTICIPANT	\N	PRESENT	0
415507	406854	14219Q	PARTICIPANT	\N	PRESENT	0
415508	406854	19479G	PARTICIPANT	\N	PRESENT	0
415509	406854	19319Q	PARTICIPANT	\N	PRESENT	0
415510	406854	19441R	PARTICIPANT	\N	PRESENT	0
415511	406854	14026U	PARTICIPANT	\N	PRESENT	0
415512	406854	14275Y	PARTICIPANT	\N	PRESENT	0
415513	406854	14205J	PARTICIPANT	\N	PRESENT	0
415514	406854	98024R	PARTICIPANT	\N	PRESENT	0
415515	406854	08009T	PARTICIPANT	\N	PRESENT	0
415516	406854	14103D	PARTICIPANT	\N	PRESENT	0
415517	406854	86034E	PARTICIPANT	\N	PRESENT	0
415518	406854	89017R	PARTICIPANT	\N	PRESENT	0
415519	406854	19335Q	PARTICIPANT	\N	PRESENT	0
415520	406854	19747H	PARTICIPANT	\N	PRESENT	0
415521	406854	19745F	PARTICIPANT	\N	PRESENT	0
421830	421829	14147R	PARTICIPANT	\N	PRESENT	0
423677	422452	14087W	PARTICIPANT	\N	PRESENT	0
423678	422452	14042U	PARTICIPANT	\N	PRESENT	0
423679	422452	19575F	PARTICIPANT	\N	PRESENT	0
423680	422452	08048B	PARTICIPANT	\N	PRESENT	0
423681	422452	14195A	PARTICIPANT	\N	PRESENT	0
423682	422452	19367Y	PARTICIPANT	\N	PRESENT	0
423683	422452	14213J	PARTICIPANT	\N	PRESENT	0
423684	422452	14217N	PARTICIPANT	\N	PRESENT	0
423685	422452	10006L	PARTICIPANT	\N	PRESENT	0
423686	422452	19683J	PARTICIPANT	\N	PRESENT	0
423687	422452	98024R	PARTICIPANT	\N	PRESENT	0
423688	422452	19521Q	PARTICIPANT	\N	PRESENT	0
423689	422452	01034P	PARTICIPANT	\N	PRESENT	0
423690	422452	04092N	PRESIDENT	0	PRESENT	0
423691	422452	08052W	PARTICIPANT	\N	PRESENT	0
423692	422452	19301E	PARTICIPANT	\N	PRESENT	0
423693	422452	19715Y	PARTICIPANT	\N	PRESENT	0
423694	422452	19691J	PARTICIPANT	\N	PRESENT	0
423695	422452	19717B	PARTICIPANT	\N	PRESENT	0
423696	422452	19723Y	PARTICIPANT	\N	PRESENT	0
423697	422452	19727D	PARTICIPANT	\N	PRESENT	0
423698	422452	14119M	PARTICIPANT	\N	PRESENT	0
423699	422452	11103C	PARTICIPANT	\N	PRESENT	0
423700	422452	14071N	PARTICIPANT	\N	PRESENT	0
423701	422452	19760E	PARTICIPANT	\N	PRESENT	0
423702	422452	19565D	PARTICIPANT	\N	EXCUSE	0
423703	422452	08041T	PARTICIPANT	\N	EXCUSE	0
423704	422488	11110B	PARTICIPANT	\N	PRESENT	0
423705	422488	08073C	PARTICIPANT	\N	PRESENT	0
423706	422488	14083S	PARTICIPANT	\N	PRESENT	0
423707	422488	14034U	PARTICIPANT	\N	PRESENT	0
423708	422488	11048N	PARTICIPANT	\N	PRESENT	0
423709	414419	08012N	PARTICIPANT	\N	EXCUSE	0
423749	422672	04042C	PRESIDENT	1	PRESENT	0
423750	422672	14255U	PARTICIPANT	\N	PRESENT	0
423751	422672	98018T	PARTICIPANT	\N	EXCUSE	0
423752	422488	08010L	PARTICIPANT	\N	PRESENT	0
423753	422672	95067Q	PARTICIPANT	\N	PRESENT	0
423754	421729	14195A	PARTICIPANT	\N	EXCUSE	0
423755	423511	19766L	PARTICIPANT	\N	PRESENT	0
423756	423511	04070G	PRESIDENT	0	PRESENT	0
423757	423511	19699S	PARTICIPANT	\N	PRESENT	0
423758	423511	19533U	PARTICIPANT	\N	PRESENT	0
423759	423511	04033B	PARTICIPANT	\N	PRESENT	0
423760	423511	14229S	PARTICIPANT	\N	PRESENT	0
423761	423511	14241N	PARTICIPANT	\N	PRESENT	0
423762	423511	19573D	PARTICIPANT	\N	PRESENT	0
423763	423511	14107H	PARTICIPANT	\N	PRESENT	0
423764	423511	08017T	PARTICIPANT	\N	PRESENT	0
423765	423511	92040Q	PARTICIPANT	\N	PRESENT	0
423766	423511	07033P	PARTICIPANT	\N	PRESENT	0
423767	423511	08012N	PARTICIPANT	\N	PRESENT	0
423768	423511	19335Q	PARTICIPANT	\N	PRESENT	0
423769	423511	14249W	PARTICIPANT	\N	PRESENT	0
423770	423511	08039A	PARTICIPANT	\N	PRESENT	0
423771	423511	08031R	PARTICIPANT	\N	PRESENT	0
423772	423511	14059S	PARTICIPANT	\N	PRESENT	0
423773	423511	19643A	PARTICIPANT	\N	PRESENT	0
423774	423511	14061L	PARTICIPANT	\N	PRESENT	0
423775	423511	04057K	PARTICIPANT	\N	PRESENT	0
423776	423511	14073Q	PARTICIPANT	\N	PRESENT	0
423777	423511	19611R	PARTICIPANT	\N	PRESENT	0
423778	423511	08035V	PARTICIPANT	\N	PRESENT	0
423779	423511	08043V	PARTICIPANT	\N	PRESENT	0
423780	423511	19693L	PARTICIPANT	\N	PRESENT	0
423781	423511	87003B	PARTICIPANT	\N	PRESENT	0
423782	423511	19399H	PARTICIPANT	\N	PRESENT	0
423783	423511	14201E	PARTICIPANT	\N	PRESENT	0
423784	423511	14030Q	PARTICIPANT	\N	PRESENT	0
423785	423511	19731Y	PARTICIPANT	\N	PRESENT	0
423786	423511	08020N	PARTICIPANT	\N	PRESENT	0
423787	423511	14251Q	PARTICIPANT	\N	PRESENT	0
423788	423511	04059M	PARTICIPANT	\N	PRESENT	0
423789	423511	19735D	PARTICIPANT	\N	PRESENT	0
423790	423511	14063N	PARTICIPANT	\N	PRESENT	0
423791	423511	11083R	PARTICIPANT	\N	PRESENT	0
423792	423511	14109K	PARTICIPANT	\N	PRESENT	0
423793	423511	11104D	PARTICIPANT	\N	PRESENT	0
423794	423511	11043H	PARTICIPANT	\N	PRESENT	0
423795	423511	04018C	PARTICIPANT	\N	PRESENT	0
423796	423511	19758L	PARTICIPANT	\N	PRESENT	0
423797	423511	19621T	PARTICIPANT	\N	PRESENT	0
423798	423511	19593H	PARTICIPANT	\N	EXCUSE	0
423799	421729	04044E	PARTICIPANT	\N	EXCUSE	0
423800	422959	14001X	PARTICIPANT	\N	PRESENT	0
423801	422959	19543W	PARTICIPANT	\N	PRESENT	0
423802	422959	04044E	PARTICIPANT	\N	PRESENT	0
423803	422959	19585H	PARTICIPANT	\N	PRESENT	0
423804	422959	19673G	PARTICIPANT	\N	PRESENT	0
423805	422959	01028R	PARTICIPANT	\N	PRESENT	0
423806	422959	19447X	PARTICIPANT	\N	PRESENT	0
423807	422959	14231L	PARTICIPANT	\N	PRESENT	0
423808	422959	19489J	PARTICIPANT	\N	PRESENT	0
423809	422959	14041T	PARTICIPANT	\N	PRESENT	0
423810	422959	14147R	PARTICIPANT	\N	PRESENT	0
423811	422959	14179A	PARTICIPANT	\N	PRESENT	0
423812	422959	14215L	PRESIDENT	0	PRESENT	0
423813	422959	08018U	PARTICIPANT	\N	PRESENT	0
423814	422959	14053L	PARTICIPANT	\N	PRESENT	0
423815	422959	98035U	PARTICIPANT	\N	PRESENT	0
423816	422959	14111D	PARTICIPANT	\N	PRESENT	0
423817	422959	14065Q	PARTICIPANT	\N	PRESENT	0
423818	422959	19649G	PARTICIPANT	\N	PRESENT	0
423819	422959	10015M	PARTICIPANT	\N	PRESENT	0
423820	422959	11026G	PARTICIPANT	\N	PRESENT	0
423821	422959	01024M	PARTICIPANT	\N	PRESENT	0
423822	422959	04038G	PARTICIPANT	\N	PRESENT	0
423823	422959	19719D	PARTICIPANT	\N	PRESENT	0
423824	422959	19725B	PARTICIPANT	\N	PRESENT	0
423825	422959	14089Y	PARTICIPANT	\N	PRESENT	0
423826	422959	19729F	PARTICIPANT	\N	PRESENT	0
423827	422959	95063L	PARTICIPANT	\N	PRESENT	0
423828	422959	19629C	PARTICIPANT	\N	PRESENT	0
423829	422959	14069U	PARTICIPANT	\N	PRESENT	0
423830	422959	11049P	PARTICIPANT	\N	PRESENT	0
423831	422959	19762G	PARTICIPANT	\N	PRESENT	0
423832	422959	14021P	PARTICIPANT	\N	PRESENT	0
423833	422959	19253P	PARTICIPANT	\N	PRESENT	0
423834	422959	08044W	PARTICIPANT	\N	EXCUSE	0
423835	422959	08045X	PARTICIPANT	\N	EXCUSE	0
423837	422959	19581D	PARTICIPANT	\N	EXCUSE	0
423838	422959	14259Y	PARTICIPANT	\N	EXCUSE	0
423839	422959	19675J	PARTICIPANT	\N	PRESENT	0
423840	422959	05008E	PARTICIPANT	\N	EXCUSE	0
423841	422959	11072N	PARTICIPANT	\N	EXCUSE	0
423842	423511	14123H	PARTICIPANT	\N	PRESENT	0
423849	422488	04071H	PARTICIPANT	\N	PRESENT	0
423850	422959	11033F	PARTICIPANT	\N	PRESENT	0
423851	422959	04008A	PARTICIPANT	\N	PRESENT	0
423855	420722	19333N	PARTICIPANT	\N	PRESENT	0
423856	420722	19383Y	PARTICIPANT	\N	PRESENT	0
423857	420722	17583W	PARTICIPANT	\N	PRESENT	0
423858	420722	19794Q	PARTICIPANT	\N	PRESENT	0
423859	420722	19387D	PARTICIPANT	\N	PRESENT	0
423860	420722	19820Y	PARTICIPANT	\N	PRESENT	0
423861	420722	14219Q	PARTICIPANT	\N	PRESENT	0
423862	420722	14221J	PARTICIPANT	\N	PRESENT	0
423863	420722	19826F	PARTICIPANT	\N	PRESENT	0
423864	420722	19599P	PARTICIPANT	\N	PRESENT	0
423865	420722	19637C	PARTICIPANT	\N	PRESENT	0
423866	420722	19551W	PARTICIPANT	\N	PRESENT	0
423867	420722	14237S	PARTICIPANT	\N	PRESENT	0
423868	420722	05012A	PARTICIPANT	\N	PRESENT	0
423869	420722	08060W	PARTICIPANT	\N	PRESENT	0
423870	420722	19347U	PARTICIPANT	\N	PRESENT	0
423871	420722	19503N	PARTICIPANT	\N	PRESENT	0
423872	420722	14157T	PARTICIPANT	\N	PRESENT	0
423873	420722	08024S	PARTICIPANT	\N	PRESENT	0
423874	420722	19681G	PARTICIPANT	\N	PRESENT	0
423875	420722	14038Y	PRESIDENT	0	PRESENT	0
423876	420722	14103D	PARTICIPANT	\N	PRESENT	0
423877	420722	14031R	PARTICIPANT	\N	PRESENT	0
423878	420722	08055A	PARTICIPANT	\N	PRESENT	0
423879	420722	14169X	PARTICIPANT	\N	PRESENT	0
423880	420722	15447F	PARTICIPANT	\N	PRESENT	0
423881	420722	14029X	PARTICIPANT	\N	PRESENT	0
423882	420722	08009T	PRESIDENT	1	PRESENT	0
423883	420722	19737F	PARTICIPANT	\N	PRESENT	0
423884	420722	19739H	PARTICIPANT	\N	PRESENT	0
423885	420722	04097T	PARTICIPANT	\N	PRESENT	0
423886	420722	14093U	PARTICIPANT	\N	EXCUSE	0
423887	420722	14051J	PARTICIPANT	\N	EXCUSE	0
423889	422959	04047H	PARTICIPANT	\N	PRESENT	0
423890	422959	11085T	PARTICIPANT	\N	PRESENT	0
423892	420720	08009T	PARTICIPANT	\N	EXCUSE	0
423894	422672	19421M	PARTICIPANT	\N	PRESENT	0
395788	392653	08015R	PARTICIPANT	\N	EXCUSE	0
397740	397739	05008E	PRESIDENT	0	PRESENT	0
397741	397739	19543W	PARTICIPANT	\N	PRESENT	0
397758	397757	14133K	PARTICIPANT	\N	PRESENT	0
397759	397757	19631V	PARTICIPANT	\N	PRESENT	0
397744	397739	19719D	PARTICIPANT	\N	PRESENT	0
397745	397739	14041T	PARTICIPANT	\N	PRESENT	0
397746	397739	14215L	PARTICIPANT	\N	PRESENT	0
397747	397739	14151M	PARTICIPANT	\N	PRESENT	0
405892	405690	19758L	PARTICIPANT	\N	PRESENT	0
397749	397739	14231L	PARTICIPANT	\N	PRESENT	0
397750	397739	14179A	PARTICIPANT	\N	PRESENT	0
405893	405690	08047A	PARTICIPANT	\N	PRESENT	0
397752	397739	01028R	PARTICIPANT	\N	PRESENT	0
405894	405690	11031D	PARTICIPANT	\N	PRESENT	0
405895	405690	17583W	PARTICIPANT	\N	PRESENT	0
405896	405690	14147R	PARTICIPANT	\N	PRESENT	0
397764	397757	14205J	PARTICIPANT	\N	PRESENT	0
397765	397757	08053X	PARTICIPANT	\N	PRESENT	0
397766	397757	14257W	PARTICIPANT	\N	PRESENT	0
397767	397757	14265W	PARTICIPANT	\N	PRESENT	0
405890	405690	19687N	PARTICIPANT	\N	PRESENT	0
397769	397757	11090Q	PARTICIPANT	\N	PRESENT	0
397770	397757	04043D	PARTICIPANT	\N	PRESENT	0
397771	397757	19269X	PARTICIPANT	\N	PRESENT	0
405897	405690	97011G	PARTICIPANT	\N	PRESENT	0
405898	405690	04057K	PARTICIPANT	\N	PRESENT	0
405899	405690	11103C	PARTICIPANT	\N	PRESENT	0
405900	405690	07033P	PARTICIPANT	\N	PRESENT	0
405901	405690	04059M	PARTICIPANT	\N	PRESENT	0
405902	405690	14217N	PARTICIPANT	\N	PRESENT	0
405903	405690	11027H	PARTICIPANT	\N	PRESENT	0
405904	405690	14331P	PARTICIPANT	\N	PRESENT	0
405905	405690	11074Q	PARTICIPANT	\N	PRESENT	0
405906	405690	08055A	PARTICIPANT	\N	PRESENT	0
405907	405690	19671E	PARTICIPANT	\N	PRESENT	0
405908	405690	14229S	PARTICIPANT	\N	PRESENT	0
405909	405690	19747H	PARTICIPANT	\N	PRESENT	0
405910	405690	08052W	PARTICIPANT	\N	PRESENT	0
405911	405690	14237S	PARTICIPANT	\N	PRESENT	0
405912	405690	14207L	PARTICIPANT	\N	PRESENT	0
405913	405690	14193X	PARTICIPANT	\N	PRESENT	0
405914	405690	08068F	PARTICIPANT	\N	PRESENT	0
405915	405690	19798U	PARTICIPANT	\N	PRESENT	0
405916	405690	01028R	PARTICIPANT	\N	PRESENT	0
405917	405690	19533U	PARTICIPANT	\N	PRESENT	0
405918	405690	08034U	PARTICIPANT	\N	PRESENT	0
405891	405690	11049P	PARTICIPANT	\N	PRESENT	0
405919	405690	05012A	PARTICIPANT	\N	PRESENT	0
405920	405690	14151M	PARTICIPANT	\N	PRESENT	0
405921	405690	14197C	PARTICIPANT	\N	PRESENT	0
405922	405690	14069U	PARTICIPANT	\N	PRESENT	0
405923	405690	04042C	PARTICIPANT	\N	PRESENT	0
405924	405690	14021P	PARTICIPANT	\N	PRESENT	0
405925	405690	19669L	PARTICIPANT	\N	PRESENT	0
405926	405690	04049K	PARTICIPANT	\N	PRESENT	0
405927	405690	14225N	PARTICIPANT	\N	PRESENT	0
405928	405690	11048N	PARTICIPANT	\N	PRESENT	0
405929	405690	14253S	PARTICIPANT	\N	PRESENT	0
405930	405690	19599P	PARTICIPANT	\N	PRESENT	0
405931	405690	19575F	PARTICIPANT	\N	PRESENT	0
405932	405690	01062T	PARTICIPANT	\N	PRESENT	0
405933	405690	14031R	PARTICIPANT	\N	PRESENT	0
405934	405690	19703U	PARTICIPANT	\N	PRESENT	0
405935	405690	19715Y	PARTICIPANT	\N	PRESENT	0
405936	405690	80013X	PARTICIPANT	\N	PRESENT	0
405937	405690	19515S	PARTICIPANT	\N	PRESENT	0
405938	405690	19649G	PARTICIPANT	\N	PRESENT	0
405939	405690	11080N	PARTICIPANT	\N	PRESENT	0
405940	405690	11041F	PARTICIPANT	\N	PRESENT	0
405941	405690	19766L	PARTICIPANT	\N	PRESENT	0
405942	405690	19647E	PARTICIPANT	\N	PRESENT	0
405943	405690	11066Q	PARTICIPANT	\N	PRESENT	0
405944	405690	01057W	PARTICIPANT	\N	PRESENT	0
405945	405690	08043V	PARTICIPANT	\N	PRESENT	0
405946	405690	87003B	PARTICIPANT	\N	PRESENT	0
405947	405690	11104D	PARTICIPANT	\N	PRESENT	0
405948	405690	95067Q	PARTICIPANT	\N	PRESENT	0
405949	405690	08035V	PARTICIPANT	\N	PRESENT	0
405950	405690	04043D	PARTICIPANT	\N	PRESENT	0
405951	405690	08012N	PARTICIPANT	\N	PRESENT	0
405952	405690	14249W	PARTICIPANT	\N	PRESENT	0
405953	405690	15447F	PARTICIPANT	\N	PRESENT	0
405954	405690	19727D	PARTICIPANT	\N	PRESENT	0
405955	405690	19643A	PARTICIPANT	\N	PRESENT	0
405956	405690	04071H	PARTICIPANT	\N	PRESENT	0
405957	405690	14081Q	PARTICIPANT	\N	PRESENT	0
405958	405690	14223L	PARTICIPANT	\N	PRESENT	0
405959	405690	19820Y	PARTICIPANT	\N	PRESENT	0
405960	405690	19525U	PARTICIPANT	\N	PRESENT	0
405961	405690	19689Q	PARTICIPANT	\N	PRESENT	0
405962	405690	14169X	PARTICIPANT	\N	PRESENT	0
405963	405690	14085U	PARTICIPANT	\N	PRESENT	0
405964	405690	19531S	PARTICIPANT	\N	PRESENT	0
405965	405690	08028W	PARTICIPANT	\N	PRESENT	0
405966	405690	17779H	PARTICIPANT	\N	PRESENT	0
405967	405690	04033B	PARTICIPANT	\N	PRESENT	0
405968	405690	19549D	PARTICIPANT	\N	PRESENT	0
405969	405690	14187A	PARTICIPANT	\N	PRESENT	0
405970	405690	19725B	PARTICIPANT	\N	PRESENT	0
405971	405690	14071N	PARTICIPANT	\N	PRESENT	0
405972	405690	08014Q	PARTICIPANT	\N	PRESENT	0
405973	405690	11097X	PARTICIPANT	\N	PRESENT	0
405974	405690	19421M	PARTICIPANT	\N	PRESENT	0
405975	405690	19333N	PARTICIPANT	\N	PRESENT	0
405976	405690	04092N	PARTICIPANT	\N	PRESENT	0
405977	405690	14227Q	PARTICIPANT	\N	PRESENT	0
405978	405690	14001X	PARTICIPANT	\N	PRESENT	0
405979	405690	04086Q	PARTICIPANT	\N	PRESENT	0
405980	405690	08069G	PARTICIPANT	\N	PRESENT	0
405981	405690	14257W	PARTICIPANT	\N	PRESENT	0
405982	405690	19683J	PARTICIPANT	\N	PRESENT	0
405983	405690	14123H	PARTICIPANT	\N	PRESENT	0
405984	405690	11109J	PARTICIPANT	\N	PRESENT	0
405985	405690	19295A	PARTICIPANT	\N	PRESENT	0
405986	405690	08010L	PARTICIPANT	\N	PRESENT	0
405987	405690	08039A	PARTICIPANT	\N	PRESENT	0
405988	405690	14063N	PARTICIPANT	\N	PRESENT	0
405989	405690	14097Y	PARTICIPANT	\N	PRESENT	0
405990	405690	04097T	PARTICIPANT	\N	PRESENT	0
405991	405690	19679N	PARTICIPANT	\N	PRESENT	0
405992	405690	11067R	PARTICIPANT	\N	PRESENT	0
405993	405690	19527W	PARTICIPANT	\N	PRESENT	0
405994	405690	17637T	PARTICIPANT	\N	PRESENT	0
405995	405690	19551W	PARTICIPANT	\N	PRESENT	0
405996	405690	08011M	PARTICIPANT	\N	PRESENT	0
405997	405690	14109K	PARTICIPANT	\N	PRESENT	0
405998	405690	19503N	PARTICIPANT	\N	PRESENT	0
405999	405690	96004D	PARTICIPANT	\N	PRESENT	0
406000	405690	19591F	PARTICIPANT	\N	PRESENT	0
406001	405690	14157T	PARTICIPANT	\N	PRESENT	0
406002	405690	19251M	PARTICIPANT	\N	PRESENT	0
406003	405690	01058X	PARTICIPANT	\N	PRESENT	0
406004	405690	19413M	PARTICIPANT	\N	PRESENT	0
406005	405690	99004R	PARTICIPANT	\N	PRESENT	0
406006	405690	95030B	PARTICIPANT	\N	PRESENT	0
406007	405690	14231L	PARTICIPANT	\N	PRESENT	0
406008	405690	04047H	PARTICIPANT	\N	PRESENT	0
406009	405690	14179A	PARTICIPANT	\N	PRESENT	0
406010	405690	08044W	PARTICIPANT	\N	PRESENT	0
406011	405690	14026U	PARTICIPANT	\N	PRESENT	0
406012	405690	01034P	PARTICIPANT	\N	PRESENT	0
406013	405690	04035D	PARTICIPANT	\N	PRESENT	0
406014	405690	19369B	PARTICIPANT	\N	PRESENT	0
406015	405690	19691J	PARTICIPANT	\N	PRESENT	0
406016	405690	98024R	PARTICIPANT	\N	PRESENT	0
406017	405690	08009T	PARTICIPANT	\N	PRESENT	0
406018	405690	86034E	PARTICIPANT	\N	PRESENT	0
406019	405690	19611R	PARTICIPANT	\N	PRESENT	0
406020	405690	19711U	PARTICIPANT	\N	PRESENT	0
406021	405690	19511N	PARTICIPANT	\N	PRESENT	0
406022	405690	19619A	PARTICIPANT	\N	PRESENT	0
406023	405690	14281W	PARTICIPANT	\N	PRESENT	0
406024	405690	19699S	PARTICIPANT	\N	PRESENT	0
406025	405690	19721W	PARTICIPANT	\N	PRESENT	0
406026	405690	19737F	PARTICIPANT	\N	PRESENT	0
406027	405690	14205J	PARTICIPANT	\N	PRESENT	0
406028	405690	08020N	PARTICIPANT	\N	PRESENT	0
406029	405690	08018U	PARTICIPANT	\N	PRESENT	0
406030	405690	16685X	PARTICIPANT	\N	PRESENT	0
406031	405690	19701S	PARTICIPANT	\N	PRESENT	0
406032	405690	19739H	PARTICIPANT	\N	PRESENT	0
406033	405690	19735D	PARTICIPANT	\N	PRESENT	0
406034	405690	14042U	PARTICIPANT	\N	PRESENT	0
406035	405690	14219Q	PARTICIPANT	\N	PRESENT	0
406036	405690	19479G	PARTICIPANT	\N	PRESENT	0
406037	405690	19441R	PARTICIPANT	\N	PRESENT	0
406038	405690	19713W	PARTICIPANT	\N	PRESENT	0
406039	405690	11064N	PARTICIPANT	\N	PRESENT	0
413110	406846	11027H	PARTICIPANT	\N	PRESENT	0
413112	406846	14231L	PARTICIPANT	\N	PRESENT	0
413113	406846	14259Y	PARTICIPANT	\N	PRESENT	0
413114	406846	19687N	PARTICIPANT	\N	PRESENT	0
413115	406846	11056N	PARTICIPANT	\N	PRESENT	0
413116	406846	19565D	PARTICIPANT	\N	PRESENT	0
413117	406846	19347U	PARTICIPANT	\N	PRESENT	0
413118	406846	19251M	PARTICIPANT	\N	PRESENT	0
413119	406846	19503N	PARTICIPANT	\N	PRESENT	0
413120	406846	14151M	PARTICIPANT	\N	PRESENT	0
413121	406846	14001X	PARTICIPANT	\N	PRESENT	0
413122	406846	19489J	PARTICIPANT	\N	PRESENT	0
413123	406846	14229S	PARTICIPANT	\N	PRESENT	0
413124	406846	14081Q	PARTICIPANT	\N	PRESENT	0
413125	406846	14065Q	PARTICIPANT	\N	PRESENT	0
413126	406846	19543W	PARTICIPANT	\N	PRESENT	0
413127	406846	14207L	PARTICIPANT	\N	PRESENT	0
413128	406846	19387D	PARTICIPANT	\N	PRESENT	0
413129	406846	19629C	PARTICIPANT	\N	PRESENT	0
413130	406846	08049C	PARTICIPANT	\N	PRESENT	0
413131	406846	04040A	PARTICIPANT	\N	PRESENT	0
413132	406846	14042U	PARTICIPANT	\N	PRESENT	0
413133	406846	14219Q	PARTICIPANT	\N	PRESENT	0
413134	406846	19737F	PARTICIPANT	\N	PRESENT	0
413135	406846	08009T	PARTICIPANT	\N	PRESENT	0
413136	406846	19441R	PARTICIPANT	\N	PRESENT	0
413137	406846	14157T	PARTICIPANT	\N	PRESENT	0
413138	406846	19794Q	PARTICIPANT	\N	PRESENT	0
413139	406846	19447X	PARTICIPANT	\N	PRESENT	0
413140	406846	19533U	PARTICIPANT	\N	PRESENT	0
413141	406846	08020N	PARTICIPANT	\N	PRESENT	0
413142	406846	11090Q	PARTICIPANT	\N	PRESENT	0
413143	406846	14147R	PARTICIPANT	\N	PRESENT	0
413144	406846	08034U	PARTICIPANT	\N	PRESENT	0
413145	406846	14069U	PARTICIPANT	\N	PRESENT	0
413146	406846	14053L	PARTICIPANT	\N	PRESENT	0
413147	406846	04069P	PARTICIPANT	\N	PRESENT	0
413148	406846	04070G	PARTICIPANT	\N	PRESENT	0
413149	406846	14215L	PARTICIPANT	\N	PRESENT	0
413150	406846	19747H	PARTICIPANT	\N	PRESENT	0
413151	406846	08010L	PARTICIPANT	\N	PRESENT	0
413152	406846	19515S	PARTICIPANT	\N	PRESENT	0
413153	406846	14038Y	PARTICIPANT	\N	PRESENT	0
413154	406846	19679N	PARTICIPANT	\N	PRESENT	0
413155	406846	11077T	PARTICIPANT	\N	PRESENT	0
413156	406846	14211G	PARTICIPANT	\N	PRESENT	0
413157	406846	11064N	PARTICIPANT	\N	PRESENT	0
413158	406846	19545Y	PARTICIPANT	\N	PRESENT	0
413159	406846	19553Y	PARTICIPANT	\N	PRESENT	0
413160	406846	08024S	PARTICIPANT	\N	PRESENT	0
413161	406846	19349W	PARTICIPANT	\N	PRESENT	0
413162	406846	08061X	PARTICIPANT	\N	PRESENT	0
413163	406846	19399H	PARTICIPANT	\N	PRESENT	0
413164	406846	92040Q	PARTICIPANT	\N	PRESENT	0
413165	406846	01057W	PARTICIPANT	\N	PRESENT	0
413166	406846	11048N	PARTICIPANT	\N	PRESENT	0
413167	406846	04049K	PARTICIPANT	\N	PRESENT	0
413168	406846	14109K	PARTICIPANT	\N	PRESENT	0
413169	406846	14123H	PARTICIPANT	\N	PRESENT	0
413170	406846	18083K	PARTICIPANT	\N	PRESENT	0
413171	406846	14169X	PARTICIPANT	\N	PRESENT	0
413172	406846	14111D	PARTICIPANT	\N	PRESENT	0
413173	406846	11109J	PARTICIPANT	\N	PRESENT	0
413174	406846	19479G	PARTICIPANT	\N	PRESENT	0
413175	406846	19521Q	PARTICIPANT	\N	PRESENT	0
413176	406846	19719D	PARTICIPANT	\N	PRESENT	0
413177	406846	17637T	PARTICIPANT	\N	PRESENT	0
413178	406846	19563B	PARTICIPANT	\N	PRESENT	0
413179	406846	14089Y	PARTICIPANT	\N	PRESENT	0
413180	406846	11097X	PARTICIPANT	\N	PRESENT	0
413181	406846	14187A	PARTICIPANT	\N	PRESENT	0
413182	406846	05012A	PARTICIPANT	\N	PRESENT	0
413183	406846	14199E	PARTICIPANT	\N	PRESENT	0
413184	406846	08031R	PARTICIPANT	\N	PRESENT	0
413185	406846	14083S	PARTICIPANT	\N	PRESENT	0
413111	406846	05008E	PARTICIPANT	\N	PRESENT	0
413186	406846	19762G	PARTICIPANT	\N	PRESENT	0
413187	406846	19575F	PARTICIPANT	\N	PRESENT	0
413188	406846	19739H	PARTICIPANT	\N	PRESENT	0
413189	406846	14249W	PARTICIPANT	\N	PRESENT	0
413190	406846	08069G	PARTICIPANT	\N	PRESENT	0
413191	406846	14073Q	PARTICIPANT	\N	PRESENT	0
413192	406846	01028R	PARTICIPANT	\N	PRESENT	0
413193	406846	04047H	PARTICIPANT	\N	PRESENT	0
413194	406846	08019V	PARTICIPANT	\N	PRESENT	0
413195	406846	14265W	PARTICIPANT	\N	PRESENT	0
413196	406846	19768N	PARTICIPANT	\N	PRESENT	0
413197	406846	04088S	PARTICIPANT	\N	PRESENT	0
413198	406846	14033T	PARTICIPANT	\N	PRESENT	0
413199	406846	07029T	PARTICIPANT	\N	PRESENT	0
413200	406846	14135M	PARTICIPANT	\N	PRESENT	0
413201	406846	08068F	PARTICIPANT	\N	PRESENT	0
413202	406846	14257W	PARTICIPANT	\N	PRESENT	0
413203	406846	19573D	PARTICIPANT	\N	PRESENT	0
413204	406846	14026U	PARTICIPANT	\N	PRESENT	0
413205	406846	19713W	PARTICIPANT	\N	PRESENT	0
413206	406846	14241N	PARTICIPANT	\N	PRESENT	0
413207	406846	80013X	PARTICIPANT	\N	PRESENT	0
413208	406846	19335Q	PARTICIPANT	\N	PRESENT	0
413209	406846	14071N	PARTICIPANT	\N	PRESENT	0
413210	406846	14107H	PARTICIPANT	\N	PRESENT	0
413211	406846	14034U	PARTICIPANT	\N	PRESENT	0
413212	406846	14213J	PARTICIPANT	\N	PRESENT	0
413213	406846	14179A	PARTICIPANT	\N	PRESENT	0
413354	411140	14229S	PARTICIPANT	\N	PRESENT	0
413355	411140	19387D	PARTICIPANT	\N	PRESENT	0
413356	411140	14123H	PARTICIPANT	\N	PRESENT	0
413359	411140	14107H	PARTICIPANT	\N	PRESENT	0
413360	411140	19735D	PARTICIPANT	\N	PRESENT	0
413361	411140	11012A	PARTICIPANT	\N	PRESENT	0
413727	406848	04086Q	PARTICIPANT	\N	PRESENT	0
413728	406848	11012A	PARTICIPANT	\N	PRESENT	0
413729	406848	14034U	PARTICIPANT	\N	PRESENT	0
413730	406848	19443T	PARTICIPANT	\N	PRESENT	0
413731	406848	19715Y	PARTICIPANT	\N	PRESENT	0
413732	406848	14199E	PARTICIPANT	\N	PRESENT	0
413733	406848	01048V	PARTICIPANT	\N	PRESENT	0
413734	406848	19687N	PARTICIPANT	\N	PRESENT	0
413735	406848	05012A	PARTICIPANT	\N	PRESENT	0
413736	406848	19289C	PARTICIPANT	\N	PRESENT	0
413737	406848	11048N	PARTICIPANT	\N	PRESENT	0
413738	406848	19619A	PARTICIPANT	\N	PRESENT	0
413739	406848	14197C	PARTICIPANT	\N	PRESENT	0
413740	406848	14030Q	PARTICIPANT	\N	PRESENT	0
413741	406848	19739H	PARTICIPANT	\N	PRESENT	0
413744	406848	11085T	PARTICIPANT	\N	PRESENT	0
413745	406848	19611R	PARTICIPANT	\N	PRESENT	0
413746	406848	19553Y	PARTICIPANT	\N	PRESENT	0
413748	406848	17637T	PARTICIPANT	\N	PRESENT	0
413749	413747	11101A	PARTICIPANT	\N	PRESENT	0
413750	413747	14085U	PARTICIPANT	\N	PRESENT	0
413751	413747	08028W	PARTICIPANT	\N	PRESENT	0
413755	413747	19703U	PARTICIPANT	\N	PRESENT	0
413753	413747	14111D	PARTICIPANT	\N	PRESENT	0
413754	413747	14223L	PARTICIPANT	\N	PRESENT	0
413757	413756	08028W	PARTICIPANT	\N	PRESENT	0
413759	413758	11053K	PARTICIPANT	\N	PRESENT	0
413760	413758	14083S	PARTICIPANT	\N	PRESENT	0
413761	413758	11097X	PARTICIPANT	\N	PRESENT	0
413762	413758	88008L	PARTICIPANT	\N	PRESENT	0
413763	406848	11077T	PARTICIPANT	\N	PRESENT	0
413769	413768	07004J	PARTICIPANT	\N	PRESENT	0
413772	400647	14030Q	PRESIDENT	0	PRESENT	0
413773	400647	19643A	PARTICIPANT	\N	PRESENT	0
413774	400647	18083K	PARTICIPANT	\N	PRESENT	0
413776	400647	19701S	PARTICIPANT	\N	PRESENT	0
413778	400647	11031D	PARTICIPANT	\N	PRESENT	0
413725	406848	14069U	PARTICIPANT	\N	PRESENT	0
413726	406848	19663E	PARTICIPANT	\N	PRESENT	0
413779	400647	19693L	PARTICIPANT	\N	PRESENT	0
413780	400647	80013X	PARTICIPANT	\N	PRESENT	0
413781	400647	14217N	PARTICIPANT	\N	PRESENT	0
413782	400647	08043V	PARTICIPANT	\N	PRESENT	0
413783	400647	19673G	PARTICIPANT	\N	PRESENT	0
413784	400647	19599P	PARTICIPANT	\N	PRESENT	0
413785	400647	14179A	PARTICIPANT	\N	PRESENT	0
413786	400647	19715Y	PARTICIPANT	\N	PRESENT	0
413787	400647	19731Y	PARTICIPANT	\N	PRESENT	0
413788	400647	08031R	PARTICIPANT	\N	PRESENT	0
413789	400647	07029T	PARTICIPANT	\N	PRESENT	0
413790	400647	08017T	PARTICIPANT	\N	PRESENT	0
413791	400647	11067R	PARTICIPANT	\N	PRESENT	0
413792	400647	14109K	PARTICIPANT	\N	PRESENT	0
413793	400647	14251Q	PARTICIPANT	\N	PRESENT	0
413794	400647	14235Q	PARTICIPANT	\N	PRESENT	0
413795	400647	19269X	PARTICIPANT	\N	PRESENT	0
413796	400647	11045K	PARTICIPANT	\N	PRESENT	0
413797	400647	19679N	PARTICIPANT	\N	PRESENT	0
396517	396516	19701S	PARTICIPANT	\N	PRESENT	0
399533	397651	14063N	PARTICIPANT	\N	EXCUSE	0
400336	393604	08031R	PARTICIPANT	\N	PRESENT	0
400337	393604	14133K	PARTICIPANT	\N	PRESENT	0
400338	393604	01057W	PARTICIPANT	\N	PRESENT	0
400339	393604	19739H	PARTICIPANT	\N	PRESENT	0
400340	393604	19253P	PARTICIPANT	\N	PRESENT	0
400341	393604	19741B	PARTICIPANT	\N	PRESENT	0
400342	393604	19745F	PARTICIPANT	\N	PRESENT	0
400343	393604	14061L	PARTICIPANT	\N	PRESENT	0
400344	393604	19443T	PARTICIPANT	\N	PRESENT	0
400345	393604	11033F	PARTICIPANT	\N	PRESENT	0
400346	393604	14107H	PARTICIPANT	\N	PRESENT	0
400347	393604	08011M	PARTICIPANT	\N	PRESENT	0
400348	393604	14121F	PARTICIPANT	\N	PRESENT	0
400349	393604	14179A	PARTICIPANT	\N	PRESENT	0
400350	393604	14225N	PARTICIPANT	\N	PRESENT	0
400351	393604	10015M	PARTICIPANT	\N	PRESENT	0
400352	393604	19503N	PARTICIPANT	\N	PRESENT	0
400353	393604	11067R	PARTICIPANT	\N	PRESENT	0
400354	393604	14237S	PARTICIPANT	\N	PRESENT	0
400355	393604	11043H	PARTICIPANT	\N	PRESENT	0
400356	393604	08010L	PARTICIPANT	\N	PRESENT	0
400357	393604	07004J	PARTICIPANT	\N	PRESENT	0
400358	393604	80013X	PARTICIPANT	\N	PRESENT	0
400359	393604	01043Q	PARTICIPANT	\N	PRESENT	0
400360	393604	04018C	PARTICIPANT	\N	PRESENT	0
400361	393604	19794Q	PARTICIPANT	\N	PRESENT	0
400362	393604	04088S	PARTICIPANT	\N	PRESENT	0
400363	393604	04059M	PARTICIPANT	\N	PRESENT	0
400364	393604	08017T	PARTICIPANT	\N	PRESENT	0
400365	393604	14229S	PARTICIPANT	\N	PRESENT	0
400366	393604	19593H	PARTICIPANT	\N	PRESENT	0
400367	393604	11040E	PARTICIPANT	\N	PRESENT	0
400368	393604	14235Q	PARTICIPANT	\N	PRESENT	0
400369	393604	19760E	PARTICIPANT	\N	PRESENT	0
400370	393604	04057K	PARTICIPANT	\N	PRESENT	0
400371	393604	19479G	PARTICIPANT	\N	PRESENT	0
400372	393604	19749K	PARTICIPANT	\N	PRESENT	0
400373	393604	19349W	PARTICIPANT	\N	PRESENT	0
400374	393604	08043V	PARTICIPANT	\N	PRESENT	0
400375	393604	04070G	PARTICIPANT	\N	PRESENT	0
400376	393604	08056B	PARTICIPANT	\N	PRESENT	0
400377	393604	92040Q	PARTICIPANT	\N	PRESENT	0
400378	393604	08039A	PARTICIPANT	\N	PRESENT	0
400379	393604	19441R	PARTICIPANT	\N	PRESENT	0
400380	393604	14241N	PARTICIPANT	\N	PRESENT	0
400381	393604	18083K	PARTICIPANT	\N	PRESENT	0
400382	393604	19758L	PARTICIPANT	\N	PRESENT	0
400383	393604	14041T	PARTICIPANT	\N	PRESENT	0
400384	393604	11097X	PARTICIPANT	\N	PRESENT	0
400385	393604	19515S	PARTICIPANT	\N	PRESENT	0
400386	393604	19711U	PARTICIPANT	\N	PRESENT	0
400387	393604	14249W	PARTICIPANT	\N	PRESENT	0
400388	393604	19693L	PARTICIPANT	\N	PRESENT	0
400389	393604	19663E	PARTICIPANT	\N	PRESENT	0
400390	393604	19735D	PARTICIPANT	\N	PRESENT	0
400391	393604	11083R	PARTICIPANT	\N	PRESENT	0
400392	393604	11104D	PARTICIPANT	\N	PRESENT	0
400393	393604	14030Q	PARTICIPANT	\N	PRESENT	0
400394	393604	14231L	PARTICIPANT	\N	PRESENT	0
400395	393604	01025N	PARTICIPANT	\N	PRESENT	0
400396	393604	97011G	PARTICIPANT	\N	PRESENT	0
400397	393604	11048N	PARTICIPANT	\N	PRESENT	0
400398	393604	19399H	PARTICIPANT	\N	PRESENT	0
400399	393604	14033T	PARTICIPANT	\N	PRESENT	0
400400	393604	01058X	PARTICIPANT	\N	PRESENT	0
400401	393604	19575F	PARTICIPANT	\N	PRESENT	0
400402	393604	19533U	PARTICIPANT	\N	PRESENT	0
400403	393604	19621T	PARTICIPANT	\N	PRESENT	0
400404	393604	19421M	PARTICIPANT	\N	PRESENT	0
400405	393604	01024M	PARTICIPANT	\N	PRESENT	0
400406	393604	19543W	PARTICIPANT	\N	PRESENT	0
400407	393604	14039A	PARTICIPANT	\N	PRESENT	0
400408	393604	19697Q	PARTICIPANT	\N	PRESENT	0
400409	393604	11012A	PARTICIPANT	\N	PRESENT	0
400410	393604	19691J	PARTICIPANT	\N	PRESENT	0
400411	393604	19611R	PARTICIPANT	\N	PRESENT	0
400412	393604	14147R	PARTICIPANT	\N	PRESENT	0
400413	393604	14265W	PARTICIPANT	\N	PRESENT	0
400414	393604	08048B	PARTICIPANT	\N	PRESENT	0
400415	393604	95030B	PARTICIPANT	\N	PRESENT	0
400416	393604	14031R	PARTICIPANT	\N	PRESENT	0
400417	393604	98022P	PARTICIPANT	\N	PRESENT	0
400418	393604	14021P	PARTICIPANT	\N	PRESENT	0
400419	393604	14357A	PARTICIPANT	\N	PRESENT	0
400420	393604	19447X	PARTICIPANT	\N	PRESENT	0
400421	393604	08019V	PARTICIPANT	\N	PRESENT	0
400422	393604	14157T	PARTICIPANT	\N	PRESENT	0
400423	393604	08020N	PARTICIPANT	\N	PRESENT	0
400424	393604	04043D	PARTICIPANT	\N	PRESENT	0
400425	393604	14193X	PARTICIPANT	\N	PRESENT	0
400426	393604	08045X	PARTICIPANT	\N	PRESENT	0
400427	393604	14038Y	PARTICIPANT	\N	PRESENT	0
400428	393604	14073Q	PARTICIPANT	\N	PRESENT	0
400429	393604	19569H	PARTICIPANT	\N	PRESENT	0
400430	393604	11072N	PARTICIPANT	\N	PRESENT	0
400431	393604	19467C	PARTICIPANT	\N	PRESENT	0
400432	393604	19673G	PARTICIPANT	\N	PRESENT	0
400433	393604	11085T	PARTICIPANT	\N	PRESENT	0
400434	393604	14051J	PARTICIPANT	\N	PRESENT	0
400435	393604	07029T	PARTICIPANT	\N	PRESENT	0
400436	393604	19747H	PARTICIPANT	\N	PRESENT	0
400437	393604	14207L	PARTICIPANT	\N	PRESENT	0
400438	393604	19413M	PARTICIPANT	\N	PRESENT	0
400439	393604	04038G	PARTICIPANT	\N	PRESENT	0
400440	393604	14042U	PARTICIPANT	\N	PRESENT	0
400441	393604	99004R	PARTICIPANT	\N	PRESENT	0
400442	393604	04034C	PARTICIPANT	\N	PRESENT	0
400532	400531	10006L	PARTICIPANT	\N	PRESENT	0
400533	400531	19553Y	PARTICIPANT	\N	PRESENT	0
400534	400531	08052W	PARTICIPANT	\N	PRESENT	0
400535	400530	10006L	PARTICIPANT	\N	PRESENT	0
400536	400530	19553Y	PARTICIPANT	\N	PRESENT	0
400537	400530	08052W	PARTICIPANT	\N	PRESENT	0
400538	399485	08017T	PARTICIPANT	\N	EXCUSE	0
400542	400541	04071H	PARTICIPANT	\N	PRESENT	0
402205	393620	19563B	PARTICIPANT	\N	PRESENT	0
402206	393620	19253P	PARTICIPANT	\N	PRESENT	0
402207	393620	14030Q	PARTICIPANT	\N	PRESENT	0
402208	393620	19691J	PARTICIPANT	\N	PRESENT	0
402209	393620	19319Q	PARTICIPANT	\N	PRESENT	0
402210	393620	14109K	PARTICIPANT	\N	PRESENT	0
402211	393620	01048V	PARTICIPANT	\N	PRESENT	0
402212	393620	14069U	PARTICIPANT	\N	PRESENT	0
402213	393620	19479G	PARTICIPANT	\N	PRESENT	0
402214	393620	19651A	PARTICIPANT	\N	PRESENT	0
402215	393620	19671E	PARTICIPANT	\N	PRESENT	0
402216	393620	14261S	PARTICIPANT	\N	PRESENT	0
402233	393620	08034U	PARTICIPANT	\N	PRESENT	0
402236	393620	19675J	PARTICIPANT	\N	PRESENT	0
402240	393620	19543W	PARTICIPANT	\N	PRESENT	0
402242	393620	19768N	PARTICIPANT	\N	PRESENT	0
402246	393620	19591F	PARTICIPANT	\N	PRESENT	0
402247	393620	19269X	PARTICIPANT	\N	PRESENT	0
402248	393620	11085T	PARTICIPANT	\N	PRESENT	0
402249	393620	19335Q	PARTICIPANT	\N	PRESENT	0
402250	393620	14039A	PARTICIPANT	\N	PRESENT	0
402251	393620	14147R	PARTICIPANT	\N	PRESENT	0
402252	393620	14179A	PARTICIPANT	\N	PRESENT	0
402253	393620	95062K	PARTICIPANT	\N	PRESENT	0
402257	393620	19760E	PARTICIPANT	\N	PRESENT	0
402260	393620	19599P	PARTICIPANT	\N	PRESENT	0
402261	393620	14021P	PARTICIPANT	\N	PRESENT	0
402262	393620	19447X	PARTICIPANT	\N	PRESENT	0
402263	393620	14123H	PARTICIPANT	\N	PRESENT	0
402264	393620	08020N	PARTICIPANT	\N	PRESENT	0
402275	401713	14053L	PARTICIPANT	\N	PRESENT	0
402276	401713	10015M	PARTICIPANT	\N	PRESENT	0
402277	401713	19585H	PARTICIPANT	\N	PRESENT	0
402278	401713	01028R	PARTICIPANT	\N	PRESENT	0
402279	401713	05008E	PRESIDENT	0	PRESENT	0
402280	401713	14231L	PARTICIPANT	\N	PRESENT	0
402281	401713	19447X	PARTICIPANT	\N	PRESENT	0
402282	401713	19489J	PARTICIPANT	\N	PRESENT	0
402283	401713	14275Y	PARTICIPANT	\N	PRESENT	0
402284	401713	95063L	PARTICIPANT	\N	PRESENT	0
402285	401713	14041T	PARTICIPANT	\N	PRESENT	0
402286	401713	14147R	PARTICIPANT	\N	PRESENT	0
402287	401713	14215L	PARTICIPANT	\N	PRESENT	0
402288	401713	14259Y	PARTICIPANT	\N	PRESENT	0
402289	401713	19762G	PARTICIPANT	\N	PRESENT	0
402290	401713	11026G	PARTICIPANT	\N	PRESENT	0
402291	401713	14069U	PARTICIPANT	\N	PRESENT	0
402292	401713	19543W	PARTICIPANT	\N	PRESENT	0
402293	401713	14021P	PARTICIPANT	\N	PRESENT	0
402298	393620	19701S	PARTICIPANT	\N	PRESENT	0
402299	393620	19551W	PARTICIPANT	\N	PRESENT	0
402308	393620	95037J	PARTICIPANT	\N	PRESENT	0
421451	421447	04070G	PRESIDENT	0	PRESENT	0
421452	421447	19699S	PARTICIPANT	\N	PRESENT	0
421453	421447	14061L	PARTICIPANT	\N	PRESENT	0
421454	421447	14073Q	PARTICIPANT	\N	PRESENT	0
421455	421447	19611R	PARTICIPANT	\N	PRESENT	0
421456	421447	08035V	PARTICIPANT	\N	PRESENT	0
421457	421447	08043V	PARTICIPANT	\N	PRESENT	0
421458	421447	19399H	PARTICIPANT	\N	PRESENT	0
421459	421447	14030Q	PARTICIPANT	\N	PRESENT	0
421460	421447	19731Y	PARTICIPANT	\N	PRESENT	0
421461	421447	14251Q	PARTICIPANT	\N	PRESENT	0
421462	421447	19573D	PARTICIPANT	\N	PRESENT	0
421463	421447	14107H	PARTICIPANT	\N	PRESENT	0
421464	421447	08017T	PARTICIPANT	\N	PRESENT	0
421465	421447	14063N	PARTICIPANT	\N	PRESENT	0
421466	421447	08012N	PARTICIPANT	\N	PRESENT	0
421467	421447	19335Q	PARTICIPANT	\N	PRESENT	0
421468	421447	11104D	PARTICIPANT	\N	PRESENT	0
421469	421447	11043H	PARTICIPANT	\N	PRESENT	0
421470	421447	19749K	PARTICIPANT	\N	PRESENT	0
421471	421447	19758L	PARTICIPANT	\N	PRESENT	0
421472	421447	04018C	PARTICIPANT	\N	PRESENT	0
421473	421447	08039A	PARTICIPANT	\N	PRESENT	0
421474	421447	08031R	PARTICIPANT	\N	PRESENT	0
421475	421447	19693L	PARTICIPANT	\N	EXCUSE	0
421476	421447	14241N	PARTICIPANT	\N	PRESENT	0
421477	421447	19533U	PARTICIPANT	\N	PRESENT	0
421481	421447	14039A	PARTICIPANT	\N	PRESENT	0
421482	421447	07033P	PARTICIPANT	\N	PRESENT	0
421483	421447	14249W	PARTICIPANT	\N	PRESENT	0
421484	421447	14229S	PARTICIPANT	\N	PRESENT	0
421485	420707	14053L	PARTICIPANT	\N	PRESENT	0
421486	420707	14111D	PARTICIPANT	\N	PRESENT	0
421487	420707	19649G	PARTICIPANT	\N	PRESENT	0
421488	420707	08045X	PARTICIPANT	\N	PRESENT	0
421489	420707	19253P	PARTICIPANT	\N	PRESENT	0
421490	420707	14001X	PARTICIPANT	\N	PRESENT	0
421491	420707	19543W	PARTICIPANT	\N	PRESENT	0
421492	420707	04038G	PARTICIPANT	\N	PRESENT	0
421493	420707	19585H	PARTICIPANT	\N	PRESENT	0
421494	420707	19673G	PARTICIPANT	\N	PRESENT	0
421495	420707	01028R	PARTICIPANT	\N	PRESENT	0
421496	420707	11033F	PARTICIPANT	\N	PRESENT	0
421497	420707	05008E	PRESIDENT	0	PRESENT	0
421498	420707	14231L	PARTICIPANT	\N	PRESENT	0
421499	420707	19725B	PARTICIPANT	\N	PRESENT	0
421500	420707	19729F	PARTICIPANT	\N	PRESENT	0
421501	420707	95063L	PARTICIPANT	\N	PRESENT	0
421502	420707	14275Y	PARTICIPANT	\N	PRESENT	0
421503	420707	14147R	PARTICIPANT	\N	PRESENT	0
421504	420707	11049P	PARTICIPANT	\N	PRESENT	0
421505	420707	19762G	PARTICIPANT	\N	PRESENT	0
421506	420707	14021P	PARTICIPANT	\N	PRESENT	0
421507	420707	19675J	PARTICIPANT	\N	EXCUSE	0
421508	420251	08056B	PARTICIPANT	\N	PRESENT	0
421509	420251	14105F	PARTICIPANT	\N	PRESENT	0
421510	420251	12041X	PARTICIPANT	\N	PRESENT	0
421511	420251	19443T	PARTICIPANT	\N	PRESENT	0
421512	420251	98018T	PARTICIPANT	\N	PRESENT	0
421513	420251	11041F	PARTICIPANT	\N	PRESENT	0
421514	420251	08058D	PARTICIPANT	\N	PRESENT	0
421515	420251	98050T	PARTICIPANT	\N	PRESENT	0
421516	420251	04042C	PRESIDENT	0	PRESENT	0
421517	420251	08061X	PARTICIPANT	\N	PRESENT	0
421518	420251	11066Q	PARTICIPANT	\N	PRESENT	0
421519	420251	14211G	PARTICIPANT	\N	PRESENT	0
421520	420251	04040A	PARTICIPANT	\N	PRESENT	0
421521	420251	19251M	PARTICIPANT	\N	PRESENT	0
421522	420251	19669L	PARTICIPANT	\N	PRESENT	0
421523	420251	98022P	PARTICIPANT	\N	PRESENT	0
421524	420251	14267Y	PARTICIPANT	\N	PRESENT	0
421525	420251	14079W	PARTICIPANT	\N	PRESENT	0
421526	420251	01058X	PARTICIPANT	\N	PRESENT	0
421527	420707	01060R	PARTICIPANT	\N	PRESENT	0
421528	420707	04044E	PARTICIPANT	\N	PRESENT	0
421529	420707	04047H	PARTICIPANT	\N	PRESENT	0
421530	420707	19447X	PARTICIPANT	\N	PRESENT	0
421531	420707	14151M	PARTICIPANT	\N	PRESENT	0
421532	420707	08018U	PARTICIPANT	\N	PRESENT	0
421533	420707	14259Y	PARTICIPANT	\N	PRESENT	0
421534	420707	98035U	PARTICIPANT	\N	PRESENT	0
421535	420707	11026G	PARTICIPANT	\N	PRESENT	0
421536	420707	01024M	PARTICIPANT	\N	PRESENT	0
421537	420707	14069U	PARTICIPANT	\N	PRESENT	0
421538	420646	19565D	PARTICIPANT	\N	PRESENT	0
421539	420646	19798U	PARTICIPANT	\N	PRESENT	0
421540	420646	19415P	PARTICIPANT	\N	PRESENT	0
421541	420646	14223L	PARTICIPANT	\N	PRESENT	0
421542	420646	04045F	PARTICIPANT	\N	PRESENT	0
421543	420646	14026U	PARTICIPANT	\N	PRESENT	0
421544	420646	17779H	PARTICIPANT	\N	PRESENT	0
421545	420646	19703U	PARTICIPANT	\N	PRESENT	0
421546	420646	14239U	PARTICIPANT	\N	PRESENT	0
421547	420646	11031D	PARTICIPANT	\N	PRESENT	0
421548	420646	14281W	PARTICIPANT	\N	PRESENT	0
421549	420646	14087W	PARTICIPANT	\N	PRESENT	0
421550	420646	19679N	PARTICIPANT	\N	PRESENT	0
421551	420646	14042U	PARTICIPANT	\N	PRESENT	0
421552	420646	19575F	PARTICIPANT	\N	PRESENT	0
421553	420646	14195A	PARTICIPANT	\N	PRESENT	0
421554	420646	19367Y	PARTICIPANT	\N	PRESENT	0
421555	420646	14213J	PARTICIPANT	\N	PRESENT	0
421556	420646	14217N	PARTICIPANT	\N	PRESENT	0
421557	420646	14261S	PARTICIPANT	\N	PRESENT	0
421558	420646	10006L	PARTICIPANT	\N	PRESENT	0
421559	420646	19683J	PARTICIPANT	\N	PRESENT	0
421560	420646	98024R	PARTICIPANT	\N	PRESENT	0
421561	420646	19521Q	PARTICIPANT	\N	PRESENT	0
421562	420646	01034P	PARTICIPANT	\N	PRESENT	0
421563	420646	04092N	PRESIDENT	0	PRESENT	0
421564	420646	08052W	PARTICIPANT	\N	PRESENT	0
421565	420646	19691J	PARTICIPANT	\N	PRESENT	0
421566	420646	19717B	PARTICIPANT	\N	PRESENT	0
421567	420646	19727D	PARTICIPANT	\N	PRESENT	0
421568	420646	14119M	PARTICIPANT	\N	PRESENT	0
421569	420646	11103C	PARTICIPANT	\N	PRESENT	0
421570	420646	14071N	PARTICIPANT	\N	PRESENT	0
421571	420646	19577H	PARTICIPANT	\N	PRESENT	0
421572	420646	19760E	PARTICIPANT	\N	PRESENT	0
421573	420646	08041T	PARTICIPANT	\N	EXCUSE	0
421574	419820	14327T	PARTICIPANT	\N	PRESENT	0
421575	419820	14331P	PARTICIPANT	\N	PRESENT	0
421576	419820	04071H	PARTICIPANT	\N	PRESENT	0
421577	419820	95041E	PARTICIPANT	\N	PRESENT	0
421578	419820	01048V	PARTICIPANT	\N	PRESENT	0
421579	419820	19545Y	PARTICIPANT	\N	PRESENT	0
421580	419820	01057W	PARTICIPANT	\N	PRESENT	0
421581	419820	11053K	PARTICIPANT	\N	PRESENT	0
421582	419820	11054L	PARTICIPANT	\N	PRESENT	0
421583	419820	19667J	PARTICIPANT	\N	PRESENT	0
421584	419820	11074Q	PRESIDENT	0	PRESENT	0
421585	419820	89017R	PARTICIPANT	\N	PRESENT	0
421586	419820	14225N	PARTICIPANT	\N	PRESENT	0
421587	419820	19671E	PARTICIPANT	\N	PRESENT	0
421588	419820	88008L	PARTICIPANT	\N	PRESENT	0
421589	419820	11070L	PARTICIPANT	\N	PRESENT	0
421590	419820	11110B	PARTICIPANT	\N	PRESENT	0
421591	419820	07029T	PARTICIPANT	\N	PRESENT	0
421592	419820	14277B	PARTICIPANT	\N	PRESENT	0
421593	419820	14085U	PARTICIPANT	\N	PRESENT	0
421594	419820	07004J	PARTICIPANT	\N	PRESENT	0
421595	419820	96004D	PARTICIPANT	\N	PRESENT	0
421596	419820	19349W	PARTICIPANT	\N	PRESENT	0
421597	419820	08010L	PARTICIPANT	\N	PRESENT	0
421598	419820	14253S	PARTICIPANT	\N	PRESENT	0
421599	419820	11072N	PARTICIPANT	\N	PRESENT	0
421600	419820	19479G	PARTICIPANT	\N	PRESENT	0
421601	419820	11048N	PARTICIPANT	\N	PRESENT	0
421602	419820	19647E	PARTICIPANT	\N	PRESENT	0
421603	419820	19711U	PARTICIPANT	\N	PRESENT	0
421604	419820	08034U	PARTICIPANT	\N	PRESENT	0
421605	419820	19651A	PARTICIPANT	\N	PRESENT	0
421606	419820	19531S	PARTICIPANT	\N	PRESENT	0
421607	419820	08069G	PARTICIPANT	\N	PRESENT	0
421608	419820	19687N	PARTICIPANT	\N	PRESENT	0
421609	419820	19689Q	PARTICIPANT	\N	PRESENT	0
421610	419820	08011M	PARTICIPANT	\N	PRESENT	0
421611	419820	14159V	PARTICIPANT	\N	PRESENT	0
421612	419820	11040E	PARTICIPANT	\N	PRESENT	0
421613	419820	04086Q	PARTICIPANT	\N	PRESENT	0
421614	419820	14083S	PARTICIPANT	\N	PRESENT	0
421615	419820	14199E	PARTICIPANT	\N	PRESENT	0
421616	419820	11012A	PARTICIPANT	\N	PRESENT	0
421617	419820	08073C	PARTICIPANT	\N	PRESENT	0
421618	419820	19741B	PARTICIPANT	\N	PRESENT	0
421619	419820	14121F	PARTICIPANT	\N	PRESENT	0
421620	419820	99004R	PARTICIPANT	\N	PRESENT	0
421667	421664	04070G	PRESIDENT	0	PRESENT	0
421668	421664	19699S	PARTICIPANT	\N	PRESENT	0
394828	378095	14237S	PARTICIPANT	\N	PRESENT	0
394829	378095	04042C	PARTICIPANT	\N	PRESENT	0
394830	378095	11026G	PARTICIPANT	\N	PRESENT	0
394831	378095	80013X	PARTICIPANT	\N	PRESENT	0
394832	378095	14001X	PARTICIPANT	\N	PRESENT	0
394833	378095	19593H	PARTICIPANT	\N	PRESENT	0
394834	378095	12041X	PARTICIPANT	\N	PRESENT	0
394835	378095	19760E	PARTICIPANT	\N	PRESENT	0
394836	378095	19758L	PARTICIPANT	\N	PRESENT	0
394837	378095	04057K	PARTICIPANT	\N	PRESENT	0
394838	378095	14121F	PARTICIPANT	\N	PRESENT	0
394839	378095	98022P	PARTICIPANT	\N	PRESENT	0
394840	378095	19553Y	PARTICIPANT	\N	PRESENT	0
394841	378095	19441R	PARTICIPANT	\N	PRESENT	0
394842	378095	14219Q	PARTICIPANT	\N	PRESENT	0
394843	378095	19479G	PARTICIPANT	\N	PRESENT	0
394844	378095	95037J	PARTICIPANT	\N	PRESENT	0
394845	378095	88008L	PARTICIPANT	\N	PRESENT	0
394846	378095	19335Q	PARTICIPANT	\N	PRESENT	0
394847	378095	14255U	PARTICIPANT	\N	PRESENT	0
394848	378095	14079W	PARTICIPANT	\N	PRESENT	0
394849	378095	19685L	PARTICIPANT	\N	PRESENT	0
394850	378095	01060R	PARTICIPANT	\N	PRESENT	0
394851	378095	14241N	PARTICIPANT	\N	PRESENT	0
394852	378095	04040A	PARTICIPANT	\N	PRESENT	0
394853	378095	17583W	PARTICIPANT	\N	PRESENT	0
394854	378095	10015M	PARTICIPANT	\N	PRESENT	0
394855	378095	14223L	PARTICIPANT	\N	PRESENT	0
394856	378095	08010L	PARTICIPANT	\N	PRESENT	0
394857	378095	04071H	PARTICIPANT	\N	PRESENT	0
394858	378095	04097T	PARTICIPANT	\N	PRESENT	0
394859	378095	98018T	PARTICIPANT	\N	PRESENT	0
394860	378095	14133K	PARTICIPANT	\N	PRESENT	0
394861	378095	19467C	PARTICIPANT	\N	PRESENT	0
394862	378095	14029X	PARTICIPANT	\N	PRESENT	0
394863	378095	01058X	PARTICIPANT	\N	PRESENT	0
394864	378095	01024M	PARTICIPANT	\N	PRESENT	0
394865	378095	19383Y	PARTICIPANT	\N	PRESENT	0
394866	378095	15447F	PARTICIPANT	\N	PRESENT	0
394867	378095	98050T	PARTICIPANT	\N	PRESENT	0
394868	378095	14051J	PARTICIPANT	\N	PRESENT	0
394869	378095	14257W	PARTICIPANT	\N	PRESENT	0
394870	378095	19762G	PARTICIPANT	\N	PRESENT	0
394874	378095	95030B	PARTICIPANT	\N	PRESENT	0
394877	378095	04088S	PARTICIPANT	\N	PRESENT	0
394878	378095	19521Q	PARTICIPANT	\N	PRESENT	0
394879	378095	14033T	PARTICIPANT	\N	PRESENT	0
394880	378095	19725B	PARTICIPANT	\N	PRESENT	0
394881	378095	19415P	PARTICIPANT	\N	PRESENT	0
394882	378095	08056B	PARTICIPANT	\N	PRESENT	0
394883	378095	87003B	PARTICIPANT	\N	PRESENT	0
394884	378095	19711U	PARTICIPANT	\N	PRESENT	0
394885	378095	14147R	PARTICIPANT	\N	PRESENT	0
394886	378095	01057W	PARTICIPANT	\N	PRESENT	0
394887	378095	19794Q	PARTICIPANT	\N	PRESENT	0
394888	378095	14021P	PARTICIPANT	\N	PRESENT	0
394889	378095	14030Q	PARTICIPANT	\N	PRESENT	0
394890	378095	11012A	PARTICIPANT	\N	PRESENT	0
394895	378095	19447X	PARTICIPANT	\N	PRESENT	0
394896	378095	19695N	PARTICIPANT	\N	PRESENT	0
394897	378095	14235Q	PARTICIPANT	\N	PRESENT	0
394898	378095	19565D	PARTICIPANT	\N	PRESENT	0
394899	378095	14213J	PARTICIPANT	\N	PRESENT	0
394900	378095	08069G	PARTICIPANT	\N	PRESENT	0
394901	378095	01025N	PARTICIPANT	\N	PRESENT	0
394902	378095	14135M	PARTICIPANT	\N	PRESENT	0
394903	378095	19782L	PARTICIPANT	\N	PRESENT	0
394951	378092	04038G	PARTICIPANT	\N	PRESENT	0
394952	378092	14151M	PARTICIPANT	\N	PRESENT	0
394953	378092	14001X	PARTICIPANT	\N	PRESENT	0
394954	378092	19543W	PARTICIPANT	\N	PRESENT	0
394955	378092	19719D	PARTICIPANT	\N	PRESENT	0
394956	378092	19553Y	PARTICIPANT	\N	PRESENT	0
394957	378092	19441R	PARTICIPANT	\N	PRESENT	0
394958	378092	19479G	PARTICIPANT	\N	PRESENT	0
394959	378092	01025N	PARTICIPANT	\N	PRESENT	0
394960	378092	14179A	PARTICIPANT	\N	PRESENT	0
394961	378092	11056N	PARTICIPANT	\N	PRESENT	0
394962	378092	19507S	PARTICIPANT	\N	PRESENT	0
394992	378092	14065Q	PARTICIPANT	\N	PRESENT	0
394964	378092	95030B	PARTICIPANT	\N	PRESENT	0
394965	378092	19711U	PARTICIPANT	\N	PRESENT	0
394966	378092	14089Y	PARTICIPANT	\N	PRESENT	0
394967	378092	19782L	PARTICIPANT	\N	PRESENT	0
394968	378092	19709B	PARTICIPANT	\N	PRESENT	0
394969	378092	11064N	PARTICIPANT	\N	PRESENT	0
394970	378092	14115H	PARTICIPANT	\N	PRESENT	0
394971	378092	19713W	PARTICIPANT	\N	PRESENT	0
394972	378092	19737F	PARTICIPANT	\N	PRESENT	0
394973	378092	14147R	PARTICIPANT	\N	PRESENT	0
394974	378092	19679N	PARTICIPANT	\N	PRESENT	0
394975	378092	19467C	PARTICIPANT	\N	PRESENT	0
394976	378092	05008E	PARTICIPANT	\N	PRESENT	0
394977	378092	17637T	PARTICIPANT	\N	PRESENT	0
394978	378092	04049K	PARTICIPANT	\N	PRESENT	0
394979	378092	14029X	PARTICIPANT	\N	PRESENT	0
394980	378092	19703U	PARTICIPANT	\N	PRESENT	0
394981	378092	01024M	PARTICIPANT	\N	PRESENT	0
394982	378092	19443T	PARTICIPANT	\N	PRESENT	0
394983	378092	04097T	PARTICIPANT	\N	PRESENT	0
394984	378092	19621T	PARTICIPANT	\N	PRESENT	0
394985	378092	14357A	PARTICIPANT	\N	PRESENT	0
394986	378092	08062Y	PARTICIPANT	\N	PRESENT	0
394987	378092	19747H	PARTICIPANT	\N	PRESENT	0
394988	378092	14215L	PARTICIPANT	\N	PRESENT	0
394989	378092	14083S	PARTICIPANT	\N	PRESENT	0
394990	378092	19447X	PARTICIPANT	\N	PRESENT	0
394991	378092	19349W	PARTICIPANT	\N	PRESENT	0
394993	378092	08020N	PARTICIPANT	\N	PRESENT	0
394994	378092	19347U	PARTICIPANT	\N	PRESENT	0
394995	378092	19565D	PARTICIPANT	\N	PRESENT	0
394996	378092	14038Y	PARTICIPANT	\N	PRESENT	0
394949	378092	04044E	PARTICIPANT	\N	PRESENT	0
394950	378092	04085P	PARTICIPANT	\N	PRESENT	0
394997	378092	19760E	PARTICIPANT	\N	PRESENT	0
394998	378092	05012A	PARTICIPANT	\N	PRESENT	0
394999	378092	14235Q	PARTICIPANT	\N	PRESENT	0
395000	378092	14030Q	PARTICIPANT	\N	PRESENT	0
395001	378092	10015M	PARTICIPANT	\N	PRESENT	0
395002	378092	14251Q	PARTICIPANT	\N	PRESENT	0
395003	378092	04047H	PARTICIPANT	\N	PRESENT	0
395004	378092	19768N	PARTICIPANT	\N	PRESENT	0
395005	378092	19575F	PARTICIPANT	\N	PRESENT	0
395006	378092	19253P	PARTICIPANT	\N	PRESENT	0
395007	378092	14087W	PARTICIPANT	\N	PRESENT	0
395008	378092	19733B	PARTICIPANT	\N	PRESENT	0
395009	378092	14197C	PARTICIPANT	\N	PRESENT	0
395010	378092	14042U	PARTICIPANT	\N	PRESENT	0
395011	378092	08012N	PARTICIPANT	\N	PRESENT	0
395012	378092	14187A	PARTICIPANT	\N	PRESENT	0
395013	378092	19573D	PARTICIPANT	\N	PRESENT	0
395014	378092	19521Q	PARTICIPANT	\N	PRESENT	0
395015	378092	14265W	PARTICIPANT	\N	PRESENT	0
395016	378092	14213J	PARTICIPANT	\N	PRESENT	0
395017	378092	08061X	PARTICIPANT	\N	PRESENT	0
395018	378092	14026U	PARTICIPANT	\N	PRESENT	0
395019	378092	14061L	PARTICIPANT	\N	PRESENT	0
395020	378092	14033T	PARTICIPANT	\N	PRESENT	0
395021	378092	14034U	PARTICIPANT	\N	PRESENT	0
395022	378092	01028R	PARTICIPANT	\N	PRESENT	0
395023	378092	19563B	PARTICIPANT	\N	PRESENT	0
395024	378092	19647E	PARTICIPANT	\N	PRESENT	0
406040	405690	14267Y	PARTICIPANT	\N	PRESENT	0
406041	405690	14103D	PARTICIPANT	\N	PRESENT	0
406042	405690	19335Q	PARTICIPANT	\N	PRESENT	0
406043	405690	14083S	PARTICIPANT	\N	PRESENT	0
406044	405690	14089Y	PARTICIPANT	\N	PRESENT	0
406045	405690	14275Y	PARTICIPANT	\N	PRESENT	0
406046	405690	14073Q	PARTICIPANT	\N	PRESENT	0
406047	405690	11012A	PARTICIPANT	\N	PRESENT	0
406048	405690	19749K	PARTICIPANT	\N	PRESENT	0
406049	405690	11085T	PARTICIPANT	\N	PRESENT	0
406050	405690	04070G	PARTICIPANT	\N	PRESENT	0
406051	405690	14221J	PARTICIPANT	\N	PRESENT	0
406052	405690	04040A	PARTICIPANT	\N	PRESENT	0
406053	405690	14030Q	PARTICIPANT	\N	PRESENT	0
406054	405690	14327T	PARTICIPANT	\N	PRESENT	0
406055	405690	01043Q	PARTICIPANT	\N	PRESENT	0
406056	405690	19319Q	PARTICIPANT	\N	PRESENT	0
406057	405690	14059S	PARTICIPANT	\N	PRESENT	0
406058	405690	14039A	PARTICIPANT	\N	PRESENT	0
406059	405690	08056B	PARTICIPANT	\N	PRESENT	0
406060	405690	19731Y	PARTICIPANT	\N	PRESENT	0
406061	405690	98022P	PARTICIPANT	\N	PRESENT	0
406062	405690	19553Y	PARTICIPANT	\N	PRESENT	0
406063	405690	11099A	PARTICIPANT	\N	PRESENT	0
406064	405690	11053K	PARTICIPANT	\N	PRESENT	0
406065	405690	14173T	PARTICIPANT	\N	PRESENT	0
413808	400647	86034E	PARTICIPANT	\N	PRESENT	0
413813	406848	19697Q	PARTICIPANT	\N	PRESENT	0
413816	410100	96004D	PRESIDENT	0	PRESENT	0
413817	410100	14249W	PARTICIPANT	\N	PRESENT	0
413818	410100	11083R	PARTICIPANT	\N	PRESENT	0
413819	410100	19553Y	PARTICIPANT	\N	PRESENT	0
413820	410100	14073Q	PARTICIPANT	\N	PRESENT	0
413822	410100	12041X	PARTICIPANT	\N	PRESENT	0
413824	410100	04057K	PARTICIPANT	\N	PRESENT	0
413825	410100	19563B	PARTICIPANT	\N	PRESENT	0
413826	410100	10015M	PARTICIPANT	\N	PRESENT	0
413827	410100	98035U	PARTICIPANT	\N	PRESENT	0
413828	410100	19399H	PARTICIPANT	\N	PRESENT	0
413829	410100	04034C	PARTICIPANT	\N	PRESENT	0
413830	410100	98050T	PARTICIPANT	\N	PRESENT	0
413831	410100	14255U	PARTICIPANT	\N	PRESENT	0
413832	410100	08011M	PARTICIPANT	\N	PRESENT	0
413833	410100	19709B	PARTICIPANT	\N	PRESENT	0
413834	410100	19711U	PARTICIPANT	\N	PRESENT	0
413837	406848	14065Q	PARTICIPANT	\N	PRESENT	0
413838	410100	19421M	PARTICIPANT	\N	PRESENT	0
413839	410100	19745F	PARTICIPANT	\N	PRESENT	0
413840	410100	14225N	PARTICIPANT	\N	PRESENT	0
413841	410100	14089Y	PARTICIPANT	\N	PRESENT	0
413842	410100	14241N	PARTICIPANT	\N	PRESENT	0
413844	406848	11099A	PARTICIPANT	\N	PRESENT	0
413845	406848	14109K	PARTICIPANT	\N	PRESENT	0
413846	406848	19399H	PARTICIPANT	\N	PRESENT	0
413847	406848	01058X	PARTICIPANT	\N	PRESENT	0
413848	406848	08069G	PARTICIPANT	\N	PRESENT	0
413849	406848	11109J	PARTICIPANT	\N	PRESENT	0
413905	406849	19631V	PARTICIPANT	\N	PRESENT	0
413906	406849	11109J	PARTICIPANT	\N	PRESENT	0
413907	406849	19295A	PARTICIPANT	\N	PRESENT	0
413908	406849	19503N	PARTICIPANT	\N	PRESENT	0
413909	406849	14215L	PARTICIPANT	\N	PRESENT	0
413910	406849	08020N	PARTICIPANT	\N	PRESENT	0
413911	406849	19711U	PARTICIPANT	\N	PRESENT	0
413912	406849	19643A	PARTICIPANT	\N	PRESENT	0
413913	406849	08019V	PARTICIPANT	\N	PRESENT	0
413914	406849	19443T	PARTICIPANT	\N	PRESENT	0
413915	406849	19693L	PARTICIPANT	\N	PRESENT	0
413916	406849	19657G	PARTICIPANT	\N	PRESENT	0
413917	406849	19335Q	PARTICIPANT	\N	PRESENT	0
413918	406849	08034U	PARTICIPANT	\N	PRESENT	0
413919	406849	08010L	PARTICIPANT	\N	PRESENT	0
413920	406849	14259Y	PARTICIPANT	\N	PRESENT	0
413921	406849	19565D	PARTICIPANT	\N	PRESENT	0
413922	406849	11077T	PARTICIPANT	\N	PRESENT	0
413923	406849	19687N	PARTICIPANT	\N	PRESENT	0
413924	406849	19489J	PARTICIPANT	\N	PRESENT	0
413925	406849	14001X	PARTICIPANT	\N	PRESENT	0
413926	406849	14034U	PARTICIPANT	\N	PRESENT	0
413927	406849	19719D	PARTICIPANT	\N	PRESENT	0
413928	406849	19741B	PARTICIPANT	\N	PRESENT	0
413929	406849	11056N	PARTICIPANT	\N	PRESENT	0
413930	406849	05008E	PARTICIPANT	\N	PRESENT	0
413931	406849	19447X	PARTICIPANT	\N	PRESENT	0
413932	406849	17637T	PARTICIPANT	\N	PRESENT	0
413933	406849	11048N	PARTICIPANT	\N	PRESENT	0
413934	406849	14329V	PARTICIPANT	\N	PRESENT	0
413935	406849	04085P	PARTICIPANT	\N	PRESENT	0
413936	406849	14187A	PARTICIPANT	\N	PRESENT	0
413937	406849	19515S	PARTICIPANT	\N	PRESENT	0
413938	406849	14179A	PARTICIPANT	\N	PRESENT	0
413939	406849	19543W	PARTICIPANT	\N	PRESENT	0
413940	406849	19551W	PARTICIPANT	\N	PRESENT	0
413941	406849	11012A	PARTICIPANT	\N	PRESENT	0
413942	406849	14069U	PARTICIPANT	\N	PRESENT	0
413943	406849	14211G	PARTICIPANT	\N	PRESENT	0
413944	406849	14205J	PARTICIPANT	\N	PRESENT	0
413999	413998	08018U	PARTICIPANT	\N	PRESENT	0
414001	414000	08018U	PARTICIPANT	\N	PRESENT	0
414150	414149	19747H	PARTICIPANT	\N	PRESENT	0
414151	414149	19295A	PARTICIPANT	\N	PRESENT	0
415011	415010	01034P	PARTICIPANT	\N	PRESENT	0
415012	415010	11097X	PARTICIPANT	\N	PRESENT	0
415017	415013	14087W	PARTICIPANT	\N	PRESENT	0
415018	415013	19521Q	PARTICIPANT	\N	PRESENT	0
415019	415013	19679N	PARTICIPANT	\N	PRESENT	0
415031	415030	14087W	PARTICIPANT	\N	PRESENT	0
415036	415030	19521Q	PARTICIPANT	\N	PRESENT	0
415040	415030	19679N	PARTICIPANT	\N	PRESENT	0
415042	412265	14257W	PARTICIPANT	\N	EXCUSE	0
413903	406849	04086Q	PARTICIPANT	\N	PRESENT	0
413904	406849	14231L	PARTICIPANT	\N	PRESENT	0
415072	415045	10006L	PARTICIPANT	\N	PRESENT	0
415073	415045	08052W	PARTICIPANT	\N	PRESENT	0
415091	415090	10006L	PARTICIPANT	\N	PRESENT	0
415092	415090	08052W	PARTICIPANT	\N	PRESENT	0
415101	415099	19747H	PARTICIPANT	\N	PRESENT	0
415102	415099	14205J	PARTICIPANT	\N	PRESENT	0
415103	415100	19747H	PARTICIPANT	\N	PRESENT	0
415227	405276	14030Q	PRESIDENT	0	PRESENT	0
415228	405276	08043V	PARTICIPANT	\N	PRESENT	0
415229	405276	08024S	PARTICIPANT	\N	PRESENT	0
415230	405276	19701S	PARTICIPANT	\N	PRESENT	0
415231	405276	11031D	PARTICIPANT	\N	PRESENT	0
415232	405276	80013X	PARTICIPANT	\N	PRESENT	0
415233	405276	19693L	PARTICIPANT	\N	PRESENT	0
415234	405276	19599P	PARTICIPANT	\N	PRESENT	0
415235	405276	14179A	PARTICIPANT	\N	PRESENT	0
415236	405276	19715Y	PARTICIPANT	\N	PRESENT	0
415237	405276	08031R	PARTICIPANT	\N	PRESENT	0
415238	405276	07029T	PARTICIPANT	\N	EXCUSE	0
415239	405276	08017T	PARTICIPANT	\N	PRESENT	0
415240	405276	14109K	PARTICIPANT	\N	PRESENT	0
415241	405276	14235Q	PARTICIPANT	\N	PRESENT	0
415242	405276	11045K	PARTICIPANT	\N	PRESENT	0
415243	405276	19749K	PARTICIPANT	\N	PRESENT	0
415246	405447	14021P	PARTICIPANT	\N	EXCUSE	0
415247	405447	19659J	PARTICIPANT	\N	EXCUSE	0
415248	405447	14038Y	PARTICIPANT	\N	PRESENT	0
415249	405447	19729F	PARTICIPANT	\N	EXCUSE	0
415555	413358	19545Y	PARTICIPANT	\N	PRESENT	0
415557	413451	11070L	PARTICIPANT	\N	PRESENT	0
415558	413451	95041E	PARTICIPANT	\N	PRESENT	0
415559	413451	01048V	PARTICIPANT	\N	PRESENT	0
415560	413451	14253S	PARTICIPANT	\N	PRESENT	0
415561	413451	08073C	PARTICIPANT	\N	PRESENT	0
415874	415869	14033T	PARTICIPANT	\N	PRESENT	0
415894	415868	14033T	PARTICIPANT	\N	PRESENT	0
415915	415908	14033T	PARTICIPANT	\N	PRESENT	0
415926	415922	14033T	PARTICIPANT	\N	PRESENT	0
415955	406854	11070L	PARTICIPANT	\N	PRESENT	0
415956	406854	19713W	PARTICIPANT	\N	PRESENT	0
416187	412265	04044E	PARTICIPANT	\N	EXCUSE	0
416483	416482	14093U	PARTICIPANT	\N	EXCUSE	0
416484	416482	19367Y	PARTICIPANT	\N	PRESENT	0
416485	416482	08060W	PARTICIPANT	\N	PRESENT	0
416486	416482	19758L	PARTICIPANT	\N	PRESENT	0
416487	416482	14053L	PARTICIPANT	\N	PRESENT	0
416488	416482	08024S	PARTICIPANT	\N	PRESENT	0
416489	416482	14079W	PARTICIPANT	\N	PRESENT	0
416490	416482	14033T	PARTICIPANT	\N	PRESENT	0
416491	416482	14026U	PARTICIPANT	\N	PRESENT	0
416492	416482	95067Q	PARTICIPANT	\N	PRESENT	0
416493	416482	14051J	PARTICIPANT	\N	EXCUSE	0
416494	416482	04070G	PARTICIPANT	\N	PRESENT	0
416495	416482	11048N	PARTICIPANT	\N	PRESENT	0
416496	416482	19637C	PARTICIPANT	\N	EXCUSE	0
416497	416482	19413M	PARTICIPANT	\N	PRESENT	0
416498	416482	08009T	PRESIDENT	0	PRESENT	0
416499	416482	19826F	PARTICIPANT	\N	PRESENT	0
416539	416482	19251M	PARTICIPANT	\N	EXCUSE	0
416674	416672	95067Q	PARTICIPANT	\N	PRESENT	0
416675	416672	14028W	PARTICIPANT	\N	PRESENT	0
416751	410795	80013X	PARTICIPANT	\N	EXCUSE	0
416752	410795	19663E	PARTICIPANT	\N	EXCUSE	0
416755	410795	19709B	PARTICIPANT	\N	PRESENT	0
416756	410795	01048V	PRESIDENT	0	PRESENT	0
416757	410795	19593H	PARTICIPANT	\N	EXCUSE	0
416758	410795	19503N	PARTICIPANT	\N	PRESENT	0
416759	410795	04043D	PARTICIPANT	\N	PRESENT	0
416761	410795	01058X	PARTICIPANT	\N	PRESENT	0
416779	410922	11067R	PARTICIPANT	\N	PRESENT	0
416811	410795	14299H	PARTICIPANT	\N	EXCUSE	0
416916	416915	14133K	PARTICIPANT	\N	PRESENT	0
416917	416915	08058D	PARTICIPANT	\N	PRESENT	0
416939	416938	14211G	PARTICIPANT	\N	PRESENT	0
416940	416938	19669L	PARTICIPANT	\N	PRESENT	0
394051	394040	08055A	PARTICIPANT	\N	PRESENT	0
394052	394040	11103C	PARTICIPANT	\N	PRESENT	0
394053	394040	14329V	PARTICIPANT	\N	PRESENT	0
394082	394075	08055A	PARTICIPANT	\N	PRESENT	0
394083	394075	11103C	PARTICIPANT	\N	PRESENT	0
394084	394075	14329V	PARTICIPANT	\N	PRESENT	0
394057	394040	11065P	PARTICIPANT	\N	PRESENT	0
394085	394075	14038Y	PARTICIPANT	\N	PRESENT	0
394059	394040	19347U	PARTICIPANT	\N	PRESENT	0
394060	394040	19333N	PARTICIPANT	\N	PRESENT	0
394061	394040	14103D	PARTICIPANT	\N	PRESENT	0
394062	394040	08009T	PRESIDENT	0	PRESENT	0
394063	394040	08061X	PARTICIPANT	\N	PRESENT	0
394235	378093	11010L	PARTICIPANT	\N	PRESENT	0
394236	378093	14223L	PARTICIPANT	\N	PRESENT	0
394237	378093	87003B	PARTICIPANT	\N	PRESENT	0
394088	394075	11065P	PARTICIPANT	\N	PRESENT	0
394238	378093	04043D	PARTICIPANT	\N	PRESENT	0
394090	394075	19347U	PARTICIPANT	\N	PRESENT	0
394091	394075	19333N	PARTICIPANT	\N	PRESENT	0
394092	394075	14103D	PARTICIPANT	\N	PRESENT	0
394093	394075	08009T	PRESIDENT	0	PRESENT	0
394094	394075	08061X	PARTICIPANT	\N	PRESENT	0
394239	378093	19447X	PARTICIPANT	\N	PRESENT	0
394240	378093	19467C	PARTICIPANT	\N	PRESENT	0
394214	378093	86034E	PARTICIPANT	\N	PRESENT	0
394234	378093	98018T	PARTICIPANT	\N	PRESENT	0
394241	378093	19794Q	PARTICIPANT	\N	PRESENT	0
394242	378093	14123H	PARTICIPANT	\N	PRESENT	0
394243	378093	08019V	PARTICIPANT	\N	PRESENT	0
394244	378093	19443T	PARTICIPANT	\N	PRESENT	0
394245	378093	14029X	PARTICIPANT	\N	PRESENT	0
394246	378093	19507S	PARTICIPANT	\N	PRESENT	0
394247	378093	14041T	PARTICIPANT	\N	PRESENT	0
394248	378093	08062Y	PARTICIPANT	\N	PRESENT	0
394249	378093	08015R	PARTICIPANT	\N	PRESENT	0
394250	378093	19768N	PARTICIPANT	\N	PRESENT	0
394251	378093	98050T	PARTICIPANT	\N	PRESENT	0
394252	378093	14061L	PARTICIPANT	\N	PRESENT	0
394253	378093	14213J	PARTICIPANT	\N	PRESENT	0
394254	378093	14331P	PARTICIPANT	\N	PRESENT	0
394255	378093	11103C	PARTICIPANT	\N	PRESENT	0
394256	378093	08039A	PARTICIPANT	\N	PRESENT	0
394257	378093	17637T	PARTICIPANT	\N	PRESENT	0
394258	378093	14187A	PARTICIPANT	\N	PRESENT	0
394259	378093	19383Y	PARTICIPANT	\N	PRESENT	0
394260	378093	19675J	PARTICIPANT	\N	PRESENT	0
394261	378093	14211G	PARTICIPANT	\N	PRESENT	0
394262	378093	19733B	PARTICIPANT	\N	PRESENT	0
394263	378093	14147R	PARTICIPANT	\N	PRESENT	0
394264	378093	19762G	PARTICIPANT	\N	PRESENT	0
394265	378093	19479G	PARTICIPANT	\N	PRESENT	0
394266	378093	14237S	PARTICIPANT	\N	PRESENT	0
394267	378093	14261S	PARTICIPANT	\N	PRESENT	0
394268	378093	19719D	PARTICIPANT	\N	PRESENT	0
394269	378093	98022P	PARTICIPANT	\N	PRESENT	0
394270	378093	19289C	PARTICIPANT	\N	PRESENT	0
394271	378093	19699S	PARTICIPANT	\N	PRESENT	0
394272	378093	14115H	PARTICIPANT	\N	PRESENT	0
394273	378093	08047A	PARTICIPANT	\N	PRESENT	0
394274	378093	17583W	PARTICIPANT	\N	PRESENT	0
394275	378093	14121F	PARTICIPANT	\N	PRESENT	0
394276	378093	04045F	PARTICIPANT	\N	PRESENT	0
394277	378093	19798U	PARTICIPANT	\N	PRESENT	0
394278	378093	19693L	PARTICIPANT	\N	PRESENT	0
394279	378093	08073C	PARTICIPANT	\N	PRESENT	0
394280	378093	95030B	PARTICIPANT	\N	PRESENT	0
394281	378093	19737F	PARTICIPANT	\N	PRESENT	0
394282	378093	14217N	PARTICIPANT	\N	PRESENT	0
394283	378093	19329S	PARTICIPANT	\N	PRESENT	0
394284	378093	14087W	PARTICIPANT	\N	PRESENT	0
394285	378093	14169X	PARTICIPANT	\N	PRESENT	0
394286	378093	07033P	PARTICIPANT	\N	PRESENT	0
394287	378093	19295A	PARTICIPANT	\N	PRESENT	0
394288	378093	19489J	PARTICIPANT	\N	PRESENT	0
394289	378093	19679N	PARTICIPANT	\N	PRESENT	0
394290	378093	17779H	PARTICIPANT	\N	PRESENT	0
394291	378093	08038Y	PARTICIPANT	\N	PRESENT	0
394292	378093	14031R	PARTICIPANT	\N	PRESENT	0
394293	378093	14038Y	PARTICIPANT	\N	PRESENT	0
394294	378093	80013X	PARTICIPANT	\N	PRESENT	0
394295	378093	19251M	PARTICIPANT	\N	PRESENT	0
394296	378093	99004R	PARTICIPANT	\N	PRESENT	0
394297	378093	19525U	PARTICIPANT	\N	PRESENT	0
394298	378093	11066Q	PARTICIPANT	\N	PRESENT	0
394299	378093	19735D	PARTICIPANT	\N	PRESENT	0
394300	378093	14069U	PARTICIPANT	\N	PRESENT	0
394301	378093	19725B	PARTICIPANT	\N	PRESENT	0
394302	378093	19527W	PARTICIPANT	\N	PRESENT	0
394303	378093	19387D	PARTICIPANT	\N	PRESENT	0
394304	378093	19549D	PARTICIPANT	\N	PRESENT	0
394305	378093	14135M	PARTICIPANT	\N	PRESENT	0
394306	378093	08014Q	PARTICIPANT	\N	PRESENT	0
394307	378093	19333N	PARTICIPANT	\N	PRESENT	0
394308	378093	19581D	PARTICIPANT	\N	PRESENT	0
394309	378093	19727D	PARTICIPANT	\N	PRESENT	0
394310	378093	19669L	PARTICIPANT	\N	PRESENT	0
394311	378093	11033F	PARTICIPANT	\N	PRESENT	0
394312	378093	19533U	PARTICIPANT	\N	PRESENT	0
394313	378093	04038G	PARTICIPANT	\N	PRESENT	0
394314	378093	14253S	PARTICIPANT	\N	PRESENT	0
394315	378093	14051J	PARTICIPANT	\N	PRESENT	0
394316	378093	08061X	PARTICIPANT	\N	PRESENT	0
394317	378093	19747H	PARTICIPANT	\N	PRESENT	0
394318	378093	14063N	PARTICIPANT	\N	PRESENT	0
394319	378093	14221J	PARTICIPANT	\N	PRESENT	0
394320	378093	19253P	PARTICIPANT	\N	PRESENT	0
394321	378093	98024R	PARTICIPANT	\N	PRESENT	0
394322	378093	14207L	PARTICIPANT	\N	PRESENT	0
394323	378093	19367Y	PARTICIPANT	\N	PRESENT	0
394324	378093	14267Y	PARTICIPANT	\N	PRESENT	0
394325	378093	19515S	PARTICIPANT	\N	PRESENT	0
394326	378093	01028R	PARTICIPANT	\N	PRESENT	0
394327	378093	11080N	PARTICIPANT	\N	PRESENT	0
394328	378093	08010L	PARTICIPANT	\N	PRESENT	0
394329	378093	19511N	PARTICIPANT	\N	PRESENT	0
394330	378093	08069G	PARTICIPANT	\N	PRESENT	0
394331	378093	01058X	PARTICIPANT	\N	PRESENT	0
394332	378093	14109K	PARTICIPANT	\N	PRESENT	0
394333	378093	08028W	PARTICIPANT	\N	PRESENT	0
394334	378093	19349W	PARTICIPANT	\N	PRESENT	0
394335	378093	19687N	PARTICIPANT	\N	PRESENT	0
394336	378093	11031D	PARTICIPANT	\N	PRESENT	0
394337	378093	04086Q	PARTICIPANT	\N	PRESENT	0
394338	378093	14085U	PARTICIPANT	\N	PRESENT	0
394339	378093	14357A	PARTICIPANT	\N	PRESENT	0
394340	378093	14197C	PARTICIPANT	\N	PRESENT	0
394341	378093	08052W	PARTICIPANT	\N	PRESENT	0
394342	378093	08024S	PARTICIPANT	\N	PRESENT	0
394343	378093	14241N	PARTICIPANT	\N	PRESENT	0
394344	378093	19649G	PARTICIPANT	\N	PRESENT	0
394345	378093	14079W	PARTICIPANT	\N	PRESENT	0
394346	378093	11104D	PARTICIPANT	\N	PRESENT	0
394347	378093	14028W	PARTICIPANT	\N	PRESENT	0
394348	378093	14151M	PARTICIPANT	\N	PRESENT	0
394349	378093	14103D	PARTICIPANT	\N	PRESENT	0
394350	378093	19611R	PARTICIPANT	\N	PRESENT	0
394351	378093	11053K	PARTICIPANT	\N	PRESENT	0
394352	378093	19703U	PARTICIPANT	\N	PRESENT	0
394353	378093	14042U	PARTICIPANT	\N	PRESENT	0
394354	378093	04040A	PARTICIPANT	\N	PRESENT	0
394355	378093	19415P	PARTICIPANT	\N	PRESENT	0
394356	378093	08060W	PARTICIPANT	\N	PRESENT	0
394357	378093	19643A	PARTICIPANT	\N	PRESENT	0
394358	378093	14157T	PARTICIPANT	\N	PRESENT	0
394359	378093	14133K	PARTICIPANT	\N	PRESENT	0
394360	378093	10015M	PARTICIPANT	\N	PRESENT	0
394361	378093	04097T	PARTICIPANT	\N	PRESENT	0
394362	378093	15447F	PARTICIPANT	\N	PRESENT	0
394363	378093	04033B	PARTICIPANT	\N	PRESENT	0
394364	378093	11040E	PARTICIPANT	\N	PRESENT	0
394365	378093	14105F	PARTICIPANT	\N	PRESENT	0
394366	378093	12041X	PARTICIPANT	\N	PRESENT	0
394367	378093	11056N	PARTICIPANT	\N	PRESENT	0
394368	378093	14235Q	PARTICIPANT	\N	PRESENT	0
394370	378093	19758L	PARTICIPANT	\N	PRESENT	0
394371	378093	19760E	PARTICIPANT	\N	PRESENT	0
394372	378093	04085P	PARTICIPANT	\N	PRESENT	0
394373	378093	19695N	PARTICIPANT	\N	PRESENT	0
394374	378093	19347U	PARTICIPANT	\N	PRESENT	0
394375	378093	19565D	PARTICIPANT	\N	PRESENT	0
394376	378093	95063L	PARTICIPANT	\N	PRESENT	0
394377	378093	95037J	PARTICIPANT	\N	PRESENT	0
394378	378093	04071H	PARTICIPANT	\N	PRESENT	0
394379	378093	19637C	PARTICIPANT	\N	PRESENT	0
394380	378093	19697Q	PARTICIPANT	\N	PRESENT	0
394381	378093	19782L	PARTICIPANT	\N	PRESENT	0
394382	378093	08020N	PARTICIPANT	\N	PRESENT	0
421706	421703	19723Y	PARTICIPANT	\N	PRESENT	0
421707	421703	01034P	PARTICIPANT	\N	PRESENT	0
421709	421708	01034P	PARTICIPANT	\N	PRESENT	0
422140	417145	04086Q	PARTICIPANT	\N	PRESENT	0
422141	417145	14231L	PARTICIPANT	\N	PRESENT	0
422142	417145	95063L	PARTICIPANT	\N	PRESENT	0
422143	417145	19687N	PARTICIPANT	\N	PRESENT	0
422144	417145	01057W	PARTICIPANT	\N	PRESENT	0
422775	421729	14259Y	PARTICIPANT	\N	EXCUSE	0
422780	422779	14327T	PARTICIPANT	\N	PRESENT	0
422784	422783	14159V	PARTICIPANT	\N	PRESENT	0
422813	422809	19729F	PARTICIPANT	\N	PRESENT	0
422814	422810	19729F	PARTICIPANT	\N	PRESENT	0
422820	422811	19729F	PARTICIPANT	\N	PRESENT	0
422823	422812	19729F	PARTICIPANT	\N	PRESENT	0
422827	421729	19565D	PARTICIPANT	\N	EXCUSE	0
422832	422687	14229S	PARTICIPANT	\N	EXCUSE	0
422840	422833	14215L	PARTICIPANT	\N	PRESENT	0
422841	422834	14215L	PARTICIPANT	\N	PRESENT	0
422842	422835	14215L	PARTICIPANT	\N	PRESENT	0
422843	422836	14215L	PARTICIPANT	\N	PRESENT	0
422844	422837	19729F	PARTICIPANT	\N	PRESENT	0
422845	422838	19729F	PARTICIPANT	\N	PRESENT	0
422846	422839	19729F	PARTICIPANT	\N	PRESENT	0
422850	422849	14033T	PARTICIPANT	\N	PRESENT	0
422851	422849	14205J	PARTICIPANT	\N	PRESENT	0
422852	422849	14135M	PARTICIPANT	\N	PRESENT	0
422854	422853	08038Y	PARTICIPANT	\N	PRESENT	0
422855	422853	01025N	PARTICIPANT	\N	PRESENT	0
422856	422853	14033T	PARTICIPANT	\N	PRESENT	0
422857	422853	19515S	PARTICIPANT	\N	PRESENT	0
422858	422853	19511N	PARTICIPANT	\N	PRESENT	0
422859	422853	11099A	PARTICIPANT	\N	PRESENT	0
422860	422853	14205J	PARTICIPANT	\N	PRESENT	0
422861	422853	19441R	PARTICIPANT	\N	PRESENT	0
422862	422853	14135M	PARTICIPANT	\N	PRESENT	0
422863	422853	19269X	PARTICIPANT	\N	PRESENT	0
422864	422853	19413M	PARTICIPANT	\N	PRESENT	0
422866	422865	14071N	PARTICIPANT	\N	PRESENT	0
422868	422867	14085U	PARTICIPANT	\N	PRESENT	0
422869	422867	14253S	PARTICIPANT	\N	PRESENT	0
422871	422870	14085U	PARTICIPANT	\N	PRESENT	0
422872	422870	14253S	PARTICIPANT	\N	PRESENT	0
422874	422873	99004R	PARTICIPANT	\N	PRESENT	0
422875	422873	19651A	PARTICIPANT	\N	PRESENT	0
422877	422876	14071N	PARTICIPANT	\N	PRESENT	0
422879	422878	11074Q	PARTICIPANT	\N	PRESENT	0
422883	422880	19515S	PARTICIPANT	\N	PRESENT	0
422884	422881	19515S	PARTICIPANT	\N	PRESENT	0
422885	422882	19515S	PARTICIPANT	\N	PRESENT	0
422890	422886	14031R	PARTICIPANT	\N	PRESENT	0
422891	422887	14031R	PARTICIPANT	\N	PRESENT	0
422892	422888	14031R	PARTICIPANT	\N	PRESENT	0
422893	422889	14031R	PARTICIPANT	\N	PRESENT	0
422909	422908	11072N	PARTICIPANT	\N	PRESENT	0
422911	422910	11072N	PARTICIPANT	\N	PRESENT	0
422919	422912	14087W	PARTICIPANT	\N	PRESENT	0
422920	422913	14087W	PARTICIPANT	\N	PRESENT	0
422921	422914	14087W	PARTICIPANT	\N	PRESENT	0
422922	422914	19521Q	PARTICIPANT	\N	PRESENT	0
422923	422914	19679N	PARTICIPANT	\N	PRESENT	0
422924	422915	14087W	PARTICIPANT	\N	PRESENT	0
422925	422915	19521Q	PARTICIPANT	\N	PRESENT	0
422926	422915	19679N	PARTICIPANT	\N	PRESENT	0
422927	422916	14087W	PARTICIPANT	\N	PRESENT	0
422928	422916	19521Q	PARTICIPANT	\N	PRESENT	0
422929	422917	14087W	PARTICIPANT	\N	PRESENT	0
422930	422917	19521Q	PARTICIPANT	\N	PRESENT	0
422931	422918	14087W	PARTICIPANT	\N	PRESENT	0
422932	422918	19521Q	PARTICIPANT	\N	PRESENT	0
422947	421729	08048B	PARTICIPANT	\N	EXCUSE	0
423084	416129	19387D	PARTICIPANT	\N	PRESENT	0
422961	407836	14147R	PARTICIPANT	\N	PRESENT	0
423083	416129	19820Y	PARTICIPANT	\N	PRESENT	0
423085	416129	19525U	PARTICIPANT	\N	PRESENT	0
423086	416129	08060W	PARTICIPANT	\N	PRESENT	0
423087	416129	14157T	PARTICIPANT	\N	PRESENT	0
423088	416129	19479G	PARTICIPANT	\N	PRESENT	0
423089	416129	19695N	PARTICIPANT	\N	PRESENT	0
423090	416129	14031R	PARTICIPANT	\N	PRESENT	0
423091	416129	19515S	PARTICIPANT	\N	PRESENT	0
423092	416129	19347U	PARTICIPANT	\N	PRESENT	0
423093	416129	19731Y	PARTICIPANT	\N	PRESENT	0
423094	416129	14261S	PARTICIPANT	\N	PRESENT	0
423095	416129	19637C	PARTICIPANT	\N	PRESENT	0
423096	416129	08049C	PARTICIPANT	\N	PRESENT	0
423097	416129	14221J	PARTICIPANT	\N	PRESENT	0
423098	416129	14105F	PARTICIPANT	\N	PRESENT	0
423099	416129	19782L	PARTICIPANT	\N	PRESENT	0
423102	416129	08055A	PARTICIPANT	\N	PRESENT	0
423103	416129	19549D	PARTICIPANT	\N	PRESENT	0
423104	416129	19551W	PARTICIPANT	\N	PRESENT	0
423105	416129	19651A	PARTICIPANT	\N	PRESENT	0
423106	416129	02002K	PARTICIPANT	\N	PRESENT	0
423107	416129	08009T	PARTICIPANT	\N	PRESENT	0
423108	416129	14267Y	PARTICIPANT	\N	PRESENT	0
423109	423100	14021P	PARTICIPANT	\N	PRESENT	0
423110	416129	14219Q	PARTICIPANT	\N	PRESENT	0
423111	416129	08020N	PARTICIPANT	\N	PRESENT	0
423112	416129	19826F	PARTICIPANT	\N	PRESENT	0
423113	416129	19333N	PARTICIPANT	\N	PRESENT	0
423114	416129	14235Q	PARTICIPANT	\N	PRESENT	0
423115	416129	14207L	PARTICIPANT	\N	PRESENT	0
423116	416129	08012N	PARTICIPANT	\N	PRESENT	0
423117	416129	19611R	PARTICIPANT	\N	PRESENT	0
423118	416129	19629C	PARTICIPANT	\N	PRESENT	0
423119	416129	88008L	PARTICIPANT	\N	PRESENT	0
423120	416129	08024S	PARTICIPANT	\N	PRESENT	0
423121	416129	19489J	PARTICIPANT	\N	PRESENT	0
423122	416129	12016W	PARTICIPANT	\N	PRESENT	0
423123	416129	14087W	PARTICIPANT	\N	PRESENT	0
423124	416129	19443T	PARTICIPANT	\N	PRESENT	0
423125	416129	01024M	PARTICIPANT	\N	PRESENT	0
423126	416129	17583W	PARTICIPANT	\N	PRESENT	0
423127	416129	19253P	PARTICIPANT	\N	PRESENT	0
423128	416129	95037J	PARTICIPANT	\N	PRESENT	0
423129	416129	19760E	PARTICIPANT	\N	PRESENT	0
423130	416129	14265W	PARTICIPANT	\N	PRESENT	0
423131	416129	19798U	PARTICIPANT	\N	PRESENT	0
423132	416129	14119M	PARTICIPANT	\N	PRESENT	0
423133	416129	04069P	PARTICIPANT	\N	PRESENT	0
423134	416129	19701S	PARTICIPANT	\N	PRESENT	0
423135	416129	19794Q	PARTICIPANT	\N	PRESENT	0
423136	416129	04088S	PARTICIPANT	\N	PRESENT	0
423137	416129	15447F	PARTICIPANT	\N	PRESENT	0
423138	416129	14041T	PARTICIPANT	\N	PRESENT	0
423139	416129	04085P	PARTICIPANT	\N	PRESENT	0
423140	416129	01025N	PARTICIPANT	\N	PRESENT	0
423141	416129	19725B	PARTICIPANT	\N	PRESENT	0
423142	416129	19349W	PARTICIPANT	\N	PRESENT	0
423143	416129	19687N	PARTICIPANT	\N	PRESENT	0
423144	416129	04059M	PARTICIPANT	\N	PRESENT	0
423145	416129	14231L	PARTICIPANT	\N	PRESENT	0
423146	416129	19697Q	PARTICIPANT	\N	PRESENT	0
423147	416129	19703U	PARTICIPANT	\N	PRESENT	0
423148	416129	14103D	PARTICIPANT	\N	PRESENT	0
423149	416129	19739H	PARTICIPANT	\N	PRESENT	0
423150	416129	01028R	PARTICIPANT	\N	PRESENT	0
423151	416129	11103C	PARTICIPANT	\N	PRESENT	0
423152	416129	19533U	PARTICIPANT	\N	PRESENT	0
423153	416129	08056B	PARTICIPANT	\N	PRESENT	0
423154	416129	98050T	PARTICIPANT	\N	PRESENT	0
423155	416129	11012A	PARTICIPANT	\N	PRESENT	0
423156	416129	14151M	PARTICIPANT	\N	PRESENT	0
423157	416129	19543W	PARTICIPANT	\N	PRESENT	0
423158	422485	95041E	PARTICIPANT	\N	PRESENT	0
423159	422485	08034U	PARTICIPANT	\N	PRESENT	0
423160	422485	99004R	PARTICIPANT	\N	PRESENT	0
423162	416129	19631V	PARTICIPANT	\N	PRESENT	0
423163	416129	14030Q	PARTICIPANT	\N	PRESENT	0
423164	422485	14327T	PRESIDENT	0	PRESENT	0
423165	422485	14083S	PARTICIPANT	\N	PRESENT	0
423166	422485	08011M	PARTICIPANT	\N	PRESENT	0
423167	422485	19671E	PARTICIPANT	\N	PRESENT	0
423168	422485	07029T	PARTICIPANT	\N	EXCUSE	0
423169	422485	19479G	PARTICIPANT	\N	PRESENT	0
423170	422485	14085U	PARTICIPANT	\N	PRESENT	0
423171	422485	19689Q	PARTICIPANT	\N	PRESENT	0
423172	416129	14107H	PARTICIPANT	\N	PRESENT	0
423173	416129	19719D	PARTICIPANT	\N	PRESENT	0
423175	416129	11104D	PARTICIPANT	\N	PRESENT	0
423176	423007	14179A	PARTICIPANT	\N	PRESENT	0
423177	416129	95030B	PARTICIPANT	\N	PRESENT	0
423178	416129	04043D	PARTICIPANT	\N	PRESENT	0
423179	422485	14331P	PARTICIPANT	\N	PRESENT	0
423180	422485	11048N	PARTICIPANT	\N	PRESENT	0
423181	422485	01048V	PARTICIPANT	\N	PRESENT	0
423182	422485	01057W	PARTICIPANT	\N	PRESENT	0
396596	396433	11070L	PARTICIPANT	\N	PRESENT	0
396597	396433	19647E	PARTICIPANT	\N	PRESENT	0
399841	397657	08053X	PARTICIPANT	\N	EXCUSE	0
399842	397657	14028W	PARTICIPANT	\N	EXCUSE	0
399926	398232	11081P	PARTICIPANT	\N	EXCUSE	0
399927	398232	14329V	PARTICIPANT	\N	EXCUSE	0
399934	398232	19812Y	PARTICIPANT	\N	PRESENT	0
399975	399906	19766L	PARTICIPANT	\N	EXCUSE	0
399977	399906	11109J	PARTICIPANT	\N	PRESENT	0
399978	399906	19621T	PARTICIPANT	\N	PRESENT	0
399979	399906	14249W	PARTICIPANT	\N	PRESENT	0
399980	399906	11083R	PARTICIPANT	\N	PRESENT	0
399981	399906	04057K	PARTICIPANT	\N	PRESENT	0
399982	399906	04018C	PARTICIPANT	\N	PRESENT	0
405287	405111	19737F	PARTICIPANT	\N	PRESENT	0
406066	405690	08060W	PARTICIPANT	\N	PRESENT	0
406067	405690	19489J	PARTICIPANT	\N	PRESENT	0
406068	405690	14105F	PARTICIPANT	\N	PRESENT	0
406069	405690	05008E	PARTICIPANT	\N	PRESENT	0
406070	405690	11090Q	PARTICIPANT	\N	PRESENT	0
406071	405690	14191V	PARTICIPANT	\N	PRESENT	0
406072	405690	11056N	PARTICIPANT	\N	PRESENT	0
406073	405690	11054L	PARTICIPANT	\N	PRESENT	0
406074	405690	02002K	PARTICIPANT	\N	PRESENT	0
406075	405690	14079W	PARTICIPANT	\N	PRESENT	0
406076	405690	08058D	PARTICIPANT	\N	PRESENT	0
406077	405690	01048V	PARTICIPANT	\N	PRESENT	0
406352	402266	14034U	PARTICIPANT	\N	PRESENT	0
406353	402266	01028R	PARTICIPANT	\N	PRESENT	0
406354	402266	80013X	PARTICIPANT	\N	PRESENT	0
406355	402266	08060W	PARTICIPANT	\N	PRESENT	0
406356	402266	11033F	PARTICIPANT	\N	PRESENT	0
406357	402266	08009T	PARTICIPANT	\N	PRESENT	0
406358	402266	19701S	PARTICIPANT	\N	PRESENT	0
406359	402266	19503N	PARTICIPANT	\N	PRESENT	0
406360	402266	19551W	PARTICIPANT	\N	PRESENT	0
406361	402266	19683J	PARTICIPANT	\N	PRESENT	0
406362	402266	11109J	PARTICIPANT	\N	PRESENT	0
406363	402266	19727D	PARTICIPANT	\N	PRESENT	0
406364	402266	19715Y	PARTICIPANT	\N	PRESENT	0
406365	402266	19599P	PARTICIPANT	\N	PRESENT	0
406366	402266	19549D	PARTICIPANT	\N	PRESENT	0
406367	402266	19651A	PARTICIPANT	\N	PRESENT	0
406368	402266	19782L	PARTICIPANT	\N	PRESENT	0
406369	402266	19333N	PARTICIPANT	\N	PRESENT	0
406370	402266	14121F	PARTICIPANT	\N	PRESENT	0
406371	402266	19253P	PARTICIPANT	\N	PRESENT	0
406372	402266	14327T	PARTICIPANT	\N	PRESENT	0
406373	402266	19713W	PARTICIPANT	\N	PRESENT	0
406374	402266	14219Q	PARTICIPANT	\N	PRESENT	0
406375	402266	19441R	PARTICIPANT	\N	PRESENT	0
406376	402266	14205J	PARTICIPANT	\N	PRESENT	0
406377	402266	19737F	PARTICIPANT	\N	PRESENT	0
406378	402266	19691J	PARTICIPANT	\N	PRESENT	0
406379	402266	14073Q	PARTICIPANT	\N	PRESENT	0
406380	402266	14089Y	PARTICIPANT	\N	PRESENT	0
406381	402266	19349W	PARTICIPANT	\N	PRESENT	0
406382	402266	08055A	PARTICIPANT	\N	PRESENT	0
406383	402266	07033P	PARTICIPANT	\N	PRESENT	0
406384	402266	19711U	PARTICIPANT	\N	PRESENT	0
406385	402266	14119M	PARTICIPANT	\N	PRESENT	0
406386	402266	14031R	PARTICIPANT	\N	PRESENT	0
406387	402266	14169X	PARTICIPANT	\N	PRESENT	0
406388	402266	19794Q	PARTICIPANT	\N	PRESENT	0
406389	402266	19573D	PARTICIPANT	\N	PRESENT	0
406390	402266	14029X	PARTICIPANT	\N	PRESENT	0
406391	402266	19681G	PARTICIPANT	\N	PRESENT	0
406392	402266	14173T	PARTICIPANT	\N	PRESENT	0
406393	402266	95037J	PARTICIPANT	\N	PRESENT	0
406394	402266	19637C	PARTICIPANT	\N	PRESENT	0
406395	402266	11067R	PARTICIPANT	\N	PRESENT	0
406396	402266	14109K	PARTICIPANT	\N	PRESENT	0
406397	402266	08024S	PARTICIPANT	\N	PRESENT	0
406398	402266	19703U	PARTICIPANT	\N	PRESENT	0
406399	405391	19768N	PARTICIPANT	\N	PRESENT	0
406400	405391	19515S	PARTICIPANT	\N	PRESENT	0
406401	405391	14357A	PARTICIPANT	\N	PRESENT	0
406402	405391	14187A	PARTICIPANT	\N	PRESENT	0
406403	405391	11090Q	PRESIDENT	0	PRESENT	0
406404	405391	80013X	PARTICIPANT	\N	PRESENT	0
406405	405391	04088S	PARTICIPANT	\N	PRESENT	0
406406	405391	08068F	PARTICIPANT	\N	PRESENT	0
406407	405391	19507S	PARTICIPANT	\N	PRESENT	0
406408	405391	14197C	PARTICIPANT	\N	PRESENT	0
406409	405391	14207L	PARTICIPANT	\N	PRESENT	0
406410	405391	08028W	PRESIDENT	1	PRESENT	0
406411	405391	14265W	PARTICIPANT	\N	PRESENT	0
406412	405391	19619A	PARTICIPANT	\N	PRESENT	0
406413	405391	14257W	PARTICIPANT	\N	PRESENT	0
406414	402266	14231L	PARTICIPANT	\N	PRESENT	0
406415	402266	19629C	PARTICIPANT	\N	PRESENT	0
406416	402266	14281W	PARTICIPANT	\N	PRESENT	0
406417	402266	19593H	PARTICIPANT	\N	PRESENT	0
406418	402266	19347U	PARTICIPANT	\N	PRESENT	0
406419	402266	14223L	PARTICIPANT	\N	PRESENT	0
406420	402266	19367Y	PARTICIPANT	\N	PRESENT	0
406421	405432	14089Y	PARTICIPANT	\N	PRESENT	0
406422	405432	19489J	PARTICIPANT	\N	PRESENT	0
406423	405432	14111D	PARTICIPANT	\N	PRESENT	0
406424	405432	14001X	PARTICIPANT	\N	PRESENT	0
406425	405432	14147R	PARTICIPANT	\N	PRESENT	0
406426	405432	19585H	PARTICIPANT	\N	PRESENT	0
406427	405432	05008E	PRESIDENT	0	PRESENT	0
406428	405432	14179A	PARTICIPANT	\N	PRESENT	0
406429	405432	11049P	PARTICIPANT	\N	PRESENT	0
406430	405432	19729F	PARTICIPANT	\N	EXCUSE	0
406431	405432	14065Q	PARTICIPANT	\N	EXCUSE	0
406432	405432	08045X	PARTICIPANT	\N	EXCUSE	0
406433	405432	01024M	PARTICIPANT	\N	EXCUSE	0
406434	405432	19581D	PARTICIPANT	\N	EXCUSE	0
406435	405391	14135M	PARTICIPANT	\N	PRESENT	0
406436	405391	19782L	PARTICIPANT	\N	PRESENT	0
406437	405391	19441R	PARTICIPANT	\N	PRESENT	0
406438	405391	19413M	PARTICIPANT	\N	PRESENT	0
406439	405391	19695N	PARTICIPANT	\N	PRESENT	0
406440	405391	14033T	PARTICIPANT	\N	PRESENT	0
406441	405391	08015R	PARTICIPANT	\N	PRESENT	0
406442	405391	19369B	PARTICIPANT	\N	PRESENT	0
406443	405391	19747H	PARTICIPANT	\N	PRESENT	0
406444	405391	08038Y	PARTICIPANT	\N	EXCUSE	0
406445	405391	01025N	PARTICIPANT	\N	EXCUSE	0
406446	405391	11081P	PARTICIPANT	\N	EXCUSE	0
406447	405391	17589D	PARTICIPANT	\N	EXCUSE	0
406448	405432	01028R	PARTICIPANT	\N	PRESENT	0
406449	405432	14053L	PARTICIPANT	\N	EXCUSE	0
406450	405432	19543W	PARTICIPANT	\N	EXCUSE	0
406451	405432	04044E	PARTICIPANT	\N	EXCUSE	0
406452	405432	14215L	PARTICIPANT	\N	EXCUSE	0
406453	405432	19673G	PARTICIPANT	\N	EXCUSE	0
406454	405432	19447X	PARTICIPANT	\N	EXCUSE	0
406455	402266	95030B	PARTICIPANT	\N	PRESENT	0
406456	402266	04049K	PARTICIPANT	\N	PRESENT	0
406457	402266	08034U	PARTICIPANT	\N	PRESENT	0
406458	402266	19733B	PARTICIPANT	\N	PRESENT	0
406459	402266	14038Y	PARTICIPANT	\N	PRESENT	0
406460	402266	19760E	PARTICIPANT	\N	PRESENT	0
406461	402266	19565D	PARTICIPANT	\N	PRESENT	0
406462	402266	04085P	PARTICIPANT	\N	PRESENT	0
406463	402266	14217N	PARTICIPANT	\N	PRESENT	0
406464	402266	14157T	PARTICIPANT	\N	PRESENT	0
406465	402266	14021P	PARTICIPANT	\N	PRESENT	0
406466	402266	19689Q	PARTICIPANT	\N	PRESENT	0
406467	402266	14079W	PARTICIPANT	\N	PRESENT	0
406468	402266	19621T	PARTICIPANT	\N	PRESENT	0
406469	402266	08020N	PARTICIPANT	\N	PRESENT	0
406470	402266	19387D	PARTICIPANT	\N	PRESENT	0
406471	402266	19575F	PARTICIPANT	\N	PRESENT	0
406472	402266	14071N	PARTICIPANT	\N	PRESENT	0
406473	405391	19511N	PARTICIPANT	\N	PRESENT	0
406474	405391	19467C	PARTICIPANT	\N	PRESENT	0
406475	405391	19295A	PARTICIPANT	\N	PRESENT	0
406476	405391	11056N	PARTICIPANT	\N	PRESENT	0
406477	405391	08019V	PARTICIPANT	\N	EXCUSE	0
406478	402266	19563B	PARTICIPANT	\N	PRESENT	0
406479	402266	19719D	PARTICIPANT	\N	PRESENT	0
406480	402266	11048N	PARTICIPANT	\N	PRESENT	0
406481	402266	08056B	PARTICIPANT	\N	PRESENT	0
406482	402266	19553Y	PARTICIPANT	\N	PRESENT	0
406483	402266	07029T	PARTICIPANT	\N	PRESENT	0
406484	402266	19611R	PARTICIPANT	\N	PRESENT	0
406485	402266	11065P	PARTICIPANT	\N	PRESENT	0
406486	402266	19749K	PARTICIPANT	\N	PRESENT	0
406487	402266	01057W	PARTICIPANT	\N	PRESENT	0
406488	402266	14195A	PARTICIPANT	\N	PRESENT	0
406489	402266	11012A	PARTICIPANT	\N	PRESENT	0
406490	402266	89017R	PARTICIPANT	\N	PRESENT	0
406491	402266	11099A	PARTICIPANT	\N	PRESENT	0
406492	402266	17583W	PARTICIPANT	\N	PRESENT	0
406493	402266	14030Q	PARTICIPANT	\N	PRESENT	0
416942	416941	14211G	PARTICIPANT	\N	PRESENT	0
416943	416941	19669L	PARTICIPANT	\N	PRESENT	0
416953	416944	11074Q	PARTICIPANT	\N	PRESENT	0
416958	416957	89017R	PARTICIPANT	\N	PRESENT	0
416959	416957	04085P	PARTICIPANT	\N	PRESENT	0
416960	416957	05008E	PARTICIPANT	\N	PRESENT	0
416961	416957	96004D	PARTICIPANT	\N	PRESENT	0
416962	416957	04042C	PARTICIPANT	\N	PRESENT	0
416963	416957	11053K	PARTICIPANT	\N	PRESENT	0
416964	416957	14079W	PARTICIPANT	\N	PRESENT	0
416965	416957	11074Q	PARTICIPANT	\N	PRESENT	0
416966	416957	14187A	PARTICIPANT	\N	PRESENT	0
416967	416957	14034U	PARTICIPANT	\N	PRESENT	0
416968	416957	14021P	PARTICIPANT	\N	PRESENT	0
416969	416957	01043Q	PARTICIPANT	\N	PRESENT	0
416970	416957	11085T	PARTICIPANT	\N	PRESENT	0
416971	416957	08009T	PARTICIPANT	\N	PRESENT	0
416972	416957	04092N	PARTICIPANT	\N	PRESENT	0
416973	416957	11072N	PARTICIPANT	\N	PRESENT	0
416974	416957	04070G	PARTICIPANT	\N	PRESENT	0
416975	416957	08061X	PARTICIPANT	\N	PRESENT	0
416976	416957	11090Q	PARTICIPANT	\N	PRESENT	0
416977	416957	11012A	PARTICIPANT	\N	PRESENT	0
416978	416957	04044E	PARTICIPANT	\N	PRESENT	0
416979	416957	01034P	PARTICIPANT	\N	PRESENT	0
417134	417133	19621T	PARTICIPANT	\N	PRESENT	0
417135	417131	19621T	PARTICIPANT	\N	PRESENT	0
417136	417131	19611R	PARTICIPANT	\N	PRESENT	0
417137	417131	19593H	PARTICIPANT	\N	PRESENT	0
417139	417132	19611R	PARTICIPANT	\N	PRESENT	0
417140	417132	19621T	PARTICIPANT	\N	PRESENT	0
417142	417132	19593H	PARTICIPANT	\N	PRESENT	0
417143	417132	08043V	PARTICIPANT	\N	PRESENT	0
417144	417132	14229S	PARTICIPANT	\N	PRESENT	0
417147	417146	19699S	PARTICIPANT	\N	PRESENT	0
417149	417148	08012N	PARTICIPANT	\N	PRESENT	0
417151	417150	08012N	PARTICIPANT	\N	PRESENT	0
417153	417152	08012N	PARTICIPANT	\N	PRESENT	0
417155	417154	19693L	PARTICIPANT	\N	PRESENT	0
417162	417161	01034P	PARTICIPANT	\N	PRESENT	0
417163	417161	19679N	PARTICIPANT	\N	PRESENT	0
417164	417161	11097X	PARTICIPANT	\N	PRESENT	0
417165	417161	14195A	PARTICIPANT	\N	PRESENT	0
417166	417160	11097X	PARTICIPANT	\N	PRESENT	0
417167	417160	08052W	PARTICIPANT	\N	PRESENT	0
417168	417160	01034P	PARTICIPANT	\N	PRESENT	0
417349	417348	08019V	PARTICIPANT	\N	PRESENT	0
417379	404748	19503N	PARTICIPANT	\N	PRESENT	0
417381	410802	19503N	PARTICIPANT	\N	PRESENT	0
417383	410803	19503N	PARTICIPANT	\N	PRESENT	0
417385	417384	11027H	PARTICIPANT	\N	PRESENT	0
417386	417384	14193X	PARTICIPANT	\N	PRESENT	0
417422	417321	14039A	PARTICIPANT	\N	PRESENT	0
417431	417154	19593H	PARTICIPANT	\N	PRESENT	0
417432	417429	14073Q	PARTICIPANT	\N	PRESENT	0
417433	417428	14073Q	PARTICIPANT	\N	PRESENT	0
417436	417434	19533U	PARTICIPANT	\N	PRESENT	0
417437	417435	19533U	PARTICIPANT	\N	PRESENT	0
417527	417523	11053K	PARTICIPANT	\N	PRESENT	0
417528	417523	05012A	PARTICIPANT	\N	PRESENT	0
417533	417532	11053K	PARTICIPANT	\N	PRESENT	0
417534	417532	14159V	PARTICIPANT	\N	PRESENT	0
417535	417532	05012A	PARTICIPANT	\N	PRESENT	0
418274	416986	08056B	PARTICIPANT	\N	PRESENT	0
418275	416986	04035D	PARTICIPANT	\N	PRESENT	0
418276	416986	14079W	PARTICIPANT	\N	PRESENT	0
418277	416986	08049C	PARTICIPANT	\N	PRESENT	0
418278	416986	04042C	PRESIDENT	0	PRESENT	0
418279	416986	11066Q	PARTICIPANT	\N	PRESENT	0
418280	416986	14211G	PARTICIPANT	\N	PRESENT	0
418281	416986	16685X	PARTICIPANT	\N	PRESENT	0
418627	416543	14097Y	PARTICIPANT	\N	PRESENT	0
418628	416543	14133K	PARTICIPANT	\N	PRESENT	0
418629	416543	01062T	PARTICIPANT	\N	PRESENT	0
418630	416543	04034C	PARTICIPANT	\N	PRESENT	0
418631	416543	14235Q	PARTICIPANT	\N	PRESENT	0
418632	416543	04040A	PARTICIPANT	\N	PRESENT	0
418633	416543	16685X	PARTICIPANT	\N	PRESENT	0
418634	416543	11027H	PARTICIPANT	\N	PRESENT	0
418635	416543	08058D	PARTICIPANT	\N	PRESENT	0
418636	416543	04042C	PRESIDENT	0	PRESENT	0
418637	416543	19251M	PARTICIPANT	\N	PRESENT	0
418638	416543	11054L	PARTICIPANT	\N	PRESENT	0
418639	416543	11066Q	PARTICIPANT	\N	PRESENT	0
418640	416543	19721W	PARTICIPANT	\N	PRESENT	0
418641	416543	98018T	PRESIDENT	1	PRESENT	0
418642	416543	19421M	PARTICIPANT	\N	PRESENT	0
418643	416543	98022P	PARTICIPANT	\N	PRESENT	0
418644	416543	14267Y	PARTICIPANT	\N	PRESENT	0
418645	416543	14193X	PARTICIPANT	\N	PRESENT	0
418646	416543	11064N	PARTICIPANT	\N	PRESENT	0
418647	416543	98050T	PARTICIPANT	\N	PRESENT	0
418648	416543	97011G	PARTICIPANT	\N	PRESENT	0
418649	416543	14211G	PARTICIPANT	\N	PRESENT	0
418650	416543	08047A	PARTICIPANT	\N	PRESENT	0
418651	416543	14079W	PARTICIPANT	\N	PRESENT	0
418652	416543	01058X	PARTICIPANT	\N	PRESENT	0
418653	416543	11041F	PARTICIPANT	\N	PRESENT	0
418654	416543	95037J	PARTICIPANT	\N	PRESENT	0
418655	416543	08061X	PARTICIPANT	\N	PRESENT	0
418656	416543	08049C	PARTICIPANT	\N	PRESENT	0
418657	416543	95067Q	PARTICIPANT	\N	PRESENT	0
418658	416543	98029W	PARTICIPANT	\N	PRESENT	0
418659	416543	08056B	PARTICIPANT	\N	PRESENT	0
418733	415001	19333N	PARTICIPANT	\N	PRESENT	0
418734	415001	19383Y	PARTICIPANT	\N	PRESENT	0
418735	415001	17583W	PARTICIPANT	\N	PRESENT	0
418736	415001	19794Q	PARTICIPANT	\N	PRESENT	0
418737	415001	19387D	PARTICIPANT	\N	PRESENT	0
418738	415001	14219Q	PARTICIPANT	\N	PRESENT	0
418739	415001	19820Y	PARTICIPANT	\N	PRESENT	0
418740	415001	19826F	PARTICIPANT	\N	PRESENT	0
418741	415001	14221J	PARTICIPANT	\N	PRESENT	0
418742	415001	19599P	PARTICIPANT	\N	PRESENT	0
418743	415001	19637C	PARTICIPANT	\N	PRESENT	0
418744	415001	14237S	PARTICIPANT	\N	PRESENT	0
418745	415001	19551W	PARTICIPANT	\N	PRESENT	0
418746	415001	08060W	PARTICIPANT	\N	PRESENT	0
418747	415001	19503N	PARTICIPANT	\N	PRESENT	0
418748	415001	14157T	PARTICIPANT	\N	PRESENT	0
418795	416166	08028W	PARTICIPANT	\N	PRESENT	0
418750	415001	14038Y	PARTICIPANT	\N	PRESENT	0
418751	415001	14103D	PARTICIPANT	\N	PRESENT	0
418752	415001	08055A	PARTICIPANT	\N	PRESENT	0
418753	415001	14191V	PARTICIPANT	\N	PRESENT	0
418754	415001	14169X	PARTICIPANT	\N	PRESENT	0
418755	415001	15447F	PARTICIPANT	\N	PRESENT	0
418756	415001	08009T	PRESIDENT	0	PRESENT	0
418757	415001	19737F	PARTICIPANT	\N	PRESENT	0
418758	415001	19745F	PARTICIPANT	\N	PRESENT	0
418759	415001	14051J	PARTICIPANT	\N	EXCUSE	0
418760	416166	19515S	PARTICIPANT	\N	PRESENT	0
418761	416166	11077T	PARTICIPANT	\N	PRESENT	0
418762	416166	19782L	PARTICIPANT	\N	PRESENT	0
418763	416166	19441R	PARTICIPANT	\N	PRESENT	0
418764	416166	19413M	PARTICIPANT	\N	PRESENT	0
418765	416166	80013X	PARTICIPANT	\N	PRESENT	0
418766	416166	19631V	PARTICIPANT	\N	PRESENT	0
418767	416166	08068F	PARTICIPANT	\N	PRESENT	0
418768	416166	08015R	PARTICIPANT	\N	PRESENT	0
418769	416166	14197C	PARTICIPANT	\N	PRESENT	0
418770	416166	19369B	PARTICIPANT	\N	PRESENT	0
418771	416166	19511N	PARTICIPANT	\N	PRESENT	0
418772	416166	14329V	PARTICIPANT	\N	PRESENT	0
418773	416166	19467C	PARTICIPANT	\N	PRESENT	0
418774	416166	14187A	PARTICIPANT	\N	PRESENT	0
418775	416166	08038Y	PARTICIPANT	\N	PRESENT	0
418776	416166	08062Y	PARTICIPANT	\N	PRESENT	0
418777	416166	01025N	PARTICIPANT	\N	PRESENT	0
418778	416166	11090Q	PRESIDENT	0	PRESENT	0
418779	416166	14033T	PARTICIPANT	\N	PRESENT	0
418780	416166	14205J	PARTICIPANT	\N	PRESENT	0
418781	416166	04088S	PARTICIPANT	\N	PRESENT	0
418782	416166	04089T	PARTICIPANT	\N	PRESENT	0
418783	416166	14115H	PARTICIPANT	\N	PRESENT	0
418784	416166	19507S	PARTICIPANT	\N	PRESENT	0
418785	416166	14257W	PARTICIPANT	\N	PRESENT	0
418786	415001	19549D	PARTICIPANT	\N	PRESENT	0
418787	415001	19713W	PARTICIPANT	\N	PRESENT	0
418788	416543	08053X	PARTICIPANT	\N	PRESENT	0
418789	415001	05012A	PARTICIPANT	\N	PRESENT	0
418790	415001	19681G	PARTICIPANT	\N	PRESENT	0
418791	415001	19701S	PARTICIPANT	\N	PRESENT	0
418792	416166	19768N	PARTICIPANT	\N	PRESENT	0
418793	416166	14081Q	PARTICIPANT	\N	PRESENT	0
418794	416166	19705W	PARTICIPANT	\N	PRESENT	0
394383	378093	19659J	PARTICIPANT	\N	PRESENT	0
394384	378093	19766L	PARTICIPANT	\N	PRESENT	0
394385	378093	19269X	PARTICIPANT	\N	PRESENT	0
394386	378093	01057W	PARTICIPANT	\N	PRESENT	0
394387	378093	02002K	PARTICIPANT	\N	PRESENT	0
394388	378093	14111D	PARTICIPANT	\N	PRESENT	0
394389	378093	19545Y	PARTICIPANT	\N	PRESENT	0
394390	378093	04057K	PARTICIPANT	\N	PRESENT	0
394391	378093	11064N	PARTICIPANT	\N	PRESENT	0
394392	378093	17589D	PARTICIPANT	\N	PRESENT	0
394393	378093	19563B	PARTICIPANT	\N	PRESENT	0
394394	378093	14199E	PARTICIPANT	\N	PRESENT	0
394395	378093	14251Q	PARTICIPANT	\N	PRESENT	0
394396	378093	11012A	PARTICIPANT	\N	PRESENT	0
394397	378093	14173T	PARTICIPANT	\N	PRESENT	0
394398	378093	08031R	PARTICIPANT	\N	PRESENT	0
394399	378093	88008L	PARTICIPANT	\N	PRESENT	0
394400	378093	19573D	PARTICIPANT	\N	PRESENT	0
394401	378093	19629C	PARTICIPANT	\N	PRESENT	0
394402	378093	92040Q	PARTICIPANT	\N	PRESENT	0
394403	378093	14119M	PARTICIPANT	\N	PRESENT	0
394404	378093	14107H	PARTICIPANT	\N	PRESENT	0
394405	378093	11099A	PARTICIPANT	\N	PRESENT	0
394406	378093	19585H	PARTICIPANT	\N	PRESENT	0
394407	378093	14021P	PARTICIPANT	\N	PRESENT	0
394408	378093	19731Y	PARTICIPANT	\N	PRESENT	0
394409	378093	89017R	PARTICIPANT	\N	PRESENT	0
394410	378093	11049P	PARTICIPANT	\N	PRESENT	0
394411	378093	19685L	PARTICIPANT	\N	PRESENT	0
394412	378093	19399H	PARTICIPANT	\N	PRESENT	0
394413	378093	14229S	PARTICIPANT	\N	PRESENT	0
394414	378093	14159V	PARTICIPANT	\N	PRESENT	0
394415	378093	04042C	PARTICIPANT	\N	PRESENT	0
394416	378093	11027H	PARTICIPANT	\N	PRESENT	0
394417	378093	11074Q	PARTICIPANT	\N	PRESENT	0
394418	378093	19689Q	PARTICIPANT	\N	PRESENT	0
394419	378093	08055A	PARTICIPANT	\N	PRESENT	0
394420	378093	19673G	PARTICIPANT	\N	PRESENT	0
394421	378093	08045X	PARTICIPANT	\N	PRESENT	0
394422	378093	19575F	PARTICIPANT	\N	PRESENT	0
394423	378093	04088S	PARTICIPANT	\N	PRESENT	0
394424	378093	14065Q	PARTICIPANT	\N	PRESENT	0
394425	378093	08018U	PARTICIPANT	\N	PRESENT	0
394426	378093	14281W	PARTICIPANT	\N	PRESENT	0
394427	378093	14227Q	PARTICIPANT	\N	PRESENT	0
394428	378093	14001X	PARTICIPANT	\N	PRESENT	0
394429	378093	19705W	PARTICIPANT	\N	PRESENT	0
394430	378093	11110B	PARTICIPANT	\N	PRESENT	0
394431	378093	19663E	PARTICIPANT	\N	PRESENT	0
394432	378093	14081Q	PARTICIPANT	\N	PRESENT	0
394433	378093	11067R	PARTICIPANT	\N	PRESENT	0
394434	378093	19503N	PARTICIPANT	\N	PRESENT	0
394435	378093	19591F	PARTICIPANT	\N	PRESENT	0
394436	378093	14059S	PARTICIPANT	\N	PRESENT	0
394437	378093	19413M	PARTICIPANT	\N	PRESENT	0
394438	378093	14329V	PARTICIPANT	\N	PRESENT	0
394439	378093	11054L	PARTICIPANT	\N	PRESENT	0
394440	378093	11109J	PARTICIPANT	\N	PRESENT	0
394441	378093	80027E	PARTICIPANT	\N	PRESENT	0
394442	378093	08058D	PARTICIPANT	\N	PRESENT	0
394443	378093	19701S	PARTICIPANT	\N	PRESENT	0
394444	378093	08012N	PARTICIPANT	\N	PRESENT	0
394445	378093	08035V	PARTICIPANT	\N	PRESENT	0
394446	378093	11045K	PARTICIPANT	\N	PRESENT	0
394447	378093	04089T	PARTICIPANT	\N	PRESENT	0
394448	378093	08044W	PARTICIPANT	\N	PRESENT	0
394449	378093	19621T	PARTICIPANT	\N	PRESENT	0
394450	378093	14179A	PARTICIPANT	\N	PRESENT	0
394451	378093	01034P	PARTICIPANT	\N	PRESENT	0
394452	378093	08009T	PARTICIPANT	\N	PRESENT	0
394453	378093	04049K	PARTICIPANT	\N	PRESENT	0
394454	378093	19619A	PARTICIPANT	\N	PRESENT	0
394455	378093	11090Q	PARTICIPANT	\N	PRESENT	0
394456	378093	19721W	PARTICIPANT	\N	PRESENT	0
394457	378093	14219Q	PARTICIPANT	\N	PRESENT	0
394459	378093	19713W	PARTICIPANT	\N	PRESENT	0
394460	378093	14265W	PARTICIPANT	\N	PRESENT	0
394461	378093	08056B	PARTICIPANT	\N	PRESENT	0
394463	378093	08048B	PARTICIPANT	\N	PRESENT	0
394464	378093	04035D	PARTICIPANT	\N	PRESENT	0
394465	378093	05012A	PARTICIPANT	\N	PRESENT	0
394466	378093	19717B	PARTICIPANT	\N	PRESENT	0
394467	378093	19543W	PARTICIPANT	\N	PRESENT	0
394468	378093	01043Q	PARTICIPANT	\N	PRESENT	0
394469	378093	14030Q	PARTICIPANT	\N	PRESENT	0
394470	378093	14327T	PARTICIPANT	\N	PRESENT	0
394471	378093	19593H	PARTICIPANT	\N	PRESENT	0
394472	378093	11065P	PARTICIPANT	\N	PRESENT	0
394473	378093	14093U	PARTICIPANT	\N	PRESENT	0
394474	378093	04092N	PARTICIPANT	\N	PRESENT	0
394475	378093	01025N	PARTICIPANT	\N	PRESENT	0
394476	378093	01024M	PARTICIPANT	\N	PRESENT	0
394477	378093	14071N	PARTICIPANT	\N	PRESENT	0
394478	378093	04070G	PARTICIPANT	\N	PRESENT	0
394479	378093	19421M	PARTICIPANT	\N	PRESENT	0
394480	378093	11085T	PARTICIPANT	\N	PRESENT	0
394481	378093	11070L	PARTICIPANT	\N	PRESENT	0
394482	378093	04044E	PARTICIPANT	\N	PRESENT	0
394483	378093	14205J	PARTICIPANT	\N	PRESENT	0
394484	378093	19521Q	PARTICIPANT	\N	PRESENT	0
394485	378093	95041E	PARTICIPANT	\N	PRESENT	0
394486	378093	19631V	PARTICIPANT	\N	PRESENT	0
394487	378093	19749K	PARTICIPANT	\N	PRESENT	0
394488	378093	19745F	PARTICIPANT	\N	PRESENT	0
394489	378093	04047H	PARTICIPANT	\N	PRESENT	0
394490	378093	19739H	PARTICIPANT	\N	PRESENT	0
394491	378093	19335Q	PARTICIPANT	\N	PRESENT	0
394492	378093	14026U	PARTICIPANT	\N	PRESENT	0
394493	378093	14257W	PARTICIPANT	\N	PRESENT	0
394494	378093	19741B	PARTICIPANT	\N	PRESENT	0
394495	378093	04008A	PARTICIPANT	\N	PRESENT	0
394496	378093	05008E	PARTICIPANT	\N	PRESENT	0
394499	378093	19441R	PARTICIPANT	\N	PRESENT	0
394500	378093	14255U	PARTICIPANT	\N	PRESENT	0
394507	378093	19553Y	PARTICIPANT	\N	PRESENT	0
394502	378093	11026G	PARTICIPANT	\N	PRESENT	0
394503	378093	08053X	PARTICIPANT	\N	PRESENT	0
394504	378093	19369B	PARTICIPANT	\N	PRESENT	0
394505	378093	95067Q	PARTICIPANT	\N	PRESENT	0
394506	378093	14053L	PARTICIPANT	\N	PRESENT	0
394508	378093	14083S	PARTICIPANT	\N	PRESENT	0
394509	378093	14215L	PARTICIPANT	\N	PRESENT	0
394510	378093	14033T	PARTICIPANT	\N	PRESENT	0
394511	378093	19551W	PARTICIPANT	\N	PRESENT	0
394513	378093	07004J	PARTICIPANT	\N	PRESENT	0
394514	378093	19531S	PARTICIPANT	\N	PRESENT	0
394526	378093	11043H	PARTICIPANT	\N	PRESENT	0
394527	378093	01048V	PARTICIPANT	\N	PRESENT	0
394528	378093	14034U	PARTICIPANT	\N	PRESENT	0
394529	378093	01060R	PARTICIPANT	\N	PRESENT	0
394530	378093	19599P	PARTICIPANT	\N	PRESENT	0
394531	378093	14259Y	PARTICIPANT	\N	PRESENT	0
394814	378095	14034U	PARTICIPANT	\N	PRESENT	0
394817	394816	19725B	PRESIDENT	0	PRESENT	0
394818	394816	14327T	PARTICIPANT	\N	PRESENT	0
394819	394816	11056N	PARTICIPANT	\N	PRESENT	0
394820	394816	04057K	PARTICIPANT	\N	PRESENT	0
394821	394816	08073C	PARTICIPANT	\N	PRESENT	0
394822	394816	14107H	PARTICIPANT	\N	PRESENT	0
394823	394816	19441R	PARTICIPANT	\N	PRESENT	0
394824	394816	19747H	PARTICIPANT	\N	PRESENT	0
394825	394816	14030Q	PARTICIPANT	\N	PRESENT	0
394826	394816	08015R	PARTICIPANT	\N	EXCUSE	0
394827	394816	14026U	PARTICIPANT	\N	EXCUSE	0
395025	378092	07029T	PARTICIPANT	\N	PRESENT	0
395026	378092	19383Y	PARTICIPANT	\N	PRESENT	0
395157	395156	14065Q	PARTICIPANT	\N	PRESENT	0
395158	395156	10015M	PARTICIPANT	\N	PRESENT	0
399768	398300	05012A	PARTICIPANT	\N	EXCUSE	0
399769	398301	05012A	PARTICIPANT	\N	EXCUSE	0
399770	398302	05012A	PARTICIPANT	\N	EXCUSE	0
401868	400530	11097X	PARTICIPANT	\N	PRESENT	0
401869	400530	19575F	PARTICIPANT	\N	PRESENT	0
401870	400531	11097X	PARTICIPANT	\N	PRESENT	0
402309	393620	11049P	PARTICIPANT	\N	PRESENT	0
402310	393620	16685X	PARTICIPANT	\N	PRESENT	0
421448	420707	14065Q	PARTICIPANT	\N	EXCUSE	0
421449	420707	19581D	PARTICIPANT	\N	EXCUSE	0
421450	420707	19719D	PARTICIPANT	\N	EXCUSE	0
421621	420251	16685X	PARTICIPANT	\N	PRESENT	0
421622	420251	04035D	PARTICIPANT	\N	PRESENT	0
421623	420251	98029W	PARTICIPANT	\N	PRESENT	0
421624	420251	01062T	PARTICIPANT	\N	PRESENT	0
421625	420251	14133K	PARTICIPANT	\N	PRESENT	0
421626	420251	14028W	PARTICIPANT	\N	PRESENT	0
421627	420529	19768N	PARTICIPANT	\N	PRESENT	0
421628	420529	19515S	PARTICIPANT	\N	PRESENT	0
421629	420529	19782L	PARTICIPANT	\N	PRESENT	0
421630	420529	14357A	PARTICIPANT	\N	PRESENT	0
421631	420529	19441R	PARTICIPANT	\N	PRESENT	0
421632	420529	19413M	PARTICIPANT	\N	PRESENT	0
421633	420529	80013X	PARTICIPANT	\N	PRESENT	0
421634	420529	19631V	PARTICIPANT	\N	PRESENT	0
421635	420529	11099A	PARTICIPANT	\N	PRESENT	0
421636	420529	04049K	PARTICIPANT	\N	PRESENT	0
421637	420529	19705W	PARTICIPANT	\N	PRESENT	0
421638	420529	08015R	PARTICIPANT	\N	PRESENT	0
421639	420529	14197C	PARTICIPANT	\N	PRESENT	0
421640	420529	19369B	PARTICIPANT	\N	PRESENT	0
421641	420529	19511N	PARTICIPANT	\N	PRESENT	0
421642	420529	14265W	PARTICIPANT	\N	PRESENT	0
421643	420529	14135M	PARTICIPANT	\N	PRESENT	0
421644	420529	19467C	PARTICIPANT	\N	PRESENT	0
421645	420529	08038Y	PARTICIPANT	\N	PRESENT	0
421646	420529	08062Y	PARTICIPANT	\N	PRESENT	0
421647	420529	19695N	PARTICIPANT	\N	PRESENT	0
421648	420529	11090Q	PRESIDENT	0	PRESENT	0
421649	420529	14033T	PARTICIPANT	\N	PRESENT	0
421650	420529	01025N	PARTICIPANT	\N	PRESENT	0
421651	420529	19269X	PARTICIPANT	\N	PRESENT	0
421652	420529	14205J	PARTICIPANT	\N	PRESENT	0
421653	420529	14115H	PARTICIPANT	\N	PRESENT	0
421654	420529	11101A	PARTICIPANT	\N	PRESENT	0
421655	420529	19507S	PARTICIPANT	\N	PRESENT	0
421656	420529	14207L	PARTICIPANT	\N	PRESENT	0
421657	420529	19747H	PARTICIPANT	\N	PRESENT	0
421658	420529	14257W	PARTICIPANT	\N	PRESENT	0
421659	420529	01043Q	PARTICIPANT	\N	PRESENT	0
421665	421447	04059M	PARTICIPANT	\N	PRESENT	0
421666	421447	14109K	PARTICIPANT	\N	PRESENT	0
421714	419820	11026G	PARTICIPANT	\N	PRESENT	0
421715	420251	95030B	PARTICIPANT	\N	PRESENT	0
421716	420251	19421M	PARTICIPANT	\N	PRESENT	0
421718	420646	19663E	PARTICIPANT	\N	PRESENT	0
422454	407839	14097Y	PARTICIPANT	\N	PRESENT	0
421853	420709	19543W	PARTICIPANT	\N	PRESENT	0
421854	420709	14179A	PARTICIPANT	\N	PRESENT	0
421855	420709	14089Y	PARTICIPANT	\N	EXCUSE	0
422448	407839	19695N	PARTICIPANT	\N	PRESENT	0
422456	407839	19413M	PARTICIPANT	\N	PRESENT	0
422457	407839	19725B	PARTICIPANT	\N	PRESENT	0
422458	407839	14115H	PARTICIPANT	\N	PRESENT	0
422459	420710	08034U	PARTICIPANT	\N	PRESENT	0
422460	420710	04092N	PRESIDENT	0	PRESENT	0
422522	407839	19533U	PARTICIPANT	\N	PRESENT	0
422462	420710	08043V	PARTICIPANT	\N	PRESENT	0
422463	420710	19415P	PARTICIPANT	\N	PRESENT	0
422464	420710	11066Q	PARTICIPANT	\N	PRESENT	0
422465	420710	04045F	PARTICIPANT	\N	PRESENT	0
422466	420710	19447X	PARTICIPANT	\N	PRESENT	0
422467	420710	11031D	PARTICIPANT	\N	PRESENT	0
422468	420710	14239U	PARTICIPANT	\N	PRESENT	0
422469	420710	14042U	PARTICIPANT	\N	PRESENT	0
422470	420710	14147R	PARTICIPANT	\N	PRESENT	0
422471	420710	14213J	PARTICIPANT	\N	PRESENT	0
422472	420710	99004R	PARTICIPANT	\N	PRESENT	0
422473	420710	19681G	PARTICIPANT	\N	PRESENT	0
422474	420710	19683J	PARTICIPANT	\N	PRESENT	0
422475	420710	11072N	PARTICIPANT	\N	PRESENT	0
422476	420710	19553Y	PARTICIPANT	\N	EXCUSE	0
422477	420710	14065Q	PARTICIPANT	\N	EXCUSE	0
422478	420710	19569H	PARTICIPANT	\N	EXCUSE	0
422479	420710	14041T	PARTICIPANT	\N	EXCUSE	0
422480	420710	08052W	PARTICIPANT	\N	EXCUSE	0
422481	420710	14215L	PARTICIPANT	\N	EXCUSE	0
422482	407839	19758L	PARTICIPANT	\N	PRESENT	0
422483	407839	19820Y	PARTICIPANT	\N	PRESENT	0
422484	407839	07029T	PARTICIPANT	\N	PRESENT	0
422487	407839	14207L	PARTICIPANT	\N	PRESENT	0
422489	407839	14039A	PARTICIPANT	\N	PRESENT	0
422490	407839	14199E	PARTICIPANT	\N	PRESENT	0
422491	407839	01024M	PARTICIPANT	\N	PRESENT	0
422492	407839	19253P	PARTICIPANT	\N	PRESENT	0
422493	407839	19629C	PARTICIPANT	\N	PRESENT	0
422495	420710	01048V	PARTICIPANT	\N	PRESENT	0
422496	420710	19335Q	PARTICIPANT	\N	PRESENT	0
422521	407839	14030Q	PARTICIPANT	\N	PRESENT	0
422523	407839	19691J	PARTICIPANT	\N	PRESENT	0
422524	407839	19441R	PARTICIPANT	\N	PRESENT	0
422525	407839	19749K	PARTICIPANT	\N	PRESENT	0
422526	407839	19467C	PARTICIPANT	\N	PRESENT	0
422527	407839	02002K	PARTICIPANT	\N	PRESENT	0
422528	420710	14179A	PARTICIPANT	\N	PRESENT	0
422529	407839	19593H	PARTICIPANT	\N	PRESENT	0
422530	407839	19443T	PARTICIPANT	\N	PRESENT	0
422531	407839	04040A	PARTICIPANT	\N	PRESENT	0
422532	407839	14179A	PARTICIPANT	\N	PRESENT	0
422568	407840	19593H	PARTICIPANT	\N	PRESENT	0
422569	407840	14207L	PARTICIPANT	\N	PRESENT	0
422570	407840	14039A	PARTICIPANT	\N	PRESENT	0
422571	407840	19749K	PARTICIPANT	\N	PRESENT	0
422572	407840	19333N	PARTICIPANT	\N	PRESENT	0
422573	407840	19563B	PARTICIPANT	\N	PRESENT	0
422574	407840	19713W	PARTICIPANT	\N	PRESENT	0
422575	407840	14030Q	PARTICIPANT	\N	PRESENT	0
422576	407840	14261S	PARTICIPANT	\N	PRESENT	0
422577	407840	19711U	PARTICIPANT	\N	PRESENT	0
422578	407840	19533U	PARTICIPANT	\N	PRESENT	0
422579	407840	19269X	PARTICIPANT	\N	PRESENT	0
422580	407840	14109K	PARTICIPANT	\N	PRESENT	0
422581	407840	14115H	PARTICIPANT	\N	PRESENT	0
422582	407840	19467C	PARTICIPANT	\N	PRESENT	0
422583	407840	19703U	PARTICIPANT	\N	PRESENT	0
422584	407840	14237S	PARTICIPANT	\N	PRESENT	0
422585	407840	19575F	PARTICIPANT	\N	PRESENT	0
422586	407840	19383Y	PARTICIPANT	\N	PRESENT	0
422587	407840	14267Y	PARTICIPANT	\N	PRESENT	0
422588	407840	14197C	PARTICIPANT	\N	PRESENT	0
422596	407840	14089Y	PARTICIPANT	\N	PRESENT	0
422597	407840	02002K	PARTICIPANT	\N	PRESENT	0
422598	407840	19413M	PARTICIPANT	\N	PRESENT	0
422599	407840	01024M	PARTICIPANT	\N	PRESENT	0
422600	407840	14213J	PARTICIPANT	\N	PRESENT	0
422601	407840	14026U	PARTICIPANT	\N	PRESENT	0
422602	407840	14147R	PARTICIPANT	\N	PRESENT	0
422603	407840	14033T	PARTICIPANT	\N	PRESENT	0
422604	407840	14069U	PARTICIPANT	\N	PRESENT	0
422605	407840	19447X	PARTICIPANT	\N	PRESENT	0
422606	407840	19443T	PARTICIPANT	\N	PRESENT	0
422642	407844	04044E	PARTICIPANT	\N	PRESENT	0
422566	407840	04044E	PARTICIPANT	\N	PRESENT	0
422567	407840	19531S	PARTICIPANT	\N	PRESENT	0
422608	407840	14217N	PARTICIPANT	\N	PRESENT	0
422609	407840	14083S	PARTICIPANT	\N	PRESENT	0
422643	407844	19669L	PARTICIPANT	\N	PRESENT	0
422644	407844	02002K	PARTICIPANT	\N	PRESENT	0
422645	407844	14267Y	PARTICIPANT	\N	PRESENT	0
422646	407844	14069U	PARTICIPANT	\N	PRESENT	0
422647	407844	19749K	PARTICIPANT	\N	PRESENT	0
422648	407844	14030Q	PARTICIPANT	\N	PRESENT	0
422649	407844	01024M	PARTICIPANT	\N	PRESENT	0
422650	407844	14255U	PARTICIPANT	\N	PRESENT	0
422651	407844	14217N	PARTICIPANT	\N	PRESENT	0
422652	407844	14033T	PARTICIPANT	\N	PRESENT	0
422653	407844	14261S	PARTICIPANT	\N	PRESENT	0
422654	407844	01058X	PARTICIPANT	\N	PRESENT	0
422655	407844	12041X	PARTICIPANT	\N	PRESENT	0
422656	407844	19443T	PARTICIPANT	\N	PRESENT	0
422657	407844	14147R	PARTICIPANT	\N	PRESENT	0
422658	407844	04070G	PARTICIPANT	\N	PRESENT	0
422659	407844	98029W	PARTICIPANT	\N	PRESENT	0
422755	422753	14221J	PARTICIPANT	\N	PRESENT	0
422757	422756	14169X	PARTICIPANT	\N	PRESENT	0
422760	422759	14169X	PARTICIPANT	\N	PRESENT	0
422762	422761	14169X	PARTICIPANT	\N	PRESENT	0
422818	422816	14093U	PARTICIPANT	\N	PRESENT	0
422819	422816	19820Y	PARTICIPANT	\N	PRESENT	0
422950	422949	04047H	PARTICIPANT	\N	PRESENT	0
422952	422951	04047H	PARTICIPANT	\N	PRESENT	0
422953	422951	11026G	PARTICIPANT	\N	PRESENT	0
422955	422954	14179A	PARTICIPANT	\N	PRESENT	0
422956	422954	14001X	PARTICIPANT	\N	PRESENT	0
422988	422987	14093U	PARTICIPANT	\N	PRESENT	0
406496	402266	19739H	PARTICIPANT	\N	PRESENT	0
406497	402266	19515S	PARTICIPANT	\N	PRESENT	0
406498	402266	14249W	PARTICIPANT	\N	PRESENT	0
406499	402266	19725B	PARTICIPANT	\N	PRESENT	0
406500	402266	19820Y	PARTICIPANT	\N	PRESENT	0
406584	402267	08009T	PARTICIPANT	\N	PRESENT	0
406585	402267	19701S	PARTICIPANT	\N	PRESENT	0
406586	402267	19549D	PARTICIPANT	\N	PRESENT	0
406587	402267	08060W	PARTICIPANT	\N	PRESENT	0
406588	402267	19637C	PARTICIPANT	\N	PRESENT	0
406589	402267	08024S	PARTICIPANT	\N	PRESENT	0
406590	402267	11067R	PARTICIPANT	\N	PRESENT	0
406591	402267	19413M	PARTICIPANT	\N	PRESENT	0
406592	402267	19503N	PARTICIPANT	\N	PRESENT	0
406593	402267	08068F	PARTICIPANT	\N	PRESENT	0
406594	402267	80013X	PARTICIPANT	\N	PRESENT	0
406595	402267	19599P	PARTICIPANT	\N	PRESENT	0
406596	402267	19347U	PARTICIPANT	\N	PRESENT	0
406597	402267	19593H	PARTICIPANT	\N	PRESENT	0
406598	402267	19812Y	PARTICIPANT	\N	PRESENT	0
406599	402267	19387D	PARTICIPANT	\N	PRESENT	0
406600	402267	14261S	PARTICIPANT	\N	PRESENT	0
406601	402267	14219Q	PARTICIPANT	\N	PRESENT	0
406602	402267	19749K	PARTICIPANT	\N	PRESENT	0
406603	402267	19713W	PARTICIPANT	\N	PRESENT	0
406604	402267	14205J	PARTICIPANT	\N	PRESENT	0
406605	402267	19383Y	PARTICIPANT	\N	PRESENT	0
406606	402267	11090Q	PARTICIPANT	\N	PRESENT	0
406607	402267	11048N	PARTICIPANT	\N	PRESENT	0
406608	402267	14223L	PARTICIPANT	\N	PRESENT	0
406609	402267	19798U	PARTICIPANT	\N	PRESENT	0
406610	402267	08015R	PARTICIPANT	\N	PRESENT	0
406611	402267	14033T	PARTICIPANT	\N	PRESENT	0
406612	402267	04088S	PARTICIPANT	\N	PRESENT	0
406613	402267	14119M	PARTICIPANT	\N	PRESENT	0
406614	402267	04097T	PARTICIPANT	\N	PRESENT	0
406615	402267	08020N	PARTICIPANT	\N	PRESENT	0
406616	402267	19794Q	PARTICIPANT	\N	PRESENT	0
406617	402267	14265W	PARTICIPANT	\N	PRESENT	0
406618	402267	95030B	PARTICIPANT	\N	PRESENT	0
406619	402267	14073Q	PARTICIPANT	\N	PRESENT	0
406620	402267	19479G	PARTICIPANT	\N	PRESENT	0
406621	402267	14197C	PARTICIPANT	\N	PRESENT	0
406622	402267	14038Y	PARTICIPANT	\N	PRESENT	0
406623	402267	14249W	PARTICIPANT	\N	PRESENT	0
406624	402267	14029X	PARTICIPANT	\N	PRESENT	0
406625	402267	14187A	PARTICIPANT	\N	PRESENT	0
406626	402267	14105F	PARTICIPANT	\N	PRESENT	0
406627	402267	04033B	PARTICIPANT	\N	PRESENT	0
406628	402267	14195A	PARTICIPANT	\N	PRESENT	0
406629	402267	19733B	PARTICIPANT	\N	PRESENT	0
406630	402267	14217N	PARTICIPANT	\N	PRESENT	0
406631	402267	07029T	PARTICIPANT	\N	PRESENT	0
406632	402267	19693L	PARTICIPANT	\N	PRESENT	0
406633	402267	19565D	PARTICIPANT	\N	PRESENT	0
406634	402267	14135M	PARTICIPANT	\N	PRESENT	0
406635	402267	14147R	PARTICIPANT	\N	PRESENT	0
406636	402267	14071N	PARTICIPANT	\N	PRESENT	0
406637	402267	19621T	PARTICIPANT	\N	PRESENT	0
406638	402267	14331P	PARTICIPANT	\N	PRESENT	0
406639	402267	14021P	PARTICIPANT	\N	PRESENT	0
406640	402267	19760E	PARTICIPANT	\N	PRESENT	0
406641	402267	19573D	PARTICIPANT	\N	PRESENT	0
406642	402267	08061X	PARTICIPANT	\N	PRESENT	0
406643	402267	14213J	PARTICIPANT	\N	PRESENT	0
406644	402267	19349W	PARTICIPANT	\N	PRESENT	0
406645	402267	19551W	PARTICIPANT	\N	PRESENT	0
406646	402267	11099A	PARTICIPANT	\N	PRESENT	0
406647	402267	19719D	PARTICIPANT	\N	PRESENT	0
406648	402267	11065P	PARTICIPANT	\N	PRESENT	0
406649	402267	19737F	PARTICIPANT	\N	PRESENT	0
406650	402267	19739H	PARTICIPANT	\N	PRESENT	0
406651	402267	04040A	PARTICIPANT	\N	PRESENT	0
406652	402267	01028R	PARTICIPANT	\N	PRESENT	0
406653	402267	08039A	PARTICIPANT	\N	PRESENT	0
406654	402267	11109J	PARTICIPANT	\N	PRESENT	0
406655	402267	14123H	PARTICIPANT	\N	PRESENT	0
406656	402267	14026U	PARTICIPANT	\N	PRESENT	0
406657	402267	14069U	PARTICIPANT	\N	PRESENT	0
406658	402267	19545Y	PARTICIPANT	\N	PRESENT	0
406659	402267	19507S	PARTICIPANT	\N	PRESENT	0
406660	402267	14083S	PARTICIPANT	\N	PRESENT	0
406661	402267	14031R	PARTICIPANT	\N	PRESENT	0
406724	404870	14111D	PARTICIPANT	\N	PRESENT	0
406725	404870	19649G	PARTICIPANT	\N	PRESENT	0
406581	405391	19383Y	PARTICIPANT	\N	PRESENT	0
406582	405391	14329V	PARTICIPANT	\N	PRESENT	0
406583	402267	11070L	PARTICIPANT	\N	PRESENT	0
406726	404870	19253P	PARTICIPANT	\N	PRESENT	0
406727	404870	19585H	PARTICIPANT	\N	PRESENT	0
406728	404870	19719D	PARTICIPANT	\N	PRESENT	0
406729	404870	01028R	PARTICIPANT	\N	PRESENT	0
406730	404870	14231L	PARTICIPANT	\N	PRESENT	0
406731	404870	05008E	PRESIDENT	0	PRESENT	0
406732	404870	19725B	PARTICIPANT	\N	PRESENT	0
406733	404870	19729F	PARTICIPANT	\N	PRESENT	0
406734	404870	95063L	PARTICIPANT	\N	PRESENT	0
406735	404870	14275Y	PARTICIPANT	\N	PRESENT	0
406736	404870	19629C	PARTICIPANT	\N	PRESENT	0
406737	404870	14041T	PARTICIPANT	\N	PRESENT	0
406738	404870	08044W	PARTICIPANT	\N	PRESENT	0
406739	404870	14179A	PARTICIPANT	\N	PRESENT	0
406740	404870	14147R	PARTICIPANT	\N	PRESENT	0
406741	404870	14069U	PARTICIPANT	\N	PRESENT	0
406742	404870	08018U	PARTICIPANT	\N	PRESENT	0
406743	404870	11049P	PARTICIPANT	\N	PRESENT	0
406744	404870	14259Y	PARTICIPANT	\N	PRESENT	0
406745	404870	19762G	PARTICIPANT	\N	PRESENT	0
406747	404870	14053L	PARTICIPANT	\N	EXCUSE	0
406748	404870	14065Q	PARTICIPANT	\N	EXCUSE	0
406749	404870	10015M	PARTICIPANT	\N	EXCUSE	0
406750	404870	08045X	PARTICIPANT	\N	EXCUSE	0
406751	404870	01024M	PARTICIPANT	\N	EXCUSE	0
406752	404870	04044E	PARTICIPANT	\N	EXCUSE	0
406753	404870	14215L	PARTICIPANT	\N	EXCUSE	0
406754	404870	19581D	PARTICIPANT	\N	EXCUSE	0
406755	404870	19673G	PARTICIPANT	\N	EXCUSE	0
406756	404870	19447X	PARTICIPANT	\N	EXCUSE	0
406757	405335	19549D	PARTICIPANT	\N	PRESENT	0
406759	405335	19637C	PARTICIPANT	\N	PRESENT	0
406760	405335	19551W	PARTICIPANT	\N	PRESENT	0
406761	405335	08024S	PARTICIPANT	\N	PRESENT	0
406762	405335	19681G	PARTICIPANT	\N	PRESENT	0
406763	405335	19525U	PARTICIPANT	\N	PRESENT	0
406767	405327	19663E	PARTICIPANT	\N	PRESENT	0
406768	405327	10006L	PARTICIPANT	\N	EXCUSE	0
406769	405382	14327T	PARTICIPANT	\N	PRESENT	0
406770	405382	14331P	PARTICIPANT	\N	PRESENT	0
406771	405382	04071H	PARTICIPANT	\N	PRESENT	0
406772	405382	01048V	PARTICIPANT	\N	PRESENT	0
406494	402266	11027H	PARTICIPANT	\N	PRESENT	0
406495	402266	19415P	PARTICIPANT	\N	PRESENT	0
406773	405382	01057W	PARTICIPANT	\N	PRESENT	0
406774	405382	11053K	PARTICIPANT	\N	PRESENT	0
406775	405382	11074Q	PRESIDENT	0	PRESENT	0
406776	405382	89017R	PARTICIPANT	\N	PRESENT	0
406777	405382	19671E	PARTICIPANT	\N	PRESENT	0
406778	405382	07029T	PARTICIPANT	\N	PRESENT	0
406779	405382	14085U	PARTICIPANT	\N	PRESENT	0
406780	405382	96004D	PARTICIPANT	\N	PRESENT	0
406781	405382	19349W	PARTICIPANT	\N	PRESENT	0
406782	405382	08010L	PARTICIPANT	\N	PRESENT	0
406783	405382	14253S	PARTICIPANT	\N	PRESENT	0
406784	405382	19479G	PARTICIPANT	\N	PRESENT	0
406785	405382	11048N	PARTICIPANT	\N	PRESENT	0
406786	405382	19531S	PARTICIPANT	\N	PRESENT	0
406787	405382	08034U	PARTICIPANT	\N	PRESENT	0
406788	405382	19689Q	PARTICIPANT	\N	PRESENT	0
406789	405382	08011M	PARTICIPANT	\N	PRESENT	0
406790	405382	14173T	PARTICIPANT	\N	PRESENT	0
406791	405382	11040E	PARTICIPANT	\N	PRESENT	0
406792	405382	04086Q	PARTICIPANT	\N	PRESENT	0
406793	405382	14083S	PARTICIPANT	\N	PRESENT	0
406794	405382	11012A	PARTICIPANT	\N	PRESENT	0
406795	405382	14121F	PARTICIPANT	\N	PRESENT	0
406796	405382	99004R	PARTICIPANT	\N	PRESENT	0
406797	405382	14159V	PARTICIPANT	\N	EXCUSE	0
406798	404870	19489J	PARTICIPANT	\N	PRESENT	0
406799	404870	14151M	PARTICIPANT	\N	PRESENT	0
406800	404870	11033F	PARTICIPANT	\N	PRESENT	0
406801	404870	14089Y	PARTICIPANT	\N	PRESENT	0
406803	406662	19766L	PARTICIPANT	\N	PRESENT	0
406804	406662	04070G	PRESIDENT	0	PRESENT	0
406805	406662	19699S	PARTICIPANT	\N	PRESENT	0
406806	406662	19533U	PARTICIPANT	\N	PRESENT	0
406807	406662	14229S	PARTICIPANT	\N	PRESENT	0
406808	406662	14241N	PARTICIPANT	\N	PRESENT	0
418796	416166	14265W	PARTICIPANT	\N	PRESENT	0
418797	416166	14135M	PARTICIPANT	\N	PRESENT	0
418798	416166	11056N	PARTICIPANT	\N	PRESENT	0
418799	416166	11101A	PARTICIPANT	\N	PRESENT	0
418800	415001	04097T	PARTICIPANT	\N	PRESENT	0
418802	415001	17637T	PARTICIPANT	\N	PRESENT	0
418803	415001	19733B	PARTICIPANT	\N	PRESENT	0
418804	416166	01043Q	PARTICIPANT	\N	PRESENT	0
418805	416166	11099A	PARTICIPANT	\N	PRESENT	0
418806	415001	19525U	PARTICIPANT	\N	PRESENT	0
418807	415001	14029X	PARTICIPANT	\N	PRESENT	0
418817	415001	19347U	PARTICIPANT	\N	PRESENT	0
418818	415001	08024S	PARTICIPANT	\N	PRESENT	0
418819	415001	14031R	PARTICIPANT	\N	PRESENT	0
418821	416166	04049K	PARTICIPANT	\N	PRESENT	0
418822	416166	19695N	PARTICIPANT	\N	PRESENT	0
418823	416166	14207L	PARTICIPANT	\N	PRESENT	0
418824	416166	04043D	PARTICIPANT	\N	PRESENT	0
418879	416986	19583F	PARTICIPANT	\N	EXCUSE	0
418880	416986	11054L	PARTICIPANT	\N	EXCUSE	0
419054	419010	14071N	PARTICIPANT	\N	PRESENT	0
419114	410853	11067R	PARTICIPANT	\N	PRESENT	0
419124	419123	11097X	PARTICIPANT	\N	PRESENT	0
419858	419803	19521Q	PARTICIPANT	\N	PRESENT	0
419126	415937	01034P	PARTICIPANT	\N	EXCUSE	0
419127	415937	11103C	PARTICIPANT	\N	EXCUSE	0
419128	415937	19691J	PARTICIPANT	\N	EXCUSE	0
419129	415937	19577H	PARTICIPANT	\N	EXCUSE	0
419130	416543	19583F	PARTICIPANT	\N	EXCUSE	0
419857	419803	14087W	PARTICIPANT	\N	PRESENT	0
419859	419803	19679N	PARTICIPANT	\N	PRESENT	0
419907	407721	14211G	PARTICIPANT	\N	PRESENT	0
419908	407721	08010L	PARTICIPANT	\N	PRESENT	0
419909	407721	14169X	PARTICIPANT	\N	PRESENT	0
419910	407721	97011G	PARTICIPANT	\N	PRESENT	0
419911	407721	95063L	PARTICIPANT	\N	PRESENT	0
419912	407721	04049K	PARTICIPANT	\N	PRESENT	0
419913	407721	19691J	PARTICIPANT	\N	PRESENT	0
419914	407721	01025N	PARTICIPANT	\N	PRESENT	0
419915	407721	19543W	PARTICIPANT	\N	PRESENT	0
419916	407721	08069G	PARTICIPANT	\N	PRESENT	0
419917	407721	04086Q	PARTICIPANT	\N	PRESENT	0
419918	407721	01024M	PARTICIPANT	\N	PRESENT	0
419919	407721	08068F	PARTICIPANT	\N	PRESENT	0
419920	407721	14135M	PARTICIPANT	\N	PRESENT	0
419921	407721	11064N	PARTICIPANT	\N	PRESENT	0
419922	407721	11099A	PARTICIPANT	\N	PRESENT	0
419923	407721	07029T	PARTICIPANT	\N	PRESENT	0
419926	407721	14265W	PARTICIPANT	\N	PRESENT	0
419927	407721	08017T	PARTICIPANT	\N	PRESENT	0
419928	407721	14033T	PARTICIPANT	\N	PRESENT	0
419930	407721	11067R	PARTICIPANT	\N	PRESENT	0
419931	407721	08039A	PARTICIPANT	\N	PRESENT	0
419932	407721	11090Q	PARTICIPANT	\N	PRESENT	0
419933	407721	11097X	PARTICIPANT	\N	PRESENT	0
419934	407721	14357A	PARTICIPANT	\N	PRESENT	0
419935	407721	19333N	PARTICIPANT	\N	PRESENT	0
419936	407721	19269X	PARTICIPANT	\N	PRESENT	0
420015	407722	11090Q	PARTICIPANT	\N	PRESENT	0
420016	407722	11067R	PARTICIPANT	\N	PRESENT	0
420017	407722	19413M	PARTICIPANT	\N	PRESENT	0
420018	407722	19333N	PARTICIPANT	\N	PRESENT	0
420019	407722	08017T	PARTICIPANT	\N	PRESENT	0
420020	407722	19647E	PARTICIPANT	\N	PRESENT	0
420021	407722	12016W	PARTICIPANT	\N	PRESENT	0
420022	407722	14021P	PARTICIPANT	\N	PRESENT	0
420042	407722	19399H	PARTICIPANT	\N	PRESENT	0
420043	407722	14135M	PARTICIPANT	\N	PRESENT	0
420044	407722	04088S	PARTICIPANT	\N	PRESENT	0
420045	407722	14033T	PARTICIPANT	\N	PRESENT	0
420047	407722	08010L	PARTICIPANT	\N	PRESENT	0
420048	407722	08020N	PARTICIPANT	\N	PRESENT	0
420049	407722	08068F	PARTICIPANT	\N	PRESENT	0
420050	407722	14034U	PARTICIPANT	\N	PRESENT	0
420051	407722	80013X	PARTICIPANT	\N	PRESENT	0
420052	407722	19695N	PARTICIPANT	\N	PRESENT	0
420116	407723	19593H	PARTICIPANT	\N	PRESENT	0
420066	420064	11026G	PARTICIPANT	\N	PRESENT	0
420067	420064	04047H	PARTICIPANT	\N	PRESENT	0
420117	407723	08043V	PARTICIPANT	\N	PRESENT	0
420118	407723	08017T	PARTICIPANT	\N	PRESENT	0
420119	407723	14109K	PARTICIPANT	\N	PRESENT	0
420120	407723	11083R	PARTICIPANT	\N	PRESENT	0
420121	407723	14241N	PARTICIPANT	\N	PRESENT	0
420122	407723	04057K	PARTICIPANT	\N	PRESENT	0
420123	407723	19545Y	PARTICIPANT	\N	PRESENT	0
420124	407723	14231L	PARTICIPANT	\N	PRESENT	0
420125	407723	19749K	PARTICIPANT	\N	PRESENT	0
420126	407723	19713W	PARTICIPANT	\N	PRESENT	0
420127	407723	19533U	PARTICIPANT	\N	PRESENT	0
420128	407723	14041T	PARTICIPANT	\N	PRESENT	0
420129	407723	04018C	PARTICIPANT	\N	PRESENT	0
420130	407723	08020N	PARTICIPANT	\N	PRESENT	0
420131	407723	14147R	PARTICIPANT	\N	PRESENT	0
420132	407723	14030Q	PARTICIPANT	\N	PRESENT	0
420133	407723	19441R	PARTICIPANT	\N	PRESENT	0
420134	407723	14059S	PARTICIPANT	\N	PRESENT	0
420135	407723	14169X	PARTICIPANT	\N	PRESENT	0
420136	407723	92040Q	PARTICIPANT	\N	PRESENT	0
420137	407723	04070G	PARTICIPANT	\N	PRESENT	0
420138	407723	19447X	PARTICIPANT	\N	PRESENT	0
420183	407746	11083R	PARTICIPANT	\N	PRESENT	0
420184	407746	08031R	PARTICIPANT	\N	PRESENT	0
420185	407746	08039A	PARTICIPANT	\N	PRESENT	0
420186	407746	04018C	PARTICIPANT	\N	PRESENT	0
420187	407746	19693L	PARTICIPANT	\N	PRESENT	0
420189	407746	14197C	PARTICIPANT	\N	PRESENT	0
420190	407746	14021P	PARTICIPANT	\N	PRESENT	0
420191	407746	14059S	PARTICIPANT	\N	PRESENT	0
420192	407746	11033F	PARTICIPANT	\N	PRESENT	0
420193	407746	04057K	PARTICIPANT	\N	PRESENT	0
420194	407746	19713W	PARTICIPANT	\N	PRESENT	0
420195	407746	19441R	PARTICIPANT	\N	PRESENT	0
420196	407746	14030Q	PARTICIPANT	\N	PRESENT	0
420197	407746	14215L	PARTICIPANT	\N	PRESENT	0
420198	407746	14147R	PARTICIPANT	\N	PRESENT	0
420199	407746	19533U	PARTICIPANT	\N	PRESENT	0
420200	407746	14231L	PARTICIPANT	\N	PRESENT	0
420201	407746	19551W	PARTICIPANT	\N	PRESENT	0
420202	407746	05008E	PARTICIPANT	\N	PRESENT	0
420203	407746	19447X	PARTICIPANT	\N	PRESENT	0
420204	407746	19749K	PARTICIPANT	\N	PRESENT	0
420205	407746	01028R	PARTICIPANT	\N	PRESENT	0
420206	407746	04070G	PARTICIPANT	\N	PRESENT	0
420114	407723	14034U	PARTICIPANT	\N	PRESENT	0
420115	407723	08039A	PARTICIPANT	\N	PRESENT	0
420207	407746	14069U	PARTICIPANT	\N	PRESENT	0
420275	420274	10006L	PARTICIPANT	\N	PRESENT	0
420276	420274	19575F	PARTICIPANT	\N	PRESENT	0
420286	420285	10006L	PARTICIPANT	\N	PRESENT	0
420303	410910	19649G	PARTICIPANT	\N	PRESENT	0
420308	413611	19649G	PARTICIPANT	\N	PRESENT	0
420312	420310	08018U	PARTICIPANT	\N	PRESENT	0
420313	414000	19649G	PARTICIPANT	\N	PRESENT	0
420013	407722	04059M	PARTICIPANT	\N	PRESENT	0
420014	407722	04049K	PARTICIPANT	\N	PRESENT	0
420334	420332	08018U	PARTICIPANT	\N	PRESENT	0
420398	420397	04086Q	PARTICIPANT	\N	PRESENT	0
420401	420399	14147R	PARTICIPANT	\N	PRESENT	0
420403	420402	14147R	PARTICIPANT	\N	PRESENT	0
420404	420400	04086Q	PARTICIPANT	\N	PRESENT	0
420406	420405	04086Q	PARTICIPANT	\N	PRESENT	0
420408	420407	04086Q	PARTICIPANT	\N	PRESENT	0
420410	420409	04086Q	PARTICIPANT	\N	PRESENT	0
420420	420419	11074Q	PARTICIPANT	\N	PRESENT	0
420422	420421	99004R	PARTICIPANT	\N	PRESENT	0
420504	420503	14229S	PARTICIPANT	\N	PRESENT	0
420505	420503	19735D	PARTICIPANT	\N	PRESENT	0
420506	420273	14123H	PARTICIPANT	\N	PRESENT	0
420508	410951	19621T	PARTICIPANT	\N	PRESENT	0
420522	417145	08048B	PARTICIPANT	\N	EXCUSE	0
420523	419341	19649G	PARTICIPANT	\N	PRESENT	0
420526	420257	19649G	PARTICIPANT	\N	PRESENT	0
420527	420257	14030Q	PARTICIPANT	\N	PRESENT	0
420528	420260	19649G	PARTICIPANT	\N	PRESENT	0
420530	417145	14259Y	PARTICIPANT	\N	PRESENT	0
420547	420546	19515S	PARTICIPANT	\N	PRESENT	0
420550	420548	19515S	PARTICIPANT	\N	PRESENT	0
420589	414386	14255U	PARTICIPANT	\N	PRESENT	0
420590	414386	01024M	PARTICIPANT	\N	PRESENT	0
420591	414386	14281W	PARTICIPANT	\N	PRESENT	0
420592	414386	08048B	PARTICIPANT	\N	PRESENT	0
420593	414386	14026U	PARTICIPANT	\N	PRESENT	0
420594	414386	19691J	PARTICIPANT	\N	PRESENT	0
420595	414386	19333N	PARTICIPANT	\N	PRESENT	0
420596	414386	07029T	PARTICIPANT	\N	PRESENT	0
420597	414386	14265W	PARTICIPANT	\N	PRESENT	0
420598	414386	14119M	PARTICIPANT	\N	PRESENT	0
420599	414386	19798U	PARTICIPANT	\N	PRESENT	0
392733	392726	14265W	PARTICIPANT	\N	EXCUSE	0
392734	392726	19503N	PARTICIPANT	\N	PRESENT	0
392735	392726	95067Q	PARTICIPANT	\N	PRESENT	0
392736	392726	19585H	PARTICIPANT	\N	PRESENT	0
393318	392420	16685X	PARTICIPANT	\N	PRESENT	0
393953	393951	19399H	PARTICIPANT	\N	PRESENT	0
393954	393951	08031R	PARTICIPANT	\N	PRESENT	0
393955	393951	14229S	PARTICIPANT	\N	PRESENT	0
393956	393952	19399H	PARTICIPANT	\N	PRESENT	0
394096	394081	19741B	PARTICIPANT	\N	PRESENT	0
394097	394081	01048V	PARTICIPANT	\N	PRESENT	0
394098	394081	14257W	PRESIDENT	0	PRESENT	0
394099	394081	08053X	PARTICIPANT	\N	PRESENT	0
394100	394081	04070G	PARTICIPANT	\N	PRESENT	0
394102	394081	19593H	PARTICIPANT	\N	PRESENT	0
394103	394081	19533U	PARTICIPANT	\N	PRESENT	0
394104	394081	19679N	PARTICIPANT	\N	PRESENT	0
395450	394110	19585H	PARTICIPANT	\N	EXCUSE	0
396101	396097	19651A	PARTICIPANT	\N	PRESENT	0
396102	396097	14085U	PARTICIPANT	\N	PRESENT	0
396589	396219	19651A	PARTICIPANT	\N	EXCUSE	0
397699	397698	96004D	PRESIDENT	0	PRESENT	0
396105	396097	14327T	PARTICIPANT	\N	PRESENT	0
396106	396097	11074Q	PARTICIPANT	\N	PRESENT	0
396107	396097	11048N	PARTICIPANT	\N	PRESENT	0
396108	396097	19711U	PARTICIPANT	\N	PRESENT	0
397700	397698	14357A	PARTICIPANT	\N	EXCUSE	0
396111	396097	08011M	PARTICIPANT	\N	PRESENT	0
397701	397698	14079W	PARTICIPANT	\N	PRESENT	0
397702	397698	11083R	PARTICIPANT	\N	PRESENT	0
397703	397698	95037J	PARTICIPANT	\N	PRESENT	0
397704	397698	14073Q	PARTICIPANT	\N	PRESENT	0
397705	397698	11026G	PARTICIPANT	\N	PRESENT	0
397706	397698	14221J	PARTICIPANT	\N	PRESENT	0
397707	397698	14225N	PARTICIPANT	\N	EXCUSE	0
397708	397698	14331P	PARTICIPANT	\N	PRESENT	0
397709	397698	14237S	PARTICIPANT	\N	PRESENT	0
398567	398563	04008A	PARTICIPANT	\N	PRESENT	0
398568	398563	11049P	PARTICIPANT	\N	PRESENT	0
402373	393625	11103C	PARTICIPANT	\N	PRESENT	0
402374	393625	19766L	PARTICIPANT	\N	PRESENT	0
402375	393625	17589D	PARTICIPANT	\N	PRESENT	0
402376	393625	80027E	PARTICIPANT	\N	PRESENT	0
402377	393625	08060W	PARTICIPANT	\N	PRESENT	0
402381	393625	14135M	PARTICIPANT	\N	PRESENT	0
402379	393625	04018C	PARTICIPANT	\N	PRESENT	0
402380	393625	14042U	PARTICIPANT	\N	PRESENT	0
402382	393625	19691J	PARTICIPANT	\N	PRESENT	0
402383	393625	95037J	PARTICIPANT	\N	PRESENT	0
402384	393625	19798U	PARTICIPANT	\N	PRESENT	0
402385	393625	08052W	PARTICIPANT	\N	PRESENT	0
402386	393625	11027H	PARTICIPANT	\N	PRESENT	0
402387	393625	11041F	PARTICIPANT	\N	PRESENT	0
402388	393625	14063N	PARTICIPANT	\N	PRESENT	0
402389	393625	14331P	PARTICIPANT	\N	PRESENT	0
402390	393625	04097T	PARTICIPANT	\N	PRESENT	0
402391	393625	19709B	PARTICIPANT	\N	PRESENT	0
402392	393625	19593H	PARTICIPANT	\N	PRESENT	0
402393	393625	19741B	PARTICIPANT	\N	PRESENT	0
402394	393625	01028R	PARTICIPANT	\N	PRESENT	0
402395	393625	14051J	PARTICIPANT	\N	PRESENT	0
402396	393625	11067R	PARTICIPANT	\N	PRESENT	0
402397	393625	19479G	PARTICIPANT	\N	PRESENT	0
402398	393625	14275Y	PARTICIPANT	\N	PRESENT	0
402399	393625	14041T	PARTICIPANT	\N	PRESENT	0
402432	393625	14071N	PARTICIPANT	\N	PRESENT	0
402401	393625	19599P	PARTICIPANT	\N	PRESENT	0
402402	393625	11054L	PARTICIPANT	\N	PRESENT	0
402403	393625	19675J	PARTICIPANT	\N	PRESENT	0
402404	393625	19563B	PARTICIPANT	\N	PRESENT	0
402405	393625	08020N	PARTICIPANT	\N	PRESENT	0
402406	393625	99004R	PARTICIPANT	\N	PRESENT	0
402407	393625	14157T	PARTICIPANT	\N	PRESENT	0
402408	393625	95062K	PARTICIPANT	\N	PRESENT	0
402409	393625	14357A	PARTICIPANT	\N	PRESENT	0
402410	393625	97011G	PARTICIPANT	\N	PRESENT	0
402411	393625	11090Q	PARTICIPANT	\N	PRESENT	0
402412	393625	01058X	PARTICIPANT	\N	PRESENT	0
402413	393625	19643A	PARTICIPANT	\N	PRESENT	0
402414	393625	11048N	PARTICIPANT	\N	PRESENT	0
402415	393625	19515S	PARTICIPANT	\N	PRESENT	0
402416	393625	19711U	PARTICIPANT	\N	PRESENT	0
402417	393625	19794Q	PARTICIPANT	\N	PRESENT	0
402418	393625	19443T	PARTICIPANT	\N	PRESENT	0
402419	393625	14031R	PARTICIPANT	\N	PRESENT	0
402420	393625	11066Q	PARTICIPANT	\N	PRESENT	0
402371	393625	04086Q	PARTICIPANT	\N	PRESENT	0
402372	393625	17779H	PARTICIPANT	\N	PRESENT	0
402421	393625	04049K	PARTICIPANT	\N	PRESENT	0
402422	393625	19760E	PARTICIPANT	\N	PRESENT	0
402423	393625	11033F	PARTICIPANT	\N	PRESENT	0
402424	393625	14079W	PARTICIPANT	\N	PRESENT	0
402425	393625	10015M	PARTICIPANT	\N	PRESENT	0
402426	393625	16685X	PARTICIPANT	\N	PRESENT	0
402427	393625	04040A	PARTICIPANT	\N	PRESENT	0
402437	393625	05012A	PARTICIPANT	\N	PRESENT	0
402429	393625	14179A	PARTICIPANT	\N	PRESENT	0
402430	393625	14197C	PARTICIPANT	\N	PRESENT	0
402431	393625	19551W	PARTICIPANT	\N	PRESENT	0
402433	393625	19581D	PARTICIPANT	\N	PRESENT	0
402434	393625	19421M	PARTICIPANT	\N	PRESENT	0
402435	393625	08034U	PARTICIPANT	\N	PRESENT	0
402436	393625	11080N	PARTICIPANT	\N	PRESENT	0
402438	393625	14265W	PARTICIPANT	\N	PRESENT	0
402439	393625	11031D	PARTICIPANT	\N	PRESENT	0
402440	393625	12041X	PARTICIPANT	\N	PRESENT	0
402441	393625	11056N	PARTICIPANT	\N	PRESENT	0
402442	393625	19687N	PARTICIPANT	\N	PRESENT	0
402443	393625	04085P	PARTICIPANT	\N	PRESENT	0
402444	393625	95063L	PARTICIPANT	\N	PRESENT	0
402445	393625	14187A	PARTICIPANT	\N	PRESENT	0
402446	393625	19651A	PARTICIPANT	\N	PRESENT	0
402447	393625	19349W	PARTICIPANT	\N	PRESENT	0
402448	393625	14033T	PARTICIPANT	\N	PRESENT	0
402449	393625	19782L	PARTICIPANT	\N	PRESENT	0
402450	393625	19697Q	PARTICIPANT	\N	PRESENT	0
402451	393625	08073C	PARTICIPANT	\N	PRESENT	0
402452	393625	08039A	PARTICIPANT	\N	PRESENT	0
402453	393625	11083R	PARTICIPANT	\N	PRESENT	0
402454	393625	98029W	PARTICIPANT	\N	PRESENT	0
402455	393625	05008E	PARTICIPANT	\N	PRESENT	0
402788	402787	11053K	PARTICIPANT	\N	PRESENT	0
402457	393625	19733B	PARTICIPANT	\N	PRESENT	0
402458	393625	14251Q	PARTICIPANT	\N	PRESENT	0
402459	393625	19585H	PARTICIPANT	\N	PRESENT	0
402460	393625	14259Y	PARTICIPANT	\N	PRESENT	0
402461	393625	11012A	PARTICIPANT	\N	PRESENT	0
402462	393625	14207L	PARTICIPANT	\N	PRESENT	0
402463	393625	14193X	PARTICIPANT	\N	PRESENT	0
402464	393625	19289C	PARTICIPANT	\N	PRESENT	0
402468	393625	11097X	PARTICIPANT	\N	PRESENT	0
402466	393625	04059M	PARTICIPANT	\N	PRESENT	0
402467	393625	08068F	PARTICIPANT	\N	PRESENT	0
402469	393625	14021P	PARTICIPANT	\N	PRESENT	0
402470	393625	19399H	PARTICIPANT	\N	PRESENT	0
402471	393625	19649G	PARTICIPANT	\N	PRESENT	0
402472	393625	11099A	PARTICIPANT	\N	PRESENT	0
402473	393625	19543W	PARTICIPANT	\N	PRESENT	0
402474	393625	14038Y	PARTICIPANT	\N	PRESENT	0
402475	393625	08035V	PARTICIPANT	\N	PRESENT	0
402476	393625	04088S	PARTICIPANT	\N	PRESENT	0
402791	402787	11097X	PARTICIPANT	\N	PRESENT	0
402478	393625	14081Q	PARTICIPANT	\N	PRESENT	0
402479	393625	19525U	PARTICIPANT	\N	PRESENT	0
402480	393625	98050T	PARTICIPANT	\N	PRESENT	0
402481	393625	19689Q	PARTICIPANT	\N	PRESENT	0
402482	393625	04043D	PARTICIPANT	\N	PRESENT	0
402483	393625	08058D	PARTICIPANT	\N	PRESENT	0
402484	393625	19549D	PARTICIPANT	\N	PRESENT	0
402485	393625	19647E	PARTICIPANT	\N	PRESENT	0
402486	393625	18083K	PARTICIPANT	\N	PRESENT	0
402487	393625	19591F	PARTICIPANT	\N	PRESENT	0
402488	393625	19467C	PARTICIPANT	\N	PRESENT	0
402489	393625	14227Q	PARTICIPANT	\N	PRESENT	0
402490	393625	11109J	PARTICIPANT	\N	PRESENT	0
402491	393625	14119M	PARTICIPANT	\N	PRESENT	0
402492	393625	19489J	PARTICIPANT	\N	PRESENT	0
402493	393625	19503N	PARTICIPANT	\N	PRESENT	0
402494	393625	14147R	PARTICIPANT	\N	PRESENT	0
402495	393625	19251M	PARTICIPANT	\N	PRESENT	0
402496	393625	19333N	PARTICIPANT	\N	PRESENT	0
402497	393625	14329V	PARTICIPANT	\N	PRESENT	0
402789	402787	14257W	PARTICIPANT	\N	PRESENT	0
402792	402787	19671E	PARTICIPANT	\N	PRESENT	0
402793	402787	19735D	PARTICIPANT	\N	PRESENT	0
402794	402787	19333N	PARTICIPANT	\N	PRESENT	0
404557	404556	19695N	PARTICIPANT	\N	PRESENT	0
420953	419131	04071H	PARTICIPANT	\N	PRESENT	0
420954	419131	19349W	PARTICIPANT	\N	PRESENT	0
420955	419131	11074Q	PRESIDENT	0	PRESENT	0
420956	419131	88008L	PARTICIPANT	\N	PRESENT	0
420957	407833	08038Y	PARTICIPANT	\N	PRESENT	0
420958	419131	11070L	PARTICIPANT	\N	PRESENT	0
420959	419131	08011M	PARTICIPANT	\N	PRESENT	0
420960	407833	04059M	PARTICIPANT	\N	PRESENT	0
420961	407833	19713W	PARTICIPANT	\N	PRESENT	0
420962	407833	19553Y	PARTICIPANT	\N	PRESENT	0
420963	407833	19727D	PARTICIPANT	\N	PRESENT	0
420968	407833	19413M	PARTICIPANT	\N	PRESENT	0
420969	407833	11099A	PARTICIPANT	\N	PRESENT	0
420970	407833	11101A	PARTICIPANT	\N	PRESENT	0
420971	407833	11054L	PARTICIPANT	\N	PRESENT	0
420972	419131	14225N	PARTICIPANT	\N	PRESENT	0
420973	407833	14034U	PARTICIPANT	\N	PRESENT	0
420998	407833	14121F	PARTICIPANT	\N	PRESENT	0
420999	407833	14083S	PARTICIPANT	\N	PRESENT	0
421000	407833	19711U	PARTICIPANT	\N	PRESENT	0
421001	407833	14205J	PARTICIPANT	\N	PRESENT	0
421002	407833	19669L	PARTICIPANT	\N	PRESENT	0
421003	407833	11070L	PARTICIPANT	\N	PRESENT	0
421004	407833	89017R	PARTICIPANT	\N	PRESENT	0
421005	407833	14079W	PARTICIPANT	\N	PRESENT	0
421006	407833	19723Y	PARTICIPANT	\N	PRESENT	0
421007	407833	11065P	PARTICIPANT	\N	PRESENT	0
421010	407833	14179A	PARTICIPANT	\N	PRESENT	0
421011	420981	14093U	PARTICIPANT	\N	PRESENT	0
421012	420981	19413M	PARTICIPANT	\N	PRESENT	0
421013	420981	19251M	PARTICIPANT	\N	PRESENT	0
421014	420981	14026U	PARTICIPANT	\N	PRESENT	0
421015	420981	08024S	PARTICIPANT	\N	PRESENT	0
421016	420981	19758L	PARTICIPANT	\N	PRESENT	0
421017	420981	04070G	PARTICIPANT	\N	EXCUSE	0
421018	420981	14051J	PARTICIPANT	\N	EXCUSE	0
421019	420981	08009T	PARTICIPANT	\N	EXCUSE	0
421020	407833	14211G	PARTICIPANT	\N	PRESENT	0
421669	421664	14073Q	PARTICIPANT	\N	PRESENT	0
421670	421664	19611R	PARTICIPANT	\N	PRESENT	0
421671	421664	08043V	PARTICIPANT	\N	PRESENT	0
421672	421664	87003B	PARTICIPANT	\N	PRESENT	0
421673	421664	14229S	PARTICIPANT	\N	PRESENT	0
421674	421664	14030Q	PARTICIPANT	\N	PRESENT	0
421675	421664	14241N	PARTICIPANT	\N	PRESENT	0
421676	421664	19731Y	PARTICIPANT	\N	PRESENT	0
421677	421664	04059M	PARTICIPANT	\N	PRESENT	0
421678	421664	14039A	PARTICIPANT	\N	PRESENT	0
421679	421664	19735D	PARTICIPANT	\N	PRESENT	0
421680	421664	14063N	PARTICIPANT	\N	PRESENT	0
421681	421664	07033P	PARTICIPANT	\N	PRESENT	0
421682	421664	08012N	PARTICIPANT	\N	PRESENT	0
421683	421664	11043H	PARTICIPANT	\N	PRESENT	0
421684	421664	19758L	PARTICIPANT	\N	PRESENT	0
421685	421664	04018C	PARTICIPANT	\N	PRESENT	0
421686	421664	08039A	PARTICIPANT	\N	PRESENT	0
421687	421664	08031R	PARTICIPANT	\N	PRESENT	0
421688	421664	19693L	PARTICIPANT	\N	EXCUSE	0
421698	420251	11054L	PARTICIPANT	\N	PRESENT	0
421699	420251	08047A	PARTICIPANT	\N	PRESENT	0
421700	420707	14179A	PARTICIPANT	\N	PRESENT	0
421701	420707	11010L	PARTICIPANT	\N	PRESENT	0
421704	420251	19709B	PARTICIPANT	\N	PRESENT	0
421719	420529	04088S	PARTICIPANT	\N	PRESENT	0
421720	420529	11056N	PARTICIPANT	\N	PRESENT	0
421721	420529	08068F	PARTICIPANT	\N	EXCUSE	0
421722	420529	19812Y	PARTICIPANT	\N	EXCUSE	0
421723	420529	19295A	PARTICIPANT	\N	EXCUSE	0
421724	420529	08028W	PARTICIPANT	\N	EXCUSE	0
421725	420529	11081P	PARTICIPANT	\N	EXCUSE	0
421726	420529	17589D	PARTICIPANT	\N	EXCUSE	0
421727	420529	14329V	PARTICIPANT	\N	EXCUSE	0
421737	420707	11072N	PARTICIPANT	\N	PRESENT	0
421740	420647	19565D	PARTICIPANT	\N	PRESENT	0
421741	420647	19798U	PARTICIPANT	\N	PRESENT	0
421742	420647	19415P	PARTICIPANT	\N	PRESENT	0
421743	420647	14223L	PARTICIPANT	\N	PRESENT	0
421744	420647	04045F	PARTICIPANT	\N	PRESENT	0
421745	420647	14026U	PARTICIPANT	\N	PRESENT	0
421746	420647	17779H	PARTICIPANT	\N	PRESENT	0
421747	420647	19703U	PARTICIPANT	\N	PRESENT	0
421748	420647	14239U	PARTICIPANT	\N	PRESENT	0
421749	420647	11031D	PARTICIPANT	\N	PRESENT	0
421750	420647	14281W	PARTICIPANT	\N	PRESENT	0
421751	420647	14087W	PARTICIPANT	\N	PRESENT	0
421752	420647	19679N	PARTICIPANT	\N	PRESENT	0
421753	420647	14042U	PARTICIPANT	\N	PRESENT	0
421754	420647	19575F	PARTICIPANT	\N	PRESENT	0
421755	420647	14195A	PARTICIPANT	\N	PRESENT	0
421756	420647	08048B	PARTICIPANT	\N	PRESENT	0
421757	420647	19367Y	PARTICIPANT	\N	PRESENT	0
421758	420647	14213J	PARTICIPANT	\N	PRESENT	0
421759	420647	14217N	PARTICIPANT	\N	PRESENT	0
421760	420647	14261S	PARTICIPANT	\N	PRESENT	0
421761	420647	10006L	PARTICIPANT	\N	PRESENT	0
421762	420647	19683J	PARTICIPANT	\N	PRESENT	0
421763	420647	98024R	PARTICIPANT	\N	PRESENT	0
421764	420647	19521Q	PARTICIPANT	\N	PRESENT	0
421765	420647	01034P	PARTICIPANT	\N	PRESENT	0
421766	420647	04092N	PRESIDENT	0	PRESENT	0
421767	420647	08052W	PARTICIPANT	\N	PRESENT	0
421768	420647	19663E	PARTICIPANT	\N	PRESENT	0
421769	420647	19691J	PARTICIPANT	\N	PRESENT	0
421770	420647	19717B	PARTICIPANT	\N	PRESENT	0
421771	420647	19727D	PARTICIPANT	\N	PRESENT	0
421772	420647	14119M	PARTICIPANT	\N	PRESENT	0
421773	420647	11103C	PARTICIPANT	\N	PRESENT	0
421774	420647	14071N	PARTICIPANT	\N	PRESENT	0
421775	420647	19577H	PARTICIPANT	\N	PRESENT	0
421776	420647	19760E	PARTICIPANT	\N	PRESENT	0
421777	420647	08041T	PARTICIPANT	\N	EXCUSE	0
421816	417145	14195A	PARTICIPANT	\N	EXCUSE	0
421817	420251	08049C	PARTICIPANT	\N	PRESENT	0
421818	420251	95067Q	PARTICIPANT	\N	PRESENT	0
421819	421664	19573D	PARTICIPANT	\N	PRESENT	0
421820	421664	14123H	PARTICIPANT	\N	PRESENT	0
421821	421664	19533U	PARTICIPANT	\N	EXCUSE	0
421822	417145	11049P	PARTICIPANT	\N	PRESENT	0
421823	420709	14065Q	PARTICIPANT	\N	EXCUSE	0
421824	420709	19581D	PARTICIPANT	\N	EXCUSE	0
421825	420709	19719D	PARTICIPANT	\N	EXCUSE	0
421826	420709	19675J	PARTICIPANT	\N	EXCUSE	0
421827	420709	19762G	PARTICIPANT	\N	PRESENT	0
421828	420709	05008E	PRESIDENT	0	PRESENT	0
421833	420709	14053L	PARTICIPANT	\N	PRESENT	0
421834	420709	14111D	PARTICIPANT	\N	PRESENT	0
421835	420709	19649G	PARTICIPANT	\N	PRESENT	0
421836	420709	11026G	PARTICIPANT	\N	PRESENT	0
421837	420709	08045X	PARTICIPANT	\N	PRESENT	0
421838	420709	01024M	PARTICIPANT	\N	PRESENT	0
421839	420709	04038G	PARTICIPANT	\N	PRESENT	0
421840	420709	04044E	PARTICIPANT	\N	PRESENT	0
421841	420709	19585H	PARTICIPANT	\N	PRESENT	0
421842	420709	04047H	PARTICIPANT	\N	PRESENT	0
421843	420709	01028R	PARTICIPANT	\N	PRESENT	0
421844	420709	14231L	PARTICIPANT	\N	PRESENT	0
421845	420709	19725B	PARTICIPANT	\N	PRESENT	0
421846	420709	14147R	PARTICIPANT	\N	PRESENT	0
421847	420709	14069U	PARTICIPANT	\N	PRESENT	0
421848	420709	14151M	PARTICIPANT	\N	PRESENT	0
421849	420709	11049P	PARTICIPANT	\N	PRESENT	0
421850	420709	14021P	PARTICIPANT	\N	PRESENT	0
421851	420709	11072N	PARTICIPANT	\N	PRESENT	0
421863	407837	19507S	PARTICIPANT	\N	PRESENT	0
421864	407837	14275Y	PARTICIPANT	\N	PRESENT	0
421865	407837	19711U	PARTICIPANT	\N	PRESENT	0
421866	407837	14042U	PARTICIPANT	\N	PRESENT	0
421867	407837	08055A	PARTICIPANT	\N	PRESENT	0
421868	407837	19387D	PARTICIPANT	\N	PRESENT	0
421869	407837	14063N	PARTICIPANT	\N	PRESENT	0
421870	407837	19443T	PARTICIPANT	\N	PRESENT	0
421871	407837	08056B	PARTICIPANT	\N	PRESENT	0
421872	407837	19511N	PARTICIPANT	\N	PRESENT	0
421873	407837	98022P	PARTICIPANT	\N	PRESENT	0
421874	407837	19599P	PARTICIPANT	\N	PRESENT	0
421875	407837	80013X	PARTICIPANT	\N	PRESENT	0
421876	407837	11041F	PARTICIPANT	\N	PRESENT	0
421877	407837	08034U	PARTICIPANT	\N	PRESENT	0
421878	407837	19251M	PARTICIPANT	\N	PRESENT	0
421879	407837	19731Y	PARTICIPANT	\N	PRESENT	0
421880	407837	14026U	PARTICIPANT	\N	PRESENT	0
421881	407837	14267Y	PARTICIPANT	\N	PRESENT	0
421883	407837	19383Y	PARTICIPANT	\N	PRESENT	0
421886	407837	14257W	PARTICIPANT	\N	PRESENT	0
421887	407837	14211G	PARTICIPANT	\N	PRESENT	0
421888	407837	08043V	PARTICIPANT	\N	PRESENT	0
421889	407837	11110B	PARTICIPANT	\N	PRESENT	0
421890	407837	15447F	PARTICIPANT	\N	PRESENT	0
421891	407837	19525U	PARTICIPANT	\N	PRESENT	0
392737	378005	19762G	PARTICIPANT	\N	PRESENT	0
392738	390061	14033T	PARTICIPANT	\N	EXCUSE	0
392739	390317	14033T	PARTICIPANT	\N	EXCUSE	0
392740	378005	14179A	PARTICIPANT	\N	PRESENT	0
392741	378005	19749K	PARTICIPANT	\N	PRESENT	0
392742	378005	11064N	PARTICIPANT	\N	PRESENT	0
392743	378005	14033T	PARTICIPANT	\N	PRESENT	0
392744	378005	11097X	PARTICIPANT	\N	PRESENT	0
393386	393384	08068F	PARTICIPANT	\N	PRESENT	0
393387	393384	08062Y	PARTICIPANT	\N	PRESENT	0
393388	393384	19269X	PARTICIPANT	\N	PRESENT	0
393389	393384	19705W	PARTICIPANT	\N	PRESENT	0
393530	378054	19715Y	PARTICIPANT	\N	PRESENT	0
393528	378054	11027H	PARTICIPANT	\N	PRESENT	0
393529	378054	14215L	PARTICIPANT	\N	PRESENT	0
393531	378054	14151M	PARTICIPANT	\N	PRESENT	0
393532	378054	14001X	PARTICIPANT	\N	PRESENT	0
393533	378054	11031D	PARTICIPANT	\N	PRESENT	0
393534	378054	04085P	PARTICIPANT	\N	PRESENT	0
393535	378054	19737F	PARTICIPANT	\N	PRESENT	0
393536	378054	14267Y	PARTICIPANT	\N	PRESENT	0
393537	378054	14179A	PARTICIPANT	\N	PRESENT	0
393538	378054	08019V	PARTICIPANT	\N	PRESENT	0
393539	378054	14119M	PARTICIPANT	\N	PRESENT	0
393540	378054	04088S	PARTICIPANT	\N	PRESENT	0
393541	378054	19467C	PARTICIPANT	\N	PRESENT	0
393542	378054	19447X	PARTICIPANT	\N	PRESENT	0
393543	378054	19711U	PARTICIPANT	\N	PRESENT	0
393544	378054	95030B	PARTICIPANT	\N	PRESENT	0
393545	378054	19507S	PARTICIPANT	\N	PRESENT	0
393546	378054	19621T	PARTICIPANT	\N	PRESENT	0
393547	378054	11072N	PARTICIPANT	\N	PRESENT	0
393548	378054	19543W	PARTICIPANT	\N	PRESENT	0
393549	378054	19713W	PARTICIPANT	\N	PRESENT	0
393550	378054	14030Q	PARTICIPANT	\N	PRESENT	0
393551	378054	19749K	PARTICIPANT	\N	PRESENT	0
393552	378054	19301E	PARTICIPANT	\N	PRESENT	0
393553	378054	19675J	PARTICIPANT	\N	PRESENT	0
393554	378054	11099A	PARTICIPANT	\N	PRESENT	0
393555	378054	19693L	PARTICIPANT	\N	PRESENT	0
393556	378054	19687N	PARTICIPANT	\N	PRESENT	0
393557	378054	11067R	PARTICIPANT	\N	PRESENT	0
393558	378054	14083S	PARTICIPANT	\N	PRESENT	0
393559	378054	05008E	PARTICIPANT	\N	PRESENT	0
393560	378054	19651A	PARTICIPANT	\N	PRESENT	0
393561	378054	19563B	PARTICIPANT	\N	PRESENT	0
393562	378054	11033F	PARTICIPANT	\N	PRESENT	0
393566	378054	19667J	PARTICIPANT	\N	PRESENT	0
393578	378054	08069G	PARTICIPANT	\N	PRESENT	0
393590	378054	19611R	PARTICIPANT	\N	PRESENT	0
393591	378054	19695N	PARTICIPANT	\N	PRESENT	0
393601	378054	01028R	PARTICIPANT	\N	PRESENT	0
393602	378054	11109J	PARTICIPANT	\N	PRESENT	0
393603	378054	04057K	PARTICIPANT	\N	PRESENT	0
393606	378054	19253P	PARTICIPANT	\N	PRESENT	0
393616	378054	19782L	PARTICIPANT	\N	PRESENT	0
393656	378054	07029T	PARTICIPANT	\N	PRESENT	0
393683	378054	19269X	PARTICIPANT	\N	PRESENT	0
393684	378054	14275Y	PARTICIPANT	\N	PRESENT	0
393717	378055	11072N	PARTICIPANT	\N	PRESENT	0
393718	378055	19269X	PARTICIPANT	\N	PRESENT	0
393719	378055	04085P	PARTICIPANT	\N	PRESENT	0
393720	378055	19715Y	PARTICIPANT	\N	PRESENT	0
393721	378055	14151M	PARTICIPANT	\N	PRESENT	0
393722	378055	11109J	PARTICIPANT	\N	PRESENT	0
393723	378055	14001X	PARTICIPANT	\N	PRESENT	0
393724	378055	14275Y	PARTICIPANT	\N	PRESENT	0
393725	378055	14030Q	PARTICIPANT	\N	PRESENT	0
393726	378055	14083S	PARTICIPANT	\N	PRESENT	0
393727	378055	19695N	PARTICIPANT	\N	PRESENT	0
393728	378055	19687N	PARTICIPANT	\N	PRESENT	0
393729	378055	19711U	PARTICIPANT	\N	PRESENT	0
393730	378055	19667J	PARTICIPANT	\N	PRESENT	0
393731	378055	19621T	PARTICIPANT	\N	PRESENT	0
393732	378055	08010L	PARTICIPANT	\N	PRESENT	0
393733	378055	19447X	PARTICIPANT	\N	PRESENT	0
393734	378055	08019V	PARTICIPANT	\N	PRESENT	0
393735	378055	19301E	PARTICIPANT	\N	PRESENT	0
393736	378055	05008E	PARTICIPANT	\N	PRESENT	0
393737	378055	14179A	PARTICIPANT	\N	PRESENT	0
393738	378055	19782L	PARTICIPANT	\N	PRESENT	0
393739	378055	19689Q	PARTICIPANT	\N	PRESENT	0
393740	378055	19693L	PARTICIPANT	\N	PRESENT	0
393741	378055	17637T	PARTICIPANT	\N	PRESENT	0
393742	378055	11099A	PARTICIPANT	\N	PRESENT	0
393743	378055	19741B	PARTICIPANT	\N	PRESENT	0
393966	393744	04045F	PARTICIPANT	\N	EXCUSE	0
393715	378055	04044E	PARTICIPANT	\N	PRESENT	0
393716	378055	14215L	PARTICIPANT	\N	PRESENT	0
394045	393744	14195A	PARTICIPANT	\N	EXCUSE	0
396627	393390	04044E	PARTICIPANT	\N	PRESENT	0
396635	393390	14105F	PARTICIPANT	\N	PRESENT	0
396636	393390	19533U	PARTICIPANT	\N	PRESENT	0
396637	393390	19758L	PARTICIPANT	\N	PRESENT	0
396640	393390	19699S	PARTICIPANT	\N	PRESENT	0
396645	393390	19585H	PARTICIPANT	\N	PRESENT	0
396646	393390	19447X	PARTICIPANT	\N	PRESENT	0
396647	393390	19515S	PARTICIPANT	\N	PRESENT	0
396648	393390	14215L	PARTICIPANT	\N	PRESENT	0
396649	393390	14063N	PARTICIPANT	\N	PRESENT	0
396650	393390	19711U	PARTICIPANT	\N	PRESENT	0
396653	393390	19593H	PARTICIPANT	\N	PRESENT	0
396654	393390	14073Q	PARTICIPANT	\N	PRESENT	0
396655	393390	08012N	PARTICIPANT	\N	PRESENT	0
396599	393383	04044E	PARTICIPANT	\N	PRESENT	0
396600	393383	14061L	PARTICIPANT	\N	PRESENT	0
396657	393390	14021P	PARTICIPANT	\N	PRESENT	0
396658	393390	14081Q	PARTICIPANT	\N	PRESENT	0
396603	393383	08010L	PARTICIPANT	\N	PRESENT	0
396659	393390	04070G	PARTICIPANT	\N	PRESENT	0
396660	393390	08024S	PARTICIPANT	\N	PRESENT	0
396606	393383	14109K	PARTICIPANT	\N	PRESENT	0
396607	393383	19637C	PARTICIPANT	\N	PRESENT	0
396608	393383	08055A	PARTICIPANT	\N	PRESENT	0
396609	393383	14169X	PARTICIPANT	\N	PRESENT	0
396610	393383	19581D	PARTICIPANT	\N	PRESENT	0
396611	393383	11049P	PARTICIPANT	\N	PRESENT	0
396613	393383	14041T	PARTICIPANT	\N	PRESENT	0
396661	393390	14229S	PARTICIPANT	\N	PRESENT	0
396664	393390	14039A	PARTICIPANT	\N	PRESENT	0
396666	393390	14241N	PARTICIPANT	\N	PRESENT	0
396669	393390	18083K	PARTICIPANT	\N	PRESENT	0
396670	393390	19301E	PARTICIPANT	\N	PRESENT	0
396671	393390	19729F	PARTICIPANT	\N	PRESENT	0
396672	393390	19399H	PARTICIPANT	\N	PRESENT	0
396673	393390	19701S	PARTICIPANT	\N	PRESENT	0
396674	393390	97011G	PARTICIPANT	\N	PRESENT	0
396675	393390	19543W	PARTICIPANT	\N	PRESENT	0
396676	393390	14197C	PARTICIPANT	\N	PRESENT	0
396625	393383	19681G	PARTICIPANT	\N	PRESENT	0
396677	393390	19762G	PARTICIPANT	\N	PRESENT	0
396678	393390	15447F	PARTICIPANT	\N	PRESENT	0
396679	393390	01025N	PARTICIPANT	\N	PRESENT	0
396680	393390	14071N	PARTICIPANT	\N	PRESENT	0
396681	393390	19695N	PARTICIPANT	\N	PRESENT	0
396682	393390	95030B	PARTICIPANT	\N	PRESENT	0
396683	393390	19798U	PARTICIPANT	\N	PRESENT	0
396684	393390	08020N	PARTICIPANT	\N	PRESENT	0
396685	393390	19749K	PARTICIPANT	\N	PRESENT	0
396686	393390	19441R	PARTICIPANT	\N	PRESENT	0
396687	393390	14089Y	PARTICIPANT	\N	PRESENT	0
396688	393390	19735D	PARTICIPANT	\N	PRESENT	0
396690	393390	98050T	PARTICIPANT	\N	PRESENT	0
396691	393390	14061L	PARTICIPANT	\N	PRESENT	0
396692	393390	11040E	PARTICIPANT	\N	PRESENT	0
396693	393390	17583W	PARTICIPANT	\N	PRESENT	0
396694	393390	01058X	PARTICIPANT	\N	PRESENT	0
396695	393390	14219Q	PARTICIPANT	\N	PRESENT	0
396696	393390	14251Q	PARTICIPANT	\N	PRESENT	0
396697	393390	87003B	PARTICIPANT	\N	PRESENT	0
396698	393390	19581D	PARTICIPANT	\N	PRESENT	0
396699	393390	14030Q	PARTICIPANT	\N	PRESENT	0
396700	393390	19443T	PARTICIPANT	\N	PRESENT	0
396701	393390	95062K	PARTICIPANT	\N	PRESENT	0
396702	393390	14259Y	PARTICIPANT	\N	PRESENT	0
396703	393390	19507S	PARTICIPANT	\N	PRESENT	0
396704	393390	19563B	PARTICIPANT	\N	PRESENT	0
396705	393390	19745F	PARTICIPANT	\N	PRESENT	0
396706	393390	14042U	PARTICIPANT	\N	PRESENT	0
396707	393390	19479G	PARTICIPANT	\N	PRESENT	0
396709	393390	14151M	PARTICIPANT	\N	PRESENT	0
396710	393390	08017T	PARTICIPANT	\N	PRESENT	0
396711	393390	08055A	PARTICIPANT	\N	PRESENT	0
396712	393390	14087W	PARTICIPANT	\N	PRESENT	0
396713	393390	11067R	PARTICIPANT	\N	PRESENT	0
396714	393390	01062T	PARTICIPANT	\N	PRESENT	0
396715	393390	19681G	PARTICIPANT	\N	PRESENT	0
420411	420306	11067R	PARTICIPANT	\N	PRESENT	0
420412	420306	14071N	PARTICIPANT	\N	PRESENT	0
420413	420305	14071N	PARTICIPANT	\N	PRESENT	0
420414	420305	11067R	PARTICIPANT	\N	PRESENT	0
420600	414386	04045F	PARTICIPANT	\N	PRESENT	0
420611	420607	08039A	PARTICIPANT	\N	PRESENT	0
420612	420607	98050T	PARTICIPANT	\N	PRESENT	0
420613	420607	19663E	PARTICIPANT	\N	PRESENT	0
420614	420607	14217N	PARTICIPANT	\N	PRESENT	0
420619	420607	19647E	PARTICIPANT	\N	PRESENT	0
420621	420607	11026G	PARTICIPANT	\N	PRESENT	0
420630	420629	98018T	PARTICIPANT	\N	PRESENT	0
420631	420629	11041F	PARTICIPANT	\N	PRESENT	0
420633	420632	98018T	PARTICIPANT	\N	PRESENT	0
420634	420632	11041F	PARTICIPANT	\N	PRESENT	0
420636	420635	11064N	PARTICIPANT	\N	PRESENT	0
420637	420635	11054L	PARTICIPANT	\N	PRESENT	0
420639	420638	14033T	PARTICIPANT	\N	PRESENT	0
420641	420640	14033T	PARTICIPANT	\N	PRESENT	0
420643	420642	14033T	PARTICIPANT	\N	PRESENT	0
420645	420644	14033T	PARTICIPANT	\N	PRESENT	0
420650	420648	10006L	PARTICIPANT	\N	PRESENT	0
420651	420649	10006L	PARTICIPANT	\N	PRESENT	0
420697	420692	19693L	PARTICIPANT	\N	PRESENT	0
420698	420693	19693L	PARTICIPANT	\N	PRESENT	0
420699	420694	19693L	PARTICIPANT	\N	PRESENT	0
420700	420695	19693L	PARTICIPANT	\N	PRESENT	0
420701	420696	19693L	PARTICIPANT	\N	PRESENT	0
420703	420702	14111D	PARTICIPANT	\N	PRESENT	0
420719	420648	14071N	PARTICIPANT	\N	PRESENT	0
420724	420723	14219Q	PARTICIPANT	\N	PRESENT	0
420726	420725	14219Q	PARTICIPANT	\N	PRESENT	0
420766	407833	04038G	PARTICIPANT	\N	PRESENT	0
420767	407833	19621T	PARTICIPANT	\N	PRESENT	0
420762	407833	04086Q	PARTICIPANT	\N	PRESENT	0
420732	420691	04070G	PRESIDENT	0	PRESENT	0
420733	420691	19699S	PARTICIPANT	\N	PRESENT	0
420734	420691	19533U	PARTICIPANT	\N	PRESENT	0
420735	420691	04033B	PARTICIPANT	\N	PRESENT	0
420736	420691	14241N	PARTICIPANT	\N	PRESENT	0
420737	420691	14039A	PARTICIPANT	\N	PRESENT	0
420738	420691	14107H	PARTICIPANT	\N	PRESENT	0
420739	420691	08017T	PARTICIPANT	\N	PRESENT	0
420740	420691	08012N	PARTICIPANT	\N	PRESENT	0
420741	420691	19335Q	PARTICIPANT	\N	PRESENT	0
420742	420691	08039A	PARTICIPANT	\N	PRESENT	0
420743	420691	08031R	PARTICIPANT	\N	PRESENT	0
420744	420691	19593H	PARTICIPANT	\N	PRESENT	0
420745	420691	19643A	PARTICIPANT	\N	PRESENT	0
420746	420691	14059S	PARTICIPANT	\N	PRESENT	0
420747	420691	14073Q	PARTICIPANT	\N	PRESENT	0
420748	420691	19611R	PARTICIPANT	\N	PRESENT	0
420749	420691	08043V	PARTICIPANT	\N	PRESENT	0
420750	420691	87003B	PARTICIPANT	\N	PRESENT	0
420751	420691	19399H	PARTICIPANT	\N	PRESENT	0
420752	420691	14030Q	PARTICIPANT	\N	PRESENT	0
420753	420691	19731Y	PARTICIPANT	\N	PRESENT	0
420754	420691	14123H	PARTICIPANT	\N	PRESENT	0
420755	420691	11104D	PARTICIPANT	\N	PRESENT	0
420756	420691	19621T	PARTICIPANT	\N	PRESENT	0
420757	420691	14061L	PARTICIPANT	\N	EXCUSE	0
420758	420691	19693L	PARTICIPANT	\N	EXCUSE	0
420759	420691	19749K	PARTICIPANT	\N	EXCUSE	0
420760	420691	04018C	PARTICIPANT	\N	EXCUSE	0
420761	420691	04057K	PARTICIPANT	\N	PRESENT	0
420768	407833	14229S	PARTICIPANT	\N	PRESENT	0
420769	407833	19479G	PARTICIPANT	\N	PRESENT	0
420770	407833	19611R	PARTICIPANT	\N	PRESENT	0
420771	407833	08012N	PARTICIPANT	\N	PRESENT	0
420772	407833	08043V	PARTICIPANT	\N	PRESENT	0
420773	407833	11104D	PARTICIPANT	\N	PRESENT	0
420774	407833	19577H	PARTICIPANT	\N	PRESENT	0
420775	407833	19533U	PARTICIPANT	\N	PRESENT	0
420776	407833	19671E	PARTICIPANT	\N	PRESENT	0
420777	407833	19695N	PARTICIPANT	\N	PRESENT	0
420778	407833	19593H	PARTICIPANT	\N	PRESENT	0
420779	407833	12041X	PARTICIPANT	\N	PRESENT	0
420780	407833	19565D	PARTICIPANT	\N	PRESENT	0
420781	407833	14039A	PARTICIPANT	\N	PRESENT	0
420782	407833	95041E	PARTICIPANT	\N	PRESENT	0
420783	407833	19731Y	PARTICIPANT	\N	PRESENT	0
420784	407833	14053L	PARTICIPANT	\N	PRESENT	0
420785	407833	14107H	PARTICIPANT	\N	PRESENT	0
420786	407833	19253P	PARTICIPANT	\N	PRESENT	0
420787	407833	11103C	PARTICIPANT	\N	PRESENT	0
420788	407833	08060W	PARTICIPANT	\N	PRESENT	0
420789	407833	98029W	PARTICIPANT	\N	PRESENT	0
420790	407833	19367Y	PARTICIPANT	\N	PRESENT	0
420791	407833	08056B	PARTICIPANT	\N	PRESENT	0
420792	407833	19737F	PARTICIPANT	\N	PRESENT	0
420793	407833	14219Q	PARTICIPANT	\N	PRESENT	0
420794	407833	14241N	PARTICIPANT	\N	PRESENT	0
420795	407833	08031R	PARTICIPANT	\N	PRESENT	0
420796	407833	19629C	PARTICIPANT	\N	PRESENT	0
420797	407833	14109K	PARTICIPANT	\N	PRESENT	0
420798	407833	04033B	PARTICIPANT	\N	PRESENT	0
420799	407833	14071N	PARTICIPANT	\N	PRESENT	0
420800	407833	04070G	PARTICIPANT	\N	PRESENT	0
420801	407833	19651A	PARTICIPANT	\N	PRESENT	0
420802	407833	08055A	PARTICIPANT	\N	PRESENT	0
420803	407833	11040E	PARTICIPANT	\N	PRESENT	0
420804	407833	11056N	PARTICIPANT	\N	PRESENT	0
420805	407833	19758L	PARTICIPANT	\N	PRESENT	0
420806	407833	19760E	PARTICIPANT	\N	PRESENT	0
420807	407833	19679N	PARTICIPANT	\N	PRESENT	0
420808	407833	08039A	PARTICIPANT	\N	PRESENT	0
420809	407833	19649G	PARTICIPANT	\N	PRESENT	0
420810	407833	19643A	PARTICIPANT	\N	PRESENT	0
420811	407833	11045K	PARTICIPANT	\N	PRESENT	0
420812	407833	14223L	PARTICIPANT	\N	PRESENT	0
420813	407833	19333N	PARTICIPANT	\N	PRESENT	0
420814	407833	11066Q	PARTICIPANT	\N	PRESENT	0
420815	407833	14021P	PARTICIPANT	\N	PRESENT	0
420816	407833	04085P	PARTICIPANT	\N	PRESENT	0
420817	407833	19347U	PARTICIPANT	\N	PRESENT	0
420818	407833	19782L	PARTICIPANT	\N	PRESENT	0
420819	407833	01058X	PARTICIPANT	\N	PRESENT	0
420820	407833	08024S	PARTICIPANT	\N	PRESENT	0
420821	407833	19289C	PARTICIPANT	\N	PRESENT	0
420822	407833	19503N	PARTICIPANT	\N	PRESENT	0
420823	407833	08017T	PARTICIPANT	\N	PRESENT	0
420824	407833	19681G	PARTICIPANT	\N	PRESENT	0
420825	407833	04057K	PARTICIPANT	\N	PRESENT	0
420826	407833	04034C	PARTICIPANT	\N	PRESENT	0
420827	407833	14197C	PARTICIPANT	\N	PRESENT	0
420828	407833	08061X	PARTICIPANT	\N	PRESENT	0
420829	407833	95037J	PARTICIPANT	\N	PRESENT	0
420830	407833	14261S	PARTICIPANT	\N	PRESENT	0
420831	407833	14157T	PARTICIPANT	\N	PRESENT	0
420832	407833	19585H	PARTICIPANT	\N	PRESENT	0
420833	407833	19545Y	PARTICIPANT	\N	PRESENT	0
420834	407833	19349W	PARTICIPANT	\N	PRESENT	0
420835	407833	14251Q	PARTICIPANT	\N	PRESENT	0
420836	407833	04040A	PARTICIPANT	\N	PRESENT	0
420837	407833	08028W	PARTICIPANT	\N	PRESENT	0
420838	407833	19569H	PARTICIPANT	\N	PRESENT	0
420839	407833	19699S	PARTICIPANT	\N	PRESENT	0
420840	407833	99004R	PARTICIPANT	\N	PRESENT	0
420841	407833	14267Y	PARTICIPANT	\N	PRESENT	0
420842	407833	17637T	PARTICIPANT	\N	PRESENT	0
420843	407833	14073Q	PARTICIPANT	\N	PRESENT	0
420844	407833	19515S	PARTICIPANT	\N	PRESENT	0
420845	407833	19826F	PARTICIPANT	\N	PRESENT	0
420846	407833	14231L	PARTICIPANT	\N	PRESENT	0
420847	407833	19703U	PARTICIPANT	\N	PRESENT	0
420848	407833	19415P	PARTICIPANT	\N	PRESENT	0
420849	407833	19447X	PARTICIPANT	\N	PRESENT	0
420850	407833	19421M	PARTICIPANT	\N	PRESENT	0
420851	407833	14038Y	PARTICIPANT	\N	PRESENT	0
420852	407833	19701S	PARTICIPANT	\N	PRESENT	0
420853	407833	19741B	PARTICIPANT	\N	PRESENT	0
420854	407833	19762G	PARTICIPANT	\N	PRESENT	0
420855	407833	19383Y	PARTICIPANT	\N	PRESENT	0
420856	407833	14029X	PARTICIPANT	\N	PRESENT	0
420857	407833	14217N	PARTICIPANT	\N	PRESENT	0
420858	407833	19573D	PARTICIPANT	\N	PRESENT	0
420859	407833	19798U	PARTICIPANT	\N	PRESENT	0
420860	407833	18083K	PARTICIPANT	\N	PRESENT	0
420861	407833	19399H	PARTICIPANT	\N	PRESENT	0
420862	407833	14187A	PARTICIPANT	\N	PRESENT	0
420863	407833	14331P	PARTICIPANT	\N	PRESENT	0
420864	407833	14135M	PARTICIPANT	\N	PRESENT	0
420865	407833	14329V	PARTICIPANT	\N	PRESENT	0
420866	407833	08062Y	PARTICIPANT	\N	PRESENT	0
420867	407833	14357A	PARTICIPANT	\N	PRESENT	0
420868	407833	14061L	PARTICIPANT	\N	PRESENT	0
420869	407833	14026U	PARTICIPANT	\N	PRESENT	0
420870	407833	14213J	PARTICIPANT	\N	PRESENT	0
420871	407833	14265W	PARTICIPANT	\N	PRESENT	0
403513	393655	19737F	PARTICIPANT	\N	PRESENT	0
403514	393655	14217N	PARTICIPANT	\N	PRESENT	0
403515	393655	14205J	PARTICIPANT	\N	PRESENT	0
403516	393655	14079W	PARTICIPANT	\N	PRESENT	0
403517	393655	19611R	PARTICIPANT	\N	PRESENT	0
403518	393655	19747H	PARTICIPANT	\N	PRESENT	0
403519	393655	19511N	PARTICIPANT	\N	PRESENT	0
403520	393655	19619A	PARTICIPANT	\N	PRESENT	0
403521	393655	16685X	PARTICIPANT	\N	PRESENT	0
403522	393655	19739H	PARTICIPANT	\N	PRESENT	0
403523	393655	05012A	PARTICIPANT	\N	PRESENT	0
403524	393655	19533U	PARTICIPANT	\N	PRESENT	0
403525	393655	14179A	PARTICIPANT	\N	PRESENT	0
403526	393655	14219Q	PARTICIPANT	\N	PRESENT	0
403527	393655	19479G	PARTICIPANT	\N	PRESENT	0
403528	393655	14053L	PARTICIPANT	\N	PRESENT	0
403529	393655	19441R	PARTICIPANT	\N	PRESENT	0
403530	393655	19543W	PARTICIPANT	\N	PRESENT	0
403531	393655	14249W	PARTICIPANT	\N	PRESENT	0
403532	393655	04043D	PARTICIPANT	\N	PRESENT	0
403533	393655	14034U	PARTICIPANT	\N	PRESENT	0
403534	393655	04033B	PARTICIPANT	\N	PRESENT	0
403535	393655	14275Y	PARTICIPANT	\N	PRESENT	0
403536	393655	14187A	PARTICIPANT	\N	PRESENT	0
403537	393655	14073Q	PARTICIPANT	\N	PRESENT	0
403538	393655	14071N	PARTICIPANT	\N	PRESENT	0
403539	393655	19699S	PARTICIPANT	\N	PRESENT	0
403540	393655	05008E	PARTICIPANT	\N	PRESENT	0
403541	393655	14089Y	PARTICIPANT	\N	PRESENT	0
403542	393655	11097X	PARTICIPANT	\N	PRESENT	0
403543	393655	19745F	PARTICIPANT	\N	PRESENT	0
403544	393655	19421M	PARTICIPANT	\N	PRESENT	0
403545	393655	11070L	PARTICIPANT	\N	PRESENT	0
403546	393655	04086Q	PARTICIPANT	\N	PRESENT	0
403547	393655	14255U	PARTICIPANT	\N	PRESENT	0
403548	393655	04044E	PARTICIPANT	\N	PRESENT	0
403549	393655	11045K	PARTICIPANT	\N	PRESENT	0
403550	393655	95041E	PARTICIPANT	\N	PRESENT	0
403551	393655	11085T	PARTICIPANT	\N	PRESENT	0
403552	393655	95030B	PARTICIPANT	\N	PRESENT	0
403553	393655	04070G	PARTICIPANT	\N	PRESENT	0
403554	393655	14030Q	PARTICIPANT	\N	PRESENT	0
403555	393655	04047H	PARTICIPANT	\N	PRESENT	0
403556	393655	14026U	PARTICIPANT	\N	PRESENT	0
403557	393655	11101A	PARTICIPANT	\N	PRESENT	0
403558	393655	01024M	PARTICIPANT	\N	PRESENT	0
403559	393655	98024R	PARTICIPANT	\N	PRESENT	0
403560	393655	04035D	PARTICIPANT	\N	PRESENT	0
403561	393655	14237S	PARTICIPANT	\N	PRESENT	0
403562	393655	19671E	PARTICIPANT	\N	PRESENT	0
403563	393655	19687N	PARTICIPANT	\N	PRESENT	0
403564	393655	14083S	PARTICIPANT	\N	PRESENT	0
403565	393655	01062T	PARTICIPANT	\N	PRESENT	0
403566	393655	14213J	PARTICIPANT	\N	PRESENT	0
403567	393655	08039A	PARTICIPANT	\N	PRESENT	0
403568	393655	19399H	PARTICIPANT	\N	PRESENT	0
403569	393655	19347U	PARTICIPANT	\N	PRESENT	0
403570	393655	14069U	PARTICIPANT	\N	PRESENT	0
403571	393655	19647E	PARTICIPANT	\N	PRESENT	0
403572	393655	11103C	PARTICIPANT	\N	PRESENT	0
403573	393655	14097Y	PARTICIPANT	\N	PRESENT	0
403574	393655	08058D	PARTICIPANT	\N	PRESENT	0
403575	393655	08056B	PARTICIPANT	\N	PRESENT	0
403576	393655	14215L	PARTICIPANT	\N	PRESENT	0
403577	393655	08011M	PARTICIPANT	\N	PRESENT	0
403578	393655	14093U	PARTICIPANT	\N	PRESENT	0
403586	393655	14135M	PARTICIPANT	\N	PRESENT	0
403580	393655	14265W	PARTICIPANT	\N	PRESENT	0
403581	393655	02002K	PARTICIPANT	\N	PRESENT	0
403582	393655	14033T	PARTICIPANT	\N	PRESENT	0
403584	393655	11048N	PARTICIPANT	\N	PRESENT	0
403585	393655	14119M	PARTICIPANT	\N	PRESENT	0
403587	393655	08034U	PARTICIPANT	\N	PRESENT	0
403588	393655	92040Q	PARTICIPANT	\N	PRESENT	0
403592	393655	04034C	PARTICIPANT	\N	PRESENT	0
403590	393655	11053K	PARTICIPANT	\N	PRESENT	0
403591	393655	04071H	PARTICIPANT	\N	PRESENT	0
403593	393655	11031D	PARTICIPANT	\N	PRESENT	0
403594	393655	19553Y	PARTICIPANT	\N	PRESENT	0
403595	393655	14151M	PARTICIPANT	\N	PRESENT	0
403596	393655	11065P	PARTICIPANT	\N	PRESENT	0
403597	393655	19335Q	PARTICIPANT	\N	PRESENT	0
403598	393655	19723Y	PARTICIPANT	\N	PRESENT	0
403603	400170	19593H	PARTICIPANT	\N	PRESENT	0
403604	400170	08061X	PARTICIPANT	\N	PRESENT	0
403605	400170	95037J	PARTICIPANT	\N	PRESENT	0
403606	400170	95063L	PARTICIPANT	\N	PRESENT	0
403607	400170	19651A	PARTICIPANT	\N	PRESENT	0
403608	400170	86034E	PARTICIPANT	\N	PRESENT	0
403609	400170	19269X	PARTICIPANT	\N	PRESENT	0
403610	400170	08024S	PARTICIPANT	\N	PRESENT	0
403611	400170	19782L	PARTICIPANT	\N	PRESENT	0
403612	400170	04097T	PARTICIPANT	\N	PRESENT	0
403613	400170	96004D	PARTICIPANT	\N	PRESENT	0
403614	400170	14251Q	PARTICIPANT	\N	PRESENT	0
403615	400170	14111D	PARTICIPANT	\N	PRESENT	0
403616	400170	99004R	PARTICIPANT	\N	PRESENT	0
403617	400170	19583F	PARTICIPANT	\N	PRESENT	0
403618	400170	08010L	PARTICIPANT	\N	PRESENT	0
403619	400170	08069G	PARTICIPANT	\N	PRESENT	0
403620	400170	11099A	PARTICIPANT	\N	PRESENT	0
403621	400170	19289C	PARTICIPANT	\N	PRESENT	0
403622	400170	19766L	PARTICIPANT	\N	PRESENT	0
403623	400170	11080N	PARTICIPANT	\N	PRESENT	0
403624	400170	11027H	PARTICIPANT	\N	PRESENT	0
403625	400170	14159V	PARTICIPANT	\N	PRESENT	0
403626	400170	19643A	PARTICIPANT	\N	PRESENT	0
403627	400170	04059M	PARTICIPANT	\N	PRESENT	0
403628	400170	11074Q	PARTICIPANT	\N	PRESENT	0
403629	400170	11090Q	PARTICIPANT	\N	PRESENT	0
403630	400170	08052W	PARTICIPANT	\N	PRESENT	0
403631	400170	14229S	PARTICIPANT	\N	PRESENT	0
403632	400170	14031R	PARTICIPANT	\N	PRESENT	0
403633	400170	14021P	PARTICIPANT	\N	PRESENT	0
403634	400170	19667J	PARTICIPANT	\N	PRESENT	0
403635	400170	11104D	PARTICIPANT	\N	PRESENT	0
403636	400170	19575F	PARTICIPANT	\N	PRESENT	0
403637	400170	19525U	PARTICIPANT	\N	PRESENT	0
403638	400170	04049K	PARTICIPANT	\N	PRESENT	0
403639	400170	14207L	PARTICIPANT	\N	PRESENT	0
403640	400170	19447X	PARTICIPANT	\N	PRESENT	0
403641	400170	14257W	PARTICIPANT	\N	PRESENT	0
403642	400170	08047A	PARTICIPANT	\N	PRESENT	0
403643	400170	08014Q	PARTICIPANT	\N	PRESENT	0
403644	400170	14259Y	PARTICIPANT	\N	PRESENT	0
403645	400170	14038Y	PARTICIPANT	\N	PRESENT	0
403646	400170	19489J	PARTICIPANT	\N	PRESENT	0
403647	400170	14227Q	PARTICIPANT	\N	PRESENT	0
403648	400170	18083K	PARTICIPANT	\N	PRESENT	0
403649	400170	19503N	PARTICIPANT	\N	PRESENT	0
403650	400170	19531S	PARTICIPANT	\N	PRESENT	0
403651	400170	19727D	PARTICIPANT	\N	PRESENT	0
403652	400170	07029T	PARTICIPANT	\N	PRESENT	0
403653	400170	19649G	PARTICIPANT	\N	PRESENT	0
403654	400170	19689Q	PARTICIPANT	\N	PRESENT	0
403655	400170	95067Q	PARTICIPANT	\N	PRESENT	0
403656	400170	08015R	PARTICIPANT	\N	PRESENT	0
403657	400170	19768N	PARTICIPANT	\N	PRESENT	0
403658	400170	19705W	PARTICIPANT	\N	PRESENT	0
403659	400170	19251M	PARTICIPANT	\N	PRESENT	0
403660	400170	11033F	PARTICIPANT	\N	PRESENT	0
403661	400170	14169X	PARTICIPANT	\N	PRESENT	0
403662	400170	19709B	PARTICIPANT	\N	PRESENT	0
403663	400170	19695N	PARTICIPANT	\N	PRESENT	0
403664	400170	14173T	PARTICIPANT	\N	PRESENT	0
403665	400170	19719D	PARTICIPANT	\N	PRESENT	0
403666	400170	14357A	PARTICIPANT	\N	PRESENT	0
403667	400170	14231L	PARTICIPANT	\N	PRESENT	0
403668	400170	08031R	PARTICIPANT	\N	PRESENT	0
403669	400170	19701S	PARTICIPANT	\N	PRESENT	0
403670	400170	19369B	PARTICIPANT	\N	PRESENT	0
403671	400170	14217N	PARTICIPANT	\N	PRESENT	0
403672	400170	14205J	PARTICIPANT	\N	PRESENT	0
403673	400170	19611R	PARTICIPANT	\N	PRESENT	0
403674	400170	19511N	PARTICIPANT	\N	PRESENT	0
403675	400170	19619A	PARTICIPANT	\N	PRESENT	0
403676	400170	16685X	PARTICIPANT	\N	PRESENT	0
403677	400170	19739H	PARTICIPANT	\N	PRESENT	0
403678	400170	05012A	PARTICIPANT	\N	PRESENT	0
403679	400170	19533U	PARTICIPANT	\N	PRESENT	0
403680	400170	14219Q	PARTICIPANT	\N	PRESENT	0
403681	400170	19479G	PARTICIPANT	\N	PRESENT	0
403682	400170	14249W	PARTICIPANT	\N	PRESENT	0
403683	400170	14034U	PARTICIPANT	\N	PRESENT	0
403684	400170	04033B	PARTICIPANT	\N	PRESENT	0
403685	400170	14275Y	PARTICIPANT	\N	PRESENT	0
403686	400170	14187A	PARTICIPANT	\N	PRESENT	0
403687	400170	14071N	PARTICIPANT	\N	PRESENT	0
392893	391857	14034U	PARTICIPANT	\N	PRESENT	0
392899	391857	14079W	PARTICIPANT	\N	PRESENT	0
392900	391857	98029W	PARTICIPANT	\N	PRESENT	0
392901	391857	01062T	PARTICIPANT	\N	PRESENT	0
392902	391857	11066Q	PARTICIPANT	\N	PRESENT	0
392903	391857	19333N	PARTICIPANT	\N	PRESENT	0
392904	391857	19301E	PARTICIPANT	\N	PRESENT	0
392905	391857	19782L	PARTICIPANT	\N	PRESENT	0
392906	391857	02002K	PARTICIPANT	\N	PRESENT	0
392907	391857	14179A	PARTICIPANT	\N	PRESENT	0
392908	391857	14219Q	PARTICIPANT	\N	PRESENT	0
392909	391857	14267Y	PARTICIPANT	\N	PRESENT	0
392927	391857	19543W	PARTICIPANT	\N	PRESENT	0
392911	391857	19768N	PARTICIPANT	\N	PRESENT	0
392912	391857	14119M	PARTICIPANT	\N	PRESENT	0
392913	391857	19794Q	PARTICIPANT	\N	PRESENT	0
392914	391857	18083K	PARTICIPANT	\N	PRESENT	0
392915	391857	19347U	PARTICIPANT	\N	PRESENT	0
392916	391857	11012A	PARTICIPANT	\N	PRESENT	0
392917	391857	08049C	PARTICIPANT	\N	PRESENT	0
392918	391857	14038Y	PARTICIPANT	\N	PRESENT	0
392920	391857	19549D	PARTICIPANT	\N	PRESENT	0
392921	391857	19737F	PARTICIPANT	\N	PRESENT	0
392922	391857	14031R	PARTICIPANT	\N	PRESENT	0
392923	391857	11043H	PARTICIPANT	\N	PRESENT	0
392924	391857	14026U	PARTICIPANT	\N	PRESENT	0
392925	391857	97011G	PARTICIPANT	\N	PRESENT	0
392926	391857	95030B	PARTICIPANT	\N	PRESENT	0
392928	391857	19701S	PARTICIPANT	\N	PRESENT	0
392929	391857	14107H	PARTICIPANT	\N	PRESENT	0
392930	391857	19335Q	PARTICIPANT	\N	PRESENT	0
392931	391857	14029X	PARTICIPANT	\N	PRESENT	0
392932	391857	19507S	PARTICIPANT	\N	PRESENT	0
392933	391857	14097Y	PARTICIPANT	\N	PRESENT	0
392934	391857	19725B	PARTICIPANT	\N	PRESENT	0
392935	391857	19253P	PARTICIPANT	\N	PRESENT	0
392936	391857	19629C	PARTICIPANT	\N	PRESENT	0
392937	391857	19729F	PARTICIPANT	\N	PRESENT	0
392938	391857	19467C	PARTICIPANT	\N	PRESENT	0
392939	391857	14105F	PARTICIPANT	\N	PRESENT	0
392940	391857	11064N	PARTICIPANT	\N	PRESENT	0
392941	391857	98022P	PARTICIPANT	\N	PRESENT	0
392942	391857	14089Y	PARTICIPANT	\N	PRESENT	0
392943	391857	19798U	PARTICIPANT	\N	PRESENT	0
392944	391857	19413M	PARTICIPANT	\N	PRESENT	0
392945	391857	08024S	PARTICIPANT	\N	PRESENT	0
392946	391857	19685L	PARTICIPANT	\N	PRESENT	0
392947	391857	14157T	PARTICIPANT	\N	PRESENT	0
392997	378052	14169X	PARTICIPANT	\N	PRESENT	0
393005	378052	98029W	PARTICIPANT	\N	PRESENT	0
392999	378052	14097Y	PARTICIPANT	\N	PRESENT	0
393001	378052	19725B	PARTICIPANT	\N	PRESENT	0
393002	378052	19333N	PARTICIPANT	\N	PRESENT	0
393003	378052	14065Q	PARTICIPANT	\N	PRESENT	0
393004	378052	19347U	PARTICIPANT	\N	PRESENT	0
393006	378052	08024S	PARTICIPANT	\N	PRESENT	0
393044	378052	19768N	PARTICIPANT	\N	PRESENT	0
393011	378052	19301E	PARTICIPANT	\N	PRESENT	0
393012	378052	02002K	PARTICIPANT	\N	PRESENT	0
393014	378052	98022P	PARTICIPANT	\N	PRESENT	0
393015	378052	14267Y	PARTICIPANT	\N	PRESENT	0
393016	378052	14089Y	PARTICIPANT	\N	PRESENT	0
393017	378052	14327T	PARTICIPANT	\N	PRESENT	0
393018	378052	19737F	PARTICIPANT	\N	PRESENT	0
393021	378052	11012A	PARTICIPANT	\N	PRESENT	0
393023	378052	19387D	PARTICIPANT	\N	PRESENT	0
393025	378052	14121F	PARTICIPANT	\N	PRESENT	0
393026	378052	14107H	PARTICIPANT	\N	PRESENT	0
393027	378052	19253P	PARTICIPANT	\N	PRESENT	0
393029	378052	14179A	PARTICIPANT	\N	PRESENT	0
393032	378052	19637C	PARTICIPANT	\N	PRESENT	0
393035	378052	19685L	PARTICIPANT	\N	PRESENT	0
393037	378052	19701S	PARTICIPANT	\N	PRESENT	0
393040	378052	95030B	PARTICIPANT	\N	PRESENT	0
393083	378052	08044W	PARTICIPANT	\N	PRESENT	0
393042	378052	14026U	PARTICIPANT	\N	PRESENT	0
393043	378052	19729F	PARTICIPANT	\N	PRESENT	0
393045	378052	19507S	PARTICIPANT	\N	PRESENT	0
393046	378052	14157T	PARTICIPANT	\N	PRESENT	0
393047	378052	14031R	PARTICIPANT	\N	PRESENT	0
393048	378052	19794Q	PARTICIPANT	\N	PRESENT	0
393049	378052	19467C	PARTICIPANT	\N	PRESENT	0
393050	378052	14029X	PARTICIPANT	\N	PRESENT	0
393051	378052	19782L	PARTICIPANT	\N	PRESENT	0
393052	378052	14038Y	PARTICIPANT	\N	PRESENT	0
393053	378052	14219Q	PARTICIPANT	\N	PRESENT	0
393054	378052	19713W	PARTICIPANT	\N	PRESENT	0
393055	378052	08019V	PARTICIPANT	\N	PRESENT	0
393056	378052	19798U	PARTICIPANT	\N	PRESENT	0
393057	378052	14105F	PARTICIPANT	\N	PRESENT	0
393058	378052	19695N	PARTICIPANT	\N	PRESENT	0
393059	378052	08056B	PARTICIPANT	\N	PRESENT	0
393060	378052	04034C	PARTICIPANT	\N	PRESENT	0
393061	378052	08049C	PARTICIPANT	\N	PRESENT	0
393062	378052	14187A	PARTICIPANT	\N	PRESENT	0
392995	378052	14034U	PARTICIPANT	\N	PRESENT	0
392996	378052	08009T	PARTICIPANT	\N	PRESENT	0
393063	378052	19383Y	PARTICIPANT	\N	PRESENT	0
393064	378052	14147R	PARTICIPANT	\N	PRESENT	0
393065	378052	14030Q	PARTICIPANT	\N	PRESENT	0
393068	378052	19531S	PARTICIPANT	\N	PRESENT	0
393081	378052	97011G	PARTICIPANT	\N	PRESENT	0
393082	378052	19611R	PARTICIPANT	\N	PRESENT	0
393085	378052	11067R	PARTICIPANT	\N	PRESENT	0
393086	378052	95062K	PARTICIPANT	\N	PRESENT	0
393087	378052	11043H	PARTICIPANT	\N	PRESENT	0
393088	378052	14073Q	PARTICIPANT	\N	PRESENT	0
393564	393563	14038Y	PARTICIPANT	\N	PRESENT	0
393565	393563	19599P	PARTICIPANT	\N	PRESENT	0
393567	393563	11083R	PARTICIPANT	\N	PRESENT	0
393568	393563	14179A	PARTICIPANT	\N	PRESENT	0
393569	393563	01048V	PARTICIPANT	\N	PRESENT	0
393570	393563	14257W	PRESIDENT	0	PRESENT	0
393571	393563	19593H	PARTICIPANT	\N	PRESENT	0
393572	393563	19679N	PARTICIPANT	\N	PRESENT	0
393573	393563	08053X	PARTICIPANT	\N	PRESENT	0
393664	391472	19533U	PARTICIPANT	\N	PRESENT	0
393665	391472	04043D	PARTICIPANT	\N	PRESENT	0
393666	391472	19503N	PARTICIPANT	\N	PRESENT	0
395030	392412	19768N	PARTICIPANT	\N	PRESENT	0
395031	392412	19515S	PARTICIPANT	\N	PRESENT	0
395032	392412	19782L	PARTICIPANT	\N	PRESENT	0
395033	392412	14357A	PARTICIPANT	\N	PRESENT	0
395034	392412	19413M	PARTICIPANT	\N	PRESENT	0
395035	392412	80013X	PARTICIPANT	\N	PRESENT	0
395036	392412	19631V	PARTICIPANT	\N	PRESENT	0
395037	392412	08021P	PARTICIPANT	\N	PRESENT	0
395038	392412	11099A	PARTICIPANT	\N	PRESENT	0
395039	392412	04049K	PRESIDENT	0	PRESENT	0
395040	392412	19705W	PARTICIPANT	\N	PRESENT	0
393132	378053	11027H	PARTICIPANT	\N	PRESENT	0
393178	378053	05012A	PARTICIPANT	\N	PRESENT	0
395041	392412	08015R	PARTICIPANT	\N	PRESENT	0
395042	392412	08019V	PARTICIPANT	\N	PRESENT	0
395043	392412	14197C	PARTICIPANT	\N	PRESENT	0
395044	392412	19369B	PARTICIPANT	\N	PRESENT	0
395045	392412	19511N	PARTICIPANT	\N	PRESENT	0
395046	392412	08028W	PARTICIPANT	\N	PRESENT	0
395047	392412	19563B	PARTICIPANT	\N	PRESENT	0
395048	392412	14265W	PARTICIPANT	\N	PRESENT	0
395049	392412	19467C	PARTICIPANT	\N	PRESENT	0
395050	392412	14187A	PARTICIPANT	\N	PRESENT	0
395051	392412	08038Y	PARTICIPANT	\N	PRESENT	0
395052	392412	08062Y	PARTICIPANT	\N	PRESENT	0
395053	392412	19695N	PARTICIPANT	\N	PRESENT	0
395054	392412	01025N	PARTICIPANT	\N	PRESENT	0
395055	392412	19295A	PARTICIPANT	\N	PRESENT	0
395056	392412	14205J	PARTICIPANT	\N	PRESENT	0
395057	392412	04088S	PARTICIPANT	\N	PRESENT	0
395058	392412	19507S	PARTICIPANT	\N	PRESENT	0
395059	392412	19747H	PARTICIPANT	\N	PRESENT	0
395060	392412	19619A	PARTICIPANT	\N	PRESENT	0
395061	392412	14257W	PARTICIPANT	\N	PRESENT	0
395062	392412	14033T	PARTICIPANT	\N	PRESENT	0
395063	392412	08068F	PARTICIPANT	\N	EXCUSE	0
395064	392412	01043Q	PARTICIPANT	\N	EXCUSE	0
395065	392412	11081P	PARTICIPANT	\N	EXCUSE	0
395066	392412	17589D	PARTICIPANT	\N	EXCUSE	0
395067	392412	19591F	PARTICIPANT	\N	EXCUSE	0
395068	392615	14038Y	PARTICIPANT	\N	PRESENT	0
395069	392615	19383Y	PARTICIPANT	\N	PRESENT	0
395070	392615	14031R	PARTICIPANT	\N	PRESENT	0
395071	392615	19549D	PARTICIPANT	\N	PRESENT	0
395072	392615	14219Q	PARTICIPANT	\N	PRESENT	0
395073	392615	19599P	PARTICIPANT	\N	PRESENT	0
395074	392615	19637C	PARTICIPANT	\N	PRESENT	0
402813	393628	11099A	PARTICIPANT	\N	PRESENT	0
402849	393635	11090Q	PARTICIPANT	\N	PRESENT	0
402850	393635	11012A	PARTICIPANT	\N	PRESENT	0
402851	393635	14251Q	PARTICIPANT	\N	PRESENT	0
402852	393635	14030Q	PARTICIPANT	\N	PRESENT	0
402853	393635	14329V	PARTICIPANT	\N	PRESENT	0
402854	393635	14357A	PARTICIPANT	\N	PRESENT	0
402855	393635	07029T	PARTICIPANT	\N	PRESENT	0
402856	393635	19467C	PARTICIPANT	\N	PRESENT	0
402857	393635	04088S	PARTICIPANT	\N	PRESENT	0
402858	393635	11048N	PARTICIPANT	\N	PRESENT	0
402859	393635	19711U	PARTICIPANT	\N	PRESENT	0
402860	393635	14071N	PARTICIPANT	\N	PRESENT	0
402861	393635	19319Q	PARTICIPANT	\N	PRESENT	0
402862	393635	80013X	PARTICIPANT	\N	PRESENT	0
402863	393635	19503N	PARTICIPANT	\N	PRESENT	0
402864	393635	11065P	PARTICIPANT	\N	PRESENT	0
402865	393635	14083S	PARTICIPANT	\N	PRESENT	0
402866	393635	19269X	PARTICIPANT	\N	PRESENT	0
402867	393635	19695N	PARTICIPANT	\N	PRESENT	0
402868	393635	11077T	PARTICIPANT	\N	PRESENT	0
402869	393635	19687N	PARTICIPANT	\N	PRESENT	0
402870	393635	19733B	PARTICIPANT	\N	PRESENT	0
402871	393635	04043D	PARTICIPANT	\N	PRESENT	0
402872	393635	14033T	PARTICIPANT	\N	PRESENT	0
402873	393635	11099A	PARTICIPANT	\N	PRESENT	0
405451	405450	14083S	PARTICIPANT	\N	PRESENT	0
405452	405450	11053K	PRESIDENT	0	PRESENT	0
405453	405450	19253P	PARTICIPANT	\N	PRESENT	0
405454	405450	14357A	PARTICIPANT	\N	PRESENT	0
405455	405450	08045X	PARTICIPANT	\N	EXCUSE	0
405456	405450	15447F	PARTICIPANT	\N	PRESENT	0
405457	405450	19387D	PARTICIPANT	\N	PRESENT	0
405458	405450	04097T	PARTICIPANT	\N	PRESENT	0
402847	393635	04059M	PARTICIPANT	\N	PRESENT	0
402848	393635	19593H	PARTICIPANT	\N	PRESENT	0
405459	405450	19715Y	PARTICIPANT	\N	PRESENT	0
405460	405450	14031R	PARTICIPANT	\N	PRESENT	0
405461	405450	19671E	PARTICIPANT	\N	PRESENT	0
405462	405450	14237S	PARTICIPANT	\N	PRESENT	0
405463	405450	19735D	PARTICIPANT	\N	PRESENT	0
405464	405450	19349W	PARTICIPANT	\N	PRESENT	0
405465	405450	14225N	PARTICIPANT	\N	EXCUSE	0
405466	405450	19301E	PARTICIPANT	\N	PRESENT	0
407094	404871	19447X	PARTICIPANT	\N	EXCUSE	0
407095	402268	14237S	PARTICIPANT	\N	PRESENT	0
407096	402268	11103C	PARTICIPANT	\N	PRESENT	0
407097	402268	11067R	PARTICIPANT	\N	PRESENT	0
407098	402268	19575F	PARTICIPANT	\N	PRESENT	0
407099	402268	19693L	PARTICIPANT	\N	PRESENT	0
407100	402268	19685L	PARTICIPANT	\N	PRESENT	0
407101	402268	19762G	PARTICIPANT	\N	PRESENT	0
407103	402268	11090Q	PARTICIPANT	\N	PRESENT	0
407104	402268	11040E	PARTICIPANT	\N	PRESENT	0
407105	402268	14229S	PARTICIPANT	\N	PRESENT	0
407106	402268	11065P	PARTICIPANT	\N	PRESENT	0
407107	402268	14039A	PARTICIPANT	\N	PRESENT	0
407108	402268	08061X	PARTICIPANT	\N	PRESENT	0
407109	402268	19737F	PARTICIPANT	\N	PRESENT	0
407110	402268	14123H	PARTICIPANT	\N	PRESENT	0
407111	402268	08039A	PARTICIPANT	\N	PRESENT	0
407112	402268	14119M	PARTICIPANT	\N	PRESENT	0
407113	402268	04043D	PARTICIPANT	\N	PRESENT	0
407114	402268	19697Q	PARTICIPANT	\N	PRESENT	0
407115	402268	19683J	PARTICIPANT	\N	PRESENT	0
407116	402268	08010L	PARTICIPANT	\N	PRESENT	0
407117	402268	04045F	PARTICIPANT	\N	PRESENT	0
407118	402268	19749K	PARTICIPANT	\N	PRESENT	0
407119	402268	19533U	PARTICIPANT	\N	PRESENT	0
407120	402268	19599P	PARTICIPANT	\N	PRESENT	0
407121	402268	19583F	PARTICIPANT	\N	PRESENT	0
407122	402268	19695N	PARTICIPANT	\N	PRESENT	0
407123	402268	19747H	PARTICIPANT	\N	PRESENT	0
407124	402268	19467C	PARTICIPANT	\N	PRESENT	0
407125	402268	04049K	PARTICIPANT	\N	PRESENT	0
407127	402268	19691J	PARTICIPANT	\N	PRESENT	0
407132	402268	19301E	PARTICIPANT	\N	PRESENT	0
407133	402268	80013X	PARTICIPANT	\N	PRESENT	0
407134	402268	14073Q	PARTICIPANT	\N	PRESENT	0
407135	402268	19553Y	PARTICIPANT	\N	PRESENT	0
407136	402268	16685X	PARTICIPANT	\N	PRESENT	0
407137	402268	14026U	PARTICIPANT	\N	PRESENT	0
407138	402268	19733B	PARTICIPANT	\N	PRESENT	0
407139	402268	14107H	PARTICIPANT	\N	PRESENT	0
407140	402268	01034P	PARTICIPANT	\N	PRESENT	0
407141	404871	11049P	PARTICIPANT	\N	PRESENT	0
407142	404871	19762G	PARTICIPANT	\N	PRESENT	0
407148	402268	19295A	PARTICIPANT	\N	PRESENT	0
407149	402268	14042U	PARTICIPANT	\N	PRESENT	0
407150	402268	19531S	PARTICIPANT	\N	PRESENT	0
407152	402268	19689Q	PARTICIPANT	\N	PRESENT	0
407153	402268	19651A	PARTICIPANT	\N	PRESENT	0
407154	402268	19545Y	PARTICIPANT	\N	PRESENT	0
407155	402268	14033T	PARTICIPANT	\N	PRESENT	0
407156	402268	14265W	PARTICIPANT	\N	PRESENT	0
407157	402268	11056N	PARTICIPANT	\N	PRESENT	0
407158	402268	19619A	PARTICIPANT	\N	PRESENT	0
407159	402268	08015R	PARTICIPANT	\N	PRESENT	0
407160	402268	19643A	PARTICIPANT	\N	PRESENT	0
407161	402268	19758L	PARTICIPANT	\N	PRESENT	0
407162	402268	14093U	PARTICIPANT	\N	PRESENT	0
407166	402268	19629C	PARTICIPANT	\N	PRESENT	0
407176	402268	07033P	PARTICIPANT	\N	PRESENT	0
407177	402268	14197C	PARTICIPANT	\N	PRESENT	0
407178	402268	14069U	PARTICIPANT	\N	PRESENT	0
407180	402268	19621T	PARTICIPANT	\N	PRESENT	0
407182	402268	11012A	PARTICIPANT	\N	PRESENT	0
407183	402268	14207L	PARTICIPANT	\N	PRESENT	0
407190	404871	11010L	PARTICIPANT	\N	PRESENT	0
407191	402268	07029T	PARTICIPANT	\N	PRESENT	0
407192	402268	14147R	PARTICIPANT	\N	PRESENT	0
402809	393628	14021P	PARTICIPANT	\N	PRESENT	0
402810	393628	14071N	PARTICIPANT	\N	PRESENT	0
407193	402268	19768N	PARTICIPANT	\N	PRESENT	0
407194	402268	14021P	PARTICIPANT	\N	PRESENT	0
407198	407197	95067Q	PARTICIPANT	\N	PRESENT	0
407199	407197	19443T	PARTICIPANT	\N	PRESENT	0
407234	406928	14219Q	PARTICIPANT	\N	PRESENT	0
407235	406928	19551W	PARTICIPANT	\N	PRESENT	0
407236	406928	19794Q	PARTICIPANT	\N	PRESENT	0
407237	406928	19549D	PARTICIPANT	\N	PRESENT	0
407238	406928	14205J	PARTICIPANT	\N	PRESENT	0
407239	406928	19347U	PARTICIPANT	\N	PRESENT	0
407303	402269	14034U	PARTICIPANT	\N	PRESENT	0
407304	402269	08009T	PARTICIPANT	\N	PRESENT	0
407305	402269	19701S	PARTICIPANT	\N	PRESENT	0
407306	402269	08055A	PARTICIPANT	\N	PRESENT	0
407307	402269	19599P	PARTICIPANT	\N	PRESENT	0
407308	402269	19683J	PARTICIPANT	\N	PRESENT	0
407309	402269	19413M	PARTICIPANT	\N	PRESENT	0
407310	402269	19333N	PARTICIPANT	\N	PRESENT	0
407331	402269	14157T	PARTICIPANT	\N	PRESENT	0
407312	402269	19503N	PARTICIPANT	\N	PRESENT	0
407313	402269	19715Y	PARTICIPANT	\N	PRESENT	0
407314	402269	14073Q	PARTICIPANT	\N	PRESENT	0
407315	402269	19637C	PARTICIPANT	\N	PRESENT	0
407316	402269	07033P	PARTICIPANT	\N	PRESENT	0
407317	402269	11048N	PARTICIPANT	\N	PRESENT	0
407318	402269	19253P	PARTICIPANT	\N	PRESENT	0
407319	402269	19629C	PARTICIPANT	\N	PRESENT	0
407320	402269	14031R	PARTICIPANT	\N	PRESENT	0
407321	402269	08024S	PARTICIPANT	\N	PRESENT	0
407322	402269	19387D	PARTICIPANT	\N	PRESENT	0
407323	402269	19399H	PARTICIPANT	\N	PRESENT	0
407324	402269	19713W	PARTICIPANT	\N	PRESENT	0
407325	402269	14083S	PARTICIPANT	\N	PRESENT	0
407326	402269	07029T	PARTICIPANT	\N	PRESENT	0
407327	402269	19737F	PARTICIPANT	\N	PRESENT	0
407328	402269	19747H	PARTICIPANT	\N	PRESENT	0
407329	402269	14038Y	PARTICIPANT	\N	PRESENT	0
407330	402269	19794Q	PARTICIPANT	\N	PRESENT	0
407332	402269	19575F	PARTICIPANT	\N	PRESENT	0
407333	402269	19549D	PARTICIPANT	\N	PRESENT	0
407342	402269	11033F	PARTICIPANT	\N	PRESENT	0
407335	402269	19301E	PARTICIPANT	\N	PRESENT	0
407336	402269	14169X	PARTICIPANT	\N	PRESENT	0
407337	402269	11067R	PARTICIPANT	\N	PRESENT	0
407338	402269	19347U	PARTICIPANT	\N	PRESENT	0
407339	402269	19563B	PARTICIPANT	\N	PRESENT	0
407340	402269	19269X	PARTICIPANT	\N	PRESENT	0
407341	402269	14069U	PARTICIPANT	\N	PRESENT	0
407343	402269	19758L	PARTICIPANT	\N	PRESENT	0
407344	402269	14197C	PARTICIPANT	\N	PRESENT	0
407345	402269	19553Y	PARTICIPANT	\N	PRESENT	0
407349	402269	19695N	PARTICIPANT	\N	PRESENT	0
407347	402269	19739H	PARTICIPANT	\N	PRESENT	0
407348	402269	11056N	PARTICIPANT	\N	PRESENT	0
407350	402269	12016W	PARTICIPANT	\N	PRESENT	0
407351	402269	19621T	PARTICIPANT	\N	PRESENT	0
397189	396520	04070G	PRESIDENT	0	PRESENT	0
397190	396520	19699S	PARTICIPANT	\N	PRESENT	0
397191	396520	19533U	PARTICIPANT	\N	PRESENT	0
397192	396520	14229S	PARTICIPANT	\N	PRESENT	0
397193	396520	14241N	PARTICIPANT	\N	PRESENT	0
397194	396520	19573D	PARTICIPANT	\N	PRESENT	0
397195	396520	14039A	PARTICIPANT	\N	PRESENT	0
397196	396520	14107H	PARTICIPANT	\N	PRESENT	0
397197	396520	92040Q	PARTICIPANT	\N	PRESENT	0
397198	396520	07033P	PARTICIPANT	\N	PRESENT	0
397199	396520	08012N	PARTICIPANT	\N	PRESENT	0
397200	396520	19335Q	PARTICIPANT	\N	PRESENT	0
397201	396520	14249W	PARTICIPANT	\N	PRESENT	0
397202	396520	08039A	PARTICIPANT	\N	PRESENT	0
397203	396520	08031R	PARTICIPANT	\N	PRESENT	0
397204	396520	19593H	PARTICIPANT	\N	PRESENT	0
397230	396435	14331P	PARTICIPANT	\N	PRESENT	0
397206	396520	14061L	PARTICIPANT	\N	PRESENT	0
397207	396520	04057K	PARTICIPANT	\N	PRESENT	0
397208	396520	14073Q	PARTICIPANT	\N	PRESENT	0
397209	396520	19611R	PARTICIPANT	\N	PRESENT	0
397210	396520	08020N	PARTICIPANT	\N	PRESENT	0
397211	396520	14251Q	PARTICIPANT	\N	PRESENT	0
397212	396520	04059M	PARTICIPANT	\N	PRESENT	0
397213	396520	19735D	PARTICIPANT	\N	PRESENT	0
397214	396520	14063N	PARTICIPANT	\N	PRESENT	0
397215	396520	11083R	PARTICIPANT	\N	PRESENT	0
397216	396520	14109K	PARTICIPANT	\N	PRESENT	0
397217	396520	14123H	PARTICIPANT	\N	PRESENT	0
397218	396520	11104D	PARTICIPANT	\N	PRESENT	0
397219	396520	19621T	PARTICIPANT	\N	PRESENT	0
397220	396520	19766L	PARTICIPANT	\N	EXCUSE	0
397221	396520	19693L	PARTICIPANT	\N	EXCUSE	0
397222	396520	87003B	PARTICIPANT	\N	EXCUSE	0
397224	396050	14255U	PARTICIPANT	\N	PRESENT	0
397225	396311	19647E	PARTICIPANT	\N	PRESENT	0
397226	396311	08034U	PARTICIPANT	\N	PRESENT	0
397227	396311	19651A	PARTICIPANT	\N	PRESENT	0
397228	396311	14034U	PARTICIPANT	\N	PRESENT	0
397229	396311	95041E	PARTICIPANT	\N	EXCUSE	0
397231	396435	01048V	PARTICIPANT	\N	PRESENT	0
397232	396435	19545Y	PARTICIPANT	\N	PRESENT	0
397233	396435	11074Q	PRESIDENT	0	PRESENT	0
397234	396435	89017R	PARTICIPANT	\N	PRESENT	0
397235	396435	14225N	PARTICIPANT	\N	PRESENT	0
397236	396435	88008L	PARTICIPANT	\N	PRESENT	0
397237	396435	07029T	PARTICIPANT	\N	PRESENT	0
397238	396435	14277B	PARTICIPANT	\N	PRESENT	0
397239	396435	07004J	PARTICIPANT	\N	PRESENT	0
397240	396435	96004D	PARTICIPANT	\N	PRESENT	0
397241	396435	08010L	PARTICIPANT	\N	PRESENT	0
397242	396435	14253S	PARTICIPANT	\N	PRESENT	0
397243	396435	19479G	PARTICIPANT	\N	PRESENT	0
397244	396435	11048N	PARTICIPANT	\N	PRESENT	0
397245	396435	19647E	PARTICIPANT	\N	PRESENT	0
397246	396435	19711U	PARTICIPANT	\N	PRESENT	0
397247	396435	19531S	PARTICIPANT	\N	PRESENT	0
397248	396435	08034U	PARTICIPANT	\N	PRESENT	0
397249	396435	19651A	PARTICIPANT	\N	PRESENT	0
397250	396435	08069G	PARTICIPANT	\N	PRESENT	0
397251	396435	08011M	PARTICIPANT	\N	PRESENT	0
397252	396435	14034U	PARTICIPANT	\N	PRESENT	0
397253	396435	11040E	PARTICIPANT	\N	PRESENT	0
397254	396435	14083S	PARTICIPANT	\N	PRESENT	0
397255	396435	14199E	PARTICIPANT	\N	PRESENT	0
397256	396435	19741B	PARTICIPANT	\N	PRESENT	0
397257	396435	99004R	PARTICIPANT	\N	PRESENT	0
397258	396435	19687N	PARTICIPANT	\N	PRESENT	0
397259	396435	11053K	PARTICIPANT	\N	PRESENT	0
397260	396435	19349W	PARTICIPANT	\N	PRESENT	0
397261	396435	19671E	PARTICIPANT	\N	PRESENT	0
397262	396435	14159V	PARTICIPANT	\N	PRESENT	0
397263	396435	11070L	PARTICIPANT	\N	PRESENT	0
397264	396435	95041E	PARTICIPANT	\N	EXCUSE	0
397267	393394	11027H	PARTICIPANT	\N	PRESENT	0
397268	395159	11067R	PARTICIPANT	\N	PRESENT	0
397269	395159	19569H	PARTICIPANT	\N	PRESENT	0
397270	395159	04045F	PARTICIPANT	\N	PRESENT	0
397271	395159	14087W	PARTICIPANT	\N	PRESENT	0
397272	395159	10006L	PARTICIPANT	\N	PRESENT	0
397273	395159	19521Q	PARTICIPANT	\N	PRESENT	0
397274	395159	19527W	PARTICIPANT	\N	PRESENT	0
397275	395159	01034P	PARTICIPANT	\N	PRESENT	0
397276	395159	19691J	PARTICIPANT	\N	PRESENT	0
397277	395159	19715Y	PARTICIPANT	\N	PRESENT	0
397278	395159	14071N	PARTICIPANT	\N	PRESENT	0
397279	395159	19760E	PARTICIPANT	\N	PRESENT	0
397280	396518	19441R	PARTICIPANT	\N	PRESENT	0
397281	396518	11099A	PARTICIPANT	\N	PRESENT	0
397282	396518	04049K	PARTICIPANT	\N	PRESENT	0
397283	396518	08038Y	PARTICIPANT	\N	PRESENT	0
397289	393394	12041X	PARTICIPANT	\N	PRESENT	0
397290	393394	14239U	PARTICIPANT	\N	PRESENT	0
397291	393394	14073Q	PARTICIPANT	\N	PRESENT	0
397292	393394	19798U	PARTICIPANT	\N	PRESENT	0
397293	393394	19415P	PARTICIPANT	\N	PRESENT	0
397294	393394	14211G	PARTICIPANT	\N	PRESENT	0
397295	393394	14267Y	PARTICIPANT	\N	PRESENT	0
397296	393394	98018T	PARTICIPANT	\N	PRESENT	0
397298	393394	99004R	PARTICIPANT	\N	PRESENT	0
397299	393394	19507S	PARTICIPANT	\N	PRESENT	0
397300	393394	14079W	PARTICIPANT	\N	PRESENT	0
397301	393394	08058D	PARTICIPANT	\N	PRESENT	0
397302	393394	19758L	PARTICIPANT	\N	PRESENT	0
397303	393394	19725B	PARTICIPANT	\N	PRESENT	0
397304	393394	19421M	PARTICIPANT	\N	PRESENT	0
397814	396239	08052W	PARTICIPANT	\N	PRESENT	0
397815	396239	19565D	PARTICIPANT	\N	PRESENT	0
397817	396239	11067R	PARTICIPANT	\N	PRESENT	0
397818	396239	14331P	PARTICIPANT	\N	PRESENT	0
400890	400889	19651A	PARTICIPANT	\N	PRESENT	0
400891	400889	19741B	PARTICIPANT	\N	PRESENT	0
400905	400889	08011M	PARTICIPANT	\N	PRESENT	0
400893	400889	14083S	PARTICIPANT	\N	PRESENT	0
400894	400889	14085U	PARTICIPANT	\N	PRESENT	0
400895	400889	11070L	PARTICIPANT	\N	PRESENT	0
400896	400889	11074Q	PRESIDENT	0	PRESENT	0
400897	400889	14121F	PARTICIPANT	\N	PRESENT	0
400898	400889	99004R	PARTICIPANT	\N	PRESENT	0
401160	401159	19701S	PARTICIPANT	\N	PRESENT	0
401162	401161	14030Q	PARTICIPANT	\N	PRESENT	0
401163	401161	14105F	PARTICIPANT	\N	PRESENT	0
401164	401161	14083S	PARTICIPANT	\N	PRESENT	0
401165	401161	14087W	PARTICIPANT	\N	PRESENT	0
401166	401161	19521Q	PARTICIPANT	\N	PRESENT	0
401167	401161	14026U	PARTICIPANT	\N	PRESENT	0
401168	401161	04049K	PRESIDENT	0	PRESENT	0
401169	401161	16685X	PARTICIPANT	\N	PRESENT	0
401170	401161	19671E	PARTICIPANT	\N	PRESENT	0
401171	401161	08047A	PARTICIPANT	\N	PRESENT	0
401172	401161	14157T	PARTICIPANT	\N	PRESENT	0
401309	401307	11053K	PRESIDENT	0	PRESENT	0
401310	401307	19253P	PARTICIPANT	\N	PRESENT	0
401311	401307	14083S	PARTICIPANT	\N	PRESENT	0
401317	401307	14237S	PARTICIPANT	\N	PRESENT	0
401314	401307	19387D	PARTICIPANT	\N	PRESENT	0
401315	401307	19729F	PARTICIPANT	\N	PRESENT	0
401316	401307	14031R	PARTICIPANT	\N	PRESENT	0
401837	398618	14135M	PARTICIPANT	\N	PRESENT	0
403026	403014	04033B	PARTICIPANT	\N	PRESENT	0
407798	407791	14173T	PARTICIPANT	\N	PRESENT	0
417483	414062	14281W	PRESIDENT	0	PRESENT	0
417484	414062	14031R	PARTICIPANT	\N	PRESENT	0
417500	417481	14191V	PARTICIPANT	\N	PRESENT	0
417501	417481	19511N	PARTICIPANT	\N	PRESENT	0
417502	414062	17583W	PARTICIPANT	\N	PRESENT	0
417503	417481	19699S	PARTICIPANT	\N	PRESENT	0
417504	417481	14201E	PARTICIPANT	\N	PRESENT	0
417505	417481	19563B	PARTICIPANT	\N	PRESENT	0
417506	417481	12041X	PARTICIPANT	\N	PRESENT	0
417507	417481	11056N	PARTICIPANT	\N	PRESENT	0
417508	417481	19593H	PARTICIPANT	\N	PRESENT	0
417509	417481	14159V	PARTICIPANT	\N	PRESENT	0
417510	417481	08049C	PARTICIPANT	\N	PRESENT	0
417511	417481	14063N	PARTICIPANT	\N	PRESENT	0
417512	417481	19619A	PARTICIPANT	\N	PRESENT	0
417513	417481	14039A	PARTICIPANT	\N	PRESENT	0
417514	417481	19503N	PARTICIPANT	\N	PRESENT	0
417515	417481	14028W	PARTICIPANT	\N	PRESENT	0
417516	417481	19782L	PARTICIPANT	\N	PRESENT	0
417517	417481	14267Y	PARTICIPANT	\N	PRESENT	0
417518	417481	14255U	PARTICIPANT	\N	PRESENT	0
417519	417481	14235Q	PARTICIPANT	\N	PRESENT	0
417520	417481	19695N	PARTICIPANT	\N	PRESENT	0
417521	417481	19735D	PARTICIPANT	\N	PRESENT	0
417522	417481	14221J	PARTICIPANT	\N	PRESENT	0
417524	417481	19335Q	PARTICIPANT	\N	PRESENT	0
417525	417481	14277B	PARTICIPANT	\N	PRESENT	0
417526	417481	19826F	PARTICIPANT	\N	PRESENT	0
403688	400170	11097X	PARTICIPANT	\N	PRESENT	0
403689	400170	19421M	PARTICIPANT	\N	PRESENT	0
403690	400170	11070L	PARTICIPANT	\N	PRESENT	0
403691	400170	04086Q	PARTICIPANT	\N	PRESENT	0
403692	400170	14255U	PARTICIPANT	\N	PRESENT	0
403693	400170	11045K	PARTICIPANT	\N	PRESENT	0
403694	400170	95041E	PARTICIPANT	\N	PRESENT	0
403695	400170	11085T	PARTICIPANT	\N	PRESENT	0
403696	400170	04070G	PARTICIPANT	\N	PRESENT	0
403697	400170	04047H	PARTICIPANT	\N	PRESENT	0
403698	400170	14026U	PARTICIPANT	\N	PRESENT	0
403699	400170	11101A	PARTICIPANT	\N	PRESENT	0
403700	400170	01024M	PARTICIPANT	\N	PRESENT	0
403701	400170	98024R	PARTICIPANT	\N	PRESENT	0
403702	400170	14237S	PARTICIPANT	\N	PRESENT	0
403703	400170	19671E	PARTICIPANT	\N	PRESENT	0
403704	400170	19687N	PARTICIPANT	\N	PRESENT	0
403705	400170	14083S	PARTICIPANT	\N	PRESENT	0
403706	400170	01062T	PARTICIPANT	\N	PRESENT	0
403707	400170	14213J	PARTICIPANT	\N	PRESENT	0
403708	400170	08039A	PARTICIPANT	\N	PRESENT	0
403709	400170	19399H	PARTICIPANT	\N	PRESENT	0
403710	400170	19347U	PARTICIPANT	\N	PRESENT	0
403711	400170	19647E	PARTICIPANT	\N	PRESENT	0
403712	400170	08058D	PARTICIPANT	\N	PRESENT	0
403713	400170	08056B	PARTICIPANT	\N	PRESENT	0
403714	400170	08011M	PARTICIPANT	\N	PRESENT	0
403715	400170	14093U	PARTICIPANT	\N	PRESENT	0
403716	400170	14265W	PARTICIPANT	\N	PRESENT	0
403717	400170	02002K	PARTICIPANT	\N	PRESENT	0
403718	400170	14033T	PARTICIPANT	\N	PRESENT	0
403719	400170	11048N	PARTICIPANT	\N	PRESENT	0
403720	400170	14119M	PARTICIPANT	\N	PRESENT	0
403721	400170	14135M	PARTICIPANT	\N	PRESENT	0
403722	400170	08034U	PARTICIPANT	\N	PRESENT	0
403723	400170	92040Q	PARTICIPANT	\N	PRESENT	0
403724	400170	11053K	PARTICIPANT	\N	PRESENT	0
403725	400170	04071H	PARTICIPANT	\N	PRESENT	0
403726	400170	11031D	PARTICIPANT	\N	PRESENT	0
403727	400170	11065P	PARTICIPANT	\N	PRESENT	0
403728	400170	19335Q	PARTICIPANT	\N	PRESENT	0
403729	400170	19723Y	PARTICIPANT	\N	PRESENT	0
403934	403730	04044E	PARTICIPANT	\N	PRESENT	0
403935	403730	19349W	PARTICIPANT	\N	PRESENT	0
403936	403730	14239U	PARTICIPANT	\N	PRESENT	0
403937	403730	08052W	PARTICIPANT	\N	PRESENT	0
403938	403730	19585H	PARTICIPANT	\N	PRESENT	0
403939	403730	19651A	PARTICIPANT	\N	PRESENT	0
403940	403730	14034U	PARTICIPANT	\N	PRESENT	0
403941	403730	10015M	PARTICIPANT	\N	PRESENT	0
403942	403730	19441R	PARTICIPANT	\N	PRESENT	0
403943	403730	19479G	PARTICIPANT	\N	PRESENT	0
403944	403730	11043H	PARTICIPANT	\N	PRESENT	0
403945	403730	04057K	PARTICIPANT	\N	PRESENT	0
403946	403730	95030B	PARTICIPANT	\N	PRESENT	0
403947	403730	19782L	PARTICIPANT	\N	PRESENT	0
403948	403730	07029T	PARTICIPANT	\N	PRESENT	0
403949	403730	14065Q	PARTICIPANT	\N	PRESENT	0
403950	403730	14173T	PARTICIPANT	\N	PRESENT	0
403951	403730	05008E	PARTICIPANT	\N	PRESENT	0
403952	403730	14069U	PARTICIPANT	\N	PRESENT	0
403953	403730	14053L	PARTICIPANT	\N	PRESENT	0
403954	403730	11049P	PARTICIPANT	\N	PRESENT	0
403955	403730	01024M	PARTICIPANT	\N	PRESENT	0
403956	403730	14215L	PARTICIPANT	\N	PRESENT	0
403957	403730	19711U	PARTICIPANT	\N	PRESENT	0
403958	403730	14147R	PARTICIPANT	\N	PRESENT	0
403959	403730	19762G	PARTICIPANT	\N	PRESENT	0
403960	403730	14073Q	PARTICIPANT	\N	PRESENT	0
403961	403730	14061L	PARTICIPANT	\N	PRESENT	0
403962	403730	19533U	PARTICIPANT	\N	PRESENT	0
403963	403730	19741B	PARTICIPANT	\N	PRESENT	0
403964	403730	08017T	PARTICIPANT	\N	PRESENT	0
403965	403730	19399H	PARTICIPANT	\N	PRESENT	0
403966	403730	19629C	PARTICIPANT	\N	PRESENT	0
403967	403730	19693L	PARTICIPANT	\N	PRESENT	0
403968	403730	11012A	PARTICIPANT	\N	PRESENT	0
403969	403730	19583F	PARTICIPANT	\N	PRESENT	0
403970	403730	04043D	PARTICIPANT	\N	PRESENT	0
403971	403730	14079W	PARTICIPANT	\N	PRESENT	0
403972	403730	14041T	PARTICIPANT	\N	PRESENT	0
403973	403730	19335Q	PARTICIPANT	\N	PRESENT	0
403974	403730	14213J	PARTICIPANT	\N	PRESENT	0
403975	403730	19703U	PARTICIPANT	\N	PRESENT	0
403976	403730	19467C	PARTICIPANT	\N	PRESENT	0
403977	403730	04070G	PARTICIPANT	\N	PRESENT	0
403978	403730	19747H	PARTICIPANT	\N	PRESENT	0
403979	403730	19563B	PARTICIPANT	\N	PRESENT	0
403980	403730	19553Y	PARTICIPANT	\N	PRESENT	0
403981	403730	14151M	PARTICIPANT	\N	PRESENT	0
403982	403730	19687N	PARTICIPANT	\N	PRESENT	0
403983	403730	19760E	PARTICIPANT	\N	PRESENT	0
403984	403730	19593H	PARTICIPANT	\N	PRESENT	0
403985	403730	19251M	PARTICIPANT	\N	PRESENT	0
404039	402258	14179A	PARTICIPANT	\N	PRESENT	0
404040	402258	19687N	PARTICIPANT	\N	PRESENT	0
404041	402258	19760E	PARTICIPANT	\N	PRESENT	0
404042	402258	14151M	PARTICIPANT	\N	PRESENT	0
404043	402258	19251M	PARTICIPANT	\N	PRESENT	0
404044	402258	14065Q	PARTICIPANT	\N	PRESENT	0
404045	402258	08052W	PARTICIPANT	\N	PRESENT	0
404046	402258	19651A	PARTICIPANT	\N	PRESENT	0
404047	402258	19349W	PARTICIPANT	\N	PRESENT	0
404048	402258	19585H	PARTICIPANT	\N	PRESENT	0
404049	402258	19583F	PARTICIPANT	\N	PRESENT	0
404050	402258	19479G	PARTICIPANT	\N	PRESENT	0
404051	402258	14073Q	PARTICIPANT	\N	PRESENT	0
404052	402258	04070G	PARTICIPANT	\N	PRESENT	0
404053	402258	19747H	PARTICIPANT	\N	PRESENT	0
404054	402258	14079W	PARTICIPANT	\N	PRESENT	0
404055	402258	01024M	PARTICIPANT	\N	PRESENT	0
404056	402258	14053L	PARTICIPANT	\N	PRESENT	0
404057	402258	01057W	PARTICIPANT	\N	PRESENT	0
404058	402258	04043D	PARTICIPANT	\N	PRESENT	0
404059	402258	19703U	PARTICIPANT	\N	PRESENT	0
404060	402258	19711U	PARTICIPANT	\N	PRESENT	0
404061	402258	19533U	PARTICIPANT	\N	PRESENT	0
404062	402258	19693L	PARTICIPANT	\N	PRESENT	0
404063	402258	19762G	PARTICIPANT	\N	PRESENT	0
404064	402258	07029T	PARTICIPANT	\N	PRESENT	0
404065	402258	14061L	PARTICIPANT	\N	PRESENT	0
404066	402258	14041T	PARTICIPANT	\N	PRESENT	0
404067	402258	11103C	PARTICIPANT	\N	PRESENT	0
404068	402258	19399H	PARTICIPANT	\N	PRESENT	0
404069	402258	14213J	PARTICIPANT	\N	PRESENT	0
404070	402258	14147R	PARTICIPANT	\N	PRESENT	0
404071	402258	11049P	PARTICIPANT	\N	PRESENT	0
404072	402258	11043H	PARTICIPANT	\N	PRESENT	0
404073	402258	10015M	PARTICIPANT	\N	PRESENT	0
404074	402258	01058X	PARTICIPANT	\N	PRESENT	0
404075	402258	08069G	PARTICIPANT	\N	PRESENT	0
404076	402258	19467C	PARTICIPANT	\N	PRESENT	0
404077	402258	01062T	PARTICIPANT	\N	PRESENT	0
404078	402258	19741B	PARTICIPANT	\N	PRESENT	0
404079	402258	08015R	PARTICIPANT	\N	PRESENT	0
404080	402258	19794Q	PARTICIPANT	\N	PRESENT	0
404081	402258	19719D	PARTICIPANT	\N	PRESENT	0
404082	402258	14173T	PARTICIPANT	\N	PRESENT	0
404083	402258	14357A	PARTICIPANT	\N	PRESENT	0
404084	402258	19543W	PARTICIPANT	\N	PRESENT	0
404085	402258	14265W	PARTICIPANT	\N	PRESENT	0
404086	402258	19727D	PARTICIPANT	\N	PRESENT	0
404087	402258	19758L	PARTICIPANT	\N	PRESENT	0
404088	402258	14026U	PARTICIPANT	\N	PRESENT	0
404089	402258	14217N	PARTICIPANT	\N	PRESENT	0
404037	402258	04044E	PARTICIPANT	\N	PRESENT	0
404038	402258	05008E	PARTICIPANT	\N	PRESENT	0
404090	402258	14215L	PARTICIPANT	\N	PRESENT	0
404091	402258	14231L	PARTICIPANT	\N	PRESENT	0
404092	402258	19593H	PARTICIPANT	\N	PRESENT	0
404093	402258	01028R	PARTICIPANT	\N	PRESENT	0
404094	402258	08014Q	PARTICIPANT	\N	PRESENT	0
404095	402258	19531S	PARTICIPANT	\N	PRESENT	0
404096	402258	11070L	PARTICIPANT	\N	PRESENT	0
404097	402258	14083S	PARTICIPANT	\N	PRESENT	0
404098	402258	17583W	PARTICIPANT	\N	PRESENT	0
404099	402258	14219Q	PARTICIPANT	\N	PRESENT	0
404100	402258	19782L	PARTICIPANT	\N	PRESENT	0
404101	402258	08034U	PARTICIPANT	\N	PRESENT	0
395075	392615	18083K	PARTICIPANT	\N	PRESENT	0
395076	392615	14051J	PARTICIPANT	\N	PRESENT	0
395077	392615	08060W	PARTICIPANT	\N	PRESENT	0
395078	392615	08009T	PRESIDENT	0	PRESENT	0
395079	392615	19739H	PARTICIPANT	\N	PRESENT	0
395080	392615	14157T	PARTICIPANT	\N	PRESENT	0
395081	392615	08024S	PARTICIPANT	\N	PRESENT	0
395082	392615	19525U	PARTICIPANT	\N	PRESENT	0
395083	391635	04092N	PRESIDENT	0	PRESENT	0
395084	391635	19569H	PARTICIPANT	\N	PRESENT	0
395085	391635	19798U	PARTICIPANT	\N	PRESENT	0
395086	391635	08052W	PARTICIPANT	\N	PRESENT	0
395087	391635	14223L	PARTICIPANT	\N	PRESENT	0
395088	391635	17779H	PARTICIPANT	\N	PRESENT	0
395089	391635	14119M	PARTICIPANT	\N	PRESENT	0
395090	391635	14087W	PARTICIPANT	\N	PRESENT	0
395091	391635	11103C	PARTICIPANT	\N	PRESENT	0
395092	391635	19679N	PARTICIPANT	\N	PRESENT	0
395093	391635	14195A	PARTICIPANT	\N	PRESENT	0
395094	391635	19367Y	PARTICIPANT	\N	PRESENT	0
395095	391635	14213J	PARTICIPANT	\N	PRESENT	0
395096	391635	14261S	PARTICIPANT	\N	PRESENT	0
395097	391635	14217N	PARTICIPANT	\N	PRESENT	0
395098	391635	98024R	PARTICIPANT	\N	PRESENT	0
395099	391635	11067R	PARTICIPANT	\N	EXCUSE	0
395100	391635	14355X	PARTICIPANT	\N	EXCUSE	0
395101	391635	08041T	PARTICIPANT	\N	EXCUSE	0
395139	392615	19681G	PARTICIPANT	\N	PRESENT	0
395140	392615	19713W	PARTICIPANT	\N	PRESENT	0
395141	392615	04085P	PARTICIPANT	\N	PRESENT	0
395142	392615	19733B	PARTICIPANT	\N	PRESENT	0
395143	392615	19745F	PARTICIPANT	\N	PRESENT	0
395144	391635	19565D	PARTICIPANT	\N	PRESENT	0
395145	391635	11097X	PARTICIPANT	0	PRESENT	0
395146	391635	19415P	PARTICIPANT	\N	PRESENT	0
395147	391635	04045F	PARTICIPANT	\N	PRESENT	0
395148	391635	14026U	PARTICIPANT	\N	PRESENT	0
395149	391635	14227Q	PARTICIPANT	\N	PRESENT	0
395150	391635	19703U	PARTICIPANT	\N	PRESENT	0
395151	391635	11031D	PARTICIPANT	\N	PRESENT	0
395152	391635	14281W	PARTICIPANT	\N	PRESENT	0
395153	391635	19521Q	PARTICIPANT	\N	PRESENT	0
395154	391635	19527W	PARTICIPANT	\N	PRESENT	0
395155	391635	19691J	PARTICIPANT	\N	PRESENT	0
395161	392615	05012A	PARTICIPANT	\N	PRESENT	0
395162	392615	08055A	PARTICIPANT	\N	PRESENT	0
395163	393757	19479G	PARTICIPANT	\N	PRESENT	0
395164	393757	19711U	PARTICIPANT	\N	PRESENT	0
395165	393757	19651A	PARTICIPANT	\N	PRESENT	0
395166	393757	08034U	PARTICIPANT	\N	PRESENT	0
395167	393757	08069G	PARTICIPANT	\N	PRESENT	0
395168	393757	01057W	PARTICIPANT	\N	PRESENT	0
395169	393757	19667J	PARTICIPANT	\N	PRESENT	0
395170	393757	89017R	PARTICIPANT	\N	PRESENT	0
395171	393757	11074Q	PRESIDENT	0	PRESENT	0
395172	393757	08014Q	PARTICIPANT	\N	PRESENT	0
395173	393757	14159V	PARTICIPANT	\N	PRESENT	0
395174	393757	19671E	PARTICIPANT	\N	PRESENT	0
395175	393757	14225N	PARTICIPANT	\N	PRESENT	0
395176	393757	14173T	PARTICIPANT	\N	PRESENT	0
395177	393757	04086Q	PARTICIPANT	\N	PRESENT	0
395178	393757	11040E	PARTICIPANT	\N	PRESENT	0
395179	393757	07029T	PARTICIPANT	\N	PRESENT	0
395180	393757	11012A	PARTICIPANT	\N	PRESENT	0
395181	393757	14085U	PARTICIPANT	\N	PRESENT	0
395182	393757	19349W	PARTICIPANT	\N	PRESENT	0
395183	393757	14121F	PARTICIPANT	\N	PRESENT	0
395184	393757	99004R	PARTICIPANT	\N	PRESENT	0
395185	393757	08010L	PARTICIPANT	\N	PRESENT	0
395189	391635	19575F	PARTICIPANT	\N	PRESENT	0
395190	393757	11048N	PARTICIPANT	\N	PRESENT	0
395191	393757	19741B	PARTICIPANT	\N	PRESENT	0
395192	392615	19685L	PARTICIPANT	\N	PRESENT	0
395193	393757	11053K	PARTICIPANT	\N	PRESENT	0
395194	393757	08011M	PARTICIPANT	\N	PRESENT	0
395195	392412	14135M	PARTICIPANT	\N	PRESENT	0
395196	392412	04043D	PARTICIPANT	\N	PRESENT	0
395197	392412	14081Q	PARTICIPANT	\N	PRESENT	0
395198	392412	14115H	PARTICIPANT	\N	PRESENT	0
395199	392412	19269X	PARTICIPANT	\N	PRESENT	0
395200	393757	14034U	PARTICIPANT	\N	PRESENT	0
395201	393757	14083S	PARTICIPANT	\N	PRESENT	0
395203	395029	19766L	PARTICIPANT	\N	PRESENT	0
395204	395029	04070G	PRESIDENT	0	PRESENT	0
395205	395029	19699S	PARTICIPANT	\N	PRESENT	0
395206	395029	19533U	PARTICIPANT	\N	PRESENT	0
395207	395029	19329S	PARTICIPANT	\N	PRESENT	0
395208	395029	04033B	PARTICIPANT	\N	PRESENT	0
395209	395029	14229S	PARTICIPANT	\N	PRESENT	0
395210	395029	19447X	PARTICIPANT	\N	PRESENT	0
395211	395029	14241N	PARTICIPANT	\N	PRESENT	0
395212	395029	19573D	PARTICIPANT	\N	PRESENT	0
395213	395029	08017T	PARTICIPANT	\N	EXCUSE	0
395214	395029	92040Q	PARTICIPANT	\N	PRESENT	0
395215	395029	07033P	PARTICIPANT	\N	PRESENT	0
395216	395029	08012N	PARTICIPANT	\N	PRESENT	0
395217	395029	19335Q	PARTICIPANT	\N	PRESENT	0
395218	395029	08039A	PARTICIPANT	\N	PRESENT	0
395219	395029	08031R	PARTICIPANT	\N	PRESENT	0
395220	395029	19593H	PARTICIPANT	\N	PRESENT	0
395221	395029	14059S	PARTICIPANT	\N	PRESENT	0
395222	395029	14061L	PARTICIPANT	\N	PRESENT	0
395223	395029	04057K	PARTICIPANT	\N	PRESENT	0
395224	395029	14073Q	PARTICIPANT	\N	PRESENT	0
395225	395029	08035V	PARTICIPANT	\N	PRESENT	0
395226	395029	19611R	PARTICIPANT	\N	PRESENT	0
395227	395029	08043V	PARTICIPANT	\N	EXCUSE	0
395228	395029	19693L	PARTICIPANT	\N	PRESENT	0
395229	395029	19399H	PARTICIPANT	\N	PRESENT	0
395230	395029	87003B	PARTICIPANT	\N	PRESENT	0
395231	395029	14030Q	PARTICIPANT	\N	PRESENT	0
395232	395029	19731Y	PARTICIPANT	\N	PRESENT	0
395233	395029	14251Q	PARTICIPANT	\N	PRESENT	0
395234	395029	08020N	PARTICIPANT	\N	PRESENT	0
395235	395029	19735D	PARTICIPANT	\N	PRESENT	0
395236	395029	11109J	PARTICIPANT	\N	PRESENT	0
395237	395029	14063N	PARTICIPANT	\N	PRESENT	0
395238	395029	14109K	PARTICIPANT	\N	PRESENT	0
395239	395029	11104D	PARTICIPANT	\N	PRESENT	0
395240	395029	19749K	PARTICIPANT	\N	PRESENT	0
395241	395029	19758L	PARTICIPANT	\N	PRESENT	0
395242	395029	14039A	PARTICIPANT	\N	EXCUSE	0
395243	395029	14107H	PARTICIPANT	\N	EXCUSE	0
395244	395029	11083R	PARTICIPANT	\N	EXCUSE	0
395245	395029	11043H	PARTICIPANT	\N	EXCUSE	0
395246	395029	14249W	PARTICIPANT	\N	EXCUSE	0
395247	393757	88008L	PARTICIPANT	\N	PRESENT	0
395248	392896	08061X	PARTICIPANT	\N	PRESENT	0
395249	392896	14055N	PARTICIPANT	\N	PRESENT	0
395250	394110	14111D	PARTICIPANT	\N	PRESENT	0
395251	394110	14065Q	PARTICIPANT	\N	PRESENT	0
395252	394110	11010L	PARTICIPANT	\N	PRESENT	0
395253	394110	10015M	PARTICIPANT	\N	PRESENT	0
395254	394110	19253P	PARTICIPANT	\N	PRESENT	0
395255	394110	01024M	PARTICIPANT	\N	PRESENT	0
395256	394110	19581D	PARTICIPANT	\N	PRESENT	0
395257	394110	04038G	PARTICIPANT	\N	PRESENT	0
395258	394110	11033F	PARTICIPANT	\N	PRESENT	0
395259	394110	05008E	PRESIDENT	0	PRESENT	0
395260	394110	19447X	PARTICIPANT	\N	PRESENT	0
395261	394110	19725B	PARTICIPANT	\N	PRESENT	0
395262	394110	19489J	PARTICIPANT	\N	PRESENT	0
395263	394110	19629C	PARTICIPANT	\N	PRESENT	0
395264	394110	14041T	PARTICIPANT	\N	PRESENT	0
395265	394110	08044W	PARTICIPANT	\N	PRESENT	0
395266	394110	14179A	PARTICIPANT	\N	PRESENT	0
395267	394110	14215L	PARTICIPANT	\N	PRESENT	0
395268	394110	11085T	PARTICIPANT	\N	PRESENT	0
395269	394110	08018U	PARTICIPANT	\N	PRESENT	0
395271	394110	14053L	PARTICIPANT	\N	PRESENT	0
395272	394110	98035U	PARTICIPANT	\N	PRESENT	0
395273	394110	19649G	PARTICIPANT	\N	PRESENT	0
395274	394110	11026G	PARTICIPANT	\N	PRESENT	0
395275	394110	08045X	PARTICIPANT	\N	PRESENT	0
395276	394110	14001X	PARTICIPANT	\N	PRESENT	0
395277	394110	19543W	PARTICIPANT	\N	PRESENT	0
395278	394110	04044E	PARTICIPANT	\N	PRESENT	0
395279	394110	04047H	PARTICIPANT	\N	PRESENT	0
395280	394110	19673G	PARTICIPANT	\N	PRESENT	0
395281	394110	01028R	PARTICIPANT	\N	PRESENT	0
395283	394110	14147R	PARTICIPANT	\N	PRESENT	0
395284	394110	14069U	PARTICIPANT	\N	PRESENT	0
395285	394110	14151M	PARTICIPANT	\N	PRESENT	0
395286	394110	11049P	PARTICIPANT	\N	PRESENT	0
395288	394110	14021P	PARTICIPANT	\N	PRESENT	0
407914	402272	19701S	PARTICIPANT	\N	PRESENT	0
407915	402272	19549D	PARTICIPANT	\N	PRESENT	0
407916	402272	19503N	PARTICIPANT	\N	PRESENT	0
407917	402272	19637C	PARTICIPANT	\N	PRESENT	0
407918	402272	19715Y	PARTICIPANT	\N	PRESENT	0
407919	402272	19333N	PARTICIPANT	\N	PRESENT	0
407920	402272	19591F	PARTICIPANT	\N	PRESENT	0
407921	402272	19347U	PARTICIPANT	\N	PRESENT	0
407922	402272	19301E	PARTICIPANT	\N	PRESENT	0
407923	402272	14039A	PARTICIPANT	\N	PRESENT	0
407924	402272	19387D	PARTICIPANT	\N	PRESENT	0
407925	402272	11012A	PARTICIPANT	\N	PRESENT	0
407926	402272	14083S	PARTICIPANT	\N	PRESENT	0
407927	402272	14073Q	PARTICIPANT	\N	PRESENT	0
407928	402272	14357A	PARTICIPANT	\N	PRESENT	0
407929	402272	07029T	PARTICIPANT	\N	PRESENT	0
407930	402272	19663E	PARTICIPANT	\N	PRESENT	0
407352	402269	14187A	PARTICIPANT	\N	PRESENT	0
407807	407806	04035D	PARTICIPANT	\N	PRESENT	0
407931	402272	19711U	PARTICIPANT	\N	PRESENT	0
407932	402272	19611R	PARTICIPANT	\N	PRESENT	0
407933	402272	19693L	PARTICIPANT	\N	PRESENT	0
407934	402272	14031R	PARTICIPANT	\N	PRESENT	0
407935	402272	11048N	PARTICIPANT	\N	PRESENT	0
407936	402272	11090Q	PARTICIPANT	\N	PRESENT	0
407937	402272	14249W	PARTICIPANT	\N	PRESENT	0
407938	402272	19319Q	PARTICIPANT	\N	PRESENT	0
407939	402272	19713W	PARTICIPANT	\N	PRESENT	0
407940	402272	07033P	PARTICIPANT	\N	PRESENT	0
407941	402272	11099A	PARTICIPANT	\N	PRESENT	0
407942	402272	19551W	PARTICIPANT	\N	PRESENT	0
407943	402272	19295A	PARTICIPANT	\N	PRESENT	0
407944	402272	19689Q	PARTICIPANT	\N	PRESENT	0
407945	402272	04085P	PARTICIPANT	\N	PRESENT	0
407946	402272	02002K	PARTICIPANT	\N	PRESENT	0
407947	402272	14205J	PARTICIPANT	\N	PRESENT	0
407948	402272	14219Q	PARTICIPANT	\N	PRESENT	0
407912	402272	11070L	PARTICIPANT	\N	PRESENT	0
407913	402272	08009T	PARTICIPANT	\N	PRESENT	0
407967	406764	04059M	PARTICIPANT	\N	PRESENT	0
407968	406764	19701S	PARTICIPANT	\N	PRESENT	0
407969	406764	08009T	PARTICIPANT	\N	PRESENT	0
407970	406764	19695N	PARTICIPANT	\N	PRESENT	0
407971	406764	19593H	PARTICIPANT	\N	PRESENT	0
407972	406764	19347U	PARTICIPANT	\N	PRESENT	0
407973	406764	19503N	PARTICIPANT	\N	PRESENT	0
407974	406764	19333N	PARTICIPANT	\N	PRESENT	0
407975	406764	19711U	PARTICIPANT	\N	PRESENT	0
407976	406764	11090Q	PARTICIPANT	\N	PRESENT	0
407977	406764	19693L	PARTICIPANT	\N	PRESENT	0
407978	406764	19549D	PARTICIPANT	\N	PRESENT	0
407979	406764	14039A	PARTICIPANT	\N	PRESENT	0
407980	406764	14031R	PARTICIPANT	\N	PRESENT	0
407981	406764	19637C	PARTICIPANT	\N	PRESENT	0
407982	406764	14041T	PARTICIPANT	\N	PRESENT	0
407983	406764	19551W	PARTICIPANT	\N	PRESENT	0
407984	406764	19387D	PARTICIPANT	\N	PRESENT	0
407985	406764	11099A	PARTICIPANT	\N	PRESENT	0
407986	406764	19713W	PARTICIPANT	\N	PRESENT	0
407987	406764	19319Q	PARTICIPANT	\N	PRESENT	0
407989	406764	14219Q	PARTICIPANT	\N	PRESENT	0
407991	406764	14073Q	PARTICIPANT	\N	PRESENT	0
407992	406764	14105F	PARTICIPANT	\N	PRESENT	0
407993	406764	02002K	PARTICIPANT	\N	PRESENT	0
407994	406764	14249W	PARTICIPANT	\N	PRESENT	0
407995	406764	11085T	PARTICIPANT	\N	PRESENT	0
407996	406764	19689Q	PARTICIPANT	\N	PRESENT	0
407997	406764	19683J	PARTICIPANT	\N	PRESENT	0
407998	406764	19583F	PARTICIPANT	\N	PRESENT	0
407999	406764	19301E	PARTICIPANT	\N	PRESENT	0
408000	406764	19295A	PARTICIPANT	\N	PRESENT	0
408001	406764	19611R	PARTICIPANT	\N	PRESENT	0
408002	406764	19747H	PARTICIPANT	\N	PRESENT	0
408003	406764	04085P	PARTICIPANT	\N	PRESENT	0
408004	406764	19715Y	PARTICIPANT	\N	PRESENT	0
408005	406764	19673G	PARTICIPANT	\N	PRESENT	0
408006	406764	19447X	PARTICIPANT	\N	PRESENT	0
408043	406765	11070L	PARTICIPANT	\N	PRESENT	0
408046	406765	14041T	PARTICIPANT	\N	PRESENT	0
408047	406765	01057W	PARTICIPANT	\N	PRESENT	0
408069	406765	19711U	PARTICIPANT	\N	PRESENT	0
408049	406765	19347U	PARTICIPANT	\N	PRESENT	0
408050	406765	19683J	PARTICIPANT	\N	PRESENT	0
408051	406765	19333N	PARTICIPANT	\N	PRESENT	0
408052	406765	19637C	PARTICIPANT	\N	PRESENT	0
408053	406765	19693L	PARTICIPANT	\N	PRESENT	0
408054	406765	14039A	PARTICIPANT	\N	PRESENT	0
408055	406765	19701S	PARTICIPANT	\N	PRESENT	0
408056	406765	19695N	PARTICIPANT	\N	PRESENT	0
408057	406765	19447X	PARTICIPANT	\N	PRESENT	0
408058	406765	04085P	PARTICIPANT	\N	PRESENT	0
408059	406765	19593H	PARTICIPANT	\N	PRESENT	0
408060	406765	19583F	PARTICIPANT	\N	PRESENT	0
408061	406765	19713W	PARTICIPANT	\N	PRESENT	0
408062	406765	14219Q	PARTICIPANT	\N	PRESENT	0
408063	406765	19611R	PARTICIPANT	\N	PRESENT	0
408064	406765	07004J	PARTICIPANT	\N	PRESENT	0
408065	406765	14261S	PARTICIPANT	\N	PRESENT	0
408066	406765	08009T	PARTICIPANT	\N	PRESENT	0
408067	406765	11090Q	PARTICIPANT	\N	PRESENT	0
408068	406765	19549D	PARTICIPANT	\N	PRESENT	0
408070	406765	19295A	PARTICIPANT	\N	PRESENT	0
408071	406765	19715Y	PARTICIPANT	\N	PRESENT	0
408072	406765	19689Q	PARTICIPANT	\N	PRESENT	0
408073	406765	19551W	PARTICIPANT	\N	PRESENT	0
408074	406765	99004R	PARTICIPANT	\N	PRESENT	0
408077	406765	14105F	PARTICIPANT	\N	PRESENT	0
408105	406765	14093U	PARTICIPANT	\N	PRESENT	0
408151	408149	14087W	PARTICIPANT	\N	PRESENT	0
408152	408149	19521Q	PARTICIPANT	\N	PRESENT	0
408153	408149	19679N	PARTICIPANT	\N	PRESENT	0
408216	405449	04044E	PARTICIPANT	\N	EXCUSE	0
408580	405277	04038G	PARTICIPANT	\N	PRESENT	0
408045	406765	14073Q	PARTICIPANT	\N	PRESENT	0
408581	405277	14107H	PARTICIPANT	\N	PRESENT	0
408582	405277	08069G	PARTICIPANT	\N	PRESENT	0
409129	409128	04049K	PARTICIPANT	\N	PRESENT	0
409130	409128	04043D	PARTICIPANT	\N	PRESENT	0
409131	409128	08068F	PARTICIPANT	\N	PRESENT	0
409244	409209	19729F	PARTICIPANT	\N	PRESENT	0
409987	405449	95067Q	PARTICIPANT	\N	PRESENT	0
409989	405449	14257W	PARTICIPANT	\N	EXCUSE	0
410870	410869	14123H	PARTICIPANT	\N	PRESENT	0
410871	410869	19611R	PARTICIPANT	\N	PRESENT	0
410872	410869	19533U	PARTICIPANT	\N	PRESENT	0
410874	410873	19699S	PARTICIPANT	\N	PRESENT	0
410876	410875	08039A	PARTICIPANT	\N	PRESENT	0
410877	410875	14109K	PARTICIPANT	\N	PRESENT	0
410878	410875	19749K	PARTICIPANT	\N	PRESENT	0
410880	410879	08039A	PARTICIPANT	\N	PRESENT	0
410881	410879	14109K	PARTICIPANT	\N	PRESENT	0
410882	410879	19749K	PARTICIPANT	\N	PRESENT	0
410888	410887	14111D	PARTICIPANT	\N	PRESENT	0
410889	410887	14151M	PARTICIPANT	\N	PRESENT	0
410890	410887	14215L	PRESIDENT	0	PRESENT	0
410891	410887	19585H	PARTICIPANT	\N	PRESENT	0
410892	410887	14259Y	PARTICIPANT	\N	PRESENT	0
410893	410887	01028R	PARTICIPANT	\N	PRESENT	0
410894	410887	19762G	PARTICIPANT	\N	PRESENT	0
410895	410887	19447X	PARTICIPANT	\N	PRESENT	0
410896	410887	04044E	PARTICIPANT	\N	PRESENT	0
410897	410887	19489J	PARTICIPANT	\N	PRESENT	0
410898	410887	14231L	PARTICIPANT	\N	PRESENT	0
410899	410887	14089Y	PARTICIPANT	\N	PRESENT	0
410900	410887	19543W	PARTICIPANT	\N	PRESENT	0
410901	410887	11072N	PARTICIPANT	\N	PRESENT	0
410904	410887	98035U	PARTICIPANT	\N	PRESENT	0
410905	410887	14069U	PARTICIPANT	\N	PRESENT	0
410906	410887	11026G	PARTICIPANT	\N	PRESENT	0
410940	410796	19503N	PARTICIPANT	\N	PRESENT	0
410908	410887	19253P	PARTICIPANT	\N	EXCUSE	0
410909	410887	05008E	PARTICIPANT	\N	EXCUSE	0
410933	406842	86034E	PARTICIPANT	\N	PRESENT	0
410942	410797	19503N	PARTICIPANT	\N	PRESENT	0
410944	410798	19503N	PARTICIPANT	\N	PRESENT	0
410948	410800	19503N	PARTICIPANT	\N	PRESENT	0
410950	410801	19503N	PARTICIPANT	\N	PRESENT	0
410952	406842	19515S	PARTICIPANT	\N	PRESENT	0
410953	406842	14259Y	PARTICIPANT	\N	PRESENT	0
410954	406842	14231L	PARTICIPANT	\N	PRESENT	0
410955	406842	04040A	PARTICIPANT	\N	PRESENT	0
410956	406842	11040E	PARTICIPANT	\N	PRESENT	0
397419	397418	14225N	PARTICIPANT	\N	PRESENT	0
397420	397418	19631V	PARTICIPANT	\N	PRESENT	0
397421	397418	19515S	PARTICIPANT	\N	PRESENT	0
397422	397418	14041T	PARTICIPANT	\N	PRESENT	0
397423	397418	07033P	PARTICIPANT	\N	PRESENT	0
397424	397418	14087W	PARTICIPANT	\N	PRESENT	0
397425	397418	19747H	PARTICIPANT	\N	PRESENT	0
397426	397418	14053L	PARTICIPANT	\N	PRESENT	0
397427	397418	95063L	PARTICIPANT	\N	PRESENT	0
404309	404307	14083S	PARTICIPANT	\N	PRESENT	0
405325	405324	19569H	PARTICIPANT	\N	PRESENT	0
405326	405324	08028W	PARTICIPANT	\N	PRESENT	0
417529	417481	19685L	PARTICIPANT	\N	PRESENT	0
419361	407720	19333N	PARTICIPANT	\N	PRESENT	0
419362	407720	04047H	PARTICIPANT	\N	PRESENT	0
419363	407720	14001X	PARTICIPANT	\N	PRESENT	0
419364	407720	14026U	PARTICIPANT	\N	PRESENT	0
419365	407720	08017T	PARTICIPANT	\N	PRESENT	0
419366	407720	04035D	PARTICIPANT	\N	PRESENT	0
419367	407720	19525U	PARTICIPANT	\N	PRESENT	0
419368	407720	98024R	PARTICIPANT	\N	PRESENT	0
419369	407720	14081Q	PARTICIPANT	\N	PRESENT	0
419370	407720	11101A	PARTICIPANT	\N	PRESENT	0
419371	407720	05008E	PARTICIPANT	\N	PRESENT	0
419372	407720	11066Q	PARTICIPANT	\N	PRESENT	0
419373	407720	11041F	PARTICIPANT	\N	PRESENT	0
419374	407720	08043V	PARTICIPANT	\N	PRESENT	0
419375	407720	11104D	PARTICIPANT	\N	PRESENT	0
419376	407720	19679N	PARTICIPANT	\N	PRESENT	0
419377	407720	17637T	PARTICIPANT	\N	PRESENT	0
419378	407720	14281W	PARTICIPANT	\N	PRESENT	0
419379	407720	80013X	PARTICIPANT	\N	PRESENT	0
419380	407720	08045X	PARTICIPANT	\N	PRESENT	0
419381	407720	11045K	PARTICIPANT	\N	PRESENT	0
419382	407720	19599P	PARTICIPANT	\N	PRESENT	0
419383	407720	19715Y	PARTICIPANT	\N	PRESENT	0
419384	407720	12016W	PARTICIPANT	\N	PRESENT	0
419385	419343	04038G	PARTICIPANT	\N	PRESENT	0
419386	407720	07033P	PARTICIPANT	\N	PRESENT	0
419387	407720	01028R	PARTICIPANT	\N	PRESENT	0
419388	407720	08052W	PARTICIPANT	\N	PRESENT	0
419389	407720	14227Q	PARTICIPANT	\N	PRESENT	0
419390	407720	14087W	PARTICIPANT	\N	PRESENT	0
419391	407720	14229S	PARTICIPANT	\N	PRESENT	0
419392	407720	08055A	PARTICIPANT	\N	PRESENT	0
419393	407720	04059M	PARTICIPANT	\N	PRESENT	0
419394	407720	98018T	PARTICIPANT	\N	PRESENT	0
419395	407720	95067Q	PARTICIPANT	\N	PRESENT	0
419396	407720	14275Y	PARTICIPANT	\N	PRESENT	0
419397	407720	19713W	PARTICIPANT	\N	PRESENT	0
419398	407720	14277B	PARTICIPANT	\N	PRESENT	0
419399	407720	14123H	PARTICIPANT	\N	PRESENT	0
419400	407720	14042U	PARTICIPANT	\N	PRESENT	0
419401	407720	14219Q	PARTICIPANT	\N	PRESENT	0
419402	407720	19479G	PARTICIPANT	\N	PRESENT	0
419406	407720	19735D	PARTICIPANT	\N	PRESENT	0
419404	407720	19441R	PARTICIPANT	\N	PRESENT	0
419405	407720	08062Y	PARTICIPANT	\N	PRESENT	0
419407	407720	19569H	PARTICIPANT	\N	PRESENT	0
419408	407720	19699S	PARTICIPANT	\N	PRESENT	0
419409	407720	19721W	PARTICIPANT	\N	PRESENT	0
419410	407720	14205J	PARTICIPANT	\N	PRESENT	0
419411	407720	19737F	PARTICIPANT	\N	PRESENT	0
419412	407720	19511N	PARTICIPANT	\N	PRESENT	0
419413	407720	19611R	PARTICIPANT	\N	PRESENT	0
419416	407720	14223L	PARTICIPANT	\N	PRESENT	0
419419	407720	19768N	PARTICIPANT	\N	PRESENT	0
419421	407720	01034P	PARTICIPANT	\N	PRESENT	0
419423	407720	19369B	PARTICIPANT	\N	PRESENT	0
419426	407720	08058D	PARTICIPANT	\N	PRESENT	0
419428	407720	19762G	PARTICIPANT	\N	PRESENT	0
419432	407720	19691J	PARTICIPANT	\N	PRESENT	0
419434	407720	11053K	PARTICIPANT	\N	PRESENT	0
419436	407720	14103D	PARTICIPANT	\N	PRESENT	0
419439	407720	14221J	PARTICIPANT	\N	PRESENT	0
419441	407720	04089T	PARTICIPANT	\N	PRESENT	0
419442	407720	19749K	PARTICIPANT	\N	PRESENT	0
419444	407720	19745F	PARTICIPANT	\N	PRESENT	0
419445	407720	14089Y	PARTICIPANT	\N	PRESENT	0
419446	407720	14083S	PARTICIPANT	\N	PRESENT	0
419447	407720	19826F	PARTICIPANT	\N	PRESENT	0
419448	407720	19521Q	PARTICIPANT	\N	PRESENT	0
419449	407720	07004J	PARTICIPANT	\N	PRESENT	0
419450	407720	11070L	PARTICIPANT	\N	PRESENT	0
419451	407720	11085T	PARTICIPANT	\N	PRESENT	0
419453	407720	04040A	PARTICIPANT	\N	PRESENT	0
419454	407720	01025N	PARTICIPANT	\N	PRESENT	0
419456	407720	01024M	PARTICIPANT	\N	PRESENT	0
419457	407720	14030Q	PARTICIPANT	\N	PRESENT	0
419458	407720	14327T	PARTICIPANT	\N	PRESENT	0
419459	407720	14231L	PARTICIPANT	\N	PRESENT	0
419460	407720	04070G	PARTICIPANT	\N	PRESENT	0
419461	407720	16685X	PARTICIPANT	\N	PRESENT	0
419462	407720	19649G	PARTICIPANT	\N	PRESENT	0
419467	407720	89017R	PARTICIPANT	\N	PRESENT	0
419468	407720	14034U	PARTICIPANT	\N	PRESENT	0
419470	419463	19507S	PARTICIPANT	\N	PRESENT	0
419471	407720	08053X	PARTICIPANT	\N	PRESENT	0
419472	419463	01025N	PARTICIPANT	\N	PRESENT	0
419473	419463	19782L	PARTICIPANT	\N	PRESENT	0
419474	407720	14028W	PARTICIPANT	\N	PRESENT	0
419475	407720	14109K	PARTICIPANT	\N	PRESENT	0
419476	419464	19507S	PARTICIPANT	\N	PRESENT	0
419477	419464	01025N	PARTICIPANT	\N	PRESENT	0
419478	407720	14197C	PARTICIPANT	\N	PRESENT	0
419479	407720	14121F	PARTICIPANT	\N	PRESENT	0
419480	419464	19782L	PARTICIPANT	\N	PRESENT	0
419481	407720	19637C	PARTICIPANT	\N	PRESENT	0
419485	419465	01025N	PARTICIPANT	\N	PRESENT	0
419483	407720	01043Q	PARTICIPANT	\N	PRESENT	0
419484	419465	19507S	PARTICIPANT	\N	PRESENT	0
419486	419466	19507S	PARTICIPANT	\N	PRESENT	0
419487	419466	01025N	PARTICIPANT	\N	PRESENT	0
419488	419469	19507S	PARTICIPANT	\N	PRESENT	0
419489	419469	01025N	PARTICIPANT	\N	PRESENT	0
419490	407720	14255U	PARTICIPANT	\N	PRESENT	0
419491	407720	19335Q	PARTICIPANT	\N	PRESENT	0
419492	407720	14237S	PARTICIPANT	\N	PRESENT	0
419499	407720	08009T	PARTICIPANT	\N	PRESENT	0
419504	407720	19687N	PARTICIPANT	\N	PRESENT	0
419805	407721	04059M	PARTICIPANT	\N	PRESENT	0
419806	407721	14173T	PARTICIPANT	\N	PRESENT	0
419815	407721	01028R	PARTICIPANT	\N	PRESENT	0
419813	407721	11040E	PARTICIPANT	\N	PRESENT	0
419814	407721	14085U	PARTICIPANT	\N	PRESENT	0
419823	407721	14109K	PARTICIPANT	\N	PRESENT	0
419817	407721	08060W	PARTICIPANT	\N	PRESENT	0
419818	407721	80013X	PARTICIPANT	\N	PRESENT	0
419819	407721	14121F	PARTICIPANT	\N	PRESENT	0
419821	407721	08014Q	PARTICIPANT	\N	PRESENT	0
419822	407721	19631V	PARTICIPANT	\N	PRESENT	0
419824	419804	14021P	PARTICIPANT	\N	PRESENT	0
419825	407721	19253P	PARTICIPANT	\N	PRESENT	0
419826	407721	19713W	PARTICIPANT	\N	PRESENT	0
419827	407721	19737F	PARTICIPANT	\N	PRESENT	0
419828	407721	19367Y	PARTICIPANT	\N	PRESENT	0
419829	407721	19549D	PARTICIPANT	\N	PRESENT	0
419830	407721	19651A	PARTICIPANT	\N	PRESENT	0
419831	407721	19762G	PARTICIPANT	\N	PRESENT	0
419832	407721	14059S	PARTICIPANT	\N	PRESENT	0
419833	407721	19768N	PARTICIPANT	\N	PRESENT	0
419834	407721	08062Y	PARTICIPANT	\N	PRESENT	0
419835	407721	95030B	PARTICIPANT	\N	PRESENT	0
419836	407721	04043D	PARTICIPANT	\N	PRESENT	0
419837	407721	14069U	PARTICIPANT	\N	PRESENT	0
419838	407721	19711U	PARTICIPANT	\N	PRESENT	0
419839	407721	99004R	PARTICIPANT	\N	PRESENT	0
419840	407721	08015R	PARTICIPANT	\N	PRESENT	0
419841	407721	14041T	PARTICIPANT	\N	PRESENT	0
419842	407721	19467C	PARTICIPANT	\N	PRESENT	0
419843	407721	14253S	PARTICIPANT	\N	PRESENT	0
419844	407721	14115H	PARTICIPANT	\N	PRESENT	0
419845	407721	19515S	PARTICIPANT	\N	PRESENT	0
419846	407721	14191V	PARTICIPANT	\N	PRESENT	0
419847	407721	14034U	PARTICIPANT	\N	PRESENT	0
419848	407721	11027H	PARTICIPANT	\N	PRESENT	0
419849	407721	14097Y	PARTICIPANT	\N	PRESENT	0
419850	407721	19545Y	PARTICIPANT	\N	PRESENT	0
419851	407721	11074Q	PARTICIPANT	\N	PRESENT	0
419852	407721	19733B	PARTICIPANT	\N	PRESENT	0
419853	407721	11085T	PARTICIPANT	\N	PRESENT	0
419855	407721	12016W	PARTICIPANT	\N	PRESENT	0
419856	407721	19551W	PARTICIPANT	\N	PRESENT	0
419860	407721	14021P	PARTICIPANT	\N	PRESENT	0
419861	407721	14053L	PARTICIPANT	\N	PRESENT	0
419862	407721	19533U	PARTICIPANT	\N	PRESENT	0
419863	407721	14197C	PARTICIPANT	\N	PRESENT	0
419864	407721	19479G	PARTICIPANT	\N	PRESENT	0
404154	400173	04044E	PARTICIPANT	\N	PRESENT	0
404155	400173	19687N	PARTICIPANT	\N	PRESENT	0
404156	400173	19647E	PARTICIPANT	\N	PRESENT	0
404157	400173	19531S	PARTICIPANT	\N	PRESENT	0
404158	400173	08014Q	PARTICIPANT	\N	PRESENT	0
404159	400173	01028R	PARTICIPANT	\N	PRESENT	0
404160	400173	08052W	PARTICIPANT	\N	PRESENT	0
404161	400173	19349W	PARTICIPANT	\N	PRESENT	0
404162	400173	19782L	PARTICIPANT	\N	PRESENT	0
404163	400173	08011M	PARTICIPANT	\N	PRESENT	0
404164	400173	14231L	PARTICIPANT	\N	PRESENT	0
404165	400173	11070L	PARTICIPANT	\N	PRESENT	0
404166	400173	14089Y	PARTICIPANT	\N	PRESENT	0
404167	400173	19747H	PARTICIPANT	\N	PRESENT	0
404168	400173	14215L	PARTICIPANT	\N	PRESENT	0
404169	400173	01024M	PARTICIPANT	\N	PRESENT	0
404170	400173	11074Q	PARTICIPANT	\N	PRESENT	0
404171	400173	08015R	PARTICIPANT	\N	PRESENT	0
404172	400173	14213J	PARTICIPANT	\N	PRESENT	0
404173	400173	14265W	PARTICIPANT	\N	PRESENT	0
404174	400173	14147R	PARTICIPANT	\N	PRESENT	0
404175	400173	14217N	PARTICIPANT	\N	PRESENT	0
404176	400173	01057W	PARTICIPANT	\N	PRESENT	0
404177	400173	19693L	PARTICIPANT	\N	PRESENT	0
404178	400173	19794Q	PARTICIPANT	\N	PRESENT	0
404179	400173	14041T	PARTICIPANT	\N	PRESENT	0
404180	400173	07029T	PARTICIPANT	\N	PRESENT	0
404181	400173	08034U	PARTICIPANT	\N	PRESENT	0
404182	400173	96004D	PARTICIPANT	\N	PRESENT	0
404183	400173	19703U	PARTICIPANT	\N	PRESENT	0
404184	400173	19741B	PARTICIPANT	\N	PRESENT	0
404185	400173	14053L	PARTICIPANT	\N	PRESENT	0
404186	400173	08010L	PARTICIPANT	\N	PRESENT	0
404187	400173	14135M	PARTICIPANT	\N	PRESENT	0
404188	400173	11048N	PARTICIPANT	\N	PRESENT	0
404189	400173	19447X	PARTICIPANT	\N	PRESENT	0
404190	400173	19739H	PARTICIPANT	\N	PRESENT	0
404191	400173	14121F	PARTICIPANT	\N	PRESENT	0
404192	400173	14093U	PARTICIPANT	\N	PRESENT	0
404193	400173	14085U	PARTICIPANT	\N	PRESENT	0
404194	400173	19737F	PARTICIPANT	\N	PRESENT	0
404195	400173	14097Y	PARTICIPANT	\N	PRESENT	0
404196	400173	14030Q	PARTICIPANT	\N	PRESENT	0
404197	400173	14033T	PARTICIPANT	\N	PRESENT	0
404198	400173	14034U	PARTICIPANT	\N	PRESENT	0
404199	400173	19479G	PARTICIPANT	\N	PRESENT	0
404200	400173	14026U	PARTICIPANT	\N	PRESENT	0
404255	404254	19643A	PARTICIPANT	\N	PRESENT	0
404256	404254	19758L	PARTICIPANT	\N	PRESENT	0
404257	404254	19693L	PARTICIPANT	\N	PRESENT	0
404258	404254	14249W	PARTICIPANT	\N	PRESENT	0
404551	404549	19503N	PARTICIPANT	\N	PRESENT	0
404260	404254	19399H	PARTICIPANT	\N	PRESENT	0
404261	404254	19447X	PARTICIPANT	\N	PRESENT	0
404263	404254	14021P	PARTICIPANT	\N	PRESENT	0
404264	404254	14073Q	PARTICIPANT	\N	PRESENT	0
404265	404254	08012N	PARTICIPANT	\N	PRESENT	0
404266	404254	04070G	PARTICIPANT	\N	PRESENT	0
404267	404254	19349W	PARTICIPANT	\N	PRESENT	0
404268	404254	14229S	PARTICIPANT	\N	PRESENT	0
404555	404553	19503N	PARTICIPANT	\N	PRESENT	0
404628	404627	14207L	PARTICIPANT	\N	PRESENT	0
404629	404627	14033T	PARTICIPANT	\N	PRESENT	0
404630	404627	14205J	PARTICIPANT	\N	PRESENT	0
404631	404627	14135M	PARTICIPANT	\N	PRESENT	0
404633	404632	14207L	PARTICIPANT	\N	PRESENT	0
404634	404632	14033T	PARTICIPANT	\N	PRESENT	0
404635	404632	19511N	PARTICIPANT	\N	PRESENT	0
404636	404632	14257W	PARTICIPANT	\N	PRESENT	0
404637	404632	14265W	PARTICIPANT	\N	PRESENT	0
404638	404632	14135M	PARTICIPANT	\N	PRESENT	0
404640	404639	19511N	PARTICIPANT	\N	PRESENT	0
404641	404639	14257W	PARTICIPANT	\N	PRESENT	0
404642	404639	14207L	PARTICIPANT	\N	PRESENT	0
404643	404639	14033T	PARTICIPANT	\N	PRESENT	0
404644	404639	14265W	PARTICIPANT	\N	PRESENT	0
404645	404639	14135M	PARTICIPANT	\N	PRESENT	0
404647	404646	19511N	PARTICIPANT	\N	PRESENT	0
404648	404646	14257W	PARTICIPANT	\N	PRESENT	0
404649	404646	14207L	PARTICIPANT	\N	PRESENT	0
404650	404646	14033T	PARTICIPANT	\N	PRESENT	0
404651	404646	14265W	PARTICIPANT	\N	PRESENT	0
404652	404646	14135M	PARTICIPANT	\N	PRESENT	0
404654	404653	14265W	PARTICIPANT	\N	PRESENT	0
404655	404653	14135M	PARTICIPANT	\N	PRESENT	0
404656	404653	14207L	PARTICIPANT	\N	PRESENT	0
404657	404653	14033T	PARTICIPANT	\N	PRESENT	0
404658	404653	19511N	PARTICIPANT	\N	PRESENT	0
404663	404660	19511N	PARTICIPANT	\N	PRESENT	0
404661	404660	14207L	PARTICIPANT	\N	PRESENT	0
404662	404660	14033T	PARTICIPANT	\N	PRESENT	0
404664	404660	14135M	PARTICIPANT	\N	PRESENT	0
404666	404665	14207L	PARTICIPANT	\N	PRESENT	0
404667	404665	19511N	PARTICIPANT	\N	PRESENT	0
404668	404665	14205J	PARTICIPANT	\N	PRESENT	0
404812	404805	14205J	PARTICIPANT	\N	PRESENT	0
404813	404806	14205J	PARTICIPANT	\N	PRESENT	0
404814	404807	14205J	PARTICIPANT	\N	PRESENT	0
404815	404808	14205J	PARTICIPANT	\N	PRESENT	0
404816	404809	14205J	PARTICIPANT	\N	PRESENT	0
404817	404810	14205J	PARTICIPANT	\N	PRESENT	0
404818	404811	14205J	PARTICIPANT	\N	PRESENT	0
404829	404819	19701S	PARTICIPANT	\N	PRESENT	0
404830	404820	19701S	PARTICIPANT	\N	PRESENT	0
404831	404821	19701S	PARTICIPANT	\N	PRESENT	0
404832	404822	19701S	PARTICIPANT	\N	PRESENT	0
404833	404823	19701S	PARTICIPANT	\N	PRESENT	0
404834	404823	19549D	PARTICIPANT	\N	PRESENT	0
404835	404824	19701S	PARTICIPANT	\N	PRESENT	0
404836	404824	19549D	PARTICIPANT	\N	PRESENT	0
404837	404825	19701S	PARTICIPANT	\N	PRESENT	0
404838	404825	19549D	PARTICIPANT	\N	PRESENT	0
404839	404825	19794Q	PARTICIPANT	\N	PRESENT	0
404840	404826	19701S	PARTICIPANT	\N	PRESENT	0
404841	404826	19549D	PARTICIPANT	\N	PRESENT	0
404842	404826	19794Q	PARTICIPANT	\N	PRESENT	0
404843	404827	19701S	PARTICIPANT	\N	PRESENT	0
404844	404827	19549D	PARTICIPANT	\N	PRESENT	0
404845	404827	19794Q	PARTICIPANT	\N	PRESENT	0
404846	404828	19701S	PARTICIPANT	\N	PRESENT	0
404847	404828	19549D	PARTICIPANT	\N	PRESENT	0
404848	404828	19794Q	PARTICIPANT	\N	PRESENT	0
404895	404893	19725B	PARTICIPANT	\N	EXCUSE	0
404896	404893	19441R	PARTICIPANT	\N	PRESENT	0
404897	404893	04057K	PARTICIPANT	\N	PRESENT	0
404898	404893	08015R	PARTICIPANT	\N	PRESENT	0
404899	404893	04097T	PARTICIPANT	\N	PRESENT	0
404900	404893	14107H	PARTICIPANT	\N	EXCUSE	0
404901	404893	14026U	PARTICIPANT	\N	PRESENT	0
404913	404903	14205J	PARTICIPANT	\N	PRESENT	0
404914	404904	14205J	PARTICIPANT	\N	PRESENT	0
404915	404905	14205J	PARTICIPANT	\N	PRESENT	0
404916	404906	14205J	PARTICIPANT	\N	PRESENT	0
404917	404907	14205J	PARTICIPANT	\N	PRESENT	0
404918	404902	14205J	PARTICIPANT	\N	PRESENT	0
404919	404908	14205J	PARTICIPANT	\N	PRESENT	0
404920	404909	14205J	PARTICIPANT	\N	PRESENT	0
404921	404910	14205J	PARTICIPANT	\N	PRESENT	0
404922	404911	14205J	PARTICIPANT	\N	PRESENT	0
404923	404912	14205J	PARTICIPANT	\N	PRESENT	0
404989	404988	14030Q	PARTICIPANT	\N	PRESENT	0
404990	404988	14187A	PARTICIPANT	\N	PRESENT	0
404991	404988	14281W	PARTICIPANT	\N	PRESENT	0
404992	404988	08034U	PARTICIPANT	\N	PRESENT	0
404993	404988	19729F	PARTICIPANT	\N	PRESENT	0
404994	404988	14031R	PARTICIPANT	\N	PRESENT	0
404995	404988	14275Y	PARTICIPANT	\N	PRESENT	0
404996	404988	04044E	PARTICIPANT	\N	PRESENT	0
404998	404997	14133K	PARTICIPANT	\N	PRESENT	0
404999	404997	14030Q	PARTICIPANT	\N	PRESENT	0
405000	404997	08043V	PARTICIPANT	\N	PRESENT	0
405001	404997	14187A	PARTICIPANT	\N	PRESENT	0
405002	404997	14281W	PARTICIPANT	\N	PRESENT	0
405003	404997	08045X	PARTICIPANT	\N	PRESENT	0
405004	404997	14031R	PARTICIPANT	\N	PRESENT	0
405006	405005	14030Q	PARTICIPANT	\N	PRESENT	0
405007	405005	08043V	PARTICIPANT	\N	PRESENT	0
405008	405005	14083S	PARTICIPANT	\N	PRESENT	0
405009	405005	14281W	PARTICIPANT	\N	PRESENT	0
405010	405005	08045X	PARTICIPANT	\N	PRESENT	0
405011	405005	08034U	PARTICIPANT	\N	PRESENT	0
405012	405005	14031R	PARTICIPANT	\N	PRESENT	0
405013	405005	14331P	PARTICIPANT	\N	PRESENT	0
405020	405014	14030Q	PARTICIPANT	\N	PRESENT	0
405021	405014	14083S	PARTICIPANT	\N	PRESENT	0
405022	405014	14031R	PARTICIPANT	\N	PRESENT	0
405023	405014	11066Q	PARTICIPANT	\N	PRESENT	0
393138	378053	19507S	PARTICIPANT	\N	PRESENT	0
393146	378053	14105F	PARTICIPANT	\N	PRESENT	0
393147	378053	04047H	PARTICIPANT	\N	PRESENT	0
393148	378053	19747H	PARTICIPANT	\N	PRESENT	0
393149	378053	14157T	PARTICIPANT	\N	PRESENT	0
393150	378053	04088S	PARTICIPANT	\N	PRESENT	0
393151	378053	14265W	PARTICIPANT	\N	PRESENT	0
393152	378053	08019V	PARTICIPANT	\N	PRESENT	0
393153	378053	95030B	PARTICIPANT	\N	PRESENT	0
393154	378053	04008A	PARTICIPANT	\N	PRESENT	0
393155	378053	14029X	PARTICIPANT	\N	PRESENT	0
393156	378053	19675J	PARTICIPANT	\N	PRESENT	0
393157	378053	19798U	PARTICIPANT	\N	PRESENT	0
393158	378053	11097X	PARTICIPANT	\N	PRESENT	0
393159	378053	95062K	PARTICIPANT	\N	PRESENT	0
393160	378053	01058X	PARTICIPANT	\N	PRESENT	0
393161	378053	14147R	PARTICIPANT	\N	PRESENT	0
393162	378053	19643A	PARTICIPANT	\N	PRESENT	0
393163	378053	18083K	PARTICIPANT	\N	PRESENT	0
393164	378053	14259Y	PARTICIPANT	\N	PRESENT	0
393165	378053	97011G	PARTICIPANT	\N	PRESENT	0
393166	378053	19711U	PARTICIPANT	\N	PRESENT	0
393167	378053	19399H	PARTICIPANT	\N	PRESENT	0
393168	378053	14191V	PARTICIPANT	\N	PRESENT	0
393169	378053	14355X	PARTICIPANT	\N	PRESENT	0
393170	378053	04097T	PARTICIPANT	\N	PRESENT	0
393171	378053	99004R	PARTICIPANT	\N	PRESENT	0
393172	390062	04057K	PARTICIPANT	\N	PRESENT	0
393173	390062	08073C	PARTICIPANT	\N	PRESENT	0
393174	390062	19441R	PRESIDENT	0	PRESENT	0
393175	390062	04097T	PARTICIPANT	\N	PRESENT	0
393176	390062	14071N	PARTICIPANT	\N	PRESENT	0
393177	390062	19747H	PARTICIPANT	\N	PRESENT	0
393179	390062	19725B	PARTICIPANT	\N	EXCUSE	0
393180	390062	11056N	PARTICIPANT	\N	EXCUSE	0
393181	390062	08015R	PARTICIPANT	\N	EXCUSE	0
393182	390062	14033T	PARTICIPANT	\N	EXCUSE	0
393183	390062	19295A	PARTICIPANT	\N	EXCUSE	0
393184	378053	08069G	PARTICIPANT	\N	PRESENT	0
393185	378053	19729F	PARTICIPANT	\N	PRESENT	0
393186	378053	04044E	PARTICIPANT	\N	PRESENT	0
393187	378053	19723Y	PARTICIPANT	\N	PRESENT	0
393188	378053	14357A	PARTICIPANT	\N	PRESENT	0
393189	378053	07029T	PARTICIPANT	\N	PRESENT	0
393190	378053	19671E	PARTICIPANT	\N	PRESENT	0
393191	378053	14215L	PARTICIPANT	\N	PRESENT	0
393192	378053	19766L	PARTICIPANT	\N	PRESENT	0
393193	378053	19705W	PARTICIPANT	\N	PRESENT	0
393194	378053	19667J	PARTICIPANT	\N	PRESENT	0
393195	378053	14026U	PARTICIPANT	\N	PRESENT	0
393196	378053	14133K	PARTICIPANT	\N	PRESENT	0
393197	378053	19515S	PARTICIPANT	\N	PRESENT	0
393198	378053	04085P	PARTICIPANT	\N	PRESENT	0
393199	378053	12041X	PARTICIPANT	\N	PRESENT	0
393200	378053	19347U	PARTICIPANT	\N	PRESENT	0
393201	378053	19593H	PARTICIPANT	\N	PRESENT	0
393202	378053	08039A	PARTICIPANT	\N	PRESENT	0
393203	378053	11033F	PARTICIPANT	\N	PRESENT	0
393204	378053	19768N	PARTICIPANT	\N	PRESENT	0
393205	378053	08061X	PARTICIPANT	\N	PRESENT	0
393206	378053	19762G	PARTICIPANT	\N	PRESENT	0
393207	378053	95063L	PARTICIPANT	\N	PRESENT	0
393208	378053	19651A	PARTICIPANT	\N	PRESENT	0
393209	378053	19543W	PARTICIPANT	\N	PRESENT	0
393210	378053	04034C	PARTICIPANT	\N	PRESENT	0
393211	378053	19782L	PARTICIPANT	\N	PRESENT	0
393212	378053	19269X	PARTICIPANT	\N	PRESENT	0
393213	378053	08010L	PARTICIPANT	\N	PRESENT	0
393214	378053	08021P	PARTICIPANT	\N	PRESENT	0
393215	378053	19697Q	PARTICIPANT	\N	PRESENT	0
393216	378053	19637C	PARTICIPANT	\N	PRESENT	0
393217	378053	08073C	PARTICIPANT	\N	PRESENT	0
393218	378053	19301E	PARTICIPANT	\N	PRESENT	0
393219	378053	11072N	PARTICIPANT	\N	PRESENT	0
393220	378053	08024S	PARTICIPANT	\N	PRESENT	0
393221	378053	04045F	PARTICIPANT	\N	PRESENT	0
393222	378053	19383Y	PARTICIPANT	\N	PRESENT	0
393223	378053	98029W	PARTICIPANT	\N	PRESENT	0
393224	378053	11083R	PARTICIPANT	\N	PRESENT	0
393225	378053	19685L	PARTICIPANT	\N	PRESENT	0
393226	378053	19679N	PARTICIPANT	\N	PRESENT	0
393227	378053	89017R	PARTICIPANT	\N	PRESENT	0
393228	378053	19731Y	PARTICIPANT	\N	PRESENT	0
393229	378053	19447X	PARTICIPANT	\N	PRESENT	0
393230	378053	01048V	PARTICIPANT	\N	PRESENT	0
393231	378053	08020N	PARTICIPANT	\N	PRESENT	0
393232	378053	14207L	PARTICIPANT	\N	PRESENT	0
393233	378053	08049C	PARTICIPANT	\N	PRESENT	0
393234	378053	08031R	PARTICIPANT	\N	PRESENT	0
393235	378053	19693L	PARTICIPANT	\N	PRESENT	0
393236	378053	88008L	PARTICIPANT	\N	PRESENT	0
393237	378053	14201E	PARTICIPANT	\N	PRESENT	0
393238	378053	14107H	PARTICIPANT	\N	PRESENT	0
393239	378053	04042C	PARTICIPANT	\N	PRESENT	0
393240	378053	11099A	PARTICIPANT	\N	PRESENT	0
393241	378053	95037J	PARTICIPANT	\N	PRESENT	0
393242	378053	15447F	PARTICIPANT	\N	PRESENT	0
393243	378053	14093U	PARTICIPANT	\N	PRESENT	0
393244	378053	11064N	PARTICIPANT	\N	PRESENT	0
393245	378053	19585H	PARTICIPANT	\N	PRESENT	0
393246	378053	14251Q	PARTICIPANT	\N	PRESENT	0
393247	378053	19563B	PARTICIPANT	\N	PRESENT	0
393248	378053	14031R	PARTICIPANT	\N	PRESENT	0
393249	378053	14038Y	PARTICIPANT	\N	PRESENT	0
393250	378053	19467C	PARTICIPANT	\N	PRESENT	0
393251	378053	02002K	PARTICIPANT	\N	PRESENT	0
393252	378053	04057K	PARTICIPANT	\N	PRESENT	0
393253	378053	04071H	PARTICIPANT	\N	PRESENT	0
393254	378053	19413M	PARTICIPANT	\N	PRESENT	0
393255	378053	14119M	PARTICIPANT	\N	PRESENT	0
393256	378053	19591F	PARTICIPANT	\N	PRESENT	0
393257	378053	11067R	PARTICIPANT	\N	PRESENT	0
393258	378053	19551W	PARTICIPANT	\N	PRESENT	0
393259	378053	11031D	PARTICIPANT	\N	PRESENT	0
393260	378053	14159V	PARTICIPANT	\N	PRESENT	0
393261	378053	08018U	PARTICIPANT	\N	PRESENT	0
393262	378053	14227Q	PARTICIPANT	\N	PRESENT	0
393263	378053	11054L	PARTICIPANT	\N	PRESENT	0
393264	378053	98035U	PARTICIPANT	\N	PRESENT	0
393265	378053	19663E	PARTICIPANT	\N	PRESENT	0
393266	378053	14001X	PARTICIPANT	\N	PRESENT	0
393267	378053	19333N	PARTICIPANT	\N	PRESENT	0
393268	378053	19549D	PARTICIPANT	\N	PRESENT	0
393269	378053	11041F	PARTICIPANT	\N	PRESENT	0
393270	378053	08048B	PARTICIPANT	\N	PRESENT	0
393271	378053	14081Q	PARTICIPANT	\N	PRESENT	0
393272	378053	19525U	PARTICIPANT	\N	PRESENT	0
393273	378053	08053X	PARTICIPANT	\N	PRESENT	0
393274	378053	08017T	PARTICIPANT	\N	PRESENT	0
393275	378053	14085U	PARTICIPANT	\N	PRESENT	0
393276	378053	17779H	PARTICIPANT	\N	PRESENT	0
393277	378053	19489J	PARTICIPANT	\N	PRESENT	0
393278	378053	19760E	PARTICIPANT	\N	PRESENT	0
393279	378053	95067Q	PARTICIPANT	\N	PRESENT	0
393280	378053	19727D	PARTICIPANT	\N	PRESENT	0
393281	378053	11080N	PARTICIPANT	\N	PRESENT	0
393282	378053	80013X	PARTICIPANT	\N	PRESENT	0
393283	378053	08012N	PARTICIPANT	\N	PRESENT	0
393284	378053	14281W	PARTICIPANT	\N	PRESENT	0
393285	378053	04049K	PARTICIPANT	\N	PRESENT	0
393286	378053	11066Q	PARTICIPANT	\N	PRESENT	0
393287	378053	01062T	PARTICIPANT	\N	PRESENT	0
393288	378053	08052W	PARTICIPANT	\N	PRESENT	0
393289	378053	11090Q	PARTICIPANT	\N	PRESENT	0
393290	378053	19647E	PARTICIPANT	\N	PRESENT	0
393291	378053	19649G	PARTICIPANT	\N	PRESENT	0
393292	378053	14187A	PARTICIPANT	\N	PRESENT	0
393293	378053	14151M	PARTICIPANT	\N	PRESENT	0
393294	378053	19715Y	PARTICIPANT	\N	PRESENT	0
393295	378053	19599P	PARTICIPANT	\N	PRESENT	0
393296	378053	19669L	PARTICIPANT	\N	PRESENT	0
393297	378053	08045X	PARTICIPANT	\N	PRESENT	0
393298	378053	04092N	PARTICIPANT	\N	PRESENT	0
393299	378053	14021P	PARTICIPANT	\N	PRESENT	0
393300	378053	14229S	PARTICIPANT	\N	PRESENT	0
393301	378053	04035D	PARTICIPANT	\N	PRESENT	0
393302	378053	01028R	PARTICIPANT	\N	PRESENT	0
393303	378053	08068F	PARTICIPANT	\N	PRESENT	0
393304	378053	11074Q	PARTICIPANT	\N	PRESENT	0
393305	378053	11045K	PARTICIPANT	\N	PRESENT	0
393306	378053	14193X	PARTICIPANT	\N	PRESENT	0
393307	378053	14097Y	PARTICIPANT	\N	PRESENT	0
393308	378053	04061F	PARTICIPANT	\N	PRESENT	0
393309	378053	19621T	PARTICIPANT	\N	PRESENT	0
393310	378053	19631V	PARTICIPANT	\N	PRESENT	0
393311	378053	14063N	PARTICIPANT	\N	PRESENT	0
393312	378053	14257W	PARTICIPANT	\N	PRESENT	0
393313	378053	19737F	PARTICIPANT	\N	PRESENT	0
393314	378053	16685X	PARTICIPANT	\N	PRESENT	0
410957	406842	11031D	PARTICIPANT	\N	PRESENT	0
410958	406842	19593H	PARTICIPANT	\N	PRESENT	0
410959	406842	19565D	PARTICIPANT	\N	PRESENT	0
410960	406842	11056N	PARTICIPANT	\N	PRESENT	0
410961	406842	17779H	PARTICIPANT	\N	PRESENT	0
410962	406842	19347U	PARTICIPANT	\N	PRESENT	0
410963	406842	19413M	PARTICIPANT	\N	PRESENT	0
410964	406842	19551W	PARTICIPANT	\N	PRESENT	0
410965	406842	14227Q	PARTICIPANT	\N	PRESENT	0
410966	406842	08043V	PARTICIPANT	\N	PRESENT	0
410967	406842	19715Y	PARTICIPANT	\N	PRESENT	0
410968	406842	08017T	PARTICIPANT	\N	PRESENT	0
410969	406842	14281W	PARTICIPANT	\N	PRESENT	0
410970	406842	14001X	PARTICIPANT	\N	PRESENT	0
410971	406842	19333N	PARTICIPANT	\N	PRESENT	0
410972	406842	14081Q	PARTICIPANT	\N	PRESENT	0
410973	406842	11066Q	PARTICIPANT	\N	PRESENT	0
410974	406842	19758L	PARTICIPANT	\N	PRESENT	0
410975	406842	19782L	PARTICIPANT	\N	PRESENT	0
410976	406842	14121F	PARTICIPANT	\N	PRESENT	0
410977	406842	14207L	PARTICIPANT	\N	PRESENT	0
410978	406842	19683J	PARTICIPANT	\N	PRESENT	0
410979	406842	14111D	PARTICIPANT	\N	PRESENT	0
410980	406842	19583F	PARTICIPANT	\N	PRESENT	0
410981	406842	19349W	PARTICIPANT	\N	PRESENT	0
410982	406842	19637C	PARTICIPANT	\N	PRESENT	0
410983	406842	14107H	PARTICIPANT	\N	PRESENT	0
410984	406842	98022P	PARTICIPANT	\N	PRESENT	0
410985	406842	14241N	PARTICIPANT	\N	PRESENT	0
410986	406842	19719D	PARTICIPANT	\N	PRESENT	0
410987	406842	19629C	PARTICIPANT	\N	PRESENT	0
410988	406842	11083R	PARTICIPANT	\N	PRESENT	0
410989	406842	98029W	PARTICIPANT	\N	PRESENT	0
410990	406842	95037J	PARTICIPANT	\N	PRESENT	0
410991	406842	88008L	PARTICIPANT	\N	PRESENT	0
410992	406842	08031R	PARTICIPANT	\N	PRESENT	0
410993	406842	04034C	PARTICIPANT	\N	PRESENT	0
410994	406842	08024S	PARTICIPANT	\N	PRESENT	0
410995	406842	19319Q	PARTICIPANT	\N	PRESENT	0
410996	406842	19479G	PARTICIPANT	\N	PRESENT	0
410997	406842	19739H	PARTICIPANT	\N	PRESENT	0
410998	406842	14034U	PARTICIPANT	\N	PRESENT	0
410999	406842	19721W	PARTICIPANT	\N	PRESENT	0
411000	406842	19737F	PARTICIPANT	\N	PRESENT	0
411001	406842	14030Q	PARTICIPANT	\N	PRESENT	0
411002	406842	19611R	PARTICIPANT	\N	PRESENT	0
411003	406842	05008E	PARTICIPANT	\N	PRESENT	0
411004	406842	14211G	PARTICIPANT	\N	PRESENT	0
411005	406842	19619A	PARTICIPANT	\N	PRESENT	0
411006	406842	08009T	PARTICIPANT	\N	PRESENT	0
411007	406842	14267Y	PARTICIPANT	\N	PRESENT	0
411008	406842	14221J	PARTICIPANT	\N	PRESENT	0
411009	406842	99004R	PARTICIPANT	\N	PRESENT	0
411010	406842	19521Q	PARTICIPANT	\N	PRESENT	0
411011	406842	04070G	PARTICIPANT	\N	PRESENT	0
411012	406842	14215L	PARTICIPANT	\N	PRESENT	0
411013	406842	14087W	PARTICIPANT	\N	PRESENT	0
411014	406842	95030B	PARTICIPANT	\N	PRESENT	0
411015	406842	14079W	PARTICIPANT	\N	PRESENT	0
411016	406842	19581D	PARTICIPANT	\N	PRESENT	0
411017	406842	19367Y	PARTICIPANT	\N	PRESENT	0
411018	406842	19745F	PARTICIPANT	\N	PRESENT	0
411019	406842	04044E	PARTICIPANT	\N	PRESENT	0
411020	406842	89017R	PARTICIPANT	\N	PRESENT	0
411021	406842	04086Q	PARTICIPANT	\N	PRESENT	0
411022	406842	11097X	PARTICIPANT	\N	PRESENT	0
411023	406842	10015M	PARTICIPANT	\N	PRESENT	0
411024	406842	11043H	PARTICIPANT	\N	PRESENT	0
411025	406842	14053L	PARTICIPANT	\N	PRESENT	0
411026	406842	14223L	PARTICIPANT	\N	PRESENT	0
411027	406842	19798U	PARTICIPANT	\N	PRESENT	0
411028	406842	04069P	PARTICIPANT	\N	PRESENT	0
411029	406842	87003B	PARTICIPANT	\N	PRESENT	0
411030	406842	14217N	PARTICIPANT	\N	PRESENT	0
411031	406842	19383Y	PARTICIPANT	\N	PRESENT	0
411032	406842	01057W	PARTICIPANT	\N	PRESENT	0
411033	406842	19731Y	PARTICIPANT	\N	PRESENT	0
411034	406842	14187A	PARTICIPANT	\N	PRESENT	0
411035	406842	14061L	PARTICIPANT	\N	PRESENT	0
411036	406842	19762G	PARTICIPANT	\N	PRESENT	0
411037	406842	08056B	PARTICIPANT	\N	PRESENT	0
411038	406842	01043Q	PARTICIPANT	\N	PRESENT	0
411039	406842	19369B	PARTICIPANT	\N	PRESENT	0
411040	406842	19701S	PARTICIPANT	\N	PRESENT	0
411041	406842	04033B	PARTICIPANT	\N	PRESENT	0
411042	406842	14329V	PARTICIPANT	\N	PRESENT	0
411043	406842	14357A	PARTICIPANT	\N	PRESENT	0
411044	406842	15447F	PARTICIPANT	\N	PRESENT	0
411045	406842	08019V	PARTICIPANT	\N	PRESENT	0
411046	406842	14065Q	PARTICIPANT	\N	PRESENT	0
411047	406842	19794Q	PARTICIPANT	\N	PRESENT	0
411048	406842	19723Y	PARTICIPANT	\N	PRESENT	0
411049	406842	19489J	PARTICIPANT	\N	PRESENT	0
411050	406842	19447X	PARTICIPANT	\N	PRESENT	0
411051	406842	19527W	PARTICIPANT	\N	PRESENT	0
411052	406842	18083K	PARTICIPANT	\N	PRESENT	0
411053	406842	04088S	PARTICIPANT	\N	PRESENT	0
411054	406842	14197C	PARTICIPANT	\N	PRESENT	0
411055	406842	19467C	PARTICIPANT	\N	PRESENT	0
411056	406842	08012N	PARTICIPANT	\N	PRESENT	0
411057	406842	19531S	PARTICIPANT	\N	PRESENT	0
411058	406842	14033T	PARTICIPANT	\N	PRESENT	0
411059	406842	14151M	PARTICIPANT	\N	PRESENT	0
411060	406842	11054L	PARTICIPANT	\N	PRESENT	0
411061	406842	14119M	PARTICIPANT	\N	PRESENT	0
411062	406842	14225N	PARTICIPANT	\N	PRESENT	0
411063	406842	19657G	PARTICIPANT	\N	PRESENT	0
411064	406842	01028R	PARTICIPANT	\N	PRESENT	0
411065	406842	08052W	PARTICIPANT	\N	PRESENT	0
411066	406842	08062Y	PARTICIPANT	\N	PRESENT	0
411067	406842	08055A	PARTICIPANT	\N	PRESENT	0
411068	406842	14105F	PARTICIPANT	\N	PRESENT	0
411069	406842	14115H	PARTICIPANT	\N	PRESENT	0
411070	406842	19760E	PARTICIPANT	\N	PRESENT	0
411071	406842	17583W	PARTICIPANT	\N	PRESENT	0
411072	406842	19575F	PARTICIPANT	\N	PRESENT	0
411073	406842	14265W	PARTICIPANT	\N	PRESENT	0
411074	406842	14219Q	PARTICIPANT	\N	PRESENT	0
411075	406842	14042U	PARTICIPANT	\N	PRESENT	0
411076	406842	08028W	PARTICIPANT	\N	PRESENT	0
411077	406842	19651A	PARTICIPANT	\N	PRESENT	0
411078	406842	01058X	PARTICIPANT	\N	PRESENT	0
411079	406842	11048N	PARTICIPANT	\N	PRESENT	0
411080	406842	08020N	PARTICIPANT	\N	PRESENT	0
411081	406842	97011G	PARTICIPANT	\N	PRESENT	0
411082	406842	14169X	PARTICIPANT	\N	PRESENT	0
411083	406842	19669L	PARTICIPANT	\N	PRESENT	0
411084	406842	19421M	PARTICIPANT	\N	PRESENT	0
411085	406842	19569H	PARTICIPANT	\N	PRESENT	0
411086	406842	19543W	PARTICIPANT	\N	PRESENT	0
411087	406842	14028W	PARTICIPANT	\N	PRESENT	0
411088	406842	19599P	PARTICIPANT	\N	PRESENT	0
411089	406842	04043D	PARTICIPANT	\N	PRESENT	0
411090	406842	19399H	PARTICIPANT	\N	PRESENT	0
411091	406842	19335Q	PARTICIPANT	\N	PRESENT	0
411092	406842	14237S	PARTICIPANT	\N	PRESENT	0
411093	406842	08058D	PARTICIPANT	\N	PRESENT	0
411094	406842	19679N	PARTICIPANT	\N	PRESENT	0
411095	406842	19585H	PARTICIPANT	\N	PRESENT	0
411096	406842	04057K	PARTICIPANT	\N	PRESENT	0
411097	406842	19681G	PARTICIPANT	\N	PRESENT	0
411098	406842	19699S	PARTICIPANT	\N	PRESENT	0
411121	406842	98050T	PARTICIPANT	\N	PRESENT	0
411102	406842	11072N	PARTICIPANT	\N	PRESENT	0
411103	406842	14327T	PARTICIPANT	\N	PRESENT	0
411104	406842	16685X	PARTICIPANT	\N	PRESENT	0
411105	406842	08045X	PARTICIPANT	\N	PRESENT	0
411106	406842	19725B	PARTICIPANT	\N	PRESENT	0
411107	406842	19631V	PARTICIPANT	\N	PRESENT	0
411108	406842	14135M	PARTICIPANT	\N	PRESENT	0
411109	406842	19533U	PARTICIPANT	\N	PRESENT	0
411110	406842	19820Y	PARTICIPANT	\N	PRESENT	0
411111	406842	14069U	PARTICIPANT	\N	PRESENT	0
411112	406842	19441R	PARTICIPANT	\N	PRESENT	0
411113	406842	19673G	PARTICIPANT	\N	PRESENT	0
411114	406842	11010L	PARTICIPANT	\N	PRESENT	0
411115	406842	14331P	PARTICIPANT	\N	PRESENT	0
411116	406842	19621T	PARTICIPANT	\N	PRESENT	0
411117	406842	19549D	PARTICIPANT	\N	PRESENT	0
411118	406842	14073Q	PARTICIPANT	\N	PRESENT	0
411119	406842	14071N	PARTICIPANT	\N	PRESENT	0
411120	406842	08015R	PARTICIPANT	\N	PRESENT	0
411122	406842	19729F	PARTICIPANT	\N	PRESENT	0
411123	406842	14031R	PARTICIPANT	\N	PRESENT	0
411124	406842	98035U	PARTICIPANT	\N	PRESENT	0
411125	406842	08034U	PARTICIPANT	\N	PRESENT	0
411126	406842	14235Q	PARTICIPANT	\N	PRESENT	0
411127	406842	04085P	PARTICIPANT	\N	PRESENT	0
398211	398209	14069U	PARTICIPANT	\N	PRESENT	0
398212	398209	14083S	PARTICIPANT	\N	PRESENT	0
398213	398209	11053K	PARTICIPANT	\N	PRESENT	0
398214	398209	14081Q	PARTICIPANT	\N	PRESENT	0
398215	398209	14179A	PARTICIPANT	\N	PRESENT	0
398216	398209	19333N	PARTICIPANT	\N	PRESENT	0
398217	398209	19611R	PARTICIPANT	\N	PRESENT	0
398218	398209	19739H	PARTICIPANT	\N	PRESENT	0
398219	398209	19735D	PARTICIPANT	\N	PRESENT	0
398222	398220	19347U	PARTICIPANT	\N	PRESENT	0
398223	398221	19347U	PARTICIPANT	\N	PRESENT	0
398224	398221	19737F	PARTICIPANT	\N	PRESENT	0
398225	398221	19637C	PARTICIPANT	\N	PRESENT	0
398227	398226	11053K	PARTICIPANT	\N	PRESENT	0
398228	398226	14159V	PARTICIPANT	\N	PRESENT	0
398229	398226	05012A	PARTICIPANT	\N	PRESENT	0
398386	398300	18083K	PARTICIPANT	\N	PRESENT	0
398387	398300	19551W	PARTICIPANT	\N	PRESENT	0
398388	398300	14031R	PARTICIPANT	\N	PRESENT	0
398389	398300	08009T	PRESIDENT	0	PRESENT	0
398390	398300	14221J	PARTICIPANT	\N	PRESENT	0
398391	398300	19599P	PARTICIPANT	\N	PRESENT	0
398392	398300	17637T	PARTICIPANT	\N	PRESENT	0
398393	398300	19637C	PARTICIPANT	\N	PRESENT	0
398394	398300	19525U	PARTICIPANT	\N	PRESENT	0
398395	398300	14051J	PARTICIPANT	\N	EXCUSE	0
398396	398300	14038Y	PARTICIPANT	\N	PRESENT	0
398397	398300	14219Q	PARTICIPANT	\N	PRESENT	0
398398	398300	15447F	PARTICIPANT	\N	PRESENT	0
398399	398300	19737F	PARTICIPANT	\N	PRESENT	0
398400	398300	19383Y	PARTICIPANT	\N	PRESENT	0
398401	398300	19701S	PARTICIPANT	\N	PRESENT	0
398402	398300	08055A	PARTICIPANT	\N	PRESENT	0
398403	398300	19503N	PARTICIPANT	\N	PRESENT	0
398404	398300	19681G	PARTICIPANT	\N	PRESENT	0
398470	398367	19766L	PARTICIPANT	\N	PRESENT	0
398471	398367	04070G	PRESIDENT	0	PRESENT	0
398472	398367	19699S	PARTICIPANT	\N	PRESENT	0
398473	398367	14073Q	PARTICIPANT	\N	PRESENT	0
398474	398367	19735D	PARTICIPANT	\N	PRESENT	0
398475	398367	04018C	PARTICIPANT	\N	PRESENT	0
398476	398367	08039A	PARTICIPANT	\N	PRESENT	0
398477	398367	14229S	PARTICIPANT	\N	PRESENT	0
398478	398367	08031R	PARTICIPANT	\N	PRESENT	0
398479	398367	14030Q	PARTICIPANT	\N	PRESENT	0
398480	398367	04057K	PARTICIPANT	\N	EXCUSE	0
398481	393595	04086Q	PARTICIPANT	\N	PRESENT	0
398482	393595	19669L	PARTICIPANT	\N	PRESENT	0
398483	393595	19758L	PARTICIPANT	\N	PRESENT	0
398484	393595	04047H	PARTICIPANT	\N	PRESENT	0
398485	393595	19673G	PARTICIPANT	\N	PRESENT	0
398486	393595	07004J	PARTICIPANT	\N	PRESENT	0
398487	393595	19629C	PARTICIPANT	\N	PRESENT	0
398488	393595	11072N	PARTICIPANT	\N	PRESENT	0
398489	393595	14119M	PARTICIPANT	\N	PRESENT	0
398490	393595	04088S	PARTICIPANT	\N	PRESENT	0
398491	393595	14021P	PARTICIPANT	\N	PRESENT	0
398492	393595	19575F	PARTICIPANT	\N	PRESENT	0
398493	393595	19713W	PARTICIPANT	\N	PRESENT	0
398494	393595	95030B	PARTICIPANT	\N	PRESENT	0
398495	393595	14147R	PARTICIPANT	\N	PRESENT	0
398496	393595	19467C	PARTICIPANT	\N	PRESENT	0
398497	393595	11064N	PARTICIPANT	\N	PRESENT	0
398498	393595	19295A	PARTICIPANT	\N	PRESENT	0
398499	393595	14211G	PARTICIPANT	\N	PRESENT	0
398500	393595	11012A	PARTICIPANT	\N	PRESENT	0
398501	393595	19747H	PARTICIPANT	\N	PRESENT	0
398502	393595	87003B	PARTICIPANT	\N	PRESENT	0
398503	393595	97011G	PARTICIPANT	\N	PRESENT	0
398504	398301	14038Y	PARTICIPANT	0	PRESENT	0
398505	398301	19333N	PARTICIPANT	\N	PRESENT	0
398506	398301	17583W	PARTICIPANT	\N	PRESENT	0
398507	398301	19794Q	PARTICIPANT	\N	PRESENT	0
398508	398301	14031R	PARTICIPANT	\N	PRESENT	0
398509	398301	14219Q	PARTICIPANT	\N	PRESENT	0
398510	398301	08055A	PARTICIPANT	\N	PRESENT	0
398511	398301	18083K	PARTICIPANT	\N	PRESENT	0
398512	398301	19551W	PARTICIPANT	\N	PRESENT	0
398513	398301	14051J	PARTICIPANT	\N	PRESENT	0
398514	398301	08060W	PARTICIPANT	\N	PRESENT	0
398515	398301	08009T	PRESIDENT	0	PRESENT	0
398516	398301	19503N	PARTICIPANT	\N	PRESENT	0
398517	398301	19737F	PARTICIPANT	\N	PRESENT	0
398518	398301	14157T	PARTICIPANT	\N	PRESENT	0
398519	398301	19745F	PARTICIPANT	\N	PRESENT	0
398520	398301	19525U	PARTICIPANT	\N	PRESENT	0
398521	393595	11103C	PARTICIPANT	\N	PRESENT	0
398522	393595	19711U	PARTICIPANT	\N	PRESENT	0
398523	393595	99004R	PARTICIPANT	\N	PRESENT	0
398524	398301	08024S	PARTICIPANT	\N	PRESENT	0
398525	393595	14115H	PARTICIPANT	\N	PRESENT	0
398526	393595	11066Q	PARTICIPANT	\N	PRESENT	0
398527	398301	04097T	PARTICIPANT	\N	PRESENT	0
398528	398301	95062K	PARTICIPANT	\N	PRESENT	0
398529	393595	19387D	PARTICIPANT	\N	PRESENT	0
398530	393595	14073Q	PARTICIPANT	\N	PRESENT	0
398531	393595	19735D	PARTICIPANT	\N	PRESENT	0
398532	393595	14042U	PARTICIPANT	\N	PRESENT	0
398533	393595	14231L	PARTICIPANT	\N	PRESENT	0
398534	393595	19515S	PARTICIPANT	\N	PRESENT	0
398535	393595	19543W	PARTICIPANT	\N	PRESENT	0
398536	393595	15447F	PARTICIPANT	\N	PRESENT	0
398537	393595	19573D	PARTICIPANT	\N	PRESENT	0
398538	393595	19507S	PARTICIPANT	\N	PRESENT	0
398539	393595	19671E	PARTICIPANT	\N	PRESENT	0
398540	393595	19729F	PARTICIPANT	\N	PRESENT	0
398541	393595	14223L	PARTICIPANT	\N	PRESENT	0
398542	393595	19687N	PARTICIPANT	\N	PRESENT	0
398544	393595	14265W	PARTICIPANT	\N	PRESENT	0
398545	393595	19681G	PARTICIPANT	\N	PRESENT	0
398546	393595	11056N	PARTICIPANT	\N	PRESENT	0
398566	393595	11049P	PARTICIPANT	\N	PRESENT	0
398548	393595	14179A	PARTICIPANT	\N	PRESENT	0
398549	393595	08010L	PARTICIPANT	\N	PRESENT	0
398550	393595	19253P	PARTICIPANT	\N	PRESENT	0
398551	393595	14111D	PARTICIPANT	\N	PRESENT	0
398552	393595	14041T	PARTICIPANT	\N	PRESENT	0
398553	393595	19531S	PARTICIPANT	\N	PRESENT	0
398554	393595	14151M	PARTICIPANT	\N	PRESENT	0
398564	393595	19719D	PARTICIPANT	\N	PRESENT	0
398565	393595	19782L	PARTICIPANT	\N	PRESENT	0
398569	393595	14053L	PARTICIPANT	\N	PRESENT	0
398570	393595	10015M	PARTICIPANT	\N	PRESENT	0
398571	393595	19762G	PARTICIPANT	\N	PRESENT	0
398572	397929	17583W	PARTICIPANT	\N	PRESENT	0
398573	397929	08034U	PARTICIPANT	\N	PRESENT	0
398574	397929	14031R	PARTICIPANT	\N	PRESENT	0
398575	397929	14187A	PARTICIPANT	\N	PRESENT	0
398576	397929	08045X	PARTICIPANT	\N	PRESENT	0
398577	397929	14235Q	PARTICIPANT	\N	PRESENT	0
398578	397929	08043V	PARTICIPANT	\N	PRESENT	0
398579	397929	04044E	PARTICIPANT	\N	PRESENT	0
398580	397929	11066Q	PARTICIPANT	\N	PRESENT	0
398581	397929	14030Q	PARTICIPANT	\N	PRESENT	0
398582	397929	14083S	PARTICIPANT	\N	PRESENT	0
398583	397929	19729F	PARTICIPANT	\N	PRESENT	0
398584	397929	14275Y	PARTICIPANT	\N	PRESENT	0
398585	397929	14157T	PARTICIPANT	\N	PRESENT	0
398586	397929	98029W	PARTICIPANT	\N	PRESENT	0
398587	397929	14331P	PARTICIPANT	\N	EXCUSE	0
398588	393595	19798U	PARTICIPANT	\N	PRESENT	0
398589	397929	14281W	PARTICIPANT	\N	PRESENT	0
398590	393595	14197C	PARTICIPANT	\N	PRESENT	0
398591	393595	14069U	PARTICIPANT	\N	PRESENT	0
398592	393595	19794Q	PARTICIPANT	\N	PRESENT	0
398593	393595	14123H	PARTICIPANT	\N	PRESENT	0
398594	393595	14038Y	PARTICIPANT	\N	PRESENT	0
398595	393595	01024M	PARTICIPANT	\N	PRESENT	0
398596	393595	14034U	PARTICIPANT	\N	PRESENT	0
398597	393595	14259Y	PARTICIPANT	\N	PRESENT	0
398598	397929	19681G	PARTICIPANT	\N	PRESENT	0
398599	393595	14087W	PARTICIPANT	\N	PRESENT	0
398600	393595	14219Q	PARTICIPANT	\N	PRESENT	0
398601	393595	19511N	PARTICIPANT	\N	PRESENT	0
398602	393595	88008L	PARTICIPANT	\N	PRESENT	0
398604	393595	19675J	PARTICIPANT	\N	PRESENT	0
398605	393595	19581D	PARTICIPANT	\N	PRESENT	0
398606	393595	19479G	PARTICIPANT	\N	PRESENT	0
398607	393595	11067R	PARTICIPANT	\N	PRESENT	0
398608	393595	19741B	PARTICIPANT	\N	PRESENT	0
398609	393595	14191V	PARTICIPANT	\N	PRESENT	0
398610	393595	14173T	PARTICIPANT	\N	PRESENT	0
398611	393595	98050T	PARTICIPANT	\N	PRESENT	0
398612	393595	11109J	PARTICIPANT	\N	PRESENT	0
398699	393596	95062K	PARTICIPANT	\N	PRESENT	0
398700	393596	04097T	PARTICIPANT	\N	PRESENT	0
398701	393596	08010L	PARTICIPANT	\N	PRESENT	0
398702	393596	11033F	PARTICIPANT	\N	PRESENT	0
398703	393596	08039A	PARTICIPANT	\N	PRESENT	0
405024	405014	17583W	PARTICIPANT	\N	PRESENT	0
405189	405187	04086Q	PARTICIPANT	\N	PRESENT	0
405192	405191	04086Q	PARTICIPANT	\N	PRESENT	0
405194	405193	14173T	PARTICIPANT	\N	PRESENT	0
405196	405195	14327T	PARTICIPANT	\N	PRESENT	0
405197	405195	11110B	PARTICIPANT	\N	PRESENT	0
405198	405195	05012A	PARTICIPANT	\N	PRESENT	0
405227	405059	17583W	PARTICIPANT	\N	PRESENT	0
405288	405110	11074Q	PRESIDENT	0	PRESENT	0
405289	405110	14327T	PARTICIPANT	\N	EXCUSE	0
405290	405110	07029T	PARTICIPANT	\N	EXCUSE	0
405291	405110	14199E	PARTICIPANT	\N	EXCUSE	0
405292	405110	11012A	PARTICIPANT	\N	EXCUSE	0
405293	405110	19545Y	PARTICIPANT	\N	EXCUSE	0
405294	405110	14159V	PARTICIPANT	\N	EXCUSE	0
405295	405110	14225N	PARTICIPANT	\N	EXCUSE	0
405296	405110	14331P	PARTICIPANT	\N	PRESENT	0
405297	405110	19479G	PARTICIPANT	\N	PRESENT	0
405298	405110	11048N	PARTICIPANT	\N	PRESENT	0
405299	405110	19711U	PARTICIPANT	\N	PRESENT	0
405300	405110	01057W	PARTICIPANT	\N	PRESENT	0
405301	405110	11070L	PARTICIPANT	\N	PRESENT	0
405302	405110	11040E	PARTICIPANT	\N	PRESENT	0
405303	405110	04086Q	PARTICIPANT	\N	PRESENT	0
405304	405110	14085U	PARTICIPANT	\N	PRESENT	0
405305	405110	96004D	PARTICIPANT	\N	PRESENT	0
405306	405110	19349W	PARTICIPANT	\N	PRESENT	0
405307	405110	98050T	PARTICIPANT	\N	PRESENT	0
405308	405110	08010L	PARTICIPANT	\N	PRESENT	0
405309	405110	14253S	PARTICIPANT	\N	PRESENT	0
405310	405110	99004R	PARTICIPANT	\N	PRESENT	0
405311	405110	19647E	PARTICIPANT	\N	PRESENT	0
405312	405110	01048V	PARTICIPANT	\N	PRESENT	0
405313	405110	19687N	PARTICIPANT	\N	PRESENT	0
405314	405110	19689Q	PARTICIPANT	\N	PRESENT	0
405315	405110	14121F	PARTICIPANT	\N	PRESENT	0
405316	405110	19741B	PARTICIPANT	\N	PRESENT	0
405317	405110	08011M	PARTICIPANT	\N	PRESENT	0
405318	405110	08069G	PARTICIPANT	\N	PRESENT	0
405319	405110	14083S	PARTICIPANT	\N	PRESENT	0
405320	405110	19671E	PARTICIPANT	\N	PRESENT	0
405321	405110	11053K	PARTICIPANT	\N	PRESENT	0
405322	405110	08034U	PARTICIPANT	\N	PRESENT	0
405372	405371	14259Y	PARTICIPANT	\N	PRESENT	0
405373	405371	14231L	PARTICIPANT	\N	PRESENT	0
405384	405383	14259Y	PARTICIPANT	\N	PRESENT	0
405376	405374	19543W	PARTICIPANT	\N	PRESENT	0
405377	405374	14259Y	PARTICIPANT	\N	PRESENT	0
405378	405374	14053L	PARTICIPANT	\N	PRESENT	0
405379	405374	14231L	PARTICIPANT	\N	PRESENT	0
405380	405374	19719D	PARTICIPANT	\N	PRESENT	0
405381	405374	95063L	PARTICIPANT	\N	PRESENT	0
405385	405383	19719D	PARTICIPANT	\N	PRESENT	0
405386	405383	14053L	PARTICIPANT	\N	PRESENT	0
405387	405383	14231L	PARTICIPANT	\N	PRESENT	0
405389	405388	14259Y	PARTICIPANT	\N	PRESENT	0
405390	405388	14231L	PARTICIPANT	\N	PRESENT	0
405395	405394	96004D	PRESIDENT	0	PRESENT	0
405396	405394	14089Y	PARTICIPANT	\N	PRESENT	0
405397	405394	98035U	PARTICIPANT	\N	PRESENT	0
405398	405394	14249W	PARTICIPANT	\N	EXCUSE	0
405399	405394	14065Q	PARTICIPANT	\N	EXCUSE	0
405400	405394	04097T	PARTICIPANT	\N	EXCUSE	0
405401	405394	14241N	PARTICIPANT	\N	EXCUSE	0
405402	405394	14073Q	PARTICIPANT	\N	EXCUSE	0
405403	405394	11026G	PARTICIPANT	\N	EXCUSE	0
405404	405394	14061L	PARTICIPANT	\N	EXCUSE	0
405405	405394	14225N	PARTICIPANT	\N	EXCUSE	0
405406	405394	14331P	PARTICIPANT	\N	EXCUSE	0
405407	405394	14135M	PARTICIPANT	\N	EXCUSE	0
405408	405394	19563B	PARTICIPANT	\N	EXCUSE	0
405410	405409	89017R	PARTICIPANT	\N	PRESENT	0
405418	404749	08053X	PARTICIPANT	\N	EXCUSE	0
405420	405419	11090Q	PARTICIPANT	\N	PRESENT	0
405421	405419	04043D	PARTICIPANT	\N	PRESENT	0
405422	405419	19667J	PARTICIPANT	\N	PRESENT	0
405423	405419	04040A	PARTICIPANT	\N	PRESENT	0
405424	405419	11083R	PARTICIPANT	\N	PRESENT	0
405426	405425	11090Q	PARTICIPANT	\N	PRESENT	0
405427	405425	04043D	PARTICIPANT	\N	PRESENT	0
405428	405425	04040A	PARTICIPANT	\N	PRESENT	0
405430	405429	11074Q	PARTICIPANT	\N	PRESENT	0
405431	405429	08011M	PARTICIPANT	\N	PRESENT	0
406864	406863	19631V	PARTICIPANT	\N	PRESENT	0
406866	406863	08043V	PARTICIPANT	\N	PRESENT	0
406867	406863	19367Y	PARTICIPANT	\N	PRESENT	0
406868	406863	19747H	PARTICIPANT	\N	PRESENT	0
406869	406863	19383Y	PARTICIPANT	\N	PRESENT	0
406870	406863	08028W	PARTICIPANT	\N	PRESENT	0
406871	406863	19467C	PARTICIPANT	\N	PRESENT	0
406872	406863	14357A	PARTICIPANT	\N	PRESENT	0
406873	406863	19693L	PARTICIPANT	\N	PRESENT	0
406874	406863	14217N	PARTICIPANT	\N	PRESENT	0
406875	406863	19507S	PARTICIPANT	\N	PRESENT	0
406876	406863	14187A	PARTICIPANT	\N	PRESENT	0
406877	406863	19727D	PARTICIPANT	\N	PRESENT	0
406878	406863	14033T	PARTICIPANT	\N	PRESENT	0
406879	406863	14026U	PARTICIPANT	\N	PRESENT	0
406880	406863	04097T	PARTICIPANT	\N	PRESENT	0
406881	406863	14213J	PARTICIPANT	\N	PRESENT	0
406882	406863	14059S	PARTICIPANT	\N	PRESENT	0
406883	406863	19441R	PARTICIPANT	\N	PRESENT	0
406884	406863	19563B	PARTICIPANT	\N	PRESENT	0
406885	406863	14257W	PARTICIPANT	\N	PRESENT	0
406886	406863	14265W	PARTICIPANT	\N	PRESENT	0
406887	406863	04088S	PARTICIPANT	\N	PRESENT	0
406888	406863	14135M	PARTICIPANT	\N	PRESENT	0
406889	406863	19798U	PARTICIPANT	\N	PRESENT	0
406890	406863	19762G	PARTICIPANT	\N	PRESENT	0
406892	406863	11090Q	PARTICIPANT	\N	PRESENT	0
406932	406863	17583W	PARTICIPANT	\N	PRESENT	0
406962	404870	19543W	PARTICIPANT	\N	EXCUSE	0
407102	405327	19569H	PARTICIPANT	\N	EXCUSE	0
407128	407126	14281W	PARTICIPANT	\N	PRESENT	0
407129	407126	14031R	PARTICIPANT	\N	PRESENT	0
407130	407126	14331P	PARTICIPANT	\N	PRESENT	0
407131	407126	14030Q	PARTICIPANT	\N	PRESENT	0
407146	405170	14031R	PARTICIPANT	\N	PRESENT	0
407147	405169	14031R	PARTICIPANT	\N	PRESENT	0
407168	407167	14073Q	PARTICIPANT	\N	PRESENT	0
407169	407167	14063N	PARTICIPANT	\N	PRESENT	0
407170	407167	11043H	PARTICIPANT	\N	PRESENT	0
407171	407167	19758L	PARTICIPANT	\N	PRESENT	0
407173	407172	14073Q	PARTICIPANT	\N	PRESENT	0
407174	407172	14063N	PARTICIPANT	\N	PRESENT	0
407175	407172	19758L	PARTICIPANT	\N	PRESENT	0
407181	405382	14034U	PARTICIPANT	\N	PRESENT	0
407185	405382	19545Y	PARTICIPANT	\N	PRESENT	0
407186	405382	19647E	PARTICIPANT	\N	PRESENT	0
407187	405382	12016W	PARTICIPANT	\N	PRESENT	0
407188	407184	11109J	PARTICIPANT	\N	PRESENT	0
407189	407184	08019V	PARTICIPANT	\N	PRESENT	0
407353	402269	11090Q	PARTICIPANT	\N	PRESENT	0
407354	402269	14329V	PARTICIPANT	\N	PRESENT	0
407355	402269	19467C	PARTICIPANT	\N	PRESENT	0
407356	402269	14229S	PARTICIPANT	\N	PRESENT	0
407357	402269	04088S	PARTICIPANT	\N	PRESENT	0
407358	402269	19551W	PARTICIPANT	\N	PRESENT	0
407359	402269	14257W	PARTICIPANT	\N	PRESENT	0
407360	402269	19768N	PARTICIPANT	\N	PRESENT	0
407361	402269	04049K	PARTICIPANT	\N	PRESENT	0
407362	402269	11097X	PARTICIPANT	\N	PRESENT	0
407363	402269	14217N	PARTICIPANT	\N	PRESENT	0
407364	402269	08015R	PARTICIPANT	\N	PRESENT	0
407365	402269	19733B	PARTICIPANT	\N	PRESENT	0
407366	402269	14059S	PARTICIPANT	\N	PRESENT	0
407367	402269	11065P	PARTICIPANT	\N	PRESENT	0
407368	402269	14265W	PARTICIPANT	\N	PRESENT	0
407369	402269	04045F	PARTICIPANT	\N	PRESENT	0
407370	402269	14219Q	PARTICIPANT	\N	PRESENT	0
407371	402269	14033T	PARTICIPANT	\N	PRESENT	0
407372	402269	14205J	PARTICIPANT	\N	PRESENT	0
407373	402269	14267Y	PARTICIPANT	\N	PRESENT	0
407374	402269	08068F	PARTICIPANT	\N	PRESENT	0
407375	402269	14357A	PARTICIPANT	\N	PRESENT	0
407376	402269	19479G	PARTICIPANT	\N	PRESENT	0
407377	402269	14249W	PARTICIPANT	\N	PRESENT	0
407379	400644	14261S	PARTICIPANT	\N	PRESENT	0
407380	400644	08043V	PARTICIPANT	\N	EXCUSE	0
407381	400644	14030Q	PRESIDENT	0	PRESENT	0
407382	400644	80013X	PARTICIPANT	\N	EXCUSE	0
407383	400644	19693L	PARTICIPANT	\N	PRESENT	0
407384	400644	19577H	PARTICIPANT	\N	PRESENT	0
407385	400644	14249W	PARTICIPANT	\N	EXCUSE	0
407386	400644	14179A	PARTICIPANT	\N	PRESENT	0
407387	400644	19715Y	PARTICIPANT	\N	PRESENT	0
407388	400644	08031R	PARTICIPANT	\N	EXCUSE	0
407389	400644	07029T	PARTICIPANT	\N	PRESENT	0
407390	400644	11067R	PARTICIPANT	\N	PRESENT	0
393315	378053	19479G	PARTICIPANT	\N	PRESENT	0
393316	378053	19713W	PARTICIPANT	\N	PRESENT	0
393317	378053	14042U	PARTICIPANT	\N	PRESENT	0
393319	378053	14061L	PARTICIPANT	\N	PRESENT	0
393320	378053	14219Q	PARTICIPANT	\N	PRESENT	0
393321	378053	14059S	PARTICIPANT	\N	PRESENT	0
393322	378053	14205J	PARTICIPANT	\N	PRESENT	0
393323	378053	08056B	PARTICIPANT	\N	PRESENT	0
393324	378053	14329V	PARTICIPANT	\N	PRESENT	0
393325	378053	04070G	PARTICIPANT	\N	PRESENT	0
393326	378053	19611R	PARTICIPANT	\N	PRESENT	0
393327	378053	19619A	PARTICIPANT	\N	PRESENT	0
393328	378053	19369B	PARTICIPANT	\N	PRESENT	0
393329	378053	01034P	PARTICIPANT	\N	PRESENT	0
393330	378053	08044W	PARTICIPANT	\N	PRESENT	0
393331	378053	14231L	PARTICIPANT	\N	PRESENT	0
393332	378053	19701S	PARTICIPANT	\N	PRESENT	0
393333	378053	14255U	PARTICIPANT	\N	PRESENT	0
393334	378053	08034U	PARTICIPANT	\N	PRESENT	0
393335	378053	04089T	PARTICIPANT	\N	PRESENT	0
393336	378053	14267Y	PARTICIPANT	\N	PRESENT	0
393337	378053	14083S	PARTICIPANT	\N	PRESENT	0
393348	378053	19335Q	PARTICIPANT	\N	PRESENT	0
393339	378053	14073Q	PARTICIPANT	\N	PRESENT	0
393340	378053	19745F	PARTICIPANT	\N	PRESENT	0
393341	378053	19749K	PARTICIPANT	\N	PRESENT	0
393342	378053	01025N	PARTICIPANT	\N	PRESENT	0
393343	378053	04040A	PARTICIPANT	\N	PRESENT	0
393344	378053	14327T	PARTICIPANT	\N	PRESENT	0
393345	378053	19441R	PARTICIPANT	\N	PRESENT	0
393346	378053	11049P	PARTICIPANT	\N	PRESENT	0
393350	378053	11077T	PARTICIPANT	\N	PRESENT	0
393349	378053	14179A	PARTICIPANT	\N	PRESENT	0
393351	378053	19687N	PARTICIPANT	\N	PRESENT	0
393352	378053	19695N	PARTICIPANT	\N	PRESENT	0
393353	378053	19689Q	PARTICIPANT	\N	PRESENT	0
393354	378053	14249W	PARTICIPANT	\N	PRESENT	0
393355	378053	11043H	PARTICIPANT	\N	PRESENT	0
393362	378053	19387D	PARTICIPANT	\N	PRESENT	0
393360	378053	11048N	PARTICIPANT	\N	PRESENT	0
393359	378053	01057W	PARTICIPANT	\N	PRESENT	0
393361	378053	14055N	PARTICIPANT	\N	PRESENT	0
393363	378053	11109J	PARTICIPANT	\N	PRESENT	0
393364	378053	14253S	PARTICIPANT	\N	PRESENT	0
393365	378053	14030Q	PARTICIPANT	\N	PRESENT	0
393366	378053	14217N	PARTICIPANT	\N	PRESENT	0
393367	378053	08062Y	PARTICIPANT	\N	PRESENT	0
393368	378053	19565D	PARTICIPANT	\N	PRESENT	0
393369	378053	98022P	PARTICIPANT	\N	PRESENT	0
393370	378053	19253P	PARTICIPANT	\N	PRESENT	0
393371	378053	05008E	PARTICIPANT	\N	PRESENT	0
393372	378053	19531S	PARTICIPANT	\N	PRESENT	0
393373	378053	11065P	PARTICIPANT	\N	PRESENT	0
393374	378053	19533U	PARTICIPANT	\N	PRESENT	0
393375	378053	14199E	PARTICIPANT	\N	PRESENT	0
393379	378053	04043D	PARTICIPANT	\N	PRESENT	0
393380	378053	19739H	PARTICIPANT	\N	PRESENT	0
393378	378053	11115U	PARTICIPANT	\N	PRESENT	0
393381	378053	19503N	PARTICIPANT	\N	PRESENT	0
393858	393857	11097X	PARTICIPANT	\N	PRESENT	0
393823	393822	14071N	PARTICIPANT	\N	PRESENT	0
393825	393824	14071N	PARTICIPANT	\N	PRESENT	0
393860	393859	17779H	PARTICIPANT	\N	PRESENT	0
393861	393859	11097X	PARTICIPANT	\N	PRESENT	0
395289	394110	19729F	PARTICIPANT	\N	EXCUSE	0
395340	392897	12041X	PARTICIPANT	\N	PRESENT	0
395341	392897	95030B	PARTICIPANT	\N	PRESENT	0
395342	392897	04040A	PARTICIPANT	\N	PRESENT	0
395343	392897	01058X	PARTICIPANT	\N	PRESENT	0
395344	392897	14079W	PARTICIPANT	\N	PRESENT	0
395345	392897	04042C	PRESIDENT	0	PRESENT	0
395346	392897	11066Q	PARTICIPANT	\N	PRESENT	0
395347	392897	08056B	PARTICIPANT	\N	PRESENT	0
395348	392897	95037J	PARTICIPANT	\N	PRESENT	0
395349	392897	14055N	PARTICIPANT	\N	PRESENT	0
395350	392897	19421M	PARTICIPANT	\N	PRESENT	0
395351	392897	19709B	PARTICIPANT	\N	PRESENT	0
395352	392897	08053X	PARTICIPANT	\N	PRESENT	0
395353	392897	08061X	PARTICIPANT	\N	PRESENT	0
395354	392897	08047A	PARTICIPANT	\N	PRESENT	0
395355	392897	04035D	PARTICIPANT	\N	PRESENT	0
395356	392897	14133K	PARTICIPANT	\N	PRESENT	0
395357	392897	14235Q	PARTICIPANT	\N	PRESENT	0
395358	392897	08058D	PARTICIPANT	\N	PRESENT	0
395359	392897	14028W	PARTICIPANT	\N	PRESENT	0
395360	392897	19251M	PARTICIPANT	\N	PRESENT	0
395361	392897	14105F	PARTICIPANT	\N	PRESENT	0
395362	392897	98018T	PARTICIPANT	\N	PRESENT	0
395363	392897	98022P	PARTICIPANT	\N	PRESENT	0
395364	392897	11064N	PARTICIPANT	\N	PRESENT	0
395365	392897	14267Y	PARTICIPANT	\N	PRESENT	0
395366	392897	98050T	PARTICIPANT	\N	PRESENT	0
395367	392897	14211G	PARTICIPANT	\N	PRESENT	0
395368	392897	14255U	PARTICIPANT	\N	PRESENT	0
395369	394110	14089Y	PARTICIPANT	\N	PRESENT	0
395370	394110	19675J	PARTICIPANT	\N	EXCUSE	0
395371	392413	11090Q	PARTICIPANT	\N	EXCUSE	0
395372	392412	11090Q	PARTICIPANT	\N	EXCUSE	0
395467	392615	19333N	PARTICIPANT	\N	PRESENT	0
395468	392615	80027E	PARTICIPANT	\N	PRESENT	0
395469	392615	11065P	PARTICIPANT	\N	PRESENT	0
395473	393757	14327T	PARTICIPANT	\N	PRESENT	0
395474	393757	04071H	PARTICIPANT	\N	PRESENT	0
395475	393757	14253S	PARTICIPANT	\N	PRESENT	0
395476	393757	19647E	PARTICIPANT	\N	PRESENT	0
395477	393757	08073C	PARTICIPANT	\N	PRESENT	0
395919	378101	14215L	PARTICIPANT	\N	PRESENT	0
395920	378101	05008E	PARTICIPANT	\N	PRESENT	0
395483	378096	11070L	PARTICIPANT	\N	PRESENT	0
395921	378101	19269X	PARTICIPANT	\N	PRESENT	0
395922	378101	19543W	PARTICIPANT	\N	PRESENT	0
395487	378096	14255U	PARTICIPANT	\N	PRESENT	0
395923	378101	19649G	PARTICIPANT	\N	PRESENT	0
395924	378101	14001X	PARTICIPANT	\N	PRESENT	0
395490	378096	08053X	PARTICIPANT	\N	PRESENT	0
395928	378101	19413M	PARTICIPANT	\N	PRESENT	0
395926	378101	19399H	PARTICIPANT	\N	PRESENT	0
395927	378101	14021P	PARTICIPANT	\N	PRESENT	0
395929	378101	11109J	PARTICIPANT	\N	PRESENT	0
395495	378096	14133K	PARTICIPANT	\N	PRESENT	0
395930	378101	19703U	PARTICIPANT	\N	PRESENT	0
395497	378096	14038Y	PARTICIPANT	\N	PRESENT	0
395931	378101	04085P	PARTICIPANT	\N	PRESENT	0
395499	378096	19399H	PARTICIPANT	\N	PRESENT	0
395932	378101	19758L	PARTICIPANT	\N	PRESENT	0
395933	378101	14169X	PARTICIPANT	\N	PRESENT	0
395934	378101	19794Q	PARTICIPANT	\N	PRESENT	0
395935	378101	19629C	PARTICIPANT	\N	PRESENT	0
395936	378101	14265W	PARTICIPANT	\N	PRESENT	0
395937	378101	11012A	PARTICIPANT	\N	PRESENT	0
395938	378101	17589D	PARTICIPANT	\N	PRESENT	0
395939	378101	14041T	PARTICIPANT	\N	PRESENT	0
395940	378101	14079W	PARTICIPANT	\N	PRESENT	0
395509	378096	19441R	PARTICIPANT	\N	PRESENT	0
395941	378101	14033T	PARTICIPANT	\N	PRESENT	0
395511	378096	14215L	PARTICIPANT	\N	PRESENT	0
395942	378101	04047H	PARTICIPANT	\N	PRESENT	0
395943	378101	14053L	PARTICIPANT	\N	PRESENT	0
395944	378101	19709B	PARTICIPANT	\N	PRESENT	0
395945	378101	04088S	PARTICIPANT	\N	PRESENT	0
395946	378101	11097X	PARTICIPANT	\N	PRESENT	0
395947	378101	19447X	PARTICIPANT	\N	PRESENT	0
395957	378101	19711U	PARTICIPANT	\N	PRESENT	0
395958	378101	19593H	PARTICIPANT	\N	PRESENT	0
395959	378101	11048N	PARTICIPANT	\N	PRESENT	0
395960	378101	14083S	PARTICIPANT	\N	PRESENT	0
395961	378101	19503N	PARTICIPANT	\N	PRESENT	0
395535	378096	14041T	PARTICIPANT	\N	PRESENT	0
395536	378096	04088S	PARTICIPANT	\N	PRESENT	0
395538	378096	19794Q	PARTICIPANT	\N	PRESENT	0
395539	378096	19673G	PARTICIPANT	\N	PRESENT	0
395540	378096	01024M	PARTICIPANT	\N	PRESENT	0
395567	378096	14053L	PARTICIPANT	\N	PRESENT	0
395568	378096	14257W	PARTICIPANT	\N	PRESENT	0
395570	378096	19631V	PARTICIPANT	\N	PRESENT	0
395571	395569	14083S	PARTICIPANT	\N	PRESENT	0
395573	378096	14179A	PARTICIPANT	\N	PRESENT	0
395918	378101	04044E	PARTICIPANT	\N	PRESENT	0
411128	406842	19709B	PARTICIPANT	\N	PRESENT	0
411129	406842	14089Y	PARTICIPANT	\N	PRESENT	0
411130	406842	14109K	PARTICIPANT	\N	PRESENT	0
411131	406842	14229S	PARTICIPANT	\N	PRESENT	0
411132	406842	14249W	PARTICIPANT	\N	PRESENT	0
411133	406842	19643A	PARTICIPANT	\N	PRESENT	0
411134	406842	14063N	PARTICIPANT	\N	PRESENT	0
411135	406842	19525U	PARTICIPANT	\N	PRESENT	0
411136	406842	14179A	PARTICIPANT	\N	PRESENT	0
411137	406842	80013X	PARTICIPANT	\N	PRESENT	0
411138	406842	11099A	PARTICIPANT	\N	PRESENT	0
411139	406842	14257W	PARTICIPANT	\N	PRESENT	0
411141	406842	14193X	PARTICIPANT	\N	PRESENT	0
411142	406842	19826F	PARTICIPANT	\N	PRESENT	0
411143	406842	19768N	PARTICIPANT	\N	PRESENT	0
411144	406842	19563B	PARTICIPANT	\N	PRESENT	0
411145	406842	17637T	PARTICIPANT	\N	PRESENT	0
411146	406842	08068F	PARTICIPANT	\N	PRESENT	0
411147	406842	14083S	PARTICIPANT	\N	PRESENT	0
411148	406842	95063L	PARTICIPANT	\N	PRESENT	0
411149	406842	08049C	PARTICIPANT	\N	PRESENT	0
411150	406842	11012A	PARTICIPANT	\N	PRESENT	0
411151	406842	19545Y	PARTICIPANT	\N	PRESENT	0
411152	406842	11103C	PARTICIPANT	\N	PRESENT	0
411153	406842	08069G	PARTICIPANT	\N	PRESENT	0
411154	406842	11110B	PARTICIPANT	\N	PRESENT	0
411155	406842	08038Y	PARTICIPANT	\N	PRESENT	0
411156	406842	19573D	PARTICIPANT	\N	PRESENT	0
411157	406842	19747H	PARTICIPANT	\N	PRESENT	0
411158	406842	19749K	PARTICIPANT	\N	PRESENT	0
411159	406842	19695N	PARTICIPANT	\N	PRESENT	0
411160	406842	04045F	PARTICIPANT	\N	PRESENT	0
411161	406842	08044W	PARTICIPANT	\N	PRESENT	0
411162	406842	14157T	PARTICIPANT	\N	PRESENT	0
411163	406842	11053K	PARTICIPANT	\N	PRESENT	0
411164	406842	14159V	PARTICIPANT	\N	PRESENT	0
411166	406842	11109J	PARTICIPANT	\N	PRESENT	0
411167	406842	19507S	PARTICIPANT	\N	PRESENT	0
411168	406842	14199E	PARTICIPANT	\N	PRESENT	0
411169	406842	10006L	PARTICIPANT	\N	PRESENT	0
411170	406842	01025N	PARTICIPANT	\N	PRESENT	0
411171	406842	11090Q	PARTICIPANT	\N	PRESENT	0
411172	406842	08010L	PARTICIPANT	\N	PRESENT	0
411173	406842	19697Q	PARTICIPANT	\N	PRESENT	0
411174	406842	11067R	PARTICIPANT	\N	PRESENT	0
411178	406842	14026U	PARTICIPANT	\N	PRESENT	0
411181	406842	19251M	PARTICIPANT	\N	PRESENT	0
411210	406842	01060R	PARTICIPANT	\N	PRESENT	0
411211	406842	14205J	PARTICIPANT	\N	PRESENT	0
411212	410912	19253P	PARTICIPANT	\N	EXCUSE	0
411213	406842	19415P	PARTICIPANT	\N	PRESENT	0
411214	406842	04049K	PARTICIPANT	\N	PRESENT	0
411215	406842	19553Y	PARTICIPANT	\N	PRESENT	0
411216	406842	14147R	PARTICIPANT	\N	PRESENT	0
411217	406842	19269X	PARTICIPANT	\N	PRESENT	0
411219	406842	14239U	PARTICIPANT	\N	PRESENT	0
411343	410912	14053L	PARTICIPANT	\N	PRESENT	0
411344	406843	14231L	PARTICIPANT	\N	PRESENT	0
411345	406843	14259Y	PARTICIPANT	\N	PRESENT	0
411346	406843	19489J	PARTICIPANT	\N	PRESENT	0
411347	406843	01028R	PARTICIPANT	\N	PRESENT	0
411348	406843	19599P	PARTICIPANT	\N	PRESENT	0
411349	406843	14197C	PARTICIPANT	\N	PRESENT	0
411350	406843	11109J	PARTICIPANT	\N	PRESENT	0
411351	406843	19503N	PARTICIPANT	\N	PRESENT	0
411352	406843	19782L	PARTICIPANT	\N	PRESENT	0
411353	406843	14207L	PARTICIPANT	\N	PRESENT	0
411354	406843	19269X	PARTICIPANT	\N	PRESENT	0
411355	406843	19543W	PARTICIPANT	\N	PRESENT	0
411356	406843	10015M	PARTICIPANT	\N	PRESENT	0
411357	406843	19349W	PARTICIPANT	\N	PRESENT	0
411358	406843	14087W	PARTICIPANT	\N	PRESENT	0
411359	406843	14239U	PARTICIPANT	\N	PRESENT	0
411360	406843	19585H	PARTICIPANT	\N	PRESENT	0
411361	406843	19673G	PARTICIPANT	\N	PRESENT	0
411362	406843	19719D	PARTICIPANT	\N	PRESENT	0
411363	406843	01057W	PARTICIPANT	\N	PRESENT	0
411364	406843	14327T	PARTICIPANT	\N	PRESENT	0
411365	406843	11048N	PARTICIPANT	\N	PRESENT	0
411366	406843	19737F	PARTICIPANT	\N	PRESENT	0
411367	406843	19575F	PARTICIPANT	\N	PRESENT	0
411368	406843	19611R	PARTICIPANT	\N	PRESENT	0
411369	406843	08009T	PARTICIPANT	\N	PRESENT	0
411370	406843	04069P	PARTICIPANT	\N	PRESENT	0
411371	406843	14265W	PARTICIPANT	\N	PRESENT	0
411372	406843	14191V	PARTICIPANT	\N	PRESENT	0
411377	406843	01025N	PARTICIPANT	\N	PRESENT	0
411374	406843	19521Q	PARTICIPANT	\N	PRESENT	0
411375	406843	19762G	PARTICIPANT	\N	PRESENT	0
411376	406843	14031R	PARTICIPANT	\N	PRESENT	0
411378	406843	19691J	PARTICIPANT	\N	PRESENT	0
411379	406843	19399H	PARTICIPANT	\N	PRESENT	0
411380	406843	14038Y	PARTICIPANT	\N	PRESENT	0
411381	406843	19335Q	PARTICIPANT	\N	PRESENT	0
411382	406843	19413M	PARTICIPANT	\N	PRESENT	0
411383	406843	19581D	PARTICIPANT	\N	PRESENT	0
411384	406843	19421M	PARTICIPANT	\N	PRESENT	0
411385	406843	14083S	PARTICIPANT	\N	PRESENT	0
411386	406843	19723Y	PARTICIPANT	\N	PRESENT	0
411387	406843	19749K	PARTICIPANT	\N	PRESENT	0
411388	406843	19701S	PARTICIPANT	\N	PRESENT	0
411389	406843	14053L	PARTICIPANT	\N	PRESENT	0
411390	406843	14069U	PARTICIPANT	\N	PRESENT	0
411391	406843	14215L	PARTICIPANT	\N	PRESENT	0
411392	406843	08056B	PARTICIPANT	\N	PRESENT	0
411393	406843	18083K	PARTICIPANT	\N	PRESENT	0
411394	406843	11056N	PARTICIPANT	\N	PRESENT	0
411395	406843	14135M	PARTICIPANT	\N	PRESENT	0
411396	406843	11077T	PARTICIPANT	\N	PRESENT	0
411397	406843	19768N	PARTICIPANT	\N	PRESENT	0
411398	406843	11097X	PARTICIPANT	\N	PRESENT	0
411399	406843	14157T	PARTICIPANT	\N	PRESENT	0
411400	406843	14107H	PARTICIPANT	\N	PRESENT	0
411401	406843	19681G	PARTICIPANT	\N	PRESENT	0
411402	406843	19367Y	PARTICIPANT	\N	PRESENT	0
411403	406843	19415P	PARTICIPANT	\N	PRESENT	0
411404	406843	14147R	PARTICIPANT	\N	PRESENT	0
411405	406843	19713W	PARTICIPANT	\N	PRESENT	0
411406	406843	19798U	PARTICIPANT	\N	PRESENT	0
411407	406843	14211G	PARTICIPANT	\N	PRESENT	0
411408	406843	19553Y	PARTICIPANT	\N	PRESENT	0
411409	406843	04049K	PARTICIPANT	\N	PRESENT	0
411410	406843	19794Q	PARTICIPANT	\N	PRESENT	0
411411	406843	19467C	PARTICIPANT	\N	PRESENT	0
411412	406843	05008E	PARTICIPANT	\N	PRESENT	0
411413	406843	14237S	PARTICIPANT	\N	PRESENT	0
411414	406843	14001X	PARTICIPANT	\N	PRESENT	0
411415	406843	14187A	PARTICIPANT	\N	PRESENT	0
411416	406843	19551W	PARTICIPANT	\N	PRESENT	0
411417	406843	04088S	PARTICIPANT	\N	PRESENT	0
411418	406843	19679N	PARTICIPANT	\N	PRESENT	0
411419	406843	08045X	PARTICIPANT	\N	PRESENT	0
411420	406843	14071N	PARTICIPANT	\N	PRESENT	0
411421	406843	14026U	PARTICIPANT	\N	PRESENT	0
411422	406843	11065P	PARTICIPANT	\N	PRESENT	0
411423	406843	19549D	PARTICIPANT	\N	PRESENT	0
411424	406843	14119M	PARTICIPANT	\N	PRESENT	0
411425	406843	19441R	PARTICIPANT	\N	PRESENT	0
411426	406843	04085P	PARTICIPANT	\N	PRESENT	0
411427	406843	05012A	PARTICIPANT	\N	PRESENT	0
411428	406843	08034U	PARTICIPANT	\N	PRESENT	0
411429	406843	19515S	PARTICIPANT	\N	PRESENT	0
411430	406843	04044E	PARTICIPANT	\N	PRESENT	0
411431	406843	19758L	PARTICIPANT	\N	PRESENT	0
411432	406843	04040A	PARTICIPANT	\N	PRESENT	0
411433	406843	04033B	PARTICIPANT	\N	PRESENT	0
411434	406843	19447X	PARTICIPANT	\N	PRESENT	0
411435	406843	14213J	PARTICIPANT	\N	PRESENT	0
411436	406843	14251Q	PARTICIPANT	\N	PRESENT	0
411437	406843	19479G	PARTICIPANT	\N	PRESENT	0
411438	406843	11043H	PARTICIPANT	\N	PRESENT	0
411326	406843	11072N	PARTICIPANT	\N	PRESENT	0
411327	410912	10015M	PARTICIPANT	\N	PRESENT	0
411328	410912	14001X	PARTICIPANT	\N	PRESENT	0
411329	410912	19543W	PARTICIPANT	\N	PRESENT	0
411330	410912	19585H	PARTICIPANT	\N	PRESENT	0
411331	410912	19719D	PARTICIPANT	\N	PRESENT	0
411332	410912	19673G	PARTICIPANT	\N	PRESENT	0
411333	410912	01028R	PARTICIPANT	\N	PRESENT	0
411334	410912	05008E	PRESIDENT	0	PRESENT	0
411335	410912	14231L	PARTICIPANT	\N	PRESENT	0
411336	410912	19489J	PARTICIPANT	\N	PRESENT	0
411337	410912	14147R	PARTICIPANT	\N	PRESENT	0
411338	410912	14179A	PARTICIPANT	\N	PRESENT	0
411339	410912	14069U	PARTICIPANT	\N	PRESENT	0
411340	410912	14215L	PARTICIPANT	\N	PRESENT	0
411341	410912	14259Y	PARTICIPANT	\N	PRESENT	0
411342	410912	19762G	PARTICIPANT	\N	PRESENT	0
394203	394081	19631V	PARTICIPANT	\N	PRESENT	0
394204	394081	19421M	PARTICIPANT	\N	PRESENT	0
394205	394081	14229S	PARTICIPANT	\N	PRESENT	0
395102	392615	17583W	PARTICIPANT	\N	PRESENT	0
395103	392615	14103D	PARTICIPANT	\N	PRESENT	0
395104	392615	14169X	PARTICIPANT	\N	PRESENT	0
395105	392615	19551W	PARTICIPANT	\N	PRESENT	0
395106	392615	14029X	PARTICIPANT	\N	PRESENT	0
395107	392615	19503N	PARTICIPANT	\N	PRESENT	0
395108	392615	19347U	PARTICIPANT	\N	PRESENT	0
395109	392615	15447F	PARTICIPANT	\N	PRESENT	0
395110	392615	02002K	PARTICIPANT	\N	EXCUSE	0
395111	392896	04035D	PARTICIPANT	\N	PRESENT	0
395112	392896	12041X	PARTICIPANT	\N	PRESENT	0
395113	392896	14133K	PARTICIPANT	\N	PRESENT	0
395114	392896	95030B	PARTICIPANT	\N	PRESENT	0
395115	392896	14235Q	PARTICIPANT	\N	PRESENT	0
395116	392896	04040A	PARTICIPANT	\N	PRESENT	0
395117	392896	01058X	PARTICIPANT	\N	PRESENT	0
395118	392896	08058D	PARTICIPANT	\N	PRESENT	0
395119	392896	04042C	PRESIDENT	0	PRESENT	0
395120	392896	14028W	PARTICIPANT	\N	PRESENT	0
395121	392896	11066Q	PARTICIPANT	\N	PRESENT	0
395122	392896	08056B	PARTICIPANT	\N	PRESENT	0
395123	392896	95037J	PARTICIPANT	\N	PRESENT	0
395124	392896	98018T	PARTICIPANT	\N	PRESENT	0
395125	392896	19421M	PARTICIPANT	\N	PRESENT	0
395126	392896	19709B	PARTICIPANT	\N	PRESENT	0
395127	392896	98022P	PARTICIPANT	\N	PRESENT	0
395128	392896	11064N	PARTICIPANT	\N	PRESENT	0
395129	392896	14267Y	PARTICIPANT	\N	PRESENT	0
395130	392896	98050T	PARTICIPANT	\N	PRESENT	0
395131	392896	14211G	PARTICIPANT	\N	PRESENT	0
395132	392896	08047A	PARTICIPANT	\N	PRESENT	0
395133	392896	14255U	PARTICIPANT	\N	PRESENT	0
395134	392615	14237S	PARTICIPANT	\N	PRESENT	0
395135	392615	04097T	PARTICIPANT	\N	PRESENT	0
395136	392896	08053X	PARTICIPANT	\N	PRESENT	0
395137	392896	19251M	PARTICIPANT	\N	PRESENT	0
395138	392896	14105F	PARTICIPANT	\N	PRESENT	0
395186	391635	11045K	PARTICIPANT	\N	PRESENT	0
395187	391635	14071N	PARTICIPANT	\N	PRESENT	0
395290	392412	19441R	PARTICIPANT	\N	PRESENT	0
395291	392412	14207L	PARTICIPANT	\N	PRESENT	0
395292	392413	19768N	PARTICIPANT	\N	PRESENT	0
395293	392413	19515S	PARTICIPANT	\N	PRESENT	0
395294	392413	19782L	PARTICIPANT	\N	PRESENT	0
395295	392413	14357A	PARTICIPANT	\N	PRESENT	0
395296	392413	19441R	PARTICIPANT	\N	PRESENT	0
395297	392413	19413M	PARTICIPANT	\N	PRESENT	0
395298	392413	14081Q	PARTICIPANT	\N	PRESENT	0
395299	392413	80013X	PARTICIPANT	\N	PRESENT	0
395300	392413	19631V	PARTICIPANT	\N	PRESENT	0
395301	392413	08021P	PARTICIPANT	\N	PRESENT	0
395302	392413	11099A	PARTICIPANT	\N	PRESENT	0
395303	392413	04049K	PRESIDENT	0	PRESENT	0
395304	392413	19705W	PARTICIPANT	\N	PRESENT	0
395305	392413	08015R	PARTICIPANT	\N	PRESENT	0
395306	392413	08019V	PARTICIPANT	\N	PRESENT	0
395307	392413	14197C	PARTICIPANT	\N	PRESENT	0
395308	392413	19369B	PARTICIPANT	\N	PRESENT	0
395309	392413	19511N	PARTICIPANT	\N	PRESENT	0
395310	392413	08028W	PARTICIPANT	\N	PRESENT	0
395311	392413	19563B	PARTICIPANT	\N	PRESENT	0
395312	392413	14265W	PARTICIPANT	\N	PRESENT	0
395313	392413	14135M	PARTICIPANT	\N	PRESENT	0
395314	392413	19467C	PARTICIPANT	\N	PRESENT	0
395315	392413	14187A	PARTICIPANT	\N	PRESENT	0
395316	392413	08038Y	PARTICIPANT	\N	PRESENT	0
395317	392413	08062Y	PARTICIPANT	\N	PRESENT	0
395318	392413	19695N	PARTICIPANT	\N	PRESENT	0
395319	392413	01025N	PARTICIPANT	\N	PRESENT	0
395320	392413	14033T	PARTICIPANT	\N	PRESENT	0
395321	392413	19295A	PARTICIPANT	\N	PRESENT	0
395322	392413	19269X	PARTICIPANT	\N	PRESENT	0
395323	392413	14205J	PARTICIPANT	\N	PRESENT	0
395324	392413	04088S	PARTICIPANT	\N	PRESENT	0
395325	392413	14115H	PARTICIPANT	\N	PRESENT	0
395326	392413	19507S	PARTICIPANT	\N	PRESENT	0
395327	392413	19747H	PARTICIPANT	\N	PRESENT	0
395328	392413	14207L	PARTICIPANT	\N	PRESENT	0
395329	392413	04043D	PARTICIPANT	\N	PRESENT	0
395330	392413	19619A	PARTICIPANT	\N	PRESENT	0
395331	392413	14257W	PARTICIPANT	\N	PRESENT	0
395332	392413	08068F	PARTICIPANT	\N	EXCUSE	0
395333	392413	01043Q	PARTICIPANT	\N	EXCUSE	0
395334	392413	11081P	PARTICIPANT	\N	EXCUSE	0
395335	392413	17589D	PARTICIPANT	\N	EXCUSE	0
395336	392413	19591F	PARTICIPANT	\N	EXCUSE	0
395337	393757	14199E	PARTICIPANT	\N	PRESENT	0
395338	393757	11070L	PARTICIPANT	\N	PRESENT	0
395339	392896	14079W	PARTICIPANT	\N	PRESENT	0
395373	394111	98035U	PARTICIPANT	\N	PRESENT	0
395374	394111	14089Y	PARTICIPANT	\N	PRESENT	0
395375	394111	19725B	PARTICIPANT	\N	PRESENT	0
395376	394111	14065Q	PARTICIPANT	\N	PRESENT	0
395377	394111	08044W	PARTICIPANT	\N	PRESENT	0
395378	394111	01024M	PARTICIPANT	\N	PRESENT	0
395379	394111	08018U	PARTICIPANT	\N	PRESENT	0
395380	394111	04047H	PARTICIPANT	\N	PRESENT	0
395381	394111	01028R	PARTICIPANT	\N	PRESENT	0
395382	394111	05008E	PRESIDENT	0	PRESENT	0
395383	394111	14041T	PARTICIPANT	\N	PRESENT	0
395384	394111	08045X	PARTICIPANT	\N	PRESENT	0
395385	394111	11026G	PARTICIPANT	\N	PRESENT	0
395386	394111	14147R	PARTICIPANT	\N	PRESENT	0
395387	394111	14179A	PARTICIPANT	\N	PRESENT	0
395388	394111	11085T	PARTICIPANT	\N	PRESENT	0
395389	394111	14215L	PARTICIPANT	\N	PRESENT	0
395390	394111	19447X	PARTICIPANT	\N	PRESENT	0
395391	394111	19729F	PARTICIPANT	\N	EXCUSE	0
395392	394111	19585H	PARTICIPANT	\N	EXCUSE	0
395393	394111	19675J	PARTICIPANT	\N	EXCUSE	0
395687	378098	18083K	PARTICIPANT	\N	PRESENT	0
395688	378098	19467C	PARTICIPANT	\N	PRESENT	0
395689	378098	19794Q	PARTICIPANT	\N	PRESENT	0
395690	378098	19447X	PARTICIPANT	\N	PRESENT	0
395691	378098	19673G	PARTICIPANT	\N	PRESENT	0
395692	391636	19697Q	PARTICIPANT	\N	PRESENT	0
395693	391636	01034P	PARTICIPANT	\N	PRESENT	0
395694	391636	11067R	PARTICIPANT	\N	PRESENT	0
395695	391636	04092N	PRESIDENT	0	PRESENT	0
395696	391636	19565D	PARTICIPANT	\N	PRESENT	0
395697	391636	08052W	PARTICIPANT	\N	PRESENT	0
395698	391636	19691J	PARTICIPANT	\N	PRESENT	0
395699	391636	04045F	PARTICIPANT	\N	PRESENT	0
395700	391636	19717B	PARTICIPANT	\N	PRESENT	0
395701	391636	17779H	PARTICIPANT	\N	PRESENT	0
395702	391636	11031D	PARTICIPANT	\N	PRESENT	0
395703	391636	19553Y	PARTICIPANT	\N	PRESENT	0
395704	391636	19703U	PARTICIPANT	\N	PRESENT	0
395705	391636	19727D	PARTICIPANT	\N	PRESENT	0
395706	391636	14119M	PARTICIPANT	\N	PRESENT	0
395707	391636	11103C	PARTICIPANT	\N	PRESENT	0
395708	391636	14042U	PARTICIPANT	\N	PRESENT	0
395709	391636	19575F	PARTICIPANT	\N	PRESENT	0
395710	391636	14213J	PARTICIPANT	\N	PRESENT	0
395711	391636	14217N	PARTICIPANT	\N	PRESENT	0
395712	391636	19521Q	PARTICIPANT	\N	PRESENT	0
395713	378098	87003B	PARTICIPANT	\N	PRESENT	0
395714	378098	14205J	PARTICIPANT	\N	PRESENT	0
395715	378098	14267Y	PARTICIPANT	\N	PRESENT	0
395716	378098	14063N	PARTICIPANT	\N	PRESENT	0
395717	378098	19251M	PARTICIPANT	\N	PRESENT	0
395718	378098	14038Y	PARTICIPANT	\N	PRESENT	0
395719	378098	11033F	PARTICIPANT	\N	PRESENT	0
395721	391636	11097X	PARTICIPANT	\N	PRESENT	0
395722	391636	19415P	PARTICIPANT	\N	PRESENT	0
395723	391636	14026U	PARTICIPANT	\N	PRESENT	0
395724	391636	14087W	PARTICIPANT	\N	PRESENT	0
395725	391636	14195A	PARTICIPANT	\N	PRESENT	0
395726	391636	14261S	PARTICIPANT	\N	PRESENT	0
395727	391636	98024R	PARTICIPANT	\N	PRESENT	0
395728	391636	14355X	PARTICIPANT	\N	EXCUSE	0
395729	391636	08041T	PARTICIPANT	\N	EXCUSE	0
395730	393770	19479G	PARTICIPANT	\N	PRESENT	0
395731	393770	11048N	PARTICIPANT	\N	PRESENT	0
395732	393770	19711U	PARTICIPANT	\N	PRESENT	0
395733	393770	01048V	PARTICIPANT	\N	PRESENT	0
395734	393770	19545Y	PARTICIPANT	\N	PRESENT	0
395735	393770	19667J	PARTICIPANT	\N	PRESENT	0
395736	393770	08011M	PARTICIPANT	\N	PRESENT	0
395737	393770	08014Q	PARTICIPANT	\N	PRESENT	0
395738	393770	14034U	PARTICIPANT	\N	PRESENT	0
395739	393770	14173T	PARTICIPANT	\N	PRESENT	0
395740	393770	11040E	PARTICIPANT	\N	PRESENT	0
395741	393770	14083S	PARTICIPANT	\N	PRESENT	0
395742	393770	11012A	PARTICIPANT	\N	PRESENT	0
395743	393770	14085U	PARTICIPANT	\N	PRESENT	0
407392	405392	19768N	PARTICIPANT	\N	PRESENT	0
407393	405392	19515S	PARTICIPANT	\N	PRESENT	0
407394	405392	14357A	PARTICIPANT	\N	PRESENT	0
407395	405392	19441R	PARTICIPANT	\N	PRESENT	0
407396	405392	19413M	PARTICIPANT	\N	PRESENT	0
407397	405392	14081Q	PARTICIPANT	\N	PRESENT	0
407398	405392	80013X	PARTICIPANT	\N	PRESENT	0
407399	405392	19631V	PARTICIPANT	\N	PRESENT	0
407400	405392	08068F	PARTICIPANT	\N	PRESENT	0
407401	405392	19705W	PARTICIPANT	\N	PRESENT	0
407402	405392	08015R	PARTICIPANT	\N	PRESENT	0
407403	405392	14197C	PARTICIPANT	\N	PRESENT	0
407404	405392	19563B	PARTICIPANT	\N	PRESENT	0
407405	405392	14265W	PARTICIPANT	\N	PRESENT	0
407406	405392	14329V	PARTICIPANT	\N	PRESENT	0
407407	405392	14135M	PARTICIPANT	\N	PRESENT	0
407408	405392	19467C	PARTICIPANT	\N	PRESENT	0
407409	405392	14187A	PARTICIPANT	\N	PRESENT	0
407410	405392	19695N	PARTICIPANT	\N	PRESENT	0
407411	405392	11090Q	PRESIDENT	0	PRESENT	0
407412	405392	14033T	PARTICIPANT	\N	PRESENT	0
407413	405392	04088S	PARTICIPANT	\N	PRESENT	0
407414	405392	11056N	PARTICIPANT	\N	PRESENT	0
407415	405392	19747H	PARTICIPANT	\N	PRESENT	0
407416	405392	19619A	PARTICIPANT	\N	PRESENT	0
407419	405188	11027H	PARTICIPANT	\N	PRESENT	0
407422	405392	04049K	PARTICIPANT	\N	PRESENT	0
407423	405393	14135M	PARTICIPANT	\N	PRESENT	0
407424	405393	19768N	PARTICIPANT	\N	PRESENT	0
407425	405393	19467C	PARTICIPANT	\N	PRESENT	0
407426	405393	19515S	PARTICIPANT	\N	PRESENT	0
407427	405393	14357A	PARTICIPANT	\N	PRESENT	0
407428	405393	14187A	PARTICIPANT	\N	PRESENT	0
407429	405393	19441R	PARTICIPANT	\N	PRESENT	0
407430	405393	19413M	PARTICIPANT	\N	PRESENT	0
407431	405393	14081Q	PARTICIPANT	\N	PRESENT	0
407432	405393	19695N	PARTICIPANT	\N	PRESENT	0
407433	405393	11090Q	PRESIDENT	0	PRESENT	0
407434	405393	14033T	PARTICIPANT	\N	PRESENT	0
407435	405393	04088S	PARTICIPANT	\N	PRESENT	0
407436	405393	11056N	PARTICIPANT	\N	PRESENT	0
407437	405393	19705W	PARTICIPANT	\N	PRESENT	0
407438	405393	08015R	PARTICIPANT	\N	PRESENT	0
407439	405393	19747H	PARTICIPANT	\N	PRESENT	0
407440	405393	14265W	PARTICIPANT	\N	PRESENT	0
407441	405393	19619A	PARTICIPANT	\N	PRESENT	0
407442	405393	14329V	PARTICIPANT	\N	PRESENT	0
407443	405393	08068F	PARTICIPANT	\N	PRESENT	0
407444	405393	04049K	PARTICIPANT	\N	PRESENT	0
407445	405393	14197C	PARTICIPANT	\N	PRESENT	0
407446	405393	80013X	PARTICIPANT	\N	PRESENT	0
407447	405393	19631V	PARTICIPANT	\N	PRESENT	0
407448	405393	19563B	PARTICIPANT	\N	PRESENT	0
407451	407450	19711U	PARTICIPANT	\N	PRESENT	0
407452	407450	01048V	PARTICIPANT	\N	PRESENT	0
407453	407450	07033P	PARTICIPANT	\N	PRESENT	0
407454	407450	98050T	PARTICIPANT	\N	PRESENT	0
407455	407450	04088S	PARTICIPANT	\N	PRESENT	0
407456	407450	19766L	PARTICIPANT	\N	PRESENT	0
407459	407450	08015R	PARTICIPANT	\N	PRESENT	0
407483	405188	19563B	PARTICIPANT	\N	PRESENT	0
407484	405188	19725B	PARTICIPANT	\N	PRESENT	0
407485	405188	19689Q	PARTICIPANT	\N	PRESENT	0
407486	405188	14179A	PARTICIPANT	\N	PRESENT	0
407487	405188	19758L	PARTICIPANT	\N	PRESENT	0
407488	405188	11090Q	PARTICIPANT	\N	PRESENT	0
407489	405188	14033T	PARTICIPANT	\N	PRESENT	0
407490	405188	14357A	PARTICIPANT	\N	PRESENT	0
407491	405188	19711U	PARTICIPANT	\N	PRESENT	0
407504	405188	11056N	PARTICIPANT	\N	PRESENT	0
407493	405188	19667J	PARTICIPANT	\N	PRESENT	0
407494	405188	04088S	PARTICIPANT	\N	PRESENT	0
407495	405188	19333N	PARTICIPANT	\N	PRESENT	0
407496	405188	11033F	PARTICIPANT	\N	PRESENT	0
407497	405188	14219Q	PARTICIPANT	\N	PRESENT	0
407498	405188	19515S	PARTICIPANT	\N	PRESENT	0
407499	405188	19619A	PARTICIPANT	\N	PRESENT	0
407500	405188	19733B	PARTICIPANT	\N	PRESENT	0
407501	405188	19663E	PARTICIPANT	\N	PRESENT	0
407502	405188	19421M	PARTICIPANT	\N	PRESENT	0
407503	405188	19695N	PARTICIPANT	\N	PRESENT	0
407505	405188	80013X	PARTICIPANT	\N	PRESENT	0
407506	405188	19503N	PARTICIPANT	\N	PRESENT	0
407507	405188	19699S	PARTICIPANT	\N	PRESENT	0
407508	405188	14217N	PARTICIPANT	\N	PRESENT	0
407509	405188	14069U	PARTICIPANT	\N	PRESENT	0
407510	405188	19671E	PARTICIPANT	\N	PRESENT	0
407511	405188	08055A	PARTICIPANT	\N	PRESENT	0
407512	405188	19631V	PARTICIPANT	\N	PRESENT	0
407513	405188	14197C	PARTICIPANT	\N	PRESENT	0
407514	405188	11065P	PARTICIPANT	\N	PRESENT	0
407515	405188	14135M	PARTICIPANT	\N	PRESENT	0
407516	405188	19747H	PARTICIPANT	\N	PRESENT	0
407517	405188	19399H	PARTICIPANT	\N	PRESENT	0
407518	405188	19269X	PARTICIPANT	\N	PRESENT	0
407519	405188	14041T	PARTICIPANT	\N	PRESENT	0
407520	405188	11012A	PARTICIPANT	\N	PRESENT	0
407521	405188	19629C	PARTICIPANT	\N	PRESENT	0
407522	405188	19693L	PARTICIPANT	\N	PRESENT	0
407523	405188	14157T	PARTICIPANT	\N	PRESENT	0
407524	405188	19731Y	PARTICIPANT	\N	PRESENT	0
407525	405188	97011G	PARTICIPANT	\N	PRESENT	0
407526	405188	11048N	PARTICIPANT	\N	PRESENT	0
407527	405188	19739H	PARTICIPANT	\N	PRESENT	0
407528	405188	07029T	PARTICIPANT	\N	PRESENT	0
407529	405188	19760E	PARTICIPANT	\N	PRESENT	0
407530	405188	19467C	PARTICIPANT	\N	PRESENT	0
407531	407179	19701S	PARTICIPANT	\N	PRESENT	0
407532	407179	08009T	PRESIDENT	0	PRESENT	0
407534	407179	14051J	PARTICIPANT	\N	EXCUSE	0
407535	407179	08060W	PARTICIPANT	\N	EXCUSE	0
407536	407179	19681G	PARTICIPANT	\N	EXCUSE	0
407567	407179	14219Q	PARTICIPANT	\N	PRESENT	0
407568	407179	19347U	PARTICIPANT	\N	PRESENT	0
407569	407179	19713W	PARTICIPANT	\N	PRESENT	0
407570	407179	19551W	PARTICIPANT	\N	PRESENT	0
407571	407179	14205J	PARTICIPANT	\N	PRESENT	0
407572	407179	19733B	PARTICIPANT	\N	PRESENT	0
407592	405188	19479G	PARTICIPANT	\N	PRESENT	0
407680	405417	14261S	PARTICIPANT	\N	PRESENT	0
407681	405417	19329S	PARTICIPANT	\N	PRESENT	0
407682	405417	19715Y	PARTICIPANT	\N	PRESENT	0
407683	405417	14059S	PARTICIPANT	\N	PRESENT	0
407684	405417	12016W	PARTICIPANT	\N	PRESENT	0
407685	405417	19319Q	PARTICIPANT	\N	PRESENT	0
407686	405417	08019V	PARTICIPANT	\N	PRESENT	0
408191	408189	14053L	PARTICIPANT	\N	PRESENT	0
408192	408189	98035U	PARTICIPANT	\N	PRESENT	0
408193	408189	14111D	PARTICIPANT	\N	PRESENT	0
408194	408189	19253P	PARTICIPANT	\N	PRESENT	0
408195	408189	01024M	PARTICIPANT	\N	PRESENT	0
408196	408189	19585H	PARTICIPANT	\N	PRESENT	0
408197	408189	01028R	PARTICIPANT	\N	PRESENT	0
408198	408189	11033F	PARTICIPANT	\N	PRESENT	0
408199	408189	14231L	PARTICIPANT	\N	PRESENT	0
408200	408189	19447X	PARTICIPANT	\N	PRESENT	0
408201	408189	05008E	PRESIDENT	0	PRESENT	0
408202	408189	14089Y	PARTICIPANT	\N	PRESENT	0
408203	408189	95063L	PARTICIPANT	\N	PRESENT	0
408204	408189	14041T	PARTICIPANT	\N	PRESENT	0
408205	408189	08044W	PARTICIPANT	\N	PRESENT	0
408206	408189	14179A	PARTICIPANT	\N	PRESENT	0
408207	408189	14147R	PARTICIPANT	\N	PRESENT	0
408208	408189	14069U	PARTICIPANT	\N	PRESENT	0
408209	408189	14215L	PARTICIPANT	\N	PRESENT	0
408210	408189	19762G	PARTICIPANT	\N	PRESENT	0
408211	408189	11072N	PARTICIPANT	\N	PRESENT	0
408212	408189	19729F	PARTICIPANT	\N	EXCUSE	0
408213	408189	04044E	PARTICIPANT	\N	EXCUSE	0
408214	408189	04047H	PARTICIPANT	\N	EXCUSE	0
408215	402273	11070L	PARTICIPANT	\N	PRESENT	0
408220	402273	19367Y	PARTICIPANT	\N	PRESENT	0
408218	402273	19295A	PARTICIPANT	\N	PRESENT	0
408219	402273	14033T	PARTICIPANT	\N	PRESENT	0
408221	402273	08069G	PARTICIPANT	\N	PRESENT	0
408222	402273	11090Q	PARTICIPANT	\N	PRESENT	0
408223	402273	19657G	PARTICIPANT	\N	PRESENT	0
408224	402273	19581D	PARTICIPANT	\N	PRESENT	0
408225	402273	19583F	PARTICIPANT	\N	PRESENT	0
408226	402273	19507S	PARTICIPANT	\N	PRESENT	0
408227	402273	15447F	PARTICIPANT	\N	PRESENT	0
408228	402273	19515S	PARTICIPANT	\N	PRESENT	0
408230	402273	19333N	PARTICIPANT	\N	PRESENT	0
408231	402273	08014Q	PARTICIPANT	\N	PRESENT	0
408232	402273	19794Q	PARTICIPANT	\N	PRESENT	0
408233	402273	18083K	PARTICIPANT	\N	PRESENT	0
408234	402273	14157T	PARTICIPANT	\N	PRESENT	0
408235	402273	11103C	PARTICIPANT	\N	PRESENT	0
408236	402273	19383Y	PARTICIPANT	\N	PRESENT	0
395997	378104	14001X	PARTICIPANT	\N	PRESENT	0
395998	378104	04085P	PARTICIPANT	\N	PRESENT	0
395576	378096	19693L	PARTICIPANT	\N	PRESENT	0
395999	378104	14215L	PARTICIPANT	\N	PRESENT	0
395578	378096	17589D	PARTICIPANT	\N	PRESENT	0
396000	378104	19693L	PARTICIPANT	\N	PRESENT	0
396001	378104	19758L	PARTICIPANT	\N	PRESENT	0
396002	378104	11043H	PARTICIPANT	\N	PRESENT	0
395582	378096	11012A	PARTICIPANT	\N	PRESENT	0
396003	378104	14021P	PARTICIPANT	\N	PRESENT	0
396004	378104	19629C	PARTICIPANT	\N	PRESENT	0
396005	378104	19447X	PARTICIPANT	\N	PRESENT	0
395586	378096	19703U	PARTICIPANT	\N	PRESENT	0
395587	378096	14021P	PARTICIPANT	\N	PRESENT	0
395588	378096	14205J	PARTICIPANT	\N	PRESENT	0
396006	378104	14231L	PARTICIPANT	\N	PRESENT	0
396007	378104	11109J	PARTICIPANT	\N	PRESENT	0
396008	378104	14053L	PARTICIPANT	\N	PRESENT	0
396009	378104	14042U	PARTICIPANT	\N	PRESENT	0
396010	378104	19543W	PARTICIPANT	\N	PRESENT	0
396011	378104	08061X	PARTICIPANT	\N	PRESENT	0
395596	395594	14173T	PARTICIPANT	\N	PRESENT	0
396012	378104	19295A	PARTICIPANT	\N	PRESENT	0
396013	378104	14061L	PARTICIPANT	\N	PRESENT	0
396014	378104	05008E	PARTICIPANT	\N	PRESENT	0
396015	378104	14265W	PARTICIPANT	\N	PRESENT	0
395601	392653	19725B	PRESIDENT	0	PRESENT	0
395602	392653	04057K	PARTICIPANT	\N	PRESENT	0
395603	392653	08073C	PARTICIPANT	\N	PRESENT	0
395604	392653	19441R	PARTICIPANT	\N	PRESENT	0
395605	392653	19747H	PARTICIPANT	\N	PRESENT	0
395606	392653	08014Q	PARTICIPANT	\N	PRESENT	0
395607	392653	19295A	PARTICIPANT	\N	PRESENT	0
395608	392653	14026U	PARTICIPANT	\N	EXCUSE	0
396016	378104	19593H	PARTICIPANT	\N	PRESENT	0
396017	378104	19695N	PARTICIPANT	\N	PRESENT	0
395611	378096	14265W	PARTICIPANT	\N	PRESENT	0
395667	378098	19593H	PARTICIPANT	\N	PRESENT	0
395668	378098	19333N	PARTICIPANT	\N	PRESENT	0
395669	378098	17589D	PARTICIPANT	\N	PRESENT	0
395670	378098	19563B	PARTICIPANT	\N	PRESENT	0
395671	378098	19479G	PARTICIPANT	\N	PRESENT	0
395672	378098	19713W	PARTICIPANT	\N	PRESENT	0
395673	378098	19739H	PARTICIPANT	\N	PRESENT	0
395674	378098	14255U	PARTICIPANT	\N	PRESENT	0
395675	378098	14061L	PARTICIPANT	\N	PRESENT	0
395676	378098	14133K	PARTICIPANT	\N	PRESENT	0
395677	378098	04043D	PARTICIPANT	\N	PRESENT	0
395678	378098	08053X	PARTICIPANT	\N	PRESENT	0
395679	378098	19631V	PARTICIPANT	\N	PRESENT	0
395680	378098	19269X	PARTICIPANT	\N	PRESENT	0
395681	378098	08015R	PARTICIPANT	\N	PRESENT	0
395682	378098	04088S	PARTICIPANT	\N	PRESENT	0
395683	378098	14265W	PARTICIPANT	\N	PRESENT	0
395684	378098	14041T	PARTICIPANT	\N	PRESENT	0
395685	378098	19693L	PARTICIPANT	\N	PRESENT	0
395686	378098	19507S	PARTICIPANT	\N	PRESENT	0
395789	378098	14219Q	PARTICIPANT	\N	PRESENT	0
395795	378098	04040A	PARTICIPANT	\N	PRESENT	0
395791	378098	19399H	PARTICIPANT	\N	PRESENT	0
395793	378098	14079W	PARTICIPANT	\N	PRESENT	0
395798	378098	14033T	PARTICIPANT	\N	PRESENT	0
395804	378098	04047H	PARTICIPANT	\N	PRESENT	0
395806	378098	14169X	PARTICIPANT	\N	PRESENT	0
395814	378098	14215L	PARTICIPANT	\N	PRESENT	0
395815	378098	14001X	PARTICIPANT	\N	PRESENT	0
395833	378098	19703U	PARTICIPANT	\N	PRESENT	0
395834	378098	14021P	PARTICIPANT	\N	PRESENT	0
395835	378098	19649G	PARTICIPANT	\N	PRESENT	0
395836	378098	11109J	PARTICIPANT	\N	PRESENT	0
395837	378098	19709B	PARTICIPANT	\N	PRESENT	0
395995	378104	14179A	PARTICIPANT	\N	PRESENT	0
395996	378104	19413M	PARTICIPANT	\N	PRESENT	0
396018	378104	17637T	PARTICIPANT	\N	PRESENT	0
396019	378104	14217N	PARTICIPANT	\N	PRESENT	0
396020	378104	14033T	PARTICIPANT	\N	PRESENT	0
396021	378104	19747H	PARTICIPANT	\N	PRESENT	0
396022	378104	14135M	PARTICIPANT	\N	PRESENT	0
396023	378104	19709B	PARTICIPANT	\N	PRESENT	0
396024	378104	08020N	PARTICIPANT	\N	PRESENT	0
396025	378104	08069G	PARTICIPANT	\N	PRESENT	0
396026	378104	14083S	PARTICIPANT	\N	PRESENT	0
396027	378104	14187A	PARTICIPANT	\N	PRESENT	0
396028	378104	08031R	PARTICIPANT	\N	PRESENT	0
396029	378104	14026U	PARTICIPANT	\N	PRESENT	0
396030	378104	04086Q	PARTICIPANT	\N	PRESENT	0
396031	378104	04047H	PARTICIPANT	\N	PRESENT	0
396032	378104	08012N	PARTICIPANT	\N	PRESENT	0
396033	378104	14213J	PARTICIPANT	\N	PRESENT	0
396034	378104	14219Q	PARTICIPANT	\N	PRESENT	0
395665	378098	11070L	PARTICIPANT	\N	PRESENT	0
395666	378098	04038G	PARTICIPANT	\N	PRESENT	0
396284	396283	14033T	PARTICIPANT	\N	PRESENT	0
396285	396283	19369B	PARTICIPANT	\N	PRESENT	0
396287	396286	14033T	PARTICIPANT	\N	PRESENT	0
396288	396286	19369B	PARTICIPANT	\N	PRESENT	0
396289	396286	04049K	PARTICIPANT	\N	PRESENT	0
396290	396286	14265W	PARTICIPANT	\N	PRESENT	0
396292	396291	14033T	PARTICIPANT	\N	PRESENT	0
396440	396439	14026U	PARTICIPANT	\N	PRESENT	0
396441	396439	19717B	PARTICIPANT	\N	PRESENT	0
396443	396442	14026U	PARTICIPANT	\N	PRESENT	0
396444	396442	19717B	PARTICIPANT	\N	PRESENT	0
396450	396449	14026U	PARTICIPANT	\N	PRESENT	0
396451	396449	19717B	PARTICIPANT	\N	PRESENT	0
396455	396454	19611R	PARTICIPANT	\N	PRESENT	0
396456	396454	14107H	PARTICIPANT	\N	PRESENT	0
396457	396454	08043V	PARTICIPANT	\N	PRESENT	0
396459	396458	14107H	PARTICIPANT	\N	PRESENT	0
396460	396458	19611R	PARTICIPANT	\N	PRESENT	0
396462	396458	08043V	PARTICIPANT	\N	PRESENT	0
396464	396463	19611R	PARTICIPANT	\N	PRESENT	0
396465	396463	14107H	PARTICIPANT	\N	PRESENT	0
396466	396463	08043V	PARTICIPANT	\N	PRESENT	0
396467	396463	19533U	PARTICIPANT	\N	PRESENT	0
396470	396469	19611R	PARTICIPANT	\N	PRESENT	0
396471	396469	14107H	PARTICIPANT	\N	PRESENT	0
396473	396472	19758L	PARTICIPANT	\N	PRESENT	0
396474	396472	14107H	PARTICIPANT	\N	PRESENT	0
396475	396472	19611R	PARTICIPANT	\N	PRESENT	0
396477	396476	19611R	PARTICIPANT	\N	PRESENT	0
396478	396476	14107H	PARTICIPANT	\N	PRESENT	0
396480	396479	19611R	PARTICIPANT	\N	PRESENT	0
396481	396479	14107H	PARTICIPANT	\N	PRESENT	0
396484	396483	19611R	PARTICIPANT	\N	PRESENT	0
395890	378096	19593H	PARTICIPANT	\N	PRESENT	0
395891	378096	19333N	PARTICIPANT	\N	PRESENT	0
395892	378096	19713W	PARTICIPANT	\N	PRESENT	0
395893	378096	04043D	PARTICIPANT	\N	PRESENT	0
395894	378096	19269X	PARTICIPANT	\N	PRESENT	0
395895	378096	19549D	PARTICIPANT	\N	PRESENT	0
395896	378096	08058D	PARTICIPANT	\N	PRESENT	0
395897	378096	19747H	PARTICIPANT	\N	PRESENT	0
395898	378096	12041X	PARTICIPANT	\N	PRESENT	0
395899	378096	19695N	PARTICIPANT	\N	PRESENT	0
395900	378096	19758L	PARTICIPANT	\N	PRESENT	0
395901	378096	04085P	PARTICIPANT	\N	PRESENT	0
395902	378096	04049K	PARTICIPANT	\N	PRESENT	0
395903	378096	19413M	PARTICIPANT	\N	PRESENT	0
395904	378096	14030Q	PARTICIPANT	\N	PRESENT	0
395905	378096	19611R	PARTICIPANT	\N	PRESENT	0
395906	378096	08031R	PARTICIPANT	\N	PRESENT	0
395907	378096	01058X	PARTICIPANT	\N	PRESENT	0
395908	378096	14219Q	PARTICIPANT	\N	PRESENT	0
395909	378096	14079W	PARTICIPANT	\N	PRESENT	0
395910	378096	04040A	PARTICIPANT	\N	PRESENT	0
395911	378096	14033T	PARTICIPANT	\N	PRESENT	0
395912	378096	04047H	PARTICIPANT	\N	PRESENT	0
395913	378096	14169X	PARTICIPANT	\N	PRESENT	0
395914	378096	14001X	PARTICIPANT	\N	PRESENT	0
395915	378096	19649G	PARTICIPANT	\N	PRESENT	0
395916	378096	11109J	PARTICIPANT	\N	PRESENT	0
395917	378096	19709B	PARTICIPANT	\N	PRESENT	0
396485	396483	14107H	PARTICIPANT	\N	PRESENT	0
396487	396486	19611R	PARTICIPANT	\N	PRESENT	0
396488	396486	14107H	PARTICIPANT	\N	PRESENT	0
396490	396489	19611R	PARTICIPANT	\N	PRESENT	0
396491	396489	14107H	PARTICIPANT	\N	PRESENT	0
397223	396520	08017T	PARTICIPANT	\N	PRESENT	0
397266	396775	19599P	PARTICIPANT	\N	PRESENT	0
397286	396050	19583F	PARTICIPANT	\N	EXCUSE	0
397363	397362	19253P	PARTICIPANT	\N	PRESENT	0
397364	397362	19671E	PARTICIPANT	\N	PRESENT	0
397365	397362	11053K	PARTICIPANT	\N	PRESENT	0
397366	397362	14083S	PARTICIPANT	\N	PRESENT	0
410830	410829	01028R	PARTICIPANT	\N	PRESENT	0
411439	406843	14109K	PARTICIPANT	\N	PRESENT	0
411440	406843	14179A	PARTICIPANT	\N	PRESENT	0
411441	406843	16685X	PARTICIPANT	\N	PRESENT	0
411442	406843	14033T	PARTICIPANT	\N	PRESENT	0
411443	406843	14151M	PARTICIPANT	\N	PRESENT	0
411444	406843	19563B	PARTICIPANT	\N	PRESENT	0
411445	406843	04045F	PARTICIPANT	\N	PRESENT	0
411446	406843	08068F	PARTICIPANT	\N	PRESENT	0
411447	406843	14081Q	PARTICIPANT	\N	PRESENT	0
411448	406843	19573D	PARTICIPANT	\N	PRESENT	0
411449	406843	14257W	PARTICIPANT	\N	PRESENT	0
411450	406843	14219Q	PARTICIPANT	\N	PRESENT	0
411451	406843	07029T	PARTICIPANT	\N	PRESENT	0
411452	406843	08010L	PARTICIPANT	\N	PRESENT	0
411453	406843	14193X	PARTICIPANT	\N	PRESENT	0
411454	406843	11090Q	PARTICIPANT	\N	PRESENT	0
411455	406843	14205J	PARTICIPANT	\N	PRESENT	0
411456	406843	14123H	PARTICIPANT	\N	PRESENT	0
411457	406843	19347U	PARTICIPANT	\N	PRESENT	0
411458	406843	19565D	PARTICIPANT	\N	PRESENT	0
411459	406843	14249W	PARTICIPANT	\N	PRESENT	0
411460	406843	19733B	PARTICIPANT	\N	PRESENT	0
411461	406843	14073Q	PARTICIPANT	\N	PRESENT	0
411462	406843	14111D	PARTICIPANT	\N	PRESENT	0
411463	406843	14357A	PARTICIPANT	\N	PRESENT	0
411464	406843	19507S	PARTICIPANT	\N	PRESENT	0
411465	406843	19383Y	PARTICIPANT	\N	PRESENT	0
411466	406843	19387D	PARTICIPANT	\N	PRESENT	0
411467	406843	14089Y	PARTICIPANT	\N	PRESENT	0
411487	410097	19443T	PARTICIPANT	\N	PRESENT	0
411488	410097	11080N	PARTICIPANT	\N	PRESENT	0
411489	410097	04034C	PARTICIPANT	\N	PRESENT	0
411490	410097	14079W	PARTICIPANT	\N	PRESENT	0
411491	410097	01058X	PARTICIPANT	\N	PRESENT	0
411492	410097	04040A	PARTICIPANT	\N	PRESENT	0
411493	410097	16685X	PARTICIPANT	\N	PRESENT	0
411494	410097	04042C	PRESIDENT	0	PRESENT	0
411495	410097	08056B	PARTICIPANT	\N	PRESENT	0
411496	410097	19709B	PARTICIPANT	\N	PRESENT	0
411497	410097	08049C	PARTICIPANT	\N	PRESENT	0
411498	410097	14193X	PARTICIPANT	\N	PRESENT	0
411499	410097	97011G	PARTICIPANT	\N	PRESENT	0
411500	410097	08047A	PARTICIPANT	\N	PRESENT	0
411501	410097	14097Y	PARTICIPANT	\N	PRESENT	0
411502	410097	04035D	PARTICIPANT	\N	PRESENT	0
411503	410097	14133K	PARTICIPANT	\N	PRESENT	0
411504	410097	11041F	PARTICIPANT	\N	PRESENT	0
411505	410097	14235Q	PARTICIPANT	\N	PRESENT	0
411506	410097	19251M	PARTICIPANT	\N	PRESENT	0
411507	410097	19319Q	PARTICIPANT	\N	PRESENT	0
411508	410097	14105F	PARTICIPANT	\N	PRESENT	0
411509	410097	98022P	PARTICIPANT	\N	PRESENT	0
411510	410097	14267Y	PARTICIPANT	\N	PRESENT	0
411511	410097	98050T	PARTICIPANT	\N	PRESENT	0
411512	410097	19583F	PARTICIPANT	\N	PRESENT	0
411513	410097	14211G	PARTICIPANT	\N	PRESENT	0
411514	410097	14255U	PARTICIPANT	\N	PRESENT	0
411515	410097	95030B	PARTICIPANT	\N	PRESENT	0
411516	410097	01062T	PARTICIPANT	\N	PRESENT	0
411517	410097	08058D	PARTICIPANT	\N	PRESENT	0
411518	410097	11115U	PARTICIPANT	\N	PRESENT	0
411519	410097	12041X	PARTICIPANT	\N	PRESENT	0
411520	410097	95037J	PARTICIPANT	\N	PRESENT	0
411521	410097	19421M	PARTICIPANT	\N	PRESENT	0
411522	410097	14028W	PARTICIPANT	\N	PRESENT	0
411525	410097	11066Q	PARTICIPANT	\N	PRESENT	0
411526	410097	14055N	PARTICIPANT	\N	PRESENT	0
411527	410097	98029W	PARTICIPANT	\N	PRESENT	0
411529	410097	19669L	PARTICIPANT	\N	PRESENT	0
411533	410097	11027H	PARTICIPANT	\N	PRESENT	0
411534	409988	14327T	PARTICIPANT	\N	PRESENT	0
411535	409988	14331P	PARTICIPANT	\N	PRESENT	0
411536	409988	11048N	PARTICIPANT	\N	PRESENT	0
411537	409988	19479G	PARTICIPANT	\N	PRESENT	0
411538	409988	19711U	PARTICIPANT	\N	PRESENT	0
411539	409988	19531S	PARTICIPANT	\N	PRESENT	0
411540	409988	11053K	PARTICIPANT	\N	PRESENT	0
411541	409988	08014Q	PARTICIPANT	\N	PRESENT	0
411542	409988	14159V	PARTICIPANT	\N	PRESENT	0
411543	409988	14225N	PRESIDENT	0	PRESENT	0
411544	409988	19671E	PARTICIPANT	\N	PRESENT	0
411545	409988	11070L	PARTICIPANT	\N	PRESENT	0
411546	409988	11110B	PARTICIPANT	\N	PRESENT	0
411547	409988	04086Q	PARTICIPANT	\N	PRESENT	0
411548	409988	14083S	PARTICIPANT	\N	PRESENT	0
411549	409988	19349W	PARTICIPANT	\N	PRESENT	0
411550	409988	08010L	PARTICIPANT	\N	PRESENT	0
411551	409988	14121F	PARTICIPANT	\N	PRESENT	0
411552	409988	14253S	PARTICIPANT	\N	PRESENT	0
411558	410097	11054L	PARTICIPANT	\N	PRESENT	0
411559	410097	19721W	PARTICIPANT	\N	PRESENT	0
411560	410914	19729F	PARTICIPANT	\N	PRESENT	0
411561	410914	14111D	PARTICIPANT	\N	PRESENT	0
411562	410914	19581D	PARTICIPANT	\N	PRESENT	0
411563	410914	14215L	PARTICIPANT	\N	PRESENT	0
411564	410914	14259Y	PARTICIPANT	\N	PRESENT	0
411565	410914	19447X	PARTICIPANT	\N	PRESENT	0
411566	410914	14231L	PARTICIPANT	\N	PRESENT	0
411567	411209	19593H	PARTICIPANT	\N	PRESENT	0
411568	411209	19643A	PARTICIPANT	\N	PRESENT	0
411569	411209	04070G	PRESIDENT	0	PRESENT	0
411570	411209	19533U	PARTICIPANT	\N	PRESENT	0
411571	411209	19693L	PARTICIPANT	\N	PRESENT	0
411572	411209	19399H	PARTICIPANT	\N	PRESENT	0
411573	411209	14229S	PARTICIPANT	\N	PRESENT	0
411574	411209	14241N	PARTICIPANT	\N	PRESENT	0
411575	411209	19731Y	PARTICIPANT	\N	PRESENT	0
411576	411209	14107H	PARTICIPANT	\N	PRESENT	0
411577	411209	08017T	PARTICIPANT	\N	PRESENT	0
411578	411209	14063N	PARTICIPANT	\N	PRESENT	0
411579	411209	11104D	PARTICIPANT	\N	PRESENT	0
411580	411209	04018C	PARTICIPANT	\N	PRESENT	0
411581	411209	14249W	PARTICIPANT	\N	PRESENT	0
411582	410914	14053L	PARTICIPANT	\N	PRESENT	0
411583	410914	19629C	PARTICIPANT	\N	PRESENT	0
411584	410914	04038G	PARTICIPANT	\N	PRESENT	0
411585	410914	04008A	PARTICIPANT	\N	PRESENT	0
411586	411209	19611R	PARTICIPANT	\N	PRESENT	0
411587	411209	87003B	PARTICIPANT	\N	PRESENT	0
411588	411209	08012N	PARTICIPANT	\N	PRESENT	0
411589	411209	19735D	PARTICIPANT	\N	PRESENT	0
411590	409432	19383Y	PARTICIPANT	\N	PRESENT	0
411591	409432	17583W	PARTICIPANT	\N	PRESENT	0
411592	409432	19794Q	PARTICIPANT	\N	PRESENT	0
411593	409432	19549D	PARTICIPANT	\N	PRESENT	0
411594	409432	19387D	PARTICIPANT	\N	PRESENT	0
411595	409432	19820Y	PARTICIPANT	\N	PRESENT	0
411596	409432	14219Q	PARTICIPANT	\N	PRESENT	0
411597	409432	19826F	PARTICIPANT	\N	PRESENT	0
411598	409432	14221J	PARTICIPANT	\N	PRESENT	0
411599	409432	19599P	PARTICIPANT	\N	PRESENT	0
411600	409432	18083K	PARTICIPANT	\N	PRESENT	0
411601	409432	14237S	PARTICIPANT	\N	PRESENT	0
411602	409432	19551W	PARTICIPANT	\N	PRESENT	0
411603	409432	05012A	PARTICIPANT	\N	PRESENT	0
411604	409432	19503N	PARTICIPANT	\N	PRESENT	0
411605	409432	19347U	PARTICIPANT	\N	PRESENT	0
411606	409432	14157T	PARTICIPANT	\N	PRESENT	0
411607	409432	08024S	PARTICIPANT	\N	PRESENT	0
411608	409432	14038Y	PARTICIPANT	\N	PRESENT	0
411609	409432	14031R	PARTICIPANT	\N	PRESENT	0
411610	409432	19713W	PARTICIPANT	\N	PRESENT	0
411611	409432	08055A	PARTICIPANT	\N	PRESENT	0
411612	409432	14191V	PARTICIPANT	\N	PRESENT	0
411613	409432	14169X	PARTICIPANT	\N	PRESENT	0
411614	409432	15447F	PARTICIPANT	\N	PRESENT	0
411615	409432	14029X	PARTICIPANT	\N	PRESENT	0
411616	409432	08009T	PRESIDENT	0	PRESENT	0
411617	409432	19737F	PARTICIPANT	\N	PRESENT	0
411618	409432	19745F	PARTICIPANT	\N	PRESENT	0
411619	409432	19739H	PARTICIPANT	\N	PRESENT	0
411620	409432	14051J	PARTICIPANT	\N	EXCUSE	0
411621	410914	19649G	PARTICIPANT	\N	PRESENT	0
411622	410914	10015M	PARTICIPANT	\N	PRESENT	0
411623	410914	08045X	PARTICIPANT	\N	PRESENT	0
411624	410914	14001X	PARTICIPANT	\N	PRESENT	0
411625	410914	01024M	PARTICIPANT	\N	PRESENT	0
411626	410914	19585H	PARTICIPANT	\N	PRESENT	0
411627	410914	19719D	PARTICIPANT	\N	PRESENT	0
411628	410914	19725B	PARTICIPANT	\N	PRESENT	0
411629	410914	11072N	PARTICIPANT	\N	PRESENT	0
411630	410914	19253P	PARTICIPANT	\N	EXCUSE	0
411631	410914	19675J	PARTICIPANT	\N	EXCUSE	0
411632	411209	08031R	PARTICIPANT	\N	PRESENT	0
411633	411209	14059S	PARTICIPANT	\N	PRESENT	0
411634	411209	14061L	PARTICIPANT	\N	PRESENT	0
411635	411209	08043V	PARTICIPANT	\N	PRESENT	0
393967	384447	19631V	PARTICIPANT	\N	EXCUSE	0
393968	384447	96004D	PARTICIPANT	\N	EXCUSE	0
393969	384447	19577H	PARTICIPANT	\N	EXCUSE	0
393970	384447	19691J	PARTICIPANT	\N	EXCUSE	0
393971	384447	14097Y	PARTICIPANT	\N	EXCUSE	0
393972	384447	14038Y	PARTICIPANT	\N	EXCUSE	0
393973	384447	14225N	PARTICIPANT	\N	EXCUSE	0
393974	384447	19657G	PARTICIPANT	\N	EXCUSE	0
393975	384447	19295A	PARTICIPANT	\N	EXCUSE	0
395744	393770	14121F	PARTICIPANT	\N	PRESENT	0
393985	393983	19575F	PARTICIPANT	\N	PRESENT	0
395745	393770	08010L	PARTICIPANT	\N	PRESENT	0
393987	393983	08052W	PARTICIPANT	\N	PRESENT	0
393988	393983	14217N	PARTICIPANT	\N	PRESENT	0
393989	393983	14042U	PRESIDENT	0	PRESENT	0
393990	393983	19727D	PARTICIPANT	\N	PRESENT	0
393991	393983	19553Y	PARTICIPANT	\N	PRESENT	0
393992	393983	14213J	PARTICIPANT	\N	PRESENT	0
395746	393770	99004R	PARTICIPANT	\N	PRESENT	0
393994	393983	04092N	PARTICIPANT	\N	PRESENT	0
393995	393983	11097X	PARTICIPANT	\N	PRESENT	0
393996	393983	19703U	PARTICIPANT	\N	PRESENT	0
395747	393770	14071N	PARTICIPANT	\N	PRESENT	0
395748	393770	07029T	PARTICIPANT	\N	EXCUSE	0
395749	378098	14147R	PARTICIPANT	\N	PRESENT	0
395750	378098	19549D	PARTICIPANT	\N	PRESENT	0
395751	378098	19591F	PARTICIPANT	\N	PRESENT	0
395752	378098	08058D	PARTICIPANT	\N	PRESENT	0
395754	378098	19253P	PARTICIPANT	\N	PRESENT	0
395755	378098	19629C	PARTICIPANT	\N	PRESENT	0
395756	378098	88008L	PARTICIPANT	\N	PRESENT	0
395757	378098	19747H	PARTICIPANT	\N	PRESENT	0
395758	378098	14053L	PARTICIPANT	\N	PRESENT	0
395759	378098	14179A	PARTICIPANT	\N	PRESENT	0
395760	378098	19441R	PARTICIPANT	\N	PRESENT	0
395761	378098	12041X	PARTICIPANT	\N	PRESENT	0
395762	378098	19699S	PARTICIPANT	\N	PRESENT	0
395763	378098	08019V	PARTICIPANT	\N	PRESENT	0
395764	378098	19695N	PARTICIPANT	\N	PRESENT	0
395765	378098	19758L	PARTICIPANT	\N	PRESENT	0
395766	378098	19349W	PARTICIPANT	\N	PRESENT	0
395767	378098	19369B	PARTICIPANT	\N	PRESENT	0
395768	378098	95030B	PARTICIPANT	\N	PRESENT	0
395769	378098	14257W	PARTICIPANT	\N	PRESENT	0
395770	378098	11012A	PARTICIPANT	\N	PRESENT	0
395771	378098	08020N	PARTICIPANT	\N	PRESENT	0
395772	378098	04085P	PARTICIPANT	\N	PRESENT	0
395773	378098	04049K	PARTICIPANT	\N	PRESENT	0
395774	393770	01057W	PARTICIPANT	\N	PRESENT	0
395775	393770	11074Q	PRESIDENT	0	PRESENT	0
395777	391636	14071N	PARTICIPANT	\N	PRESENT	0
395778	378098	19413M	PARTICIPANT	\N	PRESENT	0
395779	378098	19768N	PARTICIPANT	\N	PRESENT	0
395780	378098	19573D	PARTICIPANT	\N	PRESENT	0
395781	378098	08039A	PARTICIPANT	\N	PRESENT	0
395782	378098	14030Q	PARTICIPANT	\N	PRESENT	0
395783	378098	01024M	PARTICIPANT	\N	PRESENT	0
395784	378098	19611R	PARTICIPANT	\N	PRESENT	0
395785	393770	11053K	PARTICIPANT	\N	PRESENT	0
395786	378098	08031R	PARTICIPANT	\N	PRESENT	0
395787	378098	01058X	PARTICIPANT	\N	PRESENT	0
396210	396209	19545Y	PARTICIPANT	\N	PRESENT	0
396211	396209	19689Q	PARTICIPANT	\N	PRESENT	0
396213	396212	19545Y	PARTICIPANT	\N	PRESENT	0
396215	396214	19647E	PARTICIPANT	\N	PRESENT	0
396216	396214	11070L	PARTICIPANT	\N	PRESENT	0
396281	396280	11074Q	PARTICIPANT	\N	PRESENT	0
396282	396280	08011M	PARTICIPANT	\N	PRESENT	0
396293	396219	19647E	PARTICIPANT	\N	EXCUSE	0
396294	396219	14147R	PARTICIPANT	\N	EXCUSE	0
396295	396219	19737F	PARTICIPANT	\N	PRESENT	0
396299	396219	19467C	PARTICIPANT	\N	PRESENT	0
396319	396318	04071H	PARTICIPANT	\N	PRESENT	0
396461	396219	11097X	PARTICIPANT	\N	EXCUSE	0
396468	396219	08069G	PARTICIPANT	\N	EXCUSE	0
396482	396219	11066Q	PARTICIPANT	\N	PRESENT	0
398704	393596	04085P	PARTICIPANT	\N	PRESENT	0
398705	393596	19695N	PARTICIPANT	\N	PRESENT	0
398706	393596	11031D	PARTICIPANT	\N	PRESENT	0
398707	393596	19687N	PARTICIPANT	\N	PRESENT	0
398708	393596	19758L	PARTICIPANT	\N	PRESENT	0
398709	393596	11077T	PARTICIPANT	\N	PRESENT	0
398710	393596	19443T	PARTICIPANT	\N	PRESENT	0
398711	393596	11056N	PARTICIPANT	\N	PRESENT	0
398712	393596	14235Q	PARTICIPANT	\N	PRESENT	0
398713	393596	19741B	PARTICIPANT	\N	PRESENT	0
398714	393596	19593H	PARTICIPANT	\N	PRESENT	0
398715	393596	04088S	PARTICIPANT	\N	PRESENT	0
398716	393596	08061X	PARTICIPANT	\N	PRESENT	0
398717	393596	95037J	PARTICIPANT	\N	PRESENT	0
398718	393596	14041T	PARTICIPANT	\N	PRESENT	0
398719	393596	04034C	PARTICIPANT	\N	PRESENT	0
398720	393596	19657G	PARTICIPANT	\N	PRESENT	0
398721	393596	98029W	PARTICIPANT	\N	PRESENT	0
398722	393596	14355X	PARTICIPANT	\N	PRESENT	0
398723	393596	11083R	PARTICIPANT	\N	PRESENT	0
398724	393596	19637C	PARTICIPANT	\N	PRESENT	0
398725	393596	08062Y	PARTICIPANT	\N	PRESENT	0
398726	393596	14039A	PARTICIPANT	\N	PRESENT	0
398727	393596	19543W	PARTICIPANT	\N	PRESENT	0
398728	393596	19693L	PARTICIPANT	\N	PRESENT	0
398729	393596	19812Y	PARTICIPANT	\N	PRESENT	0
398730	393596	14265W	PARTICIPANT	\N	PRESENT	0
398731	393596	19782L	PARTICIPANT	\N	PRESENT	0
398732	393596	08024S	PARTICIPANT	\N	PRESENT	0
398733	393596	19399H	PARTICIPANT	\N	PRESENT	0
398734	393596	08019V	PARTICIPANT	\N	PRESENT	0
398735	393596	14033T	PARTICIPANT	\N	PRESENT	0
398736	393596	18083K	PARTICIPANT	\N	PRESENT	0
398737	393596	14038Y	PARTICIPANT	\N	PRESENT	0
398738	393596	14173T	PARTICIPANT	\N	PRESENT	0
398739	393596	19447X	PARTICIPANT	\N	PRESENT	0
398740	393596	11012A	PARTICIPANT	\N	PRESENT	0
398741	393596	19794Q	PARTICIPANT	\N	PRESENT	0
398742	393596	88008L	PARTICIPANT	\N	PRESENT	0
398743	393596	19253P	PARTICIPANT	\N	PRESENT	0
398744	393596	92040Q	PARTICIPANT	\N	PRESENT	0
398745	393596	19629C	PARTICIPANT	\N	PRESENT	0
398746	393596	14119M	PARTICIPANT	\N	PRESENT	0
398747	393596	14207L	PARTICIPANT	\N	PRESENT	0
398748	393596	14201E	PARTICIPANT	\N	PRESENT	0
398749	393596	11049P	PARTICIPANT	\N	PRESENT	0
398750	393596	98022P	PARTICIPANT	\N	PRESENT	0
398751	393596	14115H	PARTICIPANT	\N	PRESENT	0
398752	393596	14241N	PARTICIPANT	\N	PRESENT	0
398753	393596	14121F	PARTICIPANT	\N	PRESENT	0
398754	393596	19719D	PARTICIPANT	\N	PRESENT	0
398755	393596	11099A	PARTICIPANT	\N	PRESENT	0
398756	393596	08047A	PARTICIPANT	\N	PRESENT	0
398757	393596	14107H	PARTICIPANT	\N	PRESENT	0
398758	393596	19387D	PARTICIPANT	\N	PRESENT	0
398759	393596	14105F	PARTICIPANT	\N	PRESENT	0
398760	393596	19289C	PARTICIPANT	\N	PRESENT	0
398761	393596	17583W	PARTICIPANT	\N	PRESENT	0
398762	393596	14034U	PARTICIPANT	\N	PRESENT	0
398763	393596	14147R	PARTICIPANT	\N	PRESENT	0
398764	393596	19563B	PARTICIPANT	\N	PRESENT	0
398765	393596	17589D	PARTICIPANT	\N	PRESENT	0
398766	393596	04049K	PARTICIPANT	\N	PRESENT	0
398767	393596	11064N	PARTICIPANT	\N	PRESENT	0
398768	393596	14253S	PARTICIPANT	\N	PRESENT	0
398769	393596	04045F	PARTICIPANT	\N	PRESENT	0
398770	393596	98005N	PARTICIPANT	\N	PRESENT	0
398771	393596	14251Q	PARTICIPANT	\N	PRESENT	0
398772	393596	14031R	PARTICIPANT	\N	PRESENT	0
398773	393596	14195A	PARTICIPANT	\N	PRESENT	0
398774	393596	19717B	PARTICIPANT	\N	PRESENT	0
398775	393596	01057W	PARTICIPANT	\N	PRESENT	0
398776	393596	19673G	PARTICIPANT	\N	PRESENT	0
398777	393596	19553Y	PARTICIPANT	\N	PRESENT	0
398778	393596	14111D	PARTICIPANT	\N	PRESENT	0
398779	393596	19703U	PARTICIPANT	\N	PRESENT	0
398780	393596	19515S	PARTICIPANT	\N	PRESENT	0
398781	393596	14191V	PARTICIPANT	\N	PRESENT	0
398782	393596	11080N	PARTICIPANT	\N	PRESENT	0
398783	393596	19766L	PARTICIPANT	\N	PRESENT	0
398784	393596	89017R	PARTICIPANT	\N	PRESENT	0
398785	393596	87003B	PARTICIPANT	\N	PRESENT	0
398786	393596	08028W	PARTICIPANT	\N	PRESENT	0
398787	393596	04059M	PARTICIPANT	\N	PRESENT	0
398788	393596	01048V	PARTICIPANT	\N	PRESENT	0
398789	393596	14159V	PARTICIPANT	\N	PRESENT	0
398790	393596	10015M	PARTICIPANT	\N	PRESENT	0
398791	393596	19631V	PARTICIPANT	\N	PRESENT	0
398792	393596	14223L	PARTICIPANT	\N	PRESENT	0
398793	393596	11074Q	PARTICIPANT	\N	PRESENT	0
398794	393596	12041X	PARTICIPANT	\N	PRESENT	0
398795	393596	11043H	PARTICIPANT	\N	PRESENT	0
398796	393596	08055A	PARTICIPANT	\N	PRESENT	0
408238	402273	19563B	PARTICIPANT	\N	PRESENT	0
408239	402273	08068F	PARTICIPANT	\N	PRESENT	0
408240	402273	01062T	PARTICIPANT	\N	PRESENT	0
408241	402273	11066Q	PARTICIPANT	\N	PRESENT	0
408242	402273	14225N	PARTICIPANT	\N	PRESENT	0
408243	402273	14257W	PARTICIPANT	\N	PRESENT	0
408244	402273	19782L	PARTICIPANT	\N	PRESENT	0
408245	402273	95037J	PARTICIPANT	\N	PRESENT	0
408246	402273	08049C	PARTICIPANT	\N	PRESENT	0
408247	402273	19731Y	PARTICIPANT	\N	PRESENT	0
408248	402273	19685L	PARTICIPANT	\N	PRESENT	0
408249	402273	11085T	PARTICIPANT	\N	PRESENT	0
408250	402273	01025N	PARTICIPANT	\N	PRESENT	0
408251	402273	19745F	PARTICIPANT	\N	PRESENT	0
408252	402273	98005N	PARTICIPANT	\N	PRESENT	0
408253	402273	14111D	PARTICIPANT	\N	PRESENT	0
408254	402273	19251M	PARTICIPANT	\N	PRESENT	0
408255	402273	14028W	PARTICIPANT	\N	PRESENT	0
408256	402273	12016W	PARTICIPANT	\N	PRESENT	0
408257	402273	01028R	PARTICIPANT	\N	PRESENT	0
408258	402273	04069P	PARTICIPANT	\N	PRESENT	0
408259	402273	14123H	PARTICIPANT	\N	PRESENT	0
408260	402273	14061L	PARTICIPANT	\N	PRESENT	0
408261	402273	04088S	PARTICIPANT	\N	PRESENT	0
408262	402273	08019V	PARTICIPANT	\N	PRESENT	0
408263	402273	14135M	PARTICIPANT	\N	PRESENT	0
408264	402273	19399H	PARTICIPANT	\N	PRESENT	0
408265	402273	19711U	PARTICIPANT	\N	PRESENT	0
408266	402273	98018T	PARTICIPANT	\N	PRESENT	0
408267	402273	99004R	PARTICIPANT	\N	PRESENT	0
408268	402273	19679N	PARTICIPANT	\N	PRESENT	0
408269	402273	14133K	PARTICIPANT	\N	PRESENT	0
408270	402273	19695N	PARTICIPANT	\N	PRESENT	0
408271	402273	14038Y	PARTICIPANT	\N	PRESENT	0
408272	402273	01058X	PARTICIPANT	\N	PRESENT	0
408273	402273	14327T	PARTICIPANT	\N	PRESENT	0
408274	402273	19269X	PARTICIPANT	\N	PRESENT	0
408275	402273	11054L	PARTICIPANT	\N	PRESENT	0
408276	402273	05012A	PARTICIPANT	\N	PRESENT	0
408277	402273	14103D	PARTICIPANT	\N	PRESENT	0
408278	402273	14223L	PARTICIPANT	\N	PRESENT	0
408279	402273	14119M	PARTICIPANT	\N	PRESENT	0
408280	402273	08053X	PARTICIPANT	\N	PRESENT	0
408281	402273	14253S	PARTICIPANT	\N	PRESENT	0
408282	402273	11099A	PARTICIPANT	\N	PRESENT	0
408283	402273	19467C	PARTICIPANT	\N	PRESENT	0
408284	402273	14097Y	PARTICIPANT	\N	PRESENT	0
408285	402273	14031R	PARTICIPANT	\N	PRESENT	0
408287	402273	14107H	PARTICIPANT	\N	PRESENT	0
408288	402273	14241N	PARTICIPANT	\N	PRESENT	0
408289	402273	95030B	PARTICIPANT	\N	PRESENT	0
408290	402273	14267Y	PARTICIPANT	\N	PRESENT	0
408291	402273	08031R	PARTICIPANT	\N	PRESENT	0
408292	402273	14207L	PARTICIPANT	\N	PRESENT	0
408293	402273	08056B	PARTICIPANT	\N	PRESENT	0
408294	402273	04049K	PARTICIPANT	\N	PRESENT	0
408295	402273	01057W	PARTICIPANT	\N	PRESENT	0
408296	402273	14265W	PARTICIPANT	\N	PRESENT	0
408297	402273	87003B	PARTICIPANT	\N	PRESENT	0
408298	402273	11043H	PARTICIPANT	\N	PRESENT	0
408299	402273	96004D	PARTICIPANT	\N	PRESENT	0
408300	402273	11048N	PARTICIPANT	\N	PRESENT	0
408301	402273	04092N	PARTICIPANT	\N	PRESENT	0
408302	402273	08017T	PARTICIPANT	\N	PRESENT	0
408303	402273	11104D	PARTICIPANT	\N	PRESENT	0
408304	402273	08058D	PARTICIPANT	\N	PRESENT	0
408305	402273	11097X	PARTICIPANT	\N	PRESENT	0
408306	402273	19798U	PARTICIPANT	\N	PRESENT	0
408307	402273	01024M	PARTICIPANT	\N	PRESENT	0
408308	402273	19319Q	PARTICIPANT	\N	PRESENT	0
408309	402273	14237S	PARTICIPANT	\N	PRESENT	0
408310	402273	14087W	PARTICIPANT	\N	PRESENT	0
408311	402273	11056N	PARTICIPANT	\N	PRESENT	0
408312	402273	14235Q	PARTICIPANT	\N	PRESENT	0
408313	402273	11040E	PARTICIPANT	\N	PRESENT	0
408314	402273	08055A	PARTICIPANT	\N	PRESENT	0
408315	402273	19747H	PARTICIPANT	\N	PRESENT	0
408316	402273	08028W	PARTICIPANT	\N	PRESENT	0
408317	402273	14115H	PARTICIPANT	\N	PRESENT	0
408318	402273	14081Q	PARTICIPANT	\N	PRESENT	0
408319	402273	19715Y	PARTICIPANT	\N	PRESENT	0
408320	402273	19531S	PARTICIPANT	\N	PRESENT	0
408321	402273	04089T	PARTICIPANT	\N	PRESENT	0
408322	402273	19599P	PARTICIPANT	\N	PRESENT	0
408323	402273	14195A	PARTICIPANT	\N	PRESENT	0
408324	402273	19549D	PARTICIPANT	\N	PRESENT	0
408326	402273	14205J	PARTICIPANT	\N	PRESENT	0
408327	402273	19739H	PARTICIPANT	\N	PRESENT	0
408328	402273	19447X	PARTICIPANT	\N	PRESENT	0
408329	402273	08020N	PARTICIPANT	\N	PRESENT	0
408330	402273	14213J	PARTICIPANT	\N	PRESENT	0
408331	402273	19762G	PARTICIPANT	\N	PRESENT	0
408332	402273	14063N	PARTICIPANT	\N	PRESENT	0
408333	402273	19369B	PARTICIPANT	\N	PRESENT	0
408334	402273	19545Y	PARTICIPANT	\N	PRESENT	0
408335	402273	19725B	PARTICIPANT	\N	PRESENT	0
408336	402273	19691J	PARTICIPANT	\N	PRESENT	0
408337	402273	01060R	PARTICIPANT	\N	PRESENT	0
408338	402273	19703U	PARTICIPANT	\N	PRESENT	0
408339	402273	08062Y	PARTICIPANT	\N	PRESENT	0
408340	402273	19521Q	PARTICIPANT	\N	PRESENT	0
408341	402273	14121F	PARTICIPANT	\N	PRESENT	0
408342	402273	17779H	PARTICIPANT	\N	PRESENT	0
408343	402273	95041E	PARTICIPANT	\N	PRESENT	0
408344	402273	14041T	PARTICIPANT	\N	PRESENT	0
408345	402273	14083S	PARTICIPANT	\N	PRESENT	0
408346	402273	14053L	PARTICIPANT	\N	PRESENT	0
408347	402273	19479G	PARTICIPANT	\N	PRESENT	0
408348	402273	08044W	PARTICIPANT	\N	PRESENT	0
408349	402273	14042U	PARTICIPANT	\N	PRESENT	0
408350	402273	19671E	PARTICIPANT	\N	PRESENT	0
408351	402273	08034U	PARTICIPANT	\N	PRESENT	0
408352	402273	14089Y	PARTICIPANT	\N	PRESENT	0
408353	402273	14331P	PARTICIPANT	\N	PRESENT	0
408354	402273	14217N	PARTICIPANT	\N	PRESENT	0
408355	402273	98050T	PARTICIPANT	\N	PRESENT	0
408356	402273	14069U	PARTICIPANT	\N	PRESENT	0
408357	402273	11101A	PARTICIPANT	\N	PRESENT	0
408483	402274	11070L	PARTICIPANT	\N	PRESENT	0
408484	402274	12016W	PARTICIPANT	\N	PRESENT	0
408485	402274	19715Y	PARTICIPANT	\N	PRESENT	0
408486	402274	80013X	PARTICIPANT	\N	PRESENT	0
408487	402274	19599P	PARTICIPANT	\N	PRESENT	0
408488	402274	14081Q	PARTICIPANT	\N	PRESENT	0
408489	402274	19725B	PARTICIPANT	\N	PRESENT	0
408490	402274	14065Q	PARTICIPANT	\N	PRESENT	0
408491	402274	11066Q	PARTICIPANT	\N	PRESENT	0
408492	402274	19531S	PARTICIPANT	\N	PRESENT	0
408493	402274	14097Y	PARTICIPANT	\N	PRESENT	0
408494	402274	19782L	PARTICIPANT	\N	PRESENT	0
408495	402274	14121F	PARTICIPANT	\N	PRESENT	0
408496	402274	14205J	PARTICIPANT	\N	PRESENT	0
408497	402274	19479G	PARTICIPANT	\N	PRESENT	0
408498	402274	11090Q	PARTICIPANT	\N	PRESENT	0
408499	402274	19691J	PARTICIPANT	\N	PRESENT	0
408500	402274	14195A	PARTICIPANT	\N	PRESENT	0
408501	402274	01025N	PARTICIPANT	\N	PRESENT	0
408502	402274	14267Y	PARTICIPANT	\N	PRESENT	0
408503	402274	19739H	PARTICIPANT	\N	PRESENT	0
408504	402274	14042U	PARTICIPANT	\N	PRESENT	0
408505	402274	19521Q	PARTICIPANT	\N	PRESENT	0
408506	402274	19747H	PARTICIPANT	\N	PRESENT	0
408507	402274	19745F	PARTICIPANT	\N	PRESENT	0
408508	402274	08061X	PARTICIPANT	\N	PRESENT	0
408509	402274	14034U	PARTICIPANT	\N	PRESENT	0
408510	402274	08044W	PARTICIPANT	\N	PRESENT	0
408511	402274	08056B	PARTICIPANT	\N	PRESENT	0
408512	402274	19685L	PARTICIPANT	\N	PRESENT	0
408513	402274	19367Y	PARTICIPANT	\N	PRESENT	0
408514	402274	01060R	PARTICIPANT	\N	PRESENT	0
408515	402274	19731Y	PARTICIPANT	\N	PRESENT	0
408516	402274	08055A	PARTICIPANT	\N	PRESENT	0
408517	402274	11110B	PARTICIPANT	\N	PRESENT	0
408518	402274	14265W	PARTICIPANT	\N	PRESENT	0
408519	402274	19762G	PARTICIPANT	\N	PRESENT	0
408520	402274	14331P	PARTICIPANT	\N	PRESENT	0
408521	402274	04069P	PARTICIPANT	\N	PRESENT	0
408522	402274	14217N	PARTICIPANT	\N	PRESENT	0
408523	402274	08034U	PARTICIPANT	\N	PRESENT	0
408524	402274	14069U	PARTICIPANT	\N	PRESENT	0
408525	402274	01024M	PARTICIPANT	\N	PRESENT	0
408526	402274	08062Y	PARTICIPANT	\N	PRESENT	0
408527	402274	14213J	PARTICIPANT	\N	PRESENT	0
408528	402274	04049K	PARTICIPANT	\N	PRESENT	0
408529	402274	19711U	PARTICIPANT	\N	PRESENT	0
408530	402274	14357A	PARTICIPANT	\N	PRESENT	0
408531	402274	14223L	PARTICIPANT	\N	PRESENT	0
408532	402274	01057W	PARTICIPANT	\N	PRESENT	0
397380	397367	14357A	PARTICIPANT	\N	PRESENT	0
397381	397367	14083S	PARTICIPANT	\N	PRESENT	0
397378	397367	19253P	PARTICIPANT	\N	PRESENT	0
397379	397367	14237S	PARTICIPANT	\N	PRESENT	0
397382	397367	19671E	PARTICIPANT	\N	PRESENT	0
397383	397367	11053K	PARTICIPANT	\N	PRESENT	0
397385	397384	19253P	PARTICIPANT	\N	PRESENT	0
397386	397384	14083S	PARTICIPANT	\N	PRESENT	0
397387	397384	08045X	PARTICIPANT	\N	PRESENT	0
397388	397384	19703U	PARTICIPANT	\N	PRESENT	0
397389	397384	19671E	PARTICIPANT	\N	PRESENT	0
397390	397384	04097T	PARTICIPANT	\N	PRESENT	0
397391	397384	11053K	PARTICIPANT	\N	PRESENT	0
397428	396129	14261S	PARTICIPANT	\N	PRESENT	0
397429	396129	19329S	PARTICIPANT	\N	PRESENT	0
397430	396129	14219Q	PARTICIPANT	\N	EXCUSE	0
397431	396129	14331P	PARTICIPANT	\N	PRESENT	0
397432	396129	14135M	PARTICIPANT	\N	PRESENT	0
397433	396129	04043D	PARTICIPANT	\N	PRESENT	0
397434	396129	11072N	PARTICIPANT	\N	PRESENT	0
397435	396129	19657G	PARTICIPANT	\N	PRESENT	0
397436	396129	08019V	PRESIDENT	0	PRESENT	0
397531	397530	19611R	PARTICIPANT	\N	PRESENT	0
397655	393592	11070L	PARTICIPANT	\N	PRESENT	0
397584	397583	19611R	PARTICIPANT	\N	PRESENT	0
397588	397581	14107H	PARTICIPANT	\N	PRESENT	0
397589	397581	19621T	PARTICIPANT	\N	PRESENT	0
397659	393592	19758L	PARTICIPANT	\N	PRESENT	0
397660	393592	19760E	PARTICIPANT	\N	PRESENT	0
397661	393592	11040E	PARTICIPANT	\N	PRESENT	0
397662	393592	19621T	PARTICIPANT	\N	PRESENT	0
397663	393592	04057K	PARTICIPANT	\N	PRESENT	0
397664	393592	19611R	PARTICIPANT	\N	PRESENT	0
397665	393592	19399H	PARTICIPANT	\N	PRESENT	0
397666	393592	14123H	PARTICIPANT	\N	PRESENT	0
397667	393592	19533U	PARTICIPANT	\N	PRESENT	0
397668	393592	14031R	PARTICIPANT	\N	PRESENT	0
397669	393592	19693L	PARTICIPANT	\N	PRESENT	0
397670	393592	19735D	PARTICIPANT	\N	PRESENT	0
397671	393592	19515S	PARTICIPANT	\N	PRESENT	0
397672	393592	14039A	PARTICIPANT	\N	PRESENT	0
397673	393592	08024S	PARTICIPANT	\N	PRESENT	0
397674	393592	08031R	PARTICIPANT	\N	PRESENT	0
397675	393592	14229S	PARTICIPANT	\N	PRESENT	0
397676	393592	14195A	PARTICIPANT	\N	PRESENT	0
397677	393592	08056B	PARTICIPANT	\N	PRESENT	0
397678	393592	19798U	PARTICIPANT	\N	PRESENT	0
397679	393592	19525U	PARTICIPANT	\N	PRESENT	0
397680	393592	19629C	PARTICIPANT	\N	PRESENT	0
397682	393592	14081Q	PARTICIPANT	\N	PRESENT	0
397683	393592	14061L	PARTICIPANT	\N	PRESENT	0
397684	393592	14109K	PARTICIPANT	\N	PRESENT	0
397685	393592	14073Q	PARTICIPANT	\N	PRESENT	0
397686	393592	04070G	PARTICIPANT	\N	PRESENT	0
397690	393592	19441R	PARTICIPANT	\N	PRESENT	0
397693	393592	19573D	PARTICIPANT	\N	PRESENT	0
397694	393592	97011G	PARTICIPANT	\N	PRESENT	0
397695	393592	19681G	PARTICIPANT	\N	PRESENT	0
397696	393592	15447F	PARTICIPANT	\N	PRESENT	0
397697	393592	14235Q	PARTICIPANT	\N	PRESENT	0
397710	393592	14231L	PARTICIPANT	\N	PRESENT	0
397711	393592	14249W	PARTICIPANT	\N	PRESENT	0
397712	393592	19711U	PARTICIPANT	\N	PRESENT	0
397713	393592	14257W	PARTICIPANT	\N	PRESENT	0
397714	393592	19301E	PARTICIPANT	\N	PRESENT	0
397715	393592	14265W	PARTICIPANT	\N	PRESENT	0
397716	393592	19479G	PARTICIPANT	\N	PRESENT	0
397717	393592	19543W	PARTICIPANT	\N	PRESENT	0
397718	393592	19467C	PARTICIPANT	\N	PRESENT	0
397719	393592	19691J	PARTICIPANT	\N	PRESENT	0
397720	393592	14021P	PARTICIPANT	\N	PRESENT	0
397721	393592	14042U	PARTICIPANT	\N	PRESENT	0
397722	393592	19739H	PARTICIPANT	\N	PRESENT	0
397723	393592	01028R	PARTICIPANT	\N	PRESENT	0
397724	393592	19697Q	PARTICIPANT	\N	PRESENT	0
397725	393592	14239U	PARTICIPANT	\N	PRESENT	0
397726	393592	19413M	PARTICIPANT	\N	PRESENT	0
397727	396238	15447F	PARTICIPANT	\N	PRESENT	0
397728	396238	14237S	PARTICIPANT	\N	PRESENT	0
397729	396238	08045X	PARTICIPANT	\N	PRESENT	0
397730	396238	19387D	PARTICIPANT	\N	PRESENT	0
397731	396238	11053K	PRESIDENT	0	PRESENT	0
397732	396238	19349W	PARTICIPANT	\N	PRESENT	0
397733	396238	19253P	PARTICIPANT	\N	PRESENT	0
397734	396238	19669L	PARTICIPANT	\N	PRESENT	0
397735	396238	14083S	PARTICIPANT	\N	PRESENT	0
397736	396238	14031R	PARTICIPANT	\N	PRESENT	0
397737	396238	19301E	PARTICIPANT	\N	PRESENT	0
397738	396238	19715Y	PARTICIPANT	\N	PRESENT	0
397754	393592	19569H	PARTICIPANT	\N	PRESENT	0
397755	393592	14179A	PARTICIPANT	\N	PRESENT	0
397756	393592	19657G	PARTICIPANT	\N	PRESENT	0
397772	396238	19333N	PARTICIPANT	\N	PRESENT	0
397773	396238	19735D	PARTICIPANT	\N	PRESENT	0
397774	396238	14069U	PARTICIPANT	\N	PRESENT	0
397775	393592	11083R	PARTICIPANT	\N	PRESENT	0
397776	393592	19553Y	PARTICIPANT	\N	PRESENT	0
397777	393592	08052W	PARTICIPANT	\N	PRESENT	0
397782	393592	11101A	PARTICIPANT	\N	PRESENT	0
397785	393592	08019V	PARTICIPANT	\N	PRESENT	0
397788	393592	19663E	PARTICIPANT	\N	PRESENT	0
397794	393592	04092N	PARTICIPANT	\N	PRESENT	0
397795	393592	19741B	PARTICIPANT	\N	PRESENT	0
397796	393592	19565D	PARTICIPANT	\N	PRESENT	0
397797	393592	14219Q	PARTICIPANT	\N	PRESENT	0
397828	393592	11067R	PARTICIPANT	\N	PRESENT	0
397829	393592	14030Q	PARTICIPANT	\N	PRESENT	0
397830	393592	19794Q	PARTICIPANT	\N	PRESENT	0
397831	393592	19387D	PARTICIPANT	\N	PRESENT	0
397832	393592	04088S	PARTICIPANT	\N	PRESENT	0
397833	393592	10006L	PARTICIPANT	\N	PRESENT	0
397892	393593	14239U	PARTICIPANT	\N	PRESENT	0
397893	393593	08052W	PARTICIPANT	\N	PRESENT	0
397894	393593	14081Q	PARTICIPANT	\N	PRESENT	0
397895	393593	19758L	PARTICIPANT	\N	PRESENT	0
397896	393593	19760E	PARTICIPANT	\N	PRESENT	0
397897	393593	14235Q	PARTICIPANT	\N	PRESENT	0
397898	393593	19347U	PARTICIPANT	\N	PRESENT	0
397899	393593	11040E	PARTICIPANT	\N	PRESENT	0
397900	393593	19565D	PARTICIPANT	\N	PRESENT	0
397901	393593	11083R	PARTICIPANT	\N	PRESENT	0
397902	393593	19697Q	PARTICIPANT	\N	PRESENT	0
397903	393593	19387D	PARTICIPANT	\N	PRESENT	0
397904	393593	14195A	PARTICIPANT	\N	PRESENT	0
397905	393593	19479G	PARTICIPANT	\N	PRESENT	0
397906	393593	19569H	PARTICIPANT	\N	PRESENT	0
397907	393593	19691J	PARTICIPANT	\N	PRESENT	0
397908	393593	19553Y	PARTICIPANT	\N	PRESENT	0
397909	393593	14030Q	PARTICIPANT	\N	PRESENT	0
397910	393593	08056B	PARTICIPANT	\N	PRESENT	0
397911	393593	14042U	PARTICIPANT	\N	PRESENT	0
397912	393593	11067R	PARTICIPANT	\N	PRESENT	0
397913	393593	19657G	PARTICIPANT	\N	PRESENT	0
397914	393593	19711U	PARTICIPANT	\N	PRESENT	0
397915	393593	14039A	PARTICIPANT	\N	PRESENT	0
397916	393593	04088S	PARTICIPANT	\N	PRESENT	0
397917	393593	19741B	PARTICIPANT	\N	PRESENT	0
397918	393593	19515S	PARTICIPANT	\N	PRESENT	0
397919	393593	19573D	PARTICIPANT	\N	PRESENT	0
397920	393593	19794Q	PARTICIPANT	\N	PRESENT	0
397921	393593	08020N	PARTICIPANT	\N	PRESENT	0
397922	393593	14123H	PARTICIPANT	\N	PRESENT	0
397923	393593	19533U	PARTICIPANT	\N	PRESENT	0
397924	393593	10006L	PARTICIPANT	\N	PRESENT	0
397925	393593	19693L	PARTICIPANT	\N	PRESENT	0
397927	393593	19798U	PARTICIPANT	\N	PRESENT	0
397928	393593	19629C	PARTICIPANT	\N	PRESENT	0
397930	393593	98050T	PARTICIPANT	\N	PRESENT	0
397931	393593	11097X	PARTICIPANT	\N	PRESENT	0
397932	393593	14069U	PARTICIPANT	\N	PRESENT	0
397933	393593	11031D	PARTICIPANT	\N	PRESENT	0
397935	396242	19333N	PARTICIPANT	\N	PRESENT	0
397936	396242	14083S	PARTICIPANT	\N	PRESENT	0
397937	396242	14031R	PARTICIPANT	\N	PRESENT	0
397938	396242	08045X	PARTICIPANT	\N	PRESENT	0
397939	396242	19735D	PARTICIPANT	\N	PRESENT	0
397940	396242	11053K	PRESIDENT	0	PRESENT	0
397941	396242	19349W	PARTICIPANT	\N	PRESENT	0
397942	396242	19253P	PARTICIPANT	\N	PRESENT	0
397943	396242	19301E	PARTICIPANT	\N	PRESENT	0
397944	396242	19715Y	PARTICIPANT	\N	PRESENT	0
397950	393593	19681G	PARTICIPANT	\N	PRESENT	0
397951	393593	14217N	PARTICIPANT	\N	PRESENT	0
397890	393593	11070L	PARTICIPANT	\N	PRESENT	0
397891	393593	04092N	PARTICIPANT	\N	PRESENT	0
411636	411209	14030Q	PARTICIPANT	\N	PRESENT	0
411637	411209	11083R	PARTICIPANT	\N	PRESENT	0
411638	411209	14123H	PARTICIPANT	\N	PRESENT	0
411639	409432	14327T	PARTICIPANT	\N	PRESENT	0
411640	409432	14331P	PARTICIPANT	\N	PRESENT	0
411641	409432	04071H	PARTICIPANT	\N	PRESENT	0
411642	409432	01057W	PARTICIPANT	\N	PRESENT	0
411643	409432	89017R	PARTICIPANT	\N	PRESENT	0
411644	409432	11070L	PARTICIPANT	\N	PRESENT	0
411645	409432	14225N	PARTICIPANT	\N	PRESENT	0
411646	409432	11110B	PARTICIPANT	\N	PRESENT	0
411647	409432	14085U	PARTICIPANT	\N	PRESENT	0
411648	409432	08010L	PARTICIPANT	\N	PRESENT	0
411649	409432	14253S	PARTICIPANT	\N	PRESENT	0
411650	409432	11048N	PARTICIPANT	\N	PRESENT	0
411651	409432	19711U	PARTICIPANT	\N	PRESENT	0
411652	409432	08034U	PARTICIPANT	\N	PRESENT	0
411653	409432	08069G	PARTICIPANT	\N	PRESENT	0
411654	409432	14173T	PARTICIPANT	\N	PRESENT	0
411655	409432	04086Q	PARTICIPANT	\N	PRESENT	0
411656	409988	04071H	PARTICIPANT	\N	PRESENT	0
411657	409988	01048V	PARTICIPANT	\N	PRESENT	0
411658	409988	01057W	PARTICIPANT	\N	PRESENT	0
411659	409988	89017R	PARTICIPANT	\N	PRESENT	0
411660	409988	14085U	PARTICIPANT	\N	PRESENT	0
411661	409988	08034U	PARTICIPANT	\N	PRESENT	0
411662	409988	08069G	PARTICIPANT	\N	PRESENT	0
411663	409988	14173T	PARTICIPANT	\N	PRESENT	0
411664	409988	11040E	PARTICIPANT	\N	PRESENT	0
411665	409988	19741B	PARTICIPANT	\N	PRESENT	0
411666	410914	04044E	PARTICIPANT	\N	PRESENT	0
411667	410914	05008E	PRESIDENT	0	PRESENT	0
411668	410914	14151M	PARTICIPANT	\N	PRESENT	0
411669	410914	14065Q	PARTICIPANT	\N	PRESENT	0
411670	410914	11033F	PARTICIPANT	\N	PRESENT	0
411671	410914	08044W	PARTICIPANT	\N	PRESENT	0
411672	410914	14069U	PARTICIPANT	\N	PRESENT	0
411673	410914	11085T	PARTICIPANT	\N	PRESENT	0
411674	409432	11053K	PARTICIPANT	\N	PRESENT	0
411675	409432	19671E	PARTICIPANT	\N	PRESENT	0
411676	409432	19349W	PARTICIPANT	\N	PRESENT	0
411677	409432	11040E	PARTICIPANT	\N	PRESENT	0
411678	409432	14083S	PARTICIPANT	\N	PRESENT	0
411679	409432	14121F	PARTICIPANT	\N	PRESENT	0
411680	409432	19479G	PARTICIPANT	\N	PRESENT	0
411681	409432	19531S	PARTICIPANT	\N	PRESENT	0
411682	409432	08014Q	PARTICIPANT	\N	PRESENT	0
411683	409432	14159V	PARTICIPANT	\N	PRESENT	0
411684	409432	19741B	PARTICIPANT	\N	PRESENT	0
411685	409432	11074Q	PARTICIPANT	\N	PRESENT	0
411686	410914	19543W	PARTICIPANT	\N	PRESENT	0
411687	410914	19489J	PARTICIPANT	\N	PRESENT	0
411688	410914	98035U	PARTICIPANT	\N	PRESENT	0
411689	410914	11026G	PARTICIPANT	\N	PRESENT	0
411690	410914	95063L	PARTICIPANT	\N	PRESENT	0
411691	410914	19762G	PARTICIPANT	\N	PRESENT	0
411692	409432	01048V	PARTICIPANT	\N	PRESENT	0
411909	411908	19631V	PARTICIPANT	\N	PRESENT	0
411910	411908	19515S	PARTICIPANT	\N	PRESENT	0
411911	411908	19747H	PARTICIPANT	\N	PRESENT	0
411912	411908	08028W	PARTICIPANT	\N	PRESENT	0
411913	411209	92040Q	PARTICIPANT	\N	EXCUSE	0
411914	411908	01025N	PARTICIPANT	\N	PRESENT	0
411915	411908	19441R	PARTICIPANT	\N	PRESENT	0
411916	411908	14265W	PARTICIPANT	\N	PRESENT	0
411917	411908	14135M	PARTICIPANT	\N	PRESENT	0
411918	411908	19269X	PARTICIPANT	\N	PRESENT	0
411921	409988	19681G	PARTICIPANT	\N	PRESENT	0
411922	409988	19685L	PARTICIPANT	\N	PRESENT	0
411923	409988	19551W	PARTICIPANT	\N	PRESENT	0
411924	409988	14029X	PARTICIPANT	\N	PRESENT	0
411931	409431	98024R	PARTICIPANT	\N	EXCUSE	0
411932	408229	14051J	PARTICIPANT	\N	EXCUSE	0
411933	408237	08055A	PARTICIPANT	\N	PRESENT	0
411934	408237	14093U	PARTICIPANT	\N	PRESENT	0
411935	408237	19549D	PARTICIPANT	\N	PRESENT	0
411936	408237	08060W	PARTICIPANT	\N	PRESENT	0
411937	408237	19733B	PARTICIPANT	\N	PRESENT	0
411938	408237	08024S	PARTICIPANT	\N	PRESENT	0
411939	408237	14038Y	PARTICIPANT	\N	PRESENT	0
411940	408237	18083K	PARTICIPANT	\N	PRESENT	0
411941	408237	19701S	PARTICIPANT	\N	PRESENT	0
411942	408237	19525U	PARTICIPANT	\N	PRESENT	0
411943	408237	11065P	PARTICIPANT	\N	PRESENT	0
411944	408237	19599P	PARTICIPANT	\N	PRESENT	0
411945	408237	02002K	PARTICIPANT	\N	PRESENT	0
411946	408237	19820Y	PARTICIPANT	\N	PRESENT	0
411947	408237	19387D	PARTICIPANT	\N	PRESENT	0
411948	408237	19347U	PARTICIPANT	\N	PRESENT	0
411949	408237	19685L	PARTICIPANT	\N	PRESENT	0
411950	408237	19333N	PARTICIPANT	\N	PRESENT	0
411951	408237	14219Q	PARTICIPANT	\N	PRESENT	0
411952	408237	14031R	PARTICIPANT	\N	PRESENT	0
411953	408237	19637C	PARTICIPANT	\N	PRESENT	0
411954	408237	19826F	PARTICIPANT	\N	PRESENT	0
411955	408237	08009T	PRESIDENT	0	PRESENT	0
411956	408237	14221J	PARTICIPANT	\N	PRESENT	0
411957	408237	14237S	PARTICIPANT	\N	PRESENT	0
411958	408237	19745F	PARTICIPANT	\N	PRESENT	0
411959	408237	05012A	PARTICIPANT	\N	PRESENT	0
411960	408237	19503N	PARTICIPANT	\N	PRESENT	0
411961	408237	19739H	PARTICIPANT	\N	PRESENT	0
411962	408237	17583W	PARTICIPANT	\N	PRESENT	0
411963	408237	19794Q	PARTICIPANT	\N	PRESENT	0
411964	408237	14157T	PARTICIPANT	\N	PRESENT	0
411965	408237	19737F	PARTICIPANT	\N	PRESENT	0
411966	408237	14051J	PARTICIPANT	\N	EXCUSE	0
411967	410097	08061X	PARTICIPANT	\N	EXCUSE	0
411968	410102	08061X	PARTICIPANT	\N	EXCUSE	0
413278	413275	11090Q	PARTICIPANT	\N	PRESENT	0
413279	413275	19711U	PARTICIPANT	\N	PRESENT	0
413280	413275	14031R	PARTICIPANT	\N	PRESENT	0
413281	413275	14038Y	PARTICIPANT	\N	PRESENT	0
413282	413275	19643A	PARTICIPANT	\N	PRESENT	0
413283	413275	11031D	PARTICIPANT	\N	PRESENT	0
413284	413275	19689Q	PARTICIPANT	\N	PRESENT	0
413285	413275	19681G	PARTICIPANT	\N	PRESENT	0
413286	413275	11053K	PARTICIPANT	\N	PRESENT	0
413287	413275	11070L	PARTICIPANT	\N	PRESENT	0
413288	413275	19399H	PARTICIPANT	\N	PRESENT	0
413289	413275	19611R	PARTICIPANT	\N	PRESENT	0
413290	413275	01048V	PARTICIPANT	\N	PRESENT	0
413291	413275	08009T	PARTICIPANT	\N	PRESENT	0
413292	413275	11085T	PARTICIPANT	\N	PRESENT	0
413293	413275	11054L	PARTICIPANT	\N	PRESENT	0
413496	413495	96004D	PRESIDENT	0	PRESENT	0
413497	413495	14255U	PARTICIPANT	\N	PRESENT	0
413498	413495	04042C	PRESIDENT	1	PRESENT	0
413499	413495	19251M	PARTICIPANT	\N	PRESENT	0
413500	413495	04035D	PARTICIPANT	\N	PRESENT	0
413501	413495	14097Y	PARTICIPANT	\N	PRESENT	0
413502	413495	14073Q	PARTICIPANT	\N	PRESENT	0
413503	413495	04057K	PARTICIPANT	\N	PRESENT	0
413504	413495	01062T	PARTICIPANT	\N	PRESENT	0
413614	406848	05008E	PARTICIPANT	\N	PRESENT	0
413615	406848	14259Y	PARTICIPANT	\N	PRESENT	0
413616	406848	14231L	PARTICIPANT	\N	PRESENT	0
413617	406848	07004J	PARTICIPANT	\N	PRESENT	0
413618	406848	19565D	PARTICIPANT	\N	PRESENT	0
413619	406848	14207L	PARTICIPANT	\N	PRESENT	0
413620	406848	19745F	PARTICIPANT	\N	PRESENT	0
413621	406848	14217N	PARTICIPANT	\N	PRESENT	0
413625	406848	11056N	PARTICIPANT	\N	PRESENT	0
413627	406848	19515S	PARTICIPANT	\N	PRESENT	0
413628	406848	14001X	PARTICIPANT	\N	PRESENT	0
413630	406848	19794Q	PARTICIPANT	\N	PRESENT	0
413632	406848	04088S	PARTICIPANT	\N	PRESENT	0
413633	406848	19489J	PARTICIPANT	\N	PRESENT	0
413634	406848	19631V	PARTICIPANT	\N	PRESENT	0
413635	406848	14133K	PARTICIPANT	\N	PRESENT	0
413636	406848	19585H	PARTICIPANT	\N	PRESENT	0
413637	406848	19575F	PARTICIPANT	\N	PRESENT	0
413638	406848	14107H	PARTICIPANT	\N	PRESENT	0
413641	406848	19479G	PARTICIPANT	\N	PRESENT	0
413642	406848	14329V	PARTICIPANT	\N	PRESENT	0
413645	406848	99004R	PARTICIPANT	\N	PRESENT	0
413646	406848	19447X	PARTICIPANT	\N	PRESENT	0
413647	406848	19826F	PARTICIPANT	\N	PRESENT	0
413648	406848	14215L	PARTICIPANT	\N	PRESENT	0
413649	406848	19741B	PARTICIPANT	\N	PRESENT	0
413650	406848	14179A	PARTICIPANT	\N	PRESENT	0
413651	406848	01028R	PARTICIPANT	\N	PRESENT	0
413652	406848	19543W	PARTICIPANT	\N	PRESENT	0
413653	406848	14265W	PARTICIPANT	\N	PRESENT	0
413654	406848	08024S	PARTICIPANT	\N	PRESENT	0
413657	406848	11067R	PARTICIPANT	\N	PRESENT	0
413660	406848	14038Y	PARTICIPANT	\N	PRESENT	0
413663	406848	19657G	PARTICIPANT	\N	PRESENT	0
393887	390980	95062K	PARTICIPANT	\N	PRESENT	0
393888	390980	19685L	PARTICIPANT	\N	PRESENT	0
393889	390980	14103D	PARTICIPANT	\N	PRESENT	0
393890	390980	14073Q	PARTICIPANT	\N	PRESENT	0
393892	393891	08055A	PARTICIPANT	\N	PRESENT	0
393893	393891	14093U	PARTICIPANT	\N	PRESENT	0
393894	393891	19549D	PARTICIPANT	\N	PRESENT	0
393895	393891	08060W	PARTICIPANT	\N	PRESENT	0
393896	393891	19733B	PARTICIPANT	\N	PRESENT	0
393897	393891	19383Y	PARTICIPANT	\N	PRESENT	0
393898	393891	08024S	PARTICIPANT	\N	PRESENT	0
393899	393891	14038Y	PARTICIPANT	\N	PRESENT	0
393900	393891	18083K	PARTICIPANT	\N	PRESENT	0
393901	393891	19701S	PARTICIPANT	\N	PRESENT	0
393902	393891	19525U	PARTICIPANT	\N	PRESENT	0
393903	393891	19599P	PARTICIPANT	\N	PRESENT	0
393904	393891	02002K	PARTICIPANT	\N	PRESENT	0
393905	393891	15447F	PARTICIPANT	\N	PRESENT	0
393942	393941	08018U	PARTICIPANT	\N	PRESENT	0
393943	393941	14093U	PARTICIPANT	\N	PRESENT	0
393944	393941	14357A	PARTICIPANT	\N	PRESENT	0
393945	393941	11083R	PARTICIPANT	\N	PRESENT	0
393946	393941	14059S	PARTICIPANT	\N	PRESENT	0
393911	393891	19387D	PARTICIPANT	\N	PRESENT	0
393912	393891	19347U	PARTICIPANT	\N	PRESENT	0
393947	393941	19631V	PARTICIPANT	\N	PRESENT	0
393914	393891	19333N	PARTICIPANT	\N	PRESENT	0
393915	393891	04097T	PARTICIPANT	\N	PRESENT	0
393916	393891	19551W	PARTICIPANT	\N	PRESENT	0
393917	393891	14029X	PARTICIPANT	\N	PRESENT	0
393948	393941	19575F	PARTICIPANT	\N	PRESENT	0
393919	393891	14219Q	PARTICIPANT	\N	PRESENT	0
394171	394170	14073Q	PARTICIPANT	\N	PRESENT	0
394172	394170	14030Q	PARTICIPANT	\N	PRESENT	0
393922	393891	14031R	PARTICIPANT	\N	PRESENT	0
393923	393891	19637C	PARTICIPANT	\N	PRESENT	0
393924	393891	08009T	PRESIDENT	0	PRESENT	0
393925	393891	14221J	PARTICIPANT	\N	PRESENT	0
393926	393891	14169X	PARTICIPANT	\N	PRESENT	0
394173	394170	08012N	PARTICIPANT	\N	PRESENT	0
393928	393891	14237S	PARTICIPANT	\N	PRESENT	0
393929	393891	17637T	PARTICIPANT	\N	PRESENT	0
393930	393891	19745F	PARTICIPANT	\N	PRESENT	0
393931	393891	05012A	PARTICIPANT	\N	PRESENT	0
393932	393891	19503N	PARTICIPANT	\N	PRESENT	0
393933	393891	19739H	PARTICIPANT	\N	PRESENT	0
393934	393891	17583W	PARTICIPANT	\N	PRESENT	0
393935	393891	19794Q	PARTICIPANT	\N	PRESENT	0
394174	394170	14241N	PARTICIPANT	\N	PRESENT	0
394177	394170	19758L	PARTICIPANT	\N	PRESENT	0
393938	393891	14051J	PARTICIPANT	\N	PRESENT	0
393939	393891	14157T	PARTICIPANT	\N	PRESENT	0
393940	393891	19737F	PARTICIPANT	\N	PRESENT	0
394178	394170	19699S	PARTICIPANT	\N	PRESENT	0
394179	394170	19611R	PARTICIPANT	\N	PRESENT	0
394180	394170	14059S	PARTICIPANT	\N	PRESENT	0
394892	394891	11053K	PARTICIPANT	\N	PRESENT	0
394893	394891	14159V	PARTICIPANT	\N	PRESENT	0
394894	394891	05012A	PARTICIPANT	\N	PRESENT	0
396509	396432	11070L	PARTICIPANT	\N	PRESENT	0
396510	396432	19647E	PARTICIPANT	\N	PRESENT	0
396511	396492	14327T	PARTICIPANT	\N	PRESENT	0
396512	396492	11110B	PARTICIPANT	\N	PRESENT	0
398797	393596	01028R	PARTICIPANT	\N	PRESENT	0
398798	393596	19643A	PARTICIPANT	\N	PRESENT	0
398799	393596	08052W	PARTICIPANT	\N	PRESENT	0
398800	393596	15447F	PARTICIPANT	\N	PRESENT	0
398801	393596	08038Y	PARTICIPANT	\N	PRESENT	0
398802	393596	19679N	PARTICIPANT	\N	PRESENT	0
398803	393596	14229S	PARTICIPANT	\N	PRESENT	0
398804	393596	14021P	PARTICIPANT	\N	PRESENT	0
398805	393596	08045X	PARTICIPANT	\N	PRESENT	0
398806	393596	19669L	PARTICIPANT	\N	PRESENT	0
398807	393596	08020N	PARTICIPANT	\N	PRESENT	0
398808	393596	14225N	PARTICIPANT	\N	PRESENT	0
398809	393596	19599P	PARTICIPANT	\N	PRESENT	0
398810	393596	14151M	PARTICIPANT	\N	PRESENT	0
398811	393596	08069G	PARTICIPANT	\N	PRESENT	0
398812	393596	14123H	PARTICIPANT	\N	PRESENT	0
398813	393596	19649G	PARTICIPANT	\N	PRESENT	0
398814	393596	99004R	PARTICIPANT	\N	PRESENT	0
398815	393596	11045K	PARTICIPANT	\N	PRESENT	0
398816	393596	08012N	PARTICIPANT	\N	PRESENT	0
398817	393596	01058X	PARTICIPANT	\N	PRESENT	0
398818	393596	11026G	PARTICIPANT	\N	PRESENT	0
398819	393596	14197C	PARTICIPANT	\N	PRESENT	0
398820	393596	17779H	PARTICIPANT	\N	PRESENT	0
398821	393596	14085U	PARTICIPANT	\N	PRESENT	0
398822	393596	14227Q	PARTICIPANT	\N	PRESENT	0
398823	393596	11067R	PARTICIPANT	\N	PRESENT	0
398824	393596	19531S	PARTICIPANT	\N	PRESENT	0
398825	393596	19503N	PARTICIPANT	\N	PRESENT	0
398826	393596	11109J	PARTICIPANT	\N	PRESENT	0
398827	393596	19681G	PARTICIPANT	\N	PRESENT	0
398828	393596	11054L	PARTICIPANT	\N	PRESENT	0
398829	393596	08053X	PARTICIPANT	\N	PRESENT	0
398830	393596	19295A	PARTICIPANT	\N	PRESENT	0
398831	393596	19489J	PARTICIPANT	\N	PRESENT	0
398832	393596	98024R	PARTICIPANT	\N	PRESENT	0
398833	393596	14026U	PARTICIPANT	\N	PRESENT	0
398834	393596	08043V	PARTICIPANT	\N	PRESENT	0
398835	393596	19251M	PARTICIPANT	\N	PRESENT	0
398836	393596	95030B	PARTICIPANT	\N	PRESENT	0
398837	393596	19413M	PARTICIPANT	\N	PRESENT	0
398838	393596	14187A	PARTICIPANT	\N	PRESENT	0
398839	393596	04044E	PARTICIPANT	\N	PRESENT	0
398840	393596	04086Q	PARTICIPANT	\N	PRESENT	0
398841	393596	11072N	PARTICIPANT	\N	PRESENT	0
398842	393596	19421M	PARTICIPANT	\N	PRESENT	0
398843	393596	11097X	PARTICIPANT	\N	PRESENT	0
398844	393596	02002K	PARTICIPANT	\N	PRESENT	0
398845	393596	04033B	PARTICIPANT	\N	PRESENT	0
398846	393596	11104D	PARTICIPANT	\N	PRESENT	0
398847	393596	11027H	PARTICIPANT	\N	PRESENT	0
398848	393596	14069U	PARTICIPANT	\N	PRESENT	0
398849	393596	19551W	PARTICIPANT	\N	PRESENT	0
398850	393596	04043D	PARTICIPANT	\N	PRESENT	0
398851	393596	14249W	PARTICIPANT	\N	PRESENT	0
398852	393596	19549D	PARTICIPANT	\N	PRESENT	0
398853	393596	14053L	PARTICIPANT	\N	PRESENT	0
398854	393596	08014Q	PARTICIPANT	\N	PRESENT	0
398855	393596	19333N	PARTICIPANT	\N	PRESENT	0
398856	393596	14087W	PARTICIPANT	\N	PRESENT	0
398857	393596	19689Q	PARTICIPANT	\N	PRESENT	0
398858	393596	19671E	PARTICIPANT	\N	PRESENT	0
398859	393596	14063N	PARTICIPANT	\N	PRESENT	0
398860	393596	19798U	PARTICIPANT	\N	PRESENT	0
398861	393596	10006L	PARTICIPANT	\N	PRESENT	0
398862	393596	80027E	PARTICIPANT	\N	PRESENT	0
398863	393596	14257W	PARTICIPANT	\N	PRESENT	0
398864	393596	14081Q	PARTICIPANT	\N	PRESENT	0
398865	393596	19533U	PARTICIPANT	\N	PRESENT	0
398866	393596	11066Q	PARTICIPANT	\N	PRESENT	0
398867	393596	14281W	PARTICIPANT	\N	PRESENT	0
398868	393596	08034U	PARTICIPANT	\N	PRESENT	0
398869	393596	05012A	PARTICIPANT	\N	PRESENT	0
398870	393596	11041F	PARTICIPANT	\N	PRESENT	0
398871	393596	08060W	PARTICIPANT	\N	PRESENT	0
398872	393596	97011G	PARTICIPANT	\N	PRESENT	0
398873	393596	11103C	PARTICIPANT	\N	PRESENT	0
398874	393596	14217N	PARTICIPANT	\N	PRESENT	0
398875	393596	14079W	PARTICIPANT	\N	PRESENT	0
398876	393596	19581D	PARTICIPANT	\N	PRESENT	0
398877	393596	14231L	PARTICIPANT	\N	PRESENT	0
398878	393596	19747H	PARTICIPANT	\N	PRESENT	0
398879	393596	08031R	PARTICIPANT	\N	PRESENT	0
398880	393596	19367Y	PARTICIPANT	\N	PRESENT	0
398881	393596	08044W	PARTICIPANT	\N	PRESENT	0
398882	393596	19621T	PARTICIPANT	\N	PRESENT	0
398883	393596	19521Q	PARTICIPANT	\N	PRESENT	0
398884	393596	04018C	PARTICIPANT	\N	PRESENT	0
398885	393596	14179A	PARTICIPANT	\N	PRESENT	0
398886	393596	01034P	PARTICIPANT	\N	PRESENT	0
398887	393596	19701S	PARTICIPANT	\N	PRESENT	0
398888	393596	19762G	PARTICIPANT	\N	PRESENT	0
398889	393596	11053K	PARTICIPANT	\N	PRESENT	0
398890	393596	19369B	PARTICIPANT	\N	PRESENT	0
398891	393596	19383Y	PARTICIPANT	\N	PRESENT	0
398892	393596	19611R	PARTICIPANT	\N	PRESENT	0
398893	393596	19675J	PARTICIPANT	\N	PRESENT	0
398894	393596	19511N	PARTICIPANT	\N	PRESENT	0
398895	393596	14357A	PARTICIPANT	\N	PRESENT	0
398896	393596	19699S	PARTICIPANT	\N	PRESENT	0
398897	393596	14061L	PARTICIPANT	\N	PRESENT	0
398898	393596	19721W	PARTICIPANT	\N	PRESENT	0
398899	393596	14205J	PARTICIPANT	\N	PRESENT	0
398900	393596	19737F	PARTICIPANT	\N	PRESENT	0
398901	393596	19569H	PARTICIPANT	\N	PRESENT	0
398902	393596	19739H	PARTICIPANT	\N	PRESENT	0
408535	402274	95041E	PARTICIPANT	\N	PRESENT	0
408536	402274	04088S	PARTICIPANT	\N	PRESENT	0
408537	402274	11101A	PARTICIPANT	\N	PRESENT	0
408538	402274	14033T	PARTICIPANT	\N	PRESENT	0
408539	402274	19703U	PARTICIPANT	\N	PRESENT	0
408540	402274	19515S	PARTICIPANT	\N	PRESENT	0
408541	402274	15447F	PARTICIPANT	\N	PRESENT	0
408542	402274	14038Y	PARTICIPANT	\N	PRESENT	0
408543	402274	19794Q	PARTICIPANT	\N	PRESENT	0
408544	402274	19467C	PARTICIPANT	\N	PRESENT	0
408545	402274	08020N	PARTICIPANT	\N	PRESENT	0
408546	402274	19695N	PARTICIPANT	\N	PRESENT	0
408547	402274	96004D	PARTICIPANT	\N	PRESENT	0
408548	402274	14103D	PARTICIPANT	\N	PRESENT	0
408549	402274	14173T	PARTICIPANT	\N	PRESENT	0
408550	402274	14031R	PARTICIPANT	\N	PRESENT	0
408551	402274	14063N	PARTICIPANT	\N	PRESENT	0
408552	402274	19507S	PARTICIPANT	\N	PRESENT	0
408553	402274	11056N	PARTICIPANT	\N	PRESENT	0
408554	402274	11040E	PARTICIPANT	\N	PRESENT	0
408555	402274	14111D	PARTICIPANT	\N	PRESENT	0
408556	402274	19563B	PARTICIPANT	\N	PRESENT	0
408557	402274	08010L	PARTICIPANT	\N	PRESENT	0
408558	402274	14187A	PARTICIPANT	\N	PRESENT	0
408559	402274	19251M	PARTICIPANT	\N	PRESENT	0
408560	402274	11026G	PARTICIPANT	\N	PRESENT	0
408561	402274	08028W	PARTICIPANT	\N	PRESENT	0
408562	402274	08038Y	PARTICIPANT	\N	PRESENT	0
408563	402274	19681G	PARTICIPANT	\N	PRESENT	0
408564	402274	19569H	PARTICIPANT	\N	PRESENT	0
408565	402274	19369B	PARTICIPANT	\N	PRESENT	0
408566	402274	19581D	PARTICIPANT	\N	PRESENT	0
408567	402274	11103C	PARTICIPANT	\N	PRESENT	0
408568	402274	19798U	PARTICIPANT	\N	PRESENT	0
408569	402274	14053L	PARTICIPANT	\N	PRESENT	0
408570	402274	14109K	PARTICIPANT	\N	PRESENT	0
408571	402274	19760E	PARTICIPANT	\N	PRESENT	0
408572	402274	02002K	PARTICIPANT	\N	PRESENT	0
408573	402274	18083K	PARTICIPANT	\N	PRESENT	0
408574	402274	11010L	PARTICIPANT	\N	PRESENT	0
408575	402274	19383Y	PARTICIPANT	\N	PRESENT	0
408576	402274	19713W	PARTICIPANT	\N	PRESENT	0
408578	402274	87003B	PARTICIPANT	\N	PRESENT	0
408579	402274	14030Q	PARTICIPANT	\N	PRESENT	0
408664	402295	80013X	PARTICIPANT	\N	PRESENT	0
408665	402295	11110B	PARTICIPANT	\N	PRESENT	0
408666	402295	19725B	PARTICIPANT	\N	PRESENT	0
408667	402295	19715Y	PARTICIPANT	\N	PRESENT	0
408668	402295	14109K	PARTICIPANT	\N	PRESENT	0
408669	402295	14097Y	PARTICIPANT	\N	PRESENT	0
408670	402295	14111D	PARTICIPANT	\N	PRESENT	0
408671	402295	19563B	PARTICIPANT	\N	PRESENT	0
408672	402295	19681G	PARTICIPANT	\N	PRESENT	0
408673	402295	14121F	PARTICIPANT	\N	PRESENT	0
408674	402295	19782L	PARTICIPANT	\N	PRESENT	0
408675	402295	14107H	PARTICIPANT	\N	PRESENT	0
408676	402295	11012A	PARTICIPANT	\N	PRESENT	0
408677	402295	14267Y	PARTICIPANT	\N	PRESENT	0
408678	402295	14103D	PARTICIPANT	\N	PRESENT	0
408679	402295	19691J	PARTICIPANT	\N	PRESENT	0
408680	402295	19253P	PARTICIPANT	\N	PRESENT	0
408681	402295	19369B	PARTICIPANT	\N	PRESENT	0
408682	402295	19521Q	PARTICIPANT	\N	PRESENT	0
408683	402295	11033F	PARTICIPANT	\N	PRESENT	0
408684	402295	11040E	PARTICIPANT	\N	PRESENT	0
408685	402295	11056N	PARTICIPANT	\N	PRESENT	0
408686	402295	08055A	PARTICIPANT	\N	PRESENT	0
408687	402295	05008E	PARTICIPANT	\N	PRESENT	0
408688	402295	14030Q	PARTICIPANT	\N	PRESENT	0
408689	402295	14179A	PARTICIPANT	\N	PRESENT	0
408690	402295	01025N	PARTICIPANT	\N	PRESENT	0
408691	402295	01028R	PARTICIPANT	\N	PRESENT	0
408692	402295	14329V	PARTICIPANT	\N	PRESENT	0
408693	402295	89017R	PARTICIPANT	\N	PRESENT	0
408694	402295	19685L	PARTICIPANT	\N	PRESENT	0
408533	402274	14157T	PARTICIPANT	\N	PRESENT	0
408534	402274	14135M	PARTICIPANT	\N	PRESENT	0
408695	402295	01060R	PARTICIPANT	\N	PRESENT	0
408696	402295	19762G	PARTICIPANT	\N	PRESENT	0
408697	402295	04069P	PARTICIPANT	\N	PRESENT	0
408698	402295	19798U	PARTICIPANT	\N	PRESENT	0
408699	402295	08034U	PARTICIPANT	\N	PRESENT	0
408700	402295	14187A	PARTICIPANT	\N	PRESENT	0
408701	402295	95041E	PARTICIPANT	\N	PRESENT	0
408702	402295	08062Y	PARTICIPANT	\N	PRESENT	0
408703	402295	14033T	PARTICIPANT	\N	PRESENT	0
408704	402295	14119M	PARTICIPANT	\N	PRESENT	0
408705	402295	19507S	PARTICIPANT	\N	PRESENT	0
408706	402295	87003B	PARTICIPANT	\N	PRESENT	0
408707	402295	08010L	PARTICIPANT	\N	PRESENT	0
408708	402295	04088S	PARTICIPANT	\N	PRESENT	0
408709	402295	11101A	PARTICIPANT	\N	PRESENT	0
408710	402295	18083K	PARTICIPANT	\N	PRESENT	0
408711	402295	19467C	PARTICIPANT	\N	PRESENT	0
408712	402295	19794Q	PARTICIPANT	\N	PRESENT	0
408713	402295	11010L	PARTICIPANT	\N	PRESENT	0
408714	402295	15447F	PARTICIPANT	\N	PRESENT	0
408715	402295	14151M	PARTICIPANT	\N	PRESENT	0
408716	402295	14173T	PARTICIPANT	\N	PRESENT	0
408717	402295	19741B	PARTICIPANT	\N	PRESENT	0
408718	402295	19383Y	PARTICIPANT	\N	PRESENT	0
408719	402295	14042U	PARTICIPANT	\N	PRESENT	0
408720	402295	99004R	PARTICIPANT	\N	PRESENT	0
408721	402295	11103C	PARTICIPANT	\N	PRESENT	0
408722	402295	14157T	PARTICIPANT	\N	PRESENT	0
408723	402295	19679N	PARTICIPANT	\N	PRESENT	0
408724	402295	14211G	PARTICIPANT	\N	PRESENT	0
408725	402295	96004D	PARTICIPANT	\N	PRESENT	0
408726	402295	14219Q	PARTICIPANT	\N	PRESENT	0
408727	402295	19739H	PARTICIPANT	\N	PRESENT	0
408728	402295	19553Y	PARTICIPANT	\N	PRESENT	0
408729	402295	95030B	PARTICIPANT	\N	PRESENT	0
408730	402295	14201E	PARTICIPANT	\N	PRESENT	0
408731	402295	14217N	PARTICIPANT	\N	PRESENT	0
408732	402295	19671E	PARTICIPANT	\N	PRESENT	0
408733	402295	14265W	PARTICIPANT	\N	PRESENT	0
408734	402295	08061X	PARTICIPANT	\N	PRESENT	0
408735	402295	14123H	PARTICIPANT	\N	PRESENT	0
408736	402295	08069G	PARTICIPANT	\N	PRESENT	0
408737	402295	19549D	PARTICIPANT	\N	PRESENT	0
408738	402295	14257W	PARTICIPANT	\N	PRESENT	0
408739	402295	11066Q	PARTICIPANT	\N	PRESENT	0
408740	402295	14065Q	PARTICIPANT	\N	PRESENT	0
408741	402295	19599P	PARTICIPANT	\N	PRESENT	0
408742	402295	14195A	PARTICIPANT	\N	PRESENT	0
408662	402295	11070L	PARTICIPANT	\N	PRESENT	0
408663	402295	14069U	PARTICIPANT	\N	PRESENT	0
408743	402295	19747H	PARTICIPANT	\N	PRESENT	0
408744	402295	19703U	PARTICIPANT	\N	PRESENT	0
408745	402295	11043H	PARTICIPANT	\N	PRESENT	0
408746	402295	14253S	PARTICIPANT	\N	PRESENT	0
408747	402295	14053L	PARTICIPANT	\N	PRESENT	0
408748	402295	14197C	PARTICIPANT	\N	PRESENT	0
408749	402295	11045K	PARTICIPANT	\N	PRESENT	0
408750	402295	14147R	PARTICIPANT	\N	PRESENT	0
408751	402295	19629C	PARTICIPANT	\N	PRESENT	0
408753	402295	19447X	PARTICIPANT	\N	PRESENT	0
408754	402295	19533U	PARTICIPANT	\N	PRESENT	0
408755	402295	04085P	PARTICIPANT	\N	PRESENT	0
408756	402295	11067R	PARTICIPANT	\N	PRESENT	0
408757	402295	19565D	PARTICIPANT	\N	PRESENT	0
408758	402295	14357A	PARTICIPANT	\N	PRESENT	0
408759	402295	08020N	PARTICIPANT	\N	PRESENT	0
408760	402295	10006L	PARTICIPANT	\N	PRESENT	0
408761	402295	14237S	PARTICIPANT	\N	PRESENT	0
408762	402295	19367Y	PARTICIPANT	\N	PRESENT	0
408763	402295	14215L	PARTICIPANT	\N	PRESENT	0
408764	402295	14221J	PARTICIPANT	\N	PRESENT	0
408765	402295	14031R	PARTICIPANT	\N	PRESENT	0
408766	402295	04033B	PARTICIPANT	\N	PRESENT	0
408767	402295	14199E	PARTICIPANT	\N	PRESENT	0
408768	402295	14061L	PARTICIPANT	\N	PRESENT	0
408769	402295	14026U	PARTICIPANT	\N	PRESENT	0
408770	407391	14327T	PARTICIPANT	\N	PRESENT	0
408771	407391	14331P	PARTICIPANT	\N	PRESENT	0
408772	407391	04071H	PARTICIPANT	\N	PRESENT	0
408773	407391	95041E	PARTICIPANT	\N	PRESENT	0
408774	407391	19545Y	PARTICIPANT	\N	PRESENT	0
408775	407391	01057W	PARTICIPANT	\N	PRESENT	0
408776	407391	11053K	PARTICIPANT	\N	PRESENT	0
408777	407391	19667J	PARTICIPANT	\N	PRESENT	0
408778	407391	11074Q	PRESIDENT	0	PRESENT	0
408779	407391	89017R	PARTICIPANT	\N	PRESENT	0
408780	407391	88008L	PARTICIPANT	\N	PRESENT	0
408781	407391	14225N	PARTICIPANT	\N	PRESENT	0
408782	407391	19671E	PARTICIPANT	\N	PRESENT	0
408783	407391	11110B	PARTICIPANT	\N	PRESENT	0
408784	407391	14085U	PARTICIPANT	\N	PRESENT	0
397597	397596	19631V	PARTICIPANT	\N	PRESENT	0
397598	397596	01048V	PARTICIPANT	\N	PRESENT	0
397599	397596	19533U	PARTICIPANT	\N	PRESENT	0
397600	397596	14257W	PARTICIPANT	\N	PRESENT	0
398002	396130	19691J	PARTICIPANT	\N	PRESENT	0
398003	396130	19715Y	PARTICIPANT	\N	PRESENT	0
398004	396130	19729F	PARTICIPANT	\N	EXCUSE	0
398005	396130	14219Q	PARTICIPANT	\N	EXCUSE	0
398006	396130	08019V	PRESIDENT	0	PRESENT	0
398007	396130	19657G	PARTICIPANT	\N	PRESENT	0
398008	396130	11072N	PARTICIPANT	\N	EXCUSE	0
398009	396130	19329S	PARTICIPANT	\N	EXCUSE	0
398010	396130	14030Q	PARTICIPANT	\N	PRESENT	0
398011	396130	11045K	PARTICIPANT	\N	PRESENT	0
398012	396130	19701S	PARTICIPANT	\N	PRESENT	0
398013	396130	19269X	PARTICIPANT	\N	PRESENT	0
398014	396130	11067R	PARTICIPANT	\N	PRESENT	0
398015	396130	19749K	PARTICIPANT	\N	PRESENT	0
398017	393594	11041F	PARTICIPANT	\N	PRESENT	0
398018	393594	19629C	PARTICIPANT	\N	PRESENT	0
398019	393594	17589D	PARTICIPANT	\N	PRESENT	0
398020	393594	14039A	PARTICIPANT	\N	PRESENT	0
398021	393594	19479G	PARTICIPANT	\N	PRESENT	0
398022	393594	19349W	PARTICIPANT	\N	PRESENT	0
398023	393594	14331P	PARTICIPANT	\N	PRESENT	0
398024	393594	95037J	PARTICIPANT	\N	PRESENT	0
398025	393594	15447F	PARTICIPANT	\N	PRESENT	0
398026	393594	98018T	PARTICIPANT	\N	PRESENT	0
398027	393594	07033P	PARTICIPANT	\N	PRESENT	0
398028	393594	14275Y	PARTICIPANT	\N	PRESENT	0
398029	393594	14041T	PARTICIPANT	\N	PRESENT	0
398030	393594	19798U	PARTICIPANT	\N	PRESENT	0
398031	393594	11040E	PARTICIPANT	\N	PRESENT	0
398032	393594	08052W	PARTICIPANT	\N	PRESENT	0
398033	393594	04047H	PARTICIPANT	\N	PRESENT	0
398034	393594	04049K	PARTICIPANT	\N	PRESENT	0
398035	393594	19329S	PARTICIPANT	\N	PRESENT	0
398036	393594	95062K	PARTICIPANT	\N	PRESENT	0
398037	393594	99004R	PARTICIPANT	\N	PRESENT	0
398038	393594	19715Y	PARTICIPANT	\N	PRESENT	0
398039	393594	11101A	PARTICIPANT	\N	PRESENT	0
398000	396130	14261S	PARTICIPANT	\N	PRESENT	0
398001	396130	19577H	PARTICIPANT	\N	EXCUSE	0
398040	393594	14051J	PARTICIPANT	\N	PRESENT	0
398041	393594	11056N	PARTICIPANT	\N	PRESENT	0
398042	393594	19467C	PARTICIPANT	\N	PRESENT	0
398043	393594	14265W	PARTICIPANT	\N	PRESENT	0
398044	393594	10006L	PARTICIPANT	\N	PRESENT	0
398045	393594	14253S	PARTICIPANT	\N	PRESENT	0
398046	393594	14135M	PARTICIPANT	\N	PRESENT	0
398047	393594	19643A	PARTICIPANT	\N	PRESENT	0
398048	393594	14187A	PARTICIPANT	\N	PRESENT	0
398049	393594	96004D	PARTICIPANT	\N	PRESENT	0
398050	393594	14217N	PARTICIPANT	\N	PRESENT	0
398051	393594	11097X	PARTICIPANT	\N	PRESENT	0
398052	393594	19693L	PARTICIPANT	\N	PRESENT	0
398053	393594	19581D	PARTICIPANT	\N	PRESENT	0
398054	393594	14033T	PARTICIPANT	\N	PRESENT	0
398055	393594	19711U	PARTICIPANT	\N	PRESENT	0
398056	393594	04088S	PARTICIPANT	\N	PRESENT	0
398057	393594	19515S	PARTICIPANT	\N	PRESENT	0
398058	393594	98024R	PARTICIPANT	\N	PRESENT	0
398059	393594	19399H	PARTICIPANT	\N	PRESENT	0
398060	393594	19421M	PARTICIPANT	\N	PRESENT	0
398061	393594	95067Q	PARTICIPANT	\N	PRESENT	0
398062	393594	19747H	PARTICIPANT	\N	PRESENT	0
398063	393594	19705W	PARTICIPANT	\N	PRESENT	0
398064	393594	19573D	PARTICIPANT	\N	PRESENT	0
398065	393594	19575F	PARTICIPANT	\N	PRESENT	0
398066	393594	19762G	PARTICIPANT	\N	PRESENT	0
398067	393594	04033B	PARTICIPANT	\N	PRESENT	0
398068	393594	14169X	PARTICIPANT	\N	PRESENT	0
398071	393594	98050T	PARTICIPANT	\N	PRESENT	0
398072	393594	14235Q	PARTICIPANT	\N	PRESENT	0
398073	393594	04085P	PARTICIPANT	\N	PRESENT	0
398075	393594	14031R	PARTICIPANT	\N	PRESENT	0
398077	393594	19758L	PARTICIPANT	\N	PRESENT	0
398078	393594	19760E	PARTICIPANT	\N	PRESENT	0
398079	393594	04044E	PARTICIPANT	\N	PRESENT	0
398081	393594	19565D	PARTICIPANT	\N	PRESENT	0
398082	393594	19695N	PARTICIPANT	\N	PRESENT	0
398083	393594	14026U	PARTICIPANT	\N	PRESENT	0
398084	393594	14123H	PARTICIPANT	\N	PRESENT	0
398085	393594	95063L	PARTICIPANT	\N	PRESENT	0
398087	393594	19651A	PARTICIPANT	\N	PRESENT	0
398088	393594	05008E	PARTICIPANT	\N	PRESENT	0
398089	393594	19637C	PARTICIPANT	\N	PRESENT	0
398091	393594	19697Q	PARTICIPANT	\N	PRESENT	0
398092	393594	19269X	PARTICIPANT	\N	PRESENT	0
398093	393594	08024S	PARTICIPANT	\N	PRESENT	0
398095	393594	19673G	PARTICIPANT	\N	PRESENT	0
398096	393594	08039A	PARTICIPANT	\N	PRESENT	0
398097	393594	11072N	PARTICIPANT	\N	PRESENT	0
398100	393594	04057K	PARTICIPANT	\N	PRESENT	0
398102	393594	14249W	PARTICIPANT	\N	PRESENT	0
398104	393594	14261S	PARTICIPANT	\N	PRESENT	0
398105	393594	19253P	PARTICIPANT	\N	PRESENT	0
398106	393594	14207L	PARTICIPANT	\N	PRESENT	0
398107	393594	19681G	PARTICIPANT	\N	PRESENT	0
398108	393594	19719D	PARTICIPANT	\N	PRESENT	0
398109	393594	19553Y	PARTICIPANT	\N	PRESENT	0
398111	393594	19387D	PARTICIPANT	\N	PRESENT	0
398112	393594	19685L	PARTICIPANT	\N	PRESENT	0
398113	393594	01028R	PARTICIPANT	\N	PRESENT	0
398114	393594	19669L	PARTICIPANT	\N	PRESENT	0
398115	393594	19367Y	PARTICIPANT	\N	PRESENT	0
398116	393594	08068F	PARTICIPANT	\N	PRESENT	0
398117	393594	11031D	PARTICIPANT	\N	PRESENT	0
398118	393594	08020N	PARTICIPANT	\N	PRESENT	0
398119	393594	11065P	PARTICIPANT	\N	PRESENT	0
398120	393594	11074Q	PARTICIPANT	\N	PRESENT	0
398121	393594	14021P	PARTICIPANT	\N	PRESENT	0
398122	393594	11033F	PARTICIPANT	\N	PRESENT	0
398123	393594	14151M	PARTICIPANT	\N	PRESENT	0
398124	393594	08055A	PARTICIPANT	\N	PRESENT	0
398125	393594	19347U	PARTICIPANT	\N	PRESENT	0
398126	393594	11045K	PARTICIPANT	\N	PRESENT	0
398127	393594	19689Q	PARTICIPANT	\N	PRESENT	0
398128	393594	11066Q	PARTICIPANT	\N	PRESENT	0
398129	393594	14281W	PARTICIPANT	\N	PRESENT	0
398130	393594	19447X	PARTICIPANT	\N	PRESENT	0
398131	393594	19687N	PARTICIPANT	\N	PRESENT	0
398132	393594	19794Q	PARTICIPANT	\N	PRESENT	0
398133	393594	14081Q	PARTICIPANT	\N	PRESENT	0
398134	393594	14257W	PARTICIPANT	\N	PRESENT	0
398135	393594	19525U	PARTICIPANT	\N	PRESENT	0
398136	393594	14085U	PARTICIPANT	\N	PRESENT	0
398137	393594	19663E	PARTICIPANT	\N	PRESENT	0
398138	393594	19333N	PARTICIPANT	\N	PRESENT	0
398139	393594	14227Q	PARTICIPANT	\N	PRESENT	0
398140	393594	19631V	PARTICIPANT	\N	PRESENT	0
398141	393594	19503N	PARTICIPANT	\N	PRESENT	0
398142	393594	11067R	PARTICIPANT	\N	PRESENT	0
398143	393594	07029T	PARTICIPANT	\N	PRESENT	0
398144	393594	11077T	PARTICIPANT	\N	PRESENT	0
398145	393594	19413M	PARTICIPANT	\N	PRESENT	0
398146	393594	19301E	PARTICIPANT	\N	PRESENT	0
398147	393594	19369B	PARTICIPANT	\N	PRESENT	0
398148	393594	19691J	PARTICIPANT	\N	PRESENT	0
398150	393594	19611R	PARTICIPANT	\N	PRESENT	0
398151	393594	19737F	PARTICIPANT	\N	PRESENT	0
398153	393594	19699S	PARTICIPANT	\N	PRESENT	0
398154	393594	19569H	PARTICIPANT	\N	PRESENT	0
398155	393594	14251Q	PARTICIPANT	\N	PRESENT	0
398156	393594	14111D	PARTICIPANT	\N	PRESENT	0
398157	393594	19585H	PARTICIPANT	\N	PRESENT	0
398158	393594	14195A	PARTICIPANT	\N	PRESENT	0
398159	393594	14219Q	PARTICIPANT	\N	PRESENT	0
398160	393594	19441R	PARTICIPANT	\N	PRESENT	0
398161	393594	19713W	PARTICIPANT	\N	PRESENT	0
398162	393594	14030Q	PARTICIPANT	\N	PRESENT	0
398163	393594	04070G	PARTICIPANT	\N	PRESENT	0
398164	393594	14083S	PARTICIPANT	\N	PRESENT	0
398165	393594	11070L	PARTICIPANT	\N	PRESENT	0
398166	393594	14221J	PARTICIPANT	\N	PRESENT	0
398167	393594	04089T	PARTICIPANT	\N	PRESENT	0
398168	393594	19739H	PARTICIPANT	\N	PRESENT	0
398169	393594	08056B	PARTICIPANT	\N	PRESENT	0
398170	393594	08034U	PARTICIPANT	\N	PRESENT	0
398171	393594	11053K	PARTICIPANT	\N	PRESENT	0
398172	393594	19701S	PARTICIPANT	\N	PRESENT	0
398173	393594	11080N	PARTICIPANT	\N	PRESENT	0
398174	393594	08073C	PARTICIPANT	\N	PRESENT	0
398175	393594	14267Y	PARTICIPANT	\N	PRESENT	0
398176	393594	11027H	PARTICIPANT	\N	PRESENT	0
398177	393594	14069U	PARTICIPANT	\N	PRESENT	0
398178	393594	19443T	PARTICIPANT	\N	PRESENT	0
398179	393594	19741B	PARTICIPANT	\N	PRESENT	0
398180	393594	14093U	PARTICIPANT	\N	PRESENT	0
413664	406848	14111D	PARTICIPANT	\N	PRESENT	0
413665	406848	14211G	PARTICIPANT	\N	PRESENT	0
413666	406848	19583F	PARTICIPANT	\N	PRESENT	0
413667	406848	19711U	PARTICIPANT	\N	PRESENT	0
413668	406848	14151M	PARTICIPANT	\N	PRESENT	0
413669	406848	19573D	PARTICIPANT	\N	PRESENT	0
413670	406848	08034U	PARTICIPANT	\N	PRESENT	0
413671	406848	14033T	PARTICIPANT	\N	PRESENT	0
413672	406848	19651A	PARTICIPANT	\N	PRESENT	0
413673	406848	19503N	PARTICIPANT	\N	PRESENT	0
413674	406848	14103D	PARTICIPANT	\N	PRESENT	0
413675	406848	08061X	PARTICIPANT	\N	PRESENT	0
413949	408325	19369B	PARTICIPANT	\N	PRESENT	0
413677	406848	08009T	PARTICIPANT	\N	PRESENT	0
413678	406848	19387D	PARTICIPANT	\N	PRESENT	0
413682	406848	14081Q	PARTICIPANT	\N	PRESENT	0
413684	406848	08010L	PARTICIPANT	\N	PRESENT	0
413686	406848	08020N	PARTICIPANT	\N	PRESENT	0
413688	406848	14123H	PARTICIPANT	\N	PRESENT	0
413690	406848	19733B	PARTICIPANT	\N	PRESENT	0
413691	406848	19335Q	PARTICIPANT	\N	PRESENT	0
413693	406848	19295A	PARTICIPANT	\N	PRESENT	0
413695	406848	04085P	PARTICIPANT	\N	PRESENT	0
413699	406848	14275Y	PARTICIPANT	\N	PRESENT	0
413700	406848	19441R	PARTICIPANT	\N	PRESENT	0
413704	406848	19563B	PARTICIPANT	\N	PRESENT	0
413705	406848	14187A	PARTICIPANT	\N	PRESENT	0
413709	406848	19521Q	PARTICIPANT	\N	PRESENT	0
413710	406848	01024M	PARTICIPANT	\N	PRESENT	0
413711	406848	11097X	PARTICIPANT	\N	PRESENT	0
413712	406848	19691J	PARTICIPANT	\N	PRESENT	0
413721	406848	19695N	PARTICIPANT	\N	PRESENT	0
413722	406848	98050T	PARTICIPANT	\N	PRESENT	0
413723	406848	19673G	PARTICIPANT	\N	PRESENT	0
413724	406848	19719D	PARTICIPANT	\N	PRESENT	0
413775	413771	14133K	PARTICIPANT	\N	PRESENT	0
413777	413771	08058D	PARTICIPANT	\N	PRESENT	0
413799	413798	98029W	PARTICIPANT	\N	PRESENT	0
413800	413798	98050T	PARTICIPANT	\N	PRESENT	0
413802	413801	04040A	PARTICIPANT	\N	PRESENT	0
413803	413801	14235Q	PARTICIPANT	\N	PRESENT	0
413805	413804	04040A	PARTICIPANT	\N	PRESENT	0
413806	413804	14235Q	PARTICIPANT	\N	PRESENT	0
413948	408325	08062Y	PARTICIPANT	\N	EXCUSE	0
413959	413958	98050T	PARTICIPANT	\N	PRESENT	0
413969	412265	14028W	PARTICIPANT	\N	EXCUSE	0
413970	408325	08012N	PARTICIPANT	\N	PRESENT	0
413972	413971	98024R	PARTICIPANT	\N	PRESENT	0
413985	408325	89017R	PARTICIPANT	\N	EXCUSE	0
414087	412265	14259Y	PARTICIPANT	\N	EXCUSE	0
414144	414027	08049C	PARTICIPANT	\N	EXCUSE	0
414271	410851	04092N	PARTICIPANT	\N	PRESENT	0
414300	410852	04092N	PARTICIPANT	\N	PRESENT	0
414336	408325	19467C	PARTICIPANT	\N	EXCUSE	0
414420	414419	19737F	PARTICIPANT	\N	EXCUSE	0
414747	413358	14327T	PARTICIPANT	\N	PRESENT	0
414748	413358	19479G	PARTICIPANT	\N	PRESENT	0
414749	413358	95041E	PARTICIPANT	\N	PRESENT	0
414750	413358	11053K	PARTICIPANT	\N	PRESENT	0
414751	413358	12016W	PARTICIPANT	\N	PRESENT	0
414752	413358	08011M	PARTICIPANT	\N	PRESENT	0
414753	413358	19671E	PARTICIPANT	\N	PRESENT	0
414754	413358	11012A	PARTICIPANT	\N	PRESENT	0
414755	413358	07004J	PARTICIPANT	\N	PRESENT	0
414756	413358	19741B	PARTICIPANT	\N	PRESENT	0
414757	413358	99004R	PARTICIPANT	\N	PRESENT	0
414758	413358	19511N	PARTICIPANT	\N	PRESENT	0
414759	413358	04043D	PARTICIPANT	\N	PRESENT	0
414760	413358	11074Q	PRESIDENT	0	PRESENT	0
414761	413358	19711U	PARTICIPANT	\N	PRESENT	0
414762	413358	01048V	PARTICIPANT	\N	PRESENT	0
414763	413358	14034U	PARTICIPANT	\N	PRESENT	0
414764	413358	11070L	PARTICIPANT	\N	PRESENT	0
414765	413358	11040E	PARTICIPANT	\N	PRESENT	0
414766	413358	14085U	PARTICIPANT	\N	PRESENT	0
414767	413358	08073C	PARTICIPANT	\N	PRESENT	0
414768	413358	19349W	PARTICIPANT	\N	PRESENT	0
414769	413358	14121F	PARTICIPANT	\N	PRESENT	0
414770	413358	14331P	PARTICIPANT	\N	PRESENT	0
414771	413358	14225N	PARTICIPANT	\N	PRESENT	0
414772	413358	88008L	PARTICIPANT	\N	PRESENT	0
414773	413358	07029T	PARTICIPANT	\N	PRESENT	0
414774	413358	08010L	PARTICIPANT	\N	PRESENT	0
414775	413358	14253S	PARTICIPANT	\N	PRESENT	0
414776	413358	11048N	PARTICIPANT	\N	PRESENT	0
414777	413358	08069G	PARTICIPANT	\N	PRESENT	0
414778	413358	19687N	PARTICIPANT	\N	PRESENT	0
414779	413358	08014Q	PARTICIPANT	\N	PRESENT	0
414780	413358	14173T	PARTICIPANT	\N	PRESENT	0
414781	413358	14083S	PARTICIPANT	\N	PRESENT	0
414782	413358	14199E	PARTICIPANT	\N	PRESENT	0
414783	413358	19533U	PARTICIPANT	\N	PRESENT	0
414784	413358	19387D	PARTICIPANT	\N	PRESENT	0
414785	413358	14237S	PARTICIPANT	\N	PRESENT	0
414786	413358	08034U	PARTICIPANT	\N	PRESENT	0
414787	413358	19369B	PARTICIPANT	\N	PRESENT	0
414788	413358	19691J	PARTICIPANT	\N	PRESENT	0
414789	413358	19647E	PARTICIPANT	\N	PRESENT	0
414790	413358	01057W	PARTICIPANT	\N	EXCUSE	0
414791	413358	14159V	PARTICIPANT	\N	EXCUSE	0
414792	413357	19729F	PARTICIPANT	\N	PRESENT	0
414793	413357	14111D	PARTICIPANT	\N	PRESENT	0
414794	413357	14041T	PARTICIPANT	\N	PRESENT	0
414795	413357	04044E	PARTICIPANT	\N	PRESENT	0
414796	413357	19585H	PARTICIPANT	\N	PRESENT	0
414798	413357	19675J	PARTICIPANT	\N	EXCUSE	0
414799	414029	08056B	PARTICIPANT	\N	PRESENT	0
414800	414029	04034C	PARTICIPANT	\N	PRESENT	0
414801	414029	11041F	PARTICIPANT	\N	PRESENT	0
414802	414029	19709B	PARTICIPANT	\N	PRESENT	0
414803	414029	14235Q	PARTICIPANT	\N	PRESENT	0
414804	414029	14267Y	PARTICIPANT	\N	PRESENT	0
414805	414029	16685X	PARTICIPANT	\N	PRESENT	0
414806	414029	98050T	PARTICIPANT	\N	PRESENT	0
414807	414029	04042C	PRESIDENT	0	PRESENT	0
414808	414029	14028W	PARTICIPANT	\N	PRESENT	0
414809	414029	11066Q	PARTICIPANT	\N	PRESENT	0
414810	413357	19543W	PARTICIPANT	\N	PRESENT	0
414811	413357	19581D	PARTICIPANT	\N	PRESENT	0
414812	413357	19447X	PARTICIPANT	\N	PRESENT	0
414813	413357	05008E	PRESIDENT	0	PRESENT	0
414814	414029	12041X	PARTICIPANT	\N	PRESENT	0
414815	414029	19443T	PARTICIPANT	\N	PRESENT	0
414816	414029	95030B	PARTICIPANT	\N	PRESENT	0
414817	414029	14079W	PARTICIPANT	\N	PRESENT	0
414818	414029	04040A	PARTICIPANT	\N	PRESENT	0
414819	414029	08058D	PARTICIPANT	\N	PRESENT	0
414820	414029	19319Q	PARTICIPANT	\N	PRESENT	0
414821	414029	14105F	PARTICIPANT	\N	PRESENT	0
414822	414029	19421M	PARTICIPANT	\N	PRESENT	0
414823	414029	98022P	PARTICIPANT	\N	PRESENT	0
414824	414029	08047A	PARTICIPANT	\N	PRESENT	0
414825	414029	14255U	PARTICIPANT	\N	PRESENT	0
414826	414029	98029W	PARTICIPANT	\N	PRESENT	0
414827	414029	01058X	PARTICIPANT	\N	PRESENT	0
414828	414029	19669L	PARTICIPANT	\N	PRESENT	0
414829	414029	95037J	PARTICIPANT	\N	PRESENT	0
414830	414029	14193X	PARTICIPANT	\N	PRESENT	0
414831	414029	01062T	PARTICIPANT	\N	PRESENT	0
414832	414029	11064N	PARTICIPANT	\N	PRESENT	0
414833	414029	14211G	PARTICIPANT	\N	PRESENT	0
414834	414029	11054L	PARTICIPANT	\N	PRESENT	0
414836	412790	08009T	PRESIDENT	0	PRESENT	0
414837	412790	14051J	PARTICIPANT	\N	EXCUSE	0
414838	412790	19701S	PARTICIPANT	\N	EXCUSE	0
414839	412790	19737F	PARTICIPANT	\N	EXCUSE	0
414840	412790	19637C	PARTICIPANT	\N	EXCUSE	0
414855	413358	89017R	PARTICIPANT	\N	PRESENT	0
414856	413358	11110B	PARTICIPANT	\N	PRESENT	0
414858	414029	08061X	PARTICIPANT	\N	PRESENT	0
414859	414029	95067Q	PARTICIPANT	\N	PRESENT	0
414860	414029	14133K	PARTICIPANT	\N	PRESENT	0
414861	413357	01060R	PARTICIPANT	\N	PRESENT	0
414862	413357	14231L	PARTICIPANT	\N	PRESENT	0
414863	413357	14275Y	PARTICIPANT	\N	PRESENT	0
414864	413357	14147R	PARTICIPANT	\N	PRESENT	0
414865	413357	14151M	PARTICIPANT	\N	PRESENT	0
414866	413357	14215L	PRESIDENT	1	PRESENT	0
414867	413357	14259Y	PARTICIPANT	\N	PRESENT	0
414868	413357	11072N	PARTICIPANT	\N	PRESENT	0
414869	413357	98035U	PARTICIPANT	\N	PRESENT	0
414870	413357	14053L	PARTICIPANT	\N	PRESENT	0
414871	413357	08045X	PARTICIPANT	\N	PRESENT	0
414872	413357	19253P	PARTICIPANT	\N	PRESENT	0
414873	413357	01024M	PARTICIPANT	\N	PRESENT	0
414874	413357	04038G	PARTICIPANT	\N	PRESENT	0
414875	413357	11033F	PARTICIPANT	\N	PRESENT	0
414876	413357	19725B	PARTICIPANT	\N	PRESENT	0
392894	391363	19798U	PARTICIPANT	\N	PRESENT	0
393090	393089	14030Q	PARTICIPANT	\N	PRESENT	0
393091	393089	19701S	PARTICIPANT	\N	PRESENT	0
393092	393089	80013X	PARTICIPANT	\N	PRESENT	0
393093	393089	19693L	PARTICIPANT	\N	PRESENT	0
393094	393089	14179A	PARTICIPANT	\N	PRESENT	0
393095	393089	19731Y	PARTICIPANT	\N	PRESENT	0
393096	393089	08031R	PARTICIPANT	\N	PRESENT	0
393097	393089	08017T	PARTICIPANT	\N	PRESENT	0
393098	393089	11067R	PARTICIPANT	\N	PRESENT	0
393099	393089	19679N	PARTICIPANT	\N	PRESENT	0
393100	393089	19749K	PARTICIPANT	\N	PRESENT	0
393101	393089	08043V	PARTICIPANT	\N	EXCUSE	0
393102	393089	08024S	PARTICIPANT	\N	EXCUSE	0
393103	393089	14249W	PARTICIPANT	\N	EXCUSE	0
393104	393089	04035D	PARTICIPANT	\N	EXCUSE	0
393105	393089	01043Q	PARTICIPANT	\N	EXCUSE	0
398903	393596	19733B	PARTICIPANT	\N	PRESENT	0
398904	393596	19735D	PARTICIPANT	\N	PRESENT	0
398905	393596	01043Q	PARTICIPANT	\N	PRESENT	0
398906	393596	01062T	PARTICIPANT	\N	PRESENT	0
398907	393596	14215L	PARTICIPANT	\N	PRESENT	0
398908	393596	16685X	PARTICIPANT	\N	PRESENT	0
398909	393596	08048B	PARTICIPANT	\N	PRESENT	0
398910	393596	19441R	PARTICIPANT	\N	PRESENT	0
398911	393596	14219Q	PARTICIPANT	\N	PRESENT	0
398912	393596	19479G	PARTICIPANT	\N	PRESENT	0
398913	393596	14255U	PARTICIPANT	\N	PRESENT	0
398914	393596	14042U	PARTICIPANT	\N	PRESENT	0
398916	393596	19713W	PARTICIPANT	\N	PRESENT	0
398917	393596	14275Y	PARTICIPANT	\N	PRESENT	0
398918	393596	19705W	PARTICIPANT	\N	PRESENT	0
398919	393596	19768N	PARTICIPANT	\N	PRESENT	0
398920	393596	98050T	PARTICIPANT	\N	PRESENT	0
398921	393596	04040A	PARTICIPANT	\N	PRESENT	0
398922	393596	14267Y	PARTICIPANT	\N	PRESENT	0
398923	393596	14089Y	PARTICIPANT	\N	PRESENT	0
398924	393596	14073Q	PARTICIPANT	\N	PRESENT	0
398926	393596	14083S	PARTICIPANT	\N	PRESENT	0
398927	393596	19507S	PARTICIPANT	\N	PRESENT	0
398928	393596	01025N	PARTICIPANT	\N	PRESENT	0
398929	393596	01024M	PARTICIPANT	\N	PRESENT	0
398930	393596	11085T	PARTICIPANT	\N	PRESENT	0
398931	393596	14135M	PARTICIPANT	\N	PRESENT	0
398932	393596	08009T	PARTICIPANT	\N	PRESENT	0
398934	393596	14030Q	PARTICIPANT	\N	PRESENT	0
398936	393596	14327T	PARTICIPANT	\N	PRESENT	0
398939	393596	95067Q	PARTICIPANT	\N	PRESENT	0
398940	393596	19745F	PARTICIPANT	\N	PRESENT	0
398941	393596	11090Q	PARTICIPANT	\N	PRESENT	0
398945	393596	96004D	PARTICIPANT	\N	PRESENT	0
398946	393596	14259Y	PARTICIPANT	\N	PRESENT	0
398947	393596	08068F	PARTICIPANT	\N	PRESENT	0
398948	393596	14051J	PARTICIPANT	\N	PRESENT	0
398949	393596	19467C	PARTICIPANT	\N	PRESENT	0
398950	393596	14199E	PARTICIPANT	\N	PRESENT	0
398951	393596	14157T	PARTICIPANT	\N	PRESENT	0
398952	393596	08015R	PARTICIPANT	\N	PRESENT	0
398953	393596	14097Y	PARTICIPANT	\N	PRESENT	0
398954	393596	14213J	PARTICIPANT	\N	PRESENT	0
398955	393596	14071N	PARTICIPANT	\N	PRESENT	0
398956	393596	04092N	PARTICIPANT	\N	PRESENT	0
398957	393596	08011M	PARTICIPANT	\N	PRESENT	0
398958	393596	19729F	PARTICIPANT	\N	PRESENT	0
398962	393596	11070L	PARTICIPANT	\N	PRESENT	0
398960	393596	19525U	PARTICIPANT	\N	PRESENT	0
398961	393596	04070G	PARTICIPANT	\N	PRESENT	0
398963	393596	04071H	PARTICIPANT	\N	PRESENT	0
398964	393596	14093U	PARTICIPANT	\N	PRESENT	0
398965	393596	11065P	PARTICIPANT	\N	PRESENT	0
399228	393597	04086Q	PARTICIPANT	\N	PRESENT	0
399229	393597	19673G	PARTICIPANT	\N	PRESENT	0
399230	393597	04047H	PARTICIPANT	\N	PRESENT	0
399231	393597	07004J	PARTICIPANT	\N	PRESENT	0
399232	393597	17589D	PARTICIPANT	\N	PRESENT	0
399233	393597	14121F	PARTICIPANT	\N	PRESENT	0
399234	393597	98022P	PARTICIPANT	\N	PRESENT	0
399291	393597	01058X	PARTICIPANT	\N	PRESENT	0
399288	393597	19251M	PARTICIPANT	\N	PRESENT	0
399242	398302	14038Y	PARTICIPANT	\N	PRESENT	0
399243	398302	19333N	PARTICIPANT	\N	PRESENT	0
399263	393597	19675J	PARTICIPANT	\N	PRESENT	0
399240	393597	19758L	PARTICIPANT	\N	PRESENT	0
399241	393597	19295A	PARTICIPANT	\N	PRESENT	0
399244	398302	17583W	PARTICIPANT	\N	PRESENT	0
399245	398302	19701S	PARTICIPANT	\N	PRESENT	0
399246	398302	19794Q	PARTICIPANT	\N	PRESENT	0
399247	398302	19387D	PARTICIPANT	\N	PRESENT	0
399248	398302	14219Q	PARTICIPANT	\N	PRESENT	0
399249	398302	08055A	PARTICIPANT	\N	PRESENT	0
399250	398302	19637C	PARTICIPANT	\N	PRESENT	0
399251	398302	02002K	PARTICIPANT	\N	PRESENT	0
399252	398302	18083K	PARTICIPANT	\N	PRESENT	0
399253	398302	19551W	PARTICIPANT	\N	PRESENT	0
399254	398302	14051J	PARTICIPANT	\N	PRESENT	0
399255	398302	08060W	PARTICIPANT	\N	PRESENT	0
399256	398302	19733B	PARTICIPANT	\N	PRESENT	0
399257	398302	19503N	PARTICIPANT	\N	PRESENT	0
399258	398302	19737F	PARTICIPANT	\N	PRESENT	0
399259	398302	19745F	PARTICIPANT	\N	PRESENT	0
399260	398302	08024S	PARTICIPANT	\N	PRESENT	0
399261	398302	11065P	PARTICIPANT	\N	PRESENT	0
399262	393597	14265W	PARTICIPANT	\N	PRESENT	0
399264	393597	08020N	PARTICIPANT	\N	PRESENT	0
399265	393597	14173T	PARTICIPANT	\N	PRESENT	0
399266	393597	19447X	PARTICIPANT	\N	PRESENT	0
399267	393597	14069U	PARTICIPANT	\N	PRESENT	0
399268	393597	14021P	PARTICIPANT	\N	PRESENT	0
399269	398302	19713W	PARTICIPANT	\N	PRESENT	0
399270	398302	14157T	PARTICIPANT	\N	PRESENT	0
399271	393597	88008L	PARTICIPANT	\N	PRESENT	0
399272	393597	10015M	PARTICIPANT	\N	PRESENT	0
399273	393597	19669L	PARTICIPANT	\N	PRESENT	0
399274	393597	14219Q	PARTICIPANT	\N	PRESENT	0
399276	393597	97011G	PARTICIPANT	\N	PRESENT	0
399277	393597	14123H	PARTICIPANT	\N	PRESENT	0
399278	393597	08039A	PARTICIPANT	\N	PRESENT	0
399279	393597	11072N	PARTICIPANT	\N	PRESENT	0
399280	393597	08047A	PARTICIPANT	\N	PRESENT	0
399281	393597	14034U	PARTICIPANT	\N	PRESENT	0
399282	393597	11064N	PARTICIPANT	\N	PRESENT	0
399283	393597	14073Q	PARTICIPANT	\N	PRESENT	0
399284	393597	14211G	PARTICIPANT	\N	PRESENT	0
399285	393597	19621T	PARTICIPANT	\N	PRESENT	0
399286	393597	04018C	PARTICIPANT	\N	PRESENT	0
399287	393597	19629C	PARTICIPANT	\N	PRESENT	0
399289	393597	11043H	PARTICIPANT	\N	PRESENT	0
399290	393597	01028R	PARTICIPANT	\N	PRESENT	0
399292	393597	19719D	PARTICIPANT	\N	PRESENT	0
399293	397572	19697Q	PARTICIPANT	\N	PRESENT	0
399294	397572	01034P	PARTICIPANT	\N	PRESENT	0
399295	397572	11067R	PARTICIPANT	\N	PRESENT	0
399296	397572	04092N	PRESIDENT	0	PRESENT	0
399297	397572	19798U	PARTICIPANT	\N	PRESENT	0
399298	397572	19569H	PARTICIPANT	\N	PRESENT	0
399299	397572	11097X	PARTICIPANT	\N	PRESENT	0
399300	397572	08052W	PARTICIPANT	\N	PRESENT	0
399301	397572	14223L	PARTICIPANT	\N	PRESENT	0
399302	397572	14026U	PARTICIPANT	\N	PRESENT	0
399303	397572	14227Q	PARTICIPANT	\N	PRESENT	0
399304	397572	17779H	PARTICIPANT	\N	PRESENT	0
399305	397572	19703U	PARTICIPANT	\N	PRESENT	0
399306	397572	19553Y	PARTICIPANT	\N	PRESENT	0
399307	397572	14281W	PARTICIPANT	\N	PRESENT	0
399308	397572	11103C	PARTICIPANT	\N	PRESENT	0
399309	397572	19679N	PARTICIPANT	\N	PRESENT	0
399310	397572	14195A	PARTICIPANT	\N	PRESENT	0
399311	397572	14213J	PARTICIPANT	\N	PRESENT	0
399312	397572	14071N	PARTICIPANT	\N	PRESENT	0
399313	397572	14217N	PARTICIPANT	\N	PRESENT	0
399314	397572	10006L	PARTICIPANT	\N	PRESENT	0
399315	397572	98024R	PRESIDENT	1	PRESENT	0
399316	397572	19521Q	PARTICIPANT	\N	PRESENT	0
399317	393597	19593H	PARTICIPANT	\N	PRESENT	0
399318	393597	89017R	PARTICIPANT	\N	PRESENT	0
399319	393597	19479G	PARTICIPANT	\N	PRESENT	0
399320	398302	19549D	PARTICIPANT	\N	PRESENT	0
399321	398302	19525U	PARTICIPANT	\N	PRESENT	0
399322	398302	14031R	PARTICIPANT	\N	PRESENT	0
399323	398302	08009T	PRESIDENT	0	PRESENT	0
399324	393597	11104D	PARTICIPANT	\N	PRESENT	0
399325	393597	14151M	PARTICIPANT	\N	PRESENT	0
399326	393597	95041E	PARTICIPANT	\N	PRESENT	0
399327	393597	14231L	PARTICIPANT	\N	PRESENT	0
399328	393597	14179A	PARTICIPANT	\N	PRESENT	0
399330	393597	08056B	PARTICIPANT	\N	PRESENT	0
399331	393597	19467C	PARTICIPANT	\N	PRESENT	0
399332	393597	19399H	PARTICIPANT	\N	PRESENT	0
408785	407391	14277B	PARTICIPANT	\N	PRESENT	0
408786	407391	19349W	PARTICIPANT	\N	PRESENT	0
408787	407391	08010L	PARTICIPANT	\N	PRESENT	0
408788	407391	14253S	PARTICIPANT	\N	PRESENT	0
408789	407391	19647E	PARTICIPANT	\N	PRESENT	0
408790	407391	11048N	PARTICIPANT	\N	PRESENT	0
408791	407391	19479G	PARTICIPANT	\N	PRESENT	0
408792	407391	19711U	PARTICIPANT	\N	PRESENT	0
408793	407391	08034U	PARTICIPANT	\N	PRESENT	0
408794	407391	08069G	PARTICIPANT	\N	PRESENT	0
408795	407391	19687N	PARTICIPANT	\N	PRESENT	0
408796	407391	19689Q	PARTICIPANT	\N	PRESENT	0
408797	407391	12016W	PARTICIPANT	\N	PRESENT	0
408798	407391	08011M	PARTICIPANT	\N	PRESENT	0
408799	407391	08014Q	PARTICIPANT	\N	PRESENT	0
408800	407391	14034U	PARTICIPANT	\N	PRESENT	0
408801	407391	14173T	PARTICIPANT	\N	PRESENT	0
408802	407391	11040E	PARTICIPANT	\N	PRESENT	0
408803	407391	04086Q	PARTICIPANT	\N	PRESENT	0
408804	407391	14083S	PARTICIPANT	\N	PRESENT	0
408805	407391	11012A	PARTICIPANT	\N	PRESENT	0
408806	407391	14199E	PARTICIPANT	\N	PRESENT	0
408807	407391	08073C	PARTICIPANT	\N	PRESENT	0
408808	407391	14121F	PARTICIPANT	\N	PRESENT	0
408809	407391	19741B	PARTICIPANT	\N	PRESENT	0
408810	407391	99004R	PARTICIPANT	\N	PRESENT	0
408811	407391	07029T	PARTICIPANT	\N	EXCUSE	0
408812	407391	07004J	PARTICIPANT	\N	EXCUSE	0
408813	407391	14159V	PARTICIPANT	\N	EXCUSE	0
408858	408815	14001X	PARTICIPANT	\N	PRESENT	0
408859	408815	01060R	PARTICIPANT	\N	PRESENT	0
408860	408815	19581D	PARTICIPANT	\N	PRESENT	0
408861	408815	04044E	PARTICIPANT	\N	PRESENT	0
408862	408815	19585H	PARTICIPANT	\N	PRESENT	0
408863	408815	19447X	PARTICIPANT	\N	PRESENT	0
408864	408815	19489J	PARTICIPANT	\N	PRESENT	0
408865	408815	14275Y	PARTICIPANT	\N	PRESENT	0
408866	408815	14041T	PARTICIPANT	\N	PRESENT	0
408867	408815	14147R	PARTICIPANT	\N	PRESENT	0
408868	408815	14151M	PARTICIPANT	\N	PRESENT	0
408869	408815	14215L	PARTICIPANT	\N	PRESENT	0
408870	408815	08018U	PARTICIPANT	\N	PRESENT	0
408871	408815	11072N	PARTICIPANT	\N	PRESENT	0
408872	408815	98035U	PARTICIPANT	\N	PRESENT	0
408873	408815	19649G	PARTICIPANT	\N	PRESENT	0
408874	408815	14065Q	PARTICIPANT	\N	PRESENT	0
408875	408815	11026G	PARTICIPANT	\N	PRESENT	0
408876	408815	19253P	PARTICIPANT	\N	PRESENT	0
408877	408815	01024M	PARTICIPANT	\N	PRESENT	0
408878	408815	19719D	PARTICIPANT	\N	PRESENT	0
408879	408815	14089Y	PARTICIPANT	\N	PRESENT	0
408880	408815	19725B	PARTICIPANT	\N	PRESENT	0
408881	408815	19729F	PARTICIPANT	\N	PRESENT	0
408882	408815	08044W	PARTICIPANT	\N	PRESENT	0
408883	408815	14069U	PARTICIPANT	\N	PRESENT	0
408884	408815	11049P	PARTICIPANT	\N	PRESENT	0
408885	408815	19762G	PARTICIPANT	\N	PRESENT	0
408886	408815	14021P	PARTICIPANT	\N	PRESENT	0
408887	408815	04047H	PRESIDENT	1	PRESENT	0
408888	408829	14229S	PARTICIPANT	\N	PRESENT	0
408889	408829	19693L	PARTICIPANT	\N	PRESENT	0
408890	408829	11109J	PARTICIPANT	\N	PRESENT	0
408891	408829	19621T	PARTICIPANT	\N	PRESENT	0
408892	407378	19701S	PARTICIPANT	\N	PRESENT	0
408893	407378	08009T	PRESIDENT	0	PRESENT	0
408894	407378	19681G	PARTICIPANT	\N	PRESENT	0
408895	407378	14038Y	PARTICIPANT	\N	EXCUSE	0
408896	407378	14051J	PARTICIPANT	\N	EXCUSE	0
408897	407378	19737F	PARTICIPANT	\N	EXCUSE	0
408932	407378	15447F	PARTICIPANT	\N	PRESENT	0
408933	407378	19794Q	PARTICIPANT	\N	PRESENT	0
408934	407378	14157T	PARTICIPANT	\N	PRESENT	0
408936	407378	19333N	PARTICIPANT	\N	PRESENT	0
408937	407378	14031R	PARTICIPANT	\N	PRESENT	0
408938	407378	19599P	PARTICIPANT	\N	PRESENT	0
408939	407378	08060W	PARTICIPANT	\N	PRESENT	0
408940	407378	19820Y	PARTICIPANT	\N	PRESENT	0
408941	407378	08055A	PARTICIPANT	\N	PRESENT	0
408942	407378	19637C	PARTICIPANT	\N	PRESENT	0
408944	407378	17583W	PARTICIPANT	\N	PRESENT	0
408945	407378	14103D	PARTICIPANT	\N	PRESENT	0
408946	407378	04069P	PARTICIPANT	\N	PRESENT	0
408947	407378	19739H	PARTICIPANT	\N	PRESENT	0
408948	407378	11065P	PARTICIPANT	\N	PRESENT	0
408949	407378	18083K	PARTICIPANT	\N	PRESENT	0
408950	407378	19745F	PARTICIPANT	\N	PRESENT	0
408952	407378	08024S	PARTICIPANT	\N	PRESENT	0
408955	407378	19503N	PARTICIPANT	\N	PRESENT	0
408956	408954	11090Q	PARTICIPANT	\N	PRESENT	0
408957	408954	04049K	PARTICIPANT	\N	PRESENT	0
408958	408954	14135M	PARTICIPANT	\N	PRESENT	0
408959	408954	14197C	PARTICIPANT	\N	PRESENT	0
408960	407378	14237S	PARTICIPANT	\N	PRESENT	0
408961	408954	14205J	PARTICIPANT	\N	PRESENT	0
408962	408954	14207L	PARTICIPANT	\N	PRESENT	0
408974	407378	14219Q	PARTICIPANT	\N	PRESENT	0
408975	407378	19525U	PARTICIPANT	\N	PRESENT	0
408976	407378	19551W	PARTICIPANT	\N	PRESENT	0
408977	407378	14029X	PARTICIPANT	\N	PRESENT	0
408978	407418	14327T	PARTICIPANT	\N	PRESENT	0
408979	407418	14331P	PARTICIPANT	\N	PRESENT	0
408980	407418	01057W	PARTICIPANT	\N	PRESENT	0
408981	407418	11053K	PARTICIPANT	\N	PRESENT	0
408982	407418	89017R	PARTICIPANT	\N	PRESENT	0
408983	407418	11074Q	PRESIDENT	0	PRESENT	0
408984	407418	14225N	PARTICIPANT	\N	PRESENT	0
408985	407418	88008L	PARTICIPANT	\N	PRESENT	0
408986	407418	19671E	PARTICIPANT	\N	PRESENT	0
408987	407418	07029T	PARTICIPANT	\N	PRESENT	0
408988	407418	14085U	PARTICIPANT	\N	PRESENT	0
408989	407418	07004J	PARTICIPANT	\N	PRESENT	0
408990	407418	96004D	PARTICIPANT	\N	PRESENT	0
408991	407418	19349W	PARTICIPANT	\N	PRESENT	0
408992	407418	08010L	PARTICIPANT	\N	PRESENT	0
408993	407418	14253S	PARTICIPANT	\N	PRESENT	0
408994	407418	19479G	PARTICIPANT	\N	PRESENT	0
408995	407418	19711U	PARTICIPANT	\N	PRESENT	0
408996	407418	19651A	PARTICIPANT	\N	PRESENT	0
408997	407418	08034U	PARTICIPANT	\N	PRESENT	0
408998	407418	08069G	PARTICIPANT	\N	PRESENT	0
408999	407418	08011M	PARTICIPANT	\N	PRESENT	0
409000	407418	08014Q	PARTICIPANT	\N	PRESENT	0
409001	407418	14034U	PARTICIPANT	\N	PRESENT	0
409002	407418	11040E	PARTICIPANT	\N	PRESENT	0
409003	407418	04086Q	PARTICIPANT	\N	PRESENT	0
409004	407418	14083S	PARTICIPANT	\N	PRESENT	0
409005	407418	11012A	PARTICIPANT	\N	PRESENT	0
409006	407418	19741B	PARTICIPANT	\N	PRESENT	0
409007	407418	99004R	PARTICIPANT	\N	PRESENT	0
409008	407418	95041E	PARTICIPANT	\N	EXCUSE	0
409009	407418	14159V	PARTICIPANT	\N	EXCUSE	0
409010	407378	19685L	PARTICIPANT	\N	PRESENT	0
409011	407378	14191V	PARTICIPANT	\N	PRESENT	0
409012	407378	05012A	PARTICIPANT	\N	PRESENT	0
409013	407378	14221J	PARTICIPANT	\N	PRESENT	0
409015	409014	08039A	PARTICIPANT	\N	PRESENT	0
409016	409014	14109K	PARTICIPANT	\N	PRESENT	0
409017	409014	19749K	PARTICIPANT	\N	PRESENT	0
409019	409018	08039A	PARTICIPANT	\N	PRESENT	0
409020	409018	19749K	PARTICIPANT	\N	PRESENT	0
409021	409018	14109K	PARTICIPANT	\N	PRESENT	0
409022	409018	19593H	PARTICIPANT	\N	PRESENT	0
409023	407378	02002K	PARTICIPANT	\N	PRESENT	0
409024	408815	11085T	PARTICIPANT	\N	PRESENT	0
409069	406862	19415P	PARTICIPANT	\N	PRESENT	0
409070	406862	14087W	PARTICIPANT	\N	PRESENT	0
409084	407378	19347U	PARTICIPANT	\N	PRESENT	0
409104	407418	11048N	PARTICIPANT	\N	PRESENT	0
409105	407418	19689Q	PARTICIPANT	\N	PRESENT	0
409106	407418	12016W	PARTICIPANT	\N	PRESENT	0
409107	407418	11110B	PARTICIPANT	\N	PRESENT	0
409108	408286	86034E	PARTICIPANT	\N	PRESENT	0
409110	407420	14030Q	PARTICIPANT	\N	PRESENT	0
409111	407420	14083S	PARTICIPANT	\N	PRESENT	0
409112	407420	19681G	PARTICIPANT	\N	PRESENT	0
409113	407420	14187A	PARTICIPANT	\N	PRESENT	0
409114	407420	11064N	PARTICIPANT	\N	PRESENT	0
409115	407420	19729F	PARTICIPANT	\N	PRESENT	0
409116	407420	17583W	PARTICIPANT	\N	PRESENT	0
409117	407420	14331P	PARTICIPANT	\N	PRESENT	0
409118	407420	11066Q	PARTICIPANT	\N	PRESENT	0
409119	407420	14157T	PARTICIPANT	\N	PRESENT	0
409120	407420	14031R	PARTICIPANT	\N	PRESENT	0
409121	407420	14281W	PRESIDENT	0	PRESENT	0
409122	407420	08043V	PARTICIPANT	\N	EXCUSE	0
409123	407420	98029W	PARTICIPANT	\N	EXCUSE	0
409124	407420	04044E	PARTICIPANT	\N	EXCUSE	0
409133	408286	12041X	PARTICIPANT	\N	PRESENT	0
409134	408286	14235Q	PARTICIPANT	\N	PRESENT	0
398181	393594	98029W	PARTICIPANT	\N	PRESENT	0
398182	393594	11054L	PARTICIPANT	\N	PRESENT	0
398183	393594	01062T	PARTICIPANT	\N	PRESENT	0
398184	393594	14231L	PARTICIPANT	\N	PRESENT	0
398185	393594	98005N	PARTICIPANT	\N	PRESENT	0
398186	393594	01058X	PARTICIPANT	\N	PRESENT	0
398187	393594	04071H	PARTICIPANT	\N	PRESENT	0
398188	393594	19745F	PARTICIPANT	\N	PRESENT	0
398189	393594	08069G	PARTICIPANT	\N	PRESENT	0
398190	393594	19533U	PARTICIPANT	\N	PRESENT	0
398191	393594	16685X	PARTICIPANT	\N	PRESENT	0
398195	393594	04043D	PARTICIPANT	\N	PRESENT	0
398193	393594	19709B	PARTICIPANT	\N	PRESENT	0
398197	393594	04059M	PARTICIPANT	\N	PRESENT	0
398196	393594	11083R	PARTICIPANT	\N	PRESENT	0
398201	398200	95067Q	PARTICIPANT	\N	PRESENT	0
398202	398200	19766L	PARTICIPANT	\N	PRESENT	0
398203	393594	19647E	PARTICIPANT	\N	PRESENT	0
398206	393594	19543W	PARTICIPANT	\N	PRESENT	0
398207	393594	12041X	PARTICIPANT	\N	PRESENT	0
398249	396131	14261S	PARTICIPANT	\N	PRESENT	0
398250	396131	19631V	PARTICIPANT	\N	PRESENT	0
398251	396131	19329S	PARTICIPANT	\N	PRESENT	0
398252	396131	19729F	PARTICIPANT	\N	EXCUSE	0
398253	396131	08019V	PRESIDENT	0	PRESENT	0
398254	396131	19301E	PARTICIPANT	\N	PRESENT	0
398255	396131	14331P	PARTICIPANT	\N	PRESENT	0
398256	396131	04043D	PARTICIPANT	\N	PRESENT	0
398257	396131	11072N	PARTICIPANT	\N	EXCUSE	0
398258	396131	08073C	PARTICIPANT	\N	PRESENT	0
398259	396131	14039A	PARTICIPANT	\N	PRESENT	0
398261	396131	19715Y	PARTICIPANT	\N	PRESENT	0
398266	396131	19691J	PARTICIPANT	\N	EXCUSE	0
398269	396131	14219Q	PARTICIPANT	\N	EXCUSE	0
398289	398288	19253P	PARTICIPANT	\N	PRESENT	0
398290	398288	08045X	PARTICIPANT	\N	PRESENT	0
398291	398288	14357A	PARTICIPANT	\N	PRESENT	0
398292	398288	19387D	PARTICIPANT	\N	PRESENT	0
398293	398288	19671E	PARTICIPANT	\N	PRESENT	0
398297	398296	08052W	PARTICIPANT	\N	PRESENT	0
398298	398296	10006L	PARTICIPANT	\N	PRESENT	0
398299	398296	19553Y	PARTICIPANT	\N	PRESENT	0
398308	398307	10006L	PARTICIPANT	\N	PRESENT	0
398442	398441	14033T	PARTICIPANT	\N	PRESENT	0
398443	398441	19269X	PARTICIPANT	\N	PRESENT	0
398445	398444	14033T	PARTICIPANT	\N	PRESENT	0
398447	398446	14033T	PARTICIPANT	\N	PRESENT	0
398448	398446	19369B	PARTICIPANT	\N	PRESENT	0
398450	398449	14033T	PARTICIPANT	\N	PRESENT	0
398452	398451	14033T	PARTICIPANT	\N	PRESENT	0
398453	398451	19369B	PARTICIPANT	\N	PRESENT	0
398455	398454	14033T	PARTICIPANT	\N	PRESENT	0
398456	398454	19369B	PARTICIPANT	\N	PRESENT	0
398457	398454	14265W	PARTICIPANT	\N	PRESENT	0
398458	398454	19782L	PARTICIPANT	\N	PRESENT	0
398459	398454	19747H	PARTICIPANT	\N	PRESENT	0
398461	398460	19782L	PARTICIPANT	\N	PRESENT	0
398462	398460	19747H	PARTICIPANT	\N	PRESENT	0
398463	398460	19733B	PARTICIPANT	\N	PRESENT	0
398464	398460	14033T	PARTICIPANT	\N	PRESENT	0
398466	398465	19733B	PARTICIPANT	\N	PRESENT	0
398467	398465	14093U	PARTICIPANT	\N	PRESENT	0
398469	398468	19733B	PARTICIPANT	\N	PRESENT	0
398925	398915	14229S	PARTICIPANT	\N	PRESENT	0
398933	398915	19679N	PARTICIPANT	\N	PRESENT	0
398935	398915	19599P	PARTICIPANT	\N	PRESENT	0
398937	398915	19533U	PARTICIPANT	\N	PRESENT	0
398938	398915	01048V	PARTICIPANT	\N	PRESENT	0
398942	398915	14257W	PARTICIPANT	\N	PRESENT	0
398943	398915	19593H	PARTICIPANT	\N	PRESENT	0
398944	398915	14093U	PARTICIPANT	\N	PRESENT	0
399832	397947	88008L	PARTICIPANT	\N	PRESENT	0
400593	400115	19695N	PARTICIPANT	\N	PRESENT	0
400594	400116	19695N	PARTICIPANT	\N	PRESENT	0
400595	400117	19695N	PARTICIPANT	\N	PRESENT	0
400596	400117	19507S	PARTICIPANT	\N	PRESENT	0
400597	400118	19695N	PARTICIPANT	\N	PRESENT	0
400598	400118	19507S	PARTICIPANT	\N	PRESENT	0
400600	400599	14135M	PARTICIPANT	\N	PRESENT	0
400602	400601	19695N	PARTICIPANT	\N	PRESENT	0
401927	396241	14093U	PARTICIPANT	\N	PRESENT	0
401929	396241	14299H	PARTICIPANT	\N	PRESENT	0
401930	396241	01048V	PRESIDENT	0	PRESENT	0
401932	396241	19533U	PARTICIPANT	\N	PRESENT	0
401933	396241	04043D	PARTICIPANT	\N	PRESENT	0
402108	401161	89017R	PARTICIPANT	\N	EXCUSE	0
402109	401161	08060W	PARTICIPANT	\N	EXCUSE	0
402110	401161	14255U	PARTICIPANT	\N	EXCUSE	0
402111	401161	19545Y	PARTICIPANT	\N	EXCUSE	0
402112	401161	14079W	PARTICIPANT	\N	EXCUSE	0
402113	401161	14041T	PARTICIPANT	\N	EXCUSE	0
402114	401161	14187A	PARTICIPANT	\N	EXCUSE	0
402115	401161	14034U	PARTICIPANT	\N	EXCUSE	0
402116	401161	14061L	PARTICIPANT	\N	EXCUSE	0
402117	401161	08015R	PARTICIPANT	\N	EXCUSE	0
402118	401161	14205J	PARTICIPANT	\N	EXCUSE	0
402119	401161	14265W	PARTICIPANT	\N	EXCUSE	0
402120	401161	14253S	PARTICIPANT	\N	EXCUSE	0
402121	401161	14051J	PARTICIPANT	\N	EXCUSE	0
402122	401161	19527W	PARTICIPANT	\N	EXCUSE	0
402124	402123	04049K	PRESIDENT	0	PRESENT	0
402125	402123	14187A	PARTICIPANT	\N	PRESENT	0
402160	401920	96004D	PRESIDENT	0	PRESENT	0
402162	401920	14089Y	PARTICIPANT	\N	EXCUSE	0
402163	401920	14357A	PARTICIPANT	\N	PRESENT	0
402164	401920	14079W	PARTICIPANT	\N	PRESENT	0
402165	401920	14249W	PARTICIPANT	\N	PRESENT	0
402166	401920	11083R	PARTICIPANT	\N	PRESENT	0
402168	401920	95037J	PARTICIPANT	\N	PRESENT	0
402169	401920	04097T	PARTICIPANT	\N	PRESENT	0
402170	401920	14061L	PARTICIPANT	\N	PRESENT	0
402171	401920	14073Q	PARTICIPANT	\N	PRESENT	0
402172	401920	11026G	PARTICIPANT	\N	PRESENT	0
402173	401920	08039A	PARTICIPANT	\N	PRESENT	0
402174	401920	14221J	PARTICIPANT	\N	PRESENT	0
402175	401920	19593H	PARTICIPANT	\N	PRESENT	0
402176	401920	14191V	PARTICIPANT	\N	EXCUSE	0
402178	401920	14331P	PARTICIPANT	\N	PRESENT	0
402179	401920	10015M	PARTICIPANT	\N	PRESENT	0
402180	401920	14135M	PARTICIPANT	\N	PRESENT	0
402217	398307	11067R	PARTICIPANT	\N	PRESENT	0
402218	398307	11097X	PARTICIPANT	\N	PRESENT	0
402988	402987	86034E	PARTICIPANT	\N	PRESENT	0
402989	402987	89017R	PARTICIPANT	\N	PRESENT	0
402990	402987	04085P	PARTICIPANT	\N	PRESENT	0
402991	402987	04059M	PARTICIPANT	\N	PRESENT	0
402992	402987	05008E	PARTICIPANT	\N	PRESENT	0
402993	402987	96004D	PARTICIPANT	\N	PRESENT	0
402994	402987	11027H	PARTICIPANT	\N	PRESENT	0
402995	402987	04086Q	PARTICIPANT	\N	PRESENT	0
402996	402987	14079W	PARTICIPANT	\N	PRESENT	0
402997	402987	98024R	PARTICIPANT	\N	PRESENT	0
402998	402987	11074Q	PARTICIPANT	\N	PRESENT	0
402999	402987	14034U	PARTICIPANT	\N	PRESENT	0
403000	402987	14021P	PARTICIPANT	\N	PRESENT	0
403001	402987	14159V	PARTICIPANT	\N	PRESENT	0
403002	402987	14251Q	PARTICIPANT	\N	PRESENT	0
403003	402987	14031R	PARTICIPANT	\N	PRESENT	0
403004	402987	11085T	PARTICIPANT	\N	PRESENT	0
403005	402987	11072N	PARTICIPANT	\N	PRESENT	0
403006	402987	04070G	PARTICIPANT	\N	PRESENT	0
403007	402987	08061X	PARTICIPANT	\N	PRESENT	0
403008	402987	14193X	PARTICIPANT	\N	PRESENT	0
403009	402987	05012A	PARTICIPANT	\N	PRESENT	0
403010	402987	11090Q	PARTICIPANT	\N	PRESENT	0
403011	402987	11012A	PARTICIPANT	\N	PRESENT	0
403012	402987	04033B	PARTICIPANT	\N	PRESENT	0
403013	402987	04044E	PARTICIPANT	\N	PRESENT	0
403028	400154	04044E	PARTICIPANT	\N	PRESENT	0
403029	403027	10015M	PARTICIPANT	\N	PRESENT	0
403030	403027	01024M	PARTICIPANT	\N	PRESENT	0
403031	403027	19543W	PARTICIPANT	\N	PRESENT	0
403032	403027	04047H	PARTICIPANT	\N	PRESENT	0
403033	403027	01028R	PARTICIPANT	\N	PRESENT	0
403034	403027	19447X	PARTICIPANT	\N	PRESENT	0
403035	403027	05008E	PRESIDENT	0	PRESENT	0
403036	403027	14089Y	PARTICIPANT	\N	PRESENT	0
403037	403027	14041T	PARTICIPANT	\N	PRESENT	0
403038	403027	14147R	PARTICIPANT	\N	PRESENT	0
403039	403027	14151M	PARTICIPANT	\N	PRESENT	0
403040	403027	14215L	PARTICIPANT	\N	PRESENT	0
403041	403027	19762G	PARTICIPANT	\N	PRESENT	0
403042	403027	14053L	PARTICIPANT	\N	PRESENT	0
403043	403027	95063L	PARTICIPANT	\N	PRESENT	0
403044	400154	14259Y	PARTICIPANT	\N	PRESENT	0
403045	403027	14065Q	PARTICIPANT	\N	PRESENT	0
403046	403027	14259Y	PARTICIPANT	\N	EXCUSE	0
407457	405334	14065Q	PARTICIPANT	\N	EXCUSE	0
407458	405334	96004D	PRESIDENT	0	PRESENT	0
407460	405334	14089Y	PARTICIPANT	\N	EXCUSE	0
407461	405334	08014Q	PARTICIPANT	\N	PRESENT	0
407462	405334	14079W	PARTICIPANT	\N	PRESENT	0
407464	405334	14249W	PARTICIPANT	\N	EXCUSE	0
407465	405334	19553Y	PARTICIPANT	\N	PRESENT	0
407466	405334	19725B	PARTICIPANT	\N	PRESENT	0
407467	405334	19569H	PARTICIPANT	\N	EXCUSE	0
407468	405334	04097T	PARTICIPANT	\N	EXCUSE	0
407469	405334	14241N	PARTICIPANT	\N	EXCUSE	0
407470	405334	14061L	PARTICIPANT	\N	EXCUSE	0
407471	405334	14073Q	PARTICIPANT	\N	PRESENT	0
407472	405334	11026G	PARTICIPANT	\N	EXCUSE	0
407473	405334	04057K	PARTICIPANT	\N	EXCUSE	0
407474	405334	14331P	PARTICIPANT	\N	EXCUSE	0
407475	405334	14225N	PARTICIPANT	\N	EXCUSE	0
407476	405334	14237S	PARTICIPANT	\N	PRESENT	0
407549	407533	19467C	PARTICIPANT	\N	PRESENT	0
407550	407533	14281W	PARTICIPANT	\N	PRESENT	0
407551	407533	14026U	PARTICIPANT	\N	PRESENT	0
407552	407533	19691J	PARTICIPANT	\N	PRESENT	0
407553	407533	07029T	PARTICIPANT	\N	PRESENT	0
407554	407533	19563B	PARTICIPANT	\N	PRESENT	0
407556	407533	14265W	PARTICIPANT	\N	PRESENT	0
407557	407533	14119M	PARTICIPANT	\N	PRESENT	0
407558	407533	19349W	PARTICIPANT	\N	PRESENT	0
407559	407533	95062K	PARTICIPANT	\N	PRESENT	0
407560	407533	19798U	PARTICIPANT	\N	PRESENT	0
407561	407533	04045F	PARTICIPANT	\N	PRESENT	0
407562	407533	95067Q	PARTICIPANT	\N	PRESENT	0
408156	408155	10006L	PARTICIPANT	\N	PRESENT	0
408157	408155	11067R	PARTICIPANT	\N	PRESENT	0
408158	408155	14147R	PARTICIPANT	\N	PRESENT	0
408159	408155	19629C	PARTICIPANT	\N	PRESENT	0
408161	408160	10006L	PARTICIPANT	\N	PRESENT	0
408162	408160	11067R	PARTICIPANT	\N	PRESENT	0
408163	408160	14147R	PARTICIPANT	\N	PRESENT	0
408164	408160	19629C	PARTICIPANT	\N	PRESENT	0
408166	408165	10006L	PARTICIPANT	\N	PRESENT	0
408167	408165	11067R	PARTICIPANT	\N	PRESENT	0
408168	408165	14147R	PARTICIPANT	\N	PRESENT	0
408169	408165	19629C	PARTICIPANT	\N	PRESENT	0
409086	409085	19621T	PARTICIPANT	\N	PRESENT	0
409087	409085	19611R	PARTICIPANT	\N	PRESENT	0
409088	409085	08031R	PARTICIPANT	\N	PRESENT	0
409089	409085	11104D	PARTICIPANT	\N	PRESENT	0
409090	409085	14109K	PARTICIPANT	\N	PRESENT	0
409092	409091	19621T	PARTICIPANT	\N	PRESENT	0
409093	409091	19611R	PARTICIPANT	\N	PRESENT	0
409094	409091	08031R	PARTICIPANT	\N	PRESENT	0
409095	409091	14109K	PARTICIPANT	\N	PRESENT	0
409097	409096	19621T	PARTICIPANT	\N	PRESENT	0
409098	409096	19611R	PARTICIPANT	\N	PRESENT	0
409099	409096	19593H	PARTICIPANT	\N	PRESENT	0
409100	409096	19533U	PARTICIPANT	\N	PRESENT	0
409101	409096	14229S	PARTICIPANT	\N	PRESENT	0
409103	409102	08031R	PARTICIPANT	\N	PRESENT	0
414877	413357	14089Y	PARTICIPANT	\N	PRESENT	0
414878	413357	95063L	PARTICIPANT	\N	PRESENT	0
414879	413357	19629C	PARTICIPANT	\N	PRESENT	0
414880	413357	14069U	PARTICIPANT	\N	PRESENT	0
414881	413357	04008A	PARTICIPANT	\N	PRESENT	0
414882	413357	01028R	PARTICIPANT	\N	PRESENT	0
414883	414029	04035D	PARTICIPANT	\N	PRESENT	0
414885	412749	19768N	PARTICIPANT	\N	PRESENT	0
414886	412749	19515S	PARTICIPANT	\N	PRESENT	0
414887	412749	19782L	PARTICIPANT	\N	PRESENT	0
414888	412749	11077T	PARTICIPANT	\N	PRESENT	0
414889	412749	14357A	PARTICIPANT	\N	PRESENT	0
414890	412749	19812Y	PARTICIPANT	\N	PRESENT	0
414891	412749	14081Q	PARTICIPANT	\N	PRESENT	0
414892	412749	19413M	PARTICIPANT	\N	PRESENT	0
414893	412749	80013X	PARTICIPANT	\N	PRESENT	0
414894	412749	19631V	PARTICIPANT	\N	PRESENT	0
414895	412749	11099A	PARTICIPANT	\N	PRESENT	0
414896	412749	08068F	PARTICIPANT	\N	PRESENT	0
414897	412749	04049K	PARTICIPANT	\N	PRESENT	0
414898	412749	19705W	PARTICIPANT	\N	PRESENT	0
414899	412749	08015R	PARTICIPANT	\N	PRESENT	0
414900	412749	08019V	PARTICIPANT	\N	PRESENT	0
414901	412749	19369B	PARTICIPANT	\N	PRESENT	0
414902	412749	19563B	PARTICIPANT	\N	PRESENT	0
414903	412749	14265W	PARTICIPANT	\N	PRESENT	0
414904	412749	14329V	PARTICIPANT	\N	PRESENT	0
414905	412749	19467C	PARTICIPANT	\N	PRESENT	0
414906	412749	14187A	PARTICIPANT	\N	PRESENT	0
414907	412749	08062Y	PARTICIPANT	\N	PRESENT	0
414908	412749	19695N	PARTICIPANT	\N	PRESENT	0
414909	412749	11090Q	PRESIDENT	0	PRESENT	0
414910	412749	14033T	PARTICIPANT	\N	PRESENT	0
414911	412749	01025N	PARTICIPANT	\N	PRESENT	0
414912	412749	04088S	PARTICIPANT	\N	PRESENT	0
414913	412749	04089T	PARTICIPANT	\N	PRESENT	0
414914	412749	14115H	PARTICIPANT	\N	PRESENT	0
414915	412749	11101A	PARTICIPANT	\N	PRESENT	0
414916	412749	19507S	PARTICIPANT	\N	PRESENT	0
414917	412749	19747H	PARTICIPANT	\N	PRESENT	0
414918	412749	14207L	PARTICIPANT	\N	PRESENT	0
414919	412749	04043D	PARTICIPANT	\N	PRESENT	0
414920	412749	14257W	PARTICIPANT	\N	PRESENT	0
414921	412790	19794Q	PARTICIPANT	\N	PRESENT	0
414922	412790	04069P	PARTICIPANT	\N	PRESENT	0
414923	412790	19549D	PARTICIPANT	\N	PRESENT	0
414924	412790	19387D	PARTICIPANT	\N	PRESENT	0
414925	412790	19820Y	PARTICIPANT	\N	PRESENT	0
414926	412790	14219Q	PARTICIPANT	\N	PRESENT	0
414927	412790	19826F	PARTICIPANT	\N	PRESENT	0
414928	412790	19599P	PARTICIPANT	\N	PRESENT	0
414929	412790	18083K	PARTICIPANT	\N	PRESENT	0
414930	412790	14237S	PARTICIPANT	\N	PRESENT	0
414931	412790	05012A	PARTICIPANT	\N	PRESENT	0
414932	412790	08060W	PARTICIPANT	\N	PRESENT	0
414933	412790	19347U	PARTICIPANT	\N	PRESENT	0
414934	412790	14157T	PARTICIPANT	\N	PRESENT	0
414935	412790	08024S	PARTICIPANT	\N	PRESENT	0
414936	412790	19525U	PARTICIPANT	\N	PRESENT	0
414937	412790	14038Y	PARTICIPANT	\N	PRESENT	0
414938	412790	14031R	PARTICIPANT	\N	PRESENT	0
414939	412790	08055A	PARTICIPANT	\N	PRESENT	0
414940	412790	14191V	PARTICIPANT	\N	PRESENT	0
414941	412790	14169X	PARTICIPANT	\N	PRESENT	0
414942	412790	15447F	PARTICIPANT	\N	PRESENT	0
414943	412790	04097T	PARTICIPANT	\N	PRESENT	0
414944	412790	19739H	PARTICIPANT	\N	PRESENT	0
414945	412790	19745F	PARTICIPANT	\N	PRESENT	0
414946	412790	19383Y	PARTICIPANT	\N	PRESENT	0
414947	412790	19503N	PARTICIPANT	\N	PRESENT	0
414948	412790	19551W	PARTICIPANT	\N	PRESENT	0
414949	410795	19693L	PARTICIPANT	\N	PRESENT	0
414950	410795	19723Y	PARTICIPANT	\N	EXCUSE	0
414951	414029	11115U	PARTICIPANT	\N	PRESENT	0
414952	414444	04070G	PRESIDENT	0	PRESENT	0
414953	414444	14059S	PARTICIPANT	\N	PRESENT	0
414954	414444	19699S	PARTICIPANT	\N	PRESENT	0
414955	414444	14073Q	PARTICIPANT	\N	PRESENT	0
414956	414444	19533U	PARTICIPANT	\N	PRESENT	0
414957	414444	19611R	PARTICIPANT	\N	PRESENT	0
414958	414444	87003B	PARTICIPANT	\N	PRESENT	0
414959	414444	19399H	PARTICIPANT	\N	PRESENT	0
414960	414444	14201E	PARTICIPANT	\N	PRESENT	0
414961	414444	14241N	PARTICIPANT	\N	PRESENT	0
414962	414444	14251Q	PARTICIPANT	\N	PRESENT	0
414963	414444	19573D	PARTICIPANT	\N	PRESENT	0
414964	414444	14107H	PARTICIPANT	\N	PRESENT	0
414965	414444	14063N	PARTICIPANT	\N	PRESENT	0
414966	414444	14109K	PARTICIPANT	\N	PRESENT	0
414967	414444	08012N	PARTICIPANT	\N	PRESENT	0
414968	414444	14123H	PARTICIPANT	\N	PRESENT	0
414969	414444	11043H	PARTICIPANT	\N	PRESENT	0
414970	414444	11104D	PARTICIPANT	\N	PRESENT	0
414971	414444	19749K	PARTICIPANT	\N	PRESENT	0
414972	414444	14249W	PARTICIPANT	\N	PRESENT	0
414973	414444	19758L	PARTICIPANT	\N	PRESENT	0
414974	414444	08039A	PARTICIPANT	\N	PRESENT	0
414975	414444	19621T	PARTICIPANT	\N	PRESENT	0
414976	414444	14061L	PARTICIPANT	\N	EXCUSE	0
414977	414444	04057K	PARTICIPANT	\N	EXCUSE	0
414978	414444	92040Q	PARTICIPANT	\N	EXCUSE	0
414979	412790	19681G	PARTICIPANT	\N	PRESENT	0
414980	414077	19533U	PARTICIPANT	\N	PRESENT	0
414981	414077	19503N	PARTICIPANT	\N	PRESENT	0
414982	414076	19693L	PARTICIPANT	\N	EXCUSE	0
414983	414076	19709B	PARTICIPANT	\N	EXCUSE	0
414984	414076	19723Y	PARTICIPANT	\N	EXCUSE	0
414985	414076	01058X	PARTICIPANT	\N	EXCUSE	0
414986	413357	04047H	PARTICIPANT	\N	PRESENT	0
414987	413357	14065Q	PARTICIPANT	\N	PRESENT	0
414988	413357	10015M	PARTICIPANT	\N	PRESENT	0
393139	391485	19737F	PARTICIPANT	\N	PRESENT	0
393140	391485	19347U	PARTICIPANT	\N	PRESENT	0
393141	391485	14179A	PARTICIPANT	\N	PRESENT	0
393142	391485	14031R	PARTICIPANT	\N	PRESENT	0
393143	391485	19551W	PARTICIPANT	\N	PRESENT	0
393144	391485	19585H	PARTICIPANT	\N	PRESENT	0
393145	391485	19637C	PARTICIPANT	\N	PRESENT	0
394524	393744	92040Q	PARTICIPANT	\N	EXCUSE	0
395799	395792	19515S	PARTICIPANT	\N	PRESENT	0
395800	395792	19251M	PARTICIPANT	\N	PRESENT	0
395801	395792	14087W	PARTICIPANT	\N	PRESENT	0
395802	395792	19347U	PARTICIPANT	\N	PRESENT	0
395803	395792	14179A	PARTICIPANT	\N	PRESENT	0
395805	395792	19551W	PARTICIPANT	\N	PRESENT	0
395807	395792	19794Q	PARTICIPANT	\N	PRESENT	0
395808	395792	19737F	PARTICIPANT	\N	PRESENT	0
395809	395792	19585H	PARTICIPANT	\N	PRESENT	0
395810	395792	14081Q	PARTICIPANT	\N	EXCUSE	0
395811	395792	14241N	PARTICIPANT	\N	EXCUSE	0
395812	395792	14031R	PARTICIPANT	\N	EXCUSE	0
395813	395792	19637C	PARTICIPANT	\N	EXCUSE	0
395816	395794	14031R	PARTICIPANT	\N	PRESENT	0
395817	395794	19347U	PARTICIPANT	\N	PRESENT	0
395818	395794	19737F	PARTICIPANT	\N	PRESENT	0
395819	395796	19549D	PARTICIPANT	\N	PRESENT	0
395820	395796	14079W	PARTICIPANT	\N	PRESENT	0
395821	395796	14241N	PARTICIPANT	\N	PRESENT	0
395822	395796	19637C	PARTICIPANT	\N	PRESENT	0
395823	395796	19794Q	PARTICIPANT	\N	PRESENT	0
395824	395796	19551W	PARTICIPANT	\N	PRESENT	0
395825	395796	19737F	PARTICIPANT	\N	PRESENT	0
395826	395796	19347U	PARTICIPANT	\N	PRESENT	0
395827	395796	14179A	PARTICIPANT	\N	PRESENT	0
395828	395796	19515S	PARTICIPANT	\N	EXCUSE	0
395829	395796	19251M	PARTICIPANT	\N	EXCUSE	0
395830	395797	19551W	PARTICIPANT	\N	PRESENT	0
395831	395797	19737F	PARTICIPANT	\N	PRESENT	0
395832	395797	19347U	PARTICIPANT	\N	PRESENT	0
399333	393597	95030B	PARTICIPANT	\N	PRESENT	0
399334	397572	11031D	PARTICIPANT	\N	PRESENT	0
399335	393597	11056N	PARTICIPANT	\N	PRESENT	0
399336	393597	19735D	PARTICIPANT	\N	PRESENT	0
399337	393597	14115H	PARTICIPANT	\N	PRESENT	0
399338	393597	01025N	PARTICIPANT	\N	PRESENT	0
399492	399485	04070G	PRESIDENT	0	PRESENT	0
399493	399485	14061L	PARTICIPANT	\N	PRESENT	0
399494	399485	19533U	PARTICIPANT	\N	PRESENT	0
399495	399485	14073Q	PARTICIPANT	\N	PRESENT	0
399496	399485	19611R	PARTICIPANT	\N	PRESENT	0
399497	399485	08043V	PARTICIPANT	\N	PRESENT	0
399498	399485	87003B	PARTICIPANT	\N	PRESENT	0
399499	399485	14030Q	PARTICIPANT	\N	PRESENT	0
399500	399485	14241N	PARTICIPANT	\N	PRESENT	0
399501	399485	14039A	PARTICIPANT	\N	PRESENT	0
399502	399485	11104D	PARTICIPANT	\N	PRESENT	0
399503	399485	19749K	PARTICIPANT	\N	PRESENT	0
399504	399485	04018C	PARTICIPANT	\N	PRESENT	0
399505	399485	08039A	PARTICIPANT	\N	PRESENT	0
399506	399485	04057K	PARTICIPANT	\N	EXCUSE	0
399507	397657	19709B	PARTICIPANT	\N	PRESENT	0
399508	398303	19383Y	PARTICIPANT	\N	PRESENT	0
399509	398303	19333N	PARTICIPANT	\N	PRESENT	0
399510	398303	17583W	PARTICIPANT	\N	PRESENT	0
399511	398303	19794Q	PARTICIPANT	\N	PRESENT	0
399512	398303	14031R	PARTICIPANT	\N	PRESENT	0
399513	398303	19549D	PARTICIPANT	\N	PRESENT	0
399514	398303	19387D	PARTICIPANT	\N	PRESENT	0
399515	398303	14219Q	PARTICIPANT	\N	PRESENT	0
399516	398303	08055A	PARTICIPANT	\N	PRESENT	0
399517	398303	19637C	PARTICIPANT	\N	PRESENT	0
399518	398303	02002K	PARTICIPANT	\N	PRESENT	0
399519	398303	15447F	PARTICIPANT	\N	PRESENT	0
399520	398303	18083K	PARTICIPANT	\N	PRESENT	0
399521	398303	19551W	PARTICIPANT	\N	PRESENT	0
399522	398303	14051J	PARTICIPANT	\N	PRESENT	0
399523	398303	08060W	PARTICIPANT	\N	PRESENT	0
399524	398303	08009T	PRESIDENT	0	PRESENT	0
399525	398303	19503N	PARTICIPANT	\N	PRESENT	0
399526	398303	19347U	PARTICIPANT	\N	PRESENT	0
399527	398303	04097T	PARTICIPANT	\N	PRESENT	0
399528	398303	19739H	PARTICIPANT	\N	PRESENT	0
399529	398303	19745F	PARTICIPANT	\N	PRESENT	0
399530	398303	19525U	PARTICIPANT	\N	PRESENT	0
399531	398303	19701S	PARTICIPANT	\N	EXCUSE	0
399532	398303	05012A	PARTICIPANT	\N	PRESENT	0
399534	397570	11097X	PARTICIPANT	\N	PRESENT	0
399535	397570	14223L	PARTICIPANT	\N	PRESENT	0
399536	397570	19673G	PARTICIPANT	\N	PRESENT	0
399537	397570	14231L	PARTICIPANT	\N	PRESENT	0
399538	397570	05008E	PARTICIPANT	\N	PRESENT	0
399539	397570	19489J	PARTICIPANT	\N	PRESENT	0
399540	397570	14087W	PARTICIPANT	\N	PRESENT	0
399541	397570	19679N	PARTICIPANT	\N	PRESENT	0
399542	397570	14041T	PARTICIPANT	\N	PRESENT	0
399543	397570	14042U	PARTICIPANT	\N	PRESENT	0
399544	397570	14195A	PARTICIPANT	\N	PRESENT	0
399545	397570	14147R	PARTICIPANT	\N	PRESENT	0
399546	397570	14053L	PARTICIPANT	\N	PRESENT	0
399547	397570	98035U	PARTICIPANT	\N	PRESENT	0
399548	397570	19253P	PARTICIPANT	\N	PRESENT	0
399549	397570	01024M	PARTICIPANT	\N	PRESENT	0
399550	397570	19691J	PARTICIPANT	\N	PRESENT	0
399551	397570	19719D	PARTICIPANT	\N	PRESENT	0
399552	397570	14089Y	PARTICIPANT	\N	PRESENT	0
399553	397570	19725B	PARTICIPANT	\N	PRESENT	0
399554	397570	14071N	PARTICIPANT	\N	PRESENT	0
399555	397570	19762G	PARTICIPANT	\N	PRESENT	0
399556	397570	14021P	PARTICIPANT	\N	PRESENT	0
399557	399485	19573D	PARTICIPANT	\N	PRESENT	0
399558	399485	04059M	PARTICIPANT	\N	PRESENT	0
399559	399485	11043H	PARTICIPANT	\N	PRESENT	0
399560	398303	19681G	PARTICIPANT	\N	PRESENT	0
399561	398303	14038Y	PARTICIPANT	\N	PRESENT	0
399562	398303	19713W	PARTICIPANT	\N	PRESENT	0
399563	398303	19737F	PARTICIPANT	\N	PRESENT	0
399564	397657	95030B	PARTICIPANT	\N	PRESENT	0
399565	397657	08061X	PARTICIPANT	\N	PRESENT	0
399566	397657	08058D	PARTICIPANT	\N	PRESENT	0
399567	397657	11064N	PARTICIPANT	\N	PRESENT	0
399568	398303	08024S	PARTICIPANT	\N	PRESENT	0
399569	397947	14327T	PARTICIPANT	\N	PRESENT	0
399570	397947	04071H	PARTICIPANT	\N	PRESENT	0
399571	397947	95041E	PARTICIPANT	\N	PRESENT	0
399572	397947	01048V	PARTICIPANT	\N	PRESENT	0
399573	397947	01057W	PRESIDENT	1	PRESENT	0
399574	397947	89017R	PARTICIPANT	\N	PRESENT	0
399575	397947	11074Q	PRESIDENT	0	PRESENT	0
399576	397947	19667J	PARTICIPANT	\N	PRESENT	0
399577	397947	14225N	PARTICIPANT	\N	PRESENT	0
399578	397947	07029T	PARTICIPANT	\N	PRESENT	0
399579	397947	14085U	PARTICIPANT	\N	PRESENT	0
399580	397947	08010L	PARTICIPANT	\N	PRESENT	0
399581	397947	14253S	PARTICIPANT	\N	PRESENT	0
399582	397947	19479G	PARTICIPANT	\N	PRESENT	0
399583	397947	11048N	PARTICIPANT	\N	PRESENT	0
399584	397947	19711U	PARTICIPANT	\N	PRESENT	0
399585	397947	08034U	PARTICIPANT	\N	PRESENT	0
399586	397947	19687N	PARTICIPANT	\N	PRESENT	0
399587	397947	19689Q	PARTICIPANT	\N	PRESENT	0
399588	397947	08011M	PARTICIPANT	\N	PRESENT	0
399589	397947	14159V	PARTICIPANT	\N	PRESENT	0
399590	397947	14173T	PARTICIPANT	\N	PRESENT	0
399591	397947	04086Q	PARTICIPANT	\N	PRESENT	0
399592	397947	11040E	PARTICIPANT	\N	PRESENT	0
399593	397947	14199E	PARTICIPANT	\N	PRESENT	0
399594	397947	11012A	PARTICIPANT	\N	PRESENT	0
399595	397947	19741B	PARTICIPANT	\N	PRESENT	0
399596	397947	14121F	PARTICIPANT	\N	PRESENT	0
399597	397947	99004R	PARTICIPANT	\N	PRESENT	0
399598	397947	19531S	PARTICIPANT	\N	EXCUSE	0
399599	397947	19545Y	PARTICIPANT	\N	EXCUSE	0
399600	399485	19693L	PARTICIPANT	\N	PRESENT	0
399601	399485	19735D	PARTICIPANT	\N	PRESENT	0
399602	399485	14249W	PARTICIPANT	\N	PRESENT	0
399603	399485	19621T	PARTICIPANT	\N	PRESENT	0
399604	398232	19768N	PARTICIPANT	\N	PRESENT	0
399605	398232	19515S	PARTICIPANT	\N	PRESENT	0
399606	398232	19782L	PARTICIPANT	\N	PRESENT	0
399607	398232	11077T	PARTICIPANT	\N	PRESENT	0
399608	398232	14357A	PARTICIPANT	\N	PRESENT	0
399609	398232	19441R	PARTICIPANT	\N	PRESENT	0
399610	398232	19413M	PARTICIPANT	\N	PRESENT	0
399611	398232	80013X	PARTICIPANT	\N	PRESENT	0
399612	398232	19631V	PARTICIPANT	\N	PRESENT	0
399613	398232	11099A	PARTICIPANT	\N	PRESENT	0
399614	398232	04049K	PARTICIPANT	\N	PRESENT	0
399615	398232	08015R	PARTICIPANT	\N	PRESENT	0
399616	398232	19369B	PARTICIPANT	\N	PRESENT	0
399617	398232	19511N	PARTICIPANT	\N	PRESENT	0
409135	408286	19760E	PARTICIPANT	\N	PRESENT	0
409136	408286	19443T	PARTICIPANT	\N	PRESENT	0
409137	408286	11031D	PARTICIPANT	\N	PRESENT	0
409138	408286	19741B	PARTICIPANT	\N	PRESENT	0
409139	408286	04085P	PARTICIPANT	\N	PRESENT	0
409140	408286	11033F	PARTICIPANT	\N	PRESENT	0
409141	408286	04038G	PARTICIPANT	\N	PRESENT	0
409142	408286	14029X	PARTICIPANT	\N	PRESENT	0
409143	408286	19565D	PARTICIPANT	\N	PRESENT	0
409144	408286	19663E	PARTICIPANT	\N	PRESENT	0
409145	408286	14041T	PARTICIPANT	\N	PRESENT	0
409146	408286	11040E	PARTICIPANT	\N	PRESENT	0
409147	408286	19758L	PARTICIPANT	\N	PRESENT	0
409148	408286	08018U	PARTICIPANT	\N	PRESENT	0
409149	408286	11056N	PARTICIPANT	\N	PRESENT	0
409150	408286	07029T	PARTICIPANT	\N	PRESENT	0
409151	408286	19593H	PARTICIPANT	\N	PRESENT	0
409152	408286	19695N	PARTICIPANT	\N	PRESENT	0
409153	408286	19347U	PARTICIPANT	\N	PRESENT	0
409154	408286	19687N	PARTICIPANT	\N	PRESENT	0
409155	408286	11077T	PARTICIPANT	\N	PRESENT	0
409156	408286	14355X	PARTICIPANT	\N	PRESENT	0
409157	408286	08061X	PARTICIPANT	\N	PRESENT	0
409158	408286	95063L	PARTICIPANT	\N	PRESENT	0
409159	408286	19705W	PARTICIPANT	\N	PRESENT	0
409160	408286	04034C	PARTICIPANT	\N	PRESENT	0
409161	408286	04045F	PARTICIPANT	\N	PRESENT	0
409162	408286	14239U	PARTICIPANT	\N	PRESENT	0
409163	408286	19657G	PARTICIPANT	\N	PRESENT	0
409164	408286	19349W	PARTICIPANT	\N	PRESENT	0
409165	408286	19637C	PARTICIPANT	\N	PRESENT	0
409166	408286	19768N	PARTICIPANT	\N	PRESENT	0
409167	408286	19543W	PARTICIPANT	\N	PRESENT	0
409168	408286	14061L	PARTICIPANT	\N	PRESENT	0
409169	408286	19269X	PARTICIPANT	\N	PRESENT	0
409170	408286	98050T	PARTICIPANT	\N	PRESENT	0
409171	408286	19812Y	PARTICIPANT	\N	PRESENT	0
409172	408286	14038Y	PARTICIPANT	\N	PRESENT	0
409173	408286	14039A	PARTICIPANT	\N	PRESENT	0
409174	408286	08073C	PARTICIPANT	\N	PRESENT	0
409175	408286	19723Y	PARTICIPANT	\N	PRESENT	0
409176	408286	19782L	PARTICIPANT	\N	PRESENT	0
409177	408286	08024S	PARTICIPANT	\N	PRESENT	0
409178	408286	19329S	PARTICIPANT	\N	PRESENT	0
409179	408286	18083K	PARTICIPANT	\N	PRESENT	0
409180	408286	11072N	PARTICIPANT	\N	PRESENT	0
409853	409852	19467C	PARTICIPANT	\N	PRESENT	0
409854	409852	19507S	PARTICIPANT	\N	PRESENT	0
409855	409852	14197C	PARTICIPANT	\N	PRESENT	0
409856	409852	14265W	PARTICIPANT	\N	PRESENT	0
409858	409852	14135M	PARTICIPANT	\N	PRESENT	0
409859	409852	11090Q	PARTICIPANT	\N	PRESENT	0
409860	409852	19383Y	PARTICIPANT	\N	PRESENT	0
410130	410128	14261S	PARTICIPANT	\N	PRESENT	0
409992	409990	14255U	PARTICIPANT	\N	PRESENT	0
410129	410128	89017R	PARTICIPANT	\N	PRESENT	0
410131	410128	14105F	PARTICIPANT	\N	PRESENT	0
410132	410128	14255U	PARTICIPANT	\N	PRESENT	0
410133	410128	14083S	PARTICIPANT	\N	PRESENT	0
410134	410128	14187A	PARTICIPANT	\N	PRESENT	0
410135	410128	19521Q	PARTICIPANT	\N	PRESENT	0
410136	410128	14034U	PARTICIPANT	\N	PRESENT	0
410137	410128	14026U	PARTICIPANT	\N	PRESENT	0
410138	410128	14121F	PARTICIPANT	\N	PRESENT	0
410139	410128	14061L	PARTICIPANT	\N	PRESENT	0
410140	410128	04049K	PARTICIPANT	\N	PRESENT	0
410141	410128	14265W	PARTICIPANT	\N	PRESENT	0
410142	410128	14253S	PARTICIPANT	\N	PRESENT	0
410143	410128	08047A	PARTICIPANT	\N	PRESENT	0
410144	410128	14157T	PARTICIPANT	\N	PRESENT	0
410145	410128	19575F	PARTICIPANT	\N	EXCUSE	0
410146	410128	14030Q	PARTICIPANT	\N	EXCUSE	0
410147	410128	08068F	PARTICIPANT	\N	EXCUSE	0
410148	410128	19545Y	PARTICIPANT	\N	EXCUSE	0
410149	410128	11031D	PARTICIPANT	\N	EXCUSE	0
410150	410128	14079W	PARTICIPANT	\N	EXCUSE	0
410151	410128	14041T	PARTICIPANT	\N	EXCUSE	0
410152	410128	14087W	PARTICIPANT	\N	EXCUSE	0
410153	410128	19695N	PARTICIPANT	\N	EXCUSE	0
410154	410128	19591F	PARTICIPANT	\N	EXCUSE	0
410155	410128	08015R	PARTICIPANT	\N	EXCUSE	0
410156	410128	16685X	PARTICIPANT	\N	EXCUSE	0
410157	410128	19671E	PARTICIPANT	\N	EXCUSE	0
410158	410128	04088S	PARTICIPANT	\N	EXCUSE	0
410159	410128	14051J	PARTICIPANT	\N	EXCUSE	0
410161	410160	14061L	PARTICIPANT	\N	PRESENT	0
410162	410160	14083S	PARTICIPANT	\N	PRESENT	0
410163	410160	04049K	PARTICIPANT	\N	PRESENT	0
410165	410164	14061L	PARTICIPANT	\N	PRESENT	0
410166	410164	14083S	PARTICIPANT	\N	PRESENT	0
410167	410164	04049K	PARTICIPANT	\N	PRESENT	0
410169	410168	04049K	PARTICIPANT	\N	PRESENT	0
410170	410168	14061L	PARTICIPANT	\N	PRESENT	0
410171	410168	14083S	PARTICIPANT	\N	PRESENT	0
410753	410752	11053K	PARTICIPANT	\N	PRESENT	0
410754	410752	14159V	PARTICIPANT	\N	PRESENT	0
410755	410752	05012A	PARTICIPANT	\N	PRESENT	0
410757	410756	11053K	PARTICIPANT	\N	PRESENT	0
410758	410756	14159V	PARTICIPANT	\N	PRESENT	0
410759	410756	05012A	PARTICIPANT	\N	PRESENT	0
410761	410760	11053K	PARTICIPANT	\N	PRESENT	0
410762	410760	14159V	PARTICIPANT	\N	PRESENT	0
410763	410760	05012A	PARTICIPANT	\N	PRESENT	0
410765	410764	11053K	PARTICIPANT	\N	PRESENT	0
410766	410764	14159V	PARTICIPANT	\N	PRESENT	0
410767	410764	05012A	PARTICIPANT	\N	PRESENT	0
410856	410853	14042U	PARTICIPANT	\N	PRESENT	0
410863	410857	14119M	PARTICIPANT	\N	PRESENT	0
410864	410858	14119M	PARTICIPANT	\N	PRESENT	0
410865	410859	14119M	PARTICIPANT	\N	PRESENT	0
410866	410860	14119M	PARTICIPANT	\N	PRESENT	0
410867	410861	14119M	PARTICIPANT	\N	PRESENT	0
410868	410862	14119M	PARTICIPANT	\N	PRESENT	0
411555	411554	19699S	PARTICIPANT	\N	PRESENT	0
411557	411556	19699S	PARTICIPANT	\N	PRESENT	0
411759	411758	14083S	PARTICIPANT	\N	PRESENT	0
411761	411760	04049K	PRESIDENT	0	PRESENT	0
411762	411760	14205J	PARTICIPANT	\N	PRESENT	0
411763	411760	14026U	PARTICIPANT	\N	PRESENT	0
411764	411760	14087W	PARTICIPANT	\N	PRESENT	0
411765	411760	14038Y	PARTICIPANT	\N	PRESENT	0
411767	411760	19575F	PARTICIPANT	\N	EXCUSE	0
411768	411760	14255U	PARTICIPANT	\N	EXCUSE	0
411769	411760	14053L	PARTICIPANT	\N	EXCUSE	0
411770	411760	19545Y	PARTICIPANT	\N	EXCUSE	0
411771	411760	14079W	PARTICIPANT	\N	EXCUSE	0
411772	411760	14041T	PARTICIPANT	\N	EXCUSE	0
411773	411760	14034U	PARTICIPANT	\N	EXCUSE	0
411774	411760	14061L	PARTICIPANT	\N	EXCUSE	0
411775	411760	08015R	PARTICIPANT	\N	EXCUSE	0
411776	411760	19669L	PARTICIPANT	\N	EXCUSE	0
411777	411760	14051J	PARTICIPANT	\N	EXCUSE	0
411778	411760	14227Q	PARTICIPANT	\N	EXCUSE	0
411862	410914	08018U	PARTICIPANT	\N	PRESENT	0
413227	411140	04059M	PARTICIPANT	\N	PRESENT	0
413228	410828	19629C	PARTICIPANT	\N	PRESENT	0
413229	410828	08045X	PARTICIPANT	\N	PRESENT	0
413230	410828	08044W	PARTICIPANT	\N	PRESENT	0
413231	410828	14151M	PARTICIPANT	\N	PRESENT	0
413232	410828	19581D	PARTICIPANT	\N	PRESENT	0
413233	410828	14259Y	PARTICIPANT	\N	PRESENT	0
413234	410828	19673G	PARTICIPANT	\N	PRESENT	0
413235	410828	19719D	PARTICIPANT	\N	PRESENT	0
413236	410828	11033F	PARTICIPANT	\N	PRESENT	0
413237	410828	14021P	PARTICIPANT	\N	PRESENT	0
413238	410828	19447X	PARTICIPANT	\N	PRESENT	0
413239	410828	14111D	PARTICIPANT	\N	PRESENT	0
413240	410828	19649G	PARTICIPANT	\N	PRESENT	0
413241	410828	05008E	PRESIDENT	0	PRESENT	0
413245	410828	14053L	PARTICIPANT	\N	PRESENT	0
413246	410828	04038G	PARTICIPANT	\N	PRESENT	0
413247	410828	04047H	PARTICIPANT	\N	PRESENT	0
413248	410828	14147R	PARTICIPANT	\N	PRESENT	0
413249	410828	11049P	PARTICIPANT	\N	PRESENT	0
413250	410828	11072N	PARTICIPANT	\N	PRESENT	0
413256	410828	01028R	PARTICIPANT	\N	PRESENT	0
413257	410828	14179A	PARTICIPANT	\N	PRESENT	0
413258	410828	14215L	PARTICIPANT	\N	PRESENT	0
413259	410828	14065Q	PARTICIPANT	\N	PRESENT	0
413260	410828	14069U	PARTICIPANT	\N	PRESENT	0
413261	410828	19762G	PARTICIPANT	\N	PRESENT	0
413267	410828	01024M	PARTICIPANT	\N	PRESENT	0
413268	410828	19253P	PARTICIPANT	\N	EXCUSE	0
413269	410828	19675J	PARTICIPANT	\N	EXCUSE	0
413270	410828	95063L	PARTICIPANT	\N	PRESENT	0
413271	410828	11085T	PARTICIPANT	\N	PRESENT	0
395951	395948	88008L	PARTICIPANT	\N	PRESENT	0
395952	395948	11049P	PARTICIPANT	\N	PRESENT	0
395953	395948	14081Q	PARTICIPANT	\N	PRESENT	0
395954	395948	80027E	PARTICIPANT	\N	PRESENT	0
395955	395948	04045F	PARTICIPANT	\N	PRESENT	0
395956	395948	95067Q	PARTICIPANT	\N	PRESENT	0
403047	400154	04085P	PARTICIPANT	\N	PRESENT	0
403048	400154	01028R	PARTICIPANT	\N	PRESENT	0
403049	400154	19782L	PARTICIPANT	\N	PRESENT	0
403050	400154	19543W	PARTICIPANT	\N	PRESENT	0
403051	400154	05008E	PARTICIPANT	\N	PRESENT	0
403052	400154	19253P	PARTICIPANT	\N	PRESENT	0
403053	400154	19553Y	PARTICIPANT	\N	PRESENT	0
403054	400154	11012A	PARTICIPANT	\N	PRESENT	0
403055	400154	19319Q	PARTICIPANT	\N	PRESENT	0
403056	400154	14079W	PARTICIPANT	\N	PRESENT	0
403057	400154	04018C	PARTICIPANT	\N	PRESENT	0
403058	400154	14217N	PARTICIPANT	\N	PRESENT	0
403059	400154	14061L	PARTICIPANT	\N	PRESENT	0
403060	400154	04047H	PARTICIPANT	\N	PRESENT	0
403061	400154	19768N	PARTICIPANT	\N	PRESENT	0
403062	400154	14147R	PARTICIPANT	\N	PRESENT	0
403063	400154	08028W	PARTICIPANT	\N	PRESENT	0
403064	400154	19575F	PARTICIPANT	\N	PRESENT	0
403065	400154	19766L	PARTICIPANT	\N	PRESENT	0
403066	400154	19447X	PARTICIPANT	\N	PRESENT	0
403067	400154	19760E	PARTICIPANT	\N	PRESENT	0
403068	400154	11056N	PARTICIPANT	\N	PRESENT	0
403069	400154	08056B	PARTICIPANT	\N	PRESENT	0
403070	402944	19647E	PARTICIPANT	\N	PRESENT	0
403071	402944	19687N	PARTICIPANT	\N	PRESENT	0
403072	402944	01057W	PARTICIPANT	\N	PRESENT	0
403073	402944	11053K	PARTICIPANT	\N	PRESENT	0
403074	402944	19667J	PARTICIPANT	\N	PRESENT	0
403075	402944	08011M	PARTICIPANT	\N	PRESENT	0
403076	402944	11074Q	PRESIDENT	0	PRESENT	0
403077	402944	08014Q	PARTICIPANT	\N	PRESENT	0
403078	402944	14225N	PARTICIPANT	\N	PRESENT	0
395949	395948	19253P	PARTICIPANT	\N	PRESENT	0
395950	395948	04040A	PARTICIPANT	\N	PRESENT	0
403079	402944	04086Q	PARTICIPANT	\N	PRESENT	0
403080	402944	07029T	PARTICIPANT	\N	PRESENT	0
403081	402944	19349W	PARTICIPANT	\N	PRESENT	0
403082	402944	08010L	PARTICIPANT	\N	PRESENT	0
403083	402944	19741B	PARTICIPANT	\N	PRESENT	0
403084	402944	99004R	PARTICIPANT	\N	PRESENT	0
403085	400154	14089Y	PARTICIPANT	\N	PRESENT	0
404201	401906	19467C	PARTICIPANT	\N	PRESENT	0
404202	401906	11099A	PARTICIPANT	\N	PRESENT	0
404203	401906	04049K	PARTICIPANT	\N	PRESENT	0
404204	401906	19782L	PARTICIPANT	\N	PRESENT	0
404205	401906	19705W	PARTICIPANT	\N	PRESENT	0
404206	401906	08015R	PARTICIPANT	\N	PRESENT	0
404207	401906	11090Q	PRESIDENT	0	PRESENT	0
404208	401906	19747H	PARTICIPANT	\N	PRESENT	0
404209	401906	08028W	PARTICIPANT	\N	PRESENT	0
404210	401906	19631V	PARTICIPANT	\N	PRESENT	0
404211	401906	14257W	PARTICIPANT	\N	PRESENT	0
404215	401906	19511N	PARTICIPANT	\N	PRESENT	0
404216	401906	19619A	PARTICIPANT	\N	PRESENT	0
404217	401906	01043Q	PARTICIPANT	\N	EXCUSE	0
404218	401906	08038Y	PARTICIPANT	\N	EXCUSE	0
404219	401906	08062Y	PARTICIPANT	\N	EXCUSE	0
404220	401906	80013X	PARTICIPANT	\N	EXCUSE	0
404221	401906	19295A	PARTICIPANT	\N	EXCUSE	0
404222	401906	11081P	PARTICIPANT	\N	EXCUSE	0
404223	401906	14265W	PARTICIPANT	\N	EXCUSE	0
404224	401906	14329V	PARTICIPANT	\N	EXCUSE	0
404225	404214	14053L	PARTICIPANT	\N	PRESENT	0
404226	404214	10015M	PARTICIPANT	\N	PRESENT	0
404227	404214	19253P	PARTICIPANT	\N	PRESENT	0
404228	404214	04044E	PARTICIPANT	\N	PRESENT	0
404229	404214	19585H	PARTICIPANT	\N	PRESENT	0
404230	404214	04047H	PARTICIPANT	\N	PRESENT	0
404231	404214	19719D	PARTICIPANT	\N	PRESENT	0
404232	404214	01028R	PARTICIPANT	\N	PRESENT	0
404233	404214	14231L	PARTICIPANT	\N	PRESENT	0
404234	404214	19447X	PARTICIPANT	\N	PRESENT	0
404235	404214	05008E	PRESIDENT	0	PRESENT	0
404236	404214	14089Y	PARTICIPANT	\N	PRESENT	0
404237	404214	19489J	PARTICIPANT	\N	PRESENT	0
404238	404214	14041T	PARTICIPANT	\N	PRESENT	0
404239	404214	14147R	PARTICIPANT	\N	PRESENT	0
404240	404214	14151M	PARTICIPANT	\N	PRESENT	0
404241	404214	14069U	PARTICIPANT	\N	PRESENT	0
404242	404214	14215L	PARTICIPANT	\N	PRESENT	0
404243	404214	08018U	PARTICIPANT	\N	PRESENT	0
404244	404214	14259Y	PARTICIPANT	\N	PRESENT	0
404245	404214	11072N	PARTICIPANT	\N	PRESENT	0
404246	404214	19729F	PARTICIPANT	\N	EXCUSE	0
404273	401906	14135M	PARTICIPANT	\N	PRESENT	0
404274	401906	19695N	PARTICIPANT	\N	PRESENT	0
404275	401906	14033T	PARTICIPANT	\N	PRESENT	0
404276	401906	14205J	PARTICIPANT	\N	PRESENT	0
404277	401906	11056N	PARTICIPANT	\N	PRESENT	0
404278	401906	11101A	PARTICIPANT	\N	PRESENT	0
404279	401906	19369B	PARTICIPANT	\N	PRESENT	0
404280	401906	14207L	PARTICIPANT	\N	PRESENT	0
404281	401906	19563B	PARTICIPANT	\N	PRESENT	0
404282	404212	19766L	PARTICIPANT	\N	PRESENT	0
404283	404212	19593H	PARTICIPANT	\N	PRESENT	0
404284	404212	04070G	PRESIDENT	0	PRESENT	0
404285	404212	19699S	PARTICIPANT	\N	PRESENT	0
404286	404212	14061L	PARTICIPANT	\N	PRESENT	0
404287	404212	04057K	PARTICIPANT	\N	PRESENT	0
404288	404212	14073Q	PARTICIPANT	\N	PRESENT	0
404289	404212	19533U	PARTICIPANT	\N	PRESENT	0
404290	404212	19611R	PARTICIPANT	\N	PRESENT	0
404291	404212	19693L	PARTICIPANT	\N	PRESENT	0
404292	404212	14030Q	PARTICIPANT	\N	PRESENT	0
404293	404212	19573D	PARTICIPANT	\N	PRESENT	0
404294	404212	14251Q	PARTICIPANT	\N	PRESENT	0
404295	404212	04059M	PARTICIPANT	\N	PRESENT	0
404296	404212	08017T	PARTICIPANT	\N	PRESENT	0
404297	404212	11083R	PARTICIPANT	\N	PRESENT	0
404298	404212	11104D	PARTICIPANT	\N	PRESENT	0
404299	404212	04018C	PARTICIPANT	\N	PRESENT	0
404300	404212	08031R	PARTICIPANT	\N	PRESENT	0
404301	404212	08039A	PARTICIPANT	\N	PRESENT	0
404302	404212	14059S	PARTICIPANT	\N	EXCUSE	0
404303	404212	92040Q	PARTICIPANT	\N	EXCUSE	0
404304	404212	08043V	PARTICIPANT	\N	EXCUSE	0
404305	404212	87003B	PARTICIPANT	\N	EXCUSE	0
404306	404212	19399H	PARTICIPANT	\N	EXCUSE	0
404308	400175	04059M	PARTICIPANT	\N	PRESENT	0
404310	400175	04043D	PARTICIPANT	\N	PRESENT	0
404311	400175	19782L	PARTICIPANT	\N	PRESENT	0
404312	400175	11033F	PARTICIPANT	\N	PRESENT	0
404313	400175	14147R	PARTICIPANT	\N	PRESENT	0
404314	400175	19737F	PARTICIPANT	\N	PRESENT	0
404315	400175	04018C	PARTICIPANT	\N	PRESENT	0
404316	400175	18083K	PARTICIPANT	\N	PRESENT	0
404317	400175	19631V	PARTICIPANT	\N	PRESENT	0
404318	400175	19269X	PARTICIPANT	\N	PRESENT	0
404319	400175	19563B	PARTICIPANT	\N	PRESENT	0
404320	400175	19695N	PARTICIPANT	\N	PRESENT	0
404321	400175	19699S	PARTICIPANT	\N	PRESENT	0
404322	400175	11012A	PARTICIPANT	\N	PRESENT	0
404323	400175	14089Y	PARTICIPANT	\N	PRESENT	0
404324	400175	19585H	PARTICIPANT	\N	PRESENT	0
404325	400175	14069U	PARTICIPANT	\N	PRESENT	0
404326	400175	19583F	PARTICIPANT	\N	PRESENT	0
404327	400175	14038Y	PARTICIPANT	\N	PRESENT	0
404328	400175	19713W	PARTICIPANT	\N	PRESENT	0
404329	400175	01057W	PARTICIPANT	\N	PRESENT	0
404330	400175	14119M	PARTICIPANT	\N	PRESENT	0
404331	400175	19441R	PARTICIPANT	\N	PRESENT	0
404332	400175	19369B	PARTICIPANT	\N	PRESENT	0
404333	400175	14073Q	PARTICIPANT	\N	PRESENT	0
411528	411524	10006L	PARTICIPANT	\N	PRESENT	0
411530	411524	11067R	PARTICIPANT	\N	PRESENT	0
411531	411524	14147R	PARTICIPANT	\N	PRESENT	0
411532	411524	19629C	PARTICIPANT	\N	PRESENT	0
413533	413531	10006L	PARTICIPANT	\N	PRESENT	0
413534	413531	08052W	PARTICIPANT	\N	PRESENT	0
413535	413531	11097X	PARTICIPANT	\N	PRESENT	0
413536	413532	10006L	PARTICIPANT	\N	PRESENT	0
413537	413532	08052W	PARTICIPANT	\N	PRESENT	0
413538	413532	11097X	PARTICIPANT	\N	PRESENT	0
413612	413611	08018U	PARTICIPANT	\N	PRESENT	0
413624	413623	19619A	PARTICIPANT	\N	PRESENT	0
413626	413623	19563B	PARTICIPANT	\N	PRESENT	0
413629	413623	19507S	PARTICIPANT	\N	PRESENT	0
413631	413623	14033T	PARTICIPANT	\N	PRESENT	0
413639	413623	14207L	PARTICIPANT	\N	PRESENT	0
413640	413623	14135M	PARTICIPANT	\N	PRESENT	0
413643	413623	11099A	PARTICIPANT	\N	PRESENT	0
413644	413623	14205J	PARTICIPANT	\N	PRESENT	0
413680	413679	14033T	PARTICIPANT	\N	PRESENT	0
413681	413679	14135M	PARTICIPANT	\N	PRESENT	0
413683	413679	14207L	PARTICIPANT	\N	PRESENT	0
413685	413679	19441R	PARTICIPANT	\N	PRESENT	0
413696	413694	14033T	PARTICIPANT	\N	PRESENT	0
413697	413694	14135M	PARTICIPANT	\N	PRESENT	0
413698	413694	14207L	PARTICIPANT	\N	PRESENT	0
413702	413701	14033T	PARTICIPANT	\N	PRESENT	0
413703	413701	14135M	PARTICIPANT	\N	PRESENT	0
413707	413706	14033T	PARTICIPANT	\N	PRESENT	0
413708	413706	14135M	PARTICIPANT	\N	PRESENT	0
413714	413713	19441R	PARTICIPANT	\N	PRESENT	0
413715	413713	14033T	PARTICIPANT	\N	PRESENT	0
413716	413713	14135M	PARTICIPANT	\N	PRESENT	0
413717	413713	14205J	PARTICIPANT	\N	PRESENT	0
413718	413713	19269X	PARTICIPANT	\N	PRESENT	0
414989	413357	11026G	PARTICIPANT	\N	PRESENT	0
414990	413357	19719D	PARTICIPANT	\N	PRESENT	0
414991	413357	08044W	PARTICIPANT	\N	PRESENT	0
414992	413357	11049P	PARTICIPANT	\N	PRESENT	0
414993	413357	19762G	PARTICIPANT	\N	PRESENT	0
414994	412749	01043Q	PARTICIPANT	\N	PRESENT	0
414995	412749	08038Y	PARTICIPANT	\N	PRESENT	0
414996	412749	14205J	PARTICIPANT	\N	PRESENT	0
414997	412749	11056N	PARTICIPANT	\N	PRESENT	0
414998	412749	19619A	PARTICIPANT	\N	PRESENT	0
414999	412749	11081P	PARTICIPANT	\N	EXCUSE	0
415000	412749	17589D	PARTICIPANT	\N	EXCUSE	0
415002	412790	19685L	PARTICIPANT	\N	PRESENT	0
415003	413357	14179A	PARTICIPANT	\N	PRESENT	0
415004	413357	11010L	PARTICIPANT	\N	PRESENT	0
415005	414444	07033P	PARTICIPANT	\N	PRESENT	0
415007	413358	19689Q	PARTICIPANT	\N	PRESENT	0
415009	414444	14039A	PARTICIPANT	\N	PRESENT	0
415015	412790	19333N	PARTICIPANT	\N	PRESENT	0
415016	412790	14103D	PARTICIPANT	\N	PRESENT	0
415020	413357	19673G	PARTICIPANT	\N	PRESENT	0
415021	413357	19489J	PARTICIPANT	\N	PRESENT	0
415022	413357	19649G	PARTICIPANT	\N	PRESENT	0
415023	413357	11085T	PARTICIPANT	\N	PRESENT	0
415024	413358	19651A	PARTICIPANT	\N	PRESENT	0
415025	412749	19441R	PARTICIPANT	\N	PRESENT	0
415026	412749	19511N	PARTICIPANT	\N	PRESENT	0
415027	412749	14135M	PARTICIPANT	\N	PRESENT	0
415028	412749	19295A	PARTICIPANT	\N	PRESENT	0
415029	412749	19269X	PARTICIPANT	\N	PRESENT	0
415032	414444	19335Q	PARTICIPANT	\N	PRESENT	0
415033	414444	14030Q	PARTICIPANT	\N	PRESENT	0
415034	414444	11109J	PARTICIPANT	\N	PRESENT	0
415035	414444	11083R	PARTICIPANT	\N	PRESENT	0
415037	414029	11027H	PARTICIPANT	\N	PRESENT	0
415038	414029	97011G	PARTICIPANT	\N	PRESENT	0
415039	414029	19721W	PARTICIPANT	\N	PRESENT	0
415041	413357	14021P	PARTICIPANT	\N	PRESENT	0
415043	414444	19693L	PARTICIPANT	\N	EXCUSE	0
415044	414029	08053X	PARTICIPANT	\N	PRESENT	0
415105	413506	11067R	PARTICIPANT	\N	PRESENT	0
415106	413506	19565D	PARTICIPANT	\N	PRESENT	0
415107	413506	19798U	PARTICIPANT	\N	PRESENT	0
415108	413506	19569H	PARTICIPANT	\N	PRESENT	0
415109	413506	11097X	PARTICIPANT	\N	PRESENT	0
415110	413506	19415P	PARTICIPANT	\N	PRESENT	0
415111	413506	14223L	PARTICIPANT	\N	PRESENT	0
415112	413506	14026U	PARTICIPANT	\N	PRESENT	0
415113	413506	14227Q	PARTICIPANT	\N	PRESENT	0
415114	413506	17779H	PARTICIPANT	\N	PRESENT	0
415115	413506	19703U	PARTICIPANT	\N	PRESENT	0
415116	413506	19553Y	PARTICIPANT	\N	PRESENT	0
415117	413506	14239U	PARTICIPANT	\N	PRESENT	0
415118	413506	14087W	PARTICIPANT	\N	PRESENT	0
415119	413506	14281W	PARTICIPANT	\N	PRESENT	0
415120	413506	19679N	PARTICIPANT	\N	PRESENT	0
415121	413506	14195A	PARTICIPANT	\N	PRESENT	0
415122	413506	19575F	PARTICIPANT	\N	PRESENT	0
415123	413506	14213J	PARTICIPANT	\N	PRESENT	0
415124	413506	19367Y	PARTICIPANT	\N	PRESENT	0
415125	413506	14261S	PARTICIPANT	\N	PRESENT	0
415126	413506	14217N	PARTICIPANT	\N	PRESENT	0
415127	413506	10006L	PARTICIPANT	\N	PRESENT	0
415128	413506	19521Q	PARTICIPANT	\N	PRESENT	0
415129	413506	98024R	PARTICIPANT	\N	PRESENT	0
415130	413506	19527W	PARTICIPANT	\N	PRESENT	0
415131	413506	04092N	PRESIDENT	0	PRESENT	0
415132	413506	08052W	PARTICIPANT	\N	PRESENT	0
415133	413506	19663E	PARTICIPANT	\N	PRESENT	0
415134	413506	19301E	PARTICIPANT	\N	PRESENT	0
415135	413506	19715Y	PARTICIPANT	\N	PRESENT	0
415136	413506	19691J	PARTICIPANT	\N	PRESENT	0
415137	413506	19723Y	PARTICIPANT	\N	PRESENT	0
415138	413506	19727D	PARTICIPANT	\N	PRESENT	0
415139	413506	14119M	PARTICIPANT	\N	PRESENT	0
415141	413506	11103C	PARTICIPANT	\N	PRESENT	0
415143	413506	14071N	PARTICIPANT	\N	PRESENT	0
415146	413506	19760E	PARTICIPANT	\N	PRESENT	0
415148	413506	14042U	PARTICIPANT	\N	EXCUSE	0
415149	413506	08041T	PARTICIPANT	\N	EXCUSE	0
415185	413451	14327T	PARTICIPANT	\N	PRESENT	0
415186	413451	14331P	PARTICIPANT	\N	PRESENT	0
415187	413451	11053K	PARTICIPANT	\N	PRESENT	0
415188	413451	11074Q	PRESIDENT	0	PRESENT	0
415189	413451	88008L	PARTICIPANT	\N	PRESENT	0
415190	413451	14225N	PARTICIPANT	\N	PRESENT	0
415191	413451	11110B	PARTICIPANT	\N	PRESENT	0
415192	413451	07029T	PARTICIPANT	\N	PRESENT	0
415193	413451	14085U	PARTICIPANT	\N	PRESENT	0
415194	413451	19349W	PARTICIPANT	\N	PRESENT	0
415195	413451	08010L	PARTICIPANT	\N	PRESENT	0
415196	413451	19479G	PARTICIPANT	\N	PRESENT	0
415197	413451	19647E	PARTICIPANT	\N	PRESENT	0
415198	413451	19711U	PARTICIPANT	\N	PRESENT	0
415199	413451	19651A	PARTICIPANT	\N	PRESENT	0
415200	413451	08069G	PARTICIPANT	\N	PRESENT	0
415201	413451	19687N	PARTICIPANT	\N	PRESENT	0
415202	413451	19689Q	PARTICIPANT	\N	PRESENT	0
415203	413451	12016W	PARTICIPANT	\N	PRESENT	0
415204	413451	08011M	PARTICIPANT	\N	PRESENT	0
415205	413451	08014Q	PARTICIPANT	\N	PRESENT	0
415206	413451	11040E	PARTICIPANT	\N	PRESENT	0
415207	413451	11012A	PARTICIPANT	\N	PRESENT	0
415208	413451	14121F	PARTICIPANT	\N	PRESENT	0
415209	413451	19741B	PARTICIPANT	\N	PRESENT	0
415210	413451	99004R	PARTICIPANT	\N	PRESENT	0
415211	413451	14083S	PARTICIPANT	\N	PRESENT	0
415212	413451	11048N	PARTICIPANT	\N	PRESENT	0
415213	413451	14199E	PARTICIPANT	\N	PRESENT	0
415214	413451	08034U	PARTICIPANT	\N	PRESENT	0
415215	413451	19545Y	PARTICIPANT	\N	PRESENT	0
415216	413451	07004J	PARTICIPANT	\N	PRESENT	0
415217	413451	89017R	PARTICIPANT	\N	PRESENT	0
415218	413451	14034U	PARTICIPANT	\N	PRESENT	0
415219	413451	19671E	PARTICIPANT	\N	PRESENT	0
415220	413451	14173T	PARTICIPANT	\N	PRESENT	0
415221	413451	01057W	PARTICIPANT	\N	EXCUSE	0
415222	413451	14159V	PARTICIPANT	\N	EXCUSE	0
415244	413357	08018U	PARTICIPANT	\N	EXCUSE	0
415245	412265	08038Y	PARTICIPANT	\N	EXCUSE	0
415250	414029	08049C	PARTICIPANT	\N	EXCUSE	0
415534	415523	08012N	PARTICIPANT	\N	PRESENT	0
415540	406854	11033F	PARTICIPANT	\N	PRESENT	0
415541	406854	19727D	PARTICIPANT	\N	PRESENT	0
415542	406854	19531S	PARTICIPANT	\N	PRESENT	0
415543	406854	04070G	PARTICIPANT	\N	PRESENT	0
415544	406854	19367Y	PARTICIPANT	\N	PRESENT	0
415545	406854	19621T	PARTICIPANT	\N	PRESENT	0
415546	406854	05008E	PARTICIPANT	\N	PRESENT	0
393791	393790	19253P	PARTICIPANT	\N	PRESENT	0
393792	393790	11053K	PARTICIPANT	\N	PRESENT	0
393793	393790	19671E	PARTICIPANT	\N	PRESENT	0
393794	393790	14083S	PARTICIPANT	\N	PRESENT	0
393795	393790	14357A	PARTICIPANT	\N	PRESENT	0
393797	393796	19253P	PARTICIPANT	\N	PRESENT	0
393798	393796	19671E	PARTICIPANT	\N	PRESENT	0
393799	393796	11053K	PARTICIPANT	\N	PRESENT	0
393800	393796	15447F	PARTICIPANT	\N	PRESENT	0
393801	393796	14357A	PARTICIPANT	\N	PRESENT	0
393802	393796	14083S	PARTICIPANT	\N	PRESENT	0
393803	393796	19729F	PARTICIPANT	\N	PRESENT	0
393805	393804	19253P	PARTICIPANT	\N	PRESENT	0
393806	393804	19333N	PARTICIPANT	\N	PRESENT	0
393807	393804	14083S	PARTICIPANT	\N	PRESENT	0
393808	393804	19671E	PARTICIPANT	\N	PRESENT	0
393810	393809	19253P	PARTICIPANT	\N	PRESENT	0
393811	393809	19301E	PARTICIPANT	\N	PRESENT	0
399641	399329	08068F	PARTICIPANT	\N	PRESENT	0
399642	399329	19782L	PARTICIPANT	\N	PRESENT	0
399643	399329	19599P	PARTICIPANT	\N	PRESENT	0
399644	399329	19695N	PARTICIPANT	\N	PRESENT	0
399645	399329	19711U	PARTICIPANT	\N	PRESENT	0
399646	399329	01043Q	PARTICIPANT	\N	PRESENT	0
399647	399329	01048V	PARTICIPANT	\N	PRESENT	0
399648	399329	19563B	PRESIDENT	0	PRESENT	0
399649	399329	19768N	PARTICIPANT	\N	PRESENT	0
399650	399329	19713W	PARTICIPANT	\N	PRESENT	0
399651	399329	19413M	PARTICIPANT	\N	PRESENT	0
399652	399329	01062T	PARTICIPANT	\N	PRESENT	0
399653	399329	95067Q	PARTICIPANT	\N	PRESENT	0
399654	399329	04049K	PARTICIPANT	\N	EXCUSE	0
399655	397570	01028R	PARTICIPANT	\N	PRESENT	0
399656	397570	19553Y	PARTICIPANT	\N	PRESENT	0
399657	397570	14151M	PARTICIPANT	\N	PRESENT	0
399658	397570	10006L	PARTICIPANT	\N	PRESENT	0
399659	397570	19521Q	PARTICIPANT	\N	PRESENT	0
399660	397570	10015M	PARTICIPANT	\N	PRESENT	0
399661	397570	19663E	PARTICIPANT	\N	PRESENT	0
399662	397570	04038G	PARTICIPANT	\N	PRESENT	0
399663	397570	04047H	PARTICIPANT	\N	PRESENT	0
399664	397570	11031D	PARTICIPANT	\N	PRESENT	0
399665	397570	19575F	PARTICIPANT	\N	PRESENT	0
399666	397570	14213J	PARTICIPANT	\N	PRESENT	0
399667	397570	14215L	PARTICIPANT	\N	PRESENT	0
399668	397570	11072N	PARTICIPANT	\N	PRESENT	0
399669	397570	01034P	PARTICIPANT	\N	PRESENT	0
399670	397570	19760E	PARTICIPANT	\N	PRESENT	0
399671	397570	19569H	PARTICIPANT	\N	PRESENT	0
399672	397570	19577H	PARTICIPANT	\N	EXCUSE	0
399673	399329	14265W	PARTICIPANT	\N	EXCUSE	0
399618	398232	08028W	PARTICIPANT	\N	PRESENT	0
399619	398232	19563B	PARTICIPANT	\N	PRESENT	0
399620	398232	14265W	PARTICIPANT	\N	PRESENT	0
399621	398232	19591F	PARTICIPANT	\N	PRESENT	0
399622	398232	14135M	PARTICIPANT	\N	PRESENT	0
399623	398232	19467C	PARTICIPANT	\N	PRESENT	0
399624	398232	14187A	PARTICIPANT	\N	PRESENT	0
399625	398232	19695N	PARTICIPANT	\N	PRESENT	0
399626	398232	01025N	PARTICIPANT	\N	PRESENT	0
399627	398232	11090Q	PRESIDENT	0	PRESENT	0
399628	398232	14033T	PARTICIPANT	\N	PRESENT	0
399629	398232	14205J	PARTICIPANT	\N	PRESENT	0
399630	398232	04088S	PARTICIPANT	\N	PRESENT	0
399631	398232	11056N	PARTICIPANT	\N	PRESENT	0
399632	398232	14115H	PARTICIPANT	\N	PRESENT	0
399633	398232	19733B	PARTICIPANT	\N	PRESENT	0
399634	398232	19507S	PARTICIPANT	\N	PRESENT	0
399635	398232	11101A	PARTICIPANT	\N	PRESENT	0
399636	398232	14207L	PARTICIPANT	\N	PRESENT	0
399637	398232	19747H	PARTICIPANT	\N	PRESENT	0
399638	398232	19619A	PARTICIPANT	\N	PRESENT	0
399639	398232	17589D	PARTICIPANT	\N	PRESENT	0
399640	399329	19575F	PARTICIPANT	\N	PRESENT	0
399674	399329	14237S	PARTICIPANT	\N	EXCUSE	0
399675	399329	19503N	PARTICIPANT	\N	EXCUSE	0
399676	397657	14097Y	PARTICIPANT	\N	PRESENT	0
399693	397570	08044W	PARTICIPANT	\N	PRESENT	0
399694	397570	14069U	PARTICIPANT	\N	PRESENT	0
399695	397570	19581D	PARTICIPANT	\N	PRESENT	0
399696	397570	14179A	PARTICIPANT	\N	PRESENT	0
399697	397570	14259Y	PARTICIPANT	\N	PRESENT	0
399698	397570	14111D	PARTICIPANT	\N	PRESENT	0
399699	397570	08045X	PARTICIPANT	\N	PRESENT	0
399700	397993	11067R	PARTICIPANT	\N	PRESENT	0
399701	397993	19798U	PARTICIPANT	\N	PRESENT	0
399702	397993	11097X	PARTICIPANT	\N	PRESENT	0
399703	397993	19673G	PARTICIPANT	\N	PRESENT	0
399704	397993	01028R	PARTICIPANT	\N	PRESENT	0
399705	397993	19553Y	PARTICIPANT	\N	PRESENT	0
399706	397993	19679N	PARTICIPANT	\N	PRESENT	0
399707	397993	14042U	PARTICIPANT	\N	PRESENT	0
399708	397993	08048B	PARTICIPANT	\N	PRESENT	0
399709	397993	14147R	PARTICIPANT	\N	PRESENT	0
399710	397993	14151M	PARTICIPANT	\N	PRESENT	0
399711	397993	10006L	PARTICIPANT	\N	PRESENT	0
399712	397993	98024R	PARTICIPANT	\N	PRESENT	0
399713	397993	19521Q	PARTICIPANT	\N	PRESENT	0
399714	397993	10015M	PARTICIPANT	\N	PRESENT	0
399715	397993	08052W	PARTICIPANT	\N	PRESENT	0
399716	397993	19663E	PARTICIPANT	\N	PRESENT	0
399717	397993	01024M	PARTICIPANT	\N	PRESENT	0
399718	397993	19691J	PARTICIPANT	\N	PRESENT	0
399719	397993	04038G	PARTICIPANT	\N	PRESENT	0
399720	397993	08044W	PARTICIPANT	\N	PRESENT	0
399721	397993	14069U	PARTICIPANT	\N	PRESENT	0
399722	397993	14071N	PARTICIPANT	\N	PRESENT	0
399723	397993	14021P	PARTICIPANT	\N	PRESENT	0
399724	397993	19569H	PARTICIPANT	\N	PRESENT	0
399725	397993	19581D	PARTICIPANT	\N	PRESENT	0
399726	397993	14223L	PARTICIPANT	\N	PRESENT	0
399727	397993	14026U	PARTICIPANT	\N	PRESENT	0
399728	397993	17779H	PARTICIPANT	\N	PRESENT	0
399729	397993	14231L	PARTICIPANT	\N	PRESENT	0
399730	397993	05008E	PRESIDENT	0	PRESENT	0
399731	397993	19703U	PARTICIPANT	\N	PRESENT	0
399732	397993	11031D	PARTICIPANT	\N	PRESENT	0
399733	397993	19489J	PARTICIPANT	\N	PRESENT	0
399734	397993	14281W	PARTICIPANT	\N	PRESENT	0
399735	397993	14087W	PARTICIPANT	\N	PRESENT	0
399736	397993	14195A	PARTICIPANT	\N	PRESENT	0
399737	397993	19575F	PARTICIPANT	\N	PRESENT	0
399738	397993	14179A	PARTICIPANT	\N	PRESENT	0
399739	397993	19367Y	PARTICIPANT	\N	PRESENT	0
399740	397993	14213J	PARTICIPANT	\N	PRESENT	0
399741	397993	14217N	PARTICIPANT	\N	PRESENT	0
399742	397993	14259Y	PARTICIPANT	\N	PRESENT	0
399743	397993	11072N	PARTICIPANT	\N	PRESENT	0
399744	397993	14053L	PARTICIPANT	\N	PRESENT	0
399745	397993	01034P	PARTICIPANT	\N	PRESENT	0
399746	397993	14111D	PARTICIPANT	\N	PRESENT	0
399747	397993	08045X	PARTICIPANT	\N	PRESENT	0
399748	397993	19719D	PARTICIPANT	\N	PRESENT	0
399749	397993	19725B	PARTICIPANT	\N	PRESENT	0
399750	397993	11103C	PARTICIPANT	\N	PRESENT	0
399751	397993	19760E	PARTICIPANT	\N	PRESENT	0
399752	397993	19762G	PARTICIPANT	\N	PRESENT	0
399753	397993	98035U	PARTICIPANT	\N	PRESENT	0
399754	397993	14089Y	PARTICIPANT	\N	PRESENT	0
399755	397993	14041T	PARTICIPANT	\N	PRESENT	0
399756	397993	19253P	PARTICIPANT	\N	PRESENT	0
399757	397993	14215L	PARTICIPANT	\N	PRESENT	0
399758	397993	04047H	PARTICIPANT	\N	PRESENT	0
399759	397993	19729F	PARTICIPANT	\N	EXCUSE	0
399760	397993	04044E	PARTICIPANT	\N	EXCUSE	0
399765	399485	11109J	PARTICIPANT	\N	PRESENT	0
399766	398232	01043Q	PARTICIPANT	\N	PRESENT	0
399767	398232	08019V	PARTICIPANT	\N	PRESENT	0
399771	397947	11053K	PARTICIPANT	\N	PRESENT	0
399797	398302	17637T	PARTICIPANT	\N	PRESENT	0
399800	397995	14215L	PARTICIPANT	\N	PRESENT	0
400012	397658	08061X	PARTICIPANT	\N	PRESENT	0
400015	397658	95067Q	PARTICIPANT	\N	PRESENT	0
400017	397658	04035D	PARTICIPANT	\N	PRESENT	0
400020	397658	01058X	PARTICIPANT	\N	PRESENT	0
400022	397658	01062T	PARTICIPANT	\N	PRESENT	0
400023	397658	11064N	PARTICIPANT	\N	PRESENT	0
407841	405342	14327T	PARTICIPANT	\N	PRESENT	0
407842	405342	14257W	PARTICIPANT	\N	PRESENT	0
407843	405342	08049C	PARTICIPANT	\N	PRESENT	0
413274	410828	19585H	PARTICIPANT	\N	PRESENT	0
413276	413273	10006L	PARTICIPANT	\N	PRESENT	0
413277	413273	08052W	PARTICIPANT	\N	PRESENT	0
413294	411906	10006L	PARTICIPANT	\N	PRESENT	0
413295	411906	11067R	PARTICIPANT	\N	PRESENT	0
413296	411906	14147R	PARTICIPANT	\N	PRESENT	0
413297	411906	19629C	PARTICIPANT	\N	PRESENT	0
413320	411140	08009T	PARTICIPANT	\N	PRESENT	0
413321	411140	14001X	PARTICIPANT	\N	PRESENT	0
413322	411140	08024S	PARTICIPANT	\N	PRESENT	0
413323	411140	19681G	PARTICIPANT	\N	PRESENT	0
413324	411140	14207L	PARTICIPANT	\N	PRESENT	0
413325	411140	19553Y	PARTICIPANT	\N	PRESENT	0
413326	411140	19631V	PARTICIPANT	\N	PRESENT	0
413327	411140	19515S	PARTICIPANT	\N	PRESENT	0
413328	411140	04070G	PARTICIPANT	\N	PRESENT	0
413329	411140	19826F	PARTICIPANT	\N	PRESENT	0
413330	411140	19739H	PARTICIPANT	\N	PRESENT	0
413331	411140	14053L	PARTICIPANT	\N	PRESENT	0
413332	411140	11048N	PARTICIPANT	\N	PRESENT	0
413333	411140	14121F	PARTICIPANT	\N	PRESENT	0
413334	411140	19747H	PARTICIPANT	\N	PRESENT	0
413335	411140	99004R	PARTICIPANT	\N	PRESENT	0
413336	411140	14042U	PARTICIPANT	\N	PRESENT	0
413337	411140	11040E	PARTICIPANT	\N	PRESENT	0
413338	411140	04085P	PARTICIPANT	\N	PRESENT	0
413339	411140	19758L	PARTICIPANT	\N	PRESENT	0
413340	411140	14251Q	PARTICIPANT	\N	PRESENT	0
413341	411140	14081Q	PARTICIPANT	\N	PRESENT	0
413342	411140	19503N	PARTICIPANT	\N	PRESENT	0
413343	411140	14038Y	PARTICIPANT	\N	PRESENT	0
413344	411140	18083K	PARTICIPANT	\N	PRESENT	0
413345	411140	19737F	PARTICIPANT	\N	PRESENT	0
413346	411140	08019V	PARTICIPANT	\N	PRESENT	0
413347	410828	14089Y	PARTICIPANT	\N	EXCUSE	0
413348	410828	19729F	PARTICIPANT	\N	EXCUSE	0
413349	410828	08018U	PARTICIPANT	\N	EXCUSE	0
413350	411140	19251M	PARTICIPANT	\N	PRESENT	0
413351	411140	19489J	PARTICIPANT	\N	PRESENT	0
413352	411140	14069U	PARTICIPANT	\N	PRESENT	0
413353	411140	14111D	PARTICIPANT	\N	PRESENT	0
413399	406847	04059M	PARTICIPANT	\N	PRESENT	0
413400	406847	99004R	PARTICIPANT	\N	PRESENT	0
413421	406847	11040E	PARTICIPANT	\N	PRESENT	0
413423	406847	14229S	PARTICIPANT	\N	PRESENT	0
413403	406847	19739H	PARTICIPANT	\N	PRESENT	0
413404	406847	19735D	PARTICIPANT	\N	PRESENT	0
413406	406847	19762G	PARTICIPANT	\N	PRESENT	0
413407	406847	80013X	PARTICIPANT	\N	PRESENT	0
413408	406847	14231L	PARTICIPANT	\N	PRESENT	0
413409	406847	19447X	PARTICIPANT	\N	PRESENT	0
413410	406847	19737F	PARTICIPANT	\N	PRESENT	0
413411	406847	19489J	PARTICIPANT	\N	PRESENT	0
413412	406847	14215L	PARTICIPANT	\N	PRESENT	0
413454	406847	05008E	PARTICIPANT	\N	PRESENT	0
413424	406847	19691J	PARTICIPANT	\N	PRESENT	0
413415	406847	14081Q	PARTICIPANT	\N	PRESENT	0
413416	406847	08045X	PARTICIPANT	\N	PRESENT	0
413417	406847	19347U	PARTICIPANT	\N	PRESENT	0
413418	406847	11056N	PARTICIPANT	\N	PRESENT	0
413419	406847	14107H	PARTICIPANT	\N	PRESENT	0
413420	406847	14259Y	PARTICIPANT	\N	PRESENT	0
413422	406847	14121F	PARTICIPANT	\N	PRESENT	0
413426	406847	19515S	PARTICIPANT	\N	PRESENT	0
413427	406847	14179A	PARTICIPANT	\N	PRESENT	0
413428	406847	11048N	PARTICIPANT	\N	PRESENT	0
413429	406847	08044W	PARTICIPANT	\N	PRESENT	0
413430	406847	08009T	PARTICIPANT	\N	PRESENT	0
413431	406847	04088S	PARTICIPANT	\N	PRESENT	0
413432	406847	11012A	PARTICIPANT	\N	PRESENT	0
413433	406847	14001X	PARTICIPANT	\N	PRESENT	0
413434	406847	14249W	PARTICIPANT	\N	PRESENT	0
413442	406847	19663E	PARTICIPANT	\N	PRESENT	0
413436	406847	19631V	PARTICIPANT	\N	PRESENT	0
413437	406847	19251M	PARTICIPANT	\N	PRESENT	0
413438	406847	19503N	PARTICIPANT	\N	PRESENT	0
413439	406847	19747H	PARTICIPANT	\N	PRESENT	0
413440	406847	19399H	PARTICIPANT	\N	PRESENT	0
413441	406847	14199E	PARTICIPANT	\N	PRESENT	0
413443	406847	01057W	PARTICIPANT	\N	PRESENT	0
413444	406847	14123H	PARTICIPANT	\N	PRESENT	0
413445	406847	19335Q	PARTICIPANT	\N	PRESENT	0
413446	406847	19565D	PARTICIPANT	\N	PRESENT	0
413457	406847	11109J	PARTICIPANT	\N	PRESENT	0
413448	406847	08024S	PARTICIPANT	\N	PRESENT	0
413449	406847	14207L	PARTICIPANT	\N	PRESENT	0
413450	406847	04086Q	PARTICIPANT	\N	PRESENT	0
413452	406847	08061X	PARTICIPANT	\N	PRESENT	0
413453	406847	19553Y	PARTICIPANT	\N	PRESENT	0
413455	406847	19681G	PARTICIPANT	\N	PRESENT	0
413456	406847	14147R	PARTICIPANT	\N	PRESENT	0
413458	406847	19387D	PARTICIPANT	\N	PRESENT	0
413459	406847	14151M	PARTICIPANT	\N	PRESENT	0
413460	406847	19820Y	PARTICIPANT	\N	PRESENT	0
413461	406847	19826F	PARTICIPANT	\N	PRESENT	0
413462	406847	19543W	PARTICIPANT	\N	PRESENT	0
413463	406847	19531S	PARTICIPANT	\N	PRESENT	0
413465	406847	19581D	PARTICIPANT	\N	PRESENT	0
413466	406847	14327T	PARTICIPANT	\N	PRESENT	0
413474	406847	19611R	PARTICIPANT	\N	PRESENT	0
413468	406847	14053L	PARTICIPANT	\N	PRESENT	0
413469	406847	14105F	PARTICIPANT	\N	PRESENT	0
413470	406847	14111D	PARTICIPANT	\N	PRESENT	0
413477	406847	19551W	PARTICIPANT	\N	PRESENT	0
413475	406847	19441R	PARTICIPANT	\N	PRESENT	0
413473	406847	04085P	PARTICIPANT	\N	PRESENT	0
413476	406847	19549D	PARTICIPANT	\N	PRESENT	0
413478	406847	19421M	PARTICIPANT	\N	PRESENT	0
413479	406847	19511N	PARTICIPANT	\N	PRESENT	0
413480	406847	19733B	PARTICIPANT	\N	PRESENT	0
413481	406847	08010L	PARTICIPANT	\N	PRESENT	0
413482	406847	19709B	PARTICIPANT	\N	PRESENT	0
413483	406847	19575F	PARTICIPANT	\N	PRESENT	0
413484	406847	19719D	PARTICIPANT	\N	PRESENT	0
413485	406847	19479G	PARTICIPANT	\N	PRESENT	0
413486	406847	19794Q	PARTICIPANT	\N	PRESENT	0
413487	406847	14211G	PARTICIPANT	\N	PRESENT	0
413488	406847	14021P	PARTICIPANT	\N	PRESENT	0
413489	406847	04040A	PARTICIPANT	\N	PRESENT	0
413490	406847	01048V	PARTICIPANT	\N	PRESENT	0
413491	406847	14071N	PARTICIPANT	\N	PRESENT	0
413492	406847	19521Q	PARTICIPANT	\N	PRESENT	0
413493	406847	19741B	PARTICIPANT	\N	PRESENT	0
413494	406847	14042U	PARTICIPANT	\N	PRESENT	0
413505	406847	19295A	PARTICIPANT	\N	PRESENT	0
413508	406847	19573D	PARTICIPANT	\N	PRESENT	0
413509	406847	11097X	PARTICIPANT	\N	PRESENT	0
413510	406847	17637T	PARTICIPANT	\N	PRESENT	0
413511	406847	19683J	PARTICIPANT	\N	PRESENT	0
413512	406847	19563B	PARTICIPANT	\N	PRESENT	0
413513	406847	14073Q	PARTICIPANT	\N	PRESENT	0
413514	406847	19711U	PARTICIPANT	\N	PRESENT	0
413515	406847	14265W	PARTICIPANT	\N	PRESENT	0
413516	406847	19657G	PARTICIPANT	\N	PRESENT	0
413517	406847	14083S	PARTICIPANT	\N	PRESENT	0
413518	406847	14133K	PARTICIPANT	\N	PRESENT	0
413520	406847	08068F	PARTICIPANT	\N	PRESENT	0
413521	406847	01028R	PARTICIPANT	\N	PRESENT	0
413522	406847	14065Q	PARTICIPANT	\N	PRESENT	0
413523	406847	98050T	PARTICIPANT	\N	PRESENT	0
413524	406847	88008L	PARTICIPANT	\N	PRESENT	0
413525	406847	14217N	PARTICIPANT	\N	PRESENT	0
413526	406847	14069U	PARTICIPANT	\N	PRESENT	0
413527	406847	19731Y	PARTICIPANT	\N	PRESENT	0
413528	406847	14033T	PARTICIPANT	\N	PRESENT	0
413529	406847	10015M	PARTICIPANT	\N	PRESENT	0
393773	393772	14121F	PARTICIPANT	\N	PRESENT	0
393775	393774	14121F	PARTICIPANT	\N	PRESENT	0
393779	393778	19545Y	PARTICIPANT	\N	PRESENT	0
393780	393778	19689Q	PARTICIPANT	\N	PRESENT	0
393782	393781	19689Q	PARTICIPANT	\N	PRESENT	0
393784	393783	14327T	PARTICIPANT	\N	PRESENT	0
393785	393783	11110B	PARTICIPANT	\N	PRESENT	0
393786	393783	05012A	PARTICIPANT	\N	PRESENT	0
393788	393787	14327T	PARTICIPANT	\N	PRESENT	0
393789	393787	05012A	PARTICIPANT	\N	PRESENT	0
393813	393812	19531S	PARTICIPANT	\N	PRESENT	0
396306	396305	14026U	PARTICIPANT	\N	PRESENT	0
396307	396305	19717B	PARTICIPANT	\N	PRESENT	0
396309	396308	14026U	PARTICIPANT	\N	PRESENT	0
396310	396308	19717B	PARTICIPANT	\N	PRESENT	0
396314	396312	14026U	PARTICIPANT	\N	PRESENT	0
396315	396312	19717B	PARTICIPANT	\N	PRESENT	0
396316	396313	14026U	PARTICIPANT	\N	PRESENT	0
396317	396313	19717B	PARTICIPANT	\N	PRESENT	0
396629	396628	14105F	PARTICIPANT	\N	PRESENT	0
396630	396628	04042C	PARTICIPANT	\N	PRESENT	0
396631	396628	98029W	PARTICIPANT	\N	PRESENT	0
396632	396628	14267Y	PARTICIPANT	\N	PRESENT	0
396633	396628	11027H	PARTICIPANT	\N	PRESENT	0
396634	396628	04035D	PARTICIPANT	\N	PRESENT	0
396638	396628	14211G	PARTICIPANT	\N	PRESENT	0
396639	396628	98022P	PARTICIPANT	\N	PRESENT	0
396641	396628	12041X	PARTICIPANT	\N	PRESENT	0
396642	396628	16685X	PARTICIPANT	\N	PRESENT	0
396643	396628	01058X	PARTICIPANT	\N	PRESENT	0
396644	396628	01062T	PARTICIPANT	\N	PRESENT	0
398074	396227	14299H	PARTICIPANT	\N	EXCUSE	0
398101	396227	19663E	PARTICIPANT	\N	PRESENT	0
398103	396227	19503N	PARTICIPANT	\N	PRESENT	0
398110	396227	01048V	PARTICIPANT	\N	EXCUSE	0
402893	402892	04044E	PARTICIPANT	\N	PRESENT	0
402894	402892	14021P	PARTICIPANT	\N	PRESENT	0
402895	402892	14179A	PARTICIPANT	\N	PRESENT	0
402897	402896	04044E	PARTICIPANT	\N	PRESENT	0
402898	402896	14021P	PARTICIPANT	\N	PRESENT	0
402899	402896	14179A	PARTICIPANT	\N	PRESENT	0
402901	402900	19701S	PARTICIPANT	\N	PRESENT	0
402903	402902	19701S	PARTICIPANT	\N	PRESENT	0
402904	402902	14083S	PARTICIPANT	\N	PRESENT	0
402907	402905	19701S	PARTICIPANT	\N	PRESENT	0
402908	402905	14031R	PARTICIPANT	\N	PRESENT	0
402910	402909	19701S	PARTICIPANT	\N	PRESENT	0
402911	402909	19794Q	PARTICIPANT	\N	PRESENT	0
402912	402906	19701S	PARTICIPANT	\N	PRESENT	0
402914	402913	19701S	PARTICIPANT	\N	PRESENT	0
402917	402916	14083S	PARTICIPANT	\N	PRESENT	0
402918	402916	14205J	PARTICIPANT	\N	PRESENT	0
402919	402916	14031R	PARTICIPANT	\N	PRESENT	0
402920	402916	19701S	PARTICIPANT	\N	PRESENT	0
402921	402916	14169X	PARTICIPANT	\N	PRESENT	0
402922	402916	08060W	PARTICIPANT	\N	PRESENT	0
402946	402945	14257W	PARTICIPANT	\N	PRESENT	0
402947	402945	01048V	PARTICIPANT	\N	PRESENT	0
402948	402945	19533U	PARTICIPANT	\N	PRESENT	0
402949	402945	19599P	PARTICIPANT	\N	PRESENT	0
402950	402945	19679N	PARTICIPANT	\N	PRESENT	0
402951	402945	14038Y	PARTICIPANT	\N	PRESENT	0
402952	402945	19593H	PARTICIPANT	\N	PRESENT	0
402954	402953	14257W	PARTICIPANT	\N	PRESENT	0
402955	402953	01048V	PARTICIPANT	\N	PRESENT	0
402956	402953	19593H	PARTICIPANT	\N	PRESENT	0
402957	402953	19611R	PARTICIPANT	\N	PRESENT	0
402958	402953	19533U	PARTICIPANT	\N	PRESENT	0
402959	402953	14229S	PARTICIPANT	\N	PRESENT	0
402960	402953	14093U	PARTICIPANT	\N	PRESENT	0
402961	402953	04070G	PARTICIPANT	\N	PRESENT	0
404334	400175	14151M	PARTICIPANT	\N	PRESENT	0
404335	400175	19758L	PARTICIPANT	\N	PRESENT	0
404336	400175	14157T	PARTICIPANT	\N	PRESENT	0
404337	400175	19447X	PARTICIPANT	\N	PRESENT	0
404338	400175	14255U	PARTICIPANT	\N	PRESENT	0
404339	400175	19387D	PARTICIPANT	\N	PRESENT	0
404340	400175	14241N	PARTICIPANT	\N	PRESENT	0
404341	400175	14219Q	PARTICIPANT	\N	PRESENT	0
404342	400175	19693L	PARTICIPANT	\N	PRESENT	0
404343	400175	97011G	PARTICIPANT	\N	PRESENT	0
404344	400175	17589D	PARTICIPANT	\N	PRESENT	0
404345	400175	11104D	PARTICIPANT	\N	PRESENT	0
404346	400175	08028W	PARTICIPANT	\N	PRESENT	0
404347	400175	19467C	PARTICIPANT	\N	PRESENT	0
404348	400175	01024M	PARTICIPANT	\N	PRESENT	0
404349	400175	14053L	PARTICIPANT	\N	PRESENT	0
404350	400175	95030B	PARTICIPANT	\N	PRESENT	0
404351	400175	19593H	PARTICIPANT	\N	PRESENT	0
404352	400175	14031R	PARTICIPANT	\N	PRESENT	0
404353	400175	14121F	PARTICIPANT	\N	PRESENT	0
404354	400175	04057K	PARTICIPANT	\N	PRESENT	0
404355	400175	19741B	PARTICIPANT	\N	PRESENT	0
404356	400175	19739H	PARTICIPANT	\N	PRESENT	0
404357	400175	19421M	PARTICIPANT	\N	PRESENT	0
404358	400175	08047A	PARTICIPANT	\N	PRESENT	0
404359	400175	88008L	PARTICIPANT	\N	PRESENT	0
404408	400177	19758L	PARTICIPANT	\N	PRESENT	0
404409	400177	19593H	PARTICIPANT	\N	PRESENT	0
404410	400177	19695N	PARTICIPANT	\N	PRESENT	0
404411	400177	19782L	PARTICIPANT	\N	PRESENT	0
404412	400177	19269X	PARTICIPANT	\N	PRESENT	0
404413	400177	88008L	PARTICIPANT	\N	PRESENT	0
404414	400177	04057K	PARTICIPANT	\N	PRESENT	0
404415	400177	19585H	PARTICIPANT	\N	PRESENT	0
404416	400177	19369B	PARTICIPANT	\N	PRESENT	0
404417	400177	19441R	PARTICIPANT	\N	PRESENT	0
404418	400177	19739H	PARTICIPANT	\N	PRESENT	0
404419	400177	14219Q	PARTICIPANT	\N	PRESENT	0
404420	400177	19699S	PARTICIPANT	\N	PRESENT	0
404421	400177	01024M	PARTICIPANT	\N	PRESENT	0
404422	400177	19631V	PARTICIPANT	\N	PRESENT	0
404423	400177	04018C	PARTICIPANT	\N	PRESENT	0
404424	400177	19533U	PARTICIPANT	\N	PRESENT	0
404425	400177	04049K	PARTICIPANT	\N	PRESENT	0
404426	400177	95030B	PARTICIPANT	\N	PRESENT	0
404427	400177	14147R	PARTICIPANT	\N	PRESENT	0
404428	400177	08047A	PARTICIPANT	\N	PRESENT	0
404429	400177	14041T	PARTICIPANT	\N	PRESENT	0
404430	400177	19467C	PARTICIPANT	\N	PRESENT	0
404431	400177	18083K	PARTICIPANT	\N	PRESENT	0
404432	400177	14119M	PARTICIPANT	\N	PRESENT	0
404433	400177	14169X	PARTICIPANT	\N	PRESENT	0
404434	400177	14031R	PARTICIPANT	\N	PRESENT	0
404435	400177	01057W	PARTICIPANT	\N	PRESENT	0
404436	400177	19447X	PARTICIPANT	\N	PRESENT	0
404437	400177	14038Y	PARTICIPANT	\N	PRESENT	0
404438	400177	99004R	PARTICIPANT	\N	PRESENT	0
404439	400177	08039A	PARTICIPANT	\N	PRESENT	0
404440	400177	11012A	PARTICIPANT	\N	PRESENT	0
404441	400177	14121F	PARTICIPANT	\N	PRESENT	0
404442	400177	14053L	PARTICIPANT	\N	PRESENT	0
404443	400177	19629C	PARTICIPANT	\N	PRESENT	0
404444	400177	14241N	PARTICIPANT	\N	PRESENT	0
404445	400177	19583F	PARTICIPANT	\N	PRESENT	0
404446	400177	14251Q	PARTICIPANT	\N	PRESENT	0
404447	400177	19335Q	PARTICIPANT	\N	PRESENT	0
404448	400177	14267Y	PARTICIPANT	\N	PRESENT	0
404449	400177	14071N	PARTICIPANT	\N	PRESENT	0
404450	400177	19693L	PARTICIPANT	\N	PRESENT	0
404451	400177	97011G	PARTICIPANT	\N	PRESENT	0
404452	400177	14231L	PARTICIPANT	\N	PRESENT	0
404453	400177	19737F	PARTICIPANT	\N	PRESENT	0
404406	400177	04059M	PARTICIPANT	\N	PRESENT	0
404407	400177	14073Q	PARTICIPANT	\N	PRESENT	0
404454	400177	01028R	PARTICIPANT	\N	PRESENT	0
404455	400177	19387D	PARTICIPANT	\N	PRESENT	0
404456	400177	14213J	PARTICIPANT	\N	PRESENT	0
404457	400177	04070G	PARTICIPANT	\N	PRESENT	0
404458	400177	19647E	PARTICIPANT	\N	PRESENT	0
404459	400177	11072N	PARTICIPANT	\N	PRESENT	0
404460	400177	19747H	PARTICIPANT	\N	PRESENT	0
404461	400177	19762G	PARTICIPANT	\N	PRESENT	0
404462	400177	14259Y	PARTICIPANT	\N	PRESENT	0
404463	400177	08010L	PARTICIPANT	\N	PRESENT	0
404464	400177	11085T	PARTICIPANT	\N	PRESENT	0
404465	400177	14030Q	PARTICIPANT	\N	PRESENT	0
404466	400177	14026U	PARTICIPANT	\N	PRESENT	0
411749	409432	19685L	PARTICIPANT	\N	PRESENT	0
411750	409432	19681G	PARTICIPANT	\N	PRESENT	0
411753	410097	11064N	PARTICIPANT	\N	PRESENT	0
411755	409431	11067R	PARTICIPANT	\N	PRESENT	0
411756	409431	14026U	PARTICIPANT	\N	PRESENT	0
411766	409431	19527W	PARTICIPANT	\N	PRESENT	0
411779	410914	01060R	PARTICIPANT	\N	PRESENT	0
411780	410914	04047H	PARTICIPANT	\N	PRESENT	0
411781	410914	01028R	PARTICIPANT	\N	PRESENT	0
411782	409988	19333N	PARTICIPANT	\N	PRESENT	0
411783	409988	17583W	PARTICIPANT	\N	PRESENT	0
411784	409988	19794Q	PARTICIPANT	\N	PRESENT	0
411785	409988	19820Y	PARTICIPANT	\N	PRESENT	0
411786	409988	19826F	PARTICIPANT	\N	PRESENT	0
411787	409988	19347U	PARTICIPANT	\N	PRESENT	0
411788	409988	14157T	PARTICIPANT	\N	PRESENT	0
411789	409988	14038Y	PARTICIPANT	\N	PRESENT	0
411790	409988	14065Q	PARTICIPANT	\N	PRESENT	0
411791	409988	08055A	PARTICIPANT	\N	PRESENT	0
411792	409988	14191V	PARTICIPANT	\N	PRESENT	0
411793	409988	19383Y	PARTICIPANT	\N	PRESENT	0
411794	409988	19387D	PARTICIPANT	\N	PRESENT	0
411795	409988	14219Q	PARTICIPANT	\N	PRESENT	0
411796	409988	14221J	PARTICIPANT	\N	PRESENT	0
411797	409988	19599P	PARTICIPANT	\N	PRESENT	0
411798	409988	18083K	PARTICIPANT	\N	PRESENT	0
411799	409988	14237S	PARTICIPANT	\N	PRESENT	0
411800	409988	05012A	PARTICIPANT	\N	PRESENT	0
411801	409988	19503N	PARTICIPANT	\N	PRESENT	0
411802	409988	08024S	PARTICIPANT	\N	PRESENT	0
411803	409988	14031R	PARTICIPANT	\N	PRESENT	0
411804	409988	19713W	PARTICIPANT	\N	PRESENT	0
411805	409988	14169X	PARTICIPANT	\N	PRESENT	0
411806	409988	15447F	PARTICIPANT	\N	PRESENT	0
411807	409988	08009T	PARTICIPANT	\N	PRESENT	0
411808	409988	19737F	PARTICIPANT	\N	PRESENT	0
411809	409988	19739H	PARTICIPANT	\N	PRESENT	0
411810	409988	19745F	PARTICIPANT	\N	PRESENT	0
411811	409988	99004R	PARTICIPANT	\N	EXCUSE	0
411812	411209	14073Q	PARTICIPANT	\N	PRESENT	0
411813	410102	19443T	PARTICIPANT	\N	PRESENT	0
411814	410102	12041X	PARTICIPANT	\N	PRESENT	0
411859	411209	14109K	PARTICIPANT	\N	PRESENT	0
411864	409432	11065P	PARTICIPANT	\N	PRESENT	0
411817	410102	04034C	PARTICIPANT	\N	PRESENT	0
411818	410102	14079W	PARTICIPANT	\N	PRESENT	0
411819	410102	01058X	PARTICIPANT	\N	PRESENT	0
411820	410102	04040A	PARTICIPANT	\N	PRESENT	0
411821	410102	16685X	PARTICIPANT	\N	PRESENT	0
411860	411209	19749K	PARTICIPANT	\N	PRESENT	0
411823	410102	04042C	PRESIDENT	0	PRESENT	0
411824	410102	11054L	PARTICIPANT	\N	PRESENT	0
411825	410102	11066Q	PARTICIPANT	\N	PRESENT	0
411861	409988	07029T	PARTICIPANT	\N	EXCUSE	0
411827	410102	08056B	PARTICIPANT	\N	PRESENT	0
411863	411209	19335Q	PARTICIPANT	\N	PRESENT	0
411829	410102	95037J	PARTICIPANT	\N	PRESENT	0
411865	409988	11065P	PARTICIPANT	\N	PRESENT	0
411831	410102	19421M	PARTICIPANT	\N	PRESENT	0
411832	410102	19709B	PARTICIPANT	\N	PRESENT	0
411866	409432	19333N	PARTICIPANT	\N	PRESENT	0
411834	410102	14193X	PARTICIPANT	\N	PRESENT	0
411835	410102	97011G	PARTICIPANT	\N	PRESENT	0
411836	410102	08047A	PARTICIPANT	\N	PRESENT	0
411837	410102	98029W	PARTICIPANT	\N	PRESENT	0
411867	409432	08011M	PARTICIPANT	\N	PRESENT	0
411839	410102	04035D	PARTICIPANT	\N	PRESENT	0
411840	410102	14133K	PRESIDENT	1	PRESENT	0
411841	410102	01062T	PARTICIPANT	\N	PRESENT	0
411842	410102	11041F	PARTICIPANT	\N	PRESENT	0
411843	410102	14235Q	PARTICIPANT	\N	PRESENT	0
411844	410102	08058D	PARTICIPANT	\N	PRESENT	0
411845	410102	19251M	PARTICIPANT	\N	PRESENT	0
411868	409988	08011M	PARTICIPANT	\N	PRESENT	0
411847	410102	19721W	PARTICIPANT	\N	PRESENT	0
411869	409988	19689Q	PARTICIPANT	\N	PRESENT	0
411849	410102	14105F	PARTICIPANT	\N	PRESENT	0
411850	410102	98022P	PARTICIPANT	\N	PRESENT	0
411851	410102	14267Y	PARTICIPANT	\N	PRESENT	0
411852	410102	11064N	PARTICIPANT	\N	PRESENT	0
411870	409432	19689Q	PARTICIPANT	\N	PRESENT	0
411854	410102	19583F	PARTICIPANT	\N	PRESENT	0
411897	411209	08039A	PARTICIPANT	\N	PRESENT	0
411856	410102	14255U	PARTICIPANT	\N	PRESENT	0
411857	410914	14147R	PARTICIPANT	\N	PRESENT	0
411858	409431	10006L	PARTICIPANT	\N	PRESENT	0
411898	411209	19758L	PARTICIPANT	\N	PRESENT	0
411899	410102	14097Y	PARTICIPANT	\N	PRESENT	0
411900	410102	14028W	PARTICIPANT	\N	PRESENT	0
411901	410102	14211G	PARTICIPANT	\N	PRESENT	0
411902	410102	11080N	PARTICIPANT	\N	PRESENT	0
411903	410102	95030B	PARTICIPANT	\N	PRESENT	0
415547	406854	19447X	PARTICIPANT	\N	PRESENT	0
415548	406854	04034C	PARTICIPANT	\N	PRESENT	0
415549	406854	95067Q	PARTICIPANT	\N	PRESENT	0
415550	406854	14135M	PARTICIPANT	\N	PRESENT	0
415551	411907	19447X	PARTICIPANT	\N	PRESENT	0
415552	406854	14249W	PARTICIPANT	\N	PRESENT	0
415553	406854	19551W	PARTICIPANT	\N	PRESENT	0
415556	406854	14089Y	PARTICIPANT	\N	PRESENT	0
415562	406854	08020N	PARTICIPANT	\N	PRESENT	0
415563	406854	14033T	PARTICIPANT	\N	PRESENT	0
415564	406854	08073C	PARTICIPANT	\N	PRESENT	0
415867	406855	14034U	PARTICIPANT	\N	PRESENT	0
415870	406855	19758L	PARTICIPANT	\N	PRESENT	0
415928	406855	14199E	PARTICIPANT	\N	PRESENT	0
415872	406855	19651A	PARTICIPANT	\N	PRESENT	0
415873	406855	19349W	PARTICIPANT	\N	PRESENT	0
415875	406855	14207L	PARTICIPANT	\N	PRESENT	0
415876	406855	14107H	PARTICIPANT	\N	PRESENT	0
415877	406855	02002K	PARTICIPANT	\N	PRESENT	0
415878	406855	14121F	PARTICIPANT	\N	PRESENT	0
415879	406855	19479G	PARTICIPANT	\N	PRESENT	0
415880	406855	19569H	PARTICIPANT	\N	PRESENT	0
415881	406855	19735D	PARTICIPANT	\N	PRESENT	0
415882	406855	07004J	PARTICIPANT	\N	PRESENT	0
415883	406855	14275Y	PARTICIPANT	\N	PRESENT	0
415884	406855	07029T	PARTICIPANT	\N	PRESENT	0
415885	406855	14265W	PARTICIPANT	\N	PRESENT	0
415886	406855	14217N	PARTICIPANT	\N	PRESENT	0
415887	406855	01060R	PARTICIPANT	\N	PRESENT	0
415929	406855	11109J	PARTICIPANT	\N	PRESENT	0
415889	406855	14249W	PARTICIPANT	\N	PRESENT	0
415890	406855	14069U	PARTICIPANT	\N	PRESENT	0
415891	406855	19533U	PARTICIPANT	\N	PRESENT	0
415893	406855	14059S	PARTICIPANT	\N	PRESENT	0
415896	406855	19415P	PARTICIPANT	\N	PRESENT	0
415897	406855	19794Q	PARTICIPANT	\N	PRESENT	0
415898	406855	19515S	PARTICIPANT	\N	PRESENT	0
415899	406855	19565D	PARTICIPANT	\N	PRESENT	0
415900	406855	19760E	PARTICIPANT	\N	PRESENT	0
415901	406855	11104D	PARTICIPANT	\N	PRESENT	0
415902	406855	08043V	PARTICIPANT	\N	PRESENT	0
415903	406855	19333N	PARTICIPANT	\N	PRESENT	0
415904	406855	08056B	PARTICIPANT	\N	PRESENT	0
415905	406855	14267Y	PARTICIPANT	\N	PRESENT	0
415906	406855	08034U	PARTICIPANT	\N	PRESENT	0
415907	406855	14081Q	PARTICIPANT	\N	PRESENT	0
415909	406855	19747H	PARTICIPANT	\N	PRESENT	0
415910	406855	11083R	PARTICIPANT	\N	PRESENT	0
415933	406855	14179A	PARTICIPANT	\N	PRESENT	0
415912	406855	08039A	PARTICIPANT	\N	PRESENT	0
415913	406855	19599P	PARTICIPANT	\N	PRESENT	0
415916	406855	04070G	PARTICIPANT	\N	PRESENT	0
415917	406855	08020N	PARTICIPANT	\N	PRESENT	0
415918	406855	19657G	PARTICIPANT	\N	PRESENT	0
415919	406855	14073Q	PARTICIPANT	\N	PRESENT	0
415920	406855	19335Q	PARTICIPANT	\N	PRESENT	0
415921	406855	14241N	PARTICIPANT	\N	PRESENT	0
415923	406855	19693L	PARTICIPANT	\N	PRESENT	0
415925	406855	14211G	PARTICIPANT	\N	PRESENT	0
415942	406855	98050T	PARTICIPANT	\N	PRESENT	0
415930	415924	11026G	PARTICIPANT	\N	PRESENT	0
415931	415895	11026G	PARTICIPANT	\N	PRESENT	0
415932	412265	19565D	PARTICIPANT	\N	EXCUSE	0
415934	415892	11026G	PARTICIPANT	\N	PRESENT	0
415935	406855	14229S	PARTICIPANT	\N	PRESENT	0
415936	406855	19387D	PARTICIPANT	\N	PRESENT	0
415939	406855	19585H	PARTICIPANT	\N	PRESENT	0
415940	406855	04057K	PARTICIPANT	\N	PRESENT	0
415941	406855	19295A	PARTICIPANT	\N	PRESENT	0
415943	406855	08068F	PARTICIPANT	\N	PRESENT	0
415944	406855	08045X	PARTICIPANT	\N	PRESENT	0
415945	406855	04088S	PARTICIPANT	\N	PRESENT	0
415946	406855	01024M	PARTICIPANT	\N	PRESENT	0
415947	406855	19399H	PARTICIPANT	\N	PRESENT	0
415948	406855	08014Q	PARTICIPANT	\N	PRESENT	0
415949	406855	14135M	PARTICIPANT	\N	PRESENT	0
415950	406855	19467C	PARTICIPANT	\N	PRESENT	0
392745	378005	08052W	PARTICIPANT	\N	PRESENT	0
392746	378005	18083K	PARTICIPANT	\N	PRESENT	0
392747	378005	08031R	PARTICIPANT	\N	PRESENT	0
392748	378005	88008L	PARTICIPANT	\N	PRESENT	0
392749	378005	14331P	PARTICIPANT	\N	PRESENT	0
392750	378005	04085P	PARTICIPANT	\N	PRESENT	0
392751	378005	11031D	PARTICIPANT	\N	PRESENT	0
392752	378005	19531S	PARTICIPANT	\N	PRESENT	0
392753	378005	14030Q	PARTICIPANT	\N	PRESENT	0
392754	378005	19782L	PARTICIPANT	\N	PRESENT	0
392822	378006	05008E	PARTICIPANT	\N	PRESENT	0
392823	378006	14151M	PARTICIPANT	\N	PRESENT	0
392824	378006	19413M	PARTICIPANT	\N	PRESENT	0
392825	378006	19503N	PARTICIPANT	\N	PRESENT	0
392826	378006	14001X	PARTICIPANT	\N	PRESENT	0
392827	378006	14030Q	PARTICIPANT	\N	PRESENT	0
392828	378006	19749K	PARTICIPANT	\N	PRESENT	0
392829	378006	14083S	PARTICIPANT	\N	PRESENT	0
392830	378006	18083K	PARTICIPANT	\N	PRESENT	0
392831	378006	08045X	PARTICIPANT	\N	PRESENT	0
392832	378006	19585H	PARTICIPANT	\N	PRESENT	0
392833	378006	19715Y	PARTICIPANT	\N	PRESENT	0
392834	378006	11072N	PARTICIPANT	\N	PRESENT	0
392835	378006	08031R	PARTICIPANT	\N	PRESENT	0
392836	378006	14207L	PARTICIPANT	\N	PRESENT	0
392837	378006	19782L	PARTICIPANT	\N	PRESENT	0
392838	378006	19575F	PARTICIPANT	\N	PRESENT	0
392839	378006	19565D	PARTICIPANT	\N	PRESENT	0
392840	378006	14235Q	PARTICIPANT	\N	PRESENT	0
392841	378006	19621T	PARTICIPANT	\N	PRESENT	0
392842	378006	14069U	PARTICIPANT	\N	PRESENT	0
392843	378006	95030B	PARTICIPANT	\N	PRESENT	0
392844	378006	19737F	PARTICIPANT	\N	PRESENT	0
392845	378006	14179A	PARTICIPANT	\N	PRESENT	0
392846	378006	19629C	PARTICIPANT	\N	PRESENT	0
392847	378006	14053L	PARTICIPANT	\N	PRESENT	0
392848	378006	19543W	PARTICIPANT	\N	PRESENT	0
392849	378006	19467C	PARTICIPANT	\N	PRESENT	0
392850	378006	08020N	PARTICIPANT	\N	PRESENT	0
392851	378006	14107H	PARTICIPANT	\N	PRESENT	0
392852	378006	11031D	PARTICIPANT	\N	PRESENT	0
392853	378006	14251Q	PARTICIPANT	\N	PRESENT	0
392854	378006	19703U	PARTICIPANT	\N	PRESENT	0
392855	378006	14213J	PARTICIPANT	\N	PRESENT	0
392856	378006	14029X	PARTICIPANT	\N	PRESENT	0
392857	378006	14147R	PARTICIPANT	\N	PRESENT	0
392858	378006	19531S	PARTICIPANT	\N	PRESENT	0
392859	378006	19447X	PARTICIPANT	\N	PRESENT	0
392860	378006	19679N	PARTICIPANT	\N	PRESENT	0
392861	378006	19479G	PARTICIPANT	\N	PRESENT	0
392862	378006	14231L	PARTICIPANT	\N	PRESENT	0
392863	378006	04085P	PARTICIPANT	\N	PRESENT	0
392864	378006	11056N	PARTICIPANT	\N	PRESENT	0
392865	378006	14249W	PARTICIPANT	\N	PRESENT	0
392866	378006	14073Q	PARTICIPANT	\N	PRESENT	0
392867	378006	14275Y	PARTICIPANT	\N	PRESENT	0
392868	378006	14219Q	PARTICIPANT	\N	PRESENT	0
392869	378006	04049K	PARTICIPANT	\N	PRESENT	0
392870	378006	14187A	PARTICIPANT	\N	PRESENT	0
392871	378006	08015R	PARTICIPANT	\N	PRESENT	0
392872	378006	14033T	PARTICIPANT	\N	PRESENT	0
392873	378006	14217N	PARTICIPANT	\N	PRESENT	0
392874	378006	04088S	PARTICIPANT	\N	PRESENT	0
392875	378006	14331P	PARTICIPANT	\N	PRESENT	0
392876	378006	11097X	PARTICIPANT	\N	PRESENT	0
392877	378006	14265W	PARTICIPANT	\N	PRESENT	0
392878	378006	19741B	PARTICIPANT	\N	PRESENT	0
392883	378006	19747H	PARTICIPANT	\N	PRESENT	0
392884	378006	04045F	PARTICIPANT	\N	PRESENT	0
392885	378006	14357A	PARTICIPANT	\N	PRESENT	0
392886	378006	19383Y	PARTICIPANT	\N	PRESENT	0
392887	378006	19507S	PARTICIPANT	\N	PRESENT	0
392888	378006	14034U	PARTICIPANT	\N	PRESENT	0
392889	378006	11012A	PARTICIPANT	\N	PRESENT	0
392820	378006	11070L	PARTICIPANT	\N	PRESENT	0
392821	378006	14215L	PARTICIPANT	\N	PRESENT	0
392890	378006	14089Y	PARTICIPANT	\N	PRESENT	0
392891	378006	14197C	PARTICIPANT	\N	PRESENT	0
392892	378006	11064N	PARTICIPANT	\N	PRESENT	0
394497	394081	11083R	PARTICIPANT	\N	EXCUSE	0
394498	394081	14038Y	PARTICIPANT	\N	EXCUSE	0
396320	378091	14001X	PARTICIPANT	\N	PRESENT	0
396321	378091	19543W	PARTICIPANT	\N	PRESENT	0
396322	378091	19719D	PARTICIPANT	\N	PRESENT	0
396323	378091	14219Q	PARTICIPANT	\N	PRESENT	0
396324	378091	14109K	PARTICIPANT	\N	PRESENT	0
396325	378091	11026G	PARTICIPANT	\N	PRESENT	0
396326	378091	14071N	PARTICIPANT	\N	PRESENT	0
396327	378091	14223L	PARTICIPANT	\N	PRESENT	0
396328	378091	14119M	PARTICIPANT	\N	PRESENT	0
396329	378091	19695N	PARTICIPANT	\N	PRESENT	0
396330	378091	14179A	PARTICIPANT	\N	PRESENT	0
396331	378091	14215L	PARTICIPANT	\N	PRESENT	0
396332	378091	14235Q	PARTICIPANT	\N	PRESENT	0
396333	378091	17589D	PARTICIPANT	\N	PRESENT	0
396334	378091	08056B	PARTICIPANT	\N	PRESENT	0
396335	378091	19507S	PARTICIPANT	\N	PRESENT	0
396336	378091	19295A	PARTICIPANT	\N	PRESENT	0
396337	378091	19591F	PARTICIPANT	\N	PRESENT	0
396338	378091	01024M	PARTICIPANT	\N	PRESENT	0
396339	378091	11070L	PARTICIPANT	\N	PRESENT	0
396340	378091	19467C	PARTICIPANT	\N	PRESENT	0
396341	378091	19701S	PARTICIPANT	\N	PRESENT	0
396342	378091	14217N	PARTICIPANT	\N	PRESENT	0
396343	378091	01028R	PARTICIPANT	\N	PRESENT	0
396344	378091	19733B	PARTICIPANT	\N	PRESENT	0
396345	378091	19533U	PARTICIPANT	\N	PRESENT	0
396346	378091	14197C	PARTICIPANT	\N	PRESENT	0
396347	378091	19413M	PARTICIPANT	\N	PRESENT	0
396348	378091	14241N	PARTICIPANT	\N	PRESENT	0
396349	378091	19745F	PARTICIPANT	\N	PRESENT	0
396350	378091	19383Y	PARTICIPANT	\N	PRESENT	0
396351	378091	19611R	PARTICIPANT	\N	PRESENT	0
396352	378091	19794Q	PARTICIPANT	\N	PRESENT	0
396353	378091	17583W	PARTICIPANT	\N	PRESENT	0
396354	378091	14069U	PARTICIPANT	\N	PRESENT	0
396355	378091	14207L	PARTICIPANT	\N	PRESENT	0
396356	378091	19443T	PARTICIPANT	\N	PRESENT	0
396357	378091	04040A	PARTICIPANT	\N	PRESENT	0
396358	378091	19727D	PARTICIPANT	\N	PRESENT	0
396359	378091	14173T	PARTICIPANT	\N	PRESENT	0
396360	378091	04044E	PARTICIPANT	\N	PRESENT	0
396361	378091	05008E	PARTICIPANT	\N	PRESENT	0
396362	378091	08024S	PARTICIPANT	\N	PRESENT	0
396363	378091	19711U	PARTICIPANT	\N	PRESENT	0
396364	378091	14063N	PARTICIPANT	\N	PRESENT	0
396365	378091	14030Q	PARTICIPANT	\N	PRESENT	0
396366	378091	14157T	PARTICIPANT	\N	PRESENT	0
396367	378091	19415P	PARTICIPANT	\N	PRESENT	0
396368	378091	19573D	PARTICIPANT	\N	PRESENT	0
396369	378091	14115H	PARTICIPANT	\N	PRESENT	0
396370	378091	19565D	PARTICIPANT	\N	PRESENT	0
396371	378091	11031D	PARTICIPANT	\N	PRESENT	0
396372	378091	14041T	PARTICIPANT	\N	PRESENT	0
396373	378091	04088S	PARTICIPANT	\N	PRESENT	0
396374	378091	08055A	PARTICIPANT	\N	PRESENT	0
396375	378091	88008L	PARTICIPANT	\N	PRESENT	0
396376	378091	19762G	PARTICIPANT	\N	PRESENT	0
396377	378091	98050T	PARTICIPANT	\N	PRESENT	0
396378	378091	19739H	PARTICIPANT	\N	PRESENT	0
396379	378091	11067R	PARTICIPANT	\N	PRESENT	0
396380	378091	19511N	PARTICIPANT	\N	PRESENT	0
396381	378091	19253P	PARTICIPANT	\N	PRESENT	0
396382	378091	14199E	PARTICIPANT	\N	PRESENT	0
396383	378091	08045X	PARTICIPANT	\N	PRESENT	0
396384	378091	95030B	PARTICIPANT	\N	PRESENT	0
396385	378091	08010L	PARTICIPANT	\N	PRESENT	0
396386	378091	19563B	PARTICIPANT	\N	PRESENT	0
396387	378091	11104D	PARTICIPANT	\N	PRESENT	0
396388	378091	19768N	PARTICIPANT	\N	PRESENT	0
396389	378091	14085U	PARTICIPANT	\N	PRESENT	0
396390	378091	99004R	PARTICIPANT	\N	PRESENT	0
396391	378091	11045K	PARTICIPANT	\N	PRESENT	0
396392	378091	11010L	PARTICIPANT	\N	PRESENT	0
396393	378091	14073Q	PARTICIPANT	\N	PRESENT	0
396394	378091	19699S	PARTICIPANT	\N	PRESENT	0
396395	378091	19581D	PARTICIPANT	\N	PRESENT	0
396396	378091	19367Y	PARTICIPANT	\N	PRESENT	0
396397	378091	19697Q	PARTICIPANT	\N	PRESENT	0
396398	378091	19782L	PARTICIPANT	\N	PRESENT	0
396399	378091	14081Q	PARTICIPANT	\N	PRESENT	0
396400	378091	11040E	PARTICIPANT	\N	PRESENT	0
396401	378091	01057W	PARTICIPANT	\N	PRESENT	0
396402	378091	19489J	PARTICIPANT	\N	PRESENT	0
396403	378091	14187A	PARTICIPANT	\N	PRESENT	0
396404	378091	01025N	PARTICIPANT	\N	PRESENT	0
396405	378091	19689Q	PARTICIPANT	\N	PRESENT	0
396406	378091	08039A	PARTICIPANT	\N	PRESENT	0
413809	413764	04049K	PARTICIPANT	\N	PRESENT	0
413810	413764	04088S	PARTICIPANT	\N	PRESENT	0
413811	413764	08068F	PARTICIPANT	\N	PRESENT	0
413812	413764	04043D	PARTICIPANT	\N	PRESENT	0
413814	413765	08068F	PARTICIPANT	\N	PRESENT	0
413815	413765	04049K	PARTICIPANT	\N	PRESENT	0
413821	413766	08068F	PARTICIPANT	\N	PRESENT	0
413823	413766	04049K	PARTICIPANT	\N	PRESENT	0
413835	413767	08068F	PARTICIPANT	\N	PRESENT	0
413836	413767	04049K	PARTICIPANT	\N	PRESENT	0
413843	413770	04049K	PARTICIPANT	\N	PRESENT	0
414088	406850	11027H	PARTICIPANT	\N	PRESENT	0
414089	406850	19511N	PARTICIPANT	\N	PRESENT	0
414090	414027	19443T	PARTICIPANT	\N	PRESENT	0
414091	414027	12041X	PARTICIPANT	\N	PRESENT	0
414092	414027	04034C	PARTICIPANT	\N	PRESENT	0
414093	414027	01058X	PARTICIPANT	\N	PRESENT	0
414094	414027	16685X	PARTICIPANT	\N	PRESENT	0
414095	414027	08058D	PARTICIPANT	\N	PRESENT	0
414096	414027	04042C	PRESIDENT	0	PRESENT	0
414097	414027	14028W	PARTICIPANT	\N	PRESENT	0
414098	414027	11066Q	PARTICIPANT	\N	PRESENT	0
414099	414027	19721W	PARTICIPANT	\N	PRESENT	0
414100	414027	19319Q	PARTICIPANT	\N	PRESENT	0
414101	414027	14267Y	PARTICIPANT	\N	PRESENT	0
414102	414027	14193X	PARTICIPANT	\N	PRESENT	0
414103	414027	98050T	PARTICIPANT	\N	PRESENT	0
414104	414027	08053X	PARTICIPANT	\N	PRESENT	0
414105	414027	97011G	PARTICIPANT	\N	PRESENT	0
414106	414027	14211G	PARTICIPANT	\N	PRESENT	0
414107	414027	98029W	PARTICIPANT	\N	PRESENT	0
414108	406850	19253P	PARTICIPANT	\N	PRESENT	0
414109	406850	19782L	PARTICIPANT	\N	PRESENT	0
414110	406850	14033T	PARTICIPANT	\N	PRESENT	0
414111	406850	14073Q	PARTICIPANT	\N	PRESENT	0
414112	414027	95067Q	PARTICIPANT	\N	PRESENT	0
414113	414027	14255U	PARTICIPANT	\N	PRESENT	0
414114	406850	14029X	PARTICIPANT	\N	PRESENT	0
414115	414027	04040A	PARTICIPANT	\N	PRESENT	0
414116	414027	19709B	PARTICIPANT	\N	PRESENT	0
414117	406850	19569H	PARTICIPANT	\N	PRESENT	0
414118	414027	14133K	PARTICIPANT	\N	PRESENT	0
414119	406850	19593H	PARTICIPANT	\N	PRESENT	0
414120	406850	11054L	PARTICIPANT	\N	PRESENT	0
414121	414027	08061X	PARTICIPANT	\N	PRESENT	0
414122	414027	04035D	PARTICIPANT	\N	PRESENT	0
414123	414027	98022P	PARTICIPANT	\N	PRESENT	0
414124	406850	14089Y	PARTICIPANT	\N	PRESENT	0
414125	406850	19693L	PARTICIPANT	\N	PRESENT	0
414126	406850	19503N	PARTICIPANT	\N	PRESENT	0
414127	414027	11054L	PARTICIPANT	\N	PRESENT	0
413610	406848	11070L	PARTICIPANT	\N	PRESENT	0
414128	406850	08015R	PARTICIPANT	\N	PRESENT	0
414129	406850	19723Y	PARTICIPANT	\N	PRESENT	0
414130	406850	08045X	PARTICIPANT	\N	PRESENT	0
414131	406850	14187A	PARTICIPANT	\N	PRESENT	0
414132	406850	18083K	PARTICIPANT	\N	PRESENT	0
414133	406850	19507S	PARTICIPANT	\N	PRESENT	0
414134	406850	08031R	PARTICIPANT	\N	PRESENT	0
414135	406850	14135M	PARTICIPANT	\N	PRESENT	0
414136	406850	14115H	PARTICIPANT	\N	PRESENT	0
414137	406850	19301E	PARTICIPANT	\N	PRESENT	0
414138	406850	19762G	PARTICIPANT	\N	PRESENT	0
414139	406850	14179A	PARTICIPANT	\N	PRESENT	0
414140	406850	14123H	PARTICIPANT	\N	PRESENT	0
414141	406850	14053L	PARTICIPANT	\N	PRESENT	0
414142	406850	14327T	PARTICIPANT	\N	PRESENT	0
414143	406850	19383Y	PARTICIPANT	\N	PRESENT	0
414145	406850	14028W	PARTICIPANT	\N	PRESENT	0
414146	406850	11066Q	PARTICIPANT	\N	PRESENT	0
414147	406850	19335Q	PARTICIPANT	\N	PRESENT	0
414148	406850	14217N	PARTICIPANT	\N	PRESENT	0
414152	406850	80013X	PARTICIPANT	\N	PRESENT	0
414153	406850	08009T	PARTICIPANT	\N	PRESENT	0
414154	406850	10006L	PARTICIPANT	\N	PRESENT	0
414155	406850	19669L	PARTICIPANT	\N	PRESENT	0
414156	406850	01028R	PARTICIPANT	\N	PRESENT	0
414157	406850	08052W	PARTICIPANT	\N	PRESENT	0
414158	406850	14069U	PARTICIPANT	\N	PRESENT	0
414159	406850	14213J	PARTICIPANT	\N	PRESENT	0
414160	406850	14119M	PARTICIPANT	\N	PRESENT	0
414171	406851	14259Y	PARTICIPANT	\N	PRESENT	0
414172	406851	11056N	PARTICIPANT	\N	PRESENT	0
414173	406851	19295A	PARTICIPANT	\N	PRESENT	0
414174	406851	19683J	PARTICIPANT	\N	PRESENT	0
414175	406851	19503N	PARTICIPANT	\N	PRESENT	0
414176	406851	14151M	PARTICIPANT	\N	PRESENT	0
414177	406851	19489J	PARTICIPANT	\N	PRESENT	0
414178	406851	05008E	PARTICIPANT	\N	PRESENT	0
414169	406851	04044E	PARTICIPANT	\N	PRESENT	0
414170	412265	01057W	PARTICIPANT	\N	EXCUSE	0
414179	406851	14231L	PARTICIPANT	\N	PRESENT	0
414180	406851	14257W	PARTICIPANT	\N	PRESENT	0
414181	406851	19782L	PARTICIPANT	\N	PRESENT	0
414182	406851	19543W	PARTICIPANT	\N	PRESENT	0
414183	406851	19585H	PARTICIPANT	\N	PRESENT	0
414184	406851	19695N	PARTICIPANT	\N	PRESENT	0
414185	406851	19563B	PARTICIPANT	\N	PRESENT	0
414186	406851	19553Y	PARTICIPANT	\N	PRESENT	0
414187	406851	14219Q	PARTICIPANT	\N	PRESENT	0
414188	406851	19737F	PARTICIPANT	\N	PRESENT	0
414189	406851	01058X	PARTICIPANT	\N	PRESENT	0
414190	406851	14179A	PARTICIPANT	\N	PRESENT	0
414191	406851	88008L	PARTICIPANT	\N	PRESENT	0
414192	406851	19333N	PARTICIPANT	\N	PRESENT	0
414193	406851	87003B	PARTICIPANT	\N	PRESENT	0
414194	406851	14205J	PARTICIPANT	\N	PRESENT	0
414195	406851	14223L	PARTICIPANT	\N	PRESENT	0
414196	406851	14103D	PARTICIPANT	\N	PRESENT	0
414197	406851	08056B	PARTICIPANT	\N	PRESENT	0
414198	406851	01048V	PARTICIPANT	\N	PRESENT	0
414199	406851	19335Q	PARTICIPANT	\N	PRESENT	0
414200	406851	19826F	PARTICIPANT	\N	PRESENT	0
414201	406851	14215L	PARTICIPANT	\N	PRESENT	0
414202	406851	14053L	PARTICIPANT	\N	PRESENT	0
414203	406851	19745F	PARTICIPANT	\N	PRESENT	0
414204	406851	14217N	PARTICIPANT	\N	PRESENT	0
414205	406851	11103C	PARTICIPANT	\N	PRESENT	0
414206	406851	14105F	PARTICIPANT	\N	PRESENT	0
414207	406851	19507S	PARTICIPANT	\N	PRESENT	0
414208	406851	19443T	PARTICIPANT	\N	PRESENT	0
414209	406851	04088S	PARTICIPANT	\N	PRESENT	0
414210	406851	19741B	PARTICIPANT	\N	PRESENT	0
414211	406851	19515S	PARTICIPANT	\N	PRESENT	0
414212	406851	14191V	PARTICIPANT	\N	PRESENT	0
414213	406851	14211G	PARTICIPANT	\N	PRESENT	0
414214	406851	14265W	PARTICIPANT	\N	PRESENT	0
414236	406851	14029X	PARTICIPANT	\N	PRESENT	0
414216	406851	11012A	PARTICIPANT	\N	PRESENT	0
414217	406851	19729F	PARTICIPANT	\N	PRESENT	0
414218	406851	08009T	PARTICIPANT	\N	PRESENT	0
414219	406851	14329V	PARTICIPANT	\N	PRESENT	0
414220	406851	14119M	PARTICIPANT	\N	PRESENT	0
414221	406851	14135M	PARTICIPANT	\N	PRESENT	0
414222	406851	14237S	PARTICIPANT	\N	PRESENT	0
414223	406851	19812Y	PARTICIPANT	\N	PRESENT	0
414224	406851	08055A	PARTICIPANT	\N	PRESENT	0
414225	406851	14033T	PARTICIPANT	\N	PRESENT	0
414226	406851	08024S	PARTICIPANT	\N	PRESENT	0
414227	406851	19629C	PARTICIPANT	\N	PRESENT	0
414228	406851	14207L	PARTICIPANT	\N	PRESENT	0
414229	406851	14063N	PARTICIPANT	\N	PRESENT	0
414230	406851	19739H	PARTICIPANT	\N	PRESENT	0
414231	406851	08069G	PARTICIPANT	\N	PRESENT	0
414232	406851	19701S	PARTICIPANT	\N	PRESENT	0
414233	406851	14157T	PARTICIPANT	\N	PRESENT	0
414234	406851	08028W	PARTICIPANT	\N	PRESENT	0
414235	406851	97011G	PARTICIPANT	\N	PRESENT	0
414237	406851	19441R	PARTICIPANT	\N	PRESENT	0
414238	406851	14187A	PARTICIPANT	\N	PRESENT	0
414239	406851	14147R	PARTICIPANT	\N	PRESENT	0
414240	406851	18083K	PARTICIPANT	\N	PRESENT	0
414241	406851	19467C	PARTICIPANT	\N	PRESENT	0
414242	406851	19762G	PARTICIPANT	\N	PRESENT	0
414243	406851	19581D	PARTICIPANT	\N	PRESENT	0
414244	406851	01025N	PARTICIPANT	\N	PRESENT	0
414245	406851	04040A	PARTICIPANT	\N	PRESENT	0
414246	406851	14081Q	PARTICIPANT	\N	PRESENT	0
414247	406851	19637C	PARTICIPANT	\N	PRESENT	0
414248	406851	19719D	PARTICIPANT	\N	PRESENT	0
414249	406851	19399H	PARTICIPANT	\N	PRESENT	0
414250	406851	08019V	PARTICIPANT	\N	PRESENT	0
414251	406851	14031R	PARTICIPANT	\N	PRESENT	0
414252	406851	19673G	PARTICIPANT	\N	PRESENT	0
414253	406851	08034U	PARTICIPANT	\N	PRESENT	0
414254	406851	14275Y	PARTICIPANT	\N	PRESENT	0
414255	412265	08048B	PARTICIPANT	\N	EXCUSE	0
414256	406851	01060R	PARTICIPANT	\N	PRESENT	0
414257	406851	19573D	PARTICIPANT	\N	PRESENT	0
393827	390967	11053K	PRESIDENT	0	PRESENT	0
393828	390967	14083S	PARTICIPANT	\N	PRESENT	0
393829	390967	19253P	PARTICIPANT	\N	PRESENT	0
393830	390967	14357A	PARTICIPANT	\N	PRESENT	0
393831	390967	08045X	PARTICIPANT	\N	PRESENT	0
393832	390967	14199E	PARTICIPANT	\N	PRESENT	0
393833	390967	15447F	PARTICIPANT	\N	PRESENT	0
393834	390967	19387D	PARTICIPANT	\N	PRESENT	0
393835	390967	19333N	PARTICIPANT	\N	PRESENT	0
393836	390967	04097T	PARTICIPANT	\N	PRESENT	0
393837	390967	11077T	PARTICIPANT	\N	PRESENT	0
393838	390967	14103D	PARTICIPANT	\N	PRESENT	0
393839	390967	19671E	PARTICIPANT	\N	PRESENT	0
393840	390967	19735D	PARTICIPANT	\N	PRESENT	0
393841	390967	14031R	PARTICIPANT	\N	EXCUSE	0
393842	390969	19549D	PARTICIPANT	\N	PRESENT	0
393843	390969	11053K	PRESIDENT	0	PRESENT	0
393844	390969	19253P	PARTICIPANT	\N	PRESENT	0
393845	390969	08045X	PARTICIPANT	\N	PRESENT	0
393846	390969	15447F	PARTICIPANT	\N	PRESENT	0
393847	390969	19387D	PARTICIPANT	\N	PRESENT	0
393848	390969	19333N	PARTICIPANT	\N	PRESENT	0
393849	390969	19729F	PARTICIPANT	\N	PRESENT	0
393850	390969	11077T	PARTICIPANT	\N	PRESENT	0
393851	390969	14031R	PARTICIPANT	\N	PRESENT	0
393852	390969	14237S	PARTICIPANT	\N	PRESENT	0
393853	390969	19349W	PARTICIPANT	\N	PRESENT	0
393854	390969	19669L	PARTICIPANT	\N	PRESENT	0
393855	390969	14357A	PARTICIPANT	\N	EXCUSE	0
393865	393862	14073Q	PARTICIPANT	\N	PRESENT	0
393866	393863	14073Q	PARTICIPANT	\N	PRESENT	0
393867	393864	14073Q	PARTICIPANT	\N	PRESENT	0
393868	393864	11043H	PARTICIPANT	\N	PRESENT	0
393869	393863	11043H	PARTICIPANT	\N	PRESENT	0
393870	393863	08012N	PARTICIPANT	\N	PRESENT	0
393871	393862	11043H	PARTICIPANT	\N	PRESENT	0
393872	393862	08012N	PARTICIPANT	\N	PRESENT	0
395471	392615	19701S	PARTICIPANT	\N	PRESENT	0
395472	392615	19737F	PARTICIPANT	\N	PRESENT	0
395545	395478	19575F	PARTICIPANT	\N	PRESENT	0
395546	395478	19782L	PARTICIPANT	\N	PRESENT	0
395547	395478	01043Q	PARTICIPANT	\N	PRESENT	0
395548	395478	19563B	PRESIDENT	0	PRESENT	0
395549	395478	95067Q	PARTICIPANT	\N	PRESENT	0
395550	395478	04049K	PARTICIPANT	\N	EXCUSE	0
395551	395478	01062T	PARTICIPANT	\N	EXCUSE	0
395555	395479	19782L	PARTICIPANT	\N	PRESENT	0
395556	395479	19599P	PARTICIPANT	\N	PRESENT	0
395557	395479	19695N	PARTICIPANT	\N	PRESENT	0
395558	395479	01043Q	PARTICIPANT	\N	PRESENT	0
395559	395479	14205J	PARTICIPANT	\N	PRESENT	0
395560	395479	19563B	PRESIDENT	0	PRESENT	0
395561	395479	19713W	PARTICIPANT	\N	PRESENT	0
395562	395479	95067Q	PARTICIPANT	\N	PRESENT	0
395563	395479	04049K	PARTICIPANT	\N	EXCUSE	0
395564	395479	01062T	PARTICIPANT	\N	EXCUSE	0
396301	396300	11053K	PARTICIPANT	\N	PRESENT	0
396302	396300	19253P	PARTICIPANT	\N	PRESENT	0
396303	396300	14083S	PARTICIPANT	\N	PRESENT	0
396304	396300	14069U	PARTICIPANT	\N	PRESENT	0
400517	400516	08011M	PARTICIPANT	\N	PRESENT	0
400525	400524	14199E	PARTICIPANT	\N	PRESENT	0
403599	402812	19253P	PARTICIPANT	\N	PRESENT	0
403600	402812	14357A	PARTICIPANT	\N	PRESENT	0
403601	402812	14083S	PARTICIPANT	\N	PRESENT	0
403602	402812	11053K	PARTICIPANT	\N	PRESENT	0
404508	400181	05008E	PARTICIPANT	\N	PRESENT	0
404509	400181	19489J	PARTICIPANT	\N	PRESENT	0
404510	400181	19727D	PARTICIPANT	\N	PRESENT	0
404511	400181	11056N	PARTICIPANT	\N	PRESENT	0
404512	400181	19585H	PARTICIPANT	\N	PRESENT	0
404513	400181	19583F	PARTICIPANT	\N	PRESENT	0
404514	400181	14030Q	PARTICIPANT	\N	PRESENT	0
404515	400181	19737F	PARTICIPANT	\N	PRESENT	0
404516	400181	19369B	PARTICIPANT	\N	PRESENT	0
404517	400181	01024M	PARTICIPANT	\N	PRESENT	0
404518	400181	14121F	PARTICIPANT	\N	PRESENT	0
404519	400181	19629C	PARTICIPANT	\N	PRESENT	0
404520	400181	19387D	PARTICIPANT	\N	PRESENT	0
404521	400181	19631V	PARTICIPANT	\N	PRESENT	0
404522	400181	14069U	PARTICIPANT	\N	PRESENT	0
404523	400181	97011G	PARTICIPANT	\N	PRESENT	0
404524	400181	19533U	PARTICIPANT	\N	PRESENT	0
404525	400181	19693L	PARTICIPANT	\N	PRESENT	0
404526	400181	08047A	PARTICIPANT	\N	PRESENT	0
404527	400181	88008L	PARTICIPANT	\N	PRESENT	0
404528	400181	11012A	PARTICIPANT	\N	PRESENT	0
404529	400181	19447X	PARTICIPANT	\N	PRESENT	0
404530	400181	14038Y	PARTICIPANT	\N	PRESENT	0
404531	400181	18083K	PARTICIPANT	\N	PRESENT	0
404532	400181	14169X	PARTICIPANT	\N	PRESENT	0
404533	400181	14231L	PARTICIPANT	\N	PRESENT	0
404534	400181	14073Q	PARTICIPANT	\N	PRESENT	0
404535	400181	19762G	PARTICIPANT	\N	PRESENT	0
404536	400181	19335Q	PARTICIPANT	\N	PRESENT	0
404537	400181	04018C	PARTICIPANT	\N	PRESENT	0
404538	400181	19747H	PARTICIPANT	\N	PRESENT	0
404539	400181	14215L	PARTICIPANT	\N	PRESENT	0
404540	400181	14249W	PARTICIPANT	\N	PRESENT	0
404541	400181	08009T	PARTICIPANT	\N	PRESENT	0
404542	400181	14219Q	PARTICIPANT	\N	PRESENT	0
404543	400181	08031R	PARTICIPANT	\N	PRESENT	0
404544	400181	19593H	PARTICIPANT	\N	PRESENT	0
404506	400181	04059M	PARTICIPANT	\N	PRESENT	0
404507	400181	14053L	PARTICIPANT	\N	PRESENT	0
404545	400181	01028R	PARTICIPANT	\N	PRESENT	0
404546	400181	19253P	PARTICIPANT	\N	PRESENT	0
404547	400181	19543W	PARTICIPANT	\N	PRESENT	0
404548	400181	14213J	PARTICIPANT	\N	PRESENT	0
404552	400181	14041T	PARTICIPANT	\N	PRESENT	0
404670	404669	10006L	PARTICIPANT	\N	PRESENT	0
404671	404669	08052W	PARTICIPANT	\N	PRESENT	0
404672	404669	19553Y	PARTICIPANT	\N	PRESENT	0
404674	404673	19701S	PARTICIPANT	\N	PRESENT	0
404676	404675	19701S	PARTICIPANT	\N	PRESENT	0
404678	404677	19701S	PARTICIPANT	\N	PRESENT	0
404689	404687	19503N	PARTICIPANT	\N	PRESENT	0
404692	404690	19503N	PARTICIPANT	\N	PRESENT	0
404798	404797	14205J	PARTICIPANT	\N	PRESENT	0
404800	404799	14205J	PARTICIPANT	\N	PRESENT	0
404802	404801	14205J	PARTICIPANT	\N	PRESENT	0
404804	404803	14205J	PARTICIPANT	\N	PRESENT	0
404954	404949	14038Y	PARTICIPANT	\N	PRESENT	0
404955	404949	19333N	PARTICIPANT	\N	PRESENT	0
404956	404949	19701S	PARTICIPANT	\N	PRESENT	0
404957	404949	14031R	PARTICIPANT	\N	PRESENT	0
404958	404949	19549D	PARTICIPANT	\N	PRESENT	0
404959	404949	19387D	PARTICIPANT	\N	PRESENT	0
404960	404949	14219Q	PARTICIPANT	\N	PRESENT	0
404961	404949	14221J	PARTICIPANT	\N	PRESENT	0
404962	404949	14169X	PARTICIPANT	\N	PRESENT	0
404963	404949	19637C	PARTICIPANT	\N	PRESENT	0
404964	404949	02002K	PARTICIPANT	\N	PRESENT	0
404965	404949	18083K	PARTICIPANT	\N	PRESENT	0
404966	404949	08060W	PARTICIPANT	\N	PRESENT	0
404967	404949	19503N	PARTICIPANT	\N	PRESENT	0
404968	404949	19347U	PARTICIPANT	\N	PRESENT	0
404969	404949	04097T	PARTICIPANT	\N	PRESENT	0
404970	404949	19745F	PARTICIPANT	\N	PRESENT	0
404971	404949	08024S	PARTICIPANT	\N	PRESENT	0
404972	404949	17637T	PARTICIPANT	\N	PRESENT	0
404973	404949	11065P	PARTICIPANT	\N	PRESENT	0
404974	404949	19737F	PARTICIPANT	\N	PRESENT	0
404975	404949	14093U	PARTICIPANT	\N	PRESENT	0
404976	404949	11099A	PARTICIPANT	\N	PRESENT	0
404977	404949	08028W	PARTICIPANT	\N	PRESENT	0
404978	404949	19551W	PARTICIPANT	\N	PRESENT	0
405043	405042	14259Y	PARTICIPANT	\N	PRESENT	0
405044	405042	14231L	PARTICIPANT	\N	PRESENT	0
405045	405042	19543W	PARTICIPANT	\N	PRESENT	0
405046	405042	19649G	PARTICIPANT	\N	PRESENT	0
405047	405042	11085T	PARTICIPANT	\N	PRESENT	0
405049	405048	19543W	PARTICIPANT	\N	PRESENT	0
405050	405048	19719D	PARTICIPANT	\N	PRESENT	0
405051	405048	14259Y	PARTICIPANT	\N	PRESENT	0
405052	405048	14231L	PARTICIPANT	\N	PRESENT	0
405053	405048	19649G	PARTICIPANT	\N	PRESENT	0
405054	405048	11085T	PARTICIPANT	\N	PRESENT	0
405055	404987	14221J	PARTICIPANT	\N	PRESENT	0
405057	405056	14259Y	PARTICIPANT	\N	PRESENT	0
405058	405056	14231L	PARTICIPANT	\N	PRESENT	0
405060	405056	19719D	PARTICIPANT	\N	PRESENT	0
405063	404795	19631V	PARTICIPANT	\N	PRESENT	0
405064	404795	14038Y	PARTICIPANT	\N	PRESENT	0
405065	404795	11083R	PARTICIPANT	\N	PRESENT	0
405066	404795	14179A	PARTICIPANT	\N	PRESENT	0
405067	404795	19611R	PARTICIPANT	\N	PRESENT	0
415951	406855	14038Y	PARTICIPANT	\N	PRESENT	0
415952	406855	19643A	PARTICIPANT	\N	PRESENT	0
415953	406855	19749K	PARTICIPANT	\N	PRESENT	0
415954	406855	19745F	PARTICIPANT	\N	PRESENT	0
415957	413464	19479G	PARTICIPANT	\N	PRESENT	0
415958	413464	11048N	PRESIDENT	1	PRESENT	0
415959	413464	19711U	PARTICIPANT	\N	PRESENT	0
415960	413464	01048V	PARTICIPANT	\N	PRESENT	0
415961	413464	11053K	PARTICIPANT	\N	PRESENT	0
415962	413464	14219Q	PARTICIPANT	\N	PRESENT	0
415963	413464	08011M	PARTICIPANT	\N	PRESENT	0
415964	413464	11074Q	PRESIDENT	0	PRESENT	0
415965	413464	14225N	PARTICIPANT	\N	PRESENT	0
415966	413464	18083K	PARTICIPANT	\N	PRESENT	0
415967	413464	07029T	PARTICIPANT	\N	PRESENT	0
415968	413464	08073C	PARTICIPANT	\N	PRESENT	0
415969	413464	14085U	PARTICIPANT	\N	PRESENT	0
415970	413464	19349W	PARTICIPANT	\N	PRESENT	0
415971	413464	14121F	PARTICIPANT	\N	PRESENT	0
415972	413464	99004R	PARTICIPANT	\N	PRESENT	0
415973	406855	14089Y	PARTICIPANT	\N	PRESENT	0
415974	406855	19826F	PARTICIPANT	\N	PRESENT	0
415975	406855	14259Y	PARTICIPANT	\N	PRESENT	0
415976	406855	95030B	PARTICIPANT	\N	PRESENT	0
415977	406855	14193X	PARTICIPANT	\N	PRESENT	0
415978	406855	11064N	PARTICIPANT	\N	PRESENT	0
415979	406855	87003B	PARTICIPANT	\N	PRESENT	0
415980	406855	14147R	PARTICIPANT	\N	PRESENT	0
415981	406855	14071N	PARTICIPANT	\N	PRESENT	0
415982	406855	11012A	PARTICIPANT	\N	PRESENT	0
415983	406855	11067R	PARTICIPANT	\N	PRESENT	0
415984	406855	14231L	PARTICIPANT	\N	PRESENT	0
415985	406855	19703U	PARTICIPANT	\N	PRESENT	0
415986	406855	17583W	PARTICIPANT	\N	PRESENT	0
415988	406855	19768N	PARTICIPANT	\N	PRESENT	0
415989	406855	19551W	PARTICIPANT	\N	PRESENT	0
415990	406855	14151M	PARTICIPANT	\N	PRESENT	0
415991	412265	11101A	PARTICIPANT	\N	PRESENT	0
415992	406855	97011G	PARTICIPANT	\N	PRESENT	0
415993	412265	19525U	PARTICIPANT	\N	PRESENT	0
415994	412265	19253P	PARTICIPANT	\N	PRESENT	0
415995	406855	19443T	PARTICIPANT	\N	PRESENT	0
415996	412265	14231L	PARTICIPANT	\N	PRESENT	0
415997	412265	95067Q	PARTICIPANT	\N	PRESENT	0
415998	412265	08049C	PARTICIPANT	\N	PRESENT	0
416000	412265	14063N	PARTICIPANT	\N	PRESENT	0
416067	406859	14231L	PARTICIPANT	\N	PRESENT	0
416068	406859	19758L	PARTICIPANT	\N	PRESENT	0
416069	406859	05008E	PARTICIPANT	\N	PRESENT	0
416070	406859	19599P	PARTICIPANT	\N	PRESENT	0
416071	406859	14081Q	PARTICIPANT	\N	PRESENT	0
416072	415999	14071N	PARTICIPANT	\N	PRESENT	0
416073	406859	14111D	PARTICIPANT	\N	PRESENT	0
416074	406859	14207L	PARTICIPANT	\N	PRESENT	0
416075	406859	11012A	PARTICIPANT	\N	PRESENT	0
416076	406859	14215L	PARTICIPANT	\N	PRESENT	0
416077	406859	14179A	PARTICIPANT	\N	PRESENT	0
416078	406859	19735D	PARTICIPANT	\N	PRESENT	0
416079	406859	19739H	PARTICIPANT	\N	PRESENT	0
416080	406859	19826F	PARTICIPANT	\N	PRESENT	0
416081	406859	19591F	PARTICIPANT	\N	PRESENT	0
416082	406859	19295A	PARTICIPANT	\N	PRESENT	0
416083	406859	11056N	PARTICIPANT	\N	PRESENT	0
416084	406859	19760E	PARTICIPANT	\N	PRESENT	0
416085	406859	87003B	PARTICIPANT	\N	PRESENT	0
416086	406859	08043V	PARTICIPANT	\N	PRESENT	0
416087	406859	14157T	PARTICIPANT	\N	PRESENT	0
416088	406859	02002K	PARTICIPANT	\N	PRESENT	0
416089	406859	08020N	PARTICIPANT	\N	PRESENT	0
416090	406859	04057K	PARTICIPANT	\N	PRESENT	0
416091	406859	14241N	PARTICIPANT	\N	PRESENT	0
416092	406859	14147R	PARTICIPANT	\N	PRESENT	0
416093	406859	19629C	PARTICIPANT	\N	PRESENT	0
416094	406859	19693L	PARTICIPANT	\N	PRESENT	0
416095	406859	14107H	PARTICIPANT	\N	PRESENT	0
416096	406859	19387D	PARTICIPANT	\N	PRESENT	0
416097	406859	19443T	PARTICIPANT	\N	PRESENT	0
416098	406859	19335Q	PARTICIPANT	\N	PRESENT	0
416099	406859	19749K	PARTICIPANT	\N	PRESENT	0
416100	406859	07029T	PARTICIPANT	\N	PRESENT	0
416101	406859	19745F	PARTICIPANT	\N	PRESENT	0
416102	406859	14135M	PARTICIPANT	\N	PRESENT	0
416103	406859	14071N	PARTICIPANT	\N	PRESENT	0
416104	406859	14053L	PARTICIPANT	\N	PRESENT	0
416105	406859	14151M	PARTICIPANT	\N	PRESENT	0
416106	406859	19768N	PARTICIPANT	\N	PRESENT	0
416107	406859	04088S	PARTICIPANT	\N	PRESENT	0
416108	406859	19794Q	PARTICIPANT	\N	PRESENT	0
416109	406859	14038Y	PARTICIPANT	\N	PRESENT	0
416110	406859	19383Y	PARTICIPANT	\N	PRESENT	0
416111	406859	14059S	PARTICIPANT	\N	PRESENT	0
416112	406859	19399H	PARTICIPANT	\N	PRESENT	0
416113	406859	19515S	PARTICIPANT	\N	PRESENT	0
416114	406859	01024M	PARTICIPANT	\N	PRESENT	0
416115	406859	19543W	PARTICIPANT	\N	PRESENT	0
416116	406859	97011G	PARTICIPANT	\N	PRESENT	0
416117	406859	08009T	PARTICIPANT	\N	PRESENT	0
416118	406859	08068F	PARTICIPANT	\N	PRESENT	0
416119	406859	19489J	PARTICIPANT	\N	PRESENT	0
416120	406859	19565D	PARTICIPANT	\N	PRESENT	0
416121	406859	98005N	PARTICIPANT	\N	PRESENT	0
416122	406859	14089Y	PARTICIPANT	\N	PRESENT	0
416123	406859	14083S	PARTICIPANT	\N	PRESENT	0
416124	406859	08024S	PARTICIPANT	\N	PRESENT	0
416125	406859	08045X	PARTICIPANT	\N	PRESENT	0
416126	406859	19741B	PARTICIPANT	\N	PRESENT	0
416127	406859	19691J	PARTICIPANT	\N	PRESENT	0
416128	406859	04045F	PARTICIPANT	\N	PRESENT	0
416130	406859	19711U	PARTICIPANT	\N	PRESENT	0
416131	406859	19657G	PARTICIPANT	\N	PRESENT	0
416065	406859	14034U	PARTICIPANT	\N	PRESENT	0
416066	406859	14259Y	PARTICIPANT	\N	PRESENT	0
416132	406859	19467C	PARTICIPANT	\N	PRESENT	0
416133	406859	17637T	PARTICIPANT	\N	PRESENT	0
416134	406859	99004R	PARTICIPANT	\N	PRESENT	0
416135	406859	19719D	PARTICIPANT	\N	PRESENT	0
416136	406859	14227Q	PARTICIPANT	\N	PRESENT	0
416137	406859	14219Q	PARTICIPANT	\N	PRESENT	0
416138	406859	19479G	PARTICIPANT	\N	PRESENT	0
416139	406859	19703U	PARTICIPANT	\N	PRESENT	0
416140	406859	19725B	PARTICIPANT	\N	PRESENT	0
416141	406859	14079W	PARTICIPANT	\N	PRESENT	0
416142	406859	19367Y	PARTICIPANT	\N	PRESENT	0
416143	406859	19575F	PARTICIPANT	\N	PRESENT	0
416144	406859	19649G	PARTICIPANT	\N	PRESENT	0
416151	406859	01028R	PARTICIPANT	\N	PRESENT	0
416146	406859	19762G	PARTICIPANT	\N	PRESENT	0
416147	406859	18083K	PARTICIPANT	\N	PRESENT	0
416148	406859	14065Q	PARTICIPANT	\N	PRESENT	0
416149	406859	19533U	PARTICIPANT	\N	PRESENT	0
416150	406859	11099A	PARTICIPANT	\N	PRESENT	0
416152	406859	14061L	PARTICIPANT	\N	PRESENT	0
416153	406859	98050T	PARTICIPANT	\N	PRESENT	0
416154	406859	19415P	PARTICIPANT	\N	PRESENT	0
416155	406859	19573D	PARTICIPANT	\N	PRESENT	0
416156	413464	12016W	PARTICIPANT	\N	PRESENT	0
416157	413464	89017R	PARTICIPANT	\N	PRESENT	0
416158	413464	08010L	PARTICIPANT	\N	PRESENT	0
416159	413464	01057W	PARTICIPANT	\N	EXCUSE	0
416160	413464	14159V	PARTICIPANT	\N	EXCUSE	0
416161	406859	14217N	PARTICIPANT	\N	PRESENT	0
416162	406859	14031R	PARTICIPANT	\N	PRESENT	0
416163	406859	14261S	PARTICIPANT	\N	PRESENT	0
416164	406859	19713W	PARTICIPANT	\N	PRESENT	0
416165	406859	01048V	PARTICIPANT	\N	PRESENT	0
416168	406859	04040A	PARTICIPANT	\N	PRESENT	0
416169	406859	11064N	PARTICIPANT	\N	PRESENT	0
416170	406859	19585H	PARTICIPANT	\N	PRESENT	0
416171	406859	19563B	PARTICIPANT	\N	PRESENT	0
416172	406859	19253P	PARTICIPANT	\N	PRESENT	0
416173	406859	08034U	PARTICIPANT	\N	PRESENT	0
416174	406859	14249W	PARTICIPANT	\N	PRESENT	0
416175	406859	95067Q	PARTICIPANT	\N	PRESENT	0
416176	406859	14069U	PARTICIPANT	\N	PRESENT	0
416177	406859	14329V	PARTICIPANT	\N	PRESENT	0
416178	406859	14026U	PARTICIPANT	\N	PRESENT	0
416179	406859	19503N	PARTICIPANT	\N	PRESENT	0
416180	406859	04085P	PARTICIPANT	\N	PRESENT	0
416181	406859	10015M	PARTICIPANT	\N	PRESENT	0
416182	406859	11077T	PARTICIPANT	\N	PRESENT	0
416183	406859	19651A	PARTICIPANT	\N	PRESENT	0
416184	406859	16685X	PARTICIPANT	\N	PRESENT	0
416185	406859	14073Q	PARTICIPANT	\N	PRESENT	0
416186	406859	14275Y	PARTICIPANT	\N	PRESENT	0
416188	406859	07004J	PARTICIPANT	\N	PRESENT	0
416189	406859	11097X	PARTICIPANT	\N	PRESENT	0
416190	406859	19507S	PARTICIPANT	\N	PRESENT	0
394218	394215	11053K	PARTICIPANT	\N	PRESENT	0
394216	394215	11040E	PARTICIPANT	\N	PRESENT	0
394217	394215	14053L	PARTICIPANT	\N	PRESENT	0
394219	394215	11027H	PARTICIPANT	\N	PRESENT	0
394220	394215	04086Q	PARTICIPANT	\N	PRESENT	0
394221	394215	11070L	PARTICIPANT	\N	PRESENT	0
394222	394215	04089T	PARTICIPANT	\N	PRESENT	0
394223	394215	14034U	PARTICIPANT	\N	PRESENT	0
394224	394215	14231L	PARTICIPANT	\N	PRESENT	0
394225	394215	11064N	PARTICIPANT	\N	PRESENT	0
394226	394215	14081Q	PARTICIPANT	\N	PRESENT	0
394227	394215	14061L	PARTICIPANT	\N	PRESENT	0
394228	394215	14159V	PARTICIPANT	\N	PRESENT	0
394229	394215	86034E	PARTICIPANT	\N	PRESENT	0
394230	394215	11072N	PARTICIPANT	\N	PRESENT	0
394231	394215	05012A	PARTICIPANT	\N	PRESENT	0
394232	394215	04045F	PARTICIPANT	\N	PRESENT	0
394233	394215	04044E	PARTICIPANT	\N	PRESENT	0
396407	378091	14267Y	PARTICIPANT	\N	PRESENT	0
396408	378091	08062Y	PARTICIPANT	\N	PRESENT	0
396409	378091	19760E	PARTICIPANT	\N	PRESENT	0
396410	378091	14133K	PARTICIPANT	\N	PRESENT	0
396411	378091	11027H	PARTICIPANT	\N	PRESENT	0
396412	378091	15447F	PARTICIPANT	\N	PRESENT	0
396413	378091	14105F	PARTICIPANT	\N	PRESENT	0
396414	378091	14265W	PARTICIPANT	\N	PRESENT	0
396415	378091	14061L	PARTICIPANT	\N	PRESENT	0
396416	378091	19731Y	PARTICIPANT	\N	PRESENT	0
396417	378091	19703U	PARTICIPANT	\N	PRESENT	0
396418	378091	19447X	PARTICIPANT	\N	PRESENT	0
396419	378091	14147R	PARTICIPANT	\N	PRESENT	0
396420	378091	14038Y	PARTICIPANT	\N	PRESENT	0
396421	378091	14042U	PARTICIPANT	\N	PRESENT	0
396422	378091	14021P	PARTICIPANT	\N	PRESENT	0
396423	378091	19651A	PARTICIPANT	\N	PRESENT	0
396424	378091	04085P	PARTICIPANT	\N	PRESENT	0
396425	378091	04038G	PARTICIPANT	\N	PRESENT	0
396426	378091	11033F	PARTICIPANT	\N	PRESENT	0
396427	378091	14151M	PARTICIPANT	\N	PRESENT	0
398327	397572	08041T	PARTICIPANT	\N	EXCUSE	0
398328	397572	19565D	PARTICIPANT	\N	EXCUSE	0
398338	397641	14053L	PARTICIPANT	\N	PRESENT	0
398339	397641	14026U	PARTICIPANT	\N	PRESENT	0
398340	397641	19725B	PRESIDENT	0	PRESENT	0
398341	397641	19441R	PRESIDENT	1	PRESENT	0
398342	397641	04057K	PARTICIPANT	\N	PRESENT	0
398343	397641	14071N	PARTICIPANT	\N	PRESENT	0
398344	397641	08015R	PARTICIPANT	\N	PRESENT	0
398345	397641	19747H	PARTICIPANT	\N	PRESENT	0
398362	398361	08015R	PARTICIPANT	\N	PRESENT	0
398363	398361	14225N	PARTICIPANT	\N	PRESENT	0
398364	398361	19735D	PARTICIPANT	\N	PRESENT	0
399446	397570	19703U	PARTICIPANT	\N	PRESENT	0
399447	397570	11067R	PARTICIPANT	\N	PRESENT	0
399448	397570	19798U	PARTICIPANT	\N	PRESENT	0
399449	397570	14281W	PARTICIPANT	\N	PRESENT	0
399450	397570	11103C	PARTICIPANT	\N	PRESENT	0
399451	397570	08052W	PARTICIPANT	\N	PRESENT	0
399452	397570	08048B	PARTICIPANT	\N	PRESENT	0
399453	397570	19367Y	PARTICIPANT	\N	PRESENT	0
399454	397570	14217N	PARTICIPANT	\N	PRESENT	0
399455	397570	14026U	PARTICIPANT	\N	PRESENT	0
399456	397570	98024R	PRESIDENT	0	PRESENT	0
399457	397570	17779H	PARTICIPANT	\N	PRESENT	0
399458	397570	19565D	PARTICIPANT	\N	EXCUSE	0
399459	397570	08041T	PARTICIPANT	\N	EXCUSE	0
399460	397657	04035D	PARTICIPANT	\N	PRESENT	0
399461	397657	19443T	PARTICIPANT	\N	PRESENT	0
399462	397657	12041X	PARTICIPANT	\N	PRESENT	0
399463	397657	14133K	PARTICIPANT	\N	PRESENT	0
399464	397657	04034C	PARTICIPANT	\N	PRESENT	0
399465	397657	11041F	PARTICIPANT	\N	PRESENT	0
399466	397657	14235Q	PARTICIPANT	\N	PRESENT	0
399467	397657	04040A	PARTICIPANT	\N	PRESENT	0
399468	397657	11027H	PARTICIPANT	\N	PRESENT	0
399469	397657	16685X	PARTICIPANT	\N	PRESENT	0
399470	397657	04042C	PRESIDENT	0	PRESENT	0
399471	397657	11066Q	PARTICIPANT	\N	PRESENT	0
399472	397657	08056B	PARTICIPANT	\N	PRESENT	0
399473	397657	14105F	PARTICIPANT	\N	PRESENT	0
399474	397657	98018T	PARTICIPANT	\N	PRESENT	0
399475	397657	98022P	PARTICIPANT	\N	PRESENT	0
399476	397657	14267Y	PARTICIPANT	\N	PRESENT	0
399477	397657	14193X	PARTICIPANT	\N	PRESENT	0
399478	397657	98050T	PARTICIPANT	\N	PRESENT	0
399479	397657	97011G	PARTICIPANT	\N	PRESENT	0
399480	397657	08047A	PARTICIPANT	\N	PRESENT	0
399481	397657	14255U	PARTICIPANT	\N	PRESENT	0
399482	397657	98029W	PARTICIPANT	\N	PRESENT	0
399483	397657	14079W	PARTICIPANT	\N	PRESENT	0
399484	397657	19251M	PARTICIPANT	\N	PRESENT	0
399486	397657	11054L	PARTICIPANT	\N	PRESENT	0
399487	397657	19421M	PARTICIPANT	\N	PRESENT	0
399488	397657	95037J	PARTICIPANT	\N	PRESENT	0
399489	397657	01062T	PARTICIPANT	\N	PRESENT	0
399490	397657	01058X	PARTICIPANT	\N	PRESENT	0
399491	397657	95067Q	PARTICIPANT	\N	PRESENT	0
399762	398303	14237S	PARTICIPANT	\N	PRESENT	0
399763	398303	14157T	PARTICIPANT	\N	PRESENT	0
399764	398303	14169X	PARTICIPANT	\N	PRESENT	0
399772	397995	98035U	PARTICIPANT	\N	PRESENT	0
399773	397995	08045X	PARTICIPANT	\N	PRESENT	0
399774	397995	19253P	PARTICIPANT	\N	PRESENT	0
399775	397995	01024M	PARTICIPANT	\N	PRESENT	0
399776	397995	19543W	PARTICIPANT	\N	PRESENT	0
399777	397995	04047H	PARTICIPANT	\N	PRESENT	0
399778	397995	01028R	PARTICIPANT	\N	PRESENT	0
399779	397995	05008E	PRESIDENT	0	PRESENT	0
399780	397995	19447X	PARTICIPANT	\N	PRESENT	0
399781	397995	19725B	PARTICIPANT	\N	PRESENT	0
399782	397995	19489J	PARTICIPANT	\N	PRESENT	0
399783	397995	14041T	PARTICIPANT	\N	PRESENT	0
399784	397995	14147R	PARTICIPANT	\N	PRESENT	0
399785	397995	14179A	PARTICIPANT	\N	PRESENT	0
399786	397995	19762G	PARTICIPANT	\N	PRESENT	0
399787	397995	11072N	PARTICIPANT	\N	PRESENT	0
399788	397995	14053L	PARTICIPANT	\N	PRESENT	0
399789	397995	10015M	PARTICIPANT	\N	PRESENT	0
399790	397995	14151M	PARTICIPANT	\N	PRESENT	0
399791	397995	14069U	PARTICIPANT	\N	PRESENT	0
399792	397995	19673G	PARTICIPANT	\N	PRESENT	0
399793	397995	19729F	PARTICIPANT	\N	EXCUSE	0
399794	397995	04044E	PARTICIPANT	\N	EXCUSE	0
399795	397995	19585H	PARTICIPANT	\N	EXCUSE	0
399796	398232	14257W	PARTICIPANT	\N	PRESENT	0
400063	393815	01043Q	PARTICIPANT	\N	PRESENT	0
400064	393815	80013X	PARTICIPANT	\N	PRESENT	0
400065	393815	19413M	PARTICIPANT	\N	PRESENT	0
400066	393815	14225N	PARTICIPANT	\N	PRESENT	0
400067	393815	11067R	PARTICIPANT	\N	PRESENT	0
400068	393815	08045X	PARTICIPANT	\N	PRESENT	0
400069	393815	05008E	PARTICIPANT	\N	PRESENT	0
400070	393815	10015M	PARTICIPANT	\N	PRESENT	0
400071	393815	11072N	PARTICIPANT	\N	PRESENT	0
400072	393815	14121F	PARTICIPANT	\N	PRESENT	0
400073	393815	07004J	PARTICIPANT	\N	PRESENT	0
400074	393815	19747H	PARTICIPANT	\N	PRESENT	0
400075	393815	14041T	PARTICIPANT	\N	PRESENT	0
400076	393815	14215L	PARTICIPANT	\N	PRESENT	0
400077	393815	19663E	PARTICIPANT	\N	PRESENT	0
400078	393815	19447X	PARTICIPANT	\N	PRESENT	0
400079	393815	14157T	PARTICIPANT	\N	PRESENT	0
400080	393815	01057W	PARTICIPANT	\N	PRESENT	0
400081	393815	19515S	PARTICIPANT	\N	PRESENT	0
414258	406851	19565D	PARTICIPANT	\N	PRESENT	0
414259	406851	14227Q	PARTICIPANT	\N	PRESENT	0
414260	406851	14111D	PARTICIPANT	\N	PRESENT	0
414261	406851	19479G	PARTICIPANT	\N	PRESENT	0
414262	406851	14327T	PARTICIPANT	\N	PRESENT	0
414263	406851	14115H	PARTICIPANT	\N	PRESENT	0
414264	406851	08038Y	PARTICIPANT	\N	PRESENT	0
414265	406851	19347U	PARTICIPANT	\N	PRESENT	0
414266	406851	19447X	PARTICIPANT	\N	PRESENT	0
414267	406851	08031R	PARTICIPANT	\N	PRESENT	0
414268	406851	19685L	PARTICIPANT	\N	PRESENT	0
414269	406851	05012A	PARTICIPANT	\N	PRESENT	0
414270	406851	19253P	PARTICIPANT	\N	PRESENT	0
414272	414028	19443T	PARTICIPANT	\N	PRESENT	0
414273	414028	95030B	PARTICIPANT	\N	PRESENT	0
414274	414028	04034C	PARTICIPANT	\N	PRESENT	0
414275	414028	04040A	PARTICIPANT	\N	PRESENT	0
414276	414028	14079W	PARTICIPANT	\N	PRESENT	0
414277	414028	16685X	PARTICIPANT	\N	PRESENT	0
414278	414028	04042C	PRESIDENT	0	PRESENT	0
414279	414028	11054L	PARTICIPANT	\N	PRESENT	0
414280	414028	11066Q	PARTICIPANT	\N	PRESENT	0
414281	414028	19669L	PARTICIPANT	\N	PRESENT	0
414282	414028	08056B	PARTICIPANT	\N	PRESENT	0
414283	414028	95037J	PARTICIPANT	\N	PRESENT	0
414284	414028	19709B	PARTICIPANT	\N	PRESENT	0
414285	414028	14193X	PARTICIPANT	\N	PRESENT	0
414286	414028	97011G	PARTICIPANT	\N	PRESENT	0
414287	414028	98029W	PARTICIPANT	\N	PRESENT	0
414288	414028	11041F	PARTICIPANT	\N	PRESENT	0
414289	414028	14235Q	PARTICIPANT	\N	PRESENT	0
414290	414028	08058D	PARTICIPANT	\N	PRESENT	0
414291	414028	14028W	PARTICIPANT	\N	PRESENT	0
414292	414028	19251M	PARTICIPANT	\N	PRESENT	0
414293	414028	19319Q	PARTICIPANT	\N	PRESENT	0
414294	414028	14267Y	PARTICIPANT	\N	PRESENT	0
414295	414028	11064N	PARTICIPANT	\N	PRESENT	0
414296	414028	98050T	PARTICIPANT	\N	PRESENT	0
414297	414028	14255U	PARTICIPANT	\N	PRESENT	0
414298	414028	08061X	PARTICIPANT	\N	PRESENT	0
414299	414028	95067Q	PARTICIPANT	\N	PRESENT	0
414301	406851	19369B	PARTICIPANT	\N	PRESENT	0
414399	406851	14241N	PARTICIPANT	\N	PRESENT	0
414400	406851	14073Q	PARTICIPANT	\N	PRESENT	0
414401	406851	19521Q	PARTICIPANT	\N	PRESENT	0
414402	406851	99004R	PARTICIPANT	\N	PRESENT	0
414403	406851	14267Y	PARTICIPANT	\N	PRESENT	0
414404	406851	14034U	PARTICIPANT	\N	PRESENT	0
414405	406851	17637T	PARTICIPANT	\N	PRESENT	0
414429	414028	08049C	PARTICIPANT	\N	EXCUSE	0
415084	414076	19663E	PARTICIPANT	\N	EXCUSE	0
415085	414076	19511N	PARTICIPANT	\N	EXCUSE	0
415086	414076	19533U	PARTICIPANT	\N	EXCUSE	0
415087	414076	04043D	PARTICIPANT	\N	EXCUSE	0
415088	410795	19511N	PARTICIPANT	\N	PRESENT	0
415226	415225	08017T	PARTICIPANT	\N	PRESENT	0
416555	416552	14219Q	PARTICIPANT	\N	PRESENT	0
416556	416552	08060W	PARTICIPANT	\N	PRESENT	0
416558	416557	08060W	PARTICIPANT	\N	PRESENT	0
416560	416559	08060W	PARTICIPANT	\N	PRESENT	0
416629	415095	96004D	PRESIDENT	0	PRESENT	0
416630	415095	08014Q	PARTICIPANT	\N	PRESENT	0
416631	415095	14357A	PARTICIPANT	\N	PRESENT	0
416632	415095	14079W	PARTICIPANT	\N	PRESENT	0
416633	415095	08018U	PARTICIPANT	\N	PRESENT	0
416634	415095	11083R	PARTICIPANT	\N	PRESENT	0
416635	415095	19725B	PARTICIPANT	\N	PRESENT	0
416636	415095	14241N	PARTICIPANT	\N	PRESENT	0
416637	415095	14073Q	PARTICIPANT	\N	PRESENT	0
416638	415095	04057K	PARTICIPANT	\N	PRESENT	0
416639	415095	19563B	PARTICIPANT	\N	PRESENT	0
416640	415095	14135M	PARTICIPANT	\N	PRESENT	0
416641	415095	14331P	PARTICIPANT	\N	PRESENT	0
416642	415095	10015M	PARTICIPANT	\N	PRESENT	0
416643	415095	98035U	PARTICIPANT	\N	PRESENT	0
416649	415095	14065Q	PARTICIPANT	\N	EXCUSE	0
416650	415095	14225N	PARTICIPANT	\N	EXCUSE	0
416651	415095	14061L	PARTICIPANT	\N	EXCUSE	0
416669	416668	04040A	PARTICIPANT	\N	PRESENT	0
416670	416668	14235Q	PARTICIPANT	\N	PRESENT	0
416671	416431	19533U	PARTICIPANT	\N	EXCUSE	0
416867	415095	14026U	PARTICIPANT	\N	EXCUSE	0
416933	416932	08045X	PARTICIPANT	\N	PRESENT	0
416934	392219	14147R	PARTICIPANT	\N	PRESENT	0
416935	392219	11097X	PARTICIPANT	\N	PRESENT	0
416946	416945	14207L	PARTICIPANT	\N	PRESENT	0
416947	416945	08024S	PARTICIPANT	\N	PRESENT	0
416948	416945	14357A	PARTICIPANT	\N	PRESENT	0
416949	416945	08015R	PARTICIPANT	\N	PRESENT	0
416950	416945	11097X	PARTICIPANT	\N	PRESENT	0
416951	416945	14213J	PARTICIPANT	\N	PRESENT	0
416952	416945	14097Y	PARTICIPANT	\N	PRESENT	0
416954	416945	19515S	PARTICIPANT	\N	PRESENT	0
417327	417326	14217N	PARTICIPANT	\N	PRESENT	0
417330	417329	14217N	PARTICIPANT	\N	PRESENT	0
417332	417331	11097X	PARTICIPANT	\N	PRESENT	0
417392	417391	14026U	PARTICIPANT	\N	PRESENT	0
417393	417391	04049K	PARTICIPANT	\N	PRESENT	0
417394	417391	14038Y	PARTICIPANT	\N	PRESENT	0
417395	417391	14087W	PARTICIPANT	\N	PRESENT	0
417396	417391	14205J	PARTICIPANT	\N	PRESENT	0
417398	417397	14039A	PARTICIPANT	\N	PRESENT	0
417404	417403	14083S	PARTICIPANT	\N	PRESENT	0
417423	417403	19631V	PARTICIPANT	\N	PRESENT	0
417425	417403	14026U	PARTICIPANT	\N	PRESENT	0
417426	417403	04049K	PARTICIPANT	\N	PRESENT	0
417408	417403	14038Y	PARTICIPANT	\N	PRESENT	0
417427	417403	19333N	PARTICIPANT	\N	PRESENT	0
417410	417403	14329V	PARTICIPANT	\N	PRESENT	0
417411	417403	16685X	PARTICIPANT	\N	PRESENT	0
417486	414062	14275Y	PARTICIPANT	\N	PRESENT	0
417487	414062	14133K	PARTICIPANT	\N	PRESENT	0
417488	414062	08034U	PARTICIPANT	\N	PRESENT	0
417489	414062	08045X	PARTICIPANT	\N	PRESENT	0
417490	414062	08043V	PARTICIPANT	\N	PRESENT	0
417491	414062	14157T	PARTICIPANT	\N	PRESENT	0
417492	414062	11066Q	PARTICIPANT	\N	PRESENT	0
417493	414062	14030Q	PARTICIPANT	\N	PRESENT	0
417494	414062	04044E	PARTICIPANT	\N	PRESENT	0
417495	414062	14083S	PARTICIPANT	\N	PRESENT	0
417496	414062	11064N	PARTICIPANT	\N	PRESENT	0
417497	414062	14187A	PARTICIPANT	\N	PRESENT	0
417498	414062	14331P	PARTICIPANT	\N	PRESENT	0
417499	417481	86034E	PARTICIPANT	\N	PRESENT	0
417530	417481	01060R	PARTICIPANT	\N	PRESENT	0
417531	417481	14001X	PARTICIPANT	\N	PRESENT	0
417543	417481	14211G	PARTICIPANT	\N	PRESENT	0
417546	417481	19711U	PARTICIPANT	\N	PRESENT	0
417549	417481	99004R	PARTICIPANT	\N	PRESENT	0
417550	417481	96004D	PARTICIPANT	\N	PRESENT	0
417552	417481	01058X	PARTICIPANT	\N	PRESENT	0
417553	417481	14157T	PARTICIPANT	\N	PRESENT	0
417554	417481	19679N	PARTICIPANT	\N	PRESENT	0
417555	417481	19760E	PARTICIPANT	\N	PRESENT	0
417556	417481	11031D	PARTICIPANT	\N	PRESENT	0
417557	417481	14038Y	PARTICIPANT	\N	PRESENT	0
417558	417481	19758L	PARTICIPANT	\N	PRESENT	0
417559	417481	11040E	PARTICIPANT	\N	PRESENT	0
417561	417481	04085P	PARTICIPANT	\N	PRESENT	0
417562	417481	19565D	PARTICIPANT	\N	PRESENT	0
417563	417481	19741B	PARTICIPANT	\N	PRESENT	0
417564	417481	19709B	PARTICIPANT	\N	PRESENT	0
417565	417481	19663E	PARTICIPANT	\N	PRESENT	0
417566	417481	11077T	PARTICIPANT	\N	PRESENT	0
417567	417481	04088S	PARTICIPANT	\N	PRESENT	0
417568	417481	19687N	PARTICIPANT	\N	PRESENT	0
417569	417481	14041T	PARTICIPANT	\N	PRESENT	0
417570	417481	11045K	PARTICIPANT	\N	PRESENT	0
417571	417481	08018U	PARTICIPANT	\N	PRESENT	0
417572	417481	95063L	PARTICIPANT	\N	PRESENT	0
417573	417481	07029T	PARTICIPANT	\N	PRESENT	0
417574	417481	08061X	PARTICIPANT	\N	PRESENT	0
417575	417481	95037J	PARTICIPANT	\N	PRESENT	0
417576	417481	14355X	PARTICIPANT	\N	PRESENT	0
417577	417481	98029W	PARTICIPANT	\N	PRESENT	0
417578	417481	08062Y	PARTICIPANT	\N	PRESENT	0
417579	417481	04045F	PARTICIPANT	\N	PRESENT	0
417580	417481	04034C	PARTICIPANT	\N	PRESENT	0
417581	417481	08015R	PARTICIPANT	\N	PRESENT	0
417582	417481	19768N	PARTICIPANT	\N	PRESENT	0
417583	417481	19651A	PARTICIPANT	\N	PRESENT	0
417584	417481	14061L	PARTICIPANT	\N	PRESENT	0
417585	417481	19349W	PARTICIPANT	\N	PRESENT	0
417586	417481	14059S	PARTICIPANT	\N	PRESENT	0
417587	417481	19507S	PARTICIPANT	\N	PRESENT	0
417588	417481	19467C	PARTICIPANT	\N	PRESENT	0
393007	393000	14033T	PARTICIPANT	\N	PRESENT	0
393008	393000	19369B	PARTICIPANT	\N	PRESENT	0
393010	393000	04089T	PARTICIPANT	\N	PRESENT	0
393019	393013	14033T	PARTICIPANT	\N	PRESENT	0
393020	393013	19369B	PARTICIPANT	\N	PRESENT	0
393022	393013	04089T	PARTICIPANT	\N	PRESENT	0
393024	393013	19733B	PARTICIPANT	\N	PRESENT	0
393030	393028	14033T	PARTICIPANT	\N	PRESENT	0
393031	393028	04089T	PARTICIPANT	\N	PRESENT	0
393033	393028	19269X	PARTICIPANT	\N	PRESENT	0
393036	393034	14033T	PARTICIPANT	\N	PRESENT	0
393038	393034	04089T	PARTICIPANT	\N	PRESENT	0
393039	393034	19269X	PARTICIPANT	\N	PRESENT	0
395518	395441	11103C	PRESIDENT	0	PRESENT	0
395519	395441	08052W	PARTICIPANT	\N	PRESENT	0
395521	395441	14026U	PARTICIPANT	\N	EXCUSE	0
395523	395441	11097X	PARTICIPANT	\N	PRESENT	0
395525	395441	19565D	PARTICIPANT	\N	PRESENT	0
395526	395441	14213J	PARTICIPANT	\N	PRESENT	0
395527	395441	14223L	PARTICIPANT	\N	PRESENT	0
395528	395441	14119M	PARTICIPANT	\N	PRESENT	0
395529	395441	19703U	PARTICIPANT	\N	PRESENT	0
395530	395441	10006L	PARTICIPANT	\N	EXCUSE	0
395531	395441	14195A	PARTICIPANT	\N	EXCUSE	0
396047	391333	14147R	PARTICIPANT	\N	PRESENT	0
396048	391333	11097X	PARTICIPANT	\N	PRESENT	0
396220	396219	19667J	PARTICIPANT	\N	EXCUSE	0
396221	396219	19711U	PARTICIPANT	\N	PRESENT	0
396222	396219	99004R	PRESIDENT	0	PRESENT	0
396223	396219	19399H	PARTICIPANT	\N	PRESENT	0
396224	396219	19515S	PARTICIPANT	\N	PRESENT	0
396225	396219	19369B	PARTICIPANT	\N	PRESENT	0
396228	396219	89017R	PARTICIPANT	\N	EXCUSE	0
396244	396219	08024S	PARTICIPANT	\N	PRESENT	0
396245	396219	19479G	PARTICIPANT	\N	EXCUSE	0
398405	392655	14239U	PARTICIPANT	\N	PRESENT	0
398406	393574	14239U	PARTICIPANT	\N	PRESENT	0
398407	396240	14239U	PARTICIPANT	\N	PRESENT	0
398408	393826	14239U	PARTICIPANT	\N	PRESENT	0
405068	404795	01048V	PARTICIPANT	\N	PRESENT	0
405069	404795	08053X	PARTICIPANT	\N	PRESENT	0
405070	404795	14257W	PRESIDENT	0	PRESENT	0
405071	404795	19533U	PARTICIPANT	\N	PRESENT	0
405072	404795	19593H	PARTICIPANT	\N	EXCUSE	0
405073	404795	19599P	PARTICIPANT	\N	EXCUSE	0
405074	404796	19631V	PARTICIPANT	\N	PRESENT	0
405075	404796	19741B	PARTICIPANT	\N	PRESENT	0
405076	404796	14038Y	PARTICIPANT	\N	PRESENT	0
405077	404796	14179A	PARTICIPANT	\N	PRESENT	0
405078	404796	19611R	PARTICIPANT	\N	PRESENT	0
405079	404796	01048V	PARTICIPANT	\N	PRESENT	0
405080	404796	08053X	PARTICIPANT	\N	PRESENT	0
405081	404796	14257W	PRESIDENT	0	PRESENT	0
405082	404796	04070G	PARTICIPANT	\N	PRESENT	0
405083	404796	19593H	PARTICIPANT	\N	PRESENT	0
405084	404796	19533U	PARTICIPANT	\N	PRESENT	0
405085	404796	11083R	PARTICIPANT	\N	EXCUSE	0
405086	404796	19599P	PARTICIPANT	\N	EXCUSE	0
405087	404796	14229S	PARTICIPANT	\N	PRESENT	0
405088	405061	19631V	PARTICIPANT	\N	PRESENT	0
405089	405061	19741B	PARTICIPANT	\N	PRESENT	0
405090	405061	14093U	PARTICIPANT	\N	PRESENT	0
405091	405061	14038Y	PARTICIPANT	\N	PRESENT	0
405092	405061	19611R	PARTICIPANT	\N	PRESENT	0
405093	405061	01048V	PARTICIPANT	\N	PRESENT	0
405094	405061	08053X	PARTICIPANT	\N	PRESENT	0
405095	405061	14257W	PRESIDENT	0	PRESENT	0
405096	405061	19593H	PARTICIPANT	\N	PRESENT	0
405097	405061	19533U	PARTICIPANT	\N	PRESENT	0
405098	405061	11083R	PARTICIPANT	\N	EXCUSE	0
405099	405061	19599P	PARTICIPANT	\N	EXCUSE	0
405103	405062	08053X	PARTICIPANT	\N	PRESENT	0
405101	405062	19611R	PARTICIPANT	\N	PRESENT	0
405102	405062	01048V	PARTICIPANT	\N	PRESENT	0
405104	405062	14257W	PRESIDENT	0	PRESENT	0
405105	405062	14038Y	PARTICIPANT	\N	PRESENT	0
405106	405062	11083R	PARTICIPANT	\N	PRESENT	0
405107	405062	19599P	PARTICIPANT	\N	EXCUSE	0
405108	405062	04070G	PARTICIPANT	\N	EXCUSE	0
405109	405062	14229S	PARTICIPANT	\N	EXCUSE	0
405113	405112	14157T	PARTICIPANT	\N	PRESENT	0
405115	405114	14157T	PARTICIPANT	\N	PRESENT	0
405116	405114	14275Y	PARTICIPANT	\N	PRESENT	0
405118	405117	14031R	PARTICIPANT	\N	PRESENT	0
405139	405138	14331P	PARTICIPANT	\N	PRESENT	0
405141	405140	14331P	PARTICIPANT	\N	PRESENT	0
405143	405142	14281W	PARTICIPANT	\N	PRESENT	0
405144	405142	14083S	PARTICIPANT	\N	PRESENT	0
405145	405142	19681G	PARTICIPANT	\N	PRESENT	0
405146	405142	14187A	PARTICIPANT	\N	PRESENT	0
405147	405142	08045X	PARTICIPANT	\N	PRESENT	0
405148	405142	08034U	PARTICIPANT	\N	PRESENT	0
405149	405142	14331P	PARTICIPANT	\N	PRESENT	0
405150	405142	11066Q	PARTICIPANT	\N	PRESENT	0
405151	405142	19760E	PARTICIPANT	\N	PRESENT	0
405152	405142	19521Q	PARTICIPANT	\N	PRESENT	0
405223	405222	11070L	PARTICIPANT	\N	PRESENT	0
405224	405222	19647E	PARTICIPANT	\N	PRESENT	0
405226	405225	01057W	PARTICIPANT	\N	PRESENT	0
405367	405366	14255U	PARTICIPANT	\N	PRESENT	0
405368	405366	08053X	PARTICIPANT	\N	PRESENT	0
405370	405369	19251M	PARTICIPANT	\N	PRESENT	0
405469	405468	14031R	PARTICIPANT	\N	PRESENT	0
405470	405468	08043V	PARTICIPANT	\N	PRESENT	0
405471	405468	14157T	PARTICIPANT	\N	PRESENT	0
405472	405468	08034U	PARTICIPANT	\N	PRESENT	0
405507	405333	14219Q	PARTICIPANT	\N	PRESENT	0
407421	405449	14259Y	PARTICIPANT	\N	EXCUSE	0
407537	405188	95067Q	PARTICIPANT	\N	PRESENT	0
407538	405188	19573D	PARTICIPANT	\N	PRESENT	0
407539	407179	14237S	PARTICIPANT	\N	PRESENT	0
407540	407179	14031R	PARTICIPANT	\N	PRESENT	0
407541	407179	19549D	PARTICIPANT	\N	PRESENT	0
407542	407179	08055A	PARTICIPANT	\N	PRESENT	0
407543	407179	19599P	PARTICIPANT	\N	PRESENT	0
407545	407179	14038Y	PARTICIPANT	\N	PRESENT	0
407546	407179	14169X	PARTICIPANT	\N	PRESENT	0
407547	407179	19387D	PARTICIPANT	\N	PRESENT	0
407548	407179	19737F	PARTICIPANT	\N	PRESENT	0
407555	405188	14073Q	PARTICIPANT	\N	PRESENT	0
407563	407179	19333N	PARTICIPANT	\N	PRESENT	0
407564	407179	14157T	PARTICIPANT	\N	PRESENT	0
407565	407179	19637C	PARTICIPANT	\N	PRESENT	0
407566	407179	08024S	PARTICIPANT	\N	PRESENT	0
407593	405188	19737F	PARTICIPANT	\N	PRESENT	0
407594	405188	14031R	PARTICIPANT	\N	PRESENT	0
407595	405188	19441R	PARTICIPANT	\N	PRESENT	0
407596	405188	14169X	PARTICIPANT	\N	PRESENT	0
407597	405188	08039A	PARTICIPANT	\N	PRESENT	0
407598	405188	04059M	PARTICIPANT	\N	PRESENT	0
407657	402270	11027H	PARTICIPANT	\N	PRESENT	0
407658	402270	04059M	PARTICIPANT	\N	PRESENT	0
407659	402270	19699S	PARTICIPANT	\N	PRESENT	0
407660	402270	19387D	PARTICIPANT	\N	PRESENT	0
407661	402270	11012A	PARTICIPANT	\N	PRESENT	0
407662	402270	19758L	PARTICIPANT	\N	PRESENT	0
407663	402270	14030Q	PARTICIPANT	\N	PRESENT	0
407664	402270	19619A	PARTICIPANT	\N	PRESENT	0
407665	402270	19737F	PARTICIPANT	\N	PRESENT	0
407666	402270	19611R	PARTICIPANT	\N	PRESENT	0
407667	402270	19731Y	PARTICIPANT	\N	PRESENT	0
407668	402270	19711U	PARTICIPANT	\N	PRESENT	0
407669	402270	97011G	PARTICIPANT	\N	PRESENT	0
407670	402270	11048N	PARTICIPANT	\N	PRESENT	0
407671	402270	19399H	PARTICIPANT	\N	PRESENT	0
407672	402270	19693L	PARTICIPANT	\N	PRESENT	0
407673	402270	11090Q	PARTICIPANT	\N	PRESENT	0
407674	402270	19663E	PARTICIPANT	\N	PRESENT	0
407675	402270	04070G	PARTICIPANT	\N	PRESENT	0
407676	402270	19515S	PARTICIPANT	\N	PRESENT	0
407677	402270	08039A	PARTICIPANT	\N	PRESENT	0
407678	402270	19760E	PARTICIPANT	\N	PRESENT	0
407679	402270	19671E	PARTICIPANT	\N	PRESENT	0
407687	402270	14073Q	PARTICIPANT	\N	PRESENT	0
407688	402270	14251Q	PARTICIPANT	\N	PRESENT	0
407689	402270	07029T	PARTICIPANT	\N	PRESENT	0
407690	402270	14033T	PARTICIPANT	\N	PRESENT	0
407691	402270	19415P	PARTICIPANT	\N	PRESENT	0
416310	406860	14231L	PARTICIPANT	\N	PRESENT	0
416295	406860	11072N	PARTICIPANT	\N	PRESENT	0
416309	406860	14259Y	PARTICIPANT	\N	PRESENT	0
416311	406860	19651A	PARTICIPANT	\N	PRESENT	0
416312	406860	19649G	PARTICIPANT	\N	PRESENT	0
416313	406860	14227Q	PARTICIPANT	\N	PRESENT	0
416314	406860	19647E	PARTICIPANT	\N	PRESENT	0
416315	406860	08024S	PARTICIPANT	\N	PRESENT	0
416316	406860	19489J	PARTICIPANT	\N	PRESENT	0
416317	406860	14151M	PARTICIPANT	\N	PRESENT	0
416318	406860	11056N	PARTICIPANT	\N	PRESENT	0
416319	406860	19565D	PARTICIPANT	\N	PRESENT	0
416320	406860	05008E	PARTICIPANT	\N	PRESENT	0
416321	406860	14073Q	PARTICIPANT	\N	PRESENT	0
416323	406860	19749K	PARTICIPANT	\N	PRESENT	0
416324	406860	19507S	PARTICIPANT	\N	PRESENT	0
416325	406860	19762G	PARTICIPANT	\N	PRESENT	0
416326	406860	14157T	PARTICIPANT	\N	PRESENT	0
416327	406860	14031R	PARTICIPANT	\N	PRESENT	0
416328	406860	19794Q	PARTICIPANT	\N	PRESENT	0
416330	406860	19467C	PARTICIPANT	\N	PRESENT	0
416331	406860	18083K	PARTICIPANT	\N	PRESENT	0
416332	406860	14207L	PARTICIPANT	\N	PRESENT	0
416334	406860	14089Y	PARTICIPANT	\N	PRESENT	0
416335	406860	08009T	PARTICIPANT	\N	PRESENT	0
416337	406860	10015M	PARTICIPANT	\N	PRESENT	0
416338	406860	99004R	PARTICIPANT	\N	PRESENT	0
416339	406860	14030Q	PARTICIPANT	\N	PRESENT	0
416340	406860	14275Y	PARTICIPANT	\N	PRESENT	0
416341	406860	19619A	PARTICIPANT	\N	PRESENT	0
416342	406860	08045X	PARTICIPANT	\N	PRESENT	0
416343	406860	14249W	PARTICIPANT	\N	PRESENT	0
416344	406860	16685X	PARTICIPANT	\N	PRESENT	0
416345	406860	14195A	PARTICIPANT	\N	PRESENT	0
416346	406860	14038Y	PARTICIPANT	\N	PRESENT	0
416348	406860	19413M	PARTICIPANT	\N	PRESENT	0
416350	406860	19521Q	PARTICIPANT	\N	PRESENT	0
416355	406860	19503N	PARTICIPANT	\N	PRESENT	0
416356	406860	19387D	PARTICIPANT	\N	PRESENT	0
416357	406860	19563B	PARTICIPANT	\N	PRESENT	0
416358	406860	19585H	PARTICIPANT	\N	PRESENT	0
416360	406860	19551W	PARTICIPANT	\N	PRESENT	0
416361	406860	14065Q	PARTICIPANT	\N	PRESENT	0
416362	406860	04071H	PARTICIPANT	\N	PRESENT	0
416363	406860	14211G	PARTICIPANT	\N	PRESENT	0
416364	406860	19747H	PARTICIPANT	\N	PRESENT	0
416365	406860	14179A	PARTICIPANT	\N	PRESENT	0
416372	406860	19531S	PARTICIPANT	\N	PRESENT	0
416373	406860	14053L	PARTICIPANT	\N	PRESENT	0
416374	406860	14071N	PARTICIPANT	\N	PRESENT	0
416376	406860	14069U	PARTICIPANT	\N	PRESENT	0
416377	406860	07029T	PARTICIPANT	\N	PRESENT	0
416378	406860	19611R	PARTICIPANT	\N	PRESENT	0
416379	406860	14219Q	PARTICIPANT	\N	PRESENT	0
416380	406860	08068F	PARTICIPANT	\N	PRESENT	0
416381	406860	19826F	PARTICIPANT	\N	PRESENT	0
416382	406860	01024M	PARTICIPANT	\N	PRESENT	0
416383	406860	14357A	PARTICIPANT	\N	PRESENT	0
416384	406860	19415P	PARTICIPANT	\N	PRESENT	0
416385	406860	19719D	PARTICIPANT	\N	PRESENT	0
416386	406860	19335Q	PARTICIPANT	\N	PRESENT	0
416387	406860	14241N	PARTICIPANT	\N	PRESENT	0
416388	406860	19768N	PARTICIPANT	\N	PRESENT	0
416389	406860	11048N	PARTICIPANT	\N	PRESENT	0
416390	406860	01028R	PARTICIPANT	\N	PRESENT	0
416391	406860	19760E	PARTICIPANT	\N	PRESENT	0
416392	406860	11077T	PARTICIPANT	\N	PRESENT	0
416393	406860	14111D	PARTICIPANT	\N	PRESENT	0
416394	406860	11080N	PARTICIPANT	\N	PRESENT	0
416395	406860	14215L	PARTICIPANT	\N	PRESENT	0
416396	406860	08034U	PARTICIPANT	\N	PRESENT	0
416397	406860	04070G	PARTICIPANT	\N	PRESENT	0
416398	406860	14229S	PARTICIPANT	\N	PRESENT	0
416399	406860	14147R	PARTICIPANT	\N	PRESENT	0
416400	406860	04044E	PARTICIPANT	\N	PRESENT	0
416401	406860	17637T	PARTICIPANT	\N	PRESENT	0
416402	406860	19447X	PARTICIPANT	\N	PRESENT	0
416403	406860	19703U	PARTICIPANT	\N	PRESENT	0
416404	406860	14059S	PARTICIPANT	\N	PRESENT	0
416405	406860	19713W	PARTICIPANT	\N	PRESENT	0
416406	406860	04040A	PARTICIPANT	\N	PRESENT	0
416407	406860	08061X	PARTICIPANT	\N	PRESENT	0
416408	406860	14061L	PARTICIPANT	\N	PRESENT	0
416409	406860	19369B	PARTICIPANT	\N	PRESENT	0
416410	406860	14026U	PARTICIPANT	\N	PRESENT	0
416411	406860	19441R	PARTICIPANT	\N	PRESENT	0
416412	406860	14083S	PARTICIPANT	\N	PRESENT	0
416413	406860	14033T	PARTICIPANT	\N	PRESENT	0
416414	406860	14257W	PARTICIPANT	\N	PRESENT	0
416415	406860	14034U	PARTICIPANT	\N	PRESENT	0
416416	406860	11012A	PARTICIPANT	\N	PRESENT	0
416417	406860	08015R	PARTICIPANT	\N	PRESENT	0
416428	408325	14107H	PARTICIPANT	\N	EXCUSE	0
416438	408325	19551W	PARTICIPANT	\N	PRESENT	0
416765	406929	05008E	PARTICIPANT	\N	PRESENT	0
416766	406929	14231L	PARTICIPANT	\N	PRESENT	0
416768	406929	14267Y	PARTICIPANT	\N	PRESENT	0
416769	406929	04038G	PARTICIPANT	\N	PRESENT	0
416770	406929	14331P	PARTICIPANT	\N	PRESENT	0
416771	406929	19826F	PARTICIPANT	\N	PRESENT	0
416772	406929	19503N	PARTICIPANT	\N	PRESENT	0
416773	406929	19629C	PARTICIPANT	\N	PRESENT	0
416774	406929	19719D	PARTICIPANT	\N	PRESENT	0
416775	406929	18083K	PARTICIPANT	\N	PRESENT	0
416776	406929	19347U	PARTICIPANT	\N	PRESENT	0
416777	406929	19565D	PARTICIPANT	\N	PRESENT	0
416778	406929	19794Q	PARTICIPANT	\N	PRESENT	0
416802	406929	14083S	PARTICIPANT	\N	PRESENT	0
416803	406929	07004J	PARTICIPANT	\N	PRESENT	0
416804	406929	19683J	PARTICIPANT	\N	PRESENT	0
416805	406929	19599P	PARTICIPANT	\N	PRESENT	0
416806	406929	19489J	PARTICIPANT	\N	PRESENT	0
416807	406929	19725B	PARTICIPANT	\N	PRESENT	0
416808	406929	14257W	PARTICIPANT	\N	PRESENT	0
416810	406929	08061X	PARTICIPANT	\N	PRESENT	0
416812	406929	19563B	PARTICIPANT	\N	PRESENT	0
416814	406929	19441R	PARTICIPANT	\N	PRESENT	0
416815	406929	19387D	PARTICIPANT	\N	PRESENT	0
416816	406929	08049C	PARTICIPANT	\N	PRESENT	0
416817	406929	08009T	PARTICIPANT	\N	PRESENT	0
416820	406929	07029T	PARTICIPANT	\N	PRESENT	0
416821	406929	11048N	PARTICIPANT	\N	PRESENT	0
416823	406929	99004R	PARTICIPANT	\N	PRESENT	0
416824	406929	14071N	PARTICIPANT	\N	PRESENT	0
416825	406929	14249W	PARTICIPANT	\N	PRESENT	0
416826	406929	08010L	PARTICIPANT	\N	PRESENT	0
416827	406929	14038Y	PARTICIPANT	\N	PRESENT	0
416828	406929	19693L	PARTICIPANT	\N	PRESENT	0
416829	406929	97011G	PARTICIPANT	\N	PRESENT	0
416830	406929	14207L	PARTICIPANT	\N	PRESENT	0
416831	406929	98050T	PARTICIPANT	\N	PRESENT	0
416832	406929	19747H	PARTICIPANT	\N	PRESENT	0
416833	406929	14215L	PARTICIPANT	\N	PRESENT	0
416835	406929	14213J	PARTICIPANT	\N	PRESENT	0
416836	406929	08034U	PARTICIPANT	\N	PRESENT	0
416837	406929	08024S	PARTICIPANT	\N	PRESENT	0
416838	406929	19335Q	PARTICIPANT	\N	PRESENT	0
416839	406929	19745F	PARTICIPANT	\N	PRESENT	0
416840	406929	14157T	PARTICIPANT	\N	PRESENT	0
416842	416841	04049K	PRESIDENT	0	PRESENT	0
416843	416841	16685X	PARTICIPANT	\N	PRESENT	0
416844	406929	19585H	PARTICIPANT	\N	PRESENT	0
416845	416841	14083S	PARTICIPANT	\N	PRESENT	0
416846	416841	14026U	PARTICIPANT	\N	PRESENT	0
416847	416841	14329V	PARTICIPANT	\N	PRESENT	0
416848	416841	14038Y	PARTICIPANT	\N	PRESENT	0
416849	416841	19333N	PARTICIPANT	\N	PRESENT	0
416850	416841	19631V	PARTICIPANT	\N	PRESENT	0
416851	406929	14265W	PARTICIPANT	\N	PRESENT	0
416852	416841	19575F	PARTICIPANT	\N	EXCUSE	0
416853	406929	19711U	PARTICIPANT	\N	PRESENT	0
416854	416841	08060W	PARTICIPANT	\N	EXCUSE	0
416855	416841	14105F	PARTICIPANT	\N	EXCUSE	0
416856	406929	19533U	PARTICIPANT	\N	PRESENT	0
416857	416841	14255U	PARTICIPANT	\N	EXCUSE	0
416858	416841	19545Y	PARTICIPANT	\N	EXCUSE	0
416859	416841	14041T	PARTICIPANT	\N	EXCUSE	0
416860	406929	19507S	PARTICIPANT	\N	PRESENT	0
416861	416841	19521Q	PARTICIPANT	\N	EXCUSE	0
416862	416841	14034U	PARTICIPANT	\N	EXCUSE	0
416864	416841	14061L	PARTICIPANT	\N	EXCUSE	0
416865	416841	08015R	PARTICIPANT	\N	EXCUSE	0
416866	416841	14265W	PARTICIPANT	\N	EXCUSE	0
416868	416863	04057K	PARTICIPANT	\N	PRESENT	0
416869	416841	08047A	PARTICIPANT	\N	EXCUSE	0
416870	416841	14227Q	PARTICIPANT	\N	EXCUSE	0
416871	406929	14073Q	PARTICIPANT	\N	PRESENT	0
416749	406929	04059M	PARTICIPANT	\N	PRESENT	0
416764	406929	14259Y	PARTICIPANT	\N	PRESENT	0
398543	397651	92040Q	PARTICIPANT	\N	EXCUSE	0
399846	399761	11067R	PARTICIPANT	\N	PRESENT	0
399847	399761	19798U	PARTICIPANT	\N	PRESENT	0
399848	399761	19569H	PARTICIPANT	\N	PRESENT	0
399849	399761	11097X	PARTICIPANT	\N	PRESENT	0
399850	399761	14223L	PARTICIPANT	\N	PRESENT	0
399851	399761	14026U	PARTICIPANT	\N	PRESENT	0
399852	399761	14227Q	PARTICIPANT	\N	PRESENT	0
399853	399761	17779H	PARTICIPANT	\N	PRESENT	0
399854	399761	19703U	PARTICIPANT	\N	PRESENT	0
399855	399761	19553Y	PARTICIPANT	\N	PRESENT	0
399856	399761	11031D	PARTICIPANT	\N	PRESENT	0
399857	399761	14087W	PARTICIPANT	\N	PRESENT	0
399858	399761	14281W	PARTICIPANT	\N	PRESENT	0
399859	399761	19679N	PARTICIPANT	\N	PRESENT	0
399860	399761	14042U	PARTICIPANT	\N	PRESENT	0
399861	399761	19575F	PARTICIPANT	\N	PRESENT	0
399862	399761	08048B	PARTICIPANT	\N	PRESENT	0
399863	399761	14195A	PARTICIPANT	\N	PRESENT	0
399864	399761	19367Y	PARTICIPANT	\N	PRESENT	0
399865	399761	14213J	PARTICIPANT	\N	PRESENT	0
399866	399761	14217N	PARTICIPANT	\N	PRESENT	0
399867	399761	10006L	PARTICIPANT	\N	PRESENT	0
399868	399761	98024R	PRESIDENT	0	PRESENT	0
399869	399761	19521Q	PARTICIPANT	\N	PRESENT	0
399870	399761	01034P	PARTICIPANT	\N	PRESENT	0
399871	399761	08052W	PARTICIPANT	\N	PRESENT	0
399872	399761	19663E	PARTICIPANT	\N	PRESENT	0
399873	399761	19691J	PARTICIPANT	\N	PRESENT	0
399874	399761	14119M	PARTICIPANT	\N	PRESENT	0
399875	399761	11103C	PARTICIPANT	\N	PRESENT	0
399876	399761	19657G	PARTICIPANT	\N	PRESENT	0
399877	399761	14071N	PARTICIPANT	\N	PRESENT	0
399878	399761	19760E	PARTICIPANT	\N	PRESENT	0
399879	399761	04092N	PARTICIPANT	\N	EXCUSE	0
399880	399761	19565D	PARTICIPANT	\N	EXCUSE	0
399881	399761	08041T	PARTICIPANT	\N	EXCUSE	0
400088	393815	14034U	PARTICIPANT	\N	PRESENT	0
400089	393815	97011G	PARTICIPANT	\N	PRESENT	0
400090	393815	18083K	PARTICIPANT	\N	PRESENT	0
400091	393815	19399H	PARTICIPANT	\N	PRESENT	0
400092	393815	14179A	PARTICIPANT	\N	PRESENT	0
400093	393815	01028R	PARTICIPANT	\N	PRESENT	0
400094	393815	14069U	PARTICIPANT	\N	PRESENT	0
400095	393815	14357A	PARTICIPANT	\N	PRESENT	0
400096	393815	14135M	PARTICIPANT	\N	PRESENT	0
400097	393815	14033T	PARTICIPANT	\N	PRESENT	0
400098	393815	14147R	PARTICIPANT	\N	PRESENT	0
400119	397658	14028W	PARTICIPANT	\N	EXCUSE	0
400120	397658	11054L	PARTICIPANT	\N	EXCUSE	0
400121	397658	08053X	PARTICIPANT	\N	EXCUSE	0
400122	393608	04059M	PARTICIPANT	\N	PRESENT	0
400123	393608	08011M	PARTICIPANT	\N	PRESENT	0
400124	393608	11074Q	PARTICIPANT	\N	PRESENT	0
400125	393608	11040E	PARTICIPANT	\N	PRESENT	0
400126	393608	19687N	PARTICIPANT	\N	PRESENT	0
400127	393608	19689Q	PARTICIPANT	\N	PRESENT	0
400128	393608	19333N	PARTICIPANT	\N	PRESENT	0
400129	393608	19479G	PARTICIPANT	\N	PRESENT	0
400130	393608	07004J	PARTICIPANT	\N	PRESENT	0
400131	393608	14147R	PARTICIPANT	\N	PRESENT	0
400132	393608	08039A	PARTICIPANT	\N	PRESENT	0
400133	393608	14069U	PARTICIPANT	\N	PRESENT	0
400134	393608	14331P	PARTICIPANT	\N	PRESENT	0
400135	393608	18083K	PARTICIPANT	\N	PRESENT	0
400136	393608	19737F	PARTICIPANT	\N	PRESENT	0
400137	393608	98005N	PARTICIPANT	\N	PRESENT	0
400138	393608	19399H	PARTICIPANT	\N	PRESENT	0
400139	393608	07029T	PARTICIPANT	\N	PRESENT	0
400140	393608	19711U	PARTICIPANT	\N	PRESENT	0
400141	393608	19691J	PARTICIPANT	\N	PRESENT	0
400142	393608	14061L	PARTICIPANT	\N	PRESENT	0
399943	399906	19593H	PARTICIPANT	\N	PRESENT	0
399944	399906	04070G	PRESIDENT	0	PRESENT	0
399945	399906	14061L	PARTICIPANT	\N	PRESENT	0
399946	399906	19533U	PARTICIPANT	\N	PRESENT	0
399947	399906	14073Q	PARTICIPANT	\N	PRESENT	0
399948	399906	19611R	PARTICIPANT	\N	PRESENT	0
399949	399906	08043V	PARTICIPANT	\N	PRESENT	0
399950	399906	14229S	PARTICIPANT	\N	PRESENT	0
399951	399906	14241N	PARTICIPANT	\N	PRESENT	0
399952	399906	04059M	PARTICIPANT	\N	PRESENT	0
399953	399906	19735D	PARTICIPANT	\N	PRESENT	0
399954	399906	08017T	PARTICIPANT	\N	PRESENT	0
399955	399906	92040Q	PARTICIPANT	\N	PRESENT	0
399956	399906	19749K	PARTICIPANT	\N	PRESENT	0
399957	399906	08039A	PARTICIPANT	\N	PRESENT	0
399958	398208	19725B	PRESIDENT	0	PRESENT	0
399959	398208	04057K	PARTICIPANT	\N	PRESENT	0
399960	398208	14107H	PARTICIPANT	\N	PRESENT	0
399961	398208	08015R	PARTICIPANT	\N	PRESENT	0
399962	398208	19441R	PARTICIPANT	\N	PRESENT	0
399963	398208	04097T	PARTICIPANT	\N	PRESENT	0
399964	398208	14033T	PARTICIPANT	\N	PRESENT	0
399965	398208	19295A	PARTICIPANT	\N	PRESENT	0
399966	398208	14026U	PARTICIPANT	\N	PRESENT	0
399967	398208	08073C	PARTICIPANT	\N	EXCUSE	0
399968	398208	14071N	PARTICIPANT	\N	EXCUSE	0
400143	393608	14041T	PARTICIPANT	\N	PRESENT	0
400144	393608	14235Q	PARTICIPANT	\N	PRESENT	0
400145	393608	14073Q	PARTICIPANT	\N	PRESENT	0
400146	393608	11048N	PARTICIPANT	\N	PRESENT	0
400147	393608	19693L	PARTICIPANT	\N	PRESENT	0
400148	393608	98050T	PARTICIPANT	\N	PRESENT	0
400149	393608	14034U	PARTICIPANT	\N	PRESENT	0
400166	393608	14021P	PARTICIPANT	\N	PRESENT	0
400168	393608	14085U	PARTICIPANT	\N	PRESENT	0
400169	393608	14225N	PARTICIPANT	\N	PRESENT	0
399986	397658	12041X	PARTICIPANT	\N	PRESENT	0
399987	397658	11041F	PARTICIPANT	\N	PRESENT	0
399988	397658	04034C	PARTICIPANT	\N	PRESENT	0
399989	397658	14235Q	PARTICIPANT	\N	PRESENT	0
399990	397658	04040A	PARTICIPANT	\N	PRESENT	0
399991	397658	08058D	PARTICIPANT	\N	PRESENT	0
399992	397658	04042C	PRESIDENT	0	PRESENT	0
399993	397658	19251M	PARTICIPANT	\N	PRESENT	0
399994	397658	11066Q	PARTICIPANT	\N	PRESENT	0
399995	397658	14105F	PARTICIPANT	\N	PRESENT	0
399996	397658	95037J	PARTICIPANT	\N	PRESENT	0
399997	397658	98018T	PARTICIPANT	\N	PRESENT	0
399998	397658	19421M	PARTICIPANT	\N	PRESENT	0
399999	397658	98022P	PARTICIPANT	\N	PRESENT	0
400000	397658	14193X	PARTICIPANT	\N	PRESENT	0
400001	397658	98050T	PARTICIPANT	\N	PRESENT	0
400002	397658	97011G	PARTICIPANT	\N	PRESENT	0
400003	397658	14255U	PARTICIPANT	\N	PRESENT	0
400004	397658	98029W	PARTICIPANT	\N	PRESENT	0
400179	393608	19725B	PARTICIPANT	\N	PRESENT	0
400006	397658	14097Y	PARTICIPANT	\N	PRESENT	0
400007	397658	14133K	PARTICIPANT	\N	PRESENT	0
400008	397658	16685X	PARTICIPANT	\N	PRESENT	0
400009	397658	08047A	PARTICIPANT	\N	PRESENT	0
400180	393608	14159V	PARTICIPANT	\N	PRESENT	0
400183	393608	19511N	PARTICIPANT	\N	PRESENT	0
400034	398208	14327T	PARTICIPANT	\N	PRESENT	0
400035	398208	08014Q	PARTICIPANT	\N	PRESENT	0
400082	393815	04038G	PARTICIPANT	\N	PRESENT	0
400083	393815	01024M	PARTICIPANT	\N	PRESENT	0
400084	393815	19758L	PARTICIPANT	\N	PRESENT	0
400085	393815	11064N	PARTICIPANT	\N	PRESENT	0
400086	393815	08031R	PARTICIPANT	\N	PRESENT	0
400087	393815	14217N	PARTICIPANT	\N	PRESENT	0
417589	417481	19415P	PARTICIPANT	\N	PRESENT	0
417590	417481	08019V	PARTICIPANT	\N	PRESENT	0
417591	417481	19399H	PARTICIPANT	\N	PRESENT	0
417592	417481	19693L	PARTICIPANT	\N	PRESENT	0
417593	417481	19729F	PARTICIPANT	\N	PRESENT	0
417594	417481	08048B	PARTICIPANT	\N	PRESENT	0
417595	417481	14265W	PARTICIPANT	\N	PRESENT	0
417596	417481	14213J	PARTICIPANT	\N	PRESENT	0
417597	417481	14329V	PARTICIPANT	\N	PRESENT	0
417598	417481	14357A	PARTICIPANT	\N	PRESENT	0
417599	417481	19383Y	PARTICIPANT	\N	PRESENT	0
417600	417481	19762G	PARTICIPANT	\N	PRESENT	0
417601	417481	14239U	PARTICIPANT	\N	PRESENT	0
417602	417481	19701S	PARTICIPANT	\N	PRESENT	0
417603	417481	04018C	PARTICIPANT	\N	PRESENT	0
417604	417481	19697Q	PARTICIPANT	\N	PRESENT	0
417605	417481	19621T	PARTICIPANT	\N	PRESENT	0
417606	417481	19637C	PARTICIPANT	\N	PRESENT	0
417607	417481	19367Y	PARTICIPANT	\N	PRESENT	0
417608	417481	14173T	PARTICIPANT	\N	PRESENT	0
417609	417481	19447X	PARTICIPANT	\N	PRESENT	0
417610	417481	19573D	PARTICIPANT	\N	PRESENT	0
417611	417481	19794Q	PARTICIPANT	\N	PRESENT	0
417612	417481	08024S	PARTICIPANT	\N	PRESENT	0
417613	417481	14133K	PARTICIPANT	\N	PRESENT	0
417614	417481	92040Q	PARTICIPANT	\N	PRESENT	0
417615	417481	08056B	PARTICIPANT	\N	PRESENT	0
417616	417481	08047A	PARTICIPANT	\N	PRESENT	0
417617	417481	11049P	PARTICIPANT	\N	PRESENT	0
417618	417481	08031R	PARTICIPANT	\N	PRESENT	0
417619	417481	14115H	PARTICIPANT	\N	PRESENT	0
417620	417481	17583W	PARTICIPANT	\N	PRESENT	0
417621	417481	11012A	PARTICIPANT	\N	PRESENT	0
417622	417481	14147R	PARTICIPANT	\N	PRESENT	0
417623	417481	88008L	PARTICIPANT	\N	PRESENT	0
417624	417481	14261S	PARTICIPANT	\N	PRESENT	0
417625	417481	19253P	PARTICIPANT	\N	PRESENT	0
417626	417481	97011G	PARTICIPANT	\N	PRESENT	0
417627	417481	14107H	PARTICIPANT	\N	PRESENT	0
417628	417481	11083R	PARTICIPANT	\N	PRESENT	0
417629	417481	07033P	PARTICIPANT	\N	PRESENT	0
417630	417481	14217N	PARTICIPANT	\N	PRESENT	0
417631	417481	14241N	PARTICIPANT	\N	PRESENT	0
417632	417481	04069P	PARTICIPANT	\N	PRESENT	0
417633	417481	14331P	PARTICIPANT	\N	PRESENT	0
417634	417481	98022P	PARTICIPANT	\N	PRESENT	0
417635	417481	19387D	PARTICIPANT	\N	PRESENT	0
417636	417481	14079W	PARTICIPANT	\N	PRESENT	0
417637	417481	11065P	PARTICIPANT	\N	PRESENT	0
417638	417481	19703U	PARTICIPANT	\N	PRESENT	0
417639	417481	19719D	PARTICIPANT	\N	PRESENT	0
417640	417481	19673G	PARTICIPANT	\N	PRESENT	0
417641	417481	11010L	PARTICIPANT	\N	PRESENT	0
417642	417481	19667J	PARTICIPANT	\N	PRESENT	0
417643	417481	11115U	PARTICIPANT	\N	PRESENT	0
417644	417481	19269X	PARTICIPANT	\N	PRESENT	0
417645	417481	14199E	PARTICIPANT	\N	PRESENT	0
417646	417481	19575F	PARTICIPANT	\N	PRESENT	0
417647	417481	19543W	PARTICIPANT	\N	PRESENT	0
417648	417481	14253S	PARTICIPANT	\N	PRESENT	0
417649	417481	04049K	PARTICIPANT	\N	PRESENT	0
417650	417481	04057K	PARTICIPANT	\N	PRESENT	0
417651	417481	05012A	PARTICIPANT	\N	PRESENT	0
417652	417481	19681G	PARTICIPANT	\N	PRESENT	0
417653	417481	14121F	PARTICIPANT	\N	PRESENT	0
417654	417481	08034U	PARTICIPANT	\N	PRESENT	0
417655	417481	19533U	PARTICIPANT	\N	PRESENT	0
417656	417481	19545Y	PARTICIPANT	\N	PRESENT	0
417657	417481	10006L	PARTICIPANT	\N	PRESENT	0
417658	417481	19585H	PARTICIPANT	\N	PRESENT	0
417659	417481	14111D	PARTICIPANT	\N	PRESENT	0
417660	417481	19798U	PARTICIPANT	\N	PRESENT	0
417661	417481	11064N	PARTICIPANT	\N	PRESENT	0
417662	417481	14251Q	PARTICIPANT	\N	PRESENT	0
417669	417481	11033F	PARTICIPANT	\N	PRESENT	0
417664	417481	19553Y	PARTICIPANT	\N	PRESENT	0
417666	417481	04059M	PARTICIPANT	\N	PRESENT	0
417667	417481	11074Q	PARTICIPANT	\N	PRESENT	0
417668	417481	14193X	PARTICIPANT	\N	PRESENT	0
417670	417481	04038G	PARTICIPANT	\N	PRESENT	0
417671	417481	11080N	PARTICIPANT	\N	PRESENT	0
417672	417481	11027H	PARTICIPANT	\N	PRESENT	0
417673	417481	14031R	PARTICIPANT	\N	PRESENT	0
417674	417481	08055A	PARTICIPANT	\N	PRESENT	0
417675	417481	14229S	PARTICIPANT	\N	PRESENT	0
417676	417481	01057W	PARTICIPANT	\N	PRESENT	0
417677	417481	98035U	PARTICIPANT	\N	PRESENT	0
417678	417481	11090Q	PARTICIPANT	\N	PRESENT	0
417679	417481	08052W	PARTICIPANT	\N	PRESENT	0
417680	417481	87003B	PARTICIPANT	\N	PRESENT	0
417681	417481	01028R	PARTICIPANT	\N	PRESENT	0
417682	417481	04043D	PARTICIPANT	\N	PRESENT	0
417683	417481	14069U	PARTICIPANT	\N	PRESENT	0
417684	417481	08045X	PARTICIPANT	\N	PRESENT	0
417685	417481	19599P	PARTICIPANT	\N	PRESENT	0
417686	417481	14249W	PARTICIPANT	\N	PRESENT	0
417687	417481	19715Y	PARTICIPANT	\N	PRESENT	0
417688	417481	14215L	PARTICIPANT	\N	PRESENT	0
417689	417481	12016W	PARTICIPANT	\N	PRESENT	0
417690	417481	15447F	PARTICIPANT	\N	PRESENT	0
417691	417481	14151M	PARTICIPANT	\N	PRESENT	0
417692	417481	14169X	PARTICIPANT	\N	PRESENT	0
417694	417481	14223L	PARTICIPANT	\N	PRESENT	0
417695	417481	08060W	PARTICIPANT	\N	PRESENT	0
417696	417481	10015M	PARTICIPANT	\N	PRESENT	0
417697	417481	08038Y	PARTICIPANT	\N	PRESENT	0
417698	417481	08028W	PARTICIPANT	\N	PRESENT	0
417699	417481	04033B	PARTICIPANT	\N	PRESENT	0
417700	417481	14187A	PARTICIPANT	\N	PRESENT	0
417701	417481	11066Q	PARTICIPANT	\N	PRESENT	0
417702	417481	14281W	PARTICIPANT	\N	PRESENT	0
417703	417481	11097X	PARTICIPANT	\N	PRESENT	0
417704	417481	19421M	PARTICIPANT	\N	PRESENT	0
417705	417481	19727D	PARTICIPANT	\N	PRESENT	0
417706	417481	19649G	PARTICIPANT	\N	PRESENT	0
417707	417481	08012N	PARTICIPANT	\N	PRESENT	0
417708	417481	19733B	PARTICIPANT	\N	PRESENT	0
417709	417481	19820Y	PARTICIPANT	\N	PRESENT	0
417710	417481	11110B	PARTICIPANT	\N	PRESENT	0
417711	417481	14257W	PARTICIPANT	\N	PRESENT	0
417712	417481	19525U	PARTICIPANT	\N	PRESENT	0
417713	417481	08053X	PARTICIPANT	\N	PRESENT	0
417714	417481	08017T	PARTICIPANT	\N	PRESENT	0
417715	417481	14085U	PARTICIPANT	\N	PRESENT	0
417716	417481	04097T	PARTICIPANT	\N	PRESENT	0
417717	417481	19647E	PARTICIPANT	\N	PRESENT	0
417718	417481	08020N	PARTICIPANT	\N	PRESENT	0
417719	417481	08058D	PARTICIPANT	\N	PRESENT	0
417720	417481	14065Q	PARTICIPANT	\N	PRESENT	0
417721	417481	08010L	PARTICIPANT	\N	PRESENT	0
417722	417481	17779H	PARTICIPANT	\N	PRESENT	0
417723	417481	19489J	PARTICIPANT	\N	PRESENT	0
417724	417481	08069G	PARTICIPANT	\N	PRESENT	0
417725	417481	14081Q	PARTICIPANT	\N	PRESENT	0
417726	417481	04086Q	PARTICIPANT	\N	PRESENT	0
417727	417481	19549D	PARTICIPANT	\N	PRESENT	0
417728	417481	04044E	PARTICIPANT	\N	PRESENT	0
417729	417481	08014Q	PARTICIPANT	\N	PRESENT	0
417730	417481	19725B	PARTICIPANT	\N	PRESENT	0
417731	417481	19333N	PARTICIPANT	\N	PRESENT	0
417732	417481	14033T	PARTICIPANT	\N	PRESENT	0
417733	417481	95041E	PARTICIPANT	\N	PRESENT	0
417734	417481	19631V	PARTICIPANT	\N	PRESENT	0
417735	417481	19643A	PARTICIPANT	\N	PRESENT	0
417736	417481	01048V	PARTICIPANT	\N	PRESENT	0
417737	417481	14207L	PARTICIPANT	\N	PRESENT	0
417738	417481	14053L	PARTICIPANT	\N	PRESENT	0
417739	417481	11067R	PARTICIPANT	\N	PRESENT	0
417740	417481	11054L	PARTICIPANT	\N	PRESENT	0
417741	417481	19747H	PARTICIPANT	\N	PRESENT	0
417742	417481	19251M	PARTICIPANT	\N	PRESENT	0
417743	417481	19413M	PARTICIPANT	\N	PRESENT	0
417744	417481	98018T	PARTICIPANT	\N	PRESENT	0
417745	417481	11041F	PARTICIPANT	\N	PRESENT	0
417746	417481	19551W	PARTICIPANT	\N	PRESENT	0
417747	417481	14231L	PARTICIPANT	\N	PRESENT	0
417748	417481	95030B	PARTICIPANT	\N	PRESENT	0
417749	417481	14026U	PARTICIPANT	\N	PRESENT	0
417750	417481	04035D	PARTICIPANT	\N	PRESENT	0
417751	417481	08044W	PARTICIPANT	\N	PRESENT	0
417752	417481	19569H	PARTICIPANT	\N	PRESENT	0
417753	417481	80013X	PARTICIPANT	\N	PRESENT	0
417754	417481	08043V	PARTICIPANT	\N	PRESENT	0
417755	417481	14119M	PARTICIPANT	\N	PRESENT	0
417756	417481	19691J	PARTICIPANT	\N	PRESENT	0
417757	417481	19369B	PARTICIPANT	\N	PRESENT	0
393067	393066	05008E	PARTICIPANT	\N	PRESENT	0
393069	393066	14053L	PARTICIPANT	\N	PRESENT	0
393070	393066	14083S	PARTICIPANT	\N	PRESENT	0
393071	393066	14281W	PARTICIPANT	\N	PRESENT	0
393072	393066	08045X	PARTICIPANT	\N	PRESENT	0
393073	393066	14213J	PARTICIPANT	\N	PRESENT	0
393074	393066	19447X	PARTICIPANT	\N	PRESENT	0
393075	393066	19489J	PARTICIPANT	\N	PRESENT	0
393076	393066	14031R	PARTICIPANT	\N	PRESENT	0
393077	393066	19745F	PARTICIPANT	\N	PRESENT	0
393078	393066	14331P	PARTICIPANT	\N	PRESENT	0
393079	393066	14051J	PARTICIPANT	\N	PRESENT	0
393080	393066	14157T	PARTICIPANT	\N	PRESENT	0
393748	391483	19515S	PARTICIPANT	\N	PRESENT	0
393749	391483	14087W	PARTICIPANT	\N	PRESENT	0
393750	391483	19347U	PARTICIPANT	\N	PRESENT	0
393751	391483	11049P	PARTICIPANT	\N	PRESENT	0
393752	391483	19551W	PARTICIPANT	\N	PRESENT	0
393753	391483	14241N	PARTICIPANT	\N	PRESENT	0
393754	391483	19637C	PARTICIPANT	\N	PRESENT	0
393755	391483	19335Q	PARTICIPANT	\N	PRESENT	0
393756	391483	19349W	PARTICIPANT	\N	PRESENT	0
393758	391483	19794Q	PARTICIPANT	\N	PRESENT	0
393759	391483	19737F	PARTICIPANT	\N	PRESENT	0
393760	391483	14079W	PARTICIPANT	\N	EXCUSE	0
393761	391483	14031R	PARTICIPANT	\N	EXCUSE	0
393762	391485	14079W	PARTICIPANT	\N	EXCUSE	0
393763	391485	14237S	PARTICIPANT	\N	EXCUSE	0
393764	391484	19737F	PARTICIPANT	\N	PRESENT	0
393765	391484	19551W	PARTICIPANT	\N	PRESENT	0
393766	391484	19347U	PARTICIPANT	\N	PRESENT	0
393767	391484	14031R	PARTICIPANT	\N	PRESENT	0
393768	391484	14237S	PARTICIPANT	\N	PRESENT	0
395448	392896	11080N	PARTICIPANT	\N	EXCUSE	0
395449	392896	11027H	PARTICIPANT	\N	EXCUSE	0
395451	392896	19583F	PARTICIPANT	\N	EXCUSE	0
395452	392896	19319Q	PARTICIPANT	\N	EXCUSE	0
395453	392896	19443T	PARTICIPANT	\N	EXCUSE	0
395454	392896	11054L	PARTICIPANT	\N	EXCUSE	0
395455	392896	01062T	PARTICIPANT	\N	EXCUSE	0
395456	392896	08049C	PARTICIPANT	\N	EXCUSE	0
395457	392896	11041F	PARTICIPANT	\N	EXCUSE	0
400156	397595	14030Q	PRESIDENT	0	PRESENT	0
400157	397595	08043V	PARTICIPANT	\N	PRESENT	0
400158	397595	19701S	PARTICIPANT	\N	PRESENT	0
400159	397595	11031D	PARTICIPANT	\N	PRESENT	0
400160	397595	19673G	PARTICIPANT	\N	PRESENT	0
400161	397595	08031R	PARTICIPANT	\N	PRESENT	0
400162	397595	07029T	PARTICIPANT	\N	PRESENT	0
400163	397595	08017T	PARTICIPANT	\N	PRESENT	0
400164	397595	11067R	PARTICIPANT	\N	PRESENT	0
395470	378093	08068F	PARTICIPANT	\N	PRESENT	0
395481	393744	08049C	PARTICIPANT	\N	EXCUSE	0
400165	397595	14235Q	PARTICIPANT	\N	EXCUSE	0
400167	397595	19693L	PARTICIPANT	\N	EXCUSE	0
404928	404927	19701S	PARTICIPANT	\N	PRESENT	0
404938	404929	14205J	PARTICIPANT	\N	PRESENT	0
404939	404930	14205J	PARTICIPANT	\N	PRESENT	0
404940	404931	14205J	PARTICIPANT	\N	PRESENT	0
404941	404933	14205J	PARTICIPANT	\N	PRESENT	0
404942	404934	14205J	PARTICIPANT	\N	PRESENT	0
404943	404935	14205J	PARTICIPANT	\N	PRESENT	0
404944	404936	14205J	PARTICIPANT	\N	PRESENT	0
404945	404937	14205J	PARTICIPANT	\N	PRESENT	0
404946	404932	14205J	PARTICIPANT	\N	PRESENT	0
407709	405190	04086Q	PARTICIPANT	\N	PRESENT	0
407724	405190	08011M	PARTICIPANT	\N	PRESENT	0
407725	405190	14157T	PARTICIPANT	\N	PRESENT	0
407726	405190	19701S	PARTICIPANT	\N	PRESENT	0
407727	405190	08009T	PARTICIPANT	\N	PRESENT	0
407728	405190	99004R	PARTICIPANT	\N	PRESENT	0
407729	405190	08055A	PARTICIPANT	\N	PRESENT	0
407730	405190	14031R	PARTICIPANT	\N	PRESENT	0
407767	405190	19683J	PARTICIPANT	\N	PRESENT	0
407732	405190	14021P	PARTICIPANT	\N	PRESENT	0
407733	405190	19549D	PARTICIPANT	\N	PRESENT	0
407734	405190	19760E	PARTICIPANT	\N	PRESENT	0
407735	405190	19593H	PARTICIPANT	\N	PRESENT	0
407736	405190	19794Q	PARTICIPANT	\N	PRESENT	0
407737	405190	11033F	PARTICIPANT	\N	PRESENT	0
407738	405190	19347U	PARTICIPANT	\N	PRESENT	0
407739	405190	19467C	PARTICIPANT	\N	PRESENT	0
407740	405190	14041T	PARTICIPANT	\N	PRESENT	0
407741	405190	11056N	PARTICIPANT	\N	PRESENT	0
407742	405190	14033T	PARTICIPANT	\N	PRESENT	0
407743	405190	19295A	PARTICIPANT	\N	PRESENT	0
407744	405190	17779H	PARTICIPANT	\N	PRESENT	0
407745	405190	07029T	PARTICIPANT	\N	PRESENT	0
407747	405190	14197C	PARTICIPANT	\N	PRESENT	0
407748	405190	12016W	PARTICIPANT	\N	PRESENT	0
407749	405190	08019V	PARTICIPANT	\N	PRESENT	0
407750	405190	19715Y	PARTICIPANT	\N	PRESENT	0
407751	405190	08015R	PARTICIPANT	\N	PRESENT	0
407752	405190	19599P	PARTICIPANT	\N	PRESENT	0
407753	405190	19503N	PARTICIPANT	\N	PRESENT	0
407754	405190	14061L	PARTICIPANT	\N	PRESENT	0
407755	405190	19689Q	PARTICIPANT	\N	PRESENT	0
407756	405190	19733B	PARTICIPANT	\N	PRESENT	0
407757	405190	19333N	PARTICIPANT	\N	PRESENT	0
407758	405190	19731Y	PARTICIPANT	\N	PRESENT	0
407759	405190	19591F	PARTICIPANT	\N	PRESENT	0
407760	405190	14357A	PARTICIPANT	\N	PRESENT	0
407761	405190	19301E	PARTICIPANT	\N	PRESENT	0
407762	405190	14329V	PARTICIPANT	\N	PRESENT	0
407763	405190	14229S	PARTICIPANT	\N	PRESENT	0
407764	405190	97011G	PARTICIPANT	\N	PRESENT	0
407765	405190	11090Q	PARTICIPANT	\N	PRESENT	0
407766	405190	04033B	PARTICIPANT	\N	PRESENT	0
407768	405190	14039A	PARTICIPANT	\N	PRESENT	0
407769	405190	02002K	PARTICIPANT	\N	PRESENT	0
407770	405190	19663E	PARTICIPANT	\N	PRESENT	0
407771	405190	19583F	PARTICIPANT	\N	PRESENT	0
407772	405190	19387D	PARTICIPANT	\N	PRESENT	0
407773	405190	19762G	PARTICIPANT	\N	PRESENT	0
407774	405190	19629C	PARTICIPANT	\N	PRESENT	0
407775	405190	14249W	PARTICIPANT	\N	PRESENT	0
407776	405190	11065P	PARTICIPANT	\N	PRESENT	0
407777	405190	14261S	PARTICIPANT	\N	PRESENT	0
407778	405190	98050T	PARTICIPANT	\N	PRESENT	0
407779	405190	11012A	PARTICIPANT	\N	PRESENT	0
407780	405190	14034U	PARTICIPANT	\N	PRESENT	0
407781	405190	19421M	PARTICIPANT	\N	PRESENT	0
407782	405190	11083R	PARTICIPANT	\N	PRESENT	0
407783	405190	19621T	PARTICIPANT	\N	PRESENT	0
407784	405190	19737F	PARTICIPANT	\N	PRESENT	0
407785	405190	14079W	PARTICIPANT	\N	PRESENT	0
407786	405190	19611R	PARTICIPANT	\N	PRESENT	0
407787	405190	19691J	PARTICIPANT	\N	PRESENT	0
407788	405190	14083S	PARTICIPANT	\N	PRESENT	0
407789	405190	14219Q	PARTICIPANT	\N	PRESENT	0
407790	405190	19671E	PARTICIPANT	\N	PRESENT	0
407792	405190	19479G	PARTICIPANT	\N	PRESENT	0
407793	405190	19713W	PARTICIPANT	\N	PRESENT	0
407794	405190	19319Q	PARTICIPANT	\N	PRESENT	0
407795	405190	11048N	PARTICIPANT	\N	PRESENT	0
407796	405190	19637C	PARTICIPANT	\N	PRESENT	0
407797	405190	14030Q	PARTICIPANT	\N	PRESENT	0
407799	405190	04070G	PARTICIPANT	\N	PRESENT	0
407800	405190	14205J	PARTICIPANT	\N	PRESENT	0
407801	405190	14073Q	PARTICIPANT	\N	PRESENT	0
407802	405190	19693L	PARTICIPANT	\N	PRESENT	0
407803	405190	14038Y	PARTICIPANT	\N	PRESENT	0
407804	405190	19649G	PARTICIPANT	\N	PRESENT	0
407805	405190	11109J	PARTICIPANT	\N	PRESENT	0
407809	405190	14135M	PARTICIPANT	\N	PRESENT	0
407830	405190	04043D	PARTICIPANT	\N	PRESENT	0
407845	405190	19253P	PARTICIPANT	\N	PRESENT	0
407846	405190	11085T	PARTICIPANT	\N	PRESENT	0
407854	405190	04085P	PARTICIPANT	\N	PRESENT	0
407855	405190	19673G	PARTICIPANT	\N	PRESENT	0
407858	405190	19551W	PARTICIPANT	\N	PRESENT	0
407859	405190	14169X	PARTICIPANT	\N	PRESENT	0
407860	405190	19399H	PARTICIPANT	\N	PRESENT	0
407861	405190	07033P	PARTICIPANT	\N	PRESENT	0
407862	405190	19631V	PARTICIPANT	\N	PRESENT	0
407863	405190	19289C	PARTICIPANT	\N	PRESENT	0
407864	405190	11099A	PARTICIPANT	\N	PRESENT	0
407865	405190	14053L	PARTICIPANT	\N	PRESENT	0
407866	405190	19447X	PARTICIPANT	\N	PRESENT	0
407867	405190	95041E	PARTICIPANT	\N	PRESENT	0
407868	405190	19695N	PARTICIPANT	\N	PRESENT	0
416872	416841	14051J	PARTICIPANT	\N	EXCUSE	0
416873	406929	19521Q	PARTICIPANT	\N	PRESENT	0
416874	406929	11104D	PARTICIPANT	\N	PRESENT	0
416875	406929	14281W	PARTICIPANT	\N	PRESENT	0
416876	406929	14111D	PARTICIPANT	\N	PRESENT	0
416877	406929	04018C	PARTICIPANT	\N	PRESENT	0
416878	406929	19701S	PARTICIPANT	\N	PRESENT	0
416880	406929	19573D	PARTICIPANT	\N	PRESENT	0
416881	406929	19741B	PARTICIPANT	\N	PRESENT	0
416882	406929	19715Y	PARTICIPANT	\N	PRESENT	0
416883	406929	12016W	PARTICIPANT	\N	PRESENT	0
416884	406929	11056N	PARTICIPANT	\N	PRESENT	0
416885	406929	19515S	PARTICIPANT	\N	PRESENT	0
416886	406929	04070G	PARTICIPANT	\N	PRESENT	0
416887	406929	19543W	PARTICIPANT	\N	PRESENT	0
416888	406929	11097X	PARTICIPANT	\N	PRESENT	0
416889	416879	14033T	PARTICIPANT	\N	PRESENT	0
416890	406929	04034C	PARTICIPANT	\N	PRESENT	0
416891	406929	17637T	PARTICIPANT	\N	PRESENT	0
416892	406929	04057K	PARTICIPANT	\N	PRESENT	0
416894	416893	96004D	PARTICIPANT	\N	PRESENT	0
416895	406929	19687N	PARTICIPANT	\N	PRESENT	0
416897	416896	19583F	PARTICIPANT	\N	PRESENT	0
416898	406929	14179A	PARTICIPANT	\N	PRESENT	0
416899	406929	14275Y	PARTICIPANT	\N	PRESENT	0
416900	406929	11066Q	PARTICIPANT	\N	PRESENT	0
416902	416901	04057K	PARTICIPANT	\N	PRESENT	0
416904	412275	14205J	PARTICIPANT	\N	PRESENT	0
416906	416905	04057K	PARTICIPANT	\N	PRESENT	0
416907	406929	19467C	PARTICIPANT	\N	PRESENT	0
416908	406929	04044E	PARTICIPANT	\N	PRESENT	0
416909	406929	19551W	PARTICIPANT	\N	PRESENT	0
416910	406929	19762G	PARTICIPANT	\N	PRESENT	0
416911	406929	19713W	PARTICIPANT	\N	PRESENT	0
416912	406929	04088S	PARTICIPANT	\N	PRESENT	0
416913	406929	19768N	PARTICIPANT	\N	PRESENT	0
416914	406929	14069U	PARTICIPANT	\N	PRESENT	0
416918	406929	19269X	PARTICIPANT	\N	PRESENT	0
416919	406929	16685X	PARTICIPANT	\N	PRESENT	0
416920	406929	19651A	PARTICIPANT	\N	PRESENT	0
416921	406929	08020N	PARTICIPANT	\N	PRESENT	0
416922	406929	11010L	PARTICIPANT	\N	PRESENT	0
416923	406929	19447X	PARTICIPANT	\N	PRESENT	0
416924	406929	14261S	PARTICIPANT	\N	PRESENT	0
416925	406929	11085T	PARTICIPANT	\N	PRESENT	0
416926	406929	01028R	PARTICIPANT	\N	PRESENT	0
416927	406929	14151M	PARTICIPANT	\N	PRESENT	0
416928	406929	01048V	PARTICIPANT	\N	PRESENT	0
416929	406929	11090Q	PARTICIPANT	\N	PRESENT	0
416930	406929	19611R	PARTICIPANT	\N	PRESENT	0
416955	406929	19691J	PARTICIPANT	\N	PRESENT	0
416956	406929	11012A	PARTICIPANT	\N	PRESENT	0
416980	406929	19399H	PARTICIPANT	\N	PRESENT	0
416981	406929	14357A	PARTICIPANT	\N	PRESENT	0
416982	406929	14329V	PARTICIPANT	\N	PRESENT	0
416983	406929	19631V	PARTICIPANT	\N	PRESENT	0
416984	406929	14211G	PARTICIPANT	\N	PRESENT	0
416985	406929	14026U	PARTICIPANT	\N	PRESENT	0
416987	406929	19643A	PARTICIPANT	\N	PRESENT	0
416989	406929	11070L	PARTICIPANT	\N	PRESENT	0
416990	406929	14053L	PARTICIPANT	\N	PRESENT	0
416991	406929	95067Q	PARTICIPANT	\N	PRESENT	0
417049	406931	14259Y	PARTICIPANT	\N	PRESENT	0
417050	406931	14231L	PARTICIPANT	\N	PRESENT	0
417051	406931	04038G	PARTICIPANT	\N	PRESENT	0
417052	406931	11056N	PARTICIPANT	\N	PRESENT	0
417053	406931	19565D	PARTICIPANT	\N	PRESENT	0
417054	406931	19489J	PARTICIPANT	\N	PRESENT	0
417055	406931	19719D	PARTICIPANT	\N	PRESENT	0
417056	406931	19629C	PARTICIPANT	\N	PRESENT	0
417057	406931	19651A	PARTICIPANT	\N	PRESENT	0
417058	406931	19543W	PARTICIPANT	\N	PRESENT	0
417059	406931	08024S	PARTICIPANT	\N	PRESENT	0
417060	406931	14275Y	PARTICIPANT	\N	PRESENT	0
417061	406931	07004J	PARTICIPANT	\N	PRESENT	0
417062	406931	19335Q	PARTICIPANT	\N	PRESENT	0
417063	406931	14053L	PARTICIPANT	\N	PRESENT	0
417064	406931	08034U	PARTICIPANT	\N	PRESENT	0
417065	406931	19768N	PARTICIPANT	\N	PRESENT	0
417066	406931	14329V	PARTICIPANT	\N	PRESENT	0
417067	406931	07029T	PARTICIPANT	\N	PRESENT	0
417068	406931	08019V	PARTICIPANT	\N	PRESENT	0
417069	406931	19711U	PARTICIPANT	\N	PRESENT	0
417070	406931	14179A	PARTICIPANT	\N	PRESENT	0
417071	406931	19447X	PARTICIPANT	\N	PRESENT	0
417072	406931	19715Y	PARTICIPANT	\N	PRESENT	0
417073	406931	99004R	PARTICIPANT	\N	PRESENT	0
417074	406931	14211G	PARTICIPANT	\N	PRESENT	0
417075	406931	19611R	PARTICIPANT	\N	PRESENT	0
417076	406931	19762G	PARTICIPANT	\N	PRESENT	0
417077	406931	19691J	PARTICIPANT	\N	PRESENT	0
417078	406931	14151M	PARTICIPANT	\N	PRESENT	0
417079	406931	11077T	PARTICIPANT	\N	PRESENT	0
417080	406931	19693L	PARTICIPANT	\N	PRESENT	0
417081	406931	14215L	PARTICIPANT	\N	PRESENT	0
417082	406931	19647E	PARTICIPANT	\N	PRESENT	0
417083	406931	04044E	PARTICIPANT	\N	PRESENT	0
417084	406931	19551W	PARTICIPANT	\N	PRESENT	0
417085	406931	14069U	PARTICIPANT	\N	PRESENT	0
417086	406931	11012A	PARTICIPANT	\N	PRESENT	0
417087	406931	11090Q	PARTICIPANT	\N	PRESENT	0
417088	406931	08069G	PARTICIPANT	\N	PRESENT	0
417089	406931	19585H	PARTICIPANT	\N	PRESENT	0
417090	406931	17637T	PARTICIPANT	\N	PRESENT	0
417091	406931	14205J	PARTICIPANT	\N	PRESENT	0
417092	406931	19687N	PARTICIPANT	\N	PRESENT	0
417093	406931	04071H	PARTICIPANT	\N	PRESENT	0
417094	406931	11053K	PARTICIPANT	\N	PRESENT	0
417095	406931	19643A	PARTICIPANT	\N	PRESENT	0
417108	417107	95041E	PARTICIPANT	\N	PRESENT	0
417110	417109	99004R	PARTICIPANT	\N	PRESENT	0
417112	417111	14083S	PARTICIPANT	\N	PRESENT	0
417115	417114	08010L	PARTICIPANT	\N	PRESENT	0
417118	417117	08010L	PARTICIPANT	\N	PRESENT	0
417122	417121	08010L	PARTICIPANT	\N	PRESENT	0
417126	417125	19711U	PARTICIPANT	\N	PRESENT	0
417128	417127	19711U	PARTICIPANT	\N	PRESENT	0
417047	406931	11070L	PARTICIPANT	\N	PRESENT	0
417048	406931	05008E	PARTICIPANT	\N	PRESENT	0
417130	417129	19349W	PARTICIPANT	\N	PRESENT	0
417141	417138	19349W	PARTICIPANT	\N	PRESENT	0
417157	417156	14173T	PARTICIPANT	\N	PRESENT	0
417158	417145	14103D	PARTICIPANT	\N	EXCUSE	0
417170	417169	08011M	PARTICIPANT	\N	PRESENT	0
417172	417171	12016W	PARTICIPANT	\N	PRESENT	0
417174	417173	12016W	PARTICIPANT	\N	PRESENT	0
417176	417175	12016W	PARTICIPANT	\N	PRESENT	0
417178	417177	08011M	PARTICIPANT	\N	PRESENT	0
417180	417179	08011M	PARTICIPANT	\N	PRESENT	0
417182	417181	14085U	PARTICIPANT	\N	PRESENT	0
417183	417181	14253S	PARTICIPANT	\N	PRESENT	0
417185	417184	19741B	PARTICIPANT	\N	PRESENT	0
417187	417186	08011M	PARTICIPANT	\N	PRESENT	0
417188	417145	08034U	PARTICIPANT	\N	PRESENT	0
417189	417145	04040A	PRESIDENT	0	PRESENT	0
417191	417190	96004D	PARTICIPANT	\N	PRESENT	0
417193	417192	19741B	PARTICIPANT	\N	PRESENT	0
417195	417194	96004D	PARTICIPANT	\N	PRESENT	0
417241	417240	04071H	PARTICIPANT	\N	PRESENT	0
417243	417242	08034U	PARTICIPANT	\N	PRESENT	0
417245	417244	08034U	PARTICIPANT	\N	PRESENT	0
417247	417246	11070L	PARTICIPANT	\N	PRESENT	0
417248	417246	19647E	PARTICIPANT	\N	PRESENT	0
417250	417249	19647E	PARTICIPANT	\N	PRESENT	0
417252	417251	19647E	PARTICIPANT	\N	PRESENT	0
417254	417253	19647E	PARTICIPANT	\N	PRESENT	0
417256	417255	19647E	PARTICIPANT	\N	PRESENT	0
417272	417270	01048V	PARTICIPANT	\N	PRESENT	0
417295	417294	04049K	PARTICIPANT	\N	PRESENT	0
417296	417294	14261S	PARTICIPANT	\N	PRESENT	0
417297	417294	19575F	PARTICIPANT	\N	PRESENT	0
417298	417294	14030Q	PARTICIPANT	\N	PRESENT	0
417299	417294	14105F	PARTICIPANT	\N	PRESENT	0
417300	417294	14255U	PARTICIPANT	\N	PRESENT	0
417301	417294	14187A	PARTICIPANT	\N	PRESENT	0
417302	417294	19521Q	PARTICIPANT	\N	PRESENT	0
417305	417294	14026U	PARTICIPANT	\N	PRESENT	0
417306	417294	14061L	PARTICIPANT	\N	PRESENT	0
417307	417294	19671E	PARTICIPANT	\N	PRESENT	0
417308	417294	14265W	PARTICIPANT	\N	PRESENT	0
417309	417294	04088S	PARTICIPANT	\N	PRESENT	0
417310	417294	14157T	PARTICIPANT	\N	PRESENT	0
417313	417312	14083S	PARTICIPANT	\N	PRESENT	0
417315	417312	14061L	PARTICIPANT	\N	PRESENT	0
417317	417316	14083S	PARTICIPANT	\N	PRESENT	0
417318	417316	14061L	PARTICIPANT	\N	PRESENT	0
417320	417145	14071N	PARTICIPANT	\N	PRESENT	0
417324	417322	14083S	PARTICIPANT	\N	PRESENT	0
417399	411920	10006L	PARTICIPANT	\N	PRESENT	0
396508	396507	19673G	PARTICIPANT	\N	PRESENT	0
398149	391367	19673G	PARTICIPANT	\N	PRESENT	0
398152	391367	14135M	PARTICIPANT	\N	PRESENT	0
398199	398198	04042C	PARTICIPANT	\N	PRESENT	0
398204	396628	19443T	PARTICIPANT	\N	PRESENT	0
398205	396628	04034C	PARTICIPANT	\N	PRESENT	0
400242	400241	11070L	PARTICIPANT	\N	PRESENT	0
400243	400241	19647E	PARTICIPANT	\N	PRESENT	0
400553	400552	19631V	PARTICIPANT	\N	PRESENT	0
400554	400552	14093U	PARTICIPANT	\N	PRESENT	0
400555	400552	01048V	PARTICIPANT	\N	PRESENT	0
400556	400552	14257W	PARTICIPANT	\N	PRESENT	0
400223	393609	11072N	PARTICIPANT	\N	PRESENT	0
400224	393609	08011M	PARTICIPANT	\N	PRESENT	0
400568	396241	01058X	PARTICIPANT	\N	PRESENT	0
400574	393777	01058X	PARTICIPANT	\N	PRESENT	0
400808	400807	14026U	PARTICIPANT	\N	PRESENT	0
400809	400807	19717B	PARTICIPANT	\N	PRESENT	0
401543	400285	14327T	PARTICIPANT	\N	PRESENT	0
401544	400285	14331P	PARTICIPANT	\N	PRESENT	0
401545	400285	19479G	PARTICIPANT	\N	PRESENT	0
401546	400285	19531S	PARTICIPANT	\N	PRESENT	0
401547	400285	89017R	PARTICIPANT	\N	PRESENT	0
401548	400285	99004R	PARTICIPANT	\N	PRESENT	0
401549	400285	14159V	PARTICIPANT	\N	PRESENT	0
401550	400285	88008L	PARTICIPANT	\N	PRESENT	0
401551	400285	19671E	PARTICIPANT	\N	PRESENT	0
401552	400285	14173T	PARTICIPANT	\N	PRESENT	0
401553	400285	04086Q	PARTICIPANT	\N	PRESENT	0
401554	400285	19545Y	PARTICIPANT	\N	PRESENT	0
401656	400285	19711U	PARTICIPANT	\N	PRESENT	0
401657	400285	19693L	PARTICIPANT	\N	PRESENT	0
401658	400285	14051J	PARTICIPANT	\N	PRESENT	0
401659	401557	04033B	PARTICIPANT	\N	PRESENT	0
401660	401557	07033P	PARTICIPANT	\N	PRESENT	0
401661	401557	19335Q	PARTICIPANT	\N	PRESENT	0
401662	401557	14251Q	PARTICIPANT	\N	PRESENT	0
401663	401557	19621T	PARTICIPANT	\N	PRESENT	0
401665	401664	19515S	PARTICIPANT	\N	PRESENT	0
401666	401664	19575F	PARTICIPANT	\N	PRESENT	0
401667	401664	11081P	PARTICIPANT	\N	PRESENT	0
401668	401664	19367Y	PARTICIPANT	\N	PRESENT	0
401669	401664	14069U	PARTICIPANT	\N	PRESENT	0
401670	401664	19383Y	PARTICIPANT	\N	PRESENT	0
401671	401664	08020N	PARTICIPANT	\N	PRESENT	0
401672	401664	19782L	PARTICIPANT	\N	PRESENT	0
401673	401664	14207L	PARTICIPANT	\N	PRESENT	0
401674	401664	14038Y	PARTICIPANT	\N	PRESENT	0
401675	401664	08028W	PARTICIPANT	\N	PRESENT	0
401676	401664	19467C	PARTICIPANT	\N	PRESENT	0
401677	401664	18083K	PARTICIPANT	\N	PRESENT	0
401678	401664	14357A	PARTICIPANT	\N	PRESENT	0
401679	401664	19693L	PARTICIPANT	\N	PRESENT	0
401680	401664	14217N	PARTICIPANT	\N	PRESENT	0
401681	401664	01024M	PARTICIPANT	\N	PRESENT	0
401682	401664	19507S	PARTICIPANT	\N	PRESENT	0
401683	401664	14187A	PARTICIPANT	\N	PRESENT	0
401684	401664	01025N	PARTICIPANT	\N	PRESENT	0
401685	401664	19727D	PARTICIPANT	\N	PRESENT	0
401686	401664	14033T	PARTICIPANT	\N	PRESENT	0
401687	401664	14213J	PARTICIPANT	\N	PRESENT	0
401688	401664	19551W	PARTICIPANT	\N	PRESENT	0
401689	401664	19511N	PARTICIPANT	\N	PRESENT	0
401690	401664	11099A	PARTICIPANT	\N	PRESENT	0
401691	401664	04049K	PARTICIPANT	\N	PRESENT	0
401692	401664	08015R	PARTICIPANT	\N	PRESENT	0
401693	401664	19369B	PARTICIPANT	\N	PRESENT	0
401694	401664	14109K	PARTICIPANT	\N	PRESENT	0
401695	401664	14257W	PARTICIPANT	\N	PRESENT	0
401696	401664	14265W	PARTICIPANT	\N	PRESENT	0
401697	401664	19745F	PARTICIPANT	\N	PRESENT	0
401698	401664	04088S	PARTICIPANT	\N	PRESENT	0
401699	401664	19349W	PARTICIPANT	\N	PRESENT	0
401700	401664	19269X	PARTICIPANT	\N	PRESENT	0
401701	401664	11097X	PARTICIPANT	\N	PRESENT	0
401702	401664	19762G	PARTICIPANT	\N	PRESENT	0
401703	401664	05012A	PARTICIPANT	\N	PRESENT	0
401704	401664	11090Q	PARTICIPANT	\N	PRESENT	0
401705	401664	19735D	PARTICIPANT	\N	PRESENT	0
401706	401664	08045X	PARTICIPANT	\N	PRESENT	0
401707	401664	96004D	PARTICIPANT	\N	PRESENT	0
401708	401664	19768N	PARTICIPANT	\N	PRESENT	0
401709	401664	17583W	PARTICIPANT	\N	PRESENT	0
401710	400285	01057W	PARTICIPANT	\N	PRESENT	0
401711	400285	11070L	PARTICIPANT	\N	PRESENT	0
401712	400285	19741B	PARTICIPANT	\N	PRESENT	0
401715	401664	19798U	PARTICIPANT	\N	PRESENT	0
401716	393617	11070L	PARTICIPANT	\N	PRESENT	0
401717	393617	17589D	PARTICIPANT	\N	PRESENT	0
401718	393617	19721W	PARTICIPANT	\N	PRESENT	0
401719	393617	19319Q	PARTICIPANT	\N	PRESENT	0
401720	393617	19511N	PARTICIPANT	\N	PRESENT	0
401721	393617	14205J	PARTICIPANT	\N	PRESENT	0
401722	393617	19333N	PARTICIPANT	\N	PRESENT	0
401723	393617	19251M	PARTICIPANT	\N	PRESENT	0
401724	393617	19711U	PARTICIPANT	\N	PRESENT	0
401725	393617	18083K	PARTICIPANT	\N	PRESENT	0
401726	393617	04085P	PARTICIPANT	\N	PRESENT	0
401727	393617	19503N	PARTICIPANT	\N	PRESENT	0
401728	393617	19768N	PARTICIPANT	\N	PRESENT	0
401729	393617	19515S	PARTICIPANT	\N	PRESENT	0
401730	393617	19687N	PARTICIPANT	\N	PRESENT	0
401731	393617	08045X	PARTICIPANT	\N	PRESENT	0
401732	393617	19782L	PARTICIPANT	\N	PRESENT	0
401733	393617	14267Y	PARTICIPANT	\N	PRESENT	0
401734	393617	04049K	PARTICIPANT	\N	PRESENT	0
401735	393617	08060W	PARTICIPANT	\N	PRESENT	0
401736	393617	14197C	PARTICIPANT	\N	PRESENT	0
401738	393617	11067R	PARTICIPANT	\N	PRESENT	0
401739	393617	14207L	PARTICIPANT	\N	PRESENT	0
401740	393617	04088S	PARTICIPANT	\N	PRESENT	0
401741	393617	14051J	PARTICIPANT	\N	PRESENT	0
401742	393617	80013X	PARTICIPANT	\N	PRESENT	0
401745	393617	11066Q	PARTICIPANT	\N	PRESENT	0
401746	393617	14063N	PARTICIPANT	\N	PRESENT	0
401747	393617	19443T	PARTICIPANT	\N	PRESENT	0
401748	393617	11048N	PARTICIPANT	\N	PRESENT	0
401749	393617	08047A	PARTICIPANT	\N	PRESENT	0
401750	393617	14061L	PARTICIPANT	\N	PRESENT	0
401751	393617	11033F	PARTICIPANT	\N	PRESENT	0
401752	393617	14031R	PARTICIPANT	\N	PRESENT	0
401753	393617	14187A	PARTICIPANT	\N	PRESENT	0
401754	393617	19551W	PARTICIPANT	\N	PRESENT	0
401755	393617	19599P	PARTICIPANT	\N	PRESENT	0
401756	393617	11065P	PARTICIPANT	\N	PRESENT	0
401757	393617	19253P	PARTICIPANT	\N	PRESENT	0
401758	393617	12041X	PARTICIPANT	\N	PRESENT	0
401759	393617	19629C	PARTICIPANT	\N	PRESENT	0
401760	393617	19369B	PARTICIPANT	\N	PRESENT	0
401761	393617	19335Q	PARTICIPANT	\N	PRESENT	0
401762	393617	19695N	PARTICIPANT	\N	PRESENT	0
401763	393617	19269X	PARTICIPANT	\N	PRESENT	0
401764	393617	01025N	PARTICIPANT	\N	PRESENT	0
401765	393617	08068F	PARTICIPANT	\N	PRESENT	0
401766	393617	11090Q	PARTICIPANT	\N	PRESENT	0
401767	393617	08034U	PARTICIPANT	\N	PRESENT	0
401768	393617	19533U	PARTICIPANT	\N	PRESENT	0
401769	393617	97011G	PARTICIPANT	\N	PRESENT	0
401770	393617	04033B	PARTICIPANT	\N	PRESENT	0
401771	393617	19671E	PARTICIPANT	\N	PRESENT	0
401772	393617	14169X	PARTICIPANT	\N	PRESENT	0
401773	393617	14151M	PARTICIPANT	\N	PRESENT	0
401774	393617	11056N	PARTICIPANT	\N	PRESENT	0
401775	393617	19387D	PARTICIPANT	\N	PRESENT	0
401776	393617	14231L	PARTICIPANT	\N	PRESENT	0
401777	393617	14217N	PARTICIPANT	\N	PRESENT	0
401778	393617	08020N	PARTICIPANT	\N	PRESENT	0
401779	393617	95062K	PARTICIPANT	\N	PRESENT	0
401780	393617	19733B	PARTICIPANT	\N	PRESENT	0
401781	393617	14033T	PARTICIPANT	\N	PRESENT	0
401782	393617	19507S	PARTICIPANT	\N	PRESENT	0
401783	393617	19347U	PARTICIPANT	\N	PRESENT	0
401784	393617	08038Y	PARTICIPANT	\N	PRESENT	0
401785	393617	11085T	PARTICIPANT	\N	PRESENT	0
401786	393617	11103C	PARTICIPANT	\N	PRESENT	0
401787	393617	19737F	PARTICIPANT	\N	PRESENT	0
401788	393617	08017T	PARTICIPANT	\N	PRESENT	0
401789	393617	19747H	PARTICIPANT	\N	PRESENT	0
401790	393617	14249W	PARTICIPANT	\N	PRESENT	0
401791	393617	14053L	PARTICIPANT	\N	PRESENT	0
401792	393617	14157T	PARTICIPANT	\N	PRESENT	0
401793	393617	14030Q	PARTICIPANT	\N	PRESENT	0
401794	393617	01058X	PARTICIPANT	\N	PRESENT	0
401795	393617	95037J	PARTICIPANT	\N	PRESENT	0
401796	393617	19349W	PARTICIPANT	\N	PRESENT	0
401797	393617	19798U	PARTICIPANT	\N	PRESENT	0
401798	393617	19467C	PARTICIPANT	\N	PRESENT	0
401799	393617	14029X	PARTICIPANT	\N	PRESENT	0
410821	410820	14121F	PARTICIPANT	\N	PRESENT	0
410823	410822	14121F	PARTICIPANT	\N	PRESENT	0
417758	417481	08009T	PARTICIPANT	\N	PRESENT	0
417759	417481	11101A	PARTICIPANT	\N	PRESENT	0
417760	417481	11053K	PARTICIPANT	\N	PRESENT	0
417761	417481	19611R	PARTICIPANT	\N	PRESENT	0
417762	417481	04008A	PARTICIPANT	\N	PRESENT	0
417763	417481	17637T	PARTICIPANT	\N	PRESENT	0
417764	417481	19515S	PARTICIPANT	\N	PRESENT	0
417765	417481	14259Y	PARTICIPANT	\N	PRESENT	0
417766	417481	14135M	PARTICIPANT	\N	PRESENT	0
417767	417481	05008E	PARTICIPANT	\N	PRESENT	0
417768	417481	14083S	PARTICIPANT	\N	PRESENT	0
417769	417481	19737F	PARTICIPANT	\N	PRESENT	0
417770	417481	11048N	PARTICIPANT	\N	PRESENT	0
417771	417481	19721W	PARTICIPANT	\N	PRESENT	0
417772	417481	19723Y	PARTICIPANT	\N	PRESENT	0
417773	417481	16685X	PARTICIPANT	\N	PRESENT	0
417774	417481	14029X	PARTICIPANT	\N	PRESENT	0
417775	417481	14042U	PARTICIPANT	\N	PRESENT	0
417776	417481	19479G	PARTICIPANT	\N	PRESENT	0
417777	417481	19441R	PARTICIPANT	\N	PRESENT	0
417778	417481	14205J	PARTICIPANT	\N	PRESENT	0
417779	417481	14275Y	PARTICIPANT	\N	PRESENT	0
417780	417481	14103D	PARTICIPANT	\N	PRESENT	0
417781	417481	89017R	PARTICIPANT	\N	PRESENT	0
417782	417481	14071N	PARTICIPANT	\N	PRESENT	0
417783	417481	19521Q	PARTICIPANT	\N	PRESENT	0
417784	417481	11026G	PARTICIPANT	\N	PRESENT	0
417785	417481	11104D	PARTICIPANT	\N	PRESENT	0
417786	417481	19749K	PARTICIPANT	\N	PRESENT	0
417787	417481	19745F	PARTICIPANT	\N	PRESENT	0
417788	417481	11070L	PARTICIPANT	\N	PRESENT	0
417789	417481	07004J	PARTICIPANT	\N	PRESENT	0
417790	417481	19289C	PARTICIPANT	\N	PRESENT	0
417791	417481	14021P	PARTICIPANT	\N	PRESENT	0
417792	417481	11085T	PARTICIPANT	\N	PRESENT	0
417793	417481	04040A	PARTICIPANT	\N	PRESENT	0
417794	417481	04070G	PARTICIPANT	\N	PRESENT	0
417795	417481	01025N	PARTICIPANT	\N	PRESENT	0
417796	417481	14030Q	PARTICIPANT	\N	PRESENT	0
417797	417481	01024M	PARTICIPANT	\N	PRESENT	0
417798	417481	14327T	PARTICIPANT	\N	PRESENT	0
417799	417481	01043Q	PARTICIPANT	\N	PRESENT	0
417800	417481	14034U	PARTICIPANT	\N	PRESENT	0
417801	417481	14109K	PARTICIPANT	\N	PRESENT	0
417802	417481	08073C	PARTICIPANT	\N	PRESENT	0
417806	417481	08068F	PARTICIPANT	\N	PRESENT	0
417804	417481	14195A	PARTICIPANT	\N	PRESENT	0
417805	417481	02002K	PARTICIPANT	\N	PRESENT	0
417807	417481	19581D	PARTICIPANT	\N	PRESENT	0
417808	417481	95067Q	PARTICIPANT	\N	PRESENT	0
417809	417481	14179A	PARTICIPANT	\N	PRESENT	0
417810	417481	04042C	PARTICIPANT	\N	PRESENT	0
417811	417481	14227Q	PARTICIPANT	\N	PRESENT	0
417812	417481	01062T	PARTICIPANT	\N	PRESENT	0
417813	417481	11043H	PARTICIPANT	\N	PRESENT	0
417814	417145	92040Q	PARTICIPANT	\N	EXCUSE	0
417815	417145	95067Q	PARTICIPANT	\N	EXCUSE	0
417816	417481	04047H	PARTICIPANT	\N	PRESENT	0
417817	417481	14087W	PARTICIPANT	\N	PRESENT	0
417821	417481	08039A	PARTICIPANT	\N	PRESENT	0
417819	417481	04092N	PARTICIPANT	\N	PRESENT	0
417820	417481	14219Q	PARTICIPANT	\N	PRESENT	0
417822	417481	14237S	PARTICIPANT	\N	PRESENT	0
418119	414857	86034E	PARTICIPANT	\N	PRESENT	0
418121	418120	04086Q	PARTICIPANT	\N	PRESENT	0
418126	414857	12041X	PARTICIPANT	\N	PRESENT	0
418127	416673	14327T	PARTICIPANT	\N	PRESENT	0
418124	418120	04040A	PARTICIPANT	\N	PRESENT	0
418125	418120	19585H	PARTICIPANT	\N	PRESENT	0
418128	416673	14331P	PARTICIPANT	\N	PRESENT	0
418129	416673	19479G	PARTICIPANT	\N	PRESENT	0
418130	416673	95041E	PARTICIPANT	\N	PRESENT	0
418131	416673	19711U	PARTICIPANT	\N	PRESENT	0
418132	416673	08034U	PARTICIPANT	\N	PRESENT	0
418133	416673	08069G	PARTICIPANT	\N	PRESENT	0
418134	416673	19687N	PARTICIPANT	\N	PRESENT	0
418135	416673	11074Q	PRESIDENT	0	PRESENT	0
418136	416673	89017R	PARTICIPANT	\N	PRESENT	0
418137	416673	08014Q	PARTICIPANT	\N	PRESENT	0
418138	416673	14034U	PARTICIPANT	\N	PRESENT	0
418139	416673	11110B	PARTICIPANT	\N	PRESENT	0
418140	416673	14173T	PARTICIPANT	\N	PRESENT	0
418141	416673	04086Q	PARTICIPANT	\N	PRESENT	0
418142	416673	07004J	PARTICIPANT	\N	PRESENT	0
418143	416673	19349W	PARTICIPANT	\N	PRESENT	0
418144	416673	19741B	PARTICIPANT	\N	PRESENT	0
418145	416673	14121F	PARTICIPANT	\N	PRESENT	0
418146	416673	99004R	PARTICIPANT	\N	PRESENT	0
418147	416673	14159V	PARTICIPANT	\N	EXCUSE	0
418148	414857	98018T	PARTICIPANT	\N	PRESENT	0
418149	414857	19820Y	PARTICIPANT	\N	PRESENT	0
418150	414857	04035D	PARTICIPANT	\N	PRESENT	0
418151	414857	95030B	PARTICIPANT	\N	PRESENT	0
418152	414857	19515S	PARTICIPANT	\N	PRESENT	0
418153	414857	14191V	PARTICIPANT	\N	PRESENT	0
418154	414857	19673G	PARTICIPANT	\N	PRESENT	0
418155	414857	19447X	PARTICIPANT	\N	PRESENT	0
418156	414857	11033F	PARTICIPANT	\N	PRESENT	0
418157	414857	04042C	PARTICIPANT	\N	PRESENT	0
418158	414857	14235Q	PARTICIPANT	\N	PRESENT	0
418159	414857	14187A	PARTICIPANT	\N	PRESENT	0
418160	414857	08058D	PARTICIPANT	\N	PRESENT	0
418161	414857	19747H	PARTICIPANT	\N	PRESENT	0
418162	414857	19647E	PARTICIPANT	\N	PRESENT	0
418163	414857	19333N	PARTICIPANT	\N	PRESENT	0
418164	414857	14237S	PARTICIPANT	\N	PRESENT	0
418165	414857	19725B	PARTICIPANT	\N	PRESENT	0
418166	414857	14081Q	PARTICIPANT	\N	PRESENT	0
418167	414857	80013X	PARTICIPANT	\N	PRESENT	0
418168	414857	97011G	PARTICIPANT	\N	PRESENT	0
418169	414857	14197C	PARTICIPANT	\N	PRESENT	0
418170	414857	14147R	PARTICIPANT	\N	PRESENT	0
418171	414857	01062T	PARTICIPANT	\N	PRESENT	0
418172	414857	17583W	PARTICIPANT	\N	PRESENT	0
418173	414857	14028W	PARTICIPANT	\N	PRESENT	0
418174	414857	14021P	PARTICIPANT	\N	PRESENT	0
418175	414857	14059S	PARTICIPANT	\N	PRESENT	0
418176	414857	08055A	PARTICIPANT	\N	PRESENT	0
418177	414857	04069P	PARTICIPANT	\N	PRESENT	0
418178	414857	01028R	PARTICIPANT	\N	PRESENT	0
418179	414857	19715Y	PARTICIPANT	\N	PRESENT	0
418180	414857	14223L	PARTICIPANT	\N	PRESENT	0
418181	414857	19651A	PARTICIPANT	\N	PRESENT	0
418182	414857	98029W	PARTICIPANT	\N	PRESENT	0
418183	414857	19621T	PARTICIPANT	\N	PRESENT	0
418184	414857	14261S	PARTICIPANT	\N	PRESENT	0
418185	414857	19703U	PARTICIPANT	\N	PRESENT	0
418186	414857	98022P	PARTICIPANT	\N	PRESENT	0
418187	414857	19545Y	PARTICIPANT	\N	PRESENT	0
418188	414857	19533U	PARTICIPANT	\N	PRESENT	0
418189	414857	19387D	PARTICIPANT	\N	PRESENT	0
418190	414857	14133K	PARTICIPANT	\N	PRESENT	0
418191	414857	19619A	PARTICIPANT	\N	PRESENT	0
418192	414857	10015M	PARTICIPANT	\N	PRESENT	0
418193	414857	19721W	PARTICIPANT	\N	PRESENT	0
418194	414857	95067Q	PARTICIPANT	\N	PRESENT	0
418195	414857	19699S	PARTICIPANT	\N	PRESENT	0
418196	414857	04018C	PARTICIPANT	\N	PRESENT	0
418197	414857	19737F	PARTICIPANT	\N	PRESENT	0
418198	414857	14069U	PARTICIPANT	\N	PRESENT	0
418199	414857	04043D	PARTICIPANT	\N	PRESENT	0
418200	414857	11064N	PARTICIPANT	\N	PRESENT	0
418201	414857	14195A	PARTICIPANT	\N	PRESENT	0
418202	414857	19441R	PARTICIPANT	\N	PRESENT	0
418203	414857	08020N	PARTICIPANT	\N	PRESENT	0
418204	414857	08018U	PARTICIPANT	\N	PRESENT	0
418205	414857	14041T	PARTICIPANT	\N	PRESENT	0
418206	414857	04088S	PARTICIPANT	\N	PRESENT	0
418207	414857	14029X	PARTICIPANT	\N	PRESENT	0
418208	414857	19467C	PARTICIPANT	\N	PRESENT	0
418209	414857	19573D	PARTICIPANT	\N	PRESENT	0
418210	414857	19794Q	PARTICIPANT	\N	PRESENT	0
418211	414857	11010L	PARTICIPANT	\N	PRESENT	0
418212	414857	19798U	PARTICIPANT	\N	PRESENT	0
418213	414857	08047A	PARTICIPANT	\N	PRESENT	0
418214	414857	14255U	PARTICIPANT	\N	PRESENT	0
418215	414857	04033B	PARTICIPANT	\N	PRESENT	0
418216	414857	11070L	PARTICIPANT	\N	PRESENT	0
418217	414857	01060R	PARTICIPANT	\N	PRESENT	0
418218	414857	08056B	PARTICIPANT	\N	PRESENT	0
418219	414857	01024M	PARTICIPANT	\N	PRESENT	0
418220	414857	19745F	PARTICIPANT	\N	PRESENT	0
418221	414857	95037J	PARTICIPANT	\N	PRESENT	0
418222	414857	14267Y	PARTICIPANT	\N	PRESENT	0
418223	414857	14115H	PARTICIPANT	\N	PRESENT	0
418224	414857	08062Y	PARTICIPANT	\N	PRESENT	0
418225	414857	19729F	PARTICIPANT	\N	PRESENT	0
392898	392726	19563B	PARTICIPANT	\N	EXCUSE	0
395395	395394	17589D	PARTICIPANT	\N	EXCUSE	0
395396	395394	19591F	PARTICIPANT	\N	EXCUSE	0
395397	395394	01043Q	PARTICIPANT	\N	EXCUSE	0
395398	395394	11081P	PARTICIPANT	\N	EXCUSE	0
395399	395394	19768N	PARTICIPANT	\N	PRESENT	0
395400	395394	80013X	PARTICIPANT	\N	PRESENT	0
395401	395394	19631V	PARTICIPANT	\N	PRESENT	0
395402	395394	19413M	PARTICIPANT	\N	PRESENT	0
395403	395394	14081Q	PARTICIPANT	\N	PRESENT	0
395404	395394	14357A	PARTICIPANT	\N	PRESENT	0
395405	395394	19441R	PARTICIPANT	\N	PRESENT	0
395406	395394	19515S	PARTICIPANT	\N	PRESENT	0
395407	395394	19782L	PARTICIPANT	\N	PRESENT	0
395408	395394	11090Q	PARTICIPANT	\N	EXCUSE	0
395409	395394	14197C	PARTICIPANT	\N	PRESENT	0
395410	395394	19369B	PARTICIPANT	\N	PRESENT	0
395411	395394	08015R	PARTICIPANT	\N	PRESENT	0
395412	395394	08019V	PARTICIPANT	\N	PRESENT	0
395413	395394	04049K	PRESIDENT	\N	PRESENT	0
395414	395394	19705W	PARTICIPANT	\N	PRESENT	0
395415	395394	08021P	PARTICIPANT	\N	PRESENT	0
395416	395394	11099A	PARTICIPANT	\N	PRESENT	0
395417	395394	14187A	PARTICIPANT	\N	PRESENT	0
395418	395394	08038Y	PARTICIPANT	\N	PRESENT	0
395419	395394	14135M	PARTICIPANT	\N	PRESENT	0
395420	395394	19467C	PARTICIPANT	\N	PRESENT	0
395421	395394	19563B	PARTICIPANT	\N	PRESENT	0
395422	395394	14265W	PARTICIPANT	\N	PRESENT	0
395423	395394	19511N	PARTICIPANT	\N	PRESENT	0
395424	395394	08028W	PARTICIPANT	\N	PRESENT	0
395425	395394	14205J	PARTICIPANT	\N	PRESENT	0
395426	395394	04088S	PARTICIPANT	\N	PRESENT	0
395427	395394	19295A	PARTICIPANT	\N	PRESENT	0
395428	395394	19269X	PARTICIPANT	\N	PRESENT	0
395429	395394	01025N	PARTICIPANT	\N	PRESENT	0
395430	395394	14033T	PARTICIPANT	\N	PRESENT	0
395431	395394	08062Y	PARTICIPANT	\N	PRESENT	0
395432	395394	19695N	PARTICIPANT	\N	PRESENT	0
395433	395394	14257W	PARTICIPANT	\N	PRESENT	0
395434	395394	08068F	PARTICIPANT	\N	EXCUSE	0
395435	395394	04043D	PARTICIPANT	\N	PRESENT	0
395436	395394	19619A	PARTICIPANT	\N	PRESENT	0
395437	395394	19747H	PARTICIPANT	\N	PRESENT	0
395438	395394	14207L	PARTICIPANT	\N	PRESENT	0
395439	395394	14115H	PARTICIPANT	\N	PRESENT	0
395440	395394	19507S	PARTICIPANT	\N	PRESENT	0
396137	393744	19525U	PARTICIPANT	\N	PRESENT	0
396138	393744	14231L	PARTICIPANT	\N	EXCUSE	0
396139	393744	01057W	PARTICIPANT	\N	PRESENT	0
396140	393744	08010L	PARTICIPANT	\N	PRESENT	0
396141	393744	14063N	PARTICIPANT	\N	PRESENT	0
396142	393744	05012A	PARTICIPANT	\N	PRESENT	0
396143	393744	19735D	PARTICIPANT	\N	PRESENT	0
398330	398329	14187A	PARTICIPANT	\N	PRESENT	0
398331	398329	19575F	PARTICIPANT	\N	PRESENT	0
398332	398329	14105F	PARTICIPANT	\N	PRESENT	0
398333	398329	04049K	PARTICIPANT	\N	PRESENT	0
398334	398329	14265W	PARTICIPANT	\N	PRESENT	0
398335	398329	04088S	PARTICIPANT	\N	PRESENT	0
398336	398329	14051J	PARTICIPANT	\N	PRESENT	0
398337	398329	08039A	PARTICIPANT	\N	PRESENT	0
398346	396492	05012A	PARTICIPANT	\N	PRESENT	0
398348	398347	14079W	PARTICIPANT	\N	PRESENT	0
398355	398347	17637T	PARTICIPANT	\N	PRESENT	0
398350	398347	95030B	PARTICIPANT	\N	PRESENT	0
398351	398347	19521Q	PARTICIPANT	\N	PRESENT	0
398353	398347	19711U	PARTICIPANT	\N	PRESENT	0
398354	398347	01048V	PARTICIPANT	\N	PRESENT	0
398356	398347	98050T	PARTICIPANT	\N	PRESENT	0
398357	398347	95067Q	PARTICIPANT	\N	PRESENT	0
398358	398347	11026G	PARTICIPANT	\N	PRESENT	0
398359	398347	19503N	PARTICIPANT	\N	PRESENT	0
398360	397651	14028W	PARTICIPANT	\N	EXCUSE	0
400605	400604	08011M	PARTICIPANT	\N	PRESENT	0
400615	400614	11053K	PARTICIPANT	\N	PRESENT	0
405119	404768	11083R	PARTICIPANT	\N	PRESENT	0
405122	405121	14107H	PARTICIPANT	\N	EXCUSE	0
405123	405121	08073C	PARTICIPANT	\N	EXCUSE	0
405124	405121	14071N	PARTICIPANT	\N	PRESENT	0
405125	405121	04057K	PARTICIPANT	\N	PRESENT	0
405126	405121	19441R	PARTICIPANT	\N	PRESENT	0
405127	405121	08015R	PARTICIPANT	\N	EXCUSE	0
405128	405121	19531S	PARTICIPANT	\N	EXCUSE	0
405129	405121	08069G	PARTICIPANT	\N	EXCUSE	0
405130	405121	19725B	PRESIDENT	0	PRESENT	0
405131	405121	14033T	PARTICIPANT	\N	EXCUSE	0
405132	405121	14327T	PARTICIPANT	\N	PRESENT	0
405133	405121	11056N	PARTICIPANT	\N	PRESENT	0
405134	405121	14030Q	PARTICIPANT	\N	EXCUSE	0
406663	405335	08009T	PRESIDENT	0	PRESENT	0
406664	405335	14051J	PARTICIPANT	\N	EXCUSE	0
406665	405335	02002K	PARTICIPANT	\N	EXCUSE	0
406666	405335	19333N	PARTICIPANT	\N	PRESENT	0
406667	405335	14157T	PARTICIPANT	\N	PRESENT	0
406668	405335	08055A	PARTICIPANT	\N	PRESENT	0
406669	405335	19599P	PARTICIPANT	\N	PRESENT	0
406670	405335	19383Y	PARTICIPANT	\N	PRESENT	0
406671	405335	14038Y	PARTICIPANT	\N	PRESENT	0
406672	405335	19794Q	PARTICIPANT	\N	PRESENT	0
406673	405335	14031R	PARTICIPANT	\N	PRESENT	0
406674	405335	19387D	PARTICIPANT	\N	PRESENT	0
406675	405335	14219Q	PARTICIPANT	\N	PRESENT	0
406676	405335	14221J	PARTICIPANT	\N	PRESENT	0
406677	405335	14169X	PARTICIPANT	\N	PRESENT	0
406678	405335	15447F	PARTICIPANT	\N	PRESENT	0
406679	405335	14237S	PARTICIPANT	\N	PRESENT	0
406680	405335	19503N	PARTICIPANT	\N	PRESENT	0
406681	405335	19347U	PARTICIPANT	\N	PRESENT	0
406682	405335	19739H	PARTICIPANT	\N	PRESENT	0
406683	405335	17583W	PARTICIPANT	\N	PRESENT	0
406684	405335	19713W	PARTICIPANT	\N	PRESENT	0
406685	405335	19737F	PARTICIPANT	\N	PRESENT	0
406686	405335	04097T	PARTICIPANT	\N	PRESENT	0
406687	405327	11067R	PARTICIPANT	\N	PRESENT	0
406688	405327	19565D	PARTICIPANT	\N	PRESENT	0
406689	405327	19798U	PARTICIPANT	\N	PRESENT	0
406690	405327	11097X	PARTICIPANT	\N	PRESENT	0
406691	405327	19415P	PARTICIPANT	\N	PRESENT	0
406692	405327	14223L	PARTICIPANT	\N	PRESENT	0
406693	405327	14227Q	PARTICIPANT	\N	PRESENT	0
406694	405327	17779H	PARTICIPANT	\N	PRESENT	0
406695	405327	19703U	PARTICIPANT	\N	PRESENT	0
406696	405327	19553Y	PARTICIPANT	\N	PRESENT	0
406697	405327	11031D	PARTICIPANT	\N	PRESENT	0
406698	405327	14281W	PARTICIPANT	\N	PRESENT	0
406699	405327	19679N	PARTICIPANT	\N	PRESENT	0
406700	405327	14042U	PARTICIPANT	\N	PRESENT	0
406701	405327	14195A	PARTICIPANT	\N	PRESENT	0
406702	405327	08048B	PARTICIPANT	\N	PRESENT	0
406703	405327	14213J	PARTICIPANT	\N	PRESENT	0
406704	405327	19367Y	PARTICIPANT	\N	PRESENT	0
406705	405327	14261S	PARTICIPANT	\N	PRESENT	0
406706	405327	19683J	PARTICIPANT	\N	PRESENT	0
406707	405327	19521Q	PARTICIPANT	\N	PRESENT	0
406708	405327	98024R	PARTICIPANT	\N	PRESENT	0
406709	405327	19527W	PARTICIPANT	\N	PRESENT	0
406710	405327	04092N	PRESIDENT	0	PRESENT	0
406711	405327	08052W	PARTICIPANT	\N	PRESENT	0
406712	405327	19301E	PARTICIPANT	\N	PRESENT	0
406713	405327	19691J	PARTICIPANT	\N	PRESENT	0
406714	405327	19715Y	PARTICIPANT	\N	PRESENT	0
406715	405327	19723Y	PARTICIPANT	\N	PRESENT	0
406716	405327	19727D	PARTICIPANT	\N	PRESENT	0
406717	405327	14119M	PARTICIPANT	\N	PRESENT	0
406718	405327	11103C	PARTICIPANT	\N	PRESENT	0
406719	405327	14071N	PARTICIPANT	\N	PRESENT	0
406720	405327	19760E	PARTICIPANT	\N	PRESENT	0
406721	405327	14355X	PARTICIPANT	\N	EXCUSE	0
406722	405327	11045K	PARTICIPANT	\N	EXCUSE	0
406723	405327	08041T	PARTICIPANT	\N	EXCUSE	0
406853	404870	14021P	PARTICIPANT	\N	PRESENT	0
406856	405335	05012A	PARTICIPANT	\N	PRESENT	0
406857	405335	17637T	PARTICIPANT	\N	PRESENT	0
406858	405335	11065P	PARTICIPANT	\N	PRESENT	0
406893	405336	19383Y	PARTICIPANT	\N	PRESENT	0
406894	405336	19333N	PARTICIPANT	\N	PRESENT	0
406895	405336	19701S	PARTICIPANT	\N	PRESENT	0
406896	405336	19794Q	PARTICIPANT	\N	PRESENT	0
406898	405336	19387D	PARTICIPANT	\N	PRESENT	0
406899	405336	14219Q	PARTICIPANT	\N	PRESENT	0
406900	405336	19599P	PARTICIPANT	\N	PRESENT	0
406901	405336	19637C	PARTICIPANT	\N	PRESENT	0
406902	405336	14237S	PARTICIPANT	\N	PRESENT	0
406903	405336	19551W	PARTICIPANT	\N	PRESENT	0
406904	405336	05012A	PARTICIPANT	\N	PRESENT	0
406905	405336	19503N	PARTICIPANT	\N	PRESENT	0
406906	405336	19347U	PARTICIPANT	\N	PRESENT	0
417400	411920	11067R	PARTICIPANT	\N	PRESENT	0
418405	406964	05008E	PARTICIPANT	\N	PRESENT	0
417447	417388	14053L	PARTICIPANT	\N	PRESENT	0
417454	414076	19553Y	PARTICIPANT	\N	EXCUSE	0
417455	417388	98035U	PARTICIPANT	\N	PRESENT	0
417456	417388	14111D	PARTICIPANT	\N	PRESENT	0
417457	417388	11026G	PARTICIPANT	\N	PRESENT	0
417458	417388	19253P	PARTICIPANT	\N	PRESENT	0
417459	417388	01024M	PARTICIPANT	\N	PRESENT	0
417460	417388	19543W	PARTICIPANT	\N	PRESENT	0
417461	417388	01028R	PRESIDENT	1	PRESENT	0
417462	417388	11033F	PARTICIPANT	\N	PRESENT	0
417463	417388	19447X	PARTICIPANT	\N	PRESENT	0
417464	417388	05008E	PRESIDENT	0	PRESENT	0
417465	417388	19489J	PARTICIPANT	\N	PRESENT	0
417466	417388	95063L	PARTICIPANT	\N	PRESENT	0
417467	417388	14147R	PARTICIPANT	\N	PRESENT	0
417468	417388	14151M	PARTICIPANT	\N	PRESENT	0
417469	417388	19585H	PARTICIPANT	\N	PRESENT	0
417470	417388	19729F	PARTICIPANT	\N	EXCUSE	0
417471	417388	04044E	PARTICIPANT	\N	EXCUSE	0
417474	417472	19503N	PARTICIPANT	\N	PRESENT	0
418282	416988	14053L	PARTICIPANT	\N	PRESENT	0
418283	416988	04070G	PARTICIPANT	\N	PRESENT	0
418284	416988	11048N	PARTICIPANT	\N	PRESENT	0
418285	416988	14079W	PARTICIPANT	\N	PRESENT	0
418286	416988	19413M	PARTICIPANT	\N	PRESENT	0
418287	416988	14001X	PARTICIPANT	\N	PRESENT	0
418288	416988	14033T	PARTICIPANT	\N	PRESENT	0
418289	416988	19826F	PARTICIPANT	\N	PRESENT	0
418290	416988	19581D	PARTICIPANT	\N	PRESENT	0
418291	416988	14026U	PARTICIPANT	\N	PRESENT	0
418292	416988	19637C	PARTICIPANT	\N	PRESENT	0
418293	416988	08060W	PARTICIPANT	\N	PRESENT	0
418294	416988	19733B	PARTICIPANT	\N	PRESENT	0
418295	416988	08009T	PRESIDENT	0	PRESENT	0
418296	416988	19367Y	PARTICIPANT	\N	PRESENT	0
418297	416988	08024S	PARTICIPANT	\N	PRESENT	0
418298	416988	19758L	PARTICIPANT	\N	PRESENT	0
418299	416988	11065P	PARTICIPANT	\N	PRESENT	0
418300	416988	14093U	PARTICIPANT	\N	EXCUSE	0
418301	416988	14051J	PARTICIPANT	\N	EXCUSE	0
418304	416986	04034C	PARTICIPANT	\N	PRESENT	0
418305	416986	08058D	PARTICIPANT	\N	PRESENT	0
418306	416986	14028W	PARTICIPANT	\N	PRESENT	0
418307	416986	19421M	PARTICIPANT	\N	PRESENT	0
418308	416986	14193X	PARTICIPANT	\N	PRESENT	0
418309	416986	97011G	PARTICIPANT	\N	PRESENT	0
418406	406964	19729F	PARTICIPANT	\N	PRESENT	0
418407	406964	11033F	PARTICIPANT	\N	PRESENT	0
418409	406964	14081Q	PARTICIPANT	\N	PRESENT	0
418412	406964	19725B	PARTICIPANT	\N	PRESENT	0
418413	406964	19549D	PARTICIPANT	\N	PRESENT	0
418414	406964	19820Y	PARTICIPANT	\N	PRESENT	0
418415	406964	19651A	PARTICIPANT	\N	PRESENT	0
418416	406964	19253P	PARTICIPANT	\N	PRESENT	0
418417	406964	14207L	PARTICIPANT	\N	PRESENT	0
418418	406964	19681G	PARTICIPANT	\N	PRESENT	0
418419	416986	12041X	PARTICIPANT	\N	PRESENT	0
418420	416986	14235Q	PARTICIPANT	\N	PRESENT	0
418421	416986	04040A	PARTICIPANT	\N	PRESENT	0
418422	416986	01058X	PARTICIPANT	\N	PRESENT	0
418423	416986	14267Y	PARTICIPANT	\N	PRESENT	0
418424	416986	11064N	PARTICIPANT	\N	PRESENT	0
418425	416986	08053X	PARTICIPANT	\N	PRESENT	0
418426	406964	04085P	PARTICIPANT	\N	PRESENT	0
418427	406964	19695N	PARTICIPANT	\N	PRESENT	0
418428	406964	14151M	PARTICIPANT	\N	PRESENT	0
418429	406964	19745F	PARTICIPANT	\N	PRESENT	0
418430	406964	14089Y	PARTICIPANT	\N	PRESENT	0
418431	406964	19369B	PARTICIPANT	\N	PRESENT	0
418432	416986	95030B	PARTICIPANT	\N	PRESENT	0
418433	416986	95037J	PARTICIPANT	\N	PRESENT	0
418434	416986	08061X	PARTICIPANT	\N	PRESENT	0
418435	416986	98029W	PARTICIPANT	\N	PRESENT	0
418436	416986	95067Q	PARTICIPANT	\N	PRESENT	0
418437	416986	98022P	PARTICIPANT	\N	PRESENT	0
418438	416986	14255U	PARTICIPANT	\N	PRESENT	0
418439	406964	19685L	PARTICIPANT	\N	PRESENT	0
418440	406964	19581D	PARTICIPANT	\N	PRESENT	0
418441	406964	19737F	PARTICIPANT	\N	PRESENT	0
418442	416986	11041F	PARTICIPANT	\N	PRESENT	0
418443	406964	08044W	PARTICIPANT	\N	PRESENT	0
418444	406964	14219Q	PARTICIPANT	\N	PRESENT	0
418445	406964	19719D	PARTICIPANT	\N	PRESENT	0
418446	406964	11043H	PARTICIPANT	\N	PRESENT	0
418447	416986	98018T	PARTICIPANT	\N	PRESENT	0
418448	406964	14041T	PARTICIPANT	\N	PRESENT	0
418449	406964	14029X	PARTICIPANT	\N	PRESENT	0
418450	406964	19794Q	PARTICIPANT	\N	PRESENT	0
418451	406964	15447F	PARTICIPANT	\N	PRESENT	0
418452	406964	04018C	PARTICIPANT	\N	PRESENT	0
418453	406964	19798U	PARTICIPANT	\N	PRESENT	0
418454	406964	19533U	PARTICIPANT	\N	PRESENT	0
418455	406964	14249W	PARTICIPANT	\N	PRESENT	0
418456	406964	14119M	PARTICIPANT	\N	PRESENT	0
418457	406964	14215L	PARTICIPANT	\N	PRESENT	0
418458	406964	01060R	PARTICIPANT	\N	PRESENT	0
418459	416986	01062T	PARTICIPANT	\N	PRESENT	0
418460	416986	14133K	PARTICIPANT	\N	PRESENT	0
418461	406964	19782L	PARTICIPANT	\N	PRESENT	0
418462	406964	19543W	PARTICIPANT	\N	PRESENT	0
418463	406964	02002K	PARTICIPANT	\N	PRESENT	0
418464	406964	14179A	PARTICIPANT	\N	PRESENT	0
418465	416986	11027H	PARTICIPANT	\N	PRESENT	0
418466	416986	08047A	PARTICIPANT	\N	PRESENT	0
418467	406964	19699S	PARTICIPANT	\N	PRESENT	0
418468	406964	19447X	PARTICIPANT	\N	PRESENT	0
418469	406964	14069U	PARTICIPANT	\N	PRESENT	0
418470	406964	19349W	PARTICIPANT	\N	PRESENT	0
418471	406964	01028R	PARTICIPANT	\N	PRESENT	0
418472	406964	08028W	PARTICIPANT	\N	PRESENT	0
418473	406964	14223L	PARTICIPANT	\N	PRESENT	0
418474	406964	14059S	PARTICIPANT	\N	PRESENT	0
418475	406964	19709B	PARTICIPANT	\N	PRESENT	0
418476	406964	14357A	PARTICIPANT	\N	PRESENT	0
418477	406964	19399H	PARTICIPANT	\N	PRESENT	0
418478	406964	08062Y	PARTICIPANT	\N	PRESENT	0
418479	416986	19647E	PARTICIPANT	\N	PRESENT	0
418480	416986	19721W	PARTICIPANT	\N	PRESENT	0
418481	406964	19479G	PARTICIPANT	\N	PRESENT	0
418482	406964	19383Y	PARTICIPANT	\N	PRESENT	0
418483	406964	14173T	PARTICIPANT	\N	PRESENT	0
418484	406964	14191V	PARTICIPANT	\N	PRESENT	0
418485	406964	19758L	PARTICIPANT	\N	PRESENT	0
418486	406964	19826F	PARTICIPANT	\N	PRESENT	0
418487	406964	14034U	PARTICIPANT	\N	PRESENT	0
418488	406964	14211G	PARTICIPANT	\N	PRESENT	0
418489	406964	14205J	PARTICIPANT	\N	PRESENT	0
418490	406964	19413M	PARTICIPANT	\N	PRESENT	0
418491	406964	04088S	PARTICIPANT	\N	PRESENT	0
418492	406964	08020N	PARTICIPANT	\N	PRESENT	0
418493	406964	80013X	PARTICIPANT	\N	PRESENT	0
418494	406964	14079W	PARTICIPANT	\N	PRESENT	0
418495	406964	14237S	PARTICIPANT	\N	PRESENT	0
418496	406964	14331P	PARTICIPANT	\N	PRESENT	0
418497	406964	95030B	PARTICIPANT	\N	PRESENT	0
418400	406964	11070L	PARTICIPANT	\N	PRESENT	0
418404	406964	19733B	PARTICIPANT	\N	PRESENT	0
418498	406964	19760E	PARTICIPANT	\N	PRESENT	0
418499	406964	14235Q	PARTICIPANT	\N	PRESENT	0
418500	406964	08038Y	PARTICIPANT	\N	PRESENT	0
418501	406964	14026U	PARTICIPANT	\N	PRESENT	0
418502	406964	14199E	PARTICIPANT	\N	PRESENT	0
418503	406964	14265W	PARTICIPANT	\N	PRESENT	0
418504	406964	19387D	PARTICIPANT	\N	PRESENT	0
418505	406964	14213J	PARTICIPANT	\N	PRESENT	0
418506	406964	19715Y	PARTICIPANT	\N	PRESENT	0
418507	406964	19599P	PARTICIPANT	\N	PRESENT	0
418508	406964	11097X	PARTICIPANT	\N	PRESENT	0
418509	406964	11012A	PARTICIPANT	\N	PRESENT	0
418510	406964	08056B	PARTICIPANT	\N	PRESENT	0
418511	406964	19467C	PARTICIPANT	\N	PRESENT	0
418512	406964	14065Q	PARTICIPANT	\N	PRESENT	0
418513	406964	14087W	PARTICIPANT	\N	PRESENT	0
418514	406964	19679N	PARTICIPANT	\N	PRESENT	0
418515	406964	14217N	PARTICIPANT	\N	PRESENT	0
418516	406964	19747H	PARTICIPANT	\N	PRESENT	0
400314	397287	14357A	PARTICIPANT	\N	PRESENT	0
393950	393744	14028W	PARTICIPANT	\N	EXCUSE	0
400100	397651	14327T	PARTICIPANT	\N	EXCUSE	0
400313	397287	96004D	PRESIDENT	0	PRESENT	0
400315	397287	04035D	PARTICIPANT	\N	PRESENT	0
400316	397287	19725B	PARTICIPANT	\N	PRESENT	0
400317	397287	04097T	PARTICIPANT	\N	PRESENT	0
400318	397287	14073Q	PARTICIPANT	\N	PRESENT	0
400319	397287	11083R	PARTICIPANT	\N	PRESENT	0
400320	397287	14033T	PARTICIPANT	\N	PRESENT	0
400321	397287	08014Q	PARTICIPANT	\N	PRESENT	0
400322	397287	14133K	PARTICIPANT	\N	PRESENT	0
400323	397287	11026G	PARTICIPANT	\N	PRESENT	0
400324	397287	14221J	PARTICIPANT	\N	PRESENT	0
400325	397287	14331P	PARTICIPANT	\N	PRESENT	0
400326	397287	14225N	PARTICIPANT	\N	PRESENT	0
400327	397287	10015M	PARTICIPANT	\N	PRESENT	0
400328	397287	14097Y	PARTICIPANT	\N	PRESENT	0
400329	397287	14061L	PARTICIPANT	\N	EXCUSE	0
400330	397287	04057K	PARTICIPANT	\N	EXCUSE	0
400331	397287	14065Q	PARTICIPANT	\N	EXCUSE	0
400332	397287	14089Y	PARTICIPANT	\N	EXCUSE	0
400444	400443	08038Y	PARTICIPANT	\N	PRESENT	0
400445	400443	01043Q	PARTICIPANT	\N	PRESENT	0
400446	400443	04043D	PARTICIPANT	\N	PRESENT	0
400447	400443	88008L	PARTICIPANT	\N	PRESENT	0
400448	400443	14225N	PARTICIPANT	\N	PRESENT	0
400449	400443	19333N	PARTICIPANT	\N	PRESENT	0
400451	400450	14030Q	PARTICIPANT	\N	PRESENT	0
400452	400450	14179A	PARTICIPANT	\N	PRESENT	0
400453	400450	08015R	PARTICIPANT	\N	PRESENT	0
400454	400450	19709B	PARTICIPANT	\N	PRESENT	0
400455	400450	11026G	PARTICIPANT	\N	PRESENT	0
400456	400450	04070G	PARTICIPANT	\N	PRESENT	0
400457	400450	19421M	PARTICIPANT	\N	PRESENT	0
401800	393617	19563B	PARTICIPANT	\N	PRESENT	0
401801	393617	19741B	PARTICIPANT	\N	PRESENT	0
401802	393617	01057W	PARTICIPANT	\N	PRESENT	0
401803	393617	14193X	PARTICIPANT	\N	PRESENT	0
401804	393617	89017R	PARTICIPANT	\N	PRESENT	0
401805	393617	19673G	PARTICIPANT	\N	PRESENT	0
401806	393617	19745F	PARTICIPANT	\N	PRESENT	0
401807	393617	14115H	PARTICIPANT	\N	PRESENT	0
401808	393617	17583W	PARTICIPANT	\N	PRESENT	0
401809	393617	01024M	PARTICIPANT	\N	PRESENT	0
401810	393617	19421M	PARTICIPANT	\N	PRESENT	0
401811	393617	19739H	PARTICIPANT	\N	PRESENT	0
401875	401714	11103C	PARTICIPANT	\N	PRESENT	0
401813	393617	14111D	PARTICIPANT	\N	PRESENT	0
401819	401817	17589D	PARTICIPANT	\N	PRESENT	0
401816	393617	14219Q	PARTICIPANT	\N	PRESENT	0
401818	401817	14071N	PARTICIPANT	\N	PRESENT	0
401820	401817	19766L	PARTICIPANT	\N	PRESENT	0
401821	401817	19575F	PARTICIPANT	\N	PRESENT	0
401822	401817	04070G	PARTICIPANT	\N	PRESENT	0
401823	393617	14071N	PARTICIPANT	\N	PRESENT	0
401824	393617	04047H	PARTICIPANT	\N	PRESENT	0
401825	393617	14135M	PARTICIPANT	\N	PRESENT	0
401826	393617	14121F	PARTICIPANT	\N	PRESENT	0
401827	393617	08015R	PARTICIPANT	\N	PRESENT	0
401828	393617	14089Y	PARTICIPANT	\N	PRESENT	0
401829	393617	14259Y	PARTICIPANT	\N	PRESENT	0
401830	393617	14069U	PARTICIPANT	\N	PRESENT	0
401831	393617	14357A	PARTICIPANT	\N	PRESENT	0
401832	393617	11109J	PARTICIPANT	\N	PRESENT	0
401833	393617	14265W	PARTICIPANT	\N	PRESENT	0
401834	393617	19669L	PARTICIPANT	\N	PRESENT	0
401835	393617	14331P	PARTICIPANT	\N	PRESENT	0
401836	393617	98050T	PARTICIPANT	\N	PRESENT	0
401838	393617	19647E	PARTICIPANT	\N	PRESENT	0
401839	393617	19760E	PARTICIPANT	\N	PRESENT	0
401840	393617	95063L	PARTICIPANT	\N	PRESENT	0
401841	393617	19762G	PARTICIPANT	\N	PRESENT	0
401842	393617	17637T	PARTICIPANT	\N	PRESENT	0
401843	393617	04043D	PARTICIPANT	\N	PRESENT	0
401844	393617	11054L	PARTICIPANT	\N	PRESENT	0
401845	393617	19691J	PARTICIPANT	\N	PRESENT	0
401852	393617	11045K	PARTICIPANT	\N	PRESENT	0
401872	401714	04092N	PARTICIPANT	\N	PRESENT	0
401873	401714	19575F	PARTICIPANT	\N	PRESENT	0
401876	401714	14195A	PARTICIPANT	\N	PRESENT	0
401877	401714	11031D	PARTICIPANT	\N	PRESENT	0
401878	401714	08052W	PARTICIPANT	\N	PRESENT	0
401879	401714	98024R	PARTICIPANT	\N	PRESENT	0
401880	401714	10006L	PARTICIPANT	\N	PRESENT	0
401881	401714	14217N	PARTICIPANT	\N	PRESENT	0
401882	401714	14042U	PARTICIPANT	\N	PRESENT	0
401883	401714	14281W	PARTICIPANT	\N	PRESENT	0
401884	401714	19521Q	PARTICIPANT	\N	PRESENT	0
401885	401714	08048B	PARTICIPANT	\N	PRESENT	0
401886	401714	19727D	PARTICIPANT	\N	PRESENT	0
401887	401714	19691J	PARTICIPANT	\N	PRESENT	0
401888	401714	19553Y	PARTICIPANT	\N	PRESENT	0
401889	401714	14213J	PARTICIPANT	\N	PRESENT	0
401890	401714	17779H	PARTICIPANT	\N	PRESENT	0
401901	401714	19703U	PARTICIPANT	\N	EXCUSE	0
401892	401714	11067R	PARTICIPANT	\N	PRESENT	0
401893	401714	14119M	PARTICIPANT	\N	PRESENT	0
401894	401714	14071N	PARTICIPANT	\N	PRESENT	0
401895	401714	19679N	PARTICIPANT	\N	PRESENT	0
401896	401714	19798U	PARTICIPANT	\N	PRESENT	0
401897	401714	11097X	PARTICIPANT	\N	PRESENT	0
401898	401714	14227Q	PARTICIPANT	\N	PRESENT	0
401900	401714	08041T	PARTICIPANT	\N	EXCUSE	0
402533	393777	14093U	PARTICIPANT	\N	PRESENT	0
402536	393777	19723Y	PARTICIPANT	\N	EXCUSE	0
402537	393777	01048V	PRESIDENT	0	PRESENT	0
402875	402874	01048V	PARTICIPANT	\N	PRESENT	0
402542	393777	04043D	PARTICIPANT	\N	PRESENT	0
402546	393777	19553Y	PARTICIPANT	\N	EXCUSE	0
402740	402725	14071N	PARTICIPANT	\N	PRESENT	0
402811	401619	14083S	PARTICIPANT	\N	PRESENT	0
402876	402874	14257W	PARTICIPANT	\N	PRESENT	0
402877	402874	19533U	PARTICIPANT	\N	PRESENT	0
402879	402878	01048V	PARTICIPANT	\N	PRESENT	0
402880	402878	14257W	PARTICIPANT	\N	PRESENT	0
402881	402878	19593H	PARTICIPANT	\N	PRESENT	0
402882	402878	19533U	PARTICIPANT	\N	PRESENT	0
402883	402878	14038Y	PARTICIPANT	\N	PRESENT	0
402885	402884	14199E	PARTICIPANT	\N	PRESENT	0
402887	402886	14199E	PARTICIPANT	\N	PRESENT	0
402890	402889	19545Y	PARTICIPANT	\N	PRESENT	0
402891	402889	19689Q	PARTICIPANT	\N	PRESENT	0
402924	402923	14327T	PARTICIPANT	\N	PRESENT	0
402925	402923	05012A	PARTICIPANT	\N	PRESENT	0
402926	402923	11110B	PARTICIPANT	\N	PRESENT	0
402928	402927	14327T	PARTICIPANT	\N	PRESENT	0
402929	402927	11110B	PARTICIPANT	\N	PRESENT	0
402930	402927	05012A	PARTICIPANT	\N	PRESENT	0
402932	402931	08011M	PARTICIPANT	\N	PRESENT	0
402934	402933	14173T	PARTICIPANT	\N	PRESENT	0
402936	402935	04086Q	PARTICIPANT	\N	PRESENT	0
402938	402937	19741B	PARTICIPANT	\N	PRESENT	0
402940	402939	19671E	PARTICIPANT	\N	PRESENT	0
402942	402941	11074Q	PARTICIPANT	\N	PRESENT	0
402943	402941	08011M	PARTICIPANT	\N	PRESENT	0
403086	400154	11049P	PARTICIPANT	\N	PRESENT	0
403087	400154	95030B	PARTICIPANT	\N	PRESENT	0
403088	400154	11103C	PARTICIPANT	\N	PRESENT	0
403089	400154	04088S	PARTICIPANT	\N	PRESENT	0
403090	400154	19387D	PARTICIPANT	\N	PRESENT	0
403091	400154	14249W	PARTICIPANT	\N	PRESENT	0
403092	400154	04086Q	PARTICIPANT	\N	PRESENT	0
403093	400154	08039A	PARTICIPANT	\N	PRESENT	0
403094	402944	14327T	PARTICIPANT	\N	EXCUSE	0
403095	402944	95041E	PARTICIPANT	\N	EXCUSE	0
403096	400154	19301E	PARTICIPANT	\N	PRESENT	0
403097	400154	11072N	PARTICIPANT	\N	PRESENT	0
403098	400154	19399H	PARTICIPANT	\N	PRESENT	0
403099	403027	19729F	PARTICIPANT	\N	EXCUSE	0
403100	403027	04044E	PARTICIPANT	\N	EXCUSE	0
403101	400154	14275Y	PARTICIPANT	\N	PRESENT	0
403102	400154	19745F	PARTICIPANT	\N	PRESENT	0
403103	400154	19479G	PARTICIPANT	\N	PRESENT	0
403104	400154	14215L	PARTICIPANT	\N	PRESENT	0
403105	400154	19737F	PARTICIPANT	\N	PRESENT	0
403106	400154	19739H	PARTICIPANT	\N	PRESENT	0
403107	400154	19699S	PARTICIPANT	\N	PRESENT	0
403108	400154	19619A	PARTICIPANT	\N	PRESENT	0
403109	400154	14030Q	PARTICIPANT	\N	PRESENT	0
403110	400154	14159V	PARTICIPANT	\N	PRESENT	0
403111	400154	14085U	PARTICIPANT	\N	PRESENT	0
410937	410936	08028W	PARTICIPANT	\N	PRESENT	0
410938	410936	19569H	PARTICIPANT	\N	PRESENT	0
417196	406891	12041X	PARTICIPANT	\N	PRESENT	0
417197	406891	14235Q	PARTICIPANT	\N	PRESENT	0
417198	406891	04042C	PARTICIPANT	\N	PRESENT	0
417199	406891	04035D	PARTICIPANT	\N	PRESENT	0
417200	406891	12016W	PARTICIPANT	\N	PRESENT	0
417201	406891	14281W	PARTICIPANT	\N	PRESENT	0
417202	406891	19599P	PARTICIPANT	\N	PRESENT	0
417203	406891	95063L	PARTICIPANT	\N	PRESENT	0
417204	406891	19333N	PARTICIPANT	\N	PRESENT	0
417205	406891	19295A	PARTICIPANT	\N	PRESENT	0
417206	406891	04034C	PARTICIPANT	\N	PRESENT	0
417207	406891	11041F	PARTICIPANT	\N	PRESENT	0
417208	406891	11066Q	PARTICIPANT	\N	PRESENT	0
417209	406891	19669L	PARTICIPANT	\N	PRESENT	0
417210	406891	14257W	PARTICIPANT	\N	PRESENT	0
417214	406891	14121F	PARTICIPANT	\N	PRESENT	0
417212	406891	14179A	PARTICIPANT	\N	PRESENT	0
417213	406891	19629C	PARTICIPANT	\N	PRESENT	0
417215	406891	08049C	PARTICIPANT	\N	PRESENT	0
417216	406891	19387D	PARTICIPANT	\N	PRESENT	0
417217	406891	14207L	PARTICIPANT	\N	PRESENT	0
417218	406891	19585H	PARTICIPANT	\N	PRESENT	0
417219	406891	19441R	PARTICIPANT	\N	PRESENT	0
417220	406891	19479G	PARTICIPANT	\N	PRESENT	0
417221	406891	11064N	PARTICIPANT	\N	PRESENT	0
417222	406891	19745F	PARTICIPANT	\N	PRESENT	0
417223	406891	19826F	PARTICIPANT	\N	PRESENT	0
417224	406891	14079W	PARTICIPANT	\N	PRESENT	0
417225	406891	14255U	PARTICIPANT	\N	PRESENT	0
417226	406891	04040A	PARTICIPANT	\N	PRESENT	0
417227	406891	14267Y	PARTICIPANT	\N	PRESENT	0
417228	406891	14215L	PARTICIPANT	\N	PRESENT	0
417229	406891	14211G	PARTICIPANT	\N	PRESENT	0
417230	406891	99004R	PARTICIPANT	\N	PRESENT	0
417231	406891	14053L	PARTICIPANT	\N	PRESENT	0
417232	406891	14259Y	PARTICIPANT	\N	PRESENT	0
417233	406891	97011G	PARTICIPANT	\N	PRESENT	0
417234	406891	14147R	PARTICIPANT	\N	PRESENT	0
417235	406891	19399H	PARTICIPANT	\N	PRESENT	0
417236	406891	11010L	PARTICIPANT	\N	PRESENT	0
417237	406891	19701S	PARTICIPANT	\N	PRESENT	0
417238	406891	98050T	PARTICIPANT	\N	PRESENT	0
417239	406891	07029T	PARTICIPANT	\N	PRESENT	0
417258	417257	01025N	PARTICIPANT	\N	PRESENT	0
417259	417257	19507S	PARTICIPANT	\N	PRESENT	0
417260	417257	19413M	PARTICIPANT	\N	PRESENT	0
417261	417257	19812Y	PARTICIPANT	\N	PRESENT	0
417262	417257	19782L	PARTICIPANT	\N	PRESENT	0
417263	417257	14033T	PARTICIPANT	\N	PRESENT	0
417265	417264	01025N	PARTICIPANT	\N	PRESENT	0
417266	417264	19507S	PARTICIPANT	\N	PRESENT	0
417267	417264	19413M	PARTICIPANT	\N	PRESENT	0
417268	417264	19812Y	PARTICIPANT	\N	PRESENT	0
417269	417264	19782L	PARTICIPANT	\N	PRESENT	0
417273	417271	01025N	PARTICIPANT	\N	PRESENT	0
417274	417271	19507S	PARTICIPANT	\N	PRESENT	0
417275	417271	19413M	PARTICIPANT	\N	PRESENT	0
417276	417271	19812Y	PARTICIPANT	\N	PRESENT	0
417278	417277	01025N	PARTICIPANT	\N	PRESENT	0
417279	417277	19507S	PARTICIPANT	\N	PRESENT	0
417280	417277	19413M	PARTICIPANT	\N	PRESENT	0
417282	417281	01025N	PARTICIPANT	\N	PRESENT	0
417283	417281	19507S	PARTICIPANT	\N	PRESENT	0
417284	417281	19413M	PARTICIPANT	\N	PRESENT	0
417286	417285	01025N	PARTICIPANT	\N	PRESENT	0
417287	417285	19507S	PARTICIPANT	\N	PRESENT	0
417288	417285	19413M	PARTICIPANT	\N	PRESENT	0
417290	417289	01025N	PARTICIPANT	\N	PRESENT	0
417291	417289	19507S	PARTICIPANT	\N	PRESENT	0
417292	417289	19413M	PARTICIPANT	\N	PRESENT	0
417303	417293	08068F	PARTICIPANT	\N	PRESENT	0
417304	417293	19515S	PARTICIPANT	\N	PRESENT	0
417319	417311	08068F	PARTICIPANT	\N	PRESENT	0
417323	417314	08068F	PARTICIPANT	\N	PRESENT	0
418226	414857	19421M	PARTICIPANT	\N	PRESENT	0
418227	414857	14179A	PARTICIPANT	\N	PRESENT	0
418228	414857	08039A	PARTICIPANT	\N	PRESENT	0
418229	414857	19543W	PARTICIPANT	\N	PRESENT	0
418230	414857	01058X	PARTICIPANT	\N	PRESENT	0
418231	414857	08017T	PARTICIPANT	\N	PRESENT	0
418232	414857	04097T	PARTICIPANT	\N	PRESENT	0
418233	414857	14211G	PARTICIPANT	\N	PRESENT	0
418234	414857	15447F	PARTICIPANT	\N	PRESENT	0
418235	414857	19383Y	PARTICIPANT	\N	PRESENT	0
418236	414857	04085P	PARTICIPANT	\N	PRESENT	0
418237	414857	19719D	PARTICIPANT	\N	PRESENT	0
418238	414857	14121F	PARTICIPANT	\N	PRESENT	0
418239	414857	19681G	PARTICIPANT	\N	PRESENT	0
418240	414857	14103D	PARTICIPANT	\N	PRESENT	0
418241	414857	19685L	PARTICIPANT	\N	PRESENT	0
418242	414857	14193X	PARTICIPANT	\N	PRESENT	0
418245	414857	08061X	PARTICIPANT	\N	PRESENT	0
418248	414857	19581D	PARTICIPANT	\N	PRESENT	0
418249	414857	16685X	PARTICIPANT	\N	PRESENT	0
418250	414857	08053X	PARTICIPANT	\N	PRESENT	0
418251	414857	14215L	PARTICIPANT	\N	PRESENT	0
418252	414857	04040A	PARTICIPANT	\N	PRESENT	0
418253	414857	19549D	PARTICIPANT	\N	PRESENT	0
418254	414857	11027H	PARTICIPANT	\N	PRESENT	0
418255	414857	04044E	PARTICIPANT	\N	PRESENT	0
418256	414857	14249W	PARTICIPANT	\N	PRESENT	0
418257	414857	19593H	PARTICIPANT	\N	PRESENT	0
418258	414857	14089Y	PARTICIPANT	\N	PRESENT	0
418259	414857	19253P	PARTICIPANT	\N	PRESENT	0
418260	414857	19399H	PARTICIPANT	\N	PRESENT	0
418262	416673	01048V	PARTICIPANT	\N	PRESENT	0
418263	416673	19545Y	PARTICIPANT	\N	PRESENT	0
418264	416673	12016W	PARTICIPANT	\N	PRESENT	0
418265	416673	07029T	PARTICIPANT	\N	PRESENT	0
418266	416673	14083S	PARTICIPANT	\N	PRESENT	0
418267	416673	14085U	PARTICIPANT	\N	PRESENT	0
418268	416673	08010L	PARTICIPANT	\N	PRESENT	0
418269	416673	11012A	PARTICIPANT	\N	PRESENT	0
418270	416673	01057W	PARTICIPANT	\N	PRESENT	0
418271	414419	99004R	PRESIDENT	0	PRESENT	0
418272	414419	04038G	PARTICIPANT	\N	PRESENT	0
418660	416543	95030B	PARTICIPANT	\N	PRESENT	0
418661	417479	04070G	PRESIDENT	0	PRESENT	0
418662	417479	19699S	PARTICIPANT	\N	PRESENT	0
418663	417479	19533U	PARTICIPANT	\N	PRESENT	0
418664	417479	04033B	PARTICIPANT	\N	PRESENT	0
418665	417479	14229S	PARTICIPANT	\N	PRESENT	0
418666	417479	14241N	PARTICIPANT	\N	PRESENT	0
418667	417479	19573D	PARTICIPANT	\N	PRESENT	0
418668	417479	14039A	PARTICIPANT	\N	PRESENT	0
418669	417479	14107H	PARTICIPANT	\N	PRESENT	0
418670	417479	08017T	PARTICIPANT	\N	PRESENT	0
418671	417479	07033P	PARTICIPANT	\N	PRESENT	0
418672	417479	08012N	PARTICIPANT	\N	PRESENT	0
418673	417479	19335Q	PARTICIPANT	\N	PRESENT	0
418674	417479	14249W	PARTICIPANT	\N	PRESENT	0
418675	417479	08039A	PRESIDENT	1	PRESENT	0
418676	417479	08031R	PARTICIPANT	\N	PRESENT	0
418677	417479	19593H	PARTICIPANT	\N	PRESENT	0
418678	417479	19643A	PARTICIPANT	\N	PRESENT	0
418679	417479	14059S	PARTICIPANT	\N	PRESENT	0
418680	417479	14061L	PARTICIPANT	\N	PRESENT	0
418681	417479	04057K	PARTICIPANT	\N	PRESENT	0
418682	417479	08035V	PARTICIPANT	\N	PRESENT	0
418683	417479	19611R	PARTICIPANT	\N	PRESENT	0
418684	417479	08043V	PARTICIPANT	\N	PRESENT	0
418685	417479	87003B	PARTICIPANT	\N	PRESENT	0
418686	417479	14201E	PARTICIPANT	\N	PRESENT	0
418687	417479	14251Q	PARTICIPANT	\N	PRESENT	0
418688	417479	08020N	PARTICIPANT	\N	PRESENT	0
418689	417479	04059M	PARTICIPANT	\N	PRESENT	0
418690	417479	19735D	PARTICIPANT	\N	PRESENT	0
418691	417479	14109K	PARTICIPANT	\N	PRESENT	0
418692	417479	11104D	PARTICIPANT	\N	PRESENT	0
418693	417479	11043H	PARTICIPANT	\N	PRESENT	0
418694	417479	19749K	PARTICIPANT	\N	PRESENT	0
418695	417479	04018C	PARTICIPANT	\N	PRESENT	0
418696	417479	19758L	PARTICIPANT	\N	PRESENT	0
418697	417479	19621T	PARTICIPANT	\N	PRESENT	0
418698	417479	14073Q	PARTICIPANT	\N	EXCUSE	0
418699	417479	92040Q	PARTICIPANT	\N	EXCUSE	0
418700	417479	19693L	PARTICIPANT	\N	EXCUSE	0
418701	415937	11067R	PARTICIPANT	\N	PRESENT	0
418702	415937	19565D	PARTICIPANT	\N	PRESENT	0
418703	415937	19798U	PARTICIPANT	\N	PRESENT	0
418704	415937	11097X	PARTICIPANT	\N	PRESENT	0
418705	415937	14223L	PARTICIPANT	\N	PRESENT	0
418706	415937	14026U	PARTICIPANT	\N	PRESENT	0
418707	415937	14227Q	PARTICIPANT	\N	PRESENT	0
418708	415937	17779H	PARTICIPANT	\N	PRESENT	0
418709	415937	19703U	PARTICIPANT	\N	PRESENT	0
418710	415937	14087W	PARTICIPANT	\N	PRESENT	0
396776	396775	19631V	PARTICIPANT	\N	PRESENT	0
396777	396775	11083R	PARTICIPANT	\N	PRESENT	0
396778	396775	14257W	PARTICIPANT	\N	PRESENT	0
396779	396775	01048V	PARTICIPANT	\N	PRESENT	0
396780	396775	19421M	PARTICIPANT	\N	PRESENT	0
396781	396775	19679N	PARTICIPANT	\N	PRESENT	0
396782	396775	19741B	PARTICIPANT	\N	PRESENT	0
396783	396775	19415P	PARTICIPANT	\N	PRESENT	0
396942	396936	04059M	PARTICIPANT	\N	PRESENT	0
396943	396936	08031R	PARTICIPANT	\N	PRESENT	0
396944	396937	04059M	PARTICIPANT	\N	PRESENT	0
396946	396945	14107H	PARTICIPANT	\N	PRESENT	0
396947	396945	19611R	PARTICIPANT	\N	PRESENT	0
396948	396945	19621T	PARTICIPANT	\N	PRESENT	0
406907	405336	14157T	PARTICIPANT	\N	PRESENT	0
406908	405336	19685L	PARTICIPANT	\N	PRESENT	0
406909	405336	08024S	PARTICIPANT	\N	PRESENT	0
406910	405336	19681G	PARTICIPANT	\N	PRESENT	0
406911	405336	17637T	PARTICIPANT	\N	PRESENT	0
406912	405336	11065P	PARTICIPANT	\N	PRESENT	0
406913	405336	19525U	PARTICIPANT	\N	PRESENT	0
406914	405336	14038Y	PARTICIPANT	\N	PRESENT	0
406915	405336	14031R	PARTICIPANT	\N	PRESENT	0
406916	405336	19713W	PARTICIPANT	\N	PRESENT	0
406917	405336	08055A	PARTICIPANT	\N	PRESENT	0
406918	405336	14169X	PARTICIPANT	\N	PRESENT	0
406919	405336	15447F	PARTICIPANT	\N	PRESENT	0
406920	405336	14029X	PARTICIPANT	\N	PRESENT	0
406921	405336	19733B	PARTICIPANT	\N	PRESENT	0
406922	405336	08009T	PRESIDENT	0	PRESENT	0
406923	405336	04097T	PARTICIPANT	\N	PRESENT	0
406924	405336	19739H	PARTICIPANT	\N	PRESENT	0
406925	405336	14051J	PARTICIPANT	\N	EXCUSE	0
406926	405336	02002K	PARTICIPANT	\N	EXCUSE	0
406930	405336	14205J	PARTICIPANT	\N	PRESENT	0
406933	406662	04057K	PARTICIPANT	\N	PRESENT	0
406934	405327	19697Q	PARTICIPANT	\N	PRESENT	0
406935	405327	19575F	PARTICIPANT	\N	PRESENT	0
406936	405327	14217N	PARTICIPANT	\N	PRESENT	0
406937	405327	01034P	PARTICIPANT	\N	EXCUSE	0
406963	402268	04059M	PARTICIPANT	\N	PRESENT	0
406965	405414	14327T	PARTICIPANT	\N	PRESENT	0
406966	405414	04057K	PARTICIPANT	\N	PRESENT	0
406967	405414	08069G	PARTICIPANT	\N	EXCUSE	0
406968	405414	19441R	PARTICIPANT	\N	PRESENT	0
406969	405414	14001X	PARTICIPANT	\N	PRESENT	0
406970	405414	14033T	PARTICIPANT	\N	PRESENT	0
406971	405414	08014Q	PARTICIPANT	\N	PRESENT	0
406972	405414	19295A	PARTICIPANT	\N	PRESENT	0
406973	405414	14026U	PARTICIPANT	\N	PRESENT	0
406974	405414	19725B	PRESIDENT	0	PRESENT	0
406975	405414	11056N	PARTICIPANT	\N	PRESENT	0
406976	405414	14107H	PARTICIPANT	\N	PRESENT	0
406977	405414	04097T	PARTICIPANT	\N	PRESENT	0
406978	405414	14071N	PARTICIPANT	\N	PRESENT	0
406979	405414	08015R	PARTICIPANT	\N	PRESENT	0
406980	405414	14030Q	PARTICIPANT	\N	EXCUSE	0
406981	405615	19794Q	PARTICIPANT	\N	PRESENT	0
406982	405615	14031R	PARTICIPANT	\N	PRESENT	0
406983	405615	14079W	PARTICIPANT	\N	PRESENT	0
406984	405615	14081Q	PARTICIPANT	\N	PRESENT	0
406985	405615	19251M	PARTICIPANT	\N	PRESENT	0
406986	405615	19585H	PARTICIPANT	\N	PRESENT	0
406987	405615	19637C	PARTICIPANT	\N	PRESENT	0
406988	405615	19551W	PARTICIPANT	\N	PRESENT	0
406989	405615	14241N	PARTICIPANT	\N	PRESENT	0
406990	405615	19737F	PARTICIPANT	\N	PRESENT	0
406991	405615	19347U	PARTICIPANT	\N	PRESENT	0
406992	405615	19349W	PARTICIPANT	\N	PRESENT	0
406993	405615	11049P	PARTICIPANT	\N	PRESENT	0
406994	405615	19335Q	PARTICIPANT	\N	PRESENT	0
406995	405615	19525U	PARTICIPANT	\N	PRESENT	0
406996	405615	19643A	PARTICIPANT	\N	EXCUSE	0
406997	405615	19569H	PARTICIPANT	\N	EXCUSE	0
406999	405414	19531S	PARTICIPANT	\N	PRESENT	0
407000	405414	19747H	PARTICIPANT	\N	PRESENT	0
407002	402268	19593H	PARTICIPANT	\N	PRESENT	0
407003	402268	11033F	PARTICIPANT	\N	PRESENT	0
407004	402268	01058X	PARTICIPANT	\N	PRESENT	0
407005	402268	14223L	PARTICIPANT	\N	PRESENT	0
407006	402268	08055A	PARTICIPANT	\N	PRESENT	0
407007	402268	14157T	PARTICIPANT	\N	PRESENT	0
407008	402268	19347U	PARTICIPANT	\N	PRESENT	0
407009	402268	08009T	PARTICIPANT	\N	PRESENT	0
407010	402268	08060W	PARTICIPANT	\N	PRESENT	0
407011	402268	11109J	PARTICIPANT	\N	PRESENT	0
407012	402268	19413M	PARTICIPANT	\N	PRESENT	0
407013	402268	12016W	PARTICIPANT	\N	PRESENT	0
407014	402268	19503N	PARTICIPANT	\N	PRESENT	0
407015	402268	19333N	PARTICIPANT	\N	PRESENT	0
407016	402268	19631V	PARTICIPANT	\N	PRESENT	0
407017	402268	14249W	PARTICIPANT	\N	PRESENT	0
407018	402268	19637C	PARTICIPANT	\N	PRESENT	0
407019	402268	08034U	PARTICIPANT	\N	PRESENT	0
407020	402268	14195A	PARTICIPANT	\N	PRESENT	0
407021	402268	19711U	PARTICIPANT	\N	PRESENT	0
407022	402268	19525U	PARTICIPANT	\N	PRESENT	0
407023	402268	14267Y	PARTICIPANT	\N	PRESENT	0
407024	402268	19739H	PARTICIPANT	\N	PRESENT	0
407025	402268	08024S	PARTICIPANT	\N	PRESENT	0
407026	402268	14235Q	PARTICIPANT	\N	PRESENT	0
407027	402268	11054L	PARTICIPANT	\N	PRESENT	0
407028	402268	08056B	PARTICIPANT	\N	PRESENT	0
407029	402268	19387D	PARTICIPANT	\N	PRESENT	0
407030	402268	19731Y	PARTICIPANT	\N	PRESENT	0
407031	402268	14061L	PARTICIPANT	\N	PRESENT	0
407032	402268	95030B	PARTICIPANT	\N	PRESENT	0
407033	402268	19701S	PARTICIPANT	\N	PRESENT	0
407034	402268	19367Y	PARTICIPANT	\N	PRESENT	0
407035	402268	14105F	PARTICIPANT	\N	PRESENT	0
407036	402268	14079W	PARTICIPANT	\N	PRESENT	0
407037	402268	14217N	PARTICIPANT	\N	PRESENT	0
407038	402268	11048N	PARTICIPANT	\N	PRESENT	0
407039	402268	14257W	PARTICIPANT	\N	PRESENT	0
407040	402268	19421M	PARTICIPANT	\N	PRESENT	0
407045	402268	14038Y	PARTICIPANT	\N	PRESENT	0
407042	402268	14169X	PARTICIPANT	\N	PRESENT	0
407043	402268	14173T	PARTICIPANT	\N	PRESENT	0
407044	402268	04088S	PARTICIPANT	\N	PRESENT	0
407046	402268	19794Q	PARTICIPANT	\N	PRESENT	0
407047	402268	14031R	PARTICIPANT	\N	PRESENT	0
407048	402268	01048V	PARTICIPANT	\N	PRESENT	0
407049	402268	11099A	PARTICIPANT	\N	PRESENT	0
407050	402268	19549D	PARTICIPANT	\N	PRESENT	0
407051	402268	11097X	PARTICIPANT	\N	PRESENT	0
407052	402268	14109K	PARTICIPANT	\N	PRESENT	0
407053	402268	19715Y	PARTICIPANT	\N	PRESENT	0
407054	402268	19713W	PARTICIPANT	\N	PRESENT	0
407055	402268	14205J	PARTICIPANT	\N	PRESENT	0
407056	402268	14219Q	PARTICIPANT	\N	PRESENT	0
407057	402268	19591F	PARTICIPANT	\N	PRESENT	0
407058	402268	19507S	PARTICIPANT	\N	PRESENT	0
407059	402268	99004R	PARTICIPANT	\N	PRESENT	0
407060	402268	14029X	PARTICIPANT	\N	PRESENT	0
407061	402268	19611R	PARTICIPANT	\N	PRESENT	0
407062	402268	01057W	PARTICIPANT	\N	PRESENT	0
407063	402268	19479G	PARTICIPANT	\N	PRESENT	0
407064	402268	19269X	PARTICIPANT	\N	PRESENT	0
407065	402268	19399H	PARTICIPANT	\N	PRESENT	0
407066	402268	19521Q	PARTICIPANT	\N	PRESENT	0
407067	404871	14111D	PARTICIPANT	\N	PRESENT	0
407068	404871	19253P	PARTICIPANT	\N	PRESENT	0
407069	404871	14001X	PARTICIPANT	\N	PRESENT	0
407070	404871	19585H	PARTICIPANT	\N	PRESENT	0
407071	404871	19719D	PARTICIPANT	\N	PRESENT	0
407072	404871	14231L	PARTICIPANT	\N	PRESENT	0
407073	404871	05008E	PRESIDENT	0	PRESENT	0
407074	404871	14089Y	PARTICIPANT	\N	PRESENT	0
407075	404871	19489J	PARTICIPANT	\N	PRESENT	0
407076	404871	95063L	PARTICIPANT	\N	PRESENT	0
407077	404871	14275Y	PARTICIPANT	\N	PRESENT	0
407078	404871	19629C	PARTICIPANT	\N	PRESENT	0
407079	404871	14147R	PARTICIPANT	\N	PRESENT	0
407080	404871	14179A	PARTICIPANT	\N	PRESENT	0
407081	404871	14151M	PARTICIPANT	\N	PRESENT	0
407082	404871	14069U	PARTICIPANT	\N	PRESENT	0
407083	404871	14259Y	PARTICIPANT	\N	PRESENT	0
407084	404871	17637T	PARTICIPANT	\N	PRESENT	0
407085	404871	14053L	PARTICIPANT	\N	EXCUSE	0
407086	404871	14065Q	PARTICIPANT	\N	EXCUSE	0
407087	404871	08045X	PARTICIPANT	\N	EXCUSE	0
407088	404871	01024M	PARTICIPANT	\N	EXCUSE	0
407089	404871	19543W	PARTICIPANT	\N	EXCUSE	0
407090	404871	04044E	PARTICIPANT	\N	EXCUSE	0
407091	404871	14215L	PARTICIPANT	\N	EXCUSE	0
407092	404871	19581D	PARTICIPANT	\N	EXCUSE	0
407093	404871	19673G	PARTICIPANT	\N	EXCUSE	0
392732	392726	14205J	PARTICIPANT	\N	PRESENT	0
418566	407001	04042C	PARTICIPANT	\N	PRESENT	0
418567	407001	98035U	PARTICIPANT	\N	PRESENT	0
418568	407001	14001X	PARTICIPANT	\N	PRESENT	0
418569	407001	19593H	PARTICIPANT	\N	PRESENT	0
418570	407001	19553Y	PARTICIPANT	\N	PRESENT	0
418571	407001	14235Q	PARTICIPANT	\N	PRESENT	0
418572	407001	04097T	PARTICIPANT	\N	PRESENT	0
418573	407001	12041X	PARTICIPANT	\N	PRESENT	0
418574	407001	01025N	PARTICIPANT	\N	PRESENT	0
418575	407001	11026G	PARTICIPANT	\N	PRESENT	0
418576	407001	14079W	PARTICIPANT	\N	PRESENT	0
418577	407001	19760E	PARTICIPANT	\N	PRESENT	0
418578	407001	14026U	PARTICIPANT	\N	PRESENT	0
418579	407001	19758L	PARTICIPANT	\N	PRESENT	0
418580	407001	14157T	PARTICIPANT	\N	PRESENT	0
418581	407001	11074Q	PARTICIPANT	\N	PRESENT	0
418582	407001	19794Q	PARTICIPANT	\N	PRESENT	0
418583	407001	14255U	PARTICIPANT	\N	PRESENT	0
418584	407001	19563B	PARTICIPANT	\N	PRESENT	0
418585	407001	14030Q	PARTICIPANT	\N	PRESENT	0
418586	407001	01060R	PARTICIPANT	\N	PRESENT	0
418587	407001	14133K	PARTICIPANT	\N	PRESENT	0
418588	407001	19507S	PARTICIPANT	\N	PRESENT	0
418592	407001	19383Y	PARTICIPANT	\N	PRESENT	0
418590	407001	14265W	PARTICIPANT	\N	PRESENT	0
418591	407001	19333N	PARTICIPANT	\N	PRESENT	0
418596	407001	95030B	PARTICIPANT	\N	PRESENT	0
418594	407001	14109K	PARTICIPANT	\N	PRESENT	0
418595	407001	14219Q	PARTICIPANT	\N	PRESENT	0
418597	407001	11083R	PARTICIPANT	\N	PRESENT	0
418598	407001	19533U	PARTICIPANT	\N	PRESENT	0
418599	407001	08039A	PARTICIPANT	\N	PRESENT	0
418600	407001	14069U	PARTICIPANT	\N	PRESENT	0
418601	407001	14249W	PARTICIPANT	\N	PRESENT	0
418602	407001	14033T	PARTICIPANT	\N	PRESENT	0
418603	407001	14089Y	PARTICIPANT	\N	PRESENT	0
418604	407001	19782L	PARTICIPANT	\N	PRESENT	0
418605	407001	11064N	PARTICIPANT	\N	PRESENT	0
418606	407001	14147R	PARTICIPANT	\N	PRESENT	0
418607	407001	07029T	PARTICIPANT	\N	PRESENT	0
418564	407001	01043Q	PARTICIPANT	\N	PRESENT	0
418565	407001	96004D	PARTICIPANT	\N	PRESENT	0
418608	407001	14034U	PARTICIPANT	\N	PRESENT	0
418609	407001	14213J	PARTICIPANT	\N	PRESENT	0
418610	407001	14179A	PARTICIPANT	\N	PRESENT	0
418809	418808	10006L	PARTICIPANT	\N	PRESENT	0
418810	418808	08052W	PARTICIPANT	\N	PRESENT	0
418811	418808	19575F	PARTICIPANT	\N	PRESENT	0
418812	418808	19723Y	PARTICIPANT	\N	PRESENT	0
418814	418813	10006L	PARTICIPANT	\N	PRESENT	0
418815	418813	19575F	PARTICIPANT	\N	PRESENT	0
418816	418813	19723Y	PARTICIPANT	\N	PRESENT	0
418825	418820	10006L	PARTICIPANT	\N	PRESENT	0
418826	418820	08052W	PARTICIPANT	\N	PRESENT	0
418827	418820	14213J	PARTICIPANT	\N	PRESENT	0
418828	418820	11097X	PARTICIPANT	\N	PRESENT	0
418830	418829	14087W	PARTICIPANT	\N	PRESENT	0
418831	418829	19521Q	PARTICIPANT	\N	PRESENT	0
418832	418829	19679N	PARTICIPANT	\N	PRESENT	0
419029	415006	05012A	PARTICIPANT	\N	PRESENT	0
419059	415006	17637T	PARTICIPANT	\N	PRESENT	0
419031	415006	19503N	PARTICIPANT	\N	PRESENT	0
419032	415006	19347U	PARTICIPANT	\N	PRESENT	0
419033	415006	14157T	PARTICIPANT	\N	PRESENT	0
419034	415006	19685L	PARTICIPANT	\N	PRESENT	0
419060	415006	11065P	PARTICIPANT	\N	PRESENT	0
419036	415006	08024S	PARTICIPANT	\N	PRESENT	0
419061	415006	08055A	PARTICIPANT	\N	PRESENT	0
419038	415006	19525U	PARTICIPANT	\N	PRESENT	0
419039	415006	14038Y	PARTICIPANT	\N	PRESENT	0
419040	415006	14103D	PARTICIPANT	\N	PRESENT	0
419041	415006	19713W	PARTICIPANT	\N	PRESENT	0
419042	415006	14031R	PARTICIPANT	\N	PRESENT	0
419062	415006	19681G	PARTICIPANT	\N	PRESENT	0
419044	415006	14191V	PARTICIPANT	\N	PRESENT	0
419045	415006	14169X	PARTICIPANT	\N	PRESENT	0
419046	415006	15447F	PARTICIPANT	\N	PRESENT	0
419047	415006	14029X	PARTICIPANT	\N	PRESENT	0
419048	415006	19733B	PARTICIPANT	\N	PRESENT	0
419049	415006	08009T	PRESIDENT	0	PRESENT	0
419050	415006	19737F	PARTICIPANT	\N	PRESENT	0
419051	415006	04097T	PARTICIPANT	\N	PRESENT	0
419052	415006	19745F	PARTICIPANT	\N	PRESENT	0
419053	415006	14051J	PARTICIPANT	\N	EXCUSE	0
419056	419055	14031R	PARTICIPANT	\N	PRESENT	0
419057	415006	19387D	PARTICIPANT	\N	PRESENT	0
419058	415006	04085P	PARTICIPANT	\N	PRESENT	0
419063	417479	14063N	PARTICIPANT	\N	EXCUSE	0
419064	416795	01048V	PARTICIPANT	\N	PRESENT	0
419065	416795	11053K	PARTICIPANT	\N	PRESENT	0
419066	416795	08011M	PARTICIPANT	\N	EXCUSE	0
419067	416834	14327T	PARTICIPANT	\N	PRESENT	0
419068	416834	19479G	PARTICIPANT	\N	PRESENT	0
419069	416834	19711U	PARTICIPANT	\N	PRESENT	0
419070	416834	08034U	PARTICIPANT	\N	PRESENT	0
419071	416834	19545Y	PARTICIPANT	\N	PRESENT	0
419072	416834	19667J	PARTICIPANT	\N	PRESENT	0
419073	416834	08014Q	PARTICIPANT	\N	PRESENT	0
419074	416834	11070L	PARTICIPANT	\N	PRESENT	0
419137	419132	04038G	PARTICIPANT	\N	PRESENT	0
419076	416834	14083S	PARTICIPANT	\N	PRESENT	0
419077	416834	14277B	PARTICIPANT	\N	PRESENT	0
419078	416834	07004J	PARTICIPANT	\N	PRESENT	0
419079	416834	96004D	PARTICIPANT	\N	PRESENT	0
419080	416834	08010L	PARTICIPANT	\N	PRESENT	0
419140	419132	19489J	PARTICIPANT	\N	PRESENT	0
419082	416834	14331P	PARTICIPANT	\N	PRESENT	0
419083	416834	04071H	PARTICIPANT	\N	PRESENT	0
419084	416834	01048V	PARTICIPANT	\N	PRESENT	0
419085	416834	01057W	PARTICIPANT	\N	PRESENT	0
419086	416834	11074Q	PRESIDENT	0	PRESENT	0
419087	416834	89017R	PARTICIPANT	\N	PRESENT	0
419088	416834	07029T	PARTICIPANT	\N	PRESENT	0
419089	416834	19647E	PARTICIPANT	\N	PRESENT	0
419090	416834	14034U	PARTICIPANT	\N	PRESENT	0
419091	416834	04086Q	PARTICIPANT	\N	PRESENT	0
419092	416834	11040E	PARTICIPANT	\N	PRESENT	0
419093	416834	08073C	PARTICIPANT	\N	PRESENT	0
419094	416834	19741B	PARTICIPANT	\N	PRESENT	0
419096	416834	14085U	PARTICIPANT	\N	PRESENT	0
419100	416543	14255U	PARTICIPANT	\N	PRESENT	0
419101	419095	08068F	PARTICIPANT	\N	PRESENT	0
419102	416834	08011M	PARTICIPANT	\N	EXCUSE	0
419103	417145	19253P	PARTICIPANT	\N	EXCUSE	0
419104	419097	08068F	PARTICIPANT	\N	PRESENT	0
419105	415937	19569H	PARTICIPANT	\N	PRESENT	0
419106	415937	04045F	PARTICIPANT	\N	PRESENT	0
419107	415937	19553Y	PARTICIPANT	\N	PRESENT	0
419108	415937	14281W	PARTICIPANT	\N	PRESENT	0
419109	415937	19663E	PARTICIPANT	\N	PRESENT	0
419110	415937	19715Y	PARTICIPANT	\N	PRESENT	0
419111	416543	14028W	PARTICIPANT	\N	PRESENT	0
419112	419098	08068F	PARTICIPANT	\N	PRESENT	0
419113	419099	08068F	PARTICIPANT	\N	PRESENT	0
419133	407720	86034E	PARTICIPANT	\N	PRESENT	0
419134	407720	14107H	PARTICIPANT	\N	PRESENT	0
419135	407720	14267Y	PARTICIPANT	\N	PRESENT	0
419149	407720	14211G	PARTICIPANT	\N	PRESENT	0
419150	407720	12041X	PARTICIPANT	\N	PRESENT	0
419151	407720	19711U	PARTICIPANT	\N	PRESENT	0
419152	407720	19758L	PARTICIPANT	\N	PRESENT	0
419153	407720	04008A	PARTICIPANT	\N	PRESENT	0
419154	407720	04038G	PARTICIPANT	\N	PRESENT	0
419155	407720	19593H	PARTICIPANT	\N	PRESENT	0
419156	407720	14157T	PARTICIPANT	\N	PRESENT	0
419157	407720	19565D	PARTICIPANT	\N	PRESENT	0
419158	407720	19695N	PARTICIPANT	\N	PRESENT	0
419159	407720	96004D	PARTICIPANT	\N	PRESENT	0
419160	407720	19760E	PARTICIPANT	\N	PRESENT	0
419161	407720	11056N	PARTICIPANT	\N	PRESENT	0
419162	407720	11033F	PARTICIPANT	\N	PRESENT	0
419163	407720	99004R	PARTICIPANT	\N	PRESENT	0
419164	407720	11031D	PARTICIPANT	\N	PRESENT	0
419165	407720	11040E	PARTICIPANT	\N	PRESENT	0
419166	407720	04085P	PARTICIPANT	\N	PRESENT	0
419167	407720	19703U	PARTICIPANT	\N	PRESENT	0
419168	407720	19673G	PARTICIPANT	\N	PRESENT	0
419169	407720	14235Q	PARTICIPANT	\N	PRESENT	0
419170	407720	11010L	PARTICIPANT	\N	PRESENT	0
419171	407720	19667J	PARTICIPANT	\N	PRESENT	0
419172	407720	04045F	PARTICIPANT	\N	PRESENT	0
419173	407720	19347U	PARTICIPANT	\N	PRESENT	0
419174	407720	04034C	PARTICIPANT	\N	PRESENT	0
419175	407720	14038Y	PARTICIPANT	\N	PRESENT	0
419176	407720	19709B	PARTICIPANT	\N	PRESENT	0
419177	407720	19782L	PARTICIPANT	\N	PRESENT	0
419178	407720	14029X	PARTICIPANT	\N	PRESENT	0
419179	407720	08024S	PARTICIPANT	\N	PRESENT	0
394141	394139	19733B	PARTICIPANT	\N	PRESENT	0
394142	394139	19713W	PARTICIPANT	\N	PRESENT	0
394146	394145	14033T	PARTICIPANT	\N	PRESENT	0
394147	394145	19369B	PARTICIPANT	\N	PRESENT	0
397779	397778	14261S	PARTICIPANT	\N	PRESENT	0
397780	397778	14030Q	PRESIDENT	0	PRESENT	0
397781	397778	19701S	PARTICIPANT	\N	PRESENT	0
397783	397778	19715Y	PARTICIPANT	\N	PRESENT	0
397784	397778	19657G	PARTICIPANT	\N	PRESENT	0
397786	397778	11067R	PARTICIPANT	\N	PRESENT	0
397787	397778	19269X	PARTICIPANT	\N	PRESENT	0
397789	397778	11045K	PARTICIPANT	\N	PRESENT	0
397790	397778	19749K	PARTICIPANT	\N	PRESENT	0
397791	397778	07029T	PARTICIPANT	\N	EXCUSE	0
397792	397778	08019V	PARTICIPANT	\N	PRESENT	0
397793	397778	19691J	PARTICIPANT	\N	PRESENT	0
397799	397798	89017R	PARTICIPANT	\N	EXCUSE	0
397800	397798	14261S	PARTICIPANT	\N	PRESENT	0
397801	397798	14030Q	PARTICIPANT	\N	EXCUSE	0
397802	397798	08060W	PARTICIPANT	\N	EXCUSE	0
397803	397798	14105F	PARTICIPANT	\N	EXCUSE	0
397804	397798	08068F	PARTICIPANT	\N	PRESENT	0
397805	397798	14053L	PARTICIPANT	\N	EXCUSE	0
397806	397798	14083S	PARTICIPANT	\N	PRESENT	0
397807	397798	19545Y	PARTICIPANT	\N	EXCUSE	0
397808	397798	14079W	PARTICIPANT	\N	EXCUSE	0
397809	397798	14041T	PARTICIPANT	\N	EXCUSE	0
397810	397798	14151M	PARTICIPANT	\N	EXCUSE	0
397811	397798	14187A	PARTICIPANT	\N	PRESENT	0
397812	397798	14087W	PARTICIPANT	\N	PRESENT	0
397813	397798	14034U	PARTICIPANT	\N	EXCUSE	0
397816	397798	14026U	PARTICIPANT	\N	PRESENT	0
397819	397798	14121F	PARTICIPANT	\N	EXCUSE	0
397820	397798	14061L	PARTICIPANT	\N	PRESENT	0
397821	397798	04049K	PRESIDENT	0	PRESENT	0
397822	397798	08015R	PARTICIPANT	\N	EXCUSE	0
397823	397798	14265W	PARTICIPANT	\N	PRESENT	0
397824	397798	14253S	PARTICIPANT	\N	PRESENT	0
397825	397798	08047A	PARTICIPANT	\N	PRESENT	0
397826	397798	04088S	PARTICIPANT	\N	PRESENT	0
397827	397798	14051J	PARTICIPANT	\N	PRESENT	0
403112	400154	14357A	PARTICIPANT	\N	PRESENT	0
403113	400154	19762G	PARTICIPANT	\N	PRESENT	0
403114	400154	19657G	PARTICIPANT	\N	PRESENT	0
403115	400154	19467C	PARTICIPANT	\N	PRESENT	0
403116	400154	19673G	PARTICIPANT	\N	PRESENT	0
403117	400154	14111D	PARTICIPANT	\N	PRESENT	0
403118	400154	19585H	PARTICIPANT	\N	PRESENT	0
403119	400154	19719D	PARTICIPANT	\N	PRESENT	0
403120	400154	19333N	PARTICIPANT	\N	PRESENT	0
403121	400154	19629C	PARTICIPANT	\N	PRESENT	0
403122	400154	14053L	PARTICIPANT	\N	PRESENT	0
403123	400154	19533U	PARTICIPANT	\N	PRESENT	0
403124	400154	14157T	PARTICIPANT	\N	PRESENT	0
403125	400154	19693L	PARTICIPANT	\N	PRESENT	0
403126	400154	08014Q	PARTICIPANT	\N	PRESENT	0
403127	400154	14065Q	PARTICIPANT	\N	PRESENT	0
403128	400154	19715Y	PARTICIPANT	\N	PRESENT	0
403129	400154	04057K	PARTICIPANT	\N	PRESENT	0
403130	400154	17589D	PARTICIPANT	\N	PRESENT	0
403131	400154	19563B	PARTICIPANT	\N	PRESENT	0
403132	400154	19583F	PARTICIPANT	\N	PRESENT	0
403133	400154	08031R	PARTICIPANT	\N	PRESENT	0
403134	400154	14219Q	PARTICIPANT	\N	PRESENT	0
403135	400154	19369B	PARTICIPANT	\N	PRESENT	0
403136	400154	19335Q	PARTICIPANT	\N	PRESENT	0
403137	400154	14073Q	PARTICIPANT	\N	PRESENT	0
403138	400154	11097X	PARTICIPANT	\N	PRESENT	0
403139	400154	19671E	PARTICIPANT	\N	PRESENT	0
403140	400154	17637T	PARTICIPANT	\N	PRESENT	0
403141	400154	08069G	PARTICIPANT	\N	PRESENT	0
403142	400154	10015M	PARTICIPANT	\N	PRESENT	0
403143	400154	11101A	PARTICIPANT	\N	PRESENT	0
403144	400154	19723Y	PARTICIPANT	\N	PRESENT	0
403145	400154	14031R	PARTICIPANT	\N	PRESENT	0
403146	400154	14069U	PARTICIPANT	\N	PRESENT	0
403147	400154	14213J	PARTICIPANT	\N	PRESENT	0
403148	400154	14173T	PARTICIPANT	\N	PRESENT	0
403149	400154	14179A	PARTICIPANT	\N	PRESENT	0
403150	400154	11043H	PARTICIPANT	\N	PRESENT	0
403151	400154	19747H	PARTICIPANT	\N	PRESENT	0
403152	400154	14151M	PARTICIPANT	\N	PRESENT	0
403153	400154	14041T	PARTICIPANT	\N	PRESENT	0
403154	400154	14225N	PARTICIPANT	\N	PRESENT	0
403155	400154	19758L	PARTICIPANT	\N	PRESENT	0
403244	400170	04044E	PARTICIPANT	\N	PRESENT	0
403245	400170	14053L	PARTICIPANT	\N	PRESENT	0
403246	400170	19758L	PARTICIPANT	\N	PRESENT	0
403247	400170	11056N	PARTICIPANT	\N	PRESENT	0
403248	400170	14085U	PARTICIPANT	\N	PRESENT	0
403252	400170	01028R	PARTICIPANT	\N	PRESENT	0
403250	400170	19333N	PARTICIPANT	\N	PRESENT	0
403251	400170	08017T	PARTICIPANT	\N	PRESENT	0
403253	400170	05008E	PARTICIPANT	\N	PRESENT	0
403263	400170	04085P	PARTICIPANT	\N	PRESENT	0
403255	400170	04045F	PARTICIPANT	\N	PRESENT	0
403256	400170	19629C	PARTICIPANT	\N	PRESENT	0
403257	400170	19387D	PARTICIPANT	\N	PRESENT	0
403258	400170	04057K	PARTICIPANT	\N	PRESENT	0
403259	400170	19543W	PARTICIPANT	\N	PRESENT	0
403260	400170	17589D	PARTICIPANT	\N	PRESENT	0
403261	400170	19553Y	PARTICIPANT	\N	PRESENT	0
403262	400170	19715Y	PARTICIPANT	\N	PRESENT	0
403264	400170	19319Q	PARTICIPANT	\N	PRESENT	0
403265	400170	19699S	PARTICIPANT	\N	PRESENT	0
403266	400170	19745F	PARTICIPANT	\N	PRESENT	0
403267	400170	14073Q	PARTICIPANT	\N	PRESENT	0
403268	400170	19747H	PARTICIPANT	\N	PRESENT	0
403269	400170	14179A	PARTICIPANT	\N	PRESENT	0
403270	400170	19737F	PARTICIPANT	\N	PRESENT	0
403271	400170	11012A	PARTICIPANT	\N	PRESENT	0
403272	400170	14215L	PARTICIPANT	\N	PRESENT	0
403273	400170	14079W	PARTICIPANT	\N	PRESENT	0
403274	400170	19301E	PARTICIPANT	\N	PRESENT	0
403275	400170	04034C	PARTICIPANT	\N	PRESENT	0
403276	400170	14065Q	PARTICIPANT	\N	PRESENT	0
403277	400170	14061L	PARTICIPANT	\N	PRESENT	0
403278	400170	19762G	PARTICIPANT	\N	PRESENT	0
403279	400170	08028W	PARTICIPANT	\N	PRESENT	0
403280	400170	14147R	PARTICIPANT	\N	PRESENT	0
403281	400170	19693L	PARTICIPANT	\N	PRESENT	0
403282	400170	14041T	PARTICIPANT	\N	PRESENT	0
403283	400170	04088S	PARTICIPANT	\N	PRESENT	0
403284	400170	19467C	PARTICIPANT	\N	PRESENT	0
403285	400170	14157T	PARTICIPANT	\N	PRESENT	0
403286	400170	01057W	PARTICIPANT	\N	PRESENT	0
403287	400170	10015M	PARTICIPANT	\N	PRESENT	0
403288	400170	17637T	PARTICIPANT	\N	PRESENT	0
403289	400170	19703U	PARTICIPANT	\N	PRESENT	0
403290	400170	19713W	PARTICIPANT	\N	PRESENT	0
403291	400170	19563B	PARTICIPANT	\N	PRESENT	0
403292	400170	08068F	PARTICIPANT	\N	PRESENT	0
403293	400170	14151M	PARTICIPANT	\N	PRESENT	0
403294	400170	14225N	PARTICIPANT	\N	PRESENT	0
403295	400170	11043H	PARTICIPANT	\N	PRESENT	0
403296	400170	17583W	PARTICIPANT	\N	PRESENT	0
403297	400170	14097Y	PARTICIPANT	\N	PRESENT	0
403298	400170	19441R	PARTICIPANT	\N	PRESENT	0
403299	400170	11049P	PARTICIPANT	\N	PRESENT	0
403300	400170	01058X	PARTICIPANT	\N	PRESENT	0
403301	400170	95030B	PARTICIPANT	\N	PRESENT	0
403302	400170	19657G	PARTICIPANT	\N	PRESENT	0
403303	400170	14069U	PARTICIPANT	\N	PRESENT	0
403304	400170	19711U	PARTICIPANT	\N	PRESENT	0
403305	400170	04018C	PARTICIPANT	\N	PRESENT	0
403306	400170	14123H	PARTICIPANT	\N	PRESENT	0
403307	400170	11072N	PARTICIPANT	\N	PRESENT	0
403308	400170	19741B	PARTICIPANT	\N	PRESENT	0
403309	400170	14051J	PARTICIPANT	\N	PRESENT	0
403310	400170	11083R	PARTICIPANT	\N	PRESENT	0
403311	400170	19585H	PARTICIPANT	\N	PRESENT	0
403312	400170	14089Y	PARTICIPANT	\N	PRESENT	0
403313	400170	14239U	PARTICIPANT	\N	PRESENT	0
403314	400170	04035D	PARTICIPANT	\N	PRESENT	0
403315	400170	14030Q	PARTICIPANT	\N	PRESENT	0
403316	400170	04043D	PARTICIPANT	\N	PRESENT	0
403317	400170	11103C	PARTICIPANT	\N	PRESENT	0
403318	400170	19760E	PARTICIPANT	\N	PRESENT	0
403319	400170	19349W	PARTICIPANT	\N	PRESENT	0
403320	400170	19812Y	PARTICIPANT	\N	PRESENT	0
403321	400170	11041F	PARTICIPANT	\N	PRESENT	0
418833	416795	14327T	PARTICIPANT	\N	PRESENT	0
418834	416795	14331P	PARTICIPANT	\N	PRESENT	0
418835	416795	04071H	PARTICIPANT	\N	PRESENT	0
418836	416795	95041E	PARTICIPANT	\N	PRESENT	0
418837	416795	19545Y	PARTICIPANT	\N	PRESENT	0
418838	416795	01057W	PARTICIPANT	\N	PRESENT	0
418839	416795	11074Q	PRESIDENT	0	PRESENT	0
418840	416795	89017R	PARTICIPANT	\N	PRESENT	0
418841	416795	19667J	PARTICIPANT	\N	PRESENT	0
418842	416795	88008L	PARTICIPANT	\N	PRESENT	0
418843	416795	11070L	PARTICIPANT	\N	PRESENT	0
418844	416795	14225N	PARTICIPANT	\N	PRESENT	0
418845	416795	07029T	PARTICIPANT	\N	PRESENT	0
418846	416795	14085U	PARTICIPANT	\N	PRESENT	0
418847	416795	14277B	PARTICIPANT	\N	PRESENT	0
418848	416795	07004J	PARTICIPANT	\N	PRESENT	0
418849	416795	96004D	PARTICIPANT	\N	PRESENT	0
418850	416795	19349W	PARTICIPANT	\N	PRESENT	0
418851	416795	08010L	PARTICIPANT	\N	PRESENT	0
418852	416795	14253S	PARTICIPANT	\N	PRESENT	0
418853	416795	11048N	PARTICIPANT	\N	PRESENT	0
418854	416795	19479G	PARTICIPANT	\N	PRESENT	0
418855	416795	19647E	PARTICIPANT	\N	PRESENT	0
418856	416795	19711U	PARTICIPANT	\N	PRESENT	0
418857	416795	19651A	PARTICIPANT	\N	PRESENT	0
418858	416795	08034U	PARTICIPANT	\N	PRESENT	0
418859	416795	08069G	PARTICIPANT	\N	PRESENT	0
418860	416795	19687N	PARTICIPANT	\N	PRESENT	0
418861	416795	19689Q	PARTICIPANT	\N	PRESENT	0
418862	416795	12016W	PARTICIPANT	\N	PRESENT	0
418863	416795	14034U	PARTICIPANT	\N	PRESENT	0
418864	416795	08014Q	PARTICIPANT	\N	PRESENT	0
418865	416795	14159V	PARTICIPANT	\N	PRESENT	0
418866	416795	14173T	PARTICIPANT	\N	PRESENT	0
418867	416795	04086Q	PARTICIPANT	\N	PRESENT	0
418868	416795	11040E	PARTICIPANT	\N	PRESENT	0
418869	416795	14083S	PARTICIPANT	\N	PRESENT	0
418870	416795	11012A	PARTICIPANT	\N	PRESENT	0
418871	416795	14199E	PARTICIPANT	\N	PRESENT	0
418872	416795	08073C	PARTICIPANT	\N	PRESENT	0
418873	416795	14121F	PARTICIPANT	\N	PRESENT	0
418874	416795	19741B	PARTICIPANT	\N	PRESENT	0
418875	416795	99004R	PARTICIPANT	\N	PRESENT	0
418876	416166	19269X	PARTICIPANT	\N	PRESENT	0
418877	415001	02002K	PARTICIPANT	\N	PRESENT	0
418878	415001	04069P	PARTICIPANT	\N	PRESENT	0
418882	418881	14221J	PARTICIPANT	\N	PRESENT	0
418883	416543	11115U	PARTICIPANT	\N	PRESENT	0
418885	417389	01060R	PARTICIPANT	\N	PRESENT	0
418886	417389	14001X	PARTICIPANT	\N	PRESENT	0
418887	417389	19543W	PARTICIPANT	\N	PRESENT	0
418888	417389	19581D	PARTICIPANT	\N	PRESENT	0
418889	417389	04044E	PARTICIPANT	\N	PRESENT	0
418890	417389	04047H	PRESIDENT	0	PRESENT	0
418891	417389	19673G	PARTICIPANT	\N	PRESENT	0
418892	417389	01028R	PARTICIPANT	\N	PRESENT	0
418893	417389	14231L	PARTICIPANT	\N	PRESENT	0
418894	417389	19447X	PARTICIPANT	\N	PRESENT	0
418895	417389	05008E	PRESIDENT	1	PRESENT	0
418896	417389	19489J	PARTICIPANT	\N	PRESENT	0
418897	417389	14275Y	PARTICIPANT	\N	PRESENT	0
418898	417389	14041T	PARTICIPANT	\N	PRESENT	0
418899	417389	14147R	PARTICIPANT	\N	PRESENT	0
418900	417389	14215L	PARTICIPANT	\N	PRESENT	0
418901	417389	08018U	PARTICIPANT	\N	PRESENT	0
418902	417389	14053L	PARTICIPANT	\N	PRESENT	0
418903	417389	14111D	PARTICIPANT	\N	PRESENT	0
418904	417389	19649G	PARTICIPANT	\N	PRESENT	0
418905	417389	14065Q	PARTICIPANT	\N	PRESENT	0
418906	417389	11010L	PARTICIPANT	\N	PRESENT	0
418907	417389	10015M	PARTICIPANT	\N	PRESENT	0
418908	417389	08045X	PARTICIPANT	\N	PRESENT	0
418909	417389	19253P	PARTICIPANT	\N	PRESENT	0
418910	417389	01024M	PARTICIPANT	\N	PRESENT	0
418911	417389	04038G	PARTICIPANT	\N	PRESENT	0
418914	417389	19719D	PARTICIPANT	\N	PRESENT	0
418916	417389	11033F	PARTICIPANT	\N	PRESENT	0
418918	417389	19725B	PARTICIPANT	\N	PRESENT	0
418920	417389	14089Y	PARTICIPANT	\N	PRESENT	0
418922	417389	19729F	PARTICIPANT	\N	PRESENT	0
418924	417389	95063L	PARTICIPANT	\N	PRESENT	0
418926	417389	08044W	PARTICIPANT	\N	PRESENT	0
418928	417389	14069U	PARTICIPANT	\N	PRESENT	0
418930	417389	11085T	PARTICIPANT	\N	PRESENT	0
418932	417389	04008A	PARTICIPANT	\N	PRESENT	0
418933	417389	19762G	PARTICIPANT	\N	PRESENT	0
418934	417389	11026G	PARTICIPANT	\N	PRESENT	0
418937	417389	11049P	PARTICIPANT	\N	PRESENT	0
418966	416167	19768N	PARTICIPANT	\N	PRESENT	0
418967	416167	19515S	PARTICIPANT	\N	PRESENT	0
418968	416167	11077T	PARTICIPANT	\N	PRESENT	0
418969	416167	19782L	PARTICIPANT	\N	PRESENT	0
418970	416167	01043Q	PARTICIPANT	\N	PRESENT	0
418971	416167	19441R	PARTICIPANT	\N	PRESENT	0
418972	416167	19413M	PARTICIPANT	\N	PRESENT	0
418973	416167	14081Q	PARTICIPANT	\N	PRESENT	0
418974	416167	80013X	PARTICIPANT	\N	PRESENT	0
418975	416167	19631V	PARTICIPANT	\N	PRESENT	0
418976	416167	11099A	PARTICIPANT	\N	PRESENT	0
418977	416167	08068F	PARTICIPANT	\N	PRESENT	0
418711	415937	19679N	PARTICIPANT	\N	PRESENT	0
418712	415937	14042U	PARTICIPANT	\N	PRESENT	0
418713	415937	14195A	PARTICIPANT	\N	PRESENT	0
418714	415937	19575F	PARTICIPANT	\N	PRESENT	0
418715	415937	14213J	PARTICIPANT	\N	PRESENT	0
418716	415937	14217N	PARTICIPANT	\N	PRESENT	0
418717	415937	14261S	PARTICIPANT	\N	PRESENT	0
418718	415937	10006L	PARTICIPANT	\N	PRESENT	0
418719	415937	19683J	PARTICIPANT	\N	PRESENT	0
418720	415937	98024R	PRESIDENT	1	PRESENT	0
418721	415937	19521Q	PARTICIPANT	\N	PRESENT	0
418722	415937	04092N	PRESIDENT	0	PRESENT	0
418723	415937	08052W	PARTICIPANT	\N	PRESENT	0
418724	415937	19723Y	PARTICIPANT	\N	PRESENT	0
418725	415937	19727D	PARTICIPANT	\N	PRESENT	0
418726	415937	14119M	PARTICIPANT	\N	PRESENT	0
418727	415937	14071N	PARTICIPANT	\N	PRESENT	0
418728	415937	19760E	PARTICIPANT	\N	PRESENT	0
418729	415937	08041T	PARTICIPANT	\N	EXCUSE	0
418730	417479	14030Q	PARTICIPANT	\N	PRESENT	0
418731	417479	11083R	PARTICIPANT	\N	PRESENT	0
418732	417479	14123H	PARTICIPANT	\N	PRESENT	0
418978	416167	04049K	PARTICIPANT	\N	PRESENT	0
418979	416167	19705W	PARTICIPANT	\N	PRESENT	0
418980	416167	08015R	PARTICIPANT	\N	PRESENT	0
418981	416167	14197C	PARTICIPANT	\N	PRESENT	0
418982	416167	19369B	PARTICIPANT	\N	PRESENT	0
418983	416167	19511N	PARTICIPANT	\N	PRESENT	0
418984	416167	08028W	PARTICIPANT	\N	PRESENT	0
418985	416167	14265W	PARTICIPANT	\N	PRESENT	0
418986	416167	14329V	PARTICIPANT	\N	PRESENT	0
418987	416167	14135M	PARTICIPANT	\N	PRESENT	0
418988	416167	19467C	PARTICIPANT	\N	PRESENT	0
418989	416167	14187A	PARTICIPANT	\N	PRESENT	0
418990	416167	08038Y	PARTICIPANT	\N	PRESENT	0
418991	416167	08062Y	PARTICIPANT	\N	PRESENT	0
418992	416167	19695N	PARTICIPANT	\N	PRESENT	0
418993	416167	01025N	PARTICIPANT	\N	PRESENT	0
418994	416167	11090Q	PRESIDENT	0	PRESENT	0
418995	416167	14033T	PARTICIPANT	\N	PRESENT	0
418996	416167	19269X	PARTICIPANT	\N	PRESENT	0
418997	416167	14205J	PARTICIPANT	\N	PRESENT	0
418998	416167	04088S	PARTICIPANT	\N	PRESENT	0
418999	416167	11056N	PARTICIPANT	\N	PRESENT	0
419000	416167	04089T	PARTICIPANT	\N	PRESENT	0
419001	416167	14115H	PARTICIPANT	\N	PRESENT	0
419002	416167	19507S	PARTICIPANT	\N	PRESENT	0
419003	416167	11101A	PARTICIPANT	\N	PRESENT	0
419004	416167	14207L	PARTICIPANT	\N	PRESENT	0
419005	416167	04043D	PARTICIPANT	\N	PRESENT	0
419006	416167	14257W	PARTICIPANT	\N	PRESENT	0
419009	415001	19685L	PARTICIPANT	\N	PRESENT	0
419012	415006	19333N	PARTICIPANT	\N	PRESENT	0
419013	415006	19383Y	PARTICIPANT	\N	PRESENT	0
419014	415006	17583W	PARTICIPANT	\N	PRESENT	0
419015	415006	19701S	PARTICIPANT	\N	PRESENT	0
419016	415006	19794Q	PARTICIPANT	\N	PRESENT	0
419017	415006	19549D	PARTICIPANT	\N	PRESENT	0
419018	415006	04069P	PARTICIPANT	\N	PRESENT	0
419020	415006	14219Q	PARTICIPANT	\N	PRESENT	0
419021	415006	19820Y	PARTICIPANT	\N	PRESENT	0
419022	415006	19826F	PARTICIPANT	\N	PRESENT	0
419023	415006	14221J	PARTICIPANT	\N	PRESENT	0
419024	415006	19599P	PARTICIPANT	\N	PRESENT	0
419025	415006	19637C	PARTICIPANT	\N	PRESENT	0
419026	415006	02002K	PARTICIPANT	\N	PRESENT	0
419027	415006	14237S	PARTICIPANT	\N	PRESENT	0
419028	415006	19551W	PARTICIPANT	\N	PRESENT	0
400640	393604	05008E	PARTICIPANT	\N	PRESENT	0
400641	393604	14217N	PARTICIPANT	\N	PRESENT	0
400642	393604	14215L	PARTICIPANT	\N	PRESENT	0
400643	393604	11064N	PARTICIPANT	\N	PRESENT	0
401921	393612	11103C	PARTICIPANT	\N	PRESENT	0
402107	393620	11072N	PARTICIPANT	\N	PRESENT	0
402127	393620	19251M	PARTICIPANT	\N	PRESENT	0
402128	393620	19413M	PARTICIPANT	\N	PRESENT	0
402129	393620	19333N	PARTICIPANT	\N	PRESENT	0
402130	393620	80013X	PARTICIPANT	\N	PRESENT	0
402131	393620	08035V	PARTICIPANT	\N	PRESENT	0
402132	393620	19503N	PARTICIPANT	\N	PRESENT	0
402133	393620	14033T	PARTICIPANT	\N	PRESENT	0
402134	393620	11012A	PARTICIPANT	\N	PRESENT	0
402135	393620	19695N	PARTICIPANT	\N	PRESENT	0
402136	393620	19387D	PARTICIPANT	\N	PRESENT	0
402137	393620	11065P	PARTICIPANT	\N	PRESENT	0
402138	393620	14107H	PARTICIPANT	\N	PRESENT	0
402139	393620	17589D	PARTICIPANT	\N	PRESENT	0
402140	393620	11066Q	PARTICIPANT	\N	PRESENT	0
402141	393620	14042U	PARTICIPANT	\N	PRESENT	0
402142	393620	19737F	PARTICIPANT	\N	PRESENT	0
402143	393620	08009T	PARTICIPANT	\N	PRESENT	0
402144	393620	19399H	PARTICIPANT	\N	PRESENT	0
402145	393620	11090Q	PARTICIPANT	\N	PRESENT	0
402146	393620	04088S	PARTICIPANT	\N	PRESENT	0
402147	393620	18083K	PARTICIPANT	\N	PRESENT	0
402148	393620	14119M	PARTICIPANT	\N	PRESENT	0
402149	393620	14157T	PARTICIPANT	\N	PRESENT	0
402150	393620	19515S	PARTICIPANT	\N	PRESENT	0
402151	393620	11067R	PARTICIPANT	\N	PRESENT	0
402152	393620	11077T	PARTICIPANT	\N	PRESENT	0
402153	393620	11048N	PARTICIPANT	\N	PRESENT	0
402154	393620	19782L	PARTICIPANT	\N	PRESENT	0
402155	393620	19758L	PARTICIPANT	\N	PRESENT	0
402156	393620	97011G	PARTICIPANT	\N	PRESENT	0
402157	393620	11103C	PARTICIPANT	\N	PRESENT	0
402158	393620	14187A	PARTICIPANT	\N	PRESENT	0
402159	393620	11033F	PARTICIPANT	\N	PRESENT	0
402161	393620	19747H	PARTICIPANT	\N	PRESENT	0
402167	393620	19798U	PARTICIPANT	\N	PRESENT	0
402177	393620	14081Q	PARTICIPANT	\N	PRESENT	0
402181	393620	08068F	PARTICIPANT	\N	PRESENT	0
402182	393620	14083S	PARTICIPANT	\N	PRESENT	0
402183	393620	14215L	PARTICIPANT	\N	PRESENT	0
402184	393620	19733B	PARTICIPANT	\N	PRESENT	0
402185	393620	14135M	PARTICIPANT	\N	PRESENT	0
402186	393620	14041T	PARTICIPANT	\N	PRESENT	0
402187	393620	19553Y	PARTICIPANT	\N	PRESENT	0
402188	393620	14329V	PARTICIPANT	\N	PRESENT	0
402189	393620	98050T	PARTICIPANT	\N	PRESENT	0
402190	393620	19467C	PARTICIPANT	\N	PRESENT	0
402191	393620	96004D	PARTICIPANT	\N	PRESENT	0
402192	393620	08060W	PARTICIPANT	\N	PRESENT	0
402193	393620	14357A	PARTICIPANT	\N	PRESENT	0
402194	393620	19349W	PARTICIPANT	\N	PRESENT	0
402195	393620	14031R	PARTICIPANT	\N	PRESENT	0
402196	393620	14331P	PARTICIPANT	\N	PRESENT	0
402197	393620	19533U	PARTICIPANT	\N	PRESENT	0
402198	393620	14197C	PARTICIPANT	\N	PRESENT	0
402199	393620	14205J	PARTICIPANT	\N	PRESENT	0
402200	393620	19369B	PARTICIPANT	\N	PRESENT	0
402201	393620	08056B	PARTICIPANT	\N	PRESENT	0
402202	393620	04049K	PARTICIPANT	\N	PRESENT	0
402203	393620	19711U	PARTICIPANT	\N	PRESENT	0
402204	393620	19347U	PARTICIPANT	\N	PRESENT	0
402498	393625	19695N	PARTICIPANT	\N	PRESENT	0
402499	393625	19699S	PARTICIPANT	\N	PRESENT	0
402500	393625	14219Q	PARTICIPANT	\N	PRESENT	0
402501	393625	19369B	PARTICIPANT	\N	PRESENT	0
402502	393625	11053K	PARTICIPANT	\N	PRESENT	0
402503	393625	19737F	PARTICIPANT	\N	PRESENT	0
402504	393625	19739H	PARTICIPANT	\N	PRESENT	0
402505	393625	14205J	PARTICIPANT	\N	PRESENT	0
402506	393625	19533U	PARTICIPANT	\N	PRESENT	0
402507	393625	19749K	PARTICIPANT	\N	PRESENT	0
402508	393625	14123H	PARTICIPANT	\N	PRESENT	0
402509	393625	19335Q	PARTICIPANT	\N	PRESENT	0
402510	393625	19745F	PARTICIPANT	\N	PRESENT	0
402511	393625	19521Q	PARTICIPANT	\N	PRESENT	0
402512	393625	14083S	PARTICIPANT	\N	PRESENT	0
402513	393625	11085T	PARTICIPANT	\N	PRESENT	0
402514	393625	14030Q	PARTICIPANT	\N	PRESENT	0
402515	393625	14327T	PARTICIPANT	\N	PRESENT	0
402516	393625	14215L	PARTICIPANT	\N	PRESENT	0
402517	393625	08056B	PARTICIPANT	\N	PRESENT	0
402518	393625	04071H	PARTICIPANT	\N	PRESENT	0
402519	393625	08017T	PARTICIPANT	\N	PRESENT	0
402520	393625	19413M	PARTICIPANT	\N	PRESENT	0
402521	393625	01048V	PARTICIPANT	\N	PRESENT	0
402522	393625	14061L	PARTICIPANT	\N	PRESENT	0
402523	393625	19673G	PARTICIPANT	\N	PRESENT	0
402524	393625	04044E	PARTICIPANT	\N	PRESENT	0
402525	393625	14039A	PARTICIPANT	\N	PRESENT	0
402526	393625	11072N	PARTICIPANT	\N	PRESENT	0
402527	393625	11049P	PARTICIPANT	\N	PRESENT	0
402528	393625	19319Q	PARTICIPANT	\N	PRESENT	0
402529	393625	19269X	PARTICIPANT	\N	PRESENT	0
402530	393625	14093U	PARTICIPANT	\N	PRESENT	0
402531	393625	19611R	PARTICIPANT	\N	PRESENT	0
402538	393625	14257W	PARTICIPANT	\N	PRESENT	0
402545	393625	19347U	PARTICIPANT	\N	PRESENT	0
402547	393625	07029T	PARTICIPANT	\N	PRESENT	0
402548	393625	08048B	PARTICIPANT	\N	PRESENT	0
402549	393625	19447X	PARTICIPANT	\N	PRESENT	0
402550	393625	19667J	PARTICIPANT	\N	PRESENT	0
402551	393625	14055N	PARTICIPANT	\N	PRESENT	0
402552	393625	14169X	PARTICIPANT	\N	PRESENT	0
402553	393625	19701S	PARTICIPANT	\N	PRESENT	0
402554	393625	08018U	PARTICIPANT	\N	PRESENT	0
402555	393625	80013X	PARTICIPANT	\N	PRESENT	0
402556	393625	11065P	PARTICIPANT	\N	PRESENT	0
402724	393628	04086Q	PARTICIPANT	\N	PRESENT	0
402726	393628	11090Q	PARTICIPANT	\N	PRESENT	0
402727	393628	14033T	PARTICIPANT	\N	PRESENT	0
402728	393628	11067R	PARTICIPANT	\N	PRESENT	0
402729	393628	04043D	PARTICIPANT	\N	PRESENT	0
402730	393628	19651A	PARTICIPANT	\N	PRESENT	0
402732	393628	17589D	PARTICIPANT	\N	PRESENT	0
402734	393628	14041T	PARTICIPANT	\N	PRESENT	0
402736	393628	14157T	PARTICIPANT	\N	PRESENT	0
402739	393628	80013X	PARTICIPANT	\N	PRESENT	0
402743	393628	11033F	PARTICIPANT	\N	PRESENT	0
402751	393628	19333N	PARTICIPANT	\N	PRESENT	0
402752	393628	19551W	PARTICIPANT	\N	PRESENT	0
402753	393628	19782L	PARTICIPANT	\N	PRESENT	0
402754	393628	14030Q	PARTICIPANT	\N	PRESENT	0
402755	393628	19794Q	PARTICIPANT	\N	PRESENT	0
402756	393628	04088S	PARTICIPANT	\N	PRESENT	0
402757	393628	04018C	PARTICIPANT	\N	PRESENT	0
402758	393628	19695N	PARTICIPANT	\N	PRESENT	0
402759	393628	11056N	PARTICIPANT	\N	PRESENT	0
402760	393628	14357A	PARTICIPANT	\N	PRESENT	0
402761	393628	19251M	PARTICIPANT	\N	PRESENT	0
402762	393628	01058X	PARTICIPANT	\N	PRESENT	0
402763	393628	19711U	PARTICIPANT	\N	PRESENT	0
402764	393628	08035V	PARTICIPANT	\N	PRESENT	0
402765	393628	19503N	PARTICIPANT	\N	PRESENT	0
402766	393628	19467C	PARTICIPANT	\N	PRESENT	0
402767	393628	04049K	PARTICIPANT	\N	PRESENT	0
402768	393628	19737F	PARTICIPANT	\N	PRESENT	0
402769	393628	19733B	PARTICIPANT	\N	PRESENT	0
402770	393628	14251Q	PARTICIPANT	\N	PRESENT	0
402771	393628	11065P	PARTICIPANT	\N	PRESENT	0
402772	393628	14207L	PARTICIPANT	\N	PRESENT	0
402778	393628	14042U	PARTICIPANT	\N	PRESENT	0
402780	393628	11048N	PARTICIPANT	\N	PRESENT	0
402781	393628	19643A	PARTICIPANT	\N	PRESENT	0
402782	393628	19269X	PARTICIPANT	\N	PRESENT	0
402783	393628	19687N	PARTICIPANT	\N	PRESENT	0
402784	393628	14329V	PARTICIPANT	\N	PRESENT	0
402785	393628	08020N	PARTICIPANT	\N	PRESENT	0
402786	393628	19447X	PARTICIPANT	\N	PRESENT	0
402790	393628	01028R	PARTICIPANT	\N	PRESENT	0
402795	393628	14135M	PARTICIPANT	\N	PRESENT	0
402796	393628	19543W	PARTICIPANT	\N	PRESENT	0
402797	393628	08034U	PARTICIPANT	\N	PRESENT	0
402798	393628	19533U	PARTICIPANT	\N	PRESENT	0
402799	393628	14081Q	PARTICIPANT	\N	PRESENT	0
402800	393628	11012A	PARTICIPANT	\N	PRESENT	0
402801	393628	07029T	PARTICIPANT	\N	PRESENT	0
402802	393628	19319Q	PARTICIPANT	\N	PRESENT	0
402803	393628	14205J	PARTICIPANT	\N	PRESENT	0
402804	393628	01048V	PARTICIPANT	\N	PRESENT	0
402805	393628	19399H	PARTICIPANT	\N	PRESENT	0
402806	393628	14169X	PARTICIPANT	\N	PRESENT	0
402807	393628	19701S	PARTICIPANT	\N	PRESENT	0
402808	393628	14083S	PARTICIPANT	\N	PRESENT	0
412791	406844	01060R	PARTICIPANT	\N	PRESENT	0
412792	406844	11026G	PARTICIPANT	\N	PRESENT	0
419180	407720	19651A	PARTICIPANT	\N	PRESENT	0
419181	407720	19663E	PARTICIPANT	\N	PRESENT	0
419182	407720	04088S	PARTICIPANT	\N	PRESENT	0
419183	407720	08073C	PARTICIPANT	\N	PRESENT	0
419184	407720	08018U	PARTICIPANT	\N	PRESENT	0
419185	407720	14039A	PARTICIPANT	\N	PRESENT	0
419186	407720	07029T	PARTICIPANT	\N	PRESENT	0
419187	407720	19697Q	PARTICIPANT	\N	PRESENT	0
419188	407720	19543W	PARTICIPANT	\N	PRESENT	0
419190	407720	19349W	PARTICIPANT	\N	PRESENT	0
419191	407720	19729F	PARTICIPANT	\N	PRESENT	0
419192	407720	14239U	PARTICIPANT	\N	PRESENT	0
419193	407720	08015R	PARTICIPANT	\N	PRESENT	0
419194	407720	11083R	PARTICIPANT	\N	PRESENT	0
419195	407720	95063L	PARTICIPANT	\N	PRESENT	0
419196	407720	98050T	PARTICIPANT	\N	PRESENT	0
419197	407720	95037J	PARTICIPANT	\N	PRESENT	0
419198	407720	14069U	PARTICIPANT	\N	PRESENT	0
419199	407720	08061X	PARTICIPANT	\N	PRESENT	0
419200	407720	14041T	PARTICIPANT	\N	PRESENT	0
419201	407720	19705W	PARTICIPANT	\N	PRESENT	0
419202	407720	14207L	PARTICIPANT	\N	PRESENT	0
419203	407720	14061L	PARTICIPANT	\N	PRESENT	0
419204	407720	19289C	PARTICIPANT	\N	PRESENT	0
419205	407720	14059S	PARTICIPANT	\N	PRESENT	0
419206	407720	19719D	PARTICIPANT	\N	PRESENT	0
419207	407720	98022P	PARTICIPANT	\N	PRESENT	0
419208	407720	19733B	PARTICIPANT	\N	PRESENT	0
419209	407720	11065P	PARTICIPANT	\N	PRESENT	0
419210	407720	14241N	PARTICIPANT	\N	PRESENT	0
419211	407720	19467C	PARTICIPANT	\N	PRESENT	0
419212	407720	14201E	PARTICIPANT	\N	PRESENT	0
419213	407720	14033T	PARTICIPANT	\N	PRESENT	0
419214	407720	19253P	PARTICIPANT	\N	PRESENT	0
419215	407720	14135M	PARTICIPANT	\N	PRESENT	0
419216	407720	98029W	PARTICIPANT	\N	PRESENT	0
419217	407720	19399H	PARTICIPANT	\N	PRESENT	0
419218	407720	19693L	PARTICIPANT	\N	PRESENT	0
419219	407720	08049C	PARTICIPANT	\N	PRESENT	0
419220	407720	14261S	PARTICIPANT	\N	PRESENT	0
419221	407720	08048B	PARTICIPANT	\N	PRESENT	0
419222	407720	14265W	PARTICIPANT	\N	PRESENT	0
419223	407720	19553Y	PARTICIPANT	\N	PRESENT	0
419224	407720	14213J	PARTICIPANT	\N	PRESENT	0
419225	407720	14329V	PARTICIPANT	\N	PRESENT	0
419226	407720	14357A	PARTICIPANT	\N	PRESENT	0
419228	407720	19383Y	PARTICIPANT	\N	PRESENT	0
419230	407720	19701S	PARTICIPANT	\N	PRESENT	0
419232	407720	19269X	PARTICIPANT	\N	PRESENT	0
419233	407720	04018C	PARTICIPANT	\N	PRESENT	0
419235	407720	19621T	PARTICIPANT	\N	PRESENT	0
419237	407720	01060R	PARTICIPANT	\N	PRESENT	0
419239	407720	19685L	PARTICIPANT	\N	PRESENT	0
419240	407720	19367Y	PARTICIPANT	\N	PRESENT	0
419241	407720	08056B	PARTICIPANT	\N	PRESENT	0
419243	407720	14173T	PARTICIPANT	\N	PRESENT	0
419245	407720	19447X	PARTICIPANT	\N	PRESENT	0
419246	407720	19545Y	PARTICIPANT	\N	PRESENT	0
419248	407720	14111D	PARTICIPANT	\N	PRESENT	0
419249	407720	04057K	PARTICIPANT	\N	PRESENT	0
419250	407720	14251Q	PARTICIPANT	\N	PRESENT	0
419252	407720	19573D	PARTICIPANT	\N	PRESENT	0
419253	407720	19794Q	PARTICIPANT	\N	PRESENT	0
419254	407720	11064N	PARTICIPANT	\N	PRESENT	0
419255	407720	14133K	PARTICIPANT	\N	PRESENT	0
419257	407720	14195A	PARTICIPANT	\N	PRESENT	0
419258	407720	92040Q	PARTICIPANT	\N	PRESENT	0
419259	407720	11049P	PARTICIPANT	\N	PRESENT	0
419260	407720	11012A	PARTICIPANT	\N	PRESENT	0
419262	407720	14115H	PARTICIPANT	\N	PRESENT	0
419263	407720	08047A	PARTICIPANT	\N	PRESENT	0
419264	407720	17583W	PARTICIPANT	\N	PRESENT	0
419265	407720	14159V	PARTICIPANT	\N	PRESENT	0
419266	407720	14147R	PARTICIPANT	\N	PRESENT	0
419267	407720	11027H	PARTICIPANT	\N	PRESENT	0
419268	407720	97011G	PARTICIPANT	\N	PRESENT	0
419269	407720	14217N	PARTICIPANT	\N	PRESENT	0
419270	407720	04069P	PARTICIPANT	\N	PRESENT	0
419272	407720	11074Q	PARTICIPANT	\N	PRESENT	0
419273	407720	14079W	PARTICIPANT	\N	PRESENT	0
419274	407720	19581D	PARTICIPANT	\N	PRESENT	0
419275	407720	11115U	PARTICIPANT	\N	PRESENT	0
419276	407720	19507S	PARTICIPANT	\N	PRESENT	0
419277	407720	14199E	PARTICIPANT	\N	PRESENT	0
419278	407720	19575F	PARTICIPANT	\N	PRESENT	0
419279	407720	14253S	PARTICIPANT	\N	PRESENT	0
419280	407720	11048N	PARTICIPANT	\N	PRESENT	0
419281	407720	05012A	PARTICIPANT	\N	PRESENT	0
419282	407720	04049K	PARTICIPANT	\N	PRESENT	0
419283	407720	08034U	PARTICIPANT	\N	PRESENT	0
419284	407720	19533U	PARTICIPANT	\N	PRESENT	0
419285	407720	08068F	PARTICIPANT	\N	PRESENT	0
419286	407720	10006L	PARTICIPANT	\N	PRESENT	0
419287	407720	08038Y	PARTICIPANT	\N	PRESENT	0
419288	407720	19798U	PARTICIPANT	\N	PRESENT	0
419289	407720	01062T	PARTICIPANT	\N	PRESENT	0
419290	407720	19413M	PARTICIPANT	\N	PRESENT	0
419291	407720	14193X	PARTICIPANT	\N	PRESENT	0
419292	407720	11026G	PARTICIPANT	\N	PRESENT	0
419293	407720	19515S	PARTICIPANT	\N	PRESENT	0
419294	407720	19503N	PARTICIPANT	\N	PRESENT	0
419295	407720	14191V	PARTICIPANT	\N	PRESENT	0
419296	407720	14259Y	PARTICIPANT	\N	PRESENT	0
419297	407720	01057W	PARTICIPANT	\N	PRESENT	0
419298	407720	11067R	PARTICIPANT	\N	PRESENT	0
419299	407720	19689Q	PARTICIPANT	\N	PRESENT	0
419300	407720	11080N	PARTICIPANT	\N	PRESENT	0
419301	407720	19683J	PARTICIPANT	\N	PRESENT	0
419302	407720	87003B	PARTICIPANT	\N	PRESENT	0
419303	407720	19387D	PARTICIPANT	\N	PRESENT	0
419304	407720	11090Q	PARTICIPANT	\N	PRESENT	0
419305	407720	14249W	PARTICIPANT	\N	PRESENT	0
419306	407720	19251M	PARTICIPANT	\N	PRESENT	0
419307	407720	14053L	PARTICIPANT	\N	PRESENT	0
419308	407720	14215L	PARTICIPANT	\N	PRESENT	0
419309	407720	14085U	PARTICIPANT	\N	PRESENT	0
419310	407720	15447F	PARTICIPANT	\N	PRESENT	0
419311	407720	14065Q	PARTICIPANT	\N	PRESENT	0
419312	407720	19643A	PARTICIPANT	\N	PRESENT	0
419313	407720	17779H	PARTICIPANT	\N	PRESENT	0
419314	407720	19489J	PARTICIPANT	\N	PRESENT	0
419315	407720	04043D	PARTICIPANT	\N	PRESENT	0
419316	407720	14021P	PARTICIPANT	\N	PRESENT	0
419317	407720	11054L	PARTICIPANT	\N	PRESENT	0
419318	407720	14119M	PARTICIPANT	\N	PRESENT	0
419319	407720	11077T	PARTICIPANT	\N	PRESENT	0
419320	407720	04071H	PARTICIPANT	\N	PRESENT	0
419321	407720	08060W	PARTICIPANT	\N	PRESENT	0
419322	407720	19727D	PARTICIPANT	\N	PRESENT	0
419323	407720	14169X	PARTICIPANT	\N	PRESENT	0
419324	407720	10015M	PARTICIPANT	\N	PRESENT	0
419325	407720	19820Y	PARTICIPANT	\N	PRESENT	0
419326	407720	08012N	PARTICIPANT	\N	PRESENT	0
419327	407720	11043H	PARTICIPANT	\N	PRESENT	0
419328	407720	01048V	PARTICIPANT	\N	PRESENT	0
419329	407720	08035V	PARTICIPANT	\N	PRESENT	0
419330	407720	08028W	PARTICIPANT	\N	PRESENT	0
419331	407720	04033B	PARTICIPANT	\N	PRESENT	0
419332	407720	14187A	PARTICIPANT	\N	PRESENT	0
419333	407720	14071N	PARTICIPANT	\N	PRESENT	0
419334	407720	11097X	PARTICIPANT	\N	PRESENT	0
419335	407720	19421M	PARTICIPANT	\N	PRESENT	0
419336	407720	04097T	PARTICIPANT	\N	PRESENT	0
419337	407720	19647E	PARTICIPANT	\N	PRESENT	0
419338	407720	08039A	PARTICIPANT	\N	PRESENT	0
419339	407720	08020N	PARTICIPANT	\N	PRESENT	0
419340	407720	11099A	PARTICIPANT	\N	PRESENT	0
419342	407720	08031R	PARTICIPANT	\N	PRESENT	0
419344	407720	08010L	PARTICIPANT	\N	PRESENT	0
419345	407720	08069G	PARTICIPANT	\N	PRESENT	0
419346	407720	14063N	PARTICIPANT	\N	PRESENT	0
419347	407720	04042C	PARTICIPANT	\N	PRESENT	0
419349	407720	19631V	PARTICIPANT	\N	PRESENT	0
419350	407720	04086Q	PARTICIPANT	\N	PRESENT	0
419351	407720	14097Y	PARTICIPANT	\N	PRESENT	0
419352	407720	04092N	PARTICIPANT	\N	PRESENT	0
419353	407720	14257W	PARTICIPANT	\N	PRESENT	0
419354	407720	04044E	PARTICIPANT	\N	PRESENT	0
419355	407720	19549D	PARTICIPANT	\N	PRESENT	0
419356	407720	95041E	PARTICIPANT	\N	PRESENT	0
419357	407720	01058X	PARTICIPANT	\N	PRESENT	0
419358	407720	19725B	PARTICIPANT	\N	PRESENT	0
419359	407720	08014Q	PARTICIPANT	\N	PRESENT	0
419360	407720	95030B	PARTICIPANT	\N	PRESENT	0
394000	393999	14133K	PARTICIPANT	\N	PRESENT	0
394001	393999	04085P	PARTICIPANT	\N	PRESENT	0
394002	393999	04059M	PARTICIPANT	\N	PRESENT	0
394003	393999	05008E	PARTICIPANT	\N	PRESENT	0
394004	393999	96004D	PARTICIPANT	\N	PRESENT	0
394005	393999	11027H	PARTICIPANT	\N	PRESENT	0
394006	393999	14079W	PARTICIPANT	\N	PRESENT	0
394007	393999	11070L	PARTICIPANT	\N	PRESENT	0
394008	393999	11074Q	PARTICIPANT	\N	PRESENT	0
394009	393999	14034U	PARTICIPANT	\N	PRESENT	0
394010	393999	14033T	PARTICIPANT	\N	PRESENT	0
394011	393999	19725B	PARTICIPANT	\N	PRESENT	0
394012	393999	14073Q	PARTICIPANT	\N	PRESENT	0
394013	393999	14251Q	PARTICIPANT	\N	PRESENT	0
394014	393999	08009T	PARTICIPANT	\N	PRESENT	0
394015	393999	04092N	PARTICIPANT	\N	PRESENT	0
394016	393999	08011M	PARTICIPANT	\N	PRESENT	0
394017	393999	04070G	PARTICIPANT	\N	PRESENT	0
394018	393999	08061X	PARTICIPANT	\N	PRESENT	0
394019	393999	05012A	PARTICIPANT	\N	PRESENT	0
394020	393999	11012A	PARTICIPANT	\N	PRESENT	0
394021	393999	04033B	PARTICIPANT	\N	PRESENT	0
394024	394023	08034U	PARTICIPANT	\N	PRESENT	0
394026	394025	14331P	PARTICIPANT	\N	PRESENT	0
396598	396519	87003B	PARTICIPANT	\N	EXCUSE	0
396612	396219	14107H	PARTICIPANT	\N	EXCUSE	0
396848	391251	14147R	PARTICIPANT	\N	PRESENT	0
396849	391251	11097X	PARTICIPANT	\N	PRESENT	0
396850	394369	14147R	PARTICIPANT	\N	PRESENT	0
396851	394369	11097X	PARTICIPANT	\N	PRESENT	0
396853	396219	08045X	PARTICIPANT	\N	PRESENT	0
397644	396227	19693L	PARTICIPANT	\N	EXCUSE	0
397645	396227	01058X	PARTICIPANT	\N	EXCUSE	0
397646	397297	14187A	PARTICIPANT	\N	EXCUSE	0
400282	397623	19551W	PARTICIPANT	\N	PRESENT	0
397650	397297	19733B	PARTICIPANT	\N	EXCUSE	0
397649	397297	14038Y	PARTICIPANT	\N	EXCUSE	0
400279	400278	14239U	PARTICIPANT	\N	PRESENT	0
400283	397628	19551W	PARTICIPANT	\N	PRESENT	0
400284	397633	19551W	PARTICIPANT	\N	PRESENT	0
400508	400507	14239U	PARTICIPANT	\N	PRESENT	0
400521	400520	14071N	PARTICIPANT	\N	PRESENT	0
400519	400518	14071N	PARTICIPANT	\N	PRESENT	0
400523	400522	14071N	PARTICIPANT	\N	PRESENT	0
403391	393655	04085P	PARTICIPANT	\N	PRESENT	0
403392	393655	11056N	PARTICIPANT	\N	PRESENT	0
403393	393655	19593H	PARTICIPANT	\N	PRESENT	0
403394	393655	08061X	PARTICIPANT	\N	PRESENT	0
403395	393655	95037J	PARTICIPANT	\N	PRESENT	0
403396	393655	95063L	PARTICIPANT	\N	PRESENT	0
403397	393655	14239U	PARTICIPANT	\N	PRESENT	0
403398	393655	19651A	PARTICIPANT	\N	PRESENT	0
403399	393655	19349W	PARTICIPANT	\N	PRESENT	0
403400	393655	11083R	PARTICIPANT	\N	PRESENT	0
403401	393655	86034E	PARTICIPANT	\N	PRESENT	0
403402	393655	19269X	PARTICIPANT	\N	PRESENT	0
403403	393655	11072N	PARTICIPANT	\N	PRESENT	0
403404	393655	08024S	PARTICIPANT	\N	PRESENT	0
403405	393655	19711U	PARTICIPANT	\N	PRESENT	0
403406	393655	19782L	PARTICIPANT	\N	PRESENT	0
403407	393655	17637T	PARTICIPANT	\N	PRESENT	0
403408	393655	19301E	PARTICIPANT	\N	PRESENT	0
403409	393655	19812Y	PARTICIPANT	\N	PRESENT	0
403410	393655	04097T	PARTICIPANT	\N	PRESENT	0
403411	393655	04045F	PARTICIPANT	\N	PRESENT	0
403412	393655	14157T	PARTICIPANT	\N	PRESENT	0
403413	393655	96004D	PARTICIPANT	\N	PRESENT	0
403414	393655	17589D	PARTICIPANT	\N	PRESENT	0
403415	393655	19563B	PARTICIPANT	\N	PRESENT	0
403416	393655	01058X	PARTICIPANT	\N	PRESENT	0
403417	393655	14251Q	PARTICIPANT	\N	PRESENT	0
403418	393655	14111D	PARTICIPANT	\N	PRESENT	0
403419	393655	99004R	PARTICIPANT	\N	PRESENT	0
403420	393655	19585H	PARTICIPANT	\N	PRESENT	0
403421	393655	19583F	PARTICIPANT	\N	PRESENT	0
403422	393655	08010L	PARTICIPANT	\N	PRESENT	0
403423	393655	08069G	PARTICIPANT	\N	PRESENT	0
403424	393655	11012A	PARTICIPANT	\N	PRESENT	0
403425	393655	14123H	PARTICIPANT	\N	PRESENT	0
403426	393655	19629C	PARTICIPANT	\N	PRESENT	0
403427	393655	19387D	PARTICIPANT	\N	PRESENT	0
403428	393655	01057W	PARTICIPANT	\N	PRESENT	0
403429	393655	11099A	PARTICIPANT	\N	PRESENT	0
403430	393655	19289C	PARTICIPANT	\N	PRESENT	0
403431	393655	19766L	PARTICIPANT	\N	PRESENT	0
403432	393655	11080N	PARTICIPANT	\N	PRESENT	0
403433	393655	11027H	PARTICIPANT	\N	PRESENT	0
403434	393655	14159V	PARTICIPANT	\N	PRESENT	0
403435	393655	19643A	PARTICIPANT	\N	PRESENT	0
403436	393655	04059M	PARTICIPANT	\N	PRESENT	0
403437	393655	11043H	PARTICIPANT	\N	PRESENT	0
403438	393655	11074Q	PARTICIPANT	\N	PRESENT	0
403439	393655	08028W	PARTICIPANT	\N	PRESENT	0
403440	393655	08068F	PARTICIPANT	\N	PRESENT	0
403441	393655	01028R	PARTICIPANT	\N	PRESENT	0
403442	393655	11090Q	PARTICIPANT	\N	PRESENT	0
403443	393655	08052W	PARTICIPANT	\N	PRESENT	0
403444	393655	14229S	PARTICIPANT	\N	PRESENT	0
403445	393655	19703U	PARTICIPANT	\N	PRESENT	0
403446	393655	14031R	PARTICIPANT	\N	PRESENT	0
403447	393655	14021P	PARTICIPANT	\N	PRESENT	0
403448	393655	08017T	PARTICIPANT	\N	PRESENT	0
403449	393655	19667J	PARTICIPANT	\N	PRESENT	0
403450	393655	11104D	PARTICIPANT	\N	PRESENT	0
403451	393655	19575F	PARTICIPANT	\N	PRESENT	0
403452	393655	19525U	PARTICIPANT	\N	PRESENT	0
403453	393655	04049K	PARTICIPANT	\N	PRESENT	0
403454	393655	11041F	PARTICIPANT	\N	PRESENT	0
403455	393655	14225N	PARTICIPANT	\N	PRESENT	0
403456	393655	14207L	PARTICIPANT	\N	PRESENT	0
403457	393655	19447X	PARTICIPANT	\N	PRESENT	0
403458	393655	11049P	PARTICIPANT	\N	PRESENT	0
403459	393655	14257W	PARTICIPANT	\N	PRESENT	0
403460	393655	08047A	PARTICIPANT	\N	PRESENT	0
403462	393655	17583W	PARTICIPANT	\N	PRESENT	0
403463	393655	08014Q	PARTICIPANT	\N	PRESENT	0
403464	393655	14147R	PARTICIPANT	\N	PRESENT	0
403465	393655	19333N	PARTICIPANT	\N	PRESENT	0
403466	393655	14259Y	PARTICIPANT	\N	PRESENT	0
403467	393655	14051J	PARTICIPANT	\N	PRESENT	0
403468	393655	14038Y	PARTICIPANT	\N	PRESENT	0
403469	393655	19467C	PARTICIPANT	\N	PRESENT	0
403470	393655	19489J	PARTICIPANT	\N	PRESENT	0
403471	393655	14227Q	PARTICIPANT	\N	PRESENT	0
403472	393655	18083K	PARTICIPANT	\N	PRESENT	0
403473	393655	19503N	PARTICIPANT	\N	PRESENT	0
403474	393655	19741B	PARTICIPANT	\N	PRESENT	0
403475	393655	14065Q	PARTICIPANT	\N	PRESENT	0
403476	393655	14085U	PARTICIPANT	\N	PRESENT	0
403477	393655	04088S	PARTICIPANT	\N	PRESENT	0
403478	393655	19531S	PARTICIPANT	\N	PRESENT	0
403479	393655	14041T	PARTICIPANT	\N	PRESENT	0
403480	393655	19727D	PARTICIPANT	\N	PRESENT	0
403481	393655	07029T	PARTICIPANT	\N	PRESENT	0
403482	393655	19649G	PARTICIPANT	\N	PRESENT	0
403483	393655	19657G	PARTICIPANT	\N	PRESENT	0
403484	393655	19689Q	PARTICIPANT	\N	PRESENT	0
403485	393655	95067Q	PARTICIPANT	\N	PRESENT	0
403487	393655	08015R	PARTICIPANT	\N	PRESENT	0
403488	393655	19715Y	PARTICIPANT	\N	PRESENT	0
403489	393655	19768N	PARTICIPANT	\N	PRESENT	0
403490	393655	19705W	PARTICIPANT	\N	PRESENT	0
403491	393655	19251M	PARTICIPANT	\N	PRESENT	0
403492	393655	11033F	PARTICIPANT	\N	PRESENT	0
403493	393655	14169X	PARTICIPANT	\N	PRESENT	0
403494	393655	19758L	PARTICIPANT	\N	PRESENT	0
403495	393655	19709B	PARTICIPANT	\N	PRESENT	0
403496	393655	19760E	PARTICIPANT	\N	PRESENT	0
403497	393655	19695N	PARTICIPANT	\N	PRESENT	0
403498	393655	14173T	PARTICIPANT	\N	PRESENT	0
403499	393655	10015M	PARTICIPANT	\N	PRESENT	0
403500	393655	19719D	PARTICIPANT	\N	PRESENT	0
403501	393655	14061L	PARTICIPANT	\N	PRESENT	0
403502	393655	04057K	PARTICIPANT	\N	PRESENT	0
403503	393655	14357A	PARTICIPANT	\N	PRESENT	0
403504	393655	19762G	PARTICIPANT	\N	PRESENT	0
403505	393655	14231L	PARTICIPANT	\N	PRESENT	0
403506	393655	04018C	PARTICIPANT	\N	PRESENT	0
403507	393655	19693L	PARTICIPANT	\N	PRESENT	0
403508	393655	08031R	PARTICIPANT	\N	PRESENT	0
403509	393655	19319Q	PARTICIPANT	\N	PRESENT	0
403510	393655	19713W	PARTICIPANT	\N	PRESENT	0
403511	393655	19701S	PARTICIPANT	\N	PRESENT	0
403512	393655	19369B	PARTICIPANT	\N	PRESENT	0
428722	428720	19691J	PARTICIPANT	\N	PRESENT	0
446068	442327	19651A	PARTICIPANT	\N	EXCUSE	0
446069	442327	19741B	PARTICIPANT	\N	EXCUSE	0
446132	442327	08045X	PARTICIPANT	\N	EXCUSE	0
446352	442327	08012N	PARTICIPANT	\N	EXCUSE	0
446387	442331	08045X	PARTICIPANT	\N	PRESENT	0
446388	439851	08045X	PARTICIPANT	\N	PRESENT	0
452879	448737	11033F	PARTICIPANT	\N	PRESENT	0
452880	448737	12041X	PARTICIPANT	\N	PRESENT	0
452881	448737	98024R	PARTICIPANT	\N	PRESENT	0
452882	448737	11101A	PARTICIPANT	\N	PRESENT	0
452883	448737	14055N	PARTICIPANT	\N	PRESENT	0
452884	448737	14213J	PARTICIPANT	\N	PRESENT	0
452885	448737	14199E	PARTICIPANT	\N	PRESENT	0
452886	448737	95041E	PARTICIPANT	\N	PRESENT	0
452887	448737	19717B	PARTICIPANT	\N	PRESENT	0
452888	448737	17779H	PARTICIPANT	\N	PRESENT	0
452889	448737	19441R	PARTICIPANT	\N	PRESENT	0
452890	448737	19683J	PARTICIPANT	\N	PRESENT	0
452891	448737	95067Q	PARTICIPANT	\N	PRESENT	0
452892	448737	11072N	PARTICIPANT	\N	PRESENT	0
452899	448737	11070L	PARTICIPANT	\N	PRESENT	0
452897	448737	19531S	PARTICIPANT	\N	PRESENT	0
452898	448737	19685L	PARTICIPANT	\N	PRESENT	0
452900	448737	19739H	PARTICIPANT	\N	PRESENT	0
453222	448738	14034U	PARTICIPANT	\N	PRESENT	0
452904	448737	11099A	PARTICIPANT	\N	PRESENT	0
452905	448737	11065P	PARTICIPANT	\N	PRESENT	0
452911	448737	11053K	PARTICIPANT	\N	PRESENT	0
452913	448737	04070G	PARTICIPANT	\N	PRESENT	0
453227	448738	14030Q	PARTICIPANT	\N	PRESENT	0
453254	448738	08017T	PARTICIPANT	\N	PRESENT	0
453235	448738	14215L	PARTICIPANT	\N	PRESENT	0
453236	448738	14261S	PARTICIPANT	\N	PRESENT	0
453237	448738	88008L	PARTICIPANT	\N	PRESENT	0
453238	448738	17589D	PARTICIPANT	\N	PRESENT	0
453240	448738	07029T	PARTICIPANT	\N	PRESENT	0
453258	448738	04034C	PARTICIPANT	\N	PRESENT	0
453244	448738	19447X	PARTICIPANT	\N	PRESENT	0
453245	448738	14041T	PARTICIPANT	\N	PRESENT	0
453253	448738	19812Y	PARTICIPANT	\N	PRESENT	0
453248	448738	19583F	PARTICIPANT	\N	PRESENT	0
453249	448738	19711U	PARTICIPANT	\N	PRESENT	0
453251	448738	14097Y	PARTICIPANT	\N	PRESENT	0
453252	448738	19683J	PARTICIPANT	\N	PRESENT	0
453255	450943	19413M	PARTICIPANT	\N	PRESENT	0
453256	450943	14033T	PARTICIPANT	\N	PRESENT	0
453257	448738	19349W	PARTICIPANT	\N	PRESENT	0
453259	448738	19735D	PARTICIPANT	\N	PRESENT	0
453266	450728	19443T	PARTICIPANT	\N	PRESENT	0
453267	450728	14193X	PARTICIPANT	\N	PRESENT	0
453268	450728	04042C	PRESIDENT	0	PRESENT	0
453269	450728	14255U	PARTICIPANT	\N	PRESENT	0
453270	448738	14235Q	PARTICIPANT	\N	PRESENT	0
453271	448738	19697Q	PARTICIPANT	\N	PRESENT	0
453272	450728	95030B	PARTICIPANT	\N	PRESENT	0
453273	450728	97011G	PARTICIPANT	\N	PRESENT	0
453274	450728	11066Q	PARTICIPANT	\N	PRESENT	0
453275	450728	98029W	PARTICIPANT	\N	PRESENT	0
453276	450728	04040A	PARTICIPANT	\N	PRESENT	0
453277	448738	19691J	PARTICIPANT	\N	PRESENT	0
453278	448738	14063N	PARTICIPANT	\N	PRESENT	0
453279	448738	04069P	PARTICIPANT	\N	PRESENT	0
453280	448738	19543W	PARTICIPANT	\N	PRESENT	0
453281	448738	95063L	PARTICIPANT	\N	PRESENT	0
453282	448738	19593H	PARTICIPANT	\N	PRESENT	0
453283	448738	08031R	PARTICIPANT	\N	PRESENT	0
453284	450943	14135M	PARTICIPANT	\N	PRESENT	0
453285	450943	19467C	PARTICIPANT	\N	PRESENT	0
453286	450943	19768N	PARTICIPANT	\N	PRESENT	0
453287	450943	19515S	PARTICIPANT	\N	PRESENT	0
453288	450943	95030B	PARTICIPANT	\N	PRESENT	0
453289	450943	14133K	PARTICIPANT	\N	PRESENT	0
453290	450943	19441R	PARTICIPANT	\N	PRESENT	0
453291	450943	04042C	PARTICIPANT	\N	PRESENT	0
453292	450943	80013X	PARTICIPANT	\N	PRESENT	0
453293	450943	19631V	PARTICIPANT	\N	PRESENT	0
453294	450943	19269X	PARTICIPANT	\N	PRESENT	0
453295	450943	14205J	PARTICIPANT	\N	PRESENT	0
453296	450943	19507S	PARTICIPANT	\N	PRESENT	0
453297	450943	14193X	PARTICIPANT	\N	PRESENT	0
453298	450943	97011G	PARTICIPANT	\N	PRESENT	0
453299	450943	98029W	PARTICIPANT	\N	PRESENT	0
453300	450943	98005N	PARTICIPANT	\N	PRESENT	0
453301	450943	04040A	PARTICIPANT	\N	PRESENT	0
453302	450943	08015R	PARTICIPANT	\N	PRESENT	0
453303	450943	19747H	PARTICIPANT	\N	PRESENT	0
453304	450943	14265W	PARTICIPANT	\N	PRESENT	0
453305	450728	08056B	PARTICIPANT	\N	PRESENT	0
453306	450728	01058X	PARTICIPANT	\N	PRESENT	0
453307	450728	98050T	PARTICIPANT	\N	PRESENT	0
453308	448738	08018U	PARTICIPANT	\N	PRESENT	0
453309	448738	08061X	PARTICIPANT	\N	PRESENT	0
453310	448738	19651A	PARTICIPANT	\N	PRESENT	0
453311	448738	14157T	PARTICIPANT	\N	PRESENT	0
453312	450943	11077T	PARTICIPANT	\N	PRESENT	0
453313	450943	11099A	PARTICIPANT	\N	PRESENT	0
453314	450943	19369B	PARTICIPANT	\N	PRESENT	0
453315	450943	14187A	PARTICIPANT	\N	PRESENT	0
453316	450943	19695N	PARTICIPANT	\N	PRESENT	0
453317	450943	11090Q	PRESIDENT	0	PRESENT	0
453318	450943	14115H	PARTICIPANT	\N	PRESENT	0
453319	450943	14207L	PARTICIPANT	\N	PRESENT	0
453320	450943	14257W	PARTICIPANT	\N	PRESENT	0
453321	448738	19758L	PARTICIPANT	\N	PRESENT	0
453322	450728	19768N	PARTICIPANT	\N	PRESENT	0
453323	450728	19515S	PARTICIPANT	\N	PRESENT	0
453324	450728	11077T	PARTICIPANT	\N	PRESENT	0
453325	450728	19441R	PARTICIPANT	\N	PRESENT	0
453326	450728	19413M	PARTICIPANT	\N	PRESENT	0
453327	450728	80013X	PARTICIPANT	\N	PRESENT	0
453328	450728	19631V	PARTICIPANT	\N	PRESENT	0
453329	450728	11099A	PARTICIPANT	\N	PRESENT	0
453330	450728	08068F	PARTICIPANT	\N	PRESENT	0
453331	450728	19705W	PARTICIPANT	\N	PRESENT	0
453332	450728	08015R	PARTICIPANT	\N	PRESENT	0
453333	450728	19369B	PARTICIPANT	\N	PRESENT	0
453335	450728	14265W	PARTICIPANT	\N	PRESENT	0
453336	450728	14135M	PARTICIPANT	\N	PRESENT	0
453337	450728	19467C	PARTICIPANT	\N	PRESENT	0
453338	450728	14187A	PARTICIPANT	\N	PRESENT	0
453339	450728	19695N	PARTICIPANT	\N	PRESENT	0
453340	450728	01025N	PARTICIPANT	\N	PRESENT	0
453341	450728	14033T	PARTICIPANT	\N	PRESENT	0
453342	450728	11090Q	PARTICIPANT	\N	PRESENT	0
453343	450728	19269X	PARTICIPANT	\N	PRESENT	0
453344	450728	14205J	PARTICIPANT	\N	PRESENT	0
453345	450728	19507S	PARTICIPANT	\N	PRESENT	0
453346	450728	14207L	PARTICIPANT	\N	PRESENT	0
453347	450728	14257W	PARTICIPANT	\N	PRESENT	0
453348	450728	14237S	PARTICIPANT	\N	PRESENT	0
453349	450728	08024S	PARTICIPANT	\N	PRESENT	0
453350	450728	19421M	PARTICIPANT	\N	PRESENT	0
453351	450728	11026G	PARTICIPANT	\N	PRESENT	0
453352	450728	04097T	PARTICIPANT	\N	PRESENT	0
453353	448738	14147R	PARTICIPANT	\N	PRESENT	0
453354	448738	04088S	PARTICIPANT	\N	PRESENT	0
453355	448738	19671E	PARTICIPANT	\N	PRESENT	0
453356	450728	11056N	PARTICIPANT	\N	PRESENT	0
453357	450943	19443T	PARTICIPANT	\N	PRESENT	0
453358	450943	01058X	PARTICIPANT	\N	PRESENT	0
453359	450943	11066Q	PARTICIPANT	\N	PRESENT	0
453360	450943	14237S	PARTICIPANT	\N	PRESENT	0
453361	450943	08068F	PARTICIPANT	\N	PRESENT	0
453362	450943	19421M	PARTICIPANT	\N	PRESENT	0
453363	450943	96004D	PARTICIPANT	\N	PRESENT	0
453364	450943	08024S	PARTICIPANT	\N	PRESENT	0
453365	450943	11026G	PARTICIPANT	\N	PRESENT	0
453366	450943	11056N	PARTICIPANT	\N	PRESENT	0
453367	450943	98050T	PARTICIPANT	\N	PRESENT	0
453368	450943	04097T	PARTICIPANT	\N	PRESENT	0
453369	450943	14255U	PARTICIPANT	\N	PRESENT	0
453370	450728	96004D	PARTICIPANT	\N	PRESENT	0
453371	450728	14357A	PARTICIPANT	\N	PRESENT	0
453372	450728	14001X	PARTICIPANT	\N	PRESENT	0
453373	450943	14357A	PARTICIPANT	\N	PRESENT	0
453374	450943	14001X	PARTICIPANT	\N	PRESENT	0
453375	448738	04018C	PARTICIPANT	\N	PRESENT	0
453376	448738	04092N	PARTICIPANT	\N	PRESENT	0
453377	448738	01024M	PARTICIPANT	\N	PRESENT	0
453378	448738	14073Q	PARTICIPANT	\N	PRESENT	0
453379	450728	14249W	PARTICIPANT	\N	PRESENT	0
453380	450943	14249W	PARTICIPANT	\N	PRESENT	0
453381	448738	19565D	PARTICIPANT	\N	PRESENT	0
440729	427774	19695N	PARTICIPANT	\N	PRESENT	0
440730	427774	11056N	PARTICIPANT	\N	PRESENT	0
440731	427774	12041X	PARTICIPANT	\N	PRESENT	0
440732	427774	19565D	PARTICIPANT	\N	PRESENT	0
440733	427774	04085P	PARTICIPANT	\N	PRESENT	0
440734	427774	19758L	PARTICIPANT	\N	PRESENT	0
440735	427774	19711U	PARTICIPANT	\N	PRESENT	0
440736	427774	04034C	PARTICIPANT	\N	PRESENT	0
440737	427774	14039A	PARTICIPANT	\N	PRESENT	0
440738	427774	19697Q	PARTICIPANT	\N	PRESENT	0
440739	427774	19543W	PARTICIPANT	\N	PRESENT	0
440740	427774	04008A	PARTICIPANT	\N	PRESENT	0
440741	427774	19812Y	PARTICIPANT	\N	PRESENT	0
440742	427774	14239U	PARTICIPANT	\N	PRESENT	0
440743	427774	14157T	PARTICIPANT	\N	PRESENT	0
440744	427774	11083R	PARTICIPANT	\N	PRESENT	0
440745	427774	19651A	PARTICIPANT	\N	PRESENT	0
440746	427774	04045F	PARTICIPANT	\N	PRESENT	0
440747	427774	11072N	PARTICIPANT	\N	PRESENT	0
440748	427774	14026U	PARTICIPANT	\N	PRESENT	0
440749	427774	19443T	PARTICIPANT	\N	PRESENT	0
440750	427774	98029W	PARTICIPANT	\N	PRESENT	0
440751	427774	19741B	PARTICIPANT	\N	PRESENT	0
440752	427774	19591F	PARTICIPANT	\N	PRESENT	0
440753	427774	04088S	PARTICIPANT	\N	PRESENT	0
440754	427774	19507S	PARTICIPANT	\N	PRESENT	0
440755	427774	07029T	PARTICIPANT	\N	PRESENT	0
440756	427774	08015R	PARTICIPANT	\N	PRESENT	0
440757	427774	19768N	PARTICIPANT	\N	PRESENT	0
440758	427774	14034U	PARTICIPANT	\N	PRESENT	0
440759	427774	98050T	PARTICIPANT	\N	PRESENT	0
440760	427774	14107H	PARTICIPANT	\N	PRESENT	0
440761	427774	14061L	PARTICIPANT	\N	PRESENT	0
440762	427774	19387D	PARTICIPANT	\N	PRESENT	0
440763	427774	14059S	PARTICIPANT	\N	PRESENT	0
440764	427774	14241N	PARTICIPANT	\N	PRESENT	0
440765	427774	19719D	PARTICIPANT	\N	PRESENT	0
440766	427774	19253P	PARTICIPANT	\N	PRESENT	0
440767	427774	19794Q	PARTICIPANT	\N	PRESENT	0
440768	427774	19629C	PARTICIPANT	\N	PRESENT	0
440769	427774	14173T	PARTICIPANT	\N	PRESENT	0
440770	427774	14207L	PARTICIPANT	\N	PRESENT	0
440771	427774	14038Y	PARTICIPANT	\N	PRESENT	0
440772	427774	19681G	PARTICIPANT	\N	PRESENT	0
440773	427774	19415P	PARTICIPANT	\N	PRESENT	0
440774	427774	14033T	PARTICIPANT	\N	PRESENT	0
440775	427774	14135M	PARTICIPANT	\N	PRESENT	0
440776	427774	19563B	PARTICIPANT	\N	PRESENT	0
440777	427774	18083K	PARTICIPANT	\N	PRESENT	0
440778	427774	14195A	PARTICIPANT	\N	PRESENT	0
440779	427774	14133K	PARTICIPANT	\N	PRESENT	0
440780	427774	14251Q	PARTICIPANT	\N	PRESENT	0
440781	427774	19399H	PARTICIPANT	\N	PRESENT	0
440782	427774	19717B	PARTICIPANT	\N	PRESENT	0
440783	427774	19693L	PARTICIPANT	\N	PRESENT	0
440784	427774	19553Y	PARTICIPANT	\N	PRESENT	0
440785	427774	14329V	PARTICIPANT	\N	PRESENT	0
440786	427774	04057K	PARTICIPANT	\N	PRESENT	0
440787	427774	11064N	PARTICIPANT	\N	PRESENT	0
440788	427774	08011M	PARTICIPANT	\N	PRESENT	0
440789	427774	04059M	PARTICIPANT	\N	PRESENT	0
440790	427774	19503N	PARTICIPANT	\N	PRESENT	0
440791	427774	19383Y	PARTICIPANT	\N	PRESENT	0
440792	427774	19675J	PARTICIPANT	\N	PRESENT	0
440793	427774	08073C	PARTICIPANT	\N	PRESENT	0
440794	427774	11067R	PARTICIPANT	\N	PRESENT	0
440795	427774	11026G	PARTICIPANT	\N	PRESENT	0
440796	427774	14357A	PARTICIPANT	\N	PRESENT	0
440797	427774	19333N	PARTICIPANT	\N	PRESENT	0
440798	427774	14265W	PARTICIPANT	\N	PRESENT	0
440799	427774	19683J	PARTICIPANT	\N	PRESENT	0
440800	427774	19701S	PARTICIPANT	\N	PRESENT	0
440801	427774	11054L	PARTICIPANT	\N	PRESENT	0
440802	427774	04018C	PARTICIPANT	\N	PRESENT	0
440803	427774	11077T	PARTICIPANT	\N	PRESENT	0
440804	427774	19621T	PARTICIPANT	\N	PRESENT	0
440805	427774	92040Q	PARTICIPANT	\N	PRESENT	0
440806	427774	14119M	PARTICIPANT	\N	PRESENT	0
440807	427774	08058D	PARTICIPANT	\N	PRESENT	0
440808	427774	19489J	PARTICIPANT	\N	PRESENT	0
440809	427774	08047A	PARTICIPANT	\N	PRESENT	0
440810	427774	11099A	PARTICIPANT	\N	PRESENT	0
440811	427774	14147R	PARTICIPANT	\N	PRESENT	0
440812	427774	19820Y	PARTICIPANT	\N	PRESENT	0
440813	427774	97011G	PARTICIPANT	\N	PRESENT	0
440814	427774	07033P	PARTICIPANT	\N	PRESENT	0
440815	427774	14217N	PARTICIPANT	\N	PRESENT	0
440816	427774	19525U	PARTICIPANT	\N	PRESENT	0
440817	427774	14331P	PARTICIPANT	\N	PRESENT	0
440818	427774	14257W	PARTICIPANT	\N	PRESENT	0
440819	427774	19671E	PARTICIPANT	\N	PRESENT	0
440820	427774	11045K	PARTICIPANT	\N	PRESENT	0
440821	427774	14028W	PARTICIPANT	\N	PRESENT	0
440822	427774	19703U	PARTICIPANT	\N	PRESENT	0
440823	427774	11104D	PARTICIPANT	\N	PRESENT	0
440824	427774	14031R	PARTICIPANT	\N	PRESENT	0
440825	427774	08043V	PARTICIPANT	\N	PRESENT	0
440826	427774	14259Y	PARTICIPANT	\N	PRESENT	0
440827	427774	11066Q	PARTICIPANT	\N	PRESENT	0
440828	427774	01062T	PARTICIPANT	\N	PRESENT	0
440829	427774	08060W	PARTICIPANT	\N	PRESENT	0
440830	427774	14199E	PARTICIPANT	\N	PRESENT	0
440831	427774	14021P	PARTICIPANT	\N	PRESENT	0
440832	427774	19575F	PARTICIPANT	\N	PRESENT	0
440833	427774	19669L	PARTICIPANT	\N	PRESENT	0
440834	427774	14253S	PARTICIPANT	\N	PRESENT	0
440835	427774	04049K	PARTICIPANT	\N	PRESENT	0
440836	427774	19599P	PARTICIPANT	\N	PRESENT	0
440837	427774	08034U	PARTICIPANT	\N	PRESENT	0
440838	427774	14151M	PARTICIPANT	\N	PRESENT	0
440839	427774	08052W	PARTICIPANT	\N	PRESENT	0
440840	427774	14229S	PARTICIPANT	\N	PRESENT	0
440841	427774	19798U	PARTICIPANT	\N	PRESENT	0
440842	427774	01028R	PARTICIPANT	\N	PRESENT	0
440843	427774	08068F	PARTICIPANT	\N	PRESENT	0
440844	427774	14193X	PARTICIPANT	\N	PRESENT	0
440845	427774	19515S	PARTICIPANT	\N	PRESENT	0
440846	427774	11074Q	PARTICIPANT	\N	PRESENT	0
440847	427774	11027H	PARTICIPANT	\N	PRESENT	0
440848	427774	11080N	PARTICIPANT	\N	PRESENT	0
440849	427774	01057W	PARTICIPANT	\N	PRESENT	0
440850	427774	87003B	PARTICIPANT	\N	PRESENT	0
440851	427774	19549D	PARTICIPANT	\N	PRESENT	0
440852	427774	95067Q	PARTICIPANT	\N	PRESENT	0
440853	427774	14065Q	PARTICIPANT	\N	PRESENT	0
440854	427774	14053L	PARTICIPANT	\N	PRESENT	0
440855	427774	14215L	PARTICIPANT	\N	PRESENT	0
440856	427774	19713W	PARTICIPANT	\N	PRESENT	0
440857	427774	14169X	PARTICIPANT	\N	PRESENT	0
440858	427774	10015M	PARTICIPANT	\N	PRESENT	0
440859	427774	11043H	PARTICIPANT	\N	PRESENT	0
440860	427774	14187A	PARTICIPANT	\N	PRESENT	0
440861	427774	14071N	PARTICIPANT	\N	PRESENT	0
440862	427774	02002K	PARTICIPANT	\N	PRESENT	0
440863	427774	11097X	PARTICIPANT	\N	PRESENT	0
440864	427774	08039A	PARTICIPANT	\N	PRESENT	0
440865	427774	19699S	PARTICIPANT	\N	PRESENT	0
440866	427774	08010L	PARTICIPANT	\N	PRESENT	0
440867	427774	19479G	PARTICIPANT	\N	PRESENT	0
440868	427774	14123H	PARTICIPANT	\N	PRESENT	0
440869	427774	14042U	PARTICIPANT	\N	PRESENT	0
440870	427774	04086Q	PARTICIPANT	\N	PRESENT	0
440871	427774	19569H	PARTICIPANT	\N	PRESENT	0
440872	427774	04092N	PARTICIPANT	\N	PRESENT	0
440873	427774	19739H	PARTICIPANT	\N	PRESENT	0
440874	427774	19735D	PARTICIPANT	\N	PRESENT	0
440875	427774	19747H	PARTICIPANT	\N	PRESENT	0
440876	427774	04040A	PARTICIPANT	\N	PRESENT	0
440877	427774	95030B	PARTICIPANT	\N	PRESENT	0
440878	427774	16685X	PARTICIPANT	\N	PRESENT	0
440879	427774	01058X	PARTICIPANT	\N	PRESENT	0
440880	427774	19721W	PARTICIPANT	\N	PRESENT	0
440881	427774	99004R	PARTICIPANT	\N	PRESENT	0
440882	427774	19619A	PARTICIPANT	\N	PRESENT	0
440883	427774	08069G	PARTICIPANT	\N	PRESENT	0
440884	427774	19737F	PARTICIPANT	\N	PRESENT	0
440885	427774	14205J	PARTICIPANT	\N	PRESENT	0
440886	427774	19369B	PARTICIPANT	\N	PRESENT	0
440887	427774	11101A	PARTICIPANT	\N	PRESENT	0
440888	427774	04035D	PARTICIPANT	\N	PRESENT	0
440889	427774	11048N	PARTICIPANT	\N	PRESENT	0
440890	427774	19611R	PARTICIPANT	\N	PRESENT	0
440891	427774	01034P	PARTICIPANT	\N	PRESENT	0
440892	427774	19691J	PARTICIPANT	\N	PRESENT	0
440893	427774	19521Q	PARTICIPANT	\N	PRESENT	0
440894	427774	08009T	PARTICIPANT	\N	PRESENT	0
440895	427774	19421M	PARTICIPANT	\N	PRESENT	0
440896	427774	19441R	PARTICIPANT	\N	PRESENT	0
426325	426324	19681G	PARTICIPANT	\N	PRESENT	0
426326	426324	14031R	PARTICIPANT	\N	PRESENT	0
437610	437609	08009T	PARTICIPANT	\N	PRESENT	0
437612	437611	08009T	PARTICIPANT	\N	PRESENT	0
437613	437611	11083R	PARTICIPANT	\N	PRESENT	0
438477	438474	19447X	PARTICIPANT	\N	PRESENT	0
438478	438474	14147R	PARTICIPANT	\N	PRESENT	0
438479	438474	14179A	PARTICIPANT	\N	PRESENT	0
438480	438476	19447X	PARTICIPANT	\N	PRESENT	0
438481	438476	08052W	PARTICIPANT	\N	PRESENT	0
438482	438476	14147R	PARTICIPANT	\N	PRESENT	0
454148	454147	19515S	PARTICIPANT	\N	PRESENT	0
454149	454147	19467C	PARTICIPANT	\N	PRESENT	0
454150	454147	19812Y	PARTICIPANT	\N	PRESENT	0
454151	454147	01024M	PARTICIPANT	\N	PRESENT	0
454152	454147	11097X	PARTICIPANT	\N	PRESENT	0
454153	454147	11090Q	PARTICIPANT	\N	PRESENT	0
454247	445947	19349W	PARTICIPANT	\N	EXCUSE	0
454248	445947	19711U	PARTICIPANT	\N	EXCUSE	0
454249	445947	01028R	PARTICIPANT	\N	EXCUSE	0
454250	445947	19399H	PARTICIPANT	\N	PRESENT	0
454251	445947	19515S	PARTICIPANT	\N	EXCUSE	0
454253	445947	08062Y	PARTICIPANT	\N	EXCUSE	0
454262	445947	19569H	PARTICIPANT	\N	EXCUSE	0
454263	445947	08012N	PARTICIPANT	\N	EXCUSE	0
454264	445947	11065P	PARTICIPANT	\N	EXCUSE	0
454288	448744	19347U	PARTICIPANT	\N	PRESENT	0
454289	448744	07004J	PARTICIPANT	\N	PRESENT	0
454290	448744	14221J	PARTICIPANT	\N	PRESENT	0
454291	448744	19709B	PARTICIPANT	\N	PRESENT	0
454292	448744	19503N	PARTICIPANT	\N	PRESENT	0
454293	448744	08043V	PARTICIPANT	\N	PRESENT	0
454294	448744	19768N	PARTICIPANT	\N	PRESENT	0
454295	445947	14147R	PARTICIPANT	\N	PRESENT	0
454296	445947	19737F	PARTICIPANT	\N	PRESENT	0
454297	448744	11043H	PARTICIPANT	\N	PRESENT	0
454298	448744	19719D	PARTICIPANT	\N	PRESENT	0
454299	448744	19349W	PARTICIPANT	\N	PRESENT	0
454300	448744	19599P	PARTICIPANT	\N	PRESENT	0
454301	454197	17637T	PARTICIPANT	\N	PRESENT	0
454302	448744	19762G	PARTICIPANT	\N	PRESENT	0
454303	448744	19253P	PARTICIPANT	\N	PRESENT	0
454304	448744	08010L	PARTICIPANT	\N	PRESENT	0
454305	448744	14031R	PARTICIPANT	\N	PRESENT	0
454306	448744	80013X	PARTICIPANT	\N	PRESENT	0
454307	448744	11115U	PARTICIPANT	\N	PRESENT	0
454308	448744	14073Q	PARTICIPANT	\N	PRESENT	0
454309	448744	19581D	PARTICIPANT	\N	PRESENT	0
454310	448744	14147R	PARTICIPANT	\N	PRESENT	0
454316	448745	19565D	PARTICIPANT	\N	PRESENT	0
454317	448745	14042U	PARTICIPANT	\N	PRESENT	0
454318	448745	14281W	PARTICIPANT	\N	PRESENT	0
454314	448745	11070L	PARTICIPANT	\N	PRESENT	0
454315	448745	14026U	PARTICIPANT	\N	PRESENT	0
454319	448745	19715Y	PARTICIPANT	\N	PRESENT	0
454320	448745	11066Q	PARTICIPANT	\N	PRESENT	0
454321	448745	04057K	PARTICIPANT	\N	PRESENT	0
454322	448745	19335Q	PARTICIPANT	\N	PRESENT	0
454323	448745	11103C	PARTICIPANT	\N	PRESENT	0
454324	448745	19711U	PARTICIPANT	\N	PRESENT	0
454325	448745	18083K	PARTICIPANT	\N	PRESENT	0
454326	448745	14213J	PARTICIPANT	\N	PRESENT	0
454327	448745	19415P	PARTICIPANT	\N	PRESENT	0
454328	448745	19515S	PARTICIPANT	\N	PRESENT	0
454329	448745	19629C	PARTICIPANT	\N	PRESENT	0
454330	448745	19760E	PARTICIPANT	\N	PRESENT	0
454331	454188	08056B	PARTICIPANT	\N	PRESENT	0
454332	454188	08053X	PARTICIPANT	\N	PRESENT	0
454333	454188	19669L	PARTICIPANT	\N	PRESENT	0
454334	454188	19719D	PRESIDENT	0	PRESENT	0
454335	454188	19673G	PARTICIPANT	\N	PRESENT	0
454336	448745	19758L	PARTICIPANT	\N	PRESENT	0
454337	448745	11067R	PARTICIPANT	\N	PRESENT	0
454338	448745	08024S	PARTICIPANT	\N	PRESENT	0
454339	448745	19697Q	PARTICIPANT	\N	PRESENT	0
454340	448745	14235Q	PARTICIPANT	\N	PRESENT	0
454341	448745	19798U	PARTICIPANT	\N	PRESENT	0
454342	448745	11031D	PARTICIPANT	\N	PRESENT	0
454343	448745	14119M	PARTICIPANT	\N	PRESENT	0
454344	448745	99004R	PARTICIPANT	\N	PRESENT	0
454345	448745	19737F	PARTICIPANT	\N	PRESENT	0
454347	448745	11072N	PARTICIPANT	\N	PRESENT	0
454348	448745	19611R	PARTICIPANT	\N	PRESENT	0
454349	448745	04092N	PARTICIPANT	\N	PRESENT	0
454350	448745	14217N	PARTICIPANT	\N	PRESENT	0
454351	448745	14261S	PARTICIPANT	\N	PRESENT	0
454352	448745	19723Y	PARTICIPANT	\N	PRESENT	0
454353	448745	14038Y	PARTICIPANT	\N	PRESENT	0
454354	448745	04033B	PARTICIPANT	\N	PRESENT	0
454355	448745	14063N	PARTICIPANT	\N	PRESENT	0
454356	448745	15447F	PARTICIPANT	\N	PRESENT	0
454357	448745	04088S	PARTICIPANT	\N	PRESENT	0
454358	448745	19467C	PARTICIPANT	\N	PRESENT	0
454359	448745	08069G	PARTICIPANT	\N	PRESENT	0
454360	448745	87003B	PARTICIPANT	\N	PRESENT	0
454361	448745	14249W	PARTICIPANT	\N	PRESENT	0
454362	448745	19533U	PARTICIPANT	\N	PRESENT	0
454363	448745	14147R	PARTICIPANT	\N	PRESENT	0
454364	448745	14327T	PARTICIPANT	\N	PRESENT	0
454365	448745	14059S	PARTICIPANT	\N	PRESENT	0
454366	448745	11101A	PARTICIPANT	\N	PRESENT	0
454367	448745	19447X	PARTICIPANT	\N	PRESENT	0
454368	448745	14083S	PARTICIPANT	\N	PRESENT	0
454369	448745	19593H	PARTICIPANT	\N	PRESENT	0
454370	448745	14265W	PARTICIPANT	\N	PRESENT	0
454371	448745	01024M	PARTICIPANT	\N	PRESENT	0
454372	448745	04018C	PARTICIPANT	\N	PRESENT	0
454373	448745	19585H	PARTICIPANT	\N	PRESENT	0
454374	448745	19747H	PARTICIPANT	\N	PRESENT	0
454375	448745	01034P	PARTICIPANT	\N	PRESENT	0
454376	448745	19369B	PARTICIPANT	\N	PRESENT	0
454377	448745	08031R	PARTICIPANT	\N	PRESENT	0
454378	448745	19687N	PARTICIPANT	\N	PRESENT	0
454379	448745	95030B	PARTICIPANT	\N	PRESENT	0
454380	448745	98050T	PARTICIPANT	\N	PRESENT	0
454381	448745	08028W	PARTICIPANT	\N	PRESENT	0
454382	448745	11048N	PARTICIPANT	\N	PRESENT	0
454383	448745	01025N	PARTICIPANT	\N	PRESENT	0
454384	448745	14211G	PARTICIPANT	\N	PRESENT	0
454385	448745	19701S	PARTICIPANT	\N	PRESENT	0
454386	448745	08020N	PARTICIPANT	\N	PRESENT	0
454387	448745	14121F	PARTICIPANT	\N	PRESENT	0
454388	448745	19581D	PARTICIPANT	\N	PRESENT	0
454389	448745	14030Q	PARTICIPANT	\N	PRESENT	0
454390	448745	19739H	PARTICIPANT	\N	PRESENT	0
454391	454188	08010L	PARTICIPANT	\N	PRESENT	0
454392	454188	14097Y	PARTICIPANT	\N	EXCUSE	0
454393	454188	07004J	PARTICIPANT	\N	EXCUSE	0
454394	454188	10015M	PARTICIPANT	\N	EXCUSE	0
454395	454188	04044E	PARTICIPANT	\N	EXCUSE	0
454396	448745	19347U	PARTICIPANT	\N	PRESENT	0
454397	448745	14069U	PARTICIPANT	\N	PRESENT	0
454398	448745	14221J	PARTICIPANT	\N	PRESENT	0
454399	448745	14103D	PARTICIPANT	\N	PRESENT	0
454400	448745	97011G	PARTICIPANT	\N	PRESENT	0
454401	448745	14355X	PARTICIPANT	\N	PRESENT	0
454402	448745	19782L	PARTICIPANT	\N	PRESENT	0
454403	448745	08056B	PARTICIPANT	\N	PRESENT	0
454404	448745	08019V	PARTICIPANT	\N	PRESENT	0
454405	448745	19399H	PARTICIPANT	\N	PRESENT	0
454406	448745	14041T	PARTICIPANT	\N	PRESENT	0
454407	448745	19731Y	PARTICIPANT	\N	PRESENT	0
454408	448745	14237S	PARTICIPANT	\N	PRESENT	0
454409	448745	01028R	PARTICIPANT	\N	PRESENT	0
454410	448745	07004J	PARTICIPANT	\N	PRESENT	0
436254	433965	01058X	PARTICIPANT	\N	PRESENT	0
436255	433965	08058D	PARTICIPANT	\N	PRESENT	0
436256	433965	11054L	PARTICIPANT	\N	PRESENT	0
436257	433965	19251M	PARTICIPANT	\N	PRESENT	0
436258	433965	98022P	PARTICIPANT	\N	PRESENT	0
436259	433965	14255U	PARTICIPANT	\N	PRESENT	0
436260	433965	16685X	PARTICIPANT	\N	PRESENT	0
436261	433965	14028W	PARTICIPANT	\N	PRESENT	0
436262	433965	19721W	PARTICIPANT	\N	PRESENT	0
436269	435787	19593H	PARTICIPANT	\N	PRESENT	0
436270	435787	19766L	PARTICIPANT	\N	PRESENT	0
436271	435787	19699S	PARTICIPANT	\N	PRESENT	0
436272	435787	14061L	PARTICIPANT	\N	PRESENT	0
436273	435787	19533U	PARTICIPANT	\N	PRESENT	0
436274	435787	19611R	PARTICIPANT	\N	PRESENT	0
436275	435787	19329S	PARTICIPANT	\N	PRESENT	0
436276	435787	19693L	PARTICIPANT	\N	PRESENT	0
436277	435787	19399H	PARTICIPANT	\N	PRESENT	0
436278	435787	87003B	PARTICIPANT	\N	PRESENT	0
436279	435787	14229S	PARTICIPANT	\N	PRESENT	0
436280	435787	14030Q	PARTICIPANT	\N	PRESENT	0
436281	435787	14251Q	PARTICIPANT	\N	PRESENT	0
436282	435787	14039A	PARTICIPANT	\N	PRESENT	0
436283	435787	04059M	PARTICIPANT	\N	PRESENT	0
436284	435787	11083R	PARTICIPANT	\N	PRESENT	0
436285	435787	07033P	PARTICIPANT	\N	PRESENT	0
436286	435787	08012N	PARTICIPANT	\N	PRESENT	0
436287	435787	11043H	PARTICIPANT	\N	PRESENT	0
436288	435787	19335Q	PARTICIPANT	\N	PRESENT	0
436289	435787	19749K	PARTICIPANT	\N	PRESENT	0
436290	435787	04018C	PARTICIPANT	\N	PRESENT	0
436291	435787	08039A	PRESIDENT	0	PRESENT	0
436292	435787	14059S	PARTICIPANT	\N	EXCUSE	0
436293	435787	04057K	PARTICIPANT	\N	EXCUSE	0
436294	435787	92040Q	PARTICIPANT	\N	EXCUSE	0
436295	435787	14063N	PARTICIPANT	\N	EXCUSE	0
436296	435787	11104D	PARTICIPANT	\N	EXCUSE	0
436297	435787	14201E	PARTICIPANT	\N	EXCUSE	0
436298	435787	04070G	PRESIDENT	1	PRESENT	0
436299	435787	19573D	PARTICIPANT	\N	PRESENT	0
436300	435787	14107H	PARTICIPANT	\N	PRESENT	0
436301	435787	08017T	PARTICIPANT	\N	PRESENT	0
436302	435787	14073Q	PARTICIPANT	\N	PRESENT	0
436303	435787	08035V	PARTICIPANT	\N	PRESENT	0
436304	432904	19383Y	PARTICIPANT	\N	PRESENT	0
436305	432904	19333N	PARTICIPANT	\N	PRESENT	0
436306	432904	19701S	PARTICIPANT	\N	PRESENT	0
436307	432904	19794Q	PARTICIPANT	\N	PRESENT	0
436308	432904	19549D	PARTICIPANT	\N	PRESENT	0
436309	432904	19387D	PARTICIPANT	\N	PRESENT	0
436310	432904	14219Q	PARTICIPANT	\N	PRESENT	0
436311	432904	19820Y	PARTICIPANT	\N	PRESENT	0
436312	432904	19826F	PARTICIPANT	\N	PRESENT	0
436313	432904	18083K	PARTICIPANT	\N	PRESENT	0
436314	432904	14237S	PARTICIPANT	\N	PRESENT	0
436315	432904	19551W	PARTICIPANT	\N	PRESENT	0
436316	432904	05012A	PARTICIPANT	\N	PRESENT	0
436317	432904	14051J	PARTICIPANT	\N	PRESENT	0
436318	432904	08060W	PARTICIPANT	\N	PRESENT	0
436319	432904	19503N	PARTICIPANT	\N	PRESENT	0
436320	432904	14157T	PARTICIPANT	\N	PRESENT	0
436321	432904	08024S	PARTICIPANT	\N	PRESENT	0
436322	432904	11065P	PARTICIPANT	\N	PRESENT	0
436323	432904	19525U	PARTICIPANT	\N	PRESENT	0
436324	432904	14038Y	PARTICIPANT	0	PRESENT	0
436325	432904	19713W	PARTICIPANT	\N	PRESENT	0
436326	432904	14031R	PARTICIPANT	\N	PRESENT	0
436327	432904	14169X	PARTICIPANT	\N	PRESENT	0
436328	432904	14093U	PARTICIPANT	\N	PRESENT	0
436329	432904	08009T	PRESIDENT	0	PRESENT	0
436330	432904	19737F	PARTICIPANT	\N	PRESENT	0
436331	432904	04097T	PARTICIPANT	\N	PRESENT	0
436332	432904	19739H	PARTICIPANT	\N	PRESENT	0
436333	432904	17583W	PARTICIPANT	\N	EXCUSE	0
436334	432904	19347U	PARTICIPANT	\N	EXCUSE	0
436335	432904	19745F	PARTICIPANT	\N	EXCUSE	0
436336	432904	19599P	PARTICIPANT	\N	EXCUSE	0
436337	435787	04033B	PARTICIPANT	\N	PRESENT	0
436338	435787	14241N	PARTICIPANT	\N	PRESENT	0
436339	435787	14249W	PARTICIPANT	\N	PRESENT	0
436340	435787	19735D	PARTICIPANT	\N	PRESENT	0
436341	435787	11109J	PARTICIPANT	\N	PRESENT	0
436342	435787	19621T	PARTICIPANT	\N	PRESENT	0
436345	435787	14123H	PARTICIPANT	\N	PRESENT	0
436351	428273	01043Q	PARTICIPANT	\N	PRESENT	0
436352	433965	19583F	PARTICIPANT	\N	PRESENT	0
436354	436353	19467C	PARTICIPANT	\N	PRESENT	0
436355	436353	19667J	PARTICIPANT	\N	PRESENT	0
436356	436353	14069U	PARTICIPANT	\N	PRESENT	0
436357	436353	04097T	PARTICIPANT	\N	PRESENT	0
436358	436353	19511N	PARTICIPANT	\N	PRESENT	0
436359	436353	19723Y	PARTICIPANT	\N	PRESENT	0
436360	436353	14265W	PARTICIPANT	\N	PRESENT	0
436361	436353	04088S	PARTICIPANT	\N	PRESENT	0
436362	436353	19269X	PARTICIPANT	\N	PRESENT	0
436363	436353	19762G	PARTICIPANT	\N	PRESENT	0
436372	436353	14173T	PARTICIPANT	\N	PRESENT	0
436473	435794	19768N	PARTICIPANT	\N	PRESENT	0
436474	435794	19515S	PARTICIPANT	\N	PRESENT	0
436475	435794	19782L	PARTICIPANT	\N	PRESENT	0
436476	435794	11077T	PARTICIPANT	\N	PRESENT	0
436477	435794	14357A	PARTICIPANT	\N	PRESENT	0
436478	435794	19441R	PARTICIPANT	\N	PRESENT	0
436479	435794	19812Y	PARTICIPANT	\N	PRESENT	0
436480	435794	19413M	PARTICIPANT	\N	PRESENT	0
436481	435794	19631V	PARTICIPANT	\N	PRESENT	0
436482	435794	11099A	PARTICIPANT	\N	PRESENT	0
436483	435794	08068F	PARTICIPANT	\N	PRESENT	0
436484	435794	04049K	PARTICIPANT	\N	PRESENT	0
436485	435794	19705W	PARTICIPANT	\N	PRESENT	0
436486	435794	08015R	PARTICIPANT	\N	PRESENT	0
436487	435794	08019V	PARTICIPANT	\N	PRESENT	0
436488	435794	19369B	PARTICIPANT	\N	PRESENT	0
436489	435794	19511N	PARTICIPANT	\N	PRESENT	0
436490	435794	08028W	PARTICIPANT	\N	PRESENT	0
436491	435794	19563B	PARTICIPANT	\N	PRESENT	0
436492	435794	14265W	PARTICIPANT	\N	PRESENT	0
436493	435794	14329V	PARTICIPANT	\N	PRESENT	0
436494	435794	19591F	PARTICIPANT	\N	PRESENT	0
436495	435794	14135M	PARTICIPANT	\N	PRESENT	0
436496	435794	19467C	PARTICIPANT	\N	PRESENT	0
436497	435794	14187A	PARTICIPANT	\N	PRESENT	0
436498	435794	08062Y	PARTICIPANT	\N	PRESENT	0
436499	435794	19695N	PARTICIPANT	\N	PRESENT	0
436500	435794	01025N	PARTICIPANT	\N	PRESENT	0
436501	435794	14033T	PARTICIPANT	\N	PRESENT	0
436502	435794	11090Q	PRESIDENT	0	PRESENT	0
436503	435794	19295A	PARTICIPANT	\N	PRESENT	0
436504	435794	19269X	PARTICIPANT	\N	PRESENT	0
436505	435794	14205J	PARTICIPANT	\N	PRESENT	0
436506	435794	04088S	PARTICIPANT	\N	PRESENT	0
436507	435794	04089T	PARTICIPANT	\N	PRESENT	0
436508	435794	14115H	PARTICIPANT	\N	PRESENT	0
436509	435794	11101A	PARTICIPANT	\N	PRESENT	0
436510	435794	19507S	PARTICIPANT	\N	PRESENT	0
436511	435794	14207L	PARTICIPANT	\N	PRESENT	0
436512	435794	19747H	PARTICIPANT	\N	PRESENT	0
436513	435794	04043D	PARTICIPANT	\N	PRESENT	0
436514	435794	19619A	PARTICIPANT	\N	PRESENT	0
436515	435794	17589D	PARTICIPANT	\N	PRESENT	0
436516	435794	14257W	PARTICIPANT	\N	PRESENT	0
436517	435794	01043Q	PARTICIPANT	\N	EXCUSE	0
436518	435794	11081P	PARTICIPANT	\N	EXCUSE	0
436519	428273	19583F	PARTICIPANT	\N	PRESENT	0
436520	428273	18083K	PARTICIPANT	\N	PRESENT	0
436521	428273	19737F	PARTICIPANT	\N	PRESENT	0
436522	428273	14069U	PARTICIPANT	\N	PRESENT	0
436523	428273	11085T	PARTICIPANT	\N	PRESENT	0
436524	428273	14105F	PARTICIPANT	\N	PRESENT	0
436525	428273	19713W	PARTICIPANT	\N	PRESENT	0
436526	428273	01024M	PARTICIPANT	\N	PRESENT	0
436527	428273	14191V	PARTICIPANT	\N	PRESENT	0
436528	428273	19794Q	PARTICIPANT	\N	PRESENT	0
436529	428273	14038Y	PARTICIPANT	\N	PRESENT	0
436530	428273	14147R	PARTICIPANT	\N	PRESENT	0
436531	428273	14253S	PARTICIPANT	\N	PRESENT	0
436532	428273	87003B	PARTICIPANT	\N	PRESENT	0
436533	428273	08010L	PARTICIPANT	\N	PRESENT	0
436534	428273	19553Y	PARTICIPANT	\N	PRESENT	0
436535	428273	95063L	PARTICIPANT	\N	PRESENT	0
436536	428273	08034U	PARTICIPANT	\N	PRESENT	0
436537	428273	14217N	PARTICIPANT	\N	PRESENT	0
436538	428273	19489J	PARTICIPANT	\N	PRESENT	0
436539	428273	14157T	PARTICIPANT	\N	PRESENT	0
436540	428273	19820Y	PARTICIPANT	\N	PRESENT	0
436541	428273	19741B	PARTICIPANT	\N	PRESENT	0
436542	432678	19737F	PARTICIPANT	\N	PRESENT	0
436543	428273	19739H	PARTICIPANT	\N	PRESENT	0
436544	428273	14051J	PARTICIPANT	\N	PRESENT	0
430544	430543	19729F	PARTICIPANT	\N	PRESENT	0
430548	430545	05008E	PARTICIPANT	\N	PRESENT	0
430553	430545	14259Y	PARTICIPANT	\N	PRESENT	0
430554	430545	08045X	PARTICIPANT	\N	PRESENT	0
430555	430545	08044W	PARTICIPANT	\N	PRESENT	0
430556	430545	11072N	PARTICIPANT	\N	PRESENT	0
439907	439807	19729F	PARTICIPANT	\N	EXCUSE	0
439908	439807	04044E	PARTICIPANT	\N	EXCUSE	0
439917	439807	14089Y	PARTICIPANT	\N	PRESENT	0
439918	439807	14111D	PARTICIPANT	\N	PRESENT	0
439919	439807	11026G	PARTICIPANT	\N	PRESENT	0
439920	439807	14147R	PARTICIPANT	\N	PRESENT	0
439921	439807	01024M	PARTICIPANT	\N	PRESENT	0
439922	439807	08018U	PARTICIPANT	\N	PRESENT	0
439923	439807	01028R	PARTICIPANT	\N	PRESENT	0
439924	439807	19447X	PARTICIPANT	\N	PRESENT	0
439925	439807	05008E	PRESIDENT	0	PRESENT	0
439926	439807	11072N	PARTICIPANT	\N	PRESENT	0
439927	439807	14151M	PARTICIPANT	\N	PRESENT	0
439928	439807	04047H	PARTICIPANT	\N	PRESENT	0
439982	427766	11070L	PARTICIPANT	\N	PRESENT	0
439983	427766	19593H	PARTICIPANT	\N	PRESENT	0
439984	427766	07004J	PARTICIPANT	\N	PRESENT	0
439985	438976	08056B	PARTICIPANT	\N	PRESENT	0
439986	438976	19673G	PARTICIPANT	\N	PRESENT	0
439987	438976	19719D	PRESIDENT	0	PRESENT	0
439988	427766	19782L	PARTICIPANT	\N	PRESENT	0
439989	427766	19629C	PARTICIPANT	\N	PRESENT	0
439990	427766	19387D	PARTICIPANT	\N	PRESENT	0
439991	427766	19703U	PARTICIPANT	\N	PRESENT	0
439992	427766	04085P	PARTICIPANT	\N	PRESENT	0
439993	427766	14031R	PARTICIPANT	\N	PRESENT	0
439994	427766	01024M	PARTICIPANT	\N	PRESENT	0
439995	427766	04057K	PARTICIPANT	\N	PRESENT	0
439996	427766	17589D	PARTICIPANT	\N	PRESENT	0
439997	427766	11026G	PARTICIPANT	\N	PRESENT	0
439998	427766	19731Y	PARTICIPANT	\N	PRESENT	0
439999	427766	14061L	PARTICIPANT	\N	PRESENT	0
440000	427766	14026U	PARTICIPANT	\N	PRESENT	0
440001	427766	19507S	PARTICIPANT	\N	PRESENT	0
440002	427766	04088S	PARTICIPANT	\N	PRESENT	0
440003	427766	19651A	PARTICIPANT	\N	PRESENT	0
440004	427766	14111D	PARTICIPANT	\N	PRESENT	0
440006	427766	11012A	PARTICIPANT	\N	PRESENT	0
440007	427766	08009T	PARTICIPANT	\N	PRESENT	0
440008	427766	19415P	PARTICIPANT	\N	PRESENT	0
440009	427766	19533U	PARTICIPANT	\N	PRESENT	0
440010	427766	18083K	PARTICIPANT	\N	PRESENT	0
440011	427766	19794Q	PARTICIPANT	\N	PRESENT	0
440012	427766	19798U	PARTICIPANT	\N	PRESENT	0
440013	427766	14105F	PARTICIPANT	\N	PRESENT	0
440014	427766	01058X	PARTICIPANT	\N	PRESENT	0
440015	427766	14028W	PARTICIPANT	\N	PRESENT	0
440016	427766	19349W	PARTICIPANT	\N	PRESENT	0
440017	427766	14147R	PARTICIPANT	\N	PRESENT	0
440018	427766	19447X	PARTICIPANT	\N	PRESENT	0
440019	438976	19421M	PARTICIPANT	\N	PRESENT	0
440020	438976	07004J	PARTICIPANT	\N	PRESENT	0
440021	438976	14187A	PARTICIPANT	\N	PRESENT	0
440022	438976	10015M	PARTICIPANT	\N	PRESENT	0
440023	438976	08053X	PARTICIPANT	\N	PRESENT	0
440024	438976	04044E	PARTICIPANT	\N	PRESENT	0
440025	438976	19721W	PARTICIPANT	\N	PRESENT	0
440026	438976	19671E	PARTICIPANT	\N	PRESENT	0
440027	438976	19669L	PARTICIPANT	\N	EXCUSE	0
440028	427766	14089Y	PARTICIPANT	\N	PRESENT	0
440029	438976	14097Y	PARTICIPANT	\N	PRESENT	0
440030	427766	05008E	PARTICIPANT	\N	PRESENT	0
440031	427766	19826F	PARTICIPANT	\N	PRESENT	0
440032	427766	14205J	PARTICIPANT	\N	PRESENT	0
440033	427766	15447F	PARTICIPANT	\N	PRESENT	0
440034	427766	14193X	PARTICIPANT	\N	PRESENT	0
440035	427766	11103C	PARTICIPANT	\N	PRESENT	0
440036	427766	14079W	PARTICIPANT	\N	PRESENT	0
440037	427766	14211G	PARTICIPANT	\N	PRESENT	0
440038	427766	08018U	PARTICIPANT	\N	PRESENT	0
440039	427766	95030B	PARTICIPANT	\N	PRESENT	0
440040	427766	08039A	PARTICIPANT	\N	PRESENT	0
440041	427766	98050T	PARTICIPANT	\N	PRESENT	0
440042	427766	87003B	PARTICIPANT	\N	PRESENT	0
440043	427766	19253P	PARTICIPANT	\N	PRESENT	0
440044	427766	19711U	PARTICIPANT	\N	PRESENT	0
440045	427766	19553Y	PARTICIPANT	\N	PRESENT	0
440046	427766	14119M	PARTICIPANT	\N	PRESENT	0
440047	427766	14197C	PARTICIPANT	\N	PRESENT	0
440048	427766	19443T	PARTICIPANT	\N	PRESENT	0
440049	427766	08028W	PARTICIPANT	\N	PRESENT	0
440050	427766	19503N	PARTICIPANT	\N	PRESENT	0
440051	427766	14071N	PARTICIPANT	\N	PRESENT	0
440052	427766	14265W	PARTICIPANT	\N	PRESENT	0
440053	427766	97011G	PARTICIPANT	\N	PRESENT	0
440054	427766	14257W	PARTICIPANT	\N	PRESENT	0
440055	427766	14237S	PARTICIPANT	\N	PRESENT	0
440056	427766	19747H	PARTICIPANT	\N	PRESENT	0
440057	427766	14151M	PARTICIPANT	\N	PRESENT	0
440058	427766	19441R	PARTICIPANT	\N	PRESENT	0
440059	427766	01028R	PARTICIPANT	\N	PRESENT	0
440060	427766	01043Q	PARTICIPANT	\N	PRESENT	0
440061	427766	14042U	PARTICIPANT	\N	PRESENT	0
440062	427766	14157T	PARTICIPANT	\N	PRESENT	0
440063	427766	04059M	PARTICIPANT	\N	PRESENT	0
440064	427766	19575F	PARTICIPANT	\N	PRESENT	0
440065	427766	19681G	PARTICIPANT	\N	PRESENT	0
440066	427766	14051J	PARTICIPANT	\N	PRESENT	0
440067	427766	08068F	PARTICIPANT	\N	PRESENT	0
440068	427766	19369B	PARTICIPANT	\N	PRESENT	0
440069	427766	19399H	PARTICIPANT	\N	PRESENT	0
440070	427766	14199E	PARTICIPANT	\N	PRESENT	0
440071	427766	14083S	PARTICIPANT	\N	PRESENT	0
440072	427766	14073Q	PARTICIPANT	\N	PRESENT	0
440073	427766	19729F	PARTICIPANT	\N	PRESENT	0
440074	427766	08056B	PARTICIPANT	\N	PRESENT	0
440075	427766	19569H	PARTICIPANT	\N	PRESENT	0
440076	427766	14187A	PARTICIPANT	\N	PRESENT	0
440077	427766	10015M	PARTICIPANT	\N	PRESENT	0
440078	427766	19737F	PARTICIPANT	\N	PRESENT	0
440079	427766	19749K	PARTICIPANT	\N	PRESENT	0
440080	427766	11072N	PARTICIPANT	\N	PRESENT	0
440088	427766	08053X	PARTICIPANT	\N	PRESENT	0
440089	427766	14195A	PARTICIPANT	\N	PRESENT	0
440090	427766	08069G	PARTICIPANT	\N	PRESENT	0
440091	427766	14231L	PARTICIPANT	\N	PRESENT	0
440093	427766	19295A	PARTICIPANT	\N	PRESENT	0
440094	427766	04070G	PARTICIPANT	\N	PRESENT	0
440095	427766	14121F	PARTICIPANT	\N	PRESENT	0
440096	427766	08052W	PARTICIPANT	\N	PRESENT	0
440097	427766	11104D	PARTICIPANT	\N	PRESENT	0
440098	427766	19649G	PARTICIPANT	\N	PRESENT	0
440099	427766	14251Q	PARTICIPANT	\N	PRESENT	0
440183	427769	11070L	PARTICIPANT	\N	PRESENT	0
440184	427769	05008E	PARTICIPANT	\N	PRESENT	0
440185	427769	04070G	PARTICIPANT	\N	PRESENT	0
440186	427769	19747H	PARTICIPANT	\N	PRESENT	0
440187	427769	08018U	PARTICIPANT	\N	PRESENT	0
440188	427769	19593H	PARTICIPANT	\N	PRESENT	0
440189	427769	04059M	PARTICIPANT	\N	PRESENT	0
440190	427769	19649G	PARTICIPANT	\N	PRESENT	0
440191	427769	11026G	PARTICIPANT	\N	PRESENT	0
440192	427769	14257W	PARTICIPANT	\N	PRESENT	0
440193	427769	11104D	PARTICIPANT	\N	PRESENT	0
440194	427769	19295A	PARTICIPANT	\N	PRESENT	0
440195	427769	19782L	PARTICIPANT	\N	PRESENT	0
440196	427769	11072N	PARTICIPANT	\N	PRESENT	0
440197	427769	19651A	PARTICIPANT	\N	PRESENT	0
440198	427769	19387D	PARTICIPANT	\N	PRESENT	0
440199	427769	14195A	PARTICIPANT	\N	PRESENT	0
440200	427769	17589D	PARTICIPANT	\N	PRESENT	0
440201	427769	14251Q	PARTICIPANT	\N	PRESENT	0
440202	427769	19553Y	PARTICIPANT	\N	PRESENT	0
440203	427769	14121F	PARTICIPANT	\N	PRESENT	0
440204	427769	08069G	PARTICIPANT	\N	PRESENT	0
440205	427769	14135M	PARTICIPANT	\N	PRESENT	0
440206	427769	14034U	PARTICIPANT	\N	PRESENT	0
440207	427769	14031R	PARTICIPANT	\N	PRESENT	0
440208	427769	19369B	PARTICIPANT	\N	PRESENT	0
440209	427769	14187A	PARTICIPANT	\N	PRESENT	0
440210	427769	19611R	PARTICIPANT	\N	PRESENT	0
440211	427769	19673G	PARTICIPANT	\N	PRESENT	0
440212	427769	19798U	PARTICIPANT	\N	PRESENT	0
440213	427769	04033B	PARTICIPANT	\N	PRESENT	0
440214	427769	08039A	PARTICIPANT	\N	PRESENT	0
440215	427769	14079W	PARTICIPANT	\N	PRESENT	0
440216	427769	19383Y	PARTICIPANT	\N	PRESENT	0
440217	427769	19731Y	PARTICIPANT	\N	PRESENT	0
440218	427769	97011G	PARTICIPANT	\N	PRESENT	0
440219	427769	14265W	PARTICIPANT	\N	PRESENT	0
440220	427769	19703U	PARTICIPANT	\N	PRESENT	0
440221	427769	19399H	PARTICIPANT	\N	PRESENT	0
440222	427769	19794Q	PARTICIPANT	\N	PRESENT	0
440897	427774	14221J	PARTICIPANT	\N	PRESENT	0
440898	427774	14103D	PARTICIPANT	\N	PRESENT	0
440899	427774	04089T	PARTICIPANT	\N	PRESENT	0
440900	427774	96004D	PARTICIPANT	\N	PRESENT	0
440901	427774	11090Q	PARTICIPANT	\N	PRESENT	0
440902	427774	14213J	PARTICIPANT	\N	PRESENT	0
440903	427774	19335Q	PARTICIPANT	\N	PRESENT	0
440904	427774	14083S	PARTICIPANT	\N	PRESENT	0
440905	427774	14089Y	PARTICIPANT	\N	PRESENT	0
440906	427774	19749K	PARTICIPANT	\N	PRESENT	0
440907	427774	19826F	PARTICIPANT	\N	PRESENT	0
440908	427774	11085T	PARTICIPANT	\N	PRESENT	0
440909	427774	01043Q	PARTICIPANT	\N	PRESENT	0
440910	427774	01025N	PARTICIPANT	\N	PRESENT	0
440911	427774	01024M	PARTICIPANT	\N	PRESENT	0
440912	427774	14030Q	PARTICIPANT	\N	PRESENT	0
440913	427774	14327T	PARTICIPANT	\N	PRESENT	0
440914	427774	14231L	PARTICIPANT	\N	PRESENT	0
440915	427774	89017R	PARTICIPANT	\N	PRESENT	0
440916	427774	14055N	PARTICIPANT	\N	PRESENT	0
440917	427774	19731Y	PARTICIPANT	\N	PRESENT	0
440918	427774	14105F	PARTICIPANT	\N	PRESENT	0
440919	427774	19269X	PARTICIPANT	\N	PRESENT	0
440920	427774	14097Y	PARTICIPANT	\N	PRESENT	0
440921	427774	04071H	PARTICIPANT	\N	PRESENT	0
440922	427774	19643A	PARTICIPANT	\N	PRESENT	0
440923	427774	19647E	PARTICIPANT	\N	PRESENT	0
440924	427774	04070G	PARTICIPANT	\N	PRESENT	0
440925	427774	14093U	PARTICIPANT	\N	PRESENT	0
440926	427774	04042C	PARTICIPANT	\N	PRESENT	0
440927	427774	07004J	PARTICIPANT	\N	PRESENT	0
440928	427774	19762G	PARTICIPANT	\N	PRESENT	0
440929	427774	14249W	PARTICIPANT	\N	PRESENT	0
440930	427774	14159V	PARTICIPANT	\N	PRESENT	0
440939	427774	14079W	PARTICIPANT	\N	PRESENT	0
440940	427774	05012A	PARTICIPANT	\N	PRESENT	0
440942	427774	08053X	PARTICIPANT	\N	PRESENT	0
440944	427774	19551W	PARTICIPANT	\N	PRESENT	0
440963	427774	19527W	PARTICIPANT	\N	PRESENT	0
440964	427774	11053K	PARTICIPANT	\N	PRESENT	0
440966	427774	08018U	PARTICIPANT	\N	PRESENT	0
440967	427774	19447X	PARTICIPANT	\N	PRESENT	0
440968	427774	11070L	PARTICIPANT	\N	PRESENT	0
440969	427774	19709B	PARTICIPANT	\N	PRESENT	0
440970	427774	05008E	PARTICIPANT	\N	PRESENT	0
440971	427774	17637T	PARTICIPANT	\N	PRESENT	0
440972	427774	98024R	PARTICIPANT	\N	PRESENT	0
440973	427774	19667J	PARTICIPANT	\N	PRESENT	0
440974	427774	08038Y	PARTICIPANT	\N	PRESENT	0
440975	427774	11012A	PARTICIPANT	\N	PRESENT	0
441217	427777	04059M	PARTICIPANT	\N	PRESENT	0
441218	427777	08011M	PARTICIPANT	\N	PRESENT	0
441221	427777	04034C	PARTICIPANT	\N	PRESENT	0
441222	427777	14107H	PARTICIPANT	\N	PRESENT	0
441223	427777	14121F	PARTICIPANT	\N	PRESENT	0
441224	427777	19713W	PARTICIPANT	\N	PRESENT	0
441225	427777	19737F	PARTICIPANT	\N	PRESENT	0
441226	427777	14331P	PARTICIPANT	\N	PRESENT	0
441227	427777	95030B	PARTICIPANT	\N	PRESENT	0
441228	427777	19711U	PARTICIPANT	\N	PRESENT	0
441229	427777	14147R	PARTICIPANT	\N	PRESENT	0
441231	427777	07029T	PARTICIPANT	\N	PRESENT	0
441232	427777	11070L	PARTICIPANT	\N	PRESENT	0
441233	427777	14111D	PARTICIPANT	\N	PRESENT	0
441234	427777	11074Q	PARTICIPANT	\N	PRESENT	0
441235	427777	11040E	PARTICIPANT	\N	PRESENT	0
441236	427777	19629C	PARTICIPANT	\N	PRESENT	0
441658	441657	07033P	PARTICIPANT	\N	PRESENT	0
441659	441657	14179A	PARTICIPANT	\N	PRESENT	0
441661	441660	04040A	PARTICIPANT	\N	PRESENT	0
441662	441660	18083K	PARTICIPANT	\N	PRESENT	0
441664	441663	04040A	PARTICIPANT	\N	PRESENT	0
441666	441665	14083S	PARTICIPANT	\N	PRESENT	0
441667	441665	04049K	PARTICIPANT	\N	PRESENT	0
441768	441767	01057W	PARTICIPANT	\N	PRESENT	0
443699	442845	19673G	PARTICIPANT	\N	PRESENT	0
443700	442845	19421M	PARTICIPANT	\N	PRESENT	0
443704	442845	04040A	PARTICIPANT	\N	PRESENT	0
444531	444530	14157T	PARTICIPANT	\N	PRESENT	0
444532	444530	19599P	PARTICIPANT	\N	PRESENT	0
444533	444530	19637C	PARTICIPANT	\N	PRESENT	0
444791	443682	01062T	PARTICIPANT	\N	EXCUSE	0
444792	443682	04034C	PARTICIPANT	\N	EXCUSE	0
445155	445140	14026U	PARTICIPANT	\N	PRESENT	0
445708	442327	99004R	PRESIDENT	0	PRESENT	0
445709	442327	19711U	PARTICIPANT	\N	PRESENT	0
445716	442327	04038G	PARTICIPANT	\N	PRESENT	0
445717	442327	19399H	PARTICIPANT	\N	EXCUSE	0
445718	442327	19369B	PARTICIPANT	\N	PRESENT	0
445724	443770	08024S	PARTICIPANT	\N	PRESENT	0
445725	443770	08045X	PARTICIPANT	\N	PRESENT	0
445749	442327	11097X	PARTICIPANT	\N	PRESENT	0
445751	442327	08024S	PARTICIPANT	\N	EXCUSE	0
445752	442327	14147R	PARTICIPANT	\N	EXCUSE	0
445755	442327	19479G	PARTICIPANT	\N	EXCUSE	0
445926	439812	14151M	PARTICIPANT	\N	PRESENT	0
445927	439812	14021P	PARTICIPANT	\N	PRESENT	0
445928	439812	04038G	PARTICIPANT	\N	PRESENT	0
445929	439812	11072N	PARTICIPANT	\N	PRESENT	0
445930	439812	19543W	PARTICIPANT	\N	PRESENT	0
445931	439812	14179A	PARTICIPANT	\N	PRESENT	0
445932	439812	19737F	PARTICIPANT	\N	PRESENT	0
445933	439812	19479G	PARTICIPANT	\N	PRESENT	0
445934	439812	14089Y	PARTICIPANT	\N	PRESENT	0
445935	439812	14083S	PARTICIPANT	\N	PRESENT	0
445936	439812	14275Y	PARTICIPANT	\N	PRESENT	0
445937	439812	19711U	PARTICIPANT	\N	PRESENT	0
445938	439812	11101A	PARTICIPANT	\N	PRESENT	0
445939	439812	19794Q	PARTICIPANT	\N	PRESENT	0
445940	439812	19447X	PARTICIPANT	\N	PRESENT	0
445941	439812	08049C	PARTICIPANT	\N	PRESENT	0
445942	439812	19319Q	PARTICIPANT	\N	PRESENT	0
445944	439812	14093U	PARTICIPANT	\N	PRESENT	0
445945	439812	19569H	PARTICIPANT	\N	PRESENT	0
446003	445988	19693L	PARTICIPANT	\N	EXCUSE	0
446004	445988	19533U	PARTICIPANT	\N	PRESENT	0
446005	445988	19723Y	PARTICIPANT	\N	PRESENT	0
446007	446006	04043D	PARTICIPANT	\N	PRESENT	0
446009	446008	04043D	PARTICIPANT	\N	PRESENT	0
446012	446010	19503N	PARTICIPANT	\N	PRESENT	0
446015	446013	19503N	PARTICIPANT	\N	PRESENT	0
445924	439812	14053L	PARTICIPANT	\N	PRESENT	0
445925	439812	11085T	PARTICIPANT	\N	PRESENT	0
446023	446022	11053K	PARTICIPANT	\N	PRESENT	0
446024	446022	14159V	PARTICIPANT	\N	PRESENT	0
446025	446022	05012A	PARTICIPANT	\N	PRESENT	0
446249	439813	08034U	PARTICIPANT	\N	PRESENT	0
446250	439813	19794Q	PARTICIPANT	\N	PRESENT	0
446251	439813	15447F	PARTICIPANT	\N	PRESENT	0
446252	439813	19675J	PARTICIPANT	\N	PRESENT	0
446253	439813	14059S	PARTICIPANT	\N	PRESENT	0
446254	439813	19729F	PARTICIPANT	\N	PRESENT	0
446255	439813	19399H	PARTICIPANT	\N	PRESENT	0
446256	439813	19693L	PARTICIPANT	\N	PRESENT	0
446257	439813	14237S	PARTICIPANT	\N	PRESENT	0
446258	439813	14259Y	PARTICIPANT	\N	PRESENT	0
446259	439813	14265W	PARTICIPANT	\N	PRESENT	0
446260	439813	19697Q	PARTICIPANT	\N	PRESENT	0
446261	439813	19591F	PARTICIPANT	\N	PRESENT	0
446262	439813	19812Y	PARTICIPANT	\N	PRESENT	0
446263	439813	14115H	PARTICIPANT	\N	PRESENT	0
446264	439813	19699S	PARTICIPANT	\N	PRESENT	0
446265	439813	14030Q	PARTICIPANT	\N	PRESENT	0
446266	439813	08014Q	PARTICIPANT	\N	PRESENT	0
446267	439813	08024S	PARTICIPANT	\N	PRESENT	0
446268	439813	19253P	PARTICIPANT	\N	PRESENT	0
446269	439813	19760E	PARTICIPANT	\N	PRESENT	0
446270	439813	14235Q	PARTICIPANT	\N	PRESENT	0
446271	439813	19695N	PARTICIPANT	\N	PRESENT	0
446272	439813	19347U	PARTICIPANT	\N	PRESENT	0
446273	439813	04038G	PARTICIPANT	\N	PRESENT	0
446274	439813	19447X	PARTICIPANT	\N	PRESENT	0
446275	439813	11054L	PARTICIPANT	\N	PRESENT	0
446276	439813	04086Q	PARTICIPANT	\N	PRESENT	0
446277	439813	98029W	PARTICIPANT	\N	PRESENT	0
446278	439813	14357A	PARTICIPANT	\N	PRESENT	0
446279	439813	19545Y	PARTICIPANT	\N	PRESENT	0
446280	439813	19685L	PARTICIPANT	\N	PRESENT	0
446281	439813	14267Y	PARTICIPANT	\N	PRESENT	0
446282	439813	88008L	PARTICIPANT	\N	PRESENT	0
446283	439813	08019V	PARTICIPANT	\N	PRESENT	0
446284	439813	14039A	PARTICIPANT	\N	PRESENT	0
446285	439813	14073Q	PARTICIPANT	\N	PRESENT	0
429476	429475	14205J	PARTICIPANT	\N	PRESENT	0
429478	429477	14205J	PARTICIPANT	\N	PRESENT	0
430521	430520	11026G	PARTICIPANT	\N	PRESENT	0
430522	427737	11026G	PARTICIPANT	\N	PRESENT	0
430523	430494	11026G	PARTICIPANT	\N	PRESENT	0
430524	427737	14089Y	PARTICIPANT	\N	PRESENT	0
438267	437428	14111D	PARTICIPANT	\N	PRESENT	0
438268	437428	11026G	PARTICIPANT	\N	PRESENT	0
438269	437428	08045X	PARTICIPANT	\N	PRESENT	0
438270	437428	14001X	PARTICIPANT	\N	PRESENT	0
438271	437428	04044E	PARTICIPANT	\N	PRESENT	0
438272	437428	19673G	PARTICIPANT	\N	PRESENT	0
438273	437428	19675J	PARTICIPANT	\N	PRESENT	0
438274	437428	11033F	PARTICIPANT	\N	PRESENT	0
438275	437428	01028R	PARTICIPANT	\N	PRESENT	0
438276	437428	05008E	PRESIDENT	0	PRESENT	0
438277	437428	14231L	PARTICIPANT	\N	PRESENT	0
438278	437428	19725B	PARTICIPANT	\N	PRESENT	0
438279	437428	19729F	PARTICIPANT	\N	PRESENT	0
438280	437428	14179A	PARTICIPANT	\N	PRESENT	0
438281	437428	14147R	PARTICIPANT	\N	PRESENT	0
438282	437428	14215L	PRESIDENT	1	PRESENT	0
438283	437428	11085T	PARTICIPANT	\N	PRESENT	0
438284	437428	14021P	PARTICIPANT	\N	PRESENT	0
438285	437428	14065Q	PARTICIPANT	\N	EXCUSE	0
438286	437428	11010L	PARTICIPANT	\N	EXCUSE	0
438287	437428	04047H	PARTICIPANT	\N	EXCUSE	0
438307	436938	19443T	PARTICIPANT	\N	PRESENT	0
438308	436938	12041X	PARTICIPANT	\N	PRESENT	0
438309	436938	11080N	PARTICIPANT	\N	PRESENT	0
438310	436938	95030B	PARTICIPANT	\N	PRESENT	0
438311	436938	04034C	PARTICIPANT	\N	PRESENT	0
438312	436938	14079W	PARTICIPANT	\N	PRESENT	0
438313	436938	01058X	PARTICIPANT	\N	PRESENT	0
438314	436938	04040A	PARTICIPANT	\N	PRESENT	0
438315	436938	16685X	PARTICIPANT	\N	PRESENT	0
438316	436938	04042C	PRESIDENT	0	PRESENT	0
438317	436938	11066Q	PARTICIPANT	\N	PRESENT	0
438318	436938	08056B	PARTICIPANT	\N	PRESENT	0
438319	436938	95037J	PARTICIPANT	\N	PRESENT	0
438320	436938	19421M	PARTICIPANT	\N	PRESENT	0
438321	436938	19709B	PARTICIPANT	\N	PRESENT	0
438322	436938	08049C	PARTICIPANT	\N	PRESENT	0
438323	436938	97011G	PARTICIPANT	\N	PRESENT	0
438324	436938	08061X	PARTICIPANT	\N	PRESENT	0
438325	436938	08047A	PARTICIPANT	\N	PRESENT	0
438326	436938	14133K	PARTICIPANT	\N	PRESENT	0
438327	436938	11041F	PARTICIPANT	\N	PRESENT	0
438328	436938	14235Q	PARTICIPANT	\N	PRESENT	0
438329	436938	19251M	PARTICIPANT	\N	PRESENT	0
438330	436938	19319Q	PARTICIPANT	\N	PRESENT	0
438331	436938	14105F	PARTICIPANT	\N	PRESENT	0
438332	436938	14267Y	PARTICIPANT	\N	PRESENT	0
438333	436938	98050T	PARTICIPANT	\N	PRESENT	0
438336	436938	19669L	PARTICIPANT	\N	PRESENT	0
438337	436938	08058D	PARTICIPANT	\N	PRESENT	0
438338	438288	19697Q	PARTICIPANT	\N	PRESENT	0
438339	438288	19565D	PARTICIPANT	\N	PRESENT	0
438340	438288	19569H	PARTICIPANT	\N	PRESENT	0
438341	438288	11097X	PARTICIPANT	\N	PRESENT	0
438342	438288	19415P	PARTICIPANT	\N	PRESENT	0
438343	438288	14223L	PARTICIPANT	\N	PRESENT	0
438344	438288	14227Q	PARTICIPANT	\N	PRESENT	0
438345	438288	19703U	PARTICIPANT	\N	PRESENT	0
438346	438288	14239U	PARTICIPANT	\N	PRESENT	0
438347	438288	19553Y	PARTICIPANT	\N	PRESENT	0
438348	438288	14087W	PARTICIPANT	\N	PRESENT	0
438349	438288	14281W	PARTICIPANT	\N	PRESENT	0
438350	438288	19679N	PARTICIPANT	\N	PRESENT	0
438351	438288	14042U	PARTICIPANT	\N	PRESENT	0
438352	438288	19575F	PARTICIPANT	\N	PRESENT	0
438353	438288	19367Y	PARTICIPANT	\N	PRESENT	0
438354	438288	14213J	PARTICIPANT	\N	PRESENT	0
438355	438288	14217N	PARTICIPANT	\N	PRESENT	0
438356	438288	19683J	PARTICIPANT	\N	PRESENT	0
438357	438288	10006L	PARTICIPANT	\N	PRESENT	0
438358	438288	98024R	PARTICIPANT	\N	PRESENT	0
438359	438288	19521Q	PARTICIPANT	\N	PRESENT	0
438360	438288	19527W	PARTICIPANT	\N	PRESENT	0
438361	438288	01034P	PARTICIPANT	\N	PRESENT	0
438362	438288	04092N	PRESIDENT	0	PRESENT	0
438363	438288	08052W	PARTICIPANT	\N	PRESENT	0
438364	438288	19691J	PARTICIPANT	\N	PRESENT	0
438365	438288	19715Y	PARTICIPANT	\N	PRESENT	0
438366	438288	19723Y	PARTICIPANT	\N	PRESENT	0
438367	438288	19727D	PARTICIPANT	\N	PRESENT	0
438368	438288	14119M	PARTICIPANT	\N	PRESENT	0
438369	438288	11103C	PARTICIPANT	\N	PRESENT	0
438370	438288	19657G	PARTICIPANT	\N	PRESENT	0
438371	438288	19760E	PARTICIPANT	\N	PRESENT	0
438372	438288	14195A	PARTICIPANT	\N	EXCUSE	0
438373	438288	08041T	PARTICIPANT	\N	EXCUSE	0
438486	438335	17589D	PARTICIPANT	\N	PRESENT	0
438488	438288	04045F	PARTICIPANT	\N	PRESENT	0
438489	438288	14026U	PARTICIPANT	\N	PRESENT	0
438490	438288	11031D	PARTICIPANT	\N	PRESENT	0
438491	438288	19301E	PARTICIPANT	\N	PRESENT	0
438493	438492	19697Q	PARTICIPANT	\N	PRESENT	0
438494	438492	19565D	PARTICIPANT	\N	PRESENT	0
438495	438492	19569H	PARTICIPANT	\N	PRESENT	0
438496	438492	11097X	PARTICIPANT	\N	PRESENT	0
438497	438492	19415P	PARTICIPANT	\N	PRESENT	0
438498	438492	14223L	PARTICIPANT	\N	PRESENT	0
438499	438492	04045F	PARTICIPANT	\N	PRESENT	0
438500	438492	14026U	PARTICIPANT	\N	PRESENT	0
438501	438492	14227Q	PARTICIPANT	\N	PRESENT	0
438502	438492	19703U	PARTICIPANT	\N	PRESENT	0
438503	438492	14239U	PARTICIPANT	\N	PRESENT	0
438504	438492	19553Y	PARTICIPANT	\N	PRESENT	0
438505	438492	11031D	PARTICIPANT	\N	PRESENT	0
438506	438492	14087W	PARTICIPANT	\N	PRESENT	0
438507	438492	14281W	PARTICIPANT	\N	PRESENT	0
438508	438492	19679N	PARTICIPANT	\N	PRESENT	0
438509	438492	14042U	PARTICIPANT	\N	PRESENT	0
438510	438492	19575F	PARTICIPANT	\N	PRESENT	0
438511	438492	19367Y	PARTICIPANT	\N	PRESENT	0
438512	438492	14213J	PARTICIPANT	\N	PRESENT	0
438513	438492	14217N	PARTICIPANT	\N	PRESENT	0
438514	438492	19683J	PARTICIPANT	\N	PRESENT	0
438515	438492	10006L	PARTICIPANT	\N	PRESENT	0
438516	438492	98024R	PARTICIPANT	\N	PRESENT	0
438517	438492	19521Q	PARTICIPANT	\N	PRESENT	0
438518	438492	19527W	PARTICIPANT	\N	PRESENT	0
438519	438492	01034P	PARTICIPANT	\N	PRESENT	0
438520	438492	04092N	PRESIDENT	0	PRESENT	0
438521	438492	08052W	PARTICIPANT	\N	PRESENT	0
438522	438492	19301E	PARTICIPANT	\N	PRESENT	0
438523	438492	19691J	PARTICIPANT	\N	PRESENT	0
438524	438492	19715Y	PARTICIPANT	\N	PRESENT	0
438525	438492	19723Y	PARTICIPANT	\N	PRESENT	0
438526	438492	19727D	PARTICIPANT	\N	PRESENT	0
438527	438492	14119M	PARTICIPANT	\N	PRESENT	0
438528	438492	11103C	PARTICIPANT	\N	PRESENT	0
438529	438492	19657G	PARTICIPANT	\N	PRESENT	0
438530	438492	19760E	PARTICIPANT	\N	PRESENT	0
438531	438492	14195A	PARTICIPANT	\N	EXCUSE	0
438532	438492	08041T	PARTICIPANT	\N	EXCUSE	0
436545	428273	14065Q	PARTICIPANT	\N	PRESENT	0
436546	428273	14073Q	PARTICIPANT	\N	PRESENT	0
436553	428273	08024S	PARTICIPANT	\N	PRESENT	0
436554	428273	14219Q	PARTICIPANT	\N	PRESENT	0
436555	428273	19295A	PARTICIPANT	\N	PRESENT	0
436556	428273	11049P	PARTICIPANT	\N	PRESENT	0
436557	428273	14034U	PARTICIPANT	\N	PRESENT	0
436558	428273	97011G	PARTICIPANT	\N	PRESENT	0
436559	428273	08009T	PARTICIPANT	\N	PRESENT	0
436560	433965	95030B	PARTICIPANT	\N	EXCUSE	0
436561	433965	04035D	PARTICIPANT	\N	EXCUSE	0
436562	433965	08053X	PARTICIPANT	\N	EXCUSE	0
436563	433965	01062T	PARTICIPANT	\N	EXCUSE	0
436564	428273	14195A	PARTICIPANT	\N	PRESENT	0
436565	428273	19545Y	PARTICIPANT	\N	PRESENT	0
436566	428273	08056B	PARTICIPANT	\N	PRESENT	0
436567	428273	89017R	PARTICIPANT	\N	PRESENT	0
436568	428273	98050T	PARTICIPANT	\N	PRESENT	0
436569	428273	14199E	PARTICIPANT	\N	PRESENT	0
436570	428273	19782L	PARTICIPANT	\N	PRESENT	0
436571	428273	19749K	PARTICIPANT	\N	PRESENT	0
436572	428273	14265W	PARTICIPANT	\N	PRESENT	0
436573	428273	19515S	PARTICIPANT	\N	PRESENT	0
436574	428273	07029T	PARTICIPANT	\N	PRESENT	0
436575	428273	19507S	PARTICIPANT	\N	PRESENT	0
436576	428273	14071N	PARTICIPANT	\N	PRESENT	0
436577	428273	04088S	PARTICIPANT	\N	PRESENT	0
436578	428273	14087W	PARTICIPANT	\N	PRESENT	0
436579	428273	10015M	PARTICIPANT	\N	PRESENT	0
436580	435786	19766L	PARTICIPANT	\N	PRESENT	0
436581	435786	04070G	PRESIDENT	0	PRESENT	0
436582	435786	19699S	PARTICIPANT	\N	PRESENT	0
436583	435786	19533U	PARTICIPANT	\N	PRESENT	0
436584	435786	04033B	PARTICIPANT	\N	PRESENT	0
436585	435786	19329S	PARTICIPANT	\N	PRESENT	0
436586	435786	14229S	PARTICIPANT	\N	PRESENT	0
436587	435786	14241N	PARTICIPANT	\N	PRESENT	0
436588	435786	19573D	PARTICIPANT	\N	PRESENT	0
436589	435786	14039A	PARTICIPANT	\N	PRESENT	0
436590	435786	14107H	PARTICIPANT	\N	PRESENT	0
436591	435786	08017T	PARTICIPANT	\N	PRESENT	0
436592	435786	07033P	PARTICIPANT	\N	PRESENT	0
436593	435786	08012N	PARTICIPANT	\N	PRESENT	0
436594	435786	19335Q	PARTICIPANT	\N	PRESENT	0
436595	435786	14249W	PARTICIPANT	\N	PRESENT	0
436596	435786	08039A	PARTICIPANT	\N	PRESENT	0
436597	435786	19593H	PARTICIPANT	\N	PRESENT	0
436598	435786	14061L	PARTICIPANT	\N	PRESENT	0
436599	435786	14073Q	PARTICIPANT	\N	PRESENT	0
436600	435786	19611R	PARTICIPANT	\N	PRESENT	0
436601	435786	08035V	PARTICIPANT	\N	PRESENT	0
436602	435786	19693L	PARTICIPANT	\N	PRESENT	0
436603	435786	87003B	PARTICIPANT	\N	PRESENT	0
436604	435786	19399H	PARTICIPANT	\N	PRESENT	0
436605	435786	14030Q	PARTICIPANT	\N	PRESENT	0
436606	435786	14251Q	PARTICIPANT	\N	PRESENT	0
436607	435786	04059M	PARTICIPANT	\N	PRESENT	0
436608	435786	19735D	PARTICIPANT	\N	PRESENT	0
436609	435786	11109J	PARTICIPANT	\N	PRESENT	0
436610	435786	11083R	PARTICIPANT	\N	PRESENT	0
436611	435786	14123H	PARTICIPANT	\N	PRESENT	0
436612	435786	11043H	PARTICIPANT	\N	PRESENT	0
436613	435786	19749K	PARTICIPANT	\N	PRESENT	0
436614	435786	04018C	PARTICIPANT	\N	PRESENT	0
436615	435786	19621T	PARTICIPANT	\N	PRESENT	0
436616	435786	14059S	PARTICIPANT	\N	EXCUSE	0
436617	435786	04057K	PARTICIPANT	\N	EXCUSE	0
436618	435786	92040Q	PARTICIPANT	\N	EXCUSE	0
436619	435786	14063N	PARTICIPANT	\N	EXCUSE	0
436620	435786	11104D	PARTICIPANT	\N	EXCUSE	0
436621	435786	14201E	PARTICIPANT	\N	EXCUSE	0
436622	428273	19333N	PARTICIPANT	\N	PRESENT	0
436623	428273	08014Q	PARTICIPANT	\N	PRESENT	0
436624	428273	14173T	PARTICIPANT	\N	PRESENT	0
436627	428273	19715Y	PARTICIPANT	\N	PRESENT	0
436719	425636	19741B	PARTICIPANT	\N	PRESENT	0
436713	425636	19399H	PARTICIPANT	\N	PRESENT	0
436714	425636	04086Q	PARTICIPANT	\N	PRESENT	0
436715	425636	10015M	PARTICIPANT	\N	PRESENT	0
436716	425636	14195A	PARTICIPANT	\N	PRESENT	0
436717	425636	04088S	PARTICIPANT	\N	PRESENT	0
436718	425636	19573D	PARTICIPANT	\N	PRESENT	0
436720	425636	08073C	PARTICIPANT	\N	PRESENT	0
436721	425636	19621T	PARTICIPANT	\N	PRESENT	0
436722	425636	19583F	PARTICIPANT	\N	PRESENT	0
436723	425636	17589D	PARTICIPANT	\N	PRESENT	0
436724	425636	14173T	PARTICIPANT	\N	PRESENT	0
436725	425636	19611R	PARTICIPANT	\N	PRESENT	0
436726	425636	87003B	PARTICIPANT	\N	PRESENT	0
436727	425636	14265W	PARTICIPANT	\N	PRESENT	0
436728	425636	14001X	PARTICIPANT	\N	PRESENT	0
436729	425636	01057W	PARTICIPANT	\N	PRESENT	0
436730	425636	14225N	PARTICIPANT	\N	PRESENT	0
436731	425636	19441R	PARTICIPANT	\N	PRESENT	0
436732	425636	14327T	PARTICIPANT	\N	PRESENT	0
436733	425636	14089Y	PARTICIPANT	\N	PRESENT	0
436734	425636	14231L	PARTICIPANT	\N	PRESENT	0
436735	425636	14105F	PARTICIPANT	\N	PRESENT	0
436736	425636	19575F	PARTICIPANT	\N	PRESENT	0
436737	425636	19711U	PARTICIPANT	\N	PRESENT	0
436738	425636	08069G	PARTICIPANT	\N	PRESENT	0
436739	425636	19387D	PARTICIPANT	\N	PRESENT	0
436740	425636	19687N	PARTICIPANT	\N	PRESENT	0
436741	425636	08034U	PARTICIPANT	\N	PRESENT	0
436742	425636	14115H	PARTICIPANT	\N	PRESENT	0
436743	425636	12016W	PARTICIPANT	\N	PRESENT	0
436744	425636	11048N	PARTICIPANT	\N	PRESENT	0
436745	425636	11067R	PARTICIPANT	\N	PRESENT	0
436746	425636	08056B	PARTICIPANT	\N	PRESENT	0
436747	433965	14133K	PARTICIPANT	\N	PRESENT	0
436748	425636	14147R	PARTICIPANT	\N	PRESENT	0
436749	425636	19671E	PARTICIPANT	\N	PRESENT	0
436750	425636	19820Y	PARTICIPANT	\N	PRESENT	0
436751	425636	14259Y	PARTICIPANT	\N	PRESENT	0
436752	425636	19693L	PARTICIPANT	\N	PRESENT	0
436753	425636	08017T	PARTICIPANT	\N	PRESENT	0
436754	425636	19715Y	PARTICIPANT	\N	PRESENT	0
436755	425636	14179A	PARTICIPANT	\N	PRESENT	0
436756	425636	19651A	PARTICIPANT	\N	PRESENT	0
436757	425636	01028R	PARTICIPANT	\N	PRESENT	0
436758	425636	05008E	PARTICIPANT	\N	PRESENT	0
436759	425636	19515S	PARTICIPANT	\N	PRESENT	0
436760	425636	14123H	PARTICIPANT	\N	PRESENT	0
436761	425636	11027H	PARTICIPANT	\N	PRESENT	0
436762	425636	19349W	PARTICIPANT	\N	PRESENT	0
436763	425636	04018C	PARTICIPANT	\N	PRESENT	0
436764	425636	14087W	PARTICIPANT	\N	PRESENT	0
436765	425636	19533U	PARTICIPANT	\N	PRESENT	0
436766	425636	19507S	PARTICIPANT	\N	PRESENT	0
436767	425636	14033T	PARTICIPANT	\N	PRESENT	0
436768	425636	19543W	PARTICIPANT	\N	PRESENT	0
436769	425636	99004R	PARTICIPANT	\N	PRESENT	0
436770	425636	19253P	PARTICIPANT	\N	PRESENT	0
436771	425636	19295A	PARTICIPANT	\N	PRESENT	0
436772	425636	01058X	PARTICIPANT	\N	PRESENT	0
436773	425636	19768N	PARTICIPANT	\N	PRESENT	0
436774	425636	19647E	PARTICIPANT	\N	PRESENT	0
436775	425636	19335Q	PARTICIPANT	\N	PRESENT	0
436776	425636	19699S	PARTICIPANT	\N	PRESENT	0
436777	425636	08015R	PARTICIPANT	\N	PRESENT	0
436778	425636	19749K	PARTICIPANT	\N	PRESENT	0
436779	425636	19527W	PARTICIPANT	\N	PRESENT	0
436782	425636	95063L	PARTICIPANT	\N	PRESENT	0
436783	425636	14199E	PARTICIPANT	\N	PRESENT	0
436784	425636	19657G	PARTICIPANT	\N	PRESENT	0
436785	425636	11097X	PARTICIPANT	\N	PRESENT	0
436786	425636	19443T	PARTICIPANT	\N	PRESENT	0
436787	425636	19691J	PARTICIPANT	\N	PRESENT	0
436788	425636	19727D	PARTICIPANT	\N	PRESENT	0
436789	425636	19333N	PARTICIPANT	\N	PRESENT	0
436790	425636	19762G	PARTICIPANT	\N	PRESENT	0
436791	425636	11090Q	PARTICIPANT	\N	PRESENT	0
436792	425636	19479G	PARTICIPANT	\N	PRESENT	0
436793	425636	01024M	PARTICIPANT	\N	PRESENT	0
436794	425636	19413M	PARTICIPANT	\N	PRESENT	0
436795	425636	19735D	PARTICIPANT	\N	PRESENT	0
436796	425636	19549D	PARTICIPANT	\N	PRESENT	0
436710	425636	14034U	PARTICIPANT	\N	PRESENT	0
436711	425636	14030Q	PARTICIPANT	\N	PRESENT	0
436797	425636	08010L	PARTICIPANT	\N	PRESENT	0
436798	425636	19301E	PARTICIPANT	\N	PRESENT	0
436799	425636	19667J	PARTICIPANT	\N	PRESENT	0
436800	425636	14111D	PARTICIPANT	\N	PRESENT	0
436801	425636	14207L	PARTICIPANT	\N	PRESENT	0
436802	425636	14021P	PARTICIPANT	\N	PRESENT	0
436803	425636	11070L	PARTICIPANT	\N	PRESENT	0
436804	425636	19467C	PARTICIPANT	\N	PRESENT	0
436805	425636	19489J	PARTICIPANT	\N	PRESENT	0
436806	425636	14083S	PARTICIPANT	\N	PRESENT	0
425284	425279	14157T	PARTICIPANT	\N	PRESENT	0
425285	425281	14157T	PARTICIPANT	\N	PRESENT	0
425303	425300	14169X	PARTICIPANT	\N	PRESENT	0
425435	425434	19521Q	PARTICIPANT	\N	PRESENT	0
425436	425434	04088S	PARTICIPANT	\N	PRESENT	0
425437	425434	98050T	PARTICIPANT	\N	PRESENT	0
425438	425434	04044E	PARTICIPANT	\N	PRESENT	0
425439	425434	19619A	PARTICIPANT	\N	PRESENT	0
425440	425434	01048V	PARTICIPANT	\N	PRESENT	0
425461	425129	14111D	PARTICIPANT	\N	PRESENT	0
425667	425666	08039A	PARTICIPANT	\N	PRESENT	0
425668	425666	04045F	PARTICIPANT	\N	PRESENT	0
425836	425835	01024M	PARTICIPANT	\N	PRESENT	0
425838	425837	10015M	PARTICIPANT	\N	PRESENT	0
425840	425839	04049K	PARTICIPANT	\N	PRESENT	0
425841	425839	16685X	PARTICIPANT	\N	PRESENT	0
425843	425842	04049K	PARTICIPANT	\N	PRESENT	0
425844	425842	16685X	PARTICIPANT	\N	PRESENT	0
425846	425845	04049K	PARTICIPANT	\N	PRESENT	0
425847	425845	16685X	PARTICIPANT	\N	PRESENT	0
425849	425848	04049K	PARTICIPANT	\N	PRESENT	0
425850	425848	16685X	PARTICIPANT	\N	PRESENT	0
425852	425851	14083S	PARTICIPANT	\N	PRESENT	0
425853	425851	14061L	PARTICIPANT	\N	PRESENT	0
425854	425851	19671E	PARTICIPANT	\N	PRESENT	0
425856	425855	04049K	PARTICIPANT	\N	PRESENT	0
425857	425855	16685X	PARTICIPANT	\N	PRESENT	0
425859	425858	16685X	PARTICIPANT	\N	PRESENT	0
425860	425858	04049K	PARTICIPANT	\N	PRESENT	0
425862	425861	16685X	PARTICIPANT	\N	PRESENT	0
425863	425861	04049K	PARTICIPANT	\N	PRESENT	0
428511	428503	19333N	PARTICIPANT	\N	PRESENT	0
428514	428506	19333N	PARTICIPANT	\N	PRESENT	0
428515	428504	19333N	PARTICIPANT	\N	PRESENT	0
428516	428505	19333N	PARTICIPANT	\N	PRESENT	0
434011	434009	14207L	PARTICIPANT	\N	PRESENT	0
434013	434009	01025N	PARTICIPANT	\N	PRESENT	0
434018	430766	01048V	PARTICIPANT	\N	PRESENT	0
434019	430766	01058X	PARTICIPANT	\N	PRESENT	0
434021	430766	19533U	PARTICIPANT	\N	PRESENT	0
434022	430766	19503N	PARTICIPANT	\N	PRESENT	0
434023	430766	19723Y	PARTICIPANT	\N	PRESENT	0
434024	430766	98050T	PARTICIPANT	\N	PRESENT	0
434025	430766	14079W	PARTICIPANT	\N	PRESENT	0
434046	430232	14257W	PARTICIPANT	\N	PRESENT	0
434047	430232	04086Q	PARTICIPANT	\N	PRESENT	0
434048	430232	08010L	PARTICIPANT	\N	PRESENT	0
434049	430232	19489J	PARTICIPANT	\N	PRESENT	0
434050	430232	08049C	PARTICIPANT	\N	PRESENT	0
434051	430232	01057W	PARTICIPANT	\N	PRESENT	0
434052	430232	11048N	PARTICIPANT	\N	PRESENT	0
434095	434094	19575F	PARTICIPANT	\N	PRESENT	0
434096	434094	14069U	PARTICIPANT	\N	PRESENT	0
434097	434094	14083S	PARTICIPANT	\N	PRESENT	0
434098	434094	11053K	PARTICIPANT	\N	PRESENT	0
434099	434094	88008L	PARTICIPANT	\N	PRESENT	0
434100	434094	19611R	PARTICIPANT	\N	PRESENT	0
434101	434094	19671E	PARTICIPANT	\N	PRESENT	0
434102	434094	14257W	PARTICIPANT	\N	PRESENT	0
436970	433637	08043V	PARTICIPANT	\N	PRESENT	0
436973	435330	11045K	PARTICIPANT	\N	PRESENT	0
436974	435330	11072N	PARTICIPANT	\N	PRESENT	0
436975	435330	08043V	PARTICIPANT	\N	PRESENT	0
440225	427769	04088S	PARTICIPANT	\N	PRESENT	0
440226	427769	19447X	PARTICIPANT	\N	PRESENT	0
440227	427769	19507S	PARTICIPANT	\N	PRESENT	0
440228	427769	19443T	PARTICIPANT	\N	PRESENT	0
440229	427769	14038Y	PARTICIPANT	\N	PRESENT	0
440230	427769	19533U	PARTICIPANT	\N	PRESENT	0
440231	427769	19711U	PARTICIPANT	\N	PRESENT	0
440232	427769	19415P	PARTICIPANT	\N	PRESENT	0
440233	427769	08028W	PARTICIPANT	\N	PRESENT	0
440234	427769	19691J	PARTICIPANT	\N	PRESENT	0
440235	427769	14089Y	PARTICIPANT	\N	PRESENT	0
440236	427769	14073Q	PARTICIPANT	\N	PRESENT	0
440237	427769	19749K	PARTICIPANT	\N	PRESENT	0
440238	427769	19713W	PARTICIPANT	\N	PRESENT	0
440239	427769	19737F	PARTICIPANT	\N	PRESENT	0
440240	427769	14231L	PARTICIPANT	\N	PRESENT	0
440241	427769	19681G	PARTICIPANT	\N	PRESENT	0
440242	427769	01024M	PARTICIPANT	\N	PRESENT	0
440243	427769	14157T	PARTICIPANT	\N	PRESENT	0
440244	427769	19549D	PARTICIPANT	\N	PRESENT	0
440245	427769	08060W	PARTICIPANT	\N	PRESENT	0
440246	427769	11103C	PARTICIPANT	\N	PRESENT	0
440247	427769	07004J	PARTICIPANT	\N	PRESENT	0
440248	427769	19253P	PARTICIPANT	\N	PRESENT	0
440249	427769	19629C	PARTICIPANT	\N	PRESENT	0
440250	427769	08052W	PARTICIPANT	\N	PRESENT	0
440251	427769	11090Q	PARTICIPANT	\N	PRESENT	0
440252	427769	11064N	PARTICIPANT	\N	PRESENT	0
440253	427769	14065Q	PARTICIPANT	\N	PRESENT	0
440254	427769	87003B	PARTICIPANT	\N	PRESENT	0
440255	427769	14229S	PARTICIPANT	\N	PRESENT	0
440257	427769	19812Y	PARTICIPANT	\N	PRESENT	0
440258	427769	19820Y	PARTICIPANT	\N	PRESENT	0
440259	427769	95030B	PARTICIPANT	\N	PRESENT	0
440260	427769	14147R	PARTICIPANT	\N	PRESENT	0
440261	427769	14217N	PARTICIPANT	\N	PRESENT	0
440262	427769	19545Y	PARTICIPANT	\N	PRESENT	0
440263	427769	19543W	PARTICIPANT	\N	PRESENT	0
440264	427769	14071N	PARTICIPANT	\N	PRESENT	0
440265	427769	14193X	PARTICIPANT	\N	PRESENT	0
440266	427769	19826F	PARTICIPANT	\N	PRESENT	0
440267	427769	19479G	PARTICIPANT	\N	PRESENT	0
440268	427769	14199E	PARTICIPANT	\N	PRESENT	0
440223	427769	14357A	PARTICIPANT	\N	PRESENT	0
440224	427769	18083K	PARTICIPANT	\N	PRESENT	0
440269	427769	01048V	PARTICIPANT	\N	PRESENT	0
440270	427769	14026U	PARTICIPANT	\N	PRESENT	0
440271	427769	04086Q	PARTICIPANT	\N	PRESENT	0
440272	427769	19521Q	PARTICIPANT	\N	PRESENT	0
440273	427769	14211G	PARTICIPANT	\N	PRESENT	0
440274	427769	14173T	PARTICIPANT	\N	PRESENT	0
440281	427769	19695N	PARTICIPANT	\N	PRESENT	0
440289	427769	19735D	PARTICIPANT	\N	PRESENT	0
440290	427769	14030Q	PARTICIPANT	\N	PRESENT	0
440291	427769	19693L	PARTICIPANT	\N	PRESENT	0
440292	427769	11067R	PARTICIPANT	\N	PRESENT	0
440293	427769	14083S	PARTICIPANT	\N	PRESENT	0
440294	427769	08017T	PARTICIPANT	\N	PRESENT	0
440295	427769	14205J	PARTICIPANT	\N	PRESENT	0
440366	427770	01043Q	PARTICIPANT	\N	PRESENT	0
440367	427770	08018U	PARTICIPANT	\N	PRESENT	0
440368	427770	19747H	PARTICIPANT	\N	PRESENT	0
440369	427770	19649G	PARTICIPANT	\N	PRESENT	0
440370	427770	14257W	PARTICIPANT	\N	PRESENT	0
440371	427770	19295A	PARTICIPANT	\N	PRESENT	0
440372	427770	19593H	PARTICIPANT	\N	PRESENT	0
440373	427770	19681G	PARTICIPANT	\N	PRESENT	0
440374	427770	19629C	PARTICIPANT	\N	PRESENT	0
440375	427770	04059M	PARTICIPANT	\N	PRESENT	0
440376	427770	19693L	PARTICIPANT	\N	PRESENT	0
440377	427770	04018C	PARTICIPANT	\N	PRESENT	0
440378	427770	19399H	PARTICIPANT	\N	PRESENT	0
440396	427770	14021P	PARTICIPANT	\N	PRESENT	0
440380	427770	19798U	PARTICIPANT	\N	PRESENT	0
440381	427770	05008E	PARTICIPANT	\N	PRESENT	0
440382	427770	19782L	PARTICIPANT	\N	PRESENT	0
440383	427770	11072N	PARTICIPANT	\N	PRESENT	0
440384	427770	04070G	PARTICIPANT	\N	PRESENT	0
440385	427770	19794Q	PARTICIPANT	\N	PRESENT	0
440386	427770	19253P	PARTICIPANT	\N	PRESENT	0
440387	427770	01034P	PARTICIPANT	\N	PRESENT	0
440388	427770	14030Q	PARTICIPANT	\N	PRESENT	0
440389	427770	19735D	PARTICIPANT	\N	PRESENT	0
440390	427770	14089Y	PARTICIPANT	\N	PRESENT	0
440391	427770	08010L	PARTICIPANT	\N	PRESENT	0
440392	427770	14147R	PARTICIPANT	\N	PRESENT	0
440393	427770	14079W	PARTICIPANT	\N	PRESENT	0
440394	427770	14119M	PARTICIPANT	\N	PRESENT	0
440395	427770	19621T	PARTICIPANT	\N	PRESENT	0
440397	427770	19545Y	PARTICIPANT	\N	PRESENT	0
440398	427770	19447X	PARTICIPANT	\N	PRESENT	0
440399	427770	14109K	PARTICIPANT	\N	PRESENT	0
440400	427770	19749K	PARTICIPANT	\N	PRESENT	0
440401	427770	14251Q	PARTICIPANT	\N	PRESENT	0
440402	427770	19741B	PARTICIPANT	\N	PRESENT	0
440403	427770	18083K	PARTICIPANT	\N	PRESENT	0
440404	427770	07029T	PARTICIPANT	\N	PRESENT	0
440405	427770	14133K	PARTICIPANT	\N	PRESENT	0
440406	427770	14026U	PARTICIPANT	\N	PRESENT	0
440407	427770	14033T	PARTICIPANT	\N	PRESENT	0
440408	427770	19383Y	PARTICIPANT	\N	PRESENT	0
440409	427770	14034U	PARTICIPANT	\N	PRESENT	0
440410	427770	14265W	PARTICIPANT	\N	PRESENT	0
440411	427770	08069G	PARTICIPANT	\N	PRESENT	0
446288	439813	19681G	PARTICIPANT	\N	PRESENT	0
446289	439813	14257W	PARTICIPANT	\N	PRESENT	0
446290	439813	14081Q	PARTICIPANT	\N	PRESENT	0
446291	439813	08060W	PARTICIPANT	\N	PRESENT	0
446292	439813	01024M	PARTICIPANT	\N	PRESENT	0
446293	439813	19723Y	PARTICIPANT	\N	PRESENT	0
446294	439813	14249W	PARTICIPANT	\N	PRESENT	0
446295	444735	08056B	PARTICIPANT	\N	PRESENT	0
446296	444735	14187A	PARTICIPANT	\N	PRESENT	0
446297	444735	19421M	PARTICIPANT	\N	PRESENT	0
446298	444735	07004J	PARTICIPANT	\N	PRESENT	0
446299	444735	04040A	PARTICIPANT	\N	PRESENT	0
446300	444735	08053X	PARTICIPANT	\N	PRESENT	0
446301	444735	08010L	PARTICIPANT	\N	PRESENT	0
446302	444735	19585H	PARTICIPANT	\N	PRESENT	0
446303	444735	19673G	PARTICIPANT	\N	PRESENT	0
446304	444735	19719D	PRESIDENT	0	PRESENT	0
446305	444735	19721W	PARTICIPANT	\N	PRESENT	0
446306	444735	14097Y	PARTICIPANT	\N	PRESENT	0
446307	444735	19669L	PARTICIPANT	\N	PRESENT	0
446308	439813	17779H	PARTICIPANT	\N	PRESENT	0
446309	439813	19749K	PARTICIPANT	\N	PRESENT	0
446310	444735	11026G	PARTICIPANT	\N	PRESENT	0
446363	446361	14237S	PARTICIPANT	\N	PRESENT	0
446364	446361	19637C	PARTICIPANT	\N	PRESENT	0
446365	446361	95067Q	PARTICIPANT	\N	PRESENT	0
446367	446366	04070G	PARTICIPANT	\N	PRESENT	0
446767	444386	11067R	PARTICIPANT	\N	PRESENT	0
446768	444386	04092N	PRESIDENT	0	PRESENT	0
446769	444386	19569H	PARTICIPANT	\N	PRESENT	0
446770	444386	08052W	PARTICIPANT	\N	PRESENT	0
446771	444386	08043V	PARTICIPANT	\N	PRESENT	0
446772	444386	11066Q	PARTICIPANT	\N	PRESENT	0
446773	444386	04045F	PARTICIPANT	\N	PRESENT	0
446774	444386	19447X	PARTICIPANT	\N	PRESENT	0
446775	444386	05008E	PARTICIPANT	\N	PRESENT	0
446776	444386	18083K	PARTICIPANT	\N	PRESENT	0
446777	444386	19553Y	PARTICIPANT	\N	PRESENT	0
446778	444386	14147R	PARTICIPANT	\N	PRESENT	0
446779	444386	14195A	PARTICIPANT	\N	PRESENT	0
446780	444386	14213J	PARTICIPANT	\N	PRESENT	0
446781	444386	99004R	PARTICIPANT	\N	PRESENT	0
446782	444386	19683J	PARTICIPANT	\N	PRESENT	0
446783	444386	14065Q	PARTICIPANT	\N	PRESENT	0
446784	444386	19415P	PARTICIPANT	\N	PRESENT	0
446785	444386	10006L	PARTICIPANT	\N	PRESENT	0
446786	444386	11072N	PARTICIPANT	\N	PRESENT	0
446795	446385	14237S	PARTICIPANT	\N	PRESENT	0
446796	446385	14038Y	PARTICIPANT	\N	PRESENT	0
446797	446385	15447F	PARTICIPANT	\N	PRESENT	0
446798	446385	14029X	PARTICIPANT	\N	PRESENT	0
446799	446385	08060W	PARTICIPANT	\N	PRESENT	0
446800	446385	19794Q	PARTICIPANT	\N	PRESENT	0
446801	446385	14031R	PARTICIPANT	\N	PRESENT	0
446802	446385	19737F	PARTICIPANT	\N	PRESENT	0
446803	446385	04097T	PARTICIPANT	\N	PRESENT	0
446804	446385	19820Y	PARTICIPANT	\N	PRESENT	0
446805	446385	19826F	PARTICIPANT	\N	PRESENT	0
446806	446385	19637C	PARTICIPANT	\N	PRESENT	0
446807	446385	19383Y	PARTICIPANT	\N	PRESENT	0
446808	446385	19333N	PARTICIPANT	\N	PRESENT	0
446809	446385	19599P	PARTICIPANT	\N	PRESENT	0
446810	446385	14051J	PARTICIPANT	\N	PRESENT	0
446811	446385	08009T	PRESIDENT	0	PRESENT	0
446812	446385	19503N	PARTICIPANT	\N	PRESENT	0
446813	446385	19739H	PARTICIPANT	\N	PRESENT	0
446814	446385	08024S	PARTICIPANT	\N	PRESENT	0
446816	446385	19713W	PARTICIPANT	\N	PRESENT	0
446817	446385	19549D	PARTICIPANT	\N	PRESENT	0
446818	446385	19347U	PARTICIPANT	\N	PRESENT	0
446819	446794	19768N	PARTICIPANT	\N	PRESENT	0
446820	446794	19515S	PARTICIPANT	\N	PRESENT	0
446821	446794	19782L	PARTICIPANT	\N	PRESENT	0
446822	446794	14357A	PARTICIPANT	\N	PRESENT	0
446823	446794	19441R	PARTICIPANT	\N	PRESENT	0
446824	446794	19812Y	PARTICIPANT	\N	PRESENT	0
446825	446794	19413M	PARTICIPANT	\N	PRESENT	0
446826	446794	19631V	PARTICIPANT	\N	PRESENT	0
446827	446794	11099A	PARTICIPANT	\N	PRESENT	0
446828	446794	08068F	PARTICIPANT	\N	PRESENT	0
446829	446794	04049K	PARTICIPANT	\N	PRESENT	0
446830	446794	08015R	PARTICIPANT	\N	PRESENT	0
446831	446794	08019V	PARTICIPANT	\N	PRESENT	0
446832	446794	14197C	PARTICIPANT	\N	PRESENT	0
446833	446794	19369B	PARTICIPANT	\N	PRESENT	0
446834	446794	08028W	PARTICIPANT	\N	PRESENT	0
446835	446794	19563B	PARTICIPANT	\N	PRESENT	0
446836	446794	14265W	PARTICIPANT	\N	PRESENT	0
446837	446794	14329V	PARTICIPANT	\N	PRESENT	0
446838	446794	14135M	PARTICIPANT	\N	PRESENT	0
446839	446794	19467C	PARTICIPANT	\N	PRESENT	0
446840	446794	14187A	PARTICIPANT	\N	PRESENT	0
446841	446794	08062Y	PARTICIPANT	\N	PRESENT	0
446842	446794	19695N	PARTICIPANT	\N	PRESENT	0
446843	446794	11090Q	PRESIDENT	0	PRESENT	0
446844	446794	14033T	PARTICIPANT	\N	PRESENT	0
446845	446794	14205J	PARTICIPANT	\N	PRESENT	0
446846	446794	04088S	PARTICIPANT	\N	PRESENT	0
446847	446794	11056N	PARTICIPANT	\N	PRESENT	0
446848	446794	04089T	PARTICIPANT	\N	PRESENT	0
446849	446794	14115H	PARTICIPANT	\N	PRESENT	0
446850	446794	19507S	PARTICIPANT	\N	PRESENT	0
446851	446794	11101A	PARTICIPANT	\N	PRESENT	0
446852	446794	19747H	PARTICIPANT	\N	PRESENT	0
446853	446794	14207L	PARTICIPANT	\N	PRESENT	0
446854	446794	04043D	PARTICIPANT	\N	PRESENT	0
446855	446794	19619A	PARTICIPANT	\N	PRESENT	0
446856	446794	14257W	PARTICIPANT	\N	PRESENT	0
446857	445753	04042C	PRESIDENT	0	PRESENT	0
446858	445753	98005N	PARTICIPANT	\N	PRESENT	0
446859	445753	19443T	PARTICIPANT	\N	PRESENT	0
446860	445753	11080N	PARTICIPANT	\N	PRESENT	0
446861	445753	95030B	PARTICIPANT	\N	PRESENT	0
446862	445753	04034C	PARTICIPANT	\N	PRESENT	0
446863	445753	14079W	PARTICIPANT	\N	PRESENT	0
446864	445753	01058X	PARTICIPANT	\N	PRESENT	0
446865	445753	04040A	PARTICIPANT	\N	PRESENT	0
446866	445753	11027H	PARTICIPANT	\N	PRESENT	0
446867	445753	16685X	PARTICIPANT	\N	PRESENT	0
446868	445753	11054L	PARTICIPANT	\N	PRESENT	0
446869	445753	19669L	PARTICIPANT	\N	PRESENT	0
446870	445753	11066Q	PARTICIPANT	\N	PRESENT	0
446871	445753	08056B	PARTICIPANT	\N	PRESENT	0
446286	439813	14107H	PARTICIPANT	\N	PRESENT	0
446287	439813	19735D	PARTICIPANT	\N	PRESENT	0
446872	445753	11115U	PARTICIPANT	\N	PRESENT	0
446873	445753	95037J	PARTICIPANT	\N	PRESENT	0
446874	445753	14055N	PARTICIPANT	\N	PRESENT	0
446875	445753	19421M	PARTICIPANT	\N	PRESENT	0
446876	445753	19709B	PARTICIPANT	\N	PRESENT	0
446877	445753	08049C	PARTICIPANT	\N	PRESENT	0
446878	445753	08053X	PARTICIPANT	\N	PRESENT	0
446879	445753	97011G	PARTICIPANT	\N	PRESENT	0
446880	445753	08061X	PARTICIPANT	\N	PRESENT	0
446881	445753	08047A	PARTICIPANT	\N	PRESENT	0
446882	445753	98029W	PARTICIPANT	\N	PRESENT	0
446883	445753	14097Y	PARTICIPANT	\N	PRESENT	0
446884	445753	04035D	PARTICIPANT	\N	PRESENT	0
446885	445753	95067Q	PARTICIPANT	\N	PRESENT	0
446886	445753	11041F	PARTICIPANT	\N	PRESENT	0
446887	445753	14235Q	PARTICIPANT	\N	PRESENT	0
446888	445753	19251M	PARTICIPANT	\N	PRESENT	0
446889	445753	19721W	PARTICIPANT	\N	PRESENT	0
446890	445753	19319Q	PARTICIPANT	\N	PRESENT	0
446891	445753	14105F	PARTICIPANT	\N	PRESENT	0
446892	445753	98018T	PARTICIPANT	\N	PRESENT	0
446893	445753	98022P	PARTICIPANT	\N	PRESENT	0
446894	445753	14267Y	PARTICIPANT	\N	PRESENT	0
446895	445753	11064N	PARTICIPANT	\N	PRESENT	0
446896	445753	14211G	PARTICIPANT	\N	PRESENT	0
446897	445753	14255U	PARTICIPANT	\N	PRESENT	0
446898	445754	98005N	PARTICIPANT	\N	PRESENT	0
446899	445754	19443T	PARTICIPANT	\N	PRESENT	0
446900	445754	11080N	PARTICIPANT	\N	PRESENT	0
446901	445754	95030B	PARTICIPANT	\N	PRESENT	0
446902	445754	04034C	PARTICIPANT	\N	PRESENT	0
446903	445754	14079W	PARTICIPANT	\N	PRESENT	0
446904	445754	01058X	PARTICIPANT	\N	PRESENT	0
446905	445754	04040A	PARTICIPANT	\N	PRESENT	0
446906	445754	11027H	PARTICIPANT	\N	PRESENT	0
446907	445754	16685X	PARTICIPANT	\N	PRESENT	0
446908	445754	04042C	PRESIDENT	0	PRESENT	0
446909	445754	11054L	PARTICIPANT	\N	PRESENT	0
446910	445754	19669L	PARTICIPANT	\N	PRESENT	0
446911	445754	11066Q	PARTICIPANT	\N	PRESENT	0
446912	445754	08056B	PARTICIPANT	\N	PRESENT	0
446913	445754	11115U	PARTICIPANT	\N	PRESENT	0
446914	445754	95037J	PARTICIPANT	\N	PRESENT	0
446915	445754	14055N	PARTICIPANT	\N	PRESENT	0
425055	423101	14021P	PARTICIPANT	\N	PRESENT	0
430316	430232	04040A	PARTICIPANT	0	EXCUSE	0
431972	431971	19447X	PARTICIPANT	\N	PRESENT	0
431973	431971	19575F	PARTICIPANT	\N	PRESENT	0
438695	436978	08034U	PARTICIPANT	\N	PRESENT	0
438696	436978	19569H	PARTICIPANT	\N	PRESENT	0
438697	436978	14042U	PRESIDENT	1	PRESENT	0
438698	436978	08052W	PARTICIPANT	\N	PRESENT	0
438699	436978	19575F	PARTICIPANT	\N	PRESENT	0
438700	436978	14213J	PARTICIPANT	\N	PRESENT	0
438701	436978	19415P	PARTICIPANT	\N	PRESENT	0
438702	436978	11066Q	PARTICIPANT	\N	PRESENT	0
438703	436978	10006L	PRESIDENT	0	PRESENT	0
438704	436978	19683J	PARTICIPANT	\N	PRESENT	0
438705	436978	19447X	PARTICIPANT	\N	PRESENT	0
438706	436978	04045F	PARTICIPANT	\N	PRESENT	0
438707	436978	18083K	PARTICIPANT	\N	PRESENT	0
438708	436978	14215L	PARTICIPANT	\N	PRESENT	0
438709	436978	11067R	PARTICIPANT	\N	EXCUSE	0
438710	436978	14195A	PARTICIPANT	\N	EXCUSE	0
438712	436978	19553Y	PARTICIPANT	\N	PRESENT	0
438713	436978	14147R	PARTICIPANT	\N	PRESENT	0
438714	426316	19511N	PARTICIPANT	\N	PRESENT	0
438715	426316	19507S	PARTICIPANT	\N	PRESENT	0
438716	426316	86034E	PARTICIPANT	\N	PRESENT	0
438717	426316	19383Y	PARTICIPANT	\N	PRESENT	0
438718	426316	15447F	PARTICIPANT	\N	PRESENT	0
438719	426316	11101A	PARTICIPANT	\N	PRESENT	0
439378	426317	19619A	PARTICIPANT	\N	PRESENT	0
439381	426317	14205J	PARTICIPANT	\N	PRESENT	0
439382	426317	14030Q	PARTICIPANT	\N	PRESENT	0
439383	426317	14261S	PARTICIPANT	\N	PRESENT	0
439384	426317	19289C	PARTICIPANT	\N	PRESENT	0
439385	426317	11012A	PARTICIPANT	\N	PRESENT	0
439386	426317	11056N	PARTICIPANT	\N	PRESENT	0
439387	426317	19415P	PARTICIPANT	\N	PRESENT	0
439388	426317	08056B	PARTICIPANT	\N	PRESENT	0
439389	426317	11090Q	PARTICIPANT	\N	PRESENT	0
439390	426317	98050T	PARTICIPANT	\N	PRESENT	0
439391	426317	14093U	PARTICIPANT	\N	PRESENT	0
439392	426317	80013X	PARTICIPANT	\N	PRESENT	0
439393	426317	95030B	PARTICIPANT	\N	PRESENT	0
439394	439298	04070G	PARTICIPANT	\N	PRESENT	0
439399	426317	19575F	PARTICIPANT	\N	PRESENT	0
439400	426317	01048V	PARTICIPANT	\N	PRESENT	0
439401	426317	19333N	PARTICIPANT	\N	PRESENT	0
439449	431205	19619A	PARTICIPANT	\N	PRESENT	0
439450	431205	01048V	PARTICIPANT	\N	PRESENT	0
439451	431205	80013X	PARTICIPANT	\N	PRESENT	0
439452	431205	19629C	PARTICIPANT	\N	PRESENT	0
439453	431205	08024S	PARTICIPANT	\N	PRESENT	0
439454	431205	19695N	PARTICIPANT	\N	PRESENT	0
439455	431205	14093U	PARTICIPANT	\N	PRESENT	0
439456	431205	14103D	PARTICIPANT	\N	PRESENT	0
439457	431205	11048N	PARTICIPANT	\N	PRESENT	0
439458	431205	19333N	PARTICIPANT	\N	PRESENT	0
439459	431205	19713W	PARTICIPANT	\N	PRESENT	0
439460	431205	14030Q	PARTICIPANT	\N	PRESENT	0
439461	431205	19479G	PARTICIPANT	\N	PRESENT	0
439462	431205	14205J	PARTICIPANT	\N	PRESENT	0
439463	431205	19521Q	PARTICIPANT	\N	PRESENT	0
439464	431205	14261S	PARTICIPANT	\N	PRESENT	0
439465	431205	11012A	PARTICIPANT	\N	PRESENT	0
439466	431205	95030B	PARTICIPANT	\N	PRESENT	0
439467	431205	19399H	PARTICIPANT	\N	PRESENT	0
439468	431205	19691J	PARTICIPANT	\N	PRESENT	0
439469	431205	01025N	PARTICIPANT	\N	PRESENT	0
439470	431205	11056N	PARTICIPANT	\N	PRESENT	0
439471	431205	19575F	PARTICIPANT	\N	PRESENT	0
439472	431205	08056B	PARTICIPANT	\N	PRESENT	0
439473	431205	14038Y	PARTICIPANT	\N	PRESENT	0
441625	441624	14089Y	PARTICIPANT	\N	PRESENT	0
441626	438470	08038Y	PARTICIPANT	\N	PRESENT	0
441627	438470	08010L	PARTICIPANT	\N	PRESENT	0
441628	438470	11099A	PARTICIPANT	\N	PRESENT	0
448061	445988	01048V	PRESIDENT	0	PRESENT	0
448062	445988	01058X	PARTICIPANT	\N	EXCUSE	0
448279	448270	19367Y	PARTICIPANT	\N	PRESENT	0
448280	448270	04070G	PARTICIPANT	\N	EXCUSE	0
448281	448270	14026U	PARTICIPANT	\N	EXCUSE	0
448282	439818	01043Q	PARTICIPANT	\N	PRESENT	0
448299	439818	04092N	PARTICIPANT	\N	PRESENT	0
448300	439818	19447X	PARTICIPANT	\N	PRESENT	0
448301	439818	19649G	PARTICIPANT	\N	PRESENT	0
448302	439818	11045K	PARTICIPANT	\N	PRESENT	0
448303	439818	19671E	PARTICIPANT	\N	PRESENT	0
448304	439818	19683J	PARTICIPANT	\N	PRESENT	0
448305	439818	19333N	PARTICIPANT	\N	PRESENT	0
448306	439818	19335Q	PARTICIPANT	\N	PRESENT	0
448307	439818	11067R	PARTICIPANT	\N	PRESENT	0
439447	431205	04044E	PARTICIPANT	\N	PRESENT	0
439448	431205	11085T	PARTICIPANT	\N	PRESENT	0
448308	439818	19503N	PARTICIPANT	\N	PRESENT	0
448309	439818	04085P	PARTICIPANT	\N	PRESENT	0
448310	439818	19581D	PARTICIPANT	\N	PRESENT	0
448311	439818	19565D	PARTICIPANT	\N	PRESENT	0
448312	439818	10015M	PARTICIPANT	\N	PRESENT	0
448313	439818	04045F	PARTICIPANT	\N	PRESENT	0
448314	439818	08069G	PARTICIPANT	\N	PRESENT	0
448315	439818	19681G	PARTICIPANT	\N	PRESENT	0
448316	439818	99004R	PARTICIPANT	\N	PRESENT	0
448317	439818	14195A	PARTICIPANT	\N	PRESENT	0
448318	439818	19479G	PARTICIPANT	\N	PRESENT	0
448319	439818	14031R	PARTICIPANT	\N	PRESENT	0
448320	439818	14042U	PARTICIPANT	\N	PRESENT	0
448321	439818	19569H	PARTICIPANT	\N	PRESENT	0
448322	439818	19737F	PARTICIPANT	\N	PRESENT	0
448323	439818	19667J	PARTICIPANT	\N	PRESENT	0
448324	439818	08052W	PARTICIPANT	\N	PRESENT	0
448325	439818	19794Q	PARTICIPANT	\N	PRESENT	0
448326	439818	19415P	PARTICIPANT	\N	PRESENT	0
448327	439818	14065Q	PARTICIPANT	\N	PRESENT	0
448328	439818	18083K	PARTICIPANT	\N	PRESENT	0
448329	439818	07004J	PARTICIPANT	\N	PRESENT	0
448330	439818	19533U	PARTICIPANT	\N	PRESENT	0
448331	439818	19711U	PARTICIPANT	\N	PRESENT	0
448332	439818	14215L	PARTICIPANT	\N	PRESENT	0
448333	439818	14105F	PARTICIPANT	\N	PRESENT	0
448334	439818	14079W	PARTICIPANT	\N	PRESENT	0
448335	439818	08034U	PARTICIPANT	\N	PRESENT	0
448336	439818	98024R	PARTICIPANT	\N	PRESENT	0
448337	439818	19798U	PARTICIPANT	\N	PRESENT	0
448338	439818	04033B	PARTICIPANT	\N	PRESENT	0
448339	439818	14179A	PARTICIPANT	\N	PRESENT	0
448340	439818	08015R	PARTICIPANT	\N	PRESENT	0
448341	439818	19731Y	PARTICIPANT	\N	PRESENT	0
448342	439818	19749K	PARTICIPANT	\N	PRESENT	0
448343	439818	04088S	PARTICIPANT	\N	PRESENT	0
448344	439818	19515S	PARTICIPANT	\N	PRESENT	0
448345	439818	08043V	PARTICIPANT	\N	PRESENT	0
448346	439818	14217N	PARTICIPANT	\N	PRESENT	0
448347	439818	14213J	PARTICIPANT	\N	PRESENT	0
448348	439818	19553Y	PARTICIPANT	\N	PRESENT	0
448349	439818	11031D	PARTICIPANT	\N	PRESENT	0
448350	439818	04034C	PARTICIPANT	\N	PRESENT	0
448351	439818	19543W	PARTICIPANT	\N	PRESENT	0
448352	439818	14239U	PARTICIPANT	\N	PRESENT	0
448353	439818	19651A	PARTICIPANT	\N	PRESENT	0
448354	439818	19573D	PARTICIPANT	\N	PRESENT	0
448355	439818	05008E	PARTICIPANT	\N	PRESENT	0
448356	439818	19693L	PARTICIPANT	\N	PRESENT	0
448357	439818	19575F	PARTICIPANT	\N	PRESENT	0
448358	439818	14069U	PARTICIPANT	\N	PRESENT	0
448359	439818	19747H	PARTICIPANT	\N	PRESENT	0
448360	439818	19689Q	PARTICIPANT	\N	PRESENT	0
448361	439818	19441R	PARTICIPANT	\N	PRESENT	0
448362	439818	19713W	PARTICIPANT	\N	PRESENT	0
448363	439818	14231L	PARTICIPANT	\N	PRESENT	0
448364	439818	19762G	PARTICIPANT	\N	PRESENT	0
448365	439818	97011G	PARTICIPANT	\N	PRESENT	0
448366	439818	14061L	PARTICIPANT	\N	PRESENT	0
448367	439818	14073Q	PARTICIPANT	\N	PRESENT	0
448368	439818	04069P	PARTICIPANT	\N	PRESENT	0
448369	439818	01028R	PARTICIPANT	\N	PRESENT	0
448372	439818	19701S	PARTICIPANT	\N	PRESENT	0
448376	439818	19637C	PARTICIPANT	\N	PRESENT	0
448377	439818	89017R	PARTICIPANT	\N	PRESENT	0
448385	439818	19735D	PARTICIPANT	\N	PRESENT	0
436807	425636	01034P	PARTICIPANT	\N	PRESENT	0
436809	425636	14213J	PARTICIPANT	\N	PRESENT	0
436810	425636	19713W	PARTICIPANT	\N	PRESENT	0
436812	425636	14219Q	PARTICIPANT	\N	PRESENT	0
436813	425636	19689Q	PARTICIPANT	\N	PRESENT	0
436814	425636	11085T	PARTICIPANT	\N	PRESENT	0
436834	425636	04070G	PARTICIPANT	\N	PRESENT	0
436835	425636	14069U	PARTICIPANT	\N	PRESENT	0
436836	425636	19563B	PARTICIPANT	\N	PRESENT	0
436837	425636	19673G	PARTICIPANT	\N	PRESENT	0
436838	425636	14121F	PARTICIPANT	\N	PRESENT	0
436839	425636	11074Q	PARTICIPANT	\N	PRESENT	0
436840	425636	14257W	PARTICIPANT	\N	PRESENT	0
436841	425636	19593H	PARTICIPANT	\N	PRESENT	0
436842	425636	11064N	PARTICIPANT	\N	PRESENT	0
436843	425636	01048V	PARTICIPANT	\N	PRESENT	0
436844	425636	14249W	PARTICIPANT	\N	PRESENT	0
436845	425636	14331P	PARTICIPANT	\N	PRESENT	0
436846	425636	11012A	PARTICIPANT	\N	PRESENT	0
436847	432678	11097X	PARTICIPANT	\N	PRESENT	0
436848	432678	19479G	PARTICIPANT	\N	PRESENT	0
436849	432678	08062Y	PARTICIPANT	\N	EXCUSE	0
436850	425636	08019V	PARTICIPANT	\N	PRESENT	0
436851	425636	19531S	PARTICIPANT	\N	PRESENT	0
436852	425636	14135M	PARTICIPANT	\N	PRESENT	0
436853	425636	14357A	PARTICIPANT	\N	PRESENT	0
436854	425636	11110B	PARTICIPANT	\N	PRESENT	0
436855	425636	19631V	PARTICIPANT	\N	PRESENT	0
436856	425636	19545Y	PARTICIPANT	\N	PRESENT	0
436857	425636	05012A	PARTICIPANT	\N	PRESENT	0
436858	425636	11072N	PARTICIPANT	\N	PRESENT	0
436969	431727	19583F	PARTICIPANT	\N	EXCUSE	0
437463	437462	14133K	PARTICIPANT	\N	PRESENT	0
437465	437464	14133K	PARTICIPANT	\N	PRESENT	0
437470	437469	14041T	PARTICIPANT	\N	PRESENT	0
437471	437469	14071N	PARTICIPANT	\N	PRESENT	0
437707	425782	11027H	PARTICIPANT	\N	PRESENT	0
437709	425782	19711U	PARTICIPANT	\N	PRESENT	0
437710	425782	14085U	PARTICIPANT	\N	PRESENT	0
437718	425782	19741B	PARTICIPANT	\N	PRESENT	0
437712	425782	19669L	PARTICIPANT	\N	PRESENT	0
437713	425782	14179A	PARTICIPANT	\N	PRESENT	0
437714	425782	07004J	PARTICIPANT	\N	PRESENT	0
437715	425782	04018C	PARTICIPANT	\N	PRESENT	0
437716	425782	88008L	PARTICIPANT	\N	PRESENT	0
437717	425782	19713W	PARTICIPANT	\N	PRESENT	0
437719	425782	19693L	PARTICIPANT	\N	PRESENT	0
437720	425782	04086Q	PARTICIPANT	\N	PRESENT	0
437721	425782	99004R	PARTICIPANT	\N	PRESENT	0
437722	425782	11074Q	PARTICIPANT	\N	PRESENT	0
437723	425782	08019V	PARTICIPANT	\N	PRESENT	0
437724	425782	01058X	PARTICIPANT	\N	PRESENT	0
437725	425782	08011M	PARTICIPANT	\N	PRESENT	0
437726	425782	19479G	PARTICIPANT	\N	PRESENT	0
437727	425782	19649G	PARTICIPANT	\N	PRESENT	0
437728	425782	19583F	PARTICIPANT	\N	PRESENT	0
437729	425782	14121F	PARTICIPANT	\N	PRESENT	0
437730	425782	04034C	PARTICIPANT	\N	PRESENT	0
437731	425782	19689Q	PARTICIPANT	\N	PRESENT	0
437732	425782	08061X	PARTICIPANT	\N	PRESENT	0
437736	425782	11109J	PARTICIPANT	\N	PRESENT	0
437734	425782	98050T	PARTICIPANT	\N	PRESENT	0
437735	425782	14039A	PARTICIPANT	\N	PRESENT	0
437737	425782	08010L	PARTICIPANT	\N	PRESENT	0
437738	425782	19651A	PARTICIPANT	\N	PRESENT	0
437739	425782	19295A	PARTICIPANT	\N	PRESENT	0
437741	425782	02002K	PARTICIPANT	\N	PRESENT	0
437742	425782	19667J	PARTICIPANT	\N	PRESENT	0
437743	425782	04085P	PARTICIPANT	\N	PRESENT	0
437744	425782	11083R	PARTICIPANT	\N	PRESENT	0
437785	425783	11074Q	PARTICIPANT	\N	PRESENT	0
437786	425783	19295A	PARTICIPANT	\N	PRESENT	0
437787	425783	19583F	PARTICIPANT	\N	PRESENT	0
437788	425783	19651A	PARTICIPANT	\N	PRESENT	0
437789	425783	07004J	PARTICIPANT	\N	PRESENT	0
437790	425783	19741B	PARTICIPANT	\N	PRESENT	0
437791	425783	04018C	PARTICIPANT	\N	PRESENT	0
437792	425783	19667J	PARTICIPANT	\N	PRESENT	0
437793	425783	19711U	PARTICIPANT	\N	PRESENT	0
437794	425783	19693L	PARTICIPANT	\N	PRESENT	0
437795	425783	14093U	PARTICIPANT	\N	PRESENT	0
437796	425783	11109J	PARTICIPANT	\N	PRESENT	0
437797	425783	19647E	PARTICIPANT	\N	PRESENT	0
437798	425783	14121F	PARTICIPANT	\N	PRESENT	0
437799	425783	14085U	PARTICIPANT	\N	PRESENT	0
437800	425783	04086Q	PARTICIPANT	\N	PRESENT	0
437801	425783	19479G	PARTICIPANT	\N	PRESENT	0
437802	425783	19657G	PARTICIPANT	\N	PRESENT	0
437803	425783	11103C	PARTICIPANT	\N	PRESENT	0
437804	425783	02002K	PARTICIPANT	\N	PRESENT	0
437805	425783	14179A	PARTICIPANT	\N	PRESENT	0
437806	425783	04085P	PARTICIPANT	\N	PRESENT	0
437807	425783	11083R	PARTICIPANT	\N	PRESENT	0
437808	425783	14253S	PARTICIPANT	\N	PRESENT	0
437809	425783	11043H	PARTICIPANT	\N	PRESENT	0
437810	425783	14039A	PARTICIPANT	\N	PRESENT	0
437811	425783	88008L	PARTICIPANT	\N	PRESENT	0
437812	425783	11085T	PARTICIPANT	\N	PRESENT	0
437813	425783	14211G	PARTICIPANT	\N	PRESENT	0
437783	425783	11072N	PARTICIPANT	\N	PRESENT	0
437784	425783	08011M	PARTICIPANT	\N	PRESENT	0
437814	425783	19301E	PARTICIPANT	\N	PRESENT	0
437815	425783	98050T	PARTICIPANT	\N	PRESENT	0
437816	425783	11097X	PARTICIPANT	\N	PRESENT	0
437817	425783	19689Q	PARTICIPANT	\N	PRESENT	0
437818	425783	19713W	PARTICIPANT	\N	PRESENT	0
437819	425783	07033P	PARTICIPANT	\N	PRESENT	0
437820	425783	19593H	PARTICIPANT	\N	PRESENT	0
437821	425783	08031R	PARTICIPANT	\N	PRESENT	0
437822	425783	08061X	PARTICIPANT	\N	PRESENT	0
437823	425783	19669L	PARTICIPANT	\N	PRESENT	0
437824	425783	01058X	PARTICIPANT	\N	PRESENT	0
437825	425783	14111D	PARTICIPANT	\N	PRESENT	0
437826	425783	14357A	PARTICIPANT	\N	PRESENT	0
437827	425783	17637T	PARTICIPANT	\N	PRESENT	0
437828	425783	01048V	PARTICIPANT	\N	PRESENT	0
437829	425783	08010L	PARTICIPANT	\N	PRESENT	0
437830	425783	11077T	PARTICIPANT	\N	PRESENT	0
437831	425783	11033F	PARTICIPANT	\N	PRESENT	0
437832	425783	14059S	PARTICIPANT	\N	PRESENT	0
437833	425783	19521Q	PARTICIPANT	\N	PRESENT	0
437834	425783	19683J	PARTICIPANT	\N	PRESENT	0
437835	425783	08019V	PARTICIPANT	\N	PRESENT	0
437836	425783	08055A	PARTICIPANT	\N	PRESENT	0
437837	425783	19543W	PARTICIPANT	\N	PRESENT	0
437838	425783	11099A	PARTICIPANT	\N	PRESENT	0
437839	425783	08052W	PARTICIPANT	\N	PRESENT	0
437840	425783	15447F	PARTICIPANT	\N	PRESENT	0
437841	425783	14042U	PARTICIPANT	\N	PRESENT	0
437842	425783	11012A	PARTICIPANT	\N	PRESENT	0
437843	425783	14089Y	PARTICIPANT	\N	PRESENT	0
437844	425783	04088S	PARTICIPANT	\N	PRESENT	0
437845	425783	14073Q	PARTICIPANT	\N	PRESENT	0
437901	437900	19447X	PARTICIPANT	\N	PRESENT	0
437902	437900	14147R	PARTICIPANT	\N	PRESENT	0
437904	437900	08043V	PARTICIPANT	\N	PRESENT	0
438243	438242	19569H	PARTICIPANT	\N	PRESENT	0
438245	438244	19569H	PARTICIPANT	\N	PRESENT	0
438247	438246	19569H	PARTICIPANT	\N	PRESENT	0
438248	438246	19447X	PARTICIPANT	\N	PRESENT	0
438249	438246	08043V	PARTICIPANT	\N	PRESENT	0
438250	438246	14147R	PARTICIPANT	\N	PRESENT	0
438251	438246	08052W	PARTICIPANT	\N	PRESENT	0
438300	438299	89017R	PARTICIPANT	\N	PRESENT	0
438301	438299	08055A	PARTICIPANT	\N	PRESENT	0
438302	438299	14255U	PARTICIPANT	\N	PRESENT	0
438303	438299	14083S	PARTICIPANT	\N	PRESENT	0
438304	438299	08012N	PARTICIPANT	\N	PRESENT	0
438305	438299	05012A	PARTICIPANT	\N	PRESENT	0
438306	438299	98035U	PARTICIPANT	\N	PRESENT	0
438334	438299	95037J	PARTICIPANT	\N	PRESENT	0
438984	438983	04070G	PARTICIPANT	\N	PRESENT	0
438985	438983	19621T	PARTICIPANT	\N	PRESENT	0
438986	438983	08031R	PARTICIPANT	\N	PRESENT	0
438987	438983	19593H	PARTICIPANT	\N	PRESENT	0
438988	438983	14229S	PARTICIPANT	\N	PRESENT	0
438989	438983	19693L	PARTICIPANT	\N	PRESENT	0
438990	438983	19329S	PARTICIPANT	\N	PRESENT	0
438991	438983	14061L	PARTICIPANT	\N	PRESENT	0
438992	438983	19611R	PARTICIPANT	\N	PRESENT	0
438993	438983	08012N	PARTICIPANT	\N	PRESENT	0
438994	438983	19735D	PARTICIPANT	\N	PRESENT	0
438995	438983	04018C	PARTICIPANT	\N	PRESENT	0
438996	438983	14059S	PARTICIPANT	\N	PRESENT	0
438998	438997	14257W	PARTICIPANT	\N	PRESENT	0
438999	438997	19768N	PARTICIPANT	\N	PRESENT	0
439005	432678	17637T	PARTICIPANT	\N	EXCUSE	0
439326	439275	14033T	PARTICIPANT	\N	PRESENT	0
439327	439275	80013X	PARTICIPANT	\N	PRESENT	0
425058	425057	89017R	PARTICIPANT	\N	PRESENT	0
425059	425057	04085P	PARTICIPANT	\N	PRESENT	0
425060	425057	04059M	PARTICIPANT	\N	PRESENT	0
425061	425057	04047H	PARTICIPANT	\N	PRESENT	0
425062	425057	04042C	PARTICIPANT	\N	PRESENT	0
425063	425057	11053K	PARTICIPANT	\N	PRESENT	0
425064	425057	14038Y	PARTICIPANT	\N	PRESENT	0
425065	425057	11027H	PARTICIPANT	\N	PRESENT	0
425066	425057	14079W	PARTICIPANT	\N	PRESENT	0
425067	425057	11070L	PARTICIPANT	\N	PRESENT	0
425071	425057	14251Q	PARTICIPANT	\N	PRESENT	0
425069	425057	11074Q	PARTICIPANT	\N	PRESENT	0
425070	425057	14034U	PARTICIPANT	\N	PRESENT	0
425072	425057	11085T	PARTICIPANT	\N	PRESENT	0
425073	425057	04092N	PARTICIPANT	\N	PRESENT	0
425074	425057	08011M	PARTICIPANT	\N	PRESENT	0
425075	425057	04070G	PARTICIPANT	\N	PRESENT	0
425076	425057	08061X	PARTICIPANT	\N	PRESENT	0
425077	425057	11090Q	PARTICIPANT	\N	PRESENT	0
425078	425057	10015M	PARTICIPANT	\N	PRESENT	0
425079	425057	11012A	PARTICIPANT	\N	PRESENT	0
425080	425057	04033B	PARTICIPANT	\N	PRESENT	0
425081	425057	01028R	PARTICIPANT	\N	PRESENT	0
425082	425057	04044E	PARTICIPANT	\N	PRESENT	0
425083	425057	01034P	PARTICIPANT	\N	PRESENT	0
428186	428185	14229S	PARTICIPANT	\N	PRESENT	0
428187	428185	08043V	PARTICIPANT	\N	PRESENT	0
428191	428188	08039A	PARTICIPANT	\N	PRESENT	0
428192	428188	19749K	PARTICIPANT	\N	PRESENT	0
428193	428189	08039A	PARTICIPANT	\N	PRESENT	0
428194	428190	08039A	PARTICIPANT	\N	PRESENT	0
428196	428195	08039A	PARTICIPANT	\N	PRESENT	0
428197	428195	08017T	PARTICIPANT	\N	PRESENT	0
431921	431920	10006L	PARTICIPANT	\N	PRESENT	0
431922	431920	11010L	PARTICIPANT	\N	PRESENT	0
431923	431920	04043D	PARTICIPANT	\N	PRESENT	0
431924	431920	14001X	PARTICIPANT	\N	PRESENT	0
431925	431920	14059S	PARTICIPANT	\N	PRESENT	0
434349	434347	19691J	PARTICIPANT	\N	PRESENT	0
434350	434347	01043Q	PARTICIPANT	\N	PRESENT	0
434351	434347	19637C	PARTICIPANT	\N	PRESENT	0
435187	434580	19711U	PRESIDENT	0	PRESENT	0
435188	434580	19479G	PARTICIPANT	\N	PRESENT	0
435189	434580	08034U	PARTICIPANT	\N	PRESENT	0
435190	434580	19687N	PARTICIPANT	\N	PRESENT	0
435191	434580	12016W	PARTICIPANT	\N	PRESENT	0
435192	434580	08011M	PARTICIPANT	\N	PRESENT	0
435193	434580	08014Q	PARTICIPANT	\N	PRESENT	0
435194	434580	14159V	PARTICIPANT	\N	PRESENT	0
435195	434580	14225N	PARTICIPANT	\N	PRESENT	0
435196	434580	11110B	PARTICIPANT	\N	PRESENT	0
435197	434580	11040E	PARTICIPANT	\N	PRESENT	0
435198	434580	04086Q	PARTICIPANT	\N	PRESENT	0
435199	434580	14085U	PARTICIPANT	\N	PRESENT	0
435200	434580	07004J	PARTICIPANT	\N	PRESENT	0
435201	434580	19741B	PARTICIPANT	\N	PRESENT	0
435202	434580	14253S	PARTICIPANT	\N	PRESENT	0
435203	434580	11074Q	PRESIDENT	1	PRESENT	0
435204	434580	99004R	PARTICIPANT	\N	PRESENT	0
435205	425522	11072N	PARTICIPANT	\N	PRESENT	0
435206	425522	11110B	PARTICIPANT	\N	PRESENT	0
435207	425522	14159V	PARTICIPANT	\N	PRESENT	0
435208	425522	12016W	PARTICIPANT	\N	PRESENT	0
435209	425522	14085U	PARTICIPANT	\N	PRESENT	0
435210	425522	19631V	PARTICIPANT	\N	PRESENT	0
435211	425522	08068F	PARTICIPANT	\N	PRESENT	0
435212	425522	19515S	PARTICIPANT	\N	PRESENT	0
435213	425522	14225N	PARTICIPANT	\N	PRESENT	0
435214	425522	10015M	PARTICIPANT	\N	PRESENT	0
435215	425522	14205J	PARTICIPANT	\N	PRESENT	0
435216	425522	19369B	PARTICIPANT	\N	PRESENT	0
435217	425522	07004J	PARTICIPANT	\N	PRESENT	0
435218	425522	19711U	PARTICIPANT	\N	PRESENT	0
435219	425522	11040E	PARTICIPANT	\N	PRESENT	0
435220	425522	19695N	PARTICIPANT	\N	PRESENT	0
435221	425522	11074Q	PARTICIPANT	\N	PRESENT	0
435222	425522	14038Y	PARTICIPANT	\N	PRESENT	0
435223	425522	19687N	PARTICIPANT	\N	PRESENT	0
435224	425522	14265W	PARTICIPANT	\N	PRESENT	0
435225	425522	08014Q	PARTICIPANT	\N	PRESENT	0
435226	425522	14261S	PARTICIPANT	\N	PRESENT	0
435232	425522	19479G	PARTICIPANT	\N	PRESENT	0
435228	425522	19563B	PARTICIPANT	\N	PRESENT	0
435229	425522	19651A	PARTICIPANT	\N	PRESENT	0
435230	425522	14253S	PARTICIPANT	\N	PRESENT	0
435231	425522	19591F	PARTICIPANT	\N	PRESENT	0
435233	425522	19693L	PARTICIPANT	\N	PRESENT	0
435234	425522	08019V	PARTICIPANT	\N	PRESENT	0
435235	425522	11099A	PARTICIPANT	\N	PRESENT	0
435236	425522	14267Y	PARTICIPANT	\N	PRESENT	0
435237	425522	19741B	PARTICIPANT	\N	PRESENT	0
435238	425522	14211G	PARTICIPANT	\N	PRESENT	0
435239	425522	11090Q	PARTICIPANT	\N	PRESENT	0
435240	425522	08034U	PARTICIPANT	\N	PRESENT	0
435241	425522	19333N	PARTICIPANT	\N	PRESENT	0
435242	425522	19657G	PARTICIPANT	\N	PRESENT	0
435243	425522	04086Q	PARTICIPANT	\N	PRESENT	0
435248	425522	14030Q	PARTICIPANT	\N	PRESENT	0
435286	425592	19591F	PARTICIPANT	\N	PRESENT	0
435287	425592	08068F	PARTICIPANT	\N	PRESENT	0
435288	425592	19631V	PARTICIPANT	\N	PRESENT	0
435289	425592	11110B	PARTICIPANT	\N	PRESENT	0
435290	425592	07004J	PARTICIPANT	\N	PRESENT	0
435291	425592	12016W	PARTICIPANT	\N	PRESENT	0
435292	425592	14085U	PARTICIPANT	\N	PRESENT	0
435293	425592	11099A	PARTICIPANT	\N	PRESENT	0
435294	425592	19651A	PARTICIPANT	\N	PRESENT	0
435295	425592	19479G	PARTICIPANT	\N	PRESENT	0
435296	425592	19333N	PARTICIPANT	\N	PRESENT	0
435297	425592	08014Q	PARTICIPANT	\N	PRESENT	0
435298	425592	19687N	PARTICIPANT	\N	PRESENT	0
435299	425592	08034U	PARTICIPANT	\N	PRESENT	0
435300	425592	19711U	PARTICIPANT	\N	PRESENT	0
435301	425592	14253S	PARTICIPANT	\N	PRESENT	0
435302	425592	19741B	PARTICIPANT	\N	PRESENT	0
435303	425592	11090Q	PARTICIPANT	\N	PRESENT	0
435304	425592	19563B	PARTICIPANT	\N	PRESENT	0
435305	425592	04086Q	PARTICIPANT	\N	PRESENT	0
435306	425592	19515S	PARTICIPANT	\N	PRESENT	0
435307	425592	11040E	PARTICIPANT	\N	PRESENT	0
435308	425592	19695N	PARTICIPANT	\N	PRESENT	0
435309	425592	11048N	PARTICIPANT	\N	PRESENT	0
435310	425592	11026G	PARTICIPANT	\N	PRESENT	0
435311	425592	19585H	PARTICIPANT	\N	PRESENT	0
435312	425592	19693L	PARTICIPANT	\N	PRESENT	0
435313	425592	14261S	PARTICIPANT	\N	PRESENT	0
435347	425603	19631V	PARTICIPANT	\N	PRESENT	0
435348	425603	12016W	PARTICIPANT	\N	PRESENT	0
435349	425603	07004J	PARTICIPANT	\N	PRESENT	0
435350	425603	19651A	PARTICIPANT	\N	PRESENT	0
435351	425603	19515S	PARTICIPANT	\N	PRESENT	0
435352	425603	14253S	PARTICIPANT	\N	PRESENT	0
435353	425603	19671E	PARTICIPANT	\N	PRESENT	0
435284	425592	11072N	PARTICIPANT	\N	PRESENT	0
435285	425592	11074Q	PARTICIPANT	\N	PRESENT	0
435354	425603	14257W	PARTICIPANT	\N	PRESENT	0
435355	425603	11074Q	PARTICIPANT	\N	PRESENT	0
435356	425603	11012A	PARTICIPANT	\N	PRESENT	0
435357	425603	14085U	PARTICIPANT	\N	PRESENT	0
435358	425603	08014Q	PARTICIPANT	\N	PRESENT	0
435359	425603	11048N	PARTICIPANT	\N	PRESENT	0
435360	425603	14261S	PARTICIPANT	\N	PRESENT	0
435361	425603	19737F	PARTICIPANT	\N	PRESENT	0
435329	425603	04044E	PARTICIPANT	\N	PRESENT	0
435346	425603	11026G	PARTICIPANT	\N	PRESENT	0
435362	425603	19713W	PARTICIPANT	\N	PRESENT	0
435363	425603	14135M	PARTICIPANT	\N	PRESENT	0
435364	425603	11097X	PARTICIPANT	\N	PRESENT	0
435365	425603	04085P	PARTICIPANT	\N	PRESENT	0
435366	425603	19563B	PARTICIPANT	\N	PRESENT	0
435367	425603	19479G	PARTICIPANT	\N	PRESENT	0
435368	425603	01048V	PARTICIPANT	\N	PRESENT	0
435369	425603	14081Q	PARTICIPANT	\N	PRESENT	0
435370	425603	14038Y	PARTICIPANT	\N	PRESENT	0
435371	425603	19679N	PARTICIPANT	\N	PRESENT	0
435372	425603	19687N	PARTICIPANT	\N	PRESENT	0
446916	445754	19421M	PARTICIPANT	\N	PRESENT	0
446917	445754	19709B	PARTICIPANT	\N	PRESENT	0
446918	445754	08049C	PARTICIPANT	\N	PRESENT	0
446919	445754	08053X	PARTICIPANT	\N	PRESENT	0
446920	445754	97011G	PARTICIPANT	\N	PRESENT	0
446921	445754	08061X	PARTICIPANT	\N	PRESENT	0
446922	445754	08047A	PARTICIPANT	\N	PRESENT	0
446923	445754	98029W	PARTICIPANT	\N	PRESENT	0
446924	445754	14097Y	PARTICIPANT	\N	PRESENT	0
446925	445754	04035D	PARTICIPANT	\N	PRESENT	0
446926	445754	95067Q	PARTICIPANT	\N	PRESENT	0
446927	445754	11041F	PARTICIPANT	\N	PRESENT	0
446928	445754	14235Q	PARTICIPANT	\N	PRESENT	0
446929	445754	19251M	PARTICIPANT	\N	PRESENT	0
446930	445754	19721W	PARTICIPANT	\N	PRESENT	0
446931	445754	19319Q	PARTICIPANT	\N	PRESENT	0
446932	445754	14105F	PARTICIPANT	\N	PRESENT	0
446933	445754	98018T	PARTICIPANT	\N	PRESENT	0
446934	445754	98022P	PARTICIPANT	\N	PRESENT	0
446935	445754	14267Y	PARTICIPANT	\N	PRESENT	0
446936	445754	11064N	PARTICIPANT	\N	PRESENT	0
446937	445754	14211G	PARTICIPANT	\N	PRESENT	0
446938	445754	14255U	PARTICIPANT	\N	PRESENT	0
446939	446794	19591F	PARTICIPANT	\N	PRESENT	0
446940	445707	04070G	PRESIDENT	0	PRESENT	0
446941	445707	19699S	PARTICIPANT	\N	PRESENT	0
446942	445707	19533U	PARTICIPANT	\N	PRESENT	0
446943	445707	14241N	PARTICIPANT	\N	PRESENT	0
446944	445707	19573D	PARTICIPANT	\N	PRESENT	0
446945	445707	14107H	PARTICIPANT	\N	PRESENT	0
446946	445707	08017T	PARTICIPANT	\N	PRESENT	0
446947	445707	92040Q	PARTICIPANT	\N	PRESENT	0
446948	445707	08039A	PARTICIPANT	\N	PRESENT	0
446949	445707	08031R	PARTICIPANT	\N	PRESENT	0
446950	445707	19593H	PARTICIPANT	\N	PRESENT	0
446951	445707	14059S	PARTICIPANT	\N	PRESENT	0
446952	445707	19643A	PARTICIPANT	\N	PRESENT	0
446953	445707	14061L	PARTICIPANT	\N	PRESENT	0
446954	445707	04057K	PARTICIPANT	\N	PRESENT	0
446955	445707	14073Q	PARTICIPANT	\N	PRESENT	0
446956	445707	19611R	PARTICIPANT	\N	PRESENT	0
446957	445707	14030Q	PARTICIPANT	\N	PRESENT	0
446958	445707	19731Y	PARTICIPANT	\N	PRESENT	0
446959	445707	14251Q	PARTICIPANT	\N	PRESENT	0
446960	445707	19735D	PARTICIPANT	\N	PRESENT	0
446961	445707	11083R	PARTICIPANT	\N	PRESENT	0
446962	445707	14063N	PARTICIPANT	\N	PRESENT	0
446963	445707	14109K	PARTICIPANT	\N	PRESENT	0
446964	445707	14123H	PARTICIPANT	\N	PRESENT	0
446965	445707	11104D	PARTICIPANT	\N	PRESENT	0
446966	445707	11043H	PARTICIPANT	\N	PRESENT	0
446967	445707	19749K	PARTICIPANT	\N	PRESENT	0
446968	445707	04018C	PARTICIPANT	\N	PRESENT	0
446969	445707	19758L	PARTICIPANT	\N	PRESENT	0
446970	445707	14039A	PARTICIPANT	\N	PRESENT	0
446971	445707	04059M	PARTICIPANT	\N	PRESENT	0
446972	445707	19621T	PARTICIPANT	\N	PRESENT	0
446973	446385	14219Q	PARTICIPANT	\N	PRESENT	0
446974	446385	14221J	PARTICIPANT	\N	PRESENT	0
446975	446385	19551W	PARTICIPANT	\N	PRESENT	0
446976	446385	18083K	PARTICIPANT	\N	PRESENT	0
446977	446385	14157T	PARTICIPANT	\N	PRESENT	0
446978	446385	08055A	PARTICIPANT	\N	PRESENT	0
446979	445710	14327T	PARTICIPANT	\N	PRESENT	0
446980	445710	14331P	PARTICIPANT	\N	PRESENT	0
446981	445710	19545Y	PARTICIPANT	\N	PRESENT	0
446982	445710	01057W	PARTICIPANT	\N	PRESENT	0
446983	445710	11074Q	PRESIDENT	0	PRESENT	0
446984	445710	89017R	PARTICIPANT	\N	PRESENT	0
446985	445710	19671E	PARTICIPANT	\N	PRESENT	0
446986	445710	11070L	PARTICIPANT	\N	PRESENT	0
446987	445710	88008L	PARTICIPANT	\N	PRESENT	0
446988	445710	11110B	PARTICIPANT	\N	PRESENT	0
446989	445710	07029T	PARTICIPANT	\N	PRESENT	0
446990	445710	14277B	PARTICIPANT	\N	PRESENT	0
446991	445710	14085U	PARTICIPANT	\N	PRESENT	0
446992	445710	07004J	PARTICIPANT	\N	PRESENT	0
446993	445710	19349W	PARTICIPANT	\N	PRESENT	0
446994	445710	08010L	PARTICIPANT	\N	PRESENT	0
446995	445710	14253S	PARTICIPANT	\N	PRESENT	0
446996	445710	19479G	PARTICIPANT	\N	PRESENT	0
446997	445710	11048N	PARTICIPANT	\N	PRESENT	0
446998	445710	19647E	PARTICIPANT	\N	PRESENT	0
446999	445710	19711U	PARTICIPANT	\N	PRESENT	0
447000	445710	08034U	PARTICIPANT	\N	PRESENT	0
447001	445710	19651A	PARTICIPANT	\N	PRESENT	0
447002	445710	19531S	PARTICIPANT	\N	PRESENT	0
447003	445710	08069G	PARTICIPANT	\N	PRESENT	0
447004	445710	19687N	PARTICIPANT	\N	PRESENT	0
447005	445710	19689Q	PARTICIPANT	\N	PRESENT	0
447006	445710	12016W	PARTICIPANT	\N	PRESENT	0
447007	445710	08014Q	PARTICIPANT	\N	PRESENT	0
447008	445710	14159V	PARTICIPANT	\N	PRESENT	0
447009	445710	11040E	PARTICIPANT	\N	PRESENT	0
447010	445710	14083S	PARTICIPANT	\N	PRESENT	0
447011	445710	14199E	PARTICIPANT	\N	PRESENT	0
447012	445710	11012A	PARTICIPANT	\N	PRESENT	0
447013	445710	08073C	PARTICIPANT	\N	PRESENT	0
447014	445710	14121F	PARTICIPANT	\N	PRESENT	0
447015	445710	19741B	PARTICIPANT	\N	PRESENT	0
447016	445710	99004R	PARTICIPANT	\N	PRESENT	0
447017	445710	14173T	PARTICIPANT	\N	PRESENT	0
447018	445710	04086Q	PARTICIPANT	\N	EXCUSE	0
447019	445710	08011M	PARTICIPANT	\N	EXCUSE	0
447020	445710	19667J	PARTICIPANT	\N	EXCUSE	0
447032	445710	04071H	PARTICIPANT	\N	PRESENT	0
447033	445710	14034U	PARTICIPANT	\N	PRESENT	0
447034	446794	80013X	PARTICIPANT	\N	PRESENT	0
447035	446794	11081P	PARTICIPANT	\N	EXCUSE	0
447036	446794	17589D	PARTICIPANT	\N	EXCUSE	0
447038	446385	14191V	PARTICIPANT	\N	PRESENT	0
447039	446385	17583W	PARTICIPANT	\N	EXCUSE	0
447040	446385	19745F	PARTICIPANT	\N	EXCUSE	0
447041	446385	19681G	PARTICIPANT	\N	PRESENT	0
447042	446385	14103D	PARTICIPANT	\N	PRESENT	0
447061	445707	19399H	PARTICIPANT	\N	EXCUSE	0
447063	445707	07033P	PARTICIPANT	\N	PRESENT	0
447064	445707	08043V	PARTICIPANT	\N	PRESENT	0
447065	445715	14327T	PARTICIPANT	\N	PRESENT	0
447066	445715	14331P	PARTICIPANT	\N	PRESENT	0
447067	445715	04071H	PARTICIPANT	\N	PRESENT	0
447068	445715	01048V	PARTICIPANT	\N	PRESENT	0
447069	445715	19545Y	PARTICIPANT	\N	PRESENT	0
447070	445715	01057W	PARTICIPANT	\N	PRESENT	0
447071	445715	11074Q	PRESIDENT	0	PRESENT	0
447072	445715	89017R	PARTICIPANT	\N	PRESENT	0
447073	445715	19667J	PARTICIPANT	\N	PRESENT	0
447074	445715	19671E	PARTICIPANT	\N	PRESENT	0
447075	445715	11070L	PARTICIPANT	\N	PRESENT	0
447076	445715	88008L	PARTICIPANT	\N	PRESENT	0
447077	445715	11110B	PARTICIPANT	\N	PRESENT	0
447078	445715	07029T	PARTICIPANT	\N	PRESENT	0
447079	445715	14277B	PARTICIPANT	\N	PRESENT	0
447080	445715	14085U	PARTICIPANT	\N	PRESENT	0
447081	445715	07004J	PARTICIPANT	\N	PRESENT	0
447082	445715	19349W	PARTICIPANT	\N	PRESENT	0
447083	445715	08010L	PARTICIPANT	\N	PRESENT	0
447084	445715	14253S	PARTICIPANT	\N	PRESENT	0
447085	445715	19479G	PARTICIPANT	\N	PRESENT	0
447086	445715	11048N	PARTICIPANT	\N	PRESENT	0
447087	445715	19647E	PARTICIPANT	\N	PRESENT	0
447088	445715	19711U	PARTICIPANT	\N	PRESENT	0
447089	445715	08034U	PARTICIPANT	\N	PRESENT	0
447090	445715	19651A	PARTICIPANT	\N	PRESENT	0
447091	445715	19531S	PARTICIPANT	\N	PRESENT	0
447092	445715	08069G	PARTICIPANT	\N	PRESENT	0
447093	445715	19687N	PARTICIPANT	\N	PRESENT	0
447094	445715	19689Q	PARTICIPANT	\N	PRESENT	0
447095	445715	12016W	PARTICIPANT	\N	PRESENT	0
447096	445715	08014Q	PARTICIPANT	\N	PRESENT	0
447097	445715	14034U	PARTICIPANT	\N	PRESENT	0
447098	445715	14159V	PARTICIPANT	\N	PRESENT	0
447099	445715	14173T	PARTICIPANT	\N	PRESENT	0
447100	445715	11040E	PARTICIPANT	\N	PRESENT	0
447101	445715	14083S	PARTICIPANT	\N	PRESENT	0
447102	445715	14199E	PARTICIPANT	\N	PRESENT	0
447103	445715	11012A	PARTICIPANT	\N	PRESENT	0
447104	445715	08073C	PARTICIPANT	\N	PRESENT	0
447105	445715	14121F	PARTICIPANT	\N	PRESENT	0
447106	445715	19741B	PARTICIPANT	\N	PRESENT	0
447107	445715	99004R	PARTICIPANT	\N	PRESENT	0
447108	445715	04086Q	PARTICIPANT	\N	EXCUSE	0
447109	445715	08011M	PARTICIPANT	\N	EXCUSE	0
447110	445995	01060R	PARTICIPANT	\N	PRESENT	0
447111	445995	14001X	PARTICIPANT	\N	PRESENT	0
447112	445995	19543W	PARTICIPANT	\N	PRESENT	0
447113	445995	19581D	PARTICIPANT	\N	PRESENT	0
447114	445995	19585H	PARTICIPANT	\N	PRESENT	0
447115	445995	19673G	PARTICIPANT	\N	PRESENT	0
424983	424982	14123H	PARTICIPANT	\N	PRESENT	0
424984	424982	19611R	PARTICIPANT	\N	PRESENT	0
424990	424989	14123H	PARTICIPANT	\N	PRESENT	0
424991	424989	08043V	PARTICIPANT	\N	PRESENT	0
429854	429531	17589D	PARTICIPANT	\N	PRESENT	0
429855	429531	01024M	PARTICIPANT	\N	PRESENT	0
429857	429531	19691J	PARTICIPANT	\N	PRESENT	0
429858	429531	07029T	PARTICIPANT	\N	PRESENT	0
429859	429531	14265W	PARTICIPANT	\N	PRESENT	0
429860	429531	14119M	PARTICIPANT	\N	PRESENT	0
429861	429531	19798U	PARTICIPANT	\N	PRESENT	0
429864	423897	14042U	PARTICIPANT	\N	PRESENT	0
439870	439869	04085P	PARTICIPANT	\N	PRESENT	0
439874	439869	04040A	PARTICIPANT	\N	PRESENT	0
439872	439869	05008E	PARTICIPANT	\N	PRESENT	0
439873	439869	14030Q	PARTICIPANT	\N	PRESENT	0
439875	439869	11053K	PARTICIPANT	\N	PRESENT	0
439876	439869	04086Q	PARTICIPANT	\N	PRESENT	0
439877	439869	14079W	PARTICIPANT	\N	PRESENT	0
439878	439869	11074Q	PARTICIPANT	\N	PRESENT	0
439879	439869	14034U	PARTICIPANT	\N	PRESENT	0
439880	439869	14021P	PARTICIPANT	\N	PRESENT	0
439881	439869	14157T	PARTICIPANT	\N	PRESENT	0
439882	439869	01043Q	PARTICIPANT	\N	PRESENT	0
439883	439869	08019V	PARTICIPANT	\N	PRESENT	0
439884	439869	08009T	PARTICIPANT	\N	PRESENT	0
439885	439869	04092N	PARTICIPANT	\N	PRESENT	0
439886	439869	04070G	PARTICIPANT	\N	PRESENT	0
439887	439869	11090Q	PARTICIPANT	\N	PRESENT	0
439888	439869	10015M	PARTICIPANT	\N	PRESENT	0
439889	439869	11012A	PARTICIPANT	\N	PRESENT	0
439890	439869	04033B	PARTICIPANT	\N	PRESENT	0
447196	445753	19583F	PARTICIPANT	\N	EXCUSE	0
447197	445754	19583F	PARTICIPANT	\N	EXCUSE	0
448400	439818	14030Q	PARTICIPANT	\N	PRESENT	0
448401	439818	08017T	PARTICIPANT	\N	PRESENT	0
448402	439818	01024M	PARTICIPANT	\N	PRESENT	0
448403	439818	19611R	PARTICIPANT	\N	PRESENT	0
448404	439818	11090Q	PARTICIPANT	\N	PRESENT	0
448405	439818	04057K	PARTICIPANT	\N	PRESENT	0
448406	439818	11012A	PARTICIPANT	\N	PRESENT	0
448407	439818	08031R	PARTICIPANT	\N	PRESENT	0
448408	439818	19663E	PARTICIPANT	\N	PRESENT	0
448416	444734	11080N	PARTICIPANT	\N	PRESENT	0
448417	444734	19421M	PARTICIPANT	\N	PRESENT	0
448426	439818	19723Y	PARTICIPANT	\N	PRESENT	0
448419	444734	11026G	PARTICIPANT	\N	PRESENT	0
448420	444734	04040A	PARTICIPANT	\N	PRESENT	0
448421	444734	19673G	PRESIDENT	1	PRESENT	0
448422	444734	19585H	PARTICIPANT	\N	PRESENT	0
448423	444734	19719D	PRESIDENT	0	PRESENT	0
448424	439818	14255U	PARTICIPANT	\N	PRESENT	0
448425	439818	19741B	PARTICIPANT	\N	PRESENT	0
448427	439818	19531S	PARTICIPANT	\N	PRESENT	0
448484	439819	19447X	PARTICIPANT	\N	PRESENT	0
448506	439819	11067R	PARTICIPANT	\N	PRESENT	0
448504	439819	08052W	PARTICIPANT	\N	PRESENT	0
448505	439819	19333N	PARTICIPANT	\N	PRESENT	0
448507	439819	19515S	PARTICIPANT	\N	PRESENT	0
448508	439819	19683J	PARTICIPANT	\N	PRESENT	0
448509	439819	08069G	PARTICIPANT	\N	PRESENT	0
448510	439819	19649G	PARTICIPANT	\N	PRESENT	0
448511	439819	08043V	PARTICIPANT	\N	PRESENT	0
448512	439819	11045K	PARTICIPANT	\N	PRESENT	0
448513	439819	11090Q	PARTICIPANT	\N	PRESENT	0
448514	439819	19569H	PARTICIPANT	\N	PRESENT	0
448515	439819	14042U	PARTICIPANT	\N	PRESENT	0
448516	439819	19693L	PARTICIPANT	\N	PRESENT	0
448517	439819	14179A	PARTICIPANT	\N	PRESENT	0
448518	439819	19667J	PARTICIPANT	\N	PRESENT	0
448519	439819	19651A	PARTICIPANT	\N	PRESENT	0
448520	439819	14105F	PARTICIPANT	\N	PRESENT	0
448521	439819	14213J	PARTICIPANT	\N	PRESENT	0
448522	439819	08034U	PARTICIPANT	\N	PRESENT	0
448523	439819	19711U	PARTICIPANT	\N	PRESENT	0
448524	439819	04034C	PARTICIPANT	\N	PRESENT	0
448525	439819	04045F	PARTICIPANT	\N	PRESENT	0
448526	439819	05008E	PARTICIPANT	\N	PRESENT	0
448527	439819	14217N	PARTICIPANT	\N	PRESENT	0
448528	439819	14065Q	PARTICIPANT	\N	PRESENT	0
448529	439819	19415P	PARTICIPANT	\N	PRESENT	0
448530	439819	19565D	PARTICIPANT	\N	PRESENT	0
448531	439819	19443T	PARTICIPANT	\N	PRESENT	0
448532	439819	11033F	PARTICIPANT	\N	PRESENT	0
448533	439819	19681G	PARTICIPANT	\N	PRESENT	0
448534	439819	98024R	PARTICIPANT	\N	PRESENT	0
448535	439819	19723Y	PARTICIPANT	\N	PRESENT	0
448536	439819	14195A	PARTICIPANT	\N	PRESENT	0
448537	439819	11031D	PARTICIPANT	\N	PRESENT	0
448538	439819	19553Y	PARTICIPANT	\N	PRESENT	0
448539	439819	19798U	PARTICIPANT	\N	PRESENT	0
448540	439819	18083K	PARTICIPANT	\N	PRESENT	0
448541	439819	19794Q	PARTICIPANT	\N	PRESENT	0
448542	439819	04085P	PARTICIPANT	\N	PRESENT	0
448543	439819	19575F	PARTICIPANT	\N	PRESENT	0
448544	439819	99004R	PARTICIPANT	\N	PRESENT	0
448545	439819	19399H	PARTICIPANT	\N	PRESENT	0
448546	439819	19611R	PARTICIPANT	\N	PRESENT	0
448547	439819	14215L	PARTICIPANT	\N	PRESENT	0
448548	439819	14069U	PARTICIPANT	\N	PRESENT	0
448549	439819	19737F	PARTICIPANT	\N	PRESENT	0
448560	439819	19663E	PARTICIPANT	\N	PRESENT	0
448564	439819	01048V	PARTICIPANT	\N	PRESENT	0
448565	439819	19573D	PARTICIPANT	\N	PRESENT	0
448566	439819	19467C	PARTICIPANT	\N	PRESENT	0
448567	439819	19762G	PARTICIPANT	\N	PRESENT	0
448568	439819	19687N	PARTICIPANT	\N	PRESENT	0
448569	439819	12041X	PARTICIPANT	\N	PRESENT	0
448482	439819	11027H	PARTICIPANT	\N	PRESENT	0
448483	439819	04092N	PARTICIPANT	\N	PRESENT	0
448570	439819	08039A	PARTICIPANT	\N	PRESENT	0
448571	439819	19713W	PARTICIPANT	\N	PRESENT	0
448572	439819	14251Q	PARTICIPANT	\N	PRESENT	0
448574	439819	11097X	PARTICIPANT	\N	PRESENT	0
448575	439819	04033B	PARTICIPANT	\N	PRESENT	0
448576	439819	14030Q	PARTICIPANT	\N	PRESENT	0
448577	439819	19531S	PARTICIPANT	\N	PRESENT	0
448578	439819	19741B	PARTICIPANT	\N	PRESENT	0
448579	439819	19747H	PARTICIPANT	\N	PRESENT	0
448580	439819	19673G	PARTICIPANT	\N	PRESENT	0
448581	439819	11085T	PARTICIPANT	\N	PRESENT	0
448582	439819	01024M	PARTICIPANT	\N	PRESENT	0
448583	439819	11053K	PARTICIPANT	\N	PRESENT	0
448584	439819	14159V	PARTICIPANT	\N	PRESENT	0
448589	439819	19671E	PARTICIPANT	\N	PRESENT	0
448597	439819	11012A	PARTICIPANT	\N	PRESENT	0
448598	439819	04057K	PARTICIPANT	\N	PRESENT	0
448599	439819	08031R	PARTICIPANT	\N	PRESENT	0
448600	439819	04043D	PARTICIPANT	\N	PRESENT	0
448614	439819	11026G	PARTICIPANT	\N	PRESENT	0
448615	439819	08017T	PARTICIPANT	\N	PRESENT	0
448620	439819	19543W	PARTICIPANT	\N	PRESENT	0
448621	439819	14079W	PARTICIPANT	\N	PRESENT	0
448622	439819	19701S	PARTICIPANT	\N	PRESENT	0
448633	439819	19647E	PARTICIPANT	\N	PRESENT	0
448635	448632	14195A	PARTICIPANT	\N	PRESENT	0
448636	448632	19575F	PARTICIPANT	\N	EXCUSE	0
500851	500408	19367Y	PARTICIPANT	\N	EXCUSE	0
500852	500408	19295A	PARTICIPANT	\N	EXCUSE	0
500853	500408	14355X	PARTICIPANT	\N	EXCUSE	0
500854	500408	19569H	PARTICIPANT	\N	PRESENT	0
500855	500408	19713W	PARTICIPANT	\N	PRESENT	0
500856	500408	17779H	PARTICIPANT	\N	PRESENT	0
500857	500408	19798U	PARTICIPANT	\N	PRESENT	0
501594	500116	20138D	PARTICIPANT	\N	PRESENT	0
501595	500116	17589D	PARTICIPANT	\N	PRESENT	0
501680	498850	14105F	PARTICIPANT	\N	PRESENT	0
501681	498850	19467C	PARTICIPANT	\N	PRESENT	0
501682	498850	14041T	PARTICIPANT	\N	PRESENT	0
501784	498850	19301E	PARTICIPANT	\N	PRESENT	0
501684	498850	14026U	PARTICIPANT	\N	PRESENT	0
501685	498850	20126Y	PARTICIPANT	\N	PRESENT	0
501686	498850	16685X	PARTICIPANT	\N	PRESENT	0
501687	498850	14031R	PARTICIPANT	\N	PRESENT	0
501786	498850	20094J	PARTICIPANT	\N	EXCUSE	0
501689	498850	19679N	PARTICIPANT	\N	PRESENT	0
501691	498850	20054A	PARTICIPANT	\N	PRESENT	0
501692	498850	20092G	PARTICIPANT	\N	PRESENT	0
501763	501761	14231L	PRESIDENT	0	PRESENT	0
501782	498850	19717B	PARTICIPANT	\N	PRESENT	0
501783	498850	20060X	PARTICIPANT	\N	PRESENT	0
501785	498850	14030Q	PARTICIPANT	\N	EXCUSE	0
501787	498850	19545Y	PARTICIPANT	\N	EXCUSE	0
501788	498850	14329V	PARTICIPANT	\N	EXCUSE	0
501789	498850	08028W	PARTICIPANT	\N	EXCUSE	0
501790	498850	19671E	PARTICIPANT	\N	PRESENT	0
501791	498850	20048C	PARTICIPANT	\N	EXCUSE	0
439328	439275	04088S	PARTICIPANT	\N	PRESENT	0
439329	439275	04089T	PARTICIPANT	\N	PRESENT	0
439330	439275	14265W	PARTICIPANT	\N	PRESENT	0
439331	439275	14357A	PARTICIPANT	\N	PRESENT	0
439332	439275	14038Y	PARTICIPANT	\N	PRESENT	0
439333	439275	14051J	PARTICIPANT	\N	PRESENT	0
439334	439275	14257W	PARTICIPANT	\N	PRESENT	0
439335	439275	04097T	PARTICIPANT	\N	PRESENT	0
439336	439275	14083S	PARTICIPANT	\N	PRESENT	0
439338	432678	08069G	PARTICIPANT	\N	EXCUSE	0
439339	432678	19711U	PARTICIPANT	\N	EXCUSE	0
439340	432678	19713W	PARTICIPANT	\N	PRESENT	0
439529	432678	19515S	PARTICIPANT	\N	PRESENT	0
439530	432678	01028R	PARTICIPANT	\N	PRESENT	0
439611	431449	08024S	PARTICIPANT	\N	PRESENT	0
439713	439610	08045X	PARTICIPANT	\N	PRESENT	0
439720	439719	04059M	PARTICIPANT	\N	PRESENT	0
439721	439719	11040E	PARTICIPANT	\N	PRESENT	0
439722	439719	11053K	PARTICIPANT	\N	PRESENT	0
439790	439787	08060W	PARTICIPANT	\N	PRESENT	0
439724	439719	04086Q	PARTICIPANT	\N	PRESENT	0
439725	439719	08052W	PARTICIPANT	\N	PRESENT	0
439726	439719	11070L	PARTICIPANT	\N	PRESENT	0
439727	439719	10006L	PARTICIPANT	\N	PRESENT	0
439728	439719	04089T	PARTICIPANT	\N	PRESENT	0
439729	439719	14034U	PARTICIPANT	\N	PRESENT	0
439730	439719	14231L	PARTICIPANT	\N	PRESENT	0
439731	439719	14061L	PARTICIPANT	\N	PRESENT	0
439732	439719	14159V	PARTICIPANT	\N	PRESENT	0
439733	439719	86034E	PARTICIPANT	\N	PRESENT	0
439734	439719	08034U	PARTICIPANT	\N	PRESENT	0
439735	439719	01043Q	PARTICIPANT	\N	PRESENT	0
439736	439719	05012A	PARTICIPANT	\N	PRESENT	0
439737	439719	04045F	PARTICIPANT	\N	PRESENT	0
439738	439719	04044E	PARTICIPANT	\N	PRESENT	0
439788	439787	08009T	PRESIDENT	0	PRESENT	0
439789	439787	19367Y	PARTICIPANT	\N	PRESENT	0
439791	439787	14051J	PARTICIPANT	\N	PRESENT	0
439792	439787	19758L	PARTICIPANT	\N	PRESENT	0
439793	439787	04070G	PARTICIPANT	\N	PRESENT	0
439794	439787	19826F	PARTICIPANT	\N	EXCUSE	0
439831	435341	08052W	PARTICIPANT	\N	PRESENT	0
439833	439832	04049K	PARTICIPANT	\N	PRESENT	0
439834	439832	16685X	PARTICIPANT	\N	PRESENT	0
439837	439836	04049K	PARTICIPANT	\N	PRESENT	0
439838	439836	16685X	PARTICIPANT	\N	PRESENT	0
439839	439835	04049K	PARTICIPANT	\N	PRESENT	0
439840	439835	16685X	PARTICIPANT	\N	PRESENT	0
439843	439842	04049K	PARTICIPANT	\N	PRESENT	0
439844	439842	16685X	PARTICIPANT	\N	PRESENT	0
442686	441590	01058X	PARTICIPANT	\N	PRESENT	0
442687	441590	04040A	PARTICIPANT	\N	PRESENT	0
442688	441590	11027H	PARTICIPANT	\N	PRESENT	0
442689	441590	11054L	PARTICIPANT	\N	PRESENT	0
442690	441590	19421M	PARTICIPANT	\N	PRESENT	0
442691	441590	01062T	PARTICIPANT	\N	PRESENT	0
442692	441590	98022P	PARTICIPANT	\N	PRESENT	0
442697	441700	14327T	PARTICIPANT	\N	PRESENT	0
442698	441700	14331P	PARTICIPANT	\N	PRESENT	0
442699	441700	01048V	PARTICIPANT	\N	PRESENT	0
442700	441700	01057W	PARTICIPANT	\N	PRESENT	0
442701	441700	11053K	PARTICIPANT	\N	PRESENT	0
442702	441700	19667J	PARTICIPANT	\N	PRESENT	0
442703	441700	88008L	PARTICIPANT	\N	PRESENT	0
442704	441700	11070L	PARTICIPANT	\N	PRESENT	0
442705	441700	14225N	PARTICIPANT	\N	PRESENT	0
442706	441700	07029T	PARTICIPANT	\N	PRESENT	0
442707	441700	14051J	PARTICIPANT	\N	PRESENT	0
442708	441700	08060W	PARTICIPANT	\N	PRESENT	0
442709	441700	07004J	PARTICIPANT	\N	PRESENT	0
442710	441700	19349W	PARTICIPANT	\N	PRESENT	0
442711	441700	14253S	PARTICIPANT	\N	PRESENT	0
442712	441700	19479G	PARTICIPANT	\N	PRESENT	0
442713	441700	11048N	PARTICIPANT	\N	PRESENT	0
442714	441700	19711U	PARTICIPANT	\N	PRESENT	0
442715	441700	08034U	PARTICIPANT	\N	PRESENT	0
442716	441700	19531S	PARTICIPANT	\N	PRESENT	0
442717	441700	08069G	PARTICIPANT	\N	PRESENT	0
442718	441700	08014Q	PARTICIPANT	\N	PRESENT	0
442719	441700	14159V	PARTICIPANT	\N	PRESENT	0
442720	441700	14173T	PARTICIPANT	\N	PRESENT	0
442721	441700	11040E	PRESIDENT	0	PRESENT	0
442722	441700	04086Q	PARTICIPANT	\N	PRESENT	0
442723	441700	14083S	PARTICIPANT	\N	PRESENT	0
442724	441700	11012A	PARTICIPANT	\N	PRESENT	0
442725	441700	14199E	PARTICIPANT	\N	PRESENT	0
442726	441700	19741B	PARTICIPANT	\N	PRESENT	0
442727	441700	14121F	PARTICIPANT	\N	PRESENT	0
442728	441700	99004R	PARTICIPANT	\N	PRESENT	0
442729	441700	08011M	PARTICIPANT	\N	EXCUSE	0
442730	441788	14001X	PARTICIPANT	\N	PRESENT	0
442731	441788	01060R	PARTICIPANT	\N	PRESENT	0
442732	441788	19543W	PARTICIPANT	\N	PRESENT	0
442733	441788	04044E	PARTICIPANT	\N	PRESENT	0
442734	441788	19581D	PARTICIPANT	\N	PRESENT	0
442735	441788	19673G	PARTICIPANT	\N	PRESENT	0
442736	441788	19675J	PARTICIPANT	\N	PRESENT	0
442737	441788	01028R	PARTICIPANT	\N	PRESENT	0
442738	441788	05008E	PRESIDENT	0	PRESENT	0
442739	441788	14231L	PARTICIPANT	\N	PRESENT	0
442740	441788	19447X	PARTICIPANT	\N	PRESENT	0
442741	441788	19489J	PARTICIPANT	\N	PRESENT	0
442742	441788	14179A	PARTICIPANT	\N	PRESENT	0
442743	441788	14151M	PARTICIPANT	\N	PRESENT	0
442744	441788	14215L	PARTICIPANT	\N	PRESENT	0
442745	441788	11072N	PARTICIPANT	\N	PRESENT	0
442746	441788	14053L	PARTICIPANT	\N	PRESENT	0
442747	441788	14111D	PARTICIPANT	\N	PRESENT	0
442748	441788	08045X	PARTICIPANT	\N	PRESENT	0
442749	441788	11026G	PARTICIPANT	\N	PRESENT	0
442750	441788	01024M	PARTICIPANT	\N	PRESENT	0
442751	441788	11033F	PARTICIPANT	\N	PRESENT	0
442752	441788	14089Y	PARTICIPANT	\N	PRESENT	0
442753	441788	19725B	PARTICIPANT	\N	PRESENT	0
442754	441788	19729F	PARTICIPANT	\N	PRESENT	0
442755	441788	95063L	PARTICIPANT	\N	PRESENT	0
442757	441788	08044W	PARTICIPANT	\N	PRESENT	0
442758	441788	14069U	PARTICIPANT	\N	PRESENT	0
442759	441788	11085T	PARTICIPANT	\N	PRESENT	0
442760	441788	14065Q	PARTICIPANT	\N	PRESENT	0
442761	441788	14275Y	PARTICIPANT	\N	EXCUSE	0
442762	441788	14041T	PARTICIPANT	\N	EXCUSE	0
442763	441788	04047H	PARTICIPANT	\N	EXCUSE	0
442764	441788	19719D	PARTICIPANT	\N	EXCUSE	0
442765	441788	08018U	PARTICIPANT	\N	PRESENT	0
442769	441700	89017R	PARTICIPANT	\N	PRESENT	0
442770	441700	08010L	PARTICIPANT	\N	PRESENT	0
442771	441700	19647E	PARTICIPANT	\N	PRESENT	0
442772	441700	19687N	PARTICIPANT	\N	PRESENT	0
442773	441700	19689Q	PARTICIPANT	\N	PRESENT	0
442774	441788	11049P	PARTICIPANT	\N	PRESENT	0
442777	441310	19697Q	PARTICIPANT	\N	PRESENT	0
442778	441310	19565D	PARTICIPANT	\N	PRESENT	0
442779	441310	19798U	PARTICIPANT	\N	PRESENT	0
442780	441310	19569H	PARTICIPANT	\N	PRESENT	0
442781	441310	11097X	PARTICIPANT	\N	PRESENT	0
442782	441310	19415P	PARTICIPANT	\N	PRESENT	0
442783	441310	14223L	PARTICIPANT	\N	PRESENT	0
442784	441310	14026U	PARTICIPANT	\N	PRESENT	0
442785	441310	14227Q	PARTICIPANT	\N	PRESENT	0
442786	441310	17779H	PARTICIPANT	\N	PRESENT	0
442787	441310	11031D	PARTICIPANT	\N	PRESENT	0
442788	441310	14239U	PARTICIPANT	\N	PRESENT	0
442789	441310	19703U	PARTICIPANT	\N	PRESENT	0
442790	441310	19553Y	PARTICIPANT	\N	PRESENT	0
442791	441310	14281W	PARTICIPANT	\N	PRESENT	0
442792	441310	19679N	PARTICIPANT	\N	PRESENT	0
442793	441310	14042U	PARTICIPANT	\N	PRESENT	0
442794	441310	19575F	PARTICIPANT	\N	PRESENT	0
442795	441310	08048B	PARTICIPANT	\N	PRESENT	0
442796	441310	14195A	PARTICIPANT	\N	PRESENT	0
442797	441310	19367Y	PARTICIPANT	\N	PRESENT	0
442798	441310	14213J	PARTICIPANT	\N	PRESENT	0
442799	441310	14217N	PARTICIPANT	\N	PRESENT	0
442800	441310	19683J	PARTICIPANT	\N	PRESENT	0
442801	441310	10006L	PARTICIPANT	\N	PRESENT	0
442802	441310	19521Q	PARTICIPANT	\N	PRESENT	0
442803	441310	98024R	PARTICIPANT	\N	PRESENT	0
442804	441310	19527W	PARTICIPANT	\N	PRESENT	0
442805	441310	04092N	PRESIDENT	0	PRESENT	0
442806	441310	11045K	PARTICIPANT	\N	PRESENT	0
442807	441310	08052W	PARTICIPANT	\N	PRESENT	0
442808	441310	19663E	PARTICIPANT	\N	PRESENT	0
442809	441310	19717B	PARTICIPANT	\N	PRESENT	0
442810	441310	19727D	PARTICIPANT	\N	PRESENT	0
442811	441310	14119M	PARTICIPANT	\N	PRESENT	0
442812	441310	11103C	PARTICIPANT	\N	PRESENT	0
442813	441310	14071N	PARTICIPANT	\N	PRESENT	0
424967	421729	04040A	PRESIDENT	0	PRESENT	0
424968	421729	14281W	PARTICIPANT	\N	PRESENT	0
424969	421729	01057W	PARTICIPANT	\N	PRESENT	0
424970	421729	14257W	PARTICIPANT	\N	PRESENT	0
424971	421729	19489J	PARTICIPANT	\N	PRESENT	0
424972	421729	08049C	PARTICIPANT	\N	PRESENT	0
424973	421729	95063L	PARTICIPANT	\N	PRESENT	0
424974	421729	08010L	PARTICIPANT	\N	PRESENT	0
424975	421729	19735D	PARTICIPANT	\N	PRESENT	0
425089	425088	19515S	PARTICIPANT	\N	PRESENT	0
425090	425088	08068F	PARTICIPANT	\N	PRESENT	0
425092	425091	08068F	PARTICIPANT	\N	PRESENT	0
425094	425093	08068F	PARTICIPANT	\N	PRESENT	0
425096	425095	08068F	PARTICIPANT	\N	PRESENT	0
425098	425097	08068F	PARTICIPANT	\N	PRESENT	0
433906	431081	19553Y	PARTICIPANT	\N	PRESENT	0
433907	431081	11067R	PARTICIPANT	\N	PRESENT	0
433908	431081	08034U	PARTICIPANT	\N	PRESENT	0
433909	431081	11045K	PARTICIPANT	\N	PRESENT	0
433910	431081	14042U	PRESIDENT	0	PRESENT	0
433911	431081	14147R	PARTICIPANT	\N	PRESENT	0
433912	431081	19575F	PARTICIPANT	\N	PRESENT	0
433913	431081	14213J	PARTICIPANT	\N	PRESENT	0
433914	431081	99004R	PARTICIPANT	\N	PRESENT	0
433915	431081	14215L	PARTICIPANT	\N	PRESENT	0
433916	431081	04045F	PARTICIPANT	\N	PRESENT	0
433917	431081	19447X	PARTICIPANT	\N	PRESENT	0
433920	431081	19569H	PARTICIPANT	\N	PRESENT	0
433921	425297	11072N	PARTICIPANT	\N	PRESENT	0
433922	431081	19335Q	PARTICIPANT	\N	PRESENT	0
433923	431081	04092N	PARTICIPANT	\N	EXCUSE	0
433924	425297	14121F	PARTICIPANT	\N	PRESENT	0
433925	425297	11104D	PARTICIPANT	\N	PRESENT	0
433926	425297	08012N	PARTICIPANT	\N	PRESENT	0
433927	425297	19758L	PARTICIPANT	\N	PRESENT	0
433928	425297	14235Q	PARTICIPANT	\N	PRESENT	0
433929	425297	08043V	PARTICIPANT	\N	PRESENT	0
433930	425297	14225N	PARTICIPANT	\N	PRESENT	0
433931	425297	14229S	PARTICIPANT	\N	PRESENT	0
433932	425297	04059M	PARTICIPANT	\N	PRESENT	0
433933	425297	19563B	PARTICIPANT	\N	PRESENT	0
433934	425297	14073Q	PARTICIPANT	\N	PRESENT	0
433935	425297	14123H	PARTICIPANT	\N	PRESENT	0
433936	425297	19399H	PARTICIPANT	\N	PRESENT	0
433937	425297	19349W	PARTICIPANT	\N	PRESENT	0
433938	425297	11074Q	PARTICIPANT	\N	PRESENT	0
433939	425297	04070G	PARTICIPANT	\N	PRESENT	0
433940	425297	14241N	PARTICIPANT	\N	PRESENT	0
433941	425297	19667J	PARTICIPANT	\N	PRESENT	0
433942	425297	19794Q	PARTICIPANT	\N	PRESENT	0
433944	425297	14157T	PARTICIPANT	\N	PRESENT	0
433959	425297	19673G	PARTICIPANT	\N	PRESENT	0
433960	425297	14031R	PARTICIPANT	\N	PRESENT	0
433962	425297	14217N	PARTICIPANT	\N	PRESENT	0
433966	425297	19679N	PARTICIPANT	\N	PRESENT	0
433967	425297	19729F	PARTICIPANT	\N	PRESENT	0
433968	425297	15447F	PARTICIPANT	\N	PRESENT	0
433969	425297	97011G	PARTICIPANT	\N	PRESENT	0
433970	425297	11097X	PARTICIPANT	\N	PRESENT	0
433971	425297	19593H	PARTICIPANT	\N	PRESENT	0
433972	425297	04043D	PARTICIPANT	\N	PRESENT	0
433973	425297	19301E	PARTICIPANT	\N	PRESENT	0
433974	425297	14107H	PARTICIPANT	\N	PRESENT	0
433975	425297	11043H	PARTICIPANT	\N	PRESENT	0
433976	425297	19573D	PARTICIPANT	\N	PRESENT	0
433977	425297	19533U	PARTICIPANT	\N	PRESENT	0
433978	425297	14119M	PARTICIPANT	\N	PRESENT	0
433979	425297	19826F	PARTICIPANT	\N	PRESENT	0
433980	425297	19699S	PARTICIPANT	\N	PRESENT	0
433981	425297	98050T	PARTICIPANT	\N	PRESENT	0
433982	425297	08062Y	PARTICIPANT	\N	PRESENT	0
433983	431081	14041T	PARTICIPANT	\N	PRESENT	0
433984	425297	08056B	PARTICIPANT	\N	PRESENT	0
433985	425297	14173T	PARTICIPANT	\N	PRESENT	0
434003	425297	19479G	PARTICIPANT	\N	PRESENT	0
434004	425297	19747H	PARTICIPANT	\N	PRESENT	0
434005	425297	08020N	PARTICIPANT	\N	PRESENT	0
434006	425297	19369B	PARTICIPANT	\N	PRESENT	0
434010	425297	19731Y	PARTICIPANT	\N	PRESENT	0
434012	425297	19413M	PARTICIPANT	\N	PRESENT	0
434014	425297	19745F	PARTICIPANT	\N	PRESENT	0
434015	425297	14069U	PARTICIPANT	\N	PRESENT	0
434016	425297	14249W	PARTICIPANT	\N	PRESENT	0
434017	425297	19467C	PARTICIPANT	\N	PRESENT	0
434033	425297	14071N	PARTICIPANT	\N	PRESENT	0
434034	425297	19713W	PARTICIPANT	\N	PRESENT	0
434035	425297	14211G	PARTICIPANT	\N	PRESENT	0
434036	425297	19531S	PARTICIPANT	\N	PRESENT	0
434037	425297	19611R	PARTICIPANT	\N	PRESENT	0
434038	425297	14041T	PARTICIPANT	\N	PRESENT	0
434039	425297	14042U	PARTICIPANT	\N	PRESENT	0
434040	425297	19543W	PARTICIPANT	\N	PRESENT	0
434045	425297	08034U	PARTICIPANT	\N	PRESENT	0
434093	425306	14073Q	PARTICIPANT	\N	PRESENT	0
434103	425306	04044E	PARTICIPANT	\N	PRESENT	0
434104	425306	08047A	PARTICIPANT	\N	PRESENT	0
434105	425306	14173T	PARTICIPANT	\N	PRESENT	0
434106	425306	11066Q	PARTICIPANT	\N	PRESENT	0
434107	425306	19671E	PARTICIPANT	\N	PRESENT	0
434108	425306	19737F	PARTICIPANT	\N	PRESENT	0
434109	425306	04047H	PARTICIPANT	\N	PRESENT	0
434110	425306	14038Y	PARTICIPANT	\N	PRESENT	0
434111	425306	04071H	PARTICIPANT	\N	PRESENT	0
434112	425306	15447F	PARTICIPANT	\N	PRESENT	0
434113	425306	04085P	PARTICIPANT	\N	PRESENT	0
434114	425306	14034U	PARTICIPANT	\N	PRESENT	0
434115	425306	04018C	PARTICIPANT	\N	PRESENT	0
434116	425306	19794Q	PARTICIPANT	\N	PRESENT	0
434117	425306	95063L	PARTICIPANT	\N	PRESENT	0
434118	425306	19479G	PARTICIPANT	\N	PRESENT	0
434119	425306	14235Q	PARTICIPANT	\N	PRESENT	0
434120	425306	19593H	PARTICIPANT	\N	PRESENT	0
434121	425306	19667J	PARTICIPANT	\N	PRESENT	0
434122	425306	01028R	PARTICIPANT	\N	PRESENT	0
434123	425306	08045X	PARTICIPANT	\N	PRESENT	0
434124	425306	19729F	PARTICIPANT	\N	PRESENT	0
434125	425306	19467C	PARTICIPANT	\N	PRESENT	0
434126	425306	19563B	PARTICIPANT	\N	PRESENT	0
434127	425306	19533U	PARTICIPANT	\N	PRESENT	0
434128	425306	08034U	PARTICIPANT	\N	PRESENT	0
434129	425306	14053L	PARTICIPANT	\N	PRESENT	0
434130	425306	19725B	PARTICIPANT	\N	PRESENT	0
434131	425306	98050T	PARTICIPANT	\N	PRESENT	0
434132	425306	11090Q	PARTICIPANT	\N	PRESENT	0
434133	425306	19621T	PARTICIPANT	\N	PRESENT	0
434134	425306	11072N	PARTICIPANT	\N	PRESENT	0
434135	425306	16685X	PARTICIPANT	\N	PRESENT	0
434136	425306	19741B	PARTICIPANT	\N	PRESENT	0
434137	425306	11012A	PARTICIPANT	\N	PRESENT	0
434138	425306	95037J	PARTICIPANT	\N	PRESENT	0
434139	425306	04042C	PARTICIPANT	\N	PRESENT	0
434091	425306	04059M	PARTICIPANT	\N	PRESENT	0
434092	425306	07004J	PARTICIPANT	\N	PRESENT	0
434140	425306	19349W	PARTICIPANT	\N	PRESENT	0
434141	425306	11045K	PARTICIPANT	\N	PRESENT	0
434142	425306	19333N	PARTICIPANT	\N	PRESENT	0
434143	425306	14089Y	PARTICIPANT	\N	PRESENT	0
434144	425306	19521Q	PARTICIPANT	\N	PRESENT	0
434145	425306	14249W	PARTICIPANT	\N	PRESENT	0
434146	425306	11048N	PARTICIPANT	\N	PRESENT	0
434150	425306	19581D	PARTICIPANT	\N	PRESENT	0
434152	425306	19387D	PARTICIPANT	\N	PRESENT	0
434153	425306	19335Q	PARTICIPANT	\N	PRESENT	0
434161	425306	14042U	PARTICIPANT	\N	PRESENT	0
434162	425306	14187A	PARTICIPANT	\N	PRESENT	0
434163	425306	04070G	PARTICIPANT	\N	PRESENT	0
434164	425306	88008L	PARTICIPANT	\N	PRESENT	0
434165	425306	99004R	PARTICIPANT	\N	PRESENT	0
434166	425306	14121F	PARTICIPANT	\N	PRESENT	0
434167	425306	14159V	PARTICIPANT	\N	PRESENT	0
434168	425306	19711U	PARTICIPANT	\N	PRESENT	0
434170	425306	14083S	PARTICIPANT	\N	PRESENT	0
434171	425306	14217N	PARTICIPANT	\N	PRESENT	0
434172	425306	19553Y	PARTICIPANT	\N	PRESENT	0
434173	425306	14033T	PARTICIPANT	\N	PRESENT	0
434174	425306	14069U	PARTICIPANT	\N	PRESENT	0
434175	425306	19699S	PARTICIPANT	\N	PRESENT	0
434176	425306	14157T	PARTICIPANT	\N	PRESENT	0
434177	425306	01048V	PARTICIPANT	\N	PRESENT	0
434178	425306	08020N	PARTICIPANT	\N	PRESENT	0
434179	425306	19253P	PARTICIPANT	\N	PRESENT	0
434180	425306	14227Q	PARTICIPANT	\N	PRESENT	0
434181	425306	19545Y	PARTICIPANT	\N	PRESENT	0
434182	425306	19651A	PARTICIPANT	\N	PRESENT	0
434183	425306	19543W	PARTICIPANT	\N	PRESENT	0
434184	425306	08010L	PARTICIPANT	\N	PRESENT	0
434185	425306	07029T	PARTICIPANT	\N	PRESENT	0
434186	425306	19701S	PARTICIPANT	\N	PRESENT	0
447116	445995	19675J	PARTICIPANT	\N	PRESENT	0
447117	445995	01028R	PARTICIPANT	\N	PRESENT	0
447118	445995	05008E	PRESIDENT	0	PRESENT	0
447119	445995	14231L	PARTICIPANT	\N	PRESENT	0
447120	445995	19447X	PARTICIPANT	\N	PRESENT	0
447121	445995	19489J	PARTICIPANT	\N	PRESENT	0
447122	445995	14275Y	PARTICIPANT	\N	PRESENT	0
447123	445995	14147R	PARTICIPANT	\N	PRESENT	0
447124	445995	14179A	PARTICIPANT	\N	PRESENT	0
447125	445995	14151M	PARTICIPANT	\N	PRESENT	0
447126	445995	14215L	PARTICIPANT	\N	PRESENT	0
447127	445995	14259Y	PARTICIPANT	\N	PRESENT	0
447128	445995	11072N	PARTICIPANT	\N	PRESENT	0
447129	445995	98035U	PARTICIPANT	\N	PRESENT	0
447130	445995	14111D	PARTICIPANT	\N	PRESENT	0
447131	445995	14065Q	PARTICIPANT	\N	PRESENT	0
447132	445995	10015M	PARTICIPANT	\N	PRESENT	0
447133	445995	11026G	PARTICIPANT	\N	PRESENT	0
447134	445995	19253P	PARTICIPANT	\N	PRESENT	0
447135	445995	01024M	PARTICIPANT	\N	PRESENT	0
447136	445995	04038G	PARTICIPANT	\N	PRESENT	0
447137	445995	19719D	PARTICIPANT	\N	PRESENT	0
447138	445995	19725B	PARTICIPANT	\N	PRESENT	0
447139	445995	14089Y	PARTICIPANT	\N	PRESENT	0
447140	445995	19729F	PARTICIPANT	\N	PRESENT	0
447141	445995	95063L	PARTICIPANT	\N	PRESENT	0
447142	445995	19629C	PARTICIPANT	\N	PRESENT	0
447143	445995	08044W	PARTICIPANT	\N	PRESENT	0
447144	445995	14069U	PARTICIPANT	\N	PRESENT	0
447145	445995	11049P	PARTICIPANT	\N	PRESENT	0
447146	445995	04008A	PARTICIPANT	\N	PRESENT	0
447147	445995	19762G	PARTICIPANT	\N	PRESENT	0
447148	445995	14021P	PARTICIPANT	\N	PRESENT	0
447149	445995	08045X	PARTICIPANT	\N	EXCUSE	0
447150	445754	12041X	PARTICIPANT	\N	PRESENT	0
447167	445995	08018U	PARTICIPANT	\N	PRESENT	0
447168	445995	14053L	PARTICIPANT	\N	PRESENT	0
447170	445995	11033F	PARTICIPANT	\N	PRESENT	0
447199	445995	04047H	PARTICIPANT	\N	PRESENT	0
447200	445995	11085T	PARTICIPANT	\N	PRESENT	0
447201	446794	19511N	PARTICIPANT	\N	EXCUSE	0
447250	447249	19599P	PARTICIPANT	\N	PRESENT	0
447251	447249	14157T	PARTICIPANT	\N	PRESENT	0
447252	447249	19681G	PARTICIPANT	\N	PRESENT	0
447253	447249	08015R	PARTICIPANT	\N	PRESENT	0
447254	447249	14051J	PARTICIPANT	\N	PRESENT	0
447256	447255	14157T	PARTICIPANT	\N	PRESENT	0
447257	447255	19599P	PARTICIPANT	\N	PRESENT	0
447258	447255	19637C	PARTICIPANT	\N	PRESENT	0
447259	447255	14083S	PARTICIPANT	\N	PRESENT	0
447260	447255	08015R	PARTICIPANT	\N	PRESENT	0
447261	447255	14051J	PARTICIPANT	\N	PRESENT	0
447263	447262	19599P	PARTICIPANT	\N	PRESENT	0
447264	447262	14157T	PARTICIPANT	\N	PRESENT	0
447265	447262	19637C	PARTICIPANT	\N	PRESENT	0
447266	439815	98022P	PARTICIPANT	\N	PRESENT	0
447267	439815	14105F	PARTICIPANT	\N	PRESENT	0
447268	439815	14191V	PARTICIPANT	\N	PRESENT	0
447269	439815	14173T	PARTICIPANT	\N	PRESENT	0
447270	439815	14042U	PARTICIPANT	\N	PRESENT	0
447271	439815	11101A	PARTICIPANT	\N	PRESENT	0
447272	439815	11040E	PARTICIPANT	\N	PRESENT	0
447273	439815	08017T	PARTICIPANT	\N	PRESENT	0
447274	439815	08052W	PARTICIPANT	\N	PRESENT	0
447275	439815	14227Q	PARTICIPANT	\N	PRESENT	0
447276	439815	14063N	PARTICIPANT	\N	PRESENT	0
447277	439815	19387D	PARTICIPANT	\N	PRESENT	0
447278	439815	19820Y	PARTICIPANT	\N	PRESENT	0
447279	439815	11031D	PARTICIPANT	\N	PRESENT	0
447280	439815	19619A	PARTICIPANT	\N	PRESENT	0
447281	439815	19593H	PARTICIPANT	\N	PRESENT	0
447282	439815	08043V	PARTICIPANT	\N	PRESENT	0
447283	439815	14073Q	PARTICIPANT	\N	PRESENT	0
447284	439815	11041F	PARTICIPANT	\N	PRESENT	0
447285	439815	19651A	PARTICIPANT	\N	PRESENT	0
447286	439815	08024S	PARTICIPANT	\N	PRESENT	0
447287	439815	08061X	PARTICIPANT	\N	PRESENT	0
447288	439815	19739H	PARTICIPANT	\N	PRESENT	0
447289	439815	14231L	PARTICIPANT	\N	PRESENT	0
447290	439815	14267Y	PARTICIPANT	\N	PRESENT	0
447291	439815	14039A	PARTICIPANT	\N	PRESENT	0
447292	439815	14277B	PARTICIPANT	\N	PRESENT	0
447293	439815	11066Q	PARTICIPANT	\N	PRESENT	0
447294	439815	19251M	PARTICIPANT	\N	PRESENT	0
447295	439815	19725B	PARTICIPANT	\N	PRESENT	0
447296	439815	95037J	PARTICIPANT	\N	PRESENT	0
447297	439815	14107H	PARTICIPANT	\N	PRESENT	0
447298	439815	19631V	PARTICIPANT	\N	PRESENT	0
447299	439815	08012N	PARTICIPANT	\N	PRESENT	0
447300	439815	11064N	PARTICIPANT	\N	PRESENT	0
447301	439815	19549D	PARTICIPANT	\N	PRESENT	0
447302	439815	19319Q	PARTICIPANT	\N	PRESENT	0
447303	439815	11067R	PARTICIPANT	\N	PRESENT	0
447304	439815	80013X	PARTICIPANT	\N	PRESENT	0
447305	439815	98035U	PARTICIPANT	\N	PRESENT	0
447306	439815	19575F	PARTICIPANT	\N	PRESENT	0
447307	439815	07033P	PARTICIPANT	\N	PRESENT	0
447308	439815	01060R	PARTICIPANT	\N	PRESENT	0
447309	439815	19731Y	PARTICIPANT	\N	PRESENT	0
447310	439815	14059S	PARTICIPANT	\N	PRESENT	0
447311	439815	19812Y	PARTICIPANT	\N	PRESENT	0
447312	439815	14151M	PARTICIPANT	\N	PRESENT	0
447314	439815	08060W	PARTICIPANT	\N	PRESENT	0
447315	439815	08035V	PARTICIPANT	\N	PRESENT	0
447316	439815	11110B	PARTICIPANT	\N	PRESENT	0
447317	439815	14239U	PARTICIPANT	\N	PRESENT	0
447318	439815	11083R	PARTICIPANT	\N	PRESENT	0
447319	439815	19782L	PARTICIPANT	\N	PRESENT	0
447320	439815	11056N	PARTICIPANT	\N	PRESENT	0
447321	439815	19695N	PARTICIPANT	\N	PRESENT	0
447322	439815	17779H	PARTICIPANT	\N	PRESENT	0
447323	439815	19441R	PARTICIPANT	\N	PRESENT	0
447324	439815	19721W	PARTICIPANT	\N	PRESENT	0
447328	439815	04038G	PARTICIPANT	\N	PRESENT	0
447326	439815	19479G	PARTICIPANT	\N	PRESENT	0
447327	439815	16685X	PARTICIPANT	\N	PRESENT	0
447329	439815	14235Q	PARTICIPANT	\N	PRESENT	0
447330	439815	19760E	PARTICIPANT	\N	PRESENT	0
447331	439815	19565D	PARTICIPANT	\N	PRESENT	0
447332	439815	04034C	PARTICIPANT	\N	PRESENT	0
447333	439815	19711U	PARTICIPANT	\N	PRESENT	0
447334	439815	19349W	PARTICIPANT	\N	PRESENT	0
447335	439815	19697Q	PARTICIPANT	\N	PRESENT	0
447336	439815	04008A	PARTICIPANT	\N	PRESENT	0
447337	439815	19301E	PARTICIPANT	\N	PRESENT	0
447338	439815	14211G	PARTICIPANT	\N	PRESENT	0
447339	439815	19685L	PARTICIPANT	\N	PRESENT	0
447340	439815	89017R	PARTICIPANT	\N	PRESENT	0
447341	439815	08056B	PARTICIPANT	\N	PRESENT	0
447342	439815	98018T	PARTICIPANT	\N	PRESENT	0
447343	439815	11012A	PARTICIPANT	\N	PRESENT	0
447344	439815	08031R	PARTICIPANT	\N	PRESENT	0
447345	439815	14157T	PARTICIPANT	\N	PRESENT	0
447346	439815	14034U	PARTICIPANT	\N	PRESENT	0
447347	439815	88008L	PARTICIPANT	\N	PRESENT	0
447348	439815	92040Q	PARTICIPANT	\N	PRESENT	0
447349	439815	14261S	PARTICIPANT	\N	PRESENT	0
447350	439815	14201E	PARTICIPANT	\N	PRESENT	0
447351	439815	96004D	PARTICIPANT	\N	PRESENT	0
447352	439815	98029W	PARTICIPANT	\N	PRESENT	0
447353	439815	14241N	PARTICIPANT	\N	PRESENT	0
447354	439815	01058X	PARTICIPANT	\N	PRESENT	0
447355	439815	08073C	PARTICIPANT	\N	PRESENT	0
447356	439815	11065P	PARTICIPANT	\N	PRESENT	0
447357	439815	99004R	PARTICIPANT	\N	PRESENT	0
447358	439815	19681G	PARTICIPANT	\N	PRESENT	0
447359	439815	14207L	PARTICIPANT	\N	PRESENT	0
447360	439815	19553Y	PARTICIPANT	\N	PRESENT	0
447361	439815	04097T	PARTICIPANT	\N	PRESENT	0
447362	439815	08069G	PARTICIPANT	\N	PRESENT	0
447363	439815	04057K	PARTICIPANT	\N	PRESENT	0
447364	439815	14251Q	PARTICIPANT	\N	PRESENT	0
447365	439815	19585H	PARTICIPANT	\N	PRESENT	0
447366	439815	15447F	PARTICIPANT	\N	PRESENT	0
447367	439815	14169X	PARTICIPANT	\N	PRESENT	0
447368	439815	14223L	PARTICIPANT	\N	PRESENT	0
447369	439815	10015M	PARTICIPANT	\N	PRESENT	0
447370	439815	11109J	PARTICIPANT	\N	PRESENT	0
447371	439815	11043H	PARTICIPANT	\N	PRESENT	0
447372	439815	04059M	PARTICIPANT	\N	PRESENT	0
447373	439815	11027H	PARTICIPANT	\N	PRESENT	0
447374	439815	08028W	PARTICIPANT	\N	PRESENT	0
447375	439815	14111D	PARTICIPANT	\N	PRESENT	0
447376	439815	19515S	PARTICIPANT	\N	PRESENT	0
447377	439815	95063L	PARTICIPANT	\N	PRESENT	0
447378	439815	14229S	PARTICIPANT	\N	PRESENT	0
447379	439815	01057W	PARTICIPANT	\N	PRESENT	0
447380	439815	11090Q	PARTICIPANT	\N	PRESENT	0
424977	424976	19667J	PARTICIPANT	\N	PRESENT	0
425004	425003	04045F	PARTICIPANT	\N	PRESENT	0
425008	425007	11027H	PARTICIPANT	\N	PRESENT	0
425018	425014	11064N	PARTICIPANT	\N	PRESENT	0
425021	425014	11054L	PARTICIPANT	\N	PRESENT	0
425036	425028	11064N	PARTICIPANT	\N	PRESENT	0
425037	425028	11054L	PARTICIPANT	\N	PRESENT	0
425226	425225	19711U	PARTICIPANT	\N	PRESENT	0
425228	425227	08011M	PARTICIPANT	\N	PRESENT	0
425230	425229	11053K	PARTICIPANT	\N	PRESENT	0
425232	425231	14034U	PARTICIPANT	\N	PRESENT	0
425236	425235	88008L	PARTICIPANT	\N	PRESENT	0
425237	425235	11012A	PARTICIPANT	\N	PRESENT	0
425242	425241	88008L	PARTICIPANT	\N	PRESENT	0
425243	425241	11012A	PARTICIPANT	\N	PRESENT	0
425245	425244	08011M	PARTICIPANT	\N	PRESENT	0
425248	425247	11048N	PARTICIPANT	\N	PRESENT	0
425250	425249	11048N	PARTICIPANT	\N	PRESENT	0
425252	425251	11048N	PARTICIPANT	\N	PRESENT	0
425267	425266	08011M	PARTICIPANT	\N	PRESENT	0
425269	425268	11048N	PARTICIPANT	\N	PRESENT	0
425274	425273	99004R	PARTICIPANT	\N	PRESENT	0
425278	425277	08011M	PARTICIPANT	\N	PRESENT	0
425289	425286	11074Q	PARTICIPANT	\N	PRESENT	0
425290	425286	08011M	PARTICIPANT	\N	PRESENT	0
425291	425286	11048N	PARTICIPANT	\N	PRESENT	0
425292	425286	01057W	PARTICIPANT	\N	PRESENT	0
425298	425296	19545Y	PARTICIPANT	\N	PRESENT	0
425299	425296	19689Q	PARTICIPANT	\N	PRESENT	0
425302	425301	19545Y	PARTICIPANT	\N	PRESENT	0
425304	425301	19689Q	PARTICIPANT	\N	PRESENT	0
425309	425308	08011M	PARTICIPANT	\N	PRESENT	0
427657	427656	01024M	PARTICIPANT	\N	PRESENT	0
437898	437897	19447X	PARTICIPANT	\N	PRESENT	0
437899	437897	14147R	PARTICIPANT	\N	PRESENT	0
440647	439795	14133K	PARTICIPANT	\N	PRESENT	0
440649	439795	08058D	PARTICIPANT	\N	PRESENT	0
440650	439795	04042C	PRESIDENT	0	PRESENT	0
440651	439795	19721W	PARTICIPANT	\N	PRESENT	0
440652	439795	98029W	PARTICIPANT	\N	PRESENT	0
440654	439795	11027H	PARTICIPANT	\N	PRESENT	0
440655	439795	14079W	PARTICIPANT	\N	PRESENT	0
440656	439795	95030B	PARTICIPANT	\N	PRESENT	0
440657	439795	97011G	PARTICIPANT	\N	PRESENT	0
440658	439795	04035D	PARTICIPANT	\N	PRESENT	0
440659	439795	08056B	PARTICIPANT	\N	PRESENT	0
440660	439795	11064N	PARTICIPANT	\N	PRESENT	0
440661	439795	95037J	PARTICIPANT	\N	PRESENT	0
440662	439795	14097Y	PARTICIPANT	\N	PRESENT	0
440663	439795	12041X	PARTICIPANT	\N	PRESENT	0
440664	439795	16685X	PARTICIPANT	\N	PRESENT	0
440665	439795	08053X	PARTICIPANT	\N	PRESENT	0
440666	439795	08061X	PARTICIPANT	\N	PRESENT	0
440667	439795	08047A	PARTICIPANT	\N	PRESENT	0
440668	439795	14028W	PARTICIPANT	\N	PRESENT	0
440669	439795	14193X	PARTICIPANT	\N	PRESENT	0
440670	439795	19319Q	PARTICIPANT	\N	PRESENT	0
440671	439795	98050T	PARTICIPANT	\N	PRESENT	0
440672	439795	19443T	PARTICIPANT	\N	PRESENT	0
440673	439795	11054L	PARTICIPANT	\N	PRESENT	0
440674	439795	01058X	PARTICIPANT	\N	PRESENT	0
440675	439795	01062T	PARTICIPANT	\N	PRESENT	0
440676	439795	11041F	PARTICIPANT	\N	PRESENT	0
440677	439795	11066Q	PARTICIPANT	\N	PRESENT	0
440678	439795	95067Q	PARTICIPANT	\N	PRESENT	0
440679	439795	04034C	PARTICIPANT	\N	PRESENT	0
440680	439795	04040A	PARTICIPANT	\N	PRESENT	0
445103	445098	19768N	PARTICIPANT	\N	PRESENT	0
445117	445116	04008A	PARTICIPANT	\N	PRESENT	0
445119	445118	04008A	PARTICIPANT	\N	PRESENT	0
445138	445136	08055A	PARTICIPANT	\N	PRESENT	0
445139	445136	19782L	PARTICIPANT	\N	PRESENT	0
445142	445136	11103C	PARTICIPANT	\N	PRESENT	0
445144	445136	14329V	PARTICIPANT	\N	PRESENT	0
445146	445136	19812Y	PARTICIPANT	\N	PRESENT	0
445148	445136	87003B	PARTICIPANT	\N	PRESENT	0
445150	445136	14187A	PARTICIPANT	\N	PRESENT	0
445152	445136	14103D	PARTICIPANT	\N	PRESENT	0
445154	445136	08053X	PARTICIPANT	\N	PRESENT	0
445156	445136	19739H	PARTICIPANT	\N	PRESENT	0
445157	445136	19679N	PARTICIPANT	\N	PRESENT	0
445158	445136	14107H	PARTICIPANT	\N	PRESENT	0
448679	439820	19447X	PARTICIPANT	\N	PRESENT	0
448680	439820	04085P	PARTICIPANT	\N	PRESENT	0
448681	439820	12041X	PARTICIPANT	\N	PRESENT	0
448682	439820	11031D	PARTICIPANT	\N	PRESENT	0
448683	439820	19565D	PARTICIPANT	\N	PRESENT	0
448684	439820	19649G	PARTICIPANT	\N	PRESENT	0
448677	439820	11070L	PARTICIPANT	\N	PRESENT	0
448678	439820	04092N	PARTICIPANT	\N	PRESENT	0
448685	439820	11026G	PARTICIPANT	\N	PRESENT	0
448686	439820	19333N	PARTICIPANT	\N	PRESENT	0
448687	439820	19301E	PARTICIPANT	\N	PRESENT	0
448688	439820	19651A	PARTICIPANT	\N	PRESENT	0
448689	439820	11012A	PARTICIPANT	\N	PRESENT	0
448690	439820	19553Y	PARTICIPANT	\N	PRESENT	0
448691	439820	14042U	PARTICIPANT	\N	PRESENT	0
448692	439820	19569H	PARTICIPANT	\N	PRESENT	0
448693	439820	19671E	PARTICIPANT	\N	PRESENT	0
448694	439820	04033B	PARTICIPANT	\N	PRESENT	0
448695	439820	19711U	PARTICIPANT	\N	PRESENT	0
448696	439820	08034U	PARTICIPANT	\N	PRESENT	0
448697	439820	05008E	PARTICIPANT	\N	PRESENT	0
448698	439820	11097X	PARTICIPANT	\N	PRESENT	0
448699	439820	01024M	PARTICIPANT	\N	PRESENT	0
448700	439820	98024R	PARTICIPANT	\N	PRESENT	0
448701	439820	99004R	PARTICIPANT	\N	PRESENT	0
448702	439820	19683J	PARTICIPANT	\N	PRESENT	0
448703	439820	14065Q	PARTICIPANT	\N	PRESENT	0
448704	439820	14195A	PARTICIPANT	\N	PRESENT	0
448705	439820	14257W	PARTICIPANT	\N	PRESENT	0
448706	439820	19347U	PARTICIPANT	\N	PRESENT	0
448707	439820	11033F	PARTICIPANT	\N	PRESENT	0
448708	439820	14179A	PARTICIPANT	\N	PRESENT	0
448709	439820	14213J	PARTICIPANT	\N	PRESENT	0
448710	439820	08069G	PARTICIPANT	\N	PRESENT	0
448711	439820	10006L	PARTICIPANT	\N	PRESENT	0
448712	439820	11045K	PARTICIPANT	\N	PRESENT	0
448713	439820	19663E	PARTICIPANT	\N	PRESENT	0
448714	439820	19693L	PARTICIPANT	\N	PRESENT	0
448715	439820	11099A	PARTICIPANT	\N	PRESENT	0
448716	439820	11074Q	PARTICIPANT	\N	PRESENT	0
450803	450802	11115U	PARTICIPANT	\N	PRESENT	0
450804	450802	11041F	PARTICIPANT	\N	PRESENT	0
450807	450806	11115U	PARTICIPANT	\N	PRESENT	0
450808	450806	11041F	PARTICIPANT	\N	PRESENT	0
450993	445946	08012N	PARTICIPANT	\N	EXCUSE	0
451808	445946	19467C	PARTICIPANT	\N	PRESENT	0
451817	445946	19629C	PARTICIPANT	\N	EXCUSE	0
451919	443730	08024S	PARTICIPANT	\N	PRESENT	0
451920	443730	08045X	PARTICIPANT	\N	PRESENT	0
451921	448634	08024S	PARTICIPANT	\N	PRESENT	0
452048	452047	14041T	PARTICIPANT	\N	PRESENT	0
452049	452047	98035U	PARTICIPANT	\N	PRESENT	0
452050	452047	07033P	PARTICIPANT	\N	PRESENT	0
452051	452047	04049K	PARTICIPANT	\N	PRESENT	0
452052	452047	14133K	PARTICIPANT	\N	PRESENT	0
452053	452047	14097Y	PARTICIPANT	\N	PRESENT	0
452054	452047	19333N	PARTICIPANT	\N	PRESENT	0
452055	452047	14215L	PARTICIPANT	\N	PRESENT	0
452056	452047	14147R	PARTICIPANT	\N	PRESENT	0
452057	452047	19731Y	PARTICIPANT	\N	PRESENT	0
452058	452047	14151M	PARTICIPANT	\N	PRESENT	0
452059	452047	14061L	PARTICIPANT	\N	PRESENT	0
452060	452047	14265W	PARTICIPANT	\N	PRESENT	0
453527	448740	04059M	PARTICIPANT	\N	PRESENT	0
453528	448740	19695N	PARTICIPANT	\N	PRESENT	0
453529	448740	19593H	PARTICIPANT	\N	PRESENT	0
453530	448740	11056N	PARTICIPANT	\N	PRESENT	0
453531	448740	04085P	PARTICIPANT	\N	PRESENT	0
453532	448740	19619A	PARTICIPANT	\N	PRESENT	0
453533	448740	19637C	PARTICIPANT	\N	PRESENT	0
453534	448740	19563B	PARTICIPANT	\N	PRESENT	0
453535	448740	19369B	PARTICIPANT	\N	PRESENT	0
453536	448740	11012A	PARTICIPANT	\N	PRESENT	0
453537	448740	19671E	PARTICIPANT	\N	PRESENT	0
453538	448740	19399H	PARTICIPANT	\N	PRESENT	0
453539	448740	14033T	PARTICIPANT	\N	PRESENT	0
453540	448740	19441R	PARTICIPANT	\N	PRESENT	0
453541	448740	11048N	PARTICIPANT	\N	PRESENT	0
453542	448740	11040E	PARTICIPANT	\N	PRESENT	0
453543	448740	80013X	PARTICIPANT	\N	PRESENT	0
453544	448740	19565D	PARTICIPANT	\N	PRESENT	0
453545	448740	18083K	PARTICIPANT	\N	PRESENT	0
453546	448740	14021P	PARTICIPANT	\N	PRESENT	0
453551	448740	14133K	PARTICIPANT	\N	PRESENT	0
453556	448740	14215L	PARTICIPANT	\N	PRESENT	0
453557	448740	14237S	PARTICIPANT	\N	PRESENT	0
442814	441310	19760E	PARTICIPANT	\N	PRESENT	0
442815	441310	08041T	PARTICIPANT	\N	EXCUSE	0
442816	441700	11074Q	PRESIDENT	1	PRESENT	0
442826	441310	19715Y	PARTICIPANT	\N	PRESENT	0
442827	441310	11067R	PARTICIPANT	\N	EXCUSE	0
442828	441310	19691J	PARTICIPANT	\N	EXCUSE	0
442831	442830	19549D	PARTICIPANT	\N	PRESENT	0
442832	442830	14038Y	PARTICIPANT	\N	PRESENT	0
442833	442830	18083K	PARTICIPANT	\N	PRESENT	0
442834	442830	19701S	PARTICIPANT	\N	PRESENT	0
442835	442830	19387D	PARTICIPANT	\N	PRESENT	0
442836	442830	19347U	PARTICIPANT	\N	PRESENT	0
442837	442830	14205J	PARTICIPANT	\N	PRESENT	0
442838	442830	14031R	PARTICIPANT	\N	PRESENT	0
443010	439637	19731Y	PARTICIPANT	\N	PRESENT	0
442840	442830	08009T	PRESIDENT	0	PRESENT	0
442841	442830	14169X	PARTICIPANT	\N	PRESENT	0
442842	442830	19503N	PARTICIPANT	\N	PRESENT	0
442843	442830	19794Q	PARTICIPANT	\N	PRESENT	0
443011	439637	19543W	PARTICIPANT	\N	PRESENT	0
443012	439637	19782L	PARTICIPANT	\N	PRESENT	0
443013	439637	98029W	PARTICIPANT	\N	PRESENT	0
443014	439637	11083R	PARTICIPANT	\N	PRESENT	0
443015	439637	04034C	PARTICIPANT	\N	PRESENT	0
443016	439637	08061X	PARTICIPANT	\N	PRESENT	0
443017	439637	19349W	PARTICIPANT	\N	PRESENT	0
443018	439637	11072N	PARTICIPANT	\N	PRESENT	0
443019	439637	19697Q	PARTICIPANT	\N	PRESENT	0
443020	439637	19591F	PARTICIPANT	\N	PRESENT	0
443021	439637	19717B	PARTICIPANT	\N	PRESENT	0
443022	439637	14207L	PARTICIPANT	\N	PRESENT	0
443023	439637	88008L	PARTICIPANT	\N	PRESENT	0
443024	439637	19681G	PARTICIPANT	\N	PRESENT	0
443025	439637	19253P	PARTICIPANT	\N	PRESENT	0
443026	439637	11065P	PARTICIPANT	\N	PRESENT	0
443027	439637	11099A	PARTICIPANT	\N	PRESENT	0
443028	439637	14241N	PARTICIPANT	\N	PRESENT	0
443029	439637	14121F	PARTICIPANT	\N	PRESENT	0
443030	439637	19575F	PARTICIPANT	\N	PRESENT	0
443031	439637	14034U	PARTICIPANT	\N	PRESENT	0
443032	439637	19387D	PARTICIPANT	\N	PRESENT	0
443033	439637	98022P	PARTICIPANT	\N	PRESENT	0
443034	439637	19553Y	PARTICIPANT	\N	PRESENT	0
443035	439637	08031R	PARTICIPANT	\N	PRESENT	0
443036	439637	14169X	PARTICIPANT	\N	PRESENT	0
443037	439637	19289C	PARTICIPANT	\N	PRESENT	0
443038	439637	11012A	PARTICIPANT	\N	PRESENT	0
443039	439637	08049C	PARTICIPANT	\N	PRESENT	0
443040	439637	14107H	PARTICIPANT	\N	PRESENT	0
443041	439637	14093U	PARTICIPANT	\N	PRESENT	0
443042	439637	14195A	PARTICIPANT	\N	PRESENT	0
443043	439637	19693L	PARTICIPANT	\N	PRESENT	0
443044	439637	02002K	PARTICIPANT	\N	PRESENT	0
443045	439637	17589D	PARTICIPANT	\N	PRESENT	0
443046	439637	14251Q	PARTICIPANT	\N	PRESENT	0
443047	439637	14111D	PARTICIPANT	\N	PRESENT	0
443048	439637	04057K	PARTICIPANT	\N	PRESENT	0
443049	439637	19563B	PARTICIPANT	\N	PRESENT	0
443050	439637	19585H	PARTICIPANT	\N	PRESENT	0
443051	439637	19631V	PARTICIPANT	\N	PRESENT	0
443052	439637	04059M	PARTICIPANT	\N	PRESENT	0
443053	439637	14065Q	PARTICIPANT	\N	PRESENT	0
443054	439637	08055A	PARTICIPANT	\N	PRESENT	0
443055	439637	19549D	PARTICIPANT	\N	PRESENT	0
443056	439637	08043V	PARTICIPANT	\N	PRESENT	0
443057	439637	08060W	PARTICIPANT	\N	PRESENT	0
443058	439637	08014Q	PARTICIPANT	\N	PRESENT	0
443059	439637	11027H	PARTICIPANT	\N	PRESENT	0
443060	439637	80013X	PARTICIPANT	\N	PRESENT	0
443061	439637	19525U	PARTICIPANT	\N	PRESENT	0
443062	439637	08052W	PARTICIPANT	\N	PRESENT	0
443063	439637	08038Y	PARTICIPANT	\N	PRESENT	0
443064	439637	19251M	PARTICIPANT	\N	PRESENT	0
443065	439637	14151M	PARTICIPANT	\N	PRESENT	0
443066	439637	14197C	PARTICIPANT	\N	PRESENT	0
443067	439637	11074Q	PARTICIPANT	\N	PRESENT	0
443068	439637	19647E	PARTICIPANT	\N	PRESENT	0
443069	439637	14281W	PARTICIPANT	\N	PRESENT	0
443070	439637	08045X	PARTICIPANT	\N	PRESENT	0
443071	439637	19820Y	PARTICIPANT	\N	PRESENT	0
443072	439637	19649G	PARTICIPANT	\N	PRESENT	0
443073	439637	19727D	PARTICIPANT	\N	PRESENT	0
443074	439637	14081Q	PARTICIPANT	\N	PRESENT	0
443075	439637	19725B	PARTICIPANT	\N	PRESENT	0
443076	439637	19551W	PARTICIPANT	\N	PRESENT	0
443077	439637	19715Y	PARTICIPANT	\N	PRESENT	0
443078	439637	19531S	PARTICIPANT	\N	PRESENT	0
443079	439637	19683J	PARTICIPANT	\N	PRESENT	0
443080	439637	14021P	PARTICIPANT	\N	PRESENT	0
443081	439637	19507S	PARTICIPANT	\N	PRESENT	0
443082	439637	19489J	PARTICIPANT	\N	PRESENT	0
443083	439637	14249W	PARTICIPANT	\N	PRESENT	0
443084	439637	11026G	PARTICIPANT	\N	PRESENT	0
443085	439637	08017T	PARTICIPANT	\N	PRESENT	0
443086	439637	08012N	PARTICIPANT	\N	PRESENT	0
443087	439637	11109J	PARTICIPANT	\N	PRESENT	0
443088	439637	11104D	PARTICIPANT	\N	PRESENT	0
443089	439637	17779H	PARTICIPANT	\N	PRESENT	0
443090	439637	14063N	PARTICIPANT	\N	PRESENT	0
443091	439637	14001X	PARTICIPANT	\N	PRESENT	0
443092	439637	14028W	PARTICIPANT	\N	PRESENT	0
443093	439637	14257W	PARTICIPANT	\N	PRESENT	0
443094	439637	19503N	PARTICIPANT	\N	PRESENT	0
443095	439637	14225N	PARTICIPANT	\N	PRESENT	0
443096	439637	14229S	PARTICIPANT	\N	PRESENT	0
443097	439637	14069U	PARTICIPANT	\N	PRESENT	0
443098	439637	11054L	PARTICIPANT	\N	PRESENT	0
443099	439637	11045K	PARTICIPANT	\N	PRESENT	0
443100	439637	01028R	PARTICIPANT	\N	PRESENT	0
443101	439637	98035U	PARTICIPANT	\N	PRESENT	0
443102	439637	19689Q	PARTICIPANT	\N	PRESENT	0
443103	439637	19669L	PARTICIPANT	\N	PRESENT	0
443104	439637	19413M	PARTICIPANT	\N	PRESENT	0
443105	439637	14051J	PARTICIPANT	\N	PRESENT	0
443106	439637	01062T	PARTICIPANT	\N	PRESENT	0
443107	439637	11041F	PARTICIPANT	\N	PRESENT	0
443108	439637	14227Q	PARTICIPANT	\N	PRESENT	0
443109	439637	19527W	PARTICIPANT	\N	PRESENT	0
443110	439637	11066Q	PARTICIPANT	\N	PRESENT	0
443111	439637	14030Q	PARTICIPANT	\N	PRESENT	0
443112	439637	04040A	PARTICIPANT	\N	PRESENT	0
443113	439637	14089Y	PARTICIPANT	\N	PRESENT	0
443114	439637	14255U	PARTICIPANT	\N	PRESENT	0
443115	439637	14083S	PARTICIPANT	\N	PRESENT	0
443116	439637	11053K	PARTICIPANT	\N	PRESENT	0
443117	439637	19721W	PARTICIPANT	\N	PRESENT	0
443118	439637	14267Y	PARTICIPANT	\N	PRESENT	0
443119	439637	11070L	PARTICIPANT	\N	PRESENT	0
443120	439637	14327T	PARTICIPANT	\N	PRESENT	0
443121	439637	01024M	PARTICIPANT	\N	PRESENT	0
443122	439637	14042U	PARTICIPANT	\N	PRESENT	0
443123	439637	19521Q	PARTICIPANT	\N	PRESENT	0
443124	439637	92040Q	PARTICIPANT	\N	PRESENT	0
443125	439637	14231L	PARTICIPANT	\N	PRESENT	0
443126	439637	07004J	PARTICIPANT	\N	PRESENT	0
443127	439637	19569H	PARTICIPANT	\N	PRESENT	0
443128	439637	14179A	PARTICIPANT	\N	PRESENT	0
443129	439637	08044W	PARTICIPANT	\N	PRESENT	0
443130	439637	19611R	PARTICIPANT	\N	PRESENT	0
443131	439637	19699S	PARTICIPANT	\N	PRESENT	0
443132	439637	14205J	PARTICIPANT	\N	PRESENT	0
443133	439637	01043Q	PARTICIPANT	\N	PRESENT	0
443134	439637	14219Q	PARTICIPANT	\N	PRESENT	0
443135	439637	19441R	PARTICIPANT	\N	PRESENT	0
443136	439637	16685X	PARTICIPANT	\N	PRESENT	0
443137	439637	11085T	PARTICIPANT	\N	PRESENT	0
443138	439637	19826F	PARTICIPANT	\N	PRESENT	0
443139	439637	08009T	PARTICIPANT	\N	PRESENT	0
443140	439637	14221J	PARTICIPANT	\N	PRESENT	0
443141	439637	19335Q	PARTICIPANT	\N	PRESENT	0
443142	439637	19369B	PARTICIPANT	\N	PRESENT	0
443143	439637	04070G	PARTICIPANT	\N	PRESENT	0
443144	439637	19479G	PARTICIPANT	\N	PRESENT	0
443145	439637	19737F	PARTICIPANT	\N	PRESENT	0
443146	439637	19749K	PARTICIPANT	\N	PRESENT	0
443147	439637	89017R	PARTICIPANT	\N	PRESENT	0
443148	439637	04071H	PARTICIPANT	\N	PRESENT	0
443149	439637	19581D	PARTICIPANT	\N	PRESENT	0
443150	439637	14123H	PARTICIPANT	\N	PRESENT	0
443151	439637	14135M	PARTICIPANT	\N	PRESENT	0
443152	439637	14109K	PARTICIPANT	\N	PRESENT	0
443158	439637	95063L	PARTICIPANT	\N	PRESENT	0
443154	439637	19739H	PARTICIPANT	\N	PRESENT	0
443156	439637	19701S	PARTICIPANT	\N	PRESENT	0
443157	443155	04008A	PARTICIPANT	\N	PRESENT	0
424917	424899	19631V	PARTICIPANT	\N	PRESENT	0
424918	424899	08049C	PARTICIPANT	\N	PRESENT	0
424915	424899	14083S	PARTICIPANT	\N	PRESENT	0
424916	424899	14026U	PARTICIPANT	\N	PRESENT	0
424919	424899	14038Y	PARTICIPANT	\N	PRESENT	0
424985	422594	14093U	PARTICIPANT	\N	PRESENT	0
424986	422594	19826F	PARTICIPANT	\N	PRESENT	0
424987	422594	14026U	PARTICIPANT	\N	PRESENT	0
424988	422594	08024S	PARTICIPANT	\N	PRESENT	0
425027	414419	19711U	PARTICIPANT	\N	PRESENT	0
425046	414419	11066Q	PARTICIPANT	\N	PRESENT	0
425048	414419	11097X	PARTICIPANT	\N	EXCUSE	0
425084	414419	01028R	PARTICIPANT	\N	EXCUSE	0
427653	416329	11072N	PARTICIPANT	\N	PRESENT	0
427654	416329	04092N	PARTICIPANT	\N	PRESENT	0
427655	416329	01034P	PARTICIPANT	\N	PRESENT	0
427658	427428	19593H	PARTICIPANT	\N	PRESENT	0
427659	427428	14039A	PARTICIPANT	\N	PRESENT	0
427660	427428	19611R	PARTICIPANT	\N	PRESENT	0
427661	427428	14123H	PARTICIPANT	\N	PRESENT	0
427662	427428	19399H	PARTICIPANT	\N	PRESENT	0
427663	427428	19621T	PRESIDENT	0	PRESENT	0
427664	427428	14251Q	PARTICIPANT	\N	PRESENT	0
427665	427428	04018C	PARTICIPANT	\N	PRESENT	0
427666	416329	19565D	PARTICIPANT	\N	PRESENT	0
427667	416329	14227Q	PARTICIPANT	\N	PRESENT	0
427668	416329	19295A	PARTICIPANT	\N	PRESENT	0
427669	416329	19683J	PARTICIPANT	\N	PRESENT	0
427670	416329	11067R	PARTICIPANT	\N	PRESENT	0
427671	416329	08055A	PARTICIPANT	\N	PRESENT	0
427672	416329	08052W	PARTICIPANT	\N	PRESENT	0
427673	416329	14041T	PARTICIPANT	\N	PRESENT	0
427674	416329	14042U	PARTICIPANT	\N	PRESENT	0
427675	416329	19569H	PARTICIPANT	\N	PRESENT	0
427676	416329	19575F	PARTICIPANT	\N	PRESENT	0
427684	416329	14195A	PARTICIPANT	\N	PRESENT	0
427678	416329	19679N	PARTICIPANT	\N	PRESENT	0
427679	416329	19691J	PARTICIPANT	\N	PRESENT	0
427680	416329	19387D	PARTICIPANT	\N	PRESENT	0
427681	416329	19719D	PARTICIPANT	\N	PRESENT	0
427682	416329	07004J	PARTICIPANT	\N	PRESENT	0
427683	416329	08015R	PARTICIPANT	\N	PRESENT	0
427685	427428	04070G	PRESIDENT	1	PRESENT	0
427686	427428	14061L	PARTICIPANT	\N	EXCUSE	0
427687	427428	14107H	PARTICIPANT	\N	EXCUSE	0
427688	416329	11045K	PARTICIPANT	\N	PRESENT	0
427689	416329	98024R	PARTICIPANT	\N	PRESENT	0
427690	416329	19415P	PARTICIPANT	\N	PRESENT	0
427691	416329	19711U	PARTICIPANT	\N	PRESENT	0
427692	416329	11103C	PARTICIPANT	\N	PRESENT	0
427693	416329	19727D	PARTICIPANT	\N	PRESENT	0
427694	416329	11097X	PARTICIPANT	\N	PRESENT	0
427695	416329	04045F	PARTICIPANT	\N	PRESENT	0
427696	416329	15447F	PARTICIPANT	\N	PRESENT	0
427697	416329	19349W	PARTICIPANT	\N	PRESENT	0
427698	416329	14239U	PARTICIPANT	\N	PRESENT	0
427699	416329	19697Q	PARTICIPANT	\N	PRESENT	0
427700	416329	14026U	PARTICIPANT	\N	PRESENT	0
427701	427428	11104D	PARTICIPANT	\N	PRESENT	0
427702	427428	19693L	PARTICIPANT	\N	PRESENT	0
427703	427428	19758L	PARTICIPANT	\N	PRESENT	0
427704	427428	14030Q	PARTICIPANT	\N	PRESENT	0
427705	416329	11031D	PARTICIPANT	\N	PRESENT	0
427706	416329	10006L	PARTICIPANT	\N	PRESENT	0
427707	416329	19367Y	PARTICIPANT	\N	PRESENT	0
427712	416329	11066Q	PARTICIPANT	\N	PRESENT	0
427709	416329	19521Q	PARTICIPANT	\N	PRESENT	0
427710	416329	19798U	PARTICIPANT	\N	PRESENT	0
427711	416329	89017R	PARTICIPANT	\N	PRESENT	0
427713	416329	19583F	PARTICIPANT	\N	PRESENT	0
427714	427428	04057K	PARTICIPANT	\N	PRESENT	0
427715	427428	08043V	PARTICIPANT	\N	PRESENT	0
427716	427428	14241N	PARTICIPANT	\N	PRESENT	0
427717	427428	08020N	PARTICIPANT	\N	PRESENT	0
427718	427428	08017T	PARTICIPANT	\N	PRESENT	0
427719	427428	19335Q	PARTICIPANT	\N	PRESENT	0
427720	427428	08031R	PARTICIPANT	\N	PRESENT	0
427721	416329	19553Y	PARTICIPANT	\N	PRESENT	0
427722	416329	14217N	PARTICIPANT	\N	PRESENT	0
428004	416333	14026U	PARTICIPANT	\N	PRESENT	0
428005	416333	14105F	PARTICIPANT	\N	PRESENT	0
428006	416333	14157T	PARTICIPANT	\N	PRESENT	0
428007	425133	07029T	PARTICIPANT	\N	PRESENT	0
428008	416333	14033T	PARTICIPANT	\N	PRESENT	0
428009	416333	15447F	PARTICIPANT	\N	PRESENT	0
428010	416333	19679N	PARTICIPANT	\N	PRESENT	0
434189	425306	11026G	PARTICIPANT	\N	PRESENT	0
428012	416333	14223L	PARTICIPANT	\N	PRESENT	0
428013	416333	19301E	PARTICIPANT	\N	PRESENT	0
428014	416333	04045F	PARTICIPANT	\N	PRESENT	0
428015	416333	14227Q	PARTICIPANT	\N	PRESENT	0
428016	416333	11067R	PARTICIPANT	\N	PRESENT	0
428017	416333	14042U	PARTICIPANT	\N	PRESENT	0
428018	416333	14061L	PARTICIPANT	\N	PRESENT	0
428019	416333	19575F	PARTICIPANT	\N	PRESENT	0
428020	416333	08015R	PARTICIPANT	\N	PRESENT	0
428021	425133	08010L	PARTICIPANT	\N	PRESENT	0
428022	416333	08056B	PARTICIPANT	\N	PRESENT	0
428023	425133	11074Q	PRESIDENT	1	PRESENT	0
428024	425133	08014Q	PARTICIPANT	\N	PRESENT	0
428025	416333	19723Y	PARTICIPANT	\N	PRESENT	0
428026	416333	11097X	PARTICIPANT	\N	PRESENT	0
428027	416333	19415P	PARTICIPANT	\N	PRESENT	0
428028	416333	14121F	PARTICIPANT	\N	PRESENT	0
428029	425133	19531S	PARTICIPANT	\N	PRESENT	0
428030	416333	04034C	PARTICIPANT	\N	PRESENT	0
428031	425133	19479G	PARTICIPANT	\N	PRESENT	0
428032	416333	14259Y	PARTICIPANT	\N	PRESENT	0
428033	416333	14213J	PARTICIPANT	\N	PRESENT	0
428034	416333	19747H	PARTICIPANT	\N	PRESENT	0
428035	416333	98024R	PARTICIPANT	\N	PRESENT	0
428036	416333	11031D	PARTICIPANT	\N	PRESENT	0
428037	416333	11077T	PARTICIPANT	\N	PRESENT	0
428038	416333	04043D	PARTICIPANT	\N	PRESENT	0
428039	416333	97011G	PARTICIPANT	\N	PRESENT	0
428040	416333	11045K	PARTICIPANT	\N	PRESENT	0
428041	416333	19253P	PARTICIPANT	\N	PRESENT	0
428045	416333	19760E	PARTICIPANT	\N	PRESENT	0
428049	416333	19663E	PARTICIPANT	\N	PRESENT	0
428053	416333	19657G	PARTICIPANT	\N	PRESENT	0
428059	416333	14249W	PARTICIPANT	\N	PRESENT	0
428070	425133	19651A	PARTICIPANT	\N	PRESENT	0
428072	416333	14217N	PARTICIPANT	\N	PRESENT	0
428076	427728	19581D	PARTICIPANT	\N	EXCUSE	0
428077	427728	08018U	PARTICIPANT	\N	EXCUSE	0
428080	416333	14265W	PARTICIPANT	\N	PRESENT	0
428082	416333	19768N	PARTICIPANT	\N	PRESENT	0
428086	416333	10006L	PARTICIPANT	\N	PRESENT	0
428089	416333	19569H	PARTICIPANT	\N	PRESENT	0
428092	416333	19697Q	PARTICIPANT	\N	PRESENT	0
428097	416333	19467C	PARTICIPANT	\N	PRESENT	0
428102	416333	19693L	PARTICIPANT	\N	PRESENT	0
428103	416333	19703U	PARTICIPANT	\N	PRESENT	0
428107	416333	19727D	PARTICIPANT	\N	PRESENT	0
428113	416333	19629C	PARTICIPANT	\N	PRESENT	0
428118	416333	19631V	PARTICIPANT	\N	PRESENT	0
428129	425133	19671E	PARTICIPANT	\N	PRESENT	0
431723	430232	14028W	PARTICIPANT	\N	EXCUSE	0
434190	425306	19399H	PARTICIPANT	\N	PRESENT	0
434191	425306	08015R	PARTICIPANT	\N	PRESENT	0
434192	425306	04049K	PARTICIPANT	\N	PRESENT	0
434193	425306	19531S	PARTICIPANT	\N	PRESENT	0
447381	439815	01028R	PARTICIPANT	\N	PRESENT	0
447382	439815	19703U	PARTICIPANT	\N	PRESENT	0
447383	439815	14051J	PARTICIPANT	\N	PRESENT	0
447384	439815	19673G	PARTICIPANT	\N	PRESENT	0
447385	439815	08068F	PARTICIPANT	\N	PRESENT	0
447386	439815	14031R	PARTICIPANT	\N	PRESENT	0
447387	439815	19599P	PARTICIPANT	\N	PRESENT	0
447388	439815	19667J	PARTICIPANT	\N	PRESENT	0
447389	439815	19647E	PARTICIPANT	\N	PRESENT	0
447390	439815	14259Y	PARTICIPANT	\N	PRESENT	0
447391	439815	14199E	PARTICIPANT	\N	PRESENT	0
447392	439815	11104D	PARTICIPANT	\N	PRESENT	0
447393	439815	14253S	PARTICIPANT	\N	PRESENT	0
447394	439815	14225N	PARTICIPANT	\N	PRESENT	0
447395	439815	08020N	PARTICIPANT	\N	PRESENT	0
447396	439815	08053X	PARTICIPANT	\N	PRESENT	0
447397	439815	08010L	PARTICIPANT	\N	PRESENT	0
447398	439815	14097Y	PARTICIPANT	\N	PRESENT	0
447399	439815	11048N	PARTICIPANT	\N	PRESENT	0
447400	439815	14081Q	PARTICIPANT	\N	PRESENT	0
447401	439815	04049K	PARTICIPANT	\N	PRESENT	0
447402	439815	19525U	PARTICIPANT	\N	PRESENT	0
447403	439815	19573D	PARTICIPANT	\N	PRESENT	0
447404	439815	14065Q	PARTICIPANT	\N	PRESENT	0
447405	439815	19794Q	PARTICIPANT	\N	PRESENT	0
447406	439815	19347U	PARTICIPANT	\N	PRESENT	0
447407	439815	14085U	PARTICIPANT	\N	PRESENT	0
447408	439815	14119M	PARTICIPANT	\N	PRESENT	0
447409	439815	08014Q	PARTICIPANT	\N	PRESENT	0
447410	439815	19333N	PARTICIPANT	\N	PRESENT	0
447411	439815	14115H	PARTICIPANT	\N	PRESENT	0
447412	439815	14001X	PARTICIPANT	\N	PRESENT	0
447413	439815	08047A	PARTICIPANT	\N	PRESENT	0
447414	439815	98005N	PARTICIPANT	\N	PRESENT	0
447415	439815	14147R	PARTICIPANT	\N	PRESENT	0
447416	439815	14038Y	PARTICIPANT	\N	PRESENT	0
447417	439815	19527W	PARTICIPANT	\N	PRESENT	0
447418	439815	19723Y	PARTICIPANT	\N	PRESENT	0
447419	439815	11054L	PARTICIPANT	\N	PRESENT	0
447420	439815	19467C	PARTICIPANT	\N	PRESENT	0
447421	439815	19683J	PARTICIPANT	\N	PRESENT	0
447422	439815	19447X	PARTICIPANT	\N	PRESENT	0
447423	439815	11045K	PARTICIPANT	\N	PRESENT	0
447424	439815	11072N	PARTICIPANT	\N	PRESENT	0
447425	439815	19591F	PARTICIPANT	\N	PRESENT	0
447426	439815	19719D	PARTICIPANT	\N	PRESENT	0
447427	439815	18083K	PARTICIPANT	\N	PRESENT	0
447428	439815	19415P	PARTICIPANT	\N	PRESENT	0
447429	439815	14109K	PARTICIPANT	\N	PRESENT	0
447430	439815	08019V	PARTICIPANT	\N	PRESENT	0
447431	439815	19399H	PARTICIPANT	\N	PRESENT	0
447432	439815	19693L	PARTICIPANT	\N	PRESENT	0
447433	439815	19503N	PARTICIPANT	\N	PRESENT	0
447434	439815	19443T	PARTICIPANT	\N	PRESENT	0
447435	439815	14121F	PARTICIPANT	\N	PRESENT	0
447436	439815	14213J	PARTICIPANT	\N	PRESENT	0
447437	439815	19741B	PARTICIPANT	\N	PRESENT	0
447438	439815	08018U	PARTICIPANT	\N	PRESENT	0
447439	439815	19413M	PARTICIPANT	\N	PRESENT	0
447440	439815	19709B	PARTICIPANT	\N	PRESENT	0
447441	439815	19543W	PARTICIPANT	\N	PRESENT	0
447442	439815	19679N	PARTICIPANT	\N	PRESENT	0
447443	439815	19663E	PARTICIPANT	\N	PRESENT	0
447444	439815	08009T	PARTICIPANT	\N	PRESENT	0
447445	439815	04088S	PARTICIPANT	\N	PRESENT	0
447446	439815	14159V	PARTICIPANT	\N	PRESENT	0
447447	439815	14179A	PARTICIPANT	\N	PRESENT	0
447448	439815	19729F	PARTICIPANT	\N	PRESENT	0
447449	439815	08015R	PARTICIPANT	\N	PRESENT	0
447450	439815	01034P	PARTICIPANT	\N	PRESENT	0
447451	439815	19369B	PARTICIPANT	\N	PRESENT	0
447452	439815	04071H	PARTICIPANT	\N	PRESENT	0
447453	439815	19691J	PARTICIPANT	\N	PRESENT	0
447454	439815	19669L	PARTICIPANT	\N	PRESENT	0
447455	439815	19611R	PARTICIPANT	\N	PRESENT	0
447456	439815	14029X	PARTICIPANT	\N	PRESENT	0
447457	439815	19699S	PARTICIPANT	\N	PRESENT	0
447458	439815	95030B	PARTICIPANT	\N	PRESENT	0
447459	439815	19735D	PARTICIPANT	\N	PRESENT	0
447460	439815	14187A	PARTICIPANT	\N	PRESENT	0
447461	439815	04092N	PARTICIPANT	\N	PRESENT	0
447462	439815	14219Q	PARTICIPANT	\N	PRESENT	0
447463	439815	14071N	PARTICIPANT	\N	PRESENT	0
447464	439815	14195A	PARTICIPANT	\N	PRESENT	0
447465	439815	11097X	PARTICIPANT	\N	PRESENT	0
447466	439815	04033B	PARTICIPANT	\N	PRESENT	0
447467	439815	14205J	PARTICIPANT	\N	PRESENT	0
447468	439815	19421M	PARTICIPANT	\N	PRESENT	0
447469	439815	19713W	PARTICIPANT	\N	PRESENT	0
447470	439815	14215L	PARTICIPANT	\N	PRESENT	0
447471	439815	14087W	PARTICIPANT	\N	PRESENT	0
447472	439815	14275Y	PARTICIPANT	\N	PRESENT	0
447473	439815	04089T	PARTICIPANT	\N	PRESENT	0
447474	439815	14053L	PARTICIPANT	\N	PRESENT	0
447475	439815	14249W	PARTICIPANT	\N	PRESENT	0
447476	439815	14221J	PARTICIPANT	\N	PRESENT	0
447477	439815	14069U	PARTICIPANT	\N	PRESENT	0
447478	439815	14103D	PARTICIPANT	\N	PRESENT	0
447479	439815	05008E	PARTICIPANT	\N	PRESENT	0
447480	439815	19335Q	PARTICIPANT	\N	PRESENT	0
447481	439815	05012A	PARTICIPANT	\N	PRESENT	0
447482	439815	14055N	PARTICIPANT	\N	PRESENT	0
447483	439815	08034U	PARTICIPANT	\N	PRESENT	0
447484	439815	14083S	PARTICIPANT	\N	PRESENT	0
447485	439815	19533U	PARTICIPANT	\N	PRESENT	0
447487	439815	07004J	PARTICIPANT	\N	PRESENT	0
447489	439815	14089Y	PARTICIPANT	\N	PRESENT	0
447491	439815	19649G	PARTICIPANT	\N	PRESENT	0
447492	439815	10006L	PARTICIPANT	\N	PRESENT	0
447493	439815	19569H	PARTICIPANT	\N	PRESENT	0
447494	439815	19798U	PARTICIPANT	\N	PRESENT	0
447495	439815	19826F	PARTICIPANT	\N	PRESENT	0
447497	439815	14193X	PARTICIPANT	\N	PRESENT	0
447500	439815	14255U	PARTICIPANT	\N	PRESENT	0
447502	439815	14026U	PARTICIPANT	\N	PRESENT	0
447503	439815	97011G	PARTICIPANT	\N	PRESENT	0
447504	439815	19745F	PARTICIPANT	\N	PRESENT	0
447505	439815	11103C	PARTICIPANT	\N	PRESENT	0
447507	439815	04070G	PARTICIPANT	\N	PRESENT	0
447509	439815	04040A	PARTICIPANT	\N	PRESENT	0
447511	439815	01024M	PARTICIPANT	\N	PRESENT	0
447513	439815	14217N	PARTICIPANT	\N	PRESENT	0
447514	439815	14030Q	PARTICIPANT	\N	PRESENT	0
447515	439815	04069P	PARTICIPANT	\N	PRESENT	0
447516	439815	01043Q	PARTICIPANT	\N	PRESENT	0
447518	439815	14331P	PARTICIPANT	\N	PRESENT	0
447520	439815	14079W	PARTICIPANT	\N	PRESENT	0
447522	439815	02002K	PARTICIPANT	\N	PRESENT	0
447523	439815	14237S	PARTICIPANT	\N	PRESENT	0
447524	439815	19671E	PARTICIPANT	\N	PRESENT	0
447525	439815	19581D	PARTICIPANT	\N	PRESENT	0
447529	439815	19367Y	PARTICIPANT	\N	PRESENT	0
447530	439815	04018C	PARTICIPANT	\N	PRESENT	0
447532	439815	19762G	PARTICIPANT	\N	PRESENT	0
447533	439815	19675J	PARTICIPANT	\N	PRESENT	0
447534	439815	14357A	PARTICIPANT	\N	PRESENT	0
447535	439815	14329V	PARTICIPANT	\N	PRESENT	0
447536	439815	11049P	PARTICIPANT	\N	PRESENT	0
447537	439815	98050T	PARTICIPANT	\N	PRESENT	0
447538	439815	08039A	PARTICIPANT	\N	PRESENT	0
447539	439815	14061L	PARTICIPANT	\N	PRESENT	0
447540	439815	14135M	PARTICIPANT	\N	PRESENT	0
447541	439815	19383Y	PARTICIPANT	\N	PRESENT	0
447542	439815	19621T	PARTICIPANT	\N	PRESENT	0
447544	439815	19733B	PARTICIPANT	\N	PRESENT	0
447545	439815	98024R	PARTICIPANT	\N	PRESENT	0
447546	439815	04035D	PARTICIPANT	\N	PRESENT	0
447547	439815	14123H	PARTICIPANT	\N	PRESENT	0
447548	439815	19507S	PARTICIPANT	\N	PRESENT	0
447549	439815	86034E	PARTICIPANT	\N	PRESENT	0
447550	439815	08062Y	PARTICIPANT	\N	PRESENT	0
447551	439815	14265W	PARTICIPANT	\N	PRESENT	0
447552	439815	04043D	PARTICIPANT	\N	PRESENT	0
447553	439815	19768N	PARTICIPANT	\N	PRESENT	0
447554	439815	17637T	PARTICIPANT	\N	PRESENT	0
447564	439815	19749K	PARTICIPANT	\N	PRESENT	0
447556	439815	11085T	PARTICIPANT	\N	PRESENT	0
447557	439815	11099A	PARTICIPANT	\N	PRESENT	0
447558	439815	19269X	PARTICIPANT	\N	PRESENT	0
447559	439815	19687N	PARTICIPANT	\N	PRESENT	0
447560	439815	12041X	PARTICIPANT	\N	PRESENT	0
447561	439815	19521Q	PARTICIPANT	\N	PRESENT	0
447562	439815	19737F	PARTICIPANT	\N	PRESENT	0
447563	439815	95067Q	PARTICIPANT	\N	PRESENT	0
447565	439815	04045F	PARTICIPANT	\N	PRESENT	0
447566	439815	11033F	PARTICIPANT	\N	PRESENT	0
447567	439815	04085P	PARTICIPANT	\N	PRESENT	0
447568	439815	11070L	PARTICIPANT	\N	PRESENT	0
428230	428229	08058D	PARTICIPANT	\N	PRESENT	0
432387	430770	19253P	PARTICIPANT	\N	PRESENT	0
432388	430770	01024M	PARTICIPANT	\N	PRESENT	0
432389	430770	14215L	PARTICIPANT	\N	PRESENT	0
432390	430770	19673G	PARTICIPANT	\N	PRESENT	0
432391	430770	19675J	PARTICIPANT	\N	PRESENT	0
432392	430770	01028R	PARTICIPANT	\N	PRESENT	0
432393	430770	05008E	PRESIDENT	0	PRESENT	0
432394	432047	04070G	PRESIDENT	0	PRESENT	0
432395	432047	19699S	PARTICIPANT	\N	PRESENT	0
432396	432047	14229S	PARTICIPANT	\N	PRESENT	0
432397	432047	19573D	PARTICIPANT	\N	PRESENT	0
432398	432047	14107H	PARTICIPANT	\N	PRESENT	0
432399	432047	08017T	PARTICIPANT	\N	PRESENT	0
432400	432047	92040Q	PARTICIPANT	\N	PRESENT	0
432401	432047	08012N	PARTICIPANT	\N	PRESENT	0
432402	432047	19335Q	PARTICIPANT	\N	PRESENT	0
432403	432047	08039A	PARTICIPANT	\N	PRESENT	0
432404	432047	08031R	PARTICIPANT	\N	PRESENT	0
432405	432047	19593H	PARTICIPANT	\N	PRESENT	0
432406	432047	19643A	PARTICIPANT	\N	PRESENT	0
432407	432047	14059S	PARTICIPANT	\N	PRESENT	0
432408	432047	14061L	PARTICIPANT	\N	PRESENT	0
432409	432047	14073Q	PARTICIPANT	\N	PRESENT	0
432410	432047	19693L	PARTICIPANT	\N	PRESENT	0
432411	432047	19399H	PARTICIPANT	\N	PRESENT	0
432412	432047	14201E	PARTICIPANT	\N	PRESENT	0
432413	432047	19731Y	PARTICIPANT	\N	PRESENT	0
432414	432047	08020N	PARTICIPANT	\N	PRESENT	0
432415	432047	04059M	PARTICIPANT	\N	PRESENT	0
432416	432047	11083R	PARTICIPANT	\N	PRESENT	0
432417	432047	14123H	PARTICIPANT	\N	PRESENT	0
432418	432047	11043H	PARTICIPANT	\N	PRESENT	0
432419	432047	11104D	PARTICIPANT	\N	PRESENT	0
432420	432047	04018C	PARTICIPANT	\N	PRESENT	0
432421	432047	19758L	PARTICIPANT	\N	PRESENT	0
432422	432047	19621T	PARTICIPANT	\N	PRESENT	0
432423	432047	14063N	PARTICIPANT	\N	EXCUSE	0
432424	432047	14030Q	PARTICIPANT	\N	PRESENT	0
432425	432047	19749K	PARTICIPANT	\N	PRESENT	0
432426	430309	19697Q	PARTICIPANT	\N	PRESENT	0
432427	430309	11067R	PARTICIPANT	\N	PRESENT	0
432428	430309	19565D	PARTICIPANT	\N	PRESENT	0
432429	430309	14355X	PARTICIPANT	\N	PRESENT	0
432430	430309	19798U	PARTICIPANT	\N	PRESENT	0
432431	430309	19569H	PARTICIPANT	\N	PRESENT	0
432432	430309	11097X	PARTICIPANT	\N	PRESENT	0
432433	430309	04045F	PARTICIPANT	\N	PRESENT	0
432434	430309	14227Q	PARTICIPANT	\N	PRESENT	0
432435	430309	19553Y	PARTICIPANT	\N	PRESENT	0
432436	430309	14239U	PARTICIPANT	\N	PRESENT	0
432437	430309	19703U	PARTICIPANT	\N	PRESENT	0
432438	430309	14087W	PARTICIPANT	\N	PRESENT	0
432439	430309	14281W	PARTICIPANT	\N	PRESENT	0
432440	430309	19679N	PARTICIPANT	\N	PRESENT	0
432441	430309	14042U	PARTICIPANT	\N	PRESENT	0
432442	430309	14195A	PARTICIPANT	\N	PRESENT	0
432443	430309	08048B	PARTICIPANT	\N	PRESENT	0
432444	430309	19575F	PARTICIPANT	\N	PRESENT	0
432445	430309	19367Y	PARTICIPANT	\N	PRESENT	0
432446	430309	14213J	PARTICIPANT	\N	PRESENT	0
432447	430309	14217N	PARTICIPANT	\N	PRESENT	0
432448	430309	14261S	PARTICIPANT	\N	PRESENT	0
432449	430309	19683J	PARTICIPANT	\N	PRESENT	0
432450	430309	10006L	PARTICIPANT	\N	PRESENT	0
432451	430309	98024R	PRESIDENT	0	PRESENT	0
432452	430309	19521Q	PARTICIPANT	\N	PRESENT	0
432453	430309	01034P	PARTICIPANT	\N	PRESENT	0
432454	430309	11045K	PARTICIPANT	\N	PRESENT	0
432455	430309	08052W	PARTICIPANT	\N	PRESENT	0
432456	430309	19301E	PARTICIPANT	\N	PRESENT	0
432457	430309	19691J	PARTICIPANT	\N	PRESENT	0
432458	430309	19723Y	PARTICIPANT	\N	PRESENT	0
432459	430309	19727D	PARTICIPANT	\N	PRESENT	0
432460	430309	14119M	PARTICIPANT	\N	PRESENT	0
432461	430309	11103C	PARTICIPANT	\N	PRESENT	0
432462	430309	19657G	PARTICIPANT	\N	PRESENT	0
432463	430309	19577H	PARTICIPANT	\N	PRESENT	0
432464	430309	19760E	PARTICIPANT	\N	PRESENT	0
432465	430309	08041T	PARTICIPANT	\N	EXCUSE	0
432466	430309	17779H	PARTICIPANT	\N	EXCUSE	0
432467	430309	19415P	PARTICIPANT	\N	PRESENT	0
432468	430309	04092N	PRESIDENT	1	PRESENT	0
432469	430646	14105F	PARTICIPANT	\N	PRESENT	0
432470	430646	14079W	PARTICIPANT	\N	PRESENT	0
432471	430646	14193X	PRESIDENT	1	PRESENT	0
432472	430646	04042C	PRESIDENT	0	PRESENT	0
432473	430646	14267Y	PARTICIPANT	\N	PRESENT	0
432474	430646	98029W	PARTICIPANT	\N	PRESENT	0
432475	430646	19721W	PARTICIPANT	\N	PRESENT	0
432476	430836	19515S	PARTICIPANT	\N	PRESENT	0
432477	430836	19782L	PARTICIPANT	\N	PRESENT	0
432478	430836	14357A	PARTICIPANT	\N	PRESENT	0
432479	430836	19812Y	PARTICIPANT	\N	PRESENT	0
432480	430836	14081Q	PARTICIPANT	\N	PRESENT	0
432481	430836	19413M	PARTICIPANT	\N	PRESENT	0
432482	430836	19631V	PARTICIPANT	\N	PRESENT	0
432483	430836	08068F	PARTICIPANT	\N	PRESENT	0
432484	430836	04049K	PARTICIPANT	\N	PRESENT	0
432485	430836	19705W	PARTICIPANT	\N	PRESENT	0
432486	430836	08015R	PARTICIPANT	\N	PRESENT	0
432487	430836	08019V	PARTICIPANT	\N	PRESENT	0
432488	430836	14197C	PARTICIPANT	\N	PRESENT	0
432489	430836	19369B	PARTICIPANT	\N	PRESENT	0
432490	430836	19511N	PARTICIPANT	\N	PRESENT	0
432491	430836	19563B	PARTICIPANT	\N	PRESENT	0
432492	430836	14329V	PARTICIPANT	\N	PRESENT	0
432493	430836	14135M	PARTICIPANT	\N	PRESENT	0
432494	430836	19467C	PARTICIPANT	\N	PRESENT	0
432495	430836	14187A	PARTICIPANT	\N	PRESENT	0
432496	430836	08038Y	PARTICIPANT	\N	PRESENT	0
432497	430836	08062Y	PARTICIPANT	\N	PRESENT	0
432498	430836	19695N	PARTICIPANT	\N	PRESENT	0
432499	430836	11090Q	PRESIDENT	0	PRESENT	0
432500	430836	01025N	PARTICIPANT	\N	PRESENT	0
432501	430836	14033T	PARTICIPANT	\N	PRESENT	0
432502	430836	04088S	PARTICIPANT	\N	PRESENT	0
432503	430836	11056N	PARTICIPANT	\N	PRESENT	0
432504	430836	04089T	PARTICIPANT	\N	PRESENT	0
432505	430836	14115H	PARTICIPANT	\N	PRESENT	0
432506	430836	11101A	PARTICIPANT	\N	PRESENT	0
432507	430836	19507S	PARTICIPANT	\N	PRESENT	0
432508	430836	19747H	PARTICIPANT	\N	PRESENT	0
432509	430836	14207L	PARTICIPANT	\N	PRESENT	0
432510	430836	04043D	PARTICIPANT	\N	PRESENT	0
432511	430836	19619A	PARTICIPANT	\N	PRESENT	0
432512	430836	17589D	PARTICIPANT	\N	PRESENT	0
432513	430836	14257W	PARTICIPANT	\N	PRESENT	0
432514	430836	19295A	PARTICIPANT	\N	EXCUSE	0
432515	430836	11081P	PARTICIPANT	\N	EXCUSE	0
432516	430836	14265W	PARTICIPANT	\N	EXCUSE	0
432517	430646	19421M	PARTICIPANT	\N	PRESENT	0
432518	430646	11064N	PARTICIPANT	\N	PRESENT	0
432519	430646	98050T	PARTICIPANT	\N	PRESENT	0
432520	430646	19251M	PARTICIPANT	\N	PRESENT	0
432521	430646	08061X	PARTICIPANT	\N	PRESENT	0
432522	430646	11041F	PARTICIPANT	\N	PRESENT	0
432523	430646	08056B	PARTICIPANT	\N	PRESENT	0
432524	430646	97011G	PARTICIPANT	\N	PRESENT	0
432525	430646	08047A	PARTICIPANT	\N	PRESENT	0
432526	431062	19741B	PARTICIPANT	\N	PRESENT	0
432527	431062	11074Q	PRESIDENT	0	PRESENT	0
432528	431062	95041E	PARTICIPANT	\N	EXCUSE	0
432529	432047	14241N	PARTICIPANT	\N	PRESENT	0
432530	432047	14039A	PARTICIPANT	\N	PRESENT	0
432531	432047	14249W	PARTICIPANT	\N	PRESENT	0
432532	432047	08043V	PARTICIPANT	\N	PRESENT	0
432533	432047	87003B	PARTICIPANT	\N	PRESENT	0
432534	432047	11109J	PARTICIPANT	\N	PRESENT	0
432535	432047	14109K	PARTICIPANT	\N	PRESENT	0
432536	432047	04057K	PARTICIPANT	\N	PRESENT	0
432537	432047	19611R	PARTICIPANT	\N	PRESENT	0
432538	432047	14251Q	PARTICIPANT	\N	PRESENT	0
432539	430646	95067Q	PARTICIPANT	\N	PRESENT	0
432540	430646	01062T	PARTICIPANT	\N	PRESENT	0
432541	430646	01058X	PARTICIPANT	\N	PRESENT	0
432542	430646	16685X	PARTICIPANT	\N	PRESENT	0
432543	430646	08058D	PARTICIPANT	\N	PRESENT	0
432544	430646	11054L	PARTICIPANT	\N	PRESENT	0
432545	430646	14211G	PARTICIPANT	\N	PRESENT	0
432546	430646	04034C	PARTICIPANT	\N	PRESENT	0
432547	430646	14235Q	PARTICIPANT	\N	PRESENT	0
432548	431062	14327T	PARTICIPANT	\N	PRESENT	0
432549	431062	14331P	PARTICIPANT	\N	PRESENT	0
432550	431062	01048V	PARTICIPANT	\N	PRESENT	0
432551	431062	11053K	PARTICIPANT	\N	PRESENT	0
432552	431062	89017R	PARTICIPANT	\N	PRESENT	0
432553	431062	19667J	PARTICIPANT	\N	PRESENT	0
432554	431062	19671E	PARTICIPANT	\N	PRESENT	0
443428	439638	01043Q	PARTICIPANT	\N	PRESENT	0
443430	439638	19565D	PARTICIPANT	\N	PRESENT	0
443431	439638	11026G	PARTICIPANT	\N	PRESENT	0
443432	439638	08017T	PARTICIPANT	\N	PRESENT	0
443433	439638	11027H	PARTICIPANT	\N	PRESENT	0
443434	439638	19683J	PARTICIPANT	\N	PRESENT	0
443435	439638	19681G	PARTICIPANT	\N	PRESENT	0
443436	439638	11065P	PARTICIPANT	\N	PRESENT	0
443437	439638	19553Y	PARTICIPANT	\N	PRESENT	0
443438	439638	19591F	PARTICIPANT	\N	PRESENT	0
443439	439638	19749K	PARTICIPANT	\N	PRESENT	0
443440	439638	01024M	PARTICIPANT	\N	PRESENT	0
443441	439638	19737F	PARTICIPANT	\N	PRESENT	0
443442	439638	14179A	PARTICIPANT	\N	PRESENT	0
443443	439638	14026U	PARTICIPANT	\N	PRESENT	0
443444	439638	07029T	PARTICIPANT	\N	PRESENT	0
443445	439638	14069U	PARTICIPANT	\N	PRESENT	0
443446	439638	19507S	PARTICIPANT	\N	PRESENT	0
443447	439638	04088S	PARTICIPANT	\N	PRESENT	0
443448	439638	80013X	PARTICIPANT	\N	PRESENT	0
443449	439638	19467C	PARTICIPANT	\N	PRESENT	0
443450	439638	14217N	PARTICIPANT	\N	PRESENT	0
443451	439638	04035D	PARTICIPANT	\N	PRESENT	0
443452	439638	08031R	PARTICIPANT	\N	PRESENT	0
443453	439638	19643A	PARTICIPANT	\N	PRESENT	0
443454	439638	19413M	PARTICIPANT	\N	PRESENT	0
443455	443429	19593H	PARTICIPANT	\N	PRESENT	0
443456	443429	19766L	PARTICIPANT	\N	PRESENT	0
443457	443429	04070G	PRESIDENT	0	PRESENT	0
443458	443429	04057K	PARTICIPANT	\N	PRESENT	0
443459	443429	19533U	PARTICIPANT	\N	PRESENT	0
443460	443429	19611R	PARTICIPANT	\N	PRESENT	0
443461	443429	08043V	PARTICIPANT	\N	PRESENT	0
443462	443429	19693L	PARTICIPANT	\N	PRESENT	0
443463	443429	14241N	PARTICIPANT	\N	PRESENT	0
443464	443429	08017T	PARTICIPANT	\N	PRESENT	0
443465	443429	14063N	PARTICIPANT	\N	PRESENT	0
443466	443429	11083R	PARTICIPANT	\N	PRESENT	0
443467	443429	14123H	PARTICIPANT	\N	PRESENT	0
443468	443429	11104D	PARTICIPANT	\N	PRESENT	0
443469	443429	14249W	PARTICIPANT	\N	PRESENT	0
443470	443429	19758L	PARTICIPANT	\N	PRESENT	0
443471	443429	08039A	PARTICIPANT	\N	PRESENT	0
443472	443429	19621T	PARTICIPANT	\N	PRESENT	0
443473	443429	14061L	PARTICIPANT	\N	EXCUSE	0
443474	443429	14073Q	PARTICIPANT	\N	EXCUSE	0
443475	443429	14201E	PARTICIPANT	\N	EXCUSE	0
443476	439638	19387D	PARTICIPANT	\N	PRESENT	0
443477	443429	19399H	PARTICIPANT	\N	PRESENT	0
443478	439638	11097X	PARTICIPANT	\N	PRESENT	0
443479	439638	19701S	PARTICIPANT	\N	PRESENT	0
443480	439638	14030Q	PARTICIPANT	\N	PRESENT	0
443481	439638	19703U	PARTICIPANT	\N	PRESENT	0
443482	439638	19563B	PARTICIPANT	\N	PRESENT	0
443483	443429	11109J	PARTICIPANT	\N	PRESENT	0
443484	439638	19715Y	PARTICIPANT	\N	PRESENT	0
443485	443429	07033P	PARTICIPANT	\N	PRESENT	0
443486	439638	98050T	PARTICIPANT	\N	PRESENT	0
443487	441620	14065Q	PARTICIPANT	\N	PRESENT	0
443488	441620	19649G	PARTICIPANT	\N	PRESENT	0
443489	441620	08034U	PARTICIPANT	\N	PRESENT	0
443490	441620	19569H	PARTICIPANT	\N	PRESENT	0
443491	441620	11045K	PARTICIPANT	\N	PRESENT	0
443492	441620	08052W	PARTICIPANT	\N	PRESENT	0
443493	441620	19415P	PARTICIPANT	\N	PRESENT	0
443494	441620	11066Q	PARTICIPANT	\N	PRESENT	0
443495	441620	19447X	PARTICIPANT	\N	PRESENT	0
443496	441620	04085P	PARTICIPANT	\N	PRESENT	0
443497	441620	05008E	PARTICIPANT	\N	PRESENT	0
443498	441620	11031D	PARTICIPANT	\N	PRESENT	0
443499	441620	19553Y	PARTICIPANT	\N	PRESENT	0
443500	441620	14042U	PARTICIPANT	\N	PRESENT	0
443501	441620	14195A	PARTICIPANT	\N	PRESENT	0
443502	441620	14147R	PARTICIPANT	\N	PRESENT	0
443503	441620	14179A	PARTICIPANT	\N	PRESENT	0
443504	441620	14213J	PARTICIPANT	\N	PRESENT	0
443505	441620	14215L	PARTICIPANT	\N	PRESENT	0
443506	441620	19683J	PARTICIPANT	\N	PRESENT	0
443507	441620	10006L	PRESIDENT	0	PRESENT	0
443508	441620	11072N	PARTICIPANT	\N	PRESENT	0
443509	443429	19573D	PARTICIPANT	\N	PRESENT	0
443510	439638	19581D	PARTICIPANT	\N	PRESENT	0
443511	439638	14251Q	PARTICIPANT	\N	PRESENT	0
443512	439638	19253P	PARTICIPANT	\N	PRESENT	0
443515	439638	95030B	PARTICIPANT	\N	PRESENT	0
443516	439638	14147R	PARTICIPANT	\N	PRESENT	0
443517	443429	08012N	PARTICIPANT	\N	PRESENT	0
443518	439638	14195A	PARTICIPANT	\N	PRESENT	0
443669	443668	05008E	PRESIDENT	0	PRESENT	0
443670	443668	08018U	PARTICIPANT	\N	PRESENT	0
443671	443668	14215L	PARTICIPANT	\N	PRESENT	0
443672	443668	14089Y	PARTICIPANT	\N	PRESENT	0
443673	443668	04059M	PARTICIPANT	\N	PRESENT	0
443674	443668	19649G	PARTICIPANT	\N	PRESENT	0
443675	443668	11072N	PARTICIPANT	\N	PRESENT	0
443732	441792	19820Y	PARTICIPANT	\N	PRESENT	0
443764	441747	14135M	PARTICIPANT	\N	EXCUSE	0
443765	441747	19691J	PARTICIPANT	\N	EXCUSE	0
443766	441747	19329S	PARTICIPANT	\N	EXCUSE	0
443767	441747	19715Y	PARTICIPANT	\N	EXCUSE	0
443768	441747	11010L	PARTICIPANT	\N	EXCUSE	0
443769	441747	14225N	PARTICIPANT	\N	EXCUSE	0
443789	443787	19503N	PARTICIPANT	\N	PRESENT	0
443792	443790	19503N	PARTICIPANT	\N	PRESENT	0
443795	443793	19503N	PARTICIPANT	\N	PRESENT	0
443797	443796	04043D	PARTICIPANT	\N	PRESENT	0
443799	443798	04043D	PARTICIPANT	\N	PRESENT	0
443801	443800	04043D	PARTICIPANT	\N	PRESENT	0
443828	441792	04044E	PARTICIPANT	\N	EXCUSE	0
443841	443839	14257W	PARTICIPANT	\N	PRESENT	0
443843	443839	19768N	PARTICIPANT	\N	PRESENT	0
443846	443840	14257W	PARTICIPANT	\N	PRESENT	0
443847	443840	19768N	PARTICIPANT	\N	PRESENT	0
443848	443840	19631V	PARTICIPANT	\N	PRESENT	0
443850	443849	14257W	PARTICIPANT	\N	PRESENT	0
443851	443849	19768N	PARTICIPANT	\N	PRESENT	0
443855	441792	08049C	PARTICIPANT	\N	PRESENT	0
443862	441792	08048B	PARTICIPANT	\N	EXCUSE	0
443866	441792	08010L	PARTICIPANT	\N	EXCUSE	0
443879	443871	14239U	PARTICIPANT	\N	PRESENT	0
443880	443871	19697Q	PARTICIPANT	\N	PRESENT	0
443883	443872	19697Q	PARTICIPANT	\N	PRESENT	0
443884	443873	19697Q	PARTICIPANT	\N	PRESENT	0
443885	443874	19697Q	PARTICIPANT	\N	PRESENT	0
443887	443877	19697Q	PARTICIPANT	\N	PRESENT	0
443889	443875	19697Q	PARTICIPANT	\N	PRESENT	0
443897	441792	14195A	PARTICIPANT	\N	EXCUSE	0
444143	444140	14026U	PARTICIPANT	\N	PRESENT	0
444360	444359	14237S	PARTICIPANT	\N	PRESENT	0
444361	444359	14038Y	PARTICIPANT	\N	PRESENT	0
444362	444359	14109K	PARTICIPANT	\N	PRESENT	0
444368	442208	08045X	PARTICIPANT	\N	PRESENT	0
444716	444715	14083S	PARTICIPANT	\N	PRESENT	0
444370	441807	14030Q	PRESIDENT	0	PRESENT	0
444371	441807	08043V	PARTICIPANT	\N	EXCUSE	0
444372	441807	11031D	PARTICIPANT	\N	EXCUSE	0
444373	441807	19693L	PARTICIPANT	\N	PRESENT	0
444374	441807	19599P	PARTICIPANT	\N	PRESENT	0
444375	441807	14179A	PARTICIPANT	\N	PRESENT	0
444376	441807	19715Y	PARTICIPANT	\N	EXCUSE	0
444377	441807	08031R	PARTICIPANT	\N	EXCUSE	0
444378	441807	01043Q	PARTICIPANT	\N	EXCUSE	0
444379	441807	19749K	PARTICIPANT	\N	PRESENT	0
444380	439610	08024S	PARTICIPANT	\N	PRESENT	0
444381	442208	08024S	PARTICIPANT	\N	PRESENT	0
444382	443747	08024S	PARTICIPANT	\N	PRESENT	0
444711	444710	14026U	PARTICIPANT	\N	PRESENT	0
444717	444715	14061L	PARTICIPANT	\N	PRESENT	0
444718	444715	19671E	PARTICIPANT	\N	PRESENT	0
444728	444727	04049K	PARTICIPANT	\N	PRESENT	0
444729	444727	16685X	PARTICIPANT	\N	PRESENT	0
444731	444730	04049K	PARTICIPANT	\N	PRESENT	0
444732	444730	16685X	PARTICIPANT	\N	PRESENT	0
444737	444736	04049K	PARTICIPANT	\N	PRESENT	0
444738	444736	16685X	PARTICIPANT	\N	PRESENT	0
444794	441747	14038Y	PARTICIPANT	\N	EXCUSE	0
444795	441747	96004D	PARTICIPANT	\N	EXCUSE	0
444796	441747	19631V	PARTICIPANT	\N	EXCUSE	0
444797	441747	19729F	PARTICIPANT	\N	EXCUSE	0
444798	441747	11054L	PARTICIPANT	\N	EXCUSE	0
444799	441792	19565D	PARTICIPANT	\N	EXCUSE	0
445110	445109	11090Q	PARTICIPANT	\N	PRESENT	0
445111	445109	19507S	PARTICIPANT	\N	PRESENT	0
425160	425159	89017R	PARTICIPANT	\N	PRESENT	0
425162	425161	14331P	PARTICIPANT	\N	PRESENT	0
425164	425163	14331P	PARTICIPANT	\N	PRESENT	0
425166	425165	14331P	PARTICIPANT	\N	PRESENT	0
425168	425167	11048N	PARTICIPANT	\N	PRESENT	0
427648	427647	10015M	PARTICIPANT	\N	PRESENT	0
431445	430232	14063N	PARTICIPANT	\N	EXCUSE	0
431446	430232	19735D	PARTICIPANT	\N	EXCUSE	0
434246	425307	19531S	PARTICIPANT	\N	PRESENT	0
434247	425307	14227Q	PARTICIPANT	\N	PRESENT	0
434248	425307	19333N	PARTICIPANT	\N	PRESENT	0
434249	425307	19671E	PARTICIPANT	\N	PRESENT	0
434250	425307	95037J	PARTICIPANT	\N	PRESENT	0
434251	425307	19349W	PARTICIPANT	\N	PRESENT	0
434252	425307	11072N	PARTICIPANT	\N	PRESENT	0
434253	425307	01028R	PARTICIPANT	\N	PRESENT	0
434254	425307	11026G	PARTICIPANT	\N	PRESENT	0
434255	425307	11033F	PARTICIPANT	\N	PRESENT	0
434256	425307	19543W	PARTICIPANT	\N	PRESENT	0
434257	425307	19545Y	PARTICIPANT	\N	PRESENT	0
434258	425307	19553Y	PARTICIPANT	\N	PRESENT	0
434259	425307	19725B	PARTICIPANT	\N	PRESENT	0
434260	425307	16685X	PARTICIPANT	\N	PRESENT	0
434261	425307	19737F	PARTICIPANT	\N	PRESENT	0
434262	425307	14121F	PARTICIPANT	\N	PRESENT	0
434263	425307	11012A	PARTICIPANT	\N	PRESENT	0
434264	425307	88008L	PARTICIPANT	\N	PRESENT	0
434265	425307	11085T	PARTICIPANT	\N	PRESENT	0
434266	425307	14073Q	PARTICIPANT	\N	PRESENT	0
434267	425307	14083S	PARTICIPANT	\N	PRESENT	0
434268	425307	19335Q	PARTICIPANT	\N	PRESENT	0
434244	425307	04059M	PARTICIPANT	\N	PRESENT	0
434245	425307	04085P	PARTICIPANT	\N	PRESENT	0
434269	425307	19621T	PARTICIPANT	\N	PRESENT	0
434270	425307	19581D	PARTICIPANT	\N	PRESENT	0
434271	425307	04018C	PARTICIPANT	\N	PRESENT	0
434272	425307	19701S	PARTICIPANT	\N	PRESENT	0
434273	425307	14217N	PARTICIPANT	\N	PRESENT	0
434274	425307	08034U	PARTICIPANT	\N	PRESENT	0
434275	425307	14069U	PARTICIPANT	\N	PRESENT	0
434276	425307	04049K	PARTICIPANT	\N	PRESENT	0
434277	425307	19711U	PARTICIPANT	\N	PRESENT	0
434278	425307	99004R	PARTICIPANT	\N	PRESENT	0
434279	425307	04044E	PARTICIPANT	\N	PRESENT	0
434280	425307	08015R	PARTICIPANT	\N	PRESENT	0
434281	425307	07029T	PARTICIPANT	\N	PRESENT	0
434282	425307	19399H	PARTICIPANT	\N	PRESENT	0
434283	425307	14157T	PARTICIPANT	\N	PRESENT	0
434284	425307	19667J	PARTICIPANT	\N	PRESENT	0
434285	425307	04047H	PARTICIPANT	\N	PRESENT	0
434288	425307	19253P	PARTICIPANT	\N	PRESENT	0
434290	425307	14034U	PARTICIPANT	\N	PRESENT	0
434301	425307	14119M	PARTICIPANT	\N	PRESENT	0
434304	425307	14030Q	PARTICIPANT	\N	PRESENT	0
434305	425307	14042U	PARTICIPANT	\N	PRESENT	0
434306	425307	07004J	PARTICIPANT	\N	PRESENT	0
434307	425307	14261S	PARTICIPANT	\N	PRESENT	0
434308	425307	11115U	PARTICIPANT	\N	PRESENT	0
434309	425307	19741B	PARTICIPANT	\N	PRESENT	0
434310	425307	14329V	PARTICIPANT	\N	PRESENT	0
434311	425307	14089Y	PARTICIPANT	\N	PRESENT	0
434312	425307	04086Q	PARTICIPANT	\N	PRESENT	0
434313	425307	19651A	PARTICIPANT	\N	PRESENT	0
434314	425307	19503N	PARTICIPANT	\N	PRESENT	0
434326	425307	19713W	PARTICIPANT	\N	PRESENT	0
434354	425307	04038G	PARTICIPANT	\N	PRESENT	0
434355	425307	14253S	PARTICIPANT	\N	PRESENT	0
434356	425307	01048V	PARTICIPANT	\N	PRESENT	0
434357	425307	19699S	PARTICIPANT	\N	PRESENT	0
434358	425307	19515S	PARTICIPANT	\N	PRESENT	0
434359	425307	19413M	PARTICIPANT	\N	PRESENT	0
434360	425307	14211G	PARTICIPANT	\N	PRESENT	0
434410	425316	19413M	PARTICIPANT	\N	PRESENT	0
434411	425316	19531S	PARTICIPANT	\N	PRESENT	0
434412	425316	01028R	PARTICIPANT	\N	PRESENT	0
434413	425316	19545Y	PARTICIPANT	\N	PRESENT	0
434414	425316	19543W	PARTICIPANT	\N	PRESENT	0
434415	425316	19651A	PARTICIPANT	\N	PRESENT	0
434416	425316	19253P	PARTICIPANT	\N	PRESENT	0
434417	425316	19553Y	PARTICIPANT	\N	PRESENT	0
434418	425316	14042U	PARTICIPANT	\N	PRESENT	0
434419	425316	14083S	PARTICIPANT	\N	PRESENT	0
434420	425316	19671E	PARTICIPANT	\N	PRESENT	0
434421	425316	19621T	PARTICIPANT	\N	PRESENT	0
434422	425316	04038G	PARTICIPANT	\N	PRESENT	0
434423	425316	11033F	PARTICIPANT	\N	PRESENT	0
434424	425316	14253S	PARTICIPANT	\N	PRESENT	0
434425	425316	11115U	PARTICIPANT	\N	PRESENT	0
434426	425316	07029T	PARTICIPANT	\N	PRESENT	0
434427	425316	19399H	PARTICIPANT	\N	PRESENT	0
434428	425316	04049K	PARTICIPANT	\N	PRESENT	0
434429	425316	19711U	PARTICIPANT	\N	PRESENT	0
434430	425316	08034U	PARTICIPANT	\N	PRESENT	0
434431	425316	14217N	PARTICIPANT	\N	PRESENT	0
434432	425316	14261S	PARTICIPANT	\N	PRESENT	0
434433	425316	07004J	PARTICIPANT	\N	PRESENT	0
434434	425316	19515S	PARTICIPANT	\N	PRESENT	0
434435	425316	14069U	PARTICIPANT	\N	PRESENT	0
434436	425316	99004R	PARTICIPANT	\N	PRESENT	0
434437	425316	08010L	PARTICIPANT	\N	PRESENT	0
434438	425316	19741B	PARTICIPANT	\N	PRESENT	0
434439	425316	19701S	PARTICIPANT	\N	PRESENT	0
434440	425316	19349W	PARTICIPANT	\N	PRESENT	0
434441	425316	14034U	PARTICIPANT	\N	PRESENT	0
434442	425316	11012A	PARTICIPANT	\N	PRESENT	0
434443	425316	11031D	PARTICIPANT	\N	PRESENT	0
434444	425316	14213J	PARTICIPANT	\N	PRESENT	0
434477	425312	11026G	PARTICIPANT	\N	PRESENT	0
434478	425312	01028R	PARTICIPANT	\N	PRESENT	0
434479	425312	19725B	PARTICIPANT	\N	PRESENT	0
434480	425312	19651A	PARTICIPANT	\N	PRESENT	0
434481	425312	19349W	PARTICIPANT	\N	PRESENT	0
434482	425312	14083S	PARTICIPANT	\N	PRESENT	0
434483	425312	07029T	PARTICIPANT	\N	PRESENT	0
434484	425312	04049K	PARTICIPANT	\N	PRESENT	0
434485	425312	19711U	PARTICIPANT	\N	PRESENT	0
434486	425312	14217N	PARTICIPANT	\N	PRESENT	0
434487	425312	14073Q	PARTICIPANT	\N	PRESENT	0
434488	425312	14255U	PARTICIPANT	\N	PRESENT	0
434408	425316	04086Q	PARTICIPANT	\N	PRESENT	0
434409	425316	19725B	PARTICIPANT	\N	PRESENT	0
434489	425312	07004J	PARTICIPANT	\N	PRESENT	0
434490	425312	19545Y	PARTICIPANT	\N	PRESENT	0
434491	425312	95063L	PARTICIPANT	\N	PRESENT	0
434492	425312	19741B	PARTICIPANT	\N	PRESENT	0
434493	425312	14253S	PARTICIPANT	\N	PRESENT	0
434494	425312	14069U	PARTICIPANT	\N	PRESENT	0
434495	425312	08034U	PARTICIPANT	\N	PRESENT	0
434496	425312	14213J	PARTICIPANT	\N	PRESENT	0
434497	425312	14034U	PARTICIPANT	\N	PRESENT	0
434498	425312	95041E	PARTICIPANT	\N	PRESENT	0
434499	425312	08069G	PARTICIPANT	\N	PRESENT	0
434500	425312	08010L	PARTICIPANT	\N	PRESENT	0
434501	425312	14089Y	PARTICIPANT	\N	PRESENT	0
434507	425327	14034U	PARTICIPANT	\N	PRESENT	0
434508	431063	19647E	PARTICIPANT	\N	PRESENT	0
434509	431063	95041E	PARTICIPANT	\N	PRESENT	0
434510	431063	19711U	PRESIDENT	0	PRESENT	0
434511	431063	08034U	PARTICIPANT	\N	PRESENT	0
434475	425312	04086Q	PARTICIPANT	\N	PRESENT	0
434476	425312	04038G	PARTICIPANT	\N	PRESENT	0
434512	431063	89017R	PARTICIPANT	\N	PRESENT	0
434513	431063	88008L	PARTICIPANT	\N	PRESENT	0
434514	431063	11070L	PARTICIPANT	\N	PRESENT	0
434515	431063	11040E	PARTICIPANT	\N	PRESENT	0
434516	431063	07029T	PARTICIPANT	\N	PRESENT	0
434517	431063	11012A	PARTICIPANT	\N	PRESENT	0
434518	431063	19741B	PARTICIPANT	\N	PRESENT	0
434519	431063	08010L	PARTICIPANT	\N	PRESENT	0
434520	431063	99004R	PARTICIPANT	\N	PRESENT	0
434521	431063	14253S	PARTICIPANT	\N	PRESENT	0
435403	425611	12016W	PARTICIPANT	\N	PRESENT	0
435404	425611	04085P	PARTICIPANT	\N	PRESENT	0
435405	425611	19687N	PARTICIPANT	\N	PRESENT	0
435406	425611	14081Q	PARTICIPANT	\N	PRESENT	0
435407	425611	19563B	PARTICIPANT	\N	PRESENT	0
435408	425611	19545Y	PARTICIPANT	\N	PRESENT	0
435409	425611	19479G	PARTICIPANT	\N	PRESENT	0
435410	425611	19713W	PARTICIPANT	\N	PRESENT	0
435411	425611	19739H	PARTICIPANT	\N	PRESENT	0
435412	425611	19737F	PARTICIPANT	\N	PRESENT	0
435413	425611	07004J	PARTICIPANT	\N	PRESENT	0
435414	425611	19671E	PARTICIPANT	\N	PRESENT	0
435415	425611	14135M	PARTICIPANT	\N	PRESENT	0
435416	425611	19515S	PARTICIPANT	\N	PRESENT	0
435417	425611	01048V	PARTICIPANT	\N	PRESENT	0
435418	425611	19651A	PARTICIPANT	\N	PRESENT	0
435401	425611	04044E	PARTICIPANT	\N	PRESENT	0
435402	425611	19631V	PARTICIPANT	\N	PRESENT	0
447569	439815	14021P	PARTICIPANT	\N	PRESENT	0
447570	439815	12016W	PARTICIPANT	\N	PRESENT	0
447571	439815	19531S	PARTICIPANT	\N	PRESENT	0
447572	439815	14257W	PARTICIPANT	\N	PRESENT	0
447573	439815	04042C	PARTICIPANT	\N	PRESENT	0
447574	439815	19747H	PARTICIPANT	\N	PRESENT	0
447575	439815	11080N	PARTICIPANT	\N	PRESENT	0
447576	439815	19637C	PARTICIPANT	\N	PRESENT	0
447577	439815	11026G	PARTICIPANT	\N	PRESENT	0
447579	439815	19701S	PARTICIPANT	\N	PRESENT	0
447580	439815	14197C	PARTICIPANT	\N	PRESENT	0
447920	439816	19649G	PARTICIPANT	\N	PRESENT	0
447878	439816	19533U	PARTICIPANT	\N	PRESENT	0
447880	439816	19553Y	PARTICIPANT	\N	PRESENT	0
447881	439816	14195A	PARTICIPANT	\N	PRESENT	0
447882	439816	14205J	PARTICIPANT	\N	PRESENT	0
447883	439816	14275Y	PARTICIPANT	\N	PRESENT	0
447884	439816	19737F	PARTICIPANT	\N	PRESENT	0
447885	439816	11067R	PARTICIPANT	\N	PRESENT	0
447886	439816	14063N	PARTICIPANT	\N	PRESENT	0
447887	439816	14197C	PARTICIPANT	\N	PRESENT	0
447888	439816	19651A	PARTICIPANT	\N	PRESENT	0
447889	439816	14261S	PARTICIPANT	\N	PRESENT	0
447890	439816	14030Q	PARTICIPANT	\N	PRESENT	0
447891	439816	01024M	PARTICIPANT	\N	PRESENT	0
447917	439816	04045F	PARTICIPANT	\N	PRESENT	0
447914	439816	19383Y	PARTICIPANT	\N	PRESENT	0
447894	439816	19631V	PARTICIPANT	\N	PRESENT	0
447895	439816	14079W	PARTICIPANT	\N	PRESENT	0
447896	439816	19581D	PARTICIPANT	\N	PRESENT	0
447897	439816	19367Y	PARTICIPANT	\N	PRESENT	0
447994	439816	08017T	PARTICIPANT	\N	PRESENT	0
447899	439816	14147R	PARTICIPANT	\N	PRESENT	0
447900	439816	14215L	PARTICIPANT	\N	PRESENT	0
447901	439816	19711U	PARTICIPANT	\N	PRESENT	0
447902	439816	10015M	PARTICIPANT	\N	PRESENT	0
447903	439816	14031R	PARTICIPANT	\N	PRESENT	0
447904	439816	14105F	PARTICIPANT	\N	PRESENT	0
447905	439816	08052W	PARTICIPANT	\N	PRESENT	0
447906	439816	99004R	PARTICIPANT	\N	PRESENT	0
447907	439816	14187A	PARTICIPANT	\N	PRESENT	0
447908	439816	14211G	PARTICIPANT	\N	PRESENT	0
447909	439816	19731Y	PARTICIPANT	\N	PRESENT	0
447910	439816	04043D	PARTICIPANT	\N	PRESENT	0
447911	439816	14121F	PARTICIPANT	\N	PRESENT	0
447912	439816	07004J	PARTICIPANT	\N	PRESENT	0
447913	439816	19671E	PARTICIPANT	\N	PRESENT	0
447915	439816	19812Y	PARTICIPANT	\N	PRESENT	0
447925	439816	14051J	PARTICIPANT	\N	PRESENT	0
447918	439816	04059M	PARTICIPANT	\N	PRESENT	0
447919	439816	19683J	PARTICIPANT	\N	PRESENT	0
447921	439816	11033F	PARTICIPANT	\N	PRESENT	0
447922	439816	04085P	PARTICIPANT	\N	PRESENT	0
447923	439816	19413M	PARTICIPANT	\N	PRESENT	0
447924	439816	01043Q	PARTICIPANT	\N	PRESENT	0
447926	439816	14065Q	PARTICIPANT	\N	PRESENT	0
447927	439816	14239U	PARTICIPANT	\N	PRESENT	0
447928	439816	14107H	PARTICIPANT	\N	PRESENT	0
447929	439816	11045K	PARTICIPANT	\N	PRESENT	0
447930	439816	19565D	PARTICIPANT	\N	PRESENT	0
447931	439816	04092N	PARTICIPANT	\N	PRESENT	0
447932	439816	19447X	PARTICIPANT	\N	PRESENT	0
447933	439816	11066Q	PARTICIPANT	\N	PRESENT	0
447934	439816	19569H	PARTICIPANT	\N	PRESENT	0
447935	439816	19611R	PARTICIPANT	\N	PRESENT	0
447936	439816	19387D	PARTICIPANT	\N	PRESENT	0
447937	439816	19507S	PARTICIPANT	\N	PRESENT	0
447938	439816	19693L	PARTICIPANT	\N	PRESENT	0
447939	439816	19335Q	PARTICIPANT	\N	PRESENT	0
447940	439816	19747H	PARTICIPANT	\N	PRESENT	0
447941	439816	19349W	PARTICIPANT	\N	PRESENT	0
447942	439816	11109J	PARTICIPANT	\N	PRESENT	0
447943	439816	14213J	PARTICIPANT	\N	PRESENT	0
447944	439816	14026U	PARTICIPANT	\N	PRESENT	0
447945	439816	14329V	PARTICIPANT	\N	PRESENT	0
447946	439816	14217N	PARTICIPANT	\N	PRESENT	0
447947	439816	97011G	PARTICIPANT	\N	PRESENT	0
447948	439816	08034U	PARTICIPANT	\N	PRESENT	0
447949	439816	19762G	PARTICIPANT	\N	PRESENT	0
447950	439816	19798U	PARTICIPANT	\N	PRESENT	0
447951	439816	19415P	PARTICIPANT	\N	PRESENT	0
447952	439816	19467C	PARTICIPANT	\N	PRESENT	0
447953	439816	19723Y	PARTICIPANT	\N	PRESENT	0
447954	439816	04088S	PARTICIPANT	\N	PRESENT	0
447955	439816	04034C	PARTICIPANT	\N	PRESENT	0
447956	439816	95030B	PARTICIPANT	\N	PRESENT	0
447957	439816	08019V	PARTICIPANT	\N	PRESENT	0
447958	439816	14083S	PARTICIPANT	\N	PRESENT	0
447959	439816	04057K	PARTICIPANT	\N	PRESENT	0
447960	439816	11031D	PARTICIPANT	\N	PRESENT	0
447961	439816	19347U	PARTICIPANT	\N	PRESENT	0
447965	439816	19735D	PARTICIPANT	\N	PRESENT	0
447963	439816	14157T	PARTICIPANT	\N	PRESENT	0
447964	439816	95063L	PARTICIPANT	\N	PRESENT	0
447966	439816	04033B	PARTICIPANT	\N	PRESENT	0
447967	439816	19515S	PARTICIPANT	\N	PRESENT	0
447968	439816	11097X	PARTICIPANT	\N	PRESENT	0
447969	439816	08020N	PARTICIPANT	\N	PRESENT	0
447970	439816	11012A	PARTICIPANT	\N	PRESENT	0
447971	439816	19575F	PARTICIPANT	\N	PRESENT	0
447972	439816	10006L	PARTICIPANT	\N	PRESENT	0
447973	439816	04018C	PARTICIPANT	\N	PRESENT	0
447974	439816	19503N	PARTICIPANT	\N	PRESENT	0
447975	439816	19697Q	PARTICIPANT	\N	PRESENT	0
447976	439816	14097Y	PARTICIPANT	\N	PRESENT	0
447977	439816	19443T	PARTICIPANT	\N	PRESENT	0
447978	439816	14231L	PARTICIPANT	\N	PRESENT	0
447979	439816	19629C	PARTICIPANT	\N	PRESENT	0
447980	439816	05008E	PARTICIPANT	\N	PRESENT	0
447981	439816	14042U	PARTICIPANT	\N	PRESENT	0
447982	439816	19333N	PARTICIPANT	\N	PRESENT	0
447983	439816	08049C	PARTICIPANT	\N	PRESENT	0
447984	439816	19681G	PARTICIPANT	\N	PRESENT	0
447985	439816	19749K	PARTICIPANT	\N	PRESENT	0
447986	439816	19713W	PARTICIPANT	\N	PRESENT	0
447987	439816	19637C	PARTICIPANT	\N	PRESENT	0
447988	439816	19619A	PARTICIPANT	\N	PRESENT	0
447989	439816	19703U	PARTICIPANT	\N	PRESENT	0
447990	439816	14061L	PARTICIPANT	\N	PRESENT	0
447991	439816	14073Q	PARTICIPANT	\N	PRESENT	0
447992	439816	14059S	PARTICIPANT	\N	PRESENT	0
447993	439816	11056N	PARTICIPANT	\N	PRESENT	0
447995	439816	19525U	PARTICIPANT	\N	PRESENT	0
447998	439816	98024R	PARTICIPANT	\N	PRESENT	0
447999	439816	14265W	PARTICIPANT	\N	PRESENT	0
448000	439816	11101A	PARTICIPANT	\N	PRESENT	0
448001	439816	18083K	PARTICIPANT	\N	PRESENT	0
448002	439816	14038Y	PARTICIPANT	\N	PRESENT	0
448003	439816	19673G	PARTICIPANT	\N	PRESENT	0
448004	439816	19369B	PARTICIPANT	\N	PRESENT	0
448005	439816	19521Q	PARTICIPANT	\N	PRESENT	0
448006	439816	14255U	PARTICIPANT	\N	PRESENT	0
448007	439816	14251Q	PARTICIPANT	\N	PRESENT	0
448008	439816	19479G	PARTICIPANT	\N	PRESENT	0
448009	439816	14029X	PARTICIPANT	\N	PRESENT	0
448010	439816	14151M	PARTICIPANT	\N	PRESENT	0
448011	439816	08069G	PARTICIPANT	\N	PRESENT	0
448012	439816	08024S	PARTICIPANT	\N	PRESENT	0
448014	439816	08039A	PARTICIPANT	\N	PRESENT	0
448015	439816	89017R	PARTICIPANT	\N	PRESENT	0
448016	439816	19441R	PARTICIPANT	\N	PRESENT	0
448028	439816	14135M	PARTICIPANT	\N	PRESENT	0
448032	439816	19794Q	PARTICIPANT	\N	PRESENT	0
448033	439816	14257W	PARTICIPANT	\N	PRESENT	0
448034	439816	19691J	PARTICIPANT	\N	PRESENT	0
448036	439816	19543W	PARTICIPANT	\N	PRESENT	0
448038	439816	19621T	PARTICIPANT	\N	PRESENT	0
448039	439816	11065P	PARTICIPANT	\N	PRESENT	0
448040	439816	01028R	PARTICIPANT	\N	PRESENT	0
448041	439816	14179A	PARTICIPANT	\N	PRESENT	0
448042	439816	19782L	PARTICIPANT	\N	PRESENT	0
448043	439816	19585H	PARTICIPANT	\N	PRESENT	0
448044	439816	08015R	PARTICIPANT	\N	PRESENT	0
448055	439816	14089Y	PARTICIPANT	\N	PRESENT	0
448056	439816	08043V	PARTICIPANT	\N	PRESENT	0
448057	439816	14237S	PARTICIPANT	\N	PRESENT	0
448058	439816	14249W	PARTICIPANT	\N	PRESENT	0
448059	439816	14069U	PARTICIPANT	\N	PRESENT	0
448060	439816	11027H	PARTICIPANT	\N	PRESENT	0
425201	414419	19741B	PARTICIPANT	\N	PRESENT	0
425351	414419	08069G	PARTICIPANT	\N	EXCUSE	0
425353	414419	89017R	PARTICIPANT	\N	EXCUSE	0
425464	423002	08024S	PARTICIPANT	\N	PRESENT	0
425485	423003	08024S	PARTICIPANT	\N	PRESENT	0
425685	414419	19399H	PARTICIPANT	\N	PRESENT	0
431012	431010	19253P	PARTICIPANT	\N	PRESENT	0
431014	431013	19253P	PARTICIPANT	\N	PRESENT	0
431017	431016	19253P	PARTICIPANT	\N	PRESENT	0
431019	431018	19253P	PARTICIPANT	\N	PRESENT	0
432555	431062	11070L	PARTICIPANT	\N	PRESENT	0
432556	431062	07029T	PARTICIPANT	\N	PRESENT	0
432557	431062	07004J	PARTICIPANT	\N	PRESENT	0
432558	431062	96004D	PARTICIPANT	\N	PRESENT	0
432559	431062	19349W	PARTICIPANT	\N	PRESENT	0
432560	431062	08010L	PARTICIPANT	\N	PRESENT	0
432561	431062	14253S	PARTICIPANT	\N	PRESENT	0
432562	431062	11048N	PARTICIPANT	\N	PRESENT	0
432563	431062	19479G	PARTICIPANT	\N	PRESENT	0
432564	431062	19711U	PARTICIPANT	\N	PRESENT	0
432565	431062	19651A	PARTICIPANT	\N	PRESENT	0
432566	431062	08069G	PARTICIPANT	\N	PRESENT	0
432567	431062	08014Q	PARTICIPANT	\N	PRESENT	0
432568	431062	14159V	PARTICIPANT	\N	PRESENT	0
432569	431062	14173T	PARTICIPANT	\N	PRESENT	0
432570	431062	14083S	PARTICIPANT	\N	PRESENT	0
432571	431062	11012A	PARTICIPANT	\N	PRESENT	0
432572	431062	14121F	PARTICIPANT	\N	PRESENT	0
432573	431062	99004R	PARTICIPANT	\N	PRESENT	0
432574	430646	14097Y	PARTICIPANT	\N	PRESENT	0
432575	432047	19735D	PARTICIPANT	\N	PRESENT	0
432576	431062	19545Y	PARTICIPANT	\N	PRESENT	0
432577	431062	14085U	PARTICIPANT	\N	PRESENT	0
432578	431062	01057W	PARTICIPANT	\N	PRESENT	0
432579	431062	04086Q	PARTICIPANT	\N	PRESENT	0
432580	431062	19689Q	PARTICIPANT	\N	PRESENT	0
432581	431062	14034U	PARTICIPANT	\N	PRESENT	0
432582	430836	01043Q	PARTICIPANT	\N	PRESENT	0
432583	430836	19441R	PARTICIPANT	\N	PRESENT	0
432584	430836	80013X	PARTICIPANT	\N	PRESENT	0
432585	430836	19591F	PARTICIPANT	\N	PRESENT	0
432586	430836	19269X	PARTICIPANT	\N	PRESENT	0
432587	430836	14205J	PARTICIPANT	\N	PRESENT	0
432588	432047	07033P	PARTICIPANT	\N	PRESENT	0
432589	431062	04071H	PARTICIPANT	\N	PRESENT	0
432590	430770	14001X	PARTICIPANT	\N	PRESENT	0
432591	430770	01060R	PARTICIPANT	\N	PRESENT	0
432592	430770	19543W	PARTICIPANT	\N	PRESENT	0
432593	430770	04044E	PARTICIPANT	\N	PRESENT	0
432594	430770	19581D	PARTICIPANT	\N	PRESENT	0
432595	430770	19585H	PARTICIPANT	\N	PRESENT	0
432596	430770	14231L	PARTICIPANT	\N	PRESENT	0
432597	430770	19447X	PARTICIPANT	\N	PRESENT	0
432598	430770	19489J	PARTICIPANT	\N	PRESENT	0
432599	430770	14147R	PARTICIPANT	\N	PRESENT	0
432600	430770	08018U	PARTICIPANT	\N	PRESENT	0
432601	430770	14259Y	PARTICIPANT	\N	PRESENT	0
432602	430770	11072N	PARTICIPANT	\N	PRESENT	0
432603	430770	14053L	PARTICIPANT	\N	PRESENT	0
432604	430770	98035U	PARTICIPANT	\N	PRESENT	0
432605	430770	14111D	PARTICIPANT	\N	PRESENT	0
432606	430770	14065Q	PARTICIPANT	\N	PRESENT	0
432607	430770	11010L	PARTICIPANT	\N	PRESENT	0
432608	430770	10015M	PARTICIPANT	\N	PRESENT	0
432609	430770	04038G	PARTICIPANT	\N	PRESENT	0
432610	430770	11033F	PARTICIPANT	\N	PRESENT	0
432611	430770	19725B	PARTICIPANT	\N	PRESENT	0
432612	430770	14089Y	PARTICIPANT	\N	PRESENT	0
432613	430770	19729F	PARTICIPANT	\N	PRESENT	0
432614	430770	19629C	PARTICIPANT	\N	PRESENT	0
432615	430770	14069U	PARTICIPANT	\N	PRESENT	0
432616	430770	11049P	PARTICIPANT	\N	PRESENT	0
432617	430770	19762G	PARTICIPANT	\N	PRESENT	0
432618	430770	08045X	PARTICIPANT	\N	PRESENT	0
432619	430770	14151M	PARTICIPANT	\N	PRESENT	0
432620	430770	11085T	PARTICIPANT	\N	PRESENT	0
432621	430770	04047H	PARTICIPANT	\N	PRESENT	0
432622	430770	14021P	PARTICIPANT	\N	PRESENT	0
432623	431062	19647E	PARTICIPANT	\N	PRESENT	0
432626	431062	19531S	PARTICIPANT	\N	PRESENT	0
432631	430646	19709B	PARTICIPANT	\N	PRESENT	0
432628	431062	08034U	PARTICIPANT	\N	PRESENT	0
432633	431062	14199E	PARTICIPANT	\N	EXCUSE	0
432630	431062	08011M	PARTICIPANT	\N	EXCUSE	0
432632	430646	19583F	PARTICIPANT	\N	PRESENT	0
432634	430836	11077T	PARTICIPANT	\N	PRESENT	0
432635	430836	11099A	PARTICIPANT	\N	PRESENT	0
432636	430836	08028W	PARTICIPANT	\N	PRESENT	0
432637	430844	19333N	PARTICIPANT	\N	PRESENT	0
432638	430844	19383Y	PARTICIPANT	\N	PRESENT	0
432639	430844	17583W	PARTICIPANT	\N	PRESENT	0
432640	430844	19794Q	PARTICIPANT	\N	PRESENT	0
432641	430844	04069P	PARTICIPANT	\N	PRESENT	0
432642	430844	19549D	PARTICIPANT	\N	PRESENT	0
432643	430844	19387D	PARTICIPANT	\N	PRESENT	0
432644	430844	19820Y	PARTICIPANT	\N	PRESENT	0
432645	430844	14219Q	PARTICIPANT	\N	PRESENT	0
432646	430844	19826F	PARTICIPANT	\N	PRESENT	0
432647	430844	14221J	PARTICIPANT	\N	PRESENT	0
432648	430844	19599P	PARTICIPANT	\N	PRESENT	0
432649	430844	19637C	PARTICIPANT	\N	PRESENT	0
432650	430844	18083K	PARTICIPANT	\N	PRESENT	0
432651	430844	14237S	PARTICIPANT	\N	PRESENT	0
432652	430844	05012A	PARTICIPANT	\N	PRESENT	0
432653	430844	08060W	PARTICIPANT	\N	PRESENT	0
432654	430844	19347U	PARTICIPANT	\N	PRESENT	0
432655	430844	19503N	PARTICIPANT	\N	PRESENT	0
432656	430844	14157T	PARTICIPANT	\N	PRESENT	0
432657	430844	19685L	PARTICIPANT	\N	PRESENT	0
432658	430844	08024S	PARTICIPANT	\N	PRESENT	0
432659	430844	19681G	PARTICIPANT	\N	PRESENT	0
432660	430844	17637T	PARTICIPANT	\N	PRESENT	0
432661	430844	19525U	PARTICIPANT	\N	PRESENT	0
432662	430844	14038Y	PRESIDENT	0	PRESENT	0
432663	430844	14103D	PARTICIPANT	\N	PRESENT	0
432664	430844	14031R	PARTICIPANT	\N	PRESENT	0
432665	430844	19713W	PARTICIPANT	\N	PRESENT	0
432666	430844	08055A	PARTICIPANT	\N	PRESENT	0
432667	430844	14169X	PARTICIPANT	\N	PRESENT	0
432668	430844	04085P	PARTICIPANT	\N	PRESENT	0
432669	430844	15447F	PARTICIPANT	\N	PRESENT	0
432670	430844	14093U	PARTICIPANT	\N	PRESENT	0
432671	430844	14029X	PARTICIPANT	\N	PRESENT	0
432672	430844	19733B	PARTICIPANT	\N	PRESENT	0
432673	430844	08009T	PARTICIPANT	\N	PRESENT	0
432674	430844	04097T	PARTICIPANT	\N	PRESENT	0
432675	430844	19739H	PARTICIPANT	\N	PRESENT	0
432676	430844	19745F	PARTICIPANT	\N	PRESENT	0
432677	430844	14051J	PARTICIPANT	\N	EXCUSE	0
432680	430309	11031D	PARTICIPANT	\N	PRESENT	0
432681	430309	19527W	PARTICIPANT	\N	PRESENT	0
432682	430309	19663E	PARTICIPANT	\N	PRESENT	0
432683	430309	14071N	PARTICIPANT	\N	PRESENT	0
432685	425280	04059M	PARTICIPANT	\N	PRESENT	0
432686	425280	08048B	PARTICIPANT	\N	PRESENT	0
432687	425280	07029T	PARTICIPANT	\N	PRESENT	0
432688	425280	01062T	PARTICIPANT	\N	PRESENT	0
432689	425280	19333N	PARTICIPANT	\N	PRESENT	0
432690	425280	19527W	PARTICIPANT	\N	PRESENT	0
432691	425280	11109J	PARTICIPANT	\N	PRESENT	0
432692	425280	14121F	PARTICIPANT	\N	PRESENT	0
432693	425280	14241N	PARTICIPANT	\N	PRESENT	0
432694	425280	17589D	PARTICIPANT	\N	PRESENT	0
432695	425280	19441R	PARTICIPANT	\N	PRESENT	0
432696	425280	11056N	PARTICIPANT	\N	PRESENT	0
432697	425280	19727D	PARTICIPANT	\N	PRESENT	0
432698	425280	14281W	PARTICIPANT	\N	PRESENT	0
432699	425280	19565D	PARTICIPANT	\N	PRESENT	0
432700	425280	14195A	PARTICIPANT	\N	PRESENT	0
432701	425280	19691J	PARTICIPANT	\N	PRESENT	0
432702	425280	11012A	PARTICIPANT	\N	PRESENT	0
432703	425280	11048N	PARTICIPANT	\N	PRESENT	0
432704	425280	19711U	PARTICIPANT	\N	PRESENT	0
432705	425280	14041T	PARTICIPANT	\N	PRESENT	0
432706	425280	14119M	PARTICIPANT	\N	PRESENT	0
432707	425280	19667J	PARTICIPANT	\N	PRESENT	0
432708	425280	19415P	PARTICIPANT	\N	PRESENT	0
432709	425280	19794Q	PARTICIPANT	\N	PRESENT	0
432710	425280	19679N	PARTICIPANT	\N	PRESENT	0
432711	425280	19703U	PARTICIPANT	\N	PRESENT	0
432712	425280	14191V	PARTICIPANT	\N	PRESENT	0
432713	425280	15447F	PARTICIPANT	\N	PRESENT	0
432714	425280	04092N	PARTICIPANT	\N	PRESENT	0
432715	425280	14073Q	PARTICIPANT	\N	PRESENT	0
432716	425280	11097X	PARTICIPANT	\N	PRESENT	0
432717	425280	19657G	PARTICIPANT	\N	PRESENT	0
432719	425280	14217N	PARTICIPANT	\N	PRESENT	0
432720	425280	14071N	PARTICIPANT	\N	PRESENT	0
445141	445137	19467C	PARTICIPANT	\N	PRESENT	0
445143	445137	19667J	PARTICIPANT	\N	PRESENT	0
445145	445137	14069U	PARTICIPANT	\N	PRESENT	0
445147	445137	19441R	PARTICIPANT	\N	PRESENT	0
445160	445137	19762G	PARTICIPANT	\N	PRESENT	0
445151	445137	19735D	PARTICIPANT	\N	PRESENT	0
445161	445137	19713W	PARTICIPANT	\N	PRESENT	0
445159	445137	19269X	PARTICIPANT	\N	PRESENT	0
445162	445137	14207L	PARTICIPANT	\N	PRESENT	0
445163	445137	08028W	PARTICIPANT	\N	PRESENT	0
445164	445137	19693L	PARTICIPANT	\N	PRESENT	0
445165	445137	01025N	PARTICIPANT	\N	PRESENT	0
445166	445137	14109K	PARTICIPANT	\N	PRESENT	0
445167	445137	11097X	PARTICIPANT	\N	PRESENT	0
445168	445137	04045F	PARTICIPANT	\N	PRESENT	0
445595	445594	14026U	PARTICIPANT	\N	PRESENT	0
445948	442327	19737F	PARTICIPANT	\N	PRESENT	0
445951	442327	08062Y	PARTICIPANT	\N	EXCUSE	0
446027	446026	19667J	PARTICIPANT	\N	PRESENT	0
446028	446026	14255U	PARTICIPANT	\N	PRESENT	0
446029	446026	14038Y	PARTICIPANT	\N	PRESENT	0
446030	446026	19701S	PARTICIPANT	\N	PRESENT	0
446031	446026	19693L	PARTICIPANT	\N	PRESENT	0
446032	446026	19762G	PARTICIPANT	\N	PRESENT	0
446033	446026	19671E	PARTICIPANT	\N	PRESENT	0
446034	446026	11026G	PARTICIPANT	\N	PRESENT	0
447037	442327	19629C	PARTICIPANT	\N	PRESENT	0
447198	445943	96004D	PARTICIPANT	\N	EXCUSE	0
448409	444733	14030Q	PRESIDENT	0	PRESENT	0
448410	444733	08043V	PARTICIPANT	\N	PRESENT	0
448411	444733	14179A	PARTICIPANT	\N	PRESENT	0
448412	444733	08017T	PARTICIPANT	\N	PRESENT	0
448413	444733	19715Y	PARTICIPANT	\N	EXCUSE	0
448414	444733	07029T	PARTICIPANT	\N	EXCUSE	0
448415	444733	14235Q	PARTICIPANT	\N	EXCUSE	0
448491	448490	11074Q	PARTICIPANT	\N	PRESENT	0
448592	448591	14229S	PARTICIPANT	\N	PRESENT	0
448593	448591	04057K	PARTICIPANT	\N	PRESENT	0
448595	448594	14229S	PARTICIPANT	\N	PRESENT	0
448596	448594	04057K	PARTICIPANT	\N	PRESENT	0
448793	445989	14239U	PARTICIPANT	\N	PRESENT	0
448939	439821	19553Y	PARTICIPANT	\N	PRESENT	0
448940	439821	14255U	PARTICIPANT	\N	PRESENT	0
448941	439821	19826F	PARTICIPANT	\N	PRESENT	0
448942	439821	19798U	PARTICIPANT	\N	PRESENT	0
448943	439821	14026U	PARTICIPANT	\N	PRESENT	0
448944	439821	01058X	PARTICIPANT	\N	PRESENT	0
448945	439821	19794Q	PARTICIPANT	\N	PRESENT	0
448946	439821	19575F	PARTICIPANT	\N	PRESENT	0
448947	439821	19533U	PARTICIPANT	\N	PRESENT	0
448948	439821	14213J	PARTICIPANT	\N	PRESENT	0
448949	439821	98024R	PARTICIPANT	\N	PRESENT	0
448950	439821	14265W	PARTICIPANT	\N	PRESENT	0
448951	439821	14157T	PARTICIPANT	\N	PRESENT	0
448952	439821	10015M	PARTICIPANT	\N	PRESENT	0
448953	439821	99004R	PARTICIPANT	\N	PRESENT	0
448954	439821	14215L	PARTICIPANT	\N	PRESENT	0
448955	439821	11056N	PARTICIPANT	\N	PRESENT	0
448956	439821	11040E	PARTICIPANT	\N	PRESENT	0
448957	439821	11045K	PARTICIPANT	\N	PRESENT	0
448958	439821	14147R	PARTICIPANT	\N	PRESENT	0
448959	439821	17589D	PARTICIPANT	\N	PRESENT	0
448960	439821	19581D	PARTICIPANT	\N	PRESENT	0
448961	439821	08015R	PARTICIPANT	\N	PRESENT	0
448962	439821	11066Q	PARTICIPANT	\N	PRESENT	0
448963	439821	19649G	PARTICIPANT	\N	PRESENT	0
448964	439821	14105F	PARTICIPANT	\N	PRESENT	0
448965	439821	19695N	PARTICIPANT	\N	PRESENT	0
448966	439821	08052W	PARTICIPANT	\N	PRESENT	0
448967	439821	11074Q	PARTICIPANT	\N	PRESENT	0
448968	439821	19760E	PARTICIPANT	\N	PRESENT	0
448969	439821	19703U	PARTICIPANT	\N	PRESENT	0
448970	439821	14089Y	PARTICIPANT	\N	PRESENT	0
449011	439821	17583W	PARTICIPANT	\N	PRESENT	0
449012	439821	08039A	PARTICIPANT	\N	PRESENT	0
449013	439821	19335Q	PARTICIPANT	\N	PRESENT	0
449014	439821	14231L	PARTICIPANT	\N	PRESENT	0
449015	439821	14033T	PARTICIPANT	\N	PRESENT	0
449016	439821	11043H	PARTICIPANT	\N	PRESENT	0
449017	439821	19441R	PARTICIPANT	\N	PRESENT	0
449018	439821	19295A	PARTICIPANT	\N	PRESENT	0
449019	439821	08045X	PARTICIPANT	\N	PRESENT	0
449020	439821	05008E	PARTICIPANT	\N	PRESENT	0
449021	439821	19467C	PARTICIPANT	\N	PRESENT	0
449022	439821	19413M	PARTICIPANT	\N	PRESENT	0
449023	439821	19691J	PARTICIPANT	\N	PRESENT	0
449024	439821	14030Q	PARTICIPANT	\N	PRESENT	0
449025	439821	19749K	PARTICIPANT	\N	PRESENT	0
449026	439821	08020N	PARTICIPANT	\N	PRESENT	0
449027	439821	12041X	PARTICIPANT	\N	PRESENT	0
449028	439821	01028R	PARTICIPANT	\N	PRESENT	0
449029	439821	19507S	PARTICIPANT	\N	PRESENT	0
445112	445109	14135M	PARTICIPANT	\N	PRESENT	0
445113	445109	14033T	PARTICIPANT	\N	PRESENT	0
449030	439821	19747H	PARTICIPANT	\N	PRESENT	0
449031	439821	04043D	PARTICIPANT	\N	PRESENT	0
449032	439821	19349W	PARTICIPANT	\N	PRESENT	0
449033	439821	14133K	PARTICIPANT	\N	PRESENT	0
449034	439821	14151M	PARTICIPANT	\N	PRESENT	0
449035	439821	87003B	PARTICIPANT	\N	PRESENT	0
449036	439821	19549D	PARTICIPANT	\N	PRESENT	0
449037	439821	19489J	PARTICIPANT	\N	PRESENT	0
449038	439821	19563B	PARTICIPANT	\N	PRESENT	0
449039	439821	04069P	PARTICIPANT	\N	PRESENT	0
449040	439821	19369B	PARTICIPANT	\N	PRESENT	0
449041	439821	19643A	PARTICIPANT	\N	PRESENT	0
449042	439821	19621T	PARTICIPANT	\N	PRESENT	0
449043	439821	14135M	PARTICIPANT	\N	PRESENT	0
449044	439821	04071H	PARTICIPANT	\N	PRESENT	0
449045	439821	19367Y	PARTICIPANT	\N	PRESENT	0
449050	439821	14169X	PARTICIPANT	\N	PRESENT	0
449051	439821	19527W	PARTICIPANT	\N	PRESENT	0
449052	439821	14197C	PARTICIPANT	\N	PRESENT	0
449053	439821	11101A	PARTICIPANT	\N	PRESENT	0
449054	439821	14119M	PARTICIPANT	\N	PRESENT	0
449055	439821	14021P	PARTICIPANT	\N	PRESENT	0
449056	439821	14259Y	PARTICIPANT	\N	PRESENT	0
449057	439821	19667J	PARTICIPANT	\N	PRESENT	0
449058	439821	04085P	PARTICIPANT	\N	PRESENT	0
449059	439821	11033F	PARTICIPANT	\N	PRESENT	0
449078	449077	11027H	PARTICIPANT	\N	PRESENT	0
449096	449095	14229S	PARTICIPANT	\N	PRESENT	0
449097	449095	04057K	PARTICIPANT	\N	PRESENT	0
449972	439823	19549D	PARTICIPANT	\N	PRESENT	0
449973	439823	14357A	PARTICIPANT	\N	PRESENT	0
449975	439823	19675J	PARTICIPANT	\N	PRESENT	0
449976	439823	08038Y	PARTICIPANT	\N	PRESENT	0
449977	439823	19383Y	PARTICIPANT	\N	PRESENT	0
449978	439823	11083R	PARTICIPANT	\N	PRESENT	0
449979	439823	04018C	PARTICIPANT	\N	PRESENT	0
449980	439823	08073C	PARTICIPANT	\N	PRESENT	0
449981	439823	14251Q	PARTICIPANT	\N	PRESENT	0
449982	439823	19621T	PARTICIPANT	\N	PRESENT	0
449983	439823	19812Y	PARTICIPANT	\N	PRESENT	0
449984	439823	19367Y	PARTICIPANT	\N	PRESENT	0
449985	439823	19725B	PARTICIPANT	\N	PRESENT	0
449986	439823	14281W	PARTICIPANT	\N	PRESENT	0
449987	439823	19447X	PARTICIPANT	\N	PRESENT	0
449988	439823	19527W	PARTICIPANT	\N	PRESENT	0
449989	439823	14133K	PARTICIPANT	\N	PRESENT	0
449990	439823	14001X	PARTICIPANT	\N	PRESENT	0
449991	439823	92040Q	PARTICIPANT	\N	PRESENT	0
449992	439823	14115H	PARTICIPANT	\N	PRESENT	0
449993	439823	14151M	PARTICIPANT	\N	PRESENT	0
449994	439823	19794Q	PARTICIPANT	\N	PRESENT	0
449995	439823	08048B	PARTICIPANT	\N	PRESENT	0
449996	439823	19531S	PARTICIPANT	\N	PRESENT	0
449997	439823	19820Y	PARTICIPANT	\N	PRESENT	0
449998	439823	14147R	PARTICIPANT	\N	PRESENT	0
449999	439823	14085U	PARTICIPANT	\N	PRESENT	0
450000	439823	17583W	PARTICIPANT	\N	PRESENT	0
450001	439823	11103C	PARTICIPANT	\N	PRESENT	0
450002	439823	19683J	PARTICIPANT	\N	PRESENT	0
450003	439823	07033P	PARTICIPANT	\N	PRESENT	0
450004	439823	04069P	PARTICIPANT	\N	PRESENT	0
450005	439823	19503N	PARTICIPANT	\N	PRESENT	0
450006	439823	14331P	PARTICIPANT	\N	PRESENT	0
450007	439823	11026G	PARTICIPANT	\N	PRESENT	0
450009	439823	14079W	PARTICIPANT	\N	PRESENT	0
450010	439823	19489J	PARTICIPANT	\N	PRESENT	0
450011	439823	11099A	PARTICIPANT	\N	PRESENT	0
450012	439823	19581D	PARTICIPANT	\N	PRESENT	0
450013	439823	19565D	PARTICIPANT	\N	PRESENT	0
450014	439823	19671E	PARTICIPANT	\N	PRESENT	0
450016	439823	08014Q	PARTICIPANT	\N	PRESENT	0
450017	439823	14061L	PARTICIPANT	\N	PRESENT	0
450018	439823	19703U	PARTICIPANT	\N	PRESENT	0
450019	439823	14111D	PARTICIPANT	\N	PRESENT	0
450020	439823	19673G	PARTICIPANT	\N	PRESENT	0
427328	426125	04059M	PARTICIPANT	\N	EXCUSE	0
428845	428807	08039A	PARTICIPANT	\N	PRESENT	0
428846	428807	19399H	PARTICIPANT	\N	PRESENT	0
428848	428807	08043V	PARTICIPANT	\N	PRESENT	0
428849	428807	11083R	PARTICIPANT	\N	PRESENT	0
429075	429074	04043D	PARTICIPANT	\N	PRESENT	0
429395	422590	11109J	PARTICIPANT	\N	PRESENT	0
429396	422590	14261S	PARTICIPANT	\N	PRESENT	0
431565	431563	19691J	PARTICIPANT	\N	PRESENT	0
431566	431564	19691J	PARTICIPANT	\N	PRESENT	0
431577	431575	08043V	PARTICIPANT	\N	PRESENT	0
431578	431575	11031D	PARTICIPANT	\N	PRESENT	0
431579	431575	19683J	PARTICIPANT	\N	PRESENT	0
431580	431575	11067R	PARTICIPANT	\N	PRESENT	0
431582	431576	08043V	PARTICIPANT	\N	PRESENT	0
431583	431576	11031D	PARTICIPANT	\N	PRESENT	0
431584	431576	19683J	PARTICIPANT	\N	PRESENT	0
435333	435332	19747H	PARTICIPANT	\N	PRESENT	0
435334	435332	14033T	PARTICIPANT	\N	PRESENT	0
435335	435332	04088S	PARTICIPANT	\N	PRESENT	0
435336	435332	19619A	PARTICIPANT	\N	PRESENT	0
435337	435332	19533U	PARTICIPANT	\N	PRESENT	0
435338	435332	19503N	PARTICIPANT	\N	PRESENT	0
435339	435332	19333N	PARTICIPANT	\N	PRESENT	0
435419	425611	14261S	PARTICIPANT	\N	PRESENT	0
435420	425611	11012A	PARTICIPANT	\N	PRESENT	0
435421	425611	14038Y	PARTICIPANT	\N	PRESENT	0
435422	425611	11097X	PARTICIPANT	\N	PRESENT	0
435423	425611	11048N	PARTICIPANT	\N	PRESENT	0
435424	425611	14085U	PARTICIPANT	\N	PRESENT	0
435425	425611	14253S	PARTICIPANT	\N	PRESENT	0
435426	425611	17779H	PARTICIPANT	\N	PRESENT	0
435427	425611	04092N	PARTICIPANT	\N	PRESENT	0
435428	425611	11070L	PARTICIPANT	\N	PRESENT	0
435429	425611	19679N	PARTICIPANT	\N	PRESENT	0
435430	425611	08034U	PARTICIPANT	\N	PRESENT	0
435431	425611	14147R	PARTICIPANT	\N	PRESENT	0
435432	425611	19521Q	PARTICIPANT	\N	PRESENT	0
435433	425611	04033B	PARTICIPANT	\N	PRESENT	0
435434	425611	08014Q	PARTICIPANT	\N	PRESENT	0
435435	425611	19741B	PARTICIPANT	\N	PRESENT	0
435436	425611	14215L	PARTICIPANT	\N	PRESENT	0
435437	425611	14159V	PARTICIPANT	\N	PRESENT	0
435438	425611	14265W	PARTICIPANT	\N	PRESENT	0
435439	425611	07029T	PARTICIPANT	\N	PRESENT	0
435440	425611	14329V	PARTICIPANT	\N	PRESENT	0
435441	425611	99004R	PARTICIPANT	\N	PRESENT	0
435442	425611	11099A	PARTICIPANT	\N	PRESENT	0
435443	425611	14255U	PARTICIPANT	\N	PRESENT	0
435444	425611	14357A	PARTICIPANT	\N	PRESENT	0
435445	425611	11074Q	PARTICIPANT	\N	PRESENT	0
435446	425611	08011M	PARTICIPANT	\N	PRESENT	0
435447	425611	12041X	PARTICIPANT	\N	PRESENT	0
435448	425611	14031R	PARTICIPANT	\N	PRESENT	0
435491	425616	08034U	PARTICIPANT	\N	PRESENT	0
435492	425616	14235Q	PARTICIPANT	\N	PRESENT	0
435493	425616	11054L	PARTICIPANT	\N	PRESENT	0
435494	425616	12041X	PARTICIPANT	\N	PRESENT	0
435495	425616	01062T	PARTICIPANT	\N	PRESENT	0
435496	425616	11027H	PARTICIPANT	\N	PRESENT	0
435497	425616	19782L	PARTICIPANT	\N	PRESENT	0
435498	425616	19545Y	PARTICIPANT	\N	PRESENT	0
435499	425616	19521Q	PARTICIPANT	\N	PRESENT	0
435500	425616	19737F	PARTICIPANT	\N	PRESENT	0
435501	425616	14267Y	PARTICIPANT	\N	PRESENT	0
435502	425616	14133K	PARTICIPANT	\N	PRESENT	0
435503	425616	19709B	PARTICIPANT	\N	PRESENT	0
435504	425616	19741B	PARTICIPANT	\N	PRESENT	0
435505	425616	14253S	PARTICIPANT	\N	PRESENT	0
435506	425616	95037J	PARTICIPANT	\N	PRESENT	0
435507	425616	19651A	PARTICIPANT	\N	PRESENT	0
435508	425616	19421M	PARTICIPANT	\N	PRESENT	0
435509	425616	08058D	PARTICIPANT	\N	PRESENT	0
435510	425616	01048V	PARTICIPANT	\N	PRESENT	0
435511	425616	98022P	PARTICIPANT	\N	PRESENT	0
435512	425616	19251M	PARTICIPANT	\N	PRESENT	0
435513	425616	08053X	PARTICIPANT	\N	PRESENT	0
435514	425616	14081Q	PARTICIPANT	\N	PRESENT	0
435515	425616	11074Q	PARTICIPANT	\N	PRESENT	0
435516	425616	04033B	PARTICIPANT	\N	PRESENT	0
435517	425616	08069G	PARTICIPANT	\N	PRESENT	0
435518	425616	19739H	PARTICIPANT	\N	PRESENT	0
435519	425616	11064N	PARTICIPANT	\N	PRESENT	0
435520	425616	11048N	PARTICIPANT	\N	PRESENT	0
435521	425616	14329V	PARTICIPANT	\N	PRESENT	0
435522	425616	14357A	PARTICIPANT	\N	PRESENT	0
435523	425616	14135M	PARTICIPANT	\N	PRESENT	0
435524	425616	19479G	PARTICIPANT	\N	PRESENT	0
435525	425616	14147R	PARTICIPANT	\N	PRESENT	0
435526	425616	14121F	PARTICIPANT	\N	PRESENT	0
435527	425616	08010L	PARTICIPANT	\N	PRESENT	0
435528	425616	19669L	PARTICIPANT	\N	PRESENT	0
435529	425616	14255U	PARTICIPANT	\N	PRESENT	0
435530	425616	19713W	PARTICIPANT	\N	PRESENT	0
435489	425616	11070L	PARTICIPANT	\N	PRESENT	0
435490	425616	04042C	PARTICIPANT	\N	PRESENT	0
435531	425616	07029T	PARTICIPANT	\N	PRESENT	0
435532	425616	11085T	PARTICIPANT	\N	PRESENT	0
436548	434673	08012N	PARTICIPANT	\N	PRESENT	0
436549	434673	17589D	PARTICIPANT	\N	PRESENT	0
436550	434673	08058D	PARTICIPANT	\N	PRESENT	0
436551	434673	14255U	PARTICIPANT	\N	PRESENT	0
436552	434673	19525U	PARTICIPANT	\N	PRESENT	0
438768	437190	19659J	PARTICIPANT	\N	EXCUSE	0
439846	439845	19569H	PARTICIPANT	\N	PRESENT	0
439847	439845	14213J	PARTICIPANT	\N	PRESENT	0
439848	439845	19447X	PARTICIPANT	\N	PRESENT	0
439849	439845	19683J	PARTICIPANT	\N	PRESENT	0
439934	439933	14205J	PARTICIPANT	\N	PRESENT	0
439935	439933	14135M	PARTICIPANT	\N	PRESENT	0
439936	439933	14033T	PARTICIPANT	\N	PRESENT	0
439939	439937	19515S	PARTICIPANT	\N	PRESENT	0
439940	439937	14207L	PARTICIPANT	\N	PRESENT	0
439941	439937	14033T	PARTICIPANT	\N	PRESENT	0
439942	439937	19441R	PARTICIPANT	\N	PRESENT	0
439943	439937	14265W	PARTICIPANT	\N	PRESENT	0
439945	439944	19515S	PARTICIPANT	\N	PRESENT	0
439946	439944	14207L	PARTICIPANT	\N	PRESENT	0
439947	439944	14033T	PARTICIPANT	\N	PRESENT	0
439948	439944	19441R	PARTICIPANT	\N	PRESENT	0
439949	439944	19269X	PARTICIPANT	\N	PRESENT	0
439951	439950	19515S	PARTICIPANT	\N	PRESENT	0
439952	439950	14207L	PARTICIPANT	\N	PRESENT	0
439953	439950	14033T	PARTICIPANT	\N	PRESENT	0
439954	439950	19441R	PARTICIPANT	\N	PRESENT	0
439955	439950	19269X	PARTICIPANT	\N	PRESENT	0
439957	439956	19515S	PARTICIPANT	\N	PRESENT	0
439958	439956	14033T	PARTICIPANT	\N	PRESENT	0
439959	439956	14257W	PARTICIPANT	\N	PRESENT	0
439960	439956	19269X	PARTICIPANT	\N	PRESENT	0
439961	439956	14265W	PARTICIPANT	\N	PRESENT	0
439963	439962	19515S	PARTICIPANT	\N	PRESENT	0
439964	439962	14033T	PARTICIPANT	\N	PRESENT	0
439965	439962	14257W	PARTICIPANT	\N	PRESENT	0
439966	439962	14265W	PARTICIPANT	\N	PRESENT	0
439967	439962	19269X	PARTICIPANT	\N	PRESENT	0
439969	439968	19515S	PARTICIPANT	\N	PRESENT	0
439970	439968	14033T	PARTICIPANT	\N	PRESENT	0
439971	439968	14265W	PARTICIPANT	\N	PRESENT	0
439973	439972	14135M	PARTICIPANT	\N	PRESENT	0
441989	441789	19826F	PARTICIPANT	\N	EXCUSE	0
442171	442169	19503N	PARTICIPANT	\N	PRESENT	0
442173	442167	19503N	PARTICIPANT	\N	PRESENT	0
442176	442174	19503N	PARTICIPANT	\N	PRESENT	0
442182	442180	19503N	PARTICIPANT	\N	PRESENT	0
442188	442186	19503N	PARTICIPANT	\N	PRESENT	0
442191	442189	19503N	PARTICIPANT	\N	PRESENT	0
442776	442775	08034U	PARTICIPANT	\N	PRESENT	0
442876	442775	19741B	PARTICIPANT	\N	PRESENT	0
442877	442775	04040A	PARTICIPANT	\N	PRESENT	0
442878	442775	19367Y	PARTICIPANT	\N	PRESENT	0
442879	442775	97011G	PARTICIPANT	\N	PRESENT	0
442880	442775	04035D	PARTICIPANT	\N	PRESENT	0
442881	442775	14179A	PARTICIPANT	\N	PRESENT	0
442882	442775	07029T	PARTICIPANT	\N	PRESENT	0
442888	442775	11041F	PARTICIPANT	\N	PRESENT	0
442889	442775	95067Q	PARTICIPANT	\N	PRESENT	0
440530	438470	19565D	PARTICIPANT	\N	EXCUSE	0
441589	441588	14061L	PARTICIPANT	\N	PRESENT	0
448170	439817	04092N	PARTICIPANT	\N	PRESENT	0
448171	439817	11045K	PARTICIPANT	\N	PRESENT	0
448172	439817	19683J	PARTICIPANT	\N	PRESENT	0
448173	439817	19333N	PARTICIPANT	\N	PRESENT	0
448174	439817	08043V	PARTICIPANT	\N	PRESENT	0
448175	439817	99004R	PARTICIPANT	\N	PRESENT	0
448176	439817	19649G	PARTICIPANT	\N	PRESENT	0
448177	439817	14187A	PARTICIPANT	\N	PRESENT	0
448178	439817	11031D	PARTICIPANT	\N	PRESENT	0
448179	439817	05008E	PARTICIPANT	\N	PRESENT	0
448180	439817	04045F	PARTICIPANT	\N	PRESENT	0
448181	439817	19747H	PARTICIPANT	\N	PRESENT	0
448182	439817	19651A	PARTICIPANT	\N	PRESENT	0
448183	439817	14239U	PARTICIPANT	\N	PRESENT	0
448184	439817	19575F	PARTICIPANT	\N	PRESENT	0
448185	439817	19503N	PARTICIPANT	\N	PRESENT	0
448186	439817	19585H	PARTICIPANT	\N	PRESENT	0
448187	439817	14213J	PARTICIPANT	\N	PRESENT	0
448188	439817	14195A	PARTICIPANT	\N	PRESENT	0
448189	439817	14329V	PARTICIPANT	\N	PRESENT	0
448190	439817	19681G	PARTICIPANT	\N	PRESENT	0
448191	439817	19671E	PARTICIPANT	\N	PRESENT	0
448192	439817	14042U	PARTICIPANT	\N	PRESENT	0
448193	439817	14030Q	PARTICIPANT	\N	PRESENT	0
448194	439817	19737F	PARTICIPANT	\N	PRESENT	0
448195	439817	14079W	PARTICIPANT	\N	PRESENT	0
448196	439817	14275Y	PARTICIPANT	\N	PRESENT	0
448197	439817	08069G	PARTICIPANT	\N	PRESENT	0
448198	439817	19565D	PARTICIPANT	\N	PRESENT	0
448199	439817	19691J	PARTICIPANT	\N	PRESENT	0
448200	439817	18083K	PARTICIPANT	\N	PRESENT	0
448201	439817	19749K	PARTICIPANT	\N	PRESENT	0
448202	439817	14089Y	PARTICIPANT	\N	PRESENT	0
448203	439817	19467C	PARTICIPANT	\N	PRESENT	0
448204	439817	14231L	PARTICIPANT	\N	PRESENT	0
448205	439817	19335Q	PARTICIPANT	\N	PRESENT	0
448206	439817	14038Y	PARTICIPANT	\N	PRESENT	0
448207	439817	19621T	PARTICIPANT	\N	PRESENT	0
448208	439817	14029X	PARTICIPANT	\N	PRESENT	0
448209	439817	19553Y	PARTICIPANT	\N	PRESENT	0
448210	439817	04088S	PARTICIPANT	\N	PRESENT	0
448211	439817	08015R	PARTICIPANT	\N	PRESENT	0
448212	439817	14251Q	PARTICIPANT	\N	PRESENT	0
448213	439817	19551W	PARTICIPANT	\N	PRESENT	0
448214	439817	14061L	PARTICIPANT	\N	PRESENT	0
448215	439817	14217N	PARTICIPANT	\N	PRESENT	0
448216	439817	19697Q	PARTICIPANT	\N	PRESENT	0
448217	439817	11066Q	PARTICIPANT	\N	PRESENT	0
448218	439817	19569H	PARTICIPANT	\N	PRESENT	0
448219	439817	19415P	PARTICIPANT	\N	PRESENT	0
448220	439817	14031R	PARTICIPANT	\N	PRESENT	0
448221	439817	14265W	PARTICIPANT	\N	PRESENT	0
448222	439817	14065Q	PARTICIPANT	\N	PRESENT	0
448223	439817	08061X	PARTICIPANT	\N	PRESENT	0
448224	439817	14235Q	PARTICIPANT	\N	PRESENT	0
448225	439817	19687N	PARTICIPANT	\N	PRESENT	0
448226	439817	01024M	PARTICIPANT	\N	PRESENT	0
448227	439817	14215L	PARTICIPANT	\N	PRESENT	0
448228	439817	19713W	PARTICIPANT	\N	PRESENT	0
448229	439817	19673G	PARTICIPANT	\N	PRESENT	0
448230	439817	19798U	PARTICIPANT	\N	PRESENT	0
448231	439817	98024R	PARTICIPANT	\N	PRESENT	0
448168	439817	14034U	PARTICIPANT	\N	PRESENT	0
448169	439817	14097Y	PARTICIPANT	\N	PRESENT	0
448232	439817	89017R	PARTICIPANT	\N	PRESENT	0
448233	439817	11097X	PARTICIPANT	\N	PRESENT	0
448234	439817	08034U	PARTICIPANT	\N	PRESENT	0
448235	439817	04085P	PARTICIPANT	\N	PRESENT	0
448236	439817	11056N	PARTICIPANT	\N	PRESENT	0
448237	439817	19782L	PARTICIPANT	\N	PRESENT	0
448238	439817	04033B	PARTICIPANT	\N	PRESENT	0
448239	439817	11026G	PARTICIPANT	\N	PRESENT	0
448240	439817	19533U	PARTICIPANT	\N	PRESENT	0
448241	439817	14107H	PARTICIPANT	\N	PRESENT	0
448242	439817	19629C	PARTICIPANT	\N	PRESENT	0
448243	439817	19387D	PARTICIPANT	\N	PRESENT	0
448244	439817	14105F	PARTICIPANT	\N	PRESENT	0
448245	439817	08031R	PARTICIPANT	\N	PRESENT	0
448246	439817	14357A	PARTICIPANT	\N	PRESENT	0
448247	439817	14073Q	PARTICIPANT	\N	PRESENT	0
448248	439817	10006L	PARTICIPANT	\N	PRESENT	0
448249	439817	19521Q	PARTICIPANT	\N	PRESENT	0
448250	439817	11067R	PARTICIPANT	\N	PRESENT	0
448251	439817	19695N	PARTICIPANT	\N	PRESENT	0
448252	439817	19441R	PARTICIPANT	\N	PRESENT	0
448253	439817	14255U	PARTICIPANT	\N	PRESENT	0
448254	439817	19723Y	PARTICIPANT	\N	PRESENT	0
448255	439817	19647E	PARTICIPANT	\N	PRESENT	0
448268	448267	14265W	PARTICIPANT	\N	PRESENT	0
448269	448267	14237S	PARTICIPANT	\N	PRESENT	0
448276	441793	19565D	PARTICIPANT	\N	EXCUSE	0
448277	441793	19820Y	PARTICIPANT	\N	EXCUSE	0
448602	448601	08055A	PARTICIPANT	\N	PRESENT	0
448603	448601	04047H	PARTICIPANT	\N	PRESENT	0
448616	448613	14026U	PARTICIPANT	\N	PRESENT	0
448605	448601	14085U	PARTICIPANT	\N	PRESENT	0
448606	448601	11080N	PARTICIPANT	\N	PRESENT	0
448626	448625	11097X	PARTICIPANT	\N	PRESENT	0
448608	448601	01057W	PARTICIPANT	\N	PRESENT	0
448627	448624	11097X	PARTICIPANT	\N	PRESENT	0
448610	448601	19687N	PARTICIPANT	\N	PRESENT	0
448611	448601	08049C	PARTICIPANT	\N	PRESENT	0
448612	448601	14157T	PARTICIPANT	\N	PRESENT	0
448638	448637	11026G	PARTICIPANT	\N	PRESENT	0
448639	448637	14255U	PARTICIPANT	\N	PRESENT	0
448640	448637	19701S	PARTICIPANT	\N	PRESENT	0
448779	448632	04092N	PRESIDENT	0	PRESENT	0
448780	448632	05008E	PARTICIPANT	\N	PRESENT	0
448781	448632	14213J	PARTICIPANT	\N	PRESENT	0
448782	448632	19447X	PARTICIPANT	\N	PRESENT	0
448783	448632	08034U	PARTICIPANT	\N	PRESENT	0
448784	448632	14065Q	PARTICIPANT	\N	PRESENT	0
448785	448632	08052W	PARTICIPANT	\N	PRESENT	0
448786	448632	19569H	PARTICIPANT	\N	PRESENT	0
448787	448632	14179A	PARTICIPANT	\N	PRESENT	0
448788	448632	19553Y	PARTICIPANT	\N	PRESENT	0
448789	448632	11031D	PARTICIPANT	\N	PRESENT	0
448790	448632	99004R	PARTICIPANT	\N	PRESENT	0
448791	448632	14217N	PARTICIPANT	\N	PRESENT	0
448792	448632	18083K	PARTICIPANT	\N	PRESENT	0
448807	448623	14257W	PARTICIPANT	\N	EXCUSE	0
448808	448632	14042U	PARTICIPANT	\N	PRESENT	0
449433	448370	19669L	PARTICIPANT	\N	PRESENT	0
449434	448370	08056B	PARTICIPANT	\N	PRESENT	0
449435	448370	08053X	PARTICIPANT	\N	PRESENT	0
449436	448370	04035D	PARTICIPANT	\N	PRESENT	0
449437	448370	19319Q	PARTICIPANT	\N	PRESENT	0
449438	448370	98022P	PARTICIPANT	\N	PRESENT	0
449439	448370	11064N	PARTICIPANT	\N	PRESENT	0
449440	448370	11115U	PARTICIPANT	\N	PRESENT	0
449709	449601	19766L	PARTICIPANT	\N	PRESENT	0
449710	449601	19699S	PARTICIPANT	\N	PRESENT	0
449711	449601	14229S	PARTICIPANT	\N	PRESENT	0
449712	449601	14241N	PARTICIPANT	\N	PRESENT	0
449713	449601	19573D	PARTICIPANT	\N	PRESENT	0
449714	449601	14107H	PARTICIPANT	\N	PRESENT	0
449715	449601	08017T	PARTICIPANT	\N	PRESENT	0
449716	449601	08012N	PARTICIPANT	\N	PRESENT	0
449717	449601	19335Q	PARTICIPANT	\N	PRESENT	0
449718	449601	08039A	PARTICIPANT	\N	PRESENT	0
449719	449601	08031R	PARTICIPANT	\N	PRESENT	0
449720	449601	19593H	PARTICIPANT	\N	PRESENT	0
449721	449601	14061L	PARTICIPANT	\N	PRESENT	0
449722	449601	04057K	PARTICIPANT	\N	PRESENT	0
449723	449601	19611R	PARTICIPANT	\N	PRESENT	0
449724	449601	19693L	PARTICIPANT	\N	PRESENT	0
449725	449601	19399H	PARTICIPANT	\N	PRESENT	0
449726	449601	14251Q	PARTICIPANT	\N	PRESENT	0
449727	449601	08020N	PARTICIPANT	\N	PRESENT	0
449728	449601	04059M	PARTICIPANT	\N	PRESENT	0
449729	449601	19735D	PARTICIPANT	\N	PRESENT	0
449730	449601	11109J	PARTICIPANT	\N	PRESENT	0
449731	449601	14063N	PARTICIPANT	\N	PRESENT	0
449732	449601	14123H	PARTICIPANT	\N	PRESENT	0
449733	449601	11043H	PARTICIPANT	\N	PRESENT	0
449734	449601	04018C	PARTICIPANT	\N	PRESENT	0
449735	449601	19621T	PARTICIPANT	\N	PRESENT	0
449736	449601	14109K	PARTICIPANT	\N	PRESENT	0
428383	428382	11053K	PARTICIPANT	\N	PRESENT	0
428384	428382	05012A	PARTICIPANT	\N	PRESENT	0
432722	425280	14105F	PARTICIPANT	\N	PRESENT	0
429455	429453	14085U	PARTICIPANT	\N	PRESENT	0
432721	425280	19798U	PARTICIPANT	\N	PRESENT	0
432723	425280	08034U	PARTICIPANT	\N	PRESENT	0
432724	425280	08028W	PARTICIPANT	\N	PRESENT	0
429459	429453	11074Q	PRESIDENT	0	PRESENT	0
429460	429453	07004J	PARTICIPANT	\N	PRESENT	0
429461	429453	11048N	PARTICIPANT	\N	PRESENT	0
429462	429453	19711U	PARTICIPANT	\N	PRESENT	0
429463	429453	19671E	PARTICIPANT	\N	PRESENT	0
429464	429453	08011M	PARTICIPANT	\N	PRESENT	0
429465	429453	19349W	PARTICIPANT	\N	PRESENT	0
429466	429453	14225N	PARTICIPANT	\N	PRESENT	0
432725	425280	08069G	PARTICIPANT	\N	PRESENT	0
432726	425280	14213J	PARTICIPANT	\N	PRESENT	0
432727	425280	19577H	PARTICIPANT	\N	PRESENT	0
432728	425280	19581D	PARTICIPANT	\N	PRESENT	0
432729	425280	19367Y	PARTICIPANT	\N	PRESENT	0
432730	425280	08056B	PARTICIPANT	\N	PRESENT	0
432731	425280	04045F	PARTICIPANT	\N	PRESENT	0
432732	425280	19782L	PARTICIPANT	\N	PRESENT	0
432733	425280	98029W	PARTICIPANT	\N	PRESENT	0
432734	425280	19349W	PARTICIPANT	\N	PRESENT	0
432735	425280	19531S	PARTICIPANT	\N	PRESENT	0
432736	425280	14031R	PARTICIPANT	\N	PRESENT	0
432737	425280	19723Y	PARTICIPANT	\N	PRESENT	0
432738	425280	19533U	PARTICIPANT	\N	PRESENT	0
432739	425280	04086Q	PARTICIPANT	\N	PRESENT	0
432740	425280	19671E	PARTICIPANT	\N	PRESENT	0
432741	425280	14237S	PARTICIPANT	\N	PRESENT	0
432742	425280	19479G	PARTICIPANT	\N	PRESENT	0
432743	425280	08024S	PARTICIPANT	\N	PRESENT	0
432744	425280	11070L	PARTICIPANT	\N	PRESENT	0
432745	425280	14173T	PARTICIPANT	\N	PRESENT	0
432746	425280	08055A	PARTICIPANT	\N	PRESENT	0
432747	425280	08052W	PARTICIPANT	\N	PRESENT	0
432748	425280	19741B	PARTICIPANT	\N	PRESENT	0
432749	425280	11031D	PARTICIPANT	\N	PRESENT	0
432750	425280	14029X	PARTICIPANT	\N	PRESENT	0
432751	425280	14085U	PARTICIPANT	\N	PRESENT	0
432752	425280	80013X	PARTICIPANT	\N	PRESENT	0
432753	425280	19575F	PARTICIPANT	\N	PRESENT	0
432754	425280	14083S	PARTICIPANT	\N	PRESENT	0
432755	425280	14038Y	PARTICIPANT	\N	PRESENT	0
432756	425280	08014Q	PARTICIPANT	\N	PRESENT	0
432757	425280	19629C	PARTICIPANT	\N	PRESENT	0
432758	425280	14107H	PARTICIPANT	\N	PRESENT	0
432759	425280	19713W	PARTICIPANT	\N	PRESENT	0
432760	425280	11053K	PARTICIPANT	\N	PRESENT	0
432761	425280	88008L	PARTICIPANT	\N	PRESENT	0
432762	425280	11067R	PARTICIPANT	\N	PRESENT	0
432763	425280	04088S	PARTICIPANT	\N	PRESENT	0
432768	425280	14069U	PARTICIPANT	\N	PRESENT	0
432770	425280	19695N	PARTICIPANT	\N	PRESENT	0
432771	425280	14042U	PARTICIPANT	\N	PRESENT	0
432772	425280	08010L	PARTICIPANT	\N	PRESENT	0
432773	432047	19533U	PARTICIPANT	\N	PRESENT	0
432774	432047	04033B	PARTICIPANT	\N	PRESENT	0
432801	432800	08060W	PARTICIPANT	\N	PRESENT	0
432802	432800	19413M	PRESIDENT	0	PRESENT	0
432803	432800	19367Y	PARTICIPANT	\N	PRESENT	0
432804	432800	19826F	PARTICIPANT	\N	PRESENT	0
432805	432800	19581D	PARTICIPANT	\N	PRESENT	0
432806	432800	08024S	PARTICIPANT	\N	PRESENT	0
432807	432800	11048N	PARTICIPANT	\N	EXCUSE	0
432808	432800	14051J	PARTICIPANT	\N	EXCUSE	0
432809	432800	08009T	PARTICIPANT	\N	EXCUSE	0
432810	432800	19758L	PARTICIPANT	\N	PRESENT	0
432811	432800	95067Q	PARTICIPANT	\N	PRESENT	0
432866	425283	11041F	PARTICIPANT	\N	PRESENT	0
432867	425283	19583F	PARTICIPANT	\N	PRESENT	0
432868	425283	14219Q	PARTICIPANT	\N	PRESENT	0
432869	425283	19599P	PARTICIPANT	\N	PRESENT	0
432870	425283	88008L	PARTICIPANT	\N	PRESENT	0
432871	425283	14227Q	PARTICIPANT	\N	PRESENT	0
432872	425283	19681G	PARTICIPANT	\N	PRESENT	0
432873	425283	19812Y	PARTICIPANT	\N	PRESENT	0
432874	425283	08043V	PARTICIPANT	\N	PRESENT	0
432875	425283	98022P	PARTICIPANT	\N	PRESENT	0
432876	425283	19611R	PARTICIPANT	\N	PRESENT	0
432877	425283	07004J	PARTICIPANT	\N	PRESENT	0
432878	425283	14001X	PARTICIPANT	\N	PRESENT	0
432879	425283	19683J	PARTICIPANT	\N	PRESENT	0
432880	425283	19725B	PARTICIPANT	\N	PRESENT	0
432881	425283	19593H	PARTICIPANT	\N	PRESENT	0
432882	425283	14039A	PARTICIPANT	\N	PRESENT	0
432883	425283	19479G	PARTICIPANT	\N	PRESENT	0
432890	425283	04034C	PARTICIPANT	\N	PRESENT	0
432892	425283	19782L	PARTICIPANT	\N	PRESENT	0
432895	425283	98035U	PARTICIPANT	\N	PRESENT	0
432896	425283	17779H	PARTICIPANT	\N	PRESENT	0
432899	425283	08045X	PARTICIPANT	\N	PRESENT	0
432901	425283	19669L	PARTICIPANT	\N	PRESENT	0
432902	425283	98029W	PARTICIPANT	\N	PRESENT	0
432905	425283	19687N	PARTICIPANT	\N	PRESENT	0
432906	425283	11033F	PARTICIPANT	\N	PRESENT	0
432907	425283	19591F	PARTICIPANT	\N	PRESENT	0
432908	425283	11085T	PARTICIPANT	\N	PRESENT	0
432909	425283	04089T	PARTICIPANT	\N	PRESENT	0
432910	425283	14201E	PARTICIPANT	\N	PRESENT	0
432911	425283	14159V	PARTICIPANT	\N	PRESENT	0
432912	425283	11104D	PARTICIPANT	\N	PRESENT	0
432913	425283	80013X	PARTICIPANT	\N	PRESENT	0
432914	425283	08055A	PARTICIPANT	\N	PRESENT	0
432915	425283	08061X	PARTICIPANT	\N	PRESENT	0
432916	425283	04045F	PARTICIPANT	\N	PRESENT	0
432917	425283	19251M	PARTICIPANT	\N	PRESENT	0
432918	425283	11067R	PARTICIPANT	\N	PRESENT	0
432851	430308	11031D	PARTICIPANT	\N	PRESENT	0
432852	430308	19703U	PARTICIPANT	\N	PRESENT	0
432853	430308	19575F	PARTICIPANT	\N	PRESENT	0
432854	430308	14213J	PARTICIPANT	\N	PRESENT	0
432855	430308	98024R	PARTICIPANT	\N	PRESENT	0
432856	430308	19527W	PARTICIPANT	\N	PRESENT	0
432857	430308	11045K	PARTICIPANT	\N	PRESENT	0
432858	430308	19301E	PARTICIPANT	\N	PRESENT	0
432859	430308	19691J	PARTICIPANT	\N	PRESENT	0
432860	430308	19727D	PARTICIPANT	\N	PRESENT	0
432861	430308	19657G	PARTICIPANT	\N	PRESENT	0
432862	430308	19577H	PARTICIPANT	\N	PRESENT	0
432863	430308	19760E	PARTICIPANT	\N	PRESENT	0
432864	430308	17779H	PARTICIPANT	\N	EXCUSE	0
432865	425283	19349W	PARTICIPANT	\N	PRESENT	0
432919	425283	19631V	PARTICIPANT	\N	PRESENT	0
433630	425287	11033F	PARTICIPANT	\N	PRESENT	0
433631	425287	19826F	PARTICIPANT	\N	PRESENT	0
433632	430776	14259Y	PARTICIPANT	\N	PRESENT	0
433633	425287	97011G	PARTICIPANT	\N	PRESENT	0
433634	425287	14253S	PARTICIPANT	\N	PRESENT	0
433635	425287	14147R	PARTICIPANT	\N	PRESENT	0
433638	425287	19691J	PARTICIPANT	\N	PRESENT	0
433639	425287	14217N	PARTICIPANT	\N	PRESENT	0
433640	425287	14225N	PARTICIPANT	\N	PRESENT	0
433641	425287	19533U	PARTICIPANT	\N	PRESENT	0
433642	425287	08017T	PARTICIPANT	\N	PRESENT	0
433645	430776	14089Y	PARTICIPANT	\N	PRESENT	0
433646	425287	04042C	PARTICIPANT	\N	PRESENT	0
433647	425287	19679N	PARTICIPANT	\N	PRESENT	0
433648	425287	19441R	PARTICIPANT	\N	PRESENT	0
433649	425287	01048V	PARTICIPANT	\N	PRESENT	0
433650	425287	08043V	PARTICIPANT	\N	PRESENT	0
433652	425287	14089Y	PARTICIPANT	\N	PRESENT	0
433653	425287	19563B	PARTICIPANT	\N	PRESENT	0
433654	425287	19701S	PARTICIPANT	\N	PRESENT	0
433655	425287	19729F	PARTICIPANT	\N	PRESENT	0
433656	425287	14061L	PARTICIPANT	\N	PRESENT	0
433657	425287	14265W	PARTICIPANT	\N	PRESENT	0
433658	425287	01057W	PARTICIPANT	\N	PRESENT	0
433659	425287	14021P	PARTICIPANT	\N	PRESENT	0
433660	425287	19725B	PARTICIPANT	\N	PRESENT	0
433661	425287	11074Q	PARTICIPANT	\N	PRESENT	0
433662	425287	19569H	PARTICIPANT	\N	PRESENT	0
433663	425287	14079W	PARTICIPANT	\N	PRESENT	0
433664	425287	01024M	PARTICIPANT	\N	PRESENT	0
433665	425287	19415P	PARTICIPANT	\N	PRESENT	0
433666	425287	19565D	PARTICIPANT	\N	PRESENT	0
433667	425287	08010L	PARTICIPANT	\N	PRESENT	0
433668	425287	11067R	PARTICIPANT	\N	PRESENT	0
433669	425287	19721W	PARTICIPANT	\N	PRESENT	0
433670	425287	14249W	PARTICIPANT	\N	PRESENT	0
433671	425287	08062Y	PARTICIPANT	\N	PRESENT	0
450021	439823	11010L	PARTICIPANT	\N	PRESENT	0
450022	439823	19727D	PARTICIPANT	\N	PRESENT	0
450023	439823	14031R	PARTICIPANT	\N	PRESENT	0
450024	439823	19667J	PARTICIPANT	\N	PRESENT	0
450025	439823	11115U	PARTICIPANT	\N	PRESENT	0
450026	439823	14267Y	PARTICIPANT	\N	PRESENT	0
450027	439823	14199E	PARTICIPANT	\N	PRESENT	0
450478	439824	01043Q	PARTICIPANT	\N	PRESENT	0
450029	439823	11109J	PARTICIPANT	\N	PRESENT	0
450030	439823	14135M	PARTICIPANT	\N	PRESENT	0
450031	439823	11048N	PARTICIPANT	\N	PRESENT	0
450032	439823	05012A	PARTICIPANT	\N	PRESENT	0
450033	439823	08034U	PARTICIPANT	\N	PRESENT	0
450034	439823	19533U	PARTICIPANT	\N	PRESENT	0
450035	439823	19768N	PARTICIPANT	\N	PRESENT	0
450036	439823	10006L	PARTICIPANT	\N	PRESENT	0
450037	439823	14103D	PARTICIPANT	\N	PRESENT	0
450038	439823	19798U	PARTICIPANT	\N	PRESENT	0
450039	439823	19737F	PARTICIPANT	\N	PRESENT	0
450040	439823	14231L	PARTICIPANT	\N	PRESENT	0
450041	439823	14179A	PARTICIPANT	\N	PRESENT	0
450042	439823	14193X	PARTICIPANT	\N	PRESENT	0
450043	439823	19511N	PARTICIPANT	\N	PRESENT	0
450044	439823	19515S	PARTICIPANT	\N	PRESENT	0
450045	439823	01034P	PARTICIPANT	\N	PRESENT	0
450046	439823	19369B	PARTICIPANT	\N	PRESENT	0
450047	439823	11080N	PARTICIPANT	\N	PRESENT	0
450048	439823	19691J	PARTICIPANT	\N	PRESENT	0
450049	439823	19611R	PARTICIPANT	\N	PRESENT	0
450050	439823	01057W	PARTICIPANT	\N	PRESENT	0
450051	439823	11053K	PARTICIPANT	\N	PRESENT	0
450052	439823	14205J	PARTICIPANT	\N	PRESENT	0
450053	439823	19766L	PARTICIPANT	\N	PRESENT	0
450054	439823	19699S	PARTICIPANT	\N	PRESENT	0
450055	439823	05008E	PARTICIPANT	\N	PRESENT	0
450056	439823	19721W	PARTICIPANT	\N	PRESENT	0
450057	439823	87003B	PARTICIPANT	\N	PRESENT	0
450058	439823	14109K	PARTICIPANT	\N	PRESENT	0
450059	439823	11090Q	PARTICIPANT	\N	PRESENT	0
450060	439823	04043D	PARTICIPANT	\N	PRESENT	0
450061	439823	14069U	PARTICIPANT	\N	PRESENT	0
450062	439823	17779H	PARTICIPANT	\N	PRESENT	0
450063	439823	19735D	PARTICIPANT	\N	PRESENT	0
450064	439823	14249W	PARTICIPANT	\N	PRESENT	0
450066	439823	19569H	PARTICIPANT	\N	PRESENT	0
450067	439823	14053L	PARTICIPANT	\N	PRESENT	0
450069	439823	14219Q	PARTICIPANT	\N	PRESENT	0
450070	439823	14087W	PARTICIPANT	\N	PRESENT	0
450071	439823	14042U	PARTICIPANT	\N	PRESENT	0
450072	439823	19479G	PARTICIPANT	\N	PRESENT	0
450073	439823	14215L	PARTICIPANT	\N	PRESENT	0
450074	439823	19441R	PARTICIPANT	\N	PRESENT	0
450075	439823	14275Y	PARTICIPANT	\N	PRESENT	0
450076	439823	19319Q	PARTICIPANT	\N	PRESENT	0
450077	439823	11097X	PARTICIPANT	\N	PRESENT	0
450078	439823	19713W	PARTICIPANT	\N	PRESENT	0
450079	439823	19749K	PARTICIPANT	\N	PRESENT	0
450080	439823	04033B	PARTICIPANT	\N	PRESENT	0
450081	439823	14327T	PARTICIPANT	\N	PRESENT	0
450082	439823	14187A	PARTICIPANT	\N	PRESENT	0
450083	439823	14083S	PARTICIPANT	\N	PRESENT	0
450084	439823	14089Y	PARTICIPANT	\N	PRESENT	0
450085	439823	11110B	PARTICIPANT	\N	PRESENT	0
450086	439823	01048V	PARTICIPANT	\N	PRESENT	0
450087	439823	14255U	PARTICIPANT	\N	PRESENT	0
450088	439823	11043H	PARTICIPANT	\N	PRESENT	0
450089	439823	10015M	PARTICIPANT	\N	PRESENT	0
450090	439823	04070G	PARTICIPANT	\N	PRESENT	0
450091	439823	19521Q	PARTICIPANT	\N	PRESENT	0
450132	439823	14217N	PARTICIPANT	\N	PRESENT	0
450093	439823	19679N	PARTICIPANT	\N	PRESENT	0
450094	439823	14277B	PARTICIPANT	\N	PRESENT	0
450095	439823	04097T	PARTICIPANT	\N	PRESENT	0
450096	439823	08044W	PARTICIPANT	\N	PRESENT	0
450097	439823	08039A	PARTICIPANT	\N	PRESENT	0
450098	439823	11085T	PARTICIPANT	\N	PRESENT	0
450099	439823	08020N	PARTICIPANT	\N	PRESENT	0
450100	439823	08010L	PARTICIPANT	\N	PRESENT	0
450101	439823	08069G	PARTICIPANT	\N	PRESENT	0
450102	439823	04086Q	PARTICIPANT	\N	PRESENT	0
450103	439823	04040A	PARTICIPANT	\N	PRESENT	0
450104	439823	14123H	PARTICIPANT	\N	PRESENT	0
450105	439823	01025N	PARTICIPANT	\N	PRESENT	0
450106	439823	04092N	PARTICIPANT	\N	PRESENT	0
450107	439823	08035V	PARTICIPANT	\N	PRESENT	0
450108	439823	04044E	PARTICIPANT	\N	PRESENT	0
450109	439823	01024M	PARTICIPANT	\N	PRESENT	0
450110	439823	19747H	PARTICIPANT	\N	PRESENT	0
450111	439823	14030Q	PARTICIPANT	\N	PRESENT	0
450112	439823	98018T	PARTICIPANT	\N	PRESENT	0
450113	439823	96004D	PARTICIPANT	\N	PRESENT	0
450114	439823	01058X	PARTICIPANT	\N	PRESENT	0
450115	439823	99004R	PARTICIPANT	\N	PRESENT	0
450116	439823	14026U	PARTICIPANT	\N	PRESENT	0
450117	439823	04035D	PARTICIPANT	\N	PRESENT	0
450118	439823	19745F	PARTICIPANT	\N	PRESENT	0
450119	439823	11101A	PARTICIPANT	\N	PRESENT	0
450121	439823	04008A	PARTICIPANT	\N	PRESENT	0
450122	439823	19295A	PARTICIPANT	\N	PRESENT	0
450123	439823	08011M	PARTICIPANT	\N	PRESENT	0
450124	439823	19573D	PARTICIPANT	\N	PRESENT	0
450125	439823	95041E	PARTICIPANT	\N	PRESENT	0
450126	439823	95063L	PARTICIPANT	\N	PRESENT	0
450127	439823	11049P	PARTICIPANT	\N	PRESENT	0
450128	439823	14257W	PARTICIPANT	\N	PRESENT	0
450129	439823	14119M	PARTICIPANT	\N	PRESENT	0
450139	439823	14055N	PARTICIPANT	\N	PRESENT	0
450131	439823	15447F	PARTICIPANT	\N	PRESENT	0
450133	439823	95067Q	PARTICIPANT	\N	PRESENT	0
450134	439823	11031D	PARTICIPANT	\N	PRESENT	0
450135	439823	01043Q	PARTICIPANT	\N	PRESENT	0
450136	439823	14157T	PARTICIPANT	\N	PRESENT	0
450137	439823	19643A	PARTICIPANT	\N	PRESENT	0
450138	439823	04071H	PARTICIPANT	\N	PRESENT	0
450140	439823	86034E	PARTICIPANT	\N	PRESENT	0
450141	439823	19689Q	PARTICIPANT	\N	PRESENT	0
450142	439823	08018U	PARTICIPANT	\N	PRESENT	0
450143	439823	04059M	PARTICIPANT	\N	PRESENT	0
450144	439823	19647E	PARTICIPANT	\N	PRESENT	0
450145	439823	98024R	PARTICIPANT	\N	PRESENT	0
450146	439823	08028W	PARTICIPANT	\N	PRESENT	0
450147	439823	19335Q	PARTICIPANT	\N	PRESENT	0
450196	439823	14195A	PARTICIPANT	\N	PRESENT	0
450197	448623	14327T	PARTICIPANT	\N	EXCUSE	0
450480	450479	14065Q	PARTICIPANT	\N	PRESENT	0
450481	450479	96004D	PRESIDENT	0	PRESENT	0
450482	450479	14089Y	PARTICIPANT	\N	PRESENT	0
450483	450479	14079W	PARTICIPANT	\N	PRESENT	0
450484	450479	04035D	PARTICIPANT	\N	PRESENT	0
450485	450479	11083R	PARTICIPANT	\N	PRESENT	0
450486	450479	04097T	PARTICIPANT	\N	PRESENT	0
450487	450479	14241N	PARTICIPANT	\N	PRESENT	0
450488	450479	14205J	PARTICIPANT	\N	PRESENT	0
450489	450479	14001X	PARTICIPANT	\N	PRESENT	0
450490	450479	04057K	PARTICIPANT	\N	PRESENT	0
450491	450479	19563B	PARTICIPANT	\N	PRESENT	0
450492	450479	14331P	PARTICIPANT	\N	PRESENT	0
450493	450479	10015M	PARTICIPANT	\N	PRESENT	0
450494	450479	98035U	PARTICIPANT	\N	PRESENT	0
450495	439824	14213J	PARTICIPANT	\N	PRESENT	0
450496	439824	04092N	PARTICIPANT	\N	PRESENT	0
450497	439824	88008L	PARTICIPANT	\N	PRESENT	0
450498	439824	17589D	PARTICIPANT	\N	PRESENT	0
450499	450479	14061L	PARTICIPANT	\N	EXCUSE	0
450500	439824	14121F	PARTICIPANT	\N	PRESENT	0
450501	439824	14195A	PARTICIPANT	\N	PRESENT	0
450502	439824	19569H	PARTICIPANT	\N	PRESENT	0
450503	439824	19683J	PARTICIPANT	\N	PRESENT	0
450504	439824	11067R	PARTICIPANT	\N	PRESENT	0
450505	439824	11031D	PARTICIPANT	\N	PRESENT	0
450506	439824	19565D	PARTICIPANT	\N	PRESENT	0
450507	439824	11056N	PARTICIPANT	\N	PRESENT	0
450508	439824	08052W	PARTICIPANT	\N	PRESENT	0
450509	439824	19333N	PARTICIPANT	\N	PRESENT	0
450510	439824	19531S	PARTICIPANT	\N	PRESENT	0
450511	439824	19737F	PARTICIPANT	\N	PRESENT	0
450512	439824	14030Q	PARTICIPANT	\N	PRESENT	0
450513	439824	19749K	PARTICIPANT	\N	PRESENT	0
450514	439824	19521Q	PARTICIPANT	\N	PRESENT	0
450515	439824	19553Y	PARTICIPANT	\N	PRESENT	0
450516	439824	14215L	PARTICIPANT	\N	PRESENT	0
450517	439824	19563B	PARTICIPANT	\N	PRESENT	0
450518	439824	19747H	PARTICIPANT	\N	PRESENT	0
450519	439824	01060R	PARTICIPANT	\N	PRESENT	0
450520	439824	19685L	PARTICIPANT	\N	PRESENT	0
450521	439824	19335Q	PARTICIPANT	\N	PRESENT	0
450522	439824	04018C	PARTICIPANT	\N	PRESENT	0
450523	439824	19383Y	PARTICIPANT	\N	PRESENT	0
450524	439824	08034U	PARTICIPANT	\N	PRESENT	0
425748	425742	19369B	PARTICIPANT	\N	PRESENT	0
425750	425749	19369B	PARTICIPANT	\N	PRESENT	0
427947	422994	14261S	PARTICIPANT	\N	PRESENT	0
427948	422994	19717B	PARTICIPANT	\N	PRESENT	0
427949	422994	19631V	PARTICIPANT	\N	PRESENT	0
427950	422994	14259Y	PARTICIPANT	\N	PRESENT	0
427951	422994	07033P	PARTICIPANT	\N	EXCUSE	0
427952	422994	19329S	PARTICIPANT	\N	PRESENT	0
427953	422994	14097Y	PARTICIPANT	\N	PRESENT	0
427954	422994	19729F	PARTICIPANT	\N	PRESENT	0
427955	422994	11072N	PARTICIPANT	\N	PRESENT	0
427956	422994	08019V	PRESIDENT	0	PRESENT	0
427957	422994	19319Q	PARTICIPANT	\N	PRESENT	0
427958	422994	14331P	PARTICIPANT	\N	PRESENT	0
427959	422994	14157T	PARTICIPANT	\N	PRESENT	0
427960	422994	14021P	PARTICIPANT	\N	PRESENT	0
427961	422994	19715Y	PARTICIPANT	\N	PRESENT	0
428498	428157	14261S	PARTICIPANT	\N	PRESENT	0
428499	428157	19715Y	PARTICIPANT	\N	PRESENT	0
428500	428157	08019V	PARTICIPANT	\N	PRESENT	0
428501	428157	14331P	PARTICIPANT	\N	PRESENT	0
428502	428157	19329S	PARTICIPANT	\N	PRESENT	0
428508	428507	07033P	PARTICIPANT	\N	PRESENT	0
428509	428507	04070G	PARTICIPANT	\N	PRESENT	0
428510	428507	04018C	PARTICIPANT	\N	PRESENT	0
428512	428507	14059S	PARTICIPANT	\N	PRESENT	0
428513	428507	19515S	PARTICIPANT	\N	PRESENT	0
442694	442693	04049K	PARTICIPANT	\N	PRESENT	0
442695	442693	16685X	PARTICIPANT	\N	PRESENT	0
442767	442766	04049K	PARTICIPANT	\N	PRESENT	0
442768	442766	16685X	PARTICIPANT	\N	PRESENT	0
442890	442775	19737F	PARTICIPANT	\N	PRESENT	0
445972	445971	14199E	PARTICIPANT	\N	PRESENT	0
445974	445973	14199E	PARTICIPANT	\N	PRESENT	0
445976	445975	14199E	PARTICIPANT	\N	PRESENT	0
446047	444383	14065Q	PARTICIPANT	\N	PRESENT	0
446048	444383	19649G	PARTICIPANT	\N	PRESENT	0
446049	444383	08034U	PARTICIPANT	\N	PRESENT	0
446050	444383	04092N	PRESIDENT	0	PRESENT	0
446051	444383	19569H	PARTICIPANT	\N	PRESENT	0
446052	444383	08052W	PARTICIPANT	\N	PRESENT	0
446053	444383	08043V	PARTICIPANT	\N	PRESENT	0
446054	444383	19447X	PARTICIPANT	\N	PRESENT	0
446055	444383	05008E	PARTICIPANT	\N	PRESENT	0
446056	444383	18083K	PARTICIPANT	\N	PRESENT	0
446057	444383	19553Y	PARTICIPANT	\N	PRESENT	0
446058	444383	11031D	PARTICIPANT	\N	PRESENT	0
446059	444383	14042U	PARTICIPANT	\N	PRESENT	0
446060	444383	99004R	PARTICIPANT	\N	PRESENT	0
446061	444383	14217N	PARTICIPANT	\N	PRESENT	0
446062	444383	19683J	PARTICIPANT	\N	PRESENT	0
446063	444383	10006L	PARTICIPANT	\N	PRESENT	0
446064	444383	11072N	PARTICIPANT	\N	PRESENT	0
446065	444383	04045F	PARTICIPANT	\N	PRESENT	0
446066	444383	01048V	PARTICIPANT	\N	PRESENT	0
446067	444383	11067R	PARTICIPANT	\N	PRESENT	0
446081	443731	04070G	PARTICIPANT	\N	PRESENT	0
446082	443731	14051J	PARTICIPANT	\N	PRESENT	0
446083	443731	95067Q	PARTICIPANT	\N	PRESENT	0
446084	443731	08060W	PARTICIPANT	\N	PRESENT	0
446085	443731	08009T	PRESIDENT	0	PRESENT	0
446086	443731	19413M	PARTICIPANT	\N	PRESENT	0
446087	443731	19367Y	PARTICIPANT	\N	PRESENT	0
446088	443731	19251M	PARTICIPANT	\N	PRESENT	0
446089	443731	14033T	PARTICIPANT	\N	PRESENT	0
446090	443731	19826F	PARTICIPANT	\N	PRESENT	0
446091	443731	14079W	PARTICIPANT	\N	EXCUSE	0
446092	443731	19758L	PARTICIPANT	\N	EXCUSE	0
446093	444383	19415P	PARTICIPANT	\N	PRESENT	0
446094	444383	19575F	PARTICIPANT	\N	PRESENT	0
446095	444383	14179A	PARTICIPANT	\N	PRESENT	0
446096	444383	14213J	PARTICIPANT	\N	PRESENT	0
446097	444383	14215L	PARTICIPANT	\N	PRESENT	0
446098	444383	19335Q	PARTICIPANT	\N	PRESENT	0
446099	444383	14239U	PARTICIPANT	\N	EXCUSE	0
446100	444383	14195A	PARTICIPANT	\N	EXCUSE	0
446101	444383	14147R	PARTICIPANT	\N	PRESENT	0
446103	444384	11067R	PARTICIPANT	\N	PRESENT	0
446104	444384	19569H	PARTICIPANT	\N	PRESENT	0
446105	444384	19415P	PARTICIPANT	\N	PRESENT	0
446106	444384	04045F	PARTICIPANT	\N	PRESENT	0
446107	444384	05008E	PARTICIPANT	\N	PRESENT	0
446108	444384	19447X	PARTICIPANT	\N	PRESENT	0
446109	444384	18083K	PARTICIPANT	\N	PRESENT	0
446110	444384	19553Y	PARTICIPANT	\N	PRESENT	0
446111	444384	14042U	PARTICIPANT	\N	PRESENT	0
446112	444384	14195A	PARTICIPANT	\N	PRESENT	0
446113	444384	14147R	PARTICIPANT	\N	PRESENT	0
446114	444384	19575F	PARTICIPANT	\N	PRESENT	0
446115	444384	14213J	PARTICIPANT	\N	PRESENT	0
446116	444384	19685L	PARTICIPANT	\N	PRESENT	0
446117	444384	14215L	PARTICIPANT	\N	PRESENT	0
446118	444384	14217N	PARTICIPANT	\N	PRESENT	0
446134	439813	14213J	PARTICIPANT	\N	PRESENT	0
446120	444384	19683J	PARTICIPANT	\N	PRESENT	0
446121	444384	11072N	PARTICIPANT	\N	PRESENT	0
446122	444384	19649G	PARTICIPANT	\N	PRESENT	0
446123	444384	14065Q	PARTICIPANT	\N	PRESENT	0
446124	444384	04092N	PRESIDENT	0	PRESENT	0
446125	444384	08034U	PARTICIPANT	\N	PRESENT	0
446126	444384	11045K	PARTICIPANT	\N	PRESENT	0
446127	444384	08052W	PARTICIPANT	\N	PRESENT	0
446128	444384	08043V	PARTICIPANT	\N	PRESENT	0
446129	444384	99004R	PARTICIPANT	\N	PRESENT	0
446130	444384	14239U	PARTICIPANT	\N	EXCUSE	0
446131	439813	86034E	PARTICIPANT	\N	PRESENT	0
446133	439813	04092N	PARTICIPANT	\N	PRESENT	0
446135	439813	19569H	PARTICIPANT	\N	PRESENT	0
446136	439813	19683J	PARTICIPANT	\N	PRESENT	0
446137	439813	11040E	PARTICIPANT	\N	PRESENT	0
446138	439813	19758L	PARTICIPANT	\N	PRESENT	0
446139	439813	19565D	PARTICIPANT	\N	PRESENT	0
446140	439813	11067R	PARTICIPANT	\N	PRESENT	0
446141	439813	14065Q	PARTICIPANT	\N	PRESENT	0
446142	439813	14085U	PARTICIPANT	\N	PRESENT	0
446143	439813	19649G	PARTICIPANT	\N	PRESENT	0
446144	439813	01028R	PARTICIPANT	\N	PRESENT	0
446145	439813	14021P	PARTICIPANT	\N	PRESENT	0
446146	439813	08052W	PARTICIPANT	\N	PRESENT	0
446147	439813	08043V	PARTICIPANT	\N	PRESENT	0
446148	439813	19333N	PARTICIPANT	\N	PRESENT	0
446149	439813	04059M	PARTICIPANT	\N	PRESENT	0
446150	439813	19503N	PARTICIPANT	\N	PRESENT	0
446151	439813	08017T	PARTICIPANT	\N	PRESENT	0
446152	439813	19782L	PARTICIPANT	\N	PRESENT	0
446153	439813	08073C	PARTICIPANT	\N	PRESENT	0
446154	439813	11072N	PARTICIPANT	\N	PRESENT	0
446155	439813	19349W	PARTICIPANT	\N	PRESENT	0
446156	439813	19543W	PARTICIPANT	\N	PRESENT	0
446157	439813	14239U	PARTICIPANT	\N	PRESENT	0
446158	439813	99004R	PARTICIPANT	\N	PRESENT	0
446159	439813	04045F	PARTICIPANT	\N	PRESENT	0
446160	439813	01058X	PARTICIPANT	\N	PRESENT	0
446161	439813	95063L	PARTICIPANT	\N	PRESENT	0
446162	439813	19679N	PARTICIPANT	\N	PRESENT	0
446163	439813	04097T	PARTICIPANT	\N	PRESENT	0
446164	439813	19387D	PARTICIPANT	\N	PRESENT	0
446165	439813	08031R	PARTICIPANT	\N	PRESENT	0
446166	439813	14169X	PARTICIPANT	\N	PRESENT	0
446167	439813	10015M	PARTICIPANT	\N	PRESENT	0
446168	439813	19629C	PARTICIPANT	\N	PRESENT	0
446169	439813	95037J	PARTICIPANT	\N	PRESENT	0
446170	439813	08061X	PARTICIPANT	\N	PRESENT	0
446171	439813	19301E	PARTICIPANT	\N	PRESENT	0
446172	439813	14063N	PARTICIPANT	\N	PRESENT	0
446173	439813	08049C	PARTICIPANT	\N	PRESENT	0
446174	439813	19611R	PARTICIPANT	\N	PRESENT	0
446175	439813	14207L	PARTICIPANT	\N	PRESENT	0
446176	439813	08028W	PARTICIPANT	\N	PRESENT	0
446177	439813	19553Y	PARTICIPANT	\N	PRESENT	0
446178	439813	14195A	PARTICIPANT	\N	PRESENT	0
446179	439813	14223L	PARTICIPANT	\N	PRESENT	0
446180	439813	19441R	PARTICIPANT	\N	PRESENT	0
446181	439813	04044E	PARTICIPANT	\N	PRESENT	0
446182	439813	19369B	PARTICIPANT	\N	PRESENT	0
446183	439813	04035D	PARTICIPANT	\N	PRESENT	0
446184	439813	19651A	PARTICIPANT	\N	PRESENT	0
446185	439813	19747H	PARTICIPANT	\N	PRESENT	0
446186	439813	19647E	PARTICIPANT	\N	PRESENT	0
446187	439813	14071N	PARTICIPANT	\N	PRESENT	0
446188	439813	05008E	PARTICIPANT	\N	PRESENT	0
446189	439813	11033F	PARTICIPANT	\N	PRESENT	0
446190	439813	98024R	PARTICIPANT	\N	PRESENT	0
446191	439813	11031D	PARTICIPANT	\N	PRESENT	0
446192	439813	04033B	PARTICIPANT	\N	PRESENT	0
446193	439813	14069U	PARTICIPANT	\N	PRESENT	0
446194	439813	04085P	PARTICIPANT	\N	PRESENT	0
446195	439813	14187A	PARTICIPANT	\N	PRESENT	0
446196	439813	11070L	PARTICIPANT	\N	PRESENT	0
449737	448370	95067Q	PARTICIPANT	\N	PRESENT	0
449738	449601	19731Y	PARTICIPANT	\N	PRESENT	0
449739	448370	19583F	PARTICIPANT	\N	EXCUSE	0
449740	448370	08047A	PARTICIPANT	\N	EXCUSE	0
449741	448370	19421M	PARTICIPANT	\N	EXCUSE	0
449756	449403	19333N	PARTICIPANT	\N	PRESENT	0
449757	449403	19383Y	PARTICIPANT	\N	PRESENT	0
449758	449403	17583W	PARTICIPANT	\N	PRESENT	0
449759	449403	19794Q	PARTICIPANT	\N	PRESENT	0
449760	449403	19549D	PARTICIPANT	\N	PRESENT	0
449761	449403	04069P	PARTICIPANT	\N	PRESENT	0
449762	449403	19387D	PARTICIPANT	\N	PRESENT	0
449763	449403	14219Q	PARTICIPANT	\N	PRESENT	0
449764	449403	19820Y	PARTICIPANT	\N	PRESENT	0
449765	449403	19826F	PARTICIPANT	\N	PRESENT	0
449766	449403	19599P	PARTICIPANT	\N	PRESENT	0
449767	449403	19637C	PARTICIPANT	\N	PRESENT	0
449768	449403	18083K	PARTICIPANT	\N	PRESENT	0
449769	449403	19551W	PARTICIPANT	\N	PRESENT	0
449770	449403	05012A	PARTICIPANT	\N	PRESENT	0
449771	449403	14051J	PARTICIPANT	\N	PRESENT	0
449772	449403	08060W	PARTICIPANT	\N	PRESENT	0
449773	449403	19503N	PARTICIPANT	\N	PRESENT	0
449774	449403	19347U	PARTICIPANT	\N	PRESENT	0
449775	449403	14157T	PARTICIPANT	\N	PRESENT	0
449776	449403	19681G	PARTICIPANT	\N	PRESENT	0
449777	449403	14038Y	PARTICIPANT	\N	PRESENT	0
449778	449403	14103D	PARTICIPANT	\N	PRESENT	0
449779	449403	19713W	PARTICIPANT	\N	PRESENT	0
449780	449403	14031R	PARTICIPANT	\N	PRESENT	0
449781	449403	08055A	PARTICIPANT	\N	PRESENT	0
449782	449403	14169X	PARTICIPANT	\N	PRESENT	0
449783	449403	15447F	PARTICIPANT	\N	PRESENT	0
449784	449403	14093U	PARTICIPANT	\N	PRESENT	0
449785	449403	14029X	PARTICIPANT	\N	PRESENT	0
449786	449403	08009T	PRESIDENT	0	PRESENT	0
449787	449403	19737F	PARTICIPANT	\N	PRESENT	0
449788	449403	04097T	PARTICIPANT	\N	PRESENT	0
449789	449403	19745F	PARTICIPANT	\N	EXCUSE	0
449790	449403	08024S	PARTICIPANT	\N	EXCUSE	0
449792	449791	96004D	PARTICIPANT	\N	PRESENT	0
449793	449791	08028W	PARTICIPANT	\N	PRESENT	0
449794	449791	19369B	PARTICIPANT	\N	PRESENT	0
449795	449791	19725B	PARTICIPANT	\N	PRESENT	0
449796	449791	14135M	PARTICIPANT	\N	PRESENT	0
449797	449791	01043Q	PARTICIPANT	\N	PRESENT	0
449798	449791	19515S	PARTICIPANT	\N	PRESENT	0
449799	449791	19467C	PARTICIPANT	\N	PRESENT	0
449800	449791	14357A	PARTICIPANT	\N	PRESENT	0
449801	448370	04042C	PARTICIPANT	\N	EXCUSE	0
449808	448841	19768N	PARTICIPANT	\N	PRESENT	0
449809	448841	19515S	PARTICIPANT	\N	PRESENT	0
449810	448841	11077T	PARTICIPANT	\N	PRESENT	0
449811	448841	19782L	PARTICIPANT	\N	PRESENT	0
449812	448841	01043Q	PARTICIPANT	\N	PRESENT	0
449813	448841	14357A	PARTICIPANT	\N	PRESENT	0
449814	448841	19441R	PARTICIPANT	\N	PRESENT	0
449815	448841	19812Y	PARTICIPANT	\N	PRESENT	0
449816	448841	19413M	PARTICIPANT	\N	PRESENT	0
449817	448841	80013X	PARTICIPANT	\N	PRESENT	0
449818	448841	19631V	PARTICIPANT	\N	PRESENT	0
449819	448841	11099A	PARTICIPANT	\N	PRESENT	0
449820	448841	08068F	PARTICIPANT	\N	PRESENT	0
449821	448841	04049K	PARTICIPANT	\N	PRESENT	0
449822	448841	19705W	PARTICIPANT	\N	PRESENT	0
449823	448841	08015R	PARTICIPANT	\N	PRESENT	0
449824	448841	08019V	PARTICIPANT	\N	PRESENT	0
449825	448841	14197C	PARTICIPANT	\N	PRESENT	0
449826	448841	19369B	PARTICIPANT	\N	PRESENT	0
449827	448841	19511N	PARTICIPANT	\N	PRESENT	0
449828	448841	08028W	PARTICIPANT	\N	PRESENT	0
449829	448841	19563B	PARTICIPANT	\N	PRESENT	0
449830	448841	19591F	PARTICIPANT	\N	PRESENT	0
449831	448841	14329V	PARTICIPANT	\N	PRESENT	0
449832	448841	14135M	PARTICIPANT	\N	PRESENT	0
449833	448841	14038Y	PARTICIPANT	\N	PRESENT	0
449834	448841	19467C	PARTICIPANT	\N	PRESENT	0
449835	448841	14187A	PARTICIPANT	\N	PRESENT	0
449836	448841	08038Y	PARTICIPANT	\N	PRESENT	0
449837	448841	19695N	PARTICIPANT	\N	PRESENT	0
449838	448841	08062Y	PARTICIPANT	\N	PRESENT	0
449839	448841	01025N	PARTICIPANT	\N	PRESENT	0
449840	448841	11090Q	PRESIDENT	0	PRESENT	0
449841	448841	14033T	PARTICIPANT	\N	PRESENT	0
449842	448841	14205J	PARTICIPANT	\N	PRESENT	0
449843	448841	04088S	PARTICIPANT	\N	PRESENT	0
449844	448841	11056N	PARTICIPANT	\N	PRESENT	0
449845	448841	14115H	PARTICIPANT	\N	PRESENT	0
449846	448841	19507S	PARTICIPANT	\N	PRESENT	0
449847	448841	11101A	PARTICIPANT	\N	PRESENT	0
449848	448841	19747H	PARTICIPANT	\N	PRESENT	0
449849	448841	14207L	PARTICIPANT	\N	PRESENT	0
449850	448841	04043D	PARTICIPANT	\N	PRESENT	0
449851	448841	17589D	PARTICIPANT	\N	PRESENT	0
449852	448841	14257W	PARTICIPANT	\N	PRESENT	0
449853	448841	11081P	PARTICIPANT	\N	EXCUSE	0
449854	448841	14265W	PARTICIPANT	\N	EXCUSE	0
449974	449968	04043D	PARTICIPANT	\N	PRESENT	0
450015	450008	04043D	PARTICIPANT	\N	PRESENT	0
450068	450065	04043D	PARTICIPANT	\N	PRESENT	0
450607	448623	14259Y	PARTICIPANT	\N	EXCUSE	0
450613	450611	96004D	PRESIDENT	0	PRESENT	0
450614	450611	14255U	PARTICIPANT	\N	PRESENT	0
450615	450611	19251M	PARTICIPANT	\N	PRESENT	0
450616	450611	04035D	PARTICIPANT	\N	PRESENT	0
450617	450611	04097T	PARTICIPANT	\N	PRESENT	0
450618	450611	04057K	PARTICIPANT	\N	PRESENT	0
450619	450611	98050T	PRESIDENT	1	PRESENT	0
450620	450611	14331P	PARTICIPANT	\N	PRESENT	0
450627	450626	11101A	PARTICIPANT	\N	PRESENT	0
450628	450626	14085U	PARTICIPANT	\N	PRESENT	0
450629	450626	19629C	PARTICIPANT	\N	PRESENT	0
450630	450626	08028W	PARTICIPANT	\N	PRESENT	0
450631	450626	14197C	PARTICIPANT	\N	PRESENT	0
450632	450626	19703U	PARTICIPANT	\N	PRESENT	0
450733	445943	19631V	PARTICIPANT	\N	PRESENT	0
450735	445943	19691J	PARTICIPANT	\N	PRESENT	0
450734	445943	07033P	PARTICIPANT	\N	PRESENT	0
450736	445943	14097Y	PARTICIPANT	\N	PRESENT	0
450737	445943	19729F	PARTICIPANT	\N	PRESENT	0
450738	445943	08019V	PRESIDENT	0	PRESENT	0
450739	445943	19657G	PARTICIPANT	\N	PRESENT	0
450740	445943	11054L	PARTICIPANT	\N	PRESENT	0
450785	450784	96004D	PARTICIPANT	\N	PRESENT	0
450815	450814	11053K	PARTICIPANT	\N	PRESENT	0
450816	450814	88008L	PARTICIPANT	\N	PRESENT	0
450817	450814	19333N	PARTICIPANT	\N	PRESENT	0
450818	450814	11077T	PARTICIPANT	\N	PRESENT	0
450819	450814	11097X	PARTICIPANT	\N	PRESENT	0
450822	450821	11074Q	PARTICIPANT	\N	PRESENT	0
450881	450880	14329V	PARTICIPANT	\N	PRESENT	0
450882	450880	14357A	PARTICIPANT	\N	PRESENT	0
450883	450880	11090Q	PARTICIPANT	\N	PRESENT	0
450884	450880	19745F	PARTICIPANT	\N	PRESENT	0
450946	450945	05008E	PARTICIPANT	\N	PRESENT	0
450947	450945	19543W	PARTICIPANT	\N	PRESENT	0
450948	450945	04038G	PARTICIPANT	\N	PRESENT	0
450949	450945	19253P	PARTICIPANT	\N	PRESENT	0
450950	450945	08018U	PARTICIPANT	\N	PRESENT	0
450951	450945	08044W	PARTICIPANT	\N	PRESENT	0
450952	450945	19585H	PARTICIPANT	\N	PRESENT	0
450953	450945	11026G	PARTICIPANT	\N	PRESENT	0
450980	450979	05008E	PARTICIPANT	\N	PRESENT	0
450981	450979	01024M	PARTICIPANT	\N	PRESENT	0
450982	450979	14215L	PARTICIPANT	\N	PRESENT	0
450983	450979	14031R	PARTICIPANT	\N	PRESENT	0
450984	450979	11026G	PARTICIPANT	\N	PRESENT	0
450985	450979	01028R	PARTICIPANT	\N	PRESENT	0
450987	450986	05008E	PARTICIPANT	\N	PRESENT	0
450988	450986	01024M	PARTICIPANT	\N	PRESENT	0
450989	450986	14215L	PARTICIPANT	\N	PRESENT	0
450990	450986	14031R	PARTICIPANT	\N	PRESENT	0
450991	450986	11026G	PARTICIPANT	\N	PRESENT	0
450992	450986	01028R	PARTICIPANT	\N	PRESENT	0
450994	449603	11067R	PARTICIPANT	\N	PRESENT	0
450995	449603	14355X	PARTICIPANT	\N	PRESENT	0
450996	449603	19565D	PARTICIPANT	\N	PRESENT	0
450997	449603	19798U	PARTICIPANT	\N	PRESENT	0
450998	449603	11097X	PARTICIPANT	\N	PRESENT	0
450999	449603	04045F	PARTICIPANT	\N	PRESENT	0
451000	449603	14026U	PARTICIPANT	\N	PRESENT	0
451001	449603	19703U	PARTICIPANT	\N	PRESENT	0
451002	449603	14281W	PARTICIPANT	\N	PRESENT	0
451003	449603	14087W	PARTICIPANT	\N	PRESENT	0
451004	449603	19679N	PARTICIPANT	\N	PRESENT	0
451005	449603	14042U	PARTICIPANT	\N	PRESENT	0
451006	449603	14195A	PARTICIPANT	\N	PRESENT	0
451007	449603	14213J	PARTICIPANT	\N	PRESENT	0
451008	449603	14217N	PARTICIPANT	\N	PRESENT	0
425128	425127	04038G	PARTICIPANT	\N	PRESENT	0
425134	425131	14111D	PARTICIPANT	\N	PRESENT	0
425135	425132	14111D	PARTICIPANT	\N	PRESENT	0
425146	425144	19333N	PARTICIPANT	\N	PRESENT	0
425145	425144	14221J	PARTICIPANT	\N	PRESENT	0
425148	425147	14221J	PARTICIPANT	\N	PRESENT	0
425153	425151	14219Q	PARTICIPANT	\N	PRESENT	0
425155	425154	14219Q	PARTICIPANT	\N	PRESENT	0
425157	425156	14219Q	PARTICIPANT	\N	PRESENT	0
425189	425006	11048N	PARTICIPANT	\N	PRESENT	0
425190	425006	08060W	PARTICIPANT	\N	PRESENT	0
425191	425006	08009T	PRESIDENT	0	PRESENT	0
425192	425006	19413M	PARTICIPANT	\N	PRESENT	0
425193	425006	19758L	PARTICIPANT	\N	PRESENT	0
425194	425006	19637C	PARTICIPANT	\N	PRESENT	0
425195	416304	19527W	PARTICIPANT	\N	PRESENT	0
425196	416304	19479G	PARTICIPANT	\N	PRESENT	0
425197	416304	07029T	PARTICIPANT	\N	PRESENT	0
425198	416304	19515S	PARTICIPANT	\N	PRESENT	0
425199	416304	11043H	PARTICIPANT	\N	PRESENT	0
425200	416304	19715Y	PARTICIPANT	\N	PRESENT	0
425202	416304	08010L	PARTICIPANT	\N	PRESENT	0
425203	416304	08073C	PARTICIPANT	\N	PRESENT	0
425204	416304	19583F	PARTICIPANT	\N	PRESENT	0
425205	416304	19727D	PARTICIPANT	\N	PRESENT	0
425206	416304	14265W	PARTICIPANT	\N	PRESENT	0
425207	416304	14001X	PARTICIPANT	\N	PRESENT	0
425208	416304	01048V	PARTICIPANT	\N	PRESENT	0
425209	416304	19531S	PARTICIPANT	\N	PRESENT	0
425210	416304	19683J	PARTICIPANT	\N	PRESENT	0
425211	416304	14159V	PARTICIPANT	\N	PRESENT	0
425212	416304	04043D	PARTICIPANT	\N	PRESENT	0
425213	416304	19507S	PARTICIPANT	\N	PRESENT	0
425318	425317	08015R	PARTICIPANT	\N	PRESENT	0
425319	425317	19515S	PARTICIPANT	\N	PRESENT	0
425320	425317	19575F	PARTICIPANT	\N	PRESENT	0
425321	425317	14329V	PARTICIPANT	\N	PRESENT	0
425322	425317	14061L	PARTICIPANT	\N	PRESENT	0
425323	425317	04049K	PARTICIPANT	\N	PRESENT	0
425324	425317	11097X	PARTICIPANT	\N	PRESENT	0
425422	425420	14187A	PARTICIPANT	\N	PRESENT	0
425425	425423	14187A	PARTICIPANT	\N	PRESENT	0
425432	425431	14187A	PARTICIPANT	\N	PRESENT	0
425441	425099	89017R	PARTICIPANT	\N	PRESENT	0
425442	425099	08014Q	PARTICIPANT	\N	PRESENT	0
425462	425099	11048N	PARTICIPANT	\N	PRESENT	0
425571	416305	14087W	PARTICIPANT	\N	PRESENT	0
425572	416305	19669L	PARTICIPANT	\N	PRESENT	0
425573	416305	11045K	PARTICIPANT	\N	PRESENT	0
425574	416305	08031R	PARTICIPANT	\N	PRESENT	0
425575	416305	14261S	PARTICIPANT	\N	PRESENT	0
425576	416305	14217N	PARTICIPANT	\N	PRESENT	0
425577	416305	19253P	PARTICIPANT	\N	PRESENT	0
425578	416305	14073Q	PARTICIPANT	\N	PRESENT	0
425579	416305	14231L	PARTICIPANT	\N	PRESENT	0
425580	416305	19826F	PARTICIPANT	\N	PRESENT	0
425581	416305	19798U	PARTICIPANT	\N	PRESENT	0
425582	416305	19367Y	PARTICIPANT	\N	PRESENT	0
425583	416305	04018C	PARTICIPANT	\N	PRESENT	0
425589	416305	19794Q	PARTICIPANT	\N	PRESENT	0
425458	416305	86034E	PARTICIPANT	\N	PRESENT	0
425460	425099	14083S	PARTICIPANT	\N	PRESENT	0
425585	416305	14267Y	PARTICIPANT	\N	PRESENT	0
425586	416305	19693L	PARTICIPANT	\N	PRESENT	0
425587	416305	19731Y	PARTICIPANT	\N	PRESENT	0
425588	416305	19657G	PARTICIPANT	\N	PRESENT	0
425590	416305	14069U	PARTICIPANT	\N	PRESENT	0
425591	416305	14331P	PARTICIPANT	\N	PRESENT	0
425593	416305	19383Y	PARTICIPANT	\N	PRESENT	0
425594	416305	19760E	PARTICIPANT	\N	PRESENT	0
425595	416305	19719D	PARTICIPANT	\N	PRESENT	0
425596	416305	19593H	PARTICIPANT	\N	PRESENT	0
425597	416305	19758L	PARTICIPANT	\N	PRESENT	0
425598	416305	19565D	PARTICIPANT	\N	PRESENT	0
425600	416305	14021P	PARTICIPANT	\N	PRESENT	0
425601	416305	14105F	PARTICIPANT	\N	PRESENT	0
425602	416305	19575F	PARTICIPANT	\N	PRESENT	0
425604	416305	19703U	PARTICIPANT	\N	PRESENT	0
425605	416305	01024M	PARTICIPANT	\N	PRESENT	0
425606	416305	08017T	PARTICIPANT	\N	PRESENT	0
425607	416305	14028W	PARTICIPANT	\N	PRESENT	0
425608	416305	08043V	PARTICIPANT	\N	PRESENT	0
425609	416305	14026U	PARTICIPANT	\N	PRESENT	0
425610	416305	14201E	PARTICIPANT	\N	PRESENT	0
425612	416305	19745F	PARTICIPANT	\N	PRESENT	0
425614	416305	08044W	PARTICIPANT	\N	PRESENT	0
425617	416305	14123H	PARTICIPANT	\N	PRESENT	0
425618	416305	01048V	PARTICIPANT	\N	PRESENT	0
425620	416305	04088S	PARTICIPANT	\N	PRESENT	0
425621	425099	11012A	PARTICIPANT	\N	PRESENT	0
425622	416305	14257W	PARTICIPANT	\N	PRESENT	0
425624	416305	19631V	PARTICIPANT	\N	PRESENT	0
425626	416305	08015R	PARTICIPANT	\N	PRESENT	0
425627	416305	14265W	PARTICIPANT	\N	PRESENT	0
425628	416305	19747H	PARTICIPANT	\N	PRESENT	0
425629	416305	14109K	PARTICIPANT	\N	PRESENT	0
425631	416305	11085T	PARTICIPANT	\N	PRESENT	0
425632	416305	19577H	PARTICIPANT	\N	PRESENT	0
425633	416305	19515S	PARTICIPANT	\N	PRESENT	0
425634	416305	01057W	PARTICIPANT	\N	PRESENT	0
425635	416305	19507S	PARTICIPANT	\N	PRESENT	0
425638	416305	14033T	PARTICIPANT	\N	PRESENT	0
425639	416305	80013X	PARTICIPANT	\N	PRESENT	0
425640	416305	14197C	PARTICIPANT	\N	PRESENT	0
425641	425005	14053L	PARTICIPANT	\N	PRESENT	0
425642	425005	11048N	PARTICIPANT	\N	PRESENT	0
425643	425005	95067Q	PARTICIPANT	\N	PRESENT	0
425644	425005	08060W	PARTICIPANT	\N	PRESENT	0
425645	425005	19733B	PARTICIPANT	\N	PRESENT	0
425646	425005	08009T	PRESIDENT	0	PRESENT	0
425647	425005	19367Y	PARTICIPANT	\N	PRESENT	0
425648	425005	19826F	PARTICIPANT	\N	PRESENT	0
425649	425005	08024S	PARTICIPANT	\N	PRESENT	0
425650	425005	14026U	PARTICIPANT	\N	PRESENT	0
425651	425005	19758L	PARTICIPANT	\N	PRESENT	0
425652	425005	04070G	PARTICIPANT	\N	EXCUSE	0
425653	425005	14051J	PARTICIPANT	\N	EXCUSE	0
425654	425005	11065P	PARTICIPANT	\N	EXCUSE	0
425656	416305	19782L	PARTICIPANT	\N	PRESENT	0
425657	416305	14221J	PARTICIPANT	\N	PRESENT	0
425660	416305	98029W	PARTICIPANT	\N	PRESENT	0
425663	416305	04059M	PARTICIPANT	\N	PRESENT	0
425665	416305	11049P	PARTICIPANT	\N	PRESENT	0
425669	416305	14030Q	PARTICIPANT	\N	PRESENT	0
425670	416305	04085P	PARTICIPANT	\N	PRESENT	0
425671	416305	08068F	PARTICIPANT	\N	PRESENT	0
425672	416305	14001X	PARTICIPANT	\N	PRESENT	0
425673	416305	19673G	PARTICIPANT	\N	PRESENT	0
425674	416305	08028W	PARTICIPANT	\N	PRESENT	0
425675	416305	19663E	PARTICIPANT	\N	PRESENT	0
425676	416305	04040A	PARTICIPANT	\N	PRESENT	0
425677	416305	11056N	PARTICIPANT	\N	PRESENT	0
425678	416305	01028R	PARTICIPANT	\N	PRESENT	0
425679	416305	19762G	PARTICIPANT	\N	PRESENT	0
425680	416305	19413M	PARTICIPANT	\N	PRESENT	0
425681	425099	19667J	PARTICIPANT	\N	PRESENT	0
425682	416305	19521Q	PARTICIPANT	\N	PRESENT	0
425683	416305	14053L	PARTICIPANT	\N	PRESENT	0
425684	416305	14179A	PARTICIPANT	\N	PRESENT	0
425686	416305	11027H	PARTICIPANT	\N	PRESENT	0
425687	416305	14083S	PARTICIPANT	\N	PRESENT	0
425688	416305	14111D	PARTICIPANT	\N	PRESENT	0
425689	416305	19549D	PARTICIPANT	\N	PRESENT	0
425690	416305	19333N	PARTICIPANT	\N	PRESENT	0
425691	416305	12016W	PARTICIPANT	\N	PRESENT	0
425692	416305	14065Q	PARTICIPANT	\N	PRESENT	0
425693	416305	19489J	PARTICIPANT	\N	PRESENT	0
425694	416305	14237S	PARTICIPANT	\N	PRESENT	0
425695	416305	19691J	PARTICIPANT	\N	PRESENT	0
425696	416305	07029T	PARTICIPANT	\N	PRESENT	0
425697	416305	14199E	PARTICIPANT	\N	PRESENT	0
425698	425424	19699S	PARTICIPANT	\N	PRESENT	0
425699	425424	04057K	PARTICIPANT	\N	PRESENT	0
425700	425424	14073Q	PARTICIPANT	\N	PRESENT	0
425703	425424	19533U	PARTICIPANT	\N	PRESENT	0
425705	425424	19693L	PARTICIPANT	\N	PRESENT	0
425706	425424	14201E	PARTICIPANT	\N	PRESENT	0
425707	425424	14039A	PARTICIPANT	\N	PRESENT	0
425709	425424	14107H	PARTICIPANT	\N	PRESENT	0
425712	425424	14109K	PARTICIPANT	\N	PRESENT	0
450525	439824	14069U	PARTICIPANT	\N	PRESENT	0
450526	439824	19533U	PARTICIPANT	\N	PRESENT	0
450527	439824	19663E	PARTICIPANT	\N	PRESENT	0
450528	439824	01048V	PARTICIPANT	\N	PRESENT	0
450529	439824	05008E	PARTICIPANT	\N	PRESENT	0
450530	439824	07029T	PARTICIPANT	\N	PRESENT	0
450531	439824	18083K	PARTICIPANT	\N	PRESENT	0
450532	439824	19415P	PARTICIPANT	\N	PRESENT	0
450533	439824	14031R	PARTICIPANT	\N	PRESENT	0
450534	439824	19697Q	PARTICIPANT	\N	PRESENT	0
450535	439824	14147R	PARTICIPANT	\N	PRESENT	0
450536	439824	99004R	PARTICIPANT	\N	PRESENT	0
450537	439824	14065Q	PARTICIPANT	\N	PRESENT	0
450538	439824	19447X	PARTICIPANT	\N	PRESENT	0
450539	439824	14063N	PARTICIPANT	\N	PRESENT	0
450540	439824	19543W	PARTICIPANT	\N	PRESENT	0
450541	439824	14231L	PARTICIPANT	\N	PRESENT	0
450542	439824	14042U	PARTICIPANT	\N	PRESENT	0
450543	439824	19575F	PARTICIPANT	\N	PRESENT	0
450544	439824	14157T	PARTICIPANT	\N	PRESENT	0
450545	439824	14083S	PARTICIPANT	\N	PRESENT	0
450546	439824	14109K	PARTICIPANT	\N	PRESENT	0
450547	447583	08056B	PARTICIPANT	\N	PRESENT	0
450548	447583	04044E	PARTICIPANT	\N	PRESENT	0
450549	447583	19673G	PARTICIPANT	\N	PRESENT	0
450550	447583	19719D	PRESIDENT	0	PRESENT	0
450551	439824	11103C	PARTICIPANT	\N	PRESENT	0
450552	439824	14217N	PARTICIPANT	\N	PRESENT	0
450553	439824	19479G	PARTICIPANT	\N	PRESENT	0
450554	439824	01024M	PARTICIPANT	\N	PRESENT	0
450555	439824	04043D	PARTICIPANT	\N	PRESENT	0
450556	439824	04088S	PARTICIPANT	\N	PRESENT	0
450557	439824	19703U	PARTICIPANT	\N	PRESENT	0
450558	439824	11101A	PARTICIPANT	\N	PRESENT	0
450559	439824	19687N	PARTICIPANT	\N	PRESENT	0
450560	439824	19671E	PARTICIPANT	\N	PRESENT	0
450561	439824	04085P	PARTICIPANT	\N	PRESENT	0
450562	439824	11012A	PARTICIPANT	\N	PRESENT	0
450563	439824	19798U	PARTICIPANT	\N	PRESENT	0
450564	439824	19399H	PARTICIPANT	\N	PRESENT	0
450565	439824	19253P	PARTICIPANT	\N	PRESENT	0
450572	439824	04069P	PARTICIPANT	\N	PRESENT	0
450567	439824	14087W	PARTICIPANT	\N	PRESENT	0
450568	439824	19758L	PARTICIPANT	\N	PRESENT	0
450569	439824	19729F	PARTICIPANT	\N	PRESENT	0
450570	439824	11099A	PARTICIPANT	\N	PRESENT	0
450571	439824	19387D	PARTICIPANT	\N	PRESENT	0
450573	439824	08019V	PARTICIPANT	\N	PRESENT	0
450574	439824	05012A	PARTICIPANT	\N	PRESENT	0
450575	439824	08039A	PARTICIPANT	\N	PRESENT	0
450576	439824	19629C	PARTICIPANT	\N	PRESENT	0
450577	439824	19713W	PARTICIPANT	\N	PRESENT	0
450578	439824	11045K	PARTICIPANT	\N	PRESENT	0
450579	439824	19649G	PARTICIPANT	\N	PRESENT	0
450580	439824	14281W	PARTICIPANT	\N	PRESENT	0
450581	439824	10015M	PARTICIPANT	\N	PRESENT	0
450582	439824	08031R	PARTICIPANT	\N	PRESENT	0
450583	439824	14179A	PARTICIPANT	\N	PRESENT	0
450584	439824	19812Y	PARTICIPANT	\N	PRESENT	0
450585	439824	19820Y	PARTICIPANT	\N	PRESENT	0
450586	439824	11097X	PARTICIPANT	\N	PRESENT	0
450587	439824	14251Q	PARTICIPANT	\N	PRESENT	0
450588	439824	11109J	PARTICIPANT	\N	PRESENT	0
450589	439824	11010L	PARTICIPANT	\N	PRESENT	0
450590	439824	19515S	PARTICIPANT	\N	PRESENT	0
450591	439824	19549D	PARTICIPANT	\N	PRESENT	0
450592	439824	14255U	PARTICIPANT	\N	PRESENT	0
450593	439824	19691J	PARTICIPANT	\N	PRESENT	0
450594	439824	19441R	PARTICIPANT	\N	PRESENT	0
450595	439824	19621T	PARTICIPANT	\N	PRESENT	0
450596	439824	04033B	PARTICIPANT	\N	PRESENT	0
450597	439824	10006L	PARTICIPANT	\N	PRESENT	0
450598	439824	98024R	PARTICIPANT	\N	PRESENT	0
450599	439824	01057W	PARTICIPANT	\N	PRESENT	0
450600	439824	04059M	PARTICIPANT	\N	PRESENT	0
450601	439824	19599P	PARTICIPANT	\N	PRESENT	0
450602	439824	19693L	PARTICIPANT	\N	PRESENT	0
450603	447583	04040A	PARTICIPANT	\N	PRESENT	0
450605	439824	08043V	PARTICIPANT	\N	PRESENT	0
450621	445946	19479G	PARTICIPANT	\N	PRESENT	0
450622	445946	02002K	PARTICIPANT	\N	EXCUSE	0
450623	439826	11027H	PARTICIPANT	\N	PRESENT	0
450624	445946	11097X	PARTICIPANT	\N	PRESENT	0
450625	445946	08069G	PARTICIPANT	\N	EXCUSE	0
450633	445946	19713W	PARTICIPANT	\N	EXCUSE	0
450634	439826	14267Y	PARTICIPANT	\N	PRESENT	0
450635	439826	11040E	PARTICIPANT	\N	PRESENT	0
450636	439826	10015M	PARTICIPANT	\N	PRESENT	0
450637	439826	18083K	PARTICIPANT	\N	PRESENT	0
450638	439826	19737F	PARTICIPANT	\N	PRESENT	0
450639	439826	14235Q	PARTICIPANT	\N	PRESENT	0
450640	439826	19669L	PARTICIPANT	\N	PRESENT	0
450641	439826	14085U	PARTICIPANT	\N	PRESENT	0
450642	439826	19251M	PARTICIPANT	\N	PRESENT	0
450643	439826	04034C	PARTICIPANT	\N	PRESENT	0
450644	439826	14121F	PARTICIPANT	\N	PRESENT	0
450645	439826	98005N	PARTICIPANT	\N	PRESENT	0
450646	439826	01057W	PARTICIPANT	\N	PRESENT	0
450647	439826	19711U	PARTICIPANT	\N	PRESENT	0
450648	439826	11012A	PARTICIPANT	\N	PRESENT	0
450649	439826	19794Q	PARTICIPANT	\N	PRESENT	0
450650	439826	14119M	PARTICIPANT	\N	PRESENT	0
450651	439826	14255U	PARTICIPANT	\N	PRESENT	0
450652	439826	14071N	PARTICIPANT	\N	PRESENT	0
450653	439826	14089Y	PARTICIPANT	\N	PRESENT	0
450654	439826	14147R	PARTICIPANT	\N	PRESENT	0
450655	439826	14069U	PARTICIPANT	\N	PRESENT	0
450656	439826	11064N	PARTICIPANT	\N	PRESENT	0
450657	439826	04086Q	PARTICIPANT	\N	PRESENT	0
450658	439826	01062T	PARTICIPANT	\N	PRESENT	0
450661	439826	11070L	PARTICIPANT	\N	PRESENT	0
450662	439826	14031R	PARTICIPANT	\N	PRESENT	0
450663	439826	19741B	PARTICIPANT	\N	PRESENT	0
450692	439827	11070L	PARTICIPANT	\N	PRESENT	0
450693	439827	14085U	PARTICIPANT	\N	PRESENT	0
450694	439827	11040E	PARTICIPANT	\N	PRESENT	0
450695	439827	14235Q	PARTICIPANT	\N	PRESENT	0
450696	439827	98005N	PARTICIPANT	\N	PRESENT	0
450697	439827	14255U	PARTICIPANT	\N	PRESENT	0
450698	439827	19737F	PARTICIPANT	\N	PRESENT	0
450699	439827	14267Y	PARTICIPANT	\N	PRESENT	0
450700	439827	11012A	PARTICIPANT	\N	PRESENT	0
450701	439827	19711U	PARTICIPANT	\N	PRESENT	0
450702	439827	04086Q	PARTICIPANT	\N	PRESENT	0
450703	439827	10015M	PARTICIPANT	\N	PRESENT	0
450704	439827	08073C	PARTICIPANT	\N	PRESENT	0
450705	439827	14031R	PARTICIPANT	\N	PRESENT	0
450706	439827	19794Q	PARTICIPANT	\N	PRESENT	0
450712	439827	19479G	PARTICIPANT	\N	PRESENT	0
450713	445946	08024S	PARTICIPANT	\N	PRESENT	0
450714	445946	08045X	PARTICIPANT	\N	PRESENT	0
450715	439827	19741B	PARTICIPANT	\N	PRESENT	0
450716	439827	08010L	PARTICIPANT	\N	PRESENT	0
450718	448623	14069U	PARTICIPANT	\N	PRESENT	0
450719	448623	19253P	PARTICIPANT	\N	PRESENT	0
450720	448623	14063N	PARTICIPANT	\N	PRESENT	0
450721	448623	04086Q	PARTICIPANT	\N	PRESENT	0
450722	448623	01057W	PARTICIPANT	\N	PRESENT	0
450724	448623	05012A	PARTICIPANT	\N	PRESENT	0
450690	439827	11027H	PARTICIPANT	\N	PRESENT	0
450691	439827	11074Q	PARTICIPANT	\N	PRESENT	0
450725	448623	14231L	PARTICIPANT	\N	PRESENT	0
450726	448623	08010L	PARTICIPANT	\N	PRESENT	0
450727	448623	17637T	PARTICIPANT	\N	PRESENT	0
450729	448623	19820Y	PARTICIPANT	\N	PRESENT	0
450730	448623	14281W	PARTICIPANT	\N	PRESENT	0
450731	448623	14071N	PARTICIPANT	\N	EXCUSE	0
450732	439827	14215L	PARTICIPANT	\N	PRESENT	0
450762	443771	08043V	PARTICIPANT	\N	PRESENT	0
450763	443771	11031D	PARTICIPANT	\N	EXCUSE	0
450764	443771	19577H	PARTICIPANT	\N	EXCUSE	0
450765	443771	19599P	PARTICIPANT	\N	PRESENT	0
450766	443771	08031R	PARTICIPANT	\N	PRESENT	0
450767	443771	07029T	PARTICIPANT	\N	EXCUSE	0
450768	443771	01043Q	PARTICIPANT	\N	EXCUSE	0
450769	443771	11067R	PARTICIPANT	\N	PRESENT	0
450770	443771	14235Q	PARTICIPANT	\N	EXCUSE	0
450771	443771	19749K	PARTICIPANT	\N	PRESENT	0
450772	445946	19737F	PARTICIPANT	\N	EXCUSE	0
450773	441731	14030Q	PRESIDENT	0	PRESENT	0
450774	441731	08043V	PARTICIPANT	\N	PRESENT	0
450775	441731	11031D	PARTICIPANT	\N	EXCUSE	0
450776	441731	19577H	PARTICIPANT	\N	EXCUSE	0
450777	441731	19599P	PARTICIPANT	\N	PRESENT	0
450778	441731	08031R	PARTICIPANT	\N	EXCUSE	0
450779	441731	07029T	PARTICIPANT	\N	EXCUSE	0
450780	441731	01043Q	PARTICIPANT	\N	EXCUSE	0
450760	443898	04086Q	PARTICIPANT	\N	PRESENT	0
450761	443771	14030Q	PRESIDENT	0	PRESENT	0
427842	424896	04040A	PRESIDENT	0	PRESENT	0
427843	424896	19253P	PARTICIPANT	\N	PRESENT	0
427844	424896	19525U	PARTICIPANT	\N	PRESENT	0
427845	424896	14231L	PARTICIPANT	\N	PRESENT	0
427846	424896	11049P	PARTICIPANT	\N	PRESENT	0
427847	424896	05012A	PARTICIPANT	\N	PRESENT	0
427848	424896	08010L	PARTICIPANT	\N	PRESENT	0
427849	424896	95067Q	PARTICIPANT	\N	PRESENT	0
427850	424896	01057W	PARTICIPANT	\N	PRESENT	0
427851	424896	19565D	PARTICIPANT	\N	PRESENT	0
432884	430647	14030Q	PRESIDENT	0	PRESENT	0
432885	430647	08043V	PARTICIPANT	\N	EXCUSE	0
432886	430647	19621T	PARTICIPANT	\N	PRESENT	0
432887	430647	19701S	PARTICIPANT	\N	PRESENT	0
432888	430647	11031D	PARTICIPANT	\N	PRESENT	0
432889	430647	19693L	PARTICIPANT	\N	PRESENT	0
432891	430647	04035D	PARTICIPANT	\N	PRESENT	0
432893	430647	19731Y	PARTICIPANT	\N	PRESENT	0
432894	430647	08031R	PARTICIPANT	\N	PRESENT	0
432897	430647	07029T	PARTICIPANT	\N	EXCUSE	0
432898	430647	08017T	PARTICIPANT	\N	PRESENT	0
432900	430647	14109K	PARTICIPANT	\N	PRESENT	0
432903	430647	11045K	PARTICIPANT	\N	PRESENT	0
434007	428497	08024S	PARTICIPANT	\N	PRESENT	0
434008	428497	08045X	PARTICIPANT	\N	PRESENT	0
434778	434777	14239U	PARTICIPANT	\N	PRESENT	0
435736	435735	14265W	PARTICIPANT	\N	PRESENT	0
435738	435735	14207L	PARTICIPANT	\N	PRESENT	0
435739	435735	19413M	PARTICIPANT	\N	PRESENT	0
435740	435735	19347U	PARTICIPANT	\N	PRESENT	0
435742	435735	19369B	PARTICIPANT	\N	PRESENT	0
435743	435735	19575F	PARTICIPANT	\N	PRESENT	0
435773	435768	14147R	PARTICIPANT	\N	PRESENT	0
435746	435735	19747H	PARTICIPANT	\N	PRESENT	0
435771	435768	19447X	PARTICIPANT	\N	PRESENT	0
435775	435770	19447X	PARTICIPANT	\N	PRESENT	0
435776	435770	14147R	PARTICIPANT	\N	PRESENT	0
439533	439532	05008E	PARTICIPANT	\N	PRESENT	0
439800	439787	14026U	PARTICIPANT	\N	PRESENT	0
439535	439532	14259Y	PARTICIPANT	\N	PRESENT	0
439536	439532	19719D	PARTICIPANT	\N	PRESENT	0
439537	439532	14215L	PARTICIPANT	\N	PRESENT	0
439550	439548	19651A	PARTICIPANT	\N	PRESENT	0
439539	439532	14231L	PARTICIPANT	\N	PRESENT	0
439540	439532	14179A	PARTICIPANT	\N	PRESENT	0
439541	439532	19489J	PARTICIPANT	\N	PRESENT	0
439542	439532	14001X	PARTICIPANT	\N	PRESENT	0
439551	439548	19741B	PARTICIPANT	\N	PRESENT	0
439544	439532	95063L	PARTICIPANT	\N	PRESENT	0
439545	439532	19762G	PARTICIPANT	\N	PRESENT	0
439546	439532	01028R	PARTICIPANT	\N	PRESENT	0
440474	438239	08043V	PARTICIPANT	\N	EXCUSE	0
439553	439548	14085U	PARTICIPANT	\N	PRESENT	0
439554	439548	04086Q	PARTICIPANT	\N	PRESENT	0
439555	439548	11070L	PARTICIPANT	\N	PRESENT	0
440462	438239	14030Q	PRESIDENT	0	PRESENT	0
439557	439548	11074Q	PARTICIPANT	\N	PRESENT	0
439558	439548	01057W	PARTICIPANT	\N	PRESENT	0
440481	438239	19621T	PARTICIPANT	\N	PRESENT	0
439560	439548	14121F	PARTICIPANT	\N	PRESENT	0
439561	439548	19711U	PARTICIPANT	\N	PRESENT	0
440482	438239	11031D	PARTICIPANT	\N	PRESENT	0
440483	438239	19693L	PARTICIPANT	\N	PRESENT	0
440484	438239	19577H	PARTICIPANT	\N	EXCUSE	0
440485	438239	04035D	PARTICIPANT	\N	PRESENT	0
440486	438239	08031R	PARTICIPANT	\N	EXCUSE	0
440487	438239	07029T	PARTICIPANT	\N	EXCUSE	0
440488	438239	08017T	PARTICIPANT	\N	PRESENT	0
440489	438239	11067R	PARTICIPANT	\N	PRESENT	0
440490	438239	19749K	PARTICIPANT	\N	PRESENT	0
440932	440931	04088S	PARTICIPANT	\N	PRESENT	0
440933	440931	14265W	PARTICIPANT	\N	PRESENT	0
440934	440931	14059S	PARTICIPANT	\N	PRESENT	0
440935	440931	19731Y	PARTICIPANT	\N	PRESENT	0
440936	440931	11048N	PARTICIPANT	\N	PRESENT	0
440937	440931	10006L	PARTICIPANT	\N	PRESENT	0
440938	440931	19575F	PARTICIPANT	\N	PRESENT	0
441961	439716	14030Q	PRESIDENT	0	PRESENT	0
441962	439716	08043V	PARTICIPANT	\N	PRESENT	0
441963	439716	19367Y	PARTICIPANT	\N	PRESENT	0
441964	439716	19621T	PARTICIPANT	\N	EXCUSE	0
441965	439716	08024S	PARTICIPANT	\N	EXCUSE	0
441966	439716	18083K	PARTICIPANT	\N	EXCUSE	0
441967	439716	19701S	PARTICIPANT	\N	PRESENT	0
441968	439716	11031D	PARTICIPANT	\N	PRESENT	0
441969	439716	80013X	PARTICIPANT	\N	EXCUSE	0
441970	439716	14217N	PARTICIPANT	\N	PRESENT	0
441972	439716	14249W	PARTICIPANT	\N	EXCUSE	0
441973	439716	19599P	PARTICIPANT	\N	EXCUSE	0
441974	439716	04035D	PARTICIPANT	\N	PRESENT	0
441975	439716	14179A	PARTICIPANT	\N	PRESENT	0
441977	439716	19715Y	PARTICIPANT	\N	PRESENT	0
441978	439716	19731Y	PARTICIPANT	\N	EXCUSE	0
441979	439716	08031R	PARTICIPANT	\N	PRESENT	0
441980	439716	07029T	PARTICIPANT	\N	EXCUSE	0
441981	439716	08017T	PARTICIPANT	\N	PRESENT	0
441982	439716	01043Q	PARTICIPANT	\N	EXCUSE	0
441983	439716	11067R	PARTICIPANT	\N	EXCUSE	0
441984	439716	14109K	PARTICIPANT	\N	PRESENT	0
441985	439716	14235Q	PARTICIPANT	\N	EXCUSE	0
441986	439716	19269X	PARTICIPANT	\N	EXCUSE	0
441987	439716	11045K	PARTICIPANT	\N	PRESENT	0
441988	439716	19749K	PARTICIPANT	\N	PRESENT	0
441990	439716	19577H	PARTICIPANT	\N	EXCUSE	0
444838	444822	04070G	PARTICIPANT	\N	PRESENT	0
444843	444822	08031R	PARTICIPANT	\N	PRESENT	0
444845	444822	11104D	PARTICIPANT	\N	PRESENT	0
444856	444822	08043V	PARTICIPANT	\N	PRESENT	0
444860	444822	08020N	PARTICIPANT	\N	PRESENT	0
444863	444822	87003B	PARTICIPANT	\N	PRESENT	0
444869	444822	19731Y	PARTICIPANT	\N	PRESENT	0
444873	444822	14061L	PARTICIPANT	\N	PRESENT	0
444876	444822	19611R	PARTICIPANT	\N	PRESENT	0
444879	444822	19699S	PARTICIPANT	\N	PRESENT	0
444881	444822	08017T	PARTICIPANT	\N	PRESENT	0
444884	444822	14063N	PARTICIPANT	\N	PRESENT	0
444886	444822	14109K	PARTICIPANT	\N	PRESENT	0
444889	444822	19573D	PARTICIPANT	\N	PRESENT	0
444894	444822	04018C	PARTICIPANT	\N	PRESENT	0
446197	439813	14053L	PARTICIPANT	\N	PRESENT	0
446198	439813	19737F	PARTICIPANT	\N	PRESENT	0
446199	439813	14042U	PARTICIPANT	\N	PRESENT	0
446200	439813	14215L	PARTICIPANT	\N	PRESENT	0
446201	439813	04040A	PARTICIPANT	\N	PRESENT	0
446202	439813	19798U	PARTICIPANT	\N	PRESENT	0
446203	439813	98005N	PARTICIPANT	\N	PRESENT	0
446204	439813	19711U	PARTICIPANT	\N	PRESENT	0
446205	439813	14261S	PARTICIPANT	\N	PRESENT	0
446206	439813	19575F	PARTICIPANT	\N	PRESENT	0
446207	439813	11066Q	PARTICIPANT	\N	PRESENT	0
446208	439813	19515S	PARTICIPANT	\N	PRESENT	0
446209	439813	04070G	PARTICIPANT	\N	PRESENT	0
446210	439813	19826F	PARTICIPANT	\N	PRESENT	0
446211	439813	19643A	PARTICIPANT	\N	PRESENT	0
446212	439813	11085T	PARTICIPANT	\N	PRESENT	0
446213	439813	11080N	PARTICIPANT	\N	PRESENT	0
446214	439813	01025N	PARTICIPANT	\N	PRESENT	0
446215	439813	01057W	PARTICIPANT	\N	PRESENT	0
446216	439813	04088S	PARTICIPANT	\N	PRESENT	0
446217	439813	19703U	PARTICIPANT	\N	PRESENT	0
446218	439813	19507S	PARTICIPANT	\N	PRESENT	0
446219	439813	19741B	PARTICIPANT	\N	PRESENT	0
446220	439813	19667J	PARTICIPANT	\N	PRESENT	0
446221	439813	19415P	PARTICIPANT	\N	PRESENT	0
446222	439813	18083K	PARTICIPANT	\N	PRESENT	0
446223	439813	19467C	PARTICIPANT	\N	PRESENT	0
446224	439813	14031R	PARTICIPANT	\N	PRESENT	0
446225	439813	14038Y	PARTICIPANT	\N	PRESENT	0
446226	439813	14055N	PARTICIPANT	\N	PRESENT	0
446227	439813	19731Y	PARTICIPANT	\N	PRESENT	0
446228	439813	19745F	PARTICIPANT	\N	PRESENT	0
446229	439813	19367Y	PARTICIPANT	\N	PRESENT	0
446230	439813	19671E	PARTICIPANT	\N	PRESENT	0
446241	439813	19383Y	PARTICIPANT	\N	PRESENT	0
446240	439813	14329V	PARTICIPANT	\N	PRESENT	0
446233	439813	14079W	PARTICIPANT	\N	PRESENT	0
446234	439813	04018C	PARTICIPANT	\N	PRESENT	0
446235	439813	11048N	PARTICIPANT	\N	PRESENT	0
446236	439813	14147R	PARTICIPANT	\N	PRESENT	0
446237	439813	14105F	PARTICIPANT	\N	PRESENT	0
446238	439813	19621T	PARTICIPANT	\N	PRESENT	0
446239	439813	08039A	PARTICIPANT	\N	PRESENT	0
446242	439813	14205J	PARTICIPANT	\N	PRESENT	0
446243	439813	11103C	PARTICIPANT	\N	PRESENT	0
446244	439813	14217N	PARTICIPANT	\N	PRESENT	0
446245	439813	10006L	PARTICIPANT	\N	PRESENT	0
446246	439813	19533U	PARTICIPANT	\N	PRESENT	0
446247	439813	11045K	PARTICIPANT	\N	PRESENT	0
446248	439813	19689Q	PARTICIPANT	\N	PRESENT	0
450868	450867	98050T	PARTICIPANT	\N	PRESENT	0
450870	450869	98050T	PARTICIPANT	\N	PRESENT	0
450871	450869	14267Y	PARTICIPANT	\N	PRESENT	0
450872	450869	11064N	PARTICIPANT	\N	PRESENT	0
450874	450873	98050T	PARTICIPANT	\N	PRESENT	0
450875	450873	11064N	PARTICIPANT	\N	PRESENT	0
450877	450876	98050T	PARTICIPANT	\N	PRESENT	0
450885	445946	11056N	PARTICIPANT	\N	EXCUSE	0
451009	449603	01034P	PARTICIPANT	\N	PRESENT	0
451010	449603	04092N	PRESIDENT	0	PRESENT	0
451011	449603	11045K	PARTICIPANT	\N	PRESENT	0
451012	449603	08052W	PARTICIPANT	\N	PRESENT	0
451013	449603	19715Y	PARTICIPANT	\N	PRESENT	0
451014	449603	19723Y	PARTICIPANT	\N	PRESENT	0
451015	449603	14119M	PARTICIPANT	\N	PRESENT	0
451016	449603	11103C	PARTICIPANT	\N	PRESENT	0
451017	449603	14071N	PARTICIPANT	\N	PRESENT	0
451018	449603	19760E	PARTICIPANT	\N	PRESENT	0
451019	449603	19727D	PARTICIPANT	\N	PRESENT	0
451020	450967	86034E	PARTICIPANT	\N	PRESENT	0
451021	450967	12041X	PARTICIPANT	\N	PRESENT	0
451022	450967	11040E	PARTICIPANT	\N	PRESENT	0
451023	450967	11056N	PARTICIPANT	\N	PRESENT	0
451024	450967	14235Q	PARTICIPANT	\N	PRESENT	0
451025	450967	11031D	PARTICIPANT	\N	PRESENT	0
451026	450967	19760E	PARTICIPANT	\N	PRESENT	0
451027	450967	19695N	PARTICIPANT	\N	PRESENT	0
451028	450967	14201E	PARTICIPANT	\N	PRESENT	0
451029	450967	98022P	PARTICIPANT	\N	PRESENT	0
451030	450967	19553Y	PARTICIPANT	\N	PRESENT	0
451031	450967	19629C	PARTICIPANT	\N	PRESENT	0
451032	450967	19681G	PARTICIPANT	\N	PRESENT	0
451033	450967	19583F	PARTICIPANT	\N	PRESENT	0
451034	450967	19387D	PARTICIPANT	\N	PRESENT	0
451035	450967	19565D	PARTICIPANT	\N	PRESENT	0
451036	450967	19758L	PARTICIPANT	\N	PRESENT	0
451037	450967	19593H	PARTICIPANT	\N	PRESENT	0
451038	450967	11077T	PARTICIPANT	\N	PRESENT	0
451039	450967	04085P	PARTICIPANT	\N	PRESENT	0
451040	450967	08031R	PARTICIPANT	\N	PRESENT	0
451041	450967	19717B	PARTICIPANT	\N	PRESENT	0
451042	450967	08061X	PARTICIPANT	\N	PRESENT	0
451043	450967	04045F	PARTICIPANT	\N	PRESENT	0
451044	450967	19301E	PARTICIPANT	\N	PRESENT	0
451045	450967	11083R	PARTICIPANT	\N	PRESENT	0
451046	450967	01060R	PARTICIPANT	\N	PRESENT	0
451047	450967	19731Y	PARTICIPANT	\N	PRESENT	0
451048	450967	19685L	PARTICIPANT	\N	PRESENT	0
451049	450967	14207L	PARTICIPANT	\N	PRESENT	0
451050	450967	88008L	PARTICIPANT	\N	PRESENT	0
451051	450967	11012A	PARTICIPANT	\N	PRESENT	0
451052	450967	14211G	PARTICIPANT	\N	PRESENT	0
451053	450967	14239U	PARTICIPANT	\N	PRESENT	0
451054	450967	08049C	PARTICIPANT	\N	PRESENT	0
451055	450967	19711U	PARTICIPANT	\N	PRESENT	0
451056	450967	14261S	PARTICIPANT	\N	PRESENT	0
451057	450967	14241N	PARTICIPANT	\N	PRESENT	0
451058	450967	14121F	PARTICIPANT	\N	PRESENT	0
451059	450967	11072N	PARTICIPANT	\N	PRESENT	0
451060	450967	19585H	PARTICIPANT	\N	PRESENT	0
451061	450967	19697Q	PARTICIPANT	\N	PRESENT	0
451062	450967	04008A	PARTICIPANT	\N	PRESENT	0
451063	450967	98005N	PARTICIPANT	\N	PRESENT	0
451064	450967	98018T	PARTICIPANT	\N	PRESENT	0
451068	450967	14157T	PARTICIPANT	\N	PRESENT	0
451066	450967	14093U	PARTICIPANT	\N	PRESENT	0
451067	450967	14195A	PARTICIPANT	\N	PRESENT	0
451069	450967	96004D	PARTICIPANT	\N	PRESENT	0
451070	450967	19443T	PARTICIPANT	\N	PRESENT	0
451071	450967	14251Q	PARTICIPANT	\N	PRESENT	0
451072	450967	19563B	PARTICIPANT	\N	PRESENT	0
451073	450967	04057K	PARTICIPANT	\N	PRESENT	0
451074	450967	19709B	PARTICIPANT	\N	PRESENT	0
451075	450967	04088S	PARTICIPANT	\N	PRESENT	0
451076	450967	08073C	PARTICIPANT	\N	PRESENT	0
451077	450967	08018U	PARTICIPANT	\N	PRESENT	0
451078	450967	19782L	PARTICIPANT	\N	PRESENT	0
451079	450967	14041T	PARTICIPANT	\N	PRESENT	0
451080	450967	19329S	PARTICIPANT	\N	PRESENT	0
451081	450967	14039A	PARTICIPANT	\N	PRESENT	0
451082	450967	07029T	PARTICIPANT	\N	PRESENT	0
451083	450967	19657G	PARTICIPANT	\N	PRESENT	0
451084	450967	19812Y	PARTICIPANT	\N	PRESENT	0
451085	450967	14355X	PARTICIPANT	\N	PRESENT	0
451086	450967	08015R	PARTICIPANT	\N	PRESENT	0
451087	450967	11065P	PARTICIPANT	\N	PRESENT	0
451088	450967	19768N	PARTICIPANT	\N	PRESENT	0
451089	450967	14061L	PARTICIPANT	\N	PRESENT	0
451090	450967	95063L	PARTICIPANT	\N	PRESENT	0
451091	450967	14059S	PARTICIPANT	\N	PRESENT	0
451092	450967	19591F	PARTICIPANT	\N	PRESENT	0
451093	450967	95037J	PARTICIPANT	\N	PRESENT	0
451094	450967	14038Y	PARTICIPANT	\N	PRESENT	0
451095	450967	04034C	PARTICIPANT	\N	PRESENT	0
451096	450967	19723Y	PARTICIPANT	\N	PRESENT	0
451097	450967	19507S	PARTICIPANT	\N	PRESENT	0
451098	450967	19421M	PARTICIPANT	\N	PRESENT	0
451099	450967	19467C	PARTICIPANT	\N	PRESENT	0
451100	450967	08056B	PARTICIPANT	\N	PRESENT	0
451101	450967	18083K	PARTICIPANT	\N	PRESENT	0
451102	450967	19415P	PARTICIPANT	\N	PRESENT	0
451103	450967	14033T	PARTICIPANT	\N	PRESENT	0
451104	450967	14135M	PARTICIPANT	\N	PRESENT	0
451105	450967	04089T	PARTICIPANT	\N	PRESENT	0
451106	450967	14231L	PARTICIPANT	\N	PRESENT	0
451107	450967	08019V	PARTICIPANT	\N	PRESENT	0
451108	450967	19253P	PARTICIPANT	\N	PRESENT	0
451109	450967	19399H	PARTICIPANT	\N	PRESENT	0
451110	450967	19691J	PARTICIPANT	\N	PRESENT	0
451111	450967	19693L	PARTICIPANT	\N	PRESENT	0
451112	450967	19729F	PARTICIPANT	\N	PRESENT	0
451113	450967	08048B	PARTICIPANT	\N	PRESENT	0
451114	450967	14329V	PARTICIPANT	\N	PRESENT	0
451115	450967	19762G	PARTICIPANT	\N	PRESENT	0
451116	450967	04018C	PARTICIPANT	\N	PRESENT	0
451117	450967	19621T	PARTICIPANT	\N	PRESENT	0
451118	450967	19369B	PARTICIPANT	\N	PRESENT	0
451119	450967	19367Y	PARTICIPANT	\N	PRESENT	0
451120	450967	19319Q	PARTICIPANT	\N	PRESENT	0
451121	450967	19581D	PARTICIPANT	\N	PRESENT	0
451122	450967	11085T	PARTICIPANT	\N	PRESENT	0
451123	450967	19671E	PARTICIPANT	\N	PRESENT	0
451124	450967	19611R	PARTICIPANT	\N	PRESENT	0
451125	450967	14079W	PARTICIPANT	\N	PRESENT	0
451126	450967	08009T	PARTICIPANT	\N	PRESENT	0
451127	450967	04069P	PARTICIPANT	\N	PRESENT	0
451128	450967	19737F	PARTICIPANT	\N	PRESENT	0
451129	450967	19699S	PARTICIPANT	\N	PRESENT	0
451130	450967	07033P	PARTICIPANT	\N	PRESENT	0
451131	450967	19721W	PARTICIPANT	\N	PRESENT	0
451132	450967	19619A	PARTICIPANT	\N	PRESENT	0
451133	450967	11064N	PARTICIPANT	\N	PRESENT	0
451134	450967	19701S	PARTICIPANT	\N	PRESENT	0
451135	450967	16685X	PARTICIPANT	\N	PRESENT	0
451136	450967	19739H	PARTICIPANT	\N	PRESENT	0
451137	450967	19735D	PARTICIPANT	\N	PRESENT	0
451138	450967	14217N	PARTICIPANT	\N	PRESENT	0
451139	450967	14042U	PARTICIPANT	\N	PRESENT	0
451140	450967	19383Y	PARTICIPANT	\N	PRESENT	0
451141	450967	14267Y	PARTICIPANT	\N	PRESENT	0
451142	450967	14103D	PARTICIPANT	\N	PRESENT	0
451143	450967	14221J	PARTICIPANT	\N	PRESENT	0
451144	450967	19335Q	PARTICIPANT	\N	PRESENT	0
451145	450967	11103C	PARTICIPANT	\N	PRESENT	0
451146	450967	14083S	PARTICIPANT	\N	PRESENT	0
451147	450967	97011G	PARTICIPANT	\N	PRESENT	0
451148	450967	19521Q	PARTICIPANT	\N	PRESENT	0
451149	450967	17583W	PARTICIPANT	\N	PRESENT	0
451150	450967	19826F	PARTICIPANT	\N	PRESENT	0
451151	450967	08047A	PARTICIPANT	\N	PRESENT	0
451152	450967	19577H	PARTICIPANT	\N	PRESENT	0
451153	450967	14115H	PARTICIPANT	\N	PRESENT	0
451154	450967	04040A	PARTICIPANT	\N	PRESENT	0
451155	450967	11049P	PARTICIPANT	\N	PRESENT	0
451156	450967	04070G	PARTICIPANT	\N	PRESENT	0
451157	450967	14030Q	PARTICIPANT	\N	PRESENT	0
451158	450967	14029X	PARTICIPANT	\N	PRESENT	0
451159	450967	14179A	PARTICIPANT	\N	PRESENT	0
451160	450967	14327T	PARTICIPANT	\N	PRESENT	0
451161	450967	01043Q	PARTICIPANT	\N	PRESENT	0
451162	450967	11033F	PARTICIPANT	\N	PRESENT	0
451163	450967	14133K	PARTICIPANT	\N	PRESENT	0
451164	450967	14119M	PARTICIPANT	\N	PRESENT	0
451165	450967	04038G	PARTICIPANT	\N	PRESENT	0
451166	450967	19794Q	PARTICIPANT	\N	PRESENT	0
451167	450967	19573D	PARTICIPANT	\N	PRESENT	0
451168	450967	14173T	PARTICIPANT	\N	PRESENT	0
451169	450967	19749K	PARTICIPANT	\N	PRESENT	0
425715	425424	07033P	PARTICIPANT	\N	PRESENT	0
425787	416305	05012A	PARTICIPANT	\N	PRESENT	0
425717	425424	19758L	PARTICIPANT	\N	PRESENT	0
425719	425424	14249W	PARTICIPANT	\N	PRESENT	0
425721	425424	08039A	PRESIDENT	0	PRESENT	0
425724	425424	08031R	PARTICIPANT	\N	PRESENT	0
425727	425424	14061L	PARTICIPANT	\N	PRESENT	0
425772	416305	19531S	PARTICIPANT	\N	PRESENT	0
425775	425424	87003B	PARTICIPANT	\N	PRESENT	0
425776	425424	19573D	PARTICIPANT	\N	EXCUSE	0
425788	416305	19543W	PARTICIPANT	\N	PRESENT	0
425789	416305	10015M	PARTICIPANT	\N	PRESENT	0
425790	423924	19768N	PARTICIPANT	\N	PRESENT	0
425791	423924	19515S	PARTICIPANT	\N	PRESENT	0
425792	423924	19782L	PARTICIPANT	\N	PRESENT	0
425793	423924	01043Q	PARTICIPANT	\N	PRESENT	0
425794	423924	19441R	PARTICIPANT	\N	PRESENT	0
425795	423924	19413M	PARTICIPANT	\N	PRESENT	0
425796	423924	14081Q	PARTICIPANT	\N	PRESENT	0
425797	423924	80013X	PARTICIPANT	\N	PRESENT	0
425798	423924	19631V	PARTICIPANT	\N	PRESENT	0
425799	423924	11099A	PARTICIPANT	\N	PRESENT	0
425800	423924	08068F	PARTICIPANT	\N	PRESENT	0
425801	423924	08015R	PARTICIPANT	\N	PRESENT	0
425802	423924	14197C	PARTICIPANT	\N	PRESENT	0
425803	423924	19369B	PARTICIPANT	\N	PRESENT	0
425804	423924	19511N	PARTICIPANT	\N	PRESENT	0
425805	423924	08028W	PARTICIPANT	\N	PRESENT	0
425806	423924	14265W	PARTICIPANT	\N	PRESENT	0
425807	423924	14135M	PARTICIPANT	\N	PRESENT	0
425808	423924	19467C	PARTICIPANT	\N	PRESENT	0
425809	423924	14187A	PARTICIPANT	\N	PRESENT	0
425810	423924	08038Y	PARTICIPANT	\N	PRESENT	0
425811	423924	08062Y	PARTICIPANT	\N	PRESENT	0
425812	423924	14033T	PARTICIPANT	\N	PRESENT	0
425813	423924	11090Q	PRESIDENT	0	PRESENT	0
425814	423924	19269X	PARTICIPANT	\N	PRESENT	0
425815	423924	14205J	PARTICIPANT	\N	PRESENT	0
425816	423924	11056N	PARTICIPANT	\N	PRESENT	0
425817	423924	14119M	PARTICIPANT	\N	PRESENT	0
425818	423924	14115H	PARTICIPANT	\N	PRESENT	0
425819	423924	19507S	PARTICIPANT	\N	PRESENT	0
425820	423924	19747H	PARTICIPANT	\N	PRESENT	0
425821	423924	14257W	PARTICIPANT	\N	PRESENT	0
425993	416306	14034U	PARTICIPANT	\N	PRESENT	0
425823	423924	19812Y	PARTICIPANT	\N	EXCUSE	0
425824	423924	11081P	PARTICIPANT	\N	EXCUSE	0
425825	423924	17589D	PARTICIPANT	\N	EXCUSE	0
425826	425424	19749K	PARTICIPANT	\N	PRESENT	0
425864	423891	11067R	PARTICIPANT	\N	PRESENT	0
425865	423891	19565D	PARTICIPANT	\N	PRESENT	0
425866	423891	19798U	PARTICIPANT	\N	PRESENT	0
425867	423891	11097X	PARTICIPANT	\N	PRESENT	0
425868	423891	19415P	PARTICIPANT	\N	PRESENT	0
425869	423891	14223L	PARTICIPANT	\N	PRESENT	0
425870	423891	14227Q	PARTICIPANT	\N	PRESENT	0
425871	423891	17779H	PARTICIPANT	\N	PRESENT	0
425872	423891	11031D	PARTICIPANT	\N	PRESENT	0
425873	423891	14239U	PARTICIPANT	\N	PRESENT	0
425874	423891	19703U	PARTICIPANT	\N	PRESENT	0
425875	423891	19553Y	PARTICIPANT	\N	PRESENT	0
425876	423891	14281W	PARTICIPANT	\N	PRESENT	0
425877	423891	14087W	PARTICIPANT	\N	PRESENT	0
425878	423891	19679N	PARTICIPANT	\N	PRESENT	0
425879	423891	14042U	PARTICIPANT	\N	PRESENT	0
425880	423891	14195A	PARTICIPANT	\N	PRESENT	0
425881	423891	19575F	PARTICIPANT	\N	PRESENT	0
425882	423891	14213J	PARTICIPANT	\N	PRESENT	0
425883	423891	14261S	PARTICIPANT	\N	PRESENT	0
425884	423891	14217N	PARTICIPANT	\N	PRESENT	0
425885	423891	10006L	PARTICIPANT	\N	PRESENT	0
425886	423891	19683J	PARTICIPANT	\N	PRESENT	0
425887	423891	19521Q	PARTICIPANT	\N	PRESENT	0
425888	423891	98024R	PARTICIPANT	\N	PRESENT	0
425889	423891	01034P	PARTICIPANT	\N	PRESENT	0
425890	423891	04092N	PARTICIPANT	\N	PRESENT	0
425891	423891	08052W	PARTICIPANT	\N	PRESENT	0
425892	423891	19715Y	PARTICIPANT	\N	PRESENT	0
425893	423891	19691J	PARTICIPANT	\N	PRESENT	0
425894	423891	14119M	PARTICIPANT	\N	PRESENT	0
425895	423891	14071N	PARTICIPANT	\N	PRESENT	0
425896	423891	19657G	PARTICIPANT	\N	PRESENT	0
425897	423891	19577H	PARTICIPANT	\N	PRESENT	0
425898	423891	19760E	PARTICIPANT	\N	PRESENT	0
425899	423891	19727D	PARTICIPANT	\N	EXCUSE	0
425900	423891	08041T	PARTICIPANT	\N	EXCUSE	0
425994	416306	04092N	PARTICIPANT	\N	PRESENT	0
425995	416306	01034P	PARTICIPANT	\N	PRESENT	0
425996	416306	11067R	PARTICIPANT	\N	PRESENT	0
425997	416306	19413M	PARTICIPANT	\N	PRESENT	0
425998	416306	19531S	PARTICIPANT	\N	PRESENT	0
425999	416306	17779H	PARTICIPANT	\N	PRESENT	0
426000	416306	11031D	PARTICIPANT	\N	PRESENT	0
426001	416306	19715Y	PARTICIPANT	\N	PRESENT	0
426002	416306	14281W	PARTICIPANT	\N	PRESENT	0
426003	416306	19503N	PARTICIPANT	\N	PRESENT	0
426004	416306	19631V	PARTICIPANT	\N	PRESENT	0
426005	416306	14109K	PARTICIPANT	\N	PRESENT	0
426006	416306	14097Y	PARTICIPANT	\N	PRESENT	0
426007	416306	08052W	PARTICIPANT	\N	PRESENT	0
426008	416306	19782L	PARTICIPANT	\N	PRESENT	0
426009	416306	19301E	PARTICIPANT	\N	PRESENT	0
426010	416306	04045F	PARTICIPANT	\N	PRESENT	0
426011	416306	14239U	PARTICIPANT	\N	PRESENT	0
426012	416306	19697Q	PARTICIPANT	\N	PRESENT	0
426013	416306	19719D	PARTICIPANT	\N	PRESENT	0
426014	416306	19553Y	PARTICIPANT	\N	PRESENT	0
426015	416306	14261S	PARTICIPANT	\N	PRESENT	0
426016	416306	14042U	PARTICIPANT	\N	PRESENT	0
426017	416306	19569H	PARTICIPANT	\N	PRESENT	0
426018	416306	19691J	PARTICIPANT	\N	PRESENT	0
426019	416306	19760E	PARTICIPANT	\N	PRESENT	0
426020	416306	19565D	PARTICIPANT	\N	PRESENT	0
426021	416306	19549D	PARTICIPANT	\N	PRESENT	0
426022	416306	19521Q	PARTICIPANT	\N	PRESENT	0
426023	416306	04018C	PARTICIPANT	\N	PRESENT	0
426024	416306	14331P	PARTICIPANT	\N	PRESENT	0
426025	416306	19798U	PARTICIPANT	\N	PRESENT	0
426026	416306	11097X	PARTICIPANT	\N	PRESENT	0
426027	416306	14071N	PARTICIPANT	\N	PRESENT	0
426028	416306	04033B	PARTICIPANT	\N	PRESENT	0
426029	416306	95030B	PARTICIPANT	\N	PRESENT	0
426030	416306	19507S	PARTICIPANT	\N	PRESENT	0
426031	416306	14087W	PARTICIPANT	\N	PRESENT	0
426032	416306	19415P	PARTICIPANT	\N	PRESENT	0
426033	416306	14119M	PARTICIPANT	\N	PRESENT	0
426034	416306	14026U	PARTICIPANT	\N	PRESENT	0
426035	416306	14265W	PARTICIPANT	\N	PRESENT	0
426036	416306	14213J	PARTICIPANT	\N	PRESENT	0
426037	416306	14147R	PARTICIPANT	\N	PRESENT	0
426038	416306	14105F	PARTICIPANT	\N	PRESENT	0
426039	416306	08047A	PARTICIPANT	\N	PRESENT	0
426040	416306	19575F	PARTICIPANT	\N	PRESENT	0
426041	416306	14033T	PARTICIPANT	\N	PRESENT	0
426042	416306	19723Y	PARTICIPANT	\N	PRESENT	0
426043	416306	19703U	PARTICIPANT	\N	PRESENT	0
426044	416306	14038Y	PARTICIPANT	\N	PRESENT	0
426045	416306	19679N	PARTICIPANT	\N	PRESENT	0
426046	416306	18083K	PARTICIPANT	\N	PRESENT	0
426047	416306	11048N	PARTICIPANT	\N	PRESENT	0
426048	416306	14223L	PARTICIPANT	\N	PRESENT	0
426049	416306	11090Q	PARTICIPANT	\N	PRESENT	0
426050	416306	14357A	PARTICIPANT	\N	PRESENT	0
426051	416306	14217N	PARTICIPANT	\N	PRESENT	0
426052	416306	19533U	PARTICIPANT	\N	PRESENT	0
426053	416306	10006L	PARTICIPANT	\N	PRESENT	0
426054	416306	11103C	PARTICIPANT	\N	PRESENT	0
426055	416306	08015R	PARTICIPANT	\N	PRESENT	0
426056	416306	19737F	PARTICIPANT	\N	PRESENT	0
426057	416306	04040A	PARTICIPANT	\N	PRESENT	0
426058	416306	14107H	PARTICIPANT	\N	PRESENT	0
426059	416306	19727D	PARTICIPANT	\N	PRESENT	0
426060	416306	98024R	PARTICIPANT	\N	PRESENT	0
426061	416306	14089Y	PARTICIPANT	\N	PRESENT	0
426062	416306	14069U	PARTICIPANT	\N	PRESENT	0
426063	416306	19573D	PARTICIPANT	\N	PRESENT	0
426064	416306	14073Q	PARTICIPANT	\N	PRESENT	0
426065	416306	19563B	PARTICIPANT	\N	PRESENT	0
426066	416306	11077T	PARTICIPANT	\N	PRESENT	0
426067	416306	11064N	PARTICIPANT	\N	PRESENT	0
426068	416306	19551W	PARTICIPANT	\N	PRESENT	0
427860	422992	14030Q	PRESIDENT	0	PRESENT	0
427861	422992	08043V	PARTICIPANT	\N	PRESENT	0
427862	422992	19367Y	PARTICIPANT	\N	EXCUSE	0
427863	422992	08024S	PARTICIPANT	\N	PRESENT	0
427864	422992	18083K	PARTICIPANT	\N	PRESENT	0
427865	422992	14249W	PARTICIPANT	\N	EXCUSE	0
427866	422992	08031R	PARTICIPANT	\N	PRESENT	0
427867	422992	07029T	PARTICIPANT	\N	EXCUSE	0
450783	441731	19749K	PARTICIPANT	\N	PRESENT	0
450786	443898	19701S	PARTICIPANT	\N	PRESENT	0
450787	443898	14157T	PARTICIPANT	\N	PRESENT	0
450788	443898	08009T	PARTICIPANT	\N	PRESENT	0
450789	443898	14073Q	PARTICIPANT	\N	PRESENT	0
450790	443898	04085P	PARTICIPANT	\N	PRESENT	0
450791	443898	19637C	PARTICIPANT	\N	PRESENT	0
450792	443898	19333N	PARTICIPANT	\N	PRESENT	0
450793	443898	19549D	PARTICIPANT	\N	PRESENT	0
450794	443898	14237S	PARTICIPANT	\N	PRESENT	0
450795	443898	14031R	PARTICIPANT	\N	PRESENT	0
450796	443898	14205J	PARTICIPANT	\N	PRESENT	0
450797	443898	19747H	PARTICIPANT	\N	PRESENT	0
450798	443898	19387D	PARTICIPANT	\N	PRESENT	0
450799	443898	19447X	PARTICIPANT	\N	PRESENT	0
450800	443898	04057K	PARTICIPANT	\N	PRESENT	0
450801	443898	14069U	PARTICIPANT	\N	PRESENT	0
450805	443898	19794Q	PARTICIPANT	\N	PRESENT	0
450809	443898	11012A	PARTICIPANT	\N	PRESENT	0
450810	443898	19253P	PARTICIPANT	\N	PRESENT	0
450812	443898	14021P	PARTICIPANT	\N	PRESENT	0
450813	445946	08062Y	PARTICIPANT	\N	EXCUSE	0
450820	445946	11066Q	PARTICIPANT	\N	EXCUSE	0
450823	445946	14107H	PARTICIPANT	\N	EXCUSE	0
450824	445946	19369B	PARTICIPANT	\N	EXCUSE	0
450831	450830	19515S	PARTICIPANT	\N	PRESENT	0
450833	450832	19515S	PARTICIPANT	\N	PRESENT	0
450835	450834	19515S	PARTICIPANT	\N	PRESENT	0
450836	450834	19812Y	PARTICIPANT	\N	PRESENT	0
450840	450839	10006L	PARTICIPANT	\N	PRESENT	0
450841	450839	08031R	PARTICIPANT	\N	PRESENT	0
450842	450839	19745F	PARTICIPANT	\N	PRESENT	0
450844	450843	10006L	PARTICIPANT	\N	PRESENT	0
450845	450843	08031R	PARTICIPANT	\N	PRESENT	0
450846	450843	19745F	PARTICIPANT	\N	PRESENT	0
450848	450847	10006L	PARTICIPANT	\N	PRESENT	0
450849	450847	98005N	PARTICIPANT	\N	PRESENT	0
450850	450847	14059S	PARTICIPANT	\N	PRESENT	0
450851	450847	01058X	PARTICIPANT	\N	PRESENT	0
450852	450847	19319Q	PARTICIPANT	\N	PRESENT	0
450853	450847	04043D	PARTICIPANT	\N	PRESENT	0
450878	449791	14249W	PARTICIPANT	\N	PRESENT	0
450888	450887	80013X	PARTICIPANT	\N	PRESENT	0
450892	450890	80013X	PARTICIPANT	\N	PRESENT	0
450894	450893	80013X	PARTICIPANT	\N	PRESENT	0
450901	450900	19575F	PARTICIPANT	\N	PRESENT	0
450902	450900	08052W	PARTICIPANT	\N	PRESENT	0
450903	450900	10006L	PARTICIPANT	\N	PRESENT	0
450904	450900	14119M	PARTICIPANT	\N	PRESENT	0
450905	450900	11097X	PARTICIPANT	\N	PRESENT	0
450906	450899	19575F	PARTICIPANT	\N	PRESENT	0
450907	450899	08052W	PARTICIPANT	\N	PRESENT	0
450908	450899	11097X	PARTICIPANT	\N	PRESENT	0
450971	441812	11010L	PARTICIPANT	\N	EXCUSE	0
450972	441812	14225N	PARTICIPANT	\N	EXCUSE	0
450973	441812	14219Q	PARTICIPANT	\N	EXCUSE	0
450974	441812	14135M	PARTICIPANT	\N	EXCUSE	0
450975	441812	19729F	PARTICIPANT	\N	EXCUSE	0
450976	441812	14259Y	PARTICIPANT	\N	EXCUSE	0
450977	441812	14038Y	PARTICIPANT	\N	EXCUSE	0
451905	441812	11109J	PARTICIPANT	\N	PRESENT	0
451906	441812	14261S	PARTICIPANT	\N	PRESENT	0
450781	441731	11067R	PARTICIPANT	\N	EXCUSE	0
450782	441731	14235Q	PARTICIPANT	\N	EXCUSE	0
451907	441812	19715Y	PARTICIPANT	\N	PRESENT	0
451908	441812	14039A	PARTICIPANT	\N	PRESENT	0
451909	441812	14059S	PARTICIPANT	\N	PRESENT	0
451910	441812	08019V	PRESIDENT	0	PRESENT	0
451911	441812	12016W	PARTICIPANT	\N	PRESENT	0
451912	441812	08073C	PARTICIPANT	\N	PRESENT	0
451913	441812	19319Q	PARTICIPANT	\N	PRESENT	0
451914	441812	04043D	PARTICIPANT	\N	EXCUSE	0
451915	441812	11054L	PARTICIPANT	\N	PRESENT	0
451916	441812	19301E	PARTICIPANT	\N	PRESENT	0
451968	450717	98005N	PARTICIPANT	\N	PRESENT	0
451969	450717	14105F	PARTICIPANT	\N	PRESENT	0
451970	450717	11115U	PARTICIPANT	\N	PRESENT	0
451971	450717	19443T	PARTICIPANT	\N	PRESENT	0
451972	450717	98018T	PARTICIPANT	\N	PRESENT	0
451973	450717	14193X	PARTICIPANT	\N	PRESENT	0
451974	450717	14079W	PARTICIPANT	\N	PRESENT	0
451975	450717	16685X	PARTICIPANT	\N	PRESENT	0
451976	450717	04042C	PRESIDENT	0	PRESENT	0
451977	450717	11066Q	PARTICIPANT	\N	PRESENT	0
451978	450717	19721W	PARTICIPANT	\N	PRESENT	0
451979	450717	12041X	PARTICIPANT	\N	PRESENT	0
451980	450717	14235Q	PARTICIPANT	\N	PRESENT	0
451981	450717	19421M	PARTICIPANT	\N	PRESENT	0
451982	450717	11080N	PARTICIPANT	\N	PRESENT	0
451983	450717	04034C	PARTICIPANT	\N	PRESENT	0
451984	450717	01058X	PARTICIPANT	\N	PRESENT	0
451985	450717	04040A	PARTICIPANT	\N	PRESENT	0
451986	450717	11027H	PARTICIPANT	\N	PRESENT	0
451987	450717	08056B	PARTICIPANT	\N	PRESENT	0
451988	450717	97011G	PARTICIPANT	\N	PRESENT	0
451989	450717	08047A	PARTICIPANT	\N	PRESENT	0
451990	450717	98029W	PARTICIPANT	\N	PRESENT	0
451991	450717	14097Y	PARTICIPANT	\N	PRESENT	0
451992	450717	14133K	PARTICIPANT	\N	PRESENT	0
451993	450717	11041F	PARTICIPANT	\N	PRESENT	0
451994	450717	19319Q	PARTICIPANT	\N	PRESENT	0
451995	450717	98050T	PARTICIPANT	\N	PRESENT	0
451996	450717	19583F	PARTICIPANT	\N	PRESENT	0
451997	450717	14211G	PARTICIPANT	\N	PRESENT	0
451998	450717	14255U	PARTICIPANT	\N	PRESENT	0
451999	450717	19251M	PARTICIPANT	\N	PRESENT	0
452000	450717	14028W	PARTICIPANT	\N	PRESENT	0
452001	450717	19669L	PARTICIPANT	\N	PRESENT	0
452002	450717	14055N	PARTICIPANT	\N	PRESENT	0
452003	450717	08053X	PARTICIPANT	\N	PRESENT	0
452004	450717	01062T	PARTICIPANT	\N	PRESENT	0
452005	450717	98022P	PARTICIPANT	\N	PRESENT	0
452007	450609	11040E	PARTICIPANT	\N	PRESENT	0
452008	450609	14327T	PARTICIPANT	\N	PRESENT	0
452009	450609	14331P	PARTICIPANT	\N	PRESENT	0
452010	450609	07004J	PARTICIPANT	\N	PRESENT	0
452011	450609	08069G	PARTICIPANT	\N	PRESENT	0
452012	450609	96004D	PARTICIPANT	\N	PRESENT	0
452013	450609	19349W	PARTICIPANT	\N	PRESENT	0
452014	450709	14001X	PARTICIPANT	\N	PRESENT	0
452015	450709	19543W	PARTICIPANT	\N	PRESENT	0
452016	450709	04044E	PARTICIPANT	\N	PRESENT	0
452017	450709	19581D	PARTICIPANT	\N	PRESENT	0
452018	450709	19585H	PARTICIPANT	\N	PRESENT	0
452019	450709	04047H	PARTICIPANT	\N	PRESENT	0
452020	450709	01028R	PARTICIPANT	\N	PRESENT	0
452021	450709	14231L	PARTICIPANT	\N	PRESENT	0
452022	450709	05008E	PRESIDENT	0	PRESENT	0
452023	450709	19447X	PARTICIPANT	\N	PRESENT	0
452024	450709	19489J	PARTICIPANT	\N	PRESENT	0
452025	450709	14041T	PARTICIPANT	\N	PRESENT	0
452026	450709	14147R	PARTICIPANT	\N	PRESENT	0
452027	450709	14151M	PARTICIPANT	\N	PRESENT	0
452028	450709	14215L	PARTICIPANT	\N	PRESENT	0
452029	450709	08018U	PARTICIPANT	\N	PRESENT	0
452030	450709	11072N	PARTICIPANT	\N	PRESENT	0
452031	450709	98035U	PARTICIPANT	\N	PRESENT	0
452032	450709	14111D	PARTICIPANT	\N	PRESENT	0
452033	450709	11010L	PARTICIPANT	\N	PRESENT	0
452034	450709	11026G	PARTICIPANT	\N	PRESENT	0
452035	450709	08045X	PARTICIPANT	\N	PRESENT	0
452036	450709	19253P	PARTICIPANT	\N	PRESENT	0
452037	450709	01024M	PARTICIPANT	\N	PRESENT	0
452038	450709	04038G	PARTICIPANT	\N	PRESENT	0
452039	450709	11033F	PARTICIPANT	\N	PRESENT	0
452040	450709	19725B	PARTICIPANT	\N	PRESENT	0
452041	450709	95063L	PARTICIPANT	\N	PRESENT	0
452042	450709	19629C	PARTICIPANT	\N	PRESENT	0
452043	450709	14069U	PARTICIPANT	\N	PRESENT	0
452044	450709	11085T	PARTICIPANT	\N	PRESENT	0
452045	450709	19762G	PARTICIPANT	\N	PRESENT	0
452046	450709	14053L	PARTICIPANT	\N	PRESENT	0
452061	450717	95030B	PARTICIPANT	\N	PRESENT	0
452062	450717	95037J	PARTICIPANT	\N	PRESENT	0
452063	450717	08049C	PARTICIPANT	\N	PRESENT	0
452064	450608	19593H	PARTICIPANT	\N	PRESENT	0
452065	450608	04070G	PRESIDENT	0	PRESENT	0
452066	450608	14059S	PARTICIPANT	\N	PRESENT	0
452067	450608	19699S	PARTICIPANT	\N	PRESENT	0
452068	450608	04057K	PARTICIPANT	\N	PRESENT	0
452069	450608	08043V	PARTICIPANT	\N	PRESENT	0
452070	450608	87003B	PARTICIPANT	\N	PRESENT	0
452071	450608	14229S	PARTICIPANT	\N	PRESENT	0
452072	450608	14030Q	PARTICIPANT	\N	PRESENT	0
426420	423926	19269X	PARTICIPANT	\N	PRESENT	0
426569	425346	11033F	PARTICIPANT	\N	EXCUSE	0
426580	416307	86034E	PARTICIPANT	\N	PRESENT	0
426581	416307	19511N	PARTICIPANT	\N	PRESENT	0
426582	416307	19367Y	PARTICIPANT	\N	PRESENT	0
426583	416307	19583F	PARTICIPANT	\N	PRESENT	0
426584	416307	19681G	PARTICIPANT	\N	PRESENT	0
426585	416307	98022P	PARTICIPANT	\N	PRESENT	0
426586	416307	14073Q	PARTICIPANT	\N	PRESENT	0
426603	416307	11027H	PARTICIPANT	\N	PRESENT	0
426588	416307	14219Q	PARTICIPANT	\N	PRESENT	0
426589	416307	19731Y	PARTICIPANT	\N	PRESENT	0
426590	416307	88008L	PARTICIPANT	\N	PRESENT	0
426591	416307	14081Q	PARTICIPANT	\N	PRESENT	0
426592	416307	19443T	PARTICIPANT	\N	PRESENT	0
426593	416307	14231L	PARTICIPANT	\N	PRESENT	0
426594	416307	11101A	PARTICIPANT	\N	PRESENT	0
426595	416307	14041T	PARTICIPANT	\N	PRESENT	0
426596	416307	14191V	PARTICIPANT	\N	PRESENT	0
426597	416307	14115H	PARTICIPANT	\N	PRESENT	0
426598	416307	19525U	PARTICIPANT	\N	PRESENT	0
426599	416307	19399H	PARTICIPANT	\N	PRESENT	0
426600	416307	19421M	PARTICIPANT	\N	PRESENT	0
426605	416307	19591F	PARTICIPANT	\N	PRESENT	0
426602	416307	19565D	PARTICIPANT	\N	PRESENT	0
426604	416307	08045X	PARTICIPANT	\N	PRESENT	0
426606	416307	04018C	PARTICIPANT	\N	PRESENT	0
426607	416307	14259Y	PARTICIPANT	\N	PRESENT	0
426608	416307	19593H	PARTICIPANT	\N	PRESENT	0
426609	416307	14123H	PARTICIPANT	\N	PRESENT	0
426610	416307	11067R	PARTICIPANT	\N	PRESENT	0
426611	416307	96004D	PARTICIPANT	\N	PRESENT	0
426612	416307	19703U	PARTICIPANT	\N	PRESENT	0
426613	416307	14267Y	PARTICIPANT	\N	PRESENT	0
426614	416307	19794Q	PARTICIPANT	\N	PRESENT	0
426615	416307	19669L	PARTICIPANT	\N	PRESENT	0
426616	416307	19766L	PARTICIPANT	\N	PRESENT	0
426617	416307	11103C	PARTICIPANT	\N	PRESENT	0
426618	416307	99004R	PARTICIPANT	\N	PRESENT	0
426619	416307	04092N	PARTICIPANT	\N	PRESENT	0
426620	416307	04069P	PARTICIPANT	\N	PRESENT	0
426621	416307	11080N	PARTICIPANT	\N	PRESENT	0
426622	416307	11056N	PARTICIPANT	\N	PRESENT	0
426623	416307	11115U	PARTICIPANT	\N	PRESENT	0
426624	416307	08012N	PARTICIPANT	\N	PRESENT	0
426625	416307	87003B	PARTICIPANT	\N	PRESENT	0
426626	416307	14239U	PARTICIPANT	\N	PRESENT	0
426627	416307	19741B	PARTICIPANT	\N	PRESENT	0
426628	416307	14211G	PARTICIPANT	\N	PRESENT	0
426629	416307	05012A	PARTICIPANT	\N	PRESENT	0
426630	416307	19413M	PARTICIPANT	\N	PRESENT	0
426631	416307	19673G	PARTICIPANT	\N	PRESENT	0
426632	416307	19683J	PARTICIPANT	\N	PRESENT	0
426633	416307	92040Q	PARTICIPANT	\N	PRESENT	0
426634	416307	14085U	PARTICIPANT	\N	PRESENT	0
426635	416307	14059S	PARTICIPANT	\N	PRESENT	0
426636	416307	14257W	PARTICIPANT	\N	PRESENT	0
426637	416307	19611R	PARTICIPANT	\N	PRESENT	0
426638	416307	19467C	PARTICIPANT	\N	PRESENT	0
426639	416307	19619A	PARTICIPANT	\N	PRESENT	0
426640	416307	07004J	PARTICIPANT	\N	PRESENT	0
426641	416307	08039A	PARTICIPANT	\N	PRESENT	0
426643	416307	19527W	PARTICIPANT	\N	PRESENT	0
426644	416307	11045K	PARTICIPANT	\N	PRESENT	0
426645	416307	08047A	PARTICIPANT	\N	PRESENT	0
426646	416307	98024R	PARTICIPANT	\N	PRESENT	0
426648	416307	19549D	PARTICIPANT	\N	PRESENT	0
426650	416307	19782L	PARTICIPANT	\N	PRESENT	0
426651	416307	19349W	PARTICIPANT	\N	PRESENT	0
426652	416307	19667J	PARTICIPANT	\N	PRESENT	0
426653	416307	12041X	PARTICIPANT	\N	PRESENT	0
426654	416307	08069G	PARTICIPANT	\N	PRESENT	0
426655	416307	19820Y	PARTICIPANT	\N	PRESENT	0
426656	416307	14253S	PARTICIPANT	\N	PRESENT	0
426657	416307	04059M	PARTICIPANT	\N	PRESENT	0
426658	416307	19747H	PARTICIPANT	\N	PRESENT	0
426659	416307	98029W	PARTICIPANT	\N	PRESENT	0
426660	416307	19515S	PARTICIPANT	\N	PRESENT	0
426661	416307	14241N	PARTICIPANT	\N	PRESENT	0
426662	416307	01062T	PARTICIPANT	\N	PRESENT	0
426663	416307	14135M	PARTICIPANT	\N	PRESENT	0
426664	416307	19737F	PARTICIPANT	\N	PRESENT	0
426665	416307	17589D	PARTICIPANT	\N	PRESENT	0
426666	416307	19507S	PARTICIPANT	\N	PRESENT	0
426667	416307	19369B	PARTICIPANT	\N	PRESENT	0
426668	416307	14111D	PARTICIPANT	\N	PRESENT	0
426669	416307	14207L	PARTICIPANT	\N	PRESENT	0
426670	416307	19675J	PARTICIPANT	\N	PRESENT	0
426671	416307	19269X	PARTICIPANT	\N	PRESENT	0
426672	416307	19723Y	PARTICIPANT	\N	PRESENT	0
426673	416307	19629C	PARTICIPANT	\N	PRESENT	0
426674	416307	19253P	PARTICIPANT	\N	PRESENT	0
426675	416307	11048N	PARTICIPANT	\N	PRESENT	0
426676	416307	80013X	PARTICIPANT	\N	PRESENT	0
426677	416307	97011G	PARTICIPANT	\N	PRESENT	0
426678	416307	11066Q	PARTICIPANT	\N	PRESENT	0
426679	416307	14227Q	PARTICIPANT	\N	PRESENT	0
426680	416307	14213J	PARTICIPANT	\N	PRESENT	0
426681	416307	11104D	PARTICIPANT	\N	PRESENT	0
426682	416307	14265W	PARTICIPANT	\N	PRESENT	0
426683	416307	14097Y	PARTICIPANT	\N	PRESENT	0
426684	416307	19725B	PARTICIPANT	\N	PRESENT	0
426685	416307	14215L	PARTICIPANT	\N	PRESENT	0
426686	416307	08034U	PARTICIPANT	\N	PRESENT	0
426687	416307	14157T	PARTICIPANT	\N	PRESENT	0
426688	416307	04086Q	PARTICIPANT	\N	PRESENT	0
426689	416307	19251M	PARTICIPANT	\N	PRESENT	0
426690	416307	14151M	PARTICIPANT	\N	PRESENT	0
426691	416307	08028W	PARTICIPANT	\N	PRESENT	0
426692	416307	08068F	PARTICIPANT	\N	PRESENT	0
426693	416307	19441R	PARTICIPANT	\N	PRESENT	0
426694	416307	04047H	PARTICIPANT	\N	PRESENT	0
426695	416307	08015R	PARTICIPANT	\N	PRESENT	0
426696	416307	04034C	PARTICIPANT	\N	PRESENT	0
426697	416307	19329S	PARTICIPANT	\N	PRESENT	0
426698	416307	19503N	PARTICIPANT	\N	PRESENT	0
426699	416307	08058D	PARTICIPANT	\N	PRESENT	0
426700	416307	98050T	PARTICIPANT	\N	PRESENT	0
426701	416307	19671E	PARTICIPANT	\N	PRESENT	0
426702	416307	19651A	PARTICIPANT	\N	PRESENT	0
426703	416307	14107H	PARTICIPANT	\N	PRESENT	0
426704	416307	04049K	PARTICIPANT	\N	PRESENT	0
426705	416307	10015M	PARTICIPANT	\N	PRESENT	0
426706	416307	19693L	PARTICIPANT	\N	PRESENT	0
426707	416307	14079W	PARTICIPANT	\N	PRESENT	0
426708	416307	14133K	PARTICIPANT	\N	PRESENT	0
426709	416307	07029T	PARTICIPANT	\N	PRESENT	0
426710	416307	19711U	PARTICIPANT	\N	PRESENT	0
426711	416307	04008A	PARTICIPANT	\N	PRESENT	0
426712	416307	19760E	PARTICIPANT	\N	PRESENT	0
426713	416307	19695N	PARTICIPANT	\N	PRESENT	0
426714	416307	04097T	PARTICIPANT	\N	PRESENT	0
426715	416307	19687N	PARTICIPANT	\N	PRESENT	0
426716	416307	04038G	PARTICIPANT	\N	PRESENT	0
426717	416307	11077T	PARTICIPANT	\N	PRESENT	0
426718	416307	19679N	PARTICIPANT	\N	PRESENT	0
426719	416307	08061X	PARTICIPANT	\N	PRESENT	0
426720	416307	04045F	PARTICIPANT	\N	PRESENT	0
426721	416307	08020N	PARTICIPANT	\N	PRESENT	0
426722	416307	19637C	PARTICIPANT	\N	PRESENT	0
426723	416307	01058X	PARTICIPANT	\N	PRESENT	0
426724	416307	95063L	PARTICIPANT	\N	PRESENT	0
426725	416307	08010L	PARTICIPANT	\N	PRESENT	0
426726	416307	14039A	PARTICIPANT	\N	PRESENT	0
426727	416307	11072N	PARTICIPANT	\N	PRESENT	0
426728	416307	15447F	PARTICIPANT	\N	PRESENT	0
426729	416307	19301E	PARTICIPANT	\N	PRESENT	0
426730	416307	19643A	PARTICIPANT	\N	PRESENT	0
426731	416307	08056B	PARTICIPANT	\N	PRESENT	0
426732	416307	19685L	PARTICIPANT	\N	PRESENT	0
426733	416307	01060R	PARTICIPANT	\N	PRESENT	0
426734	416307	19758L	PARTICIPANT	\N	PRESENT	0
426735	416307	11043H	PARTICIPANT	\N	PRESENT	0
426736	416307	11033F	PARTICIPANT	\N	PRESENT	0
426737	416307	19543W	PARTICIPANT	\N	PRESENT	0
426738	416307	11012A	PARTICIPANT	\N	PRESENT	0
426739	416307	11083R	PARTICIPANT	\N	PRESENT	0
426740	416307	14034U	PARTICIPANT	\N	PRESENT	0
426741	416307	08031R	PARTICIPANT	\N	PRESENT	0
426742	416307	14261S	PARTICIPANT	\N	PRESENT	0
426743	416307	14223L	PARTICIPANT	\N	PRESENT	0
426744	416307	08049C	PARTICIPANT	\N	PRESENT	0
426745	416307	14201E	PARTICIPANT	\N	PRESENT	0
426746	416307	14031R	PARTICIPANT	\N	PRESENT	0
426747	416307	19387D	PARTICIPANT	\N	PRESENT	0
426748	416307	19657G	PARTICIPANT	\N	PRESENT	0
426749	416307	11099A	PARTICIPANT	\N	PRESENT	0
426750	416307	19585H	PARTICIPANT	\N	PRESENT	0
451170	450967	19703U	PARTICIPANT	\N	PRESENT	0
451171	450967	19673G	PARTICIPANT	\N	PRESENT	0
451172	450967	11010L	PARTICIPANT	\N	PRESENT	0
451173	450967	14031R	PARTICIPANT	\N	PRESENT	0
451174	450967	11115U	PARTICIPANT	\N	PRESENT	0
451175	450967	14199E	PARTICIPANT	\N	PRESENT	0
451176	450967	19575F	PARTICIPANT	\N	PRESENT	0
451177	450967	11048N	PARTICIPANT	\N	PRESENT	0
451178	450967	92040Q	PARTICIPANT	\N	PRESENT	0
451179	450967	14089Y	PARTICIPANT	\N	PRESENT	0
451180	450967	08034U	PARTICIPANT	\N	PRESENT	0
451181	450967	19533U	PARTICIPANT	\N	PRESENT	0
451182	450967	10006L	PARTICIPANT	\N	PRESENT	0
451183	450967	19798U	PARTICIPANT	\N	PRESENT	0
451184	450967	04049K	PARTICIPANT	\N	PRESENT	0
451185	450967	14193X	PARTICIPANT	\N	PRESENT	0
451186	450967	14237S	PARTICIPANT	\N	PRESENT	0
451187	450967	14147R	PARTICIPANT	\N	PRESENT	0
451188	450967	11097X	PARTICIPANT	\N	PRESENT	0
451189	450967	14331P	PARTICIPANT	\N	PRESENT	0
451190	450967	98050T	PARTICIPANT	\N	PRESENT	0
451191	450967	19543W	PARTICIPANT	\N	PRESENT	0
451192	450967	19269X	PARTICIPANT	\N	PRESENT	0
451193	450967	19349W	PARTICIPANT	\N	PRESENT	0
451194	450967	08062Y	PARTICIPANT	\N	PRESENT	0
451195	450967	19741B	PARTICIPANT	\N	PRESENT	0
451196	450967	19289C	PARTICIPANT	\N	PRESENT	0
451197	450967	14215L	PARTICIPANT	\N	PRESENT	0
451198	450967	04059M	PARTICIPANT	\N	PRESENT	0
451199	450967	14087W	PARTICIPANT	\N	PRESENT	0
451200	450967	14249W	PARTICIPANT	\N	PRESENT	0
451201	450967	11027H	PARTICIPANT	\N	PRESENT	0
451202	450967	98035U	PARTICIPANT	\N	PRESENT	0
451203	450967	04043D	PARTICIPANT	\N	PRESENT	0
451204	450967	11090Q	PARTICIPANT	\N	PRESENT	0
451205	450967	11074Q	PARTICIPANT	\N	PRESENT	0
451206	450967	08055A	PARTICIPANT	\N	PRESENT	0
451207	450967	14259Y	PARTICIPANT	\N	PRESENT	0
451208	450967	14229S	PARTICIPANT	\N	PRESENT	0
451209	450967	01057W	PARTICIPANT	\N	PRESENT	0
451210	450967	87003B	PARTICIPANT	\N	PRESENT	0
451211	450967	08052W	PARTICIPANT	\N	PRESENT	0
451212	450967	19766L	PARTICIPANT	\N	PRESENT	0
451213	450967	19689Q	PARTICIPANT	\N	PRESENT	0
451214	450967	11080N	PARTICIPANT	\N	PRESENT	0
451215	450967	14191V	PARTICIPANT	\N	PRESENT	0
451216	450967	01028R	PARTICIPANT	\N	PRESENT	0
451217	450967	19515S	PARTICIPANT	\N	PRESENT	0
451218	450967	08068F	PARTICIPANT	\N	PRESENT	0
451219	450967	14051J	PARTICIPANT	\N	PRESENT	0
451220	450967	15447F	PARTICIPANT	\N	PRESENT	0
451221	450967	19643A	PARTICIPANT	\N	PRESENT	0
451222	450967	10015M	PARTICIPANT	\N	PRESENT	0
451223	450967	01048V	PARTICIPANT	\N	PRESENT	0
451224	450967	14021P	PARTICIPANT	\N	PRESENT	0
451225	450967	08028W	PARTICIPANT	\N	PRESENT	0
451226	450967	08045X	PARTICIPANT	\N	PRESENT	0
451227	450967	14169X	PARTICIPANT	\N	PRESENT	0
451228	450967	19669L	PARTICIPANT	\N	PRESENT	0
451229	450967	19599P	PARTICIPANT	\N	PRESENT	0
451230	450967	04033B	PARTICIPANT	\N	PRESENT	0
451231	450967	12016W	PARTICIPANT	\N	PRESENT	0
451232	450967	14187A	PARTICIPANT	\N	PRESENT	0
451233	450967	19715Y	PARTICIPANT	\N	PRESENT	0
451234	450967	14071N	PARTICIPANT	\N	PRESENT	0
451235	450967	05008E	PARTICIPANT	\N	PRESENT	0
451236	450967	14151M	PARTICIPANT	\N	PRESENT	0
451237	450967	01062T	PARTICIPANT	\N	PRESENT	0
451238	450967	80013X	PARTICIPANT	\N	PRESENT	0
451239	450967	11045K	PARTICIPANT	\N	PRESENT	0
451240	450967	14028W	PARTICIPANT	\N	PRESENT	0
451241	450967	14026U	PARTICIPANT	\N	PRESENT	0
451242	450967	19649G	PARTICIPANT	\N	PRESENT	0
451243	450967	19647E	PARTICIPANT	\N	PRESENT	0
451244	450967	11066Q	PARTICIPANT	\N	PRESENT	0
451245	450967	08043V	PARTICIPANT	\N	PRESENT	0
451246	450967	95041E	PARTICIPANT	\N	PRESENT	0
451247	450967	08035V	PARTICIPANT	\N	PRESENT	0
451248	450967	04044E	PARTICIPANT	\N	PRESENT	0
451249	450967	11104D	PARTICIPANT	\N	PRESENT	0
451250	450967	04086Q	PARTICIPANT	\N	PRESENT	0
451251	450967	08012N	PARTICIPANT	\N	PRESENT	0
451252	450967	19820Y	PARTICIPANT	\N	PRESENT	0
451253	450967	04042C	PARTICIPANT	\N	PRESENT	0
451254	450967	19727D	PARTICIPANT	\N	PRESENT	0
451255	450967	99004R	PARTICIPANT	\N	PRESENT	0
451256	450967	19531S	PARTICIPANT	\N	PRESENT	0
451257	450967	14123H	PARTICIPANT	\N	PRESENT	0
451258	450967	14081Q	PARTICIPANT	\N	PRESENT	0
451259	450967	14257W	PARTICIPANT	\N	PRESENT	0
451260	450967	08010L	PARTICIPANT	\N	PRESENT	0
451261	450967	19525U	PARTICIPANT	\N	PRESENT	0
451262	450967	08020N	PARTICIPANT	\N	PRESENT	0
451263	450967	08053X	PARTICIPANT	\N	PRESENT	0
451264	450967	04097T	PARTICIPANT	\N	PRESENT	0
451265	450967	89017R	PARTICIPANT	\N	PRESENT	0
451266	450967	14055N	PARTICIPANT	\N	PRESENT	0
451267	450967	19679N	PARTICIPANT	\N	PRESENT	0
451298	450967	14063N	PARTICIPANT	\N	PRESENT	0
451269	450967	14065Q	PARTICIPANT	\N	PRESENT	0
451270	450967	19549D	PARTICIPANT	\N	PRESENT	0
451271	450967	08011M	PARTICIPANT	\N	PRESENT	0
451272	450967	08017T	PARTICIPANT	\N	PRESENT	0
451273	450967	19637C	PARTICIPANT	\N	PRESENT	0
451274	450967	01058X	PARTICIPANT	\N	PRESENT	0
451275	450967	17637T	PARTICIPANT	\N	PRESENT	0
451276	450967	14085U	PARTICIPANT	\N	PRESENT	0
451277	450967	14281W	PARTICIPANT	\N	PRESENT	0
451278	450967	17779H	PARTICIPANT	\N	PRESENT	0
451279	450967	95030B	PARTICIPANT	\N	PRESENT	0
451280	450967	19489J	PARTICIPANT	\N	PRESENT	0
451281	450967	19725B	PARTICIPANT	\N	PRESENT	0
451282	450967	04035D	PARTICIPANT	\N	PRESENT	0
451283	450967	08014Q	PARTICIPANT	\N	PRESENT	0
451284	450967	02002K	PARTICIPANT	\N	PRESENT	0
451285	450967	98024R	PARTICIPANT	\N	PRESENT	0
451286	450967	11101A	PARTICIPANT	\N	PRESENT	0
451287	450967	14107H	PARTICIPANT	\N	PRESENT	0
451288	450967	14001X	PARTICIPANT	\N	PRESENT	0
451289	450967	19333N	PARTICIPANT	\N	PRESENT	0
451290	450967	11109J	PARTICIPANT	\N	PRESENT	0
451291	450967	19295A	PARTICIPANT	\N	PRESENT	0
451292	450967	11054L	PARTICIPANT	\N	PRESENT	0
451293	450967	19719D	PARTICIPANT	\N	PRESENT	0
451294	450967	19733B	PARTICIPANT	\N	PRESENT	0
451295	450967	14109K	PARTICIPANT	\N	PRESENT	0
451296	450967	19705W	PARTICIPANT	\N	PRESENT	0
451297	450967	14197C	PARTICIPANT	\N	PRESENT	0
451303	450967	11026G	PARTICIPANT	\N	PRESENT	0
451301	450967	19551W	PARTICIPANT	\N	PRESENT	0
451302	450967	19503N	PARTICIPANT	\N	PRESENT	0
451304	450967	14105F	PARTICIPANT	\N	PRESENT	0
451305	450967	19251M	PARTICIPANT	\N	PRESENT	0
451306	450967	19413M	PARTICIPANT	\N	PRESENT	0
451307	450967	14265W	PARTICIPANT	\N	PRESENT	0
451308	450967	19631V	PARTICIPANT	\N	PRESENT	0
451309	450967	19687N	PARTICIPANT	\N	PRESENT	0
451310	450967	98029W	PARTICIPANT	\N	PRESENT	0
451311	450967	04092N	PARTICIPANT	\N	PRESENT	0
451312	450967	08024S	PARTICIPANT	\N	PRESENT	0
451313	450967	19447X	PARTICIPANT	\N	PRESENT	0
451314	450967	14097Y	PARTICIPANT	\N	PRESENT	0
451315	450967	11067R	PARTICIPANT	\N	PRESENT	0
451316	450967	14213J	PARTICIPANT	\N	PRESENT	0
451317	450967	14227Q	PARTICIPANT	\N	PRESENT	0
451318	450967	19651A	PARTICIPANT	\N	PRESENT	0
451319	450967	01034P	PARTICIPANT	\N	PRESENT	0
451320	450967	19479G	PARTICIPANT	\N	PRESENT	0
451321	450967	19713W	PARTICIPANT	\N	PRESENT	0
451322	450967	14219Q	PARTICIPANT	\N	PRESENT	0
451324	450967	11070L	PARTICIPANT	\N	PRESENT	0
451325	450967	08044W	PARTICIPANT	\N	PRESENT	0
451326	450967	14073Q	PARTICIPANT	\N	PRESENT	0
451327	450967	07004J	PARTICIPANT	\N	PRESENT	0
451328	450967	14255U	PARTICIPANT	\N	PRESENT	0
451329	450967	19441R	PARTICIPANT	\N	PRESENT	0
451330	450967	19745F	PARTICIPANT	\N	PRESENT	0
451331	450967	08060W	PARTICIPANT	\N	PRESENT	0
451335	450967	05012A	PARTICIPANT	\N	PRESENT	0
451333	450967	19747H	PARTICIPANT	\N	PRESENT	0
451334	450967	11099A	PARTICIPANT	\N	PRESENT	0
451336	450967	14159V	PARTICIPANT	\N	PRESENT	0
451337	450967	11053K	PARTICIPANT	\N	PRESENT	0
451338	450967	14034U	PARTICIPANT	\N	PRESENT	0
451339	450967	08038Y	PARTICIPANT	\N	PRESENT	0
451340	450967	01024M	PARTICIPANT	\N	PRESENT	0
451341	450967	19683J	PARTICIPANT	\N	PRESENT	0
451342	450967	19569H	PARTICIPANT	\N	PRESENT	0
427870	422992	14235Q	PARTICIPANT	\N	PRESENT	0
427871	422992	19269X	PARTICIPANT	\N	PRESENT	0
427872	422992	19749K	PARTICIPANT	\N	PRESENT	0
427969	425126	14299H	PARTICIPANT	\N	PRESENT	0
427868	422992	08017T	PARTICIPANT	\N	PRESENT	0
427869	422992	14109K	PARTICIPANT	\N	PRESENT	0
427974	425126	80013X	PARTICIPANT	\N	PRESENT	0
427975	425126	19723Y	PARTICIPANT	\N	PRESENT	0
427976	425126	01048V	PRESIDENT	0	PRESENT	0
427977	425126	19503N	PARTICIPANT	\N	PRESENT	0
427978	425126	01058X	PARTICIPANT	\N	PRESENT	0
427979	425126	08053X	PARTICIPANT	\N	EXCUSE	0
427981	425126	19693L	PARTICIPANT	\N	EXCUSE	0
427982	425126	19511N	PARTICIPANT	\N	EXCUSE	0
427983	425126	14093U	PARTICIPANT	\N	EXCUSE	0
428228	428227	14187A	PARTICIPANT	\N	PRESENT	0
430650	425056	14261S	PARTICIPANT	\N	PRESENT	0
430651	425056	14030Q	PRESIDENT	0	PRESENT	0
430652	425056	08043V	PARTICIPANT	\N	PRESENT	0
430653	425056	19621T	PARTICIPANT	\N	PRESENT	0
430654	425056	19693L	PARTICIPANT	\N	PRESENT	0
430655	425056	14217N	PARTICIPANT	\N	PRESENT	0
430656	425056	19599P	PARTICIPANT	\N	PRESENT	0
430657	425056	19715Y	PARTICIPANT	\N	EXCUSE	0
430658	425056	19731Y	PARTICIPANT	\N	PRESENT	0
430659	425056	08031R	PARTICIPANT	\N	PRESENT	0
430660	425056	11067R	PARTICIPANT	\N	PRESENT	0
430661	425056	19749K	PARTICIPANT	\N	PRESENT	0
430663	430662	19369B	PARTICIPANT	\N	PRESENT	0
430665	430664	19369B	PARTICIPANT	\N	PRESENT	0
430763	428529	08052W	PARTICIPANT	\N	PRESENT	0
430765	428529	11072N	PARTICIPANT	\N	PRESENT	0
430800	430799	19741B	PARTICIPANT	\N	PRESENT	0
430802	430801	10006L	PARTICIPANT	\N	PRESENT	0
430803	423928	01048V	PARTICIPANT	\N	PRESENT	0
430804	422993	19691J	PARTICIPANT	\N	PRESENT	0
430805	422993	19715Y	PARTICIPANT	\N	PRESENT	0
430806	422993	08019V	PRESIDENT	0	PRESENT	0
430807	422993	19319Q	PARTICIPANT	\N	PRESENT	0
430808	422993	14021P	PARTICIPANT	\N	PRESENT	0
430809	422993	19301E	PARTICIPANT	\N	EXCUSE	0
431980	431979	19369B	PARTICIPANT	\N	PRESENT	0
431981	431979	14257W	PARTICIPANT	\N	PRESENT	0
431982	431979	19515S	PARTICIPANT	\N	PRESENT	0
431983	431979	19747H	PARTICIPANT	\N	PRESENT	0
431984	431979	19441R	PARTICIPANT	\N	PRESENT	0
431986	431979	14033T	PARTICIPANT	\N	PRESENT	0
432799	430232	14195A	PARTICIPANT	\N	EXCUSE	0
433737	425295	19711U	PARTICIPANT	\N	PRESENT	0
433738	425295	80013X	PARTICIPANT	\N	PRESENT	0
433739	425295	19551W	PARTICIPANT	\N	PRESENT	0
433740	425295	19820Y	PARTICIPANT	\N	PRESENT	0
433741	425295	08043V	PARTICIPANT	\N	PRESENT	0
433742	425295	19333N	PARTICIPANT	\N	PRESENT	0
433743	425295	19593H	PARTICIPANT	\N	PRESENT	0
433744	425295	19347U	PARTICIPANT	\N	PRESENT	0
433745	425295	08020N	PARTICIPANT	\N	PRESENT	0
433746	425295	14069U	PARTICIPANT	\N	PRESENT	0
433747	425295	19749K	PARTICIPANT	\N	PRESENT	0
433748	425295	14331P	PARTICIPANT	\N	PRESENT	0
433749	425295	14039A	PARTICIPANT	\N	PRESENT	0
433750	425295	19826F	PARTICIPANT	\N	PRESENT	0
433751	425295	11065P	PARTICIPANT	\N	PRESENT	0
433752	425295	08062Y	PARTICIPANT	\N	PRESENT	0
433753	425295	14207L	PARTICIPANT	\N	PRESENT	0
433754	425295	14033T	PARTICIPANT	\N	PRESENT	0
433755	425295	19415P	PARTICIPANT	\N	PRESENT	0
433756	425295	19713W	PARTICIPANT	\N	PRESENT	0
433757	425295	19737F	PARTICIPANT	\N	PRESENT	0
433758	425295	19467C	PARTICIPANT	\N	PRESENT	0
433759	425295	19611R	PARTICIPANT	\N	PRESENT	0
433760	425295	19413M	PARTICIPANT	\N	PRESENT	0
433761	425295	19503N	PARTICIPANT	\N	PRESENT	0
433762	425295	19747H	PARTICIPANT	\N	PRESENT	0
433763	425295	19521Q	PARTICIPANT	\N	PRESENT	0
433764	425295	19758L	PARTICIPANT	\N	PRESENT	0
433765	425295	11074Q	PARTICIPANT	\N	PRESENT	0
433766	425295	19387D	PARTICIPANT	\N	PRESENT	0
433767	425295	14253S	PARTICIPANT	\N	PRESENT	0
433768	425295	19533U	PARTICIPANT	\N	PRESENT	0
433769	425295	19531S	PARTICIPANT	\N	PRESENT	0
433770	425295	04070G	PARTICIPANT	\N	PRESENT	0
433771	425295	04057K	PARTICIPANT	\N	PRESENT	0
433772	425295	14187A	PARTICIPANT	\N	PRESENT	0
433773	425295	14219Q	PARTICIPANT	\N	PRESENT	0
433774	425295	19369B	PARTICIPANT	\N	PRESENT	0
433775	425295	19703U	PARTICIPANT	\N	PRESENT	0
433776	425295	11104D	PARTICIPANT	\N	PRESENT	0
433777	425295	04045F	PARTICIPANT	\N	PRESENT	0
433778	425295	19723Y	PARTICIPANT	\N	PRESENT	0
433779	425295	14089Y	PARTICIPANT	\N	PRESENT	0
433780	425295	19479G	PARTICIPANT	\N	PRESENT	0
433781	425295	14105F	PARTICIPANT	\N	PRESENT	0
433782	425295	14357A	PARTICIPANT	\N	PRESENT	0
433783	425295	14147R	PARTICIPANT	\N	PRESENT	0
433784	425295	14123H	PARTICIPANT	\N	PRESENT	0
433785	425295	14179A	PARTICIPANT	\N	PRESENT	0
433786	425295	04049K	PARTICIPANT	\N	PRESENT	0
433787	425295	14241N	PARTICIPANT	\N	PRESENT	0
433788	425295	08031R	PARTICIPANT	\N	PRESENT	0
433789	425295	14249W	PARTICIPANT	\N	PRESENT	0
433790	425295	14030Q	PARTICIPANT	\N	PRESENT	0
433791	425295	08024S	PARTICIPANT	\N	PRESENT	0
433792	425295	14217N	PARTICIPANT	\N	PRESENT	0
433793	425295	04085P	PARTICIPANT	\N	PRESENT	0
433735	425295	04044E	PARTICIPANT	\N	PRESENT	0
433736	425295	11048N	PARTICIPANT	\N	PRESENT	0
433794	425295	14265W	PARTICIPANT	\N	PRESENT	0
433795	425295	14073Q	PARTICIPANT	\N	PRESENT	0
433796	425295	11097X	PARTICIPANT	\N	PRESENT	0
433797	425295	19621T	PARTICIPANT	\N	PRESENT	0
433851	425294	14039A	PARTICIPANT	\N	PRESENT	0
433852	425294	14123H	PARTICIPANT	\N	PRESENT	0
433853	425294	19593H	PARTICIPANT	\N	PRESENT	0
433854	425294	19758L	PARTICIPANT	\N	PRESENT	0
433855	425294	19531S	PARTICIPANT	\N	PRESENT	0
433856	425294	19820Y	PARTICIPANT	\N	PRESENT	0
433857	425294	11104D	PARTICIPANT	\N	PRESENT	0
433858	425294	08043V	PARTICIPANT	\N	PRESENT	0
433859	425294	14229S	PARTICIPANT	\N	PRESENT	0
433860	425294	08031R	PARTICIPANT	\N	PRESENT	0
433861	425294	08024S	PARTICIPANT	\N	PRESENT	0
433862	425294	04057K	PARTICIPANT	\N	PRESENT	0
433863	425294	19713W	PARTICIPANT	\N	PRESENT	0
433864	425294	14030Q	PARTICIPANT	\N	PRESENT	0
433865	425294	08020N	PARTICIPANT	\N	PRESENT	0
433866	425294	19479G	PARTICIPANT	\N	PRESENT	0
433867	425294	14253S	PARTICIPANT	\N	PRESENT	0
433868	425294	14073Q	PARTICIPANT	\N	PRESENT	0
433869	425294	19749K	PARTICIPANT	\N	PRESENT	0
433870	425294	14265W	PARTICIPANT	\N	PRESENT	0
433871	425294	19621T	PARTICIPANT	\N	PRESENT	0
433872	425294	14357A	PARTICIPANT	\N	PRESENT	0
433873	425294	14061L	PARTICIPANT	\N	PRESENT	0
433874	425294	19533U	PARTICIPANT	\N	PRESENT	0
433875	425294	04049K	PARTICIPANT	\N	PRESENT	0
433876	425294	14069U	PARTICIPANT	\N	PRESENT	0
433877	425294	19723Y	PARTICIPANT	\N	PRESENT	0
433878	425294	19611R	PARTICIPANT	\N	PRESENT	0
433879	425294	19551W	PARTICIPANT	\N	PRESENT	0
433880	425294	14249W	PARTICIPANT	\N	PRESENT	0
433881	425294	04070G	PARTICIPANT	\N	PRESENT	0
433882	425294	14213J	PARTICIPANT	\N	PRESENT	0
433883	425294	14241N	PARTICIPANT	\N	PRESENT	0
433884	425294	14034U	PARTICIPANT	\N	PRESENT	0
433945	433943	05008E	PRESIDENT	0	PRESENT	0
434027	428464	08043V	PARTICIPANT	\N	PRESENT	0
433947	433943	14030Q	PARTICIPANT	\N	PRESENT	0
434026	428464	14030Q	PRESIDENT	0	PRESENT	0
433949	433943	08024S	PARTICIPANT	\N	PRESENT	0
434028	428464	80013X	PARTICIPANT	\N	PRESENT	0
433951	433943	14215L	PARTICIPANT	\N	PRESENT	0
434029	428464	19599P	PARTICIPANT	\N	PRESENT	0
433953	433943	19649G	PARTICIPANT	\N	PRESENT	0
433954	433943	14179A	PARTICIPANT	\N	PRESENT	0
434030	428464	08031R	PARTICIPANT	\N	PRESENT	0
433956	433943	14147R	PARTICIPANT	\N	PRESENT	0
433957	433943	11045K	PARTICIPANT	\N	PRESENT	0
433958	433943	01028R	PARTICIPANT	\N	PRESENT	0
434031	428464	08017T	PARTICIPANT	\N	PRESENT	0
434032	428464	11067R	PARTICIPANT	\N	EXCUSE	0
433849	425294	04044E	PARTICIPANT	\N	PRESENT	0
433850	425294	01048V	PARTICIPANT	\N	PRESENT	0
452073	450608	14241N	PARTICIPANT	\N	PRESENT	0
452074	450608	19731Y	PARTICIPANT	\N	PRESENT	0
452075	450608	14063N	PARTICIPANT	\N	PRESENT	0
452076	450608	92040Q	PARTICIPANT	\N	PRESENT	0
452077	450608	08012N	PARTICIPANT	\N	PRESENT	0
452078	450608	11104D	PARTICIPANT	\N	PRESENT	0
452079	450608	19758L	PARTICIPANT	\N	PRESENT	0
452080	450608	04018C	PARTICIPANT	\N	PRESENT	0
452081	450608	14249W	PARTICIPANT	\N	PRESENT	0
452082	450608	19643A	PARTICIPANT	\N	EXCUSE	0
452083	450609	95041E	PARTICIPANT	\N	PRESENT	0
452084	450609	11053K	PARTICIPANT	\N	PRESENT	0
452085	450609	89017R	PARTICIPANT	\N	PRESENT	0
452086	450609	88008L	PARTICIPANT	\N	PRESENT	0
452087	450609	14225N	PARTICIPANT	\N	PRESENT	0
452088	450609	11070L	PARTICIPANT	\N	PRESENT	0
452089	450609	19671E	PARTICIPANT	\N	PRESENT	0
452090	450609	14085U	PARTICIPANT	\N	PRESENT	0
452091	450609	19711U	PARTICIPANT	\N	PRESENT	0
452092	450609	19687N	PARTICIPANT	\N	PRESENT	0
452093	450609	08014Q	PARTICIPANT	\N	PRESENT	0
452095	450609	14173T	PARTICIPANT	\N	PRESENT	0
452096	450609	04086Q	PARTICIPANT	\N	PRESENT	0
452097	450609	14199E	PARTICIPANT	\N	PRESENT	0
452098	450609	11012A	PARTICIPANT	\N	PRESENT	0
452099	450609	08073C	PARTICIPANT	\N	PRESENT	0
452100	450609	19741B	PARTICIPANT	\N	PRESENT	0
452101	450609	14121F	PARTICIPANT	\N	PRESENT	0
452102	450609	99004R	PARTICIPANT	\N	PRESENT	0
452103	450709	14259Y	PARTICIPANT	\N	PRESENT	0
452104	450608	19533U	PARTICIPANT	\N	PRESENT	0
452105	450608	19749K	PARTICIPANT	\N	PRESENT	0
452106	450942	19768N	PARTICIPANT	\N	PRESENT	0
452107	450942	19515S	PARTICIPANT	\N	PRESENT	0
452108	450942	11077T	PARTICIPANT	\N	PRESENT	0
452109	450942	19782L	PARTICIPANT	\N	PRESENT	0
452110	450942	19441R	PARTICIPANT	\N	PRESENT	0
452111	450942	19812Y	PARTICIPANT	\N	PRESENT	0
452112	450942	14081Q	PARTICIPANT	\N	PRESENT	0
452113	450942	19413M	PARTICIPANT	\N	PRESENT	0
452114	450942	80013X	PARTICIPANT	\N	PRESENT	0
452115	450942	19631V	PARTICIPANT	\N	PRESENT	0
452116	450942	08068F	PARTICIPANT	\N	PRESENT	0
452117	450942	04049K	PARTICIPANT	\N	PRESENT	0
452118	450942	19705W	PARTICIPANT	\N	PRESENT	0
452119	450942	08015R	PARTICIPANT	\N	PRESENT	0
452120	450942	08019V	PARTICIPANT	\N	PRESENT	0
452121	450942	14197C	PARTICIPANT	\N	PRESENT	0
452122	450942	19369B	PARTICIPANT	\N	PRESENT	0
452123	450942	19511N	PARTICIPANT	\N	PRESENT	0
452124	450942	08028W	PARTICIPANT	\N	PRESENT	0
452125	450942	19563B	PARTICIPANT	\N	PRESENT	0
452126	450942	14265W	PARTICIPANT	\N	PRESENT	0
452127	450942	14329V	PARTICIPANT	\N	PRESENT	0
452128	450942	19591F	PARTICIPANT	\N	PRESENT	0
452129	450942	19467C	PARTICIPANT	\N	PRESENT	0
452130	450942	14187A	PARTICIPANT	\N	PRESENT	0
452131	450942	08062Y	PARTICIPANT	\N	PRESENT	0
452132	450942	11090Q	PRESIDENT	0	PRESENT	0
452133	450942	14033T	PARTICIPANT	\N	PRESENT	0
452134	450942	19269X	PARTICIPANT	\N	PRESENT	0
452135	450942	04088S	PARTICIPANT	\N	PRESENT	0
452136	450942	04089T	PARTICIPANT	\N	PRESENT	0
452137	450942	11101A	PARTICIPANT	\N	PRESENT	0
452138	450942	19747H	PARTICIPANT	\N	PRESENT	0
452139	450942	14207L	PARTICIPANT	\N	PRESENT	0
452140	450942	19619A	PARTICIPANT	\N	PRESENT	0
452141	450942	14257W	PARTICIPANT	\N	PRESENT	0
452142	450608	14061L	PARTICIPANT	\N	PRESENT	0
452143	450608	14073Q	PARTICIPANT	\N	PRESENT	0
452144	450609	07029T	PARTICIPANT	\N	PRESENT	0
452145	450609	11048N	PARTICIPANT	\N	PRESENT	0
452146	450609	08034U	PARTICIPANT	\N	PRESENT	0
452147	450609	19651A	PARTICIPANT	\N	PRESENT	0
452148	450609	19531S	PARTICIPANT	\N	PRESENT	0
452149	450608	11083R	PARTICIPANT	\N	PRESENT	0
452150	450709	04008A	PARTICIPANT	\N	PRESENT	0
452151	450942	01043Q	PARTICIPANT	\N	PRESENT	0
452152	450942	14357A	PARTICIPANT	\N	PRESENT	0
452153	450942	14205J	PARTICIPANT	\N	PRESENT	0
452154	450942	04043D	PARTICIPANT	\N	PRESENT	0
452155	450609	04071H	PARTICIPANT	\N	PRESENT	0
452156	450609	01057W	PARTICIPANT	\N	PRESENT	0
452157	450609	11074Q	PRESIDENT	0	PRESENT	0
452158	450609	12016W	PARTICIPANT	\N	PRESENT	0
452159	449605	19697Q	PARTICIPANT	\N	PRESENT	0
452160	449605	11067R	PARTICIPANT	\N	PRESENT	0
452161	449605	19565D	PARTICIPANT	\N	PRESENT	0
452162	449605	19798U	PARTICIPANT	\N	PRESENT	0
452163	449605	19569H	PARTICIPANT	\N	PRESENT	0
452164	449605	11097X	PARTICIPANT	\N	PRESENT	0
452165	449605	19415P	PARTICIPANT	\N	PRESENT	0
452166	449605	04045F	PARTICIPANT	\N	PRESENT	0
452167	449605	14227Q	PARTICIPANT	\N	PRESENT	0
452168	449605	19703U	PARTICIPANT	\N	PRESENT	0
452169	449605	14239U	PARTICIPANT	\N	PRESENT	0
452170	449605	11031D	PARTICIPANT	\N	PRESENT	0
452171	449605	19553Y	PARTICIPANT	\N	PRESENT	0
452172	449605	14087W	PARTICIPANT	\N	PRESENT	0
452173	449605	19679N	PARTICIPANT	\N	PRESENT	0
452174	449605	14042U	PARTICIPANT	\N	PRESENT	0
452175	449605	19575F	PARTICIPANT	\N	PRESENT	0
452176	449605	14195A	PARTICIPANT	\N	PRESENT	0
452177	449605	14213J	PARTICIPANT	\N	PRESENT	0
452178	449605	19367Y	PARTICIPANT	\N	PRESENT	0
452179	449605	14261S	PARTICIPANT	\N	PRESENT	0
452180	449605	14217N	PARTICIPANT	\N	PRESENT	0
452181	449605	10006L	PARTICIPANT	\N	PRESENT	0
452182	449605	98024R	PARTICIPANT	\N	PRESENT	0
452183	449605	19521Q	PARTICIPANT	\N	PRESENT	0
452184	449605	04092N	PRESIDENT	0	PRESENT	0
452185	449605	11045K	PARTICIPANT	\N	PRESENT	0
452186	449605	08052W	PARTICIPANT	\N	PRESENT	0
452187	449605	19301E	PARTICIPANT	\N	PRESENT	0
452188	449605	19715Y	PARTICIPANT	\N	PRESENT	0
452189	449605	19691J	PARTICIPANT	\N	PRESENT	0
452190	449605	14119M	PARTICIPANT	\N	PRESENT	0
452191	449605	11103C	PARTICIPANT	\N	PRESENT	0
452192	449605	14071N	PARTICIPANT	\N	PRESENT	0
452193	449605	19657G	PARTICIPANT	\N	PRESENT	0
452194	449605	19760E	PARTICIPANT	\N	PRESENT	0
452195	449605	08041T	PARTICIPANT	\N	EXCUSE	0
452196	450609	08010L	PARTICIPANT	\N	PRESENT	0
452197	450608	19573D	PARTICIPANT	\N	PRESENT	0
452198	450608	08017T	PARTICIPANT	\N	PRESENT	0
452199	450608	08031R	PARTICIPANT	\N	PRESENT	0
452200	450608	19611R	PARTICIPANT	\N	PRESENT	0
452201	450608	19399H	PARTICIPANT	\N	PRESENT	0
452202	450608	11109J	PARTICIPANT	\N	PRESENT	0
452203	450942	11099A	PARTICIPANT	\N	PRESENT	0
452204	450942	08038Y	PARTICIPANT	\N	PRESENT	0
452205	450609	19479G	PARTICIPANT	\N	PRESENT	0
452206	450609	19545Y	PARTICIPANT	\N	EXCUSE	0
452207	450609	08011M	PARTICIPANT	\N	PRESENT	0
452208	450942	14115H	PARTICIPANT	\N	PRESENT	0
452209	450609	19689Q	PARTICIPANT	\N	PRESENT	0
452210	450609	14083S	PARTICIPANT	\N	PRESENT	0
452211	450717	11064N	PARTICIPANT	\N	PRESENT	0
452212	450608	08020N	PARTICIPANT	\N	PRESENT	0
452213	450942	19507S	PARTICIPANT	\N	PRESENT	0
452215	452214	10006L	PARTICIPANT	\N	PRESENT	0
452216	452214	15447F	PARTICIPANT	\N	PRESENT	0
452217	452214	19553Y	PARTICIPANT	\N	PRESENT	0
452218	452214	11048N	PARTICIPANT	\N	PRESENT	0
452219	452214	19711U	PARTICIPANT	\N	PRESENT	0
452220	452214	14059S	PARTICIPANT	\N	PRESENT	0
452221	452214	14063N	PARTICIPANT	\N	PRESENT	0
452222	452214	14265W	PARTICIPANT	\N	PRESENT	0
452223	452214	04088S	PARTICIPANT	\N	PRESENT	0
452224	450609	01048V	PARTICIPANT	\N	PRESENT	0
452225	450608	19693L	PARTICIPANT	\N	PRESENT	0
452226	450709	14179A	PARTICIPANT	\N	PRESENT	0
452227	450709	19729F	PARTICIPANT	\N	PRESENT	0
452228	450709	08044W	PARTICIPANT	\N	PRESENT	0
452229	450709	14021P	PARTICIPANT	\N	PRESENT	0
452230	450942	14135M	PARTICIPANT	\N	PRESENT	0
452231	450942	11056N	PARTICIPANT	\N	PRESENT	0
452232	450942	11081P	PARTICIPANT	\N	EXCUSE	0
452233	450723	98005N	PARTICIPANT	\N	PRESENT	0
452234	450723	19443T	PARTICIPANT	\N	PRESENT	0
452235	450723	12041X	PARTICIPANT	\N	PRESENT	0
452236	450723	11080N	PARTICIPANT	\N	PRESENT	0
452237	450723	95030B	PARTICIPANT	\N	PRESENT	0
452238	450723	04034C	PARTICIPANT	\N	PRESENT	0
452239	450723	14079W	PARTICIPANT	\N	PRESENT	0
452240	450723	01058X	PARTICIPANT	\N	PRESENT	0
452241	450723	04040A	PARTICIPANT	\N	PRESENT	0
452242	450723	16685X	PARTICIPANT	\N	PRESENT	0
426751	416307	14199E	PARTICIPANT	\N	PRESENT	0
426752	416307	19545Y	PARTICIPANT	\N	PRESENT	0
426753	416307	19575F	PARTICIPANT	\N	PRESENT	0
426754	416307	14251Q	PARTICIPANT	\N	PRESENT	0
426755	416307	19347U	PARTICIPANT	\N	PRESENT	0
426756	416307	14093U	PARTICIPANT	\N	PRESENT	0
426757	416307	19717B	PARTICIPANT	\N	PRESENT	0
426758	416307	14173T	PARTICIPANT	\N	PRESENT	0
426759	416307	19447X	PARTICIPANT	\N	PRESENT	0
426760	416307	14055N	PARTICIPANT	\N	PRESENT	0
426761	416307	04071H	PARTICIPANT	\N	PRESENT	0
426762	416307	19573D	PARTICIPANT	\N	PRESENT	0
426763	416307	14119M	PARTICIPANT	\N	PRESENT	0
426764	416307	11049P	PARTICIPANT	\N	PRESENT	0
426765	416307	14105F	PARTICIPANT	\N	PRESENT	0
426766	416307	11074Q	PARTICIPANT	\N	PRESENT	0
426767	416307	04042C	PARTICIPANT	\N	PRESENT	0
426768	416307	14159V	PARTICIPANT	\N	PRESENT	0
426769	416307	08055A	PARTICIPANT	\N	PRESENT	0
426770	416307	17583W	PARTICIPANT	\N	PRESENT	0
426771	416307	14229S	PARTICIPANT	\N	PRESENT	0
426772	416307	01028R	PARTICIPANT	\N	PRESENT	0
426773	416307	17637T	PARTICIPANT	\N	PRESENT	0
426774	416307	14147R	PARTICIPANT	\N	PRESENT	0
426775	416307	08052W	PARTICIPANT	\N	PRESENT	0
426776	416307	19689Q	PARTICIPANT	\N	PRESENT	0
426777	416307	14021P	PARTICIPANT	\N	PRESENT	0
426778	416307	18083K	PARTICIPANT	\N	PRESENT	0
426779	416307	14195A	PARTICIPANT	\N	PRESENT	0
426780	416307	19415P	PARTICIPANT	\N	PRESENT	0
426781	416307	95037J	PARTICIPANT	\N	PRESENT	0
426782	416307	08019V	PARTICIPANT	\N	PRESENT	0
426783	416307	19599P	PARTICIPANT	\N	PRESENT	0
426784	416307	19715Y	PARTICIPANT	\N	PRESENT	0
426785	416307	14033T	PARTICIPANT	\N	PRESENT	0
426786	416307	08060W	PARTICIPANT	\N	PRESENT	0
426787	416307	08038Y	PARTICIPANT	\N	PRESENT	0
426788	416307	19697Q	PARTICIPANT	\N	PRESENT	0
426789	416307	14028W	PARTICIPANT	\N	PRESENT	0
426790	416307	14197C	PARTICIPANT	\N	PRESENT	0
426791	416307	19727D	PARTICIPANT	\N	PRESENT	0
426792	416307	08062Y	PARTICIPANT	\N	PRESENT	0
426793	416307	11110B	PARTICIPANT	\N	PRESENT	0
426794	416307	08053X	PARTICIPANT	\N	PRESENT	0
426795	416307	19768N	PARTICIPANT	\N	PRESENT	0
426796	416307	08017T	PARTICIPANT	\N	PRESENT	0
426797	416307	08011M	PARTICIPANT	\N	PRESENT	0
426798	416307	19705W	PARTICIPANT	\N	PRESENT	0
426799	416307	14065Q	PARTICIPANT	\N	PRESENT	0
426800	416307	17779H	PARTICIPANT	\N	PRESENT	0
426801	416307	14061L	PARTICIPANT	\N	PRESENT	0
426802	416307	14329V	PARTICIPANT	\N	PRESENT	0
426803	416307	19333N	PARTICIPANT	\N	PRESENT	0
426804	416307	14357A	PARTICIPANT	\N	PRESENT	0
426805	416307	19383Y	PARTICIPANT	\N	PRESENT	0
426806	416307	14001X	PARTICIPANT	\N	PRESENT	0
426807	416307	19553Y	PARTICIPANT	\N	PRESENT	0
426808	416307	19762G	PARTICIPANT	\N	PRESENT	0
426809	416307	19701S	PARTICIPANT	\N	PRESENT	0
426810	416307	14109K	PARTICIPANT	\N	PRESENT	0
426811	416307	19621T	PARTICIPANT	\N	PRESENT	0
426812	416307	19631V	PARTICIPANT	\N	PRESENT	0
426813	416307	14281W	PARTICIPANT	\N	PRESENT	0
426814	416307	19531S	PARTICIPANT	\N	PRESENT	0
426815	416307	07033P	PARTICIPANT	\N	PRESENT	0
426816	416307	14217N	PARTICIPANT	\N	PRESENT	0
426817	416307	14331P	PARTICIPANT	\N	PRESENT	0
426818	416307	04089T	PARTICIPANT	\N	PRESENT	0
426819	416307	08044W	PARTICIPANT	\N	PRESENT	0
426820	416307	19691J	PARTICIPANT	\N	PRESENT	0
426821	416307	14205J	PARTICIPANT	\N	PRESENT	0
426822	416307	10006L	PARTICIPANT	\N	PRESENT	0
426823	416307	11053K	PARTICIPANT	\N	PRESENT	0
426824	416307	19798U	PARTICIPANT	\N	PRESENT	0
426825	416307	19721W	PARTICIPANT	\N	PRESENT	0
426826	416307	14237S	PARTICIPANT	\N	PRESENT	0
426827	416307	19699S	PARTICIPANT	\N	PRESENT	0
426828	416307	19569H	PARTICIPANT	\N	PRESENT	0
426829	416307	14026U	PARTICIPANT	\N	PRESENT	0
426830	416307	19739H	PARTICIPANT	\N	PRESENT	0
426831	416307	19663E	PARTICIPANT	\N	PRESENT	0
426832	416307	19735D	PARTICIPANT	\N	PRESENT	0
426833	416307	16685X	PARTICIPANT	\N	PRESENT	0
426834	416307	19551W	PARTICIPANT	\N	PRESENT	0
426835	416307	04043D	PARTICIPANT	\N	PRESENT	0
426836	416307	14069U	PARTICIPANT	\N	PRESENT	0
426837	416307	14042U	PARTICIPANT	\N	PRESENT	0
426838	416307	19479G	PARTICIPANT	\N	PRESENT	0
426839	416307	14053L	PARTICIPANT	\N	PRESENT	0
426840	416307	19319Q	PARTICIPANT	\N	PRESENT	0
426841	416307	14249W	PARTICIPANT	\N	PRESENT	0
426842	416307	04057K	PARTICIPANT	\N	PRESENT	0
426843	416307	14103D	PARTICIPANT	\N	PRESENT	0
426844	416307	14087W	PARTICIPANT	\N	PRESENT	0
426845	416307	14221J	PARTICIPANT	\N	PRESENT	0
426846	416307	19335Q	PARTICIPANT	\N	PRESENT	0
426847	416307	05008E	PARTICIPANT	\N	PRESENT	0
426848	416307	19745F	PARTICIPANT	\N	PRESENT	0
426849	416307	04033B	PARTICIPANT	\N	PRESENT	0
426850	416307	19749K	PARTICIPANT	\N	PRESENT	0
426851	416307	19826F	PARTICIPANT	\N	PRESENT	0
426852	416307	14187A	PARTICIPANT	\N	PRESENT	0
426853	416307	19521Q	PARTICIPANT	\N	PRESENT	0
426854	416307	11097X	PARTICIPANT	\N	PRESENT	0
426855	416307	14255U	PARTICIPANT	\N	PRESENT	0
426856	416307	19577H	PARTICIPANT	\N	PRESENT	0
426857	416307	11085T	PARTICIPANT	\N	PRESENT	0
426858	416307	04040A	PARTICIPANT	\N	PRESENT	0
426859	416307	01024M	PARTICIPANT	\N	PRESENT	0
426860	416307	04044E	PARTICIPANT	\N	PRESENT	0
426861	416307	14030Q	PARTICIPANT	\N	PRESENT	0
426862	416307	14327T	PARTICIPANT	\N	PRESENT	0
426863	416307	14121F	PARTICIPANT	\N	PRESENT	0
426864	416307	95030B	PARTICIPANT	\N	PRESENT	0
426865	416307	08024S	PARTICIPANT	\N	PRESENT	0
426866	416307	04035D	PARTICIPANT	\N	PRESENT	0
426867	416307	01043Q	PARTICIPANT	\N	PRESENT	0
426868	416307	11090Q	PARTICIPANT	\N	PRESENT	0
426869	416307	19719D	PARTICIPANT	\N	PRESENT	0
426870	416307	01057W	PARTICIPANT	\N	PRESENT	0
426871	416307	01034P	PARTICIPANT	\N	PRESENT	0
426872	416307	19733B	PARTICIPANT	\N	PRESENT	0
426873	416307	04085P	PARTICIPANT	\N	PRESENT	0
426874	416307	12016W	PARTICIPANT	\N	PRESENT	0
426875	416307	11054L	PARTICIPANT	\N	PRESENT	0
426876	416307	14225N	PARTICIPANT	\N	PRESENT	0
426877	416307	19295A	PARTICIPANT	\N	PRESENT	0
426878	416307	02002K	PARTICIPANT	\N	PRESENT	0
426879	416307	14235Q	PARTICIPANT	\N	PRESENT	0
426880	416307	08043V	PARTICIPANT	\N	PRESENT	0
426881	416307	08073C	PARTICIPANT	\N	PRESENT	0
426882	416307	14089Y	PARTICIPANT	\N	PRESENT	0
426883	416307	11031D	PARTICIPANT	\N	PRESENT	0
426903	416307	19649G	PARTICIPANT	\N	PRESENT	0
426904	416307	19647E	PARTICIPANT	\N	PRESENT	0
426905	416307	95067Q	PARTICIPANT	\N	PRESENT	0
426906	416307	11026G	PARTICIPANT	\N	PRESENT	0
426907	416307	89017R	PARTICIPANT	\N	PRESENT	0
426908	416307	19729F	PARTICIPANT	\N	PRESENT	0
426909	416307	08014Q	PARTICIPANT	\N	PRESENT	0
426913	416307	14275Y	PARTICIPANT	\N	PRESENT	0
451343	450967	11110B	PARTICIPANT	\N	PRESENT	0
451344	450967	19347U	PARTICIPANT	\N	PRESENT	0
451345	450967	08069G	PARTICIPANT	\N	PRESENT	0
451346	450967	95067Q	PARTICIPANT	\N	PRESENT	0
451347	450967	04071H	PARTICIPANT	\N	PRESENT	0
451350	450967	14053L	PARTICIPANT	\N	PRESENT	0
451355	450967	14069U	PARTICIPANT	\N	PRESENT	0
451351	450967	19527W	PARTICIPANT	\N	PRESENT	0
451353	450967	14357A	PARTICIPANT	\N	PRESENT	0
451358	450967	14205J	PARTICIPANT	\N	PRESENT	0
451357	451356	04044E	PARTICIPANT	\N	EXCUSE	0
451359	450967	14225N	PARTICIPANT	\N	PRESENT	0
451688	448735	04044E	PARTICIPANT	\N	PRESENT	0
451689	448735	14026U	PARTICIPANT	\N	PRESENT	0
451690	451356	08056B	PARTICIPANT	\N	PRESENT	0
451691	451356	07004J	PARTICIPANT	0	PRESENT	0
451692	451356	08010L	PARTICIPANT	\N	PRESENT	0
451693	451356	19673G	PARTICIPANT	\N	PRESENT	0
451694	451356	19719D	PRESIDENT	0	PRESENT	0
451695	448735	04033B	PARTICIPANT	\N	PRESENT	0
451697	450811	14038Y	PARTICIPANT	\N	PRESENT	0
451698	450811	19711U	PARTICIPANT	\N	PRESENT	0
451699	450811	19531S	PARTICIPANT	\N	PRESENT	0
451700	450811	19543W	PARTICIPANT	\N	PRESENT	0
451701	450811	80013X	PARTICIPANT	\N	PRESENT	0
451702	450811	11070L	PARTICIPANT	\N	PRESENT	0
451703	450811	87003B	PARTICIPANT	\N	PRESENT	0
451704	450811	02002K	PARTICIPANT	\N	PRESENT	0
451705	450811	15447F	PRESIDENT	0	PRESENT	0
451706	450811	11040E	PARTICIPANT	\N	PRESENT	0
451707	450811	14205J	PARTICIPANT	\N	PRESENT	0
451708	450811	19551W	PARTICIPANT	\N	PRESENT	0
451709	450811	19737F	PARTICIPANT	\N	PRESENT	0
451710	450811	19741B	PARTICIPANT	\N	PRESENT	0
451711	450811	14069U	PARTICIPANT	\N	PRESENT	0
451712	450811	19525U	PARTICIPANT	\N	PRESENT	0
451713	448735	19695N	PARTICIPANT	\N	PRESENT	0
451714	448735	19760E	PARTICIPANT	\N	PRESENT	0
451715	451696	19631V	PARTICIPANT	\N	PRESENT	0
451716	448735	19758L	PARTICIPANT	\N	PRESENT	0
451717	451696	14197C	PARTICIPANT	\N	PRESENT	0
451718	451356	19721W	PARTICIPANT	\N	PRESENT	0
451719	451696	19441R	PARTICIPANT	\N	PRESENT	0
451720	448735	19565D	PARTICIPANT	\N	PRESENT	0
451721	451696	14265W	PARTICIPANT	\N	PRESENT	0
451722	448735	19347U	PARTICIPANT	\N	PRESENT	0
451723	451696	19347U	PARTICIPANT	\N	PRESENT	0
451724	451696	14109K	PARTICIPANT	\N	PRESENT	0
451725	451696	14237S	PARTICIPANT	\N	PRESENT	0
451726	448735	17779H	PARTICIPANT	\N	PRESENT	0
451727	448735	19820Y	PARTICIPANT	\N	PRESENT	0
451728	448735	14197C	PARTICIPANT	\N	PRESENT	0
451729	448735	01028R	PARTICIPANT	\N	PRESENT	0
451730	448735	14225N	PARTICIPANT	\N	PRESENT	0
451731	448735	11072N	PARTICIPANT	\N	PRESENT	0
451732	448735	19631V	PARTICIPANT	\N	PRESENT	0
451733	448735	14063N	PARTICIPANT	\N	PRESENT	0
451734	448735	08068F	PARTICIPANT	\N	PRESENT	0
451735	448735	19583F	PARTICIPANT	\N	PRESENT	0
451736	448735	98005N	PARTICIPANT	\N	PRESENT	0
451737	448735	19479G	PARTICIPANT	\N	PRESENT	0
451738	448735	19739H	PARTICIPANT	\N	PRESENT	0
451739	448735	19611R	PARTICIPANT	\N	PRESENT	0
451740	448735	14083S	PARTICIPANT	\N	PRESENT	0
451741	448735	14089Y	PARTICIPANT	\N	PRESENT	0
451742	448735	14215L	PARTICIPANT	\N	PRESENT	0
451743	448735	19671E	PARTICIPANT	\N	PRESENT	0
451744	448735	14079W	PARTICIPANT	\N	PRESENT	0
451745	448735	14237S	PARTICIPANT	\N	PRESENT	0
451746	448735	19629C	PARTICIPANT	\N	PRESENT	0
451747	448735	19387D	PARTICIPANT	\N	PRESENT	0
451748	448735	19681G	PARTICIPANT	\N	PRESENT	0
451749	448735	04043D	PARTICIPANT	\N	PRESENT	0
451750	448735	14187A	PARTICIPANT	\N	PRESENT	0
451751	448735	11103C	PARTICIPANT	\N	PRESENT	0
451752	448735	19731Y	PARTICIPANT	\N	PRESENT	0
451753	448735	14147R	PARTICIPANT	\N	PRESENT	0
451754	448735	14213J	PARTICIPANT	\N	PRESENT	0
451755	448735	19768N	PARTICIPANT	\N	PRESENT	0
451756	448735	08062Y	PARTICIPANT	\N	PRESENT	0
451757	448735	19657G	PARTICIPANT	\N	PRESENT	0
451758	448735	19679N	PARTICIPANT	\N	PRESENT	0
451759	448735	07029T	PARTICIPANT	\N	PRESENT	0
451760	448735	19447X	PARTICIPANT	\N	PRESENT	0
451761	448735	19399H	PARTICIPANT	\N	PRESENT	0
451762	448735	19383Y	PARTICIPANT	\N	PRESENT	0
451763	448735	11049P	PARTICIPANT	\N	PRESENT	0
451764	448735	18083K	PARTICIPANT	\N	PRESENT	0
451765	448735	14123H	PARTICIPANT	\N	PRESENT	0
451766	448735	19507S	PARTICIPANT	\N	PRESENT	0
451767	448735	19415P	PARTICIPANT	\N	PRESENT	0
451768	448735	99004R	PARTICIPANT	\N	PRESENT	0
451769	448735	14033T	PARTICIPANT	\N	PRESENT	0
451770	448735	95030B	PARTICIPANT	\N	PRESENT	0
451771	448735	11048N	PARTICIPANT	\N	PRESENT	0
451772	448735	19575F	PARTICIPANT	\N	PRESENT	0
451773	448735	04088S	PARTICIPANT	\N	PRESENT	0
451774	448735	19467C	PARTICIPANT	\N	PRESENT	0
451775	448735	11056N	PARTICIPANT	\N	PRESENT	0
451776	448735	04085P	PARTICIPANT	\N	PRESENT	0
451777	448735	14031R	PARTICIPANT	\N	PRESENT	0
451778	448735	14071N	PARTICIPANT	\N	PRESENT	0
451779	448735	19747H	PARTICIPANT	\N	PRESENT	0
451780	448735	11012A	PARTICIPANT	\N	PRESENT	0
451781	448735	11045K	PARTICIPANT	\N	PRESENT	0
451782	451356	08053X	PARTICIPANT	\N	PRESENT	0
451783	448735	14034U	PARTICIPANT	\N	PRESENT	0
451784	448735	04092N	PARTICIPANT	\N	PRESENT	0
451785	448735	19729F	PARTICIPANT	\N	PRESENT	0
451786	448735	19533U	PARTICIPANT	\N	PRESENT	0
451787	448735	19798U	PARTICIPANT	\N	PRESENT	0
451788	448735	89017R	PARTICIPANT	\N	PRESENT	0
451789	448735	19563B	PARTICIPANT	\N	PRESENT	0
451790	448735	11064N	PARTICIPANT	\N	PRESENT	0
451791	448735	19333N	PARTICIPANT	\N	PRESENT	0
451792	448735	19489J	PARTICIPANT	\N	PRESENT	0
451793	448735	08028W	PARTICIPANT	\N	PRESENT	0
451794	448735	14157T	PARTICIPANT	\N	PRESENT	0
451795	448735	19621T	PARTICIPANT	\N	PRESENT	0
451796	448735	19737F	PARTICIPANT	\N	PRESENT	0
451797	448735	01058X	PARTICIPANT	\N	PRESENT	0
451798	448735	14059S	PARTICIPANT	\N	PRESENT	0
451799	448735	19573D	PARTICIPANT	\N	PRESENT	0
451800	448735	14105F	PARTICIPANT	\N	PRESENT	0
451801	448735	19289C	PARTICIPANT	\N	PRESENT	0
451802	448735	19443T	PARTICIPANT	\N	PRESENT	0
451803	451356	10015M	PARTICIPANT	\N	PRESENT	0
451804	448735	19581D	PARTICIPANT	\N	PRESENT	0
451805	448735	14265W	PARTICIPANT	\N	PRESENT	0
451806	448735	14173T	PARTICIPANT	\N	PRESENT	0
451807	448735	19553Y	PARTICIPANT	\N	PRESENT	0
451809	448735	14249W	PARTICIPANT	\N	PRESENT	0
451810	448735	14041T	PARTICIPANT	\N	PRESENT	0
451811	448735	11031D	PARTICIPANT	\N	PRESENT	0
451812	448735	14231L	PARTICIPANT	\N	PRESENT	0
451813	450811	14121F	PRESIDENT	1	PRESENT	0
451814	448735	87003B	PARTICIPANT	\N	PRESENT	0
451815	448735	15447F	PARTICIPANT	\N	PRESENT	0
451816	448735	19551W	PARTICIPANT	\N	PRESENT	0
451818	448735	19685L	PARTICIPANT	\N	PRESENT	0
451819	448735	01060R	PARTICIPANT	\N	PRESENT	0
451820	448735	19691J	PARTICIPANT	\N	PRESENT	0
451821	448735	14069U	PARTICIPANT	\N	PRESENT	0
451822	448735	14103D	PARTICIPANT	\N	PRESENT	0
451823	448735	19335Q	PARTICIPANT	\N	PRESENT	0
451824	448735	08020N	PARTICIPANT	\N	PRESENT	0
451825	448735	19703U	PARTICIPANT	\N	PRESENT	0
451826	448735	19593H	PARTICIPANT	\N	PRESENT	0
451827	448735	08044W	PARTICIPANT	\N	PRESENT	0
451828	450978	04070G	PARTICIPANT	\N	PRESENT	0
451829	450978	14051J	PARTICIPANT	\N	PRESENT	0
451830	450978	08060W	PARTICIPANT	\N	PRESENT	0
451831	450978	95067Q	PARTICIPANT	\N	PRESENT	0
451832	450978	08009T	PRESIDENT	0	PRESENT	0
451833	450978	19413M	PARTICIPANT	\N	PRESENT	0
451834	450978	19367Y	PARTICIPANT	\N	PRESENT	0
451835	450978	14079W	PARTICIPANT	\N	PRESENT	0
451836	450978	19758L	PARTICIPANT	\N	PRESENT	0
451839	450978	11048N	PARTICIPANT	\N	PRESENT	0
451840	450978	14033T	PARTICIPANT	\N	PRESENT	0
451843	448735	10006L	PARTICIPANT	\N	PRESENT	0
451844	448735	14219Q	PARTICIPANT	\N	PRESENT	0
451845	448735	19699S	PARTICIPANT	\N	PRESENT	0
451846	450978	19581D	PARTICIPANT	\N	PRESENT	0
451847	450978	11065P	PARTICIPANT	\N	PRESENT	0
451848	448735	19599P	PARTICIPANT	\N	PRESENT	0
451849	450978	14026U	PARTICIPANT	\N	EXCUSE	0
427784	427783	11103C	PARTICIPANT	\N	PRESENT	0
427785	427783	14329V	PARTICIPANT	\N	PRESENT	0
427786	427783	18083K	PARTICIPANT	\N	PRESENT	0
427787	427783	14357A	PARTICIPANT	\N	PRESENT	0
427788	427783	19723Y	PARTICIPANT	\N	PRESENT	0
427790	427783	14059S	PARTICIPANT	\N	PRESENT	0
427791	427783	04092N	PARTICIPANT	\N	PRESENT	0
427792	427783	19679N	PARTICIPANT	\N	PRESENT	0
427794	427783	14331P	PARTICIPANT	\N	PRESENT	0
427795	427783	95067Q	PARTICIPANT	\N	PRESENT	0
433171	433168	19569H	PARTICIPANT	\N	PRESENT	0
433172	433168	14042U	PARTICIPANT	\N	PRESENT	0
434147	431548	96004D	PRESIDENT	0	PRESENT	0
434148	431548	11026G	PARTICIPANT	\N	PRESENT	0
434149	431548	14135M	PARTICIPANT	\N	PRESENT	0
434151	431548	10015M	PARTICIPANT	\N	PRESENT	0
434154	431548	98035U	PARTICIPANT	\N	PRESENT	0
434155	431548	14331P	PARTICIPANT	\N	PRESENT	0
434156	431548	14357A	PARTICIPANT	\N	PRESENT	0
434157	431548	14249W	PARTICIPANT	\N	PRESENT	0
434158	431548	14079W	PARTICIPANT	\N	PRESENT	0
434159	431548	19725B	PARTICIPANT	\N	PRESENT	0
434160	431548	14061L	PARTICIPANT	\N	EXCUSE	0
434169	430232	04044E	PARTICIPANT	\N	EXCUSE	0
434188	434187	01024M	PARTICIPANT	\N	PRESENT	0
434286	430777	19723Y	PARTICIPANT	\N	PRESENT	0
434287	430777	01048V	PRESIDENT	0	PRESENT	0
434289	430777	19503N	PARTICIPANT	\N	PRESENT	0
434291	430777	19693L	PARTICIPANT	\N	EXCUSE	0
434292	430777	08053X	PARTICIPANT	\N	EXCUSE	0
434293	430777	04043D	PARTICIPANT	\N	EXCUSE	0
434297	430777	14299H	PARTICIPANT	\N	PRESENT	0
434316	434315	14261S	PARTICIPANT	\N	PRESENT	0
434317	434315	14083S	PARTICIPANT	\N	PRESENT	0
434318	434315	19521Q	PARTICIPANT	\N	PRESENT	0
434319	434315	19695N	PARTICIPANT	\N	PRESENT	0
434320	434315	14061L	PARTICIPANT	\N	PRESENT	0
434321	434315	04049K	PRESIDENT	0	PRESENT	0
434322	434315	14205J	PARTICIPANT	\N	PRESENT	0
434323	434315	19671E	PARTICIPANT	\N	PRESENT	0
434324	434315	04088S	PARTICIPANT	\N	PRESENT	0
434325	434315	14251Q	PARTICIPANT	\N	PRESENT	0
434327	434315	89017R	PARTICIPANT	\N	EXCUSE	0
434328	434315	19575F	PARTICIPANT	\N	EXCUSE	0
434329	434315	14030Q	PARTICIPANT	\N	EXCUSE	0
434330	434315	08060W	PARTICIPANT	\N	EXCUSE	0
434331	434315	14105F	PARTICIPANT	\N	EXCUSE	0
434332	434315	08068F	PARTICIPANT	\N	EXCUSE	0
434333	434315	19545Y	PARTICIPANT	\N	EXCUSE	0
434334	434315	14079W	PARTICIPANT	\N	EXCUSE	0
434335	434315	14041T	PARTICIPANT	\N	EXCUSE	0
434336	434315	14087W	PARTICIPANT	\N	EXCUSE	0
434337	434315	14034U	PARTICIPANT	\N	EXCUSE	0
434338	434315	14026U	PARTICIPANT	\N	EXCUSE	0
434339	434315	14121F	PARTICIPANT	\N	EXCUSE	0
434340	434315	08015R	PARTICIPANT	\N	EXCUSE	0
434341	434315	19697Q	PARTICIPANT	\N	EXCUSE	0
434342	434315	14253S	PARTICIPANT	\N	EXCUSE	0
434343	434315	08047A	PARTICIPANT	\N	EXCUSE	0
434344	434315	14051J	PARTICIPANT	\N	EXCUSE	0
434345	434315	14157T	PARTICIPANT	\N	EXCUSE	0
435570	425619	19319Q	PARTICIPANT	\N	PRESENT	0
435571	425619	19713W	PARTICIPANT	\N	PRESENT	0
435572	425619	14219Q	PARTICIPANT	\N	PRESENT	0
435573	425619	19679N	PARTICIPANT	\N	PRESENT	0
435574	425619	95067Q	PARTICIPANT	\N	PRESENT	0
435575	425619	14267Y	PARTICIPANT	\N	PRESENT	0
435576	425619	17583W	PARTICIPANT	\N	PRESENT	0
435577	425619	14031R	PARTICIPANT	\N	PRESENT	0
435578	425619	19583F	PARTICIPANT	\N	PRESENT	0
435579	425619	01060R	PARTICIPANT	\N	PRESENT	0
435585	425619	14073Q	PARTICIPANT	\N	PRESENT	0
435586	434667	19687N	PARTICIPANT	\N	PRESENT	0
435587	434667	11053K	PARTICIPANT	\N	PRESENT	0
435588	434667	89017R	PARTICIPANT	\N	PRESENT	0
435589	434667	07029T	PARTICIPANT	\N	PRESENT	0
435592	425619	19581D	PARTICIPANT	\N	PRESENT	0
435593	425619	04045F	PARTICIPANT	\N	PRESENT	0
435594	425619	14026U	PARTICIPANT	\N	PRESENT	0
435595	425619	19253P	PARTICIPANT	\N	PRESENT	0
435596	425619	19735D	PARTICIPANT	\N	PRESENT	0
435597	434667	08010L	PARTICIPANT	\N	PRESENT	0
435598	425619	11045K	PARTICIPANT	\N	PRESENT	0
435599	425619	04069P	PARTICIPANT	\N	PRESENT	0
435600	425619	19599P	PARTICIPANT	\N	PRESENT	0
435601	425619	14038Y	PARTICIPANT	\N	PRESENT	0
435602	425619	07033P	PARTICIPANT	\N	PRESENT	0
435603	425619	14249W	PARTICIPANT	\N	PRESENT	0
435604	425619	19575F	PARTICIPANT	\N	PRESENT	0
435605	425619	01025N	PARTICIPANT	\N	PRESENT	0
435606	425619	14033T	PARTICIPANT	\N	PRESENT	0
435607	425619	18083K	PARTICIPANT	\N	PRESENT	0
435608	425619	19415P	PARTICIPANT	\N	PRESENT	0
435609	425619	80013X	PARTICIPANT	\N	PRESENT	0
435610	425619	14237S	PARTICIPANT	\N	PRESENT	0
435611	425619	14169X	PARTICIPANT	\N	PRESENT	0
435612	425619	19573D	PARTICIPANT	\N	PRESENT	0
435613	425619	14229S	PARTICIPANT	\N	PRESENT	0
435614	425619	11027H	PARTICIPANT	\N	PRESENT	0
435615	425619	14030Q	PARTICIPANT	\N	PRESENT	0
435616	425619	19709B	PARTICIPANT	\N	PRESENT	0
435617	425619	11031D	PARTICIPANT	\N	PRESENT	0
435618	425619	14281W	PARTICIPANT	\N	PRESENT	0
435619	425619	19637C	PARTICIPANT	\N	PRESENT	0
435620	425619	19631V	PARTICIPANT	\N	PRESENT	0
435631	425623	14121F	PARTICIPANT	\N	PRESENT	0
435633	425623	19673G	PARTICIPANT	\N	PRESENT	0
435634	425623	14169X	PARTICIPANT	\N	PRESENT	0
435635	425623	19629C	PARTICIPANT	\N	PRESENT	0
435636	425623	19479G	PARTICIPANT	\N	PRESENT	0
435637	425623	14195A	PARTICIPANT	\N	PRESENT	0
435638	425623	19711U	PARTICIPANT	\N	PRESENT	0
435639	425623	14107H	PARTICIPANT	\N	PRESENT	0
435629	425623	11027H	PARTICIPANT	\N	PRESENT	0
435655	425623	14191V	PARTICIPANT	\N	PRESENT	0
435640	425623	08060W	PARTICIPANT	\N	PRESENT	0
435641	425623	04086Q	PARTICIPANT	\N	PRESENT	0
435642	425623	14119M	PARTICIPANT	\N	PRESENT	0
435643	425623	14033T	PARTICIPANT	\N	PRESENT	0
435644	425623	14327T	PARTICIPANT	\N	PRESENT	0
435645	425623	19399H	PARTICIPANT	\N	PRESENT	0
435646	425623	19637C	PARTICIPANT	\N	PRESENT	0
435647	425623	19515S	PARTICIPANT	\N	PRESENT	0
435648	425623	19651A	PARTICIPANT	\N	PRESENT	0
435649	425623	19631V	PARTICIPANT	\N	PRESENT	0
435650	425623	19794Q	PARTICIPANT	\N	PRESENT	0
435651	425623	14241N	PARTICIPANT	\N	PRESENT	0
435652	425623	11077T	PARTICIPANT	\N	PRESENT	0
435653	425623	04088S	PARTICIPANT	\N	PRESENT	0
435654	425623	08009T	PARTICIPANT	\N	PRESENT	0
435656	425623	14081Q	PARTICIPANT	\N	PRESENT	0
435657	425623	99004R	PARTICIPANT	\N	PRESENT	0
435658	425623	19549D	PARTICIPANT	\N	PRESENT	0
435659	425623	14187A	PARTICIPANT	\N	PRESENT	0
435660	425623	87003B	PARTICIPANT	\N	PRESENT	0
435661	425623	19826F	PARTICIPANT	\N	PRESENT	0
435662	425623	08068F	PARTICIPANT	\N	PRESENT	0
435663	425623	08024S	PARTICIPANT	\N	PRESENT	0
435664	425623	14051J	PARTICIPANT	\N	PRESENT	0
435665	425623	19820Y	PARTICIPANT	\N	PRESENT	0
435666	425623	19443T	PARTICIPANT	\N	PRESENT	0
435667	425623	11090Q	PARTICIPANT	\N	PRESENT	0
435668	425623	17589D	PARTICIPANT	\N	PRESENT	0
435672	425623	08034U	PARTICIPANT	\N	PRESENT	0
435670	425623	14219Q	PARTICIPANT	\N	PRESENT	0
435671	425623	08014Q	PARTICIPANT	\N	PRESENT	0
435673	425623	11074Q	PARTICIPANT	\N	PRESENT	0
435674	425623	14259Y	PARTICIPANT	\N	PRESENT	0
435675	425623	19251M	PARTICIPANT	\N	PRESENT	0
435676	425623	19295A	PARTICIPANT	\N	PRESENT	0
435677	425623	05012A	PARTICIPANT	\N	PRESENT	0
435678	425623	14157T	PARTICIPANT	\N	PRESENT	0
435679	425623	19583F	PARTICIPANT	\N	PRESENT	0
435680	425623	14223L	PARTICIPANT	\N	PRESENT	0
435681	425623	14038Y	PARTICIPANT	\N	PRESENT	0
435682	425623	14235Q	PARTICIPANT	\N	PRESENT	0
435683	425623	14028W	PARTICIPANT	\N	PRESENT	0
435684	425623	19253P	PARTICIPANT	\N	PRESENT	0
435685	425623	19333N	PARTICIPANT	\N	PRESENT	0
435686	425623	14227Q	PARTICIPANT	\N	PRESENT	0
435687	425623	15447F	PARTICIPANT	\N	PRESENT	0
452243	450723	11027H	PARTICIPANT	\N	PRESENT	0
452244	450723	04042C	PRESIDENT	0	PRESENT	0
452245	450723	11066Q	PARTICIPANT	\N	PRESENT	0
452246	450723	19669L	PARTICIPANT	\N	PRESENT	0
452247	450723	08056B	PARTICIPANT	\N	PRESENT	0
452248	450723	11115U	PARTICIPANT	\N	PRESENT	0
452249	450723	95037J	PARTICIPANT	\N	PRESENT	0
452250	450723	14055N	PARTICIPANT	\N	PRESENT	0
452251	450723	19421M	PARTICIPANT	\N	PRESENT	0
452252	450723	14193X	PARTICIPANT	\N	PRESENT	0
452253	450723	08049C	PARTICIPANT	\N	PRESENT	0
452254	450723	08053X	PARTICIPANT	\N	PRESENT	0
452255	450723	97011G	PARTICIPANT	\N	PRESENT	0
452256	450723	08047A	PARTICIPANT	\N	PRESENT	0
452257	450723	98029W	PARTICIPANT	\N	PRESENT	0
452258	450723	14097Y	PARTICIPANT	\N	PRESENT	0
452259	450723	95067Q	PARTICIPANT	\N	PRESENT	0
452260	450723	14133K	PARTICIPANT	\N	PRESENT	0
452261	450723	01062T	PARTICIPANT	\N	PRESENT	0
452262	450723	11041F	PARTICIPANT	\N	PRESENT	0
452263	450723	14235Q	PARTICIPANT	\N	PRESENT	0
452264	450723	19251M	PARTICIPANT	\N	PRESENT	0
452265	450723	14028W	PARTICIPANT	\N	PRESENT	0
452266	450723	19721W	PARTICIPANT	\N	PRESENT	0
452267	450723	19319Q	PARTICIPANT	\N	PRESENT	0
452268	450723	14105F	PARTICIPANT	\N	PRESENT	0
452269	450723	98018T	PARTICIPANT	\N	PRESENT	0
452270	450723	98022P	PARTICIPANT	\N	PRESENT	0
452271	450723	11064N	PARTICIPANT	\N	PRESENT	0
452272	450723	98050T	PARTICIPANT	\N	PRESENT	0
452273	450723	19583F	PARTICIPANT	\N	PRESENT	0
452274	450723	14211G	PARTICIPANT	\N	PRESENT	0
452275	450723	14255U	PARTICIPANT	\N	PRESENT	0
452276	450608	04059M	PARTICIPANT	\N	PRESENT	0
452277	450608	19735D	PARTICIPANT	\N	PRESENT	0
452278	450942	19695N	PARTICIPANT	\N	PRESENT	0
452279	450942	01025N	PARTICIPANT	\N	PRESENT	0
452280	450609	19647E	PARTICIPANT	\N	PRESENT	0
452328	450717	04035D	PARTICIPANT	\N	EXCUSE	0
452333	450608	07033P	PARTICIPANT	\N	PRESENT	0
452334	450612	14331P	PARTICIPANT	\N	PRESENT	0
452335	450612	04071H	PRESIDENT	1	PRESENT	0
452336	450612	01048V	PARTICIPANT	\N	PRESENT	0
452337	450612	01057W	PARTICIPANT	\N	PRESENT	0
452338	450612	89017R	PARTICIPANT	\N	PRESENT	0
452339	450612	11074Q	PRESIDENT	0	PRESENT	0
452340	450612	88008L	PARTICIPANT	\N	PRESENT	0
452341	450612	14225N	PARTICIPANT	\N	PRESENT	0
452342	450612	07029T	PARTICIPANT	\N	PRESENT	0
452343	450612	14085U	PARTICIPANT	\N	PRESENT	0
452344	450612	96004D	PARTICIPANT	\N	PRESENT	0
452345	450612	08010L	PARTICIPANT	\N	PRESENT	0
452346	450612	19479G	PARTICIPANT	\N	PRESENT	0
452347	450612	19647E	PARTICIPANT	\N	PRESENT	0
452348	450612	19711U	PARTICIPANT	\N	PRESENT	0
452349	450612	19687N	PARTICIPANT	\N	PRESENT	0
452350	450612	12016W	PARTICIPANT	\N	PRESENT	0
452351	450612	08011M	PARTICIPANT	\N	PRESENT	0
452352	450612	11040E	PARTICIPANT	\N	PRESENT	0
452353	450612	04086Q	PARTICIPANT	\N	PRESENT	0
452354	450612	14083S	PARTICIPANT	\N	PRESENT	0
452355	450612	11012A	PARTICIPANT	\N	PRESENT	0
452356	450612	08073C	PARTICIPANT	\N	PRESENT	0
452357	450612	19741B	PARTICIPANT	\N	PRESENT	0
452358	450612	14121F	PARTICIPANT	\N	PRESENT	0
452359	450612	11048N	PARTICIPANT	\N	PRESENT	0
452360	450612	19545Y	PARTICIPANT	\N	EXCUSE	0
452361	450612	08034U	PARTICIPANT	\N	PRESENT	0
452362	450612	14034U	PARTICIPANT	\N	PRESENT	0
452363	450942	17589D	PARTICIPANT	\N	PRESENT	0
452370	449607	19697Q	PARTICIPANT	\N	PRESENT	0
452371	449607	11067R	PARTICIPANT	\N	PRESENT	0
452372	449607	19565D	PARTICIPANT	\N	PRESENT	0
452373	449607	19798U	PARTICIPANT	\N	PRESENT	0
452374	449607	19569H	PARTICIPANT	\N	PRESENT	0
452375	449607	11097X	PARTICIPANT	\N	PRESENT	0
452376	449607	19415P	PARTICIPANT	\N	PRESENT	0
452377	449607	04045F	PARTICIPANT	\N	PRESENT	0
452378	449607	14227Q	PARTICIPANT	\N	PRESENT	0
452379	449607	19703U	PARTICIPANT	\N	PRESENT	0
452380	449607	14239U	PARTICIPANT	\N	PRESENT	0
452381	449607	11031D	PARTICIPANT	\N	PRESENT	0
452382	449607	19553Y	PARTICIPANT	\N	PRESENT	0
452383	449607	14087W	PARTICIPANT	\N	PRESENT	0
452384	449607	19679N	PARTICIPANT	\N	PRESENT	0
452385	449607	14042U	PARTICIPANT	\N	PRESENT	0
452386	449607	19575F	PARTICIPANT	\N	PRESENT	0
452387	449607	14195A	PARTICIPANT	\N	PRESENT	0
452388	449607	14213J	PARTICIPANT	\N	PRESENT	0
452389	449607	19367Y	PARTICIPANT	\N	PRESENT	0
452390	449607	14261S	PARTICIPANT	\N	PRESENT	0
452391	449607	14217N	PARTICIPANT	\N	PRESENT	0
452392	449607	10006L	PARTICIPANT	\N	PRESENT	0
452393	449607	98024R	PARTICIPANT	\N	PRESENT	0
452394	449607	19521Q	PARTICIPANT	\N	PRESENT	0
452395	449607	19527W	PARTICIPANT	\N	PRESENT	0
452396	449607	01034P	PARTICIPANT	\N	PRESENT	0
452397	449607	04092N	PRESIDENT	0	PRESENT	0
452398	449607	11045K	PARTICIPANT	\N	PRESENT	0
452399	449607	08052W	PARTICIPANT	\N	PRESENT	0
452400	449607	19301E	PARTICIPANT	\N	PRESENT	0
452401	449607	19715Y	PARTICIPANT	\N	PRESENT	0
452402	449607	19691J	PARTICIPANT	\N	PRESENT	0
452403	449607	19717B	PARTICIPANT	\N	PRESENT	0
452404	449607	19723Y	PARTICIPANT	\N	PRESENT	0
452405	449607	14119M	PARTICIPANT	\N	PRESENT	0
452406	449607	11103C	PARTICIPANT	\N	PRESENT	0
452407	449607	14071N	PARTICIPANT	\N	PRESENT	0
452408	449607	19657G	PARTICIPANT	\N	PRESENT	0
452409	449607	19760E	PARTICIPANT	\N	PRESENT	0
452410	449607	08041T	PARTICIPANT	\N	EXCUSE	0
452494	450608	14039A	PARTICIPANT	\N	PRESENT	0
452495	450608	14251Q	PARTICIPANT	\N	PRESENT	0
452558	452557	08015R	PARTICIPANT	\N	PRESENT	0
452559	452557	08056B	PARTICIPANT	\N	PRESENT	0
452560	452557	14197C	PARTICIPANT	\N	PRESENT	0
452573	452572	14205J	PARTICIPANT	\N	PRESENT	0
452574	452572	14207L	PARTICIPANT	\N	PRESENT	0
452576	452575	19812Y	PARTICIPANT	\N	PRESENT	0
452577	452575	19507S	PARTICIPANT	\N	PRESENT	0
452578	452575	14205J	PARTICIPANT	\N	PRESENT	0
452579	452575	14207L	PARTICIPANT	\N	PRESENT	0
452580	452575	19563B	PARTICIPANT	\N	PRESENT	0
452593	450723	04035D	PARTICIPANT	\N	EXCUSE	0
453498	449607	08048B	PARTICIPANT	\N	PRESENT	0
453500	449606	04045F	PARTICIPANT	\N	EXCUSE	0
453558	448740	19289C	PARTICIPANT	\N	PRESENT	0
453563	450728	04035D	PARTICIPANT	\N	EXCUSE	0
453564	450728	19583F	PARTICIPANT	\N	EXCUSE	0
453565	448740	04088S	PARTICIPANT	\N	PRESENT	0
453566	448740	19689Q	PARTICIPANT	\N	PRESENT	0
453568	448740	19725B	PARTICIPANT	\N	PRESENT	0
453569	448740	11031D	PARTICIPANT	\N	PRESENT	0
453570	448740	19347U	PARTICIPANT	\N	PRESENT	0
453571	448740	11033F	PARTICIPANT	\N	PRESENT	0
453572	448740	19669L	PARTICIPANT	\N	PRESENT	0
453573	448740	19585H	PARTICIPANT	\N	PRESENT	0
453574	448740	14147R	PARTICIPANT	\N	PRESENT	0
453575	448740	19447X	PARTICIPANT	\N	PRESENT	0
453576	448740	14069U	PARTICIPANT	\N	PRESENT	0
453577	448740	07029T	PARTICIPANT	\N	PRESENT	0
453578	448740	98050T	PARTICIPANT	\N	PRESENT	0
453580	448740	19820Y	PARTICIPANT	\N	PRESENT	0
453581	448740	19301E	PARTICIPANT	\N	PRESENT	0
453582	448740	19573D	PARTICIPANT	\N	PRESENT	0
453583	448740	14038Y	PARTICIPANT	\N	PRESENT	0
453584	448740	19467C	PARTICIPANT	\N	PRESENT	0
453585	448740	19713W	PARTICIPANT	\N	PRESENT	0
453586	448740	19543W	PARTICIPANT	\N	PRESENT	0
453587	448740	08034U	PARTICIPANT	\N	PRESENT	0
453588	448740	12016W	PARTICIPANT	\N	PRESENT	0
453589	448740	08010L	PARTICIPANT	\N	PRESENT	0
453590	448740	19479G	PARTICIPANT	\N	PRESENT	0
453591	448740	19711U	PARTICIPANT	\N	PRESENT	0
453592	448740	14217N	PARTICIPANT	\N	PRESENT	0
423921	422672	19583F	PARTICIPANT	\N	EXCUSE	0
423922	422672	19319Q	PARTICIPANT	\N	EXCUSE	0
427221	416322	11070L	PARTICIPANT	\N	PRESENT	0
427222	416322	14041T	PARTICIPANT	\N	PRESENT	0
427223	416322	19507S	PARTICIPANT	\N	PRESENT	0
427224	416322	19713W	PARTICIPANT	\N	PRESENT	0
427225	416322	19737F	PARTICIPANT	\N	PRESENT	0
427226	416322	19479G	PARTICIPANT	\N	PRESENT	0
427227	416322	14195A	PARTICIPANT	\N	PRESENT	0
427228	416322	19719D	PARTICIPANT	\N	PRESENT	0
427229	416322	19820Y	PARTICIPANT	\N	PRESENT	0
427230	416322	08052W	PARTICIPANT	\N	PRESENT	0
427231	416322	80013X	PARTICIPANT	\N	PRESENT	0
427232	416322	19715Y	PARTICIPANT	\N	PRESENT	0
427233	416322	19367Y	PARTICIPANT	\N	PRESENT	0
427234	416322	19745F	PARTICIPANT	\N	PRESENT	0
427235	416322	11031D	PARTICIPANT	\N	PRESENT	0
427236	416322	04045F	PARTICIPANT	\N	PRESENT	0
427237	416322	04043D	PARTICIPANT	\N	PRESENT	0
427238	416322	11067R	PARTICIPANT	\N	PRESENT	0
427239	416322	10006L	PARTICIPANT	\N	PRESENT	0
427240	416322	14059S	PARTICIPANT	\N	PRESENT	0
427241	416322	14223L	PARTICIPANT	\N	PRESENT	0
427242	416322	19735D	PARTICIPANT	\N	PRESENT	0
427243	416322	19569H	PARTICIPANT	\N	PRESENT	0
427244	416322	14281W	PARTICIPANT	\N	PRESENT	0
427245	416322	19760E	PARTICIPANT	\N	PRESENT	0
427246	416322	19667J	PARTICIPANT	\N	PRESENT	0
427247	416322	19565D	PARTICIPANT	\N	PRESENT	0
427248	416322	08019V	PARTICIPANT	\N	PRESENT	0
427249	416322	19679N	PARTICIPANT	\N	PRESENT	0
427250	416322	14069U	PARTICIPANT	\N	PRESENT	0
427251	416322	04092N	PARTICIPANT	\N	PRESENT	0
427252	416322	14089Y	PARTICIPANT	\N	PRESENT	0
427253	416322	14267Y	PARTICIPANT	\N	PRESENT	0
427254	416322	14261S	PARTICIPANT	\N	PRESENT	0
427255	416322	19717B	PARTICIPANT	\N	PRESENT	0
427256	416322	14042U	PARTICIPANT	\N	PRESENT	0
427257	416322	19683J	PARTICIPANT	\N	PRESENT	0
427258	416322	14147R	PARTICIPANT	\N	PRESENT	0
427259	416322	19387D	PARTICIPANT	\N	PRESENT	0
427260	416322	11101A	PARTICIPANT	\N	PRESENT	0
427261	416322	19703U	PARTICIPANT	\N	PRESENT	0
427262	416322	11097X	PARTICIPANT	\N	PRESENT	0
427263	416322	14119M	PARTICIPANT	\N	PRESENT	0
427264	416322	98024R	PARTICIPANT	\N	PRESENT	0
427265	416322	04018C	PARTICIPANT	\N	PRESENT	0
427266	416322	14213J	PARTICIPANT	\N	PRESENT	0
427267	416322	19521Q	PARTICIPANT	\N	PRESENT	0
427268	416322	19826F	PARTICIPANT	\N	PRESENT	0
427269	416322	19301E	PARTICIPANT	\N	PRESENT	0
427270	416322	14065Q	PARTICIPANT	\N	PRESENT	0
427271	416322	14039A	PARTICIPANT	\N	PRESENT	0
427272	416322	14105F	PARTICIPANT	\N	PRESENT	0
427273	416322	19553Y	PARTICIPANT	\N	PRESENT	0
427274	416322	19575F	PARTICIPANT	\N	PRESENT	0
427275	416322	14239U	PARTICIPANT	\N	PRESENT	0
427276	416322	08055A	PARTICIPANT	\N	PRESENT	0
427277	416322	14083S	PARTICIPANT	\N	PRESENT	0
427278	416322	19681G	PARTICIPANT	\N	PRESENT	0
427279	416322	19619A	PARTICIPANT	\N	PRESENT	0
427280	416322	14157T	PARTICIPANT	\N	PRESENT	0
427281	416322	17779H	PARTICIPANT	\N	PRESENT	0
427282	416322	19727D	PARTICIPANT	\N	PRESENT	0
427283	416322	19739H	PARTICIPANT	\N	PRESENT	0
427284	423927	19768N	PARTICIPANT	\N	PRESENT	0
427285	423927	19515S	PARTICIPANT	\N	PRESENT	0
427286	423927	19441R	PARTICIPANT	\N	PRESENT	0
427287	423927	14081Q	PARTICIPANT	\N	PRESENT	0
427288	423927	19413M	PARTICIPANT	\N	PRESENT	0
427289	423927	80013X	PARTICIPANT	\N	PRESENT	0
427290	423927	19631V	PARTICIPANT	\N	PRESENT	0
427291	423927	08068F	PARTICIPANT	\N	PRESENT	0
427292	423927	04049K	PARTICIPANT	\N	PRESENT	0
427293	423927	19705W	PARTICIPANT	\N	PRESENT	0
427294	423927	08015R	PARTICIPANT	\N	PRESENT	0
427295	423927	14197C	PARTICIPANT	\N	PRESENT	0
427296	423927	19369B	PARTICIPANT	\N	PRESENT	0
427297	423927	08028W	PARTICIPANT	\N	PRESENT	0
427298	423927	14265W	PARTICIPANT	\N	PRESENT	0
427299	423927	14329V	PARTICIPANT	\N	PRESENT	0
427300	423927	14187A	PARTICIPANT	\N	PRESENT	0
427301	423927	08062Y	PARTICIPANT	\N	PRESENT	0
427302	423927	19695N	PARTICIPANT	\N	PRESENT	0
427303	423927	11090Q	PRESIDENT	0	PRESENT	0
427304	423927	14033T	PARTICIPANT	\N	PRESENT	0
427305	423927	14205J	PARTICIPANT	\N	PRESENT	0
427306	423927	11056N	PARTICIPANT	\N	PRESENT	0
427307	423927	19747H	PARTICIPANT	\N	PRESENT	0
427308	423927	14207L	PARTICIPANT	\N	PRESENT	0
427309	423927	14257W	PARTICIPANT	\N	PRESENT	0
427310	416322	19295A	PARTICIPANT	\N	PRESENT	0
427311	416322	14227Q	PARTICIPANT	\N	PRESENT	0
427312	416322	01034P	PARTICIPANT	\N	PRESENT	0
427313	416322	14217N	PARTICIPANT	\N	PRESENT	0
427314	416322	95030B	PARTICIPANT	\N	PRESENT	0
427315	416322	14061L	PARTICIPANT	\N	PRESENT	0
427316	416322	19657G	PARTICIPANT	\N	PRESENT	0
427317	416322	08073C	PARTICIPANT	\N	PRESENT	0
427318	416322	11103C	PARTICIPANT	\N	PRESENT	0
427319	416322	19729F	PARTICIPANT	\N	PRESENT	0
427320	416322	08047A	PARTICIPANT	\N	PRESENT	0
427321	416322	19798U	PARTICIPANT	\N	PRESENT	0
427322	416322	08056B	PARTICIPANT	\N	PRESENT	0
427323	416322	11045K	PARTICIPANT	\N	PRESENT	0
427324	423927	19782L	PARTICIPANT	\N	PRESENT	0
427325	423927	19295A	PARTICIPANT	\N	PRESENT	0
427326	423927	19812Y	PARTICIPANT	\N	EXCUSE	0
427327	423927	11081P	PARTICIPANT	\N	EXCUSE	0
427329	416322	19413M	PARTICIPANT	\N	PRESENT	0
427330	416322	14257W	PARTICIPANT	\N	PRESENT	0
427331	416322	07004J	PARTICIPANT	\N	PRESENT	0
427332	416322	19527W	PARTICIPANT	\N	PRESENT	0
427333	416322	15447F	PARTICIPANT	\N	PRESENT	0
427334	416322	19697Q	PARTICIPANT	\N	PRESENT	0
427335	416322	19673G	PARTICIPANT	\N	PRESENT	0
427336	416322	11072N	PARTICIPANT	\N	PRESENT	0
427337	416322	19467C	PARTICIPANT	\N	PRESENT	0
427338	416322	99004R	PARTICIPANT	\N	PRESENT	0
427339	416322	19651A	PARTICIPANT	\N	PRESENT	0
427340	426127	19699S	PARTICIPANT	\N	PRESENT	0
427341	426127	19533U	PARTICIPANT	\N	PRESENT	0
427342	426127	14229S	PARTICIPANT	\N	PRESENT	0
427343	426127	14241N	PARTICIPANT	\N	PRESENT	0
427344	426127	19573D	PARTICIPANT	\N	PRESENT	0
427345	426127	14039A	PARTICIPANT	\N	PRESENT	0
427346	426127	14107H	PARTICIPANT	\N	PRESENT	0
427347	426127	08017T	PARTICIPANT	\N	PRESENT	0
427348	426127	07033P	PRESIDENT	0	PRESENT	0
427349	426127	08012N	PARTICIPANT	\N	PRESENT	0
427350	426127	19335Q	PARTICIPANT	\N	PRESENT	0
427351	426127	14249W	PARTICIPANT	\N	PRESENT	0
427352	426127	08031R	PARTICIPANT	\N	PRESENT	0
427353	426127	19593H	PARTICIPANT	\N	PRESENT	0
427354	426127	14061L	PARTICIPANT	\N	PRESENT	0
427355	426127	04057K	PARTICIPANT	\N	PRESENT	0
427356	426127	19611R	PARTICIPANT	\N	PRESENT	0
427357	426127	08043V	PARTICIPANT	\N	PRESENT	0
427358	426127	19693L	PARTICIPANT	\N	PRESENT	0
427359	426127	19399H	PARTICIPANT	\N	PRESENT	0
427360	426127	14030Q	PARTICIPANT	\N	PRESENT	0
427361	426127	04059M	PARTICIPANT	\N	PRESENT	0
427362	426127	19735D	PARTICIPANT	\N	PRESENT	0
427363	426127	14109K	PARTICIPANT	\N	PRESENT	0
427364	426127	14123H	PRESIDENT	1	PRESENT	0
427365	426127	11104D	PARTICIPANT	\N	PRESENT	0
427366	426127	19749K	PARTICIPANT	\N	PRESENT	0
427367	426127	19758L	PARTICIPANT	\N	PRESENT	0
427368	426127	19621T	PARTICIPANT	\N	PRESENT	0
427369	426127	04070G	PARTICIPANT	\N	EXCUSE	0
427370	426127	08039A	PARTICIPANT	\N	EXCUSE	0
427374	416322	14026U	PARTICIPANT	\N	PRESENT	0
427375	416322	19723Y	PARTICIPANT	\N	PRESENT	0
427376	416322	12016W	PARTICIPANT	\N	PRESENT	0
427377	425130	14331P	PARTICIPANT	\N	PRESENT	0
427378	425130	19479G	PARTICIPANT	\N	PRESENT	0
427379	425130	19711U	PARTICIPANT	\N	PRESENT	0
427380	425130	19545Y	PARTICIPANT	\N	PRESENT	0
427381	425130	01057W	PARTICIPANT	\N	PRESENT	0
427382	425130	19689Q	PARTICIPANT	\N	PRESENT	0
427383	425130	11053K	PARTICIPANT	\N	PRESENT	0
427384	425130	11074Q	PRESIDENT	0	PRESENT	0
427385	425130	14034U	PARTICIPANT	\N	PRESENT	0
427386	425130	14225N	PARTICIPANT	\N	PRESENT	0
427387	425130	19671E	PARTICIPANT	\N	PRESENT	0
427389	425130	04086Q	PARTICIPANT	\N	PRESENT	0
427390	425130	07029T	PARTICIPANT	\N	PRESENT	0
427391	425130	14083S	PARTICIPANT	\N	PRESENT	0
451851	451850	19599P	PARTICIPANT	\N	PRESENT	0
451852	451850	14157T	PARTICIPANT	\N	PRESENT	0
451853	448735	95041E	PARTICIPANT	\N	PRESENT	0
451854	451850	19637C	PARTICIPANT	\N	PRESENT	0
451855	451850	19826F	PARTICIPANT	\N	PRESENT	0
451856	451850	19745F	PARTICIPANT	\N	PRESENT	0
451857	451850	14051J	PARTICIPANT	\N	PRESENT	0
451858	448735	19643A	PARTICIPANT	\N	PRESENT	0
451860	451859	19599P	PARTICIPANT	\N	PRESENT	0
451861	451859	14157T	PARTICIPANT	\N	PRESENT	0
451862	451859	19745F	PARTICIPANT	\N	PRESENT	0
451863	451859	19637C	PARTICIPANT	\N	PRESENT	0
451864	451859	19826F	PARTICIPANT	\N	PRESENT	0
451865	451859	14051J	PARTICIPANT	\N	PRESENT	0
451866	451859	14053L	PARTICIPANT	\N	PRESENT	0
451868	448735	19369B	PARTICIPANT	\N	PRESENT	0
451869	451867	19599P	PARTICIPANT	\N	PRESENT	0
451870	451867	14157T	PARTICIPANT	\N	PRESENT	0
451871	451867	19745F	PARTICIPANT	\N	PRESENT	0
451872	448735	19521Q	PARTICIPANT	\N	PRESENT	0
451873	450978	14053L	PARTICIPANT	\N	PRESENT	0
451874	448735	14038Y	PARTICIPANT	\N	PRESENT	0
451875	448735	14115H	PARTICIPANT	\N	PRESENT	0
451876	450978	19251M	PARTICIPANT	\N	PRESENT	0
451877	448735	19711U	PARTICIPANT	\N	PRESENT	0
451878	451356	11026G	PARTICIPANT	\N	PRESENT	0
451879	451356	04040A	PARTICIPANT	\N	PRESENT	0
451880	448735	19713W	PARTICIPANT	\N	PRESENT	0
451881	448735	19721W	PARTICIPANT	\N	PRESENT	0
451882	448735	19782L	PARTICIPANT	\N	PRESENT	0
451883	450978	19826F	PARTICIPANT	\N	PRESENT	0
451884	448735	19701S	PARTICIPANT	\N	PRESENT	0
451885	448735	14073Q	PARTICIPANT	\N	PRESENT	0
451887	448735	98022P	PARTICIPANT	\N	PRESENT	0
451888	448735	08015R	PARTICIPANT	\N	PRESENT	0
451889	448735	14257W	PARTICIPANT	\N	PRESENT	0
451890	448735	08061X	PARTICIPANT	\N	PRESENT	0
451891	448735	19826F	PARTICIPANT	\N	PRESENT	0
451892	448735	01024M	PARTICIPANT	\N	PRESENT	0
451893	448735	04069P	PARTICIPANT	\N	PRESENT	0
451894	448735	97011G	PARTICIPANT	\N	PRESENT	0
451895	448735	14053L	PARTICIPANT	\N	PRESENT	0
451896	448735	19549D	PARTICIPANT	\N	PRESENT	0
451897	448735	19251M	PARTICIPANT	\N	PRESENT	0
451898	448735	14109K	PARTICIPANT	\N	PRESENT	0
451899	448735	14121F	PARTICIPANT	\N	PRESENT	0
451900	448735	19715Y	PARTICIPANT	\N	PRESENT	0
451901	448735	14199E	PARTICIPANT	\N	PRESENT	0
451902	448735	19723Y	PARTICIPANT	\N	PRESENT	0
451903	448735	14191V	PARTICIPANT	\N	PRESENT	0
451904	448735	17583W	PARTICIPANT	\N	PRESENT	0
451917	448735	14021P	PARTICIPANT	\N	PRESENT	0
451918	448735	08024S	PARTICIPANT	\N	PRESENT	0
451922	448735	14211G	PARTICIPANT	\N	PRESENT	0
451923	448735	14217N	PARTICIPANT	\N	PRESENT	0
451924	448735	19253P	PARTICIPANT	\N	PRESENT	0
451925	449743	14133K	PARTICIPANT	\N	PRESENT	0
451926	449743	96004D	PRESIDENT	0	PRESENT	0
451927	449743	14089Y	PARTICIPANT	\N	PRESENT	0
451928	449743	08014Q	PARTICIPANT	\N	PRESENT	0
451929	449743	14249W	PARTICIPANT	\N	PRESENT	0
451930	449743	11083R	PARTICIPANT	\N	PRESENT	0
451931	449743	95037J	PARTICIPANT	\N	PRESENT	0
451932	449743	19725B	PARTICIPANT	\N	PRESENT	0
451933	449743	04097T	PARTICIPANT	\N	PRESENT	0
451934	449743	14097Y	PARTICIPANT	\N	PRESENT	0
451935	449743	14241N	PARTICIPANT	\N	PRESENT	0
451936	449743	14073Q	PARTICIPANT	\N	PRESENT	0
451937	449743	12041X	PARTICIPANT	\N	PRESENT	0
451938	449743	14001X	PARTICIPANT	\N	PRESENT	0
451939	449743	04057K	PARTICIPANT	\N	EXCUSE	0
451940	449743	14331P	PARTICIPANT	\N	PRESENT	0
451941	449743	14237S	PARTICIPANT	\N	PRESENT	0
451942	448735	04040A	PARTICIPANT	\N	PRESENT	0
451943	448735	08011M	PARTICIPANT	\N	PRESENT	0
451944	448735	11104D	PARTICIPANT	\N	PRESENT	0
451945	448735	14030Q	PARTICIPANT	\N	PRESENT	0
451947	451946	11097X	PARTICIPANT	\N	PRESENT	0
451948	451946	08052W	PARTICIPANT	\N	PRESENT	0
451949	451946	14217N	PARTICIPANT	\N	PRESENT	0
451950	451946	01034P	PARTICIPANT	\N	PRESENT	0
451952	451951	11097X	PARTICIPANT	\N	PRESENT	0
451953	451951	08052W	PARTICIPANT	\N	PRESENT	0
451954	451951	14217N	PARTICIPANT	\N	PRESENT	0
451955	451951	01034P	PARTICIPANT	\N	PRESENT	0
451957	451956	11097X	PARTICIPANT	\N	PRESENT	0
451958	451956	01034P	PARTICIPANT	\N	PRESENT	0
451959	451956	14217N	PARTICIPANT	\N	PRESENT	0
451961	451960	11097X	PARTICIPANT	\N	PRESENT	0
452006	441812	98005N	PARTICIPANT	\N	PRESENT	0
452322	452281	14169X	PARTICIPANT	\N	PRESENT	0
452323	452281	14083S	PARTICIPANT	\N	PRESENT	0
452324	452281	08034U	PARTICIPANT	\N	PRESENT	0
452325	452281	19729F	PARTICIPANT	\N	PRESENT	0
452326	452281	19687N	PARTICIPANT	\N	PRESENT	0
452327	452281	04018C	PARTICIPANT	\N	PRESENT	0
452545	452544	14157T	PARTICIPANT	\N	PRESENT	0
452546	452544	19599P	PARTICIPANT	\N	PRESENT	0
452547	450932	19593H	PARTICIPANT	\N	PRESENT	0
452548	450932	19533U	PARTICIPANT	\N	PRESENT	0
452549	450932	01048V	PARTICIPANT	\N	PRESENT	0
452550	450932	19503N	PARTICIPANT	\N	PRESENT	0
452552	450932	14093U	PARTICIPANT	\N	PRESENT	0
452553	450932	19693L	PARTICIPANT	\N	EXCUSE	0
452563	452562	19515S	PARTICIPANT	\N	PRESENT	0
452564	452562	19631V	PARTICIPANT	\N	PRESENT	0
452566	452565	19515S	PARTICIPANT	\N	PRESENT	0
452567	452565	19812Y	PARTICIPANT	\N	PRESENT	0
452568	452565	19631V	PARTICIPANT	\N	PRESENT	0
452570	452569	19515S	PARTICIPANT	\N	PRESENT	0
452571	452569	19812Y	PARTICIPANT	\N	PRESENT	0
452587	450711	19521Q	PARTICIPANT	\N	PRESENT	0
452895	452894	17589D	PARTICIPANT	\N	PRESENT	0
452896	452894	14205J	PARTICIPANT	\N	PRESENT	0
452903	452902	19719D	PARTICIPANT	\N	PRESENT	0
452912	452902	11080N	PARTICIPANT	\N	PRESENT	0
453261	452902	19673G	PARTICIPANT	\N	PRESENT	0
453382	448738	19575F	PARTICIPANT	\N	PRESENT	0
453494	453493	14229S	PARTICIPANT	\N	PRESENT	0
453496	453493	04057K	PARTICIPANT	\N	PRESENT	0
453497	453493	19693L	PARTICIPANT	\N	PRESENT	0
453504	448739	04049K	PARTICIPANT	\N	PRESENT	0
453505	448739	14235Q	PARTICIPANT	\N	PRESENT	0
453507	453506	14087W	PARTICIPANT	\N	PRESENT	0
453508	453506	19521Q	PARTICIPANT	\N	PRESENT	0
453510	450943	11081P	PARTICIPANT	\N	EXCUSE	0
453547	449597	19725B	PARTICIPANT	\N	PRESENT	0
453548	449597	14026U	PARTICIPANT	\N	PRESENT	0
453549	449598	19725B	PARTICIPANT	\N	PRESENT	0
453550	449598	14026U	PARTICIPANT	\N	PRESENT	0
453579	452902	11026G	PARTICIPANT	\N	PRESENT	0
453594	453593	14115H	PARTICIPANT	\N	PRESENT	0
453595	453593	14207L	PARTICIPANT	\N	PRESENT	0
453596	453593	14197C	PARTICIPANT	\N	PRESENT	0
453597	453593	01025N	PARTICIPANT	\N	PRESENT	0
453598	453593	14265W	PARTICIPANT	\N	PRESENT	0
453599	453593	04088S	PARTICIPANT	\N	PRESENT	0
453600	453593	14135M	PARTICIPANT	\N	PRESENT	0
453601	453593	08015R	PARTICIPANT	\N	PRESENT	0
425107	425102	19507S	PARTICIPANT	\N	PRESENT	0
425108	425102	01025N	PARTICIPANT	\N	PRESENT	0
425109	425102	19782L	PARTICIPANT	\N	PRESENT	0
425110	425102	19269X	PARTICIPANT	\N	PRESENT	0
425111	425102	19413M	PARTICIPANT	\N	PRESENT	0
425113	425103	14357A	PARTICIPANT	\N	PRESENT	0
425114	425103	19507S	PARTICIPANT	\N	PRESENT	0
425115	425103	01025N	PARTICIPANT	\N	PRESENT	0
425116	425103	19768N	PARTICIPANT	\N	PRESENT	0
425117	425103	19413M	PARTICIPANT	\N	PRESENT	0
425118	425104	19507S	PARTICIPANT	\N	PRESENT	0
425119	425104	01025N	PARTICIPANT	\N	PRESENT	0
425120	425104	19413M	PARTICIPANT	\N	PRESENT	0
425121	425104	19269X	PARTICIPANT	\N	PRESENT	0
425122	425106	19507S	PARTICIPANT	\N	PRESENT	0
425123	425106	01025N	PARTICIPANT	\N	PRESENT	0
425124	425106	19413M	PARTICIPANT	\N	PRESENT	0
425125	425106	19269X	PARTICIPANT	\N	PRESENT	0
425142	425138	14157T	PARTICIPANT	\N	PRESENT	0
425143	425139	14157T	PARTICIPANT	\N	PRESENT	0
428428	428198	04071H	PARTICIPANT	\N	PRESENT	0
428429	428198	11048N	PARTICIPANT	\N	PRESENT	0
428430	428198	19711U	PARTICIPANT	\N	PRESENT	0
428431	428198	19545Y	PARTICIPANT	\N	PRESENT	0
428432	428198	01057W	PARTICIPANT	\N	PRESENT	0
428433	428198	11074Q	PRESIDENT	0	PRESENT	0
428434	428198	14083S	PARTICIPANT	\N	PRESENT	0
428435	428198	14085U	PARTICIPANT	\N	PRESENT	0
428436	428198	08010L	PARTICIPANT	\N	PRESENT	0
428437	428198	19741B	PARTICIPANT	\N	PRESENT	0
428438	428198	07029T	PARTICIPANT	\N	EXCUSE	0
428439	416354	04059M	PARTICIPANT	\N	PRESENT	0
428440	416354	19527W	PARTICIPANT	\N	PRESENT	0
428441	416354	14083S	PARTICIPANT	\N	PRESENT	0
428442	416354	14331P	PARTICIPANT	\N	PRESENT	0
428443	416354	11040E	PARTICIPANT	\N	PRESENT	0
428444	416354	19687N	PARTICIPANT	\N	PRESENT	0
428445	416354	19651A	PARTICIPANT	\N	PRESENT	0
428446	416354	19545Y	PARTICIPANT	\N	PRESENT	0
428447	416354	11012A	PARTICIPANT	\N	PRESENT	0
428448	416354	07004J	PARTICIPANT	\N	PRESENT	0
428449	416354	14085U	PARTICIPANT	\N	PRESENT	0
428450	416354	19711U	PARTICIPANT	\N	PRESENT	0
428451	416354	11048N	PARTICIPANT	\N	PRESENT	0
428452	416354	11103C	PARTICIPANT	\N	PRESENT	0
428453	416354	19693L	PARTICIPANT	\N	PRESENT	0
428454	416354	14041T	PARTICIPANT	\N	PRESENT	0
428455	416354	01057W	PARTICIPANT	\N	PRESENT	0
428456	416354	04086Q	PARTICIPANT	\N	PRESENT	0
428457	416354	99004R	PARTICIPANT	\N	PRESENT	0
428458	416354	19667J	PARTICIPANT	\N	PRESENT	0
428459	416354	08061X	PARTICIPANT	\N	PRESENT	0
428460	416354	11074Q	PARTICIPANT	\N	PRESENT	0
428461	416354	08011M	PARTICIPANT	\N	PRESENT	0
428462	416354	14327T	PARTICIPANT	\N	PRESENT	0
428463	416354	19741B	PARTICIPANT	\N	PRESENT	0
428465	416354	04071H	PARTICIPANT	\N	PRESENT	0
428466	416354	19647E	PARTICIPANT	\N	PRESENT	0
428467	416354	12016W	PARTICIPANT	\N	PRESENT	0
428468	416354	19479G	PARTICIPANT	\N	PRESENT	0
428469	416354	14159V	PARTICIPANT	\N	PRESENT	0
428470	416354	14107H	PARTICIPANT	\N	PRESENT	0
428471	416354	19593H	PARTICIPANT	\N	PRESENT	0
428472	416354	14021P	PARTICIPANT	\N	PRESENT	0
428473	416354	19631V	PARTICIPANT	\N	PRESENT	0
428475	416354	04034C	PARTICIPANT	\N	PRESENT	0
428479	416354	04045F	PARTICIPANT	\N	PRESENT	0
428480	416354	08031R	PARTICIPANT	\N	PRESENT	0
428481	416354	19719D	PARTICIPANT	\N	PRESENT	0
428482	416354	19721W	PARTICIPANT	\N	PRESENT	0
428483	416354	19725B	PARTICIPANT	\N	PRESENT	0
428484	416354	08010L	PARTICIPANT	\N	PRESENT	0
428485	416354	14229S	PARTICIPANT	\N	PRESENT	0
428486	416354	19723Y	PARTICIPANT	\N	PRESENT	0
428533	428528	14213J	PARTICIPANT	\N	PRESENT	0
428534	428529	14213J	PARTICIPANT	\N	PRESENT	0
428535	428530	14213J	PARTICIPANT	\N	PRESENT	0
428536	428530	19569H	PARTICIPANT	\N	PRESENT	0
428537	428531	14213J	PARTICIPANT	\N	PRESENT	0
435688	425623	14207L	PARTICIPANT	\N	PRESENT	0
428541	428540	98029W	PARTICIPANT	\N	PRESENT	0
428543	428542	98029W	PARTICIPANT	\N	PRESENT	0
428545	428544	14227Q	PARTICIPANT	\N	PRESENT	0
428692	428691	19569H	PARTICIPANT	\N	PRESENT	0
428942	428941	19683J	PARTICIPANT	\N	PRESENT	0
433187	433185	96004D	PARTICIPANT	\N	PRESENT	0
433188	433185	14089Y	PARTICIPANT	\N	PRESENT	0
433189	433185	11083R	PARTICIPANT	\N	PRESENT	0
433190	433185	14097Y	PARTICIPANT	\N	PRESENT	0
433191	433185	14001X	PARTICIPANT	\N	PRESENT	0
433192	433185	14241N	PARTICIPANT	\N	PRESENT	0
433193	433185	04097T	PARTICIPANT	\N	PRESENT	0
433194	433185	10015M	PARTICIPANT	\N	PRESENT	0
433195	433185	14331P	PARTICIPANT	\N	PRESENT	0
433196	433185	19521Q	PARTICIPANT	\N	PRESENT	0
433197	433185	14083S	PARTICIPANT	\N	PRESENT	0
433198	433185	08045X	PARTICIPANT	\N	PRESENT	0
435547	425619	04044E	PARTICIPANT	\N	PRESENT	0
435548	434667	14327T	PARTICIPANT	\N	PRESENT	0
435549	434667	11048N	PARTICIPANT	\N	PRESENT	0
435550	434667	19479G	PARTICIPANT	\N	PRESENT	0
435551	434667	19711U	PARTICIPANT	\N	PRESENT	0
435552	434667	01048V	PARTICIPANT	\N	PRESENT	0
435553	434667	19531S	PARTICIPANT	\N	PRESENT	0
435554	434667	08034U	PARTICIPANT	\N	PRESENT	0
435555	434667	01057W	PARTICIPANT	\N	PRESENT	0
435556	434667	11074Q	PRESIDENT	0	PRESENT	0
435557	434667	08011M	PARTICIPANT	\N	PRESENT	0
435558	434667	08014Q	PARTICIPANT	\N	PRESENT	0
435559	434667	88008L	PARTICIPANT	\N	PRESENT	0
435560	434667	11040E	PARTICIPANT	\N	PRESENT	0
435561	434667	04086Q	PARTICIPANT	\N	PRESENT	0
435562	434667	14085U	PARTICIPANT	\N	PRESENT	0
435563	434667	07004J	PARTICIPANT	\N	PRESENT	0
435564	434667	19349W	PARTICIPANT	\N	PRESENT	0
435565	434667	19741B	PARTICIPANT	\N	PRESENT	0
435566	434667	14121F	PARTICIPANT	\N	PRESENT	0
435567	434667	14253S	PARTICIPANT	\N	PRESENT	0
435568	434667	99004R	PARTICIPANT	\N	PRESENT	0
435569	434667	14225N	PARTICIPANT	\N	PRESENT	0
435689	425623	14265W	PARTICIPANT	\N	PRESENT	0
435690	425623	19782L	PARTICIPANT	\N	PRESENT	0
435691	425623	10015M	PARTICIPANT	\N	PRESENT	0
435692	425623	88008L	PARTICIPANT	\N	PRESENT	0
435693	425623	19737F	PARTICIPANT	\N	PRESENT	0
435694	425623	95030B	PARTICIPANT	\N	PRESENT	0
435695	425623	01024M	PARTICIPANT	\N	PRESENT	0
435696	425623	01025N	PARTICIPANT	\N	PRESENT	0
435697	425623	19701S	PARTICIPANT	\N	PRESENT	0
435698	425623	14281W	PARTICIPANT	\N	PRESENT	0
435699	425623	19747H	PARTICIPANT	\N	PRESENT	0
435700	425623	11081P	PARTICIPANT	\N	PRESENT	0
435701	425623	14105F	PARTICIPANT	\N	PRESENT	0
435702	425623	01058X	PARTICIPANT	\N	PRESENT	0
435703	425623	19762G	PARTICIPANT	\N	PRESENT	0
435704	425623	04089T	PARTICIPANT	\N	PRESENT	0
435705	425623	19441R	PARTICIPANT	\N	PRESENT	0
435706	425623	19387D	PARTICIPANT	\N	PRESENT	0
435707	425623	98050T	PARTICIPANT	\N	PRESENT	0
435708	425623	18083K	PARTICIPANT	\N	PRESENT	0
435709	425623	19689Q	PARTICIPANT	\N	PRESENT	0
435710	425623	11056N	PARTICIPANT	\N	PRESENT	0
435711	425623	08039A	PARTICIPANT	\N	PRESENT	0
435712	425623	14111D	PARTICIPANT	\N	PRESENT	0
435713	425623	07029T	PARTICIPANT	\N	PRESENT	0
435714	425623	97011G	PARTICIPANT	\N	PRESENT	0
435715	425623	08015R	PARTICIPANT	\N	PRESENT	0
435716	425623	14151M	PARTICIPANT	\N	PRESENT	0
435717	425623	11054L	PARTICIPANT	\N	PRESENT	0
435718	425623	14237S	PARTICIPANT	\N	PRESENT	0
435719	425623	19695N	PARTICIPANT	\N	PRESENT	0
435720	425623	01043Q	PARTICIPANT	\N	PRESENT	0
435721	425623	14135M	PARTICIPANT	\N	PRESENT	0
435722	425623	19703U	PARTICIPANT	\N	PRESENT	0
435723	425623	19563B	PARTICIPANT	\N	PRESENT	0
435724	425623	19349W	PARTICIPANT	\N	PRESENT	0
435725	425623	08012N	PARTICIPANT	\N	PRESENT	0
435726	425623	14087W	PARTICIPANT	\N	PRESENT	0
435727	425623	14073Q	PARTICIPANT	\N	PRESENT	0
435728	425623	04043D	PARTICIPANT	\N	PRESENT	0
435729	425623	19507S	PARTICIPANT	\N	PRESENT	0
435730	425623	11048N	PARTICIPANT	\N	PRESENT	0
435731	425623	14034U	PARTICIPANT	\N	PRESENT	0
435732	425623	14221J	PARTICIPANT	\N	PRESENT	0
435733	425623	19768N	PARTICIPANT	\N	PRESENT	0
435734	425623	14261S	PARTICIPANT	\N	PRESENT	0
435737	425623	19723Y	PARTICIPANT	\N	PRESENT	0
435741	425623	14021P	PARTICIPANT	\N	PRESENT	0
450928	450927	11054L	PARTICIPANT	\N	PRESENT	0
450929	450927	14267Y	PARTICIPANT	\N	PRESENT	0
450930	450927	04034C	PARTICIPANT	\N	PRESENT	0
452282	450608	19335Q	PARTICIPANT	\N	PRESENT	0
452283	451967	14001X	PARTICIPANT	\N	PRESENT	0
452284	451967	19543W	PARTICIPANT	\N	PRESENT	0
452285	451967	04044E	PARTICIPANT	\N	PRESENT	0
452286	451967	19581D	PARTICIPANT	\N	PRESENT	0
452287	451967	04047H	PARTICIPANT	\N	PRESENT	0
452288	451967	01028R	PARTICIPANT	\N	PRESENT	0
452289	451967	05008E	PRESIDENT	0	PRESENT	0
452290	451967	19447X	PARTICIPANT	\N	PRESENT	0
452291	451967	19489J	PARTICIPANT	\N	PRESENT	0
452292	451967	14041T	PARTICIPANT	\N	PRESENT	0
452293	451967	14147R	PARTICIPANT	\N	PRESENT	0
452294	451967	14179A	PARTICIPANT	\N	PRESENT	0
452295	451967	14151M	PARTICIPANT	\N	PRESENT	0
452296	451967	14215L	PARTICIPANT	\N	PRESENT	0
452297	451967	08018U	PARTICIPANT	\N	PRESENT	0
452298	451967	14259Y	PARTICIPANT	\N	PRESENT	0
452299	451967	11072N	PARTICIPANT	\N	PRESENT	0
452300	451967	98035U	PARTICIPANT	\N	PRESENT	0
452301	451967	14053L	PARTICIPANT	\N	PRESENT	0
452302	451967	14111D	PARTICIPANT	\N	PRESENT	0
452303	451967	11010L	PARTICIPANT	\N	PRESENT	0
452304	451967	08045X	PARTICIPANT	\N	PRESENT	0
452305	451967	19253P	PARTICIPANT	\N	PRESENT	0
452306	451967	01024M	PARTICIPANT	\N	PRESENT	0
452307	451967	04038G	PARTICIPANT	\N	PRESENT	0
452308	451967	11033F	PARTICIPANT	\N	PRESENT	0
452309	451967	19725B	PARTICIPANT	\N	PRESENT	0
452310	451967	19729F	PARTICIPANT	\N	PRESENT	0
452311	451967	95063L	PARTICIPANT	\N	PRESENT	0
452312	451967	19629C	PARTICIPANT	\N	PRESENT	0
452313	451967	08044W	PARTICIPANT	\N	PRESENT	0
452314	451967	14069U	PARTICIPANT	\N	PRESENT	0
452315	451967	11085T	PARTICIPANT	\N	PRESENT	0
452316	451967	04008A	PARTICIPANT	\N	PRESENT	0
452317	451967	19762G	PARTICIPANT	\N	PRESENT	0
452318	451967	14021P	PARTICIPANT	\N	PRESENT	0
452319	451967	11026G	PARTICIPANT	\N	PRESENT	0
452320	451967	19585H	PARTICIPANT	\N	PRESENT	0
452321	451967	14231L	PARTICIPANT	\N	PRESENT	0
452329	450609	11110B	PARTICIPANT	\N	PRESENT	0
452330	450608	08039A	PARTICIPANT	\N	PRESENT	0
452331	450723	08061X	PARTICIPANT	\N	PRESENT	0
452332	450608	14123H	PARTICIPANT	\N	PRESENT	0
452365	451967	11049P	PARTICIPANT	\N	PRESENT	0
452366	449605	19527W	PARTICIPANT	\N	PRESENT	0
452367	449605	01034P	PARTICIPANT	\N	PRESENT	0
452368	449605	19717B	PARTICIPANT	\N	PRESENT	0
452369	449605	19723Y	PARTICIPANT	\N	PRESENT	0
452411	450711	11067R	PARTICIPANT	\N	PRESENT	0
452412	450711	19798U	PARTICIPANT	\N	PRESENT	0
452413	450711	11097X	PARTICIPANT	\N	PRESENT	0
452414	450711	19543W	PARTICIPANT	\N	PRESENT	0
452415	450711	19415P	PARTICIPANT	\N	PRESENT	0
452416	450711	01028R	PARTICIPANT	\N	PRESENT	0
452417	450711	19447X	PARTICIPANT	\N	PRESENT	0
452418	450711	05008E	PRESIDENT	0	PRESENT	0
452419	450711	11031D	PARTICIPANT	\N	PRESENT	0
452420	450711	19489J	PARTICIPANT	\N	PRESENT	0
452421	450711	14087W	PARTICIPANT	\N	PRESENT	0
452422	450711	14041T	PARTICIPANT	\N	PRESENT	0
452423	450711	19679N	PARTICIPANT	\N	PRESENT	0
452424	450711	14147R	PARTICIPANT	\N	PRESENT	0
452425	450711	14213J	PARTICIPANT	\N	PRESENT	0
452426	450711	19367Y	PARTICIPANT	\N	PRESENT	0
452427	450711	14215L	PARTICIPANT	\N	PRESENT	0
452428	450711	14261S	PARTICIPANT	\N	PRESENT	0
452429	450711	10006L	PARTICIPANT	\N	PRESENT	0
452430	450711	98024R	PARTICIPANT	\N	PRESENT	0
452431	450711	19527W	PARTICIPANT	\N	PRESENT	0
452432	450711	11010L	PARTICIPANT	\N	PRESENT	0
452433	450711	04092N	PARTICIPANT	\N	PRESENT	0
452434	450711	11045K	PARTICIPANT	\N	PRESENT	0
452435	450711	08045X	PARTICIPANT	\N	PRESENT	0
452436	450711	19253P	PARTICIPANT	\N	PRESENT	0
452437	450711	01024M	PARTICIPANT	\N	PRESENT	0
452438	450711	19715Y	PARTICIPANT	\N	PRESENT	0
452439	450711	14119M	PARTICIPANT	\N	PRESENT	0
452440	450711	19629C	PARTICIPANT	\N	PRESENT	0
452441	450711	08044W	PARTICIPANT	\N	PRESENT	0
452442	450711	11103C	PARTICIPANT	\N	PRESENT	0
452443	450711	19657G	PARTICIPANT	\N	PRESENT	0
452444	450711	14071N	PARTICIPANT	\N	PRESENT	0
452446	450711	04044E	PARTICIPANT	\N	EXCUSE	0
452447	450711	19565D	PARTICIPANT	\N	PRESENT	0
452448	450711	19703U	PARTICIPANT	\N	PRESENT	0
452449	450711	08048B	PARTICIPANT	\N	PRESENT	0
452450	450711	19691J	PARTICIPANT	\N	PRESENT	0
452451	450711	19760E	PARTICIPANT	\N	PRESENT	0
452452	449606	19565D	PARTICIPANT	\N	PRESENT	0
452453	449606	19798U	PARTICIPANT	\N	PRESENT	0
452454	449606	11097X	PARTICIPANT	\N	PRESENT	0
452455	449606	19415P	PARTICIPANT	\N	PRESENT	0
452456	449606	19543W	PARTICIPANT	\N	PRESENT	0
452457	449606	19581D	PARTICIPANT	\N	PRESENT	0
452458	449606	01028R	PARTICIPANT	\N	PRESENT	0
452459	449606	19447X	PARTICIPANT	\N	PRESENT	0
452460	449606	05008E	PARTICIPANT	\N	PRESENT	0
452461	449606	11031D	PARTICIPANT	\N	PRESENT	0
452462	449606	19703U	PARTICIPANT	\N	PRESENT	0
452463	449606	19489J	PARTICIPANT	\N	PRESENT	0
452464	449606	14087W	PARTICIPANT	\N	PRESENT	0
452465	449606	19679N	PARTICIPANT	\N	PRESENT	0
452466	449606	14041T	PARTICIPANT	\N	PRESENT	0
452467	449606	14042U	PARTICIPANT	\N	PRESENT	0
452468	449606	08048B	PARTICIPANT	\N	PRESENT	0
452469	449606	14147R	PARTICIPANT	\N	PRESENT	0
452470	449606	19367Y	PARTICIPANT	\N	PRESENT	0
452471	449606	14213J	PARTICIPANT	\N	PRESENT	0
452472	449606	14215L	PARTICIPANT	\N	PRESENT	0
452473	449606	10006L	PARTICIPANT	\N	PRESENT	0
452474	449606	19521Q	PARTICIPANT	\N	PRESENT	0
452475	449606	98024R	PARTICIPANT	\N	PRESENT	0
452476	449606	11072N	PARTICIPANT	\N	PRESENT	0
452477	449606	19527W	PARTICIPANT	\N	PRESENT	0
452478	449606	04092N	PRESIDENT	0	PRESENT	0
452479	449606	11010L	PARTICIPANT	\N	PRESENT	0
452480	449606	11045K	PARTICIPANT	\N	PRESENT	0
452481	449606	08045X	PARTICIPANT	\N	PRESENT	0
452482	449606	19253P	PARTICIPANT	\N	PRESENT	0
452483	449606	19301E	PARTICIPANT	\N	PRESENT	0
452484	449606	01024M	PARTICIPANT	\N	PRESENT	0
452485	449606	19715Y	PARTICIPANT	\N	PRESENT	0
452486	449606	19691J	PARTICIPANT	\N	PRESENT	0
452487	449606	14119M	PARTICIPANT	\N	PRESENT	0
452488	449606	19629C	PARTICIPANT	\N	PRESENT	0
452489	449606	11103C	PARTICIPANT	\N	PRESENT	0
452490	449606	08044W	PARTICIPANT	\N	PRESENT	0
452491	449606	14071N	PARTICIPANT	\N	PRESENT	0
452492	449606	19657G	PARTICIPANT	\N	PRESENT	0
452493	449606	19760E	PARTICIPANT	\N	PRESENT	0
452496	450612	19689Q	PARTICIPANT	\N	PRESENT	0
452497	449606	14179A	PARTICIPANT	\N	PRESENT	0
452498	449606	14261S	PARTICIPANT	\N	PRESENT	0
452499	450711	19581D	PARTICIPANT	\N	PRESENT	0
452500	450711	19553Y	PARTICIPANT	\N	PRESENT	0
452501	450711	14179A	PARTICIPANT	\N	PRESENT	0
452502	450711	19575F	PARTICIPANT	\N	PRESENT	0
452504	450711	11072N	PARTICIPANT	\N	PRESENT	0
452507	450837	19383Y	PARTICIPANT	\N	PRESENT	0
452508	450837	19333N	PARTICIPANT	\N	PRESENT	0
452509	450837	17583W	PARTICIPANT	\N	PRESENT	0
452510	450837	19701S	PARTICIPANT	\N	PRESENT	0
452511	450837	19794Q	PARTICIPANT	\N	PRESENT	0
452512	450837	19549D	PARTICIPANT	\N	PRESENT	0
452513	450837	19387D	PARTICIPANT	\N	PRESENT	0
452514	450837	19820Y	PARTICIPANT	\N	PRESENT	0
452515	450837	14219Q	PARTICIPANT	\N	PRESENT	0
452516	450837	19826F	PARTICIPANT	\N	PRESENT	0
452517	450837	14221J	PARTICIPANT	\N	PRESENT	0
452518	450837	19599P	PARTICIPANT	\N	PRESENT	0
452519	450837	19637C	PARTICIPANT	\N	PRESENT	0
452520	450837	02002K	PARTICIPANT	\N	PRESENT	0
452521	450837	18083K	PARTICIPANT	\N	PRESENT	0
452522	450837	14237S	PARTICIPANT	\N	PRESENT	0
452523	450837	19551W	PARTICIPANT	\N	PRESENT	0
452524	450837	05012A	PARTICIPANT	\N	PRESENT	0
452525	450837	14051J	PARTICIPANT	\N	PRESENT	0
452526	450837	08060W	PARTICIPANT	\N	PRESENT	0
452527	450837	19503N	PARTICIPANT	\N	PRESENT	0
452528	450837	19347U	PARTICIPANT	\N	PRESENT	0
452529	450837	14157T	PARTICIPANT	\N	PRESENT	0
452530	450837	08024S	PARTICIPANT	\N	PRESENT	0
452531	450837	19525U	PARTICIPANT	\N	PRESENT	0
424002	423958	19611R	PARTICIPANT	\N	PRESENT	0
424008	423958	19735D	PARTICIPANT	\N	PRESENT	0
424016	423958	14109K	PARTICIPANT	\N	PRESENT	0
424020	423958	92040Q	PARTICIPANT	\N	PRESENT	0
424026	423958	04018C	PARTICIPANT	\N	PRESENT	0
424087	424071	08039A	PARTICIPANT	\N	PRESENT	0
424193	424190	96004D	PRESIDENT	0	PRESENT	0
424195	424190	14089Y	PARTICIPANT	\N	PRESENT	0
424201	424190	14079W	PARTICIPANT	\N	PRESENT	0
424203	424190	14249W	PARTICIPANT	\N	PRESENT	0
424206	424190	11083R	PARTICIPANT	\N	PRESENT	0
424209	424190	14033T	PARTICIPANT	\N	PRESENT	0
424211	424190	14026U	PARTICIPANT	\N	PRESENT	0
424216	424190	19725B	PARTICIPANT	\N	PRESENT	0
424218	424190	95037J	PARTICIPANT	\N	PRESENT	0
424221	424190	19569H	PARTICIPANT	\N	PRESENT	0
424224	424190	04097T	PARTICIPANT	\N	PRESENT	0
424227	424190	14061L	PARTICIPANT	\N	EXCUSE	0
424230	424190	14097Y	PARTICIPANT	\N	PRESENT	0
424233	424190	14241N	PARTICIPANT	\N	PRESENT	0
424236	424190	14073Q	PARTICIPANT	\N	PRESENT	0
424240	424190	11026G	PARTICIPANT	\N	PRESENT	0
424243	424190	14205J	PARTICIPANT	\N	PRESENT	0
424245	424190	14001X	PARTICIPANT	\N	PRESENT	0
424247	424190	04057K	PARTICIPANT	\N	PRESENT	0
424254	424190	14237S	PARTICIPANT	\N	PRESENT	0
424259	424190	14135M	PARTICIPANT	\N	PRESENT	0
424260	424190	14331P	PARTICIPANT	\N	PRESENT	0
424261	424190	10015M	PARTICIPANT	\N	PRESENT	0
424263	424190	98035U	PARTICIPANT	\N	PRESENT	0
424285	424284	14123H	PARTICIPANT	\N	PRESENT	0
426124	424896	14259Y	PARTICIPANT	\N	EXCUSE	0
424287	424284	08043V	PARTICIPANT	\N	PRESENT	0
424291	424290	11026G	PARTICIPANT	\N	PRESENT	0
427400	416322	19503N	PARTICIPANT	\N	PRESENT	0
427401	416322	08020N	PARTICIPANT	\N	PRESENT	0
427402	416322	14133K	PARTICIPANT	\N	PRESENT	0
427404	416322	14021P	PARTICIPANT	\N	PRESENT	0
427405	416322	19671E	PARTICIPANT	\N	PRESENT	0
427406	416322	18083K	PARTICIPANT	\N	PRESENT	0
427407	416322	14121F	PARTICIPANT	\N	PRESENT	0
427408	416322	01057W	PARTICIPANT	\N	PRESENT	0
427409	416322	14249W	PARTICIPANT	\N	PRESENT	0
427410	416322	10015M	PARTICIPANT	\N	PRESENT	0
427411	416322	97011G	PARTICIPANT	\N	PRESENT	0
427412	423927	14357A	PARTICIPANT	\N	PRESENT	0
427413	423927	19269X	PARTICIPANT	\N	PRESENT	0
427414	416322	07029T	PARTICIPANT	\N	PRESENT	0
427415	416322	19441R	PARTICIPANT	\N	PRESENT	0
427416	416322	19253P	PARTICIPANT	\N	PRESENT	0
427417	416322	01028R	PARTICIPANT	\N	PRESENT	0
427418	416322	19741B	PARTICIPANT	\N	PRESENT	0
427419	416322	17583W	PARTICIPANT	\N	PRESENT	0
427420	416322	08034U	PARTICIPANT	\N	PRESENT	0
427421	416322	11012A	PARTICIPANT	\N	PRESENT	0
427649	414419	08062Y	PARTICIPANT	\N	PRESENT	0
427650	414419	14147R	PARTICIPANT	\N	PRESENT	0
427651	414419	14107H	PARTICIPANT	\N	EXCUSE	0
427652	414419	19713W	PARTICIPANT	\N	PRESENT	0
427832	423006	19737F	PARTICIPANT	\N	PRESENT	0
427833	423006	99004R	PRESIDENT	0	PRESENT	0
428184	422994	19691J	PARTICIPANT	\N	EXCUSE	0
428279	428278	01048V	PARTICIPANT	\N	PRESENT	0
428281	428280	14133K	PARTICIPANT	\N	PRESENT	0
428283	428282	95030B	PARTICIPANT	\N	PRESENT	0
428285	428284	08012N	PARTICIPANT	\N	PRESENT	0
428359	428358	14069U	PARTICIPANT	\N	PRESENT	0
428360	428358	08058D	PARTICIPANT	\N	PRESENT	0
428361	428358	04044E	PARTICIPANT	\N	PRESENT	0
428362	428358	14157T	PARTICIPANT	\N	PRESENT	0
428363	428358	14331P	PARTICIPANT	\N	PRESENT	0
428365	428364	14069U	PARTICIPANT	\N	PRESENT	0
430299	422993	19631V	PARTICIPANT	\N	EXCUSE	0
430300	422993	14259Y	PARTICIPANT	\N	EXCUSE	0
430301	422993	19729F	PARTICIPANT	\N	EXCUSE	0
430304	422993	14059S	PARTICIPANT	\N	EXCUSE	0
430761	430759	19503N	PARTICIPANT	\N	PRESENT	0
430987	428245	19479G	PARTICIPANT	\N	PRESENT	0
430988	428245	19711U	PARTICIPANT	\N	PRESENT	0
430989	428245	01057W	PARTICIPANT	\N	PRESENT	0
430990	428245	11053K	PARTICIPANT	\N	PRESENT	0
430991	428245	11074Q	PRESIDENT	0	PRESENT	0
430992	428245	08011M	PARTICIPANT	\N	PRESENT	0
430993	428245	14225N	PARTICIPANT	\N	PRESENT	0
430994	428245	11070L	PARTICIPANT	\N	PRESENT	0
430995	428245	11040E	PARTICIPANT	\N	PRESENT	0
430996	428245	04086Q	PARTICIPANT	\N	PRESENT	0
430997	428245	14083S	PARTICIPANT	\N	PRESENT	0
430998	428245	07004J	PARTICIPANT	\N	PRESENT	0
430999	428245	96004D	PARTICIPANT	\N	PRESENT	0
431000	428245	19741B	PARTICIPANT	\N	PRESENT	0
431001	428245	99004R	PARTICIPANT	\N	PRESENT	0
431002	428245	88008L	PARTICIPANT	\N	PRESENT	0
431003	428245	14085U	PARTICIPANT	\N	PRESENT	0
431004	428245	08010L	PARTICIPANT	\N	PRESENT	0
431005	428245	08034U	PARTICIPANT	\N	PRESENT	0
431006	428245	01048V	PARTICIPANT	\N	PRESENT	0
431007	428245	19651A	PARTICIPANT	\N	PRESENT	0
431008	428245	07029T	PARTICIPANT	\N	PRESENT	0
431009	428245	04071H	PARTICIPANT	\N	PRESENT	0
431015	423006	19369B	PARTICIPANT	\N	PRESENT	0
431020	423006	19479G	PARTICIPANT	\N	PRESENT	0
431021	424871	11072N	PARTICIPANT	\N	PRESENT	0
431022	424871	08011M	PARTICIPANT	\N	PRESENT	0
431023	424871	11074Q	PARTICIPANT	\N	PRESENT	0
431024	424871	88008L	PARTICIPANT	\N	PRESENT	0
431025	424871	14225N	PARTICIPANT	\N	PRESENT	0
431026	424871	99004R	PARTICIPANT	\N	PRESENT	0
431027	424871	11070L	PARTICIPANT	\N	PRESENT	0
431028	424871	14085U	PARTICIPANT	\N	PRESENT	0
431029	424871	11040E	PARTICIPANT	\N	PRESENT	0
431030	424871	11012A	PARTICIPANT	\N	PRESENT	0
431031	424871	19349W	PARTICIPANT	\N	PRESENT	0
431032	424871	14119M	PARTICIPANT	\N	PRESENT	0
431033	424871	19711U	PARTICIPANT	\N	PRESENT	0
431034	424871	19687N	PARTICIPANT	\N	PRESENT	0
431035	424871	04085P	PARTICIPANT	\N	PRESENT	0
431036	424871	19651A	PARTICIPANT	\N	PRESENT	0
431037	424871	19503N	PARTICIPANT	\N	PRESENT	0
431038	424871	07029T	PARTICIPANT	\N	PRESENT	0
431039	424871	04086Q	PARTICIPANT	\N	PRESENT	0
431040	424871	19667J	PARTICIPANT	\N	PRESENT	0
431041	424871	19741B	PARTICIPANT	\N	PRESENT	0
431042	424871	04034C	PARTICIPANT	\N	PRESENT	0
431043	424871	01057W	PARTICIPANT	\N	PRESENT	0
431044	424871	12016W	PARTICIPANT	\N	PRESENT	0
431045	424871	19647E	PARTICIPANT	\N	PRESENT	0
431046	424871	19689Q	PARTICIPANT	\N	PRESENT	0
431048	424871	04057K	PARTICIPANT	\N	PRESENT	0
431049	424871	98050T	PARTICIPANT	\N	PRESENT	0
431050	424871	14261S	PARTICIPANT	\N	PRESENT	0
431053	424871	08034U	PARTICIPANT	\N	PRESENT	0
431054	424871	19479G	PARTICIPANT	\N	PRESENT	0
431055	424871	01048V	PARTICIPANT	\N	PRESENT	0
431056	424871	04044E	PARTICIPANT	\N	PRESENT	0
431057	424871	08017T	PARTICIPANT	\N	PRESENT	0
431060	424871	08019V	PARTICIPANT	\N	PRESENT	0
431061	424871	08073C	PARTICIPANT	\N	PRESENT	0
431064	424871	14089Y	PARTICIPANT	\N	PRESENT	0
431065	424871	11043H	PARTICIPANT	\N	PRESENT	0
431066	424871	11065P	PARTICIPANT	\N	PRESENT	0
431067	424871	19583F	PARTICIPANT	\N	PRESENT	0
431068	424871	19301E	PARTICIPANT	\N	PRESENT	0
431069	424871	19295A	PARTICIPANT	\N	PRESENT	0
431073	424871	04071H	PARTICIPANT	\N	PRESENT	0
431074	424871	14039A	PARTICIPANT	\N	PRESENT	0
427392	425130	11012A	PARTICIPANT	\N	PRESENT	0
427393	425130	14085U	PARTICIPANT	\N	PRESENT	0
427394	425130	19349W	PARTICIPANT	\N	PRESENT	0
427395	425130	14121F	PARTICIPANT	\N	PRESENT	0
427396	425130	08010L	PARTICIPANT	\N	PRESENT	0
427397	425130	11048N	PARTICIPANT	\N	PRESENT	0
427398	425130	99004R	PARTICIPANT	\N	PRESENT	0
427399	416322	19691J	PARTICIPANT	\N	PRESENT	0
431075	424871	14021P	PARTICIPANT	\N	PRESENT	0
431076	424871	96004D	PARTICIPANT	\N	PRESENT	0
431077	424871	11026G	PARTICIPANT	\N	PRESENT	0
431078	424871	11053K	PARTICIPANT	\N	PRESENT	0
431080	423006	19515S	PARTICIPANT	\N	EXCUSE	0
431082	424871	19443T	PARTICIPANT	\N	PRESENT	0
431083	424871	11085T	PARTICIPANT	\N	PRESENT	0
431084	424871	08069G	PARTICIPANT	\N	PRESENT	0
450970	450969	19421M	PARTICIPANT	\N	PRESENT	0
453383	448738	19782L	PARTICIPANT	\N	PRESENT	0
453384	450728	14115H	PARTICIPANT	\N	PRESENT	0
453385	450728	19747H	PARTICIPANT	\N	PRESENT	0
453386	448738	14239U	PARTICIPANT	\N	PRESENT	0
453387	450728	19619A	PARTICIPANT	\N	PRESENT	0
453388	450943	19705W	PARTICIPANT	\N	PRESENT	0
453389	450943	19619A	PARTICIPANT	\N	PRESENT	0
453390	448738	14069U	PARTICIPANT	\N	PRESENT	0
453391	448738	14059S	PARTICIPANT	\N	PRESENT	0
453392	448738	19657G	PARTICIPANT	\N	PRESENT	0
453393	448738	19599P	PARTICIPANT	\N	PRESENT	0
453394	448738	95037J	PARTICIPANT	\N	PRESENT	0
453395	448738	14249W	PARTICIPANT	\N	PRESENT	0
453396	448738	14265W	PARTICIPANT	\N	PRESENT	0
453448	448739	14261S	PARTICIPANT	\N	PRESENT	0
453449	448739	04092N	PARTICIPANT	\N	PRESENT	0
453450	448739	19697Q	PARTICIPANT	\N	PRESENT	0
453451	448739	19543W	PARTICIPANT	\N	PRESENT	0
453452	448739	19565D	PARTICIPANT	\N	PRESENT	0
453453	448739	19758L	PARTICIPANT	\N	PRESENT	0
453454	448739	19683J	PARTICIPANT	\N	PRESENT	0
453455	448739	19503N	PARTICIPANT	\N	PRESENT	0
453456	448739	19651A	PARTICIPANT	\N	PRESENT	0
453457	448739	19637C	PARTICIPANT	\N	PRESENT	0
453458	448739	19812Y	PARTICIPANT	\N	PRESENT	0
453459	448739	19782L	PARTICIPANT	\N	PRESENT	0
453460	448739	17589D	PARTICIPANT	\N	PRESENT	0
453461	448739	19735D	PARTICIPANT	\N	PRESENT	0
453462	448739	19691J	PARTICIPANT	\N	PRESENT	0
453463	448739	01024M	PARTICIPANT	\N	PRESENT	0
453464	448739	14215L	PARTICIPANT	\N	PRESENT	0
453465	448739	14059S	PARTICIPANT	\N	PRESENT	0
453466	448739	19575F	PARTICIPANT	\N	PRESENT	0
453467	448739	14265W	PARTICIPANT	\N	PRESENT	0
453468	448739	14071N	PARTICIPANT	\N	PRESENT	0
453469	448739	14147R	PARTICIPANT	\N	PRESENT	0
453470	448739	19447X	PARTICIPANT	\N	PRESENT	0
453471	448739	14157T	PARTICIPANT	\N	PRESENT	0
453472	448739	04088S	PARTICIPANT	\N	PRESENT	0
453473	448739	19599P	PARTICIPANT	\N	PRESENT	0
453474	448739	11067R	PARTICIPANT	\N	PRESENT	0
453475	448739	98024R	PARTICIPANT	\N	PRESENT	0
453476	448739	14249W	PARTICIPANT	\N	PRESENT	0
453477	448739	04069P	PARTICIPANT	\N	PRESENT	0
453478	448739	11048N	PARTICIPANT	\N	PRESENT	0
453479	448739	14069U	PARTICIPANT	\N	PRESENT	0
453480	450728	14097Y	PARTICIPANT	\N	PRESENT	0
453481	450943	14097Y	PARTICIPANT	\N	PRESENT	0
453482	448739	14239U	PARTICIPANT	\N	PRESENT	0
453483	448739	95063L	PARTICIPANT	\N	PRESENT	0
453484	448739	19533U	PARTICIPANT	\N	PRESENT	0
453485	448739	01057W	PARTICIPANT	\N	PRESENT	0
453486	448739	97011G	PARTICIPANT	\N	PRESENT	0
453491	448739	19479G	PARTICIPANT	\N	PRESENT	0
453492	448739	14073Q	PARTICIPANT	\N	PRESENT	0
453495	448739	08020N	PARTICIPANT	\N	PRESENT	0
453499	448739	14083S	PARTICIPANT	\N	PRESENT	0
453501	448739	19467C	PARTICIPANT	\N	PRESENT	0
453502	448739	11012A	PARTICIPANT	\N	PRESENT	0
453503	448739	19820Y	PARTICIPANT	\N	PRESENT	0
453509	448739	01025N	PARTICIPANT	\N	PRESENT	0
453511	448739	14033T	PARTICIPANT	\N	PRESENT	0
453512	448739	19657G	PARTICIPANT	\N	PRESENT	0
453446	448739	14034U	PARTICIPANT	\N	PRESENT	0
453447	450728	14133K	PRESIDENT	1	PRESENT	0
453513	448739	19611R	PARTICIPANT	\N	PRESENT	0
453514	448739	19737F	PARTICIPANT	\N	PRESENT	0
453515	448739	14030Q	PARTICIPANT	\N	PRESENT	0
453516	448739	11097X	PARTICIPANT	\N	PRESENT	0
453517	448739	14193X	PARTICIPANT	\N	PRESENT	0
453518	448739	19413M	PARTICIPANT	\N	PRESENT	0
453519	448739	14217N	PARTICIPANT	\N	PRESENT	0
453654	448741	14021P	PARTICIPANT	\N	PRESENT	0
453655	448741	19669L	PARTICIPANT	\N	PRESENT	0
453656	448741	19301E	PARTICIPANT	\N	PRESENT	0
453657	448741	12016W	PARTICIPANT	\N	PRESENT	0
453658	448741	19689Q	PARTICIPANT	\N	PRESENT	0
453659	448741	80013X	PARTICIPANT	\N	PRESENT	0
453660	448741	11040E	PARTICIPANT	\N	PRESENT	0
453661	448741	19441R	PARTICIPANT	\N	PRESENT	0
453662	448741	19369B	PARTICIPANT	\N	PRESENT	0
453663	448741	14215L	PARTICIPANT	\N	PRESENT	0
453665	453664	19631V	PARTICIPANT	\N	PRESENT	0
453666	453664	14085U	PARTICIPANT	\N	PRESENT	0
453667	453664	04038G	PARTICIPANT	\N	PRESENT	0
453668	453664	14215L	PRESIDENT	1	PRESENT	0
453652	448741	04059M	PARTICIPANT	\N	PRESENT	0
453653	448741	04085P	PARTICIPANT	\N	PRESENT	0
453669	453664	14087W	PRESIDENT	0	PRESENT	0
453670	448741	14217N	PARTICIPANT	\N	PRESENT	0
453671	453664	19711U	PARTICIPANT	\N	PRESENT	0
453672	453664	14059S	PARTICIPANT	\N	PRESENT	0
453673	448741	08034U	PARTICIPANT	\N	PRESENT	0
453674	453664	14265W	PARTICIPANT	\N	PRESENT	0
453676	453664	95063L	PARTICIPANT	\N	PRESENT	0
453677	453664	14229S	PARTICIPANT	\N	PRESENT	0
453678	448741	19711U	PARTICIPANT	\N	PRESENT	0
453679	453664	01028R	PARTICIPANT	\N	PRESENT	0
453680	448741	08010L	PARTICIPANT	\N	PRESENT	0
453681	453664	19479G	PARTICIPANT	\N	PRESENT	0
453682	453664	19585H	PARTICIPANT	\N	PRESENT	0
453683	453664	19575F	PARTICIPANT	\N	EXCUSE	0
453684	453664	19782L	PARTICIPANT	\N	EXCUSE	0
453685	453664	19253P	PARTICIPANT	\N	EXCUSE	0
453686	453664	11056N	PARTICIPANT	\N	EXCUSE	0
453687	453664	19333N	PARTICIPANT	\N	EXCUSE	0
453688	453664	19521Q	PARTICIPANT	\N	EXCUSE	0
453689	453664	14219Q	PARTICIPANT	\N	EXCUSE	0
453690	453664	19349W	PARTICIPANT	\N	EXCUSE	0
453691	448741	14038Y	PARTICIPANT	\N	PRESENT	0
453692	448741	19619A	PARTICIPANT	\N	PRESENT	0
453693	448741	14147R	PARTICIPANT	\N	PRESENT	0
453694	448741	19289C	PARTICIPANT	\N	PRESENT	0
453695	448741	19695N	PARTICIPANT	\N	PRESENT	0
453696	448741	19593H	PARTICIPANT	\N	PRESENT	0
453697	448741	11031D	PARTICIPANT	\N	PRESENT	0
453698	448741	19347U	PARTICIPANT	\N	PRESENT	0
453699	448741	11033F	PARTICIPANT	\N	PRESENT	0
453700	448741	14237S	PARTICIPANT	\N	PRESENT	0
453701	448741	14069U	PARTICIPANT	\N	PRESENT	0
453702	448741	19543W	PARTICIPANT	\N	PRESENT	0
453703	448741	19573D	PARTICIPANT	\N	PRESENT	0
453704	448741	14169X	PARTICIPANT	\N	PRESENT	0
453705	446001	14261S	PARTICIPANT	\N	PRESENT	0
453706	446001	14030Q	PRESIDENT	0	PRESENT	0
453707	446001	08043V	PARTICIPANT	\N	EXCUSE	0
453708	446001	08024S	PARTICIPANT	\N	EXCUSE	0
453709	446001	19693L	PARTICIPANT	\N	PRESENT	0
453710	446001	14217N	PARTICIPANT	\N	PRESENT	0
453711	446001	19715Y	PARTICIPANT	\N	PRESENT	0
453712	446001	19731Y	PARTICIPANT	\N	EXCUSE	0
453713	446001	08031R	PARTICIPANT	\N	PRESENT	0
453714	446001	11067R	PARTICIPANT	\N	PRESENT	0
453715	446001	11045K	PARTICIPANT	\N	PRESENT	0
453716	448741	19399H	PARTICIPANT	\N	PRESENT	0
453717	448741	01028R	PARTICIPANT	\N	PRESENT	0
453718	453675	18083K	PARTICIPANT	\N	PRESENT	0
453719	453675	04049K	PARTICIPANT	\N	PRESENT	0
453720	453675	08017T	PARTICIPANT	\N	PRESENT	0
453721	453675	04070G	PARTICIPANT	\N	PRESENT	0
453722	448741	19725B	PARTICIPANT	\N	PRESENT	0
453723	448741	19820Y	PARTICIPANT	\N	PRESENT	0
453724	448741	19631V	PARTICIPANT	\N	PRESENT	0
453725	448741	14205J	PARTICIPANT	\N	PRESENT	0
453726	449855	19631V	PARTICIPANT	\N	PRESENT	0
453727	449855	96004D	PARTICIPANT	\N	PRESENT	0
453728	449855	19583F	PARTICIPANT	\N	PRESENT	0
453729	449855	14039A	PARTICIPANT	\N	PRESENT	0
453730	449855	14059S	PARTICIPANT	\N	PRESENT	0
453731	449855	12016W	PARTICIPANT	\N	PRESENT	0
453732	449855	08019V	PRESIDENT	0	PRESENT	0
453733	449855	19657G	PARTICIPANT	\N	EXCUSE	0
453734	449855	11054L	PARTICIPANT	\N	EXCUSE	0
453735	449855	19301E	PARTICIPANT	\N	PRESENT	0
453736	448741	14251Q	PARTICIPANT	\N	PRESENT	0
453737	448741	04043D	PARTICIPANT	\N	PRESENT	0
453738	448741	14087W	PARTICIPANT	\N	PRESENT	0
453739	448741	19671E	PARTICIPANT	\N	PRESENT	0
453740	448741	11067R	PARTICIPANT	\N	PRESENT	0
453741	448741	04038G	PARTICIPANT	\N	PRESENT	0
453743	448741	19583F	PARTICIPANT	\N	PRESENT	0
453744	448741	19507S	PARTICIPANT	\N	PRESENT	0
453745	448741	97011G	PARTICIPANT	\N	PRESENT	0
453746	448741	98050T	PARTICIPANT	\N	PRESENT	0
453747	448741	11012A	PARTICIPANT	\N	PRESENT	0
453748	445946	14147R	PARTICIPANT	\N	PRESENT	0
453749	445946	19711U	PARTICIPANT	\N	PRESENT	0
453750	448741	19447X	PARTICIPANT	\N	PRESENT	0
435745	425623	19503N	PARTICIPANT	\N	PRESENT	0
435747	425623	19693L	PARTICIPANT	\N	PRESENT	0
435748	425623	19521Q	PARTICIPANT	\N	PRESENT	0
435749	425623	19798U	PARTICIPANT	\N	PRESENT	0
435750	425623	19511N	PARTICIPANT	\N	PRESENT	0
435751	425623	08028W	PARTICIPANT	\N	PRESENT	0
435752	425623	04069P	PARTICIPANT	\N	PRESENT	0
435753	425623	14133K	PARTICIPANT	\N	PRESENT	0
435754	425623	19413M	PARTICIPANT	\N	PRESENT	0
435755	425623	01057W	PARTICIPANT	\N	PRESENT	0
435756	425623	14061L	PARTICIPANT	\N	PRESENT	0
435757	425623	08069G	PARTICIPANT	\N	PRESENT	0
435758	425623	19671E	PARTICIPANT	\N	PRESENT	0
435759	425623	19383Y	PARTICIPANT	\N	PRESENT	0
435760	425623	14030Q	PARTICIPANT	\N	PRESENT	0
435761	425623	11043H	PARTICIPANT	\N	PRESENT	0
435762	425623	19525U	PARTICIPANT	\N	PRESENT	0
435763	425623	19531S	PARTICIPANT	\N	PRESENT	0
435764	425623	19735D	PARTICIPANT	\N	PRESENT	0
435765	425623	14199E	PARTICIPANT	\N	PRESENT	0
435766	425623	19621T	PARTICIPANT	\N	PRESENT	0
435767	425623	11101A	PARTICIPANT	\N	PRESENT	0
435769	425623	14053L	PARTICIPANT	\N	PRESENT	0
435772	425623	19533U	PARTICIPANT	\N	PRESENT	0
435774	425623	04097T	PARTICIPANT	\N	PRESENT	0
435777	425623	19573D	PARTICIPANT	\N	PRESENT	0
435778	425623	19467C	PARTICIPANT	\N	PRESENT	0
435780	425623	19569H	PARTICIPANT	\N	PRESENT	0
435781	425623	14205J	PARTICIPANT	\N	PRESENT	0
435782	425623	11067R	PARTICIPANT	\N	PRESENT	0
435784	425623	19667J	PARTICIPANT	\N	PRESENT	0
435785	425623	14031R	PARTICIPANT	\N	PRESENT	0
435788	425623	14042U	PARTICIPANT	\N	PRESENT	0
435789	425623	08010L	PARTICIPANT	\N	PRESENT	0
435790	425623	14041T	PARTICIPANT	\N	PRESENT	0
435791	425623	19739H	PARTICIPANT	\N	PRESENT	0
435792	425623	19415P	PARTICIPANT	\N	PRESENT	0
435795	425623	11012A	PARTICIPANT	\N	PRESENT	0
435796	433574	14053L	PARTICIPANT	\N	PRESENT	0
435797	433574	11048N	PARTICIPANT	\N	PRESENT	0
435798	433574	14051J	PARTICIPANT	\N	PRESENT	0
435799	433574	08060W	PARTICIPANT	\N	PRESENT	0
435800	433574	95067Q	PARTICIPANT	\N	PRESENT	0
435801	433574	08009T	PRESIDENT	0	PRESENT	0
435802	433574	19826F	PARTICIPANT	\N	PRESENT	0
435803	433574	14026U	PARTICIPANT	\N	PRESENT	0
435804	433574	11065P	PARTICIPANT	\N	PRESENT	0
435805	433574	04070G	PARTICIPANT	\N	EXCUSE	0
435806	433574	19367Y	PARTICIPANT	\N	EXCUSE	0
435807	425623	08053X	PARTICIPANT	\N	PRESENT	0
435808	433574	19251M	PARTICIPANT	\N	PRESENT	0
435809	425623	19715Y	PARTICIPANT	\N	PRESENT	0
435810	425623	14257W	PARTICIPANT	\N	PRESENT	0
435812	425623	08061X	PARTICIPANT	\N	PRESENT	0
435813	425623	14215L	PARTICIPANT	\N	PRESENT	0
435814	425623	11103C	PARTICIPANT	\N	PRESENT	0
435815	425623	19369B	PARTICIPANT	\N	PRESENT	0
435816	425623	14217N	PARTICIPANT	\N	PRESENT	0
435818	434570	19673G	PARTICIPANT	\N	PRESENT	0
435819	434570	19719D	PRESIDENT	0	PRESENT	0
435820	434570	04040A	PARTICIPANT	\N	EXCUSE	0
435821	434570	08053X	PARTICIPANT	\N	PRESENT	0
435822	425623	19335Q	PARTICIPANT	\N	PRESENT	0
435831	425623	14147R	PARTICIPANT	\N	PRESENT	0
435832	425623	14267Y	PARTICIPANT	\N	PRESENT	0
435833	425623	19713W	PARTICIPANT	\N	PRESENT	0
435834	425623	14173T	PARTICIPANT	\N	PRESENT	0
435848	434570	04044E	PARTICIPANT	\N	PRESENT	0
435836	434570	11080N	PARTICIPANT	\N	PRESENT	0
435837	434570	19421M	PARTICIPANT	\N	PRESENT	0
435838	434570	07004J	PARTICIPANT	\N	PRESENT	0
435839	434570	10015M	PARTICIPANT	\N	PRESENT	0
435840	434570	08010L	PARTICIPANT	\N	PRESENT	0
435841	434570	19669L	PARTICIPANT	\N	PRESENT	0
435842	434570	14249W	PARTICIPANT	\N	PRESENT	0
435843	434570	19721W	PARTICIPANT	\N	PRESENT	0
435844	434570	04085P	PARTICIPANT	\N	PRESENT	0
435845	433574	19413M	PARTICIPANT	\N	PRESENT	0
435846	425623	19691J	PARTICIPANT	\N	PRESENT	0
435847	425623	98022P	PARTICIPANT	\N	PRESENT	0
435849	434570	08056B	PARTICIPANT	\N	PRESENT	0
435855	425623	08062Y	PARTICIPANT	\N	PRESENT	0
435856	425623	11097X	PARTICIPANT	\N	PRESENT	0
435864	425623	14083S	PARTICIPANT	\N	PRESENT	0
435865	435632	11067R	PARTICIPANT	\N	PRESENT	0
435866	435632	14065Q	PARTICIPANT	\N	PRESENT	0
435867	435632	04092N	PRESIDENT	0	PRESENT	0
435868	435632	19569H	PARTICIPANT	\N	PRESENT	0
435869	435632	08052W	PARTICIPANT	\N	PRESENT	0
435870	435632	19415P	PARTICIPANT	\N	PRESENT	0
435871	435632	11066Q	PARTICIPANT	\N	PRESENT	0
435872	435632	04045F	PARTICIPANT	\N	PRESENT	0
435873	435632	18083K	PARTICIPANT	\N	PRESENT	0
435874	435632	19553Y	PARTICIPANT	\N	PRESENT	0
435875	435632	14042U	PARTICIPANT	\N	PRESENT	0
435876	435632	14179A	PARTICIPANT	\N	PRESENT	0
435877	435632	14195A	PARTICIPANT	\N	PRESENT	0
435878	435632	14213J	PARTICIPANT	\N	PRESENT	0
435879	435632	14215L	PARTICIPANT	\N	PRESENT	0
435880	435632	14217N	PARTICIPANT	\N	PRESENT	0
435881	435632	19335Q	PARTICIPANT	\N	PRESENT	0
435884	425623	14026U	PARTICIPANT	\N	PRESENT	0
435885	425623	14159V	PARTICIPANT	\N	PRESENT	0
435886	425623	08052W	PARTICIPANT	\N	PRESENT	0
435887	425623	19269X	PARTICIPANT	\N	PRESENT	0
435898	425623	11064N	PARTICIPANT	\N	PRESENT	0
435899	425623	08019V	PARTICIPANT	\N	PRESENT	0
435976	425625	11027H	PARTICIPANT	\N	PRESENT	0
435977	425625	08069G	PARTICIPANT	\N	PRESENT	0
435978	425625	08014Q	PARTICIPANT	\N	PRESENT	0
435979	425625	19503N	PARTICIPANT	\N	PRESENT	0
435980	425625	19269X	PARTICIPANT	\N	PRESENT	0
435981	425625	19782L	PARTICIPANT	\N	PRESENT	0
435982	425625	14159V	PARTICIPANT	\N	PRESENT	0
435983	425625	14107H	PARTICIPANT	\N	PRESENT	0
435984	425625	14121F	PARTICIPANT	\N	PRESENT	0
435985	425625	19629C	PARTICIPANT	\N	PRESENT	0
435986	425625	19387D	PARTICIPANT	\N	PRESENT	0
435987	425625	14207L	PARTICIPANT	\N	PRESENT	0
435988	425625	19563B	PARTICIPANT	\N	PRESENT	0
435989	425625	11064N	PARTICIPANT	\N	PRESENT	0
435990	425625	14257W	PARTICIPANT	\N	PRESENT	0
435991	425625	19631V	PARTICIPANT	\N	PRESENT	0
435992	425625	19413M	PARTICIPANT	\N	PRESENT	0
435993	425625	19511N	PARTICIPANT	\N	PRESENT	0
435994	425625	14327T	PARTICIPANT	\N	PRESENT	0
435995	425625	19739H	PARTICIPANT	\N	PRESENT	0
435996	425625	14042U	PARTICIPANT	\N	PRESENT	0
435997	425625	01043Q	PARTICIPANT	\N	PRESENT	0
435998	425625	14205J	PARTICIPANT	\N	PRESENT	0
435999	425625	19735D	PARTICIPANT	\N	PRESENT	0
436000	425625	01025N	PARTICIPANT	\N	PRESENT	0
436001	425625	01024M	PARTICIPANT	\N	PRESENT	0
436002	425625	19737F	PARTICIPANT	\N	PRESENT	0
436003	425625	14261S	PARTICIPANT	\N	PRESENT	0
436004	425625	97011G	PARTICIPANT	\N	PRESENT	0
436005	425625	19533U	PARTICIPANT	\N	PRESENT	0
436006	425625	19693L	PARTICIPANT	\N	PRESENT	0
436007	435632	14147R	PARTICIPANT	\N	PRESENT	0
436008	425625	95030B	PARTICIPANT	\N	PRESENT	0
436009	425625	11101A	PARTICIPANT	\N	PRESENT	0
436010	425625	11099A	PARTICIPANT	\N	PRESENT	0
436011	425625	19507S	PARTICIPANT	\N	PRESENT	0
436012	425625	14133K	PARTICIPANT	\N	PRESENT	0
436013	425625	14033T	PARTICIPANT	\N	PRESENT	0
436014	425625	19467C	PARTICIPANT	\N	PRESENT	0
436015	425625	19723Y	PARTICIPANT	\N	PRESENT	0
436016	425625	19515S	PARTICIPANT	\N	PRESENT	0
436017	425625	19703U	PARTICIPANT	\N	PRESENT	0
436018	425625	19621T	PARTICIPANT	\N	PRESENT	0
436019	425625	08056B	PARTICIPANT	\N	PRESENT	0
436020	425625	14038Y	PARTICIPANT	\N	PRESENT	0
436021	435632	19447X	PARTICIPANT	\N	PRESENT	0
436022	435632	01048V	PARTICIPANT	\N	PRESENT	0
436023	425625	14115H	PARTICIPANT	\N	PRESENT	0
436024	425625	04088S	PARTICIPANT	\N	PRESENT	0
436025	425625	11097X	PARTICIPANT	\N	PRESENT	0
436026	425625	19349W	PARTICIPANT	\N	PRESENT	0
436027	435632	19681G	PARTICIPANT	\N	EXCUSE	0
436028	425625	14265W	PARTICIPANT	\N	PRESENT	0
436029	425625	19719D	PARTICIPANT	\N	PRESENT	0
450120	449601	11104D	PARTICIPANT	\N	EXCUSE	0
450150	450148	19503N	PARTICIPANT	\N	PRESENT	0
450153	450151	19503N	PARTICIPANT	\N	PRESENT	0
450156	450154	19503N	PARTICIPANT	\N	PRESENT	0
450159	450157	19503N	PARTICIPANT	\N	PRESENT	0
450162	450160	19503N	PARTICIPANT	\N	PRESENT	0
450165	450163	19503N	PARTICIPANT	\N	PRESENT	0
450168	450166	19503N	PARTICIPANT	\N	PRESENT	0
450171	450169	19503N	PARTICIPANT	\N	PRESENT	0
450174	450172	19503N	PARTICIPANT	\N	PRESENT	0
450177	450175	19503N	PARTICIPANT	\N	PRESENT	0
450180	450178	19503N	PARTICIPANT	\N	PRESENT	0
450183	450181	19503N	PARTICIPANT	\N	PRESENT	0
450186	450184	19503N	PARTICIPANT	\N	PRESENT	0
450192	450190	19503N	PARTICIPANT	\N	PRESENT	0
450195	450193	19503N	PARTICIPANT	\N	PRESENT	0
450931	445946	19349W	PARTICIPANT	\N	EXCUSE	0
450933	445946	01028R	PARTICIPANT	\N	EXCUSE	0
452364	450709	11049P	PARTICIPANT	\N	PRESENT	0
452532	450837	14038Y	PARTICIPANT	\N	PRESENT	0
452533	450837	14031R	PARTICIPANT	\N	PRESENT	0
452534	450837	08055A	PARTICIPANT	\N	PRESENT	0
452535	450837	14169X	PARTICIPANT	\N	PRESENT	0
452536	450837	14191V	PARTICIPANT	\N	PRESENT	0
452537	450837	15447F	PARTICIPANT	\N	PRESENT	0
452538	450837	14093U	PARTICIPANT	\N	PRESENT	0
452539	450837	08009T	PRESIDENT	0	PRESENT	0
452540	450837	19737F	PARTICIPANT	\N	PRESENT	0
452541	450837	04097T	PARTICIPANT	\N	PRESENT	0
452542	450837	19739H	PARTICIPANT	\N	PRESENT	0
452543	450837	19745F	PARTICIPANT	\N	PRESENT	0
452554	450711	14042U	PARTICIPANT	\N	PRESENT	0
452555	450711	14217N	PARTICIPANT	\N	PRESENT	0
452556	450711	19301E	PARTICIPANT	\N	PRESENT	0
452581	449606	11067R	PARTICIPANT	\N	PRESENT	0
452582	449606	19553Y	PARTICIPANT	\N	PRESENT	0
452583	449606	19575F	PARTICIPANT	\N	PRESENT	0
452584	449606	14195A	PARTICIPANT	\N	PRESENT	0
452585	449606	14217N	PARTICIPANT	\N	PRESENT	0
452586	449606	19723Y	PARTICIPANT	\N	PRESENT	0
452588	448737	98022P	PARTICIPANT	\N	PRESENT	0
452589	448737	19715Y	PARTICIPANT	\N	PRESENT	0
452590	448737	88008L	PARTICIPANT	\N	PRESENT	0
452591	448737	14227Q	PARTICIPANT	\N	PRESENT	0
452592	448737	11077T	PARTICIPANT	\N	PRESENT	0
452594	448737	11104D	PARTICIPANT	\N	PRESENT	0
452595	448737	08053X	PARTICIPANT	\N	PRESENT	0
452596	448737	08060W	PARTICIPANT	\N	PRESENT	0
452597	448737	11041F	PARTICIPANT	\N	PRESENT	0
452598	448737	95037J	PARTICIPANT	\N	PRESENT	0
452599	448737	19563B	PARTICIPANT	\N	PRESENT	0
452600	448737	14042U	PARTICIPANT	\N	PRESENT	0
452601	448737	04089T	PARTICIPANT	\N	PRESENT	0
452602	448737	14207L	PARTICIPANT	\N	PRESENT	0
452603	448737	14225N	PARTICIPANT	\N	PRESENT	0
452604	448737	19758L	PARTICIPANT	\N	PRESENT	0
452605	448737	14051J	PARTICIPANT	\N	PRESENT	0
452606	448737	08055A	PARTICIPANT	\N	PRESENT	0
452607	448737	19525U	PARTICIPANT	\N	PRESENT	0
452608	448737	11040E	PARTICIPANT	\N	PRESENT	0
452609	448737	14030Q	PARTICIPANT	\N	PRESENT	0
452610	448737	19611R	PARTICIPANT	\N	PRESENT	0
452611	448737	08056B	PARTICIPANT	\N	PRESENT	0
452612	448737	11067R	PARTICIPANT	\N	PRESENT	0
452613	448737	14219Q	PARTICIPANT	\N	PRESENT	0
452614	448737	08068F	PARTICIPANT	\N	PRESENT	0
452615	448737	08031R	PARTICIPANT	\N	PRESENT	0
452616	448737	19737F	PARTICIPANT	\N	PRESENT	0
452617	448737	02002K	PARTICIPANT	\N	PRESENT	0
452618	448737	19782L	PARTICIPANT	\N	PRESENT	0
452619	448737	14151M	PARTICIPANT	\N	PRESENT	0
452620	448737	08073C	PARTICIPANT	\N	PRESENT	0
452621	448737	19253P	PARTICIPANT	\N	PRESENT	0
452622	448737	14197C	PARTICIPANT	\N	PRESENT	0
452623	448737	19511N	PARTICIPANT	\N	PRESENT	0
452624	448737	14195A	PARTICIPANT	\N	PRESENT	0
452625	448737	19585H	PARTICIPANT	\N	PRESENT	0
452626	448737	19319Q	PARTICIPANT	\N	PRESENT	0
452627	448737	14179A	PARTICIPANT	\N	PRESENT	0
452628	448737	19699S	PARTICIPANT	\N	PRESENT	0
452629	448737	19619A	PARTICIPANT	\N	PRESENT	0
452630	448737	14221J	PARTICIPANT	\N	PRESENT	0
452631	448737	08044W	PARTICIPANT	\N	PRESENT	0
452632	448737	14327T	PARTICIPANT	\N	PRESENT	0
452633	448737	08043V	PARTICIPANT	\N	PRESENT	0
452634	448737	14063N	PARTICIPANT	\N	PRESENT	0
452635	448737	19820Y	PARTICIPANT	\N	PRESENT	0
452636	448737	08012N	PARTICIPANT	\N	PRESENT	0
452637	448737	14028W	PARTICIPANT	\N	PRESENT	0
452638	448737	04059M	PARTICIPANT	\N	PRESENT	0
452639	448737	19301E	PARTICIPANT	\N	PRESENT	0
452640	448737	14039A	PARTICIPANT	\N	PRESENT	0
452641	448737	14121F	PARTICIPANT	\N	PRESENT	0
452642	448737	19583F	PARTICIPANT	\N	PRESENT	0
452643	448737	11085T	PARTICIPANT	\N	PRESENT	0
452644	448737	19745F	PARTICIPANT	\N	PRESENT	0
452645	448737	19826F	PARTICIPANT	\N	PRESENT	0
452646	448737	19721W	PARTICIPANT	\N	PRESENT	0
452647	448737	14261S	PARTICIPANT	\N	PRESENT	0
452648	448737	14211G	PARTICIPANT	\N	PRESENT	0
452649	448737	04085P	PARTICIPANT	\N	PRESENT	0
452650	448737	17637T	PARTICIPANT	\N	PRESENT	0
452651	448737	11031D	PARTICIPANT	\N	PRESENT	0
452652	448737	11056N	PARTICIPANT	\N	PRESENT	0
452653	448737	14235Q	PARTICIPANT	\N	PRESENT	0
452654	448737	19711U	PARTICIPANT	\N	PRESENT	0
452655	448737	19760E	PARTICIPANT	\N	PRESENT	0
452656	448737	98018T	PARTICIPANT	\N	PRESENT	0
452657	448737	19347U	PARTICIPANT	\N	PRESENT	0
452658	448737	19695N	PARTICIPANT	\N	PRESENT	0
452659	448737	19565D	PARTICIPANT	\N	PRESENT	0
452660	448737	08011M	PARTICIPANT	\N	PRESENT	0
452661	448737	19687N	PARTICIPANT	\N	PRESENT	0
452662	448737	14157T	PARTICIPANT	\N	PRESENT	0
452663	448737	19593H	PARTICIPANT	\N	PRESENT	0
452664	448737	96004D	PARTICIPANT	\N	PRESENT	0
452665	448737	89017R	PARTICIPANT	\N	PRESENT	0
452666	448737	19731Y	PARTICIPANT	\N	PRESENT	0
452667	448737	08018U	PARTICIPANT	\N	PRESENT	0
452668	448737	19443T	PARTICIPANT	\N	PRESENT	0
452669	448737	08061X	PARTICIPANT	\N	PRESENT	0
452670	448737	19741B	PARTICIPANT	\N	PRESENT	0
452671	448737	04034C	PARTICIPANT	\N	PRESENT	0
452672	448737	19507S	PARTICIPANT	\N	PRESENT	0
452673	448737	04045F	PARTICIPANT	\N	PRESENT	0
452674	448737	04088S	PARTICIPANT	\N	PRESENT	0
452675	448737	98029W	PARTICIPANT	\N	PRESENT	0
452676	448737	11083R	PARTICIPANT	\N	PRESENT	0
452677	448737	19575F	PARTICIPANT	\N	PRESENT	0
452678	448737	19651A	PARTICIPANT	\N	PRESENT	0
452679	448737	19349W	PARTICIPANT	\N	PRESENT	0
452680	448737	07029T	PARTICIPANT	\N	PRESENT	0
452681	448737	19637C	PARTICIPANT	\N	PRESENT	0
452682	448737	19657G	PARTICIPANT	\N	PRESENT	0
452683	448737	95063L	PARTICIPANT	\N	PRESENT	0
452684	448737	08062Y	PARTICIPANT	\N	PRESENT	0
452685	448737	19705W	PARTICIPANT	\N	PRESENT	0
452687	448737	08015R	PARTICIPANT	\N	PRESENT	0
452688	448737	19812Y	PARTICIPANT	\N	PRESENT	0
452689	448737	14059S	PARTICIPANT	\N	PRESENT	0
452690	448737	14038Y	PARTICIPANT	\N	PRESENT	0
452691	448737	19723Y	PARTICIPANT	\N	PRESENT	0
452692	448737	19415P	PARTICIPANT	\N	PRESENT	0
452693	448737	14111D	PARTICIPANT	\N	PRESENT	0
452694	448737	18083K	PARTICIPANT	\N	PRESENT	0
452695	448737	14135M	PARTICIPANT	\N	PRESENT	0
452696	448737	98005N	PARTICIPANT	\N	PRESENT	0
452697	448737	14251Q	PARTICIPANT	\N	PRESENT	0
452698	448737	08019V	PARTICIPANT	\N	PRESENT	0
452699	448737	19399H	PARTICIPANT	\N	PRESENT	0
452700	448737	14265W	PARTICIPANT	\N	PRESENT	0
431126	424872	11074Q	PARTICIPANT	\N	PRESENT	0
431127	424872	11040E	PARTICIPANT	\N	PRESENT	0
431128	424872	19295A	PARTICIPANT	\N	PRESENT	0
431129	424872	14085U	PARTICIPANT	\N	PRESENT	0
431130	424872	19503N	PARTICIPANT	\N	PRESENT	0
431131	424872	14225N	PARTICIPANT	\N	PRESENT	0
431132	424872	14039A	PARTICIPANT	\N	PRESENT	0
431133	424872	19301E	PARTICIPANT	\N	PRESENT	0
431134	424872	19349W	PARTICIPANT	\N	PRESENT	0
431135	424872	88008L	PARTICIPANT	\N	PRESENT	0
431136	424872	12016W	PARTICIPANT	\N	PRESENT	0
431137	424872	14089Y	PARTICIPANT	\N	PRESENT	0
431138	424872	07004J	PARTICIPANT	\N	PRESENT	0
431139	424872	07029T	PARTICIPANT	\N	PRESENT	0
431140	424872	08019V	PARTICIPANT	\N	PRESENT	0
431141	424872	14119M	PARTICIPANT	\N	PRESENT	0
431142	424872	19667J	PARTICIPANT	\N	PRESENT	0
431143	424872	01057W	PARTICIPANT	\N	PRESENT	0
431144	424872	11048N	PARTICIPANT	\N	PRESENT	0
431145	424872	08034U	PARTICIPANT	\N	PRESENT	0
431146	424872	99004R	PARTICIPANT	\N	PRESENT	0
431147	424872	96004D	PARTICIPANT	\N	PRESENT	0
431148	424872	08069G	PARTICIPANT	\N	PRESENT	0
431149	424872	19515S	PARTICIPANT	\N	PRESENT	0
431150	424872	04086Q	PARTICIPANT	\N	PRESENT	0
431151	424872	19711U	PARTICIPANT	\N	PRESENT	0
431152	424872	19647E	PARTICIPANT	\N	PRESENT	0
431153	424872	19687N	PARTICIPANT	\N	PRESENT	0
431154	424872	11053K	PARTICIPANT	\N	PRESENT	0
431155	424872	14261S	PARTICIPANT	\N	PRESENT	0
431156	424872	14021P	PARTICIPANT	\N	PRESENT	0
431157	424872	11077T	PARTICIPANT	\N	PRESENT	0
431158	424872	11085T	PARTICIPANT	\N	PRESENT	0
431124	424872	04044E	PARTICIPANT	\N	PRESENT	0
431125	424872	08011M	PARTICIPANT	\N	PRESENT	0
431163	424872	19741B	PARTICIPANT	\N	PRESENT	0
431160	424872	14083S	PARTICIPANT	\N	PRESENT	0
431161	424872	11026G	PARTICIPANT	\N	PRESENT	0
431162	424872	11043H	PARTICIPANT	\N	PRESENT	0
431164	424872	19551W	PARTICIPANT	\N	PRESENT	0
431165	424872	04071H	PARTICIPANT	\N	PRESENT	0
431429	424881	11040E	PARTICIPANT	\N	PRESENT	0
431430	424881	19741B	PARTICIPANT	\N	PRESENT	0
431431	424881	14030Q	PARTICIPANT	\N	PRESENT	0
431432	424881	19479G	PARTICIPANT	\N	PRESENT	0
431433	424881	19301E	PARTICIPANT	\N	PRESENT	0
431434	424881	14157T	PARTICIPANT	\N	PRESENT	0
431435	424881	07033P	PARTICIPANT	\N	PRESENT	0
431436	424881	04085P	PARTICIPANT	\N	PRESENT	0
431437	424881	19549D	PARTICIPANT	\N	PRESENT	0
431438	424881	99004R	PARTICIPANT	\N	PRESENT	0
431439	424881	08034U	PARTICIPANT	\N	PRESENT	0
431440	424881	11072N	PARTICIPANT	\N	PRESENT	0
431441	424881	19583F	PARTICIPANT	\N	PRESENT	0
431442	424881	11090Q	PARTICIPANT	\N	PRESENT	0
431443	424881	11103C	PARTICIPANT	\N	PRESENT	0
431444	424881	19441R	PARTICIPANT	\N	PRESENT	0
431447	424881	14033T	PARTICIPANT	\N	PRESENT	0
431448	424881	14357A	PARTICIPANT	\N	PRESENT	0
431498	424882	11109J	PARTICIPANT	\N	PRESENT	0
431499	424882	19669L	PARTICIPANT	\N	PRESENT	0
431500	424882	19533U	PARTICIPANT	\N	PRESENT	0
431501	424882	08011M	PARTICIPANT	\N	PRESENT	0
431502	424882	11074Q	PARTICIPANT	\N	PRESENT	0
431503	424882	14157T	PARTICIPANT	\N	PRESENT	0
431504	424882	11048N	PARTICIPANT	\N	PRESENT	0
431505	424882	14085U	PARTICIPANT	\N	PRESENT	0
431506	424882	19651A	PARTICIPANT	\N	PRESENT	0
431507	424882	11012A	PARTICIPANT	\N	PRESENT	0
431508	424882	19503N	PARTICIPANT	\N	PRESENT	0
431509	424882	19637C	PARTICIPANT	\N	PRESENT	0
431510	424882	19711U	PARTICIPANT	\N	PRESENT	0
431511	424882	14039A	PARTICIPANT	\N	PRESENT	0
431512	424882	08019V	PARTICIPANT	\N	PRESENT	0
431513	424882	19683J	PARTICIPANT	\N	PRESENT	0
431514	424882	19549D	PARTICIPANT	\N	PRESENT	0
431515	424882	14327T	PARTICIPANT	\N	PRESENT	0
431516	424882	14033T	PARTICIPANT	\N	PRESENT	0
431517	424882	11070L	PARTICIPANT	\N	PRESENT	0
431518	424882	19545Y	PARTICIPANT	\N	PRESENT	0
431519	424882	14331P	PARTICIPANT	\N	PRESENT	0
431520	424882	14119M	PARTICIPANT	\N	PRESENT	0
431521	424882	12016W	PARTICIPANT	\N	PRESENT	0
431522	424882	14261S	PARTICIPANT	\N	PRESENT	0
431523	424882	19301E	PARTICIPANT	\N	PRESENT	0
431524	424882	07029T	PARTICIPANT	\N	PRESENT	0
431525	424882	99004R	PARTICIPANT	\N	PRESENT	0
431526	424882	08034U	PARTICIPANT	\N	PRESENT	0
431527	424882	19647E	PARTICIPANT	\N	PRESENT	0
431528	424882	19691J	PARTICIPANT	\N	PRESENT	0
431529	424882	14121F	PARTICIPANT	\N	PRESENT	0
431530	424882	04043D	PARTICIPANT	\N	PRESENT	0
431531	424882	04069P	PARTICIPANT	\N	PRESENT	0
431532	424882	98050T	PARTICIPANT	\N	PRESENT	0
431533	424882	19794Q	PARTICIPANT	\N	PRESENT	0
431534	424882	19689Q	PARTICIPANT	\N	PRESENT	0
431535	424882	19741B	PARTICIPANT	\N	PRESENT	0
431536	424882	19479G	PARTICIPANT	\N	PRESENT	0
431537	424882	19687N	PARTICIPANT	\N	PRESENT	0
431538	424882	11090Q	PARTICIPANT	\N	PRESENT	0
431496	424882	04059M	PARTICIPANT	\N	PRESENT	0
431497	424882	11040E	PARTICIPANT	\N	PRESENT	0
431539	424882	19583F	PARTICIPANT	\N	PRESENT	0
431540	424882	19667J	PARTICIPANT	\N	PRESENT	0
431541	424882	14357A	PARTICIPANT	\N	PRESENT	0
431542	424882	14034U	PARTICIPANT	\N	PRESENT	0
431543	424882	14219Q	PARTICIPANT	\N	PRESENT	0
431544	424882	19441R	PARTICIPANT	\N	PRESENT	0
431545	424882	01057W	PARTICIPANT	\N	PRESENT	0
431546	424882	04042C	PARTICIPANT	\N	PRESENT	0
431547	424882	19551W	PARTICIPANT	\N	PRESENT	0
431550	424882	14031R	PARTICIPANT	\N	PRESENT	0
431551	424882	04033B	PARTICIPANT	\N	PRESENT	0
431552	424882	04086Q	PARTICIPANT	\N	PRESENT	0
431553	424882	14030Q	PARTICIPANT	\N	PRESENT	0
431554	424882	04071H	PARTICIPANT	\N	PRESENT	0
431555	424882	11027H	PARTICIPANT	\N	PRESENT	0
431556	424882	95037J	PARTICIPANT	\N	PRESENT	0
431557	424882	80013X	PARTICIPANT	\N	PRESENT	0
431558	424882	04085P	PARTICIPANT	\N	PRESENT	0
431559	424882	04045F	PARTICIPANT	\N	PRESENT	0
431560	424882	08009T	PARTICIPANT	\N	PRESENT	0
431561	424882	14187A	PARTICIPANT	\N	PRESENT	0
431562	424882	16685X	PARTICIPANT	\N	PRESENT	0
431567	424882	11103C	PARTICIPANT	\N	PRESENT	0
431569	424882	19575F	PARTICIPANT	\N	PRESENT	0
431572	424882	14267Y	PARTICIPANT	\N	PRESENT	0
431573	424882	08061X	PARTICIPANT	\N	PRESENT	0
431574	424882	14021P	PARTICIPANT	\N	PRESENT	0
431581	424882	08015R	PARTICIPANT	\N	PRESENT	0
431631	424883	04044E	PARTICIPANT	\N	PRESENT	0
431632	424883	11074Q	PARTICIPANT	\N	PRESENT	0
431633	424883	08011M	PARTICIPANT	\N	PRESENT	0
431634	424883	19669L	PARTICIPANT	\N	PRESENT	0
431635	424883	19503N	PARTICIPANT	\N	PRESENT	0
431636	424883	14085U	PARTICIPANT	\N	PRESENT	0
431637	424883	11109J	PARTICIPANT	\N	PRESENT	0
431638	424883	04045F	PARTICIPANT	\N	PRESENT	0
431639	424883	19549D	PARTICIPANT	\N	PRESENT	0
431640	424883	11053K	PARTICIPANT	\N	PRESENT	0
431641	424883	14327T	PARTICIPANT	\N	PRESENT	0
431642	424883	14033T	PARTICIPANT	\N	PRESENT	0
431643	424883	08019V	PARTICIPANT	\N	PRESENT	0
431644	424883	14157T	PARTICIPANT	\N	PRESENT	0
431645	424883	19794Q	PARTICIPANT	\N	PRESENT	0
431646	424883	95037J	PARTICIPANT	\N	PRESENT	0
431647	424883	14357A	PARTICIPANT	\N	PRESENT	0
431648	424883	08034U	PARTICIPANT	\N	PRESENT	0
431649	424883	19711U	PARTICIPANT	\N	PRESENT	0
431650	424883	14187A	PARTICIPANT	\N	PRESENT	0
431651	424883	14031R	PARTICIPANT	\N	PRESENT	0
431652	424883	12016W	PARTICIPANT	\N	PRESENT	0
431653	424883	14121F	PARTICIPANT	\N	PRESENT	0
431654	424883	96004D	PARTICIPANT	\N	PRESENT	0
431655	424883	14331P	PARTICIPANT	\N	PRESENT	0
431656	424883	11048N	PARTICIPANT	\N	PRESENT	0
431657	424883	19575F	PARTICIPANT	\N	PRESENT	0
431658	424883	14029X	PARTICIPANT	\N	PRESENT	0
431659	424883	14083S	PARTICIPANT	\N	PRESENT	0
431660	424883	08010L	PARTICIPANT	\N	PRESENT	0
431661	424883	19647E	PARTICIPANT	\N	PRESENT	0
431662	424883	14251Q	PARTICIPANT	\N	PRESENT	0
431663	424883	07029T	PARTICIPANT	\N	PRESENT	0
431664	424883	19695N	PARTICIPANT	\N	PRESENT	0
431665	424883	19687N	PARTICIPANT	\N	PRESENT	0
431666	424883	11099A	PARTICIPANT	\N	PRESENT	0
431667	424883	19551W	PARTICIPANT	\N	PRESENT	0
431668	424883	14119M	PARTICIPANT	\N	PRESENT	0
452818	452811	14357A	PARTICIPANT	\N	PRESENT	0
452822	452811	17589D	PARTICIPANT	\N	PRESENT	0
452825	452811	14041T	PARTICIPANT	\N	PRESENT	0
452827	452811	97011G	PARTICIPANT	\N	PRESENT	0
452830	452811	14179A	PARTICIPANT	\N	PRESENT	0
452834	452811	08034U	PARTICIPANT	\N	PRESENT	0
452839	452811	14169X	PARTICIPANT	\N	PRESENT	0
452840	452811	19766L	PARTICIPANT	\N	PRESENT	0
452842	452811	19737F	PARTICIPANT	\N	PRESENT	0
452907	452906	04034C	PARTICIPANT	\N	PRESENT	0
452909	452908	04034C	PARTICIPANT	\N	PRESENT	0
452914	449855	14259Y	PARTICIPANT	\N	EXCUSE	0
452915	449855	14135M	PARTICIPANT	\N	EXCUSE	0
452916	449855	14219Q	PARTICIPANT	\N	EXCUSE	0
452917	449855	14038Y	PARTICIPANT	\N	EXCUSE	0
452918	449855	19729F	PARTICIPANT	\N	EXCUSE	0
452919	449855	11010L	PARTICIPANT	\N	EXCUSE	0
452920	449855	14225N	PARTICIPANT	\N	EXCUSE	0
453224	453223	96004D	PRESIDENT	0	PRESENT	0
453225	453223	08014Q	PARTICIPANT	\N	PRESENT	0
453226	453223	14079W	PARTICIPANT	\N	PRESENT	0
453228	453223	11083R	PARTICIPANT	\N	PRESENT	0
453229	453223	14033T	PARTICIPANT	\N	PRESENT	0
453230	453223	14097Y	PARTICIPANT	\N	PRESENT	0
453231	453223	14241N	PARTICIPANT	\N	PRESENT	0
453233	453223	14061L	PARTICIPANT	\N	PRESENT	0
453234	453223	14073Q	PARTICIPANT	\N	PRESENT	0
453239	453223	14001X	PARTICIPANT	\N	PRESENT	0
453241	453223	14237S	PARTICIPANT	\N	PRESENT	0
453243	453223	14331P	PARTICIPANT	\N	PRESENT	0
453751	448741	14119M	PARTICIPANT	\N	PRESENT	0
453752	448741	14041T	PARTICIPANT	\N	PRESENT	0
453753	449593	14030Q	PARTICIPANT	\N	PRESENT	0
453754	449593	19693L	PARTICIPANT	\N	PRESENT	0
453755	449593	08031R	PARTICIPANT	\N	PRESENT	0
453756	449593	11067R	PARTICIPANT	\N	PRESENT	0
453757	449593	19749K	PARTICIPANT	\N	PRESENT	0
453758	449593	14109K	PARTICIPANT	\N	PRESENT	0
453759	449594	19693L	PARTICIPANT	\N	PRESENT	0
453760	449594	08031R	PARTICIPANT	\N	PRESENT	0
453761	449594	11067R	PARTICIPANT	\N	PRESENT	0
453762	449594	14109K	PARTICIPANT	\N	PRESENT	0
453763	449594	19749K	PARTICIPANT	\N	PRESENT	0
453807	453805	14217N	PARTICIPANT	\N	PRESENT	0
453810	453809	14217N	PARTICIPANT	\N	PRESENT	0
453811	453809	11097X	PARTICIPANT	\N	PRESENT	0
453812	453809	01034P	PARTICIPANT	\N	PRESENT	0
453814	453813	14217N	PARTICIPANT	\N	PRESENT	0
453815	453813	11097X	PARTICIPANT	\N	PRESENT	0
453816	448742	14069U	PARTICIPANT	\N	PRESENT	0
453817	453813	01034P	PARTICIPANT	\N	PRESENT	0
453818	448742	19725B	PARTICIPANT	\N	PRESENT	0
453819	448742	19820Y	PARTICIPANT	\N	PRESENT	0
453820	448742	19715Y	PARTICIPANT	\N	PRESENT	0
453821	448742	04038G	PARTICIPANT	\N	PRESENT	0
453822	448742	95063L	PARTICIPANT	\N	PRESENT	0
453823	448742	14231L	PARTICIPANT	\N	PRESENT	0
453824	448742	14034U	PARTICIPANT	\N	PRESENT	0
453825	448742	07029T	PARTICIPANT	\N	PRESENT	0
453826	448742	14237S	PARTICIPANT	\N	PRESENT	0
453827	448742	19533U	PARTICIPANT	\N	PRESENT	0
453828	448742	19507S	PARTICIPANT	\N	PRESENT	0
453829	448742	19447X	PARTICIPANT	\N	PRESENT	0
453830	448742	19467C	PARTICIPANT	\N	PRESENT	0
453831	448742	19545Y	PARTICIPANT	\N	PRESENT	0
453832	448742	19593H	PARTICIPANT	\N	PRESENT	0
453833	448742	05008E	PARTICIPANT	\N	PRESENT	0
453834	448742	19399H	PARTICIPANT	\N	PRESENT	0
453835	448742	19741B	PARTICIPANT	\N	PRESENT	0
453836	453664	14225N	PARTICIPANT	\N	EXCUSE	0
453839	448742	01048V	PARTICIPANT	\N	PRESENT	0
453840	448742	14038Y	PARTICIPANT	\N	PRESENT	0
453841	448742	14215L	PARTICIPANT	\N	PRESENT	0
453842	448742	97011G	PARTICIPANT	\N	PRESENT	0
453843	448742	19583F	PARTICIPANT	\N	PRESENT	0
453844	448742	01025N	PARTICIPANT	\N	PRESENT	0
453845	448742	19573D	PARTICIPANT	\N	PRESENT	0
453846	448742	98050T	PARTICIPANT	\N	PRESENT	0
453848	448742	14251Q	PARTICIPANT	\N	PRESENT	0
453849	448742	14257W	PARTICIPANT	\N	PRESENT	0
453850	448742	19563B	PARTICIPANT	\N	PRESENT	0
453851	448742	08034U	PARTICIPANT	\N	PRESENT	0
453852	448742	19762G	PARTICIPANT	\N	PRESENT	0
453804	448742	11070L	PARTICIPANT	\N	PRESENT	0
453806	453805	11097X	PARTICIPANT	\N	PRESENT	0
453853	448742	08020N	PARTICIPANT	\N	PRESENT	0
453855	453854	11090Q	PARTICIPANT	\N	PRESENT	0
453856	453854	11065P	PARTICIPANT	\N	PRESENT	0
453858	453857	19687N	PARTICIPANT	\N	PRESENT	0
453859	453857	99004R	PARTICIPANT	\N	PRESENT	0
453860	453857	19711U	PARTICIPANT	\N	PRESENT	0
453861	453857	04071H	PARTICIPANT	\N	PRESENT	0
453862	453857	19647E	PARTICIPANT	\N	PRESENT	0
453863	453857	04086Q	PARTICIPANT	\N	PRESENT	0
453864	453857	11074Q	PARTICIPANT	\N	PRESENT	0
453865	453854	04033B	PARTICIPANT	\N	PRESENT	0
453866	453854	11064N	PARTICIPANT	\N	PRESENT	0
453867	453854	11066Q	PARTICIPANT	\N	PRESENT	0
453868	448742	19269X	PARTICIPANT	\N	PRESENT	0
453869	448742	19695N	PARTICIPANT	\N	PRESENT	0
453897	448743	19441R	PARTICIPANT	\N	PRESENT	0
453898	448743	14251Q	PARTICIPANT	\N	PRESENT	0
453899	448743	19545Y	PARTICIPANT	\N	PRESENT	0
453900	448743	19269X	PARTICIPANT	\N	PRESENT	0
453901	448743	19820Y	PARTICIPANT	\N	PRESENT	0
453902	448743	14257W	PARTICIPANT	\N	PRESENT	0
453903	448743	19695N	PARTICIPANT	\N	PRESENT	0
453904	448743	14207L	PARTICIPANT	\N	PRESENT	0
453905	448743	01025N	PARTICIPANT	\N	PRESENT	0
453906	448743	98050T	PARTICIPANT	\N	PRESENT	0
453907	448743	07029T	PARTICIPANT	\N	PRESENT	0
453908	448743	19507S	PARTICIPANT	\N	PRESENT	0
453909	448743	08034U	PARTICIPANT	\N	PRESENT	0
453910	448743	01048V	PARTICIPANT	\N	PRESENT	0
453911	448743	19762G	PARTICIPANT	\N	PRESENT	0
453912	448743	11012A	PARTICIPANT	\N	PRESENT	0
453913	448743	19715Y	PARTICIPANT	\N	PRESENT	0
453914	448743	14038Y	PARTICIPANT	\N	PRESENT	0
453915	448743	14093U	PARTICIPANT	\N	PRESENT	0
453917	453916	19794Q	PARTICIPANT	\N	PRESENT	0
453918	453916	19637C	PARTICIPANT	\N	PRESENT	0
453919	453916	19347U	PARTICIPANT	\N	PRESENT	0
453920	453916	19599P	PARTICIPANT	\N	PRESENT	0
453921	453916	19383Y	PARTICIPANT	\N	PRESENT	0
453922	453916	14038Y	PARTICIPANT	\N	PRESENT	0
453895	448743	11070L	PARTICIPANT	\N	PRESENT	0
453896	448743	19563B	PARTICIPANT	\N	PRESENT	0
453923	453916	18083K	PARTICIPANT	\N	PRESENT	0
453924	453916	19333N	PARTICIPANT	\N	PRESENT	0
453929	453926	19347U	PARTICIPANT	\N	PRESENT	0
453927	453926	19794Q	PARTICIPANT	\N	PRESENT	0
453928	453926	19637C	PARTICIPANT	\N	PRESENT	0
453930	453926	19549D	PARTICIPANT	\N	PRESENT	0
453931	453926	19599P	PARTICIPANT	\N	PRESENT	0
453932	453926	14038Y	PARTICIPANT	\N	PRESENT	0
453933	453926	18083K	PARTICIPANT	\N	PRESENT	0
453934	453926	19333N	PARTICIPANT	\N	PRESENT	0
453937	450886	14299H	PARTICIPANT	\N	EXCUSE	0
453943	450886	19709B	PARTICIPANT	\N	EXCUSE	0
453944	450886	08053X	PARTICIPANT	\N	EXCUSE	0
453945	450886	01058X	PARTICIPANT	\N	EXCUSE	0
453946	450886	19723Y	PARTICIPANT	\N	EXCUSE	0
453947	450886	01048V	PRESIDENT	0	PRESENT	0
453948	450886	19533U	PARTICIPANT	\N	PRESENT	0
453949	450886	19503N	PARTICIPANT	\N	PRESENT	0
453950	448743	19399H	PARTICIPANT	\N	PRESENT	0
453951	448743	14237S	PARTICIPANT	\N	PRESENT	0
453954	453952	19503N	PARTICIPANT	\N	PRESENT	0
453957	453955	19503N	PARTICIPANT	\N	PRESENT	0
453960	453958	19503N	PARTICIPANT	\N	PRESENT	0
453963	453961	19503N	PARTICIPANT	\N	PRESENT	0
453966	453964	19503N	PARTICIPANT	\N	PRESENT	0
453969	453968	14083S	PARTICIPANT	\N	PRESENT	0
453970	453968	14061L	PARTICIPANT	\N	PRESENT	0
453972	453971	04049K	PARTICIPANT	\N	PRESENT	0
453973	453971	16685X	PARTICIPANT	\N	PRESENT	0
453975	453974	16685X	PARTICIPANT	\N	PRESENT	0
429060	429055	04043D	PARTICIPANT	\N	PRESENT	0
429067	429066	11074Q	PARTICIPANT	\N	PRESENT	0
429069	429068	11049P	PARTICIPANT	\N	PRESENT	0
431568	423006	04038G	PARTICIPANT	\N	EXCUSE	0
431570	423006	14147R	PARTICIPANT	\N	PRESENT	0
431571	423006	19551W	PARTICIPANT	\N	EXCUSE	0
436082	425630	04086Q	PARTICIPANT	\N	PRESENT	0
436083	425630	08069G	PARTICIPANT	\N	PRESENT	0
436084	425630	19631V	PARTICIPANT	\N	PRESENT	0
436085	425630	19629C	PARTICIPANT	\N	PRESENT	0
436086	425630	14205J	PARTICIPANT	\N	PRESENT	0
436087	425630	19511N	PARTICIPANT	\N	PRESENT	0
436088	425630	14030Q	PARTICIPANT	\N	PRESENT	0
436089	425630	01025N	PARTICIPANT	\N	PRESENT	0
436090	425630	14021P	PARTICIPANT	\N	PRESENT	0
436091	425630	19503N	PARTICIPANT	\N	PRESENT	0
436092	425630	19413M	PARTICIPANT	\N	PRESENT	0
436093	425630	11090Q	PARTICIPANT	\N	PRESENT	0
436094	425630	14105F	PARTICIPANT	\N	PRESENT	0
436095	425630	14115H	PARTICIPANT	\N	PRESENT	0
436096	425630	07029T	PARTICIPANT	\N	PRESENT	0
436097	425630	04088S	PARTICIPANT	\N	PRESENT	0
436098	425630	19467C	PARTICIPANT	\N	PRESENT	0
436099	425630	14033T	PARTICIPANT	\N	PRESENT	0
436100	425630	95030B	PARTICIPANT	\N	PRESENT	0
436101	425630	19387D	PARTICIPANT	\N	PRESENT	0
436102	425630	19269X	PARTICIPANT	\N	PRESENT	0
436103	425630	11097X	PARTICIPANT	\N	PRESENT	0
436104	425630	19573D	PARTICIPANT	\N	PRESENT	0
436105	425630	19253P	PARTICIPANT	\N	PRESENT	0
436106	425630	19673G	PARTICIPANT	\N	PRESENT	0
436107	425630	19798U	PARTICIPANT	\N	PRESENT	0
436108	425630	19671E	PARTICIPANT	\N	PRESENT	0
436109	425630	14237S	PARTICIPANT	\N	PRESENT	0
436110	425630	14265W	PARTICIPANT	\N	PRESENT	0
436111	425630	08014Q	PARTICIPANT	\N	PRESENT	0
436112	425630	14215L	PARTICIPANT	\N	PRESENT	0
436113	425630	14179A	PARTICIPANT	\N	PRESENT	0
436114	425630	96004D	PARTICIPANT	\N	PRESENT	0
436115	425630	19715Y	PARTICIPANT	\N	PRESENT	0
436116	425630	19507S	PARTICIPANT	\N	PRESENT	0
436117	425630	14187A	PARTICIPANT	\N	PRESENT	0
436118	425630	08015R	PARTICIPANT	\N	PRESENT	0
436119	425630	19383Y	PARTICIPANT	\N	PRESENT	0
436120	425630	14207L	PARTICIPANT	\N	PRESENT	0
436121	425630	19369B	PARTICIPANT	\N	PRESENT	0
436122	425630	14169X	PARTICIPANT	\N	PRESENT	0
436123	425630	19713W	PARTICIPANT	\N	PRESENT	0
436124	425630	19782L	PARTICIPANT	\N	PRESENT	0
436125	425630	11056N	PARTICIPANT	\N	PRESENT	0
436126	425630	14257W	PARTICIPANT	\N	PRESENT	0
436127	425630	14107H	PARTICIPANT	\N	PRESENT	0
436128	425630	14121F	PARTICIPANT	\N	PRESENT	0
436129	425630	14195A	PARTICIPANT	\N	PRESENT	0
436130	425630	14219Q	PARTICIPANT	\N	PRESENT	0
436131	425630	11099A	PARTICIPANT	\N	PRESENT	0
436132	425630	19531S	PARTICIPANT	\N	PRESENT	0
436133	425630	14225N	PARTICIPANT	\N	PRESENT	0
436134	425630	19515S	PARTICIPANT	\N	PRESENT	0
436135	425630	14147R	PARTICIPANT	\N	PRESENT	0
436136	425630	14026U	PARTICIPANT	\N	PRESENT	0
436137	425630	14083S	PARTICIPANT	\N	PRESENT	0
436138	425630	14135M	PARTICIPANT	\N	PRESENT	0
436139	425630	18083K	PARTICIPANT	\N	PRESENT	0
436140	425630	04033B	PARTICIPANT	\N	PRESENT	0
436141	425630	01024M	PARTICIPANT	\N	PRESENT	0
436142	425630	19723Y	PARTICIPANT	\N	PRESENT	0
436143	425630	08010L	PARTICIPANT	\N	PRESENT	0
436144	425630	19295A	PARTICIPANT	\N	PRESENT	0
436145	425630	14157T	PARTICIPANT	\N	PRESENT	0
436146	425630	19563B	PARTICIPANT	\N	PRESENT	0
436147	425630	19762G	PARTICIPANT	\N	PRESENT	0
436148	425630	11048N	PARTICIPANT	\N	PRESENT	0
436149	425630	19703U	PARTICIPANT	\N	PRESENT	0
436150	425630	11109J	PARTICIPANT	\N	PRESENT	0
436151	425630	19621T	PARTICIPANT	\N	PRESENT	0
436152	425630	14357A	PARTICIPANT	\N	PRESENT	0
436153	425630	89017R	PARTICIPANT	\N	PRESENT	0
436154	425630	14213J	PARTICIPANT	\N	PRESENT	0
436155	425630	19443T	PARTICIPANT	\N	PRESENT	0
436156	425630	14069U	PARTICIPANT	\N	PRESENT	0
436157	425630	14034U	PARTICIPANT	\N	PRESENT	0
436167	435793	19768N	PARTICIPANT	\N	PRESENT	0
436168	435793	19515S	PARTICIPANT	\N	PRESENT	0
436169	435793	19782L	PARTICIPANT	\N	PRESENT	0
436170	435793	14357A	PARTICIPANT	\N	PRESENT	0
436171	435793	19441R	PARTICIPANT	\N	PRESENT	0
436172	435793	19812Y	PARTICIPANT	\N	PRESENT	0
436173	435793	08068F	PARTICIPANT	\N	PRESENT	0
436174	435793	04049K	PARTICIPANT	\N	PRESENT	0
436175	435793	19705W	PARTICIPANT	\N	PRESENT	0
436176	435793	08015R	PARTICIPANT	\N	PRESENT	0
436177	435793	08019V	PARTICIPANT	\N	PRESENT	0
436178	435793	19511N	PARTICIPANT	\N	PRESENT	0
436179	435793	08028W	PARTICIPANT	\N	PRESENT	0
436180	435793	19563B	PARTICIPANT	\N	PRESENT	0
436181	435793	14265W	PARTICIPANT	\N	PRESENT	0
436182	435793	14135M	PARTICIPANT	\N	PRESENT	0
436183	435793	19467C	PARTICIPANT	\N	PRESENT	0
436184	435793	14187A	PARTICIPANT	\N	PRESENT	0
436185	435793	08062Y	PARTICIPANT	\N	PRESENT	0
436186	435793	19695N	PARTICIPANT	\N	PRESENT	0
436187	435793	01025N	PARTICIPANT	\N	PRESENT	0
436188	435793	14033T	PARTICIPANT	\N	PRESENT	0
436189	435793	11090Q	PRESIDENT	0	PRESENT	0
436190	435793	19295A	PARTICIPANT	\N	PRESENT	0
436191	435793	19269X	PARTICIPANT	\N	PRESENT	0
436192	435793	14205J	PARTICIPANT	\N	PRESENT	0
436193	435793	04088S	PARTICIPANT	\N	PRESENT	0
436194	435793	11101A	PARTICIPANT	\N	PRESENT	0
436195	435793	19507S	PARTICIPANT	\N	PRESENT	0
436196	435793	14207L	PARTICIPANT	\N	PRESENT	0
436197	435793	19747H	PARTICIPANT	\N	PRESENT	0
436198	435793	19619A	PARTICIPANT	\N	PRESENT	0
436199	435793	17589D	PARTICIPANT	\N	PRESENT	0
436200	435793	14257W	PARTICIPANT	\N	PRESENT	0
436201	435793	11081P	PARTICIPANT	\N	EXCUSE	0
436202	434669	14327T	PARTICIPANT	\N	PRESENT	0
436203	434669	01048V	PARTICIPANT	\N	PRESENT	0
436204	434669	01057W	PARTICIPANT	\N	PRESENT	0
436205	434669	11074Q	PRESIDENT	0	PRESENT	0
436206	434669	89017R	PARTICIPANT	\N	PRESENT	0
436207	434669	19667J	PARTICIPANT	\N	PRESENT	0
436208	434669	88008L	PARTICIPANT	\N	PRESENT	0
436209	434669	11070L	PARTICIPANT	\N	PRESENT	0
436210	434669	14225N	PARTICIPANT	\N	PRESENT	0
436211	434669	07029T	PARTICIPANT	\N	PRESENT	0
436212	434669	14085U	PARTICIPANT	\N	PRESENT	0
436213	434669	07004J	PARTICIPANT	\N	PRESENT	0
436214	434669	19349W	PARTICIPANT	\N	PRESENT	0
436215	434669	08010L	PARTICIPANT	\N	PRESENT	0
436216	434669	14253S	PARTICIPANT	\N	PRESENT	0
436217	434669	19479G	PARTICIPANT	\N	PRESENT	0
436218	434669	11048N	PARTICIPANT	\N	PRESENT	0
436219	434669	19711U	PARTICIPANT	\N	PRESENT	0
436220	434669	19651A	PARTICIPANT	\N	PRESENT	0
436221	434669	08034U	PARTICIPANT	\N	PRESENT	0
436222	434669	19531S	PARTICIPANT	\N	PRESENT	0
436223	434669	08069G	PARTICIPANT	\N	PRESENT	0
436224	434669	19687N	PARTICIPANT	\N	PRESENT	0
436225	434669	19689Q	PARTICIPANT	\N	PRESENT	0
436226	434669	08014Q	PARTICIPANT	\N	PRESENT	0
436227	434669	14034U	PARTICIPANT	\N	PRESENT	0
436228	434669	14159V	PARTICIPANT	\N	PRESENT	0
436229	434669	14173T	PARTICIPANT	\N	PRESENT	0
436230	434669	04086Q	PARTICIPANT	\N	PRESENT	0
436231	434669	14083S	PARTICIPANT	\N	PRESENT	0
436232	434669	14199E	PARTICIPANT	\N	PRESENT	0
436233	434669	11012A	PARTICIPANT	\N	PRESENT	0
436234	434669	08073C	PARTICIPANT	\N	PRESENT	0
436235	434669	14121F	PARTICIPANT	\N	PRESENT	0
436236	434669	19741B	PARTICIPANT	\N	PRESENT	0
436237	434669	99004R	PARTICIPANT	\N	PRESENT	0
436238	434669	19545Y	PARTICIPANT	\N	EXCUSE	0
436239	435793	19369B	PARTICIPANT	\N	PRESENT	0
436240	433965	14105F	PARTICIPANT	\N	PRESENT	0
436241	433965	11041F	PARTICIPANT	\N	PRESENT	0
436242	433965	11064N	PARTICIPANT	\N	PRESENT	0
436243	433965	14267Y	PARTICIPANT	\N	PRESENT	0
436244	433965	04042C	PRESIDENT	0	PRESENT	0
436245	433965	11066Q	PARTICIPANT	\N	PRESENT	0
436246	433965	98050T	PARTICIPANT	\N	PRESENT	0
436247	433965	97011G	PARTICIPANT	\N	PRESENT	0
436248	433965	19421M	PARTICIPANT	\N	PRESENT	0
436249	433965	12041X	PARTICIPANT	\N	PRESENT	0
436250	433965	19443T	PARTICIPANT	\N	PRESENT	0
436251	433965	08056B	PARTICIPANT	\N	PRESENT	0
436252	433965	08047A	PARTICIPANT	\N	PRESENT	0
436253	433965	14235Q	PARTICIPANT	\N	PRESENT	0
452701	448737	14329V	PARTICIPANT	\N	PRESENT	0
452702	448737	14357A	PARTICIPANT	\N	PRESENT	0
452703	448737	14034U	PARTICIPANT	\N	PRESENT	0
452704	448737	19383Y	PARTICIPANT	\N	PRESENT	0
452705	448737	19762G	PARTICIPANT	\N	PRESENT	0
452706	448737	08024S	PARTICIPANT	\N	PRESENT	0
452707	448737	19701S	PARTICIPANT	\N	PRESENT	0
452708	448737	08049C	PARTICIPANT	\N	PRESENT	0
452709	448737	04018C	PARTICIPANT	\N	PRESENT	0
452710	448737	19621T	PARTICIPANT	\N	PRESENT	0
452711	448737	14201E	PARTICIPANT	\N	PRESENT	0
452712	448737	19367Y	PARTICIPANT	\N	PRESENT	0
452713	448737	14241N	PARTICIPANT	\N	PRESENT	0
452714	448737	14173T	PARTICIPANT	\N	PRESENT	0
452715	448737	19387D	PARTICIPANT	\N	PRESENT	0
452716	448737	19447X	PARTICIPANT	\N	PRESENT	0
452717	448737	19719D	PARTICIPANT	\N	PRESENT	0
452718	448737	19573D	PARTICIPANT	\N	PRESENT	0
452719	448737	19269X	PARTICIPANT	\N	PRESENT	0
452720	448737	19794Q	PARTICIPANT	\N	PRESENT	0
452721	448737	14133K	PARTICIPANT	\N	PRESENT	0
452722	448737	92040Q	PARTICIPANT	\N	PRESENT	0
452723	448737	19467C	PARTICIPANT	\N	PRESENT	0
452724	448737	19543W	PARTICIPANT	\N	PRESENT	0
452725	448737	14093U	PARTICIPANT	\N	PRESENT	0
452726	448737	14119M	PARTICIPANT	\N	PRESENT	0
452727	448737	11049P	PARTICIPANT	\N	PRESENT	0
452728	448737	19631V	PARTICIPANT	\N	PRESENT	0
452729	448737	14115H	PARTICIPANT	\N	PRESENT	0
452730	448737	11027H	PARTICIPANT	\N	PRESENT	0
452731	448737	08047A	PARTICIPANT	\N	PRESENT	0
452732	448737	14105F	PARTICIPANT	\N	PRESENT	0
452733	448737	11074Q	PARTICIPANT	\N	PRESENT	0
452734	448737	19697Q	PARTICIPANT	\N	PRESENT	0
452735	448737	17583W	PARTICIPANT	\N	PRESENT	0
452736	448737	14147R	PARTICIPANT	\N	PRESENT	0
452737	448737	97011G	PARTICIPANT	\N	PRESENT	0
452738	448737	01028R	PARTICIPANT	\N	PRESENT	0
452739	448737	11103C	PARTICIPANT	\N	PRESENT	0
452740	448737	14229S	PARTICIPANT	\N	PRESENT	0
452741	448737	08045X	PARTICIPANT	\N	PRESENT	0
452742	448737	04069P	PARTICIPANT	\N	PRESENT	0
452743	448737	14217N	PARTICIPANT	\N	PRESENT	0
452744	448737	14331P	PARTICIPANT	\N	PRESENT	0
452745	448737	19599P	PARTICIPANT	\N	PRESENT	0
452746	448737	14079W	PARTICIPANT	\N	PRESENT	0
452747	448737	12016W	PARTICIPANT	\N	PRESENT	0
452748	448737	14061L	PARTICIPANT	\N	PRESENT	0
452749	448737	04042C	PARTICIPANT	\N	PRESENT	0
452750	448737	19647E	PARTICIPANT	\N	PRESENT	0
452751	448737	19671E	PARTICIPANT	\N	PRESENT	0
452752	448737	19649G	PARTICIPANT	\N	PRESENT	0
452753	448737	11045K	PARTICIPANT	\N	PRESENT	0
452754	448737	19581D	PARTICIPANT	\N	PRESENT	0
452755	448737	11064N	PARTICIPANT	\N	PRESENT	0
452756	448737	14085U	PARTICIPANT	\N	PRESENT	0
452757	448737	19527W	PARTICIPANT	\N	PRESENT	0
452758	448737	11109J	PARTICIPANT	\N	PRESENT	0
452759	448737	19551W	PARTICIPANT	\N	PRESENT	0
452760	448737	19503N	PARTICIPANT	\N	PRESENT	0
452761	448737	19251M	PARTICIPANT	\N	PRESENT	0
452762	448737	19333N	PARTICIPANT	\N	PRESENT	0
452763	448737	14001X	PARTICIPANT	\N	PRESENT	0
452764	448737	05008E	PARTICIPANT	\N	PRESENT	0
452765	448737	08014Q	PARTICIPANT	\N	PRESENT	0
452766	448737	19703U	PARTICIPANT	\N	PRESENT	0
452767	448737	19549D	PARTICIPANT	\N	PRESENT	0
452768	448737	19673G	PARTICIPANT	\N	PRESENT	0
452769	448737	19591F	PARTICIPANT	\N	PRESENT	0
452770	448737	19729F	PARTICIPANT	\N	PRESENT	0
452771	448737	11026G	PARTICIPANT	\N	PRESENT	0
452772	448737	11010L	PARTICIPANT	\N	PRESENT	0
452773	448737	14081Q	PARTICIPANT	\N	PRESENT	0
452774	448737	14031R	PARTICIPANT	\N	PRESENT	0
452775	448737	11110B	PARTICIPANT	\N	PRESENT	0
452776	448737	14257W	PARTICIPANT	\N	PRESENT	0
452777	448737	04043D	PARTICIPANT	\N	PRESENT	0
452778	448737	14259Y	PARTICIPANT	\N	PRESENT	0
452779	448737	15447F	PARTICIPANT	\N	PRESENT	0
452780	448737	80013X	PARTICIPANT	\N	PRESENT	0
452781	448737	19768N	PARTICIPANT	\N	PRESENT	0
452782	448737	08017T	PARTICIPANT	\N	PRESENT	0
452783	448737	11066Q	PARTICIPANT	\N	PRESENT	0
452784	448737	08048B	PARTICIPANT	\N	PRESENT	0
452785	448737	98050T	PARTICIPANT	\N	PRESENT	0
452786	448737	14097Y	PARTICIPANT	\N	PRESENT	0
452787	448737	19413M	PARTICIPANT	\N	PRESENT	0
452788	448737	11048N	PARTICIPANT	\N	PRESENT	0
452789	448737	19725B	PARTICIPANT	\N	PRESENT	0
452790	448737	04049K	PARTICIPANT	\N	PRESENT	0
452791	448737	05012A	PARTICIPANT	\N	PRESENT	0
452792	448737	19329S	PARTICIPANT	\N	PRESENT	0
452793	448737	08034U	PARTICIPANT	\N	PRESENT	0
452794	448737	19533U	PARTICIPANT	\N	PRESENT	0
452795	448737	10006L	PARTICIPANT	\N	PRESENT	0
452796	448737	14239U	PARTICIPANT	\N	PRESENT	0
452797	448737	19798U	PARTICIPANT	\N	PRESENT	0
452798	448737	14193X	PARTICIPANT	\N	PRESENT	0
452799	448737	14237S	PARTICIPANT	\N	PRESENT	0
452800	448737	19515S	PARTICIPANT	\N	PRESENT	0
452801	448737	14191V	PARTICIPANT	\N	PRESENT	0
452802	448737	11080N	PARTICIPANT	\N	PRESENT	0
452803	448737	01034P	PARTICIPANT	\N	PRESENT	0
452804	448737	19766L	PARTICIPANT	\N	PRESENT	0
452805	448737	19369B	PARTICIPANT	\N	PRESENT	0
452806	448737	19691J	PARTICIPANT	\N	PRESENT	0
452807	448737	11115U	PARTICIPANT	\N	PRESENT	0
452808	448737	14041T	PARTICIPANT	\N	PRESENT	0
452809	448737	14205J	PARTICIPANT	\N	PRESENT	0
452810	448737	08069G	PARTICIPANT	\N	PRESENT	0
452812	448737	04040A	PARTICIPANT	\N	PRESENT	0
452813	448737	01057W	PARTICIPANT	\N	PRESENT	0
452814	448737	87003B	PARTICIPANT	\N	PRESENT	0
452815	448737	19335Q	PARTICIPANT	\N	PRESENT	0
452816	448737	14103D	PARTICIPANT	\N	PRESENT	0
452817	448737	11090Q	PARTICIPANT	\N	PRESENT	0
452819	448737	19713W	PARTICIPANT	\N	PRESENT	0
452820	448737	04008A	PARTICIPANT	\N	PRESENT	0
452821	448737	14069U	PARTICIPANT	\N	PRESENT	0
452823	448737	14249W	PARTICIPANT	\N	PRESENT	0
452824	448737	14021P	PARTICIPANT	\N	PRESENT	0
452826	448737	14053L	PARTICIPANT	\N	PRESENT	0
452828	448737	14087W	PARTICIPANT	\N	PRESENT	0
452829	448737	14215L	PARTICIPANT	\N	PRESENT	0
452831	448737	19569H	PARTICIPANT	\N	PRESENT	0
452832	448737	19479G	PARTICIPANT	\N	PRESENT	0
452833	448737	19689Q	PARTICIPANT	\N	PRESENT	0
452835	448737	19669L	PARTICIPANT	\N	PRESENT	0
452836	448737	19643A	PARTICIPANT	\N	PRESENT	0
452837	448737	17589D	PARTICIPANT	\N	PRESENT	0
452838	448737	04071H	PARTICIPANT	\N	PRESENT	0
452841	448737	14169X	PARTICIPANT	\N	PRESENT	0
452843	448737	01048V	PARTICIPANT	\N	PRESENT	0
452844	448737	16685X	PARTICIPANT	\N	PRESENT	0
452845	448737	08028W	PARTICIPANT	\N	PRESENT	0
452846	448737	19735D	PARTICIPANT	\N	PRESENT	0
452847	448737	04033B	PARTICIPANT	\N	PRESENT	0
452848	448737	14187A	PARTICIPANT	\N	PRESENT	0
452849	448737	01025N	PARTICIPANT	\N	PRESENT	0
452850	448737	14071N	PARTICIPANT	\N	PRESENT	0
452851	448737	14089Y	PARTICIPANT	\N	PRESENT	0
452852	448737	11097X	PARTICIPANT	\N	PRESENT	0
452853	448737	19489J	PARTICIPANT	\N	PRESENT	0
452854	448737	19421M	PARTICIPANT	\N	PRESENT	0
452855	448737	14033T	PARTICIPANT	\N	PRESENT	0
452856	448737	19679N	PARTICIPANT	\N	PRESENT	0
452857	448737	19749K	PARTICIPANT	\N	PRESENT	0
452858	448737	14083S	PARTICIPANT	\N	PRESENT	0
452859	448737	04097T	PARTICIPANT	\N	PRESENT	0
452860	448737	14073Q	PARTICIPANT	\N	PRESENT	0
452861	448737	08039A	PARTICIPANT	\N	PRESENT	0
452862	448737	08020N	PARTICIPANT	\N	PRESENT	0
452863	448737	08010L	PARTICIPANT	\N	PRESENT	0
452864	448737	19521Q	PARTICIPANT	\N	PRESENT	0
452865	448737	14123H	PARTICIPANT	\N	PRESENT	0
452866	448737	07004J	PARTICIPANT	\N	PRESENT	0
452867	448737	14255U	PARTICIPANT	\N	PRESENT	0
452868	448737	04086Q	PARTICIPANT	\N	PRESENT	0
452869	448737	01024M	PARTICIPANT	\N	PRESENT	0
452870	448737	04092N	PARTICIPANT	\N	PRESENT	0
452871	448737	86034E	PARTICIPANT	\N	PRESENT	0
452872	448737	04044E	PARTICIPANT	\N	PRESENT	0
452873	448737	19747H	PARTICIPANT	\N	PRESENT	0
452874	448737	01058X	PARTICIPANT	\N	PRESENT	0
452875	448737	99004R	PARTICIPANT	\N	PRESENT	0
452876	448737	95030B	PARTICIPANT	\N	PRESENT	0
452877	448737	04038G	PARTICIPANT	\N	PRESENT	0
452878	448737	04047H	PARTICIPANT	\N	PRESENT	0
428177	428176	19515S	PARTICIPANT	\N	PRESENT	0
428179	428178	19515S	PARTICIPANT	\N	PRESENT	0
431671	424883	04049K	PARTICIPANT	\N	PRESENT	0
431672	424883	14030Q	PARTICIPANT	\N	PRESENT	0
431673	424883	04033B	PARTICIPANT	\N	PRESENT	0
431674	424883	14021P	PARTICIPANT	\N	PRESENT	0
431675	424883	14034U	PARTICIPANT	\N	PRESENT	0
431676	424883	19441R	PARTICIPANT	\N	PRESENT	0
431677	424883	01057W	PARTICIPANT	\N	PRESENT	0
431678	424883	19533U	PARTICIPANT	\N	PRESENT	0
431669	424883	14219Q	PARTICIPANT	\N	PRESENT	0
431670	424883	19479G	PARTICIPANT	\N	PRESENT	0
431679	424883	04086Q	PARTICIPANT	\N	PRESENT	0
431680	424883	01028R	PARTICIPANT	\N	PRESENT	0
431681	424883	14249W	PARTICIPANT	\N	PRESENT	0
434042	434041	08018U	PARTICIPANT	\N	PRESENT	0
434044	434043	08018U	PARTICIPANT	\N	PRESENT	0
438466	438465	08052W	PARTICIPANT	\N	PRESENT	0
438468	438465	19569H	PARTICIPANT	\N	PRESENT	0
439614	426318	80013X	PARTICIPANT	\N	PRESENT	0
439628	426318	14069U	PARTICIPANT	\N	PRESENT	0
439629	426318	04086Q	PARTICIPANT	\N	PRESENT	0
439929	438470	14257W	PARTICIPANT	\N	EXCUSE	0
439938	438470	92040Q	PARTICIPANT	\N	EXCUSE	0
439975	439974	19671E	PARTICIPANT	\N	PRESENT	0
439977	439976	08034U	PARTICIPANT	\N	PRESENT	0
439978	439976	04040A	PARTICIPANT	\N	PRESENT	0
439979	439976	14357A	PARTICIPANT	\N	PRESENT	0
439980	439976	97011G	PARTICIPANT	\N	PRESENT	0
439981	439976	19737F	PARTICIPANT	\N	PRESENT	0
440428	438470	19820Y	PARTICIPANT	\N	EXCUSE	0
440460	439891	19563B	PARTICIPANT	\N	PRESENT	0
440461	439891	14033T	PARTICIPANT	\N	PRESENT	0
440463	440427	19593H	PARTICIPANT	\N	PRESENT	0
440464	440427	04070G	PRESIDENT	0	PRESENT	0
440465	440427	19699S	PARTICIPANT	\N	PRESENT	0
440466	440427	19611R	PARTICIPANT	\N	PRESENT	0
440467	440427	08043V	PARTICIPANT	\N	PRESENT	0
440468	440427	87003B	PARTICIPANT	\N	PRESENT	0
440469	440427	14229S	PARTICIPANT	\N	PRESENT	0
440470	440427	19731Y	PARTICIPANT	\N	PRESENT	0
440471	440427	14039A	PARTICIPANT	\N	PRESENT	0
440472	440427	19735D	PARTICIPANT	\N	PRESENT	0
440473	440427	14107H	PARTICIPANT	\N	PRESENT	0
440475	440427	11083R	PARTICIPANT	\N	PRESENT	0
440476	440427	11104D	PARTICIPANT	\N	PRESENT	0
440477	440427	19749K	PARTICIPANT	\N	PRESENT	0
440478	440427	04018C	PARTICIPANT	\N	PRESENT	0
440479	440427	19758L	PARTICIPANT	\N	PRESENT	0
440480	440427	08039A	PARTICIPANT	\N	PRESENT	0
440491	440427	08031R	PARTICIPANT	\N	EXCUSE	0
440492	440427	14030Q	PARTICIPANT	\N	PRESENT	0
440493	427774	86034E	PARTICIPANT	\N	PRESENT	0
440494	440427	14059S	PARTICIPANT	\N	PRESENT	0
440495	440427	19399H	PARTICIPANT	\N	PRESENT	0
440496	440427	14241N	PARTICIPANT	\N	PRESENT	0
440497	439891	11099A	PARTICIPANT	\N	PRESENT	0
440498	440427	08012N	PARTICIPANT	\N	PRESENT	0
440499	440427	14249W	PARTICIPANT	\N	PRESENT	0
440500	440427	14109K	PARTICIPANT	\N	PRESENT	0
440501	440427	11043H	PARTICIPANT	\N	PRESENT	0
440502	440427	14061L	PARTICIPANT	\N	PRESENT	0
440503	440427	14073Q	PARTICIPANT	\N	PRESENT	0
440504	440427	14251Q	PARTICIPANT	\N	PRESENT	0
440505	440427	08017T	PARTICIPANT	\N	PRESENT	0
440506	440427	19335Q	PARTICIPANT	\N	PRESENT	0
440507	440427	14123H	PARTICIPANT	\N	PRESENT	0
440531	439891	19591F	PARTICIPANT	\N	PRESENT	0
440532	439891	19269X	PARTICIPANT	\N	PRESENT	0
440533	439891	11056N	PARTICIPANT	\N	PRESENT	0
440534	439891	19695N	PARTICIPANT	\N	PRESENT	0
440570	439892	19768N	PARTICIPANT	\N	PRESENT	0
440571	439892	19515S	PARTICIPANT	\N	PRESENT	0
440572	439892	19782L	PARTICIPANT	\N	PRESENT	0
440573	439892	01043Q	PARTICIPANT	\N	PRESENT	0
440574	439892	14357A	PARTICIPANT	\N	PRESENT	0
440575	439892	19441R	PARTICIPANT	\N	PRESENT	0
440576	439892	11099A	PARTICIPANT	\N	PRESENT	0
440577	439892	08068F	PARTICIPANT	\N	PRESENT	0
440578	439892	04049K	PARTICIPANT	\N	PRESENT	0
440579	439892	19705W	PARTICIPANT	\N	PRESENT	0
440580	439892	08015R	PARTICIPANT	\N	PRESENT	0
440581	439892	14197C	PARTICIPANT	\N	PRESENT	0
440582	439892	19369B	PARTICIPANT	\N	PRESENT	0
440583	439892	19511N	PARTICIPANT	\N	PRESENT	0
440584	439892	19563B	PARTICIPANT	\N	PRESENT	0
440585	439892	14265W	PARTICIPANT	\N	PRESENT	0
440586	439892	14329V	PARTICIPANT	\N	PRESENT	0
440587	439892	19591F	PARTICIPANT	\N	PRESENT	0
440588	439892	14135M	PARTICIPANT	\N	PRESENT	0
440589	439892	14187A	PARTICIPANT	\N	PRESENT	0
440590	439892	19695N	PARTICIPANT	\N	PRESENT	0
440591	439892	11090Q	PRESIDENT	0	PRESENT	0
440592	439892	01025N	PARTICIPANT	\N	PRESENT	0
440593	439892	14033T	PARTICIPANT	\N	PRESENT	0
440594	439892	19269X	PARTICIPANT	\N	PRESENT	0
440595	439892	14205J	PARTICIPANT	\N	PRESENT	0
440596	439892	04088S	PARTICIPANT	\N	PRESENT	0
440597	439892	11056N	PARTICIPANT	\N	PRESENT	0
440598	439892	04089T	PARTICIPANT	\N	PRESENT	0
440599	439892	11101A	PARTICIPANT	\N	PRESENT	0
440600	439892	19507S	PARTICIPANT	\N	PRESENT	0
440601	439892	19747H	PARTICIPANT	\N	PRESENT	0
440602	439892	14207L	PARTICIPANT	\N	PRESENT	0
440603	439892	14257W	PARTICIPANT	\N	PRESENT	0
440604	439892	19467C	PARTICIPANT	\N	EXCUSE	0
440605	439892	14081Q	PARTICIPANT	\N	EXCUSE	0
440606	439892	11081P	PARTICIPANT	\N	EXCUSE	0
440607	439892	19631V	PARTICIPANT	\N	EXCUSE	0
440608	440256	19383Y	PARTICIPANT	\N	PRESENT	0
440609	440256	19701S	PARTICIPANT	\N	PRESENT	0
440610	440256	19794Q	PARTICIPANT	\N	PRESENT	0
440611	440256	19549D	PARTICIPANT	\N	PRESENT	0
440612	440256	19387D	PARTICIPANT	\N	PRESENT	0
440613	440256	19820Y	PARTICIPANT	\N	PRESENT	0
440614	440256	14219Q	PARTICIPANT	\N	PRESENT	0
440615	440256	19826F	PARTICIPANT	\N	PRESENT	0
440616	440256	14221J	PARTICIPANT	\N	PRESENT	0
440617	440256	19599P	PARTICIPANT	\N	PRESENT	0
440618	440256	18083K	PARTICIPANT	\N	PRESENT	0
440619	440256	14237S	PARTICIPANT	\N	PRESENT	0
440620	440256	19551W	PARTICIPANT	\N	PRESENT	0
440621	440256	05012A	PARTICIPANT	\N	PRESENT	0
440622	440256	14051J	PARTICIPANT	\N	PRESENT	0
440623	440256	08060W	PARTICIPANT	\N	PRESENT	0
440624	440256	19503N	PARTICIPANT	\N	PRESENT	0
440625	440256	19347U	PARTICIPANT	\N	PRESENT	0
440626	440256	14157T	PARTICIPANT	\N	PRESENT	0
440627	440256	08024S	PARTICIPANT	\N	PRESENT	0
440628	440256	19681G	PARTICIPANT	\N	PRESENT	0
440629	440256	14038Y	PARTICIPANT	\N	PRESENT	0
440630	440256	14103D	PARTICIPANT	\N	PRESENT	0
440631	440256	14031R	PARTICIPANT	\N	PRESENT	0
440632	440256	19713W	PARTICIPANT	\N	PRESENT	0
440633	440256	14169X	PARTICIPANT	\N	PRESENT	0
440634	440256	15447F	PARTICIPANT	\N	PRESENT	0
440635	440256	14093U	PARTICIPANT	\N	PRESENT	0
440636	440256	08009T	PRESIDENT	0	PRESENT	0
440637	440256	19737F	PARTICIPANT	\N	PRESENT	0
440638	440256	19739H	PARTICIPANT	\N	PRESENT	0
440639	440256	19333N	PARTICIPANT	\N	EXCUSE	0
440640	440256	17583W	PARTICIPANT	\N	EXCUSE	0
440641	440256	19745F	PARTICIPANT	\N	EXCUSE	0
440642	440256	08055A	PARTICIPANT	\N	EXCUSE	0
440643	440256	19659J	PARTICIPANT	\N	EXCUSE	0
440644	440256	19637C	PARTICIPANT	\N	EXCUSE	0
440645	439635	19647E	PARTICIPANT	\N	PRESENT	0
440707	427774	14227Q	PARTICIPANT	\N	PRESENT	0
440708	427774	14085U	PARTICIPANT	\N	PRESENT	0
440709	427774	14051J	PARTICIPANT	\N	PRESENT	0
440710	427774	14121F	PARTICIPANT	\N	PRESENT	0
440711	427774	14111D	PARTICIPANT	\N	PRESENT	0
440712	427774	19319Q	PARTICIPANT	\N	PRESENT	0
440713	427774	19511N	PARTICIPANT	\N	PRESENT	0
440714	427774	08017T	PARTICIPANT	\N	PRESENT	0
440715	427774	14219Q	PARTICIPANT	\N	PRESENT	0
440716	427774	11041F	PARTICIPANT	\N	PRESENT	0
440717	427774	19782L	PARTICIPANT	\N	PRESENT	0
440718	427774	08024S	PARTICIPANT	\N	PRESENT	0
440719	427774	19593H	PARTICIPANT	\N	PRESENT	0
440720	427774	95037J	PARTICIPANT	\N	PRESENT	0
440721	427774	11040E	PARTICIPANT	\N	PRESENT	0
440722	427774	14201E	PARTICIPANT	\N	PRESENT	0
440723	427774	14225N	PARTICIPANT	\N	PRESENT	0
440724	427774	08061X	PARTICIPANT	\N	PRESENT	0
440726	427774	11031D	PARTICIPANT	\N	PRESENT	0
440727	427774	19727D	PARTICIPANT	\N	PRESENT	0
440728	427774	19687N	PARTICIPANT	\N	PRESENT	0
450660	450659	04008A	PARTICIPANT	\N	PRESENT	0
450935	450934	04042C	PARTICIPANT	\N	PRESENT	0
450936	450934	08047A	PARTICIPANT	\N	PRESENT	0
450937	450934	14267Y	PARTICIPANT	\N	PRESENT	0
450938	450934	19709B	PARTICIPANT	\N	PRESENT	0
450939	450934	16685X	PARTICIPANT	\N	PRESENT	0
450940	450934	14193X	PARTICIPANT	\N	PRESENT	0
450941	450934	19319Q	PARTICIPANT	\N	PRESENT	0
453976	453974	04049K	PARTICIPANT	\N	PRESENT	0
453978	453977	04049K	PARTICIPANT	\N	PRESENT	0
453979	453977	16685X	PARTICIPANT	\N	PRESENT	0
453981	453980	04049K	PARTICIPANT	\N	PRESENT	0
453982	453980	16685X	PARTICIPANT	\N	PRESENT	0
453983	448743	14083S	PARTICIPANT	\N	PRESENT	0
453985	453984	14083S	PARTICIPANT	\N	PRESENT	0
453986	453984	14061L	PARTICIPANT	\N	PRESENT	0
453988	453987	14083S	PARTICIPANT	\N	PRESENT	0
453989	453987	14061L	PARTICIPANT	\N	PRESENT	0
454007	453567	19703U	PARTICIPANT	\N	PRESENT	0
454009	454008	14207L	PARTICIPANT	\N	PRESENT	0
454010	454008	14205J	PARTICIPANT	\N	PRESENT	0
454012	454011	89017R	PARTICIPANT	\N	PRESENT	0
454013	454011	04085P	PARTICIPANT	\N	PRESENT	0
454014	454011	04059M	PARTICIPANT	\N	PRESENT	0
454015	454011	05008E	PARTICIPANT	\N	PRESENT	0
454016	454011	96004D	PARTICIPANT	\N	PRESENT	0
454017	454011	14038Y	PARTICIPANT	\N	PRESENT	0
454018	454011	88008L	PARTICIPANT	\N	PRESENT	0
454019	454011	11027H	PARTICIPANT	\N	PRESENT	0
454020	454011	14079W	PARTICIPANT	\N	PRESENT	0
454021	454011	07033P	PARTICIPANT	\N	PRESENT	0
454022	454011	14187A	PARTICIPANT	\N	PRESENT	0
454023	454011	01043Q	PARTICIPANT	\N	PRESENT	0
454024	454011	14205J	PARTICIPANT	\N	PRESENT	0
454025	454011	14251Q	PARTICIPANT	\N	PRESENT	0
454026	454011	11085T	PARTICIPANT	\N	PRESENT	0
454027	454011	04092N	PARTICIPANT	\N	PRESENT	0
454028	454011	98018T	PARTICIPANT	\N	PRESENT	0
454029	454011	05012A	PARTICIPANT	\N	PRESENT	0
454030	454011	11012A	PARTICIPANT	\N	PRESENT	0
454031	454011	01028R	PARTICIPANT	\N	PRESENT	0
454033	454032	04085P	PARTICIPANT	\N	PRESENT	0
454034	454032	04059M	PARTICIPANT	\N	PRESENT	0
454035	454032	96004D	PARTICIPANT	\N	PRESENT	0
454036	454032	04042C	PARTICIPANT	\N	PRESENT	0
454037	454032	04086Q	PARTICIPANT	\N	PRESENT	0
454038	454032	14079W	PARTICIPANT	\N	PRESENT	0
454039	454032	11070L	PARTICIPANT	\N	PRESENT	0
454040	454032	11074Q	PARTICIPANT	\N	PRESENT	0
454041	454032	14034U	PARTICIPANT	\N	PRESENT	0
454042	454032	14021P	PARTICIPANT	\N	PRESENT	0
454043	454032	01043Q	PARTICIPANT	\N	PRESENT	0
454044	454032	14251Q	PARTICIPANT	\N	PRESENT	0
454045	454032	11085T	PARTICIPANT	\N	PRESENT	0
454046	454032	08009T	PARTICIPANT	\N	PRESENT	0
454047	454032	04092N	PARTICIPANT	\N	PRESENT	0
454048	454032	04070G	PARTICIPANT	\N	PRESENT	0
454049	454032	08061X	PARTICIPANT	\N	PRESENT	0
454050	454032	05012A	PARTICIPANT	\N	PRESENT	0
454051	454032	11090Q	PARTICIPANT	\N	PRESENT	0
454052	454032	11012A	PARTICIPANT	\N	PRESENT	0
454053	454032	04033B	PARTICIPANT	\N	PRESENT	0
454057	454056	04042C	PARTICIPANT	\N	PRESENT	0
454058	454056	08047A	PARTICIPANT	\N	PRESENT	0
454059	454056	11027H	PARTICIPANT	\N	PRESENT	0
454060	454056	95037J	PARTICIPANT	\N	PRESENT	0
454061	454056	11066Q	PARTICIPANT	\N	PRESENT	0
454062	454056	12041X	PARTICIPANT	\N	PRESENT	0
454063	454056	14105F	PARTICIPANT	\N	PRESENT	0
454064	454056	14193X	PARTICIPANT	\N	PRESENT	0
454066	454056	19319Q	PARTICIPANT	\N	PRESENT	0
454070	454069	07004J	PARTICIPANT	\N	PRESENT	0
454072	454071	07004J	PARTICIPANT	\N	PRESENT	0
454073	454071	12016W	PARTICIPANT	\N	PRESENT	0
454075	454074	07004J	PARTICIPANT	\N	PRESENT	0
454076	454074	12016W	PARTICIPANT	\N	PRESENT	0
454078	454077	07004J	PARTICIPANT	\N	PRESENT	0
454080	454079	11048N	PARTICIPANT	\N	PRESENT	0
454082	454081	19647E	PARTICIPANT	\N	PRESENT	0
454083	454081	11070L	PARTICIPANT	\N	PRESENT	0
454085	454084	14083S	PARTICIPANT	\N	PRESENT	0
454087	454086	08011M	PARTICIPANT	\N	PRESENT	0
454089	454088	04086Q	PARTICIPANT	\N	PRESENT	0
454091	454090	99004R	PARTICIPANT	\N	PRESENT	0
454093	454092	99004R	PARTICIPANT	\N	PRESENT	0
454107	445947	04038G	PARTICIPANT	\N	PRESENT	0
454108	445947	99004R	PRESIDENT	0	PRESENT	0
454128	454127	11115U	PARTICIPANT	\N	PRESENT	0
454129	454127	11041F	PARTICIPANT	\N	PRESENT	0
454131	454130	11115U	PARTICIPANT	\N	PRESENT	0
454132	454130	11041F	PARTICIPANT	\N	PRESENT	0
454133	454130	14235Q	PARTICIPANT	\N	PRESENT	0
454136	454134	19503N	PARTICIPANT	\N	PRESENT	0
454139	454138	14157T	PARTICIPANT	\N	PRESENT	0
454140	454138	19599P	PARTICIPANT	\N	PRESENT	0
454142	454141	19599P	PARTICIPANT	\N	PRESENT	0
454143	454141	14157T	PARTICIPANT	\N	PRESENT	0
454145	454144	07004J	PARTICIPANT	\N	PRESENT	0
454156	454154	19503N	PARTICIPANT	\N	PRESENT	0
454159	454157	19503N	PARTICIPANT	\N	PRESENT	0
454162	454160	19503N	PARTICIPANT	\N	PRESENT	0
454165	454163	19503N	PARTICIPANT	\N	PRESENT	0
454168	454166	19503N	PARTICIPANT	\N	PRESENT	0
454170	454169	14089Y	PARTICIPANT	\N	PRESENT	0
454172	454171	14089Y	PARTICIPANT	\N	PRESENT	0
454173	454169	11026G	PARTICIPANT	\N	PRESENT	0
454175	454174	14089Y	PARTICIPANT	\N	PRESENT	0
454177	454176	14089Y	PARTICIPANT	\N	PRESENT	0
454189	445947	19467C	PARTICIPANT	\N	PRESENT	0
454192	445947	14107H	PARTICIPANT	\N	EXCUSE	0
454194	445947	11097X	PARTICIPANT	\N	PRESENT	0
454196	445947	08048B	PARTICIPANT	\N	EXCUSE	0
454198	454197	04040A	PARTICIPANT	0	EXCUSE	0
454199	445947	19667J	PARTICIPANT	\N	EXCUSE	0
454200	445947	11066Q	PARTICIPANT	\N	EXCUSE	0
454201	454197	19735D	PARTICIPANT	\N	EXCUSE	0
454202	454197	14071N	PARTICIPANT	\N	EXCUSE	0
454204	454203	11070L	PARTICIPANT	\N	PRESENT	0
454211	454205	19697Q	PARTICIPANT	\N	PRESENT	0
454212	454205	11097X	PARTICIPANT	\N	PRESENT	0
454213	454205	01034P	PARTICIPANT	\N	PRESENT	0
454214	454206	19697Q	PARTICIPANT	\N	PRESENT	0
454215	454206	11097X	PARTICIPANT	\N	PRESENT	0
454216	454206	01034P	PARTICIPANT	\N	PRESENT	0
454217	454207	19697Q	PARTICIPANT	\N	PRESENT	0
454218	454207	11097X	PARTICIPANT	\N	PRESENT	0
454219	454207	01034P	PARTICIPANT	\N	PRESENT	0
454220	454208	19697Q	PARTICIPANT	\N	PRESENT	0
454221	454208	11097X	PARTICIPANT	\N	PRESENT	0
454222	454208	01034P	PARTICIPANT	\N	PRESENT	0
454223	454209	19697Q	PARTICIPANT	\N	PRESENT	0
454224	454209	11097X	PARTICIPANT	\N	PRESENT	0
454225	454210	19697Q	PARTICIPANT	\N	PRESENT	0
454226	454210	11097X	PARTICIPANT	\N	PRESENT	0
454227	445947	19369B	PARTICIPANT	\N	EXCUSE	0
454229	451300	96004D	PARTICIPANT	\N	EXCUSE	0
454230	451300	14225N	PARTICIPANT	\N	EXCUSE	0
454231	451300	14135M	PARTICIPANT	\N	EXCUSE	0
454252	454197	04044E	PARTICIPANT	\N	EXCUSE	0
454255	454254	01048V	PARTICIPANT	\N	PRESENT	0
454257	454256	14089Y	PARTICIPANT	\N	PRESENT	0
454261	454197	19565D	PARTICIPANT	\N	EXCUSE	0
454267	448744	11027H	PARTICIPANT	\N	PRESENT	0
454268	448744	19565D	PARTICIPANT	\N	PRESENT	0
454269	448744	11045K	PARTICIPANT	\N	PRESENT	0
454270	448744	14265W	PARTICIPANT	\N	PRESENT	0
454271	448744	14038Y	PARTICIPANT	\N	PRESENT	0
454272	448744	14253S	PARTICIPANT	\N	PRESENT	0
454273	448744	19507S	PARTICIPANT	\N	PRESENT	0
454274	448744	19703U	PARTICIPANT	\N	PRESENT	0
454275	448744	14179A	PARTICIPANT	\N	PRESENT	0
454276	448744	14195A	PARTICIPANT	\N	PRESENT	0
454277	445947	19551W	PARTICIPANT	\N	EXCUSE	0
454278	445947	19479G	PARTICIPANT	\N	EXCUSE	0
454279	448744	19820Y	PARTICIPANT	\N	PRESENT	0
454280	448744	19415P	PARTICIPANT	\N	PRESENT	0
454281	448744	19631V	PARTICIPANT	\N	PRESENT	0
454282	448744	19725B	PARTICIPANT	\N	PRESENT	0
454283	448744	08073C	PARTICIPANT	\N	PRESENT	0
454284	448744	19713W	PARTICIPANT	\N	PRESENT	0
454285	448744	14030Q	PARTICIPANT	\N	PRESENT	0
454286	448744	14237S	PARTICIPANT	\N	PRESENT	0
454287	448744	19479G	PARTICIPANT	\N	PRESENT	0
429346	427859	04042C	PRESIDENT	0	PRESENT	0
429347	427859	11054L	PARTICIPANT	\N	PRESENT	0
429348	427859	11066Q	PARTICIPANT	\N	PRESENT	0
429349	427859	19421M	PARTICIPANT	\N	PRESENT	0
429350	427859	14193X	PARTICIPANT	\N	PRESENT	0
429351	427859	08061X	PARTICIPANT	\N	PRESENT	0
429352	427859	08047A	PARTICIPANT	\N	PRESENT	0
429353	427859	14097Y	PARTICIPANT	\N	PRESENT	0
429354	427859	11041F	PARTICIPANT	\N	PRESENT	0
429355	427859	14235Q	PARTICIPANT	\N	PRESENT	0
429356	427859	08058D	PARTICIPANT	\N	PRESENT	0
429357	427859	19251M	PARTICIPANT	\N	PRESENT	0
429358	427859	14028W	PARTICIPANT	\N	PRESENT	0
429359	427859	19721W	PARTICIPANT	\N	PRESENT	0
429360	427859	19319Q	PARTICIPANT	\N	PRESENT	0
429361	427859	98018T	PARTICIPANT	\N	PRESENT	0
429362	427859	98022P	PARTICIPANT	\N	PRESENT	0
429363	427859	14267Y	PARTICIPANT	\N	PRESENT	0
429364	427859	11064N	PARTICIPANT	\N	PRESENT	0
429365	427859	98050T	PARTICIPANT	\N	PRESENT	0
429366	427859	14211G	PARTICIPANT	\N	PRESENT	0
429367	427859	19583F	PARTICIPANT	\N	PRESENT	0
429368	427859	14255U	PARTICIPANT	\N	PRESENT	0
429369	428662	19533U	PARTICIPANT	\N	PRESENT	0
429370	428662	04057K	PARTICIPANT	\N	PRESENT	0
429371	428662	14109K	PARTICIPANT	\N	PRESENT	0
429372	427859	95037J	PARTICIPANT	\N	PRESENT	0
429373	427859	98029W	PARTICIPANT	\N	PRESENT	0
429374	427859	01062T	PARTICIPANT	\N	PRESENT	0
429375	427448	19551W	PARTICIPANT	\N	PRESENT	0
429376	427448	19347U	PARTICIPANT	\N	PRESENT	0
429377	427859	08056B	PARTICIPANT	\N	PRESENT	0
429378	427859	08053X	PARTICIPANT	\N	PRESENT	0
429379	428373	14089Y	PARTICIPANT	\N	PRESENT	0
429380	428373	14069U	PARTICIPANT	\N	PRESENT	0
429381	428373	11049P	PARTICIPANT	\N	PRESENT	0
429382	428373	08044W	PARTICIPANT	\N	EXCUSE	0
429383	428202	96004D	PARTICIPANT	\N	PRESENT	0
429384	428202	08073C	PARTICIPANT	\N	PRESENT	0
429385	428202	99004R	PARTICIPANT	\N	PRESENT	0
429386	427448	19637C	PARTICIPANT	\N	PRESENT	0
429387	427859	14079W	PARTICIPANT	\N	PRESENT	0
429388	427859	14055N	PARTICIPANT	\N	PRESENT	0
429389	427448	18083K	PARTICIPANT	\N	PRESENT	0
429390	427859	95030B	PARTICIPANT	\N	PRESENT	0
429391	427859	11115U	PARTICIPANT	\N	PRESENT	0
429392	427448	19685L	PARTICIPANT	\N	PRESENT	0
429393	427859	14105F	PARTICIPANT	\N	PRESENT	0
429394	427859	14133K	PARTICIPANT	\N	PRESENT	0
429398	428239	19768N	PARTICIPANT	\N	PRESENT	0
429399	428239	19515S	PARTICIPANT	\N	PRESENT	0
429400	428239	11077T	PARTICIPANT	\N	PRESENT	0
429401	428239	19782L	PARTICIPANT	\N	PRESENT	0
429402	428239	01043Q	PARTICIPANT	\N	PRESENT	0
429403	428239	14357A	PARTICIPANT	\N	PRESENT	0
429404	428239	19441R	PARTICIPANT	\N	PRESENT	0
429405	428239	19812Y	PARTICIPANT	\N	PRESENT	0
429406	428239	14081Q	PARTICIPANT	\N	PRESENT	0
429407	428239	19413M	PARTICIPANT	\N	PRESENT	0
429408	428239	80013X	PARTICIPANT	\N	PRESENT	0
429409	428239	19631V	PARTICIPANT	\N	PRESENT	0
429410	428239	11099A	PARTICIPANT	\N	PRESENT	0
429411	428239	08068F	PARTICIPANT	\N	PRESENT	0
429412	428239	04049K	PARTICIPANT	\N	PRESENT	0
429413	428239	19705W	PARTICIPANT	\N	PRESENT	0
429414	428239	08015R	PARTICIPANT	\N	PRESENT	0
429415	428239	08019V	PARTICIPANT	\N	PRESENT	0
429416	428239	19369B	PARTICIPANT	\N	PRESENT	0
429417	428239	19511N	PARTICIPANT	\N	PRESENT	0
429418	428239	19563B	PARTICIPANT	\N	PRESENT	0
429419	428239	08028W	PARTICIPANT	\N	PRESENT	0
429420	428239	14265W	PARTICIPANT	\N	PRESENT	0
429421	428239	14329V	PARTICIPANT	\N	PRESENT	0
429422	428239	19591F	PARTICIPANT	\N	PRESENT	0
429423	428239	14135M	PARTICIPANT	\N	PRESENT	0
429424	428239	19467C	PARTICIPANT	\N	PRESENT	0
429425	428239	14187A	PARTICIPANT	\N	PRESENT	0
429426	428239	08038Y	PARTICIPANT	\N	PRESENT	0
429427	428239	08062Y	PARTICIPANT	\N	PRESENT	0
429428	428239	01025N	PARTICIPANT	\N	PRESENT	0
429429	428239	11090Q	PRESIDENT	0	PRESENT	0
429430	428239	14033T	PARTICIPANT	\N	PRESENT	0
429431	428239	19295A	PARTICIPANT	\N	PRESENT	0
429432	428239	19269X	PARTICIPANT	\N	PRESENT	0
429433	428239	14205J	PARTICIPANT	\N	PRESENT	0
429434	428239	04088S	PARTICIPANT	\N	PRESENT	0
429435	428239	11056N	PARTICIPANT	\N	PRESENT	0
429436	428239	04089T	PARTICIPANT	\N	PRESENT	0
429437	428239	14115H	PARTICIPANT	\N	PRESENT	0
429438	428239	11101A	PARTICIPANT	\N	PRESENT	0
429439	428239	19507S	PARTICIPANT	\N	PRESENT	0
429440	428239	14207L	PARTICIPANT	\N	PRESENT	0
429441	428239	19747H	PARTICIPANT	\N	PRESENT	0
429442	428239	04043D	PARTICIPANT	\N	PRESENT	0
429443	428239	17589D	PARTICIPANT	\N	PRESENT	0
429444	428239	14257W	PARTICIPANT	\N	PRESENT	0
429445	428239	11081P	PARTICIPANT	\N	EXCUSE	0
429446	427859	95067Q	PARTICIPANT	\N	PRESENT	0
429447	427448	14029X	PARTICIPANT	\N	PRESENT	0
429448	427448	19733B	PARTICIPANT	\N	PRESENT	0
429449	428202	11110B	PARTICIPANT	\N	PRESENT	0
429450	428202	14034U	PARTICIPANT	\N	PRESENT	0
429451	428202	11012A	PARTICIPANT	\N	PRESENT	0
429452	427859	04040A	PARTICIPANT	\N	PRESENT	0
429468	428373	10015M	PARTICIPANT	\N	PRESENT	0
429469	428373	19719D	PARTICIPANT	\N	PRESENT	0
429470	428373	14179A	PARTICIPANT	\N	PRESENT	0
429471	428373	14151M	PARTICIPANT	\N	PRESENT	0
429472	428373	11085T	PARTICIPANT	\N	PRESENT	0
429473	428373	08045X	PARTICIPANT	\N	PRESENT	0
429474	428662	08035V	PARTICIPANT	\N	PRESENT	0
429479	428202	07004J	PARTICIPANT	\N	EXCUSE	0
429480	428202	19531S	PARTICIPANT	\N	PRESENT	0
429481	428373	11033F	PARTICIPANT	\N	EXCUSE	0
429483	428202	14179A	PARTICIPANT	\N	PRESENT	0
429484	429197	19697Q	PARTICIPANT	\N	PRESENT	0
429485	429197	11067R	PARTICIPANT	\N	PRESENT	0
429486	429197	19565D	PARTICIPANT	\N	PRESENT	0
429487	429197	14355X	PARTICIPANT	\N	PRESENT	0
429488	429197	19569H	PARTICIPANT	\N	PRESENT	0
429489	429197	19798U	PARTICIPANT	\N	PRESENT	0
429490	429197	11097X	PARTICIPANT	\N	PRESENT	0
429491	429197	19415P	PARTICIPANT	\N	PRESENT	0
429492	429197	14223L	PARTICIPANT	\N	PRESENT	0
429493	429197	04045F	PARTICIPANT	\N	PRESENT	0
429494	429197	14026U	PARTICIPANT	\N	PRESENT	0
429495	429197	14227Q	PARTICIPANT	\N	PRESENT	0
429496	429197	17779H	PARTICIPANT	\N	PRESENT	0
429497	429197	11031D	PARTICIPANT	\N	PRESENT	0
429498	429197	14239U	PARTICIPANT	\N	PRESENT	0
429499	429197	19703U	PARTICIPANT	\N	PRESENT	0
429500	429197	19553Y	PARTICIPANT	\N	PRESENT	0
429501	429197	14281W	PARTICIPANT	\N	PRESENT	0
429502	429197	14087W	PARTICIPANT	\N	PRESENT	0
429503	429197	19679N	PARTICIPANT	\N	PRESENT	0
429504	429197	14042U	PARTICIPANT	\N	PRESENT	0
429505	429197	08048B	PARTICIPANT	\N	PRESENT	0
429506	429197	19575F	PARTICIPANT	\N	PRESENT	0
429507	429197	14195A	PARTICIPANT	\N	PRESENT	0
429508	429197	19367Y	PARTICIPANT	\N	PRESENT	0
429509	429197	14213J	PARTICIPANT	\N	PRESENT	0
429510	429197	14261S	PARTICIPANT	\N	PRESENT	0
429511	429197	14217N	PARTICIPANT	\N	PRESENT	0
429512	429197	19683J	PARTICIPANT	\N	PRESENT	0
429513	429197	10006L	PARTICIPANT	\N	PRESENT	0
429514	429197	98024R	PARTICIPANT	\N	PRESENT	0
429515	429197	19521Q	PARTICIPANT	\N	PRESENT	0
429516	429197	19527W	PARTICIPANT	\N	PRESENT	0
429517	429197	01034P	PARTICIPANT	\N	PRESENT	0
429518	429197	04092N	PRESIDENT	0	PRESENT	0
429519	429197	11045K	PARTICIPANT	\N	PRESENT	0
429520	429197	08052W	PARTICIPANT	\N	PRESENT	0
429521	429197	19663E	PARTICIPANT	\N	PRESENT	0
429522	429197	19301E	PARTICIPANT	\N	PRESENT	0
429523	429197	19691J	PARTICIPANT	\N	PRESENT	0
429524	429197	19723Y	PARTICIPANT	\N	PRESENT	0
429525	429197	19727D	PARTICIPANT	\N	PRESENT	0
429526	429197	14119M	PARTICIPANT	\N	PRESENT	0
429527	429197	11103C	PARTICIPANT	\N	PRESENT	0
429528	429197	14071N	PARTICIPANT	\N	PRESENT	0
429529	429197	19760E	PARTICIPANT	\N	PRESENT	0
429530	429197	08041T	PARTICIPANT	\N	EXCUSE	0
429532	428276	11067R	PARTICIPANT	\N	PRESENT	0
429533	428276	04092N	PRESIDENT	0	PRESENT	0
429534	428276	08034U	PARTICIPANT	\N	PRESENT	0
429535	428276	19569H	PARTICIPANT	\N	PRESENT	0
429536	428276	08052W	PARTICIPANT	\N	PRESENT	0
429537	428276	11066Q	PARTICIPANT	\N	PRESENT	0
429538	428276	19447X	PARTICIPANT	\N	PRESENT	0
423930	423928	01058X	PARTICIPANT	\N	PRESENT	0
426321	425346	04008A	PARTICIPANT	\N	PRESENT	0
426322	425100	14034U	PARTICIPANT	\N	PRESENT	0
426323	425100	19507S	PARTICIPANT	\N	PRESENT	0
426327	423940	19333N	PARTICIPANT	\N	PRESENT	0
426328	423940	19383Y	PARTICIPANT	\N	PRESENT	0
426329	423940	17583W	PARTICIPANT	\N	PRESENT	0
426330	423940	19701S	PARTICIPANT	\N	PRESENT	0
426331	423940	19794Q	PARTICIPANT	\N	PRESENT	0
426332	423940	19549D	PARTICIPANT	\N	PRESENT	0
426333	423940	19387D	PARTICIPANT	\N	PRESENT	0
426334	423940	19820Y	PARTICIPANT	\N	PRESENT	0
426335	423940	14219Q	PARTICIPANT	\N	PRESENT	0
426336	423940	14221J	PARTICIPANT	\N	PRESENT	0
426337	423940	19826F	PARTICIPANT	\N	PRESENT	0
426338	423940	19599P	PARTICIPANT	\N	PRESENT	0
426339	423940	19637C	PARTICIPANT	\N	PRESENT	0
426340	423940	18083K	PARTICIPANT	\N	PRESENT	0
426341	423940	14237S	PARTICIPANT	\N	PRESENT	0
426342	423940	19551W	PARTICIPANT	\N	PRESENT	0
426343	423940	05012A	PARTICIPANT	\N	PRESENT	0
426344	423940	08060W	PARTICIPANT	\N	PRESENT	0
426345	423940	19503N	PARTICIPANT	\N	PRESENT	0
426346	423940	19347U	PARTICIPANT	\N	PRESENT	0
426347	423940	14157T	PARTICIPANT	\N	PRESENT	0
426348	423940	19685L	PARTICIPANT	\N	PRESENT	0
426349	423940	19681G	PARTICIPANT	\N	PRESENT	0
426350	423940	08024S	PARTICIPANT	\N	PRESENT	0
426351	423940	17637T	PARTICIPANT	\N	PRESENT	0
426352	423940	14038Y	PARTICIPANT	\N	PRESENT	0
426353	423940	14103D	PARTICIPANT	\N	PRESENT	0
426354	423940	19713W	PARTICIPANT	\N	PRESENT	0
426355	423940	14031R	PARTICIPANT	\N	PRESENT	0
426356	423940	08055A	PARTICIPANT	\N	PRESENT	0
426357	423940	14191V	PARTICIPANT	\N	PRESENT	0
426358	423940	14169X	PARTICIPANT	\N	PRESENT	0
426359	423940	04085P	PARTICIPANT	\N	PRESENT	0
426360	423940	15447F	PARTICIPANT	\N	PRESENT	0
426361	423940	14093U	PARTICIPANT	\N	PRESENT	0
426362	423940	19733B	PARTICIPANT	\N	PRESENT	0
426363	423940	08009T	PARTICIPANT	\N	PRESENT	0
426364	423940	19737F	PARTICIPANT	\N	PRESENT	0
426365	423940	04097T	PARTICIPANT	\N	PRESENT	0
426366	423940	19739H	PARTICIPANT	\N	PRESENT	0
426367	423940	19745F	PARTICIPANT	\N	PRESENT	0
426368	423940	14051J	PARTICIPANT	\N	EXCUSE	0
426369	423940	02002K	PARTICIPANT	\N	EXCUSE	0
426370	423940	19525U	PARTICIPANT	\N	EXCUSE	0
426371	423940	04069P	PARTICIPANT	\N	PRESENT	0
426421	423853	19697Q	PARTICIPANT	\N	PRESENT	0
426422	423853	11067R	PARTICIPANT	\N	PRESENT	0
426423	423853	19565D	PARTICIPANT	\N	PRESENT	0
426424	423853	19798U	PARTICIPANT	\N	PRESENT	0
426425	423853	19569H	PARTICIPANT	\N	PRESENT	0
426426	423853	11097X	PARTICIPANT	\N	PRESENT	0
426427	423853	19415P	PARTICIPANT	\N	PRESENT	0
426428	423853	04045F	PARTICIPANT	\N	PRESENT	0
426429	423853	14223L	PARTICIPANT	\N	PRESENT	0
426430	423853	14026U	PARTICIPANT	\N	PRESENT	0
426431	423853	14227Q	PARTICIPANT	\N	PRESENT	0
426432	423853	17779H	PARTICIPANT	\N	PRESENT	0
426433	423853	19703U	PARTICIPANT	\N	PRESENT	0
426434	423853	14239U	PARTICIPANT	\N	PRESENT	0
426435	423853	19553Y	PARTICIPANT	\N	PRESENT	0
426436	423853	11031D	PARTICIPANT	\N	PRESENT	0
426437	423853	14087W	PARTICIPANT	\N	PRESENT	0
426438	423853	14281W	PARTICIPANT	\N	PRESENT	0
426439	423853	19679N	PARTICIPANT	\N	PRESENT	0
426440	423853	14042U	PARTICIPANT	\N	PRESENT	0
426441	423853	19575F	PARTICIPANT	\N	PRESENT	0
426442	423853	08048B	PARTICIPANT	\N	PRESENT	0
426443	423853	14195A	PARTICIPANT	\N	PRESENT	0
426444	423853	19367Y	PARTICIPANT	\N	PRESENT	0
426445	423853	14213J	PARTICIPANT	\N	PRESENT	0
426446	423853	14217N	PARTICIPANT	\N	PRESENT	0
426447	423853	10006L	PARTICIPANT	\N	PRESENT	0
426448	423853	19683J	PARTICIPANT	\N	PRESENT	0
426449	423853	98024R	PARTICIPANT	\N	PRESENT	0
426450	423853	19521Q	PARTICIPANT	\N	PRESENT	0
426451	423853	19527W	PARTICIPANT	\N	PRESENT	0
426452	423853	01034P	PARTICIPANT	\N	PRESENT	0
426453	423853	04092N	PARTICIPANT	\N	PRESENT	0
426454	423853	11045K	PARTICIPANT	\N	PRESENT	0
426455	423853	08052W	PARTICIPANT	\N	PRESENT	0
426456	423853	19663E	PARTICIPANT	\N	PRESENT	0
426457	423853	19691J	PARTICIPANT	\N	PRESENT	0
426458	423853	19715Y	PARTICIPANT	\N	PRESENT	0
426459	423853	19717B	PARTICIPANT	\N	PRESENT	0
426460	423853	19723Y	PARTICIPANT	\N	PRESENT	0
426461	423853	19727D	PARTICIPANT	\N	PRESENT	0
426462	423853	14119M	PARTICIPANT	\N	PRESENT	0
426463	423853	11103C	PARTICIPANT	\N	PRESENT	0
426464	423853	19657G	PARTICIPANT	\N	PRESENT	0
426465	423853	14071N	PARTICIPANT	\N	PRESENT	0
426466	423853	19577H	PARTICIPANT	\N	PRESENT	0
426467	423853	19760E	PARTICIPANT	\N	PRESENT	0
427422	416322	14115H	PARTICIPANT	\N	PRESENT	0
427430	416322	14265W	PARTICIPANT	\N	PRESENT	0
427424	416322	19631V	PARTICIPANT	\N	PRESENT	0
427425	416322	14197C	PARTICIPANT	\N	PRESENT	0
427426	425130	19741B	PARTICIPANT	\N	PRESENT	0
427427	416322	19531S	PARTICIPANT	\N	PRESENT	0
427429	416322	14357A	PARTICIPANT	\N	PRESENT	0
427431	416322	19794Q	PARTICIPANT	\N	PRESENT	0
427432	416322	14231L	PARTICIPANT	\N	PRESENT	0
427433	416322	01024M	PARTICIPANT	\N	PRESENT	0
427434	416322	08015R	PARTICIPANT	\N	PRESENT	0
427435	416322	19669L	PARTICIPANT	\N	PRESENT	0
427436	416322	19515S	PARTICIPANT	\N	PRESENT	0
427437	416322	11026G	PARTICIPANT	\N	PRESENT	0
427438	416322	19335Q	PARTICIPANT	\N	PRESENT	0
427439	416322	14215L	PARTICIPANT	\N	PRESENT	0
427440	416322	19701S	PARTICIPANT	\N	PRESENT	0
427441	416322	14033T	PARTICIPANT	\N	PRESENT	0
427442	416322	19533U	PARTICIPANT	\N	PRESENT	0
427443	416322	19747H	PARTICIPANT	\N	PRESENT	0
427444	416322	14038Y	PARTICIPANT	\N	PRESENT	0
427445	416322	14187A	PARTICIPANT	\N	PRESENT	0
427449	416322	14097Y	PARTICIPANT	\N	PRESENT	0
427450	416322	11090Q	PARTICIPANT	\N	PRESENT	0
427451	416322	89017R	PARTICIPANT	\N	PRESENT	0
431936	431932	19533U	PARTICIPANT	\N	PRESENT	0
431937	431932	14073Q	PARTICIPANT	\N	PRESENT	0
431938	431932	19611R	PARTICIPANT	\N	PRESENT	0
431939	431932	08043V	PARTICIPANT	\N	EXCUSE	0
431940	431932	19693L	PARTICIPANT	\N	PRESENT	0
431941	431932	87003B	PARTICIPANT	\N	PRESENT	0
431942	431932	14229S	PARTICIPANT	\N	PRESENT	0
431943	431932	14241N	PARTICIPANT	\N	PRESENT	0
431944	431932	19573D	PARTICIPANT	\N	PRESENT	0
431945	431932	08020N	PARTICIPANT	\N	PRESENT	0
431946	431932	11083R	PARTICIPANT	\N	PRESENT	0
431947	431932	08012N	PARTICIPANT	\N	PRESENT	0
431948	431932	14123H	PRESIDENT	1	PRESENT	0
431949	431932	11043H	PARTICIPANT	\N	PRESENT	0
431950	431932	19758L	PARTICIPANT	\N	PRESENT	0
431951	431932	14063N	PARTICIPANT	\N	EXCUSE	0
431952	431932	14061L	PARTICIPANT	\N	PRESENT	0
431953	431932	14249W	PARTICIPANT	\N	PRESENT	0
431954	431731	14053L	PARTICIPANT	\N	PRESENT	0
431955	431731	19251M	PARTICIPANT	\N	PRESENT	0
431956	425265	14038Y	PARTICIPANT	\N	PRESENT	0
431957	431932	04057K	PARTICIPANT	\N	PRESENT	0
431958	431932	14030Q	PARTICIPANT	\N	PRESENT	0
431959	431932	19335Q	PARTICIPANT	\N	PRESENT	0
431960	431932	08039A	PARTICIPANT	\N	PRESENT	0
431961	425265	19762G	PARTICIPANT	\N	PRESENT	0
431962	429840	04040A	PARTICIPANT	\N	EXCUSE	0
431963	425265	14201E	PARTICIPANT	\N	PRESENT	0
431964	425265	14205J	PARTICIPANT	\N	PRESENT	0
431965	425265	19369B	PARTICIPANT	\N	PRESENT	0
431966	425265	19760E	PARTICIPANT	\N	PRESENT	0
431968	425265	19703U	PARTICIPANT	\N	PRESENT	0
431987	425265	19657G	PARTICIPANT	\N	PRESENT	0
431988	425265	11048N	PARTICIPANT	\N	PRESENT	0
431989	425265	14281W	PARTICIPANT	\N	PRESENT	0
431990	425265	11101A	PARTICIPANT	\N	PRESENT	0
431991	429840	08056B	PARTICIPANT	\N	PRESENT	0
431992	429840	14097Y	PARTICIPANT	\N	PRESENT	0
431993	429840	07004J	PARTICIPANT	\N	PRESENT	0
431994	429840	08053X	PRESIDENT	0	PRESENT	0
431995	429840	19669L	PARTICIPANT	\N	PRESENT	0
431996	429840	19671E	PARTICIPANT	\N	PRESENT	0
431997	429840	19673G	PARTICIPANT	\N	PRESENT	0
431998	429840	19719D	PRESIDENT	1	PRESENT	0
431999	430843	19383Y	PARTICIPANT	\N	PRESENT	0
432000	430843	18083K	PARTICIPANT	\N	PRESENT	0
432001	430843	14029X	PARTICIPANT	\N	PRESENT	0
432002	430843	08060W	PARTICIPANT	\N	PRESENT	0
432003	430843	19794Q	PARTICIPANT	\N	PRESENT	0
432004	430843	08009T	PRESIDENT	0	PRESENT	0
432005	430843	19549D	PARTICIPANT	\N	PRESENT	0
432006	430843	14219Q	PARTICIPANT	\N	PRESENT	0
432007	430843	19826F	PARTICIPANT	\N	PRESENT	0
432008	430843	08055A	PARTICIPANT	\N	PRESENT	0
432009	430843	14169X	PARTICIPANT	\N	PRESENT	0
432010	430843	17637T	PARTICIPANT	\N	PRESENT	0
432012	430843	04097T	PARTICIPANT	\N	PRESENT	0
432013	430843	14051J	PARTICIPANT	\N	EXCUSE	0
432014	425265	11099A	PARTICIPANT	\N	PRESENT	0
432015	429840	11080N	PARTICIPANT	\N	PRESENT	0
432016	429840	14187A	PARTICIPANT	\N	PRESENT	0
432017	429840	10015M	PARTICIPANT	\N	PRESENT	0
432018	429840	04044E	PARTICIPANT	\N	PRESENT	0
432019	429840	19585H	PARTICIPANT	\N	PRESENT	0
432020	429840	19421M	PARTICIPANT	\N	PRESENT	0
432021	429840	08010L	PARTICIPANT	\N	PRESENT	0
432022	429840	14249W	PARTICIPANT	\N	PRESENT	0
432023	429840	19721W	PARTICIPANT	\N	PRESENT	0
432024	429840	04085P	PARTICIPANT	\N	PRESENT	0
432025	425265	04059M	PARTICIPANT	\N	PRESENT	0
432026	425265	14107H	PARTICIPANT	\N	PRESENT	0
432029	430843	19333N	PARTICIPANT	\N	PRESENT	0
432030	430843	19387D	PARTICIPANT	\N	PRESENT	0
432031	430843	19820Y	PARTICIPANT	\N	PRESENT	0
432032	430843	14221J	PARTICIPANT	\N	PRESENT	0
432033	430843	19599P	PARTICIPANT	\N	PRESENT	0
432034	430843	14237S	PARTICIPANT	\N	PRESENT	0
432035	430843	19347U	PARTICIPANT	\N	PRESENT	0
432036	430843	19503N	PARTICIPANT	\N	PRESENT	0
432037	430843	14038Y	PARTICIPANT	\N	PRESENT	0
432038	430843	19713W	PARTICIPANT	\N	PRESENT	0
432039	430843	19737F	PARTICIPANT	\N	PRESENT	0
432040	430843	19745F	PARTICIPANT	\N	PRESENT	0
432041	425265	19563B	PARTICIPANT	\N	PRESENT	0
432042	425265	14059S	PARTICIPANT	\N	PRESENT	0
432043	425265	14083S	PARTICIPANT	\N	PRESENT	0
432044	431932	04059M	PARTICIPANT	\N	PRESENT	0
432045	430843	19551W	PARTICIPANT	\N	PRESENT	0
432046	430843	19701S	PARTICIPANT	\N	EXCUSE	0
432048	430843	05012A	PARTICIPANT	\N	PRESENT	0
432049	425265	19758L	PARTICIPANT	\N	PRESENT	0
432050	425265	19335Q	PARTICIPANT	\N	PRESENT	0
432051	430768	14053L	PARTICIPANT	\N	PRESENT	0
432052	430768	19649G	PARTICIPANT	\N	PRESENT	0
432053	430768	14111D	PARTICIPANT	\N	PRESENT	0
432054	430768	14147R	PARTICIPANT	\N	PRESENT	0
432055	430768	14069U	PARTICIPANT	\N	PRESENT	0
432056	430768	19581D	PARTICIPANT	\N	PRESENT	0
432057	430768	14215L	PARTICIPANT	\N	PRESENT	0
432058	430768	04044E	PARTICIPANT	\N	PRESENT	0
432059	425265	19611R	PARTICIPANT	\N	PRESENT	0
432060	425265	19569H	PARTICIPANT	\N	PRESENT	0
432061	430768	19253P	PARTICIPANT	\N	PRESENT	0
432062	430768	19673G	PARTICIPANT	\N	PRESENT	0
432063	430768	19725B	PARTICIPANT	\N	PRESENT	0
432064	430768	95063L	PARTICIPANT	\N	PRESENT	0
432065	430768	14151M	PARTICIPANT	\N	PRESENT	0
432066	430843	14157T	PARTICIPANT	\N	PRESENT	0
432067	430843	19681G	PARTICIPANT	\N	PRESENT	0
432068	425265	80013X	PARTICIPANT	\N	PRESENT	0
432213	425275	14034U	PARTICIPANT	\N	PRESENT	0
432214	425275	08011M	PARTICIPANT	\N	PRESENT	0
432215	425275	11074Q	PARTICIPANT	\N	PRESENT	0
432216	432126	04086Q	PARTICIPANT	\N	PRESENT	0
432217	432126	11040E	PARTICIPANT	\N	PRESENT	0
432218	432126	07029T	PARTICIPANT	\N	PRESENT	0
432219	432126	19711U	PARTICIPANT	\N	PRESENT	0
432220	432126	14085U	PARTICIPANT	\N	PRESENT	0
432221	432126	19651A	PARTICIPANT	\N	PRESENT	0
432222	432126	11074Q	PRESIDENT	0	PRESENT	0
432223	432126	08011M	PARTICIPANT	\N	PRESENT	0
432224	432126	11048N	PARTICIPANT	\N	PRESENT	0
432225	432126	11012A	PARTICIPANT	\N	PRESENT	0
432226	432126	19545Y	PARTICIPANT	\N	PRESENT	0
432227	432126	14034U	PARTICIPANT	\N	PRESENT	0
432247	425275	19479G	PARTICIPANT	\N	PRESENT	0
432248	425275	14119M	PARTICIPANT	\N	PRESENT	0
432249	425275	19794Q	PARTICIPANT	\N	PRESENT	0
432250	425275	07029T	PARTICIPANT	\N	PRESENT	0
432251	425275	11048N	PARTICIPANT	\N	PRESENT	0
432252	425275	19725B	PARTICIPANT	\N	PRESENT	0
432253	425275	08017T	PARTICIPANT	\N	PRESENT	0
432254	425275	19629C	PARTICIPANT	\N	PRESENT	0
432255	425275	19798U	PARTICIPANT	\N	PRESENT	0
432256	425275	04086Q	PARTICIPANT	\N	PRESENT	0
432257	425275	19711U	PARTICIPANT	\N	PRESENT	0
432258	425275	14030Q	PARTICIPANT	\N	PRESENT	0
432259	425275	19543W	PARTICIPANT	\N	PRESENT	0
432260	425275	89017R	PARTICIPANT	\N	PRESENT	0
432261	425275	19733B	PARTICIPANT	\N	PRESENT	0
432262	425275	14197C	PARTICIPANT	\N	PRESENT	0
432263	425275	19735D	PARTICIPANT	\N	PRESENT	0
432264	425275	19687N	PARTICIPANT	\N	PRESENT	0
432265	425275	19760E	PARTICIPANT	\N	PRESENT	0
432266	425275	14235Q	PARTICIPANT	\N	PRESENT	0
432267	425275	08020N	PARTICIPANT	\N	PRESENT	0
432268	425275	19713W	PARTICIPANT	\N	PRESENT	0
432269	425275	19551W	PARTICIPANT	\N	PRESENT	0
432270	425275	14147R	PARTICIPANT	\N	PRESENT	0
432271	425275	14071N	PARTICIPANT	\N	PRESENT	0
449454	448851	05008E	PRESIDENT	0	PRESENT	0
449455	448851	19489J	PARTICIPANT	\N	PRESENT	0
449456	448851	14275Y	PARTICIPANT	\N	PRESENT	0
449457	448851	14147R	PARTICIPANT	\N	PRESENT	0
449458	448851	14179A	PARTICIPANT	\N	PRESENT	0
449459	448851	14151M	PARTICIPANT	\N	PRESENT	0
449460	448851	14215L	PARTICIPANT	\N	PRESENT	0
449461	448851	14259Y	PARTICIPANT	\N	PRESENT	0
449462	448851	98035U	PARTICIPANT	\N	PRESENT	0
449463	448851	14053L	PARTICIPANT	\N	PRESENT	0
449464	448851	14065Q	PARTICIPANT	\N	PRESENT	0
449465	448851	14111D	PARTICIPANT	\N	PRESENT	0
449466	448851	08045X	PARTICIPANT	\N	PRESENT	0
449467	448851	19253P	PARTICIPANT	\N	PRESENT	0
449468	448851	04038G	PARTICIPANT	\N	PRESENT	0
449469	448851	11033F	PARTICIPANT	\N	PRESENT	0
449470	448851	19725B	PARTICIPANT	\N	PRESENT	0
449471	448851	14089Y	PARTICIPANT	\N	PRESENT	0
449472	448851	19729F	PARTICIPANT	\N	PRESENT	0
449473	448851	95063L	PARTICIPANT	\N	PRESENT	0
449474	448851	19629C	PARTICIPANT	\N	PRESENT	0
449475	448851	08044W	PARTICIPANT	\N	PRESENT	0
449476	448851	14069U	PARTICIPANT	\N	PRESENT	0
449477	448851	10015M	PARTICIPANT	\N	PRESENT	0
449608	448851	11049P	PARTICIPANT	\N	PRESENT	0
449484	448370	04040A	PARTICIPANT	\N	PRESENT	0
449486	449485	11027H	PARTICIPANT	\N	PRESENT	0
449487	448370	98005N	PARTICIPANT	\N	PRESENT	0
449488	448573	11040E	PARTICIPANT	\N	PRESENT	0
449489	448573	14083S	PARTICIPANT	\N	PRESENT	0
449490	448573	11048N	PARTICIPANT	\N	PRESENT	0
449491	448573	11012A	PARTICIPANT	\N	PRESENT	0
449492	448573	08034U	PARTICIPANT	\N	PRESENT	0
449493	448573	01057W	PARTICIPANT	\N	PRESENT	0
449494	448573	11074Q	PRESIDENT	0	PRESENT	0
449495	448573	99004R	PARTICIPANT	\N	PRESENT	0
449496	448573	08014Q	PARTICIPANT	\N	PRESENT	0
449497	448573	19671E	PARTICIPANT	\N	PRESENT	0
449498	448573	14159V	PARTICIPANT	\N	PRESENT	0
449499	448573	14173T	PARTICIPANT	\N	PRESENT	0
449500	448573	14331P	PARTICIPANT	\N	PRESENT	0
449501	448573	08069G	PARTICIPANT	\N	PRESENT	0
449502	448573	04086Q	PARTICIPANT	\N	PRESENT	0
449503	448573	19741B	PARTICIPANT	\N	PRESENT	0
449504	448573	19667J	PARTICIPANT	\N	PRESENT	0
449506	449505	14259Y	PARTICIPANT	\N	PRESENT	0
449507	448573	19711U	PARTICIPANT	\N	PRESENT	0
449508	448573	14085U	PARTICIPANT	\N	PRESENT	0
449509	448573	14327T	PARTICIPANT	\N	PRESENT	0
449510	449505	17589D	PARTICIPANT	\N	PRESENT	0
449511	449505	19553Y	PARTICIPANT	\N	PRESENT	0
449512	449505	19551W	PARTICIPANT	\N	PRESENT	0
449513	449505	14061L	PARTICIPANT	\N	PRESENT	0
449514	449505	19637C	PARTICIPANT	\N	PRESENT	0
449515	449505	19563B	PARTICIPANT	\N	PRESENT	0
449516	449505	19335Q	PARTICIPANT	\N	PRESENT	0
449517	449505	92040Q	PARTICIPANT	\N	PRESENT	0
449518	449505	01062T	PARTICIPANT	\N	PRESENT	0
449519	448573	88008L	PARTICIPANT	\N	PRESENT	0
449520	448573	19349W	PARTICIPANT	\N	PRESENT	0
449521	448573	14121F	PARTICIPANT	\N	PRESENT	0
449522	448573	19689Q	PARTICIPANT	\N	PRESENT	0
449523	448573	89017R	PARTICIPANT	\N	PRESENT	0
449524	448573	08011M	PARTICIPANT	\N	PRESENT	0
449525	448573	19479G	PARTICIPANT	\N	PRESENT	0
449527	448370	14255U	PARTICIPANT	\N	PRESENT	0
449528	449526	19507S	PARTICIPANT	\N	PRESENT	0
449529	449526	14033T	PARTICIPANT	\N	PRESENT	0
449530	449526	08015R	PARTICIPANT	\N	PRESENT	0
449531	448573	95041E	PARTICIPANT	\N	PRESENT	0
449532	449526	19441R	PARTICIPANT	\N	PRESENT	0
449533	449526	19563B	PARTICIPANT	\N	PRESENT	0
449534	449526	14257W	PARTICIPANT	\N	PRESENT	0
449535	448573	19531S	PARTICIPANT	\N	PRESENT	0
449537	448370	19709B	PARTICIPANT	\N	PRESENT	0
449538	449536	19507S	PARTICIPANT	\N	PRESENT	0
449539	449536	14115H	PARTICIPANT	\N	PRESENT	0
449540	448573	08010L	PARTICIPANT	\N	PRESENT	0
449541	449536	14033T	PARTICIPANT	\N	PRESENT	0
449542	449536	19441R	PARTICIPANT	\N	PRESENT	0
449584	448851	01024M	PARTICIPANT	\N	PRESENT	0
449585	449583	19507S	PARTICIPANT	\N	PRESENT	0
449586	449583	14115H	PARTICIPANT	\N	PRESENT	0
449587	449583	14033T	PARTICIPANT	\N	PRESENT	0
449588	449583	19441R	PARTICIPANT	\N	PRESENT	0
449592	448573	07029T	PARTICIPANT	\N	PRESENT	0
449595	448851	08018U	PARTICIPANT	\N	PRESENT	0
449596	448573	11053K	PARTICIPANT	\N	PRESENT	0
449604	448851	11085T	PARTICIPANT	\N	PRESENT	0
449609	448573	01048V	PARTICIPANT	\N	PRESENT	0
449610	449601	04070G	PRESIDENT	0	PRESENT	0
449611	449601	87003B	PARTICIPANT	\N	PRESENT	0
449612	449601	14030Q	PARTICIPANT	\N	PRESENT	0
449613	449601	14059S	PARTICIPANT	\N	EXCUSE	0
449614	449601	14073Q	PARTICIPANT	\N	EXCUSE	0
449615	449601	11083R	PARTICIPANT	\N	PRESENT	0
449616	449601	08043V	PARTICIPANT	\N	EXCUSE	0
449617	449601	07033P	PARTICIPANT	\N	EXCUSE	0
449618	449601	14249W	PARTICIPANT	\N	EXCUSE	0
449619	447997	19697Q	PARTICIPANT	\N	PRESENT	0
449620	447997	11067R	PARTICIPANT	\N	PRESENT	0
449621	447997	14355X	PARTICIPANT	\N	PRESENT	0
449622	447997	19565D	PARTICIPANT	\N	PRESENT	0
449623	447997	19798U	PARTICIPANT	\N	PRESENT	0
449624	447997	11097X	PARTICIPANT	\N	PRESENT	0
449625	447997	19415P	PARTICIPANT	\N	PRESENT	0
449626	447997	04045F	PARTICIPANT	\N	PRESENT	0
449627	447997	14026U	PARTICIPANT	\N	PRESENT	0
449628	447997	17779H	PARTICIPANT	\N	PRESENT	0
449629	447997	19703U	PARTICIPANT	\N	PRESENT	0
449630	447997	14281W	PARTICIPANT	\N	PRESENT	0
449631	447997	14087W	PARTICIPANT	\N	PRESENT	0
449632	447997	19679N	PARTICIPANT	\N	PRESENT	0
449633	447997	14042U	PARTICIPANT	\N	PRESENT	0
449634	447997	08048B	PARTICIPANT	\N	PRESENT	0
449635	447997	14195A	PARTICIPANT	\N	PRESENT	0
449636	447997	14213J	PARTICIPANT	\N	PRESENT	0
449637	447997	19367Y	PARTICIPANT	\N	PRESENT	0
429539	428276	18083K	PARTICIPANT	\N	PRESENT	0
429540	428276	14041T	PARTICIPANT	\N	PRESENT	0
429541	428276	14147R	PARTICIPANT	\N	PRESENT	0
429542	428276	14213J	PARTICIPANT	\N	PRESENT	0
429543	428276	99004R	PARTICIPANT	\N	PRESENT	0
429544	428276	14217N	PARTICIPANT	\N	PRESENT	0
429545	428276	11072N	PARTICIPANT	\N	PRESENT	0
429546	428276	04045F	PARTICIPANT	\N	PRESENT	0
429547	428276	19681G	PARTICIPANT	\N	EXCUSE	0
429548	428276	01048V	PARTICIPANT	\N	PRESENT	0
429549	428276	19415P	PARTICIPANT	\N	PRESENT	0
429550	428276	19553Y	PARTICIPANT	\N	PRESENT	0
429551	428276	19575F	PARTICIPANT	\N	PRESENT	0
429552	428276	14195A	PARTICIPANT	\N	PRESENT	0
429553	428276	10006L	PRESIDENT	1	PRESENT	0
429554	416368	19565D	PARTICIPANT	\N	PRESENT	0
429555	416368	19593H	PARTICIPANT	\N	PRESENT	0
429556	416368	98035U	PARTICIPANT	\N	PRESENT	0
429557	416368	04059M	PARTICIPANT	\N	PRESENT	0
429558	416368	08055A	PARTICIPANT	\N	PRESENT	0
429559	416368	14197C	PARTICIPANT	\N	PRESENT	0
429560	416368	14151M	PARTICIPANT	\N	PRESENT	0
429561	416368	80013X	PARTICIPANT	\N	PRESENT	0
429562	416368	11041F	PARTICIPANT	\N	PRESENT	0
429563	416368	14081Q	PARTICIPANT	\N	PRESENT	0
429564	416368	11110B	PARTICIPANT	\N	PRESENT	0
429565	416368	19725B	PARTICIPANT	\N	PRESENT	0
429566	416368	19525U	PARTICIPANT	\N	PRESENT	0
429567	416368	14257W	PARTICIPANT	\N	PRESENT	0
429568	416368	17779H	PARTICIPANT	\N	PRESENT	0
429569	416368	19489J	PARTICIPANT	\N	PRESENT	0
429570	416368	04045F	PARTICIPANT	\N	PRESENT	0
429571	416368	98029W	PARTICIPANT	\N	PRESENT	0
429572	416368	19349W	PARTICIPANT	\N	PRESENT	0
429573	416368	19651A	PARTICIPANT	\N	PRESENT	0
429574	416368	14039A	PARTICIPANT	\N	PRESENT	0
429575	416368	08038Y	PARTICIPANT	\N	PRESENT	0
429576	416368	08053X	PARTICIPANT	\N	PRESENT	0
429577	416368	19697Q	PARTICIPANT	\N	PRESENT	0
429578	416368	08012N	PARTICIPANT	\N	PRESENT	0
429579	416368	19669L	PARTICIPANT	\N	PRESENT	0
429580	416368	08058D	PARTICIPANT	\N	PRESENT	0
429581	416368	19503N	PARTICIPANT	\N	PRESENT	0
429582	416368	04034C	PARTICIPANT	\N	PRESENT	0
429583	416368	08061X	PARTICIPANT	\N	PRESENT	0
429584	416368	19347U	PARTICIPANT	\N	PRESENT	0
429585	416368	19647E	PARTICIPANT	\N	PRESENT	0
429586	416368	14235Q	PARTICIPANT	\N	PRESENT	0
429587	416368	14211G	PARTICIPANT	\N	PRESENT	0
429588	416368	11056N	PARTICIPANT	\N	PRESENT	0
429589	416368	11031D	PARTICIPANT	\N	PRESENT	0
429590	416368	17637T	PARTICIPANT	\N	PRESENT	0
429591	416368	11040E	PARTICIPANT	\N	PRESENT	0
429592	416368	04085P	PARTICIPANT	\N	PRESENT	0
429593	416368	19758L	PARTICIPANT	\N	PRESENT	0
429594	416368	95063L	PARTICIPANT	\N	PRESENT	0
429596	416368	08024S	PARTICIPANT	\N	PRESENT	0
429597	416368	19711U	PARTICIPANT	\N	PRESENT	0
429598	416368	11077T	PARTICIPANT	\N	PRESENT	0
429599	416368	19731Y	PARTICIPANT	\N	PRESENT	0
429600	416368	19685L	PARTICIPANT	\N	PRESENT	0
429601	416368	19301E	PARTICIPANT	\N	PRESENT	0
429602	416368	11074Q	PARTICIPANT	\N	PRESENT	0
429603	416368	19443T	PARTICIPANT	\N	PRESENT	0
429604	416368	08068F	PARTICIPANT	\N	PRESENT	0
429605	416368	19741B	PARTICIPANT	\N	PRESENT	0
429606	416368	14029X	PARTICIPANT	\N	PRESENT	0
429607	416368	19637C	PARTICIPANT	\N	PRESENT	0
429608	416368	19663E	PARTICIPANT	\N	PRESENT	0
429609	416368	11012A	PARTICIPANT	\N	PRESENT	0
429610	416368	14041T	PARTICIPANT	\N	PRESENT	0
429611	416368	14034U	PARTICIPANT	\N	PRESENT	0
429612	416368	19507S	PARTICIPANT	\N	PRESENT	0
429613	416368	88008L	PARTICIPANT	\N	PRESENT	0
429614	416368	14261S	PARTICIPANT	\N	PRESENT	0
429615	416368	14355X	PARTICIPANT	\N	PRESENT	0
429616	416368	19629C	PARTICIPANT	\N	PRESENT	0
429617	416368	08062Y	PARTICIPANT	\N	PRESENT	0
429618	416368	19253P	PARTICIPANT	\N	PRESENT	0
429619	416368	08015R	PARTICIPANT	\N	PRESENT	0
429620	416368	19768N	PARTICIPANT	\N	PRESENT	0
429621	416368	14107H	PARTICIPANT	\N	PRESENT	0
429622	416368	19729F	PARTICIPANT	\N	PRESENT	0
429624	416368	05012A	PARTICIPANT	\N	PRESENT	0
429625	416368	14201E	PARTICIPANT	\N	PRESENT	0
429626	416368	08039A	PARTICIPANT	\N	PRESENT	0
429627	416368	11099A	PARTICIPANT	\N	PRESENT	0
429628	416368	14213J	PARTICIPANT	\N	PRESENT	0
429629	416368	19591F	PARTICIPANT	\N	PRESENT	0
429630	416368	98050T	PARTICIPANT	\N	PRESENT	0
429631	416368	19681G	PARTICIPANT	\N	PRESENT	0
429632	416368	14061L	PARTICIPANT	\N	PRESENT	0
429633	416368	14121F	PARTICIPANT	\N	PRESENT	0
429634	416368	14059S	PARTICIPANT	\N	PRESENT	0
429635	416368	11083R	PARTICIPANT	\N	PRESENT	0
429636	416368	14038Y	PARTICIPANT	\N	PRESENT	0
429637	416368	14251Q	PARTICIPANT	\N	PRESENT	0
429638	416368	19415P	PARTICIPANT	\N	PRESENT	0
429639	416368	14195A	PARTICIPANT	\N	PRESENT	0
429640	416368	17589D	PARTICIPANT	\N	PRESENT	0
429641	416368	11064N	PARTICIPANT	\N	PRESENT	0
429642	416368	14111D	PARTICIPANT	\N	PRESENT	0
429643	416368	19563B	PARTICIPANT	\N	PRESENT	0
429644	416368	18083K	PARTICIPANT	\N	PRESENT	0
429645	416368	04057K	PARTICIPANT	\N	PRESENT	0
429646	416368	19687N	PARTICIPANT	\N	PRESENT	0
429647	416368	08031R	PARTICIPANT	\N	PRESENT	0
429648	416368	08019V	PARTICIPANT	\N	PRESENT	0
429649	416368	19399H	PARTICIPANT	\N	PRESENT	0
429650	416368	11027H	PARTICIPANT	\N	PRESENT	0
429651	416368	14159V	PARTICIPANT	\N	PRESENT	0
429652	416368	14329V	PARTICIPANT	\N	PRESENT	0
429653	416368	08052W	PARTICIPANT	\N	PRESENT	0
429654	416368	01028R	PARTICIPANT	\N	PRESENT	0
429655	416368	14357A	PARTICIPANT	\N	PRESENT	0
429656	416368	19689Q	PARTICIPANT	\N	PRESENT	0
429657	416368	19675J	PARTICIPANT	\N	PRESENT	0
429658	416368	19383Y	PARTICIPANT	\N	PRESENT	0
429659	416368	12016W	PARTICIPANT	\N	PRESENT	0
429660	416368	19762G	PARTICIPANT	\N	PRESENT	0
429661	416368	04018C	PARTICIPANT	\N	PRESENT	0
429662	416368	19621T	PARTICIPANT	\N	PRESENT	0
429663	416368	14021P	PARTICIPANT	\N	PRESENT	0
429664	416368	01062T	PARTICIPANT	\N	PRESENT	0
429665	416368	19367Y	PARTICIPANT	\N	PRESENT	0
429666	416368	08060W	PARTICIPANT	\N	PRESENT	0
429667	416368	14028W	PARTICIPANT	\N	PRESENT	0
429668	416368	14173T	PARTICIPANT	\N	PRESENT	0
429669	416368	11045K	PARTICIPANT	\N	PRESENT	0
429670	416368	19693L	PARTICIPANT	\N	PRESENT	0
429671	416368	04038G	PARTICIPANT	\N	PRESENT	0
429672	416368	19705W	PARTICIPANT	\N	PRESENT	0
429673	416368	19649G	PARTICIPANT	\N	PRESENT	0
429674	416368	11066Q	PARTICIPANT	\N	PRESENT	0
429675	416368	19573D	PARTICIPANT	\N	PRESENT	0
429676	416368	19794Q	PARTICIPANT	\N	PRESENT	0
429677	416368	08043V	PARTICIPANT	\N	PRESENT	0
429678	416368	11104D	PARTICIPANT	\N	PRESENT	0
429679	416368	14133K	PARTICIPANT	\N	PRESENT	0
429680	416368	08035V	PARTICIPANT	\N	PRESENT	0
429681	416368	92040Q	PARTICIPANT	\N	PRESENT	0
429682	416368	14135M	PARTICIPANT	\N	PRESENT	0
429683	416368	19820Y	PARTICIPANT	\N	PRESENT	0
429684	416368	14119M	PARTICIPANT	\N	PRESENT	0
429685	416368	11049P	PARTICIPANT	\N	PRESENT	0
429686	416368	08017T	PARTICIPANT	\N	PRESENT	0
429687	416368	14115H	PARTICIPANT	\N	PRESENT	0
429688	416368	14085U	PARTICIPANT	\N	PRESENT	0
429689	416368	08047A	PARTICIPANT	\N	PRESENT	0
429690	416368	19599P	PARTICIPANT	\N	PRESENT	0
429691	416368	14065Q	PARTICIPANT	\N	PRESENT	0
429692	416368	19549D	PARTICIPANT	\N	PRESENT	0
429693	416368	19333N	PARTICIPANT	\N	PRESENT	0
429694	416368	17583W	PARTICIPANT	\N	PRESENT	0
429695	416368	19683J	PARTICIPANT	\N	PRESENT	0
429696	416368	14001X	PARTICIPANT	\N	PRESENT	0
429697	416368	19631V	PARTICIPANT	\N	PRESENT	0
429698	416368	14147R	PARTICIPANT	\N	PRESENT	0
429699	416368	19551W	PARTICIPANT	\N	PRESENT	0
429700	416368	19812Y	PARTICIPANT	\N	PRESENT	0
429701	416368	11067R	PARTICIPANT	\N	PRESENT	0
429702	416368	14217N	PARTICIPANT	\N	PRESENT	0
429703	416368	04069P	PARTICIPANT	\N	PRESENT	0
429704	416368	08045X	PARTICIPANT	\N	PRESENT	0
429705	416368	14331P	PARTICIPANT	\N	PRESENT	0
429706	416368	11026G	PARTICIPANT	\N	PRESENT	0
429707	416368	14079W	PARTICIPANT	\N	PRESENT	0
429708	416368	14281W	PARTICIPANT	\N	PRESENT	0
427452	416322	04049K	PARTICIPANT	\N	PRESENT	0
427545	416308	01034P	PARTICIPANT	\N	PRESENT	0
427546	416308	19715Y	PARTICIPANT	\N	PRESENT	0
427547	416308	08052W	PARTICIPANT	\N	PRESENT	0
427548	416308	19669L	PARTICIPANT	\N	PRESENT	0
427549	416308	19820Y	PARTICIPANT	\N	PRESENT	0
427550	416308	19683J	PARTICIPANT	\N	PRESENT	0
427551	416308	19295A	PARTICIPANT	\N	PRESENT	0
427552	416308	17779H	PARTICIPANT	\N	PRESENT	0
427553	416308	04045F	PARTICIPANT	\N	PRESENT	0
427554	416308	19697Q	PARTICIPANT	\N	PRESENT	0
427555	416308	11067R	PARTICIPANT	\N	PRESENT	0
427556	416308	14223L	PARTICIPANT	\N	PRESENT	0
427557	416308	19651A	PARTICIPANT	\N	PRESENT	0
427558	416308	14187A	PARTICIPANT	\N	PRESENT	0
427559	416308	19301E	PARTICIPANT	\N	PRESENT	0
427560	416308	11103C	PARTICIPANT	\N	PRESENT	0
427561	416308	14281W	PARTICIPANT	\N	PRESENT	0
427562	416308	98024R	PARTICIPANT	\N	PRESENT	0
427563	416308	14039A	PARTICIPANT	\N	PRESENT	0
427564	416308	19681G	PARTICIPANT	\N	PRESENT	0
427565	416308	19747H	PARTICIPANT	\N	PRESENT	0
427566	416308	19717B	PARTICIPANT	\N	PRESENT	0
427567	416308	11031D	PARTICIPANT	\N	PRESENT	0
427568	416308	19569H	PARTICIPANT	\N	PRESENT	0
427569	416308	14261S	PARTICIPANT	\N	PRESENT	0
427570	416308	14157T	PARTICIPANT	\N	PRESENT	0
427571	416308	11072N	PARTICIPANT	\N	PRESENT	0
427572	416308	04088S	PARTICIPANT	\N	PRESENT	0
427573	416308	14195A	PARTICIPANT	\N	PRESENT	0
427574	416308	19794Q	PARTICIPANT	\N	PRESENT	0
427575	416308	19719D	PARTICIPANT	\N	PRESENT	0
427576	416308	14267Y	PARTICIPANT	\N	PRESENT	0
427577	416308	19691J	PARTICIPANT	\N	PRESENT	0
427578	416308	19745F	PARTICIPANT	\N	PRESENT	0
427579	416308	19679N	PARTICIPANT	\N	PRESENT	0
427580	416308	19760E	PARTICIPANT	\N	PRESENT	0
427581	416308	19415P	PARTICIPANT	\N	PRESENT	0
427582	416308	19367Y	PARTICIPANT	\N	PRESENT	0
427583	416308	19447X	PARTICIPANT	\N	PRESENT	0
427584	416308	19798U	PARTICIPANT	\N	PRESENT	0
427585	416308	08019V	PARTICIPANT	\N	PRESENT	0
427586	416308	19657G	PARTICIPANT	\N	PRESENT	0
427587	416308	14038Y	PARTICIPANT	\N	PRESENT	0
427588	416308	14213J	PARTICIPANT	\N	PRESENT	0
427589	416308	19565D	PARTICIPANT	\N	PRESENT	0
427590	416308	12016W	PARTICIPANT	\N	PRESENT	0
427591	416308	19467C	PARTICIPANT	\N	PRESENT	0
427592	416308	08015R	PARTICIPANT	\N	PRESENT	0
427593	416308	11077T	PARTICIPANT	\N	PRESENT	0
427594	416308	19723Y	PARTICIPANT	\N	PRESENT	0
427595	416308	14215L	PARTICIPANT	\N	PRESENT	0
427596	416308	19758L	PARTICIPANT	\N	PRESENT	0
427597	416308	19727D	PARTICIPANT	\N	PRESENT	0
427598	416308	19703U	PARTICIPANT	\N	PRESENT	0
427599	416308	14169X	PARTICIPANT	\N	PRESENT	0
427600	416308	14041T	PARTICIPANT	\N	PRESENT	0
427601	416308	19479G	PARTICIPANT	\N	PRESENT	0
427602	416308	14042U	PARTICIPANT	\N	PRESENT	0
427603	416308	19631V	PARTICIPANT	\N	PRESENT	0
427608	416308	08047A	PARTICIPANT	\N	PRESENT	0
427605	416308	14147R	PARTICIPANT	\N	PRESENT	0
427606	416308	19705W	PARTICIPANT	\N	PRESENT	0
427607	416308	08010L	PARTICIPANT	\N	PRESENT	0
427609	416308	01028R	PARTICIPANT	\N	PRESENT	0
427610	416308	19503N	PARTICIPANT	\N	PRESENT	0
427611	416308	14026U	PARTICIPANT	\N	PRESENT	0
427612	416308	14265W	PARTICIPANT	\N	PRESENT	0
427613	416308	14061L	PARTICIPANT	\N	PRESENT	0
427614	416308	14059S	PARTICIPANT	\N	PRESENT	0
427615	416308	14033T	PARTICIPANT	\N	PRESENT	0
427616	416308	19573D	PARTICIPANT	\N	PRESENT	0
427617	416308	14119M	PARTICIPANT	\N	PRESENT	0
427618	416308	14217N	PARTICIPANT	\N	PRESENT	0
427619	416308	10006L	PARTICIPANT	\N	PRESENT	0
427620	416308	19575F	PARTICIPANT	\N	PRESENT	0
427621	416308	19527W	PARTICIPANT	\N	PRESENT	0
427622	416308	14197C	PARTICIPANT	\N	PRESENT	0
427623	416308	14257W	PARTICIPANT	\N	PRESENT	0
427624	416308	14239U	PARTICIPANT	\N	PRESENT	0
427625	416308	14083S	PARTICIPANT	\N	PRESENT	0
427626	416308	19563B	PARTICIPANT	\N	PRESENT	0
427627	416308	11048N	PARTICIPANT	\N	PRESENT	0
427628	416308	19621T	PARTICIPANT	\N	PRESENT	0
427629	416308	18083K	PARTICIPANT	\N	PRESENT	0
427630	416308	19693L	PARTICIPANT	\N	PRESENT	0
427631	416308	14105F	PARTICIPANT	\N	PRESENT	0
427632	416308	14357A	PARTICIPANT	\N	PRESENT	0
427633	416308	11097X	PARTICIPANT	\N	PRESENT	0
427634	416308	11026G	PARTICIPANT	\N	PRESENT	0
427635	416308	19553Y	PARTICIPANT	\N	PRESENT	0
427543	416308	01043Q	PARTICIPANT	\N	PRESENT	0
427544	416308	04092N	PARTICIPANT	\N	PRESENT	0
427636	416308	19713W	PARTICIPANT	\N	PRESENT	0
427637	416308	07029T	PARTICIPANT	\N	PRESENT	0
428003	425133	14225N	PARTICIPANT	\N	PRESENT	0
428379	428378	11053K	PARTICIPANT	\N	PRESENT	0
428380	428378	14159V	PARTICIPANT	\N	PRESENT	0
428381	428378	05012A	PARTICIPANT	\N	PRESENT	0
432095	432090	14215L	PARTICIPANT	\N	PRESENT	0
432096	432090	19649G	PARTICIPANT	\N	PRESENT	0
432097	432090	19683J	PARTICIPANT	\N	PRESENT	0
432098	432090	19447X	PARTICIPANT	\N	PRESENT	0
432101	432090	14147R	PARTICIPANT	\N	PRESENT	0
432102	432090	11067R	PARTICIPANT	\N	PRESENT	0
444136	439687	14111D	PARTICIPANT	\N	PRESENT	0
434786	428530	11067R	PARTICIPANT	\N	PRESENT	0
444138	439687	19507S	PARTICIPANT	\N	PRESENT	0
444139	439687	14026U	PARTICIPANT	\N	PRESENT	0
444141	439687	19747H	PARTICIPANT	\N	PRESENT	0
444142	439687	19737F	PARTICIPANT	\N	PRESENT	0
444144	439687	19415P	PARTICIPANT	\N	PRESENT	0
444145	439687	19413M	PARTICIPANT	\N	PRESENT	0
444146	439687	17637T	PARTICIPANT	\N	PRESENT	0
444147	439687	14219Q	PARTICIPANT	\N	PRESENT	0
444148	439687	14053L	PARTICIPANT	\N	PRESENT	0
444149	439687	08068F	PARTICIPANT	\N	PRESENT	0
444152	439687	14083S	PARTICIPANT	\N	PRESENT	0
444137	439687	95030B	PARTICIPANT	\N	PRESENT	0
444153	439687	14115H	PARTICIPANT	\N	PRESENT	0
444154	439687	19745F	PARTICIPANT	\N	PRESENT	0
444155	439687	14215L	PARTICIPANT	\N	PRESENT	0
444156	439687	14079W	PARTICIPANT	\N	PRESENT	0
444157	439687	19657G	PARTICIPANT	\N	PRESENT	0
444158	439687	14331P	PARTICIPANT	\N	PRESENT	0
444159	439687	08055A	PARTICIPANT	\N	PRESENT	0
444160	439687	19521Q	PARTICIPANT	\N	PRESENT	0
444161	439687	19563B	PARTICIPANT	\N	PRESENT	0
444162	439687	14119M	PARTICIPANT	\N	PRESENT	0
444163	439687	01057W	PARTICIPANT	\N	PRESENT	0
444164	439687	08056B	PARTICIPANT	\N	PRESENT	0
444165	439687	14223L	PARTICIPANT	\N	PRESENT	0
444166	439687	11090Q	PARTICIPANT	\N	PRESENT	0
444167	439687	19729F	PARTICIPANT	\N	PRESENT	0
444168	439687	98022P	PARTICIPANT	\N	PRESENT	0
444169	439687	19794Q	PARTICIPANT	\N	PRESENT	0
444170	439687	14211G	PARTICIPANT	\N	PRESENT	0
444171	439687	19733B	PARTICIPANT	\N	PRESENT	0
444172	439687	14038Y	PARTICIPANT	\N	PRESENT	0
444173	439687	11101A	PARTICIPANT	\N	PRESENT	0
444174	439687	14173T	PARTICIPANT	\N	PRESENT	0
444175	439687	01048V	PARTICIPANT	\N	PRESENT	0
436344	436343	11064N	PARTICIPANT	\N	PRESENT	0
436347	436346	01057W	PARTICIPANT	\N	PRESENT	0
436348	436346	19723Y	PARTICIPANT	\N	PRESENT	0
436349	436346	14147R	PARTICIPANT	\N	PRESENT	0
436350	436346	14026U	PARTICIPANT	\N	PRESENT	0
437596	437594	19563B	PARTICIPANT	\N	PRESENT	0
437597	437594	08043V	PARTICIPANT	\N	PRESENT	0
437598	437594	19553Y	PARTICIPANT	\N	PRESENT	0
438289	437428	19447X	PARTICIPANT	\N	PRESENT	0
438290	437428	14259Y	PARTICIPANT	\N	PRESENT	0
438291	437428	19253P	PARTICIPANT	\N	PRESENT	0
438292	437428	01024M	PARTICIPANT	\N	PRESENT	0
438293	437428	14089Y	PARTICIPANT	\N	PRESENT	0
438294	437428	19629C	PARTICIPANT	\N	PRESENT	0
438295	437428	19762G	PARTICIPANT	\N	PRESENT	0
438296	437428	01060R	PARTICIPANT	\N	PRESENT	0
438297	437428	19581D	PARTICIPANT	\N	PRESENT	0
438298	437428	04038G	PARTICIPANT	\N	PRESENT	0
438410	438335	19768N	PARTICIPANT	\N	PRESENT	0
438411	438335	19515S	PARTICIPANT	\N	PRESENT	0
438412	438335	19782L	PARTICIPANT	\N	PRESENT	0
438413	438335	14357A	PARTICIPANT	\N	PRESENT	0
438414	438335	19441R	PARTICIPANT	\N	PRESENT	0
438415	438335	19812Y	PARTICIPANT	\N	PRESENT	0
438416	438335	19413M	PARTICIPANT	\N	PRESENT	0
438417	438335	80013X	PARTICIPANT	\N	PRESENT	0
438418	438335	19631V	PARTICIPANT	\N	PRESENT	0
438419	438335	11099A	PARTICIPANT	\N	PRESENT	0
438420	438335	19705W	PARTICIPANT	\N	PRESENT	0
438421	438335	08015R	PARTICIPANT	\N	PRESENT	0
438422	438335	08019V	PARTICIPANT	\N	PRESENT	0
438423	438335	19369B	PARTICIPANT	\N	PRESENT	0
438424	438335	19511N	PARTICIPANT	\N	PRESENT	0
438425	438335	08028W	PARTICIPANT	\N	PRESENT	0
438426	438335	19563B	PARTICIPANT	\N	PRESENT	0
438427	438335	14265W	PARTICIPANT	\N	PRESENT	0
438428	438335	14329V	PARTICIPANT	\N	PRESENT	0
438429	438335	14187A	PARTICIPANT	\N	PRESENT	0
438430	438335	14033T	PARTICIPANT	\N	PRESENT	0
438431	438335	11090Q	PRESIDENT	0	PRESENT	0
438432	438335	01025N	PARTICIPANT	\N	PRESENT	0
438433	438335	19269X	PARTICIPANT	\N	PRESENT	0
438434	438335	14205J	PARTICIPANT	\N	PRESENT	0
438435	438335	04088S	PARTICIPANT	\N	PRESENT	0
438436	438335	04089T	PARTICIPANT	\N	PRESENT	0
438437	438335	14115H	PARTICIPANT	\N	PRESENT	0
438438	438335	11101A	PARTICIPANT	\N	PRESENT	0
438439	438335	19747H	PARTICIPANT	\N	PRESENT	0
438440	438335	14207L	PARTICIPANT	\N	PRESENT	0
438441	438335	19619A	PARTICIPANT	\N	PRESENT	0
438442	438335	14257W	PARTICIPANT	\N	PRESENT	0
438443	437428	19649G	PARTICIPANT	\N	PRESENT	0
438444	437428	95063L	PARTICIPANT	\N	PRESENT	0
438445	437428	14069U	PARTICIPANT	\N	PRESENT	0
438446	437428	04008A	PARTICIPANT	\N	PRESENT	0
438447	437428	98035U	PARTICIPANT	\N	EXCUSE	0
438448	436938	98029W	PARTICIPANT	\N	PRESENT	0
438449	436938	14097Y	PARTICIPANT	\N	PRESENT	0
438450	436938	04035D	PARTICIPANT	\N	PRESENT	0
438451	436938	95067Q	PARTICIPANT	\N	PRESENT	0
438452	436938	11064N	PARTICIPANT	\N	PRESENT	0
438453	438335	19695N	PARTICIPANT	\N	PRESENT	0
438454	438335	11077T	PARTICIPANT	\N	PRESENT	0
438455	438335	14081Q	PARTICIPANT	\N	PRESENT	0
438456	437428	19489J	PARTICIPANT	\N	PRESENT	0
438457	437428	14031R	RAPPORTEUR_AVIS	\N	PRESENT	0
438458	436938	11115U	PARTICIPANT	\N	PRESENT	0
438459	436938	14055N	PARTICIPANT	\N	PRESENT	0
438460	436938	14255U	PARTICIPANT	\N	PRESENT	0
438461	438335	04049K	PARTICIPANT	\N	PRESENT	0
438462	438335	19467C	PARTICIPANT	\N	EXCUSE	0
438463	438335	08068F	PARTICIPANT	\N	EXCUSE	0
438464	438335	11081P	PARTICIPANT	\N	EXCUSE	0
438475	437428	08018U	PARTICIPANT	\N	PRESENT	0
438485	437428	19747H	RAPPORTEUR_AVIS	\N	PRESENT	0
438618	436940	19443T	PARTICIPANT	\N	PRESENT	0
438619	436940	12041X	PARTICIPANT	\N	PRESENT	0
438620	436940	11080N	PARTICIPANT	\N	PRESENT	0
438621	436940	95030B	PARTICIPANT	\N	PRESENT	0
438622	436940	04034C	PARTICIPANT	\N	PRESENT	0
438623	436940	14079W	PARTICIPANT	\N	PRESENT	0
438624	436940	01058X	PARTICIPANT	\N	PRESENT	0
438625	436940	04040A	PARTICIPANT	\N	PRESENT	0
438626	436940	16685X	PARTICIPANT	\N	PRESENT	0
438627	436940	04042C	PRESIDENT	0	PRESENT	0
438628	436940	11066Q	PARTICIPANT	\N	PRESENT	0
438629	436940	19669L	PARTICIPANT	\N	PRESENT	0
438630	436940	08056B	PARTICIPANT	\N	PRESENT	0
438631	436940	95037J	PARTICIPANT	\N	PRESENT	0
438632	436940	11115U	PARTICIPANT	\N	PRESENT	0
438633	436940	14055N	PARTICIPANT	\N	PRESENT	0
438634	436940	19421M	PARTICIPANT	\N	PRESENT	0
438635	436940	19709B	PARTICIPANT	\N	PRESENT	0
438636	436940	08049C	PARTICIPANT	\N	PRESENT	0
438637	436940	97011G	PARTICIPANT	\N	PRESENT	0
438638	436940	08061X	PARTICIPANT	\N	PRESENT	0
438639	436940	08047A	PARTICIPANT	\N	PRESENT	0
438640	436940	98029W	PARTICIPANT	\N	PRESENT	0
438641	436940	14097Y	PARTICIPANT	\N	PRESENT	0
438642	436940	04035D	PARTICIPANT	\N	PRESENT	0
438643	436940	95067Q	PARTICIPANT	\N	PRESENT	0
438644	436940	14133K	PARTICIPANT	\N	PRESENT	0
438645	436940	11041F	PARTICIPANT	\N	PRESENT	0
438646	436940	14235Q	PARTICIPANT	\N	PRESENT	0
438647	436940	08058D	PARTICIPANT	\N	PRESENT	0
438648	436940	19251M	PARTICIPANT	\N	PRESENT	0
438649	436940	19319Q	PARTICIPANT	\N	PRESENT	0
438650	436940	14105F	PARTICIPANT	\N	PRESENT	0
438651	436940	14267Y	PARTICIPANT	\N	PRESENT	0
438652	436940	11064N	PARTICIPANT	\N	PRESENT	0
438653	436940	98050T	PARTICIPANT	\N	PRESENT	0
438654	436940	14255U	PARTICIPANT	\N	PRESENT	0
438656	437190	19333N	PARTICIPANT	\N	PRESENT	0
438657	437190	19383Y	PARTICIPANT	\N	PRESENT	0
438658	437190	17583W	PARTICIPANT	\N	PRESENT	0
438659	437190	19701S	PARTICIPANT	\N	PRESENT	0
438660	437190	19549D	PARTICIPANT	\N	PRESENT	0
438661	437190	19387D	PARTICIPANT	\N	PRESENT	0
438662	437190	19820Y	PARTICIPANT	\N	PRESENT	0
438663	437190	14219Q	PARTICIPANT	\N	PRESENT	0
438664	437190	19826F	PARTICIPANT	\N	PRESENT	0
438665	437190	14221J	PARTICIPANT	\N	PRESENT	0
438666	437190	19599P	PARTICIPANT	\N	PRESENT	0
438667	437190	19637C	PARTICIPANT	\N	PRESENT	0
438668	437190	18083K	PARTICIPANT	\N	PRESENT	0
438669	437190	14237S	PARTICIPANT	\N	PRESENT	0
438670	437190	19551W	PARTICIPANT	\N	PRESENT	0
438671	437190	05012A	PARTICIPANT	\N	PRESENT	0
438672	437190	14051J	PARTICIPANT	\N	PRESENT	0
438673	437190	08060W	PARTICIPANT	\N	PRESENT	0
438674	437190	19347U	PARTICIPANT	\N	PRESENT	0
438675	437190	14157T	PARTICIPANT	\N	PRESENT	0
438676	437190	08024S	PARTICIPANT	\N	PRESENT	0
438677	437190	17637T	PARTICIPANT	\N	PRESENT	0
438678	437190	14038Y	PARTICIPANT	0	PRESENT	0
438679	437190	14103D	PARTICIPANT	\N	PRESENT	0
438680	437190	14031R	PARTICIPANT	\N	PRESENT	0
438681	437190	14093U	PARTICIPANT	\N	PRESENT	0
438682	437190	19733B	PARTICIPANT	\N	PRESENT	0
438683	437190	08009T	PRESIDENT	0	PRESENT	0
438684	437190	19737F	PARTICIPANT	\N	PRESENT	0
438685	437190	19739H	PARTICIPANT	\N	PRESENT	0
438686	437190	19745F	PARTICIPANT	\N	PRESENT	0
438687	437190	02002K	PARTICIPANT	\N	EXCUSE	0
438720	426316	19631V	PARTICIPANT	\N	PRESENT	0
438721	426316	14038Y	PARTICIPANT	\N	PRESENT	0
438722	426316	08069G	PARTICIPANT	\N	PRESENT	0
438723	426316	01043Q	PARTICIPANT	\N	PRESENT	0
438724	426316	14225N	PARTICIPANT	\N	PRESENT	0
438725	426316	11041F	PARTICIPANT	\N	PRESENT	0
438726	426316	19387D	PARTICIPANT	\N	PRESENT	0
438727	426316	14097Y	PARTICIPANT	\N	PRESENT	0
438728	426316	19762G	PARTICIPANT	\N	PRESENT	0
438729	426316	95030B	PARTICIPANT	\N	PRESENT	0
438730	426316	19739H	PARTICIPANT	\N	PRESENT	0
438731	426316	14115H	PARTICIPANT	\N	PRESENT	0
438732	426316	14223L	PARTICIPANT	\N	PRESENT	0
438733	426316	19703U	PARTICIPANT	\N	PRESENT	0
438734	426316	08028W	PARTICIPANT	\N	PRESENT	0
438735	426316	14147R	PARTICIPANT	\N	PRESENT	0
438736	426316	04018C	PARTICIPANT	\N	PRESENT	0
438737	426316	08020N	PARTICIPANT	\N	PRESENT	0
438738	426316	19719D	PARTICIPANT	\N	PRESENT	0
438739	426316	14261S	PARTICIPANT	\N	PRESENT	0
438740	426316	88008L	PARTICIPANT	\N	PRESENT	0
438741	426316	19731Y	PARTICIPANT	\N	PRESENT	0
438742	426316	04049K	PARTICIPANT	\N	PRESENT	0
438743	426316	04035D	PARTICIPANT	\N	PRESENT	0
438744	426316	14059S	PARTICIPANT	\N	PRESENT	0
425030	425029	14097Y	PARTICIPANT	\N	PRESENT	0
425032	425031	14097Y	PARTICIPANT	\N	PRESENT	0
425149	424896	04044E	PARTICIPANT	\N	EXCUSE	0
425047	424896	14071N	PARTICIPANT	\N	EXCUSE	0
425087	424896	11048N	PARTICIPANT	\N	EXCUSE	0
429036	420728	08045X	PARTICIPANT	\N	PRESENT	0
429042	420727	08045X	PARTICIPANT	\N	PRESENT	0
431051	431047	01025N	PARTICIPANT	\N	PRESENT	0
431052	431047	14207L	PARTICIPANT	\N	PRESENT	0
431059	431058	14187A	PARTICIPANT	\N	PRESENT	0
431071	431070	01024M	PARTICIPANT	\N	PRESENT	0
431072	431070	19581D	PARTICIPANT	\N	PRESENT	0
445949	441793	04040A	PRESIDENT	0	PRESENT	0
445950	441793	04086Q	PARTICIPANT	\N	EXCUSE	0
445953	445952	19467C	PARTICIPANT	\N	PRESENT	0
445954	445952	19369B	PARTICIPANT	\N	PRESENT	0
449744	448623	14195A	PARTICIPANT	\N	EXCUSE	0
445956	445952	14135M	PARTICIPANT	\N	PRESENT	0
449638	447997	14217N	PARTICIPANT	\N	PRESENT	0
449639	447997	10006L	PARTICIPANT	\N	PRESENT	0
449640	447997	98024R	PARTICIPANT	\N	PRESENT	0
449641	447997	01034P	PARTICIPANT	\N	PRESENT	0
449642	447997	04092N	PRESIDENT	0	PRESENT	0
449643	447997	11045K	PARTICIPANT	\N	PRESENT	0
449644	447997	08052W	PARTICIPANT	\N	PRESENT	0
449645	447997	19663E	PARTICIPANT	\N	PRESENT	0
449646	447997	19691J	PARTICIPANT	\N	PRESENT	0
449647	447997	19723Y	PARTICIPANT	\N	PRESENT	0
449648	447997	11103C	PARTICIPANT	\N	PRESENT	0
449649	447997	19760E	PARTICIPANT	\N	PRESENT	0
449650	447997	19527W	PARTICIPANT	\N	PRESENT	0
449651	447997	14239U	PARTICIPANT	\N	PRESENT	0
449652	447997	19553Y	PARTICIPANT	\N	PRESENT	0
449655	447997	14119M	PARTICIPANT	\N	PRESENT	0
449657	447997	19569H	PARTICIPANT	\N	PRESENT	0
449659	447997	19683J	PARTICIPANT	\N	PRESENT	0
449662	447997	14227Q	PARTICIPANT	\N	PRESENT	0
449663	447997	14071N	PARTICIPANT	\N	EXCUSE	0
449666	447997	08041T	PARTICIPANT	\N	EXCUSE	0
449746	449745	19467C	PARTICIPANT	\N	PRESENT	0
449747	449745	19667J	PARTICIPANT	\N	PRESENT	0
449748	449745	14033T	PARTICIPANT	\N	PRESENT	0
449750	449745	19511N	PARTICIPANT	\N	PRESENT	0
449751	449745	11099A	PARTICIPANT	\N	PRESENT	0
449752	449745	04088S	PARTICIPANT	\N	PRESENT	0
449753	449745	19735D	PARTICIPANT	\N	PRESENT	0
449754	449745	19713W	PARTICIPANT	\N	PRESENT	0
449755	449745	14173T	PARTICIPANT	\N	PRESENT	0
449802	445943	19329S	PARTICIPANT	\N	EXCUSE	0
449803	445943	19301E	PARTICIPANT	\N	EXCUSE	0
449804	445943	14331P	PARTICIPANT	\N	EXCUSE	0
449805	445943	19319Q	PARTICIPANT	\N	EXCUSE	0
449806	445943	19583F	PARTICIPANT	\N	EXCUSE	0
449807	441812	14275Y	PARTICIPANT	\N	EXCUSE	0
449856	449855	14275Y	PARTICIPANT	\N	EXCUSE	0
449857	448623	11048N	PARTICIPANT	\N	EXCUSE	0
449858	439823	19585H	PARTICIPANT	\N	PRESENT	0
449859	439823	19563B	PARTICIPANT	\N	PRESENT	0
449860	439823	98022P	PARTICIPANT	\N	PRESENT	0
449861	439823	11040E	PARTICIPANT	\N	PRESENT	0
449862	439823	19347U	PARTICIPANT	\N	PRESENT	0
449863	439823	14051J	PARTICIPANT	\N	PRESENT	0
449864	439823	11027H	PARTICIPANT	\N	PRESENT	0
449865	439823	80013X	PARTICIPANT	\N	PRESENT	0
449866	439823	11066Q	PARTICIPANT	\N	PRESENT	0
449867	439823	19525U	PARTICIPANT	\N	PRESENT	0
449868	439823	14097Y	PARTICIPANT	\N	PRESENT	0
449869	439823	08056B	PARTICIPANT	\N	PRESENT	0
449870	439823	19731Y	PARTICIPANT	\N	PRESENT	0
449871	439823	08060W	PARTICIPANT	\N	PRESENT	0
449872	439823	08061X	PARTICIPANT	\N	PRESENT	0
449873	439823	19253P	PARTICIPANT	\N	PRESENT	0
449874	439823	08055A	PARTICIPANT	\N	PRESENT	0
449875	439823	14229S	PARTICIPANT	\N	PRESENT	0
449876	439823	14197C	PARTICIPANT	\N	PRESENT	0
449877	439823	14159V	PARTICIPANT	\N	PRESENT	0
449878	439823	14239U	PARTICIPANT	\N	PRESENT	0
449879	439823	19697Q	PARTICIPANT	\N	PRESENT	0
449880	439823	19685L	PARTICIPANT	\N	PRESENT	0
449881	439823	19782L	PARTICIPANT	\N	PRESENT	0
449882	439823	19637C	PARTICIPANT	\N	PRESENT	0
449883	439823	08068F	PARTICIPANT	\N	PRESENT	0
449884	439823	11054L	PARTICIPANT	\N	PRESENT	0
449885	439823	08031R	PARTICIPANT	\N	PRESENT	0
449886	439823	19669L	PARTICIPANT	\N	PRESENT	0
449887	439823	11041F	PARTICIPANT	\N	PRESENT	0
449888	439823	11067R	PARTICIPANT	\N	PRESENT	0
449889	439823	11045K	PARTICIPANT	\N	PRESENT	0
449890	439823	08012N	PARTICIPANT	\N	PRESENT	0
449891	439823	98035U	PARTICIPANT	\N	PRESENT	0
449892	439823	19591F	PARTICIPANT	\N	PRESENT	0
449893	439823	04045F	PARTICIPANT	\N	PRESENT	0
449894	439823	19681G	PARTICIPANT	\N	PRESENT	0
449895	439823	14227Q	PARTICIPANT	\N	PRESENT	0
449896	439823	19251M	PARTICIPANT	\N	PRESENT	0
449897	439823	14121F	PARTICIPANT	\N	PRESENT	0
449898	439823	19760E	PARTICIPANT	\N	PRESENT	0
449899	439823	04057K	PARTICIPANT	\N	PRESENT	0
449900	439823	01060R	PARTICIPANT	\N	PRESENT	0
449901	439823	19599P	PARTICIPANT	\N	PRESENT	0
449902	439823	14235Q	PARTICIPANT	\N	PRESENT	0
449903	439823	14201E	PARTICIPANT	\N	PRESENT	0
449904	439823	19349W	PARTICIPANT	\N	PRESENT	0
449905	439823	19543W	PARTICIPANT	\N	PRESENT	0
449906	439823	19387D	PARTICIPANT	\N	PRESENT	0
449907	439823	19719D	PARTICIPANT	\N	PRESENT	0
449908	439823	19649G	PARTICIPANT	\N	PRESENT	0
449909	439823	19413M	PARTICIPANT	\N	PRESENT	0
449910	439823	19333N	PARTICIPANT	\N	PRESENT	0
449911	439823	14063N	PARTICIPANT	\N	PRESENT	0
449912	439823	14241N	PARTICIPANT	\N	PRESENT	0
449913	439823	01062T	PARTICIPANT	\N	PRESENT	0
449914	439823	08052W	PARTICIPANT	\N	PRESENT	0
449915	439823	14107H	PARTICIPANT	\N	PRESENT	0
449916	439823	14065Q	PARTICIPANT	\N	PRESENT	0
449917	439823	14207L	PARTICIPANT	\N	PRESENT	0
449918	439823	19545Y	PARTICIPANT	\N	PRESENT	0
449919	439823	11056N	PARTICIPANT	\N	PRESENT	0
449920	439823	19758L	PARTICIPANT	\N	PRESENT	0
449921	439823	12041X	PARTICIPANT	\N	PRESENT	0
449922	439823	04038G	PARTICIPANT	\N	PRESENT	0
449923	439823	11074Q	PARTICIPANT	\N	PRESENT	0
449924	439823	04085P	PARTICIPANT	\N	PRESENT	0
449925	439823	19593H	PARTICIPANT	\N	PRESENT	0
449926	439823	04034C	PARTICIPANT	\N	PRESENT	0
449927	439823	14211G	PARTICIPANT	\N	PRESENT	0
449928	439823	19711U	PARTICIPANT	\N	PRESENT	0
449929	439823	08053X	PARTICIPANT	\N	PRESENT	0
449930	439823	89017R	PARTICIPANT	\N	PRESENT	0
449931	439823	11064N	PARTICIPANT	\N	PRESENT	0
449932	439823	14093U	PARTICIPANT	\N	PRESENT	0
449933	439823	19443T	PARTICIPANT	\N	PRESENT	0
449934	439823	98005N	PARTICIPANT	\N	PRESENT	0
449935	439823	19741B	PARTICIPANT	\N	PRESENT	0
449936	439823	19631V	PARTICIPANT	\N	PRESENT	0
449937	439823	14029X	PARTICIPANT	\N	PRESENT	0
449938	439823	19709B	PARTICIPANT	\N	PRESENT	0
449939	439823	04088S	PARTICIPANT	\N	PRESENT	0
449940	439823	19507S	PARTICIPANT	\N	PRESENT	0
449941	439823	19551W	PARTICIPANT	\N	PRESENT	0
449942	439823	07029T	PARTICIPANT	\N	PRESENT	0
449943	439823	17589D	PARTICIPANT	\N	PRESENT	0
449944	439823	19729F	PARTICIPANT	\N	PRESENT	0
449945	439823	11012A	PARTICIPANT	\N	PRESENT	0
449946	439823	14034U	PARTICIPANT	\N	PRESENT	0
449947	439823	88008L	PARTICIPANT	\N	PRESENT	0
449948	439823	19629C	PARTICIPANT	\N	PRESENT	0
449949	439823	14355X	PARTICIPANT	\N	PRESENT	0
449950	439823	08062Y	PARTICIPANT	\N	PRESENT	0
449951	439823	08015R	PARTICIPANT	\N	PRESENT	0
449952	439823	19705W	PARTICIPANT	\N	PRESENT	0
449953	439823	98050T	PARTICIPANT	\N	PRESENT	0
449954	439823	19553Y	PARTICIPANT	\N	PRESENT	0
449956	439823	19687N	PARTICIPANT	\N	PRESENT	0
449957	439823	19723Y	PARTICIPANT	\N	PRESENT	0
449958	439823	19467C	PARTICIPANT	\N	PRESENT	0
449959	439823	18083K	PARTICIPANT	\N	PRESENT	0
449960	439823	19415P	PARTICIPANT	\N	PRESENT	0
449961	439823	19269X	PARTICIPANT	\N	PRESENT	0
449962	439823	08019V	PARTICIPANT	\N	PRESENT	0
449963	439823	19399H	PARTICIPANT	\N	PRESENT	0
449964	439823	19693L	PARTICIPANT	\N	PRESENT	0
449965	439823	01028R	PARTICIPANT	\N	PRESENT	0
449966	439823	19663E	PARTICIPANT	\N	PRESENT	0
449967	439823	14021P	PARTICIPANT	\N	PRESENT	0
449969	439823	14213J	PARTICIPANT	\N	PRESENT	0
449970	439823	08045X	PARTICIPANT	\N	PRESENT	0
449971	439823	14329V	PARTICIPANT	\N	PRESENT	0
429709	416368	11054L	PARTICIPANT	\N	PRESENT	0
429710	416368	19671E	PARTICIPANT	\N	PRESENT	0
429711	416368	19251M	PARTICIPANT	\N	PRESENT	0
429712	416368	19581D	PARTICIPANT	\N	PRESENT	0
429713	416368	19413M	PARTICIPANT	\N	PRESENT	0
429714	416368	19703U	PARTICIPANT	\N	PRESENT	0
429715	416368	19673G	PARTICIPANT	\N	PRESENT	0
429716	416368	14265W	PARTICIPANT	\N	PRESENT	0
429717	416368	11053K	PARTICIPANT	\N	PRESENT	0
429718	416368	14231L	PARTICIPANT	\N	PRESENT	0
429719	416368	11010L	PARTICIPANT	\N	PRESENT	0
429720	416368	04089T	PARTICIPANT	\N	PRESENT	0
429721	416368	14031R	PARTICIPANT	\N	PRESENT	0
429812	416368	04086Q	PARTICIPANT	\N	PRESENT	0
429723	416368	19667J	PARTICIPANT	\N	PRESENT	0
429724	416368	14069U	PARTICIPANT	\N	PRESENT	0
429725	416368	19387D	PARTICIPANT	\N	PRESENT	0
429726	416368	11115U	PARTICIPANT	\N	PRESENT	0
429727	416368	14199E	PARTICIPANT	\N	PRESENT	0
429728	416368	95037J	PARTICIPANT	\N	PRESENT	0
429729	416368	19575F	PARTICIPANT	\N	PRESENT	0
429730	416368	08044W	PARTICIPANT	\N	PRESENT	0
429731	416368	14179A	PARTICIPANT	\N	PRESENT	0
429732	416368	19467C	PARTICIPANT	\N	PRESENT	0
429733	416368	19691J	PARTICIPANT	\N	PRESENT	0
429734	416368	14253S	PARTICIPANT	\N	PRESENT	0
429735	416368	19369B	PARTICIPANT	\N	PRESENT	0
429736	416368	11048N	PARTICIPANT	\N	PRESENT	0
429737	416368	04040A	PARTICIPANT	\N	PRESENT	0
429738	416368	08009T	PARTICIPANT	\N	PRESENT	0
429739	416368	08034U	PARTICIPANT	\N	PRESENT	0
429740	416368	19611R	PARTICIPANT	\N	PRESENT	0
429741	416368	19737F	PARTICIPANT	\N	PRESENT	0
429742	416368	19533U	PARTICIPANT	\N	PRESENT	0
429743	416368	11085T	PARTICIPANT	\N	PRESENT	0
429744	416368	19699S	PARTICIPANT	\N	PRESENT	0
429745	416368	10006L	PARTICIPANT	\N	PRESENT	0
429746	416368	19721W	PARTICIPANT	\N	PRESENT	0
429747	416368	19798U	PARTICIPANT	\N	PRESENT	0
429748	416368	14193X	PARTICIPANT	\N	PRESENT	0
429749	416368	19619A	PARTICIPANT	\N	PRESENT	0
429750	416368	14237S	PARTICIPANT	\N	PRESENT	0
429751	416368	19569H	PARTICIPANT	\N	PRESENT	0
429752	416368	19515S	PARTICIPANT	\N	PRESENT	0
429754	416368	14191V	PARTICIPANT	\N	PRESENT	0
429755	416368	16685X	PARTICIPANT	\N	PRESENT	0
429756	416368	14219Q	PARTICIPANT	\N	PRESENT	0
429757	416368	11080N	PARTICIPANT	\N	PRESENT	0
429758	416368	19527W	PARTICIPANT	\N	PRESENT	0
429759	416368	19479G	PARTICIPANT	\N	PRESENT	0
429760	416368	19766L	PARTICIPANT	\N	PRESENT	0
429761	416368	11065P	PARTICIPANT	\N	PRESENT	0
429762	416368	14259Y	PARTICIPANT	\N	PRESENT	0
429763	416368	19739H	PARTICIPANT	\N	PRESENT	0
429764	416368	87003B	PARTICIPANT	\N	PRESENT	0
429765	416368	19441R	PARTICIPANT	\N	PRESENT	0
429766	416368	19713W	PARTICIPANT	\N	PRESENT	0
429767	416368	01057W	PARTICIPANT	\N	PRESENT	0
429768	416368	19319Q	PARTICIPANT	\N	PRESENT	0
429769	416368	14223L	PARTICIPANT	\N	PRESENT	0
429770	416368	14275Y	PARTICIPANT	\N	PRESENT	0
429771	416368	11090Q	PARTICIPANT	\N	PRESENT	0
429772	416368	04043D	PARTICIPANT	\N	PRESENT	0
429773	416368	14093U	PARTICIPANT	\N	PRESENT	0
429774	416368	14053L	PARTICIPANT	\N	PRESENT	0
429775	416368	95067Q	PARTICIPANT	\N	PRESENT	0
429776	416368	14103D	PARTICIPANT	\N	PRESENT	0
429777	416368	14205J	PARTICIPANT	\N	PRESENT	0
429778	416368	14073Q	PARTICIPANT	\N	PRESENT	0
429779	416368	14087W	PARTICIPANT	\N	PRESENT	0
429780	416368	14267Y	PARTICIPANT	\N	PRESENT	0
429781	416368	14215L	PARTICIPANT	\N	PRESENT	0
429782	416368	08056B	PARTICIPANT	\N	PRESENT	0
429783	416368	14055N	PARTICIPANT	\N	PRESENT	0
429784	416368	19643A	PARTICIPANT	\N	PRESENT	0
429785	416368	04071H	PARTICIPANT	\N	PRESENT	0
429786	416368	14083S	PARTICIPANT	\N	PRESENT	0
429787	416368	14221J	PARTICIPANT	\N	PRESENT	0
429788	416368	19745F	PARTICIPANT	\N	PRESENT	0
429789	416368	14169X	PARTICIPANT	\N	PRESENT	0
429790	416368	19826F	PARTICIPANT	\N	PRESENT	0
429791	416368	10015M	PARTICIPANT	\N	PRESENT	0
429792	416368	14255U	PARTICIPANT	\N	PRESENT	0
429793	416368	11043H	PARTICIPANT	\N	PRESENT	0
429794	416368	01048V	PARTICIPANT	\N	PRESENT	0
429795	416368	14277B	PARTICIPANT	\N	PRESENT	0
429796	416368	08028W	PARTICIPANT	\N	PRESENT	0
429797	416368	04033B	PARTICIPANT	\N	PRESENT	0
429798	416368	01024M	PARTICIPANT	\N	PRESENT	0
429799	416368	14187A	PARTICIPANT	\N	PRESENT	0
429800	416368	14030Q	PARTICIPANT	\N	PRESENT	0
429801	416368	14327T	PARTICIPANT	\N	PRESENT	0
429802	416368	14071N	PARTICIPANT	\N	PRESENT	0
429803	416368	05008E	PARTICIPANT	\N	PRESENT	0
429804	416368	11097X	PARTICIPANT	\N	PRESENT	0
429805	416368	19421M	PARTICIPANT	\N	PRESENT	0
429806	416368	19679N	PARTICIPANT	\N	PRESENT	0
429807	416368	04097T	PARTICIPANT	\N	PRESENT	0
429808	416368	08010L	PARTICIPANT	\N	PRESENT	0
429809	416368	14207L	PARTICIPANT	\N	PRESENT	0
429810	416368	19553Y	PARTICIPANT	\N	PRESENT	0
429811	416368	04042C	PARTICIPANT	\N	PRESENT	0
429813	416368	04092N	PARTICIPANT	\N	PRESENT	0
429814	416368	04044E	PARTICIPANT	\N	PRESENT	0
429815	416368	95041E	PARTICIPANT	\N	PRESENT	0
429816	416368	19747H	PARTICIPANT	\N	PRESENT	0
429817	416368	98018T	PARTICIPANT	\N	PRESENT	0
429818	416368	14157T	PARTICIPANT	\N	PRESENT	0
429819	416368	96004D	PARTICIPANT	\N	PRESENT	0
429820	416368	01058X	PARTICIPANT	\N	PRESENT	0
429821	416368	99004R	PARTICIPANT	\N	PRESENT	0
429822	416368	95030B	PARTICIPANT	\N	PRESENT	0
429823	416368	14026U	PARTICIPANT	\N	PRESENT	0
429824	416368	11101A	PARTICIPANT	\N	PRESENT	0
429825	416368	98024R	PARTICIPANT	\N	PRESENT	0
429826	416368	04035D	PARTICIPANT	\N	PRESENT	0
429827	416368	19719D	PARTICIPANT	\N	PRESENT	0
429828	416368	01034P	PARTICIPANT	\N	PRESENT	0
429829	416368	19335Q	PARTICIPANT	\N	PRESENT	0
429830	416368	07029T	PARTICIPANT	\N	PRESENT	0
429831	416368	19733B	PARTICIPANT	\N	PRESENT	0
429832	416368	19723Y	PARTICIPANT	\N	PRESENT	0
429833	416368	86034E	PARTICIPANT	\N	PRESENT	0
429834	416368	08014Q	PARTICIPANT	\N	PRESENT	0
429835	416368	07033P	PARTICIPANT	\N	PRESENT	0
429836	416368	14249W	PARTICIPANT	\N	PRESENT	0
429837	416368	19782L	PARTICIPANT	\N	PRESENT	0
429838	416368	11072N	PARTICIPANT	\N	PRESENT	0
429839	416368	19727D	PARTICIPANT	\N	PRESENT	0
429841	416368	89017R	PARTICIPANT	\N	PRESENT	0
429842	416368	14225N	PARTICIPANT	\N	PRESENT	0
429843	416368	14105F	PARTICIPANT	\N	PRESENT	0
429844	416368	08069G	PARTICIPANT	\N	PRESENT	0
429845	416368	14227Q	PARTICIPANT	\N	PRESENT	0
429846	416368	19521Q	PARTICIPANT	\N	PRESENT	0
429847	416368	19715Y	PARTICIPANT	\N	PRESENT	0
429848	416368	01025N	PARTICIPANT	\N	PRESENT	0
429849	416368	14042U	PARTICIPANT	\N	PRESENT	0
429853	416368	19760E	PARTICIPANT	\N	PRESENT	0
429851	416368	14109K	PARTICIPANT	\N	PRESENT	0
429852	416368	08020N	PARTICIPANT	\N	PRESENT	0
429856	416368	19531S	PARTICIPANT	\N	PRESENT	0
429862	416368	04049K	PARTICIPANT	\N	PRESENT	0
429863	416368	19447X	PARTICIPANT	\N	PRESENT	0
429865	416368	11070L	PARTICIPANT	\N	PRESENT	0
429866	416368	04070G	PARTICIPANT	\N	PRESENT	0
429867	416368	19543W	PARTICIPANT	\N	PRESENT	0
429868	416368	04088S	PARTICIPANT	\N	PRESENT	0
429874	416368	14033T	PARTICIPANT	\N	PRESENT	0
429870	416368	08048B	PARTICIPANT	\N	PRESENT	0
429871	416368	14089Y	PARTICIPANT	\N	PRESENT	0
426647	426642	08038Y	PARTICIPANT	\N	PRESENT	0
426649	426642	19413M	PARTICIPANT	\N	PRESENT	0
426885	426884	19515S	PARTICIPANT	\N	PRESENT	0
426886	426884	08055A	PARTICIPANT	\N	PRESENT	0
426887	426884	19575F	PARTICIPANT	\N	PRESENT	0
426888	426884	14105F	PARTICIPANT	\N	PRESENT	0
426889	426884	19782L	PARTICIPANT	\N	PRESENT	0
426890	426884	14207L	PARTICIPANT	\N	PRESENT	0
426891	426884	19719D	PARTICIPANT	\N	PRESENT	0
426892	426884	19820Y	PARTICIPANT	\N	PRESENT	0
426893	426884	19725B	PARTICIPANT	\N	PRESENT	0
426894	426884	08069G	PARTICIPANT	\N	PRESENT	0
426895	426884	19723Y	PARTICIPANT	\N	PRESENT	0
426896	426884	08015R	PARTICIPANT	\N	PRESENT	0
426897	426884	14205J	PARTICIPANT	\N	PRESENT	0
426898	426884	19441R	PARTICIPANT	\N	PRESENT	0
426899	426884	14109K	PARTICIPANT	\N	PRESENT	0
426900	426884	19745F	PARTICIPANT	\N	PRESENT	0
426901	426884	19269X	PARTICIPANT	\N	PRESENT	0
426902	426884	11097X	PARTICIPANT	\N	PRESENT	0
430364	416368	98022P	PARTICIPANT	\N	PRESENT	0
430366	416368	14097Y	PARTICIPANT	\N	PRESENT	0
444262	439688	14135M	PARTICIPANT	\N	PRESENT	0
444263	439688	14257W	PARTICIPANT	\N	PRESENT	0
444264	439688	19413M	PARTICIPANT	\N	PRESENT	0
444299	439688	14051J	PARTICIPANT	\N	PRESENT	0
444266	439688	14207L	PARTICIPANT	\N	PRESENT	0
444267	439688	08055A	PARTICIPANT	\N	PRESENT	0
444268	439688	19349W	PARTICIPANT	\N	PRESENT	0
444269	439688	08061X	PARTICIPANT	\N	PRESENT	0
444270	439688	19782L	PARTICIPANT	\N	PRESENT	0
444271	439688	14121F	PARTICIPANT	\N	PRESENT	0
444272	439688	19563B	PARTICIPANT	\N	PRESENT	0
444273	439688	98022P	PARTICIPANT	\N	PRESENT	0
444274	439688	19593H	PARTICIPANT	\N	PRESENT	0
444275	439688	19760E	PARTICIPANT	\N	PRESENT	0
444276	439688	17589D	PARTICIPANT	\N	PRESENT	0
444277	439688	19479G	PARTICIPANT	\N	PRESENT	0
444278	439688	19521Q	PARTICIPANT	\N	PRESENT	0
444279	439688	01024M	PARTICIPANT	\N	PRESENT	0
444280	439688	19737F	PARTICIPANT	\N	PRESENT	0
444281	439688	14089Y	PARTICIPANT	\N	PRESENT	0
444282	439688	19679N	PARTICIPANT	\N	PRESENT	0
444283	439688	01025N	PARTICIPANT	\N	PRESENT	0
444284	439688	19745F	PARTICIPANT	\N	PRESENT	0
444285	439688	15447F	PARTICIPANT	\N	PRESENT	0
444286	439688	19367Y	PARTICIPANT	\N	PRESENT	0
444287	439688	14215L	PARTICIPANT	\N	PRESENT	0
444288	439688	14223L	PARTICIPANT	\N	PRESENT	0
444289	439688	14205J	PARTICIPANT	\N	PRESENT	0
444290	439688	01057W	PARTICIPANT	\N	PRESENT	0
444291	439688	19747H	PARTICIPANT	\N	PRESENT	0
444292	439688	14119M	PARTICIPANT	\N	PRESENT	0
444293	439688	08056B	PARTICIPANT	\N	PRESENT	0
444294	439688	19703U	PARTICIPANT	\N	PRESENT	0
444295	439688	19549D	PARTICIPANT	\N	PRESENT	0
444296	439688	19794Q	PARTICIPANT	\N	PRESENT	0
444297	439688	19447X	PARTICIPANT	\N	PRESENT	0
444298	439688	14038Y	PARTICIPANT	\N	PRESENT	0
444300	439688	19798U	PARTICIPANT	\N	PRESENT	0
444301	439688	19533U	PARTICIPANT	\N	PRESENT	0
444302	439688	14115H	PARTICIPANT	\N	PRESENT	0
444303	439688	14187A	PARTICIPANT	\N	PRESENT	0
444304	439688	19711U	PARTICIPANT	\N	PRESENT	0
444305	439688	19729F	PARTICIPANT	\N	PRESENT	0
444306	439688	19657G	PARTICIPANT	\N	PRESENT	0
444307	439688	14147R	PARTICIPANT	\N	PRESENT	0
444308	439688	04088S	PARTICIPANT	\N	PRESENT	0
444309	439688	14105F	PARTICIPANT	\N	PRESENT	0
444310	439688	19507S	PARTICIPANT	\N	PRESENT	0
444311	439688	11101A	PARTICIPANT	\N	PRESENT	0
444312	439688	19467C	PARTICIPANT	\N	PRESENT	0
444313	439688	11103C	PARTICIPANT	\N	PRESENT	0
444314	439688	08010L	PARTICIPANT	\N	PRESENT	0
444315	439688	08015R	PARTICIPANT	\N	PRESENT	0
444316	439688	14201E	PARTICIPANT	\N	PRESENT	0
444317	439688	19269X	PARTICIPANT	\N	PRESENT	0
444318	439688	19333N	PARTICIPANT	\N	PRESENT	0
444319	439688	19319Q	PARTICIPANT	\N	PRESENT	0
444320	439688	19723Y	PARTICIPANT	\N	PRESENT	0
444260	439688	11070L	PARTICIPANT	\N	PRESENT	0
444261	439688	11090Q	PARTICIPANT	\N	PRESENT	0
444321	439688	19762G	PARTICIPANT	\N	PRESENT	0
444322	439688	19691J	PARTICIPANT	\N	PRESENT	0
444323	439688	88008L	PARTICIPANT	\N	PRESENT	0
444340	439688	14083S	PARTICIPANT	\N	PRESENT	0
444341	439688	14107H	PARTICIPANT	\N	PRESENT	0
444342	439688	19739H	PARTICIPANT	\N	PRESENT	0
444343	439688	14042U	PARTICIPANT	\N	PRESENT	0
444344	439688	11048N	PARTICIPANT	\N	PRESENT	0
444345	439688	19347U	PARTICIPANT	\N	PRESENT	0
444346	439688	08028W	PARTICIPANT	\N	PRESENT	0
444347	439688	11099A	PARTICIPANT	\N	PRESENT	0
444348	439688	19441R	PARTICIPANT	\N	PRESENT	0
444349	439688	19383Y	PARTICIPANT	\N	PRESENT	0
444350	439688	19713W	PARTICIPANT	\N	PRESENT	0
444351	439688	11067R	PARTICIPANT	\N	PRESENT	0
444352	439688	14033T	PARTICIPANT	\N	PRESENT	0
444353	439688	14133K	PARTICIPANT	\N	PRESENT	0
444354	439688	18083K	PARTICIPANT	\N	PRESENT	0
444355	439688	14255U	PARTICIPANT	\N	PRESENT	0
444356	439688	89017R	PARTICIPANT	\N	PRESENT	0
444357	439688	19253P	PARTICIPANT	\N	PRESENT	0
444358	439688	19399H	PARTICIPANT	\N	PRESENT	0
444365	439688	08053X	PARTICIPANT	\N	PRESENT	0
444366	439688	19531S	PARTICIPANT	\N	PRESENT	0
444367	439688	95030B	PARTICIPANT	\N	PRESENT	0
444647	443676	19651A	PARTICIPANT	\N	PRESENT	0
444648	443676	19687N	PARTICIPANT	\N	PRESENT	0
444649	443676	12016W	PARTICIPANT	\N	PRESENT	0
444650	443676	08011M	PARTICIPANT	\N	PRESENT	0
444651	443676	04086Q	PARTICIPANT	\N	PRESENT	0
444652	443676	11040E	PARTICIPANT	\N	PRESENT	0
444653	443676	14083S	PARTICIPANT	\N	PRESENT	0
444654	443676	11012A	PARTICIPANT	\N	PRESENT	0
444655	443676	19741B	PARTICIPANT	\N	PRESENT	0
444656	443676	99004R	PARTICIPANT	\N	PRESENT	0
444657	443807	14123H	PARTICIPANT	\N	PRESENT	0
444658	443807	14251Q	PARTICIPANT	\N	PRESENT	0
444659	443805	19543W	PARTICIPANT	\N	PRESENT	0
444660	443805	19489J	PARTICIPANT	\N	PRESENT	0
444661	443805	08018U	PARTICIPANT	\N	PRESENT	0
444662	443681	19383Y	PARTICIPANT	\N	PRESENT	0
444663	443681	08038Y	PARTICIPANT	\N	PRESENT	0
444664	443667	95041E	PARTICIPANT	\N	PRESENT	0
444665	443667	08034U	PARTICIPANT	\N	PRESENT	0
444666	443667	19687N	PARTICIPANT	\N	PRESENT	0
444667	443807	07033P	PARTICIPANT	\N	PRESENT	0
444668	443806	01060R	PARTICIPANT	\N	PRESENT	0
444669	443806	19543W	PARTICIPANT	\N	PRESENT	0
444670	443806	04047H	PARTICIPANT	\N	PRESENT	0
444671	443806	19673G	PARTICIPANT	\N	PRESENT	0
444672	443806	19675J	PARTICIPANT	\N	PRESENT	0
444673	443806	01028R	PARTICIPANT	\N	PRESENT	0
444674	443806	05008E	PRESIDENT	0	PRESENT	0
444675	443806	19447X	PARTICIPANT	\N	PRESENT	0
444676	443806	14231L	PARTICIPANT	\N	PRESENT	0
444677	443806	19489J	PARTICIPANT	\N	PRESENT	0
444678	443806	14275Y	PARTICIPANT	\N	PRESENT	0
444679	443806	14147R	PARTICIPANT	\N	PRESENT	0
444680	443806	14179A	PARTICIPANT	\N	PRESENT	0
444681	443806	14151M	PARTICIPANT	\N	PRESENT	0
444682	443806	08018U	PARTICIPANT	\N	PRESENT	0
444683	443806	14259Y	PARTICIPANT	\N	PRESENT	0
444684	443806	11072N	PARTICIPANT	\N	PRESENT	0
444685	443806	14053L	PARTICIPANT	\N	PRESENT	0
444686	443806	98035U	PARTICIPANT	\N	PRESENT	0
444687	443806	14065Q	PARTICIPANT	\N	PRESENT	0
444688	443806	19649G	PARTICIPANT	\N	PRESENT	0
444689	443806	14111D	PARTICIPANT	\N	PRESENT	0
444690	443806	10015M	PARTICIPANT	\N	PRESENT	0
444691	443806	11026G	PARTICIPANT	\N	PRESENT	0
444692	443806	19253P	PARTICIPANT	\N	PRESENT	0
444693	443806	01024M	PARTICIPANT	\N	PRESENT	0
444694	443806	04038G	PARTICIPANT	\N	PRESENT	0
444695	443806	14089Y	PARTICIPANT	\N	PRESENT	0
444696	443806	19725B	PARTICIPANT	\N	PRESENT	0
444697	443806	19729F	PARTICIPANT	\N	PRESENT	0
444698	443806	19629C	PARTICIPANT	\N	PRESENT	0
444699	443806	14069U	PARTICIPANT	\N	PRESENT	0
444700	443806	11085T	PARTICIPANT	\N	PRESENT	0
444701	443806	11049P	PARTICIPANT	\N	PRESENT	0
444702	443806	04008A	PARTICIPANT	\N	PRESENT	0
444703	443806	19762G	PARTICIPANT	\N	PRESENT	0
444704	443806	14021P	PARTICIPANT	\N	PRESENT	0
444705	443806	04044E	PARTICIPANT	\N	EXCUSE	0
444706	443806	19585H	PARTICIPANT	\N	EXCUSE	0
444708	443681	14257W	PARTICIPANT	\N	PRESENT	0
444739	443805	04008A	PARTICIPANT	\N	PRESENT	0
432624	425429	08045X	PARTICIPANT	\N	PRESENT	0
432625	423004	08045X	PARTICIPANT	\N	PRESENT	0
432679	432678	99004R	PRESIDENT	0	PRESENT	0
433181	423006	11065P	PARTICIPANT	\N	EXCUSE	0
433182	423006	19399H	PARTICIPANT	\N	PRESENT	0
433636	423006	02002K	PARTICIPANT	\N	EXCUSE	0
437410	425664	14034U	PARTICIPANT	\N	PRESENT	0
438745	426316	14179A	PARTICIPANT	\N	PRESENT	0
438746	426316	14329V	PARTICIPANT	\N	PRESENT	0
438747	426316	14157T	PARTICIPANT	\N	PRESENT	0
438748	426316	14331P	PARTICIPANT	\N	PRESENT	0
438749	426316	14191V	PARTICIPANT	\N	PRESENT	0
438750	426316	19347U	PARTICIPANT	\N	PRESENT	0
438751	426316	11066Q	PARTICIPANT	\N	PRESENT	0
438752	426316	01060R	PARTICIPANT	\N	PRESENT	0
438753	426316	08018U	PARTICIPANT	\N	PRESENT	0
438754	426316	19619A	PARTICIPANT	\N	PRESENT	0
438755	426316	19673G	PARTICIPANT	\N	PRESENT	0
438756	426316	19725B	PARTICIPANT	\N	PRESENT	0
438757	426316	08015R	PARTICIPANT	\N	PRESENT	0
438758	426316	08017T	PARTICIPANT	\N	PRESENT	0
438759	426316	19671E	PARTICIPANT	\N	PRESENT	0
438760	426316	08034U	PARTICIPANT	\N	PRESENT	0
438761	426316	14051J	PARTICIPANT	\N	PRESENT	0
438762	426316	19758L	PARTICIPANT	\N	PRESENT	0
438763	426316	14235Q	PARTICIPANT	\N	PRESENT	0
438764	426316	08060W	PARTICIPANT	\N	PRESENT	0
438765	426316	11077T	PARTICIPANT	\N	PRESENT	0
438766	426316	04088S	PARTICIPANT	\N	PRESENT	0
438767	426316	19565D	PARTICIPANT	\N	PRESENT	0
438769	426316	14001X	PARTICIPANT	\N	PRESENT	0
438770	426316	08019V	PARTICIPANT	\N	PRESENT	0
438771	426316	14259Y	PARTICIPANT	\N	PRESENT	0
438772	426316	14087W	PARTICIPANT	\N	PRESENT	0
438773	426316	14257W	PARTICIPANT	\N	PRESENT	0
438774	426316	01024M	PARTICIPANT	\N	PRESENT	0
438775	426316	19689Q	PARTICIPANT	\N	PRESENT	0
438776	426316	19820Y	PARTICIPANT	\N	PRESENT	0
438777	426316	14267Y	PARTICIPANT	\N	PRESENT	0
438778	426316	19319Q	PARTICIPANT	\N	PRESENT	0
438779	426316	19749K	PARTICIPANT	\N	PRESENT	0
438780	426316	19421M	PARTICIPANT	\N	PRESENT	0
438781	426316	08052W	PARTICIPANT	\N	PRESENT	0
438782	426316	08056B	PARTICIPANT	\N	PRESENT	0
438783	426316	14241N	PARTICIPANT	\N	PRESENT	0
438784	426316	19333N	PARTICIPANT	\N	PRESENT	0
438785	426316	01025N	PARTICIPANT	\N	PRESENT	0
438786	426316	14327T	PARTICIPANT	\N	PRESENT	0
438787	426316	14265W	PARTICIPANT	\N	PRESENT	0
438788	426316	19679N	PARTICIPANT	\N	PRESENT	0
438789	426316	19812Y	PARTICIPANT	\N	PRESENT	0
438790	426316	14085U	PARTICIPANT	\N	PRESENT	0
438791	426316	14229S	PARTICIPANT	\N	PRESENT	0
438792	426316	04040A	PARTICIPANT	\N	PRESENT	0
438793	426316	19563B	PARTICIPANT	\N	PRESENT	0
438794	426316	19629C	PARTICIPANT	\N	PRESENT	0
438795	426316	14030Q	PARTICIPANT	\N	PRESENT	0
438796	426316	19503N	PARTICIPANT	\N	PRESENT	0
438797	426316	11040E	PARTICIPANT	\N	PRESENT	0
438798	426316	04085P	PARTICIPANT	\N	PRESENT	0
438799	426316	19826F	PARTICIPANT	\N	PRESENT	0
438800	426316	98029W	PARTICIPANT	\N	PRESENT	0
438801	426316	04045F	PARTICIPANT	\N	PRESENT	0
438802	426316	07029T	PARTICIPANT	\N	PRESENT	0
438803	426316	04069P	PARTICIPANT	\N	PRESENT	0
438804	426316	04034C	PARTICIPANT	\N	PRESENT	0
438805	426316	19717B	PARTICIPANT	\N	PRESENT	0
438806	426316	19637C	PARTICIPANT	\N	PRESENT	0
438807	426316	01034P	PARTICIPANT	\N	PRESENT	0
438808	426316	14255U	PARTICIPANT	\N	PRESENT	0
438809	426316	19782L	PARTICIPANT	\N	PRESENT	0
438810	426316	08073C	PARTICIPANT	\N	PRESENT	0
438811	426316	11056N	PARTICIPANT	\N	PRESENT	0
438812	426316	19683J	PARTICIPANT	\N	PRESENT	0
438813	426316	04089T	PARTICIPANT	\N	PRESENT	0
438814	426316	19611R	PARTICIPANT	\N	PRESENT	0
438815	426316	95037J	PARTICIPANT	\N	PRESENT	0
438816	426316	08058D	PARTICIPANT	\N	PRESENT	0
438817	426316	19369B	PARTICIPANT	\N	PRESENT	0
438818	426316	11104D	PARTICIPANT	\N	PRESENT	0
438819	426316	14021P	PARTICIPANT	\N	PRESENT	0
438820	426316	19289C	PARTICIPANT	\N	PRESENT	0
438821	426316	08043V	PARTICIPANT	\N	PRESENT	0
438822	426316	19691J	PARTICIPANT	\N	PRESENT	0
438823	426316	14231L	PARTICIPANT	\N	PRESENT	0
438824	426316	04038G	PARTICIPANT	\N	PRESENT	0
438825	426316	19760E	PARTICIPANT	\N	PRESENT	0
438826	426316	19687N	PARTICIPANT	\N	PRESENT	0
438827	426316	19695N	PARTICIPANT	\N	PRESENT	0
438828	426316	14211G	PARTICIPANT	\N	PRESENT	0
438829	426316	08061X	PARTICIPANT	\N	PRESENT	0
438830	426316	19711U	PARTICIPANT	\N	PRESENT	0
438831	426316	04008A	PARTICIPANT	\N	PRESENT	0
438832	426316	19697Q	PARTICIPANT	\N	PRESENT	0
438833	426316	19329S	PARTICIPANT	\N	PRESENT	0
438834	426316	19301E	PARTICIPANT	\N	PRESENT	0
438835	426316	08011M	PARTICIPANT	\N	PRESENT	0
438836	426316	08024S	PARTICIPANT	\N	PRESENT	0
438837	426316	19269X	PARTICIPANT	\N	PRESENT	0
438838	426316	01058X	PARTICIPANT	\N	PRESENT	0
438839	426316	11012A	PARTICIPANT	\N	PRESENT	0
438840	426316	14034U	PARTICIPANT	\N	PRESENT	0
438841	426316	08031R	PARTICIPANT	\N	PRESENT	0
438842	426316	08049C	PARTICIPANT	\N	PRESENT	0
438843	426316	99004R	PARTICIPANT	\N	PRESENT	0
438844	426316	19253P	PARTICIPANT	\N	PRESENT	0
438845	426316	11099A	PARTICIPANT	\N	PRESENT	0
438846	426316	19553Y	PARTICIPANT	\N	PRESENT	0
438847	426316	14121F	PARTICIPANT	\N	PRESENT	0
438848	426316	14207L	PARTICIPANT	\N	PRESENT	0
438849	426316	19545Y	PARTICIPANT	\N	PRESENT	0
438850	426316	17589D	PARTICIPANT	\N	PRESENT	0
438851	426316	19741B	PARTICIPANT	\N	PRESENT	0
438852	426316	14251Q	PARTICIPANT	\N	PRESENT	0
438853	426316	04057K	PARTICIPANT	\N	PRESENT	0
438854	426316	14111D	PARTICIPANT	\N	PRESENT	0
438855	426316	14239U	PARTICIPANT	\N	PRESENT	0
438856	426316	19657G	PARTICIPANT	\N	PRESENT	0
438857	426316	11064N	PARTICIPANT	\N	PRESENT	0
438858	426316	19768N	PARTICIPANT	\N	PRESENT	0
438859	426316	19705W	PARTICIPANT	\N	PRESENT	0
438860	426316	11074Q	PARTICIPANT	\N	PRESENT	0
438861	426316	98050T	PARTICIPANT	\N	PRESENT	0
438862	426316	04059M	PARTICIPANT	\N	PRESENT	0
438863	426316	19447X	PARTICIPANT	\N	PRESENT	0
438864	426316	14159V	PARTICIPANT	\N	PRESENT	0
438865	426316	01028R	PARTICIPANT	\N	PRESENT	0
438866	426316	14061L	PARTICIPANT	\N	PRESENT	0
438867	426316	19669L	PARTICIPANT	\N	PRESENT	0
438868	426316	19651A	PARTICIPANT	\N	PRESENT	0
438869	426316	19723Y	PARTICIPANT	\N	PRESENT	0
438870	426316	11083R	PARTICIPANT	\N	PRESENT	0
438871	426316	19415P	PARTICIPANT	\N	PRESENT	0
438872	426316	14033T	PARTICIPANT	\N	PRESENT	0
438873	426316	19599P	PARTICIPANT	\N	PRESENT	0
438874	426316	19715Y	PARTICIPANT	\N	PRESENT	0
438875	426316	19399H	PARTICIPANT	\N	PRESENT	0
438876	426316	19647E	PARTICIPANT	\N	PRESENT	0
438877	426316	19649G	PARTICIPANT	\N	PRESENT	0
438878	426316	19693L	PARTICIPANT	\N	PRESENT	0
438879	426316	95063L	PARTICIPANT	\N	PRESENT	0
438880	426316	19675J	PARTICIPANT	\N	PRESENT	0
438881	426316	08012N	PARTICIPANT	\N	PRESENT	0
438882	426316	19727D	PARTICIPANT	\N	PRESENT	0
438883	426316	14357A	PARTICIPANT	\N	PRESENT	0
438884	426316	19573D	PARTICIPANT	\N	PRESENT	0
438885	426316	19549D	PARTICIPANT	\N	PRESENT	0
438886	426316	14133K	PARTICIPANT	\N	PRESENT	0
438887	426316	08047A	PARTICIPANT	\N	PRESENT	0
438888	426316	14105F	PARTICIPANT	\N	PRESENT	0
438889	426316	19489J	PARTICIPANT	\N	PRESENT	0
438890	426316	17583W	PARTICIPANT	\N	PRESENT	0
438891	426316	19251M	PARTICIPANT	\N	PRESENT	0
438892	426316	19413M	PARTICIPANT	\N	PRESENT	0
438893	426316	19531S	PARTICIPANT	\N	PRESENT	0
438894	426316	97011G	PARTICIPANT	\N	PRESENT	0
438895	426316	14119M	PARTICIPANT	\N	PRESENT	0
438896	426316	11033F	PARTICIPANT	\N	PRESENT	0
438897	426316	19701S	PARTICIPANT	\N	PRESENT	0
438898	426316	19527W	PARTICIPANT	\N	PRESENT	0
438899	426316	14079W	PARTICIPANT	\N	PRESENT	0
438900	426316	14227Q	PARTICIPANT	\N	PRESENT	0
438901	426316	14093U	PARTICIPANT	\N	PRESENT	0
438902	426316	19581D	PARTICIPANT	\N	PRESENT	0
438903	426316	19591F	PARTICIPANT	\N	PRESENT	0
438904	426316	19667J	PARTICIPANT	\N	PRESENT	0
438905	426316	14042U	PARTICIPANT	\N	PRESENT	0
438906	426316	11115U	PARTICIPANT	\N	PRESENT	0
438907	426316	08009T	PARTICIPANT	\N	PRESENT	0
423931	422452	14355X	PARTICIPANT	\N	PRESENT	0
423932	422452	14227Q	PARTICIPANT	\N	PRESENT	0
423933	422452	11031D	PARTICIPANT	\N	PRESENT	0
423934	422452	19679N	PARTICIPANT	\N	PRESENT	0
423935	422452	19527W	PARTICIPANT	\N	PRESENT	0
423936	422452	11045K	PARTICIPANT	\N	PRESENT	0
423937	422452	19663E	PARTICIPANT	\N	PRESENT	0
423959	416301	19695N	PARTICIPANT	\N	PRESENT	0
423960	416301	96004D	PARTICIPANT	\N	PRESENT	0
423961	416301	19687N	PARTICIPANT	\N	PRESENT	0
424604	416302	19649G	PARTICIPANT	\N	PRESENT	0
424605	416302	01028R	PARTICIPANT	\N	PRESENT	0
424606	416302	19715Y	PARTICIPANT	\N	PRESENT	0
424607	416302	80013X	PARTICIPANT	\N	PRESENT	0
424608	416302	08024S	PARTICIPANT	\N	PRESENT	0
424609	416302	11067R	PARTICIPANT	\N	PRESENT	0
424610	416302	14042U	PARTICIPANT	\N	PRESENT	0
424611	416302	14030Q	PARTICIPANT	\N	PRESENT	0
424612	416302	11085T	PARTICIPANT	\N	PRESENT	0
424613	416302	01024M	PARTICIPANT	\N	PRESENT	0
424614	416302	04047H	PARTICIPANT	\N	PRESENT	0
424615	416302	14147R	PARTICIPANT	\N	PRESENT	0
424616	416302	11033F	PARTICIPANT	\N	PRESENT	0
424617	416302	14251Q	PARTICIPANT	\N	PRESENT	0
424618	416302	19731Y	PARTICIPANT	\N	PRESENT	0
424619	416302	19253P	PARTICIPANT	\N	PRESENT	0
424620	416302	19629C	PARTICIPANT	\N	PRESENT	0
424621	416302	08031R	PARTICIPANT	\N	PRESENT	0
424622	416302	14215L	PARTICIPANT	\N	PRESENT	0
424623	416302	19621T	PARTICIPANT	\N	PRESENT	0
424624	416302	19415P	PARTICIPANT	\N	PRESENT	0
424625	416302	19383Y	PARTICIPANT	\N	PRESENT	0
424626	416302	14033T	PARTICIPANT	\N	PRESENT	0
424627	416302	19701S	PARTICIPANT	\N	PRESENT	0
424628	416302	19675J	PARTICIPANT	\N	PRESENT	0
424629	416302	04088S	PARTICIPANT	\N	PRESENT	0
424630	416302	19693L	PARTICIPANT	\N	PRESENT	0
424631	416302	19533U	PARTICIPANT	\N	PRESENT	0
424632	416302	14235Q	PARTICIPANT	\N	PRESENT	0
424633	416302	11045K	PARTICIPANT	\N	PRESENT	0
424634	416302	08043V	PARTICIPANT	\N	PRESENT	0
424635	416302	19673G	PARTICIPANT	\N	PRESENT	0
424636	416302	95030B	PARTICIPANT	\N	PRESENT	0
424637	416302	86034E	PARTICIPANT	\N	PRESENT	0
424638	416302	08020N	PARTICIPANT	\N	PRESENT	0
424639	416302	14211G	PARTICIPANT	\N	PRESENT	0
424640	416302	14065Q	PARTICIPANT	\N	PRESENT	0
424641	416302	19295A	PARTICIPANT	\N	PRESENT	0
424642	416302	11056N	PARTICIPANT	\N	PRESENT	0
424643	416302	11031D	PARTICIPANT	\N	PRESENT	0
424644	416302	17779H	PARTICIPANT	\N	PRESENT	0
424645	416302	19758L	PARTICIPANT	\N	PRESENT	0
424646	416302	14265W	PARTICIPANT	\N	PRESENT	0
424647	416302	14026U	PARTICIPANT	\N	PRESENT	0
424648	416302	08017T	PARTICIPANT	\N	PRESENT	0
424649	416302	14053L	PARTICIPANT	\N	PRESENT	0
424650	416302	14109K	PARTICIPANT	\N	PRESENT	0
424651	422494	14331P	PARTICIPANT	\N	PRESENT	0
424652	422494	01048V	PARTICIPANT	\N	PRESENT	0
424653	422494	19545Y	PARTICIPANT	\N	PRESENT	0
424654	422494	19667J	PARTICIPANT	\N	PRESENT	0
424655	422494	08011M	PARTICIPANT	\N	PRESENT	0
424656	422494	08014Q	PARTICIPANT	\N	PRESENT	0
424657	422494	14159V	PARTICIPANT	\N	PRESENT	0
424658	422494	08010L	PARTICIPANT	\N	PRESENT	0
424664	422453	19727D	PARTICIPANT	\N	PRESENT	0
424665	422453	19703U	PARTICIPANT	\N	PRESENT	0
424666	422453	04092N	PARTICIPANT	\N	PRESENT	0
424667	422453	08052W	PARTICIPANT	\N	PRESENT	0
424668	422453	14213J	PARTICIPANT	\N	PRESENT	0
424669	422453	04045F	PARTICIPANT	\N	PRESENT	0
424670	422453	10006L	PARTICIPANT	\N	PRESENT	0
424671	422453	19760E	PARTICIPANT	\N	PRESENT	0
424672	422453	19565D	PARTICIPANT	\N	EXCUSE	0
424673	422453	08041T	PARTICIPANT	\N	EXCUSE	0
424674	416302	14179A	PARTICIPANT	\N	PRESENT	0
424675	416302	04069P	PARTICIPANT	\N	PRESENT	0
424676	416302	97011G	PARTICIPANT	\N	PRESENT	0
424677	416302	19691J	PARTICIPANT	\N	PRESENT	0
424678	422494	11074Q	PARTICIPANT	\N	EXCUSE	0
424680	416302	14097Y	PARTICIPANT	\N	PRESENT	0
424686	420765	19333N	PARTICIPANT	\N	PRESENT	0
424687	420765	19701S	PARTICIPANT	\N	PRESENT	0
424688	420765	19794Q	PARTICIPANT	\N	PRESENT	0
424689	420765	19387D	PARTICIPANT	\N	PRESENT	0
424690	420765	11053K	PARTICIPANT	\N	PRESENT	0
424691	420765	19820Y	PARTICIPANT	\N	PRESENT	0
424692	420765	14219Q	PARTICIPANT	\N	PRESENT	0
424693	420765	14221J	PARTICIPANT	\N	PRESENT	0
424694	420765	19826F	PARTICIPANT	\N	PRESENT	0
424695	420765	19637C	PARTICIPANT	\N	PRESENT	0
424696	420765	14237S	PARTICIPANT	\N	PRESENT	0
424697	420765	19551W	PARTICIPANT	\N	PRESENT	0
424698	420765	08060W	PARTICIPANT	\N	PRESENT	0
424699	420765	19347U	PARTICIPANT	\N	PRESENT	0
424700	420765	14157T	PARTICIPANT	\N	PRESENT	0
424701	420765	19681G	PARTICIPANT	\N	PRESENT	0
424702	420765	17637T	PARTICIPANT	\N	PRESENT	0
424703	420765	19525U	PARTICIPANT	\N	PRESENT	0
424704	420765	14038Y	PRESIDENT	0	PRESENT	0
424705	420765	19711U	PARTICIPANT	\N	PRESENT	0
424706	420765	14031R	PARTICIPANT	\N	PRESENT	0
424707	420765	14169X	PARTICIPANT	\N	PRESENT	0
424708	420765	14191V	PARTICIPANT	\N	PRESENT	0
424709	420765	08009T	PARTICIPANT	\N	PRESENT	0
424710	420765	19737F	PARTICIPANT	\N	PRESENT	0
424711	420765	04097T	PARTICIPANT	\N	PRESENT	0
424712	420765	19745F	PARTICIPANT	\N	PRESENT	0
424713	420765	14093U	PARTICIPANT	\N	EXCUSE	0
424714	420765	14051J	PARTICIPANT	\N	EXCUSE	0
424716	416302	19760E	PARTICIPANT	\N	PRESENT	0
424717	416302	19727D	PARTICIPANT	\N	PRESENT	0
424718	416302	19399H	PARTICIPANT	\N	PRESENT	0
424719	416302	07029T	PARTICIPANT	\N	PRESENT	0
424724	416302	14069U	PARTICIPANT	\N	PRESENT	0
424725	416302	11064N	PARTICIPANT	\N	PRESENT	0
424726	416302	14089Y	PARTICIPANT	\N	PRESENT	0
424727	416302	19826F	PARTICIPANT	\N	PRESENT	0
424731	416302	19507S	PARTICIPANT	\N	PRESENT	0
424732	416302	19703U	PARTICIPANT	\N	PRESENT	0
424733	416302	14157T	PARTICIPANT	\N	PRESENT	0
424734	416302	19762G	PARTICIPANT	\N	PRESENT	0
424735	416302	19413M	PARTICIPANT	\N	PRESENT	0
424736	416302	14281W	PARTICIPANT	\N	PRESENT	0
424737	416302	14031R	PARTICIPANT	\N	PRESENT	0
424738	416302	14249W	PARTICIPANT	\N	PRESENT	0
424739	416302	19367Y	PARTICIPANT	\N	PRESENT	0
424745	416302	19737F	PARTICIPANT	\N	PRESENT	0
424743	416302	19443T	PARTICIPANT	\N	PRESENT	0
424744	416302	14083S	PARTICIPANT	\N	PRESENT	0
424746	416302	11012A	PARTICIPANT	\N	PRESENT	0
424747	416302	08010L	PARTICIPANT	\N	PRESENT	0
424748	416302	19521Q	PARTICIPANT	\N	PRESENT	0
424749	416302	14073Q	PARTICIPANT	\N	PRESENT	0
424750	416302	14217N	PARTICIPANT	\N	PRESENT	0
424751	416302	14021P	PARTICIPANT	\N	PRESENT	0
424752	416302	19543W	PARTICIPANT	\N	PRESENT	0
424753	416302	01057W	PARTICIPANT	\N	PRESENT	0
424814	416303	14034U	PARTICIPANT	\N	PRESENT	0
424815	416303	11031D	PARTICIPANT	\N	PRESENT	0
424816	416303	14235Q	PARTICIPANT	\N	PRESENT	0
424817	416303	14065Q	PARTICIPANT	\N	PRESENT	0
424818	416303	19295A	PARTICIPANT	\N	PRESENT	0
424819	416303	11067R	PARTICIPANT	\N	PRESENT	0
424820	416303	11045K	PARTICIPANT	\N	PRESENT	0
424821	416303	19649G	PARTICIPANT	\N	PRESENT	0
424822	416303	08017T	PARTICIPANT	\N	PRESENT	0
424823	416303	08043V	PARTICIPANT	\N	PRESENT	0
424824	416303	04047H	PARTICIPANT	\N	PRESENT	0
424825	416303	14147R	PARTICIPANT	\N	PRESENT	0
424826	416303	08024S	PARTICIPANT	\N	PRESENT	0
424827	416303	14021P	PARTICIPANT	\N	PRESENT	0
424828	416303	04045F	PARTICIPANT	\N	PRESENT	0
424829	416303	19758L	PARTICIPANT	\N	PRESENT	0
424830	416303	19503N	PARTICIPANT	\N	PRESENT	0
424831	416303	14030Q	PARTICIPANT	\N	PRESENT	0
424832	416303	19253P	PARTICIPANT	\N	PRESENT	0
424833	416303	19629C	PARTICIPANT	\N	PRESENT	0
424834	416303	14215L	PARTICIPANT	\N	PRESENT	0
424835	416303	04069P	PARTICIPANT	\N	PRESENT	0
424836	416303	19723Y	PARTICIPANT	\N	PRESENT	0
424837	416303	14033T	PARTICIPANT	\N	PRESENT	0
424838	416303	01058X	PARTICIPANT	\N	PRESENT	0
424839	416303	19715Y	PARTICIPANT	\N	PRESENT	0
424840	416303	07029T	PARTICIPANT	\N	PRESENT	0
424841	416303	19693L	PARTICIPANT	\N	PRESENT	0
424842	416303	14053L	PARTICIPANT	\N	PRESENT	0
424843	416303	10006L	PARTICIPANT	\N	PRESENT	0
424844	416303	08031R	PARTICIPANT	\N	PRESENT	0
430179	416369	04044E	PARTICIPANT	\N	PRESENT	0
430181	416369	19447X	PARTICIPANT	\N	PRESENT	0
430182	416369	19687N	PARTICIPANT	\N	PRESENT	0
430183	416369	14235Q	PARTICIPANT	\N	PRESENT	0
430184	416369	11056N	PARTICIPANT	\N	PRESENT	0
430185	416369	04085P	PARTICIPANT	\N	PRESENT	0
430186	416369	14065Q	PARTICIPANT	\N	PRESENT	0
430187	416369	11045K	PARTICIPANT	\N	PRESENT	0
430188	416369	08017T	PARTICIPANT	\N	PRESENT	0
430189	416369	19782L	PARTICIPANT	\N	PRESENT	0
430190	416369	04034C	PARTICIPANT	\N	PRESENT	0
430191	416369	88008L	PARTICIPANT	\N	PRESENT	0
430192	416369	19253P	PARTICIPANT	\N	PRESENT	0
430193	416369	04057K	PARTICIPANT	\N	PRESENT	0
430194	416369	19812Y	PARTICIPANT	\N	PRESENT	0
430195	416369	14089Y	PARTICIPANT	\N	PRESENT	0
430196	416369	19507S	PARTICIPANT	\N	PRESENT	0
430197	416369	19794Q	PARTICIPANT	\N	PRESENT	0
430198	416369	19673G	PARTICIPANT	\N	PRESENT	0
430199	416369	14147R	PARTICIPANT	\N	PRESENT	0
430200	416369	95030B	PARTICIPANT	\N	PRESENT	0
430201	416369	11043H	PARTICIPANT	\N	PRESENT	0
430202	416369	14215L	PARTICIPANT	\N	PRESENT	0
430203	416369	19747H	PARTICIPANT	\N	PRESENT	0
430204	416369	04035D	PARTICIPANT	\N	PRESENT	0
430205	416369	19820Y	PARTICIPANT	\N	PRESENT	0
430206	416369	19591F	PARTICIPANT	\N	PRESENT	0
430207	428242	14327T	PARTICIPANT	\N	PRESENT	0
430208	428242	19479G	PARTICIPANT	\N	PRESENT	0
430209	428242	19711U	PARTICIPANT	\N	PRESENT	0
430210	428242	19531S	PARTICIPANT	\N	PRESENT	0
430211	428242	08034U	PARTICIPANT	\N	PRESENT	0
430212	428242	14187A	PARTICIPANT	\N	PRESENT	0
430213	428242	01057W	PARTICIPANT	\N	PRESENT	0
430214	428242	11053K	PARTICIPANT	\N	PRESENT	0
430215	428242	12016W	PARTICIPANT	\N	PRESENT	0
430216	428242	08011M	PARTICIPANT	\N	PRESENT	0
430217	428242	11074Q	PRESIDENT	0	PRESENT	0
430218	428242	19667J	PARTICIPANT	\N	PRESENT	0
430219	428242	08014Q	PARTICIPANT	\N	PRESENT	0
430220	428242	88008L	PARTICIPANT	\N	PRESENT	0
430221	428242	14169X	PARTICIPANT	\N	PRESENT	0
430222	428242	11040E	PARTICIPANT	\N	PRESENT	0
430223	428242	04086Q	PARTICIPANT	\N	PRESENT	0
430224	428242	07029T	PARTICIPANT	\N	PRESENT	0
430225	428242	14085U	PARTICIPANT	\N	PRESENT	0
430226	428242	96004D	PARTICIPANT	\N	PRESENT	0
430227	428242	19349W	PARTICIPANT	\N	PRESENT	0
430228	428242	14253S	PARTICIPANT	\N	PRESENT	0
430229	428242	99004R	PARTICIPANT	\N	PRESENT	0
430230	428242	07004J	PARTICIPANT	\N	EXCUSE	0
430231	416369	19693L	PARTICIPANT	\N	PRESENT	0
430233	416369	01025N	PARTICIPANT	\N	PRESENT	0
430234	416369	19599P	PARTICIPANT	\N	PRESENT	0
430235	430180	19697Q	PARTICIPANT	\N	PRESENT	0
430236	430180	11067R	PARTICIPANT	\N	PRESENT	0
430237	430180	04092N	PRESIDENT	0	PRESENT	0
430238	430180	19798U	PARTICIPANT	\N	PRESENT	0
430239	430180	11097X	PRESIDENT	1	PRESENT	0
430240	430180	08052W	PARTICIPANT	\N	PRESENT	0
430241	430180	19415P	PARTICIPANT	\N	PRESENT	0
430242	430180	19715Y	PARTICIPANT	\N	PRESENT	0
430243	430180	04045F	PARTICIPANT	\N	PRESENT	0
430244	430180	14223L	PARTICIPANT	\N	PRESENT	0
430245	430180	19723Y	PARTICIPANT	\N	PRESENT	0
430246	430180	17779H	PARTICIPANT	\N	PRESENT	0
430247	430180	19727D	PARTICIPANT	\N	PRESENT	0
430248	430180	14119M	PARTICIPANT	\N	PRESENT	0
430249	430180	14087W	PARTICIPANT	\N	PRESENT	0
430250	430180	14281W	PARTICIPANT	\N	PRESENT	0
430251	430180	19679N	PARTICIPANT	\N	PRESENT	0
430252	430180	14042U	PARTICIPANT	\N	PRESENT	0
430253	430180	14213J	PARTICIPANT	\N	PRESENT	0
430254	430180	14071N	PARTICIPANT	\N	PRESENT	0
430255	430180	14261S	PARTICIPANT	\N	PRESENT	0
430256	430180	14217N	PARTICIPANT	\N	PRESENT	0
430257	430180	19760E	PARTICIPANT	\N	PRESENT	0
430258	430180	19521Q	PARTICIPANT	\N	PRESENT	0
430259	416369	08056B	PARTICIPANT	\N	PRESENT	0
430260	416369	19527W	PARTICIPANT	\N	PRESENT	0
430261	416369	05008E	PARTICIPANT	\N	PRESENT	0
430262	416369	14069U	PARTICIPANT	\N	PRESENT	0
430263	416369	14135M	PARTICIPANT	\N	PRESENT	0
430264	428242	14081Q	PARTICIPANT	\N	PRESENT	0
430265	428242	14225N	PARTICIPANT	\N	PRESENT	0
430266	428242	08010L	PARTICIPANT	\N	PRESENT	0
430267	428242	19689Q	PARTICIPANT	\N	PRESENT	0
430268	428242	11012A	PARTICIPANT	\N	PRESENT	0
430269	428242	14121F	PARTICIPANT	\N	PRESENT	0
430270	428242	14119M	PARTICIPANT	\N	PRESENT	0
430271	416369	01028R	PARTICIPANT	\N	PRESENT	0
430272	416369	04088S	PARTICIPANT	\N	PRESENT	0
430273	416369	19649G	PARTICIPANT	\N	PRESENT	0
430274	416369	14097Y	PARTICIPANT	\N	PRESENT	0
430275	416369	19762G	PARTICIPANT	\N	PRESENT	0
430276	416369	14223L	PARTICIPANT	\N	PRESENT	0
430277	416369	19629C	PARTICIPANT	\N	PRESENT	0
430278	416369	19399H	PARTICIPANT	\N	PRESENT	0
430279	428235	14053L	PARTICIPANT	\N	PRESENT	0
430280	428235	04070G	PARTICIPANT	\N	PRESENT	0
430281	428235	11048N	PARTICIPANT	\N	PRESENT	0
430282	428235	19413M	PARTICIPANT	\N	PRESENT	0
430283	428235	19251M	PARTICIPANT	\N	PRESENT	0
430284	428235	19826F	PARTICIPANT	\N	PRESENT	0
430285	428235	19581D	PARTICIPANT	\N	PRESENT	0
430286	428235	14033T	PARTICIPANT	\N	PRESENT	0
430287	428235	14026U	PARTICIPANT	\N	PRESENT	0
430288	428235	08060W	PARTICIPANT	\N	PRESENT	0
430289	428235	08009T	PRESIDENT	0	PRESENT	0
430290	428235	19367Y	PARTICIPANT	\N	PRESENT	0
430291	428235	08024S	PARTICIPANT	\N	PRESENT	0
430292	428235	19758L	PARTICIPANT	\N	PRESENT	0
430293	428235	14051J	PARTICIPANT	\N	EXCUSE	0
430294	416369	14265W	PARTICIPANT	\N	PRESENT	0
430295	416369	04018C	PARTICIPANT	\N	PRESENT	0
430296	416369	19441R	PARTICIPANT	\N	PRESENT	0
430297	416369	14079W	PARTICIPANT	\N	PRESENT	0
430298	416369	14157T	PARTICIPANT	\N	PRESENT	0
430302	416369	11115U	PARTICIPANT	\N	PRESENT	0
430305	416369	14033T	PARTICIPANT	\N	PRESENT	0
430306	416369	14219Q	PARTICIPANT	\N	PRESENT	0
430311	416369	19543W	PARTICIPANT	\N	PRESENT	0
430312	416369	17583W	PARTICIPANT	\N	PRESENT	0
430313	416369	19533U	PARTICIPANT	\N	PRESENT	0
430314	416369	14249W	PARTICIPANT	\N	PRESENT	0
430315	416369	19553Y	PARTICIPANT	\N	PRESENT	0
430317	416369	08020N	PARTICIPANT	\N	PRESENT	0
430318	416369	04045F	PARTICIPANT	\N	PRESENT	0
430319	416369	99004R	PARTICIPANT	\N	PRESENT	0
430320	416369	14061L	PARTICIPANT	\N	PRESENT	0
430321	416369	14191V	PARTICIPANT	\N	PRESENT	0
430322	416369	11110B	PARTICIPANT	\N	PRESENT	0
430323	428240	19515S	PARTICIPANT	\N	PRESENT	0
430324	428240	19782L	PARTICIPANT	\N	PRESENT	0
430325	428240	14357A	PARTICIPANT	\N	PRESENT	0
430326	428240	19812Y	PARTICIPANT	\N	PRESENT	0
430327	428240	19441R	PARTICIPANT	\N	PRESENT	0
430328	428240	80013X	PARTICIPANT	\N	PRESENT	0
430329	428240	19631V	PARTICIPANT	\N	PRESENT	0
430330	428240	11099A	PARTICIPANT	\N	PRESENT	0
430331	428240	08015R	PARTICIPANT	\N	PRESENT	0
430332	428240	14197C	PARTICIPANT	\N	PRESENT	0
430333	428240	19369B	PARTICIPANT	\N	PRESENT	0
430334	428240	08028W	PARTICIPANT	\N	PRESENT	0
430335	428240	14265W	PARTICIPANT	\N	PRESENT	0
430336	428240	14135M	PARTICIPANT	\N	PRESENT	0
430337	428240	14187A	PARTICIPANT	\N	PRESENT	0
430338	428240	08038Y	PARTICIPANT	\N	PRESENT	0
430339	428240	14033T	PARTICIPANT	\N	PRESENT	0
430340	428240	11090Q	PARTICIPANT	\N	PRESENT	0
430341	428240	14205J	PARTICIPANT	\N	PRESENT	0
430342	428240	04088S	PARTICIPANT	\N	PRESENT	0
430343	428240	19507S	PARTICIPANT	\N	PRESENT	0
430344	428240	11101A	PARTICIPANT	\N	PRESENT	0
430345	428240	14207L	PARTICIPANT	\N	PRESENT	0
430346	428240	19747H	PARTICIPANT	\N	PRESENT	0
430347	428240	19619A	PARTICIPANT	\N	PRESENT	0
430348	428240	11081P	PARTICIPANT	\N	EXCUSE	0
430349	416369	11031D	PARTICIPANT	\N	PRESENT	0
430350	416369	19637C	PARTICIPANT	\N	PRESENT	0
430351	428240	19413M	PARTICIPANT	\N	PRESENT	0
430352	428242	14034U	PARTICIPANT	\N	PRESENT	0
430353	428242	14071N	PARTICIPANT	\N	PRESENT	0
430354	416369	14038Y	PARTICIPANT	\N	PRESENT	0
430356	416369	10015M	PARTICIPANT	\N	PRESENT	0
430357	416369	11012A	PARTICIPANT	\N	PRESENT	0
430367	430180	19565D	PARTICIPANT	\N	PRESENT	0
430368	430180	01034P	PARTICIPANT	\N	PRESENT	0
430369	430180	08041T	PARTICIPANT	\N	EXCUSE	0
428249	428248	11053K	PARTICIPANT	\N	PRESENT	0
428250	428248	14059S	PARTICIPANT	\N	PRESENT	0
428251	428248	19671E	PARTICIPANT	\N	PRESENT	0
428252	428248	19735D	PARTICIPANT	\N	PRESENT	0
428253	428248	11097X	PARTICIPANT	\N	PRESENT	0
428255	428254	14331P	PARTICIPANT	\N	PRESENT	0
428257	428256	89017R	PARTICIPANT	\N	PRESENT	0
428259	428258	89017R	PARTICIPANT	\N	PRESENT	0
428260	428258	14331P	PARTICIPANT	\N	PRESENT	0
428263	428262	89017R	PARTICIPANT	\N	PRESENT	0
428264	428261	14331P	PARTICIPANT	\N	PRESENT	0
428266	428265	04086Q	PARTICIPANT	\N	PRESENT	0
428268	428267	11048N	PARTICIPANT	\N	PRESENT	0
428270	428269	14327T	PARTICIPANT	\N	PRESENT	0
428272	428271	19667J	PARTICIPANT	\N	PRESENT	0
428275	428274	19667J	PARTICIPANT	\N	PRESENT	0
430961	428238	11081P	PARTICIPANT	\N	EXCUSE	0
437430	425613	04059M	PARTICIPANT	\N	PRESENT	0
437431	425613	11040E	PARTICIPANT	\N	PRESENT	0
437432	425613	11074Q	PARTICIPANT	\N	PRESENT	0
437433	425613	14087W	PARTICIPANT	\N	PRESENT	0
437434	425613	19689Q	PARTICIPANT	\N	PRESENT	0
437435	425613	14281W	PARTICIPANT	\N	PRESENT	0
437436	425613	19651A	PARTICIPANT	\N	PRESENT	0
437437	425613	19583F	PARTICIPANT	\N	PRESENT	0
437438	425613	19479G	PARTICIPANT	\N	PRESENT	0
437439	425613	11012A	PARTICIPANT	\N	PRESENT	0
437440	425613	04086Q	PARTICIPANT	\N	PRESENT	0
437441	425613	19697Q	PARTICIPANT	\N	PRESENT	0
437442	425613	11048N	PARTICIPANT	\N	PRESENT	0
437443	425613	08010L	PARTICIPANT	\N	PRESENT	0
437444	425613	19679N	PARTICIPANT	\N	PRESENT	0
437445	425613	19741B	PARTICIPANT	\N	PRESENT	0
437446	425613	08031R	PARTICIPANT	\N	PRESENT	0
437447	425613	14225N	PARTICIPANT	\N	PRESENT	0
437448	425613	14261S	PARTICIPANT	\N	PRESENT	0
437449	425613	19545Y	PARTICIPANT	\N	PRESENT	0
437450	425613	08019V	PARTICIPANT	\N	PRESENT	0
437451	425613	19711U	PARTICIPANT	\N	PRESENT	0
437452	425613	11031D	PARTICIPANT	\N	PRESENT	0
437453	425613	14331P	PARTICIPANT	\N	PRESENT	0
437454	425613	19301E	PARTICIPANT	\N	PRESENT	0
437455	425613	19319Q	PARTICIPANT	\N	PRESENT	0
437456	425613	14327T	PARTICIPANT	\N	PRESENT	0
437457	425613	19693L	PARTICIPANT	\N	PRESENT	0
437458	425613	14069U	PARTICIPANT	\N	PRESENT	0
437459	425613	19673G	PARTICIPANT	\N	PRESENT	0
437460	425613	19643A	PARTICIPANT	\N	PRESENT	0
437461	425613	11026G	PARTICIPANT	\N	PRESENT	0
437466	425613	14205J	PARTICIPANT	\N	PRESENT	0
437467	425613	14227Q	PARTICIPANT	\N	PRESENT	0
437473	425613	99004R	PARTICIPANT	\N	PRESENT	0
437474	425613	19715Y	PARTICIPANT	\N	PRESENT	0
437513	425756	11040E	PARTICIPANT	\N	PRESENT	0
437514	425756	99004R	PARTICIPANT	\N	PRESENT	0
437515	425756	04086Q	PARTICIPANT	\N	PRESENT	0
437516	425756	14069U	PARTICIPANT	\N	PRESENT	0
437517	425756	19693L	PARTICIPANT	\N	PRESENT	0
437518	425756	08011M	PARTICIPANT	\N	PRESENT	0
437519	425756	14331P	PARTICIPANT	\N	PRESENT	0
437520	425756	14261S	PARTICIPANT	\N	PRESENT	0
437521	425756	11026G	PARTICIPANT	\N	PRESENT	0
437522	425756	14227Q	PARTICIPANT	\N	PRESENT	0
437523	425756	14327T	PARTICIPANT	\N	PRESENT	0
437524	425756	19715Y	PARTICIPANT	\N	PRESENT	0
437525	425756	19319Q	PARTICIPANT	\N	PRESENT	0
437526	425756	19651A	PARTICIPANT	\N	PRESENT	0
437527	425756	19583F	PARTICIPANT	\N	PRESENT	0
437528	425756	19711U	PARTICIPANT	\N	PRESENT	0
437529	425756	14034U	PARTICIPANT	\N	PRESENT	0
437530	425756	14205J	PARTICIPANT	\N	PRESENT	0
437531	425756	04034C	PARTICIPANT	\N	PRESENT	0
437532	425756	11012A	PARTICIPANT	\N	PRESENT	0
437533	425756	19741B	PARTICIPANT	\N	PRESENT	0
437534	425756	14225N	PARTICIPANT	\N	PRESENT	0
437535	425756	19301E	PARTICIPANT	\N	PRESENT	0
437536	425756	19545Y	PARTICIPANT	\N	PRESENT	0
437537	425756	11031D	PARTICIPANT	\N	PRESENT	0
437538	425756	08010L	PARTICIPANT	\N	PRESENT	0
437539	425756	11048N	PARTICIPANT	\N	PRESENT	0
437540	425756	19479G	PARTICIPANT	\N	PRESENT	0
437541	425756	08031R	PARTICIPANT	\N	PRESENT	0
437575	425770	19693L	PARTICIPANT	\N	PRESENT	0
437576	425770	08031R	PARTICIPANT	\N	PRESENT	0
437577	425770	11040E	PARTICIPANT	\N	PRESENT	0
437578	425770	19593H	PARTICIPANT	\N	PRESENT	0
437579	425770	14225N	PARTICIPANT	\N	PRESENT	0
437580	425770	99004R	PARTICIPANT	\N	PRESENT	0
437581	425770	19583F	PARTICIPANT	\N	PRESENT	0
437511	425756	04059M	PARTICIPANT	\N	PRESENT	0
437512	425756	11074Q	PARTICIPANT	\N	PRESENT	0
437582	425770	14205J	PARTICIPANT	\N	PRESENT	0
437583	425770	19711U	PARTICIPANT	\N	PRESENT	0
437584	425770	19479G	PARTICIPANT	\N	PRESENT	0
437585	425770	11074Q	PARTICIPANT	\N	PRESENT	0
437586	425770	08011M	PARTICIPANT	\N	PRESENT	0
437587	425770	11048N	PARTICIPANT	\N	PRESENT	0
437588	425770	14331P	PARTICIPANT	\N	PRESENT	0
437589	425770	14034U	PARTICIPANT	\N	PRESENT	0
437590	425770	14327T	PARTICIPANT	\N	PRESENT	0
437591	425770	19651A	PARTICIPANT	\N	PRESENT	0
437592	425770	14069U	PARTICIPANT	\N	PRESENT	0
437593	425770	19667J	PARTICIPANT	\N	PRESENT	0
437595	425770	19545Y	PARTICIPANT	\N	PRESENT	0
437599	425770	19301E	PARTICIPANT	\N	PRESENT	0
437600	425770	19689Q	PARTICIPANT	\N	PRESENT	0
437601	425770	11031D	PARTICIPANT	\N	PRESENT	0
437602	425770	11083R	PARTICIPANT	\N	PRESENT	0
437603	425770	19647E	PARTICIPANT	\N	PRESENT	0
437604	425770	04034C	PARTICIPANT	\N	PRESENT	0
437605	425770	19741B	PARTICIPANT	\N	PRESENT	0
437606	425770	08010L	PARTICIPANT	\N	PRESENT	0
437607	425770	08019V	PARTICIPANT	\N	PRESENT	0
437608	425770	19701S	PARTICIPANT	\N	PRESENT	0
437614	425770	19611R	PARTICIPANT	\N	PRESENT	0
437573	425770	11072N	PARTICIPANT	\N	PRESENT	0
437574	425770	04086Q	PARTICIPANT	\N	PRESENT	0
437615	425770	07004J	PARTICIPANT	\N	PRESENT	0
437616	425770	19657G	PARTICIPANT	\N	PRESENT	0
437617	425770	08034U	PARTICIPANT	\N	PRESENT	0
437618	425770	14169X	PARTICIPANT	\N	PRESENT	0
437619	425770	11109J	PARTICIPANT	\N	PRESENT	0
437620	425770	11110B	PARTICIPANT	\N	PRESENT	0
437622	425770	19295A	PARTICIPANT	\N	PRESENT	0
437623	425770	19319Q	PARTICIPANT	\N	PRESENT	0
437624	425770	19643A	PARTICIPANT	\N	PRESENT	0
437626	425770	14085U	PARTICIPANT	\N	PRESENT	0
437657	425771	11074Q	PARTICIPANT	\N	PRESENT	0
437658	425771	19295A	PARTICIPANT	\N	PRESENT	0
437659	425771	19301E	PARTICIPANT	\N	PRESENT	0
437660	425771	14085U	PARTICIPANT	\N	PRESENT	0
437661	425771	19593H	PARTICIPANT	\N	PRESENT	0
437662	425771	14225N	PARTICIPANT	\N	PRESENT	0
437663	425771	19319Q	PARTICIPANT	\N	PRESENT	0
437664	425771	19667J	PARTICIPANT	\N	PRESENT	0
437665	425771	19693L	PARTICIPANT	\N	PRESENT	0
437666	425771	19657G	PARTICIPANT	\N	PRESENT	0
437667	425771	14327T	PARTICIPANT	\N	PRESENT	0
437668	425771	19711U	PARTICIPANT	\N	PRESENT	0
437669	425771	11048N	PARTICIPANT	\N	PRESENT	0
437670	425771	11090Q	PARTICIPANT	\N	PRESENT	0
437671	425771	08034U	PARTICIPANT	\N	PRESENT	0
437672	425771	99004R	PARTICIPANT	\N	PRESENT	0
437673	425771	08010L	PARTICIPANT	\N	PRESENT	0
437674	425771	04086Q	PARTICIPANT	\N	PRESENT	0
437675	425771	04034C	PARTICIPANT	\N	PRESENT	0
437676	425771	07004J	PARTICIPANT	\N	PRESENT	0
437677	425771	08031R	PARTICIPANT	\N	PRESENT	0
437678	425771	14261S	PARTICIPANT	\N	PRESENT	0
437679	425771	14331P	PARTICIPANT	\N	PRESENT	0
437680	425771	12016W	PARTICIPANT	\N	PRESENT	0
437681	425771	11109J	PARTICIPANT	\N	PRESENT	0
437682	425771	19545Y	PARTICIPANT	\N	PRESENT	0
437683	425771	01034P	PARTICIPANT	\N	PRESENT	0
437684	425771	08019V	PARTICIPANT	\N	PRESENT	0
437655	425771	11070L	PARTICIPANT	\N	PRESENT	0
437656	425771	08011M	PARTICIPANT	\N	PRESENT	0
437685	425771	19647E	PARTICIPANT	\N	PRESENT	0
437686	425771	14069U	PARTICIPANT	\N	PRESENT	0
437687	425771	19741B	PARTICIPANT	\N	PRESENT	0
437688	425771	11053K	PARTICIPANT	\N	PRESENT	0
437689	425771	11110B	PARTICIPANT	\N	PRESENT	0
437690	425771	17637T	PARTICIPANT	\N	PRESENT	0
437691	425771	07029T	PARTICIPANT	\N	PRESENT	0
444741	443676	19545Y	PARTICIPANT	\N	PRESENT	0
444742	443676	19647E	PARTICIPANT	\N	PRESENT	0
444743	443676	08069G	PARTICIPANT	\N	PRESENT	0
444744	443676	14034U	PARTICIPANT	\N	PRESENT	0
438471	438470	04040A	PRESIDENT	0	PRESENT	0
438908	426316	11053K	PARTICIPANT	\N	PRESENT	0
438909	426316	19575F	PARTICIPANT	\N	PRESENT	0
438910	426316	11048N	PARTICIPANT	\N	PRESENT	0
438911	426316	80013X	PARTICIPANT	\N	PRESENT	0
438912	426316	05012A	PARTICIPANT	\N	PRESENT	0
438913	426316	19699S	PARTICIPANT	\N	PRESENT	0
438914	426316	19737F	PARTICIPANT	\N	PRESENT	0
438915	426316	10006L	PARTICIPANT	\N	PRESENT	0
438916	426316	19569H	PARTICIPANT	\N	PRESENT	0
438917	426316	19735D	PARTICIPANT	\N	PRESENT	0
438918	426316	14193X	PARTICIPANT	\N	PRESENT	0
438919	426316	16685X	PARTICIPANT	\N	PRESENT	0
438920	426316	19515S	PARTICIPANT	\N	PRESENT	0
438921	426316	19441R	PARTICIPANT	\N	PRESENT	0
438922	426316	19479G	PARTICIPANT	\N	PRESENT	0
438923	426316	19713W	PARTICIPANT	\N	PRESENT	0
438924	426316	11080N	PARTICIPANT	\N	PRESENT	0
438925	426316	12041X	PARTICIPANT	\N	PRESENT	0
438926	426316	19766L	PARTICIPANT	\N	PRESENT	0
438927	426316	04071H	PARTICIPANT	\N	PRESENT	0
438928	426316	14031R	PARTICIPANT	\N	PRESENT	0
438929	426316	01057W	PARTICIPANT	\N	PRESENT	0
438930	426316	11090Q	PARTICIPANT	\N	PRESENT	0
438931	426316	14069U	PARTICIPANT	\N	PRESENT	0
438932	426316	14215L	PARTICIPANT	\N	PRESENT	0
438933	426316	19643A	PARTICIPANT	\N	PRESENT	0
438934	426316	14169X	PARTICIPANT	\N	PRESENT	0
438935	426316	10015M	PARTICIPANT	\N	PRESENT	0
438936	426316	01048V	PARTICIPANT	\N	PRESENT	0
438937	426316	04033B	PARTICIPANT	\N	PRESENT	0
438938	426316	14187A	PARTICIPANT	\N	PRESENT	0
438939	426316	11097X	PARTICIPANT	\N	PRESENT	0
438940	426316	04097T	PARTICIPANT	\N	PRESENT	0
438941	426316	08039A	PARTICIPANT	\N	PRESENT	0
438942	426316	14219Q	PARTICIPANT	\N	PRESENT	0
438943	426316	08010L	PARTICIPANT	\N	PRESENT	0
438944	426316	04042C	PARTICIPANT	\N	PRESENT	0
438945	426316	05008E	PARTICIPANT	\N	PRESENT	0
438946	426316	04086Q	PARTICIPANT	\N	PRESENT	0
438947	426316	19577H	PARTICIPANT	\N	PRESENT	0
438948	426316	04092N	PARTICIPANT	\N	PRESENT	0
438949	426316	04044E	PARTICIPANT	\N	PRESENT	0
438950	426316	19747H	PARTICIPANT	\N	PRESENT	0
438951	426316	14103D	PARTICIPANT	\N	PRESENT	0
438952	426316	14221J	PARTICIPANT	\N	PRESENT	0
438953	426316	11085T	PARTICIPANT	\N	PRESENT	0
438954	426316	98024R	PARTICIPANT	\N	PRESENT	0
438955	426316	19733B	PARTICIPANT	\N	PRESENT	0
438956	426316	14281W	PARTICIPANT	\N	PRESENT	0
438957	426316	14217N	PARTICIPANT	\N	PRESENT	0
438958	426316	04070G	PARTICIPANT	\N	PRESENT	0
438959	426316	19729F	PARTICIPANT	\N	PRESENT	0
438963	426316	14213J	PARTICIPANT	\N	PRESENT	0
438961	426316	19551W	PARTICIPANT	\N	PRESENT	0
438962	426316	18083K	PARTICIPANT	\N	PRESENT	0
438964	426316	11070L	PARTICIPANT	\N	PRESENT	0
438977	426316	17637T	PARTICIPANT	\N	PRESENT	0
438981	426316	19621T	PARTICIPANT	\N	PRESENT	0
438967	426316	11031D	PARTICIPANT	\N	PRESENT	0
438979	426316	95067Q	PARTICIPANT	\N	PRESENT	0
438970	426316	14026U	PARTICIPANT	\N	PRESENT	0
438974	426316	11109J	PARTICIPANT	\N	PRESENT	0
438978	426316	19367Y	PARTICIPANT	\N	PRESENT	0
438980	426316	14173T	PARTICIPANT	\N	PRESENT	0
438982	426316	89017R	PARTICIPANT	\N	PRESENT	0
439269	426317	04044E	PARTICIPANT	\N	PRESENT	0
439007	426316	19709B	PARTICIPANT	\N	PRESENT	0
439008	426316	14237S	PARTICIPANT	\N	PRESENT	0
439270	426317	01043Q	PARTICIPANT	\N	PRESENT	0
439271	426317	19691J	PARTICIPANT	\N	PRESENT	0
439272	426317	19717B	PARTICIPANT	\N	PRESENT	0
439273	426317	18083K	PARTICIPANT	\N	PRESENT	0
439274	426317	14097Y	PARTICIPANT	\N	PRESENT	0
439276	426317	14121F	PARTICIPANT	\N	PRESENT	0
439277	426317	19737F	PARTICIPANT	\N	PRESENT	0
439295	426317	19735D	PARTICIPANT	\N	PRESENT	0
439290	426317	19657G	PARTICIPANT	\N	PRESENT	0
439280	426317	14069U	PARTICIPANT	\N	PRESENT	0
439281	426317	19551W	PARTICIPANT	\N	PRESENT	0
439282	426317	11040E	PARTICIPANT	\N	PRESENT	0
439283	426317	14223L	PARTICIPANT	\N	PRESENT	0
439284	426317	19760E	PARTICIPANT	\N	PRESENT	0
439296	426317	19253P	PARTICIPANT	\N	PRESENT	0
439286	426317	19739H	PARTICIPANT	\N	PRESENT	0
439287	426317	14237S	PARTICIPANT	\N	PRESENT	0
439288	426317	19629C	PARTICIPANT	\N	PRESENT	0
439289	426317	19637C	PARTICIPANT	\N	PRESENT	0
439291	426317	19553Y	PARTICIPANT	\N	PRESENT	0
439292	426317	11064N	PARTICIPANT	\N	PRESENT	0
439293	426317	19511N	PARTICIPANT	\N	PRESENT	0
439294	426317	14103D	PARTICIPANT	\N	PRESENT	0
439297	426317	14042U	PARTICIPANT	\N	PRESENT	0
439299	426317	14031R	PARTICIPANT	\N	PRESENT	0
439300	426317	14157T	PARTICIPANT	\N	PRESENT	0
439301	439298	14051J	PARTICIPANT	\N	PRESENT	0
439302	439298	08060W	PARTICIPANT	\N	PRESENT	0
439303	439298	08009T	PRESIDENT	0	PRESENT	0
439304	439298	14079W	PARTICIPANT	\N	PRESENT	0
439305	439298	19413M	PARTICIPANT	\N	PRESENT	0
439306	439298	19367Y	PARTICIPANT	\N	PRESENT	0
439307	439298	19251M	PARTICIPANT	\N	PRESENT	0
439308	439298	19758L	PARTICIPANT	\N	PRESENT	0
439309	426317	97011G	PARTICIPANT	\N	PRESENT	0
439310	426317	19715Y	PARTICIPANT	\N	PRESENT	0
439311	426317	14281W	PARTICIPANT	\N	PRESENT	0
439312	426317	19713W	PARTICIPANT	\N	PRESENT	0
439313	426317	19479G	PARTICIPANT	\N	PRESENT	0
439314	426317	19812Y	PARTICIPANT	\N	PRESENT	0
439315	426317	14217N	PARTICIPANT	\N	PRESENT	0
439316	426317	14021P	PARTICIPANT	\N	PRESENT	0
439317	426317	01025N	PARTICIPANT	\N	PRESENT	0
439318	426317	14147R	PARTICIPANT	\N	PRESENT	0
439319	426317	19697Q	PARTICIPANT	\N	PRESENT	0
439321	426317	19569H	PARTICIPANT	\N	PRESENT	0
439322	426317	04092N	PARTICIPANT	\N	PRESENT	0
439323	426317	19521Q	PARTICIPANT	\N	PRESENT	0
439324	439298	95067Q	PARTICIPANT	\N	PRESENT	0
439325	426317	14211G	PARTICIPANT	\N	PRESENT	0
439337	426317	19399H	PARTICIPANT	\N	PRESENT	0
439341	439298	11048N	PARTICIPANT	\N	PRESENT	0
439474	431205	98050T	PARTICIPANT	\N	PRESENT	0
439475	431205	01057W	PARTICIPANT	\N	PRESENT	0
439476	431205	14237S	PARTICIPANT	\N	PRESENT	0
439477	436980	04092N	PRESIDENT	0	PRESENT	0
439478	431205	19758L	PARTICIPANT	\N	PRESENT	0
439479	436980	18083K	PARTICIPANT	\N	PRESENT	0
439480	436980	19415P	PARTICIPANT	\N	PRESENT	0
439481	436980	14217N	PARTICIPANT	\N	PRESENT	0
439482	436980	10006L	PRESIDENT	1	PRESENT	0
439483	436980	08034U	PARTICIPANT	\N	PRESENT	0
439484	436980	14213J	PARTICIPANT	\N	PRESENT	0
439485	436980	04045F	PARTICIPANT	\N	PRESENT	0
439486	431205	14257W	PARTICIPANT	\N	PRESENT	0
439487	431205	14079W	PARTICIPANT	\N	PRESENT	0
439488	431205	19739H	PARTICIPANT	\N	PRESENT	0
439489	436980	05008E	PARTICIPANT	\N	EXCUSE	0
439490	431205	14033T	PARTICIPANT	\N	PRESENT	0
439492	439491	08015R	PARTICIPANT	\N	PRESENT	0
439493	439491	14225N	PARTICIPANT	\N	PRESENT	0
439494	439491	01043Q	PARTICIPANT	\N	PRESENT	0
439495	439491	19737F	PARTICIPANT	\N	PRESENT	0
439496	439491	14001X	PARTICIPANT	\N	PRESENT	0
439497	439491	04035D	PARTICIPANT	\N	PRESENT	0
439498	439491	88008L	PARTICIPANT	\N	PRESENT	0
439499	439491	04049K	PARTICIPANT	\N	PRESENT	0
439500	439491	19657G	PARTICIPANT	\N	PRESENT	0
441630	441629	14026U	PARTICIPANT	\N	PRESENT	0
441632	441631	19575F	PARTICIPANT	\N	PRESENT	0
441633	441631	19383Y	PARTICIPANT	\N	PRESENT	0
441634	441631	19782L	PARTICIPANT	\N	PRESENT	0
441635	441631	11103C	PARTICIPANT	\N	PRESENT	0
441636	441631	14329V	PARTICIPANT	\N	PRESENT	0
441637	441631	18083K	PARTICIPANT	\N	PRESENT	0
441638	441631	14357A	PARTICIPANT	\N	PRESENT	0
441639	441631	17589D	PARTICIPANT	\N	PRESENT	0
441640	441631	04089T	PARTICIPANT	\N	PRESENT	0
441641	441631	87003B	PARTICIPANT	\N	PRESENT	0
441642	441631	19507S	PARTICIPANT	\N	PRESENT	0
441643	441631	14187A	PARTICIPANT	\N	PRESENT	0
441644	441631	14026U	PARTICIPANT	\N	PRESENT	0
441645	441631	01057W	PARTICIPANT	\N	PRESENT	0
441646	441631	14059S	PARTICIPANT	\N	PRESENT	0
441647	441631	14103D	PARTICIPANT	\N	PRESENT	0
441648	441631	08053X	PARTICIPANT	\N	PRESENT	0
441649	441631	14221J	PARTICIPANT	\N	PRESENT	0
441650	441631	19563B	PARTICIPANT	\N	PRESENT	0
424588	424587	11064N	PARTICIPANT	\N	PRESENT	0
424847	416303	14211G	PARTICIPANT	\N	PRESENT	0
424848	416303	14251Q	PARTICIPANT	\N	PRESENT	0
424849	416303	80013X	PARTICIPANT	\N	PRESENT	0
424850	416303	19768N	PARTICIPANT	\N	PRESENT	0
424851	416303	14109K	PARTICIPANT	\N	PRESENT	0
424852	416303	14073Q	PARTICIPANT	\N	PRESENT	0
424853	416303	19826F	PARTICIPANT	\N	PRESENT	0
424854	416303	19447X	PARTICIPANT	\N	PRESENT	0
424855	416303	19762G	PARTICIPANT	\N	PRESENT	0
424856	416303	04088S	PARTICIPANT	\N	PRESENT	0
424857	416303	14265W	PARTICIPANT	\N	PRESENT	0
424858	416303	14026U	PARTICIPANT	\N	PRESENT	0
424859	416303	14089Y	PARTICIPANT	\N	PRESENT	0
424860	416303	14059S	PARTICIPANT	\N	PRESENT	0
424861	416303	14179A	PARTICIPANT	\N	PRESENT	0
424862	416303	01024M	PARTICIPANT	\N	PRESENT	0
424863	416303	14071N	PARTICIPANT	\N	PRESENT	0
424864	416303	14187A	PARTICIPANT	\N	PRESENT	0
424865	416303	14213J	PARTICIPANT	\N	PRESENT	0
424866	416303	04040A	PARTICIPANT	\N	PRESENT	0
424867	416303	19621T	PARTICIPANT	\N	PRESENT	0
424876	416303	14069U	PARTICIPANT	\N	PRESENT	0
424877	416303	14038Y	PARTICIPANT	\N	PRESENT	0
424900	422594	08060W	PARTICIPANT	\N	PRESENT	0
424901	422594	95067Q	PARTICIPANT	\N	PRESENT	0
424902	422594	08009T	PRESIDENT	0	PRESENT	0
424903	422594	19367Y	PARTICIPANT	\N	PRESENT	0
424904	422594	19251M	PARTICIPANT	\N	PRESENT	0
424905	422594	14033T	PARTICIPANT	\N	PRESENT	0
424845	416303	01028R	PARTICIPANT	\N	PRESENT	0
424846	416303	11033F	PARTICIPANT	\N	PRESENT	0
424906	422594	19758L	PARTICIPANT	\N	PRESENT	0
424907	422594	14053L	PARTICIPANT	\N	EXCUSE	0
424908	422594	04070G	PARTICIPANT	\N	PRESENT	0
424909	422594	14051J	PARTICIPANT	\N	EXCUSE	0
424910	422594	14079W	PARTICIPANT	\N	EXCUSE	0
424911	422594	11065P	PARTICIPANT	\N	EXCUSE	0
424912	422594	19637C	PARTICIPANT	\N	EXCUSE	0
424937	424897	04045F	PARTICIPANT	\N	EXCUSE	0
424938	424897	19681G	PARTICIPANT	\N	EXCUSE	0
424939	424897	11072N	PARTICIPANT	\N	EXCUSE	0
424940	424897	05008E	PARTICIPANT	\N	EXCUSE	0
424941	424897	14042U	PRESIDENT	0	PRESENT	0
424942	424897	11067R	PARTICIPANT	\N	PRESENT	0
424943	424897	04092N	PARTICIPANT	\N	PRESENT	0
424944	424897	19569H	PARTICIPANT	\N	PRESENT	0
424945	424897	08043V	PARTICIPANT	\N	PRESENT	0
424946	424897	19447X	PARTICIPANT	\N	PRESENT	0
424947	424897	04085P	PARTICIPANT	\N	PRESENT	0
424948	424897	14195A	PARTICIPANT	\N	PRESENT	0
424949	424897	14213J	PARTICIPANT	\N	PRESENT	0
424950	424897	11085T	PARTICIPANT	\N	PRESENT	0
424951	424897	99004R	PARTICIPANT	\N	PRESENT	0
424952	424897	14215L	PARTICIPANT	\N	PRESENT	0
424953	424897	19683J	PARTICIPANT	\N	PRESENT	0
424954	424897	14147R	PARTICIPANT	\N	PRESENT	0
424955	424897	14065Q	PARTICIPANT	\N	PRESENT	0
428171	416333	14225N	PARTICIPANT	\N	PRESENT	0
424959	424897	14217N	PARTICIPANT	\N	PRESENT	0
424960	424897	19553Y	PARTICIPANT	\N	PRESENT	0
428172	416333	14199E	PARTICIPANT	\N	PRESENT	0
428173	416333	01028R	PARTICIPANT	\N	PRESENT	0
428174	416333	19563B	PARTICIPANT	\N	PRESENT	0
428175	416333	19715Y	PARTICIPANT	\N	PRESENT	0
428180	416333	19687N	PARTICIPANT	\N	PRESENT	0
428181	416333	14038Y	PARTICIPANT	\N	PRESENT	0
428182	416333	19295A	PARTICIPANT	\N	PRESENT	0
428183	416333	19593H	PARTICIPANT	\N	PRESENT	0
428200	416333	19527W	PARTICIPANT	\N	PRESENT	0
428201	416333	19543W	PARTICIPANT	\N	PRESENT	0
428203	416333	11085T	PARTICIPANT	\N	PRESENT	0
428204	416333	14251Q	PARTICIPANT	\N	PRESENT	0
428205	416333	11012A	PARTICIPANT	\N	PRESENT	0
428206	416333	01024M	PARTICIPANT	\N	PRESENT	0
428207	416333	19399H	PARTICIPANT	\N	PRESENT	0
428208	416333	14331P	PARTICIPANT	\N	PRESENT	0
428213	416333	04059M	PARTICIPANT	\N	PRESENT	0
428210	416333	08010L	PARTICIPANT	\N	PRESENT	0
428211	416333	14119M	PARTICIPANT	\N	PRESENT	0
428212	416333	04033B	PARTICIPANT	\N	PRESENT	0
428214	416333	19531S	PARTICIPANT	\N	PRESENT	0
428215	416333	14261S	PARTICIPANT	\N	PRESENT	0
428216	416333	08019V	PARTICIPANT	\N	PRESENT	0
428217	416333	14205J	PARTICIPANT	\N	PRESENT	0
428218	416333	04018C	PARTICIPANT	\N	PRESENT	0
428495	422995	14219Q	PARTICIPANT	\N	EXCUSE	0
428496	422995	14038Y	PARTICIPANT	\N	EXCUSE	0
431929	430232	14259Y	PRESIDENT	0	PRESENT	0
432078	432075	19691J	PARTICIPANT	\N	PRESENT	0
432080	432076	19691J	PARTICIPANT	\N	PRESENT	0
432764	430646	95030B	PARTICIPANT	\N	EXCUSE	0
432765	430646	08053X	PARTICIPANT	\N	EXCUSE	0
432766	430646	14028W	PARTICIPANT	\N	EXCUSE	0
432767	430646	19443T	PARTICIPANT	\N	EXCUSE	0
441601	439607	18083K	PARTICIPANT	\N	PRESENT	0
441602	439607	11067R	PARTICIPANT	\N	PRESENT	0
441603	439607	04092N	PRESIDENT	0	PRESENT	0
441604	439607	19569H	PARTICIPANT	\N	PRESENT	0
441605	439607	08052W	PARTICIPANT	\N	PRESENT	0
441606	439607	14042U	PRESIDENT	1	PRESENT	0
441607	439607	08043V	PARTICIPANT	\N	PRESENT	0
441608	439607	99004R	PARTICIPANT	\N	PRESENT	0
441609	439607	19683J	PARTICIPANT	\N	PRESENT	0
441610	439607	19447X	PARTICIPANT	\N	PRESENT	0
441611	439607	19575F	PARTICIPANT	\N	EXCUSE	0
441612	439607	14213J	PARTICIPANT	\N	EXCUSE	0
441614	439607	01048V	PARTICIPANT	\N	PRESENT	0
441615	439607	14215L	PARTICIPANT	\N	PRESENT	0
444389	443682	19443T	PARTICIPANT	\N	PRESENT	0
444390	443682	12041X	PARTICIPANT	\N	PRESENT	0
444391	443682	14133K	PARTICIPANT	\N	PRESENT	0
444392	443682	11041F	PARTICIPANT	\N	PRESENT	0
444393	443682	14235Q	PARTICIPANT	\N	PRESENT	0
444394	443682	14079W	PARTICIPANT	\N	PRESENT	0
444395	443682	16685X	PARTICIPANT	\N	PRESENT	0
444396	443682	04042C	PRESIDENT	0	PRESENT	0
444397	443682	14028W	PARTICIPANT	\N	PRESENT	0
444398	443682	11054L	PARTICIPANT	\N	PRESENT	0
444399	443682	11066Q	PARTICIPANT	\N	PRESENT	0
444400	443682	19721W	PARTICIPANT	\N	PRESENT	0
444401	443682	19319Q	PARTICIPANT	\N	PRESENT	0
444402	443682	14105F	PARTICIPANT	\N	PRESENT	0
444403	443682	95037J	PARTICIPANT	\N	PRESENT	0
444404	443682	98018T	PRESIDENT	1	PRESENT	0
444405	443682	98022P	PARTICIPANT	\N	PRESENT	0
444406	443682	14267Y	PARTICIPANT	\N	PRESENT	0
444407	443682	08061X	PARTICIPANT	\N	PRESENT	0
444408	443682	19583F	PARTICIPANT	\N	PRESENT	0
444409	443682	08047A	PARTICIPANT	\N	PRESENT	0
444410	443682	14255U	PARTICIPANT	\N	PRESENT	0
444411	443682	98029W	PARTICIPANT	\N	PRESENT	0
444412	443682	14097Y	PARTICIPANT	\N	PRESENT	0
444413	443682	19251M	PARTICIPANT	\N	PRESENT	0
444414	443682	01058X	PARTICIPANT	\N	PRESENT	0
444415	443682	08056B	PARTICIPANT	\N	PRESENT	0
444416	443682	04035D	PARTICIPANT	\N	PRESENT	0
444417	443682	97011G	PARTICIPANT	\N	PRESENT	0
444418	443681	19768N	PARTICIPANT	\N	PRESENT	0
444419	443681	19515S	PARTICIPANT	\N	PRESENT	0
444420	443681	19782L	PARTICIPANT	\N	PRESENT	0
444421	443681	01043Q	PARTICIPANT	\N	PRESENT	0
444422	443681	19812Y	PARTICIPANT	\N	PRESENT	0
444423	443681	19413M	PARTICIPANT	\N	PRESENT	0
444424	443681	14081Q	PARTICIPANT	\N	PRESENT	0
444425	443681	80013X	PARTICIPANT	\N	PRESENT	0
444426	443681	11099A	PARTICIPANT	\N	PRESENT	0
444427	443681	08068F	PARTICIPANT	\N	PRESENT	0
444428	443681	19705W	PARTICIPANT	\N	PRESENT	0
444429	443681	08019V	PARTICIPANT	\N	PRESENT	0
444430	443681	14197C	PARTICIPANT	\N	PRESENT	0
444431	443681	19369B	PARTICIPANT	\N	PRESENT	0
444432	443681	19511N	PARTICIPANT	\N	PRESENT	0
444433	443681	08028W	PARTICIPANT	\N	PRESENT	0
444434	443681	19563B	PARTICIPANT	\N	PRESENT	0
444435	443681	19591F	PARTICIPANT	\N	PRESENT	0
444436	443681	14329V	PARTICIPANT	\N	PRESENT	0
444437	443681	14135M	PARTICIPANT	\N	PRESENT	0
444438	443681	19467C	PARTICIPANT	\N	PRESENT	0
444439	443681	14187A	PARTICIPANT	\N	PRESENT	0
444440	443681	19695N	PARTICIPANT	\N	PRESENT	0
444441	443681	14033T	PARTICIPANT	\N	PRESENT	0
444442	443681	11090Q	PRESIDENT	0	PRESENT	0
444443	443681	01025N	PARTICIPANT	\N	PRESENT	0
430437	416375	11012A	PARTICIPANT	\N	PRESENT	0
430438	416375	14093U	PARTICIPANT	\N	PRESENT	0
430439	416375	14103D	PARTICIPANT	\N	PRESENT	0
430440	416375	12041X	PARTICIPANT	\N	PRESENT	0
430441	416375	08031R	PARTICIPANT	\N	PRESENT	0
430442	416375	19737F	PARTICIPANT	\N	PRESENT	0
430467	416370	11070L	PARTICIPANT	\N	PRESENT	0
430468	416370	19745F	PARTICIPANT	\N	PRESENT	0
430469	416370	08009T	PARTICIPANT	\N	PRESENT	0
430470	416370	19637C	PARTICIPANT	\N	PRESENT	0
430471	416370	14151M	PARTICIPANT	\N	PRESENT	0
430472	416370	19387D	PARTICIPANT	\N	PRESENT	0
430473	416370	19820Y	PARTICIPANT	\N	PRESENT	0
430474	416370	14093U	PARTICIPANT	\N	PRESENT	0
430475	416370	19333N	PARTICIPANT	\N	PRESENT	0
430476	416370	17583W	PARTICIPANT	\N	PRESENT	0
430477	416370	19533U	PARTICIPANT	\N	PRESENT	0
430478	416370	04088S	PARTICIPANT	\N	PRESENT	0
430479	416370	19782L	PARTICIPANT	\N	PRESENT	0
430480	416370	14038Y	PARTICIPANT	\N	PRESENT	0
430481	416370	95030B	PARTICIPANT	\N	PRESENT	0
430482	416370	04070G	PARTICIPANT	\N	PRESENT	0
430483	416370	17589D	PARTICIPANT	\N	PRESENT	0
430484	416370	19794Q	PARTICIPANT	\N	PRESENT	0
430485	416370	19347U	PARTICIPANT	\N	PRESENT	0
430486	416370	14251Q	PARTICIPANT	\N	PRESENT	0
430487	416370	14147R	PARTICIPANT	\N	PRESENT	0
430488	416370	14109K	PARTICIPANT	\N	PRESENT	0
430489	416370	14107H	PARTICIPANT	\N	PRESENT	0
430490	416370	14197C	PARTICIPANT	\N	PRESENT	0
430491	416370	14219Q	PARTICIPANT	\N	PRESENT	0
430492	416370	14033T	PARTICIPANT	\N	PRESENT	0
430493	416370	19739H	PARTICIPANT	\N	PRESENT	0
430495	416370	19583F	PARTICIPANT	\N	PRESENT	0
430496	416370	19415P	PARTICIPANT	\N	PRESENT	0
430497	428243	14327T	PARTICIPANT	\N	PRESENT	0
430498	428243	11048N	PARTICIPANT	\N	PRESENT	0
430499	428243	19479G	PARTICIPANT	\N	PRESENT	0
430500	428243	19647E	PARTICIPANT	\N	PRESENT	0
430501	428243	19711U	PARTICIPANT	\N	PRESENT	0
430502	428243	95041E	PARTICIPANT	\N	PRESENT	0
430503	428243	01048V	PARTICIPANT	\N	PRESENT	0
430504	428243	19651A	PARTICIPANT	\N	PRESENT	0
430505	428243	01057W	PARTICIPANT	\N	PRESENT	0
430506	428243	11074Q	PRESIDENT	0	PRESENT	0
430507	428243	08011M	PARTICIPANT	\N	PRESENT	0
430508	428243	89017R	PARTICIPANT	\N	PRESENT	0
430509	428243	19667J	PARTICIPANT	\N	PRESENT	0
430510	428243	14159V	PARTICIPANT	\N	PRESENT	0
430511	428243	04086Q	PARTICIPANT	\N	PRESENT	0
430512	428243	07029T	PARTICIPANT	\N	PRESENT	0
430513	428243	11012A	PARTICIPANT	\N	PRESENT	0
430514	428243	14085U	PARTICIPANT	\N	PRESENT	0
430515	428243	07004J	PARTICIPANT	\N	PRESENT	0
430516	428243	19741B	PARTICIPANT	\N	PRESENT	0
430517	428243	14121F	PARTICIPANT	\N	PRESENT	0
430518	428243	08010L	PARTICIPANT	\N	PRESENT	0
430519	428243	99004R	PARTICIPANT	\N	PRESENT	0
430525	416370	08056B	PARTICIPANT	\N	PRESENT	0
430526	416370	14059S	PARTICIPANT	\N	PRESENT	0
430527	416370	19581D	PARTICIPANT	\N	PRESENT	0
430528	416370	14083S	PARTICIPANT	\N	PRESENT	0
430529	416370	04057K	PARTICIPANT	\N	PRESENT	0
430534	416370	14069U	PARTICIPANT	\N	PRESENT	0
430535	416370	11048N	PARTICIPANT	\N	PRESENT	0
430536	416370	11012A	PARTICIPANT	\N	PRESENT	0
430537	416370	19549D	PARTICIPANT	\N	PRESENT	0
430538	416370	08055A	PARTICIPANT	\N	PRESENT	0
430539	416370	19413M	PARTICIPANT	\N	PRESENT	0
430540	416370	19479G	PARTICIPANT	\N	PRESENT	0
430542	416370	11053K	PARTICIPANT	\N	PRESENT	0
430546	416370	14179A	PARTICIPANT	\N	PRESENT	0
430547	416370	19731Y	PARTICIPANT	\N	PRESENT	0
430549	428277	04092N	PRESIDENT	0	PRESENT	0
430550	428277	14042U	PRESIDENT	1	PRESENT	0
430551	428277	19683J	PARTICIPANT	\N	PRESENT	0
430552	428277	19569H	PARTICIPANT	\N	EXCUSE	0
430557	416370	14195A	PARTICIPANT	\N	PRESENT	0
430558	428277	14213J	PARTICIPANT	\N	PRESENT	0
430559	416370	14157T	PARTICIPANT	\N	PRESENT	0
430560	428277	11067R	PARTICIPANT	\N	PRESENT	0
430561	428277	19415P	PARTICIPANT	\N	PRESENT	0
430562	428277	99004R	PARTICIPANT	\N	PRESENT	0
430563	428277	14217N	PARTICIPANT	\N	PRESENT	0
430564	428277	11066Q	PARTICIPANT	\N	PRESENT	0
430565	428277	04045F	PARTICIPANT	\N	PRESENT	0
430566	428277	14195A	PARTICIPANT	\N	PRESENT	0
430567	428277	14179A	PARTICIPANT	\N	PRESENT	0
430568	428277	19575F	PARTICIPANT	\N	PRESENT	0
430613	428277	11085T	PARTICIPANT	\N	PRESENT	0
430614	428241	14135M	PARTICIPANT	\N	PRESENT	0
430615	428241	19467C	PARTICIPANT	\N	PRESENT	0
430616	428241	19515S	PARTICIPANT	\N	PRESENT	0
430617	428241	19782L	PARTICIPANT	\N	PRESENT	0
430618	428241	14357A	PARTICIPANT	\N	PRESENT	0
430619	428241	14187A	PARTICIPANT	\N	PRESENT	0
430620	428241	19812Y	PARTICIPANT	\N	PRESENT	0
430621	428241	19413M	PARTICIPANT	\N	PRESENT	0
430622	428241	14033T	PARTICIPANT	\N	PRESENT	0
430623	428241	80013X	PARTICIPANT	\N	PRESENT	0
430624	428241	04088S	PARTICIPANT	\N	PRESENT	0
430625	428241	11101A	PARTICIPANT	\N	PRESENT	0
430626	428241	19507S	PARTICIPANT	\N	PRESENT	0
430627	428241	08015R	PARTICIPANT	\N	PRESENT	0
430628	428241	14197C	PARTICIPANT	\N	PRESENT	0
430629	428241	19369B	PARTICIPANT	\N	PRESENT	0
430630	428241	19747H	PARTICIPANT	\N	PRESENT	0
430631	428241	19511N	PARTICIPANT	\N	PRESENT	0
430632	428241	19619A	PARTICIPANT	\N	PRESENT	0
430633	428241	14265W	PARTICIPANT	\N	PRESENT	0
430634	428241	14257W	PARTICIPANT	\N	PRESENT	0
430635	428241	19768N	PARTICIPANT	\N	PRESENT	0
430636	428241	11090Q	PRESIDENT	0	PRESENT	0
430637	428241	11081P	PARTICIPANT	\N	EXCUSE	0
430638	428241	19631V	PARTICIPANT	\N	EXCUSE	0
430639	428277	10006L	PARTICIPANT	\N	PRESENT	0
430640	428241	14081Q	PARTICIPANT	\N	PRESENT	0
430641	428241	08038Y	PARTICIPANT	\N	PRESENT	0
430642	428277	14147R	PARTICIPANT	\N	PRESENT	0
430435	416375	19621T	PARTICIPANT	\N	PRESENT	0
430436	416375	14261S	PARTICIPANT	\N	PRESENT	0
430643	428277	19553Y	PARTICIPANT	\N	PRESENT	0
430666	424868	01043Q	PARTICIPANT	\N	PRESENT	0
430667	424868	08011M	PARTICIPANT	\N	PRESENT	0
430668	424868	11074Q	PARTICIPANT	\N	PRESENT	0
430669	424868	19651A	PARTICIPANT	\N	PRESENT	0
430670	424868	14033T	PARTICIPANT	\N	PRESENT	0
430671	424868	19295A	PARTICIPANT	\N	PRESENT	0
430672	424868	14157T	PARTICIPANT	\N	PRESENT	0
430673	424868	99004R	PARTICIPANT	\N	PRESENT	0
430674	424868	11048N	PARTICIPANT	\N	PRESENT	0
430675	424868	19399H	PARTICIPANT	\N	PRESENT	0
430676	424868	19794Q	PARTICIPANT	\N	PRESENT	0
430611	428277	11031D	PARTICIPANT	\N	PRESENT	0
430612	428277	08052W	PARTICIPANT	\N	PRESENT	0
430677	424868	14021P	PARTICIPANT	\N	PRESENT	0
430678	424868	19333N	PARTICIPANT	\N	PRESENT	0
430679	424868	08014Q	PARTICIPANT	\N	PRESENT	0
430680	424868	14085U	PARTICIPANT	\N	PRESENT	0
430681	424868	11040E	PARTICIPANT	\N	PRESENT	0
430682	424868	19647E	PARTICIPANT	\N	PRESENT	0
430683	424868	04085P	PARTICIPANT	\N	PRESENT	0
430684	424868	19599P	PARTICIPANT	\N	PRESENT	0
430685	424868	19758L	PARTICIPANT	\N	PRESENT	0
430686	424868	19687N	PARTICIPANT	\N	PRESENT	0
430687	424868	88008L	PARTICIPANT	\N	PRESENT	0
430688	424868	11053K	PARTICIPANT	\N	PRESENT	0
430689	424868	19737F	PARTICIPANT	\N	PRESENT	0
430690	424868	11070L	PARTICIPANT	\N	PRESENT	0
430691	424868	08010L	PARTICIPANT	\N	PRESENT	0
430692	424868	14089Y	PARTICIPANT	\N	PRESENT	0
430693	424868	14327T	PARTICIPANT	\N	PRESENT	0
430694	424868	07004J	PARTICIPANT	\N	PRESENT	0
430695	424868	19711U	PARTICIPANT	\N	PRESENT	0
430696	424868	14261S	PARTICIPANT	\N	PRESENT	0
430697	424868	14030Q	PARTICIPANT	\N	PRESENT	0
430698	424868	19820Y	PARTICIPANT	\N	PRESENT	0
430699	424868	19693L	PARTICIPANT	\N	PRESENT	0
430700	424868	14147R	PARTICIPANT	\N	PRESENT	0
430701	424868	01057W	PARTICIPANT	\N	PRESENT	0
430702	424868	04086Q	PARTICIPANT	\N	PRESENT	0
430703	424868	19443T	PARTICIPANT	\N	PRESENT	0
430704	424868	19367Y	PARTICIPANT	\N	PRESENT	0
430705	424868	04088S	PARTICIPANT	\N	PRESENT	0
430706	424868	19741B	PARTICIPANT	\N	PRESENT	0
430707	424868	14257W	PARTICIPANT	\N	PRESENT	0
430708	424868	19301E	PARTICIPANT	\N	PRESENT	0
430709	424868	19507S	PARTICIPANT	\N	PRESENT	0
430710	424868	04033B	PARTICIPANT	\N	PRESENT	0
425426	423923	19782L	PARTICIPANT	\N	PRESENT	0
425427	423923	11099A	PARTICIPANT	\N	PRESENT	0
425428	423923	08069G	PARTICIPANT	\N	PRESENT	0
437847	431727	96004D	PARTICIPANT	\N	EXCUSE	0
437848	431727	19631V	PARTICIPANT	\N	EXCUSE	0
437849	431727	19729F	PARTICIPANT	\N	EXCUSE	0
437850	431727	14135M	PARTICIPANT	\N	EXCUSE	0
437851	431727	14225N	PARTICIPANT	\N	EXCUSE	0
437852	431727	11054L	PARTICIPANT	\N	EXCUSE	0
437853	431727	14275Y	PARTICIPANT	\N	EXCUSE	0
437854	437846	19741B	PARTICIPANT	\N	PRESENT	0
437855	437846	19667J	PARTICIPANT	\N	PRESENT	0
437856	437846	88008L	PARTICIPANT	\N	PRESENT	0
437857	437846	04086Q	PARTICIPANT	\N	PRESENT	0
437858	437846	11074Q	PRESIDENT	0	PRESENT	0
437859	437846	07004J	PARTICIPANT	\N	PRESENT	0
437860	437846	14121F	PARTICIPANT	\N	PRESENT	0
437861	437846	99004R	PARTICIPANT	\N	PRESENT	0
437862	437846	19711U	PARTICIPANT	\N	PRESENT	0
437863	437846	08010L	PARTICIPANT	\N	PRESENT	0
437864	437846	08011M	PARTICIPANT	\N	PRESENT	0
437865	437846	11012A	PARTICIPANT	\N	PRESENT	0
437866	437846	19479G	PARTICIPANT	\N	PRESENT	0
437892	432678	19467C	PARTICIPANT	\N	EXCUSE	0
437893	432678	11066Q	PARTICIPANT	\N	PRESENT	0
438182	431450	08045X	PARTICIPANT	\N	PRESENT	0
438252	432678	19629C	PARTICIPANT	\N	EXCUSE	0
444745	444387	19697Q	PARTICIPANT	\N	PRESENT	0
444746	444387	11067R	PARTICIPANT	\N	PRESENT	0
444747	444387	19565D	PARTICIPANT	\N	PRESENT	0
444748	444387	19798U	PARTICIPANT	\N	PRESENT	0
444749	444387	19569H	PARTICIPANT	\N	PRESENT	0
444750	444387	11097X	PARTICIPANT	\N	PRESENT	0
444751	444387	19415P	PARTICIPANT	\N	PRESENT	0
444752	444387	14223L	PARTICIPANT	\N	PRESENT	0
444753	444387	04045F	PARTICIPANT	\N	PRESENT	0
444754	444387	14026U	PARTICIPANT	\N	PRESENT	0
444755	444387	14227Q	PARTICIPANT	\N	PRESENT	0
444756	444387	17779H	PARTICIPANT	\N	PRESENT	0
444757	444387	19703U	PARTICIPANT	\N	PRESENT	0
444758	444387	19553Y	PARTICIPANT	\N	PRESENT	0
444759	444387	14087W	PARTICIPANT	\N	PRESENT	0
444760	444387	14281W	PARTICIPANT	\N	PRESENT	0
444761	444387	19679N	PARTICIPANT	\N	PRESENT	0
444762	444387	14042U	PARTICIPANT	\N	PRESENT	0
444763	444387	19575F	PARTICIPANT	\N	PRESENT	0
444764	444387	08048B	PARTICIPANT	\N	PRESENT	0
444765	444387	14195A	PARTICIPANT	\N	PRESENT	0
444766	444387	19367Y	PARTICIPANT	\N	PRESENT	0
444767	444387	14213J	PARTICIPANT	\N	PRESENT	0
444768	444387	14217N	PARTICIPANT	\N	PRESENT	0
444769	444387	14261S	PARTICIPANT	\N	PRESENT	0
444770	444387	10006L	PARTICIPANT	\N	PRESENT	0
444771	444387	19683J	PARTICIPANT	\N	PRESENT	0
444772	444387	98024R	PARTICIPANT	\N	PRESENT	0
444773	444387	19521Q	PARTICIPANT	\N	PRESENT	0
444774	444387	19527W	PARTICIPANT	\N	PRESENT	0
444775	444387	01034P	PARTICIPANT	\N	PRESENT	0
444776	444387	04092N	PRESIDENT	0	PRESENT	0
444777	444387	08052W	PARTICIPANT	\N	PRESENT	0
444778	444387	19663E	PARTICIPANT	\N	PRESENT	0
444779	444387	19301E	PARTICIPANT	\N	PRESENT	0
444780	444387	19691J	PARTICIPANT	\N	PRESENT	0
444781	444387	19717B	PARTICIPANT	\N	PRESENT	0
444782	444387	19723Y	PARTICIPANT	\N	PRESENT	0
444783	444387	19727D	PARTICIPANT	\N	PRESENT	0
444784	444387	14119M	PARTICIPANT	\N	PRESENT	0
444785	444387	11103C	PARTICIPANT	\N	PRESENT	0
444786	444387	14071N	PARTICIPANT	\N	PRESENT	0
444787	444387	19657G	PARTICIPANT	\N	PRESENT	0
444788	444387	19760E	PARTICIPANT	\N	PRESENT	0
444789	444387	14355X	PARTICIPANT	\N	EXCUSE	0
444790	444387	08041T	PARTICIPANT	\N	EXCUSE	0
445009	439808	19693L	PARTICIPANT	\N	PRESENT	0
445010	439808	19737F	PARTICIPANT	\N	PRESENT	0
445011	439808	14042U	PARTICIPANT	\N	PRESENT	0
445012	439808	14213J	PARTICIPANT	\N	PRESENT	0
445013	439808	19699S	PARTICIPANT	\N	PRESENT	0
445014	439808	19619A	PARTICIPANT	\N	PRESENT	0
445015	439808	19553Y	PARTICIPANT	\N	PRESENT	0
445016	439808	14034U	PARTICIPANT	\N	PRESENT	0
445017	439808	19511N	PARTICIPANT	\N	PRESENT	0
445018	439808	19663E	PARTICIPANT	\N	PRESENT	0
445019	439808	19611R	PARTICIPANT	\N	PRESENT	0
445020	439808	14329V	PARTICIPANT	\N	PRESENT	0
445021	439808	08009T	PARTICIPANT	\N	PRESENT	0
445022	439808	14357A	PARTICIPANT	\N	PRESENT	0
445023	439808	01034P	PARTICIPANT	\N	PRESENT	0
445024	439808	19675J	PARTICIPANT	\N	PRESENT	0
445025	439808	19369B	PARTICIPANT	\N	PRESENT	0
445026	439808	19691J	PARTICIPANT	\N	PRESENT	0
445027	439808	19383Y	PARTICIPANT	\N	PRESENT	0
445028	439808	19701S	PARTICIPANT	\N	PRESENT	0
445029	439808	19319Q	PARTICIPANT	\N	PRESENT	0
445030	439808	19762G	PARTICIPANT	\N	PRESENT	0
445031	439808	14205J	PARTICIPANT	\N	PRESENT	0
445032	439808	04018C	PARTICIPANT	\N	PRESENT	0
445033	439808	19621T	PARTICIPANT	\N	PRESENT	0
445034	439808	14179A	PARTICIPANT	\N	PRESENT	0
445035	439808	19367Y	PARTICIPANT	\N	PRESENT	0
445036	439808	14231L	PARTICIPANT	\N	PRESENT	0
445037	439808	14219Q	PARTICIPANT	\N	PRESENT	0
445038	439808	04089T	PARTICIPANT	\N	PRESENT	0
445039	439808	19335Q	PARTICIPANT	\N	PRESENT	0
445040	439808	14059S	PARTICIPANT	\N	PRESENT	0
445041	439808	14103D	PARTICIPANT	\N	PRESENT	0
445042	439808	14061L	PARTICIPANT	\N	PRESENT	0
445043	439808	98050T	PARTICIPANT	\N	PRESENT	0
445044	439808	14089Y	PARTICIPANT	\N	PRESENT	0
445045	439808	19705W	PARTICIPANT	\N	PRESENT	0
445046	439808	19749K	PARTICIPANT	\N	PRESENT	0
445047	439808	19768N	PARTICIPANT	\N	PRESENT	0
445048	439808	14267Y	PARTICIPANT	\N	PRESENT	0
445049	439808	19729F	PARTICIPANT	\N	PRESENT	0
445050	439808	19657G	PARTICIPANT	\N	PRESENT	0
445051	439808	14221J	PARTICIPANT	\N	PRESENT	0
445052	439808	07029T	PARTICIPANT	\N	PRESENT	0
445053	439808	19507S	PARTICIPANT	\N	PRESENT	0
445054	439808	08018U	PARTICIPANT	\N	PRESENT	0
445055	439808	19467C	PARTICIPANT	\N	PRESENT	0
445056	439808	19741B	PARTICIPANT	\N	PRESENT	0
445057	439808	19443T	PARTICIPANT	\N	PRESENT	0
445058	439808	14073Q	PARTICIPANT	\N	PRESENT	0
445059	439808	19521Q	PARTICIPANT	\N	PRESENT	0
445060	439808	19826F	PARTICIPANT	\N	PRESENT	0
445061	439808	14255U	PARTICIPANT	\N	PRESENT	0
445062	439808	14277B	PARTICIPANT	\N	PRESENT	0
445063	439808	11085T	PARTICIPANT	\N	PRESENT	0
445064	439808	11070L	PARTICIPANT	\N	PRESENT	0
445065	439808	01025N	PARTICIPANT	\N	PRESENT	0
445066	439808	01024M	PARTICIPANT	\N	PRESENT	0
445067	439808	04070G	PARTICIPANT	\N	PRESENT	0
445068	439808	14327T	PARTICIPANT	\N	PRESENT	0
445069	439808	14030Q	PARTICIPANT	\N	PRESENT	0
445070	439808	01043Q	PARTICIPANT	\N	PRESENT	0
445071	439808	19721W	PARTICIPANT	\N	PRESENT	0
445072	439808	14055N	PARTICIPANT	\N	PRESENT	0
445073	439808	01060R	PARTICIPANT	\N	PRESENT	0
445074	439808	19717B	PARTICIPANT	\N	PRESENT	0
445075	439808	19543W	PARTICIPANT	\N	PRESENT	0
445076	439808	19681G	PARTICIPANT	\N	PRESENT	0
445077	439808	11065P	PARTICIPANT	\N	PRESENT	0
445078	439808	14093U	PARTICIPANT	\N	PRESENT	0
445079	439808	11064N	PARTICIPANT	\N	PRESENT	0
445080	439808	19329S	PARTICIPANT	\N	PRESENT	0
445081	439808	19525U	PARTICIPANT	\N	PRESENT	0
445082	439808	14229S	PARTICIPANT	\N	PRESENT	0
445083	439808	01028R	PARTICIPANT	\N	PRESENT	0
445084	439808	14259Y	PARTICIPANT	\N	PRESENT	0
445085	439808	11080N	PARTICIPANT	\N	PRESENT	0
445086	439808	04071H	PARTICIPANT	\N	PRESENT	0
445087	439808	11115U	PARTICIPANT	\N	PRESENT	0
445088	439808	05008E	PARTICIPANT	\N	PRESENT	0
445089	439808	14087W	PARTICIPANT	\N	PRESENT	0
445090	439808	04035D	PARTICIPANT	\N	PRESENT	0
445091	439808	08048B	PARTICIPANT	\N	PRESENT	0
445092	439808	04088S	PARTICIPANT	\N	PRESENT	0
445093	439808	95067Q	PARTICIPANT	\N	PRESENT	0
445094	439808	11101A	PARTICIPANT	\N	PRESENT	0
445095	439808	14105F	PARTICIPANT	\N	PRESENT	0
445096	439808	04092N	PARTICIPANT	\N	PRESENT	0
445097	439808	89017R	PARTICIPANT	\N	PRESENT	0
445099	439808	08049C	PARTICIPANT	\N	PRESENT	0
445100	439808	14237S	PARTICIPANT	\N	PRESENT	0
445101	439808	08060W	PARTICIPANT	\N	PRESENT	0
445102	439808	14207L	PARTICIPANT	\N	PRESENT	0
445106	439808	19551W	PARTICIPANT	\N	PRESENT	0
445107	439808	14257W	PARTICIPANT	\N	PRESENT	0
445114	439808	14275Y	PARTICIPANT	\N	PRESENT	0
433560	433554	19503N	PARTICIPANT	\N	PRESENT	0
433562	433558	19503N	PARTICIPANT	\N	PRESENT	0
433643	433637	14213J	PARTICIPANT	\N	PRESENT	0
433644	433637	19569H	PARTICIPANT	\N	PRESENT	0
433651	416333	19479G	PARTICIPANT	\N	PRESENT	0
441651	441631	14169X	PARTICIPANT	\N	PRESENT	0
441652	441631	08061X	PARTICIPANT	\N	PRESENT	0
441653	441631	04088S	PARTICIPANT	\N	PRESENT	0
441654	441631	05012A	PARTICIPANT	\N	PRESENT	0
441655	441631	19739H	PARTICIPANT	\N	PRESENT	0
441656	441631	95067Q	PARTICIPANT	\N	PRESENT	0
441862	441791	11080N	PARTICIPANT	\N	EXCUSE	0
441863	441791	14097Y	PARTICIPANT	\N	EXCUSE	0
441864	441791	14249W	PARTICIPANT	\N	EXCUSE	0
441866	441865	19673G	PARTICIPANT	\N	PRESENT	0
442666	441687	19467C	PARTICIPANT	\N	PRESENT	0
443161	443160	14026U	PARTICIPANT	\N	PRESENT	0
443163	443162	14026U	PARTICIPANT	\N	PRESENT	0
443882	439641	17589D	PARTICIPANT	\N	PRESENT	0
443886	439641	18083K	PARTICIPANT	\N	PRESENT	0
443888	439641	11066Q	PARTICIPANT	\N	PRESENT	0
443890	439641	14083S	PARTICIPANT	\N	PRESENT	0
443891	439641	19621T	PARTICIPANT	\N	PRESENT	0
443892	439641	01028R	PARTICIPANT	\N	PRESENT	0
443893	439641	19301E	PARTICIPANT	\N	PRESENT	0
443894	439641	11054L	PARTICIPANT	\N	PRESENT	0
443895	439641	19335Q	PARTICIPANT	\N	PRESENT	0
443896	439641	97011G	PARTICIPANT	\N	PRESENT	0
443925	439642	19669L	PARTICIPANT	\N	PRESENT	0
443926	443683	01043Q	PARTICIPANT	\N	PRESENT	0
443927	443683	08038Y	PARTICIPANT	\N	PRESENT	0
443928	443683	01025N	PARTICIPANT	\N	PRESENT	0
443929	443683	19269X	PARTICIPANT	\N	PRESENT	0
443930	443683	14115H	PARTICIPANT	\N	PRESENT	0
443931	443683	14197C	PARTICIPANT	\N	PRESENT	0
443932	443683	14257W	PARTICIPANT	\N	PRESENT	0
443933	443683	19515S	PARTICIPANT	\N	PRESENT	0
443934	439642	19479G	PARTICIPANT	\N	PRESENT	0
443935	439642	19399H	PARTICIPANT	\N	PRESENT	0
443936	439642	04088S	PARTICIPANT	\N	PRESENT	0
443911	439642	11070L	PARTICIPANT	\N	PRESENT	0
443912	443683	14135M	PARTICIPANT	\N	PRESENT	0
443913	443683	04088S	PARTICIPANT	\N	PRESENT	0
443914	443683	08068F	PARTICIPANT	\N	PRESENT	0
443915	443683	19782L	PARTICIPANT	\N	PRESENT	0
443916	443683	19705W	PARTICIPANT	\N	PRESENT	0
443917	443683	19812Y	PARTICIPANT	\N	PRESENT	0
443918	443683	14081Q	PARTICIPANT	\N	PRESENT	0
443919	443683	11090Q	PRESIDENT	0	PRESENT	0
443920	443683	14033T	PARTICIPANT	\N	PRESENT	0
443982	439642	11101A	PARTICIPANT	\N	PRESENT	0
443922	443683	11081P	PARTICIPANT	\N	EXCUSE	0
443923	443683	19631V	PARTICIPANT	\N	EXCUSE	0
443924	443683	14265W	PARTICIPANT	\N	EXCUSE	0
443937	439642	11090Q	PARTICIPANT	\N	PRESENT	0
443938	439642	19695N	PARTICIPANT	\N	PRESENT	0
443939	439642	19333N	PARTICIPANT	\N	PRESENT	0
443940	439642	19760E	PARTICIPANT	\N	PRESENT	0
443941	439642	01043Q	PARTICIPANT	\N	PRESENT	0
443942	439642	14033T	PARTICIPANT	\N	PRESENT	0
443943	439642	19549D	PARTICIPANT	\N	PRESENT	0
443944	439642	19705W	PARTICIPANT	\N	PRESENT	0
443945	439642	19441R	PARTICIPANT	\N	PRESENT	0
443946	439642	19289C	PARTICIPANT	\N	PRESENT	0
443947	439642	14105F	PARTICIPANT	\N	PRESENT	0
443948	439642	01024M	PARTICIPANT	\N	PRESENT	0
443949	439642	97011G	PARTICIPANT	\N	PRESENT	0
443950	439642	88008L	PARTICIPANT	\N	PRESENT	0
443951	439642	14135M	PARTICIPANT	\N	PRESENT	0
443952	439642	19697Q	PARTICIPANT	\N	PRESENT	0
443953	439642	19347U	PARTICIPANT	\N	PRESENT	0
443954	439642	01025N	PARTICIPANT	\N	PRESENT	0
443955	439642	08031R	PARTICIPANT	\N	PRESENT	0
443956	439642	14197C	PARTICIPANT	\N	PRESENT	0
443957	439642	19515S	PARTICIPANT	\N	PRESENT	0
443958	439642	19413M	PARTICIPANT	\N	PRESENT	0
443980	439642	19387D	PARTICIPANT	\N	PRESENT	0
443960	439642	08038Y	PARTICIPANT	\N	PRESENT	0
443961	439642	08068F	PARTICIPANT	\N	PRESENT	0
443962	439642	14205J	PARTICIPANT	\N	PRESENT	0
443963	439642	15447F	PARTICIPANT	\N	PRESENT	0
443964	439642	04057K	PARTICIPANT	\N	PRESENT	0
443965	439642	19782L	PARTICIPANT	\N	PRESENT	0
443966	439642	11056N	PARTICIPANT	\N	PRESENT	0
443967	439642	19319Q	PARTICIPANT	\N	PRESENT	0
443968	439642	19611R	PARTICIPANT	\N	PRESENT	0
443969	439642	14147R	PARTICIPANT	\N	PRESENT	0
443970	439642	19543W	PARTICIPANT	\N	PRESENT	0
443971	439642	19679N	PARTICIPANT	\N	PRESENT	0
443972	439642	14069U	PARTICIPANT	\N	PRESENT	0
443973	439642	18083K	PARTICIPANT	\N	PRESENT	0
443976	439642	19703U	PARTICIPANT	\N	PRESENT	0
443977	439642	17589D	PARTICIPANT	\N	PRESENT	0
443978	439642	14257W	PARTICIPANT	\N	PRESENT	0
443979	443683	19747H	PARTICIPANT	\N	PRESENT	0
443981	439642	14089Y	PARTICIPANT	\N	PRESENT	0
443983	439642	14249W	PARTICIPANT	\N	PRESENT	0
443984	439642	19737F	PARTICIPANT	\N	PRESENT	0
443985	439642	11103C	PARTICIPANT	\N	PRESENT	0
444364	444363	14237S	PARTICIPANT	\N	PRESENT	0
444713	444712	11064N	PARTICIPANT	\N	PRESENT	0
444714	444712	14195A	PARTICIPANT	\N	PRESENT	0
444720	444719	04040A	PARTICIPANT	\N	PRESENT	0
444721	444719	10015M	PARTICIPANT	\N	PRESENT	0
444722	444719	11074Q	PARTICIPANT	\N	PRESENT	0
444723	444719	04035D	PARTICIPANT	\N	PRESENT	0
444724	444719	19826F	PARTICIPANT	\N	PRESENT	0
444725	444719	14255U	PARTICIPANT	\N	PRESENT	0
444726	444719	14221J	PARTICIPANT	\N	PRESENT	0
445578	443733	14221J	PARTICIPANT	\N	PRESENT	0
445579	443733	14169X	PARTICIPANT	\N	PRESENT	0
445592	443874	14239U	PARTICIPANT	\N	PRESENT	0
445590	443872	14239U	PARTICIPANT	\N	PRESENT	0
445591	443873	14239U	PARTICIPANT	\N	PRESENT	0
445702	428544	14097Y	PARTICIPANT	\N	PRESENT	0
445739	441747	19659J	PARTICIPANT	\N	EXCUSE	0
445740	441747	14097Y	PARTICIPANT	\N	PRESENT	0
445741	441747	14219Q	PARTICIPANT	\N	PRESENT	0
445742	441747	14059S	PARTICIPANT	\N	PRESENT	0
445743	441747	08019V	PRESIDENT	0	PRESENT	0
445744	441747	14157T	PARTICIPANT	\N	PRESENT	0
445745	441747	19301E	PARTICIPANT	\N	PRESENT	0
445746	441747	19319Q	PARTICIPANT	\N	PRESENT	0
445747	441747	11072N	PARTICIPANT	\N	PRESENT	0
445748	441747	04043D	PARTICIPANT	\N	EXCUSE	0
445750	441747	14275Y	PARTICIPANT	\N	PRESENT	0
445756	441792	11101A	PARTICIPANT	\N	PRESENT	0
445757	441792	19253P	PARTICIPANT	\N	PRESENT	0
445758	441792	14231L	PARTICIPANT	\N	PRESENT	0
445759	441792	14281W	PARTICIPANT	\N	PRESENT	0
445760	441792	01057W	PARTICIPANT	\N	PRESENT	0
445761	441792	11048N	PARTICIPANT	\N	PRESENT	0
445762	441792	04086Q	PARTICIPANT	\N	PRESENT	0
445763	441792	14327T	PARTICIPANT	\N	PRESENT	0
445764	441792	14257W	PARTICIPANT	\N	PRESENT	0
445765	441792	05012A	PARTICIPANT	\N	PRESENT	0
445766	441792	04045F	PARTICIPANT	\N	PRESENT	0
445767	441792	95067Q	PARTICIPANT	\N	PRESENT	0
445768	439811	04086Q	PARTICIPANT	\N	PRESENT	0
445771	445770	19515S	PARTICIPANT	\N	PRESENT	0
445772	445770	19812Y	PARTICIPANT	\N	PRESENT	0
445774	445773	19515S	PARTICIPANT	\N	PRESENT	0
445775	445773	19812Y	PARTICIPANT	\N	PRESENT	0
445777	445776	19515S	PARTICIPANT	\N	PRESENT	0
445778	445776	19812Y	PARTICIPANT	\N	PRESENT	0
445779	445776	04049K	PARTICIPANT	\N	PRESENT	0
445781	445780	11115U	PARTICIPANT	\N	PRESENT	0
445782	445780	19721W	PARTICIPANT	\N	PRESENT	0
445785	445783	19515S	PARTICIPANT	\N	PRESENT	0
445786	445783	19812Y	PARTICIPANT	\N	PRESENT	0
445787	445784	14053L	PARTICIPANT	\N	PRESENT	0
445788	445784	19521Q	PARTICIPANT	\N	PRESENT	0
445789	445784	14255U	PARTICIPANT	\N	PRESENT	0
445790	445784	04088S	PARTICIPANT	\N	PRESENT	0
445791	445784	14061L	PARTICIPANT	\N	PRESENT	0
445792	445784	14087W	PARTICIPANT	\N	PRESENT	0
445793	445784	08047A	PARTICIPANT	\N	PRESENT	0
445794	445784	16685X	PARTICIPANT	\N	PRESENT	0
445795	445784	14329V	PARTICIPANT	\N	PRESENT	0
445796	445784	19671E	PARTICIPANT	\N	PRESENT	0
445797	445784	14083S	PARTICIPANT	\N	PRESENT	0
445798	445784	14079W	PARTICIPANT	\N	PRESENT	0
445799	445784	14026U	PARTICIPANT	\N	PRESENT	0
445800	445784	04049K	PRESIDENT	0	PRESENT	0
445803	445801	08019V	PARTICIPANT	\N	PRESENT	0
445804	445802	14257W	PARTICIPANT	\N	PRESENT	0
445805	445802	19768N	PARTICIPANT	\N	PRESENT	0
424935	424934	08018U	PARTICIPANT	\N	PRESENT	0
424994	424992	08039A	PARTICIPANT	\N	PRESENT	0
424995	424992	19611R	PARTICIPANT	\N	PRESENT	0
424996	424993	08039A	PARTICIPANT	\N	PRESENT	0
424998	424997	19631V	PARTICIPANT	\N	PRESENT	0
424999	424997	14038Y	PARTICIPANT	\N	PRESENT	0
425000	424997	08049C	PARTICIPANT	\N	PRESENT	0
425001	424997	14083S	PARTICIPANT	\N	PRESENT	0
425002	424997	14026U	PARTICIPANT	\N	PRESENT	0
437171	436943	04008A	PARTICIPANT	\N	PRESENT	0
437172	436943	14089Y	PARTICIPANT	\N	PRESENT	0
441723	441722	19515S	PARTICIPANT	\N	PRESENT	0
441724	441722	19511N	PARTICIPANT	\N	PRESENT	0
441725	441722	19812Y	PARTICIPANT	\N	PRESENT	0
441726	441722	04049K	PARTICIPANT	\N	PRESENT	0
441728	441727	19515S	PARTICIPANT	\N	PRESENT	0
441729	441727	19511N	PARTICIPANT	\N	PRESENT	0
441730	441727	19812Y	PARTICIPANT	\N	PRESENT	0
441733	441732	19569H	PARTICIPANT	\N	PRESENT	0
441735	441734	19569H	PARTICIPANT	\N	PRESENT	0
441736	441734	19447X	PARTICIPANT	\N	PRESENT	0
441737	441734	19683J	PARTICIPANT	\N	PRESENT	0
441738	441734	14213J	PARTICIPANT	\N	PRESENT	0
441739	441734	04092N	PARTICIPANT	\N	PRESENT	0
443677	441792	19735D	PARTICIPANT	\N	EXCUSE	0
443678	441792	04040A	PARTICIPANT	\N	EXCUSE	0
443679	441792	14259Y	PRESIDENT	0	PRESENT	0
444444	443681	04088S	PARTICIPANT	\N	PRESENT	0
444445	443681	14115H	PARTICIPANT	\N	PRESENT	0
444446	443681	11101A	PARTICIPANT	\N	PRESENT	0
444447	443681	19507S	PARTICIPANT	\N	PRESENT	0
444448	443681	19747H	PARTICIPANT	\N	PRESENT	0
444449	443681	14207L	PARTICIPANT	\N	PRESENT	0
444450	443681	08015R	PARTICIPANT	\N	EXCUSE	0
444451	443681	11081P	PARTICIPANT	\N	EXCUSE	0
444452	443681	19631V	PARTICIPANT	\N	EXCUSE	0
444453	443681	14265W	PARTICIPANT	\N	EXCUSE	0
444454	443807	19593H	PARTICIPANT	\N	PRESENT	0
444455	443807	04070G	PRESIDENT	0	PRESENT	0
444456	443807	14061L	PARTICIPANT	\N	PRESENT	0
444457	443807	04059M	PARTICIPANT	\N	PRESENT	0
444458	443807	11104D	PARTICIPANT	\N	PRESENT	0
444459	443807	19693L	PARTICIPANT	\N	PRESENT	0
444460	443807	19399H	PARTICIPANT	\N	PRESENT	0
444461	443807	87003B	PARTICIPANT	\N	PRESENT	0
444462	443807	04018C	PARTICIPANT	\N	PRESENT	0
444463	443807	19758L	PARTICIPANT	\N	PRESENT	0
444464	443807	19621T	PARTICIPANT	\N	PRESENT	0
444465	443807	14030Q	PARTICIPANT	\N	PRESENT	0
444466	443681	14205J	PARTICIPANT	\N	PRESENT	0
444467	443681	19619A	PARTICIPANT	\N	PRESENT	0
444468	443682	95030B	PARTICIPANT	\N	PRESENT	0
444469	443682	19421M	PARTICIPANT	\N	PRESENT	0
444470	443682	08053X	PARTICIPANT	\N	PRESENT	0
444471	443682	14193X	PARTICIPANT	\N	PRESENT	0
444473	443807	19699S	PARTICIPANT	\N	PRESENT	0
444474	443807	19533U	PARTICIPANT	\N	PRESENT	0
444475	443807	14229S	PARTICIPANT	\N	PRESENT	0
444476	443807	19573D	PARTICIPANT	\N	PRESENT	0
444477	443807	08017T	PARTICIPANT	\N	PRESENT	0
444478	443807	08012N	PARTICIPANT	\N	PRESENT	0
444479	443807	08031R	PARTICIPANT	\N	PRESENT	0
444480	443807	14059S	PARTICIPANT	\N	PRESENT	0
444481	443807	04057K	PARTICIPANT	\N	PRESENT	0
444482	443807	19611R	PARTICIPANT	\N	PRESENT	0
444483	443807	08043V	PARTICIPANT	\N	PRESENT	0
444484	443807	19735D	PARTICIPANT	\N	PRESENT	0
444485	443807	14109K	PARTICIPANT	\N	PRESENT	0
444546	443682	95067Q	PARTICIPANT	\N	PRESENT	0
444547	443682	11064N	PARTICIPANT	\N	PRESENT	0
444548	444388	19697Q	PARTICIPANT	\N	PRESENT	0
444549	444388	11067R	PARTICIPANT	\N	PRESENT	0
444550	444388	19565D	PARTICIPANT	\N	PRESENT	0
444551	444388	19798U	PARTICIPANT	\N	PRESENT	0
444552	444388	11097X	PARTICIPANT	\N	PRESENT	0
444553	444388	19415P	PARTICIPANT	\N	PRESENT	0
444554	444388	14223L	PARTICIPANT	\N	PRESENT	0
444555	444388	04045F	PARTICIPANT	\N	PRESENT	0
444556	444388	14026U	PARTICIPANT	\N	PRESENT	0
444557	444388	14227Q	PARTICIPANT	\N	PRESENT	0
444558	444388	17779H	PARTICIPANT	\N	PRESENT	0
444559	444388	19553Y	PARTICIPANT	\N	PRESENT	0
444560	444388	19703U	PARTICIPANT	\N	PRESENT	0
444561	444388	14087W	PARTICIPANT	\N	PRESENT	0
444562	444388	14281W	PARTICIPANT	\N	PRESENT	0
444563	444388	19679N	PARTICIPANT	\N	PRESENT	0
444564	444388	14042U	PARTICIPANT	\N	PRESENT	0
444565	444388	19575F	PARTICIPANT	\N	PRESENT	0
444566	444388	08048B	PARTICIPANT	\N	PRESENT	0
444567	444388	14195A	PARTICIPANT	\N	PRESENT	0
444568	444388	19367Y	PARTICIPANT	\N	PRESENT	0
444569	444388	14213J	PARTICIPANT	\N	PRESENT	0
444570	444388	14261S	PARTICIPANT	\N	PRESENT	0
444571	444388	14217N	PARTICIPANT	\N	PRESENT	0
444572	444388	10006L	PARTICIPANT	\N	PRESENT	0
444573	444388	19683J	PARTICIPANT	\N	PRESENT	0
444574	444388	98024R	PARTICIPANT	\N	PRESENT	0
444575	444388	19521Q	PARTICIPANT	\N	PRESENT	0
444576	444388	19527W	PARTICIPANT	\N	PRESENT	0
444577	444388	01034P	PARTICIPANT	\N	PRESENT	0
444578	444388	04092N	PRESIDENT	0	PRESENT	0
444579	444388	11045K	PARTICIPANT	\N	PRESENT	0
444580	444388	08052W	PARTICIPANT	\N	PRESENT	0
444581	444388	19301E	PARTICIPANT	\N	PRESENT	0
444582	444388	19691J	PARTICIPANT	\N	PRESENT	0
444583	444388	19717B	PARTICIPANT	\N	PRESENT	0
444584	444388	19723Y	PARTICIPANT	\N	PRESENT	0
444585	444388	19727D	PARTICIPANT	\N	PRESENT	0
444586	444388	14119M	PARTICIPANT	\N	PRESENT	0
444587	444388	11103C	PARTICIPANT	\N	PRESENT	0
444588	444388	19657G	PARTICIPANT	\N	PRESENT	0
444589	444388	14071N	PARTICIPANT	\N	PRESENT	0
444590	444388	19760E	PARTICIPANT	\N	PRESENT	0
444591	444388	14355X	PARTICIPANT	\N	EXCUSE	0
444592	444388	08041T	PARTICIPANT	\N	EXCUSE	0
444593	443805	01060R	PARTICIPANT	\N	PRESENT	0
444594	443805	04047H	PARTICIPANT	\N	PRESENT	0
444595	443805	19673G	PARTICIPANT	\N	PRESENT	0
444596	443805	19675J	PARTICIPANT	\N	PRESENT	0
444597	443805	01028R	PARTICIPANT	\N	PRESENT	0
444598	443805	14231L	PARTICIPANT	\N	PRESENT	0
444599	443805	19447X	PARTICIPANT	\N	PRESENT	0
444600	443805	05008E	PRESIDENT	0	PRESENT	0
444601	443805	14275Y	PARTICIPANT	\N	PRESENT	0
444602	443805	14179A	PARTICIPANT	\N	PRESENT	0
444603	443805	14147R	PARTICIPANT	\N	PRESENT	0
444604	443805	14151M	PARTICIPANT	\N	PRESENT	0
444605	443805	14259Y	PARTICIPANT	\N	PRESENT	0
444606	443805	11072N	PARTICIPANT	\N	PRESENT	0
444607	443805	14053L	PARTICIPANT	\N	PRESENT	0
444608	443805	98035U	PARTICIPANT	\N	PRESENT	0
444609	443805	14111D	PARTICIPANT	\N	PRESENT	0
444610	443805	14065Q	PARTICIPANT	\N	PRESENT	0
444611	443805	19649G	PARTICIPANT	\N	PRESENT	0
444612	443805	10015M	PARTICIPANT	\N	PRESENT	0
444613	443805	11026G	PARTICIPANT	\N	PRESENT	0
444614	443805	19253P	PARTICIPANT	\N	PRESENT	0
444615	443805	01024M	PARTICIPANT	\N	PRESENT	0
444616	443805	04038G	PARTICIPANT	\N	PRESENT	0
444617	443805	14089Y	PARTICIPANT	\N	PRESENT	0
444618	443805	19725B	PARTICIPANT	\N	PRESENT	0
444619	443805	19729F	PARTICIPANT	\N	PRESENT	0
444620	443805	19629C	PARTICIPANT	\N	PRESENT	0
444621	443805	14069U	PARTICIPANT	\N	PRESENT	0
444622	443805	11085T	PARTICIPANT	\N	PRESENT	0
444623	443805	11049P	PARTICIPANT	\N	PRESENT	0
444624	443805	14021P	PARTICIPANT	\N	PRESENT	0
444625	443805	19762G	PARTICIPANT	\N	PRESENT	0
444626	443805	04044E	PARTICIPANT	\N	EXCUSE	0
444627	443805	19585H	PARTICIPANT	\N	EXCUSE	0
444628	443676	04071H	PARTICIPANT	\N	PRESENT	0
444629	443676	01057W	PARTICIPANT	\N	PRESENT	0
444630	443676	19667J	PARTICIPANT	\N	PRESENT	0
444631	443676	89017R	PARTICIPANT	\N	PRESENT	0
444632	443676	11074Q	PRESIDENT	0	PRESENT	0
444633	443676	14225N	PARTICIPANT	\N	PRESENT	0
444634	443676	19671E	PARTICIPANT	\N	PRESENT	0
444635	443676	88008L	PARTICIPANT	\N	PRESENT	0
444636	443676	07029T	PARTICIPANT	\N	PRESENT	0
444637	443676	14085U	PARTICIPANT	\N	PRESENT	0
444638	443676	14277B	PARTICIPANT	\N	PRESENT	0
444639	443676	96004D	PARTICIPANT	\N	PRESENT	0
444640	443676	19349W	PARTICIPANT	\N	PRESENT	0
444641	443676	08010L	PARTICIPANT	\N	PRESENT	0
444642	443676	14253S	PARTICIPANT	\N	PRESENT	0
444643	443676	11048N	PARTICIPANT	\N	PRESENT	0
444644	443676	19479G	PARTICIPANT	\N	PRESENT	0
444645	443676	19711U	PARTICIPANT	\N	PRESENT	0
444646	443676	19531S	PARTICIPANT	\N	PRESENT	0
430711	424868	08069G	PARTICIPANT	\N	PRESENT	0
430712	424868	96004D	PARTICIPANT	\N	PRESENT	0
430713	424868	19467C	PARTICIPANT	\N	PRESENT	0
430714	424868	08034U	PARTICIPANT	\N	PRESENT	0
430715	424868	14219Q	PARTICIPANT	\N	PRESENT	0
430716	424868	07029T	PARTICIPANT	\N	PRESENT	0
430717	424868	19689Q	PARTICIPANT	\N	PRESENT	0
430718	424868	89017R	PARTICIPANT	\N	PRESENT	0
430719	424868	19479G	PARTICIPANT	\N	PRESENT	0
430720	424868	19782L	PARTICIPANT	\N	PRESENT	0
430721	424868	19619A	PARTICIPANT	\N	PRESENT	0
430722	424868	19671E	PARTICIPANT	\N	PRESENT	0
430723	424868	04071H	PARTICIPANT	\N	PRESENT	0
430724	424868	19667J	PARTICIPANT	\N	PRESENT	0
430725	424868	19533U	PARTICIPANT	\N	PRESENT	0
430726	424868	04043D	PARTICIPANT	\N	PRESENT	0
430727	424868	19527W	PARTICIPANT	\N	PRESENT	0
430743	424868	01058X	PARTICIPANT	\N	PRESENT	0
430744	424868	14109K	PARTICIPANT	\N	PRESENT	0
430745	424868	08073C	PARTICIPANT	\N	PRESENT	0
430746	424868	14265W	PARTICIPANT	\N	PRESENT	0
430747	424868	17589D	PARTICIPANT	\N	PRESENT	0
430748	424868	19715Y	PARTICIPANT	\N	PRESENT	0
430749	424868	14159V	PARTICIPANT	\N	PRESENT	0
430750	424868	14105F	PARTICIPANT	\N	PRESENT	0
430751	424868	04042C	PARTICIPANT	\N	PRESENT	0
430752	424868	12016W	PARTICIPANT	\N	PRESENT	0
430753	424868	08024S	PARTICIPANT	\N	PRESENT	0
430754	424868	11010L	PARTICIPANT	\N	PRESENT	0
430755	424868	14357A	PARTICIPANT	\N	PRESENT	0
430756	424868	19531S	PARTICIPANT	\N	PRESENT	0
430757	424868	19543W	PARTICIPANT	\N	PRESENT	0
430758	424868	19725B	PARTICIPANT	\N	PRESENT	0
430762	424868	14151M	PARTICIPANT	\N	PRESENT	0
430764	424868	19335Q	PARTICIPANT	\N	PRESENT	0
430778	424868	08020N	PARTICIPANT	\N	PRESENT	0
430779	428236	08060W	PARTICIPANT	\N	PRESENT	0
430780	428236	08009T	PRESIDENT	0	PRESENT	0
430781	428236	19367Y	PARTICIPANT	\N	PRESENT	0
430782	428236	19251M	PARTICIPANT	\N	PRESENT	0
430783	428236	14033T	PARTICIPANT	\N	PRESENT	0
430784	428236	08024S	PARTICIPANT	\N	PRESENT	0
430785	428236	19758L	PARTICIPANT	\N	PRESENT	0
430786	428236	11065P	PARTICIPANT	\N	PRESENT	0
430787	428236	14053L	PARTICIPANT	\N	EXCUSE	0
430788	428236	11048N	PARTICIPANT	\N	EXCUSE	0
430789	428236	14051J	PARTICIPANT	\N	EXCUSE	0
430790	428236	19826F	PARTICIPANT	\N	EXCUSE	0
430791	428236	14026U	PARTICIPANT	\N	EXCUSE	0
430792	424868	19733B	PARTICIPANT	\N	PRESENT	0
430793	424868	08055A	PARTICIPANT	\N	PRESENT	0
430794	424868	19583F	PARTICIPANT	\N	PRESENT	0
430795	424868	19739H	PARTICIPANT	\N	PRESENT	0
430796	424868	14069U	PARTICIPANT	\N	PRESENT	0
430797	424868	14251Q	PARTICIPANT	\N	PRESENT	0
430798	424868	95030B	PARTICIPANT	\N	PRESENT	0
430812	424868	04057K	PARTICIPANT	\N	PRESENT	0
430813	424868	11097X	PARTICIPANT	\N	PRESENT	0
430815	424868	05012A	PARTICIPANT	\N	PRESENT	0
430818	424868	08043V	PARTICIPANT	\N	PRESENT	0
430819	424868	14083S	PARTICIPANT	\N	PRESENT	0
430822	424868	19643A	PARTICIPANT	\N	PRESENT	0
430823	428236	04070G	PARTICIPANT	\N	PRESENT	0
430824	424868	14331P	PARTICIPANT	\N	PRESENT	0
430825	424868	11043H	PARTICIPANT	\N	PRESENT	0
430826	424868	08017T	PARTICIPANT	\N	PRESENT	0
430827	424868	11054L	PARTICIPANT	\N	PRESENT	0
430828	424868	08056B	PARTICIPANT	\N	PRESENT	0
430829	424868	19253P	PARTICIPANT	\N	PRESENT	0
430830	424868	19683J	PARTICIPANT	\N	PRESENT	0
430833	424868	14034U	PARTICIPANT	\N	PRESENT	0
430834	424868	14275Y	PARTICIPANT	\N	PRESENT	0
430835	424868	19691J	PARTICIPANT	\N	PRESENT	0
430839	424868	98035U	PARTICIPANT	\N	PRESENT	0
430840	424868	11083R	PARTICIPANT	\N	PRESENT	0
430841	424868	08015R	PARTICIPANT	\N	PRESENT	0
430842	424868	11012A	PARTICIPANT	\N	PRESENT	0
430846	424870	01043Q	PARTICIPANT	\N	PRESENT	0
430847	424870	08011M	PARTICIPANT	\N	PRESENT	0
430848	424870	11074Q	PARTICIPANT	\N	PRESENT	0
430849	424870	19651A	PARTICIPANT	\N	PRESENT	0
430850	424870	11048N	PARTICIPANT	\N	PRESENT	0
430851	424870	14021P	PARTICIPANT	\N	PRESENT	0
430852	424870	11040E	PARTICIPANT	\N	PRESENT	0
430853	424870	19647E	PARTICIPANT	\N	PRESENT	0
430854	424870	19687N	PARTICIPANT	\N	PRESENT	0
430855	424870	88008L	PARTICIPANT	\N	PRESENT	0
430856	424870	08010L	PARTICIPANT	\N	PRESENT	0
430857	424870	14089Y	PARTICIPANT	\N	PRESENT	0
430858	424870	07004J	PARTICIPANT	\N	PRESENT	0
430859	424870	19711U	PARTICIPANT	\N	PRESENT	0
430860	424870	19693L	PARTICIPANT	\N	PRESENT	0
430861	424870	01057W	PARTICIPANT	\N	PRESENT	0
430862	424870	19443T	PARTICIPANT	\N	PRESENT	0
430863	424870	19741B	PARTICIPANT	\N	PRESENT	0
430864	424870	19301E	PARTICIPANT	\N	PRESENT	0
430865	424870	04033B	PARTICIPANT	\N	PRESENT	0
430866	424870	96004D	PARTICIPANT	\N	PRESENT	0
430867	424870	08034U	PARTICIPANT	\N	PRESENT	0
430868	424870	07029T	PARTICIPANT	\N	PRESENT	0
430869	424870	19479G	PARTICIPANT	\N	PRESENT	0
430870	424870	04071H	PARTICIPANT	\N	PRESENT	0
430871	424870	19715Y	PARTICIPANT	\N	PRESENT	0
430872	424870	12016W	PARTICIPANT	\N	PRESENT	0
430873	424870	19531S	PARTICIPANT	\N	PRESENT	0
430874	424870	14251Q	PARTICIPANT	\N	PRESENT	0
430875	424870	04057K	PARTICIPANT	\N	PRESENT	0
430876	424870	14083S	PARTICIPANT	\N	PRESENT	0
430877	424870	19643A	PARTICIPANT	\N	PRESENT	0
430878	424870	14331P	PARTICIPANT	\N	PRESENT	0
430879	424870	11043H	PARTICIPANT	\N	PRESENT	0
430880	424870	08017T	PARTICIPANT	\N	PRESENT	0
430881	424870	14034U	PARTICIPANT	\N	PRESENT	0
430882	424870	14275Y	PARTICIPANT	\N	PRESENT	0
430883	424870	19691J	PARTICIPANT	\N	PRESENT	0
430884	424870	98035U	PARTICIPANT	\N	PRESENT	0
430885	424870	11083R	PARTICIPANT	\N	PRESENT	0
430886	424870	08015R	PARTICIPANT	\N	PRESENT	0
430887	424870	11012A	PARTICIPANT	\N	PRESENT	0
430932	424869	14085U	PARTICIPANT	\N	PRESENT	0
430933	424869	11040E	PARTICIPANT	\N	PRESENT	0
430934	424869	12016W	PARTICIPANT	\N	PRESENT	0
430935	424869	19647E	PARTICIPANT	\N	PRESENT	0
430936	424869	98035U	PARTICIPANT	\N	PRESENT	0
430937	424869	19301E	PARTICIPANT	\N	PRESENT	0
430938	424869	11083R	PARTICIPANT	\N	PRESENT	0
430939	424869	19651A	PARTICIPANT	\N	PRESENT	0
430940	424869	04057K	PARTICIPANT	\N	PRESENT	0
430941	424869	19479G	PARTICIPANT	\N	PRESENT	0
430942	424869	19691J	PARTICIPANT	\N	PRESENT	0
430943	424869	14089Y	PARTICIPANT	\N	PRESENT	0
430944	424869	14331P	PARTICIPANT	\N	PRESENT	0
430945	424869	14357A	PARTICIPANT	\N	PRESENT	0
430946	424869	08034U	PARTICIPANT	\N	PRESENT	0
430947	424869	08010L	PARTICIPANT	\N	PRESENT	0
430948	424869	19711U	PARTICIPANT	\N	PRESENT	0
430949	424869	19693L	PARTICIPANT	\N	PRESENT	0
430950	424869	07029T	PARTICIPANT	\N	PRESENT	0
430951	424869	01057W	PARTICIPANT	\N	PRESENT	0
430952	424869	19667J	PARTICIPANT	\N	PRESENT	0
430953	424869	04071H	PARTICIPANT	\N	PRESENT	0
430954	424869	19531S	PARTICIPANT	\N	PRESENT	0
430955	424869	96004D	PARTICIPANT	\N	PRESENT	0
430956	424869	88008L	PARTICIPANT	\N	PRESENT	0
430957	424869	11012A	PARTICIPANT	\N	PRESENT	0
430958	424869	04085P	PARTICIPANT	\N	PRESENT	0
430959	424869	19593H	PARTICIPANT	\N	PRESENT	0
430960	424869	19741B	PARTICIPANT	\N	PRESENT	0
430962	424869	19687N	PARTICIPANT	\N	PRESENT	0
430963	424869	11074Q	PARTICIPANT	\N	PRESENT	0
430964	424869	19533U	PARTICIPANT	\N	PRESENT	0
430965	424869	01028R	PARTICIPANT	\N	PRESENT	0
430966	424869	14069U	PARTICIPANT	\N	PRESENT	0
430967	424869	14083S	PARTICIPANT	\N	PRESENT	0
431167	424873	11027H	PARTICIPANT	\N	PRESENT	0
431168	424873	19741B	PARTICIPANT	\N	PRESENT	0
431169	424873	08019V	PARTICIPANT	\N	PRESENT	0
431170	424873	01057W	PARTICIPANT	\N	PRESENT	0
431171	424873	96004D	PARTICIPANT	\N	PRESENT	0
431172	424873	14225N	PARTICIPANT	\N	PRESENT	0
431173	424873	11040E	PARTICIPANT	\N	PRESENT	0
430930	424869	14034U	PARTICIPANT	\N	PRESENT	0
430931	424869	12041X	PARTICIPANT	\N	PRESENT	0
431174	424873	04085P	PARTICIPANT	\N	PRESENT	0
431175	424873	08011M	PARTICIPANT	\N	PRESENT	0
431176	424873	11074Q	PARTICIPANT	\N	PRESENT	0
431177	424873	95063L	PARTICIPANT	\N	PRESENT	0
431178	424873	99004R	PARTICIPANT	\N	PRESENT	0
431179	424873	11070L	PARTICIPANT	\N	PRESENT	0
428371	428370	11054L	PARTICIPANT	\N	PRESENT	0
431454	431452	80013X	PARTICIPANT	\N	PRESENT	0
438616	438614	14257W	PARTICIPANT	\N	PRESENT	0
438617	438614	19768N	PARTICIPANT	\N	PRESENT	0
438655	438613	14257W	PARTICIPANT	\N	PRESENT	0
445115	439808	11053K	PARTICIPANT	\N	PRESENT	0
445121	445120	96004D	PRESIDENT	0	PRESENT	0
445122	445120	14089Y	PARTICIPANT	\N	PRESENT	0
445123	445120	14079W	PARTICIPANT	\N	PRESENT	0
445124	445120	11083R	PARTICIPANT	\N	PRESENT	0
445125	445120	14026U	PARTICIPANT	\N	PRESENT	0
445126	445120	19725B	PARTICIPANT	\N	PRESENT	0
445127	445120	19569H	PARTICIPANT	\N	PRESENT	0
445128	445120	04097T	PARTICIPANT	\N	PRESENT	0
445129	445120	14097Y	PARTICIPANT	\N	PRESENT	0
445130	445120	14073Q	PARTICIPANT	\N	PRESENT	0
445131	445120	11026G	PARTICIPANT	\N	PRESENT	0
445132	445120	04057K	PARTICIPANT	\N	EXCUSE	0
445133	445120	10015M	PARTICIPANT	\N	PRESENT	0
445134	445120	98035U	PARTICIPANT	\N	PRESENT	0
445135	445120	14237S	PARTICIPANT	\N	PRESENT	0
445462	439809	04059M	PARTICIPANT	\N	PRESENT	0
445463	443733	19383Y	PARTICIPANT	\N	PRESENT	0
445464	443733	19333N	PARTICIPANT	\N	PRESENT	0
445465	443733	17583W	PARTICIPANT	\N	PRESENT	0
445466	443733	19701S	PARTICIPANT	\N	PRESENT	0
445467	443733	19794Q	PARTICIPANT	\N	PRESENT	0
445468	443733	19549D	PARTICIPANT	\N	PRESENT	0
445469	443733	04069P	PARTICIPANT	\N	PRESENT	0
445470	443733	19387D	PARTICIPANT	\N	PRESENT	0
445471	443733	19820Y	PARTICIPANT	\N	PRESENT	0
445472	443733	14219Q	PARTICIPANT	\N	PRESENT	0
445473	443733	19826F	PARTICIPANT	\N	PRESENT	0
445474	443733	19599P	PARTICIPANT	\N	PRESENT	0
445475	443733	19637C	PARTICIPANT	\N	PRESENT	0
445476	443733	18083K	PARTICIPANT	\N	PRESENT	0
445477	443733	14237S	PARTICIPANT	\N	PRESENT	0
445478	443733	19551W	PARTICIPANT	\N	PRESENT	0
445479	443733	14051J	PARTICIPANT	\N	PRESENT	0
445480	443733	08060W	PARTICIPANT	\N	PRESENT	0
445481	443733	19503N	PARTICIPANT	\N	PRESENT	0
445482	443733	19347U	PARTICIPANT	\N	PRESENT	0
445483	443733	14157T	PARTICIPANT	\N	PRESENT	0
445484	443733	19685L	PARTICIPANT	\N	PRESENT	0
445485	443733	19681G	PARTICIPANT	\N	PRESENT	0
445486	443733	08024S	PARTICIPANT	\N	PRESENT	0
445487	443733	11065P	PARTICIPANT	\N	PRESENT	0
445488	443733	17637T	PARTICIPANT	\N	PRESENT	0
445489	443733	19525U	PARTICIPANT	\N	PRESENT	0
445490	443733	14038Y	PARTICIPANT	\N	PRESENT	0
445491	443733	14103D	PARTICIPANT	\N	PRESENT	0
445492	443733	14031R	PARTICIPANT	\N	PRESENT	0
445493	443733	08055A	PARTICIPANT	\N	PRESENT	0
445494	443733	15447F	PARTICIPANT	\N	PRESENT	0
445495	443733	14093U	PARTICIPANT	\N	PRESENT	0
445496	443733	19739H	PARTICIPANT	\N	PRESENT	0
445497	443733	19659J	PARTICIPANT	\N	PRESENT	0
445498	443733	04097T	PARTICIPANT	\N	PRESENT	0
445499	439809	14051J	PARTICIPANT	\N	PRESENT	0
445500	439809	11048N	PARTICIPANT	\N	PRESENT	0
445501	443733	08009T	PARTICIPANT	\N	EXCUSE	0
445502	439809	12016W	PARTICIPANT	\N	PRESENT	0
445503	439809	19347U	PARTICIPANT	\N	PRESENT	0
445504	439809	19295A	PARTICIPANT	\N	PRESENT	0
445505	439809	19551W	PARTICIPANT	\N	PRESENT	0
445506	439809	19333N	PARTICIPANT	\N	PRESENT	0
445507	439809	14081Q	PARTICIPANT	\N	PRESENT	0
445508	439809	19549D	PARTICIPANT	\N	PRESENT	0
445509	439809	11040E	PARTICIPANT	\N	PRESENT	0
445510	439809	19651A	PARTICIPANT	\N	PRESENT	0
445511	439809	19637C	PARTICIPANT	\N	PRESENT	0
445512	439809	14207L	PARTICIPANT	\N	PRESENT	0
445513	439809	17589D	PARTICIPANT	\N	PRESENT	0
445514	439809	14197C	PARTICIPANT	\N	PRESENT	0
445515	439809	19583F	PARTICIPANT	\N	PRESENT	0
445516	439809	19479G	PARTICIPANT	\N	PRESENT	0
445517	439809	19739H	PARTICIPANT	\N	PRESENT	0
445518	439809	19737F	PARTICIPANT	\N	PRESENT	0
445519	439809	08038Y	PARTICIPANT	\N	PRESENT	0
445520	439809	19629C	PARTICIPANT	\N	PRESENT	0
445521	439809	08045X	PARTICIPANT	\N	PRESENT	0
445522	439809	14261S	PARTICIPANT	\N	PRESENT	0
445523	439809	01024M	PARTICIPANT	\N	PRESENT	0
445524	439809	14059S	PARTICIPANT	\N	PRESENT	0
445525	439809	19533U	PARTICIPANT	\N	PRESENT	0
445526	439809	19711U	PARTICIPANT	\N	PRESENT	0
445527	439809	14157T	PARTICIPANT	\N	PRESENT	0
445528	439809	14031R	PARTICIPANT	\N	PRESENT	0
445529	439809	14038Y	PARTICIPANT	\N	PRESENT	0
445530	439809	19507S	PARTICIPANT	\N	PRESENT	0
445531	439809	19727D	PARTICIPANT	\N	PRESENT	0
445532	439809	19503N	PARTICIPANT	\N	PRESENT	0
445533	439809	08055A	PARTICIPANT	\N	PRESENT	0
445534	439809	14097Y	PARTICIPANT	\N	PRESENT	0
445535	439809	14173T	PARTICIPANT	\N	PRESENT	0
445536	439809	08009T	PARTICIPANT	\N	PRESENT	0
445537	439809	01058X	PARTICIPANT	\N	PRESENT	0
445538	439809	14187A	PARTICIPANT	\N	PRESENT	0
445539	439809	19413M	PARTICIPANT	\N	PRESENT	0
445540	439809	95030B	PARTICIPANT	\N	PRESENT	0
445541	439809	08060W	PARTICIPANT	\N	PRESENT	0
445542	439809	18083K	PARTICIPANT	\N	PRESENT	0
445543	439809	19525U	PARTICIPANT	\N	PRESENT	0
445544	439809	08043V	PARTICIPANT	\N	PRESENT	0
445545	439809	19747H	PARTICIPANT	\N	PRESENT	0
445546	439809	19713W	PARTICIPANT	\N	PRESENT	0
445547	439809	19441R	PARTICIPANT	\N	PRESENT	0
445548	439809	19826F	PARTICIPANT	\N	PRESENT	0
445549	439809	19681G	PARTICIPANT	\N	PRESENT	0
445550	439809	14021P	PARTICIPANT	\N	PRESENT	0
445551	439809	92040Q	PARTICIPANT	\N	PRESENT	0
445552	439809	04088S	PARTICIPANT	\N	PRESENT	0
445553	439809	11101A	PARTICIPANT	\N	PRESENT	0
445554	439809	19671E	PARTICIPANT	\N	PRESENT	0
445555	439809	19820Y	PARTICIPANT	\N	PRESENT	0
445556	439809	14169X	PARTICIPANT	\N	PRESENT	0
445557	439809	14042U	PARTICIPANT	\N	PRESENT	0
445558	439809	14151M	PARTICIPANT	\N	PRESENT	0
445559	439809	97011G	PARTICIPANT	\N	PRESENT	0
445560	439809	14071N	PARTICIPANT	\N	PRESENT	0
445561	439809	14069U	PARTICIPANT	\N	PRESENT	0
445562	439809	14219Q	PARTICIPANT	\N	PRESENT	0
445563	439809	11065P	PARTICIPANT	\N	PRESENT	0
445564	439809	19687N	PARTICIPANT	\N	PRESENT	0
445565	439809	19593H	PARTICIPANT	\N	PRESENT	0
445566	439809	19782L	PARTICIPANT	\N	PRESENT	0
445567	439809	19762G	PARTICIPANT	\N	PRESENT	0
445568	439809	19399H	PARTICIPANT	\N	PRESENT	0
445569	439809	19703U	PARTICIPANT	\N	PRESENT	0
445570	439809	19521Q	PARTICIPANT	\N	PRESENT	0
445571	439809	14083S	PARTICIPANT	\N	PRESENT	0
445572	439809	19697Q	PARTICIPANT	\N	PRESENT	0
445573	439809	19543W	PARTICIPANT	\N	PRESENT	0
445574	439809	19563B	PARTICIPANT	\N	PRESENT	0
445575	439809	19531S	PARTICIPANT	\N	PRESENT	0
445576	439809	19741B	PARTICIPANT	\N	PRESENT	0
445577	439809	14089Y	PARTICIPANT	\N	PRESENT	0
445580	439809	14053L	PARTICIPANT	\N	PRESENT	0
445581	439809	11012A	PARTICIPANT	\N	PRESENT	0
445582	439809	14259Y	PARTICIPANT	\N	PRESENT	0
445583	439809	19489J	PARTICIPANT	\N	PRESENT	0
445584	439809	19647E	PARTICIPANT	\N	PRESENT	0
445585	439809	14281W	PARTICIPANT	\N	PRESENT	0
445586	439809	11074Q	PARTICIPANT	\N	PRESENT	0
445587	439809	11067R	PARTICIPANT	\N	PRESENT	0
445589	439809	19657G	PARTICIPANT	\N	PRESENT	0
445593	439809	08010L	PARTICIPANT	\N	PRESENT	0
445596	439809	19443T	PARTICIPANT	\N	PRESENT	0
445597	439809	11097X	PARTICIPANT	\N	PRESENT	0
445598	439809	14251Q	PARTICIPANT	\N	PRESENT	0
445599	439809	04085P	PARTICIPANT	\N	PRESENT	0
445600	439809	19695N	PARTICIPANT	\N	PRESENT	0
445601	439809	17779H	PARTICIPANT	\N	PRESENT	0
445602	439809	14030Q	PARTICIPANT	\N	PRESENT	0
439643	435247	14261S	PARTICIPANT	\N	PRESENT	0
439644	435247	14030Q	PRESIDENT	0	PRESENT	0
439645	435247	08043V	PARTICIPANT	\N	PRESENT	0
439646	435247	18083K	PARTICIPANT	\N	PRESENT	0
439647	435247	19701S	PARTICIPANT	\N	PRESENT	0
439648	435247	80013X	PARTICIPANT	\N	PRESENT	0
439649	435247	19715Y	PARTICIPANT	\N	PRESENT	0
439650	435247	19731Y	PARTICIPANT	\N	PRESENT	0
439651	435247	11067R	PARTICIPANT	\N	EXCUSE	0
439652	435247	19691J	PARTICIPANT	\N	PRESENT	0
439653	435247	08019V	PARTICIPANT	\N	PRESENT	0
439654	435247	19319Q	PARTICIPANT	\N	PRESENT	0
439896	439895	11074Q	PARTICIPANT	\N	PRESENT	0
439897	439895	08011M	PARTICIPANT	\N	PRESENT	0
439899	439898	11074Q	PARTICIPANT	\N	PRESENT	0
441613	441311	14147R	PARTICIPANT	\N	PRESENT	0
441617	441616	14089Y	PARTICIPANT	\N	PRESENT	0
444488	443667	14327T	PARTICIPANT	\N	PRESENT	0
444489	443667	19545Y	PARTICIPANT	\N	PRESENT	0
444490	443667	01057W	PARTICIPANT	\N	PRESENT	0
444491	443667	11074Q	PRESIDENT	0	PRESENT	0
444492	443667	19667J	PARTICIPANT	\N	PRESENT	0
444493	443667	89017R	PARTICIPANT	\N	PRESENT	0
444494	443667	11070L	PARTICIPANT	\N	PRESENT	0
444495	443667	19671E	PARTICIPANT	\N	PRESENT	0
444496	443667	14225N	PARTICIPANT	\N	PRESENT	0
444497	443667	07029T	PARTICIPANT	\N	PRESENT	0
444498	443667	14277B	PARTICIPANT	\N	PRESENT	0
444499	443667	14085U	PARTICIPANT	\N	PRESENT	0
444500	443667	07004J	PARTICIPANT	\N	PRESENT	0
444501	443667	96004D	PARTICIPANT	\N	PRESENT	0
444502	443667	19349W	PARTICIPANT	\N	PRESENT	0
444503	443667	08010L	PARTICIPANT	\N	PRESENT	0
444504	443667	14253S	PARTICIPANT	\N	PRESENT	0
444505	443667	11048N	PARTICIPANT	\N	PRESENT	0
444506	443667	19479G	PARTICIPANT	\N	PRESENT	0
444507	443667	19711U	PARTICIPANT	\N	PRESENT	0
444508	443667	19651A	PARTICIPANT	\N	PRESENT	0
444509	443667	19531S	PARTICIPANT	\N	PRESENT	0
444510	443667	08069G	PARTICIPANT	\N	PRESENT	0
444511	443667	12016W	PARTICIPANT	\N	PRESENT	0
444512	443667	14159V	PARTICIPANT	\N	PRESENT	0
444513	443667	14173T	PARTICIPANT	\N	PRESENT	0
444514	443667	04086Q	PARTICIPANT	\N	PRESENT	0
444515	443667	11040E	PARTICIPANT	\N	PRESENT	0
444516	443667	14083S	PARTICIPANT	\N	PRESENT	0
444517	443667	14199E	PARTICIPANT	\N	PRESENT	0
444518	443667	11012A	PARTICIPANT	\N	PRESENT	0
444519	443667	19741B	PARTICIPANT	\N	PRESENT	0
444520	443667	99004R	PARTICIPANT	\N	PRESENT	0
444521	443667	14331P	PARTICIPANT	\N	PRESENT	0
444522	443667	08011M	PARTICIPANT	\N	PRESENT	0
444523	443807	19766L	PARTICIPANT	\N	PRESENT	0
444524	443807	08039A	PARTICIPANT	\N	PRESENT	0
444525	443807	19643A	PARTICIPANT	\N	PRESENT	0
444526	443807	08020N	PARTICIPANT	\N	PRESENT	0
444527	443807	11043H	PARTICIPANT	\N	PRESENT	0
444528	443807	14241N	PARTICIPANT	\N	EXCUSE	0
444529	443807	14073Q	PARTICIPANT	\N	EXCUSE	0
444534	443681	04043D	PARTICIPANT	\N	PRESENT	0
444535	443807	19335Q	PARTICIPANT	\N	PRESENT	0
444536	443807	11083R	PARTICIPANT	\N	PRESENT	0
444537	443681	19441R	PARTICIPANT	\N	PRESENT	0
444538	443807	14107H	PARTICIPANT	\N	PRESENT	0
444539	443807	14249W	PARTICIPANT	\N	PRESENT	0
444540	443807	19731Y	PARTICIPANT	\N	PRESENT	0
444707	443682	11115U	PARTICIPANT	\N	PRESENT	0
444793	439808	86034E	PARTICIPANT	\N	PRESENT	0
444800	439808	11040E	PARTICIPANT	\N	PRESENT	0
444801	439808	04085P	PARTICIPANT	\N	PRESENT	0
444802	439808	04038G	PARTICIPANT	\N	PRESENT	0
444803	439808	14211G	PARTICIPANT	\N	PRESENT	0
444804	439808	12041X	PARTICIPANT	\N	PRESENT	0
444805	439808	14235Q	PARTICIPANT	\N	PRESENT	0
444806	439808	19565D	PARTICIPANT	\N	PRESENT	0
444807	439808	17637T	PARTICIPANT	\N	PRESENT	0
444808	439808	19760E	PARTICIPANT	\N	PRESENT	0
444809	439808	19758L	PARTICIPANT	\N	PRESENT	0
444810	439808	19711U	PARTICIPANT	\N	PRESENT	0
444811	439808	19695N	PARTICIPANT	\N	PRESENT	0
444812	439808	19347U	PARTICIPANT	\N	PRESENT	0
444813	439808	19687N	PARTICIPANT	\N	PRESENT	0
444814	439808	19593H	PARTICIPANT	\N	PRESENT	0
444815	439808	04008A	PARTICIPANT	\N	PRESENT	0
444816	439808	08061X	PARTICIPANT	\N	PRESENT	0
444817	439808	19697Q	PARTICIPANT	\N	PRESENT	0
444818	439808	04045F	PARTICIPANT	\N	PRESENT	0
444819	439808	19651A	PARTICIPANT	\N	PRESENT	0
444820	439808	14239U	PARTICIPANT	\N	PRESENT	0
444821	439808	11031D	PARTICIPANT	\N	PRESENT	0
444823	439808	19637C	PARTICIPANT	\N	PRESENT	0
444824	439808	98018T	PARTICIPANT	\N	PRESENT	0
444825	439808	19269X	PARTICIPANT	\N	PRESENT	0
444826	439808	19349W	PARTICIPANT	\N	PRESENT	0
444827	439808	14157T	PARTICIPANT	\N	PRESENT	0
444828	439808	11072N	PARTICIPANT	\N	PRESENT	0
444829	439808	19812Y	PARTICIPANT	\N	PRESENT	0
444830	439808	96004D	PARTICIPANT	\N	PRESENT	0
444831	439808	19782L	PARTICIPANT	\N	PRESENT	0
444832	439808	08024S	PARTICIPANT	\N	PRESENT	0
444833	439808	19301E	PARTICIPANT	\N	PRESENT	0
444834	439808	01058X	PARTICIPANT	\N	PRESENT	0
444835	439808	19659J	PARTICIPANT	\N	PRESENT	0
444836	439808	99004R	PARTICIPANT	\N	PRESENT	0
444837	439808	11083R	PARTICIPANT	\N	PRESENT	0
444839	439808	98029W	PARTICIPANT	\N	PRESENT	0
444840	439808	17589D	PARTICIPANT	\N	PRESENT	0
444841	439808	19545Y	PARTICIPANT	\N	PRESENT	0
444842	439808	08011M	PARTICIPANT	\N	PRESENT	0
444844	439808	14251Q	PARTICIPANT	\N	PRESENT	0
444846	439808	19563B	PARTICIPANT	\N	PRESENT	0
444847	439808	14195A	PARTICIPANT	\N	PRESENT	0
444848	439808	04047H	PARTICIPANT	\N	PRESENT	0
444849	439808	19583F	PARTICIPANT	\N	PRESENT	0
444850	439808	98005N	PARTICIPANT	\N	PRESENT	0
444851	439808	95030B	PARTICIPANT	\N	PRESENT	0
444852	439808	98024R	PARTICIPANT	\N	PRESENT	0
444853	439808	04057K	PARTICIPANT	\N	PRESENT	0
444854	439808	14026U	PARTICIPANT	\N	PRESENT	0
444855	439808	11012A	PARTICIPANT	\N	PRESENT	0
444857	439808	88008L	PARTICIPANT	\N	PRESENT	0
444858	439808	08031R	PARTICIPANT	\N	PRESENT	0
444859	439808	95041E	PARTICIPANT	\N	PRESENT	0
444861	439808	19253P	PARTICIPANT	\N	PRESENT	0
444862	439808	19747H	PARTICIPANT	\N	PRESENT	0
444864	439808	19629C	PARTICIPANT	\N	PRESENT	0
444865	439808	04086Q	PARTICIPANT	\N	PRESENT	0
444866	439808	14201E	PARTICIPANT	\N	PRESENT	0
444867	439808	98022P	PARTICIPANT	\N	PRESENT	0
444868	439808	04042C	PARTICIPANT	\N	PRESENT	0
444870	439808	19387D	PARTICIPANT	\N	PRESENT	0
444871	439808	08069G	PARTICIPANT	\N	PRESENT	0
444872	439808	11099A	PARTICIPANT	\N	PRESENT	0
444874	439808	08010L	PARTICIPANT	\N	PRESENT	0
444875	439808	08039A	PARTICIPANT	\N	PRESENT	0
444877	439808	14107H	PARTICIPANT	\N	PRESENT	0
444878	439808	04097T	PARTICIPANT	\N	PRESENT	0
444880	439808	19679N	PARTICIPANT	\N	PRESENT	0
444882	439808	15447F	PARTICIPANT	\N	PRESENT	0
444883	439808	14261S	PARTICIPANT	\N	PRESENT	0
444885	439808	14169X	PARTICIPANT	\N	PRESENT	0
444887	439808	14223L	PARTICIPANT	\N	PRESENT	0
444888	439808	19731Y	PARTICIPANT	\N	PRESENT	0
444890	439808	08028W	PARTICIPANT	\N	PRESENT	0
444891	439808	19685L	PARTICIPANT	\N	PRESENT	0
444892	439808	11043H	PARTICIPANT	\N	PRESENT	0
444893	439808	19591F	PARTICIPANT	\N	PRESENT	0
444895	439808	98035U	PARTICIPANT	\N	PRESENT	0
444896	439808	04059M	PARTICIPANT	\N	PRESENT	0
444897	439808	10015M	PARTICIPANT	\N	PRESENT	0
444898	439808	14159V	PARTICIPANT	\N	PRESENT	0
444899	439808	04033B	PARTICIPANT	\N	PRESENT	0
444900	439808	11074Q	PARTICIPANT	\N	PRESENT	0
444901	439808	14187A	PARTICIPANT	\N	PRESENT	0
444902	439808	14051J	PARTICIPANT	\N	PRESENT	0
444903	439808	14071N	PARTICIPANT	\N	PRESENT	0
444904	439808	08068F	PARTICIPANT	\N	PRESENT	0
444905	439808	11097X	PARTICIPANT	\N	PRESENT	0
444906	439808	19421M	PARTICIPANT	\N	PRESENT	0
444907	439808	08052W	PARTICIPANT	\N	PRESENT	0
444908	439808	08055A	PARTICIPANT	\N	PRESENT	0
444909	439808	14053L	PARTICIPANT	\N	PRESENT	0
444910	439808	14069U	PARTICIPANT	\N	PRESENT	0
444911	439808	14021P	PARTICIPANT	\N	PRESENT	0
444912	439808	08045X	PARTICIPANT	\N	PRESENT	0
444913	439808	14225N	PARTICIPANT	\N	PRESENT	0
444914	439808	04043D	PARTICIPANT	\N	PRESENT	0
444915	439808	11090Q	PARTICIPANT	\N	PRESENT	0
444916	439808	12016W	PARTICIPANT	\N	PRESENT	0
428105	428104	14105F	PARTICIPANT	\N	PRESENT	0
428106	428104	14053L	PARTICIPANT	\N	PRESENT	0
428108	428104	14083S	PARTICIPANT	\N	PRESENT	0
428109	428104	14026U	PARTICIPANT	\N	PRESENT	0
428110	428104	14061L	PARTICIPANT	\N	PRESENT	0
428111	428104	08015R	PARTICIPANT	\N	PRESENT	0
428112	428104	04088S	PARTICIPANT	\N	PRESENT	0
428114	428104	04049K	PRESIDENT	0	PRESENT	0
428115	428104	89017R	PARTICIPANT	\N	EXCUSE	0
428116	428104	14030Q	PARTICIPANT	\N	EXCUSE	0
428117	428104	08060W	PARTICIPANT	\N	EXCUSE	0
428119	428104	08068F	PARTICIPANT	\N	EXCUSE	0
428120	428104	14255U	PARTICIPANT	\N	EXCUSE	0
428121	428104	14329V	PARTICIPANT	\N	EXCUSE	0
428122	428104	19545Y	PARTICIPANT	\N	EXCUSE	0
428123	428104	14041T	PARTICIPANT	\N	EXCUSE	0
428124	428104	14034U	PARTICIPANT	\N	EXCUSE	0
428125	428104	11099A	PARTICIPANT	\N	EXCUSE	0
428126	428104	16685X	PARTICIPANT	\N	EXCUSE	0
428127	428104	19697Q	PARTICIPANT	\N	EXCUSE	0
428128	428104	14205J	PARTICIPANT	\N	EXCUSE	0
428130	428104	14265W	PARTICIPANT	\N	EXCUSE	0
428131	428104	14253S	PARTICIPANT	\N	EXCUSE	0
428132	428104	14051J	PARTICIPANT	\N	EXCUSE	0
428133	428104	14187A	PARTICIPANT	\N	EXCUSE	0
428137	428136	14061L	PARTICIPANT	\N	PRESENT	0
428138	428136	14083S	PARTICIPANT	\N	PRESENT	0
428139	428136	04049K	PARTICIPANT	\N	PRESENT	0
428140	428136	14053L	PARTICIPANT	\N	PRESENT	0
428144	428143	14061L	PARTICIPANT	\N	PRESENT	0
428145	428143	14083S	PARTICIPANT	\N	PRESENT	0
428404	422995	11109J	PARTICIPANT	\N	PRESENT	0
428405	422995	14261S	PARTICIPANT	\N	PRESENT	0
428406	422995	19717B	PARTICIPANT	\N	PRESENT	0
428407	422995	19631V	PARTICIPANT	\N	PRESENT	0
428408	422995	14259Y	PARTICIPANT	\N	EXCUSE	0
428409	422995	19659J	PARTICIPANT	\N	EXCUSE	0
428410	422995	07033P	PARTICIPANT	\N	EXCUSE	0
428411	422995	19691J	PARTICIPANT	\N	EXCUSE	0
428412	422995	19329S	PARTICIPANT	\N	PRESENT	0
428413	422995	19715Y	PARTICIPANT	\N	PRESENT	0
428414	422995	08019V	PRESIDENT	0	PRESENT	0
428415	422995	12016W	PARTICIPANT	\N	PRESENT	0
428416	422995	08073C	PARTICIPANT	\N	PRESENT	0
428417	422995	11072N	PARTICIPANT	\N	PRESENT	0
428418	422995	14277B	PARTICIPANT	\N	PRESENT	0
428419	422995	14039A	PARTICIPANT	\N	PRESENT	0
428420	422995	14331P	PARTICIPANT	\N	PRESENT	0
428421	422995	14157T	PARTICIPANT	\N	PRESENT	0
428422	422995	14275Y	PARTICIPANT	\N	PRESENT	0
428423	422995	19301E	PARTICIPANT	\N	PRESENT	0
428424	422995	98005N	PARTICIPANT	\N	EXCUSE	0
428425	422995	19657G	PARTICIPANT	\N	PRESENT	0
428426	422995	19583F	PARTICIPANT	\N	PRESENT	0
428427	422995	86034E	PARTICIPANT	\N	PRESENT	0
442627	441687	19515S	PARTICIPANT	\N	PRESENT	0
442628	441687	11077T	PARTICIPANT	\N	PRESENT	0
442629	441687	19782L	PARTICIPANT	\N	PRESENT	0
442630	441687	19441R	PARTICIPANT	\N	PRESENT	0
442631	441687	19413M	PARTICIPANT	\N	PRESENT	0
442632	441687	19631V	PARTICIPANT	\N	PRESENT	0
442633	441687	19705W	PARTICIPANT	\N	PRESENT	0
442634	441687	08015R	PARTICIPANT	\N	PRESENT	0
442635	441687	14197C	PARTICIPANT	\N	PRESENT	0
442636	441687	19511N	PARTICIPANT	\N	PRESENT	0
442637	441687	08028W	PARTICIPANT	\N	PRESENT	0
442638	441687	19563B	PARTICIPANT	\N	PRESENT	0
442639	441687	14265W	PARTICIPANT	\N	PRESENT	0
442640	441687	14329V	PARTICIPANT	\N	PRESENT	0
442641	441687	08062Y	PARTICIPANT	\N	PRESENT	0
442642	441687	11090Q	PRESIDENT	0	PRESENT	0
442643	441687	14033T	PARTICIPANT	\N	PRESENT	0
442644	441687	19399H	PARTICIPANT	\N	PRESENT	0
442645	441687	11056N	PARTICIPANT	\N	PRESENT	0
442646	441687	04088S	PARTICIPANT	\N	PRESENT	0
442647	441687	04089T	PARTICIPANT	\N	PRESENT	0
442648	441687	11101A	PARTICIPANT	\N	PRESENT	0
442649	441687	19507S	PARTICIPANT	\N	PRESENT	0
442650	441687	19747H	PARTICIPANT	\N	PRESENT	0
442651	441687	14257W	PARTICIPANT	\N	PRESENT	0
442652	441687	19768N	PARTICIPANT	\N	PRESENT	0
442653	441687	14207L	PARTICIPANT	\N	PRESENT	0
442654	441687	19812Y	PARTICIPANT	\N	EXCUSE	0
442655	441687	11081P	PARTICIPANT	\N	EXCUSE	0
442656	441687	14081Q	PARTICIPANT	\N	PRESENT	0
442657	441687	80013X	PARTICIPANT	\N	PRESENT	0
442658	441687	04049K	PARTICIPANT	\N	PRESENT	0
442659	441687	14205J	PARTICIPANT	\N	PRESENT	0
442660	441687	04043D	PARTICIPANT	\N	PRESENT	0
442661	441687	19369B	PARTICIPANT	\N	PRESENT	0
442662	441687	08038Y	PARTICIPANT	\N	PRESENT	0
442663	441687	01043Q	PARTICIPANT	\N	PRESENT	0
442664	441687	14135M	PARTICIPANT	\N	PRESENT	0
442665	441687	11099A	PARTICIPANT	\N	PRESENT	0
442667	441590	08056B	PARTICIPANT	\N	PRESENT	0
442668	441590	12041X	PARTICIPANT	\N	PRESENT	0
442669	441590	98018T	PARTICIPANT	\N	PRESENT	0
442670	441590	14133K	PARTICIPANT	\N	PRESENT	0
442671	441590	11041F	PARTICIPANT	\N	PRESENT	0
442672	441590	14267Y	PARTICIPANT	\N	PRESENT	0
442673	441590	98050T	PARTICIPANT	\N	PRESENT	0
442674	441590	19251M	PARTICIPANT	\N	PRESENT	0
442675	441590	97011G	PARTICIPANT	\N	PRESENT	0
442676	441590	11066Q	PARTICIPANT	\N	PRESENT	0
442677	441590	19721W	PARTICIPANT	\N	PRESENT	0
442678	441590	95030B	PARTICIPANT	\N	PRESENT	0
442679	441590	14105F	PARTICIPANT	\N	PRESENT	0
442680	441590	95067Q	PARTICIPANT	\N	PRESENT	0
442681	441590	14255U	PARTICIPANT	\N	PRESENT	0
442682	441590	14028W	PARTICIPANT	\N	PRESENT	0
442683	441590	04042C	PRESIDENT	0	PRESENT	0
442684	441590	04034C	PARTICIPANT	\N	PRESENT	0
442685	441590	16685X	PARTICIPANT	\N	PRESENT	0
442817	441590	19709B	PARTICIPANT	\N	PRESENT	0
442818	441590	14193X	PARTICIPANT	\N	PRESENT	0
442819	441590	08061X	PARTICIPANT	\N	PRESENT	0
442820	441590	08047A	PARTICIPANT	\N	PRESENT	0
442821	441590	98029W	PARTICIPANT	\N	PRESENT	0
442822	441590	04035D	PARTICIPANT	\N	PRESENT	0
442823	441788	14147R	PARTICIPANT	\N	PRESENT	0
442824	441788	04008A	PARTICIPANT	\N	PRESENT	0
442825	441788	19762G	PARTICIPANT	\N	PRESENT	0
442829	441788	19253P	PARTICIPANT	\N	PRESENT	0
442846	442696	19649G	PARTICIPANT	\N	PRESENT	0
442847	442696	14065Q	PARTICIPANT	\N	PRESENT	0
442848	442696	04092N	PRESIDENT	0	PRESENT	0
442849	442696	19569H	PARTICIPANT	\N	PRESENT	0
442850	442696	11045K	PARTICIPANT	\N	PRESENT	0
442851	442696	08052W	PARTICIPANT	\N	PRESENT	0
442852	442696	08043V	PARTICIPANT	\N	PRESENT	0
442853	442696	19415P	PARTICIPANT	\N	PRESENT	0
442854	442696	11066Q	PARTICIPANT	\N	PRESENT	0
442855	442696	19447X	PARTICIPANT	\N	PRESENT	0
442856	442696	18083K	PARTICIPANT	\N	PRESENT	0
442857	442696	14239U	PARTICIPANT	\N	PRESENT	0
442858	442696	14042U	PARTICIPANT	\N	PRESENT	0
442859	442696	14147R	PARTICIPANT	\N	PRESENT	0
442860	442696	19575F	PARTICIPANT	\N	PRESENT	0
442861	442696	14213J	PARTICIPANT	\N	PRESENT	0
442862	442696	14215L	PARTICIPANT	\N	PRESENT	0
442863	442696	99004R	PARTICIPANT	\N	PRESENT	0
442864	442696	19335Q	PARTICIPANT	\N	PRESENT	0
442865	442696	14217N	PARTICIPANT	\N	PRESENT	0
442866	442696	10006L	PARTICIPANT	\N	PRESENT	0
442867	442696	19683J	PARTICIPANT	\N	PRESENT	0
442868	442696	11072N	PARTICIPANT	\N	PRESENT	0
442883	442696	01048V	PARTICIPANT	\N	PRESENT	0
442884	442696	11031D	PARTICIPANT	\N	PRESENT	0
442885	442696	19553Y	PARTICIPANT	\N	PRESENT	0
442886	442696	19681G	PARTICIPANT	\N	PRESENT	0
442887	442696	14179A	PARTICIPANT	\N	PRESENT	0
442891	442696	11067R	PARTICIPANT	\N	EXCUSE	0
442892	439637	04008A	PARTICIPANT	\N	PRESENT	0
442893	439637	19711U	PARTICIPANT	\N	PRESENT	0
442894	439637	98018T	PARTICIPANT	\N	PRESENT	0
442895	439637	14157T	PARTICIPANT	\N	PRESENT	0
442896	439637	01058X	PARTICIPANT	\N	PRESENT	0
442897	439637	19679N	PARTICIPANT	\N	PRESENT	0
442898	439637	04097T	PARTICIPANT	\N	PRESENT	0
442899	439637	08039A	PARTICIPANT	\N	PRESENT	0
442900	439637	08010L	PARTICIPANT	\N	PRESENT	0
442901	439637	19741B	PARTICIPANT	\N	PRESENT	0
442902	439637	14029X	PARTICIPANT	\N	PRESENT	0
442903	439637	19663E	PARTICIPANT	\N	PRESENT	0
442904	439637	19667J	PARTICIPANT	\N	PRESENT	0
442905	439637	04088S	PARTICIPANT	\N	PRESENT	0
442906	439637	08018U	PARTICIPANT	\N	PRESENT	0
442907	439637	07029T	PARTICIPANT	\N	PRESENT	0
442908	439637	08062Y	PARTICIPANT	\N	PRESENT	0
431180	424873	07004J	PARTICIPANT	\N	PRESENT	0
431181	424873	04034C	PARTICIPANT	\N	PRESENT	0
431182	424873	04086Q	PARTICIPANT	\N	PRESENT	0
431183	424873	19651A	PARTICIPANT	\N	PRESENT	0
431184	424873	19349W	PARTICIPANT	\N	PRESENT	0
431185	424873	19301E	PARTICIPANT	\N	PRESENT	0
431186	424873	19527W	PARTICIPANT	\N	PRESENT	0
431187	424873	14085U	PARTICIPANT	\N	PRESENT	0
431188	424873	19709B	PARTICIPANT	\N	PRESENT	0
431189	424873	14119M	PARTICIPANT	\N	PRESENT	0
431190	424873	88008L	PARTICIPANT	\N	PRESENT	0
431191	424873	11012A	PARTICIPANT	\N	PRESENT	0
431192	424873	08034U	PARTICIPANT	\N	PRESENT	0
431193	424873	07029T	PARTICIPANT	\N	PRESENT	0
431194	424873	19711U	PARTICIPANT	\N	PRESENT	0
431195	424873	14083S	PARTICIPANT	\N	PRESENT	0
431196	424873	19647E	PARTICIPANT	\N	PRESENT	0
431197	424873	19295A	PARTICIPANT	\N	PRESENT	0
431198	424873	19543W	PARTICIPANT	\N	PRESENT	0
431199	424873	14219Q	PARTICIPANT	\N	PRESENT	0
431200	424873	12016W	PARTICIPANT	\N	PRESENT	0
431201	424873	19533U	PARTICIPANT	\N	PRESENT	0
431202	424873	11048N	PARTICIPANT	\N	PRESENT	0
431203	424873	19689Q	PARTICIPANT	\N	PRESENT	0
431204	424873	14039A	PARTICIPANT	\N	PRESENT	0
431206	424873	14021P	PARTICIPANT	\N	PRESENT	0
431207	424873	14001X	PARTICIPANT	\N	PRESENT	0
431208	424873	19669L	PARTICIPANT	\N	PRESENT	0
431209	424873	19667J	PARTICIPANT	\N	PRESENT	0
431210	424873	14261S	PARTICIPANT	\N	PRESENT	0
431211	424873	11090Q	PARTICIPANT	\N	PRESENT	0
431212	424873	04042C	PARTICIPANT	\N	PRESENT	0
431213	424873	11010L	PARTICIPANT	\N	PRESENT	0
431214	424873	19687N	PARTICIPANT	\N	PRESENT	0
431215	424873	19551W	PARTICIPANT	\N	PRESENT	0
431264	424874	19651A	PARTICIPANT	\N	PRESENT	0
431265	424874	19301E	PARTICIPANT	\N	PRESENT	0
431266	424874	14225N	PARTICIPANT	\N	PRESENT	0
431267	424874	11040E	PARTICIPANT	\N	PRESENT	0
431268	424874	14085U	PARTICIPANT	\N	PRESENT	0
431269	424874	11074Q	PARTICIPANT	\N	PRESENT	0
431270	424874	08011M	PARTICIPANT	\N	PRESENT	0
431271	424874	11027H	PARTICIPANT	\N	PRESENT	0
431272	424874	07004J	PARTICIPANT	\N	PRESENT	0
431273	424874	11070L	PARTICIPANT	\N	PRESENT	0
431274	424874	14327T	PARTICIPANT	\N	PRESENT	0
431275	424874	07029T	PARTICIPANT	\N	PRESENT	0
431276	424874	08019V	PARTICIPANT	\N	PRESENT	0
431277	424874	01057W	PARTICIPANT	\N	PRESENT	0
431278	424874	19667J	PARTICIPANT	\N	PRESENT	0
431279	424874	12016W	PARTICIPANT	\N	PRESENT	0
431280	424874	11090Q	PARTICIPANT	\N	PRESENT	0
431281	424874	08034U	PARTICIPANT	\N	PRESENT	0
431282	424874	04086Q	PARTICIPANT	\N	PRESENT	0
431283	424874	19709B	PARTICIPANT	\N	PRESENT	0
431284	424874	99004R	PARTICIPANT	\N	PRESENT	0
431285	424874	08069G	PARTICIPANT	\N	PRESENT	0
431286	424874	14119M	PARTICIPANT	\N	PRESENT	0
431287	424874	14331P	PARTICIPANT	\N	PRESENT	0
431288	424874	14083S	PARTICIPANT	\N	PRESENT	0
431289	424874	19687N	PARTICIPANT	\N	PRESENT	0
431290	424874	04071H	PARTICIPANT	\N	PRESENT	0
431291	424874	11048N	PARTICIPANT	\N	PRESENT	0
431292	424874	11026G	PARTICIPANT	\N	PRESENT	0
431293	424874	14001X	PARTICIPANT	\N	PRESENT	0
431294	424874	19711U	PARTICIPANT	\N	PRESENT	0
431295	424874	14261S	PARTICIPANT	\N	PRESENT	0
431296	424874	11010L	PARTICIPANT	\N	PRESENT	0
431297	424874	19741B	PARTICIPANT	\N	PRESENT	0
431298	424874	14357A	PARTICIPANT	\N	PRESENT	0
431299	424874	88008L	PARTICIPANT	\N	PRESENT	0
431300	424874	11053K	PARTICIPANT	\N	PRESENT	0
431301	424874	95063L	PARTICIPANT	\N	PRESENT	0
431302	424874	19527W	PARTICIPANT	\N	PRESENT	0
431303	424874	11077T	PARTICIPANT	\N	PRESENT	0
431304	424874	19647E	PARTICIPANT	\N	PRESENT	0
431305	424874	19563B	PARTICIPANT	\N	PRESENT	0
431306	424874	08073C	PARTICIPANT	\N	PRESENT	0
431307	424874	19295A	PARTICIPANT	\N	PRESENT	0
431308	424874	14219Q	PARTICIPANT	\N	PRESENT	0
431309	424874	19533U	PARTICIPANT	\N	PRESENT	0
431262	424874	04059M	PARTICIPANT	\N	PRESENT	0
431263	424874	04034C	PARTICIPANT	\N	PRESENT	0
431310	424874	19543W	PARTICIPANT	\N	PRESENT	0
431311	424874	14039A	PARTICIPANT	\N	PRESENT	0
431312	424874	01028R	PARTICIPANT	\N	PRESENT	0
431313	424874	19669L	PARTICIPANT	\N	PRESENT	0
431350	424875	11074Q	PARTICIPANT	\N	PRESENT	0
431351	424875	14225N	PARTICIPANT	\N	PRESENT	0
431352	424875	14085U	PARTICIPANT	\N	PRESENT	0
431353	424875	12016W	PARTICIPANT	\N	PRESENT	0
431354	424875	95063L	PARTICIPANT	\N	PRESENT	0
431355	424875	07004J	PARTICIPANT	\N	PRESENT	0
431356	424875	14327T	PARTICIPANT	\N	PRESENT	0
431357	424875	19741B	PARTICIPANT	\N	PRESENT	0
431358	424875	14119M	PARTICIPANT	\N	PRESENT	0
431359	424875	19667J	PARTICIPANT	\N	PRESENT	0
431360	424875	11040E	PARTICIPANT	\N	PRESENT	0
431361	424875	11077T	PARTICIPANT	\N	PRESENT	0
431362	424875	19687N	PARTICIPANT	\N	PRESENT	0
431363	424875	14331P	PARTICIPANT	\N	PRESENT	0
431364	424875	04086Q	PARTICIPANT	\N	PRESENT	0
431365	424875	19711U	PARTICIPANT	\N	PRESENT	0
431366	424875	99004R	PARTICIPANT	\N	PRESENT	0
431367	424875	88008L	PARTICIPANT	\N	PRESENT	0
431368	424875	07029T	PARTICIPANT	\N	PRESENT	0
431369	424875	11026G	PARTICIPANT	\N	PRESENT	0
431370	424875	19651A	PARTICIPANT	\N	PRESENT	0
431371	424875	14205J	PARTICIPANT	\N	PRESENT	0
431388	424881	14034U	PARTICIPANT	\N	PRESENT	0
431389	424881	07029T	PARTICIPANT	\N	PRESENT	0
431390	424881	08019V	PARTICIPANT	\N	PRESENT	0
431391	424881	19651A	PARTICIPANT	\N	PRESENT	0
431392	424881	08073C	PARTICIPANT	\N	PRESENT	0
431393	424881	11109J	PARTICIPANT	\N	PRESENT	0
431394	424881	19503N	PARTICIPANT	\N	PRESENT	0
431395	424881	14085U	PARTICIPANT	\N	PRESENT	0
431396	424881	19687N	PARTICIPANT	\N	PRESENT	0
431397	424881	08011M	PARTICIPANT	\N	PRESENT	0
431398	424881	11074Q	PARTICIPANT	\N	PRESENT	0
431399	424881	12016W	PARTICIPANT	\N	PRESENT	0
431348	424875	11072N	PARTICIPANT	\N	PRESENT	0
431349	424875	08011M	PARTICIPANT	\N	PRESENT	0
431400	424881	19691J	PARTICIPANT	\N	PRESENT	0
431401	424881	14327T	PARTICIPANT	\N	PRESENT	0
431402	424881	04086Q	PARTICIPANT	\N	PRESENT	0
431403	424881	19711U	PARTICIPANT	\N	PRESENT	0
431404	424881	11048N	PARTICIPANT	\N	PRESENT	0
431405	424881	04069P	PARTICIPANT	\N	PRESENT	0
431406	424881	19667J	PARTICIPANT	\N	PRESENT	0
431407	424881	11012A	PARTICIPANT	\N	PRESENT	0
431408	424881	19689Q	PARTICIPANT	\N	PRESENT	0
431409	424881	14119M	PARTICIPANT	\N	PRESENT	0
431410	424881	19573D	PARTICIPANT	\N	PRESENT	0
431411	424881	14039A	PARTICIPANT	\N	PRESENT	0
431412	424881	19647E	PARTICIPANT	\N	PRESENT	0
431413	424881	19545Y	PARTICIPANT	\N	PRESENT	0
431414	431387	14327T	PARTICIPANT	\N	PRESENT	0
431415	431387	11048N	PARTICIPANT	\N	PRESENT	0
431416	431387	19711U	PARTICIPANT	\N	PRESENT	0
431417	431387	19651A	PARTICIPANT	\N	PRESENT	0
431418	431387	19687N	PARTICIPANT	\N	PRESENT	0
431419	431387	12016W	PARTICIPANT	\N	PRESENT	0
431420	431387	19667J	PARTICIPANT	\N	PRESENT	0
431421	431387	11074Q	PRESIDENT	0	PRESENT	0
431422	431387	08011M	PARTICIPANT	\N	PRESENT	0
431423	431387	11110B	PARTICIPANT	\N	PRESENT	0
431424	431387	04086Q	PARTICIPANT	\N	PRESENT	0
431425	431387	07029T	PARTICIPANT	\N	PRESENT	0
431426	431387	11012A	PARTICIPANT	\N	PRESENT	0
431427	431387	14085U	PARTICIPANT	\N	PRESENT	0
431428	431387	08073C	PARTICIPANT	\N	PRESENT	0
424292	414419	19369B	PARTICIPANT	\N	PRESENT	0
424921	424899	89017R	PARTICIPANT	\N	EXCUSE	0
424922	424899	19545Y	PARTICIPANT	\N	EXCUSE	0
424923	424899	14187A	PARTICIPANT	\N	EXCUSE	0
424924	424899	14039A	PARTICIPANT	\N	EXCUSE	0
424925	424899	14061L	PARTICIPANT	\N	EXCUSE	0
424926	424899	04049K	PARTICIPANT	\N	EXCUSE	0
424927	424899	08015R	PARTICIPANT	\N	EXCUSE	0
424928	424899	19697Q	PARTICIPANT	\N	EXCUSE	0
424929	424899	14265W	PARTICIPANT	\N	EXCUSE	0
424930	424899	14051J	PARTICIPANT	\N	EXCUSE	0
424931	424899	11048N	PARTICIPANT	\N	EXCUSE	0
424932	424899	11077T	PARTICIPANT	\N	EXCUSE	0
424933	424899	04057K	PARTICIPANT	\N	EXCUSE	0
425009	414079	19663E	PARTICIPANT	\N	PRESENT	0
425011	414079	04043D	PARTICIPANT	\N	PRESENT	0
425013	414079	01058X	PARTICIPANT	\N	PRESENT	0
425016	414079	19503N	PARTICIPANT	\N	PRESENT	0
425017	414079	14239U	PARTICIPANT	\N	PRESENT	0
425019	414079	01048V	PRESIDENT	0	PRESENT	0
425023	414079	19709B	PARTICIPANT	\N	PRESENT	0
425025	414079	14221J	PARTICIPANT	\N	EXCUSE	0
425026	414079	19511N	PARTICIPANT	\N	EXCUSE	0
425034	414079	19693L	PARTICIPANT	\N	EXCUSE	0
425035	414079	19683J	PARTICIPANT	\N	EXCUSE	0
425040	414079	14299H	PARTICIPANT	\N	EXCUSE	0
425051	425050	14255U	PARTICIPANT	\N	PRESENT	0
425052	425050	08053X	PARTICIPANT	\N	PRESENT	0
425054	425053	08049C	PARTICIPANT	\N	PRESENT	0
428247	428246	18083K	PARTICIPANT	\N	PRESENT	0
428517	428233	14053L	PARTICIPANT	\N	PRESENT	0
428518	428233	95067Q	PARTICIPANT	\N	PRESENT	0
428519	428233	14079W	PARTICIPANT	\N	PRESENT	0
428520	428233	19413M	PARTICIPANT	\N	PRESENT	0
428521	428233	19251M	PARTICIPANT	\N	PRESENT	0
428522	428233	19826F	PARTICIPANT	\N	PRESENT	0
428523	428233	14033T	PARTICIPANT	\N	PRESENT	0
428546	416366	01043Q	PARTICIPANT	\N	PRESENT	0
428548	428547	19697Q	PARTICIPANT	\N	PRESENT	0
428549	428547	11067R	PARTICIPANT	\N	PRESENT	0
428550	428547	01034P	PARTICIPANT	\N	PRESENT	0
428551	428547	19565D	PARTICIPANT	\N	PRESENT	0
428552	428547	04092N	PRESIDENT	0	PRESENT	0
428553	428547	19798U	PARTICIPANT	\N	PRESENT	0
428554	428547	11097X	PARTICIPANT	\N	PRESENT	0
428555	428547	08052W	PARTICIPANT	\N	PRESENT	0
428556	428547	14026U	PARTICIPANT	\N	PRESENT	0
428557	428547	19723Y	PARTICIPANT	\N	PRESENT	0
428558	428547	19727D	PARTICIPANT	\N	PRESENT	0
428559	428547	14239U	PARTICIPANT	\N	PRESENT	0
428560	428547	14119M	PARTICIPANT	\N	PRESENT	0
428561	428547	14281W	PARTICIPANT	\N	PRESENT	0
428562	428547	14087W	PARTICIPANT	\N	PRESENT	0
428563	428547	11103C	PARTICIPANT	\N	PRESENT	0
428564	428547	19679N	PARTICIPANT	\N	PRESENT	0
428565	428547	14042U	PARTICIPANT	\N	PRESENT	0
428566	428547	19575F	PARTICIPANT	\N	PRESENT	0
428567	428547	14213J	PARTICIPANT	\N	PRESENT	0
428568	428547	14071N	PARTICIPANT	\N	PRESENT	0
428569	428547	14217N	PARTICIPANT	\N	PRESENT	0
428570	428547	10006L	PARTICIPANT	\N	PRESENT	0
428571	428547	08041T	PARTICIPANT	\N	EXCUSE	0
428572	416366	19565D	PARTICIPANT	\N	PRESENT	0
428573	416366	14281W	PARTICIPANT	\N	PRESENT	0
428574	416366	11066Q	PARTICIPANT	\N	PRESENT	0
428575	416366	19585H	PARTICIPANT	\N	PRESENT	0
428576	416366	14195A	PARTICIPANT	\N	PRESENT	0
428577	416366	07004J	PARTICIPANT	\N	PRESENT	0
428578	416366	14042U	PARTICIPANT	\N	PRESENT	0
428579	416366	19798U	PARTICIPANT	\N	PRESENT	0
428580	416366	19731Y	PARTICIPANT	\N	PRESENT	0
428581	416366	01060R	PARTICIPANT	\N	PRESENT	0
428582	416366	04088S	PARTICIPANT	\N	PRESENT	0
428583	416366	14087W	PARTICIPANT	\N	PRESENT	0
428584	416366	19737F	PARTICIPANT	\N	PRESENT	0
428585	416366	10006L	PARTICIPANT	\N	PRESENT	0
428586	416366	11103C	PARTICIPANT	\N	PRESENT	0
428587	416366	19701S	PARTICIPANT	\N	PRESENT	0
428588	416366	14261S	PARTICIPANT	\N	PRESENT	0
428589	416366	04092N	PARTICIPANT	\N	PRESENT	0
428590	416366	19415P	PARTICIPANT	\N	PRESENT	0
428591	416366	19671E	PARTICIPANT	\N	PRESENT	0
428592	416366	08034U	PARTICIPANT	\N	PRESENT	0
428593	416366	01034P	PARTICIPANT	\N	PRESENT	0
428594	416366	11067R	PARTICIPANT	\N	PRESENT	0
428595	416366	19583F	PARTICIPANT	\N	PRESENT	0
428596	416366	08056B	PARTICIPANT	\N	PRESENT	0
428597	416366	14105F	PARTICIPANT	\N	PRESENT	0
428598	416366	18083K	PARTICIPANT	\N	PRESENT	0
428599	416366	14213J	PARTICIPANT	\N	PRESENT	0
428600	416366	14071N	PARTICIPANT	\N	PRESENT	0
428601	416366	19679N	PARTICIPANT	\N	PRESENT	0
428602	416366	14026U	PARTICIPANT	\N	PRESENT	0
428603	416366	19333N	PARTICIPANT	\N	PRESENT	0
428604	416366	19681G	PARTICIPANT	\N	PRESENT	0
428605	416366	14119M	PARTICIPANT	\N	PRESENT	0
428606	416366	04045F	PARTICIPANT	\N	PRESENT	0
428607	416366	95037J	PARTICIPANT	\N	PRESENT	0
428608	416366	10015M	PARTICIPANT	\N	PRESENT	0
428609	416366	19723Y	PARTICIPANT	\N	PRESENT	0
428610	416366	14107H	PARTICIPANT	\N	PRESENT	0
428611	416366	11097X	PARTICIPANT	\N	PRESENT	0
428612	416366	14265W	PARTICIPANT	\N	PRESENT	0
428613	416366	14069U	PARTICIPANT	\N	PRESENT	0
428614	416366	95030B	PARTICIPANT	\N	PRESENT	0
428615	416366	19727D	PARTICIPANT	\N	PRESENT	0
428616	416366	14055N	PARTICIPANT	\N	PRESENT	0
428617	416366	19629C	PARTICIPANT	\N	PRESENT	0
428618	416366	11045K	PARTICIPANT	\N	PRESENT	0
428619	416366	11049P	PARTICIPANT	\N	PRESENT	0
428620	416366	14038Y	PARTICIPANT	\N	PRESENT	0
428621	416366	14223L	PARTICIPANT	\N	PRESENT	0
428622	416366	04059M	PARTICIPANT	\N	PRESENT	0
428623	416366	01048V	PARTICIPANT	\N	PRESENT	0
428624	416366	08062Y	PARTICIPANT	\N	PRESENT	0
428625	416366	01025N	PARTICIPANT	\N	PRESENT	0
428626	416366	14219Q	PARTICIPANT	\N	PRESENT	0
428627	416366	14147R	PARTICIPANT	\N	PRESENT	0
428628	416366	08028W	PARTICIPANT	\N	PRESENT	0
428629	416366	88008L	PARTICIPANT	\N	PRESENT	0
428630	416366	19697Q	PARTICIPANT	\N	PRESENT	0
428648	416366	19703U	PARTICIPANT	\N	PRESENT	0
428632	416366	19533U	PARTICIPANT	\N	PRESENT	0
428633	416366	14121F	PARTICIPANT	\N	PRESENT	0
428634	416366	11031D	PARTICIPANT	\N	PRESENT	0
428635	416366	19695N	PARTICIPANT	\N	PRESENT	0
428636	416366	19545Y	PARTICIPANT	\N	PRESENT	0
428637	416366	19611R	PARTICIPANT	\N	PRESENT	0
428638	416366	08044W	PARTICIPANT	\N	PRESENT	0
428639	416366	11043H	PARTICIPANT	\N	PRESENT	0
428640	416366	19349W	PARTICIPANT	\N	PRESENT	0
428641	416366	14031R	PARTICIPANT	\N	PRESENT	0
428642	416366	14173T	PARTICIPANT	\N	PRESENT	0
428643	416366	14133K	PARTICIPANT	\N	PRESENT	0
428644	416366	19739H	PARTICIPANT	\N	PRESENT	0
428645	416366	19479G	PARTICIPANT	\N	PRESENT	0
428646	416366	14217N	PARTICIPANT	\N	PRESENT	0
428647	416366	14331P	PARTICIPANT	\N	PRESENT	0
428649	416366	11072N	PARTICIPANT	\N	PRESENT	0
428650	416366	14041T	PARTICIPANT	\N	PRESENT	0
428651	416366	19507S	PARTICIPANT	\N	PRESENT	0
428652	416366	14033T	PARTICIPANT	\N	PRESENT	0
428653	416366	08014Q	PARTICIPANT	\N	PRESENT	0
428654	416366	19413M	PARTICIPANT	\N	PRESENT	0
428655	416366	08053X	PARTICIPANT	\N	PRESENT	0
428656	416366	19691J	PARTICIPANT	\N	PRESENT	0
428657	416366	14061L	PARTICIPANT	\N	PRESENT	0
428658	416366	19575F	PARTICIPANT	\N	PRESENT	0
428659	416366	14193X	PARTICIPANT	\N	PRESENT	0
428660	416366	19581D	PARTICIPANT	\N	PRESENT	0
428661	416366	19467C	PARTICIPANT	\N	PRESENT	0
428663	416366	19335Q	PARTICIPANT	\N	PRESENT	0
428664	416366	14135M	PARTICIPANT	\N	PRESENT	0
428665	416366	14109K	PARTICIPANT	\N	PRESENT	0
428666	416366	19387D	PARTICIPANT	\N	PRESENT	0
428667	428199	14327T	PARTICIPANT	\N	PRESENT	0
428668	428199	14331P	PARTICIPANT	\N	PRESENT	0
440005	438470	14327T	PARTICIPANT	\N	EXCUSE	0
440092	438470	19735D	PARTICIPANT	\N	EXCUSE	0
440276	440275	14083S	PARTICIPANT	\N	PRESENT	0
440277	440275	14061L	PARTICIPANT	\N	PRESENT	0
440279	440278	04049K	PARTICIPANT	\N	PRESENT	0
440280	440278	16685X	PARTICIPANT	\N	PRESENT	0
440282	440278	14030Q	PARTICIPANT	\N	PRESENT	0
440284	440283	04049K	PARTICIPANT	\N	PRESENT	0
440285	440283	16685X	PARTICIPANT	\N	PRESENT	0
440287	440286	04049K	PARTICIPANT	\N	PRESENT	0
440288	440286	16685X	PARTICIPANT	\N	PRESENT	0
444541	444487	19447X	PARTICIPANT	\N	PRESENT	0
444542	444487	01043Q	PARTICIPANT	\N	PRESENT	0
444543	444487	14205J	PARTICIPANT	\N	PRESENT	0
444544	444487	19762G	PARTICIPANT	\N	PRESENT	0
444545	444487	14173T	PARTICIPANT	\N	PRESENT	0
444917	439808	87003B	PARTICIPANT	\N	PRESENT	0
444918	439808	80013X	PARTICIPANT	\N	PRESENT	0
444919	439808	14281W	PARTICIPANT	\N	PRESENT	0
444920	439808	01057W	PARTICIPANT	\N	PRESENT	0
444921	439808	08043V	PARTICIPANT	\N	PRESENT	0
444922	439808	19766L	PARTICIPANT	\N	PRESENT	0
444923	439808	11066Q	PARTICIPANT	\N	PRESENT	0
444924	439808	19515S	PARTICIPANT	\N	PRESENT	0
444925	439808	19703U	PARTICIPANT	\N	PRESENT	0
444926	439808	08038Y	PARTICIPANT	\N	PRESENT	0
444927	439808	19673G	PARTICIPANT	\N	PRESENT	0
444928	439808	14031R	PARTICIPANT	\N	PRESENT	0
444929	439808	14081Q	PARTICIPANT	\N	PRESENT	0
444930	439808	19549D	PARTICIPANT	\N	PRESENT	0
444931	439808	08053X	PARTICIPANT	\N	PRESENT	0
444932	439808	08017T	PARTICIPANT	\N	PRESENT	0
444933	439808	19667J	PARTICIPANT	\N	PRESENT	0
444934	439808	19333N	PARTICIPANT	\N	PRESENT	0
444935	439808	19527W	PARTICIPANT	\N	PRESENT	0
444936	439808	14199E	PARTICIPANT	\N	PRESENT	0
444937	439808	11048N	PARTICIPANT	\N	PRESENT	0
444938	439808	14097Y	PARTICIPANT	\N	PRESENT	0
444939	439808	14253S	PARTICIPANT	\N	PRESENT	0
444940	439808	14109K	PARTICIPANT	\N	PRESENT	0
444941	439808	04049K	PARTICIPANT	\N	PRESENT	0
444942	439808	19725B	PARTICIPANT	\N	PRESENT	0
444943	439808	05012A	PARTICIPANT	\N	PRESENT	0
444944	439808	14065Q	PARTICIPANT	\N	PRESENT	0
444945	439808	11041F	PARTICIPANT	\N	PRESENT	0
444946	439808	08034U	PARTICIPANT	\N	PRESENT	0
444947	439808	10006L	PARTICIPANT	\N	PRESENT	0
444948	439808	11067R	PARTICIPANT	\N	PRESENT	0
444949	439808	19798U	PARTICIPANT	\N	PRESENT	0
444950	439808	19503N	PARTICIPANT	\N	PRESENT	0
444951	439808	19533U	PARTICIPANT	\N	PRESENT	0
444952	439808	19689Q	PARTICIPANT	\N	PRESENT	0
444953	439808	14193X	PARTICIPANT	\N	PRESENT	0
444954	439808	19251M	PARTICIPANT	\N	PRESENT	0
444955	439808	19413M	PARTICIPANT	\N	PRESENT	0
444956	439808	11077T	PARTICIPANT	\N	PRESENT	0
444957	439808	95063L	PARTICIPANT	\N	PRESENT	0
444958	439808	11054L	PARTICIPANT	\N	PRESENT	0
444959	439808	19295A	PARTICIPANT	\N	PRESENT	0
444960	439808	19683J	PARTICIPANT	\N	PRESENT	0
444961	439808	14227Q	PARTICIPANT	\N	PRESENT	0
444962	439808	14085U	PARTICIPANT	\N	PRESENT	0
444963	439808	17779H	PARTICIPANT	\N	PRESENT	0
444964	439808	19489J	PARTICIPANT	\N	PRESENT	0
444965	439808	19531S	PARTICIPANT	\N	PRESENT	0
444966	439808	19820Y	PARTICIPANT	\N	PRESENT	0
444967	439808	08012N	PARTICIPANT	\N	PRESENT	0
444968	439808	19727D	PARTICIPANT	\N	PRESENT	0
444969	439808	14079W	PARTICIPANT	\N	PRESENT	0
444970	439808	08035V	PARTICIPANT	\N	PRESENT	0
444971	439808	19671E	PARTICIPANT	\N	PRESENT	0
444972	439808	14028W	PARTICIPANT	\N	PRESENT	0
444973	439808	11045K	PARTICIPANT	\N	PRESENT	0
444974	439808	04069P	PARTICIPANT	\N	PRESENT	0
444975	439808	14197C	PARTICIPANT	\N	PRESENT	0
444976	439808	07033P	PARTICIPANT	\N	PRESENT	0
444977	439808	19649G	PARTICIPANT	\N	PRESENT	0
444978	439808	11103C	PARTICIPANT	\N	PRESENT	0
444979	439808	97011G	PARTICIPANT	\N	PRESENT	0
444980	439808	11104D	PARTICIPANT	\N	PRESENT	0
444981	439808	17583W	PARTICIPANT	\N	PRESENT	0
444982	439808	14151M	PARTICIPANT	\N	PRESENT	0
444983	439808	08047A	PARTICIPANT	\N	PRESENT	0
444984	439808	11033F	PARTICIPANT	\N	PRESENT	0
444985	439808	14115H	PARTICIPANT	\N	PRESENT	0
444986	439808	19647E	PARTICIPANT	\N	PRESENT	0
444987	439808	11049P	PARTICIPANT	\N	PRESENT	0
444988	439808	14119M	PARTICIPANT	\N	PRESENT	0
444989	439808	19794Q	PARTICIPANT	\N	PRESENT	0
444990	439808	19573D	PARTICIPANT	\N	PRESENT	0
444991	439808	19447X	PARTICIPANT	\N	PRESENT	0
444992	439808	14173T	PARTICIPANT	\N	PRESENT	0
444993	439808	19713W	PARTICIPANT	\N	PRESENT	0
444994	439808	19735D	PARTICIPANT	\N	PRESENT	0
444995	439808	14038Y	PARTICIPANT	\N	PRESENT	0
444996	439808	14083S	PARTICIPANT	\N	PRESENT	0
444997	439808	19723Y	PARTICIPANT	\N	PRESENT	0
444998	439808	19479G	PARTICIPANT	\N	PRESENT	0
444999	439808	18083K	PARTICIPANT	\N	PRESENT	0
445000	439808	19441R	PARTICIPANT	\N	PRESENT	0
445001	439808	19415P	PARTICIPANT	\N	PRESENT	0
445002	439808	19569H	PARTICIPANT	\N	PRESENT	0
445003	439808	14135M	PARTICIPANT	\N	PRESENT	0
445004	439808	19739H	PARTICIPANT	\N	PRESENT	0
445005	439808	16685X	PARTICIPANT	\N	PRESENT	0
445006	439808	08019V	PARTICIPANT	\N	PRESENT	0
445007	439808	19399H	PARTICIPANT	\N	PRESENT	0
445008	439808	19669L	PARTICIPANT	\N	PRESENT	0
445810	445809	14257W	PARTICIPANT	\N	PRESENT	0
445811	445809	19768N	PARTICIPANT	\N	PRESENT	0
445812	439811	19479G	PARTICIPANT	\N	PRESENT	0
445813	439811	14179A	PARTICIPANT	\N	PRESENT	0
445816	445815	14087W	PARTICIPANT	\N	PRESENT	0
445817	445815	14061L	PARTICIPANT	\N	PRESENT	0
445818	445815	14083S	PARTICIPANT	\N	PRESENT	0
445819	445815	04049K	PRESIDENT	0	PRESENT	0
445820	445815	19671E	PARTICIPANT	\N	PRESENT	0
445821	445815	19521Q	PARTICIPANT	\N	PRESENT	0
445822	445815	14026U	PARTICIPANT	\N	PRESENT	0
445823	439811	08009T	PARTICIPANT	\N	PRESENT	0
445824	439811	19737F	PARTICIPANT	\N	PRESENT	0
445825	439811	14053L	PARTICIPANT	\N	PRESENT	0
445826	439811	19794Q	PARTICIPANT	\N	PRESENT	0
445827	439811	19585H	PARTICIPANT	\N	PRESENT	0
445828	439811	14026U	PARTICIPANT	\N	PRESENT	0
445829	439811	19711U	PARTICIPANT	\N	PRESENT	0
445830	439811	05008E	PARTICIPANT	\N	PRESENT	0
445831	439811	14151M	PARTICIPANT	\N	PRESENT	0
445832	439811	14089Y	PARTICIPANT	\N	PRESENT	0
445833	439811	10015M	PARTICIPANT	\N	PRESENT	0
445834	439811	14069U	PARTICIPANT	\N	PRESENT	0
445835	439811	19253P	PARTICIPANT	\N	PRESENT	0
445806	445802	11090Q	PARTICIPANT	\N	PRESENT	0
445808	445807	14257W	PARTICIPANT	\N	PRESENT	0
445836	439811	14249W	PARTICIPANT	\N	PRESENT	0
445837	439811	11072N	PARTICIPANT	\N	PRESENT	0
445838	439811	19563B	PARTICIPANT	\N	PRESENT	0
445839	439811	95067Q	PARTICIPANT	\N	PRESENT	0
445840	439811	19543W	PARTICIPANT	\N	PRESENT	0
445841	445814	11070L	PARTICIPANT	\N	PRESENT	0
445842	445784	89017R	PARTICIPANT	\N	EXCUSE	0
445843	445784	19575F	PARTICIPANT	\N	EXCUSE	0
445844	439811	04038G	PARTICIPANT	\N	PRESENT	0
445845	445784	08060W	PARTICIPANT	\N	EXCUSE	0
445846	439811	19533U	PARTICIPANT	\N	PRESENT	0
445847	445784	14105F	PARTICIPANT	\N	EXCUSE	0
445848	439811	19749K	PARTICIPANT	\N	PRESENT	0
445849	445784	08068F	PARTICIPANT	\N	EXCUSE	0
445850	445784	19545Y	PARTICIPANT	\N	EXCUSE	0
445851	445784	14041T	PARTICIPANT	\N	EXCUSE	0
445852	445784	14187A	PARTICIPANT	\N	EXCUSE	0
445853	445784	14051J	PARTICIPANT	\N	EXCUSE	0
445854	445784	14034U	PARTICIPANT	\N	EXCUSE	0
445855	445784	08015R	PARTICIPANT	\N	EXCUSE	0
445856	445784	14265W	PARTICIPANT	\N	EXCUSE	0
445857	439811	11101A	PARTICIPANT	\N	PRESENT	0
445858	445784	19669L	PARTICIPANT	\N	EXCUSE	0
445859	439811	19762G	PARTICIPANT	\N	PRESENT	0
445860	445815	14255U	PARTICIPANT	\N	EXCUSE	0
445861	445815	14053L	PARTICIPANT	\N	EXCUSE	0
445863	445862	14199E	PARTICIPANT	\N	PRESENT	0
445864	445862	14085U	PARTICIPANT	\N	PRESENT	0
445865	439811	99004R	PARTICIPANT	\N	PRESENT	0
445866	439811	14261S	PARTICIPANT	\N	PRESENT	0
445867	439811	14083S	PARTICIPANT	\N	PRESENT	0
445868	445815	89017R	PARTICIPANT	\N	EXCUSE	0
445869	445815	19575F	PARTICIPANT	\N	EXCUSE	0
445870	439811	19441R	PARTICIPANT	\N	PRESENT	0
445871	445815	08060W	PARTICIPANT	\N	EXCUSE	0
428043	428042	04085P	PARTICIPANT	\N	PRESENT	0
428044	428042	08055A	PARTICIPANT	\N	PRESENT	0
428046	428042	14093U	PARTICIPANT	\N	PRESENT	0
428047	428042	19549D	PARTICIPANT	\N	PRESENT	0
428048	428042	08060W	PARTICIPANT	\N	PRESENT	0
428050	428042	19733B	PARTICIPANT	\N	PRESENT	0
428051	428042	19383Y	PARTICIPANT	\N	PRESENT	0
428052	428042	08024S	PARTICIPANT	\N	PRESENT	0
428054	428042	14038Y	PARTICIPANT	\N	PRESENT	0
428055	428042	18083K	PARTICIPANT	\N	PRESENT	0
428056	428042	19701S	PARTICIPANT	\N	PRESENT	0
428057	428042	19681G	PARTICIPANT	\N	PRESENT	0
428058	428042	19599P	PARTICIPANT	\N	PRESENT	0
428060	428042	19820Y	PARTICIPANT	\N	PRESENT	0
428061	428042	15447F	PARTICIPANT	\N	PRESENT	0
428062	428042	19387D	PARTICIPANT	\N	PRESENT	0
428063	428042	19347U	PARTICIPANT	\N	PRESENT	0
428064	428042	19685L	PARTICIPANT	\N	PRESENT	0
428065	428042	19333N	PARTICIPANT	\N	PRESENT	0
428066	428042	04097T	PARTICIPANT	\N	PRESENT	0
428067	428042	19551W	PARTICIPANT	\N	PRESENT	0
428068	428042	14219Q	PARTICIPANT	\N	PRESENT	0
428069	428042	14103D	PARTICIPANT	\N	PRESENT	0
428071	428042	14031R	PARTICIPANT	\N	PRESENT	0
428073	428042	19637C	PARTICIPANT	\N	PRESENT	0
428074	428042	19826F	PARTICIPANT	\N	PRESENT	0
428075	428042	08009T	PRESIDENT	0	PRESENT	0
428078	428042	14221J	PARTICIPANT	\N	PRESENT	0
428079	428042	14169X	PARTICIPANT	\N	PRESENT	0
428081	428042	14191V	PARTICIPANT	\N	PRESENT	0
428083	428042	14237S	PARTICIPANT	\N	PRESENT	0
428084	428042	19745F	PARTICIPANT	\N	PRESENT	0
428085	428042	05012A	PARTICIPANT	\N	PRESENT	0
428087	428042	19503N	PARTICIPANT	\N	PRESENT	0
428088	428042	17637T	PARTICIPANT	\N	PRESENT	0
428090	428042	19739H	PARTICIPANT	\N	PRESENT	0
428091	428042	17583W	PARTICIPANT	\N	PRESENT	0
428093	428042	19794Q	PARTICIPANT	\N	PRESENT	0
428094	428042	04069P	PARTICIPANT	\N	PRESENT	0
428095	428042	19713W	PARTICIPANT	\N	PRESENT	0
428096	428042	14157T	PARTICIPANT	\N	PRESENT	0
428098	428042	19737F	PARTICIPANT	\N	PRESENT	0
428099	428042	19525U	PARTICIPANT	\N	EXCUSE	0
428100	428042	02002K	PARTICIPANT	\N	EXCUSE	0
428101	428042	14051J	PARTICIPANT	\N	EXCUSE	0
436993	436992	08015R	PARTICIPANT	\N	PRESENT	0
436994	436992	14105F	PARTICIPANT	\N	PRESENT	0
436995	436992	11097X	PARTICIPANT	\N	PRESENT	0
436996	436992	05012A	PARTICIPANT	\N	PRESENT	0
436997	436992	04049K	PARTICIPANT	\N	PRESENT	0
436998	436992	19723Y	PARTICIPANT	\N	PRESENT	0
441878	441618	19649G	PARTICIPANT	\N	PRESENT	0
441879	441618	04092N	PRESIDENT	0	PRESENT	0
441880	441618	19569H	PARTICIPANT	\N	PRESENT	0
441881	441618	19415P	PARTICIPANT	\N	PRESENT	0
441882	441618	05008E	PARTICIPANT	\N	PRESENT	0
441883	441618	19447X	PARTICIPANT	\N	PRESENT	0
441884	441618	18083K	PARTICIPANT	\N	PRESENT	0
441885	441618	14239U	PARTICIPANT	\N	PRESENT	0
441886	441618	14042U	PARTICIPANT	\N	PRESENT	0
441887	441618	14195A	PARTICIPANT	\N	PRESENT	0
441888	441618	14147R	PARTICIPANT	\N	PRESENT	0
441889	441618	14213J	PARTICIPANT	\N	PRESENT	0
441890	441618	14215L	PARTICIPANT	\N	PRESENT	0
441891	441618	19683J	PARTICIPANT	\N	PRESENT	0
441892	441618	11072N	PARTICIPANT	\N	PRESENT	0
441893	441618	11066Q	PARTICIPANT	\N	PRESENT	0
441894	441618	19575F	PARTICIPANT	\N	PRESENT	0
441895	441618	14217N	PARTICIPANT	\N	PRESENT	0
441896	441618	19335Q	PARTICIPANT	\N	PRESENT	0
441897	441618	10006L	PARTICIPANT	\N	PRESENT	0
441898	441618	14065Q	PARTICIPANT	\N	PRESENT	0
441899	441618	08034U	PARTICIPANT	\N	PRESENT	0
441900	441618	11045K	PARTICIPANT	\N	PRESENT	0
441901	441618	08052W	PARTICIPANT	\N	PRESENT	0
441902	441618	08043V	PARTICIPANT	\N	PRESENT	0
441903	441618	11067R	PARTICIPANT	\N	EXCUSE	0
441904	439631	19533U	PARTICIPANT	\N	PRESENT	0
441905	439631	19551W	PARTICIPANT	\N	PRESENT	0
441906	439631	19782L	PARTICIPANT	\N	PRESENT	0
441907	439631	19253P	PARTICIPANT	\N	PRESENT	0
441908	439631	19737F	PARTICIPANT	\N	PRESENT	0
441909	439631	14063N	PARTICIPANT	\N	PRESENT	0
441910	439631	04085P	PARTICIPANT	\N	PRESENT	0
441911	439631	19711U	PARTICIPANT	\N	PRESENT	0
441912	439631	14053L	PARTICIPANT	\N	PRESENT	0
441913	439631	14038Y	PARTICIPANT	\N	PRESENT	0
441914	439631	14033T	PARTICIPANT	\N	PRESENT	0
441915	439631	19399H	PARTICIPANT	\N	PRESENT	0
441916	439631	14031R	PARTICIPANT	\N	PRESENT	0
441917	439631	97011G	PARTICIPANT	\N	PRESENT	0
441918	439631	19760E	PARTICIPANT	\N	PRESENT	0
441919	439631	19583F	PARTICIPANT	\N	PRESENT	0
441920	439631	08069G	PARTICIPANT	\N	PRESENT	0
441921	439631	04088S	PARTICIPANT	\N	PRESENT	0
441922	439631	14157T	PARTICIPANT	\N	PRESENT	0
441923	439631	14105F	PARTICIPANT	\N	PRESENT	0
441924	439631	11103C	PARTICIPANT	\N	PRESENT	0
441925	439631	14133K	PARTICIPANT	\N	PRESENT	0
441926	439631	17589D	PARTICIPANT	\N	PRESENT	0
441927	439631	19511N	PARTICIPANT	\N	PRESENT	0
441928	439631	19349W	PARTICIPANT	\N	PRESENT	0
441929	439631	19333N	PARTICIPANT	\N	PRESENT	0
441930	439631	19549D	PARTICIPANT	\N	PRESENT	0
441931	439631	15447F	PARTICIPANT	\N	PRESENT	0
441932	439631	19820Y	PARTICIPANT	\N	PRESENT	0
441933	439631	14241N	PARTICIPANT	\N	PRESENT	0
441934	439631	14219Q	PARTICIPANT	\N	PRESENT	0
441935	439631	14030Q	PARTICIPANT	\N	PRESENT	0
441936	439631	08031R	PARTICIPANT	\N	PRESENT	0
441937	439631	19591F	PARTICIPANT	\N	PRESENT	0
441938	439631	19745F	PARTICIPANT	\N	PRESENT	0
441939	439631	98050T	PARTICIPANT	\N	PRESENT	0
441940	439631	14026U	PARTICIPANT	\N	PRESENT	0
441941	439631	14147R	PARTICIPANT	\N	PRESENT	0
441942	439631	87003B	PARTICIPANT	\N	PRESENT	0
441943	439631	19251M	PARTICIPANT	\N	PRESENT	0
441944	439631	08028W	PARTICIPANT	\N	PRESENT	0
441945	439631	19387D	PARTICIPANT	\N	PRESENT	0
441946	439631	08049C	PARTICIPANT	\N	PRESENT	0
441947	439631	08061X	PARTICIPANT	\N	PRESENT	0
441948	439631	19565D	PARTICIPANT	\N	PRESENT	0
441949	439631	19581D	PARTICIPANT	\N	PRESENT	0
441950	439631	95030B	PARTICIPANT	\N	PRESENT	0
441951	439631	19725B	PARTICIPANT	\N	PRESENT	0
441952	439631	19631V	PARTICIPANT	\N	PRESENT	0
441953	439631	14265W	PARTICIPANT	\N	PRESENT	0
441954	439631	08015R	PARTICIPANT	\N	PRESENT	0
441955	439631	14223L	PARTICIPANT	\N	PRESENT	0
441956	439631	19521Q	PARTICIPANT	\N	PRESENT	0
441957	439631	19441R	PARTICIPANT	\N	PRESENT	0
441960	441791	19421M	PARTICIPANT	\N	PRESENT	0
441971	439631	01043Q	PARTICIPANT	\N	PRESENT	0
441976	439631	14179A	PARTICIPANT	\N	PRESENT	0
441991	439631	19703U	PARTICIPANT	\N	PRESENT	0
441992	439631	11048N	PARTICIPANT	\N	PRESENT	0
441993	439631	19798U	PARTICIPANT	\N	PRESENT	0
441994	439631	11040E	PARTICIPANT	\N	PRESENT	0
441995	439631	14029X	PARTICIPANT	\N	PRESENT	0
441996	439631	14083S	PARTICIPANT	\N	PRESENT	0
441997	439631	08056B	PARTICIPANT	\N	PRESENT	0
441998	439631	01025N	PARTICIPANT	\N	PRESENT	0
441999	439631	08009T	PARTICIPANT	\N	PRESENT	0
442000	439631	01024M	PARTICIPANT	\N	PRESENT	0
442001	439631	19758L	PARTICIPANT	\N	PRESENT	0
442002	439631	19503N	PARTICIPANT	\N	PRESENT	0
442003	439631	11104D	PARTICIPANT	\N	PRESENT	0
442004	439631	19563B	PARTICIPANT	\N	PRESENT	0
442005	439631	14109K	PARTICIPANT	\N	PRESENT	0
442006	439631	19731Y	PARTICIPANT	\N	PRESENT	0
442007	439631	19507S	PARTICIPANT	\N	PRESENT	0
442008	439631	04069P	PARTICIPANT	\N	PRESENT	0
442009	439631	14199E	PARTICIPANT	\N	PRESENT	0
442010	439631	11012A	PARTICIPANT	\N	PRESENT	0
442011	439631	14081Q	PARTICIPANT	\N	PRESENT	0
442012	439631	14051J	PARTICIPANT	\N	PRESENT	0
442013	441618	11031D	PARTICIPANT	\N	PRESENT	0
442014	441618	14179A	PARTICIPANT	\N	PRESENT	0
442015	441618	99004R	PARTICIPANT	\N	PRESENT	0
442016	439631	19383Y	PARTICIPANT	\N	PRESENT	0
442017	439631	14069U	PARTICIPANT	\N	PRESENT	0
442018	439631	19713W	PARTICIPANT	\N	PRESENT	0
432352	425276	14034U	PARTICIPANT	\N	PRESENT	0
432353	425276	08011M	PARTICIPANT	\N	PRESENT	0
432354	425276	11074Q	PARTICIPANT	\N	PRESENT	0
432355	425276	19551W	PARTICIPANT	\N	PRESENT	0
432356	425276	19565D	PARTICIPANT	\N	PRESENT	0
432357	425276	14085U	PARTICIPANT	\N	PRESENT	0
432358	425276	14197C	PARTICIPANT	\N	PRESENT	0
432359	425276	19413M	PARTICIPANT	\N	PRESENT	0
432360	425276	14021P	PARTICIPANT	\N	PRESENT	0
432361	425276	19349W	PARTICIPANT	\N	PRESENT	0
432362	425276	08020N	PARTICIPANT	\N	PRESENT	0
432363	425276	19545Y	PARTICIPANT	\N	PRESENT	0
432364	425276	11064N	PARTICIPANT	\N	PRESENT	0
432365	425276	04086Q	PARTICIPANT	\N	PRESENT	0
432366	425276	14251Q	PARTICIPANT	\N	PRESENT	0
432367	425276	19479G	PARTICIPANT	\N	PRESENT	0
432368	425276	19713W	PARTICIPANT	\N	PRESENT	0
432369	425276	19735D	PARTICIPANT	\N	PRESENT	0
432370	425276	01034P	PARTICIPANT	\N	PRESENT	0
432371	425276	14107H	PARTICIPANT	\N	PRESENT	0
432372	425276	19629C	PARTICIPANT	\N	PRESENT	0
432373	425276	19651A	PARTICIPANT	\N	PRESENT	0
432374	425276	11012A	PARTICIPANT	\N	PRESENT	0
432375	425276	07029T	PARTICIPANT	\N	PRESENT	0
432376	425276	19733B	PARTICIPANT	\N	PRESENT	0
432377	425276	14033T	PARTICIPANT	\N	PRESENT	0
432378	425276	14147R	PARTICIPANT	\N	PRESENT	0
432379	425276	19711U	PARTICIPANT	\N	PRESENT	0
432380	425276	19826F	PARTICIPANT	\N	PRESENT	0
432381	425276	19681G	PARTICIPANT	\N	PRESENT	0
432382	425276	11048N	PARTICIPANT	\N	PRESENT	0
432383	425276	14083S	PARTICIPANT	\N	PRESENT	0
432384	425276	01057W	PARTICIPANT	\N	PRESENT	0
432385	425276	18083K	PARTICIPANT	\N	PRESENT	0
432386	425276	19741B	PARTICIPANT	\N	PRESENT	0
434562	434561	14215L	PARTICIPANT	\N	PRESENT	0
434563	434561	19447X	PARTICIPANT	\N	PRESENT	0
434565	434564	11031D	PARTICIPANT	\N	PRESENT	0
434566	434564	19683J	PARTICIPANT	\N	PRESENT	0
434567	434564	11067R	PARTICIPANT	\N	PRESENT	0
434573	434571	19683J	PARTICIPANT	\N	PRESENT	0
434574	434571	19447X	PARTICIPANT	\N	PRESENT	0
434575	434571	11031D	PARTICIPANT	\N	PRESENT	0
434577	434571	11067R	PARTICIPANT	\N	PRESENT	0
434579	434352	19683J	PARTICIPANT	\N	PRESENT	0
435245	435244	14073Q	PARTICIPANT	\N	PRESENT	0
435246	435244	04057K	PARTICIPANT	\N	PRESENT	0
435343	435330	14213J	PARTICIPANT	\N	PRESENT	0
435345	435341	14213J	PARTICIPANT	\N	PRESENT	0
436263	433965	11027H	PARTICIPANT	\N	PRESENT	0
436264	433965	95067Q	PARTICIPANT	\N	PRESENT	0
436265	434669	19671E	PARTICIPANT	\N	PRESENT	0
436266	434669	19647E	PARTICIPANT	\N	PRESENT	0
436267	434669	12016W	PARTICIPANT	\N	PRESENT	0
436268	434669	08011M	PARTICIPANT	\N	EXCUSE	0
436364	435793	11077T	PARTICIPANT	\N	PRESENT	0
436365	435793	19413M	PARTICIPANT	\N	PRESENT	0
436366	435793	19631V	PARTICIPANT	\N	PRESENT	0
436367	435793	11099A	PARTICIPANT	\N	PRESENT	0
436368	435793	14329V	PARTICIPANT	\N	PRESENT	0
436369	435793	04089T	PARTICIPANT	\N	PRESENT	0
436370	435793	14115H	PARTICIPANT	\N	PRESENT	0
436371	435793	01043Q	PARTICIPANT	\N	EXCUSE	0
436373	432684	19697Q	PARTICIPANT	\N	PRESENT	0
436374	432684	11067R	PARTICIPANT	\N	PRESENT	0
436375	432684	19798U	PARTICIPANT	\N	PRESENT	0
436376	432684	11097X	PARTICIPANT	\N	PRESENT	0
436377	432684	14223L	PARTICIPANT	\N	PRESENT	0
436378	432684	14026U	PARTICIPANT	\N	PRESENT	0
436379	432684	14227Q	PARTICIPANT	\N	PRESENT	0
436380	432684	17779H	PARTICIPANT	\N	PRESENT	0
436381	432684	19553Y	PARTICIPANT	\N	PRESENT	0
436382	432684	19703U	PARTICIPANT	\N	PRESENT	0
436383	432684	11031D	PARTICIPANT	\N	PRESENT	0
436384	432684	14087W	PARTICIPANT	\N	PRESENT	0
436385	432684	14281W	PARTICIPANT	\N	PRESENT	0
436386	432684	19679N	PARTICIPANT	\N	PRESENT	0
436387	432684	14042U	PARTICIPANT	\N	PRESENT	0
436388	432684	19575F	PARTICIPANT	\N	PRESENT	0
436389	432684	08048B	PARTICIPANT	\N	PRESENT	0
436390	432684	14195A	PARTICIPANT	\N	PRESENT	0
436391	432684	14213J	PARTICIPANT	\N	PRESENT	0
436392	432684	14217N	PARTICIPANT	\N	PRESENT	0
436393	432684	14261S	PARTICIPANT	\N	PRESENT	0
436394	432684	19683J	PARTICIPANT	\N	PRESENT	0
436395	432684	98024R	PARTICIPANT	\N	PRESENT	0
436396	432684	19521Q	PARTICIPANT	\N	PRESENT	0
436397	432684	19527W	PARTICIPANT	\N	PRESENT	0
436398	432684	01034P	PARTICIPANT	\N	PRESENT	0
436399	432684	04092N	PRESIDENT	0	PRESENT	0
436400	432684	11045K	PARTICIPANT	\N	PRESENT	0
436401	432684	08052W	PARTICIPANT	\N	PRESENT	0
436402	432684	19663E	PARTICIPANT	\N	PRESENT	0
436403	432684	19301E	PARTICIPANT	\N	PRESENT	0
436404	432684	19691J	PARTICIPANT	\N	PRESENT	0
436405	432684	19723Y	PARTICIPANT	\N	PRESENT	0
436406	432684	19727D	PARTICIPANT	\N	PRESENT	0
436407	432684	14119M	PARTICIPANT	\N	PRESENT	0
436408	432684	11103C	PARTICIPANT	\N	PRESENT	0
436409	432684	19657G	PARTICIPANT	\N	PRESENT	0
436410	432684	14071N	PARTICIPANT	\N	PRESENT	0
436411	432684	19760E	PARTICIPANT	\N	PRESENT	0
436412	432684	14355X	PARTICIPANT	\N	EXCUSE	0
436413	432684	19565D	PARTICIPANT	\N	EXCUSE	0
436414	432684	08041T	PARTICIPANT	\N	EXCUSE	0
436415	428273	01057W	PARTICIPANT	\N	PRESENT	0
436416	428273	14225N	PARTICIPANT	\N	PRESENT	0
436417	428273	14179A	PARTICIPANT	\N	PRESENT	0
436418	428273	12016W	PARTICIPANT	\N	PRESENT	0
436419	428273	14085U	PARTICIPANT	\N	PRESENT	0
436420	428273	14001X	PARTICIPANT	\N	PRESENT	0
436421	428273	19525U	PARTICIPANT	\N	PRESENT	0
436422	428273	01028R	PARTICIPANT	\N	PRESENT	0
436423	428273	19651A	PARTICIPANT	\N	PRESENT	0
436424	428273	19387D	PARTICIPANT	\N	PRESENT	0
436425	428273	14121F	PARTICIPANT	\N	PRESENT	0
436426	428273	11074Q	PARTICIPANT	\N	PRESENT	0
436427	428273	19349W	PARTICIPANT	\N	PRESENT	0
436428	428273	04086Q	PARTICIPANT	\N	PRESENT	0
436429	428273	08073C	PARTICIPANT	\N	PRESENT	0
436430	428273	19629C	PARTICIPANT	\N	PRESENT	0
436431	428273	19711U	PARTICIPANT	\N	PRESENT	0
436432	428273	14223L	PARTICIPANT	\N	PRESENT	0
436433	428273	11012A	PARTICIPANT	\N	PRESENT	0
436434	428273	11048N	PARTICIPANT	\N	PRESENT	0
436435	428273	14327T	PARTICIPANT	\N	PRESENT	0
436436	428273	14231L	PARTICIPANT	\N	PRESENT	0
436437	428273	14083S	PARTICIPANT	\N	PRESENT	0
436438	428273	19671E	PARTICIPANT	\N	PRESENT	0
436439	428273	14053L	PARTICIPANT	\N	PRESENT	0
436440	428273	08069G	PARTICIPANT	\N	PRESENT	0
436441	428273	14249W	PARTICIPANT	\N	PRESENT	0
436442	428273	05008E	PARTICIPANT	\N	PRESENT	0
436443	428273	04038G	PARTICIPANT	\N	PRESENT	0
436444	428273	14151M	PARTICIPANT	\N	PRESENT	0
436445	428273	14021P	PARTICIPANT	\N	PRESENT	0
436446	428273	19543W	PARTICIPANT	\N	PRESENT	0
436447	428273	19479G	PARTICIPANT	\N	PRESENT	0
436448	428273	19826F	PARTICIPANT	\N	PRESENT	0
436449	428273	19383Y	PARTICIPANT	\N	PRESENT	0
436450	428273	19673G	PARTICIPANT	\N	PRESENT	0
436451	428273	19687N	PARTICIPANT	\N	PRESENT	0
436452	428273	08052W	PARTICIPANT	\N	PRESENT	0
436453	435793	19591F	PARTICIPANT	\N	PRESENT	0
436454	435793	04043D	PARTICIPANT	\N	PRESENT	0
436455	428273	17637T	PARTICIPANT	\N	PRESENT	0
436456	428273	14215L	PARTICIPANT	\N	PRESENT	0
436457	428273	19301E	PARTICIPANT	\N	PRESENT	0
436458	428273	11103C	PARTICIPANT	\N	PRESENT	0
436459	428273	14089Y	PARTICIPANT	\N	PRESENT	0
436460	428273	14107H	PARTICIPANT	\N	PRESENT	0
428669	428199	19479G	PARTICIPANT	\N	PRESENT	0
428670	428199	19533U	PARTICIPANT	\N	PRESENT	0
428712	416366	04042C	PARTICIPANT	\N	PRESENT	0
428672	428199	89017R	PARTICIPANT	\N	PRESENT	0
428673	428199	19693L	PARTICIPANT	\N	PRESENT	0
428674	428199	19671E	PARTICIPANT	\N	PRESENT	0
428675	428199	11070L	PARTICIPANT	\N	PRESENT	0
428676	428199	14173T	PARTICIPANT	\N	PRESENT	0
428677	428199	11040E	PARTICIPANT	\N	PRESENT	0
428678	428199	19741B	PARTICIPANT	\N	PRESENT	0
428679	428199	99004R	PARTICIPANT	\N	PRESENT	0
428680	428199	14253S	PARTICIPANT	\N	PRESENT	0
428681	428199	19711U	PARTICIPANT	\N	PRESENT	0
428682	428199	88008L	PARTICIPANT	\N	PRESENT	0
428696	428199	96004D	PARTICIPANT	\N	PRESENT	0
428697	416366	14151M	PARTICIPANT	\N	PRESENT	0
428698	428199	01048V	PARTICIPANT	\N	PRESENT	0
428699	416366	14079W	PARTICIPANT	\N	PRESENT	0
428700	428199	11048N	PARTICIPANT	\N	PRESENT	0
428701	416366	19251M	PARTICIPANT	\N	PRESENT	0
428702	416366	19794Q	PARTICIPANT	\N	PRESENT	0
428703	428199	01057W	PRESIDENT	0	PRESENT	0
428704	416366	19253P	PARTICIPANT	\N	PRESENT	0
428711	428199	08069G	PARTICIPANT	\N	PRESENT	0
428713	416366	14073Q	PARTICIPANT	\N	PRESENT	0
428714	416366	19713W	PARTICIPANT	\N	PRESENT	0
428715	416366	19573D	PARTICIPANT	\N	PRESENT	0
428717	416366	11012A	PARTICIPANT	\N	PRESENT	0
428718	416366	19347U	PARTICIPANT	\N	PRESENT	0
428719	416366	19820Y	PARTICIPANT	\N	PRESENT	0
428721	416366	14157T	PARTICIPANT	\N	PRESENT	0
428723	428199	19689Q	PARTICIPANT	\N	PRESENT	0
428724	416366	19369B	PARTICIPANT	\N	PRESENT	0
428725	416366	04085P	PARTICIPANT	\N	PRESENT	0
428726	416366	19443T	PARTICIPANT	\N	PRESENT	0
428727	416366	17583W	PARTICIPANT	\N	PRESENT	0
428728	428199	14034U	PARTICIPANT	\N	PRESENT	0
428729	416366	19637C	PARTICIPANT	\N	PRESENT	0
428730	416366	14179A	PARTICIPANT	\N	PRESENT	0
428810	416367	19347U	PARTICIPANT	\N	PRESENT	0
428811	416367	19683J	PARTICIPANT	\N	PRESENT	0
428812	416367	19333N	PARTICIPANT	\N	PRESENT	0
428813	416367	19697Q	PARTICIPANT	\N	PRESENT	0
428814	416367	19637C	PARTICIPANT	\N	PRESENT	0
428815	416367	11031D	PARTICIPANT	\N	PRESENT	0
428827	416367	14031R	PARTICIPANT	\N	PRESENT	0
428892	416367	01024M	PARTICIPANT	\N	PRESENT	0
428893	427858	08056B	PARTICIPANT	\N	PRESENT	0
428894	427858	14097Y	PARTICIPANT	\N	PRESENT	0
428895	427858	19443T	PARTICIPANT	\N	PRESENT	0
428896	427858	04042C	PRESIDENT	0	PRESENT	0
428898	427858	19768N	PARTICIPANT	\N	PRESENT	0
428899	427858	08019V	PARTICIPANT	\N	PRESENT	0
428900	427858	08062Y	PARTICIPANT	\N	PRESENT	0
428901	427858	11090Q	PARTICIPANT	\N	PRESENT	0
428902	427858	14265W	PARTICIPANT	\N	PRESENT	0
428912	427858	14033T	PARTICIPANT	\N	PRESENT	0
428913	427858	11066Q	PARTICIPANT	\N	PRESENT	0
428914	427858	19721W	PARTICIPANT	\N	PRESENT	0
428915	427858	04088S	PARTICIPANT	\N	PRESENT	0
428916	427858	95037J	PARTICIPANT	\N	PRESENT	0
428917	427858	08053X	PARTICIPANT	\N	PRESENT	0
428918	427858	04043D	PARTICIPANT	\N	PRESENT	0
428919	427858	08028W	PARTICIPANT	\N	PRESENT	0
428920	427858	14257W	PARTICIPANT	\N	PRESENT	0
429753	427448	11065P	PARTICIPANT	\N	PRESENT	0
429873	429872	08009T	PARTICIPANT	\N	PRESENT	0
436902	436894	14257W	PARTICIPANT	\N	PRESENT	0
436903	436894	19768N	PARTICIPANT	\N	PRESENT	0
436904	436895	14257W	PARTICIPANT	\N	PRESENT	0
436905	436895	19768N	PARTICIPANT	\N	PRESENT	0
436906	436896	14257W	PARTICIPANT	\N	PRESENT	0
436907	436897	14257W	PARTICIPANT	\N	PRESENT	0
436908	436897	19768N	PARTICIPANT	\N	PRESENT	0
436909	436898	19768N	PARTICIPANT	\N	PRESENT	0
436958	436957	14225N	PARTICIPANT	\N	PRESENT	0
436959	436957	07033P	PARTICIPANT	\N	PRESENT	0
436960	436957	14151M	PARTICIPANT	\N	PRESENT	0
436961	436957	14087W	PARTICIPANT	\N	PRESENT	0
436962	436957	14241N	PARTICIPANT	\N	PRESENT	0
436963	436957	11026G	PARTICIPANT	\N	PRESENT	0
436965	436957	95063L	PARTICIPANT	\N	PRESENT	0
436966	436957	19747H	PARTICIPANT	\N	PRESENT	0
436967	436957	11027H	PARTICIPANT	\N	PRESENT	0
440943	440941	14133K	PARTICIPANT	\N	PRESENT	0
440945	440941	96004D	PRESIDENT	0	PRESENT	0
440946	440941	14089Y	PARTICIPANT	\N	PRESENT	0
440947	440941	14357A	PARTICIPANT	\N	EXCUSE	0
440948	440941	14079W	PARTICIPANT	\N	PRESENT	0
440949	440941	04035D	PARTICIPANT	\N	PRESENT	0
440950	440941	11083R	PARTICIPANT	\N	PRESENT	0
440951	440941	19553Y	PARTICIPANT	\N	PRESENT	0
440952	440941	95037J	PARTICIPANT	\N	PRESENT	0
440953	440941	08044W	PARTICIPANT	\N	EXCUSE	0
440954	440941	14097Y	PARTICIPANT	\N	PRESENT	0
440955	440941	11026G	PARTICIPANT	\N	PRESENT	0
440956	440941	04057K	PARTICIPANT	\N	EXCUSE	0
440957	440941	14237S	PARTICIPANT	\N	PRESENT	0
440958	440941	14331P	PARTICIPANT	\N	PRESENT	0
440959	440941	10015M	PARTICIPANT	\N	PRESENT	0
440960	440941	14026U	PARTICIPANT	\N	EXCUSE	0
440961	440941	14001X	PARTICIPANT	\N	EXCUSE	0
440962	440941	14061L	PARTICIPANT	\N	EXCUSE	0
440965	440941	04034C	PARTICIPANT	\N	PRESENT	0
445660	439810	04092N	PARTICIPANT	\N	PRESENT	0
445661	439810	19347U	PARTICIPANT	\N	PRESENT	0
445662	439810	19695N	PARTICIPANT	\N	PRESENT	0
445663	439810	04085P	PARTICIPANT	\N	PRESENT	0
445664	439810	19593H	PARTICIPANT	\N	PRESENT	0
445665	439810	19503N	PARTICIPANT	\N	PRESENT	0
445666	439810	11067R	PARTICIPANT	\N	PRESENT	0
445687	439810	14031R	PARTICIPANT	\N	PRESENT	0
445668	439810	19551W	PARTICIPANT	\N	PRESENT	0
445669	439810	19333N	PARTICIPANT	\N	PRESENT	0
428806	416367	01043Q	PARTICIPANT	\N	PRESENT	0
428808	428199	07004J	PARTICIPANT	\N	PRESENT	0
428809	428199	11012A	PARTICIPANT	\N	PRESENT	0
445670	439810	14281W	PARTICIPANT	\N	PRESENT	0
445671	439810	14081Q	PARTICIPANT	\N	PRESENT	0
445672	439810	19697Q	PARTICIPANT	\N	PRESENT	0
445673	439810	14251Q	PARTICIPANT	\N	PRESENT	0
445674	439810	19479G	PARTICIPANT	\N	PRESENT	0
445675	439810	19441R	PARTICIPANT	\N	PRESENT	0
445676	439810	14030Q	PARTICIPANT	\N	PRESENT	0
445677	439810	01024M	PARTICIPANT	\N	PRESENT	0
445678	439810	19521Q	PARTICIPANT	\N	PRESENT	0
445679	439810	19687N	PARTICIPANT	\N	PRESENT	0
445680	439810	19413M	PARTICIPANT	\N	PRESENT	0
445681	439810	14021P	PARTICIPANT	\N	PRESENT	0
445682	439810	19737F	PARTICIPANT	\N	PRESENT	0
445683	439810	11012A	PARTICIPANT	\N	PRESENT	0
445684	439810	19295A	PARTICIPANT	\N	PRESENT	0
445685	439810	14157T	PARTICIPANT	\N	PRESENT	0
445686	439810	19762G	PARTICIPANT	\N	PRESENT	0
445688	439810	14073Q	PARTICIPANT	\N	PRESENT	0
445689	439810	17779H	PARTICIPANT	\N	PRESENT	0
445690	439810	14053L	PARTICIPANT	\N	PRESENT	0
445691	439810	14087W	PARTICIPANT	\N	PRESENT	0
445692	439810	04088S	PARTICIPANT	\N	PRESENT	0
445693	439810	19443T	PARTICIPANT	\N	PRESENT	0
445694	439810	14219Q	PARTICIPANT	\N	PRESENT	0
445695	439810	08055A	PARTICIPANT	\N	PRESENT	0
445696	439810	14051J	PARTICIPANT	\N	PRESENT	0
445697	439810	19369B	PARTICIPANT	\N	PRESENT	0
445698	439810	14034U	PARTICIPANT	\N	PRESENT	0
445699	439810	19531S	PARTICIPANT	\N	PRESENT	0
445700	439810	08052W	PARTICIPANT	\N	PRESENT	0
445701	439810	14089Y	PARTICIPANT	\N	PRESENT	0
445658	439810	04059M	PARTICIPANT	\N	PRESENT	0
445659	439810	19727D	PARTICIPANT	\N	PRESENT	0
445712	445711	14069U	PARTICIPANT	\N	PRESENT	0
445714	445713	14069U	PARTICIPANT	\N	PRESENT	0
445720	445719	14069U	PARTICIPANT	\N	PRESENT	0
445721	445719	95063L	PARTICIPANT	\N	PRESENT	0
445722	436811	08043V	PARTICIPANT	\N	EXCUSE	0
445723	436811	19599P	PARTICIPANT	\N	EXCUSE	0
445726	436811	14030Q	PRESIDENT	0	PRESENT	0
445727	436811	19701S	PARTICIPANT	\N	PRESENT	0
445728	436811	80013X	PARTICIPANT	\N	PRESENT	0
445729	436811	19693L	PARTICIPANT	\N	PRESENT	0
445730	436811	14179A	PARTICIPANT	\N	PRESENT	0
445731	436811	08031R	PARTICIPANT	\N	PRESENT	0
445732	436811	07029T	PARTICIPANT	\N	PRESENT	0
445733	436811	11067R	PARTICIPANT	\N	PRESENT	0
445734	436811	11045K	PARTICIPANT	\N	PRESENT	0
445735	436811	19749K	PARTICIPANT	\N	PRESENT	0
445736	436811	14235Q	PARTICIPANT	\N	PRESENT	0
445737	441747	14261S	PARTICIPANT	\N	PRESENT	0
445738	441747	14259Y	PARTICIPANT	\N	EXCUSE	0
432775	430308	19697Q	PARTICIPANT	\N	PRESENT	0
432776	430308	11067R	PARTICIPANT	\N	PRESENT	0
432777	430308	01034P	PARTICIPANT	\N	PRESENT	0
432778	430308	19565D	PARTICIPANT	\N	PRESENT	0
432779	430308	14355X	PARTICIPANT	\N	PRESENT	0
432780	430308	04092N	PRESIDENT	0	PRESENT	0
432781	430308	19798U	PARTICIPANT	\N	PRESENT	0
432782	430308	11097X	PARTICIPANT	\N	PRESENT	0
432783	430308	08052W	PARTICIPANT	\N	PRESENT	0
432784	430308	19415P	PARTICIPANT	\N	PRESENT	0
432785	430308	14227Q	PARTICIPANT	\N	PRESENT	0
432786	430308	19723Y	PARTICIPANT	\N	PRESENT	0
432787	430308	19553Y	PARTICIPANT	\N	PRESENT	0
432788	430308	14119M	PARTICIPANT	\N	PRESENT	0
432789	430308	14281W	PARTICIPANT	\N	PRESENT	0
432790	430308	19679N	PARTICIPANT	\N	PRESENT	0
432791	430308	11103C	PARTICIPANT	\N	PRESENT	0
432792	430308	14042U	PARTICIPANT	\N	PRESENT	0
432793	430308	14195A	PARTICIPANT	\N	PRESENT	0
432794	430308	14071N	PARTICIPANT	\N	PRESENT	0
432795	430308	14217N	PARTICIPANT	\N	PRESENT	0
432796	430308	19683J	PARTICIPANT	\N	PRESENT	0
432797	430308	10006L	PARTICIPANT	\N	PRESENT	0
432798	430308	08041T	PARTICIPANT	\N	EXCUSE	0
432920	432800	14093U	PARTICIPANT	\N	PRESENT	0
432921	425283	95063L	PARTICIPANT	\N	PRESENT	0
432922	425283	04059M	PARTICIPANT	\N	PRESENT	0
432923	425283	11074Q	PARTICIPANT	\N	PRESENT	0
432924	425283	11031D	PARTICIPANT	\N	PRESENT	0
432925	425283	19760E	PARTICIPANT	\N	PRESENT	0
432926	425283	11056N	PARTICIPANT	\N	PRESENT	0
432927	425283	04038G	PARTICIPANT	\N	PRESENT	0
432928	425283	19695N	PARTICIPANT	\N	PRESENT	0
432929	425283	11077T	PARTICIPANT	\N	PRESENT	0
432930	425283	19647E	PARTICIPANT	\N	PRESENT	0
432931	425283	19741B	PARTICIPANT	\N	PRESENT	0
432932	425283	14235Q	PARTICIPANT	\N	PRESENT	0
432933	425283	14029X	PARTICIPANT	\N	PRESENT	0
432934	425283	95037J	PARTICIPANT	\N	PRESENT	0
432935	425283	14239U	PARTICIPANT	\N	PRESENT	0
432936	425283	19663E	PARTICIPANT	\N	PRESENT	0
432937	425283	11083R	PARTICIPANT	\N	PRESENT	0
432938	425283	19637C	PARTICIPANT	\N	PRESENT	0
432939	425283	04088S	PARTICIPANT	\N	PRESENT	0
432940	425283	19543W	PARTICIPANT	\N	PRESENT	0
432941	425283	14041T	PARTICIPANT	\N	PRESENT	0
432942	425283	19269X	PARTICIPANT	\N	PRESENT	0
432943	425283	07029T	PARTICIPANT	\N	PRESENT	0
432944	425283	19697Q	PARTICIPANT	\N	PRESENT	0
432945	425283	19657G	PARTICIPANT	\N	PRESENT	0
432946	425283	08024S	PARTICIPANT	\N	PRESENT	0
432947	425283	14355X	PARTICIPANT	\N	PRESENT	0
432948	425283	19347U	PARTICIPANT	\N	PRESENT	0
432949	425283	08015R	PARTICIPANT	\N	PRESENT	0
432950	425283	19301E	PARTICIPANT	\N	PRESENT	0
432951	425283	19705W	PARTICIPANT	\N	PRESENT	0
432952	425283	19685L	PARTICIPANT	\N	PRESENT	0
432953	425283	98050T	PARTICIPANT	\N	PRESENT	0
432954	425283	19731Y	PARTICIPANT	\N	PRESENT	0
432955	425283	08056B	PARTICIPANT	\N	PRESENT	0
432956	425283	14061L	PARTICIPANT	\N	PRESENT	0
432957	425283	14059S	PARTICIPANT	\N	PRESENT	0
432958	425283	14038Y	PARTICIPANT	\N	PRESENT	0
432959	425283	08031R	PARTICIPANT	\N	PRESENT	0
432960	425283	19723Y	PARTICIPANT	\N	PRESENT	0
432961	425283	11012A	PARTICIPANT	\N	PRESENT	0
432962	425283	08049C	PARTICIPANT	\N	PRESENT	0
432963	425283	19507S	PARTICIPANT	\N	PRESENT	0
432964	425283	14261S	PARTICIPANT	\N	PRESENT	0
432965	425283	14135M	PARTICIPANT	\N	PRESENT	0
432966	425283	14034U	PARTICIPANT	\N	PRESENT	0
432967	425283	18083K	PARTICIPANT	\N	PRESENT	0
432968	425283	19387D	PARTICIPANT	\N	PRESENT	0
432969	425283	19629C	PARTICIPANT	\N	PRESENT	0
432970	425283	19415P	PARTICIPANT	\N	PRESENT	0
432971	425283	08019V	PARTICIPANT	\N	PRESENT	0
432972	425283	14241N	PARTICIPANT	\N	PRESENT	0
432973	425283	19399H	PARTICIPANT	\N	PRESENT	0
432974	425283	19719D	PARTICIPANT	\N	PRESENT	0
432975	425283	19693L	PARTICIPANT	\N	PRESENT	0
432976	425283	14107H	PARTICIPANT	\N	PRESENT	0
432977	425283	19729F	PARTICIPANT	\N	PRESENT	0
432978	425283	14207L	PARTICIPANT	\N	PRESENT	0
432979	425283	11099A	PARTICIPANT	\N	PRESENT	0
432980	425283	14213J	PARTICIPANT	\N	PRESENT	0
432981	425283	19289C	PARTICIPANT	\N	PRESENT	0
432982	425283	14329V	PARTICIPANT	\N	PRESENT	0
432983	425283	14357A	PARTICIPANT	\N	PRESENT	0
432984	425283	14121F	PARTICIPANT	\N	PRESENT	0
432985	425283	19675J	PARTICIPANT	\N	PRESENT	0
432986	425283	19383Y	PARTICIPANT	\N	PRESENT	0
432987	425283	19762G	PARTICIPANT	\N	PRESENT	0
432988	425283	14111D	PARTICIPANT	\N	PRESENT	0
432989	425283	19545Y	PARTICIPANT	\N	PRESENT	0
432990	425283	14093U	PARTICIPANT	\N	PRESENT	0
432991	425283	19701S	PARTICIPANT	\N	PRESENT	0
432992	425283	11115U	PARTICIPANT	\N	PRESENT	0
432993	425283	17589D	PARTICIPANT	\N	PRESENT	0
432994	425283	11064N	PARTICIPANT	\N	PRESENT	0
432995	425283	14173T	PARTICIPANT	\N	PRESENT	0
432996	425283	14251Q	PARTICIPANT	\N	PRESENT	0
432997	425283	19563B	PARTICIPANT	\N	PRESENT	0
432998	425283	19573D	PARTICIPANT	\N	PRESENT	0
432999	425283	19794Q	PARTICIPANT	\N	PRESENT	0
433000	425283	19585H	PARTICIPANT	\N	PRESENT	0
433001	425283	04057K	PARTICIPANT	\N	PRESENT	0
433002	425283	14133K	PARTICIPANT	\N	PRESENT	0
433003	425283	14195A	PARTICIPANT	\N	PRESENT	0
433004	425283	92040Q	PARTICIPANT	\N	PRESENT	0
433005	425283	14119M	PARTICIPANT	\N	PRESENT	0
433006	425283	08010L	PARTICIPANT	\N	PRESENT	0
433007	425283	11049P	PARTICIPANT	\N	PRESENT	0
433008	425283	04085P	PARTICIPANT	\N	PRESENT	0
433009	425283	14115H	PARTICIPANT	\N	PRESENT	0
433010	425283	08047A	PARTICIPANT	\N	PRESENT	0
433011	425283	14055N	PARTICIPANT	\N	PRESENT	0
433012	425283	19758L	PARTICIPANT	\N	PRESENT	0
433013	425283	17583W	PARTICIPANT	\N	PRESENT	0
433014	425283	14105F	PARTICIPANT	\N	PRESENT	0
433015	425283	97011G	PARTICIPANT	\N	PRESENT	0
433016	425283	11103C	PARTICIPANT	\N	PRESENT	0
433017	425283	14217N	PARTICIPANT	\N	PRESENT	0
433018	425283	14229S	PARTICIPANT	\N	PRESENT	0
433019	425283	07033P	PARTICIPANT	\N	PRESENT	0
433020	425283	08052W	PARTICIPANT	\N	PRESENT	0
433021	425283	14079W	PARTICIPANT	\N	PRESENT	0
433022	425283	01028R	PARTICIPANT	\N	PRESENT	0
433023	425283	19671E	PARTICIPANT	\N	PRESENT	0
433024	425283	19689Q	PARTICIPANT	\N	PRESENT	0
433025	425283	08068F	PARTICIPANT	\N	PRESENT	0
433026	425283	19581D	PARTICIPANT	\N	PRESENT	0
433027	425283	19703U	PARTICIPANT	\N	PRESENT	0
433028	425283	14021P	PARTICIPANT	\N	PRESENT	0
433029	425283	19673G	PARTICIPANT	\N	PRESENT	0
433030	425283	14225N	PARTICIPANT	\N	PRESENT	0
433031	425283	14031R	PARTICIPANT	\N	PRESENT	0
433032	425283	19667J	PARTICIPANT	\N	PRESENT	0
433033	425283	12016W	PARTICIPANT	\N	PRESENT	0
433034	425283	19575F	PARTICIPANT	\N	PRESENT	0
433035	425283	14151M	PARTICIPANT	\N	PRESENT	0
433036	425283	14253S	PARTICIPANT	\N	PRESENT	0
433037	425283	04049K	PARTICIPANT	\N	PRESENT	0
433038	425283	05012A	PARTICIPANT	\N	PRESENT	0
433039	425283	08034U	PARTICIPANT	\N	PRESENT	0
433040	425283	19533U	PARTICIPANT	\N	PRESENT	0
433041	425283	08060W	PARTICIPANT	\N	PRESENT	0
433042	425283	95067Q	PARTICIPANT	\N	PRESENT	0
433043	425283	01062T	PARTICIPANT	\N	PRESENT	0
433044	425283	10006L	PARTICIPANT	\N	PRESENT	0
433045	425283	08038Y	PARTICIPANT	\N	PRESENT	0
433046	425283	19798U	PARTICIPANT	\N	PRESENT	0
433047	425283	11045K	PARTICIPANT	\N	PRESENT	0
433048	425283	14193X	PARTICIPANT	\N	PRESENT	0
433049	425283	19649G	PARTICIPANT	\N	PRESENT	0
433050	425283	14237S	PARTICIPANT	\N	PRESENT	0
433051	425283	19553Y	PARTICIPANT	\N	PRESENT	0
433052	425283	19515S	PARTICIPANT	\N	PRESENT	0
433053	425283	14191V	PARTICIPANT	\N	PRESENT	0
433054	425283	14065Q	PARTICIPANT	\N	PRESENT	0
433055	425283	08062Y	PARTICIPANT	\N	PRESENT	0
433056	425283	08012N	PARTICIPANT	\N	PRESENT	0
433057	425283	11080N	PARTICIPANT	\N	PRESENT	0
433058	425283	19820Y	PARTICIPANT	\N	PRESENT	0
433059	425283	01057W	PARTICIPANT	\N	PRESENT	0
433060	425283	14081Q	PARTICIPANT	\N	PRESENT	0
433061	425283	11110B	PARTICIPANT	\N	PRESENT	0
433062	425283	14331P	PARTICIPANT	\N	PRESENT	0
433063	425283	19525U	PARTICIPANT	\N	PRESENT	0
433064	425283	87003B	PARTICIPANT	\N	PRESENT	0
437867	437203	15447F	PARTICIPANT	\N	PRESENT	0
437868	437203	14051J	PARTICIPANT	\N	PRESENT	0
437869	437203	14031R	PARTICIPANT	0	PRESENT	0
437870	437203	19820Y	PARTICIPANT	\N	PRESENT	0
437871	437203	19826F	PARTICIPANT	\N	PRESENT	0
437872	437203	08055A	PARTICIPANT	\N	PRESENT	0
437873	437203	14237S	PARTICIPANT	\N	EXCUSE	0
437874	437203	08024S	PARTICIPANT	\N	EXCUSE	0
437875	437203	19333N	PARTICIPANT	\N	PRESENT	0
437876	437203	14038Y	PRESIDENT	0	PRESENT	0
437877	437203	19701S	PARTICIPANT	\N	PRESENT	0
437878	437203	19794Q	PARTICIPANT	\N	PRESENT	0
437879	437203	19387D	PARTICIPANT	\N	PRESENT	0
437880	437203	14093U	PARTICIPANT	\N	PRESENT	0
437881	437203	19739H	PARTICIPANT	\N	PRESENT	0
437882	437203	04097T	PARTICIPANT	\N	PRESENT	0
437883	437203	19745F	PARTICIPANT	\N	PRESENT	0
437884	437203	19681G	PARTICIPANT	\N	PRESENT	0
437885	437203	19525U	PARTICIPANT	\N	PRESENT	0
437886	437203	18083K	PARTICIPANT	\N	EXCUSE	0
437887	437203	08009T	PARTICIPANT	\N	EXCUSE	0
437888	437203	19503N	PARTICIPANT	\N	EXCUSE	0
437889	437203	19549D	PARTICIPANT	\N	PRESENT	0
437890	437203	14221J	PARTICIPANT	\N	PRESENT	0
437891	437203	14103D	PARTICIPANT	\N	PRESENT	0
437894	437203	19659J	PARTICIPANT	\N	EXCUSE	0
437896	437203	19713W	PARTICIPANT	\N	PRESENT	0
437910	437085	14239U	PRESIDENT	0	PRESENT	0
437911	437085	04092N	PRESIDENT	1	PRESENT	0
437912	437085	08034U	PARTICIPANT	\N	PRESENT	0
437913	437085	14042U	PARTICIPANT	\N	PRESENT	0
437914	437085	14213J	PARTICIPANT	\N	PRESENT	0
437915	437085	19415P	PARTICIPANT	\N	PRESENT	0
437916	437085	14215L	PARTICIPANT	\N	PRESENT	0
437917	437085	04045F	PARTICIPANT	\N	PRESENT	0
437918	437085	11066Q	PARTICIPANT	\N	PRESENT	0
437919	437085	19447X	PARTICIPANT	\N	PRESENT	0
437920	437085	11072N	PARTICIPANT	\N	PRESENT	0
437921	437085	19681G	PARTICIPANT	\N	PRESENT	0
437922	437085	19553Y	PARTICIPANT	\N	PRESENT	0
437923	437085	19575F	PARTICIPANT	\N	PRESENT	0
437924	425785	86034E	PARTICIPANT	\N	PRESENT	0
437925	437079	04088S	PARTICIPANT	\N	PRESENT	0
437926	437079	19515S	PARTICIPANT	\N	PRESENT	0
437927	437079	14357A	PARTICIPANT	\N	PRESENT	0
437928	437079	08015R	PARTICIPANT	\N	PRESENT	0
437929	437079	11090Q	PRESIDENT	0	PRESENT	0
437930	437079	19369B	PARTICIPANT	\N	PRESENT	0
437931	437079	19747H	PARTICIPANT	\N	PRESENT	0
437932	437079	19511N	PARTICIPANT	\N	PRESENT	0
437933	437079	08028W	PARTICIPANT	\N	PRESENT	0
437934	437079	19631V	PARTICIPANT	\N	PRESENT	0
437935	437079	14187A	PARTICIPANT	\N	PRESENT	0
437936	437079	14205J	PARTICIPANT	\N	PRESENT	0
437937	437079	14257W	PARTICIPANT	\N	PRESENT	0
437938	437079	14329V	PARTICIPANT	\N	PRESENT	0
437939	437079	19413M	PARTICIPANT	\N	PRESENT	0
437940	437079	14033T	PARTICIPANT	\N	PRESENT	0
437941	437079	04049K	PARTICIPANT	\N	PRESENT	0
437942	437079	19768N	PARTICIPANT	\N	PRESENT	0
437943	437079	19507S	PARTICIPANT	\N	PRESENT	0
437944	437079	19467C	PARTICIPANT	\N	EXCUSE	0
437945	437079	08068F	PARTICIPANT	\N	EXCUSE	0
437946	437079	11081P	PARTICIPANT	\N	EXCUSE	0
437947	437085	19569H	PARTICIPANT	\N	PRESENT	0
437948	437085	14179A	PARTICIPANT	\N	PRESENT	0
437949	437085	14147R	PARTICIPANT	\N	PRESENT	0
437950	437085	10006L	PARTICIPANT	\N	PRESENT	0
437951	437079	19782L	PARTICIPANT	\N	PRESENT	0
437952	425785	19583F	PARTICIPANT	\N	PRESENT	0
437953	425785	07004J	PARTICIPANT	\N	PRESENT	0
437954	425785	19577H	PARTICIPANT	\N	PRESENT	0
437955	425785	19611R	PARTICIPANT	\N	PRESENT	0
437956	437079	80013X	PARTICIPANT	\N	PRESENT	0
437957	437079	11099A	PARTICIPANT	\N	PRESENT	0
437958	425785	14055N	PARTICIPANT	\N	PRESENT	0
437959	425785	14151M	PARTICIPANT	\N	PRESENT	0
437960	425785	19657G	PARTICIPANT	\N	PRESENT	0
437961	425785	14191V	PARTICIPANT	\N	PRESENT	0
437962	425785	11101A	PARTICIPANT	\N	PRESENT	0
437963	425785	19703U	PARTICIPANT	\N	PRESENT	0
437964	425785	19812Y	PARTICIPANT	\N	PRESENT	0
437965	425785	08043V	PARTICIPANT	\N	PRESENT	0
437966	425785	19737F	PARTICIPANT	\N	PRESENT	0
437967	425785	14123H	PARTICIPANT	\N	PRESENT	0
437968	425785	19762G	PARTICIPANT	\N	PRESENT	0
437969	425785	19673G	PARTICIPANT	\N	PRESENT	0
437970	425785	19826F	PARTICIPANT	\N	PRESENT	0
437971	425785	19565D	PARTICIPANT	\N	PRESENT	0
437972	425785	12041X	PARTICIPANT	\N	PRESENT	0
437973	425785	11104D	PARTICIPANT	\N	PRESENT	0
437974	425785	08047A	PARTICIPANT	\N	PRESENT	0
437975	425785	11103C	PARTICIPANT	\N	PRESENT	0
437976	425785	01025N	PARTICIPANT	\N	PRESENT	0
437977	425785	19766L	PARTICIPANT	\N	PRESENT	0
437978	425785	14079W	PARTICIPANT	\N	PRESENT	0
437979	425785	19683J	PARTICIPANT	\N	PRESENT	0
437980	425785	19443T	PARTICIPANT	\N	PRESENT	0
437981	425785	14085U	PARTICIPANT	\N	PRESENT	0
437982	425785	19479G	PARTICIPANT	\N	PRESENT	0
437983	425785	11043H	PARTICIPANT	\N	PRESENT	0
437984	425785	08052W	PARTICIPANT	\N	PRESENT	0
437985	425785	04089T	PARTICIPANT	\N	PRESENT	0
437987	425785	14081Q	PARTICIPANT	\N	PRESENT	0
437988	425785	08055A	PARTICIPANT	\N	PRESENT	0
437991	425785	19333N	PARTICIPANT	\N	PRESENT	0
437992	425785	14051J	PARTICIPANT	\N	PRESENT	0
437993	425785	19525U	PARTICIPANT	\N	PRESENT	0
437994	425785	19549D	PARTICIPANT	\N	PRESENT	0
437995	425785	19820Y	PARTICIPANT	\N	PRESENT	0
437996	425785	01058X	PARTICIPANT	\N	PRESENT	0
437997	425785	19667J	PARTICIPANT	\N	PRESENT	0
437998	425785	14267Y	PARTICIPANT	\N	PRESENT	0
437999	425785	19347U	PARTICIPANT	\N	PRESENT	0
438000	425785	19687N	PARTICIPANT	\N	PRESENT	0
438001	425785	14001X	PARTICIPANT	\N	PRESENT	0
438002	425785	19441R	PARTICIPANT	\N	PRESENT	0
438003	425785	04059M	PARTICIPANT	\N	PRESENT	0
438004	425785	11031D	PARTICIPANT	\N	PRESENT	0
438005	425785	07029T	PARTICIPANT	\N	PRESENT	0
438006	425785	08061X	PARTICIPANT	\N	PRESENT	0
438007	425785	01028R	PARTICIPANT	\N	PRESENT	0
438008	425785	16685X	PARTICIPANT	\N	PRESENT	0
438009	425785	19319Q	PARTICIPANT	\N	PRESENT	0
438010	425785	11066Q	PARTICIPANT	\N	PRESENT	0
438011	425785	14235Q	PARTICIPANT	\N	PRESENT	0
438012	425785	14207L	PARTICIPANT	\N	PRESENT	0
438013	425785	98035U	PARTICIPANT	\N	PRESENT	0
438014	425785	19619A	PARTICIPANT	\N	PRESENT	0
438015	425785	11056N	PARTICIPANT	\N	PRESENT	0
438016	425785	14253S	PARTICIPANT	\N	PRESENT	0
438017	425785	19295A	PARTICIPANT	\N	PRESENT	0
438018	425785	04085P	PARTICIPANT	\N	PRESENT	0
438019	425785	19758L	PARTICIPANT	\N	PRESENT	0
438020	425785	19695N	PARTICIPANT	\N	PRESENT	0
438021	425785	11040E	PARTICIPANT	\N	PRESENT	0
438022	425785	19593H	PARTICIPANT	\N	PRESENT	0
438023	425785	95037J	PARTICIPANT	\N	PRESENT	0
438024	425785	04045F	PARTICIPANT	\N	PRESENT	0
438025	425785	98029W	PARTICIPANT	\N	PRESENT	0
438026	425785	19651A	PARTICIPANT	\N	PRESENT	0
438027	425785	19637C	PARTICIPANT	\N	PRESENT	0
438028	425785	11072N	PARTICIPANT	\N	PRESENT	0
438029	425785	14039A	PARTICIPANT	\N	PRESENT	0
438030	425785	08073C	PARTICIPANT	\N	PRESENT	0
438031	425785	95063L	PARTICIPANT	\N	PRESENT	0
438032	425785	14239U	PARTICIPANT	\N	PRESENT	0
438033	425785	19760E	PARTICIPANT	\N	PRESENT	0
438034	425785	08017T	PARTICIPANT	\N	PRESENT	0
438035	425785	19711U	PARTICIPANT	\N	PRESENT	0
438036	425785	14225N	PARTICIPANT	\N	PRESENT	0
438037	425785	11027H	PARTICIPANT	\N	PRESENT	0
438038	425785	08058D	PARTICIPANT	\N	PRESENT	0
438039	425785	08012N	PARTICIPANT	\N	PRESENT	0
438040	425785	04035D	PARTICIPANT	\N	PRESENT	0
438041	425785	19599P	PARTICIPANT	\N	PRESENT	0
438042	425785	95030B	PARTICIPANT	\N	PRESENT	0
438043	425785	99004R	PARTICIPANT	\N	PRESENT	0
438044	425785	11012A	PARTICIPANT	\N	PRESENT	0
438045	425785	88008L	PARTICIPANT	\N	PRESENT	0
438046	425785	08031R	PARTICIPANT	\N	PRESENT	0
438047	425785	14261S	PARTICIPANT	\N	PRESENT	0
438048	425785	08049C	PARTICIPANT	\N	PRESENT	0
438049	425785	19649G	PARTICIPANT	\N	PRESENT	0
438050	425785	11109J	PARTICIPANT	\N	PRESENT	0
438051	425785	96004D	PARTICIPANT	\N	PRESENT	0
438052	425785	19553Y	PARTICIPANT	\N	PRESENT	0
438053	425785	19629C	PARTICIPANT	\N	PRESENT	0
438054	425785	19253P	PARTICIPANT	\N	PRESENT	0
433963	433961	11064N	PARTICIPANT	\N	PRESENT	0
433964	433961	19251M	PARTICIPANT	\N	PRESENT	0
433987	433986	14205J	PARTICIPANT	\N	PRESENT	0
433988	433986	08055A	PARTICIPANT	\N	PRESENT	0
433989	433986	19575F	PARTICIPANT	\N	PRESENT	0
433990	433986	19467C	PARTICIPANT	\N	PRESENT	0
433991	433986	14042U	PARTICIPANT	\N	PRESENT	0
433992	433986	14197C	PARTICIPANT	\N	PRESENT	0
433993	433986	14034U	PARTICIPANT	\N	PRESENT	0
433994	433986	19723Y	PARTICIPANT	\N	PRESENT	0
433995	433986	92040Q	PARTICIPANT	\N	PRESENT	0
433996	433986	04088S	PARTICIPANT	\N	PRESENT	0
433997	433986	98050T	PARTICIPANT	\N	PRESENT	0
433998	433986	17583W	PARTICIPANT	\N	PRESENT	0
433999	433986	11097X	PARTICIPANT	\N	PRESENT	0
434000	433986	11043H	PARTICIPANT	\N	PRESENT	0
434001	433986	19713W	PARTICIPANT	\N	PRESENT	0
434002	433986	95067Q	PARTICIPANT	\N	PRESENT	0
436461	428273	14261S	PARTICIPANT	\N	PRESENT	0
436462	428273	14111D	PARTICIPANT	\N	PRESENT	0
436463	428273	19701S	PARTICIPANT	\N	PRESENT	0
436464	428273	14026U	PARTICIPANT	\N	PRESENT	0
436465	428273	19647E	PARTICIPANT	\N	PRESENT	0
436466	428273	19575F	PARTICIPANT	\N	PRESENT	0
436467	428273	19760E	PARTICIPANT	\N	PRESENT	0
436468	428273	14281W	PARTICIPANT	\N	PRESENT	0
436469	428273	19621T	PARTICIPANT	\N	PRESENT	0
436470	428273	14042U	PARTICIPANT	\N	PRESENT	0
436471	428273	19768N	PARTICIPANT	\N	PRESENT	0
436472	433965	11085T	PARTICIPANT	\N	PRESENT	0
436867	432678	04038G	PARTICIPANT	\N	EXCUSE	0
436868	432678	19651A	PARTICIPANT	\N	EXCUSE	0
436869	432678	19399H	PARTICIPANT	\N	PRESENT	0
436870	425655	04059M	PARTICIPANT	\N	PRESENT	0
436871	434671	14331P	PARTICIPANT	\N	PRESENT	0
436872	434671	19479G	PARTICIPANT	\N	PRESENT	0
436873	434671	11048N	PARTICIPANT	\N	PRESENT	0
436874	434671	19711U	PARTICIPANT	\N	PRESENT	0
436875	434671	01048V	PARTICIPANT	\N	PRESENT	0
436876	434671	19651A	PARTICIPANT	\N	PRESENT	0
436877	434671	19531S	PARTICIPANT	\N	PRESENT	0
436878	434671	19545Y	PARTICIPANT	\N	PRESENT	0
436879	434671	19689Q	PARTICIPANT	\N	PRESENT	0
436880	434671	11053K	PARTICIPANT	\N	PRESENT	0
436881	434671	11074Q	PRESIDENT	0	PRESENT	0
436882	434671	14225N	PARTICIPANT	\N	PRESENT	0
436883	434671	19671E	PARTICIPANT	\N	PRESENT	0
436884	434671	04086Q	PARTICIPANT	\N	PRESENT	0
436885	434671	14083S	PARTICIPANT	\N	PRESENT	0
436886	434671	08073C	PARTICIPANT	\N	PRESENT	0
436887	434671	14085U	PARTICIPANT	\N	PRESENT	0
436888	434671	19741B	PARTICIPANT	\N	PRESENT	0
436889	434671	08010L	PARTICIPANT	\N	PRESENT	0
436890	434671	14121F	PARTICIPANT	\N	PRESENT	0
436891	434671	14253S	PARTICIPANT	\N	PRESENT	0
436892	434671	99004R	PARTICIPANT	\N	PRESENT	0
436893	434671	14327T	PARTICIPANT	\N	EXCUSE	0
436899	432678	19369B	PARTICIPANT	\N	PRESENT	0
436900	434671	07029T	PARTICIPANT	\N	EXCUSE	0
436901	434671	08011M	PARTICIPANT	\N	EXCUSE	0
436910	425655	08019V	PARTICIPANT	\N	PRESENT	0
436911	425655	11074Q	PARTICIPANT	\N	PRESENT	0
436912	425655	08073C	PARTICIPANT	\N	PRESENT	0
436913	425655	14039A	PARTICIPANT	\N	PRESENT	0
436914	425655	19631V	PARTICIPANT	\N	PRESENT	0
436915	425655	19295A	PARTICIPANT	\N	PRESENT	0
436916	425655	11109J	PARTICIPANT	\N	PRESENT	0
436917	425655	19715Y	PARTICIPANT	\N	PRESENT	0
436918	425655	11072N	PARTICIPANT	\N	PRESENT	0
436919	425655	19583F	PARTICIPANT	\N	PRESENT	0
436920	425655	19319Q	PARTICIPANT	\N	PRESENT	0
436921	425655	19691J	PARTICIPANT	\N	PRESENT	0
436922	425655	19479G	PARTICIPANT	\N	PRESENT	0
436923	425655	19253P	PARTICIPANT	\N	PRESENT	0
436924	425655	14261S	PARTICIPANT	\N	PRESENT	0
436925	425655	01034P	PARTICIPANT	\N	PRESENT	0
436926	425655	19651A	PARTICIPANT	\N	PRESENT	0
436927	425655	19301E	PARTICIPANT	\N	PRESENT	0
436928	425655	19711U	PARTICIPANT	\N	PRESENT	0
436929	425655	11048N	PARTICIPANT	\N	PRESENT	0
436930	425655	04018C	PARTICIPANT	\N	PRESENT	0
436931	425655	19657G	PARTICIPANT	\N	PRESENT	0
436932	425655	01048V	PARTICIPANT	\N	PRESENT	0
436933	425655	96004D	PARTICIPANT	\N	PRESENT	0
436934	425655	19515S	PARTICIPANT	\N	PRESENT	0
436936	425655	12016W	PARTICIPANT	\N	PRESENT	0
436937	425655	19671E	PARTICIPANT	\N	PRESENT	0
436939	425655	01024M	PARTICIPANT	\N	PRESENT	0
436941	425655	19543W	PARTICIPANT	\N	PRESENT	0
436942	425655	11033F	PARTICIPANT	\N	PRESENT	0
436944	425655	01028R	PARTICIPANT	\N	PRESENT	0
436945	425655	11090Q	PARTICIPANT	\N	PRESENT	0
436946	425655	19593H	PARTICIPANT	\N	PRESENT	0
436947	425655	14021P	PARTICIPANT	\N	PRESENT	0
436948	425655	08043V	PARTICIPANT	\N	PRESENT	0
436949	425655	04086Q	PARTICIPANT	\N	PRESENT	0
436950	425655	19329S	PARTICIPANT	\N	PRESENT	0
436951	425655	19545Y	PARTICIPANT	\N	PRESENT	0
436952	425655	19699S	PARTICIPANT	\N	PRESENT	0
436953	425655	14251Q	PARTICIPANT	\N	PRESENT	0
436954	425655	14253S	PARTICIPANT	\N	PRESENT	0
436955	425655	11026G	PARTICIPANT	\N	PRESENT	0
436956	425655	19673G	PARTICIPANT	\N	PRESENT	0
436964	425655	14121F	PARTICIPANT	\N	PRESENT	0
436968	425655	11027H	PARTICIPANT	\N	PRESENT	0
436971	425655	08039A	PARTICIPANT	\N	PRESENT	0
436972	425655	14083S	PARTICIPANT	\N	PRESENT	0
436976	425655	19531S	PARTICIPANT	\N	PRESENT	0
436977	425655	08031R	PARTICIPANT	\N	PRESENT	0
436979	425655	14331P	PARTICIPANT	\N	PRESENT	0
436981	425655	19713W	PARTICIPANT	\N	PRESENT	0
436983	425655	14207L	PARTICIPANT	\N	PRESENT	0
436984	425655	14259Y	PARTICIPANT	\N	PRESENT	0
436985	425655	08034U	PARTICIPANT	\N	PRESENT	0
436986	425655	14069U	PARTICIPANT	\N	PRESENT	0
436987	425655	14087W	PARTICIPANT	\N	PRESENT	0
436989	425655	19611R	PARTICIPANT	\N	PRESENT	0
436990	425655	11012A	PARTICIPANT	\N	PRESENT	0
437044	436991	19593H	PARTICIPANT	\N	PRESENT	0
437045	436991	14039A	PARTICIPANT	\N	PRESENT	0
437046	436991	19651A	PARTICIPANT	\N	PRESENT	0
437047	436991	14331P	PARTICIPANT	\N	PRESENT	0
437048	436991	19583F	PARTICIPANT	\N	PRESENT	0
437049	436991	04086Q	PARTICIPANT	\N	PRESENT	0
437050	436991	14229S	PARTICIPANT	\N	PRESENT	0
437051	436991	19715Y	PARTICIPANT	\N	PRESENT	0
437052	436991	12016W	PARTICIPANT	\N	PRESENT	0
437053	436991	11109J	PARTICIPANT	\N	PRESENT	0
437054	436991	19295A	PARTICIPANT	\N	PRESENT	0
437055	436991	08073C	PARTICIPANT	\N	PRESENT	0
437056	436991	08019V	PARTICIPANT	\N	PRESENT	0
437057	436991	19319Q	PARTICIPANT	\N	PRESENT	0
437058	436991	19329S	PARTICIPANT	\N	PRESENT	0
437059	436991	19301E	PARTICIPANT	\N	PRESENT	0
437060	436991	04018C	PARTICIPANT	\N	PRESENT	0
437061	436991	19515S	PARTICIPANT	\N	PRESENT	0
437062	436991	19671E	PARTICIPANT	\N	PRESENT	0
437063	436991	14259Y	PARTICIPANT	\N	PRESENT	0
437064	436991	08031R	PARTICIPANT	\N	PRESENT	0
437065	436991	19693L	PARTICIPANT	\N	PRESENT	0
437066	436991	08034U	PARTICIPANT	\N	PRESENT	0
437067	436991	19711U	PARTICIPANT	\N	PRESENT	0
437068	436991	19657G	PARTICIPANT	\N	PRESENT	0
437069	436991	14261S	PARTICIPANT	\N	PRESENT	0
437070	432678	11065P	PARTICIPANT	\N	EXCUSE	0
437071	436991	19611R	PARTICIPANT	\N	PRESENT	0
437072	436991	14121F	PARTICIPANT	\N	PRESENT	0
437073	436991	14225N	PARTICIPANT	\N	PRESENT	0
437075	436991	19735D	PARTICIPANT	\N	PRESENT	0
437076	436991	19673G	PARTICIPANT	\N	PRESENT	0
437077	436991	19643A	PARTICIPANT	\N	PRESENT	0
437078	436991	19253P	PARTICIPANT	\N	PRESENT	0
437080	436991	11074Q	PARTICIPANT	\N	PRESENT	0
437081	436991	08017T	PARTICIPANT	\N	PRESENT	0
437082	436991	19699S	PARTICIPANT	\N	PRESENT	0
437083	436991	14083S	PARTICIPANT	\N	PRESENT	0
437084	436991	14207L	PARTICIPANT	\N	PRESENT	0
437086	436991	14253S	PARTICIPANT	\N	PRESENT	0
437087	436991	11048N	PARTICIPANT	\N	PRESENT	0
437088	436991	19531S	PARTICIPANT	\N	PRESENT	0
437042	436991	11072N	PARTICIPANT	\N	PRESENT	0
437043	436991	08043V	PARTICIPANT	\N	PRESENT	0
437089	436991	99004R	PARTICIPANT	\N	PRESENT	0
437090	436991	14087W	PARTICIPANT	\N	PRESENT	0
437091	436991	11012A	PARTICIPANT	\N	PRESENT	0
437092	436991	19741B	PARTICIPANT	\N	PRESENT	0
425105	414419	19349W	PARTICIPANT	\N	EXCUSE	0
425112	414419	19647E	PARTICIPANT	\N	EXCUSE	0
425141	414419	19479G	PARTICIPANT	\N	EXCUSE	0
425158	414419	08045X	PARTICIPANT	\N	EXCUSE	0
434522	425327	04042C	PARTICIPANT	\N	PRESENT	0
434523	425327	07029T	PARTICIPANT	\N	PRESENT	0
434524	425327	14041T	PARTICIPANT	\N	PRESENT	0
434525	425327	04034C	PARTICIPANT	\N	PRESENT	0
434526	425327	98029W	PARTICIPANT	\N	PRESENT	0
434527	425327	04070G	PARTICIPANT	\N	PRESENT	0
434528	425327	11027H	PARTICIPANT	\N	PRESENT	0
434529	425327	11026G	PARTICIPANT	\N	PRESENT	0
434530	425327	19669L	PARTICIPANT	\N	PRESENT	0
434531	425327	14235Q	PARTICIPANT	\N	PRESENT	0
434532	425327	14211G	PARTICIPANT	\N	PRESENT	0
434533	425327	08017T	PARTICIPANT	\N	PRESENT	0
434534	425327	11041F	PARTICIPANT	\N	PRESENT	0
434535	425327	19711U	PARTICIPANT	\N	PRESENT	0
434536	425327	95041E	PARTICIPANT	\N	PRESENT	0
434537	425327	19647E	PARTICIPANT	\N	PRESENT	0
434538	425327	14253S	PARTICIPANT	\N	PRESENT	0
434539	425327	19515S	PARTICIPANT	\N	PRESENT	0
434540	425327	19251M	PARTICIPANT	\N	PRESENT	0
434541	425327	08019V	PARTICIPANT	\N	PRESENT	0
434542	425327	88008L	PARTICIPANT	\N	PRESENT	0
434543	425327	11012A	PARTICIPANT	\N	PRESENT	0
434544	425327	14073Q	PARTICIPANT	\N	PRESENT	0
434545	425327	19583F	PARTICIPANT	\N	PRESENT	0
434546	425327	14331P	PARTICIPANT	\N	PRESENT	0
434547	425327	19335Q	PARTICIPANT	\N	PRESENT	0
434548	425327	14028W	PARTICIPANT	\N	PRESENT	0
434549	425327	95037J	PARTICIPANT	\N	PRESENT	0
434550	431063	19349W	PARTICIPANT	\N	EXCUSE	0
434551	425327	11040E	PARTICIPANT	\N	PRESENT	0
434552	425327	08010L	PARTICIPANT	\N	PRESENT	0
434553	425327	16685X	PARTICIPANT	\N	PRESENT	0
434554	425327	95067Q	PARTICIPANT	\N	PRESENT	0
434555	425327	08034U	PARTICIPANT	\N	PRESENT	0
434556	425327	99004R	PARTICIPANT	\N	PRESENT	0
434557	425327	19553Y	PARTICIPANT	\N	PRESENT	0
434558	425327	19693L	PARTICIPANT	\N	PRESENT	0
434559	425327	14255U	PARTICIPANT	\N	PRESENT	0
434560	425327	19741B	PARTICIPANT	\N	PRESENT	0
434568	425327	14227Q	PARTICIPANT	\N	PRESENT	0
434572	425327	14121F	PARTICIPANT	\N	PRESENT	0
434576	425327	14042U	PARTICIPANT	\N	PRESENT	0
434578	425327	07004J	PARTICIPANT	\N	PRESENT	0
434581	425327	14229S	PARTICIPANT	\N	PRESENT	0
434582	425327	11097X	PARTICIPANT	\N	PRESENT	0
434583	425327	14071N	PARTICIPANT	\N	PRESENT	0
434584	425327	14213J	PARTICIPANT	\N	PRESENT	0
434585	425327	04086Q	PARTICIPANT	\N	PRESENT	0
434586	425327	89017R	PARTICIPANT	\N	PRESENT	0
434587	425327	11109J	PARTICIPANT	\N	PRESENT	0
434594	425327	19369B	PARTICIPANT	\N	PRESENT	0
434595	425327	14217N	PARTICIPANT	\N	PRESENT	0
434644	425329	11027H	PARTICIPANT	\N	PRESENT	0
434645	425329	19583F	PARTICIPANT	\N	PRESENT	0
434646	425329	19683J	PARTICIPANT	\N	PRESENT	0
434647	425329	88008L	PARTICIPANT	\N	PRESENT	0
434648	425329	11012A	PARTICIPANT	\N	PRESENT	0
434649	425329	95067Q	PARTICIPANT	\N	PRESENT	0
434650	425329	14028W	PARTICIPANT	\N	PRESENT	0
434651	425329	16685X	PARTICIPANT	\N	PRESENT	0
434652	425329	14071N	PARTICIPANT	\N	PRESENT	0
434653	425329	14235Q	PARTICIPANT	\N	PRESENT	0
434654	425329	14121F	PARTICIPANT	\N	PRESENT	0
434655	425329	04034C	PARTICIPANT	\N	PRESENT	0
434656	425329	04092N	PARTICIPANT	\N	PRESENT	0
434657	425329	04042C	PARTICIPANT	\N	PRESENT	0
434658	425329	14227Q	PARTICIPANT	\N	PRESENT	0
434659	425329	19301E	PARTICIPANT	\N	PRESENT	0
434660	425329	08017T	PARTICIPANT	\N	PRESENT	0
434661	425329	14119M	PARTICIPANT	\N	PRESENT	0
434662	425329	99004R	PARTICIPANT	\N	PRESENT	0
434663	425329	14217N	PARTICIPANT	\N	PRESENT	0
434664	425329	19657G	PARTICIPANT	\N	PRESENT	0
434665	425329	19651A	PARTICIPANT	\N	PRESENT	0
434666	425329	19565D	PARTICIPANT	\N	PRESENT	0
434668	425329	19711U	PARTICIPANT	\N	PRESENT	0
434670	425329	19667J	PARTICIPANT	\N	PRESENT	0
434674	425329	19553Y	PARTICIPANT	\N	PRESENT	0
434676	425329	95041E	PARTICIPANT	\N	PRESENT	0
434677	425329	19369B	PARTICIPANT	\N	PRESENT	0
434678	425329	14042U	PARTICIPANT	\N	PRESENT	0
434679	425329	19693L	PARTICIPANT	\N	PRESENT	0
434680	425329	19689Q	PARTICIPANT	\N	PRESENT	0
434681	425329	11097X	PARTICIPANT	\N	PRESENT	0
434682	425329	11040E	PARTICIPANT	\N	PRESENT	0
434683	425329	08010L	PARTICIPANT	\N	PRESENT	0
434684	425329	14213J	PARTICIPANT	\N	PRESENT	0
434685	425329	04057K	PARTICIPANT	\N	PRESENT	0
434686	425329	19741B	PARTICIPANT	\N	PRESENT	0
434687	425329	19695N	PARTICIPANT	\N	PRESENT	0
434688	425329	07004J	PARTICIPANT	\N	PRESENT	0
434689	425329	14089Y	PARTICIPANT	\N	PRESENT	0
434690	425329	11026G	PARTICIPANT	\N	PRESENT	0
434691	425329	19611R	PARTICIPANT	\N	PRESENT	0
434692	425329	11031D	PARTICIPANT	\N	PRESENT	0
434740	425331	14213J	PARTICIPANT	\N	PRESENT	0
434741	425331	19683J	PARTICIPANT	\N	PRESENT	0
434742	425331	19553Y	PARTICIPANT	\N	PRESENT	0
434642	425329	04086Q	PARTICIPANT	\N	PRESENT	0
434643	425329	14331P	PARTICIPANT	\N	PRESENT	0
434743	425331	19301E	PARTICIPANT	\N	PRESENT	0
434744	425331	11031D	PARTICIPANT	\N	PRESENT	0
434745	425331	04057K	PARTICIPANT	\N	PRESENT	0
434746	425331	14042U	PARTICIPANT	\N	PRESENT	0
434747	425331	14071N	PARTICIPANT	\N	PRESENT	0
434748	425331	08052W	PARTICIPANT	\N	PRESENT	0
434749	425331	11026G	PARTICIPANT	\N	PRESENT	0
434750	425331	19689Q	PARTICIPANT	\N	PRESENT	0
434751	425331	14227Q	PARTICIPANT	\N	PRESENT	0
434752	425331	19651A	PARTICIPANT	\N	PRESENT	0
434753	425331	14121F	PARTICIPANT	\N	PRESENT	0
434754	425331	14089Y	PARTICIPANT	\N	PRESENT	0
434755	425331	19611R	PARTICIPANT	\N	PRESENT	0
434756	425331	19369B	PARTICIPANT	\N	PRESENT	0
434757	425331	11097X	PARTICIPANT	\N	PRESENT	0
434758	425331	04092N	PARTICIPANT	\N	PRESENT	0
434759	425331	19693L	PARTICIPANT	\N	PRESENT	0
434760	425331	14217N	PARTICIPANT	\N	PRESENT	0
434761	425331	19667J	PARTICIPANT	\N	PRESENT	0
434762	425331	08010L	PARTICIPANT	\N	PRESENT	0
434763	425331	14331P	PARTICIPANT	\N	PRESENT	0
434764	425331	19711U	PARTICIPANT	\N	PRESENT	0
434765	425331	07004J	PARTICIPANT	\N	PRESENT	0
434766	425331	19695N	PARTICIPANT	\N	PRESENT	0
434767	425331	11040E	PARTICIPANT	\N	PRESENT	0
434768	425331	19583F	PARTICIPANT	\N	PRESENT	0
434769	425331	19741B	PARTICIPANT	\N	PRESENT	0
434770	425331	14261S	PARTICIPANT	\N	PRESENT	0
434771	425331	89017R	PARTICIPANT	\N	PRESENT	0
434772	425331	19565D	PARTICIPANT	\N	PRESENT	0
434773	425331	10006L	PARTICIPANT	\N	PRESENT	0
434774	425331	19687N	PARTICIPANT	\N	PRESENT	0
434775	425331	11045K	PARTICIPANT	\N	PRESENT	0
434776	425331	19533U	PARTICIPANT	\N	PRESENT	0
434779	425331	19593H	PARTICIPANT	\N	PRESENT	0
434780	425331	11074Q	PARTICIPANT	\N	PRESENT	0
434781	425331	19657G	PARTICIPANT	\N	PRESENT	0
434782	425331	11109J	PARTICIPANT	\N	PRESENT	0
434783	425331	19545Y	PARTICIPANT	\N	PRESENT	0
434784	425331	14281W	PARTICIPANT	\N	PRESENT	0
434785	425331	19697Q	PARTICIPANT	\N	PRESENT	0
434738	425331	04086Q	PARTICIPANT	\N	PRESENT	0
434739	425331	95041E	PARTICIPANT	\N	PRESENT	0
433065	425283	11090Q	PARTICIPANT	\N	PRESENT	0
433066	425283	14085U	PARTICIPANT	\N	PRESENT	0
433067	425283	04043D	PARTICIPANT	\N	PRESENT	0
433068	425283	08058D	PARTICIPANT	\N	PRESENT	0
433069	425283	14215L	PARTICIPANT	\N	PRESENT	0
433070	425283	19549D	PARTICIPANT	\N	PRESENT	0
433071	425283	15447F	PARTICIPANT	\N	PRESENT	0
433072	425283	08014Q	PARTICIPANT	\N	PRESENT	0
433073	425283	19333N	PARTICIPANT	\N	PRESENT	0
433074	425283	19643A	PARTICIPANT	\N	PRESENT	0
433075	425283	19503N	PARTICIPANT	\N	PRESENT	0
433076	425283	10015M	PARTICIPANT	\N	PRESENT	0
433077	425283	11010L	PARTICIPANT	\N	PRESENT	0
433078	425283	19489J	PARTICIPANT	\N	PRESENT	0
433079	425283	19527W	PARTICIPANT	\N	PRESENT	0
433080	425283	11043H	PARTICIPANT	\N	PRESENT	0
433081	425283	01048V	PARTICIPANT	\N	PRESENT	0
433082	425283	08028W	PARTICIPANT	\N	PRESENT	0
433083	425283	14257W	PARTICIPANT	\N	PRESENT	0
433084	425283	14187A	PARTICIPANT	\N	PRESENT	0
433085	425283	19413M	PARTICIPANT	\N	PRESENT	0
433086	425283	08018U	PARTICIPANT	\N	PRESENT	0
433087	425283	04033B	PARTICIPANT	\N	PRESENT	0
433088	425283	14071N	PARTICIPANT	\N	PRESENT	0
433089	425283	19253P	PARTICIPANT	\N	PRESENT	0
433090	425283	11097X	PARTICIPANT	\N	PRESENT	0
433091	425283	19421M	PARTICIPANT	\N	PRESENT	0
433092	425283	14231L	PARTICIPANT	\N	PRESENT	0
433093	425283	19679N	PARTICIPANT	\N	PRESENT	0
433094	425283	14103D	PARTICIPANT	\N	PRESENT	0
433095	425283	04097T	PARTICIPANT	\N	PRESENT	0
433096	425283	14179A	PARTICIPANT	\N	PRESENT	0
433097	425283	08039A	PARTICIPANT	\N	PRESENT	0
433098	425283	01034P	PARTICIPANT	\N	PRESENT	0
433099	425283	19369B	PARTICIPANT	\N	PRESENT	0
433100	425283	08020N	PARTICIPANT	\N	PRESENT	0
433101	425283	19577H	PARTICIPANT	\N	PRESENT	0
433102	425283	11070L	PARTICIPANT	\N	PRESENT	0
433103	425283	14123H	PARTICIPANT	\N	PRESENT	0
433104	425283	11053K	PARTICIPANT	\N	PRESENT	0
433105	425283	08069G	PARTICIPANT	\N	PRESENT	0
433106	425283	04042C	PARTICIPANT	\N	PRESENT	0
433107	425283	04086Q	PARTICIPANT	\N	PRESENT	0
433108	425283	04092N	PARTICIPANT	\N	PRESENT	0
433109	425283	04044E	PARTICIPANT	\N	PRESENT	0
433110	425283	19511N	PARTICIPANT	\N	PRESENT	0
433111	425283	19619A	PARTICIPANT	\N	PRESENT	0
433112	425283	19721W	PARTICIPANT	\N	PRESENT	0
433113	425283	19747H	PARTICIPANT	\N	PRESENT	0
433114	425283	19699S	PARTICIPANT	\N	PRESENT	0
433115	425283	14205J	PARTICIPANT	\N	PRESENT	0
433116	425283	19737F	PARTICIPANT	\N	PRESENT	0
433117	425283	08011M	PARTICIPANT	\N	PRESENT	0
433118	425283	14157T	PARTICIPANT	\N	PRESENT	0
433119	425283	19569H	PARTICIPANT	\N	PRESENT	0
433120	425283	01058X	PARTICIPANT	\N	PRESENT	0
433121	425283	19739H	PARTICIPANT	\N	PRESENT	0
433122	425283	99004R	PARTICIPANT	\N	PRESENT	0
433123	425283	16685X	PARTICIPANT	\N	PRESENT	0
433124	425283	04047H	PARTICIPANT	\N	PRESENT	0
433125	425283	11065P	PARTICIPANT	\N	PRESENT	0
433126	425283	14211G	PARTICIPANT	\N	PRESENT	0
433127	425283	17637T	PARTICIPANT	\N	PRESENT	0
433128	425283	19711U	PARTICIPANT	\N	PRESENT	0
433129	425283	19735D	PARTICIPANT	\N	PRESENT	0
433130	425283	19713W	PARTICIPANT	\N	PRESENT	0
433131	425283	86034E	PARTICIPANT	\N	PRESENT	0
433132	425283	11101A	PARTICIPANT	\N	PRESENT	0
433133	425283	19441R	PARTICIPANT	\N	PRESENT	0
433134	425283	98024R	PARTICIPANT	\N	PRESENT	0
433135	425283	19447X	PARTICIPANT	\N	PRESENT	0
433136	425283	14267Y	PARTICIPANT	\N	PRESENT	0
433137	425283	14221J	PARTICIPANT	\N	PRESENT	0
433138	425283	19335Q	PARTICIPANT	\N	PRESENT	0
433139	425283	14073Q	PARTICIPANT	\N	PRESENT	0
433140	425283	14089Y	PARTICIPANT	\N	PRESENT	0
433141	425283	19749K	PARTICIPANT	\N	PRESENT	0
433142	425283	19745F	PARTICIPANT	\N	PRESENT	0
433143	425283	14042U	PARTICIPANT	\N	PRESENT	0
433144	425283	14083S	PARTICIPANT	\N	PRESENT	0
433145	425283	19521Q	PARTICIPANT	\N	PRESENT	0
433146	425283	19826F	PARTICIPANT	\N	PRESENT	0
433147	425283	19367Y	PARTICIPANT	\N	PRESENT	0
433148	425283	01060R	PARTICIPANT	\N	PRESENT	0
433149	425283	04035D	PARTICIPANT	\N	PRESENT	0
433150	425283	89017R	PARTICIPANT	\N	PRESENT	0
433151	425283	19691J	PARTICIPANT	\N	PRESENT	0
433152	425283	19709B	PARTICIPANT	\N	PRESENT	0
433153	425283	04070G	PARTICIPANT	\N	PRESENT	0
433154	425283	01025N	PARTICIPANT	\N	PRESENT	0
433155	425283	01024M	PARTICIPANT	\N	PRESENT	0
433156	425283	14030Q	PARTICIPANT	\N	PRESENT	0
433157	425283	14327T	PARTICIPANT	\N	PRESENT	0
433158	425283	01043Q	PARTICIPANT	\N	PRESENT	0
433159	425283	19467C	PARTICIPANT	\N	PRESENT	0
433160	425283	19727D	PARTICIPANT	\N	PRESENT	0
433161	425283	14097Y	PARTICIPANT	\N	PRESENT	0
433162	425283	96004D	PARTICIPANT	\N	PRESENT	0
433163	425283	05008E	PARTICIPANT	\N	PRESENT	0
433164	425283	19565D	PARTICIPANT	\N	PRESENT	0
433165	425283	19651A	PARTICIPANT	\N	PRESENT	0
433166	425283	08017T	PARTICIPANT	\N	PRESENT	0
433167	425283	11054L	PARTICIPANT	\N	PRESENT	0
433169	425283	14033T	PARTICIPANT	\N	PRESENT	0
433170	425283	11048N	PARTICIPANT	\N	PRESENT	0
433173	425283	04018C	PARTICIPANT	\N	PRESENT	0
433174	425283	14087W	PARTICIPANT	\N	PRESENT	0
433175	425283	14069U	PARTICIPANT	\N	PRESENT	0
433176	425283	14053L	PARTICIPANT	\N	PRESENT	0
433177	425283	11109J	PARTICIPANT	\N	PRESENT	0
433178	425283	14259Y	PARTICIPANT	\N	PRESENT	0
433179	425283	11072N	PARTICIPANT	\N	PRESENT	0
433180	425283	19531S	PARTICIPANT	\N	PRESENT	0
433183	425283	04071H	PARTICIPANT	\N	PRESENT	0
433186	425283	19551W	PARTICIPANT	\N	PRESENT	0
433499	425287	11070L	PARTICIPANT	\N	PRESENT	0
433500	425287	19711U	PARTICIPANT	\N	PRESENT	0
433501	425287	11048N	PARTICIPANT	\N	PRESENT	0
433502	425287	80013X	PARTICIPANT	\N	PRESENT	0
433503	425287	14121F	PARTICIPANT	\N	PRESENT	0
433504	425287	14093U	PARTICIPANT	\N	PRESENT	0
433505	425287	11077T	PARTICIPANT	\N	PRESENT	0
433506	425287	19347U	PARTICIPANT	\N	PRESENT	0
433507	425287	14107H	PARTICIPANT	\N	PRESENT	0
433508	425287	19387D	PARTICIPANT	\N	PRESENT	0
433509	425287	88008L	PARTICIPANT	\N	PRESENT	0
433510	425287	19713W	PARTICIPANT	\N	PRESENT	0
433511	425287	19681G	PARTICIPANT	\N	PRESENT	0
433512	425287	19577H	PARTICIPANT	\N	PRESENT	0
433513	425287	19583F	PARTICIPANT	\N	PRESENT	0
433514	425287	19820Y	PARTICIPANT	\N	PRESENT	0
433515	425287	19479G	PARTICIPANT	\N	PRESENT	0
433516	425287	04049K	PARTICIPANT	\N	PRESENT	0
433517	425287	14215L	PARTICIPANT	\N	PRESENT	0
433518	425287	14097Y	PARTICIPANT	\N	PRESENT	0
433519	425287	08060W	PARTICIPANT	\N	PRESENT	0
433520	425287	07029T	PARTICIPANT	\N	PRESENT	0
433521	425287	19333N	PARTICIPANT	\N	PRESENT	0
433522	425287	14033T	PARTICIPANT	\N	PRESENT	0
433523	425287	08069G	PARTICIPANT	\N	PRESENT	0
433524	425287	18083K	PARTICIPANT	\N	PRESENT	0
433525	425287	19467C	PARTICIPANT	\N	PRESENT	0
433526	425287	14157T	PARTICIPANT	\N	PRESENT	0
433527	425287	14173T	PARTICIPANT	\N	PRESENT	0
433528	425287	19651A	PARTICIPANT	\N	PRESENT	0
433529	425287	19637C	PARTICIPANT	\N	PRESENT	0
433530	425287	11065P	PARTICIPANT	\N	PRESENT	0
433531	425287	19812Y	PARTICIPANT	\N	PRESENT	0
433532	425287	11053K	PARTICIPANT	\N	PRESENT	0
433533	425287	14105F	PARTICIPANT	\N	PRESENT	0
433534	425287	14069U	PARTICIPANT	\N	PRESENT	0
433536	425287	19611R	PARTICIPANT	\N	PRESENT	0
433537	425287	14135M	PARTICIPANT	\N	PRESENT	0
433538	425287	14031R	PARTICIPANT	\N	PRESENT	0
433539	425287	19737F	PARTICIPANT	\N	PRESENT	0
433540	425287	19745F	PARTICIPANT	\N	PRESENT	0
433541	425287	14331P	PARTICIPANT	\N	PRESENT	0
433542	425287	14207L	PARTICIPANT	\N	PRESENT	0
433543	425287	15447F	PARTICIPANT	\N	PRESENT	0
433544	425287	19413M	PARTICIPANT	\N	PRESENT	0
433545	425287	19549D	PARTICIPANT	\N	PRESENT	0
433546	425287	19551W	PARTICIPANT	\N	PRESENT	0
433547	425287	08024S	PARTICIPANT	\N	PRESENT	0
433548	425287	14221J	PARTICIPANT	\N	PRESENT	0
433549	425287	14257W	PARTICIPANT	\N	PRESENT	0
433550	425287	19703U	PARTICIPANT	\N	PRESENT	0
433551	425287	19507S	PARTICIPANT	\N	PRESENT	0
428152	428147	08048B	PARTICIPANT	\N	PRESENT	0
428153	428147	14026U	PARTICIPANT	\N	PRESENT	0
431916	431915	04049K	PARTICIPANT	\N	PRESENT	0
431917	431915	14061L	PARTICIPANT	\N	PRESENT	0
431918	431915	14083S	PARTICIPANT	\N	PRESENT	0
431919	431915	19671E	PARTICIPANT	\N	PRESENT	0
438055	425785	04097T	PARTICIPANT	\N	PRESENT	0
438056	425785	08010L	PARTICIPANT	\N	PRESENT	0
438057	425785	14241N	PARTICIPANT	\N	PRESENT	0
438058	425785	19387D	PARTICIPANT	\N	PRESENT	0
438059	425785	19289C	PARTICIPANT	\N	PRESENT	0
438060	425785	14121F	PARTICIPANT	\N	PRESENT	0
438061	425785	19681G	PARTICIPANT	\N	PRESENT	0
438062	425785	04092N	PARTICIPANT	\N	PRESENT	0
438063	425785	19543W	PARTICIPANT	\N	PRESENT	0
438064	425785	04044E	PARTICIPANT	\N	PRESENT	0
438065	425785	19421M	PARTICIPANT	\N	PRESENT	0
438066	425785	14111D	PARTICIPANT	\N	PRESENT	0
438067	425785	14071N	PARTICIPANT	\N	PRESENT	0
438068	425785	19329S	PARTICIPANT	\N	PRESENT	0
438069	425785	19545Y	PARTICIPANT	\N	PRESENT	0
438070	425785	04033B	PARTICIPANT	\N	PRESENT	0
438071	425785	19563B	PARTICIPANT	\N	PRESENT	0
438072	425785	14251Q	PARTICIPANT	\N	PRESENT	0
438073	425785	02002K	PARTICIPANT	\N	PRESENT	0
438074	425785	14227Q	PARTICIPANT	\N	PRESENT	0
438075	425785	19643A	PARTICIPANT	\N	PRESENT	0
438076	425785	19699S	PARTICIPANT	\N	PRESENT	0
438077	425785	19735D	PARTICIPANT	\N	PRESENT	0
438078	425785	14042U	PARTICIPANT	\N	PRESENT	0
438079	425785	19335Q	PARTICIPANT	\N	PRESENT	0
438080	425785	14103D	PARTICIPANT	\N	PRESENT	0
438081	425785	14221J	PARTICIPANT	\N	PRESENT	0
438082	425785	14073Q	PARTICIPANT	\N	PRESENT	0
438083	425785	11080N	PARTICIPANT	\N	PRESENT	0
438084	425785	80013X	PARTICIPANT	\N	PRESENT	0
438085	425785	01057W	PARTICIPANT	\N	PRESENT	0
438086	425785	14223L	PARTICIPANT	\N	PRESENT	0
438087	425785	19527W	PARTICIPANT	\N	PRESENT	0
438088	425785	08034U	PARTICIPANT	\N	PRESENT	0
438089	425785	14021P	PARTICIPANT	\N	PRESENT	0
438090	425785	19575F	PARTICIPANT	\N	PRESENT	0
438091	425785	14281W	PARTICIPANT	\N	PRESENT	0
438092	425785	14157T	PARTICIPANT	\N	PRESENT	0
438093	425785	14159V	PARTICIPANT	\N	PRESENT	0
438094	425785	14031R	PARTICIPANT	\N	PRESENT	0
438095	425785	19725B	PARTICIPANT	\N	PRESENT	0
438096	425785	19551W	PARTICIPANT	\N	PRESENT	0
438097	425785	19741B	PARTICIPANT	\N	PRESENT	0
438098	425785	15447F	PARTICIPANT	\N	PRESENT	0
438099	425785	11110B	PARTICIPANT	\N	PRESENT	0
438100	425785	19794Q	PARTICIPANT	\N	PRESENT	0
438101	425785	14115H	PARTICIPANT	\N	PRESENT	0
438102	425785	19697Q	PARTICIPANT	\N	PRESENT	0
438103	425785	04086Q	PARTICIPANT	\N	PRESENT	0
438104	425785	19689Q	PARTICIPANT	\N	PRESENT	0
438105	425785	19719D	PARTICIPANT	\N	PRESENT	0
438106	425785	14147R	PARTICIPANT	\N	PRESENT	0
438107	425785	97011G	PARTICIPANT	\N	PRESENT	0
438108	425785	05012A	PARTICIPANT	\N	PRESENT	0
438109	425785	04018C	PARTICIPANT	\N	PRESENT	0
438110	425785	19701S	PARTICIPANT	\N	PRESENT	0
438111	425785	19569H	PARTICIPANT	\N	PRESENT	0
438112	425785	19739H	PARTICIPANT	\N	PRESENT	0
438113	425785	08039A	PARTICIPANT	\N	PRESENT	0
438114	425785	01034P	PARTICIPANT	\N	PRESENT	0
438115	425785	19675J	PARTICIPANT	\N	PRESENT	0
438116	425785	11070L	PARTICIPANT	\N	PRESENT	0
438117	425785	14255U	PARTICIPANT	\N	PRESENT	0
438118	425785	14213J	PARTICIPANT	\N	PRESENT	0
438119	425785	14030Q	PARTICIPANT	\N	PRESENT	0
438120	425785	01024M	PARTICIPANT	\N	PRESENT	0
438121	425785	19693L	PARTICIPANT	\N	PRESENT	0
438122	425785	19415P	PARTICIPANT	\N	PRESENT	0
438123	425785	19591F	PARTICIPANT	\N	PRESENT	0
438124	425785	14038Y	PARTICIPANT	\N	PRESENT	0
438125	425785	19573D	PARTICIPANT	\N	PRESENT	0
438126	425785	19717B	PARTICIPANT	\N	PRESENT	0
438127	425785	11099A	PARTICIPANT	\N	PRESENT	0
438128	425785	14265W	PARTICIPANT	\N	PRESENT	0
438129	425785	14179A	PARTICIPANT	\N	PRESENT	0
438130	425785	14329V	PARTICIPANT	\N	PRESENT	0
438131	425785	19691J	PARTICIPANT	\N	PRESENT	0
438132	425785	19709B	PARTICIPANT	\N	PRESENT	0
438133	425785	01043Q	PARTICIPANT	\N	PRESENT	0
438134	425785	04040A	PARTICIPANT	\N	PRESENT	0
438135	425785	14211G	PARTICIPANT	\N	PRESENT	0
438136	425785	19511N	PARTICIPANT	\N	PRESENT	0
438137	425785	19723Y	PARTICIPANT	\N	PRESENT	0
438138	425785	04049K	PARTICIPANT	\N	PRESENT	0
438139	425785	19782L	PARTICIPANT	\N	PRESENT	0
438140	425785	19749K	PARTICIPANT	\N	PRESENT	0
438141	425785	19515S	PARTICIPANT	\N	PRESENT	0
438142	425785	19745F	PARTICIPANT	\N	PRESENT	0
438143	425785	14219Q	PARTICIPANT	\N	PRESENT	0
438144	425785	08056B	PARTICIPANT	\N	PRESENT	0
438145	425785	19251M	PARTICIPANT	\N	PRESENT	0
438146	425785	19663E	PARTICIPANT	\N	PRESENT	0
438147	425785	19715Y	PARTICIPANT	\N	PRESENT	0
438148	425785	08018U	PARTICIPANT	\N	PRESENT	0
438149	425785	04038G	PARTICIPANT	\N	PRESENT	0
438150	425785	08028W	PARTICIPANT	\N	PRESENT	0
438151	425785	19671E	PARTICIPANT	\N	PRESENT	0
438152	425785	19747H	PARTICIPANT	\N	PRESENT	0
438153	425785	14187A	PARTICIPANT	\N	PRESENT	0
438154	425785	19621T	PARTICIPANT	\N	PRESENT	0
438155	425785	19399H	PARTICIPANT	\N	PRESENT	0
438156	425785	14034U	PARTICIPANT	\N	PRESENT	0
438157	425785	04069P	PARTICIPANT	\N	PRESENT	0
438158	425785	14257W	PARTICIPANT	\N	PRESENT	0
438159	425785	14093U	PARTICIPANT	\N	PRESENT	0
438160	425785	14357A	PARTICIPANT	\N	PRESENT	0
438161	425785	14059S	PARTICIPANT	\N	PRESENT	0
438162	425785	14061L	PARTICIPANT	\N	PRESENT	0
438163	425785	19768N	PARTICIPANT	\N	PRESENT	0
438164	425785	08015R	PARTICIPANT	\N	PRESENT	0
438165	425785	19729F	PARTICIPANT	\N	PRESENT	0
438166	425785	95067Q	PARTICIPANT	\N	PRESENT	0
438167	425785	19301E	PARTICIPANT	\N	PRESENT	0
438168	425785	19383Y	PARTICIPANT	\N	PRESENT	0
438169	425785	01048V	PARTICIPANT	\N	PRESENT	0
438170	425785	19413M	PARTICIPANT	\N	PRESENT	0
438171	425785	14119M	PARTICIPANT	\N	PRESENT	0
438172	425785	14215L	PARTICIPANT	\N	PRESENT	0
438173	425785	08060W	PARTICIPANT	\N	PRESENT	0
438174	425785	19507S	PARTICIPANT	\N	PRESENT	0
438175	425785	08020N	PARTICIPANT	\N	PRESENT	0
438176	425785	14105F	PARTICIPANT	\N	PRESENT	0
438177	425785	14089Y	PARTICIPANT	\N	PRESENT	0
438178	425785	14053L	PARTICIPANT	\N	PRESENT	0
438179	425785	01060R	PARTICIPANT	\N	PRESENT	0
438180	425785	04008A	PARTICIPANT	\N	PRESENT	0
438181	425785	19727D	PARTICIPANT	\N	PRESENT	0
438183	425785	04057K	PARTICIPANT	\N	PRESENT	0
438184	425785	19581D	PARTICIPANT	\N	PRESENT	0
438185	425785	14033T	PARTICIPANT	\N	PRESENT	0
438186	425785	11097X	PARTICIPANT	\N	PRESENT	0
438187	425785	04088S	PARTICIPANT	\N	PRESENT	0
438188	425785	08019V	PARTICIPANT	\N	PRESENT	0
438189	425785	98050T	PARTICIPANT	\N	PRESENT	0
438190	425785	98024R	PARTICIPANT	\N	PRESENT	0
438191	425785	04071H	PARTICIPANT	\N	PRESENT	0
438192	425785	11090Q	PARTICIPANT	\N	PRESENT	0
438193	425785	19521Q	PARTICIPANT	\N	PRESENT	0
438194	425785	08011M	PARTICIPANT	\N	PRESENT	0
438195	425785	19713W	PARTICIPANT	\N	PRESENT	0
438196	425785	04070G	PARTICIPANT	\N	PRESENT	0
438197	425785	19369B	PARTICIPANT	\N	PRESENT	0
438198	425785	08045X	PARTICIPANT	\N	PRESENT	0
438199	425785	11074Q	PARTICIPANT	\N	PRESENT	0
438207	425785	95041E	PARTICIPANT	\N	PRESENT	0
438201	425785	12016W	PARTICIPANT	\N	PRESENT	0
438206	425785	14026U	PARTICIPANT	\N	PRESENT	0
438214	425785	19631V	PARTICIPANT	\N	PRESENT	0
438204	425785	11115U	PARTICIPANT	\N	PRESENT	0
438205	425785	11077T	PARTICIPANT	\N	PRESENT	0
438208	425785	04034C	PARTICIPANT	\N	PRESENT	0
438209	425785	14205J	PARTICIPANT	\N	PRESENT	0
438210	425785	10006L	PARTICIPANT	\N	PRESENT	0
438211	425785	14097Y	PARTICIPANT	\N	PRESENT	0
438217	425785	19531S	PARTICIPANT	\N	PRESENT	0
438213	425785	19489J	PARTICIPANT	\N	PRESENT	0
438215	425785	19269X	PARTICIPANT	\N	PRESENT	0
438216	425785	04042C	PARTICIPANT	\N	PRESENT	0
438218	425785	11026G	PARTICIPANT	\N	PRESENT	0
438219	425785	19447X	PARTICIPANT	\N	PRESENT	0
438220	425785	14083S	PARTICIPANT	\N	PRESENT	0
438221	425785	89017R	PARTICIPANT	\N	PRESENT	0
435824	435823	14087W	PARTICIPANT	\N	PRESENT	0
435825	435823	19521Q	PARTICIPANT	\N	PRESENT	0
435826	435823	19679N	PARTICIPANT	\N	PRESENT	0
435827	435811	14213J	PARTICIPANT	\N	PRESENT	0
435828	435811	04092N	PARTICIPANT	\N	PRESENT	0
435829	435811	11067R	PARTICIPANT	\N	PRESENT	0
435830	435811	19569H	PARTICIPANT	\N	PRESENT	0
435853	435850	11026G	PARTICIPANT	\N	PRESENT	0
435854	435850	14089Y	PARTICIPANT	\N	PRESENT	0
435883	435882	14267Y	PARTICIPANT	\N	PRESENT	0
437141	425659	11074Q	PARTICIPANT	\N	PRESENT	0
437142	425659	14207L	PARTICIPANT	\N	PRESENT	0
437143	425659	19253P	PARTICIPANT	\N	PRESENT	0
437144	425659	19593H	PARTICIPANT	\N	PRESENT	0
437145	425659	14085U	PARTICIPANT	\N	PRESENT	0
437146	425659	19715Y	PARTICIPANT	\N	PRESENT	0
437147	425659	08043V	PARTICIPANT	\N	PRESENT	0
437148	425659	08017T	PARTICIPANT	\N	PRESENT	0
437149	425659	04034C	PARTICIPANT	\N	PRESENT	0
437150	425659	14039A	PARTICIPANT	\N	PRESENT	0
437151	425659	04057K	PARTICIPANT	\N	PRESENT	0
437152	425659	19301E	PARTICIPANT	\N	PRESENT	0
437153	425659	08031R	PARTICIPANT	\N	PRESENT	0
437154	425659	14261S	PARTICIPANT	\N	PRESENT	0
437155	425659	19735D	PARTICIPANT	\N	PRESENT	0
437156	425659	14083S	PARTICIPANT	\N	PRESENT	0
437158	425659	19319Q	PARTICIPANT	\N	PRESENT	0
437160	425659	19479G	PARTICIPANT	\N	PRESENT	0
437161	425659	19699S	PARTICIPANT	\N	PRESENT	0
437162	425659	19671E	PARTICIPANT	\N	PRESENT	0
437163	425659	19611R	PARTICIPANT	\N	PRESENT	0
437164	425659	14253S	PARTICIPANT	\N	PRESENT	0
437165	425659	08034U	PARTICIPANT	\N	PRESENT	0
437166	425659	19711U	PARTICIPANT	\N	PRESENT	0
437167	425659	11048N	PARTICIPANT	\N	PRESENT	0
437168	425659	11083R	PARTICIPANT	\N	PRESENT	0
437169	425659	19515S	PARTICIPANT	\N	PRESENT	0
437170	425659	19643A	PARTICIPANT	\N	PRESENT	0
437173	425659	04018C	PARTICIPANT	\N	PRESENT	0
437174	425659	14331P	PARTICIPANT	\N	PRESENT	0
437175	425659	19673G	PARTICIPANT	\N	PRESENT	0
437176	425659	99004R	PARTICIPANT	\N	PRESENT	0
437177	425659	14225N	PARTICIPANT	\N	PRESENT	0
437178	425659	08039A	PARTICIPANT	\N	PRESENT	0
437179	425659	14229S	PARTICIPANT	\N	PRESENT	0
437180	425659	04070G	PARTICIPANT	\N	PRESENT	0
437181	425659	01048V	PARTICIPANT	\N	PRESENT	0
437182	425659	11026G	PARTICIPANT	\N	PRESENT	0
437183	425659	11109J	PARTICIPANT	\N	PRESENT	0
437184	425659	19545Y	PARTICIPANT	\N	PRESENT	0
437185	425659	19631V	PARTICIPANT	\N	PRESENT	0
437186	425659	14109K	PARTICIPANT	\N	PRESENT	0
437187	425659	19693L	PARTICIPANT	\N	PRESENT	0
437139	425659	04086Q	PARTICIPANT	\N	PRESENT	0
437140	425659	19651A	PARTICIPANT	\N	PRESENT	0
437188	425659	19741B	PARTICIPANT	\N	PRESENT	0
437189	425659	12016W	PARTICIPANT	\N	PRESENT	0
437193	425659	14069U	PARTICIPANT	\N	PRESENT	0
437194	425659	08010L	PARTICIPANT	\N	PRESENT	0
437195	425659	19713W	PARTICIPANT	\N	PRESENT	0
437196	425659	04059M	PARTICIPANT	\N	PRESENT	0
437197	425659	11012A	PARTICIPANT	\N	PRESENT	0
437198	425659	04035D	PARTICIPANT	\N	PRESENT	0
437204	425659	14034U	PARTICIPANT	\N	PRESENT	0
437205	425659	04085P	PARTICIPANT	\N	PRESENT	0
437206	425659	08011M	PARTICIPANT	\N	PRESENT	0
437207	425659	08069G	PARTICIPANT	\N	PRESENT	0
437266	425661	19593H	PARTICIPANT	\N	PRESENT	0
437267	425661	11026G	PARTICIPANT	\N	PRESENT	0
437268	425661	14085U	PARTICIPANT	\N	PRESENT	0
437269	425661	12016W	PARTICIPANT	\N	PRESENT	0
437270	425661	19715Y	PARTICIPANT	\N	PRESENT	0
437271	425661	19631V	PARTICIPANT	\N	PRESENT	0
437272	425661	08017T	PARTICIPANT	\N	PRESENT	0
437273	425661	14039A	PARTICIPANT	\N	PRESENT	0
437274	425661	19301E	PARTICIPANT	\N	PRESENT	0
437275	425661	19651A	PARTICIPANT	\N	PRESENT	0
437276	425661	11083R	PARTICIPANT	\N	PRESENT	0
437277	425661	19713W	PARTICIPANT	\N	PRESENT	0
437278	425661	19479G	PARTICIPANT	\N	PRESENT	0
437279	425661	19611R	PARTICIPANT	\N	PRESENT	0
437280	425661	19699S	PARTICIPANT	\N	PRESENT	0
437281	425661	11074Q	PARTICIPANT	\N	PRESENT	0
437282	425661	08010L	PARTICIPANT	\N	PRESENT	0
437283	425661	14083S	PARTICIPANT	\N	PRESENT	0
437284	425661	04057K	PARTICIPANT	\N	PRESENT	0
437285	425661	08043V	PARTICIPANT	\N	PRESENT	0
437286	425661	14069U	PARTICIPANT	\N	PRESENT	0
437287	425661	14253S	PARTICIPANT	\N	PRESENT	0
437288	425661	08034U	PARTICIPANT	\N	PRESENT	0
437289	425661	11048N	PARTICIPANT	\N	PRESENT	0
437290	425661	01048V	PARTICIPANT	\N	PRESENT	0
437291	425661	19515S	PARTICIPANT	\N	PRESENT	0
437292	425661	19643A	PARTICIPANT	\N	PRESENT	0
437293	425661	07033P	PARTICIPANT	\N	PRESENT	0
437294	425661	08039A	PARTICIPANT	\N	PRESENT	0
437295	425661	19693L	PARTICIPANT	\N	PRESENT	0
437296	425661	19673G	PARTICIPANT	\N	PRESENT	0
437297	425661	01024M	PARTICIPANT	\N	PRESENT	0
437298	425661	14034U	PARTICIPANT	\N	PRESENT	0
437299	425661	19671E	PARTICIPANT	\N	PRESENT	0
437300	425661	11072N	PARTICIPANT	\N	PRESENT	0
437301	425661	14229S	PARTICIPANT	\N	PRESENT	0
437302	425661	04035D	PARTICIPANT	\N	PRESENT	0
437303	425661	08031R	PARTICIPANT	\N	PRESENT	0
437304	425661	04070G	PARTICIPANT	\N	PRESENT	0
437305	425661	99004R	PARTICIPANT	\N	PRESENT	0
437306	425661	08069G	PARTICIPANT	\N	PRESENT	0
437307	425661	04059M	PARTICIPANT	\N	PRESENT	0
437308	425661	14087W	PARTICIPANT	\N	PRESENT	0
437309	425661	19711U	PARTICIPANT	\N	PRESENT	0
437310	432678	14147R	PARTICIPANT	\N	EXCUSE	0
437311	425661	14225N	PARTICIPANT	\N	PRESENT	0
437312	425661	19319Q	PARTICIPANT	\N	PRESENT	0
437313	425661	19545Y	PARTICIPANT	\N	PRESENT	0
437315	437314	14041T	PARTICIPANT	\N	PRESENT	0
437316	437314	11083R	PARTICIPANT	\N	PRESENT	0
437317	437314	04035D	PARTICIPANT	\N	PRESENT	0
437318	437314	14059S	PARTICIPANT	\N	PRESENT	0
437319	437314	14071N	PARTICIPANT	\N	PRESENT	0
437320	437314	14147R	PARTICIPANT	\N	PRESENT	0
437321	437314	95063L	PARTICIPANT	\N	PRESENT	0
437322	437314	14255U	PARTICIPANT	\N	PRESENT	0
437264	425661	04086Q	PARTICIPANT	\N	PRESENT	0
437265	425661	04085P	PARTICIPANT	\N	PRESENT	0
437369	425664	11027H	PARTICIPANT	\N	PRESENT	0
437370	434672	14331P	PARTICIPANT	\N	PRESENT	0
437371	434672	19479G	PARTICIPANT	\N	PRESENT	0
437372	434672	19711U	PARTICIPANT	\N	PRESENT	0
437373	434672	08034U	PARTICIPANT	\N	PRESENT	0
437374	434672	19651A	PARTICIPANT	\N	PRESENT	0
437375	434672	12016W	PARTICIPANT	\N	PRESENT	0
437376	434672	08011M	PARTICIPANT	\N	PRESENT	0
437377	434672	11074Q	PRESIDENT	0	PRESENT	0
437378	434672	19671E	PARTICIPANT	\N	PRESENT	0
437379	434672	04086Q	PARTICIPANT	\N	PRESENT	0
437380	434672	11012A	PARTICIPANT	\N	PRESENT	0
437381	434672	14085U	PARTICIPANT	\N	PRESENT	0
437382	434672	19741B	PARTICIPANT	\N	PRESENT	0
437383	434672	08010L	PARTICIPANT	\N	PRESENT	0
437384	434672	99004R	PARTICIPANT	\N	PRESENT	0
437385	434672	19545Y	PARTICIPANT	\N	PRESENT	0
437386	434672	14034U	PARTICIPANT	\N	PRESENT	0
437387	434672	14327T	PARTICIPANT	\N	EXCUSE	0
437388	434672	07029T	PARTICIPANT	\N	EXCUSE	0
437389	425664	04085P	PARTICIPANT	\N	PRESENT	0
437390	425664	08010L	PARTICIPANT	\N	PRESENT	0
437391	425664	19253P	PARTICIPANT	\N	PRESENT	0
437392	425664	19651A	PARTICIPANT	\N	PRESENT	0
437393	425664	11072N	PARTICIPANT	\N	PRESENT	0
437394	425664	19545Y	PARTICIPANT	\N	PRESENT	0
437395	425664	19319Q	PARTICIPANT	\N	PRESENT	0
437396	425664	19479G	PARTICIPANT	\N	PRESENT	0
437397	425664	14087W	PARTICIPANT	\N	PRESENT	0
437398	425664	19671E	PARTICIPANT	\N	PRESENT	0
437399	425664	19301E	PARTICIPANT	\N	PRESENT	0
437400	425664	19673G	PARTICIPANT	\N	PRESENT	0
437401	425664	01024M	PARTICIPANT	\N	PRESENT	0
437402	425664	14085U	PARTICIPANT	\N	PRESENT	0
437403	425664	04086Q	PARTICIPANT	\N	PRESENT	0
437404	425664	19741B	PARTICIPANT	\N	PRESENT	0
437405	425664	14069U	PARTICIPANT	\N	PRESENT	0
437406	425664	19647E	PARTICIPANT	\N	PRESENT	0
437407	425664	11074Q	PARTICIPANT	\N	PRESENT	0
437408	425664	08031R	PARTICIPANT	\N	PRESENT	0
437409	425664	11012A	PARTICIPANT	\N	PRESENT	0
428160	428159	19631V	PARTICIPANT	\N	PRESENT	0
428161	428159	19747H	PARTICIPANT	\N	PRESENT	0
428162	428159	14197C	PARTICIPANT	\N	PRESENT	0
428163	428159	19369B	PARTICIPANT	\N	PRESENT	0
428165	428159	14265W	PARTICIPANT	\N	PRESENT	0
428166	428159	19629C	PARTICIPANT	\N	PRESENT	0
430644	428277	19447X	PARTICIPANT	\N	EXCUSE	0
430645	428277	01048V	PARTICIPANT	\N	PRESENT	0
430648	428243	14331P	PARTICIPANT	\N	PRESENT	0
430649	428243	19671E	PARTICIPANT	\N	PRESENT	0
434829	425334	11040E	PARTICIPANT	\N	PRESENT	0
434830	425334	11074Q	PARTICIPANT	\N	PRESENT	0
434831	425334	08052W	PARTICIPANT	\N	PRESENT	0
434832	425334	11026G	PARTICIPANT	\N	PRESENT	0
434833	425334	14281W	PARTICIPANT	\N	PRESENT	0
434834	425334	11045K	PARTICIPANT	\N	PRESENT	0
434835	425334	11067R	PARTICIPANT	\N	PRESENT	0
434836	425334	11109J	PARTICIPANT	\N	PRESENT	0
434837	425334	19565D	PARTICIPANT	\N	PRESENT	0
434838	425334	19651A	PARTICIPANT	\N	PRESENT	0
434839	425334	19697Q	PARTICIPANT	\N	PRESENT	0
434840	425334	19301E	PARTICIPANT	\N	PRESENT	0
434841	425334	19545Y	PARTICIPANT	\N	PRESENT	0
434842	425334	14042U	PARTICIPANT	\N	PRESENT	0
434843	425334	19369B	PARTICIPANT	\N	PRESENT	0
434844	425334	89017R	PARTICIPANT	\N	PRESENT	0
434845	425334	11031D	PARTICIPANT	\N	PRESENT	0
434846	425334	11085T	PARTICIPANT	\N	PRESENT	0
434827	425334	04086Q	PARTICIPANT	\N	PRESENT	0
434828	425334	19667J	PARTICIPANT	\N	PRESENT	0
434847	425334	04092N	PARTICIPANT	\N	PRESENT	0
434848	425334	19693L	PARTICIPANT	\N	PRESENT	0
434849	425334	19657G	PARTICIPANT	\N	PRESENT	0
434850	425334	14213J	PARTICIPANT	\N	PRESENT	0
434851	425334	11097X	PARTICIPANT	\N	PRESENT	0
434852	425334	10006L	PARTICIPANT	\N	PRESENT	0
434853	425334	08010L	PARTICIPANT	\N	PRESENT	0
434854	425334	14217N	PARTICIPANT	\N	PRESENT	0
434855	425334	14227Q	PARTICIPANT	\N	PRESENT	0
434856	425334	14331P	PARTICIPANT	\N	PRESENT	0
434857	425334	19711U	PARTICIPANT	\N	PRESENT	0
434858	425334	14261S	PARTICIPANT	\N	PRESENT	0
434859	425334	19553Y	PARTICIPANT	\N	PRESENT	0
434860	425334	14071N	PARTICIPANT	\N	PRESENT	0
434861	425334	19695N	PARTICIPANT	\N	PRESENT	0
434862	425334	19687N	PARTICIPANT	\N	PRESENT	0
434863	425334	19689Q	PARTICIPANT	\N	PRESENT	0
434929	430310	19691J	PARTICIPANT	\N	EXCUSE	0
434930	425340	11026G	PARTICIPANT	\N	PRESENT	0
434931	425340	08017T	PARTICIPANT	\N	PRESENT	0
434932	425340	19667J	PARTICIPANT	\N	PRESENT	0
434933	425340	11040E	PARTICIPANT	\N	PRESENT	0
434934	425340	11031D	PARTICIPANT	\N	PRESENT	0
434935	425340	19565D	PARTICIPANT	\N	PRESENT	0
434936	425340	19651A	PARTICIPANT	\N	PRESENT	0
434937	425340	14042U	PARTICIPANT	\N	PRESENT	0
434938	425340	19611R	PARTICIPANT	\N	PRESENT	0
434939	425340	14071N	PARTICIPANT	\N	PRESENT	0
434940	425340	19693L	PARTICIPANT	\N	PRESENT	0
434941	425340	14331P	PARTICIPANT	\N	PRESENT	0
434942	425340	19553Y	PARTICIPANT	\N	PRESENT	0
434943	425340	01034P	PARTICIPANT	\N	PRESENT	0
434944	425340	14227Q	PARTICIPANT	\N	PRESENT	0
434945	425340	19593H	PARTICIPANT	\N	PRESENT	0
434946	425340	19711U	PARTICIPANT	\N	PRESENT	0
434947	425340	19533U	PARTICIPANT	\N	PRESENT	0
434948	425340	19369B	PARTICIPANT	\N	PRESENT	0
434949	425340	11045K	PARTICIPANT	\N	PRESENT	0
434950	425340	19689Q	PARTICIPANT	\N	PRESENT	0
434951	425340	11067R	PARTICIPANT	\N	PRESENT	0
434952	425340	19695N	PARTICIPANT	\N	PRESENT	0
434953	425340	19621T	PARTICIPANT	\N	PRESENT	0
434954	425340	11083R	PARTICIPANT	\N	PRESENT	0
434955	425340	19741B	PARTICIPANT	\N	PRESENT	0
434956	425340	19545Y	PARTICIPANT	\N	PRESENT	0
434957	425340	04043D	PARTICIPANT	\N	PRESENT	0
434958	425340	14213J	PARTICIPANT	\N	PRESENT	0
434959	425340	11097X	PARTICIPANT	\N	PRESENT	0
434960	425340	11090Q	PARTICIPANT	\N	PRESENT	0
434961	425340	08052W	PARTICIPANT	\N	PRESENT	0
434962	425340	04092N	PARTICIPANT	\N	PRESENT	0
434963	425340	10006L	PARTICIPANT	\N	PRESENT	0
434964	425340	14217N	PARTICIPANT	\N	PRESENT	0
434965	425340	19333N	PARTICIPANT	\N	PRESENT	0
434905	425340	11070L	PARTICIPANT	\N	PRESENT	0
434906	430310	19697Q	PARTICIPANT	\N	PRESENT	0
434907	430310	11067R	PARTICIPANT	\N	PRESENT	0
434908	430310	01034P	PARTICIPANT	\N	PRESENT	0
434909	430310	19565D	PARTICIPANT	\N	PRESENT	0
434910	430310	04092N	PRESIDENT	0	PRESENT	0
434911	430310	11045K	PARTICIPANT	\N	PRESENT	0
434912	430310	11097X	PARTICIPANT	\N	PRESENT	0
434913	430310	08052W	PARTICIPANT	\N	PRESENT	0
434914	430310	14227Q	PARTICIPANT	\N	PRESENT	0
434915	430310	17779H	PARTICIPANT	\N	PRESENT	0
434916	430310	19553Y	PARTICIPANT	\N	PRESENT	0
434917	430310	11031D	PARTICIPANT	\N	PRESENT	0
434918	430310	14119M	PARTICIPANT	\N	PRESENT	0
434919	430310	14281W	PARTICIPANT	\N	PRESENT	0
434920	430310	14042U	PARTICIPANT	\N	PRESENT	0
434921	430310	14213J	PARTICIPANT	\N	PRESENT	0
434922	430310	19657G	PARTICIPANT	\N	PRESENT	0
434923	430310	14071N	PARTICIPANT	\N	PRESENT	0
434924	430310	14261S	PARTICIPANT	\N	PRESENT	0
434925	430310	14217N	PARTICIPANT	\N	PRESENT	0
434926	430310	10006L	PARTICIPANT	\N	PRESENT	0
434927	430310	14195A	PARTICIPANT	\N	EXCUSE	0
434928	430310	08041T	PARTICIPANT	\N	EXCUSE	0
434966	425340	19657G	PARTICIPANT	\N	PRESENT	0
434967	425340	14229S	PARTICIPANT	\N	PRESENT	0
435009	425342	19333N	PARTICIPANT	\N	PRESENT	0
435010	425342	11074Q	PARTICIPANT	\N	PRESENT	0
435011	425342	14229S	PARTICIPANT	\N	PRESENT	0
435012	425342	08017T	PARTICIPANT	\N	PRESENT	0
435013	425342	11067R	PARTICIPANT	\N	PRESENT	0
435014	425342	19689Q	PARTICIPANT	\N	PRESENT	0
435015	425342	19593H	PARTICIPANT	\N	PRESENT	0
435016	425342	19651A	PARTICIPANT	\N	PRESENT	0
435017	425342	11083R	PARTICIPANT	\N	PRESENT	0
435018	425342	19545Y	PARTICIPANT	\N	PRESENT	0
435019	425342	19369B	PARTICIPANT	\N	PRESENT	0
435020	425342	14213J	PARTICIPANT	\N	PRESENT	0
435021	425342	19533U	PARTICIPANT	\N	PRESENT	0
435022	425342	19621T	PARTICIPANT	\N	PRESENT	0
435023	425342	10006L	PARTICIPANT	\N	PRESENT	0
435024	425342	04043D	PARTICIPANT	\N	PRESENT	0
435025	425342	19657G	PARTICIPANT	\N	PRESENT	0
435026	425342	14261S	PARTICIPANT	\N	PRESENT	0
435027	425342	19611R	PARTICIPANT	\N	PRESENT	0
435028	425342	19693L	PARTICIPANT	\N	PRESENT	0
435029	425342	11090Q	PARTICIPANT	\N	PRESENT	0
435030	425342	14083S	PARTICIPANT	\N	PRESENT	0
435031	425342	14034U	PARTICIPANT	\N	PRESENT	0
435032	425342	19553Y	PARTICIPANT	\N	PRESENT	0
435047	425342	19687N	PARTICIPANT	\N	PRESENT	0
435048	425342	14331P	PARTICIPANT	\N	PRESENT	0
435052	425305	19565D	PARTICIPANT	\N	PRESENT	0
435050	425305	14034U	PARTICIPANT	\N	PRESENT	0
435051	425305	11031D	PARTICIPANT	\N	PRESENT	0
435053	425305	11067R	PARTICIPANT	\N	PRESENT	0
435054	425305	14071N	PARTICIPANT	\N	PRESENT	0
435055	425305	11097X	PARTICIPANT	\N	PRESENT	0
435056	425305	98024R	PARTICIPANT	\N	PRESENT	0
435057	425305	14281W	PARTICIPANT	\N	PRESENT	0
435058	425305	14217N	PARTICIPANT	\N	PRESENT	0
435059	425305	19762G	PARTICIPANT	\N	PRESENT	0
435060	425305	08052W	PARTICIPANT	\N	PRESENT	0
435061	425305	19683J	PARTICIPANT	\N	PRESENT	0
435062	425305	04018C	PARTICIPANT	\N	PRESENT	0
435007	425342	11070L	PARTICIPANT	\N	PRESENT	0
435008	425342	89017R	PARTICIPANT	\N	PRESENT	0
435063	425305	04092N	PARTICIPANT	\N	PRESENT	0
435064	425305	01034P	PARTICIPANT	\N	PRESENT	0
435065	425305	14261S	PARTICIPANT	\N	PRESENT	0
435066	425305	19697Q	PARTICIPANT	\N	PRESENT	0
435067	425305	14042U	PARTICIPANT	\N	PRESENT	0
435068	425305	11085T	PARTICIPANT	\N	PRESENT	0
435069	425305	19691J	PARTICIPANT	\N	PRESENT	0
435070	425305	14213J	PARTICIPANT	\N	PRESENT	0
435071	425305	19657G	PARTICIPANT	\N	PRESENT	0
435072	425305	14331P	PARTICIPANT	\N	PRESENT	0
435073	425305	19415P	PARTICIPANT	\N	PRESENT	0
435074	425305	19663E	PARTICIPANT	\N	PRESENT	0
435075	425305	14253S	PARTICIPANT	\N	PRESENT	0
435076	425305	10006L	PARTICIPANT	\N	PRESENT	0
435077	425305	19703U	PARTICIPANT	\N	PRESENT	0
435078	425305	12016W	PARTICIPANT	\N	PRESENT	0
435079	425305	19553Y	PARTICIPANT	\N	PRESENT	0
435080	425305	95037J	PARTICIPANT	\N	PRESENT	0
433552	425287	08028W	PARTICIPANT	\N	PRESENT	0
433553	425287	08056B	PARTICIPANT	\N	PRESENT	0
433555	425287	19553Y	PARTICIPANT	\N	PRESENT	0
433556	425287	19581D	PARTICIPANT	\N	PRESENT	0
433557	425287	11012A	PARTICIPANT	\N	PRESENT	0
433563	425287	14059S	PARTICIPANT	\N	PRESENT	0
433564	425287	19619A	PARTICIPANT	\N	PRESENT	0
433565	425287	14211G	PARTICIPANT	\N	PRESENT	0
433566	425287	19525U	PARTICIPANT	\N	PRESENT	0
433567	425287	19731Y	PARTICIPANT	\N	PRESENT	0
433568	425287	04088S	PARTICIPANT	\N	PRESENT	0
433569	425287	19383Y	PARTICIPANT	\N	PRESENT	0
433570	425287	04085P	PARTICIPANT	\N	PRESENT	0
433571	425287	11101A	PARTICIPANT	\N	PRESENT	0
433572	425287	19599P	PARTICIPANT	\N	PRESENT	0
433573	425287	14219Q	PARTICIPANT	\N	PRESENT	0
433575	425287	19758L	PARTICIPANT	\N	PRESENT	0
433576	425287	19399H	PARTICIPANT	\N	PRESENT	0
433577	425287	17637T	PARTICIPANT	\N	PRESENT	0
433578	425287	14038Y	PARTICIPANT	\N	PRESENT	0
433579	425287	19503N	PARTICIPANT	\N	PRESENT	0
433580	425287	14030Q	PARTICIPANT	\N	PRESENT	0
433581	425287	08015R	PARTICIPANT	\N	PRESENT	0
433582	425287	19749K	PARTICIPANT	\N	PRESENT	0
433583	425287	19521Q	PARTICIPANT	\N	PRESENT	0
433584	425287	11090Q	PARTICIPANT	\N	PRESENT	0
433585	425287	19531S	PARTICIPANT	\N	PRESENT	0
433586	425287	19301E	PARTICIPANT	\N	PRESENT	0
433587	425287	19747H	PARTICIPANT	\N	PRESENT	0
433588	430776	14053L	PARTICIPANT	\N	PRESENT	0
433589	430776	10015M	PARTICIPANT	\N	PRESENT	0
433590	430776	01024M	PARTICIPANT	\N	PRESENT	0
433591	430776	04038G	PARTICIPANT	\N	PRESENT	0
433592	430776	01028R	PARTICIPANT	\N	PRESENT	0
433593	430776	05008E	PRESIDENT	0	PRESENT	0
433594	430776	14231L	PARTICIPANT	\N	PRESENT	0
433595	430776	19725B	PARTICIPANT	\N	PRESENT	0
433596	430776	19489J	PARTICIPANT	\N	PRESENT	0
433597	430776	19729F	PARTICIPANT	\N	PRESENT	0
433598	430776	95063L	PARTICIPANT	\N	PRESENT	0
433599	430776	14179A	PARTICIPANT	\N	PRESENT	0
433600	430776	14069U	PARTICIPANT	\N	PRESENT	0
433601	430776	14151M	PARTICIPANT	\N	PRESENT	0
433602	430776	19762G	PARTICIPANT	\N	PRESENT	0
433603	430776	14147R	PARTICIPANT	\N	PRESENT	0
433604	425287	11097X	PARTICIPANT	\N	PRESENT	0
433605	425287	19689Q	PARTICIPANT	\N	PRESENT	0
433606	425287	08020N	PARTICIPANT	\N	PRESENT	0
433607	431079	11067R	PARTICIPANT	\N	PRESENT	0
433608	431079	19649G	PARTICIPANT	\N	PRESENT	0
433609	431079	14065Q	PARTICIPANT	\N	PRESENT	0
433610	431079	08034U	PARTICIPANT	\N	PRESENT	0
433611	431079	04092N	PRESIDENT	0	PRESENT	0
433612	431079	19569H	PARTICIPANT	\N	PRESENT	0
433613	431079	19415P	PARTICIPANT	\N	PRESENT	0
433614	431079	04045F	PARTICIPANT	\N	PRESENT	0
433615	431079	19447X	PARTICIPANT	\N	PRESENT	0
433616	431079	11031D	PARTICIPANT	\N	PRESENT	0
433617	431079	19553Y	PARTICIPANT	\N	PRESENT	0
433618	431079	14041T	PARTICIPANT	\N	PRESENT	0
433619	431079	14042U	PARTICIPANT	\N	PRESENT	0
433620	431079	14195A	PARTICIPANT	\N	PRESENT	0
433621	431079	19575F	PARTICIPANT	\N	PRESENT	0
433622	431079	14213J	PARTICIPANT	\N	PRESENT	0
433623	431079	11085T	PARTICIPANT	\N	PRESENT	0
433624	431079	14215L	PARTICIPANT	\N	PRESENT	0
433625	431079	19685L	PARTICIPANT	\N	PRESENT	0
433626	431079	14217N	PARTICIPANT	\N	PRESENT	0
433627	431079	19335Q	PARTICIPANT	\N	PRESENT	0
433628	431079	10006L	PARTICIPANT	\N	PRESENT	0
433629	431079	19683J	PARTICIPANT	\N	PRESENT	0
433888	433887	04033B	PARTICIPANT	\N	PRESENT	0
433889	433887	01058X	PARTICIPANT	\N	PRESENT	0
433890	433887	14115H	PARTICIPANT	\N	PRESENT	0
433891	433887	97011G	PARTICIPANT	\N	PRESENT	0
433892	433887	08034U	PARTICIPANT	\N	PRESENT	0
433893	433887	10006L	PARTICIPANT	\N	PRESENT	0
433894	433887	95067Q	PARTICIPANT	\N	PRESENT	0
433895	433887	16685X	PARTICIPANT	\N	PRESENT	0
433896	433887	08058D	PARTICIPANT	\N	PRESENT	0
433897	433887	04049K	PARTICIPANT	\N	PRESENT	0
433898	433887	95030B	PARTICIPANT	\N	PRESENT	0
433899	433887	19723Y	PARTICIPANT	\N	PRESENT	0
433900	433887	19367Y	PARTICIPANT	\N	PRESENT	0
433902	433901	14237S	PARTICIPANT	\N	PRESENT	0
433903	433901	14079W	PARTICIPANT	\N	PRESENT	0
433904	433901	04070G	PARTICIPANT	\N	PRESENT	0
433905	433901	19637C	PARTICIPANT	\N	PRESENT	0
433919	433918	14237S	PARTICIPANT	\N	PRESENT	0
438472	432678	08024S	PARTICIPANT	\N	PRESENT	0
438473	432678	08045X	PARTICIPANT	\N	EXCUSE	0
438487	432678	14107H	PARTICIPANT	\N	EXCUSE	0
438692	432678	02002K	PARTICIPANT	\N	EXCUSE	0
439867	438470	14071N	PARTICIPANT	\N	EXCUSE	0
439868	438470	04044E	PARTICIPANT	\N	EXCUSE	0
441713	441703	19727D	PARTICIPANT	\N	PRESENT	0
441711	441701	19727D	PARTICIPANT	\N	PRESENT	0
441712	441702	19727D	PARTICIPANT	\N	PRESENT	0
441714	441704	19727D	PARTICIPANT	\N	PRESENT	0
441715	441705	19727D	PARTICIPANT	\N	PRESENT	0
441716	441706	19727D	PARTICIPANT	\N	PRESENT	0
441718	441717	19727D	PARTICIPANT	\N	PRESENT	0
441719	441707	19727D	PARTICIPANT	\N	PRESENT	0
441720	441708	19447X	PARTICIPANT	\N	PRESENT	0
441721	441709	19447X	PARTICIPANT	\N	PRESENT	0
443720	443719	14257W	PARTICIPANT	\N	PRESENT	0
443722	443719	04049K	PARTICIPANT	\N	PRESENT	0
443723	443719	19515S	PARTICIPANT	\N	PRESENT	0
443725	443724	19515S	PARTICIPANT	\N	PRESENT	0
443726	443724	04049K	PARTICIPANT	\N	PRESENT	0
443727	443724	14257W	PARTICIPANT	\N	PRESENT	0
443728	443724	04088S	PARTICIPANT	\N	PRESENT	0
443729	443724	19631V	PARTICIPANT	\N	PRESENT	0
445872	445815	14105F	PARTICIPANT	\N	EXCUSE	0
445873	445815	08068F	PARTICIPANT	\N	EXCUSE	0
445874	445815	19545Y	PARTICIPANT	\N	EXCUSE	0
445875	445815	14079W	PARTICIPANT	\N	EXCUSE	0
445876	445815	14041T	PARTICIPANT	\N	EXCUSE	0
445877	445815	14187A	PARTICIPANT	\N	EXCUSE	0
445878	445815	14034U	PARTICIPANT	\N	EXCUSE	0
445879	445815	08015R	PARTICIPANT	\N	EXCUSE	0
445880	445815	16685X	PARTICIPANT	\N	EXCUSE	0
445881	445815	14265W	PARTICIPANT	\N	EXCUSE	0
445882	445815	14051J	PARTICIPANT	\N	EXCUSE	0
445883	439811	14073Q	PARTICIPANT	\N	PRESENT	0
445884	445815	08047A	PARTICIPANT	\N	EXCUSE	0
445885	445815	04088S	PARTICIPANT	\N	EXCUSE	0
445886	445815	19669L	PARTICIPANT	\N	EXCUSE	0
445887	439811	19531S	PARTICIPANT	\N	PRESENT	0
445888	439811	19447X	PARTICIPANT	\N	PRESENT	0
445889	439811	19301E	PARTICIPANT	\N	PRESENT	0
445890	439811	14275Y	PARTICIPANT	\N	PRESENT	0
445891	439808	14147R	PARTICIPANT	\N	PRESENT	0
445967	441793	08048B	PARTICIPANT	\N	EXCUSE	0
445968	442327	19551W	PARTICIPANT	\N	PRESENT	0
445969	441793	19253P	PARTICIPANT	\N	EXCUSE	0
445970	442327	01028R	PARTICIPANT	\N	PRESENT	0
445977	442327	11066Q	PARTICIPANT	\N	EXCUSE	0
445978	441793	14327T	PARTICIPANT	\N	EXCUSE	0
445979	442327	14107H	PARTICIPANT	\N	PRESENT	0
445987	441793	04044E	PARTICIPANT	\N	EXCUSE	0
445991	445989	19697Q	PARTICIPANT	\N	PRESENT	0
445993	445992	19697Q	PARTICIPANT	\N	PRESENT	0
445997	442327	19515S	PARTICIPANT	\N	EXCUSE	0
445998	442327	19349W	PARTICIPANT	\N	PRESENT	0
445999	445946	99004R	PRESIDENT	0	PRESENT	0
446000	442327	19713W	PARTICIPANT	\N	PRESENT	0
446072	446070	80013X	PARTICIPANT	\N	PRESENT	0
446074	446073	80013X	PARTICIPANT	\N	PRESENT	0
446077	446076	80013X	PARTICIPANT	\N	PRESENT	0
446102	441793	14063N	PARTICIPANT	\N	EXCUSE	0
446342	446341	14133K	PARTICIPANT	\N	PRESENT	0
446343	446341	08056B	PARTICIPANT	\N	PRESENT	0
446371	441793	14257W	PARTICIPANT	\N	EXCUSE	0
446375	446374	19515S	PARTICIPANT	\N	PRESENT	0
446376	446374	19812Y	PARTICIPANT	\N	PRESENT	0
446412	446411	14083S	PARTICIPANT	\N	PRESENT	0
446413	446411	14061L	PARTICIPANT	\N	PRESENT	0
446415	446414	16685X	PARTICIPANT	\N	PRESENT	0
446417	446416	16685X	PARTICIPANT	\N	PRESENT	0
446418	446416	14083S	PARTICIPANT	\N	PRESENT	0
446787	444386	14042U	PARTICIPANT	\N	PRESENT	0
446788	444386	19575F	PARTICIPANT	\N	PRESENT	0
446789	444386	14179A	PARTICIPANT	\N	PRESENT	0
446790	444386	19685L	PARTICIPANT	\N	PRESENT	0
446791	444386	14215L	PARTICIPANT	\N	PRESENT	0
424266	424257	19631V	PARTICIPANT	\N	PRESENT	0
424267	424257	19515S	PARTICIPANT	\N	PRESENT	0
424268	424257	14207L	PARTICIPANT	\N	PRESENT	0
424269	424257	14187A	PARTICIPANT	\N	PRESENT	0
424270	424257	19695N	PARTICIPANT	\N	PRESENT	0
424271	424257	19511N	PARTICIPANT	\N	PRESENT	0
424272	424257	04049K	PARTICIPANT	\N	PRESENT	0
424273	424257	19563B	PARTICIPANT	\N	PRESENT	0
424274	424257	14257W	PARTICIPANT	\N	PRESENT	0
424276	424257	04088S	PARTICIPANT	\N	PRESENT	0
424277	424257	19747H	PARTICIPANT	\N	PRESENT	0
424288	424280	08028W	PARTICIPANT	\N	PRESENT	0
438222	425785	11085T	PARTICIPANT	\N	PRESENT	0
438223	425785	14173T	PARTICIPANT	\N	PRESENT	0
438224	425785	07033P	PARTICIPANT	\N	PRESENT	0
438225	425785	19669L	PARTICIPANT	\N	PRESENT	0
438226	425785	08069G	PARTICIPANT	\N	PRESENT	0
438227	425785	14135M	PARTICIPANT	\N	PRESENT	0
438228	425785	08035V	PARTICIPANT	\N	PRESENT	0
438229	425785	11064N	PARTICIPANT	\N	PRESENT	0
438230	425785	17583W	PARTICIPANT	\N	PRESENT	0
438231	425785	14249W	PARTICIPANT	\N	PRESENT	0
438238	425785	17637T	PARTICIPANT	\N	PRESENT	0
438233	425785	14133K	PARTICIPANT	\N	PRESENT	0
438234	425785	14169X	PARTICIPANT	\N	PRESENT	0
438236	425785	17589D	PARTICIPANT	\N	PRESENT	0
438237	425785	05008E	PARTICIPANT	\N	PRESENT	0
439000	431727	14038Y	PARTICIPANT	\N	EXCUSE	0
439001	431727	11010L	PARTICIPANT	\N	EXCUSE	0
439002	431727	04043D	PARTICIPANT	\N	EXCUSE	0
439003	431727	12016W	PARTICIPANT	\N	EXCUSE	0
439396	439395	95030B	PARTICIPANT	\N	PRESENT	0
439397	439395	01048V	PARTICIPANT	\N	PRESENT	0
439398	439395	95067Q	PARTICIPANT	\N	PRESENT	0
439508	439507	14051J	PARTICIPANT	\N	PRESENT	0
439509	439507	08060W	PARTICIPANT	\N	PRESENT	0
439510	439507	08009T	PRESIDENT	0	PRESENT	0
439511	439507	19367Y	PARTICIPANT	\N	PRESENT	0
439512	439507	19758L	PARTICIPANT	\N	PRESENT	0
439513	439507	19826F	PARTICIPANT	\N	EXCUSE	0
439514	436031	08056B	PARTICIPANT	\N	PRESENT	0
439515	436031	14097Y	PARTICIPANT	\N	PRESENT	0
439516	436031	04040A	PARTICIPANT	\N	PRESENT	0
439517	436031	08010L	PARTICIPANT	\N	PRESENT	0
439518	436031	19669L	PARTICIPANT	\N	PRESENT	0
439519	436031	19673G	PARTICIPANT	\N	PRESENT	0
439520	436031	19719D	PRESIDENT	0	PRESENT	0
439521	439507	19413M	PARTICIPANT	\N	PRESENT	0
439522	426318	14034U	PARTICIPANT	\N	PRESENT	0
439523	436031	07004J	PARTICIPANT	\N	EXCUSE	0
439524	436031	19421M	PARTICIPANT	\N	EXCUSE	0
439525	436031	10015M	PARTICIPANT	\N	EXCUSE	0
439526	436031	08053X	PARTICIPANT	\N	EXCUSE	0
439527	436031	04044E	PARTICIPANT	\N	EXCUSE	0
439528	436031	14249W	PARTICIPANT	\N	EXCUSE	0
439531	439507	14026U	PARTICIPANT	\N	PRESENT	0
439547	426318	12041X	PARTICIPANT	\N	PRESENT	0
439549	426318	14235Q	PARTICIPANT	\N	PRESENT	0
439564	426318	08058D	PARTICIPANT	\N	PRESENT	0
439565	426318	11041F	PARTICIPANT	\N	PRESENT	0
439566	426318	04034C	PARTICIPANT	\N	PRESENT	0
439567	426318	19479G	PARTICIPANT	\N	PRESENT	0
439568	426318	19737F	PARTICIPANT	\N	PRESENT	0
439569	436982	04092N	PRESIDENT	0	PRESENT	0
439570	436982	14042U	PARTICIPANT	\N	PRESENT	0
439571	436982	19575F	PARTICIPANT	\N	PRESENT	0
439572	436982	14213J	PARTICIPANT	\N	PRESENT	0
439573	436982	08043V	PARTICIPANT	\N	PRESENT	0
439574	436982	14217N	PARTICIPANT	\N	PRESENT	0
439575	436982	19447X	PARTICIPANT	\N	PRESENT	0
439597	426318	11012A	PARTICIPANT	\N	PRESENT	0
439598	436982	99004R	PARTICIPANT	\N	PRESENT	0
439600	426318	11066Q	PARTICIPANT	\N	PRESENT	0
439601	426318	11031D	PARTICIPANT	\N	PRESENT	0
439604	436982	19569H	PARTICIPANT	\N	PRESENT	0
439605	436982	19683J	PARTICIPANT	\N	PRESENT	0
439582	436982	19681G	PARTICIPANT	\N	EXCUSE	0
439583	426318	01025N	PARTICIPANT	\N	PRESENT	0
439584	426318	19593H	PARTICIPANT	\N	PRESENT	0
439585	426318	19695N	PARTICIPANT	\N	PRESENT	0
439586	426318	14157T	PARTICIPANT	\N	PRESENT	0
439587	426318	19399H	PARTICIPANT	\N	PRESENT	0
439588	426318	19794Q	PARTICIPANT	\N	PRESENT	0
439589	426318	19515S	PARTICIPANT	\N	PRESENT	0
439590	426318	97011G	PARTICIPANT	\N	PRESENT	0
439591	426318	98050T	PARTICIPANT	\N	PRESENT	0
439592	426318	04042C	PARTICIPANT	\N	PRESENT	0
439593	439507	11048N	PARTICIPANT	\N	PRESENT	0
439594	439507	19251M	PARTICIPANT	\N	PRESENT	0
439596	426318	04040A	PARTICIPANT	\N	PRESENT	0
439608	426318	95063L	PARTICIPANT	\N	PRESENT	0
439609	426318	14093U	PARTICIPANT	\N	PRESENT	0
439613	426318	04085P	PARTICIPANT	\N	PRESENT	0
439689	426319	19717B	PARTICIPANT	\N	PRESENT	0
439690	426319	19713W	PARTICIPANT	\N	PRESENT	0
439692	426319	19413M	PARTICIPANT	\N	PRESENT	0
439693	426319	95030B	PARTICIPANT	\N	PRESENT	0
439695	426319	19301E	PARTICIPANT	\N	PRESENT	0
439696	426319	14207L	PARTICIPANT	\N	PRESENT	0
439697	426319	19719D	PARTICIPANT	\N	PRESENT	0
439698	426319	19563B	PARTICIPANT	\N	PRESENT	0
439699	426319	01025N	PARTICIPANT	\N	PRESENT	0
439700	426319	18083K	PARTICIPANT	\N	PRESENT	0
439701	426319	14217N	PARTICIPANT	\N	PRESENT	0
439702	426319	99004R	PARTICIPANT	\N	PRESENT	0
439703	426319	19695N	PARTICIPANT	\N	PRESENT	0
439704	426319	19511N	PARTICIPANT	\N	PRESENT	0
439705	426319	11099A	PARTICIPANT	\N	PRESENT	0
439706	426319	14069U	PARTICIPANT	\N	PRESENT	0
439707	426319	11077T	PARTICIPANT	\N	PRESENT	0
439708	426319	19333N	PARTICIPANT	\N	PRESENT	0
439709	426319	19794Q	PARTICIPANT	\N	PRESENT	0
439710	426319	19737F	PARTICIPANT	\N	PRESENT	0
439711	426319	14030Q	PARTICIPANT	\N	PRESENT	0
439712	426319	19657G	PARTICIPANT	\N	PRESENT	0
439715	426319	19269X	PARTICIPANT	\N	PRESENT	0
439717	426319	98050T	PARTICIPANT	\N	PRESENT	0
439718	426319	19731Y	PARTICIPANT	\N	PRESENT	0
439739	426319	14034U	PARTICIPANT	\N	PRESENT	0
439767	426320	14207L	PARTICIPANT	\N	PRESENT	0
439768	426320	14034U	PARTICIPANT	\N	PRESENT	0
439683	426319	04086Q	PARTICIPANT	\N	PRESENT	0
439684	426319	08031R	PARTICIPANT	\N	PRESENT	0
439769	426320	19719D	PARTICIPANT	\N	PRESENT	0
439770	426320	19269X	PARTICIPANT	\N	PRESENT	0
439771	426320	19695N	PARTICIPANT	\N	PRESENT	0
439772	426320	19563B	PARTICIPANT	\N	PRESENT	0
439773	426320	95030B	PARTICIPANT	\N	PRESENT	0
439774	426320	19413M	PARTICIPANT	\N	PRESENT	0
439775	426320	19511N	PARTICIPANT	\N	PRESENT	0
439797	426320	07004J	PARTICIPANT	\N	PRESENT	0
439777	426320	01025N	PARTICIPANT	\N	PRESENT	0
439778	426320	19333N	PARTICIPANT	\N	PRESENT	0
439779	426320	19717B	PARTICIPANT	\N	PRESENT	0
439780	426320	11099A	PARTICIPANT	\N	PRESENT	0
439781	426320	19737F	PARTICIPANT	\N	PRESENT	0
439782	426320	14030Q	PARTICIPANT	\N	PRESENT	0
439783	426320	19794Q	PARTICIPANT	\N	PRESENT	0
439784	426320	19731Y	PARTICIPANT	\N	PRESENT	0
439785	426320	11077T	PARTICIPANT	\N	PRESENT	0
439786	426320	08031R	PARTICIPANT	\N	PRESENT	0
439796	426320	19762G	PARTICIPANT	\N	PRESENT	0
439799	426320	14157T	PARTICIPANT	\N	PRESENT	0
440083	440082	19735D	PARTICIPANT	\N	PRESENT	0
440084	440082	14039A	PARTICIPANT	\N	PRESENT	0
440085	440082	19749K	PARTICIPANT	\N	PRESENT	0
439765	426320	04086Q	PARTICIPANT	\N	PRESENT	0
439766	426320	14026U	PARTICIPANT	\N	PRESENT	0
440086	440082	19399H	PARTICIPANT	\N	PRESENT	0
440087	440082	04018C	PARTICIPANT	\N	PRESENT	0
437625	432678	19551W	PARTICIPANT	\N	EXCUSE	0
437708	432678	19349W	PARTICIPANT	\N	EXCUSE	0
437740	432678	19421M	PARTICIPANT	\N	EXCUSE	0
437748	437745	19447X	PARTICIPANT	\N	PRESENT	0
437749	437745	14147R	PARTICIPANT	\N	PRESENT	0
437468	432678	19667J	PARTICIPANT	\N	EXCUSE	0
437621	432678	08012N	PARTICIPANT	\N	PRESENT	0
437750	437746	19447X	PARTICIPANT	\N	PRESENT	0
437751	437746	14147R	PARTICIPANT	\N	PRESENT	0
437752	437746	11066Q	PARTICIPANT	\N	PRESENT	0
437753	437747	19447X	PARTICIPANT	\N	PRESENT	0
438240	437085	11067R	PARTICIPANT	\N	EXCUSE	0
438241	437085	14195A	PARTICIPANT	\N	EXCUSE	0
439599	439595	14255U	PARTICIPANT	\N	PRESENT	0
439603	439602	04086Q	PARTICIPANT	\N	PRESENT	0
439612	438470	08024S	PARTICIPANT	\N	PRESENT	0
439615	431727	14261S	PARTICIPANT	\N	PRESENT	0
439616	431727	19691J	PARTICIPANT	\N	PRESENT	0
439617	431727	19715Y	PARTICIPANT	\N	PRESENT	0
439618	431727	98005N	PARTICIPANT	\N	EXCUSE	0
439619	431727	14059S	PARTICIPANT	\N	EXCUSE	0
439620	431727	19319Q	PARTICIPANT	\N	PRESENT	0
439621	431727	08019V	PRESIDENT	0	PRESENT	0
439622	431727	18083K	PARTICIPANT	\N	PRESENT	0
439623	431727	19731Y	PARTICIPANT	\N	PRESENT	0
439624	431727	08043V	PARTICIPANT	\N	PRESENT	0
439625	431727	19701S	PARTICIPANT	\N	PRESENT	0
439626	431727	14030Q	PARTICIPANT	\N	PRESENT	0
439627	431727	80013X	PARTICIPANT	\N	PRESENT	0
439685	439342	01060R	PARTICIPANT	\N	PRESENT	0
440458	439891	01043Q	PARTICIPANT	\N	PRESENT	0
440429	439891	19768N	PARTICIPANT	\N	PRESENT	0
440430	439891	19515S	PARTICIPANT	\N	PRESENT	0
440431	439891	19782L	PARTICIPANT	\N	PRESENT	0
440432	439891	14357A	PARTICIPANT	\N	PRESENT	0
440433	439891	19441R	PARTICIPANT	\N	PRESENT	0
440434	439891	08068F	PARTICIPANT	\N	PRESENT	0
440435	439891	04049K	PARTICIPANT	\N	PRESENT	0
440436	439891	19705W	PARTICIPANT	\N	PRESENT	0
440437	439891	08015R	PARTICIPANT	\N	PRESENT	0
440438	439891	14197C	PARTICIPANT	\N	PRESENT	0
440439	439891	19369B	PARTICIPANT	\N	PRESENT	0
440440	439891	19511N	PARTICIPANT	\N	PRESENT	0
440441	439891	14265W	PARTICIPANT	\N	PRESENT	0
440442	439891	14329V	PARTICIPANT	\N	PRESENT	0
440443	439891	14135M	PARTICIPANT	\N	PRESENT	0
440444	439891	14187A	PARTICIPANT	\N	PRESENT	0
440445	439891	11090Q	PRESIDENT	0	PRESENT	0
440446	439891	01025N	PARTICIPANT	\N	PRESENT	0
440447	439891	14205J	PARTICIPANT	\N	PRESENT	0
440448	439891	04089T	PARTICIPANT	\N	PRESENT	0
440449	439891	11101A	PARTICIPANT	\N	PRESENT	0
440450	439891	19507S	PARTICIPANT	\N	PRESENT	0
440451	439891	19747H	PARTICIPANT	\N	PRESENT	0
440452	439891	14207L	PARTICIPANT	\N	PRESENT	0
440453	439891	14257W	PARTICIPANT	\N	PRESENT	0
440454	439891	19467C	PARTICIPANT	\N	EXCUSE	0
440455	439891	14081Q	PARTICIPANT	\N	EXCUSE	0
440456	439891	11081P	PARTICIPANT	\N	EXCUSE	0
440457	439891	19631V	PARTICIPANT	\N	EXCUSE	0
440459	439891	04088S	PARTICIPANT	\N	PRESENT	0
440535	440427	04057K	PARTICIPANT	\N	PRESENT	0
440536	439635	14327T	PARTICIPANT	\N	PRESENT	0
440537	439635	14331P	PARTICIPANT	\N	PRESENT	0
440538	439635	19545Y	PARTICIPANT	\N	PRESENT	0
440539	439635	01057W	PARTICIPANT	\N	PRESENT	0
440540	439635	11053K	PARTICIPANT	\N	PRESENT	0
440541	439635	11074Q	PRESIDENT	0	PRESENT	0
440542	439635	89017R	PARTICIPANT	\N	PRESENT	0
440543	439635	11070L	PARTICIPANT	\N	PRESENT	0
440544	439635	14225N	PARTICIPANT	\N	PRESENT	0
440545	439635	88008L	PARTICIPANT	\N	PRESENT	0
440546	439635	07029T	PARTICIPANT	\N	PRESENT	0
440547	439635	14085U	PARTICIPANT	\N	PRESENT	0
440548	439635	07004J	PARTICIPANT	\N	PRESENT	0
440549	439635	96004D	PARTICIPANT	\N	PRESENT	0
440550	439635	19349W	PARTICIPANT	\N	PRESENT	0
440551	439635	14253S	PARTICIPANT	\N	PRESENT	0
440552	439635	19479G	PARTICIPANT	\N	PRESENT	0
440553	439635	11048N	PARTICIPANT	\N	PRESENT	0
440554	439635	19711U	PARTICIPANT	\N	PRESENT	0
440555	439635	19651A	PARTICIPANT	\N	PRESENT	0
440556	439635	08034U	PARTICIPANT	\N	PRESENT	0
440557	439635	08069G	PARTICIPANT	\N	PRESENT	0
440558	439635	19687N	PARTICIPANT	\N	PRESENT	0
440559	439635	08011M	PARTICIPANT	\N	PRESENT	0
440560	439635	14034U	PARTICIPANT	\N	PRESENT	0
440561	439635	14159V	PARTICIPANT	\N	PRESENT	0
440562	439635	14173T	PARTICIPANT	\N	PRESENT	0
440563	439635	11040E	PARTICIPANT	\N	PRESENT	0
440564	439635	04086Q	PARTICIPANT	\N	PRESENT	0
440565	439635	14083S	PARTICIPANT	\N	PRESENT	0
440566	439635	14199E	PARTICIPANT	\N	PRESENT	0
440567	439635	19741B	PARTICIPANT	\N	PRESENT	0
440568	439635	14121F	PARTICIPANT	\N	PRESENT	0
440646	440256	19733B	PARTICIPANT	\N	EXCUSE	0
440706	427774	17779H	PARTICIPANT	\N	PRESENT	0
440684	440653	14331P	PARTICIPANT	\N	PRESENT	0
440685	440653	19479G	PARTICIPANT	\N	PRESENT	0
440686	440653	19647E	PARTICIPANT	\N	PRESENT	0
440687	440653	19711U	PARTICIPANT	\N	PRESENT	0
440688	440653	08034U	PARTICIPANT	\N	PRESENT	0
440689	440653	19651A	PARTICIPANT	\N	PRESENT	0
440690	440653	11053K	PARTICIPANT	\N	PRESENT	0
440691	440653	11074Q	PRESIDENT	0	PRESENT	0
440692	440653	08011M	PARTICIPANT	\N	PRESENT	0
440693	440653	19667J	PARTICIPANT	\N	PRESENT	0
440694	440653	11070L	PARTICIPANT	\N	PRESENT	0
440695	440653	14225N	PARTICIPANT	\N	PRESENT	0
440696	440653	19671E	PARTICIPANT	\N	PRESENT	0
440697	440653	14173T	PARTICIPANT	\N	PRESENT	0
440698	440653	04086Q	PARTICIPANT	\N	PRESENT	0
440699	440653	11040E	PARTICIPANT	\N	PRESENT	0
440700	440653	07029T	PARTICIPANT	\N	PRESENT	0
440701	440653	14085U	PARTICIPANT	\N	PRESENT	0
440702	440653	99004R	PARTICIPANT	\N	PRESENT	0
440703	440653	14121F	PARTICIPANT	\N	PRESENT	0
440704	440653	14083S	PARTICIPANT	\N	PRESENT	0
440705	440653	01057W	PARTICIPANT	\N	PRESENT	0
441237	427777	19651A	PARTICIPANT	\N	PRESENT	0
441238	427777	19794Q	PARTICIPANT	\N	PRESENT	0
441239	427777	01058X	PARTICIPANT	\N	PRESENT	0
441240	427777	97011G	PARTICIPANT	\N	PRESENT	0
441241	427777	11064N	PARTICIPANT	\N	PRESENT	0
441242	439894	11048N	PARTICIPANT	\N	PRESENT	0
441243	439894	14051J	PARTICIPANT	\N	PRESENT	0
441244	439894	08060W	PARTICIPANT	\N	PRESENT	0
441245	439894	95067Q	PARTICIPANT	\N	PRESENT	0
441246	439894	08009T	PRESIDENT	0	PRESENT	0
441247	439894	14033T	PARTICIPANT	\N	PRESENT	0
441248	439894	19826F	PARTICIPANT	\N	PRESENT	0
441249	439894	14026U	PARTICIPANT	\N	PRESENT	0
441250	439894	19758L	PARTICIPANT	\N	PRESENT	0
441251	439894	19413M	PARTICIPANT	\N	EXCUSE	0
441252	439894	19367Y	PARTICIPANT	\N	EXCUSE	0
441253	427777	19647E	PARTICIPANT	\N	PRESENT	0
441254	439606	11067R	PARTICIPANT	\N	PRESENT	0
441255	439606	14065Q	PARTICIPANT	\N	PRESENT	0
441256	439606	04092N	PRESIDENT	0	PRESENT	0
441257	439606	08034U	PARTICIPANT	\N	PRESENT	0
441258	439606	19569H	PARTICIPANT	\N	PRESENT	0
441259	439606	08052W	PARTICIPANT	\N	PRESENT	0
441260	439606	08043V	PARTICIPANT	\N	PRESENT	0
441261	439606	04045F	PARTICIPANT	\N	PRESENT	0
441262	439606	11066Q	PARTICIPANT	\N	PRESENT	0
441263	439606	19447X	PARTICIPANT	\N	PRESENT	0
441264	439606	18083K	PARTICIPANT	\N	PRESENT	0
441265	439606	14239U	PARTICIPANT	\N	PRESENT	0
441266	439606	14042U	PARTICIPANT	\N	PRESENT	0
441267	439606	14213J	PARTICIPANT	\N	PRESENT	0
441268	439606	14215L	PARTICIPANT	\N	PRESENT	0
441269	439606	14217N	PARTICIPANT	\N	PRESENT	0
441270	439606	19683J	PARTICIPANT	\N	PRESENT	0
441271	439606	11072N	PARTICIPANT	\N	PRESENT	0
441272	439606	19681G	PARTICIPANT	\N	EXCUSE	0
441275	427777	19619A	PARTICIPANT	\N	PRESENT	0
441276	439606	19553Y	PARTICIPANT	\N	PRESENT	0
441277	439606	14195A	PARTICIPANT	\N	PRESENT	0
441278	439606	19335Q	PARTICIPANT	\N	PRESENT	0
441279	439894	14053L	PARTICIPANT	\N	PRESENT	0
441280	439894	04070G	PARTICIPANT	\N	PRESENT	0
441282	427777	19253P	PARTICIPANT	\N	PRESENT	0
441283	427777	19687N	PARTICIPANT	\N	PRESENT	0
441284	439606	19415P	PARTICIPANT	\N	PRESENT	0
441285	439606	05008E	PARTICIPANT	\N	PRESENT	0
441286	439606	11031D	PARTICIPANT	\N	PRESENT	0
441287	439606	19575F	PARTICIPANT	\N	PRESENT	0
441289	439606	01048V	PARTICIPANT	\N	EXCUSE	0
441290	427777	14030Q	PARTICIPANT	\N	PRESENT	0
424956	422994	96004D	PARTICIPANT	\N	EXCUSE	0
424957	422994	14219Q	PARTICIPANT	\N	EXCUSE	0
426912	426910	19503N	PARTICIPANT	\N	PRESENT	0
428526	428525	80013X	PARTICIPANT	\N	PRESENT	0
429482	427448	19701S	PARTICIPANT	\N	EXCUSE	0
435081	425305	04057K	PARTICIPANT	\N	PRESENT	0
435082	425305	14227Q	PARTICIPANT	\N	PRESENT	0
435083	425305	14119M	PARTICIPANT	\N	PRESENT	0
435084	425305	08019V	PARTICIPANT	\N	PRESENT	0
435085	425305	11077T	PARTICIPANT	\N	PRESENT	0
435086	425305	19533U	PARTICIPANT	\N	PRESENT	0
435087	425305	14087W	PARTICIPANT	\N	PRESENT	0
435088	425305	11045K	PARTICIPANT	\N	PRESENT	0
435089	425305	11109J	PARTICIPANT	\N	PRESENT	0
435090	425305	17779H	PARTICIPANT	\N	PRESENT	0
435091	425305	07004J	PARTICIPANT	\N	PRESENT	0
435092	425305	19701S	PARTICIPANT	\N	PRESENT	0
435135	425347	01034P	PARTICIPANT	\N	PRESENT	0
435136	425347	11070L	PARTICIPANT	\N	PRESENT	0
435137	425347	19565D	PARTICIPANT	\N	PRESENT	0
435138	425347	11031D	PARTICIPANT	\N	PRESENT	0
435139	425347	17779H	PARTICIPANT	\N	PRESENT	0
435140	425347	11109J	PARTICIPANT	\N	PRESENT	0
435141	425347	14281W	PARTICIPANT	\N	PRESENT	0
435142	425347	08052W	PARTICIPANT	\N	PRESENT	0
435143	425347	11067R	PARTICIPANT	\N	PRESENT	0
435144	425347	19697Q	PARTICIPANT	\N	PRESENT	0
435145	425347	14042U	PARTICIPANT	\N	PRESENT	0
435146	425347	07004J	PARTICIPANT	\N	PRESENT	0
435147	425347	14213J	PARTICIPANT	\N	PRESENT	0
435148	425347	98024R	PARTICIPANT	\N	PRESENT	0
435149	425347	19675J	PARTICIPANT	\N	PRESENT	0
435150	425347	19643A	PARTICIPANT	\N	PRESENT	0
435151	425347	19657G	PARTICIPANT	\N	PRESENT	0
435152	425347	19663E	PARTICIPANT	\N	PRESENT	0
435153	425347	19415P	PARTICIPANT	\N	PRESENT	0
435154	425347	11097X	PARTICIPANT	\N	PRESENT	0
435155	425347	04018C	PARTICIPANT	\N	PRESENT	0
435156	425347	19683J	PARTICIPANT	\N	PRESENT	0
435157	425347	14261S	PARTICIPANT	\N	PRESENT	0
435158	425347	19701S	PARTICIPANT	\N	PRESENT	0
435159	425347	14083S	PARTICIPANT	\N	PRESENT	0
435160	425347	04057K	PARTICIPANT	\N	PRESENT	0
435161	425347	19691J	PARTICIPANT	\N	PRESENT	0
435162	425347	11045K	PARTICIPANT	\N	PRESENT	0
435163	425347	14119M	PARTICIPANT	\N	PRESENT	0
435164	425347	19553Y	PARTICIPANT	\N	PRESENT	0
435165	425347	19671E	PARTICIPANT	\N	PRESENT	0
435166	425347	11077T	PARTICIPANT	\N	PRESENT	0
435167	425347	12016W	PARTICIPANT	\N	PRESENT	0
435168	425347	10006L	PARTICIPANT	\N	PRESENT	0
435169	425347	11085T	PARTICIPANT	\N	PRESENT	0
435170	425347	14087W	PARTICIPANT	\N	PRESENT	0
435171	425347	14217N	PARTICIPANT	\N	PRESENT	0
435172	425347	19762G	PARTICIPANT	\N	PRESENT	0
435173	425347	14071N	PARTICIPANT	\N	PRESENT	0
435174	425347	08019V	PARTICIPANT	\N	PRESENT	0
435175	425347	14227Q	PARTICIPANT	\N	PRESENT	0
435134	425347	04092N	PARTICIPANT	\N	PRESENT	0
435176	425347	19527W	PARTICIPANT	\N	PRESENT	0
435177	425347	14253S	PARTICIPANT	\N	PRESENT	0
439343	439342	05008E	PRESIDENT	0	PRESENT	0
439344	439342	11033F	PARTICIPANT	\N	PRESENT	0
439345	439342	14069U	PARTICIPANT	\N	PRESENT	0
439346	439342	14089Y	PARTICIPANT	\N	PRESENT	0
439347	439342	19629C	PARTICIPANT	\N	PRESENT	0
439348	439342	04038G	PARTICIPANT	\N	PRESENT	0
439349	439342	19253P	PARTICIPANT	\N	PRESENT	0
439350	439342	14259Y	PARTICIPANT	\N	PRESENT	0
439351	439342	04008A	PARTICIPANT	\N	PRESENT	0
439352	439342	01024M	PARTICIPANT	\N	PRESENT	0
439353	439342	14215L	PARTICIPANT	\N	PRESENT	0
439354	439342	19673G	PARTICIPANT	\N	PRESENT	0
439355	439342	08045X	PARTICIPANT	\N	PRESENT	0
439356	439342	08018U	PARTICIPANT	\N	PRESENT	0
439357	439342	14231L	PARTICIPANT	\N	PRESENT	0
439358	439342	19649G	PARTICIPANT	\N	PRESENT	0
439359	439342	19725B	PARTICIPANT	\N	PRESENT	0
439360	439342	14179A	PARTICIPANT	\N	PRESENT	0
439361	439342	19447X	PARTICIPANT	\N	PRESENT	0
439362	439342	14021P	PARTICIPANT	\N	PRESENT	0
439363	439342	19489J	PARTICIPANT	\N	PRESENT	0
439364	439342	11026G	PARTICIPANT	\N	PRESENT	0
439365	439342	19729F	PARTICIPANT	\N	PRESENT	0
439366	439342	19581D	PARTICIPANT	\N	PRESENT	0
439367	439342	14111D	PARTICIPANT	\N	PRESENT	0
439368	439342	14001X	PARTICIPANT	\N	PRESENT	0
439369	439342	11085T	PARTICIPANT	\N	PRESENT	0
439370	439342	14147R	PARTICIPANT	\N	PRESENT	0
439371	439342	95063L	PARTICIPANT	\N	PRESENT	0
439372	439342	19762G	PARTICIPANT	\N	PRESENT	0
439373	439342	01028R	PARTICIPANT	\N	PRESENT	0
439374	439342	19675J	PARTICIPANT	\N	PRESENT	0
439375	439342	04044E	PARTICIPANT	\N	PRESENT	0
439376	439342	14065Q	PARTICIPANT	\N	EXCUSE	0
439377	439342	04047H	PARTICIPANT	\N	EXCUSE	0
439379	439342	11010L	PARTICIPANT	\N	EXCUSE	0
439380	439342	98035U	PARTICIPANT	\N	EXCUSE	0
439910	439909	19683J	PARTICIPANT	\N	PRESENT	0
439911	439909	19447X	PARTICIPANT	\N	PRESENT	0
439912	428941	11031D	PARTICIPANT	\N	PRESENT	0
439913	428941	08043V	PARTICIPANT	\N	PRESENT	0
439915	439914	08043V	PARTICIPANT	\N	PRESENT	0
439916	439914	19683J	PARTICIPANT	\N	PRESENT	0
439932	439930	19503N	PARTICIPANT	\N	PRESENT	0
441274	441273	14089Y	PARTICIPANT	\N	PRESENT	0
441294	441219	19727D	PARTICIPANT	\N	PRESENT	0
441297	441220	19727D	PARTICIPANT	\N	PRESENT	0
441298	441230	19727D	PARTICIPANT	\N	PRESENT	0
441299	441230	17779H	PARTICIPANT	\N	PRESENT	0
441300	441281	19727D	PARTICIPANT	\N	PRESENT	0
441301	441281	17779H	PARTICIPANT	\N	PRESENT	0
441302	441288	19727D	PARTICIPANT	\N	PRESENT	0
441312	441311	11043H	PARTICIPANT	\N	PRESENT	0
441313	441311	14073Q	PARTICIPANT	\N	PRESENT	0
441314	441311	08012N	PARTICIPANT	\N	PRESENT	0
441316	441311	14213J	PARTICIPANT	\N	PRESENT	0
441317	441311	01024M	PARTICIPANT	\N	PRESENT	0
441319	441311	19349W	PARTICIPANT	\N	PRESENT	0
441320	441311	14241N	PARTICIPANT	\N	PRESENT	0
441321	441311	14030Q	PARTICIPANT	\N	PRESENT	0
441322	441311	19399H	PARTICIPANT	\N	PRESENT	0
441323	441311	14061L	PARTICIPANT	\N	PRESENT	0
443749	443748	11053K	PARTICIPANT	\N	PRESENT	0
443750	443748	14159V	PARTICIPANT	\N	PRESENT	0
443751	443748	05012A	PARTICIPANT	\N	PRESENT	0
443753	443752	11053K	PARTICIPANT	\N	PRESENT	0
443754	443752	14159V	PARTICIPANT	\N	PRESENT	0
443755	443752	05012A	PARTICIPANT	\N	PRESENT	0
443757	443756	11053K	PARTICIPANT	\N	PRESENT	0
443758	443756	14159V	PARTICIPANT	\N	PRESENT	0
443759	443756	05012A	PARTICIPANT	\N	PRESENT	0
443827	439641	11027H	PARTICIPANT	\N	PRESENT	0
443829	439641	04070G	PARTICIPANT	\N	PRESENT	0
443830	439641	19685L	PARTICIPANT	\N	PRESENT	0
443831	439641	14331P	PARTICIPANT	\N	PRESENT	0
443832	439641	14187A	PARTICIPANT	\N	PRESENT	0
443833	439641	08060W	PARTICIPANT	\N	PRESENT	0
443834	439641	14213J	PARTICIPANT	\N	PRESENT	0
443835	439641	10006L	PARTICIPANT	\N	PRESENT	0
443836	439641	19812Y	PARTICIPANT	\N	PRESENT	0
443837	439641	19585H	PARTICIPANT	\N	PRESENT	0
443838	439641	19367Y	PARTICIPANT	\N	PRESENT	0
443842	439641	08015R	PARTICIPANT	\N	PRESENT	0
443844	439641	14107H	PARTICIPANT	\N	PRESENT	0
443845	439641	19533U	PARTICIPANT	\N	PRESENT	0
443852	439641	08010L	PARTICIPANT	\N	PRESENT	0
443853	439641	14223L	PARTICIPANT	\N	PRESENT	0
443854	439641	19421M	PARTICIPANT	\N	PRESENT	0
443856	439641	14089Y	PARTICIPANT	\N	PRESENT	0
443857	439641	04043D	PARTICIPANT	\N	PRESENT	0
443858	439641	04044E	PARTICIPANT	\N	PRESENT	0
443859	439641	14205J	PARTICIPANT	\N	PRESENT	0
443860	439641	14028W	PARTICIPANT	\N	PRESENT	0
443861	439641	14053L	PARTICIPANT	\N	PRESENT	0
443863	439641	14071N	PARTICIPANT	\N	PRESENT	0
443864	439641	19527W	PARTICIPANT	\N	PRESENT	0
443865	439641	14033T	PARTICIPANT	\N	PRESENT	0
443867	439641	14103D	PARTICIPANT	\N	PRESENT	0
443868	439641	19553Y	PARTICIPANT	\N	PRESENT	0
443870	439641	19669L	PARTICIPANT	\N	PRESENT	0
443881	439641	19758L	PARTICIPANT	\N	PRESENT	0
447022	445754	98050T	PARTICIPANT	\N	PRESENT	0
447023	445707	08012N	PARTICIPANT	\N	PRESENT	0
447024	445707	14249W	PARTICIPANT	\N	PRESENT	0
447025	445753	98050T	PARTICIPANT	\N	PRESENT	0
447026	445754	14193X	PARTICIPANT	\N	PRESENT	0
447027	445753	14193X	PARTICIPANT	\N	PRESENT	0
447028	446385	19387D	PARTICIPANT	\N	PRESENT	0
447029	446385	05012A	PARTICIPANT	\N	PRESENT	0
447030	446385	11065P	PARTICIPANT	\N	PRESENT	0
447031	446385	14169X	PARTICIPANT	\N	PRESENT	0
447044	447043	19747H	PARTICIPANT	\N	PRESENT	0
447045	447043	19782L	PARTICIPANT	\N	PRESENT	0
447049	447043	14197C	PARTICIPANT	\N	PRESENT	0
447047	447043	14083S	PARTICIPANT	\N	PRESENT	0
447048	447043	04089T	PARTICIPANT	\N	PRESENT	0
447050	447043	14033T	PARTICIPANT	\N	PRESENT	0
447051	447043	19333N	PARTICIPANT	\N	PRESENT	0
447052	447043	04097T	PARTICIPANT	\N	PRESENT	0
447053	447043	11048N	PARTICIPANT	\N	PRESENT	0
447054	447043	14257W	PARTICIPANT	\N	PRESENT	0
447055	447043	14265W	PARTICIPANT	\N	PRESENT	0
447056	447043	19533U	PARTICIPANT	\N	PRESENT	0
447057	447043	04088S	PARTICIPANT	\N	PRESENT	0
447058	447043	19503N	PARTICIPANT	\N	PRESENT	0
447059	447043	19619A	PARTICIPANT	\N	PRESENT	0
447060	447043	14051J	PARTICIPANT	\N	PRESENT	0
447062	447043	95067Q	PARTICIPANT	\N	PRESENT	0
447151	443772	11109J	PARTICIPANT	\N	PRESENT	0
447152	443772	14261S	PARTICIPANT	\N	PRESENT	0
447153	443772	19717B	PARTICIPANT	\N	EXCUSE	0
447154	443772	19631V	PARTICIPANT	\N	PRESENT	0
447155	443772	11033F	PARTICIPANT	\N	EXCUSE	0
447156	443772	96004D	PARTICIPANT	\N	PRESENT	0
447157	443772	14038Y	PARTICIPANT	\N	EXCUSE	0
447158	443772	19295A	PARTICIPANT	\N	EXCUSE	0
447159	443772	14259Y	PARTICIPANT	\N	EXCUSE	0
447160	443772	19659J	PARTICIPANT	\N	EXCUSE	0
447161	443772	19577H	PARTICIPANT	\N	EXCUSE	0
447162	443772	07033P	PARTICIPANT	\N	EXCUSE	0
447163	443772	11010L	PARTICIPANT	\N	EXCUSE	0
447164	443772	14199E	PARTICIPANT	\N	EXCUSE	0
447165	443772	14033T	PARTICIPANT	\N	EXCUSE	0
447166	443772	19691J	PARTICIPANT	\N	EXCUSE	0
447169	443772	19329S	PARTICIPANT	\N	EXCUSE	0
447171	443772	19715Y	PARTICIPANT	\N	EXCUSE	0
447172	443772	14097Y	PARTICIPANT	\N	PRESENT	0
447173	443772	14021P	PARTICIPANT	\N	EXCUSE	0
447174	443772	14039A	PARTICIPANT	\N	EXCUSE	0
447175	443772	19583F	PARTICIPANT	\N	EXCUSE	0
447176	443772	98005N	PARTICIPANT	\N	EXCUSE	0
447177	443772	14277B	PARTICIPANT	\N	EXCUSE	0
447178	443772	19729F	PARTICIPANT	\N	EXCUSE	0
447179	443772	14219Q	PARTICIPANT	\N	EXCUSE	0
447180	443772	14059S	PARTICIPANT	\N	PRESENT	0
447181	443772	12016W	PARTICIPANT	\N	EXCUSE	0
447182	443772	08019V	PRESIDENT	0	PRESENT	0
447183	443772	19657G	PARTICIPANT	\N	EXCUSE	0
447184	443772	11072N	PARTICIPANT	\N	EXCUSE	0
447185	443772	08073C	PARTICIPANT	\N	PRESENT	0
447186	443772	19319Q	PARTICIPANT	\N	EXCUSE	0
447187	443772	04043D	PARTICIPANT	\N	EXCUSE	0
447188	443772	14135M	PARTICIPANT	\N	EXCUSE	0
447189	443772	14331P	PARTICIPANT	\N	EXCUSE	0
447190	443772	14225N	PARTICIPANT	\N	EXCUSE	0
447191	443772	14157T	PARTICIPANT	\N	EXCUSE	0
447192	443772	19301E	PARTICIPANT	\N	PRESENT	0
447193	443772	14275Y	PARTICIPANT	\N	PRESENT	0
447194	443772	11054L	PARTICIPANT	\N	PRESENT	0
447195	443772	19703U	PARTICIPANT	\N	EXCUSE	0
447202	445994	05008E	PRESIDENT	0	PRESENT	0
447203	445994	19543W	PARTICIPANT	\N	PRESENT	0
447204	445994	11033F	PARTICIPANT	\N	PRESENT	0
447205	445994	14065Q	PARTICIPANT	\N	PRESENT	0
447206	445994	14069U	PARTICIPANT	\N	PRESENT	0
447207	445994	14089Y	PARTICIPANT	\N	PRESENT	0
447208	445994	14053L	PARTICIPANT	\N	PRESENT	0
447209	445994	04047H	PARTICIPANT	\N	PRESENT	0
447210	445994	19629C	PARTICIPANT	\N	PRESENT	0
447211	445994	04038G	PARTICIPANT	\N	PRESENT	0
446792	444386	14217N	PARTICIPANT	\N	PRESENT	0
446793	444386	19335Q	PARTICIPANT	\N	PRESENT	0
447021	446385	04069P	PARTICIPANT	\N	PRESENT	0
447212	445994	19253P	PARTICIPANT	\N	PRESENT	0
447213	445994	14259Y	PARTICIPANT	\N	PRESENT	0
447214	445994	04008A	PARTICIPANT	\N	PRESENT	0
447215	445994	19719D	PARTICIPANT	\N	PRESENT	0
447216	445994	01024M	PARTICIPANT	\N	PRESENT	0
447217	445994	14215L	PARTICIPANT	\N	PRESENT	0
447218	445994	14151M	PARTICIPANT	\N	PRESENT	0
447219	445994	19673G	PARTICIPANT	\N	PRESENT	0
447220	445994	08045X	PARTICIPANT	\N	EXCUSE	0
447221	445994	08018U	PARTICIPANT	\N	PRESENT	0
447222	445994	14231L	PARTICIPANT	\N	PRESENT	0
447223	445994	11049P	PARTICIPANT	\N	PRESENT	0
447224	445994	19725B	PARTICIPANT	\N	PRESENT	0
447225	445994	14179A	PARTICIPANT	\N	PRESENT	0
447226	445994	08044W	PARTICIPANT	\N	PRESENT	0
447227	445994	19447X	PARTICIPANT	\N	PRESENT	0
447228	445994	14021P	PARTICIPANT	\N	PRESENT	0
447229	445994	19489J	PARTICIPANT	\N	PRESENT	0
447230	445994	11026G	PARTICIPANT	\N	PRESENT	0
447231	445994	19729F	PARTICIPANT	\N	PRESENT	0
447232	445994	19581D	PARTICIPANT	\N	PRESENT	0
447233	445994	14111D	PARTICIPANT	\N	PRESENT	0
447234	445994	14001X	PARTICIPANT	\N	PRESENT	0
447235	445994	11085T	PARTICIPANT	\N	PRESENT	0
447236	445994	01060R	PARTICIPANT	\N	PRESENT	0
447237	445994	14147R	PARTICIPANT	\N	PRESENT	0
447238	445994	11072N	PARTICIPANT	\N	PRESENT	0
447239	445994	10015M	PARTICIPANT	\N	PRESENT	0
447240	445994	95063L	PARTICIPANT	\N	PRESENT	0
447241	445994	19762G	PARTICIPANT	\N	PRESENT	0
447242	445994	01028R	PARTICIPANT	\N	PRESENT	0
447243	445994	98035U	PARTICIPANT	\N	PRESENT	0
447244	445994	14275Y	PARTICIPANT	\N	PRESENT	0
447245	445994	19675J	PARTICIPANT	\N	PRESENT	0
447246	445994	19585H	PARTICIPANT	\N	PRESENT	0
447486	445169	96004D	PRESIDENT	0	PRESENT	0
447488	445169	14089Y	PARTICIPANT	\N	PRESENT	0
447490	445169	08014Q	PARTICIPANT	\N	PRESENT	0
447496	445169	14079W	PARTICIPANT	\N	PRESENT	0
447498	445169	11083R	PARTICIPANT	\N	PRESENT	0
447499	445169	14026U	PARTICIPANT	\N	PRESENT	0
447501	445169	19553Y	PARTICIPANT	\N	PRESENT	0
447506	445169	19725B	PARTICIPANT	\N	PRESENT	0
447508	445169	95037J	PARTICIPANT	\N	PRESENT	0
447510	445169	04097T	PARTICIPANT	\N	PRESENT	0
447512	445169	14097Y	PARTICIPANT	\N	PRESENT	0
447517	445169	14073Q	PARTICIPANT	\N	PRESENT	0
447519	445169	14001X	PARTICIPANT	\N	PRESENT	0
447521	445169	04057K	PARTICIPANT	\N	PRESENT	0
447526	445169	14237S	PARTICIPANT	\N	PRESENT	0
447527	445169	14331P	PARTICIPANT	\N	PRESENT	0
447528	445169	98035U	PARTICIPANT	\N	PRESENT	0
447531	445169	11026G	PARTICIPANT	\N	PRESENT	0
447543	445169	08018U	PARTICIPANT	\N	EXCUSE	0
447578	441793	11048N	PARTICIPANT	\N	EXCUSE	0
447877	441793	08010L	PARTICIPANT	\N	EXCUSE	0
447879	441793	14103D	PARTICIPANT	\N	EXCUSE	0
448018	448017	04070G	PARTICIPANT	\N	PRESENT	0
448019	448017	11043H	PARTICIPANT	\N	PRESENT	0
448020	448017	14105F	PARTICIPANT	\N	PRESENT	0
448021	448017	14073Q	PARTICIPANT	\N	PRESENT	0
448022	448017	19711U	PARTICIPANT	\N	PRESENT	0
448023	448017	08012N	PARTICIPANT	\N	PRESENT	0
448024	448017	19631V	PARTICIPANT	\N	PRESENT	0
448025	448017	14030Q	PARTICIPANT	\N	PRESENT	0
448026	448017	14231L	PARTICIPANT	\N	PRESENT	0
448027	448017	19725B	PARTICIPANT	\N	PRESENT	0
448029	448017	14061L	PARTICIPANT	\N	PRESENT	0
448030	448017	19699S	PARTICIPANT	\N	PRESENT	0
448031	448017	19758L	PARTICIPANT	\N	PRESENT	0
448035	447581	14249W	PARTICIPANT	\N	EXCUSE	0
448046	448045	08015R	PARTICIPANT	\N	PRESENT	0
448047	448045	14197C	PARTICIPANT	\N	PRESENT	0
448048	448045	08056B	PARTICIPANT	\N	PRESENT	0
448049	448045	04049K	PARTICIPANT	\N	PRESENT	0
448051	448050	08015R	PARTICIPANT	\N	PRESENT	0
448052	448050	14197C	PARTICIPANT	\N	PRESENT	0
448053	448050	04049K	PARTICIPANT	\N	PRESENT	0
448054	448050	08056B	PARTICIPANT	\N	PRESENT	0
448271	448270	14051J	PARTICIPANT	\N	PRESENT	0
448272	448270	08009T	PRESIDENT	0	PRESENT	0
448273	448270	19413M	PARTICIPANT	\N	PRESENT	0
448274	448270	19581D	PARTICIPANT	\N	PRESENT	0
448275	448270	08060W	PARTICIPANT	\N	EXCUSE	0
448278	448270	14079W	PARTICIPANT	\N	PRESENT	0
448284	448283	19549D	PARTICIPANT	\N	PRESENT	0
425152	425150	14215L	PARTICIPANT	\N	PRESENT	0
425187	416304	04059M	PARTICIPANT	\N	PRESENT	0
425214	425006	14053L	PARTICIPANT	\N	PRESENT	0
425215	425006	95067Q	PARTICIPANT	\N	PRESENT	0
425216	425006	19826F	PARTICIPANT	\N	PRESENT	0
425217	425006	14033T	PARTICIPANT	\N	PRESENT	0
425218	425006	14093U	PARTICIPANT	\N	PRESENT	0
425219	425006	19733B	PARTICIPANT	\N	PRESENT	0
425220	425006	19367Y	PARTICIPANT	\N	PRESENT	0
425221	425006	04070G	PARTICIPANT	\N	EXCUSE	0
425222	425006	14051J	PARTICIPANT	\N	EXCUSE	0
425223	425006	08024S	PARTICIPANT	\N	EXCUSE	0
425224	425006	11065P	PARTICIPANT	\N	EXCUSE	0
425233	416304	19621T	PARTICIPANT	\N	PRESENT	0
425234	416304	04085P	PARTICIPANT	\N	PRESENT	0
425238	416304	14083S	PARTICIPANT	\N	PRESENT	0
425239	416304	14105F	PARTICIPANT	\N	PRESENT	0
425240	416304	19611R	PARTICIPANT	\N	PRESENT	0
425246	416304	19415P	PARTICIPANT	\N	PRESENT	0
425253	416304	01062T	PARTICIPANT	\N	PRESENT	0
425254	416304	19760E	PARTICIPANT	\N	PRESENT	0
425255	416304	14199E	PARTICIPANT	\N	PRESENT	0
425256	416304	04034C	PARTICIPANT	\N	PRESENT	0
425258	425257	14205J	PARTICIPANT	\N	PRESENT	0
425259	425257	14169X	PARTICIPANT	\N	PRESENT	0
425260	425257	14033T	PARTICIPANT	\N	PRESENT	0
425261	425257	19563B	PARTICIPANT	\N	PRESENT	0
425262	425257	14265W	PARTICIPANT	\N	PRESENT	0
425263	425257	04088S	PARTICIPANT	\N	PRESENT	0
425264	425257	19347U	PARTICIPANT	\N	PRESENT	0
425270	416304	19719D	PARTICIPANT	\N	PRESENT	0
425271	416304	19768N	PARTICIPANT	\N	PRESENT	0
425282	416304	19383Y	PARTICIPANT	\N	PRESENT	0
425288	416304	19691J	PARTICIPANT	\N	PRESENT	0
425310	416304	14107H	PARTICIPANT	\N	PRESENT	0
425313	416304	19721W	PARTICIPANT	\N	PRESENT	0
425314	416304	14121F	PARTICIPANT	\N	PRESENT	0
425354	425099	14327T	PARTICIPANT	\N	PRESENT	0
425355	425099	04071H	PARTICIPANT	\N	PRESENT	0
425356	425099	19711U	PARTICIPANT	\N	PRESENT	0
425357	425099	08011M	PARTICIPANT	\N	PRESENT	0
425358	425099	04044E	PARTICIPANT	\N	PRESENT	0
425359	425099	11074Q	PRESIDENT	0	PRESENT	0
425360	425099	11066Q	PARTICIPANT	\N	PRESENT	0
425361	425099	14034U	PARTICIPANT	\N	PRESENT	0
425362	425099	19671E	PARTICIPANT	\N	PRESENT	0
425363	425099	14173T	PARTICIPANT	\N	PRESENT	0
425364	425099	04086Q	PARTICIPANT	\N	PRESENT	0
425365	425099	07029T	PARTICIPANT	\N	PRESENT	0
425366	425099	96004D	PARTICIPANT	\N	PRESENT	0
425367	425099	08010L	PARTICIPANT	\N	PRESENT	0
425368	425099	99004R	PARTICIPANT	\N	PRESENT	0
425369	425099	08047A	PARTICIPANT	\N	PRESENT	0
425370	423923	19768N	PARTICIPANT	\N	PRESENT	0
425371	423923	19515S	PARTICIPANT	\N	PRESENT	0
425372	423923	14357A	PARTICIPANT	\N	PRESENT	0
425373	423923	19441R	PARTICIPANT	\N	PRESENT	0
425374	423923	19413M	PARTICIPANT	\N	PRESENT	0
425375	423923	14081Q	PARTICIPANT	\N	PRESENT	0
425376	423923	80013X	PARTICIPANT	\N	PRESENT	0
425377	423923	19631V	PARTICIPANT	\N	PRESENT	0
425378	423923	08068F	PARTICIPANT	\N	PRESENT	0
425379	423923	19705W	PARTICIPANT	\N	PRESENT	0
425380	423923	08015R	PARTICIPANT	\N	PRESENT	0
425381	423923	08019V	PARTICIPANT	\N	PRESENT	0
425382	423923	14197C	PARTICIPANT	\N	PRESENT	0
425383	423923	19369B	PARTICIPANT	\N	PRESENT	0
425384	423923	19511N	PARTICIPANT	\N	PRESENT	0
425385	423923	08028W	PARTICIPANT	\N	PRESENT	0
425386	423923	19563B	PARTICIPANT	\N	PRESENT	0
425387	423923	14265W	PARTICIPANT	\N	PRESENT	0
425388	423923	14329V	PARTICIPANT	\N	PRESENT	0
425389	423923	19467C	PARTICIPANT	\N	PRESENT	0
425390	423923	14187A	PARTICIPANT	\N	PRESENT	0
425391	423923	08062Y	PARTICIPANT	\N	PRESENT	0
425392	423923	14033T	PARTICIPANT	\N	PRESENT	0
425393	423923	11090Q	PRESIDENT	0	PRESENT	0
425394	423923	19269X	PARTICIPANT	\N	PRESENT	0
425395	423923	14205J	PARTICIPANT	\N	PRESENT	0
425396	423923	04088S	PARTICIPANT	\N	PRESENT	0
425397	423923	11056N	PARTICIPANT	\N	PRESENT	0
425398	423923	19507S	PARTICIPANT	\N	PRESENT	0
425399	423923	11101A	PARTICIPANT	\N	PRESENT	0
425400	423923	19747H	PARTICIPANT	\N	PRESENT	0
425401	423923	14257W	PARTICIPANT	\N	PRESENT	0
425402	423923	19812Y	PARTICIPANT	\N	EXCUSE	0
425403	423923	11081P	PARTICIPANT	\N	EXCUSE	0
425404	423923	17589D	PARTICIPANT	\N	EXCUSE	0
425405	425099	19349W	PARTICIPANT	\N	PRESENT	0
425406	425099	19531S	PARTICIPANT	\N	PRESENT	0
425407	425099	12016W	PARTICIPANT	\N	PRESENT	0
425408	425099	14085U	PARTICIPANT	\N	PRESENT	0
425409	425099	14225N	PARTICIPANT	\N	PRESENT	0
425410	425099	19647E	PARTICIPANT	\N	PRESENT	0
425411	425099	01048V	PARTICIPANT	\N	PRESENT	0
425412	425099	19479G	PARTICIPANT	\N	PRESENT	0
425413	425099	14121F	PARTICIPANT	\N	PRESENT	0
425414	423923	14135M	PARTICIPANT	\N	PRESENT	0
425415	423923	08038Y	PARTICIPANT	\N	PRESENT	0
425416	423923	04089T	PARTICIPANT	\N	PRESENT	0
425417	423923	14115H	PARTICIPANT	\N	PRESENT	0
425418	425099	19741B	PARTICIPANT	\N	PRESENT	0
425419	425099	08034U	PARTICIPANT	\N	PRESENT	0
425430	425099	14199E	PARTICIPANT	\N	PRESENT	0
425433	425099	01057W	PARTICIPANT	\N	PRESENT	0
425465	423852	19697Q	PARTICIPANT	\N	PRESENT	0
425466	423852	11067R	PARTICIPANT	\N	PRESENT	0
425467	423852	19565D	PARTICIPANT	\N	PRESENT	0
425468	423852	19569H	PARTICIPANT	\N	PRESENT	0
425469	423852	19798U	PARTICIPANT	\N	PRESENT	0
425470	423852	11097X	PARTICIPANT	\N	PRESENT	0
425471	423852	19415P	PARTICIPANT	\N	PRESENT	0
425472	423852	04045F	PARTICIPANT	\N	PRESENT	0
425473	423852	14223L	PARTICIPANT	\N	PRESENT	0
425474	423852	14026U	PARTICIPANT	\N	PRESENT	0
425475	423852	14227Q	PARTICIPANT	\N	PRESENT	0
425476	423852	17779H	PARTICIPANT	\N	PRESENT	0
425477	423852	14239U	PARTICIPANT	\N	PRESENT	0
425478	423852	19703U	PARTICIPANT	\N	PRESENT	0
425479	423852	11031D	PARTICIPANT	\N	PRESENT	0
425480	423852	19553Y	PARTICIPANT	\N	PRESENT	0
425481	423852	14281W	PARTICIPANT	\N	PRESENT	0
425482	423852	14087W	PARTICIPANT	\N	PRESENT	0
425483	423852	19679N	PARTICIPANT	\N	PRESENT	0
425484	423852	14042U	PARTICIPANT	\N	PRESENT	0
425486	423852	14195A	PARTICIPANT	\N	PRESENT	0
425487	423852	19575F	PARTICIPANT	\N	PRESENT	0
425488	423852	14213J	PARTICIPANT	\N	PRESENT	0
425489	423852	14217N	PARTICIPANT	\N	PRESENT	0
425490	423852	19683J	PARTICIPANT	\N	PRESENT	0
425491	423852	10006L	PARTICIPANT	\N	PRESENT	0
425492	423852	19521Q	PARTICIPANT	\N	PRESENT	0
425493	423852	98024R	PARTICIPANT	\N	PRESENT	0
425494	423852	01034P	PARTICIPANT	\N	PRESENT	0
425495	423852	04092N	PRESIDENT	0	PRESENT	0
425496	423852	11045K	PARTICIPANT	\N	PRESENT	0
425497	423852	08052W	PARTICIPANT	\N	PRESENT	0
425498	423852	19663E	PARTICIPANT	\N	PRESENT	0
425499	423852	19301E	PARTICIPANT	\N	PRESENT	0
425500	423852	19715Y	PARTICIPANT	\N	PRESENT	0
425501	423852	19691J	PARTICIPANT	\N	PRESENT	0
425502	423852	19717B	PARTICIPANT	\N	PRESENT	0
425503	423852	19723Y	PARTICIPANT	\N	PRESENT	0
425504	423852	19727D	PARTICIPANT	\N	PRESENT	0
425505	423852	14119M	PARTICIPANT	\N	PRESENT	0
425506	423852	11103C	PARTICIPANT	\N	PRESENT	0
425507	423852	19657G	PARTICIPANT	\N	PRESENT	0
425508	423852	14071N	PARTICIPANT	\N	PRESENT	0
425509	423852	19577H	PARTICIPANT	\N	PRESENT	0
425510	423852	08041T	PARTICIPANT	\N	EXCUSE	0
425513	416305	87003B	PARTICIPANT	\N	PRESENT	0
425514	416305	14119M	PARTICIPANT	\N	PRESENT	0
425515	416305	19415P	PARTICIPANT	\N	PRESENT	0
425516	416305	98024R	PARTICIPANT	\N	PRESENT	0
425517	416305	14071N	PARTICIPANT	\N	PRESENT	0
425518	416305	19683J	PARTICIPANT	\N	PRESENT	0
425519	416305	14281W	PARTICIPANT	\N	PRESENT	0
425520	416305	04033B	PARTICIPANT	\N	PRESENT	0
425521	416305	14227Q	PARTICIPANT	\N	PRESENT	0
425523	416305	17779H	PARTICIPANT	\N	PRESENT	0
425524	416305	11103C	PARTICIPANT	\N	PRESENT	0
425525	416305	11031D	PARTICIPANT	\N	PRESENT	0
425526	416305	19715Y	PARTICIPANT	\N	PRESENT	0
425527	416305	97011G	PARTICIPANT	\N	PRESENT	0
425528	416305	14061L	PARTICIPANT	\N	PRESENT	0
425529	416305	19301E	PARTICIPANT	\N	PRESENT	0
425530	416305	08052W	PARTICIPANT	\N	PRESENT	0
425531	416305	19637C	PARTICIPANT	\N	PRESENT	0
425532	416305	19651A	PARTICIPANT	\N	PRESENT	0
440509	440508	14133K	PARTICIPANT	\N	PRESENT	0
440510	440508	04040A	PARTICIPANT	\N	PRESENT	0
440511	440508	14105F	PARTICIPANT	\N	PRESENT	0
440512	440508	04042C	PARTICIPANT	\N	PRESENT	0
440513	440508	14079W	PARTICIPANT	\N	PRESENT	0
440514	440508	95030B	PARTICIPANT	\N	PRESENT	0
440515	440508	95037J	PARTICIPANT	\N	PRESENT	0
440516	440508	12041X	PARTICIPANT	\N	PRESENT	0
440517	440508	16685X	PARTICIPANT	\N	PRESENT	0
440518	440508	14028W	PARTICIPANT	\N	PRESENT	0
440519	440508	14193X	PARTICIPANT	\N	PRESENT	0
440520	440508	19319Q	PARTICIPANT	\N	PRESENT	0
440521	440508	98050T	PARTICIPANT	\N	PRESENT	0
440522	440508	19443T	PARTICIPANT	\N	PRESENT	0
440523	440508	11054L	PARTICIPANT	\N	PRESENT	0
440524	440508	01058X	PARTICIPANT	\N	PRESENT	0
440525	440508	01062T	PARTICIPANT	\N	PRESENT	0
440529	440508	14051J	PARTICIPANT	\N	PRESENT	0
440527	440508	95067Q	PARTICIPANT	\N	PRESENT	0
440528	440508	04034C	PARTICIPANT	\N	PRESENT	0
440569	438239	11045K	PARTICIPANT	\N	EXCUSE	0
441291	427777	19565D	PARTICIPANT	\N	PRESENT	0
441292	427777	98050T	PARTICIPANT	\N	PRESENT	0
441293	427777	14249W	PARTICIPANT	\N	PRESENT	0
441304	427777	14085U	PARTICIPANT	\N	PRESENT	0
441296	427777	96004D	PARTICIPANT	\N	PRESENT	0
441303	427777	14133K	PARTICIPANT	\N	PRESENT	0
441305	427777	14031R	PARTICIPANT	\N	PRESENT	0
441306	427777	19798U	PARTICIPANT	\N	PRESENT	0
441307	427777	19671E	PARTICIPANT	\N	PRESENT	0
441308	427777	04086Q	PARTICIPANT	\N	PRESENT	0
441309	427777	99004R	PARTICIPANT	\N	PRESENT	0
441315	427777	14034U	PARTICIPANT	\N	PRESENT	0
441318	427777	11045K	PARTICIPANT	\N	PRESENT	0
441324	427777	19399H	PARTICIPANT	\N	PRESENT	0
441325	427777	04088S	PARTICIPANT	\N	PRESENT	0
441326	427777	19387D	PARTICIPANT	\N	PRESENT	0
441327	427777	19479G	PARTICIPANT	\N	PRESENT	0
441328	427777	08068F	PARTICIPANT	\N	PRESENT	0
441329	427777	19691J	PARTICIPANT	\N	PRESENT	0
441330	427777	14231L	PARTICIPANT	\N	PRESENT	0
441331	427777	19441R	PARTICIPANT	\N	PRESENT	0
441374	427778	05008E	PARTICIPANT	\N	PRESENT	0
441375	427778	11031D	PARTICIPANT	\N	PRESENT	0
441376	427778	19565D	PARTICIPANT	\N	PRESENT	0
441377	427778	08068F	PARTICIPANT	\N	PRESENT	0
441378	427778	11045K	PARTICIPANT	\N	PRESENT	0
441379	427778	08017T	PARTICIPANT	\N	PRESENT	0
441380	427778	14097Y	PARTICIPANT	\N	PRESENT	0
441381	427778	14111D	PARTICIPANT	\N	PRESENT	0
441382	427778	19387D	PARTICIPANT	\N	PRESENT	0
441383	427778	14201E	PARTICIPANT	\N	PRESENT	0
441384	427778	19629C	PARTICIPANT	\N	PRESENT	0
441385	427778	14121F	PARTICIPANT	\N	PRESENT	0
441386	427778	19737F	PARTICIPANT	\N	PRESENT	0
441387	427778	19479G	PARTICIPANT	\N	PRESENT	0
441388	427778	19691J	PARTICIPANT	\N	PRESENT	0
441389	427778	14030Q	PARTICIPANT	\N	PRESENT	0
441390	427778	14231L	PARTICIPANT	\N	PRESENT	0
441391	427778	08024S	PARTICIPANT	\N	PRESENT	0
441392	427778	07029T	PARTICIPANT	\N	PRESENT	0
441393	427778	14033T	PARTICIPANT	\N	PRESENT	0
441394	427778	14215L	PARTICIPANT	\N	PRESENT	0
441395	440427	08020N	PARTICIPANT	\N	EXCUSE	0
441396	440427	14201E	PARTICIPANT	\N	EXCUSE	0
441397	427778	14251Q	PARTICIPANT	\N	PRESENT	0
441398	427778	19758L	PARTICIPANT	\N	PRESENT	0
441399	427778	14026U	PARTICIPANT	\N	PRESENT	0
441400	427778	14265W	PARTICIPANT	\N	PRESENT	0
441401	427778	14053L	PARTICIPANT	\N	PRESENT	0
441402	427778	19349W	PARTICIPANT	\N	PRESENT	0
441403	427778	14107H	PARTICIPANT	\N	PRESENT	0
441404	427778	19295A	PARTICIPANT	\N	PRESENT	0
441405	427778	19671E	PARTICIPANT	\N	PRESENT	0
441406	427778	14187A	PARTICIPANT	\N	PRESENT	0
441408	427778	11097X	PARTICIPANT	\N	PRESENT	0
441409	427778	14133K	PARTICIPANT	\N	PRESENT	0
441410	427778	19399H	PARTICIPANT	\N	PRESENT	0
441411	427778	11026G	PARTICIPANT	\N	PRESENT	0
441412	427778	19543W	PARTICIPANT	\N	PRESENT	0
441413	427778	04040A	PARTICIPANT	\N	PRESENT	0
441414	427778	19713W	PARTICIPANT	\N	PRESENT	0
441372	427778	04059M	PARTICIPANT	\N	PRESENT	0
441373	427778	14147R	PARTICIPANT	\N	PRESENT	0
441415	427778	19695N	PARTICIPANT	\N	PRESENT	0
441416	427778	11056N	PARTICIPANT	\N	PRESENT	0
441417	427778	04088S	PARTICIPANT	\N	PRESENT	0
441418	427778	19701S	PARTICIPANT	\N	PRESENT	0
441463	441407	14259Y	PARTICIPANT	\N	PRESENT	0
441464	441407	05008E	PARTICIPANT	\N	PRESENT	0
441465	441407	19695N	PARTICIPANT	\N	PRESENT	0
441466	441407	19489J	PARTICIPANT	\N	PRESENT	0
441467	441407	14111D	PARTICIPANT	\N	PRESENT	0
441468	441407	19543W	PARTICIPANT	\N	PRESENT	0
441469	441407	19387D	PARTICIPANT	\N	PRESENT	0
441470	441407	14107H	PARTICIPANT	\N	PRESENT	0
441471	441407	19629C	PARTICIPANT	\N	PRESENT	0
441472	441407	14121F	PARTICIPANT	\N	PRESENT	0
441473	441407	08024S	PARTICIPANT	\N	PRESENT	0
441474	441407	19349W	PARTICIPANT	\N	PRESENT	0
441475	441407	19295A	PARTICIPANT	\N	PRESENT	0
441476	441407	08017T	PARTICIPANT	\N	PRESENT	0
441477	441407	11056N	PARTICIPANT	\N	PRESENT	0
441478	441407	19479G	PARTICIPANT	\N	PRESENT	0
441479	441407	19691J	PARTICIPANT	\N	PRESENT	0
441480	441407	19713W	PARTICIPANT	\N	PRESENT	0
441481	441407	14030Q	PARTICIPANT	\N	PRESENT	0
441482	441407	04040A	PARTICIPANT	\N	PRESENT	0
441483	441407	19737F	PARTICIPANT	\N	PRESENT	0
441484	441407	19565D	PARTICIPANT	\N	PRESENT	0
441485	441407	19758L	PARTICIPANT	\N	PRESENT	0
441486	441407	04088S	PARTICIPANT	\N	PRESENT	0
441487	441407	14133K	PARTICIPANT	\N	PRESENT	0
441488	441407	14033T	PARTICIPANT	\N	PRESENT	0
441489	441407	07029T	PARTICIPANT	\N	PRESENT	0
441490	441407	14026U	PARTICIPANT	\N	PRESENT	0
441491	441407	14265W	PARTICIPANT	\N	PRESENT	0
441492	441407	11097X	PARTICIPANT	\N	PRESENT	0
441493	441407	19701S	PARTICIPANT	\N	PRESENT	0
441494	441407	14053L	PARTICIPANT	\N	PRESENT	0
441495	441407	14187A	PARTICIPANT	\N	PRESENT	0
441496	441407	14038Y	PARTICIPANT	\N	PRESENT	0
441497	441407	11026G	PARTICIPANT	\N	PRESENT	0
441498	441407	11031D	PARTICIPANT	\N	PRESENT	0
441499	441407	18083K	PARTICIPANT	\N	PRESENT	0
441500	441407	19717B	PARTICIPANT	\N	PRESENT	0
441501	441407	19826F	PARTICIPANT	\N	PRESENT	0
441502	441407	19335Q	PARTICIPANT	\N	PRESENT	0
441503	441407	14217N	PARTICIPANT	\N	PRESENT	0
441504	441407	14089Y	PARTICIPANT	\N	PRESENT	0
441461	441407	04059M	PARTICIPANT	\N	PRESENT	0
441462	441407	14231L	PARTICIPANT	\N	PRESENT	0
441505	441407	19553Y	PARTICIPANT	\N	PRESENT	0
441506	441407	19569H	PARTICIPANT	\N	PRESENT	0
441507	441407	14249W	PARTICIPANT	\N	PRESENT	0
441508	441407	11048N	PARTICIPANT	\N	PRESENT	0
441509	441407	14257W	PARTICIPANT	\N	PRESENT	0
441559	427781	14034U	PARTICIPANT	\N	PRESENT	0
441560	427781	12041X	PARTICIPANT	\N	PRESENT	0
441561	427781	96004D	PARTICIPANT	\N	PRESENT	0
441562	427781	08047A	PARTICIPANT	\N	PRESENT	0
441563	427781	11026G	PARTICIPANT	\N	PRESENT	0
441564	427781	11083R	PARTICIPANT	\N	PRESENT	0
441565	427781	14225N	PARTICIPANT	\N	PRESENT	0
441566	427781	04057K	PARTICIPANT	\N	PRESENT	0
441567	427781	19737F	PARTICIPANT	\N	PRESENT	0
441568	427781	19553Y	PARTICIPANT	\N	PRESENT	0
441569	427781	11056N	PARTICIPANT	\N	PRESENT	0
441570	427781	14219Q	PARTICIPANT	\N	PRESENT	0
441571	427781	14026U	PARTICIPANT	\N	PRESENT	0
441572	427781	14265W	PARTICIPANT	\N	PRESENT	0
441573	427781	14089Y	PARTICIPANT	\N	PRESENT	0
441574	427781	01024M	PARTICIPANT	\N	PRESENT	0
441575	427781	07029T	PARTICIPANT	\N	PRESENT	0
441587	438470	14259Y	PARTICIPANT	\N	EXCUSE	0
441594	441593	19599P	PARTICIPANT	\N	PRESENT	0
441595	441593	14157T	PARTICIPANT	\N	PRESENT	0
441596	441593	14093U	PARTICIPANT	\N	PRESENT	0
441597	441593	19820Y	PARTICIPANT	\N	PRESENT	0
441598	441593	14031R	PARTICIPANT	\N	PRESENT	0
441599	441593	19826F	PARTICIPANT	\N	PRESENT	0
441600	441593	14083S	PARTICIPANT	\N	PRESENT	0
441691	441690	14257W	PARTICIPANT	\N	PRESENT	0
441692	441690	19768N	PARTICIPANT	\N	PRESENT	0
441696	441694	14257W	PARTICIPANT	\N	PRESENT	0
441697	441694	19768N	PARTICIPANT	\N	PRESENT	0
441698	441695	14257W	PARTICIPANT	\N	PRESENT	0
441699	441695	11090Q	PARTICIPANT	\N	PRESENT	0
441827	441789	14051J	PARTICIPANT	\N	PRESENT	0
423939	423938	04044E	PARTICIPANT	\N	PRESENT	0
423941	416301	12041X	PARTICIPANT	\N	PRESENT	0
423942	416301	11031D	PARTICIPANT	\N	PRESENT	0
423943	416301	14211G	PARTICIPANT	\N	PRESENT	0
423945	416301	17637T	PARTICIPANT	\N	PRESENT	0
423946	416301	19711U	PARTICIPANT	\N	PRESENT	0
423948	416301	04008A	PARTICIPANT	\N	PRESENT	0
423949	416301	11033F	PARTICIPANT	\N	PRESENT	0
423950	416301	04085P	PARTICIPANT	\N	PRESENT	0
423951	423947	14179A	PARTICIPANT	\N	PRESENT	0
423952	416301	04038G	PARTICIPANT	\N	PRESENT	0
423953	416301	08011M	PARTICIPANT	\N	PRESENT	0
423954	416301	11056N	PARTICIPANT	\N	PRESENT	0
423955	416301	19347U	PARTICIPANT	\N	PRESENT	0
423956	416301	14157T	PARTICIPANT	\N	PRESENT	0
423957	416301	19760E	PARTICIPANT	\N	PRESENT	0
423962	416301	11077T	PARTICIPANT	\N	PRESENT	0
423963	416301	14235Q	PARTICIPANT	\N	PRESENT	0
423964	416301	95063L	PARTICIPANT	\N	PRESENT	0
423965	416301	08061X	PARTICIPANT	\N	PRESENT	0
423966	416301	04045F	PARTICIPANT	\N	PRESENT	0
423967	416301	95037J	PARTICIPANT	\N	PRESENT	0
423968	416301	04034C	PARTICIPANT	\N	PRESENT	0
423969	416301	14239U	PARTICIPANT	\N	PRESENT	0
423970	416301	19637C	PARTICIPANT	\N	PRESENT	0
423971	416301	19349W	PARTICIPANT	\N	PRESENT	0
423972	416301	19697Q	PARTICIPANT	\N	PRESENT	0
423973	416301	19543W	PARTICIPANT	\N	PRESENT	0
423974	416301	08073C	PARTICIPANT	\N	PRESENT	0
423975	416301	08024S	PARTICIPANT	\N	PRESENT	0
423976	416301	19447X	PARTICIPANT	\N	PRESENT	0
423977	416301	19301E	PARTICIPANT	\N	PRESENT	0
423978	416301	19443T	PARTICIPANT	\N	PRESENT	0
423979	416301	11083R	PARTICIPANT	\N	PRESENT	0
423980	416301	19741B	PARTICIPANT	\N	PRESENT	0
423981	416301	98029W	PARTICIPANT	\N	PRESENT	0
423982	416301	19731Y	PARTICIPANT	\N	PRESENT	0
423983	416301	19663E	PARTICIPANT	\N	PRESENT	0
423984	416301	19685L	PARTICIPANT	\N	PRESENT	0
423985	416301	08056B	PARTICIPANT	\N	PRESENT	0
423986	416301	04088S	PARTICIPANT	\N	PRESENT	0
423987	416301	08018U	PARTICIPANT	\N	PRESENT	0
423988	416301	07029T	PARTICIPANT	\N	PRESENT	0
423989	416301	14355X	PARTICIPANT	\N	PRESENT	0
423990	416301	08062Y	PARTICIPANT	\N	PRESENT	0
423991	416301	19651A	PARTICIPANT	\N	PRESENT	0
423992	416301	19705W	PARTICIPANT	\N	PRESENT	0
423993	416301	98050T	PARTICIPANT	\N	PRESENT	0
423994	416301	11012A	PARTICIPANT	\N	PRESENT	0
423995	416301	08031R	PARTICIPANT	\N	PRESENT	0
423996	416301	14059S	PARTICIPANT	\N	PRESENT	0
423997	416301	88008L	PARTICIPANT	\N	PRESENT	0
423998	416301	19758L	PARTICIPANT	\N	PRESENT	0
423999	416301	14038Y	PARTICIPANT	\N	PRESENT	0
424000	416301	19467C	PARTICIPANT	\N	PRESENT	0
424001	416301	19253P	PARTICIPANT	\N	PRESENT	0
424003	416301	19507S	PARTICIPANT	\N	PRESENT	0
424004	416301	08049C	PARTICIPANT	\N	PRESENT	0
424005	416301	19709B	PARTICIPANT	\N	PRESENT	0
424006	416301	19629C	PARTICIPANT	\N	PRESENT	0
424007	416301	14107H	PARTICIPANT	\N	PRESENT	0
424009	416301	19415P	PARTICIPANT	\N	PRESENT	0
424010	416301	14201E	PARTICIPANT	\N	PRESENT	0
424011	416301	19719D	PARTICIPANT	\N	PRESENT	0
424012	416301	08015R	PARTICIPANT	\N	PRESENT	0
424013	416301	19387D	PARTICIPANT	\N	PRESENT	0
424014	416301	14241N	PARTICIPANT	\N	PRESENT	0
424015	416301	14033T	PARTICIPANT	\N	PRESENT	0
424017	416301	98022P	PARTICIPANT	\N	PRESENT	0
424018	416301	14135M	PARTICIPANT	\N	PRESENT	0
424019	416301	19269X	PARTICIPANT	\N	PRESENT	0
424021	416301	14041T	PARTICIPANT	\N	PRESENT	0
424022	416301	19399H	PARTICIPANT	\N	PRESENT	0
424023	416301	19693L	PARTICIPANT	\N	PRESENT	0
424024	416301	14207L	PARTICIPANT	\N	PRESENT	0
424025	416301	19717B	PARTICIPANT	\N	PRESENT	0
424027	416301	14265W	PARTICIPANT	\N	PRESENT	0
424028	416301	14213J	PARTICIPANT	\N	PRESENT	0
424029	416301	19591F	PARTICIPANT	\N	PRESENT	0
424030	416301	14329V	PARTICIPANT	\N	PRESENT	0
424031	416301	14357A	PARTICIPANT	\N	PRESENT	0
424032	416301	19675J	PARTICIPANT	\N	PRESENT	0
424033	416301	19383Y	PARTICIPANT	\N	PRESENT	0
424034	416301	19681G	PARTICIPANT	\N	PRESENT	0
424035	416301	19762G	PARTICIPANT	\N	PRESENT	0
424036	416301	14121F	PARTICIPANT	\N	PRESENT	0
424037	416301	19701S	PARTICIPANT	\N	PRESENT	0
424038	416301	19621T	PARTICIPANT	\N	PRESENT	0
424039	416301	19545Y	PARTICIPANT	\N	PRESENT	0
424040	416301	11064N	PARTICIPANT	\N	PRESENT	0
424041	416301	19585H	PARTICIPANT	\N	PRESENT	0
424042	416301	19367Y	PARTICIPANT	\N	PRESENT	0
424043	416301	02002K	PARTICIPANT	\N	PRESENT	0
424044	416301	04057K	PARTICIPANT	\N	PRESENT	0
424045	416301	14251Q	PARTICIPANT	\N	PRESENT	0
424046	416301	14173T	PARTICIPANT	\N	PRESENT	0
424047	416301	14195A	PARTICIPANT	\N	PRESENT	0
424048	416301	19563B	PARTICIPANT	\N	PRESENT	0
424049	416301	14111D	PARTICIPANT	\N	PRESENT	0
424050	416301	08039A	PARTICIPANT	\N	PRESENT	0
424051	416301	19573D	PARTICIPANT	\N	PRESENT	0
424052	416301	19794Q	PARTICIPANT	\N	PRESENT	0
424053	416301	92040Q	PARTICIPANT	\N	PRESENT	0
424054	416301	14119M	PARTICIPANT	\N	PRESENT	0
424055	416301	11049P	PARTICIPANT	\N	PRESENT	0
424056	416301	14115H	PARTICIPANT	\N	PRESENT	0
424057	416301	08047A	PARTICIPANT	\N	PRESENT	0
424058	416301	98035U	PARTICIPANT	\N	PRESENT	0
424059	416301	14159V	PARTICIPANT	\N	PRESENT	0
424060	416301	17583W	PARTICIPANT	\N	PRESENT	0
424061	416301	11027H	PARTICIPANT	\N	PRESENT	0
424062	416301	08048B	PARTICIPANT	\N	PRESENT	0
424063	416301	04059M	PARTICIPANT	\N	PRESENT	0
424064	416301	11074Q	PARTICIPANT	\N	PRESENT	0
424065	416301	19723Y	PARTICIPANT	\N	PRESENT	0
424066	416301	08068F	PARTICIPANT	\N	PRESENT	0
424067	416301	01028R	PARTICIPANT	\N	PRESENT	0
424068	416301	14147R	PARTICIPANT	\N	PRESENT	0
424069	416301	08052W	PARTICIPANT	\N	PRESENT	0
424070	416301	14229S	PARTICIPANT	\N	PRESENT	0
424072	416301	97011G	PARTICIPANT	\N	PRESENT	0
424073	416301	08055A	PARTICIPANT	\N	PRESENT	0
424074	416301	11103C	PARTICIPANT	\N	PRESENT	0
424075	416301	14021P	PARTICIPANT	\N	PRESENT	0
424076	416301	11045K	PARTICIPANT	\N	PRESENT	0
424077	416301	07033P	PARTICIPANT	\N	PRESENT	0
424078	416301	19669L	PARTICIPANT	\N	PRESENT	0
424079	416301	80013X	PARTICIPANT	\N	PRESENT	0
424080	416301	04069P	PARTICIPANT	\N	PRESENT	0
424081	416301	08060W	PARTICIPANT	\N	PRESENT	0
424082	416301	14331P	PARTICIPANT	\N	PRESENT	0
424083	416301	01062T	PARTICIPANT	\N	PRESENT	0
424084	416301	11041F	PARTICIPANT	\N	PRESENT	0
424085	416301	14079W	PARTICIPANT	\N	PRESENT	0
424086	416301	11066Q	PARTICIPANT	\N	PRESENT	0
424088	416301	19527W	PARTICIPANT	\N	PRESENT	0
424089	416301	19671E	PARTICIPANT	\N	PRESENT	0
424090	416301	14081Q	PARTICIPANT	\N	PRESENT	0
424091	416301	19703U	PARTICIPANT	\N	PRESENT	0
424092	416301	19673G	PARTICIPANT	\N	PRESENT	0
424093	416301	11110B	PARTICIPANT	\N	PRESENT	0
424094	416301	14031R	PARTICIPANT	\N	PRESENT	0
424095	416301	19525U	PARTICIPANT	\N	PRESENT	0
424096	416301	19667J	PARTICIPANT	\N	PRESENT	0
424097	416301	08014Q	PARTICIPANT	\N	PRESENT	0
424098	416301	14199E	PARTICIPANT	\N	PRESENT	0
424099	416301	19333N	PARTICIPANT	\N	PRESENT	0
424100	416301	14001X	PARTICIPANT	\N	PRESENT	0
424101	416301	19575F	PARTICIPANT	\N	PRESENT	0
424102	416301	08017T	PARTICIPANT	\N	PRESENT	0
424103	416301	14253S	PARTICIPANT	\N	PRESENT	0
424104	416301	04049K	PARTICIPANT	\N	PRESENT	0
424105	416301	14063N	PARTICIPANT	\N	PRESENT	0
424106	416301	05012A	PARTICIPANT	\N	PRESENT	0
424107	416301	19631V	PARTICIPANT	\N	PRESENT	0
424108	416301	08035V	PARTICIPANT	\N	PRESENT	0
424109	416301	08034U	PARTICIPANT	\N	PRESENT	0
424110	416301	14097Y	PARTICIPANT	\N	PRESENT	0
424111	416301	19725B	PARTICIPANT	\N	PRESENT	0
424112	416301	19533U	PARTICIPANT	\N	PRESENT	0
424113	416301	14257W	PARTICIPANT	\N	PRESENT	0
424114	416301	11067R	PARTICIPANT	\N	PRESENT	0
424115	416301	10006L	PARTICIPANT	\N	PRESENT	0
424116	416301	19798U	PARTICIPANT	\N	PRESENT	0
424117	416301	19489J	PARTICIPANT	\N	PRESENT	0
424118	416301	14193X	PARTICIPANT	\N	PRESENT	0
424119	416301	11026G	PARTICIPANT	\N	PRESENT	0
424120	416301	19515S	PARTICIPANT	\N	PRESENT	0
446311	439813	14331P	PARTICIPANT	\N	PRESENT	0
446312	439813	14109K	PARTICIPANT	\N	PRESENT	0
446313	439813	11097X	PARTICIPANT	\N	PRESENT	0
446314	439813	14197C	PARTICIPANT	\N	PRESENT	0
446315	439813	14135M	PARTICIPANT	\N	PRESENT	0
446316	439813	98022P	PARTICIPANT	\N	PRESENT	0
446317	439813	01048V	PARTICIPANT	\N	PRESENT	0
446318	439813	19713W	PARTICIPANT	\N	PRESENT	0
446319	439813	08062Y	PARTICIPANT	\N	PRESENT	0
446320	439813	14179A	PARTICIPANT	\N	PRESENT	0
446321	439813	11104D	PARTICIPANT	\N	PRESENT	0
446322	439813	14051J	PARTICIPANT	\N	PRESENT	0
446323	439813	98050T	PARTICIPANT	\N	PRESENT	0
446324	439813	14034U	PARTICIPANT	\N	PRESENT	0
446325	439813	19768N	PARTICIPANT	\N	PRESENT	0
446326	439813	19549D	PARTICIPANT	\N	PRESENT	0
446327	439813	08055A	PARTICIPANT	\N	PRESENT	0
446328	439813	19663E	PARTICIPANT	\N	PRESENT	0
446329	439813	08015R	PARTICIPANT	\N	PRESENT	0
446330	439813	14221J	PARTICIPANT	\N	PRESENT	0
446331	439813	14061L	PARTICIPANT	\N	PRESENT	0
446332	439813	89017R	PARTICIPANT	\N	PRESENT	0
446333	439813	05012A	PARTICIPANT	\N	PRESENT	0
446334	439813	19691J	PARTICIPANT	\N	PRESENT	0
446335	439813	11064N	PARTICIPANT	\N	PRESENT	0
446336	439813	19521Q	PARTICIPANT	\N	PRESENT	0
446337	439813	19479G	PARTICIPANT	\N	PRESENT	0
446338	439813	08044W	PARTICIPANT	\N	PRESENT	0
446339	439813	08020N	PARTICIPANT	\N	PRESENT	0
446340	439813	14173T	PARTICIPANT	\N	PRESENT	0
446344	439813	14255U	PARTICIPANT	\N	PRESENT	0
446345	439813	19593H	PARTICIPANT	\N	PRESENT	0
446346	439813	19637C	PARTICIPANT	\N	PRESENT	0
446347	439813	14201E	PARTICIPANT	\N	PRESENT	0
446348	439813	19733B	PARTICIPANT	\N	PRESENT	0
446349	439813	19599P	PARTICIPANT	\N	PRESENT	0
446350	439813	14026U	PARTICIPANT	\N	PRESENT	0
446351	439813	19319Q	PARTICIPANT	\N	PRESENT	0
446353	439813	14157T	PARTICIPANT	\N	PRESENT	0
446354	439813	11101A	PARTICIPANT	\N	PRESENT	0
446355	439813	08069G	PARTICIPANT	\N	PRESENT	0
446356	439813	04042C	PARTICIPANT	\N	PRESENT	0
446357	444735	04044E	PARTICIPANT	\N	PRESENT	0
446358	444735	19671E	PARTICIPANT	\N	EXCUSE	0
446359	439813	80013X	PARTICIPANT	\N	PRESENT	0
446360	439813	14229S	PARTICIPANT	\N	PRESENT	0
446362	439813	04057K	PARTICIPANT	\N	PRESENT	0
446368	439813	19413M	PARTICIPANT	\N	PRESENT	0
446369	439813	19527W	PARTICIPANT	\N	PRESENT	0
446370	444735	14249W	PARTICIPANT	\N	PRESENT	0
446373	439813	11056N	PARTICIPANT	\N	PRESENT	0
446378	439813	19762G	PARTICIPANT	\N	PRESENT	0
446379	439813	14119M	PARTICIPANT	\N	PRESENT	0
446381	439813	04049K	PARTICIPANT	\N	PRESENT	0
446382	439813	11012A	PARTICIPANT	\N	PRESENT	0
446383	439813	04089T	PARTICIPANT	\N	PRESENT	0
446384	439813	04069P	PARTICIPANT	\N	PRESENT	0
446386	439813	11027H	PARTICIPANT	\N	PRESENT	0
446389	439813	08045X	PARTICIPANT	\N	PRESENT	0
446390	439813	08009T	PARTICIPANT	\N	PRESENT	0
446391	439813	11074Q	PARTICIPANT	\N	PRESENT	0
446392	439813	14083S	PARTICIPANT	\N	PRESENT	0
446393	439813	19631V	PARTICIPANT	\N	PRESENT	0
446394	439813	08068F	PARTICIPANT	\N	PRESENT	0
446395	439813	14033T	PARTICIPANT	\N	PRESENT	0
446396	439813	02002K	PARTICIPANT	\N	PRESENT	0
446397	439813	14251Q	PARTICIPANT	\N	PRESENT	0
446398	439813	17637T	PARTICIPANT	\N	PRESENT	0
446399	439813	14199E	PARTICIPANT	\N	PRESENT	0
446400	439813	11090Q	PARTICIPANT	\N	PRESENT	0
446401	439813	14151M	PARTICIPANT	\N	PRESENT	0
446402	439813	14121F	PARTICIPANT	\N	PRESENT	0
446403	439813	11109J	PARTICIPANT	\N	PRESENT	0
446404	439813	95067Q	PARTICIPANT	\N	PRESENT	0
446405	439813	07004J	PARTICIPANT	\N	PRESENT	0
446406	439813	08053X	PARTICIPANT	\N	PRESENT	0
446407	439813	19719D	PARTICIPANT	\N	PRESENT	0
446408	439813	04047H	PARTICIPANT	\N	PRESENT	0
446409	439813	04043D	PARTICIPANT	\N	PRESENT	0
446410	439813	12016W	PARTICIPANT	\N	PRESENT	0
446419	439813	95030B	PARTICIPANT	\N	PRESENT	0
446420	444385	04092N	PRESIDENT	0	PRESENT	0
446421	444385	08034U	PARTICIPANT	\N	PRESENT	0
446422	444385	19569H	PARTICIPANT	\N	PRESENT	0
446423	444385	19415P	PARTICIPANT	\N	PRESENT	0
446424	444385	04045F	PARTICIPANT	\N	PRESENT	0
446425	444385	19447X	PARTICIPANT	\N	PRESENT	0
446426	444385	05008E	PARTICIPANT	\N	PRESENT	0
446427	444385	19553Y	PARTICIPANT	\N	PRESENT	0
446428	444385	11031D	PARTICIPANT	\N	PRESENT	0
446429	444385	14042U	PARTICIPANT	\N	PRESENT	0
446430	444385	14195A	PARTICIPANT	\N	PRESENT	0
446431	444385	14147R	PARTICIPANT	\N	PRESENT	0
446432	444385	14213J	PARTICIPANT	\N	PRESENT	0
446433	444385	14215L	PARTICIPANT	\N	PRESENT	0
446434	444385	19685L	PARTICIPANT	\N	PRESENT	0
446435	444385	99004R	PARTICIPANT	\N	PRESENT	0
446436	444385	10006L	PARTICIPANT	\N	PRESENT	0
446437	444385	11072N	PARTICIPANT	\N	PRESENT	0
446438	444385	11067R	PARTICIPANT	\N	PRESENT	0
446439	444385	19649G	PARTICIPANT	\N	PRESENT	0
446440	444385	11045K	PARTICIPANT	\N	PRESENT	0
446441	444385	08052W	PARTICIPANT	\N	PRESENT	0
446442	444385	11066Q	PARTICIPANT	\N	PRESENT	0
446443	444385	18083K	PARTICIPANT	\N	PRESENT	0
446444	444385	19575F	PARTICIPANT	\N	PRESENT	0
446445	444385	14217N	PARTICIPANT	\N	PRESENT	0
446446	444385	14065Q	PARTICIPANT	\N	PRESENT	0
446447	444385	08043V	PARTICIPANT	\N	PRESENT	0
446598	439814	11072N	PARTICIPANT	\N	PRESENT	0
446599	439814	04092N	PARTICIPANT	\N	PRESENT	0
446600	439814	11031D	PARTICIPANT	\N	PRESENT	0
446601	439814	19683J	PARTICIPANT	\N	PRESENT	0
446602	439814	19503N	PARTICIPANT	\N	PRESENT	0
446603	439814	11067R	PARTICIPANT	\N	PRESENT	0
446604	439814	14257W	PARTICIPANT	\N	PRESENT	0
446605	439814	14097Y	PARTICIPANT	\N	PRESENT	0
446606	439814	14109K	PARTICIPANT	\N	PRESENT	0
446607	439814	19631V	PARTICIPANT	\N	PRESENT	0
446608	439814	19333N	PARTICIPANT	\N	PRESENT	0
446609	439814	19549D	PARTICIPANT	\N	PRESENT	0
446610	439814	19649G	PARTICIPANT	\N	PRESENT	0
446611	439814	11066Q	PARTICIPANT	\N	PRESENT	0
446612	439814	08043V	PARTICIPANT	\N	PRESENT	0
446613	439814	19679N	PARTICIPANT	\N	PRESENT	0
446614	439814	19703U	PARTICIPANT	\N	PRESENT	0
446638	439814	14065Q	PARTICIPANT	\N	PRESENT	0
446616	439814	19575F	PARTICIPANT	\N	PRESENT	0
446617	439814	14157T	PARTICIPANT	\N	PRESENT	0
446618	439814	14029X	PARTICIPANT	\N	PRESENT	0
446619	439814	14115H	PARTICIPANT	\N	PRESENT	0
446620	439814	08019V	PARTICIPANT	\N	PRESENT	0
446621	439814	95030B	PARTICIPANT	\N	PRESENT	0
446622	439814	14026U	PARTICIPANT	\N	PRESENT	0
446623	439814	19768N	PARTICIPANT	\N	PRESENT	0
446624	439814	12016W	PARTICIPANT	\N	PRESENT	0
446625	439814	01028R	PARTICIPANT	\N	PRESENT	0
446626	439814	14061L	PARTICIPANT	\N	PRESENT	0
446627	439814	04059M	PARTICIPANT	\N	PRESENT	0
446628	439814	14329V	PARTICIPANT	\N	PRESENT	0
446629	439814	08052W	PARTICIPANT	\N	PRESENT	0
446630	439814	05012A	PARTICIPANT	\N	PRESENT	0
446631	439814	08034U	PARTICIPANT	\N	PRESENT	0
446632	439814	19301E	PARTICIPANT	\N	PRESENT	0
446633	439814	19533U	PARTICIPANT	\N	PRESENT	0
446634	439814	14069U	PARTICIPANT	\N	PRESENT	0
446635	439814	08017T	PARTICIPANT	\N	PRESENT	0
446636	439814	11045K	PARTICIPANT	\N	PRESENT	0
446637	439814	19367Y	PARTICIPANT	\N	PRESENT	0
446639	439814	11033F	PARTICIPANT	\N	PRESENT	0
446640	439814	04085P	PARTICIPANT	\N	PRESENT	0
446641	439814	14053L	PARTICIPANT	\N	PRESENT	0
446642	439814	11056N	PARTICIPANT	\N	PRESENT	0
446643	439814	14187A	PARTICIPANT	\N	PRESENT	0
446644	439814	19760E	PARTICIPANT	\N	PRESENT	0
446645	439814	14071N	PARTICIPANT	\N	PRESENT	0
446646	439814	05008E	PARTICIPANT	\N	PRESENT	0
446647	439814	19695N	PARTICIPANT	\N	PRESENT	0
446648	439814	19565D	PARTICIPANT	\N	PRESENT	0
446649	439814	11097X	PARTICIPANT	\N	PRESENT	0
446650	439814	14223L	PARTICIPANT	\N	PRESENT	0
446651	439814	11090Q	PARTICIPANT	\N	PRESENT	0
446652	439814	99004R	PARTICIPANT	\N	PRESENT	0
446653	439814	08020N	PARTICIPANT	\N	PRESENT	0
446654	439814	14259Y	PARTICIPANT	\N	PRESENT	0
446655	439814	19697Q	PARTICIPANT	\N	PRESENT	0
446656	439814	19543W	PARTICIPANT	\N	PRESENT	0
446657	439814	19269X	PARTICIPANT	\N	PRESENT	0
446658	439814	19733B	PARTICIPANT	\N	PRESENT	0
424685	424679	11026G	PARTICIPANT	\N	PRESENT	0
424715	424679	14089Y	PARTICIPANT	\N	PRESENT	0
425533	416305	04034C	PARTICIPANT	\N	PRESENT	0
425534	416305	19697Q	PARTICIPANT	\N	PRESENT	0
425535	416305	04092N	PARTICIPANT	\N	PRESENT	0
425536	416305	14147R	PARTICIPANT	\N	PRESENT	0
425537	416305	01034P	PARTICIPANT	\N	PRESENT	0
425538	416305	19399H	PARTICIPANT	\N	PRESENT	0
425539	416305	19527W	PARTICIPANT	\N	PRESENT	0
425540	416305	14195A	PARTICIPANT	\N	PRESENT	0
425541	416305	19723Y	PARTICIPANT	\N	PRESENT	0
425542	416305	14038Y	PARTICIPANT	\N	PRESENT	0
425543	416305	19717B	PARTICIPANT	\N	PRESENT	0
425544	416305	14157T	PARTICIPANT	\N	PRESENT	0
425545	416305	19699S	PARTICIPANT	\N	PRESENT	0
425546	416305	19737F	PARTICIPANT	\N	PRESENT	0
425547	416305	14031R	PARTICIPANT	\N	PRESENT	0
425548	416305	19569H	PARTICIPANT	\N	PRESENT	0
425549	416305	19739H	PARTICIPANT	\N	PRESENT	0
425550	416305	14042U	PARTICIPANT	\N	PRESENT	0
425551	416305	15447F	PARTICIPANT	\N	PRESENT	0
425552	416305	19679N	PARTICIPANT	\N	PRESENT	0
425553	416305	19713W	PARTICIPANT	\N	PRESENT	0
425554	416305	08069G	PARTICIPANT	\N	PRESENT	0
425555	416305	19387D	PARTICIPANT	\N	PRESENT	0
425556	416305	14107H	PARTICIPANT	\N	PRESENT	0
425557	416305	14223L	PARTICIPANT	\N	PRESENT	0
425558	416305	14213J	PARTICIPANT	\N	PRESENT	0
425559	416305	98050T	PARTICIPANT	\N	PRESENT	0
425560	416305	19553Y	PARTICIPANT	\N	PRESENT	0
425561	416305	14239U	PARTICIPANT	\N	PRESENT	0
425562	416305	10006L	PARTICIPANT	\N	PRESENT	0
425563	416305	95063L	PARTICIPANT	\N	PRESENT	0
425564	416305	04045F	PARTICIPANT	\N	PRESENT	0
425565	416305	11097X	PARTICIPANT	\N	PRESENT	0
425566	416305	11072N	PARTICIPANT	\N	PRESENT	0
425567	416305	19421M	PARTICIPANT	\N	PRESENT	0
425568	416305	11067R	PARTICIPANT	\N	PRESENT	0
425569	416305	19820Y	PARTICIPANT	\N	PRESENT	0
425732	416305	08053X	PARTICIPANT	\N	PRESENT	0
425730	416305	11064N	PARTICIPANT	\N	PRESENT	0
425731	416305	14121F	PARTICIPANT	\N	PRESENT	0
425733	416305	98022P	PARTICIPANT	\N	PRESENT	0
425734	425424	19611R	PARTICIPANT	\N	PRESENT	0
425735	425424	14030Q	PARTICIPANT	\N	PRESENT	0
425736	425424	14241N	PARTICIPANT	\N	PRESENT	0
425737	425424	08017T	PARTICIPANT	\N	PRESENT	0
425738	425424	08012N	PARTICIPANT	\N	PRESENT	0
425739	425424	19621T	PARTICIPANT	\N	PRESENT	0
425740	425424	04070G	PARTICIPANT	\N	EXCUSE	0
425741	416305	17583W	PARTICIPANT	\N	PRESENT	0
425743	425424	14229S	PARTICIPANT	\N	PRESENT	0
425744	425424	08043V	PARTICIPANT	\N	PRESENT	0
425745	425424	08020N	PARTICIPANT	\N	PRESENT	0
425746	425424	19735D	PARTICIPANT	\N	PRESENT	0
425747	425424	11043H	PARTICIPANT	\N	PRESENT	0
425751	416305	19563B	PARTICIPANT	\N	PRESENT	0
425752	416305	95030B	PARTICIPANT	\N	PRESENT	0
425828	416305	14219Q	PARTICIPANT	\N	PRESENT	0
425757	425753	14053L	PARTICIPANT	\N	PRESENT	0
425758	425753	08060W	PARTICIPANT	\N	PRESENT	0
425759	425753	08009T	PRESIDENT	0	PRESENT	0
425760	425753	19367Y	PARTICIPANT	\N	PRESENT	0
425761	425753	19826F	PARTICIPANT	\N	PRESENT	0
425762	425753	08024S	PARTICIPANT	\N	PRESENT	0
425763	425753	14026U	PARTICIPANT	\N	PRESENT	0
425764	425753	04070G	PARTICIPANT	\N	EXCUSE	0
425765	425753	11048N	PARTICIPANT	\N	EXCUSE	0
425766	425753	14051J	PARTICIPANT	\N	EXCUSE	0
425767	425753	11065P	PARTICIPANT	\N	EXCUSE	0
425768	416305	11066Q	PARTICIPANT	\N	PRESENT	0
425827	416305	14225N	PARTICIPANT	\N	PRESENT	0
425829	416305	14173T	PARTICIPANT	\N	PRESENT	0
425830	416305	11012A	PARTICIPANT	\N	PRESENT	0
425831	416305	18083K	PARTICIPANT	\N	PRESENT	0
425832	416305	14103D	PARTICIPANT	\N	PRESENT	0
425833	416305	08056B	PARTICIPANT	\N	PRESENT	0
425834	416305	11054L	PARTICIPANT	\N	PRESENT	0
426087	425100	14327T	PARTICIPANT	\N	PRESENT	0
426088	425100	14331P	PARTICIPANT	\N	PRESENT	0
426089	425100	19545Y	PARTICIPANT	\N	PRESENT	0
426090	425100	01057W	PARTICIPANT	\N	PRESENT	0
426091	425100	19667J	PARTICIPANT	\N	PRESENT	0
426092	425100	11074Q	PRESIDENT	0	PRESENT	0
426093	425100	89017R	PARTICIPANT	\N	PRESENT	0
426094	425100	14225N	PARTICIPANT	\N	PRESENT	0
426095	425100	88008L	PARTICIPANT	\N	PRESENT	0
426096	425100	19671E	PARTICIPANT	\N	PRESENT	0
426097	425100	07029T	PARTICIPANT	\N	PRESENT	0
426098	425100	07004J	PARTICIPANT	\N	PRESENT	0
426099	425100	19349W	PARTICIPANT	\N	PRESENT	0
426100	425100	08010L	PARTICIPANT	\N	PRESENT	0
426101	425100	14253S	PARTICIPANT	\N	PRESENT	0
426102	425100	19479G	PARTICIPANT	\N	PRESENT	0
426103	425100	11048N	PARTICIPANT	\N	PRESENT	0
426104	425100	19711U	PARTICIPANT	\N	PRESENT	0
426105	425100	19531S	PARTICIPANT	\N	PRESENT	0
426106	425100	08034U	PARTICIPANT	\N	PRESENT	0
426107	425100	19651A	PARTICIPANT	\N	PRESENT	0
426108	425100	08069G	PARTICIPANT	\N	PRESENT	0
426109	425100	12016W	PARTICIPANT	\N	PRESENT	0
426110	425100	08011M	PARTICIPANT	\N	PRESENT	0
426111	425100	08014Q	PARTICIPANT	\N	PRESENT	0
426112	425100	14159V	PARTICIPANT	\N	PRESENT	0
426113	425100	14173T	PARTICIPANT	\N	PRESENT	0
426114	425100	04086Q	PARTICIPANT	\N	PRESENT	0
426115	425100	14083S	PARTICIPANT	\N	PRESENT	0
426116	425100	14199E	PARTICIPANT	\N	PRESENT	0
426117	425100	11012A	PARTICIPANT	\N	PRESENT	0
426118	425100	19741B	PARTICIPANT	\N	PRESENT	0
426119	425100	99004R	PARTICIPANT	\N	PRESENT	0
426120	425100	01048V	PARTICIPANT	\N	PRESENT	0
426121	425100	14085U	PARTICIPANT	\N	PRESENT	0
426122	425100	14121F	PARTICIPANT	\N	PRESENT	0
426128	425100	96004D	PARTICIPANT	\N	PRESENT	0
426129	425100	19687N	PARTICIPANT	\N	PRESENT	0
426130	425100	19689Q	PARTICIPANT	\N	PRESENT	0
426131	425100	08073C	PARTICIPANT	\N	PRESENT	0
426132	424936	19443T	PARTICIPANT	\N	PRESENT	0
426133	424936	12041X	PARTICIPANT	\N	PRESENT	0
426134	424936	11080N	PARTICIPANT	\N	PRESENT	0
426135	424936	04034C	PARTICIPANT	\N	PRESENT	0
426136	424936	14079W	PARTICIPANT	\N	PRESENT	0
426137	424936	11027H	PARTICIPANT	\N	PRESENT	0
426138	424936	04042C	PRESIDENT	0	PRESENT	0
426139	424936	11054L	PARTICIPANT	\N	PRESENT	0
426140	424936	11066Q	PARTICIPANT	\N	PRESENT	0
426141	424936	08056B	PARTICIPANT	\N	PRESENT	0
426142	424936	19421M	PARTICIPANT	\N	PRESENT	0
426143	424936	14193X	PARTICIPANT	\N	PRESENT	0
426144	424936	08053X	PARTICIPANT	\N	PRESENT	0
426145	424936	97011G	PARTICIPANT	\N	PRESENT	0
426146	424936	14097Y	PARTICIPANT	\N	PRESENT	0
426147	424936	14133K	PARTICIPANT	\N	PRESENT	0
426148	424936	01062T	PARTICIPANT	\N	PRESENT	0
426149	424936	11041F	PARTICIPANT	\N	PRESENT	0
426150	424936	14235Q	PARTICIPANT	\N	PRESENT	0
426151	424936	14028W	PARTICIPANT	\N	PRESENT	0
426152	424936	19251M	PARTICIPANT	\N	PRESENT	0
426153	424936	14105F	PARTICIPANT	\N	PRESENT	0
426154	424936	98022P	PARTICIPANT	\N	PRESENT	0
426155	424936	11064N	PARTICIPANT	\N	PRESENT	0
426156	424936	14267Y	PARTICIPANT	\N	PRESENT	0
426157	424936	98050T	PARTICIPANT	\N	PRESENT	0
426158	424936	14211G	PARTICIPANT	\N	PRESENT	0
426159	424936	19583F	PARTICIPANT	\N	PRESENT	0
426160	424936	01058X	PARTICIPANT	\N	PRESENT	0
426161	424936	16685X	PARTICIPANT	\N	PRESENT	0
426162	424936	08049C	PARTICIPANT	\N	PRESENT	0
426163	424936	19319Q	PARTICIPANT	\N	PRESENT	0
426164	424936	14255U	PARTICIPANT	\N	PRESENT	0
426165	426125	19766L	PARTICIPANT	\N	PRESENT	0
426166	426125	19699S	PARTICIPANT	\N	PRESENT	0
426167	426125	14061L	PARTICIPANT	\N	PRESENT	0
426168	426125	14073Q	PARTICIPANT	\N	PRESENT	0
426169	426125	19611R	PARTICIPANT	\N	PRESENT	0
426170	426125	19399H	PARTICIPANT	\N	PRESENT	0
426171	426125	14201E	PARTICIPANT	\N	PRESENT	0
426172	426125	14030Q	PARTICIPANT	\N	PRESENT	0
426173	426125	19731Y	PARTICIPANT	\N	PRESENT	0
426174	426125	14251Q	PARTICIPANT	\N	PRESENT	0
426175	426125	19573D	PARTICIPANT	\N	PRESENT	0
426176	426125	14039A	PARTICIPANT	\N	PRESENT	0
426177	426125	04018C	PARTICIPANT	\N	PRESENT	0
426178	426125	14249W	PARTICIPANT	\N	PRESENT	0
426179	426125	04070G	PARTICIPANT	\N	EXCUSE	0
426180	426125	19593H	PARTICIPANT	\N	PRESENT	0
426181	426125	14241N	PARTICIPANT	\N	PRESENT	0
426182	426125	14107H	PARTICIPANT	\N	PRESENT	0
426183	426125	08039A	PRESIDENT	0	PRESENT	0
435581	435580	19549D	PARTICIPANT	\N	PRESENT	0
435582	435580	14255U	PARTICIPANT	\N	PRESENT	0
435583	435580	04040A	PARTICIPANT	\N	PRESENT	0
435584	435580	11026G	PARTICIPANT	\N	PRESENT	0
435591	435590	19549D	PARTICIPANT	\N	PRESENT	0
435858	435852	08043V	PARTICIPANT	\N	PRESENT	0
435859	435852	11031D	PARTICIPANT	\N	PRESENT	0
435860	435852	14215L	PARTICIPANT	\N	PRESENT	0
435861	435852	08052W	PARTICIPANT	\N	PRESENT	0
435862	435852	19683J	PARTICIPANT	\N	PRESENT	0
435863	435852	19447X	PARTICIPANT	\N	PRESENT	0
440682	440681	14053L	PARTICIPANT	\N	PRESENT	0
441854	441789	19551W	PARTICIPANT	\N	PRESENT	0
441855	441789	04097T	PARTICIPANT	\N	PRESENT	0
441856	441789	17583W	PARTICIPANT	\N	EXCUSE	0
441857	441789	08024S	PARTICIPANT	\N	EXCUSE	0
442092	439632	04086Q	PARTICIPANT	\N	PRESENT	0
441859	441789	19333N	PARTICIPANT	\N	EXCUSE	0
441860	441789	14237S	PARTICIPANT	\N	PRESENT	0
441861	441789	17637T	PARTICIPANT	\N	PRESENT	0
441867	441791	08056B	PARTICIPANT	\N	PRESENT	0
441868	441791	14187A	PARTICIPANT	\N	PRESENT	0
441869	441791	04040A	PARTICIPANT	\N	PRESENT	0
441870	441791	08010L	PARTICIPANT	\N	PRESENT	0
441871	441791	04044E	PARTICIPANT	\N	PRESENT	0
441872	441791	19673G	PARTICIPANT	\N	PRESENT	0
441873	441791	19719D	PRESIDENT	0	PRESENT	0
441874	441791	08053X	PARTICIPANT	\N	EXCUSE	0
441875	441791	19671E	PARTICIPANT	\N	EXCUSE	0
441828	441789	08060W	PARTICIPANT	\N	PRESENT	0
441829	441789	19549D	PARTICIPANT	\N	PRESENT	0
441830	441789	19503N	PARTICIPANT	\N	PRESENT	0
441831	441789	19820Y	PARTICIPANT	\N	PRESENT	0
441832	441789	08055A	PARTICIPANT	\N	PRESENT	0
441833	441789	19525U	PARTICIPANT	\N	PRESENT	0
441834	441789	19383Y	PARTICIPANT	\N	PRESENT	0
441835	441789	19701S	PARTICIPANT	\N	PRESENT	0
441836	441789	19794Q	PARTICIPANT	\N	PRESENT	0
441837	441789	19387D	PARTICIPANT	\N	PRESENT	0
441838	441789	14219Q	PARTICIPANT	\N	PRESENT	0
441839	441789	18083K	PARTICIPANT	\N	PRESENT	0
441840	441789	19347U	PARTICIPANT	\N	PRESENT	0
441841	441789	14157T	PARTICIPANT	\N	PRESENT	0
441842	441789	14038Y	PARTICIPANT	\N	PRESENT	0
441843	441789	14031R	PARTICIPANT	\N	PRESENT	0
441844	441789	19713W	PARTICIPANT	\N	PRESENT	0
441845	441789	14191V	PARTICIPANT	\N	PRESENT	0
441846	441789	14169X	PARTICIPANT	\N	PRESENT	0
441847	441789	15447F	PARTICIPANT	\N	PRESENT	0
441848	441789	14093U	PARTICIPANT	\N	PRESENT	0
441849	441789	14029X	PARTICIPANT	\N	PRESENT	0
441850	441789	08009T	PRESIDENT	0	PRESENT	0
441851	441789	19737F	PARTICIPANT	\N	PRESENT	0
441852	441789	19739H	PARTICIPANT	\N	PRESENT	0
441853	441789	19745F	PARTICIPANT	\N	PRESENT	0
441876	439631	04086Q	PARTICIPANT	\N	PRESENT	0
441877	439631	14331P	PARTICIPANT	\N	PRESENT	0
441958	439631	19679N	PARTICIPANT	\N	PRESENT	0
441959	439631	19347U	PARTICIPANT	\N	PRESENT	0
442094	439632	19758L	PARTICIPANT	\N	PRESENT	0
442095	439632	19347U	PARTICIPANT	\N	PRESENT	0
442096	439632	11056N	PARTICIPANT	\N	PRESENT	0
442097	439632	19503N	PARTICIPANT	\N	PRESENT	0
442098	439632	19820Y	PARTICIPANT	\N	PRESENT	0
442099	439632	11104D	PARTICIPANT	\N	PRESENT	0
442100	439632	14063N	PARTICIPANT	\N	PRESENT	0
442101	439632	19631V	PARTICIPANT	\N	PRESENT	0
442102	439632	14051J	PARTICIPANT	\N	PRESENT	0
442103	439632	14109K	PARTICIPANT	\N	PRESENT	0
442104	439632	19725B	PARTICIPANT	\N	PRESENT	0
442105	439632	14081Q	PARTICIPANT	\N	PRESENT	0
442106	439632	19782L	PARTICIPANT	\N	PRESENT	0
442107	439632	19349W	PARTICIPANT	\N	PRESENT	0
442108	439632	19387D	PARTICIPANT	\N	PRESENT	0
442109	439632	11012A	PARTICIPANT	\N	PRESENT	0
442110	439632	04034C	PARTICIPANT	\N	PRESENT	0
442111	439632	19563B	PARTICIPANT	\N	PRESENT	0
442112	439632	19583F	PARTICIPANT	\N	PRESENT	0
442113	439632	14207L	PARTICIPANT	\N	PRESENT	0
442114	439632	19511N	PARTICIPANT	\N	PRESENT	0
442115	439632	08061X	PARTICIPANT	\N	PRESENT	0
442116	439632	19713W	PARTICIPANT	\N	PRESENT	0
442117	439632	19737F	PARTICIPANT	\N	PRESENT	0
442118	439632	14083S	PARTICIPANT	\N	PRESENT	0
442119	439632	08009T	PARTICIPANT	\N	PRESENT	0
442120	439632	01024M	PARTICIPANT	\N	PRESENT	0
442121	439632	01025N	PARTICIPANT	\N	PRESENT	0
442122	439632	19521Q	PARTICIPANT	\N	PRESENT	0
442123	439632	19745F	PARTICIPANT	\N	PRESENT	0
442124	439632	19367Y	PARTICIPANT	\N	PRESENT	0
442125	439632	08056B	PARTICIPANT	\N	PRESENT	0
442126	439632	19798U	PARTICIPANT	\N	PRESENT	0
442127	439632	19731Y	PARTICIPANT	\N	PRESENT	0
442128	439632	19701S	PARTICIPANT	\N	PRESENT	0
442129	439632	19383Y	PARTICIPANT	\N	PRESENT	0
442130	439632	98050T	PARTICIPANT	\N	PRESENT	0
442131	439632	95030B	PARTICIPANT	\N	PRESENT	0
442132	439632	97011G	PARTICIPANT	\N	PRESENT	0
442133	439632	14069U	PARTICIPANT	\N	PRESENT	0
442134	439632	11043H	PARTICIPANT	\N	PRESENT	0
442135	439632	87003B	PARTICIPANT	\N	PRESENT	0
442136	439632	19399H	PARTICIPANT	\N	PRESENT	0
442137	439632	14105F	PARTICIPANT	\N	PRESENT	0
442138	439632	19507S	PARTICIPANT	\N	PRESENT	0
442139	439632	19741B	PARTICIPANT	\N	PRESENT	0
442140	439632	04088S	PARTICIPANT	\N	PRESENT	0
442093	439632	11040E	PARTICIPANT	\N	PRESENT	0
442141	439632	14029X	PARTICIPANT	\N	PRESENT	0
442142	439632	19573D	PARTICIPANT	\N	PRESENT	0
442143	439632	14031R	PARTICIPANT	\N	PRESENT	0
442144	439632	19703U	PARTICIPANT	\N	PRESENT	0
442145	439632	14038Y	PARTICIPANT	\N	PRESENT	0
442146	439632	08069G	PARTICIPANT	\N	PRESENT	0
442147	439632	14173T	PARTICIPANT	\N	PRESENT	0
442148	439632	14223L	PARTICIPANT	\N	PRESENT	0
442149	439632	19679N	PARTICIPANT	\N	PRESENT	0
442150	439632	19479G	PARTICIPANT	\N	PRESENT	0
442151	439632	19581D	PARTICIPANT	\N	PRESENT	0
442152	439632	14033T	PARTICIPANT	\N	PRESENT	0
442153	439632	14199E	PARTICIPANT	\N	PRESENT	0
442154	439632	19531S	PARTICIPANT	\N	PRESENT	0
442155	439632	14265W	PARTICIPANT	\N	PRESENT	0
442156	439632	19467C	PARTICIPANT	\N	PRESENT	0
442157	439632	08055A	PARTICIPANT	\N	PRESENT	0
442158	439632	19333N	PARTICIPANT	\N	PRESENT	0
442159	439632	14133K	PARTICIPANT	\N	PRESENT	0
442160	439632	11103C	PARTICIPANT	\N	PRESENT	0
442161	439632	14257W	PARTICIPANT	\N	PRESENT	0
442162	439632	01057W	PARTICIPANT	\N	PRESENT	0
442163	439632	14030Q	PARTICIPANT	\N	PRESENT	0
442164	439632	08031R	PARTICIPANT	\N	PRESENT	0
442165	439632	15447F	PARTICIPANT	\N	PRESENT	0
442166	439632	14026U	PARTICIPANT	\N	PRESENT	0
442168	439632	19441R	PARTICIPANT	\N	PRESENT	0
442177	441865	08010L	PARTICIPANT	\N	PRESENT	0
442178	441865	04044E	PARTICIPANT	\N	PRESENT	0
442179	439632	19749K	PARTICIPANT	\N	PRESENT	0
442192	439632	14135M	PARTICIPANT	\N	PRESENT	0
442193	439632	19593H	PARTICIPANT	\N	PRESENT	0
442194	439632	14205J	PARTICIPANT	\N	PRESENT	0
442195	439632	14221J	PARTICIPANT	\N	PRESENT	0
442196	439632	14229S	PARTICIPANT	\N	PRESENT	0
442197	439632	08014Q	PARTICIPANT	\N	PRESENT	0
442198	439632	14225N	PARTICIPANT	\N	PRESENT	0
442199	439632	80013X	PARTICIPANT	\N	PRESENT	0
442200	439632	19549D	PARTICIPANT	\N	PRESENT	0
442201	439632	08028W	PARTICIPANT	\N	PRESENT	0
442202	439632	17589D	PARTICIPANT	\N	PRESENT	0
442203	439632	08034U	PARTICIPANT	\N	PRESENT	0
442204	439632	11097X	PARTICIPANT	\N	PRESENT	0
442205	439632	19697Q	PARTICIPANT	\N	PRESENT	0
442206	439632	12041X	PARTICIPANT	\N	PRESENT	0
442207	439632	11077T	PARTICIPANT	\N	PRESENT	0
442209	439632	14087W	PARTICIPANT	\N	PRESENT	0
442210	441618	01048V	PARTICIPANT	\N	PRESENT	0
442211	439632	19717B	PARTICIPANT	\N	PRESENT	0
442212	439632	14191V	PARTICIPANT	\N	PRESENT	0
442213	439632	14227Q	PARTICIPANT	\N	PRESENT	0
442214	439632	08044W	PARTICIPANT	\N	PRESENT	0
442215	439632	19739H	PARTICIPANT	\N	PRESENT	0
442216	439632	14179A	PARTICIPANT	\N	PRESENT	0
442217	439632	14195A	PARTICIPANT	\N	PRESENT	0
442218	439632	14121F	PARTICIPANT	\N	PRESENT	0
442219	439632	11066Q	PARTICIPANT	\N	PRESENT	0
442220	439632	08043V	PARTICIPANT	\N	PRESENT	0
424121	416301	11054L	PARTICIPANT	\N	PRESENT	0
424122	416301	19295A	PARTICIPANT	\N	PRESENT	0
424123	416301	11080N	PARTICIPANT	\N	PRESENT	0
424124	416301	19413M	PARTICIPANT	\N	PRESENT	0
424125	416301	19766L	PARTICIPANT	\N	PRESENT	0
424126	416301	19251M	PARTICIPANT	\N	PRESENT	0
424127	416301	17779H	PARTICIPANT	\N	PRESENT	0
424128	416301	01057W	PARTICIPANT	\N	PRESENT	0
424129	416301	19683J	PARTICIPANT	\N	PRESENT	0
424130	416301	87003B	PARTICIPANT	\N	PRESENT	0
424131	416301	08058D	PARTICIPANT	\N	PRESENT	0
424132	416301	11090Q	PARTICIPANT	\N	PRESENT	0
424133	416301	04043D	PARTICIPANT	\N	PRESENT	0
424134	416301	14065Q	PARTICIPANT	\N	PRESENT	0
424135	416301	14085U	PARTICIPANT	\N	PRESENT	0
424136	416301	14069U	PARTICIPANT	\N	PRESENT	0
424137	416301	14249W	PARTICIPANT	\N	PRESENT	0
424138	416301	08012N	PARTICIPANT	\N	PRESENT	0
424139	416301	14053L	PARTICIPANT	\N	PRESENT	0
424140	416301	19820Y	PARTICIPANT	\N	PRESENT	0
424141	416301	14087W	PARTICIPANT	\N	PRESENT	0
424142	416301	12016W	PARTICIPANT	\N	PRESENT	0
424143	416301	19531S	PARTICIPANT	\N	PRESENT	0
424144	416301	14215L	PARTICIPANT	\N	PRESENT	0
424145	416301	19727D	PARTICIPANT	\N	PRESENT	0
424146	416301	15447F	PARTICIPANT	\N	PRESENT	0
424147	416301	19649G	PARTICIPANT	\N	PRESENT	0
424148	416301	14197C	PARTICIPANT	\N	PRESENT	0
424149	416301	19643A	PARTICIPANT	\N	PRESENT	0
424150	416301	14028W	PARTICIPANT	\N	PRESENT	0
424151	416301	04071H	PARTICIPANT	\N	PRESENT	0
424152	416301	14169X	PARTICIPANT	\N	PRESENT	0
424153	416301	19599P	PARTICIPANT	\N	PRESENT	0
424154	416301	19715Y	PARTICIPANT	\N	PRESENT	0
424155	416301	14223L	PARTICIPANT	\N	PRESENT	0
424156	416301	14281W	PARTICIPANT	\N	PRESENT	0
424157	416301	10015M	PARTICIPANT	\N	PRESENT	0
424158	416301	11043H	PARTICIPANT	\N	PRESENT	0
424159	416301	19689Q	PARTICIPANT	\N	PRESENT	0
424160	416301	01048V	PARTICIPANT	\N	PRESENT	0
424161	416301	11048N	PARTICIPANT	\N	PRESENT	0
424162	416301	08028W	PARTICIPANT	\N	PRESENT	0
424163	416301	04033B	PARTICIPANT	\N	PRESENT	0
424164	416301	14231L	PARTICIPANT	\N	PRESENT	0
424165	416301	04089T	PARTICIPANT	\N	PRESENT	0
424166	416301	14187A	PARTICIPANT	\N	PRESENT	0
424167	416301	14071N	PARTICIPANT	\N	PRESENT	0
424168	416301	14034U	PARTICIPANT	\N	PRESENT	0
424169	416301	11097X	PARTICIPANT	\N	PRESENT	0
424170	416301	14179A	PARTICIPANT	\N	PRESENT	0
424171	416301	19421M	PARTICIPANT	\N	PRESENT	0
424172	416301	01034P	PARTICIPANT	\N	PRESENT	0
424173	416301	04070G	PARTICIPANT	\N	PRESENT	0
424174	416301	19369B	PARTICIPANT	\N	PRESENT	0
424175	416301	19691J	PARTICIPANT	\N	PRESENT	0
424176	416301	04097T	PARTICIPANT	\N	PRESENT	0
424177	416301	11053K	PARTICIPANT	\N	PRESENT	0
424178	416301	14255U	PARTICIPANT	\N	PRESENT	0
424179	416301	08020N	PARTICIPANT	\N	PRESENT	0
424180	416301	19611R	PARTICIPANT	\N	PRESENT	0
424181	416301	08010L	PARTICIPANT	\N	PRESENT	0
424182	416301	04042C	PARTICIPANT	\N	PRESENT	0
424183	416301	19511N	PARTICIPANT	\N	PRESENT	0
424184	416301	95041E	PARTICIPANT	\N	PRESENT	0
424185	416301	04092N	PARTICIPANT	\N	PRESENT	0
424186	416301	19721W	PARTICIPANT	\N	PRESENT	0
424187	416301	19521Q	PARTICIPANT	\N	PRESENT	0
424188	416301	04044E	PARTICIPANT	\N	PRESENT	0
424189	416301	14205J	PARTICIPANT	\N	PRESENT	0
424191	416301	19747H	PARTICIPANT	\N	PRESENT	0
424192	416301	19737F	PARTICIPANT	\N	PRESENT	0
424194	416301	19569H	PARTICIPANT	\N	PRESENT	0
424196	416301	19739H	PARTICIPANT	\N	PRESENT	0
424197	416301	19735D	PARTICIPANT	\N	PRESENT	0
424198	416301	01058X	PARTICIPANT	\N	PRESENT	0
424199	416301	16685X	PARTICIPANT	\N	PRESENT	0
424200	416301	19441R	PARTICIPANT	\N	PRESENT	0
424202	416301	99004R	PARTICIPANT	\N	PRESENT	0
424204	416301	95030B	PARTICIPANT	\N	PRESENT	0
424205	416301	14219Q	PARTICIPANT	\N	PRESENT	0
424207	416301	19479G	PARTICIPANT	\N	PRESENT	0
424208	416301	04047H	PARTICIPANT	\N	PRESENT	0
424210	416301	14042U	PARTICIPANT	\N	PRESENT	0
424212	416301	14026U	PARTICIPANT	\N	PRESENT	0
424213	416301	19713W	PARTICIPANT	\N	PRESENT	0
424214	416301	19699S	PARTICIPANT	\N	PRESENT	0
424215	416301	14267Y	PARTICIPANT	\N	PRESENT	0
424217	416301	14103D	PARTICIPANT	\N	PRESENT	0
424219	416301	86034E	PARTICIPANT	\N	PRESENT	0
424220	416301	14221J	PARTICIPANT	\N	PRESENT	0
424222	416301	11101A	PARTICIPANT	\N	PRESENT	0
424223	416301	19335Q	PARTICIPANT	\N	PRESENT	0
424225	416301	98024R	PARTICIPANT	\N	PRESENT	0
424226	416301	19553Y	PARTICIPANT	\N	PRESENT	0
424228	416301	08043V	PARTICIPANT	\N	PRESENT	0
424229	416301	14073Q	PARTICIPANT	\N	PRESENT	0
424231	416301	14083S	PARTICIPANT	\N	PRESENT	0
424232	416301	11085T	PARTICIPANT	\N	PRESENT	0
424234	416301	19745F	PARTICIPANT	\N	PRESENT	0
424235	416301	11070L	PARTICIPANT	\N	PRESENT	0
424237	416301	14327T	PARTICIPANT	\N	PRESENT	0
424238	416301	14061L	PARTICIPANT	\N	PRESENT	0
424239	416301	08009T	PARTICIPANT	\N	PRESENT	0
424241	416301	19768N	PARTICIPANT	\N	PRESENT	0
424242	416301	04040A	PARTICIPANT	\N	PRESENT	0
424244	416301	19729F	PARTICIPANT	\N	PRESENT	0
424246	416301	01024M	PARTICIPANT	\N	PRESENT	0
424248	416301	01025N	PARTICIPANT	\N	PRESENT	0
424249	416301	14030Q	PARTICIPANT	\N	PRESENT	0
424250	416301	04018C	PARTICIPANT	\N	PRESENT	0
424262	416301	95067Q	PARTICIPANT	\N	PRESENT	0
424252	416301	19551W	PARTICIPANT	\N	PRESENT	0
424253	416301	14109K	PARTICIPANT	\N	PRESENT	0
424255	416301	14055N	PARTICIPANT	\N	PRESENT	0
424275	416301	14089Y	PARTICIPANT	\N	PRESENT	0
424258	416301	08069G	PARTICIPANT	\N	PRESENT	0
424264	416301	07004J	PARTICIPANT	\N	PRESENT	0
424265	416301	14217N	PARTICIPANT	\N	PRESENT	0
424278	416301	19826F	PARTICIPANT	\N	PRESENT	0
424279	416301	14227Q	PARTICIPANT	\N	PRESENT	0
424281	416301	08053X	PARTICIPANT	\N	PRESENT	0
424282	416301	14237S	PARTICIPANT	\N	PRESENT	0
424283	416301	11104D	PARTICIPANT	\N	PRESENT	0
424289	416301	14123H	PARTICIPANT	\N	PRESENT	0
424586	416302	11027H	PARTICIPANT	\N	PRESENT	0
424591	422494	14327T	PRESIDENT	0	PRESENT	0
424592	422494	07029T	PARTICIPANT	\N	PRESENT	0
424593	422494	14083S	PARTICIPANT	\N	PRESENT	0
424594	422494	11048N	PARTICIPANT	\N	PRESENT	0
424595	422494	19479G	PARTICIPANT	\N	PRESENT	0
424596	422494	14085U	PARTICIPANT	\N	PRESENT	0
424597	422494	96004D	PARTICIPANT	\N	PRESENT	0
424598	422494	12016W	PARTICIPANT	\N	PRESENT	0
424599	422494	14121F	PARTICIPANT	\N	PRESENT	0
424600	422494	99004R	PARTICIPANT	\N	PRESENT	0
424601	422494	19671E	PARTICIPANT	\N	PRESENT	0
424602	422494	11012A	PARTICIPANT	\N	PRESENT	0
427837	427836	19467C	PARTICIPANT	\N	PRESENT	0
427838	427836	07029T	PARTICIPANT	\N	PRESENT	0
427839	427836	14265W	PARTICIPANT	\N	PRESENT	0
427840	427836	14119M	PARTICIPANT	\N	PRESENT	0
427841	427836	19349W	PARTICIPANT	\N	PRESENT	0
428392	428198	04086Q	PARTICIPANT	\N	PRESENT	0
428393	428198	14327T	PARTICIPANT	\N	PRESENT	0
428394	428198	11040E	PARTICIPANT	\N	PRESENT	0
428395	428198	14331P	PARTICIPANT	\N	PRESENT	0
428396	428198	19479G	PARTICIPANT	\N	PRESENT	0
428397	428198	11012A	PARTICIPANT	\N	PRESENT	0
428398	428198	19651A	PARTICIPANT	\N	PRESENT	0
428399	428198	07004J	PARTICIPANT	\N	PRESENT	0
428400	428198	99004R	PARTICIPANT	\N	PRESENT	0
428401	428198	19667J	PARTICIPANT	\N	PRESENT	0
428402	428198	14253S	PARTICIPANT	\N	PRESENT	0
428403	428198	08011M	PARTICIPANT	\N	PRESENT	0
429087	429086	19575F	PARTICIPANT	\N	PRESENT	0
429088	429086	19383Y	PARTICIPANT	\N	PRESENT	0
429089	429086	11101A	PARTICIPANT	\N	PRESENT	0
429090	429086	14265W	PARTICIPANT	\N	PRESENT	0
429091	429086	14237S	PARTICIPANT	\N	PRESENT	0
429092	429086	95067Q	PARTICIPANT	\N	PRESENT	0
429139	429138	01034P	PARTICIPANT	\N	PRESENT	0
429140	429138	10006L	PARTICIPANT	\N	PRESENT	0
429141	429138	08052W	PARTICIPANT	\N	PRESENT	0
429143	429138	14281W	PARTICIPANT	\N	PRESENT	0
429144	429138	19301E	PARTICIPANT	\N	PRESENT	0
429145	429138	19415P	PARTICIPANT	\N	PRESENT	0
429146	429138	98024R	PARTICIPANT	\N	PRESENT	0
429149	429148	04085P	PARTICIPANT	\N	PRESENT	0
429150	429148	04059M	PARTICIPANT	\N	PRESENT	0
436816	436815	96004D	PRESIDENT	0	PRESENT	0
436817	436815	14089Y	PARTICIPANT	\N	PRESENT	0
436818	436815	14357A	PARTICIPANT	\N	PRESENT	0
436819	436815	14249W	PARTICIPANT	\N	PRESENT	0
436820	436815	11083R	PARTICIPANT	\N	PRESENT	0
436821	436815	19553Y	PARTICIPANT	\N	PRESENT	0
436822	436815	04097T	PARTICIPANT	\N	PRESENT	0
436823	436815	14241N	PARTICIPANT	\N	PRESENT	0
436824	436815	11026G	PARTICIPANT	\N	PRESENT	0
436825	436815	04057K	PARTICIPANT	\N	EXCUSE	0
436826	436815	14237S	PARTICIPANT	\N	PRESENT	0
436827	436815	10015M	PARTICIPANT	\N	PRESENT	0
436828	436815	98050T	PARTICIPANT	\N	PRESENT	0
436829	436815	19711U	PARTICIPANT	\N	PRESENT	0
436830	436815	14255U	PARTICIPANT	\N	PRESENT	0
436831	436815	19467C	PARTICIPANT	\N	PRESENT	0
436832	436815	08024S	PARTICIPANT	\N	PRESENT	0
436833	436815	11064N	PARTICIPANT	\N	PRESENT	0
439857	439856	19569H	PARTICIPANT	\N	PRESENT	0
439854	439853	19447X	PARTICIPANT	\N	PRESENT	0
439855	439853	19569H	PARTICIPANT	\N	PRESENT	0
439859	439858	19569H	PARTICIPANT	\N	PRESENT	0
444324	441810	96004D	PRESIDENT	0	PRESENT	0
444325	441810	14357A	PARTICIPANT	\N	PRESENT	0
444326	441810	14079W	PARTICIPANT	\N	PRESENT	0
444327	441810	11083R	PARTICIPANT	\N	PRESENT	0
444328	441810	19725B	PARTICIPANT	\N	PRESENT	0
444329	441810	19553Y	PARTICIPANT	\N	PRESENT	0
444330	441810	04097T	PARTICIPANT	\N	PRESENT	0
444331	441810	14061L	PARTICIPANT	\N	EXCUSE	0
444332	441810	11026G	PARTICIPANT	\N	PRESENT	0
444333	441810	14331P	PARTICIPANT	\N	PRESENT	0
444334	441810	10015M	PARTICIPANT	\N	PRESENT	0
444335	441810	14237S	PARTICIPANT	\N	PRESENT	0
444336	441810	14001X	PARTICIPANT	\N	EXCUSE	0
444337	441810	14089Y	PARTICIPANT	\N	PRESENT	0
444338	441810	14097Y	PARTICIPANT	\N	PRESENT	0
444339	441810	04057K	PARTICIPANT	\N	PRESENT	0
446661	439814	14239U	PARTICIPANT	\N	PRESENT	0
446662	439814	10006L	PARTICIPANT	\N	PRESENT	0
446663	439814	19253P	PARTICIPANT	\N	PRESENT	0
446664	439814	19729F	PARTICIPANT	\N	PRESENT	0
446665	439814	18083K	PARTICIPANT	\N	PRESENT	0
446666	439814	19629C	PARTICIPANT	\N	PRESENT	0
446667	439814	19681G	PARTICIPANT	\N	PRESENT	0
446668	439814	11064N	PARTICIPANT	\N	PRESENT	0
446669	439814	19507S	PARTICIPANT	\N	PRESENT	0
446670	439814	14195A	PARTICIPANT	\N	PRESENT	0
446671	439814	14033T	PARTICIPANT	\N	PRESENT	0
446672	439814	19441R	PARTICIPANT	\N	PRESENT	0
446673	439814	19415P	PARTICIPANT	\N	PRESENT	0
446674	439814	19467C	PARTICIPANT	\N	PRESENT	0
446675	439814	95063L	PARTICIPANT	\N	PRESENT	0
446676	439814	19723Y	PARTICIPANT	\N	PRESENT	0
446677	439814	04045F	PARTICIPANT	\N	PRESENT	0
446678	439814	14038Y	PARTICIPANT	\N	PRESENT	0
446679	439814	19741B	PARTICIPANT	\N	PRESENT	0
446680	439814	19719D	PARTICIPANT	\N	PRESENT	0
446681	439814	14207L	PARTICIPANT	\N	PRESENT	0
446682	439814	11101A	PARTICIPANT	\N	PRESENT	0
446683	439814	19553Y	PARTICIPANT	\N	PRESENT	0
446684	439814	19713W	PARTICIPANT	\N	PRESENT	0
446685	439814	14199E	PARTICIPANT	\N	PRESENT	0
446686	439814	14042U	PARTICIPANT	\N	PRESENT	0
446687	439814	08069G	PARTICIPANT	\N	PRESENT	0
446688	439814	19569H	PARTICIPANT	\N	PRESENT	0
446689	439814	19737F	PARTICIPANT	\N	PRESENT	0
446690	439814	08044W	PARTICIPANT	\N	PRESENT	0
446691	439814	14030Q	PARTICIPANT	\N	PRESENT	0
446692	439814	01048V	PARTICIPANT	\N	PRESENT	0
446693	439814	14205J	PARTICIPANT	\N	PRESENT	0
446694	439814	19691J	PARTICIPANT	\N	PRESENT	0
446695	439814	19521Q	PARTICIPANT	\N	PRESENT	0
446696	439814	14255U	PARTICIPANT	\N	PRESENT	0
446697	439814	14147R	PARTICIPANT	\N	PRESENT	0
446698	439814	19749K	PARTICIPANT	\N	PRESENT	0
446699	439814	98024R	PARTICIPANT	\N	PRESENT	0
446700	439814	14267Y	PARTICIPANT	\N	PRESENT	0
446701	439814	14105F	PARTICIPANT	\N	PRESENT	0
446702	439814	19826F	PARTICIPANT	\N	PRESENT	0
446703	439814	14193X	PARTICIPANT	\N	PRESENT	0
446704	439814	08056B	PARTICIPANT	\N	PRESENT	0
446705	439814	19685L	PARTICIPANT	\N	PRESENT	0
446706	439814	08061X	PARTICIPANT	\N	PRESENT	0
446707	439814	14079W	PARTICIPANT	\N	PRESENT	0
446708	439814	08068F	PARTICIPANT	\N	PRESENT	0
446709	439814	19531S	PARTICIPANT	\N	PRESENT	0
446710	439814	19413M	PARTICIPANT	\N	PRESENT	0
446711	439814	19447X	PARTICIPANT	\N	PRESENT	0
446712	439814	14217N	PARTICIPANT	\N	PRESENT	0
446713	439814	19489J	PARTICIPANT	\N	PRESENT	0
446714	439814	19747H	PARTICIPANT	\N	PRESENT	0
446715	439814	19671E	PARTICIPANT	\N	PRESENT	0
446716	439814	19621T	PARTICIPANT	\N	PRESENT	0
446717	439814	11048N	PARTICIPANT	\N	PRESENT	0
446718	439814	04033B	PARTICIPANT	\N	PRESENT	0
446719	439814	19762G	PARTICIPANT	\N	PRESENT	0
446720	439814	19383Y	PARTICIPANT	\N	PRESENT	0
446721	439814	14055N	PARTICIPANT	\N	PRESENT	0
446722	439814	19731Y	PARTICIPANT	\N	PRESENT	0
446723	439814	14261S	PARTICIPANT	\N	PRESENT	0
446724	439814	08031R	PARTICIPANT	\N	PRESENT	0
446725	439814	04070G	PARTICIPANT	\N	PRESENT	0
446726	439814	14215L	PARTICIPANT	\N	PRESENT	0
446727	439814	04043D	PARTICIPANT	\N	PRESENT	0
446728	439814	04088S	PARTICIPANT	\N	PRESENT	0
446729	439814	19673G	PARTICIPANT	\N	PRESENT	0
446730	439814	14235Q	PARTICIPANT	\N	PRESENT	0
446731	439814	19347U	PARTICIPANT	\N	PRESENT	0
446732	439814	19647E	PARTICIPANT	\N	PRESENT	0
446733	439814	14265W	PARTICIPANT	\N	PRESENT	0
446734	439814	19545Y	PARTICIPANT	\N	PRESENT	0
446735	439814	19693L	PARTICIPANT	\N	PRESENT	0
446736	439814	04040A	PARTICIPANT	\N	PRESENT	0
446737	439814	08010L	PARTICIPANT	\N	PRESENT	0
446738	439814	14331P	PARTICIPANT	\N	PRESENT	0
446739	439814	08039A	PARTICIPANT	\N	PRESENT	0
446740	439814	19782L	PARTICIPANT	\N	PRESENT	0
446741	439814	19812Y	PARTICIPANT	\N	PRESENT	0
446742	439814	04047H	PARTICIPANT	\N	PRESENT	0
446743	439814	11043H	PARTICIPANT	\N	PRESENT	0
446744	439814	01024M	PARTICIPANT	\N	PRESENT	0
446745	439814	95067Q	PARTICIPANT	\N	PRESENT	0
446746	439814	14197C	PARTICIPANT	\N	PRESENT	0
446747	439814	08053X	PARTICIPANT	\N	PRESENT	0
446748	439814	08049C	PARTICIPANT	\N	PRESENT	0
446749	439814	19551W	PARTICIPANT	\N	PRESENT	0
446750	439814	08015R	PARTICIPANT	\N	PRESENT	0
446659	439814	08024S	PARTICIPANT	\N	PRESENT	0
446660	439814	17637T	PARTICIPANT	\N	PRESENT	0
446751	439814	19611R	PARTICIPANT	\N	PRESENT	0
446752	439814	19758L	PARTICIPANT	\N	PRESENT	0
446753	439814	14021P	PARTICIPANT	\N	PRESENT	0
446754	439814	14121F	PARTICIPANT	\N	PRESENT	0
446755	439814	19563B	PARTICIPANT	\N	PRESENT	0
446756	439814	14083S	PARTICIPANT	\N	PRESENT	0
446757	439814	14031R	PARTICIPANT	\N	PRESENT	0
446758	439814	14135M	PARTICIPANT	\N	PRESENT	0
446759	439814	14357A	PARTICIPANT	\N	PRESENT	0
446760	439814	19798U	PARTICIPANT	\N	PRESENT	0
446761	439814	19669L	PARTICIPANT	\N	PRESENT	0
446762	439814	08045X	PARTICIPANT	\N	PRESENT	0
446763	439814	19349W	PARTICIPANT	\N	PRESENT	0
446764	439814	14119M	PARTICIPANT	\N	PRESENT	0
446765	439814	14179A	PARTICIPANT	\N	PRESENT	0
446766	439814	14034U	PARTICIPANT	\N	PRESENT	0
448285	448283	14038Y	PARTICIPANT	\N	PRESENT	0
448286	448283	18083K	PARTICIPANT	\N	PRESENT	0
448287	448283	19701S	PARTICIPANT	\N	PRESENT	0
448288	448283	11065P	PARTICIPANT	\N	PRESENT	0
448375	448371	08043V	PARTICIPANT	\N	PRESENT	0
448290	448283	02002K	PARTICIPANT	\N	PRESENT	0
448291	448283	19333N	PARTICIPANT	\N	PRESENT	0
448292	448283	14219Q	PARTICIPANT	\N	PRESENT	0
448293	448283	19637C	PARTICIPANT	\N	PRESENT	0
448294	448283	19794Q	PARTICIPANT	\N	PRESENT	0
448295	448283	19713W	PARTICIPANT	\N	PRESENT	0
448373	448371	08031R	PARTICIPANT	\N	PRESENT	0
448374	448371	19621T	PARTICIPANT	\N	PRESENT	0
448378	445170	14065Q	PARTICIPANT	\N	PRESENT	0
448379	445170	96004D	PRESIDENT	0	PRESENT	0
448380	445170	14089Y	PARTICIPANT	\N	PRESENT	0
448381	445170	14357A	PARTICIPANT	\N	PRESENT	0
448382	445170	11083R	PARTICIPANT	\N	PRESENT	0
448383	445170	14073Q	PARTICIPANT	\N	PRESENT	0
448384	445170	11026G	PARTICIPANT	\N	PRESENT	0
448386	445170	04057K	PARTICIPANT	\N	PRESENT	0
448387	445170	14237S	PARTICIPANT	\N	PRESENT	0
448388	445170	14331P	PARTICIPANT	\N	EXCUSE	0
426184	426125	08031R	PARTICIPANT	\N	PRESENT	0
426185	426125	08043V	PARTICIPANT	\N	PRESENT	0
426186	426125	14229S	PARTICIPANT	\N	PRESENT	0
426187	425346	14053L	PARTICIPANT	\N	PRESENT	0
426188	425346	19729F	PARTICIPANT	\N	PRESENT	0
426189	425346	08044W	PARTICIPANT	\N	PRESENT	0
426190	425346	04038G	PARTICIPANT	\N	PRESENT	0
426191	425346	19675J	PARTICIPANT	\N	PRESENT	0
426192	425346	05008E	PRESIDENT	0	PRESENT	0
426193	425346	19447X	PARTICIPANT	\N	PRESENT	0
426194	425346	19581D	PARTICIPANT	\N	EXCUSE	0
426195	425346	08018U	PARTICIPANT	\N	EXCUSE	0
426196	424936	04040A	PARTICIPANT	\N	PRESENT	0
426197	424936	08061X	PARTICIPANT	\N	PRESENT	0
426198	424936	08047A	PARTICIPANT	\N	PRESENT	0
426199	424936	98029W	PARTICIPANT	\N	PRESENT	0
426200	424936	04035D	PARTICIPANT	\N	PRESENT	0
426201	424936	19721W	PARTICIPANT	\N	PRESENT	0
426202	424936	98018T	PARTICIPANT	\N	EXCUSE	0
426203	424936	95030B	PARTICIPANT	\N	PRESENT	0
426204	424936	19669L	PARTICIPANT	\N	PRESENT	0
426205	424936	08058D	PARTICIPANT	\N	PRESENT	0
426206	426125	08017T	PARTICIPANT	\N	PRESENT	0
426207	426125	92040Q	PARTICIPANT	\N	PRESENT	0
426208	426125	07033P	PARTICIPANT	\N	PRESENT	0
426209	426125	08012N	PARTICIPANT	\N	PRESENT	0
426210	426125	14059S	PARTICIPANT	\N	PRESENT	0
426211	426125	19643A	PARTICIPANT	\N	PRESENT	0
426212	426125	19621T	PARTICIPANT	\N	PRESENT	0
426213	424936	11115U	PARTICIPANT	\N	PRESENT	0
426214	424936	14055N	PARTICIPANT	\N	PRESENT	0
426215	426125	19335Q	PARTICIPANT	\N	PRESENT	0
426216	426125	87003B	PARTICIPANT	\N	PRESENT	0
426217	426125	08020N	PARTICIPANT	\N	PRESENT	0
426218	426125	11083R	PARTICIPANT	\N	PRESENT	0
426219	426125	11043H	PARTICIPANT	\N	PRESENT	0
426220	426125	19758L	PARTICIPANT	\N	PRESENT	0
426221	425346	14001X	PARTICIPANT	\N	PRESENT	0
426222	425346	01060R	PARTICIPANT	\N	PRESENT	0
426223	425346	19543W	PARTICIPANT	\N	PRESENT	0
426224	425346	04044E	PARTICIPANT	\N	PRESENT	0
426225	425346	19585H	PARTICIPANT	\N	PRESENT	0
426226	425346	01028R	PARTICIPANT	\N	PRESENT	0
426227	425346	14231L	PARTICIPANT	\N	PRESENT	0
426228	425346	19489J	PARTICIPANT	\N	PRESENT	0
426229	425346	14041T	PARTICIPANT	\N	PRESENT	0
426230	425346	14147R	PARTICIPANT	\N	PRESENT	0
426231	425346	14215L	PARTICIPANT	\N	PRESENT	0
426232	425346	11072N	PARTICIPANT	\N	PRESENT	0
426233	425346	14065Q	PARTICIPANT	\N	PRESENT	0
426234	425346	08045X	PARTICIPANT	\N	PRESENT	0
426235	425346	10015M	PARTICIPANT	\N	PRESENT	0
426236	425346	19253P	PARTICIPANT	\N	PRESENT	0
426237	425346	01024M	PARTICIPANT	\N	PRESENT	0
426238	425346	19725B	PARTICIPANT	\N	PRESENT	0
426239	425346	95063L	PARTICIPANT	\N	PRESENT	0
426240	425346	19629C	PARTICIPANT	\N	PRESENT	0
426241	425346	14069U	PARTICIPANT	\N	PRESENT	0
426242	425346	11049P	PARTICIPANT	\N	PRESENT	0
426243	425346	14021P	PARTICIPANT	\N	PRESENT	0
426244	425346	19762G	PARTICIPANT	\N	PRESENT	0
426245	426125	19735D	PARTICIPANT	\N	PRESENT	0
426246	423925	19768N	PARTICIPANT	\N	PRESENT	0
426247	423925	19515S	PARTICIPANT	\N	PRESENT	0
426248	423925	19782L	PARTICIPANT	\N	PRESENT	0
426249	423925	11077T	PARTICIPANT	\N	PRESENT	0
426250	423925	14357A	PARTICIPANT	\N	PRESENT	0
426251	423925	19441R	PARTICIPANT	\N	PRESENT	0
426252	423925	19413M	PARTICIPANT	\N	PRESENT	0
426253	423925	80013X	PARTICIPANT	\N	PRESENT	0
426254	423925	19631V	PARTICIPANT	\N	PRESENT	0
426255	423925	11099A	PARTICIPANT	\N	PRESENT	0
426256	423925	08068F	PARTICIPANT	\N	PRESENT	0
426257	423925	04049K	PARTICIPANT	\N	PRESENT	0
426258	423925	19705W	PARTICIPANT	\N	PRESENT	0
426259	423925	08015R	PARTICIPANT	\N	PRESENT	0
426260	423925	08019V	PARTICIPANT	\N	PRESENT	0
426261	423925	14197C	PARTICIPANT	\N	PRESENT	0
426262	423925	19369B	PARTICIPANT	\N	PRESENT	0
426263	423925	19511N	PARTICIPANT	\N	PRESENT	0
426264	423925	08028W	PARTICIPANT	\N	PRESENT	0
426265	423925	19563B	PARTICIPANT	\N	PRESENT	0
426266	423925	14265W	PARTICIPANT	\N	PRESENT	0
426267	423925	14329V	PARTICIPANT	\N	PRESENT	0
426268	423925	19591F	PARTICIPANT	\N	PRESENT	0
426269	423925	14135M	PARTICIPANT	\N	PRESENT	0
426270	423925	19467C	PARTICIPANT	\N	PRESENT	0
426271	423925	14187A	PARTICIPANT	\N	PRESENT	0
426272	423925	08038Y	PARTICIPANT	\N	PRESENT	0
426273	423925	08062Y	PARTICIPANT	\N	PRESENT	0
426274	423925	19695N	PARTICIPANT	\N	PRESENT	0
426275	423925	14033T	PARTICIPANT	\N	PRESENT	0
426276	423925	11090Q	PRESIDENT	0	PRESENT	0
426277	423925	19295A	PARTICIPANT	\N	PRESENT	0
426278	423925	14205J	PARTICIPANT	\N	PRESENT	0
426279	423925	11056N	PARTICIPANT	\N	PRESENT	0
426280	423925	04089T	PARTICIPANT	\N	PRESENT	0
426281	423925	14115H	PARTICIPANT	\N	PRESENT	0
426282	423925	11101A	PARTICIPANT	\N	PRESENT	0
426283	423925	19507S	PARTICIPANT	\N	PRESENT	0
426284	423925	19747H	PARTICIPANT	\N	PRESENT	0
426285	423925	14207L	PARTICIPANT	\N	PRESENT	0
426286	423925	04043D	PARTICIPANT	\N	PRESENT	0
426287	423925	19619A	PARTICIPANT	\N	PRESENT	0
426288	423925	17589D	PARTICIPANT	\N	PRESENT	0
426289	423925	14257W	PARTICIPANT	\N	PRESENT	0
426290	423925	19812Y	PARTICIPANT	\N	EXCUSE	0
426291	423925	11081P	PARTICIPANT	\N	EXCUSE	0
426292	425346	14151M	PARTICIPANT	\N	PRESENT	0
426293	425346	11026G	PARTICIPANT	\N	PRESENT	0
426294	426125	04033B	PARTICIPANT	\N	PRESENT	0
426295	425346	19673G	PARTICIPANT	\N	PRESENT	0
426296	426125	14109K	PARTICIPANT	\N	PRESENT	0
426297	425346	14275Y	PARTICIPANT	\N	PRESENT	0
426298	425346	14111D	PARTICIPANT	\N	PRESENT	0
426299	426125	04057K	PARTICIPANT	\N	PRESENT	0
426300	426125	19693L	PARTICIPANT	\N	PRESENT	0
426301	424936	95037J	PARTICIPANT	\N	PRESENT	0
426302	426125	19749K	PARTICIPANT	\N	PRESENT	0
426303	423925	01043Q	PARTICIPANT	\N	PRESENT	0
426304	423925	14081Q	PARTICIPANT	\N	PRESENT	0
426305	425346	14259Y	PARTICIPANT	\N	PRESENT	0
426307	425100	04071H	PARTICIPANT	\N	PRESENT	0
426308	425100	11110B	PARTICIPANT	\N	PRESENT	0
426309	425100	11053K	PARTICIPANT	\N	PRESENT	0
426310	425346	14089Y	PARTICIPANT	\N	PRESENT	0
426312	425346	04047H	PARTICIPANT	\N	PRESENT	0
426313	424936	95067Q	PARTICIPANT	\N	PRESENT	0
426314	426125	14123H	PARTICIPANT	\N	PRESENT	0
426315	426125	19329S	PARTICIPANT	\N	PRESENT	0
426372	423926	19768N	PARTICIPANT	\N	PRESENT	0
426373	423926	19515S	PARTICIPANT	\N	PRESENT	0
426374	423926	19782L	PARTICIPANT	\N	PRESENT	0
426375	423926	11077T	PARTICIPANT	\N	PRESENT	0
426376	423926	01043Q	PARTICIPANT	\N	PRESENT	0
426377	423926	14357A	PARTICIPANT	\N	PRESENT	0
426378	423926	19441R	PARTICIPANT	\N	PRESENT	0
426379	423926	19413M	PARTICIPANT	\N	PRESENT	0
426380	423926	14081Q	PARTICIPANT	\N	PRESENT	0
426381	423926	80013X	PARTICIPANT	\N	PRESENT	0
426382	423926	19631V	PARTICIPANT	\N	PRESENT	0
426383	423926	11099A	PARTICIPANT	\N	PRESENT	0
426384	423926	08068F	PARTICIPANT	\N	PRESENT	0
426385	423926	04049K	PARTICIPANT	\N	PRESENT	0
426386	423926	19705W	PARTICIPANT	\N	PRESENT	0
426387	423926	08015R	PARTICIPANT	\N	PRESENT	0
426388	423926	08019V	PARTICIPANT	\N	PRESENT	0
426389	423926	14197C	PARTICIPANT	\N	PRESENT	0
426390	423926	19369B	PARTICIPANT	\N	PRESENT	0
426391	423926	19511N	PARTICIPANT	\N	PRESENT	0
426392	423926	08028W	PARTICIPANT	\N	PRESENT	0
426393	423926	19563B	PARTICIPANT	\N	PRESENT	0
426394	423926	14265W	PARTICIPANT	\N	PRESENT	0
426395	423926	14329V	PARTICIPANT	\N	PRESENT	0
426396	423926	19591F	PARTICIPANT	\N	PRESENT	0
426397	423926	14135M	PARTICIPANT	\N	PRESENT	0
426398	423926	19467C	PARTICIPANT	\N	PRESENT	0
426399	423926	14187A	PARTICIPANT	\N	PRESENT	0
426400	423926	08038Y	PARTICIPANT	\N	PRESENT	0
426401	423926	08062Y	PARTICIPANT	\N	PRESENT	0
426402	423926	19695N	PARTICIPANT	\N	PRESENT	0
426403	423926	14033T	PARTICIPANT	\N	PRESENT	0
426404	423926	11090Q	PRESIDENT	0	PRESENT	0
426405	423926	19295A	PARTICIPANT	\N	PRESENT	0
426406	423926	14205J	PARTICIPANT	\N	PRESENT	0
426407	423926	11056N	PARTICIPANT	\N	PRESENT	0
426408	423926	04089T	PARTICIPANT	\N	PRESENT	0
426409	423926	14115H	PARTICIPANT	\N	PRESENT	0
426410	423926	11101A	PARTICIPANT	\N	PRESENT	0
438688	436938	19583F	PARTICIPANT	\N	EXCUSE	0
438689	436938	14028W	PARTICIPANT	\N	EXCUSE	0
438690	436940	19583F	PARTICIPANT	\N	EXCUSE	0
438691	436940	14028W	PARTICIPANT	\N	EXCUSE	0
438693	436940	14193X	PARTICIPANT	\N	EXCUSE	0
438694	436938	14193X	PARTICIPANT	\N	EXCUSE	0
438711	438288	11067R	PARTICIPANT	\N	EXCUSE	0
438971	438492	11067R	PARTICIPANT	\N	EXCUSE	0
442297	439633	11097X	PARTICIPANT	\N	PRESENT	0
442298	439633	12041X	PARTICIPANT	\N	PRESENT	0
442299	439633	19758L	PARTICIPANT	\N	PRESENT	0
442300	439633	19760E	PARTICIPANT	\N	PRESENT	0
442301	439633	19593H	PARTICIPANT	\N	PRESENT	0
442302	439633	11077T	PARTICIPANT	\N	PRESENT	0
442303	439633	19565D	PARTICIPANT	\N	PRESENT	0
442304	439633	14227Q	PARTICIPANT	\N	PRESENT	0
442305	439633	14065Q	PARTICIPANT	\N	PRESENT	0
442306	439633	80013X	PARTICIPANT	\N	PRESENT	0
442307	439633	14051J	PARTICIPANT	\N	PRESENT	0
442308	439633	19503N	PARTICIPANT	\N	PRESENT	0
442309	439633	14081Q	PARTICIPANT	\N	PRESENT	0
442310	439633	19549D	PARTICIPANT	\N	PRESENT	0
442311	439633	11066Q	PARTICIPANT	\N	PRESENT	0
442312	439633	08043V	PARTICIPANT	\N	PRESENT	0
442313	439633	08060W	PARTICIPANT	\N	PRESENT	0
442314	439633	19669L	PARTICIPANT	\N	PRESENT	0
442315	439633	14021P	PARTICIPANT	\N	PRESENT	0
442316	439633	01028R	PARTICIPANT	\N	PRESENT	0
442317	439633	08052W	PARTICIPANT	\N	PRESENT	0
442318	439633	04085P	PARTICIPANT	\N	PRESENT	0
442319	439633	11031D	PARTICIPANT	\N	PRESENT	0
442320	439633	11026G	PARTICIPANT	\N	PRESENT	0
442321	439633	19727D	PARTICIPANT	\N	PRESENT	0
442322	439633	19697Q	PARTICIPANT	\N	PRESENT	0
442323	439633	19349W	PARTICIPANT	\N	PRESENT	0
442324	439633	19782L	PARTICIPANT	\N	PRESENT	0
442325	439633	14121F	PARTICIPANT	\N	PRESENT	0
442326	439633	11045K	PARTICIPANT	\N	PRESENT	0
442328	439633	14028W	PARTICIPANT	\N	PRESENT	0
442329	439633	19333N	PARTICIPANT	\N	PRESENT	0
442330	439633	19725B	PARTICIPANT	\N	PRESENT	0
442332	439633	19527W	PARTICIPANT	\N	PRESENT	0
442333	439633	19489J	PARTICIPANT	\N	PRESENT	0
442334	439633	14229S	PARTICIPANT	\N	PRESENT	0
442335	439633	11072N	PARTICIPANT	\N	PRESENT	0
442336	439633	19717B	PARTICIPANT	\N	PRESENT	0
442337	439633	19387D	PARTICIPANT	\N	PRESENT	0
442338	439633	11012A	PARTICIPANT	\N	PRESENT	0
442339	439633	08031R	PARTICIPANT	\N	PRESENT	0
442340	439633	14207L	PARTICIPANT	\N	PRESENT	0
442341	439633	17589D	PARTICIPANT	\N	PRESENT	0
442342	439633	14195A	PARTICIPANT	\N	PRESENT	0
442343	439633	08055A	PARTICIPANT	\N	PRESENT	0
442344	439633	19631V	PARTICIPANT	\N	PRESENT	0
442345	439633	19683J	PARTICIPANT	\N	PRESENT	0
442346	439633	14239U	PARTICIPANT	\N	PRESENT	0
442347	439633	19479G	PARTICIPANT	\N	PRESENT	0
442348	439633	14042U	PARTICIPANT	\N	PRESENT	0
442349	439633	08044W	PARTICIPANT	\N	PRESENT	0
442350	439633	19737F	PARTICIPANT	\N	PRESENT	0
442351	439633	19721W	PARTICIPANT	\N	PRESENT	0
442410	439633	01043Q	PARTICIPANT	\N	PRESENT	0
442353	439633	14221J	PARTICIPANT	\N	PRESENT	0
442354	439633	19739H	PARTICIPANT	\N	PRESENT	0
442355	439633	19521Q	PARTICIPANT	\N	PRESENT	0
442356	439633	01025N	PARTICIPANT	\N	PRESENT	0
442357	439633	19335Q	PARTICIPANT	\N	PRESENT	0
442358	439633	19745F	PARTICIPANT	\N	PRESENT	0
442359	439633	14087W	PARTICIPANT	\N	PRESENT	0
442360	439633	19798U	PARTICIPANT	\N	PRESENT	0
442361	439633	10006L	PARTICIPANT	\N	PRESENT	0
442362	439633	14217N	PARTICIPANT	\N	PRESENT	0
442363	439633	11103C	PARTICIPANT	\N	PRESENT	0
442364	439633	95030B	PARTICIPANT	\N	PRESENT	0
442365	439633	97011G	PARTICIPANT	\N	PRESENT	0
442366	439633	19383Y	PARTICIPANT	\N	PRESENT	0
442367	439633	19731Y	PARTICIPANT	\N	PRESENT	0
442368	439633	98024R	PARTICIPANT	\N	PRESENT	0
442295	439633	86034E	PARTICIPANT	\N	PRESENT	0
442296	439633	04092N	PARTICIPANT	\N	PRESENT	0
442369	439633	14187A	PARTICIPANT	\N	PRESENT	0
442370	439633	04033B	PARTICIPANT	\N	PRESENT	0
442371	439633	14071N	PARTICIPANT	\N	PRESENT	0
442372	439633	99004R	PARTICIPANT	\N	PRESENT	0
442373	439633	08039A	PARTICIPANT	\N	PRESENT	0
442374	439633	14223L	PARTICIPANT	\N	PRESENT	0
442375	439633	11043H	PARTICIPANT	\N	PRESENT	0
442376	439633	19575F	PARTICIPANT	\N	PRESENT	0
442377	439633	01057W	PARTICIPANT	\N	PRESENT	0
442378	439633	14157T	PARTICIPANT	\N	PRESENT	0
442379	439633	14033T	PARTICIPANT	\N	PRESENT	0
442380	439633	14135M	PARTICIPANT	\N	PRESENT	0
442381	439633	19399H	PARTICIPANT	\N	PRESENT	0
442382	439633	08062Y	PARTICIPANT	\N	PRESENT	0
442383	439633	14105F	PARTICIPANT	\N	PRESENT	0
442384	439633	08056B	PARTICIPANT	\N	PRESENT	0
442385	439633	87003B	PARTICIPANT	\N	PRESENT	0
442386	439633	04088S	PARTICIPANT	\N	PRESENT	0
442387	439633	18083K	PARTICIPANT	\N	PRESENT	0
442388	439633	19467C	PARTICIPANT	\N	PRESENT	0
442389	439633	19709B	PARTICIPANT	\N	PRESENT	0
442390	439633	14029X	PARTICIPANT	\N	PRESENT	0
442391	439633	19573D	PARTICIPANT	\N	PRESENT	0
442392	439633	14038Y	PARTICIPANT	\N	PRESENT	0
442393	439633	14173T	PARTICIPANT	\N	PRESENT	0
442394	439633	19703U	PARTICIPANT	\N	PRESENT	0
442395	439633	19679N	PARTICIPANT	\N	PRESENT	0
442396	439633	19715Y	PARTICIPANT	\N	PRESENT	0
442397	439633	17779H	PARTICIPANT	\N	PRESENT	0
442398	439633	19695N	PARTICIPANT	\N	PRESENT	0
442399	439633	11033F	PARTICIPANT	\N	PRESENT	0
442400	439633	11056N	PARTICIPANT	\N	PRESENT	0
442401	439633	19525U	PARTICIPANT	\N	PRESENT	0
442402	439633	19507S	PARTICIPANT	\N	PRESENT	0
442403	439633	19741B	PARTICIPANT	\N	PRESENT	0
442404	439633	19747H	PARTICIPANT	\N	PRESENT	0
442405	439633	14215L	PARTICIPANT	\N	PRESENT	0
442406	439633	19251M	PARTICIPANT	\N	PRESENT	0
442407	439633	19647E	PARTICIPANT	\N	PRESENT	0
442408	439633	08045X	PARTICIPANT	\N	PRESENT	0
442409	439633	01034P	PARTICIPANT	\N	PRESENT	0
442411	439633	14030Q	PARTICIPANT	\N	PRESENT	0
442412	439633	14205J	PARTICIPANT	\N	PRESENT	0
442413	439633	08038Y	PARTICIPANT	\N	PRESENT	0
442414	439633	19415P	PARTICIPANT	\N	PRESENT	0
442415	439633	14213J	PARTICIPANT	\N	PRESENT	0
442416	439633	19413M	PARTICIPANT	\N	PRESENT	0
442417	439633	11027H	PARTICIPANT	\N	PRESENT	0
442418	439633	04086Q	PARTICIPANT	\N	PRESENT	0
442419	439633	14225N	PARTICIPANT	\N	PRESENT	0
442420	439633	14083S	PARTICIPANT	\N	PRESENT	0
442421	439633	14251Q	PARTICIPANT	\N	PRESENT	0
442422	439633	19347U	PARTICIPANT	\N	PRESENT	0
442423	439633	08015R	PARTICIPANT	\N	PRESENT	0
442424	439633	14026U	PARTICIPANT	\N	PRESENT	0
442425	439633	19729F	PARTICIPANT	\N	PRESENT	0
442426	439633	04049K	PARTICIPANT	\N	PRESENT	0
442427	439633	08048B	PARTICIPANT	\N	PRESENT	0
442428	439633	14265W	PARTICIPANT	\N	PRESENT	0
442429	439633	01048V	PARTICIPANT	\N	PRESENT	0
442430	439633	14267Y	PARTICIPANT	\N	PRESENT	0
442431	439633	19551W	PARTICIPANT	\N	PRESENT	0
442432	439633	19253P	PARTICIPANT	\N	PRESENT	0
442433	441619	19649G	PARTICIPANT	\N	PRESENT	0
442434	441619	14065Q	PARTICIPANT	\N	PRESENT	0
442435	441619	19569H	PARTICIPANT	\N	PRESENT	0
442436	441619	11045K	PARTICIPANT	\N	PRESENT	0
442437	441619	08052W	PARTICIPANT	\N	PRESENT	0
442438	441619	08043V	PARTICIPANT	\N	PRESENT	0
442439	441619	11066Q	PARTICIPANT	\N	PRESENT	0
442440	441619	19447X	PARTICIPANT	\N	PRESENT	0
442441	441619	18083K	PARTICIPANT	\N	PRESENT	0
442442	441619	14042U	PARTICIPANT	\N	PRESENT	0
442443	441619	14195A	PARTICIPANT	\N	PRESENT	0
442444	441619	19575F	PARTICIPANT	\N	PRESENT	0
442445	441619	14213J	PARTICIPANT	\N	PRESENT	0
442446	441619	99004R	PARTICIPANT	\N	PRESENT	0
442447	441619	14215L	PARTICIPANT	\N	PRESENT	0
442448	441619	19683J	PARTICIPANT	\N	PRESENT	0
429151	429148	04086Q	PARTICIPANT	\N	PRESENT	0
429152	429148	08052W	PARTICIPANT	\N	PRESENT	0
429153	429148	11074Q	PARTICIPANT	\N	PRESENT	0
429154	429148	14034U	PARTICIPANT	\N	PRESENT	0
429155	429148	19697Q	PARTICIPANT	\N	PRESENT	0
429156	429148	14251Q	PARTICIPANT	\N	PRESENT	0
429157	429148	11085T	PARTICIPANT	\N	PRESENT	0
429158	429148	04092N	PARTICIPANT	\N	PRESENT	0
429159	429148	08011M	PARTICIPANT	\N	PRESENT	0
429160	429148	11090Q	PARTICIPANT	\N	PRESENT	0
429161	429148	11012A	PARTICIPANT	\N	PRESENT	0
429162	429148	04033B	PARTICIPANT	\N	PRESENT	0
429163	429148	01034P	PARTICIPANT	\N	PRESENT	0
430728	427797	14089Y	PARTICIPANT	\N	PRESENT	0
430729	427797	08014Q	PARTICIPANT	\N	PRESENT	0
430730	427797	14357A	PARTICIPANT	\N	PRESENT	0
430731	427797	14079W	PARTICIPANT	\N	PRESENT	0
430732	427797	11083R	PARTICIPANT	\N	PRESENT	0
430733	427797	04097T	PARTICIPANT	\N	PRESENT	0
430734	427797	14097Y	PARTICIPANT	\N	PRESENT	0
430735	427797	11026G	PARTICIPANT	\N	PRESENT	0
430736	427797	14001X	PARTICIPANT	\N	PRESENT	0
430737	427797	14331P	PARTICIPANT	\N	PRESENT	0
430738	427797	96004D	PRESIDENT	0	PRESENT	0
430739	427797	14061L	PARTICIPANT	\N	EXCUSE	0
430740	427797	14065Q	PARTICIPANT	\N	EXCUSE	0
430741	427797	04057K	PARTICIPANT	\N	EXCUSE	0
430742	427797	10015M	PARTICIPANT	\N	EXCUSE	0
431688	431687	08060W	PARTICIPANT	\N	PRESENT	0
431689	431687	08009T	PRESIDENT	0	PRESENT	0
431690	431687	19367Y	PARTICIPANT	\N	PRESENT	0
431691	431687	19758L	PARTICIPANT	\N	PRESENT	0
431692	431687	14051J	PARTICIPANT	\N	EXCUSE	0
431694	431693	19447X	PARTICIPANT	\N	PRESENT	0
431695	430767	19447X	PARTICIPANT	\N	PRESENT	0
431696	430767	19729F	PARTICIPANT	\N	EXCUSE	0
431697	430767	04047H	PARTICIPANT	\N	EXCUSE	0
431698	431693	14147R	PARTICIPANT	\N	PRESENT	0
431700	431693	14179A	PARTICIPANT	\N	PRESENT	0
431702	431693	14215L	PRESIDENT	0	PRESENT	0
431703	431693	19729F	PARTICIPANT	\N	EXCUSE	0
431704	431693	04047H	PARTICIPANT	\N	EXCUSE	0
431705	431693	04038G	PARTICIPANT	\N	PRESENT	0
431706	431693	05008E	PARTICIPANT	\N	PRESENT	0
431707	431693	14001X	PARTICIPANT	\N	PRESENT	0
431708	431693	19585H	PARTICIPANT	\N	PRESENT	0
431709	431693	01028R	PARTICIPANT	\N	PRESENT	0
431710	431693	14111D	PARTICIPANT	\N	PRESENT	0
431711	431693	10015M	PARTICIPANT	\N	PRESENT	0
431712	431693	01024M	PARTICIPANT	\N	PRESENT	0
431713	431693	98035U	PARTICIPANT	\N	PRESENT	0
431715	431693	14089Y	PARTICIPANT	\N	PRESENT	0
431716	431693	11010L	PARTICIPANT	\N	PRESENT	0
431717	431693	19762G	PARTICIPANT	\N	PRESENT	0
431718	431693	04044E	PARTICIPANT	\N	PRESENT	0
431719	431693	14259Y	PARTICIPANT	\N	PRESENT	0
431720	431687	19413M	PARTICIPANT	\N	PRESENT	0
431721	431687	19251M	PARTICIPANT	\N	PRESENT	0
431722	431687	14033T	PARTICIPANT	\N	PRESENT	0
431729	431728	98029W	PARTICIPANT	\N	PRESENT	0
431730	425265	86034E	PARTICIPANT	\N	PRESENT	0
431732	425265	04045F	PARTICIPANT	\N	PRESENT	0
431733	425265	14021P	PARTICIPANT	\N	PRESENT	0
431734	425265	08045X	PARTICIPANT	\N	PRESENT	0
431735	425265	19669L	PARTICIPANT	\N	PRESENT	0
431736	425265	14039A	PARTICIPANT	\N	PRESENT	0
431737	425265	19681G	PARTICIPANT	\N	PRESENT	0
431738	425265	14267Y	PARTICIPANT	\N	PRESENT	0
431739	425265	14073Q	PARTICIPANT	\N	PRESENT	0
431740	425265	19713W	PARTICIPANT	\N	PRESENT	0
431741	425265	14042U	PARTICIPANT	\N	PRESENT	0
431742	425265	19826F	PARTICIPANT	\N	PRESENT	0
431743	425265	19549D	PARTICIPANT	\N	PRESENT	0
431744	425265	19525U	PARTICIPANT	\N	PRESENT	0
431747	425265	08014Q	PARTICIPANT	\N	PRESENT	0
431748	425265	19333N	PARTICIPANT	\N	PRESENT	0
431749	425265	11109J	PARTICIPANT	\N	PRESENT	0
431750	425265	11074Q	PARTICIPANT	\N	PRESENT	0
431751	425265	08011M	PARTICIPANT	\N	PRESENT	0
431752	425265	19711U	PARTICIPANT	\N	PRESENT	0
431754	425265	19741B	PARTICIPANT	\N	PRESENT	0
431755	425265	14029X	PARTICIPANT	\N	PRESENT	0
431756	425265	19709B	PARTICIPANT	\N	PRESENT	0
431757	425265	19663E	PARTICIPANT	\N	PRESENT	0
431758	425265	07029T	PARTICIPANT	\N	PRESENT	0
431759	425265	11040E	PARTICIPANT	\N	PRESENT	0
431760	425265	11056N	PARTICIPANT	\N	PRESENT	0
431761	425265	19729F	PARTICIPANT	\N	PRESENT	0
431762	425265	11031D	PARTICIPANT	\N	PRESENT	0
431763	425265	08062Y	PARTICIPANT	\N	PRESENT	0
431764	425265	08015R	PARTICIPANT	\N	PRESENT	0
431765	425265	04085P	PARTICIPANT	\N	PRESENT	0
431766	425265	19593H	PARTICIPANT	\N	PRESENT	0
431767	425265	08034U	PARTICIPANT	\N	PRESENT	0
431768	425265	19347U	PARTICIPANT	\N	PRESENT	0
431769	425265	19687N	PARTICIPANT	\N	PRESENT	0
431771	425265	11077T	PARTICIPANT	\N	PRESENT	0
431772	425265	95037J	PARTICIPANT	\N	PRESENT	0
431773	425265	19697Q	PARTICIPANT	\N	PRESENT	0
431774	425265	19812Y	PARTICIPANT	\N	PRESENT	0
431775	425265	14239U	PARTICIPANT	\N	PRESENT	0
431776	425265	19651A	PARTICIPANT	\N	PRESENT	0
431777	425265	98029W	PARTICIPANT	\N	PRESENT	0
431778	425265	08031R	PARTICIPANT	\N	PRESENT	0
431779	425265	11012A	PARTICIPANT	\N	PRESENT	0
431780	425265	14261S	PARTICIPANT	\N	PRESENT	0
431781	425265	14241N	PARTICIPANT	\N	PRESENT	0
431782	425265	19387D	PARTICIPANT	\N	PRESENT	0
431783	425265	14061L	PARTICIPANT	\N	PRESENT	0
431784	425265	19289C	PARTICIPANT	\N	PRESENT	0
431785	425265	19723Y	PARTICIPANT	\N	PRESENT	0
431786	425265	19507S	PARTICIPANT	\N	PRESENT	0
431787	425265	18083K	PARTICIPANT	\N	PRESENT	0
431788	425265	19467C	PARTICIPANT	\N	PRESENT	0
431789	425265	04088S	PARTICIPANT	\N	PRESENT	0
431790	425265	19553Y	PARTICIPANT	\N	PRESENT	0
431791	425265	14135M	PARTICIPANT	\N	PRESENT	0
431792	425265	19629C	PARTICIPANT	\N	PRESENT	0
431793	425265	19399H	PARTICIPANT	\N	PRESENT	0
431794	425265	19585H	PARTICIPANT	\N	PRESENT	0
431795	425265	19693L	PARTICIPANT	\N	PRESENT	0
431796	425265	19583F	PARTICIPANT	\N	PRESENT	0
431797	425265	14213J	PARTICIPANT	\N	PRESENT	0
431798	425265	14357A	PARTICIPANT	\N	PRESENT	0
431799	425265	01028R	PARTICIPANT	\N	PRESENT	0
431800	425265	19383Y	PARTICIPANT	\N	PRESENT	0
431801	425265	08068F	PARTICIPANT	\N	PRESENT	0
431802	425265	19701S	PARTICIPANT	\N	PRESENT	0
431803	425265	19599P	PARTICIPANT	\N	PRESENT	0
431804	425265	04018C	PARTICIPANT	\N	PRESENT	0
431805	425265	12016W	PARTICIPANT	\N	PRESENT	0
431806	425265	19649G	PARTICIPANT	\N	PRESENT	0
431807	425265	19647E	PARTICIPANT	\N	PRESENT	0
431808	425265	14197C	PARTICIPANT	\N	PRESENT	0
431809	425265	19820Y	PARTICIPANT	\N	PRESENT	0
431810	425265	14225N	PARTICIPANT	\N	PRESENT	0
431811	425265	19671E	PARTICIPANT	\N	PRESENT	0
431812	425265	08058D	PARTICIPANT	\N	PRESENT	0
431813	425265	19581D	PARTICIPANT	\N	PRESENT	0
431814	425265	14085U	PARTICIPANT	\N	PRESENT	0
431815	425265	14227Q	PARTICIPANT	\N	PRESENT	0
431816	425265	14079W	PARTICIPANT	\N	PRESENT	0
431817	425265	11104D	PARTICIPANT	\N	PRESENT	0
431825	425265	97011G	PARTICIPANT	\N	PRESENT	0
431819	425265	19689Q	PARTICIPANT	\N	PRESENT	0
431820	425265	04069P	PARTICIPANT	\N	PRESENT	0
431821	425265	14217N	PARTICIPANT	\N	PRESENT	0
431822	425265	14257W	PARTICIPANT	\N	PRESENT	0
431823	425265	14331P	PARTICIPANT	\N	PRESENT	0
431824	425265	14109K	PARTICIPANT	\N	PRESENT	0
431826	425265	19725B	PARTICIPANT	\N	PRESENT	0
431827	425265	14147R	PARTICIPANT	\N	PRESENT	0
431828	425265	19301E	PARTICIPANT	\N	PRESENT	0
431829	425265	14105F	PARTICIPANT	\N	PRESENT	0
431830	425265	14115H	PARTICIPANT	\N	PRESENT	0
431831	425265	14081Q	PARTICIPANT	\N	PRESENT	0
431832	425265	08019V	PARTICIPANT	\N	PRESENT	0
431833	425265	14119M	PARTICIPANT	\N	PRESENT	0
431834	425265	19794Q	PARTICIPANT	\N	PRESENT	0
431835	425265	14195A	PARTICIPANT	\N	PRESENT	0
431836	425265	19573D	PARTICIPANT	\N	PRESENT	0
431837	425265	11064N	PARTICIPANT	\N	PRESENT	0
431838	425265	11010L	PARTICIPANT	\N	PRESENT	0
431839	425265	19479G	PARTICIPANT	\N	PRESENT	0
431840	425265	14031R	PARTICIPANT	\N	PRESENT	0
431841	425265	19735D	PARTICIPANT	\N	PRESENT	0
431842	425265	19619A	PARTICIPANT	\N	PRESENT	0
435779	428524	08045X	PARTICIPANT	\N	PRESENT	0
435889	435888	95067Q	PARTICIPANT	\N	PRESENT	0
435890	435888	97011G	PARTICIPANT	\N	PRESENT	0
435891	435888	14179A	PARTICIPANT	\N	PRESENT	0
435892	435888	19575F	PARTICIPANT	\N	PRESENT	0
435893	435888	14237S	PARTICIPANT	\N	PRESENT	0
435895	435894	19629C	PARTICIPANT	\N	PRESENT	0
435896	435894	19383Y	PARTICIPANT	\N	PRESENT	0
435897	435894	14237S	PARTICIPANT	\N	PRESENT	0
448297	448296	04008A	PARTICIPANT	\N	PRESENT	0
448298	448296	19585H	PARTICIPANT	\N	PRESENT	0
448389	445170	14225N	PARTICIPANT	\N	EXCUSE	0
448390	445170	14061L	PARTICIPANT	\N	EXCUSE	0
448391	445170	08018U	PARTICIPANT	\N	EXCUSE	0
448392	445170	14241N	PARTICIPANT	\N	EXCUSE	0
448393	441793	14069U	PARTICIPANT	\N	PRESENT	0
448394	441793	19525U	PARTICIPANT	\N	PRESENT	0
448395	441793	14231L	PARTICIPANT	\N	PRESENT	0
448396	441793	05012A	PARTICIPANT	\N	PRESENT	0
448397	441793	04045F	PARTICIPANT	\N	PRESENT	0
448398	441793	95063L	PARTICIPANT	\N	PRESENT	0
448399	441793	19735D	PARTICIPANT	\N	PRESENT	0
448487	448486	14257W	PARTICIPANT	\N	PRESENT	0
448488	448486	19768N	PARTICIPANT	\N	PRESENT	0
448489	448486	14205J	PARTICIPANT	\N	PRESENT	0
448492	445988	04043D	PARTICIPANT	\N	PRESENT	0
448493	445988	19593H	PARTICIPANT	\N	PRESENT	0
448497	448496	19515S	PARTICIPANT	\N	PRESENT	0
448498	448496	04088S	PARTICIPANT	\N	PRESENT	0
448501	445988	11099A	PARTICIPANT	\N	PRESENT	0
448503	445988	19709B	PARTICIPANT	\N	EXCUSE	0
448552	445988	14299H	PARTICIPANT	\N	EXCUSE	0
448559	437906	08024S	PARTICIPANT	\N	PRESENT	0
448618	448617	98050T	PARTICIPANT	\N	PRESENT	0
448619	448617	14267Y	PARTICIPANT	\N	PRESENT	0
448628	446079	11074Q	PARTICIPANT	\N	PRESENT	0
448629	446079	88008L	PARTICIPANT	\N	PRESENT	0
448630	446079	19745F	PARTICIPANT	\N	PRESENT	0
448631	446079	04043D	PARTICIPANT	\N	PRESENT	0
448729	448728	11115U	PARTICIPANT	\N	PRESENT	0
448810	448809	89017R	PARTICIPANT	\N	PRESENT	0
448811	448809	04085P	PARTICIPANT	\N	PRESENT	0
448812	448809	04059M	PARTICIPANT	\N	PRESENT	0
448813	448809	05008E	PARTICIPANT	\N	PRESENT	0
448814	448809	96004D	PARTICIPANT	\N	PRESENT	0
448815	448809	14038Y	PARTICIPANT	\N	PRESENT	0
448816	448809	88008L	PARTICIPANT	\N	PRESENT	0
448817	448809	11027H	PARTICIPANT	\N	PRESENT	0
448818	448809	14079W	PARTICIPANT	\N	PRESENT	0
448819	448809	07033P	PARTICIPANT	\N	PRESENT	0
448820	448809	14187A	PARTICIPANT	\N	PRESENT	0
448821	448809	01043Q	PARTICIPANT	\N	PRESENT	0
448822	448809	14205J	PARTICIPANT	\N	PRESENT	0
448823	448809	14251Q	PARTICIPANT	\N	PRESENT	0
448824	448809	11085T	PARTICIPANT	\N	PRESENT	0
448825	448809	04092N	PARTICIPANT	\N	PRESENT	0
448826	448809	98018T	PARTICIPANT	\N	PRESENT	0
448827	448809	05012A	PARTICIPANT	\N	PRESENT	0
448828	448809	11012A	PARTICIPANT	\N	PRESENT	0
448829	448809	01028R	PARTICIPANT	\N	PRESENT	0
448830	448623	08049C	PARTICIPANT	\N	EXCUSE	0
448831	448623	04044E	PARTICIPANT	\N	EXCUSE	0
448832	448623	04040A	PRESIDENT	0	PRESENT	0
448834	448833	04038G	PARTICIPANT	\N	PRESENT	0
448835	448833	14199E	PARTICIPANT	\N	PRESENT	0
448838	448836	14267Y	PARTICIPANT	\N	PRESENT	0
448840	448836	11054L	PARTICIPANT	\N	PRESENT	0
448842	448836	08047A	PARTICIPANT	\N	PRESENT	0
448843	448836	01058X	PARTICIPANT	\N	PRESENT	0
448845	448844	80013X	PARTICIPANT	\N	PRESENT	0
448848	448847	08034U	PARTICIPANT	\N	PRESENT	0
448854	444822	19399H	PARTICIPANT	\N	PRESENT	0
448855	439821	04059M	PARTICIPANT	\N	PRESENT	0
448858	448857	19599P	PARTICIPANT	\N	PRESENT	0
448859	448857	14157T	PARTICIPANT	\N	PRESENT	0
448860	448857	19681G	PARTICIPANT	\N	PRESENT	0
448861	448857	19820Y	PARTICIPANT	\N	PRESENT	0
448862	448857	14083S	PARTICIPANT	\N	PRESENT	0
448863	448857	08045X	PARTICIPANT	\N	PRESENT	0
448864	448857	14051J	PARTICIPANT	\N	PRESENT	0
448865	439821	19683J	PARTICIPANT	\N	PRESENT	0
448866	439821	19731Y	PARTICIPANT	\N	PRESENT	0
448867	439821	11067R	PARTICIPANT	\N	PRESENT	0
448868	439821	19569H	PARTICIPANT	\N	PRESENT	0
448869	439821	11031D	PARTICIPANT	\N	PRESENT	0
448871	448870	19599P	PARTICIPANT	\N	PRESENT	0
448873	448870	14157T	PARTICIPANT	\N	PRESENT	0
448874	448870	14083S	PARTICIPANT	\N	PRESENT	0
448875	448849	14001X	PARTICIPANT	\N	PRESENT	0
448876	448849	04044E	PARTICIPANT	\N	PRESENT	0
448877	448849	19585H	PARTICIPANT	\N	PRESENT	0
448878	448849	19675J	PARTICIPANT	\N	PRESENT	0
448879	448849	01028R	PARTICIPANT	\N	PRESENT	0
448880	448849	05008E	PRESIDENT	0	PRESENT	0
448881	448849	14231L	PARTICIPANT	\N	PRESENT	0
448882	448849	19447X	PARTICIPANT	\N	PRESENT	0
448883	448849	19489J	PARTICIPANT	\N	PRESENT	0
448884	448849	14147R	PARTICIPANT	\N	PRESENT	0
448885	448849	14151M	PARTICIPANT	\N	PRESENT	0
448886	448849	14215L	PARTICIPANT	\N	PRESENT	0
448887	448849	08018U	PARTICIPANT	\N	PRESENT	0
448888	448849	14053L	PARTICIPANT	\N	PRESENT	0
448889	448849	98035U	PARTICIPANT	\N	PRESENT	0
448890	448849	19649G	PARTICIPANT	\N	PRESENT	0
448891	448849	14111D	PARTICIPANT	\N	PRESENT	0
448892	448849	11010L	PARTICIPANT	\N	PRESENT	0
448893	448849	10015M	PARTICIPANT	\N	PRESENT	0
448894	448849	08045X	PARTICIPANT	\N	PRESENT	0
448895	448849	11026G	PARTICIPANT	\N	PRESENT	0
448896	448849	01024M	PARTICIPANT	\N	PRESENT	0
448897	448849	04038G	PARTICIPANT	\N	PRESENT	0
448898	448849	19719D	PARTICIPANT	\N	PRESENT	0
448899	448849	14089Y	PARTICIPANT	\N	PRESENT	0
448900	448849	95063L	PARTICIPANT	\N	PRESENT	0
448901	448849	19629C	PARTICIPANT	\N	PRESENT	0
448902	448849	08044W	PARTICIPANT	\N	PRESENT	0
448903	448849	14021P	PARTICIPANT	\N	PRESENT	0
448904	439821	19611R	PARTICIPANT	\N	PRESENT	0
448905	439821	14195A	PARTICIPANT	\N	PRESENT	0
448906	439821	14042U	PARTICIPANT	\N	PRESENT	0
448907	439821	19685L	PARTICIPANT	\N	PRESENT	0
448908	439821	08034U	PARTICIPANT	\N	PRESENT	0
448909	439821	11103C	PARTICIPANT	\N	PRESENT	0
448910	439821	95030B	PARTICIPANT	\N	PRESENT	0
448911	439821	19415P	PARTICIPANT	\N	PRESENT	0
448912	439821	14267Y	PARTICIPANT	\N	PRESENT	0
448913	439821	18083K	PARTICIPANT	\N	PRESENT	0
448914	439821	01025N	PARTICIPANT	\N	PRESENT	0
448915	439821	19599P	PARTICIPANT	\N	PRESENT	0
448916	439821	14031R	PARTICIPANT	\N	PRESENT	0
448917	439821	19399H	PARTICIPANT	\N	PRESENT	0
448918	439821	14079W	PARTICIPANT	\N	PRESENT	0
448919	439821	14038Y	PARTICIPANT	\N	PRESENT	0
448920	439821	04088S	PARTICIPANT	\N	PRESENT	0
448921	439821	19387D	PARTICIPANT	\N	PRESENT	0
448922	439821	19671E	PARTICIPANT	\N	PRESENT	0
448923	439821	14251Q	PARTICIPANT	\N	PRESENT	0
448924	439821	15447F	PARTICIPANT	\N	PRESENT	0
448925	439821	14103D	PARTICIPANT	\N	PRESENT	0
448926	439821	19545Y	PARTICIPANT	\N	PRESENT	0
448927	439821	04092N	PARTICIPANT	\N	PRESENT	0
448928	439821	08055A	PARTICIPANT	\N	PRESENT	0
448929	439821	19713W	PARTICIPANT	\N	PRESENT	0
448930	439821	14217N	PARTICIPANT	\N	PRESENT	0
448931	439821	14065Q	PARTICIPANT	\N	PRESENT	0
448932	439821	19820Y	PARTICIPANT	\N	PRESENT	0
448933	439821	14051J	PARTICIPANT	\N	PRESENT	0
448934	439821	19333N	PARTICIPANT	\N	PRESENT	0
448935	439821	14063N	PARTICIPANT	\N	PRESENT	0
448936	439821	19543W	PARTICIPANT	\N	PRESENT	0
448937	439821	14239U	PARTICIPANT	\N	PRESENT	0
448938	439821	04045F	PARTICIPANT	\N	PRESENT	0
448971	439821	19521Q	PARTICIPANT	\N	PRESENT	0
424964	424962	14071N	PARTICIPANT	\N	PRESENT	0
424965	424963	14071N	PARTICIPANT	\N	PRESENT	0
424966	424961	14071N	PARTICIPANT	\N	PRESENT	0
426411	423926	19507S	PARTICIPANT	\N	PRESENT	0
424980	424978	19521Q	PARTICIPANT	\N	PRESENT	0
424981	424978	14087W	PARTICIPANT	\N	PRESENT	0
426412	423926	19747H	PARTICIPANT	\N	PRESENT	0
426413	423926	14207L	PARTICIPANT	\N	PRESENT	0
426414	423926	04043D	PARTICIPANT	\N	PRESENT	0
426415	423926	19619A	PARTICIPANT	\N	PRESENT	0
426416	423926	17589D	PARTICIPANT	\N	PRESENT	0
426417	423926	14257W	PARTICIPANT	\N	PRESENT	0
426418	423926	19812Y	PARTICIPANT	\N	EXCUSE	0
426419	423926	11081P	PARTICIPANT	\N	EXCUSE	0
426468	423947	19543W	PARTICIPANT	\N	PRESENT	0
426469	423947	14231L	PARTICIPANT	\N	PRESENT	0
426470	423947	14001X	PARTICIPANT	\N	PRESENT	0
426472	426471	14231L	PARTICIPANT	\N	PRESENT	0
426473	426471	14179A	PARTICIPANT	\N	PRESENT	0
426568	426123	14021P	PARTICIPANT	\N	PRESENT	0
426570	422994	14059S	PARTICIPANT	\N	EXCUSE	0
426571	422994	14135M	PARTICIPANT	\N	EXCUSE	0
426572	422994	19659J	PARTICIPANT	\N	EXCUSE	0
426573	422994	11010L	PARTICIPANT	\N	EXCUSE	0
426574	422995	96004D	PARTICIPANT	\N	EXCUSE	0
426575	422995	14059S	PARTICIPANT	\N	EXCUSE	0
426576	422995	11054L	PARTICIPANT	\N	EXCUSE	0
426577	422995	19319Q	PARTICIPANT	\N	EXCUSE	0
426578	422993	11054L	PARTICIPANT	\N	EXCUSE	0
426579	422993	19659J	PARTICIPANT	\N	EXCUSE	0
428355	428354	04042C	PARTICIPANT	\N	PRESENT	0
428357	428356	04042C	PARTICIPANT	\N	PRESENT	0
428487	428233	04070G	PARTICIPANT	\N	PRESENT	0
428488	428233	11048N	PARTICIPANT	\N	PRESENT	0
428489	428233	08060W	PARTICIPANT	\N	PRESENT	0
428490	428233	08009T	PRESIDENT	0	PRESENT	0
428491	428233	19367Y	PARTICIPANT	\N	PRESENT	0
428492	428233	11065P	PARTICIPANT	\N	PRESENT	0
428493	428233	14051J	PARTICIPANT	\N	EXCUSE	0
428494	428233	19758L	PARTICIPANT	\N	PRESENT	0
428683	428199	19349W	PARTICIPANT	\N	PRESENT	0
428684	428199	08014Q	PARTICIPANT	\N	PRESENT	0
428685	428199	08034U	PARTICIPANT	\N	PRESENT	0
428686	428199	19545Y	PARTICIPANT	\N	PRESENT	0
428687	428199	11074Q	PRESIDENT	1	PRESENT	0
428688	428199	14085U	PARTICIPANT	\N	PRESENT	0
428689	428199	08010L	PARTICIPANT	\N	PRESENT	0
428690	428199	08011M	PARTICIPANT	\N	PRESENT	0
428693	428199	07029T	PARTICIPANT	\N	PRESENT	0
428694	428199	12016W	PARTICIPANT	\N	PRESENT	0
428695	428199	14083S	PARTICIPANT	\N	PRESENT	0
428706	428705	14229S	PARTICIPANT	\N	PRESENT	0
428707	428705	08043V	PARTICIPANT	\N	PRESENT	0
428708	428705	19399H	PARTICIPANT	\N	PRESENT	0
428709	428705	08031R	PARTICIPANT	\N	PRESENT	0
428710	428705	19735D	PARTICIPANT	\N	PRESENT	0
428716	428199	14121F	PARTICIPANT	\N	PRESENT	0
428816	416367	19737F	PARTICIPANT	\N	PRESENT	0
428817	416367	19253P	PARTICIPANT	\N	PRESENT	0
428818	416367	19349W	PARTICIPANT	\N	PRESENT	0
428819	416367	14261S	PARTICIPANT	\N	PRESENT	0
428820	416367	19713W	PARTICIPANT	\N	PRESENT	0
428821	416367	14042U	PARTICIPANT	\N	PRESENT	0
428822	416367	19585H	PARTICIPANT	\N	PRESENT	0
428823	416367	19629C	PARTICIPANT	\N	PRESENT	0
428824	416367	19679N	PARTICIPANT	\N	PRESENT	0
428825	416367	14195A	PARTICIPANT	\N	PRESENT	0
428826	416367	10015M	PARTICIPANT	\N	PRESENT	0
428828	428199	11097X	PARTICIPANT	\N	PRESENT	0
428829	416367	14087W	PARTICIPANT	\N	PRESENT	0
428830	428234	08060W	PARTICIPANT	\N	PRESENT	0
428831	428234	08009T	PRESIDENT	0	PRESENT	0
428832	428234	19367Y	PARTICIPANT	\N	PRESENT	0
428833	428234	19758L	PARTICIPANT	\N	PRESENT	0
428834	416367	14041T	PARTICIPANT	\N	PRESENT	0
428835	416367	17583W	PARTICIPANT	\N	PRESENT	0
428836	416367	04088S	PARTICIPANT	\N	PRESENT	0
428837	416367	14079W	PARTICIPANT	\N	PRESENT	0
428838	416367	14213J	PARTICIPANT	\N	PRESENT	0
428839	416367	14157T	PARTICIPANT	\N	PRESENT	0
428840	416367	08062Y	PARTICIPANT	\N	PRESENT	0
428841	416367	19794Q	PARTICIPANT	\N	PRESENT	0
428842	416367	19703U	PARTICIPANT	\N	PRESENT	0
428843	416367	19573D	PARTICIPANT	\N	PRESENT	0
428844	416367	19443T	PARTICIPANT	\N	PRESENT	0
428847	416367	18083K	PARTICIPANT	\N	PRESENT	0
428850	416367	14211G	PARTICIPANT	\N	PRESENT	0
428851	416367	19289C	PARTICIPANT	\N	PRESENT	0
428852	416367	14187A	PARTICIPANT	\N	PRESENT	0
428853	428234	14026U	PARTICIPANT	\N	PRESENT	0
428854	416367	11103C	PARTICIPANT	\N	PRESENT	0
428855	428199	19531S	PARTICIPANT	\N	PRESENT	0
428856	416367	19467C	PARTICIPANT	\N	PRESENT	0
428857	416367	19335Q	PARTICIPANT	\N	PRESENT	0
428858	416367	19581D	PARTICIPANT	\N	PRESENT	0
428352	428286	04042C	PARTICIPANT	\N	PRESENT	0
428353	428286	07033P	PARTICIPANT	\N	PRESENT	0
428859	428234	04070G	PARTICIPANT	\N	EXCUSE	0
428860	428234	11048N	PARTICIPANT	\N	EXCUSE	0
428861	428234	14051J	PARTICIPANT	\N	EXCUSE	0
428862	416367	14179A	PARTICIPANT	\N	PRESENT	0
428863	416367	19551W	PARTICIPANT	\N	PRESENT	0
428864	416367	14089Y	PARTICIPANT	\N	PRESENT	0
428865	416367	19251M	PARTICIPANT	\N	PRESENT	0
428866	416367	14073Q	PARTICIPANT	\N	PRESENT	0
428867	416367	04085P	PARTICIPANT	\N	PRESENT	0
428868	428199	14225N	PARTICIPANT	\N	PRESENT	0
428869	416367	14030Q	PARTICIPANT	\N	PRESENT	0
428870	416367	08019V	PARTICIPANT	\N	PRESENT	0
428872	416367	98050T	PARTICIPANT	\N	PRESENT	0
428873	416367	19533U	PARTICIPANT	\N	PRESENT	0
428874	416367	19599P	PARTICIPANT	\N	PRESENT	0
428875	416367	19681G	PARTICIPANT	\N	PRESENT	0
428877	416367	19521Q	PARTICIPANT	\N	PRESENT	0
428878	416367	14281W	PARTICIPANT	\N	PRESENT	0
428879	416367	19820Y	PARTICIPANT	\N	PRESENT	0
428880	428234	14093U	PARTICIPANT	\N	PRESENT	0
428881	428234	19413M	PRESIDENT	1	PRESENT	0
428882	416367	08039A	PARTICIPANT	\N	PRESENT	0
428883	416367	14123H	PARTICIPANT	\N	PRESENT	0
428884	416367	08028W	PARTICIPANT	\N	PRESENT	0
428885	416367	12041X	PARTICIPANT	\N	PRESENT	0
428886	416367	14147R	PARTICIPANT	\N	PRESENT	0
428887	416367	14038Y	PARTICIPANT	\N	PRESENT	0
428888	416367	14135M	PARTICIPANT	\N	PRESENT	0
428889	416367	08069G	PARTICIPANT	\N	PRESENT	0
428890	416367	98022P	PARTICIPANT	\N	PRESENT	0
428891	416367	19745F	PARTICIPANT	\N	PRESENT	0
428921	427858	19515S	PARTICIPANT	\N	PRESENT	0
428922	427858	01058X	PARTICIPANT	\N	PRESENT	0
428923	427858	08068F	PARTICIPANT	\N	PRESENT	0
428924	427858	08015R	PARTICIPANT	\N	PRESENT	0
428925	416367	01025N	PARTICIPANT	\N	PRESENT	0
428926	428234	19251M	PARTICIPANT	\N	PRESENT	0
428927	428234	95067Q	PARTICIPANT	\N	PRESENT	0
428928	416367	19549D	PARTICIPANT	\N	PRESENT	0
428929	416367	14221J	PARTICIPANT	\N	PRESENT	0
428930	416367	14119M	PARTICIPANT	\N	PRESENT	0
428931	416367	14059S	PARTICIPANT	\N	PRESENT	0
428932	416367	14071N	PARTICIPANT	\N	PRESENT	0
428933	416367	11104D	PARTICIPANT	\N	PRESENT	0
428934	416367	19727D	PARTICIPANT	\N	PRESENT	0
428935	416367	08031R	PARTICIPANT	\N	PRESENT	0
428936	416367	14223L	PARTICIPANT	\N	PRESENT	0
428937	416367	95030B	PARTICIPANT	\N	PRESENT	0
428938	427858	19421M	PARTICIPANT	\N	PRESENT	0
428939	427858	11101A	PARTICIPANT	\N	PRESENT	0
428940	427858	19747H	PARTICIPANT	\N	PRESENT	0
442578	439634	19333N	PARTICIPANT	\N	PRESENT	0
442579	439634	11066Q	PARTICIPANT	\N	PRESENT	0
442580	439634	08045X	PARTICIPANT	\N	PRESENT	0
442581	439634	98029W	PARTICIPANT	\N	PRESENT	0
442582	439634	19545Y	PARTICIPANT	\N	PRESENT	0
442583	439634	19387D	PARTICIPANT	\N	PRESENT	0
442584	439634	01028R	PARTICIPANT	\N	PRESENT	0
442585	439634	14030Q	PARTICIPANT	\N	PRESENT	0
442586	439634	14231L	PARTICIPANT	\N	PRESENT	0
442587	439634	95030B	PARTICIPANT	\N	PRESENT	0
442588	439634	14105F	PARTICIPANT	\N	PRESENT	0
442589	439634	14069U	PARTICIPANT	\N	PRESENT	0
442590	439634	14157T	PARTICIPANT	\N	PRESENT	0
442591	439634	19565D	PARTICIPANT	\N	PRESENT	0
442592	439634	14281W	PARTICIPANT	\N	PRESENT	0
442593	439634	14053L	PARTICIPANT	\N	PRESENT	0
442594	439634	14331P	PARTICIPANT	\N	PRESENT	0
442595	439634	14179A	PARTICIPANT	\N	PRESENT	0
442596	439634	19739H	PARTICIPANT	\N	PRESENT	0
442597	439634	04033B	PARTICIPANT	\N	PRESENT	0
442598	439634	19349W	PARTICIPANT	\N	PRESENT	0
442599	439634	19413M	PARTICIPANT	\N	PRESENT	0
442600	439634	14187A	PARTICIPANT	\N	PRESENT	0
442601	439634	19729F	PARTICIPANT	\N	PRESENT	0
442602	439634	14033T	PARTICIPANT	\N	PRESENT	0
442603	439634	14083S	PARTICIPANT	\N	PRESENT	0
442604	439634	14241N	PARTICIPANT	\N	PRESENT	0
442605	439634	19621T	PARTICIPANT	\N	PRESENT	0
442606	439634	19531S	PARTICIPANT	\N	PRESENT	0
442607	439634	19507S	PARTICIPANT	\N	PRESENT	0
442608	439634	19383Y	PARTICIPANT	\N	PRESENT	0
442609	439634	11043H	PARTICIPANT	\N	PRESENT	0
442610	439634	19679N	PARTICIPANT	\N	PRESENT	0
442611	439634	01024M	PARTICIPANT	\N	PRESENT	0
442612	439634	19741B	PARTICIPANT	\N	PRESENT	0
442613	439634	19760E	PARTICIPANT	\N	PRESENT	0
442614	439634	17637T	PARTICIPANT	\N	PRESENT	0
442615	439634	08034U	PARTICIPANT	\N	PRESENT	0
442616	441619	04092N	PARTICIPANT	\N	PRESENT	0
442617	441619	08034U	PARTICIPANT	\N	PRESENT	0
442618	441619	19415P	PARTICIPANT	\N	PRESENT	0
442619	441619	05008E	PARTICIPANT	\N	PRESENT	0
442620	441619	19553Y	PARTICIPANT	\N	PRESENT	0
442621	441619	14179A	PARTICIPANT	\N	PRESENT	0
442622	441619	19335Q	PARTICIPANT	\N	PRESENT	0
442623	441619	10006L	PARTICIPANT	\N	PRESENT	0
442624	441619	11072N	PARTICIPANT	\N	PRESENT	0
442869	441590	08058D	PARTICIPANT	\N	EXCUSE	0
442870	441590	14097Y	PARTICIPANT	\N	EXCUSE	0
442871	441590	19583F	PARTICIPANT	\N	EXCUSE	0
442872	441590	08053X	PARTICIPANT	\N	EXCUSE	0
442873	441590	19319Q	PARTICIPANT	\N	EXCUSE	0
442874	441590	14235Q	PARTICIPANT	\N	EXCUSE	0
442875	441590	19443T	PARTICIPANT	\N	EXCUSE	0
442909	439637	19729F	PARTICIPANT	\N	PRESENT	0
442910	439637	19768N	PARTICIPANT	\N	PRESENT	0
442911	439637	19705W	PARTICIPANT	\N	PRESENT	0
442912	439637	14059S	PARTICIPANT	\N	PRESENT	0
442913	439637	19467C	PARTICIPANT	\N	PRESENT	0
442914	439637	18083K	PARTICIPANT	\N	PRESENT	0
442915	439637	19415P	PARTICIPANT	\N	PRESENT	0
442916	439637	19709B	PARTICIPANT	\N	PRESENT	0
442917	439637	14033T	PARTICIPANT	\N	PRESENT	0
442918	439637	19399H	PARTICIPANT	\N	PRESENT	0
442919	439637	14265W	PARTICIPANT	\N	PRESENT	0
442920	439637	14213J	PARTICIPANT	\N	PRESENT	0
442921	439637	14329V	PARTICIPANT	\N	PRESENT	0
442922	439637	14357A	PARTICIPANT	\N	PRESENT	0
442923	439637	19675J	PARTICIPANT	\N	PRESENT	0
442924	439637	19762G	PARTICIPANT	\N	PRESENT	0
442925	439637	19383Y	PARTICIPANT	\N	PRESENT	0
442926	439637	98050T	PARTICIPANT	\N	PRESENT	0
442927	439637	04018C	PARTICIPANT	\N	PRESENT	0
442928	439637	19621T	PARTICIPANT	\N	PRESENT	0
442929	439637	19367Y	PARTICIPANT	\N	PRESENT	0
442930	439637	14173T	PARTICIPANT	\N	PRESENT	0
442931	439637	19447X	PARTICIPANT	\N	PRESENT	0
442932	439637	19573D	PARTICIPANT	\N	PRESENT	0
442933	439637	19794Q	PARTICIPANT	\N	PRESENT	0
442934	439637	14133K	PARTICIPANT	\N	PRESENT	0
442935	439637	14119M	PARTICIPANT	\N	PRESENT	0
442936	439637	11049P	PARTICIPANT	\N	PRESENT	0
442937	439637	08047A	PARTICIPANT	\N	PRESENT	0
442938	439637	17583W	PARTICIPANT	\N	PRESENT	0
442939	439637	14147R	PARTICIPANT	\N	PRESENT	0
442940	439637	97011G	PARTICIPANT	\N	PRESENT	0
442941	439637	14105F	PARTICIPANT	\N	PRESENT	0
442942	439637	11103C	PARTICIPANT	\N	PRESENT	0
442943	439637	07033P	PARTICIPANT	\N	PRESENT	0
442944	439637	04069P	PARTICIPANT	\N	PRESENT	0
442945	439637	14331P	PARTICIPANT	\N	PRESENT	0
442946	439637	14217N	PARTICIPANT	\N	PRESENT	0
442947	439637	19703U	PARTICIPANT	\N	PRESENT	0
442948	439637	19673G	PARTICIPANT	\N	PRESENT	0
442949	439637	14031R	PARTICIPANT	\N	PRESENT	0
442950	439637	14199E	PARTICIPANT	\N	PRESENT	0
442951	439637	11048N	PARTICIPANT	\N	PRESENT	0
442952	439637	05012A	PARTICIPANT	\N	PRESENT	0
442953	439637	08034U	PARTICIPANT	\N	PRESENT	0
442954	439637	19533U	PARTICIPANT	\N	PRESENT	0
442955	439637	10006L	PARTICIPANT	\N	PRESENT	0
442956	439637	19798U	PARTICIPANT	\N	PRESENT	0
442957	439637	14193X	PARTICIPANT	\N	PRESENT	0
442958	439637	19515S	PARTICIPANT	\N	PRESENT	0
442959	439637	14191V	PARTICIPANT	\N	PRESENT	0
442960	439637	11080N	PARTICIPANT	\N	PRESENT	0
442961	439637	19766L	PARTICIPANT	\N	PRESENT	0
442962	439637	01057W	PARTICIPANT	\N	PRESENT	0
442963	439637	87003B	PARTICIPANT	\N	PRESENT	0
442964	439637	11090Q	PARTICIPANT	\N	PRESENT	0
442965	439637	04043D	PARTICIPANT	\N	PRESENT	0
442966	439637	14215L	PARTICIPANT	\N	PRESENT	0
442967	439637	15447F	PARTICIPANT	\N	PRESENT	0
442968	439637	19643A	PARTICIPANT	\N	PRESENT	0
442969	439637	14223L	PARTICIPANT	\N	PRESENT	0
442970	439637	11043H	PARTICIPANT	\N	PRESENT	0
442971	439637	01048V	PARTICIPANT	\N	PRESENT	0
442972	439637	08028W	PARTICIPANT	\N	PRESENT	0
442576	439634	04044E	PARTICIPANT	\N	PRESENT	0
442577	439634	19758L	PARTICIPANT	\N	PRESENT	0
442973	439637	04033B	PARTICIPANT	\N	PRESENT	0
442974	439637	14187A	PARTICIPANT	\N	PRESENT	0
442975	439637	14071N	PARTICIPANT	\N	PRESENT	0
442976	439637	05008E	PARTICIPANT	\N	PRESENT	0
442977	439637	11097X	PARTICIPANT	\N	PRESENT	0
442978	439637	19421M	PARTICIPANT	\N	PRESENT	0
442979	439637	08069G	PARTICIPANT	\N	PRESENT	0
442980	439637	04042C	PARTICIPANT	\N	PRESENT	0
442981	439637	04086Q	PARTICIPANT	\N	PRESENT	0
442982	439637	04092N	PARTICIPANT	\N	PRESENT	0
442983	439637	99004R	PARTICIPANT	\N	PRESENT	0
442984	439637	95030B	PARTICIPANT	\N	PRESENT	0
442985	439637	14026U	PARTICIPANT	\N	PRESENT	0
442986	439637	04035D	PARTICIPANT	\N	PRESENT	0
442987	439637	98024R	PARTICIPANT	\N	PRESENT	0
442988	439637	11101A	PARTICIPANT	\N	PRESENT	0
442989	439637	17637T	PARTICIPANT	\N	PRESENT	0
442990	439637	86034E	PARTICIPANT	\N	PRESENT	0
442991	439637	95067Q	PARTICIPANT	\N	PRESENT	0
442992	439637	19760E	PARTICIPANT	\N	PRESENT	0
442993	439637	04085P	PARTICIPANT	\N	PRESENT	0
442994	439637	11033F	PARTICIPANT	\N	PRESENT	0
442995	439637	11040E	PARTICIPANT	\N	PRESENT	0
442996	439637	19758L	PARTICIPANT	\N	PRESENT	0
442997	439637	11031D	PARTICIPANT	\N	PRESENT	0
442998	439637	11056N	PARTICIPANT	\N	PRESENT	0
442999	439637	19695N	PARTICIPANT	\N	PRESENT	0
443000	439637	19347U	PARTICIPANT	\N	PRESENT	0
443001	439637	19565D	PARTICIPANT	\N	PRESENT	0
443002	439637	12041X	PARTICIPANT	\N	PRESENT	0
443003	439637	11077T	PARTICIPANT	\N	PRESENT	0
443004	439637	19593H	PARTICIPANT	\N	PRESENT	0
443005	439637	19687N	PARTICIPANT	\N	PRESENT	0
443006	439637	14239U	PARTICIPANT	\N	PRESENT	0
443007	439637	08056B	PARTICIPANT	\N	PRESENT	0
443008	439637	19685L	PARTICIPANT	\N	PRESENT	0
443009	439637	01060R	PARTICIPANT	\N	PRESENT	0
443513	441620	19575F	PARTICIPANT	\N	PRESENT	0
443514	441620	11067R	PARTICIPANT	\N	EXCUSE	0
443519	439638	14042U	PARTICIPANT	\N	PRESENT	0
443520	439638	19415P	PARTICIPANT	\N	PRESENT	0
443521	439638	11101A	PARTICIPANT	\N	PRESENT	0
443522	439638	19673G	PARTICIPANT	\N	PRESENT	0
443523	439638	99004R	PARTICIPANT	\N	PRESENT	0
443524	439638	08044W	PARTICIPANT	\N	PRESENT	0
443525	439638	19741B	PARTICIPANT	\N	PRESENT	0
443526	439638	14249W	PARTICIPANT	\N	PRESENT	0
443527	439638	11012A	PARTICIPANT	\N	PRESENT	0
443528	439638	19333N	PARTICIPANT	\N	PRESENT	0
430358	416369	19573D	PARTICIPANT	\N	PRESENT	0
430359	416369	19758L	PARTICIPANT	\N	PRESENT	0
430360	416369	19565D	PARTICIPANT	\N	PRESENT	0
430361	416369	19826F	PARTICIPANT	\N	PRESENT	0
430362	416369	19760E	PARTICIPANT	\N	PRESENT	0
430363	416369	19715Y	PARTICIPANT	\N	PRESENT	0
430412	416375	04085P	PARTICIPANT	\N	PRESENT	0
430413	416375	11031D	PARTICIPANT	\N	PRESENT	0
430414	416375	14191V	PARTICIPANT	\N	PRESENT	0
430415	416375	19599P	PARTICIPANT	\N	PRESENT	0
430416	416375	14265W	PARTICIPANT	\N	PRESENT	0
430417	416375	14147R	PARTICIPANT	\N	PRESENT	0
430418	416375	95030B	PARTICIPANT	\N	PRESENT	0
430419	416375	14225N	PARTICIPANT	\N	PRESENT	0
430420	416375	19637C	PARTICIPANT	\N	PRESENT	0
430421	416375	11110B	PARTICIPANT	\N	PRESENT	0
430422	416375	19715Y	PARTICIPANT	\N	PRESENT	0
430423	416375	19551W	PARTICIPANT	\N	PRESENT	0
430424	416375	19760E	PARTICIPANT	\N	PRESENT	0
430425	416375	19758L	PARTICIPANT	\N	PRESENT	0
430426	416375	19565D	PARTICIPANT	\N	PRESENT	0
430427	416375	19820Y	PARTICIPANT	\N	PRESENT	0
430428	416375	19253P	PARTICIPANT	\N	PRESENT	0
430429	416375	19553Y	PARTICIPANT	\N	PRESENT	0
430430	416375	19711U	PARTICIPANT	\N	PRESENT	0
430431	416375	14038Y	PARTICIPANT	\N	PRESENT	0
430432	416375	19415P	PARTICIPANT	\N	PRESENT	0
430433	416375	14219Q	PARTICIPANT	\N	PRESENT	0
430434	416375	19347U	PARTICIPANT	\N	PRESENT	0
430443	416375	04088S	PARTICIPANT	\N	PRESENT	0
430444	416375	14033T	PARTICIPANT	\N	PRESENT	0
430445	416375	14073Q	PARTICIPANT	\N	PRESENT	0
430446	416375	19413M	PARTICIPANT	\N	PRESENT	0
430447	416375	19333N	PARTICIPANT	\N	PRESENT	0
430448	416375	19812Y	PARTICIPANT	\N	PRESENT	0
430449	416375	14021P	PARTICIPANT	\N	PRESENT	0
430531	430530	14239U	PARTICIPANT	\N	PRESENT	0
430532	430530	04040A	PARTICIPANT	\N	PRESENT	0
430533	430530	19647E	PARTICIPANT	\N	PRESENT	0
430541	430530	10015M	PARTICIPANT	\N	PRESENT	0
430811	423006	11097X	PARTICIPANT	\N	PRESENT	0
430814	423006	08062Y	PARTICIPANT	\N	PRESENT	0
430816	423006	08024S	PARTICIPANT	\N	EXCUSE	0
430817	423006	11066Q	PARTICIPANT	\N	EXCUSE	0
430820	423006	19667J	PARTICIPANT	\N	EXCUSE	0
430821	423006	19421M	PARTICIPANT	\N	EXCUSE	0
430410	416375	04044E	PARTICIPANT	\N	PRESENT	0
430411	416375	11056N	PARTICIPANT	\N	PRESENT	0
430831	423006	19467C	PARTICIPANT	\N	PRESENT	0
430832	423006	89017R	PARTICIPANT	\N	EXCUSE	0
431699	423006	19629C	PARTICIPANT	\N	EXCUSE	0
431701	423006	14107H	PARTICIPANT	\N	PRESENT	0
431724	423006	01028R	PARTICIPANT	\N	EXCUSE	0
431725	423006	08012N	PARTICIPANT	\N	EXCUSE	0
431726	423006	19349W	PARTICIPANT	\N	PRESENT	0
431843	425265	08010L	PARTICIPANT	\N	PRESENT	0
431844	425265	19721W	PARTICIPANT	\N	PRESENT	0
431845	425265	19737F	PARTICIPANT	\N	PRESENT	0
431846	425265	19667J	PARTICIPANT	\N	PRESENT	0
431847	425265	11103C	PARTICIPANT	\N	PRESENT	0
431848	425265	11070L	PARTICIPANT	\N	PRESENT	0
431849	425265	19565D	PARTICIPANT	\N	PRESENT	0
431850	425265	19533U	PARTICIPANT	\N	PRESENT	0
431851	425265	19798U	PARTICIPANT	\N	PRESENT	0
431852	425265	10006L	PARTICIPANT	\N	PRESENT	0
431853	425265	14215L	PARTICIPANT	\N	PRESENT	0
431854	425265	01058X	PARTICIPANT	\N	PRESENT	0
431855	425265	14121F	PARTICIPANT	\N	PRESENT	0
431856	425265	19441R	PARTICIPANT	\N	PRESENT	0
431857	425265	14251Q	PARTICIPANT	\N	PRESENT	0
431858	425265	11090Q	PARTICIPANT	\N	PRESENT	0
431859	425265	19577H	PARTICIPANT	\N	PRESENT	0
431860	425265	19745F	PARTICIPANT	\N	PRESENT	0
431861	425265	01057W	PARTICIPANT	\N	PRESENT	0
431862	425265	14071N	PARTICIPANT	\N	PRESENT	0
431863	425265	19515S	PARTICIPANT	\N	PRESENT	0
431864	425265	15447F	PARTICIPANT	\N	PRESENT	0
431865	425265	10015M	PARTICIPANT	\N	PRESENT	0
431866	425265	11043H	PARTICIPANT	\N	PRESENT	0
431867	425265	08028W	PARTICIPANT	\N	PRESENT	0
431868	425265	14187A	PARTICIPANT	\N	PRESENT	0
428232	428231	01024M	PARTICIPANT	\N	PRESENT	0
430355	416369	08024S	PARTICIPANT	\N	PRESENT	0
431869	425265	11097X	PARTICIPANT	\N	PRESENT	0
431870	425265	19421M	PARTICIPANT	\N	PRESENT	0
431871	425265	19747H	PARTICIPANT	\N	PRESENT	0
431872	425265	08053X	PARTICIPANT	\N	PRESENT	0
431873	425265	04086Q	PARTICIPANT	\N	PRESENT	0
431874	425265	99004R	PARTICIPANT	\N	PRESENT	0
431875	425265	19251M	PARTICIPANT	\N	PRESENT	0
431876	425265	08020N	PARTICIPANT	\N	PRESENT	0
431877	425265	04097T	PARTICIPANT	\N	PRESENT	0
431878	425265	04035D	PARTICIPANT	\N	PRESENT	0
431879	425265	04044E	PARTICIPANT	\N	PRESENT	0
431880	425265	14030Q	PARTICIPANT	\N	PRESENT	0
431881	425265	01043Q	PARTICIPANT	\N	PRESENT	0
431882	425265	14327T	PARTICIPANT	\N	PRESENT	0
431883	425265	07004J	PARTICIPANT	\N	PRESENT	0
431884	425265	08056B	PARTICIPANT	\N	PRESENT	0
431885	425265	14259Y	PARTICIPANT	\N	PRESENT	0
431886	425265	14231L	PARTICIPANT	\N	PRESENT	0
431887	431731	04070G	PARTICIPANT	\N	PRESENT	0
431888	431731	08060W	PARTICIPANT	\N	PRESENT	0
431889	431731	08009T	PRESIDENT	0	PRESENT	0
431890	431731	19367Y	PARTICIPANT	\N	PRESENT	0
431891	431731	14033T	PARTICIPANT	\N	PRESENT	0
431892	431731	19826F	PARTICIPANT	\N	PRESENT	0
431893	431731	19758L	PARTICIPANT	\N	PRESENT	0
431894	431731	14051J	PARTICIPANT	\N	EXCUSE	0
431974	423006	08045X	PARTICIPANT	\N	PRESENT	0
431975	425265	11054L	PARTICIPANT	\N	PRESENT	0
431976	425265	19253P	PARTICIPANT	\N	PRESENT	0
431977	425265	19675J	PARTICIPANT	\N	PRESENT	0
432028	423006	19713W	PARTICIPANT	\N	PRESENT	0
431985	425265	14265W	PARTICIPANT	\N	PRESENT	0
432027	423006	19569H	PARTICIPANT	\N	EXCUSE	0
432069	430768	14065Q	PARTICIPANT	\N	PRESENT	0
432070	430768	01024M	PARTICIPANT	\N	PRESENT	0
432071	430768	14231L	PARTICIPANT	\N	PRESENT	0
432072	430768	05008E	PRESIDENT	0	PRESENT	0
432073	430843	14031R	PARTICIPANT	\N	PRESENT	0
432074	425265	08039A	PARTICIPANT	\N	PRESENT	0
432077	425265	14249W	PARTICIPANT	\N	PRESENT	0
432079	425265	19679N	PARTICIPANT	\N	PRESENT	0
432081	430768	01028R	PARTICIPANT	\N	PRESENT	0
432087	432086	14087W	PARTICIPANT	\N	PRESENT	0
432088	432086	19521Q	PARTICIPANT	\N	PRESENT	0
432089	432086	19679N	PARTICIPANT	\N	PRESENT	0
432092	432091	14087W	PARTICIPANT	\N	PRESENT	0
432093	432091	19521Q	PARTICIPANT	\N	PRESENT	0
432094	432091	19679N	PARTICIPANT	\N	PRESENT	0
432100	432099	19521Q	PARTICIPANT	\N	PRESENT	0
432103	432099	19679N	PARTICIPANT	\N	PRESENT	0
432105	425265	08055A	PARTICIPANT	\N	PRESENT	0
432106	432085	19479G	PARTICIPANT	\N	PRESENT	0
432107	432085	04071H	PARTICIPANT	\N	PRESENT	0
432108	432085	19647E	PARTICIPANT	\N	PRESENT	0
432109	432085	19711U	PARTICIPANT	\N	PRESENT	0
432110	432085	19651A	PARTICIPANT	\N	PRESENT	0
432111	432085	19687N	PARTICIPANT	\N	PRESENT	0
432112	432085	11074Q	PRESIDENT	0	PRESENT	0
432113	432085	08011M	PARTICIPANT	\N	PRESENT	0
432114	432085	14173T	PARTICIPANT	\N	PRESENT	0
432115	432085	11040E	PARTICIPANT	\N	PRESENT	0
432116	432085	04086Q	PARTICIPANT	\N	PRESENT	0
432117	432085	14083S	PARTICIPANT	\N	PRESENT	0
432118	432085	07029T	PARTICIPANT	\N	PRESENT	0
432119	432085	11012A	PARTICIPANT	\N	PRESENT	0
432120	432085	14085U	PARTICIPANT	\N	PRESENT	0
432121	432085	14121F	PARTICIPANT	\N	PRESENT	0
432228	432126	19479G	PARTICIPANT	\N	PRESENT	0
432229	425275	19413M	PARTICIPANT	\N	PRESENT	0
432230	425275	14085U	PARTICIPANT	\N	PRESENT	0
432231	425275	19651A	PARTICIPANT	\N	PRESENT	0
432232	425275	11040E	PARTICIPANT	\N	PRESENT	0
432233	425275	19758L	PARTICIPANT	\N	PRESENT	0
432234	425275	19565D	PARTICIPANT	\N	PRESENT	0
432235	425275	19349W	PARTICIPANT	\N	PRESENT	0
432236	425275	19545Y	PARTICIPANT	\N	PRESENT	0
432237	425275	14021P	PARTICIPANT	\N	PRESENT	0
432238	425275	11064N	PARTICIPANT	\N	PRESENT	0
432239	425275	14081Q	PARTICIPANT	\N	PRESENT	0
432240	425275	14107H	PARTICIPANT	\N	PRESENT	0
432241	425275	14121F	PARTICIPANT	\N	PRESENT	0
432242	425275	19681G	PARTICIPANT	\N	PRESENT	0
432243	425275	19631V	PARTICIPANT	\N	PRESENT	0
432244	425275	11012A	PARTICIPANT	\N	PRESENT	0
432245	425275	01034P	PARTICIPANT	\N	PRESENT	0
432246	425275	19826F	PARTICIPANT	\N	PRESENT	0
448972	439821	19679N	PARTICIPANT	\N	PRESENT	0
448973	439821	04033B	PARTICIPANT	\N	PRESENT	0
448974	439821	19737F	PARTICIPANT	\N	PRESENT	0
448975	439821	14028W	PARTICIPANT	\N	PRESENT	0
448976	439821	11085T	PARTICIPANT	\N	PRESENT	0
448977	439821	19503N	PARTICIPANT	\N	PRESENT	0
448978	447581	14097Y	PARTICIPANT	\N	PRESENT	0
448979	447581	11080N	PARTICIPANT	\N	PRESENT	0
448980	447581	14187A	PARTICIPANT	\N	PRESENT	0
448981	447581	11026G	PARTICIPANT	\N	PRESENT	0
448982	447581	04040A	PARTICIPANT	\N	PRESENT	0
448983	447581	04044E	PARTICIPANT	\N	PRESENT	0
448984	447581	19669L	PARTICIPANT	\N	PRESENT	0
448985	447581	19585H	PARTICIPANT	\N	PRESENT	0
448986	447581	19671E	PARTICIPANT	\N	PRESENT	0
448987	447581	19673G	PARTICIPANT	\N	PRESENT	0
448988	447581	19719D	PRESIDENT	0	PRESENT	0
448989	447581	19721W	PARTICIPANT	\N	PRESENT	0
448990	447581	08056B	PARTICIPANT	\N	PRESENT	0
448991	447581	19421M	PARTICIPANT	\N	PRESENT	0
448992	447581	07004J	PARTICIPANT	\N	PRESENT	0
448993	447581	08010L	PARTICIPANT	\N	PRESENT	0
448994	447581	08053X	PARTICIPANT	\N	PRESENT	0
448995	439821	19447X	PARTICIPANT	\N	PRESENT	0
448996	439821	19443T	PARTICIPANT	\N	PRESENT	0
448997	447583	08010L	PARTICIPANT	\N	EXCUSE	0
448998	439821	19729F	PARTICIPANT	\N	PRESENT	0
448999	439821	19723Y	PARTICIPANT	\N	PRESENT	0
449001	439821	19629C	PARTICIPANT	\N	PRESENT	0
449002	439821	14053L	PARTICIPANT	\N	PRESENT	0
449003	448849	14179A	PARTICIPANT	\N	PRESENT	0
449004	448849	14259Y	PARTICIPANT	\N	PRESENT	0
449005	439821	14329V	PARTICIPANT	\N	PRESENT	0
449006	439821	10006L	PARTICIPANT	\N	PRESENT	0
449049	449046	19631V	PARTICIPANT	\N	PRESENT	0
449008	439821	19711U	PARTICIPANT	\N	PRESENT	0
449009	439821	14179A	PARTICIPANT	\N	PRESENT	0
449010	439821	08044W	PARTICIPANT	\N	PRESENT	0
449047	449046	14257W	PARTICIPANT	\N	PRESENT	0
449048	449046	19768N	PARTICIPANT	\N	PRESENT	0
449060	439821	19741B	PARTICIPANT	\N	PRESENT	0
449061	439821	19347U	PARTICIPANT	\N	PRESENT	0
449062	439821	14331P	PARTICIPANT	\N	PRESENT	0
449063	439821	14205J	PARTICIPANT	\N	PRESENT	0
449064	439821	11048N	PARTICIPANT	\N	PRESENT	0
449065	439821	08061X	PARTICIPANT	\N	PRESENT	0
449066	439821	19675J	PARTICIPANT	\N	PRESENT	0
449067	439821	80013X	PARTICIPANT	\N	PRESENT	0
449068	439821	14253S	PARTICIPANT	\N	PRESENT	0
449069	439821	14173T	PARTICIPANT	\N	PRESENT	0
449070	439821	19253P	PARTICIPANT	\N	PRESENT	0
449071	439821	08028W	PARTICIPANT	\N	PRESENT	0
449072	439821	88008L	PARTICIPANT	\N	PRESENT	0
449073	439821	19758L	PARTICIPANT	\N	PRESENT	0
449074	448850	19649G	PARTICIPANT	\N	PRESENT	0
449075	448850	11026G	PARTICIPANT	\N	PRESENT	0
449101	439821	19479G	PARTICIPANT	\N	PRESENT	0
449079	448850	19543W	PARTICIPANT	\N	PRESENT	0
449080	448850	04044E	PARTICIPANT	\N	PRESENT	0
449081	448850	01028R	PARTICIPANT	\N	PRESENT	0
449082	448850	19675J	PARTICIPANT	\N	PRESENT	0
449083	448850	19447X	PARTICIPANT	\N	PRESENT	0
449084	448850	05008E	PRESIDENT	0	PRESENT	0
449085	448850	14231L	PARTICIPANT	\N	PRESENT	0
449086	448850	14089Y	PARTICIPANT	\N	PRESENT	0
449087	448850	19725B	PARTICIPANT	\N	PRESENT	0
449088	448850	19489J	PARTICIPANT	\N	PRESENT	0
449089	448850	95063L	PARTICIPANT	\N	PRESENT	0
449090	448850	08044W	PARTICIPANT	\N	PRESENT	0
449091	448850	14147R	PARTICIPANT	\N	PRESENT	0
449092	448850	14151M	PARTICIPANT	\N	PRESENT	0
449093	448850	14069U	PARTICIPANT	\N	PRESENT	0
449094	448850	08018U	PARTICIPANT	\N	PRESENT	0
449098	448850	08045X	PARTICIPANT	\N	PRESENT	0
449099	448850	19729F	PARTICIPANT	\N	PRESENT	0
449100	439821	14121F	PARTICIPANT	\N	PRESENT	0
449102	439821	08056B	PARTICIPANT	\N	PRESENT	0
449103	439821	19383Y	PARTICIPANT	\N	PRESENT	0
449104	439821	11097X	PARTICIPANT	\N	PRESENT	0
449105	448850	14215L	PARTICIPANT	\N	PRESENT	0
449106	439821	01057W	PARTICIPANT	\N	PRESENT	0
449107	439821	08069G	PARTICIPANT	\N	PRESENT	0
449108	439821	14201E	PARTICIPANT	\N	PRESENT	0
449109	439821	19681G	PARTICIPANT	\N	PRESENT	0
449110	439821	11012A	PARTICIPANT	\N	PRESENT	0
449112	449111	14059S	PARTICIPANT	\N	PRESENT	0
449113	449111	11048N	PARTICIPANT	\N	PRESENT	0
449114	449111	11083R	PARTICIPANT	\N	PRESENT	0
449115	449111	96004D	PARTICIPANT	\N	PRESENT	0
449116	439821	08019V	PARTICIPANT	\N	PRESENT	0
449117	448837	19515S	PARTICIPANT	\N	PRESENT	0
449118	448837	14357A	PARTICIPANT	\N	PRESENT	0
449119	448837	14187A	PARTICIPANT	\N	PRESENT	0
449120	448837	08015R	PARTICIPANT	\N	PRESENT	0
449121	448837	08019V	PARTICIPANT	\N	PRESENT	0
449122	448837	19747H	PARTICIPANT	\N	PRESENT	0
449123	448837	19413M	PARTICIPANT	\N	PRESENT	0
449124	448837	11090Q	PRESIDENT	0	PRESENT	0
449125	448837	01025N	PARTICIPANT	\N	PRESENT	0
449126	448837	80013X	PARTICIPANT	\N	PRESENT	0
449127	448837	14205J	PARTICIPANT	\N	PRESENT	0
449128	448837	08068F	PARTICIPANT	\N	PRESENT	0
449129	448837	14197C	PARTICIPANT	\N	PRESENT	0
449130	448837	19369B	PARTICIPANT	\N	PRESENT	0
449131	448837	19511N	PARTICIPANT	\N	PRESENT	0
449132	448837	14257W	PARTICIPANT	\N	PRESENT	0
449133	448837	19782L	PARTICIPANT	\N	EXCUSE	0
449134	448837	11081P	PARTICIPANT	\N	EXCUSE	0
449135	439821	19735D	PARTICIPANT	\N	PRESENT	0
449136	448837	19768N	PARTICIPANT	\N	PRESENT	0
449137	448837	08038Y	PARTICIPANT	\N	PRESENT	0
449138	448837	14033T	PARTICIPANT	\N	PRESENT	0
449139	448837	19507S	PARTICIPANT	\N	PRESENT	0
449140	448837	08028W	PARTICIPANT	\N	PRESENT	0
449141	448837	19695N	PARTICIPANT	\N	PRESENT	0
449142	448837	11056N	PARTICIPANT	\N	PRESENT	0
449144	449143	19621T	PARTICIPANT	\N	PRESENT	0
449145	449143	08031R	PARTICIPANT	\N	PRESENT	0
449146	449143	19611R	PARTICIPANT	\N	PRESENT	0
449147	439821	14097Y	PARTICIPANT	\N	PRESENT	0
449148	439821	14069U	PARTICIPANT	\N	PRESENT	0
449149	439821	14199E	PARTICIPANT	\N	PRESENT	0
449150	439821	08031R	PARTICIPANT	\N	PRESENT	0
449151	439821	14235Q	PARTICIPANT	\N	PRESENT	0
449152	448850	14259Y	PARTICIPANT	\N	PRESENT	0
449153	448850	10015M	PARTICIPANT	\N	PRESENT	0
449154	448850	14053L	PARTICIPANT	\N	EXCUSE	0
449155	439821	14115H	PARTICIPANT	\N	PRESENT	0
449156	448837	14265W	PARTICIPANT	\N	PRESENT	0
449157	439821	14061L	PARTICIPANT	\N	PRESENT	0
449158	439821	14083S	PARTICIPANT	\N	PRESENT	0
449159	439821	19631V	PARTICIPANT	\N	PRESENT	0
449160	439821	11027H	PARTICIPANT	\N	PRESENT	0
449161	439821	14281W	PARTICIPANT	\N	PRESENT	0
449163	449162	04085P	PARTICIPANT	\N	PRESENT	0
449164	449162	04059M	PARTICIPANT	\N	PRESENT	0
449165	449162	96004D	PARTICIPANT	\N	PRESENT	0
449166	449162	04042C	PARTICIPANT	\N	PRESENT	0
449167	449162	04086Q	PARTICIPANT	\N	PRESENT	0
449168	449162	14079W	PARTICIPANT	\N	PRESENT	0
449169	449162	11070L	PARTICIPANT	\N	PRESENT	0
449170	449162	11074Q	PARTICIPANT	\N	PRESENT	0
449171	449162	14034U	PARTICIPANT	\N	PRESENT	0
449172	449162	14021P	PARTICIPANT	\N	PRESENT	0
449173	449162	01043Q	PARTICIPANT	\N	PRESENT	0
449174	449162	14251Q	PARTICIPANT	\N	PRESENT	0
449175	449162	11085T	PARTICIPANT	\N	PRESENT	0
449176	449162	08009T	PARTICIPANT	\N	PRESENT	0
449177	449162	04092N	PARTICIPANT	\N	PRESENT	0
449178	449162	04070G	PARTICIPANT	\N	PRESENT	0
449179	449162	08061X	PARTICIPANT	\N	PRESENT	0
449180	449162	05012A	PARTICIPANT	\N	PRESENT	0
449181	449162	11090Q	PARTICIPANT	\N	PRESENT	0
449182	449162	11012A	PARTICIPANT	\N	PRESENT	0
449183	449162	04033B	PARTICIPANT	\N	PRESENT	0
449184	439821	14187A	PARTICIPANT	\N	PRESENT	0
449185	448563	14331P	PARTICIPANT	\N	PRESENT	0
449186	448563	11048N	PARTICIPANT	\N	PRESENT	0
449187	448563	19479G	PARTICIPANT	\N	PRESENT	0
449188	448563	01057W	PARTICIPANT	\N	PRESENT	0
449189	448563	11074Q	PRESIDENT	0	PRESENT	0
449190	448563	14173T	PARTICIPANT	\N	PRESENT	0
449191	448563	04086Q	PARTICIPANT	\N	PRESENT	0
449192	448563	14083S	PARTICIPANT	\N	PRESENT	0
449193	448563	14085U	PARTICIPANT	\N	PRESENT	0
449194	448563	96004D	PARTICIPANT	\N	PRESENT	0
449195	448563	19349W	PARTICIPANT	\N	PRESENT	0
449196	448563	14253S	PARTICIPANT	\N	PRESENT	0
424590	421729	14327T	PARTICIPANT	\N	EXCUSE	0
424662	424661	14087W	PARTICIPANT	\N	PRESENT	0
424663	424661	14281W	PARTICIPANT	\N	PRESENT	0
424721	424720	14087W	PARTICIPANT	\N	PRESENT	0
424723	424722	14087W	PARTICIPANT	\N	PRESENT	0
424729	424728	14281W	PARTICIPANT	\N	PRESENT	0
424730	424728	14087W	PARTICIPANT	\N	PRESENT	0
424741	424740	08048B	PARTICIPANT	\N	PRESENT	0
425326	425325	01024M	PARTICIPANT	\N	PRESENT	0
425343	425341	14081Q	PARTICIPANT	\N	PRESENT	0
425345	425336	14081Q	PARTICIPANT	\N	PRESENT	0
425349	425337	14081Q	PARTICIPANT	\N	PRESENT	0
425350	425339	14081Q	PARTICIPANT	\N	PRESENT	0
425352	425330	14081Q	PARTICIPANT	\N	PRESENT	0
429017	425038	04038G	PARTICIPANT	\N	PRESENT	0
429018	425038	19727D	PARTICIPANT	\N	PRESENT	0
429019	425038	19820Y	PARTICIPANT	\N	PRESENT	0
429020	428237	14357A	PARTICIPANT	\N	PRESENT	0
429021	428237	08038Y	PARTICIPANT	\N	PRESENT	0
429022	425038	11104D	PARTICIPANT	\N	PRESENT	0
429023	425038	19349W	PARTICIPANT	\N	PRESENT	0
429024	425038	14257W	PARTICIPANT	\N	PRESENT	0
429025	425038	19629C	PARTICIPANT	\N	PRESENT	0
429026	425038	98022P	PARTICIPANT	\N	PRESENT	0
429027	425038	19553Y	PARTICIPANT	\N	PRESENT	0
429028	425038	19703U	PARTICIPANT	\N	PRESENT	0
429029	425038	19681G	PARTICIPANT	\N	PRESENT	0
429030	425038	08031R	PARTICIPANT	\N	PRESENT	0
429031	425038	14261S	PARTICIPANT	\N	PRESENT	0
429032	425038	01028R	PARTICIPANT	\N	PRESENT	0
429033	425038	14157T	PARTICIPANT	\N	PRESENT	0
429034	425038	19739H	PARTICIPANT	\N	PRESENT	0
429035	425038	14030Q	PARTICIPANT	\N	PRESENT	0
429037	425038	14219Q	PARTICIPANT	\N	PRESENT	0
429038	425038	01025N	PARTICIPANT	\N	PRESENT	0
429039	425038	01024M	PARTICIPANT	\N	PRESENT	0
429040	425038	19745F	PARTICIPANT	\N	PRESENT	0
429041	425038	95030B	PARTICIPANT	\N	PRESENT	0
429043	425038	14093U	PARTICIPANT	\N	PRESENT	0
429044	425038	18083K	PARTICIPANT	\N	PRESENT	0
428990	425038	01043Q	PARTICIPANT	\N	PRESENT	0
428991	428237	19768N	PARTICIPANT	\N	PRESENT	0
428992	428237	19515S	PARTICIPANT	\N	PRESENT	0
428993	428237	19443T	PARTICIPANT	\N	PRESENT	0
428994	428237	01058X	PARTICIPANT	\N	PRESENT	0
428995	428237	04042C	PARTICIPANT	\N	PRESENT	0
428996	428237	11066Q	PARTICIPANT	\N	PRESENT	0
428997	428237	08056B	PARTICIPANT	\N	PRESENT	0
428998	428237	95037J	PARTICIPANT	\N	PRESENT	0
428999	428237	08068F	PARTICIPANT	\N	PRESENT	0
429000	428237	19421M	PARTICIPANT	\N	PRESENT	0
429001	428237	08015R	PARTICIPANT	\N	PRESENT	0
429002	428237	08019V	PARTICIPANT	\N	PRESENT	0
429003	428237	08053X	PARTICIPANT	\N	PRESENT	0
429004	428237	08028W	PARTICIPANT	\N	PRESENT	0
429005	428237	14265W	PARTICIPANT	\N	PRESENT	0
429006	428237	14097Y	PARTICIPANT	\N	PRESENT	0
429007	428237	19467C	PARTICIPANT	\N	PRESENT	0
429008	428237	08062Y	PARTICIPANT	\N	PRESENT	0
429009	428237	11090Q	PRESIDENT	0	PRESENT	0
429010	428237	14033T	PARTICIPANT	\N	PRESENT	0
429011	428237	19721W	PARTICIPANT	\N	PRESENT	0
429012	428237	04088S	PARTICIPANT	\N	PRESENT	0
429013	428237	11101A	PARTICIPANT	\N	PRESENT	0
429014	428237	19747H	PARTICIPANT	\N	PRESENT	0
429015	428237	04043D	PARTICIPANT	\N	PRESENT	0
429016	428237	14257W	PARTICIPANT	\N	PRESENT	0
429045	425038	19521Q	PARTICIPANT	\N	PRESENT	0
429046	425038	14059S	PARTICIPANT	\N	PRESENT	0
429047	425038	19335Q	PARTICIPANT	\N	PRESENT	0
429048	425038	14223L	PARTICIPANT	\N	PRESENT	0
429049	427858	14357A	PARTICIPANT	\N	PRESENT	0
429050	427858	19467C	PARTICIPANT	\N	PRESENT	0
429051	427858	08038Y	PARTICIPANT	\N	PRESENT	0
429052	425038	19794Q	PARTICIPANT	\N	PRESENT	0
429053	425038	14217N	PARTICIPANT	\N	PRESENT	0
429054	425038	17583W	PARTICIPANT	\N	PRESENT	0
429056	425038	19421M	PARTICIPANT	\N	PRESENT	0
429057	425038	14249W	PARTICIPANT	\N	PRESENT	0
429058	425038	11012A	PARTICIPANT	\N	PRESENT	0
429059	425038	14147R	PARTICIPANT	\N	PRESENT	0
429061	425038	14221J	PARTICIPANT	\N	PRESENT	0
429062	425038	14038Y	PARTICIPANT	\N	PRESENT	0
429063	425038	14237S	PARTICIPANT	\N	PRESENT	0
429064	425038	19369B	PARTICIPANT	\N	PRESENT	0
429065	425038	14265W	PARTICIPANT	\N	PRESENT	0
429070	425038	17779H	PARTICIPANT	\N	PRESENT	0
429071	425038	08053X	PARTICIPANT	\N	PRESENT	0
429072	425038	19565D	PARTICIPANT	\N	PRESENT	0
429073	425038	19479G	PARTICIPANT	\N	PRESENT	0
429077	425038	07029T	PARTICIPANT	\N	PRESENT	0
429078	425038	11101A	PARTICIPANT	\N	PRESENT	0
429079	425038	04088S	PARTICIPANT	\N	PRESENT	0
429080	425038	19467C	PARTICIPANT	\N	PRESENT	0
429081	425038	19747H	PARTICIPANT	\N	PRESENT	0
429082	425038	19782L	PARTICIPANT	\N	PRESENT	0
429083	425038	14357A	PARTICIPANT	\N	PRESENT	0
429084	425038	08028W	PARTICIPANT	\N	PRESENT	0
429085	425038	14115H	PARTICIPANT	\N	PRESENT	0
429093	425038	19569H	PARTICIPANT	\N	PRESENT	0
429094	425038	19675J	PARTICIPANT	\N	PRESENT	0
429095	425038	14021P	PARTICIPANT	\N	PRESENT	0
429096	425038	19573D	PARTICIPANT	\N	PRESENT	0
429097	427446	19333N	PARTICIPANT	\N	PRESENT	0
429098	427446	17583W	PARTICIPANT	\N	PRESENT	0
429099	427446	19701S	PARTICIPANT	\N	PRESENT	0
429100	427446	19794Q	PARTICIPANT	\N	PRESENT	0
429101	427446	19549D	PARTICIPANT	\N	PRESENT	0
429102	427446	19387D	PARTICIPANT	\N	PRESENT	0
429103	427446	19820Y	PARTICIPANT	\N	PRESENT	0
429104	427446	14219Q	PARTICIPANT	\N	PRESENT	0
429105	427446	14221J	PARTICIPANT	\N	PRESENT	0
429106	427446	19599P	PARTICIPANT	\N	PRESENT	0
429107	427446	19637C	PARTICIPANT	\N	PRESENT	0
429108	427446	14237S	PARTICIPANT	\N	PRESENT	0
429109	427446	18083K	PARTICIPANT	\N	PRESENT	0
429110	427446	05012A	PARTICIPANT	\N	PRESENT	0
429111	427446	19503N	PARTICIPANT	\N	PRESENT	0
429112	427446	14157T	PARTICIPANT	\N	PRESENT	0
429113	427446	19681G	PARTICIPANT	\N	PRESENT	0
429114	427446	11065P	PARTICIPANT	\N	PRESENT	0
429115	427446	19525U	PARTICIPANT	\N	PRESENT	0
429116	427446	14038Y	PRESIDENT	0	PRESENT	0
429117	427446	11048N	PARTICIPANT	\N	PRESENT	0
429118	427446	19711U	PARTICIPANT	\N	PRESENT	0
429119	427446	14031R	PARTICIPANT	\N	PRESENT	0
429120	427446	19713W	PARTICIPANT	\N	PRESENT	0
429121	427446	14169X	PARTICIPANT	\N	PRESENT	0
429132	425038	08015R	PARTICIPANT	\N	PRESENT	0
429123	427446	08009T	PARTICIPANT	\N	PRESENT	0
429124	427446	19737F	PARTICIPANT	\N	PRESENT	0
429125	427446	14051J	PARTICIPANT	\N	EXCUSE	0
429126	425038	08014Q	PARTICIPANT	\N	PRESENT	0
429127	427446	19551W	PARTICIPANT	\N	PRESENT	0
429128	427446	04097T	PARTICIPANT	\N	PRESENT	0
429129	427446	19347U	PARTICIPANT	\N	PRESENT	0
429130	427446	19733B	PARTICIPANT	\N	PRESENT	0
429131	425038	14083S	PARTICIPANT	\N	PRESENT	0
429133	425038	14213J	PARTICIPANT	\N	PRESENT	0
429134	425038	14061L	PARTICIPANT	\N	PRESENT	0
429135	425038	11097X	PARTICIPANT	\N	PRESENT	0
429136	427446	08060W	PARTICIPANT	\N	PRESENT	0
429137	425038	89017R	PARTICIPANT	\N	PRESENT	0
429142	425038	19563B	PARTICIPANT	\N	PRESENT	0
429147	425038	14033T	PARTICIPANT	\N	PRESENT	0
429167	428238	19768N	PARTICIPANT	\N	PRESENT	0
429168	428238	19515S	PARTICIPANT	\N	PRESENT	0
429169	428238	14357A	PARTICIPANT	\N	PRESENT	0
429170	428238	19441R	PARTICIPANT	\N	PRESENT	0
429171	428238	14081Q	PARTICIPANT	\N	PRESENT	0
429172	428238	19413M	PARTICIPANT	\N	PRESENT	0
429173	428238	19631V	PARTICIPANT	\N	PRESENT	0
429174	428238	11099A	PARTICIPANT	\N	PRESENT	0
429175	428238	08068F	PARTICIPANT	\N	PRESENT	0
429176	428238	08015R	PARTICIPANT	\N	PRESENT	0
429177	428238	96004D	PARTICIPANT	\N	PRESENT	0
429178	428238	08019V	PARTICIPANT	\N	PRESENT	0
429179	428238	19511N	PARTICIPANT	\N	PRESENT	0
429180	428238	19563B	PARTICIPANT	\N	PRESENT	0
429181	428238	14265W	PARTICIPANT	\N	PRESENT	0
429182	428238	14329V	PARTICIPANT	\N	PRESENT	0
429183	428238	14135M	PARTICIPANT	\N	PRESENT	0
429184	428238	19467C	PARTICIPANT	\N	PRESENT	0
429185	428238	01025N	PARTICIPANT	\N	PRESENT	0
429186	428238	11090Q	PRESIDENT	0	PRESENT	0
429187	428238	14033T	PARTICIPANT	\N	PRESENT	0
429188	428238	19295A	PARTICIPANT	\N	PRESENT	0
429189	428238	04088S	PARTICIPANT	\N	PRESENT	0
429190	428238	14115H	PARTICIPANT	\N	PRESENT	0
443529	439638	19503N	PARTICIPANT	\N	PRESENT	0
443573	439686	14251Q	PARTICIPANT	\N	PRESENT	0
443574	439686	19333N	PARTICIPANT	\N	PRESENT	0
443575	439686	19503N	PARTICIPANT	\N	PRESENT	0
443576	439686	80013X	PARTICIPANT	\N	PRESENT	0
443577	439686	11027H	PARTICIPANT	\N	PRESENT	0
443578	439686	19715Y	PARTICIPANT	\N	PRESENT	0
443579	439686	08031R	PARTICIPANT	\N	PRESENT	0
443580	439686	19289C	PARTICIPANT	\N	PRESENT	0
443581	439686	19631V	PARTICIPANT	\N	PRESENT	0
443582	439686	01024M	PARTICIPANT	\N	PRESENT	0
443583	439686	19253P	PARTICIPANT	\N	PRESENT	0
443584	439686	19415P	PARTICIPANT	\N	PRESENT	0
443585	439686	19673G	PARTICIPANT	\N	PRESENT	0
443586	439686	19741B	PARTICIPANT	\N	PRESENT	0
443587	439686	19669L	PARTICIPANT	\N	PRESENT	0
443588	439686	19749K	PARTICIPANT	\N	PRESENT	0
443589	439686	14217N	PARTICIPANT	\N	PRESENT	0
443590	439686	14147R	PARTICIPANT	\N	PRESENT	0
443591	439686	04088S	PARTICIPANT	\N	PRESENT	0
443592	439686	07029T	PARTICIPANT	\N	PRESENT	0
443593	439686	11097X	PARTICIPANT	\N	PRESENT	0
443594	439686	14179A	PARTICIPANT	\N	PRESENT	0
443595	439686	11012A	PARTICIPANT	\N	PRESENT	0
443596	439686	19581D	PARTICIPANT	\N	PRESENT	0
443597	439686	08044W	PARTICIPANT	\N	PRESENT	0
443598	439686	99004R	PARTICIPANT	\N	PRESENT	0
443599	439686	19573D	PARTICIPANT	\N	PRESENT	0
443600	443429	08031R	PARTICIPANT	\N	EXCUSE	0
443601	439686	19543W	PARTICIPANT	\N	PRESENT	0
443602	439686	01057W	PARTICIPANT	\N	PRESENT	0
443603	439686	19621T	PARTICIPANT	\N	PRESENT	0
443604	439686	08039A	PARTICIPANT	\N	PRESENT	0
443605	439686	19531S	PARTICIPANT	\N	PRESENT	0
443606	439686	04085P	PARTICIPANT	\N	PRESENT	0
443607	439686	12041X	PARTICIPANT	\N	PRESENT	0
443608	439686	19565D	PARTICIPANT	\N	PRESENT	0
443648	439639	19715Y	PARTICIPANT	\N	PRESENT	0
443649	439639	19565D	PARTICIPANT	\N	PRESENT	0
443650	439639	11031D	PARTICIPANT	\N	PRESENT	0
443651	439639	14195A	PARTICIPANT	\N	PRESENT	0
443652	439639	19553Y	PARTICIPANT	\N	PRESENT	0
443571	439686	01043Q	PARTICIPANT	\N	PRESENT	0
443572	439686	14195A	PARTICIPANT	\N	PRESENT	0
443653	439639	14042U	PARTICIPANT	\N	PRESENT	0
443654	439639	14147R	PARTICIPANT	\N	PRESENT	0
443655	439639	14331P	PARTICIPANT	\N	PRESENT	0
443656	439639	08031R	PARTICIPANT	\N	PRESENT	0
443657	439639	14021P	PARTICIPANT	\N	PRESENT	0
443658	439639	19591F	PARTICIPANT	\N	PRESENT	0
443659	439639	19768N	PARTICIPANT	\N	PRESENT	0
443660	439639	07029T	PARTICIPANT	\N	PRESENT	0
443661	439639	19531S	PARTICIPANT	\N	PRESENT	0
443662	439639	14033T	PARTICIPANT	\N	PRESENT	0
443663	439639	14135M	PARTICIPANT	\N	PRESENT	0
443680	439640	11027H	PARTICIPANT	\N	PRESENT	0
443684	439640	99004R	PARTICIPANT	\N	PRESENT	0
443685	439640	11097X	PARTICIPANT	\N	PRESENT	0
443686	439640	19467C	PARTICIPANT	\N	PRESENT	0
443687	439640	19695N	PARTICIPANT	\N	PRESENT	0
443688	439640	19711U	PARTICIPANT	\N	PRESENT	0
443689	439640	19333N	PARTICIPANT	\N	PRESENT	0
443690	439640	04043D	PARTICIPANT	\N	PRESENT	0
443691	439640	14255U	PARTICIPANT	\N	PRESENT	0
443692	439640	19713W	PARTICIPANT	\N	PRESENT	0
443693	439640	14257W	PARTICIPANT	\N	PRESENT	0
443694	439640	19631V	PARTICIPANT	\N	PRESENT	0
443695	439640	01028R	PARTICIPANT	\N	PRESENT	0
443696	439640	19387D	PARTICIPANT	\N	PRESENT	0
443697	439640	19563B	PARTICIPANT	\N	PRESENT	0
443698	439640	14147R	PARTICIPANT	\N	PRESENT	0
443701	439640	19737F	PARTICIPANT	\N	PRESENT	0
443702	439640	19543W	PARTICIPANT	\N	PRESENT	0
443703	439640	11083R	PARTICIPANT	\N	PRESENT	0
443705	439640	19687N	PARTICIPANT	\N	PRESENT	0
443706	439640	19531S	PARTICIPANT	\N	PRESENT	0
443646	439639	11072N	PARTICIPANT	\N	PRESENT	0
443647	439639	14227Q	PARTICIPANT	\N	PRESENT	0
443707	439640	14237S	PARTICIPANT	\N	PRESENT	0
443708	439640	19749K	PARTICIPANT	\N	PRESENT	0
443709	439640	95063L	PARTICIPANT	\N	PRESENT	0
443710	439640	07029T	PARTICIPANT	\N	PRESENT	0
443711	439640	11012A	PARTICIPANT	\N	PRESENT	0
443712	439640	19693L	PARTICIPANT	\N	PRESENT	0
443713	439640	08039A	PARTICIPANT	\N	PRESENT	0
443714	439640	04088S	PARTICIPANT	\N	PRESENT	0
443715	439640	19253P	PARTICIPANT	\N	PRESENT	0
443974	439642	19533U	PARTICIPANT	\N	PRESENT	0
443975	439642	19583F	PARTICIPANT	\N	PRESENT	0
443986	439642	11040E	PARTICIPANT	\N	PRESENT	0
443987	439642	14097Y	PARTICIPANT	\N	PRESENT	0
443988	439642	14109K	PARTICIPANT	\N	PRESENT	0
443989	439642	08069G	PARTICIPANT	\N	PRESENT	0
443990	439642	19467C	PARTICIPANT	\N	PRESENT	0
443991	439642	19671E	PARTICIPANT	\N	PRESENT	0
443992	439642	08061X	PARTICIPANT	\N	PRESENT	0
443993	439642	14073Q	PARTICIPANT	\N	PRESENT	0
443994	439642	11048N	PARTICIPANT	\N	PRESENT	0
443995	439642	14031R	PARTICIPANT	\N	PRESENT	0
443996	439642	19798U	PARTICIPANT	\N	PRESENT	0
443997	439642	11104D	PARTICIPANT	\N	PRESENT	0
443998	439642	87003B	PARTICIPANT	\N	PRESENT	0
443999	439642	11083R	PARTICIPANT	\N	PRESENT	0
444000	439642	14111D	PARTICIPANT	\N	PRESENT	0
444001	439642	19731Y	PARTICIPANT	\N	PRESENT	0
444002	439642	14083S	PARTICIPANT	\N	PRESENT	0
444003	439642	08028W	PARTICIPANT	\N	PRESENT	0
444004	439642	19711U	PARTICIPANT	\N	PRESENT	0
444005	439642	19723Y	PARTICIPANT	\N	PRESENT	0
444006	439642	14207L	PARTICIPANT	\N	PRESENT	0
444076	439687	11070L	PARTICIPANT	\N	PRESENT	0
444077	439687	08061X	PARTICIPANT	\N	PRESENT	0
444078	439687	19669L	PARTICIPANT	\N	PRESENT	0
444079	439687	11048N	PARTICIPANT	\N	PRESENT	0
444080	439687	11104D	PARTICIPANT	\N	PRESENT	0
444081	439687	19347U	PARTICIPANT	\N	PRESENT	0
444082	439687	19760E	PARTICIPANT	\N	PRESENT	0
444083	439687	19695N	PARTICIPANT	\N	PRESENT	0
444084	439687	11040E	PARTICIPANT	\N	PRESENT	0
444085	439687	11056N	PARTICIPANT	\N	PRESENT	0
444086	439687	11026G	PARTICIPANT	\N	PRESENT	0
444087	439687	19549D	PARTICIPANT	\N	PRESENT	0
444088	439687	19679N	PARTICIPANT	\N	PRESENT	0
444124	439687	14267Y	PARTICIPANT	\N	PRESENT	0
444090	439687	15447F	PARTICIPANT	\N	PRESENT	0
444091	439687	19703U	PARTICIPANT	\N	PRESENT	0
444092	439687	14197C	PARTICIPANT	\N	PRESENT	0
444093	439687	19333N	PARTICIPANT	\N	PRESENT	0
444094	439687	96004D	PARTICIPANT	\N	PRESENT	0
444095	439687	14109K	PARTICIPANT	\N	PRESENT	0
444096	439687	08069G	PARTICIPANT	\N	PRESENT	0
444097	439687	14097Y	PARTICIPANT	\N	PRESENT	0
444098	439687	19349W	PARTICIPANT	\N	PRESENT	0
444099	439687	19575F	PARTICIPANT	\N	PRESENT	0
444100	439687	11083R	PARTICIPANT	\N	PRESENT	0
444101	439687	19399H	PARTICIPANT	\N	PRESENT	0
444102	439687	19387D	PARTICIPANT	\N	PRESENT	0
444103	439687	14135M	PARTICIPANT	\N	PRESENT	0
444104	439687	14207L	PARTICIPANT	\N	PRESENT	0
444105	439687	87003B	PARTICIPANT	\N	PRESENT	0
444106	439687	17589D	PARTICIPANT	\N	PRESENT	0
444107	439687	19583F	PARTICIPANT	\N	PRESENT	0
444108	439687	04088S	PARTICIPANT	\N	PRESENT	0
444109	439687	19319Q	PARTICIPANT	\N	PRESENT	0
444110	439687	19723Y	PARTICIPANT	\N	PRESENT	0
444111	439687	01043Q	PARTICIPANT	\N	PRESENT	0
444112	439687	19467C	PARTICIPANT	\N	PRESENT	0
444113	439687	19479G	PARTICIPANT	\N	PRESENT	0
444114	439687	19441R	PARTICIPANT	\N	PRESENT	0
444115	439687	14147R	PARTICIPANT	\N	PRESENT	0
444116	439687	11099A	PARTICIPANT	\N	PRESENT	0
444117	439687	19711U	PARTICIPANT	\N	PRESENT	0
444118	439687	01024M	PARTICIPANT	\N	PRESENT	0
444119	439687	14073Q	PARTICIPANT	\N	PRESENT	0
444120	439687	01025N	PARTICIPANT	\N	PRESENT	0
444121	439687	14205J	PARTICIPANT	\N	PRESENT	0
444122	439687	19533U	PARTICIPANT	\N	PRESENT	0
444123	439687	11103C	PARTICIPANT	\N	PRESENT	0
444125	439687	19671E	PARTICIPANT	\N	PRESENT	0
444126	439687	14089Y	PARTICIPANT	\N	PRESENT	0
444127	439687	14187A	PARTICIPANT	\N	PRESENT	0
444128	439687	88008L	PARTICIPANT	\N	PRESENT	0
444129	439687	08028W	PARTICIPANT	\N	PRESENT	0
444130	439687	19367Y	PARTICIPANT	\N	PRESENT	0
444131	439687	19798U	PARTICIPANT	\N	PRESENT	0
444132	439687	14042U	PARTICIPANT	\N	PRESENT	0
444133	439687	18083K	PARTICIPANT	\N	PRESENT	0
444134	439687	14033T	PARTICIPANT	\N	PRESENT	0
444135	439687	14107H	PARTICIPANT	\N	PRESENT	0
423911	423901	08043V	PARTICIPANT	\N	PRESENT	0
423912	423902	08039A	PARTICIPANT	\N	PRESENT	0
423913	423902	19758L	PARTICIPANT	\N	PRESENT	0
423914	423902	14229S	PARTICIPANT	\N	PRESENT	0
423915	423902	08043V	PARTICIPANT	\N	PRESENT	0
423916	423902	19399H	PARTICIPANT	\N	PRESENT	0
423917	423905	08039A	PARTICIPANT	\N	PRESENT	0
423918	423905	08043V	PARTICIPANT	\N	PRESENT	0
423919	423905	14241N	PARTICIPANT	\N	PRESENT	0
423920	423905	19399H	PARTICIPANT	\N	PRESENT	0
427723	416329	04088S	PARTICIPANT	\N	PRESENT	0
427724	416329	14119M	PARTICIPANT	\N	PRESENT	0
427725	416329	14223L	PARTICIPANT	\N	PRESENT	0
427726	427428	14229S	PARTICIPANT	\N	PRESENT	0
427727	427428	14109K	PARTICIPANT	\N	PRESENT	0
427729	416329	19715Y	PARTICIPANT	\N	PRESENT	0
427730	416329	19717B	PARTICIPANT	\N	PRESENT	0
427731	427728	19729F	PARTICIPANT	\N	PRESENT	0
427732	427728	04071H	PARTICIPANT	\N	PRESENT	0
427733	427728	10015M	PARTICIPANT	\N	PRESENT	0
427734	427728	14147R	PARTICIPANT	\N	PRESENT	0
427735	427728	19671E	PARTICIPANT	\N	PRESENT	0
427736	427728	19675J	PARTICIPANT	\N	PRESENT	0
427738	427428	08039A	PARTICIPANT	\N	EXCUSE	0
427739	416329	19657G	PARTICIPANT	\N	PRESENT	0
427740	416329	18083K	PARTICIPANT	\N	PRESENT	0
427741	416329	19745F	PARTICIPANT	\N	PRESENT	0
427742	416329	14115H	PARTICIPANT	\N	PRESENT	0
427743	416329	14281W	PARTICIPANT	\N	PRESENT	0
427744	416329	17779H	PARTICIPANT	\N	PRESENT	0
427745	416329	14197C	PARTICIPANT	\N	PRESENT	0
427746	427728	14199E	PARTICIPANT	\N	PRESENT	0
427747	427728	04047H	PARTICIPANT	\N	PRESENT	0
427828	416329	08020N	PARTICIPANT	\N	PRESENT	0
427749	427728	01028R	PARTICIPANT	\N	PRESENT	0
427750	427728	19762G	PARTICIPANT	\N	PRESENT	0
427751	427728	05008E	PRESIDENT	0	PRESENT	0
427752	427428	04059M	PARTICIPANT	\N	PRESENT	0
427753	427428	19735D	PARTICIPANT	\N	PRESENT	0
427754	416329	14081Q	PARTICIPANT	\N	PRESENT	0
427755	416329	14267Y	PARTICIPANT	\N	PRESENT	0
427756	416329	11077T	PARTICIPANT	\N	PRESENT	0
427757	416329	14213J	PARTICIPANT	\N	PRESENT	0
427758	416329	14033T	PARTICIPANT	\N	PRESENT	0
427759	416329	19531S	PARTICIPANT	\N	PRESENT	0
427760	416329	14157T	PARTICIPANT	\N	PRESENT	0
427761	416329	19675J	PARTICIPANT	\N	PRESENT	0
427762	416329	14225N	PARTICIPANT	\N	PRESENT	0
427763	416329	19663E	PARTICIPANT	\N	PRESENT	0
427764	416329	08047A	PARTICIPANT	\N	PRESENT	0
427765	416329	14331P	PARTICIPANT	\N	PRESENT	0
427768	416329	14261S	PARTICIPANT	\N	PRESENT	0
427771	416329	19703U	PARTICIPANT	\N	PRESENT	0
427772	416329	14069U	PARTICIPANT	\N	PRESENT	0
427773	416329	97011G	PARTICIPANT	\N	PRESENT	0
427775	416329	19667J	PARTICIPANT	\N	PRESENT	0
427776	416329	19747H	PARTICIPANT	\N	PRESENT	0
427779	416329	11053K	PARTICIPANT	\N	PRESENT	0
427789	416329	19741B	PARTICIPANT	\N	PRESENT	0
427793	416329	11056N	PARTICIPANT	\N	PRESENT	0
427796	416329	14249W	PARTICIPANT	\N	PRESENT	0
427800	416329	19301E	PARTICIPANT	\N	PRESENT	0
427801	416329	19467C	PARTICIPANT	\N	PRESENT	0
427802	416329	02002K	PARTICIPANT	\N	PRESENT	0
427803	416329	14121F	PARTICIPANT	\N	PRESENT	0
427808	416329	19543W	PARTICIPANT	\N	PRESENT	0
427809	416329	14265W	PARTICIPANT	\N	PRESENT	0
427810	416329	19695N	PARTICIPANT	\N	PRESENT	0
427811	416329	14147R	PARTICIPANT	\N	PRESENT	0
427812	416329	19253P	PARTICIPANT	\N	PRESENT	0
427813	427728	19649G	PARTICIPANT	\N	PRESENT	0
427814	427728	11026G	PARTICIPANT	\N	PRESENT	0
427815	427728	01024M	PARTICIPANT	\N	PRESENT	0
427816	427728	04044E	PARTICIPANT	\N	PRESENT	0
427817	427728	04038G	PARTICIPANT	\N	PRESENT	0
427818	427728	19719D	PARTICIPANT	\N	PRESENT	0
427819	427728	14231L	PARTICIPANT	\N	PRESENT	0
427820	427728	95063L	PARTICIPANT	\N	PRESENT	0
427821	427728	14041T	PARTICIPANT	\N	PRESENT	0
427822	427728	14053L	PARTICIPANT	\N	PRESENT	0
427823	427728	19629C	PARTICIPANT	\N	PRESENT	0
427824	427728	11049P	PARTICIPANT	\N	PRESENT	0
427825	427728	14021P	PARTICIPANT	\N	PRESENT	0
427826	416329	14105F	PARTICIPANT	\N	PRESENT	0
427827	416329	14199E	PARTICIPANT	\N	PRESENT	0
427829	416329	19479G	PARTICIPANT	\N	PRESENT	0
427830	416329	08048B	PARTICIPANT	\N	PRESENT	0
427831	416329	19399H	PARTICIPANT	\N	PRESENT	0
427834	416329	98050T	PARTICIPANT	\N	PRESENT	0
427835	416329	08019V	PARTICIPANT	\N	PRESENT	0
427852	416329	14357A	PARTICIPANT	\N	PRESENT	0
427853	416329	19527W	PARTICIPANT	\N	PRESENT	0
427854	416329	19533U	PARTICIPANT	\N	PRESENT	0
427855	416329	07029T	PARTICIPANT	\N	PRESENT	0
427856	416329	11012A	PARTICIPANT	\N	PRESENT	0
427857	416329	19735D	PARTICIPANT	\N	PRESENT	0
427873	416329	19760E	PARTICIPANT	\N	PRESENT	0
427874	416329	08010L	PARTICIPANT	\N	PRESENT	0
427963	416333	04092N	PARTICIPANT	\N	PRESENT	0
427965	425133	11012A	PARTICIPANT	\N	PRESENT	0
427966	425133	08073C	PARTICIPANT	\N	PRESENT	0
427967	425133	12016W	PARTICIPANT	\N	PRESENT	0
427968	425133	99004R	PARTICIPANT	\N	PRESENT	0
427980	425133	19711U	PARTICIPANT	\N	PRESENT	0
427984	416333	19565D	PARTICIPANT	\N	PRESENT	0
427985	425133	14327T	PARTICIPANT	\N	PRESENT	0
427986	425133	08011M	PARTICIPANT	\N	PRESENT	0
427987	416333	17779H	PARTICIPANT	\N	PRESENT	0
427988	416333	08058D	PARTICIPANT	\N	PRESENT	0
427989	425133	89017R	PARTICIPANT	\N	PRESENT	0
427991	425133	14083S	PARTICIPANT	\N	PRESENT	0
427992	425133	14085U	PARTICIPANT	\N	PRESENT	0
427993	425133	01057W	PRESIDENT	0	PRESENT	0
427994	416333	08052W	PARTICIPANT	\N	PRESENT	0
427995	416333	19387D	PARTICIPANT	\N	PRESENT	0
427996	416333	19553Y	PARTICIPANT	\N	PRESENT	0
427997	416333	14195A	PARTICIPANT	\N	PRESENT	0
427998	416333	07004J	PARTICIPANT	\N	PRESENT	0
427999	416333	14239U	PARTICIPANT	\N	PRESENT	0
428000	416333	11103C	PARTICIPANT	\N	PRESENT	0
428001	416333	19367Y	PARTICIPANT	\N	PRESENT	0
428002	416333	19798U	PARTICIPANT	\N	PRESENT	0
428134	416333	19683J	PARTICIPANT	\N	PRESENT	0
428135	416333	14030Q	PARTICIPANT	\N	PRESENT	0
428141	416333	19717B	PARTICIPANT	\N	PRESENT	0
428142	416333	19762G	PARTICIPANT	\N	PRESENT	0
428146	425133	19667J	PARTICIPANT	\N	PRESENT	0
428148	416333	11090Q	PARTICIPANT	\N	PRESENT	0
428149	416333	11072N	PARTICIPANT	\N	PRESENT	0
428150	416333	14231L	PARTICIPANT	\N	PRESENT	0
428151	416333	98050T	PARTICIPANT	\N	PRESENT	0
428154	416333	14115H	PARTICIPANT	\N	PRESENT	0
428155	416333	14281W	PARTICIPANT	\N	PRESENT	0
428156	416333	19695N	PARTICIPANT	\N	PRESENT	0
428158	416333	08047A	PARTICIPANT	\N	PRESENT	0
428164	416333	19691J	PARTICIPANT	\N	PRESENT	0
428167	416333	04085P	PARTICIPANT	\N	PRESENT	0
428168	416333	08020N	PARTICIPANT	\N	PRESENT	0
428169	416333	19503N	PARTICIPANT	\N	PRESENT	0
431895	425265	19731Y	PARTICIPANT	\N	PRESENT	0
431896	425265	14033T	PARTICIPANT	\N	PRESENT	0
431897	425265	14219Q	PARTICIPANT	\N	PRESENT	0
431898	425265	89017R	PARTICIPANT	\N	PRESENT	0
431899	425265	19575F	PARTICIPANT	\N	PRESENT	0
431900	425265	14157T	PARTICIPANT	\N	PRESENT	0
431901	425265	01048V	PARTICIPANT	\N	PRESENT	0
431902	425265	95030B	PARTICIPANT	\N	PRESENT	0
431903	425265	98050T	PARTICIPANT	\N	PRESENT	0
431904	425265	04071H	PARTICIPANT	\N	PRESENT	0
431905	425265	14229S	PARTICIPANT	\N	PRESENT	0
431906	425265	19691J	PARTICIPANT	\N	PRESENT	0
431907	425265	14089Y	PARTICIPANT	\N	PRESENT	0
431908	425265	19643A	PARTICIPANT	\N	PRESENT	0
431909	425265	14173T	PARTICIPANT	\N	PRESENT	0
431910	425265	14237S	PARTICIPANT	\N	PRESENT	0
431911	425265	14069U	PARTICIPANT	\N	PRESENT	0
431912	425265	87003B	PARTICIPANT	\N	PRESENT	0
431913	425265	08038Y	PARTICIPANT	\N	PRESENT	0
431914	425265	01060R	PARTICIPANT	\N	PRESENT	0
431926	425265	14151M	PARTICIPANT	\N	PRESENT	0
431927	425265	08069G	PARTICIPANT	\N	PRESENT	0
431928	425265	04049K	PARTICIPANT	\N	PRESENT	0
427939	416333	04086Q	PARTICIPANT	\N	PRESENT	0
427962	416333	01034P	PARTICIPANT	\N	PRESENT	0
431930	425265	19531S	PARTICIPANT	\N	PRESENT	0
431931	425265	19631V	PARTICIPANT	\N	PRESENT	0
431933	425265	14111D	PARTICIPANT	\N	PRESENT	0
431934	431932	04070G	PRESIDENT	0	PRESENT	0
431935	431932	19699S	PARTICIPANT	\N	PRESENT	0
436626	436625	14031R	PARTICIPANT	\N	PRESENT	0
449197	448563	99004R	PARTICIPANT	\N	PRESENT	0
449198	448563	14327T	PARTICIPANT	\N	EXCUSE	0
449199	448563	07029T	PARTICIPANT	\N	EXCUSE	0
449282	439822	04092N	PARTICIPANT	\N	PRESENT	0
449283	439822	04045F	PARTICIPANT	\N	PRESENT	0
449284	439822	19683J	PARTICIPANT	\N	PRESENT	0
449285	439822	11067R	PARTICIPANT	\N	PRESENT	0
449286	439822	19333N	PARTICIPANT	\N	PRESENT	0
449287	439822	11031D	PARTICIPANT	\N	PRESENT	0
449288	439822	19569H	PARTICIPANT	\N	PRESENT	0
449289	439822	14195A	PARTICIPANT	\N	PRESENT	0
449290	439822	14030Q	PARTICIPANT	\N	PRESENT	0
449291	439822	04033B	PARTICIPANT	\N	PRESENT	0
449292	439822	14089Y	PARTICIPANT	\N	PRESENT	0
449293	439822	19533U	PARTICIPANT	\N	PRESENT	0
449294	439822	14069U	PARTICIPANT	\N	PRESENT	0
449295	439822	19367Y	PARTICIPANT	\N	PRESENT	0
449296	439822	11097X	PARTICIPANT	\N	PRESENT	0
449297	439822	14065Q	PARTICIPANT	\N	PRESENT	0
449298	439822	14215L	PARTICIPANT	\N	PRESENT	0
449299	439822	14053L	PARTICIPANT	\N	PRESENT	0
449300	439822	19798U	PARTICIPANT	\N	PRESENT	0
449301	439822	14079W	PARTICIPANT	\N	PRESENT	0
449302	439822	19507S	PARTICIPANT	\N	PRESENT	0
449303	439822	08034U	PARTICIPANT	\N	PRESENT	0
449304	439822	14105F	PARTICIPANT	\N	PRESENT	0
449305	439822	18083K	PARTICIPANT	\N	PRESENT	0
449306	439822	19693L	PARTICIPANT	\N	PRESENT	0
449307	439822	19415P	PARTICIPANT	\N	PRESENT	0
449308	439822	19399H	PARTICIPANT	\N	PRESENT	0
449309	439822	19723Y	PARTICIPANT	\N	PRESENT	0
449310	439822	99004R	PARTICIPANT	\N	PRESENT	0
449311	439822	14357A	PARTICIPANT	\N	PRESENT	0
449312	439822	14239U	PARTICIPANT	\N	PRESENT	0
449313	439822	01025N	PARTICIPANT	\N	PRESENT	0
449314	439822	19737F	PARTICIPANT	\N	PRESENT	0
449315	439822	19671E	PARTICIPANT	\N	PRESENT	0
449316	439822	14083S	PARTICIPANT	\N	PRESENT	0
449317	439822	19691J	PARTICIPANT	\N	PRESENT	0
449318	439822	08052W	PARTICIPANT	\N	PRESENT	0
449319	439822	19553Y	PARTICIPANT	\N	PRESENT	0
449320	439822	08031R	PARTICIPANT	\N	PRESENT	0
449321	439822	98024R	PARTICIPANT	\N	PRESENT	0
449322	439822	14231L	PARTICIPANT	\N	PRESENT	0
449323	439822	14281W	PARTICIPANT	\N	PRESENT	0
449324	439822	14097Y	PARTICIPANT	\N	PRESENT	0
449325	439822	08039A	PARTICIPANT	\N	PRESENT	0
449326	439822	19621T	PARTICIPANT	\N	PRESENT	0
449327	439822	19681G	PARTICIPANT	\N	PRESENT	0
449328	439822	19349W	PARTICIPANT	\N	PRESENT	0
449329	439822	14213J	PARTICIPANT	\N	PRESENT	0
449330	439822	19447X	PARTICIPANT	\N	PRESENT	0
449331	439822	19679N	PARTICIPANT	\N	PRESENT	0
449332	439822	04040A	PARTICIPANT	\N	PRESENT	0
449333	439822	04088S	PARTICIPANT	\N	PRESENT	0
449334	439822	05008E	PARTICIPANT	\N	PRESENT	0
449335	439822	14038Y	PARTICIPANT	\N	PRESENT	0
449336	439822	14042U	PARTICIPANT	\N	PRESENT	0
449337	439822	08020N	PARTICIPANT	\N	PRESENT	0
449338	439822	14147R	PARTICIPANT	\N	PRESENT	0
449339	439822	10006L	PARTICIPANT	\N	PRESENT	0
449340	439822	17589D	PARTICIPANT	\N	PRESENT	0
449341	439822	19335Q	PARTICIPANT	\N	PRESENT	0
449342	439822	14241N	PARTICIPANT	\N	PRESENT	0
449343	439822	14119M	PARTICIPANT	\N	PRESENT	0
449344	439822	19563B	PARTICIPANT	\N	PRESENT	0
449345	439822	19703U	PARTICIPANT	\N	PRESENT	0
449346	439822	14031R	PARTICIPANT	\N	PRESENT	0
449347	439822	14021P	PARTICIPANT	\N	PRESENT	0
449348	439822	11048N	PARTICIPANT	\N	PRESENT	0
449349	439822	08044W	PARTICIPANT	\N	PRESENT	0
449350	439822	08061X	PARTICIPANT	\N	PRESENT	0
449351	439822	19647E	PARTICIPANT	\N	PRESENT	0
449352	439822	19768N	PARTICIPANT	\N	PRESENT	0
449353	439822	05012A	PARTICIPANT	\N	PRESENT	0
449272	439822	11070L	PARTICIPANT	\N	PRESENT	0
449273	448563	19647E	PARTICIPANT	\N	PRESENT	0
449274	448563	19711U	PARTICIPANT	\N	PRESENT	0
449275	448563	89017R	PARTICIPANT	\N	PRESENT	0
449276	448563	08011M	PARTICIPANT	\N	PRESENT	0
449277	448563	11070L	PARTICIPANT	\N	PRESENT	0
449278	448563	19671E	PARTICIPANT	\N	PRESENT	0
449279	448563	19741B	PARTICIPANT	\N	PRESENT	0
449280	448563	14121F	PARTICIPANT	\N	PRESENT	0
449281	448563	08010L	PARTICIPANT	\N	PRESENT	0
449354	439822	08015R	PARTICIPANT	\N	PRESENT	0
449355	439822	14211G	PARTICIPANT	\N	PRESENT	0
449356	439822	14061L	PARTICIPANT	\N	PRESENT	0
449357	439822	19747H	PARTICIPANT	\N	PRESENT	0
449358	439822	14187A	PARTICIPANT	\N	PRESENT	0
449359	439822	14033T	PARTICIPANT	\N	PRESENT	0
449360	439822	14179A	PARTICIPANT	\N	PRESENT	0
449361	439822	14217N	PARTICIPANT	\N	PRESENT	0
449362	439822	19467C	PARTICIPANT	\N	PRESENT	0
449363	439822	19741B	PARTICIPANT	\N	PRESENT	0
449364	439822	19629C	PARTICIPANT	\N	PRESENT	0
449365	439822	11066Q	PARTICIPANT	\N	PRESENT	0
449366	439822	19695N	PARTICIPANT	\N	PRESENT	0
449367	439822	11056N	PARTICIPANT	\N	PRESENT	0
449368	439822	14265W	PARTICIPANT	\N	PRESENT	0
449369	439822	07029T	PARTICIPANT	\N	PRESENT	0
449370	439822	14251Q	PARTICIPANT	\N	PRESENT	0
449371	439822	19758L	PARTICIPANT	\N	PRESENT	0
449372	439822	19383Y	PARTICIPANT	\N	PRESENT	0
449373	439822	19760E	PARTICIPANT	\N	PRESENT	0
449374	439822	19573D	PARTICIPANT	\N	PRESENT	0
449375	439822	14103D	PARTICIPANT	\N	PRESENT	0
449376	439822	19387D	PARTICIPANT	\N	PRESENT	0
449377	439822	19575F	PARTICIPANT	\N	PRESENT	0
449378	439822	19347U	PARTICIPANT	\N	PRESENT	0
449379	439822	04085P	PARTICIPANT	\N	PRESENT	0
449387	448370	19443T	PARTICIPANT	\N	PRESENT	0
449388	448370	14133K	PARTICIPANT	\N	PRESENT	0
449389	448370	01062T	PARTICIPANT	\N	PRESENT	0
449390	448370	11041F	PARTICIPANT	\N	PRESENT	0
449391	448370	04034C	PARTICIPANT	\N	PRESENT	0
449392	448370	14235Q	PARTICIPANT	\N	PRESENT	0
449394	448370	11054L	PARTICIPANT	\N	PRESENT	0
449395	448370	11066Q	PARTICIPANT	\N	PRESENT	0
449396	448370	19721W	PARTICIPANT	\N	PRESENT	0
449397	448370	14193X	PRESIDENT	0	PRESENT	0
449398	448370	14267Y	PARTICIPANT	\N	PRESENT	0
449399	448370	08061X	PARTICIPANT	\N	PRESENT	0
449400	448370	14097Y	PARTICIPANT	\N	PRESENT	0
449401	448370	01058X	PARTICIPANT	\N	PRESENT	0
449402	448370	08049C	PARTICIPANT	\N	PRESENT	0
449420	448370	12041X	PARTICIPANT	\N	PRESENT	0
449421	448370	14079W	PARTICIPANT	\N	PRESENT	0
449422	448370	14028W	PARTICIPANT	\N	PRESENT	0
449423	448370	19251M	PARTICIPANT	\N	PRESENT	0
449424	448370	14105F	PARTICIPANT	\N	PRESENT	0
449425	448370	98018T	PARTICIPANT	\N	PRESENT	0
449426	448370	98050T	PARTICIPANT	\N	PRESENT	0
449446	448851	14001X	PARTICIPANT	\N	PRESENT	0
449447	448851	19543W	PARTICIPANT	\N	PRESENT	0
449448	448851	19581D	PARTICIPANT	\N	PRESENT	0
449449	448851	04044E	PARTICIPANT	\N	PRESENT	0
449450	448851	19585H	PARTICIPANT	\N	PRESENT	0
449451	448851	01028R	PARTICIPANT	\N	PRESENT	0
449452	448851	19447X	PARTICIPANT	\N	PRESENT	0
449453	448851	14231L	PARTICIPANT	\N	PRESENT	0
424898	421729	14028W	PARTICIPANT	\N	EXCUSE	0
424920	421729	04086Q	PARTICIPANT	\N	EXCUSE	0
425188	424896	14028W	PARTICIPANT	\N	EXCUSE	0
425459	424896	14195A	PARTICIPANT	\N	EXCUSE	0
426306	423003	08045X	PARTICIPANT	\N	PRESENT	0
427403	414419	19515S	PARTICIPANT	\N	EXCUSE	0
428903	428897	19447X	PARTICIPANT	\N	PRESENT	0
428478	428477	19701S	PARTICIPANT	\N	PRESENT	0
428476	428367	99004R	PARTICIPANT	\N	PRESENT	0
428876	428871	01025N	PARTICIPANT	\N	PRESENT	0
428904	428897	11066Q	PARTICIPANT	\N	PRESENT	0
428905	428897	11067R	PARTICIPANT	\N	PRESENT	0
428906	428897	14215L	PARTICIPANT	\N	PRESENT	0
428907	428897	08052W	PARTICIPANT	\N	PRESENT	0
428908	428897	11072N	PARTICIPANT	\N	PRESENT	0
428909	428897	19649G	PARTICIPANT	\N	PRESENT	0
429200	428662	19766L	PARTICIPANT	\N	PRESENT	0
428911	428897	08043V	PARTICIPANT	\N	PRESENT	0
429191	428238	11101A	PARTICIPANT	\N	PRESENT	0
429192	428238	19507S	PARTICIPANT	\N	PRESENT	0
429193	428238	14207L	PARTICIPANT	\N	PRESENT	0
429194	428238	19747H	PARTICIPANT	\N	PRESENT	0
429195	428238	04043D	PARTICIPANT	\N	PRESENT	0
429196	428238	14257W	PARTICIPANT	\N	PRESENT	0
429201	428662	04070G	PRESIDENT	0	PRESENT	0
429202	428662	19699S	PARTICIPANT	\N	PRESENT	0
429203	428662	04033B	PARTICIPANT	\N	PRESENT	0
429204	428662	14229S	PARTICIPANT	\N	PRESENT	0
429205	428662	19573D	PARTICIPANT	\N	PRESENT	0
429206	428662	14039A	PARTICIPANT	\N	PRESENT	0
429207	428662	14107H	PARTICIPANT	\N	PRESENT	0
429208	428662	08017T	PARTICIPANT	\N	PRESENT	0
429209	428662	19335Q	PARTICIPANT	\N	PRESENT	0
429210	428662	08039A	PARTICIPANT	\N	PRESENT	0
429211	428662	08031R	PARTICIPANT	\N	PRESENT	0
429212	428662	19593H	PARTICIPANT	\N	PRESENT	0
429213	428662	14061L	PARTICIPANT	\N	PRESENT	0
429214	428662	14073Q	PARTICIPANT	\N	PRESENT	0
429215	428662	08043V	PARTICIPANT	\N	PRESENT	0
429216	428662	19693L	PARTICIPANT	\N	PRESENT	0
429217	428662	19399H	PARTICIPANT	\N	PRESENT	0
429218	428662	14201E	PARTICIPANT	\N	PRESENT	0
429219	428662	14030Q	PARTICIPANT	\N	PRESENT	0
429220	428662	11083R	PARTICIPANT	\N	PRESENT	0
429221	428662	11104D	PARTICIPANT	\N	PRESENT	0
429222	428662	11043H	PARTICIPANT	\N	PRESENT	0
429223	428662	19749K	PARTICIPANT	\N	PRESENT	0
429224	428662	04018C	PARTICIPANT	\N	PRESENT	0
429225	428662	19758L	PARTICIPANT	\N	PRESENT	0
429226	428662	87003B	PARTICIPANT	\N	PRESENT	0
429227	428662	08012N	PARTICIPANT	\N	PRESENT	0
429228	428662	19611R	PARTICIPANT	\N	PRESENT	0
429229	428662	19731Y	PARTICIPANT	\N	PRESENT	0
429230	428662	14251Q	PARTICIPANT	\N	PRESENT	0
429231	428662	04059M	PARTICIPANT	\N	PRESENT	0
429232	428202	14327T	PARTICIPANT	\N	PRESENT	0
429233	428202	14331P	PARTICIPANT	\N	PRESENT	0
429234	428202	95041E	PARTICIPANT	\N	PRESENT	0
429235	428202	01057W	PARTICIPANT	\N	PRESENT	0
429236	428202	11053K	PARTICIPANT	\N	PRESENT	0
429237	428202	89017R	PARTICIPANT	\N	PRESENT	0
429238	428202	11074Q	PRESIDENT	1	PRESENT	0
429239	428202	19667J	PARTICIPANT	\N	PRESENT	0
429240	428202	11070L	PARTICIPANT	\N	PRESENT	0
429241	428202	19671E	PARTICIPANT	\N	PRESENT	0
429242	428202	14225N	PARTICIPANT	\N	PRESENT	0
429243	428202	88008L	PRESIDENT	0	PRESENT	0
429244	428202	07029T	PARTICIPANT	\N	PRESENT	0
429245	428202	14277B	PARTICIPANT	\N	PRESENT	0
429246	428202	19349W	PARTICIPANT	\N	PRESENT	0
429247	428202	08010L	PARTICIPANT	\N	PRESENT	0
429248	428202	14253S	PARTICIPANT	\N	PRESENT	0
429249	428202	19479G	PARTICIPANT	\N	PRESENT	0
429250	428202	19647E	PARTICIPANT	\N	PRESENT	0
429251	428202	11048N	PARTICIPANT	\N	PRESENT	0
429252	428202	19711U	PARTICIPANT	\N	PRESENT	0
429253	428202	08034U	PARTICIPANT	\N	PRESENT	0
429254	428202	19651A	PARTICIPANT	\N	PRESENT	0
429255	428202	08069G	PARTICIPANT	\N	PRESENT	0
429256	428202	19687N	PARTICIPANT	\N	PRESENT	0
429257	428202	12016W	PARTICIPANT	\N	PRESENT	0
429258	428202	08011M	PARTICIPANT	\N	PRESENT	0
429259	428202	08014Q	PARTICIPANT	\N	PRESENT	0
429260	428202	14159V	PARTICIPANT	\N	PRESENT	0
429261	428202	14173T	PARTICIPANT	\N	PRESENT	0
429262	428202	04086Q	PARTICIPANT	\N	PRESENT	0
429263	428202	11040E	PARTICIPANT	\N	PRESENT	0
429264	428202	14083S	PARTICIPANT	\N	PRESENT	0
429265	428202	14199E	PARTICIPANT	\N	PRESENT	0
429266	428202	19741B	PARTICIPANT	\N	PRESENT	0
429268	428662	14059S	PARTICIPANT	\N	PRESENT	0
429269	428662	08020N	PARTICIPANT	\N	PRESENT	0
429270	427448	19333N	PARTICIPANT	\N	PRESENT	0
429271	427448	19383Y	PARTICIPANT	\N	PRESENT	0
429272	427448	17583W	PARTICIPANT	\N	PRESENT	0
429273	427448	19794Q	PARTICIPANT	\N	PRESENT	0
429274	427448	04069P	PARTICIPANT	\N	PRESENT	0
429275	427448	19549D	PARTICIPANT	\N	PRESENT	0
429276	427448	19387D	PARTICIPANT	\N	PRESENT	0
429277	427448	14219Q	PARTICIPANT	\N	PRESENT	0
429278	427448	19820Y	PARTICIPANT	\N	PRESENT	0
429279	427448	14221J	PARTICIPANT	\N	PRESENT	0
429280	427448	19599P	PARTICIPANT	\N	PRESENT	0
429281	427448	05012A	PARTICIPANT	\N	PRESENT	0
429282	427448	08060W	PARTICIPANT	\N	PRESENT	0
429283	427448	19503N	PARTICIPANT	\N	PRESENT	0
429284	427448	14157T	PARTICIPANT	\N	PRESENT	0
429285	427448	19681G	PARTICIPANT	\N	PRESENT	0
429286	427448	08024S	PARTICIPANT	\N	PRESENT	0
429287	427448	19525U	PARTICIPANT	\N	PRESENT	0
429288	427448	14038Y	PRESIDENT	0	PRESENT	0
429289	427448	14103D	PARTICIPANT	\N	PRESENT	0
429290	427448	14031R	PARTICIPANT	\N	PRESENT	0
429291	427448	19713W	PARTICIPANT	\N	PRESENT	0
429292	427448	08055A	PARTICIPANT	\N	PRESENT	0
429293	427448	14191V	PARTICIPANT	\N	PRESENT	0
429294	427448	14169X	PARTICIPANT	\N	PRESENT	0
429295	427448	04085P	PARTICIPANT	\N	PRESENT	0
429296	427448	14093U	PARTICIPANT	\N	PRESENT	0
429297	427448	19737F	PARTICIPANT	\N	PRESENT	0
429298	427448	19739H	PARTICIPANT	\N	PRESENT	0
429299	427448	14051J	PARTICIPANT	\N	EXCUSE	0
429300	427448	08009T	PARTICIPANT	\N	PRESENT	0
429301	428373	14001X	PARTICIPANT	\N	PRESENT	0
429302	428373	19543W	PARTICIPANT	\N	PRESENT	0
429303	428373	19581D	PARTICIPANT	\N	PRESENT	0
429304	428373	04044E	PARTICIPANT	\N	PRESENT	0
429305	428373	04047H	PARTICIPANT	\N	PRESENT	0
429306	428373	19675J	PARTICIPANT	\N	PRESENT	0
429307	428373	01028R	PARTICIPANT	\N	PRESENT	0
429308	428373	19447X	PARTICIPANT	\N	PRESENT	0
429309	428373	05008E	PRESIDENT	0	PRESENT	0
429310	428373	19489J	PARTICIPANT	\N	PRESENT	0
429311	428373	14275Y	PARTICIPANT	\N	PRESENT	0
429312	428373	14041T	PARTICIPANT	\N	PRESENT	0
429313	428373	14147R	PARTICIPANT	\N	PRESENT	0
429314	428373	14215L	PRESIDENT	1	PRESENT	0
429315	428373	11072N	PARTICIPANT	\N	PRESENT	0
429316	428373	98035U	PARTICIPANT	\N	PRESENT	0
429317	428373	19649G	PARTICIPANT	\N	PRESENT	0
429318	428373	14065Q	PARTICIPANT	\N	PRESENT	0
429319	428373	14111D	PARTICIPANT	\N	PRESENT	0
429320	428373	11010L	PARTICIPANT	\N	PRESENT	0
429321	428373	11026G	PARTICIPANT	\N	PRESENT	0
429322	428373	19253P	PARTICIPANT	\N	PRESENT	0
429323	428373	01024M	PARTICIPANT	\N	PRESENT	0
429324	428373	04038G	PARTICIPANT	\N	PRESENT	0
429325	428373	19729F	PARTICIPANT	\N	PRESENT	0
429326	428373	14021P	PARTICIPANT	\N	PRESENT	0
429327	428373	19762G	PARTICIPANT	\N	PRESENT	0
429328	428373	08018U	PARTICIPANT	\N	EXCUSE	0
429329	428373	19585H	PARTICIPANT	\N	EXCUSE	0
429330	428662	07033P	PARTICIPANT	\N	PRESENT	0
429331	428662	19643A	PARTICIPANT	\N	PRESENT	0
429332	427448	14237S	PARTICIPANT	\N	PRESENT	0
429333	427448	19745F	PARTICIPANT	\N	PRESENT	0
429334	428662	19735D	PARTICIPANT	\N	PRESENT	0
429335	428662	14241N	PARTICIPANT	\N	PRESENT	0
429336	427448	19826F	PARTICIPANT	\N	PRESENT	0
429337	427448	04097T	PARTICIPANT	\N	PRESENT	0
429338	428202	04071H	PARTICIPANT	\N	PRESENT	0
429339	428202	01048V	PARTICIPANT	\N	PRESENT	0
429340	428202	14085U	PARTICIPANT	\N	PRESENT	0
429341	427859	19443T	PARTICIPANT	\N	PRESENT	0
429342	427859	04034C	PARTICIPANT	\N	PRESENT	0
429343	427859	01058X	PARTICIPANT	\N	PRESENT	0
429344	427859	11027H	PARTICIPANT	\N	PRESENT	0
429345	427859	16685X	PARTICIPANT	\N	PRESENT	0
460815	456887	11072N	PARTICIPANT	\N	PRESENT	0
460816	456887	14059S	PARTICIPANT	\N	PRESENT	0
460817	456887	08019V	PRESIDENT	0	PRESENT	0
460813	456887	14038Y	PARTICIPANT	\N	EXCUSE	0
460814	456887	19729F	PARTICIPANT	\N	PRESENT	0
460818	456887	14030Q	PARTICIPANT	\N	PRESENT	0
460819	456887	19731Y	PARTICIPANT	\N	PRESENT	0
460820	456887	14109K	PARTICIPANT	\N	PRESENT	0
460821	456887	08043V	PARTICIPANT	\N	PRESENT	0
463522	463521	14030Q	PRESIDENT	0	PRESENT	0
463523	463521	19621T	PARTICIPANT	\N	PRESENT	0
463524	463521	11031D	PARTICIPANT	\N	PRESENT	0
463525	463521	19693L	PARTICIPANT	\N	PRESENT	0
463526	463521	08031R	PARTICIPANT	\N	PRESENT	0
463527	463521	08017T	PARTICIPANT	\N	PRESENT	0
463528	463521	11045K	PARTICIPANT	\N	PRESENT	0
463529	463521	08043V	PARTICIPANT	\N	PRESENT	0
463530	463521	19701S	PARTICIPANT	\N	PRESENT	0
463532	463531	04085P	PARTICIPANT	\N	PRESENT	0
463533	463531	08055A	PARTICIPANT	\N	PRESENT	0
463534	463531	14093U	PARTICIPANT	\N	PRESENT	0
463535	463531	19549D	PARTICIPANT	\N	PRESENT	0
463536	463531	08060W	PARTICIPANT	\N	PRESENT	0
463537	463531	19733B	PARTICIPANT	\N	PRESENT	0
463538	463531	08024S	PARTICIPANT	\N	PRESENT	0
463539	463531	19383Y	PARTICIPANT	\N	PRESENT	0
463540	463531	14038Y	PARTICIPANT	\N	PRESENT	0
463541	463531	18083K	PARTICIPANT	\N	PRESENT	0
463543	463531	19701S	PARTICIPANT	\N	PRESENT	0
463544	463531	19681G	PARTICIPANT	\N	PRESENT	0
463545	463531	11065P	PARTICIPANT	\N	PRESENT	0
463546	463531	19599P	PARTICIPANT	\N	PRESENT	0
463547	463531	02002K	PARTICIPANT	\N	PRESENT	0
463548	463531	19820Y	PARTICIPANT	\N	PRESENT	0
463549	463531	19387D	PARTICIPANT	\N	PRESENT	0
463550	463531	19347U	PARTICIPANT	\N	PRESENT	0
463551	463531	19685L	PARTICIPANT	\N	PRESENT	0
463552	463531	19333N	PARTICIPANT	\N	PRESENT	0
463553	463531	04097T	PARTICIPANT	\N	PRESENT	0
463554	463531	19551W	PARTICIPANT	\N	PRESENT	0
463555	463531	14029X	PARTICIPANT	\N	PRESENT	0
463556	463531	14031R	PARTICIPANT	\N	PRESENT	0
463557	463531	14219Q	PARTICIPANT	\N	PRESENT	0
463558	463531	19637C	PARTICIPANT	\N	PRESENT	0
463559	463531	08009T	PRESIDENT	0	PRESENT	0
463560	463531	19826F	PARTICIPANT	\N	PRESENT	0
463561	463531	14221J	PARTICIPANT	\N	PRESENT	0
463562	463531	14169X	PARTICIPANT	\N	PRESENT	0
463563	463531	14237S	PARTICIPANT	\N	PRESENT	0
463564	463531	19745F	PARTICIPANT	\N	PRESENT	0
463565	463531	05012A	PARTICIPANT	\N	PRESENT	0
463566	463531	19503N	PARTICIPANT	\N	PRESENT	0
463567	463531	19739H	PARTICIPANT	\N	PRESENT	0
463568	463531	19794Q	PARTICIPANT	\N	PRESENT	0
463569	463531	04069P	PARTICIPANT	\N	PRESENT	0
463570	463531	14051J	PARTICIPANT	\N	PRESENT	0
463571	463531	14157T	PARTICIPANT	\N	PRESENT	0
463572	463531	19737F	PARTICIPANT	\N	PRESENT	0
463573	463531	17583W	PARTICIPANT	\N	PRESENT	0
463988	463595	04040A	PRESIDENT	0	PRESENT	0
463989	463595	11101A	PARTICIPANT	\N	PRESENT	0
463990	463595	14195A	PARTICIPANT	\N	PRESENT	0
463991	463595	19253P	PARTICIPANT	\N	PRESENT	0
463992	463595	04086Q	PARTICIPANT	\N	PRESENT	0
463993	463595	14259Y	PARTICIPANT	\N	PRESENT	0
463994	463595	08038Y	PARTICIPANT	\N	PRESENT	0
463995	463595	14327T	PARTICIPANT	\N	PRESENT	0
463996	463595	14281W	PARTICIPANT	\N	PRESENT	0
463997	463595	14231L	PARTICIPANT	\N	PRESENT	0
463998	463595	19820Y	PARTICIPANT	\N	PRESENT	0
463999	463595	19565D	PARTICIPANT	\N	PRESENT	0
464000	463595	11049P	PARTICIPANT	\N	PRESENT	0
464001	463595	01057W	PARTICIPANT	\N	PRESENT	0
464002	463595	11048N	PARTICIPANT	\N	PRESENT	0
464003	463595	19489J	PARTICIPANT	\N	PRESENT	0
464004	463595	08010L	PARTICIPANT	\N	PRESENT	0
464005	463595	14257W	PARTICIPANT	\N	PRESENT	0
464006	463595	14071N	PARTICIPANT	\N	PRESENT	0
464007	463595	17637T	PARTICIPANT	\N	PRESENT	0
464008	463595	05012A	PARTICIPANT	\N	PRESENT	0
464009	463595	19735D	PARTICIPANT	\N	PRESENT	0
464010	463595	95063L	PARTICIPANT	\N	PRESENT	0
464011	463595	19687N	PARTICIPANT	\N	PRESENT	0
464012	463595	04045F	PARTICIPANT	\N	PRESENT	0
464013	463595	04044E	PARTICIPANT	\N	PRESENT	0
464014	463595	95067Q	PARTICIPANT	\N	PRESENT	0
466209	466208	05008E	PARTICIPANT	\N	PRESENT	0
466210	466208	95063L	PARTICIPANT	\N	PRESENT	0
466211	466208	14069U	PARTICIPANT	\N	PRESENT	0
466212	466208	19719D	PARTICIPANT	\N	PRESENT	0
466213	466208	01024M	PARTICIPANT	\N	PRESENT	0
466214	466208	14215L	PARTICIPANT	\N	PRESENT	0
466215	466208	19725B	PARTICIPANT	\N	PRESENT	0
466216	466208	19447X	PARTICIPANT	\N	PRESENT	0
466217	466208	19489J	PARTICIPANT	\N	PRESENT	0
466218	466208	11085T	PARTICIPANT	\N	PRESENT	0
466219	466208	04044E	PARTICIPANT	\N	PRESENT	0
466222	466220	05008E	PARTICIPANT	\N	PRESENT	0
466223	466220	95063L	PARTICIPANT	\N	PRESENT	0
466224	466220	11026G	PARTICIPANT	\N	PRESENT	0
466225	466220	08018U	PARTICIPANT	\N	PRESENT	0
466226	466220	14041T	PARTICIPANT	\N	PRESENT	0
467804	466826	14030Q	PRESIDENT	0	PRESENT	0
467805	466826	08043V	PARTICIPANT	\N	PRESENT	0
467806	466826	19643A	PARTICIPANT	\N	PRESENT	0
467807	466826	08024S	PARTICIPANT	\N	PRESENT	0
467808	466826	19701S	PARTICIPANT	\N	PRESENT	0
467809	466826	19599P	PARTICIPANT	\N	PRESENT	0
467810	466826	19731Y	PARTICIPANT	\N	PRESENT	0
467811	466826	08031R	PARTICIPANT	\N	PRESENT	0
467812	466826	11067R	PARTICIPANT	\N	PRESENT	0
467813	466826	08020N	PARTICIPANT	\N	EXCUSE	0
467814	466826	07029T	PARTICIPANT	\N	EXCUSE	0
467815	466826	19693L	PARTICIPANT	\N	EXCUSE	0
468392	468391	19631V	PARTICIPANT	\N	PRESENT	0
468393	468391	19515S	PARTICIPANT	\N	PRESENT	0
468394	468391	19747H	PARTICIPANT	\N	PRESENT	0
468395	468391	08068F	PARTICIPANT	\N	PRESENT	0
468396	468391	19782L	PARTICIPANT	\N	PRESENT	0
468397	468391	14329V	PARTICIPANT	\N	PRESENT	0
468398	468391	08028W	PARTICIPANT	\N	PRESENT	0
468399	468391	19467C	PARTICIPANT	\N	PRESENT	0
468400	468391	19812Y	PARTICIPANT	\N	PRESENT	0
468401	468391	80013X	PARTICIPANT	\N	PRESENT	0
468402	468391	14357A	PARTICIPANT	\N	PRESENT	0
468404	468391	08038Y	PARTICIPANT	\N	PRESENT	0
468405	468391	19507S	PARTICIPANT	\N	PRESENT	0
468406	468391	14197C	PARTICIPANT	\N	PRESENT	0
468407	468391	14187A	PARTICIPANT	\N	PRESENT	0
468409	468391	01025N	PARTICIPANT	\N	PRESENT	0
468411	468391	19695N	PARTICIPANT	\N	PRESENT	0
468413	468391	14033T	PARTICIPANT	\N	PRESENT	0
468415	468391	14081Q	PARTICIPANT	\N	PRESENT	0
468417	468391	04049K	PARTICIPANT	\N	PRESENT	0
468418	468391	01043Q	PARTICIPANT	\N	PRESENT	0
468419	468391	19441R	PARTICIPANT	\N	PRESENT	0
468420	468391	14207L	PARTICIPANT	\N	PRESENT	0
468421	468391	11099A	PARTICIPANT	\N	PRESENT	0
468422	468391	19563B	PARTICIPANT	\N	PRESENT	0
468423	468391	19369B	PARTICIPANT	\N	PRESENT	0
468424	468391	14257W	PARTICIPANT	\N	PRESENT	0
468425	468391	14265W	PARTICIPANT	\N	PRESENT	0
468426	468391	11090Q	PARTICIPANT	\N	PRESENT	0
468427	468391	14135M	PARTICIPANT	\N	PRESENT	0
468428	468391	19705W	PARTICIPANT	\N	PRESENT	0
468429	468391	04045F	PARTICIPANT	\N	PRESENT	0
468483	468261	98005N	PARTICIPANT	\N	PRESENT	0
468484	468261	19443T	PARTICIPANT	\N	PRESENT	0
468485	468261	12041X	PARTICIPANT	\N	PRESENT	0
468486	468261	95030B	PARTICIPANT	\N	PRESENT	0
468487	468261	04034C	PARTICIPANT	\N	PRESENT	0
468488	468261	14079W	PARTICIPANT	\N	PRESENT	0
468489	468261	01058X	PARTICIPANT	\N	PRESENT	0
468490	468261	04040A	PARTICIPANT	\N	PRESENT	0
468491	468261	11027H	PARTICIPANT	\N	PRESENT	0
468492	468261	16685X	PARTICIPANT	\N	PRESENT	0
468493	468261	04042C	PRESIDENT	0	PRESENT	0
468494	468261	11054L	PARTICIPANT	\N	PRESENT	0
468495	468261	11066Q	PARTICIPANT	\N	PRESENT	0
468496	468261	08056B	PARTICIPANT	\N	PRESENT	0
468497	468261	11115U	PARTICIPANT	\N	PRESENT	0
468498	468261	19421M	PARTICIPANT	\N	PRESENT	0
468499	468261	19709B	PARTICIPANT	\N	PRESENT	0
468500	468261	14193X	PARTICIPANT	\N	PRESENT	0
468501	468261	08053X	PARTICIPANT	\N	PRESENT	0
468502	468261	97011G	PARTICIPANT	\N	PRESENT	0
468503	468261	08061X	PARTICIPANT	\N	PRESENT	0
468504	468261	08047A	PARTICIPANT	\N	PRESENT	0
468505	468261	98029W	PARTICIPANT	\N	PRESENT	0
464823	464342	80013X	PARTICIPANT	\N	PRESENT	0
464824	464342	04045F	PARTICIPANT	\N	PRESENT	0
464825	464342	19631V	PARTICIPANT	\N	PRESENT	0
464826	464342	19269X	PARTICIPANT	\N	PRESENT	0
464827	464342	14205J	PARTICIPANT	\N	PRESENT	0
464828	464342	11056N	PARTICIPANT	\N	PRESENT	0
464829	464342	14119M	PARTICIPANT	\N	PRESENT	0
464830	464342	08015R	PARTICIPANT	\N	PRESENT	0
464831	464342	14197C	PARTICIPANT	\N	PRESENT	0
464832	464342	19369B	PARTICIPANT	\N	PRESENT	0
464833	464342	14207L	PARTICIPANT	\N	PRESENT	0
464834	464342	04043D	PARTICIPANT	\N	PRESENT	0
464835	464342	08028W	PARTICIPANT	\N	PRESENT	0
464836	464342	19619A	PARTICIPANT	\N	PRESENT	0
464837	464342	14257W	PARTICIPANT	\N	PRESENT	0
464841	464342	19768N	PARTICIPANT	\N	PRESENT	0
464842	464342	19782L	PARTICIPANT	\N	PRESENT	0
464843	464342	19441R	PARTICIPANT	\N	PRESENT	0
464844	464342	11099A	PARTICIPANT	\N	PRESENT	0
464845	464342	08068F	PARTICIPANT	\N	PRESENT	0
464846	464342	19705W	PARTICIPANT	\N	PRESENT	0
464847	464342	08019V	PARTICIPANT	\N	PRESENT	0
464848	464342	19563B	PARTICIPANT	\N	PRESENT	0
464849	464342	14033T	PARTICIPANT	\N	PRESENT	0
464850	464342	14115H	PARTICIPANT	\N	PRESENT	0
464851	464342	19747H	PARTICIPANT	\N	PRESENT	0
464868	464342	14265W	PARTICIPANT	\N	PRESENT	0
464881	464342	19413M	PARTICIPANT	\N	PRESENT	0
464952	464309	14327T	PARTICIPANT	\N	PRESENT	0
464953	464309	95041E	PARTICIPANT	\N	PRESENT	0
464954	464309	01048V	PARTICIPANT	\N	PRESENT	0
464955	464309	11074Q	PRESIDENT	0	PRESENT	0
464956	464309	19667J	PARTICIPANT	\N	PRESENT	0
464957	464309	19671E	PARTICIPANT	\N	PRESENT	0
464958	464309	88008L	PARTICIPANT	\N	PRESENT	0
464959	464309	14225N	PARTICIPANT	\N	PRESENT	0
464960	464309	11110B	PARTICIPANT	\N	PRESENT	0
464961	464309	14085U	PARTICIPANT	\N	PRESENT	0
464962	464309	96004D	PARTICIPANT	\N	PRESENT	0
464963	464309	19349W	PARTICIPANT	\N	PRESENT	0
464964	464309	08010L	PARTICIPANT	\N	PRESENT	0
464965	464309	14253S	PARTICIPANT	\N	PRESENT	0
464966	464309	11048N	PARTICIPANT	\N	PRESENT	0
464967	464309	19647E	PARTICIPANT	\N	PRESENT	0
464968	464309	19479G	PARTICIPANT	\N	PRESENT	0
464969	464309	19711U	PARTICIPANT	\N	PRESENT	0
464970	464309	19651A	PARTICIPANT	\N	PRESENT	0
464971	464309	19687N	PARTICIPANT	\N	PRESENT	0
464972	464309	19689Q	PARTICIPANT	\N	PRESENT	0
464973	464309	12016W	PARTICIPANT	\N	PRESENT	0
464974	464309	08011M	PARTICIPANT	\N	PRESENT	0
464975	464309	14034U	PARTICIPANT	\N	PRESENT	0
464976	464309	14173T	PARTICIPANT	\N	PRESENT	0
464977	464309	04086Q	PARTICIPANT	\N	PRESENT	0
464978	464309	11040E	PARTICIPANT	\N	PRESENT	0
464979	464309	14083S	PARTICIPANT	\N	PRESENT	0
464980	464309	14121F	PARTICIPANT	\N	PRESENT	0
464981	464309	19741B	PARTICIPANT	\N	PRESENT	0
464982	464309	99004R	PARTICIPANT	\N	PRESENT	0
464983	464309	14331P	PARTICIPANT	\N	PRESENT	0
464984	464309	19531S	PARTICIPANT	\N	PRESENT	0
464985	464309	01057W	PARTICIPANT	\N	PRESENT	0
465016	464309	04071H	PARTICIPANT	\N	PRESENT	0
465017	464309	19545Y	PARTICIPANT	\N	PRESENT	0
465018	464309	11053K	PARTICIPANT	\N	PRESENT	0
465054	465053	14133K	PARTICIPANT	\N	PRESENT	0
465055	465053	04040A	PARTICIPANT	\N	PRESENT	0
465056	465053	14105F	PARTICIPANT	\N	PRESENT	0
465057	465053	08058D	PARTICIPANT	\N	PRESENT	0
465058	465053	14255U	PARTICIPANT	\N	PRESENT	0
465059	465053	04042C	PRESIDENT	0	PRESENT	0
465060	465053	98029W	PARTICIPANT	\N	PRESENT	0
465061	465053	14267Y	PARTICIPANT	\N	PRESENT	0
465062	465053	11027H	PARTICIPANT	\N	PRESENT	0
465063	465053	11115U	PARTICIPANT	\N	PRESENT	0
465064	465053	98018T	PARTICIPANT	\N	PRESENT	0
465065	465053	19251M	PARTICIPANT	\N	PRESENT	0
465066	465053	95030B	PARTICIPANT	\N	PRESENT	0
465067	465053	04035D	PARTICIPANT	\N	PRESENT	0
465068	465053	08056B	PARTICIPANT	\N	PRESENT	0
465069	465053	98022P	PARTICIPANT	\N	PRESENT	0
465070	465053	11064N	PARTICIPANT	\N	PRESENT	0
465071	465053	95037J	PARTICIPANT	\N	PRESENT	0
465072	465053	14097Y	PARTICIPANT	\N	PRESENT	0
465073	465053	98005N	PARTICIPANT	\N	PRESENT	0
465074	465053	12041X	PARTICIPANT	\N	PRESENT	0
465075	465053	19709B	PARTICIPANT	\N	PRESENT	0
465076	465053	16685X	PARTICIPANT	\N	PRESENT	0
465077	465053	08053X	PARTICIPANT	\N	PRESENT	0
465078	465053	08061X	PARTICIPANT	\N	PRESENT	0
465079	465053	08047A	PARTICIPANT	\N	PRESENT	0
465080	465053	14028W	PARTICIPANT	\N	PRESENT	0
465081	465053	14193X	PARTICIPANT	\N	PRESENT	0
465082	465053	98050T	PARTICIPANT	\N	PRESENT	0
465083	465053	14235Q	PARTICIPANT	\N	PRESENT	0
465084	465053	19443T	PARTICIPANT	\N	PRESENT	0
465085	465053	11054L	PARTICIPANT	\N	PRESENT	0
465086	465053	19421M	PARTICIPANT	\N	PRESENT	0
465087	465053	01058X	PARTICIPANT	\N	PRESENT	0
465088	465053	19669L	PARTICIPANT	\N	PRESENT	0
465089	465053	01062T	PARTICIPANT	\N	PRESENT	0
465090	465053	11041F	PARTICIPANT	\N	PRESENT	0
465091	465053	08049C	PARTICIPANT	\N	PRESENT	0
465092	465053	11066Q	PARTICIPANT	\N	PRESENT	0
465093	465053	95067Q	PARTICIPANT	\N	PRESENT	0
465094	465053	04034C	PARTICIPANT	\N	PRESENT	0
465641	465288	89017R	PARTICIPANT	\N	PRESENT	0
465642	465288	19651A	PARTICIPANT	\N	PRESENT	0
465643	465288	19741B	PARTICIPANT	\N	PRESENT	0
465644	465288	19667J	PARTICIPANT	\N	PRESENT	0
465645	465288	11040E	PARTICIPANT	\N	PRESENT	0
465646	465288	14085U	PARTICIPANT	\N	PRESENT	0
465647	465288	04086Q	PARTICIPANT	\N	PRESENT	0
465648	465288	11074Q	PRESIDENT	0	PRESENT	0
465649	465288	11070L	PARTICIPANT	\N	PRESENT	0
465650	465288	14034U	PARTICIPANT	\N	PRESENT	0
465651	465288	11048N	PARTICIPANT	\N	PRESENT	0
465652	465288	08010L	PARTICIPANT	\N	PRESENT	0
465653	465288	19479G	PARTICIPANT	\N	PRESENT	0
465654	465288	08011M	PARTICIPANT	\N	PRESENT	0
465655	465288	14225N	PARTICIPANT	\N	PRESENT	0
465656	465288	19349W	PARTICIPANT	\N	PRESENT	0
465657	465288	14331P	PARTICIPANT	\N	PRESENT	0
465658	465288	01048V	PARTICIPANT	\N	PRESENT	0
465659	465288	14083S	PARTICIPANT	\N	PRESENT	0
465660	465288	11053K	PARTICIPANT	\N	PRESENT	0
465661	465288	14327T	PARTICIPANT	\N	PRESENT	0
465662	465288	19531S	PARTICIPANT	\N	PRESENT	0
465663	465288	95041E	PARTICIPANT	\N	PRESENT	0
465664	465288	14121F	PARTICIPANT	\N	PRESENT	0
465665	465288	11110B	PARTICIPANT	\N	PRESENT	0
465774	465772	19503N	PARTICIPANT	\N	PRESENT	0
465780	465775	19503N	PARTICIPANT	\N	PRESENT	0
465782	465777	19503N	PARTICIPANT	\N	PRESENT	0
465784	465778	19503N	PARTICIPANT	\N	PRESENT	0
466139	466138	04038G	PARTICIPANT	\N	PRESENT	0
466140	466138	14231L	PARTICIPANT	\N	PRESENT	0
466141	466138	14215L	PARTICIPANT	\N	PRESENT	0
466142	466138	19725B	PARTICIPANT	\N	PRESENT	0
466144	466143	04038G	PARTICIPANT	\N	PRESENT	0
466145	466143	14231L	PARTICIPANT	\N	PRESENT	0
466146	466143	14215L	PARTICIPANT	\N	PRESENT	0
466148	466147	04038G	PARTICIPANT	\N	PRESENT	0
466149	466147	14231L	PARTICIPANT	\N	PRESENT	0
466150	466147	14215L	PARTICIPANT	\N	PRESENT	0
466152	466151	14053L	PARTICIPANT	\N	PRESENT	0
466153	466151	04038G	PARTICIPANT	\N	PRESENT	0
466154	466151	14215L	PARTICIPANT	\N	PRESENT	0
466155	466151	14231L	PARTICIPANT	\N	PRESENT	0
466156	466151	19725B	PARTICIPANT	\N	PRESENT	0
466157	466151	19489J	PARTICIPANT	\N	PRESENT	0
466158	466151	11085T	PARTICIPANT	\N	PRESENT	0
466160	466159	14231L	PARTICIPANT	\N	PRESENT	0
466161	466159	14215L	PARTICIPANT	\N	PRESENT	0
466162	466159	04038G	PARTICIPANT	\N	PRESENT	0
466163	466159	19447X	PARTICIPANT	\N	PRESENT	0
466165	466164	04038G	PARTICIPANT	\N	PRESENT	0
466166	466164	14231L	PARTICIPANT	\N	PRESENT	0
466167	466164	14215L	PARTICIPANT	\N	PRESENT	0
466169	466168	04038G	PARTICIPANT	\N	PRESENT	0
466170	466168	14215L	PARTICIPANT	\N	PRESENT	0
466171	466168	01024M	PARTICIPANT	\N	PRESENT	0
466172	466168	14231L	PARTICIPANT	\N	PRESENT	0
466173	466168	95063L	PARTICIPANT	\N	PRESENT	0
455310	455309	19507S	PARTICIPANT	\N	PRESENT	0
455311	455309	14207L	PARTICIPANT	\N	PRESENT	0
455312	455309	14257W	PARTICIPANT	\N	PRESENT	0
455313	455309	19269X	PARTICIPANT	\N	PRESENT	0
455314	455309	19413M	PARTICIPANT	\N	PRESENT	0
455352	455350	19575F	PARTICIPANT	\N	PRESENT	0
455353	455350	19747H	PARTICIPANT	\N	PRESENT	0
455354	455350	14083S	PARTICIPANT	\N	PRESENT	0
455355	455350	80013X	PARTICIPANT	\N	PRESENT	0
455356	455350	01024M	PARTICIPANT	\N	PRESENT	0
455357	455350	14197C	PARTICIPANT	\N	PRESENT	0
455358	455350	14033T	PARTICIPANT	\N	PRESENT	0
455359	455350	19333N	PARTICIPANT	\N	PRESENT	0
455360	455350	04097T	PARTICIPANT	\N	PRESENT	0
455361	455350	11048N	PARTICIPANT	\N	PRESENT	0
455362	455350	19551W	PARTICIPANT	\N	PRESENT	0
455363	455350	14265W	PARTICIPANT	\N	PRESENT	0
455364	455350	19533U	PARTICIPANT	\N	PRESENT	0
455365	455350	04088S	PARTICIPANT	\N	PRESENT	0
455366	455350	19503N	PARTICIPANT	\N	PRESENT	0
455367	455350	19739H	PARTICIPANT	\N	PRESENT	0
455368	455350	19619A	PARTICIPANT	\N	PRESENT	0
455369	455350	01058X	PARTICIPANT	\N	PRESENT	0
463508	463507	04070G	PRESIDENT	0	PRESENT	0
463509	463507	19621T	PARTICIPANT	\N	PRESENT	0
463510	463507	14123H	PARTICIPANT	\N	PRESENT	0
463511	463507	19693L	PARTICIPANT	\N	PRESENT	0
463512	463507	19533U	PARTICIPANT	\N	PRESENT	0
463513	463507	14229S	PARTICIPANT	\N	PRESENT	0
463514	463507	08043V	PARTICIPANT	\N	PRESENT	0
463515	463507	11083R	PARTICIPANT	\N	PRESENT	0
463516	463507	19611R	PARTICIPANT	\N	PRESENT	0
463517	463507	19735D	PARTICIPANT	\N	PRESENT	0
463518	463507	04057K	PARTICIPANT	\N	PRESENT	0
463519	463507	19593H	PARTICIPANT	\N	PRESENT	0
463737	463607	19693L	PARTICIPANT	\N	PRESENT	0
463738	463607	19723Y	PARTICIPANT	\N	PRESENT	0
463739	463607	01048V	PARTICIPANT	\N	PRESENT	0
463740	463607	19593H	PARTICIPANT	\N	PRESENT	0
463741	463607	19533U	PARTICIPANT	\N	PRESENT	0
463742	463607	04043D	PARTICIPANT	\N	PRESENT	0
463743	463607	14093U	PARTICIPANT	\N	EXCUSE	0
463745	463744	11053K	PARTICIPANT	\N	PRESENT	0
463746	463744	14159V	PARTICIPANT	\N	PRESENT	0
463747	463744	05012A	PARTICIPANT	\N	PRESENT	0
466512	465365	14261S	PARTICIPANT	\N	EXCUSE	0
466513	465365	19717B	PARTICIPANT	\N	EXCUSE	0
466514	465365	19663E	PARTICIPANT	\N	EXCUSE	0
466515	465365	14281W	PARTICIPANT	\N	EXCUSE	0
466516	465365	14355X	PARTICIPANT	\N	EXCUSE	0
466517	465365	08041T	PARTICIPANT	\N	EXCUSE	0
466518	465365	19691J	PARTICIPANT	\N	EXCUSE	0
466519	465365	19591F	PARTICIPANT	\N	EXCUSE	0
466520	465365	11045K	PARTICIPANT	\N	EXCUSE	0
466521	465365	14227Q	PARTICIPANT	\N	EXCUSE	0
470169	470168	05008E	PARTICIPANT	\N	PRESENT	0
470170	470168	14215L	PARTICIPANT	\N	PRESENT	0
470171	470168	01024M	PARTICIPANT	\N	PRESENT	0
470172	470168	95063L	PARTICIPANT	\N	PRESENT	0
470173	470168	10015M	PARTICIPANT	\N	PRESENT	0
470174	470168	14147R	PARTICIPANT	\N	PRESENT	0
470175	469648	01048V	PARTICIPANT	\N	PRESENT	0
470353	470352	11070L	PARTICIPANT	\N	PRESENT	0
470354	470352	11040E	PARTICIPANT	\N	PRESENT	0
470355	470352	19711U	PARTICIPANT	\N	PRESENT	0
470443	468732	19443T	PARTICIPANT	\N	PRESENT	0
479095	479094	04040A	PRESIDENT	0	PRESENT	0
479287	479286	05008E	PARTICIPANT	\N	PRESENT	0
479307	479304	04018C	PARTICIPANT	\N	PRESENT	0
479308	479304	08039A	PARTICIPANT	\N	PRESENT	0
479290	479286	14041T	PARTICIPANT	\N	PRESENT	0
479291	479286	14215L	PRESIDENT	0	PRESENT	0
479309	479304	14109K	PARTICIPANT	\N	PRESENT	0
479310	479304	19749K	PARTICIPANT	\N	PRESENT	0
481111	481110	08058D	PARTICIPANT	\N	PRESENT	0
479295	479286	19611R	PARTICIPANT	\N	PRESENT	0
479296	479286	11026G	PARTICIPANT	\N	PRESENT	0
479297	479286	11085T	PARTICIPANT	\N	PRESENT	0
479298	479286	95063L	PARTICIPANT	\N	PRESENT	0
479299	479286	01028R	PARTICIPANT	\N	PRESENT	0
481116	481115	08058D	PARTICIPANT	\N	PRESENT	0
482414	481507	19679N	PARTICIPANT	\N	PRESENT	0
482415	481507	19798U	PARTICIPANT	\N	PRESENT	0
482416	481507	11045K	PARTICIPANT	\N	PRESENT	0
482417	481507	08041T	PARTICIPANT	\N	EXCUSE	0
482418	481626	08060W	PARTICIPANT	\N	EXCUSE	0
482419	480818	14133K	PARTICIPANT	\N	PRESENT	0
482420	480818	04040A	PARTICIPANT	\N	PRESENT	0
482421	480818	08058D	PARTICIPANT	\N	PRESENT	0
482422	480818	14255U	PARTICIPANT	\N	PRESENT	0
482423	480818	04042C	PRESIDENT	0	PRESENT	0
482424	480818	98029W	PARTICIPANT	\N	PRESENT	0
482425	480818	14267Y	PARTICIPANT	\N	PRESENT	0
482426	480818	98018T	PARTICIPANT	\N	PRESENT	0
482427	480818	19251M	PARTICIPANT	\N	PRESENT	0
482428	480818	95030B	PARTICIPANT	\N	PRESENT	0
482429	480818	97011G	PARTICIPANT	\N	PRESENT	0
482430	480818	04035D	PARTICIPANT	\N	PRESENT	0
482431	480818	08056B	PARTICIPANT	\N	PRESENT	0
482432	480818	11064N	PARTICIPANT	\N	PRESENT	0
482433	480818	12041X	PARTICIPANT	\N	PRESENT	0
482434	480818	19709B	PARTICIPANT	\N	PRESENT	0
482435	480818	16685X	PARTICIPANT	\N	PRESENT	0
482436	480818	08053X	PARTICIPANT	\N	PRESENT	0
482437	480818	14193X	PARTICIPANT	\N	PRESENT	0
482438	480818	19319Q	PARTICIPANT	\N	PRESENT	0
482439	480818	98050T	PARTICIPANT	\N	PRESENT	0
482440	480818	19443T	PARTICIPANT	\N	PRESENT	0
482441	480818	11054L	PARTICIPANT	\N	PRESENT	0
482442	480818	19421M	PARTICIPANT	\N	PRESENT	0
482443	480818	01058X	PARTICIPANT	\N	PRESENT	0
482444	480818	19669L	PARTICIPANT	\N	PRESENT	0
482445	480818	01062T	PARTICIPANT	\N	PRESENT	0
482446	480818	11041F	PARTICIPANT	\N	PRESENT	0
482447	480818	11066Q	PARTICIPANT	\N	PRESENT	0
482448	480818	04034C	PARTICIPANT	\N	PRESENT	0
482449	480818	08049C	PARTICIPANT	\N	EXCUSE	0
482450	481068	04086Q	PARTICIPANT	\N	PRESENT	0
482451	481068	04071H	PARTICIPANT	\N	PRESENT	0
482452	481068	19479G	PARTICIPANT	\N	PRESENT	0
482453	481068	19711U	PARTICIPANT	\N	PRESENT	0
482454	481068	19531S	PARTICIPANT	\N	PRESENT	0
482455	481068	14085U	PARTICIPANT	\N	PRESENT	0
482456	481068	07004J	PARTICIPANT	\N	PRESENT	0
482457	481068	19667J	PARTICIPANT	\N	PRESENT	0
482458	481068	11074Q	PRESIDENT	0	PRESENT	0
482459	481068	08011M	PARTICIPANT	\N	PRESENT	0
482460	481068	19762G	PARTICIPANT	\N	PRESENT	0
482473	481626	04085P	PARTICIPANT	\N	EXCUSE	0
482475	481626	19637C	PARTICIPANT	\N	EXCUSE	0
482463	481068	11053K	PARTICIPANT	\N	PRESENT	0
482466	482465	14083S	PARTICIPANT	\N	PRESENT	0
482476	481626	11065P	PARTICIPANT	\N	EXCUSE	0
482494	481068	08010L	PARTICIPANT	\N	PRESENT	0
482497	481068	11040E	PARTICIPANT	\N	PRESENT	0
482499	481068	14331P	PARTICIPANT	\N	PRESENT	0
482506	481068	11048N	PARTICIPANT	\N	PRESENT	0
482899	482898	11040E	PARTICIPANT	\N	PRESENT	0
482900	482898	80013X	PARTICIPANT	\N	PRESENT	0
482901	482898	11070L	PARTICIPANT	\N	PRESENT	0
482902	482898	19551W	PARTICIPANT	\N	PRESENT	0
482903	482898	14121F	PRESIDENT	0	PRESENT	0
482935	481067	19651A	PARTICIPANT	\N	PRESENT	0
482936	481067	11040E	PARTICIPANT	\N	PRESENT	0
482937	481067	07004J	PARTICIPANT	\N	PRESENT	0
482938	481067	14121F	PARTICIPANT	\N	PRESENT	0
482939	481067	12016W	PARTICIPANT	\N	PRESENT	0
482940	481067	19671E	PARTICIPANT	\N	PRESENT	0
482941	481067	14225N	PARTICIPANT	\N	PRESENT	0
482942	481067	11012A	PARTICIPANT	\N	PRESENT	0
482943	481067	19479G	PARTICIPANT	\N	PRESENT	0
482952	481136	19575F	PARTICIPANT	\N	PRESENT	0
482953	481136	14030Q	PARTICIPANT	\N	PRESENT	0
482954	481136	08060W	PARTICIPANT	\N	EXCUSE	0
482955	481136	89017R	PARTICIPANT	\N	EXCUSE	0
462146	459251	14069U	PARTICIPANT	\N	PRESENT	0
462147	459251	05012A	PARTICIPANT	\N	PRESENT	0
462148	459251	14255U	PARTICIPANT	\N	PRESENT	0
462149	459251	14083S	PARTICIPANT	\N	PRESENT	0
462245	462243	19507S	PARTICIPANT	\N	PRESENT	0
462247	462246	19507S	PARTICIPANT	\N	PRESENT	0
462251	462250	19515S	PARTICIPANT	\N	PRESENT	0
462294	446002	14030Q	PRESIDENT	0	PRESENT	0
462295	446002	08043V	PARTICIPANT	\N	PRESENT	0
462296	446002	11031D	PARTICIPANT	\N	PRESENT	0
462297	446002	19693L	PARTICIPANT	\N	PRESENT	0
462298	446002	14179A	PARTICIPANT	\N	EXCUSE	0
462299	446002	19715Y	PARTICIPANT	\N	EXCUSE	0
462300	446002	07029T	PARTICIPANT	\N	EXCUSE	0
462301	446002	08017T	PARTICIPANT	\N	PRESENT	0
462302	446002	11067R	PARTICIPANT	\N	PRESENT	0
462303	446002	19749K	PARTICIPANT	\N	PRESENT	0
462390	462389	14083S	PARTICIPANT	\N	PRESENT	0
462397	462396	19479G	PARTICIPANT	\N	PRESENT	0
462435	462434	19399H	PARTICIPANT	\N	PRESENT	0
462436	462434	19735D	PARTICIPANT	\N	PRESENT	0
462437	462434	04057K	PARTICIPANT	\N	PRESENT	0
462438	462434	08043V	PARTICIPANT	\N	PRESENT	0
462587	462478	19551W	PARTICIPANT	\N	PRESENT	0
462588	462478	11040E	PARTICIPANT	\N	PRESENT	0
462589	462478	08034U	PARTICIPANT	\N	PRESENT	0
462590	462478	19737F	PARTICIPANT	\N	PRESENT	0
462591	462478	19741B	PARTICIPANT	\N	PRESENT	0
462592	462478	14121F	PRESIDENT	0	PRESENT	0
462593	462478	11070L	PARTICIPANT	\N	PRESENT	0
462600	462568	07004J	PARTICIPANT	\N	PRESENT	0
462601	462568	19719D	PRESIDENT	0	PRESENT	0
462602	462568	08010L	PARTICIPANT	\N	PRESENT	0
462603	462568	19673G	PARTICIPANT	\N	PRESENT	0
462604	462568	19421M	PARTICIPANT	\N	EXCUSE	0
462605	462568	04044E	PARTICIPANT	\N	EXCUSE	0
462618	462617	11097X	PARTICIPANT	\N	PRESENT	0
462620	462619	11097X	PARTICIPANT	\N	PRESENT	0
462621	462619	01034P	PARTICIPANT	\N	PRESENT	0
463348	463347	11053K	PARTICIPANT	\N	PRESENT	0
463349	463347	14159V	PARTICIPANT	\N	PRESENT	0
463350	463347	05012A	PARTICIPANT	\N	PRESENT	0
463352	463351	14159V	PARTICIPANT	\N	PRESENT	0
463353	463351	05012A	PARTICIPANT	\N	PRESENT	0
463355	463354	11053K	PARTICIPANT	\N	PRESENT	0
463356	463354	14159V	PARTICIPANT	\N	PRESENT	0
463357	463354	05012A	PARTICIPANT	\N	PRESENT	0
463590	463589	19717B	PARTICIPANT	\N	PRESENT	0
463591	463589	19631V	PARTICIPANT	\N	PRESENT	0
463593	463592	04049K	PARTICIPANT	\N	PRESENT	0
463594	463592	16685X	PARTICIPANT	\N	PRESENT	0
464340	464191	19669L	PARTICIPANT	\N	PRESENT	0
464348	464347	19575F	PARTICIPANT	\N	PRESENT	0
464349	464347	14030Q	PARTICIPANT	\N	PRESENT	0
464350	464347	14255U	PARTICIPANT	\N	PRESENT	0
464351	464347	14329V	PARTICIPANT	\N	PRESENT	0
464352	464347	14105F	PARTICIPANT	\N	PRESENT	0
464353	464347	14041T	PARTICIPANT	\N	PRESENT	0
464354	464347	14087W	PARTICIPANT	\N	PRESENT	0
464355	464347	19521Q	PARTICIPANT	\N	PRESENT	0
464356	464347	14061L	PARTICIPANT	\N	PRESENT	0
464357	464347	16685X	PARTICIPANT	\N	PRESENT	0
464358	464347	19671E	PARTICIPANT	\N	PRESENT	0
464359	464347	19695N	PARTICIPANT	\N	PRESENT	0
464360	464347	14157T	PARTICIPANT	\N	PRESENT	0
464361	464347	19515S	PARTICIPANT	\N	PRESENT	0
464440	464307	11074Q	PRESIDENT	0	PRESENT	0
464452	463587	14069U	PARTICIPANT	\N	PRESENT	0
464453	463587	14089Y	PARTICIPANT	\N	PRESENT	0
464454	463587	14053L	PARTICIPANT	\N	PRESENT	0
464455	463587	19629C	PARTICIPANT	\N	PRESENT	0
464456	463587	04038G	PARTICIPANT	\N	PRESENT	0
464457	463587	19253P	PARTICIPANT	\N	PRESENT	0
464458	463587	14259Y	PARTICIPANT	\N	PRESENT	0
464459	463587	19719D	PARTICIPANT	\N	PRESENT	0
464460	463587	01024M	PARTICIPANT	\N	PRESENT	0
464461	463587	14215L	PARTICIPANT	\N	PRESENT	0
464462	463587	14151M	PARTICIPANT	\N	PRESENT	0
464463	463587	19673G	PARTICIPANT	\N	PRESENT	0
464464	463587	08045X	PARTICIPANT	\N	PRESENT	0
464465	463587	14231L	PARTICIPANT	\N	PRESENT	0
464466	463587	19649G	PARTICIPANT	\N	PRESENT	0
464467	463587	19725B	PARTICIPANT	\N	PRESENT	0
464468	463587	14179A	PARTICIPANT	\N	PRESENT	0
464469	463587	08044W	PARTICIPANT	\N	PRESENT	0
464470	463587	19447X	PARTICIPANT	\N	PRESENT	0
464471	463587	19489J	PARTICIPANT	\N	PRESENT	0
464472	463587	19581D	PARTICIPANT	\N	PRESENT	0
464473	463587	14111D	PARTICIPANT	\N	PRESENT	0
464474	463587	14001X	PARTICIPANT	\N	PRESENT	0
464475	463587	11085T	PARTICIPANT	\N	PRESENT	0
464476	463587	14147R	PARTICIPANT	\N	PRESENT	0
464477	463587	11072N	PARTICIPANT	\N	PRESENT	0
464478	463587	10015M	PARTICIPANT	\N	PRESENT	0
464479	463587	95063L	PARTICIPANT	\N	PRESENT	0
464391	464307	89017R	PARTICIPANT	\N	PRESENT	0
464480	463587	19762G	PARTICIPANT	\N	PRESENT	0
464393	464307	19741B	PARTICIPANT	\N	PRESENT	0
464394	464307	19667J	PARTICIPANT	\N	PRESENT	0
464395	464307	96004D	PARTICIPANT	\N	PRESENT	0
464396	464307	11040E	PARTICIPANT	\N	PRESENT	0
464481	463587	01028R	PARTICIPANT	\N	PRESENT	0
464398	464307	14083S	PARTICIPANT	\N	PRESENT	0
464399	464307	11053K	PARTICIPANT	\N	PRESENT	0
464400	464307	19545Y	PARTICIPANT	\N	PRESENT	0
464401	464307	14085U	PARTICIPANT	\N	PRESENT	0
464402	464307	88008L	PARTICIPANT	\N	PRESENT	0
464403	464307	04086Q	PARTICIPANT	\N	PRESENT	0
464482	463587	19675J	PARTICIPANT	\N	PRESENT	0
464405	464307	14327T	PARTICIPANT	\N	PRESENT	0
464483	463587	04044E	PARTICIPANT	\N	PRESENT	0
464558	464308	19651A	PARTICIPANT	\N	PRESENT	0
464408	464307	11110B	PARTICIPANT	\N	PRESENT	0
464559	464308	19741B	PARTICIPANT	\N	PRESENT	0
464410	464307	14034U	PARTICIPANT	\N	PRESENT	0
464560	464308	19667J	PARTICIPANT	\N	PRESENT	0
464561	464308	96004D	PARTICIPANT	\N	PRESENT	0
464413	464307	01057W	PARTICIPANT	\N	PRESENT	0
464562	464308	14327T	PARTICIPANT	\N	PRESENT	0
464415	464307	11048N	PARTICIPANT	\N	PRESENT	0
464416	464307	14121F	PARTICIPANT	\N	PRESENT	0
464417	464307	19531S	PARTICIPANT	\N	PRESENT	0
464563	464308	04086Q	PARTICIPANT	\N	PRESENT	0
464419	464307	99004R	PARTICIPANT	\N	PRESENT	0
464564	464308	14085U	PARTICIPANT	\N	PRESENT	0
464565	464308	11053K	PARTICIPANT	\N	PRESENT	0
464566	464308	14083S	PARTICIPANT	\N	PRESENT	0
464423	464307	19711U	PARTICIPANT	\N	PRESENT	0
464567	464308	19545Y	PARTICIPANT	\N	PRESENT	0
464568	464308	11040E	PARTICIPANT	\N	PRESENT	0
464426	464307	01048V	PARTICIPANT	\N	PRESENT	0
464427	464307	12016W	PARTICIPANT	\N	PRESENT	0
464428	464307	19671E	PARTICIPANT	\N	PRESENT	0
464429	464307	08011M	PARTICIPANT	\N	PRESENT	0
464569	464308	11074Q	PRESIDENT	0	PRESENT	0
464570	464308	19711U	PARTICIPANT	\N	PRESENT	0
464432	464307	19349W	PARTICIPANT	\N	PRESENT	0
464433	464307	14331P	PARTICIPANT	\N	PRESENT	0
464571	464308	08010L	PARTICIPANT	\N	PRESENT	0
464572	464308	99004R	PARTICIPANT	\N	PRESENT	0
464573	464308	08011M	PARTICIPANT	\N	PRESENT	0
464437	464307	19689Q	PARTICIPANT	\N	PRESENT	0
464438	464307	19479G	PARTICIPANT	\N	PRESENT	0
464574	464308	19671E	PARTICIPANT	\N	PRESENT	0
464575	464308	19349W	PARTICIPANT	\N	PRESENT	0
464576	464308	19531S	PARTICIPANT	\N	PRESENT	0
464577	464308	14121F	PARTICIPANT	\N	PRESENT	0
464578	464308	07004J	PARTICIPANT	\N	PRESENT	0
464579	464308	14034U	PARTICIPANT	\N	PRESENT	0
464580	464308	19647E	PARTICIPANT	\N	PRESENT	0
464581	464308	01057W	PARTICIPANT	\N	PRESENT	0
464582	464308	11048N	PARTICIPANT	\N	PRESENT	0
464583	464308	14173T	PARTICIPANT	\N	PRESENT	0
464584	464308	19479G	PARTICIPANT	\N	PRESENT	0
464585	464308	14225N	PARTICIPANT	\N	PRESENT	0
464586	464308	14331P	PARTICIPANT	\N	PRESENT	0
465146	465145	04070G	PRESIDENT	0	PRESENT	0
465147	465145	08043V	PARTICIPANT	\N	PRESENT	0
465148	465145	08039A	PARTICIPANT	\N	PRESENT	0
465149	465145	19399H	PARTICIPANT	\N	PRESENT	0
465150	465145	14229S	PARTICIPANT	\N	PRESENT	0
465151	465145	04059M	PARTICIPANT	\N	PRESENT	0
465152	465145	08031R	PARTICIPANT	\N	PRESENT	0
465153	465145	04018C	PARTICIPANT	\N	PRESENT	0
465154	465145	19749K	PARTICIPANT	\N	PRESENT	0
465155	465145	19699S	PARTICIPANT	\N	PRESENT	0
465156	465145	19735D	PARTICIPANT	\N	PRESENT	0
465157	465145	19758L	PARTICIPANT	\N	PRESENT	0
465158	465145	04057K	PARTICIPANT	\N	PRESENT	0
455372	454054	98029W	PARTICIPANT	\N	EXCUSE	0
455373	454054	14097Y	PARTICIPANT	\N	EXCUSE	0
455374	454054	19583F	PARTICIPANT	\N	EXCUSE	0
455375	454054	14028W	PARTICIPANT	\N	EXCUSE	0
455376	454055	98029W	PARTICIPANT	\N	EXCUSE	0
455377	454055	14097Y	PARTICIPANT	\N	EXCUSE	0
455378	454055	14028W	PARTICIPANT	\N	EXCUSE	0
455401	454055	19583F	PARTICIPANT	\N	EXCUSE	0
459107	456887	19583F	PARTICIPANT	\N	EXCUSE	0
459108	456887	07033P	PARTICIPANT	\N	EXCUSE	0
459109	456887	19717B	PARTICIPANT	\N	EXCUSE	0
459110	456887	11010L	PARTICIPANT	\N	EXCUSE	0
459111	456887	14135M	PARTICIPANT	\N	EXCUSE	0
459112	456887	11054L	PARTICIPANT	\N	EXCUSE	0
459116	453250	19583F	PARTICIPANT	\N	EXCUSE	0
459114	453250	07033P	PARTICIPANT	\N	EXCUSE	0
459115	453250	11010L	PARTICIPANT	\N	EXCUSE	0
459117	453250	14135M	PARTICIPANT	\N	EXCUSE	0
462608	462478	15447F	PARTICIPANT	\N	EXCUSE	0
462606	462478	14038Y	PARTICIPANT	\N	EXCUSE	0
462607	462478	87003B	PARTICIPANT	\N	EXCUSE	0
462609	462478	19269X	PARTICIPANT	\N	EXCUSE	0
465633	465632	04047H	PARTICIPANT	\N	PRESENT	0
465634	465632	14021P	PARTICIPANT	\N	PRESENT	0
465635	465632	19649G	PARTICIPANT	\N	PRESENT	0
465636	465632	08044W	PARTICIPANT	\N	PRESENT	0
465637	465632	19447X	PARTICIPANT	\N	PRESENT	0
465638	465632	14147R	PARTICIPANT	\N	PRESENT	0
465639	465632	14065Q	PARTICIPANT	\N	PRESENT	0
465640	465632	11072N	PARTICIPANT	\N	PRESENT	0
466677	466675	19503N	PARTICIPANT	\N	PRESENT	0
466679	466678	19719D	PARTICIPANT	\N	PRESENT	0
466680	466678	14215L	PARTICIPANT	\N	PRESENT	0
468233	468217	08012N	PARTICIPANT	\N	PRESENT	0
466728	466727	19611R	PARTICIPANT	\N	PRESENT	0
466729	466727	19621T	PARTICIPANT	\N	PRESENT	0
466730	466727	14123H	PARTICIPANT	\N	PRESENT	0
466732	466731	19611R	PARTICIPANT	\N	PRESENT	0
466733	466731	19621T	PARTICIPANT	\N	PRESENT	0
466734	466731	14123H	PARTICIPANT	\N	PRESENT	0
466735	466731	19758L	PARTICIPANT	\N	PRESENT	0
466736	466731	14109K	PARTICIPANT	\N	PRESENT	0
466737	466731	19533U	PARTICIPANT	\N	PRESENT	0
466739	466738	19611R	PARTICIPANT	\N	PRESENT	0
466740	466738	19621T	PARTICIPANT	\N	PRESENT	0
466741	466738	14123H	PARTICIPANT	\N	PRESENT	0
466742	466738	19758L	PARTICIPANT	\N	PRESENT	0
466743	466738	14109K	PARTICIPANT	\N	PRESENT	0
466744	466738	19533U	PARTICIPANT	\N	PRESENT	0
466746	466745	19611R	PARTICIPANT	\N	PRESENT	0
466747	466745	19621T	PARTICIPANT	\N	PRESENT	0
466748	466745	14123H	PARTICIPANT	\N	PRESENT	0
466749	466745	19758L	PARTICIPANT	\N	PRESENT	0
466750	466745	14109K	PARTICIPANT	\N	PRESENT	0
466751	466745	19533U	PARTICIPANT	\N	PRESENT	0
466752	466745	14107H	PARTICIPANT	\N	PRESENT	0
466754	466753	19611R	PARTICIPANT	\N	PRESENT	0
466755	466753	19621T	PARTICIPANT	\N	PRESENT	0
466756	466753	14123H	PARTICIPANT	\N	PRESENT	0
466757	466753	14109K	PARTICIPANT	\N	PRESENT	0
466758	466753	19533U	PARTICIPANT	\N	PRESENT	0
466759	466753	14107H	PARTICIPANT	\N	PRESENT	0
466761	466760	19611R	PARTICIPANT	\N	PRESENT	0
466762	466760	19621T	PARTICIPANT	\N	PRESENT	0
466763	466760	14123H	PARTICIPANT	\N	PRESENT	0
466764	466760	14109K	PARTICIPANT	\N	PRESENT	0
466765	466760	19533U	PARTICIPANT	\N	PRESENT	0
466767	466766	14123H	PARTICIPANT	\N	PRESENT	0
466768	466766	19621T	PARTICIPANT	\N	PRESENT	0
466769	466766	19758L	PARTICIPANT	\N	PRESENT	0
466770	466766	19611R	PARTICIPANT	\N	PRESENT	0
466771	466766	14107H	PARTICIPANT	\N	PRESENT	0
466772	466766	14249W	PARTICIPANT	\N	PRESENT	0
466773	466766	11104D	PARTICIPANT	\N	PRESENT	0
466775	466774	19621T	PARTICIPANT	\N	PRESENT	0
466776	466774	19611R	PARTICIPANT	\N	PRESENT	0
466777	466774	14039A	PARTICIPANT	\N	PRESENT	0
466778	466774	19758L	PARTICIPANT	\N	PRESENT	0
466779	466774	14109K	PARTICIPANT	\N	PRESENT	0
466780	466774	14249W	PARTICIPANT	\N	PRESENT	0
466781	466774	14123H	PARTICIPANT	\N	PRESENT	0
466782	466774	14107H	PARTICIPANT	\N	PRESENT	0
466784	466783	19758L	PARTICIPANT	\N	PRESENT	0
466785	466783	14123H	PARTICIPANT	\N	PRESENT	0
466786	466783	19611R	PARTICIPANT	\N	PRESENT	0
466787	466783	19621T	PARTICIPANT	\N	PRESENT	0
466788	466783	14249W	PARTICIPANT	\N	PRESENT	0
466789	466783	14109K	PARTICIPANT	\N	PRESENT	0
466791	466790	14123H	PARTICIPANT	\N	PRESENT	0
466792	466790	19621T	PARTICIPANT	\N	PRESENT	0
466793	466790	19758L	PARTICIPANT	\N	PRESENT	0
466794	466790	14249W	PARTICIPANT	\N	PRESENT	0
466795	466790	14107H	PARTICIPANT	\N	PRESENT	0
466796	466790	19611R	PARTICIPANT	\N	PRESENT	0
466797	466790	14109K	PARTICIPANT	\N	PRESENT	0
466799	466798	14123H	PARTICIPANT	\N	PRESENT	0
466801	466800	14123H	PARTICIPANT	\N	PRESENT	0
466802	466800	19621T	PARTICIPANT	\N	PRESENT	0
466803	466800	19611R	PARTICIPANT	\N	PRESENT	0
466804	466800	19758L	PARTICIPANT	\N	PRESENT	0
466805	466800	14039A	PARTICIPANT	\N	PRESENT	0
466806	466800	14107H	PARTICIPANT	\N	PRESENT	0
466807	466800	14109K	PARTICIPANT	\N	PRESENT	0
466808	466800	14249W	PARTICIPANT	\N	PRESENT	0
466810	466809	14123H	PARTICIPANT	\N	PRESENT	0
468232	468217	04070G	PRESIDENT	0	PRESENT	0
468234	468217	11043H	PARTICIPANT	\N	PRESENT	0
468235	468217	19643A	PARTICIPANT	\N	PRESENT	0
468236	468217	19399H	PARTICIPANT	\N	PRESENT	0
468237	468217	14073Q	PARTICIPANT	\N	PRESENT	0
468238	468217	19699S	PARTICIPANT	\N	PRESENT	0
468239	468217	11104D	PARTICIPANT	\N	PRESENT	0
468240	468217	14241N	PARTICIPANT	\N	PRESENT	0
468241	468217	14039A	PARTICIPANT	\N	PRESENT	0
468242	468217	19758L	PARTICIPANT	\N	PRESENT	0
468243	468217	04057K	PARTICIPANT	\N	PRESENT	0
468244	468217	19731Y	PARTICIPANT	\N	PRESENT	0
468245	468217	19766L	PARTICIPANT	\N	PRESENT	0
468246	468217	19749K	PARTICIPANT	\N	PRESENT	0
468247	468217	19611R	PARTICIPANT	\N	PRESENT	0
468248	468217	14109K	PARTICIPANT	\N	PRESENT	0
468249	468217	14249W	PARTICIPANT	\N	PRESENT	0
468250	468217	19735D	PARTICIPANT	\N	PRESENT	0
468251	468217	19533U	PARTICIPANT	\N	PRESENT	0
468252	468217	08020N	PARTICIPANT	\N	PRESENT	0
468253	468217	14061L	PARTICIPANT	\N	PRESENT	0
468254	468217	14030Q	PARTICIPANT	\N	PRESENT	0
468255	468217	08017T	PARTICIPANT	\N	PRESENT	0
468256	468217	08039A	PRESIDENT	1	PRESENT	0
468257	468217	08043V	PARTICIPANT	\N	PRESENT	0
468258	468217	14059S	PARTICIPANT	\N	PRESENT	0
468259	468217	19329S	PARTICIPANT	\N	EXCUSE	0
468260	468217	07033P	PARTICIPANT	\N	EXCUSE	0
468353	468351	19503N	PARTICIPANT	\N	PRESENT	0
468356	468354	19503N	PARTICIPANT	\N	PRESENT	0
468359	468357	19503N	PARTICIPANT	\N	PRESENT	0
468506	468261	14097Y	PARTICIPANT	\N	PRESENT	0
468507	468261	04035D	PARTICIPANT	\N	PRESENT	0
468508	468261	95067Q	PARTICIPANT	\N	PRESENT	0
468509	468261	14133K	PARTICIPANT	\N	PRESENT	0
468510	468261	01062T	PARTICIPANT	\N	PRESENT	0
468511	468261	11041F	PARTICIPANT	\N	PRESENT	0
468512	468261	08058D	PARTICIPANT	\N	PRESENT	0
468513	468261	19251M	PARTICIPANT	\N	PRESENT	0
468514	468261	14028W	PARTICIPANT	\N	PRESENT	0
468515	468261	19319Q	PARTICIPANT	\N	PRESENT	0
468516	468261	14105F	PARTICIPANT	\N	PRESENT	0
468517	468261	98018T	PARTICIPANT	\N	PRESENT	0
468518	468261	98022P	PARTICIPANT	\N	PRESENT	0
468519	468261	14267Y	PARTICIPANT	\N	PRESENT	0
468520	468261	98050T	PARTICIPANT	\N	PRESENT	0
468521	468261	14211G	PARTICIPANT	\N	PRESENT	0
468522	468261	19583F	PARTICIPANT	\N	PRESENT	0
468523	468261	14255U	PARTICIPANT	\N	PRESENT	0
468524	468261	08049C	PARTICIPANT	\N	EXCUSE	0
468534	467224	86034E	PARTICIPANT	\N	PRESENT	0
468535	467224	19713W	PARTICIPANT	\N	PRESENT	0
468536	467224	19651A	PARTICIPANT	\N	PRESENT	0
468541	467224	19525U	PARTICIPANT	\N	PRESENT	0
468542	467224	04085P	PARTICIPANT	\N	PRESENT	0
468544	467224	11056N	PARTICIPANT	\N	PRESENT	0
468546	467224	19629C	PARTICIPANT	\N	PRESENT	0
468548	467224	14085U	PARTICIPANT	\N	PRESENT	0
468549	467224	14259Y	PARTICIPANT	\N	PRESENT	0
468550	467224	14157T	PARTICIPANT	\N	PRESENT	0
466175	466174	04038G	PARTICIPANT	\N	PRESENT	0
466176	466174	14215L	PARTICIPANT	\N	PRESENT	0
466177	466174	14231L	PARTICIPANT	\N	PRESENT	0
466179	466178	04038G	PARTICIPANT	\N	PRESENT	0
466180	466178	14231L	PARTICIPANT	\N	PRESENT	0
466181	466178	14215L	PARTICIPANT	\N	PRESENT	0
466182	466178	19447X	PARTICIPANT	\N	PRESENT	0
466205	465336	19489J	PARTICIPANT	\N	PRESENT	0
466206	465336	14069U	PARTICIPANT	\N	PRESENT	0
466207	465336	14147R	PARTICIPANT	\N	PRESENT	0
468023	467221	86034E	PARTICIPANT	\N	PRESENT	0
468024	467221	11033F	PARTICIPANT	\N	PRESENT	0
468025	467221	19553Y	PARTICIPANT	\N	PRESENT	0
468026	467221	19629C	PARTICIPANT	\N	PRESENT	0
468027	467221	08031R	PARTICIPANT	\N	PRESENT	0
468028	467221	07033P	PARTICIPANT	\N	PRESENT	0
468029	467221	19691J	PARTICIPANT	\N	PRESENT	0
468030	467221	19695N	PARTICIPANT	\N	PRESENT	0
468031	467221	11056N	PARTICIPANT	\N	PRESENT	0
468032	467221	14229S	PARTICIPANT	\N	PRESENT	0
468033	467221	95063L	PARTICIPANT	\N	PRESENT	0
468034	467221	08061X	PARTICIPANT	\N	PRESENT	0
468035	467221	19585H	PARTICIPANT	\N	PRESENT	0
468009	467706	14053L	PARTICIPANT	\N	PRESENT	0
468010	467706	19649G	PARTICIPANT	\N	PRESENT	0
468011	467706	04047H	PRESIDENT	0	PRESENT	0
468012	467706	19673G	PARTICIPANT	\N	PRESENT	0
468013	467706	01028R	PARTICIPANT	\N	PRESENT	0
468014	467706	05008E	PARTICIPANT	\N	PRESENT	0
468015	467706	14089Y	PARTICIPANT	\N	PRESENT	0
468016	467706	19629C	PARTICIPANT	\N	PRESENT	0
468017	467706	08044W	PARTICIPANT	\N	PRESENT	0
468018	467706	14215L	PARTICIPANT	\N	PRESENT	0
468019	467706	14259Y	PARTICIPANT	\N	PRESENT	0
468020	467706	14021P	PARTICIPANT	\N	PRESENT	0
468021	467706	19762G	PARTICIPANT	\N	PRESENT	0
468022	467706	11033F	PARTICIPANT	\N	PRESENT	0
468036	467221	19545Y	PARTICIPANT	\N	PRESENT	0
468037	467221	08009T	PARTICIPANT	\N	PRESENT	0
468038	467221	14055N	PARTICIPANT	\N	PRESENT	0
468039	467221	14215L	PARTICIPANT	\N	PRESENT	0
468040	467221	11097X	PARTICIPANT	\N	PRESENT	0
468041	467221	14157T	PARTICIPANT	\N	PRESENT	0
468042	467221	19762G	PARTICIPANT	\N	PRESENT	0
468043	467221	08010L	PARTICIPANT	\N	PRESENT	0
468044	467221	14259Y	PARTICIPANT	\N	PRESENT	0
468045	467221	19673G	PARTICIPANT	\N	PRESENT	0
468046	467221	14038Y	PARTICIPANT	\N	PRESENT	0
468047	467221	04033B	PARTICIPANT	\N	PRESENT	0
468048	467221	19621T	PARTICIPANT	\N	PRESENT	0
468049	467221	19647E	PARTICIPANT	\N	PRESENT	0
468050	467221	14281W	PARTICIPANT	\N	PRESENT	0
468051	467221	11045K	PARTICIPANT	\N	PRESENT	0
468052	467221	19697Q	PARTICIPANT	\N	PRESENT	0
468053	467221	19649G	PARTICIPANT	\N	PRESENT	0
468054	467221	14021P	PARTICIPANT	\N	PRESENT	0
468055	467221	01028R	PARTICIPANT	\N	PRESENT	0
468056	467221	05008E	PARTICIPANT	\N	PRESENT	0
468057	467221	14089Y	PARTICIPANT	\N	PRESENT	0
468058	467221	14071N	PARTICIPANT	\N	PRESENT	0
468059	467221	14053L	PARTICIPANT	\N	PRESENT	0
468060	467221	04070G	PARTICIPANT	\N	PRESENT	0
468061	467221	19569H	PARTICIPANT	\N	PRESENT	0
468062	467221	04092N	PARTICIPANT	\N	PRESENT	0
468063	467221	14151M	PARTICIPANT	\N	PRESENT	0
468064	467221	19591F	PARTICIPANT	\N	PRESENT	0
468065	467221	19573D	PARTICIPANT	\N	PRESENT	0
468066	467221	14123H	PARTICIPANT	\N	PRESENT	0
468067	467221	10006L	PARTICIPANT	\N	PRESENT	0
468068	467221	11085T	PARTICIPANT	\N	PRESENT	0
468069	467221	11012A	PARTICIPANT	\N	PRESENT	0
468070	467221	04047H	PARTICIPANT	\N	PRESENT	0
468071	467221	08044W	PARTICIPANT	\N	PRESENT	0
468072	467221	14179A	PARTICIPANT	\N	PRESENT	0
468073	467221	17637T	PARTICIPANT	\N	PRESENT	0
468074	467221	19689Q	PARTICIPANT	\N	PRESENT	0
468075	467221	04085P	PARTICIPANT	\N	PRESENT	0
468076	467221	04035D	PARTICIPANT	\N	PRESENT	0
468077	467221	19758L	PARTICIPANT	\N	PRESENT	0
468078	467221	19760E	PARTICIPANT	\N	PRESENT	0
468087	467221	12041X	PARTICIPANT	\N	PRESENT	0
468677	468368	19443T	PARTICIPANT	\N	PRESENT	0
468678	468368	95030B	PARTICIPANT	\N	PRESENT	0
468679	468368	04034C	PARTICIPANT	\N	PRESENT	0
468680	468368	14079W	PARTICIPANT	\N	PRESENT	0
468681	468368	01058X	PARTICIPANT	\N	PRESENT	0
468682	468368	04040A	PARTICIPANT	\N	PRESENT	0
468683	468368	11027H	PARTICIPANT	\N	PRESENT	0
468684	468368	04042C	PRESIDENT	0	PRESENT	0
468685	468368	11066Q	PARTICIPANT	\N	PRESENT	0
468686	468368	08056B	PARTICIPANT	\N	PRESENT	0
468687	468368	19421M	PARTICIPANT	\N	PRESENT	0
468688	468368	19709B	PARTICIPANT	\N	PRESENT	0
468689	468368	14193X	PARTICIPANT	\N	PRESENT	0
468690	468368	08049C	PARTICIPANT	\N	PRESENT	0
468691	468368	97011G	PARTICIPANT	\N	PRESENT	0
468692	468368	08047A	PARTICIPANT	\N	PRESENT	0
468693	468368	14097Y	PARTICIPANT	\N	PRESENT	0
468694	468368	04035D	PARTICIPANT	\N	PRESENT	0
468695	468368	95067Q	PARTICIPANT	\N	PRESENT	0
468696	468368	14133K	PARTICIPANT	\N	PRESENT	0
468697	468368	01062T	PARTICIPANT	\N	PRESENT	0
468698	468368	11041F	PARTICIPANT	\N	PRESENT	0
468699	468368	14235Q	PARTICIPANT	\N	PRESENT	0
468700	468368	14105F	PARTICIPANT	\N	PRESENT	0
468701	468368	98018T	PARTICIPANT	\N	PRESENT	0
468702	468368	14267Y	PARTICIPANT	\N	PRESENT	0
468703	468368	11064N	PARTICIPANT	\N	PRESENT	0
468704	468368	14211G	PARTICIPANT	\N	PRESENT	0
468705	468368	14255U	PARTICIPANT	\N	PRESENT	0
468735	468734	04047H	PARTICIPANT	\N	PRESENT	0
468736	468734	14021P	PARTICIPANT	\N	PRESENT	0
468737	468734	14147R	PARTICIPANT	\N	PRESENT	0
468738	468734	14053L	PARTICIPANT	\N	PRESENT	0
468739	468734	19649G	PARTICIPANT	\N	PRESENT	0
468741	468740	08024S	PARTICIPANT	\N	PRESENT	0
468742	468740	08045X	PARTICIPANT	\N	PRESENT	0
468744	468743	99004R	PRESIDENT	0	PRESENT	0
468745	468743	19651A	PARTICIPANT	\N	EXCUSE	0
468746	468743	19629C	PARTICIPANT	\N	EXCUSE	0
468747	468743	04038G	PARTICIPANT	\N	EXCUSE	0
468748	468743	08045X	PARTICIPANT	\N	EXCUSE	0
468749	468743	08048B	PARTICIPANT	\N	EXCUSE	0
468750	468743	19399H	PARTICIPANT	\N	EXCUSE	0
468751	468743	19711U	PARTICIPANT	\N	PRESENT	0
468752	468743	19349W	PARTICIPANT	\N	PRESENT	0
468753	468743	14107H	PARTICIPANT	\N	EXCUSE	0
468754	468743	19713W	PARTICIPANT	\N	PRESENT	0
468755	468743	11066Q	PARTICIPANT	\N	PRESENT	0
468756	468743	19479G	PARTICIPANT	\N	PRESENT	0
468757	468743	19737F	PARTICIPANT	\N	PRESENT	0
468795	468794	04042C	PARTICIPANT	\N	PRESENT	0
468796	468794	04035D	PARTICIPANT	\N	PRESENT	0
468797	468794	14193X	PARTICIPANT	\N	PRESENT	0
468798	468794	01062T	PARTICIPANT	\N	PRESENT	0
468799	468794	11054L	PARTICIPANT	\N	PRESENT	0
468800	468794	98022P	PARTICIPANT	\N	PRESENT	0
468801	468794	04040A	PARTICIPANT	\N	PRESENT	0
468802	468743	19515S	PARTICIPANT	\N	PRESENT	0
468803	468743	08024S	PARTICIPANT	\N	PRESENT	0
468804	468743	02002K	PARTICIPANT	\N	PRESENT	0
468805	468743	14147R	PARTICIPANT	\N	PRESENT	0
468808	468807	04049K	PARTICIPANT	\N	PRESENT	0
468809	468807	14265W	PARTICIPANT	\N	PRESENT	0
468810	468807	14157T	PARTICIPANT	\N	PRESENT	0
468811	468807	14105F	PARTICIPANT	\N	PRESENT	0
468812	468807	11099A	PARTICIPANT	\N	PRESENT	0
468813	466642	14073Q	PARTICIPANT	\N	PRESENT	0
468814	466642	08012N	PARTICIPANT	\N	PRESENT	0
468815	466642	11043H	PARTICIPANT	\N	PRESENT	0
468816	466642	14241N	PARTICIPANT	\N	PRESENT	0
468817	466642	19643A	PARTICIPANT	\N	PRESENT	0
468818	466642	14249W	PARTICIPANT	\N	PRESENT	0
468820	468819	19643A	PARTICIPANT	\N	PRESENT	0
468821	468819	14249W	PARTICIPANT	\N	PRESENT	0
468822	468819	14241N	PARTICIPANT	\N	PRESENT	0
468823	468819	14073Q	PARTICIPANT	\N	PRESENT	0
468824	468819	08012N	PARTICIPANT	\N	PRESENT	0
468825	468819	11043H	PARTICIPANT	\N	PRESENT	0
468827	468826	14073Q	PARTICIPANT	\N	PRESENT	0
468828	468826	14241N	PARTICIPANT	\N	PRESENT	0
468829	468826	11043H	PARTICIPANT	\N	PRESENT	0
468830	468826	08012N	PARTICIPANT	\N	PRESENT	0
468831	468826	19643A	PARTICIPANT	\N	PRESENT	0
468832	468826	14249W	PARTICIPANT	\N	PRESENT	0
468833	466590	11083R	PARTICIPANT	\N	PRESENT	0
468834	466590	19399H	PARTICIPANT	\N	PRESENT	0
468835	466590	04059M	PARTICIPANT	\N	PRESENT	0
468837	468836	11083R	PARTICIPANT	\N	PRESENT	0
454493	454411	14042U	PARTICIPANT	\N	PRESENT	0
454517	454509	14042U	PARTICIPANT	\N	PRESENT	0
454520	454510	14042U	PARTICIPANT	\N	PRESENT	0
454532	454530	14042U	PARTICIPANT	\N	PRESENT	0
454550	454549	14219Q	PARTICIPANT	\N	PRESENT	0
454551	454549	19631V	PARTICIPANT	\N	PRESENT	0
454552	454549	11101A	PARTICIPANT	\N	PRESENT	0
454553	454549	11056N	PARTICIPANT	\N	PRESENT	0
454554	454549	14215L	PARTICIPANT	\N	PRESENT	0
454555	454549	14059S	PARTICIPANT	\N	PRESENT	0
454556	454549	14265W	PARTICIPANT	\N	PRESENT	0
454557	454549	19349W	PARTICIPANT	\N	PRESENT	0
454558	454549	14229S	PARTICIPANT	\N	PRESENT	0
454560	454549	01028R	PARTICIPANT	\N	PRESENT	0
454568	454567	07004J	PARTICIPANT	\N	PRESENT	0
454569	454567	14085U	PARTICIPANT	\N	PRESENT	0
456849	456847	14249W	PARTICIPANT	\N	PRESENT	0
456846	456844	04043D	PARTICIPANT	\N	PRESENT	0
456848	456847	98029W	PARTICIPANT	\N	PRESENT	0
456850	456847	11041F	PARTICIPANT	\N	PRESENT	0
456851	456847	19647E	PARTICIPANT	\N	PRESENT	0
456853	456852	19647E	PARTICIPANT	\N	PRESENT	0
459207	448769	11072N	PARTICIPANT	\N	PRESENT	0
459209	448769	04034C	PARTICIPANT	\N	PRESENT	0
459210	448769	14219Q	PARTICIPANT	\N	PRESENT	0
459211	448769	01028R	PARTICIPANT	\N	PRESENT	0
459212	448769	14217N	PARTICIPANT	\N	PRESENT	0
459213	448769	11066Q	PARTICIPANT	\N	PRESENT	0
459214	448769	04038G	PARTICIPANT	\N	PRESENT	0
459215	448769	14079W	PARTICIPANT	\N	PRESENT	0
459216	448769	19749K	PARTICIPANT	\N	PRESENT	0
459217	448769	19515S	PARTICIPANT	\N	PRESENT	0
459218	448769	11101A	PARTICIPANT	\N	PRESENT	0
459219	448769	19679N	PARTICIPANT	\N	PRESENT	0
459220	448769	19727D	PARTICIPANT	\N	PRESENT	0
459221	448769	19399H	PARTICIPANT	\N	PRESENT	0
459222	448769	14061L	PARTICIPANT	\N	PRESENT	0
459225	448769	02002K	PARTICIPANT	\N	PRESENT	0
459227	448769	95067Q	PARTICIPANT	\N	PRESENT	0
459228	448769	19527W	PARTICIPANT	\N	PRESENT	0
459234	448769	96004D	PARTICIPANT	\N	PRESENT	0
459236	448769	14241N	PARTICIPANT	\N	PRESENT	0
459237	448769	19826F	PARTICIPANT	\N	PRESENT	0
459238	448769	14135M	PARTICIPANT	\N	PRESENT	0
459239	448769	19741B	PARTICIPANT	\N	PRESENT	0
459240	448769	19711U	PARTICIPANT	\N	PRESENT	0
459244	448769	19533U	PARTICIPANT	\N	PRESENT	0
459246	448769	19593H	PARTICIPANT	\N	PRESENT	0
459247	448769	19507S	PARTICIPANT	\N	PRESENT	0
459248	448769	14033T	PARTICIPANT	\N	PRESENT	0
459249	448769	14109K	PARTICIPANT	\N	PRESENT	0
459250	448769	08024S	PARTICIPANT	\N	PRESENT	0
459252	448769	04070G	PARTICIPANT	\N	PRESENT	0
459253	448769	14197C	PARTICIPANT	\N	PRESENT	0
459254	448769	19689Q	PARTICIPANT	\N	PRESENT	0
459255	448769	14042U	PARTICIPANT	\N	PRESENT	0
459256	448769	14179A	PARTICIPANT	\N	PRESENT	0
459257	448769	14249W	PARTICIPANT	\N	PRESENT	0
459258	448769	19251M	PARTICIPANT	\N	PRESENT	0
459259	448769	19629C	PARTICIPANT	\N	PRESENT	0
459260	448769	19573D	PARTICIPANT	\N	PRESENT	0
459261	448769	14083S	PARTICIPANT	\N	PRESENT	0
459274	458796	19697Q	PARTICIPANT	\N	PRESENT	0
459275	458796	11067R	PARTICIPANT	\N	PRESENT	0
459276	458796	04092N	PRESIDENT	0	PRESENT	0
459277	458796	19565D	PARTICIPANT	\N	PRESENT	0
459278	458796	11097X	PARTICIPANT	\N	PRESENT	0
459279	458796	11045K	PARTICIPANT	\N	PRESENT	0
459280	458796	08052W	PARTICIPANT	\N	PRESENT	0
459281	458796	19663E	PARTICIPANT	\N	PRESENT	0
459282	458796	14227Q	PARTICIPANT	\N	PRESENT	0
459283	458796	19723Y	PARTICIPANT	\N	PRESENT	0
459284	458796	11031D	PARTICIPANT	\N	PRESENT	0
459285	458796	19727D	PARTICIPANT	\N	PRESENT	0
459286	458796	19703U	PARTICIPANT	\N	PRESENT	0
459287	458796	14119M	PARTICIPANT	\N	PRESENT	0
459288	458796	14087W	PARTICIPANT	\N	PRESENT	0
459289	458796	14281W	PARTICIPANT	\N	PRESENT	0
459290	458796	19679N	PARTICIPANT	\N	PRESENT	0
459291	458796	14042U	PARTICIPANT	\N	PRESENT	0
459292	458796	14213J	PARTICIPANT	\N	PRESENT	0
459293	458796	19367Y	PARTICIPANT	\N	PRESENT	0
459294	458796	19683J	PARTICIPANT	\N	PRESENT	0
459295	458796	19760E	PARTICIPANT	\N	PRESENT	0
459296	458796	08041T	PARTICIPANT	\N	EXCUSE	0
459335	448770	98024R	PARTICIPANT	\N	PRESENT	0
459336	448770	99004R	PARTICIPANT	\N	PRESENT	0
459337	448770	19671E	PARTICIPANT	\N	PRESENT	0
459338	448770	11101A	PARTICIPANT	\N	PRESENT	0
459339	448770	11043H	PARTICIPANT	\N	PRESENT	0
459340	448770	10015M	PARTICIPANT	\N	PRESENT	0
459341	448770	87003B	PARTICIPANT	\N	PRESENT	0
459342	448770	08039A	PARTICIPANT	\N	PRESENT	0
459333	448770	86034E	PARTICIPANT	\N	PRESENT	0
459334	448770	14211G	PARTICIPANT	\N	PRESENT	0
459343	448770	01057W	PARTICIPANT	\N	PRESENT	0
459344	448770	11080N	PARTICIPANT	\N	PRESENT	0
459345	448770	96004D	PARTICIPANT	\N	PRESENT	0
459346	448770	15447F	PARTICIPANT	\N	PRESENT	0
459347	448770	19679N	PARTICIPANT	\N	PRESENT	0
459348	448770	19766L	PARTICIPANT	\N	PRESENT	0
459349	448770	08018U	PARTICIPANT	\N	PRESENT	0
459350	448770	14038Y	PARTICIPANT	\N	PRESENT	0
459351	448770	19741B	PARTICIPANT	\N	PRESENT	0
459352	448770	19663E	PARTICIPANT	\N	PRESENT	0
459353	448770	04088S	PARTICIPANT	\N	PRESENT	0
459354	448770	14041T	PARTICIPANT	\N	PRESENT	0
459356	448770	07029T	PARTICIPANT	\N	PRESENT	0
459357	448770	19705W	PARTICIPANT	\N	PRESENT	0
459358	448770	98050T	PARTICIPANT	\N	PRESENT	0
459359	448770	14061L	PARTICIPANT	\N	PRESENT	0
459360	448770	04085P	PARTICIPANT	\N	PRESENT	0
459361	448770	19723Y	PARTICIPANT	\N	PRESENT	0
459362	448770	19507S	PARTICIPANT	\N	PRESENT	0
459363	448770	11040E	PARTICIPANT	\N	PRESENT	0
459364	448770	19760E	PARTICIPANT	\N	PRESENT	0
459365	448770	11033F	PARTICIPANT	\N	PRESENT	0
459366	448770	19758L	PARTICIPANT	\N	PRESENT	0
459367	448770	18083K	PARTICIPANT	\N	PRESENT	0
459368	448770	11031D	PARTICIPANT	\N	PRESENT	0
459369	448770	04038G	PARTICIPANT	\N	PRESENT	0
459370	448770	14033T	PARTICIPANT	\N	PRESENT	0
459371	448770	11056N	PARTICIPANT	\N	PRESENT	0
459372	448770	14135M	PARTICIPANT	\N	PRESENT	0
459373	448770	11077T	PARTICIPANT	\N	PRESENT	0
459374	448770	19695N	PARTICIPANT	\N	PRESENT	0
459375	448770	08019V	PARTICIPANT	\N	PRESENT	0
459376	448770	19565D	PARTICIPANT	\N	PRESENT	0
459377	448770	19693L	PARTICIPANT	\N	PRESENT	0
459378	448770	14235Q	PARTICIPANT	\N	PRESENT	0
459379	448770	19593H	PARTICIPANT	\N	PRESENT	0
459380	448770	19729F	PARTICIPANT	\N	PRESENT	0
459381	448770	12041X	PARTICIPANT	\N	PRESENT	0
459382	448770	19399H	PARTICIPANT	\N	PRESENT	0
459383	448770	14265W	PARTICIPANT	\N	PRESENT	0
459384	448770	08015R	PARTICIPANT	\N	PRESENT	0
459385	448770	19383Y	PARTICIPANT	\N	PRESENT	0
459386	448770	08061X	PARTICIPANT	\N	PRESENT	0
459387	448770	19621T	PARTICIPANT	\N	PRESENT	0
459388	448770	04034C	PARTICIPANT	\N	PRESENT	0
459389	448770	19367Y	PARTICIPANT	\N	PRESENT	0
459390	448770	04045F	PARTICIPANT	\N	PRESENT	0
459391	448770	95037J	PARTICIPANT	\N	PRESENT	0
459392	448770	11083R	PARTICIPANT	\N	PRESENT	0
459393	448770	11072N	PARTICIPANT	\N	PRESENT	0
459394	448770	19651A	PARTICIPANT	\N	PRESENT	0
459395	448770	19349W	PARTICIPANT	\N	PRESENT	0
459396	448770	19637C	PARTICIPANT	\N	PRESENT	0
459397	448770	19697Q	PARTICIPANT	\N	PRESENT	0
459398	448770	19443T	PARTICIPANT	\N	PRESENT	0
459399	448770	19812Y	PARTICIPANT	\N	PRESENT	0
459400	448770	19782L	PARTICIPANT	\N	PRESENT	0
459401	448770	08024S	PARTICIPANT	\N	PRESENT	0
459402	448770	01060R	PARTICIPANT	\N	PRESENT	0
459403	448770	08056B	PARTICIPANT	\N	PRESENT	0
459404	448770	19685L	PARTICIPANT	\N	PRESENT	0
459405	448770	19731Y	PARTICIPANT	\N	PRESENT	0
459406	448770	14173T	PARTICIPANT	\N	PRESENT	0
459407	448770	11012A	PARTICIPANT	\N	PRESENT	0
459408	448770	19447X	PARTICIPANT	\N	PRESENT	0
459409	448770	98029W	PARTICIPANT	\N	PRESENT	0
459410	448770	19573D	PARTICIPANT	\N	PRESENT	0
459411	448770	14133K	PARTICIPANT	\N	PRESENT	0
459412	448770	19629C	PARTICIPANT	\N	PRESENT	0
459413	448770	19253P	PARTICIPANT	\N	PRESENT	0
459414	448770	98022P	PARTICIPANT	\N	PRESENT	0
459415	448770	92040Q	PARTICIPANT	\N	PRESENT	0
465159	465145	14030Q	PARTICIPANT	\N	PRESENT	0
465160	465145	14123H	PARTICIPANT	\N	PRESENT	0
465161	465145	08017T	PARTICIPANT	\N	PRESENT	0
465162	465145	19611R	PARTICIPANT	\N	PRESENT	0
465163	465145	14109K	PARTICIPANT	\N	PRESENT	0
465164	465145	14251Q	PARTICIPANT	\N	PRESENT	0
465165	465145	08020N	PARTICIPANT	\N	PRESENT	0
465166	465145	14241N	PARTICIPANT	\N	PRESENT	0
465167	465145	19643A	PARTICIPANT	\N	PRESENT	0
465168	465145	19533U	PARTICIPANT	\N	PRESENT	0
465169	465145	07033P	PARTICIPANT	\N	PRESENT	0
465170	465145	11083R	PARTICIPANT	\N	PRESENT	0
465171	465145	11043H	PARTICIPANT	\N	PRESENT	0
465172	465145	14073Q	PARTICIPANT	\N	EXCUSE	0
465173	465145	92040Q	PARTICIPANT	\N	EXCUSE	0
465174	465145	14039A	PARTICIPANT	\N	PRESENT	0
465175	465145	19621T	PARTICIPANT	\N	PRESENT	0
465180	465145	19693L	PARTICIPANT	\N	PRESENT	0
465181	465145	19593H	PARTICIPANT	\N	PRESENT	0
465291	465145	19329S	PARTICIPANT	\N	PRESENT	0
465292	465145	19573D	PARTICIPANT	\N	PRESENT	0
465327	465293	08061X	PARTICIPANT	\N	EXCUSE	0
465387	465274	14219Q	PARTICIPANT	\N	PRESENT	0
465388	465274	14331P	PARTICIPANT	\N	EXCUSE	0
465389	465274	19577H	PARTICIPANT	\N	PRESENT	0
465391	465390	04047H	PARTICIPANT	\N	PRESENT	0
465392	465390	14021P	PARTICIPANT	\N	PRESENT	0
465393	465390	01028R	PARTICIPANT	\N	PRESENT	0
465394	465390	19673G	PARTICIPANT	\N	PRESENT	0
465395	465390	19649G	PARTICIPANT	\N	PRESENT	0
465396	465390	01024M	PARTICIPANT	\N	PRESENT	0
465397	465390	95063L	PARTICIPANT	\N	PRESENT	0
465398	465390	19725B	PARTICIPANT	\N	PRESENT	0
465399	465390	14215L	PARTICIPANT	\N	PRESENT	0
465400	465390	11085T	PARTICIPANT	\N	PRESENT	0
465401	465390	19581D	PARTICIPANT	\N	PRESENT	0
465402	465390	04044E	PARTICIPANT	\N	PRESENT	0
465404	465403	04047H	PARTICIPANT	\N	PRESENT	0
465405	465403	14021P	PARTICIPANT	\N	PRESENT	0
465406	465403	01028R	PARTICIPANT	\N	PRESENT	0
465407	465403	19673G	PARTICIPANT	\N	PRESENT	0
465408	465403	19725B	PARTICIPANT	\N	PRESENT	0
465409	465403	19649G	PARTICIPANT	\N	PRESENT	0
465410	465403	01024M	PARTICIPANT	\N	PRESENT	0
465411	465403	14215L	PARTICIPANT	\N	PRESENT	0
465412	465403	19719D	PARTICIPANT	\N	PRESENT	0
465413	465403	14065Q	PARTICIPANT	\N	PRESENT	0
465414	465403	19447X	PARTICIPANT	\N	PRESENT	0
465417	465416	07004J	PARTICIPANT	\N	PRESENT	0
465419	465418	07004J	PARTICIPANT	\N	PRESENT	0
465420	465274	11109J	PARTICIPANT	\N	PRESENT	0
465421	465415	11090Q	PRESIDENT	0	PRESENT	0
465422	465415	11099A	PARTICIPANT	\N	EXCUSE	0
465423	465415	14205J	PARTICIPANT	\N	PRESENT	0
465424	465415	19812Y	PARTICIPANT	\N	PRESENT	0
465425	465415	14207L	PARTICIPANT	\N	PRESENT	0
465426	465415	08028W	PARTICIPANT	\N	PRESENT	0
465427	465415	14257W	PARTICIPANT	\N	PRESENT	0
465428	465333	14053L	PARTICIPANT	\N	PRESENT	0
465429	465333	14065Q	PARTICIPANT	\N	PRESENT	0
465430	465333	14111D	PARTICIPANT	\N	PRESENT	0
465431	465333	19649G	PARTICIPANT	\N	PRESENT	0
465432	465333	08045X	PARTICIPANT	\N	PRESENT	0
465433	465333	10015M	PARTICIPANT	\N	PRESENT	0
465434	465333	19253P	PARTICIPANT	\N	PRESENT	0
465435	465333	19585H	PARTICIPANT	\N	PRESENT	0
465436	465333	11033F	PARTICIPANT	\N	PRESENT	0
465437	465333	01028R	PARTICIPANT	\N	PRESENT	0
465438	465333	05008E	PRESIDENT	0	PRESENT	0
465439	465333	19489J	PARTICIPANT	\N	PRESENT	0
465440	465333	95063L	PARTICIPANT	\N	PRESENT	0
465441	465333	14041T	PARTICIPANT	\N	PRESENT	0
465442	465333	14147R	PARTICIPANT	\N	PRESENT	0
465443	465333	14179A	PARTICIPANT	\N	PRESENT	0
465444	465333	14069U	PARTICIPANT	\N	PRESENT	0
465445	465333	14151M	PARTICIPANT	\N	PRESENT	0
465446	465333	11085T	PARTICIPANT	\N	PRESENT	0
465447	465333	14259Y	PARTICIPANT	\N	PRESENT	0
465448	465333	14021P	PARTICIPANT	\N	PRESENT	0
465449	465415	19467C	PARTICIPANT	\N	PRESENT	0
465450	465415	19515S	PARTICIPANT	\N	PRESENT	0
465451	465415	14357A	PARTICIPANT	\N	PRESENT	0
465452	465415	14187A	PARTICIPANT	\N	PRESENT	0
465453	465415	08038Y	PARTICIPANT	\N	PRESENT	0
465454	465415	80013X	PARTICIPANT	\N	PRESENT	0
465455	465415	19507S	PARTICIPANT	\N	PRESENT	0
465456	465415	14197C	PARTICIPANT	\N	PRESENT	0
465457	465415	19747H	PARTICIPANT	\N	PRESENT	0
465458	465415	01043Q	PARTICIPANT	\N	PRESENT	0
465459	465415	04045F	PARTICIPANT	\N	PRESENT	0
465460	465415	04049K	PARTICIPANT	\N	PRESENT	0
465461	465415	08019V	PARTICIPANT	\N	PRESENT	0
465462	465415	19369B	PARTICIPANT	\N	PRESENT	0
465463	465415	14265W	PARTICIPANT	\N	PRESENT	0
465464	465415	19619A	PARTICIPANT	\N	PRESENT	0
465470	465469	19443T	PARTICIPANT	\N	PRESENT	0
465471	465469	12041X	PARTICIPANT	\N	PRESENT	0
465472	465469	95030B	PARTICIPANT	\N	PRESENT	0
465473	465469	04034C	PARTICIPANT	\N	PRESENT	0
465474	465469	01058X	PARTICIPANT	\N	PRESENT	0
465475	465469	04040A	PARTICIPANT	\N	PRESENT	0
465476	465469	11054L	PARTICIPANT	\N	PRESENT	0
465477	465469	11066Q	PARTICIPANT	\N	PRESENT	0
465478	465469	08056B	PARTICIPANT	\N	PRESENT	0
465479	465469	11115U	PARTICIPANT	\N	PRESENT	0
465480	465469	19421M	PARTICIPANT	\N	PRESENT	0
465481	465469	19709B	PARTICIPANT	\N	PRESENT	0
465482	465469	14193X	PRESIDENT	0	PRESENT	0
465483	465469	08061X	PARTICIPANT	\N	PRESENT	0
465484	465469	08047A	PARTICIPANT	\N	PRESENT	0
465485	465469	98029W	PARTICIPANT	\N	PRESENT	0
465486	465469	04035D	PARTICIPANT	\N	PRESENT	0
465487	465469	95067Q	PARTICIPANT	\N	PRESENT	0
465488	465469	01062T	PARTICIPANT	\N	PRESENT	0
465489	465469	08058D	PARTICIPANT	\N	PRESENT	0
465490	465469	19251M	PARTICIPANT	\N	PRESENT	0
465491	465469	14028W	PARTICIPANT	\N	PRESENT	0
465492	465469	14105F	PARTICIPANT	\N	PRESENT	0
465493	465469	98018T	PARTICIPANT	\N	PRESENT	0
465494	465469	98022P	PARTICIPANT	\N	PRESENT	0
465495	465469	14267Y	PARTICIPANT	\N	PRESENT	0
465496	465469	11064N	PARTICIPANT	\N	PRESENT	0
465497	465469	98050T	PARTICIPANT	\N	PRESENT	0
465498	465469	14255U	PARTICIPANT	\N	PRESENT	0
465499	465469	08049C	PARTICIPANT	\N	EXCUSE	0
465500	465469	16685X	PARTICIPANT	\N	EXCUSE	0
465501	465469	04042C	PARTICIPANT	\N	EXCUSE	0
465528	465527	14030Q	PRESIDENT	0	PRESENT	0
465529	465527	08020N	PARTICIPANT	\N	PRESENT	0
465530	465527	80013X	PARTICIPANT	\N	PRESENT	0
465531	465527	19693L	PARTICIPANT	\N	PRESENT	0
465532	465527	14217N	PARTICIPANT	\N	PRESENT	0
465533	465527	14179A	PARTICIPANT	\N	PRESENT	0
465534	465527	19715Y	PARTICIPANT	\N	PRESENT	0
465535	465527	19731Y	PARTICIPANT	\N	PRESENT	0
465536	465527	08031R	PARTICIPANT	\N	PRESENT	0
465537	465527	19679N	PARTICIPANT	\N	PRESENT	0
465538	465527	19749K	PARTICIPANT	\N	PRESENT	0
465539	465527	19701S	PARTICIPANT	\N	EXCUSE	0
465540	465527	07029T	PARTICIPANT	\N	EXCUSE	0
465923	465335	08045X	PARTICIPANT	\N	PRESENT	0
465927	465926	11027H	PARTICIPANT	\N	PRESENT	0
465928	465926	14193X	PARTICIPANT	\N	PRESENT	0
465968	465963	04070G	PRESIDENT	0	PRESENT	0
465970	465963	19693L	PARTICIPANT	\N	PRESENT	0
465971	465963	19533U	PARTICIPANT	\N	PRESENT	0
465972	465963	19621T	PARTICIPANT	\N	PRESENT	0
465973	465963	19735D	PARTICIPANT	\N	PRESENT	0
465974	465963	14109K	PARTICIPANT	\N	PRESENT	0
465975	465963	14241N	PARTICIPANT	\N	PRESENT	0
465976	465963	11083R	PARTICIPANT	\N	PRESENT	0
465977	465963	04057K	PARTICIPANT	\N	PRESENT	0
465978	465963	19758L	PARTICIPANT	\N	PRESENT	0
465979	465963	19329S	PARTICIPANT	\N	PRESENT	0
465981	465963	04018C	PARTICIPANT	\N	PRESENT	0
465982	465963	14030Q	PARTICIPANT	\N	PRESENT	0
465984	465963	19643A	PARTICIPANT	\N	PRESENT	0
465985	465963	14251Q	PARTICIPANT	\N	PRESENT	0
465986	465963	19731Y	PARTICIPANT	\N	PRESENT	0
465987	465963	19766L	PARTICIPANT	\N	PRESENT	0
465988	465963	08031R	PARTICIPANT	\N	PRESENT	0
465989	465963	14061L	PARTICIPANT	\N	PRESENT	0
465990	465963	19399H	PARTICIPANT	\N	PRESENT	0
465992	465963	14123H	PARTICIPANT	\N	PRESENT	0
465993	465963	08039A	PARTICIPANT	\N	PRESENT	0
465994	465963	14107H	PARTICIPANT	\N	PRESENT	0
465995	465963	19611R	PARTICIPANT	\N	PRESENT	0
465996	465963	08020N	PARTICIPANT	\N	PRESENT	0
465997	465963	19593H	PARTICIPANT	\N	PRESENT	0
457226	457225	19515S	PARTICIPANT	\N	PRESENT	0
457228	457227	19515S	PARTICIPANT	\N	PRESENT	0
457415	457414	19599P	PARTICIPANT	\N	PRESENT	0
457416	457414	14157T	PARTICIPANT	\N	PRESENT	0
457417	457414	19637C	PARTICIPANT	\N	PRESENT	0
457423	457422	19599P	PARTICIPANT	\N	PRESENT	0
457424	457422	14157T	PARTICIPANT	\N	PRESENT	0
457425	457422	19826F	PARTICIPANT	\N	PRESENT	0
457426	457422	17583W	PARTICIPANT	\N	PRESENT	0
457427	457422	14083S	PARTICIPANT	\N	PRESENT	0
457429	457428	19599P	PARTICIPANT	\N	PRESENT	0
457430	457428	14157T	PARTICIPANT	\N	PRESENT	0
457431	457428	14083S	PARTICIPANT	\N	PRESENT	0
457433	457432	19599P	PARTICIPANT	\N	PRESENT	0
457434	457432	14157T	PARTICIPANT	\N	PRESENT	0
457435	457432	14083S	PARTICIPANT	\N	PRESENT	0
457436	457432	14031R	PARTICIPANT	\N	PRESENT	0
457437	457432	17583W	PARTICIPANT	\N	PRESENT	0
457444	457443	19599P	PARTICIPANT	\N	PRESENT	0
457445	457443	14157T	PARTICIPANT	\N	PRESENT	0
457446	457443	14053L	PARTICIPANT	\N	PRESENT	0
457447	457443	14083S	PARTICIPANT	\N	PRESENT	0
457449	457448	19599P	PARTICIPANT	\N	PRESENT	0
457450	457448	14157T	PARTICIPANT	\N	PRESENT	0
457452	457448	14053L	PARTICIPANT	\N	PRESENT	0
457453	457448	14083S	PARTICIPANT	\N	PRESENT	0
461939	458749	19583F	PARTICIPANT	\N	EXCUSE	0
461941	458749	14028W	PARTICIPANT	\N	EXCUSE	0
461943	458749	19443T	PARTICIPANT	\N	EXCUSE	0
461944	458749	19421M	PARTICIPANT	\N	EXCUSE	0
461973	461972	08018U	PARTICIPANT	\N	PRESENT	0
461974	461972	14259Y	PARTICIPANT	\N	PRESENT	0
468551	467224	19621T	PARTICIPANT	\N	PRESENT	0
468552	467224	14331P	PARTICIPANT	\N	PRESENT	0
468553	467224	05008E	PARTICIPANT	\N	PRESENT	0
468555	467224	96004D	PARTICIPANT	\N	PRESENT	0
468556	467224	19527W	PARTICIPANT	\N	PRESENT	0
468557	467224	14021P	PARTICIPANT	\N	PRESENT	0
468558	467224	08061X	PARTICIPANT	\N	PRESENT	0
468559	467224	14251Q	PARTICIPANT	\N	PRESENT	0
468560	467224	11064N	PARTICIPANT	\N	PRESENT	0
468561	467224	19585H	PARTICIPANT	\N	PRESENT	0
468562	467224	95063L	PARTICIPANT	\N	PRESENT	0
468563	467224	11072N	PARTICIPANT	\N	PRESENT	0
468564	467224	11074Q	PARTICIPANT	\N	PRESENT	0
468565	467224	11012A	PARTICIPANT	\N	PRESENT	0
468566	467224	11085T	PARTICIPANT	\N	PRESENT	0
468567	467224	14231L	PARTICIPANT	\N	PRESENT	0
468568	467224	08009T	PARTICIPANT	\N	PRESENT	0
468569	467224	14089Y	PARTICIPANT	\N	PRESENT	0
468570	467224	04092N	PARTICIPANT	\N	PRESENT	0
468571	467224	11090Q	PARTICIPANT	\N	PRESENT	0
468572	467224	19685L	PARTICIPANT	\N	PRESENT	0
468573	467224	04033B	PARTICIPANT	\N	PRESENT	0
468574	467224	01058X	PARTICIPANT	\N	PRESENT	0
468575	467224	17637T	PARTICIPANT	\N	PRESENT	0
468576	467224	04047H	PARTICIPANT	\N	PRESENT	0
468577	467224	08031R	PARTICIPANT	\N	PRESENT	0
468578	467224	11053K	PARTICIPANT	\N	PRESENT	0
468579	467224	08010L	PARTICIPANT	\N	PRESENT	0
468582	467224	04042C	PARTICIPANT	\N	PRESENT	0
468594	467534	11085T	PARTICIPANT	\N	PRESENT	0
468595	467534	14259Y	PARTICIPANT	\N	PRESENT	0
468596	467534	05008E	PRESIDENT	0	PRESENT	0
468597	467534	14231L	PARTICIPANT	\N	PRESENT	0
468977	468976	19545Y	PARTICIPANT	\N	PRESENT	0
468978	468976	19689Q	PARTICIPANT	\N	PRESENT	0
468980	468979	96004D	PARTICIPANT	\N	PRESENT	0
468981	468979	14331P	PARTICIPANT	\N	PRESENT	0
470112	468776	19631V	PARTICIPANT	\N	PRESENT	0
470113	468776	19515S	PARTICIPANT	\N	PRESENT	0
470114	468776	19545Y	PARTICIPANT	\N	PRESENT	0
470116	468776	19489J	PARTICIPANT	\N	PRESENT	0
470117	468776	19593H	PARTICIPANT	\N	PRESENT	0
470118	468776	19503N	PARTICIPANT	\N	PRESENT	0
470119	468776	19689Q	PARTICIPANT	\N	PRESENT	0
470447	468968	19667J	PARTICIPANT	\N	PRESENT	0
470448	468968	01057W	PARTICIPANT	\N	PRESENT	0
470449	468968	14225N	PARTICIPANT	\N	PRESENT	0
470450	468968	19711U	PARTICIPANT	\N	PRESENT	0
470451	468968	19349W	PARTICIPANT	\N	PRESENT	0
470452	468968	14331P	PARTICIPANT	\N	PRESENT	0
470453	468968	01048V	PARTICIPANT	\N	PRESENT	0
470454	468968	99004R	PARTICIPANT	\N	PRESENT	0
470455	468968	19671E	PARTICIPANT	\N	PRESENT	0
470456	468968	19687N	PARTICIPANT	\N	PRESENT	0
470457	468968	19479G	PARTICIPANT	\N	PRESENT	0
470458	468968	19689Q	PARTICIPANT	\N	PRESENT	0
470459	468968	08010L	PARTICIPANT	\N	PRESENT	0
470460	468968	08011M	PARTICIPANT	\N	PRESENT	0
470461	468968	11074Q	PRESIDENT	0	PRESENT	0
470462	468968	14083S	PARTICIPANT	\N	PRESENT	0
470463	468968	88008L	PARTICIPANT	\N	PRESENT	0
470464	468968	19741B	PARTICIPANT	\N	PRESENT	0
470465	468968	96004D	PARTICIPANT	\N	PRESENT	0
470466	468968	11040E	PARTICIPANT	\N	PRESENT	0
470467	468968	14085U	PARTICIPANT	\N	PRESENT	0
470468	468968	04086Q	PARTICIPANT	\N	PRESENT	0
470469	468968	19531S	PARTICIPANT	\N	PRESENT	0
470471	468968	11048N	PARTICIPANT	\N	PRESENT	0
470472	468968	11110B	PARTICIPANT	\N	PRESENT	0
470486	468968	11012A	PARTICIPANT	\N	EXCUSE	0
470487	468968	11053K	PARTICIPANT	\N	PRESENT	0
470488	468968	19647E	PARTICIPANT	\N	PRESENT	0
474920	474327	14001X	PARTICIPANT	\N	PRESENT	0
474921	474327	04044E	PARTICIPANT	\N	PRESENT	0
474922	474327	19581D	PARTICIPANT	\N	PRESENT	0
474923	474327	19447X	PARTICIPANT	\N	PRESENT	0
474924	474327	19489J	PARTICIPANT	\N	PRESENT	0
474925	474327	14215L	PARTICIPANT	\N	PRESENT	0
474926	474327	98035U	PARTICIPANT	\N	PRESENT	0
474927	474327	14111D	PARTICIPANT	\N	PRESENT	0
474928	474327	11033F	PARTICIPANT	\N	PRESENT	0
474929	474327	19729F	PARTICIPANT	\N	PRESENT	0
474930	474327	19629C	PARTICIPANT	\N	PRESENT	0
474931	474276	08041T	PARTICIPANT	\N	EXCUSE	0
474961	473521	19443T	PARTICIPANT	\N	PRESENT	0
474962	473521	12041X	PARTICIPANT	\N	PRESENT	0
474963	473521	95030B	PARTICIPANT	\N	PRESENT	0
474964	473521	04034C	PARTICIPANT	\N	PRESENT	0
474965	473521	01058X	PARTICIPANT	\N	PRESENT	0
474966	473521	04040A	PARTICIPANT	\N	PRESENT	0
474967	473521	14079W	PARTICIPANT	\N	PRESENT	0
474968	473521	11027H	PARTICIPANT	\N	PRESENT	0
474969	473521	16685X	PARTICIPANT	\N	PRESENT	0
474970	473521	04042C	PRESIDENT	0	PRESENT	0
474971	473521	11054L	PARTICIPANT	\N	PRESENT	0
474972	473521	11066Q	PARTICIPANT	\N	PRESENT	0
474973	473521	08056B	PARTICIPANT	\N	PRESENT	0
474974	473521	11115U	PARTICIPANT	\N	PRESENT	0
474975	473521	95037J	PARTICIPANT	\N	PRESENT	0
474976	473521	19421M	PARTICIPANT	\N	PRESENT	0
474977	473521	19709B	PARTICIPANT	\N	PRESENT	0
474978	473521	14193X	PARTICIPANT	\N	PRESENT	0
474979	473521	97011G	PARTICIPANT	\N	PRESENT	0
474980	473521	08061X	PARTICIPANT	\N	PRESENT	0
474981	473521	08047A	PARTICIPANT	\N	PRESENT	0
474982	473521	98029W	PARTICIPANT	\N	PRESENT	0
474983	473521	14097Y	PARTICIPANT	\N	PRESENT	0
474984	473521	04035D	PARTICIPANT	\N	PRESENT	0
474985	473521	95067Q	PARTICIPANT	\N	PRESENT	0
474986	473521	14133K	PARTICIPANT	\N	PRESENT	0
474987	473521	01062T	PARTICIPANT	\N	PRESENT	0
474988	473521	11041F	PARTICIPANT	\N	PRESENT	0
474989	473521	08058D	PARTICIPANT	\N	PRESENT	0
474990	473521	19251M	PARTICIPANT	\N	PRESENT	0
474991	473521	14105F	PARTICIPANT	\N	PRESENT	0
474992	473521	98018T	PARTICIPANT	\N	PRESENT	0
474993	473521	98022P	PARTICIPANT	\N	PRESENT	0
474994	473521	14267Y	PARTICIPANT	\N	PRESENT	0
474995	473521	11064N	PARTICIPANT	\N	PRESENT	0
474997	473521	19583F	PARTICIPANT	\N	PRESENT	0
474998	473521	14255U	PARTICIPANT	\N	PRESENT	0
474999	473521	14028W	PARTICIPANT	\N	EXCUSE	0
475002	472986	19768N	PARTICIPANT	\N	PRESENT	0
475003	472986	19515S	PARTICIPANT	\N	PRESENT	0
475004	472986	14187A	PARTICIPANT	\N	PRESENT	0
475005	472986	19812Y	PARTICIPANT	\N	PRESENT	0
475006	472986	19695N	PARTICIPANT	\N	PRESENT	0
475007	472986	11090Q	PRESIDENT	0	PRESENT	0
475008	472986	14205J	PARTICIPANT	\N	PRESENT	0
475009	472986	11056N	PARTICIPANT	\N	PRESENT	0
475010	472986	11099A	PARTICIPANT	\N	PRESENT	0
475011	472986	14115H	PARTICIPANT	\N	PRESENT	0
475012	472986	04049K	PARTICIPANT	\N	PRESENT	0
475013	472986	14197C	PARTICIPANT	\N	PRESENT	0
475014	472986	19747H	PARTICIPANT	\N	PRESENT	0
475015	472986	14207L	PARTICIPANT	\N	PRESENT	0
468838	468836	08039A	PARTICIPANT	\N	PRESENT	0
468839	468836	04059M	PARTICIPANT	\N	PRESENT	0
468840	468836	19399H	PARTICIPANT	\N	PRESENT	0
468841	467728	14331P	PARTICIPANT	\N	PRESENT	0
468842	467728	19545Y	PARTICIPANT	\N	PRESENT	0
468843	467728	01057W	PARTICIPANT	\N	PRESENT	0
468844	467728	11053K	PARTICIPANT	\N	PRESENT	0
468845	467728	19667J	PARTICIPANT	\N	PRESENT	0
468846	467728	11074Q	PRESIDENT	0	PRESENT	0
468847	467728	19671E	PARTICIPANT	\N	PRESENT	0
468848	467728	14225N	PARTICIPANT	\N	PRESENT	0
468849	467728	14085U	PARTICIPANT	\N	PRESENT	0
468850	467728	96004D	PARTICIPANT	\N	PRESENT	0
468851	467728	19349W	PARTICIPANT	\N	PRESENT	0
468852	467728	08010L	PARTICIPANT	\N	PRESENT	0
468853	467728	14253S	PARTICIPANT	\N	PRESENT	0
468854	467728	19479G	PARTICIPANT	\N	PRESENT	0
468855	467728	11048N	PARTICIPANT	\N	PRESENT	0
468856	467728	19711U	PARTICIPANT	\N	PRESENT	0
468857	467728	19531S	PARTICIPANT	\N	PRESENT	0
468858	467728	08034U	PARTICIPANT	\N	PRESENT	0
468859	467728	19687N	PARTICIPANT	\N	PRESENT	0
468860	467728	08011M	PARTICIPANT	\N	PRESENT	0
468861	467728	14173T	PARTICIPANT	\N	PRESENT	0
468862	467728	04086Q	PARTICIPANT	\N	PRESENT	0
468863	467728	11040E	PARTICIPANT	\N	PRESENT	0
468864	467728	14083S	PARTICIPANT	\N	PRESENT	0
468971	466411	11072N	PARTICIPANT	\N	EXCUSE	0
468866	467728	19741B	PARTICIPANT	\N	PRESENT	0
468867	467728	99004R	PARTICIPANT	\N	PRESENT	0
468868	467728	07029T	PARTICIPANT	\N	EXCUSE	0
468970	466411	19659J	PARTICIPANT	\N	EXCUSE	0
468973	468972	11072N	PARTICIPANT	\N	PRESENT	0
468974	468972	08019V	PRESIDENT	0	PRESENT	0
468975	466411	08019V	PARTICIPANT	\N	PRESENT	0
468982	468946	14063N	PARTICIPANT	\N	EXCUSE	0
468993	468946	04040A	PRESIDENT	0	PRESENT	0
468994	468946	19253P	PARTICIPANT	\N	EXCUSE	0
468996	468995	11053K	PARTICIPANT	\N	PRESENT	0
468997	468995	14159V	PARTICIPANT	\N	PRESENT	0
468998	468995	05012A	PARTICIPANT	\N	PRESENT	0
469000	468999	04018C	PARTICIPANT	\N	PRESENT	0
469001	468999	07033P	PARTICIPANT	\N	PRESENT	0
469002	468999	08039A	PARTICIPANT	\N	PRESENT	0
469003	468999	14109K	PARTICIPANT	\N	PRESENT	0
469004	468999	19749K	PARTICIPANT	\N	PRESENT	0
469006	469005	08020N	PARTICIPANT	\N	PRESENT	0
469007	469005	19693L	PARTICIPANT	\N	PRESENT	0
469008	469005	08031R	PARTICIPANT	\N	PRESENT	0
469009	469005	19699S	PARTICIPANT	\N	PRESENT	0
469010	469005	04057K	PARTICIPANT	\N	PRESENT	0
469011	469005	19335Q	PARTICIPANT	\N	PRESENT	0
469013	469012	08020N	PARTICIPANT	\N	PRESENT	0
469014	469012	19693L	PARTICIPANT	\N	PRESENT	0
469015	469012	08031R	PARTICIPANT	\N	PRESENT	0
469016	469012	19699S	PARTICIPANT	\N	PRESENT	0
469017	469012	04057K	PARTICIPANT	\N	PRESENT	0
469018	469012	19335Q	PARTICIPANT	\N	PRESENT	0
469020	469019	08020N	PARTICIPANT	\N	PRESENT	0
469021	469019	19693L	PARTICIPANT	\N	PRESENT	0
469022	469019	08031R	PARTICIPANT	\N	PRESENT	0
469023	469019	19699S	PARTICIPANT	\N	PRESENT	0
469024	469019	04057K	PARTICIPANT	\N	PRESENT	0
469025	469019	19335Q	PARTICIPANT	\N	PRESENT	0
469027	469026	08020N	PARTICIPANT	\N	PRESENT	0
469028	469026	19335Q	PARTICIPANT	\N	PRESENT	0
469029	469026	04057K	PARTICIPANT	\N	PRESENT	0
469030	469026	19699S	PARTICIPANT	\N	PRESENT	0
469031	469026	08031R	PARTICIPANT	\N	PRESENT	0
469032	469026	19693L	PARTICIPANT	\N	PRESENT	0
469034	469033	19575F	PARTICIPANT	\N	PRESENT	0
469035	469033	14030Q	PARTICIPANT	\N	PRESENT	0
469036	469033	14105F	PARTICIPANT	\N	PRESENT	0
469037	469033	14083S	PARTICIPANT	\N	PRESENT	0
469038	469033	14061L	PARTICIPANT	\N	PRESENT	0
469039	469033	04049K	PRESIDENT	0	PRESENT	0
469040	469033	14205J	PARTICIPANT	\N	PRESENT	0
469041	469033	14087W	PARTICIPANT	\N	PRESENT	0
469042	469033	14255U	PARTICIPANT	\N	PRESENT	0
469043	469033	08015R	PARTICIPANT	\N	PRESENT	0
469044	469033	19671E	PARTICIPANT	\N	PRESENT	0
469045	469033	08060W	PARTICIPANT	\N	EXCUSE	0
469046	469033	14053L	PARTICIPANT	\N	EXCUSE	0
469047	469033	14041T	PARTICIPANT	\N	EXCUSE	0
469048	469033	08047A	PARTICIPANT	\N	EXCUSE	0
469049	469033	14051J	PARTICIPANT	\N	EXCUSE	0
469050	469033	14157T	PARTICIPANT	\N	EXCUSE	0
469051	468946	04044E	PARTICIPANT	\N	EXCUSE	0
469067	468946	04086Q	PARTICIPANT	\N	EXCUSE	0
469109	468730	19319Q	PARTICIPANT	\N	PRESENT	0
469111	469110	11070L	PARTICIPANT	\N	PRESENT	0
469112	469110	11040E	PARTICIPANT	\N	PRESENT	0
469113	469110	19711U	PARTICIPANT	\N	PRESENT	0
469114	467697	19766L	PARTICIPANT	\N	PRESENT	0
469115	467697	08017T	PARTICIPANT	\N	PRESENT	0
469116	467699	08017T	PARTICIPANT	\N	PRESENT	0
469117	467699	19766L	PARTICIPANT	\N	PRESENT	0
469119	469118	14241N	PARTICIPANT	\N	PRESENT	0
469120	469118	08012N	PARTICIPANT	\N	PRESENT	0
469121	469118	11043H	PARTICIPANT	\N	PRESENT	0
469122	469118	14073Q	PARTICIPANT	\N	PRESENT	0
469123	469118	19643A	PARTICIPANT	\N	PRESENT	0
469124	467689	19593H	PARTICIPANT	\N	PRESENT	0
469327	469242	10006L	PARTICIPANT	\N	PRESENT	0
469328	469242	19575F	PARTICIPANT	\N	PRESENT	0
469329	469242	14042U	PARTICIPANT	\N	PRESENT	0
469330	469242	19657G	PARTICIPANT	\N	PRESENT	0
469331	469242	19703U	PARTICIPANT	\N	PRESENT	0
469332	469242	19679N	PARTICIPANT	\N	PRESENT	0
469333	469242	14281W	PARTICIPANT	\N	PRESENT	0
469335	469242	08048B	PARTICIPANT	\N	PRESENT	0
469336	469242	19415P	PARTICIPANT	\N	PRESENT	0
469339	469242	19569H	PARTICIPANT	\N	PRESENT	0
469340	469242	19577H	PARTICIPANT	\N	PRESENT	0
469341	469242	19553Y	PARTICIPANT	\N	PRESENT	0
469342	469242	11097X	PARTICIPANT	\N	PRESENT	0
469343	469242	01034P	PARTICIPANT	\N	PRESENT	0
469351	469242	14217N	PARTICIPANT	\N	PRESENT	0
469352	469242	08052W	PARTICIPANT	\N	PRESENT	0
469353	469242	11067R	PARTICIPANT	\N	PRESENT	0
469354	469242	19798U	PARTICIPANT	\N	PRESENT	0
469600	467691	08017T	PARTICIPANT	\N	PRESENT	0
469601	467691	19766L	PARTICIPANT	\N	PRESENT	0
469602	467693	19766L	PARTICIPANT	\N	PRESENT	0
469603	467693	08017T	PARTICIPANT	\N	PRESENT	0
469833	468604	14239U	PARTICIPANT	\N	PRESENT	0
469834	468604	19575F	PARTICIPANT	\N	PRESENT	0
469836	468604	19723Y	PARTICIPANT	\N	PRESENT	0
469837	468604	19697Q	PARTICIPANT	\N	PRESENT	0
469838	468604	11097X	PARTICIPANT	\N	PRESENT	0
469840	469379	14042U	PARTICIPANT	\N	PRESENT	0
469841	469379	19723Y	PARTICIPANT	\N	PRESENT	0
469842	469381	19575F	PARTICIPANT	\N	PRESENT	0
469844	469381	08052W	PARTICIPANT	\N	PRESENT	0
469845	469381	11097X	PARTICIPANT	\N	PRESENT	0
469855	466583	80013X	PARTICIPANT	\N	PRESENT	0
469997	469996	05008E	PARTICIPANT	\N	PRESENT	0
469998	469996	19649G	PARTICIPANT	\N	PRESENT	0
469999	469996	01024M	PARTICIPANT	\N	PRESENT	0
470000	469996	19489J	PARTICIPANT	\N	PRESENT	0
470001	469996	11026G	PARTICIPANT	\N	PRESENT	0
470002	469996	11085T	PARTICIPANT	\N	PRESENT	0
470003	469996	14147R	PARTICIPANT	\N	PRESENT	0
470004	469996	10015M	PARTICIPANT	\N	PRESENT	0
470006	469996	95063L	PARTICIPANT	\N	PRESENT	0
470008	466583	19701S	PARTICIPANT	\N	EXCUSE	0
470009	466583	19599P	PARTICIPANT	\N	EXCUSE	0
470012	466583	14261S	PARTICIPANT	\N	PRESENT	0
470014	466583	14030Q	PRESIDENT	0	PRESENT	0
470015	466583	08043V	PARTICIPANT	\N	PRESENT	0
470016	466583	19621T	PARTICIPANT	\N	PRESENT	0
470017	466583	08024S	PARTICIPANT	\N	PRESENT	0
470018	466583	18083K	PARTICIPANT	\N	PRESENT	0
470019	466583	11031D	PARTICIPANT	\N	PRESENT	0
470020	466583	19693L	PARTICIPANT	\N	PRESENT	0
470021	466583	19577H	PARTICIPANT	\N	PRESENT	0
470022	466583	14179A	PARTICIPANT	\N	PRESENT	0
470023	466583	19715Y	PARTICIPANT	\N	PRESENT	0
470024	466583	08031R	PARTICIPANT	\N	PRESENT	0
470025	466583	08017T	PARTICIPANT	\N	PRESENT	0
470026	466583	19657G	PARTICIPANT	\N	PRESENT	0
470027	466583	14251Q	PARTICIPANT	\N	PRESENT	0
470028	466583	11067R	PARTICIPANT	\N	PRESENT	0
470029	466583	19679N	PARTICIPANT	\N	PRESENT	0
470030	466583	19269X	PARTICIPANT	\N	PRESENT	0
470031	466583	11045K	PARTICIPANT	\N	PRESENT	0
470032	466411	11109J	PARTICIPANT	\N	PRESENT	0
470033	466411	14261S	PARTICIPANT	\N	PRESENT	0
470034	466411	19717B	PARTICIPANT	\N	PRESENT	0
459416	448770	19719D	PARTICIPANT	\N	PRESENT	0
459417	448770	14241N	PARTICIPANT	\N	PRESENT	0
459418	448770	14115H	PARTICIPANT	\N	PRESENT	0
459419	448770	19387D	PARTICIPANT	\N	PRESENT	0
459420	448770	11099A	PARTICIPANT	\N	PRESENT	0
459421	448770	08047A	PARTICIPANT	\N	PRESENT	0
459422	448770	14107H	PARTICIPANT	\N	PRESENT	0
459423	448770	97011G	PARTICIPANT	\N	PRESENT	0
459424	448770	14201E	PARTICIPANT	\N	PRESENT	0
459425	448770	07033P	PARTICIPANT	\N	PRESENT	0
459426	448770	04057K	PARTICIPANT	\N	PRESENT	0
459427	448770	02002K	PARTICIPANT	\N	PRESENT	0
459428	448770	14217N	PARTICIPANT	\N	PRESENT	0
459429	448770	17589D	PARTICIPANT	\N	PRESENT	0
459430	448770	04069P	PARTICIPANT	\N	PRESENT	0
459431	448770	14111D	PARTICIPANT	\N	PRESENT	0
459432	448770	19585H	PARTICIPANT	\N	PRESENT	0
459433	448770	14331P	PARTICIPANT	\N	PRESENT	0
459434	448770	14079W	PARTICIPANT	\N	PRESENT	0
459435	448770	19553Y	PARTICIPANT	\N	PRESENT	0
459436	448770	19717B	PARTICIPANT	\N	PRESENT	0
459437	448770	14207L	PARTICIPANT	\N	PRESENT	0
459438	448770	14237S	PARTICIPANT	\N	PRESENT	0
459439	448770	19798U	PARTICIPANT	\N	PRESENT	0
459440	448770	10006L	PARTICIPANT	\N	PRESENT	0
459441	448770	19533U	PARTICIPANT	\N	PRESENT	0
459442	448770	08034U	PARTICIPANT	\N	PRESENT	0
459443	448770	04049K	PARTICIPANT	\N	PRESENT	0
459444	448770	14253S	PARTICIPANT	\N	PRESENT	0
459445	448770	19575F	PARTICIPANT	\N	PRESENT	0
459446	448770	14199E	PARTICIPANT	\N	PRESENT	0
459447	448770	19667J	PARTICIPANT	\N	PRESENT	0
459448	448770	19673G	PARTICIPANT	\N	PRESENT	0
459449	448770	19703U	PARTICIPANT	\N	PRESENT	0
459450	448770	19515S	PARTICIPANT	\N	PRESENT	0
459451	448770	98035U	PARTICIPANT	\N	PRESENT	0
459452	448770	04059M	PARTICIPANT	\N	PRESENT	0
459453	448770	11074Q	PARTICIPANT	\N	PRESENT	0
459454	448770	14051J	PARTICIPANT	\N	PRESENT	0
459455	448770	11090Q	PARTICIPANT	\N	PRESENT	0
459456	448770	04043D	PARTICIPANT	\N	PRESENT	0
459457	448770	08068F	PARTICIPANT	\N	PRESENT	0
459458	448770	14053L	PARTICIPANT	\N	PRESENT	0
459459	448770	14087W	PARTICIPANT	\N	PRESENT	0
459460	448770	08052W	PARTICIPANT	\N	PRESENT	0
459461	448770	19421M	PARTICIPANT	\N	PRESENT	0
459462	448770	14229S	PARTICIPANT	\N	PRESENT	0
459463	448770	11097X	PARTICIPANT	\N	PRESENT	0
459464	448770	05008E	PARTICIPANT	\N	PRESENT	0
459465	448770	14071N	PARTICIPANT	\N	PRESENT	0
459466	448770	14187A	PARTICIPANT	\N	PRESENT	0
459467	448770	04033B	PARTICIPANT	\N	PRESENT	0
459468	448770	08028W	PARTICIPANT	\N	PRESENT	0
459469	448770	01028R	PARTICIPANT	\N	PRESENT	0
459470	448770	01048V	PARTICIPANT	\N	PRESENT	0
459471	448770	14021P	PARTICIPANT	\N	PRESENT	0
459472	448770	14147R	PARTICIPANT	\N	PRESENT	0
459473	448770	08045X	PARTICIPANT	\N	PRESENT	0
459474	448770	14225N	PARTICIPANT	\N	PRESENT	0
459475	448770	19599P	PARTICIPANT	\N	PRESENT	0
459476	448770	14169X	PARTICIPANT	\N	PRESENT	0
459477	448770	04071H	PARTICIPANT	\N	PRESENT	0
459478	448770	08060W	PARTICIPANT	\N	PRESENT	0
459479	448770	19643A	PARTICIPANT	\N	PRESENT	0
459480	448770	11041F	PARTICIPANT	\N	PRESENT	0
459481	448770	11066Q	PARTICIPANT	\N	PRESENT	0
459482	448770	04097T	PARTICIPANT	\N	PRESENT	0
459483	448770	80013X	PARTICIPANT	\N	PRESENT	0
459484	448770	08020N	PARTICIPANT	\N	PRESENT	0
459485	448770	19687N	PARTICIPANT	\N	PRESENT	0
459486	448770	04042C	PARTICIPANT	\N	PRESENT	0
459487	448770	14029X	PARTICIPANT	\N	PRESENT	0
459488	448770	04044E	PARTICIPANT	\N	PRESENT	0
459489	448770	19689Q	PARTICIPANT	\N	PRESENT	0
459490	448770	19747H	PARTICIPANT	\N	PRESENT	0
459491	448770	14026U	PARTICIPANT	\N	PRESENT	0
459492	448770	19768N	PARTICIPANT	\N	PRESENT	0
459493	448770	95030B	PARTICIPANT	\N	PRESENT	0
459494	448770	08011M	PARTICIPANT	\N	PRESENT	0
459495	448770	14151M	PARTICIPANT	\N	PRESENT	0
459496	448770	14197C	PARTICIPANT	\N	PRESENT	0
459497	448770	98018T	PARTICIPANT	\N	PRESENT	0
459498	448770	04008A	PARTICIPANT	\N	PRESENT	0
459499	448770	19727D	PARTICIPANT	\N	PRESENT	0
459500	448770	19649G	PARTICIPANT	\N	PRESENT	0
459501	448770	19711U	PARTICIPANT	\N	PRESENT	0
459502	448770	11045K	PARTICIPANT	\N	PRESENT	0
459503	448770	14028W	PARTICIPANT	\N	PRESENT	0
459504	448770	08043V	PARTICIPANT	\N	PRESENT	0
459505	448770	11104D	PARTICIPANT	\N	PRESENT	0
459506	448770	14281W	PARTICIPANT	\N	PRESENT	0
459507	448770	04035D	PARTICIPANT	\N	PRESENT	0
459508	448770	14215L	PARTICIPANT	\N	PRESENT	0
459509	448770	14105F	PARTICIPANT	\N	PRESENT	0
459510	448770	19820Y	PARTICIPANT	\N	PRESENT	0
459511	448770	19531S	PARTICIPANT	\N	PRESENT	0
459512	448770	19489J	PARTICIPANT	\N	PRESENT	0
459513	448770	14191V	PARTICIPANT	\N	PRESENT	0
459514	448770	17779H	PARTICIPANT	\N	PRESENT	0
459515	448770	14065Q	PARTICIPANT	\N	PRESENT	0
459516	448770	14085U	PARTICIPANT	\N	PRESENT	0
459517	448770	08017T	PARTICIPANT	\N	PRESENT	0
459518	448770	08053X	PARTICIPANT	\N	PRESENT	0
459519	448770	19525U	PARTICIPANT	\N	PRESENT	0
459520	448770	14081Q	PARTICIPANT	\N	PRESENT	0
459521	448770	11110B	PARTICIPANT	\N	PRESENT	0
459522	448770	19333N	PARTICIPANT	\N	PRESENT	0
459523	448770	14001X	PARTICIPANT	\N	PRESENT	0
459524	448770	19669L	PARTICIPANT	\N	PRESENT	0
459525	448770	14227Q	PARTICIPANT	\N	PRESENT	0
459526	448770	19683J	PARTICIPANT	\N	PRESENT	0
459527	448770	11109J	PARTICIPANT	\N	PRESENT	0
459528	448770	19709B	PARTICIPANT	\N	PRESENT	0
459529	448770	19295A	PARTICIPANT	\N	PRESENT	0
459530	448770	11054L	PARTICIPANT	\N	PRESENT	0
459531	448770	19413M	PARTICIPANT	\N	PRESENT	0
459532	448770	19251M	PARTICIPANT	\N	PRESENT	0
459533	448770	14069U	PARTICIPANT	\N	PRESENT	0
459534	448770	11026G	PARTICIPANT	\N	PRESENT	0
459535	448770	14063N	PARTICIPANT	\N	PRESENT	0
459536	448770	04086Q	PARTICIPANT	\N	PRESENT	0
459537	448770	19503N	PARTICIPANT	\N	PRESENT	0
459538	448770	11067R	PARTICIPANT	\N	PRESENT	0
459539	448770	19725B	PARTICIPANT	\N	PRESENT	0
459540	448770	19631V	PARTICIPANT	\N	PRESENT	0
459541	448770	14097Y	PARTICIPANT	\N	PRESENT	0
459542	448770	11065P	PARTICIPANT	\N	PRESENT	0
459543	448770	19329S	PARTICIPANT	\N	PRESENT	0
459544	448770	19713W	PARTICIPANT	\N	PRESENT	0
459545	448770	14275Y	PARTICIPANT	\N	PRESENT	0
459546	448770	19441R	PARTICIPANT	\N	PRESENT	0
459547	448770	14251Q	PARTICIPANT	\N	PRESENT	0
459548	448770	19563B	PARTICIPANT	\N	PRESENT	0
459549	448770	14219Q	PARTICIPANT	\N	PRESENT	0
459550	448770	07004J	PARTICIPANT	\N	PRESENT	0
459551	448770	19521Q	PARTICIPANT	\N	PRESENT	0
459552	448770	19569H	PARTICIPANT	\N	PRESENT	0
459553	448770	16685X	PARTICIPANT	\N	PRESENT	0
459554	448770	19699S	PARTICIPANT	\N	PRESENT	0
459555	448770	19527W	PARTICIPANT	\N	PRESENT	0
459556	448770	19721W	PARTICIPANT	\N	PRESENT	0
459557	448770	11085T	PARTICIPANT	\N	PRESENT	0
459558	448770	19737F	PARTICIPANT	\N	PRESENT	0
459559	448770	14205J	PARTICIPANT	\N	PRESENT	0
459560	448770	19611R	PARTICIPANT	\N	PRESENT	0
459561	448770	14329V	PARTICIPANT	\N	PRESENT	0
459562	448770	19511N	PARTICIPANT	\N	PRESENT	0
459563	448770	19691J	PARTICIPANT	\N	PRESENT	0
459564	448770	01034P	PARTICIPANT	\N	PRESENT	0
459565	448770	01043Q	PARTICIPANT	\N	PRESENT	0
459566	448770	04089T	PARTICIPANT	\N	PRESENT	0
459567	448770	14267Y	PARTICIPANT	\N	PRESENT	0
459568	448770	14221J	PARTICIPANT	\N	PRESENT	0
459569	448770	19335Q	PARTICIPANT	\N	PRESENT	0
459570	448770	89017R	PARTICIPANT	\N	PRESENT	0
459571	448770	14249W	PARTICIPANT	\N	PRESENT	0
459572	448770	14231L	PARTICIPANT	\N	PRESENT	0
459573	448770	14073Q	PARTICIPANT	\N	PRESENT	0
459574	448770	14255U	PARTICIPANT	\N	PRESENT	0
459575	448770	14277B	PARTICIPANT	\N	PRESENT	0
459576	448770	11070L	PARTICIPANT	\N	PRESENT	0
459577	448770	14042U	PARTICIPANT	\N	PRESENT	0
459578	448770	04070G	PARTICIPANT	\N	PRESENT	0
459579	448770	01025N	PARTICIPANT	\N	PRESENT	0
459580	448770	01024M	PARTICIPANT	\N	PRESENT	0
459581	448770	14030Q	PARTICIPANT	\N	PRESENT	0
459582	448770	14327T	PARTICIPANT	\N	PRESENT	0
459583	448770	14089Y	PARTICIPANT	\N	PRESENT	0
465998	465963	14059S	PARTICIPANT	\N	PRESENT	0
465999	465963	14073Q	PARTICIPANT	\N	PRESENT	0
466002	465963	08043V	PARTICIPANT	\N	EXCUSE	0
466005	465963	14213J	PARTICIPANT	\N	PRESENT	0
466203	465336	14179A	PARTICIPANT	\N	PRESENT	0
466204	465336	14215L	PARTICIPANT	\N	PRESENT	0
466388	464622	14034U	PARTICIPANT	\N	PRESENT	0
466390	464622	19651A	PARTICIPANT	\N	PRESENT	0
466391	464622	19687N	PARTICIPANT	\N	PRESENT	0
466392	464622	19563B	PARTICIPANT	\N	PRESENT	0
466393	464622	11053K	PARTICIPANT	\N	PRESENT	0
466394	464622	14085U	PARTICIPANT	\N	PRESENT	0
466395	464622	11048N	PARTICIPANT	\N	PRESENT	0
466396	464622	14157T	PARTICIPANT	\N	PRESENT	0
466397	464622	19543W	PARTICIPANT	\N	PRESENT	0
466398	464622	11074Q	PARTICIPANT	\N	PRESENT	0
466399	464622	19671E	PARTICIPANT	\N	PRESENT	0
466400	464622	07033P	PARTICIPANT	\N	PRESENT	0
466402	464622	08010L	PARTICIPANT	\N	PRESENT	0
466403	464622	11085T	PARTICIPANT	\N	PRESENT	0
466404	464622	19647E	PARTICIPANT	\N	PRESENT	0
466405	464622	98050T	PARTICIPANT	\N	PRESENT	0
466406	464622	11045K	PARTICIPANT	\N	PRESENT	0
466408	464622	19531S	PARTICIPANT	\N	PRESENT	0
466409	464622	14251Q	PARTICIPANT	\N	PRESENT	0
466410	464622	11072N	PARTICIPANT	\N	PRESENT	0
466528	466527	14179A	PARTICIPANT	\N	PRESENT	0
466529	466527	19489J	PARTICIPANT	\N	PRESENT	0
466530	466527	19585H	PARTICIPANT	\N	PRESENT	0
466555	466554	04049K	PARTICIPANT	\N	PRESENT	0
466556	466554	16685X	PARTICIPANT	\N	PRESENT	0
466563	466561	19503N	PARTICIPANT	\N	PRESENT	0
466869	466046	19768N	PARTICIPANT	\N	PRESENT	0
466870	466046	14081Q	PARTICIPANT	\N	PRESENT	0
466871	466046	19369B	PARTICIPANT	\N	PRESENT	0
466872	466046	14135M	PARTICIPANT	\N	PRESENT	0
466873	466046	14205J	PARTICIPANT	\N	PRESENT	0
466262	464622	86034E	PARTICIPANT	\N	PRESENT	0
466263	466221	98005N	PARTICIPANT	\N	PRESENT	0
466264	466221	19443T	PARTICIPANT	\N	PRESENT	0
466265	466221	12041X	PARTICIPANT	\N	PRESENT	0
466266	466221	95030B	PARTICIPANT	\N	PRESENT	0
466267	466221	04034C	PARTICIPANT	\N	PRESENT	0
466268	466221	14079W	PARTICIPANT	\N	PRESENT	0
466269	466221	01058X	PARTICIPANT	\N	PRESENT	0
466270	466221	04040A	PARTICIPANT	\N	PRESENT	0
466271	466221	11027H	PARTICIPANT	\N	PRESENT	0
466272	466221	16685X	PARTICIPANT	\N	PRESENT	0
466273	466221	04042C	PRESIDENT	0	PRESENT	0
466274	466221	11054L	PARTICIPANT	\N	PRESENT	0
466275	466221	19669L	PARTICIPANT	\N	PRESENT	0
466276	466221	11066Q	PARTICIPANT	\N	PRESENT	0
466277	466221	08056B	PARTICIPANT	\N	PRESENT	0
466278	466221	19421M	PARTICIPANT	\N	PRESENT	0
466279	466221	19709B	PARTICIPANT	\N	PRESENT	0
466280	466221	14193X	PARTICIPANT	\N	PRESENT	0
466281	466221	97011G	PARTICIPANT	\N	PRESENT	0
466282	466221	08061X	PARTICIPANT	\N	PRESENT	0
466283	466221	08047A	PARTICIPANT	\N	PRESENT	0
466284	466221	98029W	PARTICIPANT	\N	PRESENT	0
466285	466221	14097Y	PARTICIPANT	\N	PRESENT	0
466286	466221	04035D	PARTICIPANT	\N	PRESENT	0
466287	466221	95067Q	PARTICIPANT	\N	PRESENT	0
466288	466221	14133K	PARTICIPANT	\N	PRESENT	0
466289	466221	01062T	PARTICIPANT	\N	PRESENT	0
466290	466221	11041F	PARTICIPANT	\N	PRESENT	0
466291	466221	14235Q	PARTICIPANT	\N	PRESENT	0
466292	466221	08058D	PARTICIPANT	\N	PRESENT	0
466293	466221	14028W	PARTICIPANT	\N	PRESENT	0
466294	466221	19319Q	PARTICIPANT	\N	PRESENT	0
466295	466221	14105F	PARTICIPANT	\N	PRESENT	0
466296	466221	98018T	PARTICIPANT	\N	PRESENT	0
466297	466221	98022P	PARTICIPANT	\N	PRESENT	0
466298	466221	14267Y	PARTICIPANT	\N	PRESENT	0
466299	466221	11064N	PARTICIPANT	\N	PRESENT	0
466300	466221	98050T	PARTICIPANT	\N	PRESENT	0
466301	466221	14211G	PARTICIPANT	\N	PRESENT	0
466302	466221	14255U	PARTICIPANT	\N	PRESENT	0
466303	466221	08049C	PARTICIPANT	\N	EXCUSE	0
466969	466967	19503N	PARTICIPANT	\N	PRESENT	0
466970	466591	19649G	PARTICIPANT	\N	PRESENT	0
466971	466591	14065Q	PARTICIPANT	\N	PRESENT	0
466972	466591	14001X	PARTICIPANT	\N	PRESENT	0
466973	466591	19253P	PARTICIPANT	\N	PRESENT	0
466974	466591	01024M	PARTICIPANT	\N	PRESENT	0
466975	466591	19543W	PARTICIPANT	\N	PRESENT	0
466976	466591	19585H	PARTICIPANT	\N	PRESENT	0
466977	466591	04047H	PARTICIPANT	\N	PRESENT	0
466978	466591	19673G	PARTICIPANT	\N	PRESENT	0
466979	466591	19719D	PARTICIPANT	\N	PRESENT	0
466980	466591	11033F	PARTICIPANT	\N	PRESENT	0
466981	466591	19447X	PARTICIPANT	\N	PRESENT	0
466982	466591	14231L	PARTICIPANT	\N	PRESENT	0
466983	466591	05008E	PRESIDENT	0	PRESENT	0
466984	466591	19725B	PARTICIPANT	\N	PRESENT	0
466985	466591	95063L	PARTICIPANT	\N	PRESENT	0
466986	466591	19629C	PARTICIPANT	\N	PRESENT	0
466987	466591	14041T	PARTICIPANT	\N	PRESENT	0
466988	466591	14179A	PARTICIPANT	\N	PRESENT	0
466989	466591	14147R	PARTICIPANT	\N	PRESENT	0
466990	466591	14215L	PARTICIPANT	\N	PRESENT	0
466991	466591	11049P	PARTICIPANT	\N	PRESENT	0
466992	466591	14021P	PARTICIPANT	\N	PRESENT	0
466995	466993	19503N	PARTICIPANT	\N	PRESENT	0
466996	466591	19581D	PARTICIPANT	\N	PRESENT	0
466997	466591	01028R	PARTICIPANT	\N	PRESENT	0
466998	466591	11072N	PARTICIPANT	\N	PRESENT	0
466999	466591	14053L	PARTICIPANT	\N	PRESENT	0
467000	466591	08045X	PARTICIPANT	\N	PRESENT	0
467001	466591	04038G	PARTICIPANT	\N	PRESENT	0
467002	466591	04044E	PARTICIPANT	\N	PRESENT	0
467003	466591	19489J	PARTICIPANT	\N	PRESENT	0
467004	466591	14151M	PARTICIPANT	\N	PRESENT	0
467005	466591	14111D	PARTICIPANT	\N	PRESENT	0
467006	466591	11026G	PARTICIPANT	\N	PRESENT	0
467007	466591	14069U	PARTICIPANT	\N	PRESENT	0
467008	466047	19768N	PARTICIPANT	\N	PRESENT	0
467009	466047	19515S	PARTICIPANT	\N	PRESENT	0
467010	466047	19782L	PARTICIPANT	\N	PRESENT	0
467011	466047	01043Q	PARTICIPANT	\N	PRESENT	0
467012	466047	14357A	PARTICIPANT	\N	PRESENT	0
467013	466047	19441R	PARTICIPANT	\N	PRESENT	0
467014	466047	19812Y	PARTICIPANT	\N	PRESENT	0
467015	466047	14081Q	PARTICIPANT	\N	PRESENT	0
467016	466047	80013X	PARTICIPANT	\N	PRESENT	0
467017	466047	04045F	PARTICIPANT	\N	PRESENT	0
467018	466047	19631V	PARTICIPANT	\N	PRESENT	0
467019	466047	08068F	PARTICIPANT	\N	PRESENT	0
467020	466047	04049K	PARTICIPANT	\N	PRESENT	0
467021	466047	19705W	PARTICIPANT	\N	PRESENT	0
467022	466047	08015R	PARTICIPANT	\N	PRESENT	0
467023	466047	14197C	PARTICIPANT	\N	PRESENT	0
467024	466047	19369B	PARTICIPANT	\N	PRESENT	0
467025	466047	08028W	PARTICIPANT	\N	PRESENT	0
467026	466047	19563B	PARTICIPANT	\N	PRESENT	0
467027	466047	14265W	PARTICIPANT	\N	PRESENT	0
467028	466047	14329V	PARTICIPANT	\N	PRESENT	0
467029	466047	14135M	PARTICIPANT	\N	PRESENT	0
467030	466047	19467C	PARTICIPANT	\N	PRESENT	0
467031	466047	14187A	PARTICIPANT	\N	PRESENT	0
467032	466047	08038Y	PARTICIPANT	\N	PRESENT	0
467033	466047	19695N	PARTICIPANT	\N	PRESENT	0
467034	466047	11090Q	PRESIDENT	0	PRESENT	0
467035	466047	01025N	PARTICIPANT	\N	PRESENT	0
467036	466047	14205J	PARTICIPANT	\N	PRESENT	0
467037	466047	11101A	PARTICIPANT	\N	PRESENT	0
467038	466047	19507S	PARTICIPANT	\N	PRESENT	0
467039	466047	19747H	PARTICIPANT	\N	PRESENT	0
467040	466047	14257W	PARTICIPANT	\N	PRESENT	0
467041	466591	11085T	PARTICIPANT	\N	PRESENT	0
467042	466591	04008A	PARTICIPANT	\N	PRESENT	0
467043	466591	19762G	PARTICIPANT	\N	PRESENT	0
467044	466809	14039A	PARTICIPANT	\N	PRESENT	0
467045	466809	14249W	PARTICIPANT	\N	PRESENT	0
467046	466809	14109K	PARTICIPANT	\N	PRESENT	0
467047	466809	19593H	PARTICIPANT	\N	PRESENT	0
467048	466809	14107H	PARTICIPANT	\N	PRESENT	0
467049	466809	19758L	PARTICIPANT	\N	PRESENT	0
467050	466590	08039A	PARTICIPANT	\N	PRESENT	0
467051	466591	14259Y	PARTICIPANT	\N	PRESENT	0
467052	466047	14033T	PARTICIPANT	\N	PRESENT	0
467053	466591	10015M	PARTICIPANT	\N	PRESENT	0
467092	465835	14331P	PARTICIPANT	\N	PRESENT	0
456267	454197	08049C	PARTICIPANT	\N	EXCUSE	0
458320	458318	19503N	PARTICIPANT	\N	PRESENT	0
462343	462342	04040A	PARTICIPANT	\N	PRESENT	0
462359	458657	04040A	PRESIDENT	0	PRESENT	0
462377	458657	19489J	PARTICIPANT	\N	PRESENT	0
462378	458657	08010L	PARTICIPANT	\N	PRESENT	0
462379	458657	19820Y	PARTICIPANT	\N	PRESENT	0
462380	458657	17637T	PARTICIPANT	\N	PRESENT	0
462381	458657	19735D	PARTICIPANT	\N	PRESENT	0
462382	458657	95063L	PARTICIPANT	\N	PRESENT	0
462383	458657	14071N	PARTICIPANT	\N	PRESENT	0
463467	463427	19673G	PARTICIPANT	\N	PRESENT	0
463468	463427	05008E	PRESIDENT	0	PRESENT	0
463469	463427	14001X	PARTICIPANT	\N	PRESENT	0
463470	463427	19543W	PARTICIPANT	\N	PRESENT	0
463471	463427	04044E	PARTICIPANT	\N	PRESENT	0
463472	463427	04047H	PARTICIPANT	\N	PRESENT	0
463473	463427	19675J	PARTICIPANT	\N	PRESENT	0
463474	463427	01028R	PARTICIPANT	\N	PRESENT	0
463475	463427	14231L	PARTICIPANT	\N	PRESENT	0
463476	463427	19489J	PARTICIPANT	\N	PRESENT	0
463477	463427	14041T	PARTICIPANT	\N	PRESENT	0
463478	463427	14179A	PARTICIPANT	\N	PRESENT	0
463479	463427	14147R	PARTICIPANT	\N	PRESENT	0
463480	463427	14151M	PARTICIPANT	\N	PRESENT	0
463481	463427	14215L	PARTICIPANT	\N	PRESENT	0
463482	463427	14259Y	PARTICIPANT	\N	PRESENT	0
463483	463427	11072N	PARTICIPANT	\N	PRESENT	0
463484	463427	14065Q	PARTICIPANT	\N	PRESENT	0
463485	463427	19649G	PARTICIPANT	\N	PRESENT	0
463486	463427	10015M	PARTICIPANT	\N	PRESENT	0
463487	463427	11026G	PARTICIPANT	\N	PRESENT	0
463869	463387	04085P	PARTICIPANT	\N	PRESENT	0
463489	463427	01024M	PARTICIPANT	\N	PRESENT	0
463490	463427	11033F	PARTICIPANT	\N	PRESENT	0
463491	463427	19725B	PARTICIPANT	\N	PRESENT	0
463492	463427	19729F	PARTICIPANT	\N	PRESENT	0
463493	463427	95063L	PARTICIPANT	\N	PRESENT	0
463494	463427	08044W	PARTICIPANT	\N	PRESENT	0
463495	463427	04008A	PARTICIPANT	\N	PRESENT	0
463496	463427	19762G	PARTICIPANT	\N	PRESENT	0
463497	463427	14021P	PARTICIPANT	\N	PRESENT	0
463498	463427	11085T	PARTICIPANT	\N	EXCUSE	0
463499	463427	19581D	PARTICIPANT	\N	PRESENT	0
463500	463427	14053L	PARTICIPANT	\N	PRESENT	0
463501	463427	14111D	PARTICIPANT	\N	PRESENT	0
463502	463427	04038G	PARTICIPANT	\N	PRESENT	0
463503	463427	19719D	PARTICIPANT	\N	PRESENT	0
463504	463427	19629C	PARTICIPANT	\N	PRESENT	0
463505	463427	14069U	PARTICIPANT	\N	PRESENT	0
463506	463427	19253P	PARTICIPANT	\N	PRESENT	0
463868	463387	89017R	PARTICIPANT	\N	PRESENT	0
463870	463387	19651A	PARTICIPANT	\N	PRESENT	0
463871	463387	19667J	PARTICIPANT	\N	PRESENT	0
463872	463387	11053K	PARTICIPANT	\N	PRESENT	0
463873	463387	14085U	PARTICIPANT	\N	PRESENT	0
463874	463387	11031D	PARTICIPANT	\N	PRESENT	0
463875	463387	19812Y	PARTICIPANT	\N	PRESENT	0
463876	463387	04086Q	PARTICIPANT	\N	PRESENT	0
463877	463387	04071H	PARTICIPANT	\N	PRESENT	0
463878	463387	11074Q	PARTICIPANT	\N	PRESENT	0
463879	463387	19647E	PARTICIPANT	\N	PRESENT	0
463880	463387	14034U	PARTICIPANT	\N	PRESENT	0
463881	463387	04035D	PARTICIPANT	\N	PRESENT	0
463882	463387	19695N	PARTICIPANT	\N	PRESENT	0
463883	463387	19649G	PARTICIPANT	\N	PRESENT	0
463884	463387	19591F	PARTICIPANT	\N	PRESENT	0
463885	463387	14021P	PARTICIPANT	\N	PRESENT	0
463886	463387	19611R	PARTICIPANT	\N	PRESENT	0
463887	463387	86034E	PARTICIPANT	\N	PRESENT	0
463888	463387	19699S	PARTICIPANT	\N	PRESENT	0
463889	463387	12041X	PARTICIPANT	\N	PRESENT	0
463890	463387	11026G	PARTICIPANT	\N	PRESENT	0
463891	463387	08010L	PARTICIPANT	\N	PRESENT	0
463892	463387	08034U	PARTICIPANT	\N	PRESENT	0
463893	463387	19697Q	PARTICIPANT	\N	PRESENT	0
463894	463387	14251Q	PARTICIPANT	\N	PRESENT	0
463895	463387	11085T	PARTICIPANT	\N	PRESENT	0
463896	463387	19563B	PARTICIPANT	\N	PRESENT	0
463897	463387	14257W	PARTICIPANT	\N	PRESENT	0
463898	463387	08011M	PARTICIPANT	\N	PRESENT	0
463899	463387	14071N	PARTICIPANT	\N	PRESENT	0
463900	463387	19593H	PARTICIPANT	\N	PRESENT	0
463901	463387	08061X	PARTICIPANT	\N	PRESENT	0
463902	463387	04033B	PARTICIPANT	\N	PRESENT	0
463903	463387	19687N	PARTICIPANT	\N	PRESENT	0
463904	463387	01028R	PARTICIPANT	\N	PRESENT	0
463905	463387	19689Q	PARTICIPANT	\N	PRESENT	0
463906	463387	19669L	PARTICIPANT	\N	PRESENT	0
463907	463387	14157T	PARTICIPANT	\N	PRESENT	0
463908	463387	19585H	PARTICIPANT	\N	PRESENT	0
463909	463387	04034C	PARTICIPANT	\N	PRESENT	0
464588	464587	08009T	PRESIDENT	0	PRESENT	0
464589	464587	04085P	PARTICIPANT	\N	PRESENT	0
464590	464587	08055A	PARTICIPANT	\N	PRESENT	0
464591	464587	14093U	PARTICIPANT	\N	PRESENT	0
464592	464587	19549D	PARTICIPANT	\N	PRESENT	0
464593	464587	19383Y	PARTICIPANT	\N	PRESENT	0
464594	464587	19701S	PARTICIPANT	\N	PRESENT	0
464595	464587	14038Y	PARTICIPANT	\N	PRESENT	0
464596	464587	11065P	PARTICIPANT	\N	PRESENT	0
464597	464587	02002K	PARTICIPANT	\N	PRESENT	0
464598	464587	19820Y	PARTICIPANT	\N	PRESENT	0
464599	464587	19347U	PARTICIPANT	\N	PRESENT	0
464600	464587	19387D	PARTICIPANT	\N	PRESENT	0
464601	464587	19333N	PARTICIPANT	\N	PRESENT	0
464602	464587	19551W	PARTICIPANT	\N	PRESENT	0
464603	464587	14029X	PARTICIPANT	\N	PRESENT	0
464604	464587	14219Q	PARTICIPANT	\N	PRESENT	0
464605	464587	14221J	PARTICIPANT	\N	PRESENT	0
464606	464587	14031R	PARTICIPANT	\N	PRESENT	0
464607	464587	19637C	PARTICIPANT	\N	PRESENT	0
464608	464587	19826F	PARTICIPANT	\N	PRESENT	0
464609	464587	14237S	PARTICIPANT	\N	PRESENT	0
464610	464587	19503N	PARTICIPANT	\N	PRESENT	0
464611	464587	17583W	PARTICIPANT	\N	PRESENT	0
464612	464587	19713W	PARTICIPANT	\N	PRESENT	0
464613	464587	14169X	PARTICIPANT	\N	PRESENT	0
464614	464587	19739H	PARTICIPANT	\N	PRESENT	0
464615	464587	05012A	PARTICIPANT	\N	PRESENT	0
464616	464587	19794Q	PARTICIPANT	\N	PRESENT	0
464617	464587	14051J	PARTICIPANT	\N	PRESENT	0
464618	464587	14157T	PARTICIPANT	\N	PRESENT	0
464619	464587	19737F	PARTICIPANT	\N	PRESENT	0
464620	464587	18083K	PARTICIPANT	\N	PRESENT	0
465294	465293	98005N	PARTICIPANT	\N	PRESENT	0
465295	465293	19443T	PARTICIPANT	\N	PRESENT	0
465296	465293	04034C	PARTICIPANT	\N	PRESENT	0
465297	465293	14079W	PARTICIPANT	\N	PRESENT	0
465298	465293	01058X	PARTICIPANT	\N	PRESENT	0
465299	465293	04040A	PARTICIPANT	\N	PRESENT	0
465300	465293	16685X	PARTICIPANT	\N	PRESENT	0
465301	465293	11027H	PARTICIPANT	\N	PRESENT	0
465302	465293	04042C	PRESIDENT	0	PRESENT	0
465303	465293	11054L	PARTICIPANT	\N	PRESENT	0
465304	465293	11066Q	PARTICIPANT	\N	PRESENT	0
465305	465293	08056B	PARTICIPANT	\N	PRESENT	0
465306	465293	19421M	PARTICIPANT	\N	PRESENT	0
465307	465293	19709B	PARTICIPANT	\N	PRESENT	0
465308	465293	14193X	PARTICIPANT	\N	PRESENT	0
465309	465293	08049C	PARTICIPANT	\N	PRESENT	0
465310	465293	97011G	PARTICIPANT	\N	PRESENT	0
465311	465293	08047A	PARTICIPANT	\N	PRESENT	0
465312	465293	98029W	PARTICIPANT	\N	PRESENT	0
465313	465293	14097Y	PARTICIPANT	\N	PRESENT	0
465314	465293	04035D	PARTICIPANT	\N	PRESENT	0
465315	465293	95067Q	PARTICIPANT	\N	PRESENT	0
465316	465293	14133K	PARTICIPANT	\N	PRESENT	0
465317	465293	01062T	PARTICIPANT	\N	PRESENT	0
465318	465293	11041F	PARTICIPANT	\N	PRESENT	0
465319	465293	14235Q	PARTICIPANT	\N	PRESENT	0
465320	465293	08058D	PARTICIPANT	\N	PRESENT	0
465321	465293	19251M	PARTICIPANT	\N	PRESENT	0
465322	465293	14105F	PARTICIPANT	\N	PRESENT	0
465323	465293	98018T	PARTICIPANT	\N	PRESENT	0
465324	465293	98022P	PARTICIPANT	\N	PRESENT	0
465325	465293	14267Y	PARTICIPANT	\N	PRESENT	0
465326	465293	11064N	PARTICIPANT	\N	PRESENT	0
470035	466411	19577H	PARTICIPANT	\N	PRESENT	0
470036	466411	19657G	PARTICIPANT	\N	PRESENT	0
470037	466411	12016W	PARTICIPANT	\N	EXCUSE	0
470038	466411	11054L	PARTICIPANT	\N	EXCUSE	0
470039	466583	08019V	PARTICIPANT	\N	PRESENT	0
470040	466583	19301E	PARTICIPANT	\N	PRESENT	0
470041	466583	19691J	PARTICIPANT	\N	PRESENT	0
470042	466411	14030Q	PARTICIPANT	\N	PRESENT	0
470043	466583	19717B	PARTICIPANT	\N	PRESENT	0
470044	466583	11109J	PARTICIPANT	\N	PRESENT	0
470045	466411	14251Q	PARTICIPANT	\N	PRESENT	0
470046	466411	08017T	PARTICIPANT	\N	PRESENT	0
470047	466411	08024S	PARTICIPANT	\N	PRESENT	0
470048	466411	18083K	PARTICIPANT	\N	PRESENT	0
470049	466411	11031D	PARTICIPANT	\N	PRESENT	0
470050	466411	19621T	PARTICIPANT	\N	PRESENT	0
470051	466411	11067R	PARTICIPANT	\N	PRESENT	0
470052	466411	19269X	PARTICIPANT	\N	PRESENT	0
470053	466411	11045K	PARTICIPANT	\N	PRESENT	0
470054	466411	80013X	PARTICIPANT	\N	PRESENT	0
470055	466411	19679N	PARTICIPANT	\N	PRESENT	0
470056	466411	14179A	PARTICIPANT	\N	PRESENT	0
470080	468967	19741B	PARTICIPANT	\N	PRESENT	0
470081	468967	19667J	PARTICIPANT	\N	PRESENT	0
470082	468967	96004D	PARTICIPANT	\N	PRESENT	0
470083	468967	14083S	PARTICIPANT	\N	PRESENT	0
470084	468967	11053K	PARTICIPANT	\N	PRESENT	0
470085	468967	14085U	PARTICIPANT	\N	PRESENT	0
470086	468967	88008L	PARTICIPANT	\N	PRESENT	0
470087	468967	04086Q	PARTICIPANT	\N	PRESENT	0
470088	468967	11070L	PARTICIPANT	\N	PRESENT	0
470089	468967	04071H	PARTICIPANT	\N	PRESENT	0
470090	468967	11074Q	PRESIDENT	0	PRESENT	0
470091	468967	11110B	PARTICIPANT	\N	PRESENT	0
470092	468967	19647E	PARTICIPANT	\N	PRESENT	0
470093	468967	14034U	PARTICIPANT	\N	PRESENT	0
470094	468967	07004J	PARTICIPANT	\N	PRESENT	0
470095	468967	01057W	PARTICIPANT	\N	PRESENT	0
470096	468967	11048N	PARTICIPANT	\N	PRESENT	0
470097	468967	14121F	PARTICIPANT	\N	PRESENT	0
470098	468967	99004R	PARTICIPANT	\N	PRESENT	0
470099	468967	19711U	PARTICIPANT	\N	PRESENT	0
470100	468967	08034U	PARTICIPANT	\N	PRESENT	0
470101	468967	19671E	PARTICIPANT	\N	PRESENT	0
470102	468967	08011M	PARTICIPANT	\N	PRESENT	0
470103	468967	14253S	PARTICIPANT	\N	PRESENT	0
470104	468967	19349W	PARTICIPANT	\N	PRESENT	0
470105	468967	14331P	PARTICIPANT	\N	PRESENT	0
470106	468967	14225N	PARTICIPANT	\N	PRESENT	0
470107	468967	11012A	PARTICIPANT	\N	EXCUSE	0
470108	468967	19687N	PARTICIPANT	\N	PRESENT	0
470109	468967	19689Q	PARTICIPANT	\N	PRESENT	0
470110	468967	19479G	PARTICIPANT	\N	PRESENT	0
470111	468967	14173T	PARTICIPANT	\N	PRESENT	0
470120	470115	04070G	PRESIDENT	0	PRESENT	0
470121	470115	08039A	PRESIDENT	1	PRESENT	0
470122	470115	11104D	PARTICIPANT	\N	PRESENT	0
470123	470115	11043H	PARTICIPANT	\N	PRESENT	0
470124	470115	19643A	PARTICIPANT	\N	PRESENT	0
470125	470115	19573D	PARTICIPANT	\N	PRESENT	0
470126	470115	19533U	PARTICIPANT	\N	PRESENT	0
470127	470115	19749K	PARTICIPANT	\N	PRESENT	0
470128	470115	14229S	PARTICIPANT	\N	PRESENT	0
470129	470115	14241N	PARTICIPANT	\N	PRESENT	0
470130	470115	14039A	PARTICIPANT	\N	PRESENT	0
470131	470115	19593H	PARTICIPANT	\N	PRESENT	0
470132	470115	04057K	PARTICIPANT	\N	PRESENT	0
470133	470115	19693L	PARTICIPANT	\N	PRESENT	0
470134	470115	19731Y	PARTICIPANT	\N	PRESENT	0
470135	470115	19611R	PARTICIPANT	\N	PRESENT	0
470136	470115	08035V	PARTICIPANT	\N	PRESENT	0
470137	470115	87003B	PARTICIPANT	\N	PRESENT	0
470138	470115	19399H	PARTICIPANT	\N	PRESENT	0
470139	470115	08020N	PARTICIPANT	\N	PRESENT	0
470140	470115	11109J	PARTICIPANT	\N	PRESENT	0
470141	470115	19699S	PARTICIPANT	\N	PRESENT	0
470142	470115	14249W	PARTICIPANT	\N	PRESENT	0
470143	470115	14059S	PARTICIPANT	\N	PRESENT	0
470144	470115	07033P	PARTICIPANT	\N	PRESENT	0
470145	470115	14123H	PARTICIPANT	\N	PRESENT	0
470146	470115	19621T	PARTICIPANT	\N	EXCUSE	0
470150	468967	01048V	PARTICIPANT	\N	PRESENT	0
470152	466583	19367Y	PARTICIPANT	\N	EXCUSE	0
470389	469053	01048V	PRESIDENT	0	PRESENT	0
470390	469053	14093U	PARTICIPANT	\N	PRESENT	0
470391	469053	80013X	PARTICIPANT	\N	PRESENT	0
470392	469053	19693L	PARTICIPANT	\N	PRESENT	0
470393	469053	19663E	PARTICIPANT	\N	PRESENT	0
470394	469053	19723Y	PARTICIPANT	\N	PRESENT	0
470395	469053	14221J	PARTICIPANT	\N	PRESENT	0
470396	469053	19593H	PARTICIPANT	\N	PRESENT	0
470397	469053	19533U	PARTICIPANT	\N	PRESENT	0
470398	469053	04043D	PARTICIPANT	\N	PRESENT	0
470399	469053	01058X	PARTICIPANT	\N	PRESENT	0
470515	468972	11109J	PARTICIPANT	\N	PRESENT	0
470516	468972	14261S	PARTICIPANT	\N	PRESENT	0
470517	468972	19717B	PARTICIPANT	\N	PRESENT	0
470518	468972	19631V	PARTICIPANT	\N	PRESENT	0
470519	468972	19295A	PARTICIPANT	\N	PRESENT	0
470520	468972	19577H	PARTICIPANT	\N	PRESENT	0
470521	468972	19691J	PARTICIPANT	\N	PRESENT	0
470522	468972	19715Y	PARTICIPANT	\N	PRESENT	0
470523	468972	14097Y	PARTICIPANT	\N	PRESENT	0
470524	468972	14039A	PARTICIPANT	\N	PRESENT	0
470525	468972	98005N	PARTICIPANT	\N	PRESENT	0
470526	468972	14219Q	PARTICIPANT	\N	PRESENT	0
470527	468972	14059S	PARTICIPANT	\N	PRESENT	0
470528	468972	19657G	PARTICIPANT	\N	PRESENT	0
470529	468972	14157T	PARTICIPANT	\N	PRESENT	0
470533	466641	04059M	PARTICIPANT	\N	PRESENT	0
470534	466641	11083R	PARTICIPANT	\N	PRESENT	0
470535	466641	19399H	PARTICIPANT	\N	PRESENT	0
470536	466641	04070G	PARTICIPANT	\N	PRESENT	0
470537	466641	08039A	PARTICIPANT	\N	PRESENT	0
470539	470538	08039A	PARTICIPANT	\N	PRESENT	0
470540	470538	04059M	PARTICIPANT	\N	PRESENT	0
470541	470538	11083R	PARTICIPANT	\N	PRESENT	0
470542	470538	19399H	PARTICIPANT	\N	PRESENT	0
470990	470986	14097Y	PARTICIPANT	\N	PRESENT	0
470991	470986	19611R	PARTICIPANT	\N	PRESENT	0
470992	470986	19723Y	PARTICIPANT	\N	PRESENT	0
470993	470986	19549D	PARTICIPANT	\N	PRESENT	0
470994	470986	19629C	PARTICIPANT	\N	PRESENT	0
470995	470986	19369B	PARTICIPANT	\N	PRESENT	0
470996	470986	19591F	PARTICIPANT	\N	PRESENT	0
470997	470985	14097Y	PARTICIPANT	\N	PRESENT	0
470998	470985	19611R	PARTICIPANT	\N	PRESENT	0
470999	470985	19549D	PARTICIPANT	\N	PRESENT	0
471000	470985	19629C	PARTICIPANT	\N	PRESENT	0
471002	471001	14259Y	PARTICIPANT	\N	PRESENT	0
471073	469558	14041T	PARTICIPANT	\N	PRESENT	0
471072	469558	04049K	PRESIDENT	0	PRESENT	0
471074	469558	14087W	PARTICIPANT	\N	PRESENT	0
471075	469558	14205J	PARTICIPANT	\N	PRESENT	0
471076	469558	19575F	PARTICIPANT	\N	EXCUSE	0
471077	469558	14053L	PARTICIPANT	\N	EXCUSE	0
471078	469558	19545Y	PARTICIPANT	\N	EXCUSE	0
471079	469558	14034U	PARTICIPANT	\N	EXCUSE	0
471080	469558	16685X	PARTICIPANT	\N	EXCUSE	0
471081	469558	08047A	PARTICIPANT	\N	EXCUSE	0
471083	471082	14042U	PARTICIPANT	\N	PRESENT	0
471176	469637	10006L	PARTICIPANT	\N	PRESENT	0
471177	469637	11031D	PARTICIPANT	\N	PRESENT	0
471178	469637	19723Y	PARTICIPANT	\N	PRESENT	0
471179	469637	19798U	PARTICIPANT	\N	PRESENT	0
471180	469637	19697Q	PARTICIPANT	\N	PRESENT	0
471181	469637	19657G	PARTICIPANT	\N	PRESENT	0
471182	469637	19575F	PARTICIPANT	\N	PRESENT	0
471183	469639	10006L	PARTICIPANT	\N	PRESENT	0
471184	469639	19697Q	PARTICIPANT	\N	PRESENT	0
471207	469639	19798U	PARTICIPANT	\N	PRESENT	0
471517	471516	11031D	PARTICIPANT	\N	PRESENT	0
471518	471516	14042U	PARTICIPANT	\N	PRESENT	0
471688	471686	04070G	PRESIDENT	0	PRESENT	0
471689	469127	14169X	PARTICIPANT	\N	PRESENT	0
471690	469127	17637T	PARTICIPANT	\N	PRESENT	0
471691	469127	08060W	PARTICIPANT	\N	PRESENT	0
471692	469127	08024S	PARTICIPANT	\N	PRESENT	0
471693	469127	14221J	PARTICIPANT	\N	PRESENT	0
471694	469127	19745F	PARTICIPANT	\N	PRESENT	0
471695	469127	19599P	PARTICIPANT	\N	PRESENT	0
471696	471686	19533U	PARTICIPANT	\N	PRESENT	0
471697	471686	04018C	PARTICIPANT	\N	PRESENT	0
471698	471686	14030Q	PARTICIPANT	\N	PRESENT	0
454723	454721	11097X	PARTICIPANT	\N	PRESENT	0
454725	454724	11097X	PARTICIPANT	\N	PRESENT	0
454726	454724	01034P	PARTICIPANT	\N	PRESENT	0
454728	454727	11097X	PARTICIPANT	\N	PRESENT	0
454729	454727	01034P	PARTICIPANT	\N	PRESENT	0
454730	454727	04092N	PARTICIPANT	\N	PRESENT	0
454731	454727	19760E	PARTICIPANT	\N	PRESENT	0
454732	454727	14217N	PARTICIPANT	\N	PRESENT	0
454734	454733	19760E	PARTICIPANT	\N	PRESENT	0
454736	454733	14217N	PARTICIPANT	\N	PRESENT	0
454737	454733	04092N	PARTICIPANT	\N	PRESENT	0
454739	454733	11097X	PARTICIPANT	\N	PRESENT	0
454740	454733	01034P	PARTICIPANT	\N	PRESENT	0
454820	453990	14030Q	PRESIDENT	0	PRESENT	0
454821	453990	08043V	PARTICIPANT	\N	PRESENT	0
454822	453990	08024S	PARTICIPANT	\N	PRESENT	0
454823	453990	11031D	PARTICIPANT	\N	PRESENT	0
454824	453990	19693L	PARTICIPANT	\N	PRESENT	0
454825	453990	14249W	PARTICIPANT	\N	PRESENT	0
454826	453990	19599P	PARTICIPANT	\N	PRESENT	0
454827	453990	14179A	PARTICIPANT	\N	PRESENT	0
454828	453990	19731Y	PARTICIPANT	\N	PRESENT	0
454830	453990	08031R	PARTICIPANT	\N	PRESENT	0
454831	453990	11067R	PARTICIPANT	\N	PRESENT	0
454833	453990	19749K	PARTICIPANT	\N	PRESENT	0
459584	448770	19415P	PARTICIPANT	\N	PRESENT	0
459585	448770	08010L	PARTICIPANT	\N	PRESENT	0
459586	448770	19826F	PARTICIPANT	\N	PRESENT	0
459587	448770	19745F	PARTICIPANT	\N	PRESENT	0
459591	448770	19551W	PARTICIPANT	\N	PRESENT	0
459592	448770	19675J	PARTICIPANT	\N	PRESENT	0
459594	448770	88008L	PARTICIPANT	\N	PRESENT	0
459597	448770	14213J	PARTICIPANT	\N	PRESENT	0
459598	448770	19581D	PARTICIPANT	\N	PRESENT	0
459599	448770	14259Y	PARTICIPANT	\N	PRESENT	0
459600	448770	14034U	PARTICIPANT	\N	PRESENT	0
459606	448770	14083S	PARTICIPANT	\N	PRESENT	0
459616	448770	14119M	PARTICIPANT	\N	PRESENT	0
459617	448770	19269X	PARTICIPANT	\N	PRESENT	0
459622	448770	19735D	PARTICIPANT	\N	PRESENT	0
459627	448770	01062T	PARTICIPANT	\N	PRESENT	0
459631	448770	17637T	PARTICIPANT	\N	PRESENT	0
459632	448770	14031R	PARTICIPANT	\N	PRESENT	0
459641	448770	19479G	PARTICIPANT	\N	PRESENT	0
459642	448770	95041E	PARTICIPANT	\N	PRESENT	0
459649	448770	17583W	PARTICIPANT	\N	PRESENT	0
459652	448770	11053K	PARTICIPANT	\N	PRESENT	0
459661	448770	95067Q	PARTICIPANT	\N	PRESENT	0
459657	448770	05012A	PARTICIPANT	\N	PRESENT	0
459658	448770	14159V	PARTICIPANT	\N	PRESENT	0
459662	448770	04018C	PARTICIPANT	\N	PRESENT	0
459663	448770	14193X	PARTICIPANT	\N	PRESENT	0
459947	457403	11070L	PARTICIPANT	\N	PRESENT	0
459665	448770	14179A	PARTICIPANT	\N	PRESENT	0
459666	448770	19762G	PARTICIPANT	\N	PRESENT	0
459948	457403	14042U	PARTICIPANT	\N	PRESENT	0
459949	457403	04038G	PARTICIPANT	\N	PRESENT	0
459950	457403	11031D	PARTICIPANT	\N	PRESENT	0
459951	457403	19565D	PARTICIPANT	\N	PRESENT	0
459952	457403	19649G	PARTICIPANT	\N	PRESENT	0
459953	457403	14227Q	PARTICIPANT	\N	PRESENT	0
459954	457403	14229S	PARTICIPANT	\N	PRESENT	0
459955	457403	19820Y	PARTICIPANT	\N	PRESENT	0
459956	457403	14065Q	PARTICIPANT	\N	PRESENT	0
459957	457403	19489J	PARTICIPANT	\N	PRESENT	0
459958	457403	14151M	PARTICIPANT	\N	PRESENT	0
459959	457403	11067R	PARTICIPANT	\N	PRESENT	0
459960	457403	19725B	PARTICIPANT	\N	PRESENT	0
459961	457403	01028R	PARTICIPANT	\N	PRESENT	0
459962	457403	11110B	PARTICIPANT	\N	PRESENT	0
459963	457403	11026G	PARTICIPANT	\N	PRESENT	0
459964	457403	19782L	PARTICIPANT	\N	PRESENT	0
459965	457403	08024S	PARTICIPANT	\N	PRESENT	0
459966	457403	14207L	PARTICIPANT	\N	PRESENT	0
459967	457403	19637C	PARTICIPANT	\N	PRESENT	0
459968	457403	19697Q	PARTICIPANT	\N	PRESENT	0
459969	457403	19812Y	PARTICIPANT	\N	PRESENT	0
459970	457403	19349W	PARTICIPANT	\N	PRESENT	0
459971	457403	19651A	PARTICIPANT	\N	PRESENT	0
459972	457403	98029W	PARTICIPANT	\N	PRESENT	0
459973	457403	88008L	PARTICIPANT	\N	PRESENT	0
459974	457403	11012A	PARTICIPANT	\N	PRESENT	0
459975	457403	14179A	PARTICIPANT	\N	PRESENT	0
459976	457403	19691J	PARTICIPANT	\N	PRESENT	0
459977	457403	19737F	PARTICIPANT	\N	PRESENT	0
459978	457403	14205J	PARTICIPANT	\N	PRESENT	0
459979	457403	01034P	PARTICIPANT	\N	PRESENT	0
459980	457403	19479G	PARTICIPANT	\N	PRESENT	0
459981	457403	19717B	PARTICIPANT	\N	PRESENT	0
459982	457403	19563B	PARTICIPANT	\N	PRESENT	0
459983	457403	17589D	PARTICIPANT	\N	PRESENT	0
459984	457403	19585H	PARTICIPANT	\N	PRESENT	0
459985	457403	04057K	PARTICIPANT	\N	PRESENT	0
459986	457403	14107H	PARTICIPANT	\N	PRESENT	0
459987	457403	98022P	PARTICIPANT	\N	PRESENT	0
459988	457403	14241N	PARTICIPANT	\N	PRESENT	0
459989	457403	04059M	PARTICIPANT	\N	PRESENT	0
459990	457403	11109J	PARTICIPANT	\N	PRESENT	0
459991	457403	14030Q	PARTICIPANT	\N	PRESENT	0
459992	457403	01024M	PARTICIPANT	\N	PRESENT	0
459993	457403	19569H	PARTICIPANT	\N	PRESENT	0
459994	457403	14089Y	PARTICIPANT	\N	PRESENT	0
459995	457403	19685L	PARTICIPANT	\N	PRESENT	0
459996	457403	19367Y	PARTICIPANT	\N	PRESENT	0
459997	457403	19679N	PARTICIPANT	\N	PRESENT	0
459998	457403	04018C	PARTICIPANT	\N	PRESENT	0
459999	457403	19798U	PARTICIPANT	\N	PRESENT	0
460000	457403	04097T	PARTICIPANT	\N	PRESENT	0
460001	457403	10006L	PARTICIPANT	\N	PRESENT	0
460002	457403	15447F	PARTICIPANT	\N	PRESENT	0
460003	457403	19533U	PARTICIPANT	\N	PRESENT	0
460004	457403	19383Y	PARTICIPANT	\N	PRESENT	0
460005	457403	14191V	PARTICIPANT	\N	PRESENT	0
460006	457403	19762G	PARTICIPANT	\N	PRESENT	0
460007	457403	19573D	PARTICIPANT	\N	PRESENT	0
460008	457403	97011G	PARTICIPANT	\N	PRESENT	0
460009	457403	19447X	PARTICIPANT	\N	PRESENT	0
460010	457403	19723Y	PARTICIPANT	\N	PRESENT	0
460011	457403	14329V	PARTICIPANT	\N	PRESENT	0
460012	457403	14147R	PARTICIPANT	\N	PRESENT	0
460013	457403	14029X	PARTICIPANT	\N	PRESENT	0
460014	457403	14265W	PARTICIPANT	\N	PRESENT	0
460015	457403	19507S	PARTICIPANT	\N	PRESENT	0
460016	457403	14213J	PARTICIPANT	\N	PRESENT	0
460017	457403	04088S	PARTICIPANT	\N	PRESENT	0
460018	457403	04049K	PARTICIPANT	\N	PRESENT	0
460019	457403	19415P	PARTICIPANT	\N	PRESENT	0
460020	457403	95067Q	PARTICIPANT	\N	PRESENT	0
460021	457403	18083K	PARTICIPANT	\N	PRESENT	0
460022	457403	11043H	PARTICIPANT	\N	PRESENT	0
460023	457403	19399H	PARTICIPANT	\N	PRESENT	0
460024	457403	19693L	PARTICIPANT	\N	PRESENT	0
460025	457403	14215L	PARTICIPANT	\N	PRESENT	0
460026	457403	08061X	PARTICIPANT	\N	PRESENT	0
460027	457403	19295A	PARTICIPANT	\N	PRESENT	0
460028	457403	19581D	PARTICIPANT	\N	PRESENT	0
460029	457403	19699S	PARTICIPANT	\N	PRESENT	0
460030	457403	14034U	PARTICIPANT	\N	PRESENT	0
460031	457403	19631V	PARTICIPANT	\N	PRESENT	0
460032	457403	19629C	PARTICIPANT	\N	PRESENT	0
460033	457403	19387D	PARTICIPANT	\N	PRESENT	0
460034	457403	14109K	PARTICIPANT	\N	PRESENT	0
460035	457403	14115H	PARTICIPANT	\N	PRESENT	0
460036	457403	19575F	PARTICIPANT	\N	PRESENT	0
460037	457403	14217N	PARTICIPANT	\N	PRESENT	0
460038	457403	19729F	PARTICIPANT	\N	PRESENT	0
460039	457403	19826F	PARTICIPANT	\N	PRESENT	0
460040	457403	14026U	PARTICIPANT	\N	PRESENT	0
460041	457403	14219Q	PARTICIPANT	\N	PRESENT	0
460042	457403	14275Y	PARTICIPANT	\N	PRESENT	0
460043	457403	98024R	PARTICIPANT	\N	PRESENT	0
460044	457403	14331P	PARTICIPANT	\N	PRESENT	0
460045	457403	14231L	PARTICIPANT	\N	PRESENT	0
460046	457403	14073Q	PARTICIPANT	\N	PRESENT	0
460047	457403	14069U	PARTICIPANT	\N	PRESENT	0
460049	457403	14211G	PARTICIPANT	\N	PRESENT	0
460051	457403	08015R	PARTICIPANT	\N	PRESENT	0
460052	457403	14119M	PARTICIPANT	\N	PRESENT	0
460053	457403	19335Q	PARTICIPANT	\N	PRESENT	0
460055	458888	14237S	PARTICIPANT	\N	PRESENT	0
460056	458888	14097Y	PARTICIPANT	\N	PRESENT	0
460057	458888	19611R	PRESIDENT	0	PRESENT	0
460058	458888	14031R	PARTICIPANT	\N	PRESENT	0
460059	458888	14079W	PARTICIPANT	\N	PRESENT	0
460060	458888	14197C	PARTICIPANT	\N	PRESENT	0
460061	458888	14033T	PARTICIPANT	\N	PRESENT	0
460062	457403	04085P	PARTICIPANT	\N	PRESENT	0
460063	459118	08056B	PARTICIPANT	\N	PRESENT	0
460064	459118	07004J	PARTICIPANT	\N	PRESENT	0
467093	465835	01048V	PARTICIPANT	\N	PRESENT	0
467094	465835	19545Y	PARTICIPANT	\N	PRESENT	0
467095	465835	01057W	PARTICIPANT	\N	PRESENT	0
467096	465835	11053K	PARTICIPANT	\N	PRESENT	0
467097	465835	11074Q	PRESIDENT	0	PRESENT	0
467098	465835	19667J	PARTICIPANT	\N	PRESENT	0
467099	465835	89017R	PARTICIPANT	\N	PRESENT	0
467100	465835	19671E	PARTICIPANT	\N	PRESENT	0
467101	465835	88008L	PARTICIPANT	\N	PRESENT	0
467102	465835	14225N	PARTICIPANT	\N	PRESENT	0
467103	465835	14085U	PARTICIPANT	\N	PRESENT	0
467104	465835	96004D	PARTICIPANT	\N	PRESENT	0
467105	465835	19349W	PARTICIPANT	\N	PRESENT	0
467106	465835	11048N	PARTICIPANT	\N	PRESENT	0
467107	465835	19479G	PARTICIPANT	\N	PRESENT	0
467108	465835	19711U	PARTICIPANT	\N	PRESENT	0
467109	465835	19651A	PARTICIPANT	\N	PRESENT	0
467110	465835	19531S	PARTICIPANT	\N	PRESENT	0
467111	465835	08069G	PARTICIPANT	\N	PRESENT	0
467112	465835	19687N	PARTICIPANT	\N	PRESENT	0
467113	465835	08011M	PARTICIPANT	\N	PRESENT	0
467114	465835	14034U	PARTICIPANT	\N	PRESENT	0
467115	465835	04086Q	PARTICIPANT	\N	PRESENT	0
467116	465835	11040E	PARTICIPANT	\N	PRESENT	0
467117	465835	14083S	PARTICIPANT	\N	PRESENT	0
467118	465835	14121F	PARTICIPANT	\N	PRESENT	0
467119	465835	19741B	PARTICIPANT	\N	PRESENT	0
467120	465835	99004R	PARTICIPANT	\N	PRESENT	0
467121	465835	07029T	PARTICIPANT	\N	EXCUSE	0
467122	465835	11012A	PARTICIPANT	\N	EXCUSE	0
467134	463733	86034E	PARTICIPANT	\N	PRESENT	0
467135	463733	14089Y	PARTICIPANT	\N	PRESENT	0
467136	463733	14281W	PARTICIPANT	\N	PRESENT	0
467137	463733	19647E	PARTICIPANT	\N	PRESENT	0
467138	463733	95063L	PARTICIPANT	\N	PRESENT	0
467139	463733	07033P	PARTICIPANT	\N	PRESENT	0
467140	463733	19687N	PARTICIPANT	\N	PRESENT	0
467141	463733	04040A	PARTICIPANT	\N	PRESENT	0
467142	463733	11065P	PARTICIPANT	\N	PRESENT	0
467143	463733	04057K	PARTICIPANT	\N	PRESENT	0
467144	463733	14251Q	PARTICIPANT	\N	PRESENT	0
467145	463733	11053K	PARTICIPANT	\N	PRESENT	0
467146	463733	04086Q	PARTICIPANT	\N	PRESENT	0
467147	463733	19697Q	PARTICIPANT	\N	PRESENT	0
467148	463733	08061X	PARTICIPANT	\N	PRESENT	0
467149	463733	11085T	PARTICIPANT	\N	PRESENT	0
467150	463733	19533U	PARTICIPANT	\N	PRESENT	0
467151	463733	89017R	PARTICIPANT	\N	PRESENT	0
467152	463733	19591F	PARTICIPANT	\N	PRESENT	0
467153	463733	11072N	PARTICIPANT	\N	PRESENT	0
467154	463733	01043Q	PARTICIPANT	\N	PRESENT	0
467155	463733	04033B	PARTICIPANT	\N	PRESENT	0
467193	467059	19575F	PARTICIPANT	\N	PRESENT	0
467157	466137	08055A	PARTICIPANT	\N	PRESENT	0
467158	466137	19549D	PARTICIPANT	\N	PRESENT	0
467159	466137	08060W	PARTICIPANT	\N	PRESENT	0
467160	466137	19383Y	PARTICIPANT	\N	PRESENT	0
467161	466137	08024S	PARTICIPANT	\N	PRESENT	0
467162	466137	14038Y	PARTICIPANT	\N	PRESENT	0
467163	466137	18083K	PARTICIPANT	\N	PRESENT	0
467164	466137	19701S	PARTICIPANT	\N	PRESENT	0
467165	466137	11065P	PARTICIPANT	\N	PRESENT	0
467166	466137	19599P	PARTICIPANT	\N	PRESENT	0
467167	466137	02002K	PARTICIPANT	\N	PRESENT	0
467168	466137	19820Y	PARTICIPANT	\N	PRESENT	0
467169	466137	19387D	PARTICIPANT	\N	PRESENT	0
467170	466137	19347U	PARTICIPANT	\N	PRESENT	0
467171	466137	19333N	PARTICIPANT	\N	PRESENT	0
467172	466137	04097T	PARTICIPANT	\N	PRESENT	0
467173	466137	19289C	PARTICIPANT	\N	PRESENT	0
467174	466137	14219Q	PARTICIPANT	\N	PRESENT	0
467175	466137	14103D	PARTICIPANT	\N	PRESENT	0
467176	466137	14031R	PARTICIPANT	\N	PRESENT	0
467177	466137	19637C	PARTICIPANT	\N	PRESENT	0
467178	466137	14221J	PARTICIPANT	\N	PRESENT	0
467179	466137	14169X	PARTICIPANT	\N	PRESENT	0
467180	466137	14237S	PARTICIPANT	\N	PRESENT	0
467181	466137	17637T	PARTICIPANT	\N	PRESENT	0
467182	466137	19745F	PARTICIPANT	\N	PRESENT	0
467183	466137	19503N	PARTICIPANT	\N	PRESENT	0
467184	466137	19739H	PARTICIPANT	\N	PRESENT	0
467185	466137	17583W	PARTICIPANT	\N	PRESENT	0
467186	466137	19794Q	PARTICIPANT	\N	PRESENT	0
467187	466137	19713W	PARTICIPANT	\N	PRESENT	0
467188	466137	14051J	PARTICIPANT	\N	PRESENT	0
467189	466137	14157T	PARTICIPANT	\N	PRESENT	0
467190	466137	19737F	PARTICIPANT	\N	PRESENT	0
467191	466137	08009T	PRESIDENT	0	PRESENT	0
467192	463733	04085P	PARTICIPANT	\N	PRESENT	0
467194	467059	10006L	PARTICIPANT	\N	PRESENT	0
467195	467059	19723Y	PARTICIPANT	\N	PRESENT	0
467196	467059	19697Q	PARTICIPANT	\N	PRESENT	0
467197	467059	11097X	PARTICIPANT	\N	PRESENT	0
467198	467059	19691J	PARTICIPANT	\N	PRESENT	0
467199	467060	19575F	PARTICIPANT	\N	PRESENT	0
467200	467060	10006L	PARTICIPANT	\N	PRESENT	0
467201	467060	19691J	PARTICIPANT	\N	PRESENT	0
467202	467060	19553Y	PARTICIPANT	\N	PRESENT	0
467203	467060	19723Y	PARTICIPANT	\N	PRESENT	0
467204	467060	19697Q	PARTICIPANT	\N	PRESENT	0
467205	467060	19657G	PARTICIPANT	\N	PRESENT	0
467206	467060	11045K	PARTICIPANT	\N	PRESENT	0
467207	467060	11097X	PARTICIPANT	\N	PRESENT	0
467208	467060	19703U	PARTICIPANT	\N	PRESENT	0
467210	467209	19575F	PARTICIPANT	\N	PRESENT	0
467211	467209	10006L	PARTICIPANT	\N	PRESENT	0
467212	467209	14217N	PARTICIPANT	\N	PRESENT	0
467213	467209	19553Y	PARTICIPANT	\N	PRESENT	0
467214	467209	19723Y	PARTICIPANT	\N	PRESENT	0
467215	467209	11067R	PARTICIPANT	\N	PRESENT	0
467216	467209	19657G	PARTICIPANT	\N	PRESENT	0
467217	467209	19703U	PARTICIPANT	\N	PRESENT	0
467218	467209	11097X	PARTICIPANT	\N	PRESENT	0
467227	467226	04070G	PRESIDENT	0	PRESENT	0
467228	467226	08039A	PARTICIPANT	\N	PRESENT	0
467229	467226	19533U	PARTICIPANT	\N	PRESENT	0
467230	467226	14229S	PARTICIPANT	\N	PRESENT	0
467231	467226	08031R	PARTICIPANT	\N	PRESENT	0
467232	467226	11083R	PARTICIPANT	\N	PRESENT	0
467233	467226	19593H	PARTICIPANT	\N	PRESENT	0
467234	467226	04018C	PARTICIPANT	\N	PRESENT	0
467235	467226	14030Q	PARTICIPANT	\N	PRESENT	0
467236	467226	19335Q	PARTICIPANT	\N	PRESENT	0
467237	467226	19643A	PARTICIPANT	\N	PRESENT	0
467238	467226	19758L	PARTICIPANT	\N	PRESENT	0
467239	467226	14073Q	PARTICIPANT	\N	PRESENT	0
467240	467226	19731Y	PARTICIPANT	\N	PRESENT	0
467241	467226	08017T	PARTICIPANT	\N	PRESENT	0
467242	467226	19766L	PARTICIPANT	\N	PRESENT	0
467243	467226	19749K	PARTICIPANT	\N	PRESENT	0
467244	467226	19399H	PARTICIPANT	\N	PRESENT	0
467245	467226	11104D	PARTICIPANT	\N	PRESENT	0
467246	467226	14123H	PARTICIPANT	\N	PRESENT	0
467247	467226	14107H	PARTICIPANT	\N	PRESENT	0
467248	467226	19611R	PARTICIPANT	\N	PRESENT	0
467249	467226	14109K	PARTICIPANT	\N	PRESENT	0
467250	467226	19621T	PARTICIPANT	\N	PRESENT	0
467251	467226	19699S	PARTICIPANT	\N	PRESENT	0
467252	467226	14241N	PARTICIPANT	\N	PRESENT	0
467253	467226	14249W	PARTICIPANT	\N	PRESENT	0
467254	467226	19735D	PARTICIPANT	\N	PRESENT	0
467255	467226	19573D	PARTICIPANT	\N	PRESENT	0
467256	467226	08020N	PARTICIPANT	\N	PRESENT	0
467257	467226	08012N	PARTICIPANT	\N	PRESENT	0
467258	467226	19693L	PARTICIPANT	\N	PRESENT	0
467259	467226	04059M	PARTICIPANT	\N	PRESENT	0
467260	467226	14061L	PARTICIPANT	\N	EXCUSE	0
467261	467226	08043V	PARTICIPANT	\N	EXCUSE	0
467487	467062	19575F	PARTICIPANT	\N	PRESENT	0
467488	467062	10006L	PARTICIPANT	\N	PRESENT	0
467489	467062	08052W	PARTICIPANT	\N	PRESENT	0
467490	467062	19553Y	PARTICIPANT	\N	PRESENT	0
467491	467062	19723Y	PARTICIPANT	\N	PRESENT	0
467492	467062	11097X	PARTICIPANT	\N	PRESENT	0
467493	467062	19657G	PARTICIPANT	\N	PRESENT	0
467495	467494	19575F	PARTICIPANT	\N	PRESENT	0
467496	467494	08052W	PARTICIPANT	\N	PRESENT	0
467497	467494	10006L	PARTICIPANT	\N	PRESENT	0
467498	467494	19697Q	PARTICIPANT	\N	PRESENT	0
467499	467494	19657G	PARTICIPANT	\N	PRESENT	0
467500	467494	11097X	PARTICIPANT	\N	PRESENT	0
467501	467494	19703U	PARTICIPANT	\N	PRESENT	0
467502	467063	19575F	PARTICIPANT	\N	PRESENT	0
467503	467063	10006L	PARTICIPANT	\N	PRESENT	0
467504	467063	08052W	PARTICIPANT	\N	PRESENT	0
467536	467535	01028R	PARTICIPANT	\N	PRESENT	0
467537	467535	19673G	PARTICIPANT	\N	PRESENT	0
467538	467535	11085T	PARTICIPANT	\N	PRESENT	0
467539	467535	14215L	PARTICIPANT	\N	PRESENT	0
456890	456889	14042U	PARTICIPANT	\N	PRESENT	0
457439	457438	08028W	PARTICIPANT	\N	PRESENT	0
457441	457438	96004D	PARTICIPANT	\N	PRESENT	0
457442	457438	19569H	PARTICIPANT	\N	PRESENT	0
468991	468776	19335Q	PRESIDENT	0	PRESENT	0
469052	468776	19619A	PARTICIPANT	\N	PRESENT	0
469054	468776	19575F	PARTICIPANT	\N	PRESENT	0
469055	468776	19591F	PARTICIPANT	\N	PRESENT	0
469056	468776	19798U	PARTICIPANT	\N	PRESENT	0
469057	468776	14038Y	PARTICIPANT	\N	PRESENT	0
469058	468776	19387D	PARTICIPANT	\N	PRESENT	0
469237	469228	96004D	PARTICIPANT	\N	PRESENT	0
469238	469228	14331P	PARTICIPANT	\N	PRESENT	0
469383	467534	14065Q	PARTICIPANT	\N	PRESENT	0
469384	467534	14053L	PARTICIPANT	\N	PRESENT	0
469385	467534	19629C	PARTICIPANT	\N	PRESENT	0
469386	467534	04038G	PARTICIPANT	\N	PRESENT	0
469387	467534	04008A	PARTICIPANT	\N	PRESENT	0
469388	467534	14041T	PARTICIPANT	\N	PRESENT	0
469389	467534	14151M	PARTICIPANT	\N	PRESENT	0
469400	467534	19725B	PARTICIPANT	\N	PRESENT	0
469401	467534	14179A	PARTICIPANT	\N	PRESENT	0
469405	467534	08044W	PARTICIPANT	\N	PRESENT	0
468437	468391	14205J	PARTICIPANT	\N	PRESENT	0
469407	467534	19447X	PARTICIPANT	\N	PRESENT	0
469408	467534	19489J	PARTICIPANT	\N	PRESENT	0
468969	468776	11104D	PARTICIPANT	\N	EXCUSE	0
468990	468776	08049C	PARTICIPANT	\N	PRESENT	0
469410	467534	14111D	PARTICIPANT	\N	PRESENT	0
469412	467534	14147R	PARTICIPANT	\N	PRESENT	0
469414	467534	11072N	PARTICIPANT	\N	PRESENT	0
469415	467534	10015M	PARTICIPANT	\N	PRESENT	0
469418	467534	19762G	PARTICIPANT	\N	PRESENT	0
469421	467534	01028R	PARTICIPANT	\N	PRESENT	0
469422	467534	04044E	PARTICIPANT	\N	PRESENT	0
470490	468968	07029T	PARTICIPANT	\N	EXCUSE	0
470547	470546	11053K	PARTICIPANT	\N	PRESENT	0
470549	470548	11053K	PARTICIPANT	\N	PRESENT	0
471048	471047	19447X	PARTICIPANT	\N	PRESENT	0
471049	471047	11026G	PARTICIPANT	\N	PRESENT	0
471050	471047	14147R	PARTICIPANT	\N	PRESENT	0
471051	471047	19649G	PARTICIPANT	\N	PRESENT	0
471053	471052	19447X	PARTICIPANT	\N	PRESENT	0
471054	471052	11026G	PARTICIPANT	\N	PRESENT	0
471056	471055	19447X	PARTICIPANT	\N	PRESENT	0
471062	470987	08039A	PARTICIPANT	\N	PRESENT	0
471058	471055	14147R	PARTICIPANT	\N	PRESENT	0
471059	471055	95063L	PARTICIPANT	\N	PRESENT	0
471061	470987	04018C	PARTICIPANT	\N	PRESENT	0
471063	470987	19749K	PARTICIPANT	\N	PRESENT	0
471064	470988	04018C	PARTICIPANT	\N	PRESENT	0
471065	470988	08039A	PARTICIPANT	\N	PRESENT	0
471066	470988	14109K	PARTICIPANT	\N	PRESENT	0
471067	470988	19749K	PARTICIPANT	\N	PRESENT	0
471068	470989	04018C	PARTICIPANT	\N	PRESENT	0
471069	470989	08039A	PARTICIPANT	\N	PRESENT	0
471070	470989	14109K	PARTICIPANT	\N	PRESENT	0
471084	470506	04040A	PRESIDENT	0	PRESENT	0
471085	470506	14071N	PARTICIPANT	\N	EXCUSE	0
473290	473288	19329S	PARTICIPANT	\N	PRESENT	0
471103	470531	05008E	PRESIDENT	0	PRESENT	0
471104	470531	19543W	PARTICIPANT	\N	PRESENT	0
471105	470531	11033F	PARTICIPANT	\N	PRESENT	0
471106	470531	01024M	PARTICIPANT	\N	PRESENT	0
471107	470531	11049P	PARTICIPANT	\N	PRESENT	0
471108	470531	14231L	PARTICIPANT	\N	EXCUSE	0
471109	470531	19725B	PARTICIPANT	\N	PRESENT	0
471110	470531	19489J	PARTICIPANT	\N	PRESENT	0
471111	470531	19729F	PARTICIPANT	\N	PRESENT	0
471112	470531	14111D	PARTICIPANT	\N	PRESENT	0
471113	470531	01028R	PARTICIPANT	\N	PRESENT	0
471114	470531	04044E	PARTICIPANT	\N	PRESENT	0
471115	470531	14147R	PARTICIPANT	\N	PRESENT	0
471116	470531	19673G	PARTICIPANT	\N	PRESENT	0
471117	470531	14041T	PARTICIPANT	\N	PRESENT	0
471118	470531	14179A	PARTICIPANT	\N	PRESENT	0
471119	470531	19585H	PARTICIPANT	\N	PRESENT	0
471120	470531	11026G	PARTICIPANT	\N	PRESENT	0
471121	470531	19447X	PARTICIPANT	\N	PRESENT	0
471122	470531	08018U	PARTICIPANT	\N	PRESENT	0
471123	470531	14259Y	PARTICIPANT	\N	PRESENT	0
471124	470531	14021P	PARTICIPANT	\N	PRESENT	0
471125	470506	08038Y	PARTICIPANT	\N	EXCUSE	0
473289	473288	04070G	PRESIDENT	0	PRESENT	0
473291	473288	04018C	PARTICIPANT	\N	PRESENT	0
473292	473288	19643A	PARTICIPANT	\N	PRESENT	0
473293	473288	19731Y	PARTICIPANT	\N	PRESENT	0
473294	473288	14123H	PARTICIPANT	\N	PRESENT	0
473295	473288	14249W	PARTICIPANT	\N	PRESENT	0
473296	473288	19699S	PARTICIPANT	\N	PRESENT	0
473297	473288	08039A	PARTICIPANT	\N	PRESENT	0
473298	473288	19766L	PARTICIPANT	\N	PRESENT	0
473299	473288	14107H	PARTICIPANT	\N	PRESENT	0
473300	473288	19758L	PARTICIPANT	\N	PRESENT	0
473301	473288	08043V	PARTICIPANT	\N	PRESENT	0
473302	473288	14061L	PARTICIPANT	\N	PRESENT	0
473303	473288	19399H	PARTICIPANT	\N	PRESENT	0
473304	473288	14241N	PARTICIPANT	\N	PRESENT	0
473305	473288	14109K	PARTICIPANT	\N	PRESENT	0
473306	473288	19533U	PARTICIPANT	\N	PRESENT	0
473307	473288	08020N	PARTICIPANT	\N	PRESENT	0
473308	473288	14030Q	PARTICIPANT	\N	PRESENT	0
473309	473288	19621T	PARTICIPANT	\N	PRESENT	0
473310	473288	87003B	PARTICIPANT	\N	PRESENT	0
473311	471687	04045F	PARTICIPANT	\N	EXCUSE	0
473312	473288	07033P	PARTICIPANT	\N	PRESENT	0
473313	473288	19693L	PARTICIPANT	\N	PRESENT	0
473314	473288	14073Q	PARTICIPANT	\N	PRESENT	0
473315	473288	08031R	PARTICIPANT	\N	PRESENT	0
473316	473288	08017T	PARTICIPANT	\N	PRESENT	0
473317	473288	14251Q	PARTICIPANT	\N	PRESENT	0
473318	473288	19749K	PARTICIPANT	\N	PRESENT	0
473319	473288	14229S	PARTICIPANT	\N	EXCUSE	0
473320	473288	92040Q	PARTICIPANT	\N	EXCUSE	0
473358	471687	04044E	PARTICIPANT	\N	PRESENT	0
473359	471687	95063L	PARTICIPANT	\N	EXCUSE	0
473381	470470	14026U	PARTICIPANT	\N	PRESENT	0
473382	470470	08049C	PARTICIPANT	\N	PRESENT	0
473383	470470	19798U	PARTICIPANT	\N	PRESENT	0
473384	470470	19619A	PARTICIPANT	\N	PRESENT	0
473388	470470	19489J	PARTICIPANT	\N	PRESENT	0
473399	470470	19335Q	PARTICIPANT	\N	PRESENT	0
475016	472986	19563B	PARTICIPANT	\N	PRESENT	0
475017	472986	19619A	PARTICIPANT	\N	PRESENT	0
475018	472986	14329V	PARTICIPANT	\N	PRESENT	0
475019	472986	01043Q	PARTICIPANT	\N	PRESENT	0
475020	472986	08015R	PARTICIPANT	\N	EXCUSE	0
475021	472986	08028W	PARTICIPANT	\N	PRESENT	0
475022	473424	19647E	PARTICIPANT	\N	PRESENT	0
475054	470583	86034E	PARTICIPANT	\N	PRESENT	0
475055	470583	17589D	PARTICIPANT	\N	PRESENT	0
475056	470583	14219Q	PARTICIPANT	\N	PRESENT	0
475057	470583	14195A	PARTICIPANT	\N	PRESENT	0
475058	470583	19826F	PARTICIPANT	\N	PRESENT	0
475059	470583	14051J	PARTICIPANT	\N	PRESENT	0
475060	470583	08060W	PARTICIPANT	\N	PRESENT	0
475061	470583	14001X	PARTICIPANT	\N	PRESENT	0
475062	470583	19631V	PARTICIPANT	\N	PRESENT	0
475064	470583	04085P	PARTICIPANT	\N	PRESENT	0
475065	470583	11033F	PARTICIPANT	\N	PRESENT	0
475066	470583	11040E	PARTICIPANT	\N	PRESENT	0
475067	470583	19758L	PARTICIPANT	\N	PRESENT	0
475068	470583	19760E	PARTICIPANT	\N	PRESENT	0
475069	470583	04086Q	PARTICIPANT	\N	PRESENT	0
475070	470583	11067R	PARTICIPANT	\N	PRESENT	0
475071	470583	19683J	PARTICIPANT	\N	PRESENT	0
475072	470583	19565D	PARTICIPANT	\N	PRESENT	0
475073	470583	98024R	PARTICIPANT	\N	PRESENT	0
475074	470583	17779H	PARTICIPANT	\N	PRESENT	0
475075	470583	08017T	PARTICIPANT	\N	PRESENT	0
475076	470583	19599P	PARTICIPANT	\N	PRESENT	0
475077	470583	19820Y	PARTICIPANT	\N	PRESENT	0
475078	470583	11027H	PARTICIPANT	\N	PRESENT	0
475080	470583	14021P	PARTICIPANT	\N	PRESENT	0
475086	470583	19585H	PARTICIPANT	\N	PRESENT	0
475082	470583	11080N	PARTICIPANT	\N	PRESENT	0
475083	470583	19647E	PARTICIPANT	\N	PRESENT	0
475088	470583	19709B	PARTICIPANT	\N	PRESENT	0
475089	470583	14251Q	PARTICIPANT	\N	PRESENT	0
475090	470583	04040A	PARTICIPANT	\N	PRESENT	0
475091	470583	18083K	PARTICIPANT	\N	PRESENT	0
475092	470583	19479G	PARTICIPANT	\N	PRESENT	0
475093	470583	14042U	PARTICIPANT	\N	PRESENT	0
475094	470583	19569H	PARTICIPANT	\N	PRESENT	0
475095	470583	19415P	PARTICIPANT	\N	PRESENT	0
475096	470583	14121F	PARTICIPANT	\N	PRESENT	0
475097	470583	19794Q	PARTICIPANT	\N	PRESENT	0
475098	470583	14105F	PARTICIPANT	\N	PRESENT	0
471699	471686	19731Y	PARTICIPANT	\N	PRESENT	0
471700	471686	08017T	PARTICIPANT	\N	PRESENT	0
471701	471686	19766L	PARTICIPANT	\N	PRESENT	0
471702	471686	04059M	PARTICIPANT	\N	PRESENT	0
471703	471686	19749K	PARTICIPANT	\N	PRESENT	0
471704	471686	19399H	PARTICIPANT	\N	PRESENT	0
471705	471686	08039A	PARTICIPANT	\N	PRESENT	0
471706	471686	14107H	PARTICIPANT	\N	PRESENT	0
471707	471686	19693L	PARTICIPANT	\N	PRESENT	0
471708	471686	19611R	PARTICIPANT	\N	PRESENT	0
471709	471686	08020N	PARTICIPANT	\N	PRESENT	0
471710	471686	19621T	PARTICIPANT	\N	PRESENT	0
471711	471686	14241N	PARTICIPANT	\N	PRESENT	0
471712	471686	19593H	PARTICIPANT	\N	PRESENT	0
471713	471686	08035V	PARTICIPANT	\N	PRESENT	0
471714	471686	14059S	PARTICIPANT	\N	PRESENT	0
471715	471686	11083R	PARTICIPANT	\N	PRESENT	0
471716	471686	19735D	PARTICIPANT	\N	PRESENT	0
471717	471686	14061L	PARTICIPANT	\N	PRESENT	0
471718	471686	14109K	PARTICIPANT	\N	PRESENT	0
471719	471686	14229S	PARTICIPANT	\N	PRESENT	0
471720	471686	14251Q	PARTICIPANT	\N	PRESENT	0
471721	471686	14123H	PARTICIPANT	\N	PRESENT	0
471722	471686	19643A	PARTICIPANT	\N	PRESENT	0
471723	471686	14073Q	PARTICIPANT	\N	PRESENT	0
471724	471686	04057K	PARTICIPANT	\N	PRESENT	0
471725	471686	11043H	PARTICIPANT	\N	PRESENT	0
471726	471686	11104D	PARTICIPANT	\N	PRESENT	0
471727	471686	19699S	PARTICIPANT	\N	PRESENT	0
471728	471686	08031R	PARTICIPANT	\N	PRESENT	0
471729	471686	14249W	PARTICIPANT	\N	PRESENT	0
471730	471686	19758L	PARTICIPANT	\N	EXCUSE	0
471731	471686	08043V	PARTICIPANT	\N	EXCUSE	0
471794	470827	19367Y	PARTICIPANT	\N	PRESENT	0
471802	470827	14239U	PARTICIPANT	\N	PRESENT	0
471803	470827	19760E	PARTICIPANT	\N	PRESENT	0
471804	470827	19575F	PARTICIPANT	\N	PRESENT	0
471805	470827	19415P	PARTICIPANT	\N	PRESENT	0
471806	470827	11103C	PARTICIPANT	\N	PRESENT	0
471807	470827	14195A	PARTICIPANT	\N	PRESENT	0
471808	470827	11031D	PARTICIPANT	\N	PRESENT	0
471809	470827	08052W	PARTICIPANT	\N	PRESENT	0
471810	470827	19663E	PARTICIPANT	\N	PRESENT	0
471811	470827	98024R	PARTICIPANT	\N	PRESENT	0
471812	470827	10006L	PARTICIPANT	\N	PRESENT	0
471813	470827	14217N	PARTICIPANT	\N	PRESENT	0
471814	470827	14042U	PARTICIPANT	\N	PRESENT	0
471815	470827	14281W	PARTICIPANT	\N	PRESENT	0
471816	470827	19727D	PARTICIPANT	\N	PRESENT	0
471817	470827	19569H	PARTICIPANT	\N	PRESENT	0
471818	470827	19591F	PARTICIPANT	\N	PRESENT	0
471820	470827	14213J	PARTICIPANT	\N	PRESENT	0
471821	470827	19715Y	PARTICIPANT	\N	PRESENT	0
471822	470827	19723Y	PARTICIPANT	\N	PRESENT	0
471823	470827	19697Q	PARTICIPANT	\N	PRESENT	0
471824	470827	17779H	PARTICIPANT	\N	PRESENT	0
471825	470827	19657G	PARTICIPANT	\N	PRESENT	0
471826	470827	11067R	PARTICIPANT	\N	PRESENT	0
471827	470827	14223L	PARTICIPANT	\N	PRESENT	0
471828	470827	14071N	PARTICIPANT	\N	PRESENT	0
471829	470827	19798U	PARTICIPANT	\N	PRESENT	0
471830	470827	11045K	PARTICIPANT	\N	PRESENT	0
471831	470827	19703U	PARTICIPANT	\N	PRESENT	0
471832	470827	19301E	PARTICIPANT	\N	PRESENT	0
471833	470827	14227Q	PARTICIPANT	\N	PRESENT	0
471834	470827	19527W	PARTICIPANT	\N	PRESENT	0
471835	470827	01034P	PARTICIPANT	\N	PRESENT	0
471921	471601	11109J	PARTICIPANT	\N	PRESENT	0
471922	471601	14261S	PARTICIPANT	\N	PRESENT	0
471923	471601	19717B	PARTICIPANT	\N	PRESENT	0
471924	471601	19631V	PARTICIPANT	\N	PRESENT	0
471925	471601	19577H	PARTICIPANT	\N	EXCUSE	0
471926	471601	19715Y	PARTICIPANT	\N	EXCUSE	0
471927	471601	08019V	PRESIDENT	0	PRESENT	0
471928	471601	12016W	PARTICIPANT	\N	EXCUSE	0
471929	471601	14331P	PARTICIPANT	\N	EXCUSE	0
471930	471601	19301E	PARTICIPANT	\N	PRESENT	0
471931	471601	14157T	PARTICIPANT	\N	PRESENT	0
472002	472001	14042U	PARTICIPANT	\N	PRESENT	0
472004	472003	14042U	PARTICIPANT	\N	PRESENT	0
472005	472001	11031D	PARTICIPANT	\N	PRESENT	0
472006	472001	14195A	PARTICIPANT	\N	PRESENT	0
472007	471173	19651A	PARTICIPANT	\N	EXCUSE	0
472009	471173	19711U	PARTICIPANT	\N	EXCUSE	0
472010	472008	14042U	PARTICIPANT	\N	PRESENT	0
472011	471173	14147R	PARTICIPANT	\N	PRESENT	0
472012	471173	19737F	PARTICIPANT	\N	PRESENT	0
472013	471173	19369B	PARTICIPANT	\N	EXCUSE	0
472016	470438	14133K	PARTICIPANT	\N	PRESENT	0
472017	470438	04040A	PARTICIPANT	\N	PRESENT	0
472018	470438	14105F	PARTICIPANT	\N	PRESENT	0
472019	470438	14255U	PARTICIPANT	\N	PRESENT	0
472020	470438	04042C	PARTICIPANT	\N	PRESENT	0
472021	470438	98029W	PARTICIPANT	\N	PRESENT	0
472022	470438	14267Y	PARTICIPANT	\N	PRESENT	0
472023	470438	95030B	PARTICIPANT	\N	PRESENT	0
472024	470438	97011G	PARTICIPANT	\N	PRESENT	0
472025	470438	04035D	PARTICIPANT	\N	PRESENT	0
472026	470438	08056B	PARTICIPANT	\N	PRESENT	0
472027	470438	98022P	PARTICIPANT	\N	PRESENT	0
472028	470438	11064N	PARTICIPANT	\N	PRESENT	0
472029	470438	95037J	PARTICIPANT	\N	PRESENT	0
472030	470438	14097Y	PARTICIPANT	\N	PRESENT	0
472031	470438	19583F	PARTICIPANT	\N	PRESENT	0
472032	470438	12041X	PARTICIPANT	\N	PRESENT	0
472033	470438	08053X	PARTICIPANT	\N	PRESENT	0
472034	470438	08061X	PARTICIPANT	\N	PRESENT	0
472035	470438	08047A	PARTICIPANT	\N	PRESENT	0
472036	470438	14028W	PARTICIPANT	\N	PRESENT	0
472037	470438	14193X	PARTICIPANT	\N	PRESENT	0
472038	470438	98050T	PARTICIPANT	\N	PRESENT	0
472039	470438	19443T	PARTICIPANT	\N	PRESENT	0
472040	470438	11054L	PARTICIPANT	\N	PRESENT	0
472041	470438	19421M	PARTICIPANT	\N	PRESENT	0
472042	470438	01058X	PARTICIPANT	\N	PRESENT	0
472043	470438	01062T	PARTICIPANT	\N	PRESENT	0
472044	470438	08049C	PARTICIPANT	\N	PRESENT	0
472045	470438	11041F	PARTICIPANT	\N	PRESENT	0
472046	470438	11066Q	PARTICIPANT	\N	PRESENT	0
472047	470438	95067Q	PARTICIPANT	\N	PRESENT	0
472048	470438	04034C	PARTICIPANT	\N	PRESENT	0
472061	470888	19575F	PARTICIPANT	\N	PRESENT	0
472062	470888	19545Y	PARTICIPANT	\N	EXCUSE	0
472068	472067	11027H	PARTICIPANT	\N	PRESENT	0
472069	472067	19709B	PARTICIPANT	\N	PRESENT	0
472070	472067	14255U	PARTICIPANT	\N	PRESENT	0
472089	472088	19507S	PARTICIPANT	\N	PRESENT	0
472090	472088	14357A	PARTICIPANT	\N	PRESENT	0
472091	472088	19782L	PARTICIPANT	\N	PRESENT	0
472092	472088	19812Y	PARTICIPANT	\N	PRESENT	0
472093	472088	11099A	PARTICIPANT	\N	PRESENT	0
472094	472088	19563B	PARTICIPANT	\N	PRESENT	0
472095	472088	14257W	PARTICIPANT	\N	PRESENT	0
472097	472096	14033T	PARTICIPANT	\N	PRESENT	0
472098	472096	14357A	PARTICIPANT	\N	PRESENT	0
472099	472096	19812Y	PARTICIPANT	\N	PRESENT	0
472100	472096	19782L	PARTICIPANT	\N	PRESENT	0
472101	472096	19507S	PARTICIPANT	\N	PRESENT	0
472102	472096	14207L	PARTICIPANT	\N	PRESENT	0
472103	472096	19369B	PARTICIPANT	\N	PRESENT	0
472104	472096	14257W	PARTICIPANT	\N	PRESENT	0
472105	472096	19563B	PARTICIPANT	\N	PRESENT	0
472106	472096	19441R	PARTICIPANT	\N	PRESENT	0
472366	472082	89017R	PARTICIPANT	\N	PRESENT	0
472367	472082	19741B	PARTICIPANT	\N	PRESENT	0
472368	472082	19667J	PARTICIPANT	\N	PRESENT	0
472369	472082	11040E	PARTICIPANT	\N	PRESENT	0
472370	472082	04086Q	PARTICIPANT	\N	PRESENT	0
472371	472082	11074Q	PRESIDENT	0	PRESENT	0
472372	472082	11110B	PARTICIPANT	\N	PRESENT	0
472373	472082	14034U	PARTICIPANT	\N	PRESENT	0
472374	472082	01057W	PARTICIPANT	\N	PRESENT	0
472375	472082	11048N	PARTICIPANT	\N	PRESENT	0
472376	472082	19531S	PARTICIPANT	\N	PRESENT	0
472377	472082	99004R	PARTICIPANT	\N	PRESENT	0
472378	472082	19711U	PARTICIPANT	\N	PRESENT	0
472379	472082	08010L	PARTICIPANT	\N	PRESENT	0
472380	472082	19671E	PARTICIPANT	\N	PRESENT	0
472381	472082	08011M	PARTICIPANT	\N	PRESENT	0
472382	472082	19349W	PARTICIPANT	\N	PRESENT	0
472383	472082	14331P	PARTICIPANT	\N	PRESENT	0
472384	472082	14225N	PARTICIPANT	\N	PRESENT	0
472385	472082	19479G	PARTICIPANT	\N	PRESENT	0
472386	472082	07029T	PARTICIPANT	\N	EXCUSE	0
472402	469644	10006L	PARTICIPANT	\N	PRESENT	0
472403	469644	19798U	PARTICIPANT	\N	PRESENT	0
472404	469645	10006L	PARTICIPANT	\N	PRESENT	0
472419	472418	14038Y	PARTICIPANT	\N	PRESENT	0
472420	472418	18083K	PARTICIPANT	\N	PRESENT	0
455403	455402	14059S	PARTICIPANT	\N	PRESENT	0
455404	455402	08017T	PARTICIPANT	\N	PRESENT	0
455405	455402	14109K	PARTICIPANT	\N	PRESENT	0
455406	455402	04057K	PARTICIPANT	\N	PRESENT	0
455407	455402	19731Y	PARTICIPANT	\N	PRESENT	0
455408	455402	04018C	PARTICIPANT	\N	PRESENT	0
455409	455402	04070G	PARTICIPANT	\N	PRESENT	0
456177	453967	11074Q	PARTICIPANT	\N	EXCUSE	0
456683	456682	19543W	PARTICIPANT	\N	PRESENT	0
456684	456682	04040A	PARTICIPANT	\N	PRESENT	0
456685	456682	14069U	PARTICIPANT	\N	PRESENT	0
456686	456682	11027H	PARTICIPANT	\N	PRESENT	0
456687	456682	14079W	PARTICIPANT	\N	PRESENT	0
456688	456682	17589D	PARTICIPANT	\N	PRESENT	0
456689	456682	14249W	PARTICIPANT	\N	PRESENT	0
456690	456682	11110B	PARTICIPANT	\N	PRESENT	0
456691	456682	11083R	PARTICIPANT	\N	PRESENT	0
456692	456682	08056B	PARTICIPANT	\N	PRESENT	0
456693	456682	08044W	PARTICIPANT	\N	PRESENT	0
456694	456682	14073Q	PARTICIPANT	\N	PRESENT	0
456695	456682	04049K	PARTICIPANT	\N	PRESENT	0
456696	456682	08015R	PARTICIPANT	\N	PRESENT	0
456697	456682	14031R	PARTICIPANT	\N	PRESENT	0
456698	456682	14221J	PARTICIPANT	\N	PRESENT	0
463677	463675	08043V	PARTICIPANT	\N	PRESENT	0
456700	456682	14169X	PARTICIPANT	\N	PRESENT	0
456701	456682	14237S	PARTICIPANT	\N	PRESENT	0
456702	456682	14135M	PARTICIPANT	\N	PRESENT	0
456703	456682	95063L	PARTICIPANT	\N	PRESENT	0
456704	456682	98035U	PARTICIPANT	\N	PRESENT	0
456705	456682	04034C	PARTICIPANT	\N	PRESENT	0
457115	454346	19367Y	PARTICIPANT	\N	EXCUSE	0
457116	454346	14109K	PARTICIPANT	\N	PRESENT	0
457117	454346	19715Y	PARTICIPANT	\N	PRESENT	0
460065	459118	04044E	PARTICIPANT	\N	PRESENT	0
460066	459118	19671E	PARTICIPANT	\N	PRESENT	0
460067	459118	14249W	PARTICIPANT	\N	PRESENT	0
460068	459118	19673G	PARTICIPANT	\N	PRESENT	0
460069	459118	19719D	PRESIDENT	0	PRESENT	0
460070	459118	19721W	PARTICIPANT	\N	PRESENT	0
460071	459118	08053X	PARTICIPANT	\N	PRESENT	0
460072	459118	19421M	PARTICIPANT	\N	EXCUSE	0
460073	459118	08010L	PARTICIPANT	\N	EXCUSE	0
460074	457403	19675J	PARTICIPANT	\N	PRESENT	0
460075	457403	95030B	PARTICIPANT	\N	PRESENT	0
460076	457403	14105F	PARTICIPANT	\N	PRESENT	0
460077	457403	14173T	PARTICIPANT	\N	PRESENT	0
460078	457403	19599P	PARTICIPANT	\N	PRESENT	0
460079	457403	14281W	PARTICIPANT	\N	PRESENT	0
460080	457403	04043D	PARTICIPANT	\N	PRESENT	0
460081	457403	19731Y	PARTICIPANT	\N	PRESENT	0
460082	457403	19695N	PARTICIPANT	\N	PRESENT	0
460083	457403	19760E	PARTICIPANT	\N	PRESENT	0
460085	458888	19527W	PARTICIPANT	\N	PRESENT	0
460095	458888	19735D	PARTICIPANT	\N	PRESENT	0
460096	457403	08062Y	PARTICIPANT	\N	PRESENT	0
460097	457403	19251M	PARTICIPANT	\N	PRESENT	0
460098	457403	19669L	PARTICIPANT	\N	PRESENT	0
460099	457403	14053L	PARTICIPANT	\N	PRESENT	0
460292	448771	19782L	PARTICIPANT	\N	PRESENT	0
460304	448771	14051J	PARTICIPANT	\N	PRESENT	0
460305	448771	14030Q	PARTICIPANT	\N	PRESENT	0
460306	448771	19585H	PARTICIPANT	\N	PRESENT	0
460315	458747	08056B	PARTICIPANT	\N	PRESENT	0
460618	460617	88008L	PARTICIPANT	\N	PRESENT	0
460619	460617	14327T	PARTICIPANT	\N	PRESENT	0
460620	460617	11074Q	PARTICIPANT	\N	PRESENT	0
460621	460617	01057W	PARTICIPANT	\N	PRESENT	0
460622	460617	19711U	PARTICIPANT	\N	PRESENT	0
460623	460617	08011M	PARTICIPANT	\N	PRESENT	0
460636	460617	14225N	PARTICIPANT	\N	PRESENT	0
460637	460617	07029T	PARTICIPANT	\N	PRESENT	0
463676	463675	04070G	PRESIDENT	0	PRESENT	0
463678	463675	14229S	PARTICIPANT	\N	PRESENT	0
463679	463675	11083R	PARTICIPANT	\N	PRESENT	0
463680	463675	19533U	PARTICIPANT	\N	PRESENT	0
463681	463675	14123H	PARTICIPANT	\N	PRESENT	0
463682	463675	19693L	PARTICIPANT	\N	PRESENT	0
463683	463675	19621T	PARTICIPANT	\N	PRESENT	0
463684	463675	19735D	PARTICIPANT	\N	PRESENT	0
463685	463675	19611R	PARTICIPANT	\N	PRESENT	0
463686	463675	04057K	PARTICIPANT	\N	PRESENT	0
463687	463675	19593H	PARTICIPANT	\N	PRESENT	0
463688	463675	08031R	PARTICIPANT	\N	PRESENT	0
463689	463542	14030Q	PRESIDENT	0	PRESENT	0
463690	463542	08043V	PARTICIPANT	\N	PRESENT	0
463691	463542	19643A	PARTICIPANT	\N	PRESENT	0
463692	463542	19621T	PARTICIPANT	\N	PRESENT	0
463693	463542	08020N	PARTICIPANT	\N	PRESENT	0
464644	464641	19503N	PARTICIPANT	\N	PRESENT	0
463695	463542	18083K	PARTICIPANT	\N	PRESENT	0
463696	463542	80013X	PARTICIPANT	\N	PRESENT	0
463697	463542	19693L	PARTICIPANT	\N	PRESENT	0
463698	463542	19599P	PARTICIPANT	\N	PRESENT	0
463699	463542	14179A	PARTICIPANT	\N	PRESENT	0
463700	463542	19715Y	PARTICIPANT	\N	PRESENT	0
463701	463542	19731Y	PARTICIPANT	\N	PRESENT	0
463702	463542	08031R	PARTICIPANT	\N	PRESENT	0
463703	463542	08017T	PARTICIPANT	\N	PRESENT	0
463704	463542	11067R	PARTICIPANT	\N	PRESENT	0
463705	463542	14109K	PARTICIPANT	\N	PRESENT	0
463706	463542	11045K	PARTICIPANT	\N	PRESENT	0
463707	463542	19749K	PARTICIPANT	\N	PRESENT	0
463708	463507	08031R	PARTICIPANT	\N	PRESENT	0
464649	464648	14030Q	PRESIDENT	0	PRESENT	0
464650	464648	08043V	PARTICIPANT	\N	PRESENT	0
464651	464648	19621T	PARTICIPANT	\N	PRESENT	0
464652	464648	19693L	PARTICIPANT	\N	PRESENT	0
464653	464648	19701S	PARTICIPANT	\N	PRESENT	0
464654	464648	19577H	PARTICIPANT	\N	PRESENT	0
464655	464648	08031R	PARTICIPANT	\N	PRESENT	0
464656	464648	08017T	PARTICIPANT	\N	PRESENT	0
464657	464648	19269X	PARTICIPANT	\N	PRESENT	0
464658	464648	11045K	PARTICIPANT	\N	PRESENT	0
464659	464648	07029T	PARTICIPANT	\N	EXCUSE	0
464660	464648	04035D	PARTICIPANT	\N	EXCUSE	0
464661	464201	14239U	PARTICIPANT	\N	PRESENT	0
464662	464201	19760E	PARTICIPANT	\N	EXCUSE	0
464663	464201	14261S	PARTICIPANT	\N	EXCUSE	0
464664	464201	19717B	PARTICIPANT	\N	PRESENT	0
464665	464201	19575F	PARTICIPANT	\N	PRESENT	0
464666	464201	19367Y	PARTICIPANT	\N	PRESENT	0
464667	464201	19415P	PARTICIPANT	\N	PRESENT	0
464668	464201	11103C	PARTICIPANT	\N	PRESENT	0
464669	464201	14195A	PARTICIPANT	\N	PRESENT	0
464670	464201	11031D	PARTICIPANT	\N	PRESENT	0
464671	464201	08052W	PARTICIPANT	\N	PRESENT	0
464672	464201	19663E	PARTICIPANT	\N	PRESENT	0
464673	464201	98024R	PARTICIPANT	\N	PRESENT	0
464674	464201	10006L	PARTICIPANT	\N	PRESENT	0
464675	464201	14217N	PARTICIPANT	\N	PRESENT	0
464676	464201	19577H	PARTICIPANT	\N	PRESENT	0
464677	464201	14042U	PARTICIPANT	\N	PRESENT	0
464678	464201	14281W	PARTICIPANT	\N	PRESENT	0
464679	464201	14087W	PARTICIPANT	\N	PRESENT	0
464680	464201	19521Q	PARTICIPANT	\N	PRESENT	0
464681	464201	14355X	PARTICIPANT	\N	EXCUSE	0
464682	464201	08048B	PARTICIPANT	\N	PRESENT	0
464683	464201	08041T	PARTICIPANT	\N	EXCUSE	0
464684	464201	19565D	PARTICIPANT	\N	PRESENT	0
464685	464201	19727D	PARTICIPANT	\N	PRESENT	0
464686	464201	14026U	PARTICIPANT	\N	EXCUSE	0
464687	464201	19691J	PARTICIPANT	\N	PRESENT	0
464688	464201	19553Y	PARTICIPANT	\N	EXCUSE	0
464689	464201	19569H	PARTICIPANT	\N	EXCUSE	0
464690	464201	19591F	PARTICIPANT	\N	PRESENT	0
464691	464201	14213J	PARTICIPANT	\N	PRESENT	0
464692	464201	19715Y	PARTICIPANT	\N	PRESENT	0
464693	464201	19683J	PARTICIPANT	\N	EXCUSE	0
464694	464201	19723Y	PARTICIPANT	\N	PRESENT	0
464695	464201	19697Q	PARTICIPANT	\N	PRESENT	0
464696	464201	17779H	PARTICIPANT	\N	PRESENT	0
464697	464201	19657G	PARTICIPANT	\N	PRESENT	0
464698	464201	11067R	PARTICIPANT	\N	PRESENT	0
464699	464201	14223L	PARTICIPANT	\N	PRESENT	0
464700	464201	04092N	PRESIDENT	0	PRESENT	0
464701	464201	14119M	PARTICIPANT	\N	PRESENT	0
464702	464201	14071N	PARTICIPANT	\N	EXCUSE	0
464703	464201	19679N	PARTICIPANT	\N	PRESENT	0
464704	464201	19798U	PARTICIPANT	\N	PRESENT	0
464705	464201	11045K	PARTICIPANT	\N	PRESENT	0
464706	464201	11097X	PARTICIPANT	\N	PRESENT	0
464707	464201	19703U	PARTICIPANT	\N	PRESENT	0
464708	464201	19301E	PARTICIPANT	\N	EXCUSE	0
464709	464201	14227Q	PARTICIPANT	\N	PRESENT	0
464710	464201	19527W	PARTICIPANT	\N	PRESENT	0
464711	464201	01034P	PARTICIPANT	\N	PRESENT	0
464712	464204	14239U	PARTICIPANT	\N	PRESENT	0
467540	467535	14147R	PARTICIPANT	\N	PRESENT	0
467541	467535	19649G	PARTICIPANT	\N	PRESENT	0
468088	466045	19768N	PARTICIPANT	\N	PRESENT	0
468089	466045	19515S	PARTICIPANT	\N	PRESENT	0
468090	466045	19782L	PARTICIPANT	\N	PRESENT	0
468091	466045	01043Q	PARTICIPANT	\N	PRESENT	0
468092	466045	19812Y	PARTICIPANT	\N	PRESENT	0
468093	466045	14081Q	PARTICIPANT	\N	PRESENT	0
468094	466045	80013X	PARTICIPANT	\N	PRESENT	0
468095	466045	19631V	PARTICIPANT	\N	PRESENT	0
468096	466045	11099A	PARTICIPANT	\N	PRESENT	0
468097	466045	08068F	PARTICIPANT	\N	PRESENT	0
468098	466045	04049K	PARTICIPANT	\N	PRESENT	0
468099	466045	19705W	PARTICIPANT	\N	PRESENT	0
468100	466045	08015R	PARTICIPANT	\N	PRESENT	0
468101	466045	14197C	PARTICIPANT	\N	PRESENT	0
468102	466045	19369B	PARTICIPANT	\N	PRESENT	0
468103	466045	08028W	PARTICIPANT	\N	PRESENT	0
468104	466045	19563B	PARTICIPANT	\N	PRESENT	0
468105	466045	14265W	PARTICIPANT	\N	PRESENT	0
468106	466045	14329V	PARTICIPANT	\N	PRESENT	0
468107	466045	14135M	PARTICIPANT	\N	PRESENT	0
468108	466045	14187A	PARTICIPANT	\N	PRESENT	0
468109	466045	19695N	PARTICIPANT	\N	PRESENT	0
468110	466045	14033T	PARTICIPANT	\N	PRESENT	0
468111	466045	11090Q	PRESIDENT	0	PRESENT	0
468112	466045	01025N	PARTICIPANT	\N	PRESENT	0
468113	466045	14205J	PARTICIPANT	\N	PRESENT	0
468114	466045	11056N	PARTICIPANT	\N	PRESENT	0
468115	466045	19507S	PARTICIPANT	\N	PRESENT	0
468116	466045	19747H	PARTICIPANT	\N	PRESENT	0
468117	466045	19619A	PARTICIPANT	\N	PRESENT	0
468118	466045	19467C	PARTICIPANT	\N	PRESENT	0
468119	466045	14257W	PARTICIPANT	\N	PRESENT	0
468141	466045	14357A	PARTICIPANT	\N	PRESENT	0
468142	466045	19441R	PARTICIPANT	\N	PRESENT	0
468143	466045	08038Y	PARTICIPANT	\N	PRESENT	0
468155	468154	11053K	PARTICIPANT	\N	PRESENT	0
468156	468154	14159V	PARTICIPANT	\N	PRESENT	0
468157	468154	05012A	PARTICIPANT	\N	PRESENT	0
468166	467222	86034E	PARTICIPANT	\N	PRESENT	0
468167	467222	14123H	PARTICIPANT	\N	PRESENT	0
468168	467222	11045K	PARTICIPANT	\N	PRESENT	0
468169	467222	14229S	PARTICIPANT	\N	PRESENT	0
468170	467222	01028R	PARTICIPANT	\N	PRESENT	0
468171	467222	19673G	PARTICIPANT	\N	PRESENT	0
468172	467222	14251Q	PARTICIPANT	\N	PRESENT	0
468173	467222	19585H	PARTICIPANT	\N	PRESENT	0
468174	467222	11033F	PARTICIPANT	\N	PRESENT	0
468175	467222	19569H	PARTICIPANT	\N	PRESENT	0
468176	467222	11085T	PARTICIPANT	\N	PRESENT	0
468177	467222	19629C	PARTICIPANT	\N	PRESENT	0
468178	467222	08031R	PARTICIPANT	\N	PRESENT	0
468179	467222	95063L	PARTICIPANT	\N	PRESENT	0
468180	467222	14157T	PARTICIPANT	\N	PRESENT	0
468181	467222	14259Y	PARTICIPANT	\N	PRESENT	0
468182	467222	05008E	PARTICIPANT	\N	PRESENT	0
468183	467222	19762G	PARTICIPANT	\N	PRESENT	0
468184	467222	07033P	PARTICIPANT	\N	PRESENT	0
468185	467222	07029T	PARTICIPANT	\N	PRESENT	0
468186	467222	98050T	PARTICIPANT	\N	PRESENT	0
468187	467222	10006L	PARTICIPANT	\N	PRESENT	0
468188	467222	11031D	PARTICIPANT	\N	PRESENT	0
468189	467222	17637T	PARTICIPANT	\N	PRESENT	0
468190	467222	19593H	PARTICIPANT	\N	PRESENT	0
468191	467222	14071N	PARTICIPANT	\N	PRESENT	0
468192	467222	14215L	PARTICIPANT	\N	PRESENT	0
468193	467222	14231L	PARTICIPANT	\N	PRESENT	0
468194	467222	14179A	PARTICIPANT	\N	PRESENT	0
468195	467222	11012A	PARTICIPANT	\N	PRESENT	0
468196	467222	04033B	PARTICIPANT	\N	PRESENT	0
468197	467222	04092N	PARTICIPANT	\N	PRESENT	0
468198	467222	14021P	PARTICIPANT	\N	PRESENT	0
468199	467222	04047H	PARTICIPANT	\N	PRESENT	0
468200	467222	19553Y	PARTICIPANT	\N	PRESENT	0
468201	467222	19621T	PARTICIPANT	\N	PRESENT	0
468202	467222	19543W	PARTICIPANT	\N	PRESENT	0
468203	467222	08010L	PARTICIPANT	\N	PRESENT	0
468204	467222	14053L	PARTICIPANT	\N	PRESENT	0
468205	467222	19685L	PARTICIPANT	\N	PRESENT	0
468206	467222	19643A	PARTICIPANT	\N	PRESENT	0
468207	467222	14089Y	PARTICIPANT	\N	PRESENT	0
468208	467222	19649G	PARTICIPANT	\N	PRESENT	0
468209	467222	19573D	PARTICIPANT	\N	PRESENT	0
468210	467222	14151M	PARTICIPANT	\N	PRESENT	0
468211	467222	11110B	PARTICIPANT	\N	PRESENT	0
468218	467222	19691J	PARTICIPANT	\N	PRESENT	0
468219	467222	19545Y	PARTICIPANT	\N	PRESENT	0
468220	467222	04085P	PARTICIPANT	\N	PRESENT	0
468221	467222	19689Q	PARTICIPANT	\N	PRESENT	0
468222	467222	11056N	PARTICIPANT	\N	PRESENT	0
468223	467222	11072N	PARTICIPANT	\N	PRESENT	0
468224	467222	19697Q	PARTICIPANT	\N	PRESENT	0
468225	467222	19647E	PARTICIPANT	\N	PRESENT	0
468226	467222	01048V	PARTICIPANT	\N	PRESENT	0
468227	467222	11070L	PARTICIPANT	\N	PRESENT	0
468228	467222	11053K	PARTICIPANT	\N	PRESENT	0
468229	467222	19651A	PARTICIPANT	\N	PRESENT	0
468230	467222	04070G	PARTICIPANT	\N	PRESENT	0
468231	467222	14055N	PARTICIPANT	\N	PRESENT	0
468313	467223	01028R	PARTICIPANT	\N	PRESENT	0
468314	467223	14021P	PARTICIPANT	\N	PRESENT	0
468315	467223	19543W	PARTICIPANT	\N	PRESENT	0
468316	467223	14229S	PARTICIPANT	\N	PRESENT	0
468317	467223	11045K	PARTICIPANT	\N	PRESENT	0
468318	467223	14151M	PARTICIPANT	\N	PRESENT	0
468319	467223	19651A	PARTICIPANT	\N	PRESENT	0
468320	467223	19553Y	PARTICIPANT	\N	PRESENT	0
468321	467223	19629C	PARTICIPANT	\N	PRESENT	0
468322	467223	19585H	PARTICIPANT	\N	PRESENT	0
468323	467223	19691J	PARTICIPANT	\N	PRESENT	0
468324	467223	19569H	PARTICIPANT	\N	PRESENT	0
468325	467223	14231L	PARTICIPANT	\N	PRESENT	0
468326	467223	04070G	PARTICIPANT	\N	PRESENT	0
468327	467223	14215L	PARTICIPANT	\N	PRESENT	0
468328	467223	98050T	PARTICIPANT	\N	PRESENT	0
468329	467223	19762G	PARTICIPANT	\N	PRESENT	0
468330	467223	07029T	PARTICIPANT	\N	PRESENT	0
468331	467223	14157T	PARTICIPANT	\N	PRESENT	0
468332	467223	19643A	PARTICIPANT	\N	PRESENT	0
468333	467223	14071N	PARTICIPANT	\N	PRESENT	0
468334	467223	04033B	PARTICIPANT	\N	PRESENT	0
468335	467223	04092N	PARTICIPANT	\N	PRESENT	0
468336	467223	04047H	PARTICIPANT	\N	PRESENT	0
468337	467223	14179A	PARTICIPANT	\N	PRESENT	0
468338	467223	19621T	PARTICIPANT	\N	PRESENT	0
468339	467223	14053L	PARTICIPANT	\N	PRESENT	0
468340	467223	11085T	PARTICIPANT	\N	PRESENT	0
468341	467223	11033F	PARTICIPANT	\N	PRESENT	0
468342	467223	19593H	PARTICIPANT	\N	PRESENT	0
468343	467223	19649G	PARTICIPANT	\N	PRESENT	0
468344	467223	08031R	PARTICIPANT	\N	PRESENT	0
468345	467223	11012A	PARTICIPANT	\N	PRESENT	0
468346	467223	11056N	PARTICIPANT	\N	PRESENT	0
468347	467223	14089Y	PARTICIPANT	\N	PRESENT	0
468348	467223	19673G	PARTICIPANT	\N	PRESENT	0
468349	467223	14055N	PARTICIPANT	\N	PRESENT	0
468350	467223	19685L	PARTICIPANT	\N	PRESENT	0
468360	467223	19647E	PARTICIPANT	\N	PRESENT	0
468537	467533	05008E	PRESIDENT	0	PRESENT	0
468539	467533	04047H	PARTICIPANT	\N	PRESENT	0
468540	467533	14215L	PARTICIPANT	\N	PRESENT	0
468543	467533	14021P	PARTICIPANT	\N	PRESENT	0
468545	467533	14231L	PARTICIPANT	\N	PRESENT	0
468547	467533	95063L	PARTICIPANT	\N	PRESENT	0
468613	467534	04047H	PARTICIPANT	\N	PRESENT	0
468614	467534	14215L	PARTICIPANT	\N	PRESENT	0
468927	467225	86034E	PARTICIPANT	\N	PRESENT	0
468928	467225	05008E	PARTICIPANT	\N	PRESENT	0
468311	467223	86034E	PARTICIPANT	\N	PRESENT	0
468312	467223	05008E	PARTICIPANT	\N	PRESENT	0
468929	467225	11064N	PARTICIPANT	\N	PRESENT	0
468930	467225	19643A	PARTICIPANT	\N	PRESENT	0
468931	467225	14041T	PARTICIPANT	\N	PRESENT	0
468932	467225	98050T	PARTICIPANT	\N	PRESENT	0
468933	467225	19701S	PARTICIPANT	\N	PRESENT	0
468934	467225	14357A	PARTICIPANT	\N	PRESENT	0
468935	467225	11033F	PARTICIPANT	\N	PRESENT	0
468936	467225	19673G	PARTICIPANT	\N	PRESENT	0
468937	467225	19629C	PARTICIPANT	\N	PRESENT	0
468938	467225	08031R	PARTICIPANT	\N	PRESENT	0
468939	467225	04085P	PARTICIPANT	\N	PRESENT	0
468940	467225	01028R	PARTICIPANT	\N	PRESENT	0
468941	467225	11085T	PARTICIPANT	\N	PRESENT	0
468942	467225	11070L	PARTICIPANT	\N	PRESENT	0
468943	467225	07033P	PARTICIPANT	\N	PRESENT	0
468944	467225	11045K	PARTICIPANT	\N	PRESENT	0
468945	467225	19649G	PARTICIPANT	\N	PRESENT	0
468947	467225	95063L	PARTICIPANT	\N	PRESENT	0
454868	453808	11067R	PARTICIPANT	\N	PRESENT	0
454869	453808	19565D	PARTICIPANT	\N	PRESENT	0
454870	453808	19798U	PARTICIPANT	\N	PRESENT	0
454871	453808	11097X	PARTICIPANT	\N	PRESENT	0
454872	453808	19415P	PARTICIPANT	\N	PRESENT	0
454873	453808	14026U	PARTICIPANT	\N	PRESENT	0
454874	453808	17779H	PARTICIPANT	\N	PRESENT	0
454875	453808	19703U	PARTICIPANT	\N	PRESENT	0
454876	453808	11031D	PARTICIPANT	\N	PRESENT	0
454877	453808	14281W	PARTICIPANT	\N	PRESENT	0
454878	453808	19679N	PARTICIPANT	\N	PRESENT	0
454879	453808	14042U	PARTICIPANT	\N	PRESENT	0
454880	453808	14195A	PARTICIPANT	\N	PRESENT	0
454881	453808	08048B	PARTICIPANT	\N	PRESENT	0
454882	453808	14213J	PARTICIPANT	\N	PRESENT	0
454883	453808	14261S	PARTICIPANT	\N	PRESENT	0
454884	453808	14217N	PARTICIPANT	\N	PRESENT	0
454885	453808	19683J	PARTICIPANT	\N	PRESENT	0
454886	453808	98024R	PARTICIPANT	\N	PRESENT	0
454887	453808	19521Q	PARTICIPANT	\N	PRESENT	0
454888	453808	08031R	PARTICIPANT	\N	PRESENT	0
454889	453808	19527W	PARTICIPANT	\N	PRESENT	0
454890	453808	04092N	PRESIDENT	0	PRESENT	0
454891	453808	19611R	PARTICIPANT	\N	PRESENT	0
454892	453808	08052W	PARTICIPANT	\N	PRESENT	0
454893	453808	19663E	PARTICIPANT	\N	PRESENT	0
454894	453808	19301E	PARTICIPANT	\N	PRESENT	0
454895	453808	19717B	PARTICIPANT	\N	PRESENT	0
454896	453808	19723Y	PARTICIPANT	\N	PRESENT	0
454897	453808	14030Q	PARTICIPANT	\N	PRESENT	0
454898	453808	19727D	PARTICIPANT	\N	PRESENT	0
454899	453808	14119M	PARTICIPANT	\N	PRESENT	0
454900	453808	11103C	PARTICIPANT	\N	PRESENT	0
454901	453808	14071N	PARTICIPANT	\N	PRESENT	0
455208	455076	19768N	PARTICIPANT	\N	PRESENT	0
454903	453808	19760E	PARTICIPANT	\N	PRESENT	0
454904	453808	08041T	PARTICIPANT	\N	EXCUSE	0
455077	454054	12041X	PARTICIPANT	\N	PRESENT	0
455078	454054	01058X	PARTICIPANT	\N	PRESENT	0
455079	454054	04040A	PARTICIPANT	\N	PRESENT	0
455080	454054	14079W	PARTICIPANT	\N	PRESENT	0
455081	454054	16685X	PARTICIPANT	\N	PRESENT	0
455082	454054	04042C	PRESIDENT	0	PRESENT	0
455083	454054	19669L	PARTICIPANT	\N	PRESENT	0
455084	454054	08056B	PARTICIPANT	\N	PRESENT	0
455085	454054	11115U	PARTICIPANT	\N	PRESENT	0
455086	454054	95037J	PARTICIPANT	\N	PRESENT	0
455087	454054	14055N	PARTICIPANT	\N	PRESENT	0
455088	454054	19421M	PARTICIPANT	\N	PRESENT	0
455089	454054	08053X	PARTICIPANT	\N	PRESENT	0
455090	454054	08061X	PARTICIPANT	\N	PRESENT	0
455091	454054	14133K	PARTICIPANT	\N	PRESENT	0
455092	454054	01062T	PARTICIPANT	\N	PRESENT	0
455093	454054	11041F	PARTICIPANT	\N	PRESENT	0
455094	454054	08058D	PARTICIPANT	\N	PRESENT	0
455095	454054	19251M	PARTICIPANT	\N	PRESENT	0
455096	454054	98022P	PARTICIPANT	\N	PRESENT	0
455097	454054	14211G	PARTICIPANT	\N	PRESENT	0
455098	454054	14255U	PARTICIPANT	\N	PRESENT	0
455099	454928	19611R	PARTICIPANT	\N	PRESENT	0
455257	454260	14001X	PARTICIPANT	\N	PRESENT	0
455101	453967	07029T	PARTICIPANT	\N	PRESENT	0
455102	453967	19479G	PARTICIPANT	\N	PRESENT	0
455103	453967	19689Q	PARTICIPANT	\N	PRESENT	0
455104	453967	14034U	PARTICIPANT	\N	PRESENT	0
455107	454054	95067Q	PARTICIPANT	\N	PRESENT	0
455209	455076	19515S	PARTICIPANT	\N	PRESENT	0
455210	455076	19782L	PARTICIPANT	\N	PRESENT	0
455211	455076	11077T	PARTICIPANT	\N	PRESENT	0
455212	455076	01043Q	PARTICIPANT	\N	PRESENT	0
455213	455076	19812Y	PARTICIPANT	\N	PRESENT	0
455214	455076	19441R	PARTICIPANT	\N	PRESENT	0
455215	455076	19413M	PARTICIPANT	\N	PRESENT	0
455216	455076	14081Q	PARTICIPANT	\N	PRESENT	0
455217	455076	80013X	PARTICIPANT	\N	PRESENT	0
455218	455076	19631V	PARTICIPANT	\N	PRESENT	0
455219	455076	11099A	PARTICIPANT	\N	PRESENT	0
455220	455076	08068F	PARTICIPANT	\N	PRESENT	0
455221	455076	04049K	PARTICIPANT	\N	PRESENT	0
455222	455076	19705W	PARTICIPANT	\N	PRESENT	0
455223	455076	08015R	PARTICIPANT	\N	PRESENT	0
455224	455076	14197C	PARTICIPANT	\N	PRESENT	0
455225	455076	19369B	PARTICIPANT	\N	PRESENT	0
455226	455076	19511N	PARTICIPANT	\N	PRESENT	0
455227	455076	08028W	PARTICIPANT	\N	PRESENT	0
455228	455076	14265W	PARTICIPANT	\N	PRESENT	0
455229	455076	19591F	PARTICIPANT	\N	PRESENT	0
455230	455076	14135M	PARTICIPANT	\N	PRESENT	0
455231	455076	19467C	PARTICIPANT	\N	PRESENT	0
455232	455076	14187A	PARTICIPANT	\N	PRESENT	0
455233	455076	08038Y	PARTICIPANT	\N	PRESENT	0
455234	455076	08062Y	PARTICIPANT	\N	PRESENT	0
455235	455076	19695N	PARTICIPANT	\N	PRESENT	0
455236	455076	11090Q	PRESIDENT	0	PRESENT	0
455237	455076	01025N	PARTICIPANT	\N	PRESENT	0
455238	455076	14033T	PARTICIPANT	\N	PRESENT	0
455239	455076	19295A	PARTICIPANT	\N	PRESENT	0
455240	455076	19269X	PARTICIPANT	\N	PRESENT	0
455241	455076	14205J	PARTICIPANT	\N	PRESENT	0
455242	455076	04088S	PARTICIPANT	\N	PRESENT	0
455243	455076	11056N	PARTICIPANT	\N	PRESENT	0
455244	455076	04089T	PARTICIPANT	\N	PRESENT	0
455245	455076	11101A	PARTICIPANT	\N	PRESENT	0
455246	455076	19507S	PARTICIPANT	\N	PRESENT	0
455247	455076	14207L	PARTICIPANT	\N	PRESENT	0
455248	455076	19747H	PARTICIPANT	\N	PRESENT	0
455249	455076	17589D	PARTICIPANT	\N	PRESENT	0
455250	455076	19619A	PARTICIPANT	\N	PRESENT	0
455251	455076	14257W	PARTICIPANT	\N	PRESENT	0
455254	453967	04071H	PARTICIPANT	\N	PRESENT	0
455255	453967	96004D	PARTICIPANT	\N	PRESENT	0
455256	453967	19647E	PARTICIPANT	\N	PRESENT	0
455258	454260	19543W	PARTICIPANT	\N	PRESENT	0
455259	454260	04044E	PARTICIPANT	\N	PRESENT	0
455260	454260	19585H	PARTICIPANT	\N	PRESENT	0
455261	454260	19673G	PARTICIPANT	\N	PRESENT	0
455262	454260	01028R	PARTICIPANT	\N	PRESENT	0
455263	454260	05008E	PRESIDENT	0	PRESENT	0
455264	454260	19447X	PARTICIPANT	\N	PRESENT	0
455265	454260	14231L	PARTICIPANT	\N	PRESENT	0
455266	454260	14041T	PARTICIPANT	\N	PRESENT	0
455267	454260	14179A	PARTICIPANT	\N	PRESENT	0
455268	454260	14151M	PARTICIPANT	\N	PRESENT	0
455269	454260	14215L	PARTICIPANT	\N	PRESENT	0
455270	454260	14259Y	PARTICIPANT	\N	PRESENT	0
455271	454260	11072N	PARTICIPANT	\N	PRESENT	0
455272	454260	98035U	PARTICIPANT	\N	PRESENT	0
455273	454260	14065Q	PARTICIPANT	\N	PRESENT	0
455274	454260	19649G	PARTICIPANT	\N	PRESENT	0
455275	454260	11010L	PARTICIPANT	\N	PRESENT	0
455276	454260	08045X	PARTICIPANT	\N	PRESENT	0
455277	454260	11026G	PARTICIPANT	\N	PRESENT	0
455278	454260	19253P	PARTICIPANT	\N	PRESENT	0
455279	454260	01024M	PARTICIPANT	\N	PRESENT	0
455280	454260	04038G	PARTICIPANT	\N	PRESENT	0
455281	454260	11033F	PARTICIPANT	\N	PRESENT	0
455282	454260	19725B	PARTICIPANT	\N	PRESENT	0
455283	454260	14089Y	PARTICIPANT	\N	PRESENT	0
455284	454260	19729F	PARTICIPANT	\N	PRESENT	0
455285	454260	95063L	PARTICIPANT	\N	PRESENT	0
455286	454260	19629C	PARTICIPANT	\N	PRESENT	0
455287	454260	08044W	PARTICIPANT	\N	PRESENT	0
455288	454260	11085T	PARTICIPANT	\N	PRESENT	0
455289	454260	19762G	PARTICIPANT	\N	PRESENT	0
455290	454260	14021P	PARTICIPANT	\N	PRESENT	0
455291	454260	14053L	PARTICIPANT	\N	PRESENT	0
455292	454260	19489J	PARTICIPANT	\N	PRESENT	0
455293	454260	14147R	PARTICIPANT	\N	PRESENT	0
455294	454260	14069U	PARTICIPANT	\N	PRESENT	0
455295	454260	04047H	PARTICIPANT	\N	PRESENT	0
455296	454260	19719D	PARTICIPANT	\N	PRESENT	0
455297	454260	19581D	PARTICIPANT	\N	PRESENT	0
455298	454260	08018U	PARTICIPANT	\N	PRESENT	0
455299	454259	19675J	PARTICIPANT	\N	EXCUSE	0
455400	454928	19573D	PARTICIPANT	\N	PRESENT	0
455477	448750	14195A	PARTICIPANT	\N	PRESENT	0
455478	448750	98022P	PARTICIPANT	\N	PRESENT	0
455479	448750	19717B	PARTICIPANT	\N	PRESENT	0
455480	448750	01043Q	PARTICIPANT	\N	PRESENT	0
455481	448750	14042U	PARTICIPANT	\N	PRESENT	0
455482	448750	14089Y	PARTICIPANT	\N	PRESENT	0
455483	448750	14073Q	PARTICIPANT	\N	PRESENT	0
455484	448750	11056N	PARTICIPANT	\N	PRESENT	0
455485	448750	14235Q	PARTICIPANT	\N	PRESENT	0
455486	448750	19758L	PARTICIPANT	\N	PRESENT	0
455487	448750	19687N	PARTICIPANT	\N	PRESENT	0
455488	448750	19593H	PARTICIPANT	\N	PRESENT	0
455489	448750	19565D	PARTICIPANT	\N	PRESENT	0
455490	448750	19347U	PARTICIPANT	\N	PRESENT	0
472421	472418	19701S	PARTICIPANT	\N	PRESENT	0
472422	472418	19599P	PARTICIPANT	\N	PRESENT	0
472423	472418	19333N	PARTICIPANT	\N	PRESENT	0
472424	472418	14219Q	PARTICIPANT	\N	PRESENT	0
472425	472418	19637C	PARTICIPANT	\N	PRESENT	0
472426	472418	19737F	PARTICIPANT	\N	PRESENT	0
472427	472418	19713W	PARTICIPANT	\N	PRESENT	0
472428	472418	19794Q	PARTICIPANT	\N	PRESENT	0
472429	472418	19745F	PARTICIPANT	\N	PRESENT	0
472430	472418	14169X	PARTICIPANT	\N	PRESENT	0
472431	472418	08009T	PRESIDENT	0	PRESENT	0
472432	472418	19820Y	PARTICIPANT	\N	PRESENT	0
472433	472418	14237S	PARTICIPANT	\N	PRESENT	0
472434	472418	04097T	PARTICIPANT	\N	PRESENT	0
472435	472418	17583W	PARTICIPANT	\N	PRESENT	0
472436	472418	19387D	PARTICIPANT	\N	PRESENT	0
472437	472418	19347U	PARTICIPANT	\N	PRESENT	0
472438	472418	11065P	PARTICIPANT	\N	PRESENT	0
472439	472418	04085P	PARTICIPANT	\N	PRESENT	0
472440	472418	14031R	PARTICIPANT	\N	PRESENT	0
472441	472418	04069P	PARTICIPANT	\N	PRESENT	0
472446	472418	17637T	PARTICIPANT	\N	PRESENT	0
472450	472418	08055A	PARTICIPANT	\N	PRESENT	0
472451	472418	19549D	PARTICIPANT	\N	PRESENT	0
472594	472071	14030Q	PRESIDENT	0	PRESENT	0
472595	472071	07029T	PARTICIPANT	\N	EXCUSE	0
472642	472057	05008E	PRESIDENT	0	PRESENT	0
472645	472057	19729F	PARTICIPANT	\N	EXCUSE	0
472646	472057	10015M	PARTICIPANT	\N	PRESENT	0
472647	472071	14251Q	PARTICIPANT	\N	EXCUSE	0
472802	472071	08031R	PARTICIPANT	\N	PRESENT	0
472814	472071	08043V	PARTICIPANT	\N	PRESENT	0
472815	472071	11045K	PARTICIPANT	\N	PRESENT	0
472816	472071	19269X	PARTICIPANT	\N	PRESENT	0
472817	472071	19701S	PARTICIPANT	\N	PRESENT	0
472818	472071	11031D	PARTICIPANT	\N	PRESENT	0
472819	472071	08017T	PARTICIPANT	\N	PRESENT	0
472820	472071	19693L	PARTICIPANT	\N	PRESENT	0
473457	471904	07033P	PARTICIPANT	\N	EXCUSE	0
473458	471904	19319Q	PARTICIPANT	\N	EXCUSE	0
473459	471904	12016W	PARTICIPANT	\N	EXCUSE	0
473460	471904	98005N	PARTICIPANT	\N	EXCUSE	0
473461	471904	08019V	PRESIDENT	0	PRESENT	0
473482	471687	08049C	PARTICIPANT	\N	EXCUSE	0
473484	471687	11101A	PARTICIPANT	\N	PRESENT	0
473485	471687	19525U	PARTICIPANT	\N	PRESENT	0
473486	471687	04086Q	PARTICIPANT	\N	PRESENT	0
473487	471687	14259Y	PARTICIPANT	\N	PRESENT	0
473488	471687	19820Y	PARTICIPANT	\N	PRESENT	0
473489	471687	11049P	PARTICIPANT	\N	PRESENT	0
473490	471687	01057W	PARTICIPANT	\N	PRESENT	0
473491	471687	11048N	PARTICIPANT	\N	PRESENT	0
473492	471687	19489J	PARTICIPANT	\N	PRESENT	0
473493	471687	08010L	PARTICIPANT	\N	PRESENT	0
473494	471687	17637T	PARTICIPANT	\N	PRESENT	0
473495	471687	19735D	PARTICIPANT	\N	PRESENT	0
473496	471687	95067Q	PARTICIPANT	\N	PRESENT	0
473497	471687	19253P	PARTICIPANT	\N	EXCUSE	0
473507	473506	96004D	PRESIDENT	0	PRESENT	0
473508	473506	14079W	PARTICIPANT	\N	PRESENT	0
473509	473506	11083R	PARTICIPANT	\N	PRESENT	0
473510	473506	19725B	PARTICIPANT	\N	PRESENT	0
473511	473506	19569H	PARTICIPANT	\N	PRESENT	0
473512	473506	04097T	PARTICIPANT	\N	PRESENT	0
473513	473506	14097Y	PARTICIPANT	\N	PRESENT	0
473514	473506	14241N	PARTICIPANT	\N	PRESENT	0
473515	473506	08039A	PARTICIPANT	\N	PRESENT	0
473516	473506	98035U	PARTICIPANT	\N	PRESENT	0
473517	473506	10015M	PARTICIPANT	\N	PRESENT	0
473518	473506	14331P	PARTICIPANT	\N	PRESENT	0
473623	473576	19760E	PARTICIPANT	\N	PRESENT	0
473626	473576	19679N	PARTICIPANT	\N	PRESENT	0
473628	473602	19760E	PARTICIPANT	\N	PRESENT	0
473629	473602	19679N	PARTICIPANT	\N	PRESENT	0
473630	473566	19760E	PARTICIPANT	\N	PRESENT	0
473631	473566	19679N	PARTICIPANT	\N	PRESENT	0
473633	473568	19760E	PARTICIPANT	\N	PRESENT	0
473637	473572	19679N	PARTICIPANT	\N	PRESENT	0
473635	473568	19679N	PARTICIPANT	\N	PRESENT	0
473636	473572	19760E	PARTICIPANT	\N	PRESENT	0
473638	473602	11067R	PARTICIPANT	\N	PRESENT	0
473689	473471	14031R	PARTICIPANT	\N	PRESENT	0
473690	473471	19681G	PARTICIPANT	\N	PRESENT	0
473691	473471	14157T	PARTICIPANT	\N	PRESENT	0
473692	473471	19637C	PARTICIPANT	\N	PRESENT	0
473693	473471	19794Q	PARTICIPANT	\N	PRESENT	0
473694	473471	19551W	PARTICIPANT	\N	PRESENT	0
473699	473574	08060W	PARTICIPANT	\N	PRESENT	0
473700	473472	14031R	PARTICIPANT	\N	PRESENT	0
473701	473472	19820Y	PARTICIPANT	\N	PRESENT	0
473702	473472	19387D	PARTICIPANT	\N	PRESENT	0
473703	473472	19333N	PARTICIPANT	\N	PRESENT	0
473704	473472	19551W	PARTICIPANT	\N	PRESENT	0
473705	473472	19637C	PARTICIPANT	\N	PRESENT	0
473706	473472	19794Q	PARTICIPANT	\N	PRESENT	0
473707	473472	19713W	PARTICIPANT	\N	PRESENT	0
473708	473472	19737F	PARTICIPANT	\N	PRESENT	0
473721	473720	14093U	PARTICIPANT	\N	PRESENT	0
473722	473720	19701S	PARTICIPANT	\N	PRESENT	0
473723	473720	19387D	PARTICIPANT	\N	PRESENT	0
473724	473720	19347U	PARTICIPANT	\N	PRESENT	0
473725	473720	11065P	PARTICIPANT	\N	PRESENT	0
473726	473720	19637C	PARTICIPANT	\N	PRESENT	0
473727	473473	17583W	PARTICIPANT	\N	PRESENT	0
473728	473473	14157T	PARTICIPANT	\N	PRESENT	0
473729	473473	14031R	PARTICIPANT	\N	PRESENT	0
473730	473473	19820Y	PARTICIPANT	\N	PRESENT	0
473731	473473	19333N	PARTICIPANT	\N	PRESENT	0
473732	473473	19599P	PARTICIPANT	\N	PRESENT	0
473733	473473	19737F	PARTICIPANT	\N	PRESENT	0
473734	473473	14169X	PARTICIPANT	\N	PRESENT	0
473735	473473	19549D	PARTICIPANT	\N	PRESENT	0
473736	473575	08060W	PARTICIPANT	\N	PRESENT	0
473737	473575	08024S	PARTICIPANT	\N	PRESENT	0
473738	473575	19701S	PARTICIPANT	\N	PRESENT	0
473739	473575	19599P	PARTICIPANT	\N	PRESENT	0
473740	473575	02002K	PARTICIPANT	\N	PRESENT	0
473741	473575	19820Y	PARTICIPANT	\N	PRESENT	0
473742	473575	19347U	PARTICIPANT	\N	PRESENT	0
473743	473575	19333N	PARTICIPANT	\N	PRESENT	0
473744	473575	19551W	PARTICIPANT	\N	PRESENT	0
473745	473575	08009T	PARTICIPANT	\N	PRESENT	0
473746	473575	14221J	PARTICIPANT	\N	PRESENT	0
473747	473575	19745F	PARTICIPANT	\N	PRESENT	0
473748	473575	19739H	PARTICIPANT	\N	PRESENT	0
473749	473575	19794Q	PARTICIPANT	\N	PRESENT	0
473750	473575	19737F	PARTICIPANT	\N	PRESENT	0
473751	473474	08009T	PARTICIPANT	\N	PRESENT	0
473752	473474	14031R	PARTICIPANT	\N	PRESENT	0
473753	473463	14031R	PARTICIPANT	\N	PRESENT	0
473754	473463	19701S	PARTICIPANT	\N	PRESENT	0
473755	473463	19549D	PARTICIPANT	\N	PRESENT	0
473756	473463	19387D	PARTICIPANT	\N	PRESENT	0
473757	473463	14093U	PARTICIPANT	\N	PRESENT	0
473758	473463	19820Y	PARTICIPANT	\N	PRESENT	0
473759	473463	19637C	PARTICIPANT	\N	PRESENT	0
473760	473463	14219Q	PARTICIPANT	\N	PRESENT	0
473761	473463	14051J	PARTICIPANT	\N	PRESENT	0
473762	473463	14038Y	PARTICIPANT	\N	PRESENT	0
473763	473463	19713W	PARTICIPANT	\N	PRESENT	0
473764	473463	08024S	PARTICIPANT	\N	PRESENT	0
473765	473463	19333N	PARTICIPANT	\N	PRESENT	0
473766	473463	19347U	PARTICIPANT	\N	PRESENT	0
473767	473463	04069P	PARTICIPANT	\N	PRESENT	0
473768	473463	19503N	PARTICIPANT	\N	PRESENT	0
473769	473463	14237S	PARTICIPANT	\N	PRESENT	0
473770	473463	19739H	PARTICIPANT	\N	PRESENT	0
473771	473463	19745F	PARTICIPANT	\N	PRESENT	0
473772	473463	14029X	PARTICIPANT	\N	PRESENT	0
473773	473463	18083K	PARTICIPANT	\N	PRESENT	0
473774	473441	14219Q	PARTICIPANT	\N	PRESENT	0
473775	473441	14169X	PARTICIPANT	\N	PRESENT	0
473776	473441	19387D	PARTICIPANT	\N	PRESENT	0
473777	473441	02002K	PARTICIPANT	\N	PRESENT	0
473778	473441	19820Y	PARTICIPANT	\N	PRESENT	0
473779	473441	19333N	PARTICIPANT	\N	PRESENT	0
473780	473441	19383Y	PARTICIPANT	\N	PRESENT	0
473781	473441	19794Q	PARTICIPANT	\N	PRESENT	0
473782	473441	18083K	PARTICIPANT	\N	PRESENT	0
473783	473441	19347U	PARTICIPANT	\N	PRESENT	0
473784	473441	19739H	PARTICIPANT	\N	PRESENT	0
473785	473441	19599P	PARTICIPANT	\N	PRESENT	0
473786	473441	19737F	PARTICIPANT	\N	PRESENT	0
473787	473441	19551W	PARTICIPANT	\N	PRESENT	0
473788	473441	14029X	PARTICIPANT	\N	PRESENT	0
473789	473578	08060W	PARTICIPANT	\N	PRESENT	0
473790	473578	08024S	PARTICIPANT	\N	PRESENT	0
473791	473578	02002K	PARTICIPANT	\N	PRESENT	0
473792	473578	19820Y	PARTICIPANT	\N	PRESENT	0
463807	463734	14331P	PARTICIPANT	\N	PRESENT	0
463808	463734	95041E	PARTICIPANT	\N	PRESENT	0
463809	463734	19545Y	PARTICIPANT	\N	PRESENT	0
463810	463734	11053K	PARTICIPANT	\N	PRESENT	0
463811	463734	19667J	PARTICIPANT	\N	PRESENT	0
463812	463734	11074Q	PRESIDENT	0	PRESENT	0
463813	463734	14225N	PARTICIPANT	\N	PRESENT	0
463814	463734	19671E	PARTICIPANT	\N	PRESENT	0
463815	463734	88008L	PARTICIPANT	\N	PRESENT	0
463816	463734	14085U	PARTICIPANT	\N	PRESENT	0
463817	463734	07004J	PARTICIPANT	\N	PRESENT	0
463818	463734	96004D	PARTICIPANT	\N	PRESENT	0
463819	463734	19349W	PARTICIPANT	\N	PRESENT	0
463820	463734	08010L	PARTICIPANT	\N	PRESENT	0
463821	463734	11048N	PARTICIPANT	\N	PRESENT	0
463822	463734	19479G	PARTICIPANT	\N	PRESENT	0
463823	463734	19647E	PARTICIPANT	\N	PRESENT	0
463824	463734	19711U	PARTICIPANT	\N	PRESENT	0
463825	463734	19651A	PARTICIPANT	\N	PRESENT	0
463826	463734	19531S	PARTICIPANT	\N	PRESENT	0
463827	463734	19687N	PARTICIPANT	\N	PRESENT	0
463828	463734	19689Q	PARTICIPANT	\N	PRESENT	0
463829	463734	12016W	PARTICIPANT	\N	PRESENT	0
463830	463734	08011M	PARTICIPANT	\N	PRESENT	0
463831	463734	14034U	PARTICIPANT	\N	PRESENT	0
463832	463734	14173T	PARTICIPANT	\N	PRESENT	0
463833	463734	04086Q	PARTICIPANT	\N	PRESENT	0
463834	463734	11040E	PARTICIPANT	\N	PRESENT	0
463835	463734	14083S	PARTICIPANT	\N	PRESENT	0
463836	463734	11012A	PARTICIPANT	\N	PRESENT	0
460978	458657	11048N	PARTICIPANT	\N	EXCUSE	0
461681	458657	14195A	PARTICIPANT	\N	EXCUSE	0
463837	463734	08073C	PARTICIPANT	\N	PRESENT	0
463838	463734	19741B	PARTICIPANT	\N	PRESENT	0
463839	463734	14121F	PARTICIPANT	\N	PRESENT	0
463840	463734	99004R	PARTICIPANT	\N	PRESENT	0
463850	463407	86034E	PARTICIPANT	\N	PRESENT	0
463851	463407	19695N	PARTICIPANT	\N	PRESENT	0
463852	463407	05008E	PARTICIPANT	\N	PRESENT	0
463853	463407	14055N	PARTICIPANT	\N	PRESENT	0
463854	463407	12041X	PARTICIPANT	\N	PRESENT	0
463855	463407	14021P	PARTICIPANT	\N	PRESENT	0
463856	463407	14151M	PARTICIPANT	\N	PRESENT	0
463857	463407	08061X	PARTICIPANT	\N	PRESENT	0
463858	463407	11064N	PARTICIPANT	\N	PRESENT	0
463859	463407	14251Q	PARTICIPANT	\N	PRESENT	0
463860	463407	11070L	PARTICIPANT	\N	PRESENT	0
463861	463407	11053K	PARTICIPANT	\N	PRESENT	0
463862	463407	11012A	PARTICIPANT	\N	PRESENT	0
463863	463407	04033B	PARTICIPANT	\N	PRESENT	0
463864	463407	17637T	PARTICIPANT	\N	PRESENT	0
463865	463407	04085P	PARTICIPANT	\N	PRESENT	0
463866	463407	11085T	PARTICIPANT	\N	PRESENT	0
463867	463407	19413M	PARTICIPANT	\N	PRESENT	0
464713	464204	19760E	PARTICIPANT	\N	PRESENT	0
464714	464204	14261S	PARTICIPANT	\N	EXCUSE	0
464715	464204	19717B	PARTICIPANT	\N	EXCUSE	0
464716	464204	19575F	PARTICIPANT	\N	PRESENT	0
464717	464204	19367Y	PARTICIPANT	\N	EXCUSE	0
464718	464204	19415P	PARTICIPANT	\N	PRESENT	0
464719	464204	11103C	PARTICIPANT	\N	PRESENT	0
464720	464204	14195A	PARTICIPANT	\N	PRESENT	0
464721	464204	11031D	PARTICIPANT	\N	EXCUSE	0
464722	464204	08052W	PARTICIPANT	\N	PRESENT	0
464723	464204	19663E	PARTICIPANT	\N	EXCUSE	0
464724	464204	98024R	PARTICIPANT	\N	EXCUSE	0
464725	464204	10006L	PARTICIPANT	\N	PRESENT	0
464726	464204	14217N	PARTICIPANT	\N	EXCUSE	0
464727	464204	19577H	PARTICIPANT	\N	PRESENT	0
464728	464204	14042U	PARTICIPANT	\N	EXCUSE	0
464729	464204	14281W	PARTICIPANT	\N	PRESENT	0
464730	464204	14087W	PARTICIPANT	\N	PRESENT	0
464731	464204	19521Q	PARTICIPANT	\N	EXCUSE	0
464732	464204	14355X	PARTICIPANT	\N	EXCUSE	0
464733	464204	08048B	PARTICIPANT	\N	PRESENT	0
464734	464204	08041T	PARTICIPANT	\N	EXCUSE	0
464735	464204	19565D	PARTICIPANT	\N	PRESENT	0
464736	464204	19727D	PARTICIPANT	\N	PRESENT	0
464737	464204	14026U	PARTICIPANT	\N	PRESENT	0
464738	464204	19691J	PARTICIPANT	\N	PRESENT	0
464739	464204	19553Y	PARTICIPANT	\N	PRESENT	0
464740	464204	19569H	PARTICIPANT	\N	EXCUSE	0
464741	464204	19591F	PARTICIPANT	\N	PRESENT	0
464742	464204	14213J	PARTICIPANT	\N	PRESENT	0
464743	464204	19715Y	PARTICIPANT	\N	PRESENT	0
464744	464204	19683J	PARTICIPANT	\N	EXCUSE	0
464745	464204	19723Y	PARTICIPANT	\N	PRESENT	0
464746	464204	19697Q	PARTICIPANT	\N	PRESENT	0
464747	464204	17779H	PARTICIPANT	\N	PRESENT	0
464748	464204	19657G	PARTICIPANT	\N	PRESENT	0
464749	464204	11067R	PARTICIPANT	\N	PRESENT	0
464750	464204	14223L	PARTICIPANT	\N	EXCUSE	0
464751	464204	04092N	PRESIDENT	0	PRESENT	0
464752	464204	14119M	PARTICIPANT	\N	PRESENT	0
464753	464204	14071N	PARTICIPANT	\N	PRESENT	0
464754	464204	19679N	PARTICIPANT	\N	PRESENT	0
464755	464204	19798U	PARTICIPANT	\N	PRESENT	0
464756	464204	11045K	PARTICIPANT	\N	EXCUSE	0
464757	464204	11097X	PARTICIPANT	\N	PRESENT	0
464758	464204	19703U	PARTICIPANT	\N	EXCUSE	0
464759	464204	19301E	PARTICIPANT	\N	PRESENT	0
464760	464204	14227Q	PARTICIPANT	\N	PRESENT	0
464761	464204	19527W	PARTICIPANT	\N	PRESENT	0
464762	464204	01034P	PARTICIPANT	\N	EXCUSE	0
464839	464203	14213J	PARTICIPANT	\N	PRESENT	0
464840	464203	19663E	PARTICIPANT	\N	PRESENT	0
464852	464203	19415P	PARTICIPANT	\N	PRESENT	0
464853	464203	14223L	PARTICIPANT	\N	PRESENT	0
464854	464203	10006L	PARTICIPANT	\N	PRESENT	0
464855	464203	19760E	PARTICIPANT	\N	PRESENT	0
464856	464203	14217N	PARTICIPANT	\N	PRESENT	0
464857	464203	14281W	PARTICIPANT	\N	PRESENT	0
464858	464203	14071N	PARTICIPANT	\N	PRESENT	0
464859	464203	19723Y	PARTICIPANT	\N	PRESENT	0
464860	464203	14042U	PARTICIPANT	\N	PRESENT	0
464861	464203	14227Q	PARTICIPANT	\N	PRESENT	0
464862	464203	19679N	PARTICIPANT	\N	PRESENT	0
464863	464203	14119M	PARTICIPANT	\N	PRESENT	0
464864	464203	11045K	PARTICIPANT	\N	PRESENT	0
464865	464203	19691J	PARTICIPANT	\N	PRESENT	0
464866	464203	11103C	PARTICIPANT	\N	PRESENT	0
464867	464203	19575F	PARTICIPANT	\N	PRESENT	0
464869	464203	14087W	PARTICIPANT	\N	PRESENT	0
464870	464203	19798U	PARTICIPANT	\N	PRESENT	0
464783	464203	14355X	PARTICIPANT	\N	EXCUSE	0
464871	464203	19565D	PARTICIPANT	\N	PRESENT	0
464785	464203	08041T	PARTICIPANT	\N	EXCUSE	0
464872	464203	17779H	PARTICIPANT	\N	PRESENT	0
464873	464203	19727D	PARTICIPANT	\N	PRESENT	0
464874	464203	19569H	PARTICIPANT	\N	PRESENT	0
464875	464203	19577H	PARTICIPANT	\N	PRESENT	0
464876	464203	11097X	PARTICIPANT	\N	PRESENT	0
464877	464203	19527W	PARTICIPANT	\N	PRESENT	0
464878	464203	19715Y	PARTICIPANT	\N	PRESENT	0
464879	464203	19657G	PARTICIPANT	\N	PRESENT	0
464880	464203	08052W	PARTICIPANT	\N	PRESENT	0
464882	464202	14026U	PARTICIPANT	\N	PRESENT	0
464883	464202	19723Y	PARTICIPANT	\N	PRESENT	0
464884	464202	19727D	PARTICIPANT	\N	PRESENT	0
464885	464202	11097X	PARTICIPANT	\N	PRESENT	0
464886	464202	19717B	PARTICIPANT	\N	PRESENT	0
464887	464202	19521Q	PARTICIPANT	\N	PRESENT	0
464888	464202	19760E	PARTICIPANT	\N	PRESENT	0
464889	464202	14281W	PARTICIPANT	\N	PRESENT	0
464890	464202	14217N	PARTICIPANT	\N	PRESENT	0
464891	464202	19679N	PARTICIPANT	\N	PRESENT	0
464892	464202	14042U	PARTICIPANT	\N	PRESENT	0
464893	464202	11031D	PARTICIPANT	\N	PRESENT	0
464894	464202	19798U	PARTICIPANT	\N	PRESENT	0
464895	464202	19697Q	PARTICIPANT	\N	PRESENT	0
464896	464202	19575F	PARTICIPANT	\N	PRESENT	0
464897	464202	14087W	PARTICIPANT	\N	PRESENT	0
464898	464202	19565D	PARTICIPANT	\N	PRESENT	0
464899	464202	11067R	PARTICIPANT	\N	PRESENT	0
464900	464202	17779H	PARTICIPANT	\N	PRESENT	0
464838	464203	04092N	PRESIDENT	0	PRESENT	0
464901	464202	14071N	PARTICIPANT	\N	PRESENT	0
464902	464202	19689Q	PARTICIPANT	\N	PRESENT	0
464903	464202	19715Y	PARTICIPANT	\N	PRESENT	0
464904	464202	08052W	PARTICIPANT	\N	PRESENT	0
464905	464202	19577H	PARTICIPANT	\N	PRESENT	0
464906	464202	19569H	PARTICIPANT	\N	PRESENT	0
464907	464202	19527W	PARTICIPANT	\N	PRESENT	0
464908	464202	04092N	PRESIDENT	0	PRESENT	0
464909	464202	14239U	PARTICIPANT	\N	EXCUSE	0
464910	464202	14261S	PARTICIPANT	\N	EXCUSE	0
464911	464202	19367Y	PARTICIPANT	\N	EXCUSE	0
464912	464202	19415P	PARTICIPANT	\N	EXCUSE	0
464913	464202	11103C	PARTICIPANT	\N	EXCUSE	0
469072	468730	19443T	PARTICIPANT	\N	PRESENT	0
469073	468730	95030B	PARTICIPANT	\N	PRESENT	0
469074	468730	14079W	PARTICIPANT	\N	PRESENT	0
469075	468730	01058X	PARTICIPANT	\N	PRESENT	0
469076	468730	04040A	PARTICIPANT	\N	PRESENT	0
469077	468730	11027H	PARTICIPANT	\N	PRESENT	0
469078	468730	16685X	PARTICIPANT	\N	PRESENT	0
469079	468730	04042C	PRESIDENT	0	PRESENT	0
469080	468730	11066Q	PARTICIPANT	\N	PRESENT	0
469081	468730	95037J	PARTICIPANT	\N	PRESENT	0
469082	468730	19421M	PARTICIPANT	\N	PRESENT	0
469083	468730	19709B	PARTICIPANT	\N	PRESENT	0
469084	468730	14193X	PARTICIPANT	\N	PRESENT	0
469085	468730	08049C	PARTICIPANT	\N	PRESENT	0
469086	468730	08053X	PARTICIPANT	\N	PRESENT	0
469087	468730	97011G	PARTICIPANT	\N	PRESENT	0
469088	468730	08047A	PARTICIPANT	\N	PRESENT	0
469089	468730	98029W	PARTICIPANT	\N	PRESENT	0
469090	468730	14097Y	PARTICIPANT	\N	PRESENT	0
469091	468730	04035D	PARTICIPANT	\N	PRESENT	0
469092	468730	95067Q	PARTICIPANT	\N	PRESENT	0
469093	468730	14133K	PARTICIPANT	\N	PRESENT	0
469094	468730	01062T	PARTICIPANT	\N	PRESENT	0
469095	468730	11041F	PARTICIPANT	\N	PRESENT	0
469096	468730	14235Q	PARTICIPANT	\N	PRESENT	0
469097	468730	08058D	PARTICIPANT	\N	PRESENT	0
469098	468730	19251M	PARTICIPANT	\N	PRESENT	0
469099	468730	14105F	PARTICIPANT	\N	PRESENT	0
469100	468730	98018T	PARTICIPANT	\N	PRESENT	0
469101	468730	98022P	PARTICIPANT	\N	PRESENT	0
469102	468730	14267Y	PARTICIPANT	\N	PRESENT	0
469103	468730	11064N	PARTICIPANT	\N	PRESENT	0
469104	468730	98050T	PARTICIPANT	\N	PRESENT	0
469105	468730	14211G	PARTICIPANT	\N	PRESENT	0
469106	468730	19583F	PARTICIPANT	\N	PRESENT	0
469107	468730	14255U	PARTICIPANT	\N	PRESENT	0
469108	468730	11054L	PARTICIPANT	\N	EXCUSE	0
469137	467279	14239U	PARTICIPANT	\N	PRESENT	0
469138	467279	19760E	PARTICIPANT	\N	PRESENT	0
469139	467279	19717B	PARTICIPANT	\N	PRESENT	0
469140	467279	19575F	PARTICIPANT	\N	PRESENT	0
469141	467279	19415P	PARTICIPANT	\N	PRESENT	0
469142	467279	11103C	PARTICIPANT	\N	PRESENT	0
469143	467279	19727D	PARTICIPANT	\N	PRESENT	0
469144	467279	14195A	PARTICIPANT	\N	PRESENT	0
469145	467279	11031D	PARTICIPANT	\N	PRESENT	0
469146	467279	08052W	PARTICIPANT	\N	PRESENT	0
469147	467279	19663E	PARTICIPANT	\N	PRESENT	0
469148	467279	98024R	PARTICIPANT	\N	PRESENT	0
469149	467279	10006L	PARTICIPANT	\N	PRESENT	0
469150	467279	14217N	PARTICIPANT	\N	PRESENT	0
469151	467279	14042U	PARTICIPANT	\N	PRESENT	0
469152	467279	14281W	PARTICIPANT	\N	PRESENT	0
469153	467279	14087W	PARTICIPANT	\N	PRESENT	0
469154	467279	19521Q	PARTICIPANT	\N	PRESENT	0
469155	467279	08048B	PARTICIPANT	\N	PRESENT	0
469156	467279	19565D	PARTICIPANT	\N	PRESENT	0
469157	467279	19691J	PARTICIPANT	\N	PRESENT	0
469158	467279	19569H	PARTICIPANT	\N	PRESENT	0
469159	467279	14213J	PARTICIPANT	\N	PRESENT	0
469160	467279	19715Y	PARTICIPANT	\N	PRESENT	0
469161	467279	19723Y	PARTICIPANT	\N	PRESENT	0
469162	467279	19697Q	PARTICIPANT	\N	PRESENT	0
469163	467279	17779H	PARTICIPANT	\N	PRESENT	0
469164	467279	19683J	PARTICIPANT	\N	PRESENT	0
469165	467279	19657G	PARTICIPANT	\N	PRESENT	0
469166	467279	11067R	PARTICIPANT	\N	PRESENT	0
469167	467279	14071N	PARTICIPANT	\N	PRESENT	0
469168	467279	14119M	PARTICIPANT	\N	PRESENT	0
469169	467279	14223L	PARTICIPANT	\N	PRESENT	0
469170	467279	01034P	PARTICIPANT	\N	PRESENT	0
469171	467279	19703U	PARTICIPANT	\N	PRESENT	0
469172	467279	11097X	PARTICIPANT	\N	PRESENT	0
469173	467279	19798U	PARTICIPANT	\N	PRESENT	0
469174	467279	19679N	PARTICIPANT	\N	PRESENT	0
469175	467279	08041T	PARTICIPANT	\N	EXCUSE	0
469177	467279	04092N	PRESIDENT	0	PRESENT	0
469186	467280	14239U	PARTICIPANT	\N	PRESENT	0
469188	467280	19717B	PARTICIPANT	\N	PRESENT	0
469195	467280	19575F	PARTICIPANT	\N	PRESENT	0
469196	467280	19415P	PARTICIPANT	\N	PRESENT	0
469198	467280	11103C	PARTICIPANT	\N	PRESENT	0
469199	467280	11031D	PARTICIPANT	\N	PRESENT	0
469200	467280	08052W	PARTICIPANT	\N	PRESENT	0
469201	467280	19663E	PARTICIPANT	\N	PRESENT	0
469202	467280	98024R	PARTICIPANT	\N	PRESENT	0
469203	467280	10006L	PARTICIPANT	\N	PRESENT	0
469204	467280	14042U	PARTICIPANT	\N	PRESENT	0
469205	467280	14087W	PARTICIPANT	\N	PRESENT	0
469206	467280	19521Q	PARTICIPANT	\N	PRESENT	0
469207	467280	08048B	PARTICIPANT	\N	PRESENT	0
469208	467280	19565D	PARTICIPANT	\N	PRESENT	0
469209	467280	19691J	PARTICIPANT	\N	PRESENT	0
469210	467280	19553Y	PARTICIPANT	\N	PRESENT	0
469212	467280	14213J	PARTICIPANT	\N	PRESENT	0
469213	467280	19715Y	PARTICIPANT	\N	PRESENT	0
469215	467280	19697Q	PARTICIPANT	\N	PRESENT	0
469216	467280	17779H	PARTICIPANT	\N	PRESENT	0
469217	467280	19657G	PARTICIPANT	\N	PRESENT	0
469218	467280	11067R	PARTICIPANT	\N	PRESENT	0
469219	467280	14223L	PARTICIPANT	\N	PRESENT	0
469221	467280	14119M	PARTICIPANT	\N	PRESENT	0
469222	467280	19679N	PARTICIPANT	\N	PRESENT	0
469223	467280	19798U	PARTICIPANT	\N	PRESENT	0
469224	467280	11097X	PARTICIPANT	\N	PRESENT	0
469225	467280	19703U	PARTICIPANT	\N	PRESENT	0
469226	467280	14227Q	PARTICIPANT	\N	PRESENT	0
469227	467280	01034P	PARTICIPANT	\N	PRESENT	0
469233	467280	04092N	PRESIDENT	0	PRESENT	0
469236	467280	08041T	PARTICIPANT	\N	EXCUSE	0
469243	467281	19575F	PARTICIPANT	\N	PRESENT	0
469244	467281	19415P	PARTICIPANT	\N	PRESENT	0
469245	467281	11103C	PARTICIPANT	\N	PRESENT	0
469246	467281	10006L	PARTICIPANT	\N	PRESENT	0
469247	467281	14042U	PARTICIPANT	\N	PRESENT	0
469249	467281	14087W	PARTICIPANT	\N	PRESENT	0
469252	467281	19565D	PARTICIPANT	\N	PRESENT	0
469254	467281	19569H	PARTICIPANT	\N	PRESENT	0
469255	467281	19591F	PARTICIPANT	\N	PRESENT	0
469256	467281	14213J	PARTICIPANT	\N	PRESENT	0
469257	467281	19723Y	PARTICIPANT	\N	PRESENT	0
469258	467281	19697Q	PARTICIPANT	\N	PRESENT	0
469259	467281	19657G	PARTICIPANT	\N	PRESENT	0
469260	467281	11067R	PARTICIPANT	\N	PRESENT	0
469261	467281	14119M	PARTICIPANT	\N	PRESENT	0
469265	467281	19679N	PARTICIPANT	\N	PRESENT	0
469268	467281	19703U	PARTICIPANT	\N	PRESENT	0
469269	467281	11097X	PRESIDENT	0	PRESENT	0
469271	467281	01034P	PARTICIPANT	\N	PRESENT	0
469283	467282	19575F	PARTICIPANT	\N	PRESENT	0
469284	467282	11103C	PARTICIPANT	\N	PRESENT	0
469285	467282	11031D	PARTICIPANT	\N	PRESENT	0
469286	467282	08052W	PARTICIPANT	\N	PRESENT	0
469287	467282	10006L	PARTICIPANT	\N	PRESENT	0
469288	467282	14217N	PARTICIPANT	\N	PRESENT	0
469289	467282	08048B	PARTICIPANT	\N	PRESENT	0
469290	467282	19565D	PARTICIPANT	\N	PRESENT	0
469291	467282	14026U	PARTICIPANT	\N	PRESENT	0
469292	467282	19569H	PARTICIPANT	\N	PRESENT	0
469293	467282	19591F	PARTICIPANT	\N	PRESENT	0
469294	467282	19723Y	PARTICIPANT	\N	PRESENT	0
469296	467282	19697Q	PARTICIPANT	\N	PRESENT	0
469297	467282	19657G	PARTICIPANT	\N	PRESENT	0
469298	467282	11067R	PARTICIPANT	\N	PRESENT	0
469301	467282	19798U	PARTICIPANT	\N	PRESENT	0
469302	467282	11045K	PARTICIPANT	\N	PRESENT	0
469307	467282	11097X	PRESIDENT	0	PRESENT	0
469357	469355	19503N	PARTICIPANT	\N	PRESENT	0
469360	469358	19503N	PARTICIPANT	\N	PRESENT	0
469368	469366	10006L	PARTICIPANT	\N	PRESENT	0
469369	469366	14213J	PARTICIPANT	\N	PRESENT	0
469370	469366	19697Q	PARTICIPANT	\N	PRESENT	0
469371	469367	10006L	PARTICIPANT	\N	PRESENT	0
469372	469367	08052W	PARTICIPANT	\N	PRESENT	0
469373	469367	14213J	PARTICIPANT	\N	PRESENT	0
469374	469367	19723Y	PARTICIPANT	\N	PRESENT	0
469375	469367	19697Q	PARTICIPANT	\N	PRESENT	0
469376	469367	11067R	PARTICIPANT	\N	PRESENT	0
469377	469367	19798U	PARTICIPANT	\N	PRESENT	0
469378	469367	11097X	PARTICIPANT	\N	PRESENT	0
469380	469379	10006L	PARTICIPANT	\N	PRESENT	0
469382	469381	10006L	PARTICIPANT	\N	PRESENT	0
469390	469264	10006L	PARTICIPANT	\N	PRESENT	0
469391	469264	14042U	PARTICIPANT	\N	PRESENT	0
469392	469264	08052W	PARTICIPANT	\N	PRESENT	0
469393	469264	19723Y	PARTICIPANT	\N	PRESENT	0
469394	469264	19657G	PARTICIPANT	\N	PRESENT	0
455491	448750	19760E	PARTICIPANT	\N	PRESENT	0
455492	448750	04038G	PARTICIPANT	\N	PRESENT	0
455493	448750	11040E	PARTICIPANT	\N	PRESENT	0
455494	448750	04085P	PARTICIPANT	\N	PRESENT	0
455495	448750	14063N	PARTICIPANT	\N	PRESENT	0
455496	448750	19782L	PARTICIPANT	\N	PRESENT	0
455497	448750	08024S	PARTICIPANT	\N	PRESENT	0
455498	448750	08073C	PARTICIPANT	\N	PRESENT	0
455499	448750	19301E	PARTICIPANT	\N	PRESENT	0
455500	448750	19443T	PARTICIPANT	\N	PRESENT	0
455501	448750	19349W	PARTICIPANT	\N	PRESENT	0
455502	448750	19709B	PARTICIPANT	\N	PRESENT	0
455503	448750	14207L	PARTICIPANT	\N	PRESENT	0
455504	448750	04088S	PARTICIPANT	\N	PRESENT	0
455505	448750	19659J	PARTICIPANT	\N	PRESENT	0
455506	448750	19269X	PARTICIPANT	\N	PRESENT	0
455507	448750	19812Y	PARTICIPANT	\N	PRESENT	0
455508	448750	14041T	PARTICIPANT	\N	PRESENT	0
455509	448750	19507S	PARTICIPANT	\N	PRESENT	0
455510	448750	14039A	PARTICIPANT	\N	PRESENT	0
455511	448750	19637C	PARTICIPANT	\N	PRESENT	0
455512	448750	07029T	PARTICIPANT	\N	PRESENT	0
455513	448750	04034C	PARTICIPANT	\N	PRESENT	0
455514	448750	14355X	PARTICIPANT	\N	PRESENT	0
455515	448750	19543W	PARTICIPANT	\N	PRESENT	0
455516	448750	08062Y	PARTICIPANT	\N	PRESENT	0
455517	448750	04045F	PARTICIPANT	\N	PRESENT	0
455518	448750	98029W	PARTICIPANT	\N	PRESENT	0
455519	448750	08015R	PARTICIPANT	\N	PRESENT	0
455520	448750	11083R	PARTICIPANT	\N	PRESENT	0
455521	448750	19729F	PARTICIPANT	\N	PRESENT	0
455522	448750	14038Y	PARTICIPANT	\N	PRESENT	0
455523	448750	19723Y	PARTICIPANT	\N	PRESENT	0
455524	448750	11099A	PARTICIPANT	\N	PRESENT	0
455525	448750	19467C	PARTICIPANT	\N	PRESENT	0
455526	448750	08061X	PARTICIPANT	\N	PRESENT	0
455527	448750	18083K	PARTICIPANT	\N	PRESENT	0
455528	448750	19415P	PARTICIPANT	\N	PRESENT	0
455529	448750	11012A	PARTICIPANT	\N	PRESENT	0
455530	448750	14033T	PARTICIPANT	\N	PRESENT	0
455531	448750	14261S	PARTICIPANT	\N	PRESENT	0
455532	448750	14201E	PARTICIPANT	\N	PRESENT	0
455533	448750	19705W	PARTICIPANT	\N	PRESENT	0
455534	448750	14034U	PARTICIPANT	\N	PRESENT	0
455535	448750	08031R	PARTICIPANT	\N	PRESENT	0
455536	448750	08019V	PARTICIPANT	\N	PRESENT	0
455537	448750	11065P	PARTICIPANT	\N	PRESENT	0
455538	448750	11072N	PARTICIPANT	\N	PRESENT	0
455539	448750	19629C	PARTICIPANT	\N	PRESENT	0
455540	448750	19253P	PARTICIPANT	\N	PRESENT	0
455541	448750	19399H	PARTICIPANT	\N	PRESENT	0
455542	448750	19719D	PARTICIPANT	\N	PRESENT	0
455543	448750	19693L	PARTICIPANT	\N	PRESENT	0
455544	448750	14241N	PARTICIPANT	\N	PRESENT	0
455545	448750	14213J	PARTICIPANT	\N	PRESENT	0
455546	448750	14173T	PARTICIPANT	\N	PRESENT	0
455547	448750	19387D	PARTICIPANT	\N	PRESENT	0
455548	448750	19447X	PARTICIPANT	\N	PRESENT	0
455549	448750	14121F	PARTICIPANT	\N	PRESENT	0
455550	448750	92040Q	PARTICIPANT	\N	PRESENT	0
455551	448750	14119M	PARTICIPANT	\N	PRESENT	0
455552	448750	19289C	PARTICIPANT	\N	PRESENT	0
455553	448750	14259Y	PARTICIPANT	\N	PRESENT	0
455554	448750	14105F	PARTICIPANT	\N	PRESENT	0
455555	448750	08047A	PARTICIPANT	\N	PRESENT	0
455556	448750	14147R	PARTICIPANT	\N	PRESENT	0
455557	448750	19591F	PARTICIPANT	\N	PRESENT	0
455558	448750	97011G	PARTICIPANT	\N	PRESENT	0
455559	448750	19703U	PARTICIPANT	\N	PRESENT	0
455560	448750	19585H	PARTICIPANT	\N	PRESENT	0
455561	448750	14093U	PARTICIPANT	\N	PRESENT	0
455562	448750	19673G	PARTICIPANT	\N	PRESENT	0
455563	448750	14251Q	PARTICIPANT	\N	PRESENT	0
455564	448750	11115U	PARTICIPANT	\N	PRESENT	0
455565	448750	95037J	PARTICIPANT	\N	PRESENT	0
455566	448750	19667J	PARTICIPANT	\N	PRESENT	0
455567	448750	14031R	PARTICIPANT	\N	PRESENT	0
455568	448750	17589D	PARTICIPANT	\N	PRESENT	0
455569	448750	14135M	PARTICIPANT	\N	PRESENT	0
455570	448750	14199E	PARTICIPANT	\N	PRESENT	0
455571	448750	19575F	PARTICIPANT	\N	PRESENT	0
455572	448750	95063L	PARTICIPANT	\N	PRESENT	0
455573	448750	14253S	PARTICIPANT	\N	PRESENT	0
455574	448750	04049K	PARTICIPANT	\N	PRESENT	0
455575	448750	14265W	PARTICIPANT	\N	PRESENT	0
455576	448750	14030Q	PARTICIPANT	\N	PRESENT	0
455577	448750	19651A	PARTICIPANT	\N	PRESENT	0
455578	448750	19515S	PARTICIPANT	\N	PRESENT	0
455579	448750	11080N	PARTICIPANT	\N	PRESENT	0
455580	448750	19766L	PARTICIPANT	\N	PRESENT	0
455581	448750	14327T	PARTICIPANT	\N	PRESENT	0
455582	448750	01057W	PARTICIPANT	\N	PRESENT	0
455583	448750	01024M	PARTICIPANT	\N	PRESENT	0
455584	448750	11053K	PARTICIPANT	\N	PRESENT	0
455585	448750	19663E	PARTICIPANT	\N	PRESENT	0
455586	448750	19521Q	PARTICIPANT	\N	PRESENT	0
455587	448750	04040A	PARTICIPANT	\N	PRESENT	0
455588	448750	11090Q	PARTICIPANT	\N	PRESENT	0
455589	448750	08028W	PARTICIPANT	\N	PRESENT	0
455590	448750	19335Q	PARTICIPANT	\N	PRESENT	0
455591	448750	01048V	PARTICIPANT	\N	PRESENT	0
455592	448750	11010L	PARTICIPANT	\N	PRESENT	0
455593	448750	08018U	PARTICIPANT	\N	PRESENT	0
455594	448750	98005N	PARTICIPANT	\N	PRESENT	0
455595	448750	11043H	PARTICIPANT	\N	PRESENT	0
455596	448750	04071H	PARTICIPANT	\N	PRESENT	0
455598	448750	19479G	PARTICIPANT	\N	PRESENT	0
455599	448750	14169X	PARTICIPANT	\N	PRESENT	0
455600	448750	19643A	PARTICIPANT	\N	PRESENT	0
455601	448750	19611R	PARTICIPANT	\N	PRESENT	0
455602	448750	15447F	PARTICIPANT	\N	PRESENT	0
455604	448750	19619A	PARTICIPANT	\N	PRESENT	0
455605	448750	19679N	PARTICIPANT	\N	PRESENT	0
455607	448750	19691J	PARTICIPANT	\N	PRESENT	0
455608	448750	04097T	PARTICIPANT	\N	PRESENT	0
455609	448750	19553Y	PARTICIPANT	\N	PRESENT	0
455611	448750	08020N	PARTICIPANT	\N	PRESENT	0
455612	448750	19369B	PARTICIPANT	\N	PRESENT	0
455613	448750	08010L	PARTICIPANT	\N	PRESENT	0
455614	448750	14123H	PARTICIPANT	\N	PRESENT	0
455615	448750	08069G	PARTICIPANT	\N	PRESENT	0
455616	448750	04042C	PARTICIPANT	\N	PRESENT	0
455617	448750	01034P	PARTICIPANT	\N	PRESENT	0
455618	448750	19441R	PARTICIPANT	\N	PRESENT	0
455619	448750	14157T	PARTICIPANT	\N	PRESENT	0
455620	448750	14219Q	PARTICIPANT	\N	PRESENT	0
455622	448750	96004D	PARTICIPANT	\N	PRESENT	0
455623	448750	19551W	PARTICIPANT	\N	PRESENT	0
455624	448750	01058X	PARTICIPANT	\N	PRESENT	0
455625	448750	99004R	PARTICIPANT	\N	PRESENT	0
455626	448750	19711U	PARTICIPANT	\N	PRESENT	0
455627	448750	01028R	PARTICIPANT	\N	PRESENT	0
455628	448750	19527W	PARTICIPANT	\N	PRESENT	0
455629	448750	11101A	PARTICIPANT	\N	PRESENT	0
455630	448750	14081Q	PARTICIPANT	\N	PRESENT	0
455631	448750	98024R	PARTICIPANT	\N	PRESENT	0
455632	448750	11041F	PARTICIPANT	\N	PRESENT	0
455633	448750	95030B	PARTICIPANT	\N	PRESENT	0
455634	448750	08060W	PARTICIPANT	\N	PRESENT	0
455635	448750	14026U	PARTICIPANT	\N	PRESENT	0
455636	448750	19747H	PARTICIPANT	\N	PRESENT	0
455637	448750	01062T	PARTICIPANT	\N	PRESENT	0
455638	448750	04044E	PARTICIPANT	\N	PRESENT	0
455639	448750	04092N	PARTICIPANT	\N	PRESENT	0
455640	448750	14021P	PARTICIPANT	\N	PRESENT	0
455641	448750	04086Q	PARTICIPANT	\N	PRESENT	0
455642	448750	08052W	PARTICIPANT	\N	PRESENT	0
455643	448750	14071N	PARTICIPANT	\N	PRESENT	0
455644	448750	98035U	PARTICIPANT	\N	PRESENT	0
455645	448750	14159V	PARTICIPANT	\N	PRESENT	0
455646	448750	05008E	PARTICIPANT	\N	PRESENT	0
455647	448750	04059M	PARTICIPANT	\N	PRESENT	0
455648	448750	11097X	PARTICIPANT	\N	PRESENT	0
455649	448750	19421M	PARTICIPANT	\N	PRESENT	0
455650	448750	80013X	PARTICIPANT	\N	PRESENT	0
455651	448750	14215L	PARTICIPANT	\N	PRESENT	0
455652	448750	14053L	PARTICIPANT	\N	PRESENT	0
455653	448750	14249W	PARTICIPANT	\N	PRESENT	0
455654	448750	11027H	PARTICIPANT	\N	PRESENT	0
455655	448750	14069U	PARTICIPANT	\N	PRESENT	0
455656	448750	08055A	PARTICIPANT	\N	PRESENT	0
455657	448750	05012A	PARTICIPANT	\N	PRESENT	0
455658	448750	08034U	PARTICIPANT	\N	PRESENT	0
455659	448750	14229S	PARTICIPANT	\N	PRESENT	0
455660	448750	19533U	PARTICIPANT	\N	PRESENT	0
455661	448750	08045X	PARTICIPANT	\N	PRESENT	0
455662	448750	14205J	PARTICIPANT	\N	PRESENT	0
455663	448750	19798U	PARTICIPANT	\N	PRESENT	0
473793	473578	19333N	PARTICIPANT	\N	PRESENT	0
473794	473578	19551W	PARTICIPANT	\N	PRESENT	0
473795	473578	19745F	PARTICIPANT	\N	PRESENT	0
473796	473578	14051J	PARTICIPANT	\N	PRESENT	0
473798	473475	19681G	PARTICIPANT	\N	PRESENT	0
473799	473475	19551W	PARTICIPANT	\N	PRESENT	0
473800	473475	19637C	PARTICIPANT	\N	PRESENT	0
473801	473475	14169X	PARTICIPANT	\N	PRESENT	0
473802	473475	19347U	PARTICIPANT	\N	PRESENT	0
473803	473475	19820Y	PARTICIPANT	\N	PRESENT	0
473804	473475	19333N	PARTICIPANT	\N	PRESENT	0
473805	473475	19794Q	PARTICIPANT	\N	PRESENT	0
473806	473475	19739H	PARTICIPANT	\N	PRESENT	0
473807	473452	18083K	PARTICIPANT	\N	PRESENT	0
473808	473442	14219Q	PARTICIPANT	\N	PRESENT	0
473809	473442	14169X	PARTICIPANT	\N	PRESENT	0
473810	473442	17583W	PARTICIPANT	\N	PRESENT	0
473811	473442	08024S	PARTICIPANT	\N	PRESENT	0
473812	473442	19794Q	PARTICIPANT	\N	PRESENT	0
473813	473442	19347U	PARTICIPANT	\N	PRESENT	0
473814	473442	19820Y	PARTICIPANT	\N	PRESENT	0
473815	473442	19739H	PARTICIPANT	\N	PRESENT	0
473816	473442	19333N	PARTICIPANT	\N	PRESENT	0
473817	473442	19599P	PARTICIPANT	\N	PRESENT	0
473818	473442	19737F	PARTICIPANT	\N	PRESENT	0
473819	473442	19713W	PARTICIPANT	\N	PRESENT	0
473820	473442	19551W	PARTICIPANT	\N	PRESENT	0
473821	473567	19347U	PARTICIPANT	\N	PRESENT	0
473822	473567	14221J	PARTICIPANT	\N	PRESENT	0
473823	473567	14051J	PARTICIPANT	\N	PRESENT	0
473824	473567	19333N	PARTICIPANT	\N	PRESENT	0
473865	473569	19347U	PARTICIPANT	\N	PRESENT	0
473866	473569	14221J	PARTICIPANT	\N	PRESENT	0
473867	473569	14051J	PARTICIPANT	\N	PRESENT	0
473868	473569	02002K	PARTICIPANT	\N	PRESENT	0
473869	473569	14029X	PARTICIPANT	\N	PRESENT	0
473870	473569	19387D	PARTICIPANT	\N	PRESENT	0
473871	473569	19820Y	PARTICIPANT	\N	PRESENT	0
473872	473569	19333N	PARTICIPANT	\N	PRESENT	0
473876	473570	19347U	PARTICIPANT	\N	PRESENT	0
473877	473570	14221J	PARTICIPANT	\N	PRESENT	0
473878	473570	14051J	PARTICIPANT	\N	PRESENT	0
473879	473570	14029X	PARTICIPANT	\N	PRESENT	0
473880	473570	02002K	PARTICIPANT	\N	PRESENT	0
473881	473570	19333N	PARTICIPANT	\N	PRESENT	0
473882	473570	19794Q	PARTICIPANT	\N	PRESENT	0
473883	473476	14031R	PARTICIPANT	\N	PRESENT	0
473884	473476	19551W	PARTICIPANT	\N	PRESENT	0
473885	473476	19713W	PARTICIPANT	\N	PRESENT	0
473886	473476	19737F	PARTICIPANT	\N	PRESENT	0
473887	473476	19794Q	PARTICIPANT	\N	PRESENT	0
473888	473476	19637C	PARTICIPANT	\N	PRESENT	0
473889	473476	19820Y	PARTICIPANT	\N	PRESENT	0
473890	473476	19347U	PARTICIPANT	\N	PRESENT	0
473891	473476	17583W	PARTICIPANT	\N	PRESENT	0
473892	473476	14029X	PARTICIPANT	\N	PRESENT	0
473941	473477	19681G	PARTICIPANT	\N	PRESENT	0
473942	473477	02002K	PARTICIPANT	\N	PRESENT	0
473943	473477	19794Q	PARTICIPANT	\N	PRESENT	0
473944	473477	19637C	PARTICIPANT	\N	PRESENT	0
473945	473477	18083K	PARTICIPANT	\N	PRESENT	0
473946	473477	14219Q	PARTICIPANT	\N	PRESENT	0
473947	473477	19333N	PARTICIPANT	\N	PRESENT	0
473948	473477	19739H	PARTICIPANT	\N	PRESENT	0
473949	473477	19549D	PARTICIPANT	\N	PRESENT	0
473951	473950	14093U	PARTICIPANT	\N	PRESENT	0
473952	473950	19503N	PARTICIPANT	\N	PRESENT	0
473953	473950	19637C	PARTICIPANT	\N	PRESENT	0
473954	473950	19701S	PARTICIPANT	\N	PRESENT	0
473955	473950	11065P	PARTICIPANT	\N	PRESENT	0
473956	473453	18083K	PARTICIPANT	\N	PRESENT	0
473957	473453	19387D	PARTICIPANT	\N	PRESENT	0
473958	473453	19794Q	PARTICIPANT	\N	PRESENT	0
473990	473453	19820Y	PARTICIPANT	\N	PRESENT	0
473991	473453	19333N	PARTICIPANT	\N	PRESENT	0
473992	473453	19713W	PARTICIPANT	\N	PRESENT	0
473994	473453	19745F	PARTICIPANT	\N	PRESENT	0
473995	473453	14169X	PARTICIPANT	\N	PRESENT	0
473996	473453	19737F	PARTICIPANT	\N	PRESENT	0
474004	473454	18083K	PARTICIPANT	\N	PRESENT	0
474005	473454	19794Q	PARTICIPANT	\N	PRESENT	0
474006	473454	19387D	PARTICIPANT	\N	PRESENT	0
474007	473454	04069P	PARTICIPANT	\N	PRESENT	0
474018	473443	14219Q	PARTICIPANT	\N	PRESENT	0
474019	473443	14169X	PARTICIPANT	\N	PRESENT	0
474021	473443	19387D	PARTICIPANT	\N	PRESENT	0
474023	473443	19745F	PARTICIPANT	\N	PRESENT	0
474024	473443	19737F	PARTICIPANT	\N	PRESENT	0
474030	473455	18083K	PARTICIPANT	\N	PRESENT	0
474031	473455	19745F	PARTICIPANT	\N	PRESENT	0
474032	473455	19820Y	PARTICIPANT	\N	PRESENT	0
474033	473455	19347U	PARTICIPANT	\N	PRESENT	0
474034	473455	19333N	PARTICIPANT	\N	PRESENT	0
474035	473455	19737F	PARTICIPANT	\N	PRESENT	0
474036	473455	19387D	PARTICIPANT	\N	PRESENT	0
474037	473455	19503N	PARTICIPANT	\N	PRESENT	0
474038	473455	11065P	PARTICIPANT	\N	PRESENT	0
474039	473455	14029X	PARTICIPANT	\N	PRESENT	0
474046	473456	18083K	PARTICIPANT	\N	PRESENT	0
474047	473456	19820Y	PARTICIPANT	\N	PRESENT	0
474048	473456	19713W	PARTICIPANT	\N	PRESENT	0
474049	473456	19347U	PARTICIPANT	\N	PRESENT	0
474050	473456	19387D	PARTICIPANT	\N	PRESENT	0
474052	473456	19737F	PARTICIPANT	\N	PRESENT	0
474054	473398	19637C	PARTICIPANT	\N	PRESENT	0
474055	473398	14051J	PARTICIPANT	\N	PRESENT	0
474056	473398	19713W	PARTICIPANT	\N	PRESENT	0
474057	473398	19745F	PARTICIPANT	\N	PRESENT	0
474058	473398	19347U	PARTICIPANT	\N	PRESENT	0
474059	473398	19333N	PARTICIPANT	\N	PRESENT	0
474060	473398	14219Q	PARTICIPANT	\N	PRESENT	0
474061	473398	14157T	PARTICIPANT	\N	PRESENT	0
474062	473398	19387D	PARTICIPANT	\N	PRESENT	0
474063	473398	19383Y	PARTICIPANT	\N	PRESENT	0
474064	473398	19737F	PARTICIPANT	\N	PRESENT	0
474065	473398	14029X	PARTICIPANT	\N	PRESENT	0
474066	473398	18083K	PARTICIPANT	\N	PRESENT	0
474067	473400	19637C	PARTICIPANT	\N	PRESENT	0
474068	473400	14051J	PARTICIPANT	\N	PRESENT	0
474069	473400	19713W	PARTICIPANT	\N	PRESENT	0
474071	473400	19745F	PARTICIPANT	\N	PRESENT	0
474072	473400	19347U	PARTICIPANT	\N	PRESENT	0
474073	473400	19333N	PARTICIPANT	\N	PRESENT	0
474075	473400	14219Q	PARTICIPANT	\N	PRESENT	0
474076	473400	19387D	PARTICIPANT	\N	PRESENT	0
474077	473400	19383Y	PARTICIPANT	\N	PRESENT	0
474078	473400	19737F	PARTICIPANT	\N	PRESENT	0
474079	473400	14029X	PARTICIPANT	\N	PRESENT	0
474080	473400	18083K	PARTICIPANT	\N	PRESENT	0
474081	473411	19637C	PARTICIPANT	\N	PRESENT	0
474082	473411	14051J	PARTICIPANT	\N	PRESENT	0
474083	473411	17583W	PARTICIPANT	\N	PRESENT	0
474084	473411	14157T	PARTICIPANT	\N	PRESENT	0
474085	473411	19739H	PARTICIPANT	\N	PRESENT	0
474086	473411	14219Q	PARTICIPANT	\N	PRESENT	0
474087	473411	08024S	PARTICIPANT	\N	PRESENT	0
474088	473411	18083K	PARTICIPANT	\N	PRESENT	0
474089	473411	19347U	PARTICIPANT	\N	PRESENT	0
474090	473411	19737F	PARTICIPANT	\N	PRESENT	0
474091	473411	19713W	PARTICIPANT	\N	PRESENT	0
474092	473411	14029X	PARTICIPANT	\N	PRESENT	0
474094	473411	19745F	PARTICIPANT	\N	PRESENT	0
474095	473411	14169X	PARTICIPANT	\N	PRESENT	0
474193	474192	14179A	PARTICIPANT	\N	PRESENT	0
474194	474192	14021P	PARTICIPANT	\N	PRESENT	0
474221	474220	19673G	PARTICIPANT	\N	PRESENT	0
474222	474220	04040A	PARTICIPANT	\N	PRESENT	0
474223	474220	19585H	PARTICIPANT	\N	PRESENT	0
474224	474220	08053X	PARTICIPANT	\N	PRESENT	0
474225	474220	04044E	PARTICIPANT	\N	PRESENT	0
474347	473215	19798U	PARTICIPANT	\N	PRESENT	0
474348	473215	08049C	PARTICIPANT	\N	PRESENT	0
474349	473215	19335Q	PRESIDENT	0	PRESENT	0
474350	473215	19575F	PARTICIPANT	\N	PRESENT	0
474398	473215	14026U	PARTICIPANT	\N	PRESENT	0
474549	473366	19798U	PARTICIPANT	\N	PRESENT	0
474550	473366	19619A	PARTICIPANT	\N	PRESENT	0
474553	473366	19503N	PARTICIPANT	\N	PRESENT	0
474554	473366	19387D	PARTICIPANT	\N	PRESENT	0
474555	473366	19575F	PARTICIPANT	\N	PRESENT	0
474556	473366	19631V	PARTICIPANT	\N	PRESENT	0
474559	474552	19629C	PARTICIPANT	\N	PRESENT	0
474560	474552	14267Y	PARTICIPANT	\N	PRESENT	0
474561	474552	19525U	PARTICIPANT	\N	PRESENT	0
474562	474552	04086Q	PARTICIPANT	\N	PRESENT	0
474563	474552	14217N	PARTICIPANT	\N	PRESENT	0
474564	474552	19695N	PARTICIPANT	\N	PRESENT	0
474565	474552	11064N	PARTICIPANT	\N	PRESENT	0
474566	474552	19715Y	PARTICIPANT	\N	PRESENT	0
456787	456707	14111D	PARTICIPANT	\N	PRESENT	0
456788	456707	01024M	PARTICIPANT	\N	PRESENT	0
456789	456707	04044E	PARTICIPANT	\N	PRESENT	0
456790	456707	19585H	PARTICIPANT	\N	PRESENT	0
456791	456707	01028R	PARTICIPANT	\N	PRESENT	0
456792	456707	19447X	PARTICIPANT	\N	PRESENT	0
456793	456707	14231L	PARTICIPANT	\N	PRESENT	0
456794	456707	05008E	PRESIDENT	0	PRESENT	0
456795	456707	19489J	PARTICIPANT	\N	PRESENT	0
456796	456707	19629C	PARTICIPANT	\N	PRESENT	0
456797	456707	14041T	PARTICIPANT	\N	PRESENT	0
456798	456707	14147R	PARTICIPANT	\N	PRESENT	0
456799	456707	14151M	PARTICIPANT	\N	PRESENT	0
456800	456707	14215L	PARTICIPANT	\N	PRESENT	0
456801	456707	14089Y	PARTICIPANT	\N	PRESENT	0
456968	448755	11010L	PARTICIPANT	\N	PRESENT	0
456969	448755	14249W	PARTICIPANT	\N	PRESENT	0
456970	448755	08028W	PARTICIPANT	\N	PRESENT	0
456971	448755	14231L	PARTICIPANT	\N	PRESENT	0
456972	448755	14225N	PARTICIPANT	\N	PRESENT	0
456973	448755	19619A	PARTICIPANT	\N	PRESENT	0
456974	455105	08056B	PRESIDENT	0	PRESENT	0
456975	455105	07004J	PARTICIPANT	\N	PRESENT	0
456976	455105	08053X	PARTICIPANT	\N	PRESENT	0
456977	455105	19671E	PARTICIPANT	\N	PRESENT	0
456978	455105	19673G	PARTICIPANT	\N	PRESENT	0
456979	455105	19721W	PARTICIPANT	\N	PRESENT	0
456980	455105	19719D	PARTICIPANT	\N	EXCUSE	0
457118	448755	11056N	PARTICIPANT	\N	PRESENT	0
456982	448755	11043H	PARTICIPANT	\N	PRESENT	0
456983	448755	19631V	PARTICIPANT	\N	PRESENT	0
456984	448755	19479G	PARTICIPANT	\N	PRESENT	0
456985	448755	14251Q	PARTICIPANT	\N	PRESENT	0
456986	448755	11085T	PARTICIPANT	\N	PRESENT	0
457113	448755	11097X	PARTICIPANT	\N	PRESENT	0
457114	448755	19399H	PARTICIPANT	\N	PRESENT	0
457119	456666	19333N	PARTICIPANT	\N	PRESENT	0
457120	456666	17583W	PARTICIPANT	\N	PRESENT	0
457121	456666	19794Q	PARTICIPANT	\N	PRESENT	0
457122	456666	14031R	PARTICIPANT	\N	PRESENT	0
457123	456666	19549D	PARTICIPANT	\N	PRESENT	0
457124	456666	14219Q	PARTICIPANT	\N	PRESENT	0
457125	456666	19820Y	PARTICIPANT	\N	PRESENT	0
457126	456666	19826F	PARTICIPANT	\N	PRESENT	0
457127	456666	19599P	PARTICIPANT	\N	PRESENT	0
457128	456666	14169X	PARTICIPANT	\N	PRESENT	0
457129	456666	18083K	PARTICIPANT	\N	PRESENT	0
457130	456666	14093U	PARTICIPANT	\N	PRESENT	0
457131	456666	14051J	PARTICIPANT	\N	PRESENT	0
457132	456666	08009T	PRESIDENT	0	PRESENT	0
457133	456666	19503N	PARTICIPANT	\N	PRESENT	0
457134	456666	19737F	PARTICIPANT	\N	PRESENT	0
457135	456666	04097T	PARTICIPANT	\N	PRESENT	0
457136	456666	14157T	PARTICIPANT	\N	PRESENT	0
457137	456666	19745F	PARTICIPANT	\N	PRESENT	0
457138	456666	08024S	PARTICIPANT	\N	PRESENT	0
457139	456666	11065P	PARTICIPANT	\N	PRESENT	0
457140	456666	19551W	PARTICIPANT	\N	EXCUSE	0
457141	456666	19701S	PARTICIPANT	\N	EXCUSE	0
457142	456666	02002K	PARTICIPANT	\N	PRESENT	0
458818	458815	19709B	PARTICIPANT	\N	PRESENT	0
458820	458815	11027H	PARTICIPANT	\N	PRESENT	0
458829	458828	19709B	PARTICIPANT	\N	PRESENT	0
458830	458828	11027H	PARTICIPANT	\N	PRESENT	0
462173	458657	14231L	PARTICIPANT	\N	EXCUSE	0
462279	462270	19673G	PARTICIPANT	\N	PRESENT	0
462280	462270	08010L	PARTICIPANT	\N	PRESENT	0
462440	462439	14147R	PARTICIPANT	\N	PRESENT	0
462442	462441	14147R	PARTICIPANT	\N	PRESENT	0
464914	464202	14195A	PARTICIPANT	\N	EXCUSE	0
464915	464202	19663E	PARTICIPANT	\N	EXCUSE	0
464916	464202	98024R	PARTICIPANT	\N	EXCUSE	0
464917	464202	10006L	PARTICIPANT	\N	EXCUSE	0
464918	464202	14355X	PARTICIPANT	\N	EXCUSE	0
464919	464202	08048B	PARTICIPANT	\N	EXCUSE	0
464920	464202	08041T	PARTICIPANT	\N	EXCUSE	0
464921	464202	19691J	PARTICIPANT	\N	EXCUSE	0
464922	464202	19553Y	PARTICIPANT	\N	EXCUSE	0
464923	464202	19591F	PARTICIPANT	\N	EXCUSE	0
464924	464202	14213J	PARTICIPANT	\N	EXCUSE	0
464925	464202	19683J	PARTICIPANT	\N	EXCUSE	0
464926	464202	19657G	PARTICIPANT	\N	EXCUSE	0
464927	464202	14223L	PARTICIPANT	\N	EXCUSE	0
464928	464202	14119M	PARTICIPANT	\N	EXCUSE	0
464929	464202	11045K	PARTICIPANT	\N	EXCUSE	0
464930	464202	19703U	PARTICIPANT	\N	EXCUSE	0
464931	464202	19301E	PARTICIPANT	\N	EXCUSE	0
464932	464202	14227Q	PARTICIPANT	\N	EXCUSE	0
464933	464202	01034P	PARTICIPANT	\N	EXCUSE	0
464934	464203	14239U	PARTICIPANT	\N	EXCUSE	0
464935	464203	14261S	PARTICIPANT	\N	EXCUSE	0
464936	464203	19717B	PARTICIPANT	\N	EXCUSE	0
464937	464203	19367Y	PARTICIPANT	\N	EXCUSE	0
464938	464203	14195A	PARTICIPANT	\N	EXCUSE	0
464939	464203	11031D	PARTICIPANT	\N	EXCUSE	0
464940	464203	98024R	PARTICIPANT	\N	EXCUSE	0
464941	464203	19521Q	PARTICIPANT	\N	EXCUSE	0
464942	464203	08048B	PARTICIPANT	\N	EXCUSE	0
464943	464203	14026U	PARTICIPANT	\N	EXCUSE	0
464944	464203	19553Y	PARTICIPANT	\N	EXCUSE	0
464945	464203	19591F	PARTICIPANT	\N	EXCUSE	0
464946	464203	19683J	PARTICIPANT	\N	EXCUSE	0
464947	464203	19697Q	PARTICIPANT	\N	EXCUSE	0
464948	464203	11067R	PARTICIPANT	\N	EXCUSE	0
464949	464203	19703U	PARTICIPANT	\N	EXCUSE	0
464950	464203	19301E	PARTICIPANT	\N	EXCUSE	0
464951	464203	01034P	PARTICIPANT	\N	EXCUSE	0
465108	465107	14001X	PARTICIPANT	\N	PRESENT	0
465109	465107	19581D	PARTICIPANT	\N	PRESENT	0
465110	465107	04044E	PARTICIPANT	\N	PRESENT	0
465111	465107	19585H	PARTICIPANT	\N	PRESENT	0
465112	465107	19673G	PARTICIPANT	\N	PRESENT	0
465113	465107	19675J	PARTICIPANT	\N	PRESENT	0
465114	465107	01028R	PARTICIPANT	\N	PRESENT	0
465115	465107	19447X	PARTICIPANT	\N	PRESENT	0
465116	465107	05008E	PRESIDENT	0	PRESENT	0
465117	465107	19489J	PARTICIPANT	\N	PRESENT	0
465118	465107	14041T	PARTICIPANT	\N	PRESENT	0
465119	465107	14147R	PARTICIPANT	\N	PRESENT	0
465120	465107	14151M	PARTICIPANT	\N	PRESENT	0
465121	465107	14215L	PARTICIPANT	\N	PRESENT	0
465122	465107	08018U	PARTICIPANT	\N	PRESENT	0
465123	465107	11072N	PARTICIPANT	\N	PRESENT	0
465124	465107	14053L	PARTICIPANT	\N	PRESENT	0
465125	465107	14111D	PARTICIPANT	\N	PRESENT	0
465126	465107	19649G	PARTICIPANT	\N	PRESENT	0
465127	465107	14065Q	PARTICIPANT	\N	PRESENT	0
465128	465107	11026G	PARTICIPANT	\N	PRESENT	0
465129	465107	08045X	PARTICIPANT	\N	PRESENT	0
465130	465107	10015M	PARTICIPANT	\N	PRESENT	0
465131	465107	19253P	PARTICIPANT	\N	PRESENT	0
465132	465107	01024M	PARTICIPANT	\N	PRESENT	0
465133	465107	11033F	PARTICIPANT	\N	PRESENT	0
465134	465107	19629C	PARTICIPANT	\N	PRESENT	0
465135	465107	08044W	PARTICIPANT	\N	PRESENT	0
465136	465107	14069U	PARTICIPANT	\N	PRESENT	0
465137	465107	19762G	PARTICIPANT	\N	PRESENT	0
465138	465107	14231L	PARTICIPANT	\N	PRESENT	0
465139	465107	19719D	PARTICIPANT	\N	PRESENT	0
465140	465107	14021P	PARTICIPANT	\N	PRESENT	0
465141	465107	14179A	PARTICIPANT	\N	PRESENT	0
465142	465107	14259Y	PARTICIPANT	\N	PRESENT	0
465143	465107	04008A	PARTICIPANT	\N	PRESENT	0
465144	465107	95063L	PARTICIPANT	\N	PRESENT	0
465177	465176	05012A	PARTICIPANT	\N	PRESENT	0
465178	465176	14159V	PARTICIPANT	\N	PRESENT	0
465179	465176	11053K	PARTICIPANT	\N	PRESENT	0
465183	465182	98018T	PARTICIPANT	\N	PRESENT	0
465184	465182	11041F	PARTICIPANT	\N	PRESENT	0
465185	465182	19669L	PARTICIPANT	\N	PRESENT	0
465186	465182	14073Q	PARTICIPANT	\N	PRESENT	0
465188	465187	04040A	PRESIDENT	0	PRESENT	0
465189	465187	14069U	PARTICIPANT	\N	PRESENT	0
465190	465187	19253P	PARTICIPANT	\N	PRESENT	0
465191	465187	14195A	PARTICIPANT	\N	EXCUSE	0
465192	465187	14259Y	PARTICIPANT	\N	PRESENT	0
465193	465187	08038Y	PARTICIPANT	\N	PRESENT	0
465194	465187	14327T	PARTICIPANT	\N	PRESENT	0
465195	465187	14231L	PARTICIPANT	\N	PRESENT	0
465196	465187	01057W	PARTICIPANT	\N	PRESENT	0
465197	465187	19489J	PARTICIPANT	\N	PRESENT	0
465198	465187	08010L	PARTICIPANT	\N	PRESENT	0
465199	465187	19687N	PARTICIPANT	\N	PRESENT	0
465202	465200	04040A	PRESIDENT	0	PRESENT	0
465203	465200	14069U	PARTICIPANT	\N	PRESENT	0
465204	465200	11101A	PARTICIPANT	\N	PRESENT	0
465205	465200	14195A	PARTICIPANT	\N	PRESENT	0
465206	465200	19253P	PARTICIPANT	\N	PRESENT	0
465207	465200	04086Q	PARTICIPANT	\N	PRESENT	0
465208	465200	14259Y	PARTICIPANT	\N	PRESENT	0
469395	469264	04092N	PARTICIPANT	\N	PRESENT	0
469396	469264	11097X	PARTICIPANT	\N	PRESENT	0
469397	469282	10006L	PARTICIPANT	\N	PRESENT	0
469398	469282	08052W	PARTICIPANT	\N	PRESENT	0
469399	469282	14042U	PARTICIPANT	\N	PRESENT	0
469402	469282	19723Y	PARTICIPANT	\N	PRESENT	0
469403	469282	19657G	PARTICIPANT	\N	PRESENT	0
469404	469282	04092N	PARTICIPANT	\N	PRESENT	0
469406	469282	11097X	PARTICIPANT	\N	PRESENT	0
469409	469303	10006L	PARTICIPANT	\N	PRESENT	0
469411	469303	19575F	PARTICIPANT	\N	PRESENT	0
469413	469303	19553Y	PARTICIPANT	\N	PRESENT	0
469416	469303	19723Y	PARTICIPANT	\N	PRESENT	0
469417	469303	19697Q	PARTICIPANT	\N	PRESENT	0
469419	469303	19798U	PARTICIPANT	\N	PRESENT	0
469420	469303	19703U	PARTICIPANT	\N	PRESENT	0
469423	469310	10006L	PARTICIPANT	\N	PRESENT	0
469424	469310	19575F	PARTICIPANT	\N	PRESENT	0
469425	469310	11031D	PARTICIPANT	\N	PRESENT	0
469426	469310	19723Y	PARTICIPANT	\N	PRESENT	0
469427	469310	19697Q	PARTICIPANT	\N	PRESENT	0
469428	469310	19657G	PARTICIPANT	\N	PRESENT	0
469429	469310	19703U	PARTICIPANT	\N	PRESENT	0
469430	469310	19798U	PARTICIPANT	\N	PRESENT	0
469431	469311	10006L	PARTICIPANT	\N	PRESENT	0
469432	469311	19575F	PARTICIPANT	\N	PRESENT	0
469433	469311	14042U	PARTICIPANT	\N	PRESENT	0
469434	469311	19723Y	PARTICIPANT	\N	PRESENT	0
469435	469311	19657G	PARTICIPANT	\N	PRESENT	0
469492	469491	04047H	PARTICIPANT	\N	PRESENT	0
469493	469491	19719D	PARTICIPANT	\N	PRESENT	0
469494	469491	19649G	PARTICIPANT	\N	PRESENT	0
469495	469491	11026G	PARTICIPANT	\N	PRESENT	0
469496	469491	14147R	PARTICIPANT	\N	PRESENT	0
469506	469505	04047H	PARTICIPANT	\N	PRESENT	0
469507	469505	19719D	PARTICIPANT	\N	PRESENT	0
469508	469505	11026G	PARTICIPANT	\N	PRESENT	0
469589	469588	04047H	PARTICIPANT	\N	PRESENT	0
469590	469588	19719D	PARTICIPANT	\N	PRESENT	0
469627	469624	19760E	PARTICIPANT	\N	PRESENT	0
469628	469624	19415P	PARTICIPANT	\N	PRESENT	0
469629	469624	11067R	PARTICIPANT	\N	PRESENT	0
469630	469626	19415P	PARTICIPANT	\N	PRESENT	0
469631	469625	05008E	PARTICIPANT	\N	PRESENT	0
469632	469625	14147R	PARTICIPANT	\N	PRESENT	0
469633	469625	19673G	PARTICIPANT	\N	PRESENT	0
469634	469625	19447X	PARTICIPANT	\N	PRESENT	0
469720	468731	19251M	PARTICIPANT	\N	PRESENT	0
469769	468946	14231L	PARTICIPANT	\N	EXCUSE	0
469772	468946	01057W	PARTICIPANT	\N	EXCUSE	0
469774	468946	19687N	PARTICIPANT	\N	EXCUSE	0
469886	468946	08049C	PARTICIPANT	\N	PRESENT	0
470264	466411	08043V	PARTICIPANT	\N	PRESENT	0
470272	466411	19693L	PARTICIPANT	\N	PRESENT	0
470281	466411	08031R	PARTICIPANT	\N	PRESENT	0
470356	468946	14259Y	PARTICIPANT	\N	PRESENT	0
470357	468946	14327T	PARTICIPANT	\N	PRESENT	0
470358	468946	11110B	PARTICIPANT	\N	PRESENT	0
470359	468946	14281W	PARTICIPANT	\N	PRESENT	0
470360	468946	19820Y	PARTICIPANT	\N	PRESENT	0
470361	468946	14071N	PARTICIPANT	\N	PRESENT	0
470362	468946	14257W	PARTICIPANT	\N	PRESENT	0
470363	468946	11101A	PARTICIPANT	\N	PRESENT	0
470364	468946	14069U	PARTICIPANT	\N	PRESENT	0
470365	468946	08010L	PARTICIPANT	\N	PRESENT	0
470366	468946	08038Y	PARTICIPANT	\N	PRESENT	0
470367	468946	04045F	PARTICIPANT	\N	PRESENT	0
470368	468946	11048N	PARTICIPANT	\N	EXCUSE	0
470369	468946	19489J	PARTICIPANT	\N	PRESENT	0
470370	468946	19565D	PARTICIPANT	\N	PRESENT	0
470371	468946	95067Q	PARTICIPANT	\N	PRESENT	0
470372	468946	19735D	PARTICIPANT	\N	PRESENT	0
470373	468946	05012A	PARTICIPANT	\N	PRESENT	0
470375	470374	01048V	PARTICIPANT	\N	PRESENT	0
470376	470374	19533U	PARTICIPANT	\N	PRESENT	0
470377	470374	19593H	PARTICIPANT	\N	PRESENT	0
470378	470374	14221J	PARTICIPANT	\N	PRESENT	0
470379	470374	14093U	PARTICIPANT	\N	PRESENT	0
470380	470374	19723Y	PARTICIPANT	\N	PRESENT	0
470381	470374	01058X	PARTICIPANT	\N	PRESENT	0
470433	470401	14021P	PARTICIPANT	\N	PRESENT	0
470434	470401	14215L	PARTICIPANT	\N	PRESENT	0
470473	470167	05008E	PARTICIPANT	\N	PRESENT	0
470474	470167	14147R	PARTICIPANT	\N	PRESENT	0
470475	470167	19447X	PARTICIPANT	\N	PRESENT	0
470476	470178	05008E	PARTICIPANT	\N	PRESENT	0
470477	470178	14147R	PARTICIPANT	\N	PRESENT	0
470478	470178	19447X	PARTICIPANT	\N	PRESENT	0
470479	470178	01024M	PARTICIPANT	\N	PRESENT	0
470482	470221	05008E	PARTICIPANT	\N	PRESENT	0
470483	470221	14147R	PARTICIPANT	\N	PRESENT	0
470484	470221	19447X	PARTICIPANT	\N	PRESENT	0
470485	470221	01024M	PARTICIPANT	\N	PRESENT	0
470491	470489	96004D	PRESIDENT	0	PRESENT	0
470493	470489	14079W	PARTICIPANT	\N	PRESENT	0
470494	470489	11083R	PARTICIPANT	\N	PRESENT	0
470495	470489	14033T	PARTICIPANT	\N	PRESENT	0
470496	470489	19569H	PARTICIPANT	\N	PRESENT	0
470497	470489	04097T	PARTICIPANT	\N	PRESENT	0
470498	470489	08044W	PARTICIPANT	\N	PRESENT	0
470499	470489	14097Y	PARTICIPANT	\N	PRESENT	0
470500	470489	14073Q	PARTICIPANT	\N	PRESENT	0
470501	470489	12041X	PARTICIPANT	\N	PRESENT	0
470502	470489	11026G	PARTICIPANT	\N	PRESENT	0
470503	470489	14001X	PARTICIPANT	\N	PRESENT	0
470504	470489	14221J	PARTICIPANT	\N	PRESENT	0
470505	470489	19563B	PARTICIPANT	\N	PRESENT	0
470507	470489	98035U	PARTICIPANT	\N	PRESENT	0
470508	470489	14241N	PARTICIPANT	\N	PRESENT	0
470509	470489	95037J	PARTICIPANT	\N	PRESENT	0
470510	470489	14249W	PARTICIPANT	\N	PRESENT	0
470511	470489	10015M	PARTICIPANT	\N	PRESENT	0
470512	470489	14229S	PARTICIPANT	\N	PRESENT	0
470513	470489	14331P	PARTICIPANT	\N	PRESENT	0
470514	470489	08039A	PARTICIPANT	\N	PRESENT	0
470550	467701	14059S	PARTICIPANT	\N	PRESENT	0
470551	467701	19735D	PARTICIPANT	\N	PRESENT	0
470552	467701	08043V	PARTICIPANT	\N	PRESENT	0
470553	467701	19399H	PARTICIPANT	\N	PRESENT	0
470554	467701	08031R	PARTICIPANT	\N	PRESENT	0
470555	467687	19533U	PARTICIPANT	\N	PRESENT	0
470556	467687	19593H	PARTICIPANT	\N	PRESENT	0
470557	467685	19593H	PARTICIPANT	\N	PRESENT	0
470558	467685	19533U	PARTICIPANT	\N	PRESENT	0
470574	470573	01028R	PARTICIPANT	\N	PRESENT	0
470575	470573	19673G	PARTICIPANT	\N	PRESENT	0
470576	470573	14147R	PARTICIPANT	\N	PRESENT	0
470577	470573	14215L	PARTICIPANT	\N	PRESENT	0
470582	470580	19711U	PARTICIPANT	\N	PRESENT	0
470596	470595	19643A	PARTICIPANT	\N	PRESENT	0
470597	470595	14241N	PARTICIPANT	\N	PRESENT	0
470598	470595	08012N	PARTICIPANT	\N	PRESENT	0
470599	470595	11043H	PARTICIPANT	\N	PRESENT	0
470600	470595	14073Q	PARTICIPANT	\N	PRESENT	0
470601	470595	14249W	PARTICIPANT	\N	PRESENT	0
470603	470602	19693L	PARTICIPANT	\N	PRESENT	0
470604	470602	19533U	PARTICIPANT	\N	PRESENT	0
470605	470602	19593H	PARTICIPANT	\N	PRESENT	0
470607	470606	11083R	PARTICIPANT	\N	PRESENT	0
470608	470606	19399H	PARTICIPANT	\N	PRESENT	0
470609	470606	08039A	PARTICIPANT	\N	PRESENT	0
470610	470606	04059M	PARTICIPANT	\N	PRESENT	0
470611	470606	14251Q	PARTICIPANT	\N	PRESENT	0
470620	469282	14217N	PARTICIPANT	\N	PRESENT	0
470621	469311	19415P	PARTICIPANT	\N	PRESENT	0
470952	470492	19545Y	PARTICIPANT	\N	EXCUSE	0
470953	470492	08049C	PARTICIPANT	\N	PRESENT	0
470954	470492	19335Q	PRESIDENT	0	PRESENT	0
470974	470492	14038Y	PARTICIPANT	\N	EXCUSE	0
470976	470975	08049C	PARTICIPANT	\N	PRESENT	0
470977	470975	19335Q	PARTICIPANT	\N	PRESENT	0
471003	470492	19387D	PARTICIPANT	\N	PRESENT	0
471004	470492	19503N	PARTICIPANT	\N	PRESENT	0
471005	470492	14026U	PARTICIPANT	\N	PRESENT	0
471006	470492	19619A	PARTICIPANT	\N	PRESENT	0
471008	470492	19575F	PARTICIPANT	\N	PRESENT	0
471009	470492	19798U	PARTICIPANT	\N	PRESENT	0
471010	470492	19515S	PARTICIPANT	\N	PRESENT	0
471011	470492	11083R	PARTICIPANT	\N	PRESENT	0
471012	470492	14069U	PARTICIPANT	\N	PRESENT	0
471013	470492	19489J	PARTICIPANT	\N	PRESENT	0
471366	471364	19503N	PARTICIPANT	\N	PRESENT	0
471401	471173	99004R	PRESIDENT	0	PRESENT	0
471402	471173	08045X	PARTICIPANT	\N	PRESENT	0
455664	448750	11109J	PARTICIPANT	\N	PRESENT	0
455665	448750	14331P	PARTICIPANT	\N	PRESENT	0
455666	448750	19669L	PARTICIPANT	\N	PRESENT	0
455667	448750	14193X	PARTICIPANT	\N	PRESENT	0
455668	448750	14079W	PARTICIPANT	\N	PRESENT	0
455669	448750	14257W	PARTICIPANT	\N	PRESENT	0
455670	448750	19671E	PARTICIPANT	\N	PRESENT	0
455671	448750	04069P	PARTICIPANT	\N	PRESENT	0
455672	448750	14217N	PARTICIPANT	\N	PRESENT	0
455673	448750	07033P	PARTICIPANT	\N	PRESENT	0
455674	448750	14225N	PARTICIPANT	\N	PRESENT	0
455675	448750	11103C	PARTICIPANT	\N	PRESENT	0
455676	448750	19295A	PARTICIPANT	\N	PRESENT	0
455677	448750	08038Y	PARTICIPANT	\N	PRESENT	0
455678	448750	19383Y	PARTICIPANT	\N	PRESENT	0
455679	448750	19762G	PARTICIPANT	\N	PRESENT	0
455680	448750	11066Q	PARTICIPANT	\N	PRESENT	0
455681	448750	08043V	PARTICIPANT	\N	PRESENT	0
455682	448750	19701S	PARTICIPANT	\N	PRESENT	0
455683	448750	11104D	PARTICIPANT	\N	PRESENT	0
455684	448750	14281W	PARTICIPANT	\N	PRESENT	0
455685	448750	04018C	PARTICIPANT	\N	PRESENT	0
455686	448750	14109K	PARTICIPANT	\N	PRESENT	0
455687	448750	19621T	PARTICIPANT	\N	PRESENT	0
455751	448750	19251M	PARTICIPANT	\N	PRESENT	0
455689	448750	14197C	PARTICIPANT	\N	PRESENT	0
455690	448750	19733B	PARTICIPANT	\N	PRESENT	0
455691	448750	08053X	PARTICIPANT	\N	PRESENT	0
455692	448750	08017T	PARTICIPANT	\N	PRESENT	0
455693	448750	14059S	PARTICIPANT	\N	PRESENT	0
455694	448750	14001X	PARTICIPANT	\N	PRESENT	0
455695	448750	19333N	PARTICIPANT	\N	PRESENT	0
455696	448750	14061L	PARTICIPANT	\N	PRESENT	0
455697	448750	19683J	PARTICIPANT	\N	PRESENT	0
455698	448750	98050T	PARTICIPANT	\N	PRESENT	0
455699	448750	14097Y	PARTICIPANT	\N	PRESENT	0
455700	448750	14187A	PARTICIPANT	\N	PRESENT	0
455701	448750	17779H	PARTICIPANT	\N	PRESENT	0
455702	448750	19725B	PARTICIPANT	\N	PRESENT	0
455703	448750	19631V	PARTICIPANT	\N	PRESENT	0
455704	448750	98018T	PARTICIPANT	\N	PRESENT	0
455705	448750	11067R	PARTICIPANT	\N	PRESENT	0
455706	448750	19503N	PARTICIPANT	\N	PRESENT	0
455707	448750	08035V	PARTICIPANT	\N	PRESENT	0
455708	448750	11026G	PARTICIPANT	\N	PRESENT	0
455709	448750	08012N	PARTICIPANT	\N	PRESENT	0
455710	448750	11054L	PARTICIPANT	\N	PRESENT	0
455711	448750	19599P	PARTICIPANT	\N	PRESENT	0
455712	448750	14227Q	PARTICIPANT	\N	PRESENT	0
455713	448750	14065Q	PARTICIPANT	\N	PRESENT	0
455714	448750	08058D	PARTICIPANT	\N	PRESENT	0
455715	448750	19489J	PARTICIPANT	\N	PRESENT	0
455716	448750	19794Q	PARTICIPANT	\N	PRESENT	0
455717	448750	14085U	PARTICIPANT	\N	PRESENT	0
455718	448750	87003B	PARTICIPANT	\N	PRESENT	0
455719	448750	08014Q	PARTICIPANT	\N	PRESENT	0
455720	448750	19820Y	PARTICIPANT	\N	PRESENT	0
455721	448750	19727D	PARTICIPANT	\N	PRESENT	0
455722	448750	19649G	PARTICIPANT	\N	PRESENT	0
455723	448750	19525U	PARTICIPANT	\N	PRESENT	0
455724	448750	11045K	PARTICIPANT	\N	PRESENT	0
455725	448750	11048N	PARTICIPANT	\N	PRESENT	0
455726	448750	19715Y	PARTICIPANT	\N	PRESENT	0
455727	448750	19768N	PARTICIPANT	\N	PRESENT	0
455728	448750	11110B	PARTICIPANT	\N	PRESENT	0
455729	448750	14151M	PARTICIPANT	\N	PRESENT	0
455730	448750	12016W	PARTICIPANT	\N	PRESENT	0
455731	448750	19581D	PARTICIPANT	\N	PRESENT	0
455732	448750	11033F	PARTICIPANT	\N	PRESENT	0
455733	448750	12041X	PARTICIPANT	\N	PRESENT	0
455734	448750	11077T	PARTICIPANT	\N	PRESENT	0
455735	448750	19695N	PARTICIPANT	\N	PRESENT	0
455736	448750	11031D	PARTICIPANT	\N	PRESENT	0
455737	448750	89017R	PARTICIPANT	\N	PRESENT	0
455738	448750	08056B	PARTICIPANT	\N	PRESENT	0
455739	448750	14055N	PARTICIPANT	\N	PRESENT	0
455740	448750	19713W	PARTICIPANT	\N	PRESENT	0
455741	448750	19749K	PARTICIPANT	\N	PRESENT	0
455742	448750	02002K	PARTICIPANT	\N	PRESENT	0
455743	448750	16685X	PARTICIPANT	\N	PRESENT	0
455744	448750	08048B	PARTICIPANT	\N	PRESENT	0
455745	448750	95067Q	PARTICIPANT	\N	PRESENT	0
455747	448750	11085T	PARTICIPANT	\N	PRESENT	0
455748	448750	08044W	PARTICIPANT	\N	PRESENT	0
455749	448750	04070G	PARTICIPANT	\N	PRESENT	0
455750	448750	95041E	PARTICIPANT	\N	PRESENT	0
455752	448750	19413M	PARTICIPANT	\N	PRESENT	0
455753	448750	04057K	PARTICIPANT	\N	PRESENT	0
455754	448750	19531S	PARTICIPANT	\N	PRESENT	0
455755	448750	19745F	PARTICIPANT	\N	PRESENT	0
455760	448750	08039A	PARTICIPANT	\N	PRESENT	0
455757	448750	04047H	PARTICIPANT	\N	PRESENT	0
455758	448750	04033B	PARTICIPANT	\N	PRESENT	0
455759	448750	19647E	PARTICIPANT	\N	PRESENT	0
456094	448751	04059M	PARTICIPANT	\N	PRESENT	0
456123	448751	04018C	PARTICIPANT	\N	PRESENT	0
456125	448751	11090Q	PARTICIPANT	\N	PRESENT	0
456107	448751	14173T	PARTICIPANT	\N	PRESENT	0
456098	448751	14041T	PARTICIPANT	\N	PRESENT	0
456105	448751	19631V	PARTICIPANT	\N	PRESENT	0
456100	448751	19820Y	PARTICIPANT	\N	PRESENT	0
456101	448751	17589D	PARTICIPANT	\N	PRESENT	0
456102	448751	19737F	PARTICIPANT	\N	PRESENT	0
456103	448751	14205J	PARTICIPANT	\N	PRESENT	0
456104	448751	14265W	PARTICIPANT	\N	PRESENT	0
456106	448751	14031R	PARTICIPANT	\N	PRESENT	0
456108	448751	19515S	PARTICIPANT	\N	PRESENT	0
456109	448751	14257W	PARTICIPANT	\N	PRESENT	0
456110	448751	19768N	PARTICIPANT	\N	PRESENT	0
456111	448751	14179A	PARTICIPANT	\N	PRESENT	0
456112	448751	19591F	PARTICIPANT	\N	PRESENT	0
456113	448751	11077T	PARTICIPANT	\N	PRESENT	0
456114	448751	19467C	PARTICIPANT	\N	PRESENT	0
456115	448751	14063N	PARTICIPANT	\N	PRESENT	0
456116	448751	19593H	PARTICIPANT	\N	PRESENT	0
456117	448751	01024M	PARTICIPANT	\N	PRESENT	0
456118	448751	19826F	PARTICIPANT	\N	PRESENT	0
456119	448751	19387D	PARTICIPANT	\N	PRESENT	0
456120	448751	08015R	PARTICIPANT	\N	PRESENT	0
456121	448751	95030B	PARTICIPANT	\N	PRESENT	0
456122	448751	01048V	PARTICIPANT	\N	PRESENT	0
456124	448751	11012A	PARTICIPANT	\N	PRESENT	0
456126	448751	04070G	PARTICIPANT	\N	PRESENT	0
456127	448751	19447X	PARTICIPANT	\N	PRESENT	0
456128	448751	14237S	PARTICIPANT	\N	PRESENT	0
456129	448751	19399H	PARTICIPANT	\N	PRESENT	0
456130	448751	19269X	PARTICIPANT	\N	PRESENT	0
456140	448751	19798U	PARTICIPANT	\N	PRESENT	0
456141	448751	19703U	PARTICIPANT	\N	PRESENT	0
456142	448751	11101A	PARTICIPANT	\N	PRESENT	0
456143	448751	08056B	PARTICIPANT	\N	PRESENT	0
456144	448751	19782L	PARTICIPANT	\N	PRESENT	0
456145	448751	19731Y	PARTICIPANT	\N	PRESENT	0
456146	448751	19747H	PARTICIPANT	\N	PRESENT	0
456147	448751	04044E	PARTICIPANT	\N	PRESENT	0
456148	448751	14251Q	PARTICIPANT	\N	PRESENT	0
456149	448751	08062Y	PARTICIPANT	\N	PRESENT	0
456150	448751	14069U	PARTICIPANT	\N	PRESENT	0
456152	454067	98050T	PRESIDENT	0	PRESENT	0
456155	448751	14109K	PARTICIPANT	\N	PRESENT	0
456159	448751	19441R	PARTICIPANT	\N	PRESENT	0
456160	454067	19443T	PARTICIPANT	\N	PRESENT	0
456161	454067	12041X	PARTICIPANT	\N	PRESENT	0
456162	454067	95030B	PARTICIPANT	\N	PRESENT	0
456163	454067	01062T	PARTICIPANT	\N	PRESENT	0
456164	454067	01058X	PARTICIPANT	\N	PRESENT	0
456165	454067	11054L	PARTICIPANT	\N	PRESENT	0
456166	454067	08056B	PARTICIPANT	\N	PRESENT	0
456167	454067	98018T	PARTICIPANT	\N	PRESENT	0
456168	454067	19421M	PARTICIPANT	\N	PRESENT	0
456169	454067	14193X	PARTICIPANT	\N	PRESENT	0
456170	454067	14267Y	PARTICIPANT	\N	PRESENT	0
456171	454067	97011G	PARTICIPANT	\N	PRESENT	0
456175	448751	14147R	PARTICIPANT	\N	PRESENT	0
456176	448751	19253P	PARTICIPANT	\N	PRESENT	0
456178	448751	19711U	PARTICIPANT	\N	PRESENT	0
456182	454067	14135M	PARTICIPANT	\N	PRESENT	0
456183	454067	04057K	PARTICIPANT	\N	PRESENT	0
456184	454067	14073Q	PARTICIPANT	\N	PRESENT	0
456185	454067	19569H	PARTICIPANT	\N	PRESENT	0
456186	454067	11026G	PARTICIPANT	\N	PRESENT	0
456187	454067	14001X	PARTICIPANT	\N	PRESENT	0
456188	454067	14026U	PARTICIPANT	\N	PRESENT	0
456189	454067	19725B	PARTICIPANT	\N	PRESENT	0
456190	454067	96004D	PARTICIPANT	\N	PRESENT	0
456191	454067	11083R	PARTICIPANT	\N	PRESENT	0
456192	454067	14249W	PARTICIPANT	\N	PRESENT	0
456193	454067	08058D	PARTICIPANT	\N	PRESENT	0
474567	474552	19447X	PARTICIPANT	\N	PRESENT	0
474568	474552	14039A	PARTICIPANT	\N	PRESENT	0
474569	474552	19729F	PARTICIPANT	\N	PRESENT	0
474570	474552	19826F	PARTICIPANT	\N	PRESENT	0
474571	474552	95067Q	PARTICIPANT	\N	PRESENT	0
474703	474692	08012N	PRESIDENT	1	PRESENT	0
474704	474692	02002K	PRESIDENT	0	PRESENT	0
474705	474692	19725B	PARTICIPANT	\N	PRESENT	0
474706	474692	14241N	PARTICIPANT	\N	PRESENT	0
474707	474692	19349W	PARTICIPANT	\N	PRESENT	0
474708	474692	14073Q	PARTICIPANT	\N	PRESENT	0
474709	474692	19251M	PARTICIPANT	\N	PRESENT	0
474710	474692	19399H	PARTICIPANT	\N	PRESENT	0
474711	474692	19758L	PARTICIPANT	\N	PRESENT	0
474712	474692	19533U	PARTICIPANT	\N	PRESENT	0
474713	474692	14147R	PARTICIPANT	\N	PRESENT	0
474714	474692	11043H	PARTICIPANT	\N	PRESENT	0
474715	474692	08024S	PARTICIPANT	\N	PRESENT	0
474716	474692	19711U	PARTICIPANT	\N	PRESENT	0
474717	474692	14030Q	PARTICIPANT	\N	PRESENT	0
474736	472083	14030Q	PARTICIPANT	\N	PRESENT	0
474737	472083	08043V	PARTICIPANT	\N	PRESENT	0
474738	472083	80013X	PARTICIPANT	\N	PRESENT	0
474739	472083	19701S	PARTICIPANT	\N	PRESENT	0
474740	472083	14179A	PARTICIPANT	\N	PRESENT	0
474741	472083	19731Y	PARTICIPANT	\N	PRESENT	0
474742	472083	19749K	PARTICIPANT	\N	PRESENT	0
474743	472085	14030Q	PARTICIPANT	\N	PRESENT	0
474744	472085	19701S	PARTICIPANT	\N	PRESENT	0
474745	472085	14179A	PARTICIPANT	\N	PRESENT	0
474746	472085	19715Y	PARTICIPANT	\N	PRESENT	0
474747	472085	19731Y	PARTICIPANT	\N	PRESENT	0
474748	472085	08017T	PARTICIPANT	\N	PRESENT	0
474749	472085	14109K	PARTICIPANT	\N	PRESENT	0
474750	472085	19749K	PARTICIPANT	\N	PRESENT	0
475053	472987	08068F	PARTICIPANT	\N	EXCUSE	0
475063	473557	14169X	PARTICIPANT	\N	PRESENT	0
475099	470583	14207L	PARTICIPANT	\N	PRESENT	0
475100	470583	14041T	PARTICIPANT	\N	PRESENT	0
475101	470583	19289C	PARTICIPANT	\N	PRESENT	0
475102	470583	01057W	PARTICIPANT	\N	PRESENT	0
475103	470583	19563B	PARTICIPANT	\N	PRESENT	0
475104	470583	01058X	PARTICIPANT	\N	PRESENT	0
475105	470583	19637C	PARTICIPANT	\N	PRESENT	0
475106	470583	14329V	PARTICIPANT	\N	PRESENT	0
475108	470583	04042C	PARTICIPANT	\N	PRESENT	0
475109	470583	19782L	PARTICIPANT	\N	PRESENT	0
475110	470583	14069U	PARTICIPANT	\N	PRESENT	0
475111	470583	19349W	PARTICIPANT	\N	PRESENT	0
475112	470583	11072N	PARTICIPANT	\N	PRESENT	0
475113	470583	19421M	PARTICIPANT	\N	PRESENT	0
475114	470583	95063L	PARTICIPANT	\N	PRESENT	0
475115	470583	19673G	PARTICIPANT	\N	PRESENT	0
475116	470583	14034U	PARTICIPANT	\N	PRESENT	0
475117	470583	14031R	PARTICIPANT	\N	PRESENT	0
475119	470583	19667J	PARTICIPANT	\N	PRESENT	0
475120	470583	19866P	PARTICIPANT	\N	PRESENT	0
475121	470583	14157T	PARTICIPANT	\N	PRESENT	0
475122	470583	11012A	PARTICIPANT	\N	PRESENT	0
475123	470583	19701S	PARTICIPANT	\N	PRESENT	0
475125	470583	14147R	PARTICIPANT	\N	PRESENT	0
475126	470583	11115U	PARTICIPANT	\N	PRESENT	0
475127	470583	04092N	PARTICIPANT	\N	PRESENT	0
475128	470583	19367Y	PARTICIPANT	\N	PRESENT	0
475129	470583	19766L	PARTICIPANT	\N	PRESENT	0
475131	470583	19679N	PARTICIPANT	\N	PRESENT	0
475132	470583	14123H	PARTICIPANT	\N	PRESENT	0
475133	470583	14079W	PARTICIPANT	\N	PRESENT	0
475134	470583	04033B	PARTICIPANT	\N	PRESENT	0
475135	470583	14187A	PARTICIPANT	\N	PRESENT	0
475138	470583	05008E	PARTICIPANT	\N	PRESENT	0
475140	470583	14231L	PARTICIPANT	\N	PRESENT	0
475142	470583	95041E	PARTICIPANT	\N	PRESENT	0
475144	470583	19251M	PARTICIPANT	\N	PRESENT	0
475145	470583	04008A	PARTICIPANT	\N	PRESENT	0
475148	470583	14030Q	PARTICIPANT	\N	PRESENT	0
475149	470583	04070G	PARTICIPANT	\N	PRESENT	0
475151	470583	01043Q	PARTICIPANT	\N	PRESENT	0
475152	470583	19549D	PARTICIPANT	\N	PRESENT	0
475154	470583	19687N	PARTICIPANT	\N	PRESENT	0
475156	470583	19533U	PARTICIPANT	\N	PRESENT	0
475158	470583	19347U	PARTICIPANT	\N	PRESENT	0
475169	470583	89017R	PARTICIPANT	\N	PRESENT	0
475172	470583	19685L	PARTICIPANT	\N	PRESENT	0
475174	470583	19735D	PARTICIPANT	\N	PRESENT	0
475176	470583	14085U	PARTICIPANT	\N	PRESENT	0
475177	470583	11085T	PARTICIPANT	\N	PRESENT	0
475178	470583	01024M	PARTICIPANT	\N	PRESENT	0
475179	470583	16685X	PARTICIPANT	\N	PRESENT	0
475191	470583	11083R	PARTICIPANT	\N	PRESENT	0
475194	470583	19762G	PARTICIPANT	\N	PRESENT	0
475203	470583	11048N	PARTICIPANT	\N	PRESENT	0
475204	473557	19253P	PARTICIPANT	\N	PRESENT	0
475205	473557	19525U	PARTICIPANT	\N	PRESENT	0
475206	473557	04086Q	PARTICIPANT	\N	PRESENT	0
475207	473557	08038Y	PARTICIPANT	\N	PRESENT	0
475208	473557	08010L	PARTICIPANT	\N	PRESENT	0
475209	473557	14257W	PARTICIPANT	\N	PRESENT	0
475210	473557	04044E	PARTICIPANT	\N	EXCUSE	0
475211	473557	17637T	PARTICIPANT	\N	PRESENT	0
475212	473557	14327T	PARTICIPANT	\N	PRESENT	0
475213	473557	14231L	PARTICIPANT	\N	PRESENT	0
475214	473557	19565D	PARTICIPANT	\N	PRESENT	0
475216	473557	01057W	PARTICIPANT	\N	PRESENT	0
475217	473557	19820Y	PARTICIPANT	\N	PRESENT	0
475218	473557	11048N	PARTICIPANT	\N	PRESENT	0
475228	470583	04057K	PARTICIPANT	\N	PRESENT	0
475247	473557	19489J	PARTICIPANT	\N	PRESENT	0
475248	470583	19725B	PARTICIPANT	\N	PRESENT	0
475346	473390	01043Q	PARTICIPANT	\N	PRESENT	0
475347	473557	19687N	PARTICIPANT	\N	EXCUSE	0
475348	473390	14229S	PARTICIPANT	\N	PRESENT	0
475350	473390	14085U	PARTICIPANT	\N	PRESENT	0
475352	473390	19631V	PARTICIPANT	\N	PRESENT	0
475353	473390	14081Q	PARTICIPANT	\N	PRESENT	0
475355	473390	19758L	PARTICIPANT	\N	PRESENT	0
475356	473390	14281W	PARTICIPANT	\N	PRESENT	0
475357	473390	04057K	PARTICIPANT	\N	PRESENT	0
475358	473390	19349W	PARTICIPANT	\N	PRESENT	0
475359	473390	11083R	PARTICIPANT	\N	PRESENT	0
475360	473390	19691J	PARTICIPANT	\N	PRESENT	0
475361	473390	19569H	PARTICIPANT	\N	PRESENT	0
475362	473390	19866P	PARTICIPANT	\N	PRESENT	0
475363	473390	07029T	PARTICIPANT	\N	PRESENT	0
475364	473390	01024M	PARTICIPANT	\N	PRESENT	0
475365	473390	19701S	PARTICIPANT	\N	PRESENT	0
475366	473390	01057W	PARTICIPANT	\N	PRESENT	0
475367	473390	14187A	PARTICIPANT	\N	PRESENT	0
475369	473390	14147R	PARTICIPANT	\N	PRESENT	0
475372	473390	19367Y	PARTICIPANT	\N	PRESENT	0
475374	473390	19479G	PARTICIPANT	\N	PRESENT	0
475375	473390	14021P	PARTICIPANT	\N	PRESENT	0
475376	473390	11074Q	PARTICIPANT	\N	PRESENT	0
475377	473390	19565D	PARTICIPANT	\N	PRESENT	0
475378	473071	19794Q	PARTICIPANT	\N	PRESENT	0
475379	473071	14031R	PARTICIPANT	\N	PRESENT	0
475380	473071	14219Q	PARTICIPANT	\N	PRESENT	0
475381	473071	19820Y	PARTICIPANT	\N	PRESENT	0
475382	473071	19599P	PARTICIPANT	\N	PRESENT	0
475383	473071	19637C	PARTICIPANT	\N	PRESENT	0
475384	473071	14169X	PARTICIPANT	\N	PRESENT	0
475385	473071	19551W	PARTICIPANT	\N	PRESENT	0
475386	473071	18083K	PARTICIPANT	\N	PRESENT	0
475387	473071	14237S	PARTICIPANT	\N	PRESENT	0
475388	473071	14051J	PARTICIPANT	\N	PRESENT	0
475389	473071	08060W	PARTICIPANT	\N	PRESENT	0
475390	473071	08009T	PRESIDENT	0	PRESENT	0
475391	473071	19347U	PARTICIPANT	\N	PRESENT	0
475392	473071	14157T	PARTICIPANT	\N	PRESENT	0
475393	473390	19533U	PARTICIPANT	\N	PRESENT	0
475394	473390	19762G	PARTICIPANT	\N	PRESENT	0
475395	473215	19515S	PARTICIPANT	\N	PRESENT	0
475397	473390	19651A	PARTICIPANT	\N	PRESENT	0
475398	473390	11040E	PARTICIPANT	\N	PRESENT	0
475399	473071	14093U	PARTICIPANT	\N	PRESENT	0
475400	473071	11065P	PARTICIPANT	\N	PRESENT	0
475401	473390	08017T	PARTICIPANT	\N	PRESENT	0
475403	473071	19333N	PARTICIPANT	\N	PRESENT	0
475404	473071	19713W	PARTICIPANT	\N	PRESENT	0
475405	473071	04085P	PARTICIPANT	\N	PRESENT	0
475406	473071	19737F	PARTICIPANT	\N	PRESENT	0
475407	473071	19745F	PARTICIPANT	\N	PRESENT	0
475408	473071	08024S	PARTICIPANT	\N	EXCUSE	0
475409	473390	11012A	PARTICIPANT	\N	PRESENT	0
475410	473071	19826F	PARTICIPANT	\N	PRESENT	0
475411	473390	14069U	PARTICIPANT	\N	PRESENT	0
475412	473390	11067R	PARTICIPANT	\N	PRESENT	0
475413	473390	14237S	PARTICIPANT	\N	PRESENT	0
475414	473390	19679N	PARTICIPANT	\N	PRESENT	0
456180	456179	11031D	PARTICIPANT	\N	PRESENT	0
456181	456179	14169X	PARTICIPANT	\N	PRESENT	0
456194	456179	18083K	PARTICIPANT	\N	PRESENT	0
456195	456179	19565D	PARTICIPANT	\N	PRESENT	0
456196	456179	11026G	PARTICIPANT	\N	PRESENT	0
456197	456179	04070G	PARTICIPANT	\N	PRESENT	0
462218	448777	19651A	PARTICIPANT	\N	PRESENT	0
462219	448777	19333N	PARTICIPANT	\N	PRESENT	0
462220	448777	14147R	PARTICIPANT	\N	PRESENT	0
462221	448777	19447X	PARTICIPANT	\N	PRESENT	0
462222	448777	19621T	PARTICIPANT	\N	PRESENT	0
462223	448777	19713W	PARTICIPANT	\N	PRESENT	0
462224	448777	04034C	PARTICIPANT	\N	PRESENT	0
462225	448777	14135M	PARTICIPANT	\N	PRESENT	0
462226	448777	14026U	PARTICIPANT	\N	PRESENT	0
462227	448777	19693L	PARTICIPANT	\N	PRESENT	0
462228	448777	14059S	PARTICIPANT	\N	PRESENT	0
462229	448777	14215L	PARTICIPANT	\N	PRESENT	0
462230	448777	19749K	PARTICIPANT	\N	PRESENT	0
462231	448777	19683J	PARTICIPANT	\N	PRESENT	0
462232	448777	11067R	PARTICIPANT	\N	PRESENT	0
462233	448777	14197C	PARTICIPANT	\N	PRESENT	0
462234	448777	14021P	PARTICIPANT	\N	PRESENT	0
462235	448777	14087W	PARTICIPANT	\N	PRESENT	0
462236	448777	18083K	PARTICIPANT	\N	PRESENT	0
462248	459119	08010L	PARTICIPANT	\N	PRESENT	0
462242	448777	14042U	PARTICIPANT	\N	PRESENT	0
462244	448777	19467C	PARTICIPANT	\N	PRESENT	0
462249	448777	10015M	PARTICIPANT	\N	PRESENT	0
462255	448777	10006L	PARTICIPANT	\N	PRESENT	0
462256	448777	19768N	PARTICIPANT	\N	PRESENT	0
462257	448777	19820Y	PARTICIPANT	\N	PRESENT	0
462263	448777	01057W	PARTICIPANT	\N	PRESENT	0
462268	448777	11012A	PARTICIPANT	\N	PRESENT	0
462269	448777	19489J	PARTICIPANT	\N	PRESENT	0
462271	459126	80013X	PARTICIPANT	\N	PRESENT	0
462272	459126	14205J	PARTICIPANT	\N	PRESENT	0
462273	459126	14115H	PARTICIPANT	\N	PRESENT	0
462274	459126	19747H	PARTICIPANT	\N	PRESENT	0
462275	459126	04043D	PARTICIPANT	\N	PRESENT	0
462276	459126	14257W	PARTICIPANT	\N	PRESENT	0
462277	459126	14033T	PARTICIPANT	\N	PRESENT	0
464315	464314	19515S	PARTICIPANT	\N	PRESENT	0
464316	464314	19631V	PARTICIPANT	\N	PRESENT	0
462596	462478	02002K	PARTICIPANT	\N	EXCUSE	0
464317	464314	19467C	PARTICIPANT	\N	PRESENT	0
462598	462478	19399H	PARTICIPANT	\N	PRESENT	0
464318	464314	19768N	PARTICIPANT	\N	PRESENT	0
464319	464314	19782L	PARTICIPANT	\N	PRESENT	0
464320	464314	11077T	PARTICIPANT	\N	PRESENT	0
464321	464314	14187A	PARTICIPANT	\N	PRESENT	0
464322	464314	19812Y	PARTICIPANT	\N	PRESENT	0
464323	464314	11090Q	PRESIDENT	0	PRESENT	0
464324	464314	14033T	PARTICIPANT	\N	PRESENT	0
464325	464314	04045F	PARTICIPANT	\N	PRESENT	0
464326	464314	80013X	PARTICIPANT	\N	PRESENT	0
464327	464314	14205J	PARTICIPANT	\N	PRESENT	0
464328	464314	19705W	PARTICIPANT	\N	PRESENT	0
464329	464314	14197C	PARTICIPANT	\N	PRESENT	0
464330	464314	14207L	PARTICIPANT	\N	PRESENT	0
464331	464314	04043D	PARTICIPANT	\N	PRESENT	0
464332	464314	14265W	PARTICIPANT	\N	PRESENT	0
464333	464314	14257W	PARTICIPANT	\N	PRESENT	0
464334	464314	19369B	PARTICIPANT	\N	PRESENT	0
464335	464314	19619A	PARTICIPANT	\N	PRESENT	0
464336	464314	19695N	PARTICIPANT	\N	PRESENT	0
464337	464314	19747H	PARTICIPANT	\N	PRESENT	0
464338	464314	19563B	PARTICIPANT	\N	PRESENT	0
464339	464314	08019V	PARTICIPANT	\N	PRESENT	0
464341	464314	08038Y	PARTICIPANT	\N	EXCUSE	0
464343	464314	11056N	PARTICIPANT	\N	PRESENT	0
464344	464314	11099A	PARTICIPANT	\N	PRESENT	0
464345	464314	08068F	PARTICIPANT	\N	PRESENT	0
464346	464314	14081Q	PARTICIPANT	\N	EXCUSE	0
465209	465200	08038Y	PARTICIPANT	\N	PRESENT	0
465210	465200	14327T	PARTICIPANT	\N	PRESENT	0
465211	465200	14281W	PARTICIPANT	\N	PRESENT	0
465212	465200	14231L	PARTICIPANT	\N	PRESENT	0
465213	465200	19820Y	PARTICIPANT	\N	PRESENT	0
465214	465200	19565D	PARTICIPANT	\N	PRESENT	0
465215	465200	11049P	PARTICIPANT	\N	PRESENT	0
465216	465200	01057W	PARTICIPANT	\N	PRESENT	0
465217	465200	11048N	PARTICIPANT	\N	PRESENT	0
465218	465200	19489J	PARTICIPANT	\N	PRESENT	0
465219	465200	08010L	PARTICIPANT	\N	PRESENT	0
465220	465200	14257W	PARTICIPANT	\N	PRESENT	0
465221	465200	14071N	PARTICIPANT	\N	PRESENT	0
465222	465200	92040Q	PARTICIPANT	\N	EXCUSE	0
465223	465200	05012A	PARTICIPANT	\N	PRESENT	0
465224	465200	19735D	PARTICIPANT	\N	PRESENT	0
465225	465200	17637T	PARTICIPANT	\N	PRESENT	0
465226	465200	95063L	PARTICIPANT	\N	PRESENT	0
465227	465200	19687N	PARTICIPANT	\N	PRESENT	0
465228	465200	04045F	PARTICIPANT	\N	PRESENT	0
465229	465200	04044E	PARTICIPANT	\N	PRESENT	0
465230	465200	08049C	PARTICIPANT	\N	PRESENT	0
465231	465200	95067Q	PARTICIPANT	\N	PRESENT	0
465233	465232	14030Q	PRESIDENT	0	PRESENT	0
465234	465232	08043V	PARTICIPANT	\N	PRESENT	0
465235	465232	19643A	PARTICIPANT	\N	PRESENT	0
465236	465232	19621T	PARTICIPANT	\N	PRESENT	0
465237	465232	18083K	PARTICIPANT	\N	PRESENT	0
465238	465232	19701S	PARTICIPANT	\N	PRESENT	0
465239	465232	19693L	PARTICIPANT	\N	PRESENT	0
465240	465232	14217N	PARTICIPANT	\N	PRESENT	0
465241	465232	19577H	PARTICIPANT	\N	PRESENT	0
465242	465232	04035D	PARTICIPANT	\N	PRESENT	0
465243	465232	14179A	PARTICIPANT	\N	PRESENT	0
465244	465232	19715Y	PARTICIPANT	\N	PRESENT	0
465245	465232	19731Y	PARTICIPANT	\N	PRESENT	0
465246	465232	08017T	PARTICIPANT	\N	PRESENT	0
465247	465232	14109K	PARTICIPANT	\N	PRESENT	0
465248	465232	14235Q	PARTICIPANT	\N	PRESENT	0
465249	465232	19679N	PARTICIPANT	\N	PRESENT	0
465250	465232	19269X	PARTICIPANT	\N	PRESENT	0
465251	465232	11045K	PARTICIPANT	\N	PRESENT	0
465252	465232	19749K	PARTICIPANT	\N	PRESENT	0
465253	465232	08024S	PARTICIPANT	\N	EXCUSE	0
465254	465232	07029T	PARTICIPANT	\N	EXCUSE	0
465255	465232	08020N	PARTICIPANT	\N	EXCUSE	0
465256	465232	11067R	PARTICIPANT	\N	PRESENT	0
465258	465257	11109J	PARTICIPANT	\N	PRESENT	0
465259	465257	14261S	PARTICIPANT	\N	PRESENT	0
465260	465257	19717B	PARTICIPANT	\N	PRESENT	0
465261	465257	19631V	PARTICIPANT	\N	PRESENT	0
465262	465257	19577H	PARTICIPANT	\N	PRESENT	0
465263	465257	07033P	PARTICIPANT	\N	EXCUSE	0
465264	465257	19691J	PARTICIPANT	\N	PRESENT	0
465265	465257	19329S	PARTICIPANT	\N	PRESENT	0
465266	465257	19715Y	PARTICIPANT	\N	PRESENT	0
465267	465257	14039A	PARTICIPANT	\N	PRESENT	0
465268	465257	98005N	PARTICIPANT	\N	PRESENT	0
465269	465257	14059S	PARTICIPANT	\N	PRESENT	0
465270	465257	12016W	PARTICIPANT	\N	PRESENT	0
465271	465257	08019V	PRESIDENT	0	PRESENT	0
465272	465257	11054L	PARTICIPANT	\N	EXCUSE	0
465273	465257	14331P	PARTICIPANT	\N	EXCUSE	0
465502	465469	11027H	PARTICIPANT	\N	PRESENT	0
465503	465469	98005N	PARTICIPANT	\N	PRESENT	0
465504	465469	97011G	PARTICIPANT	\N	PRESENT	0
465506	465505	89017R	PARTICIPANT	\N	PRESENT	0
465507	465505	14030Q	PARTICIPANT	\N	PRESENT	0
465508	465505	19575F	PARTICIPANT	\N	PRESENT	0
465509	465505	08068F	PARTICIPANT	\N	PRESENT	0
465510	465505	14083S	PARTICIPANT	\N	PRESENT	0
465511	465505	14329V	PARTICIPANT	\N	PRESENT	0
465512	465505	14061L	PARTICIPANT	\N	PRESENT	0
465513	465505	04049K	PRESIDENT	0	PRESENT	0
465514	465505	08015R	PARTICIPANT	\N	PRESENT	0
465515	465505	19671E	PARTICIPANT	\N	PRESENT	0
465516	465505	19545Y	PARTICIPANT	\N	EXCUSE	0
465517	465505	14255U	PARTICIPANT	\N	EXCUSE	0
465518	465505	16685X	PARTICIPANT	\N	EXCUSE	0
466183	465336	05008E	PRESIDENT	0	PRESENT	0
466184	465336	19725B	PARTICIPANT	\N	PRESENT	0
466185	465336	14053L	PARTICIPANT	\N	PRESENT	0
466186	465336	14065Q	PARTICIPANT	\N	PRESENT	0
466187	465336	14111D	PARTICIPANT	\N	PRESENT	0
466188	465336	19629C	PARTICIPANT	\N	PRESENT	0
466189	465336	14041T	PARTICIPANT	\N	PRESENT	0
466190	465336	11026G	PARTICIPANT	\N	PRESENT	0
466191	465336	19253P	PARTICIPANT	\N	PRESENT	0
466192	465336	04038G	PARTICIPANT	\N	PRESENT	0
466193	465336	01028R	PARTICIPANT	\N	PRESENT	0
466194	465336	14021P	PARTICIPANT	\N	PRESENT	0
466195	465336	14259Y	PARTICIPANT	\N	PRESENT	0
466196	465336	11072N	PARTICIPANT	\N	PRESENT	0
466201	465336	01024M	PARTICIPANT	\N	PRESENT	0
466202	465336	95063L	PARTICIPANT	\N	PRESENT	0
471759	467802	14169X	PARTICIPANT	\N	PRESENT	0
471760	467802	19713W	PARTICIPANT	\N	PRESENT	0
471761	467802	14157T	PARTICIPANT	\N	PRESENT	0
471762	467802	19745F	PARTICIPANT	\N	PRESENT	0
471763	467802	19549D	PARTICIPANT	\N	PRESENT	0
471764	467802	19820Y	PARTICIPANT	\N	PRESENT	0
471765	467802	04097T	PARTICIPANT	\N	PRESENT	0
471766	467802	19383Y	PARTICIPANT	\N	PRESENT	0
471767	467802	14219Q	PARTICIPANT	\N	PRESENT	0
471768	467802	17637T	PARTICIPANT	\N	PRESENT	0
471769	467802	14038Y	PARTICIPANT	\N	PRESENT	0
471770	467802	19826F	PARTICIPANT	\N	PRESENT	0
471771	467802	19637C	PARTICIPANT	\N	PRESENT	0
471772	467802	02002K	PARTICIPANT	\N	PRESENT	0
471773	467802	14221J	PARTICIPANT	\N	PRESENT	0
471774	467802	19794Q	PARTICIPANT	\N	PRESENT	0
471775	467802	19701S	PARTICIPANT	\N	PRESENT	0
471776	467802	14051J	PARTICIPANT	\N	PRESENT	0
471777	467802	18083K	PARTICIPANT	\N	PRESENT	0
471778	467802	19739H	PARTICIPANT	\N	PRESENT	0
471779	467802	19387D	PARTICIPANT	\N	PRESENT	0
471780	467802	19347U	PARTICIPANT	\N	PRESENT	0
471593	470616	19549D	PARTICIPANT	\N	PRESENT	0
471594	470616	14097Y	PARTICIPANT	\N	PRESENT	0
471595	470616	19611R	PRESIDENT	0	PRESENT	0
471596	470616	14197C	PARTICIPANT	\N	PRESENT	0
471597	470616	14033T	PARTICIPANT	\N	PRESENT	0
471598	470616	19687N	PARTICIPANT	\N	PRESENT	0
471599	470616	19723Y	PARTICIPANT	\N	PRESENT	0
471781	467802	19503N	PARTICIPANT	\N	PRESENT	0
471758	467802	08009T	PRESIDENT	0	PRESENT	0
472072	470888	14071N	PARTICIPANT	\N	PRESENT	0
472074	470890	14071N	PARTICIPANT	\N	EXCUSE	0
472084	471173	19629C	PARTICIPANT	\N	EXCUSE	0
472087	470888	19593H	PARTICIPANT	\N	EXCUSE	0
472107	470888	19503N	PARTICIPANT	\N	PRESENT	0
472108	470888	11083R	PARTICIPANT	\N	PRESENT	0
472109	470888	19619A	PARTICIPANT	\N	PRESENT	0
472110	470888	14026U	PARTICIPANT	\N	PRESENT	0
472111	470888	19387D	PARTICIPANT	\N	PRESENT	0
472112	470619	19611R	PRESIDENT	0	PRESENT	0
472113	470888	19689Q	PARTICIPANT	\N	PRESENT	0
472114	470888	19631V	PARTICIPANT	\N	PRESENT	0
472115	470619	14097Y	PARTICIPANT	\N	PRESENT	0
472116	470888	19515S	PARTICIPANT	\N	PRESENT	0
472117	470619	14197C	PARTICIPANT	\N	PRESENT	0
472118	470619	19549D	PARTICIPANT	\N	PRESENT	0
472119	470619	19629C	PARTICIPANT	\N	PRESENT	0
472120	470619	19527W	PARTICIPANT	\N	PRESENT	0
472121	470619	19723Y	PARTICIPANT	\N	PRESENT	0
472124	472123	04018C	PARTICIPANT	\N	PRESENT	0
472125	472123	08039A	PARTICIPANT	\N	PRESENT	0
472126	472123	14109K	PARTICIPANT	\N	PRESENT	0
472127	472123	19735D	PARTICIPANT	\N	PRESENT	0
472128	472123	19749K	PARTICIPANT	\N	PRESENT	0
472129	470984	14073Q	PARTICIPANT	\N	PRESENT	0
472130	470984	14241N	PARTICIPANT	\N	PRESENT	0
472131	470984	19643A	PARTICIPANT	\N	PRESENT	0
472132	470984	08012N	PARTICIPANT	\N	PRESENT	0
472133	470984	11043H	PARTICIPANT	\N	PRESENT	0
472134	470984	14039A	PARTICIPANT	\N	PRESENT	0
472136	472135	08039A	PARTICIPANT	\N	PRESENT	0
472137	472135	11083R	PARTICIPANT	\N	PRESENT	0
472138	470871	19723Y	PARTICIPANT	\N	PRESENT	0
472141	472140	19693L	PARTICIPANT	\N	PRESENT	0
472144	472143	19693L	PARTICIPANT	\N	PRESENT	0
472146	472073	04086Q	PARTICIPANT	\N	PRESENT	0
472147	472073	95067Q	PARTICIPANT	\N	PRESENT	0
472148	472073	14039A	PARTICIPANT	\N	PRESENT	0
472149	472073	08045X	PARTICIPANT	\N	PRESENT	0
472150	472073	14267Y	PRESIDENT	0	PRESENT	0
472151	472073	16685X	PARTICIPANT	\N	PRESENT	0
472152	472073	19715Y	PARTICIPANT	\N	PRESENT	0
472153	472073	19826F	PARTICIPANT	\N	PRESENT	0
472154	472073	14217N	PARTICIPANT	\N	PRESENT	0
472155	472073	14261S	PARTICIPANT	\N	PRESENT	0
472156	472073	19525U	PARTICIPANT	\N	PRESENT	0
472157	472073	19729F	PARTICIPANT	\N	EXCUSE	0
472158	469641	19575F	PARTICIPANT	\N	PRESENT	0
472159	469641	10006L	PARTICIPANT	\N	PRESENT	0
472160	469641	19723Y	PARTICIPANT	\N	PRESENT	0
472161	469641	19697Q	PARTICIPANT	\N	PRESENT	0
472162	469642	10006L	PARTICIPANT	\N	PRESENT	0
472163	469643	10006L	PARTICIPANT	\N	PRESENT	0
472164	469643	19723Y	PARTICIPANT	\N	PRESENT	0
472165	469643	19697Q	PARTICIPANT	\N	PRESENT	0
472567	472056	14111D	PARTICIPANT	\N	PRESENT	0
472568	472056	08045X	PARTICIPANT	\N	PRESENT	0
472569	472056	11026G	PARTICIPANT	\N	PRESENT	0
472570	472056	19253P	PARTICIPANT	\N	PRESENT	0
472571	472056	04047H	PARTICIPANT	\N	PRESENT	0
472572	472056	01028R	PARTICIPANT	\N	PRESENT	0
472573	472056	05008E	PRESIDENT	0	PRESENT	0
472574	472056	19447X	PARTICIPANT	\N	PRESENT	0
472575	472056	95063L	PARTICIPANT	\N	PRESENT	0
472576	472056	14147R	PARTICIPANT	\N	PRESENT	0
472577	472056	14179A	PARTICIPANT	\N	PRESENT	0
472578	472056	14151M	PARTICIPANT	\N	PRESENT	0
472579	472056	14215L	PARTICIPANT	\N	PRESENT	0
472580	472056	11085T	PARTICIPANT	\N	PRESENT	0
472581	472056	14021P	PARTICIPANT	\N	PRESENT	0
472583	472086	11048N	PARTICIPANT	\N	PRESENT	0
472584	472086	07004J	PARTICIPANT	\N	PRESENT	0
472585	472086	01057W	PARTICIPANT	\N	PRESENT	0
472586	472086	19689Q	PARTICIPANT	\N	PRESENT	0
472587	472086	19741B	PARTICIPANT	\N	PRESENT	0
472588	472086	14253S	PARTICIPANT	\N	PRESENT	0
472589	472086	19687N	PARTICIPANT	\N	PRESENT	0
472590	472086	89017R	PARTICIPANT	\N	PRESENT	0
472591	472086	11074Q	PRESIDENT	0	PRESENT	0
472592	472086	08011M	PARTICIPANT	\N	PRESENT	0
472593	472086	14083S	PARTICIPANT	\N	PRESENT	0
472596	472086	08010L	PARTICIPANT	\N	PRESENT	0
472605	472086	19647E	PARTICIPANT	\N	PRESENT	0
472606	472064	19697Q	PARTICIPANT	\N	PRESENT	0
472607	472064	04092N	PRESIDENT	0	PRESENT	0
472608	472064	11097X	PARTICIPANT	\N	PRESENT	0
472609	472064	14026U	PARTICIPANT	\N	PRESENT	0
472610	472064	17779H	PARTICIPANT	\N	PRESENT	0
472611	472064	14239U	PARTICIPANT	\N	PRESENT	0
472612	472064	19553Y	PARTICIPANT	\N	PRESENT	0
472613	472064	14281W	PARTICIPANT	\N	PRESENT	0
472614	472064	14042U	PARTICIPANT	\N	PRESENT	0
472615	472064	14213J	PARTICIPANT	\N	PRESENT	0
472616	472064	14071N	PARTICIPANT	\N	PRESENT	0
472617	472064	19683J	PARTICIPANT	\N	PRESENT	0
472618	472064	19760E	PARTICIPANT	\N	PRESENT	0
472619	472064	98024R	PARTICIPANT	\N	PRESENT	0
472620	472064	19521Q	PARTICIPANT	\N	PRESENT	0
472623	472058	14111D	PARTICIPANT	\N	PRESENT	0
472624	472058	11026G	PARTICIPANT	\N	PRESENT	0
472625	472058	19253P	PARTICIPANT	\N	PRESENT	0
472626	472058	01028R	PARTICIPANT	\N	PRESENT	0
472627	472058	05008E	PRESIDENT	0	PRESENT	0
472628	472058	19447X	PARTICIPANT	\N	PRESENT	0
472629	472058	19489J	PARTICIPANT	\N	PRESENT	0
472630	472058	95063L	PARTICIPANT	\N	PRESENT	0
472631	472058	14147R	PARTICIPANT	\N	PRESENT	0
472632	472058	14179A	PARTICIPANT	\N	PRESENT	0
472633	472058	14151M	PARTICIPANT	\N	PRESENT	0
472634	472058	14069U	PARTICIPANT	\N	PRESENT	0
472635	472058	14215L	PARTICIPANT	\N	PRESENT	0
472636	472058	11085T	PARTICIPANT	\N	PRESENT	0
472637	472058	14021P	PARTICIPANT	\N	PRESENT	0
472638	472058	08045X	PARTICIPANT	\N	PRESENT	0
472639	472058	04047H	PARTICIPANT	\N	PRESENT	0
472648	472058	19649G	PARTICIPANT	\N	PRESENT	0
472649	472058	10015M	PARTICIPANT	\N	PRESENT	0
472650	472058	19729F	PARTICIPANT	\N	EXCUSE	0
472735	472734	04070G	PRESIDENT	0	PRESENT	0
472736	472734	14229S	PARTICIPANT	\N	PRESENT	0
472737	472734	19533U	PARTICIPANT	\N	PRESENT	0
472738	472734	19593H	PARTICIPANT	\N	PRESENT	0
472739	472734	14249W	PARTICIPANT	\N	PRESENT	0
472740	472734	14241N	PARTICIPANT	\N	PRESENT	0
472741	472734	19699S	PARTICIPANT	\N	PRESENT	0
472742	472734	08043V	PARTICIPANT	\N	PRESENT	0
472743	472734	08020N	PARTICIPANT	\N	PRESENT	0
472744	472734	19611R	PARTICIPANT	\N	PRESENT	0
472745	472734	19693L	PARTICIPANT	\N	PRESENT	0
472746	472734	14107H	PARTICIPANT	\N	PRESENT	0
472747	472734	11104D	PARTICIPANT	\N	PRESENT	0
472748	472734	19749K	PARTICIPANT	\N	PRESENT	0
472749	472734	19766L	PARTICIPANT	\N	PRESENT	0
456198	454067	95037J	PARTICIPANT	\N	PRESENT	0
456199	448751	08034U	PARTICIPANT	\N	PRESENT	0
456201	448751	19701S	PARTICIPANT	\N	PRESENT	0
456202	448751	08020N	PARTICIPANT	\N	PRESENT	0
456203	448751	97011G	PARTICIPANT	\N	PRESENT	0
456204	448751	19533U	PARTICIPANT	\N	PRESENT	0
456205	454067	14229S	PARTICIPANT	\N	PRESENT	0
456206	448751	11056N	PARTICIPANT	\N	PRESENT	0
456207	448751	19687N	PARTICIPANT	\N	PRESENT	0
456208	448751	14197C	PARTICIPANT	\N	PRESENT	0
456209	448751	19479G	PARTICIPANT	\N	PRESENT	0
456210	448751	11048N	PARTICIPANT	\N	PRESENT	0
456211	448751	19629C	PARTICIPANT	\N	PRESENT	0
456212	454067	14079W	PARTICIPANT	\N	PRESENT	0
456213	448751	19443T	PARTICIPANT	\N	PRESENT	0
456214	448751	19503N	PARTICIPANT	\N	PRESENT	0
456215	448751	19383Y	PARTICIPANT	\N	PRESENT	0
456218	448751	08031R	PARTICIPANT	\N	PRESENT	0
456219	448751	19507S	PARTICIPANT	\N	PRESENT	0
456220	448751	14079W	PARTICIPANT	\N	PRESENT	0
456236	448751	08061X	PARTICIPANT	\N	PRESENT	0
456237	448751	11099A	PARTICIPANT	\N	PRESENT	0
456238	448751	14034U	PARTICIPANT	\N	PRESENT	0
456239	448751	11097X	PARTICIPANT	\N	PRESENT	0
456240	448751	18083K	PARTICIPANT	\N	PRESENT	0
456241	448751	14038Y	PARTICIPANT	\N	PRESENT	0
456736	456735	19349W	PARTICIPANT	\N	PRESENT	0
456737	456735	19521Q	PARTICIPANT	\N	PRESENT	0
456738	456735	19711U	PARTICIPANT	\N	PRESENT	0
456739	456735	19575F	PARTICIPANT	\N	PRESENT	0
456740	456735	14213J	PARTICIPANT	\N	PRESENT	0
456741	456735	14265W	PARTICIPANT	\N	PRESENT	0
456742	456735	14219Q	PARTICIPANT	\N	PRESENT	0
456744	456743	14265W	PARTICIPANT	\N	PRESENT	0
456746	456745	14265W	PARTICIPANT	\N	PRESENT	0
456987	453247	14038Y	PARTICIPANT	\N	EXCUSE	0
457000	453247	14059S	PARTICIPANT	\N	EXCUSE	0
457001	453247	14219Q	PARTICIPANT	\N	EXCUSE	0
457002	453247	19729F	PARTICIPANT	\N	EXCUSE	0
457014	454195	19729F	PARTICIPANT	\N	EXCUSE	0
457010	453247	14135M	PARTICIPANT	\N	EXCUSE	0
457013	454195	14038Y	PARTICIPANT	\N	EXCUSE	0
457015	454195	14219Q	PARTICIPANT	\N	EXCUSE	0
457016	454195	14059S	PARTICIPANT	\N	EXCUSE	0
457017	454195	14135M	PARTICIPANT	\N	EXCUSE	0
457027	456640	19415P	PARTICIPANT	\N	EXCUSE	0
458407	458397	14087W	PARTICIPANT	\N	PRESENT	0
458408	458397	19521Q	PARTICIPANT	\N	PRESENT	0
458409	458397	19679N	PARTICIPANT	\N	PRESENT	0
458410	458400	14087W	PARTICIPANT	\N	PRESENT	0
458411	458400	19521Q	PARTICIPANT	\N	PRESENT	0
458412	458400	19760E	PARTICIPANT	\N	PRESENT	0
458413	458401	14087W	PARTICIPANT	\N	PRESENT	0
458414	458401	19521Q	PARTICIPANT	\N	PRESENT	0
458415	458401	19679N	PARTICIPANT	\N	PRESENT	0
458419	458404	14087W	PARTICIPANT	\N	PRESENT	0
458420	458404	19521Q	PARTICIPANT	\N	PRESENT	0
458422	458404	19679N	PARTICIPANT	\N	PRESENT	0
458424	458406	19679N	PARTICIPANT	\N	PRESENT	0
458425	458406	14087W	PARTICIPANT	\N	PRESENT	0
458426	458406	19521Q	PARTICIPANT	\N	PRESENT	0
458659	458658	11053K	PARTICIPANT	\N	PRESENT	0
458660	458658	14159V	PARTICIPANT	\N	PRESENT	0
458661	458658	05012A	PARTICIPANT	\N	PRESENT	0
458949	458948	08031R	PARTICIPANT	\N	PRESENT	0
458950	458948	14063N	PARTICIPANT	\N	PRESENT	0
458951	458948	08043V	PARTICIPANT	\N	PRESENT	0
458953	458753	14089Y	PARTICIPANT	\N	PRESENT	0
458954	458753	11026G	PARTICIPANT	\N	PRESENT	0
458955	458754	11026G	PARTICIPANT	\N	PRESENT	0
458956	458754	14089Y	PARTICIPANT	\N	PRESENT	0
458957	458755	11026G	PARTICIPANT	\N	PRESENT	0
458958	458755	14089Y	PARTICIPANT	\N	PRESENT	0
458959	458756	11026G	PARTICIPANT	\N	PRESENT	0
458960	458756	14089Y	PARTICIPANT	\N	PRESENT	0
458961	458758	11026G	PARTICIPANT	\N	PRESENT	0
458962	458758	14089Y	PARTICIPANT	\N	PRESENT	0
460678	460677	08010L	PARTICIPANT	\N	PRESENT	0
460679	460084	19631V	PARTICIPANT	\N	PRESENT	0
460680	460084	11101A	PARTICIPANT	\N	PRESENT	0
460681	460084	14085U	PARTICIPANT	\N	PRESENT	0
460682	460084	08028W	PARTICIPANT	\N	PRESENT	0
460683	460084	19812Y	PARTICIPANT	\N	PRESENT	0
460684	460084	14197C	PARTICIPANT	\N	PRESENT	0
460685	460084	14211G	PARTICIPANT	\N	PRESENT	0
460686	460084	14257W	PARTICIPANT	\N	PRESENT	0
460687	460084	19703U	PARTICIPANT	\N	PRESENT	0
460971	458654	14199E	PARTICIPANT	\N	PRESENT	0
460986	460985	14255U	PARTICIPANT	\N	PRESENT	0
460987	460985	19721W	PARTICIPANT	\N	PRESENT	0
460988	460985	14259Y	PARTICIPANT	\N	PRESENT	0
460989	460985	97011G	PARTICIPANT	\N	PRESENT	0
460990	460985	19565D	PARTICIPANT	\N	PRESENT	0
460991	460985	19553Y	PARTICIPANT	\N	PRESENT	0
460992	460985	19551W	PARTICIPANT	\N	PRESENT	0
460993	460985	19335Q	PARTICIPANT	\N	PRESENT	0
460994	460985	92040Q	PARTICIPANT	\N	PRESENT	0
460995	460985	01062T	PARTICIPANT	\N	PRESENT	0
462258	453250	19717B	PARTICIPANT	\N	PRESENT	0
462259	453250	14038Y	PARTICIPANT	\N	EXCUSE	0
462260	453250	14097Y	PARTICIPANT	\N	PRESENT	0
462261	453250	19729F	PARTICIPANT	\N	EXCUSE	0
462262	453250	14059S	PARTICIPANT	\N	PRESENT	0
462264	453250	19301E	PARTICIPANT	\N	EXCUSE	0
462265	453250	11054L	PARTICIPANT	\N	PRESENT	0
462266	453250	08019V	PRESIDENT	0	PRESENT	0
462267	453250	19631V	PARTICIPANT	\N	PRESENT	0
463211	462692	04086Q	PARTICIPANT	\N	PRESENT	0
463212	462692	19647E	PARTICIPANT	\N	PRESENT	0
463213	462692	19651A	PARTICIPANT	\N	PRESENT	0
463214	462692	07004J	PARTICIPANT	\N	PRESENT	0
463215	462692	19687N	PARTICIPANT	\N	PRESENT	0
463216	462692	19689Q	PARTICIPANT	\N	PRESENT	0
463217	462692	11053K	PARTICIPANT	\N	PRESENT	0
463218	462692	08010L	PARTICIPANT	\N	PRESENT	0
463219	462692	11074Q	PRESIDENT	0	PRESENT	0
463220	462692	04071H	PARTICIPANT	\N	PRESENT	0
463221	462692	14085U	PARTICIPANT	\N	PRESENT	0
463222	462692	08011M	PARTICIPANT	\N	PRESENT	0
463223	462692	19545Y	PARTICIPANT	\N	PRESENT	0
463224	462692	89017R	PARTICIPANT	\N	PRESENT	0
463225	462692	14034U	PARTICIPANT	\N	PRESENT	0
475417	473071	17583W	PARTICIPANT	\N	PRESENT	0
475418	473071	19503N	PARTICIPANT	\N	PRESENT	0
475419	473557	04045F	PARTICIPANT	\N	PRESENT	0
475420	473557	95063L	PARTICIPANT	\N	PRESENT	0
475455	473391	19689Q	PARTICIPANT	\N	PRESENT	0
475456	473391	11040E	PARTICIPANT	\N	PRESENT	0
475471	473391	19762G	PARTICIPANT	\N	PRESENT	0
475472	473391	19651A	PARTICIPANT	\N	PRESENT	0
475473	473391	19691J	PARTICIPANT	\N	PRESENT	0
475474	473391	19479G	PARTICIPANT	\N	PRESENT	0
475475	473391	08017T	PARTICIPANT	\N	PRESENT	0
475476	473391	14281W	PARTICIPANT	\N	PRESENT	0
475477	473391	11067R	PARTICIPANT	\N	PRESENT	0
475478	473391	14021P	PARTICIPANT	\N	PRESENT	0
475479	473391	14085U	PARTICIPANT	\N	PRESENT	0
475480	473391	04057K	PARTICIPANT	\N	PRESENT	0
475483	473391	19563B	PARTICIPANT	\N	PRESENT	0
475487	473391	14121F	PARTICIPANT	\N	PRESENT	0
475492	473391	19545Y	PARTICIPANT	\N	PRESENT	0
475493	473391	01024M	PARTICIPANT	\N	PRESENT	0
475494	473391	11012A	PARTICIPANT	\N	PRESENT	0
475495	473391	01057W	PARTICIPANT	\N	PRESENT	0
475496	473391	01058X	PARTICIPANT	\N	PRESENT	0
475497	473391	11026G	PARTICIPANT	\N	PRESENT	0
475498	473391	19631V	PARTICIPANT	\N	PRESENT	0
475502	473391	07029T	PARTICIPANT	\N	PRESENT	0
475500	475486	80013X	PARTICIPANT	\N	PRESENT	0
475501	475486	04089T	PARTICIPANT	\N	PRESENT	0
475415	473390	19760E	PARTICIPANT	\N	PRESENT	0
475416	473390	14121F	PARTICIPANT	\N	PRESENT	0
475503	473391	19647E	PARTICIPANT	\N	PRESENT	0
475505	475504	14033T	PARTICIPANT	\N	PRESENT	0
475506	475504	80013X	PARTICIPANT	\N	PRESENT	0
475507	475504	04089T	PARTICIPANT	\N	PRESENT	0
475509	475508	14033T	PARTICIPANT	\N	PRESENT	0
475510	475508	80013X	PARTICIPANT	\N	PRESENT	0
475511	475508	04089T	PARTICIPANT	\N	PRESENT	0
475512	475256	14033T	PARTICIPANT	\N	PRESENT	0
475453	473391	01043Q	PARTICIPANT	\N	PRESENT	0
475454	473391	11074Q	PARTICIPANT	\N	PRESENT	0
475513	475256	04089T	PARTICIPANT	\N	PRESENT	0
475514	475256	80013X	PARTICIPANT	\N	PRESENT	0
475515	475256	14197C	PARTICIPANT	\N	PRESENT	0
475516	475256	19533U	PARTICIPANT	\N	PRESENT	0
475517	475256	14265W	PARTICIPANT	\N	PRESENT	0
475518	475256	11077T	PARTICIPANT	\N	PRESENT	0
475519	475256	19333N	PARTICIPANT	\N	PRESENT	0
475520	475256	11090Q	PARTICIPANT	\N	PRESENT	0
475521	475256	14357A	PARTICIPANT	\N	PRESENT	0
475522	475256	11099A	PARTICIPANT	\N	PRESENT	0
475523	475255	14033T	PARTICIPANT	\N	PRESENT	0
475524	475255	80013X	PARTICIPANT	\N	PRESENT	0
475525	475255	04089T	PARTICIPANT	\N	PRESENT	0
475527	475254	14033T	PARTICIPANT	\N	PRESENT	0
475528	475254	80013X	PARTICIPANT	\N	PRESENT	0
475529	475254	04089T	PARTICIPANT	\N	PRESENT	0
475530	475254	11099A	PARTICIPANT	\N	PRESENT	0
475531	475250	14033T	PARTICIPANT	\N	PRESENT	0
475532	475250	04089T	PARTICIPANT	\N	PRESENT	0
475533	475257	14033T	PARTICIPANT	\N	PRESENT	0
475535	475257	80013X	PARTICIPANT	\N	PRESENT	0
475537	475257	04089T	PARTICIPANT	\N	PRESENT	0
475539	475257	14357A	PARTICIPANT	\N	PRESENT	0
475541	475257	11099A	PARTICIPANT	\N	PRESENT	0
475542	475257	14083S	PARTICIPANT	\N	PRESENT	0
475543	475257	19533U	PARTICIPANT	\N	PRESENT	0
475544	475257	95067Q	PARTICIPANT	\N	PRESENT	0
475545	475257	14257W	PARTICIPANT	\N	PRESENT	0
475546	475257	19575F	PARTICIPANT	\N	PRESENT	0
475548	475547	14033T	PARTICIPANT	\N	PRESENT	0
475549	475547	80013X	PARTICIPANT	\N	PRESENT	0
475550	475547	04089T	PARTICIPANT	\N	PRESENT	0
475551	475547	14357A	PARTICIPANT	\N	PRESENT	0
475552	475547	11099A	PARTICIPANT	\N	PRESENT	0
475553	473391	14157T	PARTICIPANT	\N	PRESENT	0
475554	473391	19794Q	PARTICIPANT	\N	PRESENT	0
475555	473391	19347U	PARTICIPANT	\N	PRESENT	0
475556	473391	19820Y	PARTICIPANT	\N	PRESENT	0
475558	475557	08028W	PARTICIPANT	\N	PRESENT	0
475559	475557	08068F	PARTICIPANT	\N	PRESENT	0
475560	475557	01043Q	PARTICIPANT	\N	PRESENT	0
475562	475561	08028W	PARTICIPANT	\N	PRESENT	0
475563	475561	08068F	PARTICIPANT	\N	PRESENT	0
475564	475561	01043Q	PARTICIPANT	\N	PRESENT	0
475566	475565	08028W	PARTICIPANT	\N	PRESENT	0
475567	475565	08068F	PARTICIPANT	\N	PRESENT	0
475568	475565	01043Q	PARTICIPANT	\N	PRESENT	0
475570	475569	08028W	PARTICIPANT	\N	PRESENT	0
475571	475569	08068F	PARTICIPANT	\N	PRESENT	0
475572	475569	01043Q	PARTICIPANT	\N	PRESENT	0
475573	473391	19551W	PARTICIPANT	\N	PRESENT	0
475575	475574	08028W	PARTICIPANT	\N	PRESENT	0
475576	475574	08068F	PARTICIPANT	\N	PRESENT	0
475577	475574	01043Q	PARTICIPANT	\N	PRESENT	0
475579	475578	08028W	PARTICIPANT	\N	PRESENT	0
475580	475578	08068F	PARTICIPANT	\N	PRESENT	0
475581	475578	19563B	PARTICIPANT	\N	PRESENT	0
475582	475578	19369B	PARTICIPANT	\N	PRESENT	0
475583	475578	19782L	PARTICIPANT	\N	PRESENT	0
475585	475584	08028W	PARTICIPANT	\N	PRESENT	0
475586	475584	08068F	PARTICIPANT	\N	PRESENT	0
475587	475584	01043Q	PARTICIPANT	\N	PRESENT	0
475589	473391	14069U	PARTICIPANT	\N	PRESENT	0
475590	475588	08028W	PARTICIPANT	\N	PRESENT	0
475591	475588	08068F	PARTICIPANT	\N	PRESENT	0
475592	473391	19701S	PARTICIPANT	\N	PRESENT	0
475593	475588	19782L	PARTICIPANT	\N	PRESENT	0
475594	473391	14034U	PARTICIPANT	\N	PRESENT	0
475595	473391	04092N	PARTICIPANT	\N	PRESENT	0
475597	475596	08028W	PARTICIPANT	\N	PRESENT	0
475598	475596	08068F	PARTICIPANT	\N	PRESENT	0
475599	475596	01043Q	PARTICIPANT	\N	PRESENT	0
475600	475596	19369B	PARTICIPANT	\N	PRESENT	0
475602	475601	08028W	PARTICIPANT	\N	PRESENT	0
475603	475601	08068F	PARTICIPANT	\N	PRESENT	0
475604	475601	01043Q	PARTICIPANT	\N	PRESENT	0
475605	475601	19369B	PARTICIPANT	\N	PRESENT	0
475607	475606	08028W	PARTICIPANT	\N	PRESENT	0
475608	475606	08068F	PARTICIPANT	\N	PRESENT	0
475609	475606	01043Q	PARTICIPANT	\N	PRESENT	0
475611	475610	08028W	PARTICIPANT	\N	PRESENT	0
475612	475610	08068F	PARTICIPANT	\N	PRESENT	0
475613	475610	01043Q	PARTICIPANT	\N	PRESENT	0
475615	475614	08028W	PARTICIPANT	\N	PRESENT	0
475616	475614	08068F	PARTICIPANT	\N	PRESENT	0
475617	475614	14033T	PARTICIPANT	\N	PRESENT	0
475619	475618	08028W	PARTICIPANT	\N	PRESENT	0
475620	475618	08068F	PARTICIPANT	\N	PRESENT	0
475621	475618	01043Q	PARTICIPANT	\N	PRESENT	0
475622	475618	19369B	PARTICIPANT	\N	PRESENT	0
475627	475623	19369B	PARTICIPANT	\N	PRESENT	0
475625	475623	08028W	PARTICIPANT	\N	PRESENT	0
475626	475623	01043Q	PARTICIPANT	\N	PRESENT	0
475629	475628	08028W	PARTICIPANT	\N	PRESENT	0
475630	475628	08068F	PARTICIPANT	\N	PRESENT	0
475631	475628	01043Q	PARTICIPANT	\N	PRESENT	0
475632	475628	14033T	PARTICIPANT	\N	PRESENT	0
475635	475633	08028W	PARTICIPANT	\N	PRESENT	0
475636	475633	08068F	PARTICIPANT	\N	PRESENT	0
475637	475633	01043Q	PARTICIPANT	\N	PRESENT	0
475638	475633	19467C	PARTICIPANT	\N	PRESENT	0
475648	470584	19760E	PARTICIPANT	\N	PRESENT	0
475649	470584	04092N	PARTICIPANT	\N	PRESENT	0
475650	470584	19687N	PARTICIPANT	\N	PRESENT	0
475651	470584	12041X	PARTICIPANT	\N	PRESENT	0
475652	470584	19695N	PARTICIPANT	\N	PRESENT	0
475653	470584	19551W	PARTICIPANT	\N	PRESENT	0
475654	470584	17779H	PARTICIPANT	\N	PRESENT	0
475656	470584	11067R	PARTICIPANT	\N	PRESENT	0
475657	470584	14093U	PARTICIPANT	\N	PRESENT	0
475658	470584	19697Q	PARTICIPANT	\N	PRESENT	0
475659	470584	19866P	PARTICIPANT	\N	PRESENT	0
475660	470584	14087W	PARTICIPANT	\N	PRESENT	0
475661	470584	19533U	PARTICIPANT	\N	PRESENT	0
475662	470584	14069U	PARTICIPANT	\N	PRESENT	0
475663	470584	19679N	PARTICIPANT	\N	PRESENT	0
475664	470584	04085P	PARTICIPANT	\N	PRESENT	0
475665	470584	19593H	PARTICIPANT	\N	PRESENT	0
475666	470584	14207L	PARTICIPANT	\N	PRESENT	0
475667	470584	19521Q	PARTICIPANT	\N	PRESENT	0
475668	470584	14237S	PARTICIPANT	\N	PRESENT	0
475669	470584	14157T	PARTICIPANT	\N	PRESENT	0
475673	470584	19701S	PARTICIPANT	\N	PRESENT	0
475675	470584	19693L	PARTICIPANT	\N	PRESENT	0
475677	470584	19631V	PARTICIPANT	\N	PRESENT	0
475679	470584	14021P	PARTICIPANT	\N	PRESENT	0
475680	475634	08049C	PARTICIPANT	\N	PRESENT	0
475681	475634	19335Q	PRESIDENT	0	PRESENT	0
458647	453247	11010L	PARTICIPANT	\N	EXCUSE	0
458648	453247	19319Q	PARTICIPANT	\N	PRESENT	0
458649	453247	11054L	PARTICIPANT	\N	PRESENT	0
458650	453247	08019V	PRESIDENT	0	PRESENT	0
458651	453247	14331P	PARTICIPANT	\N	PRESENT	0
458652	453247	19301E	PARTICIPANT	\N	EXCUSE	0
458678	458657	04086Q	PARTICIPANT	\N	EXCUSE	0
458759	458757	04070G	PRESIDENT	0	PRESENT	0
458760	458757	08017T	PARTICIPANT	\N	PRESENT	0
458761	458757	04059M	PARTICIPANT	\N	PRESENT	0
458762	458757	14229S	PARTICIPANT	\N	PRESENT	0
458764	458757	19399H	PARTICIPANT	\N	PRESENT	0
458767	458757	19533U	PARTICIPANT	\N	PRESENT	0
458770	458757	19766L	PARTICIPANT	\N	PRESENT	0
458771	458757	19749K	PARTICIPANT	\N	PRESENT	0
458772	458757	11043H	PARTICIPANT	\N	PRESENT	0
458774	458757	07033P	PARTICIPANT	\N	PRESENT	0
458775	458757	19731Y	PARTICIPANT	\N	PRESENT	0
458777	458757	14241N	PARTICIPANT	\N	PRESENT	0
458779	458757	19693L	PARTICIPANT	\N	PRESENT	0
458780	458757	08043V	PARTICIPANT	\N	PRESENT	0
458781	458757	19699S	PARTICIPANT	\N	PRESENT	0
458782	458757	19611R	PARTICIPANT	\N	PRESENT	0
458783	458757	14030Q	PARTICIPANT	\N	PRESENT	0
458784	458757	19758L	PARTICIPANT	\N	PRESENT	0
458785	458757	08039A	PARTICIPANT	\N	EXCUSE	0
458786	458757	04057K	PARTICIPANT	\N	EXCUSE	0
458787	458757	14063N	PARTICIPANT	\N	EXCUSE	0
458788	458757	14107H	PARTICIPANT	\N	EXCUSE	0
458789	458757	08031R	PARTICIPANT	\N	EXCUSE	0
458790	458757	19573D	PARTICIPANT	\N	PRESENT	0
458791	458757	14073Q	PARTICIPANT	\N	PRESENT	0
458792	458757	11067R	PARTICIPANT	\N	PRESENT	0
462610	462569	07004J	PARTICIPANT	\N	PRESENT	0
462611	462569	08010L	PARTICIPANT	\N	PRESENT	0
462612	462569	19719D	PRESIDENT	0	PRESENT	0
462613	462569	19673G	PARTICIPANT	\N	PRESENT	0
462614	462569	19421M	PARTICIPANT	\N	EXCUSE	0
462615	462569	04044E	PARTICIPANT	\N	EXCUSE	0
462616	462569	04040A	PARTICIPANT	\N	PRESENT	0
462622	462570	04040A	PARTICIPANT	\N	PRESENT	0
462623	462570	08010L	PARTICIPANT	\N	PRESENT	0
462624	462570	19719D	PRESIDENT	0	PRESENT	0
462625	462570	19673G	PARTICIPANT	\N	PRESENT	0
462626	462570	07004J	PARTICIPANT	\N	PRESENT	0
462627	462570	19421M	PARTICIPANT	\N	EXCUSE	0
462628	462570	04044E	PARTICIPANT	\N	EXCUSE	0
462631	462479	11040E	PARTICIPANT	\N	PRESENT	0
462632	462479	19551W	PARTICIPANT	\N	PRESENT	0
462633	462479	08034U	PARTICIPANT	\N	PRESENT	0
462634	462479	19737F	PARTICIPANT	\N	PRESENT	0
462635	462479	14121F	PRESIDENT	0	PRESENT	0
462636	462479	19741B	PARTICIPANT	\N	PRESENT	0
462637	462479	11070L	PARTICIPANT	\N	PRESENT	0
462638	462479	19399H	PARTICIPANT	\N	PRESENT	0
462639	462479	14038Y	PARTICIPANT	\N	EXCUSE	0
462640	462479	15447F	PARTICIPANT	\N	EXCUSE	0
462641	462479	87003B	PARTICIPANT	\N	EXCUSE	0
462642	462479	19269X	PARTICIPANT	\N	EXCUSE	0
462643	462479	02002K	PARTICIPANT	\N	EXCUSE	0
463367	462908	86034E	PARTICIPANT	\N	PRESENT	0
463368	462908	19669L	PARTICIPANT	\N	PRESENT	0
463369	462908	04086Q	PARTICIPANT	\N	PRESENT	0
463370	462908	19527W	PARTICIPANT	\N	PRESENT	0
463371	462908	11097X	PARTICIPANT	\N	PRESENT	0
463372	462908	19687N	PARTICIPANT	\N	PRESENT	0
463373	462908	04033B	PARTICIPANT	\N	PRESENT	0
463374	462908	04085P	PARTICIPANT	\N	PRESENT	0
463375	462908	19697Q	PARTICIPANT	\N	PRESENT	0
463376	462908	11072N	PARTICIPANT	\N	PRESENT	0
463377	462908	11099A	PARTICIPANT	\N	PRESENT	0
463378	462908	14251Q	PARTICIPANT	\N	PRESENT	0
463379	462908	19611R	PARTICIPANT	\N	PRESENT	0
463380	462908	14021P	PARTICIPANT	\N	PRESENT	0
463381	462908	11085T	PARTICIPANT	\N	PRESENT	0
463382	462908	11053K	PARTICIPANT	\N	PRESENT	0
463383	462908	04071H	PARTICIPANT	\N	PRESENT	0
463446	463445	11053K	PARTICIPANT	\N	PRESENT	0
463447	463445	14159V	PARTICIPANT	\N	PRESENT	0
463448	463445	05012A	PARTICIPANT	\N	PRESENT	0
464015	463842	19782L	PARTICIPANT	\N	PRESENT	0
464016	463842	11077T	PARTICIPANT	\N	PRESENT	0
464017	463842	14357A	PARTICIPANT	\N	PRESENT	0
464018	463842	19812Y	PARTICIPANT	\N	PRESENT	0
464019	463842	19413M	PARTICIPANT	\N	PRESENT	0
464020	463842	80013X	PARTICIPANT	\N	PRESENT	0
464021	463842	04045F	PARTICIPANT	\N	PRESENT	0
464022	463842	19631V	PARTICIPANT	\N	PRESENT	0
464023	463842	04049K	PARTICIPANT	\N	PRESENT	0
464024	463842	08015R	PARTICIPANT	\N	PRESENT	0
464025	463842	08019V	PARTICIPANT	\N	PRESENT	0
464026	463842	14197C	PARTICIPANT	\N	PRESENT	0
464027	463842	08028W	PARTICIPANT	\N	PRESENT	0
464028	463842	19563B	PARTICIPANT	\N	PRESENT	0
464029	463842	14265W	PARTICIPANT	\N	PRESENT	0
464030	463842	14135M	PARTICIPANT	\N	PRESENT	0
464031	463842	19467C	PARTICIPANT	\N	PRESENT	0
464032	463842	14187A	PARTICIPANT	\N	PRESENT	0
464033	463842	08038Y	PARTICIPANT	\N	PRESENT	0
464034	463842	19695N	PARTICIPANT	\N	PRESENT	0
464035	463842	11090Q	PRESIDENT	0	PRESENT	0
464036	463842	01025N	PARTICIPANT	\N	PRESENT	0
464037	463842	14205J	PARTICIPANT	\N	PRESENT	0
464038	463842	11056N	PARTICIPANT	\N	PRESENT	0
464039	463842	14115H	PARTICIPANT	\N	PRESENT	0
464040	463842	14207L	PARTICIPANT	\N	PRESENT	0
464041	463842	19619A	PARTICIPANT	\N	PRESENT	0
464042	463842	14257W	PARTICIPANT	\N	PRESENT	0
464043	463842	19768N	PARTICIPANT	\N	PRESENT	0
464044	463842	01043Q	PARTICIPANT	\N	PRESENT	0
464045	463842	19441R	PARTICIPANT	\N	PRESENT	0
464046	463842	14081Q	PARTICIPANT	\N	PRESENT	0
464047	463842	08068F	PARTICIPANT	\N	PRESENT	0
464048	463842	19369B	PARTICIPANT	\N	PRESENT	0
464049	463842	19295A	PARTICIPANT	\N	PRESENT	0
464050	463842	19269X	PARTICIPANT	\N	PRESENT	0
464051	463842	19507S	PARTICIPANT	\N	PRESENT	0
464052	463842	96004D	PARTICIPANT	\N	PRESENT	0
464053	463842	14033T	PARTICIPANT	\N	PRESENT	0
464054	463842	19747H	PARTICIPANT	\N	PRESENT	0
464055	463842	04088S	PARTICIPANT	\N	EXCUSE	0
464205	464194	14133K	PARTICIPANT	\N	PRESENT	0
464206	464194	04040A	PARTICIPANT	\N	PRESENT	0
464207	464194	14255U	PARTICIPANT	\N	PRESENT	0
464208	464194	14105F	PARTICIPANT	\N	PRESENT	0
464209	464194	08058D	PARTICIPANT	\N	PRESENT	0
464210	464194	04042C	PRESIDENT	0	PRESENT	0
464211	464194	98029W	PARTICIPANT	\N	PRESENT	0
464212	464194	11080N	PARTICIPANT	\N	PRESENT	0
464213	464194	14267Y	PARTICIPANT	\N	PRESENT	0
464214	464194	11027H	PARTICIPANT	\N	PRESENT	0
464215	464194	11115U	PARTICIPANT	\N	PRESENT	0
464216	464194	98018T	PARTICIPANT	\N	PRESENT	0
464217	464194	19251M	PARTICIPANT	\N	PRESENT	0
464218	464194	95030B	PARTICIPANT	\N	PRESENT	0
464219	464194	04035D	PARTICIPANT	\N	PRESENT	0
464220	464194	08056B	PARTICIPANT	\N	PRESENT	0
464221	464194	14211G	PARTICIPANT	\N	PRESENT	0
464222	464194	98022P	PARTICIPANT	\N	PRESENT	0
464223	464194	11064N	PARTICIPANT	\N	PRESENT	0
464224	464194	95037J	PARTICIPANT	\N	PRESENT	0
464225	464194	14097Y	PARTICIPANT	\N	PRESENT	0
464226	464194	98005N	PARTICIPANT	\N	PRESENT	0
464227	464194	12041X	PARTICIPANT	\N	PRESENT	0
464228	464194	19709B	PARTICIPANT	\N	PRESENT	0
464229	464194	16685X	PARTICIPANT	\N	PRESENT	0
464230	464194	08053X	PARTICIPANT	\N	PRESENT	0
464231	464194	08047A	PARTICIPANT	\N	PRESENT	0
464232	464194	14028W	PARTICIPANT	\N	PRESENT	0
464233	464194	14193X	PARTICIPANT	\N	PRESENT	0
464234	464194	98050T	PARTICIPANT	\N	PRESENT	0
464235	464194	14235Q	PARTICIPANT	\N	PRESENT	0
464236	464194	19443T	PARTICIPANT	\N	PRESENT	0
464237	464194	11054L	PARTICIPANT	\N	PRESENT	0
464238	464194	19421M	PARTICIPANT	\N	PRESENT	0
464239	464194	01058X	PARTICIPANT	\N	PRESENT	0
464240	464194	19669L	PARTICIPANT	\N	PRESENT	0
464241	464194	01062T	PARTICIPANT	\N	PRESENT	0
464242	464194	11041F	PARTICIPANT	\N	PRESENT	0
464243	464194	08049C	PARTICIPANT	\N	PRESENT	0
464244	464194	11066Q	PARTICIPANT	\N	PRESENT	0
464245	464194	04034C	PARTICIPANT	\N	PRESENT	0
464246	464194	11072N	PARTICIPANT	\N	PRESENT	0
464247	464194	08019V	PARTICIPANT	\N	PRESENT	0
464447	463587	05008E	PRESIDENT	0	PRESENT	0
464448	463587	04047H	PARTICIPANT	\N	PRESENT	0
464449	463587	14021P	PARTICIPANT	\N	PRESENT	0
464450	463587	11033F	PARTICIPANT	\N	PRESENT	0
464451	463587	14065Q	PARTICIPANT	\N	PRESENT	0
472750	472734	19735D	PARTICIPANT	\N	PRESENT	0
472751	472734	04057K	PARTICIPANT	\N	PRESENT	0
472752	472734	08017T	PARTICIPANT	\N	PRESENT	0
472753	472734	19731Y	PARTICIPANT	\N	PRESENT	0
472754	472734	14251Q	PARTICIPANT	\N	PRESENT	0
472755	472734	19758L	PARTICIPANT	\N	PRESENT	0
472756	472734	19643A	PARTICIPANT	\N	PRESENT	0
472757	472734	19335Q	PARTICIPANT	\N	PRESENT	0
472758	472734	14030Q	PARTICIPANT	\N	PRESENT	0
472759	472734	11083R	PARTICIPANT	\N	PRESENT	0
472760	472734	04018C	PARTICIPANT	\N	PRESENT	0
472761	472734	14073Q	PARTICIPANT	\N	PRESENT	0
472762	472734	08039A	PARTICIPANT	\N	PRESENT	0
472763	472734	19621T	PARTICIPANT	\N	PRESENT	0
472764	472734	14123H	PARTICIPANT	\N	PRESENT	0
472765	472734	07033P	PARTICIPANT	\N	PRESENT	0
472766	472734	19399H	PARTICIPANT	\N	EXCUSE	0
472767	472734	14039A	PARTICIPANT	\N	PRESENT	0
472768	471687	08038Y	PARTICIPANT	\N	EXCUSE	0
473114	471687	14281W	PARTICIPANT	\N	EXCUSE	0
473142	471687	19687N	PARTICIPANT	\N	EXCUSE	0
473144	473143	04059M	PARTICIPANT	\N	PRESENT	0
473145	473143	11040E	PARTICIPANT	\N	PRESENT	0
473146	473143	14053L	PARTICIPANT	\N	PRESENT	0
473147	473143	11053K	PARTICIPANT	\N	PRESENT	0
473148	473143	11027H	PARTICIPANT	\N	PRESENT	0
473149	473143	04086Q	PARTICIPANT	\N	PRESENT	0
473150	473143	08052W	PARTICIPANT	\N	PRESENT	0
473151	473143	11070L	PARTICIPANT	\N	PRESENT	0
473152	473143	10006L	PARTICIPANT	\N	PRESENT	0
473153	473143	14041T	PARTICIPANT	\N	PRESENT	0
473154	473143	04089T	PARTICIPANT	\N	PRESENT	0
473155	473143	14034U	PARTICIPANT	\N	PRESENT	0
473156	473143	14231L	PARTICIPANT	\N	PRESENT	0
473157	473143	11064N	PARTICIPANT	\N	PRESENT	0
473158	473143	14081Q	PARTICIPANT	\N	PRESENT	0
473159	473143	14061L	PARTICIPANT	\N	PRESENT	0
473160	473143	14159V	PARTICIPANT	\N	PRESENT	0
473161	473143	86034E	PARTICIPANT	\N	PRESENT	0
473162	473143	08034U	PARTICIPANT	\N	PRESENT	0
473163	473143	01043Q	PARTICIPANT	\N	PRESENT	0
473164	473143	12016W	PARTICIPANT	\N	PRESENT	0
473165	473143	11072N	PARTICIPANT	\N	PRESENT	0
473166	473143	05012A	PARTICIPANT	\N	PRESENT	0
473167	473143	14135M	PARTICIPANT	\N	PRESENT	0
473168	473143	04045F	PARTICIPANT	\N	PRESENT	0
473169	473143	04044E	PARTICIPANT	\N	PRESENT	0
473338	473288	14039A	PARTICIPANT	\N	EXCUSE	0
473339	473288	11083R	PARTICIPANT	\N	EXCUSE	0
473360	472598	14097Y	PARTICIPANT	\N	PRESENT	0
473361	472598	19611R	PRESIDENT	0	PRESENT	0
473362	472598	19549D	PARTICIPANT	\N	PRESENT	0
473363	472598	19629C	PARTICIPANT	\N	PRESENT	0
473364	472598	14197C	PARTICIPANT	\N	PRESENT	0
473437	473215	19387D	PARTICIPANT	\N	PRESENT	0
473639	471007	19709B	PARTICIPANT	\N	PRESENT	0
473640	471007	01048V	PRESIDENT	0	PRESENT	0
473641	471007	19533U	PARTICIPANT	\N	PRESENT	0
473642	471007	19503N	PARTICIPANT	\N	PRESENT	0
473643	471007	01058X	PARTICIPANT	\N	PRESENT	0
473646	471007	18003S	PARTICIPANT	\N	PRESENT	0
473648	471007	19693L	PARTICIPANT	\N	EXCUSE	0
473688	471173	11065P	PARTICIPANT	\N	PRESENT	0
473695	471173	19667J	PARTICIPANT	\N	PRESENT	0
473696	471173	19467C	PARTICIPANT	\N	PRESENT	0
473697	471173	14107H	PARTICIPANT	\N	PRESENT	0
473698	471173	19421M	PARTICIPANT	\N	PRESENT	0
473709	471904	11109J	PARTICIPANT	\N	PRESENT	0
473710	471904	19717B	PARTICIPANT	\N	PRESENT	0
473711	471904	19631V	PARTICIPANT	\N	PRESENT	0
473712	471904	19577H	PARTICIPANT	\N	PRESENT	0
473713	471904	11010L	PARTICIPANT	\N	EXCUSE	0
473714	471904	19715Y	PARTICIPANT	\N	PRESENT	0
473715	471904	14097Y	PARTICIPANT	\N	PRESENT	0
473716	471904	14059S	PARTICIPANT	\N	PRESENT	0
473717	471904	14331P	PARTICIPANT	\N	PRESENT	0
473718	471904	11054L	PARTICIPANT	\N	PRESENT	0
473719	471904	19301E	PARTICIPANT	\N	PRESENT	0
473893	470887	14030Q	PARTICIPANT	\N	PRESENT	0
473894	470887	08043V	PARTICIPANT	\N	PRESENT	0
473895	470887	19701S	PARTICIPANT	\N	PRESENT	0
473896	470887	80013X	PARTICIPANT	\N	PRESENT	0
473897	470887	19599P	PARTICIPANT	\N	PRESENT	0
473898	470887	14179A	PARTICIPANT	\N	PRESENT	0
473899	470887	19715Y	PARTICIPANT	\N	PRESENT	0
473900	470887	08017T	PARTICIPANT	\N	PRESENT	0
473901	470887	14109K	PARTICIPANT	\N	PRESENT	0
473902	470887	19749K	PARTICIPANT	\N	PRESENT	0
473931	470890	19515S	PARTICIPANT	\N	PRESENT	0
473932	470890	19387D	PARTICIPANT	\N	PRESENT	0
473933	470890	19631V	PARTICIPANT	\N	PRESENT	0
473934	470890	19503N	PARTICIPANT	\N	PRESENT	0
474277	469646	10006L	PARTICIPANT	\N	PRESENT	0
474278	469646	19697Q	PARTICIPANT	\N	PRESENT	0
474279	469646	19798U	PARTICIPANT	\N	PRESENT	0
474280	469783	10006L	PARTICIPANT	\N	PRESENT	0
474281	469783	19575F	PARTICIPANT	\N	PRESENT	0
474282	469783	11031D	PARTICIPANT	\N	PRESENT	0
474283	469783	19697Q	PARTICIPANT	\N	PRESENT	0
474284	469783	19798U	PARTICIPANT	\N	PRESENT	0
474285	469783	19703U	PARTICIPANT	\N	PRESENT	0
474286	471500	10006L	PARTICIPANT	\N	PRESENT	0
474287	471500	08052W	PARTICIPANT	\N	PRESENT	0
474288	471500	19798U	PARTICIPANT	\N	PRESENT	0
474289	471500	19703U	PARTICIPANT	\N	PRESENT	0
474290	473498	14281W	PARTICIPANT	\N	PRESENT	0
474291	473498	19715Y	PARTICIPANT	\N	PRESENT	0
474292	473500	19715Y	PARTICIPANT	\N	PRESENT	0
474293	473500	14281W	PARTICIPANT	\N	PRESENT	0
474307	474306	98050T	PARTICIPANT	\N	PRESENT	0
474351	473405	17583W	PARTICIPANT	\N	PRESENT	0
474352	473405	14157T	PARTICIPANT	\N	PRESENT	0
474353	473405	19739H	PARTICIPANT	\N	PRESENT	0
474354	473405	14219Q	PARTICIPANT	\N	PRESENT	0
474355	473405	08024S	PARTICIPANT	\N	PRESENT	0
474356	473405	18083K	PARTICIPANT	\N	PRESENT	0
474357	473405	19347U	PARTICIPANT	\N	PRESENT	0
474358	473405	19737F	PARTICIPANT	\N	PRESENT	0
474359	473405	19713W	PARTICIPANT	\N	PRESENT	0
474360	473405	14029X	PARTICIPANT	\N	PRESENT	0
474361	473405	19745F	PARTICIPANT	\N	PRESENT	0
474362	473405	14169X	PARTICIPANT	\N	PRESENT	0
474363	473405	19794Q	PARTICIPANT	\N	PRESENT	0
474364	473405	19637C	PARTICIPANT	\N	PRESENT	0
474365	473405	14051J	PARTICIPANT	\N	PRESENT	0
474366	473413	19637C	PARTICIPANT	\N	PRESENT	0
474367	473413	14051J	PARTICIPANT	\N	PRESENT	0
474368	473413	17583W	PARTICIPANT	\N	PRESENT	0
474369	473413	14157T	PARTICIPANT	\N	PRESENT	0
474370	473413	19739H	PARTICIPANT	\N	PRESENT	0
474371	473413	14219Q	PARTICIPANT	\N	PRESENT	0
474372	473413	08024S	PARTICIPANT	\N	PRESENT	0
474373	473413	18083K	PARTICIPANT	\N	PRESENT	0
474374	473413	19347U	PARTICIPANT	\N	PRESENT	0
474375	473413	19737F	PARTICIPANT	\N	PRESENT	0
474376	473413	19713W	PARTICIPANT	\N	PRESENT	0
474377	473413	14029X	PARTICIPANT	\N	PRESENT	0
474378	473413	19745F	PARTICIPANT	\N	PRESENT	0
474379	473413	14169X	PARTICIPANT	\N	PRESENT	0
474380	473413	19333N	PARTICIPANT	\N	PRESENT	0
474381	473413	19820Y	PARTICIPANT	\N	PRESENT	0
474382	473413	19551W	PARTICIPANT	\N	PRESENT	0
474383	473571	19347U	PARTICIPANT	\N	PRESENT	0
474384	473571	14221J	PARTICIPANT	\N	PRESENT	0
474385	473571	14051J	PARTICIPANT	\N	PRESENT	0
474386	473571	14029X	PARTICIPANT	\N	PRESENT	0
474387	473571	19745F	PARTICIPANT	\N	PRESENT	0
474388	473571	19333N	PARTICIPANT	\N	PRESENT	0
474389	473571	19737F	PARTICIPANT	\N	PRESENT	0
474390	473571	19826F	PARTICIPANT	\N	PRESENT	0
474391	473571	19503N	PARTICIPANT	\N	PRESENT	0
474392	473571	02002K	PARTICIPANT	\N	PRESENT	0
474393	473571	19387D	PARTICIPANT	\N	PRESENT	0
474394	473571	19794Q	PARTICIPANT	\N	PRESENT	0
474395	473571	19820Y	PARTICIPANT	\N	PRESENT	0
474399	473438	19637C	PARTICIPANT	\N	PRESENT	0
474400	473438	14051J	PARTICIPANT	\N	PRESENT	0
474401	473438	19794Q	PARTICIPANT	\N	PRESENT	0
474402	473438	19387D	PARTICIPANT	\N	PRESENT	0
474403	473438	19745F	PARTICIPANT	\N	PRESENT	0
474404	473438	18083K	PARTICIPANT	\N	PRESENT	0
474405	473438	19347U	PARTICIPANT	\N	PRESENT	0
474406	473438	19820Y	PARTICIPANT	\N	PRESENT	0
455305	455304	19599P	PARTICIPANT	\N	PRESENT	0
455306	455304	14157T	PARTICIPANT	\N	PRESENT	0
455307	455304	08015R	PARTICIPANT	\N	PRESENT	0
455308	455304	14213J	PARTICIPANT	\N	PRESENT	0
455431	454867	19733B	PARTICIPANT	\N	PRESENT	0
455432	454867	19383Y	PARTICIPANT	\N	PRESENT	0
455433	454867	08009T	PARTICIPANT	\N	EXCUSE	0
456668	456667	01043Q	PARTICIPANT	\N	PRESENT	0
456669	456667	14205J	PARTICIPANT	\N	PRESENT	0
456671	456670	01043Q	PARTICIPANT	\N	PRESENT	0
456672	456670	14205J	PARTICIPANT	\N	PRESENT	0
456674	456673	01043Q	PARTICIPANT	\N	PRESENT	0
456679	456678	01043Q	PARTICIPANT	\N	PRESENT	0
456680	456678	14205J	PARTICIPANT	\N	PRESENT	0
456681	439823	14253S	PARTICIPANT	\N	PRESENT	0
457147	455746	04070G	PRESIDENT	0	PRESENT	0
457148	455746	14061L	PARTICIPANT	\N	PRESENT	0
457149	455746	19699S	PARTICIPANT	\N	PRESENT	0
457150	455746	19731Y	PARTICIPANT	\N	PRESENT	0
457151	455746	19611R	PARTICIPANT	\N	PRESENT	0
457152	455746	14109K	PARTICIPANT	\N	PRESENT	0
457153	455746	14123H	PARTICIPANT	\N	PRESENT	0
457154	455746	19693L	PARTICIPANT	\N	PRESENT	0
457155	455746	19399H	PARTICIPANT	\N	PRESENT	0
457156	455746	04018C	PARTICIPANT	\N	PRESENT	0
457157	455746	14030Q	PARTICIPANT	\N	PRESENT	0
457158	455746	19735D	PARTICIPANT	\N	PRESENT	0
457159	455746	19758L	PARTICIPANT	\N	PRESENT	0
457160	456490	19443T	PARTICIPANT	\N	PRESENT	0
457161	456490	12041X	PARTICIPANT	\N	PRESENT	0
457162	456490	04034C	PARTICIPANT	\N	PRESENT	0
457163	456490	14079W	PARTICIPANT	\N	PRESENT	0
457164	456490	01058X	PARTICIPANT	\N	PRESENT	0
457165	456490	04040A	PARTICIPANT	\N	PRESENT	0
457166	456490	16685X	PARTICIPANT	\N	PRESENT	0
457167	456490	04042C	PRESIDENT	0	PRESENT	0
457168	456490	11054L	PARTICIPANT	\N	PRESENT	0
457169	456490	19669L	PARTICIPANT	\N	PRESENT	0
457170	456490	08056B	PARTICIPANT	\N	PRESENT	0
457171	456490	11115U	PARTICIPANT	\N	PRESENT	0
457172	456490	95037J	PARTICIPANT	\N	PRESENT	0
457173	456490	14055N	PARTICIPANT	\N	PRESENT	0
457174	456490	19421M	PARTICIPANT	\N	PRESENT	0
457175	456490	08049C	PARTICIPANT	\N	PRESENT	0
457176	456490	14193X	PARTICIPANT	\N	PRESENT	0
457177	456490	08053X	PARTICIPANT	\N	PRESENT	0
457178	456490	97011G	PARTICIPANT	\N	PRESENT	0
457179	456490	08061X	PARTICIPANT	\N	PRESENT	0
457180	456490	08047A	PARTICIPANT	\N	PRESENT	0
457181	456490	98029W	PARTICIPANT	\N	PRESENT	0
457182	456490	01062T	PARTICIPANT	\N	PRESENT	0
457183	456490	11041F	PARTICIPANT	\N	PRESENT	0
457184	456490	19251M	PARTICIPANT	\N	PRESENT	0
457185	456490	19721W	PARTICIPANT	\N	PRESENT	0
457186	456490	19319Q	PARTICIPANT	\N	PRESENT	0
457187	456490	14105F	PARTICIPANT	\N	PRESENT	0
457188	456490	98018T	PARTICIPANT	\N	PRESENT	0
456645	456643	14229S	PARTICIPANT	\N	PRESENT	0
456646	456643	04057K	PARTICIPANT	\N	PRESENT	0
457189	456490	11064N	PARTICIPANT	\N	PRESENT	0
457190	456490	98050T	PARTICIPANT	\N	PRESENT	0
457191	456490	14211G	PARTICIPANT	\N	PRESENT	0
457298	456226	14327T	PARTICIPANT	\N	PRESENT	0
457299	456226	14331P	PARTICIPANT	\N	PRESENT	0
457300	456226	01048V	PARTICIPANT	\N	PRESENT	0
457301	456226	01057W	PARTICIPANT	\N	PRESENT	0
457302	456226	11053K	PARTICIPANT	\N	PRESENT	0
457303	456226	11074Q	PRESIDENT	0	PRESENT	0
457304	456226	14225N	PARTICIPANT	\N	PRESENT	0
457305	456226	11070L	PARTICIPANT	\N	PRESENT	0
457306	456226	19671E	PARTICIPANT	\N	PRESENT	0
457307	456226	07029T	PARTICIPANT	\N	PRESENT	0
457308	456226	14085U	PARTICIPANT	\N	PRESENT	0
457309	456226	96004D	PARTICIPANT	\N	PRESENT	0
457310	456226	19349W	PARTICIPANT	\N	PRESENT	0
457311	456226	14253S	PARTICIPANT	\N	PRESENT	0
457312	456226	11048N	PARTICIPANT	\N	PRESENT	0
457313	456226	19711U	PARTICIPANT	\N	PRESENT	0
457314	456226	19531S	PARTICIPANT	\N	PRESENT	0
457315	456226	08034U	PARTICIPANT	\N	PRESENT	0
457316	456226	08069G	PARTICIPANT	\N	PRESENT	0
457317	456226	19687N	PARTICIPANT	\N	PRESENT	0
457318	456226	08011M	PARTICIPANT	\N	PRESENT	0
457319	456226	14173T	PARTICIPANT	\N	PRESENT	0
457320	456226	04086Q	PARTICIPANT	\N	PRESENT	0
457321	456226	11040E	PARTICIPANT	\N	PRESENT	0
457322	456226	14083S	PARTICIPANT	\N	PRESENT	0
457323	456226	14199E	PARTICIPANT	\N	PRESENT	0
457324	456226	14121F	PARTICIPANT	\N	PRESENT	0
457325	456226	99004R	PARTICIPANT	\N	PRESENT	0
457326	456226	89017R	PARTICIPANT	\N	PRESENT	0
457327	456226	19741B	PARTICIPANT	\N	PRESENT	0
457328	456710	14001X	PARTICIPANT	\N	PRESENT	0
457329	456710	04044E	PARTICIPANT	\N	PRESENT	0
457330	456710	19581D	PARTICIPANT	\N	PRESENT	0
457331	456710	04047H	PARTICIPANT	\N	PRESENT	0
457332	456710	19673G	PARTICIPANT	\N	PRESENT	0
457333	456710	19675J	PARTICIPANT	\N	PRESENT	0
457334	456710	01028R	PARTICIPANT	\N	PRESENT	0
457335	456710	05008E	PRESIDENT	0	PRESENT	0
457336	456710	14231L	PARTICIPANT	\N	PRESENT	0
457337	456710	19489J	PARTICIPANT	\N	PRESENT	0
457338	456710	14041T	PARTICIPANT	\N	PRESENT	0
457339	456710	14215L	PARTICIPANT	\N	PRESENT	0
457340	456710	08018U	PARTICIPANT	\N	PRESENT	0
457341	456710	11072N	PARTICIPANT	\N	PRESENT	0
457342	456710	14065Q	PARTICIPANT	\N	PRESENT	0
457343	456710	19649G	PARTICIPANT	\N	PRESENT	0
457344	456710	11010L	PARTICIPANT	\N	PRESENT	0
457345	456710	10015M	PARTICIPANT	\N	PRESENT	0
457346	456710	08045X	PARTICIPANT	\N	PRESENT	0
457347	456710	11026G	PARTICIPANT	\N	PRESENT	0
457348	456710	19253P	PARTICIPANT	\N	PRESENT	0
457349	456710	01024M	PARTICIPANT	\N	PRESENT	0
457350	456710	04038G	PARTICIPANT	\N	PRESENT	0
457351	456710	19719D	PARTICIPANT	\N	PRESENT	0
457352	456710	11033F	PARTICIPANT	\N	PRESENT	0
457353	456710	19725B	PARTICIPANT	\N	PRESENT	0
457354	456710	14089Y	PARTICIPANT	\N	PRESENT	0
457355	456710	19729F	PARTICIPANT	\N	PRESENT	0
457356	456710	95063L	PARTICIPANT	\N	PRESENT	0
457357	456710	08044W	PARTICIPANT	\N	PRESENT	0
457358	456710	14069U	PARTICIPANT	\N	PRESENT	0
457359	456710	04008A	PARTICIPANT	\N	PRESENT	0
457360	456710	19762G	PARTICIPANT	\N	PRESENT	0
457361	456710	01060R	PARTICIPANT	\N	PRESENT	0
457362	456710	14147R	PARTICIPANT	\N	PRESENT	0
457525	456617	11067R	PARTICIPANT	\N	PRESENT	0
457364	456716	01060R	PARTICIPANT	\N	PRESENT	0
457365	456716	14001X	PARTICIPANT	\N	PRESENT	0
457366	456716	04044E	PARTICIPANT	\N	PRESENT	0
457367	456716	19581D	PARTICIPANT	\N	PRESENT	0
457368	456716	04047H	PARTICIPANT	\N	PRESENT	0
457369	456716	19673G	PARTICIPANT	\N	PRESENT	0
457370	456716	19675J	PARTICIPANT	\N	PRESENT	0
457371	456716	01028R	PARTICIPANT	\N	PRESENT	0
457372	456716	05008E	PRESIDENT	0	PRESENT	0
457373	456716	14231L	PARTICIPANT	\N	PRESENT	0
457374	456716	19447X	PARTICIPANT	\N	PRESENT	0
457375	456716	19489J	PARTICIPANT	\N	PRESENT	0
457376	456716	14041T	PARTICIPANT	\N	PRESENT	0
457377	456716	14147R	PARTICIPANT	\N	PRESENT	0
457378	456716	14215L	PARTICIPANT	\N	PRESENT	0
457379	456716	08018U	PARTICIPANT	\N	PRESENT	0
457380	456716	11072N	PARTICIPANT	\N	PRESENT	0
457381	456716	19649G	PARTICIPANT	\N	PRESENT	0
457382	456716	14065Q	PARTICIPANT	\N	PRESENT	0
457383	456716	11010L	PARTICIPANT	\N	PRESENT	0
457384	456716	08045X	PARTICIPANT	\N	PRESENT	0
457385	456716	11026G	PARTICIPANT	\N	PRESENT	0
457386	456716	10015M	PARTICIPANT	\N	PRESENT	0
457387	456716	19253P	PARTICIPANT	\N	PRESENT	0
457388	456716	01024M	PARTICIPANT	\N	PRESENT	0
457389	456716	04038G	PARTICIPANT	\N	PRESENT	0
457390	456716	19719D	PARTICIPANT	\N	PRESENT	0
457391	456716	14089Y	PARTICIPANT	\N	PRESENT	0
457392	456716	19725B	PARTICIPANT	\N	PRESENT	0
457393	456716	19729F	PARTICIPANT	\N	PRESENT	0
457394	456716	95063L	PARTICIPANT	\N	PRESENT	0
457395	456716	14069U	PARTICIPANT	\N	PRESENT	0
457396	456716	04008A	PARTICIPANT	\N	PRESENT	0
457397	456716	19762G	PARTICIPANT	\N	PRESENT	0
457398	456716	14259Y	PARTICIPANT	\N	PRESENT	0
457404	456710	14053L	PARTICIPANT	\N	PRESENT	0
457405	456710	11085T	PARTICIPANT	\N	PRESENT	0
457524	456617	19697Q	PARTICIPANT	\N	PRESENT	0
457420	456226	08010L	PARTICIPANT	\N	EXCUSE	0
457421	456226	14034U	PARTICIPANT	\N	PRESENT	0
475682	475634	19798U	PARTICIPANT	\N	PRESENT	0
475683	470584	14081Q	PARTICIPANT	\N	PRESENT	0
475684	470584	11077T	PARTICIPANT	\N	PRESENT	0
475685	470584	19651A	PARTICIPANT	\N	PRESENT	0
475686	470584	19563B	PARTICIPANT	\N	PRESENT	0
475687	470584	11056N	PARTICIPANT	\N	PRESENT	0
475688	470584	01043Q	PARTICIPANT	\N	PRESENT	0
475724	470585	14207L	PARTICIPANT	\N	PRESENT	0
475725	470585	19651A	PARTICIPANT	\N	PRESENT	0
475726	470585	11090Q	PARTICIPANT	\N	PRESENT	0
475727	470585	14187A	PARTICIPANT	\N	PRESENT	0
475728	470585	19631V	PARTICIPANT	\N	PRESENT	0
475729	470585	11067R	PARTICIPANT	\N	PRESENT	0
475730	470585	14081Q	PARTICIPANT	\N	PRESENT	0
475731	470585	11056N	PARTICIPANT	\N	PRESENT	0
475732	470585	12041X	PARTICIPANT	\N	PRESENT	0
475733	470585	19695N	PARTICIPANT	\N	PRESENT	0
475734	470585	01043Q	PARTICIPANT	\N	PRESENT	0
475735	470585	14093U	PARTICIPANT	\N	PRESENT	0
475736	470585	14251Q	PARTICIPANT	\N	PRESENT	0
475737	470585	19563B	PARTICIPANT	\N	PRESENT	0
475738	470585	19693L	PARTICIPANT	\N	PRESENT	0
475739	470585	14157T	PARTICIPANT	\N	PRESENT	0
475740	470585	19533U	PARTICIPANT	\N	PRESENT	0
475741	470585	04085P	PARTICIPANT	\N	PRESENT	0
475742	470585	11077T	PARTICIPANT	\N	PRESENT	0
475760	475758	19503N	PARTICIPANT	\N	PRESENT	0
475763	475761	19503N	PARTICIPANT	\N	PRESENT	0
475766	475764	19503N	PARTICIPANT	\N	PRESENT	0
475769	475767	19503N	PARTICIPANT	\N	PRESENT	0
475772	475770	19503N	PARTICIPANT	\N	PRESENT	0
475775	475773	19503N	PARTICIPANT	\N	PRESENT	0
475722	470585	14034U	PARTICIPANT	\N	PRESENT	0
475723	470585	19866P	PARTICIPANT	\N	PRESENT	0
475778	475776	19503N	PARTICIPANT	\N	PRESENT	0
475781	475779	19503N	PARTICIPANT	\N	PRESENT	0
475784	475783	99004R	PRESIDENT	0	PRESENT	0
475785	475783	19711U	PARTICIPANT	\N	PRESENT	0
475786	475783	11097X	PARTICIPANT	\N	EXCUSE	0
475787	470585	19521Q	PARTICIPANT	\N	PRESENT	0
475788	470585	19569H	PARTICIPANT	\N	PRESENT	0
475789	470585	19347U	PARTICIPANT	\N	PRESENT	0
475820	475783	19399H	PARTICIPANT	\N	EXCUSE	0
475821	470586	04092N	PARTICIPANT	\N	PRESENT	0
475822	470586	14042U	PARTICIPANT	\N	PRESENT	0
475823	470586	19683J	PARTICIPANT	\N	PRESENT	0
475824	470586	11067R	PARTICIPANT	\N	PRESENT	0
475825	470586	19553Y	PARTICIPANT	\N	PRESENT	0
475826	470586	19569H	PARTICIPANT	\N	PRESENT	0
475827	470586	14195A	PARTICIPANT	\N	PRESENT	0
475828	470586	11031D	PARTICIPANT	\N	PRESENT	0
475831	470586	11097X	PARTICIPANT	\N	PRESENT	0
475832	470586	19591F	PARTICIPANT	\N	PRESENT	0
475833	470586	19585H	PARTICIPANT	\N	PRESENT	0
475834	470586	19693L	PARTICIPANT	\N	PRESENT	0
475844	470586	19565D	PARTICIPANT	\N	PRESENT	0
475845	470586	19760E	PARTICIPANT	\N	PRESENT	0
475849	470586	19697Q	PARTICIPANT	\N	PRESENT	0
475850	472990	19768N	PARTICIPANT	\N	PRESENT	0
475851	472990	19515S	PARTICIPANT	\N	PRESENT	0
475852	472990	19782L	PARTICIPANT	\N	PRESENT	0
475853	472990	19441R	PARTICIPANT	\N	PRESENT	0
475854	472990	14081Q	PARTICIPANT	\N	PRESENT	0
475855	472990	80013X	PARTICIPANT	\N	PRESENT	0
475818	470586	11027H	PARTICIPANT	\N	PRESENT	0
475819	475783	19737F	PARTICIPANT	\N	PRESENT	0
475856	472990	11099A	PARTICIPANT	\N	PRESENT	0
475857	472990	08068F	PARTICIPANT	\N	PRESENT	0
475858	472990	04049K	PARTICIPANT	\N	PRESENT	0
475859	472990	08015R	PARTICIPANT	\N	PRESENT	0
475860	472990	14197C	PARTICIPANT	\N	PRESENT	0
475861	472990	08028W	PARTICIPANT	\N	PRESENT	0
475862	472990	19563B	PARTICIPANT	\N	PRESENT	0
475863	472990	14265W	PARTICIPANT	\N	PRESENT	0
475864	472990	19467C	PARTICIPANT	\N	PRESENT	0
475865	472990	08038Y	PARTICIPANT	\N	PRESENT	0
475866	472990	11090Q	PRESIDENT	0	PRESENT	0
475867	472990	01025N	PARTICIPANT	\N	PRESENT	0
475868	472990	14205J	PARTICIPANT	\N	PRESENT	0
475869	472990	11056N	PARTICIPANT	\N	PRESENT	0
475870	472990	04089T	PARTICIPANT	\N	PRESENT	0
475871	472990	14115H	PARTICIPANT	\N	PRESENT	0
475872	472990	19747H	PARTICIPANT	\N	PRESENT	0
475873	472990	14207L	PARTICIPANT	\N	PRESENT	0
475874	472990	19619A	PARTICIPANT	\N	PRESENT	0
475875	472990	14257W	PARTICIPANT	\N	PRESENT	0
475876	472990	14329V	PARTICIPANT	\N	PRESENT	0
475877	472990	19507S	PARTICIPANT	\N	PRESENT	0
475878	470586	04040A	PARTICIPANT	\N	PRESENT	0
475880	470586	11053K	PARTICIPANT	\N	PRESENT	0
475881	470586	10015M	PARTICIPANT	\N	PRESENT	0
475882	470586	14219Q	PARTICIPANT	\N	PRESENT	0
475883	470586	11065P	PARTICIPANT	\N	PRESENT	0
475885	472990	19705W	PARTICIPANT	\N	PRESENT	0
475886	472990	14135M	PARTICIPANT	\N	PRESENT	0
475887	472990	14187A	PARTICIPANT	\N	PRESENT	0
475888	472990	14033T	PARTICIPANT	\N	EXCUSE	0
475889	470586	19533U	PARTICIPANT	\N	PRESENT	0
475891	470586	07004J	PARTICIPANT	\N	PRESENT	0
475895	475893	19503N	PARTICIPANT	\N	PRESENT	0
475904	474577	14187A	PARTICIPANT	\N	PRESENT	0
475905	474577	14081Q	PARTICIPANT	\N	PRESENT	0
475945	475944	14187A	PARTICIPANT	\N	PRESENT	0
475947	475946	14187A	PARTICIPANT	\N	PRESENT	0
475948	475946	14081Q	PARTICIPANT	\N	PRESENT	0
475949	475946	01043Q	PARTICIPANT	\N	PRESENT	0
475951	475950	14187A	PARTICIPANT	\N	PRESENT	0
475952	475950	14081Q	PARTICIPANT	\N	PRESENT	0
475954	475953	14187A	PARTICIPANT	\N	PRESENT	0
475955	475953	14081Q	PARTICIPANT	\N	PRESENT	0
475957	475956	14187A	PARTICIPANT	\N	PRESENT	0
475958	475956	14081Q	PARTICIPANT	\N	PRESENT	0
475960	475959	14187A	PARTICIPANT	\N	PRESENT	0
475961	475959	14081Q	PARTICIPANT	\N	PRESENT	0
475963	475962	14187A	PARTICIPANT	\N	PRESENT	0
475964	475962	14081Q	PARTICIPANT	\N	PRESENT	0
475966	475965	14187A	PARTICIPANT	\N	PRESENT	0
475967	475965	14081Q	PARTICIPANT	\N	PRESENT	0
475969	475968	14187A	PARTICIPANT	\N	PRESENT	0
475970	475968	14081Q	PARTICIPANT	\N	PRESENT	0
475972	475971	14187A	PARTICIPANT	\N	PRESENT	0
475973	475971	14081Q	PARTICIPANT	\N	PRESENT	0
475975	475974	14081Q	PARTICIPANT	\N	PRESENT	0
475992	475783	19741B	PARTICIPANT	\N	EXCUSE	0
475993	475991	19667J	PARTICIPANT	\N	PRESENT	0
475994	475991	04086Q	PARTICIPANT	\N	PRESENT	0
475995	475991	19647E	PARTICIPANT	\N	PRESENT	0
475996	475991	19545Y	PARTICIPANT	\N	PRESENT	0
475997	475991	99004R	PARTICIPANT	\N	PRESENT	0
475998	475991	19711U	PARTICIPANT	\N	PRESENT	0
476000	475990	08044W	PARTICIPANT	\N	PRESENT	0
476001	475990	14065Q	PARTICIPANT	\N	PRESENT	0
476003	476002	08044W	PARTICIPANT	\N	PRESENT	0
476004	476002	14065Q	PARTICIPANT	\N	PRESENT	0
476013	476012	14187A	PARTICIPANT	\N	PRESENT	0
476014	476012	14081Q	PARTICIPANT	\N	PRESENT	0
476016	476015	08044W	PARTICIPANT	\N	PRESENT	0
476017	476015	14065Q	PARTICIPANT	\N	PRESENT	0
476264	476263	04059M	PARTICIPANT	\N	PRESENT	0
476265	476263	04070G	PARTICIPANT	\N	PRESENT	0
476266	476263	08039A	PARTICIPANT	\N	PRESENT	0
476270	476269	11053K	PARTICIPANT	\N	PRESENT	0
476271	476269	14159V	PARTICIPANT	\N	PRESENT	0
476272	476269	05012A	PARTICIPANT	\N	PRESENT	0
476274	476273	14039A	PARTICIPANT	\N	PRESENT	0
476275	476273	19695N	PARTICIPANT	\N	PRESENT	0
476276	476273	14267Y	PARTICIPANT	\N	PRESENT	0
476277	476273	19729F	PARTICIPANT	\N	PRESENT	0
476278	476273	04086Q	PARTICIPANT	\N	PRESENT	0
476279	476273	14217N	PARTICIPANT	\N	PRESENT	0
476280	476273	95067Q	PARTICIPANT	\N	PRESENT	0
476281	476273	19525U	PARTICIPANT	\N	PRESENT	0
476282	476273	11064N	PARTICIPANT	\N	PRESENT	0
476285	476273	19295A	PARTICIPANT	\N	PRESENT	0
476286	476273	19629C	PARTICIPANT	\N	PRESENT	0
476287	472063	04092N	PRESIDENT	0	PRESENT	0
476288	472063	11031D	PARTICIPANT	\N	PRESENT	0
476289	472063	10006L	PARTICIPANT	\N	PRESENT	0
476290	472063	14042U	PARTICIPANT	\N	PRESENT	0
456676	456675	11097X	PARTICIPANT	\N	PRESENT	0
456677	456675	01034P	PARTICIPANT	\N	PRESENT	0
456715	456714	19507S	PARTICIPANT	\N	PRESENT	0
456719	456718	11054L	PARTICIPANT	\N	PRESENT	0
456720	456718	11026G	PARTICIPANT	\N	PRESENT	0
456721	456718	95067Q	PARTICIPANT	\N	PRESENT	0
456722	456718	97011G	PARTICIPANT	\N	PRESENT	0
456730	456729	14041T	PARTICIPANT	\N	PRESENT	0
456724	456718	19647E	PARTICIPANT	\N	PRESENT	0
456726	456725	99004R	PARTICIPANT	\N	PRESENT	0
456733	456732	14041T	PARTICIPANT	\N	PRESENT	0
456734	456732	19741B	PARTICIPANT	\N	PRESENT	0
457917	448757	19585H	PARTICIPANT	\N	PRESENT	0
458212	448760	11072N	PARTICIPANT	\N	PRESENT	0
458223	448760	14071N	PARTICIPANT	\N	PRESENT	0
458224	448760	07029T	PARTICIPANT	\N	PRESENT	0
458225	448760	14041T	PARTICIPANT	\N	PRESENT	0
458226	448760	19693L	PARTICIPANT	\N	PRESENT	0
458227	448760	01024M	PARTICIPANT	\N	PRESENT	0
458228	448760	19713W	PARTICIPANT	\N	PRESENT	0
458229	448760	17589D	PARTICIPANT	\N	PRESENT	0
458230	448760	14195A	PARTICIPANT	\N	PRESENT	0
458231	448760	19681G	PARTICIPANT	\N	PRESENT	0
458232	448760	19697Q	PARTICIPANT	\N	PRESENT	0
458233	448760	19629C	PARTICIPANT	\N	PRESENT	0
458234	448760	14281W	PARTICIPANT	\N	PRESENT	0
458235	448760	11067R	PARTICIPANT	\N	PRESENT	0
458367	439828	11072N	PARTICIPANT	\N	PRESENT	0
458237	448760	19593H	PARTICIPANT	\N	PRESENT	0
458238	455397	14051J	PARTICIPANT	\N	PRESENT	0
458239	455397	08060W	PARTICIPANT	\N	PRESENT	0
458240	455397	08009T	PRESIDENT	0	PRESENT	0
458241	455397	19413M	PARTICIPANT	\N	PRESENT	0
458242	455397	19367Y	PARTICIPANT	\N	PRESENT	0
458243	455397	19581D	PARTICIPANT	\N	PRESENT	0
458244	448760	19760E	PARTICIPANT	\N	PRESENT	0
458245	448760	14267Y	PARTICIPANT	\N	PRESENT	0
458246	455397	95067Q	PARTICIPANT	\N	PRESENT	0
458247	448760	19798U	PARTICIPANT	\N	PRESENT	0
458248	448760	97011G	PARTICIPANT	\N	PRESENT	0
458249	448760	14147R	PARTICIPANT	\N	PRESENT	0
458250	455397	19251M	PARTICIPANT	\N	PRESENT	0
458251	448760	19415P	PARTICIPANT	\N	PRESENT	0
458252	448760	14191V	PARTICIPANT	\N	PRESENT	0
458253	448760	19727D	PARTICIPANT	\N	PRESENT	0
458254	448760	19443T	PARTICIPANT	\N	PRESENT	0
458368	439828	11067R	PARTICIPANT	\N	PRESENT	0
458256	448760	19691J	PARTICIPANT	\N	PRESENT	0
458257	457099	04070G	PARTICIPANT	\N	PRESENT	0
458258	457099	14079W	PARTICIPANT	\N	PRESENT	0
458259	457099	14219Q	PRESIDENT	0	PRESENT	0
458260	457099	89017R	PARTICIPANT	\N	PRESENT	0
458261	457099	19585H	PARTICIPANT	\N	PRESENT	0
458263	457099	19631V	PARTICIPANT	\N	PRESENT	0
458264	457099	14229S	PARTICIPANT	\N	PRESENT	0
458265	457099	01028R	PARTICIPANT	\N	PRESENT	0
458266	457099	19573D	PARTICIPANT	\N	PRESENT	0
458267	457099	14085U	PARTICIPANT	\N	PRESENT	0
458268	457099	08015R	PARTICIPANT	\N	PRESENT	0
458269	457099	19503N	PARTICIPANT	\N	PRESENT	0
458270	457099	19575F	PARTICIPANT	\N	PRESENT	0
458271	457099	19349W	PARTICIPANT	\N	PRESENT	0
458272	457099	14215L	PARTICIPANT	\N	PRESENT	0
458273	457099	14265W	PARTICIPANT	\N	PRESENT	0
458274	457099	14059S	PARTICIPANT	\N	PRESENT	0
458275	457099	19467C	PARTICIPANT	\N	PRESENT	0
458276	457099	19479G	PARTICIPANT	\N	PRESENT	0
458277	457099	14073Q	PARTICIPANT	\N	PRESENT	0
458278	457099	19253P	PARTICIPANT	\N	PRESENT	0
458279	457099	04038G	PARTICIPANT	\N	PRESENT	0
458281	457099	19399H	PARTICIPANT	\N	PRESENT	0
458282	457099	14205J	PARTICIPANT	\N	PRESENT	0
458283	457099	19745F	PARTICIPANT	\N	PRESENT	0
458284	457099	19747H	PARTICIPANT	\N	PRESENT	0
458285	457099	19621T	PARTICIPANT	\N	PRESENT	0
458286	457099	14225N	PARTICIPANT	\N	EXCUSE	0
458287	448760	04092N	PARTICIPANT	\N	PRESENT	0
458288	455106	07004J	PARTICIPANT	\N	PRESENT	0
458289	455106	10015M	PARTICIPANT	\N	PRESENT	0
458290	455106	04040A	PARTICIPANT	\N	PRESENT	0
458291	455106	08053X	PARTICIPANT	\N	PRESENT	0
458292	455106	04044E	PARTICIPANT	\N	PRESENT	0
458293	455106	19673G	PRESIDENT	1	PRESENT	0
458295	448760	19591F	PARTICIPANT	\N	PRESENT	0
458296	456711	19551W	PARTICIPANT	\N	PRESENT	0
458297	456711	11040E	PARTICIPANT	\N	PRESENT	0
458298	456711	08034U	PARTICIPANT	\N	PRESENT	0
458299	456711	19531S	PARTICIPANT	\N	PRESENT	0
458300	456711	19737F	PARTICIPANT	\N	PRESENT	0
458301	456711	14121F	PRESIDENT	0	PRESENT	0
458302	456711	80013X	PARTICIPANT	\N	PRESENT	0
458303	456711	11070L	PARTICIPANT	\N	PRESENT	0
458304	456711	19269X	PARTICIPANT	\N	PRESENT	0
458305	456711	14169X	PARTICIPANT	\N	PRESENT	0
458306	456711	02002K	PARTICIPANT	\N	PRESENT	0
458307	456711	19525U	PARTICIPANT	\N	PRESENT	0
458308	456711	87003B	PARTICIPANT	\N	EXCUSE	0
458309	448760	19447X	PARTICIPANT	\N	PRESENT	0
458310	457099	19489J	PARTICIPANT	\N	PRESENT	0
458311	457099	14087W	PARTICIPANT	\N	EXCUSE	0
458312	457099	95063L	PARTICIPANT	\N	PRESENT	0
458314	455397	19758L	PARTICIPANT	\N	PRESENT	0
458315	455397	14026U	PARTICIPANT	\N	EXCUSE	0
458316	448760	19715Y	PARTICIPANT	\N	PRESENT	0
458317	448760	14251Q	PARTICIPANT	\N	PRESENT	0
458321	448760	19703U	PARTICIPANT	\N	PRESENT	0
458322	457099	19521Q	PARTICIPANT	\N	PRESENT	0
458328	448760	08020N	PARTICIPANT	\N	PRESENT	0
458329	448760	11043H	PARTICIPANT	\N	PRESENT	0
458330	448760	14151M	PARTICIPANT	\N	PRESENT	0
458331	448760	04043D	PARTICIPANT	\N	PRESENT	0
458369	439828	14151M	PARTICIPANT	\N	PRESENT	0
458370	439828	08018U	PARTICIPANT	\N	PRESENT	0
458371	439828	14251Q	PARTICIPANT	\N	PRESENT	0
458372	439828	17589D	PARTICIPANT	\N	PRESENT	0
458373	439828	01024M	PARTICIPANT	\N	PRESENT	0
458374	439828	19629C	PARTICIPANT	\N	PRESENT	0
458375	439828	19727D	PARTICIPANT	\N	PRESENT	0
458376	439828	19593H	PARTICIPANT	\N	PRESENT	0
458377	439828	14041T	PARTICIPANT	\N	PRESENT	0
458378	439828	08020N	PARTICIPANT	\N	PRESENT	0
458379	439828	19693L	PARTICIPANT	\N	PRESENT	0
458380	439828	04043D	PARTICIPANT	\N	PRESENT	0
458381	439828	14069U	PARTICIPANT	\N	PRESENT	0
458382	439828	19798U	PARTICIPANT	\N	PRESENT	0
458383	439828	19703U	PARTICIPANT	\N	PRESENT	0
458384	439828	19447X	PARTICIPANT	\N	PRESENT	0
458385	439828	19713W	PARTICIPANT	\N	PRESENT	0
458386	439828	19467C	PARTICIPANT	\N	PRESENT	0
458387	439828	19697Q	PARTICIPANT	\N	PRESENT	0
458388	439828	14089Y	PARTICIPANT	\N	PRESENT	0
458398	439828	04070G	PARTICIPANT	\N	PRESENT	0
458399	439828	05008E	PARTICIPANT	\N	PRESENT	0
458402	439828	08043V	PARTICIPANT	\N	PRESENT	0
458403	439828	95030B	PARTICIPANT	\N	PRESENT	0
458405	439828	19747H	PARTICIPANT	\N	PRESENT	0
458416	439828	19573D	PARTICIPANT	\N	PRESENT	0
458417	439828	08015R	PARTICIPANT	\N	PRESENT	0
458418	439828	14257W	PARTICIPANT	\N	PRESENT	0
458421	439828	19715Y	PARTICIPANT	\N	PRESENT	0
458423	439828	97011G	PARTICIPANT	\N	PRESENT	0
458427	439828	19749K	PARTICIPANT	\N	PRESENT	0
458428	456711	19399H	PARTICIPANT	\N	EXCUSE	0
458429	439828	19782L	PARTICIPANT	\N	PRESENT	0
458430	439828	19691J	PARTICIPANT	\N	PRESENT	0
458439	457100	14059S	PARTICIPANT	\N	PRESENT	0
458440	457100	19711U	PARTICIPANT	\N	PRESENT	0
458441	457100	14073Q	PARTICIPANT	\N	PRESENT	0
458442	457100	14079W	PARTICIPANT	\N	PRESENT	0
458443	457100	19253P	PARTICIPANT	\N	PRESENT	0
458444	457100	14219Q	PRESIDENT	0	PRESENT	0
458445	457100	04038G	PARTICIPANT	\N	PRESENT	0
458446	457100	19585H	PARTICIPANT	\N	PRESENT	0
458447	457100	19399H	PARTICIPANT	\N	PRESENT	0
458448	457100	19631V	PARTICIPANT	\N	PRESENT	0
458449	457100	14229S	PARTICIPANT	\N	PRESENT	0
458450	457100	01028R	PARTICIPANT	\N	PRESENT	0
458451	457100	14205J	PARTICIPANT	\N	PRESENT	0
474407	473438	19333N	PARTICIPANT	\N	PRESENT	0
474408	473438	19739H	PARTICIPANT	\N	PRESENT	0
474409	473438	17583W	PARTICIPANT	\N	PRESENT	0
474410	473438	08024S	PARTICIPANT	\N	PRESENT	0
474411	473438	19737F	PARTICIPANT	\N	PRESENT	0
474412	473438	14029X	PARTICIPANT	\N	PRESENT	0
474413	473438	19503N	PARTICIPANT	\N	PRESENT	0
474415	473439	19637C	PARTICIPANT	\N	PRESENT	0
474416	473439	14051J	PARTICIPANT	\N	PRESENT	0
474417	473439	19794Q	PARTICIPANT	\N	PRESENT	0
474418	473439	19387D	PARTICIPANT	\N	PRESENT	0
474419	473439	19745F	PARTICIPANT	\N	PRESENT	0
474420	473439	18083K	PARTICIPANT	\N	PRESENT	0
474421	473439	19347U	PARTICIPANT	\N	PRESENT	0
474422	473439	19820Y	PARTICIPANT	\N	PRESENT	0
474423	473439	19333N	PARTICIPANT	\N	PRESENT	0
474424	473439	19739H	PARTICIPANT	\N	PRESENT	0
474425	473439	19503N	PARTICIPANT	\N	PRESENT	0
474426	473439	19713W	PARTICIPANT	\N	PRESENT	0
474427	473439	14169X	PARTICIPANT	\N	PRESENT	0
474437	473520	14038Y	PARTICIPANT	\N	PRESENT	0
474438	473520	18083K	PARTICIPANT	\N	PRESENT	0
474439	473520	19333N	PARTICIPANT	\N	PRESENT	0
474440	473520	19794Q	PARTICIPANT	\N	PRESENT	0
474441	473520	19347U	PARTICIPANT	\N	PRESENT	0
474442	473520	19713W	PARTICIPANT	\N	PRESENT	0
474443	473520	19737F	PARTICIPANT	\N	PRESENT	0
474444	473520	19820Y	PARTICIPANT	\N	PRESENT	0
474445	473520	14169X	PARTICIPANT	\N	PRESENT	0
474446	473520	19599P	PARTICIPANT	\N	PRESENT	0
474447	473520	19739H	PARTICIPANT	\N	PRESENT	0
474448	473440	19637C	PARTICIPANT	\N	PRESENT	0
474449	473440	14051J	PARTICIPANT	\N	PRESENT	0
474450	473440	02002K	PARTICIPANT	\N	PRESENT	0
474451	473440	19503N	PARTICIPANT	\N	PRESENT	0
474452	473440	19745F	PARTICIPANT	\N	PRESENT	0
474453	473440	08024S	PARTICIPANT	\N	PRESENT	0
474454	473440	19794Q	PARTICIPANT	\N	PRESENT	0
474455	473440	19820Y	PARTICIPANT	\N	PRESENT	0
474456	473440	14157T	PARTICIPANT	\N	PRESENT	0
474457	473440	18083K	PARTICIPANT	\N	PRESENT	0
474458	473440	14219Q	PARTICIPANT	\N	PRESENT	0
474459	473440	19333N	PARTICIPANT	\N	PRESENT	0
474460	473440	19737F	PARTICIPANT	\N	PRESENT	0
474461	473440	19387D	PARTICIPANT	\N	PRESENT	0
474462	473451	19383Y	PARTICIPANT	\N	PRESENT	0
474463	473451	19387D	PARTICIPANT	\N	PRESENT	0
474464	473451	14169X	PARTICIPANT	\N	PRESENT	0
474465	473451	19737F	PARTICIPANT	\N	PRESENT	0
474466	473451	19713W	PARTICIPANT	\N	PRESENT	0
474467	473451	19794Q	PARTICIPANT	\N	PRESENT	0
474468	473451	02002K	PARTICIPANT	\N	PRESENT	0
474486	474483	19631V	PARTICIPANT	\N	PRESENT	0
474487	474483	19515S	PARTICIPANT	\N	PRESENT	0
474488	474483	19747H	PARTICIPANT	\N	PRESENT	0
474489	474483	19467C	PARTICIPANT	\N	PRESENT	0
474490	474483	14197C	PARTICIPANT	\N	PRESENT	0
474491	474483	14187A	PARTICIPANT	\N	PRESENT	0
474492	474483	11099A	PARTICIPANT	\N	PRESENT	0
474493	474483	19441R	PARTICIPANT	\N	PRESENT	0
474494	474483	19369B	PARTICIPANT	\N	PRESENT	0
474495	474483	14257W	PARTICIPANT	\N	PRESENT	0
474497	474483	14265W	PARTICIPANT	\N	PRESENT	0
474499	474483	19768N	PARTICIPANT	\N	PRESENT	0
474501	474483	19866P	PARTICIPANT	\N	PRESENT	0
474503	474483	11090Q	PARTICIPANT	\N	PRESENT	0
474504	474483	04043D	PARTICIPANT	\N	PRESENT	0
474506	474483	14135M	PARTICIPANT	\N	PRESENT	0
474508	474483	19269X	PARTICIPANT	\N	PRESENT	0
474510	474483	19705W	PARTICIPANT	\N	PRESENT	0
474849	474848	04070G	PRESIDENT	0	PRESENT	0
474883	474848	08017T	PARTICIPANT	\N	PRESENT	0
474884	474848	19766L	PARTICIPANT	\N	PRESENT	0
474885	474848	19593H	PARTICIPANT	\N	PRESENT	0
474886	474848	19621T	PARTICIPANT	\N	PRESENT	0
474887	474848	19731Y	PARTICIPANT	\N	PRESENT	0
474888	474848	08031R	PARTICIPANT	\N	PRESENT	0
474889	474848	19611R	PARTICIPANT	\N	PRESENT	0
474890	474848	14107H	PARTICIPANT	\N	PRESENT	0
474891	474848	14109K	PARTICIPANT	\N	PRESENT	0
474892	474848	19643A	PARTICIPANT	\N	PRESENT	0
474893	474848	04018C	PARTICIPANT	\N	PRESENT	0
474894	474848	14030Q	PARTICIPANT	\N	PRESENT	0
474895	474848	19335Q	PARTICIPANT	\N	PRESENT	0
474896	474848	14073Q	PARTICIPANT	\N	PRESENT	0
474897	474848	11104D	PARTICIPANT	\N	PRESENT	0
474898	474848	19758L	PARTICIPANT	\N	PRESENT	0
474899	474848	08039A	PARTICIPANT	\N	PRESENT	0
474900	474848	19399H	PARTICIPANT	\N	PRESENT	0
474902	474848	08020N	PARTICIPANT	\N	PRESENT	0
474903	474848	08043V	PARTICIPANT	\N	PRESENT	0
474904	474848	19699S	PARTICIPANT	\N	PRESENT	0
474905	474848	14241N	PARTICIPANT	\N	PRESENT	0
474906	474848	19533U	PARTICIPANT	\N	PRESENT	0
474907	474848	11083R	PARTICIPANT	\N	PRESENT	0
474908	474848	14251Q	PARTICIPANT	\N	PRESENT	0
474909	474848	14123H	PARTICIPANT	\N	PRESENT	0
474910	474848	19693L	PARTICIPANT	\N	PRESENT	0
474911	474848	14061L	PARTICIPANT	\N	PRESENT	0
474912	474848	19749K	PARTICIPANT	\N	PRESENT	0
474913	474848	11043H	PARTICIPANT	\N	PRESENT	0
474914	474848	14039A	PARTICIPANT	\N	PRESENT	0
474915	474848	04057K	PARTICIPANT	\N	PRESENT	0
474916	474848	07033P	PARTICIPANT	\N	PRESENT	0
474917	474848	04059M	PARTICIPANT	\N	PRESENT	0
475396	473215	19593H	PARTICIPANT	\N	PRESENT	0
475402	473215	19503N	PARTICIPANT	\N	PRESENT	0
475670	473557	11101A	PARTICIPANT	\N	PRESENT	0
475671	473557	14281W	PARTICIPANT	\N	PRESENT	0
475674	473557	14259Y	PARTICIPANT	\N	PRESENT	0
475676	473557	19735D	PARTICIPANT	\N	PRESENT	0
475678	473557	95067Q	PARTICIPANT	\N	PRESENT	0
475791	475790	11070L	PARTICIPANT	\N	PRESENT	0
475794	475792	19503N	PARTICIPANT	\N	PRESENT	0
475835	475795	19629C	PARTICIPANT	\N	PRESENT	0
475836	475795	14267Y	PARTICIPANT	\N	PRESENT	0
475837	475795	19525U	PARTICIPANT	\N	PRESENT	0
475838	475795	04086Q	PARTICIPANT	\N	PRESENT	0
475839	475795	14217N	PARTICIPANT	\N	PRESENT	0
475840	475795	19695N	PARTICIPANT	\N	PRESENT	0
475841	475795	14039A	PARTICIPANT	\N	PRESENT	0
475842	475795	16685X	PARTICIPANT	\N	PRESENT	0
475843	475795	19729F	PARTICIPANT	\N	PRESENT	0
475879	475795	14059S	PARTICIPANT	\N	PRESENT	0
475898	475795	19447X	PARTICIPANT	\N	PRESENT	0
475943	475795	11064N	PARTICIPANT	\N	PRESENT	0
476048	476047	04040A	PRESIDENT	0	PRESENT	0
476228	476227	08019V	PARTICIPANT	\N	PRESENT	0
476248	476247	08028W	PARTICIPANT	\N	PRESENT	0
476249	476247	01043Q	PARTICIPANT	\N	PRESENT	0
476250	476247	19369B	PARTICIPANT	\N	PRESENT	0
476255	476252	08068F	PARTICIPANT	\N	PRESENT	0
476253	476247	19467C	PARTICIPANT	\N	PRESENT	0
476254	476252	08028W	PARTICIPANT	\N	PRESENT	0
476256	476252	01043Q	PARTICIPANT	\N	PRESENT	0
476257	476252	14257W	PARTICIPANT	\N	PRESENT	0
476268	475634	19503N	PARTICIPANT	\N	EXCUSE	0
476283	475634	14026U	PARTICIPANT	\N	EXCUSE	0
476284	475634	19619A	PARTICIPANT	\N	EXCUSE	0
476448	476447	14225N	PARTICIPANT	\N	PRESENT	0
476449	476447	19515S	PARTICIPANT	\N	PRESENT	0
476450	476447	04040A	PARTICIPANT	\N	PRESENT	0
476451	476447	07033P	PARTICIPANT	\N	PRESENT	0
476452	476447	14151M	PARTICIPANT	\N	PRESENT	0
476453	476447	04035D	PARTICIPANT	\N	PRESENT	0
476454	476447	12041X	PARTICIPANT	\N	PRESENT	0
476455	476447	19766L	PARTICIPANT	\N	PRESENT	0
476456	476447	14107H	PARTICIPANT	\N	PRESENT	0
476468	476467	14331P	PARTICIPANT	\N	PRESENT	0
476474	472733	11099A	PARTICIPANT	\N	PRESENT	0
476475	472733	14061L	PARTICIPANT	\N	PRESENT	0
476476	472733	19575F	PARTICIPANT	\N	PRESENT	0
476477	472733	14261S	PARTICIPANT	\N	PRESENT	0
476478	472733	14083S	PARTICIPANT	\N	PRESENT	0
476479	472390	96004D	PARTICIPANT	\N	PRESENT	0
476480	472390	14026U	PARTICIPANT	\N	PRESENT	0
476481	472390	04035D	PARTICIPANT	\N	PRESENT	0
476482	472390	19725B	PARTICIPANT	\N	PRESENT	0
476483	472390	95037J	PARTICIPANT	\N	PRESENT	0
476484	472390	14097Y	PARTICIPANT	\N	PRESENT	0
476485	472390	11026G	PARTICIPANT	\N	PRESENT	0
476486	472390	14241N	PARTICIPANT	\N	PRESENT	0
476487	472390	08039A	PARTICIPANT	\N	PRESENT	0
476488	472390	14001X	PARTICIPANT	\N	PRESENT	0
476489	472390	14237S	PARTICIPANT	\N	PRESENT	0
476490	472390	10015M	PARTICIPANT	\N	PRESENT	0
476491	472390	14229S	PARTICIPANT	\N	PRESENT	0
476492	472390	98035U	PARTICIPANT	\N	PRESENT	0
455380	455379	14157T	PARTICIPANT	\N	PRESENT	0
455381	455379	19599P	PARTICIPANT	\N	PRESENT	0
455382	455379	14053L	PARTICIPANT	\N	PRESENT	0
455383	455379	14083S	PARTICIPANT	\N	PRESENT	0
455385	455384	19599P	PARTICIPANT	\N	PRESENT	0
455386	455384	14157T	PARTICIPANT	\N	PRESENT	0
456400	454197	14231L	PARTICIPANT	\N	PRESENT	0
456401	454197	04086Q	PARTICIPANT	\N	PRESENT	0
456402	454197	14063N	PARTICIPANT	\N	PRESENT	0
456403	454197	11101A	PARTICIPANT	\N	PRESENT	0
456404	454197	19687N	PARTICIPANT	\N	PRESENT	0
456405	454197	19253P	PRESIDENT	0	PRESENT	0
456441	454228	14221J	PARTICIPANT	\N	PRESENT	0
456442	454228	19533U	PARTICIPANT	\N	PRESENT	0
456445	454228	19709B	PARTICIPANT	\N	PRESENT	0
456447	454228	14093U	PARTICIPANT	\N	PRESENT	0
456452	454228	01058X	PARTICIPANT	\N	PRESENT	0
456463	454228	01048V	PRESIDENT	0	PRESENT	0
456465	454228	19503N	PARTICIPANT	\N	PRESENT	0
456467	454228	19693L	PARTICIPANT	\N	EXCUSE	0
456468	454228	19723Y	PARTICIPANT	\N	EXCUSE	0
456469	454228	80013X	PARTICIPANT	\N	EXCUSE	0
457526	456617	14355X	PARTICIPANT	\N	PRESENT	0
457527	456617	19798U	PARTICIPANT	\N	PRESENT	0
457528	456617	19569H	PARTICIPANT	\N	PRESENT	0
457529	456617	11097X	PARTICIPANT	\N	PRESENT	0
457530	456617	19415P	PARTICIPANT	\N	PRESENT	0
457531	456617	14227Q	PARTICIPANT	\N	PRESENT	0
457532	456617	19703U	PARTICIPANT	\N	PRESENT	0
457533	456617	14239U	PARTICIPANT	\N	PRESENT	0
457534	456617	11031D	PARTICIPANT	\N	PRESENT	0
457535	456617	19553Y	PARTICIPANT	\N	PRESENT	0
457536	456617	14087W	PARTICIPANT	\N	PRESENT	0
457537	456617	14281W	PARTICIPANT	\N	PRESENT	0
457538	456617	19679N	PARTICIPANT	\N	PRESENT	0
457539	456617	14042U	PARTICIPANT	\N	PRESENT	0
457540	456617	19575F	PARTICIPANT	\N	PRESENT	0
457541	456617	14261S	PARTICIPANT	\N	PRESENT	0
457542	456617	10006L	PARTICIPANT	\N	PRESENT	0
457543	456617	98024R	PARTICIPANT	\N	PRESENT	0
457544	456617	19521Q	PARTICIPANT	\N	PRESENT	0
457545	456617	19527W	PARTICIPANT	\N	PRESENT	0
457546	456617	04092N	PRESIDENT	0	PRESENT	0
457547	456617	11045K	PARTICIPANT	\N	PRESENT	0
457548	456617	08052W	PARTICIPANT	\N	PRESENT	0
457549	456617	19663E	PARTICIPANT	\N	PRESENT	0
457550	456617	19715Y	PARTICIPANT	\N	PRESENT	0
457551	456617	19691J	PARTICIPANT	\N	PRESENT	0
457552	456617	19717B	PARTICIPANT	\N	PRESENT	0
457553	456617	19723Y	PARTICIPANT	\N	PRESENT	0
457554	456617	14119M	PARTICIPANT	\N	PRESENT	0
457555	456617	14071N	PARTICIPANT	\N	PRESENT	0
457556	456617	11103C	PARTICIPANT	\N	PRESENT	0
457557	456617	14195A	PARTICIPANT	\N	PRESENT	0
457558	456617	19367Y	PARTICIPANT	\N	PRESENT	0
457559	456617	14026U	PARTICIPANT	\N	PRESENT	0
457560	456617	19683J	PARTICIPANT	\N	PRESENT	0
457561	456617	17779H	PARTICIPANT	\N	PRESENT	0
457562	456617	08041T	PARTICIPANT	\N	EXCUSE	0
460855	460854	10015M	PARTICIPANT	\N	PRESENT	0
460857	460856	10015M	PARTICIPANT	\N	PRESENT	0
461305	461304	19515S	PARTICIPANT	\N	PRESENT	0
461306	461304	14105F	PARTICIPANT	\N	PRESENT	0
461307	461304	08020N	PARTICIPANT	\N	PRESENT	0
461308	461304	19812Y	PARTICIPANT	\N	PRESENT	0
461309	461304	01025N	PARTICIPANT	\N	PRESENT	0
461310	461304	19820Y	PARTICIPANT	\N	PRESENT	0
461311	461304	14213J	PARTICIPANT	\N	PRESENT	0
461312	461304	19723Y	PARTICIPANT	\N	PRESENT	0
461313	461304	08015R	PARTICIPANT	\N	PRESENT	0
461314	461304	19441R	PARTICIPANT	\N	PRESENT	0
461315	461304	08053X	PARTICIPANT	\N	PRESENT	0
461316	461304	14257W	PARTICIPANT	\N	PRESENT	0
461317	461304	19745F	PARTICIPANT	\N	PRESENT	0
463268	462693	19647E	PARTICIPANT	\N	PRESENT	0
463269	462693	19687N	PARTICIPANT	\N	PRESENT	0
463728	463727	19503N	PARTICIPANT	\N	PRESENT	0
463271	462693	11053K	PARTICIPANT	\N	PRESENT	0
463730	463729	19503N	PARTICIPANT	\N	PRESENT	0
463273	462693	11074Q	PRESIDENT	0	PRESENT	0
463274	462693	08011M	PARTICIPANT	\N	PRESENT	0
464057	463589	14261S	PARTICIPANT	\N	PRESENT	0
463278	462693	04086Q	PARTICIPANT	\N	PRESENT	0
464058	463589	96004D	PARTICIPANT	\N	EXCUSE	0
464059	463589	19329S	PARTICIPANT	\N	PRESENT	0
464060	463589	19715Y	PARTICIPANT	\N	EXCUSE	0
464061	463589	14097Y	PARTICIPANT	\N	PRESENT	0
463283	462693	08010L	PARTICIPANT	\N	PRESENT	0
464062	463589	98005N	PARTICIPANT	\N	PRESENT	0
464063	463589	12016W	PARTICIPANT	\N	PRESENT	0
463286	462693	04071H	PARTICIPANT	\N	PRESENT	0
463287	462693	19651A	PARTICIPANT	\N	PRESENT	0
463288	462693	19689Q	PARTICIPANT	\N	PRESENT	0
463289	462693	89017R	PARTICIPANT	\N	PRESENT	0
463290	462693	14034U	PARTICIPANT	\N	PRESENT	0
463291	462693	14085U	PARTICIPANT	\N	PRESENT	0
463292	462693	19667J	PARTICIPANT	\N	PRESENT	0
464064	463589	08019V	PRESIDENT	0	PRESENT	0
464065	463589	19657G	PARTICIPANT	\N	EXCUSE	0
464066	463589	19319Q	PARTICIPANT	\N	EXCUSE	0
464067	463589	14225N	PARTICIPANT	\N	PRESENT	0
464068	463589	19729F	PARTICIPANT	\N	EXCUSE	0
464069	463542	11031D	PARTICIPANT	\N	EXCUSE	0
464070	463542	08024S	PARTICIPANT	\N	EXCUSE	0
464071	463542	04035D	PARTICIPANT	\N	EXCUSE	0
464072	463542	19269X	PARTICIPANT	\N	EXCUSE	0
464073	463542	14235Q	PARTICIPANT	\N	EXCUSE	0
464075	464074	14239U	PARTICIPANT	\N	PRESENT	0
464076	464074	18003S	PARTICIPANT	\N	PRESENT	0
464078	464074	14093U	PARTICIPANT	\N	PRESENT	0
464081	464074	19693L	PARTICIPANT	\N	PRESENT	0
464085	464074	14299H	PARTICIPANT	\N	PRESENT	0
464089	464074	01048V	PARTICIPANT	\N	PRESENT	0
464090	464074	14221J	PARTICIPANT	\N	PRESENT	0
464091	464074	19593H	PARTICIPANT	\N	PRESENT	0
464092	464074	19533U	PARTICIPANT	\N	PRESENT	0
464093	464074	19503N	PARTICIPANT	\N	PRESENT	0
464094	464074	04043D	PARTICIPANT	\N	PRESENT	0
464098	464097	14133K	PARTICIPANT	\N	PRESENT	0
464099	464097	04040A	PARTICIPANT	\N	PRESENT	0
464100	464097	14105F	PARTICIPANT	\N	PRESENT	0
464101	464097	08058D	PARTICIPANT	\N	PRESENT	0
464102	464097	14255U	PARTICIPANT	\N	PRESENT	0
464103	464097	04042C	PRESIDENT	0	PRESENT	0
464104	464097	98029W	PARTICIPANT	\N	PRESENT	0
464105	464097	14267Y	PARTICIPANT	\N	PRESENT	0
464106	464097	11027H	PARTICIPANT	\N	PRESENT	0
464107	464097	11115U	PARTICIPANT	\N	PRESENT	0
464108	464097	98018T	PARTICIPANT	\N	PRESENT	0
464109	464097	19251M	PARTICIPANT	\N	PRESENT	0
464110	464097	04035D	PARTICIPANT	\N	PRESENT	0
464111	464097	08056B	PARTICIPANT	\N	PRESENT	0
464112	464097	14211G	PARTICIPANT	\N	PRESENT	0
464113	464097	98022P	PARTICIPANT	\N	PRESENT	0
464114	464097	11064N	PARTICIPANT	\N	PRESENT	0
464115	464097	14097Y	PARTICIPANT	\N	PRESENT	0
464116	464097	12041X	PARTICIPANT	\N	PRESENT	0
464117	464097	19709B	PARTICIPANT	\N	PRESENT	0
464118	464097	16685X	PARTICIPANT	\N	PRESENT	0
464119	464097	08047A	PARTICIPANT	\N	PRESENT	0
464120	464097	14028W	PARTICIPANT	\N	PRESENT	0
464121	464097	14193X	PARTICIPANT	\N	PRESENT	0
464122	464097	19319Q	PARTICIPANT	\N	PRESENT	0
464123	464097	14235Q	PARTICIPANT	\N	EXCUSE	0
464124	464097	19443T	PARTICIPANT	\N	PRESENT	0
464125	464097	11054L	PARTICIPANT	\N	PRESENT	0
464126	464097	19669L	PARTICIPANT	\N	PRESENT	0
476291	472063	14281W	PARTICIPANT	\N	PRESENT	0
476292	472063	19591F	PARTICIPANT	\N	PRESENT	0
476293	472063	19691J	PARTICIPANT	\N	PRESENT	0
476294	472063	19553Y	PARTICIPANT	\N	PRESENT	0
476295	472063	19723Y	PARTICIPANT	\N	PRESENT	0
476296	472063	17779H	PARTICIPANT	\N	PRESENT	0
476297	472063	14071N	PARTICIPANT	\N	PRESENT	0
476298	472063	11097X	PARTICIPANT	\N	PRESENT	0
476299	472063	19760E	PARTICIPANT	\N	PRESENT	0
476300	472063	19717B	PARTICIPANT	\N	PRESENT	0
476301	472063	19575F	PARTICIPANT	\N	PRESENT	0
476302	472063	19415P	PARTICIPANT	\N	PRESENT	0
476303	472063	11103C	PARTICIPANT	\N	PRESENT	0
476304	472063	14195A	PARTICIPANT	\N	PRESENT	0
476305	472063	19663E	PARTICIPANT	\N	PRESENT	0
476306	472063	14217N	PARTICIPANT	\N	PRESENT	0
476307	472063	19565D	PARTICIPANT	\N	PRESENT	0
476308	476273	14059S	PARTICIPANT	\N	PRESENT	0
476309	472063	14213J	PARTICIPANT	\N	PRESENT	0
476310	472063	19697Q	PARTICIPANT	\N	PRESENT	0
476311	472063	14223L	PARTICIPANT	\N	PRESENT	0
476312	472063	14119M	PARTICIPANT	\N	PRESENT	0
476313	472063	19679N	PARTICIPANT	\N	PRESENT	0
476314	472063	19798U	PARTICIPANT	\N	PRESENT	0
476315	472063	19703U	PARTICIPANT	\N	PRESENT	0
476316	472063	19301E	PARTICIPANT	\N	PRESENT	0
476317	472063	01034P	PARTICIPANT	\N	PRESENT	0
476318	472063	08041T	PARTICIPANT	\N	EXCUSE	0
476319	472063	19521Q	PARTICIPANT	\N	EXCUSE	0
476320	472063	14355X	PARTICIPANT	\N	EXCUSE	0
476321	475634	19631V	PARTICIPANT	\N	PRESENT	0
476322	475634	19575F	PARTICIPANT	\N	PRESENT	0
476323	475634	19387D	PARTICIPANT	\N	PRESENT	0
476325	472064	19367Y	PARTICIPANT	\N	PRESENT	0
476326	472064	19717B	PARTICIPANT	\N	PRESENT	0
476327	472064	19575F	PARTICIPANT	\N	PRESENT	0
476328	472064	19415P	PARTICIPANT	\N	PRESENT	0
476329	472064	11103C	PARTICIPANT	\N	PRESENT	0
476330	472064	14195A	PARTICIPANT	\N	PRESENT	0
476331	472064	11031D	PARTICIPANT	\N	PRESENT	0
476332	472064	19663E	PARTICIPANT	\N	PRESENT	0
476333	472064	14217N	PARTICIPANT	\N	PRESENT	0
476334	472064	08041T	PARTICIPANT	\N	EXCUSE	0
476335	472064	14355X	PARTICIPANT	\N	EXCUSE	0
476336	472064	19565D	PARTICIPANT	\N	PRESENT	0
476337	472064	19691J	PARTICIPANT	\N	PRESENT	0
476338	472064	19527W	PARTICIPANT	\N	PRESENT	0
476339	472064	19569H	PARTICIPANT	\N	PRESENT	0
476340	472064	19723Y	PARTICIPANT	\N	PRESENT	0
476341	472064	19657G	PARTICIPANT	\N	PRESENT	0
476342	472064	11067R	PARTICIPANT	\N	PRESENT	0
476343	472064	14223L	PARTICIPANT	\N	PRESENT	0
476344	472064	14119M	PARTICIPANT	\N	PRESENT	0
476345	472064	19679N	PARTICIPANT	\N	PRESENT	0
476346	472064	19798U	PARTICIPANT	\N	PRESENT	0
476347	472064	11045K	PARTICIPANT	\N	PRESENT	0
476348	472064	19703U	PARTICIPANT	\N	PRESENT	0
476350	472064	01034P	PARTICIPANT	\N	PRESENT	0
476371	474276	14355X	PARTICIPANT	\N	EXCUSE	0
476372	474276	19717B	PARTICIPANT	\N	PRESENT	0
476373	474276	19575F	PARTICIPANT	\N	PRESENT	0
476374	474276	11103C	PARTICIPANT	\N	PRESENT	0
476375	474276	19727D	PARTICIPANT	\N	PRESENT	0
476376	474276	08052W	PARTICIPANT	\N	PRESENT	0
476377	474276	19663E	PARTICIPANT	\N	PRESENT	0
476378	474276	10006L	PARTICIPANT	\N	PRESENT	0
476379	474276	14217N	PARTICIPANT	\N	PRESENT	0
476380	474276	19577H	PARTICIPANT	\N	PRESENT	0
476381	474276	14281W	PARTICIPANT	\N	PRESENT	0
476382	474276	14087W	PARTICIPANT	\N	PRESENT	0
476383	474276	19565D	PARTICIPANT	\N	PRESENT	0
476384	474276	19527W	PARTICIPANT	\N	PRESENT	0
476385	474276	19591F	PARTICIPANT	\N	PRESENT	0
476386	474276	14213J	PARTICIPANT	\N	PRESENT	0
476387	474276	19723Y	PARTICIPANT	\N	PRESENT	0
476388	474276	19657G	PARTICIPANT	\N	PRESENT	0
476389	474276	14223L	PARTICIPANT	\N	PRESENT	0
476390	474276	19798U	PARTICIPANT	\N	PRESENT	0
476391	474276	11097X	PARTICIPANT	\N	PRESENT	0
476392	474276	19703U	PARTICIPANT	\N	PRESENT	0
476393	474276	19301E	PARTICIPANT	\N	PRESENT	0
476394	474276	01034P	PARTICIPANT	\N	PRESENT	0
476395	474276	14071N	PARTICIPANT	\N	EXCUSE	0
476396	473478	04092N	PRESIDENT	0	PRESENT	0
476397	473478	19717B	PARTICIPANT	\N	PRESENT	0
476398	473478	19575F	PARTICIPANT	\N	PRESENT	0
476399	473478	11103C	PARTICIPANT	\N	PRESENT	0
476400	473478	08052W	PARTICIPANT	\N	PRESENT	0
476401	473478	19663E	PARTICIPANT	\N	PRESENT	0
476402	473478	10006L	PARTICIPANT	\N	PRESENT	0
476403	473478	14217N	PARTICIPANT	\N	PRESENT	0
476404	473478	14042U	PARTICIPANT	\N	PRESENT	0
476405	473478	19565D	PARTICIPANT	\N	PRESENT	0
476406	473478	19569H	PARTICIPANT	\N	PRESENT	0
476407	473478	14213J	PARTICIPANT	\N	PRESENT	0
476408	473478	19715Y	PARTICIPANT	\N	PRESENT	0
476409	473478	19657G	PARTICIPANT	\N	PRESENT	0
476410	473478	11067R	PARTICIPANT	\N	PRESENT	0
476411	473478	14119M	PARTICIPANT	\N	PRESENT	0
476412	473478	19798U	PARTICIPANT	\N	PRESENT	0
476413	473478	11097X	PARTICIPANT	\N	PRESENT	0
476414	473478	19301E	PARTICIPANT	\N	PRESENT	0
476415	473478	01034P	PARTICIPANT	\N	PRESENT	0
476416	473478	14071N	PARTICIPANT	\N	EXCUSE	0
476421	473478	17779H	PARTICIPANT	\N	EXCUSE	0
476423	473478	14355X	PARTICIPANT	\N	EXCUSE	0
476457	472733	04049K	PRESIDENT	0	PRESENT	0
476458	472733	14255U	PARTICIPANT	\N	EXCUSE	0
476459	472733	89017R	PARTICIPANT	\N	EXCUSE	0
476460	472733	19521Q	PARTICIPANT	\N	EXCUSE	0
476461	472733	14034U	PARTICIPANT	\N	EXCUSE	0
476462	472733	14051J	PARTICIPANT	\N	EXCUSE	0
476643	476642	96004D	PRESIDENT	0	PRESENT	0
476644	476642	11083R	PARTICIPANT	\N	PRESENT	0
476645	476642	14033T	PARTICIPANT	\N	PRESENT	0
476646	476642	95037J	PARTICIPANT	\N	PRESENT	0
476647	476642	04097T	PARTICIPANT	\N	PRESENT	0
476648	476642	19569H	PARTICIPANT	\N	PRESENT	0
476957	476356	04047H	PARTICIPANT	\N	EXCUSE	0
476955	476356	11033F	PARTICIPANT	\N	PRESENT	0
476956	476356	14065Q	PARTICIPANT	\N	PRESENT	0
476958	476356	19629C	PARTICIPANT	\N	PRESENT	0
476959	476356	04038G	PARTICIPANT	\N	PRESENT	0
476960	476356	19719D	PARTICIPANT	\N	PRESENT	0
476961	476356	14041T	PARTICIPANT	\N	PRESENT	0
476962	476356	01024M	PARTICIPANT	\N	PRESENT	0
476963	476356	19673G	PARTICIPANT	\N	PRESENT	0
476964	476356	08045X	PARTICIPANT	\N	PRESENT	0
476965	476356	08018U	PARTICIPANT	\N	PRESENT	0
476966	476356	19725B	PARTICIPANT	\N	PRESENT	0
476967	476356	19489J	PARTICIPANT	\N	PRESENT	0
476968	476356	19729F	PARTICIPANT	\N	PRESENT	0
476969	476356	19581D	PARTICIPANT	\N	PRESENT	0
476970	476356	11072N	PARTICIPANT	\N	PRESENT	0
476971	476356	10015M	PARTICIPANT	\N	PRESENT	0
476972	476356	01028R	PARTICIPANT	\N	PRESENT	0
476973	476356	19675J	PARTICIPANT	\N	PRESENT	0
476974	476356	04044E	PARTICIPANT	\N	PRESENT	0
476975	476356	14001X	PARTICIPANT	\N	PRESENT	0
477092	476357	19489J	PARTICIPANT	\N	PRESENT	0
477115	477114	04070G	PRESIDENT	0	PRESENT	0
477116	477114	04018C	PARTICIPANT	\N	PRESENT	0
477117	477114	07033P	PARTICIPANT	\N	PRESENT	0
477118	477114	19758L	PARTICIPANT	\N	PRESENT	0
477119	477114	19693L	PARTICIPANT	\N	PRESENT	0
477120	477114	14030Q	PARTICIPANT	\N	PRESENT	0
477121	477114	14061L	PARTICIPANT	\N	PRESENT	0
477122	477114	19611R	PARTICIPANT	\N	PRESENT	0
477123	477114	14109K	PARTICIPANT	\N	PRESENT	0
477124	477114	19643A	PARTICIPANT	\N	PRESENT	0
477125	477114	08020N	PARTICIPANT	\N	PRESENT	0
477126	477114	19621T	PARTICIPANT	\N	PRESENT	0
477127	477114	19699S	PARTICIPANT	\N	PRESENT	0
477128	477114	14249W	PARTICIPANT	\N	PRESENT	0
477129	477114	19593H	PARTICIPANT	\N	PRESENT	0
477130	477114	14229S	PARTICIPANT	\N	PRESENT	0
477131	477114	19399H	PARTICIPANT	\N	PRESENT	0
477132	477114	19735D	PARTICIPANT	\N	PRESENT	0
477133	477114	08039A	PARTICIPANT	\N	PRESENT	0
477134	477114	11083R	PARTICIPANT	\N	PRESENT	0
477135	477114	14251Q	PARTICIPANT	\N	PRESENT	0
477136	477114	14073Q	PARTICIPANT	\N	PRESENT	0
477137	477114	19731Y	PARTICIPANT	\N	PRESENT	0
477138	477114	08017T	PARTICIPANT	\N	PRESENT	0
477139	477114	19749K	PARTICIPANT	\N	PRESENT	0
477140	477114	08031R	PARTICIPANT	\N	PRESENT	0
477141	477114	14123H	PARTICIPANT	\N	PRESENT	0
477142	477114	11043H	PARTICIPANT	\N	PRESENT	0
477143	477114	14059S	PARTICIPANT	\N	PRESENT	0
458523	439828	19563B	PARTICIPANT	\N	PRESENT	0
458524	439828	14021P	PARTICIPANT	\N	PRESENT	0
458525	439828	14121F	PARTICIPANT	\N	PRESENT	0
458526	439828	08031R	PARTICIPANT	\N	PRESENT	0
458527	439828	11026G	PARTICIPANT	\N	PRESENT	0
458528	456727	14097Y	PARTICIPANT	\N	PRESENT	0
458529	456727	19611R	PARTICIPANT	\N	PRESENT	0
458530	456727	14031R	PARTICIPANT	\N	PRESENT	0
458531	456727	19549D	PARTICIPANT	\N	PRESENT	0
458532	456727	19735D	PARTICIPANT	\N	PRESENT	0
458533	456727	19687N	PARTICIPANT	\N	PRESENT	0
458534	439828	80013X	PARTICIPANT	\N	PRESENT	0
458535	439828	19507S	PARTICIPANT	\N	PRESENT	0
458536	439828	14135M	PARTICIPANT	\N	PRESENT	0
458537	439828	08056B	PARTICIPANT	\N	PRESENT	0
458539	439828	19737F	PARTICIPANT	\N	PRESENT	0
458540	439828	14217N	PARTICIPANT	\N	PRESENT	0
458541	439828	19673G	PARTICIPANT	\N	PRESENT	0
458542	439828	19551W	PARTICIPANT	\N	PRESENT	0
458543	439828	14038Y	PARTICIPANT	\N	PRESENT	0
458544	439828	19709B	PARTICIPANT	\N	PRESENT	0
458545	439828	14026U	PARTICIPANT	\N	PRESENT	0
458560	439828	04086Q	PARTICIPANT	\N	PRESENT	0
458614	448762	04085P	PARTICIPANT	\N	PRESENT	0
458615	448762	19347U	PARTICIPANT	\N	PRESENT	0
458616	448762	19551W	PARTICIPANT	\N	PRESENT	0
458617	448762	11026G	PARTICIPANT	\N	PRESENT	0
458618	448762	80013X	PARTICIPANT	\N	PRESENT	0
458619	448762	19563B	PARTICIPANT	\N	PRESENT	0
458620	448762	14121F	PARTICIPANT	\N	PRESENT	0
458621	448762	08031R	PARTICIPANT	\N	PRESENT	0
458622	448762	19441R	PARTICIPANT	\N	PRESENT	0
458623	448762	19737F	PARTICIPANT	\N	PRESENT	0
458624	448762	14041T	PARTICIPANT	\N	PRESENT	0
458625	448762	19507S	PARTICIPANT	\N	PRESENT	0
458626	448762	19693L	PARTICIPANT	\N	PRESENT	0
458627	448762	10006L	PARTICIPANT	\N	PRESENT	0
458628	448762	14026U	PARTICIPANT	\N	PRESENT	0
458629	448762	14217N	PARTICIPANT	\N	PRESENT	0
458630	448762	19447X	PARTICIPANT	\N	PRESENT	0
458631	448762	19533U	PARTICIPANT	\N	PRESENT	0
458632	448762	19782L	PARTICIPANT	\N	PRESENT	0
458633	448762	14119M	PARTICIPANT	\N	PRESENT	0
458634	448762	14089Y	PARTICIPANT	\N	PRESENT	0
458635	448762	14073Q	PARTICIPANT	\N	PRESENT	0
458636	448762	19758L	PARTICIPANT	\N	PRESENT	0
458637	448762	19599P	PARTICIPANT	\N	PRESENT	0
458638	448762	14215L	PARTICIPANT	\N	PRESENT	0
458639	448762	19575F	PARTICIPANT	\N	PRESENT	0
458640	448762	05008E	PARTICIPANT	\N	PRESENT	0
458794	458793	14041T	PARTICIPANT	\N	PRESENT	0
458795	458793	11026G	PARTICIPANT	\N	PRESENT	0
459028	459027	80013X	PARTICIPANT	\N	PRESENT	0
459031	459030	80013X	PARTICIPANT	\N	PRESENT	0
459034	459033	80013X	PARTICIPANT	\N	PRESENT	0
459037	459036	80013X	PARTICIPANT	\N	PRESENT	0
459180	459179	19479G	PARTICIPANT	\N	PRESENT	0
459182	459181	99004R	PARTICIPANT	\N	PRESENT	0
459184	459183	99004R	PARTICIPANT	\N	PRESENT	0
460639	460596	19593H	PARTICIPANT	\N	PRESENT	0
460640	460596	04070G	PRESIDENT	0	PRESENT	0
460641	460596	19699S	PARTICIPANT	\N	PRESENT	0
460642	460596	14073Q	PARTICIPANT	\N	PRESENT	0
460643	460596	19533U	PARTICIPANT	\N	PRESENT	0
460644	460596	19611R	PARTICIPANT	\N	PRESENT	0
460645	460596	08043V	PARTICIPANT	\N	PRESENT	0
460646	460596	19693L	PARTICIPANT	\N	PRESENT	0
460647	460596	19399H	PARTICIPANT	\N	PRESENT	0
460648	460596	87003B	PARTICIPANT	\N	PRESENT	0
460649	460596	14229S	PARTICIPANT	\N	PRESENT	0
458612	448762	04086Q	PARTICIPANT	\N	PRESENT	0
458613	448762	01024M	PARTICIPANT	\N	PRESENT	0
460650	460596	14030Q	PARTICIPANT	\N	PRESENT	0
460651	460596	14241N	PARTICIPANT	\N	PRESENT	0
460652	460596	19731Y	PARTICIPANT	\N	PRESENT	0
460653	460596	08020N	PARTICIPANT	\N	PRESENT	0
460654	460596	14107H	PARTICIPANT	\N	PRESENT	0
460655	460596	08017T	PARTICIPANT	\N	PRESENT	0
460656	460596	11109J	PARTICIPANT	\N	PRESENT	0
460657	460596	14109K	PARTICIPANT	\N	PRESENT	0
460658	460596	08012N	PARTICIPANT	\N	PRESENT	0
460659	460596	11104D	PARTICIPANT	\N	PRESENT	0
460660	460596	04018C	PARTICIPANT	\N	PRESENT	0
460661	460596	19758L	PARTICIPANT	\N	PRESENT	0
460662	460596	08039A	PARTICIPANT	\N	PRESENT	0
460663	460596	14061L	PARTICIPANT	\N	EXCUSE	0
460664	460596	07033P	PARTICIPANT	\N	EXCUSE	0
460665	459124	11077T	PARTICIPANT	\N	PRESENT	0
460666	459124	11056N	PARTICIPANT	\N	PRESENT	0
460667	460596	19573D	PARTICIPANT	\N	PRESENT	0
460668	460596	14059S	PARTICIPANT	\N	PRESENT	0
460669	460596	14251Q	PARTICIPANT	\N	PRESENT	0
460670	460596	11043H	PARTICIPANT	\N	PRESENT	0
460671	460596	19335Q	PARTICIPANT	\N	PRESENT	0
460672	460596	14249W	PARTICIPANT	\N	PRESENT	0
460673	460596	19735D	PARTICIPANT	\N	PRESENT	0
460674	459124	14205J	PARTICIPANT	\N	PRESENT	0
460675	459124	19507S	PARTICIPANT	\N	PRESENT	0
460676	459124	17589D	PARTICIPANT	\N	PRESENT	0
460688	458653	11053K	PARTICIPANT	\N	PRESENT	0
460689	458653	11110B	PARTICIPANT	\N	PRESENT	0
460690	458653	14041T	PARTICIPANT	\N	PRESENT	0
460691	458653	19689Q	PARTICIPANT	\N	PRESENT	0
460692	458653	14034U	PARTICIPANT	\N	PRESENT	0
460693	458653	14159V	PARTICIPANT	\N	PRESENT	0
460833	458748	14211G	PARTICIPANT	\N	PRESENT	0
460853	460596	04057K	PARTICIPANT	\N	PRESENT	0
460858	458947	14001X	PARTICIPANT	\N	PRESENT	0
460859	458947	01060R	PARTICIPANT	\N	PRESENT	0
460860	458947	19543W	PARTICIPANT	\N	PRESENT	0
460861	458947	19581D	PARTICIPANT	\N	PRESENT	0
460862	458947	19675J	PARTICIPANT	\N	PRESENT	0
460863	458947	01028R	PARTICIPANT	\N	PRESENT	0
460864	458947	19447X	PARTICIPANT	\N	PRESENT	0
460865	458947	14231L	PARTICIPANT	\N	PRESENT	0
460866	458947	19489J	PARTICIPANT	\N	PRESENT	0
460867	458947	14147R	PARTICIPANT	\N	PRESENT	0
460868	458947	14151M	PARTICIPANT	\N	PRESENT	0
460869	458947	08018U	PARTICIPANT	\N	PRESENT	0
460870	458947	14053L	PARTICIPANT	\N	PRESENT	0
460871	458947	98035U	PARTICIPANT	\N	PRESENT	0
460872	458947	19649G	PARTICIPANT	\N	PRESENT	0
460873	458947	10015M	PARTICIPANT	\N	PRESENT	0
460874	458947	08045X	PARTICIPANT	\N	PRESENT	0
460875	458947	11026G	PARTICIPANT	\N	PRESENT	0
460876	458947	19253P	PARTICIPANT	\N	PRESENT	0
458452	457100	19489J	PARTICIPANT	\N	PRESENT	0
458453	457100	95063L	PARTICIPANT	\N	PRESENT	0
458454	457100	14085U	PARTICIPANT	\N	PRESENT	0
458455	457100	19503N	PARTICIPANT	\N	PRESENT	0
458456	457100	19575F	PARTICIPANT	\N	PRESENT	0
458457	457100	19349W	PARTICIPANT	\N	PRESENT	0
458458	457100	14215L	PARTICIPANT	\N	PRESENT	0
458459	457100	14265W	PARTICIPANT	\N	PRESENT	0
458460	457100	19521Q	PARTICIPANT	\N	PRESENT	0
458461	457100	19621T	PARTICIPANT	\N	PRESENT	0
458462	457100	14087W	PARTICIPANT	\N	EXCUSE	0
458463	457100	14225N	PARTICIPANT	\N	EXCUSE	0
458522	439828	10006L	PARTICIPANT	\N	PRESENT	0
460877	458947	19719D	PARTICIPANT	\N	PRESENT	0
461002	448773	19581D	PARTICIPANT	\N	PRESENT	0
460879	458947	19725B	PARTICIPANT	\N	PRESENT	0
460880	458947	19741B	PARTICIPANT	\N	PRESENT	0
460882	458947	11085T	PARTICIPANT	\N	PRESENT	0
461003	448773	14259Y	PARTICIPANT	\N	PRESENT	0
460886	458947	19762G	PARTICIPANT	\N	PRESENT	0
460888	458947	14021P	PARTICIPANT	\N	PRESENT	0
460890	458947	14089Y	PARTICIPANT	\N	PRESENT	0
460892	458947	14069U	PARTICIPANT	\N	PRESENT	0
460895	458947	01024M	PARTICIPANT	\N	PRESENT	0
460896	458947	14259Y	PARTICIPANT	\N	PRESENT	0
460899	458947	11072N	PARTICIPANT	\N	PRESENT	0
461004	448773	08053X	PARTICIPANT	\N	PRESENT	0
461005	448773	87003B	PARTICIPANT	\N	PRESENT	0
461006	448773	14257W	PARTICIPANT	\N	PRESENT	0
461007	448773	11101A	PARTICIPANT	\N	PRESENT	0
461008	448773	14041T	PARTICIPANT	\N	PRESENT	0
461009	448773	14173T	PARTICIPANT	\N	PRESENT	0
461010	448773	19741B	PARTICIPANT	\N	PRESENT	0
461011	448773	19675J	PARTICIPANT	\N	PRESENT	0
461012	448773	14237S	PARTICIPANT	\N	PRESENT	0
461013	448773	14277B	PARTICIPANT	\N	PRESENT	0
461014	448773	19565D	PARTICIPANT	\N	PRESENT	0
461015	448773	14083S	PARTICIPANT	\N	PRESENT	0
461016	448773	14211G	PARTICIPANT	\N	PRESENT	0
476493	472390	04057K	PARTICIPANT	\N	PRESENT	0
476494	472390	14331P	PARTICIPANT	\N	PRESENT	0
476495	472390	04097T	PARTICIPANT	\N	EXCUSE	0
476518	475783	01028R	PARTICIPANT	\N	PRESENT	0
476599	476598	14089Y	PARTICIPANT	\N	PRESENT	0
476602	476601	14089Y	PARTICIPANT	\N	PRESENT	0
476604	476603	14089Y	PARTICIPANT	\N	PRESENT	0
476607	476606	14089Y	PARTICIPANT	\N	PRESENT	0
476609	476608	14089Y	PARTICIPANT	\N	PRESENT	0
476611	476610	14089Y	PARTICIPANT	\N	PRESENT	0
476984	476642	14241N	PARTICIPANT	\N	PRESENT	0
476985	476642	14205J	PARTICIPANT	\N	PRESENT	0
476995	476993	96004D	PARTICIPANT	\N	PRESENT	0
476996	476993	14033T	PARTICIPANT	\N	PRESENT	0
476997	476993	98035U	PARTICIPANT	\N	PRESENT	0
477075	476047	14327T	PARTICIPANT	\N	EXCUSE	0
477089	477083	19715Y	PARTICIPANT	\N	PRESENT	0
477090	477083	12016W	PARTICIPANT	\N	PRESENT	0
477091	477083	19301E	PARTICIPANT	\N	PRESENT	0
477093	477083	08019V	PARTICIPANT	\N	PRESENT	0
477104	476047	08049C	PARTICIPANT	\N	EXCUSE	0
477586	475829	08056B	PARTICIPANT	\N	PRESENT	0
477587	475829	10015M	PARTICIPANT	\N	PRESENT	0
477588	475829	08053X	PARTICIPANT	\N	PRESENT	0
477589	475829	19673G	PRESIDENT	0	PRESENT	0
477590	475829	19719D	PARTICIPANT	\N	EXCUSE	0
477591	475829	11026G	PARTICIPANT	\N	PRESENT	0
477605	476190	04071H	PARTICIPANT	\N	PRESENT	0
477606	476190	19647E	PARTICIPANT	\N	PRESENT	0
477607	476190	19711U	PARTICIPANT	\N	PRESENT	0
477608	476190	19531S	PARTICIPANT	\N	PRESENT	0
477609	476190	01048V	PARTICIPANT	\N	PRESENT	0
477610	476190	19687N	PARTICIPANT	\N	PRESENT	0
477611	476190	01057W	PARTICIPANT	\N	PRESENT	0
477612	476190	08011M	PARTICIPANT	\N	PRESENT	0
477613	476190	11074Q	PRESIDENT	0	PRESENT	0
477614	476190	14034U	PARTICIPANT	\N	PRESENT	0
477615	476190	04086Q	PARTICIPANT	\N	PRESENT	0
477616	476190	14085U	PARTICIPANT	\N	PRESENT	0
477617	476190	08073C	PARTICIPANT	\N	PRESENT	0
477618	476190	96004D	PARTICIPANT	\N	PRESENT	0
477619	476190	07029T	PARTICIPANT	\N	EXCUSE	0
477620	475829	04040A	PARTICIPANT	\N	PRESENT	0
477704	475830	04040A	PARTICIPANT	\N	PRESENT	0
477705	475830	19673G	PARTICIPANT	\N	PRESENT	0
477706	475830	19719D	PRESIDENT	0	PRESENT	0
477707	475830	08010L	PARTICIPANT	\N	PRESENT	0
477756	477755	04097T	PARTICIPANT	\N	PRESENT	0
477757	477755	11026G	PARTICIPANT	\N	PRESENT	0
477768	477767	04097T	PARTICIPANT	\N	PRESENT	0
477769	477767	11026G	PARTICIPANT	\N	PRESENT	0
477780	477779	96004D	PARTICIPANT	\N	PRESENT	0
477781	477779	98035U	PARTICIPANT	\N	PRESENT	0
477783	477782	96004D	PRESIDENT	0	PRESENT	0
477784	477782	98035U	PARTICIPANT	\N	PRESENT	0
477785	477782	14331P	PARTICIPANT	\N	PRESENT	0
477786	477782	04057K	PARTICIPANT	\N	PRESENT	0
477787	477782	14241N	PARTICIPANT	\N	PRESENT	0
477788	477782	04097T	PARTICIPANT	\N	PRESENT	0
477789	477782	14001X	PARTICIPANT	\N	PRESENT	0
477790	477782	19563B	PARTICIPANT	\N	PRESENT	0
477791	477782	11083R	PARTICIPANT	\N	PRESENT	0
477792	477782	14357A	PARTICIPANT	\N	PRESENT	0
477793	477782	14079W	PARTICIPANT	\N	PRESENT	0
477794	477782	10015M	PARTICIPANT	\N	PRESENT	0
477795	477782	14033T	PARTICIPANT	\N	PRESENT	0
477796	477782	14225N	PARTICIPANT	\N	PRESENT	0
477797	477782	19553Y	PARTICIPANT	\N	PRESENT	0
477798	477782	14097Y	PARTICIPANT	\N	PRESENT	0
477846	477845	12016W	PARTICIPANT	\N	PRESENT	0
477847	477845	08019V	PARTICIPANT	\N	PRESENT	0
477848	477845	19715Y	PARTICIPANT	\N	PRESENT	0
477850	477849	08019V	PARTICIPANT	\N	PRESENT	0
477922	477621	08019V	PARTICIPANT	\N	PRESENT	0
477991	476054	19335Q	PARTICIPANT	\N	PRESENT	0
477992	476054	19619A	PARTICIPANT	\N	PRESENT	0
477993	476054	19798U	PARTICIPANT	\N	PRESENT	0
477994	476054	19631V	PARTICIPANT	\N	PRESENT	0
477995	476054	19503N	PARTICIPANT	\N	PRESENT	0
477996	476054	19387D	PARTICIPANT	\N	PRESENT	0
477997	476054	08049C	PARTICIPANT	\N	PRESENT	0
478056	473406	14197C	PARTICIPANT	\N	PRESENT	0
478048	473406	11072N	PARTICIPANT	\N	PRESENT	0
478050	478049	14133K	PARTICIPANT	\N	PRESENT	0
478051	478049	08058D	PARTICIPANT	\N	PRESENT	0
478052	473406	14221J	PARTICIPANT	\N	PRESENT	0
478053	473406	19735D	PARTICIPANT	\N	PRESENT	0
478054	473406	19585H	PARTICIPANT	\N	PRESENT	0
478055	473406	08060W	PARTICIPANT	\N	PRESENT	0
478057	473406	14331P	PARTICIPANT	\N	PRESENT	0
478058	477747	19649G	PARTICIPANT	\N	PRESENT	0
478059	477747	11026G	PARTICIPANT	\N	PRESENT	0
478060	477747	04044E	PARTICIPANT	\N	PRESENT	0
478061	477747	01028R	PARTICIPANT	\N	PRESENT	0
478062	477747	19675J	PARTICIPANT	\N	PRESENT	0
478063	477747	05008E	PRESIDENT	0	PRESENT	0
478064	477747	19447X	PARTICIPANT	\N	PRESENT	0
478065	477747	19725B	PARTICIPANT	\N	PRESENT	0
478066	477747	95063L	PARTICIPANT	\N	PRESENT	0
478067	477747	14147R	PARTICIPANT	\N	PRESENT	0
478068	477747	14215L	PRESIDENT	1	PRESENT	0
478069	477747	08018U	PARTICIPANT	\N	PRESENT	0
478070	477747	14021P	PARTICIPANT	\N	PRESENT	0
478252	478250	01058X	PARTICIPANT	\N	PRESENT	0
478072	477747	19719D	PARTICIPANT	\N	PRESENT	0
478073	477747	19585H	PARTICIPANT	\N	PRESENT	0
478074	473406	14237S	PARTICIPANT	\N	PRESENT	0
478075	473406	04092N	PARTICIPANT	\N	PRESENT	0
478076	473406	19695N	PARTICIPANT	\N	PRESENT	0
478077	473406	19569H	PARTICIPANT	\N	PRESENT	0
478078	473406	14030Q	PARTICIPANT	\N	PRESENT	0
478079	473406	07033P	PARTICIPANT	\N	PRESENT	0
478080	473406	19369B	PARTICIPANT	\N	PRESENT	0
478081	473406	19782L	PARTICIPANT	\N	PRESENT	0
478082	473406	11043H	PARTICIPANT	\N	PRESENT	0
478083	473406	19719D	PARTICIPANT	\N	PRESENT	0
478084	477747	14069U	PARTICIPANT	\N	PRESENT	0
478085	473406	01028R	PARTICIPANT	\N	PRESENT	0
478086	473406	11054L	PARTICIPANT	\N	PRESENT	0
478087	477747	01024M	PARTICIPANT	\N	PRESENT	0
478088	473406	11066Q	PARTICIPANT	\N	PRESENT	0
478089	473406	04044E	PARTICIPANT	\N	PRESENT	0
478090	473406	19758L	PARTICIPANT	\N	PRESENT	0
478091	473406	14227Q	PARTICIPANT	\N	PRESENT	0
478092	473406	19768N	PARTICIPANT	\N	PRESENT	0
478093	473406	19367Y	PARTICIPANT	\N	PRESENT	0
478094	473406	10006L	PARTICIPANT	\N	PRESENT	0
478095	473406	19575F	PARTICIPANT	\N	PRESENT	0
478096	473406	14069U	PARTICIPANT	\N	PRESENT	0
478097	473406	14071N	PARTICIPANT	\N	PRESENT	0
478098	473406	19621T	PARTICIPANT	\N	PRESENT	0
478099	473406	19723Y	PARTICIPANT	\N	PRESENT	0
478100	473406	19387D	PARTICIPANT	\N	PRESENT	0
478103	473406	14187A	PARTICIPANT	\N	PRESENT	0
478104	473406	11027H	PARTICIPANT	\N	PRESENT	0
478186	476868	19798U	PARTICIPANT	\N	PRESENT	0
478187	476868	19503N	PARTICIPANT	\N	PRESENT	0
478188	476868	19387D	PARTICIPANT	\N	PRESENT	0
478189	476868	19631V	PARTICIPANT	\N	PRESENT	0
478222	476533	19647E	PARTICIPANT	\N	EXCUSE	0
478224	476591	08049C	PARTICIPANT	\N	PRESENT	0
478225	476591	19335Q	PARTICIPANT	\N	PRESENT	0
478226	476591	19503N	PARTICIPANT	\N	PRESENT	0
478227	476591	19631V	PARTICIPANT	\N	PRESENT	0
478228	476591	19387D	PARTICIPANT	\N	PRESENT	0
478117	473407	04086Q	PARTICIPANT	\N	PRESENT	0
478118	477837	19467C	PARTICIPANT	\N	PRESENT	0
478119	477837	11090Q	PRESIDENT	0	PRESENT	0
478120	477837	80013X	PARTICIPANT	\N	PRESENT	0
478121	477837	19747H	PARTICIPANT	\N	PRESENT	0
478122	477837	04043D	PARTICIPANT	\N	PRESENT	0
478123	477837	19631V	PARTICIPANT	\N	PRESENT	0
478124	477837	14265W	PARTICIPANT	\N	PRESENT	0
478229	476591	19798U	PARTICIPANT	\N	PRESENT	0
478251	478250	14267Y	PARTICIPANT	\N	PRESENT	0
478256	477701	19651A	PARTICIPANT	\N	PRESENT	0
478257	477701	14083S	PARTICIPANT	\N	PRESENT	0
478258	477701	11110B	PARTICIPANT	\N	PRESENT	0
478259	477701	99004R	PARTICIPANT	\N	PRESENT	0
478260	477701	19711U	PARTICIPANT	\N	PRESENT	0
478261	477701	12016W	PARTICIPANT	\N	PRESENT	0
478262	477701	14225N	PARTICIPANT	\N	PRESENT	0
478263	477701	19479G	PARTICIPANT	\N	PRESENT	0
478265	478264	08012N	PARTICIPANT	\N	PRESENT	0
457204	456707	19729F	PARTICIPANT	\N	EXCUSE	0
457516	456716	14053L	PARTICIPANT	\N	PRESENT	0
457517	456716	11033F	PARTICIPANT	\N	PRESENT	0
457518	456716	08044W	PARTICIPANT	\N	PRESENT	0
457519	456716	11085T	PARTICIPANT	\N	PRESENT	0
464127	464097	01062T	PARTICIPANT	\N	PRESENT	0
464128	464097	11041F	PARTICIPANT	\N	PRESENT	0
464129	464097	11066Q	PARTICIPANT	\N	PRESENT	0
464130	464097	95067Q	PARTICIPANT	\N	PRESENT	0
464131	464097	04034C	PARTICIPANT	\N	PRESENT	0
464132	464097	19421M	PARTICIPANT	\N	PRESENT	0
464133	464097	19647E	PARTICIPANT	\N	PRESENT	0
464135	464134	14255U	PARTICIPANT	\N	PRESENT	0
464136	464134	08053X	PARTICIPANT	\N	PRESENT	0
464138	464137	14255U	PARTICIPANT	\N	PRESENT	0
464139	464137	08053X	PARTICIPANT	\N	PRESENT	0
464492	464307	14173T	PARTICIPANT	\N	PRESENT	0
464514	464513	96004D	PARTICIPANT	\N	PRESENT	0
464515	464513	14331P	PARTICIPANT	\N	PRESENT	0
465466	465465	19719D	PARTICIPANT	\N	PRESENT	0
465467	465465	04047H	PARTICIPANT	\N	PRESENT	0
465468	465465	08044W	PARTICIPANT	\N	PRESENT	0
465918	465335	04047H	PARTICIPANT	\N	PRESENT	0
465919	465335	14065Q	PARTICIPANT	\N	PRESENT	0
466064	465631	14157T	PARTICIPANT	\N	PRESENT	0
466065	465631	19413M	PARTICIPANT	\N	PRESENT	0
466066	465631	19551W	PARTICIPANT	\N	PRESENT	0
466067	465631	19531S	PARTICIPANT	\N	PRESENT	0
466068	465631	11045K	PARTICIPANT	\N	PRESENT	0
466069	465631	11027H	PARTICIPANT	\N	PRESENT	0
466070	465631	19687N	PARTICIPANT	\N	PRESENT	0
466071	465631	14085U	PARTICIPANT	\N	PRESENT	0
466072	465631	11026G	PARTICIPANT	\N	PRESENT	0
466073	465631	19647E	PARTICIPANT	\N	PRESENT	0
466074	465631	19649G	PARTICIPANT	\N	PRESENT	0
466075	465631	19689Q	PARTICIPANT	\N	PRESENT	0
466076	465631	11074Q	PARTICIPANT	\N	PRESENT	0
466077	465631	08011M	PARTICIPANT	\N	PRESENT	0
466078	465631	11099A	PARTICIPANT	\N	PRESENT	0
466079	465631	19563B	PARTICIPANT	\N	PRESENT	0
466080	465631	19719D	PARTICIPANT	\N	PRESENT	0
466081	465631	19713W	PARTICIPANT	\N	PRESENT	0
466082	465631	19762G	PARTICIPANT	\N	PRESENT	0
466083	465631	08010L	PARTICIPANT	\N	PRESENT	0
466084	465631	11090Q	PARTICIPANT	\N	PRESENT	0
466085	465631	11048N	PARTICIPANT	\N	PRESENT	0
466086	465631	19533U	PARTICIPANT	\N	PRESENT	0
466087	465631	07029T	PARTICIPANT	\N	PRESENT	0
466088	465631	19741B	PARTICIPANT	\N	PRESENT	0
466089	465631	14031R	PARTICIPANT	\N	PRESENT	0
466090	465631	11053K	PARTICIPANT	\N	PRESENT	0
466091	465631	11070L	PARTICIPANT	\N	PRESENT	0
466092	465631	19651A	PARTICIPANT	\N	PRESENT	0
466093	465631	19479G	PARTICIPANT	\N	PRESENT	0
466094	465631	19691J	PARTICIPANT	\N	PRESENT	0
466095	465631	19347U	PARTICIPANT	\N	PRESENT	0
466096	465631	96004D	PARTICIPANT	\N	PRESENT	0
466097	465631	19573D	PARTICIPANT	\N	PRESENT	0
466098	465631	04086Q	PARTICIPANT	\N	PRESENT	0
466099	465631	01028R	PARTICIPANT	\N	PRESENT	0
466100	465631	04085P	PARTICIPANT	\N	PRESENT	0
466101	465631	04033B	PARTICIPANT	\N	PRESENT	0
466102	465631	11085T	PARTICIPANT	\N	PRESENT	0
466103	465631	19545Y	PARTICIPANT	\N	PRESENT	0
466104	465631	11110B	PARTICIPANT	\N	PRESENT	0
466105	465631	04071H	PARTICIPANT	\N	PRESENT	0
466108	466107	04047H	PARTICIPANT	\N	PRESENT	0
466113	466111	14259Y	PARTICIPANT	\N	PRESENT	0
466110	466107	14215L	PARTICIPANT	\N	PRESENT	0
466112	466111	05008E	PARTICIPANT	\N	PRESENT	0
466114	466111	14231L	PARTICIPANT	\N	PRESENT	0
466115	466111	04040A	PARTICIPANT	\N	PRESENT	0
466117	466116	19515S	PARTICIPANT	\N	PRESENT	0
466118	466116	19629C	PARTICIPANT	\N	PRESENT	0
466119	466116	08045X	PARTICIPANT	\N	PRESENT	0
466120	466116	19399H	PARTICIPANT	\N	PRESENT	0
466121	466116	02002K	PARTICIPANT	\N	PRESENT	0
466062	465631	14034U	PARTICIPANT	\N	PRESENT	0
466063	465631	19667J	PARTICIPANT	\N	PRESENT	0
466122	466116	99004R	PRESIDENT	0	PRESENT	0
466123	466116	19711U	PARTICIPANT	\N	PRESENT	0
466124	466116	14147R	PARTICIPANT	\N	PRESENT	0
466125	466116	19349W	PARTICIPANT	\N	PRESENT	0
466126	466116	11097X	PARTICIPANT	\N	PRESENT	0
466127	466116	11066Q	PARTICIPANT	\N	PRESENT	0
466128	466116	19479G	PARTICIPANT	\N	PRESENT	0
466129	466116	19737F	PARTICIPANT	\N	PRESENT	0
466130	466116	19651A	PARTICIPANT	\N	EXCUSE	0
466131	466116	19667J	PARTICIPANT	\N	EXCUSE	0
466132	466116	08024S	PARTICIPANT	\N	EXCUSE	0
466133	466116	19369B	PARTICIPANT	\N	EXCUSE	0
466134	466116	14107H	PARTICIPANT	\N	EXCUSE	0
466135	466116	19713W	PARTICIPANT	\N	EXCUSE	0
467284	467283	14249W	PARTICIPANT	\N	PRESENT	0
467285	467283	14039A	PARTICIPANT	\N	PRESENT	0
467286	467283	19758L	PARTICIPANT	\N	PRESENT	0
467287	467283	19621T	PARTICIPANT	\N	PRESENT	0
467288	467283	14123H	PARTICIPANT	\N	PRESENT	0
467289	467283	14107H	PARTICIPANT	\N	PRESENT	0
467290	467283	11043H	PARTICIPANT	\N	PRESENT	0
467292	467291	19643A	PARTICIPANT	\N	PRESENT	0
467293	467291	11104D	PARTICIPANT	\N	PRESENT	0
467294	467291	19749K	PARTICIPANT	\N	PRESENT	0
467296	467295	11104D	PARTICIPANT	\N	PRESENT	0
467298	467297	19643A	PARTICIPANT	\N	PRESENT	0
467299	467297	11104D	PARTICIPANT	\N	PRESENT	0
467301	467300	11104D	PARTICIPANT	\N	PRESENT	0
467303	467302	19719D	PARTICIPANT	\N	PRESENT	0
467304	467302	04047H	PARTICIPANT	\N	PRESENT	0
467305	467302	14215L	PARTICIPANT	\N	PRESENT	0
467306	467302	14147R	PARTICIPANT	\N	PRESENT	0
467312	467311	19621T	PARTICIPANT	\N	PRESENT	0
467313	467311	19758L	PARTICIPANT	\N	PRESENT	0
467314	467311	04059M	PARTICIPANT	\N	PRESENT	0
467315	467311	19699S	PARTICIPANT	\N	PRESENT	0
467542	467359	04044E	PARTICIPANT	\N	PRESENT	0
467543	467359	14179A	PARTICIPANT	\N	PRESENT	0
467544	467359	14021P	PARTICIPANT	\N	PRESENT	0
467830	467220	14055N	PARTICIPANT	\N	PRESENT	0
467831	467220	11056N	PARTICIPANT	\N	PRESENT	0
467832	467220	14281W	PARTICIPANT	\N	PRESENT	0
467833	467220	19695N	PARTICIPANT	\N	PRESENT	0
467890	467219	86034E	PARTICIPANT	\N	PRESENT	0
467891	467821	14053L	PARTICIPANT	\N	PRESENT	0
467892	467821	10015M	PARTICIPANT	\N	PRESENT	0
467893	467821	19585H	PARTICIPANT	\N	PRESENT	0
467894	467821	04047H	PARTICIPANT	\N	PRESENT	0
467895	467821	19673G	PARTICIPANT	\N	PRESENT	0
467896	467821	11033F	PARTICIPANT	\N	PRESENT	0
467897	467821	05008E	PRESIDENT	0	PRESENT	0
467898	467821	14089Y	PARTICIPANT	\N	PRESENT	0
467899	467821	08044W	PARTICIPANT	\N	PRESENT	0
467900	467821	14151M	PARTICIPANT	\N	PRESENT	0
467901	467821	14215L	PARTICIPANT	\N	PRESENT	0
467902	467821	11085T	PARTICIPANT	\N	PRESENT	0
467903	467821	14259Y	PARTICIPANT	\N	PRESENT	0
467904	467219	11110B	PARTICIPANT	\N	PRESENT	0
467905	467219	11033F	PARTICIPANT	\N	PRESENT	0
467906	467219	04085P	PARTICIPANT	\N	PRESENT	0
467907	467219	14021P	PARTICIPANT	\N	PRESENT	0
467908	467219	01028R	PARTICIPANT	\N	PRESENT	0
467909	467219	14229S	PARTICIPANT	\N	PRESENT	0
467910	467219	19545Y	PARTICIPANT	\N	PRESENT	0
467911	467219	19585H	PARTICIPANT	\N	PRESENT	0
467912	467219	19647E	PARTICIPANT	\N	PRESENT	0
467913	467219	14281W	PARTICIPANT	\N	PRESENT	0
467914	467219	19553Y	PARTICIPANT	\N	PRESENT	0
467915	467219	19629C	PARTICIPANT	\N	PRESENT	0
467916	467219	14089Y	PARTICIPANT	\N	PRESENT	0
467917	467219	14251Q	PARTICIPANT	\N	PRESENT	0
467918	467219	19691J	PARTICIPANT	\N	PRESENT	0
467919	467219	19685L	PARTICIPANT	\N	PRESENT	0
467920	467219	07033P	PARTICIPANT	\N	PRESENT	0
467921	467219	19621T	PARTICIPANT	\N	PRESENT	0
467922	467219	08031R	PARTICIPANT	\N	PRESENT	0
467923	467219	11012A	PARTICIPANT	\N	PRESENT	0
467924	467219	14215L	PARTICIPANT	\N	PRESENT	0
467925	467219	19762G	PARTICIPANT	\N	PRESENT	0
467926	467219	14071N	PARTICIPANT	\N	PRESENT	0
467927	467219	04092N	PARTICIPANT	\N	PRESENT	0
467928	467219	19673G	PARTICIPANT	\N	PRESENT	0
467929	467219	14038Y	PARTICIPANT	\N	PRESENT	0
477144	477114	19533U	PARTICIPANT	\N	PRESENT	0
477145	477114	19573D	PARTICIPANT	\N	PRESENT	0
477146	477114	19766L	PARTICIPANT	\N	PRESENT	0
477147	477114	08043V	PARTICIPANT	\N	EXCUSE	0
477148	477114	14241N	PARTICIPANT	\N	EXCUSE	0
477149	477114	14039A	PARTICIPANT	\N	EXCUSE	0
477150	477114	04057K	PARTICIPANT	\N	PRESENT	0
477151	477114	04059M	PARTICIPANT	\N	PRESENT	0
477258	477254	14187A	PARTICIPANT	\N	PRESENT	0
477261	477260	14187A	PARTICIPANT	\N	PRESENT	0
477264	477262	14187A	PARTICIPANT	\N	PRESENT	0
477265	477262	14081Q	PARTICIPANT	\N	PRESENT	0
477268	477267	14187A	PARTICIPANT	\N	PRESENT	0
477269	477267	08028W	PARTICIPANT	\N	PRESENT	0
477291	476055	19631V	PARTICIPANT	\N	PRESENT	0
477292	476055	08049C	PARTICIPANT	\N	PRESENT	0
477293	476055	19335Q	PARTICIPANT	\N	PRESENT	0
477297	476055	19387D	PARTICIPANT	\N	PRESENT	0
477308	476164	14097Y	PARTICIPANT	\N	PRESENT	0
477309	476164	19611R	PRESIDENT	0	PRESENT	0
477310	476164	19687N	PARTICIPANT	\N	PRESENT	0
477311	476189	19479G	PARTICIPANT	\N	PRESENT	0
477318	476267	14073Q	PARTICIPANT	\N	PRESENT	0
477320	476267	08012N	PARTICIPANT	\N	PRESENT	0
477373	477322	19399H	PARTICIPANT	\N	PRESENT	0
477306	476164	14197C	PARTICIPANT	0	PRESENT	0
477307	476164	14033T	PARTICIPANT	\N	PRESENT	0
477319	476267	11043H	PARTICIPANT	\N	PRESENT	0
477374	477322	11083R	PARTICIPANT	\N	PRESENT	0
477375	477322	08039A	PARTICIPANT	\N	PRESENT	0
477384	477382	08039A	PARTICIPANT	\N	PRESENT	0
477390	477388	96004D	PRESIDENT	0	PRESENT	0
477393	477388	14089Y	PARTICIPANT	\N	PRESENT	0
477394	477388	14065Q	PARTICIPANT	\N	PRESENT	0
477395	477388	14249W	PARTICIPANT	\N	PRESENT	0
477396	477388	11083R	PARTICIPANT	\N	PRESENT	0
477397	477388	14033T	PARTICIPANT	\N	PRESENT	0
477398	477388	19725B	PARTICIPANT	\N	PRESENT	0
477399	477388	04097T	PARTICIPANT	\N	PRESENT	0
477400	477388	14073Q	PARTICIPANT	\N	PRESENT	0
477401	477388	11026G	PARTICIPANT	\N	PRESENT	0
477402	477388	14237S	PARTICIPANT	\N	PRESENT	0
477403	477388	14229S	PARTICIPANT	\N	PRESENT	0
477420	477419	96004D	PRESIDENT	0	PRESENT	0
477421	477419	14089Y	PARTICIPANT	\N	PRESENT	0
477422	477419	98035U	PARTICIPANT	\N	PRESENT	0
477423	477419	11083R	PARTICIPANT	\N	PRESENT	0
477424	477419	14073Q	PARTICIPANT	\N	PRESENT	0
477425	477419	10015M	PARTICIPANT	\N	PRESENT	0
477426	477419	11026G	PARTICIPANT	\N	PRESENT	0
477427	477419	19563B	PARTICIPANT	\N	PRESENT	0
477428	477419	19569H	PARTICIPANT	\N	PRESENT	0
477429	477419	19725B	PARTICIPANT	\N	PRESENT	0
477431	477419	08044W	PARTICIPANT	\N	PRESENT	0
477432	477419	14249W	PARTICIPANT	\N	PRESENT	0
477446	475999	19335Q	PARTICIPANT	\N	PRESENT	0
477447	475999	08049C	PARTICIPANT	\N	PRESENT	0
477448	475999	19631V	PARTICIPANT	\N	PRESENT	0
477449	475999	19387D	PARTICIPANT	\N	PRESENT	0
477456	477455	14030Q	PARTICIPANT	\N	PRESENT	0
477457	477455	19701S	PARTICIPANT	\N	PRESENT	0
477458	477455	14179A	PARTICIPANT	\N	PRESENT	0
477459	477455	19731Y	PARTICIPANT	\N	PRESENT	0
477460	477455	11045K	PARTICIPANT	\N	PRESENT	0
477461	477455	19749K	PARTICIPANT	\N	PRESENT	0
477475	476792	19739H	PARTICIPANT	\N	PRESENT	0
477715	477713	14267Y	PARTICIPANT	\N	PRESENT	0
477716	477713	04086Q	PARTICIPANT	\N	PRESENT	0
477717	477713	19695N	PARTICIPANT	\N	PRESENT	0
477718	477713	11064N	PARTICIPANT	\N	PRESENT	0
477719	477713	14039A	PARTICIPANT	\N	PRESENT	0
477720	477713	16685X	PARTICIPANT	\N	PRESENT	0
477721	477713	95067Q	PARTICIPANT	\N	PRESENT	0
477722	477713	19525U	PARTICIPANT	\N	PRESENT	0
477723	477713	19729F	PARTICIPANT	\N	PRESENT	0
477725	477724	96004D	PRESIDENT	0	PRESENT	0
477726	477724	14133K	PARTICIPANT	\N	PRESENT	0
477727	477724	14097Y	PARTICIPANT	\N	PRESENT	0
477728	477724	14073Q	PARTICIPANT	\N	PRESENT	0
477729	477724	14237S	PARTICIPANT	\N	PRESENT	0
477730	477724	14357A	PARTICIPANT	\N	PRESENT	0
477731	477724	14249W	PARTICIPANT	\N	PRESENT	0
477732	477724	04035D	PARTICIPANT	\N	PRESENT	0
477733	477724	19569H	PARTICIPANT	\N	PRESENT	0
477734	477724	04097T	PARTICIPANT	\N	PRESENT	0
477735	477724	08044W	PARTICIPANT	\N	PRESENT	0
477736	477724	11026G	PARTICIPANT	\N	PRESENT	0
477737	477724	14001X	PARTICIPANT	\N	PRESENT	0
477738	477724	19563B	PARTICIPANT	\N	PRESENT	0
477739	477724	14331P	PARTICIPANT	\N	PRESENT	0
477740	477724	14225N	PARTICIPANT	\N	PRESENT	0
477741	477724	14205J	PARTICIPANT	\N	PRESENT	0
477742	477724	14089Y	PARTICIPANT	\N	PRESENT	0
477753	477752	04097T	PARTICIPANT	\N	PRESENT	0
477754	477752	11026G	PARTICIPANT	\N	PRESENT	0
477771	477770	05008E	PARTICIPANT	\N	PRESENT	0
477772	477770	08058D	PARTICIPANT	\N	PRESENT	0
477810	476142	19367Y	PARTICIPANT	\N	PRESENT	0
477774	477770	04042C	PARTICIPANT	\N	PRESENT	0
477811	476142	19717B	PARTICIPANT	\N	PRESENT	0
477812	476142	19575F	PARTICIPANT	\N	PRESENT	0
477813	476142	19415P	PARTICIPANT	\N	PRESENT	0
477814	476142	11103C	PARTICIPANT	\N	PRESENT	0
477815	476142	19727D	PARTICIPANT	\N	PRESENT	0
477816	476142	14195A	PARTICIPANT	\N	PRESENT	0
477817	476142	11031D	PARTICIPANT	\N	PRESENT	0
477818	476142	19663E	PARTICIPANT	\N	PRESENT	0
477819	476142	10006L	PARTICIPANT	\N	PRESENT	0
477820	476142	14217N	PARTICIPANT	\N	PRESENT	0
477821	476142	19577H	PARTICIPANT	\N	PRESENT	0
477822	476142	14281W	PARTICIPANT	\N	PRESENT	0
477823	476142	14087W	PARTICIPANT	\N	PRESENT	0
477824	476142	19565D	PARTICIPANT	\N	PRESENT	0
477825	476142	19553Y	PARTICIPANT	\N	PRESENT	0
477826	476142	08041T	PARTICIPANT	\N	EXCUSE	0
477827	476142	19569H	PARTICIPANT	\N	PRESENT	0
477828	476142	19591F	PARTICIPANT	\N	PRESENT	0
477829	476142	14213J	PARTICIPANT	\N	PRESENT	0
477830	476142	19657G	PARTICIPANT	\N	PRESENT	0
477831	476142	14223L	PARTICIPANT	\N	PRESENT	0
477832	476142	14119M	PARTICIPANT	\N	PRESENT	0
477833	476142	19798U	PARTICIPANT	\N	PRESENT	0
477834	476142	19703U	PARTICIPANT	\N	PRESENT	0
477835	476142	19301E	PARTICIPANT	\N	PRESENT	0
477836	476142	01034P	PARTICIPANT	\N	PRESENT	0
477868	477867	02002K	PARTICIPANT	\N	PRESENT	0
477869	477867	19533U	PARTICIPANT	\N	PRESENT	0
477870	477867	08012N	PARTICIPANT	\N	PRESENT	0
477871	477867	19725B	PARTICIPANT	\N	PRESENT	0
477872	477867	14030Q	PARTICIPANT	\N	PRESENT	0
477873	477867	19251M	PARTICIPANT	\N	PRESENT	0
477874	477867	19349W	PARTICIPANT	\N	PRESENT	0
477875	477867	11043H	PARTICIPANT	\N	PRESENT	0
477876	477867	19399H	PARTICIPANT	\N	PRESENT	0
477877	477867	19711U	PARTICIPANT	\N	PRESENT	0
477879	477878	02002K	PARTICIPANT	\N	PRESENT	0
477880	477878	19533U	PARTICIPANT	\N	PRESENT	0
477881	477878	14030Q	PARTICIPANT	\N	PRESENT	0
477882	477878	19251M	PARTICIPANT	\N	PRESENT	0
477883	477878	19349W	PARTICIPANT	\N	PRESENT	0
477884	477878	08012N	PARTICIPANT	\N	PRESENT	0
477885	477878	11043H	PARTICIPANT	\N	PRESENT	0
477886	477878	19399H	PARTICIPANT	\N	PRESENT	0
477888	477887	02002K	PARTICIPANT	\N	PRESENT	0
477889	477887	19533U	PARTICIPANT	\N	PRESENT	0
477890	477887	14030Q	PARTICIPANT	\N	PRESENT	0
477891	477887	19251M	PARTICIPANT	\N	PRESENT	0
477892	477887	19349W	PARTICIPANT	\N	PRESENT	0
477893	477887	08012N	PARTICIPANT	\N	PRESENT	0
477894	477887	11043H	PARTICIPANT	\N	PRESENT	0
477895	477887	19399H	PARTICIPANT	\N	PRESENT	0
477896	477887	19711U	PARTICIPANT	\N	PRESENT	0
477940	477934	19679N	PARTICIPANT	\N	PRESENT	0
477942	477935	11067R	PARTICIPANT	\N	PRESENT	0
477941	477935	19415P	PARTICIPANT	\N	PRESENT	0
477943	477935	19575F	PARTICIPANT	\N	PRESENT	0
477944	477935	19703U	PARTICIPANT	\N	PRESENT	0
477945	477936	19415P	PARTICIPANT	\N	PRESENT	0
477946	477936	11067R	PARTICIPANT	\N	PRESENT	0
477947	477937	19415P	PARTICIPANT	\N	PRESENT	0
477948	477937	11067R	PARTICIPANT	\N	PRESENT	0
477950	477949	19415P	PARTICIPANT	\N	PRESENT	0
477951	477949	19760E	PARTICIPANT	\N	PRESENT	0
477952	477949	19657G	PARTICIPANT	\N	PRESENT	0
477953	477949	19703U	PARTICIPANT	\N	PRESENT	0
477990	476592	19575F	PARTICIPANT	\N	PRESENT	0
477999	477921	14267Y	PARTICIPANT	\N	PRESENT	0
478000	477921	19826F	PARTICIPANT	\N	PRESENT	0
456268	454067	98029W	PARTICIPANT	\N	EXCUSE	0
456269	454067	14097Y	PARTICIPANT	\N	EXCUSE	0
456270	454067	19583F	PARTICIPANT	\N	EXCUSE	0
456271	454067	19709B	PARTICIPANT	\N	EXCUSE	0
456272	454067	14028W	PARTICIPANT	\N	EXCUSE	0
456322	456321	18083K	PARTICIPANT	\N	PRESENT	0
456323	456321	19447X	PARTICIPANT	\N	PRESENT	0
456324	456321	14205J	PARTICIPANT	\N	PRESENT	0
456325	456321	19762G	PARTICIPANT	\N	PRESENT	0
456326	456321	14173T	PARTICIPANT	\N	PRESENT	0
456364	456363	19569H	PARTICIPANT	\N	PRESENT	0
456365	456363	08028W	PARTICIPANT	\N	PRESENT	0
456366	456363	96004D	PARTICIPANT	\N	PRESENT	0
456368	456363	19747H	PARTICIPANT	\N	PRESENT	0
456369	456363	11083R	PARTICIPANT	\N	PRESENT	0
456370	456363	19515S	PARTICIPANT	\N	PRESENT	0
456371	456363	14001X	PARTICIPANT	\N	PRESENT	0
456372	456363	19467C	PARTICIPANT	\N	PRESENT	0
456373	456363	14079W	PARTICIPANT	\N	PRESENT	0
456374	456363	11099A	PARTICIPANT	\N	PRESENT	0
456375	456363	19369B	PARTICIPANT	\N	PRESENT	0
456376	456363	19507S	PARTICIPANT	\N	PRESENT	0
456377	456363	19441R	PARTICIPANT	\N	PRESENT	0
456752	456749	14121F	PARTICIPANT	\N	PRESENT	0
456763	456762	11040E	PARTICIPANT	\N	PRESENT	0
456764	456762	14331P	PARTICIPANT	\N	PRESENT	0
456765	456762	14225N	PARTICIPANT	\N	PRESENT	0
456767	456766	08010L	PARTICIPANT	\N	PRESENT	0
456769	456768	08010L	PARTICIPANT	\N	PRESENT	0
456771	456770	11040E	PARTICIPANT	\N	PRESENT	0
456772	456770	19667J	PARTICIPANT	\N	PRESENT	0
456774	456773	14199E	PARTICIPANT	\N	PRESENT	0
457566	456615	19565D	PARTICIPANT	\N	EXCUSE	0
457567	456617	19565D	PARTICIPANT	\N	EXCUSE	0
457568	456490	14255U	PARTICIPANT	\N	EXCUSE	0
457569	456490	98022P	PARTICIPANT	\N	EXCUSE	0
457570	456490	19583F	PARTICIPANT	\N	EXCUSE	0
457571	456490	14028W	PARTICIPANT	\N	EXCUSE	0
457572	456490	11066Q	PARTICIPANT	\N	EXCUSE	0
457573	456491	14255U	PARTICIPANT	\N	EXCUSE	0
457574	456491	98022P	PARTICIPANT	\N	EXCUSE	0
457575	456491	19583F	PARTICIPANT	\N	EXCUSE	0
457576	456491	14028W	PARTICIPANT	\N	EXCUSE	0
457577	456491	11066Q	PARTICIPANT	\N	EXCUSE	0
459306	459305	19631V	PARTICIPANT	\N	PRESENT	0
459307	459305	19575F	PARTICIPANT	\N	PRESENT	0
459308	459305	19747H	PARTICIPANT	\N	PRESENT	0
459309	459305	19621T	PARTICIPANT	\N	PRESENT	0
459310	459305	14085U	PARTICIPANT	\N	PRESENT	0
459311	459305	11056N	PARTICIPANT	\N	PRESENT	0
459312	459305	14079W	PARTICIPANT	\N	PRESENT	0
459313	459305	14215L	PARTICIPANT	\N	PRESENT	0
459314	459305	14087W	PARTICIPANT	\N	PRESENT	0
459315	459305	19521Q	PARTICIPANT	\N	PRESENT	0
459316	459305	19333N	PARTICIPANT	\N	PRESENT	0
459317	459305	14213J	PARTICIPANT	\N	PRESENT	0
459318	459305	14073Q	PARTICIPANT	\N	PRESENT	0
459319	459305	19489J	PARTICIPANT	\N	PRESENT	0
459320	459305	19711U	PARTICIPANT	\N	PRESENT	0
459321	459305	14205J	PARTICIPANT	\N	PRESENT	0
459322	459305	14219Q	PRESIDENT	0	PRESENT	0
459323	459305	14059S	PARTICIPANT	\N	PRESENT	0
459324	459305	14265W	PARTICIPANT	\N	PRESENT	0
459325	459305	19768N	PARTICIPANT	\N	PRESENT	0
459326	459305	19503N	PARTICIPANT	\N	PRESENT	0
459327	459305	19349W	PARTICIPANT	\N	PRESENT	0
459328	459305	14229S	PARTICIPANT	\N	PRESENT	0
459329	459305	19703U	PARTICIPANT	\N	PRESENT	0
459330	459305	01028R	PARTICIPANT	\N	PRESENT	0
459331	459305	19479G	PARTICIPANT	\N	EXCUSE	0
459332	459305	19629C	PARTICIPANT	\N	EXCUSE	0
460307	458313	14030Q	PRESIDENT	0	PRESENT	0
460308	458313	08043V	PARTICIPANT	\N	PRESENT	0
460309	458313	19715Y	PARTICIPANT	\N	EXCUSE	0
460310	458313	19731Y	PARTICIPANT	\N	PRESENT	0
460311	458313	14109K	PARTICIPANT	\N	PRESENT	0
460312	458313	08019V	PARTICIPANT	\N	PRESENT	0
460313	458313	11072N	PARTICIPANT	\N	PRESENT	0
460314	458313	19729F	PARTICIPANT	\N	PRESENT	0
460316	458313	14059S	PARTICIPANT	\N	PRESENT	0
461017	448773	14115H	PARTICIPANT	\N	PRESENT	0
461018	448773	19415P	PARTICIPANT	\N	PRESENT	0
461019	448773	19745F	PARTICIPANT	\N	PRESENT	0
461020	448773	14063N	PARTICIPANT	\N	PRESENT	0
461021	448773	11033F	PARTICIPANT	\N	PRESENT	0
461022	448773	19681G	PARTICIPANT	\N	PRESENT	0
461023	448773	07004J	PARTICIPANT	\N	PRESENT	0
461024	448773	04045F	PARTICIPANT	\N	PRESENT	0
461025	448773	08019V	PARTICIPANT	\N	PRESENT	0
461026	448773	19533U	PARTICIPANT	\N	PRESENT	0
461027	448773	14053L	PARTICIPANT	\N	PRESENT	0
461028	448773	04047H	PARTICIPANT	\N	PRESENT	0
461029	448773	19543W	PARTICIPANT	\N	PRESENT	0
461030	448773	08043V	PARTICIPANT	\N	PRESENT	0
461031	448773	80013X	PARTICIPANT	\N	PRESENT	0
461032	448773	08028W	PARTICIPANT	\N	PRESENT	0
461033	448773	14031R	PARTICIPANT	\N	PRESENT	0
461034	448773	19649G	PARTICIPANT	\N	PRESENT	0
461035	448773	98018T	PARTICIPANT	\N	PRESENT	0
461036	448773	14033T	PARTICIPANT	\N	PRESENT	0
461037	448773	19575F	PARTICIPANT	\N	PRESENT	0
461038	448773	08060W	PARTICIPANT	\N	PRESENT	0
461039	448773	14231L	PARTICIPANT	\N	PRESENT	0
461040	448773	19731Y	PARTICIPANT	\N	PRESENT	0
461041	448773	19367Y	PARTICIPANT	\N	PRESENT	0
461042	448773	14028W	PARTICIPANT	\N	PRESENT	0
461043	448773	14107H	PARTICIPANT	\N	PRESENT	0
461044	448773	19651A	PARTICIPANT	\N	PRESENT	0
461045	448773	04059M	PARTICIPANT	\N	PRESENT	0
461046	448773	95030B	PARTICIPANT	\N	PRESENT	0
461047	448773	14179A	PARTICIPANT	\N	PRESENT	0
461048	448773	14267Y	PARTICIPANT	\N	PRESENT	0
461049	448773	14275Y	PARTICIPANT	\N	PRESENT	0
461050	448773	14123H	PARTICIPANT	\N	PRESENT	0
461051	448773	19782L	PARTICIPANT	\N	PRESENT	0
461052	448773	19812Y	PARTICIPANT	\N	PRESENT	0
461053	448773	14147R	PARTICIPANT	\N	PRESENT	0
461054	448773	19515S	PARTICIPANT	\N	PRESENT	0
461055	448773	19717B	PARTICIPANT	\N	PRESENT	0
461056	448773	11041F	PARTICIPANT	\N	PRESENT	0
461057	448773	14103D	PARTICIPANT	\N	PRESENT	0
461058	448773	08056B	PARTICIPANT	\N	PRESENT	0
461059	448773	19619A	PARTICIPANT	\N	PRESENT	0
461060	448773	14109K	PARTICIPANT	\N	PRESENT	0
461061	448773	08052W	PARTICIPANT	\N	PRESENT	0
461062	448773	04057K	PARTICIPANT	\N	PRESENT	0
461063	448773	14197C	PARTICIPANT	\N	PRESENT	0
461064	448773	98035U	PARTICIPANT	\N	PRESENT	0
461065	448773	19683J	PARTICIPANT	\N	PRESENT	0
461066	448773	16685X	PARTICIPANT	\N	PRESENT	0
461067	448773	08045X	PARTICIPANT	\N	PRESENT	0
461068	448773	19637C	PARTICIPANT	\N	PRESENT	0
461069	448773	19503N	PARTICIPANT	\N	PRESENT	0
461070	448773	08061X	PARTICIPANT	\N	PRESENT	0
461071	448773	19387D	PARTICIPANT	\N	PRESENT	0
461072	448773	11040E	PARTICIPANT	\N	PRESENT	0
461073	448773	11054L	PARTICIPANT	\N	PRESENT	0
461074	448773	19629C	PARTICIPANT	\N	PRESENT	0
461075	448773	19253P	PARTICIPANT	\N	PRESENT	0
461076	448773	14159V	PARTICIPANT	\N	PRESENT	0
461077	448773	14229S	PARTICIPANT	\N	PRESENT	0
461078	448773	14255U	PARTICIPANT	\N	PRESENT	0
461079	448773	04089T	PARTICIPANT	\N	PRESENT	0
461080	448773	19699S	PARTICIPANT	\N	PRESENT	0
461081	448773	14221J	PARTICIPANT	\N	PRESENT	0
461082	448773	14207L	PARTICIPANT	\N	PRESENT	0
461083	448773	19593H	PARTICIPANT	\N	PRESENT	0
461084	448773	11045K	PARTICIPANT	\N	PRESENT	0
461085	448773	14021P	PARTICIPANT	\N	PRESENT	0
461086	448773	11056N	PARTICIPANT	\N	PRESENT	0
461087	448773	04085P	PARTICIPANT	\N	PRESENT	0
461088	448773	19760E	PARTICIPANT	\N	PRESENT	0
461089	448773	19695N	PARTICIPANT	\N	PRESENT	0
461090	448773	19251M	PARTICIPANT	\N	PRESENT	0
461091	448773	19413M	PARTICIPANT	\N	PRESENT	0
461092	448773	19691J	PARTICIPANT	\N	PRESENT	0
461093	448773	19441R	PARTICIPANT	\N	PRESENT	0
461094	448773	19631V	PARTICIPANT	\N	PRESENT	0
461095	448773	19599P	PARTICIPANT	\N	PRESENT	0
461096	448773	19289C	PARTICIPANT	\N	PRESENT	0
461097	448773	17779H	PARTICIPANT	\N	PRESENT	0
461098	448773	11104D	PARTICIPANT	\N	PRESENT	0
461099	448773	95037J	PARTICIPANT	\N	PRESENT	0
461100	448773	14079W	PARTICIPANT	\N	PRESENT	0
461101	448773	19758L	PARTICIPANT	\N	PRESENT	0
461102	448773	14235Q	PARTICIPANT	\N	PRESENT	0
461103	448773	04034C	PARTICIPANT	\N	PRESENT	0
461104	448773	11083R	PARTICIPANT	\N	PRESENT	0
461105	448773	14191V	PARTICIPANT	\N	PRESENT	0
478266	478264	14073Q	PARTICIPANT	\N	PRESENT	0
478267	478264	02002K	PARTICIPANT	\N	PRESENT	0
478268	478264	11043H	PARTICIPANT	\N	PRESENT	0
478269	478264	19349W	PARTICIPANT	\N	PRESENT	0
478270	478264	19533U	PARTICIPANT	\N	PRESENT	0
478272	478271	08012N	PARTICIPANT	\N	PRESENT	0
478273	478271	02002K	PARTICIPANT	\N	PRESENT	0
478274	478271	19349W	PARTICIPANT	\N	PRESENT	0
478275	478271	11043H	PARTICIPANT	\N	PRESENT	0
478276	478271	19533U	PARTICIPANT	\N	PRESENT	0
478277	478271	19399H	PARTICIPANT	\N	PRESENT	0
478278	478271	14030Q	PARTICIPANT	\N	PRESENT	0
478280	478279	08012N	PARTICIPANT	\N	PRESENT	0
478281	478279	02002K	PARTICIPANT	\N	PRESENT	0
478282	478279	14030Q	PARTICIPANT	\N	PRESENT	0
478283	478279	19533U	PARTICIPANT	\N	PRESENT	0
478284	478279	19251M	PARTICIPANT	\N	PRESENT	0
478285	478279	19399H	PARTICIPANT	\N	PRESENT	0
478286	478279	19349W	PARTICIPANT	\N	PRESENT	0
478289	477712	14097Y	PARTICIPANT	\N	PRESENT	0
478290	477712	95067Q	PARTICIPANT	\N	PRESENT	0
478291	477712	19443T	PARTICIPANT	\N	PRESENT	0
478292	477712	01062T	PARTICIPANT	\N	PRESENT	0
478293	477712	11041F	PARTICIPANT	\N	PRESENT	0
478294	477712	04034C	PARTICIPANT	\N	PRESENT	0
478295	477712	14235Q	PARTICIPANT	\N	PRESENT	0
478296	477712	01058X	PARTICIPANT	\N	PRESENT	0
478297	477712	08058D	PARTICIPANT	\N	PRESENT	0
478298	477712	16685X	PARTICIPANT	\N	PRESENT	0
478299	477712	04042C	PRESIDENT	0	PRESENT	0
478300	477712	11054L	PARTICIPANT	\N	PRESENT	0
478301	477712	19251M	PARTICIPANT	\N	PRESENT	0
478302	477712	11066Q	PARTICIPANT	\N	PRESENT	0
478303	477712	08056B	PARTICIPANT	\N	PRESENT	0
478304	477712	98018T	PARTICIPANT	\N	PRESENT	0
478305	477712	19709B	PARTICIPANT	\N	PRESENT	0
478306	477712	11064N	PARTICIPANT	\N	PRESENT	0
478307	477712	08049C	PARTICIPANT	\N	PRESENT	0
478308	477712	14193X	PARTICIPANT	\N	PRESENT	0
478309	477712	14267Y	PARTICIPANT	\N	PRESENT	0
478310	477712	97011G	PARTICIPANT	\N	PRESENT	0
478311	477712	14211G	PARTICIPANT	\N	PRESENT	0
478312	477712	14255U	PARTICIPANT	\N	PRESENT	0
478313	477712	12041X	PARTICIPANT	\N	PRESENT	0
478314	477712	19721W	PARTICIPANT	\N	PRESENT	0
478315	477712	19421M	PARTICIPANT	\N	PRESENT	0
478316	477712	04035D	PARTICIPANT	\N	PRESENT	0
478317	477703	14083S	PARTICIPANT	\N	PRESENT	0
478318	477703	14331P	PARTICIPANT	\N	PRESENT	0
478319	477703	07029T	PARTICIPANT	\N	PRESENT	0
478320	477703	14085U	PARTICIPANT	\N	PRESENT	0
478407	477748	01024M	PARTICIPANT	\N	PRESENT	0
478322	477703	08010L	PARTICIPANT	\N	PRESENT	0
478323	477703	14253S	PARTICIPANT	\N	PRESENT	0
478324	477703	99004R	PARTICIPANT	\N	PRESENT	0
478326	477703	11070L	PARTICIPANT	\N	PRESENT	0
478327	477703	11048N	PRESIDENT	0	PRESENT	0
478328	477703	08011M	PARTICIPANT	\N	PRESENT	0
478329	477712	95030B	PARTICIPANT	\N	PRESENT	0
478330	477703	19531S	PARTICIPANT	\N	PRESENT	0
478331	477703	19687N	PARTICIPANT	\N	PRESENT	0
478333	477712	14133K	PARTICIPANT	\N	PRESENT	0
478349	477703	04071H	PARTICIPANT	\N	PRESENT	0
478350	477703	19545Y	PARTICIPANT	\N	PRESENT	0
478351	477703	11053K	PARTICIPANT	\N	PRESENT	0
478352	477703	19671E	PARTICIPANT	\N	PRESENT	0
478353	477703	14225N	PARTICIPANT	\N	PRESENT	0
478354	477703	11110B	PARTICIPANT	\N	PRESENT	0
478355	477703	07004J	PARTICIPANT	\N	PRESENT	0
478356	477703	96004D	PARTICIPANT	\N	PRESENT	0
478357	477703	19479G	PARTICIPANT	\N	PRESENT	0
478358	477703	19711U	PARTICIPANT	\N	PRESENT	0
478359	477703	19651A	PARTICIPANT	\N	PRESENT	0
478360	477703	11040E	PARTICIPANT	\N	PRESENT	0
478361	477703	19741B	PARTICIPANT	\N	PRESENT	0
478362	477703	14121F	PARTICIPANT	\N	PRESENT	0
478372	477712	98029W	PARTICIPANT	\N	PRESENT	0
478374	477748	19725B	PARTICIPANT	\N	PRESENT	0
478375	477748	14041T	PARTICIPANT	\N	PRESENT	0
478376	477748	08045X	PARTICIPANT	\N	PRESENT	0
478377	477748	14147R	PARTICIPANT	\N	PRESENT	0
478378	477748	14069U	PARTICIPANT	\N	PRESENT	0
478379	477748	14215L	PRESIDENT	0	PRESENT	0
478380	477748	04044E	PARTICIPANT	\N	PRESENT	0
478390	477748	11026G	PARTICIPANT	\N	PRESENT	0
478391	477748	14179A	PARTICIPANT	\N	PRESENT	0
478392	477748	19719D	PARTICIPANT	\N	PRESENT	0
478393	477748	19447X	PARTICIPANT	\N	PRESENT	0
478394	477748	11072N	PARTICIPANT	\N	PRESENT	0
478395	477748	14021P	PARTICIPANT	\N	PRESENT	0
478396	477748	95063L	PARTICIPANT	\N	PRESENT	0
478398	477712	08053X	PARTICIPANT	\N	PRESENT	0
478401	477703	01048V	PARTICIPANT	\N	PRESENT	0
478402	477703	88008L	PARTICIPANT	\N	PRESENT	0
478403	477703	19647E	PARTICIPANT	\N	PRESENT	0
478404	477703	08034U	PARTICIPANT	\N	PRESENT	0
478405	477703	14034U	PARTICIPANT	\N	PRESENT	0
478406	477712	98050T	PARTICIPANT	\N	PRESENT	0
478408	477748	14231L	PARTICIPANT	\N	PRESENT	0
478409	477748	11085T	PARTICIPANT	\N	PRESENT	0
478410	477748	08018U	PARTICIPANT	\N	PRESENT	0
478411	477748	14151M	PARTICIPANT	\N	PRESENT	0
478419	477712	04040A	PARTICIPANT	\N	PRESENT	0
478420	477712	11027H	PARTICIPANT	\N	PRESENT	0
478422	477703	04086Q	PARTICIPANT	\N	PRESENT	0
478423	477748	05008E	PRESIDENT	1	PRESENT	0
478426	477748	14259Y	PARTICIPANT	\N	PRESENT	0
478427	477748	19729F	PARTICIPANT	\N	PRESENT	0
478428	477748	19673G	PARTICIPANT	\N	PRESENT	0
478429	477748	19675J	PARTICIPANT	\N	PRESENT	0
478430	477748	19489J	PARTICIPANT	\N	PRESENT	0
478431	477748	14053L	PARTICIPANT	\N	PRESENT	0
478432	477748	19253P	PARTICIPANT	\N	PRESENT	0
478433	477748	11033F	PARTICIPANT	\N	PRESENT	0
478434	477748	19629C	PARTICIPANT	\N	PRESENT	0
478438	478424	19333N	PARTICIPANT	\N	PRESENT	0
478439	478424	14031R	PARTICIPANT	\N	PRESENT	0
478440	478424	19549D	PARTICIPANT	\N	PRESENT	0
478441	478424	19820Y	PARTICIPANT	\N	PRESENT	0
478442	478424	14219Q	PARTICIPANT	\N	PRESENT	0
478443	478424	19826F	PARTICIPANT	\N	PRESENT	0
478444	478424	08055A	PARTICIPANT	\N	PRESENT	0
478445	478424	19637C	PARTICIPANT	\N	PRESENT	0
478446	478424	18083K	PARTICIPANT	\N	PRESENT	0
478447	478424	15447F	PARTICIPANT	\N	PRESENT	0
478448	478424	14051J	PARTICIPANT	\N	PRESENT	0
478449	478424	08009T	PRESIDENT	0	PRESENT	0
478450	478424	19745F	PARTICIPANT	\N	PRESENT	0
478451	478424	11065P	PARTICIPANT	\N	PRESENT	0
478452	478424	19503N	PARTICIPANT	\N	EXCUSE	0
478453	477838	19768N	PARTICIPANT	\N	PRESENT	0
478454	477838	19515S	PARTICIPANT	\N	PRESENT	0
478455	477838	01043Q	PARTICIPANT	\N	PRESENT	0
478456	477838	14357A	PARTICIPANT	\N	PRESENT	0
478457	477838	19441R	PARTICIPANT	\N	PRESENT	0
478458	477838	19812Y	PARTICIPANT	\N	PRESENT	0
478459	477838	14081Q	PARTICIPANT	\N	PRESENT	0
478460	477838	80013X	PARTICIPANT	\N	PRESENT	0
478461	477838	19866P	PARTICIPANT	\N	PRESENT	0
478462	477838	04045F	PARTICIPANT	\N	PRESENT	0
478463	477838	19912C	PARTICIPANT	\N	PRESENT	0
478464	477838	19631V	PARTICIPANT	\N	PRESENT	0
478465	477838	11099A	PARTICIPANT	\N	PRESENT	0
478466	477838	04049K	PARTICIPANT	\N	PRESENT	0
478467	477838	19705W	PARTICIPANT	\N	PRESENT	0
478468	477838	08015R	PARTICIPANT	\N	PRESENT	0
478469	477838	08019V	PARTICIPANT	\N	PRESENT	0
478470	477838	14197C	PARTICIPANT	\N	PRESENT	0
478471	477838	19369B	PARTICIPANT	\N	PRESENT	0
478472	477838	19511N	PARTICIPANT	\N	PRESENT	0
478473	477838	19563B	PARTICIPANT	\N	PRESENT	0
478474	477838	14265W	PARTICIPANT	\N	PRESENT	0
478475	477838	14329V	PARTICIPANT	\N	PRESENT	0
478476	477838	14135M	PARTICIPANT	\N	PRESENT	0
478477	477838	19467C	PARTICIPANT	\N	PRESENT	0
478478	477838	14187A	PARTICIPANT	\N	PRESENT	0
478479	477838	19695N	PARTICIPANT	\N	PRESENT	0
478480	477838	14033T	PARTICIPANT	\N	PRESENT	0
478481	477838	11090Q	PRESIDENT	0	PRESENT	0
478482	477838	01025N	PARTICIPANT	\N	PRESENT	0
478483	477838	04088S	PARTICIPANT	\N	PRESENT	0
478484	477838	11056N	PARTICIPANT	\N	PRESENT	0
478485	477838	14115H	PARTICIPANT	\N	PRESENT	0
478486	477838	19507S	PARTICIPANT	\N	PRESENT	0
478487	477838	19747H	PARTICIPANT	\N	PRESENT	0
478488	477838	14207L	PARTICIPANT	\N	PRESENT	0
478489	477838	04043D	PARTICIPANT	\N	PRESENT	0
478490	477838	19619A	PARTICIPANT	\N	PRESENT	0
456485	456484	11027H	PARTICIPANT	\N	PRESENT	0
456486	456484	19709B	PARTICIPANT	\N	PRESENT	0
456487	456484	14255U	PARTICIPANT	\N	PRESENT	0
456547	454228	14299H	PARTICIPANT	\N	EXCUSE	0
456567	456566	16685X	PARTICIPANT	\N	PRESENT	0
456568	456566	98029W	PARTICIPANT	\N	PRESENT	0
456569	456566	97011G	PARTICIPANT	\N	PRESENT	0
456570	456566	14249W	PARTICIPANT	\N	PRESENT	0
456571	456566	11083R	PARTICIPANT	\N	PRESENT	0
456636	456635	11115U	PARTICIPANT	\N	PRESENT	0
456637	456635	19721W	PARTICIPANT	\N	PRESENT	0
456638	456635	11041F	PARTICIPANT	\N	PRESENT	0
456639	456635	14235Q	PARTICIPANT	\N	PRESENT	0
456644	456642	14041T	PARTICIPANT	\N	PRESENT	0
456648	456647	14041T	PARTICIPANT	\N	PRESENT	0
456662	456661	14041T	PARTICIPANT	\N	PRESENT	0
456664	456663	14041T	PARTICIPANT	\N	PRESENT	0
457861	455746	19643A	PARTICIPANT	\N	EXCUSE	0
462668	462667	08011M	PARTICIPANT	\N	PRESENT	0
463628	463627	19515S	PARTICIPANT	\N	PRESENT	0
463629	463627	19782L	PARTICIPANT	\N	PRESENT	0
463630	463627	11077T	PARTICIPANT	\N	PRESENT	0
463631	463627	01043Q	PARTICIPANT	\N	PRESENT	0
463632	463627	14357A	PARTICIPANT	\N	PRESENT	0
463633	463627	19545Y	PARTICIPANT	\N	PRESENT	0
463634	463627	19441R	PARTICIPANT	\N	PRESENT	0
463635	463627	19812Y	PARTICIPANT	\N	PRESENT	0
463636	463627	80013X	PARTICIPANT	\N	PRESENT	0
463637	463627	04045F	PARTICIPANT	\N	PRESENT	0
463638	463627	19631V	PARTICIPANT	\N	PRESENT	0
463639	463627	11099A	PARTICIPANT	\N	PRESENT	0
463640	463627	08068F	PARTICIPANT	\N	PRESENT	0
463641	463627	04049K	PARTICIPANT	\N	PRESENT	0
463642	463627	08060W	PARTICIPANT	\N	PRESENT	0
463643	463627	19705W	PARTICIPANT	\N	PRESENT	0
463644	463627	08015R	PARTICIPANT	\N	PRESENT	0
463645	463627	08019V	PARTICIPANT	\N	PRESENT	0
463646	463627	14197C	PARTICIPANT	\N	PRESENT	0
463647	463627	08028W	PARTICIPANT	\N	PRESENT	0
463648	463627	19563B	PARTICIPANT	\N	PRESENT	0
463649	463627	14265W	PARTICIPANT	\N	PRESENT	0
463650	463627	14329V	PARTICIPANT	\N	PRESENT	0
463651	463627	14135M	PARTICIPANT	\N	PRESENT	0
463652	463627	19467C	PARTICIPANT	\N	PRESENT	0
463653	463627	14187A	PARTICIPANT	\N	PRESENT	0
463654	463627	08038Y	PARTICIPANT	\N	PRESENT	0
463655	463627	19695N	PARTICIPANT	\N	PRESENT	0
463656	463627	11090Q	PRESIDENT	0	PRESENT	0
463657	463627	01025N	PARTICIPANT	\N	PRESENT	0
463658	463627	19295A	PARTICIPANT	\N	PRESENT	0
463659	463627	19269X	PARTICIPANT	\N	PRESENT	0
463660	463627	14205J	PARTICIPANT	\N	PRESENT	0
463661	463627	11056N	PARTICIPANT	\N	PRESENT	0
463662	463627	11101A	PARTICIPANT	\N	PRESENT	0
463663	463627	19747H	PARTICIPANT	\N	PRESENT	0
463664	463627	14207L	PARTICIPANT	\N	PRESENT	0
463665	463627	04043D	PARTICIPANT	\N	PRESENT	0
463666	463627	19619A	PARTICIPANT	\N	PRESENT	0
463667	463627	14255U	PARTICIPANT	\N	PRESENT	0
463668	463627	14257W	PARTICIPANT	\N	PRESENT	0
463669	463627	14033T	PARTICIPANT	\N	PRESENT	0
463670	463627	19866P	PARTICIPANT	\N	EXCUSE	0
463671	463627	19507S	PARTICIPANT	\N	PRESENT	0
463672	463627	19768N	PARTICIPANT	\N	PRESENT	0
463673	463627	14051J	PARTICIPANT	\N	PRESENT	0
463674	463627	14081Q	PARTICIPANT	\N	EXCUSE	0
466628	466627	96004D	PARTICIPANT	\N	PRESENT	0
466629	466627	14331P	PARTICIPANT	\N	PRESENT	0
466631	466630	19711U	PARTICIPANT	\N	PRESENT	0
466638	466637	19711U	PARTICIPANT	\N	PRESENT	0
466634	466632	11053K	PARTICIPANT	\N	PRESENT	0
466636	466635	11053K	PARTICIPANT	\N	PRESENT	0
466640	466639	19711U	PARTICIPANT	\N	PRESENT	0
467628	467627	14229S	PARTICIPANT	\N	PRESENT	0
467629	467627	08043V	PARTICIPANT	\N	PRESENT	0
467630	467627	08031R	PARTICIPANT	\N	PRESENT	0
467631	467627	19735D	PARTICIPANT	\N	PRESENT	0
467633	467632	14039A	PARTICIPANT	\N	PRESENT	0
467634	467632	08043V	PARTICIPANT	\N	PRESENT	0
467635	467632	14123H	PARTICIPANT	\N	PRESENT	0
467636	467632	19621T	PARTICIPANT	\N	PRESENT	0
467637	467632	14109K	PARTICIPANT	\N	PRESENT	0
467639	467638	14039A	PARTICIPANT	\N	PRESENT	0
467641	467640	19699S	PARTICIPANT	\N	PRESENT	0
467642	467640	19758L	PARTICIPANT	\N	PRESENT	0
467643	467640	19621T	PARTICIPANT	\N	PRESENT	0
467645	467644	19699S	PARTICIPANT	\N	PRESENT	0
467646	467644	04059M	PARTICIPANT	\N	PRESENT	0
467653	467652	19533U	PARTICIPANT	\N	PRESENT	0
467654	467652	14241N	PARTICIPANT	\N	PRESENT	0
467655	467652	19593H	PARTICIPANT	\N	PRESENT	0
467656	467652	14061L	PARTICIPANT	\N	PRESENT	0
467657	467652	19611R	PARTICIPANT	\N	PRESENT	0
467659	467658	19533U	PARTICIPANT	\N	PRESENT	0
467661	467660	19533U	PARTICIPANT	\N	PRESENT	0
467662	467660	14241N	PARTICIPANT	\N	PRESENT	0
467663	467660	19593H	PARTICIPANT	\N	PRESENT	0
467664	467660	19611R	PARTICIPANT	\N	PRESENT	0
467665	467660	14061L	PARTICIPANT	\N	PRESENT	0
467666	467660	14229S	PARTICIPANT	\N	PRESENT	0
467668	467667	19533U	PARTICIPANT	\N	PRESENT	0
467669	467667	14241N	PARTICIPANT	\N	PRESENT	0
467671	467670	14073Q	PARTICIPANT	\N	PRESENT	0
467672	467670	19766L	PARTICIPANT	\N	PRESENT	0
467673	467670	08017T	PARTICIPANT	\N	PRESENT	0
467675	467674	19533U	PARTICIPANT	\N	PRESENT	0
467676	467674	19593H	PARTICIPANT	\N	PRESENT	0
467677	467674	14241N	PARTICIPANT	\N	PRESENT	0
467678	467674	14061L	PARTICIPANT	\N	PRESENT	0
467679	467674	19611R	PARTICIPANT	\N	PRESENT	0
467680	467658	19593H	PARTICIPANT	\N	PRESENT	0
467681	467658	14241N	PARTICIPANT	\N	PRESENT	0
467682	467658	14061L	PARTICIPANT	\N	PRESENT	0
467683	467658	19573D	PARTICIPANT	\N	PRESENT	0
467684	467658	19611R	PARTICIPANT	\N	PRESENT	0
467686	467685	19693L	PARTICIPANT	\N	PRESENT	0
467688	467687	19693L	PARTICIPANT	\N	PRESENT	0
467690	467689	19693L	PARTICIPANT	\N	PRESENT	0
467692	467691	14073Q	PARTICIPANT	\N	PRESENT	0
467694	467693	14073Q	PARTICIPANT	\N	PRESENT	0
467696	467695	14073Q	PARTICIPANT	\N	PRESENT	0
467698	467697	14073Q	PARTICIPANT	\N	PRESENT	0
467700	467699	14073Q	PARTICIPANT	\N	PRESENT	0
467702	467701	14229S	PARTICIPANT	\N	PRESENT	0
467704	467703	14229S	PARTICIPANT	\N	PRESENT	0
467932	467219	08044W	PARTICIPANT	\N	PRESENT	0
467933	467219	11085T	PARTICIPANT	\N	PRESENT	0
467934	467219	95063L	PARTICIPANT	\N	PRESENT	0
467935	467219	14217N	PARTICIPANT	\N	PRESENT	0
467936	467219	04033B	PARTICIPANT	\N	PRESENT	0
467937	467219	11097X	PARTICIPANT	\N	PRESENT	0
467938	467219	14026U	PARTICIPANT	\N	PRESENT	0
467939	467219	17637T	PARTICIPANT	\N	PRESENT	0
467940	467219	12041X	PARTICIPANT	\N	PRESENT	0
467941	467219	08009T	PARTICIPANT	\N	PRESENT	0
467930	467219	04047H	PARTICIPANT	\N	PRESENT	0
467931	467219	19649G	PARTICIPANT	\N	PRESENT	0
467942	467219	05008E	PARTICIPANT	\N	PRESENT	0
467943	467219	11045K	PARTICIPANT	\N	PRESENT	0
467944	467219	14123H	PARTICIPANT	\N	PRESENT	0
467945	467219	19697Q	PARTICIPANT	\N	PRESENT	0
467946	467219	14151M	PARTICIPANT	\N	PRESENT	0
467947	467219	19591F	PARTICIPANT	\N	PRESENT	0
467948	467219	08061X	PARTICIPANT	\N	PRESENT	0
467952	467219	14179A	PARTICIPANT	\N	PRESENT	0
467953	467219	10006L	PARTICIPANT	\N	PRESENT	0
467954	467219	14053L	PARTICIPANT	\N	PRESENT	0
467955	467219	04070G	PARTICIPANT	\N	PRESENT	0
467956	467219	89017R	PARTICIPANT	\N	PRESENT	0
467963	467219	19689Q	PARTICIPANT	\N	PRESENT	0
467964	467219	14259Y	PARTICIPANT	\N	PRESENT	0
478001	477921	14039A	PARTICIPANT	\N	PRESENT	0
478002	477921	16685X	PARTICIPANT	\N	PRESENT	0
478003	477921	19695N	PARTICIPANT	\N	PRESENT	0
478004	477921	14059S	PARTICIPANT	\N	PRESENT	0
478005	477921	11064N	PARTICIPANT	\N	PRESENT	0
478010	476727	19725B	PARTICIPANT	\N	PRESENT	0
478011	476727	14026U	PARTICIPANT	\N	PRESENT	0
478012	477921	19525U	PARTICIPANT	\N	PRESENT	0
478101	476533	11097X	PARTICIPANT	\N	PRESENT	0
478102	476533	99004R	PRESIDENT	0	PRESENT	0
478105	476868	19335Q	PARTICIPANT	\N	PRESENT	0
478106	476868	08049C	PARTICIPANT	\N	PRESENT	0
478126	477837	19515S	PARTICIPANT	\N	PRESENT	0
478127	477837	19812Y	PARTICIPANT	\N	PRESENT	0
478128	477837	14033T	PARTICIPANT	\N	PRESENT	0
478129	477837	19705W	PARTICIPANT	\N	PRESENT	0
478130	477837	19619A	PARTICIPANT	\N	PRESENT	0
478131	477837	14257W	PARTICIPANT	\N	PRESENT	0
478157	477837	19768N	PARTICIPANT	\N	PRESENT	0
478158	477837	19782L	PARTICIPANT	\N	PRESENT	0
478159	477837	11099A	PARTICIPANT	\N	PRESENT	0
478160	477837	14197C	PARTICIPANT	\N	PRESENT	0
478161	477837	19563B	PARTICIPANT	\N	PRESENT	0
478162	473407	19826F	PARTICIPANT	\N	PRESENT	0
478163	473407	19731Y	PARTICIPANT	\N	PRESENT	0
478164	473407	19679N	PARTICIPANT	\N	PRESENT	0
478165	473407	19683J	PARTICIPANT	\N	PRESENT	0
478166	473407	19575F	PARTICIPANT	\N	PRESENT	0
478167	473407	19697Q	PARTICIPANT	\N	PRESENT	0
478168	473407	10006L	PARTICIPANT	\N	PRESENT	0
478169	473407	11097X	PARTICIPANT	\N	PRESENT	0
478170	473407	19691J	PARTICIPANT	\N	PRESENT	0
478171	473407	04057K	PARTICIPANT	\N	PRESENT	0
478172	473407	19760E	PARTICIPANT	\N	PRESENT	0
478173	473407	04092N	PARTICIPANT	\N	PRESENT	0
478174	473407	98024R	PARTICIPANT	\N	PRESENT	0
478175	473407	19553Y	PARTICIPANT	\N	PRESENT	0
478176	473407	01024M	PARTICIPANT	\N	PRESENT	0
478177	473407	14030Q	PARTICIPANT	\N	PRESENT	0
478178	473407	19367Y	PARTICIPANT	\N	PRESENT	0
478180	473407	14071N	PARTICIPANT	\N	PRESENT	0
478181	473407	11115U	PARTICIPANT	\N	PRESENT	0
478182	473407	15447F	PARTICIPANT	\N	PRESENT	0
478183	473407	18083K	PARTICIPANT	\N	PRESENT	0
478184	473407	04085P	PARTICIPANT	\N	PRESENT	0
478185	473407	19719D	PARTICIPANT	\N	PRESENT	0
478190	473407	19563B	PARTICIPANT	\N	PRESENT	0
478191	473407	19573D	PARTICIPANT	\N	PRESENT	0
478192	473407	14069U	PARTICIPANT	\N	PRESENT	0
478193	473407	14115H	PARTICIPANT	\N	PRESENT	0
478194	473407	14119M	PARTICIPANT	\N	PRESENT	0
478195	473407	14197C	PARTICIPANT	\N	PRESENT	0
478196	473407	08039A	PARTICIPANT	\N	PRESENT	0
478197	473407	14147R	PARTICIPANT	\N	PRESENT	0
478198	473407	14187A	PARTICIPANT	\N	PRESENT	0
478199	473407	14121F	PARTICIPANT	\N	PRESENT	0
478200	477701	11040E	PARTICIPANT	\N	PRESENT	0
478201	477701	14331P	PARTICIPANT	\N	PRESENT	0
478202	477701	04071H	PARTICIPANT	\N	PRESENT	0
478203	477701	19647E	PARTICIPANT	\N	PRESENT	0
478204	477701	19531S	PARTICIPANT	\N	PRESENT	0
478205	477701	96004D	PARTICIPANT	\N	PRESENT	0
478206	477701	19741B	PARTICIPANT	\N	PRESENT	0
478207	477701	89017R	PARTICIPANT	\N	PRESENT	0
478208	477701	08011M	PARTICIPANT	\N	PRESENT	0
478209	477701	11074Q	PRESIDENT	0	PRESENT	0
478210	477701	04086Q	PARTICIPANT	\N	EXCUSE	0
478211	477701	11012A	PARTICIPANT	\N	EXCUSE	0
478212	477701	14034U	PARTICIPANT	\N	EXCUSE	0
478213	473407	19347U	PARTICIPANT	\N	PRESENT	0
478214	473407	11043H	PARTICIPANT	\N	PRESENT	0
478215	473407	19447X	PARTICIPANT	\N	PRESENT	0
478216	473407	11067R	PARTICIPANT	\N	PRESENT	0
478217	473407	08031R	PARTICIPANT	\N	PRESENT	0
478218	477701	11048N	PARTICIPANT	\N	PRESENT	0
478219	477701	07029T	PARTICIPANT	\N	EXCUSE	0
478220	473407	87003B	PARTICIPANT	\N	PRESENT	0
478221	473407	08052W	PARTICIPANT	\N	PRESENT	0
478223	473407	19415P	PARTICIPANT	\N	PRESENT	0
478230	477923	11040E	PARTICIPANT	\N	PRESENT	0
478231	477923	14069U	PARTICIPANT	\N	PRESENT	0
478232	477923	80013X	PARTICIPANT	\N	PRESENT	0
478233	477923	19525U	PARTICIPANT	\N	PRESENT	0
478234	477923	11070L	PARTICIPANT	\N	PRESENT	0
478235	477923	87003B	PARTICIPANT	\N	PRESENT	0
478236	477923	19551W	PARTICIPANT	\N	PRESENT	0
478237	477923	14121F	PRESIDENT	0	PRESENT	0
478238	477923	19711U	PARTICIPANT	\N	PRESENT	0
478239	477923	19737F	PARTICIPANT	\N	PRESENT	0
478240	477701	01057W	PARTICIPANT	\N	PRESENT	0
478241	477747	19543W	PARTICIPANT	\N	PRESENT	0
478242	477747	11033F	PARTICIPANT	\N	PRESENT	0
478243	477747	19629C	PARTICIPANT	\N	PRESENT	0
478244	477747	04038G	PARTICIPANT	\N	PRESENT	0
478245	477747	19253P	PARTICIPANT	\N	PRESENT	0
478246	477747	14151M	PARTICIPANT	\N	PRESENT	0
478247	477747	19673G	PARTICIPANT	\N	PRESENT	0
478966	478963	14033T	PARTICIPANT	\N	PRESENT	0
478967	478963	80013X	PARTICIPANT	\N	PRESENT	0
478968	478963	14265W	PARTICIPANT	\N	PRESENT	0
478970	478969	14033T	PARTICIPANT	\N	PRESENT	0
478971	478969	14265W	PARTICIPANT	\N	PRESENT	0
479007	477621	19565D	PARTICIPANT	\N	EXCUSE	0
479008	477621	11110B	PARTICIPANT	\N	EXCUSE	0
479012	477621	04045F	PARTICIPANT	\N	EXCUSE	0
479013	477621	08049C	PARTICIPANT	\N	EXCUSE	0
479037	479036	14135M	PARTICIPANT	\N	PRESENT	0
479038	479036	19866P	PARTICIPANT	\N	PRESENT	0
479039	479036	19631V	PARTICIPANT	\N	PRESENT	0
479040	479036	19705W	PARTICIPANT	\N	PRESENT	0
479047	476507	04049K	PRESIDENT	0	PRESENT	0
479048	476507	19575F	PARTICIPANT	\N	PRESENT	0
479049	476507	14083S	PARTICIPANT	\N	PRESENT	0
479052	476507	19695N	PARTICIPANT	\N	PRESENT	0
479054	476507	14026U	PARTICIPANT	\N	PRESENT	0
479056	476507	14061L	PARTICIPANT	\N	PRESENT	0
479057	476507	19671E	PARTICIPANT	\N	PRESENT	0
479059	476507	14030Q	PARTICIPANT	\N	EXCUSE	0
479060	476507	14255U	PARTICIPANT	\N	EXCUSE	0
479061	476507	19545Y	PARTICIPANT	\N	EXCUSE	0
479062	476507	14053L	PARTICIPANT	\N	EXCUSE	0
479063	476507	14041T	PARTICIPANT	\N	EXCUSE	0
479064	476507	19521Q	PARTICIPANT	\N	EXCUSE	0
479065	476507	14034U	PARTICIPANT	\N	EXCUSE	0
479066	476507	14087W	PARTICIPANT	\N	EXCUSE	0
479067	476507	08047A	PARTICIPANT	\N	EXCUSE	0
479115	477695	14221J	PARTICIPANT	\N	PRESENT	0
479116	477695	19503N	PARTICIPANT	\N	PRESENT	0
479117	477695	04043D	PARTICIPANT	\N	PRESENT	0
479119	477695	80013X	PARTICIPANT	\N	PRESENT	0
479120	477695	19693L	PARTICIPANT	\N	PRESENT	0
479123	477695	01048V	PRESIDENT	0	PRESENT	0
479129	477695	01058X	PARTICIPANT	\N	EXCUSE	0
479134	476070	08049C	PARTICIPANT	\N	PRESENT	0
479135	476070	19335Q	PARTICIPANT	\N	PRESENT	0
479142	477714	19443T	PARTICIPANT	\N	PRESENT	0
479143	477714	12041X	PARTICIPANT	\N	PRESENT	0
479144	477714	11080N	PARTICIPANT	\N	PRESENT	0
479145	477714	95030B	PARTICIPANT	\N	PRESENT	0
479146	477714	04034C	PARTICIPANT	\N	PRESENT	0
479147	477714	01058X	PARTICIPANT	\N	PRESENT	0
479148	477714	04040A	PARTICIPANT	\N	PRESENT	0
479149	477714	11027H	PARTICIPANT	\N	PRESENT	0
479150	477714	16685X	PARTICIPANT	\N	PRESENT	0
479151	477714	04042C	PRESIDENT	0	PRESENT	0
479152	477714	11054L	PARTICIPANT	\N	PRESENT	0
479153	477714	11066Q	PARTICIPANT	\N	PRESENT	0
479154	477714	14193X	PARTICIPANT	\N	PRESENT	0
479155	477714	08053X	PARTICIPANT	\N	PRESENT	0
479156	477714	97011G	PARTICIPANT	\N	PRESENT	0
479157	477714	98029W	PARTICIPANT	\N	PRESENT	0
479158	477714	95067Q	PARTICIPANT	\N	PRESENT	0
479159	477714	11041F	PARTICIPANT	\N	PRESENT	0
479160	477714	08058D	PARTICIPANT	\N	PRESENT	0
479161	477714	19251M	PARTICIPANT	\N	PRESENT	0
479162	477714	14028W	PARTICIPANT	\N	PRESENT	0
479163	477714	19319Q	PARTICIPANT	\N	PRESENT	0
479164	477714	14105F	PARTICIPANT	\N	PRESENT	0
479165	477714	98018T	PARTICIPANT	\N	PRESENT	0
479166	477714	14267Y	PARTICIPANT	\N	PRESENT	0
479167	477714	11064N	PARTICIPANT	\N	PRESENT	0
479168	477714	98050T	PARTICIPANT	\N	PRESENT	0
479170	477714	19583F	PARTICIPANT	\N	PRESENT	0
479187	477714	08061X	PARTICIPANT	\N	PRESENT	0
479219	476533	19737F	PARTICIPANT	\N	PRESENT	0
479220	476533	19711U	PARTICIPANT	\N	PRESENT	0
459090	459089	19701S	PARTICIPANT	\N	PRESENT	0
459091	459089	11027H	PARTICIPANT	\N	PRESENT	0
459092	459089	19762G	PARTICIPANT	\N	PRESENT	0
461106	448773	19349W	PARTICIPANT	\N	PRESENT	0
461107	448773	19697Q	PARTICIPANT	\N	PRESENT	0
461108	448773	08024S	PARTICIPANT	\N	PRESENT	0
461109	448773	98029W	PARTICIPANT	\N	PRESENT	0
461110	448773	19329S	PARTICIPANT	\N	PRESENT	0
461111	448773	08011M	PARTICIPANT	\N	PRESENT	0
461112	448773	19685L	PARTICIPANT	\N	PRESENT	0
461113	448773	11012A	PARTICIPANT	\N	PRESENT	0
461114	448773	88008L	PARTICIPANT	\N	PRESENT	0
461115	448773	14034U	PARTICIPANT	\N	PRESENT	0
461116	448773	08049C	PARTICIPANT	\N	PRESENT	0
461117	448773	14241N	PARTICIPANT	\N	PRESENT	0
461118	448773	89017R	PARTICIPANT	\N	PRESENT	0
461119	448773	14029X	PARTICIPANT	\N	PRESENT	0
461120	448773	19663E	PARTICIPANT	\N	PRESENT	0
461121	448773	04088S	PARTICIPANT	\N	PRESENT	0
461122	448773	19563B	PARTICIPANT	\N	PRESENT	0
461123	448773	17589D	PARTICIPANT	\N	PRESENT	0
461124	448773	19729F	PARTICIPANT	\N	PRESENT	0
461125	448773	14251Q	PARTICIPANT	\N	PRESENT	0
461126	448773	08062Y	PARTICIPANT	\N	PRESENT	0
461127	448773	11072N	PARTICIPANT	\N	PRESENT	0
461128	448773	08015R	PARTICIPANT	\N	PRESENT	0
461129	448773	19553Y	PARTICIPANT	\N	PRESENT	0
461130	448773	19705W	PARTICIPANT	\N	PRESENT	0
461131	448773	98050T	PARTICIPANT	\N	PRESENT	0
461132	448773	19527W	PARTICIPANT	\N	PRESENT	0
461133	448773	14059S	PARTICIPANT	\N	PRESENT	0
461134	448773	11074Q	PARTICIPANT	\N	PRESENT	0
461135	448773	14038Y	PARTICIPANT	\N	PRESENT	0
461136	448773	19723Y	PARTICIPANT	\N	PRESENT	0
461137	448773	01028R	PARTICIPANT	\N	PRESENT	0
461138	448773	19467C	PARTICIPANT	\N	PRESENT	0
461139	448773	18083K	PARTICIPANT	\N	PRESENT	0
461140	448773	14051J	PARTICIPANT	\N	PRESENT	0
461141	448773	19669L	PARTICIPANT	\N	PRESENT	0
461142	448773	14135M	PARTICIPANT	\N	PRESENT	0
461143	448773	19399H	PARTICIPANT	\N	PRESENT	0
461144	448773	19693L	PARTICIPANT	\N	PRESENT	0
461145	448773	11066Q	PARTICIPANT	\N	PRESENT	0
461146	448773	14265W	PARTICIPANT	\N	PRESENT	0
461147	448773	14281W	PARTICIPANT	\N	PRESENT	0
461148	448773	14213J	PARTICIPANT	\N	PRESENT	0
461149	448773	08012N	PARTICIPANT	\N	PRESENT	0
461150	448773	19820Y	PARTICIPANT	\N	PRESENT	0
461151	448773	19531S	PARTICIPANT	\N	PRESENT	0
461152	448773	14081Q	PARTICIPANT	\N	PRESENT	0
461153	448773	19383Y	PARTICIPANT	\N	PRESENT	0
461154	448773	11110B	PARTICIPANT	\N	PRESENT	0
461155	448773	04018C	PARTICIPANT	\N	PRESENT	0
461156	448773	19525U	PARTICIPANT	\N	PRESENT	0
461157	448773	14085U	PARTICIPANT	\N	PRESENT	0
461158	448773	19447X	PARTICIPANT	\N	PRESENT	0
461159	448773	08058D	PARTICIPANT	\N	PRESENT	0
461160	448773	19573D	PARTICIPANT	\N	PRESENT	0
461161	448773	19489J	PARTICIPANT	\N	PRESENT	0
461162	448773	14133K	PARTICIPANT	\N	PRESENT	0
461163	448773	11077T	PARTICIPANT	\N	PRESENT	0
461164	448773	92040Q	PARTICIPANT	\N	PRESENT	0
461165	448773	19333N	PARTICIPANT	\N	PRESENT	0
461166	448773	14119M	PARTICIPANT	\N	PRESENT	0
461167	448773	14001X	PARTICIPANT	\N	PRESENT	0
461168	448773	11109J	PARTICIPANT	\N	PRESENT	0
461169	448773	08047A	PARTICIPANT	\N	PRESENT	0
461170	448773	17583W	PARTICIPANT	\N	PRESENT	0
461171	448773	97011G	PARTICIPANT	\N	PRESENT	0
461172	448773	19725B	PARTICIPANT	\N	PRESENT	0
461173	448773	11067R	PARTICIPANT	\N	PRESENT	0
461174	448773	07033P	PARTICIPANT	\N	PRESENT	0
461175	448773	14217N	PARTICIPANT	\N	PRESENT	0
461176	448773	11026G	PARTICIPANT	\N	PRESENT	0
461177	448773	04069P	PARTICIPANT	\N	PRESENT	0
461178	448773	19719D	PARTICIPANT	\N	PRESENT	0
461179	448773	14331P	PARTICIPANT	\N	PRESENT	0
461180	448773	14205J	PARTICIPANT	\N	PRESENT	0
461181	448773	11053K	PARTICIPANT	\N	PRESENT	0
461182	448773	19703U	PARTICIPANT	\N	PRESENT	0
461183	448773	19611R	PARTICIPANT	\N	PRESENT	0
461184	448773	19507S	PARTICIPANT	\N	PRESENT	0
461185	448773	19511N	PARTICIPANT	\N	PRESENT	0
461186	448773	19585H	PARTICIPANT	\N	PRESENT	0
461187	448773	19673G	PARTICIPANT	\N	PRESENT	0
461188	448773	14121F	PARTICIPANT	\N	PRESENT	0
461189	448773	19737F	PARTICIPANT	\N	PRESENT	0
461190	448773	14199E	PARTICIPANT	\N	PRESENT	0
461191	448773	04049K	PARTICIPANT	\N	PRESENT	0
461192	448773	14219Q	PARTICIPANT	\N	PRESENT	0
461193	448773	05012A	PARTICIPANT	\N	PRESENT	0
461194	448773	19713W	PARTICIPANT	\N	PRESENT	0
461195	448773	08034U	PARTICIPANT	\N	PRESENT	0
461196	448773	10006L	PARTICIPANT	\N	PRESENT	0
461197	448773	19335Q	PARTICIPANT	\N	PRESENT	0
461198	448773	19762G	PARTICIPANT	\N	PRESENT	0
461199	448773	14073Q	PARTICIPANT	\N	PRESENT	0
461200	448773	14089Y	PARTICIPANT	\N	PRESENT	0
461201	448773	19826F	PARTICIPANT	\N	PRESENT	0
461202	448773	19798U	PARTICIPANT	\N	PRESENT	0
461203	448773	14193X	PARTICIPANT	\N	PRESENT	0
461204	448773	11085T	PARTICIPANT	\N	PRESENT	0
461205	448773	04040A	PARTICIPANT	\N	PRESENT	0
461206	448773	11080N	PARTICIPANT	\N	PRESENT	0
461207	448773	04070G	PARTICIPANT	\N	PRESENT	0
461257	448773	14157T	PARTICIPANT	\N	PRESENT	0
461209	448773	01024M	PARTICIPANT	\N	PRESENT	0
461210	448773	14030Q	PARTICIPANT	\N	PRESENT	0
461211	448773	19749K	PARTICIPANT	\N	PRESENT	0
461212	448773	01057W	PARTICIPANT	\N	PRESENT	0
461213	448773	14327T	PARTICIPANT	\N	PRESENT	0
461214	448773	01043Q	PARTICIPANT	\N	PRESENT	0
461215	448773	11090Q	PARTICIPANT	\N	PRESENT	0
461216	448773	14069U	PARTICIPANT	\N	PRESENT	0
461217	448773	19647E	PARTICIPANT	\N	PRESENT	0
461218	448773	14215L	PARTICIPANT	\N	PRESENT	0
461219	448773	14087W	PARTICIPANT	\N	PRESENT	0
461220	448773	11099A	PARTICIPANT	\N	PRESENT	0
461221	448773	15447F	PARTICIPANT	\N	PRESENT	0
461222	448773	19643A	PARTICIPANT	\N	PRESENT	0
461223	448773	01060R	PARTICIPANT	\N	PRESENT	0
461224	448773	04071H	PARTICIPANT	\N	PRESENT	0
461225	448773	10015M	PARTICIPANT	\N	PRESENT	0
461226	448773	11043H	PARTICIPANT	\N	PRESENT	0
461227	448773	01048V	PARTICIPANT	\N	PRESENT	0
461228	448773	04033B	PARTICIPANT	\N	PRESENT	0
461229	448773	14187A	PARTICIPANT	\N	PRESENT	0
461230	448773	14071N	PARTICIPANT	\N	PRESENT	0
461231	448773	14151M	PARTICIPANT	\N	PRESENT	0
461232	448773	05008E	PARTICIPANT	\N	PRESENT	0
461233	448773	11097X	PARTICIPANT	\N	PRESENT	0
461234	448773	19735D	PARTICIPANT	\N	PRESENT	0
461235	448773	19679N	PARTICIPANT	\N	PRESENT	0
461236	448773	14042U	PARTICIPANT	\N	PRESENT	0
461237	448773	04097T	PARTICIPANT	\N	PRESENT	0
461238	448773	08020N	PARTICIPANT	\N	PRESENT	0
461239	448773	19521Q	PARTICIPANT	\N	PRESENT	0
461240	448773	08010L	PARTICIPANT	\N	PRESENT	0
461241	448773	01025N	PARTICIPANT	\N	PRESENT	0
461242	448773	04086Q	PARTICIPANT	\N	PRESENT	0
461243	448773	04092N	PARTICIPANT	\N	PRESENT	0
461244	448773	95041E	PARTICIPANT	\N	PRESENT	0
461245	448773	19747H	PARTICIPANT	\N	PRESENT	0
461246	448773	01058X	PARTICIPANT	\N	PRESENT	0
461247	448773	99004R	PARTICIPANT	\N	PRESENT	0
461248	448773	14026U	PARTICIPANT	\N	PRESENT	0
461249	448773	08039A	PARTICIPANT	\N	PRESENT	0
461250	448773	19269X	PARTICIPANT	\N	PRESENT	0
461251	448773	14227Q	PARTICIPANT	\N	PRESENT	0
461252	448773	04035D	PARTICIPANT	\N	PRESENT	0
461253	448773	86034E	PARTICIPANT	\N	PRESENT	0
461254	448773	17637T	PARTICIPANT	\N	PRESENT	0
461255	448773	19766L	PARTICIPANT	\N	PRESENT	0
461256	448773	19711U	PARTICIPANT	\N	PRESENT	0
461258	448773	04038G	PARTICIPANT	\N	PRESENT	0
461259	448773	96004D	PARTICIPANT	\N	PRESENT	0
461260	448773	08048B	PARTICIPANT	\N	PRESENT	0
461261	448773	11031D	PARTICIPANT	\N	PRESENT	0
461262	448773	04044E	PARTICIPANT	\N	PRESENT	0
461263	448773	14105F	PARTICIPANT	\N	PRESENT	0
461264	448773	04042C	PARTICIPANT	\N	PRESENT	0
461265	448773	19551W	PARTICIPANT	\N	PRESENT	0
461266	448773	98024R	PARTICIPANT	\N	PRESENT	0
461267	448773	14249W	PARTICIPANT	\N	PRESENT	0
461268	448773	08017T	PARTICIPANT	\N	PRESENT	0
461269	448773	04043D	PARTICIPANT	\N	PRESENT	0
461271	448773	01062T	PARTICIPANT	\N	PRESENT	0
478491	477838	14257W	PARTICIPANT	\N	PRESENT	0
478496	478424	04097T	PARTICIPANT	\N	PRESENT	0
478497	478424	19383Y	PARTICIPANT	\N	PRESENT	0
478498	478424	19701S	PARTICIPANT	\N	PRESENT	0
478499	478424	04069P	PARTICIPANT	\N	PRESENT	0
478500	478424	19387D	PARTICIPANT	\N	PRESENT	0
478501	478424	14221J	PARTICIPANT	\N	PRESENT	0
478502	478424	19551W	PARTICIPANT	\N	PRESENT	0
478503	478424	08024S	PARTICIPANT	\N	PRESENT	0
478504	478424	17637T	PARTICIPANT	\N	PRESENT	0
478505	478424	19713W	PARTICIPANT	\N	PRESENT	0
478506	478424	14093U	PARTICIPANT	\N	PRESENT	0
478507	478424	14029X	PARTICIPANT	\N	PRESENT	0
478508	478424	19737F	PARTICIPANT	\N	PRESENT	0
478509	478424	19739H	PARTICIPANT	\N	PRESENT	0
478513	478512	19766L	PARTICIPANT	\N	PRESENT	0
478514	478512	04070G	PRESIDENT	0	PRESENT	0
478515	478512	19699S	PARTICIPANT	\N	PRESENT	0
478516	478512	19533U	PARTICIPANT	\N	PRESENT	0
478517	478512	14229S	PARTICIPANT	\N	PRESENT	0
478518	478512	14241N	PARTICIPANT	\N	PRESENT	0
478519	478512	14039A	PARTICIPANT	\N	PRESENT	0
478520	478512	14107H	PARTICIPANT	\N	PRESENT	0
478521	478512	08017T	PARTICIPANT	\N	PRESENT	0
478522	478512	07033P	PARTICIPANT	\N	PRESENT	0
478523	478512	08012N	PARTICIPANT	\N	PRESENT	0
478524	478512	19335Q	PARTICIPANT	\N	PRESENT	0
478525	478512	14249W	PARTICIPANT	\N	PRESENT	0
478526	478512	08039A	PARTICIPANT	\N	PRESENT	0
478527	478512	08031R	PARTICIPANT	\N	PRESENT	0
478528	478512	19593H	PARTICIPANT	\N	PRESENT	0
478529	478512	19643A	PARTICIPANT	\N	PRESENT	0
478530	478512	14059S	PARTICIPANT	\N	PRESENT	0
478531	478512	14061L	PARTICIPANT	\N	PRESENT	0
478532	478512	04057K	PARTICIPANT	\N	PRESENT	0
478533	478512	14073Q	PARTICIPANT	\N	PRESENT	0
478534	478512	08035V	PARTICIPANT	\N	PRESENT	0
478535	478512	19611R	PARTICIPANT	\N	PRESENT	0
478536	478512	08043V	PARTICIPANT	\N	PRESENT	0
478537	478512	19693L	PARTICIPANT	\N	PRESENT	0
478538	478512	87003B	PARTICIPANT	\N	PRESENT	0
478539	478512	19399H	PARTICIPANT	\N	PRESENT	0
478540	478512	14030Q	PARTICIPANT	\N	PRESENT	0
478541	478512	19731Y	PARTICIPANT	\N	PRESENT	0
478542	478512	14251Q	PARTICIPANT	\N	PRESENT	0
478543	478512	08020N	PARTICIPANT	\N	PRESENT	0
478544	478512	19735D	PARTICIPANT	\N	PRESENT	0
478545	478512	11083R	PARTICIPANT	\N	PRESENT	0
478546	478512	14109K	PARTICIPANT	\N	PRESENT	0
478547	478512	14123H	PARTICIPANT	\N	PRESENT	0
478548	478512	11043H	PARTICIPANT	\N	PRESENT	0
478549	478512	11104D	PARTICIPANT	\N	PRESENT	0
478550	478512	19758L	PARTICIPANT	\N	PRESENT	0
478551	478512	04018C	PARTICIPANT	\N	PRESENT	0
478552	478512	19621T	PARTICIPANT	\N	PRESENT	0
478557	473409	86034E	PARTICIPANT	\N	PRESENT	0
478558	473409	14051J	PARTICIPANT	\N	PRESENT	0
478559	473409	19651A	PARTICIPANT	\N	PRESENT	0
478560	473409	19621T	PARTICIPANT	\N	PRESENT	0
478561	473409	14331P	PARTICIPANT	\N	PRESENT	0
478562	473409	14173T	PARTICIPANT	\N	PRESENT	0
478563	473409	19741B	PARTICIPANT	\N	PRESENT	0
478564	473409	08052W	PARTICIPANT	\N	PRESENT	0
478565	473409	99004R	PARTICIPANT	\N	PRESENT	0
478566	473409	07033P	PARTICIPANT	\N	PRESENT	0
478567	473409	14357A	PARTICIPANT	\N	PRESENT	0
478568	473409	14159V	PARTICIPANT	\N	PRESENT	0
478569	473409	19731Y	PARTICIPANT	\N	PRESENT	0
478570	473409	14103D	PARTICIPANT	\N	PRESENT	0
478571	473409	19693L	PARTICIPANT	\N	PRESENT	0
478572	473409	14253S	PARTICIPANT	\N	PRESENT	0
478573	473409	14041T	PARTICIPANT	\N	PRESENT	0
478574	473409	14193X	PARTICIPANT	\N	PRESENT	0
478575	473409	19367Y	PARTICIPANT	\N	PRESENT	0
478576	473409	08019V	PARTICIPANT	\N	PRESENT	0
478577	473409	14197C	PARTICIPANT	\N	PRESENT	0
478578	473409	14063N	PARTICIPANT	\N	PRESENT	0
478579	473409	14073Q	PARTICIPANT	\N	PRESENT	0
478580	473409	11027H	PARTICIPANT	\N	PRESENT	0
478581	473409	08055A	PARTICIPANT	\N	PRESENT	0
478582	473409	19503N	PARTICIPANT	\N	PRESENT	0
478583	473409	14179A	PARTICIPANT	\N	PRESENT	0
478584	473409	11072N	PARTICIPANT	\N	PRESENT	0
478585	473409	08061X	PARTICIPANT	\N	PRESENT	0
478586	473409	14219Q	PARTICIPANT	\N	PRESENT	0
478587	473409	04034C	PARTICIPANT	\N	PRESENT	0
478588	473409	08039A	PARTICIPANT	\N	PRESENT	0
478589	473409	19333N	PARTICIPANT	\N	PRESENT	0
478590	473409	19762G	PARTICIPANT	\N	PRESENT	0
478592	473409	14281W	PARTICIPANT	\N	PRESENT	0
478593	473409	14227Q	PARTICIPANT	\N	PRESENT	0
478594	473409	12041X	PARTICIPANT	\N	PRESENT	0
478595	473409	19637C	PARTICIPANT	\N	PRESENT	0
478596	473409	19525U	PARTICIPANT	\N	PRESENT	0
478597	473409	95063L	PARTICIPANT	\N	PRESENT	0
478637	473409	08045X	PARTICIPANT	\N	PRESENT	0
478599	473409	08031R	PARTICIPANT	\N	PRESENT	0
478600	473409	11012A	PARTICIPANT	\N	PRESENT	0
478601	473409	14065Q	PARTICIPANT	\N	PRESENT	0
478602	473409	18083K	PARTICIPANT	\N	PRESENT	0
478603	473409	19725B	PARTICIPANT	\N	PRESENT	0
478604	473409	19415P	PARTICIPANT	\N	PRESENT	0
478605	473409	07029T	PARTICIPANT	\N	PRESENT	0
478606	473409	19647E	PARTICIPANT	\N	PRESENT	0
478607	473409	14115H	PARTICIPANT	\N	PRESENT	0
478608	473409	14235Q	PARTICIPANT	\N	PRESENT	0
478609	473409	05012A	PARTICIPANT	\N	PRESENT	0
478610	473409	19687N	PARTICIPANT	\N	PRESENT	0
478611	473409	19565D	PARTICIPANT	\N	PRESENT	0
478612	473409	14021P	PARTICIPANT	\N	PRESENT	0
478613	473409	14119M	PARTICIPANT	\N	PRESENT	0
478614	473409	11083R	PARTICIPANT	\N	PRESENT	0
478615	473409	04044E	PARTICIPANT	\N	PRESENT	0
478616	473409	14059S	PARTICIPANT	\N	PRESENT	0
478617	473409	14251Q	PARTICIPANT	\N	PRESENT	0
478673	473409	19719D	PARTICIPANT	\N	PRESENT	0
478619	473409	19447X	PARTICIPANT	\N	PRESENT	0
478620	473409	19575F	PARTICIPANT	\N	PRESENT	0
478621	473409	14034U	PARTICIPANT	\N	PRESENT	0
478622	473409	14079W	PARTICIPANT	\N	PRESENT	0
478623	473409	04040A	PARTICIPANT	\N	PRESENT	0
478624	473409	19826F	PARTICIPANT	\N	PRESENT	0
478625	473409	11067R	PARTICIPANT	\N	PRESENT	0
478626	473409	15447F	PARTICIPANT	\N	PRESENT	0
478627	473409	01057W	PARTICIPANT	\N	PRESENT	0
478628	473409	87003B	PARTICIPANT	\N	PRESENT	0
478629	473409	08010L	PARTICIPANT	\N	PRESENT	0
478630	473409	19399H	PARTICIPANT	\N	PRESENT	0
478631	473409	04033B	PARTICIPANT	\N	PRESENT	0
478632	473409	19747H	PARTICIPANT	\N	PRESENT	0
478633	473409	92040Q	PARTICIPANT	\N	PRESENT	0
478634	473409	96004D	PARTICIPANT	\N	PRESENT	0
478635	473409	98024R	PARTICIPANT	\N	PRESENT	0
478636	473409	04042C	PARTICIPANT	\N	PRESENT	0
478638	473409	14030Q	PARTICIPANT	\N	PRESENT	0
478639	473409	14081Q	PARTICIPANT	\N	PRESENT	0
478640	473409	11085T	PARTICIPANT	\N	PRESENT	0
478641	473409	14083S	PARTICIPANT	\N	PRESENT	0
478642	473409	19421M	PARTICIPANT	\N	PRESENT	0
478646	473409	19912C	PARTICIPANT	\N	PRESENT	0
478644	473409	19691J	PARTICIPANT	\N	PRESENT	0
478645	473409	14147R	PARTICIPANT	\N	PRESENT	0
478647	473409	19369B	PARTICIPANT	\N	PRESENT	0
478648	473409	14031R	PARTICIPANT	\N	PRESENT	0
478649	473409	14085U	PARTICIPANT	\N	PRESENT	0
478650	473409	01024M	PARTICIPANT	\N	PRESENT	0
478651	473409	16685X	PARTICIPANT	\N	PRESENT	0
478652	473409	14205J	PARTICIPANT	\N	PRESENT	0
478653	473409	89017R	PARTICIPANT	\N	PRESENT	0
478654	473409	14151M	PARTICIPANT	\N	PRESENT	0
478655	473409	08009T	PARTICIPANT	\N	PRESENT	0
478656	473409	19745F	PARTICIPANT	\N	PRESENT	0
478657	473409	14255U	PARTICIPANT	\N	PRESENT	0
478658	473409	08015R	PARTICIPANT	\N	PRESENT	0
478659	473409	14229S	PARTICIPANT	\N	PRESENT	0
478660	473409	19663E	PARTICIPANT	\N	PRESENT	0
478661	473409	08034U	PARTICIPANT	\N	PRESENT	0
478662	473409	14213J	PARTICIPANT	\N	PRESENT	0
478663	473409	19766L	PARTICIPANT	\N	PRESENT	0
478664	473409	11048N	PARTICIPANT	\N	PRESENT	0
478665	473409	08018U	PARTICIPANT	\N	PRESENT	0
478666	473409	14029X	PARTICIPANT	\N	PRESENT	0
478667	473409	14071N	PARTICIPANT	\N	PRESENT	0
478668	473409	04092N	PARTICIPANT	\N	PRESENT	0
478669	473409	14061L	PARTICIPANT	\N	PRESENT	0
478670	473409	14069U	PARTICIPANT	\N	PRESENT	0
478671	473409	14123H	PARTICIPANT	\N	PRESENT	0
461611	461609	19747H	PARTICIPANT	\N	PRESENT	0
461612	461609	01024M	PARTICIPANT	\N	PRESENT	0
461613	461609	14033T	PARTICIPANT	\N	PRESENT	0
461614	461609	19533U	PARTICIPANT	\N	PRESENT	0
461615	461609	95067Q	PARTICIPANT	\N	PRESENT	0
461616	461609	19575F	PARTICIPANT	\N	PRESENT	0
461617	461609	19503N	PARTICIPANT	\N	PRESENT	0
462177	462176	01043Q	PARTICIPANT	\N	PRESENT	0
465541	465287	14327T	PARTICIPANT	\N	PRESENT	0
465542	465287	14331P	PARTICIPANT	\N	PRESENT	0
465543	465287	19545Y	PARTICIPANT	\N	PRESENT	0
465544	465287	01057W	PARTICIPANT	\N	PRESENT	0
465545	465287	19667J	PARTICIPANT	\N	PRESENT	0
465546	465287	89017R	PARTICIPANT	\N	PRESENT	0
465547	465287	11074Q	PRESIDENT	0	PRESENT	0
465548	465287	19671E	PARTICIPANT	\N	PRESENT	0
465549	465287	11070L	PARTICIPANT	\N	PRESENT	0
465550	465287	14225N	PARTICIPANT	\N	PRESENT	0
465551	465287	11110B	PARTICIPANT	\N	PRESENT	0
465552	465287	14085U	PARTICIPANT	\N	PRESENT	0
465553	465287	07004J	PARTICIPANT	\N	PRESENT	0
465580	464310	11074Q	PARTICIPANT	\N	PRESENT	0
465555	465287	19349W	PARTICIPANT	\N	PRESENT	0
465556	465287	08010L	PARTICIPANT	\N	PRESENT	0
465557	465287	14253S	PARTICIPANT	\N	PRESENT	0
465558	465287	19479G	PARTICIPANT	\N	PRESENT	0
465559	465287	19647E	PARTICIPANT	\N	PRESENT	0
465560	465287	11048N	PARTICIPANT	\N	PRESENT	0
465561	465287	19711U	PARTICIPANT	\N	PRESENT	0
465562	465287	19651A	PARTICIPANT	\N	PRESENT	0
465563	465287	19531S	PARTICIPANT	\N	PRESENT	0
465564	465287	19687N	PARTICIPANT	\N	PRESENT	0
465565	465287	08011M	PARTICIPANT	\N	PRESENT	0
465566	465287	14034U	PARTICIPANT	\N	PRESENT	0
465567	465287	14173T	PARTICIPANT	\N	PRESENT	0
465568	465287	04086Q	PARTICIPANT	\N	PRESENT	0
465569	465287	11040E	PARTICIPANT	\N	PRESENT	0
465570	465287	14083S	PARTICIPANT	\N	PRESENT	0
465571	465287	11012A	PARTICIPANT	\N	PRESENT	0
465572	465287	19741B	PARTICIPANT	\N	PRESENT	0
465573	465287	14121F	PARTICIPANT	\N	PRESENT	0
465574	465287	99004R	PARTICIPANT	\N	PRESENT	0
465575	465287	01048V	PARTICIPANT	\N	PRESENT	0
465576	465287	88008L	PARTICIPANT	\N	PRESENT	0
465577	465287	14199E	PARTICIPANT	\N	PRESENT	0
465578	465287	11053K	PARTICIPANT	\N	PRESENT	0
465579	464310	11070L	PARTICIPANT	\N	PRESENT	0
465581	464310	14021P	PARTICIPANT	\N	PRESENT	0
465582	464310	14225N	PARTICIPANT	\N	PRESENT	0
465583	464310	11040E	PARTICIPANT	\N	PRESENT	0
465584	464310	19689Q	PARTICIPANT	\N	PRESENT	0
465585	464310	14085U	PARTICIPANT	\N	PRESENT	0
465586	464310	01028R	PARTICIPANT	\N	PRESENT	0
465587	464310	19551W	PARTICIPANT	\N	PRESENT	0
465588	464310	11110B	PARTICIPANT	\N	PRESENT	0
465589	464310	19647E	PARTICIPANT	\N	PRESENT	0
465590	464310	11099A	PARTICIPANT	\N	PRESENT	0
465591	464310	19545Y	PARTICIPANT	\N	PRESENT	0
465592	464310	19569H	PARTICIPANT	\N	PRESENT	0
465593	464310	19441R	PARTICIPANT	\N	PRESENT	0
465594	464310	19479G	PARTICIPANT	\N	PRESENT	0
465595	464310	19691J	PARTICIPANT	\N	PRESENT	0
465596	464310	19719D	PARTICIPANT	\N	PRESENT	0
465597	464310	19651A	PARTICIPANT	\N	PRESENT	0
465598	464310	19531S	PARTICIPANT	\N	PRESENT	0
465599	464310	08011M	PARTICIPANT	\N	PRESENT	0
465600	464310	89017R	PARTICIPANT	\N	PRESENT	0
465601	464310	19741B	PARTICIPANT	\N	PRESENT	0
465602	464310	19573D	PARTICIPANT	\N	PRESENT	0
465603	464310	19591F	PARTICIPANT	\N	PRESENT	0
465604	464310	07033P	PARTICIPANT	\N	PRESENT	0
465605	464310	04033B	PARTICIPANT	\N	PRESENT	0
465606	464310	98050T	PARTICIPANT	\N	PRESENT	0
465607	464310	11048N	PARTICIPANT	\N	PRESENT	0
465608	464310	14157T	PARTICIPANT	\N	PRESENT	0
465609	464310	07029T	PARTICIPANT	\N	PRESENT	0
465610	464310	11085T	PARTICIPANT	\N	PRESENT	0
465611	464310	08010L	PARTICIPANT	\N	PRESENT	0
465612	464310	96004D	PARTICIPANT	\N	PRESENT	0
465613	464310	19762G	PARTICIPANT	\N	PRESENT	0
465614	464310	14034U	PARTICIPANT	\N	PRESENT	0
465615	464310	14031R	PARTICIPANT	\N	PRESENT	0
465616	464310	04086Q	PARTICIPANT	\N	PRESENT	0
465617	464310	04085P	PARTICIPANT	\N	PRESENT	0
465618	464310	19687N	PARTICIPANT	\N	PRESENT	0
465619	464310	11090Q	PARTICIPANT	\N	PRESENT	0
465620	464310	11045K	PARTICIPANT	\N	PRESENT	0
465621	464310	19713W	PARTICIPANT	\N	PRESENT	0
465622	464310	95041E	PARTICIPANT	\N	PRESENT	0
465623	464310	19533U	PARTICIPANT	\N	PRESENT	0
465624	464310	19671E	PARTICIPANT	\N	PRESENT	0
465625	464310	04071H	PARTICIPANT	\N	PRESENT	0
465626	464310	04092N	PARTICIPANT	\N	PRESENT	0
465627	464310	19413M	PARTICIPANT	\N	PRESENT	0
465628	464310	19667J	PARTICIPANT	\N	PRESENT	0
465722	464311	14225N	PARTICIPANT	\N	PRESENT	0
465723	464311	11040E	PARTICIPANT	\N	PRESENT	0
465724	464311	11074Q	PARTICIPANT	\N	PRESENT	0
465725	464311	14021P	PARTICIPANT	\N	PRESENT	0
465726	464311	04034C	PARTICIPANT	\N	PRESENT	0
465727	464311	19551W	PARTICIPANT	\N	PRESENT	0
465728	464311	11110B	PARTICIPANT	\N	PRESENT	0
465729	464311	19413M	PARTICIPANT	\N	PRESENT	0
465730	464311	14085U	PARTICIPANT	\N	PRESENT	0
465731	464311	19689Q	PARTICIPANT	\N	PRESENT	0
465732	464311	11099A	PARTICIPANT	\N	PRESENT	0
465733	464311	19591F	PARTICIPANT	\N	PRESENT	0
465734	464311	19719D	PARTICIPANT	\N	PRESENT	0
465735	464311	19441R	PARTICIPANT	\N	PRESENT	0
465736	464311	19695N	PARTICIPANT	\N	PRESENT	0
465737	464311	19687N	PARTICIPANT	\N	PRESENT	0
465738	464311	19531S	PARTICIPANT	\N	PRESENT	0
465739	464311	11070L	PARTICIPANT	\N	PRESENT	0
465740	464311	19479G	PARTICIPANT	\N	PRESENT	0
465741	464311	19691J	PARTICIPANT	\N	PRESENT	0
465742	464311	11085T	PARTICIPANT	\N	PRESENT	0
465743	464311	19713W	PARTICIPANT	\N	PRESENT	0
465744	464311	19651A	PARTICIPANT	\N	PRESENT	0
465745	464311	01043Q	PARTICIPANT	\N	PRESENT	0
465746	464311	08010L	PARTICIPANT	\N	PRESENT	0
465747	464311	19671E	PARTICIPANT	\N	PRESENT	0
465748	464311	07033P	PARTICIPANT	\N	PRESENT	0
465749	464311	19762G	PARTICIPANT	\N	PRESENT	0
465750	464311	04033B	PARTICIPANT	\N	PRESENT	0
465751	464311	19667J	PARTICIPANT	\N	PRESENT	0
465752	464311	07029T	PARTICIPANT	\N	PRESENT	0
465753	464311	14157T	PARTICIPANT	\N	PRESENT	0
465754	464311	96004D	PARTICIPANT	\N	PRESENT	0
465755	464311	19533U	PARTICIPANT	\N	PRESENT	0
465756	464311	11090Q	PARTICIPANT	\N	PRESENT	0
465757	464311	11048N	PARTICIPANT	\N	PRESENT	0
465758	464311	14031R	PARTICIPANT	\N	PRESENT	0
465759	464311	04086Q	PARTICIPANT	\N	PRESENT	0
465760	464311	95041E	PARTICIPANT	\N	PRESENT	0
465761	464311	19741B	PARTICIPANT	\N	PRESENT	0
465762	464311	04092N	PARTICIPANT	\N	PRESENT	0
465763	464311	04071H	PARTICIPANT	\N	PRESENT	0
465764	464311	19573D	PARTICIPANT	\N	PRESENT	0
465765	464311	19563B	PARTICIPANT	\N	PRESENT	0
465766	464311	14034U	PARTICIPANT	\N	PRESENT	0
465767	464311	11026G	PARTICIPANT	\N	PRESENT	0
465768	464311	19647E	PARTICIPANT	\N	PRESENT	0
465769	464311	19545Y	PARTICIPANT	\N	PRESENT	0
465770	464311	14229S	PARTICIPANT	\N	PRESENT	0
465771	464311	11053K	PARTICIPANT	\N	PRESENT	0
465720	464311	86034E	PARTICIPANT	\N	PRESENT	0
465721	464311	08011M	PARTICIPANT	\N	PRESENT	0
479285	479284	19507S	PARTICIPANT	\N	PRESENT	0
479311	476988	07033P	PARTICIPANT	\N	EXCUSE	0
479312	476988	19329S	PARTICIPANT	\N	EXCUSE	0
479313	476988	14219Q	PARTICIPANT	\N	EXCUSE	0
479314	476988	14135M	PARTICIPANT	\N	EXCUSE	0
479322	476988	96004D	PARTICIPANT	\N	EXCUSE	0
479323	478425	96004D	PARTICIPANT	\N	PRESENT	0
479324	478425	11083R	PARTICIPANT	\N	PRESENT	0
479325	478425	12041X	PARTICIPANT	\N	PRESENT	0
479326	478425	11026G	PARTICIPANT	\N	PRESENT	0
479327	478425	14331P	PARTICIPANT	\N	PRESENT	0
479328	478425	14205J	PARTICIPANT	\N	PRESENT	0
479329	478425	14033T	PARTICIPANT	\N	PRESENT	0
479330	478425	14135M	PARTICIPANT	\N	PRESENT	0
479334	479331	19415P	PARTICIPANT	\N	PRESENT	0
479335	479331	14217N	PARTICIPANT	\N	PRESENT	0
479336	479331	19798U	PARTICIPANT	\N	PRESENT	0
479337	479331	11067R	PARTICIPANT	\N	PRESENT	0
479338	479332	19415P	PARTICIPANT	\N	PRESENT	0
479339	479332	14042U	PARTICIPANT	\N	PRESENT	0
479340	479332	14217N	PARTICIPANT	\N	PRESENT	0
479341	479332	11067R	PARTICIPANT	\N	PRESENT	0
479342	479332	19798U	PARTICIPANT	\N	PRESENT	0
479343	479333	19415P	PARTICIPANT	\N	PRESENT	0
479344	479333	11067R	PARTICIPANT	\N	PRESENT	0
479345	479333	19798U	PARTICIPANT	\N	PRESENT	0
479346	477494	14097Y	PARTICIPANT	\N	PRESENT	0
479347	477494	14197C	PARTICIPANT	\N	PRESENT	0
479348	477494	19549D	PARTICIPANT	\N	PRESENT	0
479349	477494	19369B	PARTICIPANT	\N	PRESENT	0
479350	477494	19611R	PRESIDENT	0	PRESENT	0
479351	477494	14033T	PARTICIPANT	\N	PRESENT	0
479352	477494	14031R	PARTICIPANT	\N	PRESENT	0
479353	477495	19611R	PRESIDENT	0	PRESENT	0
479354	477495	14097Y	PARTICIPANT	\N	PRESENT	0
479355	477495	14033T	PARTICIPANT	\N	PRESENT	0
479356	477495	14031R	PARTICIPANT	\N	PRESENT	0
479357	477495	19549D	PARTICIPANT	\N	PRESENT	0
479358	477496	14097Y	PARTICIPANT	\N	PRESENT	0
479359	477496	19611R	PRESIDENT	0	PRESENT	0
479360	477496	14031R	PARTICIPANT	\N	PRESENT	0
479361	477496	14033T	PARTICIPANT	\N	PRESENT	0
479362	477496	19549D	PARTICIPANT	\N	PRESENT	0
479368	479171	14147R	PARTICIPANT	\N	PRESENT	0
479373	476533	19399H	PARTICIPANT	\N	EXCUSE	0
479416	479033	19387D	PARTICIPANT	\N	PRESENT	0
479422	479418	19503N	PARTICIPANT	\N	PRESENT	0
479436	479434	19503N	PARTICIPANT	\N	PRESENT	0
479439	479437	19503N	PARTICIPANT	\N	PRESENT	0
479443	479441	19503N	PARTICIPANT	\N	PRESENT	0
479446	479444	19503N	PARTICIPANT	\N	PRESENT	0
479469	479468	19349W	PARTICIPANT	\N	PRESENT	0
479470	479468	02002K	PARTICIPANT	\N	PRESENT	0
479471	479468	19711U	PARTICIPANT	\N	PRESENT	0
479472	479468	11043H	PARTICIPANT	\N	PRESENT	0
479473	479468	14241N	PARTICIPANT	\N	PRESENT	0
479474	479468	19251M	PARTICIPANT	\N	PRESENT	0
479475	479468	08012N	PARTICIPANT	\N	PRESENT	0
479476	479468	14147R	PARTICIPANT	\N	PRESENT	0
479478	479477	08012N	PARTICIPANT	\N	PRESENT	0
479479	479477	19349W	PARTICIPANT	\N	PRESENT	0
479480	479477	02002K	PARTICIPANT	\N	PRESENT	0
479481	479477	19711U	PARTICIPANT	\N	PRESENT	0
479482	479477	11043H	PARTICIPANT	\N	PRESENT	0
479483	479477	14241N	PARTICIPANT	\N	PRESENT	0
479484	479477	14147R	PARTICIPANT	\N	PRESENT	0
479485	479477	19399H	PARTICIPANT	\N	PRESENT	0
479487	479486	08012N	PARTICIPANT	\N	PRESENT	0
479488	479486	02002K	PARTICIPANT	\N	PRESENT	0
479489	479486	19349W	PARTICIPANT	\N	PRESENT	0
479490	479486	19711U	PARTICIPANT	\N	PRESENT	0
479491	479486	11043H	PARTICIPANT	\N	PRESENT	0
479492	479486	14147R	PARTICIPANT	\N	PRESENT	0
479493	479486	19533U	PARTICIPANT	\N	PRESENT	0
479494	479486	14030Q	PARTICIPANT	\N	PRESENT	0
479538	479400	14231L	PARTICIPANT	\N	EXCUSE	0
479622	479620	19760E	PARTICIPANT	\N	PRESENT	0
479623	479620	14217N	PARTICIPANT	\N	PRESENT	0
479624	479620	19577H	PARTICIPANT	\N	PRESENT	0
479625	479620	14042U	PARTICIPANT	\N	PRESENT	0
479626	479620	19697Q	PARTICIPANT	\N	PRESENT	0
479627	479620	04092N	PARTICIPANT	\N	PRESENT	0
479628	479620	11097X	PARTICIPANT	\N	PRESENT	0
479629	479620	19798U	PARTICIPANT	\N	PRESENT	0
479634	478591	19711U	PARTICIPANT	\N	PRESENT	0
479635	478591	19737F	PARTICIPANT	\N	PRESENT	0
479636	478591	80013X	PARTICIPANT	\N	PRESENT	0
479675	479055	19415P	PARTICIPANT	\N	PRESENT	0
479676	479055	11097X	PARTICIPANT	\N	PRESENT	0
479708	479055	19717B	PARTICIPANT	\N	PRESENT	0
479709	478591	14069U	PARTICIPANT	\N	PRESENT	0
479710	478591	14205J	PARTICIPANT	\N	PRESENT	0
479999	479072	19723Y	PARTICIPANT	\N	PRESENT	0
480002	478886	19507S	PARTICIPANT	\N	PRESENT	0
480005	478886	19651A	PARTICIPANT	\N	PRESENT	0
480006	478886	11053K	PARTICIPANT	\N	PRESENT	0
480007	478886	11048N	PARTICIPANT	\N	PRESENT	0
480008	478886	14121F	PARTICIPANT	\N	PRESENT	0
480009	478886	19711U	PARTICIPANT	\N	PRESENT	0
480010	478886	19671E	PARTICIPANT	\N	PRESENT	0
480011	478886	14225N	PARTICIPANT	\N	PRESENT	0
480012	478886	19479G	PARTICIPANT	\N	PRESENT	0
480020	478886	07029T	PARTICIPANT	\N	EXCUSE	0
480021	478886	14034U	PARTICIPANT	\N	EXCUSE	0
480064	479880	11033F	PARTICIPANT	\N	PRESENT	0
480065	479880	19629C	PARTICIPANT	\N	PRESENT	0
480066	479880	19719D	PARTICIPANT	\N	PRESENT	0
480067	479880	08018U	PARTICIPANT	\N	PRESENT	0
480068	479880	19649G	PARTICIPANT	\N	PRESENT	0
480069	479880	19729F	PARTICIPANT	\N	PRESENT	0
480070	479880	98035U	PARTICIPANT	\N	PRESENT	0
480071	479880	19675J	PARTICIPANT	\N	PRESENT	0
480081	480080	14147R	PARTICIPANT	\N	PRESENT	0
480082	480080	11072N	PARTICIPANT	\N	PRESENT	0
480720	479094	04044E	PARTICIPANT	\N	EXCUSE	0
480723	479092	14227Q	PARTICIPANT	\N	PRESENT	0
480724	479092	01060R	PARTICIPANT	\N	PRESENT	0
480726	479092	14031R	PARTICIPANT	\N	PRESENT	0
480727	479092	14079W	PARTICIPANT	\N	PRESENT	0
480728	479092	08045X	PARTICIPANT	\N	PRESENT	0
480733	479092	14133K	PARTICIPANT	\N	PRESENT	0
480747	479092	19697Q	PARTICIPANT	\N	PRESENT	0
480748	479092	10006L	PARTICIPANT	\N	PRESENT	0
480791	473425	04044E	PARTICIPANT	\N	PRESENT	0
480792	473425	14179A	PARTICIPANT	\N	PRESENT	0
480793	473425	01024M	PARTICIPANT	\N	PRESENT	0
480794	473425	19691J	PARTICIPANT	\N	PRESENT	0
480795	473425	19697Q	PARTICIPANT	\N	PRESENT	0
480796	473425	14081Q	PARTICIPANT	\N	PRESENT	0
480798	473425	01028R	PARTICIPANT	\N	PRESENT	0
480799	473425	14021P	PARTICIPANT	\N	PRESENT	0
480800	473425	19631V	PARTICIPANT	\N	PRESENT	0
480801	473425	14195A	PARTICIPANT	\N	PRESENT	0
480820	473425	19553Y	PARTICIPANT	\N	PRESENT	0
480803	473425	19467C	PARTICIPANT	\N	PRESENT	0
480804	473425	14061L	PARTICIPANT	\N	PRESENT	0
480805	473425	11067R	PARTICIPANT	\N	PRESENT	0
480806	473425	19413M	PARTICIPANT	\N	PRESENT	0
480807	473425	08052W	PARTICIPANT	\N	PRESENT	0
480808	473425	19349W	PARTICIPANT	\N	PRESENT	0
480809	473425	19565D	PARTICIPANT	\N	PRESENT	0
480810	473425	19551W	PARTICIPANT	\N	PRESENT	0
480812	473425	19333N	PARTICIPANT	\N	PRESENT	0
480813	473425	14227Q	PARTICIPANT	\N	PRESENT	0
480814	473425	19715Y	PARTICIPANT	\N	PRESENT	0
480815	473425	14281W	PARTICIPANT	\N	PRESENT	0
480816	473425	11097X	PARTICIPANT	\N	PRESENT	0
480817	473425	10006L	PARTICIPANT	\N	PRESENT	0
480819	473425	14065Q	PARTICIPANT	\N	PRESENT	0
480821	473425	14030Q	PARTICIPANT	\N	PRESENT	0
480822	473425	17779H	PARTICIPANT	\N	PRESENT	0
480823	473425	08010L	PARTICIPANT	\N	PRESENT	0
480824	473425	19766L	PARTICIPANT	\N	PRESENT	0
480825	473425	19533U	PARTICIPANT	\N	PRESENT	0
480826	473425	19683J	PARTICIPANT	\N	PRESENT	0
480827	473425	19762G	PARTICIPANT	\N	PRESENT	0
480831	473425	19695N	PARTICIPANT	\N	PRESENT	0
480832	473425	19253P	PARTICIPANT	\N	PRESENT	0
480840	479094	19735D	PARTICIPANT	\N	PRESENT	0
480841	479094	05012A	PARTICIPANT	\N	PRESENT	0
480842	479094	14069U	PARTICIPANT	\N	PRESENT	0
480843	479094	11101A	PARTICIPANT	\N	PRESENT	0
480844	479094	19253P	PARTICIPANT	\N	PRESENT	0
480845	479094	19820Y	PARTICIPANT	\N	PRESENT	0
455449	454259	08018U	PARTICIPANT	\N	PRESENT	0
455450	454259	19581D	PARTICIPANT	\N	PRESENT	0
455597	454065	98029W	PARTICIPANT	\N	EXCUSE	0
455603	454065	14097Y	PARTICIPANT	\N	EXCUSE	0
455606	454065	19583F	PARTICIPANT	\N	EXCUSE	0
455610	454065	19709B	PARTICIPANT	\N	EXCUSE	0
455621	454065	14028W	PARTICIPANT	\N	EXCUSE	0
456132	456131	14327T	PARTICIPANT	\N	PRESENT	0
456133	456131	19347U	PARTICIPANT	\N	PRESENT	0
456134	456131	19575F	PARTICIPANT	\N	PRESENT	0
456135	456131	14237S	PARTICIPANT	\N	PRESENT	0
456137	456136	19575F	PARTICIPANT	\N	PRESENT	0
456138	456136	14179A	PARTICIPANT	\N	PRESENT	0
456139	456136	14237S	PARTICIPANT	\N	PRESENT	0
456151	454191	19695N	PARTICIPANT	\N	PRESENT	0
456153	454191	08028W	PARTICIPANT	\N	PRESENT	0
456154	454191	19295A	PARTICIPANT	\N	PRESENT	0
456156	454191	11081P	PARTICIPANT	\N	EXCUSE	0
456157	454191	14357A	PARTICIPANT	\N	EXCUSE	0
456158	454191	19563B	PARTICIPANT	\N	EXCUSE	0
456172	455076	11081P	PARTICIPANT	\N	EXCUSE	0
456173	455076	14357A	PARTICIPANT	\N	EXCUSE	0
456174	455076	19563B	PARTICIPANT	\N	EXCUSE	0
461272	448773	11070L	PARTICIPANT	\N	PRESENT	0
461295	448773	19687N	PARTICIPANT	\N	PRESENT	0
461274	448773	08014Q	PARTICIPANT	\N	PRESENT	0
461275	448773	14097Y	PARTICIPANT	\N	PRESENT	0
461276	448773	01034P	PARTICIPANT	\N	PRESENT	0
461277	448773	19671E	PARTICIPANT	\N	PRESENT	0
461278	448773	19479G	PARTICIPANT	\N	PRESENT	0
461318	448773	08018U	PARTICIPANT	\N	PRESENT	0
461319	448773	95067Q	PARTICIPANT	\N	PRESENT	0
461320	448773	19768N	PARTICIPANT	\N	PRESENT	0
461607	448774	01043Q	PARTICIPANT	\N	PRESENT	0
461327	448773	11048N	PARTICIPANT	\N	PRESENT	0
461618	448774	19782L	PARTICIPANT	\N	PRESENT	0
461619	448774	14207L	PARTICIPANT	\N	PRESENT	0
461620	448774	14109K	PARTICIPANT	\N	PRESENT	0
461621	448774	17589D	PARTICIPANT	\N	PRESENT	0
461622	448774	19563B	PARTICIPANT	\N	PRESENT	0
461623	448774	11056N	PARTICIPANT	\N	PRESENT	0
461624	448774	14235Q	PARTICIPANT	\N	PRESENT	0
461625	448774	19441R	PARTICIPANT	\N	PRESENT	0
461626	448774	11103C	PARTICIPANT	\N	PRESENT	0
461627	448774	95030B	PARTICIPANT	\N	PRESENT	0
461628	448774	19383Y	PARTICIPANT	\N	PRESENT	0
461629	448774	04088S	PARTICIPANT	\N	PRESENT	0
461630	448774	08061X	PARTICIPANT	\N	PRESENT	0
461631	448774	88008L	PARTICIPANT	\N	PRESENT	0
461632	448774	19685L	PARTICIPANT	\N	PRESENT	0
461633	448774	19673G	PARTICIPANT	\N	PRESENT	0
461634	448774	04057K	PARTICIPANT	\N	PRESENT	0
461635	448774	19631V	PARTICIPANT	\N	PRESENT	0
461636	448774	01058X	PARTICIPANT	\N	PRESENT	0
461637	448774	19766L	PARTICIPANT	\N	PRESENT	0
461638	448774	19758L	PARTICIPANT	\N	PRESENT	0
461639	448774	14205J	PARTICIPANT	\N	PRESENT	0
461640	448774	14073Q	PARTICIPANT	\N	PRESENT	0
461641	448774	19413M	PARTICIPANT	\N	PRESENT	0
461642	448774	14033T	PARTICIPANT	\N	PRESENT	0
461643	448774	19812Y	PARTICIPANT	\N	PRESENT	0
461644	448774	11090Q	PARTICIPANT	\N	PRESENT	0
461645	448774	14265W	PARTICIPANT	\N	PRESENT	0
461646	458749	04035D	PARTICIPANT	\N	PRESENT	0
461647	458749	14133K	PARTICIPANT	\N	PRESENT	0
461648	458749	11080N	PARTICIPANT	\N	PRESENT	0
461649	458749	04034C	PARTICIPANT	\N	PRESENT	0
461650	458749	04040A	PARTICIPANT	\N	PRESENT	0
461651	458749	16685X	PARTICIPANT	\N	PRESENT	0
461652	458749	08058D	PARTICIPANT	\N	PRESENT	0
461653	458749	04042C	PRESIDENT	0	PRESENT	0
461654	458749	11066Q	PARTICIPANT	\N	PRESENT	0
461655	458749	08056B	PARTICIPANT	\N	PRESENT	0
461656	458749	95037J	PARTICIPANT	\N	PRESENT	0
461657	458749	98018T	PARTICIPANT	\N	PRESENT	0
461658	458749	14193X	PARTICIPANT	\N	PRESENT	0
461659	458749	14267Y	PARTICIPANT	\N	PRESENT	0
461660	458749	98050T	PARTICIPANT	\N	PRESENT	0
461661	458749	97011G	PARTICIPANT	\N	PRESENT	0
461662	458749	08047A	PARTICIPANT	\N	PRESENT	0
461663	458749	14255U	PARTICIPANT	\N	PRESENT	0
461665	458656	14038Y	PARTICIPANT	\N	PRESENT	0
461666	458656	15447F	PARTICIPANT	\N	PRESENT	0
461667	458656	19551W	PARTICIPANT	\N	PRESENT	0
461668	458656	19711U	PARTICIPANT	\N	PRESENT	0
461669	458656	08034U	PARTICIPANT	\N	PRESENT	0
461670	458656	19531S	PARTICIPANT	\N	PRESENT	0
461671	458656	19737F	PARTICIPANT	\N	PRESENT	0
461672	458656	14069U	PARTICIPANT	\N	PRESENT	0
461673	458656	14121F	PARTICIPANT	\N	PRESENT	0
461674	458656	80013X	PARTICIPANT	\N	PRESENT	0
461675	458656	19399H	PARTICIPANT	\N	PRESENT	0
461676	458656	11070L	PARTICIPANT	\N	PRESENT	0
461677	448774	19798U	PARTICIPANT	\N	PRESENT	0
461678	448774	19826F	PARTICIPANT	\N	PRESENT	0
461679	448774	04045F	PARTICIPANT	\N	PRESENT	0
461680	448774	19629C	PARTICIPANT	\N	PRESENT	0
461682	448774	11099A	PARTICIPANT	\N	PRESENT	0
461683	448774	08015R	PARTICIPANT	\N	PRESENT	0
461684	448774	19651A	PARTICIPANT	\N	PRESENT	0
461685	448774	11110B	PARTICIPANT	\N	PRESENT	0
461686	448774	19515S	PARTICIPANT	\N	PRESENT	0
461687	458656	19525U	PARTICIPANT	\N	PRESENT	0
461688	448774	19619A	PARTICIPANT	\N	PRESENT	0
461689	448774	19713W	PARTICIPANT	\N	PRESENT	0
461690	448774	14135M	PARTICIPANT	\N	PRESENT	0
461691	448774	04049K	PARTICIPANT	\N	PRESENT	0
461692	448774	14115H	PARTICIPANT	\N	PRESENT	0
461693	448774	11012A	PARTICIPANT	\N	PRESENT	0
461694	448774	19349W	PARTICIPANT	\N	PRESENT	0
461695	458749	14097Y	PARTICIPANT	\N	PRESENT	0
461696	458749	14079W	PARTICIPANT	\N	PRESENT	0
461697	458749	01058X	PARTICIPANT	\N	PRESENT	0
461698	458749	11054L	PARTICIPANT	\N	PRESENT	0
461699	458749	08061X	PARTICIPANT	\N	PRESENT	0
461700	458749	98029W	PARTICIPANT	\N	PRESENT	0
461701	458749	95067Q	PARTICIPANT	\N	PRESENT	0
461769	461768	19479G	PARTICIPANT	\N	PRESENT	0
461779	458798	19553Y	PARTICIPANT	\N	PRESENT	0
461780	458798	19697Q	PARTICIPANT	\N	PRESENT	0
461781	458798	14119M	PARTICIPANT	\N	PRESENT	0
461782	458798	19565D	PARTICIPANT	\N	PRESENT	0
461783	458798	04092N	PRESIDENT	0	PRESENT	0
461784	458798	14042U	PARTICIPANT	\N	PRESENT	0
461785	458798	19575F	PARTICIPANT	\N	PRESENT	0
461786	458798	14213J	PARTICIPANT	\N	PRESENT	0
461787	458798	19760E	PARTICIPANT	\N	PRESENT	0
461788	458798	14195A	PARTICIPANT	\N	EXCUSE	0
461789	458798	08041T	PARTICIPANT	\N	EXCUSE	0
461871	457407	01034P	PARTICIPANT	\N	PRESENT	0
461872	457407	19737F	PARTICIPANT	\N	PRESENT	0
461873	457407	14327T	PARTICIPANT	\N	PRESENT	0
461874	457407	19713W	PARTICIPANT	\N	PRESENT	0
461875	457407	19563B	PARTICIPANT	\N	PRESENT	0
461876	457407	19651A	PARTICIPANT	\N	PRESENT	0
461877	457407	19647E	PARTICIPANT	\N	PRESENT	0
461878	457407	19649G	PARTICIPANT	\N	PRESENT	0
461879	457407	19531S	PARTICIPANT	\N	PRESENT	0
461881	457407	11074Q	PARTICIPANT	\N	PRESENT	0
461882	457407	14073Q	PARTICIPANT	\N	PRESENT	0
461883	457407	11070L	PARTICIPANT	\N	PRESENT	0
461884	457407	07004J	PARTICIPANT	\N	PRESENT	0
461888	457407	19399H	PARTICIPANT	\N	PRESENT	0
461890	457407	14119M	PARTICIPANT	\N	PRESENT	0
461891	457407	14033T	PARTICIPANT	\N	PRESENT	0
461893	457407	04088S	PARTICIPANT	\N	PRESENT	0
461895	457407	18083K	PARTICIPANT	\N	PRESENT	0
461896	457407	14215L	PARTICIPANT	\N	PRESENT	0
461897	457407	01057W	PARTICIPANT	\N	PRESENT	0
461898	457407	19515S	PARTICIPANT	\N	PRESENT	0
461899	457407	19565D	PARTICIPANT	\N	PRESENT	0
461900	457407	19711U	PARTICIPANT	\N	PRESENT	0
461901	457407	14069U	PARTICIPANT	\N	PRESENT	0
461902	457407	99004R	PARTICIPANT	\N	PRESENT	0
461903	457407	04086Q	PARTICIPANT	\N	PRESENT	0
461904	457407	95037J	PARTICIPANT	\N	PRESENT	0
461905	457407	14083S	PARTICIPANT	\N	PRESENT	0
461906	457407	19826F	PARTICIPANT	\N	PRESENT	0
461907	457407	04018C	PARTICIPANT	\N	PRESENT	0
461744	457407	86034E	PARTICIPANT	\N	PRESENT	0
461756	461755	19479G	PARTICIPANT	\N	PRESENT	0
461908	457407	19731Y	PARTICIPANT	\N	PRESENT	0
461909	457407	10015M	PARTICIPANT	\N	PRESENT	0
461913	457407	14085U	PARTICIPANT	\N	PRESENT	0
461914	457407	19747H	PARTICIPANT	\N	PRESENT	0
461915	457407	14133K	PARTICIPANT	\N	PRESENT	0
461916	457407	11053K	PARTICIPANT	\N	PRESENT	0
461917	457407	19521Q	PARTICIPANT	\N	PRESENT	0
461918	457407	11012A	PARTICIPANT	\N	PRESENT	0
478674	473409	19709B	PARTICIPANT	\N	PRESENT	0
478675	473409	19533U	PARTICIPANT	\N	PRESENT	0
478676	473409	19543W	PARTICIPANT	\N	PRESENT	0
478677	473409	19593H	PARTICIPANT	\N	PRESENT	0
478679	473409	19563B	PARTICIPANT	\N	PRESENT	0
478680	473409	02002K	PARTICIPANT	\N	PRESENT	0
478681	473409	11099A	PARTICIPANT	\N	PRESENT	0
478696	473409	01043Q	PARTICIPANT	\N	PRESENT	0
478698	478697	19745F	PARTICIPANT	\N	PRESENT	0
478699	478697	14029X	PARTICIPANT	\N	PRESENT	0
478700	478697	19739H	PARTICIPANT	\N	PRESENT	0
478701	478697	19737F	PARTICIPANT	\N	PRESENT	0
478702	473409	11065P	PARTICIPANT	\N	PRESENT	0
478703	478697	19794Q	PARTICIPANT	\N	PRESENT	0
478704	478697	14051J	PARTICIPANT	\N	PRESENT	0
478705	478697	19637C	PARTICIPANT	\N	PRESENT	0
478808	473410	14115H	PARTICIPANT	\N	PRESENT	0
478809	473410	19693L	PARTICIPANT	\N	PRESENT	0
478810	473410	19766L	PARTICIPANT	\N	PRESENT	0
478811	473410	14235Q	PARTICIPANT	\N	PRESENT	0
478812	473410	19447X	PARTICIPANT	\N	PRESENT	0
478813	473410	05008E	PARTICIPANT	\N	PRESENT	0
478814	473410	14041T	PARTICIPANT	\N	PRESENT	0
478815	473410	19565D	PARTICIPANT	\N	PRESENT	0
478816	473410	04034C	PARTICIPANT	\N	PRESENT	0
478817	473410	19719D	PARTICIPANT	\N	PRESENT	0
478818	473410	11067R	PARTICIPANT	\N	PRESENT	0
478819	473410	14255U	PARTICIPANT	\N	PRESENT	0
478821	473410	08039A	PARTICIPANT	\N	PRESENT	0
478822	473410	14147R	PARTICIPANT	\N	PRESENT	0
478823	473410	19709B	PARTICIPANT	\N	PRESENT	0
478824	473410	08018U	PARTICIPANT	\N	PRESENT	0
478825	473410	19733B	PARTICIPANT	\N	PRESENT	0
478826	473410	14031R	PARTICIPANT	\N	PRESENT	0
478827	473410	14215L	PARTICIPANT	\N	PRESENT	0
478828	473410	19705W	PARTICIPANT	\N	PRESENT	0
478829	473410	15447F	PARTICIPANT	\N	PRESENT	0
478830	473410	14357A	PARTICIPANT	\N	PRESENT	0
478831	473410	01028R	PARTICIPANT	\N	PRESENT	0
478832	473410	08017T	PARTICIPANT	\N	PRESENT	0
478833	473410	07029T	PARTICIPANT	\N	PRESENT	0
478834	473410	02002K	PARTICIPANT	\N	PRESENT	0
478835	473410	19820Y	PARTICIPANT	\N	PRESENT	0
478836	473410	18083K	PARTICIPANT	\N	PRESENT	0
478837	473410	14119M	PARTICIPANT	\N	PRESENT	0
478838	478425	18083K	PARTICIPANT	\N	PRESENT	0
478839	478425	19333N	PARTICIPANT	\N	PRESENT	0
478840	478425	08009T	PRESIDENT	0	PRESENT	0
478841	478425	19503N	PARTICIPANT	\N	PRESENT	0
478842	478425	08055A	PARTICIPANT	\N	PRESENT	0
478843	473410	01043Q	PARTICIPANT	\N	PRESENT	0
478844	473410	11027H	PARTICIPANT	\N	PRESENT	0
478845	473410	19647E	PARTICIPANT	\N	PRESENT	0
478846	473410	19533U	PARTICIPANT	\N	PRESENT	0
478847	478425	14093U	PARTICIPANT	\N	PRESENT	0
478848	478425	14031R	PARTICIPANT	\N	PRESENT	0
478866	473410	14193X	PARTICIPANT	\N	PRESENT	0
478851	473410	04033B	PARTICIPANT	\N	PRESENT	0
478852	473410	08031R	PARTICIPANT	\N	PRESENT	0
478863	478425	15447F	PARTICIPANT	\N	PRESENT	0
478864	473410	14179A	PARTICIPANT	\N	PRESENT	0
478865	473410	08015R	PARTICIPANT	\N	PRESENT	0
478867	473410	14083S	PARTICIPANT	\N	PRESENT	0
478868	473410	11012A	PARTICIPANT	\N	PRESENT	0
478869	473410	08061X	PARTICIPANT	\N	PRESENT	0
478870	473410	04071H	PARTICIPANT	\N	PRESENT	0
478871	473410	11026G	PARTICIPANT	\N	PRESENT	0
478872	473410	19643A	PARTICIPANT	\N	PRESENT	0
478873	473410	14213J	PARTICIPANT	\N	PRESENT	0
478874	473410	14069U	PARTICIPANT	\N	PRESENT	0
478879	473410	01024M	PARTICIPANT	\N	PRESENT	0
478880	473410	19543W	PARTICIPANT	\N	PRESENT	0
478883	478425	11065P	PARTICIPANT	\N	PRESENT	0
478932	473414	04034C	PARTICIPANT	\N	PRESENT	0
478933	473414	08061X	PARTICIPANT	\N	PRESENT	0
478934	473414	11027H	PARTICIPANT	\N	PRESENT	0
478935	473414	11026G	PARTICIPANT	\N	PRESENT	0
478936	473414	14041T	PARTICIPANT	\N	PRESENT	0
478937	473414	02002K	PARTICIPANT	\N	PRESENT	0
478938	473414	19543W	PARTICIPANT	\N	PRESENT	0
478939	473414	08017T	PARTICIPANT	\N	PRESENT	0
478940	473414	19709B	PARTICIPANT	\N	PRESENT	0
478941	473414	11012A	PARTICIPANT	\N	PRESENT	0
478942	473414	19766L	PARTICIPANT	\N	PRESENT	0
478943	473414	19693L	PARTICIPANT	\N	PRESENT	0
478944	473414	19447X	PARTICIPANT	\N	PRESENT	0
478945	473414	14357A	PARTICIPANT	\N	PRESENT	0
478946	473414	04033B	PARTICIPANT	\N	PRESENT	0
478947	473414	14255U	PARTICIPANT	\N	PRESENT	0
478948	473414	14179A	PARTICIPANT	\N	PRESENT	0
478949	473414	14083S	PARTICIPANT	\N	PRESENT	0
478950	473414	08031R	PARTICIPANT	\N	PRESENT	0
478952	473414	18083K	PARTICIPANT	\N	PRESENT	0
478961	473414	14069U	PARTICIPANT	\N	PRESENT	0
478962	473414	05008E	PARTICIPANT	\N	PRESENT	0
478964	473414	01024M	PARTICIPANT	\N	PRESENT	0
478965	473414	19565D	PARTICIPANT	\N	PRESENT	0
478980	477750	14041T	PARTICIPANT	\N	PRESENT	0
478981	477750	14147R	PARTICIPANT	\N	PRESENT	0
478982	477750	14179A	PARTICIPANT	\N	PRESENT	0
478983	477750	14069U	PARTICIPANT	\N	PRESENT	0
478803	473410	86034E	PARTICIPANT	\N	PRESENT	0
478806	473410	95063L	PARTICIPANT	\N	PRESENT	0
478984	477750	14215L	PARTICIPANT	\N	PRESENT	0
478985	477750	08018U	PARTICIPANT	\N	PRESENT	0
478986	477750	04047H	PARTICIPANT	\N	PRESENT	0
478987	477750	19719D	PARTICIPANT	\N	PRESENT	0
478988	477750	05008E	PRESIDENT	0	PRESENT	0
478989	477750	19447X	PARTICIPANT	\N	PRESENT	0
479218	479217	08058D	PARTICIPANT	\N	PRESENT	0
479452	479407	80013X	PARTICIPANT	\N	PRESENT	0
479454	479407	04043D	PARTICIPANT	\N	PRESENT	0
479848	479847	11115U	PARTICIPANT	\N	PRESENT	0
479849	479088	19768N	PARTICIPANT	\N	PRESENT	0
479850	479088	19515S	PARTICIPANT	\N	PRESENT	0
479851	479088	11077T	PARTICIPANT	\N	PRESENT	0
479852	479088	14357A	PARTICIPANT	\N	PRESENT	0
478930	473414	01043Q	PARTICIPANT	\N	PRESENT	0
478931	473414	01028R	PARTICIPANT	\N	PRESENT	0
479853	479088	19441R	PARTICIPANT	\N	PRESENT	0
479854	479088	14081Q	PARTICIPANT	\N	PRESENT	0
479855	479088	19413M	PARTICIPANT	\N	PRESENT	0
479856	479088	80013X	PARTICIPANT	\N	PRESENT	0
479857	479088	04045F	PARTICIPANT	\N	PRESENT	0
479858	479088	19631V	PARTICIPANT	\N	PRESENT	0
479859	479088	11099A	PARTICIPANT	\N	PRESENT	0
479860	479088	04049K	PARTICIPANT	\N	PRESENT	0
479861	479088	19705W	PARTICIPANT	\N	PRESENT	0
479862	479088	08015R	PARTICIPANT	\N	PRESENT	0
479863	479088	14197C	PARTICIPANT	\N	PRESENT	0
479864	479088	19369B	PARTICIPANT	\N	PRESENT	0
479865	479088	19511N	PARTICIPANT	\N	PRESENT	0
479866	479088	19563B	PARTICIPANT	\N	PRESENT	0
479867	479088	14265W	PARTICIPANT	\N	PRESENT	0
479868	479088	19467C	PARTICIPANT	\N	PRESENT	0
479869	479088	14187A	PARTICIPANT	\N	PRESENT	0
479870	479088	11090Q	PRESIDENT	0	PRESENT	0
479871	479088	14205J	PARTICIPANT	\N	PRESENT	0
479872	479088	14115H	PARTICIPANT	\N	PRESENT	0
479873	479088	11101A	PARTICIPANT	\N	PRESENT	0
479874	479088	19507S	PARTICIPANT	\N	PRESENT	0
479875	479088	19747H	PARTICIPANT	\N	PRESENT	0
479876	479088	14207L	PARTICIPANT	\N	PRESENT	0
479877	479088	04043D	PARTICIPANT	\N	PRESENT	0
479878	479088	19619A	PARTICIPANT	\N	PRESENT	0
479879	479088	14257W	PARTICIPANT	\N	PRESENT	0
479882	479881	14093U	PARTICIPANT	\N	PRESENT	0
479883	479881	19549D	PARTICIPANT	\N	PRESENT	0
479884	479881	08060W	PARTICIPANT	\N	PRESENT	0
479885	479881	19383Y	PARTICIPANT	\N	PRESENT	0
479886	479881	14038Y	PARTICIPANT	\N	PRESENT	0
479887	479881	18083K	PARTICIPANT	\N	PRESENT	0
479888	479881	19701S	PARTICIPANT	\N	PRESENT	0
479890	479881	11065P	PARTICIPANT	\N	PRESENT	0
479891	479881	19599P	PARTICIPANT	\N	PRESENT	0
479893	479881	19820Y	PARTICIPANT	\N	PRESENT	0
479895	479881	15447F	PARTICIPANT	\N	PRESENT	0
479896	479881	19387D	PARTICIPANT	\N	PRESENT	0
479897	479881	19347U	PARTICIPANT	\N	PRESENT	0
479898	479881	19333N	PARTICIPANT	\N	PRESENT	0
479900	479881	14219Q	PARTICIPANT	\N	PRESENT	0
479902	479881	19637C	PARTICIPANT	\N	PRESENT	0
479903	479881	14221J	PARTICIPANT	\N	PRESENT	0
479904	479881	19745F	PARTICIPANT	\N	PRESENT	0
479905	479881	19739H	PARTICIPANT	\N	PRESENT	0
479906	479881	19794Q	PARTICIPANT	\N	PRESENT	0
479907	479881	04069P	PARTICIPANT	\N	PRESENT	0
479908	479881	19713W	PARTICIPANT	\N	PRESENT	0
460054	457403	11097X	PARTICIPANT	\N	PRESENT	0
460100	459118	19585H	PARTICIPANT	\N	PRESENT	0
460101	457403	19713W	PARTICIPANT	\N	PRESENT	0
460102	457403	19467C	PARTICIPANT	\N	PRESENT	0
460116	457403	89017R	PARTICIPANT	\N	PRESENT	0
460129	457403	08020N	PARTICIPANT	\N	PRESENT	0
460132	457403	11045K	PARTICIPANT	\N	PRESENT	0
460133	457403	11104D	PARTICIPANT	\N	PRESENT	0
460135	457403	87003B	PARTICIPANT	\N	PRESENT	0
460136	457403	19711U	PARTICIPANT	\N	PRESENT	0
460137	457403	19703U	PARTICIPANT	\N	PRESENT	0
460138	457403	11101A	PARTICIPANT	\N	PRESENT	0
460215	448771	19565D	PARTICIPANT	\N	PRESENT	0
460216	448771	11056N	PARTICIPANT	\N	PRESENT	0
460217	448771	19593H	PARTICIPANT	\N	PRESENT	0
460218	448771	19503N	PARTICIPANT	\N	PRESENT	0
460219	448771	11067R	PARTICIPANT	\N	PRESENT	0
460220	448771	19295A	PARTICIPANT	\N	PRESENT	0
460221	448771	14197C	PARTICIPANT	\N	PRESENT	0
460222	448771	14065Q	PARTICIPANT	\N	PRESENT	0
460223	448771	19820Y	PARTICIPANT	\N	PRESENT	0
460224	448771	14281W	PARTICIPANT	\N	PRESENT	0
460225	458747	12041X	PARTICIPANT	\N	PRESENT	0
460226	458747	01062T	PARTICIPANT	\N	PRESENT	0
460227	458747	04034C	PARTICIPANT	\N	PRESENT	0
460228	458747	11041F	PARTICIPANT	\N	PRESENT	0
460229	458747	14235Q	PARTICIPANT	\N	PRESENT	0
460230	458747	08058D	PARTICIPANT	\N	PRESENT	0
460231	458747	14028W	PARTICIPANT	\N	PRESENT	0
460232	458747	11054L	PARTICIPANT	\N	PRESENT	0
460233	458747	04042C	PRESIDENT	0	PRESENT	0
460234	458747	11066Q	PARTICIPANT	\N	PRESENT	0
460235	458747	19669L	PARTICIPANT	\N	PRESENT	0
460236	458747	98018T	PARTICIPANT	\N	PRESENT	0
460237	458747	98022P	PARTICIPANT	\N	PRESENT	0
460238	458747	14267Y	PARTICIPANT	\N	PRESENT	0
460239	458747	14193X	PARTICIPANT	\N	PRESENT	0
460240	458747	98050T	PARTICIPANT	\N	PRESENT	0
460241	458747	08061X	PARTICIPANT	\N	PRESENT	0
460242	458747	14255U	PARTICIPANT	\N	PRESENT	0
460243	448771	11104D	PARTICIPANT	\N	PRESENT	0
460244	448771	14229S	PARTICIPANT	\N	PRESENT	0
460245	448771	19631V	PARTICIPANT	\N	PRESENT	0
460246	448771	19812Y	PARTICIPANT	\N	PRESENT	0
460247	448771	19387D	PARTICIPANT	\N	PRESENT	0
460248	458747	04040A	PARTICIPANT	\N	PRESENT	0
460249	458747	97011G	PARTICIPANT	\N	PRESENT	0
460250	448771	19349W	PARTICIPANT	\N	PRESENT	0
460251	448771	19629C	PARTICIPANT	\N	PRESENT	0
460252	448771	17589D	PARTICIPANT	\N	PRESENT	0
460253	448771	19737F	PARTICIPANT	\N	PRESENT	0
460254	448771	19713W	PARTICIPANT	\N	PRESENT	0
460255	448771	19479G	PARTICIPANT	\N	PRESENT	0
460256	448771	19521Q	PARTICIPANT	\N	PRESENT	0
460257	448771	14073Q	PARTICIPANT	\N	PRESENT	0
460258	448771	19749K	PARTICIPANT	\N	PRESENT	0
460259	448771	19725B	PARTICIPANT	\N	PRESENT	0
460260	448771	19691J	PARTICIPANT	\N	PRESENT	0
460261	448771	01024M	PARTICIPANT	\N	PRESENT	0
460262	448771	14215L	PARTICIPANT	\N	PRESENT	0
460263	448771	14079W	PARTICIPANT	\N	PRESENT	0
460264	448771	19621T	PARTICIPANT	\N	PRESENT	0
460265	448771	14069U	PARTICIPANT	\N	PRESENT	0
460266	448771	19762G	PARTICIPANT	\N	PRESENT	0
460267	448771	19383Y	PARTICIPANT	\N	PRESENT	0
460268	448771	19675J	PARTICIPANT	\N	PRESENT	0
460269	448771	17583W	PARTICIPANT	\N	PRESENT	0
460270	448771	19711U	PARTICIPANT	\N	PRESENT	0
460271	448771	19575F	PARTICIPANT	\N	PRESENT	0
460272	458747	04035D	PARTICIPANT	\N	PRESENT	0
460273	458747	95067Q	PARTICIPANT	\N	PRESENT	0
460274	458747	14133K	PARTICIPANT	\N	PRESENT	0
460275	458747	19251M	PARTICIPANT	\N	PRESENT	0
460276	448771	19399H	PARTICIPANT	\N	PRESENT	0
460277	458747	95030B	PARTICIPANT	\N	PRESENT	0
460278	448771	07029T	PARTICIPANT	\N	PRESENT	0
460279	448771	14033T	PARTICIPANT	\N	PRESENT	0
460280	448771	18083K	PARTICIPANT	\N	PRESENT	0
460281	448771	14119M	PARTICIPANT	\N	PRESENT	0
460285	448771	11043H	PARTICIPANT	\N	PRESENT	0
460283	448771	14031R	PARTICIPANT	\N	PRESENT	0
460284	448771	87003B	PARTICIPANT	\N	PRESENT	0
460286	448771	08020N	PARTICIPANT	\N	PRESENT	0
460213	448771	11070L	PARTICIPANT	\N	PRESENT	0
460214	448771	14265W	PARTICIPANT	\N	PRESENT	0
460287	448771	14275Y	PARTICIPANT	\N	PRESENT	0
460288	448771	19747H	PARTICIPANT	\N	PRESENT	0
460289	448771	11097X	PARTICIPANT	\N	PRESENT	0
460290	448771	14219Q	PARTICIPANT	\N	PRESENT	0
460291	458747	14097Y	PARTICIPANT	\N	PRESENT	0
460317	448771	11099A	PARTICIPANT	\N	PRESENT	0
460318	448771	19333N	PARTICIPANT	\N	PRESENT	0
460319	448771	19651A	PARTICIPANT	\N	PRESENT	0
460320	448771	11012A	PARTICIPANT	\N	PRESENT	0
460321	448771	14213J	PARTICIPANT	\N	PRESENT	0
460322	448771	14059S	PARTICIPANT	\N	PRESENT	0
460323	448771	08039A	PARTICIPANT	\N	PRESENT	0
460324	448771	19533U	PARTICIPANT	\N	PRESENT	0
460325	448771	19467C	PARTICIPANT	\N	PRESENT	0
460326	448771	04047H	PARTICIPANT	\N	PRESENT	0
460327	448771	10006L	PARTICIPANT	\N	PRESENT	0
460328	448771	14083S	PARTICIPANT	\N	PRESENT	0
460329	448771	14205J	PARTICIPANT	\N	PRESENT	0
460330	448771	08015R	PARTICIPANT	\N	PRESENT	0
460331	448771	14038Y	PARTICIPANT	\N	PRESENT	0
460344	448771	11101A	PARTICIPANT	\N	PRESENT	0
460345	448771	19703U	PARTICIPANT	\N	PRESENT	0
460346	448771	14105F	PARTICIPANT	\N	PRESENT	0
460347	448771	14329V	PARTICIPANT	\N	PRESENT	0
460348	448771	19507S	PARTICIPANT	\N	PRESENT	0
460349	458747	14105F	PARTICIPANT	\N	PRESENT	0
460350	448771	01025N	PARTICIPANT	\N	PRESENT	0
460351	448771	14199E	PARTICIPANT	\N	PRESENT	0
460352	448771	14026U	PARTICIPANT	\N	PRESENT	0
460353	448771	14217N	PARTICIPANT	\N	PRESENT	0
460354	448771	01057W	PARTICIPANT	\N	PRESENT	0
460355	448771	19413M	PARTICIPANT	\N	PRESENT	0
460356	448771	04088S	PARTICIPANT	\N	PRESENT	0
460357	448771	14042U	PARTICIPANT	\N	PRESENT	0
460358	448771	04049K	PARTICIPANT	\N	PRESENT	0
460359	448771	97011G	PARTICIPANT	\N	PRESENT	0
460360	448771	08056B	PARTICIPANT	\N	PRESENT	0
460361	448771	14097Y	PARTICIPANT	\N	PRESENT	0
460362	448771	04070G	PARTICIPANT	\N	PRESENT	0
460363	448771	14123H	PARTICIPANT	\N	PRESENT	0
460432	448772	04044E	PARTICIPANT	\N	PRESENT	0
460433	448772	14265W	PARTICIPANT	\N	PRESENT	0
460434	448772	19503N	PARTICIPANT	\N	PRESENT	0
460435	448772	19295A	PARTICIPANT	\N	PRESENT	0
460436	448772	01028R	PARTICIPANT	\N	PRESENT	0
460437	448772	19631V	PARTICIPANT	\N	PRESENT	0
460438	448772	14229S	PARTICIPANT	\N	PRESENT	0
460439	448772	11056N	PARTICIPANT	\N	PRESENT	0
460440	448772	19333N	PARTICIPANT	\N	PRESENT	0
460441	448772	19585H	PARTICIPANT	\N	PRESENT	0
460442	448772	19387D	PARTICIPANT	\N	PRESENT	0
460443	448772	19253P	PARTICIPANT	\N	PRESENT	0
460444	448772	19629C	PARTICIPANT	\N	PRESENT	0
460445	448772	14219Q	PARTICIPANT	\N	PRESENT	0
460446	448772	07029T	PARTICIPANT	\N	PRESENT	0
460447	448772	19703U	PARTICIPANT	\N	PRESENT	0
460448	448772	08020N	PARTICIPANT	\N	PRESENT	0
460449	448772	14105F	PARTICIPANT	\N	PRESENT	0
460450	448772	19349W	PARTICIPANT	\N	PRESENT	0
460451	448772	14073Q	PARTICIPANT	\N	PRESENT	0
460452	448772	14030Q	PARTICIPANT	\N	PRESENT	0
460453	448772	14275Y	PARTICIPANT	\N	PRESENT	0
460454	448772	14083S	PARTICIPANT	\N	PRESENT	0
460455	448772	14034U	PARTICIPANT	\N	PRESENT	0
460456	448772	14069U	PARTICIPANT	\N	PRESENT	0
460457	448772	19711U	PARTICIPANT	\N	PRESENT	0
460458	448772	19737F	PARTICIPANT	\N	PRESENT	0
460459	448772	19812Y	PARTICIPANT	\N	PRESENT	0
460460	448772	19760E	PARTICIPANT	\N	PRESENT	0
460461	448772	19565D	PARTICIPANT	\N	PRESENT	0
460462	448772	14235Q	PARTICIPANT	\N	PRESENT	0
460463	448772	11077T	PARTICIPANT	\N	PRESENT	0
460464	448772	19826F	PARTICIPANT	\N	PRESENT	0
460465	448772	04018C	PARTICIPANT	\N	PRESENT	0
460466	448772	19621T	PARTICIPANT	\N	PRESENT	0
460467	448772	19798U	PARTICIPANT	\N	PRESENT	0
460468	448772	14249W	PARTICIPANT	\N	PRESENT	0
460469	448772	95030B	PARTICIPANT	\N	PRESENT	0
460470	448772	19747H	PARTICIPANT	\N	PRESENT	0
460471	448772	19531S	PARTICIPANT	\N	PRESENT	0
460472	448772	08068F	PARTICIPANT	\N	PRESENT	0
460473	448772	01025N	PARTICIPANT	\N	PRESENT	0
460474	448772	19593H	PARTICIPANT	\N	PRESENT	0
480846	479094	01057W	PARTICIPANT	\N	PRESENT	0
480847	479094	11048N	PARTICIPANT	\N	PRESENT	0
480848	479094	95063L	PARTICIPANT	\N	PRESENT	0
480849	473425	07029T	PARTICIPANT	\N	PRESENT	0
480850	479094	04086Q	PARTICIPANT	\N	PRESENT	0
480851	479094	08031R	PARTICIPANT	\N	PRESENT	0
480852	479094	14169X	PARTICIPANT	\N	PRESENT	0
480874	473425	19725B	PARTICIPANT	\N	PRESENT	0
480875	473425	14157T	PARTICIPANT	\N	PRESENT	0
480879	473425	04042C	PARTICIPANT	\N	PRESENT	0
480880	473425	14241N	PARTICIPANT	\N	PRESENT	0
480881	473425	19599P	PARTICIPANT	\N	PRESENT	0
480883	473425	11027H	PARTICIPANT	\N	PRESENT	0
480942	476988	19631V	PARTICIPANT	\N	PRESENT	0
480943	476988	19577H	PARTICIPANT	\N	PRESENT	0
480944	476988	19715Y	PARTICIPANT	\N	PRESENT	0
480945	476988	08019V	PRESIDENT	0	PRESENT	0
480946	476988	19301E	PARTICIPANT	\N	PRESENT	0
480947	476988	11072N	PARTICIPANT	\N	PRESENT	0
480948	476988	14261S	PARTICIPANT	\N	PRESENT	0
480949	476988	19691J	PARTICIPANT	\N	PRESENT	0
480950	473426	19758L	PARTICIPANT	\N	PRESENT	0
480951	473426	19643A	PARTICIPANT	\N	PRESENT	0
480952	473426	14229S	PARTICIPANT	\N	PRESENT	0
480953	473426	11083R	PARTICIPANT	\N	PRESENT	0
480955	473426	19766L	PARTICIPANT	\N	PRESENT	0
480956	473426	14157T	PARTICIPANT	\N	PRESENT	0
480957	473426	04070G	PARTICIPANT	\N	PRESENT	0
480959	473426	19399H	PARTICIPANT	\N	PRESENT	0
480960	473426	19749K	PARTICIPANT	\N	PRESENT	0
480961	473426	19593H	PARTICIPANT	\N	PRESENT	0
480962	473426	14241N	PARTICIPANT	\N	PRESENT	0
480963	473426	04057K	PARTICIPANT	\N	PRESENT	0
480964	473426	19685L	PARTICIPANT	\N	PRESENT	0
480973	473426	19637C	PARTICIPANT	\N	PRESENT	0
480974	473426	19349W	PARTICIPANT	\N	PRESENT	0
480975	473426	19533U	PARTICIPANT	\N	PRESENT	0
480976	473426	10006L	PARTICIPANT	\N	PRESENT	0
480978	473426	19467C	PARTICIPANT	\N	PRESENT	0
480980	480979	05008E	PARTICIPANT	\N	PRESENT	0
480981	480979	14041T	PARTICIPANT	\N	PRESENT	0
480982	480979	19673G	PARTICIPANT	\N	PRESENT	0
480983	480979	14089Y	PARTICIPANT	\N	PRESENT	0
480984	480979	08045X	PARTICIPANT	\N	PRESENT	0
480985	480979	01028R	PARTICIPANT	\N	PRESENT	0
480986	480979	95063L	PARTICIPANT	\N	PRESENT	0
480987	480979	11033F	PARTICIPANT	\N	PRESENT	0
480988	480856	01024M	PARTICIPANT	\N	PRESENT	0
480989	480856	14215L	PARTICIPANT	\N	PRESENT	0
480990	480856	04044E	PARTICIPANT	\N	PRESENT	0
480934	473426	04086Q	PARTICIPANT	\N	PRESENT	0
480941	476988	19717B	PARTICIPANT	\N	PRESENT	0
480991	480856	05008E	PRESIDENT	0	PRESENT	0
480992	480003	11064N	PARTICIPANT	\N	PRESENT	0
480993	480003	14267Y	PARTICIPANT	\N	PRESENT	0
480994	480003	14039A	PARTICIPANT	\N	PRESENT	0
480995	480003	19695N	PARTICIPANT	\N	PRESENT	0
480996	473426	08045X	PARTICIPANT	\N	PRESENT	0
480997	476509	89017R	PARTICIPANT	\N	EXCUSE	0
480998	476509	19575F	PARTICIPANT	\N	PRESENT	0
480999	476509	14030Q	PARTICIPANT	\N	PRESENT	0
481000	476509	08060W	PARTICIPANT	\N	EXCUSE	0
481001	476509	14255U	PARTICIPANT	\N	EXCUSE	0
481002	476509	14053L	PARTICIPANT	\N	EXCUSE	0
481003	476509	14083S	PARTICIPANT	\N	PRESENT	0
481004	476509	14041T	PARTICIPANT	\N	EXCUSE	0
481005	476509	14187A	PARTICIPANT	\N	EXCUSE	0
481006	476509	14034U	PARTICIPANT	\N	EXCUSE	0
481007	476509	14026U	PARTICIPANT	\N	EXCUSE	0
481008	476509	19591F	PARTICIPANT	\N	EXCUSE	0
481009	476509	14061L	PARTICIPANT	\N	PRESENT	0
481010	476509	11099A	PARTICIPANT	\N	PRESENT	0
481011	476509	04049K	PRESIDENT	0	PRESENT	0
481012	476509	08015R	PARTICIPANT	\N	EXCUSE	0
481013	476509	16685X	PARTICIPANT	\N	PRESENT	0
481014	476509	14265W	PARTICIPANT	\N	PRESENT	0
481015	476509	14051J	PARTICIPANT	\N	EXCUSE	0
481016	476509	14157T	PARTICIPANT	\N	PRESENT	0
481018	473426	11067R	PARTICIPANT	\N	PRESENT	0
481019	480003	14217N	PARTICIPANT	\N	PRESENT	0
481020	473426	04044E	PARTICIPANT	\N	PRESENT	0
481043	473427	08045X	PARTICIPANT	\N	PRESENT	0
481044	473427	19349W	PARTICIPANT	\N	PRESENT	0
481045	473427	04085P	PARTICIPANT	\N	PRESENT	0
481046	473427	19467C	PARTICIPANT	\N	PRESENT	0
481047	473427	10006L	PARTICIPANT	\N	PRESENT	0
481048	473427	11067R	PARTICIPANT	\N	PRESENT	0
481049	473427	19758L	PARTICIPANT	\N	PRESENT	0
481050	473427	19593H	PARTICIPANT	\N	PRESENT	0
481051	473427	11065P	PARTICIPANT	\N	PRESENT	0
481052	473427	19647E	PARTICIPANT	\N	PRESENT	0
481053	473427	14179A	PARTICIPANT	\N	PRESENT	0
481060	476988	14059S	PARTICIPANT	\N	PRESENT	0
481061	480003	19629C	PARTICIPANT	\N	PRESENT	0
481062	476988	19657G	PARTICIPANT	\N	PRESENT	0
481063	473427	14093U	PARTICIPANT	\N	PRESENT	0
481064	473427	19599P	PARTICIPANT	\N	PRESENT	0
481065	473427	14215L	PARTICIPANT	\N	PRESENT	0
481066	473427	05008E	PARTICIPANT	\N	PRESENT	0
481088	481086	04057K	PARTICIPANT	\N	PRESENT	0
481089	480856	19629C	PARTICIPANT	\N	PRESENT	0
481041	473427	04086Q	PARTICIPANT	\N	PRESENT	0
481042	473427	04044E	PARTICIPANT	\N	PRESENT	0
481090	480856	19447X	PARTICIPANT	\N	PRESENT	0
481091	480856	14147R	PARTICIPANT	\N	PRESENT	0
481092	473428	04049K	PARTICIPANT	\N	PRESENT	0
481093	473428	14083S	PARTICIPANT	\N	PRESENT	0
481094	473428	19715Y	PARTICIPANT	\N	PRESENT	0
481095	473428	14227Q	PARTICIPANT	\N	PRESENT	0
481096	473428	19593H	PARTICIPANT	\N	PRESENT	0
481097	473428	10006L	PARTICIPANT	\N	PRESENT	0
481099	473428	14026U	PARTICIPANT	\N	PRESENT	0
481100	473428	19762G	PARTICIPANT	\N	PRESENT	0
481101	473428	19758L	PARTICIPANT	\N	PRESENT	0
481102	473428	19693L	PARTICIPANT	\N	PRESENT	0
481103	473428	14093U	PARTICIPANT	\N	PRESENT	0
481104	473428	07029T	PARTICIPANT	\N	PRESENT	0
481085	473428	04086Q	PARTICIPANT	\N	PRESENT	0
481087	481086	19725B	PARTICIPANT	\N	PRESENT	0
481105	473428	14061L	PARTICIPANT	\N	PRESENT	0
481106	473428	11099A	PARTICIPANT	\N	PRESENT	0
481107	473428	14065Q	PARTICIPANT	\N	PRESENT	0
481108	473428	19533U	PARTICIPANT	\N	PRESENT	0
481109	473428	19651A	PARTICIPANT	\N	PRESENT	0
481131	481130	96004D	PARTICIPANT	\N	PRESENT	0
481132	481130	11083R	PARTICIPANT	\N	PRESENT	0
481133	481130	14089Y	PARTICIPANT	\N	PRESENT	0
481134	481130	19553Y	PARTICIPANT	\N	PRESENT	0
481135	481130	98035U	PARTICIPANT	\N	PRESENT	0
481163	479283	19647E	PARTICIPANT	\N	PRESENT	0
481164	479283	99004R	PARTICIPANT	\N	PRESENT	0
481165	479283	19711U	PARTICIPANT	\N	PRESENT	0
481166	479283	19671E	PARTICIPANT	\N	PRESENT	0
481187	481185	19503N	PARTICIPANT	\N	PRESENT	0
481190	481188	19503N	PARTICIPANT	\N	PRESENT	0
481193	481191	19503N	PARTICIPANT	\N	PRESENT	0
481210	481205	19503N	PARTICIPANT	\N	PRESENT	0
481221	481215	19503N	PARTICIPANT	\N	PRESENT	0
481228	481225	19503N	PARTICIPANT	\N	PRESENT	0
481234	481232	19503N	PARTICIPANT	\N	PRESENT	0
481275	476540	08044W	PARTICIPANT	\N	PRESENT	0
481281	476540	14065Q	PARTICIPANT	\N	PRESENT	0
481415	481414	08019V	PARTICIPANT	\N	PRESENT	0
481475	481474	19709B	PARTICIPANT	\N	PRESENT	0
481476	481474	14028W	PARTICIPANT	\N	PRESENT	0
481509	481508	19575F	PARTICIPANT	\N	EXCUSE	0
481510	481508	19545Y	PARTICIPANT	\N	EXCUSE	0
481518	480873	14257W	PARTICIPANT	\N	EXCUSE	0
481527	481508	14071N	PARTICIPANT	\N	EXCUSE	0
481528	481508	19335Q	PRESIDENT	0	PRESENT	0
481529	481508	08049C	PARTICIPANT	\N	PRESENT	0
481532	481508	19515S	PARTICIPANT	\N	PRESENT	0
481533	481531	19545Y	PARTICIPANT	\N	EXCUSE	0
481534	481508	19503N	PARTICIPANT	\N	PRESENT	0
481535	481508	19387D	PARTICIPANT	\N	PRESENT	0
481536	481508	19619A	PARTICIPANT	\N	PRESENT	0
481566	480797	14267Y	PARTICIPANT	\N	PRESENT	0
481567	480797	14039A	PARTICIPANT	\N	PRESENT	0
481568	480797	11064N	PARTICIPANT	\N	PRESENT	0
481569	480797	19695N	PARTICIPANT	\N	PRESENT	0
481570	480797	19729F	PARTICIPANT	\N	PRESENT	0
481571	480797	04035D	PARTICIPANT	\N	PRESENT	0
457279	457216	11031D	PARTICIPANT	\N	PRESENT	0
457280	457216	01034P	PARTICIPANT	\N	PRESENT	0
457281	457216	11097X	PARTICIPANT	\N	PRESENT	0
457283	457282	11097X	PARTICIPANT	\N	PRESENT	0
457284	457282	01034P	PARTICIPANT	\N	PRESENT	0
457285	457282	11031D	PARTICIPANT	\N	PRESENT	0
457286	457282	19760E	PARTICIPANT	\N	PRESENT	0
457287	457282	14217N	PARTICIPANT	\N	PRESENT	0
457288	457282	19479G	PARTICIPANT	\N	PRESENT	0
457290	457289	11097X	PARTICIPANT	\N	PRESENT	0
457291	457289	14217N	PARTICIPANT	\N	PRESENT	0
457292	457289	19760E	PARTICIPANT	\N	PRESENT	0
457293	457289	11031D	PARTICIPANT	\N	PRESENT	0
457295	457294	19760E	PARTICIPANT	\N	PRESENT	0
457296	457294	14217N	PARTICIPANT	\N	PRESENT	0
457297	457294	11097X	PARTICIPANT	\N	PRESENT	0
461924	457407	14059S	PARTICIPANT	\N	PRESENT	0
461926	457407	19575F	PARTICIPANT	\N	PRESENT	0
461927	457407	14255U	PARTICIPANT	\N	PRESENT	0
461928	457407	11099A	PARTICIPANT	\N	PRESENT	0
461929	457407	19760E	PARTICIPANT	\N	PRESENT	0
461930	457407	11040E	PARTICIPANT	\N	PRESENT	0
461931	457407	14187A	PARTICIPANT	\N	PRESENT	0
461932	457407	08015R	PARTICIPANT	\N	PRESENT	0
461933	457407	01060R	PARTICIPANT	\N	PRESENT	0
461934	457407	14213J	PARTICIPANT	\N	PRESENT	0
461935	457407	14265W	PARTICIPANT	\N	PRESENT	0
461936	457407	11048N	PARTICIPANT	\N	PRESENT	0
461937	457407	08039A	PARTICIPANT	\N	PRESENT	0
461938	457407	04049K	PARTICIPANT	\N	PRESENT	0
461940	457407	95041E	PARTICIPANT	\N	PRESENT	0
461942	457407	08010L	PARTICIPANT	\N	PRESENT	0
461945	457407	01028R	PARTICIPANT	\N	PRESENT	0
461946	457407	95067Q	PARTICIPANT	\N	PRESENT	0
461947	457407	08017T	PARTICIPANT	\N	PRESENT	0
461948	457407	14053L	PARTICIPANT	\N	PRESENT	0
461949	457407	19679N	PARTICIPANT	\N	PRESENT	0
461950	457407	14257W	PARTICIPANT	\N	PRESENT	0
461951	457407	19251M	PARTICIPANT	\N	PRESENT	0
461952	457407	08011M	PARTICIPANT	\N	PRESENT	0
461953	457407	14087W	PARTICIPANT	\N	PRESENT	0
461954	457407	19762G	PARTICIPANT	\N	PRESENT	0
461955	457407	14041T	PARTICIPANT	\N	PRESENT	0
461956	458887	19735D	PARTICIPANT	\N	PRESENT	0
461957	458887	14093U	PARTICIPANT	\N	EXCUSE	0
461958	458887	19549D	PARTICIPANT	\N	EXCUSE	0
461959	457407	14205J	PARTICIPANT	\N	PRESENT	0
461960	457407	19333N	PARTICIPANT	\N	PRESENT	0
461961	457407	04044E	PARTICIPANT	\N	PRESENT	0
461962	457407	80013X	PARTICIPANT	\N	PRESENT	0
461963	457407	19681G	PARTICIPANT	\N	PRESENT	0
461964	457407	14038Y	PARTICIPANT	\N	PRESENT	0
461965	457407	19691J	PARTICIPANT	\N	PRESENT	0
461966	457407	14121F	PARTICIPANT	\N	PRESENT	0
461967	457407	14281W	PARTICIPANT	\N	PRESENT	0
461968	457407	19349W	PARTICIPANT	\N	PRESENT	0
461969	457407	19383Y	PARTICIPANT	\N	PRESENT	0
461970	457407	08069G	PARTICIPANT	\N	PRESENT	0
461971	457407	19415P	PARTICIPANT	\N	PRESENT	0
461975	458887	19629C	PARTICIPANT	\N	PRESENT	0
461976	457407	14147R	PARTICIPANT	\N	PRESENT	0
461977	457407	14081Q	PARTICIPANT	\N	PRESENT	0
461978	457407	19820Y	PARTICIPANT	\N	PRESENT	0
461979	457407	08034U	PARTICIPANT	\N	PRESENT	0
461980	457407	05012A	PARTICIPANT	\N	PRESENT	0
461981	457407	19599P	PARTICIPANT	\N	PRESENT	0
461982	457407	19735D	PARTICIPANT	\N	PRESENT	0
461983	457407	14231L	PARTICIPANT	\N	PRESENT	0
461984	457407	14249W	PARTICIPANT	\N	PRESENT	0
461985	457407	14030Q	PARTICIPANT	\N	PRESENT	0
461986	457407	19503N	PARTICIPANT	\N	PRESENT	0
461987	457407	19479G	PARTICIPANT	\N	PRESENT	0
461988	457407	14219Q	PARTICIPANT	\N	PRESENT	0
461989	457407	14179A	PARTICIPANT	\N	PRESENT	0
461990	457407	19768N	PARTICIPANT	\N	PRESENT	0
461991	457407	19741B	PARTICIPANT	\N	PRESENT	0
461992	457407	14135M	PARTICIPANT	\N	PRESENT	0
461993	457407	14034U	PARTICIPANT	\N	PRESENT	0
462059	459251	14021P	PARTICIPANT	\N	PRESENT	0
462060	459251	11045K	PARTICIPANT	\N	PRESENT	0
462061	459251	14081Q	PARTICIPANT	\N	PRESENT	0
462062	459251	14281W	PARTICIPANT	\N	PRESENT	0
462063	459251	08017T	PARTICIPANT	\N	PRESENT	0
462064	459251	19413M	PARTICIPANT	\N	PRESENT	0
462065	459251	11067R	PARTICIPANT	\N	PRESENT	0
462066	459251	19679N	PARTICIPANT	\N	PRESENT	0
462067	459251	08039A	PARTICIPANT	\N	PRESENT	0
462068	459251	19820Y	PARTICIPANT	\N	PRESENT	0
462069	459251	11090Q	PARTICIPANT	\N	PRESENT	0
462070	459251	04092N	PARTICIPANT	\N	PRESENT	0
462071	459251	17779H	PARTICIPANT	\N	PRESENT	0
462072	459251	19565D	PARTICIPANT	\N	PRESENT	0
462073	459251	14071N	PARTICIPANT	\N	PRESENT	0
462074	459251	11031D	PARTICIPANT	\N	PRESENT	0
462075	459251	14193X	PARTICIPANT	\N	PRESENT	0
462076	459251	11097X	PARTICIPANT	\N	PRESENT	0
462077	459251	08024S	PARTICIPANT	\N	PRESENT	0
462078	459251	19782L	PARTICIPANT	\N	PRESENT	0
462079	459251	19747H	PARTICIPANT	\N	PRESENT	0
462080	459251	19697Q	PARTICIPANT	\N	PRESENT	0
462081	459251	11077T	PARTICIPANT	\N	PRESENT	0
462082	459251	14053L	PARTICIPANT	\N	PRESENT	0
462083	459251	01028R	PARTICIPANT	\N	PRESENT	0
462084	459251	19703U	PARTICIPANT	\N	PRESENT	0
462085	459251	19629C	PARTICIPANT	\N	PRESENT	0
462086	459251	14251Q	PARTICIPANT	\N	PRESENT	0
462087	459251	19553Y	PARTICIPANT	\N	PRESENT	0
462088	459251	14207L	PARTICIPANT	\N	PRESENT	0
462089	459251	19333N	PARTICIPANT	\N	PRESENT	0
462090	459251	14197C	PARTICIPANT	\N	PRESENT	0
462091	459251	14187A	PARTICIPANT	\N	PRESENT	0
462092	459251	19441R	PARTICIPANT	\N	PRESENT	0
462093	459251	14219Q	PARTICIPANT	\N	PRESENT	0
462094	459251	14042U	PARTICIPANT	\N	PRESENT	0
462095	459251	19713W	PARTICIPANT	\N	PRESENT	0
462096	459251	19735D	PARTICIPANT	\N	PRESENT	0
462097	459251	19737F	PARTICIPANT	\N	PRESENT	0
462098	459251	14030Q	PARTICIPANT	\N	PRESENT	0
462099	459251	14073Q	PARTICIPANT	\N	PRESENT	0
462100	459251	01024M	PARTICIPANT	\N	PRESENT	0
462101	459251	14231L	PARTICIPANT	\N	PRESENT	0
462102	459251	14327T	PARTICIPANT	\N	PRESENT	0
462103	459251	04070G	PARTICIPANT	\N	PRESENT	0
462104	459251	98029W	PARTICIPANT	\N	PRESENT	0
462105	459251	08061X	PARTICIPANT	\N	PRESENT	0
462106	459251	88008L	PARTICIPANT	\N	PRESENT	0
462107	459251	14034U	PARTICIPANT	\N	PRESENT	0
462108	459251	19421M	PARTICIPANT	\N	PRESENT	0
462109	459251	11099A	PARTICIPANT	\N	PRESENT	0
462110	459251	19503N	PARTICIPANT	\N	PRESENT	0
462111	459251	14135M	PARTICIPANT	\N	PRESENT	0
462112	459251	14265W	PARTICIPANT	\N	PRESENT	0
462113	459251	19731Y	PARTICIPANT	\N	PRESENT	0
462114	459251	99004R	PARTICIPANT	\N	PRESENT	0
462115	459251	14059S	PARTICIPANT	\N	PRESENT	0
462116	459251	08019V	PARTICIPANT	\N	PRESENT	0
462117	459251	19762G	PARTICIPANT	\N	PRESENT	0
462118	459251	19383Y	PARTICIPANT	\N	PRESENT	0
462119	459251	04033B	PARTICIPANT	\N	PRESENT	0
462120	459251	14033T	PARTICIPANT	\N	PRESENT	0
462121	459251	14147R	PARTICIPANT	\N	PRESENT	0
462057	459251	86034E	PARTICIPANT	\N	PRESENT	0
462058	459251	08052W	PARTICIPANT	\N	PRESENT	0
462122	459251	14119M	PARTICIPANT	\N	PRESENT	0
462123	459251	10006L	PARTICIPANT	\N	PRESENT	0
462124	459251	19575F	PARTICIPANT	\N	PRESENT	0
462125	459251	14041T	PARTICIPANT	\N	PRESENT	0
462126	459251	04088S	PARTICIPANT	\N	PRESENT	0
462127	459251	19447X	PARTICIPANT	\N	PRESENT	0
462128	459251	19467C	PARTICIPANT	\N	PRESENT	0
462129	459251	19507S	PARTICIPANT	\N	PRESENT	0
462130	459251	19741B	PARTICIPANT	\N	PRESENT	0
462131	459251	14038Y	PARTICIPANT	\N	PRESENT	0
462144	459251	19269X	PARTICIPANT	\N	PRESENT	0
462133	459251	19758L	PARTICIPANT	\N	PRESENT	0
462134	459251	04085P	PARTICIPANT	\N	PRESENT	0
462135	459251	19760E	PARTICIPANT	\N	PRESENT	0
462136	459251	11056N	PARTICIPANT	\N	PRESENT	0
462137	459251	19621T	PARTICIPANT	\N	PRESENT	0
462138	459251	04018C	PARTICIPANT	\N	PRESENT	0
461920	457407	19812Y	PARTICIPANT	\N	PRESENT	0
461923	457407	19441R	PARTICIPANT	\N	PRESENT	0
462139	459251	19768N	PARTICIPANT	\N	PRESENT	0
462140	459251	11064N	PARTICIPANT	\N	PRESENT	0
462141	459251	14237S	PARTICIPANT	\N	PRESENT	0
462142	459251	14259Y	PARTICIPANT	\N	PRESENT	0
462143	459251	19415P	PARTICIPANT	\N	PRESENT	0
462145	459251	14179A	PARTICIPANT	\N	PRESENT	0
479909	479881	14157T	PARTICIPANT	\N	PRESENT	0
479910	479881	14051J	PARTICIPANT	\N	PRESENT	0
479912	479881	19737F	PARTICIPANT	\N	PRESENT	0
479913	479881	08009T	PRESIDENT	0	PRESENT	0
479914	479881	14031R	PARTICIPANT	\N	PRESENT	0
479915	479881	19503N	PARTICIPANT	\N	PRESENT	0
479917	479881	05012A	PARTICIPANT	\N	PRESENT	0
479918	479881	14169X	PARTICIPANT	\N	PRESENT	0
479919	479072	19697Q	PARTICIPANT	\N	PRESENT	0
479920	479072	11067R	PARTICIPANT	\N	PRESENT	0
479921	479072	01034P	PARTICIPANT	\N	PRESENT	0
479922	479072	19565D	PARTICIPANT	\N	PRESENT	0
479923	479072	19569H	PARTICIPANT	\N	PRESENT	0
479924	479072	11097X	PARTICIPANT	\N	PRESENT	0
479925	479072	08052W	PARTICIPANT	\N	PRESENT	0
479926	479072	19301E	PARTICIPANT	\N	PRESENT	0
479927	479072	19415P	PARTICIPANT	\N	PRESENT	0
479928	479072	19715Y	PARTICIPANT	\N	PRESENT	0
479929	479072	19691J	PARTICIPANT	\N	PRESENT	0
479930	479072	17779H	PARTICIPANT	\N	PRESENT	0
479931	479072	11031D	PARTICIPANT	\N	PRESENT	0
479932	479072	14281W	PARTICIPANT	\N	PRESENT	0
479933	479072	11103C	PARTICIPANT	\N	PRESENT	0
479934	479072	14213J	PARTICIPANT	\N	PRESENT	0
479935	479072	14071N	PARTICIPANT	\N	PRESENT	0
479936	479072	19683J	PARTICIPANT	\N	PRESENT	0
479937	479072	19760E	PARTICIPANT	\N	PRESENT	0
479938	479072	98024R	PARTICIPANT	\N	PRESENT	0
479939	479881	19551W	PARTICIPANT	\N	PRESENT	0
479941	478886	14331P	PARTICIPANT	\N	PRESENT	0
479942	478886	95041E	PARTICIPANT	\N	PRESENT	0
479943	478886	19531S	PARTICIPANT	\N	PRESENT	0
479944	478886	19687N	PARTICIPANT	\N	PRESENT	0
479945	478886	01057W	PARTICIPANT	\N	PRESENT	0
479946	478886	19689Q	PARTICIPANT	\N	PRESENT	0
479947	478886	11074Q	PRESIDENT	0	PRESENT	0
479948	478886	08011M	PARTICIPANT	\N	PRESENT	0
479949	478886	11070L	PARTICIPANT	\N	PRESENT	0
479950	478886	88008L	PARTICIPANT	\N	PRESENT	0
479951	478886	04086Q	PARTICIPANT	\N	PRESENT	0
479952	478886	14083S	PARTICIPANT	\N	PRESENT	0
479953	478886	11012A	PARTICIPANT	\N	PRESENT	0
479954	478886	14085U	PARTICIPANT	\N	PRESENT	0
479955	478886	07004J	PARTICIPANT	\N	PRESENT	0
479956	478886	96004D	PARTICIPANT	\N	PRESENT	0
479957	478886	19349W	PARTICIPANT	\N	PRESENT	0
479958	478886	19741B	PARTICIPANT	\N	PRESENT	0
479959	478886	99004R	PARTICIPANT	\N	PRESENT	0
479960	479880	19725B	PARTICIPANT	\N	PRESENT	0
479961	479880	14041T	PARTICIPANT	\N	PRESENT	0
479962	479880	14147R	PARTICIPANT	\N	PRESENT	0
479963	479880	19253P	PARTICIPANT	\N	PRESENT	0
479964	479880	04044E	PARTICIPANT	\N	PRESENT	0
479965	479880	14231L	PARTICIPANT	\N	PRESENT	0
479966	479880	19489J	PARTICIPANT	\N	PRESENT	0
479967	479880	08045X	PARTICIPANT	\N	PRESENT	0
479968	479880	01028R	PARTICIPANT	\N	PRESENT	0
479969	479880	19762G	PARTICIPANT	\N	PRESENT	0
479970	479072	19798U	PARTICIPANT	\N	PRESENT	0
479971	479072	14223L	PARTICIPANT	\N	PRESENT	0
479972	479072	19703U	PARTICIPANT	\N	PRESENT	0
479973	479072	19679N	PARTICIPANT	\N	PRESENT	0
479974	479072	14042U	PARTICIPANT	\N	PRESENT	0
479975	479072	14195A	PARTICIPANT	\N	PRESENT	0
479976	479072	19367Y	PARTICIPANT	\N	PRESENT	0
479977	479072	14217N	PARTICIPANT	\N	PRESENT	0
479978	479072	10006L	PARTICIPANT	\N	PRESENT	0
479979	479072	19521Q	PARTICIPANT	\N	PRESENT	0
479980	479072	19527W	PARTICIPANT	\N	PRESENT	0
479981	479072	04092N	PRESIDENT	0	PRESENT	0
479982	479072	19663E	PARTICIPANT	\N	PRESENT	0
479983	479072	14119M	PARTICIPANT	\N	PRESENT	0
479984	479072	19657G	PARTICIPANT	\N	PRESENT	0
479985	479072	19577H	PARTICIPANT	\N	PRESENT	0
479986	479880	19673G	PARTICIPANT	\N	PRESENT	0
479987	479880	05008E	PRESIDENT	0	PRESENT	0
479991	479880	01024M	PARTICIPANT	\N	PRESENT	0
479992	479880	95063L	PARTICIPANT	\N	PRESENT	0
479993	479880	14179A	PARTICIPANT	\N	PRESENT	0
479994	479880	14069U	PARTICIPANT	\N	PRESENT	0
479995	479880	11085T	PARTICIPANT	\N	PRESENT	0
479996	479880	14259Y	PARTICIPANT	\N	PRESENT	0
479997	479880	04008A	PARTICIPANT	\N	PRESENT	0
479998	479072	19553Y	PARTICIPANT	\N	PRESENT	0
480001	479880	10015M	PARTICIPANT	\N	PRESENT	0
480004	479880	19543W	PARTICIPANT	\N	PRESENT	0
480014	480013	04070G	PRESIDENT	0	PRESENT	0
480015	480013	19399H	PARTICIPANT	\N	PRESENT	0
480016	480013	04018C	PARTICIPANT	\N	PRESENT	0
480017	480013	08039A	PARTICIPANT	\N	PRESENT	0
480018	480013	14030Q	PARTICIPANT	\N	PRESENT	0
480019	480013	19593H	PARTICIPANT	\N	PRESENT	0
480022	480013	19749K	PARTICIPANT	\N	PRESENT	0
480023	480013	19731Y	PARTICIPANT	\N	PRESENT	0
480024	480013	14229S	PARTICIPANT	\N	PRESENT	0
480025	480013	14241N	PARTICIPANT	\N	PRESENT	0
480026	480013	19693L	PARTICIPANT	\N	PRESENT	0
480027	480013	08043V	PARTICIPANT	\N	PRESENT	0
480028	480013	11083R	PARTICIPANT	\N	PRESENT	0
480029	480013	19699S	PARTICIPANT	\N	PRESENT	0
480030	480013	19643A	PARTICIPANT	\N	PRESENT	0
480031	480013	19766L	PARTICIPANT	\N	PRESENT	0
480032	480013	08031R	PARTICIPANT	\N	PRESENT	0
480033	480013	19611R	PARTICIPANT	\N	PRESENT	0
480034	480013	11043H	PARTICIPANT	\N	PRESENT	0
480035	480013	08035V	PARTICIPANT	\N	PRESENT	0
480036	480013	19533U	PARTICIPANT	\N	PRESENT	0
480037	480013	14107H	PARTICIPANT	\N	PRESENT	0
480038	480013	14073Q	PARTICIPANT	\N	PRESENT	0
480039	480013	19758L	PARTICIPANT	\N	PRESENT	0
480040	480013	14109K	PARTICIPANT	\N	PRESENT	0
480041	480013	19735D	PARTICIPANT	\N	PRESENT	0
480042	480013	14249W	PARTICIPANT	\N	PRESENT	0
480043	480013	08020N	PARTICIPANT	\N	PRESENT	0
480044	480013	11104D	PARTICIPANT	\N	PRESENT	0
480045	480013	04057K	PARTICIPANT	\N	PRESENT	0
480046	480013	08017T	PARTICIPANT	\N	PRESENT	0
480047	480013	19335Q	PARTICIPANT	\N	PRESENT	0
480048	480013	14059S	PARTICIPANT	\N	PRESENT	0
480049	480013	07033P	PARTICIPANT	\N	PRESENT	0
480050	480013	14039A	PARTICIPANT	\N	PRESENT	0
480051	480013	04059M	PARTICIPANT	\N	PRESENT	0
480052	480013	14061L	PARTICIPANT	\N	EXCUSE	0
480496	478253	11040E	PARTICIPANT	\N	PRESENT	0
480497	478253	80013X	PARTICIPANT	\N	PRESENT	0
480498	478253	14038Y	PARTICIPANT	\N	PRESENT	0
480504	478253	11070L	PARTICIPANT	\N	PRESENT	0
480624	479094	14257W	PARTICIPANT	\N	EXCUSE	0
480501	478253	19399H	PARTICIPANT	\N	PRESENT	0
480502	478253	19551W	PARTICIPANT	\N	PRESENT	0
480503	478253	14121F	PRESIDENT	0	PRESENT	0
480505	478253	19737F	PARTICIPANT	\N	PRESENT	0
480616	478253	02002K	PARTICIPANT	\N	PRESENT	0
480623	479094	14281W	PARTICIPANT	\N	EXCUSE	0
480687	479094	19687N	PARTICIPANT	\N	EXCUSE	0
480688	479092	04044E	PARTICIPANT	\N	PRESENT	0
480689	479092	17637T	PARTICIPANT	\N	PRESENT	0
480690	479092	19533U	PARTICIPANT	\N	PRESENT	0
480691	479092	19687N	PARTICIPANT	\N	PRESENT	0
480692	479092	19565D	PARTICIPANT	\N	PRESENT	0
480693	479092	19399H	PARTICIPANT	\N	PRESENT	0
480694	479092	14065Q	PARTICIPANT	\N	PRESENT	0
480695	479092	19551W	PARTICIPANT	\N	PRESENT	0
480696	479092	14001X	PARTICIPANT	\N	PRESENT	0
480697	479092	01028R	PARTICIPANT	\N	PRESENT	0
480698	479092	19413M	PARTICIPANT	\N	PRESENT	0
480699	479092	19333N	PARTICIPANT	\N	PRESENT	0
480700	479092	14231L	PARTICIPANT	\N	PRESENT	0
480701	479092	19489J	PARTICIPANT	\N	PRESENT	0
480702	479092	19715Y	PARTICIPANT	\N	PRESENT	0
480703	479092	11074Q	PARTICIPANT	\N	PRESENT	0
480704	479092	19349W	PARTICIPANT	\N	PRESENT	0
480705	479092	14021P	PARTICIPANT	\N	PRESENT	0
480706	479092	19631V	PARTICIPANT	\N	PRESENT	0
480707	479092	14151M	PARTICIPANT	\N	PRESENT	0
480708	479092	14195A	PARTICIPANT	\N	PRESENT	0
480709	479092	11012A	PARTICIPANT	\N	PRESENT	0
480710	479092	04040A	PARTICIPANT	\N	PRESENT	0
480711	479092	14281W	PARTICIPANT	\N	PRESENT	0
480712	479092	11067R	PARTICIPANT	\N	PRESENT	0
480713	479092	14069U	PARTICIPANT	\N	PRESENT	0
480714	479092	19301E	PARTICIPANT	\N	PRESENT	0
480715	479092	14229S	PARTICIPANT	\N	PRESENT	0
480716	479092	14081Q	PARTICIPANT	\N	PRESENT	0
480717	479092	19820Y	PARTICIPANT	\N	PRESENT	0
480718	479092	19553Y	PARTICIPANT	\N	PRESENT	0
480719	479092	18083K	PARTICIPANT	\N	PRESENT	0
480721	479092	08052W	PARTICIPANT	\N	PRESENT	0
480722	479092	19599P	PARTICIPANT	\N	PRESENT	0
457564	456200	19399H	PARTICIPANT	\N	EXCUSE	0
459602	459601	14030Q	PARTICIPANT	\N	PRESENT	0
459603	459601	11031D	PARTICIPANT	\N	PRESENT	0
459604	459601	19693L	PARTICIPANT	\N	PRESENT	0
459605	459601	11067R	PARTICIPANT	\N	PRESENT	0
459667	458796	17779H	PARTICIPANT	\N	EXCUSE	0
460050	460048	14237S	PARTICIPANT	\N	PRESENT	0
460477	448772	08061X	PARTICIPANT	\N	PRESENT	0
460478	448772	19447X	PARTICIPANT	\N	PRESENT	0
460479	448772	14026U	PARTICIPANT	\N	PRESENT	0
460480	448772	19651A	PARTICIPANT	\N	PRESENT	0
460481	448772	19679N	PARTICIPANT	\N	PRESENT	0
460482	448772	11090Q	PARTICIPANT	\N	PRESENT	0
460483	448772	19489J	PARTICIPANT	\N	PRESENT	0
460484	448772	10006L	PARTICIPANT	\N	PRESENT	0
460485	448772	95041E	PARTICIPANT	\N	PRESENT	0
460486	448772	19415P	PARTICIPANT	\N	PRESENT	0
460487	448772	11097X	PARTICIPANT	\N	PRESENT	0
460488	448772	19575F	PARTICIPANT	\N	PRESENT	0
460489	448772	08015R	PARTICIPANT	\N	PRESENT	0
460490	448772	95067Q	PARTICIPANT	\N	PRESENT	0
460491	448772	14215L	PARTICIPANT	\N	PRESENT	0
460492	448772	14135M	PARTICIPANT	\N	PRESENT	0
460493	448772	04088S	PARTICIPANT	\N	PRESENT	0
460494	448772	14033T	PARTICIPANT	\N	PRESENT	0
460495	448772	04049K	PARTICIPANT	\N	PRESENT	0
460496	448772	14205J	PARTICIPANT	\N	PRESENT	0
460497	448772	11099A	PARTICIPANT	\N	PRESENT	0
460498	448772	19573D	PARTICIPANT	\N	PRESENT	0
460499	448772	14231L	PARTICIPANT	\N	PRESENT	0
460500	448772	19675J	PARTICIPANT	\N	PRESENT	0
460501	448772	14213J	PARTICIPANT	\N	PRESENT	0
460475	448772	14059S	PARTICIPANT	\N	PRESENT	0
460476	448772	19782L	PARTICIPANT	\N	PRESENT	0
460502	448772	19551W	PARTICIPANT	\N	PRESENT	0
460503	448772	04070G	PARTICIPANT	\N	PRESENT	0
460504	448772	14217N	PARTICIPANT	\N	PRESENT	0
460505	448772	19383Y	PARTICIPANT	\N	PRESENT	0
460506	448772	19521Q	PARTICIPANT	\N	PRESENT	0
460507	448772	19507S	PARTICIPANT	\N	PRESENT	0
460508	448772	18083K	PARTICIPANT	\N	PRESENT	0
460509	448772	11072N	PARTICIPANT	\N	PRESENT	0
460973	460972	14157T	PARTICIPANT	\N	PRESENT	0
460974	460972	19599P	PARTICIPANT	\N	PRESENT	0
460975	460972	14051J	PARTICIPANT	\N	PRESENT	0
460976	460972	19637C	PARTICIPANT	\N	PRESENT	0
460979	460977	14157T	PARTICIPANT	\N	PRESENT	0
460980	460977	14031R	PARTICIPANT	\N	PRESENT	0
460981	460977	14083S	PARTICIPANT	\N	PRESENT	0
462516	462515	19599P	PARTICIPANT	\N	PRESENT	0
462517	462515	14038Y	PARTICIPANT	\N	PRESENT	0
462518	462515	19333N	PARTICIPANT	\N	PRESENT	0
462519	462515	18083K	PARTICIPANT	\N	PRESENT	0
462520	462515	19713W	PARTICIPANT	\N	PRESENT	0
462528	462527	99004R	PARTICIPANT	\N	PRESENT	0
462553	462552	19667J	PARTICIPANT	\N	PRESENT	0
462554	462552	11040E	PARTICIPANT	\N	PRESENT	0
462556	462555	11070L	PARTICIPANT	\N	PRESENT	0
462557	462555	14121F	PARTICIPANT	\N	PRESENT	0
462558	462555	19525U	PARTICIPANT	\N	PRESENT	0
462559	462555	14169X	PARTICIPANT	\N	PRESENT	0
462561	462560	11070L	PARTICIPANT	\N	PRESENT	0
462562	462560	14121F	PARTICIPANT	\N	PRESENT	0
462563	462560	19525U	PARTICIPANT	\N	PRESENT	0
462564	462560	19551W	PARTICIPANT	\N	PRESENT	0
462566	462565	11070L	PARTICIPANT	\N	PRESENT	0
462567	462565	19711U	PARTICIPANT	\N	PRESENT	0
464484	464313	19725B	PARTICIPANT	\N	PRESENT	0
464485	464313	08045X	PARTICIPANT	\N	PRESENT	0
464486	464313	11026G	PARTICIPANT	\N	PRESENT	0
464487	464313	14147R	PARTICIPANT	\N	PRESENT	0
464488	464313	14215L	PARTICIPANT	\N	PRESENT	0
464489	464313	11033F	PARTICIPANT	\N	PRESENT	0
464490	464313	01028R	PARTICIPANT	\N	PRESENT	0
464491	464313	19762G	PARTICIPANT	\N	PRESENT	0
464493	464313	14001X	PARTICIPANT	\N	PRESENT	0
464494	464313	04044E	PARTICIPANT	\N	PRESENT	0
464495	464313	19585H	PARTICIPANT	\N	PRESENT	0
464496	464313	19673G	PARTICIPANT	\N	PRESENT	0
464497	464313	19675J	PARTICIPANT	\N	PRESENT	0
464498	464313	19447X	PARTICIPANT	\N	PRESENT	0
464499	464313	05008E	PRESIDENT	0	PRESENT	0
464500	464313	14041T	PARTICIPANT	\N	PRESENT	0
464501	464313	14179A	PARTICIPANT	\N	PRESENT	0
464502	464313	14151M	PARTICIPANT	\N	PRESENT	0
464503	464313	11072N	PARTICIPANT	\N	PRESENT	0
464504	464313	14053L	PARTICIPANT	\N	PRESENT	0
464505	464313	14065Q	PARTICIPANT	\N	PRESENT	0
464506	464313	19649G	PARTICIPANT	\N	PRESENT	0
464507	464313	10015M	PARTICIPANT	\N	PRESENT	0
464508	464313	01024M	PARTICIPANT	\N	PRESENT	0
464509	464313	04038G	PARTICIPANT	\N	PRESENT	0
464510	464313	95063L	PARTICIPANT	\N	PRESENT	0
464511	464313	04008A	PARTICIPANT	\N	PRESENT	0
464512	464313	14021P	PARTICIPANT	\N	PRESENT	0
464516	464313	19489J	PARTICIPANT	\N	PRESENT	0
464517	464313	19629C	PARTICIPANT	\N	PRESENT	0
464518	464313	08044W	PARTICIPANT	\N	PRESENT	0
464519	464313	14111D	PARTICIPANT	\N	PRESENT	0
464520	464313	14231L	PARTICIPANT	\N	PRESENT	0
464521	464313	14069U	PARTICIPANT	\N	PRESENT	0
464522	464313	19253P	PARTICIPANT	\N	PRESENT	0
464523	464312	14001X	PARTICIPANT	\N	PRESENT	0
464524	464312	04044E	PARTICIPANT	\N	PRESENT	0
464525	464312	19585H	PARTICIPANT	\N	PRESENT	0
464526	464312	19673G	PARTICIPANT	\N	PRESENT	0
464527	464312	01028R	PARTICIPANT	\N	PRESENT	0
464528	464312	19675J	PARTICIPANT	\N	PRESENT	0
464529	464312	19447X	PARTICIPANT	\N	PRESENT	0
464530	464312	05008E	PRESIDENT	0	PRESENT	0
464531	464312	14231L	PARTICIPANT	\N	PRESENT	0
464532	464312	19489J	PARTICIPANT	\N	PRESENT	0
464533	464312	14041T	PARTICIPANT	\N	PRESENT	0
464534	464312	14147R	PARTICIPANT	\N	PRESENT	0
464535	464312	14179A	PARTICIPANT	\N	PRESENT	0
464536	464312	14151M	PARTICIPANT	\N	PRESENT	0
464537	464312	14215L	PARTICIPANT	\N	PRESENT	0
464538	464312	11072N	PARTICIPANT	\N	PRESENT	0
464539	464312	14053L	PARTICIPANT	\N	PRESENT	0
464540	464312	14065Q	PARTICIPANT	\N	PRESENT	0
464541	464312	19649G	PARTICIPANT	\N	PRESENT	0
464542	464312	14111D	PARTICIPANT	\N	PRESENT	0
464543	464312	08045X	PARTICIPANT	\N	PRESENT	0
464544	464312	11026G	PARTICIPANT	\N	PRESENT	0
464545	464312	19253P	PARTICIPANT	\N	PRESENT	0
464546	464312	01024M	PARTICIPANT	\N	PRESENT	0
464547	464312	04038G	PARTICIPANT	\N	PRESENT	0
464548	464312	11033F	PARTICIPANT	\N	PRESENT	0
464549	464312	19725B	PARTICIPANT	\N	PRESENT	0
464550	464312	95063L	PARTICIPANT	\N	PRESENT	0
464551	464312	19629C	PARTICIPANT	\N	PRESENT	0
464552	464312	08044W	PARTICIPANT	\N	PRESENT	0
464553	464312	14069U	PARTICIPANT	\N	PRESENT	0
464554	464312	04008A	PARTICIPANT	\N	PRESENT	0
464555	464312	19762G	PARTICIPANT	\N	PRESENT	0
464556	464312	14021P	PARTICIPANT	\N	PRESENT	0
464557	464312	10015M	PARTICIPANT	\N	PRESENT	0
464621	463731	86034E	PARTICIPANT	\N	PRESENT	0
464623	463731	19719D	PARTICIPANT	\N	PRESENT	0
464624	463731	14251Q	PARTICIPANT	\N	PRESENT	0
464625	463731	04033B	PARTICIPANT	\N	PRESENT	0
464626	463731	19697Q	PARTICIPANT	\N	PRESENT	0
464627	463731	19585H	PARTICIPANT	\N	PRESENT	0
464628	463731	07033P	PARTICIPANT	\N	PRESENT	0
464629	463731	19543W	PARTICIPANT	\N	PRESENT	0
464630	463731	04047H	PARTICIPANT	\N	PRESENT	0
464631	463731	08061X	PARTICIPANT	\N	PRESENT	0
464632	463731	11085T	PARTICIPANT	\N	PRESENT	0
464633	463731	19689Q	PARTICIPANT	\N	PRESENT	0
464634	463731	19599P	PARTICIPANT	\N	PRESENT	0
464635	463731	14021P	PARTICIPANT	\N	PRESENT	0
464636	463731	19758L	PARTICIPANT	\N	PRESENT	0
464637	463731	04085P	PARTICIPANT	\N	PRESENT	0
464638	463731	14179A	PARTICIPANT	\N	PRESENT	0
464639	463731	19611R	PARTICIPANT	\N	PRESENT	0
464640	463731	14071N	PARTICIPANT	\N	PRESENT	0
464642	463731	19591F	PARTICIPANT	\N	PRESENT	0
464645	463731	89017R	PARTICIPANT	\N	PRESENT	0
464646	463731	11012A	PARTICIPANT	\N	PRESENT	0
464647	463731	95063L	PARTICIPANT	\N	PRESENT	0
464814	464342	19467C	PARTICIPANT	\N	PRESENT	0
464815	464342	11077T	PARTICIPANT	\N	PRESENT	0
464816	464342	01043Q	PARTICIPANT	\N	PRESENT	0
464817	464342	14187A	PARTICIPANT	\N	PRESENT	0
464818	464342	08038Y	PARTICIPANT	\N	PRESENT	0
464819	464342	14081Q	PARTICIPANT	\N	PRESENT	0
464820	464342	19695N	PARTICIPANT	\N	PRESENT	0
464821	464342	11090Q	PRESIDENT	0	PRESENT	0
464822	464342	01025N	PARTICIPANT	\N	PRESENT	0
481572	480797	14059S	PARTICIPANT	\N	PRESENT	0
481573	480797	19525U	PARTICIPANT	\N	PRESENT	0
481576	481575	14135M	PARTICIPANT	\N	EXCUSE	0
481578	481577	11053K	PARTICIPANT	\N	PRESENT	0
481579	481577	14159V	PARTICIPANT	\N	PRESENT	0
481580	481577	05012A	PARTICIPANT	\N	PRESENT	0
481582	481581	11053K	PARTICIPANT	\N	PRESENT	0
481583	481581	14159V	PARTICIPANT	\N	PRESENT	0
481584	481581	05012A	PARTICIPANT	\N	PRESENT	0
481586	481585	11053K	PARTICIPANT	\N	PRESENT	0
481587	481585	14159V	PARTICIPANT	\N	PRESENT	0
481588	481585	05012A	PARTICIPANT	\N	PRESENT	0
481607	481575	14331P	PARTICIPANT	\N	EXCUSE	0
481612	481611	08012N	PARTICIPANT	\N	PRESENT	0
481613	481611	02002K	PARTICIPANT	\N	PRESENT	0
481614	481611	11043H	PARTICIPANT	\N	PRESENT	0
481615	481611	19711U	PARTICIPANT	\N	PRESENT	0
481616	481611	19533U	PARTICIPANT	\N	PRESENT	0
481617	481611	14147R	PARTICIPANT	\N	PRESENT	0
481619	481618	02002K	PARTICIPANT	\N	PRESENT	0
481620	481618	08012N	PARTICIPANT	\N	PRESENT	0
481621	481618	11043H	PARTICIPANT	\N	PRESENT	0
481622	481618	19533U	PARTICIPANT	\N	PRESENT	0
481623	481618	19711U	PARTICIPANT	\N	PRESENT	0
481624	481618	14147R	PARTICIPANT	\N	PRESENT	0
481625	481618	19399H	PARTICIPANT	\N	PRESENT	0
481639	480977	19531S	PARTICIPANT	\N	PRESENT	0
481651	478951	08055A	PARTICIPANT	\N	PRESENT	0
481656	478951	14093U	PARTICIPANT	\N	PRESENT	0
481657	478951	08024S	PARTICIPANT	\N	PRESENT	0
481659	478951	18083K	PARTICIPANT	\N	PRESENT	0
481660	478951	19701S	PARTICIPANT	\N	PRESENT	0
481661	478951	11065P	PARTICIPANT	\N	PRESENT	0
481663	478951	15447F	PARTICIPANT	\N	PRESENT	0
481665	478951	19333N	PARTICIPANT	\N	PRESENT	0
481666	478951	14031R	PARTICIPANT	\N	PRESENT	0
481667	478951	19637C	PARTICIPANT	\N	PRESENT	0
481668	478951	08009T	PARTICIPANT	\N	PRESENT	0
481672	478951	19503N	PARTICIPANT	\N	PRESENT	0
481673	478951	19794Q	PARTICIPANT	\N	PRESENT	0
481674	478951	19713W	PARTICIPANT	\N	PRESENT	0
481675	478951	14157T	PARTICIPANT	\N	PRESENT	0
481676	478951	19737F	PARTICIPANT	\N	PRESENT	0
481677	478951	14221J	PARTICIPANT	\N	PRESENT	0
481678	481129	08018U	PARTICIPANT	\N	EXCUSE	0
481712	481711	14026U	PARTICIPANT	\N	PRESENT	0
481713	481711	19725B	PARTICIPANT	\N	PRESENT	0
481944	481943	14133K	PARTICIPANT	\N	PRESENT	0
481945	481943	08058D	PARTICIPANT	\N	PRESENT	0
481947	481946	14133K	PARTICIPANT	\N	PRESENT	0
481948	481946	08058D	PARTICIPANT	\N	PRESENT	0
482070	482069	96004D	PARTICIPANT	\N	PRESENT	0
482071	482069	98035U	PARTICIPANT	\N	PRESENT	0
482072	482069	11083R	PARTICIPANT	\N	PRESENT	0
482073	482069	14033T	PARTICIPANT	\N	PRESENT	0
482074	482069	19553Y	PARTICIPANT	\N	PRESENT	0
482167	481626	14051J	PARTICIPANT	\N	PRESENT	0
482168	481626	19794Q	PARTICIPANT	\N	PRESENT	0
482169	481626	14157T	PARTICIPANT	\N	PRESENT	0
482170	481626	19599P	PARTICIPANT	\N	PRESENT	0
482174	481557	19930E	PARTICIPANT	\N	PRESENT	0
482175	481557	19489J	PARTICIPANT	\N	PRESENT	0
482176	481557	19629C	PARTICIPANT	\N	PRESENT	0
482177	481557	11026G	PARTICIPANT	\N	PRESENT	0
482178	481557	14147R	PARTICIPANT	\N	PRESENT	0
482179	481557	14215L	PARTICIPANT	\N	PRESENT	0
482180	481557	19673G	PARTICIPANT	\N	PRESENT	0
482181	481557	01028R	PARTICIPANT	\N	PRESENT	0
482182	481557	05008E	PRESIDENT	0	PRESENT	0
482183	481557	19447X	PARTICIPANT	\N	PRESENT	0
482194	481626	18083K	PARTICIPANT	\N	PRESENT	0
482195	481626	19347U	PARTICIPANT	\N	PRESENT	0
482196	481626	04097T	PARTICIPANT	\N	PRESENT	0
482197	481626	17583W	PARTICIPANT	\N	PRESENT	0
482198	481626	04069P	PARTICIPANT	\N	PRESENT	0
482199	481626	19387D	PARTICIPANT	\N	PRESENT	0
482200	481626	19745F	PARTICIPANT	\N	PRESENT	0
482201	481557	19729F	PARTICIPANT	\N	PRESENT	0
482202	481557	95063L	PARTICIPANT	\N	PRESENT	0
482203	481557	14259Y	PARTICIPANT	\N	PRESENT	0
482204	481557	14001X	PARTICIPANT	\N	PRESENT	0
482205	481626	19737F	PARTICIPANT	\N	PRESENT	0
482206	481626	14029X	PARTICIPANT	\N	PRESENT	0
482207	481557	08045X	PARTICIPANT	\N	PRESENT	0
482208	481626	14219Q	PARTICIPANT	\N	PRESENT	0
482209	481557	08018U	PARTICIPANT	\N	PRESENT	0
482210	481626	17637T	PARTICIPANT	\N	PRESENT	0
482211	481626	19713W	PARTICIPANT	\N	PRESENT	0
482212	481626	19383Y	PARTICIPANT	\N	PRESENT	0
482213	481557	01024M	PARTICIPANT	\N	PRESENT	0
482214	481557	14151M	PARTICIPANT	\N	PRESENT	0
482215	481626	02002K	PARTICIPANT	\N	PRESENT	0
482217	481626	19701S	PARTICIPANT	\N	PRESENT	0
482270	482268	19503N	PARTICIPANT	\N	PRESENT	0
482300	482296	19503N	PARTICIPANT	\N	PRESENT	0
482322	481507	19415P	PARTICIPANT	\N	PRESENT	0
482323	481507	19723Y	PARTICIPANT	\N	PRESENT	0
482324	481507	11067R	PARTICIPANT	\N	PRESENT	0
482325	481507	04092N	PRESIDENT	0	PRESENT	0
482326	481507	14119M	PARTICIPANT	\N	PRESENT	0
482327	481507	11097X	PARTICIPANT	\N	PRESENT	0
482328	481507	19703U	PARTICIPANT	\N	PRESENT	0
482329	481507	19301E	PARTICIPANT	\N	PRESENT	0
482349	481067	14331P	PARTICIPANT	\N	PRESENT	0
482350	481067	11048N	PARTICIPANT	\N	PRESENT	0
482351	481067	19711U	PARTICIPANT	\N	PRESENT	0
482352	481067	19531S	PARTICIPANT	\N	PRESENT	0
482353	481067	19545Y	PARTICIPANT	\N	PRESENT	0
482354	481067	01057W	PARTICIPANT	\N	PRESENT	0
482355	481067	19687N	PARTICIPANT	\N	PRESENT	0
482356	481067	19689Q	PARTICIPANT	\N	PRESENT	0
482357	481067	11053K	PARTICIPANT	\N	PRESENT	0
482358	481067	08011M	PARTICIPANT	\N	PRESENT	0
482359	481067	11074Q	PRESIDENT	0	PRESENT	0
482360	481067	19667J	PARTICIPANT	\N	PRESENT	0
482361	481067	89017R	PARTICIPANT	\N	PRESENT	0
482362	481067	14034U	PARTICIPANT	\N	PRESENT	0
482363	481067	11070L	PARTICIPANT	\N	PRESENT	0
482364	481067	88008L	PARTICIPANT	\N	PRESENT	0
482365	481067	04086Q	PARTICIPANT	\N	PRESENT	0
482366	481067	14083S	PARTICIPANT	\N	PRESENT	0
482367	481067	19349W	PARTICIPANT	\N	PRESENT	0
482368	481067	19741B	PARTICIPANT	\N	PRESENT	0
482369	481067	08010L	PARTICIPANT	\N	PRESENT	0
482370	481067	14253S	PARTICIPANT	\N	PRESENT	0
482371	481067	99004R	PARTICIPANT	\N	PRESENT	0
482372	481067	19762G	PARTICIPANT	\N	PRESENT	0
482374	482053	04070G	PRESIDENT	0	PRESENT	0
482375	482053	19699S	PARTICIPANT	\N	PRESENT	0
482376	482053	19533U	PARTICIPANT	\N	PRESENT	0
482377	482053	14229S	PARTICIPANT	\N	PRESENT	0
482378	482053	19335Q	PARTICIPANT	\N	PRESENT	0
482379	482053	14249W	PARTICIPANT	\N	PRESENT	0
482380	482053	08039A	PARTICIPANT	\N	PRESENT	0
482381	482053	08031R	PARTICIPANT	\N	PRESENT	0
482382	482053	19593H	PARTICIPANT	\N	PRESENT	0
482383	482053	14059S	PARTICIPANT	\N	PRESENT	0
482384	482053	04057K	PARTICIPANT	\N	PRESENT	0
482385	482053	14073Q	PARTICIPANT	\N	PRESENT	0
482386	482053	19611R	PARTICIPANT	\N	PRESENT	0
482387	482053	08043V	PARTICIPANT	\N	PRESENT	0
482388	482053	87003B	PARTICIPANT	\N	PRESENT	0
482389	482053	19399H	PARTICIPANT	\N	PRESENT	0
482390	482053	14030Q	PARTICIPANT	\N	PRESENT	0
482391	482053	19731Y	PARTICIPANT	\N	PRESENT	0
482392	482053	08020N	PARTICIPANT	\N	PRESENT	0
482393	482053	14251Q	PARTICIPANT	\N	PRESENT	0
482394	482053	04059M	PARTICIPANT	\N	PRESENT	0
482395	482053	19735D	PARTICIPANT	\N	PRESENT	0
482396	482053	11083R	PARTICIPANT	\N	PRESENT	0
482397	482053	14109K	PARTICIPANT	\N	PRESENT	0
482398	482053	14063N	PARTICIPANT	\N	PRESENT	0
482399	482053	11043H	PARTICIPANT	\N	PRESENT	0
482400	482053	04018C	PARTICIPANT	\N	PRESENT	0
482401	482053	19758L	PARTICIPANT	\N	PRESENT	0
482402	482053	19621T	PARTICIPANT	\N	PRESENT	0
482403	482053	19643A	PARTICIPANT	\N	EXCUSE	0
482404	482053	14061L	PARTICIPANT	\N	EXCUSE	0
482405	482053	19749K	PARTICIPANT	\N	EXCUSE	0
482406	481507	14281W	PARTICIPANT	\N	PRESENT	0
482407	481067	14085U	PARTICIPANT	\N	PRESENT	0
482408	481507	19553Y	PARTICIPANT	\N	PRESENT	0
482409	481507	19527W	PARTICIPANT	\N	PRESENT	0
482410	481507	19591F	PARTICIPANT	\N	PRESENT	0
482411	481507	14213J	PARTICIPANT	\N	PRESENT	0
482412	481507	17779H	PARTICIPANT	\N	PRESENT	0
482413	481507	19657G	PARTICIPANT	\N	PRESENT	0
458559	458323	19413M	PARTICIPANT	\N	PRESENT	0
458680	458679	14187A	PARTICIPANT	\N	PRESENT	0
458681	458679	01043Q	PARTICIPANT	\N	PRESENT	0
458683	458682	14187A	PARTICIPANT	\N	PRESENT	0
458685	458684	14187A	PARTICIPANT	\N	PRESENT	0
458686	458684	01043Q	PARTICIPANT	\N	PRESENT	0
458688	458687	14187A	PARTICIPANT	\N	PRESENT	0
458689	458687	01043Q	PARTICIPANT	\N	PRESENT	0
458696	458695	14038Y	PARTICIPANT	\N	PRESENT	0
458697	458695	18083K	PARTICIPANT	\N	PRESENT	0
458698	458695	19333N	PARTICIPANT	\N	PRESENT	0
458699	458695	19347U	PARTICIPANT	\N	PRESENT	0
458700	458695	19794Q	PARTICIPANT	\N	PRESENT	0
458702	458701	14038Y	PARTICIPANT	\N	PRESENT	0
458703	458701	18083K	PARTICIPANT	\N	PRESENT	0
458704	458701	19333N	PARTICIPANT	\N	PRESENT	0
458705	458701	19347U	PARTICIPANT	\N	PRESENT	0
458706	458701	19794Q	PARTICIPANT	\N	PRESENT	0
458707	458701	19713W	PARTICIPANT	\N	PRESENT	0
458709	458708	14038Y	PARTICIPANT	\N	PRESENT	0
458710	458708	18083K	PARTICIPANT	\N	PRESENT	0
458711	458708	19333N	PARTICIPANT	\N	PRESENT	0
458712	458708	19347U	PARTICIPANT	\N	PRESENT	0
458713	458708	19794Q	PARTICIPANT	\N	PRESENT	0
458714	458708	19713W	PARTICIPANT	\N	PRESENT	0
458715	451323	14030Q	PRESIDENT	0	PRESENT	0
458716	451323	08043V	PARTICIPANT	\N	PRESENT	0
458717	451323	19367Y	PARTICIPANT	\N	EXCUSE	0
458718	451323	19701S	PARTICIPANT	\N	PRESENT	0
458719	451323	11031D	PARTICIPANT	\N	PRESENT	0
458720	451323	80013X	PARTICIPANT	\N	PRESENT	0
458721	451323	19693L	PARTICIPANT	\N	PRESENT	0
458722	451323	19715Y	PARTICIPANT	\N	PRESENT	0
458723	451323	19731Y	PARTICIPANT	\N	PRESENT	0
458724	451323	08017T	PARTICIPANT	\N	PRESENT	0
458725	451323	11067R	PARTICIPANT	\N	PRESENT	0
458726	451323	19749K	PARTICIPANT	\N	PRESENT	0
458728	458727	11097X	PARTICIPANT	\N	PRESENT	0
458730	458729	19651A	PARTICIPANT	\N	PRESENT	0
458731	458729	19667J	PARTICIPANT	\N	PRESENT	0
458735	458729	11074Q	PARTICIPANT	\N	PRESENT	0
458733	458729	04086Q	PARTICIPANT	\N	PRESENT	0
458734	458729	04071H	PARTICIPANT	\N	PRESENT	0
458736	458729	19647E	PARTICIPANT	\N	PRESENT	0
458737	458729	99004R	PARTICIPANT	\N	PRESENT	0
458738	458729	19711U	PARTICIPANT	\N	PRESENT	0
458739	458729	19671E	PARTICIPANT	\N	PRESENT	0
458740	458729	19687N	PARTICIPANT	\N	PRESENT	0
458741	456728	80013X	PARTICIPANT	\N	PRESENT	0
458742	456728	19525U	PARTICIPANT	\N	PRESENT	0
458743	456728	11070L	PARTICIPANT	\N	PRESENT	0
458744	456728	14121F	PARTICIPANT	\N	PRESENT	0
458745	456728	19711U	PARTICIPANT	\N	PRESENT	0
458746	456728	19737F	PARTICIPANT	\N	PRESENT	0
458765	458763	19599P	PARTICIPANT	\N	PRESENT	0
458766	458763	14157T	PARTICIPANT	\N	PRESENT	0
458768	458763	14031R	PARTICIPANT	\N	PRESENT	0
458769	458763	19820Y	PARTICIPANT	\N	PRESENT	0
458776	458773	19599P	PARTICIPANT	\N	PRESENT	0
458778	458773	14157T	PARTICIPANT	\N	PRESENT	0
458881	454195	14259Y	PARTICIPANT	\N	EXCUSE	0
458882	454195	19301E	PARTICIPANT	\N	PRESENT	0
458883	454195	11054L	PARTICIPANT	\N	PRESENT	0
458884	454195	08019V	PRESIDENT	0	PRESENT	0
458885	454195	12016W	PARTICIPANT	\N	PRESENT	0
458886	454195	11010L	PARTICIPANT	\N	EXCUSE	0
458966	458965	08055A	PARTICIPANT	\N	PRESENT	0
458967	458965	04047H	PARTICIPANT	\N	PRESENT	0
458968	458965	19545Y	PARTICIPANT	\N	EXCUSE	0
458969	458965	14085U	PARTICIPANT	\N	PRESENT	0
458970	458965	11080N	PARTICIPANT	\N	EXCUSE	0
458971	458965	11083R	PARTICIPANT	\N	EXCUSE	0
458972	458965	01057W	PARTICIPANT	\N	PRESENT	0
458973	458965	19611R	PARTICIPANT	\N	EXCUSE	0
458974	458965	19687N	PARTICIPANT	\N	PRESENT	0
458975	458965	08049C	PARTICIPANT	\N	EXCUSE	0
458976	458965	14157T	PARTICIPANT	\N	EXCUSE	0
458984	458983	11053K	PARTICIPANT	\N	PRESENT	0
458985	458983	14159V	PARTICIPANT	\N	PRESENT	0
458986	458983	05012A	PARTICIPANT	\N	PRESENT	0
458988	458987	11053K	PARTICIPANT	\N	PRESENT	0
458989	458987	14159V	PARTICIPANT	\N	PRESENT	0
458990	458987	05012A	PARTICIPANT	\N	PRESENT	0
458992	458991	11053K	PARTICIPANT	\N	PRESENT	0
458993	458991	14159V	PARTICIPANT	\N	PRESENT	0
458994	458991	05012A	PARTICIPANT	\N	PRESENT	0
458996	458995	11053K	PARTICIPANT	\N	PRESENT	0
458997	458995	14159V	PARTICIPANT	\N	PRESENT	0
458998	458995	05012A	PARTICIPANT	\N	PRESENT	0
459000	458999	11053K	PARTICIPANT	\N	PRESENT	0
459001	458999	14159V	PARTICIPANT	\N	PRESENT	0
459002	458999	05012A	PARTICIPANT	\N	PRESENT	0
459004	459003	11053K	PARTICIPANT	\N	PRESENT	0
459005	459003	14159V	PARTICIPANT	\N	PRESENT	0
459006	459003	05012A	PARTICIPANT	\N	PRESENT	0
459008	459007	11053K	PARTICIPANT	\N	PRESENT	0
459009	459007	14159V	PARTICIPANT	\N	PRESENT	0
459010	459007	05012A	PARTICIPANT	\N	PRESENT	0
459128	459127	19647E	PARTICIPANT	\N	PRESENT	0
459132	459131	19741B	PARTICIPANT	\N	PRESENT	0
459130	459129	89017R	PARTICIPANT	\N	PRESENT	0
459134	459133	19741B	PARTICIPANT	\N	PRESENT	0
459136	459135	19741B	PARTICIPANT	\N	PRESENT	0
459138	459137	11074Q	PARTICIPANT	\N	PRESENT	0
459139	459137	08011M	PARTICIPANT	\N	PRESENT	0
459140	459137	04071H	PARTICIPANT	\N	PRESENT	0
459141	459137	11040E	PARTICIPANT	\N	PRESENT	0
459142	459137	19545Y	PARTICIPANT	\N	PRESENT	0
459143	459137	19479G	PARTICIPANT	\N	PRESENT	0
459144	459137	07004J	PARTICIPANT	\N	PRESENT	0
459145	459137	19689Q	PARTICIPANT	\N	PRESENT	0
459147	459146	07004J	PARTICIPANT	\N	PRESENT	0
459148	459146	12016W	PARTICIPANT	\N	PRESENT	0
459171	459170	14199E	PARTICIPANT	\N	PRESENT	0
459173	459172	11048N	PARTICIPANT	\N	PRESENT	0
459175	459174	14121F	PARTICIPANT	\N	PRESENT	0
459177	459176	11074Q	PARTICIPANT	\N	PRESENT	0
459178	459176	08011M	PARTICIPANT	\N	PRESENT	0
460982	458748	19583F	PARTICIPANT	\N	EXCUSE	0
460983	458748	08047A	PARTICIPANT	\N	EXCUSE	0
460984	458748	19421M	PARTICIPANT	\N	EXCUSE	0
463428	462909	86034E	PARTICIPANT	\N	PRESENT	0
463429	462909	19691J	PARTICIPANT	\N	PRESENT	0
463430	462909	14021P	PARTICIPANT	\N	PRESENT	0
463431	462909	11045K	PARTICIPANT	\N	PRESENT	0
463432	462909	04033B	PARTICIPANT	\N	PRESENT	0
463433	462909	10006L	PARTICIPANT	\N	PRESENT	0
463434	462909	05012A	PARTICIPANT	\N	PRESENT	0
463435	462909	14001X	PARTICIPANT	\N	PRESENT	0
463436	462909	19760E	PARTICIPANT	\N	PRESENT	0
463437	462909	04085P	PARTICIPANT	\N	PRESENT	0
463438	462909	19697Q	PARTICIPANT	\N	PRESENT	0
463439	462909	19591F	PARTICIPANT	\N	PRESENT	0
463440	462909	19545Y	PARTICIPANT	\N	PRESENT	0
463441	462909	14251Q	PARTICIPANT	\N	PRESENT	0
463442	462909	14034U	PARTICIPANT	\N	PRESENT	0
463443	462909	11085T	PARTICIPANT	\N	PRESENT	0
463444	462909	19699S	PARTICIPANT	\N	PRESENT	0
463849	463847	19503N	PARTICIPANT	\N	PRESENT	0
466533	466531	19503N	PARTICIPANT	\N	PRESENT	0
466535	466534	14239U	PARTICIPANT	\N	PRESENT	0
466536	466534	14093U	PARTICIPANT	\N	PRESENT	0
466537	466534	19693L	PARTICIPANT	\N	PRESENT	0
466538	466534	80013X	PARTICIPANT	\N	EXCUSE	0
466539	466534	19553Y	PARTICIPANT	\N	PRESENT	0
466540	466534	19723Y	PARTICIPANT	\N	PRESENT	0
466541	466534	19593H	PARTICIPANT	\N	PRESENT	0
466542	466534	14221J	PARTICIPANT	\N	PRESENT	0
466543	466534	04043D	PARTICIPANT	\N	PRESENT	0
466544	466534	01048V	PRESIDENT	0	PRESENT	0
466545	466534	01058X	PARTICIPANT	\N	PRESENT	0
466546	466534	18003S	PARTICIPANT	\N	PRESENT	0
466881	466136	08009T	PARTICIPANT	\N	PRESENT	0
466882	466136	14038Y	PARTICIPANT	\N	PRESENT	0
466883	466136	14221J	PARTICIPANT	\N	PRESENT	0
466884	466136	19503N	PARTICIPANT	\N	PRESENT	0
466885	466136	14051J	PARTICIPANT	\N	PRESENT	0
466886	466136	19347U	PARTICIPANT	\N	PRESENT	0
466887	466136	19387D	PARTICIPANT	\N	PRESENT	0
466888	466136	17583W	PARTICIPANT	\N	PRESENT	0
459026	459025	19569H	PARTICIPANT	\N	PRESENT	0
459022	459021	19569H	PARTICIPANT	\N	PRESENT	0
459024	459023	19569H	PARTICIPANT	\N	PRESENT	0
459040	459039	10006L	PARTICIPANT	\N	PRESENT	0
459041	459039	11097X	PARTICIPANT	\N	PRESENT	0
459042	459039	11067R	PARTICIPANT	\N	PRESENT	0
459043	459039	14041T	PARTICIPANT	\N	PRESENT	0
459044	459039	19575F	PARTICIPANT	\N	PRESENT	0
460527	458747	19583F	PARTICIPANT	\N	EXCUSE	0
460528	458747	08047A	PARTICIPANT	\N	EXCUSE	0
460529	458747	19421M	PARTICIPANT	\N	EXCUSE	0
460757	460756	98022P	PARTICIPANT	\N	PRESENT	0
462167	459126	14357A	PARTICIPANT	\N	EXCUSE	0
462168	459126	19369B	PARTICIPANT	\N	EXCUSE	0
462169	459126	04045F	PARTICIPANT	\N	EXCUSE	0
462170	459126	08028W	PARTICIPANT	\N	EXCUSE	0
462171	459126	14265W	PARTICIPANT	\N	EXCUSE	0
462172	459126	11090Q	PRESIDENT	0	PRESENT	0
462174	448777	04044E	PARTICIPANT	\N	PRESENT	0
462175	459126	19705W	PARTICIPANT	\N	PRESENT	0
462178	448777	14219Q	PARTICIPANT	\N	PRESENT	0
462179	448777	14265W	PARTICIPANT	\N	PRESENT	0
462180	448777	19760E	PARTICIPANT	\N	PRESENT	0
462181	448777	11056N	PARTICIPANT	\N	PRESENT	0
462182	448777	14229S	PARTICIPANT	\N	PRESENT	0
462183	448777	19631V	PARTICIPANT	\N	PRESENT	0
462184	448777	01028R	PARTICIPANT	\N	PRESENT	0
462185	448777	08024S	PARTICIPANT	\N	PRESENT	0
462186	448777	11099A	PARTICIPANT	\N	PRESENT	0
462187	448777	19629C	PARTICIPANT	\N	PRESENT	0
462188	448777	19585H	PARTICIPANT	\N	PRESENT	0
462189	448777	11072N	PARTICIPANT	\N	PRESENT	0
462190	459126	19768N	PARTICIPANT	\N	PRESENT	0
462191	459126	04088S	PARTICIPANT	\N	PRESENT	0
462192	459126	19515S	PARTICIPANT	\N	PRESENT	0
462193	459126	08015R	PARTICIPANT	\N	PRESENT	0
462194	459126	19441R	PARTICIPANT	\N	PRESENT	0
462195	459126	14197C	PARTICIPANT	\N	PRESENT	0
462196	459126	14207L	PARTICIPANT	\N	PRESENT	0
462197	459126	19563B	PARTICIPANT	\N	PRESENT	0
462198	459126	19619A	PARTICIPANT	\N	PRESENT	0
462199	448777	19782L	PARTICIPANT	\N	PRESENT	0
462200	448777	19479G	PARTICIPANT	\N	PRESENT	0
462201	448777	14073Q	PARTICIPANT	\N	PRESENT	0
462202	448777	14133K	PARTICIPANT	\N	PRESENT	0
462203	448777	19711U	PARTICIPANT	\N	PRESENT	0
462204	448777	19575F	PARTICIPANT	\N	PRESENT	0
462205	448777	04018C	PARTICIPANT	\N	PRESENT	0
462206	459119	10015M	PARTICIPANT	\N	PRESENT	0
462207	459119	19673G	PRESIDENT	0	PRESENT	0
462208	459119	19585H	PARTICIPANT	\N	EXCUSE	0
462209	448777	19521Q	PARTICIPANT	\N	PRESENT	0
462210	448777	14083S	PARTICIPANT	\N	PRESENT	0
462211	448777	19737F	PARTICIPANT	\N	PRESENT	0
462212	448777	19758L	PARTICIPANT	\N	PRESENT	0
462213	448777	19687N	PARTICIPANT	\N	PRESENT	0
462214	448777	19413M	PARTICIPANT	\N	PRESENT	0
462215	448777	14033T	PARTICIPANT	\N	PRESENT	0
462216	459119	11026G	PARTICIPANT	\N	PRESENT	0
462217	448777	19253P	PARTICIPANT	\N	PRESENT	0
462281	448777	95067Q	PARTICIPANT	\N	PRESENT	0
462283	448777	14257W	PARTICIPANT	\N	PRESENT	0
462284	448777	11064N	PARTICIPANT	\N	PRESENT	0
462285	448777	19573D	PARTICIPANT	\N	PRESENT	0
462290	448777	19441R	PARTICIPANT	\N	PRESENT	0
462291	448777	19731Y	PARTICIPANT	\N	PRESENT	0
462292	448777	14105F	PARTICIPANT	\N	PRESENT	0
462293	448777	11097X	PARTICIPANT	\N	PRESENT	0
462345	448778	14219Q	PARTICIPANT	\N	PRESENT	0
462346	448778	11056N	PARTICIPANT	\N	PRESENT	0
462347	448778	19758L	PARTICIPANT	\N	PRESENT	0
462348	448778	11099A	PARTICIPANT	\N	PRESENT	0
462349	448778	19651A	PARTICIPANT	\N	PRESENT	0
462350	448778	19631V	PARTICIPANT	\N	PRESENT	0
462351	448778	19585H	PARTICIPANT	\N	PRESENT	0
462352	448778	19737F	PARTICIPANT	\N	PRESENT	0
462353	448778	14073Q	PARTICIPANT	\N	PRESENT	0
462354	448778	19521Q	PARTICIPANT	\N	PRESENT	0
462355	448778	14105F	PARTICIPANT	\N	PRESENT	0
462356	448778	19575F	PARTICIPANT	\N	PRESENT	0
462357	448778	19573D	PARTICIPANT	\N	PRESENT	0
462358	448778	10015M	PARTICIPANT	\N	PRESENT	0
462360	448778	14038Y	PARTICIPANT	\N	PRESENT	0
462361	448778	01028R	PARTICIPANT	\N	PRESENT	0
462362	448778	19333N	PARTICIPANT	\N	PRESENT	0
462363	448778	19533U	PARTICIPANT	\N	PRESENT	0
462364	448778	95067Q	PARTICIPANT	\N	PRESENT	0
462365	448778	14083S	PARTICIPANT	\N	PRESENT	0
462366	448778	14257W	PARTICIPANT	\N	PRESENT	0
462367	448778	19413M	PARTICIPANT	\N	PRESENT	0
462368	448778	14215L	PARTICIPANT	\N	PRESENT	0
462369	448778	19693L	PARTICIPANT	\N	PRESENT	0
462370	448778	01024M	PARTICIPANT	\N	PRESENT	0
462371	448778	14042U	PARTICIPANT	\N	PRESENT	0
462372	448778	19467C	PARTICIPANT	\N	PRESENT	0
462373	448778	19621T	PARTICIPANT	\N	PRESENT	0
462374	448778	19489J	PARTICIPANT	\N	PRESENT	0
462375	448778	19711U	PARTICIPANT	\N	PRESENT	0
462376	448778	07004J	PARTICIPANT	\N	PRESENT	0
462384	448778	19747H	PARTICIPANT	\N	PRESENT	0
462385	448778	04034C	PARTICIPANT	\N	PRESENT	0
462387	448778	04043D	PARTICIPANT	\N	PRESENT	0
462388	448778	14030Q	PARTICIPANT	\N	PRESENT	0
462395	448778	14041T	PARTICIPANT	\N	PRESENT	0
462398	448778	11097X	PARTICIPANT	\N	PRESENT	0
462341	448778	04086Q	PARTICIPANT	\N	PRESENT	0
462344	448778	14265W	PARTICIPANT	\N	PRESENT	0
462403	448778	11012A	PARTICIPANT	\N	PRESENT	0
462404	448778	95063L	PARTICIPANT	\N	PRESENT	0
462405	448778	11064N	PARTICIPANT	\N	PRESENT	0
462406	448778	14033T	PARTICIPANT	\N	PRESENT	0
462407	448778	11026G	PARTICIPANT	\N	PRESENT	0
462408	448778	14021P	PARTICIPANT	\N	PRESENT	0
462409	448778	19441R	PARTICIPANT	\N	PRESENT	0
462410	448778	19253P	PARTICIPANT	\N	PRESENT	0
462411	448778	19507S	PARTICIPANT	\N	PRESENT	0
462424	448778	19713W	PARTICIPANT	\N	PRESENT	0
462431	448778	19687N	PARTICIPANT	\N	PRESENT	0
462432	448778	11085T	PARTICIPANT	\N	PRESENT	0
462651	462649	11045K	PARTICIPANT	\N	PRESENT	0
462652	462650	11045K	PARTICIPANT	\N	PRESENT	0
464189	464188	14255U	PARTICIPANT	\N	PRESENT	0
464190	464188	08053X	PARTICIPANT	\N	PRESENT	0
464192	464191	14211G	PARTICIPANT	\N	PRESENT	0
464989	464986	04059M	PARTICIPANT	\N	PRESENT	0
464197	464195	19503N	PARTICIPANT	\N	PRESENT	0
464200	464198	19503N	PARTICIPANT	\N	PRESENT	0
464987	464986	89017R	PARTICIPANT	\N	PRESENT	0
464988	464986	04085P	PARTICIPANT	\N	PRESENT	0
464990	464986	05008E	PARTICIPANT	\N	PRESENT	0
464991	464986	96004D	PARTICIPANT	\N	PRESENT	0
464992	464986	04042C	PARTICIPANT	\N	PRESENT	0
464993	464986	11053K	PARTICIPANT	\N	PRESENT	0
464994	464986	11027H	PARTICIPANT	\N	PRESENT	0
464995	464986	04086Q	PARTICIPANT	\N	PRESENT	0
464996	464986	11070L	PARTICIPANT	\N	PRESENT	0
464997	464986	11074Q	PARTICIPANT	\N	PRESENT	0
464998	464986	14034U	PARTICIPANT	\N	PRESENT	0
464999	464986	14021P	PARTICIPANT	\N	PRESENT	0
465000	464986	01043Q	PARTICIPANT	\N	PRESENT	0
465001	464986	14219Q	PARTICIPANT	\N	PRESENT	0
465002	464986	14251Q	PARTICIPANT	\N	PRESENT	0
465003	464986	11085T	PARTICIPANT	\N	PRESENT	0
465004	464986	08009T	PARTICIPANT	\N	PRESENT	0
465005	464986	04092N	PARTICIPANT	\N	PRESENT	0
465006	464986	11072N	PARTICIPANT	\N	PRESENT	0
465007	464986	08011M	PARTICIPANT	\N	PRESENT	0
465008	464986	04070G	PARTICIPANT	\N	PRESENT	0
465009	464986	08061X	PARTICIPANT	\N	PRESENT	0
465010	464986	11090Q	PARTICIPANT	\N	PRESENT	0
465011	464986	11012A	PARTICIPANT	\N	PRESENT	0
465012	464986	04033B	PARTICIPANT	\N	PRESENT	0
465013	464986	04044E	PARTICIPANT	\N	PRESENT	0
465021	463408	08015R	PARTICIPANT	\N	PRESENT	0
465015	464986	01034P	PARTICIPANT	\N	PRESENT	0
465019	463408	19782L	PARTICIPANT	\N	PRESENT	0
465020	463408	19705W	PARTICIPANT	\N	PRESENT	0
465022	463408	11056N	PARTICIPANT	\N	PRESENT	0
465023	463408	14207L	PARTICIPANT	\N	PRESENT	0
465024	463408	04043D	PARTICIPANT	\N	PRESENT	0
465025	463408	14257W	PARTICIPANT	\N	PRESENT	0
465026	463408	19866P	PARTICIPANT	\N	PRESENT	0
465027	463408	19695N	PARTICIPANT	\N	PRESENT	0
465028	463408	19563B	PARTICIPANT	\N	PRESENT	0
465029	463408	19631V	PARTICIPANT	\N	PRESENT	0
465030	463408	14187A	PARTICIPANT	\N	PRESENT	0
465031	463408	19768N	PARTICIPANT	\N	PRESENT	0
468988	468984	14061L	PARTICIPANT	\N	PRESENT	0
468989	468984	19591F	PARTICIPANT	\N	PRESENT	0
469125	466583	07029T	PARTICIPANT	\N	EXCUSE	0
469126	466583	19749K	PARTICIPANT	\N	EXCUSE	0
469323	469321	19503N	PARTICIPANT	\N	PRESENT	0
469326	469324	19503N	PARTICIPANT	\N	PRESENT	0
469338	469334	19503N	PARTICIPANT	\N	PRESENT	0
469527	469128	14053L	PARTICIPANT	\N	PRESENT	0
469528	469128	14111D	PARTICIPANT	\N	PRESENT	0
469529	469128	19629C	PARTICIPANT	\N	PRESENT	0
469530	469128	14215L	PARTICIPANT	\N	PRESENT	0
469531	469128	11049P	PARTICIPANT	\N	PRESENT	0
469532	469128	19673G	PARTICIPANT	\N	PRESENT	0
469533	469128	19675J	PARTICIPANT	\N	PRESENT	0
469534	469128	11033F	PARTICIPANT	\N	PRESENT	0
469535	469128	19447X	PARTICIPANT	\N	PRESENT	0
469536	469128	14021P	PARTICIPANT	\N	PRESENT	0
469537	469128	14001X	PARTICIPANT	\N	PRESENT	0
469538	469128	19581D	PARTICIPANT	\N	PRESENT	0
469539	469128	14231L	PARTICIPANT	\N	PRESENT	0
469540	469128	19489J	PARTICIPANT	\N	PRESENT	0
469541	469128	14041T	PARTICIPANT	\N	PRESENT	0
469542	469128	14147R	PARTICIPANT	\N	PRESENT	0
469543	469128	14179A	PARTICIPANT	\N	PRESENT	0
469544	469128	14151M	PARTICIPANT	\N	PRESENT	0
469545	469128	11072N	PARTICIPANT	\N	PRESENT	0
469546	469128	14065Q	PARTICIPANT	\N	PRESENT	0
469547	469128	10015M	PARTICIPANT	\N	PRESENT	0
469548	469128	08045X	PARTICIPANT	\N	PRESENT	0
469549	469128	19253P	PARTICIPANT	\N	PRESENT	0
469550	469128	01024M	PARTICIPANT	\N	PRESENT	0
469551	469128	04038G	PARTICIPANT	\N	PRESENT	0
469552	469128	11085T	PARTICIPANT	\N	PRESENT	0
469553	469128	19762G	PARTICIPANT	\N	PRESENT	0
469554	469128	04044E	PARTICIPANT	\N	PRESENT	0
469555	469128	01028R	PARTICIPANT	\N	PRESENT	0
469556	469128	14069U	PARTICIPANT	\N	PRESENT	0
469557	469128	04008A	PARTICIPANT	\N	PRESENT	0
469559	469071	19768N	PARTICIPANT	\N	PRESENT	0
469560	469071	19515S	PARTICIPANT	\N	PRESENT	0
469561	469071	19782L	PARTICIPANT	\N	PRESENT	0
469562	469071	11077T	PARTICIPANT	\N	PRESENT	0
469563	469071	19441R	PARTICIPANT	\N	PRESENT	0
469564	469071	19812Y	PARTICIPANT	\N	PRESENT	0
469565	469071	19413M	PARTICIPANT	\N	PRESENT	0
469566	469071	14081Q	PARTICIPANT	\N	PRESENT	0
469567	469071	80013X	PARTICIPANT	\N	PRESENT	0
469568	469071	04045F	PARTICIPANT	\N	PRESENT	0
469569	469071	19631V	PARTICIPANT	\N	PRESENT	0
469570	469071	04049K	PARTICIPANT	\N	PRESENT	0
469571	469071	19705W	PARTICIPANT	\N	PRESENT	0
469572	469071	08015R	PARTICIPANT	\N	PRESENT	0
469573	469071	14197C	PARTICIPANT	\N	PRESENT	0
469574	469071	08028W	PARTICIPANT	\N	PRESENT	0
469575	469071	19563B	PARTICIPANT	\N	PRESENT	0
469576	469071	14265W	PARTICIPANT	\N	PRESENT	0
469577	469071	14135M	PARTICIPANT	\N	PRESENT	0
469578	469071	19467C	PARTICIPANT	\N	PRESENT	0
469579	469071	14187A	PARTICIPANT	\N	PRESENT	0
469580	469071	19695N	PARTICIPANT	\N	PRESENT	0
469581	469071	11090Q	PRESIDENT	0	PRESENT	0
469582	469071	01025N	PARTICIPANT	\N	PRESENT	0
469583	469071	19269X	PARTICIPANT	\N	PRESENT	0
469584	469071	14115H	PARTICIPANT	\N	PRESENT	0
469585	469071	19747H	PARTICIPANT	\N	PRESENT	0
469586	469071	14207L	PARTICIPANT	\N	PRESENT	0
469587	469071	14257W	PARTICIPANT	\N	PRESENT	0
469591	469128	14259Y	PARTICIPANT	\N	PRESENT	0
469592	469128	19649G	PARTICIPANT	\N	PRESENT	0
469593	469071	11099A	PARTICIPANT	\N	PRESENT	0
469594	469071	08068F	PARTICIPANT	\N	PRESENT	0
469595	469071	14205J	PARTICIPANT	\N	PRESENT	0
469596	469071	11056N	PARTICIPANT	\N	PRESENT	0
469597	469071	19619A	PARTICIPANT	\N	PRESENT	0
469598	469128	05008E	PRESIDENT	0	PRESENT	0
469599	469128	08044W	PARTICIPANT	\N	PRESENT	0
470568	470567	14083S	PARTICIPANT	\N	PRESENT	0
470569	470567	14061L	PARTICIPANT	\N	PRESENT	0
470570	470567	08015R	PARTICIPANT	\N	PRESENT	0
470571	468992	14083S	PARTICIPANT	\N	PRESENT	0
470572	468992	14061L	PARTICIPANT	\N	PRESENT	0
470612	469312	19575F	PARTICIPANT	\N	PRESENT	0
470613	469312	11031D	PARTICIPANT	\N	PRESENT	0
470614	469312	14071N	PARTICIPANT	\N	PRESENT	0
470615	469312	04092N	PARTICIPANT	\N	PRESENT	0
470617	469312	19798U	PARTICIPANT	\N	PRESENT	0
470618	469312	10006L	PARTICIPANT	\N	PRESENT	0
470622	467703	08043V	PARTICIPANT	\N	PRESENT	0
470623	467703	08031R	PARTICIPANT	\N	PRESENT	0
470624	467703	14059S	PARTICIPANT	\N	PRESENT	0
470625	467703	19735D	PARTICIPANT	\N	PRESENT	0
470801	470800	19758L	PARTICIPANT	\N	PRESENT	0
470802	470800	19621T	PARTICIPANT	\N	PRESENT	0
470803	470800	19699S	PARTICIPANT	\N	PRESENT	0
470805	470804	14215L	PARTICIPANT	\N	PRESENT	0
470806	470804	14021P	PARTICIPANT	\N	PRESENT	0
470808	470807	04047H	PARTICIPANT	\N	PRESENT	0
470809	470807	14021P	PARTICIPANT	\N	PRESENT	0
470810	470807	95063L	PARTICIPANT	\N	PRESENT	0
470811	470807	19581D	PARTICIPANT	\N	PRESENT	0
470812	470807	14147R	PARTICIPANT	\N	PRESENT	0
470813	470807	14215L	PARTICIPANT	\N	PRESENT	0
470848	470847	14241N	PARTICIPANT	\N	PRESENT	0
470849	470847	14061L	PARTICIPANT	\N	PRESENT	0
470850	470847	19533U	PARTICIPANT	\N	PRESENT	0
470851	470847	19593H	PARTICIPANT	\N	PRESENT	0
470852	470847	19611R	PARTICIPANT	\N	PRESENT	0
470854	470853	14073Q	PARTICIPANT	\N	PRESENT	0
470855	470853	08017T	PARTICIPANT	\N	PRESENT	0
470856	470853	19766L	PARTICIPANT	\N	PRESENT	0
471548	471547	11109J	PARTICIPANT	\N	PRESENT	0
471549	471547	14261S	PARTICIPANT	\N	PRESENT	0
471550	471547	19717B	PARTICIPANT	\N	PRESENT	0
471551	471547	19631V	PARTICIPANT	\N	PRESENT	0
471552	471547	19295A	PARTICIPANT	\N	PRESENT	0
471553	471547	14259Y	PARTICIPANT	\N	EXCUSE	0
471554	471547	19659J	PARTICIPANT	\N	PRESENT	0
471555	471547	19577H	PARTICIPANT	\N	PRESENT	0
471556	471547	19691J	PARTICIPANT	\N	PRESENT	0
471557	471547	19715Y	PARTICIPANT	\N	PRESENT	0
471558	471547	14039A	PARTICIPANT	\N	PRESENT	0
471559	471547	14059S	PARTICIPANT	\N	PRESENT	0
471560	471547	12016W	PARTICIPANT	\N	PRESENT	0
471561	471547	08019V	PRESIDENT	0	PRESENT	0
471563	471547	19657G	PARTICIPANT	\N	PRESENT	0
471564	471547	19301E	PARTICIPANT	\N	PRESENT	0
471565	471547	14157T	PARTICIPANT	\N	PRESENT	0
471566	471547	14097Y	PARTICIPANT	\N	EXCUSE	0
471602	470532	11097X	PARTICIPANT	\N	PRESENT	0
471603	470532	14231L	PARTICIPANT	\N	PRESENT	0
471604	470532	19553Y	PARTICIPANT	\N	PRESENT	0
471605	470532	19489J	PARTICIPANT	\N	PRESENT	0
471606	470532	14259Y	PARTICIPANT	\N	PRESENT	0
471607	470532	11085T	PARTICIPANT	\N	PRESENT	0
471737	470532	04038G	PARTICIPANT	\N	PRESENT	0
471738	470532	04008A	PARTICIPANT	\N	PRESENT	0
471739	470532	19719D	PARTICIPANT	\N	PRESENT	0
471740	470532	01024M	PARTICIPANT	\N	PRESENT	0
471741	470532	14215L	PARTICIPANT	\N	PRESENT	0
471742	470532	19673G	PARTICIPANT	\N	PRESENT	0
471743	470532	08045X	PARTICIPANT	\N	PRESENT	0
471744	470532	19649G	PARTICIPANT	\N	PRESENT	0
471745	470532	11049P	PARTICIPANT	\N	PRESENT	0
471746	470532	14021P	PARTICIPANT	\N	PRESENT	0
471747	470532	19729F	PARTICIPANT	\N	PRESENT	0
471748	470532	19581D	PARTICIPANT	\N	PRESENT	0
471749	470532	08044W	PARTICIPANT	\N	PRESENT	0
471750	470532	19725B	PARTICIPANT	\N	PRESENT	0
471751	470532	14111D	PARTICIPANT	\N	PRESENT	0
471752	470532	10015M	PARTICIPANT	\N	PRESENT	0
471753	470532	19762G	PARTICIPANT	\N	PRESENT	0
471754	470532	01028R	PARTICIPANT	\N	PRESENT	0
471755	470532	98035U	PARTICIPANT	\N	PRESENT	0
471756	470532	19675J	PARTICIPANT	\N	PRESENT	0
471757	470532	04044E	PARTICIPANT	\N	PRESENT	0
471782	470827	19553Y	PARTICIPANT	\N	PRESENT	0
471783	470827	14119M	PARTICIPANT	\N	PRESENT	0
471784	470827	04092N	PRESIDENT	0	PRESENT	0
471785	470827	19565D	PARTICIPANT	\N	PRESENT	0
471786	470827	14087W	PARTICIPANT	\N	PRESENT	0
471787	470827	11097X	PARTICIPANT	\N	PRESENT	0
471788	470827	19679N	PARTICIPANT	\N	PRESENT	0
471789	470827	19691J	PARTICIPANT	\N	PRESENT	0
471790	470827	14026U	PARTICIPANT	\N	PRESENT	0
471791	470827	19683J	PARTICIPANT	\N	PRESENT	0
471792	470827	19521Q	PARTICIPANT	\N	PRESENT	0
458496	439828	19533U	PARTICIPANT	\N	PRESENT	0
458497	439828	14249W	PARTICIPANT	\N	PRESENT	0
458513	455106	08056B	PARTICIPANT	\N	PRESENT	0
470958	470955	98005N	PARTICIPANT	\N	PRESENT	0
458515	455106	11026G	PARTICIPANT	\N	PRESENT	0
458516	455106	19669L	PARTICIPANT	\N	PRESENT	0
458517	439828	14147R	PARTICIPANT	\N	PRESENT	0
458518	439828	19762G	PARTICIPANT	\N	PRESENT	0
458519	439828	19741B	PARTICIPANT	\N	PRESENT	0
458520	439828	19812Y	PARTICIPANT	\N	PRESENT	0
458521	439828	04085P	PARTICIPANT	\N	PRESENT	0
470956	470955	08020N	PARTICIPANT	\N	PRESENT	0
470957	470955	08024S	PARTICIPANT	\N	PRESENT	0
470959	470955	14219Q	PARTICIPANT	\N	PRESENT	0
470960	470955	04043D	PARTICIPANT	\N	PRESENT	0
470961	470955	14059S	PARTICIPANT	\N	PRESENT	0
470964	470963	14207L	PARTICIPANT	\N	PRESENT	0
470965	470963	01025N	PARTICIPANT	\N	PRESENT	0
470966	470963	19812Y	PARTICIPANT	\N	PRESENT	0
470967	470963	11099A	PARTICIPANT	\N	PRESENT	0
470968	470963	19619A	PARTICIPANT	\N	PRESENT	0
470969	470963	19563B	PARTICIPANT	\N	PRESENT	0
470970	470963	08015R	PARTICIPANT	\N	PRESENT	0
470971	470963	14357A	PARTICIPANT	\N	PRESENT	0
470973	470972	14187A	PARTICIPANT	\N	PRESENT	0
471024	471022	19503N	PARTICIPANT	\N	PRESENT	0
471027	471025	19503N	PARTICIPANT	\N	PRESENT	0
471531	470544	11053K	PARTICIPANT	\N	PRESENT	0
471532	470544	19545Y	PARTICIPANT	\N	PRESENT	0
471533	470544	14085U	PARTICIPANT	\N	PRESENT	0
471534	470544	14327T	PARTICIPANT	\N	PRESENT	0
471535	470544	04071H	PARTICIPANT	\N	PRESENT	0
471536	470544	11110B	PARTICIPANT	\N	PRESENT	0
471537	470544	01057W	PARTICIPANT	\N	PRESENT	0
471538	470544	11048N	PARTICIPANT	\N	PRESENT	0
471539	470544	19531S	PARTICIPANT	\N	PRESENT	0
471540	470544	99004R	PARTICIPANT	\N	PRESENT	0
481197	481194	19611R	PARTICIPANT	\N	PRESENT	0
471542	470544	19671E	PARTICIPANT	\N	PRESENT	0
471543	470544	14331P	PARTICIPANT	\N	PRESENT	0
471544	470544	14225N	PARTICIPANT	\N	PRESENT	0
471545	470544	19689Q	PARTICIPANT	\N	PRESENT	0
471546	470544	14034U	PARTICIPANT	\N	PRESENT	0
471567	470544	19711U	PARTICIPANT	\N	PRESENT	0
481195	481194	14197C	PARTICIPANT	\N	PRESENT	0
481196	481194	14097Y	PARTICIPANT	\N	PRESENT	0
481202	481200	14097Y	PARTICIPANT	\N	PRESENT	0
481207	481200	19611R	PARTICIPANT	\N	PRESENT	0
481287	481286	19415P	PARTICIPANT	\N	PRESENT	0
481288	481286	11067R	PARTICIPANT	\N	PRESENT	0
481289	481286	11097X	PARTICIPANT	\N	PRESENT	0
481290	481286	19703U	PARTICIPANT	\N	PRESENT	0
481291	481286	17779H	PARTICIPANT	\N	PRESENT	0
481292	481286	19760E	PARTICIPANT	\N	PRESENT	0
481303	481297	96004D	PRESIDENT	0	PRESENT	0
481309	481297	14133K	PARTICIPANT	\N	PRESENT	0
481310	481297	04035D	PARTICIPANT	\N	PRESENT	0
481311	481297	11083R	PARTICIPANT	\N	PRESENT	0
481312	481297	14357A	PARTICIPANT	\N	PRESENT	0
481313	481297	14033T	PARTICIPANT	\N	PRESENT	0
481314	481297	14026U	PARTICIPANT	\N	PRESENT	0
481316	481297	14073Q	PARTICIPANT	\N	PRESENT	0
481320	481297	19725B	PARTICIPANT	\N	PRESENT	0
481322	481297	04097T	PARTICIPANT	\N	PRESENT	0
481323	481297	14097Y	PARTICIPANT	\N	PRESENT	0
481324	481297	14241N	PARTICIPANT	\N	PRESENT	0
481325	481297	11026G	PARTICIPANT	\N	PRESENT	0
481327	481297	14135M	PARTICIPANT	\N	PRESENT	0
481328	481297	14331P	PARTICIPANT	\N	PRESENT	0
481331	481297	10015M	PARTICIPANT	\N	PRESENT	0
481335	481297	98035U	PARTICIPANT	\N	PRESENT	0
481340	481297	01058X	PARTICIPANT	\N	PRESENT	0
481341	481297	14255U	PARTICIPANT	\N	PRESENT	0
481342	481297	19443T	PARTICIPANT	\N	PRESENT	0
481343	481297	19251M	PARTICIPANT	\N	PRESENT	0
481345	481297	95030B	PARTICIPANT	\N	PRESENT	0
481346	481297	19583F	PARTICIPANT	\N	PRESENT	0
481351	481297	19709B	PARTICIPANT	\N	PRESENT	0
481352	481297	98050T	PARTICIPANT	\N	PRESENT	0
481354	481297	19421M	PARTICIPANT	\N	PRESENT	0
481357	481297	11041F	PARTICIPANT	\N	PRESENT	0
481360	481297	11066Q	PARTICIPANT	\N	PRESENT	0
481363	481297	04034C	PARTICIPANT	\N	PRESENT	0
481364	481297	97011G	PARTICIPANT	\N	PRESENT	0
481365	481297	04042C	PARTICIPANT	\N	PRESENT	0
481366	481297	98029W	PARTICIPANT	\N	PRESENT	0
481382	481297	04040A	PARTICIPANT	\N	PRESENT	0
481388	481297	11027H	PARTICIPANT	\N	PRESENT	0
481492	481297	14061L	PARTICIPANT	\N	EXCUSE	0
481493	481297	95037J	PARTICIPANT	\N	EXCUSE	0
481494	481297	14089Y	PARTICIPANT	\N	EXCUSE	0
482630	479258	14133K	PARTICIPANT	\N	PRESENT	0
482631	479258	19383Y	PARTICIPANT	\N	PRESENT	0
482632	479258	11064N	PARTICIPANT	\N	PRESENT	0
482633	479258	01060R	PARTICIPANT	\N	PRESENT	0
482634	479258	04018C	PARTICIPANT	\N	PRESENT	0
482635	479258	19621T	PARTICIPANT	\N	PRESENT	0
482636	479258	19367Y	PARTICIPANT	\N	PRESENT	0
482637	479258	01058X	PARTICIPANT	\N	PRESENT	0
482638	479258	14059S	PARTICIPANT	\N	PRESENT	0
482639	479258	19729F	PARTICIPANT	\N	PRESENT	0
482640	479258	19768N	PARTICIPANT	\N	PRESENT	0
482641	479258	14135M	PARTICIPANT	\N	PRESENT	0
482642	479258	04088S	PARTICIPANT	\N	PRESENT	0
482643	479258	19663E	PARTICIPANT	\N	PRESENT	0
482644	479258	19709B	PARTICIPANT	\N	PRESENT	0
482645	479258	19443T	PARTICIPANT	\N	PRESENT	0
482646	479258	17637T	PARTICIPANT	\N	PRESENT	0
482647	479258	19701S	PARTICIPANT	\N	PRESENT	0
482648	479258	14231L	PARTICIPANT	\N	PRESENT	0
482649	479258	19699S	PARTICIPANT	\N	PRESENT	0
482650	479258	14087W	PARTICIPANT	\N	PRESENT	0
482651	479258	01057W	PARTICIPANT	\N	PRESENT	0
482652	479258	14157T	PARTICIPANT	\N	PRESENT	0
482653	481557	98035U	PARTICIPANT	\N	PRESENT	0
482654	481557	11033F	PARTICIPANT	\N	PRESENT	0
482655	481557	19649G	PARTICIPANT	\N	PRESENT	0
482656	479258	19545Y	PARTICIPANT	\N	PRESENT	0
482657	479258	01024M	PARTICIPANT	\N	PRESENT	0
482658	479258	14121F	PARTICIPANT	\N	PRESENT	0
482659	479258	14251Q	PARTICIPANT	\N	PRESENT	0
482660	479258	19689Q	PARTICIPANT	\N	PRESENT	0
482661	481555	11056N	PARTICIPANT	\N	PRESENT	0
482662	481555	19667J	PARTICIPANT	\N	PRESENT	0
482663	481555	19820Y	PARTICIPANT	\N	PRESENT	0
482664	481555	04097T	PARTICIPANT	\N	PRESENT	0
482665	481555	04045F	PARTICIPANT	\N	PRESENT	0
482666	481555	19725B	PARTICIPANT	\N	PRESENT	0
482667	479258	04047H	PARTICIPANT	\N	PRESENT	0
482671	479258	19721W	PARTICIPANT	\N	PRESENT	0
482669	479258	89017R	PARTICIPANT	\N	PRESENT	0
482670	479258	11056N	PARTICIPANT	\N	PRESENT	0
482672	479258	14038Y	PARTICIPANT	\N	PRESENT	0
482673	481068	14083S	PARTICIPANT	\N	PRESENT	0
482859	479183	04059M	PARTICIPANT	\N	PRESENT	0
482860	479183	19689Q	PARTICIPANT	\N	PRESENT	0
482861	479183	14081Q	PARTICIPANT	\N	PRESENT	0
482862	479183	19569H	PARTICIPANT	\N	PRESENT	0
482884	479183	01034P	PARTICIPANT	\N	PRESENT	0
482864	479183	19301E	PARTICIPANT	\N	PRESENT	0
482865	479183	19367Y	PARTICIPANT	\N	PRESENT	0
482886	479183	11103C	PARTICIPANT	\N	PRESENT	0
482867	479183	19663E	PARTICIPANT	\N	PRESENT	0
482868	479183	08052W	PARTICIPANT	\N	PRESENT	0
482869	479183	14195A	PARTICIPANT	\N	PRESENT	0
482870	479183	19467C	PARTICIPANT	\N	PRESENT	0
482871	479183	19794Q	PARTICIPANT	\N	PRESENT	0
482872	479183	11048N	PARTICIPANT	\N	PRESENT	0
482873	479183	19651A	PARTICIPANT	\N	PRESENT	0
482874	479183	19599P	PARTICIPANT	\N	PRESENT	0
482875	479183	14085U	PARTICIPANT	\N	PRESENT	0
482876	479183	11067R	PARTICIPANT	\N	PRESENT	0
482877	479183	11074Q	PARTICIPANT	\N	PRESENT	0
482878	479183	14261S	PARTICIPANT	\N	PRESENT	0
482885	479183	04092N	PARTICIPANT	\N	PRESENT	0
482881	479183	14217N	PARTICIPANT	\N	PRESENT	0
482882	479183	18083K	PARTICIPANT	\N	PRESENT	0
482883	479183	04088S	PARTICIPANT	\N	PRESENT	0
482887	479183	11097X	PARTICIPANT	\N	PRESENT	0
482888	479183	10006L	PARTICIPANT	\N	PRESENT	0
482889	479183	19415P	PARTICIPANT	\N	PRESENT	0
482890	479183	19565D	PARTICIPANT	\N	PRESENT	0
482891	479183	19760E	PARTICIPANT	\N	PRESENT	0
482892	479183	11031D	PARTICIPANT	\N	PRESENT	0
482893	479183	19711U	PARTICIPANT	\N	PRESENT	0
482894	479183	14042U	PARTICIPANT	\N	PRESENT	0
466889	466136	18083K	PARTICIPANT	\N	PRESENT	0
466890	466136	19820Y	PARTICIPANT	\N	PRESENT	0
466891	466136	14219Q	PARTICIPANT	\N	PRESENT	0
466892	466136	19333N	PARTICIPANT	\N	PRESENT	0
467836	467834	04035D	PARTICIPANT	\N	PRESENT	0
467837	467834	08049C	PARTICIPANT	\N	PRESENT	0
467838	467835	04035D	PARTICIPANT	\N	PRESENT	0
467839	467835	08049C	PARTICIPANT	\N	PRESENT	0
468759	466893	19621T	PARTICIPANT	\N	EXCUSE	0
468760	466893	07029T	PARTICIPANT	\N	EXCUSE	0
468761	466893	14030Q	PRESIDENT	0	PRESENT	0
468762	466893	08043V	PARTICIPANT	\N	PRESENT	0
468763	466893	19643A	PARTICIPANT	\N	PRESENT	0
468764	466893	19701S	PARTICIPANT	\N	PRESENT	0
468765	466893	11031D	PARTICIPANT	\N	PRESENT	0
468766	466893	80013X	PARTICIPANT	\N	PRESENT	0
468767	466893	19693L	PARTICIPANT	\N	PRESENT	0
468768	466893	04035D	PARTICIPANT	\N	PRESENT	0
468769	466893	14179A	PARTICIPANT	\N	PRESENT	0
468770	466893	19715Y	PARTICIPANT	\N	PRESENT	0
468771	466893	19731Y	PARTICIPANT	\N	PRESENT	0
468772	466893	08031R	PARTICIPANT	\N	PRESENT	0
468773	466893	11067R	PARTICIPANT	\N	PRESENT	0
468774	466893	11045K	PARTICIPANT	\N	PRESENT	0
468775	466893	19749K	PARTICIPANT	\N	PRESENT	0
469068	468776	14026U	PARTICIPANT	\N	PRESENT	0
469069	468776	14071N	PARTICIPANT	\N	PRESENT	0
469070	468776	14069U	PARTICIPANT	\N	EXCUSE	0
469659	469657	05008E	PARTICIPANT	\N	PRESENT	0
469660	469657	14259Y	PARTICIPANT	\N	PRESENT	0
469662	469657	14231L	PARTICIPANT	\N	PRESENT	0
469934	469931	19507S	PARTICIPANT	\N	PRESENT	0
469684	469657	04040A	PARTICIPANT	\N	PRESENT	0
469933	469931	14357A	PARTICIPANT	\N	PRESENT	0
469935	469931	14257W	PARTICIPANT	\N	PRESENT	0
469936	469931	19563B	PARTICIPANT	\N	PRESENT	0
469937	469931	19269X	PARTICIPANT	\N	PRESENT	0
469938	469906	19782L	PARTICIPANT	\N	PRESENT	0
469939	469906	08020N	PARTICIPANT	\N	PRESENT	0
469940	469906	14207L	PARTICIPANT	\N	PRESENT	0
469941	469906	19812Y	PARTICIPANT	\N	PRESENT	0
469942	469906	80013X	PARTICIPANT	\N	PRESENT	0
469943	469906	14105F	PARTICIPANT	\N	PRESENT	0
469944	469906	01025N	PARTICIPANT	\N	PRESENT	0
469945	469906	04049K	PARTICIPANT	\N	PRESENT	0
469946	469906	08015R	PARTICIPANT	\N	PRESENT	0
469947	469906	19723Y	PARTICIPANT	\N	PRESENT	0
469948	469906	14109K	PARTICIPANT	\N	PRESENT	0
469949	469906	19745F	PARTICIPANT	\N	PRESENT	0
469950	469906	11097X	PARTICIPANT	\N	PRESENT	0
469954	469951	14105F	PARTICIPANT	\N	PRESENT	0
469955	469951	19782L	PARTICIPANT	\N	PRESENT	0
469956	469951	14207L	PARTICIPANT	\N	PRESENT	0
469957	469951	19467C	PARTICIPANT	\N	PRESENT	0
469958	469951	80013X	PARTICIPANT	\N	PRESENT	0
469959	469951	14329V	PARTICIPANT	\N	PRESENT	0
469960	469951	01025N	PARTICIPANT	\N	PRESENT	0
469961	469951	19820Y	PARTICIPANT	\N	PRESENT	0
469962	469951	19725B	PARTICIPANT	\N	PRESENT	0
469963	469951	95037J	PARTICIPANT	\N	PRESENT	0
469964	469951	08015R	PARTICIPANT	\N	PRESENT	0
469965	469951	19723Y	PARTICIPANT	\N	PRESENT	0
469966	469951	08053X	PARTICIPANT	\N	PRESENT	0
469967	469951	14109K	PARTICIPANT	\N	PRESENT	0
469968	469951	14257W	PARTICIPANT	\N	PRESENT	0
469969	469951	19563B	PARTICIPANT	\N	PRESENT	0
469970	469951	11097X	PARTICIPANT	\N	PRESENT	0
469971	469952	19782L	PARTICIPANT	\N	PRESENT	0
469972	469952	14207L	PARTICIPANT	\N	PRESENT	0
469973	469952	19812Y	PARTICIPANT	\N	PRESENT	0
469974	469952	19507S	PARTICIPANT	\N	PRESENT	0
469975	469952	14257W	PARTICIPANT	\N	PRESENT	0
469976	469952	19563B	PARTICIPANT	\N	PRESENT	0
469977	469953	19782L	PARTICIPANT	\N	PRESENT	0
469978	469953	14207L	PARTICIPANT	\N	PRESENT	0
469979	469953	19812Y	PARTICIPANT	\N	PRESENT	0
469980	469953	14033T	PARTICIPANT	\N	PRESENT	0
469981	469953	11099A	PARTICIPANT	\N	PRESENT	0
469982	469953	11077T	PARTICIPANT	\N	PRESENT	0
469983	469953	14257W	PARTICIPANT	\N	PRESENT	0
469984	469953	19563B	PARTICIPANT	\N	PRESENT	0
469986	469985	19782L	PARTICIPANT	\N	PRESENT	0
469987	469985	14207L	PARTICIPANT	\N	PRESENT	0
469988	469985	19812Y	PARTICIPANT	\N	PRESENT	0
469989	469985	14357A	PARTICIPANT	\N	PRESENT	0
469990	469985	19507S	PARTICIPANT	\N	PRESENT	0
469991	469985	14033T	PARTICIPANT	\N	PRESENT	0
469992	469985	11099A	PARTICIPANT	\N	PRESENT	0
469993	469985	19441R	PARTICIPANT	\N	PRESENT	0
469994	469985	19563B	PARTICIPANT	\N	PRESENT	0
469995	469985	14257W	PARTICIPANT	\N	PRESENT	0
470011	470010	14207L	PARTICIPANT	\N	PRESENT	0
470013	470010	01025N	PARTICIPANT	\N	PRESENT	0
470058	470057	19782L	PARTICIPANT	\N	PRESENT	0
470059	470057	14207L	PARTICIPANT	\N	PRESENT	0
470060	470057	01025N	PARTICIPANT	\N	PRESENT	0
470061	470057	11099A	PARTICIPANT	\N	PRESENT	0
470062	470057	19563B	PARTICIPANT	\N	PRESENT	0
470063	470057	14265W	PARTICIPANT	\N	PRESENT	0
470064	470057	19269X	PARTICIPANT	\N	PRESENT	0
470065	470057	19619A	PARTICIPANT	\N	PRESENT	0
470067	470066	14207L	PARTICIPANT	\N	PRESENT	0
470068	470066	14357A	PARTICIPANT	\N	PRESENT	0
470069	470066	14197C	PARTICIPANT	\N	PRESENT	0
470070	470066	01025N	PARTICIPANT	\N	PRESENT	0
470071	470066	11099A	PARTICIPANT	\N	PRESENT	0
470072	470066	19619A	PARTICIPANT	\N	PRESENT	0
470074	470073	14207L	PARTICIPANT	\N	PRESENT	0
470075	470073	14357A	PARTICIPANT	\N	PRESENT	0
470076	470073	01025N	PARTICIPANT	\N	PRESENT	0
470077	470073	14197C	PARTICIPANT	\N	PRESENT	0
470078	470073	19619A	PARTICIPANT	\N	PRESENT	0
470079	470073	11099A	PARTICIPANT	\N	PRESENT	0
470179	463732	89017R	PARTICIPANT	\N	PRESENT	0
470180	463732	04085P	PARTICIPANT	\N	PRESENT	0
470181	463732	04059M	PARTICIPANT	\N	PRESENT	0
470182	463732	19651A	PARTICIPANT	\N	PRESENT	0
470183	463732	14093U	PARTICIPANT	\N	PRESENT	0
470184	463732	96004D	PARTICIPANT	\N	PRESENT	0
470185	463732	11027H	PARTICIPANT	\N	PRESENT	0
470186	463732	11070L	PARTICIPANT	\N	PRESENT	0
470187	463732	19719D	PARTICIPANT	\N	PRESENT	0
470188	463732	11074Q	PARTICIPANT	\N	PRESENT	0
470189	463732	14034U	PARTICIPANT	\N	PRESENT	0
470190	463732	19347U	PARTICIPANT	\N	PRESENT	0
470191	463732	19591F	PARTICIPANT	\N	PRESENT	0
470192	463732	19551W	PARTICIPANT	\N	PRESENT	0
470193	463732	19531S	PARTICIPANT	\N	PRESENT	0
470194	463732	95041E	PARTICIPANT	\N	PRESENT	0
470195	463732	14021P	PARTICIPANT	\N	PRESENT	0
470196	463732	07029T	PARTICIPANT	\N	PRESENT	0
470197	463732	86034E	PARTICIPANT	\N	PRESENT	0
470198	463732	11026G	PARTICIPANT	\N	PRESENT	0
470199	463732	08010L	PARTICIPANT	\N	PRESENT	0
470200	463732	19441R	PARTICIPANT	\N	PRESENT	0
470201	463732	14251Q	PARTICIPANT	\N	PRESENT	0
470202	463732	14031R	PARTICIPANT	\N	PRESENT	0
470203	463732	11085T	PARTICIPANT	\N	PRESENT	0
470204	463732	08011M	PARTICIPANT	\N	PRESENT	0
470205	463732	14071N	PARTICIPANT	\N	PRESENT	0
470206	463732	19573D	PARTICIPANT	\N	PRESENT	0
470207	463732	08061X	PARTICIPANT	\N	PRESENT	0
470208	463732	19533U	PARTICIPANT	\N	PRESENT	0
470209	463732	05012A	PARTICIPANT	\N	PRESENT	0
470210	463732	11090Q	PARTICIPANT	\N	PRESENT	0
470211	463732	04043D	PARTICIPANT	\N	PRESENT	0
470212	463732	04033B	PARTICIPANT	\N	PRESENT	0
470213	463732	95063L	PARTICIPANT	\N	PRESENT	0
470214	463732	14229S	PARTICIPANT	\N	PRESENT	0
470215	463732	19762G	PARTICIPANT	\N	PRESENT	0
470216	463732	19713W	PARTICIPANT	\N	PRESENT	0
470217	463732	19689Q	PARTICIPANT	\N	PRESENT	0
470218	463732	19413M	PARTICIPANT	\N	PRESENT	0
470219	463732	14157T	PARTICIPANT	\N	PRESENT	0
470220	463732	04034C	PARTICIPANT	\N	PRESENT	0
470222	465629	04034C	PARTICIPANT	\N	PRESENT	0
470223	465629	14157T	PARTICIPANT	\N	PRESENT	0
470224	465629	19413M	PARTICIPANT	\N	PRESENT	0
470225	465629	19689Q	PARTICIPANT	\N	PRESENT	0
470226	465629	19713W	PARTICIPANT	\N	PRESENT	0
470227	465629	19762G	PARTICIPANT	\N	PRESENT	0
470228	465629	14229S	PARTICIPANT	\N	PRESENT	0
470229	465629	95063L	PARTICIPANT	\N	PRESENT	0
470231	465629	89017R	PARTICIPANT	\N	PRESENT	0
470232	465629	11074Q	PARTICIPANT	\N	PRESENT	0
470233	465629	19719D	PARTICIPANT	\N	PRESENT	0
470234	465629	11070L	PARTICIPANT	\N	PRESENT	0
459016	459015	19569H	PARTICIPANT	\N	PRESENT	0
459018	459017	19569H	PARTICIPANT	\N	PRESENT	0
459020	459019	19569H	PARTICIPANT	\N	PRESENT	0
459263	459262	14157T	PARTICIPANT	\N	PRESENT	0
459264	459262	19599P	PARTICIPANT	\N	PRESENT	0
459265	459262	14031R	PARTICIPANT	\N	PRESENT	0
459266	459262	19826F	PARTICIPANT	\N	PRESENT	0
459267	459262	14051J	PARTICIPANT	\N	PRESENT	0
459269	459268	19820Y	PARTICIPANT	\N	PRESENT	0
459270	459268	19826F	PARTICIPANT	\N	PRESENT	0
459271	459268	14157T	PARTICIPANT	\N	PRESENT	0
459272	459268	19599P	PARTICIPANT	\N	PRESENT	0
461911	461910	07004J	PARTICIPANT	\N	PRESENT	0
461912	461910	19713W	PARTICIPANT	\N	PRESENT	0
461921	461919	14041T	PARTICIPANT	\N	PRESENT	0
461922	461919	14215L	PARTICIPANT	\N	PRESENT	0
461925	461919	19731Y	PARTICIPANT	\N	PRESENT	0
463843	463734	14327T	PARTICIPANT	\N	PRESENT	0
463844	463734	01048V	PARTICIPANT	\N	PRESENT	0
463845	463734	01057W	PARTICIPANT	\N	PRESENT	0
463846	463734	89017R	PARTICIPANT	\N	PRESENT	0
465032	463408	14197C	PARTICIPANT	\N	PRESENT	0
465033	463408	01025N	PARTICIPANT	\N	PRESENT	0
465034	463408	04045F	PARTICIPANT	\N	PRESENT	0
465035	463408	19467C	PARTICIPANT	\N	PRESENT	0
465036	463408	01043Q	PARTICIPANT	\N	PRESENT	0
465037	463408	14115H	PARTICIPANT	\N	PRESENT	0
465038	463408	14357A	PARTICIPANT	\N	PRESENT	0
465039	463408	08068F	PARTICIPANT	\N	PRESENT	0
465040	463408	14135M	PARTICIPANT	\N	PRESENT	0
465041	463408	11090Q	PRESIDENT	0	PRESENT	0
465042	463408	19507S	PARTICIPANT	\N	PRESENT	0
465043	463408	14033T	PARTICIPANT	\N	PRESENT	0
465044	463408	14205J	PARTICIPANT	\N	PRESENT	0
465045	463408	11099A	PARTICIPANT	\N	PRESENT	0
465046	463408	04049K	PARTICIPANT	\N	PRESENT	0
465047	463408	19369B	PARTICIPANT	\N	PRESENT	0
465048	463408	19413M	PARTICIPANT	\N	PRESENT	0
465049	463408	19747H	PARTICIPANT	\N	PRESENT	0
465050	463408	08038Y	PARTICIPANT	\N	PRESENT	0
465051	463408	11077T	PARTICIPANT	\N	PRESENT	0
465052	463408	19619A	PARTICIPANT	\N	PRESENT	0
467827	467705	10006L	PARTICIPANT	\N	PRESENT	0
467828	467705	19697Q	PARTICIPANT	\N	PRESENT	0
467829	467705	04092N	PARTICIPANT	0	PRESENT	0
467949	467705	11097X	PRESIDENT	0	PRESENT	0
467950	467705	11045K	PARTICIPANT	\N	PRESENT	0
467951	467705	11031D	PARTICIPANT	\N	PRESENT	0
467957	467705	14217N	PARTICIPANT	\N	PRESENT	0
467958	467705	14026U	PARTICIPANT	\N	PRESENT	0
467959	467705	14071N	PARTICIPANT	\N	PRESENT	0
467960	467705	19691J	PARTICIPANT	\N	PRESENT	0
467961	467705	19569H	PARTICIPANT	\N	PRESENT	0
467962	467705	19553Y	PARTICIPANT	\N	PRESENT	0
468474	468473	19719D	PARTICIPANT	\N	PRESENT	0
468475	468473	14147R	PARTICIPANT	\N	PRESENT	0
482223	481562	01024M	PARTICIPANT	\N	PRESENT	0
482224	481562	14215L	PARTICIPANT	\N	PRESENT	0
482225	481562	08018U	PARTICIPANT	\N	PRESENT	0
482226	481562	19673G	PARTICIPANT	\N	PRESENT	0
482227	481562	05008E	PARTICIPANT	\N	PRESENT	0
482228	481562	19447X	PARTICIPANT	\N	PRESENT	0
482229	481562	11085T	PARTICIPANT	\N	PRESENT	0
482230	481626	19549D	PARTICIPANT	\N	PRESENT	0
482231	481626	08024S	PARTICIPANT	\N	PRESENT	0
482232	481626	14038Y	PARTICIPANT	\N	PRESENT	0
482234	482233	19467C	PARTICIPANT	\N	PRESENT	0
482235	482233	19768N	PARTICIPANT	\N	PRESENT	0
482236	482233	19515S	PARTICIPANT	\N	PRESENT	0
482237	482233	14357A	PARTICIPANT	\N	PRESENT	0
482238	482233	14187A	PARTICIPANT	\N	PRESENT	0
482239	482233	14033T	PARTICIPANT	\N	PRESENT	0
482240	482233	11090Q	PRESIDENT	0	PRESENT	0
482241	482233	04088S	PARTICIPANT	\N	PRESENT	0
482242	482233	14115H	PARTICIPANT	\N	PRESENT	0
482243	482233	04049K	PARTICIPANT	\N	PRESENT	0
482244	482233	19705W	PARTICIPANT	\N	PRESENT	0
482245	482233	11101A	PARTICIPANT	\N	PRESENT	0
482246	482233	19507S	PARTICIPANT	\N	PRESENT	0
482247	482233	08019V	PARTICIPANT	\N	PRESENT	0
482248	482233	19747H	PARTICIPANT	\N	PRESENT	0
482249	482233	04043D	PARTICIPANT	\N	PRESENT	0
482250	482233	14265W	PARTICIPANT	\N	PRESENT	0
482251	482233	14329V	PARTICIPANT	\N	PRESENT	0
482252	482233	19441R	PARTICIPANT	\N	PRESENT	0
482253	482233	19413M	PARTICIPANT	\N	PRESENT	0
482254	482233	80013X	PARTICIPANT	\N	PRESENT	0
482255	482233	19912C	PARTICIPANT	\N	PRESENT	0
482256	482233	19631V	PARTICIPANT	\N	PRESENT	0
467818	467817	95067Q	PARTICIPANT	\N	PRESENT	0
482257	482233	11099A	PARTICIPANT	\N	PRESENT	0
482258	482233	14197C	PARTICIPANT	\N	PRESENT	0
482259	482233	19369B	PARTICIPANT	\N	PRESENT	0
465840	465335	19581D	PARTICIPANT	\N	PRESENT	0
465841	465335	04044E	PARTICIPANT	\N	PRESENT	0
465842	465335	19585H	PARTICIPANT	\N	PRESENT	0
465843	465335	19673G	PARTICIPANT	\N	PRESENT	0
465844	465335	01028R	PARTICIPANT	\N	PRESENT	0
465845	465335	05008E	PRESIDENT	0	PRESENT	0
465846	465335	19489J	PARTICIPANT	\N	PRESENT	0
465847	465335	14147R	PARTICIPANT	\N	PRESENT	0
465848	465335	14179A	PARTICIPANT	\N	PRESENT	0
465849	465335	14151M	PARTICIPANT	\N	PRESENT	0
465850	465335	14215L	PARTICIPANT	\N	PRESENT	0
465851	465335	14259Y	PARTICIPANT	\N	PRESENT	0
465852	465335	14053L	PARTICIPANT	\N	PRESENT	0
465853	465335	19649G	PARTICIPANT	\N	PRESENT	0
465854	465335	14111D	PARTICIPANT	\N	PRESENT	0
465855	465335	11026G	PARTICIPANT	\N	PRESENT	0
465856	465335	10015M	PARTICIPANT	\N	PRESENT	0
465857	465335	19253P	PARTICIPANT	\N	PRESENT	0
465858	465335	01024M	PARTICIPANT	\N	PRESENT	0
465859	465335	11033F	PARTICIPANT	\N	PRESENT	0
465861	465335	19725B	PARTICIPANT	\N	PRESENT	0
465863	465335	95063L	PARTICIPANT	\N	PRESENT	0
465865	465335	08044W	PARTICIPANT	\N	PRESENT	0
465867	465335	14069U	PARTICIPANT	\N	PRESENT	0
465869	465335	11049P	PARTICIPANT	\N	PRESENT	0
465871	465335	04008A	PARTICIPANT	\N	PRESENT	0
467819	467817	14028W	PARTICIPANT	\N	PRESENT	0
482260	482233	19563B	PARTICIPANT	\N	PRESENT	0
482261	482233	19695N	PARTICIPANT	\N	PRESENT	0
482262	482233	01025N	PARTICIPANT	\N	PRESENT	0
482263	482233	14205J	PARTICIPANT	\N	PRESENT	0
482264	482233	11056N	PARTICIPANT	\N	PRESENT	0
482265	482233	14207L	PARTICIPANT	\N	PRESENT	0
482266	482233	19619A	PARTICIPANT	\N	PRESENT	0
482267	481626	19739H	PARTICIPANT	\N	PRESENT	0
482272	482271	04059M	PARTICIPANT	\N	PRESENT	0
482273	482271	14053L	PARTICIPANT	\N	PRESENT	0
482274	482271	11053K	PARTICIPANT	\N	PRESENT	0
482275	482271	11027H	PARTICIPANT	\N	PRESENT	0
482276	482271	04086Q	PARTICIPANT	\N	PRESENT	0
482277	482271	08052W	PARTICIPANT	\N	PRESENT	0
482278	482271	11070L	PARTICIPANT	\N	PRESENT	0
482279	482271	10006L	PARTICIPANT	\N	PRESENT	0
482280	482271	14041T	PARTICIPANT	\N	PRESENT	0
482284	482271	11064N	PARTICIPANT	\N	PRESENT	0
482282	482271	14034U	PARTICIPANT	\N	PRESENT	0
482283	482271	14231L	PARTICIPANT	\N	PRESENT	0
482285	482271	14081Q	PARTICIPANT	\N	PRESENT	0
482286	482271	14061L	PARTICIPANT	\N	PRESENT	0
482287	482271	14159V	PARTICIPANT	\N	PRESENT	0
482288	482271	86034E	PARTICIPANT	\N	PRESENT	0
482289	482271	08034U	PARTICIPANT	\N	PRESENT	0
482290	482271	01043Q	PARTICIPANT	\N	PRESENT	0
482291	482271	12016W	PARTICIPANT	\N	PRESENT	0
482292	482271	11072N	PARTICIPANT	\N	PRESENT	0
482293	482271	05012A	PARTICIPANT	\N	PRESENT	0
482294	482271	14135M	PARTICIPANT	\N	PRESENT	0
482295	482271	04045F	PARTICIPANT	\N	PRESENT	0
482297	482271	04044E	PARTICIPANT	\N	PRESENT	0
482299	481507	19760E	PARTICIPANT	\N	PRESENT	0
482301	481507	19575F	PARTICIPANT	\N	PRESENT	0
482302	481507	19367Y	PARTICIPANT	\N	PRESENT	0
482303	481507	19926J	PARTICIPANT	\N	PRESENT	0
482304	481507	11103C	PARTICIPANT	\N	PRESENT	0
482305	481507	11031D	PARTICIPANT	\N	PRESENT	0
482306	481507	08052W	PARTICIPANT	\N	PRESENT	0
482307	481507	98024R	PARTICIPANT	\N	PRESENT	0
482308	481507	14217N	PARTICIPANT	\N	PRESENT	0
482309	481507	14042U	PARTICIPANT	\N	PRESENT	0
482310	481507	14087W	PARTICIPANT	\N	PRESENT	0
482311	481507	19565D	PARTICIPANT	\N	PRESENT	0
482312	481507	14026U	PARTICIPANT	\N	PRESENT	0
482313	481507	19691J	PARTICIPANT	\N	PRESENT	0
482314	481507	19569H	PARTICIPANT	\N	PRESENT	0
482315	481507	19683J	PARTICIPANT	\N	PRESENT	0
471793	470827	08041T	PARTICIPANT	\N	EXCUSE	0
471952	470888	19798U	PARTICIPANT	\N	PRESENT	0
471953	470890	08049C	PARTICIPANT	\N	PRESENT	0
471954	470890	19335Q	PRESIDENT	0	PRESENT	0
471955	470890	19798U	PARTICIPANT	\N	EXCUSE	0
471956	471173	19515S	PARTICIPANT	\N	PRESENT	0
472202	472200	19503N	PARTICIPANT	\N	PRESENT	0
472205	472203	19503N	PARTICIPANT	\N	PRESENT	0
472208	472206	19503N	PARTICIPANT	\N	PRESENT	0
472211	472209	19503N	PARTICIPANT	\N	PRESENT	0
472215	472213	19503N	PARTICIPANT	\N	PRESENT	0
472218	472216	19503N	PARTICIPANT	\N	PRESENT	0
472221	472219	19503N	PARTICIPANT	\N	PRESENT	0
472224	472222	19503N	PARTICIPANT	\N	PRESENT	0
472227	472225	19503N	PARTICIPANT	\N	PRESENT	0
472230	472228	19503N	PARTICIPANT	\N	PRESENT	0
472233	472231	19503N	PARTICIPANT	\N	PRESENT	0
472236	472234	19503N	PARTICIPANT	\N	PRESENT	0
472239	472237	19503N	PARTICIPANT	\N	PRESENT	0
472242	472240	19503N	PARTICIPANT	\N	PRESENT	0
472245	472243	19503N	PARTICIPANT	\N	PRESENT	0
472248	472246	19503N	PARTICIPANT	\N	PRESENT	0
472251	472249	19503N	PARTICIPANT	\N	PRESENT	0
472254	472252	19503N	PARTICIPANT	\N	PRESENT	0
472680	471957	19768N	PARTICIPANT	\N	PRESENT	0
472681	471957	19515S	PARTICIPANT	\N	PRESENT	0
472682	471957	19782L	PARTICIPANT	\N	PRESENT	0
472683	471957	11077T	PARTICIPANT	\N	PRESENT	0
472684	471957	01043Q	PARTICIPANT	\N	PRESENT	0
472685	471957	14357A	PARTICIPANT	\N	PRESENT	0
472686	471957	19812Y	PARTICIPANT	\N	PRESENT	0
472687	471957	14081Q	PARTICIPANT	\N	PRESENT	0
472688	471957	80013X	PARTICIPANT	\N	PRESENT	0
472689	471957	19631V	PARTICIPANT	\N	PRESENT	0
472690	471957	11099A	PARTICIPANT	\N	PRESENT	0
472691	471957	08068F	PARTICIPANT	\N	PRESENT	0
472692	471957	08015R	PARTICIPANT	\N	PRESENT	0
472693	471957	14197C	PARTICIPANT	\N	PRESENT	0
472694	471957	19369B	PARTICIPANT	\N	PRESENT	0
472695	471957	08028W	PARTICIPANT	\N	PRESENT	0
472696	471957	19563B	PARTICIPANT	\N	PRESENT	0
472697	471957	14265W	PARTICIPANT	\N	PRESENT	0
472698	471957	19467C	PARTICIPANT	\N	PRESENT	0
472699	471957	14187A	PARTICIPANT	\N	PRESENT	0
472700	471957	08038Y	PARTICIPANT	\N	PRESENT	0
472701	471957	19695N	PARTICIPANT	\N	PRESENT	0
472702	471957	11090Q	PRESIDENT	0	PRESENT	0
472703	471957	01025N	PARTICIPANT	\N	PRESENT	0
472704	471957	19269X	PARTICIPANT	\N	PRESENT	0
472705	471957	11056N	PARTICIPANT	\N	PRESENT	0
472706	471957	14115H	PARTICIPANT	\N	PRESENT	0
472707	471957	11101A	PARTICIPANT	\N	PRESENT	0
472708	471957	19507S	PARTICIPANT	\N	PRESENT	0
472709	471957	14207L	PARTICIPANT	\N	PRESENT	0
472710	471957	19747H	PARTICIPANT	\N	PRESENT	0
472711	471957	19619A	PARTICIPANT	\N	PRESENT	0
472712	471957	14135M	PARTICIPANT	\N	EXCUSE	0
472713	471957	04045F	PARTICIPANT	\N	EXCUSE	0
472714	471957	19866P	PARTICIPANT	\N	EXCUSE	0
472715	472057	19649G	PARTICIPANT	\N	PRESENT	0
472716	472057	14111D	PARTICIPANT	\N	PRESENT	0
472717	472057	11026G	PARTICIPANT	\N	PRESENT	0
472718	472057	08045X	PARTICIPANT	\N	PRESENT	0
472719	472057	19253P	PARTICIPANT	\N	PRESENT	0
472720	472057	04047H	PARTICIPANT	\N	PRESENT	0
472721	472057	01028R	PARTICIPANT	\N	PRESENT	0
472722	472057	19447X	PARTICIPANT	\N	PRESENT	0
472723	472057	19489J	PARTICIPANT	\N	PRESENT	0
472724	472057	95063L	PARTICIPANT	\N	PRESENT	0
472725	472057	14147R	PARTICIPANT	\N	PRESENT	0
472726	472057	14179A	PARTICIPANT	\N	PRESENT	0
472727	472057	14069U	PARTICIPANT	\N	PRESENT	0
472728	472057	14151M	PARTICIPANT	\N	PRESENT	0
472729	472057	14215L	PARTICIPANT	\N	PRESENT	0
472730	472057	11085T	PARTICIPANT	\N	PRESENT	0
472731	472057	14021P	PARTICIPANT	\N	PRESENT	0
472732	472057	14053L	PARTICIPANT	\N	PRESENT	0
472826	467273	86034E	PARTICIPANT	\N	PRESENT	0
472827	467273	14159V	PARTICIPANT	\N	PRESENT	0
472828	467273	11027H	PARTICIPANT	\N	PRESENT	0
472829	467273	08045X	PARTICIPANT	\N	PRESENT	0
472830	467273	08055A	PARTICIPANT	\N	PRESENT	0
472831	467273	98029W	PARTICIPANT	\N	PRESENT	0
472832	467273	08061X	PARTICIPANT	\N	PRESENT	0
472833	467273	19525U	PARTICIPANT	\N	PRESENT	0
472834	467273	19631V	PARTICIPANT	\N	PRESENT	0
472835	467273	14081Q	PARTICIPANT	\N	PRESENT	0
472836	467273	19251M	PARTICIPANT	\N	PRESENT	0
472837	467273	08017T	PARTICIPANT	\N	PRESENT	0
472838	467273	19599P	PARTICIPANT	\N	PRESENT	0
472839	467273	19760E	PARTICIPANT	\N	PRESENT	0
472840	467273	19593H	PARTICIPANT	\N	PRESENT	0
472841	467273	04034C	PARTICIPANT	\N	PRESENT	0
472842	467273	19349W	PARTICIPANT	\N	PRESENT	0
472843	467273	05012A	PARTICIPANT	\N	PRESENT	0
472844	467273	08024S	PARTICIPANT	\N	PRESENT	0
472845	467273	04044E	PARTICIPANT	\N	PRESENT	0
472846	467273	19563B	PARTICIPANT	\N	PRESENT	0
472847	467273	19585H	PARTICIPANT	\N	PRESENT	0
472848	467273	14034U	PARTICIPANT	\N	PRESENT	0
472849	467273	14219Q	PARTICIPANT	\N	PRESENT	0
472850	467273	14267Y	PARTICIPANT	\N	PRESENT	0
472851	467273	11080N	PARTICIPANT	\N	PRESENT	0
472852	467273	14231L	PARTICIPANT	\N	PRESENT	0
472853	467273	01057W	PARTICIPANT	\N	PRESENT	0
472854	467273	14251Q	PARTICIPANT	\N	PRESENT	0
472855	467273	11072N	PARTICIPANT	\N	PRESENT	0
472856	467273	11083R	PARTICIPANT	\N	PRESENT	0
472857	467273	08038Y	PARTICIPANT	\N	PRESENT	0
472858	467273	14021P	PARTICIPANT	\N	PRESENT	0
472859	467273	14042U	PARTICIPANT	\N	PRESENT	0
472860	467273	19619A	PARTICIPANT	\N	PRESENT	0
472861	467273	11012A	PARTICIPANT	\N	PRESENT	0
472862	467273	19739H	PARTICIPANT	\N	PRESENT	0
472863	467273	14221J	PARTICIPANT	\N	PRESENT	0
472864	467273	14073Q	PARTICIPANT	\N	PRESENT	0
472865	467273	19553Y	PARTICIPANT	\N	PRESENT	0
472866	467273	04042C	PARTICIPANT	\N	PRESENT	0
472867	467273	14111D	PARTICIPANT	\N	PRESENT	0
472868	467273	14147R	PARTICIPANT	\N	PRESENT	0
472869	467273	14157T	PARTICIPANT	\N	PRESENT	0
472870	467273	14083S	PARTICIPANT	\N	PRESENT	0
472871	467273	04085P	PARTICIPANT	\N	PRESENT	0
472872	467273	14030Q	PARTICIPANT	\N	PRESENT	0
472873	467273	19503N	PARTICIPANT	\N	PRESENT	0
472874	467273	19709B	PARTICIPANT	\N	PRESENT	0
472875	467273	08010L	PARTICIPANT	\N	PRESENT	0
472876	467273	04092N	PARTICIPANT	\N	PRESENT	0
472877	467273	10006L	PARTICIPANT	\N	PRESENT	0
472878	467273	14038Y	PARTICIPANT	\N	PRESENT	0
472879	467273	19747H	PARTICIPANT	\N	PRESENT	0
472880	467273	19685L	PARTICIPANT	\N	PRESENT	0
472881	467273	14053L	PARTICIPANT	\N	PRESENT	0
472882	467273	14357A	PARTICIPANT	\N	PRESENT	0
472883	467273	18083K	PARTICIPANT	\N	PRESENT	0
472884	467273	19253P	PARTICIPANT	\N	PRESENT	0
472885	467273	88008L	PARTICIPANT	\N	PRESENT	0
472886	467273	19723Y	PARTICIPANT	\N	PRESENT	0
472887	467273	04049K	PARTICIPANT	\N	PRESENT	0
472893	467273	19447X	PARTICIPANT	\N	PRESENT	0
472889	467273	08034U	PARTICIPANT	\N	PRESENT	0
472890	467273	14187A	PARTICIPANT	\N	PRESENT	0
472891	467273	10015M	PARTICIPANT	\N	PRESENT	0
472892	467273	01048V	PARTICIPANT	\N	PRESENT	0
472894	467273	04033B	PARTICIPANT	\N	PRESENT	0
472895	467273	11099A	PARTICIPANT	\N	PRESENT	0
472896	467273	14169X	PARTICIPANT	\N	PRESENT	0
472898	467273	19693L	PARTICIPANT	\N	PRESENT	0
472899	467273	14069U	PARTICIPANT	\N	PRESENT	0
472900	467273	14213J	PARTICIPANT	\N	PRESENT	0
455055	445947	08045X	PARTICIPANT	\N	EXCUSE	0
456328	454187	14097Y	PARTICIPANT	\N	PRESENT	0
456329	454187	19421M	PARTICIPANT	\N	PRESENT	0
456330	454187	08056B	PARTICIPANT	\N	PRESENT	0
456331	454187	07004J	PARTICIPANT	\N	EXCUSE	0
456332	454187	10015M	PARTICIPANT	\N	EXCUSE	0
456333	454187	04044E	PARTICIPANT	\N	EXCUSE	0
456334	454190	19269X	PARTICIPANT	\N	PRESENT	0
456335	454190	14213J	PARTICIPANT	\N	PRESENT	0
456336	454190	14265W	PARTICIPANT	\N	PRESENT	0
456337	454190	19369B	PARTICIPANT	\N	EXCUSE	0
456338	454190	19563B	PARTICIPANT	\N	EXCUSE	0
456353	454190	19441R	PARTICIPANT	\N	PRESENT	0
456354	454190	11056N	PARTICIPANT	\N	PRESENT	0
456408	456407	14087W	PARTICIPANT	\N	PRESENT	0
456409	456407	19521Q	PARTICIPANT	\N	PRESENT	0
456410	456407	19679N	PARTICIPANT	\N	PRESENT	0
456411	456406	14087W	PARTICIPANT	\N	PRESENT	0
456412	456406	19679N	PARTICIPANT	\N	PRESENT	0
456415	456413	14042U	PARTICIPANT	\N	PRESENT	0
456416	456413	14227Q	PARTICIPANT	\N	PRESENT	0
456417	456414	14042U	PARTICIPANT	\N	PRESENT	0
456418	456414	11067R	PARTICIPANT	\N	PRESENT	0
456479	448753	19691J	PARTICIPANT	\N	PRESENT	0
456480	448753	14083S	PARTICIPANT	\N	PRESENT	0
456481	448753	14331P	PARTICIPANT	\N	PRESENT	0
456482	448753	14221J	PARTICIPANT	\N	PRESENT	0
456483	448753	11056N	PARTICIPANT	\N	PRESENT	0
456488	448753	11012A	PARTICIPANT	\N	PRESENT	0
456489	448753	12041X	PARTICIPANT	\N	PRESENT	0
456493	448753	19533U	PARTICIPANT	\N	PRESENT	0
456494	448753	01024M	PARTICIPANT	\N	PRESENT	0
456495	448753	11072N	PARTICIPANT	\N	PRESENT	0
456497	448753	14251Q	PARTICIPANT	\N	PRESENT	0
456498	448753	08055A	PARTICIPANT	\N	PRESENT	0
456536	448754	14331P	PARTICIPANT	\N	PRESENT	0
456537	448754	19333N	PARTICIPANT	\N	PRESENT	0
456538	448754	04057K	PARTICIPANT	\N	PRESENT	0
456539	448754	14073Q	PARTICIPANT	\N	PRESENT	0
456540	448754	19691J	PARTICIPANT	\N	PRESENT	0
456541	448754	01024M	PARTICIPANT	\N	PRESENT	0
456542	448754	19533U	PARTICIPANT	\N	PRESENT	0
456543	448754	19693L	PARTICIPANT	\N	PRESENT	0
456545	448754	14157T	PARTICIPANT	\N	PRESENT	0
456546	448754	19794Q	PARTICIPANT	\N	PRESENT	0
456548	448754	19715Y	PARTICIPANT	\N	PRESENT	0
456550	448754	97011G	PARTICIPANT	\N	PRESENT	0
456553	448754	14257W	PARTICIPANT	\N	PRESENT	0
456554	448754	11012A	PARTICIPANT	\N	PRESENT	0
456555	448754	96004D	PARTICIPANT	\N	PRESENT	0
456556	448754	19599P	PARTICIPANT	\N	PRESENT	0
456557	448754	14039A	PARTICIPANT	\N	PRESENT	0
456558	448754	11090Q	PARTICIPANT	\N	PRESENT	0
456559	448754	19399H	PARTICIPANT	\N	PRESENT	0
456560	448754	14083S	PARTICIPANT	\N	PRESENT	0
456561	448754	01058X	PARTICIPANT	\N	PRESENT	0
456562	448754	01048V	PARTICIPANT	\N	PRESENT	0
456563	448754	19709B	PARTICIPANT	\N	PRESENT	0
456564	448754	14093U	PARTICIPANT	\N	PRESENT	0
456565	448754	12041X	PARTICIPANT	\N	PRESENT	0
466566	466564	04040A	PRESIDENT	0	PRESENT	0
466567	466564	11101A	PARTICIPANT	\N	PRESENT	0
466568	466564	14259Y	PARTICIPANT	\N	PRESENT	0
466569	466564	14195A	PARTICIPANT	\N	PRESENT	0
466570	466564	08038Y	PARTICIPANT	\N	PRESENT	0
466571	466564	14281W	PARTICIPANT	\N	PRESENT	0
466572	466564	19820Y	PARTICIPANT	\N	PRESENT	0
466573	466564	19565D	PARTICIPANT	\N	PRESENT	0
456534	448754	04086Q	PARTICIPANT	\N	PRESENT	0
456535	448754	08015R	PARTICIPANT	\N	PRESENT	0
466574	466564	01060R	PARTICIPANT	\N	PRESENT	0
466575	466564	19735D	PARTICIPANT	\N	PRESENT	0
466576	466564	19253P	PARTICIPANT	\N	EXCUSE	0
466577	466564	14327T	PARTICIPANT	\N	EXCUSE	0
466578	466564	14231L	PARTICIPANT	\N	EXCUSE	0
466579	466564	11048N	PARTICIPANT	\N	EXCUSE	0
466580	466564	19687N	PARTICIPANT	\N	EXCUSE	0
466581	466564	04045F	PARTICIPANT	\N	EXCUSE	0
466582	466564	04044E	PARTICIPANT	\N	EXCUSE	0
466585	466584	04047H	PARTICIPANT	\N	PRESENT	0
466586	466584	19719D	PARTICIPANT	\N	PRESENT	0
466587	466584	14215L	PARTICIPANT	\N	PRESENT	0
466588	466584	11033F	PARTICIPANT	\N	PRESENT	0
466589	466584	19649G	PARTICIPANT	\N	PRESENT	0
466593	466592	04086Q	PARTICIPANT	\N	PRESENT	0
466595	466594	04047H	PARTICIPANT	\N	PRESENT	0
466596	466594	14021P	PARTICIPANT	\N	PRESENT	0
466597	466594	19447X	PARTICIPANT	\N	PRESENT	0
467360	466834	97011G	PARTICIPANT	\N	PRESENT	0
481511	480855	07004J	PARTICIPANT	\N	PRESENT	0
481512	480855	19421M	PARTICIPANT	\N	PRESENT	0
481513	480855	10015M	PARTICIPANT	\N	PRESENT	0
481514	480855	11026G	PARTICIPANT	\N	PRESENT	0
481515	480855	04040A	PARTICIPANT	\N	PRESENT	0
481516	480855	08010L	PARTICIPANT	\N	PRESENT	0
481517	480855	19673G	PRESIDENT	0	PRESENT	0
482895	479183	95030B	PARTICIPANT	\N	PRESENT	0
482896	479183	19479G	PARTICIPANT	\N	PRESENT	0
482897	479183	01057W	PARTICIPANT	\N	PRESENT	0
482904	479183	14071N	PARTICIPANT	\N	PRESENT	0
482905	479183	11012A	PARTICIPANT	\N	PRESENT	0
482906	479183	14059S	PARTICIPANT	\N	PRESENT	0
482907	479183	04018C	PARTICIPANT	\N	PRESENT	0
482908	479183	14193X	PARTICIPANT	\N	PRESENT	0
482909	479183	19443T	PARTICIPANT	\N	PRESENT	0
482910	481559	19798U	PARTICIPANT	\N	PRESENT	0
482912	482911	14030Q	PRESIDENT	0	PRESENT	0
482913	482911	19621T	PARTICIPANT	\N	PRESENT	0
482914	482911	08020N	PARTICIPANT	\N	EXCUSE	0
482915	482911	19701S	PARTICIPANT	\N	PRESENT	0
482916	482911	11031D	PARTICIPANT	\N	PRESENT	0
482917	482911	19693L	PARTICIPANT	\N	EXCUSE	0
482918	482911	14179A	PARTICIPANT	\N	PRESENT	0
482919	482911	19731Y	PARTICIPANT	\N	PRESENT	0
482920	482911	07029T	PARTICIPANT	\N	EXCUSE	0
482921	482911	14235Q	PARTICIPANT	\N	EXCUSE	0
482922	482911	19269X	PARTICIPANT	\N	PRESENT	0
482923	482911	11045K	PARTICIPANT	\N	PRESENT	0
482924	482911	19715Y	PARTICIPANT	\N	PRESENT	0
482925	482911	11067R	PARTICIPANT	\N	PRESENT	0
482926	479183	19703U	PARTICIPANT	\N	PRESENT	0
482927	479183	19533U	PARTICIPANT	\N	PRESENT	0
482928	479183	08031R	PARTICIPANT	\N	PRESENT	0
482929	479183	17779H	PARTICIPANT	\N	PRESENT	0
482930	479183	19629C	PARTICIPANT	\N	PRESENT	0
482931	479183	19691J	PARTICIPANT	\N	PRESENT	0
482932	479183	19729F	PARTICIPANT	\N	PRESENT	0
482933	481559	19387D	PARTICIPANT	\N	PRESENT	0
482934	479183	19399H	PARTICIPANT	\N	PRESENT	0
482944	479183	19695N	PARTICIPANT	\N	PRESENT	0
482945	479183	14357A	PARTICIPANT	\N	PRESENT	0
482946	479183	14157T	PARTICIPANT	\N	PRESENT	0
482947	479183	01058X	PARTICIPANT	\N	PRESENT	0
482948	479183	11083R	PARTICIPANT	\N	PRESENT	0
482949	479183	07029T	PARTICIPANT	\N	PRESENT	0
482950	479183	19826F	PARTICIPANT	\N	PRESENT	0
482951	479183	19441R	PARTICIPANT	\N	PRESENT	0
482956	481136	14105F	PARTICIPANT	\N	EXCUSE	0
482957	481136	14255U	PARTICIPANT	\N	PRESENT	0
482958	481136	14053L	PARTICIPANT	\N	PRESENT	0
482959	481136	14083S	PARTICIPANT	\N	PRESENT	0
482960	481136	19545Y	PARTICIPANT	\N	PRESENT	0
482961	481136	14329V	PARTICIPANT	\N	EXCUSE	0
482962	481136	11031D	PARTICIPANT	\N	EXCUSE	0
482963	481136	14079W	PARTICIPANT	\N	EXCUSE	0
482964	481136	14041T	PARTICIPANT	\N	PRESENT	0
482965	481136	14187A	PARTICIPANT	\N	PRESENT	0
482966	481136	14087W	PARTICIPANT	\N	PRESENT	0
482967	481136	19521Q	PARTICIPANT	\N	EXCUSE	0
482968	481136	14034U	PARTICIPANT	\N	PRESENT	0
482969	481136	19695N	PARTICIPANT	\N	EXCUSE	0
482970	481136	14026U	PARTICIPANT	\N	PRESENT	0
482971	481136	19591F	PARTICIPANT	\N	EXCUSE	0
482972	481136	14121F	PARTICIPANT	\N	EXCUSE	0
482973	481136	14039A	PARTICIPANT	\N	EXCUSE	0
482974	481136	14061L	PARTICIPANT	\N	PRESENT	0
482975	481136	11099A	PARTICIPANT	\N	PRESENT	0
482976	481136	04049K	PRESIDENT	0	PRESENT	0
482977	481136	08015R	PARTICIPANT	\N	EXCUSE	0
482978	481136	16685X	PARTICIPANT	\N	PRESENT	0
482979	481136	19697Q	PARTICIPANT	\N	EXCUSE	0
482980	481136	14205J	PARTICIPANT	\N	PRESENT	0
482981	481136	19671E	PARTICIPANT	\N	EXCUSE	0
482982	481136	14265W	PARTICIPANT	\N	EXCUSE	0
482983	481136	08047A	PARTICIPANT	\N	EXCUSE	0
482984	481136	04088S	PARTICIPANT	\N	PRESENT	0
482985	481136	19912C	PARTICIPANT	\N	PRESENT	0
482986	481136	14051J	PARTICIPANT	\N	PRESENT	0
482987	481136	19527W	PARTICIPANT	\N	EXCUSE	0
470236	465629	96004D	PARTICIPANT	\N	PRESENT	0
470265	465629	19741B	PARTICIPANT	\N	PRESENT	0
470238	465629	19651A	PARTICIPANT	\N	PRESENT	0
470266	465629	19667J	PARTICIPANT	\N	PRESENT	0
470240	465629	07029T	PARTICIPANT	\N	PRESENT	0
470241	465629	14021P	PARTICIPANT	\N	PRESENT	0
470267	465629	11040E	PARTICIPANT	\N	PRESENT	0
470243	465629	19531S	PARTICIPANT	\N	PRESENT	0
470244	465629	19551W	PARTICIPANT	\N	PRESENT	0
470245	465629	19591F	PARTICIPANT	\N	PRESENT	0
470268	465629	11053K	PARTICIPANT	\N	PRESENT	0
470269	465629	19545Y	PARTICIPANT	\N	PRESENT	0
470248	465629	08011M	PARTICIPANT	\N	PRESENT	0
470249	465629	11085T	PARTICIPANT	\N	PRESENT	0
470250	465629	14031R	PARTICIPANT	\N	PRESENT	0
470270	465629	14085U	PARTICIPANT	\N	PRESENT	0
470252	465629	19441R	PARTICIPANT	\N	PRESENT	0
470253	465629	08010L	PARTICIPANT	\N	PRESENT	0
470271	465629	04086Q	PARTICIPANT	\N	PRESENT	0
470255	465629	86034E	PARTICIPANT	\N	PRESENT	0
470256	465629	04033B	PARTICIPANT	\N	PRESENT	0
470273	465629	04071H	PARTICIPANT	\N	PRESENT	0
470258	465629	11090Q	PARTICIPANT	\N	PRESENT	0
470259	465629	05012A	PARTICIPANT	\N	PRESENT	0
470260	465629	19533U	PARTICIPANT	\N	PRESENT	0
470261	465629	08061X	PARTICIPANT	\N	PRESENT	0
470262	465629	19573D	PARTICIPANT	\N	PRESENT	0
470274	465629	07033P	PARTICIPANT	\N	PRESENT	0
470275	465629	11110B	PARTICIPANT	\N	PRESENT	0
470276	465629	19647E	PARTICIPANT	\N	PRESENT	0
470277	465629	19695N	PARTICIPANT	\N	PRESENT	0
470278	465629	19691J	PARTICIPANT	\N	PRESENT	0
470279	465629	11048N	PARTICIPANT	\N	PRESENT	0
470280	465629	11099A	PARTICIPANT	\N	PRESENT	0
470282	465629	19699S	PARTICIPANT	\N	PRESENT	0
470283	465629	19563B	PARTICIPANT	\N	PRESENT	0
470284	465629	98050T	PARTICIPANT	\N	PRESENT	0
470285	465629	11045K	PARTICIPANT	\N	PRESENT	0
470286	465629	19687N	PARTICIPANT	\N	PRESENT	0
470287	465629	19479G	PARTICIPANT	\N	PRESENT	0
470288	465630	14229S	PARTICIPANT	\N	PRESENT	0
470289	465630	19762G	PARTICIPANT	\N	PRESENT	0
470290	465630	19713W	PARTICIPANT	\N	PRESENT	0
470291	465630	19689Q	PARTICIPANT	\N	PRESENT	0
470292	465630	19413M	PARTICIPANT	\N	PRESENT	0
470293	465630	14157T	PARTICIPANT	\N	PRESENT	0
470294	465630	04034C	PARTICIPANT	\N	PRESENT	0
470295	465630	96004D	PARTICIPANT	\N	PRESENT	0
470296	465630	11070L	PARTICIPANT	\N	PRESENT	0
470297	465630	19719D	PARTICIPANT	\N	PRESENT	0
470298	465630	11074Q	PARTICIPANT	\N	PRESENT	0
470341	465630	11027H	PARTICIPANT	\N	PRESENT	0
470351	466583	19731Y	PARTICIPANT	\N	EXCUSE	0
470301	465630	19551W	PARTICIPANT	\N	PRESENT	0
470302	465630	19531S	PARTICIPANT	\N	PRESENT	0
470303	465630	14021P	PARTICIPANT	\N	PRESENT	0
470304	465630	07029T	PARTICIPANT	\N	PRESENT	0
470305	465630	19651A	PARTICIPANT	\N	PRESENT	0
470306	465630	19441R	PARTICIPANT	\N	PRESENT	0
470307	465630	14031R	PARTICIPANT	\N	PRESENT	0
470308	465630	11085T	PARTICIPANT	\N	PRESENT	0
470309	465630	08011M	PARTICIPANT	\N	PRESENT	0
470310	465630	19591F	PARTICIPANT	\N	PRESENT	0
470311	465630	19533U	PARTICIPANT	\N	PRESENT	0
470480	469053	18003S	PARTICIPANT	\N	EXCUSE	0
470313	465630	11090Q	PARTICIPANT	\N	PRESENT	0
470314	465630	04033B	PARTICIPANT	\N	PRESENT	0
470315	465630	86034E	PARTICIPANT	\N	PRESENT	0
470316	465630	08010L	PARTICIPANT	\N	PRESENT	0
470317	465630	11053K	PARTICIPANT	\N	PRESENT	0
470342	465630	14034U	PARTICIPANT	\N	PRESENT	0
470319	465630	19667J	PARTICIPANT	\N	PRESENT	0
470320	465630	19741B	PARTICIPANT	\N	PRESENT	0
470321	465630	19573D	PARTICIPANT	\N	PRESENT	0
470347	465630	01028R	PARTICIPANT	\N	PRESENT	0
470323	465630	19647E	PARTICIPANT	\N	PRESENT	0
470344	465630	19649G	PARTICIPANT	\N	PRESENT	0
470325	465630	07033P	PARTICIPANT	\N	PRESENT	0
470326	465630	04071H	PARTICIPANT	\N	PRESENT	0
470327	465630	04086Q	PARTICIPANT	\N	PRESENT	0
470328	465630	14085U	PARTICIPANT	\N	PRESENT	0
470329	465630	19545Y	PARTICIPANT	\N	PRESENT	0
470330	465630	98050T	PARTICIPANT	\N	PRESENT	0
470331	465630	19563B	PARTICIPANT	\N	PRESENT	0
470333	465630	11099A	PARTICIPANT	\N	PRESENT	0
470334	465630	11048N	PARTICIPANT	\N	PRESENT	0
470335	465630	19691J	PARTICIPANT	\N	PRESENT	0
470336	465630	19695N	PARTICIPANT	\N	PRESENT	0
470337	465630	19479G	PARTICIPANT	\N	PRESENT	0
470338	465630	19687N	PARTICIPANT	\N	PRESENT	0
470339	465630	11045K	PARTICIPANT	\N	PRESENT	0
470340	465630	04059M	PARTICIPANT	\N	PRESENT	0
470343	465630	19347U	PARTICIPANT	\N	PRESENT	0
470345	465630	11026G	PARTICIPANT	\N	PRESENT	0
470346	465630	14251Q	PARTICIPANT	\N	PRESENT	0
470590	470589	04047H	PARTICIPANT	\N	PRESENT	0
470591	470589	14021P	PARTICIPANT	\N	PRESENT	0
470592	470589	14147R	PARTICIPANT	\N	PRESENT	0
470593	470589	19581D	PARTICIPANT	\N	PRESENT	0
470594	470589	14215L	PARTICIPANT	\N	PRESENT	0
470627	470626	14042U	PARTICIPANT	\N	PRESENT	0
470629	470628	19415P	PARTICIPANT	\N	PRESENT	0
470630	470628	14042U	PARTICIPANT	\N	PRESENT	0
470632	470631	14042U	PARTICIPANT	\N	PRESENT	0
470633	470631	19569H	PARTICIPANT	\N	PRESENT	0
470634	470631	19657G	PARTICIPANT	\N	PRESENT	0
470635	468895	19367Y	PARTICIPANT	\N	PRESENT	0
470636	468895	19760E	PARTICIPANT	\N	PRESENT	0
470637	468895	19717B	PARTICIPANT	\N	PRESENT	0
470638	468895	19575F	PARTICIPANT	\N	PRESENT	0
470639	468895	19415P	PARTICIPANT	\N	PRESENT	0
470640	468895	11103C	PARTICIPANT	\N	PRESENT	0
470641	468895	19727D	PARTICIPANT	\N	PRESENT	0
470642	468895	11031D	PARTICIPANT	\N	PRESENT	0
470643	468895	08052W	PARTICIPANT	\N	PRESENT	0
470644	468895	19663E	PARTICIPANT	\N	PRESENT	0
470645	468895	10006L	PARTICIPANT	\N	PRESENT	0
470646	468895	14217N	PARTICIPANT	\N	PRESENT	0
470647	468895	19577H	PARTICIPANT	\N	PRESENT	0
470648	468895	14042U	PARTICIPANT	\N	PRESENT	0
470649	468895	14281W	PARTICIPANT	\N	PRESENT	0
470650	468895	14087W	PARTICIPANT	\N	PRESENT	0
470651	468895	19521Q	PARTICIPANT	\N	PRESENT	0
470652	468895	08048B	PARTICIPANT	\N	PRESENT	0
470653	468895	19565D	PARTICIPANT	\N	PRESENT	0
470654	468895	19691J	PARTICIPANT	\N	PRESENT	0
470655	468895	19569H	PARTICIPANT	\N	PRESENT	0
470656	468895	19591F	PARTICIPANT	\N	PRESENT	0
470657	468895	14213J	PARTICIPANT	\N	PRESENT	0
470658	468895	19715Y	PARTICIPANT	\N	PRESENT	0
470659	468895	19723Y	PARTICIPANT	\N	PRESENT	0
470660	468895	19697Q	PARTICIPANT	\N	PRESENT	0
470661	468895	17779H	PARTICIPANT	\N	PRESENT	0
470662	468895	19657G	PARTICIPANT	\N	PRESENT	0
470663	468895	11067R	PARTICIPANT	\N	PRESENT	0
470664	468895	14223L	PARTICIPANT	\N	PRESENT	0
470665	468895	14119M	PARTICIPANT	\N	PRESENT	0
470666	468895	14071N	PARTICIPANT	\N	PRESENT	0
470667	468895	19679N	PARTICIPANT	\N	PRESENT	0
470668	468895	19798U	PARTICIPANT	\N	PRESENT	0
470669	468895	11097X	PARTICIPANT	\N	PRESENT	0
470670	468895	19703U	PARTICIPANT	\N	PRESENT	0
470671	468895	19301E	PARTICIPANT	\N	PRESENT	0
470672	468895	14227Q	PARTICIPANT	\N	PRESENT	0
470673	468895	04092N	PRESIDENT	0	PRESENT	0
470681	470674	19515S	PARTICIPANT	\N	PRESENT	0
470682	470674	14329V	PARTICIPANT	\N	PRESENT	0
470683	470674	19695N	PARTICIPANT	\N	PRESENT	0
470684	470674	04049K	PARTICIPANT	\N	PRESENT	0
470685	470675	19515S	PARTICIPANT	\N	PRESENT	0
470686	470675	14115H	PARTICIPANT	\N	PRESENT	0
470687	470675	14329V	PARTICIPANT	\N	PRESENT	0
470688	470675	19467C	PARTICIPANT	\N	PRESENT	0
470689	470675	19695N	PARTICIPANT	\N	PRESENT	0
470690	470675	11099A	PARTICIPANT	\N	PRESENT	0
470691	470675	04049K	PARTICIPANT	\N	PRESENT	0
470692	470675	04045F	PARTICIPANT	\N	PRESENT	0
470693	470676	19515S	PARTICIPANT	\N	PRESENT	0
470694	470676	14329V	PARTICIPANT	\N	PRESENT	0
470695	470676	19695N	PARTICIPANT	\N	PRESENT	0
470696	470676	04049K	PARTICIPANT	\N	PRESENT	0
470697	470677	19515S	PARTICIPANT	\N	PRESENT	0
470698	470677	14329V	PARTICIPANT	\N	PRESENT	0
470699	470677	19695N	PARTICIPANT	\N	PRESENT	0
470700	470677	04049K	PARTICIPANT	\N	PRESENT	0
470701	470677	14205J	PARTICIPANT	\N	PRESENT	0
470702	470677	19369B	PARTICIPANT	\N	PRESENT	0
470703	470677	14257W	PARTICIPANT	\N	PRESENT	0
457507	457451	19521Q	PARTICIPANT	\N	PRESENT	0
457508	457451	04097T	PARTICIPANT	\N	PRESENT	0
457509	457451	01048V	PARTICIPANT	\N	PRESENT	0
457510	457451	05012A	PARTICIPANT	\N	PRESENT	0
457511	457451	19503N	PARTICIPANT	\N	PRESENT	0
457512	457451	19766L	PARTICIPANT	\N	PRESENT	0
457513	457451	19669L	PARTICIPANT	\N	PRESENT	0
457514	457451	95067Q	PARTICIPANT	\N	PRESENT	0
457515	457451	19711U	PARTICIPANT	\N	PRESENT	0
471468	471467	11090Q	PRESIDENT	0	PRESENT	0
457523	456710	19447X	PARTICIPANT	\N	PRESENT	0
471031	471030	19447X	PARTICIPANT	\N	PRESENT	0
477391	476792	19551W	PARTICIPANT	\N	PRESENT	0
479221	477714	19421M	PARTICIPANT	\N	PRESENT	0
482316	481507	01034P	PARTICIPANT	\N	PRESENT	0
482317	481562	08045X	PARTICIPANT	\N	PRESENT	0
482318	481562	19762G	PARTICIPANT	\N	PRESENT	0
482319	481562	19581D	PARTICIPANT	\N	EXCUSE	0
482320	481562	11026G	PARTICIPANT	\N	PRESENT	0
482321	481562	01028R	PARTICIPANT	\N	PRESENT	0
482333	481530	08049C	PARTICIPANT	\N	PRESENT	0
482334	481530	19335Q	PARTICIPANT	\N	PRESENT	0
482337	481553	08049C	PARTICIPANT	\N	PRESENT	0
482338	481553	19335Q	PARTICIPANT	\N	PRESENT	0
482339	481553	19575F	PARTICIPANT	\N	PRESENT	0
482341	481559	19335Q	PARTICIPANT	\N	PRESENT	0
482343	481560	08049C	PARTICIPANT	\N	PRESENT	0
482344	481560	19335Q	PARTICIPANT	\N	PRESENT	0
482346	482345	08049C	PARTICIPANT	\N	PRESENT	0
482347	482345	19335Q	PRESIDENT	0	PRESENT	0
482464	479258	86034E	PARTICIPANT	\N	PRESENT	0
482467	479258	19826F	PARTICIPANT	\N	PRESENT	0
482470	479258	08052W	PARTICIPANT	\N	PRESENT	0
482471	479258	14173T	PARTICIPANT	\N	PRESENT	0
482472	479258	19731Y	PARTICIPANT	\N	PRESENT	0
482474	479258	19711U	PARTICIPANT	\N	PRESENT	0
482477	479258	19737F	PARTICIPANT	\N	PRESENT	0
482478	479258	19479G	PARTICIPANT	\N	PRESENT	0
482479	479258	19762G	PARTICIPANT	\N	PRESENT	0
482480	479258	92040Q	PARTICIPANT	\N	PRESENT	0
482481	479258	19766L	PARTICIPANT	\N	PRESENT	0
482482	479258	19866P	PARTICIPANT	\N	PRESENT	0
482483	479258	14041T	PARTICIPANT	\N	PRESENT	0
482486	479258	14063N	PARTICIPANT	\N	PRESENT	0
482487	479258	11085T	PARTICIPANT	\N	PRESENT	0
482488	479258	01025N	PARTICIPANT	\N	PRESENT	0
482489	479258	19413M	PARTICIPANT	\N	PRESENT	0
482490	479258	11045K	PARTICIPANT	\N	PRESENT	0
482491	479258	19926J	PARTICIPANT	\N	PRESENT	0
457505	457451	14079W	PARTICIPANT	\N	PRESENT	0
457506	457451	95030B	PARTICIPANT	\N	PRESENT	0
482492	479258	19683J	PARTICIPANT	\N	PRESENT	0
482493	479258	19912C	PARTICIPANT	\N	PRESENT	0
482495	479258	01028R	PARTICIPANT	\N	PRESENT	0
482496	479258	11066Q	PARTICIPANT	\N	PRESENT	0
482498	479258	19599P	PARTICIPANT	\N	PRESENT	0
482500	479258	95037J	PARTICIPANT	\N	PRESENT	0
482501	479258	19611R	PARTICIPANT	\N	PRESENT	0
482502	479258	19593H	PARTICIPANT	\N	PRESENT	0
482503	479258	19820Y	PARTICIPANT	\N	PRESENT	0
482504	479258	08053X	PARTICIPANT	\N	PRESENT	0
482505	479258	11067R	PARTICIPANT	\N	PRESENT	0
482507	479258	08012N	PARTICIPANT	\N	PRESENT	0
482508	479258	19333N	PARTICIPANT	\N	PRESENT	0
482509	479258	11012A	PARTICIPANT	\N	PRESENT	0
482510	479258	19758L	PARTICIPANT	\N	PRESENT	0
482511	479258	08024S	PARTICIPANT	\N	PRESENT	0
482512	479258	11070L	PARTICIPANT	\N	PRESENT	0
482513	479258	19691J	PARTICIPANT	\N	PRESENT	0
482514	479258	19441R	PARTICIPANT	\N	PRESENT	0
482515	479258	14030Q	PARTICIPANT	\N	PRESENT	0
482516	479258	04040A	PARTICIPANT	\N	PRESENT	0
482517	479258	14211G	PARTICIPANT	\N	PRESENT	0
482518	479258	12041X	PARTICIPANT	\N	PRESENT	0
482519	479258	98024R	PARTICIPANT	\N	PRESENT	0
482520	479258	19347U	PARTICIPANT	\N	PRESENT	0
482521	479258	04085P	PARTICIPANT	\N	PRESENT	0
482522	479258	19695N	PARTICIPANT	\N	PRESENT	0
482523	479258	08011M	PARTICIPANT	\N	PRESENT	0
482524	479258	11031D	PARTICIPANT	\N	PRESENT	0
482525	479258	19760E	PARTICIPANT	\N	PRESENT	0
482526	479258	99004R	PARTICIPANT	\N	PRESENT	0
482527	479258	19687N	PARTICIPANT	\N	PRESENT	0
482528	479258	95030B	PARTICIPANT	\N	PRESENT	0
482529	479258	14026U	PARTICIPANT	\N	PRESENT	0
482530	479258	04092N	PARTICIPANT	\N	PRESENT	0
482531	479258	19697Q	PARTICIPANT	\N	PRESENT	0
482532	479258	19591F	PARTICIPANT	\N	PRESENT	0
482533	479258	04086Q	PARTICIPANT	\N	PRESENT	0
482534	479258	11083R	PARTICIPANT	\N	PRESENT	0
482535	479258	08010L	PARTICIPANT	\N	PRESENT	0
482536	479258	95063L	PARTICIPANT	\N	PRESENT	0
482537	479258	08020N	PARTICIPANT	\N	PRESENT	0
482538	479258	08061X	PARTICIPANT	\N	PRESENT	0
482539	479258	08039A	PARTICIPANT	\N	PRESENT	0
482540	479258	04097T	PARTICIPANT	\N	PRESENT	0
482541	479258	15447F	PARTICIPANT	\N	PRESENT	0
482542	479258	19651A	PARTICIPANT	\N	PRESENT	0
482543	479258	04071H	PARTICIPANT	\N	PRESENT	0
482544	479258	19301E	PARTICIPANT	\N	PRESENT	0
482545	479258	10015M	PARTICIPANT	\N	PRESENT	0
482546	479258	11072N	PARTICIPANT	\N	PRESENT	0
482547	479258	05012A	PARTICIPANT	\N	PRESENT	0
482548	479258	04033B	PARTICIPANT	\N	PRESENT	0
482549	479258	04057K	PARTICIPANT	\N	PRESENT	0
482550	479258	14195A	PARTICIPANT	\N	PRESENT	0
482551	479258	14093U	PARTICIPANT	\N	PRESENT	0
482552	479258	14187A	PARTICIPANT	\N	PRESENT	0
482553	479258	11097X	PARTICIPANT	\N	PRESENT	0
482554	479258	08031R	PARTICIPANT	\N	PRESENT	0
482555	479258	88008L	PARTICIPANT	\N	PRESENT	0
482556	479258	14215L	PARTICIPANT	\N	PRESENT	0
482557	479258	08049C	PARTICIPANT	\N	PRESENT	0
482558	479258	14053L	PARTICIPANT	\N	PRESENT	0
482559	479258	11065P	PARTICIPANT	\N	PRESENT	0
482560	479258	04044E	PARTICIPANT	\N	PRESENT	0
482561	479258	04043D	PARTICIPANT	\N	PRESENT	0
482562	479258	11090Q	PARTICIPANT	\N	PRESENT	0
482563	479258	19629C	PARTICIPANT	\N	PRESENT	0
482564	479258	87003B	PARTICIPANT	\N	PRESENT	0
482565	479258	14034U	PARTICIPANT	\N	PRESENT	0
482566	479258	11080N	PARTICIPANT	\N	PRESENT	0
482567	479258	19563B	PARTICIPANT	\N	PRESENT	0
482568	479258	19515S	PARTICIPANT	\N	PRESENT	0
482569	479258	19703U	PARTICIPANT	\N	PRESENT	0
482570	479258	14031R	PARTICIPANT	\N	PRESENT	0
482571	479258	11033F	PARTICIPANT	\N	PRESENT	0
482572	479258	19673G	PARTICIPANT	\N	PRESENT	0
482573	479258	19667J	PARTICIPANT	\N	PRESENT	0
482574	479258	19914E	PARTICIPANT	\N	PRESENT	0
482575	479258	19930E	PARTICIPANT	\N	PRESENT	0
482576	479258	19575F	PARTICIPANT	\N	PRESENT	0
482577	479258	11048N	PARTICIPANT	\N	PRESENT	0
482578	479258	04049K	PARTICIPANT	\N	PRESENT	0
482579	479258	19565D	PARTICIPANT	\N	PRESENT	0
482580	479258	19533U	PARTICIPANT	\N	PRESENT	0
482581	479258	10006L	PARTICIPANT	\N	PRESENT	0
482582	479258	14205J	PARTICIPANT	\N	PRESENT	0
482583	479258	14219Q	PARTICIPANT	\N	PRESENT	0
482584	479258	14193X	PARTICIPANT	\N	PRESENT	0
482585	479258	01034P	PARTICIPANT	\N	PRESENT	0
482586	479258	14255U	PARTICIPANT	\N	PRESENT	0
482587	479258	14083S	PARTICIPANT	\N	PRESENT	0
482588	479258	16685X	PARTICIPANT	\N	PRESENT	0
482589	479258	19369B	PARTICIPANT	\N	PRESENT	0
482590	479258	19569H	PARTICIPANT	\N	PRESENT	0
482591	479258	04069P	PARTICIPANT	\N	PRESENT	0
482592	479258	14217N	PARTICIPANT	\N	PRESENT	0
482593	479258	04070G	PARTICIPANT	\N	PRESENT	0
482594	479258	11103C	PARTICIPANT	\N	PRESENT	0
482595	479258	14147R	PARTICIPANT	\N	PRESENT	0
482596	479258	01043Q	PARTICIPANT	\N	PRESENT	0
482597	479258	14115H	PARTICIPANT	\N	PRESENT	0
482598	479258	14119M	PARTICIPANT	\N	PRESENT	0
482599	479258	14042U	PARTICIPANT	\N	PRESENT	0
482600	479258	04059M	PARTICIPANT	\N	PRESENT	0
482601	479258	19503N	PARTICIPANT	\N	PRESENT	0
482602	479258	14227Q	PARTICIPANT	\N	PRESENT	0
482603	479258	19549D	PARTICIPANT	\N	PRESENT	0
482604	479258	11099A	PARTICIPANT	\N	PRESENT	0
482605	479258	19253P	PARTICIPANT	\N	PRESENT	0
482606	479258	97011G	PARTICIPANT	\N	PRESENT	0
482607	479258	14097Y	PARTICIPANT	\N	PRESENT	0
482608	479258	19713W	PARTICIPANT	\N	PRESENT	0
482609	479258	14081Q	PARTICIPANT	\N	PRESENT	0
482610	479258	14357A	PARTICIPANT	\N	PRESENT	0
482611	479258	08045X	PARTICIPANT	\N	PRESENT	0
472901	467273	14193X	PARTICIPANT	\N	PRESENT	0
472902	467273	89017R	PARTICIPANT	\N	PRESENT	0
472903	467273	08009T	PARTICIPANT	\N	PRESENT	0
472904	467273	87003B	PARTICIPANT	\N	PRESENT	0
472905	467273	14249W	PARTICIPANT	\N	PRESENT	0
472906	467273	08053X	PARTICIPANT	\N	PRESENT	0
472907	467273	19533U	PARTICIPANT	\N	PRESENT	0
472967	467274	88008L	PARTICIPANT	\N	PRESENT	0
472968	467274	11083R	PARTICIPANT	\N	PRESENT	0
472969	467274	14055N	PARTICIPANT	\N	PRESENT	0
472970	467274	04085P	PARTICIPANT	\N	PRESENT	0
472971	467274	04057K	PARTICIPANT	\N	PRESENT	0
472972	467274	19619A	PARTICIPANT	\N	PRESENT	0
472973	467274	14038Y	PARTICIPANT	\N	PRESENT	0
472974	467274	19631V	PARTICIPANT	\N	PRESENT	0
472975	467274	19335Q	PARTICIPANT	\N	PRESENT	0
472976	467274	04049K	PARTICIPANT	\N	PRESENT	0
472977	467274	19333N	PARTICIPANT	\N	PRESENT	0
472978	467274	18083K	PARTICIPANT	\N	PRESENT	0
472979	467274	11045K	PARTICIPANT	\N	PRESENT	0
472980	467274	19503N	PARTICIPANT	\N	PRESENT	0
472981	467274	19349W	PARTICIPANT	\N	PRESENT	0
472982	467274	19820Y	PARTICIPANT	\N	PRESENT	0
472983	467274	01058X	PARTICIPANT	\N	PRESENT	0
472984	467274	14147R	PARTICIPANT	\N	PRESENT	0
472985	467274	19533U	PARTICIPANT	\N	PRESENT	0
472988	467274	19593H	PARTICIPANT	\N	PRESENT	0
472989	467274	01057W	PARTICIPANT	\N	PRESENT	0
472995	467274	19585H	PARTICIPANT	\N	PRESENT	0
472997	467274	14187A	PARTICIPANT	\N	PRESENT	0
473006	467274	01048V	PARTICIPANT	\N	PRESENT	0
473008	467274	11012A	PARTICIPANT	\N	PRESENT	0
473009	467274	19760E	PARTICIPANT	\N	PRESENT	0
473010	467274	19687N	PARTICIPANT	\N	PRESENT	0
473014	467274	19599P	PARTICIPANT	\N	PRESENT	0
473017	467274	19651A	PARTICIPANT	\N	PRESENT	0
473022	467274	11099A	PARTICIPANT	\N	PRESENT	0
473025	467274	19413M	PARTICIPANT	\N	PRESENT	0
473026	467274	14193X	PARTICIPANT	\N	PRESENT	0
473027	467274	01028R	PARTICIPANT	\N	PRESENT	0
473028	467274	14213J	PARTICIPANT	\N	PRESENT	0
473030	467274	14083S	PARTICIPANT	\N	PRESENT	0
473031	467274	14069U	PARTICIPANT	\N	PRESENT	0
473032	467274	14219Q	PARTICIPANT	\N	PRESENT	0
473033	467274	04092N	PARTICIPANT	\N	PRESENT	0
473034	467274	14157T	PARTICIPANT	\N	PRESENT	0
473035	472049	12041X	PARTICIPANT	\N	PRESENT	0
473036	472049	19709B	PARTICIPANT	\N	PRESENT	0
473037	472049	01058X	PARTICIPANT	\N	PRESENT	0
473038	472049	14267Y	PRESIDENT	1	PRESENT	0
473039	472049	14193X	PARTICIPANT	\N	PRESENT	0
473040	472049	11027H	PARTICIPANT	\N	PRESENT	0
473041	472049	04042C	PRESIDENT	0	PRESENT	0
473042	472049	08053X	PARTICIPANT	\N	PRESENT	0
473043	472049	98029W	PARTICIPANT	\N	PRESENT	0
473044	467274	96004D	PARTICIPANT	\N	PRESENT	0
473045	472049	19443T	PARTICIPANT	\N	PRESENT	0
473046	472049	95030B	PARTICIPANT	\N	PRESENT	0
473047	472049	04034C	PARTICIPANT	\N	PRESENT	0
473048	472049	04040A	PARTICIPANT	\N	PRESENT	0
473049	472049	16685X	PARTICIPANT	\N	PRESENT	0
473050	472049	11054L	PARTICIPANT	\N	PRESENT	0
473051	472049	11066Q	PARTICIPANT	\N	PRESENT	0
473052	472049	08056B	PARTICIPANT	\N	PRESENT	0
472965	467274	11072N	PARTICIPANT	\N	PRESENT	0
472966	467274	14205J	PARTICIPANT	\N	PRESENT	0
473053	472049	95037J	PARTICIPANT	\N	PRESENT	0
473054	472049	19421M	PARTICIPANT	\N	PRESENT	0
473055	472049	08049C	PARTICIPANT	\N	PRESENT	0
473056	472049	97011G	PARTICIPANT	\N	PRESENT	0
473057	472049	08047A	PARTICIPANT	\N	PRESENT	0
473058	472049	95067Q	PARTICIPANT	\N	PRESENT	0
473059	472049	14133K	PARTICIPANT	\N	PRESENT	0
473060	472049	01062T	PARTICIPANT	\N	PRESENT	0
473061	472049	11041F	PARTICIPANT	\N	PRESENT	0
473062	472049	14235Q	PARTICIPANT	\N	PRESENT	0
473063	472049	08058D	PARTICIPANT	\N	PRESENT	0
473064	472049	14028W	PARTICIPANT	\N	PRESENT	0
473065	472049	98018T	PARTICIPANT	\N	PRESENT	0
473066	472049	98022P	PARTICIPANT	\N	PRESENT	0
473067	472049	11064N	PARTICIPANT	\N	PRESENT	0
473068	472049	98050T	PARTICIPANT	\N	PRESENT	0
473069	472049	19583F	PARTICIPANT	\N	PRESENT	0
473070	472049	14255U	PARTICIPANT	\N	PRESENT	0
473072	467274	01043Q	PARTICIPANT	\N	PRESENT	0
473109	470440	19820Y	PARTICIPANT	\N	PRESENT	0
473110	470440	19333N	PARTICIPANT	\N	PRESENT	0
473111	470440	19651A	PARTICIPANT	\N	PRESENT	0
473112	470440	19631V	PARTICIPANT	\N	PRESENT	0
473113	470440	19503N	PARTICIPANT	\N	PRESENT	0
473115	470440	19413M	PARTICIPANT	\N	PRESENT	0
473116	470440	11045K	PARTICIPANT	\N	PRESENT	0
473117	470440	19599P	PARTICIPANT	\N	PRESENT	0
473118	470440	11099A	PARTICIPANT	\N	PRESENT	0
473119	472049	04035D	PARTICIPANT	\N	PRESENT	0
473120	470440	19349W	PARTICIPANT	\N	PRESENT	0
473121	470440	14179A	PARTICIPANT	\N	PRESENT	0
473122	470440	04057K	PARTICIPANT	\N	PRESENT	0
473123	470440	19760E	PARTICIPANT	\N	PRESENT	0
473124	470440	19585H	PARTICIPANT	\N	PRESENT	0
473125	470440	19269X	PARTICIPANT	\N	PRESENT	0
473126	470440	19619A	PARTICIPANT	\N	PRESENT	0
473127	470440	01043Q	PARTICIPANT	\N	PRESENT	0
473128	470440	14219Q	PARTICIPANT	\N	PRESENT	0
473129	470440	14083S	PARTICIPANT	\N	PRESENT	0
473130	470440	01057W	PARTICIPANT	\N	PRESENT	0
473131	470440	14157T	PARTICIPANT	\N	PRESENT	0
473132	470440	04049K	PARTICIPANT	\N	PRESENT	0
473133	470440	14213J	PARTICIPANT	\N	PRESENT	0
473134	470440	18083K	PARTICIPANT	\N	PRESENT	0
473135	470440	11090Q	PARTICIPANT	\N	PRESENT	0
473136	470440	19533U	PARTICIPANT	\N	PRESENT	0
473137	470440	96004D	PARTICIPANT	\N	PRESENT	0
473138	470440	14038Y	PARTICIPANT	\N	PRESENT	0
473139	470440	14055N	PARTICIPANT	\N	PRESENT	0
473140	470440	04085P	PARTICIPANT	\N	PRESENT	0
473141	470440	19563B	PARTICIPANT	\N	PRESENT	0
473170	470440	19441R	PARTICIPANT	\N	PRESENT	0
473171	470440	14357A	PARTICIPANT	\N	PRESENT	0
473107	470440	11072N	PARTICIPANT	\N	PRESENT	0
473108	470440	19695N	PARTICIPANT	\N	PRESENT	0
473172	470440	14193X	PARTICIPANT	\N	PRESENT	0
473173	470440	14030Q	PARTICIPANT	\N	PRESENT	0
473174	470440	11012A	PARTICIPANT	\N	PRESENT	0
473175	470440	19545Y	PARTICIPANT	\N	PRESENT	0
473176	470440	11026G	PARTICIPANT	\N	PRESENT	0
473177	470440	14073Q	PARTICIPANT	\N	PRESENT	0
473218	470441	19349W	PARTICIPANT	\N	PRESENT	0
473219	470441	19525U	PARTICIPANT	\N	PRESENT	0
473220	470441	19697Q	PARTICIPANT	\N	PRESENT	0
473221	470441	14151M	PARTICIPANT	\N	PRESENT	0
473222	470441	19820Y	PARTICIPANT	\N	PRESENT	0
473223	470441	19649G	PARTICIPANT	\N	PRESENT	0
473224	470441	11033F	PARTICIPANT	\N	PRESENT	0
473225	470441	04085P	PARTICIPANT	\N	PRESENT	0
473226	470441	19593H	PARTICIPANT	\N	PRESENT	0
473227	470441	08061X	PARTICIPANT	\N	PRESENT	0
473228	470441	19651A	PARTICIPANT	\N	PRESENT	0
473229	470441	19553Y	PARTICIPANT	\N	PRESENT	0
473230	470441	19545Y	PARTICIPANT	\N	PRESENT	0
473231	470441	19585H	PARTICIPANT	\N	PRESENT	0
473232	470441	11012A	PARTICIPANT	\N	PRESENT	0
473233	470441	14251Q	PARTICIPANT	\N	PRESENT	0
473234	470441	19563B	PARTICIPANT	\N	PRESENT	0
473235	470441	19569H	PARTICIPANT	\N	PRESENT	0
473236	470441	08031R	PARTICIPANT	\N	PRESENT	0
473237	470441	19619A	PARTICIPANT	\N	PRESENT	0
473238	470441	14179A	PARTICIPANT	\N	PRESENT	0
473239	470441	89017R	PARTICIPANT	\N	PRESENT	0
473240	470441	14215L	PARTICIPANT	\N	PRESENT	0
473241	470441	05008E	PARTICIPANT	\N	PRESENT	0
473242	470441	14213J	PARTICIPANT	\N	PRESENT	0
473243	470441	19621T	PARTICIPANT	\N	PRESENT	0
473244	470441	19533U	PARTICIPANT	\N	PRESENT	0
473245	470441	11090Q	PARTICIPANT	\N	PRESENT	0
473246	470441	19709B	PARTICIPANT	\N	PRESENT	0
473207	470441	14034U	PARTICIPANT	\N	PRESENT	0
473217	470441	01028R	PARTICIPANT	\N	PRESENT	0
473247	470441	18083K	PARTICIPANT	\N	PRESENT	0
473248	470441	19447X	PARTICIPANT	\N	PRESENT	0
473249	470441	14038Y	PARTICIPANT	\N	PRESENT	0
473250	470441	04092N	PARTICIPANT	\N	PRESENT	0
473251	470441	14187A	PARTICIPANT	\N	PRESENT	0
473252	470441	14071N	PARTICIPANT	\N	PRESENT	0
473253	470441	86034E	PARTICIPANT	\N	PRESENT	0
473254	470441	11048N	PARTICIPANT	\N	PRESENT	0
473255	470441	19503N	PARTICIPANT	\N	PRESENT	0
473256	470441	19760E	PARTICIPANT	\N	PRESENT	0
454495	445947	19629C	PARTICIPANT	\N	EXCUSE	0
455391	454197	14327T	PARTICIPANT	\N	EXCUSE	0
457400	457399	08069G	PARTICIPANT	\N	PRESENT	0
457401	457399	14199E	PARTICIPANT	\N	PRESENT	0
457402	457399	04038G	PARTICIPANT	\N	PRESENT	0
457408	457406	19251M	PARTICIPANT	\N	PRESENT	0
457409	457406	11085T	PARTICIPANT	\N	PRESENT	0
457410	457406	95067Q	PARTICIPANT	\N	PRESENT	0
457411	457406	14179A	PARTICIPANT	\N	PRESENT	0
459158	456492	04040A	PARTICIPANT	\N	PRESENT	0
459159	456492	19253P	PARTICIPANT	\N	PRESENT	0
459160	456492	14327T	PARTICIPANT	\N	PRESENT	0
459161	456492	01057W	PARTICIPANT	\N	PRESENT	0
459163	456492	05012A	PARTICIPANT	\N	PRESENT	0
459165	456492	14231L	PARTICIPANT	\N	PRESENT	0
459166	456492	14281W	PARTICIPANT	\N	PRESENT	0
459167	456492	08034U	PARTICIPANT	\N	PRESENT	0
459168	456492	14063N	PARTICIPANT	\N	PRESENT	0
459169	456492	08049C	PARTICIPANT	\N	PRESENT	0
467055	467054	96004D	PARTICIPANT	\N	EXCUSE	0
467091	467054	11054L	PARTICIPANT	\N	EXCUSE	0
468706	468368	19319Q	PARTICIPANT	\N	PRESENT	0
470845	467695	08017T	PARTICIPANT	\N	PRESENT	0
470846	467695	19766L	PARTICIPANT	\N	PRESENT	0
482990	476508	19575F	PARTICIPANT	\N	PRESENT	0
482991	476508	14030Q	PARTICIPANT	\N	PRESENT	0
482992	476508	08060W	PARTICIPANT	\N	EXCUSE	0
482993	476508	14105F	PARTICIPANT	\N	PRESENT	0
482994	476508	14255U	PARTICIPANT	\N	PRESENT	0
482995	476508	14053L	PARTICIPANT	\N	EXCUSE	0
482996	476508	14083S	PARTICIPANT	\N	PRESENT	0
482997	476508	19545Y	PARTICIPANT	\N	PRESENT	0
482998	476508	14329V	PARTICIPANT	\N	EXCUSE	0
482999	476508	14041T	PARTICIPANT	\N	PRESENT	0
483000	476508	14187A	PARTICIPANT	\N	EXCUSE	0
483001	476508	19521Q	PARTICIPANT	\N	PRESENT	0
483002	476508	14034U	PARTICIPANT	\N	PRESENT	0
483003	476508	14026U	PARTICIPANT	\N	PRESENT	0
483004	476508	14061L	PARTICIPANT	\N	EXCUSE	0
483005	476508	11099A	PARTICIPANT	\N	PRESENT	0
483006	476508	04049K	PRESIDENT	0	PRESENT	0
483007	476508	08015R	PARTICIPANT	\N	EXCUSE	0
483008	476508	14205J	PARTICIPANT	\N	PRESENT	0
483009	476508	14265W	PARTICIPANT	\N	EXCUSE	0
483010	476508	08047A	PARTICIPANT	\N	EXCUSE	0
483011	476508	19912C	PARTICIPANT	\N	PRESENT	0
483012	476508	14051J	PARTICIPANT	\N	PRESENT	0
483013	479183	19531S	PARTICIPANT	\N	PRESENT	0
483015	483014	05008E	PARTICIPANT	\N	PRESENT	0
483016	483014	10015M	PARTICIPANT	\N	PRESENT	0
483017	483014	19447X	PARTICIPANT	\N	PRESENT	0
483018	483014	01024M	PARTICIPANT	\N	PRESENT	0
483019	483014	01028R	PARTICIPANT	\N	PRESENT	0
483023	483014	11065P	PARTICIPANT	\N	PRESENT	0
483021	483014	19697Q	PARTICIPANT	\N	PRESENT	0
483022	483014	11066Q	PARTICIPANT	\N	PRESENT	0
483027	479183	14034U	PARTICIPANT	\N	PRESENT	0
483025	479183	11072N	PARTICIPANT	\N	PRESENT	0
483026	479183	01024M	PARTICIPANT	\N	PRESENT	0
483028	479183	19503N	PARTICIPANT	\N	PRESENT	0
483048	479186	14034U	PARTICIPANT	\N	PRESENT	0
483049	480873	14259Y	PARTICIPANT	\N	EXCUSE	0
483051	483050	14261S	PARTICIPANT	\N	PRESENT	0
483052	483050	88008L	PARTICIPANT	\N	PRESENT	0
483053	483050	11026G	PARTICIPANT	\N	PRESENT	0
483054	483050	95067Q	PARTICIPANT	\N	PRESENT	0
483055	483050	19253P	PARTICIPANT	\N	PRESENT	0
483059	481565	08049C	PARTICIPANT	\N	PRESENT	0
483060	479186	05008E	PARTICIPANT	\N	PRESENT	0
483061	479186	01028R	PARTICIPANT	\N	PRESENT	0
483062	479186	19333N	PARTICIPANT	\N	PRESENT	0
483063	479186	19629C	PARTICIPANT	\N	PRESENT	0
483064	479186	19585H	PARTICIPANT	\N	PRESENT	0
483065	479186	01024M	PARTICIPANT	\N	PRESENT	0
483066	479186	01058X	PARTICIPANT	\N	PRESENT	0
483067	479186	19673G	PARTICIPANT	\N	PRESENT	0
483068	479186	10015M	PARTICIPANT	\N	PRESENT	0
483069	479186	19651A	PARTICIPANT	\N	PRESENT	0
483070	481127	19335Q	PRESIDENT	0	PRESENT	0
483071	479186	04085P	PARTICIPANT	\N	PRESENT	0
483072	481127	08049C	PARTICIPANT	\N	PRESENT	0
483073	479186	19711U	PARTICIPANT	\N	PRESENT	0
483074	479186	19565D	PARTICIPANT	\N	PRESENT	0
483076	483075	08039A	PARTICIPANT	\N	PRESENT	0
483077	483075	04059M	PARTICIPANT	\N	PRESENT	0
483078	483075	11083R	PARTICIPANT	\N	PRESENT	0
483080	483079	04085P	PARTICIPANT	\N	PRESENT	0
483081	483079	04059M	PARTICIPANT	\N	PRESENT	0
483082	483079	19667J	PARTICIPANT	\N	PRESENT	0
483083	483079	19545Y	PARTICIPANT	\N	EXCUSE	0
483084	483079	11031D	PARTICIPANT	\N	PRESENT	0
483085	483079	19663E	PARTICIPANT	\N	PRESENT	0
483086	483079	10006L	PARTICIPANT	\N	PRESENT	0
483087	483079	14041T	PRESIDENT	0	PRESENT	0
483088	483079	19649G	PARTICIPANT	\N	PRESENT	0
483089	479186	11026G	PARTICIPANT	\N	PRESENT	0
483090	483079	19691J	PARTICIPANT	\N	PRESENT	0
483091	483079	14081Q	PARTICIPANT	\N	PRESENT	0
483093	479186	19914E	PARTICIPANT	\N	PRESENT	0
483092	483079	19553Y	PARTICIPANT	\N	PRESENT	0
483094	483079	19683J	PARTICIPANT	\N	PRESENT	0
483095	483079	19447X	PARTICIPANT	\N	PRESENT	0
483096	483079	99004R	PARTICIPANT	\N	PRESENT	0
483097	483079	19697Q	PARTICIPANT	\N	PRESENT	0
482988	481136	14157T	PARTICIPANT	\N	PRESENT	0
482989	481136	14151M	PARTICIPANT	\N	EXCUSE	0
483098	483079	14251Q	PARTICIPANT	\N	EXCUSE	0
483099	483079	11067R	PARTICIPANT	\N	PRESENT	0
483100	483079	04092N	PRESIDENT	1	PRESENT	0
483102	483079	19503N	PARTICIPANT	\N	PRESENT	0
483103	483079	01034P	PARTICIPANT	\N	EXCUSE	0
483104	483079	19479G	PARTICIPANT	\N	EXCUSE	0
483105	483079	19703U	PARTICIPANT	\N	PRESENT	0
483106	483079	11097X	PARTICIPANT	\N	PRESENT	0
483107	483079	19766L	PARTICIPANT	\N	PRESENT	0
483108	483079	14331P	PARTICIPANT	\N	PRESENT	0
483109	483079	19349W	PARTICIPANT	\N	EXCUSE	0
483110	479186	14215L	PARTICIPANT	\N	PRESENT	0
483113	483111	04040A	PARTICIPANT	\N	PRESENT	0
483114	483111	96004D	PARTICIPANT	\N	PRESENT	0
483115	483111	14255U	PARTICIPANT	\N	PRESENT	0
483116	483112	19531S	PARTICIPANT	\N	PRESENT	0
483117	483111	18083K	PARTICIPANT	\N	PRESENT	0
483118	481127	11104D	PARTICIPANT	\N	PRESENT	0
483119	483111	19333N	PARTICIPANT	\N	PRESENT	0
483120	483111	19826F	PARTICIPANT	\N	PRESENT	0
483121	483111	11064N	PARTICIPANT	\N	PRESENT	0
483122	483111	19585H	PARTICIPANT	\N	PRESENT	0
483123	481127	19798U	PARTICIPANT	\N	PRESENT	0
483124	479244	11070L	PARTICIPANT	\N	PRESENT	0
483125	479244	19551W	PARTICIPANT	\N	PRESENT	0
483126	479186	14041T	PARTICIPANT	\N	PRESENT	0
483127	483047	19768N	PARTICIPANT	\N	PRESENT	0
483128	483047	14331P	PARTICIPANT	\N	PRESENT	0
483129	483047	14357A	PARTICIPANT	\N	PRESENT	0
483130	483047	19441R	PARTICIPANT	\N	PRESENT	0
483131	483047	19912C	PARTICIPANT	\N	PRESENT	0
483132	483047	14026U	PARTICIPANT	\N	PRESENT	0
483133	483047	19631V	PARTICIPANT	\N	PRESENT	0
483134	483047	14237S	PARTICIPANT	\N	PRESENT	0
483135	483047	11099A	PARTICIPANT	\N	PRESENT	0
483136	483047	14241N	PARTICIPANT	\N	PRESENT	0
483137	483047	96004D	PARTICIPANT	\N	PRESENT	0
483138	483047	14197C	PARTICIPANT	\N	PRESENT	0
483139	483047	19563B	PARTICIPANT	\N	PRESENT	0
483140	483047	98035U	PARTICIPANT	\N	PRESENT	0
483141	483047	14135M	PARTICIPANT	\N	PRESENT	0
483142	483047	19467C	PARTICIPANT	\N	PRESENT	0
483143	483047	11026G	PARTICIPANT	\N	PRESENT	0
483144	483047	10015M	PARTICIPANT	\N	PRESENT	0
483145	483047	11090Q	PRESIDENT	0	PRESENT	0
483146	483047	14033T	PARTICIPANT	\N	PRESENT	0
483147	483047	19269X	PARTICIPANT	\N	PRESENT	0
483148	483047	14205J	PARTICIPANT	\N	PRESENT	0
483149	483047	14115H	PARTICIPANT	\N	PRESENT	0
483150	483047	04097T	PARTICIPANT	\N	PRESENT	0
483151	483047	14207L	PARTICIPANT	\N	PRESENT	0
483152	483047	19619A	PARTICIPANT	\N	PRESENT	0
483153	479186	19447X	PARTICIPANT	\N	PRESENT	0
483154	479186	14331P	PARTICIPANT	\N	PRESENT	0
483155	480873	04040A	PRESIDENT	0	PRESENT	0
483159	480873	14231L	PARTICIPANT	\N	PRESENT	0
483157	480873	19253P	PARTICIPANT	\N	PRESENT	0
483158	480873	04086Q	PARTICIPANT	\N	PRESENT	0
483160	480873	19820Y	PARTICIPANT	\N	PRESENT	0
483161	480873	19565D	PARTICIPANT	\N	PRESENT	0
483162	480873	01057W	PARTICIPANT	\N	PRESENT	0
483163	480873	08010L	PARTICIPANT	\N	PRESENT	0
483167	481128	96004D	PRESIDENT	0	PRESENT	0
470704	470677	14265W	PARTICIPANT	\N	PRESENT	0
470705	470677	14033T	PARTICIPANT	\N	PRESENT	0
470706	470678	19515S	PARTICIPANT	\N	PRESENT	0
470707	470678	14357A	PARTICIPANT	\N	PRESENT	0
470708	470678	19695N	PARTICIPANT	\N	PRESENT	0
470709	470678	14329V	PARTICIPANT	\N	PRESENT	0
470710	470678	04049K	PARTICIPANT	\N	PRESENT	0
470711	470679	19515S	PARTICIPANT	\N	PRESENT	0
470712	470679	14329V	PARTICIPANT	\N	PRESENT	0
470713	470679	19695N	PARTICIPANT	\N	PRESENT	0
470714	470679	04049K	PARTICIPANT	\N	PRESENT	0
470715	470680	19515S	PARTICIPANT	\N	PRESENT	0
470716	470680	14329V	PARTICIPANT	\N	PRESENT	0
470717	470680	14357A	PARTICIPANT	\N	PRESENT	0
470718	470680	19695N	PARTICIPANT	\N	PRESENT	0
470719	470680	04049K	PARTICIPANT	\N	PRESENT	0
470720	470680	19369B	PARTICIPANT	\N	PRESENT	0
470722	470721	19515S	PARTICIPANT	\N	PRESENT	0
470723	470721	14329V	PARTICIPANT	\N	PRESENT	0
470724	470721	19695N	PARTICIPANT	\N	PRESENT	0
470725	470721	14357A	PARTICIPANT	\N	PRESENT	0
470726	470721	04049K	PARTICIPANT	\N	PRESENT	0
470727	470721	19563B	PARTICIPANT	\N	PRESENT	0
470728	470721	11090Q	PARTICIPANT	\N	PRESENT	0
470734	470729	19515S	PARTICIPANT	\N	PRESENT	0
470735	470729	14329V	PARTICIPANT	\N	PRESENT	0
470736	470729	14357A	PARTICIPANT	\N	PRESENT	0
470737	470729	19695N	PARTICIPANT	\N	PRESENT	0
470738	470729	04049K	PARTICIPANT	\N	PRESENT	0
470739	470729	11099A	PARTICIPANT	\N	PRESENT	0
470740	470730	19515S	PARTICIPANT	\N	PRESENT	0
470741	470730	19695N	PARTICIPANT	\N	PRESENT	0
470742	470730	14329V	PARTICIPANT	\N	PRESENT	0
470747	470730	19545Y	PARTICIPANT	\N	PRESENT	0
470748	470731	19515S	PARTICIPANT	\N	PRESENT	0
470749	470731	14329V	PARTICIPANT	\N	PRESENT	0
470746	470730	19697Q	PARTICIPANT	\N	PRESENT	0
470750	470731	14357A	PARTICIPANT	\N	PRESENT	0
470751	470731	19695N	PARTICIPANT	\N	PRESENT	0
470752	470731	04049K	PARTICIPANT	\N	PRESENT	0
470753	470731	14265W	PARTICIPANT	\N	PRESENT	0
470754	470731	19697Q	PARTICIPANT	\N	PRESENT	0
470755	470732	19515S	PARTICIPANT	\N	PRESENT	0
470756	470732	14329V	PARTICIPANT	\N	PRESENT	0
470757	470732	19695N	PARTICIPANT	\N	PRESENT	0
470758	470732	14357A	PARTICIPANT	\N	PRESENT	0
470759	470732	04049K	PARTICIPANT	\N	PRESENT	0
470763	470733	19515S	PARTICIPANT	\N	PRESENT	0
470761	470732	19697Q	PARTICIPANT	\N	PRESENT	0
470762	470732	14265W	PARTICIPANT	\N	PRESENT	0
470764	470733	14329V	PARTICIPANT	\N	PRESENT	0
470765	470733	14357A	PARTICIPANT	\N	PRESENT	0
470766	470733	19695N	PARTICIPANT	\N	PRESENT	0
470767	470733	04049K	PARTICIPANT	\N	PRESENT	0
470768	470733	14157T	PARTICIPANT	\N	PRESENT	0
470769	470733	19697Q	PARTICIPANT	\N	PRESENT	0
470771	470770	19515S	PARTICIPANT	\N	PRESENT	0
470772	470770	14329V	PARTICIPANT	\N	PRESENT	0
470773	470770	14357A	PARTICIPANT	\N	PRESENT	0
470774	470770	19695N	PARTICIPANT	\N	PRESENT	0
470775	470770	04049K	PARTICIPANT	\N	PRESENT	0
470776	470770	14157T	PARTICIPANT	\N	PRESENT	0
470777	470770	19697Q	PARTICIPANT	\N	PRESENT	0
470781	470778	19515S	PARTICIPANT	\N	PRESENT	0
470782	470778	19695N	PARTICIPANT	\N	PRESENT	0
470783	470778	14329V	PARTICIPANT	\N	PRESENT	0
470784	470778	04049K	PARTICIPANT	\N	PRESENT	0
470785	470779	19515S	PARTICIPANT	\N	PRESENT	0
470786	470779	14329V	PARTICIPANT	\N	PRESENT	0
470787	470779	19695N	PARTICIPANT	\N	PRESENT	0
470788	470780	19515S	PARTICIPANT	\N	PRESENT	0
470789	470780	14329V	PARTICIPANT	\N	PRESENT	0
470790	470780	19695N	PARTICIPANT	\N	PRESENT	0
470793	470792	01025N	PARTICIPANT	\N	PRESENT	0
470794	470792	14207L	PARTICIPANT	\N	PRESENT	0
470795	470792	14197C	PARTICIPANT	\N	PRESENT	0
470796	470792	14357A	PARTICIPANT	\N	PRESENT	0
470797	470792	19619A	PARTICIPANT	\N	PRESENT	0
470798	468895	19683J	PARTICIPANT	\N	EXCUSE	0
470799	468895	08041T	PARTICIPANT	\N	EXCUSE	0
470818	470814	11097X	PARTICIPANT	\N	PRESENT	0
470819	470814	04092N	PARTICIPANT	\N	PRESENT	0
470820	470814	19679N	PARTICIPANT	\N	PRESENT	0
470821	470814	11031D	PARTICIPANT	\N	PRESENT	0
470822	470814	14227Q	PARTICIPANT	\N	PRESENT	0
470824	470814	17779H	PARTICIPANT	\N	PRESENT	0
470825	470814	14223L	PARTICIPANT	\N	PRESENT	0
470826	470814	19521Q	PARTICIPANT	\N	PRESENT	0
470828	470815	11097X	PARTICIPANT	\N	PRESENT	0
470829	470815	19575F	PARTICIPANT	\N	PRESENT	0
470830	470815	11031D	PARTICIPANT	\N	PRESENT	0
470831	470815	19723Y	PARTICIPANT	\N	PRESENT	0
470832	470815	17779H	PARTICIPANT	\N	PRESENT	0
470833	470815	04092N	PARTICIPANT	\N	PRESENT	0
470837	470816	11097X	PARTICIPANT	\N	PRESENT	0
470835	470815	14227Q	PARTICIPANT	\N	PRESENT	0
470836	470816	17779H	PARTICIPANT	\N	PRESENT	0
470838	470816	19798U	PARTICIPANT	\N	PRESENT	0
470839	470816	14217N	PARTICIPANT	\N	PRESENT	0
470840	470816	11031D	PARTICIPANT	\N	PRESENT	0
470841	470817	17779H	PARTICIPANT	\N	PRESENT	0
470842	470817	11097X	PARTICIPANT	\N	PRESENT	0
470843	470817	19679N	PARTICIPANT	\N	PRESENT	0
470844	470817	14087W	PARTICIPANT	\N	PRESENT	0
470892	470891	14215L	PARTICIPANT	\N	PRESENT	0
470893	470891	19725B	PARTICIPANT	\N	PRESENT	0
470894	470891	19489J	PARTICIPANT	\N	PRESENT	0
470895	470891	04038G	PARTICIPANT	\N	PRESENT	0
470896	470891	14231L	PARTICIPANT	\N	PRESENT	0
470898	470897	14231L	PARTICIPANT	\N	PRESENT	0
470899	470897	04038G	PARTICIPANT	\N	PRESENT	0
470900	470897	14215L	PARTICIPANT	\N	PRESENT	0
470902	470901	14151M	PARTICIPANT	\N	PRESENT	0
470903	470901	14231L	PARTICIPANT	\N	PRESENT	0
470904	470901	04038G	PARTICIPANT	\N	PRESENT	0
470905	470901	19489J	PARTICIPANT	\N	PRESENT	0
470906	470901	14147R	PARTICIPANT	\N	PRESENT	0
470908	470907	04038G	PARTICIPANT	\N	PRESENT	0
470909	470907	14231L	PARTICIPANT	\N	PRESENT	0
470910	470907	14151M	PARTICIPANT	\N	PRESENT	0
470911	470907	19489J	PARTICIPANT	\N	PRESENT	0
470912	470907	14147R	PARTICIPANT	\N	PRESENT	0
470913	470907	95063L	PARTICIPANT	\N	PRESENT	0
470915	470914	04038G	PARTICIPANT	\N	PRESENT	0
470916	470914	14231L	PARTICIPANT	\N	PRESENT	0
470917	470914	14215L	PARTICIPANT	\N	PRESENT	0
470919	470918	04038G	PARTICIPANT	\N	PRESENT	0
470920	470918	14231L	PARTICIPANT	\N	PRESENT	0
470922	470921	04038G	PARTICIPANT	\N	PRESENT	0
470923	470921	14231L	PARTICIPANT	\N	PRESENT	0
470924	470921	14147R	PARTICIPANT	\N	PRESENT	0
470926	470925	04038G	PARTICIPANT	\N	PRESENT	0
470927	470925	14231L	PARTICIPANT	\N	PRESENT	0
470928	470925	14215L	PARTICIPANT	\N	PRESENT	0
470929	470925	19489J	PARTICIPANT	\N	PRESENT	0
470930	470925	14147R	PARTICIPANT	\N	PRESENT	0
470932	470931	14053L	PARTICIPANT	\N	PRESENT	0
470933	470931	04038G	PARTICIPANT	\N	PRESENT	0
470934	470931	14231L	PARTICIPANT	\N	PRESENT	0
470936	470935	14231L	PARTICIPANT	\N	PRESENT	0
470937	470935	19725B	PARTICIPANT	\N	PRESENT	0
470938	470935	04038G	PARTICIPANT	\N	PRESENT	0
470939	470935	14053L	PARTICIPANT	\N	PRESENT	0
470940	470935	11085T	PARTICIPANT	\N	PRESENT	0
470941	470935	14147R	PARTICIPANT	\N	PRESENT	0
470942	470935	95063L	PARTICIPANT	\N	PRESENT	0
470944	470578	14083S	PARTICIPANT	\N	PRESENT	0
470945	470578	14061L	PARTICIPANT	\N	PRESENT	0
470946	470943	19585H	PARTICIPANT	\N	PRESENT	0
470947	470943	95063L	PARTICIPANT	\N	PRESENT	0
470948	470943	19489J	PARTICIPANT	\N	PRESENT	0
470949	470943	14151M	PARTICIPANT	\N	PRESENT	0
470950	470943	04038G	PARTICIPANT	\N	PRESENT	0
470951	470943	14231L	PARTICIPANT	\N	PRESENT	0
471019	471018	04038G	PARTICIPANT	\N	PRESENT	0
471020	471018	14231L	PARTICIPANT	\N	PRESENT	0
471021	471018	95063L	PARTICIPANT	\N	PRESENT	0
471088	471087	19631V	PARTICIPANT	\N	PRESENT	0
471089	471087	80013X	PARTICIPANT	\N	PRESENT	0
471090	471087	14207L	PARTICIPANT	\N	PRESENT	0
471091	471087	08015R	PARTICIPANT	\N	PRESENT	0
471092	471087	19515S	PARTICIPANT	\N	PRESENT	0
471093	471087	04049K	PARTICIPANT	\N	PRESENT	0
471094	471087	14329V	PARTICIPANT	\N	PRESENT	0
471095	471087	19723Y	PARTICIPANT	\N	PRESENT	0
471096	471087	19820Y	PARTICIPANT	\N	PRESENT	0
471097	471087	08024S	PARTICIPANT	\N	PRESENT	0
471098	471087	14105F	PARTICIPANT	\N	PRESENT	0
456290	456289	14041T	PARTICIPANT	\N	PRESENT	0
457144	457143	19703U	PARTICIPANT	\N	PRESENT	0
457146	457145	19703U	PARTICIPANT	\N	PRESENT	0
460823	460822	19575F	PARTICIPANT	\N	PRESENT	0
460824	460822	14205J	PARTICIPANT	\N	PRESENT	0
460825	460822	14034U	PARTICIPANT	\N	PRESENT	0
460826	460822	19723Y	PARTICIPANT	\N	PRESENT	0
460827	460822	19563B	PARTICIPANT	\N	PRESENT	0
460828	460822	19533U	PARTICIPANT	\N	PRESENT	0
460829	460822	17583W	PARTICIPANT	\N	PRESENT	0
460830	460822	11043H	PARTICIPANT	\N	PRESENT	0
460831	460822	19713W	PARTICIPANT	\N	PRESENT	0
460832	460822	95067Q	PARTICIPANT	\N	PRESENT	0
460835	460834	14207L	PARTICIPANT	\N	PRESENT	0
460836	460834	01025N	PARTICIPANT	\N	PRESENT	0
460837	460834	14135M	PARTICIPANT	\N	PRESENT	0
460838	460834	04088S	PARTICIPANT	\N	PRESENT	0
460839	460834	19441R	PARTICIPANT	\N	PRESENT	0
460840	460834	14115H	PARTICIPANT	\N	PRESENT	0
460841	460834	19269X	PARTICIPANT	\N	PRESENT	0
460842	460834	19413M	PARTICIPANT	\N	PRESENT	0
460843	460834	19507S	PARTICIPANT	\N	PRESENT	0
460845	460844	14207L	PARTICIPANT	\N	PRESENT	0
460846	460844	01025N	PARTICIPANT	\N	PRESENT	0
460847	460844	14115H	PARTICIPANT	\N	PRESENT	0
460848	460844	19507S	PARTICIPANT	\N	PRESENT	0
460849	460844	04088S	PARTICIPANT	\N	PRESENT	0
460850	460844	19269X	PARTICIPANT	\N	PRESENT	0
460851	460844	19413M	PARTICIPANT	\N	PRESENT	0
460852	460844	14135M	PARTICIPANT	\N	PRESENT	0
461885	461880	11054L	PARTICIPANT	\N	PRESENT	0
461886	461880	11026G	PARTICIPANT	\N	PRESENT	0
461887	461880	14179A	PARTICIPANT	\N	PRESENT	0
461889	461880	95067Q	PARTICIPANT	\N	PRESENT	0
461892	461880	01062T	PARTICIPANT	\N	PRESENT	0
461894	461880	04040A	PARTICIPANT	\N	PRESENT	0
466322	466320	17637T	PARTICIPANT	\N	PRESENT	0
466323	466320	19347U	PARTICIPANT	\N	PRESENT	0
466324	466320	19551W	PARTICIPANT	\N	PRESENT	0
466325	466320	02002K	PARTICIPANT	\N	PRESENT	0
466326	466320	08009T	PRESIDENT	0	PRESENT	0
466327	466320	04085P	PARTICIPANT	\N	PRESENT	0
466328	466320	19733B	PARTICIPANT	\N	PRESENT	0
466329	466320	14169X	PARTICIPANT	\N	PRESENT	0
466330	466320	19289C	PARTICIPANT	\N	PRESENT	0
466331	466320	08055A	PARTICIPANT	\N	PRESENT	0
466332	466320	19681G	PARTICIPANT	\N	PRESENT	0
466333	466320	19549D	PARTICIPANT	\N	PRESENT	0
466334	466320	18083K	PARTICIPANT	\N	PRESENT	0
466335	466320	19701S	PARTICIPANT	\N	PRESENT	0
466336	466320	14031R	PARTICIPANT	\N	PRESENT	0
466337	466320	11065P	PARTICIPANT	\N	PRESENT	0
466338	466320	14237S	PARTICIPANT	\N	PRESENT	0
466339	466320	14038Y	PARTICIPANT	\N	PRESENT	0
466340	466320	19503N	PARTICIPANT	\N	PRESENT	0
466341	466320	19387D	PARTICIPANT	\N	PRESENT	0
466342	466320	19820Y	PARTICIPANT	\N	PRESENT	0
466343	466320	19826F	PARTICIPANT	\N	PRESENT	0
466344	466320	19599P	PARTICIPANT	\N	PRESENT	0
466345	466320	19383Y	PARTICIPANT	\N	PRESENT	0
466346	466320	19737F	PARTICIPANT	\N	PRESENT	0
466347	466320	19745F	PARTICIPANT	\N	PRESENT	0
466348	466320	17583W	PARTICIPANT	\N	PRESENT	0
466349	466320	14051J	PARTICIPANT	\N	PRESENT	0
466350	466320	14219Q	PARTICIPANT	\N	PRESENT	0
466351	466320	19333N	PARTICIPANT	\N	PRESENT	0
466352	466320	19637C	PARTICIPANT	\N	PRESENT	0
466353	466320	19794Q	PARTICIPANT	\N	PRESENT	0
466354	466320	14221J	PARTICIPANT	\N	PRESENT	0
466355	466320	14157T	PARTICIPANT	\N	PRESENT	0
466356	466321	02002K	PARTICIPANT	\N	PRESENT	0
466357	466321	14237S	PARTICIPANT	0	PRESENT	0
466358	466321	14031R	PARTICIPANT	\N	PRESENT	0
466359	466321	04085P	PARTICIPANT	\N	PRESENT	0
466360	466321	08055A	PARTICIPANT	\N	PRESENT	0
466361	466321	19794Q	PARTICIPANT	\N	PRESENT	0
466362	466321	19637C	PARTICIPANT	\N	PRESENT	0
466363	466321	18083K	PARTICIPANT	\N	PRESENT	0
466364	466321	19739H	PARTICIPANT	\N	PRESENT	0
466365	466321	08009T	PRESIDENT	0	PRESENT	0
466366	466321	08024S	PARTICIPANT	\N	PRESENT	0
466367	466321	19820Y	PARTICIPANT	\N	PRESENT	0
466368	466321	19387D	PARTICIPANT	\N	PRESENT	0
466369	466321	14219Q	PARTICIPANT	\N	PRESENT	0
466370	466321	19383Y	PARTICIPANT	\N	PRESENT	0
466371	466321	19333N	PARTICIPANT	\N	PRESENT	0
466372	466321	19549D	PARTICIPANT	\N	PRESENT	0
466373	466321	14169X	PARTICIPANT	\N	PRESENT	0
466374	466321	14157T	PARTICIPANT	\N	PRESENT	0
466375	466321	19701S	PARTICIPANT	\N	PRESENT	0
466376	466321	19599P	PARTICIPANT	\N	PRESENT	0
466377	466321	19737F	PARTICIPANT	\N	PRESENT	0
466378	466321	08060W	PARTICIPANT	\N	PRESENT	0
466379	466321	14051J	PARTICIPANT	\N	PRESENT	0
466380	466321	19551W	PARTICIPANT	\N	PRESENT	0
466381	466321	14038Y	PARTICIPANT	\N	PRESENT	0
466382	466321	19826F	PARTICIPANT	\N	PRESENT	0
466383	466321	14221J	PARTICIPANT	\N	PRESENT	0
466384	466321	19745F	PARTICIPANT	\N	PRESENT	0
466385	466321	17637T	PARTICIPANT	\N	PRESENT	0
466386	466321	11065P	PARTICIPANT	\N	PRESENT	0
466387	466321	19681G	PARTICIPANT	\N	PRESENT	0
466683	466682	14030Q	PARTICIPANT	\N	PRESENT	0
466684	466682	19575F	PARTICIPANT	\N	PRESENT	0
466685	466682	04049K	PARTICIPANT	\N	PRESENT	0
466686	466682	16685X	PARTICIPANT	\N	PRESENT	0
466687	466682	14083S	PARTICIPANT	\N	PRESENT	0
466688	466682	14105F	PARTICIPANT	\N	PRESENT	0
466690	466689	14261S	PARTICIPANT	\N	PRESENT	0
466691	466689	19575F	PARTICIPANT	\N	PRESENT	0
466692	466689	14030Q	PARTICIPANT	\N	PRESENT	0
466693	466689	14105F	PARTICIPANT	\N	PRESENT	0
466694	466689	14255U	PARTICIPANT	\N	PRESENT	0
466695	466689	14053L	PARTICIPANT	\N	PRESENT	0
466696	466689	14083S	PARTICIPANT	\N	PRESENT	0
466697	466689	14041T	PARTICIPANT	\N	PRESENT	0
466698	466689	14087W	PARTICIPANT	\N	PRESENT	0
466699	466689	14061L	PARTICIPANT	\N	PRESENT	0
466700	466689	04049K	PRESIDENT	0	PRESENT	0
466701	466689	08015R	PARTICIPANT	\N	PRESENT	0
466702	466689	14205J	PARTICIPANT	\N	PRESENT	0
466703	466689	19671E	PARTICIPANT	\N	PRESENT	0
466704	466689	14265W	PARTICIPANT	\N	PRESENT	0
466705	466689	08060W	PARTICIPANT	\N	EXCUSE	0
466706	466689	19545Y	PARTICIPANT	\N	EXCUSE	0
466707	466689	08047A	PARTICIPANT	\N	EXCUSE	0
466708	466689	04088S	PARTICIPANT	\N	EXCUSE	0
466709	466689	14051J	PARTICIPANT	\N	EXCUSE	0
471369	471368	14042U	PARTICIPANT	\N	PRESENT	0
471370	471368	11031D	PARTICIPANT	\N	PRESENT	0
471371	471368	11067R	PARTICIPANT	\N	PRESENT	0
471372	471368	14227Q	PARTICIPANT	\N	PRESENT	0
471374	471373	19367Y	PARTICIPANT	\N	PRESENT	0
471375	471373	14042U	PARTICIPANT	\N	PRESENT	0
475034	475033	14033T	PARTICIPANT	\N	PRESENT	0
475035	475033	80013X	PARTICIPANT	\N	PRESENT	0
475036	475033	04089T	PARTICIPANT	\N	PRESENT	0
475038	475037	14033T	PARTICIPANT	\N	PRESENT	0
475039	475037	80013X	PARTICIPANT	\N	PRESENT	0
475040	475037	19747H	PARTICIPANT	\N	PRESENT	0
475042	475041	14033T	PARTICIPANT	\N	PRESENT	0
475043	475041	80013X	PARTICIPANT	\N	PRESENT	0
475044	475041	04089T	PARTICIPANT	\N	PRESENT	0
475045	475041	08028W	PARTICIPANT	\N	PRESENT	0
475046	475041	14357A	PARTICIPANT	\N	PRESENT	0
475048	475047	14033T	PARTICIPANT	\N	PRESENT	0
475049	475047	80013X	PARTICIPANT	\N	PRESENT	0
475050	475047	04089T	PARTICIPANT	\N	PRESENT	0
475051	475047	08028W	PARTICIPANT	\N	PRESENT	0
475052	475047	14357A	PARTICIPANT	\N	PRESENT	0
475084	472986	19631V	PARTICIPANT	\N	PRESENT	0
475085	472986	08068F	PARTICIPANT	\N	EXCUSE	0
475107	472986	19782L	PARTICIPANT	\N	PRESENT	0
475130	472986	14081Q	PARTICIPANT	\N	PRESENT	0
477709	477708	19725B	PARTICIPANT	\N	PRESENT	0
477711	477710	19725B	PARTICIPANT	\N	PRESENT	0
478400	477747	19729F	PARTICIPANT	\N	PRESENT	0
482612	479258	19489J	PARTICIPANT	\N	PRESENT	0
482613	479258	08034U	PARTICIPANT	\N	PRESENT	0
482614	479258	14001X	PARTICIPANT	\N	PRESENT	0
482615	479258	19531S	PARTICIPANT	\N	PRESENT	0
482616	479258	14085U	PARTICIPANT	\N	PRESENT	0
482617	479258	19723Y	PARTICIPANT	\N	PRESENT	0
482618	479258	17779H	PARTICIPANT	\N	PRESENT	0
482619	479258	14033T	PARTICIPANT	\N	PRESENT	0
482620	479258	14151M	PARTICIPANT	\N	PRESENT	0
482621	479258	19507S	PARTICIPANT	\N	PRESENT	0
482622	479258	19649G	PARTICIPANT	\N	PRESENT	0
482623	479258	19794Q	PARTICIPANT	\N	PRESENT	0
472582	472418	08024S	PARTICIPANT	\N	PRESENT	0
472600	472597	19591F	PARTICIPANT	\N	EXCUSE	0
472601	472597	19611R	PRESIDENT	0	PRESENT	0
472603	472597	14097Y	PARTICIPANT	\N	PRESENT	0
472669	472060	05008E	PRESIDENT	0	PRESENT	0
472670	472060	19729F	PARTICIPANT	\N	EXCUSE	0
472671	472060	14179A	PARTICIPANT	\N	PRESENT	0
472672	472060	19447X	PARTICIPANT	\N	PRESENT	0
472673	472060	14147R	PARTICIPANT	\N	PRESENT	0
472674	472060	01028R	PARTICIPANT	\N	PRESENT	0
472675	472060	19489J	PARTICIPANT	\N	PRESENT	0
472676	472060	14021P	PARTICIPANT	\N	PRESENT	0
472677	472060	95063L	PARTICIPANT	\N	PRESENT	0
472678	472060	11026G	PARTICIPANT	\N	PRESENT	0
472679	472060	11085T	PARTICIPANT	\N	PRESENT	0
473257	470441	04070G	PARTICIPANT	\N	PRESENT	0
473258	470441	04033B	PARTICIPANT	\N	PRESENT	0
473259	470441	14193X	PARTICIPANT	\N	PRESENT	0
473260	470441	11099A	PARTICIPANT	\N	PRESENT	0
473261	470441	19441R	PARTICIPANT	\N	PRESENT	0
473262	470441	14021P	PARTICIPANT	\N	PRESENT	0
473263	470441	14281W	PARTICIPANT	\N	PRESENT	0
473264	470441	14053L	PARTICIPANT	\N	PRESENT	0
473265	470441	14030Q	PARTICIPANT	\N	PRESENT	0
473266	470441	08069G	PARTICIPANT	\N	PRESENT	0
473267	470441	14069U	PARTICIPANT	\N	PRESENT	0
473321	467275	11027H	PARTICIPANT	\N	PRESENT	0
473322	467275	19253P	PARTICIPANT	\N	PRESENT	0
473323	467275	14239U	PARTICIPANT	\N	PRESENT	0
473324	467275	14111D	PARTICIPANT	\N	PRESENT	0
473325	467275	18083K	PARTICIPANT	\N	PRESENT	0
473326	467275	19565D	PARTICIPANT	\N	PRESENT	0
473327	467275	11033F	PARTICIPANT	\N	PRESENT	0
473328	467275	05008E	PARTICIPANT	\N	PRESENT	0
473329	467275	19591F	PARTICIPANT	\N	PRESENT	0
473330	467275	08031R	PARTICIPANT	\N	PRESENT	0
473331	467275	11012A	PARTICIPANT	\N	PRESENT	0
473332	467275	19713W	PARTICIPANT	\N	PRESENT	0
473333	467275	19749K	PARTICIPANT	\N	PRESENT	0
473334	467275	14249W	PARTICIPANT	\N	PRESENT	0
473335	467275	14042U	PARTICIPANT	\N	PRESENT	0
473336	467275	11072N	PARTICIPANT	\N	PRESENT	0
473337	467275	19533U	PARTICIPANT	\N	PRESENT	0
473340	467275	19762G	PARTICIPANT	\N	PRESENT	0
473341	467275	04092N	PARTICIPANT	\N	PRESENT	0
473342	467275	19447X	PARTICIPANT	\N	PRESENT	0
473343	467275	01028R	PARTICIPANT	\N	PRESENT	0
473344	467275	14081Q	PARTICIPANT	\N	PRESENT	0
473345	467275	14213J	PARTICIPANT	\N	PRESENT	0
473346	467275	14215L	PARTICIPANT	\N	PRESENT	0
473347	467275	19760E	PARTICIPANT	\N	PRESENT	0
473348	467275	19631V	PARTICIPANT	\N	PRESENT	0
473349	467275	11026G	PARTICIPANT	\N	PRESENT	0
473350	467275	19553Y	PARTICIPANT	\N	PRESENT	0
473351	467275	14071N	PARTICIPANT	\N	PRESENT	0
473352	467275	19399H	PARTICIPANT	\N	PRESENT	0
473353	467275	11099A	PARTICIPANT	\N	PRESENT	0
473354	467275	19693L	PARTICIPANT	\N	PRESENT	0
473355	467275	95030B	PARTICIPANT	\N	PRESENT	0
473356	467275	14069U	PARTICIPANT	\N	PRESENT	0
473357	467275	11048N	PARTICIPANT	\N	PRESENT	0
473386	467275	19441R	PARTICIPANT	\N	PRESENT	0
473387	467275	14055N	PARTICIPANT	\N	PRESENT	0
473404	467275	14251Q	PARTICIPANT	\N	PRESENT	0
473429	472014	08056B	PRESIDENT	0	PRESENT	0
473430	472014	19421M	PARTICIPANT	\N	PRESENT	0
473431	472014	08053X	PARTICIPANT	\N	PRESENT	0
473432	472014	08010L	PARTICIPANT	\N	PRESENT	0
473433	472014	19673G	PARTICIPANT	\N	PRESENT	0
473434	472014	19719D	PARTICIPANT	\N	EXCUSE	0
473444	467275	19563B	PARTICIPANT	\N	PRESENT	0
473445	467275	14073Q	PARTICIPANT	\N	PRESENT	0
473448	467275	14034U	PARTICIPANT	\N	PRESENT	0
473450	467275	14031R	PARTICIPANT	\N	PRESENT	0
473481	467275	14257W	PARTICIPANT	\N	PRESENT	0
473565	467277	14083S	PARTICIPANT	\N	PRESENT	0
473577	467277	11040E	PARTICIPANT	\N	PRESENT	0
473579	467277	11045K	PARTICIPANT	\N	PRESENT	0
473580	467277	19820Y	PARTICIPANT	\N	PRESENT	0
473581	467277	11074Q	PARTICIPANT	\N	PRESENT	0
473582	467277	19647E	PARTICIPANT	\N	PRESENT	0
473584	467277	11064N	PARTICIPANT	\N	PRESENT	0
473585	467277	14021P	PARTICIPANT	\N	PRESENT	0
473586	467277	19689Q	PARTICIPANT	\N	PRESENT	0
473587	467277	19591F	PARTICIPANT	\N	PRESENT	0
473588	467277	19709B	PARTICIPANT	\N	PRESENT	0
473589	467277	19711U	PARTICIPANT	\N	PRESENT	0
473590	467277	14133K	PARTICIPANT	\N	PRESENT	0
473591	467277	19447X	PARTICIPANT	\N	PRESENT	0
473592	467277	14071N	PARTICIPANT	\N	PRESENT	0
473593	467277	19533U	PARTICIPANT	\N	PRESENT	0
473594	467277	04086Q	PARTICIPANT	\N	PRESENT	0
473595	467277	07004J	PARTICIPANT	\N	PRESENT	0
473596	467277	14085U	PARTICIPANT	\N	PRESENT	0
473597	467277	19569H	PARTICIPANT	\N	PRESENT	0
473598	467277	11048N	PARTICIPANT	\N	PRESENT	0
473600	467277	19762G	PARTICIPANT	\N	PRESENT	0
473601	467277	18083K	PARTICIPANT	\N	PRESENT	0
473603	467277	17779H	PARTICIPANT	\N	PRESENT	0
473604	467277	14081Q	PARTICIPANT	\N	PRESENT	0
473606	467277	14034U	PARTICIPANT	\N	PRESENT	0
473607	467277	19693L	PARTICIPANT	\N	PRESENT	0
473608	467277	08011M	PARTICIPANT	\N	PRESENT	0
473609	472075	19729F	PARTICIPANT	\N	PRESENT	0
473610	472075	95067Q	PARTICIPANT	\N	PRESENT	0
473611	472075	19629C	PARTICIPANT	\N	PRESENT	0
473612	472075	14039A	PARTICIPANT	\N	PRESENT	0
473613	472075	14267Y	PRESIDENT	0	PRESENT	0
473614	472075	16685X	PARTICIPANT	\N	PRESENT	0
473556	467277	11070L	PARTICIPANT	\N	PRESENT	0
473558	472051	08056B	PARTICIPANT	\N	PRESENT	0
473559	472051	11026G	PARTICIPANT	\N	PRESENT	0
473560	472051	08053X	PARTICIPANT	\N	PRESENT	0
473561	472051	04044E	PARTICIPANT	\N	PRESENT	0
473562	472051	19673G	PARTICIPANT	\N	PRESENT	0
473563	472051	19719D	PRESIDENT	0	PRESENT	0
473564	472051	04040A	PARTICIPANT	\N	PRESENT	0
473615	472075	19695N	PARTICIPANT	\N	PRESENT	0
473616	472075	19715Y	PARTICIPANT	\N	PRESENT	0
473617	472075	19826F	PARTICIPANT	\N	PRESENT	0
473618	472075	14259Y	PARTICIPANT	\N	PRESENT	0
473619	472075	19295A	PARTICIPANT	\N	PRESENT	0
473620	472075	19525U	PARTICIPANT	\N	PRESENT	0
473621	467277	19551W	PARTICIPANT	\N	PRESENT	0
473622	467277	19687N	PARTICIPANT	\N	PRESENT	0
473624	467277	19399H	PARTICIPANT	\N	PRESENT	0
473625	472075	14059S	PARTICIPANT	\N	PRESENT	0
473627	467277	04059M	PARTICIPANT	\N	PRESENT	0
473632	467277	14329V	PARTICIPANT	\N	PRESENT	0
473652	467277	19667J	PARTICIPANT	\N	PRESENT	0
473653	467277	14157T	PARTICIPANT	\N	PRESENT	0
473654	467277	04042C	PARTICIPANT	\N	PRESENT	0
473655	467277	19651A	PARTICIPANT	\N	PRESENT	0
473656	467277	19489J	PARTICIPANT	\N	PRESENT	0
473657	473462	19701S	PARTICIPANT	\N	PRESENT	0
473658	473462	14031R	PARTICIPANT	\N	PRESENT	0
473659	473465	14031R	PARTICIPANT	\N	PRESENT	0
473660	473465	19681G	PARTICIPANT	\N	PRESENT	0
473661	472075	11064N	PARTICIPANT	\N	EXCUSE	0
473662	473466	14157T	PARTICIPANT	\N	PRESENT	0
473663	473466	14031R	PARTICIPANT	\N	PRESENT	0
473664	473466	19599P	PARTICIPANT	\N	PRESENT	0
473665	473466	19794Q	PARTICIPANT	\N	PRESENT	0
473666	473466	14093U	PARTICIPANT	\N	PRESENT	0
473667	473466	19701S	PARTICIPANT	\N	PRESENT	0
473668	473573	08060W	PARTICIPANT	\N	PRESENT	0
473669	473467	08009T	PARTICIPANT	\N	PRESENT	0
473670	473467	14031R	PARTICIPANT	\N	PRESENT	0
473671	473468	14031R	PARTICIPANT	\N	PRESENT	0
473672	473468	19681G	PARTICIPANT	\N	PRESENT	0
473673	473468	14157T	PARTICIPANT	\N	PRESENT	0
473674	473468	19637C	PARTICIPANT	\N	PRESENT	0
473675	473468	19551W	PARTICIPANT	\N	PRESENT	0
473676	473469	14031R	PARTICIPANT	\N	PRESENT	0
473677	473469	14157T	PARTICIPANT	\N	PRESENT	0
473678	473469	14093U	PARTICIPANT	\N	PRESENT	0
473679	473469	19599P	PARTICIPANT	\N	PRESENT	0
473680	473469	19637C	PARTICIPANT	\N	PRESENT	0
473681	473469	19551W	PARTICIPANT	\N	PRESENT	0
473682	473470	14031R	PARTICIPANT	\N	PRESENT	0
473683	473470	19681G	PARTICIPANT	\N	PRESENT	0
473684	473470	19637C	PARTICIPANT	\N	PRESENT	0
473685	473470	19794Q	PARTICIPANT	\N	PRESENT	0
473686	473470	14051J	PARTICIPANT	\N	PRESENT	0
473687	473470	19551W	PARTICIPANT	\N	PRESENT	0
473797	467277	01034P	PARTICIPANT	\N	PRESENT	0
454574	454197	14195A	PARTICIPANT	\N	EXCUSE	0
460739	458981	14111D	PARTICIPANT	\N	PRESENT	0
462707	462689	19812Y	PARTICIPANT	\N	PRESENT	0
462708	462689	19413M	PARTICIPANT	\N	PRESENT	0
462709	462689	11090Q	PRESIDENT	0	PRESENT	0
462710	462689	04043D	PARTICIPANT	\N	PRESENT	0
462711	462689	19563B	PARTICIPANT	\N	PRESENT	0
462712	462689	14329V	PARTICIPANT	\N	PRESENT	0
462713	462689	14257W	PARTICIPANT	\N	PRESENT	0
462714	462689	19768N	PARTICIPANT	\N	EXCUSE	0
462715	462689	19515S	PARTICIPANT	\N	EXCUSE	0
462716	462689	11077T	PARTICIPANT	\N	EXCUSE	0
462717	462689	19782L	PARTICIPANT	\N	EXCUSE	0
462718	462689	01043Q	PARTICIPANT	\N	EXCUSE	0
462719	462689	14357A	PARTICIPANT	\N	EXCUSE	0
462720	462689	14081Q	PARTICIPANT	\N	EXCUSE	0
462721	462689	80013X	PARTICIPANT	\N	EXCUSE	0
462722	462689	04045F	PARTICIPANT	\N	EXCUSE	0
462723	462689	19631V	PARTICIPANT	\N	EXCUSE	0
462724	462689	11099A	PARTICIPANT	\N	EXCUSE	0
462725	462689	08068F	PARTICIPANT	\N	EXCUSE	0
462726	462689	04049K	PARTICIPANT	\N	EXCUSE	0
462727	462689	19705W	PARTICIPANT	\N	EXCUSE	0
462728	462689	08015R	PARTICIPANT	\N	EXCUSE	0
462729	462689	08019V	PARTICIPANT	\N	EXCUSE	0
462730	462689	14197C	PARTICIPANT	\N	EXCUSE	0
462731	462689	19369B	PARTICIPANT	\N	EXCUSE	0
462732	462689	19511N	PARTICIPANT	\N	EXCUSE	0
462733	462689	08028W	PARTICIPANT	\N	EXCUSE	0
462734	462689	14265W	PARTICIPANT	\N	EXCUSE	0
462735	462689	14135M	PARTICIPANT	\N	EXCUSE	0
462736	462689	19467C	PARTICIPANT	\N	EXCUSE	0
462737	462689	14187A	PARTICIPANT	\N	EXCUSE	0
462738	462689	08038Y	PARTICIPANT	\N	EXCUSE	0
462739	462689	08062Y	PARTICIPANT	\N	EXCUSE	0
462740	462689	01025N	PARTICIPANT	\N	EXCUSE	0
462741	462689	14033T	PARTICIPANT	\N	EXCUSE	0
462742	462689	19295A	PARTICIPANT	\N	EXCUSE	0
462743	462689	19269X	PARTICIPANT	\N	EXCUSE	0
462744	462689	14205J	PARTICIPANT	\N	EXCUSE	0
462745	462689	04088S	PARTICIPANT	\N	EXCUSE	0
462746	462689	11056N	PARTICIPANT	\N	EXCUSE	0
462747	462689	04089T	PARTICIPANT	\N	EXCUSE	0
462748	462689	14115H	PARTICIPANT	\N	EXCUSE	0
462749	462689	11101A	PARTICIPANT	\N	EXCUSE	0
462750	462689	19507S	PARTICIPANT	\N	EXCUSE	0
462751	462689	14207L	PARTICIPANT	\N	EXCUSE	0
462752	462689	19747H	PARTICIPANT	\N	EXCUSE	0
462753	462689	17589D	PARTICIPANT	\N	EXCUSE	0
462754	462689	19441R	PARTICIPANT	\N	PRESENT	0
462755	462689	19695N	PARTICIPANT	\N	PRESENT	0
462756	462690	19697Q	PARTICIPANT	\N	PRESENT	0
462757	462690	11031D	PARTICIPANT	\N	PRESENT	0
462758	462690	04092N	PARTICIPANT	\N	PRESENT	0
462759	462690	11045K	PARTICIPANT	\N	PRESENT	0
462760	462690	11097X	PARTICIPANT	\N	PRESENT	0
462761	462690	19691J	PARTICIPANT	\N	PRESENT	0
462762	462690	14071N	PARTICIPANT	\N	PRESENT	0
462763	462690	10006L	PARTICIPANT	\N	PRESENT	0
462764	462690	19683J	PARTICIPANT	\N	PRESENT	0
462765	462690	19591F	PARTICIPANT	\N	PRESENT	0
462766	462690	11067R	PARTICIPANT	\N	EXCUSE	0
462767	462690	14355X	PARTICIPANT	\N	EXCUSE	0
462768	462690	19565D	PARTICIPANT	\N	EXCUSE	0
462769	462690	19569H	PARTICIPANT	\N	EXCUSE	0
462770	462690	19798U	PARTICIPANT	\N	EXCUSE	0
462771	462690	19415P	PARTICIPANT	\N	EXCUSE	0
462772	462690	14223L	PARTICIPANT	\N	EXCUSE	0
462773	462690	14026U	PARTICIPANT	\N	EXCUSE	0
462774	462690	14227Q	PARTICIPANT	\N	EXCUSE	0
462775	462690	17779H	PARTICIPANT	\N	EXCUSE	0
462776	462690	14239U	PARTICIPANT	\N	EXCUSE	0
462777	462690	19553Y	PARTICIPANT	\N	EXCUSE	0
462778	462690	19703U	PARTICIPANT	\N	EXCUSE	0
462779	462690	14087W	PARTICIPANT	\N	EXCUSE	0
462780	462690	14281W	PARTICIPANT	\N	EXCUSE	0
462781	462690	19679N	PARTICIPANT	\N	EXCUSE	0
462782	462690	14042U	PARTICIPANT	\N	EXCUSE	0
462783	462690	08048B	PARTICIPANT	\N	EXCUSE	0
462784	462690	14195A	PARTICIPANT	\N	EXCUSE	0
462785	462690	19575F	PARTICIPANT	\N	EXCUSE	0
462786	462690	14213J	PARTICIPANT	\N	EXCUSE	0
462787	462690	19367Y	PARTICIPANT	\N	EXCUSE	0
462788	462690	14261S	PARTICIPANT	\N	EXCUSE	0
462789	462690	14217N	PARTICIPANT	\N	EXCUSE	0
462790	462690	98024R	PARTICIPANT	\N	EXCUSE	0
462791	462690	19521Q	PARTICIPANT	\N	EXCUSE	0
462792	462690	19527W	PARTICIPANT	\N	EXCUSE	0
462793	462690	01034P	PARTICIPANT	\N	EXCUSE	0
462794	462690	08052W	PARTICIPANT	\N	EXCUSE	0
462795	462690	19663E	PARTICIPANT	\N	EXCUSE	0
462796	462690	19301E	PARTICIPANT	\N	EXCUSE	0
462797	462690	19715Y	PARTICIPANT	\N	EXCUSE	0
462798	462690	19717B	PARTICIPANT	\N	EXCUSE	0
462799	462690	08041T	PARTICIPANT	\N	EXCUSE	0
462800	462690	19723Y	PARTICIPANT	\N	EXCUSE	0
462801	462690	19727D	PARTICIPANT	\N	EXCUSE	0
462802	462690	14119M	PARTICIPANT	\N	EXCUSE	0
462803	462690	11103C	PARTICIPANT	\N	EXCUSE	0
462804	462690	19657G	PARTICIPANT	\N	EXCUSE	0
462805	462690	19577H	PARTICIPANT	\N	EXCUSE	0
462806	462690	19760E	PARTICIPANT	\N	EXCUSE	0
462829	462688	19729F	PARTICIPANT	\N	EXCUSE	0
462830	462688	04044E	PARTICIPANT	\N	EXCUSE	0
462831	462688	14259Y	PARTICIPANT	\N	EXCUSE	0
462810	462688	19649G	PARTICIPANT	\N	PRESENT	0
462811	462688	11026G	PARTICIPANT	\N	PRESENT	0
462812	462688	19543W	PARTICIPANT	\N	PRESENT	0
462813	462688	11090Q	PARTICIPANT	\N	PRESENT	0
462814	462688	19585H	PARTICIPANT	\N	PRESENT	0
462815	462688	19673G	PARTICIPANT	\N	PRESENT	0
462816	462688	19719D	PARTICIPANT	\N	PRESENT	0
462817	462688	01028R	PARTICIPANT	\N	PRESENT	0
462818	462688	11033F	PARTICIPANT	\N	PRESENT	0
462819	462688	05008E	PRESIDENT	0	PRESENT	0
462820	462688	19447X	PARTICIPANT	\N	PRESENT	0
462821	462688	14231L	PARTICIPANT	\N	PRESENT	0
462822	462688	95063L	PARTICIPANT	\N	PRESENT	0
462823	462688	14215L	PARTICIPANT	\N	PRESENT	0
462824	462688	11085T	PARTICIPANT	\N	PRESENT	0
462832	462694	86034E	PARTICIPANT	\N	PRESENT	0
462826	462688	19762G	PARTICIPANT	\N	PRESENT	0
462827	462688	14021P	PARTICIPANT	\N	PRESENT	0
462828	462688	04047H	PARTICIPANT	\N	PRESENT	0
462833	462694	19525U	PARTICIPANT	\N	PRESENT	0
462834	462694	19563B	PARTICIPANT	\N	PRESENT	0
462835	462694	07004J	PARTICIPANT	\N	PRESENT	0
462836	462694	11033F	PARTICIPANT	\N	PRESENT	0
462837	462694	19683J	PARTICIPANT	\N	PRESENT	0
462838	462694	19593H	PARTICIPANT	\N	PRESENT	0
462839	462694	19413M	PARTICIPANT	\N	PRESENT	0
462840	462694	11066Q	PARTICIPANT	\N	PRESENT	0
462841	462694	19812Y	PARTICIPANT	\N	PRESENT	0
462842	462694	95041E	PARTICIPANT	\N	PRESENT	0
462843	462694	14249W	PARTICIPANT	\N	PRESENT	0
462844	462694	19695N	PARTICIPANT	\N	PRESENT	0
462845	462694	14231L	PARTICIPANT	\N	PRESENT	0
462846	462694	14085U	PARTICIPANT	\N	PRESENT	0
462847	462694	19669L	PARTICIPANT	\N	PRESENT	0
462848	462694	11045K	PARTICIPANT	\N	PRESENT	0
462849	462694	98050T	PARTICIPANT	\N	PRESENT	0
462850	462694	11053K	PARTICIPANT	\N	PRESENT	0
462851	462694	19699S	PARTICIPANT	\N	PRESENT	0
462852	462694	14329V	PARTICIPANT	\N	PRESENT	0
462853	462694	19673G	PARTICIPANT	\N	PRESENT	0
462854	462694	19447X	PARTICIPANT	\N	PRESENT	0
462855	462694	14055N	PARTICIPANT	\N	PRESENT	0
462856	462694	14071N	PARTICIPANT	\N	PRESENT	0
462857	462694	11097X	PARTICIPANT	\N	PRESENT	0
462858	462694	14215L	PARTICIPANT	\N	PRESENT	0
462859	462694	08010L	PARTICIPANT	\N	PRESENT	0
462860	462694	05012A	PARTICIPANT	\N	PRESENT	0
462861	462694	12041X	PARTICIPANT	\N	PRESENT	0
462862	462694	11031D	PARTICIPANT	\N	PRESENT	0
462863	462694	19649G	PARTICIPANT	\N	PRESENT	0
462864	462694	19687N	PARTICIPANT	\N	PRESENT	0
462865	462694	08011M	PARTICIPANT	\N	PRESENT	0
462866	462694	01028R	PARTICIPANT	\N	PRESENT	0
462867	462694	11074Q	PARTICIPANT	\N	PRESENT	0
462868	462694	04059M	PARTICIPANT	\N	PRESENT	0
462869	462694	14021P	PARTICIPANT	\N	PRESENT	0
462870	462694	04071H	PARTICIPANT	\N	PRESENT	0
462871	462694	14257W	PARTICIPANT	\N	PRESENT	0
462872	462694	04047H	PARTICIPANT	\N	PRESENT	0
462873	462694	19689Q	PARTICIPANT	\N	PRESENT	0
462874	462694	19643A	PARTICIPANT	\N	PRESENT	0
462875	462694	04034C	PARTICIPANT	\N	PRESENT	0
462876	462694	14034U	PARTICIPANT	\N	PRESENT	0
462877	462694	19719D	PARTICIPANT	\N	PRESENT	0
471099	471087	19575F	PARTICIPANT	\N	PRESENT	0
471100	471087	14069U	PARTICIPANT	\N	PRESENT	0
471101	471087	19725B	PARTICIPANT	\N	PRESENT	0
471102	471087	14061L	PARTICIPANT	\N	PRESENT	0
471135	467271	11012A	PARTICIPANT	\N	PRESENT	0
471283	470435	11026G	PARTICIPANT	\N	PRESENT	0
471284	470435	07033P	PARTICIPANT	\N	PRESENT	0
471285	470435	19709B	PARTICIPANT	\N	PRESENT	0
471286	470435	14041T	PARTICIPANT	\N	PRESENT	0
471287	470435	11085T	PARTICIPANT	\N	PRESENT	0
471288	470435	04034C	PARTICIPANT	\N	PRESENT	0
471289	470435	05008E	PARTICIPANT	\N	PRESENT	0
471290	470435	08018U	PARTICIPANT	\N	PRESENT	0
471291	470435	04033B	PARTICIPANT	\N	PRESENT	0
471292	470435	14235Q	PARTICIPANT	\N	PRESENT	0
471293	470435	19741B	PARTICIPANT	\N	PRESENT	0
471332	467272	14235Q	PARTICIPANT	\N	PRESENT	0
471360	467272	19733B	PARTICIPANT	\N	PRESENT	0
471334	467272	14041T	PARTICIPANT	\N	PRESENT	0
471335	467272	11026G	PARTICIPANT	\N	PRESENT	0
471336	467272	04034C	PARTICIPANT	\N	PRESENT	0
471337	467272	11064N	PARTICIPANT	\N	PRESENT	0
471338	467272	14121F	PARTICIPANT	\N	PRESENT	0
471359	467272	11074Q	PARTICIPANT	\N	PRESENT	0
471340	467272	04070G	PARTICIPANT	\N	PRESENT	0
471341	467272	11085T	PARTICIPANT	\N	PRESENT	0
471342	467272	19479G	PARTICIPANT	\N	PRESENT	0
471343	467272	19621T	PARTICIPANT	\N	PRESENT	0
471344	467272	07033P	PARTICIPANT	\N	PRESENT	0
471345	467272	05008E	PARTICIPANT	\N	PRESENT	0
471346	467272	19399H	PARTICIPANT	\N	PRESENT	0
471347	467272	19709B	PARTICIPANT	\N	PRESENT	0
471348	467272	08018U	PARTICIPANT	\N	PRESENT	0
471349	467272	14123H	PARTICIPANT	\N	PRESENT	0
471350	467272	14147R	PARTICIPANT	\N	PRESENT	0
471351	467272	19693L	PARTICIPANT	\N	PRESENT	0
471352	467272	04033B	PARTICIPANT	\N	PRESENT	0
471353	467272	19533U	PARTICIPANT	\N	PRESENT	0
471354	467272	19647E	PARTICIPANT	\N	PRESENT	0
471355	467272	19741B	PARTICIPANT	\N	PRESENT	0
471356	467272	08017T	PARTICIPANT	\N	PRESENT	0
471357	467272	14255U	PARTICIPANT	\N	PRESENT	0
471358	467272	11012A	PARTICIPANT	\N	PRESENT	0
471361	467272	19667J	PARTICIPANT	\N	PRESENT	0
471362	467272	14331P	PARTICIPANT	\N	PRESENT	0
471363	467272	14109K	PARTICIPANT	\N	PRESENT	0
471367	467272	08011M	PARTICIPANT	\N	PRESENT	0
471376	467272	11053K	PARTICIPANT	\N	PRESENT	0
471377	467272	04035D	PARTICIPANT	\N	PRESENT	0
471378	467272	14157T	PARTICIPANT	\N	PRESENT	0
471379	467272	14135M	PARTICIPANT	\N	PRESENT	0
471380	471001	14059S	PARTICIPANT	\N	PRESENT	0
471330	467272	11027H	PARTICIPANT	\N	PRESENT	0
471331	467272	19573D	PARTICIPANT	\N	PRESENT	0
471381	471001	08045X	PARTICIPANT	\N	PRESENT	0
471382	471001	11026G	PARTICIPANT	\N	PRESENT	0
471383	471001	16685X	PARTICIPANT	\N	PRESENT	0
471384	471001	19695N	PARTICIPANT	\N	PRESENT	0
471385	471001	19715Y	PARTICIPANT	\N	PRESENT	0
471386	471001	19826F	PARTICIPANT	\N	PRESENT	0
471387	471001	19295A	PARTICIPANT	\N	PRESENT	0
471388	471001	19447X	PARTICIPANT	\N	PRESENT	0
471389	471001	04086Q	PARTICIPANT	\N	PRESENT	0
471390	471001	19729F	PRESIDENT	0	PRESENT	0
471391	471001	08073C	PARTICIPANT	\N	PRESENT	0
471392	471001	19629C	PARTICIPANT	\N	PRESENT	0
471393	471001	14039A	PARTICIPANT	\N	PRESENT	0
471394	471001	14267Y	PRESIDENT	1	PRESENT	0
471395	471001	14217N	PARTICIPANT	\N	PRESENT	0
471396	471001	19525U	PARTICIPANT	\N	PRESENT	0
471397	471001	95067Q	PARTICIPANT	\N	EXCUSE	0
471398	467272	14259Y	PARTICIPANT	\N	PRESENT	0
471399	467272	19593H	PARTICIPANT	\N	PRESENT	0
471400	467272	04088S	PARTICIPANT	\N	PRESENT	0
471403	467272	14237S	PARTICIPANT	\N	PRESENT	0
471404	467272	19531S	PARTICIPANT	\N	PRESENT	0
471442	470436	05008E	PARTICIPANT	\N	PRESENT	0
471443	470436	14041T	PARTICIPANT	\N	PRESENT	0
471444	470436	04034C	PARTICIPANT	\N	PRESENT	0
471445	470436	11012A	PARTICIPANT	\N	PRESENT	0
471446	470436	14235Q	PARTICIPANT	\N	PRESENT	0
471447	470436	19593H	PARTICIPANT	\N	PRESENT	0
471448	470436	14255U	PARTICIPANT	\N	PRESENT	0
471449	470436	19693L	PARTICIPANT	\N	PRESENT	0
471450	470436	14157T	PARTICIPANT	\N	PRESENT	0
471451	470436	08018U	PARTICIPANT	\N	PRESENT	0
471452	470436	19709B	PARTICIPANT	\N	PRESENT	0
471453	470436	14147R	PARTICIPANT	\N	PRESENT	0
471454	470436	19741B	PARTICIPANT	\N	PRESENT	0
471455	470436	14135M	PARTICIPANT	\N	PRESENT	0
471456	470436	19621T	PARTICIPANT	\N	PRESENT	0
471457	470436	14259Y	PARTICIPANT	\N	PRESENT	0
471458	470436	04088S	PARTICIPANT	\N	PRESENT	0
471459	470436	11027H	PARTICIPANT	\N	PRESENT	0
471460	470436	08011M	PARTICIPANT	\N	PRESENT	0
471461	470436	04035D	PARTICIPANT	\N	PRESENT	0
471462	470436	19647E	PARTICIPANT	\N	PRESENT	0
471463	470436	14331P	PARTICIPANT	\N	PRESENT	0
471464	470436	04033B	PARTICIPANT	\N	PRESENT	0
471465	470436	14034U	PARTICIPANT	\N	PRESENT	0
471469	471467	19768N	PARTICIPANT	\N	PRESENT	0
471470	471467	19515S	PARTICIPANT	\N	PRESENT	0
471471	471467	19782L	PARTICIPANT	\N	PRESENT	0
471472	471467	01043Q	PARTICIPANT	\N	PRESENT	0
471473	471467	14357A	PARTICIPANT	\N	PRESENT	0
471474	471467	19812Y	PARTICIPANT	\N	PRESENT	0
471475	471467	14081Q	PARTICIPANT	\N	PRESENT	0
471476	471467	80013X	PARTICIPANT	\N	PRESENT	0
471477	471467	19631V	PARTICIPANT	\N	PRESENT	0
471478	471467	11099A	PARTICIPANT	\N	PRESENT	0
471479	471467	19705W	PARTICIPANT	\N	PRESENT	0
471440	470436	04086Q	PARTICIPANT	\N	PRESENT	0
471441	470436	08017T	PARTICIPANT	\N	PRESENT	0
471480	471467	08015R	PARTICIPANT	\N	PRESENT	0
471481	471467	14197C	PARTICIPANT	\N	PRESENT	0
471482	471467	19369B	PARTICIPANT	\N	PRESENT	0
471483	471467	08028W	PARTICIPANT	\N	PRESENT	0
471484	471467	19563B	PARTICIPANT	\N	PRESENT	0
471485	471467	14329V	PARTICIPANT	\N	PRESENT	0
471486	471467	14187A	PARTICIPANT	\N	PRESENT	0
471487	471467	08038Y	PARTICIPANT	\N	PRESENT	0
471488	471467	19695N	PARTICIPANT	\N	PRESENT	0
471489	471467	14033T	PARTICIPANT	\N	PRESENT	0
471490	471467	01025N	PARTICIPANT	\N	PRESENT	0
471491	471467	14205J	PARTICIPANT	\N	PRESENT	0
471492	471467	11056N	PARTICIPANT	\N	PRESENT	0
471493	471467	14115H	PARTICIPANT	\N	PRESENT	0
471494	471467	19507S	PARTICIPANT	\N	PRESENT	0
471495	471467	19747H	PARTICIPANT	\N	PRESENT	0
471496	471467	14207L	PARTICIPANT	\N	PRESENT	0
471497	471467	19619A	PARTICIPANT	\N	PRESENT	0
471498	471467	14257W	PARTICIPANT	\N	PRESENT	0
471499	471467	19467C	PARTICIPANT	\N	EXCUSE	0
471501	470544	11040E	PARTICIPANT	\N	PRESENT	0
471502	470544	14083S	PARTICIPANT	\N	PRESENT	0
471503	470544	95041E	PARTICIPANT	\N	PRESENT	0
471504	470544	19479G	PARTICIPANT	\N	PRESENT	0
471505	470544	19687N	PARTICIPANT	\N	PRESENT	0
471506	470544	08010L	PARTICIPANT	\N	PRESENT	0
471507	470544	19741B	PARTICIPANT	\N	PRESENT	0
471508	470544	19667J	PARTICIPANT	\N	PRESENT	0
471509	470544	11074Q	PRESIDENT	0	PRESENT	0
471510	471467	19441R	PARTICIPANT	\N	PRESENT	0
471511	470544	04086Q	PARTICIPANT	\N	PRESENT	0
471512	470544	19651A	PARTICIPANT	\N	PRESENT	0
471513	470544	89017R	PARTICIPANT	\N	PRESENT	0
471514	470544	19647E	PARTICIPANT	\N	PRESENT	0
471515	470544	08011M	PARTICIPANT	\N	PRESENT	0
471519	470532	95063L	PARTICIPANT	\N	PRESENT	0
471520	470532	14041T	PARTICIPANT	\N	PRESENT	0
471521	470532	11026G	PARTICIPANT	\N	PRESENT	0
471522	470532	14147R	PARTICIPANT	\N	PRESENT	0
471523	470532	14179A	PARTICIPANT	\N	PRESENT	0
471524	470532	19253P	PARTICIPANT	\N	PRESENT	0
471525	470532	14001X	PARTICIPANT	\N	PRESENT	0
471526	470532	08018U	PARTICIPANT	\N	PRESENT	0
471527	470532	19585H	PARTICIPANT	\N	PRESENT	0
471528	470532	11033F	PARTICIPANT	\N	PRESENT	0
471529	470532	05008E	PRESIDENT	0	PRESENT	0
471530	470532	19447X	PARTICIPANT	\N	PRESENT	0
471562	471467	04049K	PARTICIPANT	\N	PRESENT	0
471608	470545	89017R	PARTICIPANT	\N	PRESENT	0
471609	470545	19741B	PARTICIPANT	\N	PRESENT	0
471610	469127	14093U	PARTICIPANT	\N	PRESENT	0
471611	470545	19667J	PARTICIPANT	\N	PRESENT	0
471612	469127	18083K	PARTICIPANT	\N	PRESENT	0
471613	470545	96004D	PARTICIPANT	\N	PRESENT	0
471614	469127	19701S	PARTICIPANT	\N	PRESENT	0
471615	469127	11065P	PARTICIPANT	\N	PRESENT	0
459224	459086	98035U	PARTICIPANT	\N	PRESENT	0
459226	459085	98035U	PARTICIPANT	\N	PRESENT	0
459229	459087	98035U	PARTICIPANT	\N	PRESENT	0
459230	459157	98035U	PARTICIPANT	\N	PRESENT	0
459231	459088	98035U	PARTICIPANT	\N	PRESENT	0
459232	459185	98035U	PARTICIPANT	\N	PRESENT	0
459233	459188	98035U	PARTICIPANT	\N	PRESENT	0
459242	459241	98035U	PARTICIPANT	\N	PRESENT	0
459245	459243	98035U	PARTICIPANT	\N	PRESENT	0
460087	460086	04044E	PARTICIPANT	\N	PRESENT	0
460088	460086	14051J	PARTICIPANT	\N	PRESENT	0
460089	460086	04045F	PARTICIPANT	\N	PRESENT	0
460090	460086	19533U	PARTICIPANT	\N	PRESENT	0
460094	460086	19749K	PARTICIPANT	\N	PRESENT	0
460092	460086	08017T	PARTICIPANT	\N	PRESENT	0
460093	460086	19503N	PARTICIPANT	\N	PRESENT	0
460530	458797	19565D	PARTICIPANT	\N	PRESENT	0
460531	458797	19798U	PARTICIPANT	\N	PRESENT	0
460532	458797	08052W	PARTICIPANT	\N	PRESENT	0
460533	458797	19415P	PARTICIPANT	\N	PRESENT	0
460534	458797	19691J	PARTICIPANT	\N	PRESENT	0
460535	458797	14227Q	PARTICIPANT	\N	PRESENT	0
460536	458797	19723Y	PARTICIPANT	\N	PRESENT	0
460537	458797	14119M	PARTICIPANT	\N	PRESENT	0
460538	458797	14087W	PARTICIPANT	\N	PRESENT	0
460539	458797	11103C	PARTICIPANT	\N	PRESENT	0
460540	458797	19679N	PARTICIPANT	\N	PRESENT	0
460541	458797	19367Y	PARTICIPANT	\N	PRESENT	0
460542	458797	14071N	PARTICIPANT	\N	PRESENT	0
460543	458797	14217N	PARTICIPANT	\N	PRESENT	0
460544	458797	10006L	PARTICIPANT	0	PRESENT	0
460545	458797	19760E	PARTICIPANT	\N	PRESENT	0
460546	458797	98024R	PRESIDENT	0	PRESENT	0
460547	458653	14327T	PARTICIPANT	\N	PRESENT	0
460548	458653	14331P	PARTICIPANT	\N	PRESENT	0
460549	458653	04071H	PARTICIPANT	\N	PRESENT	0
460550	458653	95041E	PARTICIPANT	\N	PRESENT	0
460551	458653	01057W	PARTICIPANT	\N	PRESENT	0
460552	458653	11074Q	PRESIDENT	0	PRESENT	0
460553	458653	89017R	PARTICIPANT	\N	PRESENT	0
460554	458653	11070L	PARTICIPANT	\N	PRESENT	0
460555	458653	88008L	PARTICIPANT	\N	PRESENT	0
460556	458653	19671E	PARTICIPANT	\N	PRESENT	0
460557	458653	07029T	PARTICIPANT	\N	PRESENT	0
460558	458653	14277B	PARTICIPANT	\N	PRESENT	0
460559	458653	14085U	PARTICIPANT	\N	PRESENT	0
460560	458653	07004J	PARTICIPANT	\N	PRESENT	0
460561	458653	96004D	PARTICIPANT	\N	PRESENT	0
460562	458653	19349W	PARTICIPANT	\N	PRESENT	0
460563	458653	08010L	PARTICIPANT	\N	PRESENT	0
460564	458653	14253S	PARTICIPANT	\N	PRESENT	0
460565	458653	19479G	PARTICIPANT	\N	PRESENT	0
460566	458653	11048N	PARTICIPANT	\N	PRESENT	0
460567	458653	19647E	PARTICIPANT	\N	PRESENT	0
460568	458653	19711U	PARTICIPANT	\N	PRESENT	0
460569	458653	08034U	PARTICIPANT	\N	PRESENT	0
460570	458653	19531S	PARTICIPANT	\N	PRESENT	0
460571	458653	19687N	PARTICIPANT	\N	PRESENT	0
460572	458653	08011M	PARTICIPANT	\N	PRESENT	0
460573	458653	08014Q	PARTICIPANT	\N	PRESENT	0
460574	458653	14173T	PARTICIPANT	\N	PRESENT	0
460575	458653	11040E	PARTICIPANT	\N	PRESENT	0
460576	458653	04086Q	PARTICIPANT	\N	PRESENT	0
460577	458653	14083S	PARTICIPANT	\N	PRESENT	0
460578	458653	11012A	PARTICIPANT	\N	PRESENT	0
460579	458653	14199E	PARTICIPANT	\N	PRESENT	0
460580	458653	19741B	PARTICIPANT	\N	PRESENT	0
460581	458653	14121F	PARTICIPANT	\N	PRESENT	0
460582	458653	99004R	PARTICIPANT	\N	PRESENT	0
460583	458797	11067R	PARTICIPANT	\N	PRESENT	0
460584	458797	11097X	PARTICIPANT	\N	PRESENT	0
460585	458797	14026U	PARTICIPANT	\N	PRESENT	0
460586	458797	19703U	PARTICIPANT	\N	PRESENT	0
460587	458797	14281W	PARTICIPANT	\N	PRESENT	0
460588	458797	14042U	PARTICIPANT	\N	PRESENT	0
460589	458797	19575F	PARTICIPANT	\N	PRESENT	0
460590	458797	14213J	PARTICIPANT	\N	PRESENT	0
460591	458797	19527W	PARTICIPANT	\N	PRESENT	0
460592	458797	01034P	PARTICIPANT	\N	PRESENT	0
460593	458797	04092N	PRESIDENT	1	PRESENT	0
460594	458797	14195A	PARTICIPANT	\N	EXCUSE	0
460595	458797	08041T	PARTICIPANT	\N	EXCUSE	0
460597	459124	19515S	PARTICIPANT	\N	PRESENT	0
460598	459124	19782L	PARTICIPANT	\N	PRESENT	0
460599	459124	14187A	PARTICIPANT	\N	PRESENT	0
460600	459124	19812Y	PARTICIPANT	\N	PRESENT	0
460601	459124	19413M	PARTICIPANT	\N	PRESENT	0
460602	459124	14081Q	PARTICIPANT	\N	PRESENT	0
460603	459124	19695N	PARTICIPANT	\N	PRESENT	0
460604	459124	14033T	PARTICIPANT	\N	PRESENT	0
460605	459124	80013X	PARTICIPANT	\N	PRESENT	0
460606	459124	04045F	PARTICIPANT	\N	PRESENT	0
460607	459124	19631V	PARTICIPANT	\N	PRESENT	0
460608	459124	04088S	PARTICIPANT	\N	PRESENT	0
460609	459124	08068F	PARTICIPANT	\N	PRESENT	0
460610	459124	14115H	PARTICIPANT	\N	PRESENT	0
460611	459124	14197C	PARTICIPANT	\N	PRESENT	0
460612	459124	14207L	PARTICIPANT	\N	PRESENT	0
460613	459124	19747H	PARTICIPANT	\N	PRESENT	0
460614	459124	08028W	PARTICIPANT	\N	PRESENT	0
460615	459124	14265W	PARTICIPANT	\N	PRESENT	0
460616	459124	14257W	PARTICIPANT	\N	PRESENT	0
460624	459124	01043Q	PARTICIPANT	\N	PRESENT	0
460625	459124	19441R	PARTICIPANT	\N	PRESENT	0
460626	459124	19705W	PARTICIPANT	\N	PRESENT	0
460627	459124	08015R	PARTICIPANT	\N	PRESENT	0
460628	459124	08019V	PARTICIPANT	\N	PRESENT	0
460629	459124	19511N	PARTICIPANT	\N	PRESENT	0
460630	459124	19563B	PARTICIPANT	\N	PRESENT	0
460631	459124	08062Y	PARTICIPANT	\N	PRESENT	0
460632	459124	01025N	PARTICIPANT	\N	PRESENT	0
460633	459124	11090Q	PRESIDENT	0	PRESENT	0
460634	459124	11101A	PARTICIPANT	\N	PRESENT	0
460635	459124	19619A	PARTICIPANT	\N	PRESENT	0
460638	459124	19467C	PARTICIPANT	\N	PRESENT	0
460694	458797	19521Q	PARTICIPANT	\N	PRESENT	0
460695	458654	14327T	PARTICIPANT	\N	PRESENT	0
460697	458654	04071H	PARTICIPANT	\N	PRESENT	0
460698	458654	95041E	PARTICIPANT	\N	PRESENT	0
460700	458654	01057W	PARTICIPANT	\N	PRESENT	0
460701	458654	11053K	PARTICIPANT	\N	PRESENT	0
460702	458654	89017R	PARTICIPANT	\N	PRESENT	0
460703	458654	11074Q	PRESIDENT	0	PRESENT	0
460705	458654	88008L	PARTICIPANT	\N	PRESENT	0
460706	458654	11070L	PARTICIPANT	\N	PRESENT	0
460707	458654	11110B	PARTICIPANT	\N	PRESENT	0
460708	458654	07029T	PARTICIPANT	\N	PRESENT	0
460709	458654	14085U	PARTICIPANT	\N	PRESENT	0
460710	458654	14277B	PARTICIPANT	\N	PRESENT	0
460711	458654	07004J	PARTICIPANT	\N	PRESENT	0
460712	458654	96004D	PARTICIPANT	\N	PRESENT	0
460713	458654	19349W	PARTICIPANT	\N	PRESENT	0
460714	458654	08010L	PARTICIPANT	\N	PRESENT	0
460716	458654	11048N	PARTICIPANT	\N	PRESENT	0
460717	458654	19479G	PARTICIPANT	\N	PRESENT	0
460718	458654	19647E	PARTICIPANT	\N	PRESENT	0
460721	458654	19531S	PARTICIPANT	\N	PRESENT	0
460722	458654	19687N	PARTICIPANT	\N	PRESENT	0
460724	458654	08011M	PARTICIPANT	\N	PRESENT	0
460725	458654	08014Q	PARTICIPANT	\N	PRESENT	0
460726	458654	14034U	PARTICIPANT	\N	PRESENT	0
460727	458654	14159V	PARTICIPANT	\N	PRESENT	0
460728	458654	14173T	PARTICIPANT	\N	PRESENT	0
460729	458654	04086Q	PARTICIPANT	\N	PRESENT	0
460730	458654	11040E	PARTICIPANT	\N	PRESENT	0
460731	458654	14083S	PARTICIPANT	\N	PRESENT	0
460732	458654	11012A	PARTICIPANT	\N	PRESENT	0
460733	458654	19741B	PARTICIPANT	\N	PRESENT	0
460734	458654	14121F	PARTICIPANT	\N	PRESENT	0
460735	458654	99004R	PARTICIPANT	\N	PRESENT	0
460736	459124	14357A	PARTICIPANT	\N	EXCUSE	0
460737	459124	19369B	PARTICIPANT	\N	EXCUSE	0
460738	459124	19295A	PARTICIPANT	\N	EXCUSE	0
460740	460596	04059M	PARTICIPANT	\N	PRESENT	0
460741	460596	14123H	PARTICIPANT	\N	PRESENT	0
460742	460596	19749K	PARTICIPANT	\N	PRESENT	0
460743	460596	19621T	PARTICIPANT	\N	PRESENT	0
460744	459124	14135M	PARTICIPANT	\N	PRESENT	0
460755	459124	04089T	PARTICIPANT	\N	PRESENT	0
460758	459124	11099A	PARTICIPANT	\N	PRESENT	0
460759	458947	14111D	PARTICIPANT	\N	PRESENT	0
460760	458947	04038G	PARTICIPANT	\N	PRESENT	0
473874	470444	14329V	PARTICIPANT	\N	PRESENT	0
473924	470444	11064N	PARTICIPANT	\N	PRESENT	0
473903	470444	19820Y	PARTICIPANT	\N	PRESENT	0
473904	470444	19689Q	PARTICIPANT	\N	PRESENT	0
473905	470444	11045K	PARTICIPANT	\N	PRESENT	0
473906	470444	14085U	PARTICIPANT	\N	PRESENT	0
473907	470444	14021P	PARTICIPANT	\N	PRESENT	0
473908	470444	19591F	PARTICIPANT	\N	PRESENT	0
473909	470444	01034P	PARTICIPANT	\N	PRESENT	0
473910	470444	19569H	PARTICIPANT	\N	PRESENT	0
473911	470444	19693L	PARTICIPANT	\N	PRESENT	0
473912	470444	14157T	PARTICIPANT	\N	PRESENT	0
473913	470444	19711U	PARTICIPANT	\N	PRESENT	0
473914	470444	14071N	PARTICIPANT	\N	PRESENT	0
473915	470444	19533U	PARTICIPANT	\N	PRESENT	0
473916	470444	19551W	PARTICIPANT	\N	PRESENT	0
473917	470444	04059M	PARTICIPANT	\N	PRESENT	0
473918	470444	14081Q	PARTICIPANT	\N	PRESENT	0
473919	470444	19399H	PARTICIPANT	\N	PRESENT	0
473920	470444	18083K	PARTICIPANT	\N	PRESENT	0
473921	470444	14030Q	PARTICIPANT	\N	PRESENT	0
473922	470444	19647E	PARTICIPANT	\N	PRESENT	0
473923	470444	04085P	PARTICIPANT	\N	PRESENT	0
473925	470444	11012A	PARTICIPANT	\N	PRESENT	0
473927	470444	11048N	PARTICIPANT	\N	PRESENT	0
473929	470444	14083S	PARTICIPANT	\N	PRESENT	0
473930	470444	14249W	PARTICIPANT	\N	PRESENT	0
473935	470444	19593H	PARTICIPANT	\N	PRESENT	0
473936	470444	01028R	PARTICIPANT	\N	PRESENT	0
473937	470444	19631V	PARTICIPANT	\N	PRESENT	0
473938	470444	19489J	PARTICIPANT	\N	PRESENT	0
473939	470444	19671E	PARTICIPANT	\N	PRESENT	0
473940	470444	14215L	PARTICIPANT	\N	PRESENT	0
473998	470445	14215L	PARTICIPANT	\N	PRESENT	0
474042	470445	19667J	PARTICIPANT	\N	PRESENT	0
474000	470445	19551W	PARTICIPANT	\N	PRESENT	0
473864	470444	11070L	PARTICIPANT	\N	PRESENT	0
473873	470444	17779H	PARTICIPANT	\N	PRESENT	0
474001	470445	14085U	PARTICIPANT	\N	PRESENT	0
474002	470445	17779H	PARTICIPANT	\N	PRESENT	0
474003	470445	19489J	PARTICIPANT	\N	PRESENT	0
474008	470445	11045K	PARTICIPANT	\N	PRESENT	0
474009	470445	19631V	PARTICIPANT	\N	PRESENT	0
474010	470445	19689Q	PARTICIPANT	\N	PRESENT	0
474011	470445	11031D	PARTICIPANT	\N	PRESENT	0
474012	470445	19651A	PARTICIPANT	\N	PRESENT	0
474013	470445	05008E	PARTICIPANT	\N	PRESENT	0
474014	470445	19447X	PARTICIPANT	\N	PRESENT	0
474015	470445	14001X	PARTICIPANT	\N	PRESENT	0
474016	470445	11012A	PARTICIPANT	\N	PRESENT	0
474017	470445	14034U	PARTICIPANT	\N	PRESENT	0
474020	470445	11048N	PARTICIPANT	\N	PRESENT	0
474022	470445	18083K	PARTICIPANT	\N	PRESENT	0
474025	470445	19741B	PARTICIPANT	\N	PRESENT	0
474026	470445	19643A	PARTICIPANT	\N	PRESENT	0
474027	470445	14157T	PARTICIPANT	\N	PRESENT	0
474028	470445	11090Q	PARTICIPANT	\N	PRESENT	0
474029	470445	19695N	PARTICIPANT	\N	PRESENT	0
474040	470445	19671E	PARTICIPANT	\N	PRESENT	0
474041	470445	14329V	PARTICIPANT	\N	PRESENT	0
474043	470445	19399H	PARTICIPANT	\N	PRESENT	0
474044	470445	14083S	PARTICIPANT	\N	PRESENT	0
474045	470445	11097X	PARTICIPANT	\N	PRESENT	0
474051	470445	96004D	PARTICIPANT	\N	PRESENT	0
474053	470445	04033B	PARTICIPANT	\N	PRESENT	0
474070	470445	08031R	PARTICIPANT	\N	PRESENT	0
473993	470445	11070L	PARTICIPANT	\N	PRESENT	0
473997	470445	19693L	PARTICIPANT	\N	PRESENT	0
474074	470445	11064N	PARTICIPANT	\N	PRESENT	0
474093	470445	19593H	PARTICIPANT	\N	PRESENT	0
474096	470445	14213J	PARTICIPANT	\N	PRESENT	0
474097	470445	01028R	PARTICIPANT	\N	PRESENT	0
474098	470445	14021P	PARTICIPANT	\N	PRESENT	0
474099	470445	19503N	PARTICIPANT	\N	PRESENT	0
474100	470445	14179A	PARTICIPANT	\N	PRESENT	0
474101	470445	11026G	PARTICIPANT	\N	PRESENT	0
474102	470445	08010L	PARTICIPANT	\N	PRESENT	0
474146	470446	17779H	PARTICIPANT	\N	PRESENT	0
474147	470446	05008E	PARTICIPANT	\N	PRESENT	0
474148	470446	19447X	PARTICIPANT	\N	PRESENT	0
474149	470446	11031D	PARTICIPANT	\N	PRESENT	0
474150	470446	19689Q	PARTICIPANT	\N	PRESENT	0
474151	470446	19631V	PARTICIPANT	\N	PRESENT	0
474152	470446	19489J	PARTICIPANT	\N	PRESENT	0
474153	470446	14001X	PARTICIPANT	\N	PRESENT	0
474154	470446	14085U	PARTICIPANT	\N	PRESENT	0
474155	470446	11012A	PARTICIPANT	\N	PRESENT	0
474156	470446	11064N	PARTICIPANT	\N	PRESENT	0
474157	470446	08031R	PARTICIPANT	\N	PRESENT	0
474158	470446	19651A	PARTICIPANT	\N	PRESENT	0
474159	470446	14179A	PARTICIPANT	\N	PRESENT	0
474160	470446	14083S	PARTICIPANT	\N	PRESENT	0
474161	470446	14157T	PARTICIPANT	\N	PRESENT	0
474162	470446	98050T	PARTICIPANT	\N	PRESENT	0
474163	470446	11090Q	PARTICIPANT	\N	PRESENT	0
474164	470446	04018C	PARTICIPANT	\N	PRESENT	0
474165	470446	19741B	PARTICIPANT	\N	PRESENT	0
474166	470446	96004D	PARTICIPANT	\N	PRESENT	0
474167	470446	19693L	PARTICIPANT	\N	PRESENT	0
474168	470446	11026G	PARTICIPANT	\N	PRESENT	0
474169	470446	19671E	PARTICIPANT	\N	PRESENT	0
474170	470446	19667J	PARTICIPANT	\N	PRESENT	0
474171	470446	19593H	PARTICIPANT	\N	PRESENT	0
474172	470446	14215L	PARTICIPANT	\N	PRESENT	0
474173	470446	14213J	PARTICIPANT	\N	PRESENT	0
474174	470446	19503N	PARTICIPANT	\N	PRESENT	0
474175	470446	19643A	PARTICIPANT	\N	PRESENT	0
474176	470446	19399H	PARTICIPANT	\N	PRESENT	0
474177	470446	11097X	PARTICIPANT	\N	PRESENT	0
474178	470446	19531S	PARTICIPANT	\N	PRESENT	0
474179	470446	19695N	PARTICIPANT	\N	PRESENT	0
474180	470446	11083R	PARTICIPANT	\N	PRESENT	0
474181	470446	11027H	PARTICIPANT	\N	PRESENT	0
474182	470446	08011M	PARTICIPANT	\N	PRESENT	0
474183	470446	04086Q	PARTICIPANT	\N	PRESENT	0
474186	474185	11027H	PARTICIPANT	\N	PRESENT	0
474187	474185	19709B	PARTICIPANT	\N	PRESENT	0
474189	474188	11027H	PARTICIPANT	\N	PRESENT	0
474190	474188	19709B	PARTICIPANT	\N	PRESENT	0
474145	470446	01028R	PARTICIPANT	\N	PRESENT	0
474191	474188	14255U	PARTICIPANT	\N	PRESENT	0
474196	473926	19629C	PARTICIPANT	\N	PRESENT	0
474197	473926	14267Y	PARTICIPANT	\N	PRESENT	0
474198	473926	19525U	PARTICIPANT	\N	PRESENT	0
474199	473926	14259Y	PARTICIPANT	\N	PRESENT	0
474200	473926	04035D	PARTICIPANT	\N	PRESENT	0
474201	473926	19695N	PARTICIPANT	\N	PRESENT	0
474202	473926	19715Y	PARTICIPANT	\N	PRESENT	0
474203	473926	16685X	PARTICIPANT	\N	PRESENT	0
474204	473926	19729F	PARTICIPANT	\N	PRESENT	0
474205	473926	19826F	PARTICIPANT	\N	PRESENT	0
474206	473926	95067Q	PARTICIPANT	\N	PRESENT	0
474207	473926	14039A	PARTICIPANT	\N	PRESENT	0
474208	473926	14059S	PARTICIPANT	\N	PRESENT	0
474209	473926	19295A	PARTICIPANT	\N	PRESENT	0
474211	474210	19545Y	PARTICIPANT	\N	PRESENT	0
474212	474210	19689Q	PARTICIPANT	\N	PRESENT	0
474214	474213	19545Y	PARTICIPANT	\N	PRESENT	0
474215	474213	19689Q	PARTICIPANT	\N	PRESENT	0
474217	474216	19741B	PARTICIPANT	\N	PRESENT	0
474219	474218	14253S	PARTICIPANT	\N	PRESENT	0
474227	474226	14253S	PARTICIPANT	\N	PRESENT	0
474229	474228	14253S	PARTICIPANT	\N	PRESENT	0
474263	474262	14083S	PARTICIPANT	\N	PRESENT	0
474265	474264	14083S	PARTICIPANT	\N	PRESENT	0
474266	472015	08056B	PRESIDENT	0	PRESENT	0
474267	472015	10015M	PARTICIPANT	\N	PRESENT	0
474268	472015	04040A	PARTICIPANT	\N	PRESENT	0
474269	472015	04044E	PARTICIPANT	\N	PRESENT	0
474270	472015	19673G	PARTICIPANT	\N	PRESENT	0
474271	472015	19719D	PARTICIPANT	\N	EXCUSE	0
474273	474272	14083S	PARTICIPANT	\N	PRESENT	0
474469	474195	14041T	PARTICIPANT	\N	PRESENT	0
474470	474195	11026G	PARTICIPANT	\N	PRESENT	0
474471	474195	14147R	PARTICIPANT	\N	PRESENT	0
474472	474195	14179A	PARTICIPANT	\N	PRESENT	0
474473	474195	01024M	PARTICIPANT	\N	PRESENT	0
474474	474195	11085T	PARTICIPANT	\N	PRESENT	0
474475	474195	01028R	PARTICIPANT	\N	PRESENT	0
474476	474195	19447X	PARTICIPANT	\N	PRESENT	0
474477	474195	19762G	PARTICIPANT	\N	PRESENT	0
474478	474195	05008E	PRESIDENT	0	PRESENT	0
474479	474195	14231L	PARTICIPANT	\N	PRESENT	0
474480	470579	11072N	PARTICIPANT	\N	PRESENT	0
474481	474195	19585H	PARTICIPANT	\N	PRESENT	0
474484	470579	11040E	PARTICIPANT	\N	PRESENT	0
474485	470579	19565D	PARTICIPANT	\N	PRESENT	0
474496	470579	19689Q	PARTICIPANT	\N	PRESENT	0
474827	474327	14053L	PARTICIPANT	\N	PRESENT	0
456274	456273	14265W	PARTICIPANT	\N	PRESENT	0
456275	456273	14219Q	PARTICIPANT	\N	PRESENT	0
456276	456273	19575F	PARTICIPANT	\N	PRESENT	0
456277	456273	01058X	PARTICIPANT	\N	PRESENT	0
456278	456273	11101A	PARTICIPANT	\N	PRESENT	0
456279	456273	19349W	PARTICIPANT	\N	PRESENT	0
456280	456273	19711U	PARTICIPANT	\N	PRESENT	0
456281	456273	19631V	PARTICIPANT	\N	PRESENT	0
456282	456273	95063L	PARTICIPANT	\N	PRESENT	0
456283	456273	19521Q	PARTICIPANT	\N	PRESENT	0
456284	456273	19333N	PARTICIPANT	\N	PRESENT	0
456285	456273	19479G	PARTICIPANT	\N	PRESENT	0
456286	456273	19629C	PARTICIPANT	\N	PRESENT	0
456287	456273	19621T	PARTICIPANT	\N	PRESENT	0
456775	456200	08024S	PARTICIPANT	\N	PRESENT	0
456776	456200	08045X	PARTICIPANT	\N	EXCUSE	0
462878	462694	04042C	PARTICIPANT	\N	PRESENT	0
462879	462694	05008E	PARTICIPANT	\N	PRESENT	0
462880	462694	19543W	PARTICIPANT	\N	PRESENT	0
462881	462694	19591F	PARTICIPANT	\N	PRESENT	0
462882	462694	08034U	PARTICIPANT	\N	PRESENT	0
462883	462694	19545Y	PARTICIPANT	\N	PRESENT	0
462884	462694	19762G	PARTICIPANT	\N	PRESENT	0
462885	462694	89017R	PARTICIPANT	\N	PRESENT	0
462886	462694	19585H	PARTICIPANT	\N	PRESENT	0
462887	462694	11070L	PARTICIPANT	\N	PRESENT	0
462888	462694	19441R	PARTICIPANT	\N	PRESENT	0
462889	462694	14251Q	PARTICIPANT	\N	PRESENT	0
462890	462694	04035D	PARTICIPANT	\N	PRESENT	0
462891	462694	08061X	PARTICIPANT	\N	PRESENT	0
462892	462694	04033B	PARTICIPANT	\N	PRESENT	0
462893	462694	11085T	PARTICIPANT	\N	PRESENT	0
462894	462694	19691J	PARTICIPANT	\N	PRESENT	0
462895	462694	01043Q	PARTICIPANT	\N	PRESENT	0
462896	462694	11026G	PARTICIPANT	\N	PRESENT	0
462897	462694	04043D	PARTICIPANT	\N	PRESENT	0
462898	462694	04086Q	PARTICIPANT	\N	PRESENT	0
462899	462694	08009T	PARTICIPANT	\N	PRESENT	0
462900	462694	19611R	PARTICIPANT	\N	PRESENT	0
462901	462694	14157T	PARTICIPANT	\N	PRESENT	0
462902	462694	04092N	PARTICIPANT	\N	PRESENT	0
462903	462694	07033P	PARTICIPANT	\N	PRESENT	0
462904	462694	14217N	PARTICIPANT	\N	PRESENT	0
462905	462694	14237S	PARTICIPANT	\N	PRESENT	0
462906	462694	04085P	PARTICIPANT	\N	PRESENT	0
462907	462694	95063L	PARTICIPANT	\N	PRESENT	0
462988	462695	11033F	PARTICIPANT	\N	PRESENT	0
462989	462695	19593H	PARTICIPANT	\N	PRESENT	0
462990	462695	19719D	PARTICIPANT	\N	PRESENT	0
462991	462695	14251Q	PARTICIPANT	\N	PRESENT	0
462992	462695	19441R	PARTICIPANT	\N	PRESENT	0
462993	462695	14231L	PARTICIPANT	\N	PRESENT	0
462994	462695	19691J	PARTICIPANT	\N	PRESENT	0
462995	462695	14329V	PARTICIPANT	\N	PRESENT	0
462996	462695	07033P	PARTICIPANT	\N	PRESENT	0
462997	462695	98050T	PARTICIPANT	\N	PRESENT	0
462998	462695	95041E	PARTICIPANT	\N	PRESENT	0
462999	462695	19673G	PARTICIPANT	\N	PRESENT	0
463000	462695	19611R	PARTICIPANT	\N	PRESENT	0
463001	462695	19447X	PARTICIPANT	\N	PRESENT	0
463002	462695	11090Q	PARTICIPANT	\N	PRESENT	0
463003	462695	19812Y	PARTICIPANT	\N	PRESENT	0
463004	462695	19525U	PARTICIPANT	\N	PRESENT	0
463005	462695	11066Q	PARTICIPANT	\N	PRESENT	0
463006	462695	04034C	PARTICIPANT	\N	PRESENT	0
463007	462695	14157T	PARTICIPANT	\N	PRESENT	0
463008	462695	08009T	PARTICIPANT	\N	PRESENT	0
463009	462695	14055N	PARTICIPANT	\N	PRESENT	0
463010	462695	14249W	PARTICIPANT	\N	PRESENT	0
463011	462695	14215L	PARTICIPANT	\N	PRESENT	0
463012	462695	19543W	PARTICIPANT	\N	PRESENT	0
463013	462695	14257W	PARTICIPANT	\N	PRESENT	0
463014	462695	12041X	PARTICIPANT	\N	PRESENT	0
463015	462695	19649G	PARTICIPANT	\N	PRESENT	0
463016	462695	11031D	PARTICIPANT	\N	PRESENT	0
463017	462695	08010L	PARTICIPANT	\N	PRESENT	0
463018	462695	04047H	PARTICIPANT	\N	PRESENT	0
463019	462695	04086Q	PARTICIPANT	\N	PRESENT	0
463020	462695	19762G	PARTICIPANT	\N	PRESENT	0
463021	462695	11070L	PARTICIPANT	\N	PRESENT	0
463022	462695	04059M	PARTICIPANT	\N	PRESENT	0
463023	462695	19683J	PARTICIPANT	\N	PRESENT	0
463024	462695	01028R	PARTICIPANT	\N	PRESENT	0
463025	462695	11074Q	PARTICIPANT	\N	PRESENT	0
463026	462695	19689Q	PARTICIPANT	\N	PRESENT	0
463027	462695	14071N	PARTICIPANT	\N	PRESENT	0
463028	462695	19413M	PARTICIPANT	\N	PRESENT	0
463029	462695	04033B	PARTICIPANT	\N	PRESENT	0
463030	462695	14021P	PARTICIPANT	\N	PRESENT	0
463031	462695	19669L	PARTICIPANT	\N	PRESENT	0
463032	462695	14034U	PARTICIPANT	\N	PRESENT	0
463033	462695	19591F	PARTICIPANT	\N	PRESENT	0
463034	462695	11026G	PARTICIPANT	\N	PRESENT	0
463035	462695	04092N	PARTICIPANT	\N	PRESENT	0
463036	462695	19563B	PARTICIPANT	\N	PRESENT	0
463037	462695	05008E	PARTICIPANT	\N	PRESENT	0
463038	462695	19699S	PARTICIPANT	\N	PRESENT	0
463039	462695	19545Y	PARTICIPANT	\N	PRESENT	0
463040	462695	11085T	PARTICIPANT	\N	PRESENT	0
463041	462695	95063L	PARTICIPANT	\N	PRESENT	0
463042	462695	08061X	PARTICIPANT	\N	PRESENT	0
463043	462695	07004J	PARTICIPANT	\N	PRESENT	0
463044	462695	19585H	PARTICIPANT	\N	PRESENT	0
463045	462695	04042C	PARTICIPANT	\N	PRESENT	0
463046	462695	19643A	PARTICIPANT	\N	PRESENT	0
463047	462695	04035D	PARTICIPANT	\N	PRESENT	0
463048	462695	04043D	PARTICIPANT	\N	PRESENT	0
463049	462695	08034U	PARTICIPANT	\N	PRESENT	0
463050	462695	11053K	PARTICIPANT	\N	PRESENT	0
463051	462695	05012A	PARTICIPANT	\N	PRESENT	0
463052	462695	01043Q	PARTICIPANT	\N	PRESENT	0
463053	462695	10006L	PARTICIPANT	\N	PRESENT	0
463054	462695	19695N	PARTICIPANT	\N	PRESENT	0
463055	462695	04085P	PARTICIPANT	\N	PRESENT	0
463056	462695	89017R	PARTICIPANT	\N	PRESENT	0
463057	462695	11097X	PARTICIPANT	\N	PRESENT	0
463058	462687	95063L	PARTICIPANT	\N	PRESENT	0
463059	462687	14215L	PARTICIPANT	\N	PRESENT	0
463060	462687	19585H	PARTICIPANT	\N	PRESENT	0
463061	462687	19673G	PARTICIPANT	\N	PRESENT	0
463062	462687	19719D	PARTICIPANT	\N	PRESENT	0
463063	462687	01028R	PARTICIPANT	\N	PRESENT	0
462986	462695	86034E	PARTICIPANT	\N	PRESENT	0
462987	462695	11045K	PARTICIPANT	\N	PRESENT	0
463064	462687	11033F	PARTICIPANT	\N	PRESENT	0
463065	462687	19447X	PARTICIPANT	\N	PRESENT	0
463066	462687	05008E	PRESIDENT	0	PRESENT	0
463129	462696	86034E	PARTICIPANT	\N	PRESENT	0
463130	462696	19593H	PARTICIPANT	\N	PRESENT	0
463131	462696	19611R	PARTICIPANT	\N	PRESENT	0
463132	462696	19413M	PARTICIPANT	\N	PRESENT	0
463133	462696	19699S	PARTICIPANT	\N	PRESENT	0
463134	462696	11031D	PARTICIPANT	\N	PRESENT	0
463135	462696	01028R	PARTICIPANT	\N	PRESENT	0
463136	462696	07004J	PARTICIPANT	\N	PRESENT	0
463137	462696	14157T	PARTICIPANT	\N	PRESENT	0
463138	462696	11033F	PARTICIPANT	\N	PRESENT	0
463139	462696	11045K	PARTICIPANT	\N	PRESENT	0
463140	462696	11026G	PARTICIPANT	\N	PRESENT	0
463141	462696	11097X	PARTICIPANT	\N	PRESENT	0
463142	462696	04092N	PARTICIPANT	\N	PRESENT	0
463143	462696	19649G	PARTICIPANT	\N	PRESENT	0
463144	462696	12041X	PARTICIPANT	\N	PRESENT	0
463145	462696	19812Y	PARTICIPANT	\N	PRESENT	0
463146	462696	19591F	PARTICIPANT	\N	PRESENT	0
463147	462696	11090Q	PARTICIPANT	\N	PRESENT	0
463148	462696	04086Q	PARTICIPANT	\N	PRESENT	0
463149	462696	19695N	PARTICIPANT	\N	PRESENT	0
463150	462696	19689Q	PARTICIPANT	\N	PRESENT	0
463151	462696	14257W	PARTICIPANT	\N	PRESENT	0
463152	462696	04085P	PARTICIPANT	\N	PRESENT	0
463153	462696	05008E	PARTICIPANT	\N	PRESENT	0
463154	462696	19543W	PARTICIPANT	\N	PRESENT	0
463155	462696	14021P	PARTICIPANT	\N	PRESENT	0
463156	462696	14071N	PARTICIPANT	\N	PRESENT	0
463157	462696	04033B	PARTICIPANT	\N	PRESENT	0
463158	462696	14329V	PARTICIPANT	\N	PRESENT	0
463159	462696	14055N	PARTICIPANT	\N	PRESENT	0
463160	462696	14231L	PARTICIPANT	\N	PRESENT	0
463161	462696	04047H	PARTICIPANT	\N	PRESENT	0
463162	462696	19563B	PARTICIPANT	\N	PRESENT	0
463163	462696	08010L	PARTICIPANT	\N	PRESENT	0
463164	462696	04035D	PARTICIPANT	\N	PRESENT	0
463165	462696	19545Y	PARTICIPANT	\N	PRESENT	0
463166	462696	11053K	PARTICIPANT	\N	PRESENT	0
463167	462696	19447X	PARTICIPANT	\N	PRESENT	0
463168	462696	19585H	PARTICIPANT	\N	PRESENT	0
463169	462696	89017R	PARTICIPANT	\N	PRESENT	0
463170	462696	08061X	PARTICIPANT	\N	PRESENT	0
471616	469127	19820Y	PARTICIPANT	\N	PRESENT	0
471617	469127	19347U	PARTICIPANT	\N	PRESENT	0
471618	470545	11040E	PARTICIPANT	\N	PRESENT	0
471619	469127	19387D	PARTICIPANT	\N	PRESENT	0
471620	470545	14083S	PARTICIPANT	\N	PRESENT	0
471621	469127	19333N	PARTICIPANT	\N	PRESENT	0
471622	470545	19545Y	PARTICIPANT	\N	PRESENT	0
471623	469127	04097T	PARTICIPANT	\N	PRESENT	0
471624	470545	14085U	PARTICIPANT	\N	PRESENT	0
471625	469127	14029X	PARTICIPANT	\N	PRESENT	0
471626	470545	88008L	PARTICIPANT	\N	PRESENT	0
471627	469127	14219Q	PARTICIPANT	\N	PRESENT	0
471628	469127	14031R	PARTICIPANT	\N	PRESENT	0
471629	470545	04086Q	PARTICIPANT	\N	PRESENT	0
471630	470545	11074Q	PRESIDENT	0	PRESENT	0
471631	469127	19637C	PARTICIPANT	\N	PRESENT	0
471632	470545	11110B	PARTICIPANT	\N	PRESENT	0
471633	469127	08009T	PRESIDENT	0	PRESENT	0
471634	470545	14034U	PARTICIPANT	\N	PRESENT	0
471635	469127	14237S	PARTICIPANT	\N	PRESENT	0
471636	470545	01057W	PARTICIPANT	\N	PRESENT	0
471637	470545	19531S	PARTICIPANT	\N	PRESENT	0
471638	470545	99004R	PARTICIPANT	\N	PRESENT	0
471639	470545	19711U	PARTICIPANT	\N	PRESENT	0
471640	470545	08010L	PARTICIPANT	\N	PRESENT	0
471641	469127	19503N	PARTICIPANT	\N	PRESENT	0
471642	470545	01048V	PARTICIPANT	\N	PRESENT	0
471643	469127	19794Q	PARTICIPANT	\N	PRESENT	0
471644	470545	19671E	PARTICIPANT	\N	PRESENT	0
471645	469127	19713W	PARTICIPANT	\N	PRESENT	0
471646	470545	08011M	PARTICIPANT	\N	PRESENT	0
471647	469127	14051J	PARTICIPANT	\N	PRESENT	0
471648	470545	14331P	PARTICIPANT	\N	PRESENT	0
471649	469127	14157T	PARTICIPANT	\N	PRESENT	0
471650	470545	14225N	PARTICIPANT	\N	PRESENT	0
471651	469127	19737F	PARTICIPANT	\N	PRESENT	0
471652	469127	14038Y	PARTICIPANT	\N	PRESENT	0
471653	469127	19826F	PARTICIPANT	\N	PRESENT	0
471654	469127	19549D	PARTICIPANT	\N	PRESENT	0
471655	469127	19739H	PARTICIPANT	\N	PRESENT	0
471656	469127	17583W	PARTICIPANT	\N	PRESENT	0
471657	470545	19631V	PARTICIPANT	\N	PRESENT	0
471658	470545	19515S	PARTICIPANT	\N	PRESENT	0
471659	470545	14115H	PARTICIPANT	\N	PRESENT	0
471660	470545	19747H	PARTICIPANT	\N	PRESENT	0
471661	470545	19782L	PARTICIPANT	\N	PRESENT	0
471662	470545	14207L	PARTICIPANT	\N	PRESENT	0
471663	470545	11101A	PARTICIPANT	\N	PRESENT	0
471664	470545	08028W	PARTICIPANT	\N	PRESENT	0
471665	470545	19812Y	PARTICIPANT	\N	PRESENT	0
471666	470545	80013X	PARTICIPANT	\N	PRESENT	0
471667	470545	11056N	PARTICIPANT	\N	PRESENT	0
471668	470545	08038Y	PARTICIPANT	\N	PRESENT	0
471669	470545	19507S	PARTICIPANT	\N	PRESENT	0
471670	470545	14197C	PARTICIPANT	\N	PRESENT	0
471671	470545	14187A	PARTICIPANT	\N	PRESENT	0
471672	470545	14033T	PARTICIPANT	\N	PRESENT	0
471673	470545	14081Q	PARTICIPANT	\N	PRESENT	0
471674	470545	11099A	PARTICIPANT	\N	PRESENT	0
471675	470545	04049K	PARTICIPANT	\N	PRESENT	0
471676	470545	11077T	PARTICIPANT	\N	PRESENT	0
471677	470545	14205J	PARTICIPANT	\N	PRESENT	0
471678	470545	19563B	PARTICIPANT	\N	PRESENT	0
471679	470545	19768N	PARTICIPANT	\N	PRESENT	0
471680	470545	04088S	PARTICIPANT	\N	PRESENT	0
471681	470545	11090Q	PARTICIPANT	\N	PRESENT	0
471682	470545	14135M	PARTICIPANT	\N	PRESENT	0
471683	470545	19705W	PARTICIPANT	\N	PRESENT	0
471684	470545	19479G	PARTICIPANT	\N	PRESENT	0
471685	470545	14257W	PARTICIPANT	\N	PRESENT	0
471797	471796	19399H	PARTICIPANT	\N	PRESENT	0
471798	471796	19735D	PARTICIPANT	\N	PRESENT	0
471799	471796	14229S	PARTICIPANT	\N	PRESENT	0
471892	470983	14241N	PARTICIPANT	\N	PRESENT	0
471893	470983	14073Q	PARTICIPANT	\N	PRESENT	0
471894	470983	19643A	PARTICIPANT	\N	PRESENT	0
471896	470983	08012N	PARTICIPANT	\N	PRESENT	0
471897	470983	11043H	PARTICIPANT	\N	PRESENT	0
471898	470983	14249W	PARTICIPANT	\N	PRESENT	0
471967	471568	19631V	PARTICIPANT	\N	PRESENT	0
471968	471568	19515S	PARTICIPANT	\N	PRESENT	0
471969	471568	14115H	PARTICIPANT	\N	PRESENT	0
471970	471568	19747H	PARTICIPANT	\N	PRESENT	0
471971	471568	19782L	PARTICIPANT	\N	PRESENT	0
471972	471568	14207L	PARTICIPANT	\N	PRESENT	0
471973	471568	11101A	PARTICIPANT	\N	PRESENT	0
471974	471568	08028W	PARTICIPANT	\N	PRESENT	0
471975	471568	19467C	PARTICIPANT	\N	EXCUSE	0
471976	471568	19812Y	PARTICIPANT	\N	PRESENT	0
471977	471568	80013X	PARTICIPANT	\N	PRESENT	0
471978	471568	11056N	PARTICIPANT	\N	PRESENT	0
471979	471568	08038Y	PARTICIPANT	\N	PRESENT	0
471980	471568	19507S	PARTICIPANT	\N	PRESENT	0
471981	471568	14197C	PARTICIPANT	\N	PRESENT	0
471982	471568	14187A	PARTICIPANT	\N	PRESENT	0
471983	471568	14033T	PARTICIPANT	\N	PRESENT	0
471984	471568	14081Q	PARTICIPANT	\N	PRESENT	0
471985	471568	11099A	PARTICIPANT	\N	PRESENT	0
471986	471568	04049K	PARTICIPANT	\N	PRESENT	0
471987	471568	11077T	PARTICIPANT	\N	PRESENT	0
471988	471568	14205J	PARTICIPANT	\N	PRESENT	0
471989	471568	19563B	PARTICIPANT	\N	PRESENT	0
471990	471568	14257W	PARTICIPANT	\N	PRESENT	0
471991	471568	19768N	PARTICIPANT	\N	PRESENT	0
471992	471568	04088S	PARTICIPANT	\N	PRESENT	0
471993	471568	11090Q	PRESIDENT	0	PRESENT	0
471994	471568	14135M	PARTICIPANT	\N	PRESENT	0
471995	471568	19705W	PARTICIPANT	\N	PRESENT	0
471998	471997	14229S	PARTICIPANT	\N	PRESENT	0
471999	471997	08031R	PARTICIPANT	\N	PRESENT	0
472000	471997	14059S	PARTICIPANT	\N	PRESENT	0
472076	470979	11083R	PARTICIPANT	\N	PRESENT	0
472077	470979	08039A	PARTICIPANT	\N	PRESENT	0
472078	470980	19399H	PARTICIPANT	\N	PRESENT	0
472079	470980	08039A	PARTICIPANT	\N	PRESENT	0
472080	470980	04070G	PARTICIPANT	\N	PRESENT	0
472081	470980	11083R	PARTICIPANT	\N	PRESENT	0
472167	471173	19479G	PARTICIPANT	\N	PRESENT	0
472168	467270	04059M	PARTICIPANT	\N	PRESENT	0
472169	467270	19335Q	PARTICIPANT	\N	PRESENT	0
472170	467270	11048N	PARTICIPANT	\N	PRESENT	0
472171	467270	08009T	PARTICIPANT	\N	PRESENT	0
472172	467270	04085P	PARTICIPANT	\N	PRESENT	0
472173	467270	14205J	PARTICIPANT	\N	PRESENT	0
472174	467270	19531S	PARTICIPANT	\N	PRESENT	0
472175	467270	14157T	PARTICIPANT	\N	PRESENT	0
472176	467270	19713W	PARTICIPANT	\N	PRESENT	0
472177	467270	19553Y	PARTICIPANT	\N	PRESENT	0
472178	467270	19693L	PARTICIPANT	\N	PRESENT	0
472179	467270	19269X	PARTICIPANT	\N	PRESENT	0
472180	467270	11115U	PARTICIPANT	\N	PRESENT	0
472181	472053	14053L	PARTICIPANT	\N	PRESENT	0
472182	472053	19489J	PARTICIPANT	\N	PRESENT	0
472183	472053	14041T	PARTICIPANT	\N	PRESENT	0
472184	472053	11026G	PARTICIPANT	\N	PRESENT	0
472185	472053	14179A	PARTICIPANT	\N	PRESENT	0
472186	472053	14001X	PARTICIPANT	\N	PRESENT	0
472187	472053	11085T	PARTICIPANT	\N	PRESENT	0
472188	472053	05008E	PRESIDENT	0	PRESENT	0
472189	472053	19447X	PARTICIPANT	\N	PRESENT	0
472190	472053	14021P	PARTICIPANT	\N	PRESENT	0
472191	472053	11072N	PARTICIPANT	\N	PRESENT	0
472192	467270	08031R	PARTICIPANT	\N	PRESENT	0
472193	467270	14265W	PARTICIPANT	\N	PRESENT	0
472194	467270	14147R	PARTICIPANT	\N	PRESENT	0
472195	467270	19621T	PARTICIPANT	\N	PRESENT	0
472196	467270	19691J	PARTICIPANT	\N	PRESENT	0
472197	467270	11031D	PARTICIPANT	\N	PRESENT	0
472198	467270	96004D	PARTICIPANT	\N	PRESENT	0
472199	467270	11110B	PARTICIPANT	\N	PRESENT	0
472212	467270	14179A	PARTICIPANT	\N	PRESENT	0
472255	467270	19685L	PARTICIPANT	\N	PRESENT	0
472256	467270	14041T	PARTICIPANT	\N	PRESENT	0
472257	467270	10006L	PARTICIPANT	\N	PRESENT	0
472258	467270	08010L	PARTICIPANT	\N	PRESENT	0
472259	467270	14259Y	PARTICIPANT	\N	PRESENT	0
472260	472052	04049K	PRESIDENT	0	PRESENT	0
472261	472052	19575F	PARTICIPANT	\N	PRESENT	0
472262	472052	14255U	PARTICIPANT	\N	PRESENT	0
472263	472052	14083S	PARTICIPANT	\N	PRESENT	0
472264	472052	14041T	PARTICIPANT	\N	PRESENT	0
472265	472052	14026U	PARTICIPANT	\N	PRESENT	0
472266	472052	08015R	PARTICIPANT	\N	PRESENT	0
472267	472052	14205J	PARTICIPANT	\N	PRESENT	0
472268	472052	19671E	PARTICIPANT	\N	PRESENT	0
472269	467270	11045K	PARTICIPANT	\N	PRESENT	0
472270	472052	19545Y	PARTICIPANT	\N	EXCUSE	0
472271	472052	08047A	PARTICIPANT	\N	EXCUSE	0
472272	467270	14038Y	PARTICIPANT	\N	PRESENT	0
456619	456093	14093U	PARTICIPANT	\N	PRESENT	0
456620	456093	19629C	PARTICIPANT	\N	PRESENT	0
456621	456093	14197C	PARTICIPANT	\N	PRESENT	0
456622	456093	11048N	PARTICIPANT	\N	PRESENT	0
456623	456093	14097Y	PARTICIPANT	\N	PRESENT	0
456624	456093	19611R	PARTICIPANT	\N	PRESENT	0
456625	456093	19581D	PARTICIPANT	\N	PRESENT	0
456626	456093	14031R	PARTICIPANT	\N	PRESENT	0
456627	456093	19369B	PRESIDENT	0	PRESENT	0
456628	456093	92040Q	PARTICIPANT	\N	PRESENT	0
456629	456093	08073C	PARTICIPANT	\N	PRESENT	0
456630	456093	14237S	PARTICIPANT	\N	PRESENT	0
456631	456093	19687N	PARTICIPANT	\N	PRESENT	0
456632	456093	19527W	PARTICIPANT	\N	PRESENT	0
456633	456093	95067Q	PARTICIPANT	\N	PRESENT	0
460761	458947	04044E	PARTICIPANT	\N	PRESENT	0
460762	458947	19585H	PARTICIPANT	\N	PRESENT	0
460763	458947	04047H	PARTICIPANT	\N	PRESENT	0
460764	458947	19673G	PARTICIPANT	\N	PRESENT	0
460765	458947	05008E	PRESIDENT	0	PRESENT	0
460766	458947	19729F	PARTICIPANT	\N	PRESENT	0
460767	458947	14275Y	PARTICIPANT	\N	PRESENT	0
460768	458947	19629C	PARTICIPANT	\N	PRESENT	0
460769	458947	14041T	PARTICIPANT	\N	PRESENT	0
460770	458947	14179A	PARTICIPANT	\N	PRESENT	0
460771	458947	14215L	PARTICIPANT	\N	PRESENT	0
460922	459124	19269X	PARTICIPANT	\N	PRESENT	0
460923	459125	19515S	PARTICIPANT	\N	PRESENT	0
460774	458654	14331P	PARTICIPANT	\N	PRESENT	0
460775	458654	01048V	PARTICIPANT	\N	PRESENT	0
460776	458654	19671E	PARTICIPANT	\N	PRESENT	0
460777	458654	14253S	PARTICIPANT	\N	PRESENT	0
460778	458654	19711U	PARTICIPANT	\N	PRESENT	0
460779	458654	08034U	PARTICIPANT	\N	PRESENT	0
460780	458654	19689Q	PARTICIPANT	\N	PRESENT	0
460781	458748	12041X	PARTICIPANT	\N	PRESENT	0
460782	458748	95030B	PARTICIPANT	\N	PRESENT	0
460783	458748	04034C	PARTICIPANT	\N	PRESENT	0
460784	458748	14079W	PARTICIPANT	\N	PRESENT	0
460785	458748	01058X	PARTICIPANT	\N	PRESENT	0
460786	458748	04040A	PARTICIPANT	\N	PRESENT	0
460787	458748	16685X	PARTICIPANT	\N	PRESENT	0
460788	458748	04042C	PRESIDENT	0	PRESENT	0
460789	458748	11054L	PARTICIPANT	\N	PRESENT	0
460790	458748	11066Q	PARTICIPANT	\N	PRESENT	0
460791	458748	08056B	PARTICIPANT	\N	PRESENT	0
460792	458748	95037J	PARTICIPANT	\N	PRESENT	0
460793	458748	14193X	PARTICIPANT	\N	PRESENT	0
460794	458748	08053X	PARTICIPANT	\N	PRESENT	0
460795	458748	97011G	PARTICIPANT	\N	PRESENT	0
460796	458748	08061X	PARTICIPANT	\N	PRESENT	0
460797	458748	98029W	PARTICIPANT	\N	PRESENT	0
460798	458748	14097Y	PARTICIPANT	\N	PRESENT	0
460799	458748	95067Q	PARTICIPANT	\N	PRESENT	0
460800	458748	01062T	PARTICIPANT	\N	PRESENT	0
460801	458748	14133K	PARTICIPANT	\N	PRESENT	0
460802	458748	11041F	PARTICIPANT	\N	PRESENT	0
460803	458748	14235Q	PARTICIPANT	\N	PRESENT	0
460804	458748	08058D	PARTICIPANT	\N	PRESENT	0
460805	458748	14028W	PARTICIPANT	\N	PRESENT	0
460806	458748	14105F	PARTICIPANT	\N	PRESENT	0
460807	458748	98022P	PARTICIPANT	\N	PRESENT	0
460808	458748	14267Y	PARTICIPANT	\N	PRESENT	0
460809	458748	98050T	PARTICIPANT	\N	PRESENT	0
460810	458748	14255U	PARTICIPANT	\N	PRESENT	0
460811	458797	19697Q	PARTICIPANT	\N	PRESENT	0
460812	458797	17779H	PARTICIPANT	\N	PRESENT	0
460924	459125	19782L	PARTICIPANT	\N	PRESENT	0
460925	459125	11077T	PARTICIPANT	\N	PRESENT	0
460926	459125	01043Q	PARTICIPANT	\N	PRESENT	0
460927	459125	19812Y	PARTICIPANT	\N	PRESENT	0
460928	459125	19441R	PARTICIPANT	\N	PRESENT	0
460929	459125	19413M	PARTICIPANT	\N	PRESENT	0
460930	459125	14081Q	PARTICIPANT	\N	PRESENT	0
460931	459125	80013X	PARTICIPANT	\N	PRESENT	0
460932	459125	04045F	PARTICIPANT	\N	PRESENT	0
460933	459125	19631V	PARTICIPANT	\N	PRESENT	0
460934	459125	11099A	PARTICIPANT	\N	PRESENT	0
460935	459125	08068F	PARTICIPANT	\N	PRESENT	0
460936	459125	04049K	PARTICIPANT	\N	PRESENT	0
460937	459125	19705W	PARTICIPANT	\N	PRESENT	0
460938	459125	08015R	PARTICIPANT	\N	PRESENT	0
460939	459125	08019V	PARTICIPANT	\N	PRESENT	0
460940	459125	14197C	PARTICIPANT	\N	PRESENT	0
460941	459125	19511N	PARTICIPANT	\N	PRESENT	0
460942	459125	08028W	PARTICIPANT	\N	PRESENT	0
460943	459125	19563B	PARTICIPANT	\N	PRESENT	0
460944	459125	14265W	PARTICIPANT	\N	PRESENT	0
460945	459125	14135M	PARTICIPANT	\N	PRESENT	0
460946	459125	19467C	PARTICIPANT	\N	PRESENT	0
460947	459125	14187A	PARTICIPANT	\N	PRESENT	0
460948	459125	19695N	PARTICIPANT	\N	PRESENT	0
460949	459125	08062Y	PARTICIPANT	\N	PRESENT	0
460950	459125	14033T	PARTICIPANT	\N	PRESENT	0
460951	459125	01025N	PARTICIPANT	\N	PRESENT	0
460952	459125	11090Q	PRESIDENT	0	PRESENT	0
460953	459125	19269X	PARTICIPANT	\N	PRESENT	0
460954	459125	14205J	PARTICIPANT	\N	PRESENT	0
460955	459125	04088S	PARTICIPANT	\N	PRESENT	0
460956	459125	11056N	PARTICIPANT	\N	PRESENT	0
460957	459125	04089T	PARTICIPANT	\N	PRESENT	0
460958	459125	14115H	PARTICIPANT	\N	PRESENT	0
460959	459125	11101A	PARTICIPANT	\N	PRESENT	0
460960	459125	19507S	PARTICIPANT	\N	PRESENT	0
460961	459125	14207L	PARTICIPANT	\N	PRESENT	0
460962	459125	19747H	PARTICIPANT	\N	PRESENT	0
460963	459125	04043D	PARTICIPANT	\N	PRESENT	0
460964	459125	19619A	PARTICIPANT	\N	PRESENT	0
460965	459125	17589D	PARTICIPANT	\N	PRESENT	0
460966	459125	14257W	PARTICIPANT	\N	PRESENT	0
460967	459125	14357A	PARTICIPANT	\N	EXCUSE	0
460968	459125	19369B	PARTICIPANT	\N	EXCUSE	0
460969	459125	19295A	PARTICIPANT	\N	EXCUSE	0
460970	458653	01048V	PARTICIPANT	\N	PRESENT	0
461664	448774	11101A	PARTICIPANT	\N	PRESENT	0
461816	458887	14097Y	PARTICIPANT	\N	PRESENT	0
462508	462507	19575F	PARTICIPANT	\N	PRESENT	0
461819	458887	19611R	PRESIDENT	0	PRESENT	0
461820	458887	14197C	PARTICIPANT	\N	PRESENT	0
461823	458887	19527W	PARTICIPANT	\N	PRESENT	0
461824	458655	14327T	PARTICIPANT	\N	PRESENT	0
461825	458655	14083S	PARTICIPANT	\N	PRESENT	0
461826	458655	11048N	PARTICIPANT	\N	PRESENT	0
461827	458655	01048V	PARTICIPANT	\N	PRESENT	0
461828	458655	14085U	PARTICIPANT	\N	PRESENT	0
461829	458655	07004J	PARTICIPANT	\N	PRESENT	0
461830	458655	01057W	PRESIDENT	1	PRESENT	0
461831	458655	96004D	PARTICIPANT	\N	PRESENT	0
461832	458655	08010L	PARTICIPANT	\N	PRESENT	0
461833	458655	11074Q	PRESIDENT	0	PRESENT	0
461834	458655	99004R	PARTICIPANT	\N	PRESENT	0
461835	458655	04086Q	PARTICIPANT	\N	PRESENT	0
461836	458655	19741B	PARTICIPANT	\N	PRESENT	0
461837	458655	08011M	PARTICIPANT	\N	EXCUSE	0
461838	458655	19671E	PARTICIPANT	\N	PRESENT	0
462509	462507	19709B	PARTICIPANT	\N	PRESENT	0
462510	462507	04069P	PARTICIPANT	\N	PRESENT	0
462512	462511	14030Q	PARTICIPANT	\N	PRESENT	0
462513	462511	19693L	PARTICIPANT	\N	PRESENT	0
462514	462511	11067R	PARTICIPANT	\N	PRESENT	0
463307	463298	86034E	PARTICIPANT	\N	PRESENT	0
463308	463298	04085P	PARTICIPANT	\N	PRESENT	0
463309	463298	19687N	PARTICIPANT	\N	PRESENT	0
463310	463298	14021P	PARTICIPANT	\N	PRESENT	0
463311	463298	19629C	PARTICIPANT	\N	PRESENT	0
463312	463298	19669L	PARTICIPANT	\N	PRESENT	0
463313	463298	01028R	PARTICIPANT	\N	PRESENT	0
463314	463298	19697Q	PARTICIPANT	\N	PRESENT	0
463315	463298	19673G	PARTICIPANT	\N	PRESENT	0
463316	463298	19741B	PARTICIPANT	\N	PRESENT	0
463317	463298	19667J	PARTICIPANT	\N	PRESENT	0
463318	463298	07029T	PARTICIPANT	\N	PRESENT	0
463319	463298	07033P	PARTICIPANT	\N	PRESENT	0
463320	463298	14329V	PARTICIPANT	\N	PRESENT	0
463321	463298	19611R	PARTICIPANT	\N	PRESENT	0
463322	463298	11033F	PARTICIPANT	\N	PRESENT	0
463323	463298	19762G	PARTICIPANT	\N	PRESENT	0
463324	463298	19649G	PARTICIPANT	\N	PRESENT	0
463325	463298	14026U	PARTICIPANT	\N	PRESENT	0
463326	463298	19591F	PARTICIPANT	\N	PRESENT	0
463327	463298	04033B	PARTICIPANT	\N	PRESENT	0
463328	463298	12041X	PARTICIPANT	\N	PRESENT	0
463329	463298	19689Q	PARTICIPANT	\N	PRESENT	0
463330	463298	19593H	PARTICIPANT	\N	PRESENT	0
463331	463298	19699S	PARTICIPANT	\N	PRESENT	0
463332	463298	11085T	PARTICIPANT	\N	PRESENT	0
463333	463298	05008E	PARTICIPANT	\N	PRESENT	0
463334	463298	11053K	PARTICIPANT	\N	PRESENT	0
463335	463298	11070L	PARTICIPANT	\N	PRESENT	0
473365	473215	14071N	PARTICIPANT	\N	EXCUSE	0
473367	473366	08049C	PARTICIPANT	\N	PRESENT	0
473368	473366	19335Q	PARTICIPANT	\N	PRESENT	0
473370	473369	08049C	PARTICIPANT	\N	PRESENT	0
473371	473369	19335Q	PARTICIPANT	\N	PRESENT	0
474828	474327	19649G	PARTICIPANT	\N	PRESENT	0
474829	474327	10015M	PARTICIPANT	\N	PRESENT	0
474830	474327	19543W	PARTICIPANT	\N	PRESENT	0
474831	474327	19673G	PARTICIPANT	\N	PRESENT	0
474832	474327	19675J	PARTICIPANT	\N	PRESENT	0
474833	474327	01028R	PRESIDENT	1	PRESENT	0
474834	474327	05008E	PRESIDENT	0	PRESENT	0
474835	474327	14231L	PARTICIPANT	\N	PRESENT	0
474836	474327	19725B	PARTICIPANT	\N	PRESENT	0
474837	474327	95063L	PARTICIPANT	\N	PRESENT	0
474838	474327	14147R	PARTICIPANT	\N	PRESENT	0
474839	474327	14179A	PARTICIPANT	\N	PRESENT	0
474840	474327	14069U	PARTICIPANT	\N	PRESENT	0
474841	474327	11085T	PARTICIPANT	\N	PRESENT	0
474842	474327	08018U	PARTICIPANT	\N	PRESENT	0
474843	474327	11049P	PARTICIPANT	\N	PRESENT	0
474844	474327	19762G	PARTICIPANT	\N	PRESENT	0
474845	474327	14021P	PARTICIPANT	\N	PRESENT	0
474846	474327	14041T	PARTICIPANT	\N	PRESENT	0
474847	474327	04008A	PARTICIPANT	\N	PRESENT	0
474850	472987	19768N	PARTICIPANT	\N	PRESENT	0
474851	472987	19515S	PARTICIPANT	\N	PRESENT	0
474852	472987	19782L	PARTICIPANT	\N	PRESENT	0
474853	472987	14357A	PARTICIPANT	\N	PRESENT	0
474854	472987	19441R	PARTICIPANT	\N	PRESENT	0
474855	472987	19812Y	PARTICIPANT	\N	PRESENT	0
474856	472987	80013X	PARTICIPANT	\N	PRESENT	0
474857	472987	04045F	PARTICIPANT	\N	PRESENT	0
474858	472987	19631V	PARTICIPANT	\N	PRESENT	0
474859	472987	11099A	PARTICIPANT	\N	PRESENT	0
474860	472987	04049K	PARTICIPANT	\N	PRESENT	0
474861	472987	19705W	PARTICIPANT	\N	PRESENT	0
474862	472987	08015R	PARTICIPANT	\N	PRESENT	0
474863	472987	14197C	PARTICIPANT	\N	PRESENT	0
474864	472987	08028W	PARTICIPANT	\N	PRESENT	0
474865	472987	19563B	PARTICIPANT	\N	PRESENT	0
474866	472987	14265W	PARTICIPANT	\N	PRESENT	0
474867	472987	14135M	PARTICIPANT	\N	PRESENT	0
474868	472987	19467C	PARTICIPANT	\N	PRESENT	0
474869	472987	14187A	PARTICIPANT	\N	PRESENT	0
474870	472987	19695N	PARTICIPANT	\N	PRESENT	0
474871	472987	11090Q	PRESIDENT	0	PRESENT	0
474872	472987	01025N	PARTICIPANT	\N	PRESENT	0
474873	472987	11056N	PARTICIPANT	\N	PRESENT	0
474874	472987	14115H	PARTICIPANT	\N	PRESENT	0
474875	472987	19507S	PARTICIPANT	\N	PRESENT	0
474876	472987	19747H	PARTICIPANT	\N	PRESENT	0
474877	472987	14207L	PARTICIPANT	\N	PRESENT	0
474878	472987	19619A	PARTICIPANT	\N	PRESENT	0
474879	472987	14257W	PARTICIPANT	\N	PRESENT	0
474880	474327	11072N	PARTICIPANT	\N	PRESENT	0
474881	472987	01043Q	PARTICIPANT	\N	PRESENT	0
474882	472987	14081Q	PARTICIPANT	\N	PRESENT	0
474901	474327	01024M	PARTICIPANT	\N	PRESENT	0
474932	474276	19697Q	PARTICIPANT	\N	PRESENT	0
474933	474276	11067R	PARTICIPANT	\N	PRESENT	0
474934	474276	04092N	PRESIDENT	0	PRESENT	0
474935	474276	19415P	PARTICIPANT	\N	PRESENT	0
474936	474276	17779H	PARTICIPANT	\N	PRESENT	0
474937	474276	11031D	PARTICIPANT	\N	PRESENT	0
474938	474276	19553Y	PARTICIPANT	\N	PRESENT	0
474939	474276	19679N	PARTICIPANT	\N	PRESENT	0
474940	474276	14042U	PARTICIPANT	\N	PRESENT	0
474941	474276	14195A	PARTICIPANT	\N	PRESENT	0
474942	474276	19367Y	PARTICIPANT	\N	PRESENT	0
474943	474276	19683J	PARTICIPANT	\N	PRESENT	0
474944	474276	98024R	PARTICIPANT	\N	PRESENT	0
474945	474276	19760E	PARTICIPANT	\N	PRESENT	0
474946	474276	19521Q	PARTICIPANT	\N	PRESENT	0
474947	473424	11048N	PARTICIPANT	\N	PRESENT	0
474948	473424	19479G	PARTICIPANT	\N	PRESENT	0
474949	473424	08034U	PARTICIPANT	\N	PRESENT	0
474950	473424	19687N	PARTICIPANT	\N	PRESENT	0
474951	473424	19689Q	PARTICIPANT	\N	PRESENT	0
474952	473424	11053K	PARTICIPANT	\N	PRESENT	0
474953	473424	08011M	PARTICIPANT	\N	PRESENT	0
474954	473424	11074Q	PRESIDENT	0	PRESENT	0
474955	473424	89017R	PARTICIPANT	\N	PRESENT	0
474956	473424	04086Q	PARTICIPANT	\N	PRESENT	0
474957	473424	11040E	PARTICIPANT	\N	PRESENT	0
474958	473424	07029T	PARTICIPANT	\N	PRESENT	0
474959	473424	14085U	PARTICIPANT	\N	PRESENT	0
474960	473424	19741B	PARTICIPANT	\N	PRESENT	0
475137	475118	80013X	PARTICIPANT	\N	PRESENT	0
475139	475118	04089T	PARTICIPANT	\N	PRESENT	0
475141	475118	19747H	PARTICIPANT	\N	PRESENT	0
475143	475124	08012N	PARTICIPANT	\N	PRESENT	0
475146	475124	02002K	PARTICIPANT	\N	PRESENT	0
475147	475124	19725B	PARTICIPANT	\N	PRESENT	0
475150	475124	14030Q	PARTICIPANT	\N	PRESENT	0
475153	475124	14073Q	PARTICIPANT	\N	PRESENT	0
475155	475124	19251M	PARTICIPANT	\N	PRESENT	0
475157	475124	19399H	PARTICIPANT	\N	PRESENT	0
475136	475118	14033T	PARTICIPANT	\N	PRESENT	0
475159	475124	19349W	PARTICIPANT	\N	PRESENT	0
475160	475124	11043H	PARTICIPANT	\N	PRESENT	0
475161	475124	14147R	PARTICIPANT	\N	PRESENT	0
475162	475124	19758L	PARTICIPANT	\N	PRESENT	0
475163	475124	19711U	PARTICIPANT	\N	PRESENT	0
475164	475124	08024S	PARTICIPANT	\N	PRESENT	0
475165	475124	19533U	PARTICIPANT	\N	PRESENT	0
475166	475124	19721W	PARTICIPANT	\N	PRESENT	0
475168	475167	14033T	PARTICIPANT	\N	PRESENT	0
475170	475167	80013X	PARTICIPANT	\N	PRESENT	0
475171	475167	04089T	PARTICIPANT	\N	PRESENT	0
475173	475167	19747H	PARTICIPANT	\N	PRESENT	0
475180	475175	14033T	PARTICIPANT	\N	PRESENT	0
475181	475175	80013X	PARTICIPANT	\N	PRESENT	0
475182	475175	04089T	PARTICIPANT	\N	PRESENT	0
475183	475175	14357A	PARTICIPANT	\N	PRESENT	0
475184	475175	19563B	PARTICIPANT	\N	PRESENT	0
475185	475175	11099A	PARTICIPANT	\N	PRESENT	0
475187	475186	14033T	PARTICIPANT	\N	PRESENT	0
475188	475186	80013X	PARTICIPANT	\N	PRESENT	0
475189	475186	04089T	PARTICIPANT	\N	PRESENT	0
475190	475186	14357A	PARTICIPANT	\N	PRESENT	0
475195	475193	11054L	PARTICIPANT	\N	PRESENT	0
475196	475193	04040A	PARTICIPANT	\N	PRESENT	0
475197	475192	80013X	PARTICIPANT	\N	PRESENT	0
475198	475192	04089T	PARTICIPANT	\N	PRESENT	0
475199	475192	14357A	PARTICIPANT	\N	PRESENT	0
475201	475200	80013X	PARTICIPANT	\N	PRESENT	0
475202	475200	04089T	PARTICIPANT	\N	PRESENT	0
475219	475215	80013X	PARTICIPANT	\N	PRESENT	0
475220	475215	14357A	PARTICIPANT	\N	PRESENT	0
475222	475221	80013X	PARTICIPANT	\N	PRESENT	0
475224	475223	14033T	PARTICIPANT	\N	PRESENT	0
475225	475223	80013X	PARTICIPANT	\N	PRESENT	0
475226	475223	04089T	PARTICIPANT	\N	PRESENT	0
475227	475223	19782L	PARTICIPANT	\N	PRESENT	0
475230	475229	14033T	PARTICIPANT	\N	PRESENT	0
475231	475229	80013X	PARTICIPANT	\N	PRESENT	0
475232	475229	04089T	PARTICIPANT	\N	PRESENT	0
475233	475229	19782L	PARTICIPANT	\N	PRESENT	0
475234	475229	14257W	PARTICIPANT	\N	PRESENT	0
475252	475235	04089T	PARTICIPANT	\N	PRESENT	0
475349	475235	14257W	PARTICIPANT	\N	PRESENT	0
475351	475235	19619A	PARTICIPANT	\N	PRESENT	0
475239	475235	14051J	PARTICIPANT	\N	PRESENT	0
475354	475235	14357A	PARTICIPANT	\N	PRESENT	0
475241	475235	19333N	PARTICIPANT	\N	PRESENT	0
475242	475235	19533U	PARTICIPANT	\N	PRESENT	0
475370	475368	14033T	PARTICIPANT	\N	PRESENT	0
475244	475235	14083S	PARTICIPANT	\N	PRESENT	0
475245	475235	19575F	PARTICIPANT	\N	PRESENT	0
475371	475368	80013X	PARTICIPANT	\N	PRESENT	0
475249	475235	14033T	PARTICIPANT	\N	PRESENT	0
475251	475235	80013X	PARTICIPANT	\N	PRESENT	0
475373	475368	04089T	PARTICIPANT	\N	PRESENT	0
476050	476049	11027H	PARTICIPANT	\N	PRESENT	0
476051	476049	19709B	PARTICIPANT	\N	PRESENT	0
476062	475783	11056N	PARTICIPANT	\N	EXCUSE	0
476071	475783	11066Q	PARTICIPANT	\N	PRESENT	0
476156	475634	19515S	PARTICIPANT	\N	EXCUSE	0
476208	476207	14039A	PARTICIPANT	\N	PRESENT	0
476209	476207	08019V	PARTICIPANT	\N	PRESENT	0
476211	476210	14275Y	PARTICIPANT	\N	PRESENT	0
476212	476210	08019V	PARTICIPANT	\N	PRESENT	0
476214	476213	98005N	PARTICIPANT	\N	PRESENT	0
476215	476213	08019V	PARTICIPANT	\N	PRESENT	0
476259	476258	08034U	PARTICIPANT	\N	PRESENT	0
476261	476260	08034U	PARTICIPANT	\N	PRESENT	0
476358	476324	19629C	PARTICIPANT	\N	PRESENT	0
476359	476324	14093U	PARTICIPANT	\N	PRESENT	0
462524	462523	14221J	PARTICIPANT	\N	PRESENT	0
462526	462525	14221J	PARTICIPANT	\N	PRESENT	0
463173	462696	14215L	PARTICIPANT	\N	PRESENT	0
463174	462696	05012A	PARTICIPANT	\N	PRESENT	0
463175	462696	14251Q	PARTICIPANT	\N	PRESENT	0
463176	462696	19762G	PARTICIPANT	\N	PRESENT	0
463177	462696	95063L	PARTICIPANT	\N	PRESENT	0
463178	462696	11085T	PARTICIPANT	\N	PRESENT	0
463179	462696	14034U	PARTICIPANT	\N	PRESENT	0
463180	462696	04059M	PARTICIPANT	\N	PRESENT	0
463187	462696	04071H	PARTICIPANT	\N	PRESENT	0
466304	465274	14261S	PARTICIPANT	\N	PRESENT	0
466305	465274	19717B	PARTICIPANT	\N	PRESENT	0
466306	465274	19631V	PARTICIPANT	\N	PRESENT	0
466307	465274	19715Y	PARTICIPANT	\N	PRESENT	0
466308	465274	14021P	PARTICIPANT	\N	EXCUSE	0
466309	465274	14039A	PARTICIPANT	\N	PRESENT	0
466310	465274	98005N	PARTICIPANT	\N	PRESENT	0
466311	465274	14059S	PARTICIPANT	\N	PRESENT	0
466312	465274	12016W	PARTICIPANT	\N	PRESENT	0
466313	465274	08019V	PRESIDENT	0	PRESENT	0
466314	465274	19657G	PARTICIPANT	\N	PRESENT	0
463171	462696	19719D	PARTICIPANT	\N	PRESENT	0
463172	462696	19691J	PARTICIPANT	\N	PRESENT	0
466315	465274	08073C	PARTICIPANT	\N	PRESENT	0
466316	465274	19703U	PARTICIPANT	\N	PRESENT	0
466317	465274	19301E	PARTICIPANT	\N	PRESENT	0
466318	465274	11054L	PARTICIPANT	\N	EXCUSE	0
466319	465274	14225N	PARTICIPANT	\N	EXCUSE	0
466422	465364	11103C	PARTICIPANT	\N	PRESENT	0
466423	465364	19727D	PARTICIPANT	\N	PRESENT	0
466424	465364	14195A	PARTICIPANT	\N	PRESENT	0
466425	465364	11031D	PARTICIPANT	\N	PRESENT	0
466426	465364	08052W	PARTICIPANT	\N	PRESENT	0
466427	465364	19663E	PARTICIPANT	\N	PRESENT	0
466428	465364	10006L	PARTICIPANT	\N	PRESENT	0
466429	465364	14217N	PARTICIPANT	\N	PRESENT	0
466420	465364	19575F	PARTICIPANT	\N	PRESENT	0
466421	465364	19367Y	PARTICIPANT	\N	PRESENT	0
466430	465364	19577H	PARTICIPANT	\N	PRESENT	0
466431	465364	14042U	PARTICIPANT	\N	PRESENT	0
466432	465364	14281W	PARTICIPANT	\N	PRESENT	0
466433	465364	14087W	PARTICIPANT	\N	PRESENT	0
466434	465364	19521Q	PARTICIPANT	\N	PRESENT	0
466435	465364	08048B	PARTICIPANT	\N	PRESENT	0
466436	465364	19565D	PARTICIPANT	\N	PRESENT	0
466437	465364	19553Y	PARTICIPANT	\N	PRESENT	0
466438	465364	19569H	PARTICIPANT	\N	PRESENT	0
466439	465364	14213J	PARTICIPANT	\N	PRESENT	0
466440	465364	19715Y	PARTICIPANT	\N	PRESENT	0
466441	465364	19723Y	PARTICIPANT	\N	PRESENT	0
466442	465364	19697Q	PARTICIPANT	\N	PRESENT	0
466443	465364	17779H	PARTICIPANT	\N	PRESENT	0
466444	465364	19657G	PARTICIPANT	\N	PRESENT	0
466445	465364	11067R	PARTICIPANT	\N	PRESENT	0
466446	465364	14223L	PARTICIPANT	\N	PRESENT	0
466447	465364	14119M	PARTICIPANT	\N	PRESENT	0
466448	465364	14071N	PARTICIPANT	\N	PRESENT	0
466449	465364	11097X	PRESIDENT	0	PRESENT	0
466450	465364	19679N	PARTICIPANT	\N	PRESENT	0
466451	465364	19798U	PARTICIPANT	\N	PRESENT	0
466452	465364	14227Q	PARTICIPANT	\N	PRESENT	0
466453	465364	19527W	PARTICIPANT	\N	PRESENT	0
466454	465364	01034P	PARTICIPANT	\N	PRESENT	0
466455	465364	14239U	PARTICIPANT	\N	EXCUSE	0
466456	465364	19760E	PARTICIPANT	\N	EXCUSE	0
466457	465364	14261S	PARTICIPANT	\N	EXCUSE	0
466458	465364	19717B	PARTICIPANT	\N	EXCUSE	0
466459	465364	19415P	PARTICIPANT	\N	EXCUSE	0
466460	465364	98024R	PARTICIPANT	\N	EXCUSE	0
466461	465364	14355X	PARTICIPANT	\N	EXCUSE	0
466462	465364	08041T	PARTICIPANT	\N	EXCUSE	0
466463	465364	14026U	PARTICIPANT	\N	EXCUSE	0
466464	465364	19691J	PARTICIPANT	\N	EXCUSE	0
466465	465364	19591F	PARTICIPANT	\N	EXCUSE	0
466466	465364	19683J	PARTICIPANT	\N	EXCUSE	0
466467	465364	04092N	PARTICIPANT	\N	EXCUSE	0
466468	465364	11045K	PARTICIPANT	\N	EXCUSE	0
466469	465364	19703U	PARTICIPANT	\N	EXCUSE	0
466470	465364	19301E	PARTICIPANT	\N	EXCUSE	0
466471	465365	14239U	PARTICIPANT	\N	PRESENT	0
466472	465365	19760E	PARTICIPANT	\N	PRESENT	0
466473	465365	19575F	PARTICIPANT	\N	PRESENT	0
466474	465365	19367Y	PARTICIPANT	\N	PRESENT	0
466475	465365	19415P	PARTICIPANT	\N	PRESENT	0
466476	465365	19521Q	PARTICIPANT	\N	PRESENT	0
466477	465365	11103C	PARTICIPANT	\N	PRESENT	0
466478	465365	19727D	PARTICIPANT	\N	PRESENT	0
466479	465365	14195A	PARTICIPANT	\N	PRESENT	0
466480	465365	11031D	PARTICIPANT	\N	PRESENT	0
466481	465365	08052W	PARTICIPANT	\N	PRESENT	0
466482	465365	98024R	PARTICIPANT	\N	PRESENT	0
466483	465365	10006L	PARTICIPANT	\N	PRESENT	0
466484	465365	14217N	PARTICIPANT	\N	PRESENT	0
466485	465365	19577H	PARTICIPANT	\N	EXCUSE	0
466486	465365	14042U	PARTICIPANT	\N	PRESENT	0
466487	465365	14087W	PARTICIPANT	\N	PRESENT	0
466488	465365	08048B	PARTICIPANT	\N	PRESENT	0
466489	465365	19565D	PARTICIPANT	\N	PRESENT	0
466490	465365	14026U	PARTICIPANT	\N	PRESENT	0
466491	465365	19553Y	PARTICIPANT	\N	PRESENT	0
466492	465365	19527W	PARTICIPANT	\N	PRESENT	0
466493	465365	19569H	PARTICIPANT	\N	PRESENT	0
466494	465365	14213J	PARTICIPANT	\N	PRESENT	0
466495	465365	19715Y	PARTICIPANT	\N	PRESENT	0
466496	465365	19723Y	PARTICIPANT	\N	PRESENT	0
466497	465365	19697Q	PARTICIPANT	\N	PRESENT	0
466498	465365	17779H	PARTICIPANT	\N	PRESENT	0
466499	465365	19683J	PARTICIPANT	\N	PRESENT	0
466500	465365	19657G	PARTICIPANT	\N	PRESENT	0
466501	465365	11067R	PARTICIPANT	\N	PRESENT	0
466502	465365	14223L	PARTICIPANT	\N	PRESENT	0
466503	465365	14119M	PARTICIPANT	\N	PRESENT	0
466504	465365	04092N	PARTICIPANT	\N	PRESENT	0
466505	465365	14071N	PARTICIPANT	\N	PRESENT	0
466506	465365	19679N	PARTICIPANT	\N	PRESENT	0
466507	465365	19798U	PARTICIPANT	\N	PRESENT	0
466508	465365	11097X	PARTICIPANT	\N	PRESENT	0
466509	465365	19703U	PARTICIPANT	\N	PRESENT	0
466510	465365	19301E	PARTICIPANT	\N	PRESENT	0
466511	465365	01034P	PARTICIPANT	\N	PRESENT	0
466835	466046	19515S	PARTICIPANT	\N	PRESENT	0
466836	466046	19782L	PARTICIPANT	\N	PRESENT	0
466837	466046	14357A	PARTICIPANT	\N	PRESENT	0
466838	466046	19812Y	PARTICIPANT	\N	PRESENT	0
466839	466046	19413M	PARTICIPANT	\N	PRESENT	0
466840	466046	80013X	PARTICIPANT	\N	PRESENT	0
466841	466046	04045F	PARTICIPANT	\N	PRESENT	0
466842	466046	19631V	PARTICIPANT	\N	PRESENT	0
466843	466046	04049K	PARTICIPANT	\N	PRESENT	0
466844	466046	19705W	PARTICIPANT	\N	PRESENT	0
466845	466046	14197C	PARTICIPANT	\N	PRESENT	0
466846	466046	08028W	PARTICIPANT	\N	PRESENT	0
466847	466046	19563B	PARTICIPANT	\N	PRESENT	0
466848	466046	14265W	PARTICIPANT	\N	PRESENT	0
466849	466046	14329V	PARTICIPANT	\N	PRESENT	0
466850	466046	14187A	PARTICIPANT	\N	PRESENT	0
466851	466046	08038Y	PARTICIPANT	\N	PRESENT	0
466852	466046	19695N	PARTICIPANT	\N	PRESENT	0
466853	466046	11090Q	PRESIDENT	0	PRESENT	0
466854	466046	01025N	PARTICIPANT	\N	PRESENT	0
467066	467056	08052W	PARTICIPANT	\N	PRESENT	0
466856	466046	19507S	PARTICIPANT	\N	PRESENT	0
466857	466046	19747H	PARTICIPANT	\N	PRESENT	0
466858	466046	14207L	PARTICIPANT	\N	PRESENT	0
466859	466046	14257W	PARTICIPANT	\N	PRESENT	0
466860	466046	08019V	PARTICIPANT	\N	PRESENT	0
466861	466046	14033T	PARTICIPANT	\N	PRESENT	0
466862	466046	11056N	PARTICIPANT	\N	PRESENT	0
466863	466046	04043D	PARTICIPANT	\N	PRESENT	0
467065	467056	10006L	PARTICIPANT	\N	PRESENT	0
467067	467056	04092N	PARTICIPANT	\N	PRESENT	0
467068	467056	11097X	PARTICIPANT	\N	PRESENT	0
467069	467056	14213J	PARTICIPANT	\N	PRESENT	0
467070	467056	19575F	PARTICIPANT	\N	PRESENT	0
467071	467056	19697Q	PARTICIPANT	\N	PRESENT	0
467072	467056	14239U	PARTICIPANT	\N	PRESENT	0
467073	467056	11031D	PARTICIPANT	\N	PRESENT	0
467074	467057	14239U	PARTICIPANT	\N	PRESENT	0
467075	467057	11031D	PARTICIPANT	\N	PRESENT	0
467076	467057	19575F	PARTICIPANT	\N	PRESENT	0
467077	467057	10006L	PARTICIPANT	\N	PRESENT	0
467078	467057	08052W	PARTICIPANT	\N	PRESENT	0
467079	467057	14213J	PARTICIPANT	\N	PRESENT	0
467080	467057	04092N	PARTICIPANT	\N	PRESENT	0
467081	467057	11097X	PARTICIPANT	\N	PRESENT	0
467082	467057	19697Q	PARTICIPANT	\N	PRESENT	0
467083	467058	10006L	PARTICIPANT	\N	PRESENT	0
467084	467058	19521Q	PARTICIPANT	\N	PRESENT	0
472273	467270	14053L	PARTICIPANT	\N	PRESENT	0
472274	467270	14237S	PARTICIPANT	\N	PRESENT	0
472275	467270	14089Y	PARTICIPANT	\N	PRESENT	0
472276	467270	14001X	PARTICIPANT	\N	PRESENT	0
472277	467270	19573D	PARTICIPANT	\N	PRESENT	0
472278	467270	12041X	PARTICIPANT	\N	PRESENT	0
472279	467270	04045F	PARTICIPANT	\N	PRESENT	0
472280	472053	11033F	PARTICIPANT	\N	PRESENT	0
472281	472053	19629C	PARTICIPANT	\N	PRESENT	0
472282	472053	14259Y	PARTICIPANT	\N	PRESENT	0
472283	472053	19719D	PARTICIPANT	\N	PRESENT	0
472284	472053	01024M	PARTICIPANT	\N	PRESENT	0
472285	472053	14151M	PARTICIPANT	\N	PRESENT	0
472286	472053	08045X	PARTICIPANT	\N	PRESENT	0
472287	472053	11049P	PARTICIPANT	\N	PRESENT	0
472288	472053	19725B	PARTICIPANT	\N	PRESENT	0
472289	472053	19729F	PARTICIPANT	\N	PRESENT	0
472290	472053	14147R	PARTICIPANT	\N	PRESENT	0
472291	472053	19762G	PARTICIPANT	\N	PRESENT	0
472292	472053	01028R	PARTICIPANT	\N	PRESENT	0
472293	472053	04044E	PARTICIPANT	\N	PRESENT	0
472294	472053	19585H	PARTICIPANT	\N	PRESENT	0
472295	471173	11066Q	PARTICIPANT	\N	PRESENT	0
472296	471173	08024S	PARTICIPANT	\N	PRESENT	0
472297	467270	05012A	PARTICIPANT	\N	PRESENT	0
472298	467270	14229S	PARTICIPANT	\N	PRESENT	0
472300	472299	11053K	PARTICIPANT	\N	PRESENT	0
472301	472299	05012A	PARTICIPANT	\N	PRESENT	0
472314	470437	19563B	PARTICIPANT	\N	PRESENT	0
472315	470437	19447X	PARTICIPANT	\N	PRESENT	0
472316	470437	19683J	PARTICIPANT	\N	PRESENT	0
472317	470437	14157T	PARTICIPANT	\N	PRESENT	0
472318	470437	14038Y	PARTICIPANT	\N	PRESENT	0
472319	470437	04045F	PARTICIPANT	\N	PRESENT	0
472320	470437	04085P	PARTICIPANT	\N	PRESENT	0
472321	470437	19489J	PARTICIPANT	\N	PRESENT	0
472322	470437	05008E	PARTICIPANT	\N	PRESENT	0
472323	470437	11072N	PARTICIPANT	\N	PRESENT	0
472312	470437	04086Q	PARTICIPANT	\N	PRESENT	0
472313	470437	14001X	PARTICIPANT	\N	PRESENT	0
472324	470437	19553Y	PARTICIPANT	\N	PRESENT	0
472325	470437	08011M	PARTICIPANT	\N	PRESENT	0
472326	470437	96004D	PARTICIPANT	\N	PRESENT	0
472327	470437	14179A	PARTICIPANT	\N	PRESENT	0
472328	470437	14215L	PARTICIPANT	\N	PRESENT	0
472329	470437	19826F	PARTICIPANT	\N	PRESENT	0
472330	470437	11033F	PARTICIPANT	\N	PRESENT	0
472331	470437	14147R	PARTICIPANT	\N	PRESENT	0
472332	470437	17779H	PARTICIPANT	\N	PRESENT	0
472333	470437	04092N	PARTICIPANT	\N	PRESENT	0
472334	470437	14229S	PARTICIPANT	\N	PRESENT	0
472335	470437	01058X	PARTICIPANT	\N	PRESENT	0
472336	470437	19649G	PARTICIPANT	\N	PRESENT	0
472337	470437	98050T	PARTICIPANT	\N	PRESENT	0
472338	470437	14021P	PARTICIPANT	\N	PRESENT	0
472339	470437	19667J	PARTICIPANT	\N	PRESENT	0
472340	470437	19531S	PARTICIPANT	\N	PRESENT	0
472341	470437	14281W	PARTICIPANT	\N	PRESENT	0
472342	470437	19253P	PARTICIPANT	\N	PRESENT	0
472343	470437	19693L	PARTICIPANT	\N	PRESENT	0
472344	470437	11031D	PARTICIPANT	\N	PRESENT	0
472345	470437	01057W	PARTICIPANT	\N	PRESENT	0
472360	470437	19479G	PARTICIPANT	\N	PRESENT	0
472347	470437	19685L	PARTICIPANT	\N	PRESENT	0
472348	470437	11097X	PARTICIPANT	\N	PRESENT	0
472349	470437	14073Q	PARTICIPANT	\N	PRESENT	0
472350	470437	19599P	PARTICIPANT	\N	PRESENT	0
472351	470437	19741B	PARTICIPANT	\N	PRESENT	0
472352	470437	11048N	PARTICIPANT	\N	PRESENT	0
472353	470437	19723Y	PARTICIPANT	\N	PRESENT	0
472354	470437	10015M	PARTICIPANT	\N	PRESENT	0
472355	470437	14034U	PARTICIPANT	\N	PRESENT	0
472356	470437	14030Q	PARTICIPANT	\N	PRESENT	0
472357	470437	14042U	PARTICIPANT	\N	PRESENT	0
472361	470437	14053L	PARTICIPANT	\N	PRESENT	0
472359	470437	11026G	PARTICIPANT	\N	PRESENT	0
472362	470437	19591F	PARTICIPANT	\N	PRESENT	0
472363	470437	11012A	PARTICIPANT	\N	PRESENT	0
472364	470437	08031R	PARTICIPANT	\N	PRESENT	0
472365	470437	14205J	PARTICIPANT	\N	PRESENT	0
472387	470437	14083S	PARTICIPANT	\N	PRESENT	0
472388	470437	08061X	PARTICIPANT	\N	PRESENT	0
472389	470437	01028R	PARTICIPANT	\N	PRESENT	0
472391	470437	95063L	PARTICIPANT	\N	PRESENT	0
472392	470437	14251Q	PARTICIPANT	\N	PRESENT	0
472393	470437	19691J	PARTICIPANT	\N	PRESENT	0
472394	470437	18083K	PARTICIPANT	\N	PRESENT	0
472395	470437	19621T	PARTICIPANT	\N	PRESENT	0
472396	470437	87003B	PARTICIPANT	\N	PRESENT	0
472397	470437	14055N	PARTICIPANT	\N	PRESENT	0
472398	470437	14069U	PARTICIPANT	\N	PRESENT	0
472399	470437	19689Q	PARTICIPANT	\N	PRESENT	0
472400	470437	04047H	PARTICIPANT	\N	PRESENT	0
472401	470437	14071N	PARTICIPANT	\N	PRESENT	0
472405	470437	01043Q	PARTICIPANT	\N	PRESENT	0
472406	470437	11085T	PARTICIPANT	\N	PRESENT	0
472407	470437	11056N	PARTICIPANT	\N	PRESENT	0
472408	470889	08049C	PARTICIPANT	\N	PRESENT	0
472409	470889	19335Q	PARTICIPANT	\N	PRESENT	0
472410	470889	19575F	PARTICIPANT	\N	PRESENT	0
472411	470889	19387D	PARTICIPANT	\N	PRESENT	0
472412	470889	19798U	PARTICIPANT	\N	PRESENT	0
472413	470889	14237S	PARTICIPANT	\N	PRESENT	0
472414	470437	19573D	PARTICIPANT	\N	PRESENT	0
472415	470975	19387D	PARTICIPANT	\N	PRESENT	0
472416	470975	19798U	PARTICIPANT	\N	PRESENT	0
472417	471173	19349W	PARTICIPANT	\N	EXCUSE	0
472443	472442	11074Q	PARTICIPANT	\N	PRESENT	0
472444	470437	08055A	PARTICIPANT	\N	PRESENT	0
472445	470437	11045K	PARTICIPANT	\N	PRESENT	0
472447	471173	19399H	PARTICIPANT	\N	EXCUSE	0
472448	470437	08069G	PARTICIPANT	\N	PRESENT	0
472449	470437	05012A	PARTICIPANT	\N	PRESENT	0
472452	470437	10006L	PARTICIPANT	\N	PRESENT	0
472454	472453	10006L	PARTICIPANT	\N	PRESENT	0
472455	472453	19745F	PARTICIPANT	\N	PRESENT	0
472457	472456	10006L	PARTICIPANT	\N	PRESENT	0
472458	472456	98005N	PARTICIPANT	\N	PRESENT	0
472459	472456	19745F	PARTICIPANT	\N	PRESENT	0
472460	470437	11043H	PARTICIPANT	\N	PRESENT	0
472461	470437	11110B	PARTICIPANT	\N	PRESENT	0
472509	470439	11033F	PARTICIPANT	\N	PRESENT	0
472510	470439	17779H	PARTICIPANT	\N	PRESENT	0
472511	470439	14001X	PARTICIPANT	\N	PRESENT	0
472512	470439	14281W	PARTICIPANT	\N	PRESENT	0
472513	470439	19593H	PARTICIPANT	\N	PRESENT	0
472514	470439	05008E	PARTICIPANT	\N	PRESENT	0
472515	470439	11026G	PARTICIPANT	\N	PRESENT	0
472516	470439	11072N	PARTICIPANT	\N	PRESENT	0
472517	470439	19489J	PARTICIPANT	\N	PRESENT	0
472518	470439	98050T	PARTICIPANT	\N	PRESENT	0
472519	470439	04092N	PARTICIPANT	\N	PRESENT	0
472520	470439	19667J	PARTICIPANT	\N	PRESENT	0
472521	470439	14038Y	PARTICIPANT	\N	PRESENT	0
472522	470439	14157T	PARTICIPANT	\N	PRESENT	0
472523	470439	14215L	PARTICIPANT	\N	PRESENT	0
472524	470439	19447X	PARTICIPANT	\N	PRESENT	0
472525	470439	08031R	PARTICIPANT	\N	PRESENT	0
472526	470439	14034U	PARTICIPANT	\N	PRESENT	0
472527	470439	11097X	PARTICIPANT	\N	PRESENT	0
472528	470439	19599P	PARTICIPANT	\N	PRESENT	0
472529	470439	14021P	PARTICIPANT	\N	PRESENT	0
472530	470439	19693L	PARTICIPANT	\N	PRESENT	0
472531	470439	19723Y	PARTICIPANT	\N	PRESENT	0
472532	470439	11048N	PARTICIPANT	\N	PRESENT	0
472533	470439	96004D	PARTICIPANT	\N	PRESENT	0
472534	470439	19563B	PARTICIPANT	\N	PRESENT	0
472535	470439	19553Y	PARTICIPANT	\N	PRESENT	0
472536	470439	08061X	PARTICIPANT	\N	PRESENT	0
472537	470439	14147R	PARTICIPANT	\N	PRESENT	0
472538	470439	14229S	PARTICIPANT	\N	PRESENT	0
472539	470439	14069U	PARTICIPANT	\N	PRESENT	0
472540	470439	11045K	PARTICIPANT	\N	PRESENT	0
472541	470439	14179A	PARTICIPANT	\N	PRESENT	0
472542	470439	14187A	PARTICIPANT	\N	PRESENT	0
472543	470439	14055N	PARTICIPANT	\N	PRESENT	0
472544	470439	14053L	PARTICIPANT	\N	PRESENT	0
472545	470439	14071N	PARTICIPANT	\N	PRESENT	0
472546	470439	19741B	PARTICIPANT	\N	PRESENT	0
472547	470439	19621T	PARTICIPANT	\N	PRESENT	0
472548	470439	04047H	PARTICIPANT	\N	PRESENT	0
472549	470439	10006L	PARTICIPANT	\N	PRESENT	0
472550	470439	10015M	PARTICIPANT	\N	PRESENT	0
472551	470439	14231L	PARTICIPANT	\N	PRESENT	0
472552	470439	19503N	PARTICIPANT	\N	PRESENT	0
472553	470439	11027H	PARTICIPANT	\N	PRESENT	0
472507	470439	01043Q	PARTICIPANT	\N	PRESENT	0
472508	470439	11031D	PARTICIPANT	\N	PRESENT	0
455388	455387	14215L	PARTICIPANT	\N	PRESENT	0
455390	455389	19703U	PARTICIPANT	\N	PRESENT	0
455466	455463	01048V	PARTICIPANT	\N	PRESENT	0
455468	455463	14299H	PARTICIPANT	\N	PRESENT	0
456802	456707	14069U	PARTICIPANT	\N	PRESENT	0
456803	456707	11072N	PARTICIPANT	\N	PRESENT	0
456804	456707	14053L	PARTICIPANT	\N	PRESENT	0
456805	456707	14065Q	PARTICIPANT	\N	PRESENT	0
456806	456707	95063L	PARTICIPANT	\N	PRESENT	0
456854	456665	19383Y	PARTICIPANT	\N	PRESENT	0
456855	456665	19333N	PARTICIPANT	\N	PRESENT	0
456856	456665	19701S	PARTICIPANT	\N	PRESENT	0
456857	456665	19794Q	PARTICIPANT	\N	PRESENT	0
456858	456665	19549D	PARTICIPANT	\N	PRESENT	0
456859	456665	19387D	PARTICIPANT	\N	PRESENT	0
456860	456665	14219Q	PARTICIPANT	\N	PRESENT	0
456861	456665	19820Y	PARTICIPANT	\N	PRESENT	0
456862	456665	19826F	PARTICIPANT	\N	PRESENT	0
456863	456665	14221J	PARTICIPANT	\N	PRESENT	0
456864	456665	19599P	PARTICIPANT	\N	PRESENT	0
456865	456665	19637C	PARTICIPANT	\N	PRESENT	0
456866	456665	18083K	PARTICIPANT	\N	PRESENT	0
456867	456665	14237S	PARTICIPANT	\N	EXCUSE	0
456868	456665	19551W	PARTICIPANT	\N	PRESENT	0
456869	456665	14051J	PARTICIPANT	\N	PRESENT	0
456870	456665	08060W	PARTICIPANT	\N	PRESENT	0
456871	456665	19347U	PARTICIPANT	\N	PRESENT	0
456872	456665	19503N	PARTICIPANT	\N	PRESENT	0
456873	456665	14157T	PARTICIPANT	\N	PRESENT	0
456874	456665	19681G	PARTICIPANT	\N	PRESENT	0
456875	456665	19525U	PARTICIPANT	\N	PRESENT	0
456876	456665	14038Y	PARTICIPANT	\N	PRESENT	0
456877	456665	14031R	PARTICIPANT	\N	PRESENT	0
456878	456665	19713W	PARTICIPANT	\N	PRESENT	0
456879	456665	08055A	PARTICIPANT	\N	PRESENT	0
456880	456665	14169X	PARTICIPANT	\N	PRESENT	0
456881	456665	14191V	PARTICIPANT	\N	PRESENT	0
456882	456665	19733B	PARTICIPANT	\N	PRESENT	0
456883	456665	08009T	PRESIDENT	0	PRESENT	0
456884	456665	19737F	PARTICIPANT	\N	PRESENT	0
456885	456665	19739H	PARTICIPANT	\N	PRESENT	0
456886	456665	19745F	PARTICIPANT	\N	PRESENT	0
456892	448755	11070L	PARTICIPANT	\N	PRESENT	0
456893	448755	14151M	PARTICIPANT	\N	PRESENT	0
456894	448755	11040E	PARTICIPANT	\N	PRESENT	0
456895	448755	14063N	PARTICIPANT	\N	PRESENT	0
456896	448755	99004R	PARTICIPANT	\N	PRESENT	0
456897	448755	19387D	PARTICIPANT	\N	PRESENT	0
456898	448755	14089Y	PARTICIPANT	\N	PRESENT	0
456899	448755	19762G	PARTICIPANT	\N	PRESENT	0
456900	448755	19671E	PARTICIPANT	\N	PRESENT	0
456901	448755	05008E	PARTICIPANT	\N	PRESENT	0
456902	448755	19760E	PARTICIPANT	\N	PRESENT	0
456903	448755	14073Q	PARTICIPANT	\N	PRESENT	0
456904	448755	14021P	PARTICIPANT	\N	PRESENT	0
456905	448755	14065Q	PARTICIPANT	\N	PRESENT	0
456906	448755	19741B	PARTICIPANT	\N	PRESENT	0
456907	448755	08056B	PARTICIPANT	\N	PRESENT	0
456908	448755	18083K	PARTICIPANT	\N	PRESENT	0
456909	448755	19447X	PARTICIPANT	\N	PRESENT	0
456910	448755	08044W	PARTICIPANT	\N	PRESENT	0
456911	448755	08009T	PARTICIPANT	\N	PRESENT	0
456912	448755	14079W	PARTICIPANT	\N	PRESENT	0
456913	448755	19335Q	PARTICIPANT	\N	PRESENT	0
456914	448755	14107H	PARTICIPANT	\N	PRESENT	0
456915	448755	14111D	PARTICIPANT	\N	PRESENT	0
456916	448755	11072N	PARTICIPANT	\N	PRESENT	0
456917	448755	14191V	PARTICIPANT	\N	PRESENT	0
456918	456640	14327T	PARTICIPANT	\N	PRESENT	0
456919	456640	19383Y	PARTICIPANT	\N	PRESENT	0
456920	456640	14061L	PARTICIPANT	\N	PRESENT	0
456921	456640	19531S	PARTICIPANT	\N	PRESENT	0
456922	456640	10015M	PARTICIPANT	\N	PRESENT	0
456923	456640	19441R	PARTICIPANT	\N	PRESENT	0
456924	456640	19387D	PARTICIPANT	\N	PRESENT	0
456925	456640	14001X	PARTICIPANT	\N	PRESENT	0
456926	456640	19820Y	PARTICIPANT	\N	PRESENT	0
456927	456640	19725B	PARTICIPANT	\N	PRESENT	0
456928	456640	11056N	PARTICIPANT	\N	PRESENT	0
456929	456640	19679N	PARTICIPANT	\N	PRESENT	0
456930	456640	04097T	PARTICIPANT	\N	PRESENT	0
456931	456640	19349W	PARTICIPANT	\N	PRESENT	0
456999	448755	14038Y	PARTICIPANT	\N	PRESENT	0
456933	456640	19621T	PARTICIPANT	\N	PRESENT	0
456934	456640	19667J	PRESIDENT	0	PRESENT	0
456935	448755	11103C	PARTICIPANT	\N	PRESENT	0
456936	448755	19729F	PARTICIPANT	\N	PRESENT	0
456937	448755	14265W	PARTICIPANT	\N	PRESENT	0
456938	448755	11099A	PARTICIPANT	\N	PRESENT	0
456939	456891	14097Y	PARTICIPANT	\N	PRESENT	0
456940	456891	11048N	PARTICIPANT	\N	PRESENT	0
456941	456891	19611R	PRESIDENT	0	PRESENT	0
457045	448755	19599P	PARTICIPANT	\N	PRESENT	0
457046	448755	80013X	PARTICIPANT	\N	PRESENT	0
456944	456891	14197C	PARTICIPANT	\N	PRESENT	0
457047	448755	14157T	PARTICIPANT	\N	PRESENT	0
457048	448755	04040A	PARTICIPANT	\N	PRESENT	0
456947	448755	19731Y	PARTICIPANT	\N	PRESENT	0
456948	448755	08020N	PARTICIPANT	\N	PRESENT	0
456949	448755	08060W	PARTICIPANT	\N	PRESENT	0
456950	448755	04085P	PARTICIPANT	\N	PRESENT	0
456951	448755	97011G	PARTICIPANT	\N	PRESENT	0
456952	448755	01028R	PARTICIPANT	\N	PRESENT	0
456953	448755	14147R	PARTICIPANT	\N	PRESENT	0
456954	448755	04088S	PARTICIPANT	\N	PRESENT	0
457032	448755	19531S	PARTICIPANT	\N	PRESENT	0
456956	448755	11104D	PARTICIPANT	\N	PRESENT	0
456957	448755	19758L	PARTICIPANT	\N	PRESENT	0
456958	448755	14215L	PARTICIPANT	\N	PRESENT	0
456959	456891	19687N	PARTICIPANT	\N	PRESENT	0
456960	456891	19581D	PARTICIPANT	\N	PRESENT	0
456961	456891	14237S	PARTICIPANT	\N	EXCUSE	0
456962	448755	19739H	PARTICIPANT	\N	PRESENT	0
456963	448755	14069U	PARTICIPANT	\N	PRESENT	0
456964	448755	14257W	PARTICIPANT	\N	PRESENT	0
456965	448755	08039A	PARTICIPANT	\N	PRESENT	0
456988	448755	19503N	PARTICIPANT	\N	PRESENT	0
456989	448755	14061L	PARTICIPANT	\N	PRESENT	0
456990	448755	11054L	PARTICIPANT	\N	PRESENT	0
456991	456640	14221J	PARTICIPANT	\N	PRESENT	0
456992	456640	04045F	PARTICIPANT	\N	EXCUSE	0
456993	456640	19563B	PARTICIPANT	\N	EXCUSE	0
456994	448755	19441R	PARTICIPANT	\N	PRESENT	0
456995	448755	10015M	PARTICIPANT	\N	PRESENT	0
456997	448755	14042U	PARTICIPANT	\N	PRESENT	0
456998	448755	19794Q	PARTICIPANT	\N	PRESENT	0
457004	448755	19525U	PARTICIPANT	\N	PRESENT	0
457005	448755	14115H	PARTICIPANT	\N	PRESENT	0
457012	448755	08045X	PARTICIPANT	\N	PRESENT	0
457018	448755	17583W	PARTICIPANT	\N	PRESENT	0
457019	448755	19383Y	PARTICIPANT	\N	PRESENT	0
457020	448755	98022P	PARTICIPANT	\N	PRESENT	0
457021	448755	19681G	PARTICIPANT	\N	PRESENT	0
457022	448755	14105F	PARTICIPANT	\N	PRESENT	0
457023	448755	14121F	PARTICIPANT	\N	PRESENT	0
457024	448755	19349W	PARTICIPANT	\N	PRESENT	0
457025	448755	19675J	PARTICIPANT	\N	PRESENT	0
457026	448755	87003B	PARTICIPANT	\N	PRESENT	0
457028	448755	19649G	PARTICIPANT	\N	PRESENT	0
457029	448755	19443T	PARTICIPANT	\N	PRESENT	0
457030	448755	04043D	PARTICIPANT	\N	PRESENT	0
457031	448755	14041T	PARTICIPANT	\N	PRESENT	0
457034	448755	14083S	PARTICIPANT	\N	PRESENT	0
457035	448755	19629C	PARTICIPANT	\N	PRESENT	0
457036	456891	19527W	PARTICIPANT	\N	PRESENT	0
457039	456891	14031R	PARTICIPANT	\N	PRESENT	0
457041	448755	14267Y	PARTICIPANT	\N	PRESENT	0
457042	455105	04040A	PARTICIPANT	\N	PRESENT	0
457043	455105	04044E	PARTICIPANT	\N	PRESENT	0
457044	455105	19669L	PARTICIPANT	\N	PRESENT	0
457049	448755	04018C	PARTICIPANT	\N	PRESENT	0
457050	448755	14109K	PARTICIPANT	\N	PRESENT	0
457051	448755	14193X	PARTICIPANT	\N	PRESENT	0
457052	448755	19826F	PARTICIPANT	\N	PRESENT	0
457053	448755	19737F	PARTICIPANT	\N	PRESENT	0
457054	448755	04059M	PARTICIPANT	\N	PRESENT	0
457055	448755	11048N	PARTICIPANT	\N	PRESENT	0
457056	448755	14030Q	PARTICIPANT	\N	PRESENT	0
457057	448755	19347U	PARTICIPANT	\N	PRESENT	0
457058	448755	08052W	PARTICIPANT	\N	PRESENT	0
457059	448755	89017R	PARTICIPANT	\N	PRESENT	0
457060	448755	19533U	PARTICIPANT	\N	PRESENT	0
457061	448755	14001X	PARTICIPANT	\N	PRESENT	0
457062	448755	01048V	PARTICIPANT	\N	PRESENT	0
474498	470579	19551W	PARTICIPANT	\N	PRESENT	0
474500	470579	19782L	PARTICIPANT	\N	PRESENT	0
474502	470579	19651A	PARTICIPANT	\N	PRESENT	0
474505	470579	14034U	PARTICIPANT	\N	PRESENT	0
474507	470579	17589D	PARTICIPANT	\N	PRESENT	0
474509	470579	19585H	PARTICIPANT	\N	PRESENT	0
474511	470579	14042U	PARTICIPANT	\N	PRESENT	0
474512	470579	01024M	PARTICIPANT	\N	PRESENT	0
474513	470579	19741B	PARTICIPANT	\N	PRESENT	0
474514	470579	14253S	PARTICIPANT	\N	PRESENT	0
474515	470579	89017R	PARTICIPANT	\N	PRESENT	0
474516	470579	14331P	PARTICIPANT	\N	PRESENT	0
474517	470579	14147R	PARTICIPANT	\N	PRESENT	0
474518	470579	04049K	PARTICIPANT	\N	PRESENT	0
474519	470579	19705W	PARTICIPANT	\N	PRESENT	0
474520	470579	19762G	PARTICIPANT	\N	PRESENT	0
474521	470579	01048V	PARTICIPANT	\N	PRESENT	0
474522	470579	11048N	PARTICIPANT	\N	PRESENT	0
474523	470579	14327T	PARTICIPANT	\N	PRESENT	0
474524	470579	07033P	PARTICIPANT	\N	PRESENT	0
474525	474195	19253P	PARTICIPANT	\N	PRESENT	0
474526	474195	04038G	PARTICIPANT	\N	PRESENT	0
474527	474195	19629C	PARTICIPANT	\N	PRESENT	0
474528	473417	14327T	PARTICIPANT	\N	PRESENT	0
474529	473417	14331P	PARTICIPANT	\N	PRESENT	0
474530	473417	11048N	PARTICIPANT	\N	PRESENT	0
474531	473417	19479G	PARTICIPANT	\N	PRESENT	0
474532	473417	19711U	PARTICIPANT	\N	PRESENT	0
474533	473417	19689Q	PARTICIPANT	\N	PRESENT	0
474534	473417	11053K	PARTICIPANT	\N	PRESENT	0
474535	473417	11074Q	PRESIDENT	0	PRESENT	0
474536	473417	14034U	PARTICIPANT	\N	PRESENT	0
474537	473417	88008L	PARTICIPANT	\N	PRESENT	0
474538	473417	04086Q	PARTICIPANT	\N	PRESENT	0
474539	473417	14083S	PARTICIPANT	\N	PRESENT	0
474540	473417	14085U	PARTICIPANT	\N	PRESENT	0
474541	473417	19741B	PARTICIPANT	\N	PRESENT	0
474542	473417	14253S	PARTICIPANT	\N	PRESENT	0
474543	473417	07029T	PARTICIPANT	\N	EXCUSE	0
474544	473417	08011M	PARTICIPANT	\N	EXCUSE	0
474545	470579	08028W	PARTICIPANT	\N	PRESENT	0
474546	470579	11067R	PARTICIPANT	\N	PRESENT	0
474547	470579	14157T	PARTICIPANT	\N	PRESENT	0
474548	470579	19415P	PARTICIPANT	\N	PRESENT	0
474551	470579	19667J	PARTICIPANT	\N	PRESENT	0
474557	470579	14021P	PARTICIPANT	\N	PRESENT	0
474558	470579	19549D	PARTICIPANT	\N	PRESENT	0
474572	470579	04033B	PARTICIPANT	\N	PRESENT	0
474573	470579	14053L	PARTICIPANT	\N	PRESENT	0
474574	470579	19543W	PARTICIPANT	\N	PRESENT	0
474575	470579	18083K	PARTICIPANT	\N	PRESENT	0
474576	470579	11026G	PARTICIPANT	\N	PRESENT	0
474578	470579	14193X	PARTICIPANT	\N	PRESENT	0
474579	470579	19758L	PARTICIPANT	\N	PRESENT	0
474580	470579	19479G	PARTICIPANT	\N	PRESENT	0
474582	470579	19647E	PARTICIPANT	\N	PRESENT	0
474583	470579	14179A	PARTICIPANT	\N	PRESENT	0
474584	470579	19649G	PARTICIPANT	\N	PRESENT	0
474622	473389	05008E	PARTICIPANT	\N	PRESENT	0
474623	473389	19649G	PARTICIPANT	\N	PRESENT	0
474624	473389	11026G	PARTICIPANT	\N	PRESENT	0
474625	473389	19782L	PARTICIPANT	\N	PRESENT	0
474626	473389	19543W	PARTICIPANT	\N	PRESENT	0
474627	473389	19585H	PARTICIPANT	\N	PRESENT	0
474628	473389	17589D	PARTICIPANT	\N	PRESENT	0
474629	473389	14034U	PARTICIPANT	\N	PRESENT	0
474630	473389	14179A	PARTICIPANT	\N	PRESENT	0
474631	473389	01028R	PARTICIPANT	\N	PRESENT	0
474632	473389	01024M	PARTICIPANT	\N	PRESENT	0
474633	473389	19479G	PARTICIPANT	\N	PRESENT	0
474634	473389	14231L	PARTICIPANT	\N	PRESENT	0
474635	473389	19565D	PARTICIPANT	\N	PRESENT	0
474636	473389	19758L	PARTICIPANT	\N	PRESENT	0
474637	473389	04033B	PARTICIPANT	\N	PRESENT	0
474638	473389	14193X	PARTICIPANT	\N	PRESENT	0
474639	473389	07033P	PARTICIPANT	\N	PRESENT	0
474640	473389	04049K	PARTICIPANT	\N	PRESENT	0
474641	473389	18083K	PARTICIPANT	\N	PRESENT	0
474642	473389	19741B	PARTICIPANT	\N	PRESENT	0
474643	473389	19687N	PARTICIPANT	\N	PRESENT	0
474645	473389	14147R	PARTICIPANT	\N	PRESENT	0
474646	473389	14331P	PARTICIPANT	\N	PRESENT	0
474647	473389	08010L	PARTICIPANT	\N	PRESENT	0
474648	473389	95063L	PARTICIPANT	\N	PRESENT	0
474651	473389	11085T	PARTICIPANT	\N	PRESENT	0
474653	473389	11053K	PARTICIPANT	\N	PRESENT	0
474656	473389	14053L	PARTICIPANT	\N	PRESENT	0
474658	473389	19489J	PARTICIPANT	\N	PRESENT	0
474686	473389	19685L	PARTICIPANT	\N	PRESENT	0
474687	473389	14021P	PARTICIPANT	\N	PRESENT	0
474688	473389	11067R	PARTICIPANT	\N	PRESENT	0
474689	473389	14001X	PARTICIPANT	\N	PRESENT	0
474690	473389	19691J	PARTICIPANT	\N	PRESENT	0
474620	473389	11072N	PARTICIPANT	\N	PRESENT	0
474621	473389	19647E	PARTICIPANT	\N	PRESENT	0
474691	473389	14069U	PARTICIPANT	\N	PRESENT	0
474718	473389	11048N	PARTICIPANT	\N	PRESENT	0
474719	473389	14157T	PARTICIPANT	\N	PRESENT	0
474720	473389	19762G	PARTICIPANT	\N	PRESENT	0
474721	473389	08061X	PARTICIPANT	\N	PRESENT	0
474786	473389	04040A	PARTICIPANT	\N	PRESENT	0
474797	472122	14053L	PARTICIPANT	\N	PRESENT	0
474798	472122	04070G	PARTICIPANT	\N	PRESENT	0
474799	472122	11048N	PARTICIPANT	\N	PRESENT	0
474800	472122	19251M	PARTICIPANT	\N	PRESENT	0
474801	472122	19826F	PARTICIPANT	\N	PRESENT	0
474802	472122	14093U	PARTICIPANT	\N	PRESENT	0
474803	472122	14051J	PARTICIPANT	\N	PRESENT	0
474804	472122	08060W	PARTICIPANT	\N	PRESENT	0
474805	472122	08009T	PRESIDENT	0	PRESENT	0
474806	472122	19367Y	PARTICIPANT	\N	PRESENT	0
474807	472122	08024S	PARTICIPANT	\N	PRESENT	0
474808	472122	19758L	PARTICIPANT	\N	PRESENT	0
474809	472122	11065P	PARTICIPANT	\N	PRESENT	0
474810	472122	14079W	PARTICIPANT	\N	EXCUSE	0
474811	472122	19413M	PARTICIPANT	\N	EXCUSE	0
474812	472122	14033T	PARTICIPANT	\N	EXCUSE	0
474813	472122	19581D	PARTICIPANT	\N	EXCUSE	0
476363	476324	14097Y	PARTICIPANT	\N	PRESENT	0
474815	472122	19637C	PARTICIPANT	\N	EXCUSE	0
476361	476324	19611R	PRESIDENT	0	PRESENT	0
476362	476324	19549D	PARTICIPANT	\N	PRESENT	0
476364	476324	19723Y	PARTICIPANT	\N	PRESENT	0
476365	476351	04047H	PARTICIPANT	\N	EXCUSE	0
476366	476357	04047H	PARTICIPANT	\N	EXCUSE	0
476417	476262	19651A	PARTICIPANT	\N	PRESENT	0
476418	476262	19667J	PARTICIPANT	\N	PRESENT	0
476419	476262	11053K	PARTICIPANT	\N	PRESENT	0
476420	476262	04086Q	PARTICIPANT	\N	PRESENT	0
476422	476262	11070L	PARTICIPANT	\N	PRESENT	0
476424	476262	04071H	PARTICIPANT	\N	PRESENT	0
476425	476262	11074Q	PARTICIPANT	\N	PRESENT	0
476426	476262	99004R	PARTICIPANT	\N	PRESENT	0
476427	476262	19711U	PARTICIPANT	\N	PRESENT	0
476428	476262	19687N	PARTICIPANT	\N	PRESENT	0
476440	476439	14147R	PARTICIPANT	\N	PRESENT	0
476441	476349	14097Y	PARTICIPANT	\N	PRESENT	0
476442	476349	19629C	PARTICIPANT	\N	PRESENT	0
476443	476349	19611R	PRESIDENT	0	PRESENT	0
476444	476349	14197C	PARTICIPANT	\N	PRESENT	0
476445	476349	19549D	PARTICIPANT	\N	PRESENT	0
476446	476349	19723Y	PARTICIPANT	\N	PRESENT	0
476510	476351	95063L	PARTICIPANT	\N	PRESENT	0
476511	476351	19649G	PARTICIPANT	\N	PRESENT	0
476512	476351	14041T	PARTICIPANT	\N	PRESENT	0
476513	476351	11026G	PARTICIPANT	\N	PRESENT	0
476514	476351	14147R	PARTICIPANT	\N	PRESENT	0
476515	476351	19585H	PARTICIPANT	\N	PRESENT	0
476516	476351	19447X	PARTICIPANT	\N	PRESENT	0
476517	476351	05008E	PRESIDENT	0	PRESENT	0
476539	473392	11027H	PARTICIPANT	\N	PRESENT	0
476541	473392	11067R	PARTICIPANT	\N	PRESENT	0
476542	473392	19649G	PARTICIPANT	\N	PRESENT	0
476543	473392	05008E	PARTICIPANT	\N	PRESENT	0
476544	473392	14147R	PARTICIPANT	\N	PRESENT	0
476545	473392	14235Q	PARTICIPANT	\N	PRESENT	0
476546	473392	19565D	PARTICIPANT	\N	PRESENT	0
476547	473392	11031D	PARTICIPANT	\N	PRESENT	0
476548	473392	19599P	PARTICIPANT	\N	PRESENT	0
476549	473392	19585H	PARTICIPANT	\N	PRESENT	0
476550	473392	08031R	PARTICIPANT	\N	PRESENT	0
476551	473392	14030Q	PARTICIPANT	\N	PRESENT	0
476552	473392	14089Y	PARTICIPANT	\N	PRESENT	0
476553	473392	19826F	PARTICIPANT	\N	PRESENT	0
476554	473392	14265W	PARTICIPANT	\N	PRESENT	0
458800	458799	04085P	PARTICIPANT	\N	PRESENT	0
458801	458799	05008E	PARTICIPANT	\N	PRESENT	0
458802	458799	96004D	PARTICIPANT	\N	PRESENT	0
458803	458799	04042C	PARTICIPANT	\N	PRESENT	0
458804	458799	04086Q	PARTICIPANT	\N	PRESENT	0
458805	458799	14079W	PARTICIPANT	\N	PRESENT	0
458806	458799	11070L	PARTICIPANT	\N	PRESENT	0
458807	458799	11074Q	PARTICIPANT	\N	PRESENT	0
458808	458799	14231L	PARTICIPANT	\N	PRESENT	0
458809	458799	14034U	PARTICIPANT	\N	PRESENT	0
458810	458799	14021P	PARTICIPANT	\N	PRESENT	0
458811	458799	01043Q	PARTICIPANT	\N	PRESENT	0
458812	458799	14219Q	PARTICIPANT	\N	PRESENT	0
458813	458799	14251Q	PARTICIPANT	\N	PRESENT	0
458814	458799	14031R	PARTICIPANT	\N	PRESENT	0
458816	458799	04092N	PARTICIPANT	\N	PRESENT	0
458817	458799	11072N	PARTICIPANT	\N	PRESENT	0
458819	458799	08011M	PARTICIPANT	\N	PRESENT	0
458821	458799	04070G	PARTICIPANT	\N	PRESENT	0
458822	458799	05012A	PARTICIPANT	\N	PRESENT	0
458823	458799	11090Q	PARTICIPANT	\N	PRESENT	0
458824	458799	11012A	PARTICIPANT	\N	PRESENT	0
458825	458799	04033B	PARTICIPANT	\N	PRESENT	0
458826	458799	04044E	PARTICIPANT	\N	PRESENT	0
458827	458799	01034P	PARTICIPANT	\N	PRESENT	0
458831	456615	14239U	PARTICIPANT	\N	PRESENT	0
458891	456617	14217N	PARTICIPANT	\N	PRESENT	0
458833	456615	14261S	PARTICIPANT	\N	PRESENT	0
458834	456615	19717B	PARTICIPANT	\N	PRESENT	0
458835	456615	19575F	PARTICIPANT	\N	PRESENT	0
458836	456615	19367Y	PARTICIPANT	\N	PRESENT	0
458837	456615	19415P	PARTICIPANT	\N	PRESENT	0
458838	456615	11103C	PARTICIPANT	\N	PRESENT	0
458839	456615	14195A	PARTICIPANT	\N	PRESENT	0
458840	456615	11031D	PARTICIPANT	\N	PRESENT	0
458841	456615	08052W	PARTICIPANT	\N	PRESENT	0
458889	456615	19527W	PARTICIPANT	\N	PRESENT	0
458843	456615	98024R	PARTICIPANT	\N	PRESENT	0
458844	456615	10006L	PARTICIPANT	\N	PRESENT	0
458845	456615	14217N	PARTICIPANT	\N	PRESENT	0
458890	456615	19663E	PARTICIPANT	\N	PRESENT	0
458847	456615	14042U	PARTICIPANT	\N	PRESENT	0
458848	456615	14281W	PARTICIPANT	\N	PRESENT	0
458849	456615	14087W	PARTICIPANT	\N	PRESENT	0
458850	456615	19521Q	PARTICIPANT	\N	PRESENT	0
458851	456615	14355X	PARTICIPANT	\N	PRESENT	0
458892	456617	01034P	PARTICIPANT	\N	PRESENT	0
458853	456615	08041T	PARTICIPANT	\N	EXCUSE	0
458893	457565	11045K	PARTICIPANT	\N	PRESENT	0
458855	456615	14026U	PARTICIPANT	\N	PRESENT	0
458856	456615	19691J	PARTICIPANT	\N	PRESENT	0
458857	456615	19553Y	PARTICIPANT	\N	PRESENT	0
458858	456615	19569H	PARTICIPANT	\N	PRESENT	0
458894	457565	01034P	PARTICIPANT	\N	PRESENT	0
458895	457565	08052W	PARTICIPANT	\N	PRESENT	0
458861	456615	19715Y	PARTICIPANT	\N	PRESENT	0
458862	456615	19683J	PARTICIPANT	\N	PRESENT	0
458863	456615	19723Y	PARTICIPANT	\N	PRESENT	0
458864	456615	19697Q	PARTICIPANT	\N	PRESENT	0
458865	456615	17779H	PARTICIPANT	\N	PRESENT	0
458896	457565	14217N	PARTICIPANT	\N	PRESENT	0
458867	456615	11067R	PARTICIPANT	\N	PRESENT	0
458897	457565	19527W	PARTICIPANT	\N	PRESENT	0
458869	456615	04092N	PARTICIPANT	\N	PRESENT	0
458870	456615	14119M	PARTICIPANT	\N	PRESENT	0
458871	456615	14071N	PARTICIPANT	\N	PRESENT	0
458872	456615	19679N	PARTICIPANT	\N	PRESENT	0
458873	456615	19798U	PARTICIPANT	\N	PRESENT	0
458874	456615	11045K	PARTICIPANT	\N	PRESENT	0
458875	456615	11097X	PARTICIPANT	\N	PRESENT	0
458876	456615	19703U	PARTICIPANT	\N	PRESENT	0
458898	457565	04092N	PRESIDENT	\N	PRESENT	0
458878	456615	14227Q	PARTICIPANT	\N	PRESENT	0
458899	457565	98024R	PARTICIPANT	\N	PRESENT	0
458880	456615	01034P	PARTICIPANT	\N	PRESENT	0
458900	457565	19521Q	PARTICIPANT	\N	PRESENT	0
458901	457565	14261S	PARTICIPANT	\N	PRESENT	0
458902	457565	10006L	PARTICIPANT	\N	PRESENT	0
458903	457565	14071N	PARTICIPANT	\N	PRESENT	0
458904	457565	11103C	PARTICIPANT	\N	PRESENT	0
458905	457565	19723Y	PARTICIPANT	\N	PRESENT	0
458906	457565	14119M	PARTICIPANT	\N	PRESENT	0
458907	457565	19691J	PARTICIPANT	\N	PRESENT	0
458908	457565	19717B	PARTICIPANT	\N	PRESENT	0
458909	457565	19663E	PARTICIPANT	\N	PRESENT	0
458910	457565	19715Y	PARTICIPANT	\N	PRESENT	0
458911	457565	17779H	PARTICIPANT	\N	PRESENT	0
458912	457565	08041T	PARTICIPANT	\N	EXCUSE	0
458913	457565	14026U	PARTICIPANT	\N	PRESENT	0
458914	457565	19683J	PARTICIPANT	\N	PRESENT	0
458915	457565	14195A	PARTICIPANT	\N	PRESENT	0
458916	457565	19367Y	PARTICIPANT	\N	PRESENT	0
458917	457565	19565D	PARTICIPANT	\N	EXCUSE	0
458918	457565	19697Q	PARTICIPANT	\N	PRESENT	0
458919	457565	14227Q	PARTICIPANT	\N	PRESENT	0
458920	457565	19703U	PARTICIPANT	\N	PRESENT	0
458921	457565	11097X	PARTICIPANT	\N	PRESENT	0
458922	457565	19415P	PARTICIPANT	\N	PRESENT	0
458923	457565	19798U	PARTICIPANT	\N	PRESENT	0
458924	457565	19569H	PARTICIPANT	\N	PRESENT	0
458925	457565	11067R	PARTICIPANT	\N	PRESENT	0
458926	457565	14355X	PARTICIPANT	\N	PRESENT	0
458927	457565	14042U	PARTICIPANT	\N	PRESENT	0
458928	457565	19575F	PARTICIPANT	\N	PRESENT	0
458929	457565	14281W	PARTICIPANT	\N	PRESENT	0
458930	457565	19679N	PARTICIPANT	\N	PRESENT	0
458931	457565	19553Y	PARTICIPANT	\N	PRESENT	0
458932	457565	14087W	PARTICIPANT	\N	PRESENT	0
458933	457565	14239U	PARTICIPANT	\N	PRESENT	0
458934	457565	11031D	PARTICIPANT	\N	PRESENT	0
460748	460747	19631V	PARTICIPANT	\N	PRESENT	0
460749	460747	11101A	PARTICIPANT	\N	PRESENT	0
460750	460747	14085U	PARTICIPANT	\N	PRESENT	0
460751	460747	19629C	PARTICIPANT	\N	PRESENT	0
460752	460747	08028W	PARTICIPANT	\N	PRESENT	0
460753	460747	14197C	PARTICIPANT	\N	PRESENT	0
460754	460747	19703U	PARTICIPANT	\N	PRESENT	0
461279	457893	96004D	PRESIDENT	0	PRESENT	0
461280	457893	08014Q	PARTICIPANT	\N	PRESENT	0
461281	457893	14079W	PARTICIPANT	\N	PRESENT	0
461282	457893	11083R	PARTICIPANT	\N	PRESENT	0
461283	457893	14026U	PARTICIPANT	\N	PRESENT	0
461284	457893	19553Y	PARTICIPANT	\N	PRESENT	0
461285	457893	04097T	PARTICIPANT	\N	PRESENT	0
461286	457893	14097Y	PARTICIPANT	\N	PRESENT	0
461287	457893	14241N	PARTICIPANT	\N	PRESENT	0
461288	457893	11026G	PARTICIPANT	\N	PRESENT	0
461289	457893	04057K	PARTICIPANT	\N	PRESENT	0
461290	457893	14237S	PARTICIPANT	\N	PRESENT	0
461291	457893	14331P	PARTICIPANT	\N	PRESENT	0
461292	457893	10015M	PARTICIPANT	\N	PRESENT	0
461293	457893	98035U	PARTICIPANT	\N	PRESENT	0
461294	457893	14073Q	PARTICIPANT	\N	PRESENT	0
461299	461298	96004D	PARTICIPANT	\N	PRESENT	0
461300	461298	11026G	PARTICIPANT	\N	PRESENT	0
461301	461298	14205J	PARTICIPANT	\N	PRESENT	0
461302	461298	04097T	PARTICIPANT	\N	PRESENT	0
461303	461298	95030B	PARTICIPANT	\N	PRESENT	0
461610	461608	14227Q	PARTICIPANT	\N	PRESENT	0
463756	463755	19515S	PARTICIPANT	\N	PRESENT	0
463757	463755	19782L	PARTICIPANT	\N	PRESENT	0
463758	463755	11077T	PARTICIPANT	\N	PRESENT	0
463759	463755	14357A	PARTICIPANT	\N	PRESENT	0
463760	463755	19812Y	PARTICIPANT	\N	PRESENT	0
463761	463755	19441R	PARTICIPANT	\N	PRESENT	0
463762	463755	14081Q	PARTICIPANT	\N	PRESENT	0
463763	463755	80013X	PARTICIPANT	\N	PRESENT	0
463764	463755	04045F	PARTICIPANT	\N	PRESENT	0
463765	463755	19631V	PARTICIPANT	\N	PRESENT	0
463766	463755	11099A	PARTICIPANT	\N	PRESENT	0
463767	463755	04049K	PARTICIPANT	\N	PRESENT	0
463768	463755	08015R	PARTICIPANT	\N	PRESENT	0
463769	463755	08019V	PARTICIPANT	\N	PRESENT	0
463770	463755	14197C	PARTICIPANT	\N	PRESENT	0
463771	463755	19369B	PARTICIPANT	\N	PRESENT	0
463772	463755	19563B	PARTICIPANT	\N	PRESENT	0
463773	463755	08028W	PARTICIPANT	\N	PRESENT	0
463774	463755	14265W	PARTICIPANT	\N	PRESENT	0
463775	463755	14135M	PARTICIPANT	\N	PRESENT	0
463776	463755	14187A	PARTICIPANT	\N	PRESENT	0
463777	463755	08038Y	PARTICIPANT	\N	PRESENT	0
463778	463755	19695N	PARTICIPANT	\N	PRESENT	0
463779	463755	11090Q	PRESIDENT	0	PRESENT	0
463780	463755	14033T	PARTICIPANT	\N	PRESENT	0
463781	463755	19269X	PARTICIPANT	\N	PRESENT	0
463782	463755	14205J	PARTICIPANT	\N	PRESENT	0
463783	463755	11056N	PARTICIPANT	\N	PRESENT	0
463784	463755	04089T	PARTICIPANT	\N	PRESENT	0
463785	463755	14115H	PARTICIPANT	\N	PRESENT	0
472050	472014	04040A	PARTICIPANT	\N	EXCUSE	0
472554	470439	01028R	PARTICIPANT	\N	PRESENT	0
472599	471173	19647E	PARTICIPANT	\N	EXCUSE	0
472602	471173	19551W	PARTICIPANT	\N	PRESENT	0
472604	471687	19565D	PARTICIPANT	\N	EXCUSE	0
472621	471687	14231L	PARTICIPANT	\N	EXCUSE	0
472622	471687	04040A	PRESIDENT	0	PRESENT	0
472640	471687	14257W	PARTICIPANT	\N	EXCUSE	0
472641	471687	14071N	PARTICIPANT	\N	EXCUSE	0
472657	471173	19713W	PARTICIPANT	\N	EXCUSE	0
472770	472056	14065Q	PARTICIPANT	\N	PRESENT	0
472771	472056	19581D	PARTICIPANT	\N	PRESENT	0
472772	472056	19675J	PARTICIPANT	\N	PRESENT	0
472773	472056	19725B	PARTICIPANT	\N	PRESENT	0
472774	472056	98035U	PARTICIPANT	\N	PRESENT	0
472775	472056	01024M	PARTICIPANT	\N	PRESENT	0
472776	472056	11049P	PARTICIPANT	\N	PRESENT	0
472777	472056	11033F	PARTICIPANT	\N	PRESENT	0
472778	472056	08018U	PARTICIPANT	\N	PRESENT	0
472779	472056	19719D	PARTICIPANT	\N	PRESENT	0
472780	472057	14065Q	PARTICIPANT	\N	PRESENT	0
472781	472057	19581D	PARTICIPANT	\N	PRESENT	0
472782	472057	19675J	PARTICIPANT	\N	PRESENT	0
472783	472057	19725B	PARTICIPANT	\N	PRESENT	0
472784	472057	98035U	PARTICIPANT	\N	PRESENT	0
472785	472057	01024M	PARTICIPANT	\N	PRESENT	0
472786	472057	11049P	PARTICIPANT	\N	PRESENT	0
472787	472057	19673G	PARTICIPANT	\N	PRESENT	0
472788	472057	11033F	PARTICIPANT	\N	PRESENT	0
472789	472057	08018U	PARTICIPANT	\N	PRESENT	0
472790	472057	19719D	PARTICIPANT	\N	PRESENT	0
472791	472058	14065Q	PARTICIPANT	\N	PRESENT	0
472792	472058	19581D	PARTICIPANT	\N	PRESENT	0
472793	472058	19675J	PARTICIPANT	\N	PRESENT	0
472794	472058	19725B	PARTICIPANT	\N	PRESENT	0
472795	472058	98035U	PARTICIPANT	\N	PRESENT	0
472796	472058	01024M	PARTICIPANT	\N	PRESENT	0
472797	472058	11049P	PARTICIPANT	\N	PRESENT	0
472798	472058	19673G	PARTICIPANT	\N	PRESENT	0
472799	472058	11033F	PARTICIPANT	\N	PRESENT	0
472800	472058	08018U	PARTICIPANT	\N	PRESENT	0
472801	472058	19719D	PARTICIPANT	\N	PRESENT	0
472803	472060	14065Q	PARTICIPANT	\N	PRESENT	0
472804	472060	19581D	PARTICIPANT	\N	PRESENT	0
472805	472060	19675J	PARTICIPANT	\N	PRESENT	0
472806	472060	19725B	PARTICIPANT	\N	PRESENT	0
472807	472060	98035U	PARTICIPANT	\N	PRESENT	0
472808	472060	01024M	PARTICIPANT	\N	PRESENT	0
472809	472060	11049P	PARTICIPANT	\N	PRESENT	0
472810	472060	19673G	PARTICIPANT	\N	PRESENT	0
472811	472060	08018U	PARTICIPANT	\N	PRESENT	0
472812	472060	19719D	PARTICIPANT	\N	PRESENT	0
472813	472060	11033F	PARTICIPANT	\N	PRESENT	0
472821	472597	19549D	PARTICIPANT	\N	PRESENT	0
472822	472597	19629C	PARTICIPANT	\N	PRESENT	0
472823	472597	14197C	PARTICIPANT	\N	PRESENT	0
472824	472597	14033T	PARTICIPANT	\N	PRESENT	0
472825	472597	19723Y	PARTICIPANT	\N	PRESENT	0
472996	470890	19575F	PARTICIPANT	\N	PRESENT	0
472999	471173	01028R	PARTICIPANT	\N	EXCUSE	0
473029	471173	11097X	PARTICIPANT	\N	PRESENT	0
473208	468777	14030Q	PRESIDENT	0	PRESENT	0
473209	468777	08043V	PARTICIPANT	\N	EXCUSE	0
473210	468777	08024S	PARTICIPANT	\N	EXCUSE	0
473211	468777	19693L	PARTICIPANT	\N	EXCUSE	0
473212	468777	07029T	PARTICIPANT	\N	EXCUSE	0
473213	468777	14235Q	PARTICIPANT	\N	EXCUSE	0
473214	468777	19701S	PARTICIPANT	\N	EXCUSE	0
473216	473215	11104D	PARTICIPANT	\N	EXCUSE	0
474230	463588	08060W	PARTICIPANT	\N	PRESENT	0
474231	463588	19733B	PARTICIPANT	\N	PRESENT	0
474232	463588	19383Y	PARTICIPANT	\N	PRESENT	0
474233	463588	14093U	PARTICIPANT	\N	PRESENT	0
474234	463588	08055A	PARTICIPANT	\N	PRESENT	0
474235	463588	14038Y	PARTICIPANT	\N	PRESENT	0
474236	463588	19681G	PARTICIPANT	\N	PRESENT	0
474237	463588	19599P	PARTICIPANT	\N	PRESENT	0
474238	463588	19820Y	PARTICIPANT	\N	PRESENT	0
474239	463588	19387D	PARTICIPANT	\N	PRESENT	0
474240	463588	19347U	PARTICIPANT	\N	PRESENT	0
474241	463588	18083K	PARTICIPANT	\N	PRESENT	0
474242	463588	19333N	PARTICIPANT	\N	PRESENT	0
474243	463588	04097T	PARTICIPANT	\N	PRESENT	0
474244	463588	19551W	PARTICIPANT	\N	PRESENT	0
474245	463588	19289C	PARTICIPANT	\N	PRESENT	0
474246	463588	14219Q	PARTICIPANT	\N	PRESENT	0
474247	463588	14031R	PARTICIPANT	\N	PRESENT	0
474248	463588	19637C	PARTICIPANT	\N	PRESENT	0
474249	463588	08009T	PRESIDENT	0	PRESENT	0
474250	463588	14221J	PARTICIPANT	\N	PRESENT	0
474251	463588	17637T	PARTICIPANT	\N	PRESENT	0
474252	463588	19745F	PARTICIPANT	\N	PRESENT	0
474253	463588	14237S	PARTICIPANT	\N	PRESENT	0
474254	463588	19503N	PARTICIPANT	\N	PRESENT	0
474255	463588	19739H	PARTICIPANT	\N	PRESENT	0
474256	463588	17583W	PARTICIPANT	\N	PRESENT	0
474257	463588	19794Q	PARTICIPANT	\N	PRESENT	0
474258	463588	19713W	PARTICIPANT	\N	PRESENT	0
474259	463588	14051J	PARTICIPANT	\N	PRESENT	0
474260	463588	14157T	PARTICIPANT	\N	PRESENT	0
474261	463588	19737F	PARTICIPANT	\N	PRESENT	0
474304	473557	14071N	PARTICIPANT	\N	EXCUSE	0
474305	473557	04040A	PRESIDENT	0	PRESENT	0
474309	474308	01034P	PARTICIPANT	\N	PRESENT	0
474310	474308	11103C	PARTICIPANT	\N	PRESENT	0
474311	474308	14227Q	PARTICIPANT	\N	PRESENT	0
474312	474308	19798U	PARTICIPANT	\N	PRESENT	0
474313	474308	11067R	PARTICIPANT	\N	PRESENT	0
474314	474308	08052W	PARTICIPANT	\N	PRESENT	0
474315	474308	10006L	PARTICIPANT	\N	PRESENT	0
474316	474308	19565D	PARTICIPANT	\N	PRESENT	0
474317	474308	17779H	PARTICIPANT	\N	PRESENT	0
474318	474308	14213J	PARTICIPANT	\N	PRESENT	0
474319	474308	19415P	PARTICIPANT	\N	PRESENT	0
474320	474308	19569H	PARTICIPANT	\N	PRESENT	0
474321	474308	19657G	PARTICIPANT	\N	PRESENT	0
474322	474308	19703U	PARTICIPANT	\N	PRESENT	0
474396	470981	08039A	PARTICIPANT	\N	PRESENT	0
474397	470982	08039A	PARTICIPANT	\N	PRESENT	0
474436	474434	14147R	PARTICIPANT	\N	PRESENT	0
474430	474428	14147R	PARTICIPANT	\N	PRESENT	0
474432	474431	19649G	PARTICIPANT	\N	PRESENT	0
474433	474431	14147R	PARTICIPANT	\N	PRESENT	0
474435	474434	11033F	PARTICIPANT	\N	PRESENT	0
475458	475457	08012N	PARTICIPANT	\N	PRESENT	0
475459	475457	02002K	PARTICIPANT	\N	PRESENT	0
475460	475457	19399H	PARTICIPANT	\N	PRESENT	0
475461	475457	19721W	PARTICIPANT	\N	PRESENT	0
475462	475457	14241N	PARTICIPANT	\N	PRESENT	0
475463	475457	19725B	PARTICIPANT	\N	PRESENT	0
475464	475457	19711U	PARTICIPANT	\N	PRESENT	0
475465	475457	14030Q	PARTICIPANT	\N	PRESENT	0
475466	475457	19349W	PARTICIPANT	\N	PRESENT	0
475467	475457	11043H	PARTICIPANT	\N	PRESENT	0
475468	475457	19251M	PARTICIPANT	\N	PRESENT	0
475469	475457	08024S	PARTICIPANT	\N	PRESENT	0
475470	475457	14073Q	PARTICIPANT	\N	PRESENT	0
475481	474785	17583W	PARTICIPANT	\N	PRESENT	0
475482	474785	19737F	PARTICIPANT	\N	PRESENT	0
475484	474785	04069P	PARTICIPANT	\N	PRESENT	0
475485	474785	19333N	PARTICIPANT	\N	PRESENT	0
475488	474785	14169X	PARTICIPANT	\N	PRESENT	0
475489	474785	19713W	PARTICIPANT	\N	PRESENT	0
475490	474785	19637C	PARTICIPANT	\N	PRESENT	0
475491	474785	14051J	PARTICIPANT	\N	PRESENT	0
475534	475526	19515S	PARTICIPANT	\N	PRESENT	0
475536	475526	14329V	PARTICIPANT	\N	PRESENT	0
475538	475526	14357A	PARTICIPANT	\N	PRESENT	0
475540	475526	14205J	PARTICIPANT	\N	PRESENT	0
475639	473557	11110B	PARTICIPANT	\N	PRESENT	0
475846	473369	19798U	PARTICIPANT	\N	PRESENT	0
475847	473369	19387D	PARTICIPANT	\N	PRESENT	0
475848	473369	19575F	PARTICIPANT	\N	PRESENT	0
476005	475890	19415P	PARTICIPANT	\N	PRESENT	0
476006	475892	19415P	PARTICIPANT	\N	PRESENT	0
476007	475892	19723Y	PARTICIPANT	\N	PRESENT	0
476008	475892	19798U	PARTICIPANT	\N	PRESENT	0
476009	475892	19657G	PARTICIPANT	\N	PRESENT	0
476010	475896	19679N	PARTICIPANT	\N	PRESENT	0
476011	475897	19679N	PARTICIPANT	\N	PRESENT	0
476021	476020	11043H	PARTICIPANT	\N	PRESENT	0
476022	476020	08012N	PARTICIPANT	\N	PRESENT	0
476023	476020	19725B	PARTICIPANT	\N	PRESENT	0
476024	476020	19349W	PARTICIPANT	\N	PRESENT	0
476025	476020	08024S	PARTICIPANT	\N	PRESENT	0
456443	453991	14030Q	PRESIDENT	0	PRESENT	0
456444	453991	08043V	PARTICIPANT	\N	PRESENT	0
456446	453991	08020N	PARTICIPANT	\N	EXCUSE	0
456448	453991	18083K	PARTICIPANT	\N	PRESENT	0
456450	453991	11031D	PARTICIPANT	\N	PRESENT	0
456451	453991	19693L	PARTICIPANT	\N	PRESENT	0
456453	453991	14217N	PARTICIPANT	\N	PRESENT	0
456454	453991	19599P	PARTICIPANT	\N	EXCUSE	0
456456	453991	19715Y	PARTICIPANT	\N	PRESENT	0
456457	453991	08031R	PARTICIPANT	\N	PRESENT	0
456459	453991	07029T	PARTICIPANT	\N	EXCUSE	0
456461	453991	08017T	PARTICIPANT	\N	PRESENT	0
456462	453991	11067R	PARTICIPANT	\N	PRESENT	0
456464	453991	19749K	PARTICIPANT	\N	PRESENT	0
456500	456499	19515S	PARTICIPANT	\N	PRESENT	0
457072	448755	14051J	PARTICIPANT	\N	PRESENT	0
457073	448755	19747H	PARTICIPANT	\N	PRESENT	0
457074	448755	14123H	PARTICIPANT	\N	PRESENT	0
457084	457083	11080N	PARTICIPANT	\N	PRESENT	0
457085	457083	10015M	PARTICIPANT	\N	PRESENT	0
457086	457083	04040A	PARTICIPANT	\N	PRESENT	0
457087	457083	04044E	PARTICIPANT	\N	PRESENT	0
457088	457083	19671E	PARTICIPANT	\N	PRESENT	0
457089	457083	19673G	PARTICIPANT	\N	PRESENT	0
457090	457083	19719D	PARTICIPANT	\N	EXCUSE	0
457091	457083	19721W	PARTICIPANT	\N	PRESENT	0
457092	457083	08056B	PRESIDENT	0	PRESENT	0
457093	457083	19421M	PARTICIPANT	\N	PRESENT	0
457094	457083	07004J	PARTICIPANT	\N	PRESENT	0
457095	457083	08010L	PARTICIPANT	\N	EXCUSE	0
457096	457083	08053X	PARTICIPANT	\N	PRESENT	0
457097	448755	95030B	PARTICIPANT	\N	PRESENT	0
457098	448755	19467C	PARTICIPANT	\N	PRESENT	0
457101	448755	14197C	PARTICIPANT	\N	PRESENT	0
457102	448755	14201E	PARTICIPANT	\N	PRESENT	0
457103	448755	11012A	PARTICIPANT	\N	PRESENT	0
457104	448755	10006L	PARTICIPANT	\N	PRESENT	0
457105	448755	14031R	PARTICIPANT	\N	PRESENT	0
457106	448755	07004J	PARTICIPANT	\N	PRESENT	0
457107	448755	19782L	PARTICIPANT	\N	PRESENT	0
457108	457083	19669L	PARTICIPANT	\N	PRESENT	0
457112	448755	19575F	PARTICIPANT	\N	PRESENT	0
457110	448755	14217N	PARTICIPANT	\N	PRESENT	0
457111	448755	19725B	PARTICIPANT	\N	PRESENT	0
457563	455106	19671E	PARTICIPANT	\N	EXCUSE	0
457645	457643	11053K	PARTICIPANT	\N	PRESENT	0
457646	457643	14159V	PARTICIPANT	\N	PRESENT	0
457648	457643	05012A	PARTICIPANT	\N	PRESENT	0
458214	458213	96004D	PRESIDENT	0	PRESENT	0
458215	458213	19251M	PARTICIPANT	\N	PRESENT	0
458216	458213	04035D	PARTICIPANT	\N	PRESENT	0
458217	458213	04034C	PARTICIPANT	\N	PRESENT	0
458218	458213	01062T	PARTICIPANT	\N	PRESENT	0
458219	458213	14331P	PARTICIPANT	\N	PRESENT	0
458220	458213	98050T	PRESIDENT	1	PRESENT	0
458221	458213	14001X	PARTICIPANT	\N	PRESENT	0
458222	458213	12041X	PARTICIPANT	\N	PRESENT	0
462472	462471	11090Q	PARTICIPANT	\N	PRESENT	0
462473	462471	08028W	PARTICIPANT	\N	PRESENT	0
462475	462474	11090Q	PARTICIPANT	\N	PRESENT	0
462477	462476	11090Q	PARTICIPANT	\N	PRESENT	0
463338	463298	19643A	PARTICIPANT	\N	PRESENT	0
463336	463298	11097X	PARTICIPANT	\N	PRESENT	0
463337	463298	08010L	PARTICIPANT	\N	PRESENT	0
463339	463298	04071H	PARTICIPANT	\N	PRESENT	0
463340	463298	14251Q	PARTICIPANT	\N	PRESENT	0
464288	464287	08011M	PARTICIPANT	\N	PRESENT	0
465334	465330	19503N	PARTICIPANT	\N	PRESENT	0
465339	465337	19503N	PARTICIPANT	\N	PRESENT	0
466197	465336	14231L	PARTICIPANT	\N	PRESENT	0
466198	465336	14089Y	PARTICIPANT	\N	PRESENT	0
466605	466603	19503N	PARTICIPANT	\N	PRESENT	0
466607	466606	04049K	PARTICIPANT	\N	PRESENT	0
466608	466606	14265W	PARTICIPANT	\N	PRESENT	0
466609	466606	14061L	PARTICIPANT	\N	PRESENT	0
466610	466606	14041T	PARTICIPANT	\N	PRESENT	0
466611	466606	14030Q	PARTICIPANT	\N	PRESENT	0
466612	466606	14083S	PARTICIPANT	\N	PRESENT	0
467822	467638	14030Q	PARTICIPANT	\N	PRESENT	0
467823	467638	08043V	PARTICIPANT	\N	PRESENT	0
467824	467638	19758L	PARTICIPANT	\N	PRESENT	0
467825	467638	14249W	PARTICIPANT	\N	PRESENT	0
468408	468403	04018C	PARTICIPANT	\N	PRESENT	0
468410	468403	08039A	PARTICIPANT	\N	PRESENT	0
468412	468403	14109K	PARTICIPANT	\N	PRESENT	0
468414	468403	19735D	PARTICIPANT	\N	PRESENT	0
468416	468403	19749K	PARTICIPANT	\N	PRESENT	0
468444	467801	19549D	PARTICIPANT	\N	PRESENT	0
468445	467801	08060W	PARTICIPANT	\N	PRESENT	0
468446	467801	08024S	PARTICIPANT	\N	PRESENT	0
468447	467801	14038Y	PARTICIPANT	\N	PRESENT	0
468448	467801	18083K	PARTICIPANT	\N	PRESENT	0
468449	467801	19701S	PARTICIPANT	\N	PRESENT	0
468450	467801	11065P	PARTICIPANT	\N	PRESENT	0
468451	467801	19599P	PARTICIPANT	\N	PRESENT	0
468452	467801	02002K	PARTICIPANT	\N	PRESENT	0
468453	467801	19820Y	PARTICIPANT	\N	PRESENT	0
468454	467801	19347U	PARTICIPANT	\N	PRESENT	0
468455	467801	19551W	PARTICIPANT	\N	PRESENT	0
468456	467801	14031R	PARTICIPANT	\N	PRESENT	0
468457	467801	19637C	PARTICIPANT	\N	PRESENT	0
468458	467801	08009T	PRESIDENT	0	PRESENT	0
468459	467801	14237S	PARTICIPANT	\N	PRESENT	0
468460	467801	14221J	PARTICIPANT	\N	PRESENT	0
468461	467801	17637T	PARTICIPANT	\N	PRESENT	0
468462	467801	19745F	PARTICIPANT	\N	PRESENT	0
468463	467801	17583W	PARTICIPANT	\N	PRESENT	0
468464	467801	19794Q	PARTICIPANT	\N	PRESENT	0
468465	467801	19739H	PARTICIPANT	\N	PRESENT	0
468466	467801	19503N	PARTICIPANT	\N	PRESENT	0
468467	467801	14051J	PARTICIPANT	\N	PRESENT	0
468468	467801	19737F	PARTICIPANT	\N	PRESENT	0
468469	467801	14157T	PARTICIPANT	\N	PRESENT	0
468470	467801	19387D	PARTICIPANT	\N	PRESENT	0
468471	467801	14169X	PARTICIPANT	\N	PRESENT	0
468472	467801	19826F	PARTICIPANT	\N	PRESENT	0
468476	467801	19333N	PARTICIPANT	\N	PRESENT	0
468477	467801	04097T	PARTICIPANT	\N	EXCUSE	0
468478	467801	19383Y	PARTICIPANT	\N	PRESENT	0
468479	467801	14219Q	PARTICIPANT	\N	PRESENT	0
468480	467801	04085P	PARTICIPANT	\N	PRESENT	0
468707	468580	14069U	PARTICIPANT	\N	PRESENT	0
468708	468580	19253P	PARTICIPANT	\N	PRESENT	0
468709	468580	19525U	PARTICIPANT	\N	PRESENT	0
468710	468580	04086Q	PARTICIPANT	\N	PRESENT	0
468711	468580	14327T	PARTICIPANT	\N	PRESENT	0
468712	468580	11110B	PARTICIPANT	\N	PRESENT	0
468713	468580	14281W	PARTICIPANT	\N	PRESENT	0
468714	468580	14231L	PARTICIPANT	\N	PRESENT	0
468715	468580	19565D	PARTICIPANT	\N	PRESENT	0
468716	468580	11049P	PARTICIPANT	\N	PRESENT	0
468717	468580	01057W	PARTICIPANT	\N	PRESENT	0
468718	468580	11048N	PARTICIPANT	\N	PRESENT	0
468719	468580	19489J	PARTICIPANT	\N	PRESENT	0
468720	468580	08010L	PARTICIPANT	\N	PRESENT	0
468721	468580	14257W	PARTICIPANT	\N	PRESENT	0
468722	468580	05012A	PARTICIPANT	\N	PRESENT	0
468723	468580	19735D	PARTICIPANT	\N	PRESENT	0
468724	468580	04045F	PARTICIPANT	\N	PRESENT	0
468725	468580	04044E	PARTICIPANT	\N	PRESENT	0
468726	468580	14259Y	PARTICIPANT	\N	EXCUSE	0
468727	468580	19820Y	PARTICIPANT	\N	EXCUSE	0
468728	468580	19687N	PARTICIPANT	\N	EXCUSE	0
468729	468580	08049C	PARTICIPANT	\N	EXCUSE	0
468758	468580	04070G	PARTICIPANT	\N	PRESENT	0
468907	468634	19717B	PARTICIPANT	\N	PRESENT	0
468908	468634	19631V	PARTICIPANT	\N	PRESENT	0
468909	468634	19715Y	PARTICIPANT	\N	PRESENT	0
468910	468634	12016W	PARTICIPANT	\N	EXCUSE	0
468911	468634	14059S	PARTICIPANT	\N	PRESENT	0
468912	468634	14261S	PARTICIPANT	\N	PRESENT	0
469129	466411	19715Y	PARTICIPANT	\N	PRESENT	0
469130	466411	19301E	PARTICIPANT	\N	PRESENT	0
469131	466411	14331P	PARTICIPANT	\N	EXCUSE	0
469132	466411	14135M	PARTICIPANT	\N	EXCUSE	0
469133	466411	19691J	PARTICIPANT	\N	PRESENT	0
471800	470888	08049C	PARTICIPANT	\N	PRESENT	0
471801	470888	19335Q	PARTICIPANT	\N	PRESENT	0
472643	472086	19709B	PARTICIPANT	\N	PRESENT	0
472644	472086	07029T	PARTICIPANT	\N	EXCUSE	0
472658	472086	19667J	PARTICIPANT	\N	PRESENT	0
472659	472086	19545Y	PARTICIPANT	\N	PRESENT	0
472660	472086	14085U	PARTICIPANT	\N	PRESENT	0
472661	472086	14121F	PARTICIPANT	\N	PRESENT	0
472662	472086	19531S	PARTICIPANT	\N	PRESENT	0
472663	472086	99004R	PARTICIPANT	\N	PRESENT	0
472664	472086	19711U	PARTICIPANT	\N	PRESENT	0
472665	472086	14331P	PARTICIPANT	\N	PRESENT	0
472666	472086	14225N	PARTICIPANT	\N	PRESENT	0
472667	472086	11012A	PARTICIPANT	\N	PRESENT	0
472668	472086	19479G	PARTICIPANT	\N	PRESENT	0
474650	474581	14187A	PARTICIPANT	\N	PRESENT	0
474652	474581	14081Q	PARTICIPANT	\N	PRESENT	0
475977	474294	11109J	PARTICIPANT	\N	PRESENT	0
475978	474294	19717B	PARTICIPANT	\N	PRESENT	0
475979	474294	19631V	PARTICIPANT	\N	PRESENT	0
475980	474294	19577H	PARTICIPANT	\N	PRESENT	0
475981	474294	19715Y	PARTICIPANT	\N	PRESENT	0
475982	474294	14097Y	PARTICIPANT	\N	PRESENT	0
475983	474294	14059S	PARTICIPANT	\N	PRESENT	0
475984	474294	12016W	PARTICIPANT	\N	PRESENT	0
475985	474294	08019V	PRESIDENT	0	PRESENT	0
475986	474294	19657G	PARTICIPANT	\N	PRESENT	0
475987	474294	19703U	PARTICIPANT	\N	PRESENT	0
475988	474294	14157T	PARTICIPANT	\N	EXCUSE	0
475989	474294	98005N	PARTICIPANT	\N	EXCUSE	0
476555	473392	19693L	PARTICIPANT	\N	PRESENT	0
476556	473392	19643A	PARTICIPANT	\N	PRESENT	0
476557	473392	19766L	PARTICIPANT	\N	PRESENT	0
476558	473392	19621T	PARTICIPANT	\N	PRESENT	0
476559	473392	11045K	PARTICIPANT	\N	PRESENT	0
476560	473392	11033F	PARTICIPANT	\N	PRESENT	0
476561	473392	14021P	PARTICIPANT	\N	PRESENT	0
476562	473392	19295A	PARTICIPANT	\N	PRESENT	0
476563	473392	19749K	PARTICIPANT	\N	PRESENT	0
476564	473392	19447X	PARTICIPANT	\N	PRESENT	0
476565	473392	08017T	PARTICIPANT	\N	PRESENT	0
476566	473392	19415P	PARTICIPANT	\N	PRESENT	0
476567	473392	14059S	PARTICIPANT	\N	PRESENT	0
476568	473392	19735D	PARTICIPANT	\N	PRESENT	0
476569	473392	14215L	PARTICIPANT	\N	PRESENT	0
476570	473392	14157T	PARTICIPANT	\N	PRESENT	0
476571	473392	11072N	PARTICIPANT	\N	PRESENT	0
476572	473392	19333N	PARTICIPANT	\N	PRESENT	0
476586	473392	08028W	PARTICIPANT	\N	PRESENT	0
476587	473392	14135M	PARTICIPANT	\N	PRESENT	0
476588	473392	15447F	PARTICIPANT	\N	PRESENT	0
476589	473392	19673G	PARTICIPANT	\N	PRESENT	0
476590	473392	14115H	PARTICIPANT	\N	PRESENT	0
476593	473392	19525U	PARTICIPANT	\N	PRESENT	0
476594	473392	08068F	PARTICIPANT	\N	PRESENT	0
476596	473392	14121F	PARTICIPANT	\N	PRESENT	0
476597	473392	19629C	PARTICIPANT	\N	PRESENT	0
476600	473392	18083K	PARTICIPANT	\N	PRESENT	0
476605	473392	14042U	PARTICIPANT	\N	PRESENT	0
476612	473392	19741B	PARTICIPANT	\N	PRESENT	0
476613	473392	19573D	PARTICIPANT	\N	PRESENT	0
476614	473392	19691J	PARTICIPANT	\N	PRESENT	0
476615	473392	17779H	PARTICIPANT	\N	PRESENT	0
476616	473392	14053L	PARTICIPANT	\N	PRESENT	0
476617	473392	08034U	PARTICIPANT	\N	PRESENT	0
476618	473392	11085T	PARTICIPANT	\N	PRESENT	0
476619	473392	07029T	PARTICIPANT	\N	PRESENT	0
476632	473392	19747H	PARTICIPANT	\N	PRESENT	0
476633	473392	14069U	PARTICIPANT	\N	PRESENT	0
476634	473392	14211G	PARTICIPANT	\N	PRESENT	0
476635	473392	08039A	PARTICIPANT	\N	PRESENT	0
476636	473392	08061X	PARTICIPANT	\N	PRESENT	0
476638	473392	14251Q	PARTICIPANT	\N	PRESENT	0
476639	473392	11012A	PARTICIPANT	\N	PRESENT	0
476650	473392	08053X	PARTICIPANT	\N	PRESENT	0
476651	473392	89017R	PARTICIPANT	\N	PRESENT	0
476687	473393	14147R	PARTICIPANT	\N	PRESENT	0
476688	473393	11031D	PARTICIPANT	\N	PRESENT	0
476689	473393	19565D	PARTICIPANT	\N	PRESENT	0
476690	473393	11067R	PARTICIPANT	\N	PRESENT	0
476691	473393	19649G	PARTICIPANT	\N	PRESENT	0
476692	473393	08017T	PARTICIPANT	\N	PRESENT	0
476693	473393	11045K	PARTICIPANT	\N	PRESENT	0
476694	473393	04034C	PARTICIPANT	\N	PRESENT	0
476695	473393	11072N	PARTICIPANT	\N	PRESENT	0
476696	473393	14030Q	PARTICIPANT	\N	PRESENT	0
476697	473393	19749K	PARTICIPANT	\N	PRESENT	0
476698	473393	14133K	PARTICIPANT	\N	PRESENT	0
476699	473393	19447X	PARTICIPANT	\N	PRESENT	0
476700	473393	19643A	PARTICIPANT	\N	PRESENT	0
476701	473393	19679N	PARTICIPANT	\N	PRESENT	0
476702	473393	19766L	PARTICIPANT	\N	PRESENT	0
476703	473393	19747H	PARTICIPANT	\N	PRESENT	0
476704	473393	14053L	PARTICIPANT	\N	PRESENT	0
476705	473393	14215L	PARTICIPANT	\N	PRESENT	0
476706	473393	19415P	PARTICIPANT	\N	PRESENT	0
476707	473393	14235Q	PARTICIPANT	\N	PRESENT	0
476708	473393	11033F	PARTICIPANT	\N	PRESENT	0
476709	473393	19629C	PARTICIPANT	\N	PRESENT	0
476710	473393	08053X	PARTICIPANT	\N	PRESENT	0
476711	473393	08031R	PARTICIPANT	\N	PRESENT	0
476712	473393	19621T	PARTICIPANT	\N	PRESENT	0
476713	473393	14026U	PARTICIPANT	\N	PRESENT	0
476714	473393	14265W	PARTICIPANT	\N	PRESENT	0
476715	473393	19693L	PARTICIPANT	\N	PRESENT	0
476716	473393	14059S	PARTICIPANT	\N	PRESENT	0
476717	473393	08039A	PARTICIPANT	\N	PRESENT	0
476718	473393	14111D	PARTICIPANT	\N	PRESENT	0
476719	473393	14121F	PARTICIPANT	\N	PRESENT	0
476685	473393	01043Q	PARTICIPANT	\N	PRESENT	0
476686	473393	05008E	PARTICIPANT	\N	PRESENT	0
476720	473393	19599P	PARTICIPANT	\N	PRESENT	0
476721	473393	14069U	PARTICIPANT	\N	PRESENT	0
476722	473393	19573D	PARTICIPANT	\N	PRESENT	0
476723	473393	07029T	PARTICIPANT	\N	PRESENT	0
476724	473393	19741B	PARTICIPANT	\N	PRESENT	0
476728	475689	12041X	PARTICIPANT	\N	PRESENT	0
476729	475689	14133K	PARTICIPANT	\N	PRESENT	0
476730	475689	19709B	PARTICIPANT	\N	PRESENT	0
476731	475689	14267Y	PARTICIPANT	\N	PRESENT	0
476732	475689	01058X	PARTICIPANT	\N	PRESENT	0
476733	475689	08058D	PARTICIPANT	\N	PRESENT	0
476734	475689	04042C	PRESIDENT	0	PRESENT	0
476735	475689	08053X	PARTICIPANT	\N	PRESENT	0
476736	475689	11054L	PARTICIPANT	\N	PRESENT	0
476737	475689	14211G	PARTICIPANT	\N	PRESENT	0
476738	475689	98029W	PARTICIPANT	\N	PRESENT	0
476739	475689	19443T	PARTICIPANT	\N	PRESENT	0
476740	475689	04034C	PARTICIPANT	\N	PRESENT	0
476741	475689	16685X	PARTICIPANT	\N	PRESENT	0
476742	475689	11066Q	PARTICIPANT	\N	PRESENT	0
476743	475689	19421M	PARTICIPANT	\N	PRESENT	0
476744	475689	14193X	PARTICIPANT	\N	PRESENT	0
476745	475689	97011G	PARTICIPANT	\N	PRESENT	0
476746	475689	08061X	PARTICIPANT	\N	PRESENT	0
476747	475689	08047A	PARTICIPANT	\N	PRESENT	0
476748	475689	14097Y	PARTICIPANT	\N	PRESENT	0
476749	475689	95067Q	PARTICIPANT	\N	PRESENT	0
476750	475689	01062T	PARTICIPANT	\N	PRESENT	0
476751	475689	19251M	PARTICIPANT	\N	PRESENT	0
476752	475689	14028W	PARTICIPANT	\N	PRESENT	0
476753	475689	14105F	PARTICIPANT	\N	PRESENT	0
476754	475689	98018T	PARTICIPANT	\N	PRESENT	0
476755	475689	11064N	PARTICIPANT	\N	PRESENT	0
476756	475689	98050T	PARTICIPANT	\N	PRESENT	0
476757	475689	19583F	PARTICIPANT	\N	PRESENT	0
476758	475689	14255U	PARTICIPANT	\N	PRESENT	0
476759	474918	19768N	PARTICIPANT	\N	PRESENT	0
476760	474918	19515S	PARTICIPANT	\N	PRESENT	0
476761	474918	19782L	PARTICIPANT	\N	PRESENT	0
476762	474918	01043Q	PARTICIPANT	\N	PRESENT	0
476763	474918	14357A	PARTICIPANT	\N	PRESENT	0
476764	474918	19812Y	PARTICIPANT	\N	PRESENT	0
476765	474918	19413M	PARTICIPANT	\N	PRESENT	0
476766	474918	14081Q	PARTICIPANT	\N	PRESENT	0
476767	474918	80013X	PARTICIPANT	\N	PRESENT	0
476768	474918	19866P	PARTICIPANT	\N	PRESENT	0
476769	474918	19631V	PARTICIPANT	\N	PRESENT	0
476770	474918	11099A	PARTICIPANT	\N	PRESENT	0
476771	474918	08068F	PARTICIPANT	\N	PRESENT	0
476772	474918	04049K	PARTICIPANT	\N	PRESENT	0
476773	474918	19705W	PARTICIPANT	\N	PRESENT	0
476774	474918	08015R	PARTICIPANT	\N	PRESENT	0
476775	474918	14197C	PARTICIPANT	\N	PRESENT	0
476776	474918	19369B	PARTICIPANT	\N	PRESENT	0
476777	474918	08028W	PARTICIPANT	\N	PRESENT	0
476778	474918	19563B	PARTICIPANT	\N	PRESENT	0
476779	474918	14265W	PARTICIPANT	\N	PRESENT	0
476780	474918	19467C	PARTICIPANT	\N	PRESENT	0
454630	448747	19715Y	PARTICIPANT	\N	PRESENT	0
454631	448747	19565D	PARTICIPANT	\N	PRESENT	0
454633	448747	19301E	PARTICIPANT	\N	PRESENT	0
454634	448747	19593H	PARTICIPANT	\N	PRESENT	0
454635	448747	11072N	PARTICIPANT	\N	PRESENT	0
454636	448747	14121F	PARTICIPANT	\N	PRESENT	0
454637	448747	19629C	PARTICIPANT	\N	PRESENT	0
454638	448747	19717B	PARTICIPANT	\N	PRESENT	0
454639	448747	19553Y	PARTICIPANT	\N	PRESENT	0
454640	448747	98005N	PARTICIPANT	\N	PRESENT	0
454641	448747	11033F	PARTICIPANT	\N	PRESENT	0
454642	448747	19737F	PARTICIPANT	\N	PRESENT	0
454643	448747	14231L	PARTICIPANT	\N	PRESENT	0
454644	448747	19739H	PARTICIPANT	\N	PRESENT	0
454645	448747	19335Q	PARTICIPANT	\N	PRESENT	0
454646	448747	14179A	PARTICIPANT	\N	PRESENT	0
454647	448747	01024M	PARTICIPANT	\N	PRESENT	0
454648	448747	99004R	PARTICIPANT	\N	PRESENT	0
454649	448747	97011G	PARTICIPANT	\N	PRESENT	0
454650	448747	14147R	PARTICIPANT	\N	PRESENT	0
454651	448747	11109J	PARTICIPANT	\N	PRESENT	0
454652	448747	07033P	PARTICIPANT	\N	PRESENT	0
454653	448747	07029T	PARTICIPANT	\N	PRESENT	0
454654	448747	14259Y	PARTICIPANT	\N	PRESENT	0
454655	448747	14261S	PARTICIPANT	\N	PRESENT	0
454656	448747	11012A	PARTICIPANT	\N	PRESENT	0
454657	448747	19447X	PARTICIPANT	\N	PRESENT	0
454658	448747	14173T	PARTICIPANT	\N	PRESENT	0
454659	448747	14038Y	PARTICIPANT	\N	PRESENT	0
454660	448747	01028R	PARTICIPANT	\N	PRESENT	0
454661	448747	08056B	PARTICIPANT	\N	PRESENT	0
454662	448747	14157T	PARTICIPANT	\N	PRESENT	0
454663	448747	12016W	PARTICIPANT	\N	PRESENT	0
454664	454632	19515S	PARTICIPANT	\N	PRESENT	0
454665	454632	19782L	PARTICIPANT	\N	PRESENT	0
454666	454632	19413M	PARTICIPANT	\N	PRESENT	0
454667	454632	80013X	PARTICIPANT	\N	PRESENT	0
454668	454632	04049K	PARTICIPANT	\N	PRESENT	0
454669	454632	19705W	PARTICIPANT	\N	PRESENT	0
454670	454632	08015R	PARTICIPANT	\N	PRESENT	0
454671	454632	14197C	PARTICIPANT	\N	PRESENT	0
454672	454632	19369B	PARTICIPANT	\N	PRESENT	0
454673	454632	19511N	PARTICIPANT	\N	PRESENT	0
454674	454632	08028W	PARTICIPANT	\N	PRESENT	0
454675	454632	14135M	PARTICIPANT	\N	PRESENT	0
454676	454632	19467C	PARTICIPANT	\N	PRESENT	0
454677	454632	14187A	PARTICIPANT	\N	PRESENT	0
454678	454632	19695N	PARTICIPANT	\N	PRESENT	0
454679	454632	08062Y	PARTICIPANT	\N	PRESENT	0
454628	448747	11070L	PARTICIPANT	\N	PRESENT	0
454629	448747	14151M	PARTICIPANT	\N	PRESENT	0
454680	454632	11090Q	PRESIDENT	0	PRESENT	0
454681	454632	01025N	PARTICIPANT	\N	PRESENT	0
454682	454632	14033T	PARTICIPANT	\N	PRESENT	0
454683	454632	19269X	PARTICIPANT	\N	PRESENT	0
454684	454632	04088S	PARTICIPANT	\N	PRESENT	0
454685	454632	19747H	PARTICIPANT	\N	PRESENT	0
454686	454632	14207L	PARTICIPANT	\N	PRESENT	0
454687	454632	19619A	PARTICIPANT	\N	PRESENT	0
454688	454632	14257W	PARTICIPANT	\N	PRESENT	0
454689	454632	19768N	PARTICIPANT	\N	PRESENT	0
454690	454632	14081Q	PARTICIPANT	\N	PRESENT	0
454691	454632	08068F	PARTICIPANT	\N	PRESENT	0
454692	454632	14205J	PARTICIPANT	\N	PRESENT	0
454693	448747	19631V	PARTICIPANT	\N	PRESENT	0
454694	448747	14031R	PARTICIPANT	\N	PRESENT	0
454695	448747	19441R	PARTICIPANT	\N	PRESENT	0
454696	448747	14079W	PARTICIPANT	\N	PRESENT	0
454697	448747	14083S	PARTICIPANT	\N	PRESENT	0
454698	454632	11099A	PARTICIPANT	\N	PRESENT	0
454699	454632	19507S	PARTICIPANT	\N	PRESENT	0
454700	454632	11101A	PARTICIPANT	\N	PRESENT	0
454701	454632	14357A	PARTICIPANT	\N	EXCUSE	0
454702	454632	11081P	PARTICIPANT	\N	EXCUSE	0
454703	454632	19563B	PARTICIPANT	\N	EXCUSE	0
454704	454632	14265W	PARTICIPANT	\N	EXCUSE	0
454705	448747	11056N	PARTICIPANT	\N	PRESENT	0
454706	448747	19758L	PARTICIPANT	\N	PRESENT	0
454707	448747	87003B	PARTICIPANT	\N	PRESENT	0
454708	448747	01062T	PARTICIPANT	\N	PRESENT	0
454709	448747	89017R	PARTICIPANT	\N	PRESENT	0
454710	448747	19729F	PARTICIPANT	\N	PRESENT	0
454711	448747	14071N	PARTICIPANT	\N	PRESENT	0
454712	448747	14217N	PARTICIPANT	\N	PRESENT	0
454713	448747	19713W	PARTICIPANT	\N	PRESENT	0
454714	448747	08019V	PARTICIPANT	\N	PRESENT	0
454715	448747	19531S	PARTICIPANT	\N	PRESENT	0
454716	448747	19479G	PARTICIPANT	\N	PRESENT	0
454717	448747	04085P	PARTICIPANT	\N	PRESENT	0
454718	448747	14059S	PARTICIPANT	\N	PRESENT	0
454719	448747	14235Q	PARTICIPANT	\N	PRESENT	0
454720	448747	14195A	PARTICIPANT	\N	PRESENT	0
454722	454632	11056N	PARTICIPANT	\N	PRESENT	0
454735	448747	19251M	PARTICIPANT	\N	PRESENT	0
454738	448747	19798U	PARTICIPANT	\N	PRESENT	0
454741	448747	14133K	PARTICIPANT	\N	PRESENT	0
454742	448747	95030B	PARTICIPANT	\N	PRESENT	0
454794	448748	11033F	PARTICIPANT	\N	PRESENT	0
454795	448748	14133K	PARTICIPANT	\N	PRESENT	0
454796	448748	14179A	PARTICIPANT	\N	PRESENT	0
454797	448748	19713W	PARTICIPANT	\N	PRESENT	0
454798	448748	19479G	PARTICIPANT	\N	PRESENT	0
454799	448748	19737F	PARTICIPANT	\N	PRESENT	0
454800	448748	11012A	PARTICIPANT	\N	PRESENT	0
454801	448748	19794Q	PARTICIPANT	\N	PRESENT	0
454802	448748	18083K	PARTICIPANT	\N	PRESENT	0
454803	448748	19415P	PARTICIPANT	\N	PRESENT	0
454804	448748	14031R	PARTICIPANT	\N	PRESENT	0
454805	448748	14151M	PARTICIPANT	\N	PRESENT	0
454806	448748	19715Y	PARTICIPANT	\N	PRESENT	0
454807	448748	19565D	PARTICIPANT	\N	PRESENT	0
454808	448748	04085P	PARTICIPANT	\N	PRESENT	0
454809	448748	14195A	PARTICIPANT	\N	PRESENT	0
454810	448748	08056B	PARTICIPANT	\N	PRESENT	0
454811	448748	95030B	PARTICIPANT	\N	PRESENT	0
454812	448748	14105F	PARTICIPANT	\N	PRESENT	0
454813	448748	19399H	PARTICIPANT	\N	PRESENT	0
454814	448748	07029T	PARTICIPANT	\N	PRESENT	0
454815	448748	19760E	PARTICIPANT	\N	PRESENT	0
454816	448748	19758L	PARTICIPANT	\N	PRESENT	0
454817	448748	14235Q	PARTICIPANT	\N	PRESENT	0
454818	448748	01028R	PARTICIPANT	\N	PRESENT	0
454819	448748	95063L	PARTICIPANT	\N	PRESENT	0
454829	448748	01025N	PARTICIPANT	\N	PRESENT	0
454832	448748	19798U	PARTICIPANT	\N	PRESENT	0
454834	448748	19333N	PARTICIPANT	\N	PRESENT	0
454835	448748	19489J	PARTICIPANT	\N	PRESENT	0
454836	448748	19689Q	PARTICIPANT	\N	PRESENT	0
454837	448748	19251M	PARTICIPANT	\N	PRESENT	0
454838	448748	19503N	PARTICIPANT	\N	PRESENT	0
454839	448748	02002K	PARTICIPANT	\N	PRESENT	0
454840	448748	11067R	PARTICIPANT	\N	PRESENT	0
454841	448748	14079W	PARTICIPANT	\N	PRESENT	0
454842	448748	14217N	PARTICIPANT	\N	PRESENT	0
454843	448748	14147R	PARTICIPANT	\N	PRESENT	0
454844	448748	19447X	PARTICIPANT	\N	PRESENT	0
454845	448748	19553Y	PARTICIPANT	\N	PRESENT	0
454846	448748	14199E	PARTICIPANT	\N	PRESENT	0
454847	448748	14193X	PARTICIPANT	\N	PRESENT	0
454848	448748	14030Q	PARTICIPANT	\N	PRESENT	0
454849	448748	14021P	PARTICIPANT	\N	PRESENT	0
454850	448748	19521Q	PARTICIPANT	\N	PRESENT	0
454851	448748	19349W	PARTICIPANT	\N	PRESENT	0
454852	448748	08020N	PARTICIPANT	\N	PRESENT	0
454853	448748	19717B	PARTICIPANT	\N	PRESENT	0
454854	448748	14261S	PARTICIPANT	\N	PRESENT	0
454792	448748	11072N	PARTICIPANT	\N	PRESENT	0
454855	448748	14033T	PARTICIPANT	\N	PRESENT	0
454856	448748	19695N	PARTICIPANT	\N	PRESENT	0
454857	448748	11031D	PARTICIPANT	\N	PRESENT	0
454858	448748	11056N	PARTICIPANT	\N	PRESENT	0
454859	448748	19679N	PARTICIPANT	\N	PRESENT	0
454860	448748	11097X	PARTICIPANT	\N	PRESENT	0
454861	448748	14265W	PARTICIPANT	\N	PRESENT	0
458690	453247	14259Y	PARTICIPANT	\N	EXCUSE	0
462392	462391	05008E	PARTICIPANT	\N	PRESENT	0
462393	462391	08058D	PARTICIPANT	\N	PRESENT	0
462394	462391	04042C	PARTICIPANT	\N	PRESENT	0
463786	463755	19507S	PARTICIPANT	\N	PRESENT	0
463787	463755	14207L	PARTICIPANT	\N	PRESENT	0
463788	463755	04043D	PARTICIPANT	\N	PRESENT	0
463789	463755	19619A	PARTICIPANT	\N	PRESENT	0
463790	463755	14257W	PARTICIPANT	\N	PRESENT	0
463791	463755	19866P	PARTICIPANT	\N	EXCUSE	0
466654	466647	18003S	PARTICIPANT	\N	PRESENT	0
466655	466647	14093U	PARTICIPANT	\N	PRESENT	0
466657	466647	80013X	PARTICIPANT	\N	PRESENT	0
466658	466647	19693L	PARTICIPANT	\N	PRESENT	0
471840	468367	14030Q	PRESIDENT	0	PRESENT	0
471841	468367	08043V	PARTICIPANT	\N	EXCUSE	0
471842	468367	07029T	PARTICIPANT	\N	EXCUSE	0
471908	468367	80013X	PARTICIPANT	\N	PRESENT	0
471909	468367	19731Y	PARTICIPANT	\N	PRESENT	0
471910	468367	19701S	PARTICIPANT	\N	PRESENT	0
471911	468367	08031R	PARTICIPANT	\N	PRESENT	0
471913	468367	08020N	PARTICIPANT	\N	PRESENT	0
471914	468367	11031D	PARTICIPANT	\N	PRESENT	0
471915	468367	19693L	PARTICIPANT	\N	PRESENT	0
471916	468367	19715Y	PARTICIPANT	\N	PRESENT	0
471917	468367	08017T	PARTICIPANT	\N	PRESENT	0
471918	468367	11067R	PARTICIPANT	\N	PRESENT	0
471919	468367	14235Q	PARTICIPANT	\N	PRESENT	0
471920	468367	19749K	PARTICIPANT	\N	PRESENT	0
476026	476020	19711U	PARTICIPANT	\N	PRESENT	0
476027	476020	19399H	PARTICIPANT	\N	PRESENT	0
476028	476020	02002K	PARTICIPANT	\N	PRESENT	0
476029	476020	19251M	PARTICIPANT	\N	PRESENT	0
476030	476020	19533U	PARTICIPANT	\N	PRESENT	0
476031	476020	14147R	PARTICIPANT	\N	PRESENT	0
476032	476020	14030Q	PARTICIPANT	\N	PRESENT	0
476061	476059	19503N	PARTICIPANT	\N	PRESENT	0
476063	476052	08044W	PARTICIPANT	\N	PRESENT	0
476064	476052	14065Q	PARTICIPANT	\N	PRESENT	0
476066	476065	08044W	PARTICIPANT	\N	PRESENT	0
476067	476065	14065Q	PARTICIPANT	\N	PRESENT	0
476073	476072	08044W	PARTICIPANT	\N	PRESENT	0
476074	476072	14065Q	PARTICIPANT	\N	PRESENT	0
476076	476075	08044W	PARTICIPANT	\N	PRESENT	0
476077	476075	14065Q	PARTICIPANT	\N	PRESENT	0
476079	476078	08044W	PARTICIPANT	\N	PRESENT	0
476080	476078	14065Q	PARTICIPANT	\N	PRESENT	0
476081	476047	14071N	PARTICIPANT	\N	EXCUSE	0
476083	476082	08044W	PARTICIPANT	\N	PRESENT	0
476084	476082	14065Q	PARTICIPANT	\N	PRESENT	0
476086	476085	08044W	PARTICIPANT	\N	PRESENT	0
476087	476085	14065Q	PARTICIPANT	\N	PRESENT	0
476089	476088	14147R	PARTICIPANT	\N	PRESENT	0
476091	476090	08044W	PARTICIPANT	\N	PRESENT	0
476092	476090	14065Q	PARTICIPANT	\N	PRESENT	0
476095	476094	08044W	PARTICIPANT	\N	PRESENT	0
476096	476094	14065Q	PARTICIPANT	\N	PRESENT	0
476100	476097	08044W	PARTICIPANT	\N	PRESENT	0
476101	476097	14065Q	PARTICIPANT	\N	PRESENT	0
476103	476102	14187A	PARTICIPANT	\N	PRESENT	0
476104	476102	14081Q	PARTICIPANT	\N	PRESENT	0
476106	476105	14187A	PARTICIPANT	\N	PRESENT	0
476107	476105	14081Q	PARTICIPANT	\N	PRESENT	0
476109	476108	14187A	PARTICIPANT	\N	PRESENT	0
476110	476108	14081Q	PARTICIPANT	\N	PRESENT	0
476112	476111	14187A	PARTICIPANT	\N	PRESENT	0
476113	476111	14081Q	PARTICIPANT	\N	PRESENT	0
476116	476115	14187A	PARTICIPANT	\N	PRESENT	0
476117	476115	14081Q	PARTICIPANT	\N	PRESENT	0
476118	476115	11077T	PARTICIPANT	\N	PRESENT	0
476120	476119	14187A	PARTICIPANT	\N	PRESENT	0
476121	476119	14081Q	PARTICIPANT	\N	PRESENT	0
476123	476122	14187A	PARTICIPANT	\N	PRESENT	0
476124	476122	14081Q	PARTICIPANT	\N	PRESENT	0
476126	476125	14187A	PARTICIPANT	\N	PRESENT	0
476127	476125	14081Q	PARTICIPANT	\N	PRESENT	0
476129	476128	14187A	PARTICIPANT	\N	PRESENT	0
476130	476128	14081Q	PARTICIPANT	\N	PRESENT	0
476133	476131	14187A	PARTICIPANT	\N	PRESENT	0
476134	476131	14081Q	PARTICIPANT	\N	PRESENT	0
476136	476135	14187A	PARTICIPANT	\N	PRESENT	0
476137	476135	14081Q	PARTICIPANT	\N	PRESENT	0
476139	476138	14187A	PARTICIPANT	\N	PRESENT	0
476140	476138	11077T	PARTICIPANT	\N	PRESENT	0
476143	476141	14187A	PARTICIPANT	\N	PRESENT	0
476144	476141	14081Q	PARTICIPANT	\N	PRESENT	0
476145	476141	11077T	PARTICIPANT	\N	PRESENT	0
476147	476146	14187A	PARTICIPANT	\N	PRESENT	0
476148	476146	14081Q	PARTICIPANT	\N	PRESENT	0
476149	476146	11077T	PARTICIPANT	\N	PRESENT	0
476151	476150	08012N	PARTICIPANT	\N	PRESENT	0
476152	476150	11043H	PARTICIPANT	\N	PRESENT	0
476153	476150	14073Q	PARTICIPANT	\N	PRESENT	0
476154	476150	14241N	PARTICIPANT	\N	PRESENT	0
476155	476150	19643A	PARTICIPANT	\N	PRESENT	0
476158	476157	19515S	PARTICIPANT	\N	PRESENT	0
476159	476157	14357A	PARTICIPANT	\N	PRESENT	0
476160	476157	14329V	PARTICIPANT	\N	PRESENT	0
476161	476157	19695N	PARTICIPANT	\N	PRESENT	0
476162	476157	04049K	PARTICIPANT	\N	PRESENT	0
476166	476165	19369B	PARTICIPANT	\N	PRESENT	0
476168	476167	11103C	PARTICIPANT	\N	PRESENT	0
476169	476167	17589D	PARTICIPANT	\N	PRESENT	0
476170	476167	14331P	PARTICIPANT	\N	PRESENT	0
476171	476167	19723Y	PARTICIPANT	\N	PRESENT	0
476172	476167	08020N	PARTICIPANT	\N	PRESENT	0
476173	476167	14119M	PARTICIPANT	\N	PRESENT	0
476174	476167	95067Q	PARTICIPANT	\N	PRESENT	0
476175	476167	19812Y	PARTICIPANT	\N	PRESENT	0
476176	476167	19782L	PARTICIPANT	\N	PRESENT	0
476177	476167	14329V	PARTICIPANT	\N	PRESENT	0
476178	476167	14135M	PARTICIPANT	\N	PRESENT	0
476179	476167	14265W	PARTICIPANT	\N	PRESENT	0
476180	476167	08053X	PARTICIPANT	\N	PRESENT	0
476181	476167	19575F	PARTICIPANT	\N	PRESENT	0
476182	473501	14281W	PARTICIPANT	\N	PRESENT	0
476183	473501	19715Y	PARTICIPANT	\N	PRESENT	0
476184	473502	08052W	PARTICIPANT	\N	PRESENT	0
476185	473502	14281W	PARTICIPANT	\N	PRESENT	0
476186	473504	14195A	PARTICIPANT	\N	PRESENT	0
476187	473504	14281W	PARTICIPANT	\N	PRESENT	0
476192	476191	96004D	PARTICIPANT	\N	PRESENT	0
476193	476191	14331P	PARTICIPANT	\N	PRESENT	0
476195	476194	19545Y	PARTICIPANT	\N	PRESENT	0
476196	476194	19689Q	PARTICIPANT	\N	PRESENT	0
476534	476197	96004D	PARTICIPANT	\N	EXCUSE	0
476536	476535	11053K	PARTICIPANT	\N	PRESENT	0
476537	476535	14159V	PARTICIPANT	\N	PRESENT	0
476538	476535	05012A	PARTICIPANT	\N	PRESENT	0
476573	475640	19741B	PARTICIPANT	\N	PRESENT	0
476574	475640	11040E	PARTICIPANT	\N	PRESENT	0
476575	475640	80013X	PARTICIPANT	\N	PRESENT	0
476576	475640	19525U	PARTICIPANT	\N	PRESENT	0
476577	475640	11070L	PARTICIPANT	\N	PRESENT	0
476578	475640	19551W	PARTICIPANT	\N	PRESENT	0
476579	475640	14121F	PRESIDENT	0	PRESENT	0
476580	475640	19531S	PARTICIPANT	\N	PRESENT	0
476581	475640	19711U	PARTICIPANT	\N	PRESENT	0
476582	475640	08034U	PARTICIPANT	\N	PRESENT	0
476583	475640	14169X	PARTICIPANT	\N	PRESENT	0
476584	475640	19737F	PARTICIPANT	\N	PRESENT	0
476585	475640	87003B	PARTICIPANT	\N	EXCUSE	0
476620	476163	19667J	PRESIDENT	0	PRESENT	0
476621	476163	19415P	PARTICIPANT	\N	PRESENT	0
476622	476163	11056N	PARTICIPANT	\N	PRESENT	0
476623	476163	19349W	PARTICIPANT	\N	PRESENT	0
476624	476163	04045F	PARTICIPANT	\N	PRESENT	0
476625	476163	14327T	PARTICIPANT	\N	PRESENT	0
476626	476163	19387D	PARTICIPANT	\N	PRESENT	0
476627	476163	14213J	PARTICIPANT	\N	PRESENT	0
476628	476163	19820Y	PARTICIPANT	\N	PRESENT	0
476629	476163	10015M	PARTICIPANT	\N	PRESENT	0
476630	476163	14001X	PARTICIPANT	\N	PRESENT	0
476631	476163	19441R	PARTICIPANT	\N	PRESENT	0
476640	476163	19563B	PARTICIPANT	\N	EXCUSE	0
476641	476163	19621T	PARTICIPANT	\N	EXCUSE	0
476793	476792	19820Y	PARTICIPANT	\N	PRESENT	0
476794	476792	19599P	PARTICIPANT	\N	PRESENT	0
476795	476792	19333N	PARTICIPANT	\N	PRESENT	0
476796	476792	19701S	PARTICIPANT	\N	PRESENT	0
476797	476792	04097T	PARTICIPANT	\N	PRESENT	0
476799	476792	15447F	PARTICIPANT	\N	PRESENT	0
476800	476792	14157T	PARTICIPANT	\N	PRESENT	0
476801	476792	19794Q	PARTICIPANT	\N	PRESENT	0
476802	476792	14237S	PARTICIPANT	\N	PRESENT	0
476806	476792	08009T	PRESIDENT	0	PRESENT	0
476807	476792	19347U	PARTICIPANT	\N	PRESENT	0
476808	476792	14093U	PARTICIPANT	\N	PRESENT	0
476809	476792	19826F	PARTICIPANT	\N	PRESENT	0
476810	475783	19467C	PARTICIPANT	\N	PRESENT	0
476824	476792	14219Q	PARTICIPANT	\N	PRESENT	0
476825	476792	19503N	PARTICIPANT	\N	PRESENT	0
476826	476792	14051J	PARTICIPANT	\N	PRESENT	0
476828	476792	19713W	PARTICIPANT	\N	PRESENT	0
476829	476792	19737F	PARTICIPANT	\N	PRESENT	0
476830	476792	11065P	PARTICIPANT	\N	PRESENT	0
476831	476792	18083K	PARTICIPANT	\N	PRESENT	0
476832	476792	19549D	PARTICIPANT	\N	PRESENT	0
456339	456327	11101A	PARTICIPANT	\N	PRESENT	0
456340	456327	14205J	PARTICIPANT	\N	PRESENT	0
456341	456327	14059S	PARTICIPANT	\N	PRESENT	0
456342	456327	19479G	PARTICIPANT	\N	PRESENT	0
456343	456327	14073Q	PARTICIPANT	\N	PRESENT	0
456344	456327	14219Q	PARTICIPANT	\N	PRESENT	0
456345	456327	14265W	PARTICIPANT	\N	PRESENT	0
456346	456327	19631V	PARTICIPANT	\N	PRESENT	0
456347	456327	19711U	PARTICIPANT	\N	PRESENT	0
456348	456327	19333N	PARTICIPANT	\N	PRESENT	0
456352	456327	11056N	PARTICIPANT	\N	PRESENT	0
456350	456327	19521Q	PARTICIPANT	\N	PRESENT	0
456351	456327	95063L	PARTICIPANT	\N	PRESENT	0
456356	456355	11056N	PARTICIPANT	\N	PRESENT	0
456357	456355	19479G	PARTICIPANT	\N	PRESENT	0
456358	456355	14219Q	PARTICIPANT	\N	PRESENT	0
456359	456355	14265W	PARTICIPANT	\N	PRESENT	0
456360	456355	14213J	PARTICIPANT	\N	PRESENT	0
456361	456355	19521Q	PARTICIPANT	\N	PRESENT	0
456362	456355	19711U	PARTICIPANT	\N	PRESENT	0
456378	456367	19631V	PARTICIPANT	\N	PRESENT	0
456379	456367	19333N	PARTICIPANT	\N	PRESENT	0
456380	456367	19253P	PARTICIPANT	\N	PRESENT	0
456381	456367	19521Q	PARTICIPANT	\N	PRESENT	0
456382	456367	11101A	PARTICIPANT	\N	PRESENT	0
456383	456367	14205J	PARTICIPANT	\N	PRESENT	0
456384	456367	14059S	PARTICIPANT	\N	PRESENT	0
456385	456367	14073Q	PARTICIPANT	\N	PRESENT	0
456386	456367	19479G	PARTICIPANT	\N	PRESENT	0
456387	456367	19711U	PARTICIPANT	\N	PRESENT	0
456388	456367	14213J	PARTICIPANT	\N	PRESENT	0
456389	456367	11056N	PARTICIPANT	\N	PRESENT	0
456392	456391	11056N	PARTICIPANT	\N	PRESENT	0
456393	456391	14073Q	PARTICIPANT	\N	PRESENT	0
456394	456391	19479G	PARTICIPANT	\N	PRESENT	0
456395	456391	14219Q	PARTICIPANT	\N	PRESENT	0
456396	456391	14265W	PARTICIPANT	\N	PRESENT	0
456397	456391	14213J	PARTICIPANT	\N	PRESENT	0
456398	456391	19711U	PARTICIPANT	\N	PRESENT	0
456399	456391	19521Q	PARTICIPANT	\N	PRESENT	0
456612	456200	19737F	PARTICIPANT	\N	PRESENT	0
456613	456200	99004R	PARTICIPANT	\N	PRESENT	0
456614	456200	19711U	PARTICIPANT	\N	EXCUSE	0
456634	456200	11097X	PARTICIPANT	\N	PRESENT	0
456967	456966	14073Q	PARTICIPANT	\N	PRESENT	0
460130	460103	10015M	PARTICIPANT	\N	PRESENT	0
460117	460103	08010L	PARTICIPANT	\N	EXCUSE	0
460118	460103	19421M	PARTICIPANT	\N	EXCUSE	0
460119	460103	08053X	PARTICIPANT	\N	PRESENT	0
460333	460332	19719D	PRESIDENT	0	PRESENT	0
460121	460103	19719D	PRESIDENT	\N	PRESENT	0
460122	460103	19673G	PARTICIPANT	\N	PRESENT	0
460123	460103	19585H	PARTICIPANT	\N	PRESENT	0
460334	460332	19673G	PARTICIPANT	\N	PRESENT	0
460125	460103	19671E	PARTICIPANT	\N	PRESENT	0
460126	460103	04044E	PARTICIPANT	\N	PRESENT	0
460127	460103	07004J	PARTICIPANT	\N	PRESENT	0
460128	460103	08056B	PARTICIPANT	\N	PRESENT	0
460335	460332	07004J	PRESIDENT	1	PRESENT	0
460336	460332	08056B	PARTICIPANT	\N	PRESENT	0
460337	460332	08010L	PARTICIPANT	\N	PRESENT	0
460338	460332	08053X	PARTICIPANT	\N	PRESENT	0
460339	460332	19671E	PARTICIPANT	\N	PRESENT	0
460340	460332	10015M	PARTICIPANT	\N	PRESENT	0
460341	460332	04044E	PARTICIPANT	\N	PRESENT	0
460342	460332	19585H	PARTICIPANT	\N	EXCUSE	0
460343	460332	19421M	PARTICIPANT	\N	EXCUSE	0
461296	459124	04049K	PARTICIPANT	\N	PRESENT	0
461297	459124	04043D	PARTICIPANT	\N	PRESENT	0
462237	459208	14085U	PARTICIPANT	\N	PRESENT	0
462238	459208	01057W	PARTICIPANT	\N	PRESENT	0
462239	459208	11048N	PARTICIPANT	\N	PRESENT	0
462240	459208	14327T	PARTICIPANT	\N	PRESENT	0
462253	462252	14085U	PARTICIPANT	\N	PRESENT	0
462254	462252	14253S	PARTICIPANT	\N	PRESENT	0
462282	462278	19479G	PARTICIPANT	\N	PRESENT	0
462286	459223	11070L	PARTICIPANT	\N	PRESENT	0
462287	459223	19525U	PARTICIPANT	\N	PRESENT	0
462288	459223	80013X	PARTICIPANT	\N	PRESENT	0
462289	459223	19737F	PARTICIPANT	\N	PRESENT	0
466875	466874	19643A	PARTICIPANT	\N	PRESENT	0
466876	466874	14249W	PARTICIPANT	\N	PRESENT	0
466877	466874	14241N	PARTICIPANT	\N	PRESENT	0
466878	466874	14073Q	PARTICIPANT	\N	PRESENT	0
466879	466874	08012N	PARTICIPANT	\N	PRESENT	0
466880	466874	11043H	PARTICIPANT	\N	PRESENT	0
468584	468583	19521Q	PARTICIPANT	\N	PRESENT	0
468585	468583	14087W	PARTICIPANT	\N	PRESENT	0
468586	468583	19679N	PARTICIPANT	\N	PRESENT	0
468589	468588	14087W	PARTICIPANT	\N	PRESENT	0
468590	468588	19521Q	PARTICIPANT	\N	PRESENT	0
468591	468588	19679N	PARTICIPANT	\N	PRESENT	0
468592	468588	11067R	PARTICIPANT	\N	PRESENT	0
468615	467534	14021P	PARTICIPANT	\N	PRESENT	0
468629	468628	08043V	PARTICIPANT	\N	PRESENT	0
468630	468628	19399H	PARTICIPANT	\N	PRESENT	0
468631	468628	08031R	PARTICIPANT	\N	PRESENT	0
468632	468628	14059S	PARTICIPANT	\N	PRESENT	0
468633	468628	14229S	PARTICIPANT	\N	PRESENT	0
468635	468634	11109J	PARTICIPANT	\N	PRESENT	0
468636	468634	19301E	PARTICIPANT	\N	PRESENT	0
468637	468634	08019V	PRESIDENT	0	PRESENT	0
468638	468634	19577H	PARTICIPANT	\N	PRESENT	0
468639	468634	19691J	PARTICIPANT	\N	PRESENT	0
468640	468634	11054L	PARTICIPANT	\N	EXCUSE	0
468641	468634	14331P	PARTICIPANT	\N	EXCUSE	0
468642	468634	11010L	PARTICIPANT	\N	EXCUSE	0
468644	468643	04049K	PRESIDENT	0	PRESENT	0
468645	468643	14030Q	PARTICIPANT	\N	PRESENT	0
468646	468643	14087W	PARTICIPANT	\N	PRESENT	0
468647	468643	14041T	PARTICIPANT	\N	PRESENT	0
468648	468643	14329V	PARTICIPANT	\N	PRESENT	0
468649	468643	19671E	PARTICIPANT	\N	PRESENT	0
468650	468643	14255U	PARTICIPANT	\N	PRESENT	0
468651	468643	19575F	PARTICIPANT	\N	PRESENT	0
468652	468643	14105F	PARTICIPANT	\N	PRESENT	0
468653	468643	04088S	PARTICIPANT	\N	PRESENT	0
468654	468643	08047A	PARTICIPANT	\N	EXCUSE	0
468655	468643	08060W	PARTICIPANT	\N	EXCUSE	0
468658	468656	19503N	PARTICIPANT	\N	PRESENT	0
469134	468972	14135M	PARTICIPANT	\N	EXCUSE	0
469135	468972	14331P	PARTICIPANT	\N	EXCUSE	0
469136	468972	12016W	PARTICIPANT	\N	EXCUSE	0
469176	468601	19415P	PARTICIPANT	\N	PRESENT	0
469178	468602	19415P	PARTICIPANT	\N	PRESENT	0
469179	468603	19415P	PARTICIPANT	\N	PRESENT	0
469180	468538	14042U	PARTICIPANT	\N	PRESENT	0
469181	468538	11067R	PARTICIPANT	\N	PRESENT	0
469182	468538	19679N	PARTICIPANT	\N	PRESENT	0
469183	468538	14227Q	PARTICIPANT	\N	PRESENT	0
469184	468605	19415P	PARTICIPANT	\N	PRESENT	0
469185	468605	14217N	PARTICIPANT	\N	PRESENT	0
469187	468605	14281W	PARTICIPANT	\N	PRESENT	0
469189	468605	11067R	PARTICIPANT	\N	PRESENT	0
469190	468605	19798U	PARTICIPANT	\N	PRESENT	0
469191	468554	14119M	PARTICIPANT	\N	PRESENT	0
469192	468554	19798U	PARTICIPANT	\N	PRESENT	0
469193	468587	19683J	PARTICIPANT	\N	PRESENT	0
469194	468587	14119M	PARTICIPANT	\N	PRESENT	0
469197	468587	19798U	PARTICIPANT	\N	PRESENT	0
469211	468593	19565D	PARTICIPANT	\N	PRESENT	0
469214	468593	14119M	PARTICIPANT	\N	PRESENT	0
469220	468598	14119M	PARTICIPANT	\N	PRESENT	0
469229	468599	19415P	PARTICIPANT	\N	PRESENT	0
469230	468599	19723Y	PARTICIPANT	\N	PRESENT	0
469231	468599	14119M	PARTICIPANT	\N	PRESENT	0
469232	468599	11067R	PARTICIPANT	\N	PRESENT	0
469234	468599	14227Q	PARTICIPANT	\N	PRESENT	0
469235	468599	19798U	PARTICIPANT	\N	PRESENT	0
469239	468600	08052W	PARTICIPANT	\N	PRESENT	0
469240	468600	19697Q	PARTICIPANT	\N	PRESENT	0
469241	468600	14119M	PARTICIPANT	\N	PRESENT	0
469248	468606	19415P	PARTICIPANT	\N	PRESENT	0
469250	468606	19657G	PARTICIPANT	\N	PRESENT	0
469251	468606	11067R	PARTICIPANT	\N	PRESENT	0
469253	468606	19679N	PARTICIPANT	\N	PRESENT	0
469262	468607	19415P	PARTICIPANT	\N	PRESENT	0
476781	474918	14187A	PARTICIPANT	\N	PRESENT	0
476782	474918	19695N	PARTICIPANT	\N	PRESENT	0
476783	474918	11090Q	PRESIDENT	0	PRESENT	0
476784	474918	01025N	PARTICIPANT	\N	PRESENT	0
476785	474918	19295A	PARTICIPANT	\N	PRESENT	0
476786	474918	11056N	PARTICIPANT	\N	PRESENT	0
476787	474918	11101A	PARTICIPANT	\N	PRESENT	0
476788	474918	19747H	PARTICIPANT	\N	PRESENT	0
476789	474918	14207L	PARTICIPANT	\N	PRESENT	0
476790	474918	14257W	PARTICIPANT	\N	PRESENT	0
476791	474918	14135M	PARTICIPANT	\N	PRESENT	0
476803	474918	04045F	PARTICIPANT	\N	PRESENT	0
476804	474918	14205J	PARTICIPANT	\N	PRESENT	0
476805	474918	14115H	PARTICIPANT	\N	PRESENT	0
476811	475689	11027H	PARTICIPANT	\N	PRESENT	0
476812	475689	98022P	PARTICIPANT	\N	EXCUSE	0
476813	475689	08049C	PARTICIPANT	\N	EXCUSE	0
476814	475689	11041F	PARTICIPANT	\N	PRESENT	0
476873	476188	11070L	PARTICIPANT	\N	PRESENT	0
476874	476142	19527W	PARTICIPANT	\N	PRESENT	0
476875	476142	19697Q	PARTICIPANT	\N	PRESENT	0
476876	476142	11067R	PARTICIPANT	\N	PRESENT	0
476877	476142	04092N	PRESIDENT	0	PRESENT	0
476878	476142	11097X	PARTICIPANT	\N	PRESENT	0
476879	476142	08052W	PARTICIPANT	\N	PRESENT	0
476880	476142	19691J	PARTICIPANT	\N	PRESENT	0
476881	476142	14026U	PARTICIPANT	\N	PRESENT	0
476882	476142	19679N	PARTICIPANT	\N	PRESENT	0
476883	476142	14042U	PARTICIPANT	\N	PRESENT	0
476884	476142	14071N	PARTICIPANT	\N	PRESENT	0
476885	476142	19683J	PARTICIPANT	\N	PRESENT	0
476886	476142	19760E	PARTICIPANT	\N	PRESENT	0
476887	476142	98024R	PARTICIPANT	\N	PRESENT	0
476888	476188	14331P	PARTICIPANT	\N	PRESENT	0
476889	476188	01048V	PARTICIPANT	\N	PRESENT	0
476890	476188	01057W	PARTICIPANT	\N	PRESENT	0
476891	476188	11053K	PARTICIPANT	\N	PRESENT	0
476892	476188	19667J	PARTICIPANT	\N	PRESENT	0
476893	476188	14225N	PARTICIPANT	\N	PRESENT	0
476894	476188	88008L	PARTICIPANT	\N	PRESENT	0
476895	476188	07029T	PARTICIPANT	\N	PRESENT	0
476896	476188	07004J	PARTICIPANT	\N	PRESENT	0
476897	476188	11048N	PARTICIPANT	\N	PRESENT	0
476898	476188	19479G	PARTICIPANT	\N	PRESENT	0
476899	476188	19651A	PARTICIPANT	\N	PRESENT	0
476900	476188	08011M	PARTICIPANT	\N	EXCUSE	0
476901	476188	11040E	PARTICIPANT	\N	PRESENT	0
476902	476188	14083S	PARTICIPANT	\N	PRESENT	0
476903	476188	14121F	PARTICIPANT	\N	PRESENT	0
476905	476188	14073Q	PARTICIPANT	\N	PRESENT	0
476906	474918	19441R	PARTICIPANT	\N	PRESENT	0
476911	476907	14031R	PARTICIPANT	\N	PRESENT	0
476912	476907	19549D	PARTICIPANT	\N	PRESENT	0
476913	476907	19701S	PARTICIPANT	\N	PRESENT	0
476914	476907	19503N	PARTICIPANT	\N	PRESENT	0
476915	476907	19745F	PARTICIPANT	\N	PRESENT	0
476916	476907	19794Q	PARTICIPANT	\N	PRESENT	0
476917	476907	19347U	PARTICIPANT	\N	PRESENT	0
476918	476907	19637C	PARTICIPANT	\N	PRESENT	0
476919	476907	19820Y	PARTICIPANT	\N	PRESENT	0
476920	476907	19333N	PARTICIPANT	\N	PRESENT	0
476922	476907	19387D	PARTICIPANT	\N	PRESENT	0
476923	476907	04069P	PARTICIPANT	\N	PRESENT	0
476924	476908	14031R	PARTICIPANT	\N	PRESENT	0
476925	476908	19549D	PARTICIPANT	\N	PRESENT	0
476926	476908	19701S	PARTICIPANT	\N	PRESENT	0
476927	476908	19387D	PARTICIPANT	\N	PRESENT	0
476928	476908	04069P	PARTICIPANT	\N	PRESENT	0
476929	476908	19745F	PARTICIPANT	\N	PRESENT	0
476931	476908	19794Q	PARTICIPANT	\N	PRESENT	0
476932	476908	19637C	PARTICIPANT	\N	PRESENT	0
476933	476908	19347U	PARTICIPANT	\N	PRESENT	0
476934	476908	19820Y	PARTICIPANT	\N	PRESENT	0
476935	476908	19739H	PARTICIPANT	\N	PRESENT	0
476936	476909	18083K	PARTICIPANT	\N	PRESENT	0
476937	476909	19739H	PARTICIPANT	\N	PRESENT	0
476938	476909	19637C	PARTICIPANT	\N	PRESENT	0
476939	476909	19713W	PARTICIPANT	\N	PRESENT	0
476940	476909	19794Q	PARTICIPANT	\N	PRESENT	0
476941	476909	08024S	PARTICIPANT	\N	PRESENT	0
476942	476909	17583W	PARTICIPANT	\N	PRESENT	0
476943	476909	19737F	PARTICIPANT	\N	PRESENT	0
476944	476909	19387D	PARTICIPANT	\N	PRESENT	0
476945	476909	14169X	PARTICIPANT	\N	PRESENT	0
476951	476356	19649G	PARTICIPANT	\N	PRESENT	0
476952	476356	14231L	PARTICIPANT	\N	PRESENT	0
476954	476188	19531S	PARTICIPANT	\N	PRESENT	0
476983	473394	86034E	PARTICIPANT	\N	PRESENT	0
476986	473394	98029W	PARTICIPANT	\N	PRESENT	0
476987	473394	08052W	PARTICIPANT	\N	PRESENT	0
476989	473394	19675J	PARTICIPANT	\N	PRESENT	0
476990	473394	14357A	PARTICIPANT	\N	PRESENT	0
476991	473394	14211G	PARTICIPANT	\N	PRESENT	0
476992	473394	11067R	PARTICIPANT	\N	PRESENT	0
476994	473394	19511N	PARTICIPANT	\N	PRESENT	0
476998	473394	14030Q	PARTICIPANT	\N	PRESENT	0
476999	473394	99004R	PARTICIPANT	\N	PRESENT	0
477000	473394	04018C	PARTICIPANT	\N	PRESENT	0
477001	473394	19820Y	PARTICIPANT	\N	PRESENT	0
477002	473394	08061X	PARTICIPANT	\N	PRESENT	0
477003	473394	04008A	PARTICIPANT	\N	PRESENT	0
477004	473394	15447F	PARTICIPANT	\N	PRESENT	0
477005	473394	19619A	PARTICIPANT	\N	PRESENT	0
477006	473394	95030B	PARTICIPANT	\N	PRESENT	0
477007	473394	14265W	PARTICIPANT	\N	PRESENT	0
477008	473394	14111D	PARTICIPANT	\N	PRESENT	0
477009	473394	08034U	PARTICIPANT	\N	PRESENT	0
477010	473394	14059S	PARTICIPANT	\N	PRESENT	0
477011	473394	19711U	PARTICIPANT	\N	PRESENT	0
477012	473394	19447X	PARTICIPANT	\N	PRESENT	0
477013	473394	14157T	PARTICIPANT	\N	PRESENT	0
477014	473394	14063N	PARTICIPANT	\N	PRESENT	0
477015	473394	19723Y	PARTICIPANT	\N	PRESENT	0
477016	473394	04033B	PARTICIPANT	\N	PRESENT	0
477017	473394	19691J	PARTICIPANT	\N	PRESENT	0
477018	473394	19766L	PARTICIPANT	\N	PRESENT	0
477019	473394	18083K	PARTICIPANT	\N	PRESENT	0
477020	473394	05012A	PARTICIPANT	\N	PRESENT	0
477021	473394	04085P	PARTICIPANT	\N	PRESENT	0
477022	473394	11097X	PARTICIPANT	\N	PRESENT	0
477023	473394	11012A	PARTICIPANT	\N	PRESENT	0
477025	473394	19697Q	PARTICIPANT	\N	PRESENT	0
477026	473394	14085U	PARTICIPANT	\N	PRESENT	0
477027	473394	19695N	PARTICIPANT	\N	PRESENT	0
477028	473394	08069G	PARTICIPANT	\N	PRESENT	0
477029	473394	19415P	PARTICIPANT	\N	PRESENT	0
477030	473394	19739H	PARTICIPANT	\N	PRESENT	0
477031	473394	04086Q	PARTICIPANT	\N	PRESENT	0
477032	473394	14069U	PARTICIPANT	\N	PRESENT	0
477034	473394	04059M	PARTICIPANT	\N	PRESENT	0
477035	473394	19565D	PARTICIPANT	\N	PRESENT	0
477036	473394	08039A	PARTICIPANT	\N	PRESENT	0
477037	473394	14235Q	PARTICIPANT	\N	PRESENT	0
477038	473394	19760E	PARTICIPANT	\N	PRESENT	0
477039	473394	11074Q	PARTICIPANT	\N	PRESENT	0
477040	473394	19413M	PARTICIPANT	\N	PRESENT	0
477041	473394	08053X	PARTICIPANT	\N	PRESENT	0
477042	473394	19527W	PARTICIPANT	\N	PRESENT	0
477043	473394	17779H	PARTICIPANT	\N	PRESENT	0
477044	473394	19563B	PARTICIPANT	\N	PRESENT	0
477045	473394	04057K	PARTICIPANT	\N	PRESENT	0
477046	473394	14251Q	PARTICIPANT	\N	PRESENT	0
477047	473394	14217N	PARTICIPANT	\N	PRESENT	0
477048	473394	14021P	PARTICIPANT	\N	PRESENT	0
477049	473394	19333N	PARTICIPANT	\N	PRESENT	0
477050	473394	07029T	PARTICIPANT	\N	PRESENT	0
477051	473394	19599P	PARTICIPANT	\N	PRESENT	0
477052	473394	14115H	PARTICIPANT	\N	PRESENT	0
477053	473394	14026U	PARTICIPANT	\N	PRESENT	0
477054	473394	11083R	PARTICIPANT	\N	PRESENT	0
477055	473394	19782L	PARTICIPANT	\N	PRESENT	0
477056	473394	14151M	PARTICIPANT	\N	PRESENT	0
477057	473394	08010L	PARTICIPANT	\N	PRESENT	0
477058	473394	11053K	PARTICIPANT	\N	PRESENT	0
477059	473394	14135M	PARTICIPANT	\N	PRESENT	0
477060	473394	95037J	PARTICIPANT	\N	PRESENT	0
477061	473394	04044E	PARTICIPANT	\N	PRESENT	0
477062	473394	04070G	PARTICIPANT	\N	PRESENT	0
477063	473394	89017R	PARTICIPANT	\N	PRESENT	0
477064	473394	14123H	PARTICIPANT	\N	PRESENT	0
477065	473394	04042C	PARTICIPANT	\N	PRESENT	0
477066	473394	14187A	PARTICIPANT	\N	PRESENT	0
477067	473394	19826F	PARTICIPANT	\N	PRESENT	0
477068	473394	19747H	PARTICIPANT	\N	PRESENT	0
477069	473394	19685L	PARTICIPANT	\N	PRESENT	0
477070	473394	14331P	PARTICIPANT	\N	PRESENT	0
477071	473394	19629C	PARTICIPANT	\N	PRESENT	0
455301	454260	19675J	PARTICIPANT	\N	EXCUSE	0
455370	454258	19675J	PARTICIPANT	\N	EXCUSE	0
456809	456743	19575F	PARTICIPANT	\N	PRESENT	0
456810	456743	19621T	PARTICIPANT	\N	PRESENT	0
456807	456743	14219Q	PARTICIPANT	\N	PRESENT	0
456808	456743	14213J	PARTICIPANT	\N	PRESENT	0
456811	456743	19479G	PARTICIPANT	\N	PRESENT	0
456812	456743	14205J	PARTICIPANT	\N	PRESENT	0
456813	456743	19703U	PARTICIPANT	\N	PRESENT	0
456814	456743	19333N	PARTICIPANT	\N	PRESENT	0
456815	456743	14059S	PARTICIPANT	\N	PRESENT	0
456816	456743	19521Q	PARTICIPANT	\N	PRESENT	0
456817	456743	19711U	PARTICIPANT	\N	PRESENT	0
456818	456745	14219Q	PARTICIPANT	\N	PRESENT	0
456819	456745	14059S	PARTICIPANT	\N	PRESENT	0
456820	456745	19521Q	PARTICIPANT	\N	PRESENT	0
456821	456745	19711U	PARTICIPANT	\N	PRESENT	0
456822	456745	14213J	PARTICIPANT	\N	PRESENT	0
456823	456745	19575F	PARTICIPANT	\N	PRESENT	0
456824	456745	19621T	PARTICIPANT	\N	PRESENT	0
456825	456745	19479G	PARTICIPANT	\N	PRESENT	0
456826	456745	14205J	PARTICIPANT	\N	PRESENT	0
456827	456745	19703U	PARTICIPANT	\N	PRESENT	0
456828	456745	19333N	PARTICIPANT	\N	PRESENT	0
456830	456200	14107H	PARTICIPANT	\N	EXCUSE	0
456831	456200	19349W	PARTICIPANT	\N	EXCUSE	0
456832	456200	01028R	PARTICIPANT	\N	EXCUSE	0
456833	456200	19713W	PARTICIPANT	\N	EXCUSE	0
456834	456200	08012N	PARTICIPANT	\N	EXCUSE	0
456835	456200	19479G	PARTICIPANT	\N	EXCUSE	0
456836	456200	19515S	PARTICIPANT	\N	EXCUSE	0
456837	456200	02002K	PARTICIPANT	\N	EXCUSE	0
456838	456200	19369B	PARTICIPANT	\N	EXCUSE	0
456839	456200	08048B	PARTICIPANT	\N	EXCUSE	0
456840	456200	19551W	PARTICIPANT	\N	EXCUSE	0
456841	456200	19667J	PARTICIPANT	\N	EXCUSE	0
456842	456200	08062Y	PARTICIPANT	\N	EXCUSE	0
456843	456200	11066Q	PARTICIPANT	\N	EXCUSE	0
456888	456200	19467C	PARTICIPANT	\N	EXCUSE	0
457033	456200	89017R	PARTICIPANT	\N	EXCUSE	0
459075	456727	14197C	PARTICIPANT	\N	PRESENT	0
459076	456727	11048N	PARTICIPANT	\N	PRESENT	0
459077	456727	19527W	PARTICIPANT	\N	PRESENT	0
461746	461745	04049K	PARTICIPANT	\N	PRESENT	0
461747	461745	16685X	PARTICIPANT	\N	PRESENT	0
461749	461748	04049K	PARTICIPANT	\N	PRESENT	0
461750	461748	16685X	PARTICIPANT	\N	PRESENT	0
461752	461751	04049K	PARTICIPANT	\N	PRESENT	0
461754	461753	04049K	PARTICIPANT	\N	PRESENT	0
461758	461757	04049K	PARTICIPANT	\N	PRESENT	0
461760	461759	04049K	PARTICIPANT	\N	PRESENT	0
461762	461761	04049K	PARTICIPANT	\N	PRESENT	0
461763	461761	19575F	PARTICIPANT	\N	PRESENT	0
461764	461761	14083S	PARTICIPANT	\N	PRESENT	0
461765	461761	19521Q	PARTICIPANT	\N	PRESENT	0
461766	461761	16685X	PARTICIPANT	\N	PRESENT	0
461767	461761	14026U	PARTICIPANT	\N	PRESENT	0
461771	461770	04049K	PARTICIPANT	\N	PRESENT	0
461772	461770	19575F	PARTICIPANT	\N	PRESENT	0
461773	461770	14083S	PARTICIPANT	\N	PRESENT	0
461774	461770	19521Q	PARTICIPANT	\N	PRESENT	0
461775	461770	14061L	PARTICIPANT	\N	PRESENT	0
461776	461770	14026U	PARTICIPANT	\N	PRESENT	0
461778	461777	14083S	PARTICIPANT	\N	PRESENT	0
461791	461790	14083S	PARTICIPANT	\N	PRESENT	0
461793	461792	14083S	PARTICIPANT	\N	PRESENT	0
461795	461794	04049K	PRESIDENT	0	PRESENT	0
461796	461794	16685X	PARTICIPANT	\N	PRESENT	0
461797	461794	14105F	PARTICIPANT	\N	PRESENT	0
461798	461794	19575F	PARTICIPANT	\N	PRESENT	0
461799	461794	08015R	PARTICIPANT	\N	PRESENT	0
461800	461794	14026U	PARTICIPANT	\N	PRESENT	0
461801	461794	14083S	PARTICIPANT	\N	PRESENT	0
461802	461794	08068F	PARTICIPANT	\N	PRESENT	0
461803	461794	14051J	PARTICIPANT	\N	PRESENT	0
461804	461794	89017R	PARTICIPANT	\N	EXCUSE	0
461805	461794	14030Q	PARTICIPANT	\N	EXCUSE	0
461806	461794	08060W	PARTICIPANT	\N	EXCUSE	0
461807	461794	14053L	PARTICIPANT	\N	EXCUSE	0
461808	461794	19545Y	PARTICIPANT	\N	EXCUSE	0
461809	461794	14329V	PARTICIPANT	\N	EXCUSE	0
461810	461794	11031D	PARTICIPANT	\N	EXCUSE	0
461811	461794	14041T	PARTICIPANT	\N	EXCUSE	0
461812	461794	14151M	PARTICIPANT	\N	EXCUSE	0
461813	461794	19591F	PARTICIPANT	\N	EXCUSE	0
461814	461794	14039A	PARTICIPANT	\N	EXCUSE	0
461815	461794	11099A	PARTICIPANT	\N	EXCUSE	0
461817	461794	19697Q	PARTICIPANT	\N	EXCUSE	0
461821	461794	14265W	PARTICIPANT	\N	EXCUSE	0
461822	461794	08047A	PARTICIPANT	\N	EXCUSE	0
461840	461839	14034U	PARTICIPANT	\N	PRESENT	0
461841	461839	19575F	PARTICIPANT	\N	PRESENT	0
461842	461839	19671E	PARTICIPANT	\N	PRESENT	0
461843	461839	14105F	PARTICIPANT	\N	PRESENT	0
461844	461839	14026U	PARTICIPANT	\N	PRESENT	0
461845	461839	14087W	PARTICIPANT	\N	PRESENT	0
461846	461839	04088S	PARTICIPANT	\N	PRESENT	0
461847	461839	04049K	PRESIDENT	0	PRESENT	0
461848	461839	16685X	PARTICIPANT	\N	PRESENT	0
461849	461839	14083S	PARTICIPANT	\N	PRESENT	0
461850	461839	19521Q	PARTICIPANT	\N	PRESENT	0
461851	461839	14255U	PARTICIPANT	\N	PRESENT	0
461852	461839	14205J	PARTICIPANT	\N	PRESENT	0
461853	461839	89017R	PARTICIPANT	\N	EXCUSE	0
461854	461839	14030Q	PARTICIPANT	\N	EXCUSE	0
461855	461839	08060W	PARTICIPANT	\N	EXCUSE	0
461856	461839	14053L	PARTICIPANT	\N	EXCUSE	0
461857	461839	19545Y	PARTICIPANT	\N	EXCUSE	0
461858	461839	14329V	PARTICIPANT	\N	EXCUSE	0
461859	461839	14079W	PARTICIPANT	\N	EXCUSE	0
461860	461839	14041T	PARTICIPANT	\N	EXCUSE	0
461861	461839	14151M	PARTICIPANT	\N	EXCUSE	0
461862	461839	14187A	PARTICIPANT	\N	EXCUSE	0
461863	461839	14039A	PARTICIPANT	\N	EXCUSE	0
461864	461839	14061L	PARTICIPANT	\N	EXCUSE	0
461865	461839	11099A	PARTICIPANT	\N	EXCUSE	0
461866	461839	19697Q	PARTICIPANT	\N	EXCUSE	0
461867	461839	14265W	PARTICIPANT	\N	EXCUSE	0
461868	461839	08047A	PARTICIPANT	\N	EXCUSE	0
461869	461839	08068F	PARTICIPANT	\N	EXCUSE	0
461870	461839	14121F	PARTICIPANT	\N	EXCUSE	0
463608	463589	19691J	PARTICIPANT	\N	PRESENT	0
463609	463589	11054L	PARTICIPANT	\N	PRESENT	0
463610	463589	14331P	PARTICIPANT	\N	PRESENT	0
463611	463589	19577H	PARTICIPANT	\N	EXCUSE	0
466661	466647	19553Y	PARTICIPANT	\N	PRESENT	0
466663	466647	19723Y	PARTICIPANT	\N	PRESENT	0
466664	466647	19709B	PARTICIPANT	\N	PRESENT	0
466665	466647	01048V	PRESIDENT	0	PRESENT	0
466668	466647	19593H	PARTICIPANT	\N	PRESENT	0
466669	466647	19533U	PARTICIPANT	\N	PRESENT	0
467064	467054	14039A	PARTICIPANT	\N	EXCUSE	0
467124	467123	10006L	PARTICIPANT	\N	PRESENT	0
467125	467123	08052W	PARTICIPANT	\N	PRESENT	0
467126	467123	19575F	PARTICIPANT	\N	PRESENT	0
467127	467123	19723Y	PARTICIPANT	\N	PRESENT	0
467128	467123	19697Q	PARTICIPANT	\N	PRESENT	0
467129	467123	11097X	PARTICIPANT	\N	PRESENT	0
467130	467090	11031D	PARTICIPANT	\N	PRESENT	0
467131	467090	10006L	PARTICIPANT	\N	PRESENT	0
467132	467090	19697Q	PARTICIPANT	\N	PRESENT	0
467133	467090	11097X	PARTICIPANT	\N	PRESENT	0
467321	466834	98005N	PARTICIPANT	\N	PRESENT	0
467322	466834	19443T	PARTICIPANT	\N	PRESENT	0
467323	466834	12041X	PARTICIPANT	\N	PRESENT	0
467324	466834	04034C	PARTICIPANT	\N	PRESENT	0
467325	466834	14079W	PARTICIPANT	\N	PRESENT	0
467326	466834	01058X	PARTICIPANT	\N	PRESENT	0
467327	466834	04040A	PARTICIPANT	\N	PRESENT	0
467328	466834	11027H	PARTICIPANT	\N	PRESENT	0
467329	466834	16685X	PARTICIPANT	\N	PRESENT	0
467330	466834	04042C	PRESIDENT	0	PRESENT	0
467331	466834	11054L	PARTICIPANT	\N	PRESENT	0
467332	466834	19669L	PARTICIPANT	\N	PRESENT	0
476833	476792	08024S	PARTICIPANT	\N	PRESENT	0
476834	476792	14029X	PARTICIPANT	\N	PRESENT	0
476835	476792	19637C	PARTICIPANT	\N	PRESENT	0
476836	476792	19745F	PARTICIPANT	\N	PRESENT	0
476837	476792	14031R	PARTICIPANT	\N	PRESENT	0
476838	476792	04069P	PARTICIPANT	\N	PRESENT	0
476839	476792	19387D	PARTICIPANT	\N	PRESENT	0
476840	476792	17583W	PARTICIPANT	\N	PRESENT	0
476841	476436	19723Y	PARTICIPANT	\N	PRESENT	0
476842	476436	19593H	PARTICIPANT	\N	PRESENT	0
476843	476436	19533U	PARTICIPANT	\N	PRESENT	0
476844	476436	01048V	PARTICIPANT	\N	PRESENT	0
476845	476437	19723Y	PARTICIPANT	\N	PRESENT	0
476846	476437	01048V	PARTICIPANT	\N	PRESENT	0
476847	476437	19593H	PARTICIPANT	\N	PRESENT	0
476848	476438	19723Y	PARTICIPANT	\N	PRESENT	0
476850	476438	19593H	PARTICIPANT	\N	PRESENT	0
476851	476792	17637T	PARTICIPANT	\N	PRESENT	0
476857	476792	14038Y	PARTICIPANT	\N	PRESENT	0
476904	475783	19551W	PARTICIPANT	\N	PRESENT	0
476921	476642	14073Q	PARTICIPANT	\N	PRESENT	0
476930	476642	11026G	PARTICIPANT	\N	PRESENT	0
476946	476642	98035U	PARTICIPANT	\N	PRESENT	0
476947	476642	10015M	PARTICIPANT	\N	PRESENT	0
476948	476642	14331P	PARTICIPANT	\N	PRESENT	0
476949	476642	14135M	PARTICIPANT	\N	PRESENT	0
476950	476642	04057K	PARTICIPANT	\N	PRESENT	0
477465	477463	19399H	PARTICIPANT	\N	PRESENT	0
477467	477463	19533U	PARTICIPANT	\N	PRESENT	0
477468	477463	19749K	PARTICIPANT	\N	PRESENT	0
477469	477463	19731Y	PARTICIPANT	\N	PRESENT	0
477470	477463	14030Q	PARTICIPANT	\N	PRESENT	0
477472	477471	19399H	PARTICIPANT	\N	PRESENT	0
477473	477471	19533U	PARTICIPANT	\N	PRESENT	0
477474	477466	14187A	PARTICIPANT	\N	PRESENT	0
477476	477466	14081Q	PARTICIPANT	\N	PRESENT	0
477478	477477	19399H	PARTICIPANT	\N	PRESENT	0
477479	477477	19533U	PARTICIPANT	\N	PRESENT	0
477480	477477	08039A	PARTICIPANT	\N	PRESENT	0
477481	477477	14030Q	PARTICIPANT	\N	PRESENT	0
477500	476165	14197C	PARTICIPANT	\N	EXCUSE	0
477501	476165	19611R	PRESIDENT	0	PRESENT	0
477502	476165	14097Y	PARTICIPANT	\N	PRESENT	0
477503	476165	19549D	PARTICIPANT	\N	PRESENT	0
477504	476165	14033T	PARTICIPANT	\N	PRESENT	0
477506	477505	14097Y	PARTICIPANT	\N	PRESENT	0
477507	477505	14197C	PARTICIPANT	\N	EXCUSE	0
477508	477505	19611R	PRESIDENT	0	PRESENT	0
477509	477505	19369B	PARTICIPANT	\N	PRESENT	0
477510	477505	19549D	PARTICIPANT	\N	PRESENT	0
477579	476197	07033P	PARTICIPANT	\N	EXCUSE	0
477581	476197	19295A	PARTICIPANT	\N	EXCUSE	0
477599	476592	08049C	PARTICIPANT	\N	PRESENT	0
477600	476592	19335Q	PRESIDENT	0	PRESENT	0
477601	476592	11104D	PARTICIPANT	\N	PRESENT	0
477693	477692	07033P	PARTICIPANT	\N	EXCUSE	0
477758	476197	14261S	PARTICIPANT	\N	EXCUSE	0
477759	476197	19717B	PARTICIPANT	\N	PRESENT	0
477760	476197	19631V	PARTICIPANT	\N	PRESENT	0
477761	476197	19577H	PARTICIPANT	\N	EXCUSE	0
477762	476197	19715Y	PARTICIPANT	\N	PRESENT	0
477763	476197	14097Y	PARTICIPANT	\N	PRESENT	0
477764	476197	12016W	PARTICIPANT	\N	PRESENT	0
477765	476197	08019V	PRESIDENT	0	PRESENT	0
477766	476197	19657G	PARTICIPANT	\N	PRESENT	0
477897	476132	08041T	PARTICIPANT	\N	EXCUSE	0
477898	476132	19367Y	PARTICIPANT	\N	PRESENT	0
477899	476132	14261S	PARTICIPANT	\N	PRESENT	0
477900	476132	19717B	PARTICIPANT	\N	PRESENT	0
477901	476132	19575F	PARTICIPANT	\N	PRESENT	0
477902	476132	11103C	PARTICIPANT	\N	PRESENT	0
477903	476132	19727D	PARTICIPANT	\N	PRESENT	0
477904	476132	14195A	PARTICIPANT	\N	PRESENT	0
477905	476132	10006L	PARTICIPANT	\N	PRESENT	0
477906	476132	19577H	PARTICIPANT	\N	PRESENT	0
477907	476132	14042U	PARTICIPANT	\N	PRESENT	0
477908	476132	14281W	PARTICIPANT	\N	PRESENT	0
477909	476132	14087W	PARTICIPANT	\N	PRESENT	0
477910	476132	19553Y	PARTICIPANT	\N	PRESENT	0
477911	476132	19569H	PARTICIPANT	\N	PRESENT	0
477912	476132	19591F	PARTICIPANT	\N	PRESENT	0
477913	476132	14213J	PARTICIPANT	\N	PRESENT	0
477914	476132	19715Y	PARTICIPANT	\N	PRESENT	0
477915	476132	19657G	PARTICIPANT	\N	PRESENT	0
477916	476132	14223L	PARTICIPANT	\N	PRESENT	0
477917	476132	19798U	PARTICIPANT	\N	PRESENT	0
477918	476132	11045K	PARTICIPANT	\N	PRESENT	0
477919	476132	19703U	PARTICIPANT	\N	PRESENT	0
477920	476132	19301E	PARTICIPANT	\N	PRESENT	0
477968	477967	19295A	PARTICIPANT	\N	PRESENT	0
477969	477967	11109J	PARTICIPANT	\N	PRESENT	0
477970	477967	08019V	PARTICIPANT	\N	PRESENT	0
478013	474414	14030Q	PARTICIPANT	\N	PRESENT	0
478014	474414	19693L	PARTICIPANT	\N	PRESENT	0
478015	474414	19577H	PARTICIPANT	\N	PRESENT	0
478016	474414	19701S	PARTICIPANT	\N	PRESENT	0
478017	474414	19749K	PARTICIPANT	\N	PRESENT	0
478019	478018	14030Q	PARTICIPANT	\N	PRESENT	0
478020	478018	19701S	PARTICIPANT	\N	PRESENT	0
478021	478018	19693L	PARTICIPANT	\N	PRESENT	0
478022	478018	08017T	PARTICIPANT	\N	PRESENT	0
478023	478018	19749K	PARTICIPANT	\N	PRESENT	0
478026	478024	08012N	PARTICIPANT	\N	PRESENT	0
478027	478024	02002K	PARTICIPANT	\N	PRESENT	0
478028	478024	11043H	PARTICIPANT	\N	PRESENT	0
478029	478024	19349W	PARTICIPANT	\N	PRESENT	0
478030	478024	19711U	PARTICIPANT	\N	PRESENT	0
478031	478024	19533U	PARTICIPANT	\N	PRESENT	0
478032	478024	14030Q	PARTICIPANT	\N	PRESENT	0
478033	478024	19399H	PARTICIPANT	\N	PRESENT	0
478034	478024	14147R	PARTICIPANT	\N	PRESENT	0
478035	478024	14241N	PARTICIPANT	\N	PRESENT	0
478036	478025	08012N	PARTICIPANT	\N	PRESENT	0
478037	478025	02002K	PARTICIPANT	\N	PRESENT	0
478038	478025	19399H	PARTICIPANT	\N	PRESENT	0
478039	478025	19533U	PARTICIPANT	\N	PRESENT	0
478040	478025	14241N	PARTICIPANT	\N	PRESENT	0
478041	478025	19711U	PARTICIPANT	\N	PRESENT	0
478125	477621	19253P	PARTICIPANT	\N	EXCUSE	0
478132	477839	19575F	PARTICIPANT	\N	PRESENT	0
478133	477839	19367Y	PARTICIPANT	\N	PRESENT	0
478149	477839	14042U	PARTICIPANT	\N	PRESENT	0
478135	477839	98024R	PARTICIPANT	\N	PRESENT	0
478136	477839	10006L	PARTICIPANT	\N	PRESENT	0
478137	477839	19691J	PARTICIPANT	\N	PRESENT	0
478138	477839	14213J	PARTICIPANT	\N	PRESENT	0
478139	477839	19683J	PARTICIPANT	\N	PRESENT	0
478140	477839	19723Y	PARTICIPANT	\N	PRESENT	0
478141	477839	19697Q	PARTICIPANT	\N	PRESENT	0
478142	477839	11067R	PARTICIPANT	\N	PRESENT	0
478143	477839	04092N	PRESIDENT	0	PRESENT	0
478144	477839	14119M	PARTICIPANT	\N	PRESENT	0
478145	477839	14071N	PARTICIPANT	\N	PRESENT	0
478146	477839	19679N	PARTICIPANT	\N	PRESENT	0
478147	477839	11097X	PARTICIPANT	\N	PRESENT	0
478148	477839	11103C	PARTICIPANT	\N	PRESENT	0
478150	477839	17779H	PARTICIPANT	\N	PRESENT	0
478151	477839	19657G	PARTICIPANT	\N	PRESENT	0
478152	477839	19798U	PARTICIPANT	\N	PRESENT	0
478153	477839	01034P	PARTICIPANT	\N	PRESENT	0
478154	477839	19301E	PARTICIPANT	\N	PRESENT	0
478155	477839	11045K	PARTICIPANT	\N	PRESENT	0
478156	477839	19577H	PARTICIPANT	\N	PRESENT	0
478179	477621	14327T	PARTICIPANT	\N	EXCUSE	0
478254	477747	10015M	PARTICIPANT	\N	PRESENT	0
478255	477747	14179A	PARTICIPANT	\N	PRESENT	0
478343	477841	19565D	PARTICIPANT	\N	PRESENT	0
478344	477841	08052W	PARTICIPANT	\N	PRESENT	0
478345	477841	04092N	PRESIDENT	0	PRESENT	0
478346	477841	11067R	PARTICIPANT	\N	PRESENT	0
478347	477841	14281W	PARTICIPANT	\N	PRESENT	0
478348	477841	19367Y	PARTICIPANT	\N	PRESENT	0
478363	477841	98024R	PARTICIPANT	\N	PRESENT	0
478365	477841	19691J	PARTICIPANT	\N	PRESENT	0
478366	477841	19569H	PARTICIPANT	\N	PRESENT	0
478367	477841	14213J	PARTICIPANT	\N	PRESENT	0
478368	477841	14119M	PARTICIPANT	\N	PRESENT	0
478369	477841	19697Q	PARTICIPANT	\N	PRESENT	0
478370	477841	19679N	PARTICIPANT	\N	PRESENT	0
478371	477841	19798U	PARTICIPANT	\N	PRESENT	0
478373	477841	19301E	PARTICIPANT	\N	PRESENT	0
478381	477841	19657G	PARTICIPANT	\N	PRESENT	0
478382	477841	14042U	PARTICIPANT	\N	PRESENT	0
478383	477841	11103C	PARTICIPANT	\N	PRESENT	0
478384	477841	11031D	PARTICIPANT	\N	PRESENT	0
478385	477841	19577H	PARTICIPANT	\N	PRESENT	0
456587	454195	07033P	PARTICIPANT	\N	EXCUSE	0
456588	454195	96004D	PARTICIPANT	\N	EXCUSE	0
456589	454195	14225N	PARTICIPANT	\N	EXCUSE	0
456590	454195	19657G	PARTICIPANT	\N	EXCUSE	0
456591	454195	19583F	PARTICIPANT	\N	EXCUSE	0
456592	453247	96004D	PARTICIPANT	\N	EXCUSE	0
456593	453247	19583F	PARTICIPANT	\N	EXCUSE	0
456594	453247	19657G	PARTICIPANT	\N	EXCUSE	0
456595	453247	14225N	PARTICIPANT	\N	EXCUSE	0
456596	451300	14038Y	PARTICIPANT	\N	EXCUSE	0
456597	451300	11109J	PARTICIPANT	\N	PRESENT	0
456598	451300	14261S	PARTICIPANT	\N	PRESENT	0
456599	451300	19631V	PARTICIPANT	\N	PRESENT	0
456600	451300	07033P	PARTICIPANT	\N	PRESENT	0
456601	451300	19691J	PARTICIPANT	\N	PRESENT	0
456602	451300	14097Y	PARTICIPANT	\N	PRESENT	0
456603	451300	98005N	PARTICIPANT	\N	PRESENT	0
456604	451300	14059S	PARTICIPANT	\N	PRESENT	0
456605	451300	08019V	PRESIDENT	0	PRESENT	0
456606	451300	19301E	PARTICIPANT	\N	PRESENT	0
456607	451300	11054L	PARTICIPANT	\N	EXCUSE	0
456608	451300	14219Q	PARTICIPANT	\N	EXCUSE	0
456609	451300	19729F	PARTICIPANT	\N	EXCUSE	0
456610	451300	19583F	PARTICIPANT	\N	EXCUSE	0
456611	451300	19329S	PARTICIPANT	\N	EXCUSE	0
466947	465833	07029T	PARTICIPANT	\N	EXCUSE	0
466948	466827	11085T	PARTICIPANT	\N	PRESENT	0
466949	466827	19447X	PARTICIPANT	\N	PRESENT	0
466951	466950	14179A	PARTICIPANT	\N	PRESENT	0
466952	466950	14021P	PARTICIPANT	\N	PRESENT	0
466953	466950	14147R	PARTICIPANT	\N	PRESENT	0
469263	468607	11031D	PARTICIPANT	\N	PRESENT	0
469266	468607	11067R	PARTICIPANT	\N	PRESENT	0
469267	468607	19798U	PARTICIPANT	\N	PRESENT	0
469270	468607	11097X	PARTICIPANT	\N	PRESENT	0
469272	468608	19415P	PARTICIPANT	\N	PRESENT	0
469273	468608	04092N	PARTICIPANT	\N	PRESENT	0
469274	468608	11097X	PARTICIPANT	\N	PRESENT	0
469275	468608	11067R	PARTICIPANT	\N	PRESENT	0
469276	468608	19798U	PARTICIPANT	\N	PRESENT	0
469277	468608	19723Y	PARTICIPANT	\N	PRESENT	0
469278	468608	11031D	PARTICIPANT	\N	PRESENT	0
469279	468609	19415P	PARTICIPANT	\N	PRESENT	0
469280	468609	11031D	PARTICIPANT	\N	PRESENT	0
469281	468609	17779H	PARTICIPANT	\N	PRESENT	0
469295	467061	10006L	PARTICIPANT	\N	PRESENT	0
469299	467061	11097X	PARTICIPANT	\N	PRESENT	0
469300	467061	08052W	PARTICIPANT	\N	PRESENT	0
469304	467061	19575F	PARTICIPANT	\N	PRESENT	0
469305	467061	14213J	PARTICIPANT	\N	PRESENT	0
469306	467061	19697Q	PARTICIPANT	\N	PRESENT	0
469308	467061	19760E	PARTICIPANT	\N	PRESENT	0
469315	468610	19798U	PARTICIPANT	\N	PRESENT	0
469313	468610	19415P	PARTICIPANT	\N	PRESENT	0
469314	468610	11097X	PARTICIPANT	\N	PRESENT	0
469316	468610	19679N	PARTICIPANT	\N	PRESENT	0
469317	468611	19415P	PARTICIPANT	\N	PRESENT	0
469318	468612	19415P	PARTICIPANT	\N	PRESENT	0
469319	468612	11067R	PARTICIPANT	\N	PRESENT	0
469320	468612	14223L	PARTICIPANT	\N	PRESENT	0
469344	469242	14239U	PARTICIPANT	\N	PRESENT	0
469345	469242	19367Y	PARTICIPANT	\N	PRESENT	0
469346	469242	11103C	PARTICIPANT	\N	PRESENT	0
469347	469242	19521Q	PARTICIPANT	\N	PRESENT	0
469348	469242	19723Y	PARTICIPANT	\N	PRESENT	0
469349	469242	98024R	PARTICIPANT	\N	PRESENT	0
469350	469242	11031D	PARTICIPANT	\N	PRESENT	0
469362	469242	19697Q	PARTICIPANT	\N	PRESENT	0
469363	469242	14223L	PARTICIPANT	\N	PRESENT	0
469364	469242	19527W	PARTICIPANT	\N	PRESENT	0
469365	468604	10006L	PARTICIPANT	\N	PRESENT	0
469436	467533	14065Q	PARTICIPANT	\N	PRESENT	0
469437	467533	14069U	PARTICIPANT	\N	PRESENT	0
469438	467533	14053L	PARTICIPANT	\N	PRESENT	0
469439	467533	19629C	PARTICIPANT	\N	PRESENT	0
469440	467533	04038G	PARTICIPANT	\N	PRESENT	0
469441	467533	19253P	PARTICIPANT	\N	PRESENT	0
469442	467533	14259Y	PARTICIPANT	\N	PRESENT	0
469443	467533	04008A	PARTICIPANT	\N	PRESENT	0
469444	467533	14041T	PARTICIPANT	\N	PRESENT	0
469445	467533	14151M	PARTICIPANT	\N	PRESENT	0
469446	467533	19673G	PARTICIPANT	\N	PRESENT	0
469447	467533	08018U	PARTICIPANT	\N	PRESENT	0
469448	467533	19649G	PARTICIPANT	\N	PRESENT	0
469449	467533	11049P	PARTICIPANT	\N	PRESENT	0
469450	467533	19725B	PARTICIPANT	\N	PRESENT	0
469451	467533	14179A	PARTICIPANT	\N	PRESENT	0
469452	467533	08044W	PARTICIPANT	\N	PRESENT	0
469453	467533	19447X	PARTICIPANT	\N	PRESENT	0
469454	467533	19489J	PARTICIPANT	\N	PRESENT	0
469455	467533	11026G	PARTICIPANT	\N	PRESENT	0
469456	467533	19581D	PARTICIPANT	\N	PRESENT	0
469457	467533	14111D	PARTICIPANT	\N	PRESENT	0
469458	467533	14001X	PARTICIPANT	\N	PRESENT	0
469459	467533	11085T	PARTICIPANT	\N	PRESENT	0
469460	467533	14147R	PARTICIPANT	\N	PRESENT	0
469461	467533	10015M	PARTICIPANT	\N	PRESENT	0
469462	467533	01028R	PARTICIPANT	\N	PRESENT	0
469463	467533	98035U	PARTICIPANT	\N	PRESENT	0
469464	467533	19675J	PARTICIPANT	\N	PRESENT	0
469465	467533	04044E	PARTICIPANT	\N	PRESENT	0
469466	467532	19543W	PARTICIPANT	\N	PRESENT	0
469467	467532	14065Q	PARTICIPANT	\N	PRESENT	0
469468	467532	04038G	PARTICIPANT	\N	PRESENT	0
469469	467532	19253P	PARTICIPANT	\N	PRESENT	0
469470	467532	19719D	PARTICIPANT	\N	PRESENT	0
469471	467532	14041T	PARTICIPANT	\N	PRESENT	0
469472	467532	01024M	PARTICIPANT	\N	PRESENT	0
469473	467532	14151M	PARTICIPANT	\N	PRESENT	0
469474	467532	08045X	PARTICIPANT	\N	PRESENT	0
469475	467532	08018U	PARTICIPANT	\N	PRESENT	0
469476	467532	11049P	PARTICIPANT	\N	PRESENT	0
469477	467532	19725B	PARTICIPANT	\N	PRESENT	0
469478	467532	14179A	PARTICIPANT	\N	PRESENT	0
469479	467532	19447X	PARTICIPANT	\N	PRESENT	0
469480	467532	19489J	PARTICIPANT	\N	PRESENT	0
469481	467532	11026G	PARTICIPANT	\N	PRESENT	0
469482	467532	19581D	PARTICIPANT	\N	PRESENT	0
469483	467532	14111D	PARTICIPANT	\N	PRESENT	0
469484	467532	14001X	PARTICIPANT	\N	PRESENT	0
469485	467532	14147R	PARTICIPANT	\N	PRESENT	0
469486	467532	11072N	PARTICIPANT	\N	PRESENT	0
469487	467532	10015M	PARTICIPANT	\N	PRESENT	0
469488	467532	98035U	PARTICIPANT	\N	PRESENT	0
469489	467532	19675J	PARTICIPANT	\N	PRESENT	0
469490	467532	04044E	PARTICIPANT	\N	PRESENT	0
469497	467706	14065Q	PARTICIPANT	\N	PRESENT	0
469498	467706	19253P	PARTICIPANT	\N	PRESENT	0
469499	467706	04008A	PARTICIPANT	\N	PRESENT	0
469500	467706	14041T	PARTICIPANT	\N	PRESENT	0
469501	467706	08018U	PARTICIPANT	\N	PRESENT	0
469502	467706	19447X	PARTICIPANT	\N	PRESENT	0
469503	467706	11026G	PARTICIPANT	\N	PRESENT	0
469504	467706	14147R	PARTICIPANT	\N	PRESENT	0
469604	469071	01043Q	PARTICIPANT	\N	PRESENT	0
469605	469071	08038Y	PARTICIPANT	\N	PRESENT	0
469606	469071	14033T	PARTICIPANT	\N	PRESENT	0
469607	469071	11101A	PARTICIPANT	\N	PRESENT	0
469608	469128	11026G	PARTICIPANT	\N	PRESENT	0
469609	469128	19729F	PARTICIPANT	\N	EXCUSE	0
469635	469128	19585H	PARTICIPANT	\N	PRESENT	0
469636	469128	08018U	PARTICIPANT	\N	PRESENT	0
469640	469128	95063L	PARTICIPANT	\N	PRESENT	0
469686	468731	19443T	PARTICIPANT	\N	PRESENT	0
469687	468731	12041X	PARTICIPANT	\N	PRESENT	0
469688	468731	95030B	PARTICIPANT	\N	PRESENT	0
469689	468731	04034C	PARTICIPANT	\N	PRESENT	0
469690	468731	01058X	PARTICIPANT	\N	PRESENT	0
469691	468731	04040A	PARTICIPANT	\N	PRESENT	0
469692	468731	04042C	PRESIDENT	0	PRESENT	0
469693	468731	11054L	PARTICIPANT	\N	PRESENT	0
469694	468731	11066Q	PARTICIPANT	\N	PRESENT	0
469695	468731	08056B	PARTICIPANT	\N	PRESENT	0
469696	468731	95037J	PARTICIPANT	\N	PRESENT	0
469697	468731	19421M	PARTICIPANT	\N	PRESENT	0
469698	468731	19709B	PARTICIPANT	\N	PRESENT	0
469699	468731	14193X	PARTICIPANT	\N	PRESENT	0
469700	468731	08053X	PARTICIPANT	\N	PRESENT	0
469701	468731	97011G	PARTICIPANT	\N	PRESENT	0
469702	468731	08061X	PARTICIPANT	\N	PRESENT	0
469703	468731	08047A	PARTICIPANT	\N	PRESENT	0
469704	468731	98029W	PARTICIPANT	\N	PRESENT	0
469705	468731	14097Y	PARTICIPANT	\N	PRESENT	0
469706	468731	04035D	PARTICIPANT	\N	PRESENT	0
469707	468731	95067Q	PARTICIPANT	\N	PRESENT	0
469708	468731	14133K	PRESIDENT	1	PRESENT	0
469709	468731	01062T	PARTICIPANT	\N	PRESENT	0
469710	468731	08058D	PARTICIPANT	\N	PRESENT	0
469711	468731	14028W	PARTICIPANT	\N	PRESENT	0
476519	476351	11033F	PARTICIPANT	\N	PRESENT	0
476520	476351	19629C	PARTICIPANT	\N	PRESENT	0
476521	476351	04038G	PARTICIPANT	\N	PRESENT	0
476522	476351	19673G	PARTICIPANT	\N	PRESENT	0
476523	476351	08045X	PARTICIPANT	\N	PRESENT	0
476524	476351	19725B	PARTICIPANT	\N	PRESENT	0
476525	476351	14179A	PARTICIPANT	\N	PRESENT	0
476526	476351	08044W	PARTICIPANT	\N	PRESENT	0
476527	476351	19489J	PARTICIPANT	\N	PRESENT	0
476528	476351	19729F	PARTICIPANT	\N	PRESENT	0
476529	476351	19581D	PARTICIPANT	\N	PRESENT	0
476530	476351	19762G	PARTICIPANT	\N	PRESENT	0
476531	476351	01028R	PARTICIPANT	\N	PRESENT	0
477072	473394	14121F	PARTICIPANT	\N	PRESENT	0
477073	473394	19749K	PARTICIPANT	\N	PRESENT	0
477074	473394	01034P	PARTICIPANT	\N	PRESENT	0
477076	473394	11085T	PARTICIPANT	\N	PRESENT	0
477077	473394	19733B	PARTICIPANT	\N	PRESENT	0
477078	473394	19573D	PARTICIPANT	\N	PRESENT	0
477079	473394	19693L	PARTICIPANT	\N	PRESENT	0
477080	473394	14053L	PARTICIPANT	\N	PRESENT	0
477112	473394	14179A	PARTICIPANT	\N	PRESENT	0
477082	473394	01043Q	PARTICIPANT	\N	PRESENT	0
477084	473394	19794Q	PARTICIPANT	\N	PRESENT	0
477085	473394	19689Q	PARTICIPANT	\N	PRESENT	0
477086	473394	04071H	PARTICIPANT	\N	PRESENT	0
477087	473394	14042U	PARTICIPANT	\N	PRESENT	0
477088	473394	19369B	PARTICIPANT	\N	PRESENT	0
477094	473394	14219Q	PARTICIPANT	\N	PRESENT	0
477095	473394	19533U	PARTICIPANT	\N	PRESENT	0
477096	473394	19531S	PARTICIPANT	\N	PRESENT	0
477101	473394	16685X	PARTICIPANT	\N	PRESENT	0
477099	473394	19525U	PARTICIPANT	\N	PRESENT	0
477100	473394	14147R	PARTICIPANT	\N	PRESENT	0
477102	473394	19621T	PARTICIPANT	\N	PRESENT	0
477103	473394	01048V	PARTICIPANT	\N	PRESENT	0
477105	473394	14133K	PARTICIPANT	\N	PRESENT	0
477106	473394	11054L	PARTICIPANT	\N	PRESENT	0
477107	473394	19347U	PARTICIPANT	\N	PRESENT	0
477108	473394	08068F	PARTICIPANT	\N	PRESENT	0
477110	473394	04040A	PARTICIPANT	\N	PRESENT	0
477111	473394	14267Y	PARTICIPANT	\N	PRESENT	0
477113	473394	19399H	PARTICIPANT	\N	PRESENT	0
477241	473395	14215L	PARTICIPANT	\N	PRESENT	0
477242	473395	15447F	PARTICIPANT	\N	PRESENT	0
477243	473395	19565D	PARTICIPANT	\N	PRESENT	0
477244	473395	05008E	PARTICIPANT	\N	PRESENT	0
477245	473395	19447X	PARTICIPANT	\N	PRESENT	0
477246	473395	11097X	PARTICIPANT	\N	PRESENT	0
477247	473395	11072N	PARTICIPANT	\N	PRESENT	0
477248	473395	04071H	PARTICIPANT	\N	PRESENT	0
477249	473395	14041T	PARTICIPANT	\N	PRESENT	0
477250	473395	19766L	PARTICIPANT	\N	PRESENT	0
477251	473395	19563B	PARTICIPANT	\N	PRESENT	0
477256	473395	19820Y	PARTICIPANT	\N	PRESENT	0
477253	473395	17779H	PARTICIPANT	\N	PRESENT	0
477255	473395	11027H	PARTICIPANT	\N	PRESENT	0
477257	473395	19794Q	PARTICIPANT	\N	PRESENT	0
477259	473395	11012A	PARTICIPANT	\N	PRESENT	0
477263	473395	19629C	PARTICIPANT	\N	PRESENT	0
477266	473395	04034C	PARTICIPANT	\N	PRESENT	0
477270	476189	14331P	PARTICIPANT	\N	PRESENT	0
477271	476189	19647E	PARTICIPANT	\N	PRESENT	0
477272	476189	19711U	PARTICIPANT	\N	PRESENT	0
477273	476189	01048V	PARTICIPANT	\N	PRESENT	0
477274	476189	19531S	PARTICIPANT	\N	PRESENT	0
477275	476189	01057W	PARTICIPANT	\N	PRESENT	0
477276	476189	11053K	PARTICIPANT	\N	PRESENT	0
477277	476189	12016W	PARTICIPANT	\N	PRESENT	0
477278	476189	08011M	PARTICIPANT	\N	PRESENT	0
477279	476189	11074Q	PRESIDENT	0	PRESENT	0
477280	476189	19671E	PARTICIPANT	\N	PRESENT	0
477281	476189	14225N	PARTICIPANT	\N	PRESENT	0
477282	476189	04086Q	PARTICIPANT	\N	PRESENT	0
477283	476189	11040E	PARTICIPANT	\N	PRESENT	0
477284	476189	07029T	PARTICIPANT	\N	PRESENT	0
477285	476189	08073C	PARTICIPANT	\N	PRESENT	0
477286	476189	96004D	PARTICIPANT	\N	PRESENT	0
477287	476189	19349W	PARTICIPANT	\N	PRESENT	0
477288	476189	08010L	PARTICIPANT	\N	PRESENT	0
477289	476189	14121F	PARTICIPANT	\N	PRESENT	0
477290	473395	08069G	PARTICIPANT	\N	PRESENT	0
477294	476189	14085U	PARTICIPANT	\N	PRESENT	0
477416	476189	11110B	PARTICIPANT	\N	PRESENT	0
477417	476189	95041E	PARTICIPANT	\N	PRESENT	0
477433	476132	19527W	PARTICIPANT	\N	PRESENT	0
477407	476189	14034U	PARTICIPANT	\N	EXCUSE	0
477434	476132	19697Q	PARTICIPANT	\N	PRESENT	0
477413	476189	19667J	PARTICIPANT	\N	PRESENT	0
477415	476189	19545Y	PARTICIPANT	\N	PRESENT	0
477435	476132	11067R	PARTICIPANT	\N	PRESENT	0
477436	476132	01034P	PARTICIPANT	\N	PRESENT	0
477437	476132	04092N	PARTICIPANT	\N	PRESENT	0
477438	476132	11097X	PARTICIPANT	\N	PRESENT	0
477439	476132	08052W	PARTICIPANT	\N	PRESENT	0
477440	476132	19415P	PARTICIPANT	\N	PRESENT	0
477441	476132	19691J	PARTICIPANT	\N	PRESENT	0
477442	476132	14026U	PARTICIPANT	\N	PRESENT	0
477443	476132	19723Y	PARTICIPANT	\N	PRESENT	0
477444	476132	11031D	PARTICIPANT	\N	PRESENT	0
477445	476132	98024R	PARTICIPANT	\N	PRESENT	0
477450	473396	19711U	PARTICIPANT	\N	PRESENT	0
477451	473396	19533U	PARTICIPANT	\N	PRESENT	0
477452	473396	08039A	PARTICIPANT	\N	PRESENT	0
477453	473396	08073C	PARTICIPANT	\N	PRESENT	0
477454	473396	04071H	PARTICIPANT	\N	PRESENT	0
477462	473396	19667J	PARTICIPANT	\N	PRESENT	0
477464	476189	19741B	PARTICIPANT	\N	PRESENT	0
477482	473396	19691J	PARTICIPANT	\N	PRESENT	0
477483	473396	11067R	PARTICIPANT	\N	PRESENT	0
477484	473396	11097X	PARTICIPANT	\N	PRESENT	0
477485	473396	19621T	PARTICIPANT	\N	PRESENT	0
477486	473396	19709B	PARTICIPANT	\N	PRESENT	0
477487	473396	08052W	PARTICIPANT	\N	PRESENT	0
477488	473396	19531S	PARTICIPANT	\N	PRESENT	0
477489	473396	19695N	PARTICIPANT	\N	PRESENT	0
477490	473396	95063L	PARTICIPANT	\N	PRESENT	0
477491	473396	14255U	PARTICIPANT	\N	PRESENT	0
477492	473396	14030Q	PARTICIPANT	\N	PRESENT	0
477493	473396	04040A	PARTICIPANT	\N	PRESENT	0
477497	473396	14251Q	PARTICIPANT	\N	PRESENT	0
477498	473396	14217N	PARTICIPANT	\N	PRESENT	0
477499	473396	07029T	PARTICIPANT	\N	PRESENT	0
477511	473396	14147R	PARTICIPANT	\N	PRESENT	0
477528	477527	14267Y	PARTICIPANT	\N	PRESENT	0
477529	477527	11054L	PARTICIPANT	\N	PRESENT	0
477530	477527	08047A	PARTICIPANT	\N	PRESENT	0
477531	477527	14133K	PARTICIPANT	\N	PRESENT	0
477532	477527	04034C	PARTICIPANT	\N	PRESENT	0
477533	475783	02002K	PARTICIPANT	\N	EXCUSE	0
477239	473395	04044E	PARTICIPANT	\N	PRESENT	0
477240	473395	14179A	PARTICIPANT	\N	PRESENT	0
477534	476047	11101A	PARTICIPANT	\N	PRESENT	0
477535	476047	19253P	PARTICIPANT	\N	PRESENT	0
477536	476047	04086Q	PARTICIPANT	\N	PRESENT	0
477537	476047	14257W	PARTICIPANT	\N	PRESENT	0
477538	476047	14281W	PARTICIPANT	\N	PRESENT	0
477539	476047	19820Y	PARTICIPANT	\N	PRESENT	0
477540	476047	19565D	PARTICIPANT	\N	PRESENT	0
477541	476047	01057W	PARTICIPANT	\N	PRESENT	0
477542	476047	19489J	PARTICIPANT	\N	PRESENT	0
477543	476047	19687N	PARTICIPANT	\N	PRESENT	0
477544	476047	19735D	PARTICIPANT	\N	EXCUSE	0
477545	476047	08010L	PARTICIPANT	\N	PRESENT	0
477546	476047	17637T	PARTICIPANT	\N	PRESENT	0
477547	476047	14259Y	PARTICIPANT	\N	PRESENT	0
477548	476047	95067Q	PARTICIPANT	\N	PRESENT	0
477549	475690	14133K	PARTICIPANT	\N	PRESENT	0
477550	475690	04040A	PARTICIPANT	\N	PRESENT	0
477551	475690	14105F	PARTICIPANT	\N	PRESENT	0
477552	475690	14255U	PARTICIPANT	\N	PRESENT	0
477553	475690	04042C	PRESIDENT	0	PRESENT	0
477554	475690	98029W	PARTICIPANT	\N	PRESENT	0
477555	475690	14079W	PARTICIPANT	\N	PRESENT	0
477556	475690	98018T	PARTICIPANT	\N	PRESENT	0
477557	475690	19251M	PARTICIPANT	\N	PRESENT	0
477558	475690	97011G	PARTICIPANT	\N	PRESENT	0
477559	475690	04035D	PARTICIPANT	\N	PRESENT	0
477560	475690	11064N	PARTICIPANT	\N	PRESENT	0
477561	475690	95037J	PARTICIPANT	\N	PRESENT	0
477562	475690	12041X	PARTICIPANT	\N	PRESENT	0
477563	475690	19709B	PARTICIPANT	\N	PRESENT	0
477564	475690	16685X	PARTICIPANT	\N	PRESENT	0
477565	475690	08053X	PARTICIPANT	\N	PRESENT	0
477566	475690	14193X	PARTICIPANT	\N	PRESENT	0
477567	475690	98050T	PARTICIPANT	\N	PRESENT	0
477568	475690	19443T	PARTICIPANT	\N	PRESENT	0
477569	475690	19421M	PARTICIPANT	\N	PRESENT	0
477570	475690	01058X	PARTICIPANT	\N	PRESENT	0
457770	457762	08055A	PARTICIPANT	\N	PRESENT	0
457772	457762	14105F	PARTICIPANT	\N	PRESENT	0
457776	457762	19383Y	PARTICIPANT	\N	PRESENT	0
457777	457762	19782L	PARTICIPANT	\N	PRESENT	0
457778	457762	11103C	PARTICIPANT	\N	PRESENT	0
457779	457762	14329V	PARTICIPANT	\N	PRESENT	0
457782	457762	19467C	PARTICIPANT	\N	PRESENT	0
457784	457762	17589D	PARTICIPANT	\N	PRESENT	0
457791	457762	14187A	PARTICIPANT	\N	PRESENT	0
457797	457762	19723Y	PARTICIPANT	\N	PRESENT	0
457800	457762	16685X	PARTICIPANT	\N	PRESENT	0
457804	457762	19563B	PARTICIPANT	\N	PRESENT	0
457807	457762	04092N	PARTICIPANT	\N	PRESENT	0
457809	457762	04088S	PARTICIPANT	\N	PRESENT	0
457812	457762	19739H	PARTICIPANT	\N	PRESENT	0
457814	457762	17583W	PARTICIPANT	\N	PRESENT	0
457818	457762	19679N	PARTICIPANT	\N	PRESENT	0
457832	457762	14107H	PARTICIPANT	\N	PRESENT	0
457835	457762	14173T	PARTICIPANT	\N	PRESENT	0
462461	462460	19507S	PARTICIPANT	\N	PRESENT	0
466812	466811	14215L	PARTICIPANT	\N	PRESENT	0
466813	466811	11085T	PARTICIPANT	\N	PRESENT	0
466814	466811	14021P	PARTICIPANT	\N	PRESENT	0
466815	466811	04047H	PARTICIPANT	\N	PRESENT	0
466817	466816	05008E	PARTICIPANT	\N	PRESENT	0
466818	466816	14259Y	PARTICIPANT	\N	PRESENT	0
466819	466816	14231L	PARTICIPANT	\N	PRESENT	0
466820	466816	04040A	PARTICIPANT	\N	PRESENT	0
466822	466821	05008E	PARTICIPANT	\N	PRESENT	0
466823	466821	14259Y	PARTICIPANT	\N	PRESENT	0
466824	466821	14231L	PARTICIPANT	\N	PRESENT	0
466825	466821	04040A	PARTICIPANT	\N	PRESENT	0
466828	466827	01028R	PARTICIPANT	\N	PRESENT	0
466829	466827	19673G	PARTICIPANT	\N	PRESENT	0
466831	466830	01028R	PARTICIPANT	\N	PRESENT	0
466832	466830	19673G	PARTICIPANT	\N	PRESENT	0
466865	466864	11040E	PARTICIPANT	\N	PRESENT	0
466866	466864	19711U	PARTICIPANT	\N	PRESENT	0
466867	466864	19551W	PARTICIPANT	\N	PRESENT	0
466868	466864	11070L	PARTICIPANT	\N	PRESENT	0
467333	466834	11066Q	PARTICIPANT	\N	PRESENT	0
467334	466834	08056B	PARTICIPANT	\N	PRESENT	0
467335	466834	19421M	PARTICIPANT	\N	PRESENT	0
467336	466834	19709B	PARTICIPANT	\N	PRESENT	0
467337	466834	08061X	PARTICIPANT	\N	PRESENT	0
467338	466834	08047A	PARTICIPANT	\N	PRESENT	0
467339	466834	98029W	PARTICIPANT	\N	PRESENT	0
467340	466834	14097Y	PARTICIPANT	\N	PRESENT	0
467341	466834	95067Q	PARTICIPANT	\N	PRESENT	0
467342	466834	14133K	PARTICIPANT	\N	PRESENT	0
467343	466834	01062T	PARTICIPANT	\N	PRESENT	0
467344	466834	11041F	PARTICIPANT	\N	PRESENT	0
467345	466834	08058D	PARTICIPANT	\N	PRESENT	0
467346	466834	19251M	PARTICIPANT	\N	PRESENT	0
467347	466834	14028W	PARTICIPANT	\N	PRESENT	0
467348	466834	19721W	PARTICIPANT	\N	PRESENT	0
467349	466834	14105F	PARTICIPANT	\N	PRESENT	0
467350	466834	98018T	PARTICIPANT	\N	PRESENT	0
467351	466834	98022P	PARTICIPANT	\N	PRESENT	0
467352	466834	14267Y	PARTICIPANT	\N	PRESENT	0
467353	466834	11064N	PARTICIPANT	\N	PRESENT	0
467354	466834	98050T	PARTICIPANT	\N	PRESENT	0
467355	466834	19583F	PARTICIPANT	\N	PRESENT	0
467356	466834	14255U	PARTICIPANT	\N	PRESENT	0
467357	466834	08049C	PARTICIPANT	\N	EXCUSE	0
467358	466834	14193X	PARTICIPANT	\N	EXCUSE	0
467361	466389	19760E	PARTICIPANT	\N	PRESENT	0
467362	466389	19575F	PARTICIPANT	\N	PRESENT	0
467363	466389	19415P	PARTICIPANT	\N	PRESENT	0
467364	466389	11103C	PARTICIPANT	\N	PRESENT	0
467365	466389	19727D	PARTICIPANT	\N	PRESENT	0
467366	466389	14195A	PARTICIPANT	\N	PRESENT	0
467367	466389	11031D	PARTICIPANT	\N	PRESENT	0
467368	466389	08052W	PARTICIPANT	\N	PRESENT	0
467369	466389	19663E	PARTICIPANT	\N	PRESENT	0
467370	466389	98024R	PARTICIPANT	\N	PRESENT	0
467371	466389	10006L	PARTICIPANT	\N	PRESENT	0
467372	466389	14042U	PARTICIPANT	\N	PRESENT	0
467373	466389	08048B	PARTICIPANT	\N	PRESENT	0
467374	466389	19565D	PARTICIPANT	\N	PRESENT	0
467375	466389	19691J	PARTICIPANT	\N	PRESENT	0
467376	466389	19527W	PARTICIPANT	\N	PRESENT	0
467377	466389	19569H	PARTICIPANT	\N	PRESENT	0
467378	466389	19591F	PARTICIPANT	\N	PRESENT	0
467379	466389	14213J	PARTICIPANT	\N	PRESENT	0
467380	466389	19723Y	PARTICIPANT	\N	PRESENT	0
467381	466389	19697Q	PARTICIPANT	\N	PRESENT	0
467382	466389	17779H	PARTICIPANT	\N	PRESENT	0
467383	466389	19683J	PARTICIPANT	\N	PRESENT	0
467384	466389	19657G	PARTICIPANT	\N	PRESENT	0
467385	466389	11067R	PARTICIPANT	\N	PRESENT	0
467386	466389	14119M	PARTICIPANT	\N	PRESENT	0
467387	466389	14071N	PARTICIPANT	\N	PRESENT	0
467388	466389	19679N	PARTICIPANT	\N	PRESENT	0
467389	466389	19798U	PARTICIPANT	\N	PRESENT	0
467390	466389	11097X	PARTICIPANT	\N	PRESENT	0
467391	466389	19703U	PARTICIPANT	\N	PRESENT	0
467392	466389	14227Q	PARTICIPANT	\N	PRESENT	0
467393	466389	01034P	PARTICIPANT	\N	PRESENT	0
467394	466389	04092N	PRESIDENT	0	PRESENT	0
467395	466401	14239U	PARTICIPANT	\N	PRESENT	0
467396	466401	19760E	PARTICIPANT	\N	PRESENT	0
467397	466401	19717B	PARTICIPANT	\N	PRESENT	0
467398	466401	19575F	PARTICIPANT	\N	PRESENT	0
467399	466401	19415P	PARTICIPANT	\N	PRESENT	0
467400	466401	11103C	PARTICIPANT	\N	PRESENT	0
467401	466401	14195A	PARTICIPANT	\N	PRESENT	0
467402	466401	11031D	PARTICIPANT	\N	PRESENT	0
467403	466401	08052W	PARTICIPANT	\N	PRESENT	0
467404	466401	98024R	PARTICIPANT	\N	PRESENT	0
467405	466401	10006L	PARTICIPANT	\N	PRESENT	0
467406	466401	14217N	PARTICIPANT	\N	PRESENT	0
467407	466401	19577H	PARTICIPANT	\N	PRESENT	0
467408	466401	14042U	PARTICIPANT	\N	PRESENT	0
467409	466401	14281W	PARTICIPANT	\N	PRESENT	0
467410	466401	14087W	PARTICIPANT	\N	PRESENT	0
467411	466401	08048B	PARTICIPANT	\N	PRESENT	0
467412	466401	19565D	PARTICIPANT	\N	PRESENT	0
467413	466401	14026U	PARTICIPANT	\N	PRESENT	0
467414	466401	19691J	PARTICIPANT	\N	PRESENT	0
467415	466401	19553Y	PARTICIPANT	\N	PRESENT	0
467416	466401	19527W	PARTICIPANT	\N	PRESENT	0
467417	466401	19569H	PARTICIPANT	\N	PRESENT	0
467418	466401	19591F	PARTICIPANT	\N	PRESENT	0
467419	466401	14213J	PARTICIPANT	\N	PRESENT	0
467420	466401	19715Y	PARTICIPANT	\N	PRESENT	0
467421	466401	19723Y	PARTICIPANT	\N	PRESENT	0
467422	466401	19697Q	PARTICIPANT	\N	PRESENT	0
467423	466401	17779H	PARTICIPANT	\N	PRESENT	0
467424	466401	19683J	PARTICIPANT	\N	PRESENT	0
467425	466401	19657G	PARTICIPANT	\N	PRESENT	0
467426	466401	14223L	PARTICIPANT	\N	PRESENT	0
467427	466401	04092N	PRESIDENT	0	PRESENT	0
467428	466401	14119M	PARTICIPANT	\N	PRESENT	0
467429	466401	14071N	PARTICIPANT	\N	PRESENT	0
467430	466401	19679N	PARTICIPANT	\N	PRESENT	0
467431	466401	19798U	PARTICIPANT	\N	PRESENT	0
467432	466401	11045K	PARTICIPANT	\N	PRESENT	0
467433	466401	11097X	PARTICIPANT	\N	PRESENT	0
467434	466401	19703U	PARTICIPANT	\N	PRESENT	0
467435	466401	01034P	PARTICIPANT	\N	PRESENT	0
467436	466407	19717B	PARTICIPANT	\N	PRESENT	0
467437	466407	19575F	PARTICIPANT	\N	PRESENT	0
467438	466407	11031D	PARTICIPANT	\N	PRESENT	0
467439	466407	08052W	PARTICIPANT	\N	PRESENT	0
467440	466407	10006L	PARTICIPANT	\N	PRESENT	0
467441	466407	14042U	PARTICIPANT	\N	PRESENT	0
467442	466407	14087W	PARTICIPANT	\N	PRESENT	0
467443	466407	08048B	PARTICIPANT	\N	PRESENT	0
467444	466407	19565D	PARTICIPANT	\N	PRESENT	0
467445	466407	14026U	PARTICIPANT	\N	EXCUSE	0
467446	466407	19691J	PARTICIPANT	\N	PRESENT	0
467447	466407	19553Y	PARTICIPANT	\N	PRESENT	0
467448	466407	19591F	PARTICIPANT	\N	PRESENT	0
467449	466407	19715Y	PARTICIPANT	\N	PRESENT	0
467450	466407	19723Y	PARTICIPANT	\N	PRESENT	0
467451	466407	19697Q	PARTICIPANT	\N	PRESENT	0
467452	466407	19657G	PARTICIPANT	\N	PRESENT	0
467453	466407	11067R	PARTICIPANT	\N	PRESENT	0
467454	466407	14071N	PARTICIPANT	\N	PRESENT	0
467455	466407	19679N	PARTICIPANT	\N	PRESENT	0
467456	466407	19798U	PARTICIPANT	\N	PRESENT	0
467457	466407	11097X	PARTICIPANT	\N	PRESENT	0
467458	466407	01034P	PARTICIPANT	\N	PRESENT	0
467459	466407	14239U	PARTICIPANT	\N	EXCUSE	0
467460	466407	19760E	PARTICIPANT	\N	EXCUSE	0
467461	466407	14261S	PARTICIPANT	\N	EXCUSE	0
467462	466407	19367Y	PARTICIPANT	\N	EXCUSE	0
467463	466407	19415P	PARTICIPANT	\N	EXCUSE	0
474659	474654	19507S	PARTICIPANT	\N	PRESENT	0
474660	474654	14033T	PARTICIPANT	\N	PRESENT	0
474661	474654	19467C	PARTICIPANT	\N	PRESENT	0
474662	474654	19782L	PARTICIPANT	\N	PRESENT	0
474663	474654	14207L	PARTICIPANT	\N	PRESENT	0
474664	474654	19441R	PARTICIPANT	\N	PRESENT	0
474665	474654	19563B	PARTICIPANT	\N	PRESENT	0
474666	474654	14257W	PARTICIPANT	\N	PRESENT	0
474667	474655	14357A	PARTICIPANT	\N	PRESENT	0
474668	474655	19782L	PARTICIPANT	\N	PRESENT	0
474669	474655	19507S	PARTICIPANT	\N	PRESENT	0
474670	474655	14033T	PARTICIPANT	\N	PRESENT	0
474671	474655	14115H	PARTICIPANT	\N	PRESENT	0
474672	474655	19467C	PARTICIPANT	\N	PRESENT	0
474673	474655	19563B	PARTICIPANT	\N	PRESENT	0
474674	474655	11090Q	PARTICIPANT	\N	PRESENT	0
474675	474655	19269X	PARTICIPANT	\N	PRESENT	0
474676	474655	14257W	PARTICIPANT	\N	PRESENT	0
474677	474655	19441R	PARTICIPANT	\N	PRESENT	0
474678	474657	19782L	PARTICIPANT	\N	PRESENT	0
474679	474657	19507S	PARTICIPANT	\N	PRESENT	0
474680	474657	14033T	PARTICIPANT	\N	PRESENT	0
474681	474657	08028W	PARTICIPANT	\N	PRESENT	0
474682	474657	11099A	PARTICIPANT	\N	PRESENT	0
474683	474657	19563B	PARTICIPANT	\N	PRESENT	0
474684	474657	14265W	PARTICIPANT	\N	PRESENT	0
474685	474657	14257W	PARTICIPANT	\N	PRESENT	0
474693	473479	14031R	PARTICIPANT	\N	PRESENT	0
474694	473479	19681G	PARTICIPANT	\N	PRESENT	0
474695	473479	19745F	PARTICIPANT	\N	PRESENT	0
474696	473479	19637C	PARTICIPANT	\N	PRESENT	0
474697	473479	19739H	PARTICIPANT	\N	PRESENT	0
474698	473479	19794Q	PARTICIPANT	\N	PRESENT	0
474699	473479	19387D	PARTICIPANT	\N	PRESENT	0
474700	473479	19820Y	PARTICIPANT	\N	PRESENT	0
474701	473479	19347U	PARTICIPANT	\N	PRESENT	0
474702	473479	14169X	PARTICIPANT	\N	PRESENT	0
474722	473480	19681G	PARTICIPANT	\N	PRESENT	0
474723	473480	19745F	PARTICIPANT	\N	PRESENT	0
474724	473480	14169X	PARTICIPANT	\N	PRESENT	0
474725	473480	19551W	PARTICIPANT	\N	PRESENT	0
474726	473480	19387D	PARTICIPANT	\N	PRESENT	0
474727	473480	19794Q	PARTICIPANT	\N	PRESENT	0
474728	473480	19739H	PARTICIPANT	\N	PRESENT	0
474729	473449	19383Y	PARTICIPANT	\N	PRESENT	0
474730	473449	14219Q	PARTICIPANT	\N	PRESENT	0
474731	473449	19387D	PARTICIPANT	\N	PRESENT	0
474732	473449	17583W	PARTICIPANT	\N	PRESENT	0
474733	473449	19794Q	PARTICIPANT	\N	PRESENT	0
474734	473449	19739H	PARTICIPANT	\N	PRESENT	0
474735	473449	19737F	PARTICIPANT	\N	PRESENT	0
474751	473499	19681G	PARTICIPANT	\N	PRESENT	0
474752	473499	19745F	PARTICIPANT	\N	PRESENT	0
474753	473499	19820Y	PARTICIPANT	\N	PRESENT	0
474754	473499	19737F	PARTICIPANT	\N	PRESENT	0
474755	473519	14031R	PARTICIPANT	\N	PRESENT	0
474756	473519	19820Y	PARTICIPANT	\N	PRESENT	0
474757	473519	19737F	PARTICIPANT	\N	PRESENT	0
474758	473519	19637C	PARTICIPANT	\N	PRESENT	0
474759	473519	14029X	PARTICIPANT	\N	PRESENT	0
474760	473519	19333N	PARTICIPANT	\N	PRESENT	0
474761	473519	19347U	PARTICIPANT	\N	PRESENT	0
474762	473519	19551W	PARTICIPANT	\N	PRESENT	0
474763	473464	19701S	PARTICIPANT	\N	PRESENT	0
474764	473464	19549D	PARTICIPANT	\N	PRESENT	0
474765	473464	17583W	PARTICIPANT	\N	PRESENT	0
474766	473464	19387D	PARTICIPANT	\N	PRESENT	0
474767	473464	04069P	PARTICIPANT	\N	PRESENT	0
474768	473464	19745F	PARTICIPANT	\N	PRESENT	0
474769	473464	19794Q	PARTICIPANT	\N	PRESENT	0
474770	473464	19637C	PARTICIPANT	\N	PRESENT	0
474771	473464	19333N	PARTICIPANT	\N	PRESENT	0
474772	473464	14051J	PARTICIPANT	\N	PRESENT	0
474773	473464	19347U	PARTICIPANT	\N	PRESENT	0
474774	473464	19737F	PARTICIPANT	\N	PRESENT	0
474775	473605	19701S	PARTICIPANT	\N	PRESENT	0
474776	473605	19549D	PARTICIPANT	\N	PRESENT	0
474777	473605	17583W	PARTICIPANT	\N	PRESENT	0
474778	473605	19387D	PARTICIPANT	\N	PRESENT	0
474779	473605	19745F	PARTICIPANT	\N	PRESENT	0
474780	473605	19794Q	PARTICIPANT	\N	PRESENT	0
474781	473605	19637C	PARTICIPANT	\N	PRESENT	0
474782	473605	19347U	PARTICIPANT	\N	PRESENT	0
474783	473605	19820Y	PARTICIPANT	\N	PRESENT	0
474784	473605	19737F	PARTICIPANT	\N	PRESENT	0
474788	474787	19637C	PARTICIPANT	\N	PRESENT	0
474789	474787	14051J	PARTICIPANT	\N	PRESENT	0
474790	474787	02002K	PARTICIPANT	\N	PRESENT	0
474791	474787	04069P	PARTICIPANT	\N	PRESENT	0
474792	474787	19794Q	PARTICIPANT	\N	PRESENT	0
474793	474787	19347U	PARTICIPANT	\N	PRESENT	0
474794	474787	19820Y	PARTICIPANT	\N	PRESENT	0
474795	474787	19733B	PARTICIPANT	\N	PRESENT	0
478386	477841	19553Y	PARTICIPANT	\N	PRESENT	0
478387	477841	17779H	PARTICIPANT	\N	PRESENT	0
478388	477841	11097X	PARTICIPANT	\N	PRESENT	0
478389	477841	19715Y	PARTICIPANT	\N	PRESENT	0
478397	477841	14195A	PARTICIPANT	\N	PRESENT	0
478399	477841	19703U	PARTICIPANT	\N	PRESENT	0
478412	477841	01034P	PARTICIPANT	\N	PRESENT	0
478413	477841	19760E	PARTICIPANT	\N	PRESENT	0
478414	477841	14217N	PARTICIPANT	\N	PRESENT	0
478415	477841	19415P	PARTICIPANT	\N	PRESENT	0
478416	477841	14223L	PARTICIPANT	\N	PRESENT	0
478417	477841	10006L	PARTICIPANT	\N	PRESENT	0
478435	477841	19717B	PARTICIPANT	\N	PRESENT	0
478436	477841	19663E	PARTICIPANT	\N	PRESENT	0
478437	477841	19575F	PARTICIPANT	\N	PRESENT	0
478492	477703	11074Q	PRESIDENT	1	PRESENT	0
478493	477703	01057W	PARTICIPANT	\N	PRESENT	0
478494	477703	11012A	PARTICIPANT	\N	EXCUSE	0
478510	477841	19521Q	PARTICIPANT	\N	PRESENT	0
478511	477841	14087W	PARTICIPANT	\N	PRESENT	0
478556	476592	14026U	PARTICIPANT	\N	EXCUSE	0
478881	477621	14231L	PARTICIPANT	\N	EXCUSE	0
478882	477621	19735D	PARTICIPANT	\N	EXCUSE	0
478972	478425	19701S	PARTICIPANT	\N	PRESENT	0
478973	478425	08024S	PARTICIPANT	\N	PRESENT	0
478974	478425	19637C	PARTICIPANT	\N	PRESENT	0
478975	478425	14221J	PARTICIPANT	\N	PRESENT	0
478976	478425	14157T	PARTICIPANT	\N	PRESENT	0
478977	478425	19737F	PARTICIPANT	\N	PRESENT	0
478978	478425	19794Q	PARTICIPANT	\N	PRESENT	0
478979	478425	19713W	PARTICIPANT	\N	PRESENT	0
478991	477621	08038Y	PARTICIPANT	\N	EXCUSE	0
478992	477621	01057W	PARTICIPANT	\N	PRESENT	0
479009	477743	19585H	PARTICIPANT	\N	PRESENT	0
479010	477743	19673G	PARTICIPANT	\N	PRESENT	0
479011	477743	19719D	PRESIDENT	0	PRESENT	0
479014	477842	19527W	PARTICIPANT	\N	PRESENT	0
479015	477842	01034P	PARTICIPANT	\N	PRESENT	0
479016	477842	11067R	PARTICIPANT	\N	PRESENT	0
479017	477842	19798U	PARTICIPANT	\N	PRESENT	0
479018	477842	08052W	PARTICIPANT	\N	PRESENT	0
479019	477842	11031D	PARTICIPANT	\N	PRESENT	0
479020	477842	14119M	PARTICIPANT	\N	PRESENT	0
479021	477842	11103C	PARTICIPANT	\N	PRESENT	0
479022	477842	14042U	PARTICIPANT	\N	PRESENT	0
479023	477842	19575F	PARTICIPANT	\N	PRESENT	0
479024	477842	14213J	PARTICIPANT	\N	PRESENT	0
479025	477842	19657G	PARTICIPANT	\N	PRESENT	0
479026	477842	19760E	PARTICIPANT	\N	PRESENT	0
479027	477842	11097X	PRESIDENT	0	PRESENT	0
479030	477842	10006L	PARTICIPANT	\N	PRESENT	0
479031	477842	19691J	PARTICIPANT	\N	PRESENT	0
479032	477842	11045K	PARTICIPANT	\N	PRESENT	0
479042	479041	08011M	PARTICIPANT	\N	PRESENT	0
479043	477988	11070L	PARTICIPANT	\N	PRESENT	0
479044	477988	11040E	PARTICIPANT	\N	PRESENT	0
479045	477988	19737F	PARTICIPANT	\N	PRESENT	0
479046	477988	19711U	PARTICIPANT	\N	PRESENT	0
479073	477621	19489J	PARTICIPANT	\N	PRESENT	0
479074	477621	11048N	PARTICIPANT	\N	PRESENT	0
479075	477621	04086Q	PARTICIPANT	\N	PRESENT	0
479076	477621	14281W	PARTICIPANT	\N	PRESENT	0
479077	477621	05012A	PARTICIPANT	\N	PRESENT	0
479078	477621	19820Y	PARTICIPANT	\N	PRESENT	0
479079	477621	14069U	PARTICIPANT	\N	PRESENT	0
479080	477621	08010L	PARTICIPANT	\N	PRESENT	0
479081	477621	95067Q	PARTICIPANT	\N	PRESENT	0
479083	477743	11026G	PARTICIPANT	\N	PRESENT	0
479084	477743	04040A	PARTICIPANT	\N	PRESENT	0
479085	477743	08053X	PARTICIPANT	\N	PRESENT	0
479086	477743	08010L	PARTICIPANT	\N	PRESENT	0
479087	477743	04044E	PARTICIPANT	\N	PRESENT	0
479132	479125	08044W	PARTICIPANT	\N	PRESENT	0
479133	479125	14065Q	PARTICIPANT	\N	PRESENT	0
479136	477744	19421M	PARTICIPANT	\N	PRESENT	0
479137	477744	11026G	PARTICIPANT	\N	PRESENT	0
462658	462657	19709B	PARTICIPANT	\N	PRESENT	0
462660	462659	19709B	PARTICIPANT	\N	PRESENT	0
462661	462659	11027H	PARTICIPANT	\N	PRESENT	0
462663	462662	11027H	PARTICIPANT	\N	PRESENT	0
462665	462664	11027H	PARTICIPANT	\N	PRESENT	0
469712	468731	19319Q	PARTICIPANT	\N	PRESENT	0
469713	468731	14105F	PARTICIPANT	\N	PRESENT	0
469714	468731	98018T	PARTICIPANT	\N	PRESENT	0
469715	468731	98022P	PARTICIPANT	\N	PRESENT	0
469716	468731	14267Y	PARTICIPANT	\N	PRESENT	0
469717	468731	11064N	PARTICIPANT	\N	PRESENT	0
469718	468731	98050T	PARTICIPANT	\N	PRESENT	0
469719	468731	14255U	PARTICIPANT	\N	PRESENT	0
469721	467278	86034E	PARTICIPANT	\N	PRESENT	0
469722	467278	08069G	PARTICIPANT	\N	PRESENT	0
469723	467278	19369B	PARTICIPANT	\N	PRESENT	0
469724	467278	11083R	PARTICIPANT	\N	PRESENT	0
469725	467278	19253P	PARTICIPANT	\N	PRESENT	0
469726	467278	11031D	PARTICIPANT	\N	PRESENT	0
469727	467278	19549D	PARTICIPANT	\N	PRESENT	0
469728	467278	14239U	PARTICIPANT	\N	PRESENT	0
469729	467278	08010L	PARTICIPANT	\N	PRESENT	0
469730	467278	19599P	PARTICIPANT	\N	PRESENT	0
469731	467278	14030Q	PARTICIPANT	\N	PRESENT	0
469732	467278	11074Q	PARTICIPANT	\N	PRESENT	0
469733	467278	14021P	PARTICIPANT	\N	PRESENT	0
469734	467278	95063L	PARTICIPANT	\N	PRESENT	0
469735	467278	14051J	PARTICIPANT	\N	PRESENT	0
469736	467278	14151M	PARTICIPANT	\N	PRESENT	0
469737	467278	19543W	PARTICIPANT	\N	PRESENT	0
469738	467278	11072N	PARTICIPANT	\N	PRESENT	0
469739	467278	11110B	PARTICIPANT	\N	PRESENT	0
469740	467278	08061X	PARTICIPANT	\N	PRESENT	0
469741	467278	14089Y	PARTICIPANT	\N	PRESENT	0
469742	467278	19739H	PARTICIPANT	\N	PRESENT	0
469743	467278	04040A	PARTICIPANT	\N	PRESENT	0
469744	467278	14133K	PARTICIPANT	\N	PRESENT	0
469745	467278	11085T	PARTICIPANT	\N	PRESENT	0
469746	467278	08009T	PARTICIPANT	\N	PRESENT	0
469747	467278	01043Q	PARTICIPANT	\N	PRESENT	0
469748	467278	11012A	PARTICIPANT	\N	PRESENT	0
469749	467278	89017R	PARTICIPANT	\N	PRESENT	0
469750	467278	04086Q	PARTICIPANT	\N	PRESENT	0
469751	467278	07029T	PARTICIPANT	\N	PRESENT	0
469752	467278	11097X	PARTICIPANT	\N	PRESENT	0
469753	467278	04042C	PARTICIPANT	\N	PRESENT	0
469754	467278	19741B	PARTICIPANT	\N	PRESENT	0
469755	467278	05012A	PARTICIPANT	\N	PRESENT	0
469756	467278	19794Q	PARTICIPANT	\N	PRESENT	0
469757	467278	19675J	PARTICIPANT	\N	PRESENT	0
469758	467278	19701S	PARTICIPANT	\N	PRESENT	0
469759	467278	14157T	PARTICIPANT	\N	PRESENT	0
469760	467278	04047H	PARTICIPANT	\N	PRESENT	0
469761	467278	14031R	PARTICIPANT	\N	PRESENT	0
469762	467278	11090Q	PARTICIPANT	\N	PRESENT	0
469763	467278	04033B	PARTICIPANT	\N	PRESENT	0
469764	467278	19747H	PARTICIPANT	\N	PRESENT	0
469765	467278	14071N	PARTICIPANT	\N	PRESENT	0
469766	467278	95041E	PARTICIPANT	\N	PRESENT	0
469767	467278	19667J	PARTICIPANT	\N	PRESENT	0
469768	467278	04085P	PARTICIPANT	\N	PRESENT	0
469770	467278	19647E	PARTICIPANT	\N	PRESENT	0
469771	467278	14251Q	PARTICIPANT	\N	PRESENT	0
470348	468972	19659J	PARTICIPANT	\N	PRESENT	0
470349	468972	11054L	PARTICIPANT	\N	PRESENT	0
470350	468972	19301E	PARTICIPANT	\N	PRESENT	0
470400	468732	04042C	PRESIDENT	0	PRESENT	0
470402	468732	95030B	PARTICIPANT	\N	PRESENT	0
470403	468732	04034C	PARTICIPANT	\N	PRESENT	0
470404	468732	04040A	PARTICIPANT	\N	PRESENT	0
470405	468732	01058X	PARTICIPANT	\N	PRESENT	0
470406	468732	11027H	PARTICIPANT	\N	PRESENT	0
470407	468732	11054L	PARTICIPANT	\N	PRESENT	0
470408	468732	11066Q	PARTICIPANT	\N	PRESENT	0
470409	468732	11115U	PARTICIPANT	\N	PRESENT	0
470410	468732	19421M	PARTICIPANT	\N	PRESENT	0
470411	468732	19709B	PARTICIPANT	\N	PRESENT	0
470412	468732	14193X	PARTICIPANT	\N	PRESENT	0
470413	468732	08049C	PARTICIPANT	\N	PRESENT	0
470414	468732	08053X	PARTICIPANT	\N	PRESENT	0
470415	468732	97011G	PARTICIPANT	\N	PRESENT	0
470416	468732	08047A	PARTICIPANT	\N	PRESENT	0
470417	468732	98029W	PARTICIPANT	\N	PRESENT	0
470418	468732	04035D	PARTICIPANT	\N	PRESENT	0
470419	468732	95067Q	PARTICIPANT	\N	PRESENT	0
470420	468732	14133K	PARTICIPANT	\N	PRESENT	0
470421	468732	01062T	PARTICIPANT	\N	PRESENT	0
470422	468732	08058D	PARTICIPANT	\N	PRESENT	0
470423	468732	19251M	PARTICIPANT	\N	PRESENT	0
470424	468732	19721W	PARTICIPANT	\N	PRESENT	0
470425	468732	14105F	PARTICIPANT	\N	PRESENT	0
470426	468732	98018T	PARTICIPANT	\N	PRESENT	0
470427	468732	98022P	PARTICIPANT	\N	PRESENT	0
470428	468732	14267Y	PARTICIPANT	\N	PRESENT	0
470429	468732	11064N	PARTICIPANT	\N	PRESENT	0
470430	468732	98050T	PARTICIPANT	\N	PRESENT	0
470431	468732	14255U	PARTICIPANT	\N	PRESENT	0
470432	468732	08056B	PARTICIPANT	\N	EXCUSE	0
471060	467271	11027H	PARTICIPANT	\N	PRESENT	0
471126	467271	04059M	PARTICIPANT	\N	PRESENT	0
471160	467271	14041T	PARTICIPANT	\N	PRESENT	0
471128	467271	14109K	PARTICIPANT	\N	PRESENT	0
471129	467271	19866P	PARTICIPANT	\N	PRESENT	0
471130	470543	04086Q	PARTICIPANT	\N	PRESENT	0
471131	470543	07029T	PARTICIPANT	\N	PRESENT	0
471132	470543	14331P	PARTICIPANT	\N	PRESENT	0
471174	467271	14055N	PARTICIPANT	\N	PRESENT	0
471134	470543	19647E	PARTICIPANT	\N	PRESENT	0
471175	467271	19611R	PARTICIPANT	\N	PRESENT	0
471137	470543	19531S	PARTICIPANT	\N	PRESENT	0
471138	470543	19741B	PARTICIPANT	\N	PRESENT	0
471139	470543	08011M	PARTICIPANT	\N	PRESENT	0
471140	470543	19667J	PARTICIPANT	\N	PRESENT	0
471141	470543	11074Q	PRESIDENT	0	PRESENT	0
471142	467271	11083R	PARTICIPANT	\N	PRESENT	0
471143	467271	14231L	PARTICIPANT	\N	PRESENT	0
471144	467271	04057K	PARTICIPANT	\N	PRESENT	0
471145	467271	19673G	PARTICIPANT	\N	PRESENT	0
471146	467271	14205J	PARTICIPANT	\N	PRESENT	0
471147	467271	14179A	PARTICIPANT	\N	PRESENT	0
471148	467271	19758L	PARTICIPANT	\N	PRESENT	0
471149	467271	14237S	PARTICIPANT	\N	PRESENT	0
471150	467271	19593H	PARTICIPANT	\N	PRESENT	0
471151	467271	14157T	PARTICIPANT	\N	PRESENT	0
471152	467271	19749K	PARTICIPANT	\N	PRESENT	0
471153	467271	14031R	PARTICIPANT	\N	PRESENT	0
471154	467271	14147R	PARTICIPANT	\N	PRESENT	0
471155	467271	19631V	PARTICIPANT	\N	PRESENT	0
471156	467271	19693L	PARTICIPANT	\N	PRESENT	0
471158	467271	14259Y	PARTICIPANT	\N	PRESENT	0
471159	467271	07033P	PARTICIPANT	\N	PRESENT	0
471161	467271	19709B	PARTICIPANT	\N	PRESENT	0
471162	467271	19399H	PARTICIPANT	\N	PRESENT	0
471163	467271	14135M	PARTICIPANT	\N	PRESENT	0
471185	470543	01048V	PARTICIPANT	\N	PRESENT	0
471165	470543	89017R	PARTICIPANT	\N	PRESENT	0
471166	470543	19447X	PARTICIPANT	\N	PRESENT	0
471167	470543	14121F	PARTICIPANT	\N	PRESENT	0
471168	467271	14021P	PARTICIPANT	\N	PRESENT	0
471169	467271	19333N	PARTICIPANT	\N	PRESENT	0
471170	467271	11115U	PARTICIPANT	\N	PRESENT	0
471171	470543	08010L	PARTICIPANT	\N	PRESENT	0
471172	467271	19533U	PARTICIPANT	\N	PRESENT	0
471186	470543	19545Y	PARTICIPANT	\N	PRESENT	0
471187	470543	01057W	PARTICIPANT	\N	PRESENT	0
471188	470543	19671E	PARTICIPANT	\N	PRESENT	0
471189	470543	14225N	PARTICIPANT	\N	PRESENT	0
471190	470543	88008L	PARTICIPANT	\N	PRESENT	0
471191	470543	11110B	PARTICIPANT	\N	PRESENT	0
471192	470543	14085U	PARTICIPANT	\N	PRESENT	0
471193	470543	19349W	PARTICIPANT	\N	PRESENT	0
471194	470543	19479G	PARTICIPANT	\N	PRESENT	0
471195	470543	19711U	PARTICIPANT	\N	PRESENT	0
471196	470543	08034U	PARTICIPANT	\N	PRESENT	0
471197	470543	19689Q	PARTICIPANT	\N	PRESENT	0
471198	470543	11040E	PARTICIPANT	\N	PRESENT	0
471199	470543	99004R	PARTICIPANT	\N	PRESENT	0
471200	467271	19479G	PARTICIPANT	\N	PRESENT	0
471201	467271	19531S	PARTICIPANT	\N	PRESENT	0
471202	467271	14331P	PARTICIPANT	\N	PRESENT	0
471203	467271	04033B	PARTICIPANT	\N	PRESENT	0
471204	467271	14123H	PARTICIPANT	\N	PRESENT	0
471205	467271	19591F	PARTICIPANT	\N	PRESENT	0
471206	467271	89017R	PARTICIPANT	\N	PRESENT	0
477571	475690	01062T	PARTICIPANT	\N	PRESENT	0
477572	475690	11041F	PARTICIPANT	\N	PRESENT	0
477573	475690	11066Q	PARTICIPANT	\N	PRESENT	0
477574	475690	95067Q	PARTICIPANT	\N	PRESENT	0
477575	475783	19515S	PARTICIPANT	\N	PRESENT	0
477576	475783	08024S	PARTICIPANT	\N	PRESENT	0
477577	476047	14069U	PARTICIPANT	\N	PRESENT	0
477578	475783	14147R	PARTICIPANT	\N	PRESENT	0
477580	475783	19349W	PARTICIPANT	\N	PRESENT	0
477582	476047	05012A	PARTICIPANT	\N	PRESENT	0
477583	475690	14028W	PARTICIPANT	\N	EXCUSE	0
477584	475690	98022P	PARTICIPANT	\N	EXCUSE	0
477585	475690	08049C	PARTICIPANT	\N	EXCUSE	0
477592	476047	14231L	PARTICIPANT	\N	EXCUSE	0
477593	476047	04044E	PARTICIPANT	\N	EXCUSE	0
477595	477594	96004D	PRESIDENT	0	PRESENT	0
477596	477594	14089Y	PARTICIPANT	\N	PRESENT	0
477597	477594	11083R	PARTICIPANT	\N	PRESENT	0
477598	477594	98035U	PARTICIPANT	\N	PRESENT	0
477622	477621	04040A	PRESIDENT	0	PRESENT	0
477623	474482	14030Q	PRESIDENT	0	PRESENT	0
477624	474482	08043V	PARTICIPANT	\N	EXCUSE	0
477625	474482	19643A	PARTICIPANT	\N	PRESENT	0
477626	474482	19621T	PARTICIPANT	\N	PRESENT	0
477627	474482	08020N	PARTICIPANT	\N	PRESENT	0
477628	474482	18083K	PARTICIPANT	\N	PRESENT	0
477629	474482	19701S	PARTICIPANT	\N	PRESENT	0
477630	474482	11031D	PARTICIPANT	\N	PRESENT	0
477631	474482	80013X	PARTICIPANT	\N	PRESENT	0
477632	474482	19693L	PARTICIPANT	\N	PRESENT	0
477633	474482	19599P	PARTICIPANT	\N	EXCUSE	0
477634	474482	04035D	PARTICIPANT	\N	PRESENT	0
477635	474482	14179A	PARTICIPANT	\N	PRESENT	0
477636	474482	19715Y	PARTICIPANT	\N	PRESENT	0
477637	474482	19731Y	PARTICIPANT	\N	PRESENT	0
477638	474482	08031R	PARTICIPANT	\N	PRESENT	0
477639	474482	07029T	PARTICIPANT	\N	EXCUSE	0
477640	474482	08017T	PARTICIPANT	\N	PRESENT	0
477641	474482	19657G	PARTICIPANT	\N	PRESENT	0
477642	474482	11067R	PARTICIPANT	\N	PRESENT	0
477643	474482	14109K	PARTICIPANT	\N	PRESENT	0
477644	474482	19269X	PARTICIPANT	\N	PRESENT	0
477645	474482	19749K	PARTICIPANT	\N	PRESENT	0
477646	476190	19651A	PARTICIPANT	\N	PRESENT	0
477647	476190	19741B	PARTICIPANT	\N	PRESENT	0
477648	476190	11040E	PARTICIPANT	\N	PRESENT	0
477649	476190	14083S	PARTICIPANT	\N	PRESENT	0
477650	476190	11053K	PARTICIPANT	\N	PRESENT	0
477651	476190	19545Y	PARTICIPANT	\N	PRESENT	0
477652	476190	14327T	PARTICIPANT	\N	PRESENT	0
477653	476190	07004J	PARTICIPANT	\N	PRESENT	0
477654	476190	11048N	PARTICIPANT	\N	PRESENT	0
477655	476190	14121F	PARTICIPANT	\N	PRESENT	0
477656	476190	99004R	PARTICIPANT	\N	PRESENT	0
477657	476190	19671E	PARTICIPANT	\N	PRESENT	0
477658	476190	19349W	PARTICIPANT	\N	PRESENT	0
477659	476190	14331P	PARTICIPANT	\N	PRESENT	0
477660	476190	14225N	PARTICIPANT	\N	PRESENT	0
477661	476190	19479G	PARTICIPANT	\N	PRESENT	0
477662	476953	96004D	PRESIDENT	0	PRESENT	0
477663	476953	14033T	PARTICIPANT	\N	PRESENT	0
477664	476953	11083R	PARTICIPANT	\N	PRESENT	0
477665	476953	14225N	PARTICIPANT	\N	PRESENT	0
477666	476953	19553Y	PARTICIPANT	\N	PRESENT	0
477667	476953	14331P	PARTICIPANT	\N	PRESENT	0
477668	476953	14026U	PARTICIPANT	\N	PRESENT	0
477669	476953	14241N	PARTICIPANT	\N	PRESENT	0
477670	476953	19725B	PARTICIPANT	\N	PRESENT	0
477671	476953	19569H	PARTICIPANT	\N	PRESENT	0
477672	476953	10015M	PARTICIPANT	\N	PRESENT	0
477673	476953	14073Q	PARTICIPANT	\N	PRESENT	0
477674	476953	14357A	PARTICIPANT	\N	PRESENT	0
477675	476953	14079W	PARTICIPANT	\N	PRESENT	0
477676	476953	04035D	PARTICIPANT	\N	PRESENT	0
477677	476953	14097Y	PARTICIPANT	\N	PRESENT	0
477678	476953	14229S	PARTICIPANT	\N	PRESENT	0
477679	476953	12041X	PARTICIPANT	\N	PRESENT	0
477680	476953	14089Y	PARTICIPANT	\N	PRESENT	0
477681	476953	11026G	PARTICIPANT	\N	PRESENT	0
477682	476953	19563B	PARTICIPANT	\N	PRESENT	0
477683	476953	01058X	PARTICIPANT	\N	PRESENT	0
477684	476953	19387D	PARTICIPANT	\N	PRESENT	0
477685	476953	14255U	PARTICIPANT	\N	PRESENT	0
477686	476953	08011M	PARTICIPANT	\N	PRESENT	0
477687	476953	98050T	PARTICIPANT	\N	PRESENT	0
477688	476953	04034C	PARTICIPANT	\N	PRESENT	0
477689	476953	04044E	PARTICIPANT	\N	PRESENT	0
477690	476953	08015R	PARTICIPANT	\N	PRESENT	0
477691	476953	97011G	PARTICIPANT	\N	PRESENT	0
477696	477694	14187A	PARTICIPANT	\N	PRESENT	0
477697	477694	14081Q	PARTICIPANT	\N	PRESENT	0
477699	477698	14187A	PARTICIPANT	\N	PRESENT	0
477700	477698	14081Q	PARTICIPANT	\N	PRESENT	0
477801	477799	11070L	PARTICIPANT	\N	PRESENT	0
477802	477799	11040E	PARTICIPANT	\N	PRESENT	0
477803	477799	19551W	PARTICIPANT	\N	PRESENT	0
477804	477799	14205J	PARTICIPANT	\N	PRESENT	0
477806	477805	11040E	PARTICIPANT	\N	PRESENT	0
477807	477805	11070L	PARTICIPANT	\N	PRESENT	0
477808	477805	19711U	PARTICIPANT	\N	PRESENT	0
477809	477805	19551W	PARTICIPANT	\N	PRESENT	0
477926	477843	19577H	PARTICIPANT	\N	PRESENT	0
477927	477843	08019V	PARTICIPANT	\N	PRESENT	0
477928	477851	19717B	PARTICIPANT	\N	PRESENT	0
477929	477851	08019V	PARTICIPANT	\N	PRESENT	0
477930	477692	14135M	PARTICIPANT	\N	EXCUSE	0
477931	477844	14261S	PARTICIPANT	\N	PRESENT	0
477932	477844	08019V	PARTICIPANT	\N	PRESENT	0
478334	477800	19415P	PARTICIPANT	\N	PRESENT	0
478335	477800	19657G	PARTICIPANT	\N	PRESENT	0
478336	477800	17779H	PARTICIPANT	\N	PRESENT	0
478337	477800	19798U	PARTICIPANT	\N	PRESENT	0
478338	477800	19703U	PARTICIPANT	\N	PRESENT	0
478339	477800	08052W	PARTICIPANT	\N	PRESENT	0
478340	477800	14042U	PARTICIPANT	\N	PRESENT	0
478341	477800	01034P	PARTICIPANT	\N	PRESENT	0
478342	477800	14147R	PARTICIPANT	\N	PRESENT	0
478495	477712	98022P	PARTICIPANT	\N	EXCUSE	0
478553	478512	19749K	PARTICIPANT	\N	PRESENT	0
478554	478512	14063N	PARTICIPANT	\N	PRESENT	0
478555	478512	92040Q	PARTICIPANT	\N	EXCUSE	0
478804	476592	19515S	PARTICIPANT	\N	PRESENT	0
478805	476592	19387D	PARTICIPANT	\N	PRESENT	0
478807	476592	19798U	PARTICIPANT	\N	PRESENT	0
478820	476592	19489J	PARTICIPANT	\N	PRESENT	0
478853	478850	08012N	PARTICIPANT	\N	PRESENT	0
478854	478850	19349W	PARTICIPANT	\N	PRESENT	0
478855	478850	19533U	PARTICIPANT	\N	PRESENT	0
478856	478850	11043H	PARTICIPANT	\N	PRESENT	0
478857	478850	02002K	PARTICIPANT	\N	PRESENT	0
478858	478850	19251M	PARTICIPANT	\N	PRESENT	0
478859	478850	14147R	PARTICIPANT	\N	PRESENT	0
478860	478850	19725B	PARTICIPANT	\N	PRESENT	0
478861	478850	19711U	PARTICIPANT	\N	PRESENT	0
478862	478850	14030Q	PARTICIPANT	\N	PRESENT	0
478875	478717	14267Y	PARTICIPANT	\N	PRESENT	0
478876	478717	14039A	PARTICIPANT	\N	PRESENT	0
478877	478717	11064N	PARTICIPANT	\N	PRESENT	0
478878	478717	16685X	PARTICIPANT	\N	PRESENT	0
479029	479028	14227Q	PARTICIPANT	\N	PRESENT	0
479096	479093	19760E	PARTICIPANT	\N	PRESENT	0
479097	479093	19697Q	PARTICIPANT	\N	PRESENT	0
479098	479093	11097X	PARTICIPANT	\N	PRESENT	0
479099	479093	19798U	PARTICIPANT	\N	PRESENT	0
479101	478990	11056N	PARTICIPANT	\N	PRESENT	0
479102	478990	19621T	PARTICIPANT	\N	PRESENT	0
479103	478990	19387D	PARTICIPANT	\N	PRESENT	0
479104	478990	19725B	PARTICIPANT	\N	PRESENT	0
479105	478990	19349W	PARTICIPANT	\N	PRESENT	0
479106	478990	19679N	PARTICIPANT	\N	PRESENT	0
479107	478990	19820Y	PARTICIPANT	\N	PRESENT	0
479122	477692	19631V	PARTICIPANT	\N	PRESENT	0
479118	477692	14261S	PARTICIPANT	\N	PRESENT	0
479121	477692	19717B	PARTICIPANT	\N	EXCUSE	0
479124	477692	19577H	PARTICIPANT	\N	PRESENT	0
479126	477692	08019V	PRESIDENT	0	PRESENT	0
479127	477692	19657G	PARTICIPANT	\N	PRESENT	0
479128	477692	11072N	PARTICIPANT	\N	PRESENT	0
479130	477692	11054L	PARTICIPANT	\N	EXCUSE	0
479131	477692	19715Y	PARTICIPANT	\N	PRESENT	0
479169	477743	19671E	PARTICIPANT	\N	PRESENT	0
479264	479263	04040A	PARTICIPANT	\N	PRESENT	0
479265	479263	14255U	PARTICIPANT	\N	PRESENT	0
479266	479263	04042C	PARTICIPANT	\N	PRESENT	0
479267	479263	19721W	PARTICIPANT	\N	PRESENT	0
479269	479263	11115U	PARTICIPANT	\N	PRESENT	0
479270	479263	95030B	PARTICIPANT	\N	PRESENT	0
479271	479263	97011G	PARTICIPANT	\N	PRESENT	0
479272	479263	16685X	PARTICIPANT	\N	PRESENT	0
460140	460139	96004D	PARTICIPANT	\N	PRESENT	0
460141	460139	95030B	PARTICIPANT	\N	PRESENT	0
462400	462399	04040A	PARTICIPANT	\N	PRESENT	0
462401	462399	18083K	PARTICIPANT	\N	PRESENT	0
462402	462399	14255U	PARTICIPANT	\N	PRESENT	0
462414	462413	11097X	PARTICIPANT	\N	PRESENT	0
462416	462415	01034P	PARTICIPANT	\N	PRESENT	0
462417	462415	11097X	PARTICIPANT	\N	PRESENT	0
462419	462418	01034P	PARTICIPANT	\N	PRESENT	0
462420	462418	11097X	PARTICIPANT	\N	PRESENT	0
462421	462418	19479G	PARTICIPANT	\N	PRESENT	0
462423	462422	11097X	PARTICIPANT	\N	PRESENT	0
462426	462425	19667J	PARTICIPANT	\N	PRESENT	0
462427	462425	11040E	PARTICIPANT	\N	PRESENT	0
462429	462428	19667J	PARTICIPANT	\N	PRESENT	0
462430	462428	11040E	PARTICIPANT	\N	PRESENT	0
466894	466833	19443T	PARTICIPANT	\N	PRESENT	0
466895	466833	12041X	PARTICIPANT	\N	PRESENT	0
466896	466833	95030B	PARTICIPANT	\N	PRESENT	0
466897	466833	04034C	PARTICIPANT	\N	PRESENT	0
466898	466833	01058X	PARTICIPANT	\N	PRESENT	0
466899	466833	04040A	PARTICIPANT	\N	PRESENT	0
466900	466833	11027H	PARTICIPANT	\N	PRESENT	0
466901	466833	16685X	PARTICIPANT	\N	PRESENT	0
466902	466833	04042C	PRESIDENT	0	PRESENT	0
466903	466833	11054L	PARTICIPANT	\N	PRESENT	0
466904	466833	11066Q	PARTICIPANT	\N	PRESENT	0
466905	466833	08056B	PARTICIPANT	\N	PRESENT	0
466906	466833	19709B	PARTICIPANT	\N	PRESENT	0
466907	466833	14193X	PARTICIPANT	\N	PRESENT	0
466908	466833	08053X	PARTICIPANT	\N	PRESENT	0
466909	466833	97011G	PARTICIPANT	\N	PRESENT	0
466910	466833	08047A	PARTICIPANT	\N	PRESENT	0
466911	466833	98029W	PARTICIPANT	\N	PRESENT	0
466912	466833	14097Y	PARTICIPANT	\N	PRESENT	0
466913	466833	95067Q	PARTICIPANT	\N	PRESENT	0
466914	466833	14133K	PARTICIPANT	\N	PRESENT	0
466915	466833	01062T	PARTICIPANT	\N	PRESENT	0
466916	466833	11041F	PARTICIPANT	\N	PRESENT	0
466917	466833	14235Q	PARTICIPANT	\N	PRESENT	0
466918	466833	19251M	PARTICIPANT	\N	PRESENT	0
466919	466833	14028W	PARTICIPANT	\N	PRESENT	0
466920	466833	14105F	PARTICIPANT	\N	PRESENT	0
466921	466833	14267Y	PARTICIPANT	\N	PRESENT	0
466922	466833	11064N	PARTICIPANT	\N	PRESENT	0
466923	466833	14255U	PARTICIPANT	\N	PRESENT	0
466924	466833	08049C	PARTICIPANT	\N	EXCUSE	0
466925	466833	98050T	PARTICIPANT	\N	EXCUSE	0
466926	466833	19583F	PARTICIPANT	\N	EXCUSE	0
466927	465833	14327T	PARTICIPANT	\N	PRESENT	0
466928	465833	14331P	PARTICIPANT	\N	PRESENT	0
466929	465833	11048N	PARTICIPANT	\N	PRESENT	0
466930	465833	19479G	PARTICIPANT	\N	PRESENT	0
466931	465833	19711U	PARTICIPANT	\N	PRESENT	0
466932	465833	19531S	PARTICIPANT	\N	PRESENT	0
466933	465833	01048V	PARTICIPANT	\N	PRESENT	0
466934	465833	01057W	PARTICIPANT	\N	PRESENT	0
466935	465833	19667J	PARTICIPANT	\N	PRESENT	0
466936	465833	11074Q	PRESIDENT	0	PRESENT	0
466937	465833	08011M	PARTICIPANT	\N	PRESENT	0
466938	465833	88008L	PARTICIPANT	\N	PRESENT	0
466939	465833	11040E	PARTICIPANT	\N	PRESENT	0
466940	465833	04086Q	PARTICIPANT	\N	PRESENT	0
466941	465833	11012A	PARTICIPANT	\N	PRESENT	0
466942	465833	14085U	PARTICIPANT	\N	PRESENT	0
466943	465833	19349W	PARTICIPANT	\N	PRESENT	0
466944	465833	08010L	PARTICIPANT	\N	PRESENT	0
466945	465833	19741B	PARTICIPANT	\N	PRESENT	0
466946	465833	99004R	PARTICIPANT	\N	PRESENT	0
467464	466407	11103C	PARTICIPANT	\N	EXCUSE	0
467465	466407	14195A	PARTICIPANT	\N	EXCUSE	0
467466	466407	19663E	PARTICIPANT	\N	EXCUSE	0
467467	466407	98024R	PARTICIPANT	\N	EXCUSE	0
467468	466407	14217N	PARTICIPANT	\N	EXCUSE	0
467469	466407	19577H	PARTICIPANT	\N	EXCUSE	0
467470	466407	14281W	PARTICIPANT	\N	EXCUSE	0
467471	466407	19521Q	PARTICIPANT	\N	EXCUSE	0
467472	466407	14355X	PARTICIPANT	\N	EXCUSE	0
467473	466407	08041T	PARTICIPANT	\N	EXCUSE	0
467474	466407	19727D	PARTICIPANT	\N	EXCUSE	0
467475	466407	19569H	PARTICIPANT	\N	EXCUSE	0
467476	466407	14213J	PARTICIPANT	\N	EXCUSE	0
467477	466407	19683J	PARTICIPANT	\N	EXCUSE	0
467478	466407	17779H	PARTICIPANT	\N	EXCUSE	0
467479	466407	14223L	PARTICIPANT	\N	EXCUSE	0
467480	466407	04092N	PRESIDENT	0	PRESENT	0
467481	466407	14119M	PARTICIPANT	\N	EXCUSE	0
467482	466407	11045K	PARTICIPANT	\N	EXCUSE	0
467483	466407	19703U	PARTICIPANT	\N	EXCUSE	0
467484	466407	19301E	PARTICIPANT	\N	EXCUSE	0
467485	466407	14227Q	PARTICIPANT	\N	EXCUSE	0
467486	466407	19527W	PARTICIPANT	\N	EXCUSE	0
467505	466389	14239U	PARTICIPANT	\N	EXCUSE	0
467506	466389	14261S	PARTICIPANT	\N	EXCUSE	0
467507	466389	19717B	PARTICIPANT	\N	EXCUSE	0
467508	466389	19367Y	PARTICIPANT	\N	EXCUSE	0
467509	466389	14217N	PARTICIPANT	\N	EXCUSE	0
467510	466389	19577H	PARTICIPANT	\N	EXCUSE	0
467511	466389	14281W	PARTICIPANT	\N	EXCUSE	0
467512	466389	14087W	PARTICIPANT	\N	EXCUSE	0
467513	466389	19521Q	PARTICIPANT	\N	EXCUSE	0
467514	466389	14355X	PARTICIPANT	\N	EXCUSE	0
467515	466389	08041T	PARTICIPANT	\N	EXCUSE	0
467516	466389	14026U	PARTICIPANT	\N	EXCUSE	0
467517	466389	19553Y	PARTICIPANT	\N	EXCUSE	0
467518	466389	19715Y	PARTICIPANT	\N	EXCUSE	0
467519	466389	14223L	PARTICIPANT	\N	EXCUSE	0
467520	466389	11045K	PARTICIPANT	\N	EXCUSE	0
467521	466389	19301E	PARTICIPANT	\N	EXCUSE	0
467522	466401	14261S	PARTICIPANT	\N	EXCUSE	0
467523	466401	19367Y	PARTICIPANT	\N	EXCUSE	0
467524	466401	19663E	PARTICIPANT	\N	EXCUSE	0
467525	466401	19521Q	PARTICIPANT	\N	EXCUSE	0
467526	466401	14355X	PARTICIPANT	\N	EXCUSE	0
467527	466401	08041T	PARTICIPANT	\N	EXCUSE	0
467528	466401	19727D	PARTICIPANT	\N	EXCUSE	0
467529	466401	11067R	PARTICIPANT	\N	EXCUSE	0
467530	466401	19301E	PARTICIPANT	\N	EXCUSE	0
467531	466401	14227Q	PARTICIPANT	\N	EXCUSE	0
467548	467547	18003S	PARTICIPANT	\N	EXCUSE	0
467551	467547	14093U	PARTICIPANT	\N	PRESENT	0
467552	467547	19693L	PARTICIPANT	\N	PRESENT	0
467554	467547	19553Y	PARTICIPANT	\N	PRESENT	0
467556	467547	19723Y	PARTICIPANT	\N	PRESENT	0
467557	467547	14221J	PARTICIPANT	\N	PRESENT	0
467558	467547	19593H	PARTICIPANT	\N	PRESENT	0
467559	467547	19533U	PARTICIPANT	\N	PRESENT	0
467560	467547	19503N	PARTICIPANT	\N	PRESENT	0
467561	467547	04043D	PARTICIPANT	\N	PRESENT	0
467562	467547	01058X	PARTICIPANT	\N	PRESENT	0
467565	467547	14299H	PARTICIPANT	\N	EXCUSE	0
467567	467547	01048V	PRESIDENT	0	PRESENT	0
467568	467547	80013X	PARTICIPANT	\N	EXCUSE	0
467569	467054	14261S	PARTICIPANT	\N	PRESENT	0
467570	467054	19717B	PARTICIPANT	\N	PRESENT	0
467571	467054	19631V	PARTICIPANT	\N	PRESENT	0
467572	467054	19577H	PARTICIPANT	\N	PRESENT	0
467573	467054	19715Y	PARTICIPANT	\N	PRESENT	0
467574	467054	98005N	PARTICIPANT	\N	PRESENT	0
467575	467054	14059S	PARTICIPANT	\N	PRESENT	0
467576	467054	12016W	PARTICIPANT	\N	PRESENT	0
467577	467054	08019V	PRESIDENT	0	PRESENT	0
467578	467054	11072N	PARTICIPANT	\N	PRESENT	0
467579	467054	19657G	PARTICIPANT	\N	PRESENT	0
467708	467707	14083S	PARTICIPANT	\N	PRESENT	0
467709	467707	14061L	PARTICIPANT	\N	PRESENT	0
467710	467707	14105F	PARTICIPANT	\N	PRESENT	0
467711	467707	14053L	PARTICIPANT	\N	PRESENT	0
467713	467712	14083S	PARTICIPANT	\N	PRESENT	0
467714	467712	14105F	PARTICIPANT	\N	PRESENT	0
467729	467532	14053L	PARTICIPANT	\N	PRESENT	0
467730	467532	19649G	PARTICIPANT	\N	PRESENT	0
467731	467532	19585H	PARTICIPANT	\N	PRESENT	0
467732	467532	04047H	PRESIDENT	1	PRESENT	0
467733	467532	19673G	PARTICIPANT	\N	PRESENT	0
467734	467532	01028R	PARTICIPANT	\N	PRESENT	0
467735	467532	11033F	PARTICIPANT	\N	PRESENT	0
467736	467532	05008E	PRESIDENT	0	PRESENT	0
467737	467532	95063L	PARTICIPANT	\N	PRESENT	0
467738	467532	19629C	PARTICIPANT	\N	PRESENT	0
467739	467532	08044W	PARTICIPANT	\N	PRESENT	0
467740	467532	14215L	PARTICIPANT	\N	PRESENT	0
467741	467532	11085T	PARTICIPANT	\N	PRESENT	0
475655	473557	14069U	PARTICIPANT	\N	PRESENT	0
475672	473557	08049C	PARTICIPANT	\N	EXCUSE	0
475747	474303	01048V	PARTICIPANT	\N	PRESENT	0
475748	474303	80013X	PARTICIPANT	\N	PRESENT	0
475749	474303	19723Y	PARTICIPANT	\N	PRESENT	0
475750	474303	14221J	PARTICIPANT	\N	PRESENT	0
475751	474303	19533U	PARTICIPANT	\N	PRESENT	0
475752	474303	19503N	PARTICIPANT	\N	PRESENT	0
475753	474303	04043D	PARTICIPANT	\N	PRESENT	0
475754	474303	01058X	PARTICIPANT	\N	PRESENT	0
475755	474303	14093U	PARTICIPANT	\N	EXCUSE	0
475756	474303	19693L	PARTICIPANT	\N	EXCUSE	0
475757	474303	19593H	PARTICIPANT	\N	EXCUSE	0
476464	476463	05008E	PARTICIPANT	\N	PRESENT	0
476465	476463	14041T	PARTICIPANT	\N	PRESENT	0
476466	476463	01024M	PARTICIPANT	\N	PRESENT	0
476470	476469	05008E	PARTICIPANT	\N	PRESENT	0
476471	476469	14041T	PARTICIPANT	\N	PRESENT	0
476472	476469	08018U	PARTICIPANT	\N	PRESENT	0
476473	476469	11026G	PARTICIPANT	\N	PRESENT	0
479138	477744	08010L	PARTICIPANT	\N	PRESENT	0
479139	477744	19671E	PARTICIPANT	\N	PRESENT	0
479140	477744	19719D	PRESIDENT	0	PRESENT	0
479141	477744	19673G	PARTICIPANT	\N	PRESENT	0
479222	479094	14071N	PARTICIPANT	\N	EXCUSE	0
479228	476533	08062Y	PARTICIPANT	\N	EXCUSE	0
479229	476533	19651A	PARTICIPANT	\N	EXCUSE	0
479230	477745	08053X	PARTICIPANT	\N	PRESENT	0
479231	477745	19673G	PARTICIPANT	\N	PRESENT	0
479232	477745	19719D	PRESIDENT	0	PRESENT	0
479233	477745	04040A	PARTICIPANT	\N	PRESENT	0
479235	479033	11104D	PARTICIPANT	\N	EXCUSE	0
479236	479033	08049C	PARTICIPANT	\N	PRESENT	0
479237	479033	19335Q	PRESIDENT	0	PRESENT	0
479238	479034	11104D	PARTICIPANT	\N	EXCUSE	0
479239	479034	08049C	PARTICIPANT	\N	PRESENT	0
479240	479034	19335Q	PRESIDENT	0	PRESENT	0
479241	476595	11104D	PARTICIPANT	\N	EXCUSE	0
479242	476595	19335Q	PRESIDENT	0	PRESENT	0
479243	476595	08049C	PARTICIPANT	\N	PRESENT	0
479278	476533	11066Q	PARTICIPANT	\N	PRESENT	0
479279	476533	19349W	PARTICIPANT	\N	EXCUSE	0
479280	476533	19369B	PARTICIPANT	\N	PRESENT	0
479301	479182	14033T	PARTICIPANT	\N	PRESENT	0
479302	479182	14241N	PARTICIPANT	\N	PRESENT	0
479303	479182	08039A	PARTICIPANT	\N	PRESENT	0
479305	479182	14205J	PARTICIPANT	\N	PRESENT	0
479306	479182	14026U	PARTICIPANT	\N	PRESENT	0
479319	476533	19515S	PARTICIPANT	\N	EXCUSE	0
479320	479033	19619A	PARTICIPANT	\N	PRESENT	0
479321	476595	19619A	PARTICIPANT	\N	EXCUSE	0
479374	479367	14089Y	PARTICIPANT	\N	PRESENT	0
479375	479367	95063L	PARTICIPANT	\N	PRESENT	0
479376	479367	14041T	PARTICIPANT	\N	PRESENT	0
479377	479367	19447X	PARTICIPANT	\N	PRESENT	0
479378	479367	05008E	PRESIDENT	0	PRESENT	0
479379	479367	11085T	PARTICIPANT	\N	PRESENT	0
479383	479367	14231L	PARTICIPANT	\N	EXCUSE	0
479398	479384	14039A	PARTICIPANT	\N	PRESENT	0
479399	479384	14267Y	PRESIDENT	0	PRESENT	0
479401	479384	04086Q	PARTICIPANT	\N	PRESENT	0
479402	479384	19729F	PARTICIPANT	\N	PRESENT	0
479403	479384	19629C	PARTICIPANT	\N	PRESENT	0
479404	479384	11064N	PARTICIPANT	\N	PRESENT	0
479405	479384	19695N	PARTICIPANT	\N	PRESENT	0
479406	479384	19715Y	PARTICIPANT	\N	PRESENT	0
479410	479384	19525U	PARTICIPANT	\N	PRESENT	0
479420	479234	19629C	PARTICIPANT	\N	PRESENT	0
479421	479234	14267Y	PARTICIPANT	\N	PRESENT	0
479423	479234	19525U	PARTICIPANT	\N	PRESENT	0
479424	479234	04086Q	PARTICIPANT	\N	PRESENT	0
479425	479234	14217N	PARTICIPANT	\N	PRESENT	0
479426	479234	19695N	PARTICIPANT	\N	PRESENT	0
479427	479234	19715Y	PARTICIPANT	\N	PRESENT	0
479428	479234	14039A	PARTICIPANT	\N	PRESENT	0
479429	479234	11064N	PARTICIPANT	\N	PRESENT	0
479430	479234	19729F	PARTICIPANT	\N	PRESENT	0
479431	479234	16685X	PARTICIPANT	\N	PRESENT	0
479432	479384	14059S	PARTICIPANT	\N	EXCUSE	0
479433	479089	04059M	PARTICIPANT	\N	PRESENT	0
479440	479089	14041T	PARTICIPANT	\N	PRESENT	0
479447	479089	04085P	PARTICIPANT	\N	PRESENT	0
479448	479089	19766L	PARTICIPANT	\N	PRESENT	0
479449	479089	19693L	PARTICIPANT	\N	PRESENT	0
479450	479089	11012A	PARTICIPANT	\N	PRESENT	0
479451	479089	19563B	PARTICIPANT	\N	PRESENT	0
479453	479089	19651A	PARTICIPANT	\N	PRESENT	0
479456	479089	05008E	PARTICIPANT	\N	PRESENT	0
479457	479089	19447X	PARTICIPANT	\N	PRESENT	0
479458	479089	11099A	PARTICIPANT	\N	PRESENT	0
479459	479089	08019V	PARTICIPANT	\N	PRESENT	0
479460	479089	19675J	PARTICIPANT	\N	PRESENT	0
479461	479089	01028R	PARTICIPANT	\N	PRESENT	0
479462	479089	11033F	PARTICIPANT	\N	PRESENT	0
479463	479089	14089Y	PARTICIPANT	\N	PRESENT	0
479464	479089	14021P	PARTICIPANT	\N	PRESENT	0
479465	479089	19631V	PARTICIPANT	\N	PRESENT	0
479466	479089	19647E	PARTICIPANT	\N	PRESENT	0
479467	479089	04033B	PARTICIPANT	\N	PRESENT	0
479495	479089	14039A	PARTICIPANT	\N	PRESENT	0
479496	479089	19695N	PARTICIPANT	\N	PRESENT	0
479497	479089	08010L	PARTICIPANT	\N	PRESENT	0
479498	479089	11031D	PARTICIPANT	\N	PRESENT	0
479499	479089	19621T	PARTICIPANT	\N	PRESENT	0
479500	479089	14267Y	PARTICIPANT	\N	PRESENT	0
479535	479400	19629C	PARTICIPANT	\N	PRESENT	0
479536	479400	14147R	PARTICIPANT	\N	PRESENT	0
479537	479400	01024M	PARTICIPANT	\N	PRESENT	0
479539	479090	11033F	PARTICIPANT	\N	PRESENT	0
479540	479090	04085P	PARTICIPANT	\N	PRESENT	0
479541	479090	11031D	PARTICIPANT	\N	PRESENT	0
479542	479090	19695N	PARTICIPANT	\N	PRESENT	0
479543	479090	05008E	PARTICIPANT	\N	PRESENT	0
479544	479090	14021P	PARTICIPANT	\N	PRESENT	0
479545	479090	19631V	PARTICIPANT	\N	PRESENT	0
479546	479090	14039A	PARTICIPANT	\N	PRESENT	0
479547	479090	19563B	PARTICIPANT	\N	PRESENT	0
479548	479090	11012A	PARTICIPANT	\N	PRESENT	0
479549	479090	11099A	PARTICIPANT	\N	PRESENT	0
479550	479090	19693L	PARTICIPANT	\N	PRESENT	0
479551	479090	19766L	PARTICIPANT	\N	PRESENT	0
479552	479090	14041T	PARTICIPANT	\N	PRESENT	0
479553	479090	04033B	PARTICIPANT	\N	PRESENT	0
479554	479090	08010L	PARTICIPANT	\N	PRESENT	0
479555	479090	19447X	PARTICIPANT	\N	PRESENT	0
479556	479090	04040A	PARTICIPANT	\N	PRESENT	0
479557	479090	19691J	PARTICIPANT	\N	PRESENT	0
479558	479090	14147R	PARTICIPANT	\N	PRESENT	0
479559	479090	19701S	PARTICIPANT	\N	PRESENT	0
479560	479090	14089Y	PARTICIPANT	\N	PRESENT	0
479561	479090	19647E	PARTICIPANT	\N	PRESENT	0
479527	479090	11070L	PARTICIPANT	\N	PRESENT	0
479528	479400	14089Y	PARTICIPANT	\N	PRESENT	0
479529	479400	14041T	PARTICIPANT	\N	PRESENT	0
479530	479400	01028R	PARTICIPANT	\N	PRESENT	0
479531	479400	11033F	PARTICIPANT	\N	PRESENT	0
479532	479400	05008E	PRESIDENT	0	PRESENT	0
479533	479400	19447X	PARTICIPANT	\N	PRESENT	0
479534	479400	14021P	PARTICIPANT	\N	PRESENT	0
479562	479090	08019V	PARTICIPANT	\N	PRESENT	0
479563	479090	19621T	PARTICIPANT	\N	PRESENT	0
479564	479090	19741B	PARTICIPANT	\N	PRESENT	0
479565	479090	19573D	PARTICIPANT	\N	PRESENT	0
479566	479090	95041E	PARTICIPANT	\N	PRESENT	0
479567	479034	19545Y	PARTICIPANT	\N	EXCUSE	0
479663	476533	01028R	PARTICIPANT	\N	EXCUSE	0
479741	479034	19619A	PARTICIPANT	\N	EXCUSE	0
479889	479088	01025N	PARTICIPANT	\N	PRESENT	0
479892	479088	19695N	PARTICIPANT	\N	PRESENT	0
479894	479088	14033T	PARTICIPANT	\N	PRESENT	0
479899	479088	14135M	PARTICIPANT	\N	PRESENT	0
479901	479088	19269X	PARTICIPANT	\N	PRESENT	0
479911	479088	19912C	PARTICIPANT	\N	PRESENT	0
479916	479088	14329V	PARTICIPANT	\N	PRESENT	0
479940	479088	19866P	PARTICIPANT	\N	PRESENT	0
479989	479988	04047H	PARTICIPANT	\N	PRESENT	0
479990	479988	19719D	PARTICIPANT	\N	PRESENT	0
480000	479094	14063N	PARTICIPANT	\N	EXCUSE	0
480054	479035	08049C	PARTICIPANT	\N	PRESENT	0
480055	479035	19335Q	PARTICIPANT	\N	PRESENT	0
480056	479182	96004D	PARTICIPANT	\N	PRESENT	0
480057	479182	19725B	PARTICIPANT	\N	PRESENT	0
480058	479182	14237S	PARTICIPANT	\N	PRESENT	0
480059	479182	14073Q	PARTICIPANT	\N	PRESENT	0
480060	479182	19569H	PARTICIPANT	\N	PRESENT	0
456750	456748	14038Y	PARTICIPANT	\N	PRESENT	0
456751	456748	18083K	PARTICIPANT	\N	PRESENT	0
456753	456748	19333N	PARTICIPANT	\N	PRESENT	0
456754	456748	19794Q	PARTICIPANT	\N	PRESENT	0
456755	456748	19599P	PARTICIPANT	\N	PRESENT	0
456756	456747	14038Y	PARTICIPANT	\N	PRESENT	0
456757	456747	18083K	PARTICIPANT	\N	PRESENT	0
456758	456747	19333N	PARTICIPANT	\N	PRESENT	0
456759	456747	19713W	PARTICIPANT	\N	PRESENT	0
456760	456747	19794Q	PARTICIPANT	\N	PRESENT	0
456761	456747	19599P	PARTICIPANT	\N	PRESENT	0
467582	467580	04040A	PRESIDENT	0	PRESENT	0
467583	467580	14069U	PARTICIPANT	\N	PRESENT	0
467584	467580	11101A	PARTICIPANT	\N	PRESENT	0
467585	467580	14195A	PARTICIPANT	\N	EXCUSE	0
467586	467580	19253P	PARTICIPANT	\N	PRESENT	0
467587	467580	04086Q	PARTICIPANT	\N	PRESENT	0
467588	467580	14259Y	PARTICIPANT	\N	PRESENT	0
467589	467580	08038Y	PARTICIPANT	\N	PRESENT	0
467590	467580	14327T	PARTICIPANT	\N	PRESENT	0
467591	467580	14281W	PARTICIPANT	\N	PRESENT	0
467592	467580	14231L	PARTICIPANT	\N	PRESENT	0
467593	467580	19820Y	PARTICIPANT	\N	PRESENT	0
467594	467580	11049P	PARTICIPANT	\N	PRESENT	0
467595	467580	01057W	PARTICIPANT	\N	PRESENT	0
467596	467580	11048N	PARTICIPANT	\N	PRESENT	0
467597	467580	14071N	PARTICIPANT	\N	PRESENT	0
467598	467580	17637T	PARTICIPANT	\N	PRESENT	0
467599	467580	19735D	PARTICIPANT	\N	PRESENT	0
467600	467580	95063L	PARTICIPANT	\N	PRESENT	0
467601	467580	04045F	PARTICIPANT	\N	PRESENT	0
467602	467580	04044E	PARTICIPANT	\N	PRESENT	0
467603	467580	08049C	PARTICIPANT	\N	PRESENT	0
467604	467580	19565D	PARTICIPANT	\N	EXCUSE	0
467605	467580	08010L	PARTICIPANT	\N	EXCUSE	0
467607	467606	07004J	PARTICIPANT	\N	PRESENT	0
468120	467727	89017R	PARTICIPANT	\N	PRESENT	0
468121	467727	19651A	PARTICIPANT	\N	PRESENT	0
468122	467727	19667J	PARTICIPANT	\N	PRESENT	0
468123	467727	11040E	PARTICIPANT	\N	PRESENT	0
468124	467727	14083S	PARTICIPANT	\N	PRESENT	0
468125	467727	11053K	PARTICIPANT	\N	PRESENT	0
468126	467727	14085U	PARTICIPANT	\N	PRESENT	0
468127	467727	88008L	PARTICIPANT	\N	PRESENT	0
468128	467727	04086Q	PARTICIPANT	\N	PRESENT	0
468129	467727	14327T	PARTICIPANT	\N	PRESENT	0
468130	467727	11074Q	PRESIDENT	0	PRESENT	0
468131	467727	11110B	PARTICIPANT	\N	PRESENT	0
468132	467727	01057W	PARTICIPANT	\N	PRESENT	0
468133	467727	11048N	PARTICIPANT	\N	PRESENT	0
468134	467727	19531S	PARTICIPANT	\N	PRESENT	0
468135	467727	99004R	PARTICIPANT	\N	PRESENT	0
468136	467727	07029T	PARTICIPANT	\N	EXCUSE	0
468137	467727	19711U	PARTICIPANT	\N	PRESENT	0
468138	467727	01048V	PARTICIPANT	\N	PRESENT	0
468139	467727	19671E	PARTICIPANT	\N	PRESENT	0
468140	467727	08011M	PARTICIPANT	\N	PRESENT	0
468144	467727	14253S	PARTICIPANT	\N	PRESENT	0
468145	467727	19349W	PARTICIPANT	\N	PRESENT	0
468146	467727	14331P	PARTICIPANT	\N	PRESENT	0
468147	467727	14225N	PARTICIPANT	\N	PRESENT	0
468148	467727	19687N	PARTICIPANT	\N	PRESENT	0
468149	467727	19689Q	PARTICIPANT	\N	PRESENT	0
468150	467727	19479G	PARTICIPANT	\N	PRESENT	0
468151	467727	14173T	PARTICIPANT	\N	PRESENT	0
468152	467727	19741B	PARTICIPANT	\N	PRESENT	0
468153	467727	14034U	PARTICIPANT	\N	PRESENT	0
468158	467727	08010L	PARTICIPANT	\N	PRESENT	0
468159	467727	96004D	PARTICIPANT	\N	PRESENT	0
468160	467727	19545Y	PARTICIPANT	\N	PRESENT	0
468526	468525	19643A	PARTICIPANT	\N	PRESENT	0
468527	468525	11104D	PARTICIPANT	\N	PRESENT	0
468530	468529	04047H	PARTICIPANT	\N	PRESENT	0
468531	468529	14021P	PARTICIPANT	\N	PRESENT	0
468532	468529	14147R	PARTICIPANT	\N	PRESENT	0
468533	468529	01024M	PARTICIPANT	\N	PRESENT	0
468581	468580	04040A	PRESIDENT	0	PRESENT	0
468870	468869	04070G	PRESIDENT	0	PRESENT	0
468871	468869	14039A	PARTICIPANT	\N	PRESENT	0
468872	468869	19621T	PARTICIPANT	\N	PRESENT	0
468873	468869	19693L	PARTICIPANT	\N	PRESENT	0
468874	468869	19533U	PARTICIPANT	\N	PRESENT	0
468875	468869	14030Q	PARTICIPANT	\N	PRESENT	0
468876	468869	19749K	PARTICIPANT	\N	PRESENT	0
468877	468869	08043V	PARTICIPANT	\N	PRESENT	0
468878	468869	11104D	PARTICIPANT	\N	PRESENT	0
468879	468869	14107H	PARTICIPANT	\N	PRESENT	0
468880	468869	19758L	PARTICIPANT	\N	PRESENT	0
468881	468869	04057K	PARTICIPANT	\N	PRESENT	0
468882	468869	19593H	PARTICIPANT	\N	PRESENT	0
468883	468869	19731Y	PARTICIPANT	\N	PRESENT	0
468884	468869	14123H	PARTICIPANT	\N	PRESENT	0
468885	468869	08039A	PARTICIPANT	\N	PRESENT	0
468886	468869	19699S	PARTICIPANT	\N	PRESENT	0
468887	468869	11043H	PARTICIPANT	\N	PRESENT	0
468888	468869	19611R	PARTICIPANT	\N	PRESENT	0
468889	468869	14249W	PARTICIPANT	\N	PRESENT	0
468890	468869	19735D	PARTICIPANT	\N	PRESENT	0
468891	468869	14059S	PARTICIPANT	\N	PRESENT	0
468892	468869	14109K	PARTICIPANT	\N	PRESENT	0
468893	468869	07033P	PARTICIPANT	\N	EXCUSE	0
468894	468869	08020N	PARTICIPANT	\N	PRESENT	0
469650	469647	17583W	PARTICIPANT	\N	PRESENT	0
469651	469647	08060W	PARTICIPANT	\N	PRESENT	0
469652	469647	19820Y	PARTICIPANT	\N	PRESENT	0
469653	469647	19503N	PARTICIPANT	\N	PRESENT	0
469654	469647	19794Q	PARTICIPANT	\N	PRESENT	0
469655	469647	19737F	PARTICIPANT	\N	PRESENT	0
469656	469647	19745F	PARTICIPANT	\N	PRESENT	0
469658	469647	19637C	PARTICIPANT	\N	PRESENT	0
469661	469647	18083K	PARTICIPANT	\N	PRESENT	0
469663	469647	04097T	PARTICIPANT	\N	PRESENT	0
469664	469647	14219Q	PARTICIPANT	\N	PRESENT	0
469665	469647	14051J	PARTICIPANT	\N	PRESENT	0
469666	469647	19333N	PARTICIPANT	\N	PRESENT	0
469668	469647	14169X	PARTICIPANT	\N	PRESENT	0
469669	469647	19826F	PARTICIPANT	\N	PRESENT	0
469670	469647	19599P	PARTICIPANT	\N	PRESENT	0
469671	469647	19551W	PARTICIPANT	\N	PRESENT	0
469672	469647	14221J	PARTICIPANT	\N	PRESENT	0
469673	469647	11065P	PARTICIPANT	\N	PRESENT	0
469674	469647	14157T	PARTICIPANT	\N	PRESENT	0
469675	469647	19387D	PARTICIPANT	\N	PRESENT	0
469676	469647	14093U	PARTICIPANT	\N	PRESENT	0
469677	469647	14038Y	PARTICIPANT	\N	PRESENT	0
469678	469647	14031R	PARTICIPANT	\N	PRESENT	0
469679	469647	14237S	PARTICIPANT	\N	PRESENT	0
469680	469647	19733B	PARTICIPANT	\N	PRESENT	0
469681	469647	19347U	PARTICIPANT	\N	PRESENT	0
469682	469647	19701S	PARTICIPANT	\N	PRESENT	0
469683	469647	08009T	PRESIDENT	0	PRESENT	0
469685	469647	19383Y	PARTICIPANT	\N	PRESENT	0
471246	470435	19631V	PARTICIPANT	\N	PRESENT	0
471247	470435	14109K	PARTICIPANT	\N	PRESENT	0
471248	470435	19333N	PARTICIPANT	\N	PRESENT	0
471249	470435	19593H	PARTICIPANT	\N	PRESENT	0
471250	470435	19621T	PARTICIPANT	\N	PRESENT	0
471251	470435	19758L	PARTICIPANT	\N	PRESENT	0
471252	470435	14121F	PARTICIPANT	\N	PRESENT	0
471253	470435	11012A	PARTICIPANT	\N	PRESENT	0
471254	470435	14123H	PARTICIPANT	\N	PRESENT	0
471255	470435	04057K	PARTICIPANT	\N	PRESENT	0
471256	470435	14147R	PARTICIPANT	\N	PRESENT	0
471257	470435	14231L	PARTICIPANT	\N	PRESENT	0
471258	470435	14157T	PARTICIPANT	\N	PRESENT	0
471259	470435	19591F	PARTICIPANT	\N	PRESENT	0
471260	470435	19611R	PARTICIPANT	\N	PRESENT	0
471261	470435	19479G	PARTICIPANT	\N	PRESENT	0
471734	470532	04047H	PARTICIPANT	\N	PRESENT	0
471263	470435	19749K	PARTICIPANT	\N	PRESENT	0
471264	470435	14179A	PARTICIPANT	\N	PRESENT	0
471265	470435	14031R	PARTICIPANT	\N	PRESENT	0
471266	470435	19399H	PARTICIPANT	\N	PRESENT	0
471267	470435	14055N	PARTICIPANT	\N	PRESENT	0
471268	470435	19693L	PARTICIPANT	\N	PRESENT	0
471269	470435	19533U	PARTICIPANT	\N	PRESENT	0
471275	470435	14331P	PARTICIPANT	\N	PRESENT	0
471271	470435	19573D	PARTICIPANT	\N	PRESENT	0
471272	470435	04059M	PARTICIPANT	\N	PRESENT	0
471273	470435	08017T	PARTICIPANT	\N	PRESENT	0
471274	470435	14205J	PARTICIPANT	\N	PRESENT	0
471732	470532	19543W	PARTICIPANT	\N	PRESENT	0
471733	470532	14065Q	PARTICIPANT	\N	PRESENT	0
471735	470532	14053L	PARTICIPANT	\N	PRESENT	0
471736	470532	19629C	PARTICIPANT	\N	PRESENT	0
471244	470435	11027H	PARTICIPANT	\N	PRESENT	0
471245	470435	04070G	PARTICIPANT	\N	PRESENT	0
479273	479263	14235Q	PARTICIPANT	\N	PRESENT	0
479274	479263	01058X	PARTICIPANT	\N	PRESENT	0
479275	479263	11041F	PARTICIPANT	\N	PRESENT	0
479276	479263	95067Q	PARTICIPANT	\N	PRESENT	0
479277	479263	98018T	PARTICIPANT	\N	PRESENT	0
479316	479315	96004D	PARTICIPANT	\N	PRESENT	0
479318	479317	96004D	PARTICIPANT	\N	PRESENT	0
479369	479227	19335Q	PARTICIPANT	\N	PRESENT	0
479370	479227	19798U	PARTICIPANT	\N	PRESENT	0
479371	479227	19387D	PARTICIPANT	\N	PRESENT	0
479372	479227	08049C	PARTICIPANT	\N	PRESENT	0
479380	479281	19711U	PARTICIPANT	\N	PRESENT	0
479381	479281	19671E	PARTICIPANT	\N	PRESENT	0
479382	479281	99004R	PARTICIPANT	\N	PRESENT	0
479385	479367	11033F	PARTICIPANT	\N	PRESENT	0
479386	479367	14065Q	PARTICIPANT	\N	PRESENT	0
479387	479367	19629C	PARTICIPANT	\N	PRESENT	0
479388	479367	04038G	PARTICIPANT	\N	PRESENT	0
479389	479367	01024M	PARTICIPANT	\N	PRESENT	0
479390	479367	14151M	PARTICIPANT	\N	PRESENT	0
479391	479367	19725B	PARTICIPANT	\N	PRESENT	0
479392	479367	19489J	PARTICIPANT	\N	PRESENT	0
479393	479367	11026G	PARTICIPANT	\N	PRESENT	0
479394	479367	19729F	PARTICIPANT	\N	PRESENT	0
479395	479367	14147R	PARTICIPANT	\N	PRESENT	0
479396	479367	01028R	PARTICIPANT	\N	PRESENT	0
479397	479367	98035U	PARTICIPANT	\N	PRESENT	0
479412	479033	19575F	PARTICIPANT	\N	PRESENT	0
479413	479033	11083R	PARTICIPANT	\N	PRESENT	0
479414	479033	19503N	PARTICIPANT	\N	PRESENT	0
479415	479033	19798U	PARTICIPANT	\N	PRESENT	0
479570	479568	19503N	PARTICIPANT	\N	PRESENT	0
479573	479571	19503N	PARTICIPANT	\N	PRESENT	0
479574	473418	11027H	PARTICIPANT	\N	PRESENT	0
479576	479575	19725B	PARTICIPANT	\N	PRESENT	0
479577	479575	14026U	PARTICIPANT	\N	PRESENT	0
479578	473418	14063N	PARTICIPANT	\N	PRESENT	0
479579	473418	19631V	PARTICIPANT	\N	PRESENT	0
479580	473418	19812Y	PARTICIPANT	\N	PRESENT	0
479581	473418	19725B	PARTICIPANT	\N	PRESENT	0
479582	473418	04045F	PARTICIPANT	\N	PRESENT	0
479583	473418	19563B	PARTICIPANT	\N	PRESENT	0
479584	473418	19912C	PARTICIPANT	\N	PRESENT	0
479585	473418	19731Y	PARTICIPANT	\N	PRESENT	0
479586	473418	19709B	PARTICIPANT	\N	PRESENT	0
479587	473418	11067R	PARTICIPANT	\N	PRESENT	0
479588	473418	19413M	PARTICIPANT	\N	PRESENT	0
479589	473418	04086Q	PARTICIPANT	\N	PRESENT	0
479590	473418	14081Q	PARTICIPANT	\N	PRESENT	0
479591	473418	14187A	PARTICIPANT	\N	PRESENT	0
479592	473418	19349W	PARTICIPANT	\N	PRESENT	0
479593	473418	11099A	PARTICIPANT	\N	PRESENT	0
479594	473418	14207L	PARTICIPANT	\N	PRESENT	0
479595	473418	11077T	PARTICIPANT	\N	PRESENT	0
479596	473418	04008A	PARTICIPANT	\N	PRESENT	0
479597	473418	19701S	PARTICIPANT	\N	PRESENT	0
479598	473418	19383Y	PARTICIPANT	\N	PRESENT	0
479599	473418	19741B	PARTICIPANT	\N	PRESENT	0
479600	473418	11090Q	PARTICIPANT	\N	PRESENT	0
479601	473418	19533U	PARTICIPANT	\N	PRESENT	0
479602	473418	15447F	PARTICIPANT	\N	PRESENT	0
479603	473418	19739H	PARTICIPANT	\N	PRESENT	0
479604	473418	01025N	PARTICIPANT	\N	PRESENT	0
479605	473418	95063L	PARTICIPANT	\N	PRESENT	0
479606	473418	19441R	PARTICIPANT	\N	PRESENT	0
479607	473418	14030Q	PARTICIPANT	\N	PRESENT	0
479608	473418	17637T	PARTICIPANT	\N	PRESENT	0
479609	473418	01058X	PARTICIPANT	\N	PRESENT	0
479610	473418	19507S	PARTICIPANT	\N	PRESENT	0
479611	478591	11040E	PARTICIPANT	\N	PRESENT	0
479612	478591	19741B	PARTICIPANT	\N	PRESENT	0
479613	478591	14121F	PRESIDENT	0	PRESENT	0
479614	478591	11070L	PARTICIPANT	\N	PRESENT	0
479615	478591	19551W	PARTICIPANT	\N	PRESENT	0
479616	478591	19399H	PARTICIPANT	\N	EXCUSE	0
479617	473418	14157T	PARTICIPANT	\N	PRESENT	0
479618	473418	01024M	PARTICIPANT	\N	PRESENT	0
479619	473418	19467C	PARTICIPANT	\N	PRESENT	0
479621	473418	14073Q	PARTICIPANT	\N	PRESENT	0
479630	479034	19798U	PARTICIPANT	\N	PRESENT	0
479631	479034	19503N	PARTICIPANT	\N	PRESENT	0
479632	479034	19387D	PARTICIPANT	\N	PRESENT	0
479633	479034	19515S	PARTICIPANT	\N	PRESENT	0
479637	473418	19333N	PARTICIPANT	\N	PRESENT	0
479639	473418	19573D	PARTICIPANT	\N	PRESENT	0
479640	473418	14357A	PARTICIPANT	\N	PRESENT	0
479641	473418	08039A	PARTICIPANT	\N	PRESENT	0
479642	473418	18083K	PARTICIPANT	\N	PRESENT	0
479643	473418	14147R	PARTICIPANT	\N	PRESENT	0
479645	479644	14231L	PARTICIPANT	\N	PRESENT	0
479646	479644	04038G	PARTICIPANT	\N	PRESENT	0
479647	473418	08043V	PARTICIPANT	\N	PRESENT	0
479648	479055	01034P	PARTICIPANT	\N	PRESENT	0
479649	479055	11067R	PARTICIPANT	\N	PRESENT	0
479711	479055	19723Y	PARTICIPANT	\N	PRESENT	0
479651	479055	08052W	PARTICIPANT	\N	PRESENT	0
479652	479055	19301E	PARTICIPANT	\N	PRESENT	0
479712	479055	14119M	PARTICIPANT	\N	PRESENT	0
479654	479055	19715Y	PARTICIPANT	\N	PRESENT	0
479655	479055	14227Q	PARTICIPANT	\N	PRESENT	0
479656	479055	17779H	PARTICIPANT	\N	PRESENT	0
479657	479055	11103C	PARTICIPANT	\N	PRESENT	0
479658	479055	14195A	PARTICIPANT	\N	PRESENT	0
479659	479055	14071N	PARTICIPANT	\N	PRESENT	0
479660	479055	14217N	PARTICIPANT	\N	PRESENT	0
479661	479055	19683J	PARTICIPANT	\N	PRESENT	0
479662	479055	98024R	PRESIDENT	0	PRESENT	0
479664	473418	14179A	PARTICIPANT	\N	PRESENT	0
479665	479055	19565D	PARTICIPANT	\N	PRESENT	0
479666	479055	19798U	PARTICIPANT	\N	PRESENT	0
479667	479055	19569H	PARTICIPANT	\N	PRESENT	0
479668	479055	14026U	PARTICIPANT	\N	PRESENT	0
479669	479055	19703U	PARTICIPANT	\N	PRESENT	0
479670	479055	14042U	PARTICIPANT	\N	PRESENT	0
479671	479055	14213J	PARTICIPANT	\N	PRESENT	0
479672	479055	19577H	PARTICIPANT	\N	PRESENT	0
479673	479055	19521Q	PARTICIPANT	\N	PRESENT	0
479674	479055	19760E	PARTICIPANT	\N	PRESENT	0
479713	473419	11040E	PARTICIPANT	\N	PRESENT	0
479714	473419	04085P	PARTICIPANT	\N	PRESENT	0
479715	473419	19760E	PARTICIPANT	\N	PRESENT	0
479716	473419	19687N	PARTICIPANT	\N	PRESENT	0
479717	473419	01043Q	PARTICIPANT	\N	PRESENT	0
479718	473419	11012A	PARTICIPANT	\N	PRESENT	0
479719	473419	19253P	PARTICIPANT	\N	PRESENT	0
479720	473419	95063L	PARTICIPANT	\N	PRESENT	0
479721	473419	14219Q	PARTICIPANT	\N	PRESENT	0
479722	473419	04070G	PARTICIPANT	\N	PRESENT	0
479723	473419	14115H	PARTICIPANT	\N	PRESENT	0
479724	473419	19415P	PARTICIPANT	\N	PRESENT	0
479725	473419	14357A	PARTICIPANT	\N	PRESENT	0
479726	473419	19762G	PARTICIPANT	\N	PRESENT	0
479727	473419	14331P	PARTICIPANT	\N	PRESENT	0
479728	473419	11090Q	PARTICIPANT	\N	PRESENT	0
479729	473419	14069U	PARTICIPANT	\N	PRESENT	0
479730	473419	96004D	PARTICIPANT	\N	PRESENT	0
479731	473419	04042C	PARTICIPANT	\N	PRESENT	0
479732	473419	04092N	PARTICIPANT	\N	PRESENT	0
479733	473419	05008E	PARTICIPANT	\N	PRESENT	0
479734	473419	08009T	PARTICIPANT	\N	PRESENT	0
479735	473419	17589D	PARTICIPANT	\N	PRESENT	0
479736	473419	01028R	PARTICIPANT	\N	PRESENT	0
479737	473419	14133K	PARTICIPANT	\N	PRESENT	0
479738	473419	01058X	PARTICIPANT	\N	PRESENT	0
479739	473419	11097X	PARTICIPANT	\N	PRESENT	0
479740	473419	19349W	PARTICIPANT	\N	PRESENT	0
479707	473419	86034E	PARTICIPANT	\N	PRESENT	0
479742	473419	19739H	PARTICIPANT	\N	PRESENT	0
479743	473419	08039A	PARTICIPANT	\N	PRESENT	0
479745	479744	19549D	PARTICIPANT	\N	PRESENT	0
479746	479744	14097Y	PARTICIPANT	\N	PRESENT	0
479747	479744	19611R	PRESIDENT	0	PRESENT	0
479748	479744	19629C	PARTICIPANT	\N	PRESENT	0
479749	479744	19723Y	PARTICIPANT	\N	PRESENT	0
479750	479744	14197C	PARTICIPANT	\N	PRESENT	0
479751	479744	14031R	PARTICIPANT	\N	PRESENT	0
479752	473419	01024M	PARTICIPANT	\N	PRESENT	0
479753	473419	19467C	PARTICIPANT	\N	PRESENT	0
479754	473419	19533U	PARTICIPANT	\N	PRESENT	0
479756	473419	14147R	PARTICIPANT	\N	PRESENT	0
479757	473419	14179A	PARTICIPANT	\N	PRESENT	0
479758	473419	11027H	PARTICIPANT	\N	PRESENT	0
479759	473419	14121F	PARTICIPANT	\N	PRESENT	0
479760	473419	14221J	PARTICIPANT	\N	PRESENT	0
479761	473419	19507S	PARTICIPANT	\N	PRESENT	0
479762	473419	14030Q	PARTICIPANT	\N	PRESENT	0
479763	473419	19441R	PARTICIPANT	\N	PRESENT	0
456222	456221	19621T	PARTICIPANT	\N	PRESENT	0
456223	456221	08031R	PARTICIPANT	\N	PRESENT	0
456224	456221	19533U	PARTICIPANT	\N	PRESENT	0
456225	456221	08043V	PARTICIPANT	\N	PRESENT	0
456229	456228	04070G	PARTICIPANT	\N	PRESENT	0
456230	456228	19621T	PARTICIPANT	\N	PRESENT	0
456231	456228	19766L	PARTICIPANT	\N	PRESENT	0
456232	456228	14030Q	PARTICIPANT	\N	PRESENT	0
456234	456228	14241N	PARTICIPANT	\N	PRESENT	0
456235	456228	14229S	PARTICIPANT	\N	PRESENT	0
456419	448753	04086Q	PARTICIPANT	\N	PRESENT	0
456420	448753	08014Q	PARTICIPANT	\N	PRESENT	0
456421	448753	14089Y	PARTICIPANT	\N	PRESENT	0
456422	448753	14073Q	PARTICIPANT	\N	PRESENT	0
456423	448753	08015R	PARTICIPANT	\N	PRESENT	0
456424	448753	19507S	PARTICIPANT	\N	PRESENT	0
456425	448753	14157T	PARTICIPANT	\N	PRESENT	0
456426	448753	99004R	PARTICIPANT	\N	PRESENT	0
456427	448753	80013X	PARTICIPANT	\N	PRESENT	0
456428	448753	14207L	PARTICIPANT	\N	PRESENT	0
456429	448753	14257W	PARTICIPANT	\N	PRESENT	0
456430	448753	19333N	PARTICIPANT	\N	PRESENT	0
456431	448753	19693L	PARTICIPANT	\N	PRESENT	0
456432	448753	19599P	PARTICIPANT	\N	PRESENT	0
456433	448753	19619A	PARTICIPANT	\N	PRESENT	0
456434	448753	08069G	PARTICIPANT	\N	PRESENT	0
456435	448753	97011G	PARTICIPANT	\N	PRESENT	0
456436	448753	19399H	PARTICIPANT	\N	PRESENT	0
456437	448753	14135M	PARTICIPANT	\N	PRESENT	0
456438	448753	19269X	PARTICIPANT	\N	PRESENT	0
456439	448753	14219Q	PARTICIPANT	\N	PRESENT	0
456440	448753	19467C	PARTICIPANT	\N	PRESENT	0
456470	448753	04057K	PARTICIPANT	\N	PRESENT	0
456471	448753	01058X	PARTICIPANT	\N	PRESENT	0
456472	448753	96004D	PARTICIPANT	\N	PRESENT	0
456473	448753	19794Q	PARTICIPANT	\N	PRESENT	0
456474	448753	08010L	PARTICIPANT	\N	PRESENT	0
456475	448753	11090Q	PARTICIPANT	\N	PRESENT	0
456476	448753	19253P	PARTICIPANT	\N	PRESENT	0
456477	448753	19715Y	PARTICIPANT	\N	PRESENT	0
456478	448753	14169X	PARTICIPANT	\N	PRESENT	0
459589	459588	04047H	PARTICIPANT	\N	PRESENT	0
459590	459588	04042C	PARTICIPANT	\N	PRESENT	0
459595	459593	08058D	PARTICIPANT	\N	PRESENT	0
459596	459593	04047H	PARTICIPANT	\N	PRESENT	0
459608	459607	04042C	PARTICIPANT	\N	PRESENT	0
459609	459607	05008E	PARTICIPANT	\N	PRESENT	0
459610	459607	08058D	PARTICIPANT	\N	PRESENT	0
459611	459607	04047H	PARTICIPANT	\N	PRESENT	0
459613	459612	08058D	PARTICIPANT	\N	PRESENT	0
459614	459612	04047H	PARTICIPANT	\N	PRESENT	0
459615	459612	04042C	PARTICIPANT	\N	PRESENT	0
459619	459618	08058D	PARTICIPANT	\N	PRESENT	0
459620	459618	04047H	PARTICIPANT	\N	PRESENT	0
459621	459618	04042C	PARTICIPANT	\N	PRESENT	0
459624	459623	08058D	PARTICIPANT	\N	PRESENT	0
459625	459623	04047H	PARTICIPANT	\N	PRESENT	0
459626	459623	04042C	PARTICIPANT	\N	PRESENT	0
459629	459628	08058D	PARTICIPANT	\N	PRESENT	0
459630	459628	04047H	PARTICIPANT	\N	PRESENT	0
459634	459633	08058D	PARTICIPANT	\N	PRESENT	0
459635	459633	04042C	PARTICIPANT	\N	PRESENT	0
459637	459636	05008E	PARTICIPANT	\N	PRESENT	0
459639	459638	05008E	PARTICIPANT	\N	PRESENT	0
459640	459638	04042C	PARTICIPANT	\N	PRESENT	0
459644	459643	05008E	PARTICIPANT	\N	PRESENT	0
459645	459643	08058D	PARTICIPANT	\N	PRESENT	0
459646	459643	04042C	PARTICIPANT	\N	PRESENT	0
459648	459647	08058D	PARTICIPANT	\N	PRESENT	0
459651	459650	08058D	PARTICIPANT	\N	PRESENT	0
459655	459654	08058D	PARTICIPANT	\N	PRESENT	0
459656	459654	04047H	PARTICIPANT	\N	PRESENT	0
459660	459659	08058D	PARTICIPANT	\N	PRESENT	0
467742	467532	19762G	PARTICIPANT	\N	PRESENT	0
467743	467532	14021P	PARTICIPANT	\N	PRESENT	0
467744	467532	04092N	PARTICIPANT	\N	PRESENT	0
467745	467532	14089Y	PARTICIPANT	\N	PRESENT	0
467746	467220	86034E	PARTICIPANT	\N	PRESENT	0
467747	467220	11033F	PARTICIPANT	\N	PRESENT	0
467748	467220	11031D	PARTICIPANT	\N	PRESENT	0
467749	467220	19569H	PARTICIPANT	\N	PRESENT	0
467750	467220	19685L	PARTICIPANT	\N	PRESENT	0
467751	467220	14053L	PARTICIPANT	\N	PRESENT	0
467752	467220	07033P	PARTICIPANT	\N	PRESENT	0
467753	467220	19621T	PARTICIPANT	\N	PRESENT	0
467754	467220	11090Q	PARTICIPANT	\N	PRESENT	0
467755	467220	19762G	PARTICIPANT	\N	PRESENT	0
467756	467220	14123H	PARTICIPANT	\N	PRESENT	0
467757	467220	19591F	PARTICIPANT	\N	PRESENT	0
467758	467220	08061X	PARTICIPANT	\N	PRESENT	0
467759	467220	19691J	PARTICIPANT	\N	PRESENT	0
467760	467220	11085T	PARTICIPANT	\N	PRESENT	0
467761	467220	04070G	PARTICIPANT	\N	PRESENT	0
467762	467220	11045K	PARTICIPANT	\N	PRESENT	0
467763	467220	14229S	PARTICIPANT	\N	PRESENT	0
467764	467220	19689Q	PARTICIPANT	\N	PRESENT	0
467765	467220	04059M	PARTICIPANT	\N	PRESENT	0
467766	467220	19649G	PARTICIPANT	\N	PRESENT	0
467767	467220	19647E	PARTICIPANT	\N	PRESENT	0
467768	467220	19697Q	PARTICIPANT	\N	PRESENT	0
467769	467220	95063L	PARTICIPANT	\N	PRESENT	0
467770	467220	14021P	PARTICIPANT	\N	PRESENT	0
467771	467220	01028R	PARTICIPANT	\N	PRESENT	0
467772	467220	04092N	PARTICIPANT	\N	PRESENT	0
467773	467220	08031R	PARTICIPANT	\N	PRESENT	0
467774	467220	04033B	PARTICIPANT	\N	PRESENT	0
467775	467220	05008E	PARTICIPANT	\N	PRESENT	0
467776	467220	19629C	PARTICIPANT	\N	PRESENT	0
467777	467220	19553Y	PARTICIPANT	\N	PRESENT	0
467778	467220	19573D	PARTICIPANT	\N	PRESENT	0
467779	467220	19585H	PARTICIPANT	\N	PRESENT	0
467780	467220	14038Y	PARTICIPANT	\N	PRESENT	0
467781	467220	14026U	PARTICIPANT	\N	PRESENT	0
467782	467220	08044W	PARTICIPANT	\N	PRESENT	0
467783	467220	14215L	PARTICIPANT	\N	PRESENT	0
467784	467220	14089Y	PARTICIPANT	\N	PRESENT	0
467785	467220	14179A	PARTICIPANT	\N	PRESENT	0
467786	467220	08009T	PARTICIPANT	\N	PRESENT	0
467787	467220	14217N	PARTICIPANT	\N	PRESENT	0
467788	467220	89017R	PARTICIPANT	\N	PRESENT	0
467789	467220	11097X	PARTICIPANT	\N	PRESENT	0
467790	467220	14071N	PARTICIPANT	\N	PRESENT	0
467791	467220	04047H	PARTICIPANT	\N	PRESENT	0
467792	467220	19673G	PARTICIPANT	\N	PRESENT	0
467793	467220	14151M	PARTICIPANT	\N	PRESENT	0
467794	467220	17637T	PARTICIPANT	\N	PRESENT	0
467795	467220	19525U	PARTICIPANT	\N	PRESENT	0
467796	467220	04085P	PARTICIPANT	\N	PRESENT	0
467797	467220	04086Q	PARTICIPANT	\N	PRESENT	0
467798	467220	14259Y	PARTICIPANT	\N	PRESENT	0
467799	467220	11012A	PARTICIPANT	\N	PRESENT	0
467800	467220	19545Y	PARTICIPANT	\N	PRESENT	0
467803	467220	14251Q	PARTICIPANT	\N	PRESENT	0
467816	467220	11110B	PARTICIPANT	\N	PRESENT	0
467820	467220	10006L	PARTICIPANT	\N	PRESENT	0
467826	467220	08010L	PARTICIPANT	\N	PRESENT	0
468660	468659	14239U	PARTICIPANT	\N	PRESENT	0
468661	468659	14093U	PARTICIPANT	\N	PRESENT	0
468662	468659	80013X	PARTICIPANT	\N	PRESENT	0
468663	468659	19693L	PARTICIPANT	\N	PRESENT	0
468664	468659	14299H	PARTICIPANT	\N	PRESENT	0
468666	468659	19723Y	PARTICIPANT	\N	PRESENT	0
468667	468659	14221J	PARTICIPANT	\N	PRESENT	0
468668	468659	19593H	PARTICIPANT	\N	PRESENT	0
468669	468659	19533U	PARTICIPANT	\N	PRESENT	0
468670	468659	04043D	PARTICIPANT	\N	PRESENT	0
468671	468659	01058X	PARTICIPANT	\N	PRESENT	0
468674	468659	01048V	PARTICIPANT	\N	PRESENT	0
469616	469610	01048V	PRESIDENT	0	PRESENT	0
469617	469610	14239U	PARTICIPANT	\N	PRESENT	0
469618	469610	14093U	PARTICIPANT	\N	PRESENT	0
469619	469610	19593H	PARTICIPANT	\N	PRESENT	0
469620	469610	19533U	PARTICIPANT	\N	PRESENT	0
469621	469610	19503N	PARTICIPANT	\N	PRESENT	0
469622	469610	04043D	PARTICIPANT	\N	PRESENT	0
469623	469610	01058X	PARTICIPANT	\N	PRESENT	0
469773	466583	19643A	PARTICIPANT	\N	EXCUSE	0
469776	469775	19507S	PARTICIPANT	\N	PRESENT	0
469777	469775	14257W	PARTICIPANT	\N	PRESENT	0
469778	469775	19563B	PARTICIPANT	\N	PRESENT	0
477925	477924	08034U	PARTICIPANT	\N	PRESENT	0
480061	479182	19563B	PARTICIPANT	\N	PRESENT	0
480062	479182	11026G	PARTICIPANT	\N	PRESENT	0
480063	479182	14331P	PARTICIPANT	\N	PRESENT	0
480475	480469	08060W	PARTICIPANT	\N	PRESENT	0
480476	480469	19383Y	PARTICIPANT	\N	PRESENT	0
480477	480469	08024S	PARTICIPANT	\N	PRESENT	0
480478	480469	18083K	PARTICIPANT	\N	PRESENT	0
480479	480469	19701S	PARTICIPANT	\N	EXCUSE	0
480480	480469	11065P	PARTICIPANT	\N	PRESENT	0
480481	480469	19599P	PARTICIPANT	\N	PRESENT	0
480482	480469	19820Y	PARTICIPANT	\N	PRESENT	0
480483	480469	19347U	PARTICIPANT	\N	PRESENT	0
480484	480469	19333N	PARTICIPANT	\N	PRESENT	0
480485	480469	19551W	PARTICIPANT	\N	PRESENT	0
480486	480469	14219Q	PARTICIPANT	\N	PRESENT	0
480487	480469	14031R	PARTICIPANT	\N	PRESENT	0
480488	480469	19637C	PARTICIPANT	\N	PRESENT	0
480489	480469	08009T	PRESIDENT	0	PRESENT	0
480493	480469	14051J	PARTICIPANT	\N	PRESENT	0
480491	480469	19503N	PARTICIPANT	\N	PRESENT	0
480492	480469	19794Q	PARTICIPANT	\N	PRESENT	0
480494	480469	14157T	PARTICIPANT	\N	PRESENT	0
480495	480469	14221J	PARTICIPANT	\N	PRESENT	0
480511	479069	14133K	PARTICIPANT	\N	PRESENT	0
480512	479069	04040A	PARTICIPANT	\N	PRESENT	0
480513	479069	14105F	PARTICIPANT	\N	PRESENT	0
480514	479069	08058D	PARTICIPANT	\N	PRESENT	0
480515	479069	14255U	PARTICIPANT	\N	PRESENT	0
480516	479069	04042C	PRESIDENT	0	PRESENT	0
480517	479069	19721W	PARTICIPANT	\N	PRESENT	0
480518	479069	98029W	PARTICIPANT	\N	PRESENT	0
480519	479069	14267Y	PARTICIPANT	\N	PRESENT	0
480520	479069	11027H	PARTICIPANT	\N	PRESENT	0
480521	479069	98018T	PARTICIPANT	\N	PRESENT	0
480522	479069	19251M	PARTICIPANT	\N	PRESENT	0
480523	479069	97011G	PARTICIPANT	\N	PRESENT	0
480524	479069	04035D	PARTICIPANT	\N	PRESENT	0
480525	479069	08056B	PARTICIPANT	\N	PRESENT	0
480526	479069	14211G	PARTICIPANT	\N	PRESENT	0
480527	479069	11064N	PARTICIPANT	\N	PRESENT	0
480528	479069	95037J	PARTICIPANT	\N	PRESENT	0
480529	479069	14097Y	PARTICIPANT	\N	PRESENT	0
480530	479069	12041X	PARTICIPANT	\N	PRESENT	0
480531	479069	19709B	PARTICIPANT	\N	PRESENT	0
480532	479069	16685X	PARTICIPANT	\N	PRESENT	0
480533	479069	08053X	PARTICIPANT	\N	PRESENT	0
480534	479069	08061X	PARTICIPANT	\N	PRESENT	0
480535	479069	14028W	PARTICIPANT	\N	PRESENT	0
480536	479069	14193X	PARTICIPANT	\N	PRESENT	0
480537	479069	14235Q	PARTICIPANT	\N	PRESENT	0
480538	479069	19421M	PARTICIPANT	\N	PRESENT	0
480539	479069	01058X	PARTICIPANT	\N	PRESENT	0
480540	479069	19669L	PARTICIPANT	\N	PRESENT	0
480541	479069	11041F	PARTICIPANT	\N	PRESENT	0
480542	479069	11066Q	PARTICIPANT	\N	PRESENT	0
480543	479069	95067Q	PARTICIPANT	\N	PRESENT	0
480544	479069	04034C	PARTICIPANT	\N	PRESENT	0
480617	479069	08049C	PARTICIPANT	\N	EXCUSE	0
480621	480620	04035D	PARTICIPANT	\N	PRESENT	0
480622	480620	08017T	PARTICIPANT	\N	PRESENT	0
480725	476533	02002K	PARTICIPANT	\N	EXCUSE	0
480729	479094	08049C	PARTICIPANT	\N	EXCUSE	0
480734	479082	96004D	PRESIDENT	0	PRESENT	0
480735	479082	14089Y	PARTICIPANT	\N	PRESENT	0
480736	479082	14357A	PARTICIPANT	\N	PRESENT	0
480737	479082	11083R	PARTICIPANT	\N	PRESENT	0
480738	479082	14033T	PARTICIPANT	\N	PRESENT	0
480739	479082	14026U	PARTICIPANT	\N	PRESENT	0
480740	479082	19725B	PARTICIPANT	\N	PRESENT	0
480741	479082	14241N	PARTICIPANT	\N	PRESENT	0
480742	479082	11026G	PARTICIPANT	\N	PRESENT	0
480743	479082	14331P	PARTICIPANT	\N	PRESENT	0
480744	479082	10015M	PARTICIPANT	\N	PRESENT	0
480745	479082	98035U	PARTICIPANT	\N	PRESENT	0
480746	479082	14221J	PARTICIPANT	\N	PRESENT	0
480829	480828	04097T	PARTICIPANT	\N	PRESENT	0
480830	480828	11026G	PARTICIPANT	\N	PRESENT	0
480834	480833	14221J	PARTICIPANT	\N	PRESENT	0
480854	480853	14221J	PARTICIPANT	\N	PRESENT	0
480877	476533	19467C	PARTICIPANT	\N	PRESENT	0
480878	476533	19479G	PARTICIPANT	\N	PRESENT	0
480882	476533	19713W	PARTICIPANT	\N	PRESENT	0
480884	476533	08024S	PARTICIPANT	\N	PRESENT	0
480885	476533	11065P	PARTICIPANT	\N	PRESENT	0
480886	476533	14147R	PARTICIPANT	\N	PRESENT	0
481017	479053	14223L	PARTICIPANT	\N	PRESENT	0
481055	481054	96004D	PARTICIPANT	\N	PRESENT	0
481056	481054	98035U	PARTICIPANT	\N	PRESENT	0
481057	481054	14331P	PARTICIPANT	\N	PRESENT	0
481059	481058	96004D	PARTICIPANT	\N	PRESENT	0
481137	479070	14133K	PARTICIPANT	\N	PRESENT	0
481138	479070	14255U	PARTICIPANT	\N	PRESENT	0
481139	479070	04042C	PRESIDENT	0	PRESENT	0
481140	479070	98029W	PARTICIPANT	\N	PRESENT	0
481141	479070	11027H	PARTICIPANT	\N	PRESENT	0
481142	479070	19709B	PARTICIPANT	\N	PRESENT	0
481143	479070	11066Q	PARTICIPANT	\N	PRESENT	0
481144	479070	04034C	PARTICIPANT	\N	PRESENT	0
481145	479070	04040A	PARTICIPANT	\N	PRESENT	0
481183	479070	19443T	PARTICIPANT	\N	PRESENT	0
481147	479070	95030B	PARTICIPANT	\N	PRESENT	0
481148	479070	97011G	PARTICIPANT	\N	PRESENT	0
481149	479070	04035D	PARTICIPANT	\N	PRESENT	0
481150	479070	14097Y	PARTICIPANT	\N	PRESENT	0
481151	479070	19583F	PARTICIPANT	\N	PRESENT	0
481152	479070	98050T	PARTICIPANT	\N	PRESENT	0
481199	481198	19631V	PARTICIPANT	\N	PRESENT	0
481154	479070	19421M	PARTICIPANT	\N	PRESENT	0
481155	479070	01058X	PARTICIPANT	\N	PRESENT	0
481156	479070	11041F	PARTICIPANT	\N	PRESENT	0
481157	479070	96004D	PARTICIPANT	\N	PRESENT	0
481158	479070	11083R	PARTICIPANT	\N	PRESENT	0
481159	479070	14357A	PARTICIPANT	\N	PRESENT	0
481160	479070	14241N	PARTICIPANT	\N	PRESENT	0
481161	479070	14026U	PARTICIPANT	\N	PRESENT	0
481162	479070	19725B	PARTICIPANT	\N	PRESENT	0
481167	479070	14331P	PARTICIPANT	\N	PRESENT	0
481168	479070	14073Q	PARTICIPANT	\N	PRESENT	0
481169	479070	98035U	PARTICIPANT	\N	PRESENT	0
481170	479070	11026G	PARTICIPANT	\N	PRESENT	0
481171	479070	14135M	PARTICIPANT	\N	PRESENT	0
481172	479070	10015M	PARTICIPANT	\N	PRESENT	0
481203	481198	19705W	PARTICIPANT	\N	PRESENT	0
481174	479070	14033T	PARTICIPANT	\N	PRESENT	0
481176	481175	19549D	PARTICIPANT	\N	PRESENT	0
481177	481175	19611R	PRESIDENT	0	PRESENT	0
481178	481175	14097Y	PARTICIPANT	\N	PRESENT	0
481179	481175	14197C	PARTICIPANT	\N	PRESENT	0
481180	481175	11048N	PARTICIPANT	\N	PRESENT	0
481182	479070	19251M	PARTICIPANT	\N	PRESENT	0
481184	479070	04097T	PARTICIPANT	\N	PRESENT	0
481201	481198	14135M	PARTICIPANT	\N	PRESENT	0
481204	481198	11099A	PARTICIPANT	\N	PRESENT	0
481206	481198	19782L	PARTICIPANT	\N	PRESENT	0
481208	481198	14257W	PARTICIPANT	\N	PRESENT	0
481212	481211	14135M	PARTICIPANT	\N	PRESENT	0
481213	481211	19631V	PARTICIPANT	\N	PRESENT	0
481214	481211	19705W	PARTICIPANT	\N	PRESENT	0
481217	481216	14135M	PARTICIPANT	\N	PRESENT	0
481218	481216	19705W	PARTICIPANT	\N	PRESENT	0
481220	481216	19631V	PARTICIPANT	\N	PRESENT	0
481222	481216	11099A	PARTICIPANT	\N	PRESENT	0
481223	481216	14197C	PARTICIPANT	\N	PRESENT	0
481227	481224	19631V	PARTICIPANT	\N	PRESENT	0
481229	481224	14135M	PARTICIPANT	\N	PRESENT	0
481230	481224	14197C	PARTICIPANT	\N	PRESENT	0
481235	481231	14135M	PARTICIPANT	\N	PRESENT	0
481236	481231	19631V	PARTICIPANT	\N	PRESENT	0
481237	481231	19705W	PARTICIPANT	\N	PRESENT	0
481239	481231	19563B	PARTICIPANT	\N	PRESENT	0
481240	481231	14357A	PARTICIPANT	\N	PRESENT	0
481241	481231	11099A	PARTICIPANT	\N	PRESENT	0
481242	481231	14197C	PARTICIPANT	\N	PRESENT	0
481244	481243	14135M	PARTICIPANT	\N	PRESENT	0
481245	481243	19631V	PARTICIPANT	\N	PRESENT	0
481246	481243	19705W	PARTICIPANT	\N	PRESENT	0
481247	481243	11099A	PARTICIPANT	\N	PRESENT	0
481248	481243	19563B	PARTICIPANT	\N	PRESENT	0
481249	481243	04049K	PARTICIPANT	\N	PRESENT	0
481250	481243	14265W	PARTICIPANT	\N	PRESENT	0
481251	481243	14357A	PARTICIPANT	\N	PRESENT	0
481252	481243	14197C	PARTICIPANT	\N	PRESENT	0
481253	481243	14105F	PARTICIPANT	\N	PRESENT	0
481254	481243	14157T	PARTICIPANT	\N	PRESENT	0
481256	481255	14135M	PARTICIPANT	\N	PRESENT	0
481257	481255	19705W	PARTICIPANT	\N	PRESENT	0
481258	481255	19631V	PARTICIPANT	\N	PRESENT	0
481259	481255	14197C	PARTICIPANT	\N	PRESENT	0
454905	454258	14053L	PARTICIPANT	\N	PRESENT	0
454906	454258	19253P	PARTICIPANT	\N	PRESENT	0
454907	454258	01024M	PARTICIPANT	\N	PRESENT	0
454908	454258	19543W	PARTICIPANT	\N	PRESENT	0
454909	454258	04044E	PARTICIPANT	\N	PRESENT	0
454910	454258	04038G	PARTICIPANT	\N	PRESENT	0
454998	454191	19515S	PARTICIPANT	\N	PRESENT	0
454999	454191	19782L	PARTICIPANT	\N	PRESENT	0
454913	454258	11033F	PARTICIPANT	\N	PRESENT	0
454914	454258	01028R	PARTICIPANT	\N	PRESENT	0
454915	454258	05008E	PRESIDENT	0	PRESENT	0
454916	454258	19447X	PARTICIPANT	\N	PRESENT	0
455000	454191	19812Y	PARTICIPANT	\N	PRESENT	0
454918	454258	19725B	PARTICIPANT	\N	PRESENT	0
454919	454258	95063L	PARTICIPANT	\N	PRESENT	0
454920	454258	19629C	PARTICIPANT	\N	PRESENT	0
454921	454258	14041T	PARTICIPANT	\N	PRESENT	0
454922	454258	14147R	PARTICIPANT	\N	PRESENT	0
454923	454258	14215L	PARTICIPANT	\N	PRESENT	0
455001	454191	19413M	PARTICIPANT	\N	PRESENT	0
454925	454258	19762G	PARTICIPANT	\N	PRESENT	0
454926	454258	14021P	PARTICIPANT	\N	PRESENT	0
455057	454191	19768N	PARTICIPANT	\N	PRESENT	0
454929	454258	19489J	PARTICIPANT	\N	PRESENT	0
454930	454258	14065Q	PARTICIPANT	\N	PRESENT	0
454931	454258	08045X	PARTICIPANT	\N	PRESENT	0
454932	454258	19581D	PARTICIPANT	\N	PRESENT	0
454933	454258	11072N	PARTICIPANT	\N	PRESENT	0
454934	454054	98005N	PARTICIPANT	\N	PRESENT	0
454935	454054	19443T	PARTICIPANT	\N	PRESENT	0
454936	454054	11080N	PARTICIPANT	\N	PRESENT	0
454937	454054	95030B	PARTICIPANT	\N	PRESENT	0
454938	454054	04034C	PARTICIPANT	\N	PRESENT	0
454939	454054	14235Q	PARTICIPANT	\N	PRESENT	0
454940	454054	11066Q	PARTICIPANT	\N	PRESENT	0
454941	454054	19721W	PARTICIPANT	\N	PRESENT	0
454942	454054	14105F	PARTICIPANT	\N	PRESENT	0
454943	454054	98018T	PARTICIPANT	\N	PRESENT	0
454944	454054	19709B	PARTICIPANT	\N	PRESENT	0
454945	454054	14193X	PARTICIPANT	\N	PRESENT	0
454946	454054	14267Y	PARTICIPANT	\N	PRESENT	0
454947	454054	98050T	PARTICIPANT	\N	PRESENT	0
454948	454054	08047A	PARTICIPANT	\N	PRESENT	0
454949	454258	19585H	PARTICIPANT	\N	PRESENT	0
455002	454191	11090Q	PRESIDENT	0	PRESENT	0
454951	454258	19729F	PARTICIPANT	\N	PRESENT	0
454952	454054	11027H	PARTICIPANT	\N	PRESENT	0
454953	454054	11054L	PARTICIPANT	\N	PRESENT	0
454954	454054	97011G	PARTICIPANT	\N	PRESENT	0
455003	454191	01025N	PARTICIPANT	\N	PRESENT	0
454956	454928	19766L	PARTICIPANT	\N	PRESENT	0
454957	454928	04070G	PRESIDENT	0	PRESENT	0
454958	454928	92040Q	PARTICIPANT	\N	PRESENT	0
454959	454928	11104D	PARTICIPANT	\N	PRESENT	0
454960	454928	04018C	PARTICIPANT	\N	PRESENT	0
454961	454928	14073Q	PARTICIPANT	\N	EXCUSE	0
454962	454928	11083R	PARTICIPANT	\N	EXCUSE	0
454963	454928	08039A	PARTICIPANT	\N	EXCUSE	0
455116	454055	14079W	PARTICIPANT	\N	PRESENT	0
455117	454055	11027H	PARTICIPANT	\N	PRESENT	0
455118	454055	16685X	PARTICIPANT	\N	PRESENT	0
455058	454191	11077T	PARTICIPANT	\N	PRESENT	0
454968	454258	14069U	PARTICIPANT	\N	PRESENT	0
455119	454055	11054L	PARTICIPANT	\N	PRESENT	0
455120	454055	04042C	PRESIDENT	0	PRESENT	0
454971	453967	14327T	PARTICIPANT	\N	PRESENT	0
454972	453967	14331P	PARTICIPANT	\N	PRESENT	0
454973	453967	11048N	PARTICIPANT	\N	PRESENT	0
454974	453967	95041E	PARTICIPANT	\N	PRESENT	0
454975	453967	01057W	PRESIDENT	0	PRESENT	0
454976	453967	19687N	PARTICIPANT	\N	PRESENT	0
454977	453967	11053K	PARTICIPANT	\N	PRESENT	0
454978	453967	19671E	PARTICIPANT	\N	PRESENT	0
454979	453967	14173T	PARTICIPANT	\N	PRESENT	0
454980	453967	04086Q	PARTICIPANT	\N	PRESENT	0
454981	453967	11040E	PARTICIPANT	\N	PRESENT	0
454982	453967	14199E	PARTICIPANT	\N	PRESENT	0
454983	453967	11012A	PARTICIPANT	\N	PRESENT	0
454984	453967	14085U	PARTICIPANT	\N	PRESENT	0
454985	453967	19349W	PARTICIPANT	\N	PRESENT	0
454986	453967	14121F	PARTICIPANT	\N	PRESENT	0
454987	453967	99004R	PARTICIPANT	\N	PRESENT	0
454988	453967	14253S	PARTICIPANT	\N	PRESENT	0
454989	454928	14061L	PARTICIPANT	\N	PRESENT	0
454990	454928	19699S	PARTICIPANT	\N	PRESENT	0
454991	454928	19533U	PARTICIPANT	\N	PRESENT	0
454992	454928	08043V	PARTICIPANT	\N	PRESENT	0
454993	454928	19693L	PARTICIPANT	\N	PRESENT	0
454994	454928	14030Q	PARTICIPANT	\N	PRESENT	0
454995	454928	19731Y	PARTICIPANT	\N	PRESENT	0
454996	454928	07033P	PARTICIPANT	\N	PRESENT	0
454997	454928	08012N	PARTICIPANT	\N	PRESENT	0
455004	454191	80013X	PARTICIPANT	\N	PRESENT	0
455005	454191	19631V	PARTICIPANT	\N	PRESENT	0
455006	454191	04088S	PARTICIPANT	\N	PRESENT	0
455007	454191	11056N	PARTICIPANT	\N	PRESENT	0
455008	454191	08068F	PARTICIPANT	\N	PRESENT	0
455009	454191	04089T	PARTICIPANT	\N	PRESENT	0
455010	454191	19705W	PARTICIPANT	\N	PRESENT	0
455011	454191	11101A	PARTICIPANT	\N	PRESENT	0
455012	454191	19507S	PARTICIPANT	\N	PRESENT	0
455013	454191	08015R	PARTICIPANT	\N	PRESENT	0
455014	454191	14197C	PARTICIPANT	\N	PRESENT	0
455015	454191	19511N	PARTICIPANT	\N	PRESENT	0
455016	454191	17589D	PARTICIPANT	\N	PRESENT	0
455017	454191	14257W	PARTICIPANT	\N	PRESENT	0
455018	454191	19591F	PARTICIPANT	\N	PRESENT	0
455019	454928	87003B	PARTICIPANT	\N	PRESENT	0
455020	454928	14241N	PARTICIPANT	\N	PRESENT	0
455021	454928	08020N	PARTICIPANT	\N	PRESENT	0
455023	454928	19758L	PARTICIPANT	\N	PRESENT	0
455024	454928	08031R	PARTICIPANT	\N	PRESENT	0
455025	453967	14225N	PARTICIPANT	\N	PRESENT	0
455026	453967	08010L	PARTICIPANT	\N	PRESENT	0
455027	453967	19711U	PARTICIPANT	\N	PRESENT	0
455028	453967	08069G	PARTICIPANT	\N	PRESENT	0
455029	453967	12016W	PARTICIPANT	\N	PRESENT	0
455030	453967	08014Q	PARTICIPANT	\N	PRESENT	0
455031	453967	14159V	PARTICIPANT	\N	PRESENT	0
455032	453967	07004J	PARTICIPANT	\N	EXCUSE	0
455033	453967	08011M	PARTICIPANT	\N	EXCUSE	0
455034	453967	14083S	PARTICIPANT	\N	PRESENT	0
455035	454191	11099A	PARTICIPANT	\N	PRESENT	0
455036	454191	04049K	PARTICIPANT	\N	PRESENT	0
455037	454191	19369B	PARTICIPANT	\N	PRESENT	0
455038	454191	14265W	PARTICIPANT	\N	PRESENT	0
455039	454191	19467C	PARTICIPANT	\N	PRESENT	0
455040	454191	14187A	PARTICIPANT	\N	PRESENT	0
455041	454191	08062Y	PARTICIPANT	\N	PRESENT	0
455042	454191	14033T	PARTICIPANT	\N	PRESENT	0
455043	454191	19269X	PARTICIPANT	\N	PRESENT	0
455044	454191	14207L	PARTICIPANT	\N	PRESENT	0
455045	454191	19747H	PARTICIPANT	\N	PRESENT	0
455046	453967	89017R	PARTICIPANT	\N	PRESENT	0
455047	454258	04047H	PARTICIPANT	\N	PRESENT	0
455048	454258	19673G	PARTICIPANT	\N	PRESENT	0
455049	454258	14231L	PARTICIPANT	\N	PRESENT	0
455050	454258	14151M	PARTICIPANT	\N	PRESENT	0
455051	454258	14259Y	PARTICIPANT	\N	PRESENT	0
455052	454258	98035U	PARTICIPANT	\N	PRESENT	0
455053	454258	11010L	PARTICIPANT	\N	PRESENT	0
455054	454258	14089Y	PARTICIPANT	\N	PRESENT	0
455056	454258	14179A	PARTICIPANT	\N	PRESENT	0
455059	454191	19441R	PARTICIPANT	\N	PRESENT	0
455060	454191	14135M	PARTICIPANT	\N	PRESENT	0
455061	454191	08038Y	PARTICIPANT	\N	PRESENT	0
455062	454191	19619A	PARTICIPANT	\N	PRESENT	0
455063	454928	14229S	PARTICIPANT	\N	PRESENT	0
455065	454928	14249W	PARTICIPANT	\N	PRESENT	0
455066	454928	14059S	PARTICIPANT	\N	PRESENT	0
455067	454928	19399H	PARTICIPANT	\N	PRESENT	0
455068	454928	14109K	PARTICIPANT	\N	PRESENT	0
455069	454928	14063N	PARTICIPANT	\N	PRESENT	0
455070	454928	19621T	PARTICIPANT	\N	PRESENT	0
455071	454191	01043Q	PARTICIPANT	\N	PRESENT	0
455072	454191	14205J	PARTICIPANT	\N	PRESENT	0
455073	453967	08034U	PARTICIPANT	\N	PRESENT	0
455074	454191	14081Q	PARTICIPANT	\N	PRESENT	0
455075	454258	19719D	PARTICIPANT	\N	PRESENT	0
455108	454055	98005N	PARTICIPANT	\N	PRESENT	0
455109	454055	19443T	PARTICIPANT	\N	PRESENT	0
455110	454055	12041X	PARTICIPANT	\N	PRESENT	0
455111	454055	11080N	PARTICIPANT	\N	PRESENT	0
455112	454055	95030B	PARTICIPANT	\N	PRESENT	0
455113	454055	04034C	PARTICIPANT	\N	PRESENT	0
455114	454055	01058X	PARTICIPANT	\N	PRESENT	0
455115	454055	04040A	PARTICIPANT	\N	PRESENT	0
479764	473419	14031R	PARTICIPANT	\N	PRESENT	0
479765	473419	19914E	PARTICIPANT	\N	PRESENT	0
479766	476429	19593H	PARTICIPANT	\N	PRESENT	0
479767	476430	19593H	PARTICIPANT	\N	PRESENT	0
479768	476431	19593H	PARTICIPANT	\N	PRESENT	0
479771	479770	19593H	PARTICIPANT	\N	PRESENT	0
479773	479772	19593H	PARTICIPANT	\N	PRESENT	0
479775	479774	19593H	PARTICIPANT	\N	PRESENT	0
479777	479776	19593H	PARTICIPANT	\N	PRESENT	0
479820	473420	04057K	PARTICIPANT	\N	PRESENT	0
479821	473420	19441R	PARTICIPANT	\N	PRESENT	0
479822	473420	19725B	PARTICIPANT	\N	PRESENT	0
479823	473420	14241N	PARTICIPANT	\N	PRESENT	0
479824	473420	01024M	PARTICIPANT	\N	PRESENT	0
479825	473420	11083R	PARTICIPANT	\N	PRESENT	0
479826	473420	96004D	PARTICIPANT	\N	PRESENT	0
479827	473420	14133K	PARTICIPANT	\N	PRESENT	0
479828	473420	14147R	PARTICIPANT	\N	PRESENT	0
479829	473420	14026U	PARTICIPANT	\N	PRESENT	0
479830	473420	11097X	PARTICIPANT	\N	PRESENT	0
479831	473420	14237S	PARTICIPANT	\N	PRESENT	0
479832	473420	14331P	PARTICIPANT	\N	PRESENT	0
479833	473420	19347U	PARTICIPANT	\N	PRESENT	0
479834	473420	04042C	PARTICIPANT	\N	PRESENT	0
479835	473420	95063L	PARTICIPANT	\N	PRESENT	0
479836	473420	19647E	PARTICIPANT	\N	PRESENT	0
479837	473420	14089Y	PARTICIPANT	\N	PRESENT	0
479838	473420	11066Q	PARTICIPANT	\N	PRESENT	0
479839	473420	19413M	PARTICIPANT	\N	PRESENT	0
479840	473420	14073Q	PARTICIPANT	\N	PRESENT	0
479841	473420	14219Q	PARTICIPANT	\N	PRESENT	0
479842	473420	19820Y	PARTICIPANT	\N	PRESENT	0
479843	473420	19760E	PARTICIPANT	\N	PRESENT	0
479844	473420	08039A	PARTICIPANT	\N	PRESENT	0
479845	473420	14069U	PARTICIPANT	\N	PRESENT	0
479846	473420	18083K	PARTICIPANT	\N	PRESENT	0
480053	479072	19717B	PARTICIPANT	\N	PRESENT	0
480072	473421	19507S	PARTICIPANT	\N	PRESENT	0
480073	473421	19383Y	PARTICIPANT	\N	PRESENT	0
480074	473421	19511N	PARTICIPANT	\N	PRESENT	0
480075	473421	19762G	PARTICIPANT	\N	PRESENT	0
480076	473421	99004R	PARTICIPANT	\N	PRESENT	0
480077	473421	19515S	PARTICIPANT	\N	PRESENT	0
480078	473421	14089Y	PARTICIPANT	\N	PRESENT	0
480079	473421	14231L	PARTICIPANT	\N	PRESENT	0
480083	473421	19766L	PARTICIPANT	\N	PRESENT	0
480084	473421	14063N	PARTICIPANT	\N	PRESENT	0
480085	473421	19812Y	PARTICIPANT	\N	PRESENT	0
480086	473421	14281W	PARTICIPANT	\N	PRESENT	0
479818	473420	01043Q	PARTICIPANT	\N	PRESENT	0
479819	473420	12041X	PARTICIPANT	\N	PRESENT	0
480087	473421	14193X	PARTICIPANT	\N	PRESENT	0
480088	473421	04088S	PARTICIPANT	\N	PRESENT	0
480089	473421	14121F	PARTICIPANT	\N	PRESENT	0
480090	473421	19253P	PARTICIPANT	\N	PRESENT	0
480091	473421	98029W	PARTICIPANT	\N	PRESENT	0
480092	473421	19673G	PARTICIPANT	\N	PRESENT	0
480093	473421	19599P	PARTICIPANT	\N	PRESENT	0
480094	473421	14079W	PARTICIPANT	\N	PRESENT	0
480098	473421	14030Q	PARTICIPANT	\N	PRESENT	0
480096	473421	19715Y	PARTICIPANT	\N	PRESENT	0
480097	473421	04045F	PARTICIPANT	\N	PRESENT	0
480099	473421	14115H	PARTICIPANT	\N	PRESENT	0
480100	473421	19794Q	PARTICIPANT	\N	PRESENT	0
480101	473421	19569H	PARTICIPANT	\N	PRESENT	0
480102	473421	14267Y	PARTICIPANT	\N	PRESENT	0
480103	473421	95063L	PARTICIPANT	\N	PRESENT	0
480104	473421	19745F	PARTICIPANT	\N	PRESENT	0
480105	473421	92040Q	PARTICIPANT	\N	PRESENT	0
480106	473421	19693L	PARTICIPANT	\N	PRESENT	0
480107	473421	11067R	PARTICIPANT	\N	PRESENT	0
480108	473421	19683J	PARTICIPANT	\N	PRESENT	0
480109	473421	04018C	PARTICIPANT	\N	PRESENT	0
480110	473421	07033P	PARTICIPANT	\N	PRESENT	0
480111	473421	08069G	PARTICIPANT	\N	PRESENT	0
480112	473421	04042C	PARTICIPANT	\N	PRESENT	0
480113	473421	11054L	PARTICIPANT	\N	PRESENT	0
480114	473421	19739H	PARTICIPANT	\N	PRESENT	0
480115	473421	08011M	PARTICIPANT	\N	PRESENT	0
480116	473421	96004D	PARTICIPANT	\N	PRESENT	0
480117	473421	19721W	PARTICIPANT	\N	PRESENT	0
480118	473421	14241N	PARTICIPANT	\N	PRESENT	0
480119	473421	04086Q	PARTICIPANT	\N	PRESENT	0
480120	473421	19731Y	PARTICIPANT	\N	PRESENT	0
480121	473421	19685L	PARTICIPANT	\N	PRESENT	0
480122	473421	14207L	PARTICIPANT	\N	PRESENT	0
480123	473421	19695N	PARTICIPANT	\N	PRESENT	0
480124	473421	19593H	PARTICIPANT	\N	PRESENT	0
480125	473421	14235Q	PARTICIPANT	\N	PRESENT	0
480126	473421	17589D	PARTICIPANT	\N	PRESENT	0
480127	473421	95037J	PARTICIPANT	\N	PRESENT	0
480128	473421	11066Q	PARTICIPANT	\N	PRESENT	0
480129	473421	08052W	PARTICIPANT	\N	PRESENT	0
480130	473421	19527W	PARTICIPANT	\N	PRESENT	0
480131	473421	95030B	PARTICIPANT	\N	PRESENT	0
480132	473421	19747H	PARTICIPANT	\N	PRESENT	0
480133	473421	08061X	PARTICIPANT	\N	PRESENT	0
480134	473421	14227Q	PARTICIPANT	\N	PRESENT	0
480135	473421	08045X	PARTICIPANT	\N	PRESENT	0
480136	473421	14257W	PARTICIPANT	\N	PRESENT	0
480137	473421	14085U	PARTICIPANT	\N	PRESENT	0
480138	473421	14093U	PARTICIPANT	\N	PRESENT	0
480139	473421	88008L	PARTICIPANT	\N	PRESENT	0
480140	473421	14179A	PARTICIPANT	\N	PRESENT	0
480141	473421	19912C	PARTICIPANT	\N	PRESENT	0
480142	473421	19637C	PARTICIPANT	\N	PRESENT	0
480143	473421	11040E	PARTICIPANT	\N	PRESENT	0
480144	473421	19349W	PARTICIPANT	\N	PRESENT	0
480145	473421	10015M	PARTICIPANT	\N	PRESENT	0
480146	473421	14031R	PARTICIPANT	\N	PRESENT	0
480147	473421	19333N	PARTICIPANT	\N	PRESENT	0
480148	473421	19251M	PARTICIPANT	\N	PRESENT	0
480149	473421	11064N	PARTICIPANT	\N	PRESENT	0
480150	473421	14255U	PARTICIPANT	\N	PRESENT	0
480151	473421	19820Y	PARTICIPANT	\N	PRESENT	0
480152	473421	04034C	PARTICIPANT	\N	PRESENT	0
480153	473421	11033F	PARTICIPANT	\N	PRESENT	0
480154	473421	19347U	PARTICIPANT	\N	PRESENT	0
480155	473421	14187A	PARTICIPANT	\N	PRESENT	0
480156	473421	14147R	PARTICIPANT	\N	PRESENT	0
480157	473421	04085P	PARTICIPANT	\N	PRESENT	0
480158	473421	19687N	PARTICIPANT	\N	PRESENT	0
480159	473421	19543W	PARTICIPANT	\N	PRESENT	0
480160	473421	19301E	PARTICIPANT	\N	PRESENT	0
480161	473421	14034U	PARTICIPANT	\N	PRESENT	0
480162	473421	14159V	PARTICIPANT	\N	PRESENT	0
480163	473421	11083R	PARTICIPANT	\N	PRESENT	0
480164	473421	11065P	PARTICIPANT	\N	PRESENT	0
480165	473421	11012A	PARTICIPANT	\N	PRESENT	0
480166	473421	14251Q	PARTICIPANT	\N	PRESENT	0
480167	473421	14151M	PARTICIPANT	\N	PRESENT	0
480168	473421	11099A	PARTICIPANT	\N	PRESENT	0
480169	473421	17779H	PARTICIPANT	\N	PRESENT	0
480170	473421	14081Q	PARTICIPANT	\N	PRESENT	0
480171	473421	98024R	PARTICIPANT	\N	PRESENT	0
480172	473421	19689Q	PARTICIPANT	\N	PRESENT	0
480173	473421	19725B	PARTICIPANT	\N	PRESENT	0
480174	473421	19565D	PARTICIPANT	\N	PRESENT	0
480175	473421	08039A	PARTICIPANT	\N	PRESENT	0
480176	473421	08010L	PARTICIPANT	\N	PRESENT	0
480177	473421	19760E	PARTICIPANT	\N	PRESENT	0
480178	473421	19369B	PARTICIPANT	\N	PRESENT	0
480179	473421	14083S	PARTICIPANT	\N	PRESENT	0
480180	473421	14205J	PARTICIPANT	\N	PRESENT	0
480181	473421	15447F	PARTICIPANT	\N	PRESENT	0
480182	473421	16685X	PARTICIPANT	\N	PRESENT	0
480183	473421	19643A	PARTICIPANT	\N	PRESENT	0
480184	473421	11053K	PARTICIPANT	\N	PRESENT	0
480185	473421	19441R	PARTICIPANT	\N	PRESENT	0
480186	473421	04040A	PARTICIPANT	\N	PRESENT	0
480187	473421	14221J	PARTICIPANT	\N	PRESENT	0
480188	473421	04033B	PARTICIPANT	\N	PRESENT	0
480189	473421	19699S	PARTICIPANT	\N	PRESENT	0
480190	473421	14219Q	PARTICIPANT	\N	PRESENT	0
480191	473421	14071N	PARTICIPANT	\N	PRESENT	0
480192	473421	01024M	PARTICIPANT	\N	PRESENT	0
480193	473421	11085T	PARTICIPANT	\N	PRESENT	0
480194	473421	01043Q	PARTICIPANT	\N	PRESENT	0
480195	473421	11031D	PARTICIPANT	\N	PRESENT	0
480196	473421	11080N	PARTICIPANT	\N	PRESENT	0
480197	473421	14069U	PARTICIPANT	\N	PRESENT	0
480198	473421	01057W	PARTICIPANT	\N	PRESENT	0
480199	473421	14259Y	PARTICIPANT	\N	PRESENT	0
480200	473421	04049K	PARTICIPANT	\N	PRESENT	0
480202	473421	04070G	PARTICIPANT	\N	PRESENT	0
458325	458324	11026G	PARTICIPANT	\N	PRESENT	0
458326	458324	14089Y	PARTICIPANT	\N	PRESENT	0
458952	458657	14327T	PARTICIPANT	\N	EXCUSE	0
464147	463841	19768N	PARTICIPANT	\N	PRESENT	0
464148	463841	19515S	PARTICIPANT	\N	PRESENT	0
464149	463841	19782L	PARTICIPANT	\N	PRESENT	0
464150	463841	14357A	PARTICIPANT	\N	PRESENT	0
464151	463841	19812Y	PARTICIPANT	\N	PRESENT	0
464152	463841	14081Q	PARTICIPANT	\N	PRESENT	0
464153	463841	19866P	PARTICIPANT	\N	PRESENT	0
464154	463841	04045F	PARTICIPANT	\N	PRESENT	0
464155	463841	19631V	PARTICIPANT	\N	PRESENT	0
464156	463841	11099A	PARTICIPANT	\N	PRESENT	0
464157	463841	08068F	PARTICIPANT	\N	PRESENT	0
464158	463841	04049K	PARTICIPANT	\N	PRESENT	0
464159	463841	19705W	PARTICIPANT	\N	PRESENT	0
464160	463841	08015R	PARTICIPANT	\N	PRESENT	0
464161	463841	14197C	PARTICIPANT	\N	PRESENT	0
464162	463841	19369B	PARTICIPANT	\N	PRESENT	0
464163	463841	08028W	PARTICIPANT	\N	PRESENT	0
464164	463841	19563B	PARTICIPANT	\N	PRESENT	0
464165	463841	14265W	PARTICIPANT	\N	PRESENT	0
464166	463841	14329V	PARTICIPANT	\N	PRESENT	0
464167	463841	14135M	PARTICIPANT	\N	PRESENT	0
464168	463841	19467C	PARTICIPANT	\N	PRESENT	0
464169	463841	14187A	PARTICIPANT	\N	PRESENT	0
464170	463841	08038Y	PARTICIPANT	\N	PRESENT	0
464171	463841	19695N	PARTICIPANT	\N	PRESENT	0
464172	463841	01025N	PARTICIPANT	\N	PRESENT	0
464173	463841	11090Q	PRESIDENT	0	PRESENT	0
464174	463841	14033T	PARTICIPANT	\N	PRESENT	0
464175	463841	19269X	PARTICIPANT	\N	PRESENT	0
464176	463841	14205J	PARTICIPANT	\N	PRESENT	0
464177	463841	11056N	PARTICIPANT	\N	PRESENT	0
464178	463841	14115H	PARTICIPANT	\N	PRESENT	0
464179	463841	19507S	PARTICIPANT	\N	PRESENT	0
464180	463841	19747H	PARTICIPANT	\N	PRESENT	0
464181	463841	14207L	PARTICIPANT	\N	PRESENT	0
464182	463841	19619A	PARTICIPANT	\N	PRESENT	0
464183	463841	14257W	PARTICIPANT	\N	PRESENT	0
464184	463841	04088S	PARTICIPANT	\N	EXCUSE	0
464185	463841	04089T	PARTICIPANT	\N	EXCUSE	0
464186	463841	01043Q	PARTICIPANT	\N	EXCUSE	0
464187	463841	80013X	PARTICIPANT	\N	EXCUSE	0
469779	469775	19782L	PARTICIPANT	\N	PRESENT	0
469784	469780	14115H	PARTICIPANT	\N	PRESENT	0
469785	469780	19782L	PARTICIPANT	\N	PRESENT	0
469786	469780	14207L	PARTICIPANT	\N	PRESENT	0
469787	469780	11101A	PARTICIPANT	\N	PRESENT	0
469788	469780	19507S	PARTICIPANT	\N	PRESENT	0
469789	469780	19747H	PARTICIPANT	\N	PRESENT	0
469790	469780	14197C	PARTICIPANT	\N	PRESENT	0
469791	469780	19441R	PARTICIPANT	\N	PRESENT	0
469792	469780	14265W	PARTICIPANT	\N	PRESENT	0
469793	469780	19563B	PARTICIPANT	\N	PRESENT	0
469794	469780	11099A	PARTICIPANT	\N	PRESENT	0
469795	469781	19782L	PARTICIPANT	\N	PRESENT	0
469796	469781	19747H	PARTICIPANT	\N	PRESENT	0
469797	469781	19507S	PARTICIPANT	\N	PRESENT	0
469798	469781	19812Y	PARTICIPANT	\N	PRESENT	0
469799	469781	19563B	PARTICIPANT	\N	PRESENT	0
469800	469781	14257W	PARTICIPANT	\N	PRESENT	0
469801	469781	19369B	PARTICIPANT	\N	PRESENT	0
469802	469781	14265W	PARTICIPANT	\N	PRESENT	0
469803	469781	19413M	PARTICIPANT	\N	PRESENT	0
469804	469781	14357A	PARTICIPANT	\N	PRESENT	0
469806	469805	19782L	PARTICIPANT	\N	PRESENT	0
469807	469805	19747H	PARTICIPANT	\N	PRESENT	0
469808	469805	14357A	PARTICIPANT	\N	PRESENT	0
469809	469805	19812Y	PARTICIPANT	\N	PRESENT	0
469810	469805	19507S	PARTICIPANT	\N	PRESENT	0
469811	469805	14033T	PARTICIPANT	\N	PRESENT	0
469812	469805	14205J	PARTICIPANT	\N	PRESENT	0
469813	469805	19563B	PARTICIPANT	\N	PRESENT	0
469814	469805	14257W	PARTICIPANT	\N	PRESENT	0
469815	469805	14265W	PARTICIPANT	\N	PRESENT	0
469816	469782	19782L	PARTICIPANT	\N	PRESENT	0
469817	469782	14357A	PARTICIPANT	\N	PRESENT	0
469818	469782	19507S	PARTICIPANT	\N	PRESENT	0
469819	469782	04049K	PARTICIPANT	\N	PRESENT	0
469820	469782	19563B	PARTICIPANT	\N	PRESENT	0
469825	469821	19782L	PARTICIPANT	\N	PRESENT	0
469826	469821	19507S	PARTICIPANT	\N	PRESENT	0
469827	469821	19563B	PARTICIPANT	\N	PRESENT	0
469828	469821	14257W	PARTICIPANT	\N	PRESENT	0
469829	469822	08015R	PARTICIPANT	\N	PRESENT	0
469830	469822	04049K	PARTICIPANT	\N	PRESENT	0
469831	469822	14257W	PARTICIPANT	\N	PRESENT	0
469832	469822	19782L	PARTICIPANT	\N	PRESENT	0
469835	469822	19467C	PARTICIPANT	\N	PRESENT	0
469839	469822	19563B	PARTICIPANT	\N	PRESENT	0
469843	469822	19575F	PARTICIPANT	\N	PRESENT	0
469846	469822	01024M	PARTICIPANT	\N	PRESENT	0
469847	469822	19820Y	PARTICIPANT	\N	PRESENT	0
469848	469822	14097Y	PARTICIPANT	\N	PRESENT	0
469849	469822	19723Y	PARTICIPANT	\N	PRESENT	0
469850	469822	14213J	PARTICIPANT	\N	PRESENT	0
469851	469822	14109K	PARTICIPANT	\N	PRESENT	0
469852	469822	19443T	PARTICIPANT	\N	PRESENT	0
469853	469822	19745F	PARTICIPANT	\N	PRESENT	0
469854	469822	11097X	PARTICIPANT	\N	PRESENT	0
469856	469822	19713W	PARTICIPANT	\N	PRESENT	0
469857	469823	19782L	PARTICIPANT	\N	PRESENT	0
469858	469823	19812Y	PARTICIPANT	\N	PRESENT	0
469859	469823	01025N	PARTICIPANT	\N	PRESENT	0
469860	469823	80013X	PARTICIPANT	\N	PRESENT	0
469861	469823	19575F	PARTICIPANT	\N	PRESENT	0
469862	469823	14097Y	PARTICIPANT	\N	PRESENT	0
469863	469823	19723Y	PARTICIPANT	\N	PRESENT	0
469864	469823	08015R	PARTICIPANT	\N	PRESENT	0
469865	469823	19441R	PARTICIPANT	\N	PRESENT	0
469866	469823	19563B	PARTICIPANT	\N	PRESENT	0
469867	469823	14109K	PARTICIPANT	\N	PRESENT	0
469868	469823	19745F	PARTICIPANT	\N	PRESENT	0
469869	469823	19798U	PARTICIPANT	\N	PRESENT	0
469870	469823	11097X	PARTICIPANT	\N	PRESENT	0
469871	469824	19575F	PARTICIPANT	\N	PRESENT	0
469872	469824	19812Y	PARTICIPANT	\N	PRESENT	0
469873	469824	14357A	PARTICIPANT	\N	PRESENT	0
469874	469824	80013X	PARTICIPANT	\N	PRESENT	0
469875	469824	19820Y	PARTICIPANT	\N	PRESENT	0
469876	469824	19782L	PARTICIPANT	\N	PRESENT	0
469877	469824	14097Y	PARTICIPANT	\N	PRESENT	0
469878	469824	19723Y	PARTICIPANT	\N	PRESENT	0
469879	469824	08015R	PARTICIPANT	\N	PRESENT	0
469880	469824	19563B	PARTICIPANT	\N	PRESENT	0
469881	469824	19443T	PARTICIPANT	\N	PRESENT	0
469882	469824	19798U	PARTICIPANT	\N	PRESENT	0
469883	469824	19745F	PARTICIPANT	\N	PRESENT	0
469888	469884	19782L	PARTICIPANT	\N	PRESENT	0
469889	469884	19812Y	PARTICIPANT	\N	PRESENT	0
469890	469884	19507S	PARTICIPANT	\N	PRESENT	0
469891	469884	19563B	PARTICIPANT	\N	PRESENT	0
469892	469884	14257W	PARTICIPANT	\N	PRESENT	0
469893	469885	19782L	PARTICIPANT	\N	PRESENT	0
469894	469885	19812Y	PARTICIPANT	\N	PRESENT	0
469895	469885	14357A	PARTICIPANT	\N	PRESENT	0
469896	469885	19507S	PARTICIPANT	\N	PRESENT	0
469897	469885	14257W	PARTICIPANT	\N	PRESENT	0
469898	469887	19782L	PARTICIPANT	\N	PRESENT	0
469899	469887	14207L	PARTICIPANT	\N	PRESENT	0
469900	469887	19507S	PARTICIPANT	\N	PRESENT	0
469901	469887	14033T	PARTICIPANT	\N	PRESENT	0
469902	469887	08015R	PARTICIPANT	\N	PRESENT	0
469903	469887	19563B	PARTICIPANT	\N	PRESENT	0
469904	469887	14257W	PARTICIPANT	\N	PRESENT	0
469907	469905	19782L	PARTICIPANT	\N	PRESENT	0
469908	469905	14207L	PARTICIPANT	\N	PRESENT	0
469909	469905	14357A	PARTICIPANT	\N	PRESENT	0
469910	469905	19507S	PARTICIPANT	\N	PRESENT	0
469911	469905	11099A	PARTICIPANT	\N	PRESENT	0
469912	469905	14257W	PARTICIPANT	\N	PRESENT	0
469913	469905	14265W	PARTICIPANT	\N	PRESENT	0
469914	469905	19563B	PARTICIPANT	\N	PRESENT	0
469915	469905	19269X	PARTICIPANT	\N	PRESENT	0
469917	469916	19782L	PARTICIPANT	\N	PRESENT	0
469918	469916	14357A	PARTICIPANT	\N	PRESENT	0
469919	469916	19507S	PARTICIPANT	\N	PRESENT	0
469920	469916	11099A	PARTICIPANT	\N	PRESENT	0
469921	469916	14257W	PARTICIPANT	\N	PRESENT	0
469922	469916	14265W	PARTICIPANT	\N	PRESENT	0
469923	469916	19269X	PARTICIPANT	\N	PRESENT	0
469925	469924	19782L	PARTICIPANT	\N	PRESENT	0
469926	469924	14357A	PARTICIPANT	\N	PRESENT	0
469927	469924	19507S	PARTICIPANT	\N	PRESENT	0
469928	469924	11099A	PARTICIPANT	\N	PRESENT	0
469929	469924	14257W	PARTICIPANT	\N	PRESENT	0
469930	469924	19269X	PARTICIPANT	\N	PRESENT	0
469932	469931	19782L	PARTICIPANT	\N	PRESENT	0
471932	470506	19253P	PARTICIPANT	\N	EXCUSE	0
471933	470506	95067Q	PARTICIPANT	\N	PRESENT	0
471934	470506	08049C	PARTICIPANT	\N	PRESENT	0
471935	470506	04044E	PARTICIPANT	\N	PRESENT	0
471936	470506	19687N	PARTICIPANT	\N	PRESENT	0
471937	470506	19735D	PARTICIPANT	\N	PRESENT	0
471938	470506	17637T	PARTICIPANT	\N	PRESENT	0
471939	470506	14257W	PARTICIPANT	\N	PRESENT	0
471940	470506	19489J	PARTICIPANT	\N	PRESENT	0
478682	477109	04049K	PRESIDENT	0	PRESENT	0
478683	477109	19575F	PARTICIPANT	\N	PRESENT	0
478684	477109	14083S	PARTICIPANT	\N	PRESENT	0
478685	477109	11099A	PARTICIPANT	\N	PRESENT	0
478686	477109	19671E	PARTICIPANT	\N	PRESENT	0
478687	477109	19515S	PARTICIPANT	\N	PRESENT	0
478688	477109	14030Q	PARTICIPANT	\N	EXCUSE	0
478689	477109	19545Y	PARTICIPANT	\N	EXCUSE	0
478690	477109	14041T	PARTICIPANT	\N	EXCUSE	0
478691	477109	19521Q	PARTICIPANT	\N	EXCUSE	0
478692	477109	14034U	PARTICIPANT	\N	EXCUSE	0
478693	477109	14026U	PARTICIPANT	\N	EXCUSE	0
478694	477109	14265W	PARTICIPANT	\N	EXCUSE	0
478695	477109	08047A	PARTICIPANT	\N	EXCUSE	0
478953	478951	96004D	PRESIDENT	0	PRESENT	0
478954	478951	11083R	PARTICIPANT	\N	PRESENT	0
478955	478951	14033T	PARTICIPANT	\N	PRESENT	0
478956	478951	12041X	PARTICIPANT	\N	PRESENT	0
478957	478951	14205J	PARTICIPANT	\N	PRESENT	0
478958	478951	11026G	PARTICIPANT	\N	PRESENT	0
478959	478951	14331P	PARTICIPANT	\N	PRESENT	0
478960	478951	14135M	PARTICIPANT	\N	PRESENT	0
481260	481255	11099A	PARTICIPANT	\N	PRESENT	0
481261	481255	04049K	PARTICIPANT	\N	PRESENT	0
481263	481262	19269X	PARTICIPANT	\N	PRESENT	0
481264	481262	14197C	PARTICIPANT	\N	PRESENT	0
481265	481262	14135M	PARTICIPANT	\N	PRESENT	0
481266	481262	19631V	PARTICIPANT	\N	PRESENT	0
481267	481262	19705W	PARTICIPANT	\N	PRESENT	0
481269	481268	14197C	PARTICIPANT	\N	PRESENT	0
481270	481268	14265W	PARTICIPANT	\N	PRESENT	0
481271	481268	14135M	PARTICIPANT	\N	PRESENT	0
481272	481268	19631V	PARTICIPANT	\N	PRESENT	0
481273	481268	19705W	PARTICIPANT	\N	PRESENT	0
481276	481274	14265W	PARTICIPANT	\N	PRESENT	0
481277	481274	14135M	PARTICIPANT	\N	PRESENT	0
481278	481274	19631V	PARTICIPANT	\N	PRESENT	0
481279	481274	19705W	PARTICIPANT	\N	PRESENT	0
481282	481280	14135M	PARTICIPANT	\N	PRESENT	0
481283	481280	19631V	PARTICIPANT	\N	PRESENT	0
481284	481280	19705W	PARTICIPANT	\N	PRESENT	0
481298	481296	01025N	PARTICIPANT	\N	PRESENT	0
481299	481296	19768N	PARTICIPANT	\N	PRESENT	0
481300	481296	14135M	PARTICIPANT	\N	PRESENT	0
481301	481296	19631V	PARTICIPANT	\N	PRESENT	0
481302	481296	19705W	PARTICIPANT	\N	PRESENT	0
481305	481304	01025N	PARTICIPANT	\N	PRESENT	0
481306	481304	19705W	PARTICIPANT	\N	PRESENT	0
481307	481304	14135M	PARTICIPANT	\N	PRESENT	0
481308	481304	19631V	PARTICIPANT	\N	PRESENT	0
481317	481315	19768N	PARTICIPANT	\N	PRESENT	0
481318	481315	14135M	PARTICIPANT	\N	PRESENT	0
481319	481315	19631V	PARTICIPANT	\N	PRESENT	0
481321	481315	19705W	PARTICIPANT	\N	PRESENT	0
481329	481326	14265W	PARTICIPANT	\N	PRESENT	0
481330	481326	19768N	PARTICIPANT	\N	PRESENT	0
481332	481326	14135M	PARTICIPANT	\N	PRESENT	0
481333	481326	19705W	PARTICIPANT	\N	PRESENT	0
481334	481326	19631V	PARTICIPANT	\N	PRESENT	0
481337	481336	19631V	PARTICIPANT	\N	PRESENT	0
481338	481336	14265W	PARTICIPANT	\N	PRESENT	0
481339	481336	19768N	PARTICIPANT	\N	PRESENT	0
481347	481344	14115H	PARTICIPANT	\N	PRESENT	0
481348	481344	14135M	PARTICIPANT	\N	PRESENT	0
481349	481344	19631V	PARTICIPANT	\N	PRESENT	0
481350	481344	19705W	PARTICIPANT	\N	PRESENT	0
481355	481353	14265W	PARTICIPANT	\N	PRESENT	0
481356	481353	14207L	PARTICIPANT	\N	PRESENT	0
481358	481353	14197C	PARTICIPANT	\N	PRESENT	0
481359	481353	14135M	PARTICIPANT	\N	PRESENT	0
481361	481353	19631V	PARTICIPANT	\N	PRESENT	0
481362	481353	19705W	PARTICIPANT	\N	PRESENT	0
481368	481367	14197C	PARTICIPANT	\N	PRESENT	0
481369	481367	19631V	PARTICIPANT	\N	PRESENT	0
481370	481367	19705W	PARTICIPANT	\N	PRESENT	0
481371	481367	14135M	PARTICIPANT	\N	PRESENT	0
481373	481372	14197C	PARTICIPANT	\N	PRESENT	0
481374	481372	08015R	PARTICIPANT	\N	PRESENT	0
481375	481372	14135M	PARTICIPANT	\N	PRESENT	0
481376	481372	19631V	PARTICIPANT	\N	PRESENT	0
481377	481372	19705W	PARTICIPANT	\N	PRESENT	0
481379	481378	14135M	PARTICIPANT	\N	PRESENT	0
481380	481378	19705W	PARTICIPANT	\N	PRESENT	0
481381	481378	19631V	PARTICIPANT	\N	PRESENT	0
481384	481383	14115H	PARTICIPANT	\N	PRESENT	0
481385	481383	14135M	PARTICIPANT	\N	PRESENT	0
481386	481383	19631V	PARTICIPANT	\N	PRESENT	0
481387	481383	19705W	PARTICIPANT	\N	PRESENT	0
481390	481389	08015R	PARTICIPANT	\N	PRESENT	0
481391	481389	14135M	PARTICIPANT	\N	PRESENT	0
481392	481389	19631V	PARTICIPANT	\N	PRESENT	0
481393	481389	19705W	PARTICIPANT	\N	PRESENT	0
481395	481394	14135M	PARTICIPANT	\N	PRESENT	0
481396	481394	19631V	PARTICIPANT	\N	PRESENT	0
481397	481394	19705W	PARTICIPANT	\N	PRESENT	0
481400	481398	14197C	PARTICIPANT	\N	PRESENT	0
481401	481398	19631V	PARTICIPANT	\N	PRESENT	0
481402	481398	14135M	PARTICIPANT	\N	PRESENT	0
481403	481398	19705W	PARTICIPANT	\N	PRESENT	0
481405	481404	14135M	PARTICIPANT	\N	PRESENT	0
481406	481404	19705W	PARTICIPANT	\N	PRESENT	0
481407	481404	19631V	PARTICIPANT	\N	PRESENT	0
481409	480873	19735D	PARTICIPANT	\N	EXCUSE	0
481410	480873	14071N	PARTICIPANT	\N	EXCUSE	0
481411	480873	14063N	PARTICIPANT	\N	EXCUSE	0
481435	481434	14135M	PARTICIPANT	\N	PRESENT	0
481436	481434	19705W	PARTICIPANT	\N	PRESENT	0
481437	481434	19631V	PARTICIPANT	\N	PRESENT	0
481438	481434	19866P	PARTICIPANT	\N	PRESENT	0
481440	481439	14135M	PARTICIPANT	\N	PRESENT	0
481441	481439	19631V	PARTICIPANT	\N	PRESENT	0
481443	481442	14135M	PARTICIPANT	\N	PRESENT	0
481444	481442	19705W	PARTICIPANT	\N	PRESENT	0
481445	481442	19631V	PARTICIPANT	\N	PRESENT	0
481446	481442	19866P	PARTICIPANT	\N	PRESENT	0
481451	481447	19705W	PARTICIPANT	\N	PRESENT	0
481449	481447	19631V	PARTICIPANT	\N	PRESENT	0
481450	481447	19866P	PARTICIPANT	\N	PRESENT	0
481453	481452	04043D	PARTICIPANT	\N	PRESENT	0
481455	481454	04043D	PARTICIPANT	\N	PRESENT	0
481457	481456	04043D	PARTICIPANT	\N	PRESENT	0
481459	481458	04043D	PARTICIPANT	\N	PRESENT	0
481461	481460	04043D	PARTICIPANT	\N	PRESENT	0
481463	481462	04043D	PARTICIPANT	\N	PRESENT	0
481519	480855	08053X	PARTICIPANT	\N	PRESENT	0
481520	480855	04044E	PARTICIPANT	\N	PRESENT	0
481521	480855	19719D	PARTICIPANT	\N	EXCUSE	0
481537	479100	04059M	PARTICIPANT	\N	PRESENT	0
481538	479100	04085P	PARTICIPANT	\N	PRESENT	0
481539	479100	19760E	PARTICIPANT	\N	PRESENT	0
481540	479100	19697Q	PARTICIPANT	\N	PRESENT	0
481541	479100	19383Y	PARTICIPANT	\N	PRESENT	0
481542	479100	11012A	PARTICIPANT	\N	PRESENT	0
481543	479100	07004J	PARTICIPANT	\N	PRESENT	0
481544	479100	19563B	PARTICIPANT	\N	PRESENT	0
481545	479100	19758L	PARTICIPANT	\N	PRESENT	0
481546	479100	19695N	PARTICIPANT	\N	PRESENT	0
481547	479100	11097X	PARTICIPANT	\N	PRESENT	0
481548	479100	11031D	PARTICIPANT	\N	PRESENT	0
481549	479100	14115H	PARTICIPANT	\N	PRESENT	0
481550	479100	14135M	PARTICIPANT	\N	PRESENT	0
481551	479100	19551W	PARTICIPANT	\N	PRESENT	0
481552	479100	14042U	PARTICIPANT	\N	PRESENT	0
481554	479100	17779H	PARTICIPANT	\N	PRESENT	0
481556	479100	19413M	PARTICIPANT	\N	PRESENT	0
481558	479100	14069U	PARTICIPANT	\N	PRESENT	0
481563	479100	19369B	PARTICIPANT	\N	PRESENT	0
481574	479100	19719D	PARTICIPANT	\N	PRESENT	0
481627	473435	86034E	PARTICIPANT	\N	PRESENT	0
481628	480977	04086Q	PARTICIPANT	\N	PRESENT	0
481629	480977	19711U	PARTICIPANT	\N	PRESENT	0
481630	480977	01057W	PARTICIPANT	\N	PRESENT	0
481631	480977	08010L	PARTICIPANT	\N	PRESENT	0
481632	480977	19741B	PARTICIPANT	\N	PRESENT	0
481633	480977	99004R	PARTICIPANT	\N	PRESENT	0
481634	480977	11070L	PARTICIPANT	\N	PRESENT	0
481635	480977	11074Q	PRESIDENT	0	PRESENT	0
481636	480977	08011M	PARTICIPANT	\N	PRESENT	0
481637	480977	11048N	PARTICIPANT	\N	PRESENT	0
481638	480977	19647E	PARTICIPANT	\N	PRESENT	0
455121	454055	11066Q	PARTICIPANT	\N	PRESENT	0
455122	454055	19669L	PARTICIPANT	\N	PRESENT	0
455123	454055	08056B	PARTICIPANT	\N	PRESENT	0
455124	454055	11115U	PARTICIPANT	\N	PRESENT	0
455125	454055	95037J	PARTICIPANT	\N	PRESENT	0
455126	454055	14055N	PARTICIPANT	\N	PRESENT	0
455127	454055	19421M	PARTICIPANT	\N	PRESENT	0
455128	454055	19709B	PARTICIPANT	\N	PRESENT	0
455129	454055	14193X	PARTICIPANT	\N	PRESENT	0
455130	454055	08053X	PARTICIPANT	\N	PRESENT	0
455131	454055	97011G	PARTICIPANT	\N	PRESENT	0
455132	454055	08061X	PARTICIPANT	\N	PRESENT	0
455133	454055	08047A	PARTICIPANT	\N	PRESENT	0
455134	454055	95067Q	PARTICIPANT	\N	PRESENT	0
455135	454055	14133K	PARTICIPANT	\N	PRESENT	0
455136	454055	01062T	PARTICIPANT	\N	PRESENT	0
455137	454055	11041F	PARTICIPANT	\N	PRESENT	0
455138	454055	14235Q	PARTICIPANT	\N	PRESENT	0
455139	454055	08058D	PARTICIPANT	\N	PRESENT	0
455140	454055	19251M	PARTICIPANT	\N	PRESENT	0
455141	454055	19721W	PARTICIPANT	\N	PRESENT	0
455142	454055	14105F	PARTICIPANT	\N	PRESENT	0
455143	454055	98018T	PARTICIPANT	\N	PRESENT	0
455144	454055	98022P	PARTICIPANT	\N	PRESENT	0
455145	454055	14267Y	PARTICIPANT	\N	PRESENT	0
455146	454055	98050T	PARTICIPANT	\N	PRESENT	0
455147	454055	14211G	PARTICIPANT	\N	PRESENT	0
455148	454055	14255U	PARTICIPANT	\N	PRESENT	0
455149	454258	14001X	PARTICIPANT	\N	PRESENT	0
455150	454258	11026G	PARTICIPANT	\N	PRESENT	0
455151	454258	08044W	PARTICIPANT	\N	PRESENT	0
455152	454258	11085T	PARTICIPANT	\N	PRESENT	0
455153	454928	19643A	PARTICIPANT	\N	PRESENT	0
455154	454928	14251Q	PARTICIPANT	\N	PRESENT	0
455155	454928	19735D	PARTICIPANT	\N	EXCUSE	0
455156	454258	19649G	PARTICIPANT	\N	PRESENT	0
455157	453808	19383Y	PARTICIPANT	\N	PRESENT	0
455158	453808	14355X	PARTICIPANT	\N	PRESENT	0
455159	453808	19749K	PARTICIPANT	\N	PRESENT	0
455160	453967	01048V	PARTICIPANT	\N	PRESENT	0
455161	453967	19531S	PARTICIPANT	\N	PRESENT	0
455162	454258	08018U	PARTICIPANT	\N	PRESENT	0
455163	454928	04057K	PARTICIPANT	\N	PRESENT	0
455164	454259	14001X	PARTICIPANT	\N	PRESENT	0
455165	454259	19543W	PARTICIPANT	\N	PRESENT	0
455166	454259	04044E	PARTICIPANT	\N	PRESENT	0
455411	454065	19443T	PARTICIPANT	\N	PRESENT	0
455168	454259	19585H	PARTICIPANT	\N	PRESENT	0
455169	454259	04047H	PARTICIPANT	\N	PRESENT	0
455170	454259	19673G	PARTICIPANT	\N	PRESENT	0
455171	454259	01028R	PARTICIPANT	\N	PRESENT	0
455172	454259	05008E	PRESIDENT	0	PRESENT	0
455173	454259	19447X	PARTICIPANT	\N	PRESENT	0
455174	454259	14231L	PARTICIPANT	\N	PRESENT	0
455175	454259	19489J	PARTICIPANT	\N	PRESENT	0
455176	454259	14041T	PARTICIPANT	\N	PRESENT	0
455177	454259	14147R	PARTICIPANT	\N	PRESENT	0
455178	454259	14179A	PARTICIPANT	\N	PRESENT	0
455179	454259	14151M	PARTICIPANT	\N	PRESENT	0
455412	454065	12041X	PARTICIPANT	\N	PRESENT	0
455181	454259	14259Y	PARTICIPANT	\N	PRESENT	0
455182	454259	11072N	PARTICIPANT	\N	PRESENT	0
455183	454259	14053L	PARTICIPANT	\N	PRESENT	0
455184	454259	98035U	PARTICIPANT	\N	PRESENT	0
455185	454259	14065Q	PARTICIPANT	\N	PRESENT	0
455186	454259	19649G	PARTICIPANT	\N	PRESENT	0
455187	454259	11010L	PARTICIPANT	\N	PRESENT	0
455188	454259	08045X	PARTICIPANT	\N	PRESENT	0
455189	454259	11026G	PARTICIPANT	\N	PRESENT	0
455190	454259	19253P	PARTICIPANT	\N	PRESENT	0
455191	454259	01024M	PARTICIPANT	\N	PRESENT	0
455192	454259	04038G	PARTICIPANT	\N	PRESENT	0
455193	454259	19719D	PARTICIPANT	\N	PRESENT	0
455194	454259	11033F	PARTICIPANT	\N	PRESENT	0
455195	454259	19725B	PARTICIPANT	\N	PRESENT	0
455196	454259	14089Y	PARTICIPANT	\N	PRESENT	0
455197	454259	19729F	PARTICIPANT	\N	PRESENT	0
455198	454259	95063L	PARTICIPANT	\N	PRESENT	0
455199	454259	19629C	PARTICIPANT	\N	PRESENT	0
455200	454259	08044W	PARTICIPANT	\N	PRESENT	0
455201	454259	14069U	PARTICIPANT	\N	PRESENT	0
455202	454259	11085T	PARTICIPANT	\N	PRESENT	0
455203	454259	19762G	PARTICIPANT	\N	PRESENT	0
455204	454259	14215L	PARTICIPANT	\N	PRESENT	0
455205	454259	14021P	PARTICIPANT	\N	PRESENT	0
455206	454928	11109J	PARTICIPANT	\N	PRESENT	0
455207	454928	14123H	PARTICIPANT	\N	PRESENT	0
455315	454867	19333N	PARTICIPANT	\N	PRESENT	0
455316	454867	19794Q	PARTICIPANT	\N	PRESENT	0
455317	454867	19387D	PARTICIPANT	\N	PRESENT	0
455318	454867	19820Y	PARTICIPANT	\N	PRESENT	0
455319	454867	14219Q	PARTICIPANT	\N	PRESENT	0
455320	454867	19826F	PARTICIPANT	\N	PRESENT	0
455321	454867	14221J	PARTICIPANT	\N	PRESENT	0
455322	454867	19599P	PARTICIPANT	\N	PRESENT	0
455323	454867	19637C	PARTICIPANT	\N	PRESENT	0
455324	454867	14237S	PARTICIPANT	\N	PRESENT	0
455325	454867	18083K	PARTICIPANT	\N	PRESENT	0
455326	454867	19551W	PARTICIPANT	\N	PRESENT	0
455327	454867	05012A	PARTICIPANT	\N	PRESENT	0
455328	454867	08060W	PARTICIPANT	\N	PRESENT	0
455329	454867	19503N	PARTICIPANT	\N	PRESENT	0
455330	454867	19347U	PARTICIPANT	\N	PRESENT	0
455331	454867	14157T	PARTICIPANT	\N	PRESENT	0
455332	454867	08024S	PARTICIPANT	\N	PRESENT	0
455434	454065	19533U	PARTICIPANT	\N	PRESENT	0
455443	454065	14026U	PARTICIPANT	\N	PRESENT	0
455335	454867	11065P	PARTICIPANT	\N	PRESENT	0
455336	454867	19525U	PARTICIPANT	\N	PRESENT	0
455337	454867	14038Y	PRESIDENT	0	PRESENT	0
455338	454867	14103D	PARTICIPANT	\N	PRESENT	0
455339	454867	14031R	PARTICIPANT	\N	PRESENT	0
455340	454867	19713W	PARTICIPANT	\N	PRESENT	0
455341	454867	08055A	PARTICIPANT	\N	PRESENT	0
455435	454065	19569H	PARTICIPANT	\N	PRESENT	0
455343	454867	14169X	PARTICIPANT	\N	PRESENT	0
455344	454867	15447F	PARTICIPANT	\N	PRESENT	0
455345	454867	14093U	PARTICIPANT	\N	PRESENT	0
455346	454867	19737F	PARTICIPANT	\N	PRESENT	0
455347	454867	04097T	PARTICIPANT	\N	PRESENT	0
455348	454867	19739H	PARTICIPANT	\N	PRESENT	0
455436	454065	19812Y	PARTICIPANT	\N	PRESENT	0
455410	454065	04042C	PRESIDENT	0	PRESENT	0
455413	454065	95030B	PARTICIPANT	\N	PRESENT	0
455414	454065	04034C	PARTICIPANT	\N	PRESENT	0
455415	454065	01058X	PARTICIPANT	\N	PRESENT	0
455416	454065	16685X	PARTICIPANT	\N	PRESENT	0
455417	454065	08058D	PARTICIPANT	\N	PRESENT	0
455418	454065	19669L	PARTICIPANT	\N	PRESENT	0
455419	454065	11066Q	PARTICIPANT	\N	PRESENT	0
455420	454065	08056B	PARTICIPANT	\N	PRESENT	0
455421	454065	98018T	PARTICIPANT	\N	PRESENT	0
455422	454065	14267Y	PARTICIPANT	\N	PRESENT	0
455423	454065	98050T	PARTICIPANT	\N	PRESENT	0
455424	454065	14255U	PARTICIPANT	\N	PRESENT	0
455425	454065	96004D	PARTICIPANT	\N	PRESENT	0
455426	454065	19251M	PARTICIPANT	\N	PRESENT	0
455427	454065	95037J	PARTICIPANT	\N	PRESENT	0
455428	454065	11083R	PARTICIPANT	\N	PRESENT	0
455429	454065	11027H	PARTICIPANT	\N	PRESENT	0
455430	454065	19521Q	PARTICIPANT	\N	PRESENT	0
455437	454065	14079W	PARTICIPANT	\N	PRESENT	0
455438	454065	14001X	PARTICIPANT	\N	PRESENT	0
455439	454065	14241N	PARTICIPANT	\N	PRESENT	0
455440	454065	11026G	PARTICIPANT	\N	PRESENT	0
455441	454065	19725B	PARTICIPANT	\N	PRESENT	0
455442	454065	08043V	PARTICIPANT	\N	PRESENT	0
455444	454065	04057K	PARTICIPANT	\N	PRESENT	0
455445	454065	14169X	PARTICIPANT	\N	PRESENT	0
455446	454065	14089Y	PARTICIPANT	\N	PRESENT	0
455447	454065	04097T	PARTICIPANT	\N	PRESENT	0
455448	454065	14331P	PARTICIPANT	\N	PRESENT	0
455451	454065	08053X	PARTICIPANT	\N	PRESENT	0
455452	454065	01062T	PARTICIPANT	\N	PRESENT	0
455453	448750	86034E	PARTICIPANT	\N	PRESENT	0
455454	454065	19705W	PARTICIPANT	\N	PRESENT	0
455458	448750	14267Y	PARTICIPANT	\N	PRESENT	0
455459	448750	19739H	PARTICIPANT	\N	PRESENT	0
455460	448750	14103D	PARTICIPANT	\N	PRESENT	0
455461	448750	04089T	PARTICIPANT	\N	PRESENT	0
455462	448750	19737F	PARTICIPANT	\N	PRESENT	0
455464	448750	19569H	PARTICIPANT	\N	PRESENT	0
455465	448750	14179A	PARTICIPANT	\N	PRESENT	0
455467	448750	01025N	PARTICIPANT	\N	PRESENT	0
455470	448750	14221J	PARTICIPANT	\N	PRESENT	0
455471	448750	19721W	PARTICIPANT	\N	PRESENT	0
455472	448750	19511N	PARTICIPANT	\N	PRESENT	0
455473	448750	19826F	PARTICIPANT	\N	PRESENT	0
455474	448750	14231L	PARTICIPANT	\N	PRESENT	0
472991	472056	19543W	PARTICIPANT	\N	PRESENT	0
472992	472056	19629C	PARTICIPANT	\N	PRESENT	0
472993	472056	14259Y	PARTICIPANT	\N	PRESENT	0
472994	472056	04008A	PARTICIPANT	\N	PRESENT	0
472998	472056	19673G	PARTICIPANT	\N	PRESENT	0
473000	472056	19649G	PARTICIPANT	\N	PRESENT	0
473001	472056	19762G	PARTICIPANT	\N	PRESENT	0
473002	472057	19543W	PARTICIPANT	\N	PRESENT	0
473003	472057	19629C	PARTICIPANT	\N	PRESENT	0
473004	472057	14259Y	PARTICIPANT	\N	PRESENT	0
473005	472057	04008A	PARTICIPANT	\N	PRESENT	0
473007	472057	19762G	PARTICIPANT	\N	PRESENT	0
473011	472058	19543W	PARTICIPANT	\N	PRESENT	0
473012	472058	19629C	PARTICIPANT	\N	PRESENT	0
473013	472058	14259Y	PARTICIPANT	\N	PRESENT	0
473015	472058	04008A	PARTICIPANT	\N	PRESENT	0
473016	472058	19762G	PARTICIPANT	\N	PRESENT	0
473018	472060	19543W	PARTICIPANT	\N	PRESENT	0
473019	472060	19629C	PARTICIPANT	\N	PRESENT	0
473020	472060	14259Y	PARTICIPANT	\N	PRESENT	0
473021	472060	04008A	PARTICIPANT	\N	PRESENT	0
473023	472060	19649G	PARTICIPANT	\N	PRESENT	0
473024	472060	19762G	PARTICIPANT	\N	PRESENT	0
476815	476356	95063L	PARTICIPANT	\N	PRESENT	0
476816	476356	11026G	PARTICIPANT	\N	PRESENT	0
476817	476356	14179A	PARTICIPANT	\N	PRESENT	0
476818	476356	14147R	PARTICIPANT	\N	PRESENT	0
476819	476356	14069U	PARTICIPANT	\N	PRESENT	0
476820	476356	14151M	PARTICIPANT	\N	PRESENT	0
476821	476356	14215L	PRESIDENT	1	PRESENT	0
476822	476356	05008E	PRESIDENT	0	PRESENT	0
476823	476356	19447X	PARTICIPANT	\N	PRESENT	0
476827	475689	04040A	PARTICIPANT	\N	PRESENT	0
476849	475689	14235Q	PARTICIPANT	\N	PRESENT	0
476852	475689	04035D	PARTICIPANT	\N	PRESENT	0
476853	476356	14053L	PARTICIPANT	\N	PRESENT	0
476854	476356	14111D	PARTICIPANT	\N	PRESENT	0
476855	476356	11085T	PARTICIPANT	\N	PRESENT	0
476856	476356	04008A	PARTICIPANT	\N	PRESENT	0
476858	476188	14085U	PARTICIPANT	\N	PRESENT	0
476976	476357	14041T	PARTICIPANT	\N	PRESENT	0
476860	476188	11074Q	PRESIDENT	0	PRESENT	0
476861	476188	89017R	PARTICIPANT	\N	PRESENT	0
476862	476188	99004R	PARTICIPANT	\N	PRESENT	0
476863	476188	19741B	PARTICIPANT	\N	PRESENT	0
476864	476188	08010L	PARTICIPANT	\N	PRESENT	0
476865	476188	14034U	PARTICIPANT	\N	EXCUSE	0
476866	476188	19711U	PARTICIPANT	\N	PRESENT	0
476867	476188	11012A	PARTICIPANT	\N	PRESENT	0
476869	476188	19647E	PARTICIPANT	\N	PRESENT	0
476870	476188	08034U	PARTICIPANT	\N	PRESENT	0
476871	476188	04086Q	PARTICIPANT	\N	PRESENT	0
476872	476188	96004D	PARTICIPANT	\N	PRESENT	0
476977	476357	11026G	PARTICIPANT	\N	PRESENT	0
476978	476357	14147R	PARTICIPANT	\N	PRESENT	0
476979	476357	14069U	PARTICIPANT	\N	PRESENT	0
476980	476357	14215L	PARTICIPANT	\N	PRESENT	0
476981	476357	05008E	PRESIDENT	0	PRESENT	0
476982	476357	19447X	PARTICIPANT	\N	PRESENT	0
477295	473395	14357A	PARTICIPANT	\N	PRESENT	0
477296	473395	11033F	PARTICIPANT	\N	PRESENT	0
477300	473395	14021P	PARTICIPANT	\N	PRESENT	0
477312	473395	01028R	PARTICIPANT	\N	PRESENT	0
477313	473395	11026G	PARTICIPANT	\N	PRESENT	0
477314	473395	19733B	PARTICIPANT	\N	PRESENT	0
477315	473395	19687N	PARTICIPANT	\N	PRESENT	0
477316	473395	14115H	PARTICIPANT	\N	PRESENT	0
477317	473395	19705W	PARTICIPANT	\N	PRESENT	0
477321	473395	95030B	PARTICIPANT	\N	PRESENT	0
477323	473395	19545Y	PARTICIPANT	\N	PRESENT	0
477355	473396	19563B	PARTICIPANT	\N	PRESENT	0
477356	473396	11012A	PARTICIPANT	\N	PRESENT	0
477357	473396	19629C	PARTICIPANT	\N	PRESENT	0
477358	473396	01028R	PARTICIPANT	\N	PRESENT	0
477359	473396	04034C	PARTICIPANT	\N	PRESENT	0
477360	473396	17779H	PARTICIPANT	\N	PRESENT	0
477361	473396	11027H	PARTICIPANT	\N	PRESENT	0
477362	473396	19820Y	PARTICIPANT	\N	PRESENT	0
477363	473396	11026G	PARTICIPANT	\N	PRESENT	0
477364	473396	05008E	PARTICIPANT	\N	PRESENT	0
477365	473396	14215L	PARTICIPANT	\N	PRESENT	0
477366	473396	19687N	PARTICIPANT	\N	PRESENT	0
477367	473396	19565D	PARTICIPANT	\N	PRESENT	0
477368	473396	19733B	PARTICIPANT	\N	PRESENT	0
477369	473396	14115H	PARTICIPANT	\N	PRESENT	0
477370	473396	19766L	PARTICIPANT	\N	PRESENT	0
477371	473396	95030B	PARTICIPANT	\N	PRESENT	0
477372	473396	14135M	PARTICIPANT	\N	PRESENT	0
477376	473396	14357A	PARTICIPANT	\N	PRESENT	0
477377	473396	19705W	PARTICIPANT	\N	PRESENT	0
477378	473396	19447X	PARTICIPANT	\N	PRESENT	0
477379	473396	14041T	PARTICIPANT	\N	PRESENT	0
477380	473396	19599P	PARTICIPANT	\N	PRESENT	0
477381	473396	14021P	PARTICIPANT	\N	PRESENT	0
477383	473396	08061X	PARTICIPANT	\N	PRESENT	0
477385	473396	15447F	PARTICIPANT	\N	PRESENT	0
477386	473396	19760E	PARTICIPANT	\N	PRESENT	0
477387	473396	04044E	PARTICIPANT	\N	PRESENT	0
477389	473396	19413M	PARTICIPANT	\N	PRESENT	0
477353	473396	14179A	PARTICIPANT	\N	PRESENT	0
477354	473396	19545Y	PARTICIPANT	\N	PRESENT	0
477392	473396	14069U	PARTICIPANT	\N	PRESENT	0
477412	473396	11085T	PARTICIPANT	\N	PRESENT	0
477414	473396	19593H	PARTICIPANT	\N	PRESENT	0
477418	473396	19333N	PARTICIPANT	\N	PRESENT	0
477430	473396	14331P	PARTICIPANT	\N	PRESENT	0
480204	473421	19533U	PARTICIPANT	\N	PRESENT	0
480205	473421	19413M	PARTICIPANT	\N	PRESENT	0
480206	473421	08034U	PARTICIPANT	\N	PRESENT	0
480207	473421	19723Y	PARTICIPANT	\N	PRESENT	0
480208	473421	11103C	PARTICIPANT	\N	PRESENT	0
480209	473421	19709B	PARTICIPANT	\N	PRESENT	0
480226	473421	14041T	PARTICIPANT	\N	PRESENT	0
480236	473421	14213J	PARTICIPANT	\N	PRESENT	0
480219	473421	01058X	PARTICIPANT	\N	PRESENT	0
480213	473421	14357A	PARTICIPANT	\N	PRESENT	0
480214	473421	05012A	PARTICIPANT	\N	PRESENT	0
480215	473421	11043H	PARTICIPANT	\N	PRESENT	0
480216	473421	19563B	PARTICIPANT	\N	PRESENT	0
480217	473421	19399H	PARTICIPANT	\N	PRESENT	0
480218	473421	14157T	PARTICIPANT	\N	PRESENT	0
480220	473421	14033T	PARTICIPANT	\N	PRESENT	0
480235	473421	11097X	PARTICIPANT	\N	PRESENT	0
480227	473421	19651A	PARTICIPANT	\N	PRESENT	0
480223	473421	18083K	PARTICIPANT	\N	PRESENT	0
480243	479058	19760E	PARTICIPANT	\N	PRESENT	0
480225	473421	08019V	PARTICIPANT	\N	PRESENT	0
480228	473421	19467C	PARTICIPANT	\N	PRESENT	0
480229	473421	08009T	PARTICIPANT	\N	PRESENT	0
480230	473421	14038Y	PARTICIPANT	\N	PRESENT	0
480231	473421	19663E	PARTICIPANT	\N	PRESENT	0
480232	473421	10006L	PARTICIPANT	\N	PRESENT	0
480233	473421	04092N	PARTICIPANT	\N	PRESENT	0
480234	473421	19741B	PARTICIPANT	\N	PRESENT	0
480237	473421	14021P	PARTICIPANT	\N	PRESENT	0
480241	473421	89017R	PARTICIPANT	\N	PRESENT	0
480240	473421	14331P	PARTICIPANT	\N	PRESENT	0
480242	473421	04059M	PARTICIPANT	\N	PRESENT	0
480244	479058	19415P	PARTICIPANT	\N	PRESENT	0
480245	479058	11103C	PARTICIPANT	\N	PRESENT	0
480246	479058	08052W	PARTICIPANT	\N	PRESENT	0
480247	479058	98024R	PARTICIPANT	\N	PRESENT	0
480248	479058	14026U	PARTICIPANT	\N	PRESENT	0
480249	479058	19691J	PARTICIPANT	\N	PRESENT	0
480250	479058	19569H	PARTICIPANT	\N	PRESENT	0
480251	479058	19715Y	PARTICIPANT	\N	PRESENT	0
480252	479058	17779H	PARTICIPANT	\N	PRESENT	0
480253	479058	11067R	PARTICIPANT	\N	PRESENT	0
480254	479058	04092N	PRESIDENT	0	PRESENT	0
480255	479058	14119M	PARTICIPANT	\N	PRESENT	0
480256	479058	14071N	PARTICIPANT	\N	PRESENT	0
480257	479058	11097X	PARTICIPANT	\N	PRESENT	0
480258	479058	19301E	PARTICIPANT	\N	PRESENT	0
480259	479058	01034P	PARTICIPANT	\N	PRESENT	0
480260	479058	19717B	PARTICIPANT	\N	PRESENT	0
480261	479058	19575F	PARTICIPANT	\N	PRESENT	0
480262	479058	14195A	PARTICIPANT	\N	PRESENT	0
480263	479058	14042U	PARTICIPANT	\N	PRESENT	0
480264	479058	08048B	PARTICIPANT	\N	PRESENT	0
480265	479058	19565D	PARTICIPANT	\N	PRESENT	0
480266	479058	19553Y	PARTICIPANT	\N	PRESENT	0
480267	479058	14213J	PARTICIPANT	\N	PRESENT	0
480268	479058	19723Y	PARTICIPANT	\N	PRESENT	0
480269	479058	19657G	PARTICIPANT	\N	PRESENT	0
480270	479058	14223L	PARTICIPANT	\N	PRESENT	0
480271	479058	19679N	PARTICIPANT	\N	PRESENT	0
480272	479058	19798U	PARTICIPANT	\N	PRESENT	0
480273	479058	19703U	PARTICIPANT	\N	PRESENT	0
480274	473421	19531S	PARTICIPANT	\N	PRESENT	0
455252	455105	08010L	PARTICIPANT	\N	EXCUSE	0
455253	455106	08010L	PARTICIPANT	\N	EXCUSE	0
457192	455746	19766L	PARTICIPANT	\N	PRESENT	0
457193	455746	14059S	PARTICIPANT	\N	PRESENT	0
457194	455746	08043V	PARTICIPANT	\N	PRESENT	0
457195	455746	04059M	PARTICIPANT	\N	PRESENT	0
457196	455746	14107H	PARTICIPANT	\N	PRESENT	0
457197	455746	11083R	PARTICIPANT	\N	EXCUSE	0
457198	455746	19593H	PARTICIPANT	\N	PRESENT	0
457199	455746	19533U	PARTICIPANT	\N	PRESENT	0
457200	455746	87003B	PARTICIPANT	\N	PRESENT	0
457201	455746	19621T	PARTICIPANT	\N	PRESENT	0
457202	455746	08017T	PARTICIPANT	\N	PRESENT	0
457203	455746	19335Q	PARTICIPANT	\N	PRESENT	0
457207	455746	14229S	PARTICIPANT	\N	PRESENT	0
457208	455746	14241N	PARTICIPANT	\N	PRESENT	0
457209	455746	08039A	PARTICIPANT	\N	PRESENT	0
457210	455746	08031R	PARTICIPANT	\N	PRESENT	0
457211	455746	14251Q	PARTICIPANT	\N	PRESENT	0
457212	455746	08020N	PARTICIPANT	\N	PRESENT	0
457213	455746	19573D	PARTICIPANT	\N	PRESENT	0
457214	455746	08012N	PARTICIPANT	\N	PRESENT	0
457215	455746	11104D	PARTICIPANT	\N	PRESENT	0
457217	455746	07033P	PARTICIPANT	\N	PRESENT	0
457218	455746	14073Q	PARTICIPANT	\N	PRESENT	0
457219	456490	95030B	PARTICIPANT	\N	PRESENT	0
457220	456490	11027H	PARTICIPANT	\N	PRESENT	0
457221	456490	14097Y	PARTICIPANT	\N	PRESENT	0
457222	456490	04035D	PARTICIPANT	\N	PRESENT	0
457223	456490	95067Q	PARTICIPANT	\N	PRESENT	0
457224	456490	08058D	PARTICIPANT	\N	PRESENT	0
457229	456491	19443T	PARTICIPANT	\N	PRESENT	0
457230	456491	12041X	PARTICIPANT	\N	PRESENT	0
457231	456491	95030B	PARTICIPANT	\N	PRESENT	0
457232	456491	04034C	PARTICIPANT	\N	PRESENT	0
457233	456491	14079W	PARTICIPANT	\N	PRESENT	0
457234	456491	01058X	PARTICIPANT	\N	PRESENT	0
457235	456491	04040A	PARTICIPANT	\N	PRESENT	0
457236	456491	16685X	PARTICIPANT	\N	PRESENT	0
457237	456491	11027H	PARTICIPANT	\N	PRESENT	0
457238	456491	04042C	PRESIDENT	0	PRESENT	0
457239	456491	11054L	PARTICIPANT	\N	PRESENT	0
457240	456491	19669L	PARTICIPANT	\N	PRESENT	0
457241	456491	08056B	PARTICIPANT	\N	PRESENT	0
457242	456491	11115U	PARTICIPANT	\N	PRESENT	0
457243	456491	95037J	PARTICIPANT	\N	PRESENT	0
457244	456491	14055N	PARTICIPANT	\N	PRESENT	0
457245	456491	19421M	PARTICIPANT	\N	PRESENT	0
457246	456491	08049C	PARTICIPANT	\N	PRESENT	0
457247	456491	14193X	PRESIDENT	1	PRESENT	0
457248	456491	08053X	PARTICIPANT	\N	PRESENT	0
457249	456491	97011G	PARTICIPANT	\N	PRESENT	0
457250	456491	08061X	PARTICIPANT	\N	PRESENT	0
457251	456491	08047A	PARTICIPANT	\N	PRESENT	0
457252	456491	98029W	PARTICIPANT	\N	PRESENT	0
457253	456491	14097Y	PARTICIPANT	\N	PRESENT	0
457254	456491	04035D	PARTICIPANT	\N	PRESENT	0
457255	456491	95067Q	PARTICIPANT	\N	PRESENT	0
457256	456491	01062T	PARTICIPANT	\N	PRESENT	0
457257	456491	11041F	PARTICIPANT	\N	PRESENT	0
457258	456491	08058D	PARTICIPANT	\N	PRESENT	0
457259	456491	19251M	PARTICIPANT	\N	PRESENT	0
457260	456491	19721W	PARTICIPANT	\N	PRESENT	0
457261	456491	19319Q	PARTICIPANT	\N	PRESENT	0
457262	456491	14105F	PARTICIPANT	\N	PRESENT	0
457263	456491	98018T	PARTICIPANT	\N	PRESENT	0
457264	456491	11064N	PARTICIPANT	\N	PRESENT	0
457265	456491	98050T	PARTICIPANT	\N	PRESENT	0
457266	456491	14211G	PARTICIPANT	\N	PRESENT	0
457267	456491	14133K	PARTICIPANT	\N	PRESENT	0
457268	455746	14249W	PARTICIPANT	\N	PRESENT	0
457269	455746	04057K	PARTICIPANT	\N	PRESENT	0
457270	455746	14063N	PARTICIPANT	\N	PRESENT	0
457271	455746	11043H	PARTICIPANT	\N	PRESENT	0
457272	455746	19749K	PARTICIPANT	\N	PRESENT	0
457273	456490	19709B	PARTICIPANT	\N	PRESENT	0
457274	456490	14133K	PARTICIPANT	\N	PRESENT	0
457275	456490	14267Y	PARTICIPANT	\N	PRESENT	0
457276	456491	19709B	PARTICIPANT	\N	PRESENT	0
457277	456491	14267Y	PARTICIPANT	\N	PRESENT	0
457278	455746	14039A	PARTICIPANT	\N	PRESENT	0
457440	456226	19651A	PARTICIPANT	\N	PRESENT	0
457520	456710	14259Y	PARTICIPANT	\N	PRESENT	0
457578	448757	11072N	PARTICIPANT	\N	PRESENT	0
457579	448757	80013X	PARTICIPANT	\N	PRESENT	0
457580	448757	11041F	PARTICIPANT	\N	PRESENT	0
457581	448757	08068F	PARTICIPANT	\N	PRESENT	0
457582	448757	08052W	PARTICIPANT	\N	PRESENT	0
457583	448757	14063N	PARTICIPANT	\N	PRESENT	0
457584	448757	19715Y	PARTICIPANT	\N	PRESENT	0
457585	448757	14257W	PARTICIPANT	\N	PRESENT	0
457586	448757	19681G	PARTICIPANT	\N	PRESENT	0
457587	448757	14107H	PARTICIPANT	\N	PRESENT	0
457588	448757	11067R	PARTICIPANT	\N	PRESENT	0
457589	448757	08043V	PARTICIPANT	\N	PRESENT	0
457590	448757	11027H	PARTICIPANT	\N	PRESENT	0
457591	448757	19349W	PARTICIPANT	\N	PRESENT	0
457592	448757	14195A	PARTICIPANT	\N	PRESENT	0
457593	448757	11045K	PARTICIPANT	\N	PRESENT	0
457594	448757	19699S	PARTICIPANT	\N	PRESENT	0
457595	448757	14219Q	PARTICIPANT	\N	PRESENT	0
457596	448757	14179A	PARTICIPANT	\N	PRESENT	0
457597	448757	19569H	PARTICIPANT	\N	PRESENT	0
457598	448757	08055A	PARTICIPANT	\N	PRESENT	0
457599	448757	19669L	PARTICIPANT	\N	PRESENT	0
457600	448757	14267Y	PARTICIPANT	\N	PRESENT	0
457601	448757	08045X	PARTICIPANT	\N	PRESENT	0
457602	448757	19619A	PARTICIPANT	\N	PRESENT	0
457603	448757	19737F	PARTICIPANT	\N	PRESENT	0
457604	448757	19511N	PARTICIPANT	\N	PRESENT	0
457605	448757	14227Q	PARTICIPANT	\N	PRESENT	0
457606	448757	04045F	PARTICIPANT	\N	PRESENT	0
457607	448757	08024S	PARTICIPANT	\N	PRESENT	0
457608	448757	19697Q	PARTICIPANT	\N	PRESENT	0
457609	448757	14207L	PARTICIPANT	\N	PRESENT	0
457610	448757	01028R	PARTICIPANT	\N	PRESENT	0
457611	448757	98029W	PARTICIPANT	\N	PRESENT	0
457612	448757	14039A	PARTICIPANT	\N	PRESENT	0
457613	448757	95037J	PARTICIPANT	\N	PRESENT	0
457614	448757	19812Y	PARTICIPANT	\N	PRESENT	0
457615	448757	14261S	PARTICIPANT	\N	PRESENT	0
457616	448757	04059M	PARTICIPANT	\N	PRESENT	0
457617	448757	11040E	PARTICIPANT	\N	PRESENT	0
457618	448757	19489J	PARTICIPANT	\N	PRESENT	0
457619	448757	11056N	PARTICIPANT	\N	PRESENT	0
457620	448757	04040A	PARTICIPANT	\N	PRESENT	0
457621	448757	14205J	PARTICIPANT	\N	PRESENT	0
457622	448757	14201E	PARTICIPANT	\N	PRESENT	0
457623	448757	19637C	PARTICIPANT	\N	PRESENT	0
457624	448757	19651A	PARTICIPANT	\N	PRESENT	0
457625	448757	08061X	PARTICIPANT	\N	PRESENT	0
457626	454193	14093U	PARTICIPANT	\N	PRESENT	0
457627	454193	14051J	PARTICIPANT	\N	PRESENT	0
457628	454193	08060W	PARTICIPANT	\N	PRESENT	0
457629	454193	08009T	PRESIDENT	0	PRESENT	0
457630	454193	19367Y	PARTICIPANT	\N	PRESENT	0
457631	454193	19251M	PARTICIPANT	\N	PRESENT	0
457632	454193	19581D	PARTICIPANT	\N	PRESENT	0
457633	454193	19826F	PARTICIPANT	\N	PRESENT	0
457634	454193	19758L	PARTICIPANT	\N	PRESENT	0
457635	454193	14026U	PARTICIPANT	\N	EXCUSE	0
457636	448757	04085P	PARTICIPANT	\N	PRESENT	0
457637	448757	14211G	PARTICIPANT	\N	PRESENT	0
457638	448757	12041X	PARTICIPANT	\N	PRESENT	0
457639	448757	19711U	PARTICIPANT	\N	PRESENT	0
457640	448757	11031D	PARTICIPANT	\N	PRESENT	0
457641	448757	19760E	PARTICIPANT	\N	PRESENT	0
457642	448757	08011M	PARTICIPANT	\N	PRESENT	0
457644	448757	19695N	PARTICIPANT	\N	PRESENT	0
457647	448757	19687N	PARTICIPANT	\N	PRESENT	0
457649	448757	19593H	PARTICIPANT	\N	PRESENT	0
457650	448757	11033F	PARTICIPANT	\N	PRESENT	0
457651	448757	19443T	PARTICIPANT	\N	PRESENT	0
457652	448757	19741B	PARTICIPANT	\N	PRESENT	0
457653	448757	95063L	PARTICIPANT	\N	PRESENT	0
457654	448757	19709B	PARTICIPANT	\N	PRESENT	0
457655	448757	14239U	PARTICIPANT	\N	PRESENT	0
457656	448757	08018U	PARTICIPANT	\N	PRESENT	0
457657	448757	04088S	PARTICIPANT	\N	PRESENT	0
457658	448757	14041T	PARTICIPANT	\N	PRESENT	0
457659	448757	07029T	PARTICIPANT	\N	PRESENT	0
457660	448757	19591F	PARTICIPANT	\N	PRESENT	0
457661	448757	14355X	PARTICIPANT	\N	PRESENT	0
457662	448757	08015R	PARTICIPANT	\N	PRESENT	0
457663	448757	19768N	PARTICIPANT	\N	PRESENT	0
457664	448757	19705W	PARTICIPANT	\N	PRESENT	0
457665	448757	14147R	PARTICIPANT	\N	PRESENT	0
457666	448757	19563B	PARTICIPANT	\N	PRESENT	0
457667	448757	14093U	PARTICIPANT	\N	PRESENT	0
479411	479094	19565D	PARTICIPANT	\N	EXCUSE	0
481640	473435	04088S	PARTICIPANT	\N	PRESENT	0
481641	473435	14261S	PARTICIPANT	\N	PRESENT	0
481642	473435	19629C	PARTICIPANT	\N	PRESENT	0
481643	473435	19866P	PARTICIPANT	\N	PRESENT	0
481644	473435	99004R	PARTICIPANT	\N	PRESENT	0
481645	473435	19467C	PARTICIPANT	\N	PRESENT	0
481646	473435	14267Y	PARTICIPANT	\N	PRESENT	0
481647	473435	04018C	PARTICIPANT	\N	PRESENT	0
481648	473435	14105F	PARTICIPANT	\N	PRESENT	0
481649	473435	14265W	PARTICIPANT	\N	PRESENT	0
481650	473435	14034U	PARTICIPANT	\N	PRESENT	0
481652	473435	88008L	PARTICIPANT	\N	PRESENT	0
481653	473435	11012A	PARTICIPANT	\N	PRESENT	0
481654	473435	19507S	PARTICIPANT	\N	PRESENT	0
481655	473435	14147R	PARTICIPANT	\N	PRESENT	0
481658	473435	14215L	PARTICIPANT	\N	PRESENT	0
481662	473435	19683J	PARTICIPANT	\N	PRESENT	0
481664	473435	08017T	PARTICIPANT	\N	PRESENT	0
481669	473435	19826F	PARTICIPANT	\N	PRESENT	0
481670	473435	19731Y	PARTICIPANT	\N	PRESENT	0
481671	473435	14217N	PARTICIPANT	\N	PRESENT	0
481704	479110	08060W	PARTICIPANT	\N	PRESENT	0
481705	479110	01028R	PARTICIPANT	\N	PRESENT	0
481706	479110	19683J	PARTICIPANT	\N	PRESENT	0
481707	479110	08024S	PARTICIPANT	\N	PRESENT	0
481708	479110	19479G	PARTICIPANT	\N	PRESENT	0
481709	479110	19367Y	PARTICIPANT	\N	PRESENT	0
481710	479110	14215L	PARTICIPANT	\N	PRESENT	0
481714	479110	11027H	PARTICIPANT	\N	PRESENT	0
481715	479110	04044E	PARTICIPANT	\N	PRESENT	0
481716	479110	86034E	PARTICIPANT	\N	PRESENT	0
481717	479110	04085P	PARTICIPANT	\N	PRESENT	0
481718	479110	11031D	PARTICIPANT	\N	PRESENT	0
481719	479110	19565D	PARTICIPANT	\N	PRESENT	0
481723	479110	05008E	PARTICIPANT	\N	PRESENT	0
481725	479110	14119M	PARTICIPANT	\N	PRESENT	0
481727	479110	19737F	PARTICIPANT	\N	PRESENT	0
481729	479110	19731Y	PARTICIPANT	\N	PRESENT	0
481731	479110	19729F	PARTICIPANT	\N	PRESENT	0
481732	479110	04088S	PARTICIPANT	\N	PRESENT	0
481733	479110	97011G	PARTICIPANT	\N	PRESENT	0
481734	479110	04018C	PARTICIPANT	\N	PRESENT	0
481735	479110	08020N	PARTICIPANT	\N	PRESENT	0
481702	479110	19413M	PARTICIPANT	\N	PRESENT	0
481703	479110	08017T	PARTICIPANT	\N	PRESENT	0
481736	479110	19766L	PARTICIPANT	\N	PRESENT	0
481737	479110	19703U	PARTICIPANT	\N	PRESENT	0
481738	479110	15447F	PARTICIPANT	\N	PRESENT	0
481739	479110	14033T	PARTICIPANT	\N	PRESENT	0
481740	479110	19467C	PARTICIPANT	\N	PRESENT	0
481741	479110	11103C	PARTICIPANT	\N	PRESENT	0
481742	479110	19691J	PARTICIPANT	\N	PRESENT	0
481743	479110	14021P	PARTICIPANT	\N	PRESENT	0
481744	479110	14051J	PARTICIPANT	\N	PRESENT	0
481745	479110	19531S	PARTICIPANT	\N	PRESENT	0
481746	479110	11067R	PARTICIPANT	\N	PRESENT	0
481747	479110	14097Y	PARTICIPANT	\N	PRESENT	0
481748	479110	14081Q	PARTICIPANT	\N	PRESENT	0
481749	479110	14207L	PARTICIPANT	\N	PRESENT	0
481750	479110	19629C	PARTICIPANT	\N	PRESENT	0
481751	479110	14034U	PARTICIPANT	\N	PRESENT	0
481752	479110	19719D	PARTICIPANT	\N	PRESENT	0
481753	479110	14042U	PARTICIPANT	\N	PRESENT	0
481754	479110	19826F	PARTICIPANT	\N	PRESENT	0
481755	479110	14053L	PARTICIPANT	\N	PRESENT	0
481756	479110	14079W	PARTICIPANT	\N	PRESENT	0
481757	479110	14147R	PARTICIPANT	\N	PRESENT	0
481758	479110	01058X	PARTICIPANT	\N	PRESENT	0
481759	479110	87003B	PARTICIPANT	\N	PRESENT	0
481760	479110	18083K	PARTICIPANT	\N	PRESENT	0
481761	479110	19663E	PARTICIPANT	\N	PRESENT	0
481762	479110	19573D	PARTICIPANT	\N	PRESENT	0
481763	479110	19447X	PARTICIPANT	\N	PRESENT	0
481764	479110	01057W	PARTICIPANT	\N	PRESENT	0
481765	479110	14211G	PARTICIPANT	\N	PRESENT	0
481766	479110	14187A	PARTICIPANT	\N	PRESENT	0
481767	479110	19739H	PARTICIPANT	\N	PRESENT	0
481768	479110	19713W	PARTICIPANT	\N	PRESENT	0
481769	479110	19545Y	PARTICIPANT	\N	PRESENT	0
481770	479110	19251M	PARTICIPANT	\N	PRESENT	0
481771	479110	19649G	PARTICIPANT	\N	PRESENT	0
481772	479110	04092N	PARTICIPANT	\N	PRESENT	0
481773	479110	11097X	PARTICIPANT	\N	PRESENT	0
481774	479110	11048N	PARTICIPANT	\N	PRESENT	0
481775	479110	19269X	PARTICIPANT	\N	PRESENT	0
481776	479110	11012A	PARTICIPANT	\N	PRESENT	0
481777	479110	19563B	PARTICIPANT	\N	PRESENT	0
481778	479110	19723Y	PARTICIPANT	\N	PRESENT	0
481779	479110	11033F	PARTICIPANT	\N	PRESENT	0
481780	479110	95030B	PARTICIPANT	\N	PRESENT	0
481781	479110	19762G	PARTICIPANT	\N	PRESENT	0
481782	479110	19443T	PARTICIPANT	\N	PRESENT	0
481783	479110	08015R	PARTICIPANT	\N	PRESENT	0
481784	479110	08009T	PARTICIPANT	\N	PRESENT	0
481785	479110	14213J	PARTICIPANT	\N	PRESENT	0
481787	479069	11054L	PARTICIPANT	\N	PRESENT	0
481861	470581	04044E	PARTICIPANT	\N	PRESENT	0
481862	470581	11067R	PARTICIPANT	\N	PRESENT	0
481863	470581	19649G	PARTICIPANT	\N	PRESENT	0
481864	470581	08020N	PARTICIPANT	\N	PRESENT	0
481865	470581	11031D	PARTICIPANT	\N	PRESENT	0
481866	470581	04085P	PARTICIPANT	\N	PRESENT	0
481867	470581	15447F	PARTICIPANT	\N	PRESENT	0
481868	470581	19703U	PARTICIPANT	\N	PRESENT	0
481869	470581	19443T	PARTICIPANT	\N	PRESENT	0
481870	470581	11027H	PARTICIPANT	\N	PRESENT	0
481871	470581	19663E	PARTICIPANT	\N	PRESENT	0
481872	470581	14081Q	PARTICIPANT	\N	PRESENT	0
481873	470581	08024S	PARTICIPANT	\N	PRESENT	0
481874	470581	04088S	PARTICIPANT	\N	PRESENT	0
481875	470581	14021P	PARTICIPANT	\N	PRESENT	0
481876	470581	19723Y	PARTICIPANT	\N	PRESENT	0
481877	470581	08017T	PARTICIPANT	\N	PRESENT	0
481878	470581	19531S	PARTICIPANT	\N	PRESENT	0
481879	470581	19251M	PARTICIPANT	\N	PRESENT	0
481880	470581	11033F	PARTICIPANT	\N	PRESENT	0
481881	470581	12041X	PARTICIPANT	\N	PRESENT	0
481882	470581	19565D	PARTICIPANT	\N	PRESENT	0
481883	470581	19413M	PARTICIPANT	\N	PRESENT	0
481884	470581	19549D	PARTICIPANT	\N	PRESENT	0
481885	470581	14097Y	PARTICIPANT	\N	PRESENT	0
481886	470581	19683J	PARTICIPANT	\N	PRESENT	0
481887	470581	14207L	PARTICIPANT	\N	PRESENT	0
481888	470581	19269X	PARTICIPANT	\N	PRESENT	0
481889	470581	19545Y	PARTICIPANT	\N	PRESENT	0
481890	470581	19629C	PARTICIPANT	\N	PRESENT	0
481891	470581	19563B	PARTICIPANT	\N	PRESENT	0
481892	470581	19719D	PARTICIPANT	\N	PRESENT	0
481893	470581	14034U	PARTICIPANT	\N	PRESENT	0
481894	470581	08009T	PARTICIPANT	\N	PRESENT	0
481895	470581	19679N	PARTICIPANT	\N	PRESENT	0
481896	470581	08060W	PARTICIPANT	\N	PRESENT	0
481897	470581	11048N	PARTICIPANT	\N	PRESENT	0
481898	470581	19758L	PARTICIPANT	\N	PRESENT	0
481899	470581	19737F	PARTICIPANT	\N	PRESENT	0
481900	470581	87003B	PARTICIPANT	\N	PRESENT	0
481901	470581	19739H	PARTICIPANT	\N	PRESENT	0
481902	470581	97011G	PARTICIPANT	\N	PRESENT	0
481903	470581	19479G	PARTICIPANT	\N	PRESENT	0
481904	470581	19713W	PARTICIPANT	\N	PRESENT	0
481905	470581	19826F	PARTICIPANT	\N	PRESENT	0
481906	470581	14079W	PARTICIPANT	\N	PRESENT	0
481907	470581	05008E	PARTICIPANT	\N	PRESENT	0
481908	470581	19762G	PARTICIPANT	\N	PRESENT	0
481909	470581	11097X	PARTICIPANT	\N	PRESENT	0
481911	470581	19691J	PARTICIPANT	\N	PRESENT	0
481912	470581	95030B	PARTICIPANT	\N	PRESENT	0
481913	470581	14187A	PARTICIPANT	\N	PRESENT	0
481914	470581	14213J	PARTICIPANT	\N	PRESENT	0
481915	470581	14053L	PARTICIPANT	\N	PRESENT	0
481916	470581	14119M	PARTICIPANT	\N	PRESENT	0
481917	470581	14087W	PARTICIPANT	\N	PRESENT	0
481918	470581	01058X	PARTICIPANT	\N	PRESENT	0
481919	470581	19573D	PARTICIPANT	\N	PRESENT	0
481920	470581	19729F	PARTICIPANT	\N	PRESENT	0
481921	470581	19367Y	PARTICIPANT	\N	PRESENT	0
481922	470581	14042U	PARTICIPANT	\N	PRESENT	0
481923	470581	18083K	PARTICIPANT	\N	PRESENT	0
481924	470581	19467C	PARTICIPANT	\N	PRESENT	0
481925	470581	14051J	PARTICIPANT	\N	PRESENT	0
481926	470581	11099A	PARTICIPANT	\N	PRESENT	0
481927	470581	88008L	PARTICIPANT	\N	PRESENT	0
481928	470581	19383Y	PARTICIPANT	\N	PRESENT	0
481929	470581	14030Q	PARTICIPANT	\N	PRESENT	0
481930	470581	19731Y	PARTICIPANT	\N	PRESENT	0
481931	470581	14093U	PARTICIPANT	\N	PRESENT	0
481932	470581	14033T	PARTICIPANT	\N	PRESENT	0
455475	448750	19699S	PARTICIPANT	\N	PRESENT	0
455476	448750	19731Y	PARTICIPANT	\N	PRESENT	0
455762	455761	96004D	PRESIDENT	0	PRESENT	0
455763	455761	14089Y	PARTICIPANT	\N	PRESENT	0
455764	455761	14079W	PARTICIPANT	\N	PRESENT	0
455765	455761	11083R	PARTICIPANT	\N	PRESENT	0
455766	455761	14026U	PARTICIPANT	\N	PRESENT	0
455767	455761	19725B	PARTICIPANT	\N	PRESENT	0
455768	455761	95037J	PARTICIPANT	\N	PRESENT	0
455769	455761	19569H	PARTICIPANT	\N	PRESENT	0
455770	455761	04097T	PARTICIPANT	\N	PRESENT	0
455771	455761	14241N	PARTICIPANT	\N	PRESENT	0
455772	455761	12041X	PARTICIPANT	\N	PRESENT	0
455773	455761	11026G	PARTICIPANT	\N	PRESENT	0
455774	455761	14001X	PARTICIPANT	\N	PRESENT	0
455775	455761	04057K	PARTICIPANT	\N	PRESENT	0
455776	455761	14331P	PARTICIPANT	\N	PRESENT	0
455777	455761	10015M	PARTICIPANT	\N	EXCUSE	0
455778	455761	04042C	PARTICIPANT	\N	PRESENT	0
455779	455761	95030B	PARTICIPANT	\N	PRESENT	0
455780	455761	08043V	PARTICIPANT	\N	PRESENT	0
455781	455761	98018T	PARTICIPANT	\N	PRESENT	0
455782	455761	14255U	PARTICIPANT	\N	PRESENT	0
455783	455761	98050T	PARTICIPANT	\N	PRESENT	0
455784	455761	16685X	PARTICIPANT	\N	PRESENT	0
455785	455761	01058X	PARTICIPANT	\N	PRESENT	0
455786	455761	19812Y	PARTICIPANT	\N	PRESENT	0
455787	455761	19717B	PARTICIPANT	\N	PRESENT	0
455788	455761	19705W	PARTICIPANT	\N	PRESENT	0
455789	455761	04034C	PARTICIPANT	\N	PRESENT	0
455790	455761	14105F	PARTICIPANT	\N	PRESENT	0
455791	455761	08056B	PARTICIPANT	\N	PRESENT	0
455792	455761	19251M	PARTICIPANT	\N	PRESENT	0
455793	455761	11027H	PARTICIPANT	\N	PRESENT	0
455794	455761	19521Q	PARTICIPANT	\N	PRESENT	0
455795	455761	14267Y	PARTICIPANT	\N	PRESENT	0
455796	455761	19443T	PARTICIPANT	\N	PRESENT	0
455797	455761	19669L	PARTICIPANT	\N	PRESENT	0
455798	455761	01062T	PARTICIPANT	\N	PRESENT	0
455799	455761	11066Q	PARTICIPANT	\N	PRESENT	0
455800	455761	08058D	PARTICIPANT	\N	PRESENT	0
456216	448751	19413M	PARTICIPANT	\N	PRESENT	0
456217	454067	14157T	PARTICIPANT	\N	PRESENT	0
456227	455761	14179A	PARTICIPANT	\N	PRESENT	0
456233	455761	04035D	PARTICIPANT	\N	EXCUSE	0
456243	456242	96004D	PARTICIPANT	\N	PRESENT	0
456244	456242	14079W	PARTICIPANT	\N	PRESENT	0
456245	456242	14249W	PARTICIPANT	\N	PRESENT	0
456246	456242	04035D	PARTICIPANT	\N	EXCUSE	0
456247	456242	11083R	PARTICIPANT	\N	PRESENT	0
456248	456242	14026U	PARTICIPANT	\N	PRESENT	0
456249	456242	19725B	PARTICIPANT	\N	PRESENT	0
456250	456242	95037J	PARTICIPANT	\N	PRESENT	0
456251	456242	19569H	PARTICIPANT	\N	PRESENT	0
456252	456242	04097T	PARTICIPANT	\N	PRESENT	0
456253	456242	14073Q	PARTICIPANT	\N	PRESENT	0
456254	456242	12041X	PARTICIPANT	\N	PRESENT	0
456255	456242	11026G	PARTICIPANT	\N	PRESENT	0
456256	456242	14001X	PARTICIPANT	\N	PRESENT	0
456257	456242	04057K	PARTICIPANT	\N	PRESENT	0
456258	456242	10015M	PARTICIPANT	\N	EXCUSE	0
456259	456242	14229S	PARTICIPANT	\N	PRESENT	0
457007	457006	14069U	PARTICIPANT	\N	PRESENT	0
457008	457006	19637C	PARTICIPANT	\N	PRESENT	0
457009	457006	08009T	PARTICIPANT	\N	PRESENT	0
457011	457006	14237S	PARTICIPANT	\N	PRESENT	0
457075	454346	14030Q	PRESIDENT	0	PRESENT	0
457076	454346	11067R	PARTICIPANT	\N	PRESENT	0
457077	454346	11031D	PARTICIPANT	\N	PRESENT	0
457078	454346	08031R	PARTICIPANT	\N	PRESENT	0
457079	454346	19731Y	PARTICIPANT	\N	PRESENT	0
457080	454346	80013X	PARTICIPANT	\N	PRESENT	0
457081	454346	08017T	PARTICIPANT	\N	PRESENT	0
457082	454346	19749K	PARTICIPANT	\N	PRESENT	0
457894	455456	96004D	PRESIDENT	0	PRESENT	0
457895	455456	14357A	PARTICIPANT	\N	EXCUSE	0
457896	455456	14079W	PARTICIPANT	\N	PRESENT	0
457897	455456	14249W	PARTICIPANT	\N	PRESENT	0
457898	455456	11083R	PARTICIPANT	\N	EXCUSE	0
457899	455456	14026U	PARTICIPANT	\N	PRESENT	0
457900	455456	19725B	PARTICIPANT	\N	PRESENT	0
457901	455456	95037J	PARTICIPANT	\N	PRESENT	0
457902	455456	04097T	PARTICIPANT	\N	PRESENT	0
457903	455456	14097Y	PARTICIPANT	\N	PRESENT	0
457904	455456	14073Q	PARTICIPANT	\N	PRESENT	0
457905	455456	14061L	PARTICIPANT	\N	EXCUSE	0
457906	455456	14241N	PARTICIPANT	\N	PRESENT	0
457907	455456	14001X	PARTICIPANT	\N	PRESENT	0
457908	455456	04057K	PARTICIPANT	\N	PRESENT	0
457910	455456	10015M	PARTICIPANT	\N	PRESENT	0
457911	455456	14237S	PARTICIPANT	\N	PRESENT	0
457912	455456	11041F	PARTICIPANT	\N	PRESENT	0
457915	455456	14205J	PARTICIPANT	\N	EXCUSE	0
457916	455456	14221J	PARTICIPANT	\N	EXCUSE	0
457922	457914	96004D	PARTICIPANT	\N	PRESENT	0
457923	457914	14225N	PARTICIPANT	\N	PRESENT	0
458211	458210	14221J	PARTICIPANT	\N	PRESENT	0
458432	458431	14038Y	PARTICIPANT	\N	PRESENT	0
458433	458431	18083K	PARTICIPANT	\N	PRESENT	0
458434	458431	19333N	PARTICIPANT	\N	PRESENT	0
458435	458431	02002K	PARTICIPANT	\N	PRESENT	0
458436	458431	19599P	PARTICIPANT	\N	PRESENT	0
458437	458431	19549D	PARTICIPANT	\N	PRESENT	0
458438	458431	19347U	PARTICIPANT	\N	PRESENT	0
458490	458489	14038Y	PARTICIPANT	\N	PRESENT	0
458491	458489	18083K	PARTICIPANT	\N	PRESENT	0
458492	458489	19333N	PARTICIPANT	\N	PRESENT	0
458493	458489	02002K	PARTICIPANT	\N	PRESENT	0
458494	458489	19549D	PARTICIPANT	\N	PRESENT	0
458495	458489	19347U	PARTICIPANT	\N	PRESENT	0
458499	458498	19515S	PARTICIPANT	\N	PRESENT	0
458500	458498	14069U	PARTICIPANT	\N	PRESENT	0
458501	458498	19747H	PARTICIPANT	\N	PRESENT	0
458502	458498	08020N	PARTICIPANT	\N	PRESENT	0
458503	458498	08028W	PARTICIPANT	\N	PRESENT	0
458504	458498	01024M	PARTICIPANT	\N	PRESENT	0
458505	458498	19507S	PARTICIPANT	\N	PRESENT	0
458506	458498	16685X	PARTICIPANT	\N	PRESENT	0
458507	458498	19441R	PARTICIPANT	\N	PRESENT	0
458508	458498	19563B	PARTICIPANT	\N	PRESENT	0
458509	458498	19745F	PARTICIPANT	\N	PRESENT	0
458510	458498	11097X	PARTICIPANT	\N	PRESENT	0
458511	458498	19413M	PARTICIPANT	\N	PRESENT	0
458512	458498	11090Q	PARTICIPANT	\N	PRESENT	0
458662	455457	96004D	PRESIDENT	0	PRESENT	0
458663	455457	14357A	PARTICIPANT	\N	EXCUSE	0
458664	455457	14249W	PARTICIPANT	\N	PRESENT	0
458665	455457	11083R	PARTICIPANT	\N	EXCUSE	0
458666	455457	14026U	PARTICIPANT	\N	PRESENT	0
458667	455457	19725B	PARTICIPANT	\N	PRESENT	0
458668	455457	04097T	PARTICIPANT	\N	PRESENT	0
458669	455457	14241N	PARTICIPANT	\N	PRESENT	0
458670	455457	14061L	PARTICIPANT	\N	EXCUSE	0
458671	455457	12041X	PARTICIPANT	\N	PRESENT	0
458672	455457	11026G	PARTICIPANT	\N	PRESENT	0
458673	455457	14001X	PARTICIPANT	\N	PRESENT	0
458674	455457	04057K	PARTICIPANT	\N	PRESENT	0
458675	455457	19563B	PARTICIPANT	\N	PRESENT	0
458676	455457	14135M	PARTICIPANT	\N	PRESENT	0
458677	455457	14331P	PARTICIPANT	\N	PRESENT	0
458692	458691	19515S	PARTICIPANT	\N	PRESENT	0
458694	458693	19812Y	PARTICIPANT	\N	PRESENT	0
458751	458750	14089Y	PARTICIPANT	\N	PRESENT	0
458752	458750	11026G	PARTICIPANT	\N	PRESENT	0
458982	458981	19553Y	PARTICIPANT	\N	PRESENT	0
459121	458657	14063N	PARTICIPANT	\N	EXCUSE	0
459122	458657	04044E	PARTICIPANT	\N	EXCUSE	0
459123	458657	14257W	PARTICIPANT	\N	EXCUSE	0
460998	458888	19369B	PARTICIPANT	\N	EXCUSE	0
460999	458888	14093U	PARTICIPANT	\N	EXCUSE	0
461000	458888	19549D	PARTICIPANT	\N	EXCUSE	0
462481	462480	19253P	PARTICIPANT	\N	PRESENT	0
462482	462480	14111D	PARTICIPANT	\N	PRESENT	0
462484	462483	19253P	PARTICIPANT	\N	PRESENT	0
462485	462483	14111D	PARTICIPANT	\N	PRESENT	0
462486	462483	19553Y	PARTICIPANT	\N	PRESENT	0
462488	462487	14111D	PARTICIPANT	\N	PRESENT	0
462490	462489	19553Y	PARTICIPANT	\N	PRESENT	0
462491	462489	14111D	PARTICIPANT	\N	PRESENT	0
462493	462492	19703U	PARTICIPANT	\N	PRESENT	0
462497	462494	14087W	PARTICIPANT	\N	PRESENT	0
462498	462494	19679N	PARTICIPANT	\N	PRESENT	0
471795	467269	86034E	PARTICIPANT	\N	PRESENT	0
471819	467269	14109K	PARTICIPANT	\N	PRESENT	0
471836	467269	07033P	PARTICIPANT	\N	PRESENT	0
471837	467269	14157T	PARTICIPANT	\N	PRESENT	0
471838	467269	14105F	PARTICIPANT	\N	PRESENT	0
471839	467269	14237S	PARTICIPANT	\N	PRESENT	0
471843	467269	11085T	PARTICIPANT	\N	PRESENT	0
471844	467269	08009T	PARTICIPANT	\N	PRESENT	0
471845	467269	19479G	PARTICIPANT	\N	PRESENT	0
471846	467269	19521Q	PARTICIPANT	\N	PRESENT	0
471847	467269	14051J	PARTICIPANT	\N	PRESENT	0
471848	467269	19820Y	PARTICIPANT	\N	PRESENT	0
471849	467269	11026G	PARTICIPANT	\N	PRESENT	0
471850	467269	19631V	PARTICIPANT	\N	PRESENT	0
471851	467269	11110B	PARTICIPANT	\N	PRESENT	0
471852	467269	19333N	PARTICIPANT	\N	PRESENT	0
471853	467269	19683J	PARTICIPANT	\N	PRESENT	0
471854	467269	19727D	PARTICIPANT	\N	PRESENT	0
471855	467269	14021P	PARTICIPANT	\N	PRESENT	0
471856	467269	04092N	PARTICIPANT	\N	PRESENT	0
471857	467269	08061X	PARTICIPANT	\N	PRESENT	0
471858	467269	14135M	PARTICIPANT	\N	PRESENT	0
471859	467269	11012A	PARTICIPANT	\N	PRESENT	0
471860	467269	04085P	PARTICIPANT	\N	PRESENT	0
471861	467269	19695N	PARTICIPANT	\N	PRESENT	0
471862	467269	14031R	PARTICIPANT	\N	PRESENT	0
471863	467269	19697Q	PARTICIPANT	\N	PRESENT	0
471864	467269	19533U	PARTICIPANT	\N	PRESENT	0
471865	467269	14121F	PARTICIPANT	\N	PRESENT	0
471866	467269	14147R	PARTICIPANT	\N	PRESENT	0
471867	467269	19553Y	PARTICIPANT	\N	PRESENT	0
471868	467269	17637T	PARTICIPANT	\N	PRESENT	0
471869	467269	14034U	PARTICIPANT	\N	PRESENT	0
471870	467269	19679N	PARTICIPANT	\N	PRESENT	0
471871	467269	14231L	PARTICIPANT	\N	PRESENT	0
471872	467269	14255U	PARTICIPANT	\N	PRESENT	0
471873	467269	14179A	PARTICIPANT	\N	PRESENT	0
471874	467269	14001X	PARTICIPANT	\N	PRESENT	0
471875	467269	04086Q	PARTICIPANT	\N	PRESENT	0
471876	467269	14041T	PARTICIPANT	\N	PRESENT	0
471877	467269	19621T	PARTICIPANT	\N	PRESENT	0
471878	467269	04088S	PARTICIPANT	\N	PRESENT	0
471879	467269	14087W	PARTICIPANT	\N	PRESENT	0
471880	467269	11090Q	PARTICIPANT	\N	PRESENT	0
471881	467269	04033B	PARTICIPANT	\N	PRESENT	0
471882	467269	04040A	PARTICIPANT	\N	PRESENT	0
471883	467269	19335Q	PARTICIPANT	\N	PRESENT	0
471884	467269	14093U	PARTICIPANT	\N	PRESENT	0
471885	467269	19525U	PARTICIPANT	\N	PRESENT	0
471886	467269	19651A	PARTICIPANT	\N	PRESENT	0
471887	467269	14026U	PARTICIPANT	\N	PRESENT	0
471888	467269	19794Q	PARTICIPANT	\N	PRESENT	0
471889	467269	14217N	PARTICIPANT	\N	PRESENT	0
471890	467269	08010L	PARTICIPANT	\N	PRESENT	0
471891	467269	89017R	PARTICIPANT	\N	PRESENT	0
471895	467269	19591F	PARTICIPANT	\N	PRESENT	0
471899	467269	19749K	PARTICIPANT	\N	PRESENT	0
471900	467269	14205J	PARTICIPANT	\N	PRESENT	0
471901	467269	14251Q	PARTICIPANT	\N	PRESENT	0
471907	467269	08018U	PARTICIPANT	\N	PRESENT	0
471941	470506	14069U	PARTICIPANT	\N	PRESENT	0
471942	470506	11101A	PARTICIPANT	\N	PRESENT	0
471943	470506	14195A	PARTICIPANT	\N	PRESENT	0
471944	470506	04086Q	PARTICIPANT	\N	PRESENT	0
471945	470506	14259Y	PARTICIPANT	\N	PRESENT	0
471946	470506	14327T	PARTICIPANT	\N	PRESENT	0
471947	470506	14281W	PARTICIPANT	\N	PRESENT	0
471948	470506	14231L	PARTICIPANT	\N	PRESENT	0
471949	470506	19820Y	PARTICIPANT	\N	PRESENT	0
471950	470506	01057W	PARTICIPANT	\N	PRESENT	0
471951	470506	08010L	PARTICIPANT	\N	PRESENT	0
475647	470584	14034U	PARTICIPANT	\N	PRESENT	0
480275	473421	19551W	PARTICIPANT	\N	PRESENT	0
480276	473421	19713W	PARTICIPANT	\N	PRESENT	0
480277	473421	19749K	PARTICIPANT	\N	PRESENT	0
480278	473421	08015R	PARTICIPANT	\N	PRESENT	0
480441	473423	04059M	PARTICIPANT	\N	PRESENT	0
480442	473423	88008L	PARTICIPANT	\N	PRESENT	0
480443	473423	14241N	PARTICIPANT	\N	PRESENT	0
480444	473423	19713W	PARTICIPANT	\N	PRESENT	0
480445	473423	19749K	PARTICIPANT	\N	PRESENT	0
480446	473423	19563B	PARTICIPANT	\N	PRESENT	0
480447	473423	17589D	PARTICIPANT	\N	PRESENT	0
480448	473423	14207L	PARTICIPANT	\N	PRESENT	0
480449	473423	11012A	PARTICIPANT	\N	PRESENT	0
480450	473423	19725B	PARTICIPANT	\N	PRESENT	0
480451	473423	19699S	PARTICIPANT	\N	PRESENT	0
480452	473423	19812Y	PARTICIPANT	\N	PRESENT	0
480453	473423	01024M	PARTICIPANT	\N	PRESENT	0
480454	473423	14257W	PARTICIPANT	\N	PRESENT	0
480455	473423	14147R	PARTICIPANT	\N	PRESENT	0
480456	473423	19467C	PARTICIPANT	\N	PRESENT	0
480457	473423	14115H	PARTICIPANT	\N	PRESENT	0
480458	473423	19695N	PARTICIPANT	\N	PRESENT	0
480459	473423	19762G	PARTICIPANT	\N	PRESENT	0
480460	479035	19575F	PARTICIPANT	\N	PRESENT	0
480461	473423	15447F	PARTICIPANT	\N	PRESENT	0
480462	473423	19565D	PARTICIPANT	\N	PRESENT	0
480463	473423	19441R	PARTICIPANT	\N	PRESENT	0
480464	473423	19731Y	PARTICIPANT	\N	PRESENT	0
480465	473423	01058X	PARTICIPANT	\N	PRESENT	0
480466	473423	14030Q	PARTICIPANT	\N	PRESENT	0
480467	473423	19253P	PARTICIPANT	\N	PRESENT	0
480468	479035	19798U	PARTICIPANT	\N	PRESENT	0
480470	473423	14081Q	PARTICIPANT	\N	PRESENT	0
480471	473423	08045X	PARTICIPANT	\N	PRESENT	0
480472	473423	14357A	PARTICIPANT	\N	PRESENT	0
480473	473423	14069U	PARTICIPANT	\N	PRESENT	0
480474	479035	19387D	PARTICIPANT	\N	PRESENT	0
480506	473423	11067R	PARTICIPANT	\N	PRESENT	0
480507	473423	01057W	PARTICIPANT	\N	PRESENT	0
480508	473423	19723Y	PARTICIPANT	\N	PRESENT	0
480509	473423	19543W	PARTICIPANT	\N	PRESENT	0
480510	473423	19413M	PARTICIPANT	\N	PRESENT	0
480545	473423	19673G	PARTICIPANT	\N	PRESENT	0
480546	473423	19533U	PARTICIPANT	\N	PRESENT	0
480547	473423	19349W	PARTICIPANT	\N	PRESENT	0
480548	473423	11064N	PARTICIPANT	\N	PRESENT	0
480587	473422	11067R	PARTICIPANT	\N	PRESENT	0
480588	473422	08045X	PARTICIPANT	\N	PRESENT	0
480589	473422	14081Q	PARTICIPANT	\N	PRESENT	0
480590	473422	19349W	PARTICIPANT	\N	PRESENT	0
480591	473422	19543W	PARTICIPANT	\N	PRESENT	0
480592	473422	19713W	PARTICIPANT	\N	PRESENT	0
480593	473422	11033F	PARTICIPANT	\N	PRESENT	0
480594	473422	11012A	PARTICIPANT	\N	PRESENT	0
480595	473422	19253P	PARTICIPANT	\N	PRESENT	0
480596	473422	88008L	PARTICIPANT	\N	PRESENT	0
480597	473422	01024M	PARTICIPANT	\N	PRESENT	0
480598	473422	14147R	PARTICIPANT	\N	PRESENT	0
480599	473422	19731Y	PARTICIPANT	\N	PRESENT	0
480600	473422	01057W	PARTICIPANT	\N	PRESENT	0
480601	473422	19673G	PARTICIPANT	\N	PRESENT	0
480602	473422	14083S	PARTICIPANT	\N	PRESENT	0
480603	473422	05008E	PARTICIPANT	\N	PRESENT	0
480604	473422	19725B	PARTICIPANT	\N	PRESENT	0
480605	473422	11064N	PARTICIPANT	\N	PRESENT	0
480606	473422	14069U	PARTICIPANT	\N	PRESENT	0
480607	473422	11099A	PARTICIPANT	\N	PRESENT	0
480608	473422	19812Y	PARTICIPANT	\N	PRESENT	0
480609	473422	11065P	PARTICIPANT	\N	PRESENT	0
480610	473422	04049K	PARTICIPANT	\N	PRESENT	0
480611	473422	01028R	PARTICIPANT	\N	PRESENT	0
480612	473422	14281W	PARTICIPANT	\N	PRESENT	0
480613	473422	19565D	PARTICIPANT	\N	PRESENT	0
480614	473422	14021P	PARTICIPANT	\N	PRESENT	0
480615	473422	19820Y	PARTICIPANT	\N	PRESENT	0
480618	473422	19533U	PARTICIPANT	\N	PRESENT	0
480619	473422	14187A	PARTICIPANT	\N	PRESENT	0
480625	473422	19467C	PARTICIPANT	\N	PRESENT	0
480626	473422	07029T	PARTICIPANT	\N	PRESENT	0
480584	473422	04059M	PARTICIPANT	\N	PRESENT	0
480586	480585	08034U	PARTICIPANT	\N	PRESENT	0
456650	456649	19669L	PARTICIPANT	\N	PRESENT	0
456652	456651	19669L	PARTICIPANT	\N	PRESENT	0
456653	456651	98050T	PARTICIPANT	\N	PRESENT	0
456655	456654	19669L	PARTICIPANT	\N	PRESENT	0
456656	456654	98050T	PARTICIPANT	\N	PRESENT	0
456658	456657	19669L	PARTICIPANT	\N	PRESENT	0
456660	456659	19421M	PARTICIPANT	\N	PRESENT	0
457668	448757	19693L	PARTICIPANT	\N	PRESENT	0
457669	448757	14251Q	PARTICIPANT	\N	PRESENT	0
457670	448757	19399H	PARTICIPANT	\N	PRESENT	0
457671	448757	17589D	PARTICIPANT	\N	PRESENT	0
457672	448757	18083K	PARTICIPANT	\N	PRESENT	0
457673	448757	02002K	PARTICIPANT	\N	PRESENT	0
457674	448757	19415P	PARTICIPANT	\N	PRESENT	0
457675	448757	14038Y	PARTICIPANT	\N	PRESENT	0
457676	448757	19467C	PARTICIPANT	\N	PRESENT	0
457677	448757	14173T	PARTICIPANT	\N	PRESENT	0
457678	448757	19447X	PARTICIPANT	\N	PRESENT	0
457679	448757	19573D	PARTICIPANT	\N	PRESENT	0
457680	448757	04057K	PARTICIPANT	\N	PRESENT	0
457681	448757	14111D	PARTICIPANT	\N	PRESENT	0
457682	448757	14119M	PARTICIPANT	\N	PRESENT	0
457683	448757	14115H	PARTICIPANT	\N	PRESENT	0
457684	448757	14055N	PARTICIPANT	\N	PRESENT	0
457685	448757	19731Y	PARTICIPANT	\N	PRESENT	0
457686	448757	14135M	PARTICIPANT	\N	PRESENT	0
457687	448757	08047A	PARTICIPANT	\N	PRESENT	0
457688	448757	14105F	PARTICIPANT	\N	PRESENT	0
457689	448757	08031R	PARTICIPANT	\N	PRESENT	0
457690	448757	17583W	PARTICIPANT	\N	PRESENT	0
457691	448757	14034U	PARTICIPANT	\N	PRESENT	0
457692	448757	11048N	PARTICIPANT	\N	PRESENT	0
457693	448757	19782L	PARTICIPANT	\N	PRESENT	0
457694	448757	14253S	PARTICIPANT	\N	PRESENT	0
457695	448757	19629C	PARTICIPANT	\N	PRESENT	0
457696	448757	14199E	PARTICIPANT	\N	PRESENT	0
457697	448757	14031R	PARTICIPANT	\N	PRESENT	0
457698	448757	19253P	PARTICIPANT	\N	PRESENT	0
457699	448757	11010L	PARTICIPANT	\N	PRESENT	0
457700	448757	14241N	PARTICIPANT	\N	PRESENT	0
457701	448757	19673G	PARTICIPANT	\N	PRESENT	0
457702	448757	19719D	PARTICIPANT	\N	PRESENT	0
457703	448757	08039A	PARTICIPANT	\N	PRESENT	0
457704	448757	19703U	PARTICIPANT	\N	PRESENT	0
457705	448757	19347U	PARTICIPANT	\N	PRESENT	0
457706	448757	04038G	PARTICIPANT	\N	PRESENT	0
457707	448757	19515S	PARTICIPANT	\N	PRESENT	0
457708	448757	14133K	PARTICIPANT	\N	PRESENT	0
457709	448757	14191V	PARTICIPANT	\N	PRESENT	0
457710	448757	11074Q	PARTICIPANT	\N	PRESENT	0
457711	448757	11080N	PARTICIPANT	\N	PRESENT	0
457712	448757	19766L	PARTICIPANT	\N	PRESENT	0
457713	448757	19729F	PARTICIPANT	\N	PRESENT	0
457714	448757	19723Y	PARTICIPANT	\N	PRESENT	0
457715	448757	01057W	PARTICIPANT	\N	PRESENT	0
457716	448757	87003B	PARTICIPANT	\N	PRESENT	0
457717	448757	04043D	PARTICIPANT	\N	PRESENT	0
457718	448757	04071H	PARTICIPANT	\N	PRESENT	0
457719	448757	14169X	PARTICIPANT	\N	PRESENT	0
457720	448757	10015M	PARTICIPANT	\N	PRESENT	0
457721	448757	11043H	PARTICIPANT	\N	PRESENT	0
457722	448757	08028W	PARTICIPANT	\N	PRESENT	0
457723	448757	08073C	PARTICIPANT	\N	PRESENT	0
457724	448757	04042C	PARTICIPANT	\N	PRESENT	0
457725	448757	08069G	PARTICIPANT	\N	PRESENT	0
457726	448757	04049K	PARTICIPANT	\N	PRESENT	0
457727	448757	08020N	PARTICIPANT	\N	PRESENT	0
457728	448757	04097T	PARTICIPANT	\N	PRESENT	0
457729	448757	19679N	PARTICIPANT	\N	PRESENT	0
457730	448757	19575F	PARTICIPANT	\N	PRESENT	0
457731	448757	98018T	PARTICIPANT	\N	PRESENT	0
457732	448757	14157T	PARTICIPANT	\N	PRESENT	0
457733	448757	96004D	PARTICIPANT	\N	PRESENT	0
457734	448757	99004R	PARTICIPANT	\N	PRESENT	0
457735	448757	04008A	PARTICIPANT	\N	PRESENT	0
457736	448757	98024R	PARTICIPANT	\N	PRESENT	0
457737	448757	04035D	PARTICIPANT	\N	PRESENT	0
457738	448757	95030B	PARTICIPANT	\N	PRESENT	0
457739	448757	04047H	PARTICIPANT	\N	PRESENT	0
457740	448757	14026U	PARTICIPANT	\N	PRESENT	0
457741	448757	11070L	PARTICIPANT	\N	PRESENT	0
457742	448757	19747H	PARTICIPANT	\N	PRESENT	0
457743	448757	04092N	PARTICIPANT	\N	PRESENT	0
457744	448757	04044E	PARTICIPANT	\N	PRESENT	0
457745	448757	01062T	PARTICIPANT	\N	PRESENT	0
457746	448757	04086Q	PARTICIPANT	\N	PRESENT	0
457747	448757	04033B	PARTICIPANT	\N	PRESENT	0
457748	448757	19758L	PARTICIPANT	\N	PRESENT	0
457749	448757	14187A	PARTICIPANT	\N	PRESENT	0
457750	448757	14071N	PARTICIPANT	\N	PRESENT	0
457751	448757	19421M	PARTICIPANT	\N	PRESENT	0
457752	448757	14215L	PARTICIPANT	\N	PRESENT	0
457753	448757	19413M	PARTICIPANT	\N	PRESENT	0
457754	448757	14053L	PARTICIPANT	\N	PRESENT	0
457755	448757	14069U	PARTICIPANT	\N	PRESENT	0
457756	448757	14249W	PARTICIPANT	\N	PRESENT	0
457757	448757	19691J	PARTICIPANT	\N	PRESENT	0
457758	448757	08034U	PARTICIPANT	\N	PRESENT	0
457759	448757	19533U	PARTICIPANT	\N	PRESENT	0
457760	448757	10006L	PARTICIPANT	\N	PRESENT	0
457761	448757	19798U	PARTICIPANT	\N	PRESENT	0
457763	448757	14193X	PARTICIPANT	\N	PRESENT	0
457764	448757	14237S	PARTICIPANT	\N	PRESENT	0
457765	448757	19671E	PARTICIPANT	\N	PRESENT	0
457766	448757	19553Y	PARTICIPANT	\N	PRESENT	0
457767	448757	19581D	PARTICIPANT	\N	PRESENT	0
457768	448757	19717B	PARTICIPANT	\N	PRESENT	0
457769	448757	14079W	PARTICIPANT	\N	PRESENT	0
457771	448757	14331P	PARTICIPANT	\N	PRESENT	0
457783	448757	11103C	PARTICIPANT	\N	PRESENT	0
457774	448757	11099A	PARTICIPANT	\N	PRESENT	0
457775	448757	19289C	PARTICIPANT	\N	PRESENT	0
457780	448757	04069P	PARTICIPANT	\N	PRESENT	0
457781	448757	14217N	PARTICIPANT	\N	PRESENT	0
457785	448757	97011G	PARTICIPANT	\N	PRESENT	0
457786	448757	14051J	PARTICIPANT	\N	PRESENT	0
457787	448757	14329V	PARTICIPANT	\N	PRESENT	0
457788	448757	07033P	PARTICIPANT	\N	PRESENT	0
457789	448757	14229S	PARTICIPANT	\N	PRESENT	0
457790	448757	19675J	PARTICIPANT	\N	PRESENT	0
457792	448757	14021P	PARTICIPANT	\N	PRESENT	0
457793	448757	19701S	PARTICIPANT	\N	PRESENT	0
457794	448757	19762G	PARTICIPANT	\N	PRESENT	0
457795	448757	14225N	PARTICIPANT	\N	PRESENT	0
457796	448757	05008E	PARTICIPANT	\N	PRESENT	0
457798	448757	19599P	PARTICIPANT	\N	PRESENT	0
457799	448757	04018C	PARTICIPANT	\N	PRESENT	0
457801	448757	19621T	PARTICIPANT	\N	PRESENT	0
457802	448757	19647E	PARTICIPANT	\N	PRESENT	0
457803	448757	19367Y	PARTICIPANT	\N	PRESENT	0
457805	448757	19733B	PARTICIPANT	\N	PRESENT	0
457806	448757	19649G	PARTICIPANT	\N	PRESENT	0
457808	448757	14059S	PARTICIPANT	\N	PRESENT	0
457810	448757	14061L	PARTICIPANT	\N	PRESENT	0
457811	448757	14197C	PARTICIPANT	\N	PRESENT	0
457813	448757	98050T	PARTICIPANT	\N	PRESENT	0
457815	448757	14151M	PARTICIPANT	\N	PRESENT	0
457816	448757	19820Y	PARTICIPANT	\N	PRESENT	0
457817	448757	19727D	PARTICIPANT	\N	PRESENT	0
457819	448757	19531S	PARTICIPANT	\N	PRESENT	0
457820	448757	17779H	PARTICIPANT	\N	PRESENT	0
457821	448757	08058D	PARTICIPANT	\N	PRESENT	0
457822	448757	14065Q	PARTICIPANT	\N	PRESENT	0
457823	448757	14085U	PARTICIPANT	\N	PRESENT	0
457824	448757	11054L	PARTICIPANT	\N	PRESENT	0
457825	448757	19683J	PARTICIPANT	\N	PRESENT	0
457826	448757	19507S	PARTICIPANT	\N	PRESENT	0
457827	448757	19503N	PARTICIPANT	\N	PRESENT	0
457828	448757	17637T	PARTICIPANT	\N	PRESENT	0
457829	448757	11026G	PARTICIPANT	\N	PRESENT	0
457830	448757	19251M	PARTICIPANT	\N	PRESENT	0
457831	448757	19527W	PARTICIPANT	\N	PRESENT	0
457833	448757	19725B	PARTICIPANT	\N	PRESENT	0
457834	448757	19631V	PARTICIPANT	\N	PRESENT	0
457836	448757	14109K	PARTICIPANT	\N	PRESENT	0
457837	448757	14097Y	PARTICIPANT	\N	PRESENT	0
457838	448757	19549D	PARTICIPANT	\N	PRESENT	0
457839	448757	14087W	PARTICIPANT	\N	PRESENT	0
457840	448757	08017T	PARTICIPANT	\N	PRESENT	0
457841	448757	19551W	PARTICIPANT	\N	PRESENT	0
457842	448757	08053X	PARTICIPANT	\N	PRESENT	0
457843	448757	19525U	PARTICIPANT	\N	PRESENT	0
457844	448757	14081Q	PARTICIPANT	\N	PRESENT	0
457845	448757	08060W	PARTICIPANT	\N	PRESENT	0
457846	448757	11104D	PARTICIPANT	\N	PRESENT	0
457847	448757	14281W	PARTICIPANT	\N	PRESENT	0
457848	448757	14231L	PARTICIPANT	\N	PRESENT	0
457849	448757	08044W	PARTICIPANT	\N	PRESENT	0
475899	473928	08056B	PARTICIPANT	\N	PRESENT	0
475900	473928	04040A	PARTICIPANT	\N	PRESENT	0
475901	473928	08010L	PARTICIPANT	\N	PRESENT	0
475902	473928	19673G	PARTICIPANT	\N	PRESENT	0
475903	473928	19719D	PRESIDENT	0	PRESENT	0
475930	470587	01028R	PARTICIPANT	\N	PRESENT	0
475931	470587	11065P	PARTICIPANT	\N	PRESENT	0
475932	470587	19697Q	PARTICIPANT	\N	PRESENT	0
475933	470587	19565D	PARTICIPANT	\N	PRESENT	0
475934	470587	19585H	PARTICIPANT	\N	PRESENT	0
475935	470587	14219Q	PARTICIPANT	\N	PRESENT	0
478707	477933	14039A	PARTICIPANT	\N	PRESENT	0
475937	470587	19693L	PARTICIPANT	\N	PRESENT	0
475938	470587	07004J	PARTICIPANT	\N	PRESENT	0
475939	470587	11085T	PARTICIPANT	\N	PRESENT	0
475940	470587	19569H	PARTICIPANT	\N	PRESENT	0
475942	470587	05008E	PARTICIPANT	\N	PRESENT	0
475976	470587	19533U	PARTICIPANT	\N	PRESENT	0
476019	473928	08053X	PARTICIPANT	\N	PRESENT	0
478706	477933	14267Y	PARTICIPANT	\N	PRESENT	0
478708	477933	16685X	PARTICIPANT	\N	PRESENT	0
478709	477933	95067Q	PARTICIPANT	\N	PRESENT	0
478710	478678	14267Y	PRESIDENT	0	PRESENT	0
478711	478678	11064N	PARTICIPANT	\N	PRESENT	0
478712	478678	14039A	PARTICIPANT	\N	PRESENT	0
478713	478678	16685X	PARTICIPANT	\N	PRESENT	0
478714	478678	95067Q	PARTICIPANT	\N	PRESENT	0
475928	470587	11027H	PARTICIPANT	\N	PRESENT	0
475929	470587	10015M	PARTICIPANT	\N	PRESENT	0
478715	478678	04086Q	PARTICIPANT	\N	EXCUSE	0
479172	479171	04033B	PARTICIPANT	\N	PRESENT	0
479173	479171	14115H	PARTICIPANT	\N	PRESENT	0
479174	479171	95067Q	PARTICIPANT	\N	PRESENT	0
479175	479171	11066Q	PARTICIPANT	\N	PRESENT	0
479176	479171	19647E	PARTICIPANT	\N	PRESENT	0
479177	479171	10006L	PARTICIPANT	\N	PRESENT	0
479178	479171	14041T	PARTICIPANT	\N	PRESENT	0
479179	479171	14217N	PARTICIPANT	\N	PRESENT	0
479180	479171	97011G	PARTICIPANT	\N	PRESENT	0
479181	479171	19766L	PARTICIPANT	\N	PRESENT	0
479185	478990	04045F	PARTICIPANT	\N	PRESENT	0
481935	470581	08015R	PARTICIPANT	\N	PRESENT	0
481936	470581	08039A	PARTICIPANT	\N	PRESENT	0
481933	470581	14031R	PARTICIPANT	\N	PRESENT	0
481934	470581	14041T	PARTICIPANT	\N	PRESENT	0
481937	470581	19637C	PARTICIPANT	\N	PRESENT	0
481938	470581	19695N	PARTICIPANT	\N	PRESENT	0
481939	470581	19507S	PARTICIPANT	\N	PRESENT	0
481940	470581	11064N	PARTICIPANT	\N	PRESENT	0
481941	470581	04070G	PARTICIPANT	\N	PRESENT	0
481942	470581	01057W	PARTICIPANT	\N	PRESENT	0
481949	470581	19515S	PARTICIPANT	\N	PRESENT	0
481950	470581	14001X	PARTICIPANT	\N	PRESENT	0
481951	470581	19926J	PARTICIPANT	\N	PRESENT	0
481952	470581	19701S	PARTICIPANT	\N	PRESENT	0
481953	470581	19709B	PARTICIPANT	\N	PRESENT	0
481954	470581	19741B	PARTICIPANT	\N	PRESENT	0
481955	470581	11026G	PARTICIPANT	\N	PRESENT	0
481956	470581	19647E	PARTICIPANT	\N	PRESENT	0
482009	473436	19741B	PARTICIPANT	\N	PRESENT	0
482010	473436	11026G	PARTICIPANT	\N	PRESENT	0
482011	473436	08015R	PARTICIPANT	\N	PRESENT	0
482012	473436	19565D	PARTICIPANT	\N	PRESENT	0
482013	473436	19758L	PARTICIPANT	\N	PRESENT	0
482014	473436	11027H	PARTICIPANT	\N	PRESENT	0
482015	473436	14081Q	PARTICIPANT	\N	PRESENT	0
482016	473436	08017T	PARTICIPANT	\N	PRESENT	0
482017	473436	11064N	PARTICIPANT	\N	PRESENT	0
482018	473436	19479G	PARTICIPANT	\N	PRESENT	0
482019	473436	19629C	PARTICIPANT	\N	PRESENT	0
482020	473436	11099A	PARTICIPANT	\N	PRESENT	0
482021	473436	19647E	PARTICIPANT	\N	PRESENT	0
482022	473436	14097Y	PARTICIPANT	\N	PRESENT	0
482023	473436	04034C	PARTICIPANT	\N	PRESENT	0
482024	473436	14255U	PARTICIPANT	\N	PRESENT	0
482025	473436	19731Y	PARTICIPANT	\N	PRESENT	0
482026	473436	95030B	PARTICIPANT	\N	PRESENT	0
482027	473436	14147R	PARTICIPANT	\N	PRESENT	0
482028	473436	14217N	PARTICIPANT	\N	PRESENT	0
482029	473436	01058X	PARTICIPANT	\N	PRESENT	0
482030	473436	14105F	PARTICIPANT	\N	PRESENT	0
482031	473436	87003B	PARTICIPANT	\N	PRESENT	0
482032	473436	01057W	PARTICIPANT	\N	PRESENT	0
482033	473436	14031R	PARTICIPANT	\N	PRESENT	0
482034	473436	08018U	PARTICIPANT	\N	PRESENT	0
482035	473436	14041T	PARTICIPANT	\N	PRESENT	0
482036	473436	18083K	PARTICIPANT	\N	PRESENT	0
482037	473436	04086Q	PARTICIPANT	\N	PRESENT	0
482038	473436	19766L	PARTICIPANT	\N	PRESENT	0
482039	473436	14079W	PARTICIPANT	\N	PRESENT	0
482040	473436	19515S	PARTICIPANT	\N	PRESENT	0
482041	473436	14030Q	PARTICIPANT	\N	PRESENT	0
482042	473436	11012A	PARTICIPANT	\N	PRESENT	0
482044	473436	19441R	PARTICIPANT	\N	PRESENT	0
482045	482043	08012N	PARTICIPANT	\N	PRESENT	0
482046	482043	02002K	PARTICIPANT	\N	PRESENT	0
482047	482043	19349W	PARTICIPANT	\N	PRESENT	0
482048	482043	11043H	PARTICIPANT	\N	PRESENT	0
482049	482043	14073Q	PARTICIPANT	\N	PRESENT	0
482050	473436	08020N	PARTICIPANT	\N	PRESENT	0
482051	482043	19533U	PARTICIPANT	\N	PRESENT	0
482056	473436	14265W	PARTICIPANT	\N	PRESENT	0
482057	473436	19709B	PARTICIPANT	\N	PRESENT	0
482058	473436	19447X	PARTICIPANT	\N	PRESENT	0
482064	473436	14133K	PARTICIPANT	\N	PRESENT	0
482065	473436	19729F	PARTICIPANT	\N	PRESENT	0
482066	473436	01024M	PARTICIPANT	\N	PRESENT	0
482067	473436	97011G	PARTICIPANT	\N	PRESENT	0
482068	473436	14033T	PARTICIPANT	\N	PRESENT	0
482007	473436	04044E	PARTICIPANT	\N	PRESENT	0
482008	473436	19926J	PARTICIPANT	\N	PRESENT	0
482075	473436	19914E	PARTICIPANT	\N	PRESENT	0
482076	473436	04035D	PARTICIPANT	\N	PRESENT	0
482077	473436	19711U	PARTICIPANT	\N	PRESENT	0
482078	473436	19533U	PARTICIPANT	\N	PRESENT	0
482079	473436	11103C	PARTICIPANT	\N	PRESENT	0
482080	473436	08028W	PARTICIPANT	\N	PRESENT	0
482081	473436	19713W	PARTICIPANT	\N	PRESENT	0
482082	473436	11067R	PARTICIPANT	\N	PRESENT	0
482083	473436	14087W	PARTICIPANT	\N	PRESENT	0
482084	473436	19347U	PARTICIPANT	\N	PRESENT	0
482085	473436	19467C	PARTICIPANT	\N	PRESENT	0
482086	473436	14211G	PARTICIPANT	\N	PRESENT	0
482126	479111	01024M	PARTICIPANT	\N	PRESENT	0
482127	479111	19479G	PARTICIPANT	\N	PRESENT	0
482128	479111	19563B	PARTICIPANT	\N	PRESENT	0
482129	479111	19629C	PARTICIPANT	\N	PRESENT	0
482130	479111	19349W	PARTICIPANT	\N	PRESENT	0
482131	479111	19269X	PARTICIPANT	\N	PRESENT	0
482132	479111	99004R	PARTICIPANT	\N	PRESENT	0
482133	479111	19713W	PARTICIPANT	\N	PRESENT	0
482134	479111	08024S	PARTICIPANT	\N	PRESENT	0
482135	479111	19441R	PARTICIPANT	\N	PRESENT	0
482136	479111	08045X	PARTICIPANT	\N	PRESENT	0
482137	479111	11090Q	PARTICIPANT	\N	PRESENT	0
482138	479111	19413M	PARTICIPANT	\N	PRESENT	0
482139	479111	14147R	PARTICIPANT	\N	PRESENT	0
482140	479111	19549D	PARTICIPANT	\N	PRESENT	0
482141	479111	11056N	PARTICIPANT	\N	PRESENT	0
482142	479111	19820Y	PARTICIPANT	\N	PRESENT	0
482143	479111	19914E	PARTICIPANT	\N	PRESENT	0
482144	479111	19565D	PARTICIPANT	\N	PRESENT	0
482145	479111	14205J	PARTICIPANT	\N	PRESENT	0
482146	479111	19691J	PARTICIPANT	\N	PRESENT	0
482147	479111	95030B	PARTICIPANT	\N	PRESENT	0
482148	479111	14051J	PARTICIPANT	\N	PRESENT	0
482149	479111	19507S	PARTICIPANT	\N	PRESENT	0
482150	479111	07033P	PARTICIPANT	\N	PRESENT	0
482151	479111	14265W	PARTICIPANT	\N	PRESENT	0
482152	479111	19711U	PARTICIPANT	\N	PRESENT	0
482153	479111	11099A	PARTICIPANT	\N	PRESENT	0
482154	479111	14033T	PARTICIPANT	\N	PRESENT	0
482155	479111	14119M	PARTICIPANT	\N	PRESENT	0
482156	479111	19467C	PARTICIPANT	\N	PRESENT	0
482157	479111	14031R	PARTICIPANT	\N	PRESENT	0
482158	479111	14357A	PARTICIPANT	\N	PRESENT	0
482159	479111	19347U	PARTICIPANT	\N	PRESENT	0
482160	479111	19383Y	PARTICIPANT	\N	PRESENT	0
482161	479111	11097X	PARTICIPANT	\N	PRESENT	0
482162	479111	19701S	PARTICIPANT	\N	PRESENT	0
482124	479111	01043Q	PARTICIPANT	\N	PRESENT	0
482125	479111	19737F	PARTICIPANT	\N	PRESENT	0
482163	479111	14251Q	PARTICIPANT	\N	PRESENT	0
482164	479111	14034U	PARTICIPANT	\N	PRESENT	0
482218	481562	19930E	PARTICIPANT	\N	PRESENT	0
482219	481562	19729F	PARTICIPANT	\N	PRESENT	0
482220	481562	95063L	PARTICIPANT	\N	PRESENT	0
482221	481562	19629C	PARTICIPANT	\N	PRESENT	0
482222	481562	14147R	PARTICIPANT	\N	PRESENT	0
462499	462495	14087W	PARTICIPANT	\N	PRESENT	0
462500	462495	19521Q	PARTICIPANT	\N	PRESENT	0
462501	462496	14087W	PARTICIPANT	\N	PRESENT	0
462502	462496	19521Q	PARTICIPANT	\N	PRESENT	0
462503	462496	19679N	PARTICIPANT	\N	PRESENT	0
462530	462529	14081Q	PARTICIPANT	\N	PRESENT	0
462531	462529	19503N	PARTICIPANT	\N	PRESENT	0
462532	462529	11066Q	PARTICIPANT	\N	PRESENT	0
462533	462529	95067Q	PARTICIPANT	\N	PRESENT	0
462535	462534	11066Q	PARTICIPANT	\N	PRESENT	0
462537	462536	11066Q	PARTICIPANT	\N	PRESENT	0
462538	462536	14097Y	PARTICIPANT	\N	PRESENT	0
462539	462536	19503N	PARTICIPANT	\N	PRESENT	0
462541	462540	11066Q	PARTICIPANT	\N	PRESENT	0
462542	462540	14097Y	PARTICIPANT	\N	PRESENT	0
462543	462540	19503N	PARTICIPANT	\N	PRESENT	0
462544	462540	95067Q	PARTICIPANT	\N	PRESENT	0
462546	462545	08053X	PARTICIPANT	\N	PRESENT	0
462547	462545	95067Q	PARTICIPANT	\N	PRESENT	0
462548	462545	19421M	PARTICIPANT	\N	PRESENT	0
462549	462545	19503N	PARTICIPANT	\N	PRESENT	0
462550	462545	14081Q	PARTICIPANT	\N	PRESENT	0
462551	462545	11066Q	PARTICIPANT	\N	PRESENT	0
463188	463181	89017R	PARTICIPANT	\N	PRESENT	0
463189	463181	04085P	PARTICIPANT	\N	PRESENT	0
463190	463181	04059M	PARTICIPANT	\N	PRESENT	0
463194	463181	04086Q	PARTICIPANT	\N	PRESENT	0
463192	463181	05008E	PARTICIPANT	\N	PRESENT	0
463193	463181	04042C	PARTICIPANT	\N	PRESENT	0
463195	463181	11070L	PARTICIPANT	\N	PRESENT	0
463196	463181	19719D	PARTICIPANT	\N	PRESENT	0
463197	463181	07033P	PARTICIPANT	\N	PRESENT	0
463198	463181	11074Q	PARTICIPANT	\N	PRESENT	0
463199	463181	14034U	PARTICIPANT	\N	PRESENT	0
463200	463181	14021P	PARTICIPANT	\N	PRESENT	0
463201	463181	01043Q	PARTICIPANT	\N	PRESENT	0
463202	463181	14251Q	PARTICIPANT	\N	PRESENT	0
463203	463181	11085T	PARTICIPANT	\N	PRESENT	0
463204	463181	08009T	PARTICIPANT	\N	PRESENT	0
463205	463181	04092N	PARTICIPANT	\N	PRESENT	0
463206	463181	08011M	PARTICIPANT	\N	PRESENT	0
463207	463181	05012A	PARTICIPANT	\N	PRESENT	0
463208	463181	08061X	PARTICIPANT	\N	PRESENT	0
463209	463181	11090Q	PARTICIPANT	\N	PRESENT	0
463210	463181	04033B	PARTICIPANT	\N	PRESENT	0
463931	463520	19515S	PARTICIPANT	\N	PRESENT	0
463932	463520	19667J	PARTICIPANT	\N	PRESENT	0
463933	463520	19629C	PARTICIPANT	\N	PRESENT	0
463934	463520	19467C	PARTICIPANT	\N	PRESENT	0
463935	463520	04038G	PARTICIPANT	\N	PRESENT	0
463936	463520	02002K	PARTICIPANT	\N	PRESENT	0
463937	463520	19399H	PARTICIPANT	\N	PRESENT	0
463938	463520	99004R	PRESIDENT	0	PRESENT	0
463939	463520	19711U	PARTICIPANT	\N	PRESENT	0
463940	463520	19369B	PARTICIPANT	\N	PRESENT	0
463941	463520	14147R	PARTICIPANT	\N	PRESENT	0
463942	463520	19421M	PARTICIPANT	\N	PRESENT	0
463943	463520	11097X	PARTICIPANT	\N	PRESENT	0
463944	463520	19713W	PARTICIPANT	\N	PRESENT	0
463945	463520	11066Q	PARTICIPANT	\N	PRESENT	0
463946	463520	19479G	PARTICIPANT	\N	PRESENT	0
463947	463520	19737F	PARTICIPANT	\N	PRESENT	0
463948	463520	01028R	PARTICIPANT	\N	EXCUSE	0
463949	463520	08024S	PARTICIPANT	\N	EXCUSE	0
463950	463520	11056N	PARTICIPANT	\N	EXCUSE	0
463951	463520	08045X	PARTICIPANT	\N	EXCUSE	0
463952	463520	19551W	PARTICIPANT	\N	EXCUSE	0
463953	463520	14107H	PARTICIPANT	\N	EXCUSE	0
463954	463520	19741B	PARTICIPANT	\N	PRESENT	0
463956	463955	04070G	PRESIDENT	0	PRESENT	0
463957	463955	08039A	PARTICIPANT	\N	PRESENT	0
463958	463955	19621T	PARTICIPANT	\N	PRESENT	0
463959	463955	14061L	PARTICIPANT	\N	PRESENT	0
463960	463955	19766L	PARTICIPANT	\N	PRESENT	0
463961	463955	19573D	PARTICIPANT	\N	PRESENT	0
463962	463955	14249W	PARTICIPANT	\N	PRESENT	0
463963	463955	19643A	PARTICIPANT	\N	PRESENT	0
463964	463955	19533U	PARTICIPANT	\N	PRESENT	0
463965	463955	19693L	PARTICIPANT	\N	PRESENT	0
463966	463955	11043H	PARTICIPANT	\N	PRESENT	0
463967	463955	14123H	PARTICIPANT	\N	PRESENT	0
463968	463955	14109K	PARTICIPANT	\N	PRESENT	0
463969	463955	08031R	PARTICIPANT	\N	PRESENT	0
463970	463955	11109J	PARTICIPANT	\N	PRESENT	0
463971	463955	19758L	PARTICIPANT	\N	PRESENT	0
463972	463955	11104D	PARTICIPANT	\N	PRESENT	0
463973	463955	19749K	PARTICIPANT	\N	PRESENT	0
463974	463955	08017T	PARTICIPANT	\N	PRESENT	0
463975	463955	19593H	PARTICIPANT	\N	PRESENT	0
463976	463955	14039A	PARTICIPANT	\N	PRESENT	0
463977	463955	14241N	PARTICIPANT	\N	PRESENT	0
463978	463955	19735D	PARTICIPANT	\N	PRESENT	0
463979	463955	19329S	PARTICIPANT	\N	PRESENT	0
463980	463955	14229S	PARTICIPANT	\N	PRESENT	0
463981	463955	19611R	PARTICIPANT	\N	PRESENT	0
463982	463955	14073Q	PARTICIPANT	\N	PRESENT	0
463983	463955	04057K	PARTICIPANT	\N	PRESENT	0
463984	463955	19731Y	PARTICIPANT	\N	PRESENT	0
463985	463955	19699S	PARTICIPANT	\N	PRESENT	0
463986	463955	08043V	PARTICIPANT	\N	PRESENT	0
463987	463955	14107H	PARTICIPANT	\N	EXCUSE	0
464056	463955	14251Q	PARTICIPANT	\N	PRESENT	0
465342	465341	01058X	PARTICIPANT	\N	PRESENT	0
465345	465341	01048V	PRESIDENT	0	PRESENT	0
465346	465341	04043D	PARTICIPANT	\N	PRESENT	0
465347	465341	19593H	PARTICIPANT	\N	PRESENT	0
465348	465341	14221J	PARTICIPANT	\N	PRESENT	0
465349	465341	19533U	PARTICIPANT	\N	PRESENT	0
465350	465341	19503N	PARTICIPANT	\N	PRESENT	0
465351	465341	14093U	PARTICIPANT	\N	PRESENT	0
465353	465341	14299H	PARTICIPANT	\N	PRESENT	0
465358	465341	80013X	PARTICIPANT	\N	PRESENT	0
465359	465341	19693L	PARTICIPANT	\N	PRESENT	0
465360	465341	19663E	PARTICIPANT	\N	PRESENT	0
465361	465341	19709B	PARTICIPANT	\N	PRESENT	0
465362	465341	19723Y	PARTICIPANT	\N	PRESENT	0
465370	465367	19503N	PARTICIPANT	\N	PRESENT	0
465667	465288	01057W	PARTICIPANT	\N	PRESENT	0
465668	465288	19711U	PARTICIPANT	\N	PRESENT	0
465666	465288	19545Y	PARTICIPANT	\N	PRESENT	0
465669	465288	07004J	PARTICIPANT	\N	PRESENT	0
466644	466643	08043V	PARTICIPANT	\N	PRESENT	0
466645	466643	19735D	PARTICIPANT	\N	PRESENT	0
466646	466643	14229S	PARTICIPANT	\N	PRESENT	0
466649	466648	08043V	PARTICIPANT	\N	PRESENT	0
466650	466648	19399H	PARTICIPANT	\N	PRESENT	0
466651	466648	08031R	PARTICIPANT	\N	PRESENT	0
466652	466648	19735D	PARTICIPANT	\N	PRESENT	0
466653	466648	14229S	PARTICIPANT	\N	PRESENT	0
466672	466671	19399H	PARTICIPANT	\N	PRESENT	0
466673	466671	19735D	PARTICIPANT	\N	PRESENT	0
466674	466671	14229S	PARTICIPANT	\N	PRESENT	0
468162	468161	19719D	PARTICIPANT	\N	PRESENT	0
468163	468161	04047H	PARTICIPANT	\N	PRESENT	0
468164	468161	14147R	PARTICIPANT	\N	PRESENT	0
468165	468161	14065Q	PARTICIPANT	\N	PRESENT	0
468213	468212	04047H	PARTICIPANT	\N	PRESENT	0
468214	468212	14021P	PARTICIPANT	\N	PRESENT	0
468215	468212	04008A	PARTICIPANT	\N	PRESENT	0
468216	468212	14065Q	PARTICIPANT	\N	PRESENT	0
468781	468778	14038Y	PARTICIPANT	\N	PRESENT	0
468782	468778	80013X	PARTICIPANT	\N	PRESENT	0
468783	468778	19711U	PARTICIPANT	\N	PRESENT	0
468784	468676	08060W	PARTICIPANT	\N	EXCUSE	0
468785	468676	14041T	PARTICIPANT	\N	EXCUSE	0
468482	468391	19269X	PARTICIPANT	\N	PRESENT	0
468528	468391	14115H	PARTICIPANT	\N	PRESENT	0
468779	468778	11070L	PARTICIPANT	\N	PRESENT	0
468780	468778	11040E	PARTICIPANT	\N	PRESENT	0
468786	468676	14255U	PARTICIPANT	\N	EXCUSE	0
468787	468676	08047A	PARTICIPANT	\N	EXCUSE	0
468788	468676	04049K	PRESIDENT	0	PRESENT	0
468789	468676	14087W	PARTICIPANT	\N	PRESENT	0
468790	468676	08015R	PARTICIPANT	\N	PRESENT	0
468791	468676	19575F	PARTICIPANT	\N	PRESENT	0
468792	468676	14083S	PARTICIPANT	\N	PRESENT	0
468793	468676	14265W	PARTICIPANT	\N	PRESENT	0
468985	468984	14030Q	PARTICIPANT	\N	PRESENT	0
468986	468984	14083S	PARTICIPANT	\N	PRESENT	0
468987	468984	19521Q	PARTICIPANT	\N	PRESENT	0
473372	468777	19731Y	PARTICIPANT	\N	PRESENT	0
473373	468777	80013X	PARTICIPANT	\N	PRESENT	0
473374	468777	19643A	PARTICIPANT	\N	PRESENT	0
473375	468777	14109K	PARTICIPANT	\N	PRESENT	0
473376	468777	19715Y	PARTICIPANT	\N	PRESENT	0
473377	468777	11031D	PARTICIPANT	\N	PRESENT	0
473378	468777	04035D	PARTICIPANT	\N	PRESENT	0
473379	468777	08017T	PARTICIPANT	\N	PRESENT	0
473380	468777	11067R	PARTICIPANT	\N	PRESENT	0
473385	468777	14179A	PARTICIPANT	\N	PRESENT	0
480654	479091	14034U	PARTICIPANT	\N	PRESENT	0
480655	479091	12041X	PARTICIPANT	\N	PRESENT	0
480656	479091	14235Q	PARTICIPANT	\N	PRESENT	0
480657	479091	19565D	PARTICIPANT	\N	PRESENT	0
480658	479091	11054L	PARTICIPANT	\N	PRESENT	0
480659	479091	01028R	PARTICIPANT	\N	PRESENT	0
480660	479091	19593H	PARTICIPANT	\N	PRESENT	0
480661	479091	11031D	PARTICIPANT	\N	PRESENT	0
480662	479091	19760E	PARTICIPANT	\N	PRESENT	0
480663	479091	11064N	PARTICIPANT	\N	PRESENT	0
480664	479091	19812Y	PARTICIPANT	\N	PRESENT	0
480665	479091	19333N	PARTICIPANT	\N	PRESENT	0
480666	479091	19551W	PARTICIPANT	\N	PRESENT	0
480667	479091	19599P	PARTICIPANT	\N	PRESENT	0
480668	479091	18083K	PARTICIPANT	\N	PRESENT	0
480669	479091	04042C	PARTICIPANT	\N	PRESENT	0
480670	479091	14133K	PARTICIPANT	\N	PRESENT	0
480671	479091	19731Y	PARTICIPANT	\N	PRESENT	0
480672	479091	14267Y	PARTICIPANT	\N	PRESENT	0
480673	479091	98029W	PARTICIPANT	\N	PRESENT	0
480674	479091	01024M	PARTICIPANT	\N	PRESENT	0
480675	479091	08039A	PARTICIPANT	\N	PRESENT	0
480676	479091	88008L	PARTICIPANT	\N	PRESENT	0
480677	479091	14069U	PARTICIPANT	\N	PRESENT	0
480678	479091	19709B	PARTICIPANT	\N	PRESENT	0
480679	479091	19347U	PARTICIPANT	\N	PRESENT	0
480680	479091	04085P	PARTICIPANT	\N	PRESENT	0
480730	476595	19503N	PARTICIPANT	\N	PRESENT	0
480731	476595	19798U	PARTICIPANT	\N	PRESENT	0
480732	476595	19387D	PARTICIPANT	\N	PRESENT	0
480749	476595	19575F	PARTICIPANT	\N	PRESENT	0
480836	480835	14133K	PARTICIPANT	\N	PRESENT	0
480837	480835	14079W	PARTICIPANT	\N	PRESENT	0
480838	480835	01048V	PARTICIPANT	\N	PRESENT	0
480839	480835	95067Q	PARTICIPANT	\N	PRESENT	0
480858	476018	14093U	PARTICIPANT	\N	PRESENT	0
480859	476018	14299H	PARTICIPANT	\N	EXCUSE	0
480861	476018	19723Y	PARTICIPANT	\N	PRESENT	0
480862	476018	01048V	PRESIDENT	0	PRESENT	0
480863	476018	19533U	PARTICIPANT	\N	PRESENT	0
480864	476018	04043D	PARTICIPANT	\N	EXCUSE	0
480865	476018	19503N	PARTICIPANT	\N	PRESENT	0
480866	476018	01058X	PARTICIPANT	\N	PRESENT	0
480870	476018	80013X	PARTICIPANT	\N	PRESENT	0
480871	476018	19693L	PARTICIPANT	\N	EXCUSE	0
480887	479053	11097X	PRESIDENT	0	PRESENT	0
480888	479053	04092N	PARTICIPANT	\N	EXCUSE	0
480889	479053	19565D	PARTICIPANT	\N	EXCUSE	0
480890	479053	14042U	PARTICIPANT	\N	PRESENT	0
480891	479053	19521Q	PARTICIPANT	\N	PRESENT	0
480892	479053	19679N	PARTICIPANT	\N	PRESENT	0
480893	479053	14213J	PARTICIPANT	\N	PRESENT	0
480931	479053	19703U	PARTICIPANT	\N	PRESENT	0
480932	479053	19798U	PARTICIPANT	\N	PRESENT	0
480933	479053	19575F	PARTICIPANT	\N	PRESENT	0
480935	479053	14087W	PARTICIPANT	\N	PRESENT	0
480936	479053	08052W	PARTICIPANT	\N	PRESENT	0
480937	479053	11067R	PARTICIPANT	\N	PRESENT	0
480938	479053	19697Q	PARTICIPANT	\N	PRESENT	0
480939	479053	19657G	PARTICIPANT	\N	PRESENT	0
480940	479053	19717B	PARTICIPANT	\N	EXCUSE	0
480954	479053	19760E	PARTICIPANT	\N	PRESENT	0
480958	479053	14227Q	PARTICIPANT	\N	PRESENT	0
480965	479282	11053K	PARTICIPANT	\N	PRESENT	0
480966	479282	04086Q	PARTICIPANT	\N	PRESENT	0
480967	479282	11074Q	PARTICIPANT	\N	PRESENT	0
480968	479282	19647E	PARTICIPANT	\N	PRESENT	0
480969	479282	19711U	PARTICIPANT	\N	PRESENT	0
480970	479282	19671E	PARTICIPANT	\N	PRESENT	0
480971	479282	19687N	PARTICIPANT	\N	PRESENT	0
480972	479053	14026U	PARTICIPANT	\N	PRESENT	0
481293	481285	10006L	PARTICIPANT	\N	PRESENT	0
481294	481285	19723Y	PARTICIPANT	\N	PRESENT	0
481295	481285	19798U	PARTICIPANT	\N	PRESENT	0
481416	481413	96004D	PRESIDENT	0	PRESENT	0
481417	481413	11083R	PARTICIPANT	\N	PRESENT	0
481418	481413	19725B	PARTICIPANT	\N	PRESENT	0
481419	481413	14001X	PARTICIPANT	\N	PRESENT	0
481420	481413	14133K	PARTICIPANT	\N	PRESENT	0
481421	481413	04035D	PARTICIPANT	\N	PRESENT	0
481422	481413	11026G	PARTICIPANT	\N	PRESENT	0
481423	481413	19553Y	PARTICIPANT	\N	PRESENT	0
481424	481413	04057K	PARTICIPANT	\N	PRESENT	0
481425	481413	12041X	PARTICIPANT	\N	PRESENT	0
481426	481413	14237S	PARTICIPANT	\N	PRESENT	0
481427	481413	14249W	PARTICIPANT	\N	PRESENT	0
481428	481413	14331P	PARTICIPANT	\N	PRESENT	0
481429	481413	14241N	PARTICIPANT	\N	PRESENT	0
481430	481413	14097Y	PARTICIPANT	\N	PRESENT	0
481431	481413	10015M	PARTICIPANT	\N	PRESENT	0
481432	481413	98035U	PARTICIPANT	\N	PRESENT	0
481433	481413	19563B	PARTICIPANT	\N	PRESENT	0
481466	481464	14147R	PARTICIPANT	\N	PRESENT	0
481467	481464	08012N	PARTICIPANT	\N	PRESENT	0
481468	481464	11043H	PARTICIPANT	\N	PRESENT	0
481469	481464	19349W	PARTICIPANT	\N	PRESENT	0
481470	481464	14030Q	PARTICIPANT	\N	PRESENT	0
481471	481464	19533U	PARTICIPANT	\N	PRESENT	0
481472	481464	19399H	PARTICIPANT	\N	PRESENT	0
481473	481464	19711U	PARTICIPANT	\N	PRESENT	0
481477	481465	08012N	PARTICIPANT	\N	PRESENT	0
481478	481465	14147R	PARTICIPANT	\N	PRESENT	0
481479	481465	02002K	PARTICIPANT	\N	PRESENT	0
481480	481465	11043H	PARTICIPANT	\N	PRESENT	0
481481	481465	19349W	PARTICIPANT	\N	PRESENT	0
481482	481465	14030Q	PARTICIPANT	\N	PRESENT	0
481483	481465	19533U	PARTICIPANT	\N	PRESENT	0
481484	481464	02002K	PARTICIPANT	\N	PRESENT	0
481486	481485	02002K	PARTICIPANT	\N	PRESENT	0
481487	481485	11043H	PARTICIPANT	\N	PRESENT	0
481488	481485	19711U	PARTICIPANT	\N	PRESENT	0
481489	481485	19399H	PARTICIPANT	\N	PRESENT	0
481490	481485	14147R	PARTICIPANT	\N	PRESENT	0
481491	481485	08012N	PARTICIPANT	\N	PRESENT	0
481523	481522	11074Q	PARTICIPANT	\N	PRESENT	0
481525	481524	08011M	PARTICIPANT	\N	PRESENT	0
481720	481531	19503N	PARTICIPANT	\N	PRESENT	0
481721	481531	19798U	PARTICIPANT	\N	PRESENT	0
481722	481531	19387D	PARTICIPANT	\N	PRESENT	0
481724	481531	19575F	PARTICIPANT	\N	PRESENT	0
481726	481531	19619A	PARTICIPANT	\N	PRESENT	0
481728	481531	08049C	PARTICIPANT	\N	PRESENT	0
482054	482053	14241N	PARTICIPANT	\N	PRESENT	0
481786	481531	14026U	PARTICIPANT	\N	PRESENT	0
482052	481531	19335Q	PRESIDENT	0	PRESENT	0
482060	482059	96004D	PARTICIPANT	\N	PRESENT	0
482061	482059	19569H	PARTICIPANT	\N	PRESENT	0
482062	482059	14001X	PARTICIPANT	\N	PRESENT	0
482063	482059	11083R	PARTICIPANT	\N	PRESENT	0
482171	481626	14093U	PARTICIPANT	\N	PRESENT	0
482331	482233	14081Q	PARTICIPANT	\N	EXCUSE	0
482173	481626	19914E	PARTICIPANT	\N	PRESENT	0
482184	481626	15447F	PARTICIPANT	\N	PRESENT	0
482185	481626	19333N	PARTICIPANT	\N	PRESENT	0
482186	481626	14031R	PARTICIPANT	\N	PRESENT	0
482187	481626	19826F	PARTICIPANT	\N	PRESENT	0
482188	481626	08009T	PRESIDENT	0	PRESENT	0
482189	481626	19503N	PARTICIPANT	\N	PRESENT	0
482332	482233	08015R	PARTICIPANT	\N	EXCUSE	0
482336	482233	01043Q	PARTICIPANT	\N	PRESENT	0
482340	482233	08028W	PARTICIPANT	\N	EXCUSE	0
482193	481626	19820Y	PARTICIPANT	\N	PRESENT	0
482330	482233	19866P	PARTICIPANT	\N	EXCUSE	0
482348	480873	17637T	PARTICIPANT	\N	EXCUSE	0
482373	480873	14195A	PARTICIPANT	\N	EXCUSE	0
482468	480873	04045F	PARTICIPANT	\N	EXCUSE	0
482469	480873	04044E	PARTICIPANT	\N	EXCUSE	0
482624	479258	14051J	PARTICIPANT	\N	PRESENT	0
482625	480873	08049C	PARTICIPANT	\N	EXCUSE	0
482626	479258	19415P	PARTICIPANT	\N	PRESENT	0
482627	479258	19467C	PARTICIPANT	\N	PRESENT	0
482628	479258	18083K	PARTICIPANT	\N	PRESENT	0
482629	479258	08019V	PARTICIPANT	\N	PRESENT	0
454482	448746	11067R	PARTICIPANT	\N	PRESENT	0
454483	448746	14281W	PARTICIPANT	\N	PRESENT	0
454484	448746	14213J	PARTICIPANT	\N	PRESENT	0
454485	448746	01028R	PARTICIPANT	\N	PRESENT	0
454486	448746	11066Q	PARTICIPANT	\N	PRESENT	0
454487	448746	11072N	PARTICIPANT	\N	PRESENT	0
454488	448746	19782L	PARTICIPANT	\N	PRESENT	0
454489	448746	14121F	PARTICIPANT	\N	PRESENT	0
454490	448746	19585H	PARTICIPANT	\N	PRESENT	0
454491	448746	14261S	PARTICIPANT	\N	PRESENT	0
454492	448746	19737F	PARTICIPANT	\N	PRESENT	0
454494	448746	01025N	PARTICIPANT	\N	PRESENT	0
454496	448746	01024M	PARTICIPANT	\N	PRESENT	0
454497	448746	19747H	PARTICIPANT	\N	PRESENT	0
454498	448746	19731Y	PARTICIPANT	\N	PRESENT	0
454499	448746	98050T	PARTICIPANT	\N	PRESENT	0
454500	448746	08028W	PARTICIPANT	\N	PRESENT	0
454501	448746	08019V	PARTICIPANT	\N	PRESENT	0
454502	448746	04092N	PARTICIPANT	\N	PRESENT	0
454503	448746	11103C	PARTICIPANT	\N	PRESENT	0
454504	448746	14069U	PARTICIPANT	\N	PRESENT	0
454505	448746	14147R	PARTICIPANT	\N	PRESENT	0
454506	448746	14105F	PARTICIPANT	\N	PRESENT	0
454507	448746	98005N	PARTICIPANT	\N	PRESENT	0
454508	448746	08044W	PARTICIPANT	\N	PRESENT	0
454511	448746	19399H	PARTICIPANT	\N	PRESENT	0
454512	448746	19415P	PARTICIPANT	\N	PRESENT	0
454513	448746	18083K	PARTICIPANT	\N	PRESENT	0
454514	448746	19447X	PARTICIPANT	\N	PRESENT	0
454515	448746	14038Y	PARTICIPANT	\N	PRESENT	0
454516	448746	08020N	PARTICIPANT	\N	PRESENT	0
454518	448746	19533U	PARTICIPANT	\N	PRESENT	0
454519	448746	04018C	PARTICIPANT	\N	PRESENT	0
454521	448746	19581D	PARTICIPANT	\N	PRESENT	0
454522	448746	19619A	PARTICIPANT	\N	PRESENT	0
454523	448746	07004J	PARTICIPANT	\N	PRESENT	0
454524	448746	19739H	PARTICIPANT	\N	PRESENT	0
454525	448746	19719D	PARTICIPANT	\N	PRESENT	0
454526	448746	19593H	PARTICIPANT	\N	PRESENT	0
454527	448746	14063N	PARTICIPANT	\N	PRESENT	0
454528	448746	14123H	PARTICIPANT	\N	PRESENT	0
454529	448746	11056N	PARTICIPANT	\N	PRESENT	0
454531	448746	19758L	PARTICIPANT	\N	PRESENT	0
454533	448746	19649G	PARTICIPANT	\N	PRESENT	0
454534	448746	14030Q	PARTICIPANT	\N	PRESENT	0
454535	448746	19599P	PARTICIPANT	\N	PRESENT	0
454480	448746	11070L	PARTICIPANT	\N	PRESENT	0
454481	448746	19565D	PARTICIPANT	\N	PRESENT	0
454536	448746	14083S	PARTICIPANT	\N	PRESENT	0
454537	448746	14197C	PARTICIPANT	\N	PRESENT	0
454538	448746	15447F	PARTICIPANT	\N	PRESENT	0
454539	448746	08015R	PARTICIPANT	\N	PRESENT	0
454540	448746	19515S	PARTICIPANT	\N	PRESENT	0
454541	448746	19301E	PARTICIPANT	\N	PRESENT	0
454542	448746	19729F	PARTICIPANT	\N	PRESENT	0
454543	448746	19798U	PARTICIPANT	\N	PRESENT	0
454544	448746	11104D	PARTICIPANT	\N	PRESENT	0
454545	448746	14151M	PARTICIPANT	\N	PRESENT	0
454546	448746	08062Y	PARTICIPANT	\N	PRESENT	0
454547	448746	99004R	PARTICIPANT	\N	PRESENT	0
454548	448746	14259Y	PARTICIPANT	\N	PRESENT	0
454559	448746	14021P	PARTICIPANT	\N	PRESENT	0
454561	448746	08055A	PARTICIPANT	\N	PRESENT	0
454562	448746	80013X	PARTICIPANT	\N	PRESENT	0
454563	448746	19335Q	PARTICIPANT	\N	PRESENT	0
454564	448746	97011G	PARTICIPANT	\N	PRESENT	0
454565	448746	19479G	PARTICIPANT	\N	PRESENT	0
454566	448746	14033T	PARTICIPANT	\N	PRESENT	0
454570	448746	19553Y	PARTICIPANT	\N	PRESENT	0
454571	448746	04088S	PARTICIPANT	\N	PRESENT	0
454572	448746	07033P	PARTICIPANT	\N	PRESENT	0
454573	448746	19629C	PARTICIPANT	\N	PRESENT	0
454575	448746	14231L	PARTICIPANT	\N	PRESENT	0
454576	448746	14173T	PARTICIPANT	\N	PRESENT	0
454577	448746	19715Y	PARTICIPANT	\N	PRESENT	0
454578	448746	14179A	PARTICIPANT	\N	PRESENT	0
456291	454190	14135M	PARTICIPANT	\N	PRESENT	0
456292	454190	19467C	PARTICIPANT	\N	PRESENT	0
456293	454190	11090Q	PRESIDENT	0	PRESENT	0
456294	454190	80013X	PARTICIPANT	\N	PRESENT	0
456295	454190	04045F	PARTICIPANT	\N	PRESENT	0
456296	454190	19631V	PARTICIPANT	\N	PRESENT	0
456297	454190	14205J	PARTICIPANT	\N	PRESENT	0
456298	454190	11099A	PARTICIPANT	\N	PRESENT	0
456299	454190	19507S	PARTICIPANT	\N	PRESENT	0
456300	454190	08015R	PARTICIPANT	\N	PRESENT	0
456301	454190	14197C	PARTICIPANT	\N	PRESENT	0
456302	454190	14207L	PARTICIPANT	\N	PRESENT	0
456303	454190	14257W	PARTICIPANT	\N	PRESENT	0
456304	454190	19782L	PARTICIPANT	\N	PRESENT	0
456305	454190	14357A	PARTICIPANT	\N	EXCUSE	0
456306	454190	08038Y	PARTICIPANT	\N	EXCUSE	0
456307	454190	19812Y	PARTICIPANT	\N	EXCUSE	0
456308	454190	01025N	PARTICIPANT	\N	EXCUSE	0
456309	454190	14033T	PARTICIPANT	\N	EXCUSE	0
456310	454190	08028W	PARTICIPANT	\N	EXCUSE	0
456311	454190	11081P	PARTICIPANT	\N	EXCUSE	0
456312	454190	17589D	PARTICIPANT	\N	EXCUSE	0
456313	454190	19768N	PARTICIPANT	\N	PRESENT	0
456314	454190	19515S	PARTICIPANT	\N	PRESENT	0
456315	454190	19695N	PARTICIPANT	\N	PRESENT	0
456316	454190	08019V	PARTICIPANT	\N	PRESENT	0
456317	454190	19619A	PARTICIPANT	\N	PRESENT	0
456318	454187	14187A	PARTICIPANT	\N	PRESENT	0
456319	454187	11026G	PRESIDENT	0	PRESENT	0
456320	454187	19673G	PARTICIPANT	\N	PRESENT	0
457850	448757	19369B	PARTICIPANT	\N	PRESENT	0
457851	448757	14265W	PARTICIPANT	\N	PRESENT	0
457852	448757	01034P	PARTICIPANT	\N	PRESENT	0
457853	448757	11053K	PARTICIPANT	\N	PRESENT	0
457854	448757	19611R	PARTICIPANT	\N	PRESENT	0
457855	448757	19721W	PARTICIPANT	\N	PRESENT	0
457856	448757	05012A	PARTICIPANT	\N	PRESENT	0
457857	448757	08009T	PARTICIPANT	\N	PRESENT	0
457858	448757	11090Q	PARTICIPANT	\N	PRESENT	0
457859	448757	19794Q	PARTICIPANT	\N	PRESENT	0
457860	448757	19739H	PARTICIPANT	\N	PRESENT	0
457862	448757	19735D	PARTICIPANT	\N	PRESENT	0
457863	448757	16685X	PARTICIPANT	\N	PRESENT	0
457864	448757	19441R	PARTICIPANT	\N	PRESENT	0
457865	448757	14089Y	PARTICIPANT	\N	PRESENT	0
457866	448757	19479G	PARTICIPANT	\N	PRESENT	0
457867	448757	19319Q	PARTICIPANT	\N	PRESENT	0
457868	448757	19713W	PARTICIPANT	\N	PRESENT	0
457869	448757	14275Y	PARTICIPANT	\N	PRESENT	0
457870	448757	19335Q	PARTICIPANT	\N	PRESENT	0
457871	448757	08056B	PARTICIPANT	\N	PRESENT	0
457872	448757	11097X	PARTICIPANT	\N	PRESENT	0
457873	448757	14083S	PARTICIPANT	\N	PRESENT	0
457874	448757	14073Q	PARTICIPANT	\N	PRESENT	0
457875	448757	07004J	PARTICIPANT	\N	PRESENT	0
457876	448757	19521Q	PARTICIPANT	\N	PRESENT	0
457877	448757	04070G	PARTICIPANT	\N	PRESENT	0
457878	448757	01024M	PARTICIPANT	\N	PRESENT	0
457879	448757	14030Q	PARTICIPANT	\N	PRESENT	0
457880	448757	14327T	PARTICIPANT	\N	PRESENT	0
457881	448757	01043Q	PARTICIPANT	\N	PRESENT	0
457882	448757	19745F	PARTICIPANT	\N	PRESENT	0
457883	448757	14103D	PARTICIPANT	\N	PRESENT	0
457884	448757	19826F	PARTICIPANT	\N	PRESENT	0
457885	448757	11064N	PARTICIPANT	\N	PRESENT	0
457886	448757	95067Q	PARTICIPANT	\N	PRESENT	0
457887	448757	14001X	PARTICIPANT	\N	PRESENT	0
457888	448757	19333N	PARTICIPANT	\N	PRESENT	0
457889	448757	14121F	PARTICIPANT	\N	PRESENT	0
457890	448757	01048V	PARTICIPANT	\N	PRESENT	0
457891	448757	01060R	PARTICIPANT	\N	PRESENT	0
457892	448757	14259Y	PARTICIPANT	\N	PRESENT	0
457909	456666	19347U	PARTICIPANT	\N	PRESENT	0
457913	456666	14237S	PARTICIPANT	\N	EXCUSE	0
457918	456891	19549D	PARTICIPANT	\N	PRESENT	0
457919	456891	19629C	PARTICIPANT	\N	PRESENT	0
457920	456891	14079W	PARTICIPANT	\N	PRESENT	0
457921	456891	19369B	PARTICIPANT	\N	PRESENT	0
457924	456891	19735D	PARTICIPANT	\N	PRESENT	0
458538	455106	19719D	PRESIDENT	0	PRESENT	0
458546	458323	14093U	PARTICIPANT	\N	PRESENT	0
458547	458323	19367Y	PARTICIPANT	\N	PRESENT	0
458548	458323	08060W	PARTICIPANT	\N	PRESENT	0
458549	458323	19758L	PARTICIPANT	\N	PRESENT	0
458550	458323	08024S	PARTICIPANT	\N	PRESENT	0
458551	458323	19251M	PARTICIPANT	\N	PRESENT	0
458552	458323	14033T	PARTICIPANT	\N	PRESENT	0
458553	458323	14026U	PARTICIPANT	\N	EXCUSE	0
458554	458323	11048N	PARTICIPANT	\N	PRESENT	0
458555	458323	14051J	PARTICIPANT	\N	PRESENT	0
458556	458323	08009T	PRESIDENT	0	PRESENT	0
458557	458323	19826F	PARTICIPANT	\N	PRESENT	0
458558	458323	95067Q	PARTICIPANT	\N	PRESENT	0
483464	483299	14039A	PARTICIPANT	\N	PRESENT	0
483465	483299	14267Y	PARTICIPANT	\N	PRESENT	0
484477	483267	14063N	PARTICIPANT	\N	PRESENT	0
484478	483267	05012A	PARTICIPANT	\N	PRESENT	0
484479	483267	04086Q	PARTICIPANT	\N	EXCUSE	0
484480	483267	19489J	PARTICIPANT	\N	PRESENT	0
484481	483267	95063L	PARTICIPANT	\N	PRESENT	0
484482	483267	19565D	PARTICIPANT	\N	EXCUSE	0
484483	483267	19735D	PARTICIPANT	\N	EXCUSE	0
484485	483267	08034U	PARTICIPANT	\N	EXCUSE	0
484490	483267	08049C	PARTICIPANT	\N	EXCUSE	0
484538	483267	14281W	PARTICIPANT	\N	PRESENT	0
484597	484596	14083S	PARTICIPANT	\N	PRESENT	0
484601	484600	04092N	PARTICIPANT	\N	PRESENT	0
484602	484600	01034P	PARTICIPANT	\N	PRESENT	0
484603	484600	14071N	PARTICIPANT	\N	PRESENT	0
484604	484600	11097X	PARTICIPANT	\N	PRESENT	0
484605	484600	08052W	PARTICIPANT	\N	PRESENT	0
484606	484600	11067R	PARTICIPANT	\N	PRESENT	0
484607	484600	19301E	PARTICIPANT	\N	PRESENT	0
484608	484600	14217N	PARTICIPANT	\N	PRESENT	0
484610	484609	04092N	PARTICIPANT	\N	PRESENT	0
484611	484609	01034P	PARTICIPANT	\N	PRESENT	0
484612	484609	14071N	PARTICIPANT	\N	PRESENT	0
484613	484609	11097X	PARTICIPANT	\N	PRESENT	0
484614	484609	08052W	PARTICIPANT	\N	PRESENT	0
484615	484609	11067R	PARTICIPANT	\N	PRESENT	0
484616	484609	19301E	PARTICIPANT	\N	PRESENT	0
484617	484609	14217N	PARTICIPANT	\N	PRESENT	0
484640	484638	19503N	PARTICIPANT	\N	PRESENT	0
484643	484641	19503N	PARTICIPANT	\N	PRESENT	0
484646	484644	19503N	PARTICIPANT	\N	PRESENT	0
484905	484689	19545Y	PARTICIPANT	\N	EXCUSE	0
484907	484690	19545Y	PARTICIPANT	\N	EXCUSE	0
493377	491477	10006L	PARTICIPANT	\N	PRESENT	0
493378	491477	19683J	PARTICIPANT	\N	PRESENT	0
491514	491513	04085P	PARTICIPANT	\N	PRESENT	0
491515	491513	05008E	PARTICIPANT	\N	PRESENT	0
491516	491513	04047H	PARTICIPANT	\N	PRESENT	0
491517	491513	04042C	PARTICIPANT	\N	PRESENT	0
491518	491513	11070L	PARTICIPANT	\N	PRESENT	0
491519	491513	19719D	PARTICIPANT	\N	PRESENT	0
491520	491513	10006L	PARTICIPANT	\N	PRESENT	0
491521	491513	19347U	PARTICIPANT	\N	PRESENT	0
491522	491513	14026U	PARTICIPANT	\N	PRESENT	0
491523	491513	14021P	PARTICIPANT	\N	PRESENT	0
491524	491513	99004R	PARTICIPANT	\N	PRESENT	0
491525	491513	19611R	PARTICIPANT	\N	PRESENT	0
491526	491513	12041X	PARTICIPANT	\N	PRESENT	0
491527	491513	01043Q	PARTICIPANT	\N	PRESENT	0
491528	491513	14251Q	PARTICIPANT	\N	PRESENT	0
491529	491513	11085T	PARTICIPANT	\N	PRESENT	0
491530	491513	01060R	PARTICIPANT	\N	PRESENT	0
491531	491513	04092N	PARTICIPANT	\N	PRESENT	0
491532	491513	11072N	PARTICIPANT	\N	PRESENT	0
491533	491513	14071N	PARTICIPANT	\N	PRESENT	0
491534	491513	08073C	PARTICIPANT	\N	PRESENT	0
491535	491513	05012A	PARTICIPANT	\N	PRESENT	0
491536	491513	11090Q	PARTICIPANT	\N	PRESENT	0
491537	491513	14331P	PARTICIPANT	\N	PRESENT	0
491538	491513	14225N	PARTICIPANT	\N	PRESENT	0
491539	491513	11012A	PARTICIPANT	\N	PRESENT	0
491540	491513	04033B	PARTICIPANT	\N	PRESENT	0
491541	491513	11045K	PARTICIPANT	\N	PRESENT	0
491542	491513	01034P	PARTICIPANT	\N	PRESENT	0
493379	491477	11097X	PARTICIPANT	\N	PRESENT	0
493376	491477	19479G	PARTICIPANT	\N	PRESENT	0
493380	491477	19715Y	PARTICIPANT	\N	PRESENT	0
493381	491477	19691J	PARTICIPANT	\N	PRESENT	0
493382	491477	11067R	PARTICIPANT	\N	PRESENT	0
493383	491477	19713W	PARTICIPANT	\N	PRESENT	0
493384	491477	04092N	PRESIDENT	0	PRESENT	0
493385	491477	19503N	PARTICIPANT	\N	PRESENT	0
493386	491477	11031D	PARTICIPANT	\N	PRESENT	0
493387	491477	11012A	PARTICIPANT	\N	EXCUSE	0
495289	495288	04042C	PARTICIPANT	\N	PRESENT	0
495290	495288	08047A	PARTICIPANT	\N	PRESENT	0
495291	495288	19565D	PARTICIPANT	\N	PRESENT	0
495292	495288	20042V	PARTICIPANT	\N	PRESENT	0
495293	495288	14193X	PARTICIPANT	\N	PRESENT	0
495294	495288	14059S	PARTICIPANT	\N	PRESENT	0
495295	495288	19709B	PARTICIPANT	\N	PRESENT	0
495296	495288	20128B	PARTICIPANT	\N	PRESENT	0
495297	495288	08069G	PARTICIPANT	\N	PRESENT	0
495299	495298	14231L	PARTICIPANT	\N	PRESENT	0
495300	495298	14259Y	PARTICIPANT	\N	PRESENT	0
495301	495298	14053L	PARTICIPANT	\N	PRESENT	0
495302	495298	19749K	PARTICIPANT	\N	PRESENT	0
495304	495303	11053K	PARTICIPANT	\N	PRESENT	0
495306	495305	05008E	PARTICIPANT	\N	PRESENT	0
495307	495305	11053K	PARTICIPANT	\N	PRESENT	0
495308	495305	14357A	PARTICIPANT	\N	PRESENT	0
495309	495305	11070L	PARTICIPANT	\N	PRESENT	0
495310	495305	19719D	PARTICIPANT	\N	PRESENT	0
495311	495305	19673G	PARTICIPANT	\N	PRESENT	0
495312	495305	01025N	PARTICIPANT	\N	PRESENT	0
495313	495305	14033T	PARTICIPANT	\N	PRESENT	0
495314	495305	14123H	PARTICIPANT	\N	PRESENT	0
495315	495305	14026U	PARTICIPANT	\N	PRESENT	0
495316	495305	14179A	PARTICIPANT	\N	PRESENT	0
495317	495305	14213J	PARTICIPANT	\N	PRESENT	0
495318	495305	19715Y	PARTICIPANT	\N	PRESENT	0
495319	495305	99004R	PARTICIPANT	\N	PRESENT	0
495320	495305	86034E	PARTICIPANT	\N	PRESENT	0
495321	495305	12041X	PARTICIPANT	\N	PRESENT	0
495322	495305	01043Q	PARTICIPANT	\N	PRESENT	0
503136	503135	08009T	PARTICIPANT	\N	PRESENT	0
503137	503135	20044X	PARTICIPANT	\N	PRESENT	0
503139	503138	08009T	PARTICIPANT	\N	PRESENT	0
495326	495305	01028R	PARTICIPANT	\N	PRESENT	0
495327	495305	19413M	PARTICIPANT	\N	PRESENT	0
503140	503138	20044X	PARTICIPANT	\N	PRESENT	0
503142	503141	08009T	PARTICIPANT	\N	PRESENT	0
503143	503141	20044X	PARTICIPANT	\N	PRESENT	0
503148	503147	11048N	PARTICIPANT	\N	PRESENT	0
503533	503532	01048V	PARTICIPANT	\N	PRESENT	0
503540	503538	01048V	PARTICIPANT	\N	PRESENT	0
503544	503543	01048V	PARTICIPANT	\N	PRESENT	0
503546	503133	20142Y	PARTICIPANT	\N	PRESENT	0
503547	503157	19577H	PARTICIPANT	\N	PRESENT	0
503548	503157	20102Q	PARTICIPANT	\N	EXCUSE	0
503549	503157	19637C	PARTICIPANT	\N	PRESENT	0
503551	503157	20020P	PARTICIPANT	\N	PRESENT	0
503556	503555	11031D	PARTICIPANT	\N	PRESENT	0
503558	503557	04070G	PARTICIPANT	\N	PRESENT	0
503559	503557	19621T	PARTICIPANT	\N	PRESENT	0
503560	503557	08017T	PARTICIPANT	\N	PRESENT	0
503561	503557	14109K	PARTICIPANT	\N	PRESENT	0
503562	503557	19593H	PARTICIPANT	\N	PRESENT	0
503563	503557	19735D	PARTICIPANT	\N	PRESENT	0
503565	503564	14229S	PARTICIPANT	\N	PRESENT	0
503566	503564	19651A	PARTICIPANT	\N	PRESENT	0
503567	503564	20052X	PARTICIPANT	\N	PRESENT	0
503568	503564	19735D	PARTICIPANT	\N	PRESENT	0
503570	503569	14229S	PARTICIPANT	\N	PRESENT	0
503571	503569	11104D	PARTICIPANT	\N	PRESENT	0
503572	503569	19651A	PARTICIPANT	\N	PRESENT	0
503573	503569	08017T	PARTICIPANT	\N	PRESENT	0
503574	503569	19735D	PARTICIPANT	\N	PRESENT	0
503632	503631	14229S	PARTICIPANT	\N	PRESENT	0
503633	503631	08017T	PARTICIPANT	\N	PRESENT	0
503635	503631	19735D	PARTICIPANT	\N	PRESENT	0
503650	503647	14229S	PARTICIPANT	\N	PRESENT	0
503651	503647	08017T	PARTICIPANT	\N	PRESENT	0
503653	503647	19735D	PARTICIPANT	\N	PRESENT	0
503654	503647	20058E	PARTICIPANT	\N	PRESENT	0
503685	503683	14229S	PARTICIPANT	\N	PRESENT	0
503687	503683	19651A	PARTICIPANT	\N	PRESENT	0
503688	503683	19399H	PARTICIPANT	\N	PRESENT	0
503691	503683	08017T	PARTICIPANT	\N	PRESENT	0
503692	503683	19735D	PARTICIPANT	\N	PRESENT	0
503694	503683	20098N	PARTICIPANT	\N	PRESENT	0
503695	503683	20058E	PARTICIPANT	\N	PRESENT	0
503714	503712	14229S	PARTICIPANT	\N	PRESENT	0
485640	484736	19533U	PARTICIPANT	\N	PRESENT	0
485641	484736	11070L	PARTICIPANT	\N	PRESENT	0
485642	484736	19441R	PARTICIPANT	\N	PRESENT	0
485643	484736	19413M	PARTICIPANT	\N	PRESENT	0
485644	484736	11085T	PARTICIPANT	\N	PRESENT	0
485650	484736	11067R	PARTICIPANT	\N	PRESENT	0
485651	484736	19479G	PARTICIPANT	\N	PRESENT	0
485652	484736	16685X	PARTICIPANT	\N	PRESENT	0
485653	484736	14179A	PARTICIPANT	\N	PRESENT	0
485654	484736	19295A	PARTICIPANT	\N	PRESENT	0
485655	484736	19683J	PARTICIPANT	\N	PRESENT	0
485656	484736	19709B	PARTICIPANT	\N	PRESENT	0
485657	484736	11097X	PARTICIPANT	\N	PRESENT	0
485658	484736	19621T	PARTICIPANT	\N	PRESENT	0
485715	479261	19715Y	PARTICIPANT	\N	PRESENT	0
485716	479261	19926J	PARTICIPANT	\N	PRESENT	0
485717	479261	11067R	PARTICIPANT	\N	PRESENT	0
485718	479261	08052W	PARTICIPANT	\N	PRESENT	0
485719	479261	19651A	PARTICIPANT	\N	PRESENT	0
485724	479261	12041X	PARTICIPANT	\N	PRESENT	0
485721	479261	08043V	PARTICIPANT	\N	PRESENT	0
485722	479261	19525U	PARTICIPANT	\N	PRESENT	0
485723	479261	04085P	PARTICIPANT	\N	PRESENT	0
485725	479261	11033F	PARTICIPANT	\N	PRESENT	0
485726	479261	11031D	PARTICIPANT	\N	PRESENT	0
485727	479261	19711U	PARTICIPANT	\N	PRESENT	0
485728	479261	19565D	PARTICIPANT	\N	PRESENT	0
485729	479261	04035D	PARTICIPANT	\N	PRESENT	0
485730	479261	19760E	PARTICIPANT	\N	PRESENT	0
485731	479261	11040E	PARTICIPANT	\N	PRESENT	0
485732	479261	96004D	PARTICIPANT	\N	PRESENT	0
485733	479261	19758L	PARTICIPANT	\N	PRESENT	0
485734	479261	99004R	PARTICIPANT	\N	PRESENT	0
485735	479261	19695N	PARTICIPANT	\N	PRESENT	0
485736	479261	19747H	PARTICIPANT	\N	PRESENT	0
485737	479261	04086Q	PARTICIPANT	\N	PRESENT	0
485738	479261	08061X	PARTICIPANT	\N	PRESENT	0
485739	479261	08039A	PARTICIPANT	\N	PRESENT	0
485740	479261	95037J	PARTICIPANT	\N	PRESENT	0
485741	479261	11080N	PARTICIPANT	\N	PRESENT	0
485742	479261	19349W	PARTICIPANT	\N	PRESENT	0
485743	479261	08024S	PARTICIPANT	\N	PRESENT	0
485744	479261	19766L	PARTICIPANT	\N	PRESENT	0
485745	479261	11048N	PARTICIPANT	\N	PRESENT	0
485746	479261	19629C	PARTICIPANT	\N	PRESENT	0
485747	479261	04049K	PARTICIPANT	\N	PRESENT	0
485748	479261	11012A	PARTICIPANT	\N	PRESENT	0
485749	479261	19794Q	PARTICIPANT	\N	PRESENT	0
485750	479261	88008L	PARTICIPANT	\N	PRESENT	0
485751	479261	14119M	PARTICIPANT	\N	PRESENT	0
485752	479261	19930E	PARTICIPANT	\N	PRESENT	0
485753	479261	14034U	PARTICIPANT	\N	PRESENT	0
485754	479261	04057K	PARTICIPANT	\N	PRESENT	0
485755	479261	14147R	PARTICIPANT	\N	PRESENT	0
485756	479261	14093U	PARTICIPANT	\N	PRESENT	0
485757	479261	11064N	PARTICIPANT	\N	PRESENT	0
485758	479261	19533U	PARTICIPANT	\N	PRESENT	0
485759	479261	11072N	PARTICIPANT	\N	PRESENT	0
485760	479261	19621T	PARTICIPANT	\N	PRESENT	0
485761	479261	19701S	PARTICIPANT	\N	PRESENT	0
485762	479261	19762G	PARTICIPANT	\N	PRESENT	0
485763	479261	11027H	PARTICIPANT	\N	PRESENT	0
485764	479261	14357A	PARTICIPANT	\N	PRESENT	0
485765	479261	01058X	PARTICIPANT	\N	PRESENT	0
485766	479261	01028R	PARTICIPANT	\N	PRESENT	0
485767	479261	11097X	PARTICIPANT	\N	PRESENT	0
485768	479261	14069U	PARTICIPANT	\N	PRESENT	0
485769	479261	19912C	PARTICIPANT	\N	PRESENT	0
485713	479261	12016W	PARTICIPANT	\N	PRESENT	0
485630	484736	14055N	PARTICIPANT	\N	PRESENT	0
485639	484736	14357A	PARTICIPANT	\N	PRESENT	0
485714	479261	19593H	PARTICIPANT	\N	PRESENT	0
485770	479261	19705W	PARTICIPANT	\N	PRESENT	0
485771	479261	08012N	PARTICIPANT	\N	PRESENT	0
485772	479261	01057W	PARTICIPANT	\N	PRESENT	0
485773	479261	19399H	PARTICIPANT	\N	PRESENT	0
485774	479261	19649G	PARTICIPANT	\N	PRESENT	0
485775	479261	14085U	PARTICIPANT	\N	PRESENT	0
485776	479261	18083K	PARTICIPANT	\N	PRESENT	0
485777	479261	19741B	PARTICIPANT	\N	PRESENT	0
485778	479261	19689Q	PARTICIPANT	\N	PRESENT	0
485779	479261	19413M	PARTICIPANT	\N	PRESENT	0
485780	479261	19709B	PARTICIPANT	\N	PRESENT	0
485781	479261	11026G	PARTICIPANT	\N	PRESENT	0
485782	479261	19663E	PARTICIPANT	\N	PRESENT	0
485783	479261	14041T	PARTICIPANT	\N	PRESENT	0
485784	479261	19295A	PARTICIPANT	\N	PRESENT	0
485785	479261	07029T	PARTICIPANT	\N	PRESENT	0
485786	479261	19503N	PARTICIPANT	\N	PRESENT	0
485787	479261	19631V	PARTICIPANT	\N	PRESENT	0
485788	479261	14109K	PARTICIPANT	\N	PRESENT	0
485789	479261	19531S	PARTICIPANT	\N	PRESENT	0
485790	479261	04043D	PARTICIPANT	\N	PRESENT	0
485791	479261	19619A	PARTICIPANT	\N	PRESENT	0
485792	479261	11053K	PARTICIPANT	\N	PRESENT	0
485793	479261	19749K	PARTICIPANT	\N	PRESENT	0
485794	479261	19713W	PARTICIPANT	\N	PRESENT	0
485795	479261	14179A	PARTICIPANT	\N	PRESENT	0
485796	479261	04070G	PARTICIPANT	\N	PRESENT	0
485797	479261	11090Q	PARTICIPANT	\N	PRESENT	0
485798	479261	14327T	PARTICIPANT	\N	PRESENT	0
485799	479261	14021P	PARTICIPANT	\N	PRESENT	0
485800	479261	19954N	PARTICIPANT	\N	PRESENT	0
485801	479261	16685X	PARTICIPANT	\N	PRESENT	0
485802	479261	01024M	PARTICIPANT	\N	PRESENT	0
485803	479261	17637T	PARTICIPANT	\N	PRESENT	0
485804	479261	19683J	PARTICIPANT	\N	PRESENT	0
485805	479261	04042C	PARTICIPANT	\N	PRESENT	0
485806	479261	19591F	PARTICIPANT	\N	PRESENT	0
485807	479261	19543W	PARTICIPANT	\N	PRESENT	0
485808	479261	19647E	PARTICIPANT	\N	PRESENT	0
485809	479261	11045K	PARTICIPANT	\N	PRESENT	0
485810	479261	11099A	PARTICIPANT	\N	PRESENT	0
485811	479261	19347U	PARTICIPANT	\N	PRESENT	0
485812	479261	14255U	PARTICIPANT	\N	PRESENT	0
485813	479261	08073C	PARTICIPANT	\N	PRESENT	0
485814	479261	86034E	PARTICIPANT	\N	PRESENT	0
489848	489847	11074Q	PARTICIPANT	\N	PRESENT	0
489849	489847	88008L	PARTICIPANT	\N	PRESENT	0
491207	490487	14133K	PARTICIPANT	\N	PRESENT	0
491208	490487	14189C	PARTICIPANT	\N	PRESENT	0
491209	490487	20112S	PARTICIPANT	\N	PRESENT	0
491210	490487	96004D	PARTICIPANT	\N	PRESENT	0
491211	490487	14089Y	PARTICIPANT	\N	PRESENT	0
491212	490487	20104S	PARTICIPANT	\N	PRESENT	0
491213	490487	11101A	PARTICIPANT	\N	PRESENT	0
491214	490487	19701S	PARTICIPANT	\N	PRESENT	0
491215	490487	14357A	PARTICIPANT	\N	PRESENT	0
491216	490487	20100N	PARTICIPANT	\N	PRESENT	0
491217	490487	19521Q	PARTICIPANT	\N	PRESENT	0
491218	490487	08018U	PARTICIPANT	\N	PRESENT	0
491219	490487	11083R	PARTICIPANT	\N	PRESENT	0
491220	490487	14033T	PARTICIPANT	\N	PRESENT	0
491221	490487	19553Y	PARTICIPANT	\N	PRESENT	0
491222	490487	19725B	PARTICIPANT	\N	PRESENT	0
491223	490487	19531S	PARTICIPANT	\N	PRESENT	0
491224	490487	14097Y	PARTICIPANT	\N	PRESENT	0
491225	490487	14073Q	PARTICIPANT	\N	PRESENT	0
491226	490487	12041X	PARTICIPANT	\N	PRESENT	0
491227	490487	11026G	PARTICIPANT	\N	PRESENT	0
491228	490487	08034U	PARTICIPANT	\N	PRESENT	0
491229	490487	19441R	PARTICIPANT	\N	PRESENT	0
491230	490487	14001X	PARTICIPANT	\N	PRESENT	0
491231	490487	04057K	PARTICIPANT	\N	PRESENT	0
491232	490487	04070G	PARTICIPANT	\N	PRESENT	0
491233	490487	14169X	PARTICIPANT	\N	PRESENT	0
491234	490487	14237S	PARTICIPANT	\N	PRESENT	0
491235	490487	14331P	PRESIDENT	0	PRESENT	0
491236	490487	10015M	PARTICIPANT	\N	PRESENT	0
491237	490487	20098N	PARTICIPANT	\N	PRESENT	0
491238	490487	19413M	PARTICIPANT	\N	PRESENT	0
491239	490487	11066Q	PARTICIPANT	\N	PRESENT	0
491240	490487	04034C	PARTICIPANT	\N	PRESENT	0
491422	490472	19479G	PARTICIPANT	\N	PRESENT	0
491423	490472	10006L	PRESIDENT	1	PRESENT	0
491424	490472	19683J	PARTICIPANT	\N	PRESENT	0
491425	490472	04092N	PRESIDENT	0	PRESENT	0
491426	490472	19697Q	PARTICIPANT	\N	PRESENT	0
491427	490472	11031D	PARTICIPANT	\N	PRESENT	0
491428	490472	19715Y	PARTICIPANT	\N	PRESENT	0
491429	490472	19503N	PARTICIPANT	\N	PRESENT	0
491430	490472	14041T	PARTICIPANT	\N	PRESENT	0
491431	490472	11067R	PARTICIPANT	\N	PRESENT	0
491432	490472	19663E	PARTICIPANT	\N	PRESENT	0
491433	490472	19649G	PARTICIPANT	\N	EXCUSE	0
491434	490472	14331P	PARTICIPANT	\N	EXCUSE	0
491435	490472	19713W	PARTICIPANT	\N	EXCUSE	0
491436	490472	11097X	PARTICIPANT	\N	PRESENT	0
491437	490472	19766L	PARTICIPANT	\N	EXCUSE	0
488975	488691	11097X	PRESIDENT	0	PRESENT	0
488976	488691	19683J	PARTICIPANT	\N	PRESENT	0
488977	488691	10006L	PARTICIPANT	\N	PRESENT	0
488978	488691	19479G	PARTICIPANT	\N	PRESENT	0
488979	488691	19715Y	PARTICIPANT	\N	PRESENT	0
488980	488691	19649G	PARTICIPANT	\N	PRESENT	0
488981	488691	14041T	PARTICIPANT	\N	PRESENT	0
488982	488691	19703U	PARTICIPANT	\N	PRESENT	0
488983	488691	19447X	PARTICIPANT	\N	PRESENT	0
488984	488691	19697Q	PARTICIPANT	\N	PRESENT	0
488985	488691	19643A	PARTICIPANT	\N	PRESENT	0
488986	488691	19766L	PARTICIPANT	\N	PRESENT	0
488987	488691	01034P	PARTICIPANT	\N	EXCUSE	0
488988	488691	19545Y	PARTICIPANT	\N	EXCUSE	0
488989	488691	11031D	PARTICIPANT	\N	EXCUSE	0
488990	488691	19663E	PARTICIPANT	\N	EXCUSE	0
488992	488691	14081Q	PARTICIPANT	\N	PRESENT	0
488993	488691	11012A	PARTICIPANT	\N	PRESENT	0
488994	488691	19667J	PARTICIPANT	\N	PRESENT	0
488996	488692	19479G	PARTICIPANT	\N	PRESENT	0
488997	488692	01034P	PARTICIPANT	\N	EXCUSE	0
488998	488692	19703U	PARTICIPANT	\N	PRESENT	0
488999	488692	11097X	PRESIDENT	0	PRESENT	0
489000	488692	19766L	PARTICIPANT	\N	PRESENT	0
489001	488692	04092N	PARTICIPANT	\N	EXCUSE	0
489002	488692	10006L	PARTICIPANT	\N	PRESENT	0
489003	488692	19683J	PARTICIPANT	\N	PRESENT	0
489004	488692	11067R	PARTICIPANT	\N	EXCUSE	0
489005	488692	19545Y	PARTICIPANT	\N	EXCUSE	0
489006	488692	19663E	PARTICIPANT	\N	EXCUSE	0
489007	488692	19715Y	PARTICIPANT	\N	PRESENT	0
489008	488692	19447X	PARTICIPANT	\N	PRESENT	0
489028	489027	07004J	PARTICIPANT	\N	PRESENT	0
489029	489027	12016W	PARTICIPANT	\N	PRESENT	0
489041	489040	19415P	PARTICIPANT	\N	PRESENT	0
489047	488616	14093U	PARTICIPANT	\N	PRESENT	0
489049	488616	80013X	PARTICIPANT	\N	EXCUSE	0
489050	488616	19663E	PARTICIPANT	\N	EXCUSE	0
489051	488616	19553Y	PARTICIPANT	\N	EXCUSE	0
489052	488616	19683J	PARTICIPANT	\N	EXCUSE	0
489053	488616	19723Y	PARTICIPANT	\N	EXCUSE	0
489054	488616	19709B	PARTICIPANT	\N	EXCUSE	0
489055	488616	01048V	PRESIDENT	0	PRESENT	0
489056	488616	14221J	PARTICIPANT	\N	EXCUSE	0
489057	488616	19593H	PARTICIPANT	\N	PRESENT	0
489058	488616	04043D	PARTICIPANT	\N	PRESENT	0
489062	488616	19693L	PARTICIPANT	\N	EXCUSE	0
489063	488616	19503N	PARTICIPANT	\N	PRESENT	0
489064	488616	18003S	PARTICIPANT	\N	EXCUSE	0
489067	488616	14299H	PARTICIPANT	\N	EXCUSE	0
489593	489592	19711U	PARTICIPANT	\N	PRESENT	0
489594	489592	11026G	PARTICIPANT	\N	PRESENT	0
489595	489592	14255U	PARTICIPANT	\N	PRESENT	0
489596	489592	19647E	PARTICIPANT	\N	PRESENT	0
489598	489597	19711U	PARTICIPANT	\N	PRESENT	0
489599	489597	11064N	PARTICIPANT	\N	PRESENT	0
489600	489597	95067Q	PARTICIPANT	\N	PRESENT	0
489601	489597	14115H	PARTICIPANT	\N	PRESENT	0
489602	489597	19611R	PARTICIPANT	\N	PRESENT	0
489604	489603	19647E	PARTICIPANT	\N	PRESENT	0
489606	489605	19711U	PARTICIPANT	\N	PRESENT	0
489607	489605	11026G	PARTICIPANT	\N	PRESENT	0
489608	489605	19545Y	PARTICIPANT	\N	PRESENT	0
489609	489605	04040A	PARTICIPANT	\N	PRESENT	0
489983	489750	11048N	PARTICIPANT	\N	PRESENT	0
489984	489750	11053K	PARTICIPANT	\N	PRESENT	0
489985	489750	08034U	PARTICIPANT	\N	PRESENT	0
489986	489750	19479G	PARTICIPANT	\N	PRESENT	0
489993	489751	11074Q	PRESIDENT	0	PRESENT	0
489994	489751	14034U	PARTICIPANT	\N	EXCUSE	0
489995	489751	07029T	PARTICIPANT	\N	PRESENT	0
489996	489751	14085U	PARTICIPANT	\N	PRESENT	0
489997	489751	07004J	PARTICIPANT	\N	PRESENT	0
489998	489751	19671E	PARTICIPANT	\N	PRESENT	0
489999	489751	01057W	PARTICIPANT	\N	PRESENT	0
490000	489751	19647E	PARTICIPANT	\N	PRESENT	0
490001	489751	19711U	PARTICIPANT	\N	PRESENT	0
490002	489751	14121F	PARTICIPANT	\N	PRESENT	0
490003	489751	19762G	PARTICIPANT	\N	PRESENT	0
490004	489751	14225N	PARTICIPANT	\N	PRESENT	0
490009	489751	01048V	PARTICIPANT	\N	PRESENT	0
490010	489751	08011M	PARTICIPANT	\N	EXCUSE	0
490011	489751	12016W	PARTICIPANT	\N	PRESENT	0
490015	489751	14327T	PARTICIPANT	\N	PRESENT	0
490016	489751	19479G	PARTICIPANT	\N	PRESENT	0
490018	489751	14083S	PARTICIPANT	\N	PRESENT	0
490022	489987	14327T	PARTICIPANT	\N	PRESENT	0
490023	489987	14331P	PARTICIPANT	\N	PRESENT	0
490024	489987	04071H	PARTICIPANT	\N	PRESENT	0
490025	489987	01048V	PARTICIPANT	\N	PRESENT	0
490026	489987	11053K	PARTICIPANT	\N	PRESENT	0
495437	495436	14255U	PARTICIPANT	\N	PRESENT	0
490028	489987	11074Q	PRESIDENT	0	PRESENT	0
490029	489987	19671E	PARTICIPANT	\N	PRESENT	0
490030	489987	14225N	PARTICIPANT	\N	PRESENT	0
490031	489987	11070L	PARTICIPANT	\N	PRESENT	0
490032	489987	07029T	PARTICIPANT	\N	PRESENT	0
490033	489987	14085U	PARTICIPANT	\N	PRESENT	0
490034	489987	96004D	PARTICIPANT	\N	PRESENT	0
490035	489987	19349W	PARTICIPANT	\N	PRESENT	0
490036	489987	14253S	PARTICIPANT	\N	PRESENT	0
490037	489987	11048N	PARTICIPANT	\N	PRESENT	0
490038	489987	19479G	PARTICIPANT	\N	PRESENT	0
490039	489987	19711U	PARTICIPANT	\N	PRESENT	0
490040	489987	08034U	PARTICIPANT	\N	PRESENT	0
490041	489987	19687N	PARTICIPANT	\N	PRESENT	0
490042	489987	12016W	PARTICIPANT	\N	PRESENT	0
490043	489987	08011M	PARTICIPANT	\N	PRESENT	0
490044	489987	08014Q	PARTICIPANT	\N	PRESENT	0
490045	489987	14173T	PARTICIPANT	\N	PRESENT	0
490046	489987	04086Q	PARTICIPANT	\N	PRESENT	0
490047	489987	14083S	PARTICIPANT	\N	PRESENT	0
490048	489987	19741B	PARTICIPANT	\N	PRESENT	0
490049	489987	14121F	PARTICIPANT	\N	PRESENT	0
490050	489987	99004R	PARTICIPANT	\N	PRESENT	0
490051	489987	19762G	PARTICIPANT	\N	PRESENT	0
490053	489987	08010L	PARTICIPANT	\N	PRESENT	0
490054	489987	14034U	PARTICIPANT	\N	EXCUSE	0
495218	495010	19735D	PARTICIPANT	\N	EXCUSE	0
497052	495344	20128B	PARTICIPANT	\N	PRESENT	0
497053	495344	20072C	PARTICIPANT	\N	PRESENT	0
497054	495344	19569H	PARTICIPANT	\N	PRESENT	0
497055	495344	19723Y	PARTICIPANT	\N	PRESENT	0
497057	495344	01048V	PARTICIPANT	\N	PRESENT	0
497058	495344	19563B	PARTICIPANT	\N	EXCUSE	0
497059	495344	19593H	PARTICIPANT	\N	EXCUSE	0
497060	495344	19503N	PARTICIPANT	\N	PRESENT	0
497061	495344	04043D	PARTICIPANT	\N	PRESENT	0
497062	495344	01058X	PARTICIPANT	\N	PRESENT	0
497091	495344	18003S	PARTICIPANT	\N	EXCUSE	0
497112	494913	11012A	PARTICIPANT	\N	EXCUSE	0
497315	495125	04059M	PARTICIPANT	\N	PRESENT	0
497316	495125	19515S	PARTICIPANT	\N	PRESENT	0
497317	495125	19651A	PARTICIPANT	\N	PRESENT	0
497318	495125	19667J	PARTICIPANT	\N	PRESENT	0
497319	495125	19954N	PARTICIPANT	\N	PRESENT	0
497320	495125	14030Q	PARTICIPANT	\N	PRESENT	0
497321	495125	19575F	PARTICIPANT	\N	PRESENT	0
497322	495125	20086J	PARTICIPANT	\N	PRESENT	0
497323	495125	14069U	PARTICIPANT	\N	PRESENT	0
497324	495125	20042V	PARTICIPANT	\N	PRESENT	0
497325	495125	14089Y	PARTICIPANT	\N	PRESENT	0
497326	495125	20138D	PARTICIPANT	\N	PRESENT	0
497327	495125	19747H	PARTICIPANT	\N	PRESENT	0
497328	495125	20152B	PARTICIPANT	\N	PRESENT	0
497332	495125	19758L	PARTICIPANT	\N	PRESENT	0
497330	495125	19383Y	PARTICIPANT	\N	PRESENT	0
497331	495125	19621T	PARTICIPANT	\N	PRESENT	0
497333	495125	11101A	PARTICIPANT	\N	PRESENT	0
497334	495125	14083S	PARTICIPANT	\N	PRESENT	0
497335	495125	19629C	PARTICIPANT	\N	PRESENT	0
497336	495125	14038Y	PARTICIPANT	\N	PRESENT	0
497337	495125	19467C	PARTICIPANT	\N	PRESENT	0
497338	495125	19701S	PARTICIPANT	\N	PRESENT	0
494952	494295	19954N	PARTICIPANT	\N	PRESENT	0
494953	494295	19649G	PARTICIPANT	\N	PRESENT	0
494954	494295	14147R	PARTICIPANT	\N	PRESENT	0
494955	494295	19581D	PARTICIPANT	\N	PRESENT	0
494956	494295	04047H	PRESIDENT	0	PRESENT	0
494957	494295	14259Y	PARTICIPANT	\N	PRESENT	0
494958	494295	19673G	PARTICIPANT	\N	PRESENT	0
494959	494295	14053L	PARTICIPANT	\N	PRESENT	0
494960	494295	14041T	PARTICIPANT	\N	PRESENT	0
494961	494295	20110Q	PARTICIPANT	\N	PRESENT	0
494962	494295	14215L	PARTICIPANT	\N	PRESENT	0
494963	494295	05008E	PARTICIPANT	\N	PRESENT	0
494964	494295	14231L	PARTICIPANT	\N	PRESENT	0
494965	494295	19447X	PARTICIPANT	\N	PRESENT	0
494966	494295	14089Y	PARTICIPANT	\N	PRESENT	0
494967	494295	95063L	PARTICIPANT	\N	PRESENT	0
494969	494295	11026G	PARTICIPANT	\N	PRESENT	0
494970	494295	01028R	PARTICIPANT	\N	PRESENT	0
494971	494295	17737W	PARTICIPANT	\N	PRESENT	0
495036	494295	14001X	PARTICIPANT	\N	EXCUSE	0
495037	494295	07004J	PARTICIPANT	\N	EXCUSE	0
495066	494295	04059M	PARTICIPANT	\N	PRESENT	0
495067	494295	19651A	PARTICIPANT	\N	PRESENT	0
495068	494295	14030Q	PARTICIPANT	\N	PRESENT	0
495069	494295	20138D	PARTICIPANT	\N	PRESENT	0
495070	494295	19643A	PARTICIPANT	\N	PRESENT	0
495072	494295	19621T	PARTICIPANT	\N	PRESENT	0
495073	494295	19758L	PARTICIPANT	\N	PRESENT	0
495074	494295	20152B	PARTICIPANT	\N	PRESENT	0
495075	494295	19693L	PARTICIPANT	\N	PRESENT	0
495076	494295	19719D	PARTICIPANT	\N	PRESENT	0
495077	494295	20134Y	PARTICIPANT	\N	PRESENT	0
495078	494295	20124W	PARTICIPANT	\N	PRESENT	0
495079	494295	14123H	PARTICIPANT	\N	PRESENT	0
495080	494295	19399H	PARTICIPANT	\N	PRESENT	0
495081	494295	19611R	PARTICIPANT	\N	PRESENT	0
495082	494295	20052X	PARTICIPANT	\N	PRESENT	0
495083	494295	04070G	PARTICIPANT	\N	PRESENT	0
495085	494295	19593H	PARTICIPANT	\N	PRESENT	0
495086	494295	19573D	PARTICIPANT	\N	PRESENT	0
495087	494295	19533U	PARTICIPANT	\N	PRESENT	0
495088	494295	20026V	PARTICIPANT	\N	PRESENT	0
495089	494295	20058E	PARTICIPANT	\N	PRESENT	0
495096	493364	19747H	PARTICIPANT	\N	PRESENT	0
495097	493364	20022R	PARTICIPANT	\N	PRESENT	0
495098	493364	14033T	PARTICIPANT	\N	PRESENT	0
495099	493364	11085T	PARTICIPANT	\N	PRESENT	0
495100	493364	14021P	PARTICIPANT	\N	PRESENT	0
495101	493364	14257W	PARTICIPANT	\N	PRESENT	0
495102	493364	19335Q	PARTICIPANT	\N	PRESENT	0
495103	493364	04085P	PARTICIPANT	\N	PRESENT	0
495104	493364	14083S	PARTICIPANT	\N	PRESENT	0
495105	493364	19387D	PARTICIPANT	\N	PRESENT	0
495108	493364	16685X	PARTICIPANT	\N	PRESENT	0
495109	493364	19762G	PARTICIPANT	\N	PRESENT	0
495110	493364	19685L	PARTICIPANT	\N	PRESENT	0
495113	493364	11110B	PARTICIPANT	\N	PRESENT	0
495114	493364	20080C	PARTICIPANT	\N	PRESENT	0
495115	493364	19573D	PARTICIPANT	\N	PRESENT	0
495116	493364	08009T	PARTICIPANT	\N	PRESENT	0
495124	493364	14225N	PARTICIPANT	\N	PRESENT	0
495127	493364	19531S	PARTICIPANT	\N	PRESENT	0
495129	493364	14327T	PARTICIPANT	\N	PRESENT	0
495183	493368	14327T	PARTICIPANT	\N	PRESENT	0
495184	493368	19333N	PARTICIPANT	\N	PRESENT	0
495185	493368	19413M	PARTICIPANT	\N	PRESENT	0
495186	493368	20080C	PARTICIPANT	\N	PRESENT	0
495187	493368	20022R	PARTICIPANT	\N	PRESENT	0
495188	493368	11110B	PARTICIPANT	\N	PRESENT	0
495189	493368	14033T	PARTICIPANT	\N	PRESENT	0
495190	493368	19685L	PARTICIPANT	\N	PRESENT	0
495191	493368	19687N	PARTICIPANT	\N	PRESENT	0
495192	493368	08010L	PARTICIPANT	\N	PRESENT	0
495193	493368	20116W	PARTICIPANT	\N	PRESENT	0
495194	493368	04070G	PARTICIPANT	\N	PRESENT	0
495195	493368	11012A	PARTICIPANT	\N	PRESENT	0
495196	493368	20036X	PARTICIPANT	\N	PRESENT	0
495197	493368	14030Q	PARTICIPANT	\N	PRESENT	0
495198	493368	14225N	PARTICIPANT	\N	PRESENT	0
495199	493368	14038Y	PARTICIPANT	\N	PRESENT	0
495200	493368	19467C	PARTICIPANT	\N	PRESENT	0
495201	493368	19383Y	PARTICIPANT	\N	PRESENT	0
495202	493368	19573D	PARTICIPANT	\N	PRESENT	0
495203	493368	07029T	PARTICIPANT	\N	PRESENT	0
495204	493368	11064N	PARTICIPANT	\N	PRESENT	0
495205	493368	19515S	PARTICIPANT	\N	PRESENT	0
495206	493368	19479G	PARTICIPANT	\N	PRESENT	0
495212	493368	19758L	PARTICIPANT	\N	PRESENT	0
495208	493368	14083S	PARTICIPANT	\N	PRESENT	0
495209	493368	20032T	PARTICIPANT	\N	PRESENT	0
495210	493368	19335Q	PARTICIPANT	\N	PRESENT	0
495211	493368	19551W	PARTICIPANT	\N	PRESENT	0
495214	493368	20092G	PARTICIPANT	\N	PRESENT	0
495215	493368	11048N	PARTICIPANT	\N	PRESENT	0
495225	493368	19762G	PARTICIPANT	\N	PRESENT	0
495226	493368	19531S	PARTICIPANT	\N	PRESENT	0
495227	493368	19713W	PARTICIPANT	\N	PRESENT	0
495228	493368	19782L	PARTICIPANT	\N	PRESENT	0
495229	491379	08012N	PARTICIPANT	\N	EXCUSE	0
495230	493368	11056N	PARTICIPANT	\N	PRESENT	0
495231	493368	20098N	PARTICIPANT	\N	PRESENT	0
495232	493368	19629C	PARTICIPANT	\N	PRESENT	0
495233	493368	19447X	PARTICIPANT	\N	PRESENT	0
495234	493368	14213J	PARTICIPANT	\N	PRESENT	0
495235	493368	19507S	PARTICIPANT	\N	PRESENT	0
495236	493368	20130U	PARTICIPANT	\N	PRESENT	0
495237	493368	19621T	PARTICIPANT	\N	PRESENT	0
495238	493368	20058E	PARTICIPANT	\N	PRESENT	0
495239	493368	14069U	PARTICIPANT	\N	PRESENT	0
495241	495240	11027H	PARTICIPANT	\N	PRESENT	0
495242	495240	14193X	PARTICIPANT	\N	PRESENT	0
495243	493368	19647E	PARTICIPANT	\N	PRESENT	0
495181	493368	08073C	PARTICIPANT	\N	PRESENT	0
495182	493368	08009T	PARTICIPANT	\N	PRESENT	0
495252	493368	11085T	PARTICIPANT	\N	PRESENT	0
495253	493368	19711U	PARTICIPANT	\N	PRESENT	0
495329	495328	11053K	PARTICIPANT	\N	PRESENT	0
495331	495330	11053K	PARTICIPANT	\N	PRESENT	0
495333	495332	11053K	PARTICIPANT	\N	PRESENT	0
495335	495334	20126Y	PARTICIPANT	\N	PRESENT	0
495337	495336	20126Y	PARTICIPANT	\N	PRESENT	0
495339	495338	20126Y	PARTICIPANT	\N	PRESENT	0
495341	495340	96004D	PARTICIPANT	\N	PRESENT	0
495343	495342	96004D	PARTICIPANT	\N	PRESENT	0
496902	495112	14189C	PARTICIPANT	\N	PRESENT	0
496903	495112	14089Y	PARTICIPANT	\N	PRESENT	0
496904	495112	14207L	PARTICIPANT	\N	PRESENT	0
496905	495112	20104S	PRESIDENT	0	PRESENT	0
496906	495112	11101A	PARTICIPANT	\N	PRESENT	0
496907	495112	14357A	PARTICIPANT	\N	PRESENT	0
496908	495112	19251M	PARTICIPANT	\N	PRESENT	0
496909	495112	20100N	PARTICIPANT	\N	PRESENT	0
494831	493327	19479G	PARTICIPANT	\N	PRESENT	0
494832	493327	04092N	PRESIDENT	0	PRESENT	0
494833	493327	11097X	PARTICIPANT	\N	PRESENT	0
494834	493327	19715Y	PARTICIPANT	\N	PRESENT	0
494835	493327	99004R	PARTICIPANT	\N	PRESENT	0
494836	493327	19691J	PARTICIPANT	\N	PRESENT	0
494837	493327	10006L	PARTICIPANT	\N	PRESENT	0
496910	495112	19521Q	PARTICIPANT	\N	PRESENT	0
496911	495112	04035D	PARTICIPANT	\N	PRESENT	0
496912	495112	11083R	PARTICIPANT	\N	PRESENT	0
496913	495112	14033T	PARTICIPANT	\N	PRESENT	0
496914	495112	14026U	PARTICIPANT	\N	PRESENT	0
496915	495112	19553Y	PARTICIPANT	\N	PRESENT	0
496916	495112	19725B	PARTICIPANT	\N	PRESENT	0
496917	495112	20128B	PARTICIPANT	\N	PRESENT	0
496918	495112	19531S	PARTICIPANT	\N	PRESENT	0
496919	495112	14097Y	PARTICIPANT	\N	PRESENT	0
496920	495112	14073Q	PARTICIPANT	\N	PRESENT	0
496921	495112	11026G	PARTICIPANT	\N	PRESENT	0
496922	495112	08034U	PARTICIPANT	\N	PRESENT	0
496923	495112	12016W	PARTICIPANT	\N	PRESENT	0
496924	495112	14001X	PARTICIPANT	\N	PRESENT	0
496925	495112	04070G	PARTICIPANT	\N	PRESENT	0
496926	495112	14169X	PARTICIPANT	\N	PRESENT	0
497008	497007	14267Y	PARTICIPANT	\N	PRESENT	0
497009	497007	19565D	PARTICIPANT	\N	PRESENT	0
497089	495128	14041T	PARTICIPANT	\N	PRESENT	0
497090	495128	14033T	PARTICIPANT	\N	PRESENT	0
497096	494913	19643A	PARTICIPANT	\N	PRESENT	0
497097	494913	19697Q	PARTICIPANT	\N	PRESENT	0
497098	494913	19479G	PARTICIPANT	\N	PRESENT	0
497099	494913	11067R	PARTICIPANT	\N	PRESENT	0
497100	494913	04092N	PARTICIPANT	\N	PRESENT	0
497101	494913	19713W	PARTICIPANT	\N	PRESENT	0
497102	494913	19715Y	PARTICIPANT	\N	PRESENT	0
497103	494913	19703U	PARTICIPANT	\N	PRESENT	0
497104	494913	11031D	PARTICIPANT	\N	PRESENT	0
488710	488469	08049C	PARTICIPANT	\N	PRESENT	0
489010	488692	19553Y	PARTICIPANT	\N	PRESENT	0
489011	488692	19503N	PARTICIPANT	\N	PRESENT	0
488711	488469	19335Q	PRESIDENT	0	PRESENT	0
489009	488692	19643A	PARTICIPANT	\N	PRESENT	0
489012	488692	19649G	PARTICIPANT	\N	PRESENT	0
489013	488692	04059M	PARTICIPANT	\N	PRESENT	0
489014	488692	19697Q	PARTICIPANT	\N	PRESENT	0
489556	489340	19643A	PARTICIPANT	\N	PRESENT	0
489557	489340	19663E	PARTICIPANT	\N	EXCUSE	0
489558	489340	19691J	PARTICIPANT	\N	PRESENT	0
489559	489340	19569H	PARTICIPANT	\N	PRESENT	0
489560	489340	19683J	PARTICIPANT	\N	PRESENT	0
489561	489340	11067R	PARTICIPANT	\N	PRESENT	0
489562	489340	04092N	PARTICIPANT	\N	PRESENT	0
489563	489340	19503N	PARTICIPANT	\N	PRESENT	0
489564	489340	14331P	PARTICIPANT	\N	PRESENT	0
489565	489340	11097X	PRESIDENT	0	PRESENT	0
489566	489340	19703U	PARTICIPANT	\N	PRESENT	0
489567	489340	19479G	PARTICIPANT	\N	PRESENT	0
489568	489340	11031D	PARTICIPANT	\N	PRESENT	0
489569	489340	19715Y	PARTICIPANT	\N	PRESENT	0
491440	491439	19551W	PARTICIPANT	\N	PRESENT	0
492482	491476	04092N	PRESIDENT	0	PRESENT	0
492696	491509	19760E	PARTICIPANT	\N	EXCUSE	0
492697	491510	19760E	PARTICIPANT	\N	EXCUSE	0
493175	493174	20096L	PARTICIPANT	\N	PRESENT	0
493176	493174	20118Y	PARTICIPANT	\N	PRESENT	0
493177	493174	20106U	PARTICIPANT	\N	PRESENT	0
493178	493174	19637C	PARTICIPANT	\N	PRESENT	0
493179	493174	19619A	PARTICIPANT	\N	PRESENT	0
493180	493174	19820Y	PARTICIPANT	\N	PRESENT	0
493181	493174	19701S	PARTICIPANT	\N	PRESENT	0
493182	493174	05012A	PARTICIPANT	\N	PRESENT	0
493183	493174	19503N	PARTICIPANT	\N	PRESENT	0
493185	493184	19701S	PARTICIPANT	\N	PRESENT	0
493189	493184	20096L	PARTICIPANT	\N	PRESENT	0
493187	493184	19820Y	PARTICIPANT	\N	PRESENT	0
493188	493184	20106U	PARTICIPANT	\N	PRESENT	0
493190	493184	20118Y	PARTICIPANT	\N	PRESENT	0
493191	493184	19619A	PARTICIPANT	\N	PRESENT	0
495365	495364	04071H	PARTICIPANT	\N	PRESENT	0
495367	495366	04071H	PARTICIPANT	\N	PRESENT	0
495369	495368	11048N	PARTICIPANT	\N	PRESENT	0
495371	495370	20116W	PARTICIPANT	\N	PRESENT	0
495373	495372	20116W	PARTICIPANT	\N	PRESENT	0
495375	495374	01048V	PARTICIPANT	\N	PRESENT	0
495377	495376	20116W	PARTICIPANT	\N	PRESENT	0
495379	495378	11070L	PARTICIPANT	\N	PRESENT	0
495380	495378	19647E	PARTICIPANT	\N	PRESENT	0
500187	500186	11027H	PARTICIPANT	\N	PRESENT	0
500188	500186	14193X	PARTICIPANT	\N	PRESENT	0
500566	498084	01048V	PARTICIPANT	\N	PRESENT	0
500592	500591	11053K	PARTICIPANT	\N	PRESENT	0
500594	500593	19711U	PARTICIPANT	\N	PRESENT	0
500663	500407	19367Y	PARTICIPANT	\N	EXCUSE	0
500664	500407	19295A	PARTICIPANT	\N	EXCUSE	0
500665	500407	14223L	PARTICIPANT	\N	PRESENT	0
500666	500407	14281W	PARTICIPANT	\N	PRESENT	0
500681	500679	19667J	PARTICIPANT	\N	PRESENT	0
500682	500679	11040E	PARTICIPANT	\N	PRESENT	0
500710	500708	19667J	PARTICIPANT	\N	PRESENT	0
500711	500708	11040E	PARTICIPANT	\N	PRESENT	0
500720	500719	20080C	PARTICIPANT	\N	PRESENT	0
500731	500729	04086Q	PARTICIPANT	\N	PRESENT	0
500734	500733	04086Q	PARTICIPANT	\N	PRESENT	0
500737	500736	11074Q	PARTICIPANT	\N	PRESENT	0
500738	500736	19349W	PARTICIPANT	\N	PRESENT	0
500740	500739	11074Q	PARTICIPANT	\N	PRESENT	0
500746	500745	99004R	PARTICIPANT	\N	PRESENT	0
500843	500838	14187A	PARTICIPANT	\N	PRESENT	0
500844	500840	14187A	PARTICIPANT	\N	PRESENT	0
503198	503197	19725B	PARTICIPANT	\N	PRESENT	0
503199	503197	08018U	PARTICIPANT	\N	PRESENT	0
503200	503196	08018U	PARTICIPANT	\N	PRESENT	0
503201	503196	19725B	PARTICIPANT	\N	PRESENT	0
503202	503195	19725B	PARTICIPANT	\N	PRESENT	0
503203	503195	08018U	PARTICIPANT	\N	PRESENT	0
503212	503206	14205J	PARTICIPANT	\N	PRESENT	0
503213	503206	14038Y	PARTICIPANT	\N	PRESENT	0
503262	503230	14329V	PARTICIPANT	\N	PRESENT	0
503263	503231	14329V	PARTICIPANT	\N	PRESENT	0
503717	503712	19651A	PARTICIPANT	\N	PRESENT	0
505914	505913	20050V	PARTICIPANT	\N	PRESENT	0
505915	505913	14331P	PARTICIPANT	\N	PRESENT	0
506002	506001	08034U	PARTICIPANT	\N	PRESENT	0
507681	502319	14001X	PARTICIPANT	\N	PRESENT	0
507682	502319	04086Q	PARTICIPANT	\N	PRESENT	0
507683	502319	19621T	PARTICIPANT	\N	PRESENT	0
507684	502319	08034U	PARTICIPANT	\N	PRESENT	0
507685	502319	14331P	PARTICIPANT	\N	PRESENT	0
507686	502319	14187A	PARTICIPANT	\N	PRESENT	0
507687	502319	19533U	PARTICIPANT	\N	PRESENT	0
507688	502319	14071N	PARTICIPANT	\N	PRESENT	0
507689	502319	14217N	PARTICIPANT	\N	PRESENT	0
507690	502319	14053L	PARTICIPANT	\N	PRESENT	0
507691	502319	20120S	PARTICIPANT	\N	PRESENT	0
507692	502319	20054A	PARTICIPANT	\N	PRESENT	0
507693	502319	20124W	PARTICIPANT	\N	PRESENT	0
507694	502319	20090E	PARTICIPANT	\N	PRESENT	0
507695	502319	14147R	PARTICIPANT	\N	PRESENT	0
507696	502319	11097X	PARTICIPANT	\N	PRESENT	0
507697	502319	19679N	PARTICIPANT	\N	PRESENT	0
507698	502319	20070A	PARTICIPANT	\N	PRESENT	0
507699	502319	20022R	PARTICIPANT	\N	PRESENT	0
507700	502319	04070G	PARTICIPANT	\N	PRESENT	0
507701	502319	14357A	PARTICIPANT	\N	PRESENT	0
507702	502319	01057W	PARTICIPANT	\N	PRESENT	0
507703	502319	08009T	PARTICIPANT	\N	PRESENT	0
507704	502319	14073Q	PARTICIPANT	\N	PRESENT	0
507705	502319	19671E	PARTICIPANT	\N	PRESENT	0
507706	502319	19966S	PARTICIPANT	\N	PRESENT	0
507707	502319	14083S	PARTICIPANT	\N	PRESENT	0
507708	502319	14097Y	PARTICIPANT	\N	PRESENT	0
507709	502319	08011M	PARTICIPANT	\N	PRESENT	0
507710	502319	08010L	PARTICIPANT	\N	PRESENT	0
507711	502319	05012A	PARTICIPANT	\N	PRESENT	0
507712	502319	14213J	PARTICIPANT	\N	PRESENT	0
507713	502319	14026U	PARTICIPANT	\N	PRESENT	0
507714	502319	11074Q	PARTICIPANT	\N	PRESENT	0
507715	502319	20086J	PARTICIPANT	\N	PRESENT	0
507716	502319	08015R	PARTICIPANT	\N	PRESENT	0
507717	502319	11043H	PARTICIPANT	\N	PRESENT	0
507718	502319	01043Q	PARTICIPANT	\N	PRESENT	0
507719	502319	04033B	PARTICIPANT	\N	PRESENT	0
507720	502319	19762G	PARTICIPANT	\N	PRESENT	0
507721	502319	95063L	PARTICIPANT	\N	PRESENT	0
507722	502319	19349W	PARTICIPANT	\N	PRESENT	0
507679	502319	19711U	PARTICIPANT	\N	PRESENT	0
507680	502319	20126Y	PARTICIPANT	\N	PRESENT	0
507723	502319	19573D	PARTICIPANT	\N	PRESENT	0
507724	502319	20030R	PARTICIPANT	\N	PRESENT	0
507725	502319	14205J	PARTICIPANT	\N	PRESENT	0
507726	502319	19667J	PARTICIPANT	\N	PRESENT	0
507727	502319	19507S	PARTICIPANT	\N	PRESENT	0
507728	502319	17367Q	PARTICIPANT	\N	PRESENT	0
507729	502319	19643A	PARTICIPANT	\N	PRESENT	0
507730	502319	19347U	PARTICIPANT	\N	PRESENT	0
507731	502319	14069U	PARTICIPANT	\N	PRESENT	0
507732	502319	20106U	PARTICIPANT	\N	PRESENT	0
507733	502319	19383Y	PARTICIPANT	\N	PRESENT	0
507734	502319	14179A	PARTICIPANT	\N	PRESENT	0
507735	502319	19335Q	PARTICIPANT	\N	PRESENT	0
507736	502319	20118Y	PARTICIPANT	\N	PRESENT	0
507737	502319	19549D	PARTICIPANT	\N	PRESENT	0
507738	502319	11065P	PARTICIPANT	\N	PRESENT	0
507747	505798	14053L	PARTICIPANT	\N	PRESENT	0
507748	505798	14111D	PARTICIPANT	\N	PRESENT	0
507749	505798	20074E	PARTICIPANT	\N	PRESENT	0
507750	505798	04047H	PRESIDENT	0	PRESENT	0
507751	505798	19673G	PARTICIPANT	\N	PRESENT	0
507752	505798	05008E	PARTICIPANT	\N	PRESENT	0
507753	505798	19447X	PARTICIPANT	\N	PRESENT	0
507754	505798	14231L	PARTICIPANT	\N	PRESENT	0
507755	505798	14089Y	PARTICIPANT	\N	PRESENT	0
507756	505798	19954N	PARTICIPANT	\N	PRESENT	0
507757	505798	19729F	PARTICIPANT	\N	PRESENT	0
507758	505798	07004J	PARTICIPANT	\N	PRESENT	0
507759	505798	14147R	PARTICIPANT	\N	PRESENT	0
507760	505798	14151M	PARTICIPANT	\N	PRESENT	0
507761	505798	19749K	PARTICIPANT	\N	PRESENT	0
491438	490472	04059M	PARTICIPANT	\N	PRESENT	0
491704	491700	20024T	PARTICIPANT	\N	PRESENT	0
491706	491700	19637C	PARTICIPANT	\N	PRESENT	0
491707	491700	20096L	PARTICIPANT	\N	PRESENT	0
491708	491700	20106U	PARTICIPANT	\N	PRESENT	0
491711	491709	20024T	PARTICIPANT	\N	PRESENT	0
491712	491709	19637C	PARTICIPANT	\N	PRESENT	0
491713	491709	20096L	PARTICIPANT	\N	PRESENT	0
491714	491709	20106U	PARTICIPANT	\N	PRESENT	0
491715	491709	20118Y	PARTICIPANT	\N	PRESENT	0
491716	491709	19503N	PARTICIPANT	\N	PRESENT	0
491719	491718	20024T	PARTICIPANT	\N	PRESENT	0
491721	491718	19637C	PARTICIPANT	\N	PRESENT	0
491722	491718	20118Y	PARTICIPANT	\N	PRESENT	0
491723	491718	19503N	PARTICIPANT	\N	PRESENT	0
492449	492447	11048N	PARTICIPANT	\N	PRESENT	0
492450	492448	19711U	PARTICIPANT	\N	PRESENT	0
492507	491468	20042V	PARTICIPANT	\N	PRESENT	0
492508	491468	16685X	PARTICIPANT	\N	PRESENT	0
492633	491261	19549D	PARTICIPANT	\N	PRESENT	0
492636	491261	11101A	PARTICIPANT	\N	PRESENT	0
492647	491261	20102Q	PARTICIPANT	\N	PRESENT	0
493924	492923	19575F	PARTICIPANT	\N	PRESENT	0
493953	493949	19735D	PARTICIPANT	\N	EXCUSE	0
493925	492923	19369B	PARTICIPANT	\N	PRESENT	0
493926	492923	20018V	PARTICIPANT	\N	PRESENT	0
493927	492923	19563B	PARTICIPANT	\N	PRESENT	0
493928	492923	08028W	PARTICIPANT	\N	PRESENT	0
493929	492923	20024T	PARTICIPANT	\N	PRESENT	0
493930	492923	19521Q	PARTICIPANT	\N	PRESENT	0
493931	492923	20028X	PARTICIPANT	\N	PRESENT	0
493932	492923	20030R	PARTICIPANT	\N	PRESENT	0
493933	492923	19467C	PARTICIPANT	\N	PRESENT	0
493934	492923	14187A	PARTICIPANT	\N	PRESENT	0
493935	492923	20144B	PARTICIPANT	\N	PRESENT	0
493936	492923	19695N	PARTICIPANT	\N	PRESENT	0
493937	492923	11090Q	PRESIDENT	0	PRESENT	0
493938	492923	14033T	PARTICIPANT	\N	PRESENT	0
493939	492923	01025N	PARTICIPANT	\N	PRESENT	0
493940	492923	20054A	PARTICIPANT	\N	PRESENT	0
493941	492923	14205J	PARTICIPANT	\N	PRESENT	0
493942	492923	20060X	PARTICIPANT	\N	PRESENT	0
493943	492923	20062A	PARTICIPANT	\N	PRESENT	0
493944	492923	19507S	PARTICIPANT	\N	PRESENT	0
493945	492923	14207L	PARTICIPANT	\N	PRESENT	0
493946	492923	19747H	PARTICIPANT	\N	PRESENT	0
493947	492923	14257W	PARTICIPANT	\N	PRESENT	0
493948	492923	11077T	PARTICIPANT	\N	EXCUSE	0
493950	492698	17779H	PARTICIPANT	\N	PRESENT	0
493951	492698	19679N	PARTICIPANT	\N	PRESENT	0
493952	492698	20066E	PARTICIPANT	\N	PRESENT	0
493954	492903	19697Q	PARTICIPANT	\N	PRESENT	0
493955	492903	17583W	PARTICIPANT	\N	PRESENT	0
493956	492903	11067R	PARTICIPANT	\N	PRESENT	0
493957	492903	20090E	PARTICIPANT	\N	PRESENT	0
493958	492903	19798U	PARTICIPANT	\N	PRESENT	0
493959	492903	19569H	PARTICIPANT	\N	PRESENT	0
493960	492903	11097X	PARTICIPANT	\N	PRESENT	0
493961	492903	14223L	PARTICIPANT	\N	PRESENT	0
493962	492903	14026U	PARTICIPANT	\N	PRESENT	0
493963	492903	17779H	PARTICIPANT	\N	PRESENT	0
493964	492903	19703U	PARTICIPANT	\N	PRESENT	0
493965	492903	19553Y	PARTICIPANT	\N	PRESENT	0
493966	492903	11031D	PARTICIPANT	\N	PRESENT	0
493967	492903	14281W	PARTICIPANT	\N	PRESENT	0
493968	492903	19679N	PARTICIPANT	\N	PRESENT	0
493969	492903	14042U	PARTICIPANT	\N	PRESENT	0
493970	492903	14213J	PARTICIPANT	\N	PRESENT	0
493971	492903	14217N	PARTICIPANT	\N	PRESENT	0
493972	492903	19683J	PARTICIPANT	\N	PRESENT	0
493973	492903	10006L	PRESIDENT	0	PRESENT	0
493974	492903	20126Y	PARTICIPANT	\N	PRESENT	0
493975	492903	20130U	PARTICIPANT	\N	PRESENT	0
493976	492903	04092N	PARTICIPANT	\N	PRESENT	0
493977	492903	19713W	PARTICIPANT	\N	PRESENT	0
493978	492903	08045X	PARTICIPANT	\N	PRESENT	0
493979	492903	19301E	PARTICIPANT	\N	PRESENT	0
493980	492903	19715Y	PARTICIPANT	\N	PRESENT	0
493981	492903	19691J	PARTICIPANT	\N	PRESENT	0
493982	492903	20066E	PARTICIPANT	\N	PRESENT	0
493983	492903	11103C	PARTICIPANT	\N	PRESENT	0
493984	492903	14071N	PARTICIPANT	\N	PRESENT	0
493985	492903	04043D	PARTICIPANT	\N	PRESENT	0
493986	493227	11053K	PARTICIPANT	\N	PRESENT	0
493987	493227	08010L	PARTICIPANT	\N	PRESENT	0
493993	493392	19387D	PARTICIPANT	\N	PRESENT	0
493994	493392	19820Y	PARTICIPANT	\N	PRESENT	0
493995	493392	20102Q	PARTICIPANT	\N	PRESENT	0
493996	493392	20118Y	PARTICIPANT	\N	PRESENT	0
493997	493392	20020P	PARTICIPANT	\N	PRESENT	0
493998	493392	20022R	PARTICIPANT	\N	PRESENT	0
493999	493392	19681G	PARTICIPANT	\N	PRESENT	0
494000	493392	20024T	PARTICIPANT	\N	PRESENT	0
494001	493392	11065P	PARTICIPANT	\N	PRESENT	0
494521	493361	10006L	PARTICIPANT	\N	PRESENT	0
494003	493392	20136B	PARTICIPANT	\N	PRESENT	0
494004	493392	20140W	PARTICIPANT	\N	PRESENT	0
494005	493392	19251M	PARTICIPANT	\N	PRESENT	0
494007	493392	17229F	PARTICIPANT	\N	PRESENT	0
494008	493392	19577H	PARTICIPANT	\N	PRESENT	0
494009	493392	19619A	PARTICIPANT	\N	PRESENT	0
494010	493392	19503N	PARTICIPANT	\N	EXCUSE	0
494014	493392	19637C	PARTICIPANT	\N	PRESENT	0
494015	493392	20122U	PARTICIPANT	\N	PRESENT	0
494017	493272	14059S	PARTICIPANT	\N	PRESENT	0
494018	493272	04035D	PARTICIPANT	\N	PRESENT	0
494019	493272	19443T	PARTICIPANT	\N	PRESENT	0
494020	493272	19565D	PARTICIPANT	\N	PRESENT	0
494021	493272	14133K	PARTICIPANT	\N	PRESENT	0
494022	493272	20042V	PARTICIPANT	\N	PRESENT	0
494023	493272	01058X	PARTICIPANT	\N	PRESENT	0
494024	493272	11027H	PARTICIPANT	\N	PRESENT	0
494025	493272	04042C	PRESIDENT	0	PRESENT	0
494026	493272	01024M	PARTICIPANT	\N	PRESENT	0
494027	493272	11066Q	PARTICIPANT	\N	PRESENT	0
494028	493272	14105F	PARTICIPANT	\N	PRESENT	0
494029	493272	20064C	PARTICIPANT	\N	PRESENT	0
494030	493272	19421M	PARTICIPANT	\N	PRESENT	0
494031	493272	19709B	PARTICIPANT	\N	PRESENT	0
494032	493272	14267Y	PARTICIPANT	\N	PRESENT	0
494033	493272	14193X	PARTICIPANT	\N	PRESENT	0
494034	493272	11083R	PARTICIPANT	\N	PRESENT	0
494035	493272	14211G	PARTICIPANT	\N	PRESENT	0
494036	493272	08047A	PARTICIPANT	\N	PRESENT	0
494038	493272	14097Y	PARTICIPANT	\N	PRESENT	0
494039	493272	17023S	PARTICIPANT	\N	PRESENT	0
494040	493227	08012N	PARTICIPANT	\N	PRESENT	0
494042	493272	14255U	PARTICIPANT	\N	PRESENT	0
494044	493272	08069G	PARTICIPANT	\N	PRESENT	0
494045	493272	19347U	PARTICIPANT	\N	PRESENT	0
494046	492923	19515S	PARTICIPANT	\N	PRESENT	0
494047	493272	95041E	PARTICIPANT	\N	PRESENT	0
494060	492923	14329V	PARTICIPANT	\N	PRESENT	0
494061	493367	19543W	PARTICIPANT	\N	PRESENT	0
494062	493367	19581D	PARTICIPANT	\N	PRESENT	0
494063	493367	04047H	PRESIDENT	0	PRESENT	0
494064	493367	01028R	PARTICIPANT	\N	PRESENT	0
494065	493367	05008E	PARTICIPANT	\N	PRESENT	0
494066	493367	19447X	PARTICIPANT	\N	PRESENT	0
494067	493367	14231L	PARTICIPANT	\N	PRESENT	0
494068	493367	19954N	PARTICIPANT	\N	PRESENT	0
494069	493367	19489J	PARTICIPANT	\N	PRESENT	0
494070	493367	14041T	PARTICIPANT	\N	PRESENT	0
494071	493367	20110Q	PARTICIPANT	\N	PRESENT	0
494072	493367	14147R	PARTICIPANT	\N	PRESENT	0
494073	493367	20114U	PARTICIPANT	\N	PRESENT	0
494074	493367	14215L	PARTICIPANT	\N	PRESENT	0
494075	493367	14053L	PARTICIPANT	\N	PRESENT	0
494076	493367	19649G	PARTICIPANT	\N	PRESENT	0
494077	493367	14111D	PARTICIPANT	\N	PRESENT	0
494078	493367	11026G	PARTICIPANT	\N	PRESENT	0
494079	493367	19725B	PARTICIPANT	\N	PRESENT	0
494080	493367	14089Y	PARTICIPANT	\N	PRESENT	0
494081	493367	11056N	PARTICIPANT	\N	PRESENT	0
494082	493367	19729F	PARTICIPANT	\N	PRESENT	0
494083	493367	95063L	PARTICIPANT	\N	PRESENT	0
494084	493367	19629C	PARTICIPANT	\N	PRESENT	0
494085	493367	04008A	PARTICIPANT	\N	PRESENT	0
494086	493367	19749K	PARTICIPANT	\N	PRESENT	0
494087	493367	14021P	PARTICIPANT	\N	PRESENT	0
494088	492923	04045F	PARTICIPANT	\N	PRESENT	0
494091	493227	19667J	PARTICIPANT	\N	PRESENT	0
494092	493227	96004D	PARTICIPANT	\N	PRESENT	0
494093	493227	20116W	PARTICIPANT	\N	PRESENT	0
494094	493227	20126Y	PARTICIPANT	\N	PRESENT	0
494095	493227	14189C	PARTICIPANT	\N	PRESENT	0
494096	493227	19689Q	PARTICIPANT	\N	PRESENT	0
494097	493227	08073C	PARTICIPANT	\N	PRESENT	0
494520	493361	20130U	PARTICIPANT	\N	PRESENT	0
487888	479251	19715Y	PARTICIPANT	\N	PRESENT	0
487889	479251	11067R	PARTICIPANT	\N	PRESENT	0
487890	479251	19563B	PARTICIPANT	\N	PRESENT	0
487891	479251	17589D	PARTICIPANT	\N	PRESENT	0
487892	479251	19301E	PARTICIPANT	\N	PRESENT	0
487893	479251	19697Q	PARTICIPANT	\N	PRESENT	0
487894	479251	11097X	PARTICIPANT	\N	PRESENT	0
487895	479251	11103C	PARTICIPANT	\N	PRESENT	0
487896	479251	07029T	PARTICIPANT	\N	PRESENT	0
487897	479251	08052W	PARTICIPANT	\N	PRESENT	0
487898	479251	14261S	PARTICIPANT	\N	PRESENT	0
487899	479251	19467C	PARTICIPANT	\N	PRESENT	0
487900	479251	19447X	PARTICIPANT	\N	PRESENT	0
487901	479251	10006L	PARTICIPANT	\N	PRESENT	0
487902	479251	19760E	PARTICIPANT	\N	PRESENT	0
487903	479251	19711U	PARTICIPANT	\N	PRESENT	0
487904	479251	19741B	PARTICIPANT	\N	PRESENT	0
487905	479251	14034U	PARTICIPANT	\N	PRESENT	0
487906	479251	19543W	PARTICIPANT	\N	PRESENT	0
487907	479251	11012A	PARTICIPANT	\N	PRESENT	0
487908	479251	14069U	PARTICIPANT	\N	PRESENT	0
489448	489038	04085P	PARTICIPANT	\N	PRESENT	0
489449	489038	19643A	PARTICIPANT	\N	PRESENT	0
489450	489038	19663E	PARTICIPANT	\N	EXCUSE	0
489451	489038	10006L	PARTICIPANT	\N	PRESENT	0
489452	489038	14041T	PARTICIPANT	\N	PRESENT	0
489453	489038	19649G	PARTICIPANT	\N	PRESENT	0
489454	489038	19569H	PARTICIPANT	\N	PRESENT	0
489455	489038	19715Y	PARTICIPANT	\N	PRESENT	0
489456	489038	19683J	PARTICIPANT	\N	PRESENT	0
489457	489038	99004R	PARTICIPANT	\N	PRESENT	0
489458	489038	19697Q	PARTICIPANT	\N	PRESENT	0
489459	489038	19503N	PARTICIPANT	\N	PRESENT	0
489460	489038	19766L	PARTICIPANT	\N	EXCUSE	0
489461	489038	11012A	PARTICIPANT	\N	PRESENT	0
489462	489038	04092N	PARTICIPANT	\N	EXCUSE	0
489463	489038	11097X	PARTICIPANT	\N	PRESENT	0
489464	489038	19703U	PARTICIPANT	\N	PRESENT	0
489465	489038	19479G	PARTICIPANT	\N	PRESENT	0
489466	489038	11067R	PARTICIPANT	\N	EXCUSE	0
489910	489909	14331P	PARTICIPANT	\N	PRESENT	0
489911	489909	96004D	PARTICIPANT	\N	PRESENT	0
489913	489912	14331P	PARTICIPANT	\N	PRESENT	0
489915	489914	14331P	PARTICIPANT	\N	PRESENT	0
491594	491141	20030R	PARTICIPANT	\N	PRESENT	0
495501	495266	19649G	PARTICIPANT	\N	PRESENT	0
495502	495266	10015M	PARTICIPANT	\N	PRESENT	0
495503	495266	04047H	PRESIDENT	0	PRESENT	0
495504	495266	19675J	PARTICIPANT	\N	PRESENT	0
495505	495266	14231L	PARTICIPANT	\N	PRESENT	0
495506	495266	19447X	PARTICIPANT	\N	PRESENT	0
495507	495266	19489J	PARTICIPANT	\N	PRESENT	0
495508	495266	14041T	PARTICIPANT	\N	PRESENT	0
495509	495266	14147R	PARTICIPANT	\N	PRESENT	0
495510	495266	20114U	PARTICIPANT	\N	PRESENT	0
495511	495266	14215L	PARTICIPANT	\N	PRESENT	0
495512	495266	08018U	PARTICIPANT	\N	PRESENT	0
495513	495266	19749K	PARTICIPANT	\N	PRESENT	0
495514	495266	14001X	PARTICIPANT	\N	PRESENT	0
495515	495266	04085P	PARTICIPANT	\N	PRESENT	0
495516	495266	14151M	PARTICIPANT	\N	PRESENT	0
495517	495266	19581D	PARTICIPANT	\N	EXCUSE	0
495518	495266	11033F	PARTICIPANT	\N	EXCUSE	0
495519	495035	11048N	PARTICIPANT	\N	PRESENT	0
495520	495035	04071H	PARTICIPANT	\N	PRESENT	0
495521	495035	08034U	PARTICIPANT	\N	PRESENT	0
495522	495035	19687N	PARTICIPANT	\N	PRESENT	0
495523	495035	20080C	PARTICIPANT	\N	PRESENT	0
495524	495035	20050V	PARTICIPANT	\N	PRESENT	0
495525	495035	20044X	PARTICIPANT	\N	PRESENT	0
495526	495035	14225N	PRESIDENT	0	PRESENT	0
495527	495035	04086Q	PARTICIPANT	\N	PRESENT	0
495528	495035	11040E	PARTICIPANT	\N	PRESENT	0
495529	495035	07029T	PARTICIPANT	\N	PRESENT	0
495530	495035	19335Q	PARTICIPANT	\N	PRESENT	0
495531	495035	20126Y	PARTICIPANT	\N	PRESENT	0
495532	495035	19762G	PARTICIPANT	\N	PRESENT	0
495533	495035	20116W	PARTICIPANT	\N	EXCUSE	0
495534	495118	19699S	PARTICIPANT	\N	PRESENT	0
495535	495118	20024T	PARTICIPANT	\N	PRESENT	0
495536	495118	20086J	PARTICIPANT	\N	PRESENT	0
495537	495118	19711U	PARTICIPANT	\N	PRESENT	0
495538	495118	19367Y	PARTICIPANT	\N	PRESENT	0
495539	495118	14219Q	PARTICIPANT	\N	PRESENT	0
495540	495118	97011G	PARTICIPANT	\N	PRESENT	0
495541	495118	18083K	PARTICIPANT	\N	PRESENT	0
495542	495118	19349W	PARTICIPANT	\N	PRESENT	0
495543	495118	19369B	PARTICIPANT	\N	PRESENT	0
495544	495118	19826F	PARTICIPANT	\N	PRESENT	0
495545	495118	14189C	PARTICIPANT	\N	PRESENT	0
495547	495266	11026G	PARTICIPANT	\N	PRESENT	0
495550	495266	19543W	PARTICIPANT	\N	PRESENT	0
495552	495266	05008E	PARTICIPANT	\N	PRESENT	0
495553	495266	14089Y	PARTICIPANT	\N	PRESENT	0
495554	495266	95063L	PARTICIPANT	\N	PRESENT	0
495555	495118	14329V	PARTICIPANT	\N	PRESENT	0
495556	495118	20106U	PARTICIPANT	\N	PRESENT	0
495557	495118	19585H	PARTICIPANT	\N	PRESENT	0
495558	495118	20032T	PARTICIPANT	\N	PRESENT	0
495559	495118	20064C	PARTICIPANT	\N	PRESENT	0
495560	495035	14331P	PARTICIPANT	\N	PRESENT	0
495561	495035	14121F	PARTICIPANT	\N	PRESENT	0
495562	495035	19741B	PARTICIPANT	\N	PRESENT	0
495563	495118	19549D	PARTICIPANT	\N	PRESENT	0
495564	495118	20018V	PARTICIPANT	\N	PRESENT	0
495565	495118	19441R	PARTICIPANT	\N	PRESENT	0
495566	495118	20140W	PARTICIPANT	\N	PRESENT	0
495567	495035	01048V	PARTICIPANT	\N	PRESENT	0
495568	495118	01058X	PARTICIPANT	\N	PRESENT	0
495569	495118	14107H	PARTICIPANT	\N	PRESENT	0
495570	495118	20054A	PARTICIPANT	\N	PRESENT	0
495571	495118	19533U	PARTICIPANT	\N	PRESENT	0
495572	495035	11053K	PARTICIPANT	\N	PRESENT	0
495573	495035	14173T	PARTICIPANT	\N	PRESENT	0
495574	495118	20020P	PARTICIPANT	\N	PRESENT	0
495575	495118	19553Y	PARTICIPANT	\N	PRESENT	0
495576	495118	19421M	PARTICIPANT	\N	PRESENT	0
495577	495118	20040T	PARTICIPANT	\N	PRESENT	0
495578	495118	19747H	PARTICIPANT	\N	PRESENT	0
495580	495266	17737W	PARTICIPANT	\N	PRESENT	0
495581	495118	08069G	PARTICIPANT	\N	PRESENT	0
495582	495118	20098N	PARTICIPANT	\N	PRESENT	0
495583	495035	14189C	PARTICIPANT	\N	PRESENT	0
495584	495035	99004R	PARTICIPANT	\N	PRESENT	0
495585	495118	14267Y	PARTICIPANT	\N	PRESENT	0
495586	495118	14031R	PARTICIPANT	\N	PRESENT	0
495587	495118	20038A	PARTICIPANT	\N	PRESENT	0
496010	495119	20066E	PARTICIPANT	\N	PRESENT	0
496011	495119	14219Q	PARTICIPANT	\N	PRESENT	0
496012	495119	14189C	PARTICIPANT	\N	PRESENT	0
496013	495119	19695N	PARTICIPANT	\N	PRESENT	0
496014	495119	19565D	PARTICIPANT	\N	PRESENT	0
496015	495119	20018V	PARTICIPANT	\N	PRESENT	0
496016	495119	20030R	PARTICIPANT	\N	PRESENT	0
496017	495119	19599P	PARTICIPANT	\N	PRESENT	0
496018	495119	19503N	PARTICIPANT	\N	PRESENT	0
496019	495119	20094J	PARTICIPANT	\N	PRESENT	0
496020	495119	19413M	PARTICIPANT	\N	PRESENT	0
496035	495119	11097X	PARTICIPANT	\N	PRESENT	0
496022	495119	14257W	PARTICIPANT	\N	PRESENT	0
496023	495119	11099A	PARTICIPANT	\N	PRESENT	0
496024	495119	20092G	PARTICIPANT	\N	PRESENT	0
496025	495119	20100N	PARTICIPANT	\N	PRESENT	0
496026	495119	20110Q	PARTICIPANT	\N	PRESENT	0
496027	495119	20134Y	PARTICIPANT	\N	PRESENT	0
496028	495119	19347U	PARTICIPANT	\N	PRESENT	0
496029	495119	20142Y	PARTICIPANT	\N	PRESENT	0
496030	495119	20076G	PARTICIPANT	\N	PRESENT	0
496031	495119	01058X	PARTICIPANT	\N	PRESENT	0
496032	495119	19549D	PARTICIPANT	\N	PRESENT	0
496033	495119	19747H	PARTICIPANT	\N	PRESENT	0
496008	495119	99004R	PARTICIPANT	\N	PRESENT	0
496009	495119	11090Q	PARTICIPANT	\N	PRESENT	0
496034	495119	19349W	PARTICIPANT	\N	PRESENT	0
496036	495119	19637C	PARTICIPANT	\N	PRESENT	0
496037	495119	20128B	PARTICIPANT	\N	PRESENT	0
496038	495119	14215L	PARTICIPANT	\N	PRESENT	0
496039	495119	19387D	PARTICIPANT	\N	PRESENT	0
496040	495119	14207L	PARTICIPANT	\N	PRESENT	0
496041	495119	19563B	PARTICIPANT	\N	PRESENT	0
496042	495119	14071N	PARTICIPANT	\N	PRESENT	0
496043	495119	20022R	PARTICIPANT	\N	PRESENT	0
496044	495119	20136B	PARTICIPANT	\N	PRESENT	0
496045	495119	14327T	PARTICIPANT	\N	PRESENT	0
496046	495119	14031R	PARTICIPANT	\N	PRESENT	0
496047	495119	19441R	PARTICIPANT	\N	PRESENT	0
496048	495119	14033T	PARTICIPANT	\N	PRESENT	0
496049	495119	01024M	PARTICIPANT	\N	PRESENT	0
496050	495119	07029T	PARTICIPANT	\N	PRESENT	0
497105	494913	19573D	PARTICIPANT	\N	PRESENT	0
497106	494913	19503N	PARTICIPANT	\N	PRESENT	0
497107	494913	19349W	PARTICIPANT	\N	PRESENT	0
497108	494913	19683J	PARTICIPANT	\N	PRESENT	0
497109	494913	10006L	PARTICIPANT	\N	PRESENT	0
497110	494913	19766L	PARTICIPANT	\N	EXCUSE	0
497111	494913	95041E	PARTICIPANT	\N	EXCUSE	0
497164	496188	20052X	PARTICIPANT	\N	PRESENT	0
497165	496188	19649G	PARTICIPANT	\N	PRESENT	0
497166	496188	20020P	PARTICIPANT	\N	PRESENT	0
497167	496188	19333N	PARTICIPANT	\N	PRESENT	0
497168	496188	19675J	PARTICIPANT	\N	PRESENT	0
497169	496188	12016W	PARTICIPANT	\N	PRESENT	0
497170	496188	17779H	PARTICIPANT	\N	PRESENT	0
497171	496188	14151M	PARTICIPANT	\N	PRESENT	0
497175	496188	04085P	PARTICIPANT	\N	PRESENT	0
497176	496188	11056N	PARTICIPANT	\N	PRESENT	0
497177	496188	11031D	PARTICIPANT	\N	PRESENT	0
497178	496188	12041X	PARTICIPANT	\N	PRESENT	0
497180	496188	19643A	PARTICIPANT	\N	PRESENT	0
497181	496188	19758L	PARTICIPANT	\N	PRESENT	0
497182	496188	19693L	PARTICIPANT	\N	PRESENT	0
497183	496188	19687N	PARTICIPANT	\N	PRESENT	0
497184	496188	08010L	PARTICIPANT	\N	PRESENT	0
497185	496188	20082E	PARTICIPANT	\N	PRESENT	0
497186	496188	01058X	PARTICIPANT	\N	PRESENT	0
497187	496188	20018V	PARTICIPANT	\N	PRESENT	0
497188	496188	19503N	PARTICIPANT	\N	PRESENT	0
497189	496188	17637T	PARTICIPANT	\N	PRESENT	0
497190	496188	20084G	PARTICIPANT	\N	PRESENT	0
497191	496188	19820Y	PARTICIPANT	\N	PRESENT	0
497192	496188	04035D	PARTICIPANT	\N	PRESENT	0
497193	496188	14109K	PARTICIPANT	\N	PRESENT	0
497194	496188	14257W	PARTICIPANT	\N	PRESENT	0
497195	496188	04047H	PARTICIPANT	\N	PRESENT	0
497196	496188	01028R	PARTICIPANT	\N	PRESENT	0
497198	496188	14026U	PARTICIPANT	\N	PRESENT	0
497199	496188	14225N	PARTICIPANT	\N	PRESENT	0
497200	496188	19515S	PARTICIPANT	\N	PRESENT	0
497201	496188	14281W	PARTICIPANT	\N	PRESENT	0
497202	496188	19673G	PARTICIPANT	\N	PRESENT	0
497203	496188	19647E	PARTICIPANT	\N	PRESENT	0
497204	496188	11080N	PARTICIPANT	\N	PRESENT	0
497205	496188	20134Y	PARTICIPANT	\N	PRESENT	0
497206	496188	01057W	PARTICIPANT	\N	PRESENT	0
497207	496188	19689Q	PARTICIPANT	\N	PRESENT	0
497208	496188	20022R	PARTICIPANT	\N	PRESENT	0
497209	496188	19347U	PARTICIPANT	\N	PRESENT	0
497210	496188	04071H	PARTICIPANT	\N	PRESENT	0
497211	496188	20092G	PARTICIPANT	\N	PRESENT	0
497212	496188	20130U	PARTICIPANT	\N	PRESENT	0
497213	496188	14001X	PARTICIPANT	\N	PRESENT	0
497214	496188	14169X	PARTICIPANT	\N	PRESENT	0
497215	496188	20038A	PARTICIPANT	\N	PRESENT	0
497216	496188	19525U	PARTICIPANT	\N	PRESENT	0
497217	496188	19329S	PARTICIPANT	\N	PRESENT	0
497162	496188	86034E	PARTICIPANT	\N	PRESENT	0
497163	496188	99004R	PARTICIPANT	\N	PRESENT	0
497219	496188	19651A	PARTICIPANT	\N	PRESENT	0
497220	496188	20142Y	PARTICIPANT	\N	PRESENT	0
497221	496188	19447X	PARTICIPANT	\N	PRESENT	0
497222	496188	20106U	PARTICIPANT	\N	PRESENT	0
497223	496188	14038Y	PARTICIPANT	\N	PRESENT	0
497225	496188	19629C	PARTICIPANT	\N	PRESENT	0
497226	496188	20086J	PARTICIPANT	\N	PRESENT	0
497227	496188	19866P	PARTICIPANT	\N	PRESENT	0
497228	496188	11083R	PARTICIPANT	\N	PRESENT	0
497229	496188	19467C	PARTICIPANT	\N	PRESENT	0
497230	496188	20128B	PARTICIPANT	\N	PRESENT	0
497231	496188	08061X	PARTICIPANT	\N	PRESENT	0
497232	496188	14231L	PARTICIPANT	\N	PRESENT	0
497233	496188	14179A	PARTICIPANT	\N	PRESENT	0
497234	496188	20044X	PARTICIPANT	\N	PRESENT	0
497236	496188	19611R	PARTICIPANT	\N	PRESENT	0
497237	496188	11053K	PARTICIPANT	\N	PRESENT	0
497238	496188	19573D	PARTICIPANT	\N	PRESENT	0
497239	496188	19691J	PARTICIPANT	\N	PRESENT	0
497240	496188	20066E	PARTICIPANT	\N	PRESENT	0
497241	496188	20026V	PARTICIPANT	\N	PRESENT	0
497242	496188	14219Q	PARTICIPANT	\N	PRESENT	0
497243	496188	19369B	PARTICIPANT	\N	PRESENT	0
497244	496188	19543W	PARTICIPANT	\N	PRESENT	0
497245	496188	20068G	PARTICIPANT	\N	PRESENT	0
497246	496188	19683J	PARTICIPANT	\N	PRESENT	0
497247	496188	14089Y	PARTICIPANT	\N	PRESENT	0
497248	496188	11085T	PARTICIPANT	\N	PRESENT	0
497249	496188	17737W	PARTICIPANT	\N	PRESENT	0
497250	496188	19749K	PARTICIPANT	\N	PRESENT	0
497251	496188	08018U	PARTICIPANT	\N	PRESENT	0
497252	496188	14189C	PARTICIPANT	\N	PRESENT	0
497253	496188	07029T	PARTICIPANT	\N	PRESENT	0
497254	496188	14215L	PARTICIPANT	\N	PRESENT	0
497256	496188	19663E	PARTICIPANT	\N	PRESENT	0
497257	496188	05008E	PARTICIPANT	\N	PRESENT	0
497258	496188	19747H	PARTICIPANT	\N	PRESENT	0
497259	496188	14030Q	PARTICIPANT	\N	PRESENT	0
497260	496188	14041T	PARTICIPANT	\N	PRESENT	0
497261	496188	14055N	PARTICIPANT	\N	PRESENT	0
497262	496188	20098N	PARTICIPANT	\N	PRESENT	0
497263	496188	19621T	PARTICIPANT	\N	PRESENT	0
497264	496188	19421M	PARTICIPANT	\N	PRESENT	0
497265	496188	17023S	PARTICIPANT	\N	PRESENT	0
497266	496188	19413M	PARTICIPANT	\N	PRESENT	0
497267	496188	19954N	PARTICIPANT	\N	PRESENT	0
497268	496188	20080C	PARTICIPANT	\N	PRESENT	0
497269	496188	19697Q	PARTICIPANT	\N	PRESENT	0
497270	496188	01048V	PARTICIPANT	\N	PRESENT	0
497271	496188	04033B	PARTICIPANT	\N	PRESENT	0
497272	496188	14021P	PARTICIPANT	\N	PRESENT	0
497273	496188	14071N	PARTICIPANT	\N	PRESENT	0
497274	496188	20126Y	PARTICIPANT	\N	PRESENT	0
497275	496188	20152B	PARTICIPANT	\N	PRESENT	0
497276	496188	11101A	PARTICIPANT	\N	PRESENT	0
497277	496188	20124W	PARTICIPANT	\N	PRESENT	0
497278	496188	20090E	PARTICIPANT	\N	PRESENT	0
497279	496188	14357A	PARTICIPANT	\N	PRESENT	0
497280	496188	14147R	PARTICIPANT	\N	PRESENT	0
497281	496188	19762G	PARTICIPANT	\N	PRESENT	0
497282	496188	11048N	PARTICIPANT	\N	PRESENT	0
497283	496188	20118Y	PARTICIPANT	\N	PRESENT	0
497284	496188	19701S	PARTICIPANT	\N	PRESENT	0
497285	496188	11090Q	PARTICIPANT	\N	PRESENT	0
497286	496188	14331P	PARTICIPANT	\N	PRESENT	0
497287	496188	04086Q	PARTICIPANT	\N	PRESENT	0
497288	496188	20058E	PARTICIPANT	\N	PRESENT	0
497289	496188	19703U	PARTICIPANT	\N	PRESENT	0
497290	496188	19399H	PARTICIPANT	\N	PRESENT	0
497291	496188	04042C	PARTICIPANT	\N	PRESENT	0
497292	496188	14033T	PARTICIPANT	\N	PRESENT	0
497293	496188	19695N	PARTICIPANT	\N	PRESENT	0
497294	496188	04092N	PARTICIPANT	\N	PRESENT	0
497295	496188	08012N	PARTICIPANT	\N	PRESENT	0
497296	496188	19715Y	PARTICIPANT	\N	PRESENT	0
497297	496188	19599P	PARTICIPANT	\N	PRESENT	0
497298	496188	08017T	PARTICIPANT	\N	PRESENT	0
497299	496188	19741B	PARTICIPANT	\N	PRESENT	0
497300	496188	18083K	PARTICIPANT	\N	PRESENT	0
497301	496188	19489J	PARTICIPANT	\N	PRESENT	0
497302	496188	20110Q	PARTICIPANT	\N	PRESENT	0
497303	496188	19713W	PARTICIPANT	\N	PRESENT	0
497304	496188	07033P	PARTICIPANT	\N	PRESENT	0
497305	496188	19669L	PARTICIPANT	\N	PRESENT	0
497306	496188	14251Q	PARTICIPANT	\N	PRESENT	0
497307	496188	11070L	PARTICIPANT	\N	PRESENT	0
497308	496188	14069U	PARTICIPANT	\N	PRESENT	0
497309	496188	19533U	PARTICIPANT	\N	PRESENT	0
497310	496188	08069G	PARTICIPANT	\N	PRESENT	0
497313	496188	19531S	PARTICIPANT	\N	PRESENT	0
497314	496188	19671E	PARTICIPANT	\N	PRESENT	0
497367	489992	14189C	PARTICIPANT	\N	PRESENT	0
497369	489992	14030Q	PRESIDENT	0	PRESENT	0
497372	489992	20080C	PARTICIPANT	\N	PRESENT	0
497374	489992	11031D	PARTICIPANT	\N	PRESENT	0
497377	489992	20140W	PARTICIPANT	\N	PRESENT	0
497379	489992	19599P	PARTICIPANT	\N	PRESENT	0
497382	489992	20106U	PARTICIPANT	\N	PRESENT	0
497385	489992	14179A	PARTICIPANT	\N	PRESENT	0
497387	489992	20066E	PARTICIPANT	\N	PRESENT	0
497390	489992	19715Y	PARTICIPANT	\N	PRESENT	0
497392	489992	08017T	PARTICIPANT	\N	PRESENT	0
497394	489992	14109K	PARTICIPANT	\N	PRESENT	0
497396	489992	19866P	PARTICIPANT	\N	PRESENT	0
497399	489992	20130U	PARTICIPANT	\N	PRESENT	0
497401	489992	19798U	PARTICIPANT	\N	PRESENT	0
497404	489992	11045K	PARTICIPANT	\N	PRESENT	0
497406	489992	19527W	PARTICIPANT	\N	PRESENT	0
497408	489992	19749K	PARTICIPANT	\N	PRESENT	0
497422	489992	20024T	PARTICIPANT	\N	EXCUSE	0
497423	489992	20138D	PARTICIPANT	\N	EXCUSE	0
483390	483389	08018U	PARTICIPANT	\N	PRESENT	0
483391	483389	11026G	PARTICIPANT	\N	PRESENT	0
483392	483389	04038G	PARTICIPANT	\N	PRESENT	0
483395	483393	19503N	PARTICIPANT	\N	PRESENT	0
483398	483396	19503N	PARTICIPANT	\N	PRESENT	0
484159	483245	19760E	PARTICIPANT	\N	PRESENT	0
484160	483245	19575F	PARTICIPANT	\N	PRESENT	0
484161	483245	19367Y	PARTICIPANT	\N	PRESENT	0
484162	483245	19415P	PARTICIPANT	\N	PRESENT	0
484163	483245	11103C	PARTICIPANT	\N	PRESENT	0
484164	483245	19577H	PARTICIPANT	\N	PRESENT	0
484166	483245	14087W	PARTICIPANT	\N	PRESENT	0
484167	483245	19553Y	PARTICIPANT	\N	PRESENT	0
484168	483245	19521Q	PARTICIPANT	\N	PRESENT	0
484169	483245	19715Y	PARTICIPANT	\N	PRESENT	0
484170	483245	14227Q	PARTICIPANT	\N	PRESENT	0
484171	483245	19723Y	PARTICIPANT	\N	PRESENT	0
484172	483245	17779H	PARTICIPANT	\N	PRESENT	0
484173	483245	19657G	PARTICIPANT	\N	PRESENT	0
484174	483245	14223L	PARTICIPANT	\N	PRESENT	0
484175	483245	14119M	PARTICIPANT	\N	PRESENT	0
484176	483245	19798U	PARTICIPANT	\N	PRESENT	0
484177	483245	19301E	PARTICIPANT	\N	PRESENT	0
484191	482216	14030Q	PRESIDENT	0	PRESENT	0
484192	482216	08043V	PARTICIPANT	\N	PRESENT	0
484193	482216	19643A	PARTICIPANT	\N	PRESENT	0
484194	482216	08020N	PARTICIPANT	\N	PRESENT	0
484195	482216	18083K	PARTICIPANT	\N	PRESENT	0
484196	482216	19701S	PARTICIPANT	\N	PRESENT	0
484197	482216	11031D	PARTICIPANT	\N	PRESENT	0
484198	482216	19693L	PARTICIPANT	\N	EXCUSE	0
484199	482216	19577H	PARTICIPANT	\N	PRESENT	0
484200	482216	14249W	PARTICIPANT	\N	EXCUSE	0
484201	482216	14179A	PARTICIPANT	\N	PRESENT	0
484202	482216	19715Y	PARTICIPANT	\N	PRESENT	0
484203	482216	19731Y	PARTICIPANT	\N	PRESENT	0
484204	482216	07029T	PARTICIPANT	\N	EXCUSE	0
484205	482216	08017T	PARTICIPANT	\N	PRESENT	0
484206	482216	11067R	PARTICIPANT	\N	PRESENT	0
484207	482216	14235Q	PARTICIPANT	\N	EXCUSE	0
484208	482216	19269X	PARTICIPANT	\N	PRESENT	0
484209	482216	11045K	PARTICIPANT	\N	PRESENT	0
484210	482216	19749K	PARTICIPANT	\N	PRESENT	0
484260	482216	01043Q	PARTICIPANT	\N	EXCUSE	0
484262	482216	19367Y	PARTICIPANT	\N	EXCUSE	0
484390	483191	14093U	PARTICIPANT	\N	EXCUSE	0
484391	483191	01058X	PARTICIPANT	\N	PRESENT	0
484393	483191	19503N	PARTICIPANT	\N	PRESENT	0
484394	483191	01048V	PRESIDENT	0	PRESENT	0
484395	483191	19533U	PARTICIPANT	\N	PRESENT	0
486800	484898	11067R	PARTICIPANT	\N	PRESENT	0
486801	484898	01034P	PARTICIPANT	\N	PRESENT	0
486802	484898	19565D	PARTICIPANT	\N	PRESENT	0
486803	484898	04092N	PARTICIPANT	\N	PRESENT	0
486804	484898	11097X	PARTICIPANT	\N	PRESENT	0
486805	484898	08052W	PARTICIPANT	\N	PRESENT	0
486806	484898	19301E	PARTICIPANT	\N	PRESENT	0
486807	484898	19415P	PARTICIPANT	\N	PRESENT	0
486808	484898	19715Y	PARTICIPANT	\N	PRESENT	0
486809	484898	11031D	PARTICIPANT	\N	PRESENT	0
486810	484898	14042U	PARTICIPANT	\N	PRESENT	0
486811	484898	19575F	PARTICIPANT	\N	PRESENT	0
486812	484898	19367Y	PARTICIPANT	\N	PRESENT	0
486813	484898	19657G	PARTICIPANT	\N	PRESENT	0
486814	484898	14217N	PARTICIPANT	\N	PRESENT	0
486815	484898	19577H	PARTICIPANT	\N	PRESENT	0
486816	484898	19760E	PARTICIPANT	\N	PRESENT	0
486817	484898	98024R	PARTICIPANT	\N	PRESENT	0
486818	484898	14355X	PARTICIPANT	\N	EXCUSE	0
486819	484898	14071N	PARTICIPANT	\N	EXCUSE	0
486820	484898	08041T	PARTICIPANT	\N	EXCUSE	0
486821	484898	19591F	PARTICIPANT	\N	EXCUSE	0
486823	484737	04070G	PARTICIPANT	\N	PRESENT	0
486824	484737	14053L	PARTICIPANT	\N	PRESENT	0
486825	484737	14169X	PARTICIPANT	\N	PRESENT	0
486834	484737	11027H	PARTICIPANT	\N	PRESENT	0
486835	484898	10006L	PARTICIPANT	\N	PRESENT	0
486849	484737	19573D	PARTICIPANT	\N	PRESENT	0
486850	484737	19335Q	PARTICIPANT	\N	PRESENT	0
486851	484737	19301E	PARTICIPANT	\N	PRESENT	0
486852	484737	19760E	PARTICIPANT	\N	PRESENT	0
486853	484737	19699S	PARTICIPANT	\N	PRESENT	0
486854	484737	11072N	PARTICIPANT	\N	PRESENT	0
486855	484737	19575F	PARTICIPANT	\N	PRESENT	0
486856	484737	12041X	PARTICIPANT	\N	PRESENT	0
486857	484737	19441R	PARTICIPANT	\N	PRESENT	0
486858	484737	19713W	PARTICIPANT	\N	PRESENT	0
486859	484737	19637C	PARTICIPANT	\N	PRESENT	0
486860	484737	19387D	PARTICIPANT	\N	PRESENT	0
486864	485543	19729F	PARTICIPANT	\N	EXCUSE	0
486865	485543	19930E	PARTICIPANT	\N	PRESENT	0
486866	485543	19673G	PARTICIPANT	\N	PRESENT	0
486867	485543	19581D	PARTICIPANT	\N	EXCUSE	0
486881	479207	19515S	PARTICIPANT	\N	PRESENT	0
486882	479207	19930E	PARTICIPANT	\N	PRESENT	0
486883	479207	11033F	PARTICIPANT	\N	PRESENT	0
486884	479207	19749K	PARTICIPANT	\N	PRESENT	0
486885	479207	14179A	PARTICIPANT	\N	PRESENT	0
486873	479207	04044E	PARTICIPANT	\N	PRESENT	0
486874	485543	11026G	PARTICIPANT	\N	PRESENT	0
486875	485543	14147R	PARTICIPANT	\N	PRESENT	0
486876	485543	14179A	PARTICIPANT	\N	PRESENT	0
486877	485543	01024M	PARTICIPANT	\N	PRESENT	0
486878	485543	19585H	PARTICIPANT	\N	PRESENT	0
486879	485543	05008E	PRESIDENT	0	PRESENT	0
486886	479207	19737F	PARTICIPANT	\N	PRESENT	0
486887	479207	05008E	PARTICIPANT	\N	PRESENT	0
486888	479207	11072N	PARTICIPANT	\N	PRESENT	0
486889	479207	18083K	PARTICIPANT	\N	PRESENT	0
486890	479207	14093U	PARTICIPANT	\N	PRESENT	0
486891	479207	19565D	PARTICIPANT	\N	PRESENT	0
486892	479207	01024M	PARTICIPANT	\N	PRESENT	0
486893	479207	14147R	PARTICIPANT	\N	PRESENT	0
486894	479207	04088S	PARTICIPANT	\N	PRESENT	0
486895	479207	01028R	PARTICIPANT	\N	PRESENT	0
486896	479207	19794Q	PARTICIPANT	\N	PRESENT	0
486897	479207	14065Q	PARTICIPANT	\N	PRESENT	0
486898	479207	19926J	PARTICIPANT	\N	PRESENT	0
486899	479207	11103C	PARTICIPANT	\N	PRESENT	0
486900	479207	14261S	PARTICIPANT	\N	PRESENT	0
486901	479207	19441R	PARTICIPANT	\N	PRESENT	0
486902	479207	19954N	PARTICIPANT	\N	PRESENT	0
486903	479207	19577H	PARTICIPANT	\N	PRESENT	0
486904	479207	97011G	PARTICIPANT	\N	PRESENT	0
486905	479207	14069U	PARTICIPANT	\N	PRESENT	0
486922	479207	17589D	PARTICIPANT	\N	PRESENT	0
486923	479207	88008L	PARTICIPANT	\N	PRESENT	0
486926	479207	19657G	PARTICIPANT	\N	PRESENT	0
486930	479207	14207L	PARTICIPANT	\N	PRESENT	0
486931	479207	19349W	PARTICIPANT	\N	PRESENT	0
486936	479207	19649G	PARTICIPANT	\N	PRESENT	0
486933	479207	19467C	PARTICIPANT	\N	PRESENT	0
486934	479207	19585H	PARTICIPANT	\N	PRESENT	0
486938	479207	19507S	PARTICIPANT	\N	PRESENT	0
486940	479207	19912C	PARTICIPANT	\N	PRESENT	0
486941	479207	19367Y	PARTICIPANT	\N	PRESENT	0
486978	479211	04044E	PARTICIPANT	\N	PRESENT	0
486979	479211	05008E	PARTICIPANT	\N	PRESENT	0
486980	479211	19912C	PARTICIPANT	\N	PRESENT	0
486982	479211	14147R	PARTICIPANT	\N	PRESENT	0
486983	479211	01028R	PARTICIPANT	\N	PRESENT	0
486984	479211	19649G	PARTICIPANT	\N	PRESENT	0
486985	479211	14065Q	PARTICIPANT	\N	PRESENT	0
486986	479211	14093U	PARTICIPANT	\N	PRESENT	0
486987	479211	11045K	PARTICIPANT	\N	PRESENT	0
486988	479211	19926J	PARTICIPANT	\N	PRESENT	0
486989	479211	11026G	PARTICIPANT	\N	PRESENT	0
486990	479211	11072N	PARTICIPANT	\N	PRESENT	0
486991	479211	01024M	PARTICIPANT	\N	PRESENT	0
486992	479211	19737F	PARTICIPANT	\N	PRESENT	0
486993	479211	19577H	PARTICIPANT	\N	PRESENT	0
486994	479211	19749K	PARTICIPANT	\N	PRESENT	0
486995	479211	19565D	PARTICIPANT	\N	PRESENT	0
486996	479211	11033F	PARTICIPANT	\N	PRESENT	0
486997	479211	19739H	PARTICIPANT	\N	PRESENT	0
486998	479211	17589D	PARTICIPANT	\N	PRESENT	0
486999	479211	19826F	PARTICIPANT	\N	PRESENT	0
487000	479211	97011G	PARTICIPANT	\N	PRESENT	0
487001	479211	11103C	PARTICIPANT	\N	PRESENT	0
487002	479211	14069U	PARTICIPANT	\N	PRESENT	0
487004	479211	14217N	PARTICIPANT	\N	PRESENT	0
487005	479211	19533U	PARTICIPANT	\N	PRESENT	0
487006	479211	19930E	PARTICIPANT	\N	PRESENT	0
487007	479211	19657G	PARTICIPANT	\N	PRESENT	0
487008	479211	04088S	PARTICIPANT	\N	PRESENT	0
487009	479211	18083K	PARTICIPANT	\N	PRESENT	0
494522	493273	14133K	PARTICIPANT	\N	PRESENT	0
494523	493361	11097X	PARTICIPANT	\N	PRESENT	0
494524	493361	19713W	PARTICIPANT	\N	PRESENT	0
494525	493361	14237S	PARTICIPANT	\N	PRESENT	0
494526	493361	19745F	PARTICIPANT	\N	PRESENT	0
494527	493361	14173T	PARTICIPANT	\N	PRESENT	0
494528	493361	19301E	PARTICIPANT	\N	PRESENT	0
494529	493361	19553Y	PARTICIPANT	\N	PRESENT	0
494530	493361	19691J	PARTICIPANT	\N	PRESENT	0
494534	493361	20090E	PARTICIPANT	\N	PRESENT	0
494542	493361	19679N	PARTICIPANT	\N	PRESENT	0
494543	493361	20032T	PARTICIPANT	\N	PRESENT	0
494544	493273	01024M	PARTICIPANT	\N	PRESENT	0
494545	493361	14281W	PARTICIPANT	\N	PRESENT	0
494546	493361	17779H	PARTICIPANT	\N	PRESENT	0
494547	493361	19479G	PARTICIPANT	\N	PRESENT	0
494548	493361	19507S	PARTICIPANT	\N	PRESENT	0
494549	493361	14195A	PARTICIPANT	\N	PRESENT	0
494550	493361	95063L	PARTICIPANT	\N	PRESENT	0
494551	493361	19447X	PARTICIPANT	\N	PRESENT	0
494552	493361	19581D	PARTICIPANT	\N	PRESENT	0
494553	493361	14231L	PARTICIPANT	\N	PRESENT	0
494554	493361	19739H	PARTICIPANT	\N	PRESENT	0
494555	493273	14211G	PARTICIPANT	\N	PRESENT	0
494556	493361	19387D	PARTICIPANT	\N	PRESENT	0
494557	493361	08045X	PARTICIPANT	\N	PRESENT	0
494558	493361	14147R	PARTICIPANT	\N	PRESENT	0
494559	493361	14026U	PARTICIPANT	\N	PRESENT	0
494560	493361	19467C	PARTICIPANT	\N	PRESENT	0
494561	493361	19383Y	PARTICIPANT	\N	PRESENT	0
494562	493361	20024T	PARTICIPANT	\N	PRESENT	0
494563	493361	14217N	PARTICIPANT	\N	PRESENT	0
494564	493361	19762G	PARTICIPANT	\N	PRESENT	0
494565	493361	18083K	PARTICIPANT	\N	PRESENT	0
494566	493361	20028X	PARTICIPANT	\N	PRESENT	0
494567	493273	08069G	PARTICIPANT	\N	PRESENT	0
494568	493361	19521Q	PARTICIPANT	\N	PRESENT	0
494569	493361	14089Y	PARTICIPANT	\N	PRESENT	0
494570	493273	01058X	PARTICIPANT	\N	PRESENT	0
494571	493361	14031R	PARTICIPANT	\N	PRESENT	0
494572	493361	14071N	PARTICIPANT	\N	PRESENT	0
494573	493361	19798U	PARTICIPANT	\N	PRESENT	0
494574	493361	20018V	PARTICIPANT	\N	PRESENT	0
494575	493361	04092N	PARTICIPANT	\N	PRESENT	0
494576	493273	19565D	PARTICIPANT	\N	PRESENT	0
494577	493361	14073Q	PARTICIPANT	\N	PRESENT	0
494578	493361	20054A	PARTICIPANT	\N	PRESENT	0
494579	493361	20062A	PARTICIPANT	\N	PRESENT	0
494580	493361	19575F	PARTICIPANT	\N	PRESENT	0
494581	493361	14215L	PARTICIPANT	\N	PRESENT	0
494598	494596	14026U	PARTICIPANT	\N	PRESENT	0
494616	494532	20128B	PARTICIPANT	\N	EXCUSE	0
494617	494532	20066E	PARTICIPANT	\N	EXCUSE	0
494618	494532	19569H	PARTICIPANT	\N	PRESENT	0
494619	494532	19503N	PARTICIPANT	\N	PRESENT	0
494620	494532	19723Y	PARTICIPANT	\N	EXCUSE	0
494621	494532	19663E	PARTICIPANT	\N	EXCUSE	0
494641	491683	19651A	PARTICIPANT	\N	PRESENT	0
494639	491683	04059M	PARTICIPANT	\N	PRESENT	0
494640	491683	20112S	PARTICIPANT	\N	PRESENT	0
494642	491683	14030Q	PARTICIPANT	\N	PRESENT	0
494643	491683	20152B	PARTICIPANT	\N	PRESENT	0
494644	491683	19621T	PRESIDENT	0	PRESENT	0
494645	491683	19758L	PARTICIPANT	\N	PRESENT	0
494646	491683	19693L	PARTICIPANT	\N	PRESENT	0
494647	491683	20134Y	PARTICIPANT	\N	PRESENT	0
494648	491683	20132W	PARTICIPANT	\N	PRESENT	0
494649	491683	20120S	PARTICIPANT	\N	PRESENT	0
494650	491683	14123H	PARTICIPANT	\N	PRESENT	0
494651	491683	20048C	PARTICIPANT	\N	PRESENT	0
494652	491683	19399H	PARTICIPANT	\N	PRESENT	0
494653	491683	20056C	PARTICIPANT	\N	PRESENT	0
494654	491683	14073Q	PARTICIPANT	\N	PRESENT	0
494655	491683	19699S	PARTICIPANT	\N	PRESENT	0
494656	491683	20052X	PARTICIPANT	\N	PRESENT	0
494719	491683	19611R	PARTICIPANT	\N	EXCUSE	0
494720	491683	20142Y	PARTICIPANT	\N	PRESENT	0
494721	491683	19593H	PARTICIPANT	\N	PRESENT	0
494722	491683	08061X	PARTICIPANT	\N	PRESENT	0
494723	491683	19533U	PARTICIPANT	\N	PRESENT	0
494724	491683	04033B	PARTICIPANT	\N	PRESENT	0
494725	491683	14229S	PARTICIPANT	\N	PRESENT	0
494726	491683	11043H	PARTICIPANT	\N	PRESENT	0
494727	491683	20098N	PARTICIPANT	\N	PRESENT	0
494728	491683	19527W	PARTICIPANT	\N	PRESENT	0
494729	491683	20026V	PARTICIPANT	\N	PRESENT	0
494730	491683	20058E	PARTICIPANT	\N	PRESENT	0
494731	491683	19719D	PARTICIPANT	\N	PRESENT	0
494733	494732	04070G	PARTICIPANT	\N	PRESENT	0
494734	494732	19593H	PARTICIPANT	\N	PRESENT	0
494735	494732	19621T	PARTICIPANT	\N	PRESENT	0
494736	491698	19611R	PARTICIPANT	\N	EXCUSE	0
494738	494737	20134Y	PARTICIPANT	\N	PRESENT	0
494739	494737	04070G	PARTICIPANT	\N	PRESENT	0
494740	494737	19593H	PARTICIPANT	\N	PRESENT	0
494751	494741	19295A	PARTICIPANT	\N	PRESENT	0
494752	494741	14071N	PARTICIPANT	\N	PRESENT	0
494753	494742	19415P	PARTICIPANT	\N	PRESENT	0
494754	494742	14071N	PARTICIPANT	\N	PRESENT	0
494758	494743	14071N	PARTICIPANT	\N	PRESENT	0
494759	494744	14071N	PARTICIPANT	\N	PRESENT	0
494757	494743	14217N	PARTICIPANT	\N	PRESENT	0
494760	494745	14071N	PARTICIPANT	\N	PRESENT	0
494761	494746	14071N	PARTICIPANT	\N	PRESENT	0
494762	494747	14213J	PARTICIPANT	\N	PRESENT	0
494763	494747	11031D	PARTICIPANT	\N	PRESENT	0
494764	494747	11067R	PARTICIPANT	\N	PRESENT	0
494765	494748	14213J	PARTICIPANT	\N	PRESENT	0
494766	494749	14213J	PARTICIPANT	\N	PRESENT	0
494767	494750	14213J	PARTICIPANT	\N	PRESENT	0
494768	493363	14133K	PARTICIPANT	\N	PRESENT	0
494769	493363	11048N	PARTICIPANT	\N	PRESENT	0
494770	493363	14331P	PARTICIPANT	\N	PRESENT	0
494771	493363	19758L	PARTICIPANT	\N	PRESENT	0
494772	493363	20100N	PARTICIPANT	\N	PRESENT	0
494773	493363	19387D	PARTICIPANT	\N	PRESENT	0
494774	493363	19629C	PARTICIPANT	\N	PRESENT	0
494775	493363	14207L	PARTICIPANT	\N	PRESENT	0
494776	493363	19441R	PARTICIPANT	\N	PRESENT	0
494777	493363	20122U	PARTICIPANT	\N	PRESENT	0
494778	493363	20112S	PARTICIPANT	\N	PRESENT	0
494779	493363	95063L	PARTICIPANT	\N	PRESENT	0
494780	493363	14073Q	PARTICIPANT	\N	PRESENT	0
494781	493363	20106U	PARTICIPANT	\N	PRESENT	0
494782	493363	19521Q	PARTICIPANT	\N	PRESENT	0
494783	493363	18083K	PARTICIPANT	\N	PRESENT	0
494784	493363	19507S	PARTICIPANT	\N	PRESENT	0
494785	493363	14033T	PARTICIPANT	\N	PRESENT	0
494786	493363	20032T	PARTICIPANT	\N	PRESENT	0
494787	493363	14031R	PARTICIPANT	\N	PRESENT	0
494788	493363	14069U	PARTICIPANT	\N	PRESENT	0
494789	493363	19701S	PARTICIPANT	\N	PRESENT	0
494790	493363	20022R	PARTICIPANT	\N	PRESENT	0
494791	493363	19954N	PARTICIPANT	\N	PRESENT	0
494792	493363	14026U	PARTICIPANT	\N	PRESENT	0
494717	491683	04070G	PARTICIPANT	\N	PRESENT	0
494718	493363	12041X	PARTICIPANT	\N	PRESENT	0
494793	493363	20024T	PARTICIPANT	\N	PRESENT	0
494794	493363	14357A	PARTICIPANT	\N	PRESENT	0
494795	493363	19383Y	PARTICIPANT	\N	PRESENT	0
494796	493363	11097X	PARTICIPANT	\N	PRESENT	0
494797	493363	20054A	PARTICIPANT	\N	PRESENT	0
494798	493363	20044X	PARTICIPANT	\N	PRESENT	0
494799	493363	19747H	PARTICIPANT	\N	PRESENT	0
494800	493363	14219Q	PARTICIPANT	\N	PRESENT	0
494801	493363	11056N	PARTICIPANT	\N	PRESENT	0
494802	493363	19531S	PARTICIPANT	\N	PRESENT	0
494803	493363	11026G	PARTICIPANT	\N	PRESENT	0
494804	493363	20094J	PARTICIPANT	\N	PRESENT	0
494805	493363	04042C	PARTICIPANT	\N	PRESENT	0
494806	493363	07029T	PARTICIPANT	\N	PRESENT	0
494807	493363	14147R	PARTICIPANT	\N	PRESENT	0
494808	493363	19347U	PARTICIPANT	\N	PRESENT	0
494809	493363	19545Y	PARTICIPANT	\N	PRESENT	0
494810	493363	14179A	PARTICIPANT	\N	PRESENT	0
494811	493363	14213J	PARTICIPANT	\N	PRESENT	0
494827	491379	95063L	PARTICIPANT	\N	PRESENT	0
494839	491379	20042V	PARTICIPANT	\N	EXCUSE	0
494840	491379	20144B	PARTICIPANT	\N	EXCUSE	0
494841	491379	19543W	PARTICIPANT	\N	PRESENT	0
494842	491379	19551W	PARTICIPANT	\N	PRESENT	0
494843	491379	04070G	PARTICIPANT	\N	PRESENT	0
494844	491379	19569H	PARTICIPANT	\N	EXCUSE	0
495095	493364	19701S	PARTICIPANT	\N	PRESENT	0
486836	485907	19349W	PARTICIPANT	\N	EXCUSE	0
486862	486861	11070L	PARTICIPANT	\N	PRESENT	0
496051	495119	19369B	PARTICIPANT	\N	PRESENT	0
496052	495119	19507S	PARTICIPANT	\N	PRESENT	0
496053	495119	20106U	PARTICIPANT	\N	PRESENT	0
496054	495119	19467C	PARTICIPANT	\N	PRESENT	0
496055	495119	01028R	PARTICIPANT	\N	PRESENT	0
496056	495119	18083K	PARTICIPANT	\N	PRESENT	0
496057	495119	11065P	PARTICIPANT	\N	PRESENT	0
496058	495119	19367Y	PARTICIPANT	\N	PRESENT	0
496059	495119	20044X	PARTICIPANT	\N	PRESENT	0
496060	495119	20126Y	PARTICIPANT	\N	PRESENT	0
496061	495119	19421M	PARTICIPANT	\N	PRESENT	0
496062	495119	19447X	PARTICIPANT	\N	PRESENT	0
496063	495119	20054A	PARTICIPANT	\N	PRESENT	0
496064	495119	20124W	PARTICIPANT	\N	PRESENT	0
496065	495119	14038Y	PARTICIPANT	\N	PRESENT	0
496087	495119	14213J	PARTICIPANT	\N	PRESENT	0
496067	495119	19551W	PARTICIPANT	\N	PRESENT	0
496068	495119	14187A	PARTICIPANT	\N	PRESENT	0
496069	495119	11048N	PARTICIPANT	\N	PRESENT	0
496070	495119	14147R	PARTICIPANT	\N	PRESENT	0
496071	495119	14329V	PARTICIPANT	\N	PRESENT	0
496072	495119	19383Y	PARTICIPANT	\N	PRESENT	0
496073	495119	19575F	PARTICIPANT	\N	PRESENT	0
496074	495119	20118Y	PARTICIPANT	\N	PRESENT	0
496075	495119	14217N	PARTICIPANT	\N	PRESENT	0
496076	495119	19798U	PARTICIPANT	\N	PRESENT	0
496077	495119	19573D	PARTICIPANT	\N	PRESENT	0
496078	495119	14357A	PARTICIPANT	\N	PRESENT	0
496079	495119	20098N	PARTICIPANT	\N	PRESENT	0
496080	495119	14026U	PARTICIPANT	\N	PRESENT	0
496081	495119	20140W	PARTICIPANT	\N	PRESENT	0
496082	495119	17367Q	PARTICIPANT	\N	PRESENT	0
496083	495119	20096L	PARTICIPANT	\N	PRESENT	0
496084	495119	20058E	PARTICIPANT	\N	PRESENT	0
496085	495119	20062A	PARTICIPANT	\N	PRESENT	0
496086	495119	08015R	PARTICIPANT	\N	PRESENT	0
496088	495119	05012A	PARTICIPANT	\N	PRESENT	0
496089	495119	14069U	PARTICIPANT	\N	PRESENT	0
496090	495119	11056N	PARTICIPANT	\N	PRESENT	0
496091	495119	14083S	PARTICIPANT	\N	PRESENT	0
496092	495119	19689Q	PARTICIPANT	\N	PRESENT	0
496290	495268	14089Y	PARTICIPANT	\N	PRESENT	0
496291	495268	14053L	PARTICIPANT	\N	PRESENT	0
496292	495268	11056N	PARTICIPANT	\N	PRESENT	0
496293	495268	14259Y	PARTICIPANT	\N	PRESENT	0
496294	495268	14215L	PARTICIPANT	\N	PRESENT	0
496295	495268	20074E	PARTICIPANT	\N	PRESENT	0
496296	495268	14151M	PARTICIPANT	\N	PRESENT	0
496297	495268	14231L	PARTICIPANT	\N	PRESENT	0
496298	495268	14179A	PARTICIPANT	\N	PRESENT	0
496299	495268	14107H	PARTICIPANT	\N	PRESENT	0
496300	495268	04047H	PRESIDENT	0	PRESENT	0
496301	495268	17737W	PARTICIPANT	\N	PRESENT	0
496302	495268	19629C	PARTICIPANT	\N	PRESENT	0
496303	495268	19749K	PARTICIPANT	\N	PRESENT	0
496304	495268	07004J	PARTICIPANT	\N	PRESENT	0
496305	495268	20110Q	PARTICIPANT	\N	PRESENT	0
497339	495125	11056N	PARTICIPANT	\N	PRESENT	0
497340	495125	14357A	PARTICIPANT	\N	PRESENT	0
497341	495125	19693L	PARTICIPANT	\N	PRESENT	0
497342	495125	17589D	PARTICIPANT	\N	PRESENT	0
497343	495125	20140W	PARTICIPANT	\N	PRESENT	0
497344	495125	14217N	PARTICIPANT	\N	PRESENT	0
497345	495125	14042U	PARTICIPANT	\N	PRESENT	0
497346	495125	20134Y	PARTICIPANT	\N	PRESENT	0
497347	495125	20124W	PARTICIPANT	\N	PRESENT	0
497348	495125	20038A	PARTICIPANT	\N	PRESENT	0
497349	495125	20132W	PARTICIPANT	\N	PRESENT	0
497350	495125	14231L	PARTICIPANT	\N	PRESENT	0
497351	495125	19695N	PARTICIPANT	\N	PRESENT	0
497352	495125	19820Y	PARTICIPANT	\N	PRESENT	0
497353	495125	19387D	PARTICIPANT	\N	PRESENT	0
497354	495125	19565D	PARTICIPANT	\N	PRESENT	0
497355	495125	14033T	PARTICIPANT	\N	PRESENT	0
497356	495125	14123H	PARTICIPANT	\N	PRESENT	0
497357	495125	19691J	PARTICIPANT	\N	PRESENT	0
497358	495125	19569H	PARTICIPANT	\N	PRESENT	0
497359	495125	14179A	PARTICIPANT	\N	PRESENT	0
497360	495125	20048C	PARTICIPANT	\N	PRESENT	0
497361	495125	19399H	PARTICIPANT	\N	PRESENT	0
497362	495125	20056C	PARTICIPANT	\N	PRESENT	0
497363	495125	14097Y	PARTICIPANT	\N	PRESENT	0
497364	495125	14021P	PARTICIPANT	\N	PRESENT	0
497365	495125	14073Q	PARTICIPANT	\N	PRESENT	0
497366	495125	19489J	PARTICIPANT	\N	PRESENT	0
497368	495125	20126Y	PARTICIPANT	\N	PRESENT	0
497370	495125	11099A	PARTICIPANT	\N	PRESENT	0
497371	495125	19611R	PARTICIPANT	\N	PRESENT	0
497373	495125	19699S	PARTICIPANT	\N	PRESENT	0
497375	495125	12041X	PARTICIPANT	\N	PRESENT	0
497376	495125	08017T	PARTICIPANT	\N	PRESENT	0
497378	495125	20052X	PARTICIPANT	\N	PRESENT	0
497380	495125	11077T	PARTICIPANT	\N	PRESENT	0
497381	495125	19441R	PARTICIPANT	\N	PRESENT	0
497383	495125	20142Y	PARTICIPANT	\N	PRESENT	0
497384	495125	14147R	PARTICIPANT	\N	PRESENT	0
497386	495125	19671E	PARTICIPANT	\N	PRESENT	0
497388	495125	20018V	PARTICIPANT	\N	PRESENT	0
497389	495125	14109K	PARTICIPANT	\N	PRESENT	0
497391	495125	19369B	PARTICIPANT	\N	PRESENT	0
497393	495125	14257W	PARTICIPANT	\N	PRESENT	0
497395	495125	14169X	PARTICIPANT	\N	PRESENT	0
497397	495125	19593H	PARTICIPANT	\N	PRESENT	0
497398	495125	19573D	PARTICIPANT	\N	PRESENT	0
497400	495125	19533U	PARTICIPANT	\N	PRESENT	0
497402	495125	19503N	PARTICIPANT	\N	PRESENT	0
497403	495125	04043D	PARTICIPANT	\N	PRESENT	0
497405	495125	14331P	PARTICIPANT	\N	PRESENT	0
497407	495125	20082E	PARTICIPANT	\N	PRESENT	0
497409	495125	14229S	PARTICIPANT	\N	PRESENT	0
497410	495125	20092G	PARTICIPANT	\N	PRESENT	0
497411	495125	20098N	PARTICIPANT	\N	PRESENT	0
497412	495125	19762G	PARTICIPANT	\N	PRESENT	0
497413	495125	19703U	PARTICIPANT	\N	PRESENT	0
497414	495125	19713W	PARTICIPANT	\N	PRESENT	0
497415	495125	20084G	PARTICIPANT	\N	PRESENT	0
497416	495125	01028R	PARTICIPANT	\N	PRESENT	0
497417	495125	20136B	PARTICIPANT	\N	PRESENT	0
497418	495125	19413M	PARTICIPANT	\N	PRESENT	0
497419	495125	20026V	PARTICIPANT	\N	PRESENT	0
497420	495125	19479G	PARTICIPANT	\N	PRESENT	0
497421	495125	20058E	PARTICIPANT	\N	PRESENT	0
498036	498035	11056N	PARTICIPANT	\N	PRESENT	0
498037	498035	19489J	PARTICIPANT	\N	PRESENT	0
498481	498477	04047H	PARTICIPANT	\N	PRESENT	0
498479	498477	04085P	PARTICIPANT	\N	PRESENT	0
498480	498477	05008E	PARTICIPANT	\N	PRESENT	0
498482	498477	04042C	PARTICIPANT	\N	PRESENT	0
498483	498477	19629C	PARTICIPANT	\N	PRESENT	0
498484	498477	19347U	PARTICIPANT	\N	PRESENT	0
498485	498477	14026U	PARTICIPANT	\N	PRESENT	0
498486	498477	11048N	PARTICIPANT	\N	PRESENT	0
498487	498477	14021P	PARTICIPANT	\N	PRESENT	0
498488	498477	99004R	PARTICIPANT	\N	PRESENT	0
498489	498477	19611R	PARTICIPANT	\N	PRESENT	0
498490	498477	12041X	PARTICIPANT	\N	PRESENT	0
498491	498477	14219Q	PARTICIPANT	\N	PRESENT	0
498492	498477	14251Q	PARTICIPANT	\N	PRESENT	0
498493	498477	11085T	PARTICIPANT	\N	PRESENT	0
498494	498477	04092N	PARTICIPANT	\N	PRESENT	0
498495	498477	08073C	PARTICIPANT	\N	PRESENT	0
498496	498477	08061X	PARTICIPANT	\N	PRESENT	0
498497	498477	11090Q	PARTICIPANT	\N	PRESENT	0
498498	498477	14331P	PARTICIPANT	\N	PRESENT	0
498499	498477	14225N	PARTICIPANT	\N	PRESENT	0
498500	498477	04033B	PARTICIPANT	\N	PRESENT	0
498501	498477	11045K	PARTICIPANT	\N	PRESENT	0
498502	498477	01034P	PARTICIPANT	\N	PRESENT	0
500552	500279	11045K	PARTICIPANT	\N	PRESENT	0
497424	489992	17737W	PARTICIPANT	\N	EXCUSE	0
497425	489992	19621T	PARTICIPANT	\N	EXCUSE	0
497426	489992	19693L	PARTICIPANT	\N	EXCUSE	0
497427	489992	04035D	PARTICIPANT	\N	EXCUSE	0
497428	489992	20056C	PARTICIPANT	\N	EXCUSE	0
497429	489992	07029T	PARTICIPANT	\N	EXCUSE	0
497430	489992	14221J	PARTICIPANT	\N	EXCUSE	0
497431	489992	20118Y	PARTICIPANT	\N	EXCUSE	0
497432	489992	20098N	PARTICIPANT	\N	EXCUSE	0
497433	495678	14147R	PARTICIPANT	\N	PRESENT	0
497570	495121	19447X	PARTICIPANT	\N	PRESENT	0
497571	495121	14151M	PARTICIPANT	\N	PRESENT	0
497572	495121	19820Y	PARTICIPANT	\N	PRESENT	0
497573	495121	19683J	PARTICIPANT	\N	PRESENT	0
497574	495121	19629C	PARTICIPANT	\N	PRESENT	0
497575	495121	20106U	PARTICIPANT	\N	PRESENT	0
497576	495121	11056N	PARTICIPANT	\N	PRESENT	0
497577	495121	19758L	PARTICIPANT	\N	PRESENT	0
497578	495121	19695N	PARTICIPANT	\N	PRESENT	0
497579	495121	12016W	PARTICIPANT	\N	PRESENT	0
497580	495121	19715Y	PARTICIPANT	\N	PRESENT	0
497581	495121	01028R	PARTICIPANT	\N	PRESENT	0
497582	495121	19649G	PARTICIPANT	\N	PRESENT	0
497583	495121	19599P	PARTICIPANT	\N	PRESENT	0
497584	495121	20082E	PARTICIPANT	\N	PRESENT	0
497585	495121	11031D	PARTICIPANT	\N	PRESENT	0
497586	495121	19713W	PARTICIPANT	\N	PRESENT	0
497587	495121	20066E	PARTICIPANT	\N	PRESENT	0
497588	495121	19691J	PARTICIPANT	\N	PRESENT	0
497589	495121	11053K	PARTICIPANT	\N	PRESENT	0
497590	495121	14089Y	PARTICIPANT	\N	PRESENT	0
497591	495121	19489J	PARTICIPANT	\N	PRESENT	0
497592	495121	14055N	PARTICIPANT	\N	PRESENT	0
497593	495121	14215L	PARTICIPANT	\N	PRESENT	0
497594	495121	19747H	PARTICIPANT	\N	PRESENT	0
497595	495121	14071N	PARTICIPANT	\N	PRESENT	0
497596	495121	07029T	PARTICIPANT	\N	PRESENT	0
497597	495121	14026U	PARTICIPANT	\N	PRESENT	0
497598	495121	20020P	PARTICIPANT	\N	PRESENT	0
497599	495121	14189C	PARTICIPANT	\N	PRESENT	0
497600	495121	20090E	PARTICIPANT	\N	PRESENT	0
497601	495121	14041T	PARTICIPANT	\N	PRESENT	0
497602	495121	20110Q	PARTICIPANT	\N	PRESENT	0
497603	495121	19954N	PARTICIPANT	\N	PRESENT	0
497604	495121	19399H	PARTICIPANT	\N	PRESENT	0
497605	495121	19543W	PARTICIPANT	\N	PRESENT	0
497606	495121	20026V	PARTICIPANT	\N	PRESENT	0
497607	495121	20038A	PARTICIPANT	\N	PRESENT	0
497608	495121	20044X	PARTICIPANT	\N	PRESENT	0
497609	495121	11026G	PARTICIPANT	\N	PRESENT	0
497610	495121	17637T	PARTICIPANT	\N	PRESENT	0
497611	495121	05008E	PARTICIPANT	\N	PRESENT	0
497612	495121	11027H	PARTICIPANT	\N	PRESENT	0
497613	495121	19749K	PARTICIPANT	\N	PRESENT	0
497614	495121	04085P	PARTICIPANT	\N	PRESENT	0
497615	495121	08069G	PARTICIPANT	\N	PRESENT	0
497616	495121	19347U	PARTICIPANT	\N	PRESENT	0
497617	495121	20086J	PARTICIPANT	\N	PRESENT	0
497618	495121	18083K	PARTICIPANT	\N	PRESENT	0
497619	495121	20080C	PARTICIPANT	\N	PRESENT	0
497620	495121	19533U	PARTICIPANT	\N	PRESENT	0
497621	495121	19673G	PARTICIPANT	\N	PRESENT	0
497622	495121	20022R	PARTICIPANT	\N	PRESENT	0
497623	495121	20058E	PARTICIPANT	\N	PRESENT	0
497624	495121	14021P	PARTICIPANT	\N	PRESENT	0
497625	495121	14357A	PARTICIPANT	\N	PRESENT	0
497626	495121	19671E	PARTICIPANT	\N	PRESENT	0
497627	495121	14030Q	PARTICIPANT	\N	PRESENT	0
497628	495121	17023S	PARTICIPANT	\N	PRESENT	0
497629	495121	17779H	PARTICIPANT	\N	PRESENT	0
497630	495121	19741B	PARTICIPANT	\N	PRESENT	0
497631	495121	14147R	PARTICIPANT	\N	PRESENT	0
497632	495121	11085T	PARTICIPANT	\N	PRESENT	0
497633	495121	11070L	PARTICIPANT	\N	PRESENT	0
497634	495121	20050V	PARTICIPANT	\N	PRESENT	0
497635	495121	07004J	PARTICIPANT	\N	PRESENT	0
497636	495121	14281W	PARTICIPANT	\N	PRESENT	0
497637	495121	19701S	PARTICIPANT	\N	PRESENT	0
497638	495121	14251Q	PARTICIPANT	\N	PRESENT	0
497639	495269	19629C	PARTICIPANT	\N	PRESENT	0
497640	495269	14041T	PARTICIPANT	\N	PRESENT	0
497641	495269	08018U	PARTICIPANT	\N	PRESENT	0
497642	495269	05008E	PARTICIPANT	\N	PRESENT	0
497643	495269	19649G	PARTICIPANT	\N	PRESENT	0
497644	495269	19543W	PARTICIPANT	\N	PRESENT	0
497645	495269	04047H	PRESIDENT	0	PRESENT	0
497646	495269	19673G	PARTICIPANT	\N	PRESENT	0
497647	495269	01028R	PARTICIPANT	\N	PRESENT	0
497648	495269	19447X	PARTICIPANT	\N	PRESENT	0
497649	495269	14089Y	PARTICIPANT	\N	PRESENT	0
497650	495269	07004J	PARTICIPANT	\N	PRESENT	0
497667	495121	19687N	PARTICIPANT	\N	PRESENT	0
497652	495269	14147R	PARTICIPANT	\N	PRESENT	0
497653	495269	14151M	PARTICIPANT	\N	PRESENT	0
497654	495269	14215L	PARTICIPANT	\N	PRESENT	0
497655	495269	19749K	PARTICIPANT	\N	PRESENT	0
497656	495269	11026G	PARTICIPANT	\N	PRESENT	0
497668	495121	17737W	PARTICIPANT	\N	PRESENT	0
497669	495121	14179A	PARTICIPANT	\N	PRESENT	0
497659	495269	01060R	PARTICIPANT	\N	PRESENT	0
497660	495269	19489J	PARTICIPANT	\N	PRESENT	0
497661	495269	08045X	PARTICIPANT	\N	PRESENT	0
497662	495269	01024M	PARTICIPANT	\N	PRESENT	0
497670	495121	19621T	PARTICIPANT	\N	PRESENT	0
497664	495269	19762G	PARTICIPANT	\N	PRESENT	0
497665	495269	17737W	PARTICIPANT	\N	PRESENT	0
497666	495269	20110Q	PARTICIPANT	\N	PRESENT	0
497723	495123	14026U	PARTICIPANT	\N	PRESENT	0
497725	495123	04047H	PARTICIPANT	\N	PRESENT	0
497726	495123	19687N	PARTICIPANT	\N	PRESENT	0
497727	495123	20106U	PARTICIPANT	\N	PRESENT	0
497728	495123	19629C	PARTICIPANT	\N	PRESENT	0
497729	495123	11027H	PARTICIPANT	\N	PRESENT	0
497730	495123	17779H	PARTICIPANT	\N	PRESENT	0
497731	495123	14151M	PARTICIPANT	\N	PRESENT	0
497732	495123	19649G	PARTICIPANT	\N	PRESENT	0
497733	495123	14251Q	PARTICIPANT	\N	PRESENT	0
497734	495123	19543W	PARTICIPANT	\N	PRESENT	0
497735	495123	19713W	PARTICIPANT	\N	PRESENT	0
497736	495123	17023S	PARTICIPANT	\N	PRESENT	0
497737	495123	20086J	PARTICIPANT	\N	PRESENT	0
497738	495123	07029T	PARTICIPANT	\N	PRESENT	0
497739	495123	19741B	PARTICIPANT	\N	PRESENT	0
497740	495123	17737W	PARTICIPANT	\N	PRESENT	0
497741	495123	20038A	PARTICIPANT	\N	PRESENT	0
497742	495123	20044X	PARTICIPANT	\N	PRESENT	0
497743	495123	04033B	PARTICIPANT	\N	PRESENT	0
497744	495123	14071N	PARTICIPANT	\N	PRESENT	0
497745	495123	19747H	PARTICIPANT	\N	PRESENT	0
497746	495123	20058E	PARTICIPANT	\N	PRESENT	0
497747	495123	14041T	PARTICIPANT	\N	PRESENT	0
497748	495123	14089Y	PARTICIPANT	\N	PRESENT	0
497749	495123	07004J	PARTICIPANT	\N	PRESENT	0
497750	495123	19749K	PARTICIPANT	\N	PRESENT	0
497751	495123	14021P	PARTICIPANT	\N	PRESENT	0
497752	495123	20110Q	PARTICIPANT	\N	PRESENT	0
497753	495123	19671E	PARTICIPANT	\N	PRESENT	0
497754	495123	04085P	PARTICIPANT	\N	PRESENT	0
497755	495123	19695N	PARTICIPANT	\N	PRESENT	0
497756	495123	19758L	PARTICIPANT	\N	PRESENT	0
497757	495123	11026G	PARTICIPANT	\N	PRESENT	0
497758	495123	01028R	PARTICIPANT	\N	PRESENT	0
497759	495123	19691J	PARTICIPANT	\N	PRESENT	0
497760	495123	14215L	PARTICIPANT	\N	PRESENT	0
497568	495121	99004R	PARTICIPANT	\N	PRESENT	0
497569	495121	04047H	PARTICIPANT	\N	PRESENT	0
497761	495123	19447X	PARTICIPANT	\N	PRESENT	0
497762	495123	19647E	PARTICIPANT	\N	PRESENT	0
497763	495123	14281W	PARTICIPANT	\N	PRESENT	0
497764	495123	19621T	PARTICIPANT	\N	PRESENT	0
497765	495123	14179A	PARTICIPANT	\N	PRESENT	0
497766	495123	20098N	PARTICIPANT	\N	PRESENT	0
497767	495123	20026V	PARTICIPANT	\N	PRESENT	0
498012	498011	04035D	PARTICIPANT	\N	PRESENT	0
498013	498011	98022P	PARTICIPANT	\N	PRESENT	0
498015	498014	11053K	PARTICIPANT	\N	PRESENT	0
497724	495123	05008E	PARTICIPANT	\N	PRESENT	0
498017	498016	19711U	PARTICIPANT	\N	PRESENT	0
498019	498018	19711U	PARTICIPANT	\N	PRESENT	0
498021	498020	96004D	PARTICIPANT	\N	PRESENT	0
498023	498022	14331P	PARTICIPANT	\N	PRESENT	0
498025	498024	14173T	PARTICIPANT	\N	PRESENT	0
498027	498026	01048V	PARTICIPANT	\N	PRESENT	0
498029	498028	01048V	PARTICIPANT	\N	PRESENT	0
498031	498030	11012A	PARTICIPANT	\N	PRESENT	0
498032	498030	14083S	PARTICIPANT	\N	PRESENT	0
498034	498033	19335Q	PARTICIPANT	\N	PRESENT	0
498039	498038	11048N	PARTICIPANT	\N	PRESENT	0
498040	498038	14225N	PARTICIPANT	\N	PRESENT	0
487012	479211	19467C	PARTICIPANT	\N	PRESENT	0
487013	479211	19515S	PARTICIPANT	\N	PRESENT	0
487014	479211	14215L	PARTICIPANT	\N	PRESENT	0
487015	479211	19367Y	PARTICIPANT	\N	PRESENT	0
487016	479211	95030B	PARTICIPANT	\N	PRESENT	0
487017	479211	19333N	PARTICIPANT	\N	PRESENT	0
487010	479211	19794Q	PARTICIPANT	\N	PRESENT	0
487011	479211	19585H	PARTICIPANT	\N	PRESENT	0
487018	479211	14081Q	PARTICIPANT	\N	PRESENT	0
487019	479211	14087W	PARTICIPANT	\N	PRESENT	0
487020	479211	19701S	PARTICIPANT	\N	PRESENT	0
487021	479211	19695N	PARTICIPANT	\N	PRESENT	0
487022	479211	04047H	PARTICIPANT	\N	PRESENT	0
487023	479211	19731Y	PARTICIPANT	\N	PRESENT	0
487024	479211	14197C	PARTICIPANT	\N	PRESENT	0
487025	479211	19713W	PARTICIPANT	\N	PRESENT	0
487026	479211	14053L	PARTICIPANT	\N	PRESENT	0
487027	479211	19637C	PARTICIPANT	\N	PRESENT	0
487028	479211	19387D	PARTICIPANT	\N	PRESENT	0
487029	479211	14227Q	PARTICIPANT	\N	PRESENT	0
487030	479211	19507S	PARTICIPANT	\N	PRESENT	0
487031	479211	19503N	PARTICIPANT	\N	PRESENT	0
487032	479211	07004J	PARTICIPANT	\N	PRESENT	0
487033	479211	19703U	PARTICIPANT	\N	PRESENT	0
487034	479211	19543W	PARTICIPANT	\N	PRESENT	0
487035	479211	14042U	PARTICIPANT	\N	PRESENT	0
487036	479211	04085P	PARTICIPANT	\N	PRESENT	0
487037	479211	14235Q	PARTICIPANT	\N	PRESENT	0
487039	479211	11054L	PARTICIPANT	\N	PRESENT	0
487040	479211	11031D	PARTICIPANT	\N	PRESENT	0
487041	479211	19673G	PARTICIPANT	\N	PRESENT	0
487042	479211	19447X	PARTICIPANT	\N	PRESENT	0
487043	479211	88008L	PARTICIPANT	\N	PRESENT	0
487044	479211	14261S	PARTICIPANT	\N	PRESENT	0
487045	479211	11067R	PARTICIPANT	\N	PRESENT	0
487046	479211	14051J	PARTICIPANT	\N	PRESENT	0
487047	479211	19671E	PARTICIPANT	\N	PRESENT	0
487106	479215	05008E	PARTICIPANT	\N	PRESENT	0
487107	479215	19912C	PARTICIPANT	\N	PRESENT	0
487108	479215	19649G	PARTICIPANT	\N	PRESENT	0
487109	479215	11026G	PARTICIPANT	\N	PRESENT	0
487110	479215	14081Q	PARTICIPANT	\N	PRESENT	0
487111	479215	14051J	PARTICIPANT	\N	PRESENT	0
487112	479215	19333N	PARTICIPANT	\N	PRESENT	0
487113	479215	19503N	PARTICIPANT	\N	PRESENT	0
487114	479215	14227Q	PARTICIPANT	\N	PRESENT	0
487115	479215	11067R	PARTICIPANT	\N	PRESENT	0
487116	479215	11054L	PARTICIPANT	\N	PRESENT	0
487117	479215	19565D	PARTICIPANT	\N	PRESENT	0
487118	479215	19585H	PARTICIPANT	\N	PRESENT	0
487119	479215	17589D	PARTICIPANT	\N	PRESENT	0
487120	479215	19387D	PARTICIPANT	\N	PRESENT	0
487121	479215	19543W	PARTICIPANT	\N	PRESENT	0
487122	479215	07004J	PARTICIPANT	\N	PRESENT	0
487123	479215	19737F	PARTICIPANT	\N	PRESENT	0
487124	479215	01024M	PARTICIPANT	\N	PRESENT	0
487125	479215	19930E	PARTICIPANT	\N	PRESENT	0
487126	479215	19367Y	PARTICIPANT	\N	PRESENT	0
487127	479215	19703U	PARTICIPANT	\N	PRESENT	0
487128	479215	14215L	PARTICIPANT	\N	PRESENT	0
487129	479215	97011G	PARTICIPANT	\N	PRESENT	0
487130	479215	19467C	PARTICIPANT	\N	PRESENT	0
487131	479215	14217N	PARTICIPANT	\N	PRESENT	0
487132	479215	14147R	PARTICIPANT	\N	PRESENT	0
487133	479215	19657G	PARTICIPANT	\N	PRESENT	0
487134	479215	19671E	PARTICIPANT	\N	PRESENT	0
487135	479215	14055N	PARTICIPANT	\N	PRESENT	0
487136	479215	19507S	PARTICIPANT	\N	PRESENT	0
487137	479215	19447X	PARTICIPANT	\N	PRESENT	0
487138	479215	11033F	PARTICIPANT	\N	PRESENT	0
487139	479215	11045K	PARTICIPANT	\N	PRESENT	0
487140	479215	14065Q	PARTICIPANT	\N	PRESENT	0
487141	479215	19794Q	PARTICIPANT	\N	PRESENT	0
487142	479215	04085P	PARTICIPANT	\N	PRESENT	0
487143	479215	14087W	PARTICIPANT	\N	PRESENT	0
487144	479215	04047H	PARTICIPANT	\N	PRESENT	0
487145	479215	19573D	PARTICIPANT	\N	PRESENT	0
487146	479215	14133K	PARTICIPANT	\N	PRESENT	0
487147	479215	04049K	PARTICIPANT	\N	PRESENT	0
487148	479215	01028R	PARTICIPANT	\N	PRESENT	0
487149	479215	88008L	PARTICIPANT	\N	PRESENT	0
487150	479215	14261S	PARTICIPANT	\N	PRESENT	0
487151	479215	11097X	PARTICIPANT	\N	PRESENT	0
487152	479215	19731Y	PARTICIPANT	\N	PRESENT	0
487153	479215	19954N	PARTICIPANT	\N	PRESENT	0
487154	479215	14059S	PARTICIPANT	\N	PRESENT	0
487155	479215	14042U	PARTICIPANT	\N	PRESENT	0
487156	479215	14235Q	PARTICIPANT	\N	PRESENT	0
487157	486929	19711U	PARTICIPANT	\N	PRESENT	0
487158	486929	19251M	PARTICIPANT	\N	PRESENT	0
487159	486929	08012N	PRESIDENT	0	PRESENT	0
487160	486929	02002K	PARTICIPANT	\N	PRESENT	0
487161	486929	11043H	PARTICIPANT	\N	EXCUSE	0
487104	479215	04044E	PARTICIPANT	\N	PRESENT	0
487105	479215	19673G	PARTICIPANT	\N	PRESENT	0
487162	486929	08024S	PARTICIPANT	\N	EXCUSE	0
487163	486929	87003B	PARTICIPANT	\N	EXCUSE	0
487164	486929	19758L	PARTICIPANT	\N	EXCUSE	0
487182	479215	19711U	PARTICIPANT	\N	PRESENT	0
487183	479215	14135M	PARTICIPANT	\N	PRESENT	0
487184	479215	89017R	PARTICIPANT	\N	PRESENT	0
487185	479215	19741B	PARTICIPANT	\N	PRESENT	0
487186	479215	19577H	PARTICIPANT	\N	PRESENT	0
487187	479215	08039A	PARTICIPANT	\N	PRESENT	0
487188	479215	14357A	PARTICIPANT	\N	PRESENT	0
487189	479215	04059M	PARTICIPANT	\N	PRESENT	0
491183	491179	19551W	PARTICIPANT	\N	PRESENT	0
491184	491178	19551W	PARTICIPANT	\N	PRESENT	0
491311	490474	11031D	PARTICIPANT	\N	PRESENT	0
491312	490474	19663E	PARTICIPANT	\N	PRESENT	0
491313	490474	10006L	PARTICIPANT	\N	PRESENT	0
491314	490474	14041T	PARTICIPANT	\N	PRESENT	0
491315	490474	19553Y	PARTICIPANT	\N	PRESENT	0
491316	490474	19715Y	PARTICIPANT	\N	PRESENT	0
491317	490474	19683J	PARTICIPANT	\N	PRESENT	0
491318	490474	19447X	PARTICIPANT	\N	PRESENT	0
491319	490474	19649G	PARTICIPANT	\N	EXCUSE	0
491320	490474	19697Q	PARTICIPANT	\N	PRESENT	0
491321	490474	11067R	PARTICIPANT	\N	PRESENT	0
491322	490474	04092N	PRESIDENT	0	PRESENT	0
491323	490474	19573D	PARTICIPANT	\N	PRESENT	0
491324	490474	19503N	PARTICIPANT	\N	PRESENT	0
491325	490474	14331P	PARTICIPANT	\N	PRESENT	0
491326	490474	11097X	PARTICIPANT	\N	PRESENT	0
491327	490474	19703U	PARTICIPANT	\N	PRESENT	0
491328	490474	01034P	PARTICIPANT	\N	PRESENT	0
491329	490474	19479G	PARTICIPANT	\N	PRESENT	0
491682	491412	19713W	PARTICIPANT	\N	PRESENT	0
491684	491412	01058X	PARTICIPANT	\N	PRESENT	0
491685	491412	14107H	PARTICIPANT	\N	PRESENT	0
491686	491412	19691J	PARTICIPANT	\N	PRESENT	0
491687	491412	19866P	PARTICIPANT	\N	PRESENT	0
491688	491486	19725B	PARTICIPANT	\N	PRESENT	0
491689	491486	19954N	PARTICIPANT	\N	PRESENT	0
491690	491486	19649G	PARTICIPANT	\N	PRESENT	0
491691	491486	11026G	PARTICIPANT	\N	PRESENT	0
491692	491486	20114U	PARTICIPANT	\N	PRESENT	0
491693	491486	19581D	PARTICIPANT	\N	PRESENT	0
491694	491486	14215L	PARTICIPANT	\N	PRESENT	0
491695	491486	19585H	PARTICIPANT	\N	PRESENT	0
491696	491486	04047H	PRESIDENT	0	PRESENT	0
491697	491486	01028R	PARTICIPANT	\N	PRESENT	0
491699	491486	11033F	PARTICIPANT	\N	PRESENT	0
491701	491486	11056N	PARTICIPANT	\N	PRESENT	0
491702	491412	19333N	PARTICIPANT	\N	PRESENT	0
491703	491412	14109K	PARTICIPANT	\N	PRESENT	0
491705	491412	19569H	PARTICIPANT	\N	PRESENT	0
491710	491412	08045X	PARTICIPANT	\N	PRESENT	0
491717	491486	14151M	PARTICIPANT	\N	PRESENT	0
491720	491412	20084G	PARTICIPANT	\N	PRESENT	0
491724	491412	14213J	PARTICIPANT	\N	PRESENT	0
491725	491412	19703U	PARTICIPANT	\N	PRESENT	0
491726	491412	11077T	PARTICIPANT	\N	PRESENT	0
491727	491412	20086J	PARTICIPANT	\N	PRESENT	0
491728	491486	14147R	PARTICIPANT	\N	PRESENT	0
491729	491486	14259Y	PARTICIPANT	\N	PRESENT	0
491730	491412	14055N	PARTICIPANT	\N	PRESENT	0
491731	491412	19669L	PARTICIPANT	\N	PRESENT	0
491732	491412	14021P	PARTICIPANT	\N	PRESENT	0
491733	491412	19659J	PARTICIPANT	\N	PRESENT	0
491734	491412	08017T	PARTICIPANT	\N	PRESENT	0
491735	491412	19820Y	PARTICIPANT	\N	PRESENT	0
491736	491412	14073Q	PARTICIPANT	\N	PRESENT	0
491737	491412	14030Q	PARTICIPANT	\N	PRESENT	0
491738	491486	05008E	PARTICIPANT	\N	PRESENT	0
491739	491412	14189C	PARTICIPANT	\N	PRESENT	0
491740	491412	19619A	PARTICIPANT	\N	PRESENT	0
495408	495407	19569H	PARTICIPANT	\N	PRESENT	0
495410	495409	19569H	PARTICIPANT	\N	PRESENT	0
496131	495038	14225N	PRESIDENT	0	PRESENT	0
496159	495106	12041X	PARTICIPANT	\N	PRESENT	0
496160	495106	19443T	PARTICIPANT	\N	PRESENT	0
496161	495106	19565D	PARTICIPANT	\N	PRESENT	0
496162	495106	04034C	PARTICIPANT	\N	PRESENT	0
496163	495106	01058X	PARTICIPANT	\N	PRESENT	0
496164	495106	11027H	PARTICIPANT	\N	PRESENT	0
496165	495106	04042C	PRESIDENT	0	PRESENT	0
496166	495106	11066Q	PARTICIPANT	\N	PRESENT	0
496167	495106	19421M	PARTICIPANT	\N	PRESENT	0
496168	495106	19347U	PARTICIPANT	\N	PRESENT	0
496169	495106	14193X	PARTICIPANT	\N	PRESENT	0
496170	495106	97011G	PARTICIPANT	\N	PRESENT	0
496171	495106	20128B	PARTICIPANT	\N	PRESENT	0
496172	495106	08047A	PARTICIPANT	\N	PRESENT	0
496173	495106	14059S	PARTICIPANT	\N	PRESENT	0
496174	495106	04035D	PARTICIPANT	\N	PRESENT	0
496175	495106	14133K	PARTICIPANT	\N	PRESENT	0
496176	495106	20042V	PARTICIPANT	\N	PRESENT	0
496177	495106	14105F	PARTICIPANT	\N	PRESENT	0
496178	495106	20064C	PARTICIPANT	\N	PRESENT	0
496179	495106	98018T	PARTICIPANT	\N	PRESENT	0
496180	495106	98022P	PARTICIPANT	\N	PRESENT	0
496181	495106	14267Y	PARTICIPANT	\N	PRESENT	0
496182	495106	11064N	PARTICIPANT	\N	PRESENT	0
496183	495106	14211G	PARTICIPANT	\N	PRESENT	0
496184	495106	17023S	PARTICIPANT	\N	PRESENT	0
496185	495106	14255U	PARTICIPANT	\N	PRESENT	0
496186	495579	20020P	PARTICIPANT	\N	PRESENT	0
496187	495579	20032T	PARTICIPANT	\N	PRESENT	0
496189	495106	14097Y	PARTICIPANT	\N	PRESENT	0
496289	495106	01024M	PARTICIPANT	\N	PRESENT	0
496192	495268	14001X	PARTICIPANT	\N	PRESENT	0
496306	494918	19697Q	PARTICIPANT	\N	PRESENT	0
496308	495106	20072C	PARTICIPANT	\N	PRESENT	0
496195	495268	19675J	PARTICIPANT	\N	PRESENT	0
496196	495268	01028R	PARTICIPANT	\N	PRESENT	0
496197	495268	05008E	PARTICIPANT	\N	PRESENT	0
496198	495268	19447X	PARTICIPANT	\N	PRESENT	0
496199	495268	19489J	PARTICIPANT	\N	PRESENT	0
496307	494918	14217N	PARTICIPANT	\N	PRESENT	0
496201	495268	14147R	PARTICIPANT	\N	PRESENT	0
496309	495106	16685X	PARTICIPANT	\N	PRESENT	0
496315	495038	14327T	PARTICIPANT	\N	PRESENT	0
496316	495038	19667J	PARTICIPANT	\N	PRESENT	0
496205	495268	10015M	PARTICIPANT	\N	PRESENT	0
496253	494946	19768N	PARTICIPANT	\N	PRESENT	0
496254	494946	19515S	PARTICIPANT	\N	PRESENT	0
496208	495268	19725B	PARTICIPANT	\N	PRESENT	0
496209	495268	19729F	PARTICIPANT	\N	PRESENT	0
496210	495268	95063L	PARTICIPANT	\N	PRESENT	0
496317	495038	07029T	PARTICIPANT	\N	PRESENT	0
496318	495038	19335Q	PARTICIPANT	\N	PRESENT	0
496319	495038	19647E	PARTICIPANT	\N	PRESENT	0
496320	495038	12016W	PARTICIPANT	\N	PRESENT	0
496215	495268	14021P	PARTICIPANT	\N	PRESENT	0
496321	495038	14083S	PARTICIPANT	\N	PRESENT	0
496217	495268	08018U	PARTICIPANT	\N	PRESENT	0
496218	495268	11033F	PARTICIPANT	\N	EXCUSE	0
496219	494918	17583W	PARTICIPANT	\N	PRESENT	0
496220	494918	11067R	PARTICIPANT	\N	PRESENT	0
496221	494918	20090E	PARTICIPANT	\N	PRESENT	0
496222	494918	19569H	PARTICIPANT	\N	PRESENT	0
496223	494918	19798U	PARTICIPANT	\N	PRESENT	0
496224	494918	11097X	PARTICIPANT	\N	PRESENT	0
496225	494918	14223L	PARTICIPANT	\N	PRESENT	0
496226	494918	18193Q	PARTICIPANT	\N	PRESENT	0
496227	494918	14026U	PARTICIPANT	\N	PRESENT	0
496228	494918	17779H	PARTICIPANT	\N	PRESENT	0
496229	494918	19703U	PARTICIPANT	\N	PRESENT	0
496230	494918	19966S	PARTICIPANT	\N	PRESENT	0
496231	494918	14281W	PARTICIPANT	\N	PRESENT	0
496232	494918	19679N	PARTICIPANT	\N	PRESENT	0
496233	494918	14042U	PARTICIPANT	\N	PRESENT	0
496392	495120	20052X	PARTICIPANT	\N	PRESENT	0
496235	494918	19367Y	PARTICIPANT	\N	PRESENT	0
496236	494918	14213J	PARTICIPANT	\N	PRESENT	0
496237	494918	10006L	PRESIDENT	0	PRESENT	0
496238	494918	19683J	PARTICIPANT	\N	PRESENT	0
496239	494918	04092N	PARTICIPANT	\N	PRESENT	0
496240	494918	19713W	PARTICIPANT	\N	PRESENT	0
496241	494918	20040T	PARTICIPANT	\N	PRESENT	0
496242	494918	17965H	PARTICIPANT	\N	PRESENT	0
496243	494918	19691J	PARTICIPANT	\N	PRESENT	0
496244	494918	19715Y	PARTICIPANT	\N	PRESENT	0
496245	494918	19723Y	PARTICIPANT	\N	PRESENT	0
496246	494918	20066E	PARTICIPANT	\N	PRESENT	0
496247	494918	11103C	PARTICIPANT	\N	PRESENT	0
496248	494918	14071N	PARTICIPANT	\N	PRESENT	0
496249	494918	04043D	PARTICIPANT	\N	PRESENT	0
496250	494918	19760E	PARTICIPANT	\N	PRESENT	0
496251	494918	19295A	PARTICIPANT	\N	EXCUSE	0
496252	494918	20130U	PARTICIPANT	\N	PRESENT	0
496255	494946	19782L	PARTICIPANT	\N	PRESENT	0
496256	494946	11077T	PARTICIPANT	\N	PRESENT	0
496257	494946	20092G	PARTICIPANT	\N	PRESENT	0
496258	494946	19441R	PARTICIPANT	\N	PRESENT	0
496259	494946	19413M	PARTICIPANT	\N	PRESENT	0
496260	494946	20094J	PARTICIPANT	\N	PRESENT	0
496261	494946	19866P	PARTICIPANT	\N	PRESENT	0
496262	494946	20104S	PARTICIPANT	\N	PRESENT	0
496263	494946	19631V	PARTICIPANT	\N	PRESENT	0
496264	494946	11099A	PARTICIPANT	\N	PRESENT	0
496265	494946	19705W	PARTICIPANT	\N	PRESENT	0
496266	494946	08015R	PARTICIPANT	\N	PRESENT	0
496267	494946	19575F	PARTICIPANT	\N	PRESENT	0
496268	494946	19369B	PARTICIPANT	\N	PRESENT	0
496269	494946	20018V	PARTICIPANT	\N	PRESENT	0
496270	494946	19511N	PARTICIPANT	\N	PRESENT	0
496271	494946	19563B	PARTICIPANT	\N	PRESENT	0
496272	494946	19521Q	PARTICIPANT	\N	PRESENT	0
496273	494946	14038Y	PARTICIPANT	\N	PRESENT	0
496274	494946	19467C	PARTICIPANT	\N	PRESENT	0
496275	494946	14187A	PARTICIPANT	\N	PRESENT	0
496276	494946	19695N	PARTICIPANT	\N	PRESENT	0
496277	494946	11090Q	PRESIDENT	0	PRESENT	0
496278	494946	01025N	PARTICIPANT	\N	PRESENT	0
496279	494946	14033T	PARTICIPANT	\N	PRESENT	0
496280	494946	20054A	PARTICIPANT	\N	PRESENT	0
496281	494946	14205J	PARTICIPANT	\N	PRESENT	0
496282	494946	20060X	PARTICIPANT	\N	PRESENT	0
496283	494946	20062A	PARTICIPANT	\N	PRESENT	0
496284	494946	19507S	PARTICIPANT	\N	PRESENT	0
496285	494946	19747H	PARTICIPANT	\N	PRESENT	0
496286	494946	14207L	PARTICIPANT	\N	PRESENT	0
496287	494946	14257W	PARTICIPANT	\N	PRESENT	0
496288	494946	08028W	PARTICIPANT	\N	EXCUSE	0
496322	495038	19741B	PARTICIPANT	\N	PRESENT	0
496323	495038	11012A	PARTICIPANT	\N	PRESENT	0
496324	495579	20096L	PARTICIPANT	\N	PRESENT	0
496325	495579	05012A	PARTICIPANT	\N	PRESENT	0
496327	495106	19721W	PARTICIPANT	\N	PRESENT	0
496390	495120	12028B	PARTICIPANT	\N	PRESENT	0
496391	495120	98022P	PARTICIPANT	\N	PRESENT	0
496393	495120	14105F	PARTICIPANT	\N	PRESENT	0
496394	495120	20068G	PARTICIPANT	\N	PRESENT	0
496395	495120	20044X	PARTICIPANT	\N	PRESENT	0
496396	495120	86034E	PARTICIPANT	\N	PRESENT	0
496401	495120	20038A	PARTICIPANT	\N	PRESENT	0
496402	495120	20130U	PARTICIPANT	\N	PRESENT	0
496403	495120	14109K	PARTICIPANT	\N	PRESENT	0
496404	495120	20072C	PARTICIPANT	\N	PRESENT	0
496405	495120	20074E	PARTICIPANT	\N	PRESENT	0
496406	495120	20032T	PARTICIPANT	\N	PRESENT	0
496407	495120	20024T	PARTICIPANT	\N	PRESENT	0
496408	495120	19745F	PARTICIPANT	\N	PRESENT	0
496409	495120	20090E	PARTICIPANT	\N	PRESENT	0
496410	495120	20064C	PARTICIPANT	\N	PRESENT	0
496411	495120	14211G	PARTICIPANT	\N	PRESENT	0
496412	495120	14357A	PARTICIPANT	\N	PRESENT	0
496413	495120	20078J	PARTICIPANT	\N	PRESENT	0
496414	495120	19399H	PARTICIPANT	\N	PRESENT	0
496415	495120	14041T	PARTICIPANT	\N	PRESENT	0
496416	495120	08034U	PARTICIPANT	\N	PRESENT	0
496417	495120	19667J	PARTICIPANT	\N	PRESENT	0
496418	495120	07004J	PARTICIPANT	\N	PRESENT	0
496419	495120	20022R	PARTICIPANT	\N	PRESENT	0
496420	495120	14069U	PARTICIPANT	\N	PRESENT	0
496421	495120	20100N	PARTICIPANT	\N	PRESENT	0
496422	495120	20048C	PARTICIPANT	\N	PRESENT	0
496423	495120	19383Y	PARTICIPANT	\N	PRESENT	0
496424	495120	04092N	PARTICIPANT	\N	PRESENT	0
496425	495120	14207L	PARTICIPANT	\N	PRESENT	0
496426	495120	11103C	PARTICIPANT	\N	PRESENT	0
483233	482345	19575F	PARTICIPANT	\N	EXCUSE	0
486039	485907	14213J	PARTICIPANT	\N	EXCUSE	0
489432	489037	11031D	PARTICIPANT	\N	PRESENT	0
489433	489037	19663E	PARTICIPANT	\N	EXCUSE	0
489434	489037	19649G	PARTICIPANT	\N	PRESENT	0
489435	489037	19715Y	PARTICIPANT	\N	PRESENT	0
489436	489037	19683J	PARTICIPANT	\N	PRESENT	0
489437	489037	10006L	PARTICIPANT	\N	PRESENT	0
489438	489037	19697Q	PARTICIPANT	\N	PRESENT	0
489439	489037	11012A	PARTICIPANT	\N	PRESENT	0
489440	489037	11097X	PRESIDENT	0	PRESENT	0
489441	489037	19703U	PARTICIPANT	\N	PRESENT	0
489442	489037	19479G	PARTICIPANT	\N	PRESENT	0
489443	489037	19503N	PARTICIPANT	\N	PRESENT	0
490019	489751	11070L	PARTICIPANT	\N	PRESENT	0
490020	489751	11053K	PARTICIPANT	\N	PRESENT	0
494972	491379	20050V	PARTICIPANT	\N	PRESENT	0
494973	491379	20018V	PARTICIPANT	\N	PRESENT	0
494974	491379	19553Y	PARTICIPANT	\N	PRESENT	0
494975	491379	20132W	PARTICIPANT	\N	PRESENT	0
494976	491379	11040E	PARTICIPANT	\N	PRESENT	0
494977	491379	19651A	PARTICIPANT	\N	PRESENT	0
501968	500284	19723Y	PARTICIPANT	\N	PRESENT	0
501969	500284	14041T	PARTICIPANT	\N	PRESENT	0
501970	500284	07029T	PARTICIPANT	\N	PRESENT	0
501971	500284	19673G	PARTICIPANT	\N	PRESENT	0
501972	500284	19651A	PARTICIPANT	\N	PRESENT	0
501973	500284	95063L	PARTICIPANT	\N	PRESENT	0
501974	500284	19667J	PARTICIPANT	\N	PRESENT	0
501975	500284	20032T	PARTICIPANT	\N	PRESENT	0
501976	500284	14259Y	PARTICIPANT	\N	PRESENT	0
501977	500284	20036X	PARTICIPANT	\N	PRESENT	0
501978	500284	19515S	PARTICIPANT	\N	PRESENT	0
501979	500284	11080N	PARTICIPANT	\N	PRESENT	0
501966	500284	20150Y	PARTICIPANT	\N	PRESENT	0
501967	500284	19663E	PARTICIPANT	\N	PRESENT	0
501980	500284	01057W	PARTICIPANT	\N	PRESENT	0
501981	500284	19643A	PARTICIPANT	\N	PRESENT	0
501982	500284	19553Y	PARTICIPANT	\N	PRESENT	0
501983	500284	04086Q	PARTICIPANT	\N	PRESENT	0
501984	500284	04057K	PARTICIPANT	\N	PRESENT	0
501985	500284	14251Q	PARTICIPANT	\N	PRESENT	0
501986	500284	19563B	PARTICIPANT	\N	PRESENT	0
501987	500284	20050V	PARTICIPANT	\N	PRESENT	0
501988	500284	19347U	PARTICIPANT	\N	PRESENT	0
501989	500284	20078J	PARTICIPANT	\N	PRESENT	0
501990	500284	04071H	PARTICIPANT	\N	PRESENT	0
501991	500284	19711U	PARTICIPANT	\N	PRESENT	0
501992	500284	08010L	PARTICIPANT	\N	PRESENT	0
501993	500284	01028R	PARTICIPANT	\N	PRESENT	0
501994	500284	14026U	PARTICIPANT	\N	PRESENT	0
501995	500284	04035D	PARTICIPANT	\N	PRESENT	0
501996	500284	19703U	PARTICIPANT	\N	PRESENT	0
501997	500284	14225N	PARTICIPANT	\N	PRESENT	0
501998	500284	14229S	PARTICIPANT	\N	PRESENT	0
501999	500284	04059M	PARTICIPANT	\N	PRESENT	0
502000	500284	19415P	PARTICIPANT	\N	PRESENT	0
502001	500284	14021P	PARTICIPANT	\N	PRESENT	0
502002	500284	04033B	PARTICIPANT	\N	PRESENT	0
502003	500284	19647E	PARTICIPANT	\N	PRESENT	0
502004	500284	11097X	PARTICIPANT	\N	PRESENT	0
502005	500284	19649G	PARTICIPANT	\N	PRESENT	0
502006	500284	19531S	PARTICIPANT	\N	PRESENT	0
502007	500284	10006L	PARTICIPANT	\N	PRESENT	0
502008	500284	19533U	PARTICIPANT	\N	PRESENT	0
502009	500284	17965H	PARTICIPANT	\N	PRESENT	0
502010	500284	19798U	PARTICIPANT	\N	PRESENT	0
502011	500284	20080C	PARTICIPANT	\N	PRESENT	0
502012	500284	19367Y	PARTICIPANT	\N	PRESENT	0
502035	500284	19657G	PARTICIPANT	\N	PRESENT	0
502014	500284	20152B	PARTICIPANT	\N	PRESENT	0
502015	500284	14217N	PARTICIPANT	\N	PRESENT	0
502016	500284	07033P	PARTICIPANT	\N	PRESENT	0
502017	500284	20124W	PARTICIPANT	\N	PRESENT	0
502018	500284	14042U	PARTICIPANT	\N	PRESENT	0
502019	500284	20090E	PARTICIPANT	\N	PRESENT	0
502020	500284	19735D	PARTICIPANT	\N	PRESENT	0
502021	500284	11053K	PARTICIPANT	\N	PRESENT	0
502022	500284	19543W	PARTICIPANT	\N	PRESENT	0
502023	500284	18083K	PARTICIPANT	\N	PRESENT	0
502024	500284	11103C	PARTICIPANT	\N	PRESENT	0
502025	500284	08034U	PARTICIPANT	\N	PRESENT	0
502026	500284	14147R	PARTICIPANT	\N	PRESENT	0
502027	500284	04042C	PARTICIPANT	\N	PRESENT	0
502028	500284	11070L	PARTICIPANT	\N	PRESENT	0
502029	500284	14083S	PARTICIPANT	\N	PRESENT	0
502030	500284	14331P	PARTICIPANT	\N	PRESENT	0
502031	500284	11085T	PARTICIPANT	\N	PRESENT	0
502032	500284	19671E	PARTICIPANT	\N	PRESENT	0
502033	500284	01043Q	PARTICIPANT	\N	PRESENT	0
502034	500284	14213J	PARTICIPANT	\N	PRESENT	0
502036	500284	20056C	PARTICIPANT	\N	PRESENT	0
502037	500284	20070A	PARTICIPANT	\N	PRESENT	0
502038	500284	20144B	PARTICIPANT	\N	PRESENT	0
502039	500284	19575F	PARTICIPANT	\N	PRESENT	0
502040	500284	04092N	PARTICIPANT	\N	PRESENT	0
502041	500284	97011G	PARTICIPANT	\N	PRESENT	0
502042	500284	20126Y	PARTICIPANT	\N	PRESENT	0
502043	500284	11090Q	PARTICIPANT	\N	PRESENT	0
502044	500284	19295A	PARTICIPANT	\N	PRESENT	0
502045	500284	20066E	PARTICIPANT	\N	PRESENT	0
502046	500284	11077T	PARTICIPANT	\N	PRESENT	0
502047	500284	11031D	PARTICIPANT	\N	PRESENT	0
502048	500284	17779H	PARTICIPANT	\N	PRESENT	0
502049	500284	12016W	PARTICIPANT	\N	PRESENT	0
502050	500284	14069U	PARTICIPANT	\N	PRESENT	0
502051	500284	14001X	PARTICIPANT	\N	PRESENT	0
502052	500284	11065P	PARTICIPANT	\N	PRESENT	0
502053	500284	11026G	PARTICIPANT	\N	PRESENT	0
502057	500284	19569H	PARTICIPANT	\N	PRESENT	0
502092	500284	17737W	PARTICIPANT	\N	PRESENT	0
502228	500285	12041X	PARTICIPANT	\N	PRESENT	0
502229	500285	10006L	PARTICIPANT	\N	PRESENT	0
502230	500285	01034P	PARTICIPANT	\N	PRESENT	0
502231	500285	11067R	PARTICIPANT	\N	PRESENT	0
502232	500285	11031D	PARTICIPANT	\N	PRESENT	0
502233	500285	19695N	PARTICIPANT	\N	PRESENT	0
502234	500285	14281W	PARTICIPANT	\N	PRESENT	0
502235	500285	17779H	PARTICIPANT	\N	PRESENT	0
502236	500285	19683J	PARTICIPANT	\N	PRESENT	0
502237	500285	20130U	PARTICIPANT	\N	PRESENT	0
502238	500285	19347U	PARTICIPANT	\N	PRESENT	0
502239	500285	19301E	PARTICIPANT	\N	PRESENT	0
502240	500285	17965H	PARTICIPANT	\N	PRESENT	0
502241	500285	14195A	PARTICIPANT	\N	PRESENT	0
502242	500285	04057K	PARTICIPANT	\N	PRESENT	0
502243	500285	19553Y	PARTICIPANT	\N	PRESENT	0
502244	500285	19717B	PARTICIPANT	\N	PRESENT	0
502245	500285	08045X	PARTICIPANT	\N	PRESENT	0
502246	500285	19719D	PARTICIPANT	\N	PRESENT	0
502247	500285	19569H	PARTICIPANT	\N	PRESENT	0
502248	500285	20042V	PARTICIPANT	\N	PRESENT	0
502249	500285	07004J	PARTICIPANT	\N	PRESENT	0
502250	500285	19415P	PARTICIPANT	\N	PRESENT	0
502251	500285	19367Y	PARTICIPANT	\N	PRESENT	0
502252	500285	19798U	PARTICIPANT	\N	PRESENT	0
502253	500285	14071N	PARTICIPANT	\N	PRESENT	0
502254	500285	18193Q	PARTICIPANT	\N	PRESENT	0
502255	500285	04092N	PARTICIPANT	\N	PRESENT	0
502256	500285	19533U	PARTICIPANT	\N	PRESENT	0
502257	500285	11103C	PARTICIPANT	\N	PRESENT	0
502258	500285	14213J	PARTICIPANT	\N	PRESENT	0
502259	500285	14147R	PARTICIPANT	\N	PRESENT	0
502260	500285	17737W	PARTICIPANT	\N	PRESENT	0
502261	500285	19663E	PARTICIPANT	\N	PRESENT	0
502262	500285	19723Y	PARTICIPANT	\N	PRESENT	0
502263	500285	20090E	PARTICIPANT	\N	PRESENT	0
502264	500285	14030Q	PARTICIPANT	\N	PRESENT	0
502265	500285	20124W	PARTICIPANT	\N	PRESENT	0
502266	500285	11077T	PARTICIPANT	\N	PRESENT	0
502268	500285	14083S	PARTICIPANT	\N	PRESENT	0
502269	500285	19657G	PARTICIPANT	\N	PRESENT	0
502270	500285	19575F	PARTICIPANT	\N	PRESENT	0
502271	500285	19715Y	PARTICIPANT	\N	PRESENT	0
502272	500285	19691J	PARTICIPANT	\N	PRESENT	0
502273	500285	04034C	PARTICIPANT	\N	PRESENT	0
502274	500285	20122U	PARTICIPANT	\N	PRESENT	0
502275	500285	11097X	PARTICIPANT	\N	PRESENT	0
502276	500285	11033F	PARTICIPANT	\N	PRESENT	0
502277	500285	20052X	PARTICIPANT	\N	PRESENT	0
502278	500285	20066E	PARTICIPANT	\N	PRESENT	0
502279	500285	14069U	PARTICIPANT	\N	PRESENT	0
502280	500285	19697Q	PARTICIPANT	\N	PRESENT	0
502281	500285	19713W	PARTICIPANT	\N	PRESENT	0
502282	500285	19679N	PARTICIPANT	\N	PRESENT	0
502283	500285	19515S	PARTICIPANT	\N	PRESENT	0
502284	500285	14231L	PARTICIPANT	\N	PRESENT	0
502285	500285	19703U	PARTICIPANT	\N	PRESENT	0
502286	500285	19673G	PARTICIPANT	\N	PRESENT	0
498042	498041	11048N	PARTICIPANT	\N	PRESENT	0
498043	498041	14225N	PARTICIPANT	\N	PRESENT	0
498045	498044	11048N	PARTICIPANT	\N	PRESENT	0
498046	498044	14225N	PARTICIPANT	\N	PRESENT	0
498048	498047	08010L	PARTICIPANT	\N	PRESENT	0
498050	498049	08010L	PARTICIPANT	\N	PRESENT	0
498052	498051	19711U	PARTICIPANT	\N	PRESENT	0
498054	498053	04086Q	PARTICIPANT	\N	PRESENT	0
498056	498055	04086Q	PARTICIPANT	\N	PRESENT	0
498058	498057	19545Y	PARTICIPANT	\N	PRESENT	0
498059	498057	19689Q	PARTICIPANT	\N	PRESENT	0
498062	498061	19545Y	PARTICIPANT	\N	PRESENT	0
498063	498061	19689Q	PARTICIPANT	\N	PRESENT	0
498065	498064	19545Y	PARTICIPANT	\N	PRESENT	0
498066	498064	19689Q	PARTICIPANT	\N	PRESENT	0
498068	498067	19545Y	PARTICIPANT	\N	PRESENT	0
498069	498067	19689Q	PARTICIPANT	\N	PRESENT	0
498071	498070	19667J	PARTICIPANT	\N	PRESENT	0
498072	498070	11040E	PARTICIPANT	\N	PRESENT	0
498074	498073	19545Y	PARTICIPANT	\N	PRESENT	0
498075	498073	19689Q	PARTICIPANT	\N	PRESENT	0
498077	498076	11048N	PARTICIPANT	\N	PRESENT	0
498079	498078	19667J	PARTICIPANT	\N	PRESENT	0
498080	498078	11040E	PARTICIPANT	\N	PRESENT	0
498082	498081	19667J	PARTICIPANT	\N	PRESENT	0
498083	498081	11040E	PARTICIPANT	\N	PRESENT	0
498086	498085	11048N	PARTICIPANT	\N	PRESENT	0
498088	498087	08034U	PARTICIPANT	\N	PRESENT	0
498090	498089	11074Q	PARTICIPANT	\N	PRESENT	0
498091	498089	19349W	PARTICIPANT	\N	PRESENT	0
498093	498092	14189C	PARTICIPANT	\N	PRESENT	0
498095	498094	14189C	PARTICIPANT	\N	PRESENT	0
498097	498096	14189C	PARTICIPANT	\N	PRESENT	0
498099	498098	19741B	PARTICIPANT	\N	PRESENT	0
498101	498100	11048N	PARTICIPANT	\N	PRESENT	0
498103	498102	11048N	PARTICIPANT	\N	PRESENT	0
498104	498102	14225N	PARTICIPANT	\N	PRESENT	0
498106	498105	11048N	PARTICIPANT	\N	PRESENT	0
498107	498105	01057W	PARTICIPANT	\N	PRESENT	0
498108	498105	14225N	PARTICIPANT	\N	PRESENT	0
498110	498109	11048N	PARTICIPANT	\N	PRESENT	0
498111	498109	01057W	PARTICIPANT	\N	PRESENT	0
498112	498109	14225N	PARTICIPANT	\N	PRESENT	0
498223	497172	11070L	PARTICIPANT	\N	PRESENT	0
498224	497671	19725B	PARTICIPANT	\N	PRESENT	0
498225	497671	19954N	PARTICIPANT	\N	PRESENT	0
498226	497671	11056N	PARTICIPANT	\N	PRESENT	0
498227	497671	14069U	PARTICIPANT	\N	PRESENT	0
498228	497671	14259Y	PARTICIPANT	\N	PRESENT	0
498229	497671	19749K	PARTICIPANT	\N	PRESENT	0
498230	497671	04047H	PRESIDENT	0	PRESENT	0
498231	497671	19675J	PARTICIPANT	\N	PRESENT	0
498232	497671	14231L	PARTICIPANT	\N	PRESENT	0
498233	497671	19543W	PARTICIPANT	\N	PRESENT	0
498237	497671	14053L	PARTICIPANT	\N	PRESENT	0
498238	497671	10015M	PARTICIPANT	\N	PRESENT	0
498239	497671	19489J	PARTICIPANT	\N	PRESENT	0
498240	497671	14147R	PARTICIPANT	\N	PRESENT	0
498241	497671	08018U	PARTICIPANT	\N	PRESENT	0
498242	497671	19581D	PARTICIPANT	\N	PRESENT	0
498246	497172	19954N	PARTICIPANT	\N	PRESENT	0
498248	497172	20108W	PARTICIPANT	\N	PRESENT	0
498250	497671	95063L	PARTICIPANT	\N	PRESENT	0
498327	497010	14327T	PARTICIPANT	\N	PRESENT	0
498328	497010	14331P	PARTICIPANT	\N	PRESENT	0
498329	497010	04071H	PARTICIPANT	\N	PRESENT	0
498330	497010	19545Y	PARTICIPANT	\N	PRESENT	0
498331	497010	11097X	PARTICIPANT	\N	PRESENT	0
498332	497010	20080C	PARTICIPANT	\N	PRESENT	0
498333	497010	19667J	PARTICIPANT	\N	PRESENT	0
498334	497010	14225N	PRESIDENT	0	PRESENT	0
498335	497010	19671E	PARTICIPANT	\N	PRESENT	0
498336	497010	19349W	PARTICIPANT	\N	PRESENT	0
498337	497010	08010L	PARTICIPANT	\N	PRESENT	0
498338	497010	20116W	PARTICIPANT	\N	PRESENT	0
498339	497010	19335Q	PARTICIPANT	\N	PRESENT	0
498340	497010	20126Y	PARTICIPANT	\N	PRESENT	0
498341	497010	19479G	PARTICIPANT	\N	PRESENT	0
498342	497010	11048N	PARTICIPANT	\N	PRESENT	0
498343	497010	19647E	PARTICIPANT	\N	PRESENT	0
498344	497010	19711U	PARTICIPANT	\N	PRESENT	0
498345	497010	14189C	PARTICIPANT	\N	PRESENT	0
498346	497010	08034U	PARTICIPANT	\N	PRESENT	0
498347	497010	19531S	PARTICIPANT	\N	PRESENT	0
498348	497010	19689Q	PARTICIPANT	\N	PRESENT	0
498349	497010	04086Q	PARTICIPANT	\N	PRESENT	0
498350	497010	11040E	PARTICIPANT	\N	PRESENT	0
498351	497010	14083S	PARTICIPANT	\N	PRESENT	0
498352	497010	14121F	PARTICIPANT	\N	PRESENT	0
498353	497010	19741B	PARTICIPANT	\N	PRESENT	0
498354	497010	99004R	PARTICIPANT	\N	PRESENT	0
498355	497010	19762G	PARTICIPANT	\N	PRESENT	0
498356	497172	11064N	PARTICIPANT	\N	PRESENT	0
498357	497817	20032T	PARTICIPANT	\N	PRESENT	0
498358	497817	14031R	PARTICIPANT	\N	PRESENT	0
498359	497817	20076G	PARTICIPANT	\N	PRESENT	0
498360	497817	18083K	PARTICIPANT	\N	PRESENT	0
498361	497817	05012A	PARTICIPANT	\N	PRESENT	0
498362	497817	20118Y	PARTICIPANT	\N	PRESENT	0
498363	497817	17367Q	PARTICIPANT	\N	PRESENT	0
498364	497817	20024T	PARTICIPANT	\N	PRESENT	0
498365	497172	19611R	PARTICIPANT	\N	PRESENT	0
498366	497172	14147R	PARTICIPANT	\N	PRESENT	0
498367	497172	11027H	PARTICIPANT	\N	PRESENT	0
498368	497172	19679N	PARTICIPANT	\N	PRESENT	0
498369	497172	19573D	PARTICIPANT	\N	PRESENT	0
498370	497817	19333N	PARTICIPANT	\N	PRESENT	0
498371	497817	19701S	PARTICIPANT	\N	PRESENT	0
498372	497817	20140W	PARTICIPANT	\N	PRESENT	0
498373	497817	19387D	PARTICIPANT	\N	PRESENT	0
498374	497817	19820Y	PARTICIPANT	\N	PRESENT	0
498375	497817	19637C	PARTICIPANT	\N	PRESENT	0
498376	497817	20100N	PARTICIPANT	\N	PRESENT	0
498377	497817	19503N	PARTICIPANT	\N	PRESENT	0
498378	497817	19549D	PARTICIPANT	\N	PRESENT	0
498379	497817	20020P	PARTICIPANT	\N	PRESENT	0
498380	497817	11065P	PARTICIPANT	\N	PRESENT	0
498381	497817	14169X	PARTICIPANT	\N	PRESENT	0
498382	497817	17637T	PARTICIPANT	\N	PRESENT	0
498383	498009	20086J	PARTICIPANT	\N	PRESENT	0
498384	498009	20088L	PARTICIPANT	\N	PRESENT	0
498385	498009	19768N	PARTICIPANT	\N	PRESENT	0
498386	498009	19515S	PARTICIPANT	\N	PRESENT	0
498387	498009	20092G	PARTICIPANT	\N	PRESENT	0
498388	498009	19782L	PARTICIPANT	\N	PRESENT	0
498389	498009	19441R	PARTICIPANT	\N	PRESENT	0
498390	498009	19413M	PARTICIPANT	\N	PRESENT	0
498391	498009	20082E	PARTICIPANT	\N	PRESENT	0
498392	498009	20094J	PARTICIPANT	\N	PRESENT	0
498393	498009	19631V	PARTICIPANT	\N	PRESENT	0
498394	498009	20104S	PARTICIPANT	\N	PRESENT	0
498395	498009	11099A	PARTICIPANT	\N	PRESENT	0
498396	498009	19705W	PARTICIPANT	\N	PRESENT	0
498397	498009	08015R	PARTICIPANT	\N	PRESENT	0
498398	498009	19575F	PARTICIPANT	\N	PRESENT	0
498399	498009	20018V	PARTICIPANT	\N	PRESENT	0
498400	498009	19511N	PARTICIPANT	\N	PRESENT	0
498401	498009	19563B	PARTICIPANT	\N	PRESENT	0
498402	498009	19521Q	PARTICIPANT	\N	PRESENT	0
498403	498009	20028X	PARTICIPANT	\N	PRESENT	0
498404	498009	14329V	PARTICIPANT	\N	PRESENT	0
498405	498009	14038Y	PARTICIPANT	\N	PRESENT	0
498406	498009	19467C	PARTICIPANT	\N	PRESENT	0
498407	498009	14187A	PARTICIPANT	\N	PRESENT	0
498408	498009	20144B	PARTICIPANT	\N	PRESENT	0
498409	498009	19695N	PARTICIPANT	\N	PRESENT	0
498410	498009	11090Q	PRESIDENT	0	PRESENT	0
498411	498009	14033T	PARTICIPANT	\N	PRESENT	0
498412	498009	01025N	PARTICIPANT	\N	PRESENT	0
498413	498009	20054A	PARTICIPANT	\N	PRESENT	0
498414	498009	14205J	PARTICIPANT	\N	PRESENT	0
498415	498009	20060X	PARTICIPANT	\N	PRESENT	0
498416	498009	20062A	PARTICIPANT	\N	PRESENT	0
498417	498009	14251Q	PARTICIPANT	\N	PRESENT	0
498418	498009	19747H	PARTICIPANT	\N	PRESENT	0
498419	498009	14207L	PARTICIPANT	\N	PRESENT	0
498420	498009	14257W	PARTICIPANT	\N	PRESENT	0
498421	497817	19251M	PARTICIPANT	\N	EXCUSE	0
498422	497172	19621T	PARTICIPANT	\N	PRESENT	0
498423	497172	08061X	PARTICIPANT	\N	PRESENT	0
498424	497172	14026U	PARTICIPANT	\N	PRESENT	0
498425	497172	14223L	PARTICIPANT	\N	PRESENT	0
498426	498009	19333N	PARTICIPANT	\N	PRESENT	0
498427	498009	19549D	PARTICIPANT	\N	PRESENT	0
498428	498009	19820Y	PARTICIPANT	\N	PRESENT	0
498429	498009	19826F	PARTICIPANT	\N	PRESENT	0
498430	498009	20020P	PARTICIPANT	\N	PRESENT	0
498431	498009	20022R	PARTICIPANT	\N	PRESENT	0
498432	498009	20024T	PARTICIPANT	\N	PRESENT	0
484564	483276	04085P	PARTICIPANT	\N	PRESENT	0
484591	483672	11040E	PARTICIPANT	\N	EXCUSE	0
484592	483672	11070L	PARTICIPANT	\N	PRESENT	0
484593	483672	19737F	PARTICIPANT	\N	PRESENT	0
484594	483672	14121F	PRESIDENT	0	PRESENT	0
484595	483672	08034U	PARTICIPANT	\N	PRESENT	0
485546	484637	14093U	PARTICIPANT	\N	PRESENT	0
485548	484637	01048V	PRESIDENT	0	PRESENT	0
485552	484637	04043D	PARTICIPANT	\N	PRESENT	0
485554	484637	19533U	PARTICIPANT	\N	PRESENT	0
485557	484637	01058X	PARTICIPANT	\N	PRESENT	0
485562	484637	19723Y	PARTICIPANT	\N	EXCUSE	0
485563	484637	80013X	PARTICIPANT	\N	EXCUSE	0
485564	484637	19693L	PARTICIPANT	\N	EXCUSE	0
488304	487670	19703U	PARTICIPANT	\N	PRESENT	0
488305	487670	19553Y	PARTICIPANT	\N	PRESENT	0
488306	487670	11067R	PARTICIPANT	\N	PRESENT	0
488307	487670	04092N	PRESIDENT	0	PRESENT	0
488308	487670	11097X	PARTICIPANT	\N	PRESENT	0
488309	487670	08052W	PARTICIPANT	\N	PRESENT	0
488310	487670	19715Y	PARTICIPANT	\N	PRESENT	0
488311	487670	19683J	PARTICIPANT	\N	PRESENT	0
488312	487670	10006L	PARTICIPANT	\N	PRESENT	0
488313	487670	19926J	PARTICIPANT	\N	PRESENT	0
488875	488688	19545Y	PARTICIPANT	\N	EXCUSE	0
488876	488688	11031D	PARTICIPANT	\N	PRESENT	0
488877	488688	19663E	PARTICIPANT	\N	EXCUSE	0
488878	488688	10006L	PARTICIPANT	\N	PRESENT	0
488879	488688	19691J	PARTICIPANT	\N	PRESENT	0
488880	488688	14081Q	PARTICIPANT	\N	PRESENT	0
488881	488688	19715Y	PARTICIPANT	\N	PRESENT	0
488882	488688	19683J	PARTICIPANT	\N	PRESENT	0
488883	488688	19447X	PARTICIPANT	\N	PRESENT	0
488884	488688	99004R	PARTICIPANT	\N	PRESENT	0
488885	488688	19697Q	PARTICIPANT	\N	PRESENT	0
488886	488688	19573D	PARTICIPANT	\N	PRESENT	0
488887	488688	19503N	PARTICIPANT	\N	PRESENT	0
488888	488688	14331P	PARTICIPANT	\N	PRESENT	0
488889	488688	19766L	PARTICIPANT	\N	PRESENT	0
488890	488688	11012A	PARTICIPANT	\N	PRESENT	0
488891	488688	11097X	PRESIDENT	0	PRESENT	0
488892	488688	19703U	PARTICIPANT	\N	PRESENT	0
488893	488688	01034P	PARTICIPANT	\N	EXCUSE	0
488894	488688	19479G	PARTICIPANT	\N	PRESENT	0
488895	488688	19349W	PARTICIPANT	\N	PRESENT	0
488896	488689	11031D	PARTICIPANT	\N	EXCUSE	0
488897	488689	19545Y	PARTICIPANT	\N	EXCUSE	0
488898	488689	19663E	PARTICIPANT	\N	EXCUSE	0
488899	488689	01034P	PARTICIPANT	\N	EXCUSE	0
488900	488689	19479G	PARTICIPANT	\N	PRESENT	0
488901	488689	19703U	PARTICIPANT	\N	PRESENT	0
488902	488689	11097X	PRESIDENT	0	PRESENT	0
488903	488689	11012A	PARTICIPANT	\N	PRESENT	0
488904	488689	19766L	PARTICIPANT	\N	PRESENT	0
488905	488689	14331P	PARTICIPANT	\N	PRESENT	0
488906	488689	19573D	PARTICIPANT	\N	PRESENT	0
488907	488689	19697Q	PARTICIPANT	\N	PRESENT	0
488908	488689	99004R	PARTICIPANT	\N	PRESENT	0
488909	488689	19447X	PARTICIPANT	\N	PRESENT	0
488910	488689	19683J	PARTICIPANT	\N	PRESENT	0
488911	488689	19715Y	PARTICIPANT	\N	PRESENT	0
488912	488689	14081Q	PARTICIPANT	\N	PRESENT	0
488913	488689	19691J	PARTICIPANT	\N	PRESENT	0
488914	488689	10006L	PARTICIPANT	\N	PRESENT	0
488915	488689	14041T	PARTICIPANT	\N	PRESENT	0
488916	488689	19503N	PARTICIPANT	\N	PRESENT	0
488917	488689	19643A	PARTICIPANT	\N	PRESENT	0
490490	490476	14033T	PARTICIPANT	\N	PRESENT	0
490491	490476	20090E	PARTICIPANT	\N	PRESENT	0
490492	490476	17229F	PARTICIPANT	\N	PRESENT	0
490493	490476	14097Y	PARTICIPANT	\N	PRESENT	0
490494	490476	19673G	PARTICIPANT	\N	PRESENT	0
490495	490476	19569H	PARTICIPANT	\N	PRESENT	0
490496	490476	08047A	PARTICIPANT	\N	PRESENT	0
490497	490476	19703U	PARTICIPANT	\N	PRESENT	0
490498	490476	11101A	PARTICIPANT	\N	PRESENT	0
490499	490476	20124W	PARTICIPANT	\N	PRESENT	0
490500	490476	20032T	PARTICIPANT	\N	PRESENT	0
490501	490476	20044X	PARTICIPANT	\N	PRESENT	0
490502	490476	19563B	PARTICIPANT	\N	PRESENT	0
490503	490476	11074Q	PARTICIPANT	\N	PRESENT	0
490504	490476	20126Y	PARTICIPANT	\N	PRESENT	0
490505	490476	98022P	PARTICIPANT	\N	PRESENT	0
490506	490476	12028B	PARTICIPANT	\N	PRESENT	0
490507	490476	11045K	PARTICIPANT	\N	PRESENT	0
490508	490476	19575F	PARTICIPANT	\N	PRESENT	0
490509	490476	04059M	PARTICIPANT	\N	PRESENT	0
490510	490476	19511N	PARTICIPANT	\N	PRESENT	0
490511	490476	11103C	PARTICIPANT	\N	PRESENT	0
490512	490476	20088L	PARTICIPANT	\N	PRESENT	0
490513	490476	19387D	PARTICIPANT	\N	PRESENT	0
490514	490476	19717B	PARTICIPANT	\N	PRESENT	0
490515	490476	18083K	PARTICIPANT	\N	PRESENT	0
490516	490476	20098N	PARTICIPANT	\N	PRESENT	0
490517	490476	20084G	PARTICIPANT	\N	PRESENT	0
490518	490476	14257W	PARTICIPANT	\N	PRESENT	0
490519	490476	20114U	PARTICIPANT	\N	PRESENT	0
490520	490476	12041X	PARTICIPANT	\N	PRESENT	0
490521	490476	14225N	PARTICIPANT	\N	PRESENT	0
490522	490476	20150Y	PARTICIPANT	\N	PRESENT	0
490523	490476	20130U	PARTICIPANT	\N	PRESENT	0
490524	490476	20074E	PARTICIPANT	\N	PRESENT	0
490525	490476	08045X	PARTICIPANT	\N	PRESENT	0
490526	490476	19629C	PARTICIPANT	\N	PRESENT	0
490527	490476	19719D	PARTICIPANT	\N	PRESENT	0
490528	490476	14107H	PARTICIPANT	\N	PRESENT	0
490529	490476	01043Q	PARTICIPANT	\N	PRESENT	0
490530	490476	19713W	PARTICIPANT	\N	PRESENT	0
490531	490476	19441R	PARTICIPANT	\N	PRESENT	0
490532	490476	20052X	PARTICIPANT	\N	PRESENT	0
490533	490476	14179A	PARTICIPANT	\N	PRESENT	0
490534	490476	11031D	PARTICIPANT	\N	PRESENT	0
490535	490476	19649G	PARTICIPANT	\N	PRESENT	0
490536	490476	14030Q	PARTICIPANT	\N	PRESENT	0
490537	490476	17737W	PARTICIPANT	\N	PRESENT	0
490538	490476	17779H	PARTICIPANT	\N	PRESENT	0
490548	490476	20082E	PARTICIPANT	\N	PRESENT	0
490540	490476	19301E	PARTICIPANT	\N	PRESENT	0
490541	490476	08073C	PARTICIPANT	\N	PRESENT	0
490542	490476	19349W	PARTICIPANT	\N	PRESENT	0
490543	490476	19651A	PARTICIPANT	\N	PRESENT	0
490544	490476	20142Y	PARTICIPANT	\N	PRESENT	0
490545	490476	20134Y	PARTICIPANT	\N	PRESENT	0
490546	490476	19599P	PARTICIPANT	\N	PRESENT	0
490547	490476	11067R	PARTICIPANT	\N	PRESENT	0
490549	490476	01028R	PARTICIPANT	\N	PRESENT	0
490550	490476	11053K	PARTICIPANT	\N	PRESENT	0
490551	490476	11070L	PARTICIPANT	\N	PRESENT	0
490552	490476	11027H	PARTICIPANT	\N	PRESENT	0
490553	490476	04085P	PARTICIPANT	\N	PRESENT	0
490554	490476	20048C	PARTICIPANT	\N	PRESENT	0
490555	490476	08061X	PARTICIPANT	\N	PRESENT	0
490556	490476	11012A	PARTICIPANT	\N	PRESENT	0
490557	490476	20050V	PARTICIPANT	\N	PRESENT	0
490558	490476	19745F	PARTICIPANT	\N	PRESENT	0
490559	490476	19699S	PARTICIPANT	\N	PRESENT	0
490560	490476	14231L	PARTICIPANT	\N	PRESENT	0
490561	490476	19521Q	PARTICIPANT	\N	PRESENT	0
490562	490476	20046A	PARTICIPANT	\N	PRESENT	0
490563	490476	11040E	PARTICIPANT	\N	PRESENT	0
490564	490476	11033F	PARTICIPANT	\N	PRESENT	0
490565	490476	11056N	PARTICIPANT	\N	PRESENT	0
490566	490476	19760E	PARTICIPANT	\N	PRESENT	0
490567	490476	19695N	PARTICIPANT	\N	PRESENT	0
490568	490476	19565D	PARTICIPANT	\N	PRESENT	0
490569	490476	19347U	PARTICIPANT	\N	PRESENT	0
490570	490476	19758L	PARTICIPANT	\N	PRESENT	0
490571	490476	19593H	PARTICIPANT	\N	PRESENT	0
490572	490476	19687N	PARTICIPANT	\N	PRESENT	0
490573	490476	19413M	PARTICIPANT	\N	PRESENT	0
490574	490476	19251M	PARTICIPANT	\N	PRESENT	0
490575	490476	20030R	PARTICIPANT	\N	PRESENT	0
490576	490476	19503N	PARTICIPANT	\N	PRESENT	0
490577	490476	20100N	PARTICIPANT	\N	PRESENT	0
490578	490476	11066Q	PARTICIPANT	\N	PRESENT	0
490579	490476	19820Y	PARTICIPANT	\N	PRESENT	0
490580	490476	19715Y	PARTICIPANT	\N	PRESENT	0
490581	490476	14151M	PARTICIPANT	\N	PRESENT	0
490582	490476	20110Q	PARTICIPANT	\N	PRESENT	0
490583	490476	14001X	PARTICIPANT	\N	PRESENT	0
490584	490476	19333N	PARTICIPANT	\N	PRESENT	0
490585	490476	19725B	PARTICIPANT	\N	PRESENT	0
490586	490476	19631V	PARTICIPANT	\N	PRESENT	0
490587	490476	14109K	PARTICIPANT	\N	PRESENT	0
490588	490476	20094J	PARTICIPANT	\N	PRESENT	0
490589	490476	19329S	PARTICIPANT	\N	PRESENT	0
496427	495120	14329V	PARTICIPANT	\N	PRESENT	0
496428	495120	14107H	PARTICIPANT	\N	PRESENT	0
496429	495120	14187A	PARTICIPANT	\N	PRESENT	0
496430	495120	19866P	PARTICIPANT	\N	PRESENT	0
496431	495120	20106U	PARTICIPANT	\N	PRESENT	0
496432	495120	11101A	PARTICIPANT	\N	PRESENT	0
496433	495120	19701S	PARTICIPANT	\N	PRESENT	0
496434	495120	11064N	PARTICIPANT	\N	PRESENT	0
496435	495120	14331P	PARTICIPANT	\N	PRESENT	0
496436	495120	20076G	PARTICIPANT	\N	PRESENT	0
496437	495120	14257W	PARTICIPANT	\N	PRESENT	0
496438	495120	14021P	PARTICIPANT	\N	PRESENT	0
496439	495120	19647E	PARTICIPANT	\N	PRESENT	0
496440	495120	14151M	PARTICIPANT	\N	PRESENT	0
496441	495120	20084G	PARTICIPANT	\N	PRESENT	0
496442	495120	18193Q	PARTICIPANT	\N	PRESENT	0
496443	495120	19687N	PARTICIPANT	\N	PRESENT	0
496444	495120	11056N	PARTICIPANT	\N	PRESENT	0
496445	495120	19758L	PARTICIPANT	\N	PRESENT	0
496446	495120	12041X	PARTICIPANT	\N	PRESENT	0
496447	495120	04085P	PARTICIPANT	\N	PRESENT	0
496448	495120	19695N	PARTICIPANT	\N	PRESENT	0
496449	495120	19565D	PARTICIPANT	\N	PRESENT	0
496450	495120	20134Y	PARTICIPANT	\N	PRESENT	0
496451	495120	20142Y	PARTICIPANT	\N	PRESENT	0
496452	495120	08061X	PARTICIPANT	\N	PRESENT	0
496453	495120	19329S	PARTICIPANT	\N	PRESENT	0
496454	495120	19349W	PARTICIPANT	\N	PRESENT	0
496455	495120	19591F	PARTICIPANT	\N	PRESENT	0
496459	495120	14123H	PARTICIPANT	\N	PRESENT	0
496462	495120	04086Q	PARTICIPANT	\N	PRESENT	0
496458	495120	19651A	PARTICIPANT	\N	PRESENT	0
496460	495120	19629C	PARTICIPANT	\N	PRESENT	0
496461	495120	04035D	PARTICIPANT	\N	PRESENT	0
496463	495120	19747H	PARTICIPANT	\N	PRESENT	0
496464	495120	04042C	PARTICIPANT	\N	PRESENT	0
496465	495120	08069G	PARTICIPANT	\N	PRESENT	0
496466	495120	17367Q	PARTICIPANT	\N	PRESENT	0
496467	495120	19387D	PARTICIPANT	\N	PRESENT	0
496468	495120	11043H	PARTICIPANT	\N	PRESENT	0
496469	495120	04033B	PARTICIPANT	\N	PRESENT	0
496470	495120	05008E	PARTICIPANT	\N	PRESENT	0
496471	495120	20042V	PARTICIPANT	\N	PRESENT	0
496472	495120	11080N	PARTICIPANT	\N	PRESENT	0
496473	495120	19441R	PARTICIPANT	\N	PRESENT	0
496474	495120	18083K	PARTICIPANT	\N	PRESENT	0
496475	495120	19479G	PARTICIPANT	\N	PRESENT	0
496476	495120	19749K	PARTICIPANT	\N	PRESENT	0
496477	495120	19543W	PARTICIPANT	\N	PRESENT	0
496478	495120	01057W	PARTICIPANT	\N	PRESENT	0
496479	495120	11070L	PARTICIPANT	\N	PRESENT	0
496480	495120	19347U	PARTICIPANT	\N	PRESENT	0
496481	495120	14089Y	PARTICIPANT	\N	PRESENT	0
496482	495120	20066E	PARTICIPANT	\N	PRESENT	0
496483	495120	19611R	PARTICIPANT	\N	PRESENT	0
496484	495120	19671E	PARTICIPANT	\N	PRESENT	0
496485	495120	14231L	PARTICIPANT	\N	PRESENT	0
496486	495120	17229F	PARTICIPANT	\N	PRESENT	0
496487	495120	19798U	PARTICIPANT	\N	PRESENT	0
496488	495120	14030Q	PARTICIPANT	\N	PRESENT	0
496489	495120	19569H	PARTICIPANT	\N	PRESENT	0
496490	495120	16685X	PARTICIPANT	\N	PRESENT	0
496491	495120	19826F	PARTICIPANT	\N	PRESENT	0
496492	495120	14255U	PARTICIPANT	\N	PRESENT	0
496493	495120	20040T	PARTICIPANT	\N	PRESENT	0
496494	495120	11085T	PARTICIPANT	\N	PRESENT	0
496495	495120	14327T	PARTICIPANT	\N	PRESENT	0
496496	495120	19413M	PARTICIPANT	\N	PRESENT	0
496497	495120	19820Y	PARTICIPANT	\N	PRESENT	0
496498	495120	19649G	PARTICIPANT	\N	PRESENT	0
496499	495120	11045K	PARTICIPANT	\N	PRESENT	0
496500	495120	01028R	PARTICIPANT	\N	PRESENT	0
496501	495120	19575F	PARTICIPANT	\N	PRESENT	0
496502	495120	14225N	PARTICIPANT	\N	PRESENT	0
496503	495120	14071N	PARTICIPANT	\N	PRESENT	0
496504	495120	12016W	PARTICIPANT	\N	PRESENT	0
496505	495120	11074Q	PARTICIPANT	\N	PRESENT	0
496506	495120	19631V	PARTICIPANT	\N	PRESENT	0
496507	495120	19489J	PARTICIPANT	\N	PRESENT	0
496508	495120	19954N	PARTICIPANT	\N	PRESENT	0
496509	495120	14229S	PARTICIPANT	\N	PRESENT	0
496510	495120	17965H	PARTICIPANT	\N	PRESENT	0
496511	495120	19683J	PARTICIPANT	\N	PRESENT	0
496512	495120	20140W	PARTICIPANT	\N	PRESENT	0
496513	495120	20114U	PARTICIPANT	\N	PRESENT	0
496514	495120	08017T	PARTICIPANT	\N	PRESENT	0
496515	495120	17583W	PARTICIPANT	\N	PRESENT	0
496516	495120	97011G	PARTICIPANT	\N	PRESENT	0
496517	495120	11097X	PARTICIPANT	\N	PRESENT	0
496518	495120	20018V	PARTICIPANT	\N	PRESENT	0
496519	495120	20060X	PARTICIPANT	\N	PRESENT	0
496520	495120	14217N	PARTICIPANT	\N	PRESENT	0
496521	495120	11067R	PARTICIPANT	\N	PRESENT	0
496522	495120	14038Y	PARTICIPANT	\N	PRESENT	0
496523	495120	19503N	PARTICIPANT	\N	PRESENT	0
496524	495120	19467C	PARTICIPANT	\N	PRESENT	0
496525	495120	14033T	PARTICIPANT	\N	PRESENT	0
496526	495120	14121F	PARTICIPANT	\N	PRESENT	0
496527	495120	01048V	PARTICIPANT	\N	PRESENT	0
496528	495120	11083R	PARTICIPANT	\N	PRESENT	0
496529	495120	20128B	PARTICIPANT	\N	PRESENT	0
496530	495120	14073Q	PARTICIPANT	\N	PRESENT	0
496581	495120	19515S	PARTICIPANT	\N	PRESENT	0
496532	495120	01034P	PARTICIPANT	\N	PRESENT	0
496533	495120	20080C	PARTICIPANT	\N	PRESENT	0
496534	495120	19599P	PARTICIPANT	\N	PRESENT	0
496535	495120	14169X	PARTICIPANT	\N	PRESENT	0
496536	495120	20112S	PARTICIPANT	\N	PRESENT	0
496537	495120	14026U	PARTICIPANT	\N	PRESENT	0
496538	495120	19741B	PARTICIPANT	\N	PRESENT	0
496539	495120	08015R	PARTICIPANT	\N	PRESENT	0
496540	495120	07029T	PARTICIPANT	\N	PRESENT	0
496541	495120	19369B	PARTICIPANT	\N	PRESENT	0
496542	495120	20026V	PARTICIPANT	\N	PRESENT	0
496543	495120	20056C	PARTICIPANT	\N	PRESENT	0
496544	495120	20124W	PARTICIPANT	\N	PRESENT	0
496545	495120	14215L	PARTICIPANT	\N	PRESENT	0
496546	495120	20132W	PARTICIPANT	\N	PRESENT	0
496547	495120	20104S	PARTICIPANT	\N	PRESENT	0
496548	495120	11065P	PARTICIPANT	\N	PRESENT	0
496549	495120	19643A	PARTICIPANT	\N	PRESENT	0
496550	495120	14031R	PARTICIPANT	\N	PRESENT	0
496551	495120	08012N	PARTICIPANT	\N	PRESENT	0
496552	495120	14147R	PARTICIPANT	\N	PRESENT	0
496553	495120	19531S	PARTICIPANT	\N	PRESENT	0
496554	495120	19663E	PARTICIPANT	\N	PRESENT	0
496555	495120	19553Y	PARTICIPANT	\N	PRESENT	0
496556	495120	20152B	PARTICIPANT	\N	PRESENT	0
496557	495120	19333N	PARTICIPANT	\N	PRESENT	0
496558	495120	11053K	PARTICIPANT	\N	PRESENT	0
496559	495120	19621T	PARTICIPANT	\N	PRESENT	0
496560	495120	19367Y	PARTICIPANT	\N	PRESENT	0
496561	495120	04071H	PARTICIPANT	\N	PRESENT	0
496562	495120	19507S	PARTICIPANT	\N	PRESENT	0
496563	495120	14251Q	PARTICIPANT	\N	PRESENT	0
496564	495120	19762G	PARTICIPANT	\N	PRESENT	0
496565	495120	20082E	PARTICIPANT	\N	PRESENT	0
496566	495120	17023S	PARTICIPANT	\N	PRESENT	0
496567	495120	20110Q	PARTICIPANT	\N	PRESENT	0
496586	495120	20062A	PARTICIPANT	\N	PRESENT	0
496569	495120	14219Q	PARTICIPANT	\N	PRESENT	0
496570	495120	14097Y	PARTICIPANT	\N	PRESENT	0
496571	495120	19669L	PARTICIPANT	\N	PRESENT	0
496572	495120	04043D	PARTICIPANT	\N	PRESENT	0
496573	495120	10006L	PARTICIPANT	\N	PRESENT	0
496574	495120	14179A	PARTICIPANT	\N	PRESENT	0
496575	495120	14213J	PARTICIPANT	\N	PRESENT	0
496576	495120	14001X	PARTICIPANT	\N	PRESENT	0
496577	495120	04047H	PARTICIPANT	\N	PRESENT	0
496578	495120	20138D	PARTICIPANT	\N	PRESENT	0
496579	495120	19966S	PARTICIPANT	\N	PRESENT	0
496580	495120	20086J	PARTICIPANT	\N	PRESENT	0
496582	495120	17737W	PARTICIPANT	\N	PRESENT	0
496583	495120	08018U	PARTICIPANT	\N	PRESENT	0
496584	495120	19533U	PARTICIPANT	\N	PRESENT	0
496585	495120	07033P	PARTICIPANT	\N	PRESENT	0
496587	495120	08010L	PARTICIPANT	\N	PRESENT	0
496588	495120	14083S	PARTICIPANT	\N	PRESENT	0
496589	495120	04059M	PARTICIPANT	\N	PRESENT	0
496590	495120	04070G	PARTICIPANT	\N	PRESENT	0
496591	495120	19699S	PARTICIPANT	\N	PRESENT	0
496595	495120	20126Y	PARTICIPANT	\N	PRESENT	0
496593	495120	19693L	PARTICIPANT	\N	PRESENT	0
496594	495120	20054A	PARTICIPANT	\N	PRESENT	0
483169	481128	14073Q	PARTICIPANT	\N	PRESENT	0
483170	481128	14237S	PARTICIPANT	\N	PRESENT	0
483171	481128	98035U	PARTICIPANT	\N	PRESENT	0
483172	481129	96004D	PARTICIPANT	\N	PRESENT	0
483173	481129	14357A	PARTICIPANT	\N	PRESENT	0
483174	481129	19563B	PARTICIPANT	\N	PRESENT	0
483175	481129	14135M	PARTICIPANT	\N	PRESENT	0
483176	481129	14331P	PARTICIPANT	\N	PRESENT	0
483177	481129	10015M	PARTICIPANT	\N	PRESENT	0
483178	481129	11026G	PARTICIPANT	\N	PRESENT	0
483179	481129	14241N	PARTICIPANT	\N	PRESENT	0
483180	481129	14237S	PARTICIPANT	\N	PRESENT	0
483181	481129	98035U	PARTICIPANT	\N	PRESENT	0
483182	481129	04097T	PARTICIPANT	\N	PRESENT	0
483183	481129	14033T	PARTICIPANT	\N	PRESENT	0
483184	481129	14205J	PARTICIPANT	\N	PRESENT	0
483192	480811	14267Y	PARTICIPANT	\N	PRESENT	0
483201	480811	14039A	PARTICIPANT	\N	PRESENT	0
483216	480811	95067Q	PARTICIPANT	\N	PRESENT	0
483234	480811	19629C	PARTICIPANT	\N	PRESENT	0
483235	480811	19695N	PARTICIPANT	\N	PRESENT	0
483407	482345	19619A	PARTICIPANT	\N	EXCUSE	0
483433	482345	14071N	PARTICIPANT	\N	EXCUSE	0
486935	485907	19820Y	PARTICIPANT	\N	EXCUSE	0
489809	489808	19447X	PARTICIPANT	\N	PRESENT	0
489811	489810	19447X	PARTICIPANT	\N	PRESENT	0
489812	489810	11026G	PARTICIPANT	\N	PRESENT	0
489814	489813	19447X	PARTICIPANT	\N	PRESENT	0
490075	490017	19593H	PARTICIPANT	\N	PRESENT	0
490076	490017	04070G	PARTICIPANT	\N	PRESENT	0
490077	489939	11083R	PARTICIPANT	\N	PRESENT	0
490078	489933	19693L	PARTICIPANT	\N	PRESENT	0
490079	489933	19593H	PARTICIPANT	\N	PRESENT	0
490080	489933	19533U	PARTICIPANT	\N	PRESENT	0
490081	489933	19611R	PARTICIPANT	\N	PRESENT	0
490082	489933	14229S	PARTICIPANT	\N	PRESENT	0
490083	489933	14109K	PARTICIPANT	\N	PRESENT	0
493317	493315	19691J	PARTICIPANT	\N	PRESENT	0
493318	493315	14071N	PARTICIPANT	\N	PRESENT	0
493319	493316	14071N	PARTICIPANT	\N	PRESENT	0
495428	495427	19367Y	PARTICIPANT	\N	PRESENT	0
495429	495427	19569H	PARTICIPANT	\N	PRESENT	0
495431	495430	05008E	PARTICIPANT	\N	PRESENT	0
495432	495430	11053K	PARTICIPANT	\N	PRESENT	0
495433	495430	01028R	PARTICIPANT	\N	PRESENT	0
497995	497993	19703U	PARTICIPANT	\N	PRESENT	0
497996	497994	19703U	PARTICIPANT	\N	PRESENT	0
497997	497994	14195A	PARTICIPANT	\N	PRESENT	0
502295	500285	04033B	PARTICIPANT	\N	PRESENT	0
502297	500285	17367Q	PARTICIPANT	\N	PRESENT	0
502298	500285	20082E	PARTICIPANT	\N	PRESENT	0
502299	500285	11090Q	PARTICIPANT	\N	PRESENT	0
502301	500285	20106U	PARTICIPANT	\N	PRESENT	0
502304	500285	14042U	PARTICIPANT	\N	PRESENT	0
502305	500285	11045K	PARTICIPANT	\N	PRESENT	0
502306	500285	19599P	PARTICIPANT	\N	PRESENT	0
502307	500285	04043D	PARTICIPANT	\N	PRESENT	0
502308	500285	19711U	PARTICIPANT	\N	PRESENT	0
502314	500285	20126Y	PARTICIPANT	\N	PRESENT	0
502317	500285	19758L	PARTICIPANT	\N	PRESENT	0
502320	500285	14026U	PARTICIPANT	\N	PRESENT	0
502339	500285	19531S	PARTICIPANT	\N	PRESENT	0
502417	502415	11104D	PARTICIPANT	\N	PRESENT	0
502425	500285	14021P	PARTICIPANT	\N	PRESENT	0
502428	500285	14053L	PARTICIPANT	\N	PRESENT	0
502445	500285	19760E	PARTICIPANT	\N	PRESENT	0
502516	500286	01034P	PARTICIPANT	\N	PRESENT	0
502517	500286	19367Y	PARTICIPANT	\N	PRESENT	0
502518	500286	19663E	PARTICIPANT	\N	PRESENT	0
502519	500286	20090E	PARTICIPANT	\N	PRESENT	0
502520	500286	19760E	PARTICIPANT	\N	PRESENT	0
502521	500286	11031D	PARTICIPANT	\N	PRESENT	0
502522	500286	19695N	PARTICIPANT	\N	PRESENT	0
502523	500286	18193Q	PARTICIPANT	\N	PRESENT	0
502524	500286	11067R	PARTICIPANT	\N	PRESENT	0
502525	500286	19715Y	PARTICIPANT	\N	PRESENT	0
502526	500286	14281W	PARTICIPANT	\N	PRESENT	0
502527	500286	17965H	PARTICIPANT	\N	PRESENT	0
502528	500286	19683J	PARTICIPANT	\N	PRESENT	0
502529	500286	20130U	PARTICIPANT	\N	PRESENT	0
502530	500286	19347U	PARTICIPANT	\N	PRESENT	0
502531	500286	19651A	PARTICIPANT	\N	PRESENT	0
502532	500286	19697Q	PARTICIPANT	\N	PRESENT	0
502533	500286	19301E	PARTICIPANT	\N	PRESENT	0
502534	500286	20106U	PARTICIPANT	\N	PRESENT	0
502535	500286	19553Y	PARTICIPANT	\N	PRESENT	0
502536	500286	19717B	PARTICIPANT	\N	PRESENT	0
502537	500286	20122U	PARTICIPANT	\N	PRESENT	0
502538	500286	19691J	PARTICIPANT	\N	PRESENT	0
502539	500286	07004J	PARTICIPANT	\N	PRESENT	0
502540	500286	19415P	PARTICIPANT	\N	PRESENT	0
502541	500286	17779H	PARTICIPANT	\N	PRESENT	0
502542	500286	14071N	PARTICIPANT	\N	PRESENT	0
502543	500286	11065P	PARTICIPANT	\N	PRESENT	0
502544	500286	20086J	PARTICIPANT	\N	PRESENT	0
502545	500286	14026U	PARTICIPANT	\N	PRESENT	0
502546	500286	11097X	PARTICIPANT	\N	PRESENT	0
502547	500286	14217N	PARTICIPANT	\N	PRESENT	0
502548	500286	17737W	PARTICIPANT	\N	PRESENT	0
502549	500286	14213J	PARTICIPANT	\N	PRESENT	0
502550	500286	19657G	PARTICIPANT	\N	PRESENT	0
502551	500286	19711U	PARTICIPANT	\N	PRESENT	0
502552	500286	19798U	PARTICIPANT	\N	PRESENT	0
502553	500286	04092N	PARTICIPANT	\N	PRESENT	0
502554	500286	19703U	PARTICIPANT	\N	PRESENT	0
502555	500286	19758L	PARTICIPANT	\N	PRESENT	0
502556	500286	08045X	PARTICIPANT	\N	PRESENT	0
502557	500286	19569H	PARTICIPANT	\N	PRESENT	0
502558	500286	19713W	PARTICIPANT	\N	PRESENT	0
502559	500286	19679N	PARTICIPANT	\N	PRESENT	0
502560	500286	20066E	PARTICIPANT	\N	PRESENT	0
502561	500286	14042U	PARTICIPANT	\N	PRESENT	0
502562	500286	20126Y	PARTICIPANT	\N	PRESENT	0
502563	500286	19575F	PARTICIPANT	\N	PRESENT	0
502564	500286	20034V	PARTICIPANT	\N	PRESENT	0
502565	500286	11077T	PARTICIPANT	\N	PRESENT	0
502566	500286	04085P	PARTICIPANT	\N	PRESENT	0
502567	500286	19531S	PARTICIPANT	\N	PRESENT	0
502568	500286	19591F	PARTICIPANT	\N	PRESENT	0
502569	500286	20082E	PARTICIPANT	\N	PRESENT	0
502570	500286	19723Y	PARTICIPANT	\N	PRESENT	0
502571	500286	04043D	PARTICIPANT	\N	PRESENT	0
502572	500286	14030Q	PARTICIPANT	\N	PRESENT	0
502293	500285	14217N	PARTICIPANT	\N	PRESENT	0
502294	500285	14357A	PARTICIPANT	\N	PRESENT	0
502573	500286	01028R	PARTICIPANT	\N	PRESENT	0
502587	500287	99004R	PARTICIPANT	\N	PRESENT	0
502514	500286	19719D	PARTICIPANT	\N	PRESENT	0
502515	500286	10006L	PARTICIPANT	\N	PRESENT	0
502589	500287	04092N	PARTICIPANT	\N	PRESENT	0
502590	500287	19760E	PARTICIPANT	\N	PRESENT	0
502591	500287	10006L	PARTICIPANT	\N	PRESENT	0
502592	500287	14041T	PARTICIPANT	\N	PRESENT	0
502593	500287	01034P	PARTICIPANT	\N	PRESENT	0
502594	500287	08045X	PARTICIPANT	\N	PRESENT	0
502595	500287	20130U	PARTICIPANT	\N	PRESENT	0
502596	500287	19657G	PARTICIPANT	\N	PRESENT	0
502597	500287	11067R	PARTICIPANT	\N	PRESENT	0
502598	500287	20090E	PARTICIPANT	\N	PRESENT	0
502599	500287	18193Q	PARTICIPANT	\N	PRESENT	0
502600	500287	19683J	PARTICIPANT	\N	PRESENT	0
502601	500287	20126Y	PARTICIPANT	\N	PRESENT	0
502602	500287	17965H	PARTICIPANT	\N	PRESENT	0
502603	500287	19301E	PARTICIPANT	\N	PRESENT	0
502604	500287	19367Y	PARTICIPANT	\N	PRESENT	0
502605	500287	19697Q	PARTICIPANT	\N	PRESENT	0
502606	500287	19798U	PARTICIPANT	\N	PRESENT	0
502607	500287	19569H	PARTICIPANT	\N	PRESENT	0
502608	500287	19415P	PARTICIPANT	\N	PRESENT	0
502609	500287	19691J	PARTICIPANT	\N	PRESENT	0
502610	500287	14071N	PARTICIPANT	\N	PRESENT	0
502611	500287	07004J	PARTICIPANT	\N	PRESENT	0
502612	500287	19515S	PARTICIPANT	\N	PRESENT	0
502613	500287	14042U	PARTICIPANT	\N	PRESENT	0
502614	500287	17779H	PARTICIPANT	\N	PRESENT	0
502615	500287	19679N	PARTICIPANT	\N	PRESENT	0
502616	500287	04057K	PARTICIPANT	\N	PRESENT	0
502617	500287	19711U	PARTICIPANT	\N	PRESENT	0
502618	500287	19723Y	PARTICIPANT	\N	PRESENT	0
502619	500287	14217N	PARTICIPANT	\N	PRESENT	0
502620	500287	14213J	PARTICIPANT	\N	PRESENT	0
502621	500287	11103C	PARTICIPANT	\N	PRESENT	0
502622	500287	11097X	PARTICIPANT	\N	PRESENT	0
502623	500287	19703U	PARTICIPANT	\N	PRESENT	0
502628	500287	19663E	PARTICIPANT	\N	PRESENT	0
502626	500287	19695N	PARTICIPANT	\N	PRESENT	0
502627	500287	11031D	PARTICIPANT	\N	PRESENT	0
502629	500287	20152B	PARTICIPANT	\N	PRESENT	0
498433	498009	11065P	PARTICIPANT	\N	PRESENT	0
498434	498009	20032T	PARTICIPANT	\N	PRESENT	0
498435	498009	20038A	PARTICIPANT	\N	PRESENT	0
498436	498009	19701S	PARTICIPANT	\N	PRESENT	0
498437	498009	14357A	PARTICIPANT	\N	PRESENT	0
498438	498009	20076G	PARTICIPANT	\N	PRESENT	0
498439	498009	19387D	PARTICIPANT	\N	PRESENT	0
498440	498009	19637C	PARTICIPANT	\N	PRESENT	0
498441	498009	18083K	PARTICIPANT	\N	PRESENT	0
498442	498009	05012A	PARTICIPANT	\N	PRESENT	0
498443	498009	20106U	PARTICIPANT	\N	PRESENT	0
498444	498009	20118Y	PARTICIPANT	\N	PRESENT	0
498445	498009	17367Q	PARTICIPANT	\N	PRESENT	0
498446	498009	17637T	PARTICIPANT	\N	PRESENT	0
498447	498009	20140W	PARTICIPANT	\N	PRESENT	0
498448	498009	14169X	PARTICIPANT	\N	PRESENT	0
498449	498009	19739H	PARTICIPANT	\N	PRESENT	0
498450	497172	20056C	PARTICIPANT	\N	PRESENT	0
498451	497172	11012A	PARTICIPANT	\N	PRESENT	0
498452	497172	14151M	PARTICIPANT	\N	PRESENT	0
498453	497172	19415P	PARTICIPANT	\N	PRESENT	0
498454	497010	07029T	PARTICIPANT	\N	PRESENT	0
498455	497172	19533U	PARTICIPANT	\N	PRESENT	0
498456	497172	14030Q	PARTICIPANT	\N	PRESENT	0
498457	497817	14219Q	PRESIDENT	0	PRESENT	0
498458	497817	19551W	PARTICIPANT	\N	EXCUSE	0
498462	497172	14211G	PARTICIPANT	\N	PRESENT	0
498463	497172	19507S	PARTICIPANT	\N	PRESENT	0
498461	497172	19581D	PARTICIPANT	\N	PRESENT	0
498464	497172	11054L	PARTICIPANT	\N	PRESENT	0
498465	497172	19703U	PARTICIPANT	\N	PRESENT	0
498466	497172	11085T	PARTICIPANT	\N	PRESENT	0
498467	497172	11097X	PARTICIPANT	\N	PRESENT	0
498468	497172	19747H	PARTICIPANT	\N	PRESENT	0
498469	497172	19515S	PARTICIPANT	\N	PRESENT	0
498470	497172	20068G	PARTICIPANT	\N	PRESENT	0
498722	495305	14147R	PARTICIPANT	\N	PRESENT	0
498723	495305	08073C	PARTICIPANT	\N	PRESENT	0
498724	495305	11045K	PARTICIPANT	\N	PRESENT	0
499581	497817	19631V	PARTICIPANT	\N	PRESENT	0
499582	497817	19515S	PARTICIPANT	\N	PRESENT	0
499583	497817	19575F	PARTICIPANT	\N	PRESENT	0
499584	497817	20086J	PARTICIPANT	\N	PRESENT	0
499585	497817	20094J	PARTICIPANT	\N	PRESENT	0
499586	497817	20088L	PARTICIPANT	\N	PRESENT	0
499587	497817	19747H	PARTICIPANT	\N	PRESENT	0
499588	497817	19782L	PARTICIPANT	\N	PRESENT	0
499589	497817	14207L	PARTICIPANT	\N	PRESENT	0
499590	497817	20104S	PARTICIPANT	\N	PRESENT	0
499591	497817	20060X	PARTICIPANT	\N	PRESENT	0
499592	497817	14329V	PARTICIPANT	\N	PRESENT	0
499593	497817	14038Y	PARTICIPANT	\N	PRESENT	0
499594	497817	20144B	PARTICIPANT	\N	PRESENT	0
499595	497817	19467C	PARTICIPANT	\N	PRESENT	0
499596	497817	14357A	PARTICIPANT	\N	PRESENT	0
499597	497817	14187A	PARTICIPANT	\N	PRESENT	0
499598	497817	01025N	PARTICIPANT	\N	PRESENT	0
499599	497817	19521Q	PARTICIPANT	\N	PRESENT	0
499600	497817	19695N	PARTICIPANT	\N	PRESENT	0
499601	497817	14033T	PARTICIPANT	\N	PRESENT	0
499602	497817	19511N	PARTICIPANT	\N	PRESENT	0
499604	497817	11099A	PARTICIPANT	\N	PRESENT	0
499605	497817	08015R	PARTICIPANT	\N	PRESENT	0
499606	497817	14205J	PARTICIPANT	\N	PRESENT	0
499607	497817	19441R	PARTICIPANT	\N	PRESENT	0
499608	497817	14251Q	PARTICIPANT	\N	PRESENT	0
499609	497817	19563B	PARTICIPANT	\N	PRESENT	0
499611	497817	20028X	PARTICIPANT	\N	PRESENT	0
499612	497817	20018V	PARTICIPANT	\N	PRESENT	0
499613	497817	14257W	PARTICIPANT	\N	PRESENT	0
499614	497817	19768N	PARTICIPANT	\N	PRESENT	0
499615	497817	20082E	PARTICIPANT	\N	PRESENT	0
499616	497817	19705W	PARTICIPANT	\N	PRESENT	0
499617	497817	20054A	PARTICIPANT	\N	PRESENT	0
499618	497817	20092G	PARTICIPANT	\N	PRESENT	0
499619	497817	20062A	PARTICIPANT	\N	PRESENT	0
499620	497817	19413M	PARTICIPANT	\N	PRESENT	0
499621	497817	20046A	PARTICIPANT	\N	EXCUSE	0
499622	497817	19681G	PARTICIPANT	\N	EXCUSE	0
499623	498009	14031R	PARTICIPANT	\N	PRESENT	0
499655	497846	19631V	PARTICIPANT	\N	PRESENT	0
499656	497846	19515S	PARTICIPANT	\N	PRESENT	0
499657	497846	19575F	PARTICIPANT	\N	PRESENT	0
499723	497846	20086J	PARTICIPANT	\N	PRESENT	0
499724	497846	20094J	PARTICIPANT	\N	PRESENT	0
499726	497846	19747H	PARTICIPANT	\N	PRESENT	0
499727	497846	19782L	PARTICIPANT	\N	PRESENT	0
499729	497846	20104S	PARTICIPANT	\N	PRESENT	0
499730	497846	14329V	PARTICIPANT	\N	PRESENT	0
499731	497846	14038Y	PARTICIPANT	\N	PRESENT	0
499769	497846	20144B	PARTICIPANT	\N	PRESENT	0
499770	497846	19467C	PARTICIPANT	\N	PRESENT	0
499771	497846	20174H	PARTICIPANT	\N	PRESENT	0
499772	497846	01025N	PARTICIPANT	\N	PRESENT	0
499773	497846	19521Q	PARTICIPANT	\N	PRESENT	0
499774	497846	19695N	PARTICIPANT	\N	PRESENT	0
499775	497846	14033T	PARTICIPANT	\N	PRESENT	0
499776	497846	08015R	PARTICIPANT	\N	PRESENT	0
499777	497846	14205J	PARTICIPANT	\N	PRESENT	0
499778	497846	20018V	PARTICIPANT	\N	PRESENT	0
499779	497846	19768N	PARTICIPANT	\N	PRESENT	0
499780	497846	11090Q	PARTICIPANT	\N	PRESENT	0
499781	497846	20082E	PARTICIPANT	\N	PRESENT	0
499782	497846	20054A	PARTICIPANT	\N	PRESENT	0
499783	497846	20062A	PARTICIPANT	\N	PRESENT	0
499784	497846	19413M	PARTICIPANT	\N	PRESENT	0
499968	498255	08012N	PARTICIPANT	\N	PRESENT	0
499969	498256	08012N	PARTICIPANT	\N	PRESENT	0
499970	498257	08012N	PARTICIPANT	\N	PRESENT	0
499971	498265	08012N	PARTICIPANT	\N	PRESENT	0
499972	498267	08012N	PARTICIPANT	\N	PRESENT	0
499973	498254	08012N	PARTICIPANT	\N	PRESENT	0
499977	498289	08012N	PARTICIPANT	\N	PRESENT	0
499979	499978	19749K	PARTICIPANT	\N	PRESENT	0
499980	499978	14053L	PARTICIPANT	\N	PRESENT	0
500062	497980	96004D	PARTICIPANT	\N	PRESENT	0
500063	497980	14089Y	PARTICIPANT	\N	PRESENT	0
500064	497980	19701S	PARTICIPANT	\N	PRESENT	0
500065	497980	14207L	PARTICIPANT	\N	PRESENT	0
500066	497980	19531S	PARTICIPANT	\N	PRESENT	0
500067	497980	11026G	PARTICIPANT	\N	PRESENT	0
500068	497980	14169X	PARTICIPANT	\N	PRESENT	0
500069	497980	14237S	PARTICIPANT	\N	PRESENT	0
500070	497980	10015M	PARTICIPANT	\N	PRESENT	0
500071	497980	04034C	PARTICIPANT	\N	PRESENT	0
500072	497980	14331P	PRESIDENT	0	PRESENT	0
500073	497980	19521Q	PARTICIPANT	\N	PRESENT	0
500075	497980	14097Y	PARTICIPANT	\N	PRESENT	0
500077	497980	19441R	PARTICIPANT	\N	PRESENT	0
500078	497980	20100N	PARTICIPANT	\N	PRESENT	0
500079	497980	19251M	PARTICIPANT	\N	PRESENT	0
500080	497980	11083R	PARTICIPANT	\N	PRESENT	0
500081	497980	20128B	PARTICIPANT	\N	PRESENT	0
500126	497039	19545Y	PARTICIPANT	\N	PRESENT	0
500127	497039	19667J	PARTICIPANT	\N	PRESENT	0
500128	497039	11110B	PARTICIPANT	\N	PRESENT	0
500129	497039	01057W	PARTICIPANT	\N	PRESENT	0
500130	497039	14121F	PARTICIPANT	\N	PRESENT	0
500131	497039	19349W	PARTICIPANT	\N	PRESENT	0
500132	497039	19687N	PARTICIPANT	\N	PRESENT	0
500133	497039	19479G	PARTICIPANT	\N	PRESENT	0
500292	500291	05008E	PARTICIPANT	\N	PRESENT	0
500293	500291	11053K	PARTICIPANT	\N	PRESENT	0
500294	500291	01028R	PARTICIPANT	\N	PRESENT	0
500688	500680	19826F	PARTICIPANT	\N	PRESENT	0
500689	500683	19826F	PARTICIPANT	\N	PRESENT	0
500692	500684	19826F	PARTICIPANT	\N	PRESENT	0
500693	500685	19826F	PARTICIPANT	\N	PRESENT	0
500697	500695	19745F	PARTICIPANT	\N	PRESENT	0
501098	501087	20140W	PARTICIPANT	\N	PRESENT	0
500709	500702	19631V	PARTICIPANT	\N	PRESENT	0
500713	500703	19631V	PARTICIPANT	\N	PRESENT	0
500714	500705	19631V	PARTICIPANT	\N	PRESENT	0
500717	500716	19631V	PARTICIPANT	\N	PRESENT	0
500718	500707	19631V	PARTICIPANT	\N	PRESENT	0
500725	500721	19631V	PARTICIPANT	\N	PRESENT	0
500726	500721	01043Q	PARTICIPANT	\N	PRESENT	0
500727	500722	01043Q	PARTICIPANT	\N	PRESENT	0
500728	500722	19631V	PARTICIPANT	\N	PRESENT	0
500735	500698	19745F	PARTICIPANT	\N	PRESENT	0
501099	501087	19599P	PARTICIPANT	\N	PRESENT	0
501100	501087	20136B	PARTICIPANT	\N	PRESENT	0
501102	501101	17229F	PARTICIPANT	\N	PRESENT	0
501103	501101	19599P	PARTICIPANT	\N	PRESENT	0
501104	501101	20136B	PARTICIPANT	\N	PRESENT	0
501109	501108	19387D	PARTICIPANT	\N	PRESENT	0
501110	501108	19551W	PARTICIPANT	\N	PRESENT	0
501111	501108	20136B	PARTICIPANT	\N	PRESENT	0
501113	501112	19599P	PARTICIPANT	\N	PRESENT	0
487486	486032	11056N	PARTICIPANT	\N	PRESENT	0
489760	489759	19693L	PARTICIPANT	\N	PRESENT	0
489761	489759	19593H	PARTICIPANT	\N	PRESENT	0
489762	489759	19533U	PARTICIPANT	\N	PRESENT	0
489763	489759	19611R	PARTICIPANT	\N	PRESENT	0
489765	489764	19693L	PARTICIPANT	\N	PRESENT	0
489766	489764	19593H	PARTICIPANT	\N	PRESENT	0
489767	489764	19533U	PARTICIPANT	\N	PRESENT	0
489768	489764	19611R	PARTICIPANT	\N	PRESENT	0
489770	489769	19693L	PARTICIPANT	\N	PRESENT	0
489771	489769	19593H	PARTICIPANT	\N	PRESENT	0
489772	489769	19611R	PARTICIPANT	\N	PRESENT	0
489773	489769	19533U	PARTICIPANT	\N	PRESENT	0
489775	489774	19693L	PARTICIPANT	\N	PRESENT	0
489776	489774	19593H	PARTICIPANT	\N	PRESENT	0
489777	489774	19611R	PARTICIPANT	\N	PRESENT	0
489778	489774	19533U	PARTICIPANT	\N	PRESENT	0
490590	490476	20092G	PARTICIPANT	\N	PRESENT	0
490591	490476	19549D	PARTICIPANT	\N	PRESENT	0
490592	490476	14021P	PARTICIPANT	\N	PRESENT	0
490593	490476	14229S	PARTICIPANT	\N	PRESENT	0
490594	490476	20112S	PARTICIPANT	\N	PRESENT	0
490595	490476	14251Q	PARTICIPANT	\N	PRESENT	0
490596	490476	20072C	PARTICIPANT	\N	PRESENT	0
490597	490477	14033T	PARTICIPANT	\N	PRESENT	0
490598	490477	20090E	PARTICIPANT	\N	PRESENT	0
490599	490477	17229F	PARTICIPANT	\N	PRESENT	0
490600	490477	14097Y	PARTICIPANT	\N	PRESENT	0
490601	490477	19673G	PARTICIPANT	\N	PRESENT	0
490602	490477	19569H	PARTICIPANT	\N	PRESENT	0
490603	490477	08047A	PARTICIPANT	\N	PRESENT	0
490604	490477	19703U	PARTICIPANT	\N	PRESENT	0
490605	490477	11101A	PARTICIPANT	\N	PRESENT	0
490606	490477	20124W	PARTICIPANT	\N	PRESENT	0
490607	490477	20032T	PARTICIPANT	\N	PRESENT	0
490608	490477	20044X	PARTICIPANT	\N	PRESENT	0
490609	490477	19563B	PARTICIPANT	\N	PRESENT	0
490610	490477	11074Q	PARTICIPANT	\N	PRESENT	0
490611	490477	20126Y	PARTICIPANT	\N	PRESENT	0
490612	490477	98022P	PARTICIPANT	\N	PRESENT	0
490613	490477	12028B	PARTICIPANT	\N	PRESENT	0
490614	490477	11045K	PARTICIPANT	\N	PRESENT	0
490615	490477	19575F	PARTICIPANT	\N	PRESENT	0
490616	490477	04059M	PARTICIPANT	\N	PRESENT	0
490617	490477	19511N	PARTICIPANT	\N	PRESENT	0
490618	490477	11103C	PARTICIPANT	\N	PRESENT	0
490619	490477	20088L	PARTICIPANT	\N	PRESENT	0
490620	490477	19387D	PARTICIPANT	\N	PRESENT	0
490621	490477	19717B	PARTICIPANT	\N	PRESENT	0
490622	490477	18083K	PARTICIPANT	\N	PRESENT	0
490623	490477	20098N	PARTICIPANT	\N	PRESENT	0
490624	490477	20084G	PARTICIPANT	\N	PRESENT	0
490625	490477	14257W	PARTICIPANT	\N	PRESENT	0
490626	490477	20114U	PARTICIPANT	\N	PRESENT	0
490627	490477	12041X	PARTICIPANT	\N	PRESENT	0
490628	490477	14225N	PARTICIPANT	\N	PRESENT	0
490629	490477	20150Y	PARTICIPANT	\N	PRESENT	0
490630	490477	20130U	PARTICIPANT	\N	PRESENT	0
490631	490477	20074E	PARTICIPANT	\N	PRESENT	0
490632	490477	08045X	PARTICIPANT	\N	PRESENT	0
490633	490477	19629C	PARTICIPANT	\N	PRESENT	0
490634	490477	19719D	PARTICIPANT	\N	PRESENT	0
490635	490477	14107H	PARTICIPANT	\N	PRESENT	0
490636	490477	01043Q	PARTICIPANT	\N	PRESENT	0
490637	490477	19713W	PARTICIPANT	\N	PRESENT	0
490638	490477	19441R	PARTICIPANT	\N	PRESENT	0
490639	490477	20052X	PARTICIPANT	\N	PRESENT	0
490640	490477	14179A	PARTICIPANT	\N	PRESENT	0
490641	490477	11031D	PARTICIPANT	\N	PRESENT	0
490642	490477	19649G	PARTICIPANT	\N	PRESENT	0
490643	490477	14030Q	PARTICIPANT	\N	PRESENT	0
490644	490477	17737W	PARTICIPANT	\N	PRESENT	0
490645	490477	17779H	PARTICIPANT	\N	PRESENT	0
490646	490477	19301E	PARTICIPANT	\N	PRESENT	0
490647	490477	08073C	PARTICIPANT	\N	PRESENT	0
490648	490477	19349W	PARTICIPANT	\N	PRESENT	0
490649	490477	19651A	PARTICIPANT	\N	PRESENT	0
490650	490477	20142Y	PARTICIPANT	\N	PRESENT	0
490651	490477	20134Y	PARTICIPANT	\N	PRESENT	0
490652	490477	19599P	PARTICIPANT	\N	PRESENT	0
490653	490477	11067R	PARTICIPANT	\N	PRESENT	0
490654	490477	20082E	PARTICIPANT	\N	PRESENT	0
490655	490477	01028R	PARTICIPANT	\N	PRESENT	0
490656	490477	11053K	PARTICIPANT	\N	PRESENT	0
490657	490477	11070L	PARTICIPANT	\N	PRESENT	0
490658	490477	11027H	PARTICIPANT	\N	PRESENT	0
490659	490477	04085P	PARTICIPANT	\N	PRESENT	0
490660	490477	20048C	PARTICIPANT	\N	PRESENT	0
490661	490477	08061X	PARTICIPANT	\N	PRESENT	0
490662	490477	11012A	PARTICIPANT	\N	PRESENT	0
490663	490477	20050V	PARTICIPANT	\N	PRESENT	0
490664	490477	19745F	PARTICIPANT	\N	PRESENT	0
490665	490477	19699S	PARTICIPANT	\N	PRESENT	0
490666	490477	14231L	PARTICIPANT	\N	PRESENT	0
490667	490477	19521Q	PARTICIPANT	\N	PRESENT	0
490668	490477	20046A	PARTICIPANT	\N	PRESENT	0
490669	490477	11040E	PARTICIPANT	\N	PRESENT	0
490670	490477	11033F	PARTICIPANT	\N	PRESENT	0
490671	490477	11056N	PARTICIPANT	\N	PRESENT	0
490672	490477	19760E	PARTICIPANT	\N	PRESENT	0
490673	490477	19695N	PARTICIPANT	\N	PRESENT	0
490674	490477	19565D	PARTICIPANT	\N	PRESENT	0
490675	490477	19347U	PARTICIPANT	\N	PRESENT	0
490676	490477	19758L	PARTICIPANT	\N	PRESENT	0
490677	490477	19593H	PARTICIPANT	\N	PRESENT	0
490678	490477	19687N	PARTICIPANT	\N	PRESENT	0
490679	490477	19413M	PARTICIPANT	\N	PRESENT	0
490680	490477	19251M	PARTICIPANT	\N	PRESENT	0
490681	490477	20030R	PARTICIPANT	\N	PRESENT	0
490682	490477	19503N	PARTICIPANT	\N	PRESENT	0
490683	490477	20100N	PARTICIPANT	\N	PRESENT	0
490684	490477	11066Q	PARTICIPANT	\N	PRESENT	0
490685	490477	19820Y	PARTICIPANT	\N	PRESENT	0
490686	490477	19715Y	PARTICIPANT	\N	PRESENT	0
490687	490477	14151M	PARTICIPANT	\N	PRESENT	0
490688	490477	20110Q	PARTICIPANT	\N	PRESENT	0
490689	490477	14001X	PARTICIPANT	\N	PRESENT	0
490690	490477	19333N	PARTICIPANT	\N	PRESENT	0
490691	490477	19725B	PARTICIPANT	\N	PRESENT	0
490692	490477	19631V	PARTICIPANT	\N	PRESENT	0
490693	490477	14109K	PARTICIPANT	\N	PRESENT	0
490694	490477	20094J	PARTICIPANT	\N	PRESENT	0
490695	490477	19329S	PARTICIPANT	\N	PRESENT	0
490696	490477	20092G	PARTICIPANT	\N	PRESENT	0
490697	490477	19549D	PARTICIPANT	\N	PRESENT	0
490698	490477	14021P	PARTICIPANT	\N	PRESENT	0
490699	490477	14229S	PARTICIPANT	\N	PRESENT	0
490700	490477	20112S	PARTICIPANT	\N	PRESENT	0
490701	490477	14251Q	PARTICIPANT	\N	PRESENT	0
490702	490477	20072C	PARTICIPANT	\N	PRESENT	0
491744	491412	14217N	PARTICIPANT	\N	PRESENT	0
491742	491412	08056B	PARTICIPANT	\N	PRESENT	0
491743	491412	19735D	PARTICIPANT	\N	PRESENT	0
491745	491471	14327T	PARTICIPANT	\N	PRESENT	0
491746	491471	14331P	PARTICIPANT	\N	PRESENT	0
491747	491471	01057W	PARTICIPANT	\N	PRESENT	0
491748	491471	20080C	PARTICIPANT	\N	PRESENT	0
491749	491471	11053K	PARTICIPANT	\N	PRESENT	0
491750	491471	19667J	PARTICIPANT	\N	PRESENT	0
491751	491471	14225N	PRESIDENT	0	PRESENT	0
491752	491471	19671E	PARTICIPANT	\N	PRESENT	0
491753	491471	11070L	PARTICIPANT	\N	PRESENT	0
491754	491471	11110B	PARTICIPANT	\N	PRESENT	0
491755	491471	07029T	PARTICIPANT	\N	PRESENT	0
491756	491471	19349W	PARTICIPANT	\N	PRESENT	0
491757	491471	19335Q	PARTICIPANT	\N	PRESENT	0
491758	491471	20126Y	PARTICIPANT	\N	PRESENT	0
491759	491471	11048N	PARTICIPANT	\N	PRESENT	0
491760	491471	19479G	PARTICIPANT	\N	PRESENT	0
491761	491471	19647E	PARTICIPANT	\N	PRESENT	0
491762	491471	19711U	PARTICIPANT	\N	PRESENT	0
491763	491471	20036X	PARTICIPANT	\N	PRESENT	0
491764	491471	19531S	PARTICIPANT	\N	PRESENT	0
491765	491471	14189C	PARTICIPANT	\N	PRESENT	0
491766	491471	19687N	PARTICIPANT	\N	PRESENT	0
491767	491471	19689Q	PARTICIPANT	\N	PRESENT	0
491768	491471	12016W	PARTICIPANT	\N	PRESENT	0
491769	491471	20050V	PARTICIPANT	\N	PRESENT	0
491770	491471	20044X	PARTICIPANT	\N	PRESENT	0
491771	491471	14173T	PARTICIPANT	\N	PRESENT	0
491772	491471	11040E	PARTICIPANT	\N	PRESENT	0
491773	491471	14083S	PARTICIPANT	\N	PRESENT	0
491774	491471	08009T	PARTICIPANT	\N	PRESENT	0
491775	491471	20070A	PARTICIPANT	\N	PRESENT	0
491776	491471	19741B	PARTICIPANT	\N	PRESENT	0
491777	491471	14121F	PARTICIPANT	\N	PRESENT	0
491778	491471	19762G	PARTICIPANT	\N	PRESENT	0
491779	491471	01048V	PARTICIPANT	\N	PRESENT	0
497312	497311	04071H	PARTICIPANT	\N	PRESENT	0
497836	497834	14026U	PARTICIPANT	\N	PRESENT	0
497840	497839	14105F	PARTICIPANT	\N	PRESENT	0
497982	497981	07033P	PARTICIPANT	\N	PRESENT	0
498115	498114	14030Q	PARTICIPANT	\N	PRESENT	0
498116	498114	11031D	PARTICIPANT	\N	PRESENT	0
498117	498114	19693L	PARTICIPANT	\N	PRESENT	0
498118	498114	19599P	PARTICIPANT	\N	PRESENT	0
498119	498114	04035D	PARTICIPANT	\N	PRESENT	0
498120	498114	20106U	PARTICIPANT	\N	PRESENT	0
498121	498114	07029T	PARTICIPANT	\N	PRESENT	0
498122	498114	14109K	PARTICIPANT	\N	PRESENT	0
498123	498114	20130U	PARTICIPANT	\N	PRESENT	0
498124	498114	19866P	PARTICIPANT	\N	PRESENT	0
498125	498114	19749K	PARTICIPANT	\N	PRESENT	0
498126	498114	19768N	PARTICIPANT	\N	PRESENT	0
498127	498114	08017T	PARTICIPANT	\N	PRESENT	0
498128	498007	19383Y	PARTICIPANT	\N	PRESENT	0
498129	498007	20086J	PARTICIPANT	\N	PRESENT	0
498130	498007	19768N	PARTICIPANT	\N	PRESENT	0
498131	498007	20088L	PARTICIPANT	\N	PRESENT	0
498132	498007	19515S	PARTICIPANT	\N	PRESENT	0
498133	498007	19782L	PARTICIPANT	\N	PRESENT	0
498134	498007	11077T	PARTICIPANT	\N	PRESENT	0
498135	498007	20092G	PARTICIPANT	\N	PRESENT	0
498136	498007	01043Q	PARTICIPANT	\N	PRESENT	0
498137	498007	20078J	PARTICIPANT	\N	PRESENT	0
498138	498007	19441R	PARTICIPANT	\N	PRESENT	0
498139	498007	20082E	PARTICIPANT	\N	PRESENT	0
498140	498007	20094J	PARTICIPANT	\N	PRESENT	0
498141	498007	04045F	PARTICIPANT	\N	PRESENT	0
498142	498007	19631V	PARTICIPANT	\N	PRESENT	0
498143	498007	11099A	PARTICIPANT	\N	PRESENT	0
498144	498007	19705W	PARTICIPANT	\N	PRESENT	0
498145	498007	08015R	PARTICIPANT	\N	PRESENT	0
498146	498007	19575F	PARTICIPANT	\N	PRESENT	0
498147	498007	19369B	PARTICIPANT	\N	PRESENT	0
498148	498007	20018V	PARTICIPANT	\N	PRESENT	0
498149	498007	19563B	PARTICIPANT	\N	PRESENT	0
498150	498007	19521Q	PARTICIPANT	\N	PRESENT	0
498151	498007	14329V	PARTICIPANT	\N	PRESENT	0
498152	498007	20028X	PARTICIPANT	\N	PRESENT	0
498153	498007	14038Y	PARTICIPANT	\N	PRESENT	0
498154	498007	20030R	PARTICIPANT	\N	PRESENT	0
498155	498007	19467C	PARTICIPANT	\N	PRESENT	0
498156	498007	20034V	PARTICIPANT	\N	PRESENT	0
498157	498007	19695N	PARTICIPANT	\N	PRESENT	0
498158	498007	14033T	PARTICIPANT	\N	PRESENT	0
498159	498007	11090Q	PRESIDENT	0	PRESENT	0
498160	498007	01025N	PARTICIPANT	\N	PRESENT	0
498161	498007	20054A	PARTICIPANT	\N	PRESENT	0
498162	498007	14205J	PARTICIPANT	\N	PRESENT	0
498163	498007	20060X	PARTICIPANT	\N	PRESENT	0
498164	498007	20062A	PARTICIPANT	\N	PRESENT	0
498165	498007	14251Q	PARTICIPANT	\N	PRESENT	0
498166	498007	14207L	PARTICIPANT	\N	PRESENT	0
498167	498007	14257W	PARTICIPANT	\N	PRESENT	0
498168	498007	08028W	PARTICIPANT	\N	EXCUSE	0
498187	496310	19711U	PARTICIPANT	\N	PRESENT	0
498194	498193	14223L	PARTICIPANT	\N	PRESENT	0
496855	495107	14059S	PARTICIPANT	\N	PRESENT	0
496856	495107	14097Y	PARTICIPANT	\N	PRESENT	0
496857	495107	04035D	PARTICIPANT	\N	PRESENT	0
496858	495107	19565D	PARTICIPANT	\N	PRESENT	0
496859	495107	08069G	PARTICIPANT	\N	PRESENT	0
496860	495107	04042C	PRESIDENT	0	PRESENT	0
496861	495107	20064C	PARTICIPANT	\N	PRESENT	0
496862	495107	19421M	PARTICIPANT	\N	PRESENT	0
496863	495107	19347U	PARTICIPANT	\N	PRESENT	0
496864	495107	11083R	PARTICIPANT	\N	PRESENT	0
496865	495107	14255U	PRESIDENT	1	PRESENT	0
496866	495107	17023S	PARTICIPANT	\N	PRESENT	0
496867	495107	20128B	PARTICIPANT	\N	PRESENT	0
498195	498193	11067R	PARTICIPANT	\N	PRESENT	0
498196	498193	11031D	PARTICIPANT	\N	PRESENT	0
496870	495107	04070G	PARTICIPANT	\N	PRESENT	0
496871	495107	14357A	PARTICIPANT	\N	PRESENT	0
496872	495107	14001X	PARTICIPANT	\N	PRESENT	0
496873	495107	14026U	PARTICIPANT	\N	PRESENT	0
496874	495107	20104S	PARTICIPANT	\N	PRESENT	0
496875	495107	20100N	PARTICIPANT	\N	PRESENT	0
496876	495107	19553Y	PARTICIPANT	\N	PRESENT	0
496877	495107	19521Q	PARTICIPANT	\N	PRESENT	0
496878	495107	08034U	PARTICIPANT	\N	PRESENT	0
496879	495107	14073Q	PARTICIPANT	\N	PRESENT	0
496880	495107	19531S	PARTICIPANT	\N	PRESENT	0
496881	495107	14189C	PARTICIPANT	\N	PRESENT	0
496882	495107	11026G	PARTICIPANT	\N	PRESENT	0
496883	495107	12016W	PARTICIPANT	\N	PRESENT	0
496884	495107	19251M	PARTICIPANT	\N	PRESENT	0
496885	495107	14169X	PARTICIPANT	\N	PRESENT	0
496886	495107	19725B	PARTICIPANT	\N	PRESENT	0
496887	495107	14089Y	PARTICIPANT	\N	PRESENT	0
496888	495107	11101A	PARTICIPANT	\N	PRESENT	0
496889	495107	14207L	PARTICIPANT	\N	PRESENT	0
497084	495345	19760E	PARTICIPANT	\N	PRESENT	0
497085	495345	14026U	PARTICIPANT	\N	PRESENT	0
498197	498192	14223L	PARTICIPANT	\N	PRESENT	0
498198	498192	11067R	PARTICIPANT	\N	PRESENT	0
498199	498192	11031D	PARTICIPANT	\N	PRESENT	0
498200	498191	11031D	PARTICIPANT	\N	PRESENT	0
498201	498191	14223L	PARTICIPANT	\N	PRESENT	0
498202	498191	11067R	PARTICIPANT	\N	PRESENT	0
498203	496310	19399H	PARTICIPANT	\N	PRESENT	0
498222	496310	14259Y	PARTICIPANT	\N	PRESENT	0
498235	498234	19399H	PARTICIPANT	\N	PRESENT	0
498236	498234	20052X	PARTICIPANT	\N	PRESENT	0
498264	497671	14215L	PARTICIPANT	\N	PRESENT	0
498295	498293	08012N	PARTICIPANT	\N	PRESENT	0
498306	497671	20074E	PARTICIPANT	\N	EXCUSE	0
498314	498311	04070G	PARTICIPANT	\N	PRESENT	0
498312	498311	19621T	PARTICIPANT	\N	PRESENT	0
498313	498311	08017T	PARTICIPANT	\N	PRESENT	0
498504	497983	14133K	PARTICIPANT	\N	PRESENT	0
498505	497983	20042V	PARTICIPANT	\N	PRESENT	0
498506	497983	14105F	PARTICIPANT	\N	PRESENT	0
498507	497983	14255U	PARTICIPANT	\N	PRESENT	0
498508	497983	04042C	PRESIDENT	0	PRESENT	0
498509	497983	11080N	PARTICIPANT	\N	PRESENT	0
498510	497983	11027H	PARTICIPANT	\N	PRESENT	0
498511	497983	98018T	PARTICIPANT	\N	PRESENT	0
498512	497983	01024M	PARTICIPANT	\N	PRESENT	0
498513	497983	14249W	PARTICIPANT	\N	PRESENT	0
498514	497983	97011G	PARTICIPANT	\N	PRESENT	0
498515	497983	04035D	PARTICIPANT	\N	PRESENT	0
498516	497983	11083R	PARTICIPANT	\N	PRESENT	0
498517	497983	19347U	PARTICIPANT	\N	PRESENT	0
498518	497983	14211G	PARTICIPANT	\N	PRESENT	0
498519	497983	19565D	PARTICIPANT	\N	PRESENT	0
498520	497983	98022P	PARTICIPANT	\N	PRESENT	0
498521	497983	11064N	PARTICIPANT	\N	PRESENT	0
498522	497983	20072C	PARTICIPANT	\N	PRESENT	0
498523	497983	14097Y	PARTICIPANT	\N	PRESENT	0
498524	497983	12041X	PARTICIPANT	\N	PRESENT	0
498525	497983	19709B	PARTICIPANT	\N	PRESENT	0
498526	497983	16685X	PARTICIPANT	\N	PRESENT	0
498527	497983	14059S	PARTICIPANT	\N	PRESENT	0
498528	497983	14193X	PARTICIPANT	\N	PRESENT	0
498529	497983	11054L	PARTICIPANT	\N	PRESENT	0
498530	497983	19421M	PARTICIPANT	\N	PRESENT	0
498531	497983	01058X	PARTICIPANT	\N	PRESENT	0
498532	497983	19669L	PARTICIPANT	\N	PRESENT	0
498533	497983	20064C	PARTICIPANT	\N	PRESENT	0
498534	497983	11066Q	PARTICIPANT	\N	PRESENT	0
498535	497983	04034C	PARTICIPANT	\N	PRESENT	0
498536	497983	20128B	PARTICIPANT	\N	PRESENT	0
498547	497011	14053L	PARTICIPANT	\N	PRESENT	0
498548	497011	14331P	PARTICIPANT	\N	PRESENT	0
498549	497011	19711U	PARTICIPANT	\N	PRESENT	0
498550	497011	08010L	PARTICIPANT	\N	PRESENT	0
498551	497011	19671E	PARTICIPANT	\N	PRESENT	0
498552	497011	11012A	PARTICIPANT	\N	PRESENT	0
498553	497011	20080C	PARTICIPANT	\N	PRESENT	0
498554	497011	20116W	PARTICIPANT	\N	PRESENT	0
498555	497011	14225N	PRESIDENT	0	PRESENT	0
498556	497011	04086Q	PARTICIPANT	\N	PRESENT	0
498557	497011	11048N	PARTICIPANT	\N	PRESENT	0
498558	497011	20044X	PARTICIPANT	\N	PRESENT	0
498559	497011	20036X	PARTICIPANT	\N	PRESENT	0
498560	497011	19689Q	PARTICIPANT	\N	PRESENT	0
498561	497011	20070A	PARTICIPANT	\N	PRESENT	0
498562	497011	19741B	PARTICIPANT	\N	PRESENT	0
498563	497011	19749K	PARTICIPANT	\N	PRESENT	0
498564	497011	19762G	PARTICIPANT	\N	PRESENT	0
498565	497011	19687N	PARTICIPANT	\N	PRESENT	0
498566	497011	20126Y	PARTICIPANT	\N	PRESENT	0
498567	497845	19333N	PARTICIPANT	\N	PRESENT	0
498568	497845	20076G	PARTICIPANT	\N	PRESENT	0
485835	484556	11074Q	PRESIDENT	0	PRESENT	0
485836	484556	08011M	PARTICIPANT	\N	PRESENT	0
485837	484556	19671E	PARTICIPANT	\N	PRESENT	0
485838	484556	07029T	PARTICIPANT	\N	PRESENT	0
485839	484556	14085U	PARTICIPANT	\N	PRESENT	0
485840	484556	96004D	PARTICIPANT	\N	PRESENT	0
485841	484556	19531S	PARTICIPANT	\N	PRESENT	0
485842	484556	19762G	PARTICIPANT	\N	PRESENT	0
485843	484556	19651A	PARTICIPANT	\N	PRESENT	0
485844	484556	19349W	PARTICIPANT	\N	PRESENT	0
485845	484556	19647E	PARTICIPANT	\N	PRESENT	0
485848	484556	11053K	PARTICIPANT	\N	PRESENT	0
485849	484556	14327T	PARTICIPANT	\N	PRESENT	0
485850	484556	14034U	PARTICIPANT	\N	PRESENT	0
485851	484556	14225N	PARTICIPANT	\N	PRESENT	0
485852	484556	11012A	PARTICIPANT	\N	PRESENT	0
485854	479204	04059M	PARTICIPANT	\N	PRESENT	0
485861	479204	14041T	PARTICIPANT	\N	PRESENT	0
485862	479204	07029T	PARTICIPANT	\N	PRESENT	0
485863	479204	11040E	PARTICIPANT	\N	PRESENT	0
485864	479204	08039A	PARTICIPANT	\N	PRESENT	0
485865	479204	19687N	PARTICIPANT	\N	PRESENT	0
485866	479204	01057W	PARTICIPANT	\N	PRESENT	0
485867	479204	19758L	PARTICIPANT	\N	PRESENT	0
485868	479204	19711U	PARTICIPANT	\N	PRESENT	0
485869	479204	19695N	PARTICIPANT	\N	PRESENT	0
485870	479204	04086Q	PARTICIPANT	\N	PRESENT	0
485871	479204	19593H	PARTICIPANT	\N	PRESENT	0
485872	479204	19760E	PARTICIPANT	\N	PRESENT	0
485873	479204	14357A	PARTICIPANT	\N	PRESENT	0
485874	479204	19675J	PARTICIPANT	\N	PRESENT	0
485875	479204	11074Q	PARTICIPANT	\N	PRESENT	0
485876	479204	19701S	PARTICIPANT	\N	PRESENT	0
485877	479204	08011M	PARTICIPANT	\N	PRESENT	0
485878	479204	12016W	PARTICIPANT	\N	PRESENT	0
485879	479204	19671E	PARTICIPANT	\N	PRESENT	0
485880	479204	19926J	PARTICIPANT	\N	PRESENT	0
485881	479204	14255U	PARTICIPANT	\N	PRESENT	0
485882	479204	14085U	PARTICIPANT	\N	PRESENT	0
485883	479204	07004J	PARTICIPANT	\N	PRESENT	0
485884	479204	19533U	PARTICIPANT	\N	PRESENT	0
485885	479204	11109J	PARTICIPANT	\N	PRESENT	0
485886	479204	19503N	PARTICIPANT	\N	PRESENT	0
485887	479204	19713W	PARTICIPANT	\N	PRESENT	0
485888	479204	19549D	PARTICIPANT	\N	PRESENT	0
485889	479204	11012A	PARTICIPANT	\N	PRESENT	0
485890	479204	14225N	PARTICIPANT	\N	PRESENT	0
485891	479204	04057K	PARTICIPANT	\N	PRESENT	0
485892	479204	01028R	PARTICIPANT	\N	PRESENT	0
485893	479204	19912C	PARTICIPANT	\N	PRESENT	0
485894	479204	19651A	PARTICIPANT	\N	PRESENT	0
485895	479204	11067R	PARTICIPANT	\N	PRESENT	0
485896	479204	19349W	PARTICIPANT	\N	PRESENT	0
485897	479204	14327T	PARTICIPANT	\N	PRESENT	0
485898	479204	19762G	PARTICIPANT	\N	PRESENT	0
485899	479204	19531S	PARTICIPANT	\N	PRESENT	0
485900	479204	11053K	PARTICIPANT	\N	PRESENT	0
485901	479204	14331P	PARTICIPANT	\N	PRESENT	0
485902	479204	19689Q	PARTICIPANT	\N	PRESENT	0
485903	479204	19749K	PARTICIPANT	\N	PRESENT	0
485904	479204	19621T	PARTICIPANT	\N	PRESENT	0
485905	479204	88008L	PARTICIPANT	\N	PRESENT	0
485906	479204	99004R	PARTICIPANT	\N	PRESENT	0
485908	479204	19591F	PARTICIPANT	\N	PRESENT	0
485909	479204	19347U	PARTICIPANT	\N	PRESENT	0
485912	479204	19565D	PARTICIPANT	\N	PRESENT	0
485913	479204	19766L	PARTICIPANT	\N	PRESENT	0
485914	479204	19741B	PARTICIPANT	\N	PRESENT	0
485915	479204	19295A	PARTICIPANT	\N	PRESENT	0
485916	479204	14034U	PARTICIPANT	\N	PRESENT	0
485917	479204	04085P	PARTICIPANT	\N	PRESENT	0
485918	479204	11072N	PARTICIPANT	\N	PRESENT	0
485921	479204	11064N	PARTICIPANT	\N	PRESENT	0
485924	479204	19599P	PARTICIPANT	\N	PRESENT	0
485983	479205	11040E	PARTICIPANT	\N	PRESENT	0
485984	479205	19689Q	PARTICIPANT	\N	PRESENT	0
485985	479205	14085U	PARTICIPANT	\N	PRESENT	0
485986	479205	19926J	PARTICIPANT	\N	PRESENT	0
485987	479205	08011M	PARTICIPANT	\N	PRESENT	0
485988	479205	19349W	PARTICIPANT	\N	PRESENT	0
485989	479205	19762G	PARTICIPANT	\N	PRESENT	0
485990	479205	14357A	PARTICIPANT	\N	PRESENT	0
485991	479205	19711U	PARTICIPANT	\N	PRESENT	0
485992	479205	04057K	PARTICIPANT	\N	PRESENT	0
485993	479205	19912C	PARTICIPANT	\N	PRESENT	0
485994	479205	19347U	PARTICIPANT	\N	PRESENT	0
485995	479205	19593H	PARTICIPANT	\N	PRESENT	0
485996	479205	14225N	PARTICIPANT	\N	PRESENT	0
485997	479205	11099A	PARTICIPANT	\N	PRESENT	0
485998	479205	14327T	PARTICIPANT	\N	PRESENT	0
485999	479205	07004J	PARTICIPANT	\N	PRESENT	0
486000	479205	19713W	PARTICIPANT	\N	PRESENT	0
486001	479205	19667J	PARTICIPANT	\N	PRESENT	0
486002	479205	19695N	PARTICIPANT	\N	PRESENT	0
486003	479205	88008L	PARTICIPANT	\N	PRESENT	0
486004	479205	19599P	PARTICIPANT	\N	PRESENT	0
486005	479205	19760E	PARTICIPANT	\N	PRESENT	0
486006	479205	19719D	PARTICIPANT	\N	PRESENT	0
486007	479205	14041T	PARTICIPANT	\N	PRESENT	0
486008	479205	12016W	PARTICIPANT	\N	PRESENT	0
486009	479205	14331P	PARTICIPANT	\N	PRESENT	0
486010	479205	01057W	PARTICIPANT	\N	PRESENT	0
486011	479205	19705W	PARTICIPANT	\N	PRESENT	0
486012	479205	99004R	PARTICIPANT	\N	PRESENT	0
486013	479205	11012A	PARTICIPANT	\N	PRESENT	0
486017	479205	19758L	PARTICIPANT	\N	PRESENT	0
486015	479205	19671E	PARTICIPANT	\N	PRESENT	0
486016	479205	07029T	PARTICIPANT	\N	PRESENT	0
486018	479205	04018C	PARTICIPANT	\N	PRESENT	0
486019	479205	08039A	PARTICIPANT	\N	PRESENT	0
486020	479205	19766L	PARTICIPANT	\N	PRESENT	0
486021	479205	19533U	PARTICIPANT	\N	PRESENT	0
486022	479205	19565D	PARTICIPANT	\N	PRESENT	0
486023	479205	19503N	PARTICIPANT	\N	PRESENT	0
486024	479205	14034U	PARTICIPANT	\N	PRESENT	0
486025	479205	14255U	PARTICIPANT	\N	PRESENT	0
486026	479205	19295A	PARTICIPANT	\N	PRESENT	0
486027	479205	11109J	PARTICIPANT	\N	PRESENT	0
486028	479205	04043D	PARTICIPANT	\N	PRESENT	0
486029	479205	19715Y	PARTICIPANT	\N	PRESENT	0
486030	479205	19749K	PARTICIPANT	\N	PRESENT	0
486031	479205	01043Q	PARTICIPANT	\N	PRESENT	0
486033	479205	01028R	PARTICIPANT	\N	PRESENT	0
486034	479205	19741B	PARTICIPANT	\N	PRESENT	0
486035	479205	12041X	PARTICIPANT	\N	PRESENT	0
486041	479205	19549D	PARTICIPANT	\N	PRESENT	0
486042	479205	19647E	PARTICIPANT	\N	PRESENT	0
486058	479205	11090Q	PARTICIPANT	\N	PRESENT	0
486061	479205	14205J	PARTICIPANT	\N	PRESENT	0
486063	479205	07033P	PARTICIPANT	\N	PRESENT	0
485981	479205	04086Q	PARTICIPANT	\N	PRESENT	0
485982	479205	19687N	PARTICIPANT	\N	PRESENT	0
486064	479205	19399H	PARTICIPANT	\N	PRESENT	0
486065	479205	19651A	PARTICIPANT	\N	PRESENT	0
486067	479205	08073C	PARTICIPANT	\N	PRESENT	0
486068	479205	08069G	PARTICIPANT	\N	PRESENT	0
486069	479205	11085T	PARTICIPANT	\N	PRESENT	0
486070	479205	11064N	PARTICIPANT	\N	PRESENT	0
486071	479205	14261S	PARTICIPANT	\N	PRESENT	0
486072	479205	19649G	PARTICIPANT	\N	PRESENT	0
486073	479205	11053K	PARTICIPANT	\N	PRESENT	0
501114	501112	19551W	PARTICIPANT	\N	PRESENT	0
501126	501112	20136B	PARTICIPANT	\N	PRESENT	0
501127	501112	19577H	PARTICIPANT	\N	PRESENT	0
501133	501132	19387D	PARTICIPANT	\N	PRESENT	0
501134	501132	19599P	PARTICIPANT	\N	PRESENT	0
501135	501132	19551W	PARTICIPANT	\N	PRESENT	0
501136	501132	20136B	PARTICIPANT	\N	PRESENT	0
501140	501139	20136B	PARTICIPANT	\N	PRESENT	0
501141	501139	19551W	PARTICIPANT	\N	PRESENT	0
501143	501142	20136B	PARTICIPANT	\N	PRESENT	0
501145	501144	19551W	PARTICIPANT	\N	PRESENT	0
501146	501144	20136B	PARTICIPANT	\N	PRESENT	0
501148	501147	19387D	PARTICIPANT	\N	PRESENT	0
501149	501147	19551W	PARTICIPANT	\N	PRESENT	0
501150	501147	20136B	PARTICIPANT	\N	PRESENT	0
501152	501151	20136B	PARTICIPANT	\N	PRESENT	0
501544	501542	19387D	PARTICIPANT	\N	PRESENT	0
501545	501542	19551W	PARTICIPANT	\N	PRESENT	0
501546	501542	20136B	PARTICIPANT	\N	PRESENT	0
501547	501543	19551W	PARTICIPANT	\N	PRESENT	0
501548	501543	20136B	PARTICIPANT	\N	PRESENT	0
501597	500572	20106U	PARTICIPANT	\N	PRESENT	0
501615	500572	19549D	PARTICIPANT	\N	PRESENT	0
501616	500572	19619A	PARTICIPANT	\N	PRESENT	0
501619	500572	19387D	PARTICIPANT	\N	PRESENT	0
501620	500572	14237S	PARTICIPANT	\N	EXCUSE	0
501621	500572	20046A	PARTICIPANT	\N	EXCUSE	0
501622	500572	20118Y	PARTICIPANT	\N	PRESENT	0
501623	500572	17637T	PARTICIPANT	\N	PRESENT	0
501628	500572	14205J	PARTICIPANT	\N	PRESENT	0
501629	500572	20060X	PARTICIPANT	\N	PRESENT	0
501631	500572	19413M	PARTICIPANT	\N	PRESENT	0
501632	500572	20082E	PARTICIPANT	\N	PRESENT	0
501633	500572	14251Q	PARTICIPANT	\N	PRESENT	0
501634	500572	19563B	PARTICIPANT	\N	PRESENT	0
501635	500572	19521Q	PARTICIPANT	\N	PRESENT	0
501636	500572	19782L	PARTICIPANT	\N	PRESENT	0
501637	500572	20018V	PARTICIPANT	\N	PRESENT	0
501638	500572	11077T	PARTICIPANT	\N	PRESENT	0
501639	500572	19467C	PARTICIPANT	\N	PRESENT	0
501640	500572	20088L	PARTICIPANT	\N	PRESENT	0
501641	500572	20030R	PARTICIPANT	\N	PRESENT	0
501643	500572	19631V	PARTICIPANT	\N	PRESENT	0
501644	500572	19575F	PARTICIPANT	\N	PRESENT	0
501645	500572	19515S	PARTICIPANT	\N	PRESENT	0
501646	500572	20094J	PARTICIPANT	\N	PRESENT	0
501647	500572	20086J	PARTICIPANT	\N	PRESENT	0
501648	500572	19747H	PARTICIPANT	\N	PRESENT	0
501650	500572	20104S	PARTICIPANT	\N	PRESENT	0
501651	500572	14357A	PARTICIPANT	\N	PRESENT	0
501652	500572	20174H	PARTICIPANT	\N	PRESENT	0
501653	500572	19511N	PARTICIPANT	\N	PRESENT	0
501654	500572	19705W	PARTICIPANT	\N	PRESENT	0
501655	500572	20054A	PARTICIPANT	\N	PRESENT	0
501656	500572	20092G	PARTICIPANT	\N	PRESENT	0
501657	500572	20062A	PARTICIPANT	\N	PRESENT	0
501662	500572	14169X	PARTICIPANT	\N	PRESENT	0
502630	500287	20066E	PARTICIPANT	\N	PRESENT	0
502631	500287	14281W	PARTICIPANT	\N	PRESENT	0
502632	500287	14123H	PARTICIPANT	\N	PRESENT	0
502633	500287	20148F	PARTICIPANT	\N	PRESENT	0
502634	500287	04043D	PARTICIPANT	\N	PRESENT	0
502635	500287	11045K	PARTICIPANT	\N	PRESENT	0
502636	500287	11070L	PARTICIPANT	\N	PRESENT	0
502637	500287	19575F	PARTICIPANT	\N	PRESENT	0
502638	500287	14030Q	PARTICIPANT	\N	PRESENT	0
502639	500287	19717B	PARTICIPANT	\N	PRESENT	0
502640	500287	11077T	PARTICIPANT	\N	PRESENT	0
502641	500287	20082E	PARTICIPANT	\N	PRESENT	0
502642	500287	20098N	PARTICIPANT	\N	PRESENT	0
502643	500287	19713W	PARTICIPANT	\N	PRESENT	0
502644	500287	14026U	PARTICIPANT	\N	PRESENT	0
502645	500287	19591F	PARTICIPANT	\N	PRESENT	0
502646	500287	19553Y	PARTICIPANT	\N	PRESENT	0
502680	502679	19675J	PARTICIPANT	\N	PRESENT	0
502681	502679	20110Q	PARTICIPANT	\N	PRESENT	0
502753	502750	19729F	PARTICIPANT	\N	PRESENT	0
502754	502750	04085P	PARTICIPANT	\N	PRESENT	0
502757	502756	19729F	PARTICIPANT	\N	PRESENT	0
502758	502756	04085P	PARTICIPANT	\N	PRESENT	0
502822	502820	19447X	PARTICIPANT	\N	PRESENT	0
502823	502820	14089Y	PARTICIPANT	\N	PRESENT	0
502837	502835	20110Q	PARTICIPANT	\N	PRESENT	0
502847	502845	14001X	PARTICIPANT	\N	PRESENT	0
502849	502848	14179A	PARTICIPANT	\N	PRESENT	0
502850	502848	14001X	PARTICIPANT	\N	PRESENT	0
502852	502851	14179A	PARTICIPANT	\N	PRESENT	0
502853	502851	14001X	PARTICIPANT	\N	PRESENT	0
502862	502861	14133K	PARTICIPANT	\N	PRESENT	0
502863	502861	11066Q	PARTICIPANT	\N	PRESENT	0
502865	502864	14331P	PARTICIPANT	\N	PRESENT	0
502867	502866	14331P	PARTICIPANT	\N	PRESENT	0
502869	502868	20050V	PARTICIPANT	\N	PRESENT	0
502871	502870	20050V	PARTICIPANT	\N	PRESENT	0
502873	502872	14331P	PARTICIPANT	\N	PRESENT	0
502988	502310	14026U	PARTICIPANT	\N	PRESENT	0
502989	502310	19760E	PARTICIPANT	\N	PRESENT	0
502990	502310	11031D	PARTICIPANT	\N	PRESENT	0
502991	502310	14071N	PARTICIPANT	\N	PRESENT	0
502992	502310	11097X	PARTICIPANT	\N	PRESENT	0
502993	502310	18193Q	PARTICIPANT	\N	PRESENT	0
502994	502310	14213J	PARTICIPANT	\N	PRESENT	0
502995	502310	20148F	PARTICIPANT	\N	PRESENT	0
502996	502310	11067R	PARTICIPANT	\N	PRESENT	0
502997	502310	19711U	PARTICIPANT	\N	PRESENT	0
502998	502310	11045K	PARTICIPANT	\N	PRESENT	0
502999	502310	19683J	PARTICIPANT	\N	PRESENT	0
503000	502310	14281W	PARTICIPANT	\N	PRESENT	0
503001	502310	19657G	PARTICIPANT	\N	PRESENT	0
503002	502310	20130U	PARTICIPANT	\N	PRESENT	0
503003	502310	19663E	PARTICIPANT	\N	PRESENT	0
503004	502310	19697Q	PARTICIPANT	\N	PRESENT	0
503005	502310	19575F	PARTICIPANT	\N	PRESENT	0
503006	502310	19713W	PARTICIPANT	\N	PRESENT	0
503007	502310	04092N	PARTICIPANT	\N	PRESENT	0
503008	502310	07004J	PARTICIPANT	\N	PRESENT	0
503009	502310	19798U	PARTICIPANT	\N	PRESENT	0
503010	502310	14041T	PARTICIPANT	\N	PRESENT	0
503011	502310	17737W	PARTICIPANT	\N	PRESENT	0
503015	502310	10006L	PARTICIPANT	\N	PRESENT	0
503013	502310	20034V	PARTICIPANT	\N	PRESENT	0
503014	502310	19569H	PARTICIPANT	\N	PRESENT	0
503016	502310	14042U	PARTICIPANT	\N	PRESENT	0
503017	502310	17779H	PARTICIPANT	\N	PRESENT	0
503018	502310	04057K	PARTICIPANT	\N	PRESENT	0
503019	502310	19301E	PARTICIPANT	\N	PRESENT	0
503020	502310	19691J	PARTICIPANT	\N	PRESENT	0
503021	502310	19717B	PARTICIPANT	\N	PRESENT	0
503022	502310	19553Y	PARTICIPANT	\N	PRESENT	0
503023	502310	04043D	PARTICIPANT	\N	PRESENT	0
503024	502310	19715Y	PARTICIPANT	\N	PRESENT	0
503025	502310	19705W	PARTICIPANT	\N	PRESENT	0
503026	502310	01034P	PARTICIPANT	\N	PRESENT	0
503027	502310	20152B	PARTICIPANT	\N	PRESENT	0
503031	502310	05008E	PARTICIPANT	\N	PRESENT	0
503029	502310	19643A	PARTICIPANT	\N	PRESENT	0
503033	502310	19591F	PARTICIPANT	\N	PRESENT	0
503032	502310	14123H	PARTICIPANT	\N	PRESENT	0
503034	502310	14069U	PARTICIPANT	\N	PRESENT	0
486775	485907	04045F	PARTICIPANT	\N	EXCUSE	0
489943	489749	12016W	PARTICIPANT	\N	PRESENT	0
489945	489749	19667J	PARTICIPANT	\N	PRESENT	0
491544	491484	04043D	PARTICIPANT	\N	PRESENT	0
491545	491484	20130U	PARTICIPANT	\N	PRESENT	0
491780	491412	19629C	PARTICIPANT	\N	PRESENT	0
491781	491412	20058E	PARTICIPANT	\N	PRESENT	0
491782	491412	14069U	PARTICIPANT	\N	PRESENT	0
491783	491412	11066Q	PARTICIPANT	\N	PRESENT	0
491784	491412	95063L	PARTICIPANT	\N	PRESENT	0
491785	491412	14133K	PARTICIPANT	\N	PRESENT	0
491786	491412	14083S	PARTICIPANT	\N	PRESENT	0
491787	491412	19693L	PARTICIPANT	\N	PRESENT	0
491788	491412	14211G	PARTICIPANT	\N	PRESENT	0
491789	491467	19768N	PARTICIPANT	\N	PRESENT	0
491790	491467	20088L	PARTICIPANT	\N	PRESENT	0
491791	491467	19515S	PARTICIPANT	\N	PRESENT	0
491792	491467	20092G	PARTICIPANT	\N	PRESENT	0
491793	491467	19782L	PARTICIPANT	\N	PRESENT	0
491794	491467	14357A	PARTICIPANT	\N	PRESENT	0
491795	491467	19441R	PARTICIPANT	\N	PRESENT	0
491796	491467	20082E	PARTICIPANT	\N	PRESENT	0
491797	491467	04045F	PARTICIPANT	\N	PRESENT	0
491798	491467	19631V	PARTICIPANT	\N	PRESENT	0
491799	491467	11099A	PARTICIPANT	\N	PRESENT	0
491800	491467	08015R	PARTICIPANT	\N	PRESENT	0
491801	491467	19575F	PARTICIPANT	\N	PRESENT	0
491802	491467	19369B	PARTICIPANT	\N	PRESENT	0
491803	491467	08028W	PARTICIPANT	\N	PRESENT	0
491804	491467	20030R	PARTICIPANT	\N	PRESENT	0
491805	491467	19467C	PARTICIPANT	\N	PRESENT	0
491806	491467	20034V	PARTICIPANT	\N	PRESENT	0
491807	491467	19695N	PARTICIPANT	\N	PRESENT	0
491808	491467	11090Q	PRESIDENT	0	PRESENT	0
491809	491467	01025N	PARTICIPANT	\N	PRESENT	0
491810	491467	20054A	PARTICIPANT	\N	PRESENT	0
491811	491467	14205J	PARTICIPANT	\N	PRESENT	0
491812	491467	20060X	PARTICIPANT	\N	PRESENT	0
491813	491467	14251Q	PARTICIPANT	\N	PRESENT	0
491814	491467	19507S	PARTICIPANT	\N	PRESENT	0
491815	491467	19747H	PARTICIPANT	\N	PRESENT	0
491816	491467	14257W	PARTICIPANT	\N	PRESENT	0
491817	491467	20144B	PARTICIPANT	\N	EXCUSE	0
492124	491509	20090E	PARTICIPANT	\N	PRESENT	0
492125	491509	04092N	PARTICIPANT	\N	PRESENT	0
492126	491509	19713W	PARTICIPANT	\N	PRESENT	0
492127	491509	11097X	PARTICIPANT	\N	PRESENT	0
492128	491509	08045X	PARTICIPANT	\N	PRESENT	0
492129	491509	20040T	PARTICIPANT	\N	PRESENT	0
492130	491509	19301E	PARTICIPANT	\N	PRESENT	0
492131	491509	19691J	PARTICIPANT	\N	PRESENT	0
492132	491509	14223L	PARTICIPANT	\N	PRESENT	0
492133	491509	17779H	PARTICIPANT	\N	PRESENT	0
492134	491509	19723Y	PARTICIPANT	\N	PRESENT	0
492135	491509	19703U	PARTICIPANT	\N	PRESENT	0
492136	491509	11031D	PARTICIPANT	\N	PRESENT	0
492137	491509	19553Y	PARTICIPANT	\N	PRESENT	0
492138	491509	20066E	PARTICIPANT	\N	PRESENT	0
492139	491509	19679N	PARTICIPANT	\N	PRESENT	0
492140	491509	14042U	PARTICIPANT	\N	PRESENT	0
492141	491509	14195A	PARTICIPANT	\N	PRESENT	0
492142	491509	14213J	PARTICIPANT	\N	PRESENT	0
492143	491509	19367Y	PARTICIPANT	\N	PRESENT	0
492144	491509	04043D	PARTICIPANT	\N	PRESENT	0
492145	491509	10006L	PRESIDENT	0	PRESENT	0
492146	491509	19657G	PARTICIPANT	\N	PRESENT	0
492170	491469	14097Y	PARTICIPANT	\N	PRESENT	0
492171	491469	14059S	PARTICIPANT	\N	PRESENT	0
492172	491469	04035D	PARTICIPANT	\N	PRESENT	0
492173	491469	12041X	PARTICIPANT	\N	PRESENT	0
492174	491469	04034C	PARTICIPANT	\N	PRESENT	0
492175	491469	20042V	PARTICIPANT	\N	PRESENT	0
492176	491469	04042C	PRESIDENT	0	PRESENT	0
492177	491469	19669L	PARTICIPANT	\N	PRESENT	0
492178	491469	11066Q	PARTICIPANT	\N	PRESENT	0
492179	491469	19721W	PARTICIPANT	\N	PRESENT	0
492180	491469	12028B	PARTICIPANT	\N	PRESENT	0
492181	491469	19421M	PARTICIPANT	\N	PRESENT	0
492182	491469	19709B	PARTICIPANT	\N	PRESENT	0
492183	491469	98022P	PARTICIPANT	\N	PRESENT	0
492184	491469	19347U	PARTICIPANT	\N	PRESENT	0
492185	491469	14193X	PARTICIPANT	\N	PRESENT	0
492186	491469	97011G	PARTICIPANT	\N	PRESENT	0
492187	491469	14255U	PARTICIPANT	\N	PRESENT	0
492188	491469	08069G	PARTICIPANT	\N	PRESENT	0
492189	491469	20064C	PARTICIPANT	\N	PRESENT	0
492190	491469	11027H	PARTICIPANT	\N	PRESENT	0
492191	491469	01024M	PARTICIPANT	\N	PRESENT	0
492192	491474	19782L	PARTICIPANT	\N	PRESENT	0
492193	491474	19521Q	PARTICIPANT	\N	PRESENT	0
492194	491474	14038Y	PARTICIPANT	\N	PRESENT	0
492195	491474	19747H	PARTICIPANT	\N	PRESENT	0
492196	491474	20144B	PARTICIPANT	\N	EXCUSE	0
492197	491469	20072C	PARTICIPANT	\N	PRESENT	0
492198	491469	19565D	PARTICIPANT	\N	PRESENT	0
492199	491488	20074E	PARTICIPANT	\N	PRESENT	0
492200	491488	19543W	PARTICIPANT	\N	PRESENT	0
492201	491488	19581D	PARTICIPANT	\N	PRESENT	0
492202	491488	19585H	PARTICIPANT	\N	PRESENT	0
492203	491488	04047H	PRESIDENT	0	PRESENT	0
492204	491488	01028R	PARTICIPANT	\N	PRESENT	0
492205	491488	19675J	PARTICIPANT	\N	PRESENT	0
492206	491488	05008E	PARTICIPANT	\N	PRESENT	0
492207	491488	19954N	PARTICIPANT	\N	PRESENT	0
492208	491488	19489J	PARTICIPANT	\N	PRESENT	0
492209	491488	07004J	PARTICIPANT	\N	PRESENT	0
492211	491488	14041T	PARTICIPANT	\N	PRESENT	0
492212	491488	20110Q	PARTICIPANT	\N	PRESENT	0
492213	491488	20114U	PARTICIPANT	\N	PRESENT	0
492214	491488	14215L	PARTICIPANT	\N	PRESENT	0
492215	491488	08018U	PARTICIPANT	\N	PRESENT	0
492216	491488	14259Y	PARTICIPANT	\N	PRESENT	0
492217	491488	11072N	PARTICIPANT	\N	PRESENT	0
492218	491488	14053L	PARTICIPANT	\N	PRESENT	0
492219	491488	14111D	PARTICIPANT	\N	PRESENT	0
492220	491488	11026G	PARTICIPANT	\N	PRESENT	0
492221	491488	11033F	PARTICIPANT	\N	PRESENT	0
492222	491488	14089Y	PARTICIPANT	\N	PRESENT	0
492223	491488	19725B	PARTICIPANT	\N	PRESENT	0
492224	491488	95063L	PARTICIPANT	\N	PRESENT	0
492225	491488	19629C	PARTICIPANT	\N	PRESENT	0
492226	491488	14069U	PARTICIPANT	\N	PRESENT	0
492227	491488	11085T	PARTICIPANT	\N	PRESENT	0
492228	491488	04008A	PARTICIPANT	\N	PRESENT	0
492229	491488	19749K	PARTICIPANT	\N	PRESENT	0
492230	491488	14021P	PARTICIPANT	\N	PRESENT	0
492231	491488	11056N	PARTICIPANT	\N	PRESENT	0
492233	491488	14151M	PARTICIPANT	\N	PRESENT	0
492234	491474	20028X	PARTICIPANT	\N	PRESENT	0
492274	491472	20116W	PARTICIPANT	\N	PRESENT	0
492236	491510	11067R	PARTICIPANT	\N	PRESENT	0
492237	491510	19569H	PARTICIPANT	\N	PRESENT	0
492238	491510	19415P	PARTICIPANT	\N	PRESENT	0
492239	491510	18193Q	PARTICIPANT	\N	PRESENT	0
492240	491510	14281W	PARTICIPANT	\N	PRESENT	0
492242	491510	14217N	PARTICIPANT	\N	PRESENT	0
492243	491510	19683J	PARTICIPANT	\N	PRESENT	0
492244	491510	20130U	PARTICIPANT	\N	PRESENT	0
492245	491510	01034P	PARTICIPANT	\N	PRESENT	0
492246	491510	17965H	PARTICIPANT	\N	PRESENT	0
492248	491488	17737W	PARTICIPANT	\N	PRESENT	0
492249	491510	14026U	PARTICIPANT	\N	PRESENT	0
492250	491510	14195A	PARTICIPANT	\N	PRESENT	0
492251	491510	19723Y	PARTICIPANT	\N	PRESENT	0
492252	491472	14327T	PARTICIPANT	\N	PRESENT	0
492253	491472	04071H	PARTICIPANT	\N	PRESENT	0
492254	491472	19647E	PARTICIPANT	\N	PRESENT	0
492255	491472	11048N	PARTICIPANT	\N	PRESENT	0
492256	491472	19711U	PARTICIPANT	\N	PRESENT	0
492257	491472	20036X	PARTICIPANT	\N	PRESENT	0
492258	491472	01048V	PARTICIPANT	\N	PRESENT	0
492259	491472	19531S	PARTICIPANT	\N	PRESENT	0
492260	491472	14189C	PARTICIPANT	\N	PRESENT	0
492261	491472	08034U	PARTICIPANT	\N	PRESENT	0
492262	491472	19545Y	PARTICIPANT	\N	PRESENT	0
492263	491472	01057W	PARTICIPANT	\N	PRESENT	0
492264	491472	20080C	PARTICIPANT	\N	PRESENT	0
492265	491472	19667J	PARTICIPANT	\N	PRESENT	0
492266	491472	14225N	PRESIDENT	0	PRESENT	0
492268	491472	04086Q	PARTICIPANT	\N	PRESENT	0
492269	491472	11040E	PARTICIPANT	\N	PRESENT	0
492270	491472	11012A	PARTICIPANT	\N	PRESENT	0
492271	491472	20070A	PARTICIPANT	\N	PRESENT	0
492272	491472	08009T	PARTICIPANT	\N	PRESENT	0
492273	491472	19741B	PARTICIPANT	\N	PRESENT	0
498573	497011	07029T	PARTICIPANT	\N	PRESENT	0
498574	497011	14121F	PARTICIPANT	\N	PRESENT	0
498575	497845	18083K	PARTICIPANT	\N	PRESENT	0
498576	497845	20068G	PARTICIPANT	\N	PRESENT	0
498577	497845	19739H	PARTICIPANT	\N	PRESENT	0
498578	497845	20024T	PARTICIPANT	\N	PRESENT	0
498579	497845	19637C	PARTICIPANT	\N	PRESENT	0
498580	497845	14169X	PARTICIPANT	\N	PRESENT	0
498581	497011	08034U	PARTICIPANT	\N	PRESENT	0
498582	497845	20122U	PARTICIPANT	\N	PRESENT	0
498583	497845	14031R	PARTICIPANT	\N	PRESENT	0
498584	497845	20140W	PARTICIPANT	\N	PRESENT	0
498585	497845	14219Q	PRESIDENT	0	PRESENT	0
498586	497845	20106U	PARTICIPANT	\N	PRESENT	0
498587	497845	20032T	PARTICIPANT	\N	PRESENT	0
498588	497845	19503N	PARTICIPANT	\N	PRESENT	0
498589	497845	19551W	PARTICIPANT	\N	EXCUSE	0
498590	497845	19681G	PARTICIPANT	\N	EXCUSE	0
498591	497845	19820Y	PARTICIPANT	\N	PRESENT	0
498592	497845	20118Y	PARTICIPANT	\N	PRESENT	0
498593	497011	19647E	PARTICIPANT	\N	PRESENT	0
498594	497011	14083S	PARTICIPANT	\N	PRESENT	0
498595	497011	08011M	PARTICIPANT	\N	PRESENT	0
498596	497984	19443T	PARTICIPANT	\N	PRESENT	0
498597	497984	19565D	PARTICIPANT	\N	PRESENT	0
498569	497845	20020P	PARTICIPANT	\N	PRESENT	0
498570	497845	19745F	PARTICIPANT	\N	PRESENT	0
498571	497845	20102Q	PARTICIPANT	\N	PRESENT	0
498572	497011	11110B	PARTICIPANT	\N	PRESENT	0
498598	497984	20072C	PARTICIPANT	\N	PRESENT	0
498599	497984	04034C	PARTICIPANT	\N	PRESENT	0
498600	497984	01058X	PARTICIPANT	\N	PRESENT	0
498601	497984	11027H	PARTICIPANT	\N	PRESENT	0
498602	497984	11054L	PARTICIPANT	\N	PRESENT	0
498603	497984	08056B	PARTICIPANT	\N	PRESENT	0
498604	497984	12028B	PARTICIPANT	\N	PRESENT	0
498605	497984	19421M	PARTICIPANT	\N	PRESENT	0
498606	497984	19709B	PARTICIPANT	\N	PRESENT	0
498607	497984	14193X	PRESIDENT	0	PRESENT	0
498608	497984	19347U	PARTICIPANT	\N	PRESENT	0
498609	497984	08047A	PARTICIPANT	\N	PRESENT	0
498610	497984	20128B	PARTICIPANT	\N	PRESENT	0
498611	497984	14059S	PARTICIPANT	\N	PRESENT	0
498612	497984	14097Y	PARTICIPANT	\N	PRESENT	0
498613	497984	04035D	PARTICIPANT	\N	PRESENT	0
498614	497984	14133K	PARTICIPANT	\N	PRESENT	0
498615	497984	20042V	PARTICIPANT	\N	PRESENT	0
498616	497984	01024M	PARTICIPANT	\N	PRESENT	0
498617	497984	14105F	PARTICIPANT	\N	PRESENT	0
498618	497984	20064C	PARTICIPANT	\N	PRESENT	0
498619	497984	98022P	PARTICIPANT	\N	PRESENT	0
498620	497984	11083R	PARTICIPANT	\N	PRESENT	0
498621	497984	14255U	PARTICIPANT	\N	PRESENT	0
498622	497845	19826F	PARTICIPANT	\N	PRESENT	0
498623	497984	17023S	PARTICIPANT	\N	PRESENT	0
498624	497984	16685X	PARTICIPANT	\N	PRESENT	0
498625	497984	19721W	PARTICIPANT	\N	PRESENT	0
498626	497845	19701S	PARTICIPANT	\N	PRESENT	0
498627	497845	19549D	PARTICIPANT	\N	PRESENT	0
498628	497845	19387D	PARTICIPANT	\N	PRESENT	0
498629	497845	20096L	PARTICIPANT	\N	PRESENT	0
498630	497845	20100N	PARTICIPANT	\N	PRESENT	0
498631	497845	08060W	PARTICIPANT	\N	PRESENT	0
498632	497845	11065P	PARTICIPANT	\N	PRESENT	0
498633	497845	20038A	PARTICIPANT	\N	PRESENT	0
498635	498113	19697Q	PARTICIPANT	\N	PRESENT	0
498636	498113	11067R	PARTICIPANT	\N	PRESENT	0
498637	498113	20090E	PARTICIPANT	\N	PRESENT	0
498638	498113	19569H	PARTICIPANT	\N	PRESENT	0
498639	498113	19798U	PARTICIPANT	\N	PRESENT	0
498640	498113	11097X	PARTICIPANT	\N	PRESENT	0
498641	498113	19415P	PARTICIPANT	\N	PRESENT	0
498642	498113	14223L	PARTICIPANT	\N	PRESENT	0
498643	498113	18193Q	PARTICIPANT	\N	PRESENT	0
498644	498113	14026U	PARTICIPANT	\N	PRESENT	0
498645	498113	17779H	PARTICIPANT	\N	PRESENT	0
498646	498113	19553Y	PARTICIPANT	\N	PRESENT	0
498647	498113	19703U	PARTICIPANT	\N	PRESENT	0
498648	498113	11031D	PARTICIPANT	\N	PRESENT	0
498649	498113	14281W	PARTICIPANT	\N	PRESENT	0
498650	498113	19679N	PARTICIPANT	\N	PRESENT	0
498651	498113	14042U	PARTICIPANT	\N	PRESENT	0
498652	498113	14195A	PARTICIPANT	\N	PRESENT	0
498653	498113	14213J	PARTICIPANT	\N	PRESENT	0
498654	498113	14217N	PARTICIPANT	\N	PRESENT	0
498655	498113	19683J	PARTICIPANT	\N	PRESENT	0
498656	498113	10006L	PRESIDENT	0	PRESENT	0
498657	498113	20126Y	PARTICIPANT	\N	PRESENT	0
498658	498113	19591F	PARTICIPANT	\N	PRESENT	0
498659	498113	20130U	PARTICIPANT	\N	PRESENT	0
498660	498113	01034P	PARTICIPANT	\N	PRESENT	0
498661	498113	04092N	PARTICIPANT	\N	PRESENT	0
498662	498113	19713W	PARTICIPANT	\N	PRESENT	0
498663	498113	08045X	PARTICIPANT	\N	PRESENT	0
498664	498113	17965H	PARTICIPANT	\N	PRESENT	0
498665	498113	19301E	PARTICIPANT	\N	PRESENT	0
498666	498113	19691J	PARTICIPANT	\N	PRESENT	0
498667	498113	20172F	PARTICIPANT	\N	PRESENT	0
498668	498113	19723Y	PARTICIPANT	\N	PRESENT	0
498669	498113	20066E	PARTICIPANT	\N	PRESENT	0
498670	498113	11103C	PARTICIPANT	\N	PRESENT	0
498671	498113	14071N	PARTICIPANT	\N	PRESENT	0
498672	498113	19657G	PARTICIPANT	\N	PRESENT	0
498673	498113	04043D	PARTICIPANT	\N	PRESENT	0
498674	498113	19760E	PARTICIPANT	\N	PRESENT	0
498675	497011	19531S	PARTICIPANT	\N	PRESENT	0
498676	497984	97011G	PARTICIPANT	\N	PRESENT	0
498677	497011	19335Q	PARTICIPANT	\N	PRESENT	0
498678	497011	96004D	PARTICIPANT	\N	PRESENT	0
498708	497011	19667J	PARTICIPANT	\N	PRESENT	0
498709	497011	19349W	PARTICIPANT	\N	PRESENT	0
498710	497984	11064N	PARTICIPANT	\N	PRESENT	0
498711	497011	11070L	PARTICIPANT	\N	PRESENT	0
498712	497011	19545Y	PARTICIPANT	\N	PRESENT	0
498713	497845	20022R	PARTICIPANT	\N	PRESENT	0
498714	497845	17637T	PARTICIPANT	\N	PRESENT	0
498715	497845	19251M	PARTICIPANT	\N	PRESENT	0
498716	497845	19619A	PARTICIPANT	\N	PRESENT	0
498717	497845	19599P	PARTICIPANT	\N	PRESENT	0
498718	497845	20046A	PARTICIPANT	\N	EXCUSE	0
498719	497011	14327T	PARTICIPANT	\N	PRESENT	0
498720	497011	19479G	PARTICIPANT	\N	PRESENT	0
498725	497011	19679N	PARTICIPANT	\N	PRESENT	0
498726	498008	20086J	PARTICIPANT	\N	PRESENT	0
498727	498008	19768N	PARTICIPANT	\N	PRESENT	0
498728	498008	19515S	PARTICIPANT	\N	PRESENT	0
498729	498008	20092G	PARTICIPANT	\N	PRESENT	0
498730	498008	19782L	PARTICIPANT	\N	PRESENT	0
498731	498008	14357A	PARTICIPANT	\N	PRESENT	0
498732	498008	19441R	PARTICIPANT	\N	PRESENT	0
498733	498008	20078J	PARTICIPANT	\N	PRESENT	0
498734	498008	20082E	PARTICIPANT	\N	PRESENT	0
498735	498008	20104S	PARTICIPANT	\N	PRESENT	0
498736	498008	19631V	PARTICIPANT	\N	PRESENT	0
498737	498008	11099A	PARTICIPANT	\N	PRESENT	0
498738	498008	19705W	PARTICIPANT	\N	PRESENT	0
498739	498008	08015R	PARTICIPANT	\N	PRESENT	0
498740	498008	19575F	PARTICIPANT	\N	PRESENT	0
498741	498008	19369B	PARTICIPANT	\N	PRESENT	0
498742	498008	20018V	PARTICIPANT	\N	PRESENT	0
498743	498008	19511N	PARTICIPANT	\N	PRESENT	0
498744	498008	19563B	PARTICIPANT	\N	PRESENT	0
498745	498008	19521Q	PARTICIPANT	\N	PRESENT	0
498746	498008	20028X	PARTICIPANT	\N	PRESENT	0
498747	498008	14329V	PARTICIPANT	\N	PRESENT	0
498748	498008	20030R	PARTICIPANT	\N	PRESENT	0
498749	498008	14038Y	PARTICIPANT	\N	PRESENT	0
498750	498008	19467C	PARTICIPANT	\N	PRESENT	0
498751	498008	14187A	PARTICIPANT	\N	PRESENT	0
498752	498008	20144B	PARTICIPANT	\N	PRESENT	0
498753	498008	19695N	PARTICIPANT	\N	PRESENT	0
498754	498008	11090Q	PRESIDENT	0	PRESENT	0
498755	498008	14033T	PARTICIPANT	\N	PRESENT	0
498756	498008	20054A	PARTICIPANT	\N	PRESENT	0
498757	498008	20174H	PARTICIPANT	\N	PRESENT	0
498758	498008	14205J	PARTICIPANT	\N	PRESENT	0
498759	498008	20060X	PARTICIPANT	\N	PRESENT	0
498760	498008	20062A	PARTICIPANT	\N	PRESENT	0
498761	498008	19507S	PARTICIPANT	\N	PRESENT	0
498762	498008	14207L	PARTICIPANT	\N	PRESENT	0
498763	498008	19747H	PARTICIPANT	\N	PRESENT	0
498764	498008	04045F	PARTICIPANT	\N	EXCUSE	0
498765	498008	08028W	PARTICIPANT	\N	EXCUSE	0
486136	479206	04044E	PARTICIPANT	\N	PRESENT	0
486138	479206	19687N	PARTICIPANT	\N	PRESENT	0
486139	479206	19503N	PARTICIPANT	\N	PRESENT	0
486140	479206	19599P	PARTICIPANT	\N	PRESENT	0
486141	479206	19549D	PARTICIPANT	\N	PRESENT	0
486142	479206	14085U	PARTICIPANT	\N	PRESENT	0
486143	479206	19926J	PARTICIPANT	\N	PRESENT	0
486144	479206	19912C	PARTICIPANT	\N	PRESENT	0
486145	479206	14225N	PARTICIPANT	\N	PRESENT	0
486146	479206	19349W	PARTICIPANT	\N	PRESENT	0
486147	479206	11099A	PARTICIPANT	\N	PRESENT	0
486148	479206	14205J	PARTICIPANT	\N	PRESENT	0
486149	479206	19671E	PARTICIPANT	\N	PRESENT	0
486150	479206	19713W	PARTICIPANT	\N	PRESENT	0
486151	479206	14041T	PARTICIPANT	\N	PRESENT	0
486152	479206	07029T	PARTICIPANT	\N	PRESENT	0
486153	479206	19399H	PARTICIPANT	\N	PRESENT	0
486154	479206	01057W	PARTICIPANT	\N	PRESENT	0
486155	479206	11090Q	PARTICIPANT	\N	PRESENT	0
486156	479206	04018C	PARTICIPANT	\N	PRESENT	0
486157	479206	19533U	PARTICIPANT	\N	PRESENT	0
486158	479206	11064N	PARTICIPANT	\N	PRESENT	0
486159	479206	19719D	PARTICIPANT	\N	PRESENT	0
486160	479206	19647E	PARTICIPANT	\N	PRESENT	0
486161	479206	07004J	PARTICIPANT	\N	PRESENT	0
486162	479206	19565D	PARTICIPANT	\N	PRESENT	0
486163	479206	12016W	PARTICIPANT	\N	PRESENT	0
486164	479206	04086Q	PARTICIPANT	\N	PRESENT	0
486165	479206	19762G	PARTICIPANT	\N	PRESENT	0
486166	479206	99004R	PARTICIPANT	\N	PRESENT	0
486167	479206	19760E	PARTICIPANT	\N	PRESENT	0
486168	479206	19593H	PARTICIPANT	\N	PRESENT	0
486169	479206	19347U	PARTICIPANT	\N	PRESENT	0
486170	479206	19695N	PARTICIPANT	\N	PRESENT	0
486171	479206	12041X	PARTICIPANT	\N	PRESENT	0
486137	479206	08011M	PARTICIPANT	\N	PRESENT	0
486172	479206	14034U	PARTICIPANT	\N	PRESENT	0
486173	479206	01043Q	PARTICIPANT	\N	PRESENT	0
486174	479206	19295A	PARTICIPANT	\N	PRESENT	0
486175	479206	11109J	PARTICIPANT	\N	PRESENT	0
486176	479206	14357A	PARTICIPANT	\N	PRESENT	0
486177	479206	08069G	PARTICIPANT	\N	PRESENT	0
486178	479206	19749K	PARTICIPANT	\N	PRESENT	0
486179	479206	11053K	PARTICIPANT	\N	PRESENT	0
486180	479206	19711U	PARTICIPANT	\N	PRESENT	0
486181	479206	14255U	PARTICIPANT	\N	PRESENT	0
486182	479206	19551W	PARTICIPANT	\N	PRESENT	0
486183	479206	19741B	PARTICIPANT	\N	PRESENT	0
486184	479206	14327T	PARTICIPANT	\N	PRESENT	0
486185	479206	11048N	PARTICIPANT	\N	PRESENT	0
486186	479206	08073C	PARTICIPANT	\N	PRESENT	0
486188	479206	11026G	PARTICIPANT	\N	PRESENT	0
488314	487670	19367Y	PARTICIPANT	\N	EXCUSE	0
488315	487670	01034P	PARTICIPANT	\N	EXCUSE	0
488316	487670	14071N	PARTICIPANT	\N	EXCUSE	0
488317	487670	19565D	PARTICIPANT	\N	EXCUSE	0
488318	487670	11031D	PARTICIPANT	\N	EXCUSE	0
488319	487670	14213J	PARTICIPANT	\N	EXCUSE	0
488320	487909	11012A	PARTICIPANT	\N	EXCUSE	0
488321	487909	01034P	PARTICIPANT	\N	EXCUSE	0
488322	487909	95041E	PARTICIPANT	\N	PRESENT	0
488323	487669	19741B	PARTICIPANT	\N	PRESENT	0
488324	487669	19367Y	PARTICIPANT	\N	EXCUSE	0
488325	487669	01034P	PARTICIPANT	\N	EXCUSE	0
488326	487669	14071N	PARTICIPANT	\N	EXCUSE	0
488327	487669	19565D	PARTICIPANT	\N	EXCUSE	0
488328	487669	11031D	PARTICIPANT	\N	EXCUSE	0
488329	487669	14213J	PARTICIPANT	\N	EXCUSE	0
488617	488616	01058X	PARTICIPANT	\N	PRESENT	0
488618	488616	19533U	PARTICIPANT	\N	PRESENT	0
488874	488467	19503N	PARTICIPANT	\N	PRESENT	0
489779	489345	19766L	PARTICIPANT	\N	PRESENT	0
489780	489345	19697Q	PARTICIPANT	\N	PRESENT	0
489781	489345	19643A	PARTICIPANT	\N	PRESENT	0
489782	489345	14331P	PARTICIPANT	\N	PRESENT	0
489783	489345	19479G	PARTICIPANT	\N	PRESENT	0
489784	489345	11067R	PARTICIPANT	\N	PRESENT	0
489785	489345	19649G	PARTICIPANT	\N	PRESENT	0
489786	489345	19569H	PARTICIPANT	\N	PRESENT	0
489787	489345	11097X	PRESIDENT	0	PRESENT	0
489788	489345	14081Q	PARTICIPANT	\N	PRESENT	0
489789	489345	19663E	PARTICIPANT	\N	PRESENT	0
489790	489345	19715Y	PARTICIPANT	\N	PRESENT	0
489791	489345	19667J	PARTICIPANT	\N	PRESENT	0
489792	489345	19447X	PARTICIPANT	\N	PRESENT	0
489793	489345	11031D	PARTICIPANT	\N	PRESENT	0
489794	489345	19553Y	PARTICIPANT	\N	PRESENT	0
489795	489345	19703U	PARTICIPANT	\N	PRESENT	0
489796	489345	04059M	PARTICIPANT	\N	PRESENT	0
489797	489345	19503N	PARTICIPANT	\N	PRESENT	0
489798	489345	19349W	PARTICIPANT	\N	PRESENT	0
489799	489345	99004R	PARTICIPANT	\N	PRESENT	0
489800	489345	19683J	PARTICIPANT	\N	PRESENT	0
489801	489345	10006L	PARTICIPANT	\N	PRESENT	0
489827	489173	19695N	PARTICIPANT	\N	PRESENT	0
489948	489947	04008A	PARTICIPANT	\N	PRESENT	0
489949	489947	04042C	PARTICIPANT	\N	PRESENT	0
489950	489947	14041T	PARTICIPANT	\N	PRESENT	0
489951	489947	19954N	PARTICIPANT	\N	PRESENT	0
489953	489952	04008A	PARTICIPANT	\N	PRESENT	0
489954	489952	11026G	PARTICIPANT	\N	PRESENT	0
489955	489952	95063L	PARTICIPANT	\N	PRESENT	0
490804	490447	20086J	PARTICIPANT	\N	PRESENT	0
490805	490447	19383Y	PARTICIPANT	\N	PRESENT	0
490806	490447	19768N	PARTICIPANT	\N	PRESENT	0
490807	490447	20088L	PARTICIPANT	\N	PRESENT	0
490808	490447	19515S	PARTICIPANT	\N	PRESENT	0
490809	490447	19782L	PARTICIPANT	\N	PRESENT	0
490810	490447	11077T	PARTICIPANT	\N	PRESENT	0
490811	490447	20092G	PARTICIPANT	\N	PRESENT	0
490812	490447	01043Q	PARTICIPANT	\N	PRESENT	0
490813	490447	14357A	PARTICIPANT	\N	PRESENT	0
490814	490447	20078J	PARTICIPANT	\N	PRESENT	0
490815	490447	19441R	PARTICIPANT	\N	PRESENT	0
490816	490447	19413M	PARTICIPANT	\N	PRESENT	0
490817	490447	20082E	PARTICIPANT	\N	PRESENT	0
490818	490447	04045F	PARTICIPANT	\N	PRESENT	0
490819	490447	19866P	PARTICIPANT	\N	PRESENT	0
490820	490447	20104S	PARTICIPANT	\N	PRESENT	0
490821	490447	19631V	PARTICIPANT	\N	PRESENT	0
490822	490447	11099A	PARTICIPANT	\N	PRESENT	0
490823	490447	19705W	PARTICIPANT	\N	PRESENT	0
490824	490447	08015R	PARTICIPANT	\N	PRESENT	0
490825	490447	19575F	PARTICIPANT	\N	PRESENT	0
490826	490447	19369B	PARTICIPANT	\N	PRESENT	0
490827	490447	20018V	PARTICIPANT	\N	PRESENT	0
490828	490447	19511N	PARTICIPANT	\N	PRESENT	0
490829	490447	08028W	PRESIDENT	0	PRESENT	0
490830	490447	19563B	PARTICIPANT	\N	PRESENT	0
490831	490447	19521Q	PARTICIPANT	\N	PRESENT	0
490832	490447	14329V	PARTICIPANT	\N	PRESENT	0
490833	490447	20028X	PARTICIPANT	\N	PRESENT	0
490834	490447	14038Y	PARTICIPANT	\N	PRESENT	0
490835	490447	20030R	PARTICIPANT	\N	PRESENT	0
490836	490447	19467C	PARTICIPANT	\N	PRESENT	0
490837	490447	20034V	PARTICIPANT	\N	PRESENT	0
490838	490447	14187A	PARTICIPANT	\N	PRESENT	0
490839	490447	20144B	PARTICIPANT	\N	PRESENT	0
490840	490447	19695N	PARTICIPANT	\N	PRESENT	0
490841	490447	11090Q	PRESIDENT	1	PRESENT	0
490842	490447	14033T	PARTICIPANT	\N	PRESENT	0
490843	490447	01025N	PARTICIPANT	\N	PRESENT	0
490844	490447	20054A	PARTICIPANT	\N	PRESENT	0
490845	490447	14205J	PARTICIPANT	\N	PRESENT	0
490846	490447	20060X	PARTICIPANT	\N	PRESENT	0
490847	490447	20062A	PARTICIPANT	\N	PRESENT	0
490848	490447	14251Q	PARTICIPANT	\N	PRESENT	0
490849	490447	19507S	PARTICIPANT	\N	PRESENT	0
490850	490447	19747H	PARTICIPANT	\N	PRESENT	0
490851	490447	14257W	PARTICIPANT	\N	PRESENT	0
490852	490467	17583W	PARTICIPANT	\N	PRESENT	0
490853	490467	11067R	PARTICIPANT	\N	PRESENT	0
490854	490467	19798U	PARTICIPANT	\N	PRESENT	0
490855	490467	11097X	PARTICIPANT	\N	PRESENT	0
490856	490467	19553Y	PARTICIPANT	\N	PRESENT	0
490857	490467	19966S	PARTICIPANT	\N	PRESENT	0
490858	490467	19679N	PARTICIPANT	\N	PRESENT	0
490859	490467	14042U	PARTICIPANT	\N	PRESENT	0
490860	490467	10006L	PRESIDENT	1	PRESENT	0
490861	490467	19683J	PARTICIPANT	\N	PRESENT	0
490862	490467	04057K	PARTICIPANT	\N	PRESENT	0
490863	490467	04092N	PARTICIPANT	0	PRESENT	0
490864	490467	20040T	PARTICIPANT	\N	PRESENT	0
490865	490467	19663E	PARTICIPANT	\N	PRESENT	0
490866	490467	19691J	PARTICIPANT	\N	PRESENT	0
490867	490467	19289C	PARTICIPANT	\N	PRESENT	0
490868	490467	20066E	PARTICIPANT	\N	PRESENT	0
490869	490467	14071N	PARTICIPANT	\N	PRESENT	0
503072	502311	11031D	PARTICIPANT	\N	PRESENT	0
503073	502311	19663E	PARTICIPANT	\N	PRESENT	0
503074	502311	14041T	PARTICIPANT	\N	PRESENT	0
503075	502311	19715Y	PARTICIPANT	\N	PRESENT	0
503076	502311	19657G	PARTICIPANT	\N	PRESENT	0
503077	502311	19711U	PARTICIPANT	\N	PRESENT	0
503070	502311	99004R	PARTICIPANT	\N	PRESENT	0
503071	502311	19760E	PARTICIPANT	\N	PRESENT	0
503078	502311	18193Q	PARTICIPANT	\N	PRESENT	0
503079	502311	11097X	PARTICIPANT	\N	PRESENT	0
503080	502311	11045K	PARTICIPANT	\N	PRESENT	0
503081	502311	19683J	PARTICIPANT	\N	PRESENT	0
503082	502311	17737W	PARTICIPANT	\N	PRESENT	0
503083	502311	17779H	PARTICIPANT	\N	PRESENT	0
503084	502311	14071N	PARTICIPANT	\N	PRESENT	0
503085	502311	20130U	PARTICIPANT	\N	PRESENT	0
503086	502311	20152B	PARTICIPANT	\N	PRESENT	0
503087	502311	10006L	PARTICIPANT	\N	PRESENT	0
503088	502311	14026U	PARTICIPANT	\N	PRESENT	0
503089	502311	14213J	PARTICIPANT	\N	PRESENT	0
503090	502311	04057K	PARTICIPANT	\N	PRESENT	0
503091	502311	19798U	PARTICIPANT	\N	PRESENT	0
503092	502311	14042U	PARTICIPANT	\N	PRESENT	0
503093	502311	19569H	PARTICIPANT	\N	PRESENT	0
503094	502311	19553Y	PARTICIPANT	\N	PRESENT	0
503095	502311	19691J	PARTICIPANT	\N	PRESENT	0
503096	502311	01034P	PARTICIPANT	\N	PRESENT	0
503097	502311	07004J	PARTICIPANT	\N	PRESENT	0
503098	502311	20148F	PARTICIPANT	\N	PRESENT	0
503099	502311	19643A	PARTICIPANT	\N	PRESENT	0
503100	502311	19697Q	PARTICIPANT	\N	PRESENT	0
503101	502311	20034V	PARTICIPANT	\N	PRESENT	0
503102	502311	19717B	PARTICIPANT	\N	PRESENT	0
503103	502311	19301E	PARTICIPANT	\N	PRESENT	0
503104	502311	14281W	PARTICIPANT	\N	PRESENT	0
503105	502311	14123H	PARTICIPANT	\N	PRESENT	0
503106	502311	11090Q	PARTICIPANT	\N	PRESENT	0
503107	502311	19591F	PARTICIPANT	\N	PRESENT	0
503108	502311	08073C	PARTICIPANT	\N	PRESENT	0
503116	502311	19713W	PARTICIPANT	\N	PRESENT	0
503117	502311	04085P	PARTICIPANT	\N	PRESENT	0
503118	502311	19701S	PARTICIPANT	\N	PRESENT	0
503145	503144	19551W	PARTICIPANT	\N	PRESENT	0
503146	503144	20136B	PARTICIPANT	\N	PRESENT	0
503152	503149	19333N	PARTICIPANT	\N	PRESENT	0
503153	503150	19333N	PARTICIPANT	\N	PRESENT	0
503154	503151	19333N	PARTICIPANT	\N	PRESENT	0
503160	503156	14169X	PARTICIPANT	\N	PRESENT	0
503164	503161	19551W	PARTICIPANT	\N	PRESENT	0
503165	503162	19551W	PARTICIPANT	\N	PRESENT	0
503166	503163	19551W	PARTICIPANT	\N	PRESENT	0
503168	503167	19551W	PARTICIPANT	\N	PRESENT	0
503171	502446	14327T	PARTICIPANT	\N	PRESENT	0
503172	502446	11048N	PARTICIPANT	\N	PRESENT	0
503173	502446	19479G	PARTICIPANT	\N	PRESENT	0
503174	502446	04071H	PARTICIPANT	\N	PRESENT	0
503175	502446	19647E	PARTICIPANT	\N	PRESENT	0
503176	502446	19711U	PARTICIPANT	\N	PRESENT	0
503177	502446	08034U	PARTICIPANT	\N	PRESENT	0
503178	502446	01057W	PARTICIPANT	\N	PRESENT	0
503179	502446	19687N	PARTICIPANT	\N	PRESENT	0
503180	502446	19689Q	PARTICIPANT	\N	PRESENT	0
503181	502446	11053K	PARTICIPANT	\N	PRESENT	0
503182	502446	20044X	PARTICIPANT	\N	PRESENT	0
503183	502446	19671E	PARTICIPANT	\N	PRESENT	0
503184	502446	11070L	PARTICIPANT	\N	PRESENT	0
503185	502446	20150Y	PARTICIPANT	\N	PRESENT	0
503186	502446	14225N	PRESIDENT	0	PRESENT	0
503187	502446	04086Q	PARTICIPANT	\N	PRESENT	0
503188	502446	11040E	PARTICIPANT	\N	PRESENT	0
503189	502446	14083S	PARTICIPANT	\N	PRESENT	0
503190	502446	08073C	PARTICIPANT	\N	PRESENT	0
503191	502446	20070A	PARTICIPANT	\N	PRESENT	0
503192	502446	19349W	PARTICIPANT	\N	PRESENT	0
503193	502446	99004R	PARTICIPANT	\N	PRESENT	0
503194	502446	19762G	PARTICIPANT	\N	PRESENT	0
503204	502446	20080C	PARTICIPANT	\N	PRESENT	0
503205	502446	07029T	PARTICIPANT	\N	EXCUSE	0
503209	501815	08073C	PARTICIPANT	\N	PRESENT	0
503211	501815	19762G	PARTICIPANT	\N	PRESENT	0
503210	501815	14223L	PARTICIPANT	\N	PRESENT	0
503214	501815	01057W	PARTICIPANT	\N	PRESENT	0
503215	501815	07004J	PARTICIPANT	\N	PRESENT	0
503216	501815	14225N	PARTICIPANT	\N	PRESENT	0
503217	501815	20070A	PARTICIPANT	\N	PRESENT	0
503218	501815	19711U	PARTICIPANT	\N	PRESENT	0
503219	501815	14031R	PARTICIPANT	\N	PRESENT	0
503220	501815	19479G	PARTICIPANT	\N	PRESENT	0
503221	501815	20044X	PARTICIPANT	\N	PRESENT	0
503222	501815	14327T	PARTICIPANT	\N	PRESENT	0
503223	501815	11048N	PARTICIPANT	\N	PRESENT	0
503224	501815	11040E	PARTICIPANT	\N	PRESENT	0
503225	501815	19671E	PARTICIPANT	\N	PRESENT	0
503226	501815	20092G	PARTICIPANT	\N	PRESENT	0
503227	501815	19689Q	PARTICIPANT	\N	PRESENT	0
503228	501815	11053K	PARTICIPANT	\N	PRESENT	0
503229	501815	20020P	PARTICIPANT	\N	PRESENT	0
503232	501815	11070L	PARTICIPANT	\N	PRESENT	0
503233	501815	07029T	PARTICIPANT	\N	PRESENT	0
503234	501815	14083S	PARTICIPANT	\N	PRESENT	0
503235	501815	14021P	PARTICIPANT	\N	PRESENT	0
503236	501815	04059M	PARTICIPANT	\N	PRESENT	0
503237	501815	20080C	PARTICIPANT	\N	PRESENT	0
503238	501815	95063L	PARTICIPANT	\N	PRESENT	0
503239	501815	04086Q	PARTICIPANT	\N	PRESENT	0
503240	501815	14211G	PARTICIPANT	\N	PRESENT	0
503241	501815	11074Q	PARTICIPANT	\N	PRESENT	0
503242	501815	19349W	PARTICIPANT	\N	PRESENT	0
503243	501815	20032T	PARTICIPANT	\N	PRESENT	0
503244	501815	20038A	PARTICIPANT	\N	PRESENT	0
503245	501815	20148F	PARTICIPANT	\N	PRESENT	0
503246	501815	20150Y	PARTICIPANT	\N	PRESENT	0
503247	501815	14055N	PARTICIPANT	\N	PRESENT	0
503252	501815	19647E	PARTICIPANT	\N	PRESENT	0
503249	501815	19531S	PARTICIPANT	\N	PRESENT	0
503250	501815	20036X	PARTICIPANT	\N	PRESENT	0
503251	501815	20050V	PARTICIPANT	\N	PRESENT	0
503253	501815	11043H	PARTICIPANT	\N	PRESENT	0
503254	501815	19741B	PARTICIPANT	\N	PRESENT	0
503255	501815	19687N	PARTICIPANT	\N	PRESENT	0
503256	501815	08061X	PARTICIPANT	\N	PRESENT	0
503257	501815	11012A	PARTICIPANT	\N	PRESENT	0
503258	501815	12016W	PARTICIPANT	\N	PRESENT	0
503267	501815	20096L	PARTICIPANT	\N	PRESENT	0
503268	501815	04071H	PARTICIPANT	\N	PRESENT	0
503269	501815	19551W	PARTICIPANT	\N	PRESENT	0
503270	501815	08015R	PARTICIPANT	\N	PRESENT	0
503271	501815	20018V	PARTICIPANT	\N	PRESENT	0
503272	501815	14229S	PARTICIPANT	\N	PRESENT	0
503278	501815	14041T	PARTICIPANT	\N	PRESENT	0
503279	501815	08034U	PARTICIPANT	\N	PRESENT	0
503277	501815	19667J	PARTICIPANT	\N	PRESENT	0
503280	501815	14173T	PARTICIPANT	\N	PRESENT	0
503281	501815	20134Y	PARTICIPANT	\N	PRESENT	0
503282	501815	19657G	PARTICIPANT	\N	PRESENT	0
503283	501815	14030Q	PARTICIPANT	\N	PRESENT	0
503296	501815	14331P	PARTICIPANT	\N	PRESENT	0
503300	501815	19713W	PARTICIPANT	\N	PRESENT	0
503306	501815	14001X	PARTICIPANT	\N	PRESENT	0
503310	501815	14219Q	PARTICIPANT	\N	PRESENT	0
503311	501815	20088L	PARTICIPANT	\N	PRESENT	0
503312	501815	08010L	PARTICIPANT	\N	PRESENT	0
503313	501815	20024T	PARTICIPANT	\N	PRESENT	0
503314	501815	20030R	PARTICIPANT	\N	PRESENT	0
503319	501815	01043Q	PARTICIPANT	\N	PRESENT	0
503320	501815	11026G	PARTICIPANT	\N	PRESENT	0
483469	483467	19503N	PARTICIPANT	\N	PRESENT	0
483472	483470	19503N	PARTICIPANT	\N	PRESENT	0
484573	483190	01048V	PARTICIPANT	\N	PRESENT	0
484575	483190	19593H	PARTICIPANT	\N	PRESENT	0
484698	484696	19503N	PARTICIPANT	\N	PRESENT	0
484701	484699	19503N	PARTICIPANT	\N	PRESENT	0
484704	484702	19503N	PARTICIPANT	\N	PRESENT	0
484707	484705	19503N	PARTICIPANT	\N	PRESENT	0
484710	484708	19503N	PARTICIPANT	\N	PRESENT	0
484713	484711	19503N	PARTICIPANT	\N	PRESENT	0
487845	485907	11056N	PARTICIPANT	\N	PRESENT	0
487846	485907	19387D	PARTICIPANT	\N	PRESENT	0
487847	485907	04097T	PARTICIPANT	\N	PRESENT	0
487848	485907	19531S	PARTICIPANT	\N	PRESENT	0
487849	485907	19441R	PARTICIPANT	\N	PRESENT	0
487850	485907	19563B	PARTICIPANT	\N	PRESENT	0
487851	485907	10015M	PARTICIPANT	\N	PRESENT	0
487852	485907	19679N	PRESIDENT	0	PRESENT	0
488033	486046	01048V	PRESIDENT	0	PRESENT	0
488034	486046	01058X	PARTICIPANT	\N	PRESENT	0
488035	486046	19533U	PARTICIPANT	\N	PRESENT	0
488041	486046	18003S	PARTICIPANT	\N	EXCUSE	0
488042	486046	14299H	PARTICIPANT	\N	EXCUSE	0
488227	487274	11067R	PARTICIPANT	\N	PRESENT	0
488228	487274	11048N	PARTICIPANT	\N	PRESENT	0
488229	487274	19479G	PARTICIPANT	\N	PRESENT	0
488230	487274	04092N	PARTICIPANT	\N	PRESENT	0
488231	487274	01057W	PARTICIPANT	\N	PRESENT	0
488232	487274	08052W	PARTICIPANT	\N	PRESENT	0
488233	487274	11053K	PARTICIPANT	\N	PRESENT	0
488234	487274	99004R	PARTICIPANT	\N	PRESENT	0
488235	487274	19715Y	PARTICIPANT	\N	PRESENT	0
488236	487274	19926J	PARTICIPANT	\N	PRESENT	0
488237	487274	14225N	PARTICIPANT	\N	EXCUSE	0
488238	487274	19671E	PARTICIPANT	\N	EXCUSE	0
488239	487274	04071H	PARTICIPANT	\N	PRESENT	0
488240	487274	08011M	PARTICIPANT	\N	PRESENT	0
488241	487274	19667J	PARTICIPANT	\N	PRESENT	0
488242	487274	11074Q	PRESIDENT	0	PRESENT	0
488243	487274	19647E	PARTICIPANT	\N	PRESENT	0
488244	487274	10006L	PARTICIPANT	\N	PRESENT	0
488245	487274	19703U	PARTICIPANT	\N	PRESENT	0
488249	487274	11097X	PARTICIPANT	\N	PRESENT	0
488250	487274	14087W	PARTICIPANT	\N	PRESENT	0
488251	487274	07029T	PARTICIPANT	\N	PRESENT	0
488254	487909	19766L	PARTICIPANT	\N	PRESENT	0
488255	487909	19697Q	PARTICIPANT	\N	PRESENT	0
488256	487909	19479G	PARTICIPANT	\N	PRESENT	0
488257	487909	11067R	PARTICIPANT	\N	PRESENT	0
488258	487909	11048N	PARTICIPANT	\N	PRESENT	0
488259	487909	04092N	PRESIDENT	0	PRESENT	0
488260	487909	11097X	PARTICIPANT	\N	PRESENT	0
488261	487909	14081Q	PARTICIPANT	\N	PRESENT	0
488262	487909	19667J	PARTICIPANT	\N	PRESENT	0
488263	487909	19715Y	PARTICIPANT	\N	PRESENT	0
488264	487909	11070L	PARTICIPANT	\N	PRESENT	0
488265	487909	19447X	PARTICIPANT	\N	PRESENT	0
488266	487909	04085P	PARTICIPANT	\N	PRESENT	0
488267	487909	19703U	PARTICIPANT	\N	PRESENT	0
488268	487909	19553Y	PARTICIPANT	\N	PRESENT	0
488269	487909	19573D	PARTICIPANT	\N	PRESENT	0
488270	487909	14041T	PARTICIPANT	\N	PRESENT	0
488271	487909	19503N	PARTICIPANT	\N	PRESENT	0
488272	487909	99004R	PARTICIPANT	\N	PRESENT	0
488273	487909	10006L	PARTICIPANT	\N	PRESENT	0
488274	487909	19683J	PARTICIPANT	\N	PRESENT	0
488301	487274	14034U	PARTICIPANT	\N	EXCUSE	0
488785	488447	14031R	PARTICIPANT	\N	EXCUSE	0
488786	488447	19723Y	PARTICIPANT	\N	EXCUSE	0
488787	488447	19629C	PARTICIPANT	\N	EXCUSE	0
492275	491472	20126Y	PARTICIPANT	\N	PRESENT	0
492276	491472	07029T	PARTICIPANT	\N	EXCUSE	0
492277	491469	08047A	PARTICIPANT	\N	PRESENT	0
492278	491469	14105F	PARTICIPANT	\N	PRESENT	0
492279	491469	19583F	PARTICIPANT	\N	PRESENT	0
492286	491510	19663E	PARTICIPANT	\N	PRESENT	0
492333	491475	19333N	PARTICIPANT	\N	PRESENT	0
492334	491475	19768N	PARTICIPANT	\N	PRESENT	0
492335	491475	19782L	PARTICIPANT	\N	PRESENT	0
492285	491488	01057W	PARTICIPANT	\N	PRESENT	0
492336	491475	14357A	PARTICIPANT	\N	PRESENT	0
492337	491475	19387D	PARTICIPANT	\N	PRESENT	0
492338	491475	19413M	PARTICIPANT	\N	PRESENT	0
492339	491475	19820Y	PARTICIPANT	\N	PRESENT	0
492340	491475	14219Q	PARTICIPANT	\N	PRESENT	0
492341	491475	20102Q	PARTICIPANT	\N	PRESENT	0
492342	491475	19599P	PARTICIPANT	\N	PRESENT	0
492343	491475	19637C	PARTICIPANT	\N	PRESENT	0
492344	491475	19575F	PARTICIPANT	\N	PRESENT	0
492345	491475	20022R	PARTICIPANT	\N	PRESENT	0
492346	491475	19563B	PARTICIPANT	\N	PRESENT	0
492347	491475	08028W	PARTICIPANT	\N	PRESENT	0
492348	491475	11065P	PARTICIPANT	\N	PRESENT	0
492349	491475	14329V	PARTICIPANT	\N	PRESENT	0
492350	491475	20028X	PARTICIPANT	\N	PRESENT	0
492351	491475	19467C	PARTICIPANT	\N	PRESENT	0
492352	491475	14187A	PRESIDENT	1	PRESENT	0
492353	491475	19695N	PARTICIPANT	\N	PRESENT	0
492354	491475	11090Q	PRESIDENT	0	PRESENT	0
492355	491475	14033T	PARTICIPANT	\N	PRESENT	0
492356	491475	20046A	PARTICIPANT	\N	PRESENT	0
492357	491475	14169X	PARTICIPANT	\N	PRESENT	0
492358	491475	20060X	PARTICIPANT	\N	PRESENT	0
492359	491475	14251Q	PARTICIPANT	\N	PRESENT	0
492360	491475	19507S	PARTICIPANT	\N	PRESENT	0
492361	491475	19739H	PARTICIPANT	\N	PRESENT	0
492362	491475	19745F	PARTICIPANT	\N	PRESENT	0
492363	491475	14207L	PARTICIPANT	\N	PRESENT	0
492364	491475	14257W	PARTICIPANT	\N	PRESENT	0
492365	491475	20144B	PARTICIPANT	\N	EXCUSE	0
492366	491475	08060W	PARTICIPANT	\N	PRESENT	0
492367	491475	20020P	PARTICIPANT	\N	PRESENT	0
492368	491475	20018V	PARTICIPANT	\N	PRESENT	0
492369	491475	20024T	PARTICIPANT	\N	PRESENT	0
492370	491475	20032T	PARTICIPANT	\N	PRESENT	0
492371	491475	17229F	PARTICIPANT	\N	PRESENT	0
492372	491475	19383Y	PARTICIPANT	\N	PRESENT	0
492373	491475	19701S	PARTICIPANT	\N	PRESENT	0
492375	491475	20082E	PARTICIPANT	\N	PRESENT	0
492376	491475	20094J	PARTICIPANT	\N	PRESENT	0
492377	491475	14221J	PARTICIPANT	\N	PRESENT	0
492378	491475	19631V	PARTICIPANT	\N	PRESENT	0
492379	491475	20096L	PARTICIPANT	\N	PRESENT	0
498806	498205	04070G	PARTICIPANT	\N	PRESENT	0
498807	498205	19699S	PARTICIPANT	\N	PRESENT	0
498808	498205	04033B	PARTICIPANT	\N	PRESENT	0
498809	498205	19329S	PARTICIPANT	\N	PRESENT	0
498810	498205	14229S	PARTICIPANT	\N	PRESENT	0
498811	498205	20098N	PARTICIPANT	\N	PRESENT	0
498812	498205	19573D	PARTICIPANT	\N	PRESENT	0
498813	498205	08017T	PARTICIPANT	\N	PRESENT	0
498814	498205	20112S	PARTICIPANT	\N	PRESENT	0
498815	498205	07033P	PARTICIPANT	\N	PRESENT	0
498816	498205	08012N	PARTICIPANT	\N	PRESENT	0
498817	498205	08061X	PARTICIPANT	\N	PRESENT	0
498818	498205	20124W	PARTICIPANT	\N	PRESENT	0
498819	498205	20026V	PARTICIPANT	\N	PRESENT	0
498820	498205	19527W	PARTICIPANT	\N	PRESENT	0
498821	498205	19593H	PARTICIPANT	\N	PRESENT	0
498822	498205	19643A	PARTICIPANT	\N	PRESENT	0
498823	498205	20132W	PARTICIPANT	\N	PRESENT	0
498824	498205	20134Y	PARTICIPANT	\N	PRESENT	0
498825	498205	14073Q	PARTICIPANT	\N	PRESENT	0
498826	498205	19651A	PARTICIPANT	\N	PRESENT	0
498827	498205	19611R	PRESIDENT	0	PRESENT	0
498828	498205	20138D	PARTICIPANT	\N	PRESENT	0
498829	498205	20142Y	PARTICIPANT	\N	PRESENT	0
498830	498205	20048C	PARTICIPANT	\N	PRESENT	0
498831	498205	19693L	PARTICIPANT	\N	PRESENT	0
498832	498205	19399H	PARTICIPANT	\N	PRESENT	0
498833	498205	20052X	PARTICIPANT	\N	PRESENT	0
498834	498205	20152B	PARTICIPANT	\N	PRESENT	0
498835	498205	20058E	PARTICIPANT	\N	PRESENT	0
498836	498205	14030Q	PARTICIPANT	\N	PRESENT	0
498837	498205	20056C	PARTICIPANT	\N	PRESENT	0
498838	498205	19735D	PARTICIPANT	\N	PRESENT	0
498852	497984	11066Q	PARTICIPANT	\N	PRESENT	0
498840	498205	14123H	PARTICIPANT	\N	PRESENT	0
498841	498205	11043H	PARTICIPANT	\N	PRESENT	0
498842	498205	11104D	PARTICIPANT	\N	PRESENT	0
498843	498205	19621T	PARTICIPANT	\N	PRESENT	0
498844	498205	20084G	PARTICIPANT	\N	PRESENT	0
498845	498205	19758L	PARTICIPANT	\N	EXCUSE	0
498846	498113	19663E	PARTICIPANT	\N	PRESENT	0
498847	498113	19717B	PARTICIPANT	\N	PRESENT	0
498848	498113	19367Y	PARTICIPANT	\N	EXCUSE	0
498849	498113	19295A	PARTICIPANT	\N	EXCUSE	0
498851	497011	11053K	PARTICIPANT	\N	PRESENT	0
498853	497984	14249W	PARTICIPANT	\N	PRESENT	0
498854	497984	08069G	PARTICIPANT	\N	PRESENT	0
498856	498721	05008E	PARTICIPANT	\N	PRESENT	0
498857	498721	11033F	PARTICIPANT	\N	PRESENT	0
498858	498721	11053K	PARTICIPANT	\N	PRESENT	0
498859	498721	14357A	PARTICIPANT	\N	PRESENT	0
498860	498721	11070L	PARTICIPANT	\N	PRESENT	0
498861	498721	19719D	PARTICIPANT	\N	PRESENT	0
498862	498721	19673G	PARTICIPANT	\N	PRESENT	0
498863	498721	01025N	PARTICIPANT	\N	PRESENT	0
498864	498721	19599P	PARTICIPANT	\N	PRESENT	0
498865	498721	14033T	PARTICIPANT	\N	PRESENT	0
498866	498721	14123H	PARTICIPANT	\N	PRESENT	0
498867	498721	14026U	PARTICIPANT	\N	PRESENT	0
498868	498721	11064N	PARTICIPANT	\N	PRESENT	0
498869	498721	14179A	PARTICIPANT	\N	PRESENT	0
498870	498721	14213J	PARTICIPANT	\N	PRESENT	0
498871	498721	19715Y	PARTICIPANT	\N	PRESENT	0
498872	498721	99004R	PARTICIPANT	\N	PRESENT	0
498873	498721	86034E	PARTICIPANT	\N	PRESENT	0
498874	498721	12041X	PARTICIPANT	\N	PRESENT	0
498875	498721	01043Q	PARTICIPANT	\N	PRESENT	0
498876	498721	14147R	PARTICIPANT	\N	PRESENT	0
498877	498721	11045K	PARTICIPANT	\N	PRESENT	0
498878	498721	04045F	PARTICIPANT	\N	PRESENT	0
498879	498721	01028R	PARTICIPANT	\N	PRESENT	0
498880	498721	19413M	PARTICIPANT	\N	PRESENT	0
498912	497174	19511N	PARTICIPANT	\N	PRESENT	0
498913	497174	20028X	PARTICIPANT	\N	PRESENT	0
498914	497174	19507S	PARTICIPANT	\N	PRESENT	0
498915	497174	20092G	PARTICIPANT	\N	PRESENT	0
498916	497174	17779H	PARTICIPANT	\N	PRESENT	0
498917	497174	19725B	PARTICIPANT	\N	PRESENT	0
498918	497174	18193Q	PARTICIPANT	\N	PRESENT	0
498919	497174	20102Q	PARTICIPANT	\N	PRESENT	0
498920	497174	11027H	PARTICIPANT	\N	PRESENT	0
498921	497174	20138D	PARTICIPANT	\N	PRESENT	0
498922	497174	20098N	PARTICIPANT	\N	PRESENT	0
498923	497174	19671E	PARTICIPANT	\N	PRESENT	0
498924	497174	19762G	PARTICIPANT	\N	PRESENT	0
498925	497174	19729F	PARTICIPANT	\N	PRESENT	0
498926	497174	20044X	PARTICIPANT	\N	PRESENT	0
498927	497174	08069G	PARTICIPANT	\N	PRESENT	0
498928	497174	19421M	PARTICIPANT	\N	PRESENT	0
498929	497174	20020P	PARTICIPANT	\N	PRESENT	0
498930	497174	19705W	PARTICIPANT	\N	PRESENT	0
498931	497174	19675J	PARTICIPANT	\N	PRESENT	0
498932	497174	20050V	PARTICIPANT	\N	PRESENT	0
498934	497174	20026V	PARTICIPANT	\N	PRESENT	0
498935	497174	20140W	PARTICIPANT	\N	PRESENT	0
498936	497174	19826F	PARTICIPANT	\N	PRESENT	0
498937	497174	19715Y	PARTICIPANT	\N	PRESENT	0
498938	497174	14195A	PARTICIPANT	\N	PRESENT	0
498939	497174	20042V	PARTICIPANT	\N	PRESENT	0
498940	497174	04059M	PARTICIPANT	\N	PRESENT	0
498941	497174	11041F	PARTICIPANT	\N	PRESENT	0
498942	497174	19333N	PARTICIPANT	\N	PRESENT	0
498943	497174	14151M	PARTICIPANT	\N	PRESENT	0
498944	497174	11040E	PARTICIPANT	\N	PRESENT	0
498945	497174	12041X	PARTICIPANT	\N	PRESENT	0
498946	497174	19760E	PARTICIPANT	\N	PRESENT	0
498947	497174	20112S	PARTICIPANT	\N	PRESENT	0
498948	497174	19687N	PARTICIPANT	\N	PRESENT	0
498949	497174	19695N	PARTICIPANT	\N	PRESENT	0
498950	497174	14249W	PARTICIPANT	\N	PRESENT	0
498951	497174	19647E	PARTICIPANT	\N	PRESENT	0
498952	497174	11067R	PARTICIPANT	\N	PRESENT	0
498953	497174	08017T	PARTICIPANT	\N	PRESENT	0
498954	497174	14021P	PARTICIPANT	\N	PRESENT	0
498955	497174	20082E	PARTICIPANT	\N	PRESENT	0
498956	497174	04034C	PARTICIPANT	\N	PRESENT	0
498957	497174	19651A	PARTICIPANT	\N	PRESENT	0
498958	497174	19689Q	PARTICIPANT	\N	PRESENT	0
498959	497174	20070A	PARTICIPANT	\N	PRESENT	0
498960	497174	14121F	PARTICIPANT	\N	PRESENT	0
498961	497174	01028R	PARTICIPANT	\N	PRESENT	0
498962	497174	08061X	PARTICIPANT	\N	PRESENT	0
498963	497174	11083R	PARTICIPANT	\N	PRESENT	0
498964	497174	04085P	PARTICIPANT	\N	PRESENT	0
498965	497174	11056N	PARTICIPANT	\N	PRESENT	0
498967	497174	11099A	PARTICIPANT	\N	PRESENT	0
498968	497174	14211G	PARTICIPANT	\N	PRESENT	0
498969	497174	20134Y	PARTICIPANT	\N	PRESENT	0
498971	497174	19347U	PARTICIPANT	\N	PRESENT	0
498972	497174	11033F	PARTICIPANT	\N	PRESENT	0
498973	497174	19711U	PARTICIPANT	\N	PRESENT	0
498974	497174	11066Q	PARTICIPANT	\N	PRESENT	0
498975	497174	17637T	PARTICIPANT	\N	PRESENT	0
498976	497174	19329S	PARTICIPANT	\N	PRESENT	0
487212	485920	11048N	PARTICIPANT	\N	PRESENT	0
487207	485540	14041T	PARTICIPANT	\N	PRESENT	0
487208	485540	19673G	PARTICIPANT	\N	PRESENT	0
487209	485540	05008E	PRESIDENT	0	PRESENT	0
487210	485540	11072N	PARTICIPANT	\N	PRESENT	0
487211	485540	19729F	PARTICIPANT	\N	EXCUSE	0
487213	485920	04071H	PARTICIPANT	\N	PRESENT	0
487214	485920	19711U	PARTICIPANT	\N	PRESENT	0
487215	485920	19531S	PARTICIPANT	\N	PRESENT	0
487216	485920	08034U	PARTICIPANT	\N	PRESENT	0
487217	485920	19687N	PARTICIPANT	\N	PRESENT	0
487218	485920	01057W	PARTICIPANT	\N	PRESENT	0
487219	485920	11074Q	PRESIDENT	0	PRESENT	0
487220	485920	08011M	PARTICIPANT	\N	PRESENT	0
487221	485920	88008L	PARTICIPANT	\N	PRESENT	0
487222	485920	04086Q	PARTICIPANT	\N	PRESENT	0
487223	485920	14085U	PARTICIPANT	\N	PRESENT	0
487224	485920	96004D	PARTICIPANT	\N	PRESENT	0
487225	485920	19741B	PARTICIPANT	\N	PRESENT	0
487226	485920	19762G	PARTICIPANT	\N	PRESENT	0
487227	485920	14225N	PARTICIPANT	\N	EXCUSE	0
487229	485920	14121F	PARTICIPANT	\N	PRESENT	0
487230	486939	19593H	PARTICIPANT	\N	PRESENT	0
487231	486939	19643A	PARTICIPANT	\N	PRESENT	0
487232	486939	19731Y	PARTICIPANT	\N	PRESENT	0
487233	486939	04018C	PARTICIPANT	\N	PRESENT	0
487234	486939	08039A	PARTICIPANT	0	PRESENT	0
487235	486939	14061L	PARTICIPANT	\N	EXCUSE	0
487236	486939	14241N	PARTICIPANT	\N	EXCUSE	0
487237	486939	04057K	PARTICIPANT	\N	EXCUSE	0
487238	486939	08020N	PARTICIPANT	\N	EXCUSE	0
487239	486939	19735D	PARTICIPANT	\N	EXCUSE	0
487240	486939	14063N	PARTICIPANT	\N	EXCUSE	0
487241	486939	11043H	PARTICIPANT	\N	EXCUSE	0
487242	486939	04070G	PRESIDENT	0	PRESENT	0
487243	486939	14123H	PARTICIPANT	\N	PRESENT	0
487244	485540	10015M	PARTICIPANT	\N	PRESENT	0
487245	485540	01024M	PARTICIPANT	\N	PRESENT	0
487246	485540	19543W	PARTICIPANT	\N	PRESENT	0
487247	485540	04038G	PARTICIPANT	\N	PRESENT	0
487248	485540	19447X	PARTICIPANT	\N	PRESENT	0
487249	485540	14231L	PARTICIPANT	\N	PRESENT	0
487250	485540	19930E	PARTICIPANT	\N	PRESENT	0
487251	485540	19954N	PARTICIPANT	\N	PRESENT	0
487252	485540	95063L	PARTICIPANT	\N	PRESENT	0
487253	485540	14147R	PARTICIPANT	\N	PRESENT	0
487254	485540	14215L	PARTICIPANT	\N	PRESENT	0
487255	485540	08018U	PARTICIPANT	\N	PRESENT	0
487256	485540	19489J	PARTICIPANT	\N	PRESENT	0
487257	485540	14065Q	PARTICIPANT	\N	PRESENT	0
487258	485540	04044E	PARTICIPANT	\N	PRESENT	0
487259	485540	04047H	PARTICIPANT	\N	PRESENT	0
487260	485540	01028R	PARTICIPANT	\N	PRESENT	0
487261	485540	14021P	PARTICIPANT	\N	PRESENT	0
487262	486939	08031R	PARTICIPANT	\N	PRESENT	0
487263	486939	19611R	PARTICIPANT	\N	PRESENT	0
487264	486939	11083R	PARTICIPANT	\N	PRESENT	0
487265	486939	14039A	PARTICIPANT	\N	PRESENT	0
487266	485540	14069U	PARTICIPANT	\N	PRESENT	0
487267	485920	19647E	PARTICIPANT	\N	PRESENT	0
487268	486939	19573D	PARTICIPANT	\N	PRESENT	0
487269	485920	14331P	PARTICIPANT	\N	PRESENT	0
487270	485920	14034U	PARTICIPANT	\N	PRESENT	0
487271	485920	07029T	PARTICIPANT	\N	PRESENT	0
487272	485920	19689Q	PARTICIPANT	\N	PRESENT	0
487273	486939	04059M	PARTICIPANT	\N	PRESENT	0
487275	485540	11026G	PARTICIPANT	\N	PRESENT	0
487276	485540	11033F	PARTICIPANT	\N	PRESENT	0
487277	485542	19333N	PARTICIPANT	\N	PRESENT	0
487278	485542	11067R	PARTICIPANT	\N	PRESENT	0
487279	485542	14357A	PARTICIPANT	\N	PRESENT	0
487280	485542	19387D	PARTICIPANT	\N	PRESENT	0
487281	485542	04044E	PARTICIPANT	\N	PRESENT	0
487282	485542	19585H	PARTICIPANT	\N	PRESENT	0
487283	485542	04047H	PARTICIPANT	\N	PRESENT	0
487284	485542	19912C	PARTICIPANT	\N	PRESENT	0
487285	485542	19673G	PARTICIPANT	\N	PRESENT	0
487286	485542	01028R	PARTICIPANT	\N	PRESENT	0
487287	485542	05008E	PRESIDENT	0	PRESENT	0
487288	485542	19447X	PARTICIPANT	\N	PRESENT	0
487289	485542	14231L	PARTICIPANT	\N	PRESENT	0
487290	485542	19926J	PARTICIPANT	\N	PRESENT	0
487291	485542	19930E	PARTICIPANT	\N	PRESENT	0
487292	485542	19954N	PARTICIPANT	\N	PRESENT	0
487293	485542	14041T	PARTICIPANT	\N	PRESENT	0
487294	485542	14147R	PARTICIPANT	\N	PRESENT	0
487295	485542	14151M	PARTICIPANT	\N	PRESENT	0
487296	485542	14215L	PARTICIPANT	\N	PRESENT	0
487297	485542	08018U	PARTICIPANT	\N	PRESENT	0
487298	485542	11072N	PARTICIPANT	\N	PRESENT	0
487299	485542	14135M	PARTICIPANT	\N	PRESENT	0
487300	485542	19649G	PARTICIPANT	\N	PRESENT	0
487301	485542	14065Q	PARTICIPANT	\N	PRESENT	0
487302	485542	19713W	PARTICIPANT	\N	PRESENT	0
487303	485542	10015M	PARTICIPANT	\N	PRESENT	0
487304	485542	11026G	PARTICIPANT	\N	PRESENT	0
487305	485542	08052W	PARTICIPANT	\N	PRESENT	0
487306	485542	01024M	PARTICIPANT	\N	PRESENT	0
487307	485542	04038G	PARTICIPANT	\N	PRESENT	0
487308	485542	11033F	PARTICIPANT	\N	PRESENT	0
487309	485542	19731Y	PARTICIPANT	\N	PRESENT	0
487310	485542	08044W	PARTICIPANT	\N	PRESENT	0
487311	485542	19737F	PARTICIPANT	\N	PRESENT	0
487312	485542	14071N	PARTICIPANT	\N	PRESENT	0
487313	485542	14021P	PARTICIPANT	\N	PRESENT	0
487314	485542	19729F	PARTICIPANT	\N	EXCUSE	0
487315	485542	19415P	PARTICIPANT	\N	PRESENT	0
487316	485542	14087W	PARTICIPANT	\N	PRESENT	0
487317	485542	10006L	PARTICIPANT	\N	PRESENT	0
487318	485542	95063L	PARTICIPANT	\N	PRESENT	0
487319	485542	19543W	PARTICIPANT	\N	PRESENT	0
487320	485542	14069U	PARTICIPANT	\N	PRESENT	0
487321	485542	19715Y	PARTICIPANT	\N	PRESENT	0
487322	479262	11054L	PARTICIPANT	\N	PRESENT	0
487323	479262	11041F	PARTICIPANT	\N	PRESENT	0
487324	479262	19585H	PARTICIPANT	\N	PRESENT	0
487325	479262	14267Y	PARTICIPANT	\N	PRESENT	0
487326	479262	14207L	PARTICIPANT	\N	PRESENT	0
487327	479262	19565D	PARTICIPANT	\N	PRESENT	0
487328	479262	14227Q	PARTICIPANT	\N	PRESENT	0
487329	479262	17589D	PARTICIPANT	\N	PRESENT	0
487330	479262	95037J	PARTICIPANT	\N	PRESENT	0
487331	479262	98029W	PARTICIPANT	\N	PRESENT	0
487332	479262	19599P	PARTICIPANT	\N	PRESENT	0
487333	479262	11066Q	PARTICIPANT	\N	PRESENT	0
487334	479262	19543W	PARTICIPANT	\N	PRESENT	0
487335	479262	19563B	PARTICIPANT	\N	PRESENT	0
487336	479262	11027H	PARTICIPANT	\N	PRESENT	0
487337	479262	19737F	PARTICIPANT	\N	PRESENT	0
487338	479262	01025N	PARTICIPANT	\N	PRESENT	0
487339	479262	88008L	PARTICIPANT	\N	PRESENT	0
487340	479262	11012A	PARTICIPANT	\N	PRESENT	0
487341	479262	14039A	PARTICIPANT	\N	PRESENT	0
487342	479262	12041X	PARTICIPANT	\N	PRESENT	0
487343	479262	19593H	PARTICIPANT	\N	PRESENT	0
487344	479262	14235Q	PARTICIPANT	\N	PRESENT	0
487345	479262	19251M	PARTICIPANT	\N	PRESENT	0
487346	479262	19387D	PARTICIPANT	\N	PRESENT	0
487347	479262	11031D	PARTICIPANT	\N	PRESENT	0
487348	479262	14211G	PARTICIPANT	\N	PRESENT	0
487349	479262	19347U	PARTICIPANT	\N	PRESENT	0
487350	479262	19695N	PARTICIPANT	\N	PRESENT	0
487351	479262	19687N	PARTICIPANT	\N	PRESENT	0
487352	479262	19651A	PARTICIPANT	\N	PRESENT	0
487353	479262	11083R	PARTICIPANT	\N	PRESENT	0
487354	479262	19591F	PARTICIPANT	\N	PRESENT	0
487355	479262	19301E	PARTICIPANT	\N	PRESENT	0
487356	479262	11072N	PARTICIPANT	\N	PRESENT	0
487357	479262	19731Y	PARTICIPANT	\N	PRESENT	0
487358	479262	19685L	PARTICIPANT	\N	PRESENT	0
487359	479262	14034U	PARTICIPANT	\N	PRESENT	0
487360	479262	19467C	PARTICIPANT	\N	PRESENT	0
487361	479262	19553Y	PARTICIPANT	\N	PRESENT	0
487362	479262	19415P	PARTICIPANT	\N	PRESENT	0
487363	479262	08031R	PARTICIPANT	\N	PRESENT	0
487364	479262	19697Q	PARTICIPANT	\N	PRESENT	0
487365	479262	19447X	PARTICIPANT	\N	PRESENT	0
487366	479262	19573D	PARTICIPANT	\N	PRESENT	0
487367	479262	14041T	PARTICIPANT	\N	PRESENT	0
487368	479262	14195A	PARTICIPANT	\N	PRESENT	0
487369	479262	14135M	PARTICIPANT	\N	PRESENT	0
487370	479262	14093U	PARTICIPANT	\N	PRESENT	0
487371	479262	07029T	PARTICIPANT	\N	PRESENT	0
487372	479262	14121F	PARTICIPANT	\N	PRESENT	0
487373	479262	19507S	PARTICIPANT	\N	PRESENT	0
503373	501816	20018V	PARTICIPANT	\N	PRESENT	0
503374	501816	20070A	PARTICIPANT	\N	PRESENT	0
503375	501816	20080C	PARTICIPANT	\N	PRESENT	0
503376	501816	12016W	PARTICIPANT	\N	PRESENT	0
503377	501816	19551W	PARTICIPANT	\N	PRESENT	0
503378	501816	11040E	PARTICIPANT	\N	PRESENT	0
503379	501816	20036X	PARTICIPANT	\N	PRESENT	0
503380	501816	19689Q	PARTICIPANT	\N	PRESENT	0
503381	501816	20134Y	PARTICIPANT	\N	PRESENT	0
503382	501816	20030R	PARTICIPANT	\N	PRESENT	0
503383	501816	19647E	PARTICIPANT	\N	PRESENT	0
503384	501816	19349W	PARTICIPANT	\N	PRESENT	0
503385	501816	11012A	PARTICIPANT	\N	PRESENT	0
503386	501816	14111D	PARTICIPANT	\N	PRESENT	0
503387	501816	19563B	PARTICIPANT	\N	PRESENT	0
503388	501816	19629C	PARTICIPANT	\N	PRESENT	0
503389	501816	19713W	PARTICIPANT	\N	PRESENT	0
503390	501816	14030Q	PARTICIPANT	\N	PRESENT	0
503391	501816	14083S	PARTICIPANT	\N	PRESENT	0
503392	501816	11070L	PARTICIPANT	\N	PRESENT	0
503393	501816	11053K	PARTICIPANT	\N	PRESENT	0
503394	501816	07004J	PARTICIPANT	\N	PRESENT	0
503395	501816	20106U	PARTICIPANT	\N	PRESENT	0
503396	501816	14327T	PARTICIPANT	\N	PRESENT	0
503397	501816	14331P	PARTICIPANT	\N	PRESENT	0
503398	501816	14237S	PARTICIPANT	\N	PRESENT	0
503399	501816	20120S	PARTICIPANT	\N	PRESENT	0
503400	501816	19671E	PARTICIPANT	\N	PRESENT	0
503401	501816	19657G	PARTICIPANT	\N	PRESENT	0
503402	501816	07029T	PARTICIPANT	\N	PRESENT	0
503403	501816	20032T	PARTICIPANT	\N	PRESENT	0
503404	501816	20096L	PARTICIPANT	\N	PRESENT	0
503405	501816	20026V	PARTICIPANT	\N	PRESENT	0
503406	501816	19667J	PARTICIPANT	\N	PRESENT	0
503407	501816	20044X	PARTICIPANT	\N	PRESENT	0
503371	501816	12041X	PARTICIPANT	\N	PRESENT	0
503372	501816	11074Q	PARTICIPANT	\N	PRESENT	0
503408	501816	14187A	PARTICIPANT	\N	PRESENT	0
503409	501816	08015R	PARTICIPANT	\N	PRESENT	0
503410	501816	14031R	PARTICIPANT	\N	PRESENT	0
503411	501816	20038A	PARTICIPANT	\N	PRESENT	0
503412	501816	04086Q	PARTICIPANT	\N	PRESENT	0
503413	501816	19711U	PARTICIPANT	\N	PRESENT	0
503414	501816	08034U	PARTICIPANT	\N	PRESENT	0
503415	501816	20024T	PARTICIPANT	\N	PRESENT	0
503416	501816	14225N	PARTICIPANT	\N	PRESENT	0
503417	501816	11048N	PARTICIPANT	\N	PRESENT	0
503418	501816	20092G	PARTICIPANT	\N	PRESENT	0
503419	501816	19687N	PARTICIPANT	\N	PRESENT	0
503420	501816	14173T	PARTICIPANT	\N	PRESENT	0
503424	501816	04033B	PARTICIPANT	\N	PRESENT	0
503422	501816	20140W	PARTICIPANT	\N	PRESENT	0
503423	501816	95063L	PARTICIPANT	\N	PRESENT	0
503425	501816	19741B	PARTICIPANT	\N	PRESENT	0
503426	501816	01057W	PARTICIPANT	\N	PRESENT	0
503427	501816	19479G	PARTICIPANT	\N	PRESENT	0
503428	501816	14069U	PARTICIPANT	\N	PRESENT	0
503429	501816	19383Y	PARTICIPANT	\N	PRESENT	0
503430	501816	19762G	PARTICIPANT	\N	PRESENT	0
503431	501816	08010L	PARTICIPANT	\N	PRESENT	0
503432	501816	11043H	PARTICIPANT	\N	PRESENT	0
503433	501816	14219Q	PARTICIPANT	\N	PRESENT	0
503434	501816	19591F	PARTICIPANT	\N	PRESENT	0
503435	501816	20150Y	PARTICIPANT	\N	PRESENT	0
503436	501816	19739H	PARTICIPANT	\N	PRESENT	0
503437	501816	19531S	PARTICIPANT	\N	PRESENT	0
503438	501816	04071H	PARTICIPANT	\N	PRESENT	0
503493	502447	14121F	PARTICIPANT	\N	PRESENT	1
503494	502447	08073C	PARTICIPANT	\N	PRESENT	1
503495	502447	19687N	PARTICIPANT	\N	PRESENT	1
503496	502447	19479G	PARTICIPANT	\N	PRESENT	1
503497	502447	19575F	PARTICIPANT	\N	PRESENT	1
503523	502446	14121F	PARTICIPANT	\N	PRESENT	1
503524	502446	19531S	PARTICIPANT	\N	PRESENT	1
503525	502446	08010L	PARTICIPANT	\N	PRESENT	1
503526	502446	01048V	PARTICIPANT	\N	PRESENT	1
503527	502446	19335Q	PARTICIPANT	\N	PRESENT	1
503528	502446	08011M	PARTICIPANT	\N	PRESENT	1
503530	503529	20110Q	PARTICIPANT	\N	PRESENT	0
503534	503157	11065P	PARTICIPANT	\N	PRESENT	0
503535	503157	17229F	PARTICIPANT	\N	PRESENT	0
503536	503157	19820Y	PARTICIPANT	\N	PRESENT	0
503537	503157	19333N	PARTICIPANT	\N	PRESENT	0
503539	503157	19619A	PARTICIPANT	\N	PRESENT	0
503541	503157	08060W	PARTICIPANT	\N	PRESENT	0
503542	503157	20136B	PARTICIPANT	\N	PRESENT	0
503545	503157	19387D	PARTICIPANT	\N	PRESENT	0
503575	502447	12016W	PARTICIPANT	\N	PRESENT	0
503718	503712	08017T	PARTICIPANT	\N	PRESENT	0
503719	503712	19735D	PARTICIPANT	\N	PRESENT	0
503731	503728	14229S	PARTICIPANT	\N	PRESENT	0
503732	503728	08017T	PARTICIPANT	\N	PRESENT	0
503733	503728	19735D	PARTICIPANT	\N	PRESENT	0
503794	503791	20112S	PARTICIPANT	\N	PRESENT	0
503806	503805	20112S	PARTICIPANT	\N	PRESENT	0
504082	503805	04070G	PARTICIPANT	\N	PRESENT	0
504085	504084	19651A	PARTICIPANT	\N	PRESENT	0
504093	504091	19651A	PARTICIPANT	\N	PRESENT	0
504113	504112	19651A	PARTICIPANT	\N	PRESENT	0
504115	504112	14229S	PARTICIPANT	\N	PRESENT	0
504122	504120	19651A	PARTICIPANT	\N	PRESENT	0
504123	504120	04070G	PARTICIPANT	\N	PRESENT	0
504168	504167	92040Q	PARTICIPANT	\N	PRESENT	0
504169	504167	14109K	PARTICIPANT	\N	PRESENT	0
504170	504167	19735D	PARTICIPANT	\N	PRESENT	0
504171	504167	20084G	PARTICIPANT	\N	PRESENT	0
504172	504167	20098N	PARTICIPANT	\N	PRESENT	0
504174	504173	92040Q	PARTICIPANT	\N	PRESENT	0
504175	504173	19735D	PARTICIPANT	\N	PRESENT	0
504177	504176	92040Q	PARTICIPANT	\N	PRESENT	0
504178	504176	19735D	PARTICIPANT	\N	PRESENT	0
504179	504176	14109K	PARTICIPANT	\N	PRESENT	0
504180	504176	19651A	PARTICIPANT	\N	PRESENT	0
504208	504207	92040Q	PARTICIPANT	\N	PRESENT	0
504209	504207	19735D	PARTICIPANT	\N	PRESENT	0
504213	504212	92040Q	PARTICIPANT	\N	PRESENT	0
504214	504212	19735D	PARTICIPANT	\N	PRESENT	0
504215	504212	14109K	PARTICIPANT	\N	PRESENT	0
504216	504212	19651A	PARTICIPANT	\N	PRESENT	0
504223	504222	92040Q	PARTICIPANT	\N	PRESENT	0
504224	504222	19735D	PARTICIPANT	\N	PRESENT	0
504260	504236	14221J	PARTICIPANT	\N	PRESENT	0
504282	504237	14221J	PARTICIPANT	\N	PRESENT	0
504285	504241	14221J	PARTICIPANT	\N	PRESENT	0
504297	504243	14221J	PARTICIPANT	\N	PRESENT	0
504300	504256	14221J	PARTICIPANT	\N	PRESENT	0
504373	502448	11048N	PARTICIPANT	\N	EXCUSE	0
504374	502448	11074Q	PARTICIPANT	\N	PRESENT	1
504375	502448	12016W	PARTICIPANT	\N	PRESENT	1
504376	502288	11056N	PARTICIPANT	\N	PRESENT	1
504377	502288	19543W	PARTICIPANT	\N	PRESENT	1
504378	502288	14151M	PARTICIPANT	\N	PRESENT	1
504379	502288	19675J	PARTICIPANT	\N	EXCUSE	0
504447	502448	14169X	PARTICIPANT	\N	PRESENT	0
504473	502289	19629C	PARTICIPANT	\N	PRESENT	0
504474	502289	14041T	PARTICIPANT	\N	PRESENT	0
504475	502289	20108W	PARTICIPANT	\N	PRESENT	0
504476	502289	14215L	PARTICIPANT	\N	PRESENT	0
504482	502449	11048N	PARTICIPANT	\N	PRESENT	0
504483	502449	19647E	PARTICIPANT	\N	PRESENT	0
504484	502449	19711U	PARTICIPANT	\N	PRESENT	0
504485	502449	11053K	PARTICIPANT	\N	PRESENT	0
504486	502449	20080C	PARTICIPANT	\N	PRESENT	0
504487	502449	11074Q	PARTICIPANT	\N	PRESENT	0
504488	502449	20044X	PARTICIPANT	\N	PRESENT	0
504489	502449	14225N	PRESIDENT	0	PRESENT	0
504490	502449	11070L	PARTICIPANT	\N	PRESENT	0
504491	502449	04086Q	PARTICIPANT	\N	PRESENT	0
504492	502449	08009T	PARTICIPANT	\N	PRESENT	0
504493	502449	96004D	PARTICIPANT	\N	PRESENT	0
504494	502449	19349W	PARTICIPANT	\N	PRESENT	0
504495	502449	99004R	PARTICIPANT	\N	PRESENT	0
504496	502449	19335Q	PARTICIPANT	\N	PRESENT	0
504497	502449	20126Y	PARTICIPANT	\N	PRESENT	0
504498	502449	19762G	PARTICIPANT	\N	PRESENT	0
504500	502289	01028R	PARTICIPANT	\N	PRESENT	0
504501	502289	14231L	PARTICIPANT	\N	PRESENT	0
504502	502289	11056N	PARTICIPANT	\N	PRESENT	0
488947	488727	14331P	PARTICIPANT	\N	PRESENT	0
488948	488727	04071H	PRESIDENT	0	PRESENT	0
488949	488727	11048N	PARTICIPANT	\N	PRESENT	0
488950	488727	19479G	PARTICIPANT	\N	PRESENT	0
488951	488727	19711U	PARTICIPANT	\N	PRESENT	0
488952	488727	19531S	PARTICIPANT	\N	PRESENT	0
488953	488727	01057W	PARTICIPANT	\N	PRESENT	0
488954	488727	19689Q	PARTICIPANT	\N	PRESENT	0
488955	488727	19667J	PARTICIPANT	\N	PRESENT	0
488956	488727	08011M	PARTICIPANT	\N	PRESENT	0
488957	488727	88008L	PARTICIPANT	\N	PRESENT	0
488958	488727	04086Q	PARTICIPANT	\N	PRESENT	0
488959	488727	14083S	PARTICIPANT	\N	PRESENT	0
488960	488727	14085U	PARTICIPANT	\N	PRESENT	0
488961	488727	07004J	PARTICIPANT	\N	PRESENT	0
488962	488727	99004R	PARTICIPANT	\N	PRESENT	0
488963	488727	11040E	PARTICIPANT	\N	EXCUSE	0
488964	488727	07029T	PARTICIPANT	\N	EXCUSE	0
488965	488727	19545Y	PARTICIPANT	\N	EXCUSE	0
488966	488727	19687N	PARTICIPANT	\N	EXCUSE	0
488967	488727	08010L	PARTICIPANT	\N	EXCUSE	0
488968	488727	11074Q	PARTICIPANT	\N	EXCUSE	0
488969	488727	14034U	PARTICIPANT	\N	EXCUSE	0
488970	488727	19762G	PARTICIPANT	\N	EXCUSE	0
488971	488727	11053K	PARTICIPANT	\N	PRESENT	0
488972	488727	11012A	PARTICIPANT	\N	PRESENT	0
488973	488727	19647E	PARTICIPANT	\N	PRESENT	0
488974	488727	14327T	PARTICIPANT	\N	EXCUSE	0
489510	489509	19683J	PARTICIPANT	\N	PRESENT	0
489512	489511	19683J	PARTICIPANT	\N	PRESENT	0
489514	489513	19683J	PARTICIPANT	\N	PRESENT	0
492380	491475	14237S	PARTICIPANT	\N	PRESENT	0
492381	491475	18083K	PARTICIPANT	\N	PRESENT	0
492382	491475	05012A	PARTICIPANT	\N	PRESENT	0
492383	491475	19503N	PARTICIPANT	\N	PRESENT	0
492385	491475	14031R	PARTICIPANT	\N	PRESENT	0
492386	491475	20140W	PARTICIPANT	\N	PRESENT	0
492387	491475	19251M	PARTICIPANT	\N	PRESENT	0
492388	491475	14205J	PARTICIPANT	\N	PRESENT	0
492389	491475	19619A	PARTICIPANT	\N	PRESENT	0
492390	491475	11099A	PARTICIPANT	\N	PRESENT	0
492391	491475	19369B	PARTICIPANT	\N	EXCUSE	0
492392	491261	19701S	PARTICIPANT	\N	PRESENT	0
492393	491261	19820Y	PARTICIPANT	\N	PRESENT	0
492394	491261	14219Q	PARTICIPANT	\N	PRESENT	0
492395	491261	14221J	PARTICIPANT	\N	PRESENT	0
492396	491261	19599P	PARTICIPANT	\N	PRESENT	0
492397	491261	20096L	PARTICIPANT	\N	PRESENT	0
492398	491261	19637C	PARTICIPANT	\N	PRESENT	0
492399	491261	18083K	PARTICIPANT	\N	PRESENT	0
492400	491261	14237S	PARTICIPANT	\N	PRESENT	0
492401	491261	05012A	PARTICIPANT	\N	PRESENT	0
492402	491261	08060W	PARTICIPANT	\N	PRESENT	0
492403	491261	20118Y	PARTICIPANT	\N	PRESENT	0
492404	491261	19503N	PARTICIPANT	\N	PRESENT	0
492405	491261	20020P	PARTICIPANT	\N	PRESENT	0
492406	491261	17367Q	PARTICIPANT	\N	PRESENT	0
492407	491261	20022R	PARTICIPANT	\N	PRESENT	0
492408	491261	20024T	PARTICIPANT	\N	PRESENT	0
492409	491261	11065P	PARTICIPANT	\N	PRESENT	0
492410	491261	20032T	PARTICIPANT	\N	PRESENT	0
492411	491261	20038A	PARTICIPANT	\N	PRESENT	0
492412	491261	14031R	PRESIDENT	0	PRESENT	0
492413	491261	20140W	PARTICIPANT	\N	PRESENT	0
492414	491261	19251M	PARTICIPANT	\N	PRESENT	0
492415	491261	20046A	PARTICIPANT	\N	PRESENT	0
492416	491261	14169X	PARTICIPANT	\N	PRESENT	0
492417	491261	17229F	PARTICIPANT	\N	PRESENT	0
492418	491261	19739H	PARTICIPANT	\N	PRESENT	0
492421	491261	19333N	PARTICIPANT	\N	PRESENT	0
492422	491261	19387D	PARTICIPANT	\N	PRESENT	0
492423	491261	19745F	PARTICIPANT	\N	PRESENT	0
492424	491261	19619A	PARTICIPANT	\N	PRESENT	0
492425	491261	20146D	PARTICIPANT	\N	EXCUSE	0
492439	492438	04070G	PARTICIPANT	\N	PRESENT	0
492440	492438	08017T	PARTICIPANT	\N	PRESENT	0
492441	492438	19593H	PARTICIPANT	\N	PRESENT	0
492442	492438	14109K	PARTICIPANT	\N	PRESENT	0
492443	492438	19329S	PARTICIPANT	\N	PRESENT	0
492444	492438	20124W	PARTICIPANT	\N	PRESENT	0
492445	492438	20134Y	PARTICIPANT	\N	PRESENT	0
492446	492438	20084G	PARTICIPANT	\N	PRESENT	0
492452	492088	04070G	PARTICIPANT	\N	PRESENT	0
492453	492088	14331P	PARTICIPANT	\N	PRESENT	0
492454	492088	19533U	PARTICIPANT	\N	PRESENT	0
492455	492088	14229S	PARTICIPANT	\N	PRESENT	0
492456	492088	20098N	PARTICIPANT	\N	PRESENT	0
492457	492088	19573D	PARTICIPANT	\N	PRESENT	0
492458	492088	08017T	PARTICIPANT	\N	PRESENT	0
492459	492088	08061X	PARTICIPANT	\N	PRESENT	0
492460	492088	08012N	PARTICIPANT	\N	PRESENT	0
492461	492088	20120S	PARTICIPANT	\N	PRESENT	0
492462	492088	19593H	PARTICIPANT	\N	PRESENT	0
492463	492088	20132W	PARTICIPANT	\N	PRESENT	0
492464	492088	19651A	PARTICIPANT	\N	PRESENT	0
492465	492088	19611R	PRESIDENT	0	PRESENT	0
492466	492088	20138D	PARTICIPANT	\N	PRESENT	0
492467	492088	20142Y	PARTICIPANT	\N	PRESENT	0
492468	492088	20048C	PARTICIPANT	\N	PRESENT	0
492469	492088	19693L	PARTICIPANT	\N	PRESENT	0
492470	492088	14030Q	PARTICIPANT	\N	PRESENT	0
492471	492088	20058E	PARTICIPANT	\N	PRESENT	0
492472	492088	04059M	PARTICIPANT	\N	PRESENT	0
492473	492088	19735D	PARTICIPANT	\N	PRESENT	0
492474	492088	14109K	PARTICIPANT	\N	PRESENT	0
492475	492088	14123H	PARTICIPANT	\N	PRESENT	0
492476	492088	11043H	PARTICIPANT	\N	PRESENT	0
492477	492088	19758L	PARTICIPANT	\N	PRESENT	0
492478	492088	17589D	PARTICIPANT	\N	PRESENT	0
492479	492088	19621T	PARTICIPANT	\N	PRESENT	0
492480	492088	20112S	PARTICIPANT	\N	EXCUSE	0
492481	492088	07033P	PARTICIPANT	\N	EXCUSE	0
492483	491415	20018V	PARTICIPANT	\N	PRESENT	0
492484	491415	14097Y	PARTICIPANT	\N	PRESENT	0
492485	491415	20052X	PARTICIPANT	\N	PRESENT	0
492486	491415	19333N	PARTICIPANT	\N	PRESENT	0
492487	491415	20106U	PARTICIPANT	\N	PRESENT	0
492488	491415	20032T	PARTICIPANT	\N	PRESENT	0
492490	491415	17737W	PARTICIPANT	\N	PRESENT	0
492493	491415	20082E	PARTICIPANT	\N	PRESENT	0
492497	491415	11027H	PARTICIPANT	\N	PRESENT	0
492498	491415	20130U	PARTICIPANT	\N	PRESENT	0
492499	491415	19367Y	PARTICIPANT	\N	PRESENT	0
492500	491415	19671E	PARTICIPANT	\N	PRESENT	0
492501	491415	14105F	PARTICIPANT	\N	PRESENT	0
492502	491415	19563B	PARTICIPANT	\N	PRESENT	0
492503	491415	98022P	PARTICIPANT	\N	PRESENT	0
492504	491415	12028B	PARTICIPANT	\N	PRESENT	0
492505	491415	14109K	PARTICIPANT	\N	PRESENT	0
492506	491415	20074E	PARTICIPANT	\N	PRESENT	0
492509	491415	20124W	PARTICIPANT	\N	PRESENT	0
492510	491415	14195A	PARTICIPANT	\N	PRESENT	0
492511	491415	20022R	PARTICIPANT	\N	PRESENT	0
492512	491415	19659J	PARTICIPANT	\N	PRESENT	0
492513	491415	19549D	PARTICIPANT	\N	PRESENT	0
492514	491415	19503N	PARTICIPANT	\N	PRESENT	0
492515	491415	20128B	PARTICIPANT	\N	PRESENT	0
492516	491415	20072C	PARTICIPANT	\N	PRESENT	0
492517	491415	19611R	PARTICIPANT	\N	PRESENT	0
492518	491415	19866P	PARTICIPANT	\N	PRESENT	0
492519	491415	19629C	PARTICIPANT	\N	PRESENT	0
492520	491415	11040E	PARTICIPANT	\N	PRESENT	0
492521	491415	19695N	PARTICIPANT	\N	PRESENT	0
492522	491415	08061X	PARTICIPANT	\N	PRESENT	0
492523	491415	20116W	PARTICIPANT	\N	PRESENT	0
492524	491415	19619A	PARTICIPANT	\N	PRESENT	0
492525	491415	20050V	PARTICIPANT	\N	PRESENT	0
492526	491415	20102Q	PARTICIPANT	\N	PRESENT	0
492527	491415	11031D	PARTICIPANT	\N	PRESENT	0
492528	491415	19687N	PARTICIPANT	\N	PRESENT	0
492529	491415	12041X	PARTICIPANT	\N	PRESENT	0
492530	491415	04057K	PARTICIPANT	\N	PRESENT	0
492531	491415	19585H	PARTICIPANT	\N	PRESENT	0
492532	491415	14111D	PARTICIPANT	\N	PRESENT	0
492533	491415	19758L	PARTICIPANT	\N	PRESENT	0
492534	491415	11056N	PARTICIPANT	\N	PRESENT	0
492535	491415	20084G	PARTICIPANT	\N	PRESENT	0
492536	491415	11067R	PARTICIPANT	\N	PRESENT	0
492537	491415	14281W	PARTICIPANT	\N	PRESENT	0
492538	491415	14121F	PARTICIPANT	\N	PRESENT	0
492539	491415	19347U	PARTICIPANT	\N	PRESENT	0
492540	491415	19301E	PARTICIPANT	\N	PRESENT	0
492541	491415	04045F	PARTICIPANT	\N	PRESENT	0
492542	491415	19593H	PARTICIPANT	\N	PRESENT	0
492543	491415	20086J	PARTICIPANT	\N	PRESENT	0
492544	491415	20134Y	PARTICIPANT	\N	PRESENT	0
492545	491415	20092G	PARTICIPANT	\N	PRESENT	0
498977	497174	04035D	PARTICIPANT	\N	PRESENT	0
498978	497174	11072N	PARTICIPANT	\N	PRESENT	0
498979	497174	08010L	PARTICIPANT	\N	PRESENT	0
498980	497174	19637C	PARTICIPANT	\N	PRESENT	0
498981	497174	01058X	PARTICIPANT	\N	PRESENT	0
498982	497174	20076G	PARTICIPANT	\N	PRESENT	0
498983	497174	99004R	PARTICIPANT	\N	PRESENT	0
498984	497174	20128B	PARTICIPANT	\N	PRESENT	0
498986	497174	14123H	PARTICIPANT	\N	PRESENT	0
498987	497174	14133K	PARTICIPANT	\N	PRESENT	0
498988	497174	05008E	PARTICIPANT	\N	PRESENT	0
498989	497174	19629C	PARTICIPANT	\N	PRESENT	0
498990	497174	14071N	PARTICIPANT	\N	PRESENT	0
498991	497174	04033B	PARTICIPANT	\N	PRESENT	0
498992	497174	14223L	PARTICIPANT	\N	PRESENT	0
498993	497174	19719D	PARTICIPANT	\N	PRESENT	0
498994	497174	14169X	PARTICIPANT	\N	PRESENT	0
498995	497174	04045F	PARTICIPANT	\N	PRESENT	0
498996	497174	19693L	PARTICIPANT	\N	PRESENT	0
498997	497174	11043H	PARTICIPANT	\N	PRESENT	0
498998	497174	19515S	PARTICIPANT	\N	PRESENT	0
498999	497174	20116W	PARTICIPANT	\N	PRESENT	0
499000	497174	19766L	PARTICIPANT	\N	PRESENT	0
499001	497174	08011M	PARTICIPANT	\N	PRESENT	0
499002	497174	11012A	PARTICIPANT	\N	PRESENT	0
499003	497174	19679N	PARTICIPANT	\N	PRESENT	0
499004	497174	20022R	PARTICIPANT	\N	PRESENT	0
499005	497174	14207L	PARTICIPANT	\N	PRESENT	0
499006	497174	05012A	PARTICIPANT	\N	PRESENT	0
499007	497174	19553Y	PARTICIPANT	\N	PRESENT	0
499008	497174	14187A	PARTICIPANT	\N	PRESENT	0
499009	497174	19701S	PARTICIPANT	\N	PRESENT	0
499010	497174	19563B	PARTICIPANT	\N	PRESENT	0
499011	497174	14069U	PARTICIPANT	\N	PRESENT	0
499012	497174	14237S	PARTICIPANT	\N	PRESENT	0
499013	497174	14193X	PARTICIPANT	\N	PRESENT	0
499014	497174	20122U	PARTICIPANT	\N	PRESENT	0
499015	497174	19545Y	PARTICIPANT	\N	PRESENT	0
499016	497174	10006L	PARTICIPANT	\N	PRESENT	0
499017	497174	04057K	PARTICIPANT	\N	PRESENT	0
499018	497174	14105F	PARTICIPANT	\N	PRESENT	0
499019	497174	14251Q	PARTICIPANT	\N	PRESENT	0
499020	497174	19703U	PARTICIPANT	\N	PRESENT	0
499021	497174	20094J	PARTICIPANT	\N	PRESENT	0
499022	497174	14001X	PARTICIPANT	\N	PRESENT	0
499023	497174	04042C	PARTICIPANT	\N	PRESENT	0
499024	497174	14147R	PARTICIPANT	\N	PRESENT	0
499025	497174	19527W	PARTICIPANT	\N	PRESENT	0
499026	497174	17589D	PARTICIPANT	\N	PRESENT	0
499027	497174	19723Y	PARTICIPANT	\N	PRESENT	0
499028	497174	04043D	PARTICIPANT	\N	PRESENT	0
499029	497174	20032T	PARTICIPANT	\N	PRESENT	0
499030	497174	19503N	PARTICIPANT	\N	PRESENT	0
499031	497174	19413M	PARTICIPANT	\N	PRESENT	0
499032	497174	20056C	PARTICIPANT	\N	PRESENT	0
499033	497174	19673G	PARTICIPANT	\N	PRESENT	0
499034	497174	19573D	PARTICIPANT	\N	PRESENT	0
499035	497174	14031R	PARTICIPANT	\N	PRESENT	0
499036	497174	14109K	PARTICIPANT	\N	PRESENT	0
499037	497174	14229S	PARTICIPANT	\N	PRESENT	0
499038	497174	19447X	PARTICIPANT	\N	PRESENT	0
499039	497174	19599P	PARTICIPANT	\N	PRESENT	0
499040	497174	20080C	PARTICIPANT	\N	PRESENT	0
499041	497174	20172F	PARTICIPANT	\N	PRESENT	0
499042	497174	20108W	PARTICIPANT	\N	PRESENT	0
499043	497174	11064N	PARTICIPANT	\N	PRESENT	0
499044	497174	20024T	PARTICIPANT	\N	PRESENT	0
499045	497174	20124W	PARTICIPANT	\N	PRESENT	0
499046	497174	11048N	PARTICIPANT	\N	PRESENT	0
499047	497174	11097X	PARTICIPANT	\N	PRESENT	0
499048	497174	19713W	PARTICIPANT	\N	PRESENT	0
499049	497174	14059S	PARTICIPANT	\N	PRESENT	0
499050	497174	16685X	PARTICIPANT	\N	PRESENT	0
499051	497174	14042U	PARTICIPANT	\N	PRESENT	0
499052	497174	19479G	PARTICIPANT	\N	PRESENT	0
499053	497174	01048V	PARTICIPANT	\N	PRESENT	0
499054	497174	19543W	PARTICIPANT	\N	PRESENT	0
499055	497174	19569H	PARTICIPANT	\N	PRESENT	0
499056	497174	20054A	PARTICIPANT	\N	PRESENT	0
499057	497174	19739H	PARTICIPANT	\N	PRESENT	0
499058	497174	14219Q	PARTICIPANT	\N	PRESENT	0
499059	497174	20126Y	PARTICIPANT	\N	PRESENT	0
499060	497174	20144B	PARTICIPANT	\N	PRESENT	0
499061	497174	20040T	PARTICIPANT	\N	PRESENT	0
499062	497174	19369B	PARTICIPANT	\N	PRESENT	0
499063	497174	20066E	PARTICIPANT	\N	PRESENT	0
499064	497174	19709B	PARTICIPANT	\N	PRESENT	0
499065	497174	01034P	PARTICIPANT	\N	PRESENT	0
499066	497174	19691J	PARTICIPANT	\N	PRESENT	0
499067	497174	20104S	PARTICIPANT	\N	PRESENT	0
499068	497174	11085T	PARTICIPANT	\N	PRESENT	0
499069	497174	20072C	PARTICIPANT	\N	PRESENT	0
499070	497174	14231L	PARTICIPANT	\N	PRESENT	0
499071	497174	14217N	PARTICIPANT	\N	PRESENT	0
499072	497174	20096L	PARTICIPANT	\N	PRESENT	0
499073	497174	01043Q	PARTICIPANT	\N	PRESENT	0
499074	497174	14030Q	PARTICIPANT	\N	PRESENT	0
499075	497174	01025N	PARTICIPANT	\N	PRESENT	0
499076	497174	07029T	PARTICIPANT	\N	PRESENT	0
499077	497174	11053K	PARTICIPANT	\N	PRESENT	0
499078	497174	14073Q	PARTICIPANT	\N	PRESENT	0
499079	497174	08009T	PARTICIPANT	\N	PRESENT	0
499080	497174	20038A	PARTICIPANT	\N	PRESENT	0
499081	497174	19441R	PARTICIPANT	\N	PRESENT	0
499082	497174	19745F	PARTICIPANT	\N	PRESENT	0
499083	497174	14179A	PARTICIPANT	\N	PRESENT	0
499084	497174	04070G	PARTICIPANT	\N	PRESENT	0
499085	497174	19699S	PARTICIPANT	\N	PRESENT	0
499086	497174	14033T	PARTICIPANT	\N	PRESENT	0
499087	497174	14331P	PARTICIPANT	\N	PRESENT	0
499088	497174	20058E	PARTICIPANT	\N	PRESENT	0
499089	497174	19954N	PARTICIPANT	\N	PRESENT	0
499090	497174	20118Y	PARTICIPANT	\N	PRESENT	0
499091	497174	19820Y	PARTICIPANT	\N	PRESENT	0
499092	497174	19415P	PARTICIPANT	\N	PRESENT	0
499093	497174	20064C	PARTICIPANT	\N	PRESENT	0
499094	497174	11045K	PARTICIPANT	\N	PRESENT	0
499095	497174	19621T	PARTICIPANT	\N	PRESENT	0
499096	497174	19649G	PARTICIPANT	\N	PRESENT	0
499097	497174	20062A	PARTICIPANT	\N	PRESENT	0
499098	497174	14213J	PARTICIPANT	\N	PRESENT	0
499099	497174	18083K	PARTICIPANT	\N	PRESENT	0
499100	497174	19581D	PARTICIPANT	\N	PRESENT	0
499101	497174	19367Y	PARTICIPANT	\N	PRESENT	0
499112	497174	17367Q	PARTICIPANT	\N	PRESENT	0
499103	497174	20174H	PARTICIPANT	\N	PRESENT	0
499104	497174	20132W	PARTICIPANT	\N	PRESENT	0
499105	497174	19349W	PARTICIPANT	\N	PRESENT	0
499106	497174	19611R	PARTICIPANT	\N	PRESENT	0
499107	497174	14327T	PARTICIPANT	\N	PRESENT	0
499108	497174	20110Q	PARTICIPANT	\N	PRESENT	0
499109	497174	14205J	PARTICIPANT	\N	PRESENT	0
499110	497174	14189C	PARTICIPANT	\N	PRESENT	0
499111	497174	20084G	PARTICIPANT	\N	PRESENT	0
499113	497174	98022P	PARTICIPANT	\N	PRESENT	0
499114	497174	19531S	PARTICIPANT	\N	PRESENT	0
499115	497174	14225N	PARTICIPANT	\N	PRESENT	0
499116	497174	19735D	PARTICIPANT	\N	PRESENT	0
499117	497174	14259Y	PARTICIPANT	\N	PRESENT	0
499118	497174	14026U	PARTICIPANT	\N	PRESENT	0
499119	497174	20068G	PARTICIPANT	\N	PRESENT	0
499120	497174	11070L	PARTICIPANT	\N	PRESENT	0
499121	497174	14089Y	PARTICIPANT	\N	PRESENT	0
499124	497174	95063L	PARTICIPANT	\N	PRESENT	0
499125	496310	20018V	PARTICIPANT	\N	PRESENT	0
487374	479262	18083K	PARTICIPANT	\N	PRESENT	0
487375	479262	14251Q	PARTICIPANT	\N	PRESENT	0
487376	479262	04059M	PARTICIPANT	\N	PRESENT	0
487377	479262	11074Q	PARTICIPANT	\N	PRESENT	0
487378	479262	01028R	PARTICIPANT	\N	PRESENT	0
487379	479262	19657G	PARTICIPANT	\N	PRESENT	0
487380	479262	14069U	PARTICIPANT	\N	PRESENT	0
487381	479262	19912C	PARTICIPANT	\N	PRESENT	0
487382	479262	08052W	PARTICIPANT	\N	PRESENT	0
487383	479262	14357A	PARTICIPANT	\N	PRESENT	0
487384	479262	14021P	PARTICIPANT	\N	PRESENT	0
487385	479262	19762G	PARTICIPANT	\N	PRESENT	0
487386	479262	19669L	PARTICIPANT	\N	PRESENT	0
487387	479262	04018C	PARTICIPANT	\N	PRESENT	0
487388	479262	19715Y	PARTICIPANT	\N	PRESENT	0
487389	479262	19701S	PARTICIPANT	\N	PRESENT	0
487390	479262	11097X	PARTICIPANT	\N	PRESENT	0
487391	479262	19649G	PARTICIPANT	\N	PRESENT	0
487392	479262	19367Y	PARTICIPANT	\N	PRESENT	0
487393	479262	11045K	PARTICIPANT	\N	PRESENT	0
487394	479262	10015M	PARTICIPANT	\N	PRESENT	0
487395	479262	08038Y	PARTICIPANT	\N	PRESENT	0
487396	479262	19741B	PARTICIPANT	\N	PRESENT	0
487397	479262	19926J	PARTICIPANT	\N	PRESENT	0
487398	479262	19794Q	PARTICIPANT	\N	PRESENT	0
487399	479262	14085U	PARTICIPANT	\N	PRESENT	0
487400	479262	14065Q	PARTICIPANT	\N	PRESENT	0
487401	479262	08058D	PARTICIPANT	\N	PRESENT	0
487402	479262	19549D	PARTICIPANT	\N	PRESENT	0
487403	479262	19954N	PARTICIPANT	\N	PRESENT	0
487404	479262	14147R	PARTICIPANT	\N	PRESENT	0
487405	479262	97011G	PARTICIPANT	\N	PRESENT	0
487406	479262	19703U	PARTICIPANT	\N	PRESENT	0
487407	479262	19683J	PARTICIPANT	\N	PRESENT	0
487408	479262	14331P	PARTICIPANT	\N	PRESENT	0
487409	479262	19333N	PARTICIPANT	\N	PRESENT	0
487410	479262	14217N	PARTICIPANT	\N	PRESENT	0
487411	479262	19631V	PARTICIPANT	\N	PRESENT	0
487412	479262	10006L	PARTICIPANT	\N	PRESENT	0
487413	479262	11056N	PARTICIPANT	\N	PRESENT	0
487414	479262	19671E	PARTICIPANT	\N	PRESENT	0
487415	479262	11067R	PARTICIPANT	\N	PRESENT	0
487416	479262	19533U	PARTICIPANT	\N	PRESENT	0
487417	479262	08034U	PARTICIPANT	\N	PRESENT	0
487418	479262	19503N	PARTICIPANT	\N	PRESENT	0
487419	479262	04049K	PARTICIPANT	\N	PRESENT	0
487420	479262	19930E	PARTICIPANT	\N	PRESENT	0
487421	479262	08018U	PARTICIPANT	\N	PRESENT	0
487422	479262	14081Q	PARTICIPANT	\N	PRESENT	0
487423	479262	19663E	PARTICIPANT	\N	PRESENT	0
487424	479262	14042U	PARTICIPANT	\N	PRESENT	0
487425	479262	19369B	PARTICIPANT	\N	PRESENT	0
487426	479262	01034P	PARTICIPANT	\N	PRESENT	0
487427	479262	19643A	PARTICIPANT	\N	PRESENT	0
487428	479262	19551W	PARTICIPANT	\N	PRESENT	0
487429	479262	11080N	PARTICIPANT	\N	PRESENT	0
487430	479262	16685X	PARTICIPANT	\N	PRESENT	0
487431	479262	19611R	PARTICIPANT	\N	PRESENT	0
487432	479262	19766L	PARTICIPANT	\N	PRESENT	0
487433	479262	19721W	PARTICIPANT	\N	PRESENT	0
487434	479262	14219Q	PARTICIPANT	\N	PRESENT	0
487435	479262	19713W	PARTICIPANT	\N	PRESENT	0
487436	479262	11085T	PARTICIPANT	\N	PRESENT	0
487437	479262	01057W	PARTICIPANT	\N	PRESENT	0
487438	479262	04043D	PARTICIPANT	\N	PRESENT	0
487439	479262	11090Q	PARTICIPANT	\N	PRESENT	0
487440	479262	19335Q	PARTICIPANT	\N	PRESENT	0
487441	479262	19914E	PARTICIPANT	\N	PRESENT	0
487442	479262	19531S	PARTICIPANT	\N	PRESENT	0
487443	479262	05008E	PARTICIPANT	\N	PRESENT	0
487444	479262	19673G	PARTICIPANT	\N	PRESENT	0
487445	479262	14255U	PARTICIPANT	\N	PRESENT	0
487446	479262	19577H	PARTICIPANT	\N	PRESENT	0
487447	479262	14087W	PARTICIPANT	\N	PRESENT	0
487448	479262	01024M	PARTICIPANT	\N	PRESENT	0
487449	479262	14215L	PARTICIPANT	\N	PRESENT	0
487450	479262	14071N	PARTICIPANT	\N	PRESENT	0
487451	479262	19421M	PARTICIPANT	\N	PRESENT	0
487452	479262	04044E	PARTICIPANT	\N	PRESENT	0
487453	479262	04092N	PARTICIPANT	\N	PRESENT	0
487454	479262	95030B	PARTICIPANT	\N	PRESENT	0
487455	479262	04085P	PARTICIPANT	\N	PRESENT	0
487456	479262	04047H	PARTICIPANT	\N	PRESENT	0
487457	479262	11101A	PARTICIPANT	\N	PRESENT	0
487458	479262	04035D	PARTICIPANT	\N	PRESENT	0
487459	479262	98024R	PARTICIPANT	\N	PRESENT	0
487460	479262	04097T	PARTICIPANT	\N	PRESENT	0
487461	479262	08010L	PARTICIPANT	\N	PRESENT	0
487462	479262	19679N	PARTICIPANT	\N	PRESENT	0
487463	479262	99004R	PARTICIPANT	\N	PRESENT	0
487464	479262	96004D	PARTICIPANT	\N	PRESENT	0
487465	479262	14193X	PARTICIPANT	\N	PRESENT	0
487466	479262	04071H	PARTICIPANT	\N	PRESENT	0
487467	479262	11103C	PARTICIPANT	\N	PRESENT	0
487471	479262	19647E	PARTICIPANT	\N	PRESENT	0
487469	479262	14123H	PARTICIPANT	\N	PRESENT	0
487470	479262	19711U	PARTICIPANT	\N	PRESENT	0
487472	479262	19760E	PARTICIPANT	\N	PRESENT	0
487473	479262	01058X	PARTICIPANT	\N	PRESENT	0
487474	479262	07033P	PARTICIPANT	\N	PRESENT	0
487475	479262	08039A	PARTICIPANT	\N	PRESENT	0
487476	479262	04086Q	PARTICIPANT	\N	PRESENT	0
487477	479262	19515S	PARTICIPANT	\N	PRESENT	0
487478	479262	11048N	PARTICIPANT	\N	PRESENT	0
487479	479262	86034E	PARTICIPANT	\N	PRESENT	0
487480	479262	14197C	PARTICIPANT	\N	PRESENT	0
487481	479262	19441R	PARTICIPANT	\N	PRESENT	0
487484	479262	08011M	PARTICIPANT	\N	PRESENT	0
487485	479262	14059S	PARTICIPANT	\N	PRESENT	0
487487	479262	11065P	PARTICIPANT	\N	PRESENT	0
487488	479262	19689Q	PARTICIPANT	\N	PRESENT	0
487489	479262	11053K	PARTICIPANT	\N	PRESENT	0
487490	479262	05012A	PARTICIPANT	\N	PRESENT	0
487491	479262	19489J	PARTICIPANT	\N	PRESENT	0
487492	479262	11033F	PARTICIPANT	\N	PRESENT	0
487493	479262	95063L	PARTICIPANT	\N	PRESENT	0
487494	479262	08073C	PARTICIPANT	\N	PRESENT	0
487495	479262	95067Q	PARTICIPANT	\N	PRESENT	0
487496	479262	89017R	PARTICIPANT	\N	PRESENT	0
487668	486187	04059M	PARTICIPANT	\N	PRESENT	0
487671	486187	11070L	PARTICIPANT	\N	PRESENT	0
487672	486187	11074Q	PARTICIPANT	\N	PRESENT	0
487673	486187	08015R	PARTICIPANT	\N	PRESENT	0
487674	486187	14121F	PARTICIPANT	\N	PRESENT	0
487675	486187	17589D	PARTICIPANT	\N	PRESENT	0
487676	486187	19553Y	PARTICIPANT	\N	PRESENT	0
487677	486187	07029T	PARTICIPANT	\N	PRESENT	0
487678	486187	19467C	PARTICIPANT	\N	PRESENT	0
487679	486187	19794Q	PARTICIPANT	\N	PRESENT	0
487680	486187	01058X	PARTICIPANT	\N	PRESENT	0
487681	486187	97011G	PARTICIPANT	\N	PRESENT	0
487682	486187	19711U	PARTICIPANT	\N	PRESENT	0
487683	486187	19551W	PARTICIPANT	\N	PRESENT	0
487684	486187	88008L	PARTICIPANT	\N	PRESENT	0
487685	486187	19415P	PARTICIPANT	\N	PRESENT	0
487686	486187	14255U	PARTICIPANT	\N	PRESENT	0
487687	486187	07004J	PARTICIPANT	\N	PRESENT	0
487688	486187	04086Q	PARTICIPANT	\N	PRESENT	0
487689	486187	19657G	PARTICIPANT	\N	PRESENT	0
487690	486187	18083K	PARTICIPANT	\N	PRESENT	0
487691	486187	08073C	PARTICIPANT	\N	PRESENT	0
487692	486187	01057W	PARTICIPANT	\N	PRESENT	0
487693	486187	11012A	PARTICIPANT	\N	PRESENT	0
487694	486187	19387D	PARTICIPANT	\N	PRESENT	0
487695	486187	08052W	PARTICIPANT	\N	PRESENT	0
487696	486187	19531S	PARTICIPANT	\N	PRESENT	0
487697	486187	19565D	PARTICIPANT	\N	PRESENT	0
487698	486187	11103C	PARTICIPANT	\N	PRESENT	0
487699	486187	19651A	PARTICIPANT	\N	PRESENT	0
487700	486187	14147R	PARTICIPANT	\N	PRESENT	0
487701	486187	19441R	PARTICIPANT	\N	PRESENT	0
487718	486187	14069U	PARTICIPANT	\N	PRESENT	0
487722	486187	14042U	PARTICIPANT	\N	PRESENT	0
487723	486187	19687N	PARTICIPANT	\N	PRESENT	0
504503	502289	19489J	PARTICIPANT	\N	PRESENT	0
504504	502289	20114U	PARTICIPANT	\N	PRESENT	0
504505	502289	14021P	PARTICIPANT	\N	PRESENT	0
504648	501778	20088L	PARTICIPANT	\N	PRESENT	0
504649	501778	19413M	PARTICIPANT	\N	PRESENT	1
504650	501778	19866P	PARTICIPANT	\N	PRESENT	1
504509	503158	20068G	PARTICIPANT	\N	PRESENT	0
504510	503158	20076G	PARTICIPANT	\N	PRESENT	0
504511	503158	19251M	PARTICIPANT	\N	PRESENT	0
504512	503158	19681G	PARTICIPANT	\N	EXCUSE	0
504523	503158	20118Y	PARTICIPANT	\N	PRESENT	0
504524	503158	20020P	PARTICIPANT	\N	PRESENT	0
504525	503158	19745F	PARTICIPANT	\N	PRESENT	0
504526	503158	20046A	PARTICIPANT	\N	PRESENT	0
504527	503158	20102Q	PARTICIPANT	\N	PRESENT	0
504528	503158	19549D	PARTICIPANT	\N	PRESENT	0
504538	503158	19333N	PARTICIPANT	\N	PRESENT	0
504539	503158	20140W	PARTICIPANT	\N	PRESENT	0
504540	503158	14219Q	PRESIDENT	0	PRESENT	0
504541	503158	19826F	PARTICIPANT	\N	PRESENT	0
504542	503158	19637C	PARTICIPANT	\N	PRESENT	0
504543	503158	18083K	PARTICIPANT	\N	PRESENT	0
504544	503158	20106U	PARTICIPANT	\N	PRESENT	0
504545	503158	19503N	PARTICIPANT	\N	PRESENT	0
504546	503158	19739H	PARTICIPANT	\N	PRESENT	0
504547	503158	20022R	PARTICIPANT	\N	PRESENT	0
504548	503158	14031R	PARTICIPANT	\N	PRESENT	0
504549	503158	19820Y	PARTICIPANT	\N	PRESENT	0
504550	503158	14221J	PARTICIPANT	\N	PRESENT	0
504551	503158	14169X	PARTICIPANT	\N	PRESENT	0
504552	503158	17367Q	PARTICIPANT	\N	PRESENT	0
504561	503158	19685L	PARTICIPANT	\N	PRESENT	0
504567	502449	14331P	PARTICIPANT	\N	PRESENT	0
504568	502449	01057W	PARTICIPANT	\N	PRESENT	0
504569	502449	19671E	PARTICIPANT	\N	PRESENT	0
504570	502449	07029T	PARTICIPANT	\N	PRESENT	0
504571	502449	08010L	PARTICIPANT	\N	PRESENT	0
504572	502449	20116W	PARTICIPANT	\N	PRESENT	0
504573	502449	14189C	PARTICIPANT	\N	PRESENT	0
504574	502449	19687N	PARTICIPANT	\N	PRESENT	0
504575	502449	20150Y	PARTICIPANT	\N	PRESENT	0
504576	502449	14083S	PARTICIPANT	\N	PRESENT	0
504577	502449	11012A	PARTICIPANT	\N	PRESENT	0
504578	502449	20070A	PARTICIPANT	\N	PRESENT	0
504579	502449	19741B	PARTICIPANT	\N	PRESENT	0
504582	501778	20086J	PARTICIPANT	\N	PRESENT	1
504583	501778	19768N	PARTICIPANT	\N	PRESENT	0
504584	501778	19515S	PARTICIPANT	\N	PRESENT	0
504585	501778	19782L	PARTICIPANT	\N	PRESENT	0
504586	501778	19441R	PARTICIPANT	\N	PRESENT	1
504587	501778	20078J	PARTICIPANT	\N	PRESENT	0
504588	501778	20094J	PARTICIPANT	\N	PRESENT	0
504589	501778	04045F	PARTICIPANT	\N	PRESENT	0
504590	501778	20104S	PARTICIPANT	\N	PRESENT	0
504591	501778	19631V	PARTICIPANT	\N	PRESENT	0
504592	501778	11099A	PARTICIPANT	\N	PRESENT	0
504593	501778	19705W	PARTICIPANT	\N	PRESENT	1
504594	501778	08015R	PARTICIPANT	\N	PRESENT	1
504595	501778	19575F	PARTICIPANT	\N	PRESENT	0
504596	501778	19369B	PARTICIPANT	\N	PRESENT	0
504597	501778	19511N	PARTICIPANT	\N	PRESENT	0
504598	501778	19521Q	PARTICIPANT	\N	PRESENT	0
504599	501778	14329V	PARTICIPANT	\N	PRESENT	0
504600	501778	14038Y	PARTICIPANT	\N	PRESENT	0
504601	501778	19467C	PARTICIPANT	\N	PRESENT	0
504602	501778	20034V	PARTICIPANT	\N	PRESENT	0
504603	501778	14187A	PARTICIPANT	\N	PRESENT	0
504604	501778	19695N	PARTICIPANT	\N	PRESENT	0
504605	501778	11090Q	PRESIDENT	0	PRESENT	0
504606	501778	01025N	PARTICIPANT	\N	PRESENT	0
504607	501778	20054A	PARTICIPANT	\N	PRESENT	1
504608	501778	20174H	PARTICIPANT	\N	PRESENT	0
504609	501778	14205J	PARTICIPANT	\N	PRESENT	0
504610	501778	14207L	PARTICIPANT	\N	PRESENT	0
504611	501778	14257W	PARTICIPANT	\N	PRESENT	1
504651	501778	08028W	PARTICIPANT	\N	EXCUSE	0
504626	502289	19543W	PARTICIPANT	\N	PRESENT	0
504616	503158	20100N	PARTICIPANT	\N	PRESENT	0
504617	503158	20024T	PARTICIPANT	\N	PRESENT	0
504618	503158	20032T	PARTICIPANT	\N	PRESENT	0
504619	501778	20082E	PARTICIPANT	\N	PRESENT	0
504620	501778	20018V	PARTICIPANT	\N	PRESENT	1
504621	501778	19563B	PARTICIPANT	\N	PRESENT	0
504622	501778	20030R	PARTICIPANT	\N	PRESENT	1
504623	501778	20062A	PARTICIPANT	\N	PRESENT	0
504629	502289	05008E	PARTICIPANT	\N	PRESENT	1
504630	502289	19447X	PARTICIPANT	\N	PRESENT	1
504631	502289	17737W	PARTICIPANT	\N	PRESENT	0
504632	502289	20110Q	PARTICIPANT	\N	PRESENT	0
504633	502289	14147R	PARTICIPANT	\N	PRESENT	0
504634	502289	11072N	PARTICIPANT	\N	PRESENT	1
504635	502289	14053L	PARTICIPANT	\N	PRESENT	1
504636	502289	10015M	PARTICIPANT	\N	PRESENT	0
504652	502289	04047H	PRESIDENT	0	PRESENT	0
504638	502289	11026G	PARTICIPANT	\N	PRESENT	0
504653	502289	19954N	PARTICIPANT	\N	PRESENT	0
504640	502289	19725B	PARTICIPANT	\N	PRESENT	0
504641	502289	14089Y	PARTICIPANT	\N	PRESENT	0
504642	502289	19729F	PARTICIPANT	\N	PRESENT	1
504643	502289	95063L	PARTICIPANT	\N	PRESENT	0
504644	502289	14069U	PARTICIPANT	\N	PRESENT	0
504645	502289	19749K	PARTICIPANT	\N	PRESENT	0
504654	503158	19701S	PARTICIPANT	\N	PRESENT	0
504655	503158	20096L	PARTICIPANT	\N	PRESENT	0
504656	501778	19383Y	PARTICIPANT	\N	PRESENT	0
504657	501778	19507S	PARTICIPANT	\N	PRESENT	0
504659	498289	20134Y	PARTICIPANT	\N	PRESENT	0
504660	498289	14073Q	PARTICIPANT	\N	PRESENT	0
504661	501778	20060X	PARTICIPANT	\N	PRESENT	0
504662	498289	11043H	PARTICIPANT	\N	PRESENT	0
504664	503158	20038A	PARTICIPANT	\N	PRESENT	0
504666	501778	20092G	PARTICIPANT	\N	PRESENT	0
504677	503158	11065P	PARTICIPANT	\N	PRESENT	1
504678	503158	19387D	PARTICIPANT	\N	PRESENT	1
504679	503158	19619A	PARTICIPANT	\N	PRESENT	1
504670	501778	20028X	PARTICIPANT	\N	PRESENT	1
504671	502449	08034U	PARTICIPANT	\N	PRESENT	0
504672	502449	19689Q	PARTICIPANT	\N	PRESENT	0
504673	503158	19599P	PARTICIPANT	\N	PRESENT	0
504674	503158	19525U	PARTICIPANT	\N	PRESENT	0
504675	503158	17229F	PARTICIPANT	\N	PRESENT	1
504676	503158	11101A	PARTICIPANT	\N	PRESENT	1
484692	483370	96004D	PARTICIPANT	\N	PRESENT	0
486527	479201	11027H	PARTICIPANT	\N	PRESENT	0
486528	479201	08011M	PARTICIPANT	\N	PRESENT	0
486529	479201	19711U	PARTICIPANT	\N	PRESENT	0
486530	479201	11090Q	PARTICIPANT	\N	PRESENT	0
486531	479201	19565D	PARTICIPANT	\N	PRESENT	0
486532	479201	07033P	PARTICIPANT	\N	PRESENT	0
486533	479201	19760E	PARTICIPANT	\N	PRESENT	0
486534	479201	14357A	PARTICIPANT	\N	PRESENT	0
486535	479201	19593H	PARTICIPANT	\N	PRESENT	0
486536	479201	04018C	PARTICIPANT	\N	PRESENT	0
486537	479201	12016W	PARTICIPANT	\N	PRESENT	0
486538	479201	19667J	PARTICIPANT	\N	PRESENT	0
486539	479201	07029T	PARTICIPANT	\N	PRESENT	0
486540	479201	19689Q	PARTICIPANT	\N	PRESENT	0
486541	479201	14041T	PARTICIPANT	\N	PRESENT	0
486542	479201	19531S	PARTICIPANT	\N	PRESENT	0
486543	479201	14051J	PARTICIPANT	\N	PRESENT	0
486544	479201	04086Q	PARTICIPANT	\N	PRESENT	0
486545	479201	19551W	PARTICIPANT	\N	PRESENT	0
486546	479201	11074Q	PARTICIPANT	\N	PRESENT	0
486547	479201	19701S	PARTICIPANT	\N	PRESENT	0
486548	479201	08024S	PARTICIPANT	\N	PRESENT	0
486549	479201	19585H	PARTICIPANT	\N	PRESENT	0
486550	479201	11012A	PARTICIPANT	\N	PRESENT	0
486551	479201	19719D	PARTICIPANT	\N	PRESENT	0
486552	479201	19695N	PARTICIPANT	\N	PRESENT	0
486553	479201	11109J	PARTICIPANT	\N	PRESENT	0
486554	479201	19671E	PARTICIPANT	\N	PRESENT	0
486555	479201	19503N	PARTICIPANT	\N	PRESENT	0
486556	479201	19741B	PARTICIPANT	\N	PRESENT	0
486557	479201	14255U	PARTICIPANT	\N	PRESENT	0
486558	479201	07004J	PARTICIPANT	\N	PRESENT	0
486559	479201	11099A	PARTICIPANT	\N	PRESENT	0
486560	479201	19766L	PARTICIPANT	\N	PRESENT	0
486561	479201	19713W	PARTICIPANT	\N	PRESENT	0
486562	479201	19651A	PARTICIPANT	\N	PRESENT	0
486563	479201	19647E	PARTICIPANT	\N	PRESENT	0
486564	479201	19663E	PARTICIPANT	\N	PRESENT	0
486565	479201	19762G	PARTICIPANT	\N	PRESENT	0
486566	479201	11048N	PARTICIPANT	\N	PRESENT	0
486567	479201	19705W	PARTICIPANT	\N	PRESENT	0
486568	479201	11026G	PARTICIPANT	\N	PRESENT	0
486569	479201	12041X	PARTICIPANT	\N	PRESENT	0
486615	484587	04085P	PARTICIPANT	\N	PRESENT	0
486616	484587	14255U	PARTICIPANT	\N	PRESENT	0
486617	484587	19585H	PARTICIPANT	\N	PRESENT	0
486618	484587	04034C	PARTICIPANT	\N	PRESENT	0
486619	484587	11026G	PARTICIPANT	\N	PRESENT	0
486620	484587	07004J	PARTICIPANT	\N	PRESENT	0
486621	484587	11090Q	PARTICIPANT	\N	PRESENT	0
486622	484587	19711U	PARTICIPANT	\N	PRESENT	0
486623	484587	14357A	PARTICIPANT	\N	PRESENT	0
486624	484587	07033P	PARTICIPANT	\N	PRESENT	0
486625	484587	19713W	PARTICIPANT	\N	PRESENT	0
486626	484587	11074Q	PARTICIPANT	\N	PRESENT	0
486627	484587	19741B	PARTICIPANT	\N	PRESENT	0
486628	484587	19593H	PARTICIPANT	\N	PRESENT	0
486629	484587	19766L	PARTICIPANT	\N	PRESENT	0
486630	484587	19695N	PARTICIPANT	\N	PRESENT	0
486631	484587	12041X	PARTICIPANT	\N	PRESENT	0
486632	484587	19651A	PARTICIPANT	\N	PRESENT	0
486633	484587	08024S	PARTICIPANT	\N	PRESENT	0
486634	484587	19667J	PARTICIPANT	\N	PRESENT	0
486635	484587	19719D	PARTICIPANT	\N	PRESENT	0
486636	484587	19531S	PARTICIPANT	\N	PRESENT	0
486637	484587	14261S	PARTICIPANT	\N	PRESENT	0
486638	484587	19671E	PARTICIPANT	\N	PRESENT	0
486639	484587	19701S	PARTICIPANT	\N	PRESENT	0
486640	484587	04018C	PARTICIPANT	\N	PRESENT	0
486641	484587	14041T	PARTICIPANT	\N	PRESENT	0
486642	484587	19762G	PARTICIPANT	\N	PRESENT	0
486643	484587	11048N	PARTICIPANT	\N	PRESENT	0
486644	484587	19663E	PARTICIPANT	\N	PRESENT	0
486645	484587	04035D	PARTICIPANT	\N	PRESENT	0
486646	484587	04086Q	PARTICIPANT	\N	PRESENT	0
486647	484587	12016W	PARTICIPANT	\N	PRESENT	0
486648	484587	07029T	PARTICIPANT	\N	PRESENT	0
486649	484587	14051J	PARTICIPANT	\N	PRESENT	0
486650	484587	19689Q	PARTICIPANT	\N	PRESENT	0
486651	484587	19647E	PARTICIPANT	\N	PRESENT	0
486652	484587	19687N	PARTICIPANT	\N	PRESENT	0
486653	484587	19705W	PARTICIPANT	\N	PRESENT	0
486654	484587	19503N	PARTICIPANT	\N	PRESENT	0
486655	484587	11085T	PARTICIPANT	\N	PRESENT	0
486656	484587	95041E	PARTICIPANT	\N	PRESENT	0
486657	484587	11099A	PARTICIPANT	\N	PRESENT	0
486613	484587	11070L	PARTICIPANT	\N	PRESENT	0
486614	484587	08011M	PARTICIPANT	\N	PRESENT	0
486658	484587	19551W	PARTICIPANT	\N	PRESENT	0
486661	484587	99004R	PARTICIPANT	\N	PRESENT	0
486699	484588	19651A	PARTICIPANT	\N	PRESENT	0
486700	484588	12016W	PARTICIPANT	\N	PRESENT	0
486701	484588	19503N	PARTICIPANT	\N	PRESENT	0
486702	484588	19689Q	PARTICIPANT	\N	PRESENT	0
486703	484588	14051J	PARTICIPANT	\N	PRESENT	0
486704	484588	12041X	PARTICIPANT	\N	PRESENT	0
486705	484588	19593H	PARTICIPANT	\N	PRESENT	0
486706	484588	19585H	PARTICIPANT	\N	PRESENT	0
486707	484588	07004J	PARTICIPANT	\N	PRESENT	0
486708	484588	19705W	PARTICIPANT	\N	PRESENT	0
486709	484588	07029T	PARTICIPANT	\N	PRESENT	0
486710	484588	19766L	PARTICIPANT	\N	PRESENT	0
486711	484588	14041T	PARTICIPANT	\N	PRESENT	0
486712	484588	11090Q	PARTICIPANT	\N	PRESENT	0
486713	484588	14357A	PARTICIPANT	\N	PRESENT	0
486714	484588	04018C	PARTICIPANT	\N	PRESENT	0
486715	484588	99004R	PARTICIPANT	\N	PRESENT	0
486716	484588	19711U	PARTICIPANT	\N	PRESENT	0
486717	484588	04086Q	PARTICIPANT	\N	PRESENT	0
486718	484588	19701S	PARTICIPANT	\N	PRESENT	0
486719	484588	19647E	PARTICIPANT	\N	PRESENT	0
486720	484588	08031R	PARTICIPANT	\N	PRESENT	0
486721	484588	14261S	PARTICIPANT	\N	PRESENT	0
486722	484588	14255U	PARTICIPANT	\N	PRESENT	0
486723	484588	11099A	PARTICIPANT	\N	PRESENT	0
486724	484588	11026G	PARTICIPANT	\N	PRESENT	0
486725	484588	11053K	PARTICIPANT	\N	PRESENT	0
486726	484588	19695N	PARTICIPANT	\N	PRESENT	0
486727	484588	04085P	PARTICIPANT	\N	PRESENT	0
486728	484588	19687N	PARTICIPANT	\N	PRESENT	0
486729	484588	19713W	PARTICIPANT	\N	PRESENT	0
486730	484588	19741B	PARTICIPANT	\N	PRESENT	0
486731	484588	19671E	PARTICIPANT	\N	PRESENT	0
487928	479213	04044E	PARTICIPANT	\N	PRESENT	0
487929	479213	11026G	PARTICIPANT	\N	PRESENT	0
487962	479213	19711U	PARTICIPANT	\N	PRESENT	0
486698	484588	08011M	PARTICIPANT	\N	PRESENT	0
487963	479213	04085P	PARTICIPANT	\N	PRESENT	0
487964	479213	01058X	PARTICIPANT	\N	PRESENT	0
487965	479213	01028R	PARTICIPANT	\N	PRESENT	0
487966	479213	97011G	PARTICIPANT	\N	PRESENT	0
487967	479213	19349W	PARTICIPANT	\N	PRESENT	0
487968	479213	01024M	PARTICIPANT	\N	PRESENT	0
487969	479213	14093U	PARTICIPANT	\N	PRESENT	0
487970	479213	07004J	PARTICIPANT	\N	PRESENT	0
487971	479213	19695N	PARTICIPANT	\N	PRESENT	0
487972	479213	19333N	PARTICIPANT	\N	PRESENT	0
487973	479213	05008E	PARTICIPANT	\N	PRESENT	0
487974	479213	19467C	PARTICIPANT	\N	PRESENT	0
487982	479213	19673G	PARTICIPANT	\N	PRESENT	0
487983	479213	19657G	PARTICIPANT	\N	PRESENT	0
487984	479213	04018C	PARTICIPANT	\N	PRESENT	0
487985	479213	14121F	PARTICIPANT	\N	PRESENT	0
487986	479213	14034U	PARTICIPANT	\N	PRESENT	0
487987	479213	18083K	PARTICIPANT	\N	PRESENT	0
487989	479213	19631V	PARTICIPANT	\N	PRESENT	0
487990	479213	19543W	PARTICIPANT	\N	PRESENT	0
487991	479213	04057K	PARTICIPANT	\N	PRESENT	0
499529	497179	19413M	PARTICIPANT	\N	PRESENT	0
499530	497179	19503N	PARTICIPANT	\N	PRESENT	0
499334	497846	18083K	PARTICIPANT	\N	PRESENT	0
499335	497846	14219Q	PRESIDENT	0	PRESENT	0
499336	497672	04047H	PRESIDENT	0	PRESENT	0
499337	497672	04008A	PARTICIPANT	\N	PRESENT	0
499338	497846	20038A	PARTICIPANT	\N	PRESENT	0
499339	497846	20022R	PARTICIPANT	\N	PRESENT	0
499531	497179	11099A	PARTICIPANT	\N	PRESENT	0
499532	497179	19347U	PARTICIPANT	\N	PRESENT	0
499533	497179	19593H	PARTICIPANT	\N	PRESENT	0
499534	497179	14021P	PARTICIPANT	\N	PRESENT	0
499535	497179	08017T	PARTICIPANT	\N	PRESENT	0
499536	497179	11027H	PARTICIPANT	\N	PRESENT	0
499537	497179	20084G	PARTICIPANT	\N	PRESENT	0
499538	498010	20086J	PARTICIPANT	\N	PRESENT	0
499348	497672	19649G	PARTICIPANT	\N	PRESENT	0
499349	497672	10015M	PARTICIPANT	\N	PRESENT	0
499350	497672	11026G	PARTICIPANT	\N	PRESENT	0
499351	497672	19543W	PARTICIPANT	\N	PRESENT	0
499352	497672	04085P	PARTICIPANT	\N	PRESENT	0
499353	497672	05008E	PARTICIPANT	\N	PRESENT	0
499354	497672	19447X	PARTICIPANT	\N	PRESENT	0
499355	497672	14231L	PARTICIPANT	\N	PRESENT	0
499356	497672	19954N	PARTICIPANT	\N	PRESENT	0
499357	497672	19729F	PARTICIPANT	\N	PRESENT	0
499358	497672	17737W	PARTICIPANT	\N	PRESENT	0
499359	497672	14041T	PARTICIPANT	\N	PRESENT	0
499360	497672	14179A	PARTICIPANT	\N	PRESENT	0
499361	497672	14147R	PARTICIPANT	\N	PRESENT	0
499362	497672	14151M	PARTICIPANT	\N	PRESENT	0
499539	497179	20092G	PARTICIPANT	\N	PRESENT	0
499364	497846	20032T	PARTICIPANT	\N	PRESENT	0
499365	497846	05012A	PARTICIPANT	\N	PRESENT	0
499366	497846	14031R	PARTICIPANT	\N	PRESENT	0
499367	497846	19820Y	PARTICIPANT	\N	PRESENT	0
499540	497179	20122U	PARTICIPANT	\N	PRESENT	0
499541	497179	17589D	PARTICIPANT	\N	PRESENT	0
499370	497846	14237S	PARTICIPANT	\N	PRESENT	0
499371	497846	19701S	PARTICIPANT	\N	PRESENT	0
499542	497179	19563B	PARTICIPANT	\N	PRESENT	0
499543	497179	19637C	PARTICIPANT	\N	PRESENT	0
499544	497179	04057K	PARTICIPANT	\N	PRESENT	0
499545	497179	19441R	PARTICIPANT	\N	PRESENT	0
499546	497179	19367Y	PARTICIPANT	\N	PRESENT	0
499547	497179	20124W	PARTICIPANT	\N	PRESENT	0
499548	497179	14059S	PARTICIPANT	\N	PRESENT	0
499379	497672	01028R	PARTICIPANT	\N	PRESENT	0
499380	497672	08018U	PARTICIPANT	\N	PRESENT	0
499549	497179	11097X	PARTICIPANT	\N	PRESENT	0
499383	497846	19503N	PARTICIPANT	\N	PRESENT	0
499384	497846	19739H	PARTICIPANT	\N	PRESENT	0
499385	497846	19745F	PARTICIPANT	\N	PRESENT	0
499386	497846	19551W	PARTICIPANT	\N	EXCUSE	0
499387	497846	20046A	PARTICIPANT	\N	EXCUSE	0
499388	497846	19681G	PARTICIPANT	\N	EXCUSE	0
499550	497179	10006L	PARTICIPANT	\N	PRESENT	0
499551	497179	14071N	PARTICIPANT	\N	PRESENT	0
499552	497179	01025N	PARTICIPANT	\N	PRESENT	0
499553	497179	14147R	PARTICIPANT	\N	PRESENT	0
499554	497179	14215L	PARTICIPANT	\N	PRESENT	0
499394	496310	20050V	PARTICIPANT	\N	PRESENT	0
499555	497179	14223L	PARTICIPANT	\N	PRESENT	0
499556	497179	20068G	PARTICIPANT	\N	PRESENT	0
499557	497179	20026V	PARTICIPANT	\N	PRESENT	0
499558	497179	19507S	PARTICIPANT	\N	PRESENT	0
499399	497846	19333N	PARTICIPANT	\N	PRESENT	0
499400	497846	19549D	PARTICIPANT	\N	PRESENT	0
499401	497846	19251M	PARTICIPANT	\N	PRESENT	0
499402	497846	14169X	PARTICIPANT	\N	PRESENT	0
499403	497846	11101A	PARTICIPANT	\N	PRESENT	0
499404	497846	20024T	PARTICIPANT	\N	PRESENT	0
499405	497846	11065P	PARTICIPANT	\N	PRESENT	0
499559	497179	07029T	PARTICIPANT	\N	PRESENT	0
499574	497179	20132W	PARTICIPANT	\N	PRESENT	0
499418	497846	20076G	PARTICIPANT	\N	PRESENT	0
499419	497846	19387D	PARTICIPANT	\N	PRESENT	0
499433	497672	14089Y	PARTICIPANT	\N	PRESENT	0
499434	497672	95063L	PARTICIPANT	\N	PRESENT	0
499435	497672	20114U	PARTICIPANT	\N	PRESENT	0
499561	497179	11056N	PARTICIPANT	\N	PRESENT	0
499562	497179	19695N	PARTICIPANT	\N	PRESENT	0
499563	497179	11012A	PARTICIPANT	\N	PRESENT	0
499564	497179	14207L	PARTICIPANT	\N	PRESENT	0
499565	497179	19679N	PARTICIPANT	\N	PRESENT	0
499566	497179	19399H	PARTICIPANT	\N	PRESENT	0
499567	497179	14357A	PARTICIPANT	\N	PRESENT	0
499568	497179	19713W	PARTICIPANT	\N	PRESENT	0
499569	497179	19543W	PARTICIPANT	\N	PRESENT	0
499570	497179	20134Y	PARTICIPANT	\N	PRESENT	0
499571	497846	20020P	PARTICIPANT	\N	PRESENT	0
499572	497179	20118Y	PARTICIPANT	\N	PRESENT	0
499573	497179	14327T	PARTICIPANT	\N	PRESENT	0
499575	497179	19760E	PARTICIPANT	\N	PRESENT	0
499576	497179	08061X	PARTICIPANT	\N	PRESENT	0
499577	497179	14030Q	PARTICIPANT	\N	PRESENT	0
499469	498010	19333N	PARTICIPANT	\N	PRESENT	0
499470	498010	19768N	PARTICIPANT	\N	PRESENT	0
499471	498010	19515S	PARTICIPANT	\N	PRESENT	0
499472	498010	19701S	PARTICIPANT	\N	PRESENT	0
499473	498010	19782L	PARTICIPANT	\N	PRESENT	0
499474	498010	19549D	PARTICIPANT	\N	PRESENT	0
499475	498010	20076G	PARTICIPANT	\N	PRESENT	0
499476	498010	19387D	PARTICIPANT	\N	PRESENT	0
499477	498010	19413M	PARTICIPANT	\N	PRESENT	0
499478	498010	14219Q	PARTICIPANT	\N	PRESENT	0
499479	498010	19820Y	PARTICIPANT	\N	PRESENT	0
499480	498010	20082E	PARTICIPANT	\N	PRESENT	0
499481	498010	20094J	PARTICIPANT	\N	PRESENT	0
499482	498010	20104S	PARTICIPANT	\N	PRESENT	0
499483	498010	19631V	PARTICIPANT	\N	PRESENT	0
499484	498010	18083K	PARTICIPANT	\N	PRESENT	0
499485	498010	14237S	PARTICIPANT	\N	PRESENT	0
499486	498010	05012A	PARTICIPANT	\N	PRESENT	0
499487	498010	08015R	PARTICIPANT	\N	PRESENT	0
499488	498010	19503N	PARTICIPANT	\N	PRESENT	0
499489	498010	19575F	PARTICIPANT	\N	PRESENT	0
499490	498010	20018V	PARTICIPANT	\N	PRESENT	0
499491	498010	20022R	PARTICIPANT	\N	PRESENT	0
499492	498010	20024T	PARTICIPANT	\N	PRESENT	0
499493	498010	11065P	PARTICIPANT	\N	PRESENT	0
499494	498010	19521Q	PARTICIPANT	\N	PRESENT	0
499495	498010	14329V	PARTICIPANT	\N	PRESENT	0
499496	498010	14038Y	PARTICIPANT	\N	PRESENT	0
499497	498010	19467C	PARTICIPANT	\N	PRESENT	0
499498	498010	20032T	PARTICIPANT	\N	PRESENT	0
499499	498010	14031R	PARTICIPANT	\N	PRESENT	0
499500	498010	20038A	PARTICIPANT	\N	PRESENT	0
499501	498010	20144B	PARTICIPANT	\N	PRESENT	0
499502	498010	19695N	PARTICIPANT	\N	PRESENT	0
499503	498010	19251M	PARTICIPANT	\N	PRESENT	0
499504	498010	11090Q	PRESIDENT	0	PRESENT	0
499505	498010	14033T	PRESIDENT	1	PRESENT	0
499506	498010	01025N	PARTICIPANT	\N	PRESENT	0
499507	498010	20054A	PARTICIPANT	\N	PRESENT	0
499508	498010	14169X	PARTICIPANT	\N	PRESENT	0
499509	498010	20174H	PARTICIPANT	\N	PRESENT	0
499510	498010	14205J	PARTICIPANT	\N	PRESENT	0
499511	498010	20062A	PARTICIPANT	\N	PRESENT	0
499512	498010	19739H	PARTICIPANT	\N	PRESENT	0
499513	498010	19745F	PARTICIPANT	\N	PRESENT	0
499514	498010	19747H	PARTICIPANT	\N	PRESENT	0
499515	498010	08028W	PARTICIPANT	\N	EXCUSE	0
499578	497179	19573D	PARTICIPANT	\N	PRESENT	0
499579	498010	20020P	PARTICIPANT	\N	PRESENT	0
499580	497179	20082E	PARTICIPANT	\N	PRESENT	0
499603	497179	19531S	PARTICIPANT	\N	PRESENT	0
499610	497179	19689Q	PARTICIPANT	\N	PRESENT	0
499624	497179	11045K	PARTICIPANT	\N	PRESENT	0
499625	497179	18083K	PARTICIPANT	\N	PRESENT	0
499626	497179	11067R	PARTICIPANT	\N	PRESENT	0
499627	497179	01028R	PARTICIPANT	\N	PRESENT	0
499629	497179	11085T	PARTICIPANT	\N	PRESENT	0
499527	497179	01043Q	PARTICIPANT	\N	PRESENT	0
499528	497179	11090Q	PARTICIPANT	\N	PRESENT	0
499631	497179	20076G	PARTICIPANT	\N	PRESENT	0
499634	497179	11043H	PARTICIPANT	\N	PRESENT	0
499635	497179	14069U	PARTICIPANT	\N	PRESENT	0
499636	497179	20022R	PARTICIPANT	\N	PRESENT	0
499637	497179	05012A	PARTICIPANT	\N	PRESENT	0
499639	497179	14033T	PARTICIPANT	\N	PRESENT	0
499645	497179	14042U	PARTICIPANT	\N	PRESENT	0
499649	497179	20044X	PARTICIPANT	\N	PRESENT	0
499650	497179	19631V	PARTICIPANT	\N	PRESENT	0
499651	497179	20038A	PARTICIPANT	\N	PRESENT	0
499652	497179	20054A	PARTICIPANT	\N	PRESENT	0
499653	497179	20052X	PARTICIPANT	\N	PRESENT	0
499654	497179	19739H	PARTICIPANT	\N	PRESENT	0
487759	479250	04059M	PARTICIPANT	\N	PRESENT	0
487760	479250	08011M	PARTICIPANT	\N	PRESENT	0
487761	479250	19687N	PARTICIPANT	\N	PRESENT	0
487762	479250	08052W	PARTICIPANT	\N	PRESENT	0
487763	479250	11074Q	PARTICIPANT	\N	PRESENT	0
487764	479250	19651A	PARTICIPANT	\N	PRESENT	0
487765	479250	11012A	PARTICIPANT	\N	PRESENT	0
487766	479250	17589D	PARTICIPANT	\N	PRESENT	0
487767	479250	19553Y	PARTICIPANT	\N	PRESENT	0
487768	479250	14121F	PARTICIPANT	\N	PRESENT	0
487769	479250	14042U	PARTICIPANT	\N	PRESENT	0
487770	479250	11053K	PARTICIPANT	\N	PRESENT	0
487771	479250	14069U	PARTICIPANT	\N	PRESENT	0
487772	479250	01058X	PARTICIPANT	\N	PRESENT	0
487773	479250	97011G	PARTICIPANT	\N	PRESENT	0
487774	479250	11103C	PARTICIPANT	\N	PRESENT	0
487776	479250	19467C	PARTICIPANT	\N	PRESENT	0
487777	479250	19794Q	PARTICIPANT	\N	PRESENT	0
487778	479250	01057W	PARTICIPANT	\N	PRESENT	0
487779	479250	19711U	PARTICIPANT	\N	PRESENT	0
487780	479250	04086Q	PARTICIPANT	\N	PRESENT	0
487781	479250	19760E	PARTICIPANT	\N	PRESENT	0
487782	479250	19441R	PARTICIPANT	\N	PRESENT	0
487783	479250	07029T	PARTICIPANT	\N	PRESENT	0
487784	479250	19657G	PARTICIPANT	\N	PRESENT	0
487785	479250	07004J	PARTICIPANT	\N	PRESENT	0
487786	479250	19679N	PARTICIPANT	\N	PRESENT	0
487787	479250	11027H	PARTICIPANT	\N	PRESENT	0
487788	479250	04071H	PARTICIPANT	\N	PRESENT	0
487789	479250	14197C	PARTICIPANT	\N	PRESENT	0
487790	479250	14085U	PARTICIPANT	\N	PRESENT	0
487792	479250	19531S	PARTICIPANT	\N	PRESENT	0
487824	479247	17589D	PARTICIPANT	\N	PRESENT	0
487825	479247	19553Y	PARTICIPANT	\N	PRESENT	0
487826	479247	14121F	PARTICIPANT	\N	PRESENT	0
487827	479247	19697Q	PARTICIPANT	\N	PRESENT	0
487828	479247	19651A	PARTICIPANT	\N	PRESENT	0
487829	479247	08052W	PARTICIPANT	\N	PRESENT	0
487830	479247	19565D	PARTICIPANT	\N	PRESENT	0
487831	479247	19657G	PARTICIPANT	\N	PRESENT	0
487832	479247	07029T	PARTICIPANT	\N	PRESENT	0
487833	479247	97011G	PARTICIPANT	\N	PRESENT	0
487834	479247	11012A	PARTICIPANT	\N	PRESENT	0
487835	479247	19760E	PARTICIPANT	\N	PRESENT	0
487836	479247	01024M	PARTICIPANT	\N	PRESENT	0
487837	479247	19683J	PARTICIPANT	\N	PRESENT	0
487838	479247	14042U	PARTICIPANT	\N	PRESENT	0
487839	479247	11103C	PARTICIPANT	\N	PRESENT	0
487840	479247	19521Q	PARTICIPANT	\N	PRESENT	0
487841	479247	10006L	PARTICIPANT	\N	PRESENT	0
487842	479247	04059M	PARTICIPANT	\N	PRESENT	0
487843	479247	19467C	PARTICIPANT	\N	PRESENT	0
487844	479247	11067R	PARTICIPANT	\N	PRESENT	0
487853	479247	19715Y	PARTICIPANT	\N	PRESENT	0
487854	479247	01034P	PARTICIPANT	\N	PRESENT	0
487855	479247	14261S	PARTICIPANT	\N	PRESENT	0
487856	479247	19301E	PARTICIPANT	\N	PRESENT	0
487857	479247	19563B	PARTICIPANT	\N	PRESENT	0
487886	479251	01024M	PARTICIPANT	\N	PRESENT	0
487822	479247	19679N	PARTICIPANT	\N	PRESENT	0
487823	479247	11027H	PARTICIPANT	\N	PRESENT	0
487887	479251	14042U	PARTICIPANT	\N	PRESENT	0
488153	488152	05008E	PARTICIPANT	\N	PRESENT	0
488154	488152	19673G	PARTICIPANT	\N	PRESENT	0
488155	488152	14041T	PARTICIPANT	\N	PRESENT	0
488156	488152	19649G	PARTICIPANT	\N	PRESENT	0
488157	488152	11026G	PARTICIPANT	\N	PRESENT	0
488158	488152	19543W	PARTICIPANT	\N	PRESENT	0
488159	488152	04044E	PARTICIPANT	\N	PRESENT	0
488160	488152	01024M	PARTICIPANT	\N	PRESENT	0
488163	486066	19717B	PARTICIPANT	\N	PRESENT	0
488164	486066	19577H	PARTICIPANT	\N	PRESENT	0
488165	486066	19631V	PARTICIPANT	\N	PRESENT	0
488166	486066	19715Y	PARTICIPANT	\N	PRESENT	0
488167	486066	14039A	PARTICIPANT	\N	PRESENT	0
488168	486066	08019V	PARTICIPANT	\N	PRESENT	0
488169	486066	19657G	PARTICIPANT	\N	PRESENT	0
488170	486066	08073C	PARTICIPANT	\N	PRESENT	0
488171	486066	19301E	PARTICIPANT	\N	PRESENT	0
489387	489035	11067R	PARTICIPANT	\N	EXCUSE	0
489388	489035	19663E	PARTICIPANT	\N	EXCUSE	0
489389	489035	11012A	PARTICIPANT	\N	PRESENT	0
489390	489035	04092N	PARTICIPANT	\N	EXCUSE	0
489391	489035	04059M	PARTICIPANT	\N	PRESENT	0
489392	489035	19479G	PARTICIPANT	\N	PRESENT	0
489393	489035	11097X	PRESIDENT	0	PRESENT	0
487884	479251	04059M	PARTICIPANT	\N	PRESENT	0
487885	479251	01034P	PARTICIPANT	\N	PRESENT	0
489394	489035	19503N	PARTICIPANT	\N	PRESENT	0
489395	489035	19703U	PARTICIPANT	\N	PRESENT	0
489396	489035	14331P	PARTICIPANT	\N	PRESENT	0
489397	489035	19643A	PARTICIPANT	\N	PRESENT	0
489398	489035	11031D	PARTICIPANT	\N	PRESENT	0
489399	489035	10006L	PARTICIPANT	\N	PRESENT	0
489400	489035	14041T	PARTICIPANT	\N	PRESENT	0
489401	489035	19649G	PARTICIPANT	\N	PRESENT	0
489402	489035	14081Q	PARTICIPANT	\N	PRESENT	0
489403	489035	11048N	PARTICIPANT	\N	PRESENT	0
489404	489035	19715Y	PARTICIPANT	\N	PRESENT	0
489405	489035	19683J	PARTICIPANT	\N	PRESENT	0
489406	489035	99004R	PARTICIPANT	\N	PRESENT	0
489407	489035	19697Q	PARTICIPANT	\N	PRESENT	0
489409	489036	11031D	PARTICIPANT	\N	PRESENT	0
489410	489036	10006L	PARTICIPANT	\N	PRESENT	0
489411	489036	14041T	PARTICIPANT	\N	PRESENT	0
489412	489036	19649G	PARTICIPANT	\N	PRESENT	0
489413	489036	19643A	PARTICIPANT	\N	PRESENT	0
489414	489036	19569H	PARTICIPANT	\N	PRESENT	0
489415	489036	11048N	PARTICIPANT	\N	PRESENT	0
489416	489036	19715Y	PARTICIPANT	\N	PRESENT	0
489417	489036	19683J	PARTICIPANT	\N	PRESENT	0
489418	489036	99004R	PARTICIPANT	\N	PRESENT	0
489419	489036	19697Q	PARTICIPANT	\N	PRESENT	0
489420	489036	19503N	PARTICIPANT	\N	PRESENT	0
489421	489036	14331P	PARTICIPANT	\N	PRESENT	0
489422	489036	19703U	PARTICIPANT	\N	PRESENT	0
489423	489036	11097X	PRESIDENT	0	PRESENT	0
489424	489036	19479G	PARTICIPANT	\N	PRESENT	0
489425	489036	04092N	PARTICIPANT	\N	EXCUSE	0
489426	489036	11067R	PARTICIPANT	\N	EXCUSE	0
489427	489036	11012A	PARTICIPANT	\N	PRESENT	0
489428	489036	19663E	PARTICIPANT	\N	EXCUSE	0
489429	489036	04059M	PARTICIPANT	\N	PRESENT	0
489430	489036	19766L	PARTICIPANT	\N	EXCUSE	0
489431	489035	19766L	PARTICIPANT	\N	EXCUSE	0
490870	490467	19697Q	PARTICIPANT	\N	PRESENT	0
490871	490467	20090E	PARTICIPANT	\N	PRESENT	0
490872	490467	14355X	PARTICIPANT	\N	PRESENT	0
490873	490467	19569H	PARTICIPANT	\N	PRESENT	0
490874	490467	19415P	PARTICIPANT	\N	PRESENT	0
490875	490467	18193Q	PARTICIPANT	\N	PRESENT	0
490876	490467	14223L	PARTICIPANT	\N	PRESENT	0
490877	490467	14026U	PARTICIPANT	\N	PRESENT	0
490878	490467	17779H	PARTICIPANT	\N	PRESENT	0
490879	490467	11031D	PARTICIPANT	\N	PRESENT	0
490880	490467	19703U	PARTICIPANT	\N	PRESENT	0
490881	490467	14281W	PARTICIPANT	\N	PRESENT	0
490882	490467	19367Y	PARTICIPANT	\N	PRESENT	0
490883	490467	14213J	PARTICIPANT	\N	PRESENT	0
490884	490467	14217N	PARTICIPANT	\N	PRESENT	0
490885	490467	19591F	PARTICIPANT	\N	PRESENT	0
490886	490467	20130U	PARTICIPANT	\N	PRESENT	0
490887	490467	01034P	PRESIDENT	0	PRESENT	0
490888	490467	19713W	PARTICIPANT	\N	PRESENT	0
490889	490467	08045X	PARTICIPANT	\N	PRESENT	0
490890	490467	11045K	PARTICIPANT	\N	PRESENT	0
490891	490467	17965H	PARTICIPANT	\N	PRESENT	0
490892	490467	19301E	PARTICIPANT	\N	PRESENT	0
490893	490467	19715Y	PARTICIPANT	\N	PRESENT	0
490894	490467	20148F	PARTICIPANT	\N	PRESENT	0
490895	490467	19717B	PARTICIPANT	\N	PRESENT	0
490896	490467	19723Y	PARTICIPANT	\N	PRESENT	0
490897	490467	11103C	PARTICIPANT	\N	PRESENT	0
490898	490467	19657G	PARTICIPANT	\N	PRESENT	0
490899	490467	04043D	PARTICIPANT	\N	PRESENT	0
490900	490467	19760E	PARTICIPANT	\N	PRESENT	0
490901	490467	14195A	PARTICIPANT	\N	EXCUSE	0
490902	490707	17583W	PARTICIPANT	\N	PRESENT	0
490903	490707	11067R	PARTICIPANT	\N	PRESENT	0
490904	490707	19798U	PARTICIPANT	\N	PRESENT	0
490905	490707	11097X	PARTICIPANT	\N	PRESENT	0
490906	490707	19553Y	PARTICIPANT	\N	PRESENT	0
490907	490707	19966S	PARTICIPANT	\N	PRESENT	0
490908	490707	19679N	PARTICIPANT	\N	PRESENT	0
490909	490707	14042U	PARTICIPANT	\N	PRESENT	0
490910	490707	10006L	PRESIDENT	0	PRESENT	0
490911	490707	19683J	PARTICIPANT	\N	PRESENT	0
490912	490707	04057K	PARTICIPANT	\N	PRESENT	0
490913	490707	04092N	PARTICIPANT	0	PRESENT	0
504683	502449	19667J	PARTICIPANT	\N	PRESENT	0
504694	504467	04070G	PARTICIPANT	\N	PRESENT	0
504695	504467	19699S	PARTICIPANT	\N	PRESENT	0
504696	504467	19533U	PARTICIPANT	\N	PRESENT	0
504697	504467	04033B	PARTICIPANT	\N	PRESENT	0
504698	504467	19329S	PARTICIPANT	\N	PRESENT	1
504699	504467	14229S	PARTICIPANT	\N	PRESENT	0
504700	504467	20098N	PARTICIPANT	\N	PRESENT	0
504701	504467	19573D	PARTICIPANT	\N	PRESENT	0
504702	504467	08017T	PARTICIPANT	\N	PRESENT	1
504703	504467	92040Q	PARTICIPANT	\N	PRESENT	0
504704	504467	20112S	PARTICIPANT	\N	PRESENT	0
504705	504467	08061X	PARTICIPANT	\N	PRESENT	0
504706	504467	20124W	PARTICIPANT	\N	PRESENT	0
504707	504467	20026V	PARTICIPANT	\N	PRESENT	0
504708	504467	20120S	PARTICIPANT	\N	PRESENT	0
504709	504467	19527W	PARTICIPANT	\N	PRESENT	1
504710	504467	19593H	PARTICIPANT	\N	PRESENT	0
504711	504467	19643A	PARTICIPANT	\N	PRESENT	0
504712	504467	20132W	PARTICIPANT	\N	PRESENT	0
504713	504467	14073Q	PARTICIPANT	\N	PRESENT	0
504714	504467	19651A	PARTICIPANT	\N	PRESENT	1
504715	504467	19611R	PRESIDENT	0	PRESENT	0
504716	504467	20142Y	PARTICIPANT	\N	PRESENT	1
504717	504467	20048C	PARTICIPANT	\N	PRESENT	0
504718	504467	19693L	PARTICIPANT	\N	PRESENT	0
504719	504467	19399H	PARTICIPANT	\N	PRESENT	0
504720	504467	20152B	PARTICIPANT	\N	PRESENT	0
504721	504467	20052X	PARTICIPANT	\N	PRESENT	0
504722	504467	20058E	PARTICIPANT	\N	PRESENT	0
504723	504467	14030Q	PARTICIPANT	\N	PRESENT	0
504724	504467	20056C	PARTICIPANT	\N	PRESENT	0
504725	504467	04059M	PARTICIPANT	\N	PRESENT	0
504726	504467	19735D	PARTICIPANT	\N	PRESENT	0
504735	502449	11040E	PARTICIPANT	\N	PRESENT	1
504728	504467	14109K	PARTICIPANT	\N	PRESENT	0
504729	504467	11043H	PARTICIPANT	\N	PRESENT	0
504730	504467	11104D	PARTICIPANT	\N	PRESENT	0
504731	504467	19758L	PARTICIPANT	\N	PRESENT	0
504732	504467	19621T	PARTICIPANT	\N	PRESENT	0
504733	504467	20084G	PARTICIPANT	\N	PRESENT	0
504734	502289	08018U	PARTICIPANT	\N	PRESENT	0
504736	502449	19545Y	PARTICIPANT	\N	PRESENT	1
504737	502449	11110B	PARTICIPANT	\N	PRESENT	1
504738	502449	14121F	PARTICIPANT	\N	PRESENT	1
504739	502449	19531S	PARTICIPANT	\N	PRESENT	1
504740	502449	01048V	PARTICIPANT	\N	PRESENT	1
504741	502449	08011M	PARTICIPANT	\N	PRESENT	1
504742	502449	19479G	PARTICIPANT	\N	PRESENT	1
504744	504743	19533U	PARTICIPANT	\N	PRESENT	0
504746	504745	19533U	PARTICIPANT	\N	PRESENT	0
504748	504747	19533U	PARTICIPANT	\N	PRESENT	0
504751	504750	19533U	PARTICIPANT	\N	PRESENT	0
504753	504752	19533U	PARTICIPANT	\N	PRESENT	1
504755	504754	19533U	PARTICIPANT	\N	PRESENT	1
504756	504754	19593H	PARTICIPANT	\N	PRESENT	1
504757	504754	20052X	PARTICIPANT	\N	PRESENT	1
504758	504754	14229S	PARTICIPANT	\N	PRESENT	1
504760	504759	19533U	PARTICIPANT	\N	PRESENT	1
504761	504759	20052X	PARTICIPANT	\N	PRESENT	1
504762	504759	19593H	PARTICIPANT	\N	PRESENT	1
504764	504763	14073Q	PARTICIPANT	\N	PRESENT	1
504765	504763	08017T	PARTICIPANT	\N	PRESENT	1
504766	504763	04070G	PARTICIPANT	\N	PRESENT	1
504767	504763	20142Y	PARTICIPANT	\N	PRESENT	1
504769	504768	14073Q	PARTICIPANT	\N	PRESENT	1
504770	504768	08017T	PARTICIPANT	\N	PRESENT	1
504771	504768	04070G	PARTICIPANT	\N	PRESENT	1
504773	504772	14073Q	PARTICIPANT	\N	PRESENT	1
504775	504774	19693L	PARTICIPANT	\N	PRESENT	1
504776	504774	19533U	PARTICIPANT	\N	PRESENT	1
504777	504774	19593H	PARTICIPANT	\N	PRESENT	1
504779	504778	19693L	PARTICIPANT	\N	PRESENT	1
504780	504778	19593H	PARTICIPANT	\N	PRESENT	1
504781	504778	19533U	PARTICIPANT	\N	PRESENT	1
504782	504778	19651A	PARTICIPANT	\N	PRESENT	1
504784	504783	19693L	PARTICIPANT	\N	PRESENT	1
504785	504783	19651A	PARTICIPANT	\N	PRESENT	1
504786	504783	19593H	PARTICIPANT	\N	PRESENT	1
504788	504787	19693L	PARTICIPANT	\N	PRESENT	1
504790	504789	19693L	PARTICIPANT	\N	PRESENT	1
504791	504789	19533U	PARTICIPANT	\N	PRESENT	1
504792	504789	19593H	PARTICIPANT	\N	PRESENT	1
504793	504789	14229S	PARTICIPANT	\N	PRESENT	1
504795	504794	19693L	PARTICIPANT	\N	PRESENT	1
504796	504794	19593H	PARTICIPANT	\N	PRESENT	1
504797	504794	19533U	PARTICIPANT	\N	PRESENT	1
504867	503845	19335Q	PARTICIPANT	\N	PRESENT	0
504841	503845	20104S	PARTICIPANT	\N	PRESENT	0
504842	503845	20100N	PARTICIPANT	\N	PRESENT	0
504843	503845	11083R	PARTICIPANT	\N	PRESENT	0
504844	503845	20128B	PARTICIPANT	\N	PRESENT	1
504845	503845	14073Q	PARTICIPANT	\N	PRESENT	0
504846	503845	14001X	PARTICIPANT	\N	PRESENT	0
504847	503845	14331P	PARTICIPANT	\N	PRESENT	0
504848	503845	14097Y	PARTICIPANT	\N	PRESENT	0
504849	503845	19521Q	PARTICIPANT	\N	PRESENT	0
504850	503845	19725B	PARTICIPANT	\N	PRESENT	0
504851	503845	19441R	PARTICIPANT	\N	PRESENT	1
504852	503845	04034C	PARTICIPANT	\N	PRESENT	1
504853	503845	04070G	PARTICIPANT	\N	PRESENT	1
504854	503845	11026G	PARTICIPANT	\N	PRESENT	0
504855	503845	08034U	PARTICIPANT	\N	PRESENT	0
504856	503845	14221J	PARTICIPANT	\N	PRESENT	0
504857	503845	96004D	PARTICIPANT	\N	PRESENT	0
504858	503845	14207L	PARTICIPANT	\N	PRESENT	0
504863	503845	04057K	PARTICIPANT	\N	PRESENT	0
504860	503845	19701S	PARTICIPANT	\N	PRESENT	0
504861	503845	19251M	PARTICIPANT	\N	PRESENT	0
504862	503845	12016W	PARTICIPANT	\N	PRESENT	0
504864	501820	86034E	PARTICIPANT	\N	PRESENT	0
504865	503845	14133K	PARTICIPANT	\N	PRESENT	0
504866	501820	19511N	PARTICIPANT	\N	PRESENT	0
504868	501820	19866P	PARTICIPANT	\N	PRESENT	0
504869	501820	18193Q	PARTICIPANT	\N	PRESENT	0
504870	501820	12028B	PARTICIPANT	\N	PRESENT	0
504871	501820	20028X	PARTICIPANT	\N	PRESENT	0
504872	501820	19525U	PARTICIPANT	\N	PRESENT	0
504873	501820	11041F	PARTICIPANT	\N	PRESENT	0
504874	501820	20032T	PARTICIPANT	\N	PRESENT	0
504876	501820	07029T	PARTICIPANT	\N	PRESENT	0
505238	501911	10006L	PRESIDENT	0	PRESENT	0
505254	501911	14223L	PARTICIPANT	\N	PRESENT	0
505363	504955	11080N	PARTICIPANT	\N	PRESENT	0
505257	501911	17779H	PARTICIPANT	\N	PRESENT	0
505258	501911	19723Y	PARTICIPANT	\N	PRESENT	0
505259	501911	19657G	PARTICIPANT	\N	PRESENT	0
505261	501911	04057K	PARTICIPANT	\N	PRESENT	0
505262	501911	14213J	PARTICIPANT	\N	PRESENT	0
505263	501911	19691J	PARTICIPANT	\N	PRESENT	0
505265	501911	14195A	PARTICIPANT	\N	PRESENT	0
505266	501911	14026U	PARTICIPANT	\N	PRESENT	0
505268	501911	11097X	PARTICIPANT	\N	PRESENT	0
505270	501911	19798U	PARTICIPANT	\N	PRESENT	0
505271	501911	19679N	PARTICIPANT	\N	PRESENT	0
505272	501911	14071N	PARTICIPANT	\N	PRESENT	0
505313	501911	19569H	PRESIDENT	1	PRESENT	0
505275	501911	18193Q	PARTICIPANT	\N	PRESENT	0
505277	501911	19697Q	PARTICIPANT	\N	PRESENT	1
505278	501911	17965H	PARTICIPANT	\N	PRESENT	0
505279	501911	14042U	PARTICIPANT	\N	PRESENT	0
505280	501911	19591F	PARTICIPANT	\N	PRESENT	0
505281	501911	14281W	PARTICIPANT	\N	PRESENT	1
505305	501911	19715Y	PARTICIPANT	\N	PRESENT	0
505307	501911	20040T	PARTICIPANT	\N	PRESENT	0
505309	501911	11031D	PARTICIPANT	\N	PRESENT	0
505311	501911	20066E	PARTICIPANT	\N	PRESENT	1
505312	501911	19703U	PARTICIPANT	\N	PRESENT	0
505315	501911	20130U	PARTICIPANT	\N	PRESENT	1
505359	501779	19866P	PARTICIPANT	\N	PRESENT	0
505373	502291	19503N	PARTICIPANT	\N	PRESENT	0
505376	502291	01058X	PARTICIPANT	\N	PRESENT	0
505377	502291	19533U	PARTICIPANT	\N	PRESENT	0
505378	502291	18003S	PARTICIPANT	\N	PRESENT	0
483185	480876	19667J	PARTICIPANT	\N	PRESENT	0
483186	480876	19820Y	PARTICIPANT	\N	PRESENT	0
483187	480876	11056N	PARTICIPANT	\N	PRESENT	0
483188	480876	19387D	PARTICIPANT	\N	PRESENT	0
483189	480876	04045F	PARTICIPANT	\N	PRESENT	0
483203	483202	11070L	PARTICIPANT	\N	PRESENT	0
483210	483202	14121F	PRESIDENT	0	PRESENT	0
483214	483202	19711U	PARTICIPANT	\N	PRESENT	0
483215	483202	02002K	PARTICIPANT	\N	PRESENT	0
483217	483202	19551W	PARTICIPANT	\N	PRESENT	0
483236	483202	11040E	PARTICIPANT	\N	PRESENT	0
484554	483191	14299H	PARTICIPANT	\N	EXCUSE	0
484560	481565	19387D	PARTICIPANT	\N	PRESENT	0
484561	481565	19798U	PARTICIPANT	\N	PRESENT	0
484562	481565	19631V	PARTICIPANT	\N	PRESENT	0
484563	481565	19515S	PARTICIPANT	\N	PRESENT	0
484565	481565	19689Q	PARTICIPANT	\N	PRESENT	0
484568	484567	19705W	PARTICIPANT	\N	PRESENT	0
484569	484567	19631V	PARTICIPANT	\N	PRESENT	0
484571	484570	19705W	PARTICIPANT	\N	PRESENT	0
484572	484570	19631V	PARTICIPANT	\N	PRESENT	0
485125	484689	04085P	PARTICIPANT	\N	PRESENT	0
485126	484689	04059M	PARTICIPANT	\N	PRESENT	0
485127	484689	19667J	PARTICIPANT	\N	PRESENT	0
485128	484689	19643A	PARTICIPANT	\N	PRESENT	0
485129	484689	11031D	PARTICIPANT	\N	PRESENT	0
485130	484689	19663E	PARTICIPANT	\N	PRESENT	0
485131	484689	10006L	PARTICIPANT	\N	PRESENT	0
485132	484689	19649G	PARTICIPANT	\N	PRESENT	0
485133	484689	19691J	PARTICIPANT	\N	PRESENT	0
485134	484689	14081Q	PARTICIPANT	\N	PRESENT	0
485135	484689	19553Y	PARTICIPANT	\N	PRESENT	0
485136	484689	11048N	PARTICIPANT	\N	PRESENT	0
485137	484689	19715Y	PARTICIPANT	\N	PRESENT	0
485138	484689	19683J	PARTICIPANT	\N	PRESENT	0
485139	484689	19447X	PARTICIPANT	\N	PRESENT	0
485140	484689	99004R	PARTICIPANT	\N	PRESENT	0
485141	484689	19697Q	PARTICIPANT	\N	PRESENT	0
485142	484689	11067R	PARTICIPANT	\N	PRESENT	0
485143	484689	04092N	PRESIDENT	0	PRESENT	0
485144	484689	19503N	PARTICIPANT	\N	PRESENT	0
485145	484689	14331P	PARTICIPANT	\N	PRESENT	0
485146	484689	19766L	PARTICIPANT	\N	PRESENT	0
485147	484689	11012A	PARTICIPANT	\N	PRESENT	0
485148	484689	11097X	PARTICIPANT	\N	PRESENT	0
485149	484689	19703U	PARTICIPANT	\N	PRESENT	0
485150	484689	19479G	PARTICIPANT	\N	PRESENT	0
486660	486659	19531S	PARTICIPANT	\N	PRESENT	0
488018	484589	19673G	PARTICIPANT	\N	PRESENT	0
488019	484589	11026G	PARTICIPANT	\N	PRESENT	0
488020	484589	14121F	PARTICIPANT	\N	PRESENT	0
488021	484589	04057K	PARTICIPANT	\N	PRESENT	0
488022	484589	04085P	PARTICIPANT	\N	PRESENT	0
488016	484589	04044E	PARTICIPANT	\N	PRESENT	0
488017	484589	05008E	PARTICIPANT	\N	PRESENT	0
488023	484589	19695N	PARTICIPANT	\N	PRESENT	0
488024	484589	07004J	PARTICIPANT	\N	PRESENT	0
488025	484589	19467C	PARTICIPANT	\N	PRESENT	0
488026	484589	01024M	PARTICIPANT	\N	PRESENT	0
488027	484589	97011G	PARTICIPANT	\N	PRESENT	0
488028	484589	19543W	PARTICIPANT	\N	PRESENT	0
488029	484589	01028R	PARTICIPANT	\N	PRESENT	0
488030	484589	18083K	PARTICIPANT	\N	PRESENT	0
488031	484589	19657G	PARTICIPANT	\N	PRESENT	0
488032	484589	14034U	PARTICIPANT	\N	PRESENT	0
488038	484589	14041T	PARTICIPANT	\N	PRESENT	0
488039	484589	11012A	PARTICIPANT	\N	PRESENT	0
488040	484589	07029T	PARTICIPANT	\N	PRESENT	0
488074	479252	99004R	PARTICIPANT	\N	PRESENT	0
488075	479252	19687N	PARTICIPANT	\N	PRESENT	0
488076	479252	07029T	PARTICIPANT	\N	PRESENT	0
488077	479252	19349W	PARTICIPANT	\N	PRESENT	0
488081	479252	08052W	PARTICIPANT	\N	PRESENT	0
488079	479252	11040E	PARTICIPANT	\N	PRESENT	0
488080	479252	19531S	PARTICIPANT	\N	PRESENT	0
488082	479252	19794Q	PARTICIPANT	\N	PRESENT	0
488083	479252	19651A	PARTICIPANT	\N	PRESENT	0
488084	479252	11074Q	PARTICIPANT	\N	PRESENT	0
488085	479252	08011M	PARTICIPANT	\N	PRESENT	0
488086	479252	04057K	PARTICIPANT	\N	PRESENT	0
488087	479252	11053K	PARTICIPANT	\N	PRESENT	0
488088	479252	04018C	PARTICIPANT	\N	PRESENT	0
488089	479252	19926J	PARTICIPANT	\N	PRESENT	0
488090	479252	11012A	PARTICIPANT	\N	PRESENT	0
488091	479252	19573D	PARTICIPANT	\N	PRESENT	0
488092	479252	97011G	PARTICIPANT	\N	PRESENT	0
488093	479252	07004J	PARTICIPANT	\N	PRESENT	0
488065	479252	04086Q	PARTICIPANT	\N	PRESENT	0
488073	479252	19711U	PARTICIPANT	\N	PRESENT	0
488094	479252	19741B	PARTICIPANT	\N	PRESENT	0
488105	479252	19467C	PARTICIPANT	\N	PRESENT	0
488106	479252	04071H	PARTICIPANT	\N	PRESENT	0
488133	479202	08052W	PARTICIPANT	\N	PRESENT	0
488134	479202	11074Q	PARTICIPANT	\N	PRESENT	0
488135	479202	19349W	PARTICIPANT	\N	PRESENT	0
488136	479202	19531S	PARTICIPANT	\N	PRESENT	0
488137	479202	11040E	PARTICIPANT	\N	PRESENT	0
488138	479202	19711U	PARTICIPANT	\N	PRESENT	0
488139	479202	11053K	PARTICIPANT	\N	PRESENT	0
488140	479202	07004J	PARTICIPANT	\N	PRESENT	0
488141	479202	04057K	PARTICIPANT	\N	PRESENT	0
488142	479202	19651A	PARTICIPANT	\N	PRESENT	0
488143	479202	07029T	PARTICIPANT	\N	PRESENT	0
488144	479202	19741B	PARTICIPANT	\N	PRESENT	0
488145	479202	04071H	PARTICIPANT	\N	PRESENT	0
488146	479202	19467C	PARTICIPANT	\N	PRESENT	0
488147	479202	99004R	PARTICIPANT	\N	PRESENT	0
488148	479202	14034U	PARTICIPANT	\N	PRESENT	0
488149	479202	01034P	PARTICIPANT	\N	PRESENT	0
488150	479202	19543W	PARTICIPANT	\N	PRESENT	0
488151	479202	19794Q	PARTICIPANT	\N	PRESENT	0
488161	479202	19657G	PARTICIPANT	\N	PRESENT	0
488162	479202	19577H	PARTICIPANT	\N	PRESENT	0
488281	487669	11097X	PARTICIPANT	\N	PRESENT	0
488282	487669	19926J	PARTICIPANT	\N	PRESENT	0
488283	487669	11067R	PARTICIPANT	\N	PRESENT	0
488131	479202	04086Q	PARTICIPANT	\N	PRESENT	0
488132	479202	08011M	PARTICIPANT	\N	PRESENT	0
488284	487669	19715Y	PARTICIPANT	\N	PRESENT	0
488285	487669	19703U	PARTICIPANT	\N	PRESENT	0
488286	487669	08052W	PARTICIPANT	\N	PRESENT	0
488287	487669	10006L	PARTICIPANT	\N	PRESENT	0
488288	487669	14087W	PARTICIPANT	\N	PRESENT	0
488289	487669	04092N	PRESIDENT	0	PRESENT	0
488290	487669	19647E	PARTICIPANT	\N	PRESENT	0
488291	487669	11074Q	PARTICIPANT	\N	PRESENT	0
488292	487669	04071H	PARTICIPANT	\N	PRESENT	0
488293	487669	07029T	PARTICIPANT	\N	PRESENT	0
488294	487669	11048N	PARTICIPANT	\N	PRESENT	0
488295	487669	19479G	PARTICIPANT	\N	PRESENT	0
488296	487669	99004R	PARTICIPANT	\N	PRESENT	0
488297	487669	01057W	PARTICIPANT	\N	PRESENT	0
488298	487669	11053K	PARTICIPANT	\N	PRESENT	0
488299	487669	08011M	PARTICIPANT	\N	PRESENT	0
488300	487669	19667J	PARTICIPANT	\N	PRESENT	0
489247	489033	04059M	PARTICIPANT	\N	PRESENT	0
489248	489033	19667J	PARTICIPANT	\N	PRESENT	0
489249	489033	11031D	PARTICIPANT	\N	PRESENT	0
489250	489033	10006L	PARTICIPANT	\N	PRESENT	0
489251	489033	19691J	PARTICIPANT	\N	PRESENT	0
489252	489033	19553Y	PARTICIPANT	\N	PRESENT	0
489253	489033	19715Y	PARTICIPANT	\N	PRESENT	0
489254	489033	19683J	PARTICIPANT	\N	PRESENT	0
489255	489033	19697Q	PARTICIPANT	\N	PRESENT	0
489256	489033	99004R	PARTICIPANT	\N	PRESENT	0
489257	489033	19503N	PARTICIPANT	\N	PRESENT	0
489258	489033	14331P	PARTICIPANT	\N	PRESENT	0
489259	489033	11097X	PRESIDENT	0	PRESENT	0
489260	489033	19703U	PARTICIPANT	\N	PRESENT	0
489261	489033	19479G	PARTICIPANT	\N	PRESENT	0
489262	489033	11048N	PARTICIPANT	\N	PRESENT	0
489263	489033	19573D	PARTICIPANT	\N	PRESENT	0
489275	489274	19631V	PARTICIPANT	\N	EXCUSE	0
489277	489274	19575F	PARTICIPANT	\N	EXCUSE	0
489279	489274	19545Y	PARTICIPANT	\N	EXCUSE	0
489281	489274	19577H	PARTICIPANT	\N	EXCUSE	0
489283	489274	19387D	PARTICIPANT	\N	EXCUSE	0
489285	489274	11048N	PARTICIPANT	\N	PRESENT	0
489287	489274	19489J	PARTICIPANT	\N	EXCUSE	0
489288	489274	11104D	PARTICIPANT	\N	EXCUSE	0
489289	489274	19335Q	PRESIDENT	0	PRESENT	0
499833	497197	19679N	PARTICIPANT	\N	PRESENT	0
499834	497197	10006L	PARTICIPANT	\N	PRESENT	0
499835	497197	11056N	PARTICIPANT	\N	PRESENT	0
499836	497197	19760E	PARTICIPANT	\N	PRESENT	0
499837	497197	19593H	PARTICIPANT	\N	PRESENT	0
499838	497197	11067R	PARTICIPANT	\N	PRESENT	0
499839	497197	20082E	PARTICIPANT	\N	PRESENT	0
499840	497197	19413M	PARTICIPANT	\N	PRESENT	0
499841	497197	19531S	PARTICIPANT	\N	PRESENT	0
499842	497197	19503N	PARTICIPANT	\N	PRESENT	0
499843	497197	19347U	PARTICIPANT	\N	PRESENT	0
499844	497197	19689Q	PARTICIPANT	\N	PRESENT	0
499845	497197	17779H	PARTICIPANT	\N	PRESENT	0
499846	497197	08017T	PARTICIPANT	\N	PRESENT	0
499847	497197	20076G	PARTICIPANT	\N	PRESENT	0
499848	497197	20134Y	PARTICIPANT	\N	PRESENT	0
499849	497197	17589D	PARTICIPANT	\N	PRESENT	0
499850	497197	04057K	PARTICIPANT	\N	PRESENT	0
499851	497197	11043H	PARTICIPANT	\N	PRESENT	0
499852	497197	19739H	PARTICIPANT	\N	PRESENT	0
499853	497197	20132W	PARTICIPANT	\N	PRESENT	0
499854	497197	14223L	PARTICIPANT	\N	PRESENT	0
499855	497197	20052X	PARTICIPANT	\N	PRESENT	0
499856	497197	19713W	PARTICIPANT	\N	PRESENT	0
499857	497197	14187A	PARTICIPANT	\N	PRESENT	0
499858	497197	14042U	PARTICIPANT	\N	PRESENT	0
499859	497197	14071N	PARTICIPANT	\N	PRESENT	0
499860	497197	14205J	PARTICIPANT	\N	PRESENT	0
499861	497197	19691J	PARTICIPANT	\N	PRESENT	0
499862	497197	19415P	PARTICIPANT	\N	PRESENT	0
499863	497197	14030Q	PARTICIPANT	\N	PRESENT	0
499868	497197	14357A	PARTICIPANT	\N	PRESENT	0
499865	497197	20068G	PARTICIPANT	\N	PRESENT	0
499866	497197	14147R	PARTICIPANT	\N	PRESENT	0
499867	497197	14083S	PARTICIPANT	\N	PRESENT	0
499869	497197	14331P	PARTICIPANT	\N	PRESENT	0
499870	497197	20038A	PARTICIPANT	\N	PRESENT	0
499871	497197	20024T	PARTICIPANT	\N	PRESENT	0
499872	497197	19671E	PARTICIPANT	\N	PRESENT	0
499873	497197	19399H	PARTICIPANT	\N	PRESENT	0
499874	497197	19693L	PARTICIPANT	\N	PRESENT	0
499875	497197	19591F	PARTICIPANT	\N	PRESENT	0
499876	497197	19527W	PARTICIPANT	\N	PRESENT	0
499877	497197	20084G	PARTICIPANT	\N	PRESENT	0
499878	497197	19820Y	PARTICIPANT	\N	PRESENT	0
499879	497197	20102Q	PARTICIPANT	\N	PRESENT	0
499923	497218	19629C	PARTICIPANT	\N	PRESENT	0
499924	497218	19593H	PARTICIPANT	\N	PRESENT	0
499925	497218	19621T	PARTICIPANT	\N	PRESENT	0
499926	497218	20068G	PARTICIPANT	\N	PRESENT	0
499927	497218	20134Y	PARTICIPANT	\N	PRESENT	0
499928	497218	19347U	PARTICIPANT	\N	PRESENT	0
499929	497218	20102Q	PARTICIPANT	\N	PRESENT	0
499930	497218	20084G	PARTICIPANT	\N	PRESENT	0
499931	497218	20132W	PARTICIPANT	\N	PRESENT	0
499932	497218	20026V	PARTICIPANT	\N	PRESENT	0
499933	497218	14109K	PARTICIPANT	\N	PRESENT	0
499934	497218	20044X	PARTICIPANT	\N	PRESENT	0
499935	497218	19399H	PARTICIPANT	\N	PRESENT	0
499936	497218	04070G	PARTICIPANT	\N	PRESENT	0
499937	497218	19611R	PARTICIPANT	\N	PRESENT	0
499938	497218	08017T	PARTICIPANT	\N	PRESENT	0
499939	497218	19719D	PARTICIPANT	\N	PRESENT	0
499940	497218	14207L	PARTICIPANT	\N	PRESENT	0
499941	497218	20052X	PARTICIPANT	\N	PRESENT	0
499942	497218	19735D	PARTICIPANT	\N	PRESENT	0
499943	497218	19527W	PARTICIPANT	\N	PRESENT	0
499944	497218	17589D	PARTICIPANT	\N	PRESENT	0
499945	497218	08061X	PARTICIPANT	\N	PRESENT	0
499946	497218	01028R	PARTICIPANT	\N	PRESENT	0
499947	497218	14033T	PARTICIPANT	\N	PRESENT	0
499948	497218	20058E	PARTICIPANT	\N	PRESENT	0
499949	497218	19747H	PARTICIPANT	\N	PRESENT	0
499950	497218	20032T	PARTICIPANT	\N	PRESENT	0
499951	497218	19447X	PARTICIPANT	\N	PRESENT	0
499952	497218	14069U	PARTICIPANT	\N	PRESENT	0
499953	497218	20120S	PARTICIPANT	\N	PRESENT	0
499954	497218	14030Q	PARTICIPANT	\N	PRESENT	0
499955	497218	14026U	PARTICIPANT	\N	PRESENT	0
499956	497218	19693L	PARTICIPANT	\N	PRESENT	0
499957	497218	04033B	PARTICIPANT	\N	PRESENT	0
499958	497218	11043H	PARTICIPANT	\N	PRESENT	0
499959	497218	18083K	PARTICIPANT	\N	PRESENT	0
499960	497218	07029T	PARTICIPANT	\N	PRESENT	0
499961	497218	14147R	PARTICIPANT	\N	PRESENT	0
499962	497218	19573D	PARTICIPANT	\N	PRESENT	0
499832	497197	01043Q	PARTICIPANT	\N	PRESENT	0
499967	497235	14026U	PARTICIPANT	\N	PRESENT	0
499921	497218	12041X	PARTICIPANT	\N	PRESENT	0
499922	497218	19329S	PARTICIPANT	\N	PRESENT	0
499981	497235	19415P	PARTICIPANT	\N	PRESENT	0
499982	497235	19713W	PARTICIPANT	\N	PRESENT	0
499983	497235	01028R	PARTICIPANT	\N	PRESENT	0
499984	497235	14109K	PARTICIPANT	\N	PRESENT	0
499985	497235	19573D	PARTICIPANT	\N	PRESENT	0
499986	497235	14147R	PARTICIPANT	\N	PRESENT	0
499987	497235	19954N	PARTICIPANT	\N	PRESENT	0
499988	497235	20076G	PARTICIPANT	\N	PRESENT	0
499989	497235	20084G	PARTICIPANT	\N	PRESENT	0
499990	497235	19413M	PARTICIPANT	\N	PRESENT	0
499991	496310	19543W	PARTICIPANT	\N	PRESENT	0
499992	496310	19651A	PARTICIPANT	\N	PRESENT	0
499993	496310	11097X	PARTICIPANT	\N	PRESENT	0
499994	496310	19669L	PARTICIPANT	\N	PRESENT	0
499995	496310	19553Y	PARTICIPANT	\N	PRESENT	0
499996	496310	19643A	PARTICIPANT	\N	PRESENT	0
499997	497235	20124W	PARTICIPANT	\N	PRESENT	0
499998	496310	11056N	PARTICIPANT	\N	PRESENT	0
499999	497235	11040E	PARTICIPANT	\N	PRESENT	0
500000	497235	14187A	PARTICIPANT	\N	PRESENT	0
500001	497039	14327T	PARTICIPANT	\N	PRESENT	0
500002	497039	04071H	PARTICIPANT	\N	PRESENT	0
500003	497039	01048V	PARTICIPANT	\N	PRESENT	0
500004	497039	20080C	PARTICIPANT	\N	PRESENT	0
500005	497039	11053K	PARTICIPANT	\N	PRESENT	0
500006	497039	14225N	PRESIDENT	0	PRESENT	0
500007	497039	11070L	PARTICIPANT	\N	PRESENT	0
500008	497039	19671E	PARTICIPANT	\N	PRESENT	0
500009	497039	07029T	PARTICIPANT	\N	PRESENT	0
500010	497039	08010L	PARTICIPANT	\N	PRESENT	0
500011	497039	20126Y	PARTICIPANT	\N	PRESENT	0
500012	497039	11048N	PARTICIPANT	\N	PRESENT	0
500013	497039	19647E	PARTICIPANT	\N	PRESENT	0
500014	497039	19711U	PARTICIPANT	\N	PRESENT	0
500015	497039	08034U	PARTICIPANT	\N	PRESENT	0
500016	497039	19531S	PARTICIPANT	\N	PRESENT	0
500017	497039	19689Q	PARTICIPANT	\N	PRESENT	0
500018	497039	20050V	PARTICIPANT	\N	PRESENT	0
500019	497039	08011M	PARTICIPANT	\N	PRESENT	0
500020	497039	20044X	PARTICIPANT	\N	PRESENT	0
500021	497039	11040E	PARTICIPANT	\N	PRESENT	0
500022	497039	04086Q	PARTICIPANT	\N	PRESENT	0
500023	497039	14083S	PARTICIPANT	\N	PRESENT	0
500024	497039	11012A	PARTICIPANT	\N	PRESENT	0
500025	497039	20070A	PARTICIPANT	\N	PRESENT	0
500026	497039	99004R	PARTICIPANT	\N	PRESENT	0
500027	497235	19691J	PARTICIPANT	\N	PRESENT	0
500028	497235	01058X	PARTICIPANT	\N	PRESENT	0
500030	497235	14083S	PARTICIPANT	\N	PRESENT	0
500031	497039	11074Q	PRESIDENT	1	PRESENT	0
500032	497039	19741B	PARTICIPANT	\N	PRESENT	0
500033	497235	04043D	PARTICIPANT	\N	PRESENT	0
500034	497235	11045K	PARTICIPANT	\N	PRESENT	0
500035	497235	19563B	PARTICIPANT	\N	PRESENT	0
500036	497235	19621T	PARTICIPANT	\N	PRESENT	0
500037	497235	19701S	PARTICIPANT	\N	PRESENT	0
500038	497235	20024T	PARTICIPANT	\N	PRESENT	0
500039	497235	14205J	PARTICIPANT	\N	PRESENT	0
500040	497235	14030Q	PARTICIPANT	\N	PRESENT	0
500041	497235	19347U	PARTICIPANT	\N	PRESENT	0
500042	497235	18083K	PARTICIPANT	\N	PRESENT	0
500043	497235	01024M	PARTICIPANT	\N	PRESENT	0
500044	497235	19826F	PARTICIPANT	\N	PRESENT	0
500045	497235	19367Y	PARTICIPANT	\N	PRESENT	0
500046	497235	19820Y	PARTICIPANT	\N	PRESENT	0
500047	497235	14223L	PARTICIPANT	\N	PRESENT	0
500048	497039	14331P	PARTICIPANT	\N	PRESENT	0
500049	497235	19631V	PARTICIPANT	\N	PRESENT	0
500054	497235	14237S	PARTICIPANT	\N	PRESENT	0
500055	497235	11115U	PARTICIPANT	\N	PRESENT	0
500056	497235	19719D	PARTICIPANT	\N	PRESENT	0
500057	497235	14038Y	PARTICIPANT	\N	PRESENT	0
500059	497235	19695N	PARTICIPANT	\N	PRESENT	0
500060	497235	14001X	PARTICIPANT	\N	PRESENT	0
500061	497235	19593H	PARTICIPANT	\N	PRESENT	0
500074	497235	20082E	PARTICIPANT	\N	PRESENT	0
500076	497235	01025N	PARTICIPANT	\N	PRESENT	0
500082	497235	14033T	PARTICIPANT	\N	PRESENT	0
484576	483244	96004D	PRESIDENT	0	PRESENT	0
484577	483244	14065Q	PARTICIPANT	\N	PRESENT	0
484579	483244	14357A	PARTICIPANT	\N	PRESENT	0
484580	483244	11083R	PARTICIPANT	\N	PRESENT	0
484581	483244	04097T	PARTICIPANT	\N	PRESENT	0
484582	483244	08044W	PARTICIPANT	\N	PRESENT	0
484583	483244	14097Y	PARTICIPANT	\N	PRESENT	0
484584	483244	14331P	PARTICIPANT	\N	PRESENT	0
484585	483244	10015M	PARTICIPANT	\N	PRESENT	0
484586	483244	98035U	PARTICIPANT	\N	PRESENT	0
484679	484676	08058D	PARTICIPANT	\N	PRESENT	0
484680	484676	04047H	PARTICIPANT	\N	PRESENT	0
484682	484681	08058D	PARTICIPANT	\N	PRESENT	0
490914	490707	20040T	PARTICIPANT	\N	PRESENT	0
490915	490707	19663E	PARTICIPANT	\N	PRESENT	0
490916	490707	19691J	PARTICIPANT	\N	PRESENT	0
491071	490453	97011G	PARTICIPANT	\N	PRESENT	0
490918	490707	20066E	PARTICIPANT	\N	PRESENT	0
490919	490707	14071N	PARTICIPANT	\N	PRESENT	0
490920	490707	19697Q	PARTICIPANT	\N	PRESENT	0
490921	490707	20090E	PARTICIPANT	\N	PRESENT	0
490922	490707	14355X	PARTICIPANT	\N	PRESENT	0
490923	490707	19569H	PARTICIPANT	\N	PRESENT	0
490924	490707	19415P	PARTICIPANT	\N	PRESENT	0
490925	490707	18193Q	PARTICIPANT	\N	PRESENT	0
490926	490707	14223L	PARTICIPANT	\N	PRESENT	0
490927	490707	14026U	PARTICIPANT	\N	PRESENT	0
490928	490707	17779H	PARTICIPANT	\N	PRESENT	0
490929	490707	11031D	PARTICIPANT	\N	PRESENT	0
490930	490707	19703U	PARTICIPANT	\N	PRESENT	0
490931	490707	14281W	PARTICIPANT	\N	PRESENT	0
490932	490707	19367Y	PARTICIPANT	\N	PRESENT	0
490933	490707	14213J	PARTICIPANT	\N	PRESENT	0
490934	490707	14217N	PARTICIPANT	\N	PRESENT	0
490935	490707	19591F	PARTICIPANT	\N	PRESENT	0
490936	490707	20130U	PARTICIPANT	\N	PRESENT	0
490937	490707	01034P	PARTICIPANT	\N	PRESENT	0
490938	490707	19713W	PARTICIPANT	\N	PRESENT	0
490939	490707	08045X	PARTICIPANT	\N	PRESENT	0
490940	490707	11045K	PARTICIPANT	\N	PRESENT	0
490941	490707	17965H	PARTICIPANT	\N	PRESENT	0
490942	490707	19301E	PARTICIPANT	\N	PRESENT	0
490943	490707	19715Y	PARTICIPANT	\N	PRESENT	0
490944	490707	20148F	PARTICIPANT	\N	PRESENT	0
490945	490707	19717B	PARTICIPANT	\N	PRESENT	0
490946	490707	19723Y	PARTICIPANT	\N	PRESENT	0
490947	490707	11103C	PARTICIPANT	\N	PRESENT	0
490948	490707	19657G	PARTICIPANT	\N	PRESENT	0
490949	490707	04043D	PARTICIPANT	\N	PRESENT	0
490950	490707	19760E	PARTICIPANT	\N	PRESENT	0
490951	490707	14195A	PARTICIPANT	\N	EXCUSE	0
491003	491002	19693L	PARTICIPANT	\N	PRESENT	0
491004	491002	19593H	PARTICIPANT	\N	PRESENT	0
491005	491002	19533U	PARTICIPANT	\N	PRESENT	0
491006	490450	04070G	PARTICIPANT	\N	PRESENT	0
491007	490450	19699S	PARTICIPANT	\N	PRESENT	0
491008	490450	19533U	PARTICIPANT	\N	PRESENT	0
491009	490450	04033B	PARTICIPANT	\N	PRESENT	0
491010	490450	19329S	PARTICIPANT	\N	PRESENT	0
491011	490450	14229S	PARTICIPANT	\N	PRESENT	0
491012	490450	20098N	PARTICIPANT	\N	PRESENT	0
491013	490450	19573D	PARTICIPANT	\N	PRESENT	0
491014	490450	08017T	PARTICIPANT	\N	PRESENT	0
491015	490450	92040Q	PARTICIPANT	\N	PRESENT	0
491016	490450	20112S	PARTICIPANT	\N	PRESENT	0
491017	490450	08061X	PARTICIPANT	\N	PRESENT	0
491018	490450	08012N	PARTICIPANT	\N	PRESENT	0
491019	490450	20124W	PARTICIPANT	\N	PRESENT	0
491020	490450	20026V	PARTICIPANT	\N	PRESENT	0
491021	490450	20120S	PARTICIPANT	\N	PRESENT	0
491022	490450	19593H	PARTICIPANT	\N	PRESENT	0
491023	490450	19527W	PARTICIPANT	\N	PRESENT	0
491024	490450	20132W	PARTICIPANT	\N	PRESENT	0
491025	490450	20134Y	PARTICIPANT	\N	PRESENT	0
491026	490450	14073Q	PARTICIPANT	\N	PRESENT	0
491027	490450	19651A	PARTICIPANT	\N	PRESENT	0
491028	490450	19611R	PRESIDENT	0	PRESENT	0
491029	490450	20138D	PARTICIPANT	\N	PRESENT	0
491030	490450	20142Y	PARTICIPANT	\N	PRESENT	0
491031	490450	20048C	PARTICIPANT	\N	PRESENT	0
491032	490450	19693L	PARTICIPANT	\N	PRESENT	0
491033	490450	19399H	PARTICIPANT	\N	PRESENT	0
491034	490450	20152B	PARTICIPANT	\N	PRESENT	0
491035	490450	20052X	PARTICIPANT	\N	PRESENT	0
491036	490450	19719D	PARTICIPANT	\N	PRESENT	0
491037	490450	14030Q	PARTICIPANT	\N	PRESENT	0
491038	490450	20058E	PARTICIPANT	\N	PRESENT	0
491039	490450	20056C	PARTICIPANT	\N	PRESENT	0
491040	490450	04059M	PARTICIPANT	\N	PRESENT	0
491041	490450	19735D	PARTICIPANT	\N	PRESENT	0
491042	490450	11083R	PARTICIPANT	\N	PRESENT	0
491043	490450	14109K	PARTICIPANT	\N	PRESENT	0
491044	490450	14123H	PARTICIPANT	\N	PRESENT	0
491045	490450	11043H	PARTICIPANT	\N	PRESENT	0
491046	490450	19758L	PARTICIPANT	\N	PRESENT	0
491047	490450	17589D	PARTICIPANT	\N	PRESENT	0
491048	490450	20084G	PARTICIPANT	\N	PRESENT	0
491049	490450	19621T	PARTICIPANT	\N	PRESENT	0
491052	490453	19443T	PARTICIPANT	\N	PRESENT	0
491053	490453	12041X	PARTICIPANT	\N	PRESENT	0
491054	490453	11080N	PARTICIPANT	\N	PRESENT	0
491055	490453	19565D	PARTICIPANT	\N	PRESENT	0
491056	490453	20072C	PARTICIPANT	\N	PRESENT	0
491057	490453	04034C	PARTICIPANT	\N	PRESENT	0
491058	490453	01058X	PARTICIPANT	\N	PRESENT	0
491059	490453	11027H	PARTICIPANT	\N	PRESENT	0
491060	490453	16685X	PARTICIPANT	\N	PRESENT	0
491061	490453	04042C	PRESIDENT	1	PRESENT	0
491062	490453	11054L	PARTICIPANT	\N	PRESENT	0
491063	490453	11066Q	PARTICIPANT	\N	PRESENT	0
491064	490453	19669L	PARTICIPANT	\N	PRESENT	0
491065	490453	08056B	PARTICIPANT	\N	PRESENT	0
491066	490453	12028B	PARTICIPANT	\N	PRESENT	0
491067	490453	19421M	PARTICIPANT	\N	PRESENT	0
491068	490453	19709B	PARTICIPANT	\N	PRESENT	0
491069	490453	14193X	PARTICIPANT	\N	PRESENT	0
491070	490453	19347U	PARTICIPANT	\N	PRESENT	0
505385	502291	20072C	PARTICIPANT	\N	PRESENT	0
505388	502291	19735D	PARTICIPANT	\N	EXCUSE	0
505389	502291	19563B	PARTICIPANT	\N	PRESENT	0
505390	502291	11067R	PARTICIPANT	\N	EXCUSE	0
505402	501779	19747H	PARTICIPANT	\N	PRESENT	1
505403	501911	19713W	PARTICIPANT	\N	PRESENT	1
505404	502291	20128B	PARTICIPANT	\N	PRESENT	0
505482	502450	19531S	PARTICIPANT	\N	PRESENT	1
505483	502450	11110B	PARTICIPANT	\N	PRESENT	1
505484	502450	19565D	PARTICIPANT	\N	PRESENT	1
505502	502450	14189C	PARTICIPANT	\N	PRESENT	0
505503	501779	20086J	PARTICIPANT	\N	PRESENT	1
505504	501779	19782L	PARTICIPANT	\N	PRESENT	1
505549	501823	20028X	PARTICIPANT	\N	PRESENT	0
505514	502291	01048V	PARTICIPANT	\N	EXCUSE	0
505545	501823	11045K	PARTICIPANT	\N	PRESENT	0
505550	501823	20082E	PARTICIPANT	\N	PRESENT	0
505551	501823	19413M	PARTICIPANT	\N	PRESENT	0
505552	501823	11099A	PARTICIPANT	\N	PRESENT	0
505553	505548	20142Y	PARTICIPANT	\N	PRESENT	0
505554	505548	14229S	PARTICIPANT	\N	PRESENT	0
505555	501823	20146D	PARTICIPANT	\N	PRESENT	0
505556	505548	17589D	PARTICIPANT	\N	PRESENT	0
505557	505548	20084G	PARTICIPANT	\N	PRESENT	0
505558	501823	19782L	PARTICIPANT	\N	PRESENT	0
505559	501823	19563B	PARTICIPANT	\N	PRESENT	0
505560	501823	14195A	PARTICIPANT	\N	PRESENT	0
505561	501823	20122U	PARTICIPANT	\N	PRESENT	0
505562	501823	20102Q	PARTICIPANT	\N	PRESENT	0
505563	501823	14219Q	PARTICIPANT	\N	PRESENT	0
505564	501823	20094J	PARTICIPANT	\N	PRESENT	0
505566	501823	19657G	PARTICIPANT	\N	PRESENT	0
505567	501823	14169X	PARTICIPANT	\N	PRESENT	0
505568	501823	20066E	PARTICIPANT	\N	PRESENT	0
505569	502451	04086Q	PARTICIPANT	\N	PRESENT	0
505570	502451	11048N	PARTICIPANT	\N	PRESENT	0
505571	502451	19479G	PARTICIPANT	\N	PRESENT	0
505572	502451	19711U	PARTICIPANT	\N	PRESENT	0
505573	502451	19349W	PARTICIPANT	\N	PRESENT	0
505574	502451	99004R	PARTICIPANT	\N	PRESENT	0
505575	502451	11074Q	PARTICIPANT	\N	PRESENT	0
505576	502451	20150Y	PARTICIPANT	\N	PRESENT	0
505577	502451	20126Y	PARTICIPANT	\N	PRESENT	0
505578	501823	14205J	PARTICIPANT	\N	PRESENT	0
505579	501823	20124W	PARTICIPANT	\N	PRESENT	0
505580	502451	19762G	PARTICIPANT	\N	PRESENT	0
505581	501823	01058X	PARTICIPANT	\N	PRESENT	0
505582	501823	20118Y	PARTICIPANT	\N	PRESENT	0
505584	501823	19637C	PARTICIPANT	\N	PRESENT	0
505585	505565	14229S	PARTICIPANT	\N	PRESENT	0
505586	505565	20084G	PARTICIPANT	\N	PRESENT	0
505587	505565	20142Y	PARTICIPANT	\N	PRESENT	0
505588	505583	20142Y	PARTICIPANT	\N	PRESENT	0
505589	505583	20084G	PARTICIPANT	\N	PRESENT	0
505590	501823	19713W	PARTICIPANT	\N	PRESENT	0
505591	502451	07029T	PARTICIPANT	\N	PRESENT	0
505628	502451	19647E	PARTICIPANT	\N	PRESENT	0
505593	501823	14207L	PARTICIPANT	\N	PRESENT	0
505594	502451	20070A	PARTICIPANT	\N	PRESENT	0
505595	501823	20134Y	PARTICIPANT	\N	PRESENT	0
505596	502451	19671E	PARTICIPANT	\N	PRESENT	0
505597	502451	08010L	PARTICIPANT	\N	PRESENT	0
505598	502451	19335Q	PARTICIPANT	\N	PRESENT	0
505599	501823	19387D	PARTICIPANT	\N	PRESENT	0
505600	501823	19723Y	PARTICIPANT	\N	PRESENT	0
505601	501823	20076G	PARTICIPANT	\N	PRESENT	0
505602	501823	19467C	PARTICIPANT	\N	PRESENT	0
505603	501823	19549D	PARTICIPANT	\N	PRESENT	0
505604	502451	01048V	PARTICIPANT	\N	PRESENT	0
505605	502451	08034U	PARTICIPANT	\N	PRESENT	0
505606	502451	19689Q	PARTICIPANT	\N	PRESENT	0
505607	502451	20080C	PARTICIPANT	\N	PRESENT	0
505608	501823	01048V	PARTICIPANT	\N	PRESENT	0
505609	502451	11070L	PARTICIPANT	\N	PRESENT	0
505610	502451	14083S	PARTICIPANT	\N	PRESENT	0
505616	502451	14225N	PRESIDENT	0	PRESENT	0
505619	502451	04071H	PARTICIPANT	\N	PRESENT	0
505620	502451	01057W	PARTICIPANT	\N	PRESENT	0
505622	502451	19399H	PARTICIPANT	\N	PRESENT	0
505623	502451	19741B	PARTICIPANT	\N	PRESENT	0
505625	501823	14069U	PARTICIPANT	\N	PRESENT	0
505626	501823	14123H	PARTICIPANT	\N	PRESENT	0
505627	501823	14021P	PARTICIPANT	\N	PRESENT	0
505629	501823	14251Q	PARTICIPANT	\N	PRESENT	0
505630	502451	11040E	PARTICIPANT	\N	PRESENT	0
505631	501823	04059M	PARTICIPANT	\N	PRESENT	0
505632	501823	08061X	PARTICIPANT	\N	PRESENT	0
505634	501823	14073Q	PARTICIPANT	\N	PRESENT	0
505635	501823	19651A	PARTICIPANT	\N	PRESENT	0
505639	501823	07004J	PARTICIPANT	\N	PRESENT	0
505642	501823	19954N	PARTICIPANT	\N	PRESENT	0
505643	501823	19643A	PARTICIPANT	\N	PRESENT	0
505644	501823	19441R	PARTICIPANT	\N	PRESENT	0
505645	501823	20112S	PARTICIPANT	\N	PRESENT	0
505687	502451	11053K	PARTICIPANT	\N	PRESENT	0
505688	502451	19667J	PARTICIPANT	\N	PRESENT	0
505689	501824	14207L	PARTICIPANT	\N	PRESENT	0
505690	501824	14251Q	PARTICIPANT	\N	PRESENT	0
505691	501824	14195A	PARTICIPANT	\N	PRESENT	0
505692	501824	20122U	PARTICIPANT	\N	PRESENT	0
505693	501824	20134Y	PARTICIPANT	\N	PRESENT	0
505694	501824	11099A	PARTICIPANT	\N	PRESENT	0
505695	501824	19725B	PARTICIPANT	\N	PRESENT	0
505696	501824	20094J	PARTICIPANT	\N	PRESENT	0
505697	501824	19251M	PARTICIPANT	\N	PRESENT	0
505698	501824	19651A	PARTICIPANT	\N	PRESENT	0
505699	501824	19441R	PARTICIPANT	\N	PRESENT	0
505700	501824	19581D	PARTICIPANT	\N	PRESENT	0
505703	501824	19723Y	PARTICIPANT	\N	PRESENT	0
505706	501824	19954N	PARTICIPANT	\N	PRESENT	0
505707	501824	14211G	PARTICIPANT	\N	PRESENT	0
505708	501824	20112S	PARTICIPANT	\N	PRESENT	0
505710	505709	05008E	PARTICIPANT	\N	PRESENT	0
505711	505709	11053K	PARTICIPANT	\N	PRESENT	0
505712	505709	01028R	PARTICIPANT	\N	PRESENT	0
505713	501824	20050V	PARTICIPANT	\N	PRESENT	0
505714	501824	20056C	PARTICIPANT	\N	PRESENT	0
505715	501824	19693L	PARTICIPANT	\N	PRESENT	0
505716	501824	07004J	PARTICIPANT	\N	PRESENT	0
505717	501824	14223L	PARTICIPANT	\N	PRESENT	0
505718	501824	14275Y	PARTICIPANT	\N	PRESENT	0
505719	501824	14151M	PARTICIPANT	\N	PRESENT	0
505720	501824	14069U	PARTICIPANT	\N	PRESENT	0
505721	501824	19643A	PARTICIPANT	\N	PRESENT	0
505722	501824	04070G	PARTICIPANT	\N	PRESENT	0
505723	501824	14031R	PARTICIPANT	\N	PRESENT	0
505724	501824	19563B	PARTICIPANT	\N	PRESENT	0
505725	501824	19387D	PARTICIPANT	\N	PRESENT	0
505685	501824	11045K	PARTICIPANT	\N	PRESENT	0
505686	501824	04059M	PARTICIPANT	\N	PRESENT	0
505726	501824	19611R	PARTICIPANT	\N	PRESENT	0
505727	501824	04057K	PARTICIPANT	\N	PRESENT	0
505728	501824	20028X	PARTICIPANT	\N	PRESENT	0
505729	501824	20052X	PARTICIPANT	\N	PRESENT	0
505730	501824	08018U	PARTICIPANT	\N	PRESENT	0
505731	501824	14059S	PARTICIPANT	\N	PRESENT	0
505734	501824	20114U	PARTICIPANT	\N	PRESENT	0
505737	501824	20116W	PARTICIPANT	\N	PRESENT	0
505742	501824	14021P	PARTICIPANT	\N	PRESENT	0
505744	501824	14257W	PARTICIPANT	\N	PRESENT	0
505745	501824	20092G	PARTICIPANT	\N	PRESENT	0
505746	501824	08061X	PARTICIPANT	\N	PRESENT	0
505747	501824	19545Y	PARTICIPANT	\N	PRESENT	0
505765	501824	19798U	PARTICIPANT	\N	PRESENT	0
505772	505771	20142Y	PARTICIPANT	\N	PRESENT	0
505773	505771	20084G	PARTICIPANT	\N	PRESENT	0
505774	505771	17589D	PARTICIPANT	\N	PRESENT	0
505775	501824	07029T	PARTICIPANT	\N	PRESENT	0
505800	501824	18083K	PARTICIPANT	\N	PRESENT	0
505801	501824	19467C	PARTICIPANT	\N	PRESENT	0
505802	501824	19399H	PARTICIPANT	\N	PRESENT	0
483669	483387	11072N	PARTICIPANT	\N	PRESENT	0
483670	483387	10015M	PARTICIPANT	\N	PRESENT	0
483671	483387	11033F	PARTICIPANT	\N	PRESENT	0
484688	484687	14331P	PARTICIPANT	\N	EXCUSE	0
490770	490769	14231L	PARTICIPANT	\N	PRESENT	0
490771	490769	14259Y	PARTICIPANT	\N	PRESENT	0
490772	490769	14053L	PARTICIPANT	\N	PRESENT	0
488854	488467	19387D	PARTICIPANT	\N	PRESENT	0
489290	489274	14071N	PARTICIPANT	\N	EXCUSE	0
490773	490769	19954N	PARTICIPANT	\N	PRESENT	0
490774	490769	01057W	PARTICIPANT	\N	PRESENT	0
489292	489274	14237S	PARTICIPANT	\N	EXCUSE	0
489293	489274	19503N	PARTICIPANT	\N	PRESENT	0
491818	491412	20018V	PARTICIPANT	\N	PRESENT	0
489295	489274	19619A	PARTICIPANT	\N	EXCUSE	0
491819	491412	19383Y	PARTICIPANT	\N	PRESENT	0
489297	489274	08049C	PARTICIPANT	\N	PRESENT	0
491820	491412	20034V	PARTICIPANT	\N	PRESENT	0
491821	491412	14123H	PARTICIPANT	\N	PRESENT	0
491822	491412	19701S	PARTICIPANT	\N	PRESENT	0
491823	491468	12041X	PARTICIPANT	\N	PRESENT	0
491824	491468	04034C	PARTICIPANT	\N	PRESENT	0
491825	491468	01058X	PARTICIPANT	\N	PRESENT	0
491826	491468	11027H	PARTICIPANT	\N	PRESENT	0
491827	491468	04042C	PRESIDENT	0	PRESENT	0
491828	491468	11054L	PARTICIPANT	\N	PRESENT	0
491829	491468	11066Q	PARTICIPANT	\N	PRESENT	0
491830	491468	19421M	PARTICIPANT	\N	PRESENT	0
491831	491468	19709B	PARTICIPANT	\N	PRESENT	0
491832	491468	14193X	PARTICIPANT	\N	PRESENT	0
491833	491468	19347U	PARTICIPANT	\N	PRESENT	0
491834	491468	08047A	PARTICIPANT	\N	PRESENT	0
491835	491468	20128B	PARTICIPANT	\N	PRESENT	0
491836	491468	14059S	PARTICIPANT	\N	PRESENT	0
491837	491468	04035D	PARTICIPANT	\N	PRESENT	0
488838	488469	19387D	PARTICIPANT	\N	PRESENT	0
491838	491468	14133K	PARTICIPANT	\N	PRESENT	0
491839	491468	01062T	PARTICIPANT	\N	PRESENT	0
491840	491468	11041F	PARTICIPANT	\N	PRESENT	0
491841	491468	01024M	PARTICIPANT	\N	PRESENT	0
491842	491468	98022P	PARTICIPANT	\N	PRESENT	0
491843	491468	14267Y	PARTICIPANT	\N	PRESENT	0
491844	491468	11064N	PARTICIPANT	\N	PRESENT	0
491845	491468	11083R	PARTICIPANT	\N	PRESENT	0
491846	491468	14211G	PARTICIPANT	\N	PRESENT	0
491847	491468	19583F	PARTICIPANT	\N	PRESENT	0
491848	491468	14255U	PARTICIPANT	\N	PRESENT	0
491849	491412	04059M	PARTICIPANT	\N	PRESENT	0
488851	488468	19335Q	PARTICIPANT	\N	PRESENT	0
488853	488467	19335Q	PRESIDENT	0	PRESENT	0
491850	491412	19631V	PARTICIPANT	\N	PRESENT	0
491851	491412	20044X	PARTICIPANT	\N	PRESENT	0
491852	491412	14173T	PARTICIPANT	\N	PRESENT	0
491853	491412	20036X	PARTICIPANT	\N	PRESENT	0
491854	491412	14121F	PARTICIPANT	\N	PRESENT	0
491855	491412	19349W	PARTICIPANT	\N	PRESENT	0
491856	491412	19689Q	PARTICIPANT	\N	PRESENT	0
491857	491412	11110B	PARTICIPANT	\N	PRESENT	0
491858	491412	19413M	PARTICIPANT	\N	PRESENT	0
491859	491412	14053L	PARTICIPANT	\N	PRESENT	0
491871	491412	20082E	PARTICIPANT	\N	PRESENT	0
491872	491412	20064C	PARTICIPANT	\N	PRESENT	0
491873	491412	20022R	PARTICIPANT	\N	PRESENT	0
491874	491412	19521Q	PARTICIPANT	\N	PRESENT	0
491875	491412	19782L	PARTICIPANT	\N	PRESENT	0
491876	491412	11097X	PARTICIPANT	\N	PRESENT	0
491877	491412	20108W	PARTICIPANT	\N	PRESENT	0
491878	491412	01043Q	PARTICIPANT	\N	PRESENT	0
491879	491412	19531S	PARTICIPANT	\N	PRESENT	0
491880	491412	01024M	PARTICIPANT	\N	PRESENT	0
491882	491412	14147R	PARTICIPANT	\N	PRESENT	0
491887	491412	14207L	PARTICIPANT	\N	PRESENT	0
491888	491412	19347U	PARTICIPANT	\N	PRESENT	0
491889	491412	20094J	PARTICIPANT	\N	PRESENT	0
491890	491412	19549D	PARTICIPANT	\N	PRESENT	0
491891	491412	01057W	PARTICIPANT	\N	PRESENT	0
491892	491412	20080C	PARTICIPANT	\N	PRESENT	0
491893	491412	11043H	PARTICIPANT	\N	PRESENT	0
491894	491412	20110Q	PARTICIPANT	\N	PRESENT	0
492546	491415	19689Q	PARTICIPANT	\N	PRESENT	0
492547	491415	19349W	PARTICIPANT	\N	PRESENT	0
492548	491415	04008A	PARTICIPANT	\N	PRESENT	0
492549	491415	19329S	PARTICIPANT	\N	PRESENT	0
492550	491415	14038Y	PARTICIPANT	\N	PRESENT	0
492551	491415	14041T	PARTICIPANT	\N	PRESENT	0
492552	491415	19782L	PARTICIPANT	\N	PRESENT	0
492553	491415	11072N	PARTICIPANT	\N	PRESENT	0
492554	491415	20038A	PARTICIPANT	\N	PRESENT	0
492555	491415	20142Y	PARTICIPANT	\N	PRESENT	0
492556	491415	19447X	PARTICIPANT	\N	PRESENT	0
492557	491415	20070A	PARTICIPANT	\N	PRESENT	0
492558	491415	19685L	PARTICIPANT	\N	PRESENT	0
492559	491415	19467C	PARTICIPANT	\N	PRESENT	0
492560	491415	14207L	PARTICIPANT	\N	PRESENT	0
492561	491415	20132W	PARTICIPANT	\N	PRESENT	0
492562	491415	19719D	PARTICIPANT	\N	PRESENT	0
492563	491415	14215L	PARTICIPANT	\N	PRESENT	0
492564	491415	19681G	PARTICIPANT	\N	PRESENT	0
492565	491415	11012A	PARTICIPANT	\N	PRESENT	0
492566	491415	19565D	PARTICIPANT	\N	PRESENT	0
492567	491415	01057W	PARTICIPANT	\N	PRESENT	0
492568	491415	14169X	PARTICIPANT	\N	PRESENT	0
492569	491415	20036X	PARTICIPANT	\N	PRESENT	0
492570	491415	19545Y	PARTICIPANT	\N	PRESENT	0
492571	491415	14221J	PARTICIPANT	\N	PRESENT	0
492572	491415	14211G	PARTICIPANT	\N	PRESENT	0
492573	491415	14251Q	PARTICIPANT	\N	PRESENT	0
492574	491415	19515S	PARTICIPANT	\N	PRESENT	0
492575	491415	11080N	PARTICIPANT	\N	PRESENT	0
492576	491415	19766L	PARTICIPANT	\N	PRESENT	0
492577	491415	01028R	PARTICIPANT	\N	PRESENT	0
492578	491415	19599P	PARTICIPANT	\N	PRESENT	0
492579	491415	11045K	PARTICIPANT	\N	PRESENT	0
492580	491415	12016W	PARTICIPANT	\N	PRESENT	0
492581	491415	11066Q	PARTICIPANT	\N	PRESENT	0
492582	491415	14021P	PARTICIPANT	\N	PRESENT	0
492583	491415	18083K	PARTICIPANT	\N	PRESENT	0
492584	491415	08015R	PARTICIPANT	\N	PRESENT	0
492585	491415	14225N	PARTICIPANT	\N	PRESENT	0
492586	491415	17779H	PARTICIPANT	\N	PRESENT	0
492587	491415	19762G	PARTICIPANT	\N	PRESENT	0
492588	491415	04059M	PARTICIPANT	\N	PRESENT	0
492589	491415	14257W	PARTICIPANT	\N	PRESENT	0
492590	491415	20060X	PARTICIPANT	\N	PRESENT	0
492591	491415	19443T	PARTICIPANT	\N	PRESENT	0
492592	491415	14229S	PARTICIPANT	\N	PRESENT	0
492593	491415	14151M	PARTICIPANT	\N	PRESENT	0
492594	491415	19575F	PARTICIPANT	\N	PRESENT	0
492595	491415	04035D	PARTICIPANT	\N	PRESENT	0
492596	491415	20114U	PARTICIPANT	\N	PRESENT	0
492597	491415	20024T	PARTICIPANT	\N	PRESENT	0
492598	491415	19820Y	PARTICIPANT	\N	PRESENT	0
492599	491415	20094J	PARTICIPANT	\N	PRESENT	0
492600	491415	19531S	PARTICIPANT	\N	PRESENT	0
492601	491415	17965H	PARTICIPANT	\N	PRESENT	0
492602	491415	19725B	PARTICIPANT	\N	PRESENT	0
492603	491415	18193Q	PARTICIPANT	\N	PRESENT	0
492604	491415	20064C	PARTICIPANT	\N	PRESENT	0
492605	491415	14329V	PARTICIPANT	\N	PRESENT	0
492606	491415	20090E	PARTICIPANT	\N	PRESENT	0
492607	491415	20046A	PARTICIPANT	\N	PRESENT	0
492608	491415	14231L	PARTICIPANT	\N	PRESENT	0
492609	491415	14179A	PARTICIPANT	\N	PRESENT	0
492610	491415	20066E	PARTICIPANT	\N	PRESENT	0
492611	491415	19749K	PARTICIPANT	\N	PRESENT	0
492612	491415	19399H	PARTICIPANT	\N	PRESENT	0
492613	491415	19569H	PARTICIPANT	\N	PRESENT	0
492614	491415	14042U	PARTICIPANT	\N	PRESENT	0
492615	491415	14357A	PARTICIPANT	\N	PRESENT	0
492616	491415	19479G	PARTICIPANT	\N	PRESENT	0
492617	491415	20048C	PARTICIPANT	\N	PRESENT	0
492618	491415	19715Y	PARTICIPANT	\N	PRESENT	0
492619	491415	14217N	PARTICIPANT	\N	PRESENT	0
492620	491415	14069U	PARTICIPANT	\N	PRESENT	0
492621	491415	10006L	PARTICIPANT	\N	PRESENT	0
492622	491415	19543W	PARTICIPANT	\N	PRESENT	0
492623	491415	19621T	PARTICIPANT	\N	PRESENT	0
492624	491415	19553Y	PARTICIPANT	\N	PRESENT	0
492625	491415	08028W	PARTICIPANT	\N	PRESENT	0
492626	491415	19735D	PARTICIPANT	\N	PRESENT	0
492627	491415	14327T	PARTICIPANT	\N	PRESENT	0
492628	491415	08009T	PARTICIPANT	\N	PRESENT	0
492629	491415	14237S	PARTICIPANT	\N	PRESENT	0
492630	491415	20040T	PARTICIPANT	\N	PRESENT	0
492631	491415	14189C	PARTICIPANT	\N	PRESENT	0
492632	491415	14187A	PARTICIPANT	\N	PRESENT	0
492634	491415	11085T	PARTICIPANT	\N	PRESENT	0
492635	491415	19701S	PARTICIPANT	\N	PRESENT	0
492637	491415	04070G	PARTICIPANT	\N	PRESENT	0
500083	497235	19301E	PARTICIPANT	\N	PRESENT	0
500084	497235	14219Q	PARTICIPANT	\N	PRESENT	0
500085	497235	14069U	PARTICIPANT	\N	PRESENT	0
500086	497235	19369B	PARTICIPANT	\N	PRESENT	0
500117	497235	07033P	PARTICIPANT	\N	PRESENT	0
500151	498985	11033F	PARTICIPANT	\N	PRESENT	0
500118	495438	11097X	PARTICIPANT	\N	PRESENT	0
500152	498985	04008A	PARTICIPANT	\N	PRESENT	0
500153	498985	14215L	PARTICIPANT	\N	PRESENT	0
500154	498985	20074E	PARTICIPANT	\N	EXCUSE	0
500138	498985	19629C	PARTICIPANT	\N	PRESENT	0
500125	497235	19531S	PARTICIPANT	\N	PRESENT	0
500139	498985	19673G	PARTICIPANT	\N	PRESENT	0
500140	498985	14053L	PARTICIPANT	\N	PRESENT	0
500141	498985	19649G	PARTICIPANT	\N	PRESENT	0
500142	498985	19543W	PARTICIPANT	\N	PRESENT	0
500143	498985	04047H	PRESIDENT	0	PRESENT	0
500144	498985	19447X	PARTICIPANT	\N	PRESENT	0
500145	498985	14231L	PARTICIPANT	\N	PRESENT	0
500146	498985	05008E	PARTICIPANT	\N	PRESENT	0
500147	498985	19954N	PARTICIPANT	\N	PRESENT	0
500148	498985	14041T	PARTICIPANT	\N	PRESENT	0
500149	498985	14147R	PARTICIPANT	\N	PRESENT	0
500150	498985	19749K	PARTICIPANT	\N	PRESENT	0
500155	498985	14151M	PARTICIPANT	\N	PRESENT	0
500156	498985	08018U	PARTICIPANT	\N	PRESENT	0
500157	498985	14179A	PARTICIPANT	\N	PRESENT	0
500158	498985	19489J	PARTICIPANT	\N	PRESENT	0
500193	500189	19637C	PARTICIPANT	\N	PRESENT	0
500160	498985	11072N	PARTICIPANT	\N	PRESENT	0
500161	498985	10015M	PARTICIPANT	\N	PRESENT	0
500162	498985	19585H	PARTICIPANT	\N	EXCUSE	0
500163	495438	19399H	PARTICIPANT	\N	PRESENT	0
500164	498985	01028R	PARTICIPANT	\N	EXCUSE	0
500165	498985	14089Y	PARTICIPANT	\N	PRESENT	0
500166	498985	14259Y	PARTICIPANT	\N	PRESENT	0
500167	498985	11026G	PARTICIPANT	\N	PRESENT	0
500168	498985	95063L	PARTICIPANT	\N	PRESENT	0
500169	495438	14193X	PARTICIPANT	\N	PRESENT	0
500195	500194	19637C	PARTICIPANT	\N	PRESENT	0
500197	500196	19637C	PARTICIPANT	\N	PRESENT	0
500198	497844	19333N	PARTICIPANT	\N	PRESENT	0
500199	497844	19701S	PARTICIPANT	\N	PRESENT	0
500200	497844	20076G	PARTICIPANT	\N	PRESENT	0
500201	497844	19387D	PARTICIPANT	\N	PRESENT	0
500202	497844	19820Y	PARTICIPANT	\N	PRESENT	0
500203	497844	14219Q	PRESIDENT	0	PRESENT	0
500204	497844	19599P	PARTICIPANT	\N	PRESENT	0
500205	497844	18083K	PARTICIPANT	\N	PRESENT	0
500206	497844	14237S	PARTICIPANT	\N	PRESENT	0
500207	497844	19551W	PARTICIPANT	\N	PRESENT	0
500208	497844	05012A	PARTICIPANT	\N	PRESENT	0
500209	497844	20118Y	PARTICIPANT	\N	PRESENT	0
500210	497844	19503N	PARTICIPANT	\N	PRESENT	0
500211	497844	20020P	PARTICIPANT	\N	PRESENT	0
500212	497844	20022R	PARTICIPANT	\N	PRESENT	0
500213	497844	11065P	PARTICIPANT	\N	PRESENT	0
500214	497844	20032T	PARTICIPANT	\N	PRESENT	0
500215	497844	20136B	PARTICIPANT	\N	PRESENT	0
500216	497844	14031R	PARTICIPANT	\N	PRESENT	0
500217	497844	20038A	PARTICIPANT	\N	PRESENT	0
500218	497844	20140W	PARTICIPANT	\N	PRESENT	0
500219	497844	20046A	PARTICIPANT	\N	PRESENT	0
500220	497844	14169X	PARTICIPANT	\N	PRESENT	0
500221	497844	17229F	PARTICIPANT	\N	PRESENT	0
500222	497844	20068G	PARTICIPANT	\N	PRESENT	0
500223	497844	19739H	PARTICIPANT	\N	PRESENT	0
500224	497844	19619A	PARTICIPANT	\N	PRESENT	0
500225	497844	19549D	PARTICIPANT	\N	PRESENT	0
500226	497844	19637C	PARTICIPANT	\N	PRESENT	0
500227	497844	20100N	PARTICIPANT	\N	PRESENT	0
500228	497844	08060W	PARTICIPANT	\N	PRESENT	0
500229	497844	19251M	PARTICIPANT	\N	PRESENT	0
500230	497844	11101A	PARTICIPANT	\N	PRESENT	0
500231	497844	20106U	PARTICIPANT	\N	PRESENT	0
500233	500232	19637C	PARTICIPANT	\N	PRESENT	0
500236	500234	14187A	PARTICIPANT	\N	PRESENT	0
500237	500235	14187A	PARTICIPANT	\N	PRESENT	0
500239	497846	14257W	PARTICIPANT	\N	PRESENT	0
500240	497844	19745F	PARTICIPANT	\N	PRESENT	0
500251	500242	19631V	PARTICIPANT	\N	PRESENT	0
500252	500242	14187A	PARTICIPANT	\N	PRESENT	0
500253	500242	01043Q	PARTICIPANT	\N	PRESENT	0
500254	500242	11077T	PARTICIPANT	\N	PRESENT	0
500255	500243	01043Q	PARTICIPANT	\N	PRESENT	0
500256	500243	11077T	PARTICIPANT	\N	PRESENT	0
500257	500244	01043Q	PARTICIPANT	\N	PRESENT	0
500258	500244	11077T	PARTICIPANT	\N	PRESENT	0
500259	500245	01043Q	PARTICIPANT	\N	PRESENT	0
500260	500245	11077T	PARTICIPANT	\N	PRESENT	0
500261	500246	01043Q	PARTICIPANT	\N	PRESENT	0
500262	500246	11077T	PARTICIPANT	\N	PRESENT	0
500266	500247	11077T	PARTICIPANT	\N	PRESENT	0
500268	500267	11072N	PARTICIPANT	\N	PRESENT	0
500265	500247	01043Q	PARTICIPANT	\N	PRESENT	0
500269	500248	11077T	PARTICIPANT	\N	PRESENT	0
500270	500248	14033T	PARTICIPANT	\N	PRESENT	0
500271	500248	19631V	PARTICIPANT	\N	PRESENT	0
500272	500249	01043Q	PARTICIPANT	\N	PRESENT	0
500273	500249	11077T	PARTICIPANT	\N	PRESENT	0
500274	500249	19631V	PARTICIPANT	\N	PRESENT	0
500276	500275	20108W	PARTICIPANT	\N	PRESENT	0
500277	500250	01043Q	PARTICIPANT	\N	PRESENT	0
500278	497844	19681G	PARTICIPANT	\N	EXCUSE	0
500283	495438	20050V	PARTICIPANT	\N	PRESENT	0
500290	495438	19479G	PARTICIPANT	\N	PRESENT	0
500330	497255	12041X	PARTICIPANT	\N	PRESENT	0
500334	497255	19649G	PARTICIPANT	\N	PRESENT	0
500335	497255	11074Q	PARTICIPANT	\N	PRESENT	0
500336	497255	05008E	PARTICIPANT	\N	PRESENT	0
500337	497255	04047H	PARTICIPANT	\N	PRESENT	0
500338	497255	04085P	PARTICIPANT	\N	PRESENT	0
500339	497255	19599P	PARTICIPANT	\N	PRESENT	0
500340	497255	19629C	PARTICIPANT	\N	PRESENT	0
500341	497255	19563B	PARTICIPANT	\N	PRESENT	0
500342	497255	14089Y	PARTICIPANT	\N	PRESENT	0
500343	497255	14231L	PARTICIPANT	\N	PRESENT	0
500344	497255	19543W	PARTICIPANT	\N	PRESENT	0
500345	497255	19671E	PARTICIPANT	\N	PRESENT	0
500346	497255	01028R	PARTICIPANT	\N	PRESENT	0
500347	497255	11026G	PARTICIPANT	\N	PRESENT	0
500348	497255	14151M	PARTICIPANT	\N	PRESENT	0
500349	497255	19711U	PARTICIPANT	\N	PRESENT	0
500350	497255	19687N	PARTICIPANT	\N	PRESENT	0
500351	497255	14053L	PARTICIPANT	\N	PRESENT	0
500352	497255	07033P	PARTICIPANT	\N	PRESENT	0
500353	497255	19749K	PARTICIPANT	\N	PRESENT	0
500354	497255	07029T	PARTICIPANT	\N	PRESENT	0
500355	497255	14041T	PARTICIPANT	\N	PRESENT	0
500356	497255	19447X	PARTICIPANT	\N	PRESENT	0
500357	497255	19399H	PARTICIPANT	\N	PRESENT	0
500358	497255	20106U	PARTICIPANT	\N	PRESENT	0
500359	497255	14329V	PARTICIPANT	\N	PRESENT	0
500360	497255	14021P	PARTICIPANT	\N	PRESENT	0
500361	497255	20060X	PARTICIPANT	\N	PRESENT	0
500362	497255	11033F	PARTICIPANT	\N	PRESENT	0
500363	497255	11090Q	PARTICIPANT	\N	PRESENT	0
500364	497255	19715Y	PARTICIPANT	\N	PRESENT	0
500365	497255	19741B	PARTICIPANT	\N	PRESENT	0
500366	497255	19531S	PARTICIPANT	\N	PRESENT	0
500367	497255	11048N	PARTICIPANT	\N	PRESENT	0
500368	497255	19701S	PARTICIPANT	\N	PRESENT	0
500369	497255	19954N	PARTICIPANT	\N	PRESENT	0
500370	497674	14053L	PARTICIPANT	\N	PRESENT	0
500371	497674	19649G	PARTICIPANT	\N	PRESENT	0
500372	497674	11026G	PARTICIPANT	\N	PRESENT	0
500373	497674	19543W	PARTICIPANT	\N	PRESENT	0
500374	497674	04047H	PRESIDENT	0	PRESENT	0
500375	497674	11033F	PARTICIPANT	\N	PRESENT	0
500376	497674	01028R	PARTICIPANT	\N	PRESENT	0
500377	497674	05008E	PARTICIPANT	\N	PRESENT	0
500378	497674	14231L	PARTICIPANT	\N	PRESENT	0
500379	497674	19447X	PARTICIPANT	\N	PRESENT	0
500380	497674	04085P	PARTICIPANT	\N	PRESENT	0
500381	497674	19725B	PARTICIPANT	\N	PRESENT	0
500382	497674	19954N	PARTICIPANT	\N	PRESENT	0
500383	497674	11056N	PARTICIPANT	\N	PRESENT	0
500384	497674	19629C	PARTICIPANT	\N	PRESENT	0
500385	497674	14041T	PARTICIPANT	\N	PRESENT	0
500386	497674	14151M	PARTICIPANT	\N	PRESENT	0
500387	497674	11085T	PARTICIPANT	\N	PRESENT	0
500388	497674	19749K	PARTICIPANT	\N	PRESENT	0
500389	497674	20074E	PARTICIPANT	\N	EXCUSE	0
500390	497674	19729F	PARTICIPANT	\N	EXCUSE	0
500391	497674	19585H	PARTICIPANT	\N	EXCUSE	0
500420	497992	19760E	PARTICIPANT	\N	PRESENT	0
500421	497992	19515S	PRESIDENT	0	PRESENT	0
500422	497992	19575F	PARTICIPANT	\N	PRESENT	0
500423	497992	20094J	PARTICIPANT	\N	PRESENT	0
488627	488431	89017R	PARTICIPANT	\N	EXCUSE	0
488628	488431	99004R	PARTICIPANT	\N	PRESENT	0
488629	488431	19715Y	PARTICIPANT	\N	PRESENT	0
488630	488431	04092N	PARTICIPANT	\N	EXCUSE	0
488631	488431	19683J	PARTICIPANT	\N	PRESENT	0
488632	488431	11067R	PARTICIPANT	\N	PRESENT	0
488633	488431	19503N	PARTICIPANT	\N	PRESENT	0
488634	488431	19553Y	PARTICIPANT	\N	PRESENT	0
488635	488431	11048N	PARTICIPANT	\N	PRESENT	0
488636	488431	14041T	PARTICIPANT	\N	PRESENT	0
488637	488431	11012A	PARTICIPANT	\N	EXCUSE	0
488638	488431	11097X	PRESIDENT	0	PRESENT	0
488639	488431	19703U	PARTICIPANT	\N	PRESENT	0
488640	488431	19447X	PARTICIPANT	\N	PRESENT	0
488641	488431	19479G	PARTICIPANT	\N	PRESENT	0
488642	488431	19667J	PARTICIPANT	\N	PRESENT	0
488643	488431	10006L	PARTICIPANT	\N	PRESENT	0
488644	488431	19649G	PARTICIPANT	\N	PRESENT	0
488645	488431	04059M	PARTICIPANT	\N	PRESENT	0
488646	488431	19349W	PARTICIPANT	\N	PRESENT	0
488649	488431	19643A	PARTICIPANT	\N	PRESENT	0
488650	488431	19663E	PARTICIPANT	\N	PRESENT	0
488651	488432	11097X	PRESIDENT	0	PRESENT	0
488652	488432	19503N	PARTICIPANT	\N	PRESENT	0
488653	488432	19766L	PARTICIPANT	\N	PRESENT	0
488654	488432	19715Y	PARTICIPANT	\N	PRESENT	0
488655	488432	19683J	PARTICIPANT	\N	PRESENT	0
488656	488432	19479G	PARTICIPANT	\N	PRESENT	0
488657	488432	19447X	PARTICIPANT	\N	PRESENT	0
488658	488432	99004R	PARTICIPANT	\N	PRESENT	0
488659	488432	19703U	PARTICIPANT	\N	PRESENT	0
488660	488432	89017R	PARTICIPANT	\N	EXCUSE	0
488661	488432	04092N	PARTICIPANT	\N	EXCUSE	0
488662	488432	11012A	PARTICIPANT	\N	EXCUSE	0
488663	488432	19573D	PARTICIPANT	\N	PRESENT	0
488664	488432	04059M	PARTICIPANT	\N	PRESENT	0
488665	488432	19553Y	PARTICIPANT	\N	PRESENT	0
488666	488432	14041T	PARTICIPANT	\N	PRESENT	0
488667	488432	19663E	PARTICIPANT	\N	PRESENT	0
488668	488432	19643A	PARTICIPANT	\N	PRESENT	0
488675	488674	19415P	PARTICIPANT	\N	PRESENT	0
488676	488674	11067R	PARTICIPANT	\N	PRESENT	0
489754	489753	14331P	PARTICIPANT	\N	PRESENT	0
489756	489755	14331P	PARTICIPANT	\N	PRESENT	0
489758	489757	14331P	PARTICIPANT	\N	PRESENT	0
491072	490453	08047A	PARTICIPANT	\N	PRESENT	0
491073	490453	20128B	PARTICIPANT	\N	PRESENT	0
491074	490453	14059S	PARTICIPANT	\N	PRESENT	0
491075	490453	14097Y	PARTICIPANT	\N	PRESENT	0
491076	490453	04035D	PARTICIPANT	\N	PRESENT	0
491077	490453	14133K	PARTICIPANT	\N	PRESENT	0
491078	490453	01062T	PARTICIPANT	\N	PRESENT	0
491079	490453	08069G	PARTICIPANT	\N	PRESENT	0
491080	490453	11041F	PARTICIPANT	\N	PRESENT	0
491081	490453	20042V	PARTICIPANT	\N	PRESENT	0
491082	490453	01024M	PARTICIPANT	\N	PRESENT	0
491083	490453	19721W	PRESIDENT	0	PRESENT	0
491084	490453	14105F	PARTICIPANT	\N	PRESENT	0
491085	490453	20064C	PARTICIPANT	\N	PRESENT	0
491086	490453	98022P	PARTICIPANT	\N	PRESENT	0
491087	490453	14267Y	PARTICIPANT	\N	PRESENT	0
491088	490453	11064N	PARTICIPANT	\N	PRESENT	0
491089	490453	11083R	PARTICIPANT	\N	PRESENT	0
491090	490453	19583F	PARTICIPANT	\N	PRESENT	0
491091	490453	14255U	PARTICIPANT	\N	PRESENT	0
491092	490453	17023S	PARTICIPANT	\N	PRESENT	0
491142	491141	86034E	PARTICIPANT	\N	PRESENT	0
491360	490470	20066E	PARTICIPANT	\N	PRESENT	0
491144	490451	19533U	PARTICIPANT	\N	PRESENT	0
491145	490451	14229S	PARTICIPANT	\N	PRESENT	0
491146	490451	19573D	PARTICIPANT	\N	PRESENT	0
491147	490451	08017T	PARTICIPANT	\N	PRESENT	0
491148	490451	20112S	PARTICIPANT	\N	PRESENT	0
491149	490451	08012N	PARTICIPANT	\N	PRESENT	0
491150	490451	08061X	PARTICIPANT	\N	PRESENT	0
491151	490451	20026V	PARTICIPANT	\N	PRESENT	0
491152	490451	20120S	PARTICIPANT	\N	PRESENT	0
491153	490451	19593H	PARTICIPANT	\N	PRESENT	0
491154	490451	19527W	PARTICIPANT	\N	PRESENT	0
491155	490451	20132W	PARTICIPANT	\N	PRESENT	0
491156	490451	20134Y	PARTICIPANT	\N	PRESENT	0
491157	490451	19651A	PARTICIPANT	\N	PRESENT	0
491158	490451	19611R	PRESIDENT	0	PRESENT	0
491159	490451	20142Y	PARTICIPANT	\N	PRESENT	0
491160	490451	20048C	PARTICIPANT	\N	PRESENT	0
491161	490451	19693L	PARTICIPANT	\N	PRESENT	0
491162	490451	19399H	PARTICIPANT	\N	PRESENT	0
491163	490451	20052X	PARTICIPANT	\N	PRESENT	0
491164	490451	14030Q	PARTICIPANT	\N	PRESENT	0
491165	490451	20058E	PARTICIPANT	\N	PRESENT	0
491166	490451	20056C	PARTICIPANT	\N	PRESENT	0
491167	490451	19735D	PARTICIPANT	\N	PRESENT	0
491330	490470	19697Q	PARTICIPANT	\N	PRESENT	0
491169	490451	14109K	PARTICIPANT	\N	PRESENT	0
491170	490451	14123H	PARTICIPANT	\N	PRESENT	0
491171	490451	19758L	PARTICIPANT	\N	PRESENT	0
491172	490451	17589D	PARTICIPANT	\N	PRESENT	0
491173	490451	14331P	PARTICIPANT	\N	PRESENT	0
491174	490451	19369B	PARTICIPANT	\N	PRESENT	0
491175	490451	20138D	PARTICIPANT	\N	PRESENT	0
491176	491141	11040E	PARTICIPANT	\N	PRESENT	0
491177	490451	20084G	PARTICIPANT	\N	PRESENT	0
491331	490470	11067R	PARTICIPANT	\N	PRESENT	0
491332	490470	19798U	PARTICIPANT	\N	PRESENT	0
491333	490470	19569H	PARTICIPANT	\N	PRESENT	0
491334	490470	11097X	PARTICIPANT	\N	PRESENT	0
491335	490470	19415P	PARTICIPANT	\N	PRESENT	0
491336	490470	17779H	PARTICIPANT	\N	PRESENT	0
491337	490470	11031D	PARTICIPANT	\N	PRESENT	0
491338	490470	19703U	PARTICIPANT	\N	PRESENT	0
491339	490470	14281W	PARTICIPANT	\N	PRESENT	0
491340	490470	14042U	PARTICIPANT	\N	PRESENT	0
491341	490470	19367Y	PARTICIPANT	\N	PRESENT	0
491342	490470	14213J	PARTICIPANT	\N	PRESENT	0
491343	490470	14217N	PARTICIPANT	\N	PRESENT	0
491344	490470	19683J	PARTICIPANT	\N	PRESENT	0
491345	490470	10006L	PRESIDENT	0	PRESENT	0
491346	490470	19591F	PARTICIPANT	\N	PRESENT	0
491347	490470	20130U	PARTICIPANT	\N	PRESENT	0
491348	490470	01034P	PARTICIPANT	\N	PRESENT	0
491349	490470	04057K	PARTICIPANT	\N	PRESENT	0
491350	490470	04092N	PARTICIPANT	\N	PRESENT	0
491351	490470	19713W	PARTICIPANT	\N	PRESENT	0
491352	490470	19663E	PARTICIPANT	\N	PRESENT	0
491353	490470	19301E	PARTICIPANT	\N	PRESENT	0
491354	490470	19691J	PARTICIPANT	\N	PRESENT	0
491355	490470	19717B	PARTICIPANT	\N	PRESENT	0
491356	490470	20148F	PARTICIPANT	\N	PRESENT	0
491357	490470	19723Y	PARTICIPANT	\N	PRESENT	0
491358	490470	19657G	PARTICIPANT	\N	PRESENT	0
491359	490470	19760E	PARTICIPANT	\N	PRESENT	0
491361	490470	14071N	PARTICIPANT	\N	PRESENT	0
491362	490470	14195A	PARTICIPANT	\N	EXCUSE	0
492685	489815	11090Q	PARTICIPANT	\N	PRESENT	0
492689	492688	11090Q	PARTICIPANT	\N	PRESENT	0
493000	492999	11090Q	PARTICIPANT	\N	PRESENT	0
493003	493001	11090Q	PARTICIPANT	\N	PRESENT	0
493005	493004	14357A	PARTICIPANT	\N	PRESENT	0
493006	493004	14257W	PARTICIPANT	\N	PRESENT	0
493007	493004	11090Q	PARTICIPANT	\N	PRESENT	0
493008	493004	20018V	PARTICIPANT	\N	PRESENT	0
493009	493004	11099A	PARTICIPANT	\N	PRESENT	0
493011	493010	14357A	PARTICIPANT	\N	PRESENT	0
493012	493010	20018V	PARTICIPANT	\N	PRESENT	0
493013	493010	11090Q	PARTICIPANT	\N	PRESENT	0
493014	493010	04045F	PARTICIPANT	\N	PRESENT	0
493015	493010	14257W	PARTICIPANT	\N	PRESENT	0
493016	493010	11099A	PARTICIPANT	\N	PRESENT	0
493018	493010	20024T	PARTICIPANT	\N	PRESENT	0
493023	493022	14357A	PARTICIPANT	\N	PRESENT	0
493024	493022	20018V	PARTICIPANT	\N	PRESENT	0
493025	493022	11090Q	PARTICIPANT	\N	PRESENT	0
493026	493022	04045F	PARTICIPANT	\N	PRESENT	0
493027	493022	11099A	PARTICIPANT	\N	PRESENT	0
493028	493022	14257W	PARTICIPANT	\N	PRESENT	0
493029	493022	14207L	PARTICIPANT	\N	PRESENT	0
493030	493022	19413M	PARTICIPANT	\N	PRESENT	0
493031	493022	19383Y	PARTICIPANT	\N	PRESENT	0
493032	493022	19507S	PARTICIPANT	\N	PRESENT	0
493035	493022	19782L	PARTICIPANT	\N	PRESENT	0
493037	493022	20024T	PARTICIPANT	\N	PRESENT	0
493038	493022	11065P	PARTICIPANT	\N	PRESENT	0
493039	493022	19637C	PARTICIPANT	\N	PRESENT	0
493041	493022	19503N	PARTICIPANT	\N	PRESENT	0
493042	493022	20118Y	PARTICIPANT	\N	PRESENT	0
505834	501825	14331P	PARTICIPANT	\N	PRESENT	0
505835	501825	19798U	PARTICIPANT	\N	PRESENT	0
505836	501825	20034V	PARTICIPANT	\N	PRESENT	0
505837	501825	14219Q	PARTICIPANT	\N	PRESENT	0
505838	501825	19826F	PARTICIPANT	\N	PRESENT	0
505839	501825	11040E	PARTICIPANT	\N	PRESENT	0
505840	501825	20052X	PARTICIPANT	\N	PRESENT	0
505841	501825	14038Y	PARTICIPANT	\N	PRESENT	0
505842	501825	11048N	PARTICIPANT	\N	PRESENT	0
505843	501825	14225N	PARTICIPANT	\N	PRESENT	0
505844	501825	19695N	PARTICIPANT	\N	PRESENT	0
505845	501825	07004J	PARTICIPANT	\N	PRESENT	0
505846	501825	14357A	PARTICIPANT	\N	PRESENT	0
505847	501825	01058X	PARTICIPANT	\N	PRESENT	0
505848	501825	08034U	PARTICIPANT	\N	PRESENT	0
505849	501825	10015M	PARTICIPANT	\N	PRESENT	0
505850	501825	20038A	PARTICIPANT	\N	PRESENT	0
505851	501825	19667J	PARTICIPANT	\N	PRESENT	0
505852	501825	07029T	PARTICIPANT	\N	PRESENT	0
505829	501825	86034E	PARTICIPANT	\N	PRESENT	0
505833	501825	20054A	PARTICIPANT	\N	PRESENT	0
505853	501825	19687N	PARTICIPANT	\N	PRESENT	0
505854	501825	19531S	PARTICIPANT	\N	PRESENT	0
505855	501825	20114U	PARTICIPANT	\N	PRESENT	0
505856	501825	19683J	PARTICIPANT	\N	PRESENT	0
505857	501825	20070A	PARTICIPANT	\N	PRESENT	0
505858	501825	20080C	PARTICIPANT	\N	PRESENT	0
505859	501825	14257W	PARTICIPANT	\N	PRESENT	0
505860	501825	19413M	PARTICIPANT	\N	PRESENT	0
505861	501825	14151M	PARTICIPANT	\N	PRESENT	0
505862	501825	20092G	PARTICIPANT	\N	PRESENT	0
505863	501825	20100N	PARTICIPANT	\N	PRESENT	0
505864	501825	19651A	PARTICIPANT	\N	PRESENT	0
505865	501825	19631V	PARTICIPANT	\N	PRESENT	0
505866	501825	14001X	PARTICIPANT	\N	PRESENT	0
505867	501825	11012A	PARTICIPANT	\N	PRESENT	0
505868	501825	14207L	PARTICIPANT	\N	PRESENT	0
505870	501825	19545Y	PARTICIPANT	\N	PRESENT	0
505871	501825	01028R	PARTICIPANT	\N	PRESENT	0
505872	501825	19349W	PARTICIPANT	\N	PRESENT	0
505873	501825	19647E	PARTICIPANT	\N	PRESENT	0
505874	501825	19441R	PARTICIPANT	\N	PRESENT	0
505875	501825	14327T	PARTICIPANT	\N	PRESENT	0
505876	501825	19739H	PARTICIPANT	\N	PRESENT	0
505877	501825	11053K	PARTICIPANT	\N	PRESENT	0
505878	501825	20116W	PARTICIPANT	\N	PRESENT	0
505879	501825	12041X	PARTICIPANT	\N	PRESENT	0
505880	501825	19543W	PARTICIPANT	\N	PRESENT	0
505881	501825	19745F	PARTICIPANT	\N	PRESENT	0
505882	501825	14021P	PARTICIPANT	\N	PRESENT	0
505883	501825	19689Q	PARTICIPANT	\N	PRESENT	0
505884	501825	12028B	PARTICIPANT	\N	PRESENT	0
505885	501825	19515S	PARTICIPANT	\N	PRESENT	0
506190	506188	11066Q	PARTICIPANT	\N	PRESENT	0
505887	501825	19335Q	PARTICIPANT	\N	PRESENT	0
505888	501825	19741B	PARTICIPANT	\N	PRESENT	0
505889	501825	20044X	PARTICIPANT	\N	PRESENT	0
505890	501825	19671E	PARTICIPANT	\N	PRESENT	0
505891	501825	18083K	PARTICIPANT	\N	PRESENT	0
505892	501825	20126Y	PARTICIPANT	\N	PRESENT	0
505893	501825	19399H	PARTICIPANT	\N	PRESENT	0
505894	501825	19347U	PARTICIPANT	\N	PRESENT	0
505895	501825	11083R	PARTICIPANT	\N	PRESENT	0
505896	501825	19711U	PARTICIPANT	\N	PRESENT	0
505897	501825	04086Q	PARTICIPANT	\N	PRESENT	0
505898	501825	11070L	PARTICIPANT	\N	PRESENT	0
505899	501825	20084G	PARTICIPANT	\N	PRESENT	0
505900	501825	20096L	PARTICIPANT	\N	PRESENT	0
505901	501825	20150Y	PARTICIPANT	\N	PRESENT	0
505902	501825	19691J	PARTICIPANT	\N	PRESENT	0
505903	501825	19701S	PARTICIPANT	\N	PRESENT	0
505904	501825	08015R	PARTICIPANT	\N	PRESENT	0
505905	501825	01057W	PARTICIPANT	\N	PRESENT	0
505906	501825	01024M	PARTICIPANT	\N	PRESENT	0
505907	501825	19467C	PARTICIPANT	\N	PRESENT	0
505908	501825	04033B	PARTICIPANT	\N	PRESENT	0
505909	501825	20118Y	PARTICIPANT	\N	PRESENT	0
505910	501825	14189C	PARTICIPANT	\N	PRESENT	0
505911	501825	19479G	PARTICIPANT	\N	PRESENT	0
505912	501825	11031D	PARTICIPANT	\N	PRESENT	0
505916	501825	14249W	PARTICIPANT	\N	PRESENT	0
505917	501825	19657G	PARTICIPANT	\N	PRESENT	0
505918	501825	19503N	PARTICIPANT	\N	PRESENT	0
505919	501825	19762G	PARTICIPANT	\N	PRESENT	0
505922	501825	14083S	PARTICIPANT	\N	PRESENT	0
505927	501825	04071H	PARTICIPANT	\N	PRESENT	0
505932	501825	14231L	PARTICIPANT	\N	PRESENT	0
505933	501825	14179A	PARTICIPANT	\N	PRESENT	0
505934	501825	08011M	PARTICIPANT	\N	PRESENT	0
505935	501825	19717B	PARTICIPANT	\N	PRESENT	0
505936	501825	14211G	PARTICIPANT	\N	PRESENT	0
505937	501825	11056N	PARTICIPANT	\N	PRESENT	0
505938	501825	19758L	PARTICIPANT	\N	PRESENT	0
505941	501825	04085P	PARTICIPANT	\N	PRESENT	0
505942	501825	20066E	PARTICIPANT	\N	PRESENT	0
505943	501825	14187A	PARTICIPANT	\N	PRESENT	0
505946	501825	14133K	PARTICIPANT	\N	PRESENT	0
505947	501825	11064N	PARTICIPANT	\N	PRESENT	0
505948	501825	08010L	PARTICIPANT	\N	PRESENT	0
505949	501825	19954N	PARTICIPANT	\N	PRESENT	0
505953	496311	14193X	PARTICIPANT	\N	PRESENT	0
505955	501825	20022R	PARTICIPANT	\N	PRESENT	0
505956	501825	20042V	PARTICIPANT	\N	PRESENT	0
505961	501825	20020P	PARTICIPANT	\N	PRESENT	0
505962	501825	12016W	PARTICIPANT	\N	PRESENT	0
505964	501825	19593H	PARTICIPANT	\N	PRESENT	0
505965	496311	19479G	PARTICIPANT	\N	PRESENT	0
505966	496311	19295A	PARTICIPANT	\N	EXCUSE	0
505974	501825	95063L	PARTICIPANT	\N	PRESENT	0
506003	501825	99004R	PARTICIPANT	\N	PRESENT	0
506006	501825	19621T	PARTICIPANT	\N	PRESENT	0
506007	501825	14259Y	PARTICIPANT	\N	PRESENT	0
506008	501825	19521Q	PARTICIPANT	\N	PRESENT	0
506009	501825	17367Q	PARTICIPANT	\N	PRESENT	0
506010	501825	08061X	PARTICIPANT	\N	PRESENT	0
506011	501825	20132W	PARTICIPANT	\N	PRESENT	0
506189	506188	14133K	PARTICIPANT	\N	PRESENT	0
506192	506191	14133K	PARTICIPANT	\N	PRESENT	0
506193	506191	11066Q	PARTICIPANT	\N	PRESENT	0
506195	506194	14133K	PARTICIPANT	\N	PRESENT	0
506196	506194	11066Q	PARTICIPANT	\N	PRESENT	0
506199	506198	11048N	PARTICIPANT	\N	PRESENT	0
506210	506209	04043D	PARTICIPANT	\N	PRESENT	0
506212	506211	04043D	PARTICIPANT	\N	PRESENT	0
506215	506214	19333N	PARTICIPANT	\N	PRESENT	0
506216	506214	18083K	PARTICIPANT	\N	PRESENT	0
506218	506217	18083K	PARTICIPANT	\N	PRESENT	0
506219	506217	19333N	PARTICIPANT	\N	PRESENT	0
506281	506280	14187A	PARTICIPANT	\N	PRESENT	0
506320	506316	20034V	PARTICIPANT	\N	PRESENT	0
506663	506662	11048N	PARTICIPANT	\N	PRESENT	0
506680	506679	04085P	PARTICIPANT	\N	PRESENT	0
506681	506679	05008E	PARTICIPANT	\N	PRESENT	0
506682	506679	04042C	PARTICIPANT	\N	PRESENT	0
506683	506679	11070L	PARTICIPANT	\N	PRESENT	0
506684	506679	19719D	PARTICIPANT	\N	PRESENT	0
506685	506679	10006L	PARTICIPANT	\N	PRESENT	0
506686	506679	14215L	PARTICIPANT	\N	PRESENT	0
506687	506679	19347U	PARTICIPANT	\N	PRESENT	0
506688	506679	14026U	PARTICIPANT	\N	PRESENT	0
506689	506679	11048N	PARTICIPANT	\N	PRESENT	0
506690	506679	14021P	PARTICIPANT	\N	PRESENT	0
506691	506679	99004R	PARTICIPANT	\N	PRESENT	0
506692	506679	19611R	PARTICIPANT	\N	PRESENT	0
506694	506679	12041X	PARTICIPANT	\N	PRESENT	0
506696	506679	01043Q	PARTICIPANT	\N	PRESENT	0
506697	506679	14219Q	PARTICIPANT	\N	PRESENT	0
506698	506679	14251Q	PARTICIPANT	\N	PRESENT	0
506699	506679	11085T	PARTICIPANT	\N	PRESENT	0
506700	506679	08061X	PARTICIPANT	\N	PRESENT	0
506701	506679	11090Q	PARTICIPANT	\N	PRESENT	0
506702	506679	14225N	PARTICIPANT	\N	PRESENT	0
506703	506679	10015M	PARTICIPANT	\N	PRESENT	0
506704	506679	11012A	PARTICIPANT	\N	PRESENT	0
506705	506679	04033B	PARTICIPANT	\N	PRESENT	0
506706	506679	11045K	PARTICIPANT	\N	PRESENT	0
506717	496311	04070G	PARTICIPANT	\N	EXCUSE	0
506855	506853	19333N	PARTICIPANT	\N	PRESENT	0
506856	506851	14169X	PARTICIPANT	\N	PRESENT	0
506857	506852	14169X	PARTICIPANT	\N	PRESENT	0
483220	483219	04092N	PRESIDENT	0	PRESENT	0
483221	483219	19679N	PARTICIPANT	\N	PRESENT	0
483222	483219	14026U	PARTICIPANT	\N	PRESENT	0
483223	483219	19691J	PARTICIPANT	\N	PRESENT	0
483224	483219	08052W	PARTICIPANT	\N	PRESENT	0
483225	483219	19683J	PARTICIPANT	\N	PRESENT	0
483226	483219	19697Q	PARTICIPANT	\N	PRESENT	0
483227	483219	10006L	PARTICIPANT	\N	PRESENT	0
483228	483219	11067R	PARTICIPANT	\N	PRESENT	0
483239	483238	14207L	PARTICIPANT	\N	PRESENT	0
483240	481129	11099A	PARTICIPANT	\N	PRESENT	0
483241	481129	19441R	PARTICIPANT	\N	PRESENT	0
483242	481129	19912C	PARTICIPANT	\N	PRESENT	0
484901	484900	19647E	PARTICIPANT	\N	PRESENT	0
489348	489346	08043V	PARTICIPANT	\N	PRESENT	0
485077	482485	08049C	PARTICIPANT	\N	PRESENT	0
489347	489346	14030Q	PARTICIPANT	\N	PRESENT	0
489349	489346	19643A	PARTICIPANT	\N	EXCUSE	0
489350	489346	19621T	PARTICIPANT	\N	PRESENT	0
489351	489346	19701S	PARTICIPANT	\N	PRESENT	0
489352	489346	11031D	PARTICIPANT	\N	PRESENT	0
489353	489346	19693L	PARTICIPANT	\N	PRESENT	0
489354	489346	14217N	PARTICIPANT	\N	EXCUSE	0
489355	489346	19599P	PARTICIPANT	\N	PRESENT	0
489356	489346	14179A	PARTICIPANT	\N	EXCUSE	0
489357	489346	19715Y	PARTICIPANT	\N	PRESENT	0
489358	489346	19731Y	PARTICIPANT	\N	PRESENT	0
489359	489346	07029T	PARTICIPANT	\N	EXCUSE	0
489360	489346	08017T	PARTICIPANT	\N	PRESENT	0
489361	489346	19679N	PARTICIPANT	\N	EXCUSE	0
489362	489346	11045K	PARTICIPANT	\N	PRESENT	0
489364	489363	14030Q	PARTICIPANT	\N	PRESENT	0
489365	489363	19621T	PARTICIPANT	\N	PRESENT	0
489366	489363	19701S	PARTICIPANT	\N	PRESENT	0
489367	489363	11031D	PARTICIPANT	\N	PRESENT	0
489368	489363	19693L	PARTICIPANT	\N	PRESENT	0
489369	489363	19599P	PARTICIPANT	\N	PRESENT	0
489370	489363	08017T	PARTICIPANT	\N	PRESENT	0
492638	491415	04033B	PARTICIPANT	\N	PRESENT	0
492639	491415	01043Q	PARTICIPANT	\N	PRESENT	0
492640	491415	14030Q	PARTICIPANT	\N	PRESENT	0
492641	491415	05008E	PARTICIPANT	\N	PRESENT	0
492642	491415	04071H	PARTICIPANT	\N	PRESENT	0
492643	491415	20080C	PARTICIPANT	\N	PRESENT	0
492644	491415	19489J	PARTICIPANT	\N	PRESENT	0
492645	491415	14259Y	PARTICIPANT	\N	PRESENT	0
492646	491415	19581D	PARTICIPANT	\N	PRESENT	0
492648	491415	14213J	PARTICIPANT	\N	PRESENT	0
492649	491415	19643A	PARTICIPANT	\N	PRESENT	0
492650	491415	16685X	PARTICIPANT	\N	PRESENT	0
492651	491415	14083S	PARTICIPANT	\N	PRESENT	0
492653	491415	20076G	PARTICIPANT	\N	PRESENT	0
492654	491415	20138D	PARTICIPANT	\N	PRESENT	0
492655	491415	19693L	PARTICIPANT	\N	PRESENT	0
492656	491415	20140W	PARTICIPANT	\N	PRESENT	0
492657	491415	19711U	PARTICIPANT	\N	PRESENT	0
492658	491415	11101A	PARTICIPANT	\N	PRESENT	0
492659	491415	14026U	PARTICIPANT	\N	PRESENT	0
492660	491415	04047H	PARTICIPANT	\N	PRESENT	0
492661	491415	19747H	PARTICIPANT	\N	PRESENT	0
492662	491415	04086Q	PARTICIPANT	\N	PRESENT	0
492663	491415	19415P	PARTICIPANT	\N	PRESENT	0
492664	491415	04042C	PARTICIPANT	\N	PRESENT	0
492665	491415	14123H	PARTICIPANT	\N	PRESENT	0
492666	491415	20078J	PARTICIPANT	\N	PRESENT	0
492667	491415	20152B	PARTICIPANT	\N	PRESENT	0
492668	491415	19741B	PARTICIPANT	\N	PRESENT	0
492669	491415	19507S	PARTICIPANT	\N	PRESENT	0
492670	491415	14031R	PARTICIPANT	\N	PRESENT	0
492671	491415	04085P	PARTICIPANT	\N	PRESENT	0
492672	491415	20104S	PARTICIPANT	\N	PRESENT	0
492673	491415	19533U	PARTICIPANT	\N	PRESENT	0
492674	491415	19954N	PARTICIPANT	\N	PRESENT	0
492675	491415	19383Y	PARTICIPANT	\N	PRESENT	0
492676	491415	17367Q	PARTICIPANT	\N	PRESENT	0
492677	491415	86034E	PARTICIPANT	\N	PRESENT	0
492678	491415	20100N	PARTICIPANT	\N	PRESENT	0
492679	491415	08073C	PARTICIPANT	\N	PRESENT	0
492680	491415	97011G	PARTICIPANT	\N	PRESENT	0
492681	491415	08056B	PARTICIPANT	\N	PRESENT	0
492682	491415	14033T	PARTICIPANT	\N	PRESENT	0
492683	491415	20120S	PARTICIPANT	\N	PRESENT	0
492684	491415	07004J	PARTICIPANT	\N	PRESENT	0
492686	491415	14193X	PARTICIPANT	\N	PRESENT	0
492687	491415	08047A	PARTICIPANT	\N	PRESENT	0
492690	491415	14147R	PARTICIPANT	\N	PRESENT	0
492693	492692	04070G	PARTICIPANT	\N	PRESENT	0
492694	492692	19593H	PARTICIPANT	\N	PRESENT	0
492695	492692	19735D	PARTICIPANT	\N	PRESENT	0
492700	491415	19649G	PARTICIPANT	\N	PRESENT	0
492895	491417	12041X	PARTICIPANT	\N	PRESENT	0
492920	491417	04047H	PARTICIPANT	\N	PRESENT	0
492921	491417	19673G	PARTICIPANT	\N	PRESENT	0
492922	491417	20034V	PARTICIPANT	\N	PRESENT	0
492925	491417	19695N	PARTICIPANT	\N	PRESENT	0
492926	491417	20052X	PARTICIPANT	\N	PRESENT	0
492928	491417	04085P	PARTICIPANT	\N	PRESENT	0
492929	491417	14215L	PARTICIPANT	\N	PRESENT	0
492930	491417	19447X	PARTICIPANT	\N	PRESENT	0
492931	491417	95063L	PARTICIPANT	\N	PRESENT	0
492932	491417	19954N	PARTICIPANT	\N	PRESENT	0
492933	491417	14147R	PARTICIPANT	\N	PRESENT	0
492934	491417	20074E	PARTICIPANT	\N	PRESENT	0
492935	491417	20090E	PARTICIPANT	\N	PRESENT	0
492936	491417	19711U	PARTICIPANT	\N	PRESENT	0
492937	491417	04042C	PARTICIPANT	\N	PRESENT	0
492938	491417	14207L	PARTICIPANT	\N	PRESENT	0
492939	491417	19782L	PARTICIPANT	\N	PRESENT	0
492940	491417	11033F	PARTICIPANT	\N	PRESENT	0
492941	491417	11056N	PARTICIPANT	\N	PRESENT	0
492942	491417	19565D	PARTICIPANT	\N	PRESENT	0
492943	491417	04008A	PARTICIPANT	\N	PRESENT	0
492944	491417	01058X	PARTICIPANT	\N	PRESENT	0
492945	491417	11012A	PARTICIPANT	\N	PRESENT	0
492946	491417	14111D	PARTICIPANT	\N	PRESENT	0
492947	491417	11026G	PARTICIPANT	\N	PRESENT	0
492948	491417	19543W	PARTICIPANT	\N	PRESENT	0
492949	491417	99004R	PARTICIPANT	\N	PRESENT	0
492950	491417	19415P	PARTICIPANT	\N	PRESENT	0
492951	491417	14089Y	PARTICIPANT	\N	PRESENT	0
492952	491417	19533U	PARTICIPANT	\N	PRESENT	0
492953	491417	14038Y	PARTICIPANT	\N	PRESENT	0
492954	491417	19762G	PARTICIPANT	\N	PRESENT	0
492955	491417	19553Y	PARTICIPANT	\N	PRESENT	0
492956	491417	20120S	PARTICIPANT	\N	PRESENT	0
492957	491417	19749K	PARTICIPANT	\N	PRESENT	0
492958	491417	20038A	PARTICIPANT	\N	PRESENT	0
492959	491417	19383Y	PARTICIPANT	\N	PRESENT	0
492963	491417	01028R	PARTICIPANT	\N	PRESENT	0
492964	491417	11048N	PARTICIPANT	\N	PRESENT	0
492992	491417	14151M	PARTICIPANT	\N	PRESENT	0
492993	491417	14179A	PARTICIPANT	\N	PRESENT	0
492994	491417	19333N	PARTICIPANT	\N	PRESENT	0
492995	491417	14033T	PARTICIPANT	\N	PRESENT	0
492997	491417	20092G	PARTICIPANT	\N	PRESENT	0
492998	491417	05008E	PARTICIPANT	\N	PRESENT	0
493002	491417	18083K	PARTICIPANT	\N	PRESENT	0
493019	491417	11072N	PARTICIPANT	\N	PRESENT	0
493020	491417	20018V	PARTICIPANT	\N	PRESENT	0
493033	491417	17737W	PARTICIPANT	\N	PRESENT	0
493034	491417	17583W	PARTICIPANT	\N	PRESENT	0
493036	491417	20084G	PARTICIPANT	\N	PRESENT	0
493040	491417	11053K	PARTICIPANT	\N	PRESENT	0
493043	491417	20094J	PARTICIPANT	\N	PRESENT	0
493044	491417	20134Y	PARTICIPANT	\N	PRESENT	0
493045	491417	14217N	PARTICIPANT	\N	PRESENT	0
493046	491417	20066E	PARTICIPANT	\N	PRESENT	0
493047	491417	14097Y	PARTICIPANT	\N	PRESENT	0
493048	491417	11097X	PARTICIPANT	\N	PRESENT	0
493049	491417	10006L	PARTICIPANT	\N	PRESENT	0
493051	491417	20110Q	PARTICIPANT	\N	PRESENT	0
493061	491417	14193X	PARTICIPANT	\N	PRESENT	0
500424	497992	14105F	PARTICIPANT	\N	PRESENT	0
500425	497992	14083S	PARTICIPANT	\N	PRESENT	0
500426	497992	14329V	PARTICIPANT	\N	PRESENT	0
500427	497992	14195A	PARTICIPANT	\N	PRESENT	0
500428	497992	19467C	PARTICIPANT	\N	PRESENT	0
500429	497992	14041T	PARTICIPANT	\N	PRESENT	0
500430	497992	19251M	PARTICIPANT	\N	PRESENT	0
500432	497992	20134Y	PARTICIPANT	\N	PRESENT	0
500437	497992	19695N	PARTICIPANT	\N	PRESENT	0
500438	497992	20126Y	PARTICIPANT	\N	PRESENT	0
500439	497992	08015R	PARTICIPANT	\N	PRESENT	0
500440	497992	16685X	PARTICIPANT	\N	PRESENT	0
500443	497992	14031R	PARTICIPANT	\N	PRESENT	0
500444	497992	19679N	PARTICIPANT	\N	PRESENT	0
500445	497992	20082E	PARTICIPANT	\N	PRESENT	0
500449	497992	08060W	PARTICIPANT	\N	EXCUSE	0
500447	497992	20054A	PARTICIPANT	\N	PRESENT	0
500448	497992	19301E	PARTICIPANT	\N	PRESENT	0
500450	497992	19545Y	PARTICIPANT	\N	EXCUSE	0
500451	497992	08028W	PARTICIPANT	\N	EXCUSE	0
500452	497992	20040T	PARTICIPANT	\N	EXCUSE	0
500453	497992	20048C	PARTICIPANT	\N	EXCUSE	0
500454	497992	19671E	PARTICIPANT	\N	EXCUSE	0
500508	500507	14225N	PARTICIPANT	\N	PRESENT	0
500509	500507	01057W	PARTICIPANT	\N	PRESENT	0
500511	500510	14225N	PARTICIPANT	\N	PRESENT	0
500513	500512	19647E	PARTICIPANT	\N	PRESENT	0
500515	500514	19647E	PARTICIPANT	\N	PRESENT	0
500516	500514	11070L	PARTICIPANT	\N	PRESENT	0
500518	500517	14253S	PARTICIPANT	\N	PRESENT	0
500519	500517	08011M	PARTICIPANT	\N	PRESENT	0
500521	500520	14253S	PARTICIPANT	\N	PRESENT	0
500522	500520	08011M	PARTICIPANT	\N	PRESENT	0
500524	500523	14253S	PARTICIPANT	\N	PRESENT	0
500525	500523	08011M	PARTICIPANT	\N	PRESENT	0
500527	500526	14253S	PARTICIPANT	\N	PRESENT	0
500528	500526	08011M	PARTICIPANT	\N	PRESENT	0
500530	500529	08011M	PARTICIPANT	\N	PRESENT	0
500532	500531	20050V	PARTICIPANT	\N	PRESENT	0
500534	500533	20050V	PARTICIPANT	\N	PRESENT	0
500536	500535	14331P	PARTICIPANT	\N	PRESENT	0
500539	500538	08034U	PARTICIPANT	\N	PRESENT	0
500541	500540	08034U	PARTICIPANT	\N	PRESENT	0
500543	500542	08034U	PARTICIPANT	\N	PRESENT	0
500545	500544	08034U	PARTICIPANT	\N	PRESENT	0
500547	500546	14327T	PARTICIPANT	\N	PRESENT	0
500549	500548	14327T	PARTICIPANT	\N	PRESENT	0
500551	500550	14327T	PARTICIPANT	\N	PRESENT	0
500558	500554	19667J	PARTICIPANT	\N	PRESENT	0
500559	500554	11040E	PARTICIPANT	\N	PRESENT	0
500564	500563	11048N	PARTICIPANT	\N	PRESENT	0
500565	500563	14225N	PARTICIPANT	\N	PRESENT	0
500568	500567	20050V	PARTICIPANT	\N	PRESENT	0
500574	500573	11048N	PARTICIPANT	\N	PRESENT	0
500577	500576	12016W	PARTICIPANT	\N	PRESENT	0
500579	500578	12016W	PARTICIPANT	\N	PRESENT	0
500581	500580	11048N	PARTICIPANT	\N	PRESENT	0
500583	500582	08009T	PARTICIPANT	\N	PRESENT	0
500584	500582	20044X	PARTICIPANT	\N	PRESENT	0
500586	500585	08009T	PARTICIPANT	\N	PRESENT	0
500587	500585	20044X	PARTICIPANT	\N	PRESENT	0
500589	500588	08009T	PARTICIPANT	\N	PRESENT	0
500590	500588	20044X	PARTICIPANT	\N	PRESENT	0
500595	500407	19697Q	PARTICIPANT	\N	PRESENT	0
500596	500407	20090E	PARTICIPANT	\N	PRESENT	0
500597	500407	11067R	PARTICIPANT	\N	PRESENT	0
500598	500407	19798U	PARTICIPANT	\N	PRESENT	0
500599	500407	11097X	PARTICIPANT	\N	PRESENT	0
500600	500407	14026U	PARTICIPANT	\N	PRESENT	0
500601	500407	17779H	PARTICIPANT	\N	PRESENT	0
500602	500407	19553Y	PARTICIPANT	\N	PRESENT	0
500603	500407	11031D	PARTICIPANT	\N	PRESENT	0
500604	500407	19679N	PARTICIPANT	\N	PRESENT	0
500605	500407	14042U	PARTICIPANT	\N	PRESENT	0
500606	500407	14195A	PARTICIPANT	\N	PRESENT	0
500607	500407	14213J	PARTICIPANT	\N	PRESENT	0
500608	500407	14217N	PARTICIPANT	\N	PRESENT	0
500609	500407	10006L	PARTICIPANT	\N	PRESENT	0
500610	500407	19683J	PARTICIPANT	\N	PRESENT	0
500611	500407	19591F	PARTICIPANT	\N	PRESENT	0
500612	500407	20130U	PARTICIPANT	\N	PRESENT	0
500613	500407	01034P	PARTICIPANT	\N	PRESENT	0
500614	500407	04057K	PARTICIPANT	\N	PRESENT	0
500615	500407	04092N	PARTICIPANT	\N	PRESENT	0
500616	500407	19713W	PARTICIPANT	\N	PRESENT	0
500617	500407	19663E	PARTICIPANT	\N	PRESENT	0
500618	500407	19301E	PARTICIPANT	\N	PRESENT	0
500619	500407	17965H	PARTICIPANT	\N	PRESENT	0
500620	500407	19691J	PARTICIPANT	\N	PRESENT	0
500621	500407	19715Y	PARTICIPANT	\N	PRESENT	0
500622	500407	19723Y	PARTICIPANT	\N	PRESENT	0
500623	500407	11103C	PARTICIPANT	\N	PRESENT	0
500624	500407	14071N	PARTICIPANT	\N	PRESENT	0
500625	500407	19657G	PARTICIPANT	\N	PRESENT	0
500626	500407	04043D	PARTICIPANT	\N	PRESENT	0
500627	500407	19760E	PARTICIPANT	\N	PRESENT	0
500628	500407	14355X	PARTICIPANT	\N	EXCUSE	0
500741	500279	11031D	PARTICIPANT	\N	PRESENT	0
500742	500279	19569H	PARTICIPANT	\N	PRESENT	0
500743	500279	20152B	PARTICIPANT	\N	PRESENT	0
500747	500279	19683J	PARTICIPANT	\N	PRESENT	0
500748	500279	20130U	PARTICIPANT	\N	PRESENT	0
500749	500279	14041T	PARTICIPANT	\N	PRESENT	0
500750	500279	17965H	PARTICIPANT	\N	PRESENT	0
500751	500279	14281W	PARTICIPANT	\N	PRESENT	0
500752	500279	11067R	PARTICIPANT	\N	PRESENT	0
500753	500279	11103C	PARTICIPANT	\N	PRESENT	0
500754	500279	14213J	PARTICIPANT	\N	PRESENT	0
500755	500279	19695N	PARTICIPANT	\N	PRESENT	0
500756	500279	20112S	PARTICIPANT	\N	PRESENT	0
500757	500279	04085P	PARTICIPANT	\N	PRESENT	0
500758	500279	17779H	PARTICIPANT	\N	PRESENT	0
500759	500279	10006L	PARTICIPANT	\N	PRESENT	0
500760	500279	19387D	PARTICIPANT	\N	PRESENT	0
500761	500279	19760E	PARTICIPANT	\N	PRESENT	0
500762	500279	95063L	PARTICIPANT	\N	PRESENT	0
500763	500279	19697Q	PARTICIPANT	\N	PRESENT	0
500764	500279	11033F	PARTICIPANT	\N	PRESENT	0
500765	500279	19687N	PARTICIPANT	\N	PRESENT	0
500766	500279	20038A	PARTICIPANT	\N	PRESENT	0
500767	500279	19717B	PARTICIPANT	\N	PRESENT	0
500768	500279	14195A	PARTICIPANT	\N	PRESENT	0
500769	500279	14026U	PARTICIPANT	\N	PRESENT	0
500770	500279	20090E	PARTICIPANT	\N	PRESENT	0
500771	500279	11097X	PARTICIPANT	\N	PRESENT	0
500772	500279	19723Y	PARTICIPANT	\N	PRESENT	0
500773	500279	19301E	PARTICIPANT	\N	PRESENT	0
500774	500279	19691J	PARTICIPANT	\N	PRESENT	0
500775	500279	18193Q	PARTICIPANT	\N	PRESENT	0
500776	500279	19591F	PARTICIPANT	\N	PRESENT	0
500777	500279	14042U	PARTICIPANT	\N	PRESENT	0
500778	500279	20034V	PARTICIPANT	\N	PRESENT	0
500779	500279	14217N	PARTICIPANT	\N	PRESENT	0
500780	500279	14107H	PARTICIPANT	\N	PRESENT	0
500781	500279	14071N	PARTICIPANT	\N	PRESENT	0
500782	500279	19703U	PARTICIPANT	\N	PRESENT	0
500783	500279	19679N	PARTICIPANT	\N	PRESENT	0
500784	500279	14123H	PARTICIPANT	\N	PRESENT	0
500785	500279	01034P	PARTICIPANT	\N	PRESENT	0
500786	500279	04092N	PARTICIPANT	\N	PRESENT	0
500787	500279	20126Y	PARTICIPANT	\N	PRESENT	0
500788	500279	19657G	PARTICIPANT	\N	PRESENT	0
500789	500279	19553Y	PARTICIPANT	\N	PRESENT	0
500790	500279	08045X	PARTICIPANT	\N	PRESENT	0
500791	500279	14021P	PARTICIPANT	\N	PRESENT	0
500792	500279	08061X	PARTICIPANT	\N	PRESENT	0
500793	500279	19715Y	PARTICIPANT	\N	PRESENT	0
500794	500279	04043D	PARTICIPANT	\N	PRESENT	0
500805	500408	19697Q	PARTICIPANT	\N	PRESENT	0
500796	500279	14187A	PARTICIPANT	\N	PRESENT	0
500801	500279	20134Y	PARTICIPANT	\N	PRESENT	0
500806	500408	11067R	PARTICIPANT	\N	PRESENT	0
500807	500408	20090E	PARTICIPANT	\N	PRESENT	0
500808	500408	11097X	PARTICIPANT	\N	PRESENT	0
500809	500408	18193Q	PARTICIPANT	\N	PRESENT	0
500810	500408	14026U	PARTICIPANT	\N	PRESENT	0
500811	500408	11031D	PARTICIPANT	\N	PRESENT	0
500812	500408	19703U	PARTICIPANT	\N	PRESENT	0
500813	500408	19553Y	PARTICIPANT	\N	PRESENT	0
500814	500408	14281W	PARTICIPANT	\N	PRESENT	0
500815	500408	19679N	PARTICIPANT	\N	PRESENT	0
500816	500408	14042U	PARTICIPANT	\N	PRESENT	0
500817	500408	14195A	PARTICIPANT	\N	PRESENT	0
500818	500408	14213J	PARTICIPANT	\N	PRESENT	0
500819	500408	14217N	PARTICIPANT	\N	PRESENT	0
500820	500408	19683J	PARTICIPANT	\N	PRESENT	0
500821	500408	10006L	PRESIDENT	1	PRESENT	0
500822	500408	20130U	PARTICIPANT	\N	PRESENT	0
500823	500408	01034P	PARTICIPANT	\N	PRESENT	0
483277	481575	19717B	PARTICIPANT	\N	PRESENT	0
483278	481575	96004D	PARTICIPANT	\N	EXCUSE	0
483279	481575	19577H	PARTICIPANT	\N	PRESENT	0
483280	481575	19715Y	PARTICIPANT	\N	PRESENT	0
483281	481575	12016W	PARTICIPANT	\N	PRESENT	0
483282	481575	19657G	PARTICIPANT	\N	PRESENT	0
483283	481575	11072N	PARTICIPANT	\N	PRESENT	0
483284	481575	08073C	PARTICIPANT	\N	PRESENT	0
483285	481575	19301E	PARTICIPANT	\N	EXCUSE	0
483288	483286	08012N	PARTICIPANT	\N	PRESENT	0
483289	483286	02002K	PARTICIPANT	\N	PRESENT	0
483290	483286	11043H	PARTICIPANT	\N	PRESENT	0
483291	483286	19399H	PARTICIPANT	\N	PRESENT	0
483293	483287	11043H	PARTICIPANT	\N	PRESENT	0
483294	483287	19711U	PARTICIPANT	\N	PRESENT	0
483295	483287	14147R	PARTICIPANT	\N	PRESENT	0
483296	483287	08012N	PRESIDENT	0	PRESENT	0
483297	483287	02002K	PARTICIPANT	\N	PRESENT	0
483298	483287	19349W	PARTICIPANT	\N	PRESENT	0
483306	481408	14197C	PARTICIPANT	\N	PRESENT	0
483307	481408	19611R	PRESIDENT	0	PRESENT	0
483308	481408	14097Y	PARTICIPANT	\N	PRESENT	0
483309	481408	11048N	PARTICIPANT	\N	PRESENT	0
483310	481408	19735D	PARTICIPANT	\N	PRESENT	0
483311	481408	14031R	PARTICIPANT	\N	PRESENT	0
483312	481408	19687N	PARTICIPANT	\N	PRESENT	0
483313	481408	19549D	PARTICIPANT	\N	PRESENT	0
486752	486748	19415P	PARTICIPANT	\N	PRESENT	0
486753	486749	19415P	PARTICIPANT	\N	PRESENT	0
486754	486749	11067R	PARTICIPANT	\N	PRESENT	0
486755	486750	19415P	PARTICIPANT	\N	PRESENT	0
486756	486750	11067R	PARTICIPANT	\N	PRESENT	0
486757	486751	19415P	PARTICIPANT	\N	PRESENT	0
486758	486751	11067R	PARTICIPANT	\N	PRESENT	0
486761	486759	11067R	PARTICIPANT	\N	PRESENT	0
486763	486762	14255U	PARTICIPANT	\N	PRESENT	0
486764	486762	19553Y	PARTICIPANT	\N	PRESENT	0
486765	486762	97011G	PARTICIPANT	\N	PRESENT	0
486766	486762	19551W	PARTICIPANT	\N	PRESENT	0
486767	486762	19335Q	PARTICIPANT	\N	PRESENT	0
486768	486762	01062T	PARTICIPANT	\N	PRESENT	0
486769	486762	19637C	PARTICIPANT	\N	PRESENT	0
486771	486770	14229S	PARTICIPANT	\N	PRESENT	0
486772	486770	19399H	PARTICIPANT	\N	PRESENT	0
486773	486760	11067R	PARTICIPANT	\N	PRESENT	0
488515	488428	11097X	PRESIDENT	0	PRESENT	0
488516	488428	10006L	PARTICIPANT	\N	PRESENT	0
488517	488428	19479G	PARTICIPANT	\N	PRESENT	0
488518	488428	11031D	PARTICIPANT	\N	PRESENT	0
488519	488428	11067R	PARTICIPANT	\N	PRESENT	0
488520	488428	19667J	PARTICIPANT	\N	PRESENT	0
488521	488428	19649G	PARTICIPANT	\N	PRESENT	0
488522	488428	19683J	PARTICIPANT	\N	PRESENT	0
488523	488428	99004R	PARTICIPANT	\N	PRESENT	0
488524	488428	19703U	PARTICIPANT	\N	PRESENT	0
488525	488428	01034P	PARTICIPANT	\N	PRESENT	0
488526	488428	19545Y	PARTICIPANT	\N	PRESENT	0
488527	488428	14081Q	PARTICIPANT	\N	PRESENT	0
488528	488428	04092N	PARTICIPANT	\N	EXCUSE	0
488529	488428	14331P	PARTICIPANT	\N	PRESENT	0
488530	488428	11012A	PARTICIPANT	\N	EXCUSE	0
488531	488428	19503N	PARTICIPANT	\N	PRESENT	0
488532	488428	19569H	PARTICIPANT	\N	PRESENT	0
488536	488428	19553Y	PARTICIPANT	\N	PRESENT	0
488539	488428	19663E	PARTICIPANT	\N	PRESENT	0
488535	488428	19447X	PARTICIPANT	\N	PRESENT	0
488543	488428	14041T	PARTICIPANT	\N	PRESENT	0
488538	488428	19766L	PARTICIPANT	\N	PRESENT	0
488540	488428	19715Y	PARTICIPANT	\N	PRESENT	0
488541	488428	19573D	PARTICIPANT	\N	PRESENT	0
488542	488428	89017R	PARTICIPANT	\N	PRESENT	0
489627	489343	11031D	PARTICIPANT	\N	PRESENT	0
489628	489343	10006L	PARTICIPANT	\N	PRESENT	0
489629	489343	14041T	PARTICIPANT	\N	PRESENT	0
489630	489343	19663E	PARTICIPANT	\N	EXCUSE	0
489631	489343	19649G	PARTICIPANT	\N	PRESENT	0
489632	489343	19691J	PARTICIPANT	\N	PRESENT	0
489633	489343	14081Q	PARTICIPANT	\N	PRESENT	0
489634	489343	19683J	PARTICIPANT	\N	PRESENT	0
489635	489343	19447X	PARTICIPANT	\N	PRESENT	0
489636	489343	19697Q	PARTICIPANT	\N	PRESENT	0
489637	489343	19715Y	PARTICIPANT	\N	PRESENT	0
489638	489343	11067R	PARTICIPANT	\N	PRESENT	0
489639	489343	04092N	PARTICIPANT	\N	EXCUSE	0
489640	489343	19573D	PARTICIPANT	\N	PRESENT	0
489641	489343	19503N	PARTICIPANT	\N	PRESENT	0
489642	489343	19766L	PARTICIPANT	\N	PRESENT	0
489643	489343	11097X	PRESIDENT	0	PRESENT	0
489644	489343	19703U	PARTICIPANT	\N	PRESENT	0
489645	489343	19479G	PARTICIPANT	\N	PRESENT	0
489646	489343	14331P	PARTICIPANT	\N	PRESENT	0
489647	489343	11048N	PARTICIPANT	\N	PRESENT	0
489648	489343	19553Y	PARTICIPANT	\N	PRESENT	0
489651	489649	19415P	PARTICIPANT	\N	PRESENT	0
489652	489649	11067R	PARTICIPANT	\N	PRESENT	0
489653	489650	19415P	PARTICIPANT	\N	PRESENT	0
489654	489650	11067R	PARTICIPANT	\N	PRESENT	0
489703	489173	04049K	PRESIDENT	0	PRESENT	0
489704	489173	19515S	PARTICIPANT	\N	PRESENT	0
489705	489173	14329V	PARTICIPANT	\N	PRESENT	0
489706	489173	16685X	PARTICIPANT	\N	PRESENT	0
489707	489173	19671E	PARTICIPANT	\N	PRESENT	0
489708	489173	04088S	PARTICIPANT	\N	PRESENT	0
489709	489173	19912C	PARTICIPANT	\N	PRESENT	0
489710	489173	89017R	PARTICIPANT	\N	EXCUSE	0
489711	489173	14030Q	PARTICIPANT	\N	EXCUSE	0
489712	489173	14105F	PARTICIPANT	\N	EXCUSE	0
489713	489173	14255U	PARTICIPANT	\N	EXCUSE	0
489714	489173	14083S	PARTICIPANT	\N	EXCUSE	0
489715	489173	19545Y	PARTICIPANT	\N	EXCUSE	0
489716	489173	11031D	PARTICIPANT	\N	EXCUSE	0
489717	489173	14079W	PARTICIPANT	\N	EXCUSE	0
489722	489173	14041T	PARTICIPANT	\N	EXCUSE	0
489723	489173	14151M	PARTICIPANT	\N	EXCUSE	0
489724	489173	14187A	PARTICIPANT	\N	EXCUSE	0
489725	489173	14034U	PARTICIPANT	\N	EXCUSE	0
489726	489173	14061L	PARTICIPANT	\N	EXCUSE	0
489727	489173	11099A	PARTICIPANT	\N	EXCUSE	0
489728	489173	08015R	PARTICIPANT	\N	EXCUSE	0
489729	489173	19697Q	PARTICIPANT	\N	EXCUSE	0
489730	489173	14205J	PARTICIPANT	\N	EXCUSE	0
489731	489173	14265W	PARTICIPANT	\N	EXCUSE	0
489732	489173	08047A	PARTICIPANT	\N	EXCUSE	0
489733	489173	14051J	PARTICIPANT	\N	EXCUSE	0
489734	489173	14227Q	PARTICIPANT	\N	EXCUSE	0
489735	489173	14157T	PARTICIPANT	\N	EXCUSE	0
489736	489173	14087W	PARTICIPANT	\N	EXCUSE	0
491382	490471	11067R	PARTICIPANT	\N	PRESENT	0
491383	490471	04057K	PARTICIPANT	\N	PRESENT	0
491384	490471	04092N	PARTICIPANT	\N	PRESENT	0
491385	490471	19569H	PARTICIPANT	\N	PRESENT	0
491386	490471	11097X	PARTICIPANT	\N	PRESENT	0
491387	490471	19663E	PARTICIPANT	\N	PRESENT	0
491388	490471	19715Y	PARTICIPANT	\N	PRESENT	0
491389	490471	19691J	PARTICIPANT	\N	PRESENT	0
491390	490471	19723Y	PARTICIPANT	\N	PRESENT	0
491391	490471	17779H	PARTICIPANT	\N	PRESENT	0
491392	490471	20066E	PARTICIPANT	\N	PRESENT	0
491393	490471	14281W	PARTICIPANT	\N	PRESENT	0
491394	490471	14213J	PARTICIPANT	\N	PRESENT	0
491395	490471	19657G	PARTICIPANT	\N	PRESENT	0
491396	490471	14217N	PARTICIPANT	\N	PRESENT	0
491397	490471	10006L	PRESIDENT	0	PRESENT	0
492966	491261	19631V	PARTICIPANT	\N	PRESENT	0
492967	491261	19575F	PARTICIPANT	\N	PRESENT	0
492968	491261	20094J	PARTICIPANT	\N	PRESENT	0
492969	491261	19383Y	PARTICIPANT	\N	PRESENT	0
492970	491261	19782L	PARTICIPANT	\N	PRESENT	0
492971	491261	14207L	PARTICIPANT	\N	PRESENT	0
492972	491261	20060X	PARTICIPANT	\N	PRESENT	0
492973	491261	14329V	PARTICIPANT	\N	PRESENT	0
492974	491261	08028W	PARTICIPANT	\N	PRESENT	0
492975	491261	19467C	PARTICIPANT	\N	PRESENT	0
492976	491261	14357A	PARTICIPANT	\N	PRESENT	0
492977	491261	19507S	PARTICIPANT	\N	PRESENT	0
492978	491261	14187A	PARTICIPANT	\N	PRESENT	0
492979	491261	19695N	PARTICIPANT	\N	PRESENT	0
492980	491261	14033T	PARTICIPANT	\N	PRESENT	0
492981	491261	11099A	PARTICIPANT	\N	PRESENT	0
492982	491261	14205J	PARTICIPANT	\N	PRESENT	0
492983	491261	14251Q	PARTICIPANT	\N	PRESENT	0
492984	491261	19563B	PARTICIPANT	\N	PRESENT	0
492985	491261	20028X	PARTICIPANT	\N	PRESENT	0
492986	491261	20018V	PARTICIPANT	\N	PRESENT	0
492987	491261	14257W	PARTICIPANT	\N	PRESENT	0
492988	491261	19768N	PARTICIPANT	\N	PRESENT	0
492989	491261	11090Q	PARTICIPANT	\N	PRESENT	0
492990	491261	20082E	PARTICIPANT	\N	PRESENT	0
492991	491261	19413M	PARTICIPANT	\N	PRESENT	0
506860	506859	14169X	PARTICIPANT	\N	PRESENT	0
506866	506863	14205J	PARTICIPANT	\N	PRESENT	0
506867	506864	14205J	PARTICIPANT	\N	PRESENT	0
506868	506864	14038Y	PARTICIPANT	\N	PRESENT	0
506869	506865	14205J	PARTICIPANT	\N	PRESENT	0
507007	505796	14111D	PARTICIPANT	\N	PRESENT	0
507008	505796	14275Y	PARTICIPANT	\N	PRESENT	0
507009	505796	04047H	PRESIDENT	0	PRESENT	0
507010	505796	19447X	PARTICIPANT	\N	PRESENT	0
507011	505796	20108W	PARTICIPANT	\N	PRESENT	0
507012	505796	11072N	PARTICIPANT	\N	PRESENT	0
507013	505796	14053L	PARTICIPANT	\N	PRESENT	0
507014	505796	20074E	PARTICIPANT	\N	PRESENT	0
507015	505796	01028R	PARTICIPANT	\N	PRESENT	0
507016	505796	05008E	PARTICIPANT	\N	PRESENT	0
507017	505796	95063L	PARTICIPANT	\N	PRESENT	0
507018	505796	14147R	PARTICIPANT	\N	PRESENT	0
507019	505796	14215L	PARTICIPANT	\N	PRESENT	0
507027	505796	14231L	PARTICIPANT	\N	EXCUSE	0
507021	505796	11056N	PARTICIPANT	\N	PRESENT	0
507025	505796	20110Q	PARTICIPANT	\N	PRESENT	1
507026	505796	19629C	PARTICIPANT	\N	PRESENT	1
507028	505796	14179A	PARTICIPANT	\N	PRESENT	1
507029	505796	14107H	PARTICIPANT	\N	PRESENT	1
507031	507030	11090Q	PARTICIPANT	\N	PRESENT	0
507032	507030	01043Q	PARTICIPANT	\N	PRESENT	0
507033	507030	19631V	PARTICIPANT	\N	PRESENT	0
507034	507030	14187A	PARTICIPANT	\N	PRESENT	0
507035	507030	11077T	PARTICIPANT	\N	PRESENT	0
507036	507030	04086Q	PARTICIPANT	\N	PRESENT	0
507041	502341	01043Q	PARTICIPANT	\N	PRESENT	0
507042	502341	11048N	PARTICIPANT	\N	PRESENT	0
507043	502341	19545Y	PARTICIPANT	\N	PRESENT	0
507044	502341	19689Q	PARTICIPANT	\N	PRESENT	0
507045	502341	19349W	PARTICIPANT	\N	PRESENT	0
507046	502341	11012A	PARTICIPANT	\N	PRESENT	0
507047	502341	11040E	PARTICIPANT	\N	PRESENT	0
507048	502341	14083S	PARTICIPANT	\N	PRESENT	0
507049	502341	19647E	PARTICIPANT	\N	PRESENT	0
507050	502341	19762G	PARTICIPANT	\N	PRESENT	0
507051	502341	19507S	PARTICIPANT	\N	PRESENT	0
507052	502341	19966S	PARTICIPANT	\N	PRESENT	0
507053	502341	97011G	PARTICIPANT	\N	PRESENT	0
507054	502341	99004R	PARTICIPANT	\N	PRESENT	0
507055	502341	19643A	PARTICIPANT	\N	PRESENT	0
507056	502341	20024T	PARTICIPANT	\N	PRESENT	0
507057	502341	11103C	PARTICIPANT	\N	PRESENT	0
507058	502341	20038A	PARTICIPANT	\N	PRESENT	0
507059	502341	20044X	PARTICIPANT	\N	PRESENT	0
507060	502341	19760E	PARTICIPANT	\N	PRESENT	0
507061	502341	19741B	PARTICIPANT	\N	PRESENT	0
507062	502341	19711U	PARTICIPANT	\N	PRESENT	0
507063	502341	14073Q	PARTICIPANT	\N	PRESENT	0
507064	502341	19671E	PARTICIPANT	\N	PRESENT	0
507065	502341	19515S	PARTICIPANT	\N	PRESENT	0
507066	502341	18083K	PARTICIPANT	\N	PRESENT	0
507067	502341	20172F	PARTICIPANT	\N	PRESENT	0
507068	502341	20062A	PARTICIPANT	\N	PRESENT	0
507069	502341	08034U	PARTICIPANT	\N	PRESENT	0
507070	502341	04045F	PARTICIPANT	\N	PRESENT	0
507071	502341	14021P	PARTICIPANT	\N	PRESENT	0
507072	502341	19333N	PARTICIPANT	\N	PRESENT	0
507076	502341	19467C	PARTICIPANT	\N	PRESENT	0
507074	502341	20050V	PARTICIPANT	\N	PRESENT	0
507075	502341	14225N	PARTICIPANT	\N	PRESENT	0
507077	502341	20084G	PARTICIPANT	\N	PRESENT	0
507078	502341	19782L	PARTICIPANT	\N	PRESENT	0
507079	502341	19503N	PARTICIPANT	\N	PRESENT	0
507080	502341	19651A	PARTICIPANT	\N	PRESENT	0
507081	502341	01024M	PARTICIPANT	\N	PRESENT	0
507082	502341	19399H	PARTICIPANT	\N	PRESENT	0
507083	502341	20076G	PARTICIPANT	\N	PRESENT	0
507084	502341	20126Y	PARTICIPANT	\N	PRESENT	0
507085	505797	14053L	PARTICIPANT	\N	PRESENT	0
507086	505797	14111D	PARTICIPANT	\N	PRESENT	0
507087	505797	19543W	PARTICIPANT	\N	PRESENT	0
507088	505797	01028R	PARTICIPANT	\N	PRESENT	0
507089	505797	05008E	PARTICIPANT	\N	PRESENT	0
507090	505797	14231L	PARTICIPANT	\N	PRESENT	0
507091	505797	11056N	PARTICIPANT	\N	PRESENT	0
507092	505797	19954N	PARTICIPANT	\N	PRESENT	0
507093	505797	95063L	PARTICIPANT	\N	PRESENT	0
507094	505797	19629C	PARTICIPANT	\N	PRESENT	0
507095	505797	20108W	PARTICIPANT	\N	PRESENT	0
507096	505797	14179A	PARTICIPANT	\N	PRESENT	0
507097	505797	14147R	PARTICIPANT	\N	PRESENT	0
507098	505797	14069U	PARTICIPANT	\N	PRESENT	0
507099	505797	14215L	PARTICIPANT	\N	PRESENT	0
507100	505797	19749K	PARTICIPANT	\N	PRESENT	0
507101	502341	14031R	PARTICIPANT	\N	PRESENT	0
507102	505797	01057W	PARTICIPANT	\N	PRESENT	0
507103	505797	04047H	PRESIDENT	0	PRESENT	0
507104	502341	11074Q	PARTICIPANT	\N	PRESENT	0
507105	502341	19687N	PARTICIPANT	\N	PRESENT	0
507106	502341	20090E	PARTICIPANT	\N	PRESENT	0
507107	502341	20070A	PARTICIPANT	\N	PRESENT	0
507108	502341	19415P	PARTICIPANT	\N	PRESENT	0
507109	502341	14267Y	PARTICIPANT	\N	PRESENT	0
507110	502341	19569H	PARTICIPANT	\N	PRESENT	0
507111	502341	12016W	PARTICIPANT	\N	PRESENT	0
507112	502341	19563B	PARTICIPANT	\N	PRESENT	0
507113	502341	19479G	PARTICIPANT	\N	PRESENT	0
507114	502341	19739H	PARTICIPANT	\N	PRESENT	0
507115	502341	20080C	PARTICIPANT	\N	PRESENT	0
507116	505797	10015M	PARTICIPANT	\N	PRESENT	1
507117	505797	19725B	PARTICIPANT	\N	PRESENT	1
507118	505797	19489J	PARTICIPANT	\N	PRESENT	1
507119	505797	14041T	PARTICIPANT	\N	PRESENT	0
507120	505797	14151M	PARTICIPANT	\N	PRESENT	0
507121	502341	20056C	PARTICIPANT	\N	PRESENT	0
507122	502341	19441R	PARTICIPANT	\N	PRESENT	0
507123	502341	20086J	PARTICIPANT	\N	PRESENT	0
507124	502341	19575F	PARTICIPANT	\N	PRESENT	0
507125	502341	19533U	PARTICIPANT	\N	PRESENT	0
507126	502341	19531S	PARTICIPANT	\N	PRESENT	0
507127	502341	14189C	PARTICIPANT	\N	PRESENT	0
507128	502341	20112S	PARTICIPANT	\N	PRESENT	0
507129	502341	19527W	PARTICIPANT	\N	PRESENT	0
507130	505797	19675J	PARTICIPANT	\N	PRESENT	1
507131	505797	14107H	PARTICIPANT	\N	PRESENT	1
507132	505797	11072N	PARTICIPANT	\N	PRESENT	0
507133	502341	20052X	PARTICIPANT	\N	PRESENT	0
507134	502341	20032T	PARTICIPANT	\N	PRESENT	0
507135	502341	19703U	PARTICIPANT	\N	PRESENT	0
507136	502341	11070L	PARTICIPANT	\N	PRESENT	0
507137	502341	14229S	PARTICIPANT	\N	PRESENT	0
507138	502341	19723Y	PARTICIPANT	\N	PRESENT	0
507139	502341	11031D	PARTICIPANT	\N	PRESENT	0
507140	502341	14089Y	PARTICIPANT	\N	PRESENT	0
507141	502341	11072N	PARTICIPANT	\N	PRESENT	0
507142	502341	04086Q	PARTICIPANT	\N	PRESENT	0
507143	502341	20066E	PARTICIPANT	\N	PRESENT	0
507144	505975	95041E	PARTICIPANT	\N	PRESENT	0
507145	505975	12041X	PARTICIPANT	\N	PRESENT	0
507146	505975	19565D	PARTICIPANT	\N	PRESENT	1
507147	505975	20072C	PARTICIPANT	\N	PRESENT	0
507148	505975	04034C	PARTICIPANT	\N	PRESENT	1
507149	505975	01058X	PARTICIPANT	\N	PRESENT	1
507150	505975	16685X	PARTICIPANT	\N	PRESENT	0
507151	505975	04042C	PRESIDENT	0	PRESENT	0
507152	505975	11054L	PARTICIPANT	\N	PRESENT	0
507153	505975	19669L	PARTICIPANT	\N	PRESENT	0
507154	505975	11066Q	PARTICIPANT	\N	PRESENT	0
507155	505975	19421M	PARTICIPANT	\N	PRESENT	0
507156	505975	19709B	PARTICIPANT	\N	PRESENT	0
507157	505975	14193X	PARTICIPANT	\N	PRESENT	1
507158	505975	19347U	PARTICIPANT	\N	PRESENT	0
507161	505975	14059S	PARTICIPANT	\N	PRESENT	0
507162	505975	01062T	PARTICIPANT	\N	PRESENT	1
507164	505975	20042V	PARTICIPANT	\N	PRESENT	0
507165	505975	01024M	PARTICIPANT	\N	PRESENT	0
507166	505975	19319Q	PARTICIPANT	\N	PRESENT	1
507167	505975	14105F	PARTICIPANT	\N	PRESENT	1
507168	505975	20064C	PARTICIPANT	\N	PRESENT	1
507169	505975	14267Y	PARTICIPANT	\N	PRESENT	0
507170	505975	11064N	PARTICIPANT	\N	PRESENT	0
507171	505975	11083R	PARTICIPANT	\N	PRESENT	0
507172	505975	14211G	PARTICIPANT	\N	PRESENT	0
483292	481575	19631V	PARTICIPANT	\N	EXCUSE	0
484902	484689	01034P	PARTICIPANT	\N	EXCUSE	0
488252	487038	19703U	PARTICIPANT	\N	PRESENT	0
488253	487038	19930E	PARTICIPANT	\N	PRESENT	0
488276	488275	19703U	PARTICIPANT	\N	PRESENT	0
488278	488277	11053K	PARTICIPANT	\N	PRESENT	0
488279	488277	14159V	PARTICIPANT	\N	PRESENT	0
488280	488277	05012A	PARTICIPANT	\N	PRESENT	0
488303	487274	19741B	PARTICIPANT	\N	PRESENT	0
493109	491419	08073C	PARTICIPANT	\N	PRESENT	0
493111	491419	04047H	PARTICIPANT	\N	PRESENT	0
493112	491419	19447X	PARTICIPANT	\N	PRESENT	0
493113	491419	11072N	PARTICIPANT	\N	PRESENT	0
493114	491419	11026G	PARTICIPANT	\N	PRESENT	0
493115	491419	19715Y	PARTICIPANT	\N	PRESENT	0
493116	491419	11033F	PARTICIPANT	\N	PRESENT	0
493117	491419	20110Q	PARTICIPANT	\N	PRESENT	0
493118	491419	19719D	PARTICIPANT	\N	PRESENT	0
493119	491419	19301E	PARTICIPANT	\N	PRESENT	0
493120	491419	14231L	PARTICIPANT	\N	PRESENT	0
493121	491419	14151M	PARTICIPANT	\N	PRESENT	0
493122	491419	01028R	PARTICIPANT	\N	PRESENT	0
493123	491419	19543W	PARTICIPANT	\N	PRESENT	0
493124	491419	19415P	PARTICIPANT	\N	PRESENT	0
493125	491419	14215L	PARTICIPANT	\N	PRESENT	0
493126	491419	14217N	PARTICIPANT	\N	PRESENT	0
493127	491419	19711U	PARTICIPANT	\N	PRESENT	0
493128	491419	11097X	PARTICIPANT	\N	PRESENT	0
493129	491419	14147R	PARTICIPANT	\N	PRESENT	0
493147	491419	04034C	PARTICIPANT	\N	PRESENT	0
493131	491419	20034V	PARTICIPANT	\N	PRESENT	0
493132	491419	20100N	PARTICIPANT	\N	PRESENT	0
493133	491419	20074E	PARTICIPANT	\N	PRESENT	0
493134	491419	20038A	PARTICIPANT	\N	PRESENT	0
493135	491419	14038Y	PARTICIPANT	\N	PRESENT	0
493136	491419	11077T	PARTICIPANT	\N	PRESENT	0
493137	491419	05008E	PARTICIPANT	\N	PRESENT	0
493138	491419	14069U	PARTICIPANT	\N	PRESENT	0
493139	491419	11099A	PARTICIPANT	\N	PRESENT	0
493140	491419	14033T	PARTICIPANT	\N	PRESENT	0
493141	491419	19585H	PARTICIPANT	\N	PRESENT	0
493142	491419	20058E	PARTICIPANT	\N	PRESENT	0
493143	491419	14089Y	PARTICIPANT	\N	PRESENT	0
493144	491419	19503N	PARTICIPANT	\N	PRESENT	0
493145	491419	20098N	PARTICIPANT	\N	PRESENT	0
493146	491419	19713W	PARTICIPANT	\N	PRESENT	0
493148	491419	19591F	PARTICIPANT	\N	PRESENT	0
493149	491419	14021P	PARTICIPANT	\N	PRESENT	0
493150	491419	20120S	PARTICIPANT	\N	PRESENT	0
493151	491419	17737W	PARTICIPANT	\N	PRESENT	0
493152	491419	11056N	PARTICIPANT	\N	PRESENT	0
493153	491419	19695N	PARTICIPANT	\N	PRESENT	0
493154	491419	19347U	PARTICIPANT	\N	PRESENT	0
493155	491419	14105F	PARTICIPANT	\N	PRESENT	0
493425	493365	20074E	PARTICIPANT	\N	EXCUSE	0
493814	493227	19711U	PARTICIPANT	\N	PRESENT	0
493807	493227	14327T	PARTICIPANT	\N	PRESENT	0
493808	493227	14331P	PARTICIPANT	\N	PRESENT	0
493809	493227	19349W	PARTICIPANT	\N	PRESENT	0
493810	493227	20050V	PARTICIPANT	\N	PRESENT	0
493811	493227	99004R	PARTICIPANT	\N	PRESENT	0
493812	493227	14225N	PRESIDENT	0	PRESENT	0
493813	493227	11070L	PARTICIPANT	\N	PRESENT	0
493815	493227	08034U	PARTICIPANT	\N	PRESENT	0
493816	493227	11110B	PARTICIPANT	\N	PRESENT	0
493817	493227	14173T	PARTICIPANT	\N	PRESENT	0
493818	493227	04086Q	PARTICIPANT	\N	PRESENT	0
493819	493227	19762G	PARTICIPANT	\N	PRESENT	0
493820	492699	19697Q	PARTICIPANT	\N	PRESENT	0
493821	492699	11067R	PARTICIPANT	\N	PRESENT	0
493822	492699	20090E	PARTICIPANT	\N	PRESENT	0
493823	492699	19798U	PARTICIPANT	\N	PRESENT	0
493824	492699	19569H	PARTICIPANT	\N	PRESENT	0
493825	492699	11097X	PARTICIPANT	\N	PRESENT	0
493826	492699	14223L	PARTICIPANT	\N	PRESENT	0
493827	492699	14026U	PARTICIPANT	\N	PRESENT	0
493828	492699	19703U	PARTICIPANT	\N	PRESENT	0
493829	492699	19553Y	PARTICIPANT	\N	PRESENT	0
493830	492699	14281W	PARTICIPANT	\N	PRESENT	0
493831	492699	14042U	PARTICIPANT	\N	PRESENT	0
493832	492699	14213J	PARTICIPANT	\N	PRESENT	0
493833	492699	14217N	PARTICIPANT	\N	PRESENT	0
493834	492699	19683J	PARTICIPANT	\N	PRESENT	0
493835	492699	10006L	PRESIDENT	0	PRESENT	0
493836	492699	20130U	PARTICIPANT	\N	PRESENT	0
493837	492699	04092N	PARTICIPANT	\N	PRESENT	0
493838	492699	19713W	PARTICIPANT	\N	PRESENT	0
493839	492699	19301E	PARTICIPANT	\N	PRESENT	0
493840	492699	19715Y	PARTICIPANT	\N	PRESENT	0
493841	492699	19691J	PARTICIPANT	\N	PRESENT	0
493842	492699	11103C	PARTICIPANT	\N	PRESENT	0
493843	492699	14071N	PARTICIPANT	\N	PRESENT	0
493844	492699	04043D	PARTICIPANT	\N	PRESENT	0
493845	493227	19479G	PARTICIPANT	\N	PRESENT	0
493846	493227	01048V	PARTICIPANT	\N	PRESENT	0
493847	493227	07029T	PARTICIPANT	\N	PRESENT	0
493848	493227	11012A	PARTICIPANT	\N	PRESENT	0
493849	493227	19335Q	PARTICIPANT	\N	PRESENT	0
493850	492698	19697Q	PARTICIPANT	\N	PRESENT	0
493851	492698	17583W	PARTICIPANT	\N	PRESENT	0
493852	492698	11067R	PARTICIPANT	\N	PRESENT	0
493853	492698	20090E	PARTICIPANT	\N	PRESENT	0
493854	492698	19798U	PARTICIPANT	\N	PRESENT	0
493855	492698	19569H	PARTICIPANT	\N	PRESENT	0
493856	492698	11097X	PARTICIPANT	\N	PRESENT	0
493857	492698	14223L	PARTICIPANT	\N	PRESENT	0
493858	492698	14026U	PARTICIPANT	\N	PRESENT	0
493859	492698	19703U	PARTICIPANT	\N	PRESENT	0
493860	492698	19553Y	PARTICIPANT	\N	PRESENT	0
493861	492698	14281W	PARTICIPANT	\N	PRESENT	0
493862	492698	14042U	PARTICIPANT	\N	PRESENT	0
493863	492698	14213J	PARTICIPANT	\N	PRESENT	0
493864	492698	14217N	PARTICIPANT	\N	PRESENT	0
493865	492698	19683J	PARTICIPANT	\N	PRESENT	0
493866	492698	10006L	PRESIDENT	0	PRESENT	0
493867	492698	20130U	PARTICIPANT	\N	PRESENT	0
493868	492698	04092N	PARTICIPANT	\N	PRESENT	0
493869	492698	19713W	PARTICIPANT	\N	PRESENT	0
493870	492698	19301E	PARTICIPANT	\N	PRESENT	0
493871	492698	19715Y	PARTICIPANT	\N	PRESENT	0
493872	492698	19691J	PARTICIPANT	\N	PRESENT	0
493873	492698	11103C	PARTICIPANT	\N	PRESENT	0
493874	492698	14071N	PARTICIPANT	\N	PRESENT	0
493875	492698	04043D	PARTICIPANT	\N	PRESENT	0
493876	492698	20126Y	PARTICIPANT	\N	PRESENT	0
493877	493227	19545Y	PARTICIPANT	\N	PRESENT	0
493878	493227	11074Q	PARTICIPANT	\N	PRESENT	0
493879	493227	19647E	PARTICIPANT	\N	PRESENT	0
493880	493227	19531S	PARTICIPANT	\N	PRESENT	0
493881	493227	19687N	PARTICIPANT	\N	PRESENT	0
493882	493227	20044X	PARTICIPANT	\N	PRESENT	0
493883	493227	19741B	PARTICIPANT	\N	PRESENT	0
493884	493227	14121F	PARTICIPANT	\N	PRESENT	0
493885	493227	11048N	PARTICIPANT	\N	PRESENT	0
493886	493227	01057W	PARTICIPANT	\N	PRESENT	0
493887	493227	14083S	PARTICIPANT	\N	PRESENT	0
493888	493227	20036X	PARTICIPANT	\N	PRESENT	0
493889	493227	04071H	PARTICIPANT	\N	PRESENT	0
493890	493227	08009T	PARTICIPANT	\N	PRESENT	0
493892	493392	19333N	PARTICIPANT	\N	PRESENT	0
493893	493392	05012A	PARTICIPANT	\N	PRESENT	0
493894	493392	19701S	PARTICIPANT	\N	PRESENT	0
493895	493392	20068G	PARTICIPANT	\N	PRESENT	0
493896	493392	14031R	PARTICIPANT	\N	PRESENT	0
493897	493392	20076G	PARTICIPANT	\N	PRESENT	0
493898	493392	14219Q	PRESIDENT	0	PRESENT	0
493899	493392	19745F	PARTICIPANT	\N	PRESENT	0
493901	493392	19739H	PARTICIPANT	\N	PRESENT	0
493902	493392	19826F	PARTICIPANT	\N	PRESENT	0
493903	493392	20046A	PARTICIPANT	\N	EXCUSE	0
493904	493392	19549D	PARTICIPANT	\N	PRESENT	0
493905	493392	14221J	PARTICIPANT	\N	PRESENT	0
493906	493392	18083K	PARTICIPANT	\N	PRESENT	0
493907	493392	14237S	PARTICIPANT	\N	PRESENT	0
493908	493392	20106U	PARTICIPANT	\N	PRESENT	0
493911	492923	19383Y	PARTICIPANT	\N	PRESENT	0
493912	492923	19768N	PARTICIPANT	\N	PRESENT	0
493913	492923	20088L	PARTICIPANT	\N	PRESENT	0
493914	492923	19782L	PARTICIPANT	\N	PRESENT	0
493915	492923	14357A	PARTICIPANT	\N	PRESENT	0
493916	492923	19441R	PARTICIPANT	\N	PRESENT	0
493917	492923	19413M	PARTICIPANT	\N	PRESENT	0
493918	492923	20082E	PARTICIPANT	\N	PRESENT	0
493919	492923	20094J	PARTICIPANT	\N	PRESENT	0
493920	492923	19631V	PARTICIPANT	\N	PRESENT	0
493921	492923	11099A	PARTICIPANT	\N	PRESENT	0
493922	492923	19705W	PARTICIPANT	\N	PRESENT	0
493923	492923	08015R	PARTICIPANT	\N	PRESENT	0
500824	500408	04092N	PARTICIPANT	\N	PRESENT	0
500825	500408	08045X	PARTICIPANT	\N	PRESENT	0
500826	500408	19663E	PARTICIPANT	\N	PRESENT	0
500827	500408	19301E	PARTICIPANT	\N	PRESENT	0
500828	500408	17965H	PARTICIPANT	\N	PRESENT	0
500829	500408	19715Y	PARTICIPANT	\N	PRESENT	0
500830	500408	19691J	PARTICIPANT	\N	PRESENT	0
500831	500408	19723Y	PARTICIPANT	\N	PRESENT	0
500832	500408	11103C	PARTICIPANT	\N	PRESENT	0
500833	500408	14071N	PRESIDENT	0	PRESENT	0
500834	500408	19657G	PARTICIPANT	\N	PRESENT	0
500835	500408	04043D	PARTICIPANT	\N	PRESENT	0
500836	500408	19760E	PARTICIPANT	\N	PRESENT	0
500845	500279	20086J	PARTICIPANT	\N	PRESENT	0
500846	500279	19713W	PARTICIPANT	\N	PRESENT	0
500847	500279	19533U	PARTICIPANT	\N	PRESENT	0
500848	500279	14225N	PARTICIPANT	\N	PRESENT	0
500849	495438	11040E	PARTICIPANT	\N	EXCUSE	0
500850	495438	08012N	PARTICIPANT	\N	EXCUSE	0
501172	500411	19697Q	PARTICIPANT	\N	PRESENT	0
501173	500411	11067R	PARTICIPANT	\N	PRESENT	0
501174	500411	20090E	PARTICIPANT	\N	PRESENT	0
501175	500411	19569H	PARTICIPANT	\N	PRESENT	0
501176	500411	19798U	PARTICIPANT	\N	PRESENT	0
501177	500411	11097X	PARTICIPANT	\N	PRESENT	0
501178	500411	19415P	PARTICIPANT	\N	PRESENT	0
501179	500411	14223L	PARTICIPANT	\N	PRESENT	0
501180	500411	18193Q	PARTICIPANT	\N	PRESENT	0
501181	500411	14026U	PARTICIPANT	\N	PRESENT	0
501182	500411	17779H	PARTICIPANT	\N	PRESENT	0
501183	500411	19553Y	PARTICIPANT	\N	PRESENT	0
501184	500411	11031D	PARTICIPANT	\N	PRESENT	0
501185	500411	19703U	PARTICIPANT	\N	PRESENT	0
501186	500411	14281W	PARTICIPANT	\N	PRESENT	0
501187	500411	19679N	PARTICIPANT	\N	PRESENT	0
501188	500411	14042U	PARTICIPANT	\N	PRESENT	0
501189	500411	14195A	PARTICIPANT	\N	PRESENT	0
501190	500411	14213J	PARTICIPANT	\N	PRESENT	0
501191	500411	14217N	PARTICIPANT	\N	PRESENT	0
501192	500411	10006L	PRESIDENT	0	PRESENT	0
501193	500411	19591F	PARTICIPANT	\N	PRESENT	0
501194	500411	20130U	PARTICIPANT	\N	PRESENT	0
501195	500411	04092N	PARTICIPANT	0	PRESENT	0
501196	500411	19713W	PARTICIPANT	\N	PRESENT	0
501197	500411	11045K	PARTICIPANT	\N	PRESENT	0
501198	500411	08045X	PARTICIPANT	\N	PRESENT	0
501199	500411	19301E	PARTICIPANT	\N	PRESENT	0
501200	500411	17965H	PARTICIPANT	\N	PRESENT	0
501201	500411	19691J	PARTICIPANT	\N	PRESENT	0
501202	500411	19715Y	PARTICIPANT	\N	PRESENT	0
501203	500411	19717B	PARTICIPANT	\N	PRESENT	0
501204	500411	19723Y	PARTICIPANT	\N	PRESENT	0
501205	500411	20066E	PARTICIPANT	\N	PRESENT	0
501206	500411	11103C	PARTICIPANT	\N	PRESENT	0
501207	500411	14071N	PARTICIPANT	\N	PRESENT	0
501208	500411	19657G	PARTICIPANT	\N	PRESENT	0
501209	500411	04043D	PARTICIPANT	\N	PRESENT	0
501210	500411	19760E	PARTICIPANT	\N	PRESENT	0
501211	500411	14355X	PARTICIPANT	\N	EXCUSE	0
501213	500241	19675J	PARTICIPANT	\N	PRESENT	0
501214	500241	19489J	PARTICIPANT	\N	PRESENT	0
501215	500241	14107H	PARTICIPANT	\N	PRESENT	0
501216	500241	20110Q	PARTICIPANT	\N	PRESENT	0
501217	500241	14179A	PARTICIPANT	\N	PRESENT	0
501218	500241	14151M	PARTICIPANT	\N	PRESENT	0
501219	500241	14215L	PARTICIPANT	\N	PRESENT	0
501220	500241	11072N	PARTICIPANT	\N	PRESENT	0
501221	500241	14053L	PARTICIPANT	\N	PRESENT	0
501222	500241	14111D	PARTICIPANT	\N	PRESENT	0
501223	500241	10015M	PARTICIPANT	\N	PRESENT	0
501224	500241	19729F	PARTICIPANT	\N	PRESENT	0
501225	500241	19629C	PARTICIPANT	\N	PRESENT	0
501226	500241	19749K	PARTICIPANT	\N	PRESENT	0
501227	499974	19699S	PARTICIPANT	\N	PRESENT	0
501228	499974	19573D	PARTICIPANT	\N	PRESENT	0
501229	499974	08017T	PARTICIPANT	\N	PRESENT	0
501230	499974	20026V	PARTICIPANT	\N	PRESENT	0
501231	499974	20120S	PARTICIPANT	\N	PRESENT	0
501232	499974	19593H	PARTICIPANT	\N	PRESENT	0
501233	499974	20132W	PARTICIPANT	\N	PRESENT	0
501234	499974	19643A	PARTICIPANT	\N	PRESENT	0
501235	499974	20134Y	PARTICIPANT	\N	PRESENT	0
501236	499974	14073Q	PARTICIPANT	\N	PRESENT	0
501237	499974	19651A	PARTICIPANT	\N	PRESENT	0
501238	499974	19611R	PRESIDENT	0	PRESENT	0
501239	499974	20142Y	PARTICIPANT	\N	PRESENT	0
501240	499974	19693L	PARTICIPANT	\N	PRESENT	0
501241	499974	19399H	PARTICIPANT	\N	PRESENT	0
501242	499974	20152B	PARTICIPANT	\N	PRESENT	0
501243	499974	19719D	PARTICIPANT	\N	PRESENT	0
501244	499974	20052X	PARTICIPANT	\N	PRESENT	0
501245	499974	14030Q	PARTICIPANT	\N	PRESENT	0
501246	499974	20058E	PARTICIPANT	\N	PRESENT	0
501247	499974	20056C	PARTICIPANT	\N	PRESENT	0
501248	499974	14123H	PARTICIPANT	\N	PRESENT	0
501249	499974	11104D	PARTICIPANT	\N	PRESENT	0
501250	499974	11043H	PARTICIPANT	\N	PRESENT	0
501251	499974	19758L	PARTICIPANT	\N	PRESENT	0
501252	499974	17589D	PARTICIPANT	\N	PRESENT	0
501253	499974	19621T	PARTICIPANT	\N	PRESENT	0
501254	499974	20084G	PARTICIPANT	\N	PRESENT	0
501255	499974	20138D	PARTICIPANT	\N	PRESENT	0
501256	499974	04070G	PARTICIPANT	\N	EXCUSE	0
501257	499974	19735D	PARTICIPANT	\N	EXCUSE	0
501284	500476	96004D	PARTICIPANT	\N	PRESENT	0
501285	500476	19335Q	PARTICIPANT	\N	PRESENT	0
501286	500281	99004R	PARTICIPANT	\N	PRESENT	0
501287	500476	14083S	PARTICIPANT	\N	PRESENT	0
501288	500476	20050V	PARTICIPANT	\N	PRESENT	0
501289	500476	19667J	PARTICIPANT	\N	PRESENT	0
501290	500476	14225N	PARTICIPANT	\N	PRESENT	0
501291	500476	07029T	PARTICIPANT	\N	PRESENT	0
501292	500476	19531S	PARTICIPANT	\N	PRESENT	0
501293	500281	14195A	PARTICIPANT	\N	PRESENT	0
501294	500281	19525U	PARTICIPANT	\N	PRESENT	0
501295	500281	14073Q	PARTICIPANT	\N	PRESENT	0
501296	500476	11053K	PARTICIPANT	\N	PRESENT	0
501297	500476	19647E	PARTICIPANT	\N	PRESENT	0
501298	500476	20126Y	PARTICIPANT	\N	PRESENT	0
501299	500476	04086Q	PARTICIPANT	\N	PRESENT	0
501300	500476	08010L	PARTICIPANT	\N	PRESENT	0
501301	500476	14331P	PARTICIPANT	\N	PRESENT	0
501302	500476	14253S	PARTICIPANT	\N	PRESENT	0
501303	500476	08011M	PARTICIPANT	\N	PRESENT	0
501304	500281	19569H	PARTICIPANT	\N	PRESENT	0
501305	500281	20130U	PARTICIPANT	\N	PRESENT	0
501306	500281	20028X	PARTICIPANT	\N	PRESENT	0
501307	500281	18193Q	PARTICIPANT	\N	PRESENT	0
501308	500281	14041T	PARTICIPANT	\N	PRESENT	0
501309	500281	11103C	PARTICIPANT	\N	PRESENT	0
501310	500281	20090E	PARTICIPANT	\N	PRESENT	0
501311	500281	14281W	PARTICIPANT	\N	PRESENT	0
501312	500281	11067R	PARTICIPANT	\N	PRESENT	0
501313	500281	07004J	PARTICIPANT	\N	PRESENT	0
501314	500281	17779H	PARTICIPANT	\N	PRESENT	0
501315	500281	19719D	PARTICIPANT	\N	PRESENT	0
501316	500281	11012A	PARTICIPANT	\N	PRESENT	0
501317	500281	20150Y	PARTICIPANT	\N	PRESENT	0
501318	500281	19782L	PARTICIPANT	\N	PRESENT	0
501319	500281	19699S	PARTICIPANT	\N	PRESENT	0
501320	500281	14071N	PARTICIPANT	\N	PRESENT	0
501321	500281	19415P	PARTICIPANT	\N	PRESENT	0
501322	500281	11097X	PARTICIPANT	\N	PRESENT	0
501323	500281	01034P	PARTICIPANT	\N	PRESENT	0
501324	500281	10006L	PARTICIPANT	\N	PRESENT	0
501325	500281	19715Y	PARTICIPANT	\N	PRESENT	0
501326	500281	11031D	PARTICIPANT	\N	PRESENT	0
501327	500281	19760E	PARTICIPANT	\N	PRESENT	0
501328	500281	11056N	PARTICIPANT	\N	PRESENT	0
501329	500281	19695N	PARTICIPANT	\N	PRESENT	0
501330	500281	19683J	PARTICIPANT	\N	PRESENT	0
501331	500281	20024T	PARTICIPANT	\N	PRESENT	0
501332	500281	19717B	PARTICIPANT	\N	PRESENT	0
501333	500281	19826F	PARTICIPANT	\N	PRESENT	0
501334	500281	19515S	PARTICIPANT	\N	PRESENT	0
501335	500281	20038A	PARTICIPANT	\N	PRESENT	0
501336	500281	04092N	PARTICIPANT	\N	PRESENT	0
501337	500281	19301E	PARTICIPANT	\N	PRESENT	0
501338	500281	14147R	PARTICIPANT	\N	PRESENT	0
501339	500281	17965H	PARTICIPANT	\N	PRESENT	0
501340	500281	19295A	PARTICIPANT	\N	PRESENT	0
501341	500281	08045X	PARTICIPANT	\N	PRESENT	0
501343	500281	19697Q	PARTICIPANT	\N	PRESENT	0
501344	500281	14042U	PARTICIPANT	\N	PRESENT	0
501345	500281	19657G	PARTICIPANT	\N	PRESENT	0
501346	500281	11045K	PARTICIPANT	\N	PRESENT	0
501347	500281	14021P	PARTICIPANT	\N	PRESENT	0
501348	500281	20152B	PARTICIPANT	\N	PRESENT	0
501349	500281	14213J	PARTICIPANT	\N	PRESENT	0
483218	481129	14026U	PARTICIPANT	\N	PRESENT	0
489829	489828	19693L	PARTICIPANT	\N	PRESENT	0
489830	489828	19593H	PARTICIPANT	\N	PRESENT	0
489890	489889	04018C	PARTICIPANT	\N	PRESENT	0
489891	489889	19593H	PARTICIPANT	\N	PRESENT	0
493050	491474	19369B	PARTICIPANT	\N	EXCUSE	0
493053	493052	19369B	PARTICIPANT	\N	PRESENT	0
493055	493054	19369B	PARTICIPANT	\N	PRESENT	0
493057	493056	19369B	PARTICIPANT	\N	PRESENT	0
493060	493058	19369B	PARTICIPANT	\N	PRESENT	0
493062	493059	19369B	PARTICIPANT	\N	PRESENT	0
493064	493063	19369B	PARTICIPANT	\N	PRESENT	0
493195	491441	96004D	PRESIDENT	0	PRESENT	0
493196	491441	14089Y	PARTICIPANT	\N	PRESENT	0
493197	491441	19701S	PARTICIPANT	\N	PRESENT	0
493198	491441	14357A	PARTICIPANT	\N	PRESENT	0
493199	491441	20100N	PARTICIPANT	\N	PRESENT	0
493200	491441	19521Q	PARTICIPANT	\N	PRESENT	0
493201	491441	11083R	PARTICIPANT	\N	PRESENT	0
493202	491441	19553Y	PARTICIPANT	\N	PRESENT	0
493203	491441	08034U	PARTICIPANT	\N	PRESENT	0
493204	491441	12016W	PARTICIPANT	\N	PRESENT	0
493205	491441	14001X	PARTICIPANT	\N	PRESENT	0
493206	491441	14221J	PARTICIPANT	\N	PRESENT	0
493207	491441	04057K	PARTICIPANT	\N	PRESENT	0
493208	491441	14331P	PARTICIPANT	\N	EXCUSE	0
493209	491441	20098N	PARTICIPANT	\N	PRESENT	0
493212	491441	04034C	PARTICIPANT	\N	PRESENT	0
493213	491441	04042C	PARTICIPANT	\N	PRESENT	0
493214	491441	14255U	PARTICIPANT	\N	PRESENT	0
493216	491441	07004J	PARTICIPANT	\N	PRESENT	0
493218	491441	19711U	PARTICIPANT	\N	PRESENT	0
493219	491441	20022R	PARTICIPANT	\N	PRESENT	0
493222	491441	01024M	PARTICIPANT	\N	PRESENT	0
493223	491441	19347U	PARTICIPANT	\N	PRESENT	0
493224	491441	01058X	PARTICIPANT	\N	PRESENT	0
493225	491441	19387D	PARTICIPANT	\N	PRESENT	0
493229	491441	14219Q	PARTICIPANT	\N	PRESENT	0
493230	491441	14179A	PARTICIPANT	\N	PRESENT	0
493231	491441	14169X	PARTICIPANT	\N	PRESENT	0
493236	491441	19575F	PARTICIPANT	\N	PRESENT	0
493263	491441	19531S	PARTICIPANT	\N	PRESENT	0
493988	492699	19679N	PARTICIPANT	\N	PRESENT	0
494011	492903	01034P	PARTICIPANT	\N	PRESENT	0
493990	492699	20066E	PARTICIPANT	\N	PRESENT	0
494043	492903	04057K	PARTICIPANT	\N	PRESENT	0
493992	492698	11031D	PARTICIPANT	\N	PRESENT	0
494048	490476	14147R	PARTICIPANT	\N	PRESENT	0
494049	490477	14147R	PARTICIPANT	\N	PRESENT	0
494050	491141	14147R	PARTICIPANT	\N	PRESENT	0
494054	492699	19760E	PARTICIPANT	\N	EXCUSE	0
494055	492699	19295A	PARTICIPANT	\N	EXCUSE	0
494056	492698	19760E	PARTICIPANT	\N	EXCUSE	0
494057	492698	19295A	PARTICIPANT	\N	EXCUSE	0
494058	492903	19760E	PARTICIPANT	\N	EXCUSE	0
494059	492903	19295A	PARTICIPANT	\N	EXCUSE	0
494104	494103	20130U	PARTICIPANT	\N	PRESENT	0
494105	494103	20108W	PARTICIPANT	\N	PRESENT	0
494106	494103	20032T	PARTICIPANT	\N	PRESENT	0
494108	494103	12028B	PARTICIPANT	\N	PRESENT	0
494109	494103	19697Q	PARTICIPANT	\N	PRESENT	0
494110	494103	19798U	PARTICIPANT	\N	PRESENT	0
494111	494103	08069G	PARTICIPANT	\N	PRESENT	0
494112	494103	14195A	PARTICIPANT	\N	PRESENT	0
494113	494103	19719D	PARTICIPANT	\N	PRESENT	0
494114	494103	20016T	PARTICIPANT	\N	PRESENT	0
494115	494103	01048V	PARTICIPANT	\N	PRESENT	0
494116	494103	19413M	PARTICIPANT	\N	PRESENT	0
494117	494103	20088L	PARTICIPANT	\N	PRESENT	0
494118	494103	19387D	PARTICIPANT	\N	PRESENT	0
494119	494103	11027H	PARTICIPANT	\N	PRESENT	0
494120	494103	08034U	PARTICIPANT	\N	PRESENT	0
494121	494103	14223L	PARTICIPANT	\N	PRESENT	0
494122	494103	20148F	PARTICIPANT	\N	PRESENT	0
494123	494103	05008E	PARTICIPANT	\N	PRESENT	0
494124	494103	19695N	PARTICIPANT	\N	PRESENT	0
494125	494103	99004R	PARTICIPANT	\N	PRESENT	0
494126	494103	20126Y	PARTICIPANT	\N	PRESENT	0
494127	494103	19699S	PARTICIPANT	\N	PRESENT	0
494128	494103	19679N	PARTICIPANT	\N	PRESENT	0
494129	494103	20068G	PARTICIPANT	\N	PRESENT	0
494130	494103	19729F	PARTICIPANT	\N	PRESENT	0
494131	494103	14042U	PARTICIPANT	\N	PRESENT	0
494132	494103	18083K	PARTICIPANT	\N	PRESENT	0
494133	494103	14211G	PARTICIPANT	\N	PRESENT	0
494134	494103	19593H	PARTICIPANT	\N	PRESENT	0
494135	494103	19683J	PARTICIPANT	\N	PRESENT	0
494136	494103	14229S	PARTICIPANT	\N	PRESENT	0
494137	494103	20106U	PARTICIPANT	\N	PRESENT	0
494138	494103	14207L	PARTICIPANT	\N	PRESENT	0
494139	494103	19687N	PARTICIPANT	\N	PRESENT	0
494140	494103	14221J	PARTICIPANT	\N	PRESENT	0
494141	494103	19563B	PARTICIPANT	\N	PRESENT	0
494142	494103	20142Y	PARTICIPANT	\N	PRESENT	0
494143	494103	05012A	PARTICIPANT	\N	PRESENT	0
494144	494103	19543W	PARTICIPANT	\N	PRESENT	0
494145	494103	04092N	PARTICIPANT	\N	PRESENT	0
494146	494103	04059M	PARTICIPANT	\N	PRESENT	0
494147	494103	11066Q	PARTICIPANT	\N	PRESENT	0
494148	494103	08061X	PARTICIPANT	\N	PRESENT	0
494149	494103	20028X	PARTICIPANT	\N	PRESENT	0
494150	494103	19820Y	PARTICIPANT	\N	PRESENT	0
494151	494103	11012A	PARTICIPANT	\N	PRESENT	0
494152	494103	19527W	PARTICIPANT	\N	PRESENT	0
494153	494103	20146D	PARTICIPANT	\N	PRESENT	0
494154	494103	19649G	PARTICIPANT	\N	PRESENT	0
494155	494103	19333N	PARTICIPANT	\N	PRESENT	0
494156	494103	08045X	PARTICIPANT	\N	PRESENT	0
494157	494103	19369B	PARTICIPANT	\N	PRESENT	0
494158	494103	19441R	PARTICIPANT	\N	PRESENT	0
494159	494103	19545Y	PARTICIPANT	\N	PRESENT	0
494160	494103	20134Y	PARTICIPANT	\N	PRESENT	0
494161	494103	95063L	PARTICIPANT	\N	PRESENT	0
494162	494103	14257W	PARTICIPANT	\N	PRESENT	0
494163	494103	17779H	PARTICIPANT	\N	PRESENT	0
494164	494103	19549D	PARTICIPANT	\N	PRESENT	0
494165	494103	19637C	PARTICIPANT	\N	PRESENT	0
494166	494103	04085P	PARTICIPANT	\N	PRESENT	0
494167	494103	11031D	PARTICIPANT	\N	PRESENT	0
494168	494103	11056N	PARTICIPANT	\N	PRESENT	0
494169	494103	19565D	PARTICIPANT	\N	PRESENT	0
494170	494103	20112S	PARTICIPANT	\N	PRESENT	0
494171	494103	11033F	PARTICIPANT	\N	PRESENT	0
494172	494103	20110Q	PARTICIPANT	\N	PRESENT	0
494173	494103	11065P	PARTICIPANT	\N	PRESENT	0
494174	494103	20092G	PARTICIPANT	\N	PRESENT	0
494175	494103	11099A	PARTICIPANT	\N	PRESENT	0
494176	494103	19591F	PARTICIPANT	\N	PRESENT	0
494177	494103	11083R	PARTICIPANT	\N	PRESENT	0
494178	494103	17637T	PARTICIPANT	\N	PRESENT	0
494179	494103	19301E	PARTICIPANT	\N	PRESENT	0
494180	494103	08010L	PARTICIPANT	\N	PRESENT	0
494181	494103	04008A	PARTICIPANT	\N	PRESENT	0
494182	494103	19711U	PARTICIPANT	\N	PRESENT	0
494183	494103	19703U	PARTICIPANT	\N	PRESENT	0
494184	494103	14251Q	PARTICIPANT	\N	PRESENT	0
494185	494103	08073C	PARTICIPANT	\N	PRESENT	0
494186	494103	20122U	PARTICIPANT	\N	PRESENT	0
494187	494103	19349W	PARTICIPANT	\N	PRESENT	0
494188	494103	19866P	PARTICIPANT	\N	PRESENT	0
494189	494103	19553Y	PARTICIPANT	\N	PRESENT	0
494190	494103	04057K	PARTICIPANT	\N	PRESENT	0
494191	494103	20116W	PARTICIPANT	\N	PRESENT	0
494192	494103	19651A	PARTICIPANT	\N	PRESENT	0
494193	494103	01028R	PARTICIPANT	\N	PRESENT	0
494194	494103	11045K	PARTICIPANT	\N	PRESENT	0
494195	494103	20058E	PARTICIPANT	\N	PRESENT	0
494196	494103	14021P	PARTICIPANT	\N	PRESENT	0
494197	494103	20044X	PARTICIPANT	\N	PRESENT	0
494198	494103	19709B	PARTICIPANT	\N	PRESENT	0
494199	494103	20100N	PARTICIPANT	\N	PRESENT	0
494200	494103	19415P	PARTICIPANT	\N	PRESENT	0
494201	494103	07029T	PARTICIPANT	\N	PRESENT	0
494202	494103	11067R	PARTICIPANT	\N	PRESENT	0
494203	494103	11026G	PARTICIPANT	\N	PRESENT	0
494204	494103	20094J	PARTICIPANT	\N	PRESENT	0
494205	494103	20030R	PARTICIPANT	\N	PRESENT	0
494206	494103	19347U	PARTICIPANT	\N	PRESENT	0
494207	494103	19701S	PARTICIPANT	\N	PRESENT	0
494208	494103	19768N	PARTICIPANT	\N	PRESENT	0
494209	494103	19705W	PARTICIPANT	\N	PRESENT	0
494210	494103	20018V	PARTICIPANT	\N	PRESENT	0
494211	494103	14059S	PARTICIPANT	\N	PRESENT	0
494212	494103	14281W	PARTICIPANT	\N	PRESENT	0
494213	494103	19715Y	PARTICIPANT	\N	PRESENT	0
494214	494103	14121F	PARTICIPANT	\N	PRESENT	0
494215	494103	20024T	PARTICIPANT	\N	PRESENT	0
507173	505975	14255U	PARTICIPANT	\N	PRESENT	0
507174	505803	19768N	PARTICIPANT	\N	PRESENT	0
507175	505803	20088L	PARTICIPANT	\N	PRESENT	0
507176	505803	20092G	PARTICIPANT	\N	PRESENT	1
507177	505803	19782L	PARTICIPANT	\N	PRESENT	0
507178	505803	14357A	PARTICIPANT	\N	PRESENT	0
507179	505803	19441R	PARTICIPANT	\N	PRESENT	0
507180	505803	19413M	PARTICIPANT	\N	PRESENT	0
507181	505803	20082E	PARTICIPANT	\N	PRESENT	0
507182	505803	19631V	PARTICIPANT	\N	PRESENT	0
507183	505803	11099A	PARTICIPANT	\N	PRESENT	0
507184	505803	19705W	PARTICIPANT	\N	PRESENT	1
507185	505803	19575F	PARTICIPANT	\N	PRESENT	0
507186	505803	20018V	PARTICIPANT	\N	PRESENT	1
507187	505803	19511N	PARTICIPANT	\N	PRESENT	0
507188	505803	19563B	PARTICIPANT	\N	PRESENT	0
507189	505803	08028W	PARTICIPANT	\N	PRESENT	1
507190	505803	19521Q	PARTICIPANT	\N	PRESENT	1
507191	505803	14038Y	PARTICIPANT	\N	PRESENT	1
507192	505803	20030R	PARTICIPANT	\N	PRESENT	0
507193	505803	19467C	PARTICIPANT	\N	PRESENT	0
507194	505803	14187A	PARTICIPANT	\N	PRESENT	0
507195	505803	20144B	PARTICIPANT	\N	PRESENT	0
507196	505803	19695N	PARTICIPANT	\N	PRESENT	0
507197	505803	14033T	PARTICIPANT	\N	PRESENT	1
507198	505803	11090Q	PRESIDENT	0	PRESENT	0
507199	505803	01025N	PARTICIPANT	\N	PRESENT	0
507200	505803	20054A	PARTICIPANT	\N	PRESENT	1
507201	505803	20174H	PARTICIPANT	\N	PRESENT	0
507202	505803	20062A	PARTICIPANT	\N	PRESENT	0
507203	505803	19507S	PARTICIPANT	\N	PRESENT	0
507204	505803	19747H	PARTICIPANT	\N	PRESENT	0
507205	505803	14257W	PARTICIPANT	\N	PRESENT	0
507206	502341	11053K	PARTICIPANT	\N	PRESENT	0
507207	505975	14055N	PARTICIPANT	\N	PRESENT	1
507208	505975	20128B	PARTICIPANT	\N	PRESENT	1
507209	505975	98022P	PARTICIPANT	\N	PRESENT	1
507210	502341	14169X	PARTICIPANT	\N	PRESENT	0
507211	502341	20026V	PARTICIPANT	\N	PRESENT	0
507212	502341	11043H	PARTICIPANT	\N	PRESENT	0
507213	502341	14217N	PARTICIPANT	\N	PRESENT	0
507214	502341	07029T	PARTICIPANT	\N	PRESENT	0
507215	502341	14069U	PARTICIPANT	\N	PRESENT	0
507216	505797	14001X	PARTICIPANT	\N	PRESENT	1
507217	505803	19383Y	PARTICIPANT	\N	PRESENT	0
507218	505803	11077T	PARTICIPANT	\N	PRESENT	1
507219	505803	08015R	PARTICIPANT	\N	PRESENT	0
507220	505803	19531S	PARTICIPANT	\N	PRESENT	1
507221	505975	14331P	PARTICIPANT	\N	PRESENT	0
507222	505975	14237S	PARTICIPANT	\N	PRESENT	0
507291	502318	11074Q	PARTICIPANT	\N	PRESENT	0
507292	502318	19760E	PARTICIPANT	\N	PRESENT	0
507293	502318	11031D	PARTICIPANT	\N	PRESENT	0
507294	502318	11040E	PARTICIPANT	\N	PRESENT	0
507295	505975	12028B	PARTICIPANT	\N	PRESENT	1
507296	505975	17023S	PARTICIPANT	\N	PRESENT	1
507297	502318	19687N	PARTICIPANT	\N	PRESENT	0
507298	502318	20112S	PARTICIPANT	\N	PRESENT	0
507299	502318	19527W	PARTICIPANT	\N	PRESENT	0
507300	502318	12016W	PARTICIPANT	\N	PRESENT	0
507301	502318	20080C	PARTICIPANT	\N	PRESENT	0
507302	502318	19647E	PARTICIPANT	\N	PRESENT	0
507303	502318	14229S	PARTICIPANT	\N	PRESENT	0
507304	502318	04059M	PARTICIPANT	\N	PRESENT	0
507305	502318	20084G	PARTICIPANT	\N	PRESENT	0
507306	502318	19689Q	PARTICIPANT	\N	PRESENT	0
507307	502318	20070A	PARTICIPANT	\N	PRESENT	0
507308	502318	19333N	PARTICIPANT	\N	PRESENT	0
507309	502318	11012A	PARTICIPANT	\N	PRESENT	0
507310	502318	19545Y	PARTICIPANT	\N	PRESENT	0
507311	502318	20050V	PARTICIPANT	\N	PRESENT	0
507312	502318	20052X	PARTICIPANT	\N	PRESENT	0
507313	502318	20066E	PARTICIPANT	\N	PRESENT	0
507314	502318	11070L	PARTICIPANT	\N	PRESENT	0
507315	502318	14327T	PARTICIPANT	\N	PRESENT	0
507316	502318	19569H	PARTICIPANT	\N	PRESENT	0
507317	502318	19739H	PARTICIPANT	\N	PRESENT	0
507318	502318	19479G	PARTICIPANT	\N	PRESENT	0
507319	502318	14073Q	PARTICIPANT	\N	PRESENT	0
507320	502318	14083S	PARTICIPANT	\N	PRESENT	0
507321	502318	14089Y	PARTICIPANT	\N	PRESENT	0
507322	502318	20126Y	PARTICIPANT	\N	PRESENT	0
507323	502318	08009T	PARTICIPANT	\N	PRESENT	0
507324	502318	19703U	PARTICIPANT	\N	PRESENT	0
507325	502318	08034U	PARTICIPANT	\N	PRESENT	0
507326	502318	19415P	PARTICIPANT	\N	PRESENT	0
507327	502318	20090E	PARTICIPANT	\N	PRESENT	0
507328	502318	11097X	PARTICIPANT	\N	PRESENT	0
507329	502318	14217N	PARTICIPANT	\N	PRESENT	0
507330	502318	11103C	PARTICIPANT	\N	PRESENT	0
507331	502318	19533U	PARTICIPANT	\N	PRESENT	0
507332	502318	14223L	PARTICIPANT	\N	PRESENT	0
507333	505803	14205J	PARTICIPANT	\N	PRESENT	1
507334	505803	20060X	PARTICIPANT	\N	PRESENT	1
507335	502318	19762G	PARTICIPANT	\N	PRESENT	0
507336	502318	14069U	PARTICIPANT	\N	PRESENT	0
507337	502318	99004R	PARTICIPANT	\N	PRESENT	0
507338	502318	11043H	PARTICIPANT	\N	PRESENT	0
507339	502318	19711U	PARTICIPANT	\N	PRESENT	0
507340	502318	14031R	PARTICIPANT	\N	PRESENT	0
507341	502318	19667J	PARTICIPANT	\N	PRESENT	0
507342	502318	20032T	PARTICIPANT	\N	PRESENT	0
507343	502318	20026V	PARTICIPANT	\N	PRESENT	0
507344	502318	20056C	PARTICIPANT	\N	PRESENT	0
507345	502318	19723Y	PARTICIPANT	\N	PRESENT	0
507346	502318	18083K	PARTICIPANT	\N	PRESENT	0
507347	502318	20044X	PARTICIPANT	\N	PRESENT	0
507348	502318	14173T	PARTICIPANT	\N	PRESENT	0
507349	502318	20038A	PARTICIPANT	\N	PRESENT	0
507350	502318	19515S	PARTICIPANT	\N	PRESENT	0
507351	502318	19643A	PARTICIPANT	\N	PRESENT	0
507352	502318	20076G	PARTICIPANT	\N	PRESENT	0
507353	502318	08011M	PARTICIPANT	\N	PRESENT	0
507354	502318	07004J	PARTICIPANT	\N	PRESENT	0
507355	502318	20024T	PARTICIPANT	\N	PRESENT	0
507356	502318	19503N	PARTICIPANT	\N	PRESENT	0
507289	502318	01043Q	PARTICIPANT	\N	PRESENT	0
507290	502318	11048N	PARTICIPANT	\N	PRESENT	0
507357	502318	20092G	PARTICIPANT	\N	PRESENT	0
507358	502318	19651A	PARTICIPANT	\N	PRESENT	0
507359	505803	20034V	PARTICIPANT	\N	PRESENT	0
507360	502318	19399H	PARTICIPANT	\N	PRESENT	0
507361	502318	14041T	PARTICIPANT	\N	PRESENT	0
507362	502318	04045F	PARTICIPANT	\N	PRESENT	0
507363	502318	19349W	PARTICIPANT	\N	PRESENT	0
507364	502318	20172F	PARTICIPANT	\N	PRESENT	0
507365	502318	14169X	PARTICIPANT	\N	PRESENT	0
507366	502318	14189C	PARTICIPANT	\N	PRESENT	0
507367	502318	07029T	PARTICIPANT	\N	PRESENT	0
507368	502318	19671E	PARTICIPANT	\N	PRESENT	0
507369	502318	14253S	PARTICIPANT	\N	PRESENT	0
507370	502318	20086J	PARTICIPANT	\N	PRESENT	0
507371	502318	11065P	PARTICIPANT	\N	PRESENT	0
507372	502318	95063L	PARTICIPANT	\N	PRESENT	0
507373	502318	14215L	PARTICIPANT	\N	PRESENT	0
507374	502318	19629C	PARTICIPANT	\N	PRESENT	0
507375	502318	14179A	PARTICIPANT	\N	PRESENT	0
507376	502318	08061X	PARTICIPANT	\N	PRESENT	0
507378	502318	17367Q	PARTICIPANT	\N	PRESENT	0
507379	502318	19367Y	PARTICIPANT	\N	PRESENT	0
507380	502318	19954N	PARTICIPANT	\N	PRESENT	0
507381	502318	19573D	PARTICIPANT	\N	PRESENT	0
507382	502318	14107H	PARTICIPANT	\N	PRESENT	0
507383	502318	19729F	PARTICIPANT	\N	PRESENT	0
507384	502318	01028R	PARTICIPANT	\N	PRESENT	0
507385	502318	19691J	PARTICIPANT	\N	PRESENT	0
507386	502318	14147R	PARTICIPANT	\N	PRESENT	0
507389	502318	01057W	PARTICIPANT	\N	PRESENT	0
507390	502318	19826F	PARTICIPANT	\N	PRESENT	0
507391	502318	14225N	PARTICIPANT	\N	PRESENT	0
507392	502318	19551W	PARTICIPANT	\N	PRESENT	0
507393	502318	97011G	PARTICIPANT	\N	PRESENT	0
507394	505976	19443T	PARTICIPANT	\N	PRESENT	1
507396	505976	01058X	PARTICIPANT	\N	PRESENT	1
507399	505976	04042C	PRESIDENT	0	PRESENT	0
507400	505976	11066Q	PARTICIPANT	\N	PRESENT	0
507402	505976	14237S	PARTICIPANT	\N	PRESENT	0
484384	483351	19349W	PARTICIPANT	\N	PRESENT	0
484385	483351	19479G	PARTICIPANT	\N	PRESENT	0
484386	483351	19766L	PARTICIPANT	\N	PRESENT	0
484387	483351	19649G	PARTICIPANT	\N	PRESENT	0
484388	483351	19691J	PARTICIPANT	\N	PRESENT	0
484389	483351	89017R	PARTICIPANT	\N	PRESENT	0
484673	484672	11083R	PARTICIPANT	\N	PRESENT	0
484674	484672	19503N	PARTICIPANT	\N	PRESENT	0
484675	484672	14255U	PARTICIPANT	\N	PRESENT	0
484750	484747	98035U	PARTICIPANT	\N	PRESENT	0
484751	484747	19649G	PARTICIPANT	\N	PRESENT	0
484752	484747	11026G	PARTICIPANT	\N	PRESENT	0
484753	484747	01024M	PARTICIPANT	\N	PRESENT	0
484754	484747	04038G	PARTICIPANT	\N	PRESENT	0
484755	484747	19585H	PARTICIPANT	\N	PRESENT	0
484756	484747	19673G	PARTICIPANT	\N	PRESENT	0
484757	484747	01028R	PARTICIPANT	\N	PRESENT	0
484758	484747	11033F	PARTICIPANT	\N	PRESENT	0
484759	484747	05008E	PRESIDENT	0	PRESENT	0
484760	484747	19930E	PARTICIPANT	\N	PRESENT	0
484761	484747	95063L	PARTICIPANT	\N	PRESENT	0
484762	484747	14147R	PARTICIPANT	\N	PRESENT	0
484763	484747	14151M	PARTICIPANT	\N	PRESENT	0
484764	484747	11072N	PARTICIPANT	\N	PRESENT	0
484765	484747	19543W	PARTICIPANT	\N	PRESENT	0
484766	484558	14327T	PARTICIPANT	\N	PRESENT	0
484767	484558	04086Q	PARTICIPANT	\N	PRESENT	0
484768	484558	14331P	PARTICIPANT	\N	PRESENT	0
484769	484558	11012A	PARTICIPANT	\N	PRESENT	0
484770	484558	19651A	PARTICIPANT	\N	PRESENT	0
484771	484558	07004J	PARTICIPANT	\N	PRESENT	0
484785	484558	19687N	PARTICIPANT	\N	PRESENT	0
484773	484558	19667J	PARTICIPANT	\N	PRESENT	0
484774	484558	11074Q	PRESIDENT	0	PRESENT	0
484775	484558	14225N	PARTICIPANT	\N	PRESENT	0
484776	484558	11070L	PARTICIPANT	\N	PRESENT	0
484777	484558	19762G	PARTICIPANT	\N	PRESENT	0
484778	484558	96004D	PARTICIPANT	\N	PRESENT	0
484779	484558	12016W	PARTICIPANT	\N	PRESENT	0
484780	484558	14085U	PARTICIPANT	\N	PRESENT	0
484781	484558	11048N	PARTICIPANT	\N	PRESENT	0
484782	484558	19741B	PARTICIPANT	\N	PRESENT	0
484783	484558	01057W	PARTICIPANT	\N	PRESENT	0
484784	484558	19531S	PARTICIPANT	\N	PRESENT	0
484786	484558	11053K	PARTICIPANT	\N	PRESENT	0
484787	484558	19479G	PARTICIPANT	\N	PRESENT	0
484788	484558	14083S	PARTICIPANT	\N	PRESENT	0
484789	484558	07029T	PARTICIPANT	\N	EXCUSE	0
484790	484558	19545Y	PARTICIPANT	\N	PRESENT	0
484791	484558	19711U	PARTICIPANT	\N	PRESENT	0
484792	484558	08011M	PARTICIPANT	\N	PRESENT	0
484830	484818	04088S	PARTICIPANT	\N	PRESENT	0
484831	484818	11056N	PARTICIPANT	\N	PRESENT	0
484832	484818	19515S	PARTICIPANT	\N	PRESENT	0
484833	484818	14357A	PARTICIPANT	\N	PRESENT	0
484834	484818	19441R	PARTICIPANT	\N	PRESENT	0
484835	484818	11090Q	PRESIDENT	0	PRESENT	0
484836	484818	19912C	PARTICIPANT	\N	PRESENT	0
484837	484818	19631V	PARTICIPANT	\N	PRESENT	0
484838	484818	19563B	PARTICIPANT	\N	PRESENT	0
484839	484818	14265W	PARTICIPANT	\N	PRESENT	0
484840	484818	19782L	PARTICIPANT	\N	EXCUSE	0
484841	484818	19369B	PARTICIPANT	\N	EXCUSE	0
484842	483388	19593H	PARTICIPANT	\N	PRESENT	0
484843	483388	04070G	PRESIDENT	0	PRESENT	0
484844	483388	19731Y	PARTICIPANT	\N	PRESENT	0
484845	483388	19573D	PARTICIPANT	\N	PRESENT	0
484846	483388	11083R	PARTICIPANT	\N	PRESENT	0
484847	483388	19693L	PARTICIPANT	\N	PRESENT	0
484848	483388	19399H	PARTICIPANT	\N	PRESENT	0
484849	483388	04018C	PARTICIPANT	\N	PRESENT	0
484850	483388	14229S	PARTICIPANT	\N	PRESENT	0
484851	483388	08039A	PARTICIPANT	\N	PRESENT	0
484852	483388	08031R	PARTICIPANT	\N	PRESENT	0
484853	483388	14030Q	PARTICIPANT	\N	PRESENT	0
484854	483388	14061L	PARTICIPANT	\N	EXCUSE	0
484855	483388	14063N	PARTICIPANT	\N	EXCUSE	0
484856	483388	87003B	PARTICIPANT	\N	EXCUSE	0
484857	483388	19758L	PARTICIPANT	\N	EXCUSE	0
484858	483388	19621T	PARTICIPANT	\N	EXCUSE	0
484861	484818	14033T	PARTICIPANT	\N	PRESENT	0
484862	484559	17583W	PARTICIPANT	\N	EXCUSE	0
484863	484559	04097T	PARTICIPANT	\N	EXCUSE	0
484864	484559	08009T	PARTICIPANT	\N	EXCUSE	0
484865	484559	19739H	PARTICIPANT	\N	PRESENT	0
484866	484559	19551W	PARTICIPANT	\N	EXCUSE	0
484867	484559	14093U	PARTICIPANT	\N	EXCUSE	0
484868	484559	19820Y	PARTICIPANT	\N	EXCUSE	0
484869	484559	19745F	PARTICIPANT	\N	EXCUSE	0
484870	484566	08049C	PARTICIPANT	\N	EXCUSE	0
485175	484735	86034E	PARTICIPANT	\N	PRESENT	0
485177	484735	11040E	PARTICIPANT	\N	PRESENT	0
485178	484735	19565D	PARTICIPANT	\N	PRESENT	0
485179	484735	11033F	PARTICIPANT	\N	PRESENT	0
485180	484735	99004R	PARTICIPANT	\N	PRESENT	0
485181	484735	19760E	PARTICIPANT	\N	PRESENT	0
485182	484735	04043D	PARTICIPANT	\N	PRESENT	0
485183	484735	19758L	PARTICIPANT	\N	PRESENT	0
485184	484735	19695N	PARTICIPANT	\N	PRESENT	0
485185	484735	19687N	PARTICIPANT	\N	PRESENT	0
485186	484735	19593H	PARTICIPANT	\N	PRESENT	0
485187	484735	98035U	PARTICIPANT	\N	PRESENT	0
485188	484735	14229S	PARTICIPANT	\N	PRESENT	0
485189	484735	01028R	PARTICIPANT	\N	PRESENT	0
485190	484735	19766L	PARTICIPANT	\N	PRESENT	0
485191	484735	08052W	PARTICIPANT	\N	PRESENT	0
485192	484735	19912C	PARTICIPANT	\N	PRESENT	0
485193	484735	14021P	PARTICIPANT	\N	PRESENT	0
485194	484735	04059M	PARTICIPANT	\N	PRESENT	0
485195	484735	19715Y	PARTICIPANT	\N	PRESENT	0
485196	484735	11080N	PARTICIPANT	\N	PRESENT	0
485197	484735	11066Q	PARTICIPANT	\N	PRESENT	0
485198	484735	14081Q	PARTICIPANT	\N	PRESENT	0
485199	484735	01057W	PARTICIPANT	\N	PRESENT	0
485200	484735	19525U	PARTICIPANT	\N	PRESENT	0
485201	484735	87003B	PARTICIPANT	\N	PRESENT	0
485202	484735	19649G	PARTICIPANT	\N	PRESENT	0
485203	484735	12041X	PARTICIPANT	\N	PRESENT	0
485204	484735	14097Y	PARTICIPANT	\N	PRESENT	0
485205	484735	11045K	PARTICIPANT	\N	PRESENT	0
485206	484735	19711U	PARTICIPANT	\N	PRESENT	0
485207	484735	08012N	PARTICIPANT	\N	PRESENT	0
485208	484735	14085U	PARTICIPANT	\N	PRESENT	0
485209	484735	08039A	PARTICIPANT	\N	PRESENT	0
485210	484735	08010L	PARTICIPANT	\N	PRESENT	0
485211	484735	04086Q	PARTICIPANT	\N	PRESENT	0
485212	484735	11067R	PARTICIPANT	\N	PRESENT	0
485213	484735	19503N	PARTICIPANT	\N	PRESENT	0
485214	484735	11026G	PARTICIPANT	\N	PRESENT	0
485215	484735	05008E	PARTICIPANT	\N	PRESENT	0
485216	484735	19413M	PARTICIPANT	\N	PRESENT	0
485217	484735	14187A	PARTICIPANT	\N	PRESENT	0
485218	484735	19347U	PARTICIPANT	\N	PRESENT	0
485219	484735	19531S	PARTICIPANT	\N	PRESENT	0
485220	484735	04033B	PARTICIPANT	\N	PRESENT	0
485221	484735	19631V	PARTICIPANT	\N	PRESENT	0
485222	484735	19725B	PARTICIPANT	\N	PRESENT	0
485223	484735	19549D	PARTICIPANT	\N	PRESENT	0
485224	484735	14069U	PARTICIPANT	\N	PRESENT	0
485225	484735	08024S	PARTICIPANT	\N	PRESENT	0
485226	484735	19573D	PARTICIPANT	\N	PRESENT	0
485227	484735	11072N	PARTICIPANT	\N	PRESENT	0
485228	484735	19794Q	PARTICIPANT	\N	PRESENT	0
485229	484735	19697Q	PARTICIPANT	\N	PRESENT	0
485230	484735	14119M	PARTICIPANT	\N	PRESENT	0
485231	484735	19349W	PARTICIPANT	\N	PRESENT	0
485232	484735	19954N	PARTICIPANT	\N	PRESENT	0
485233	484735	19637C	PARTICIPANT	\N	PRESENT	0
485234	484735	01048V	PARTICIPANT	\N	PRESENT	0
485235	484735	19651A	PARTICIPANT	\N	PRESENT	0
485236	484735	11048N	PARTICIPANT	\N	PRESENT	0
485237	484735	11083R	PARTICIPANT	\N	PRESENT	0
485238	484735	04049K	PARTICIPANT	\N	PRESENT	0
485239	484735	04045F	PARTICIPANT	\N	PRESENT	0
485240	484735	08061X	PARTICIPANT	\N	PRESENT	0
485241	484735	19533U	PARTICIPANT	\N	PRESENT	0
485242	484735	95063L	PARTICIPANT	\N	PRESENT	0
485243	484735	10006L	PARTICIPANT	\N	PRESENT	0
485244	484735	88008L	PARTICIPANT	\N	PRESENT	0
485245	484735	14147R	PARTICIPANT	\N	PRESENT	0
485246	484735	95037J	PARTICIPANT	\N	PRESENT	0
485247	484735	14217N	PARTICIPANT	\N	PRESENT	0
485248	484735	19585H	PARTICIPANT	\N	PRESENT	0
485249	484735	11041F	PARTICIPANT	\N	PRESENT	0
485250	484735	14331P	PARTICIPANT	\N	PRESENT	0
485251	484735	19563B	PARTICIPANT	\N	PRESENT	0
485252	484735	11097X	PARTICIPANT	\N	PRESENT	0
485253	484735	04057K	PARTICIPANT	\N	PRESENT	0
485254	484735	04018C	PARTICIPANT	\N	PRESENT	0
501350	500281	19679N	PARTICIPANT	\N	PRESENT	0
501351	500476	11048N	PARTICIPANT	\N	PRESENT	0
501352	500476	19479G	PARTICIPANT	\N	PRESENT	0
501353	500476	19711U	PARTICIPANT	\N	PRESENT	0
501354	500476	19671E	PARTICIPANT	\N	PRESENT	0
501355	500476	11070L	PARTICIPANT	\N	PRESENT	0
501356	500476	11040E	PARTICIPANT	\N	PRESENT	0
501357	500476	20070A	PARTICIPANT	\N	PRESENT	0
501358	500476	19762G	PARTICIPANT	\N	PRESENT	0
501359	500281	14069U	PARTICIPANT	\N	PRESENT	0
501360	500281	19575F	PARTICIPANT	\N	PRESENT	0
501361	500281	19723Y	PARTICIPANT	\N	PRESENT	0
501362	500281	14031R	PARTICIPANT	\N	PRESENT	0
501363	500281	19591F	PARTICIPANT	\N	PRESENT	0
501364	500281	19553Y	PARTICIPANT	\N	PRESENT	0
501365	500281	20104S	PARTICIPANT	\N	PRESENT	0
501366	500281	19643A	PARTICIPANT	\N	PRESENT	0
501367	500281	20122U	PARTICIPANT	\N	PRESENT	0
501368	500281	19387D	PARTICIPANT	\N	PRESENT	0
501369	500281	08061X	PARTICIPANT	\N	PRESENT	0
501370	500281	11043H	PARTICIPANT	\N	PRESENT	0
501371	500281	14231L	PARTICIPANT	\N	PRESENT	0
501372	500281	20086J	PARTICIPANT	\N	PRESENT	0
501373	500281	19758L	PARTICIPANT	\N	PRESENT	0
501374	500281	19703U	PARTICIPANT	\N	PRESENT	0
501375	500281	04043D	PARTICIPANT	\N	PRESENT	0
501376	500281	20114U	PARTICIPANT	\N	PRESENT	0
501377	500281	08069G	PARTICIPANT	\N	PRESENT	0
501378	500281	19691J	PARTICIPANT	\N	PRESENT	0
501379	500281	19543W	PARTICIPANT	\N	PRESENT	0
501381	500281	08017T	PARTICIPANT	\N	PRESENT	0
501382	500281	14123H	PARTICIPANT	\N	PRESENT	0
501383	500281	19333N	PARTICIPANT	\N	PRESENT	0
501384	500281	20034V	PARTICIPANT	\N	PRESENT	0
501387	500281	19629C	PARTICIPANT	\N	PRESENT	0
501388	500281	19649G	PARTICIPANT	\N	PRESENT	0
501389	500281	19619A	PARTICIPANT	\N	PRESENT	0
501390	500572	20122U	PARTICIPANT	\N	PRESENT	0
501391	500572	19701S	PARTICIPANT	\N	PRESENT	0
501392	500572	14031R	PARTICIPANT	\N	PRESENT	0
501393	500572	20038A	PARTICIPANT	\N	PRESENT	0
501394	500572	20140W	PARTICIPANT	\N	PRESENT	0
501395	500572	19739H	PARTICIPANT	\N	PRESENT	0
501396	500572	19820Y	PARTICIPANT	\N	PRESENT	0
501397	500572	14219Q	PRESIDENT	0	PRESENT	0
501398	500572	19251M	PARTICIPANT	\N	PRESENT	0
501399	500572	20022R	PARTICIPANT	\N	PRESENT	0
501400	500572	19577H	PARTICIPANT	\N	PRESENT	0
501402	500572	20136B	PARTICIPANT	\N	PRESENT	0
501403	500572	11101A	PARTICIPANT	\N	PRESENT	0
501404	500572	19745F	PARTICIPANT	\N	PRESENT	0
501405	500572	18083K	PARTICIPANT	\N	PRESENT	0
501406	500572	19826F	PARTICIPANT	\N	PRESENT	0
501407	500572	20068G	PARTICIPANT	\N	PRESENT	0
501408	500572	20024T	PARTICIPANT	\N	PRESENT	0
501409	500572	19695N	PARTICIPANT	\N	PRESENT	0
501410	500572	11090Q	PARTICIPANT	\N	PRESENT	0
501411	500572	19768N	PARTICIPANT	\N	PRESENT	0
501412	500572	19441R	PARTICIPANT	\N	PRESENT	0
501413	500572	05012A	PARTICIPANT	\N	PRESENT	0
501414	500572	08015R	PARTICIPANT	\N	PRESENT	0
501415	500572	19503N	PARTICIPANT	\N	PRESENT	0
501417	500572	11065P	PARTICIPANT	\N	PRESENT	0
501418	500572	20144B	PARTICIPANT	\N	PRESENT	0
501419	500572	14033T	PARTICIPANT	\N	PRESENT	0
501420	500572	14207L	PARTICIPANT	\N	PRESENT	0
501421	500572	14257W	PARTICIPANT	\N	PRESENT	0
501422	500476	14327T	PARTICIPANT	\N	PRESENT	0
501423	500476	04071H	PARTICIPANT	\N	PRESENT	0
501424	500476	19689Q	PARTICIPANT	\N	PRESENT	0
501425	500476	20044X	PARTICIPANT	\N	PRESENT	0
501426	500476	11012A	PARTICIPANT	\N	PRESENT	0
501427	500281	20172F	PARTICIPANT	\N	PRESENT	0
501428	500281	19507S	PARTICIPANT	\N	PRESENT	0
501429	500281	20142Y	PARTICIPANT	\N	PRESENT	0
501430	500281	19663E	PARTICIPANT	\N	PRESENT	0
501431	500281	11085T	PARTICIPANT	\N	PRESENT	0
501432	500281	14217N	PARTICIPANT	\N	PRESENT	0
501435	500281	20124W	PARTICIPANT	\N	PRESENT	0
501436	500281	20126Y	PARTICIPANT	\N	PRESENT	0
501439	500281	19479G	PARTICIPANT	\N	PRESENT	0
501440	500502	20086J	PARTICIPANT	\N	PRESENT	0
501441	500502	19515S	PARTICIPANT	\N	PRESENT	0
501442	500502	20092G	PARTICIPANT	\N	PRESENT	0
501443	500502	14357A	PARTICIPANT	\N	PRESENT	0
501444	500502	19695N	PARTICIPANT	\N	PRESENT	0
501445	500502	11090Q	PRESIDENT	0	PRESENT	0
501446	500502	20094J	PARTICIPANT	\N	PRESENT	0
501447	500502	20054A	PARTICIPANT	\N	PRESENT	0
501448	500502	20104S	PARTICIPANT	\N	PRESENT	0
501449	500502	20174H	PARTICIPANT	\N	PRESENT	0
501450	500502	20062A	PARTICIPANT	\N	PRESENT	0
501451	500502	19705W	PARTICIPANT	\N	PRESENT	0
501452	500502	19575F	PARTICIPANT	\N	PRESENT	0
501453	500502	19747H	PARTICIPANT	\N	PRESENT	0
501454	500502	19511N	PARTICIPANT	\N	PRESENT	0
501455	500476	19669L	PARTICIPANT	\N	PRESENT	0
501456	500476	19421M	PARTICIPANT	\N	PRESENT	0
501457	500476	14073Q	PARTICIPANT	\N	PRESENT	0
501458	500502	19768N	PARTICIPANT	\N	PRESENT	0
501459	500502	20088L	PARTICIPANT	\N	PRESENT	0
501460	500502	19701S	PARTICIPANT	\N	PRESENT	0
501461	500502	19441R	PARTICIPANT	\N	PRESENT	0
501462	500502	19387D	PARTICIPANT	\N	PRESENT	0
501463	500502	19413M	PARTICIPANT	\N	PRESENT	0
501464	500502	20082E	PARTICIPANT	\N	PRESENT	0
501465	500502	14219Q	PARTICIPANT	\N	PRESENT	0
501466	500502	18083K	PARTICIPANT	\N	PRESENT	0
501467	500502	05012A	PARTICIPANT	\N	PRESENT	0
501468	500502	20106U	PARTICIPANT	\N	PRESENT	0
501469	500502	20118Y	PARTICIPANT	\N	PRESENT	0
501470	500502	08015R	PARTICIPANT	\N	PRESENT	0
501471	500502	19503N	PARTICIPANT	\N	PRESENT	0
501472	500502	20018V	PARTICIPANT	\N	PRESENT	0
501473	500502	19563B	PARTICIPANT	\N	PRESENT	0
501474	500502	19521Q	PARTICIPANT	\N	PRESENT	0
501475	500502	11065P	PARTICIPANT	\N	PRESENT	0
501476	500502	20140W	PARTICIPANT	\N	PRESENT	0
501477	500502	20144B	PARTICIPANT	\N	PRESENT	0
501478	500502	14033T	PARTICIPANT	\N	PRESENT	0
501479	500502	14169X	PARTICIPANT	\N	PRESENT	0
501480	500502	20060X	PARTICIPANT	\N	PRESENT	0
501481	500502	19739H	PARTICIPANT	\N	PRESENT	0
501482	500502	19745F	PARTICIPANT	\N	PRESENT	0
501483	500502	14207L	PARTICIPANT	\N	PRESENT	0
501484	500502	19577H	PARTICIPANT	\N	PRESENT	0
501485	500502	19619A	PARTICIPANT	\N	PRESENT	0
501486	500502	14257W	PARTICIPANT	\N	PRESENT	0
501487	500502	14251Q	PARTICIPANT	\N	PRESENT	0
501488	500281	19565D	PARTICIPANT	\N	PRESENT	0
501489	500281	14026U	PARTICIPANT	\N	PRESENT	0
501490	500281	19713W	PARTICIPANT	\N	PRESENT	0
501493	500281	04059M	PARTICIPANT	\N	PRESENT	0
501494	500281	19533U	PARTICIPANT	\N	PRESENT	0
501495	500281	14331P	PARTICIPANT	\N	PRESENT	0
501496	500502	11077T	PARTICIPANT	\N	PRESENT	0
501497	500502	11101A	PARTICIPANT	\N	PRESENT	0
501498	500116	19643A	PARTICIPANT	\N	PRESENT	0
501499	500116	19693L	PARTICIPANT	\N	PRESENT	0
501500	500116	20152B	PARTICIPANT	\N	PRESENT	0
501501	500116	20124W	PARTICIPANT	\N	EXCUSE	0
501504	500116	04070G	PARTICIPANT	\N	PRESENT	0
501505	500116	19699S	PARTICIPANT	\N	PRESENT	0
501506	500116	19533U	PARTICIPANT	\N	PRESENT	0
501507	500116	14229S	PARTICIPANT	\N	PRESENT	0
501508	500116	20098N	PARTICIPANT	\N	PRESENT	0
501509	500116	08017T	PARTICIPANT	\N	PRESENT	0
501510	500116	92040Q	PARTICIPANT	\N	PRESENT	0
501511	500116	07033P	PARTICIPANT	\N	PRESENT	0
501512	500116	20026V	PARTICIPANT	\N	PRESENT	0
501513	500116	20120S	PARTICIPANT	\N	PRESENT	0
501514	500116	19527W	PARTICIPANT	\N	PRESENT	0
501515	500116	19593H	PARTICIPANT	\N	PRESENT	0
501516	500116	20132W	PARTICIPANT	\N	PRESENT	0
501517	500116	20134Y	PARTICIPANT	\N	PRESENT	0
501518	500116	19651A	PARTICIPANT	\N	PRESENT	0
501519	500116	19611R	PRESIDENT	0	PRESENT	0
501520	500116	19399H	PARTICIPANT	\N	PRESENT	0
501521	500116	20052X	PARTICIPANT	\N	PRESENT	0
501522	500116	14030Q	PARTICIPANT	\N	PRESENT	0
501523	500116	20056C	PARTICIPANT	\N	PRESENT	0
501524	500116	04059M	PARTICIPANT	\N	PRESENT	0
501525	500116	19735D	PARTICIPANT	\N	PRESENT	0
501526	500116	14109K	PARTICIPANT	\N	PRESENT	0
501527	500116	19758L	PARTICIPANT	\N	PRESENT	0
501528	500116	20084G	PARTICIPANT	\N	PRESENT	0
501529	500281	08010L	PARTICIPANT	\N	PRESENT	0
488487	488427	19766L	PARTICIPANT	\N	PRESENT	0
489555	489553	19647E	PARTICIPANT	\N	PRESENT	0
488489	488427	19479G	PARTICIPANT	\N	PRESENT	0
488490	488427	11067R	PARTICIPANT	\N	PRESENT	0
494216	494103	20052X	PARTICIPANT	\N	PRESENT	0
494217	494103	20054A	PARTICIPANT	\N	PRESENT	0
488493	488427	11097X	PRESIDENT	0	PRESENT	0
494218	494103	11053K	PARTICIPANT	\N	PRESENT	0
488495	488427	19715Y	PARTICIPANT	\N	PRESENT	0
488497	488427	19667J	PARTICIPANT	\N	PRESENT	0
488498	488427	19447X	PARTICIPANT	\N	PRESENT	0
488499	488427	04085P	PARTICIPANT	\N	PRESENT	0
491870	491869	11053K	PARTICIPANT	\N	PRESENT	0
488501	488427	19703U	PARTICIPANT	\N	PRESENT	0
488502	488427	19573D	PARTICIPANT	\N	PRESENT	0
494219	494103	19573D	PARTICIPANT	\N	PRESENT	0
488504	488427	14041T	PARTICIPANT	\N	PRESENT	0
488505	488427	99004R	PARTICIPANT	\N	PRESENT	0
488506	488427	10006L	PARTICIPANT	\N	PRESENT	0
488507	488427	89017R	PARTICIPANT	\N	EXCUSE	0
488508	488427	19697Q	PARTICIPANT	\N	PRESENT	0
488509	488427	11048N	PARTICIPANT	\N	PRESENT	0
488510	488427	04092N	PARTICIPANT	\N	PRESENT	0
488511	488427	14081Q	PARTICIPANT	\N	PRESENT	0
488512	488427	11070L	PARTICIPANT	\N	PRESENT	0
488513	488427	19503N	PARTICIPANT	\N	PRESENT	0
488514	488427	19683J	PARTICIPANT	\N	PRESENT	0
489554	489553	11070L	PARTICIPANT	\N	PRESENT	0
494220	494103	20034V	PARTICIPANT	\N	PRESENT	0
494221	494103	19521Q	PARTICIPANT	\N	PRESENT	0
494222	494103	14231L	PARTICIPANT	\N	PRESENT	0
494223	494103	14179A	PARTICIPANT	\N	PRESENT	0
494224	494103	20098N	PARTICIPANT	\N	PRESENT	0
494225	494103	19691J	PARTICIPANT	\N	PRESENT	0
494226	494103	19447X	PARTICIPANT	\N	PRESENT	0
494227	494103	14173T	PARTICIPANT	\N	PRESENT	0
494228	494103	11070L	PARTICIPANT	\N	PRESENT	0
494229	494103	14219Q	PARTICIPANT	\N	PRESENT	0
494230	494103	19569H	PARTICIPANT	\N	PRESENT	0
494231	494103	19739H	PARTICIPANT	\N	PRESENT	0
494232	494103	19479G	PARTICIPANT	\N	PRESENT	0
494233	494103	20096L	PARTICIPANT	\N	PRESENT	0
494234	494103	19713W	PARTICIPANT	\N	PRESENT	0
494235	494103	14073Q	PARTICIPANT	\N	PRESENT	0
494236	494103	19399H	PARTICIPANT	\N	PRESENT	0
494237	494103	14267Y	PARTICIPANT	\N	PRESENT	0
494238	494103	01025N	PARTICIPANT	\N	PRESENT	0
494239	494103	19335Q	PARTICIPANT	\N	PRESENT	0
494240	494103	14255U	PARTICIPANT	\N	PRESENT	0
494241	494103	14217N	PARTICIPANT	\N	PRESENT	0
494242	494103	11085T	PARTICIPANT	\N	PRESENT	0
494243	494103	19762G	PARTICIPANT	\N	PRESENT	0
494244	494103	14030Q	PARTICIPANT	\N	PRESENT	0
494245	494103	01024M	PARTICIPANT	\N	PRESENT	0
494246	494103	01043Q	PARTICIPANT	\N	PRESENT	0
494247	494103	20020P	PARTICIPANT	\N	PRESENT	0
494248	494103	19826F	PARTICIPANT	\N	PRESENT	0
494249	494103	95041E	PARTICIPANT	\N	PRESENT	0
494250	494103	19581D	PARTICIPANT	\N	PRESENT	0
494251	494103	14133K	PARTICIPANT	\N	PRESENT	0
494252	494103	14237S	PARTICIPANT	\N	PRESENT	0
494253	494103	14071N	PARTICIPANT	\N	PRESENT	0
494254	494103	11097X	PARTICIPANT	\N	PRESENT	0
494255	494103	20132W	PARTICIPANT	\N	PRESENT	0
494256	494103	01058X	PARTICIPANT	\N	PRESENT	0
494257	494103	11090Q	PARTICIPANT	\N	PRESENT	0
494258	494103	04033B	PARTICIPANT	\N	PRESENT	0
494259	494103	19533U	PARTICIPANT	\N	PRESENT	0
494260	494103	04042C	PARTICIPANT	\N	PRESENT	0
494261	494103	19575F	PARTICIPANT	\N	PRESENT	0
494262	494103	14193X	PARTICIPANT	\N	PRESENT	0
494263	494103	20136B	PARTICIPANT	\N	PRESENT	0
494264	494103	14147R	PARTICIPANT	\N	PRESENT	0
494265	494103	11043H	PARTICIPANT	\N	PRESENT	0
494266	494103	14055N	PARTICIPANT	\N	PRESENT	0
494267	494103	19685L	PARTICIPANT	\N	PRESENT	0
494268	494103	14189C	PARTICIPANT	\N	PRESENT	0
494269	494103	14031R	PARTICIPANT	\N	PRESENT	0
494270	494103	86034E	PARTICIPANT	\N	PRESENT	0
494271	494103	20026V	PARTICIPANT	\N	PRESENT	0
494272	494103	19551W	PARTICIPANT	\N	PRESENT	0
494273	494103	12041X	PARTICIPANT	\N	PRESENT	0
494274	494103	19467C	PARTICIPANT	\N	PRESENT	0
494275	494103	20124W	PARTICIPANT	\N	PRESENT	0
494276	494103	19954N	PARTICIPANT	\N	PRESENT	0
494277	494103	19693L	PARTICIPANT	\N	PRESENT	0
494278	494103	14331P	PARTICIPANT	\N	PRESENT	0
494279	494103	14213J	PARTICIPANT	\N	PRESENT	0
494280	494103	20056C	PARTICIPANT	\N	PRESENT	0
494281	494103	20118Y	PARTICIPANT	\N	PRESENT	0
494282	494103	19667J	PARTICIPANT	\N	PRESENT	0
494283	494103	08015R	PARTICIPANT	\N	PRESENT	0
494284	494103	08012N	PARTICIPANT	\N	PRESENT	0
494285	494103	17023S	PARTICIPANT	\N	PRESENT	0
494287	494103	01057W	PARTICIPANT	\N	PRESENT	0
494288	494103	17367Q	PARTICIPANT	\N	PRESENT	0
494289	494103	14069U	PARTICIPANT	\N	PRESENT	0
494290	494103	20102Q	PARTICIPANT	\N	PRESENT	0
494291	494103	20036X	PARTICIPANT	\N	PRESENT	0
494292	494103	20066E	PARTICIPANT	\N	PRESENT	0
494293	494103	20042V	PARTICIPANT	\N	PRESENT	0
494294	494103	19507S	PARTICIPANT	\N	PRESENT	0
494296	494103	20062A	PARTICIPANT	\N	PRESENT	0
494297	494103	19525U	PARTICIPANT	\N	PRESENT	0
494298	494103	19531S	PARTICIPANT	\N	PRESENT	0
494299	494103	19745F	PARTICIPANT	\N	PRESENT	0
494493	493361	11045K	PARTICIPANT	\N	PRESENT	0
494494	493273	14059S	PARTICIPANT	\N	PRESENT	0
494495	493273	11041F	PARTICIPANT	\N	PRESENT	0
494496	493273	14193X	PARTICIPANT	\N	PRESENT	0
494497	493273	04042C	PRESIDENT	0	PRESENT	0
494498	493273	11066Q	PARTICIPANT	\N	PRESENT	0
494499	493273	12041X	PARTICIPANT	\N	PRESENT	0
494500	493273	20064C	PARTICIPANT	\N	PRESENT	0
494501	493273	19443T	PARTICIPANT	\N	PRESENT	0
494502	493273	19421M	PARTICIPANT	\N	PRESENT	0
494503	493273	20042V	PARTICIPANT	\N	PRESENT	0
494504	493273	11027H	PARTICIPANT	\N	PRESENT	0
494505	493273	14255U	PARTICIPANT	\N	PRESENT	0
494506	493361	20146D	PARTICIPANT	\N	PRESENT	0
494507	493361	14121F	PARTICIPANT	\N	PRESENT	0
494508	493361	20026V	PARTICIPANT	\N	PRESENT	0
494509	493361	20034V	PARTICIPANT	\N	PRESENT	0
494514	493361	14042U	PARTICIPANT	\N	PRESENT	0
494515	493273	14097Y	PARTICIPANT	\N	PRESENT	0
494516	493273	04035D	PARTICIPANT	\N	PRESENT	0
494517	493273	95041E	PARTICIPANT	\N	PRESENT	0
494518	493273	11083R	PARTICIPANT	\N	PRESENT	0
494519	493361	20066E	PARTICIPANT	\N	PRESENT	0
494582	493361	19515S	PARTICIPANT	\N	PRESENT	0
494583	493273	14105F	PARTICIPANT	\N	PRESENT	0
494594	493361	19695N	PARTICIPANT	\N	PRESENT	0
494585	493361	19820Y	PARTICIPANT	\N	PRESENT	0
494586	493361	19569H	PARTICIPANT	\N	PRESENT	0
494600	493361	14083S	PARTICIPANT	\N	PRESENT	0
494601	493361	20038A	PARTICIPANT	\N	PRESENT	0
494602	493361	20058E	PARTICIPANT	\N	PRESENT	0
494603	491698	19593H	PARTICIPANT	\N	PRESENT	0
494604	491698	19533U	PARTICIPANT	\N	PRESENT	0
494605	491698	19651A	PARTICIPANT	\N	PRESENT	0
494606	491698	20142Y	PARTICIPANT	\N	PRESENT	0
494607	491698	20048C	PARTICIPANT	\N	PRESENT	0
494608	491698	19693L	PARTICIPANT	\N	PRESENT	0
494609	491698	20052X	PARTICIPANT	\N	PRESENT	0
494610	491698	14030Q	PARTICIPANT	\N	PRESENT	0
494830	493327	19643A	PARTICIPANT	\N	PRESENT	0
494612	491698	20124W	PARTICIPANT	\N	PRESENT	0
494613	491698	19758L	PARTICIPANT	\N	PRESENT	0
494614	491698	19621T	PRESIDENT	0	PRESENT	0
494615	491698	20132W	PARTICIPANT	\N	PRESENT	0
494622	493361	14189C	PARTICIPANT	\N	PRESENT	0
494623	493361	20022R	PARTICIPANT	\N	PRESENT	0
494624	493361	14030Q	PARTICIPANT	\N	PRESENT	0
494626	493361	20052X	PARTICIPANT	\N	PRESENT	0
494627	493361	14123H	PARTICIPANT	\N	PRESENT	0
494628	493361	19533U	PARTICIPANT	\N	PRESENT	0
494629	493273	04034C	PARTICIPANT	\N	PRESENT	0
494630	493361	14053L	PARTICIPANT	\N	PRESENT	0
494631	493361	11067R	PARTICIPANT	\N	PRESENT	0
494632	493361	08010L	PARTICIPANT	\N	PRESENT	0
494633	493361	20108W	PARTICIPANT	\N	PRESENT	0
494634	493361	07029T	PARTICIPANT	\N	PRESENT	0
494635	493361	19711U	PARTICIPANT	\N	PRESENT	0
494636	493361	19693L	PARTICIPANT	\N	PRESENT	0
494637	493361	19399H	PARTICIPANT	\N	PRESENT	0
494638	493361	19747H	PARTICIPANT	\N	PRESENT	0
494828	493327	20130U	PARTICIPANT	\N	PRESENT	0
494829	493327	19697Q	PARTICIPANT	\N	PRESENT	0
507444	502318	14275Y	PARTICIPANT	\N	PRESENT	0
507404	505976	14055N	PARTICIPANT	\N	PRESENT	1
507405	505976	19421M	PARTICIPANT	\N	PRESENT	0
507406	505976	19709B	PARTICIPANT	\N	PRESENT	0
507445	502318	19531S	PARTICIPANT	\N	PRESENT	0
507446	505976	16685X	PARTICIPANT	\N	PRESENT	0
507448	502318	14053L	PARTICIPANT	\N	PRESENT	0
507449	502318	14257W	PARTICIPANT	\N	PRESENT	0
507412	505976	01062T	PARTICIPANT	\N	PRESENT	1
507413	505976	11041F	PARTICIPANT	\N	PRESENT	0
507450	502318	19621T	PARTICIPANT	\N	PRESENT	0
507415	505976	14105F	PARTICIPANT	\N	PRESENT	1
507451	502318	20040T	PARTICIPANT	\N	PRESENT	0
507417	505976	98022P	PARTICIPANT	\N	PRESENT	1
507418	505976	14267Y	PARTICIPANT	\N	PRESENT	0
507419	505976	11064N	PARTICIPANT	\N	PRESENT	0
507420	505976	14211G	PARTICIPANT	\N	PRESENT	0
507452	505803	01043Q	PARTICIPANT	\N	EXCUSE	0
507422	505976	14255U	PARTICIPANT	\N	PRESENT	0
507423	502318	19747H	PARTICIPANT	\N	PRESENT	0
507424	502318	20118Y	PARTICIPANT	\N	PRESENT	0
507425	502318	19713W	PARTICIPANT	\N	PRESENT	0
507426	505976	12041X	PARTICIPANT	\N	PRESENT	0
507427	505976	19565D	PARTICIPANT	\N	PRESENT	1
507428	505976	20072C	PARTICIPANT	\N	PRESENT	0
507429	505976	11054L	PARTICIPANT	\N	PRESENT	0
507430	505976	19669L	PARTICIPANT	\N	PRESENT	0
507431	505976	12028B	PARTICIPANT	\N	PRESENT	1
507432	505976	14193X	PARTICIPANT	\N	PRESENT	0
507433	505976	19347U	PARTICIPANT	\N	PRESENT	0
507434	505976	14249W	PARTICIPANT	\N	PRESENT	0
507435	505976	20128B	PARTICIPANT	\N	PRESENT	1
507436	505976	14059S	PARTICIPANT	\N	PRESENT	0
507437	505976	08069G	PARTICIPANT	\N	PRESENT	0
507438	505976	20042V	PARTICIPANT	\N	PRESENT	0
507439	505976	01024M	PARTICIPANT	\N	PRESENT	0
507440	505976	20064C	PARTICIPANT	\N	PRESENT	1
507441	505976	11083R	PARTICIPANT	\N	PRESENT	0
507442	502318	08010L	PARTICIPANT	\N	PRESENT	0
507443	502318	14121F	PARTICIPANT	\N	PRESENT	0
507453	502318	11101A	PARTICIPANT	\N	PRESENT	0
507455	507454	04043D	PARTICIPANT	\N	PRESENT	0
507456	502318	14071N	PARTICIPANT	\N	PRESENT	0
507457	502318	01025N	PARTICIPANT	\N	PRESENT	0
507458	502318	19563B	PARTICIPANT	\N	PRESENT	0
507459	502318	20046A	PARTICIPANT	\N	PRESENT	0
507460	502318	19768N	PARTICIPANT	\N	PRESENT	0
507461	502318	08015R	PARTICIPANT	\N	PRESENT	0
507462	502318	19507S	PARTICIPANT	\N	PRESENT	0
507463	502318	19631V	PARTICIPANT	\N	PRESENT	0
507464	502318	20096L	PARTICIPANT	\N	PRESENT	0
507465	502318	20128B	PARTICIPANT	\N	PRESENT	0
507466	502318	14231L	PARTICIPANT	\N	PRESENT	0
507467	502318	19413M	PARTICIPANT	\N	PRESENT	0
507468	502318	19782L	PARTICIPANT	\N	PRESENT	0
507469	502318	19543W	PARTICIPANT	\N	PRESENT	0
507470	502318	20124W	PARTICIPANT	\N	PRESENT	0
507471	502318	19383Y	PARTICIPANT	\N	PRESENT	0
507472	502318	19369B	PARTICIPANT	\N	PRESENT	0
507473	502318	19575F	PARTICIPANT	\N	PRESENT	0
507474	502318	14038Y	PARTICIPANT	\N	PRESENT	0
507476	507475	01048V	PARTICIPANT	\N	PRESENT	0
507478	502318	19467C	PARTICIPANT	\N	PRESENT	0
507479	507477	01048V	PARTICIPANT	\N	PRESENT	0
507481	507480	01048V	PARTICIPANT	\N	PRESENT	0
507482	502318	20142Y	PARTICIPANT	\N	PRESENT	0
507483	502318	11099A	PARTICIPANT	\N	PRESENT	0
507484	502318	20030R	PARTICIPANT	\N	PRESENT	0
507485	502318	20054A	PARTICIPANT	\N	PRESENT	0
507486	502318	04086Q	PARTICIPANT	\N	PRESENT	0
507487	502318	05012A	PARTICIPANT	\N	PRESENT	0
507488	502318	20062A	PARTICIPANT	\N	PRESENT	0
507489	502318	20082E	PARTICIPANT	\N	PRESENT	0
507490	502318	19441R	PARTICIPANT	\N	PRESENT	0
507491	502318	14213J	PARTICIPANT	\N	PRESENT	0
507492	502318	19669L	PARTICIPANT	\N	PRESENT	0
507493	502318	19421M	PARTICIPANT	\N	PRESENT	0
507494	502318	14187A	PARTICIPANT	\N	PRESENT	0
507495	502318	14026U	PARTICIPANT	\N	PRESENT	0
507496	502318	11053K	PARTICIPANT	\N	PRESENT	0
507497	502318	08069G	PARTICIPANT	\N	PRESENT	0
507498	502318	19611R	PARTICIPANT	\N	PRESENT	0
507499	502318	14331P	PARTICIPANT	\N	PRESENT	0
507500	502318	14042U	PARTICIPANT	\N	PRESENT	0
507501	502318	17737W	PARTICIPANT	\N	PRESENT	0
507502	502318	20108W	PARTICIPANT	\N	PRESENT	0
507503	502318	01024M	PARTICIPANT	\N	PRESENT	0
507504	502318	19565D	PARTICIPANT	\N	PRESENT	0
507505	502318	14001X	PARTICIPANT	\N	PRESENT	0
507506	502318	16685X	PARTICIPANT	\N	PRESENT	0
507507	502318	20018V	PARTICIPANT	\N	PRESENT	0
507508	502318	04033B	PARTICIPANT	\N	PRESENT	0
507509	502318	19715Y	PARTICIPANT	\N	PRESENT	0
507510	502318	04070G	PARTICIPANT	\N	PRESENT	0
507511	502318	14097Y	PARTICIPANT	\N	PRESENT	0
507512	502318	20174H	PARTICIPANT	\N	PRESENT	0
507513	502318	20022R	PARTICIPANT	\N	PRESENT	0
507514	502318	20104S	PARTICIPANT	\N	PRESENT	0
507515	502318	14021P	PARTICIPANT	\N	PRESENT	0
507516	502318	19820Y	PARTICIPANT	\N	PRESENT	0
507619	502319	19719D	PARTICIPANT	\N	PRESENT	0
507620	502319	19760E	PARTICIPANT	\N	PRESENT	0
507621	502319	20112S	PARTICIPANT	\N	PRESENT	0
507622	502319	19565D	PARTICIPANT	\N	PRESENT	0
507623	502319	19687N	PARTICIPANT	\N	PRESENT	0
507624	502319	19515S	PARTICIPANT	\N	PRESENT	0
507625	502319	20046A	PARTICIPANT	\N	PRESENT	0
507626	502319	20018V	PARTICIPANT	\N	PRESENT	0
507627	502319	20074E	PARTICIPANT	\N	PRESENT	0
507628	502319	19503N	PARTICIPANT	\N	PRESENT	0
507629	502319	20034V	PARTICIPANT	\N	PRESENT	0
507630	502319	19631V	PARTICIPANT	\N	PRESENT	0
507631	502319	20092G	PARTICIPANT	\N	PRESENT	0
507632	502319	20136B	PARTICIPANT	\N	PRESENT	0
507633	502319	20142Y	PARTICIPANT	\N	PRESENT	0
507634	502319	19575F	PARTICIPANT	\N	PRESENT	0
507635	502319	19782L	PARTICIPANT	\N	PRESENT	0
507636	502319	19954N	PARTICIPANT	\N	PRESENT	0
507637	502319	19467C	PARTICIPANT	\N	PRESENT	0
507638	502319	20038A	PARTICIPANT	\N	PRESENT	0
507639	502319	14038Y	PARTICIPANT	\N	PRESENT	0
507640	502319	20044X	PARTICIPANT	\N	PRESENT	0
507641	502319	20128B	PARTICIPANT	\N	PRESENT	0
507642	502319	18083K	PARTICIPANT	\N	PRESENT	0
507643	502319	20174H	PARTICIPANT	\N	PRESENT	0
507644	502319	07029T	PARTICIPANT	\N	PRESENT	0
507645	502319	04045F	PARTICIPANT	\N	PRESENT	0
507646	502319	11099A	PARTICIPANT	\N	PRESENT	0
507647	502319	20032T	PARTICIPANT	\N	PRESENT	0
507648	502319	14207L	PARTICIPANT	\N	PRESENT	0
507649	502319	20050V	PARTICIPANT	\N	PRESENT	0
507650	502319	19629C	PARTICIPANT	\N	PRESENT	0
507651	502319	20132W	PARTICIPANT	\N	PRESENT	0
507652	502319	20140W	PARTICIPANT	\N	PRESENT	0
507653	502319	14107H	PARTICIPANT	\N	PRESENT	0
507654	502319	19689Q	PARTICIPANT	\N	PRESENT	0
507655	502319	19531S	PARTICIPANT	\N	PRESENT	0
507656	502319	20080C	PARTICIPANT	\N	PRESENT	0
507657	502319	20024T	PARTICIPANT	\N	PRESENT	0
507658	502319	19647E	PARTICIPANT	\N	PRESENT	0
507659	502319	19399H	PARTICIPANT	\N	PRESENT	0
507660	502319	20052X	PARTICIPANT	\N	PRESENT	0
507661	502319	20104S	PARTICIPANT	\N	PRESENT	0
507662	502319	19713W	PARTICIPANT	\N	PRESENT	0
507663	502319	14042U	PARTICIPANT	\N	PRESENT	0
507664	502319	19569H	PARTICIPANT	\N	PRESENT	0
507665	502319	19441R	PARTICIPANT	\N	PRESENT	0
507666	502319	19479G	PARTICIPANT	\N	PRESENT	0
507667	502319	14231L	PARTICIPANT	\N	PRESENT	0
507668	502319	19768N	PARTICIPANT	\N	PRESENT	0
507669	502319	14327T	PARTICIPANT	\N	PRESENT	0
507670	502319	19521Q	PARTICIPANT	\N	PRESENT	0
507671	502319	14189C	PARTICIPANT	\N	PRESENT	0
507672	502319	14215L	PARTICIPANT	\N	PRESENT	0
507673	502319	19703U	PARTICIPANT	\N	PRESENT	0
507674	502319	19747H	PARTICIPANT	\N	PRESENT	0
507675	502319	19415P	PARTICIPANT	\N	PRESENT	0
507676	502319	14225N	PARTICIPANT	\N	PRESENT	0
507677	502319	20096L	PARTICIPANT	\N	PRESENT	0
507678	502319	11048N	PARTICIPANT	\N	PRESENT	0
485255	484735	11099A	PARTICIPANT	\N	PRESENT	0
485256	484735	14079W	PARTICIPANT	\N	PRESENT	0
485257	484735	19621T	PARTICIPANT	\N	PRESENT	0
485258	484735	19543W	PARTICIPANT	\N	PRESENT	0
485259	484735	19387D	PARTICIPANT	\N	PRESENT	0
485260	484735	14357A	PARTICIPANT	\N	PRESENT	0
485261	484735	19701S	PARTICIPANT	\N	PRESENT	0
485262	484735	19629C	PARTICIPANT	\N	PRESENT	0
485263	484735	14121F	PARTICIPANT	\N	PRESENT	0
485264	484735	01058X	PARTICIPANT	\N	PRESENT	0
485265	484735	14251Q	PARTICIPANT	\N	PRESENT	0
485266	484735	19762G	PARTICIPANT	\N	PRESENT	0
485267	484735	14093U	PARTICIPANT	\N	PRESENT	0
485268	484735	17583W	PARTICIPANT	\N	PRESENT	0
485269	484735	19399H	PARTICIPANT	\N	PRESENT	0
485270	484735	19441R	PARTICIPANT	\N	PRESENT	0
485271	484735	19479G	PARTICIPANT	\N	PRESENT	0
485272	484735	19747H	PARTICIPANT	\N	PRESENT	0
485273	484735	19619A	PARTICIPANT	\N	PRESENT	0
485274	484735	19739H	PARTICIPANT	\N	PRESENT	0
485275	484735	18083K	PARTICIPANT	\N	PRESENT	0
485276	484735	19369B	PARTICIPANT	\N	PRESENT	0
485277	484735	19467C	PARTICIPANT	\N	PRESENT	0
485278	484735	11053K	PARTICIPANT	\N	PRESENT	0
485279	484735	19611R	PARTICIPANT	\N	PRESENT	0
485280	484735	19709B	PARTICIPANT	\N	PRESENT	0
485281	484735	01034P	PARTICIPANT	\N	PRESENT	0
485282	484735	19691J	PARTICIPANT	\N	PRESENT	0
485283	484735	14029X	PARTICIPANT	\N	PRESENT	0
485284	484735	11012A	PARTICIPANT	\N	PRESENT	0
485285	484735	19741B	PARTICIPANT	\N	PRESENT	0
485286	484735	11070L	PARTICIPANT	\N	PRESENT	0
485287	484735	19693L	PARTICIPANT	\N	PRESENT	0
485288	484735	14073Q	PARTICIPANT	\N	PRESENT	0
485289	484735	14179A	PARTICIPANT	\N	PRESENT	0
485290	484735	19930E	PARTICIPANT	\N	PRESENT	0
485291	484735	11085T	PARTICIPANT	\N	PRESENT	0
485292	484735	04040A	PARTICIPANT	\N	PRESENT	0
485293	484735	11054L	PARTICIPANT	\N	PRESENT	0
485294	484735	89017R	PARTICIPANT	\N	PRESENT	0
485295	484735	11109J	PARTICIPANT	\N	PRESENT	0
485296	484735	14255U	PARTICIPANT	\N	PRESENT	0
485297	484735	14055N	PARTICIPANT	\N	PRESENT	0
485298	484735	14237S	PARTICIPANT	\N	PRESENT	0
485299	484735	14083S	PARTICIPANT	\N	PRESENT	0
485300	484735	01025N	PARTICIPANT	\N	PRESENT	0
485301	484735	14327T	PARTICIPANT	\N	PRESENT	0
485302	484735	01043Q	PARTICIPANT	\N	PRESENT	0
485303	484735	96004D	PARTICIPANT	\N	PRESENT	0
485304	484735	17779H	PARTICIPANT	\N	PRESENT	0
485305	484735	19703U	PARTICIPANT	\N	PRESENT	0
485306	484735	07029T	PARTICIPANT	\N	PRESENT	0
485307	484735	19689Q	PARTICIPANT	\N	PRESENT	0
485308	484735	19643A	PARTICIPANT	\N	PRESENT	0
485309	484735	14041T	PARTICIPANT	\N	PRESENT	0
485310	484735	19295A	PARTICIPANT	\N	PRESENT	0
485311	484735	14026U	PARTICIPANT	\N	PRESENT	0
485312	484735	19447X	PARTICIPANT	\N	PRESENT	0
485313	484735	04092N	PARTICIPANT	\N	PRESENT	0
485327	484735	19553Y	PARTICIPANT	\N	PRESENT	0
485328	484735	19749K	PARTICIPANT	\N	PRESENT	0
485329	484735	04085P	PARTICIPANT	\N	PRESENT	0
485330	484735	11031D	PARTICIPANT	\N	PRESENT	0
485331	484735	11110B	PARTICIPANT	\N	PRESENT	0
485332	484735	19591F	PARTICIPANT	\N	PRESENT	0
485333	484735	19269X	PARTICIPANT	\N	PRESENT	0
485334	484735	11074Q	PARTICIPANT	\N	PRESENT	0
485335	484735	14109K	PARTICIPANT	\N	PRESENT	0
485336	484735	19683J	PARTICIPANT	\N	PRESENT	0
485337	484735	19926J	PARTICIPANT	\N	PRESENT	0
485338	484735	14061L	PARTICIPANT	\N	PRESENT	0
485339	484735	19421M	PARTICIPANT	\N	PRESENT	0
485340	484735	01024M	PARTICIPANT	\N	PRESENT	0
485341	484735	19713W	PARTICIPANT	\N	PRESENT	0
485342	484735	16685X	PARTICIPANT	\N	PRESENT	0
485343	484735	17637T	PARTICIPANT	\N	PRESENT	0
485344	484735	12016W	PARTICIPANT	\N	PRESENT	0
485345	484735	19663E	PARTICIPANT	\N	PRESENT	0
485346	484735	14034U	PARTICIPANT	\N	PRESENT	0
485572	484736	19912C	PARTICIPANT	\N	PRESENT	0
485506	484690	04059M	PARTICIPANT	\N	PRESENT	0
485507	484690	11031D	PARTICIPANT	\N	PRESENT	0
485508	484690	19649G	PARTICIPANT	\N	PRESENT	0
485509	484690	19553Y	PARTICIPANT	\N	PRESENT	0
485510	484690	11048N	PARTICIPANT	\N	PRESENT	0
485511	484690	19697Q	PARTICIPANT	\N	PRESENT	0
485512	484690	04092N	PRESIDENT	0	PRESENT	0
485513	484690	14331P	PARTICIPANT	\N	PRESENT	0
485514	484690	11097X	PRESIDENT	1	PRESENT	0
485515	484690	19691J	PARTICIPANT	\N	PRESENT	0
485516	484690	14041T	PARTICIPANT	\N	PRESENT	0
485517	484690	10006L	PARTICIPANT	\N	PRESENT	0
485518	484690	19479G	PARTICIPANT	\N	PRESENT	0
485519	484690	01034P	PARTICIPANT	\N	PRESENT	0
485530	484690	14081Q	PARTICIPANT	\N	PRESENT	0
485521	484690	19573D	PARTICIPANT	\N	PRESENT	0
485522	484690	11067R	PARTICIPANT	\N	PRESENT	0
485523	484690	19766L	PARTICIPANT	\N	PRESENT	0
485524	484690	19349W	PARTICIPANT	\N	PRESENT	0
485525	484690	19683J	PARTICIPANT	\N	PRESENT	0
485526	484690	19447X	PARTICIPANT	\N	PRESENT	0
485527	484690	19503N	PARTICIPANT	\N	PRESENT	0
485528	484690	19643A	PARTICIPANT	\N	EXCUSE	0
485529	484690	19667J	PARTICIPANT	\N	PRESENT	0
485531	484690	19703U	PARTICIPANT	\N	PRESENT	0
485535	484690	19715Y	PARTICIPANT	\N	PRESENT	0
485544	484690	19663E	PARTICIPANT	\N	PRESENT	0
485545	484690	99004R	PARTICIPANT	\N	PRESENT	0
485568	484736	19711U	PARTICIPANT	\N	PRESENT	0
485569	484736	01057W	PARTICIPANT	\N	PRESENT	0
485570	484736	11074Q	PARTICIPANT	\N	PRESENT	0
485571	484736	04086Q	PARTICIPANT	\N	PRESENT	0
485573	484736	08011M	PARTICIPANT	\N	PRESENT	0
485574	484736	19651A	PARTICIPANT	\N	PRESENT	0
485575	484736	19565D	PARTICIPANT	\N	PRESENT	0
485576	484736	14069U	PARTICIPANT	\N	PRESENT	0
485577	484736	08073C	PARTICIPANT	\N	PRESENT	0
485578	484736	19695N	PARTICIPANT	\N	PRESENT	0
485579	484736	01058X	PARTICIPANT	\N	PRESENT	0
485580	484736	19687N	PARTICIPANT	\N	PRESENT	0
485581	484736	19930E	PARTICIPANT	\N	PRESENT	0
485582	484736	19593H	PARTICIPANT	\N	PRESENT	0
485583	484736	19926J	PARTICIPANT	\N	PRESENT	0
485584	484736	14085U	PARTICIPANT	\N	PRESENT	0
485585	484736	19689Q	PARTICIPANT	\N	PRESENT	0
485586	484736	07004J	PARTICIPANT	\N	PRESENT	0
485587	484736	14327T	PARTICIPANT	\N	PRESENT	0
485588	484736	04049K	PARTICIPANT	\N	PRESENT	0
485589	484736	11048N	PARTICIPANT	\N	PRESENT	0
485590	484736	19705W	PARTICIPANT	\N	PRESENT	0
485591	484736	04045F	PARTICIPANT	\N	PRESENT	0
485592	484736	19531S	PARTICIPANT	\N	PRESENT	0
485593	484736	19563B	PARTICIPANT	\N	PRESENT	0
485594	484736	01028R	PARTICIPANT	\N	PRESENT	0
485595	484736	19758L	PARTICIPANT	\N	PRESENT	0
485596	484736	11072N	PARTICIPANT	\N	PRESENT	0
485597	484736	19619A	PARTICIPANT	\N	PRESENT	0
485598	484736	99004R	PARTICIPANT	\N	PRESENT	0
485599	484736	96004D	PARTICIPANT	\N	PRESENT	0
485600	484736	19794Q	PARTICIPANT	\N	PRESENT	0
485601	484736	14041T	PARTICIPANT	\N	PRESENT	0
485602	484736	14119M	PARTICIPANT	\N	PRESENT	0
485603	484736	19347U	PARTICIPANT	\N	PRESENT	0
485604	484736	11033F	PARTICIPANT	\N	PRESENT	0
485605	484736	14021P	PARTICIPANT	\N	PRESENT	0
485606	484736	14147R	PARTICIPANT	\N	PRESENT	0
485607	484736	19637C	PARTICIPANT	\N	PRESENT	0
485608	484736	01024M	PARTICIPANT	\N	PRESENT	0
485609	484736	14331P	PARTICIPANT	\N	PRESENT	0
485610	484736	19741B	PARTICIPANT	\N	PRESENT	0
485611	484736	19760E	PARTICIPANT	\N	PRESENT	0
485612	484736	01025N	PARTICIPANT	\N	PRESENT	0
485613	484736	19647E	PARTICIPANT	\N	PRESENT	0
485614	484736	88008L	PARTICIPANT	\N	PRESENT	0
485615	484736	19739H	PARTICIPANT	\N	PRESENT	0
485616	484736	19762G	PARTICIPANT	\N	PRESENT	0
485617	484736	89017R	PARTICIPANT	\N	PRESENT	0
485618	484736	07029T	PARTICIPANT	\N	PRESENT	0
485619	484736	08062Y	PARTICIPANT	\N	PRESENT	0
485620	484736	04057K	PARTICIPANT	\N	PRESENT	0
485621	484736	19631V	PARTICIPANT	\N	PRESENT	0
485622	484736	19349W	PARTICIPANT	\N	PRESENT	0
485623	484736	04043D	PARTICIPANT	\N	PRESENT	0
485624	484736	08039A	PARTICIPANT	\N	PRESENT	0
485625	484736	11040E	PARTICIPANT	\N	PRESENT	0
485626	484736	19467C	PARTICIPANT	\N	PRESENT	0
485627	484736	12041X	PARTICIPANT	\N	PRESENT	0
485628	484736	19269X	PARTICIPANT	\N	PRESENT	0
485629	484736	12016W	PARTICIPANT	\N	PRESENT	0
501530	500116	20058E	PARTICIPANT	\N	PRESENT	0
501531	500281	19671E	PARTICIPANT	\N	PRESENT	0
501549	500501	19515S	PARTICIPANT	\N	PRESENT	0
501550	500501	19782L	PARTICIPANT	\N	PRESENT	0
501551	500501	20092G	PARTICIPANT	\N	PRESENT	0
501552	500501	11077T	PARTICIPANT	\N	PRESENT	0
501553	500501	01043Q	PARTICIPANT	\N	PRESENT	0
501554	500501	14357A	PARTICIPANT	\N	PRESENT	0
501555	500501	19441R	PARTICIPANT	\N	PRESENT	0
501556	500501	19413M	PARTICIPANT	\N	PRESENT	0
501557	500501	20082E	PARTICIPANT	\N	PRESENT	0
501558	500501	04045F	PARTICIPANT	\N	PRESENT	0
501559	500501	19631V	PARTICIPANT	\N	PRESENT	0
501560	500501	19705W	PARTICIPANT	\N	PRESENT	0
501561	500501	08015R	PARTICIPANT	\N	PRESENT	0
501562	500501	19575F	PARTICIPANT	\N	PRESENT	0
501563	500501	19369B	PARTICIPANT	\N	PRESENT	0
501564	500501	20018V	PARTICIPANT	\N	PRESENT	0
501565	500501	19521Q	PARTICIPANT	\N	PRESENT	0
501566	500501	20030R	PARTICIPANT	\N	PRESENT	0
501567	500501	19467C	PARTICIPANT	\N	PRESENT	0
501568	500501	19695N	PARTICIPANT	\N	PRESENT	0
501569	500501	11090Q	PRESIDENT	0	PRESENT	0
501570	500501	20054A	PARTICIPANT	\N	PRESENT	0
501571	500501	20174H	PARTICIPANT	\N	PRESENT	0
501572	500501	14205J	PARTICIPANT	\N	PRESENT	0
501573	500501	20060X	PARTICIPANT	\N	PRESENT	0
501574	500501	20062A	PARTICIPANT	\N	PRESENT	0
501575	500501	14207L	PARTICIPANT	\N	PRESENT	0
501576	500501	14257W	PARTICIPANT	\N	PRESENT	0
501699	500282	11031D	PARTICIPANT	\N	PRESENT	0
501700	500282	19758L	PARTICIPANT	\N	PRESENT	0
501701	500282	04092N	PARTICIPANT	\N	PRESENT	0
501702	500282	19295A	PARTICIPANT	\N	PRESENT	0
501703	500282	19703U	PARTICIPANT	\N	PRESENT	0
501704	500282	11067R	PARTICIPANT	\N	PRESENT	0
501705	500282	11043H	PARTICIPANT	\N	PRESENT	0
501706	500282	18193Q	PARTICIPANT	\N	PRESENT	0
501707	500282	18083K	PARTICIPANT	\N	PRESENT	0
501708	500282	19715Y	PARTICIPANT	\N	PRESENT	0
501709	500282	19683J	PARTICIPANT	\N	PRESENT	0
501710	500282	14021P	PARTICIPANT	\N	PRESENT	0
501711	500282	17965H	PARTICIPANT	\N	PRESENT	0
501712	500282	20032T	PARTICIPANT	\N	PRESENT	0
501713	500282	14281W	PARTICIPANT	\N	PRESENT	0
501714	500282	20082E	PARTICIPANT	\N	PRESENT	0
501715	500282	19695N	PARTICIPANT	\N	PRESENT	0
501716	500282	20130U	PARTICIPANT	\N	PRESENT	0
501717	500282	20092G	PARTICIPANT	\N	PRESENT	0
501718	500282	19569H	PARTICIPANT	\N	PRESENT	0
501719	500282	20114U	PARTICIPANT	\N	PRESENT	0
501720	500282	19301E	PARTICIPANT	\N	PRESENT	0
501721	500282	19697Q	PARTICIPANT	\N	PRESENT	0
501722	500282	14042U	PARTICIPANT	\N	PRESENT	0
501723	500282	04034C	PARTICIPANT	\N	PRESENT	0
501724	500282	14195A	PARTICIPANT	\N	PRESENT	0
501725	500282	11097X	PARTICIPANT	\N	PRESENT	0
501726	500282	10006L	PARTICIPANT	\N	PRESENT	0
501727	500282	20124W	PARTICIPANT	\N	PRESENT	0
501728	500282	14041T	PARTICIPANT	\N	PRESENT	0
501729	500282	14217N	PARTICIPANT	\N	PRESENT	0
501730	500282	19657G	PARTICIPANT	\N	PRESENT	0
501731	500282	11103C	PARTICIPANT	\N	PRESENT	0
501732	500282	20090E	PARTICIPANT	\N	PRESENT	0
501733	500282	19679N	PARTICIPANT	\N	PRESENT	0
501734	500282	20066E	PARTICIPANT	\N	PRESENT	0
501735	500282	14071N	PARTICIPANT	\N	PRESENT	0
501736	500282	19798U	PARTICIPANT	\N	PRESENT	0
501737	500282	19826F	PARTICIPANT	\N	PRESENT	0
501738	500282	19691J	PARTICIPANT	\N	PRESENT	0
501739	500282	14213J	PARTICIPANT	\N	PRESENT	0
501740	500282	19367Y	PARTICIPANT	\N	PRESENT	0
501741	500282	19717B	PARTICIPANT	\N	PRESENT	0
501742	500282	04057K	PARTICIPANT	\N	PRESENT	0
501743	500282	08045X	PARTICIPANT	\N	PRESENT	0
501744	500282	20152B	PARTICIPANT	\N	PRESENT	0
501745	500282	01028R	PARTICIPANT	\N	PRESENT	0
501746	500282	07004J	PARTICIPANT	\N	PRESENT	0
501747	500282	19415P	PARTICIPANT	\N	PRESENT	0
501748	500282	01034P	PARTICIPANT	\N	PRESENT	0
501749	500282	19713W	PARTICIPANT	\N	PRESENT	0
501750	500282	11045K	PARTICIPANT	\N	PRESENT	0
501751	500282	20034V	PARTICIPANT	\N	PRESENT	0
501752	500282	12016W	PARTICIPANT	\N	PRESENT	0
501753	500282	19663E	PARTICIPANT	\N	PRESENT	0
501754	500282	14249W	PARTICIPANT	\N	PRESENT	0
501755	500282	19563B	PARTICIPANT	\N	PRESENT	0
501756	500282	04033B	PARTICIPANT	\N	PRESENT	0
501757	500282	14147R	PARTICIPANT	\N	PRESENT	0
501758	500477	19349W	PARTICIPANT	\N	PRESENT	0
501759	500282	08010L	PARTICIPANT	\N	PRESENT	0
501760	500282	19723Y	PARTICIPANT	\N	PRESENT	0
501762	500282	17779H	PARTICIPANT	\N	PRESENT	0
501764	500282	19673G	PARTICIPANT	\N	PRESENT	0
501765	500282	14069U	PARTICIPANT	\N	PRESENT	0
501766	500282	19766L	PARTICIPANT	\N	PRESENT	0
501767	500282	17737W	PARTICIPANT	\N	PRESENT	0
501768	500282	04043D	PARTICIPANT	\N	PRESENT	0
501769	500282	14105F	PARTICIPANT	\N	PRESENT	0
501770	500282	20126Y	PARTICIPANT	\N	PRESENT	0
501771	500282	97011G	PARTICIPANT	\N	PRESENT	0
501772	500282	19533U	PARTICIPANT	\N	PRESENT	0
501773	500282	19575F	PARTICIPANT	\N	PRESENT	0
501774	500282	11070L	PARTICIPANT	\N	PRESENT	0
501775	500282	19667J	PARTICIPANT	\N	PRESENT	0
501776	500282	20056C	PARTICIPANT	\N	PRESENT	0
501777	500282	14001X	PARTICIPANT	\N	PRESENT	0
501781	500282	19349W	PARTICIPANT	\N	PRESENT	0
501792	498850	08015R	PARTICIPANT	\N	EXCUSE	0
501836	500478	14331P	PARTICIPANT	\N	PRESENT	0
501837	500478	20034V	PARTICIPANT	\N	PRESENT	0
501838	500478	11048N	PARTICIPANT	\N	PRESENT	0
501839	500478	19711U	PARTICIPANT	\N	PRESENT	0
501840	500478	19531S	PARTICIPANT	\N	PRESENT	0
501841	500478	12016W	PARTICIPANT	\N	PRESENT	0
501842	500478	20080C	PARTICIPANT	\N	PRESENT	0
501843	500478	20150Y	PARTICIPANT	\N	PRESENT	0
501844	500478	14225N	PRESIDENT	0	PRESENT	0
501845	500478	19671E	PARTICIPANT	\N	PRESENT	0
501846	500478	04086Q	PARTICIPANT	\N	PRESENT	0
501847	500478	07029T	PARTICIPANT	\N	PRESENT	0
501848	500478	08073C	PARTICIPANT	\N	PRESENT	0
501849	500478	20070A	PARTICIPANT	\N	PRESENT	0
501908	500478	19647E	PARTICIPANT	\N	PRESENT	0
501909	500478	01057W	PARTICIPANT	\N	PRESENT	0
501912	500284	19593H	PARTICIPANT	\N	PRESENT	0
501913	500284	20082E	PARTICIPANT	\N	PRESENT	0
501914	500284	14173T	PARTICIPANT	\N	PRESENT	0
501915	500284	14357A	PARTICIPANT	\N	PRESENT	0
501916	500284	14105F	PARTICIPANT	\N	PRESENT	0
501917	500284	19581D	PARTICIPANT	\N	PRESENT	0
501918	500284	19715Y	PARTICIPANT	\N	PRESENT	0
501919	500284	19683J	PARTICIPANT	\N	PRESENT	0
501920	500284	11067R	PARTICIPANT	\N	PRESENT	0
501921	500284	19599P	PARTICIPANT	\N	PRESENT	0
501923	500284	11041F	PARTICIPANT	\N	PRESENT	0
501924	500284	14195A	PARTICIPANT	\N	PRESENT	0
501925	500284	20052X	PARTICIPANT	\N	PRESENT	0
501926	500284	08045X	PARTICIPANT	\N	PRESENT	0
501928	500284	19719D	PARTICIPANT	\N	PRESENT	0
501930	500284	20102Q	PARTICIPANT	\N	PRESENT	0
501931	500284	19251M	PARTICIPANT	\N	PRESENT	0
501932	500284	20042V	PARTICIPANT	\N	PRESENT	0
501933	500284	20106U	PARTICIPANT	\N	PRESENT	0
501934	500284	12041X	PARTICIPANT	\N	PRESENT	0
501935	500284	20130U	PARTICIPANT	\N	PRESENT	0
501936	500284	14231L	PARTICIPANT	\N	PRESENT	0
501937	500284	04085P	PARTICIPANT	\N	PRESENT	0
501938	500284	19695N	PARTICIPANT	\N	PRESENT	0
501939	500284	14030Q	PARTICIPANT	\N	PRESENT	0
501940	500284	18193Q	PARTICIPANT	\N	PRESENT	0
501941	500284	19717B	PARTICIPANT	\N	PRESENT	0
501942	500284	11045K	PARTICIPANT	\N	PRESENT	0
501943	500284	19826F	PARTICIPANT	\N	PRESENT	0
501944	500284	19687N	PARTICIPANT	\N	PRESENT	0
501945	500284	19549D	PARTICIPANT	\N	PRESENT	0
501946	500284	20146D	PARTICIPANT	\N	PRESENT	0
501950	500284	01034P	PARTICIPANT	\N	PRESENT	0
501955	500284	19679N	PARTICIPANT	\N	PRESENT	0
501956	500284	19758L	PARTICIPANT	\N	PRESENT	0
501957	500284	99004R	PARTICIPANT	\N	PRESENT	0
501958	500284	11033F	PARTICIPANT	\N	PRESENT	0
501959	500284	20134Y	PARTICIPANT	\N	PRESENT	0
501960	500284	19591F	PARTICIPANT	\N	PRESENT	0
501961	500284	14249W	PARTICIPANT	\N	PRESENT	0
501962	500284	19349W	PARTICIPANT	\N	PRESENT	0
501963	500284	11083R	PARTICIPANT	\N	PRESENT	0
501964	500284	19301E	PARTICIPANT	\N	PRESENT	0
501965	500284	20086J	PARTICIPANT	\N	PRESENT	0
507871	506033	19591F	PARTICIPANT	\N	PRESENT	0
507872	506033	11031D	PARTICIPANT	\N	PRESENT	0
507910	506033	17965H	PARTICIPANT	\N	PRESENT	1
507969	506033	11067R	PARTICIPANT	\N	PRESENT	0
508023	506033	18193Q	PARTICIPANT	\N	PRESENT	1
508024	506033	14026U	PARTICIPANT	\N	PRESENT	0
508043	508042	14215L	PARTICIPANT	\N	PRESENT	0
508044	508042	19629C	PARTICIPANT	\N	PRESENT	0
508045	508042	14151M	PARTICIPANT	\N	PRESENT	0
508047	508046	19629C	PARTICIPANT	\N	PRESENT	0
508050	508049	19629C	PARTICIPANT	\N	PRESENT	0
508053	508052	19629C	PARTICIPANT	\N	PRESENT	0
508054	508052	14215L	PARTICIPANT	\N	PRESENT	0
508057	508055	19629C	PARTICIPANT	\N	PRESENT	0
508058	508055	14215L	PARTICIPANT	\N	PRESENT	0
508060	508059	19629C	PARTICIPANT	\N	PRESENT	0
508061	508059	14215L	PARTICIPANT	\N	PRESENT	0
508063	503109	19649G	PARTICIPANT	\N	PRESENT	0
508064	503115	19749K	PARTICIPANT	\N	PRESENT	0
508065	503115	14053L	PARTICIPANT	\N	PRESENT	0
508066	503115	19649G	PARTICIPANT	\N	PRESENT	0
508079	506221	14151M	PARTICIPANT	\N	PRESENT	0
508082	508081	19543W	PARTICIPANT	\N	PRESENT	0
508084	508083	19543W	PARTICIPANT	\N	PRESENT	0
508086	508085	19543W	PARTICIPANT	\N	PRESENT	0
508088	508087	19543W	PARTICIPANT	\N	PRESENT	0
508090	508089	19543W	PARTICIPANT	\N	PRESENT	0
508091	508089	14151M	PARTICIPANT	\N	PRESENT	0
508093	508092	19543W	PARTICIPANT	\N	PRESENT	0
508095	508094	19543W	PARTICIPANT	\N	PRESENT	0
508096	508094	14151M	PARTICIPANT	\N	PRESENT	0
509083	506668	11067R	PARTICIPANT	\N	PRESENT	0
509080	506668	20072C	PARTICIPANT	\N	PRESENT	0
509084	506668	01058X	PARTICIPANT	\N	PRESENT	0
509085	502324	14026U	PARTICIPANT	\N	PRESENT	0
509086	506668	04043D	PARTICIPANT	\N	PRESENT	0
509087	506668	18003S	PARTICIPANT	\N	EXCUSE	0
509093	502324	19569H	PARTICIPANT	\N	PRESENT	0
509094	502324	14195A	PARTICIPANT	\N	PRESENT	0
509095	502324	19683J	PARTICIPANT	\N	PRESENT	0
509096	502324	07004J	PARTICIPANT	\N	PRESENT	0
509097	502324	20130U	PARTICIPANT	\N	PRESENT	0
509098	502324	19697Q	PARTICIPANT	\N	PRESENT	0
509099	502324	19553Y	PARTICIPANT	\N	PRESENT	0
509100	502324	11031D	PARTICIPANT	\N	PRESENT	0
509101	505805	14331P	PARTICIPANT	\N	PRESENT	0
509102	505805	14026U	PARTICIPANT	\N	PRESENT	0
509103	505805	20100N	PARTICIPANT	\N	PRESENT	0
509104	505805	96004D	PARTICIPANT	\N	PRESENT	0
509105	505805	20128B	PARTICIPANT	\N	PRESENT	0
509106	505805	14097Y	PARTICIPANT	\N	PRESENT	0
509107	505805	19531S	PARTICIPANT	\N	PRESENT	0
509108	505805	12016W	PARTICIPANT	\N	PRESENT	0
509109	505805	19251M	PARTICIPANT	\N	PRESENT	1
509110	505805	14169X	PARTICIPANT	\N	PRESENT	0
509111	505805	14089Y	PARTICIPANT	\N	PRESENT	0
509112	505805	11101A	PARTICIPANT	\N	PRESENT	0
509113	505805	11083R	PARTICIPANT	\N	PRESENT	0
509114	502324	11067R	PARTICIPANT	\N	PRESENT	0
509115	502324	20030R	PARTICIPANT	\N	PRESENT	0
509116	502324	14042U	PARTICIPANT	\N	PRESENT	0
509117	502324	20132W	PARTICIPANT	\N	PRESENT	0
509118	502324	19703U	PARTICIPANT	\N	PRESENT	0
509119	502324	14217N	PARTICIPANT	\N	PRESENT	0
509120	502324	14213J	PARTICIPANT	\N	PRESENT	0
509121	502324	18083K	PARTICIPANT	\N	PRESENT	0
509122	502324	18193Q	PARTICIPANT	\N	PRESENT	0
509123	502324	19760E	PARTICIPANT	\N	PRESENT	0
509124	502324	20098N	PARTICIPANT	\N	PRESENT	0
509125	502324	19515S	PARTICIPANT	\N	PRESENT	0
509126	502324	14021P	PARTICIPANT	\N	PRESENT	0
509127	502324	20040T	PARTICIPANT	\N	PRESENT	0
509128	502324	10006L	PARTICIPANT	\N	PRESENT	0
509129	502324	01034P	PARTICIPANT	\N	PRESENT	0
509130	502324	19691J	PARTICIPANT	\N	PRESENT	0
509131	502324	04057K	PARTICIPANT	\N	PRESENT	0
509132	502324	20090E	PARTICIPANT	\N	PRESENT	0
509133	502324	19715Y	PARTICIPANT	\N	PRESENT	0
509134	502324	14123H	PARTICIPANT	\N	PRESENT	0
509135	502324	19467C	PARTICIPANT	\N	PRESENT	0
509136	502324	20034V	PARTICIPANT	\N	PRESENT	0
509137	502324	19507S	PARTICIPANT	\N	PRESENT	0
509138	502324	11045K	PARTICIPANT	\N	PRESENT	0
509139	502324	19713W	PARTICIPANT	\N	PRESENT	0
509140	502324	08069G	PARTICIPANT	\N	PRESENT	0
509141	502324	20116W	PARTICIPANT	\N	PRESENT	0
509142	509029	19593H	PARTICIPANT	\N	PRESENT	0
509143	509029	19643A	PARTICIPANT	\N	PRESENT	0
509144	509029	20132W	PARTICIPANT	\N	PRESENT	0
509145	509029	19699S	PARTICIPANT	\N	PRESENT	0
509146	509029	14073Q	PARTICIPANT	\N	PRESENT	0
509147	509029	19533U	PARTICIPANT	\N	PRESENT	0
509148	509029	19611R	PRESIDENT	0	PRESENT	0
509149	509029	20142Y	PARTICIPANT	\N	PRESENT	0
509150	509029	19399H	PARTICIPANT	\N	PRESENT	0
509151	509029	20152B	PARTICIPANT	\N	PRESENT	0
509152	509029	14030Q	PARTICIPANT	\N	PRESENT	0
509153	509029	14123H	PARTICIPANT	\N	PRESENT	0
509154	509029	20124W	PARTICIPANT	\N	PRESENT	0
509155	509029	19758L	PARTICIPANT	\N	PRESENT	0
509156	509029	20084G	PARTICIPANT	\N	PRESENT	0
509157	509029	19621T	PARTICIPANT	\N	PRESENT	0
509158	502324	20032T	PARTICIPANT	\N	PRESENT	0
509159	509029	04070G	PARTICIPANT	\N	PRESENT	1
509160	509029	14229S	PARTICIPANT	\N	PRESENT	0
509161	509029	20026V	PARTICIPANT	\N	PRESENT	1
509162	509029	20134Y	PARTICIPANT	\N	PRESENT	1
509163	509029	20138D	PARTICIPANT	\N	PRESENT	1
509164	509029	20052X	PARTICIPANT	\N	PRESENT	1
509165	509029	20056C	PARTICIPANT	\N	PRESENT	1
509166	509029	19735D	PARTICIPANT	\N	PRESENT	1
509167	509029	11104D	PARTICIPANT	\N	PRESENT	1
509168	506668	20128B	PARTICIPANT	\N	PRESENT	0
509169	506668	19735D	PARTICIPANT	\N	PRESENT	0
509170	502324	14038Y	PARTICIPANT	\N	PRESENT	0
509171	502324	20038A	PARTICIPANT	\N	PRESENT	0
509173	502324	19369B	PARTICIPANT	\N	PRESENT	0
509174	502324	19549D	PARTICIPANT	\N	PRESENT	0
509175	502324	14219Q	PARTICIPANT	\N	PRESENT	0
509176	502324	19565D	PARTICIPANT	\N	PRESENT	0
509177	502324	20028X	PARTICIPANT	\N	PRESENT	0
509179	502324	14071N	PARTICIPANT	\N	PRESENT	0
509180	506628	14327T	PARTICIPANT	\N	PRESENT	0
509182	506628	04071H	PARTICIPANT	\N	PRESENT	0
509183	506628	01057W	PARTICIPANT	\N	PRESENT	0
509184	506628	20080C	PARTICIPANT	\N	PRESENT	0
509185	506628	11053K	PARTICIPANT	\N	PRESENT	0
509186	506628	14225N	PRESIDENT	0	PRESENT	0
509187	506628	19671E	PARTICIPANT	\N	PRESENT	0
509188	506628	11070L	PARTICIPANT	\N	PRESENT	0
509189	506628	07029T	PARTICIPANT	\N	PRESENT	0
509190	506628	14253S	PARTICIPANT	\N	PRESENT	0
509191	506628	19335Q	PARTICIPANT	\N	PRESENT	0
509192	506628	20126Y	PARTICIPANT	\N	PRESENT	0
509193	506628	11048N	PARTICIPANT	\N	PRESENT	0
509194	506628	19647E	PARTICIPANT	\N	PRESENT	0
509195	506628	19711U	PARTICIPANT	\N	PRESENT	0
509196	506628	08034U	PARTICIPANT	\N	PRESENT	0
509197	506628	19687N	PARTICIPANT	\N	PRESENT	0
509198	506628	20050V	PARTICIPANT	\N	PRESENT	0
509199	506628	08011M	PARTICIPANT	\N	PRESENT	0
509200	506628	20044X	PARTICIPANT	\N	PRESENT	0
509201	506628	11040E	PARTICIPANT	\N	PRESENT	0
509202	506628	14083S	PARTICIPANT	\N	PRESENT	0
509203	506628	11012A	PARTICIPANT	\N	PRESENT	0
509204	506628	08009T	PARTICIPANT	\N	PRESENT	0
509205	506628	19741B	PARTICIPANT	\N	PRESENT	0
509206	506628	99004R	PARTICIPANT	\N	PRESENT	0
509207	506628	19762G	PARTICIPANT	\N	PRESENT	0
509208	508434	19735D	PARTICIPANT	\N	PRESENT	0
509209	508434	01048V	PARTICIPANT	\N	PRESENT	0
509212	508434	04043D	PARTICIPANT	\N	PRESENT	0
509213	508434	19503N	PARTICIPANT	\N	PRESENT	0
486044	486043	11053K	PARTICIPANT	\N	PRESENT	0
486045	486043	05012A	PARTICIPANT	\N	PRESENT	0
486056	485907	19667J	PARTICIPANT	\N	EXCUSE	0
489803	489802	04018C	PARTICIPANT	\N	PRESENT	0
489804	489802	19593H	PARTICIPANT	\N	PRESENT	0
489806	489805	04018C	PARTICIPANT	\N	PRESENT	0
495357	495354	14225N	PARTICIPANT	\N	PRESENT	0
495355	495354	11048N	PARTICIPANT	\N	PRESENT	0
495356	495352	14225N	PARTICIPANT	\N	PRESENT	0
495359	495358	19741B	PARTICIPANT	\N	PRESENT	0
495361	495360	19741B	PARTICIPANT	\N	PRESENT	0
495363	495362	19335Q	PARTICIPANT	\N	PRESENT	0
506627	502313	19719D	PARTICIPANT	\N	PRESENT	0
506629	502313	11048N	PARTICIPANT	\N	PRESENT	0
506630	502313	14225N	PARTICIPANT	\N	PRESENT	0
506632	502313	19651A	PARTICIPANT	\N	PRESENT	0
506633	502313	19782L	PARTICIPANT	\N	PRESENT	0
506634	502313	12016W	PARTICIPANT	\N	PRESENT	0
506635	502313	14257W	PARTICIPANT	\N	PRESENT	0
506636	502313	20080C	PARTICIPANT	\N	PRESENT	0
506637	502313	11040E	PARTICIPANT	\N	PRESENT	0
506638	502313	14327T	PARTICIPANT	\N	PRESENT	0
506639	502313	19479G	PARTICIPANT	\N	PRESENT	0
506640	502313	19713W	PARTICIPANT	\N	PRESENT	0
506641	502313	20050V	PARTICIPANT	\N	PRESENT	0
506642	502313	11070L	PARTICIPANT	\N	PRESENT	0
506643	502313	20044X	PARTICIPANT	\N	PRESENT	0
506644	502313	14357A	PARTICIPANT	\N	PRESENT	0
506645	502313	01048V	PARTICIPANT	\N	PRESENT	0
506646	502313	19711U	PARTICIPANT	\N	PRESENT	0
506647	502313	19691J	PARTICIPANT	\N	PRESENT	0
506648	502313	20038A	PARTICIPANT	\N	PRESENT	0
506649	502313	04086Q	PARTICIPANT	\N	PRESENT	0
506650	502313	07029T	PARTICIPANT	\N	PRESENT	0
506651	502313	14173T	PARTICIPANT	\N	PRESENT	0
506652	502313	11012A	PARTICIPANT	\N	PRESENT	0
506653	502313	14205J	PARTICIPANT	\N	PRESENT	0
506654	502313	20124W	PARTICIPANT	\N	PRESENT	0
506655	502313	20070A	PARTICIPANT	\N	PRESENT	0
506656	502313	19647E	PARTICIPANT	\N	PRESENT	0
506657	502313	19631V	PARTICIPANT	\N	PRESENT	0
506658	502313	19689Q	PARTICIPANT	\N	PRESENT	0
506659	502313	19687N	PARTICIPANT	\N	PRESENT	0
506660	502313	95063L	PARTICIPANT	\N	PRESENT	0
506661	502313	14329V	PARTICIPANT	\N	PRESENT	0
506667	502313	19515S	PARTICIPANT	\N	PRESENT	0
506671	502313	14331P	PARTICIPANT	\N	PRESENT	0
506672	502313	14083S	PARTICIPANT	\N	PRESENT	0
506675	502313	19741B	PARTICIPANT	\N	PRESENT	0
506676	502313	04071H	PARTICIPANT	\N	PRESENT	0
506677	502313	04043D	PARTICIPANT	\N	PRESENT	0
506678	502313	04045F	PARTICIPANT	\N	PRESENT	0
506693	502313	19667J	PARTICIPANT	\N	PRESENT	0
506695	502313	19531S	PARTICIPANT	\N	PRESENT	0
506707	502313	14041T	PARTICIPANT	\N	PRESENT	0
506708	502313	19695N	PARTICIPANT	\N	PRESENT	0
506709	502313	08011M	PARTICIPANT	\N	PRESENT	0
506710	502313	19643A	PARTICIPANT	\N	PRESENT	0
506711	502313	20034V	PARTICIPANT	\N	PRESENT	0
506712	502313	14021P	PARTICIPANT	\N	PRESENT	0
506713	502313	99004R	PARTICIPANT	\N	PRESENT	0
506714	502313	20092G	PARTICIPANT	\N	PRESENT	0
506715	502313	01043Q	PARTICIPANT	\N	PRESENT	0
506716	502313	19551W	PARTICIPANT	\N	PRESENT	0
506787	502315	20044X	PARTICIPANT	\N	PRESENT	0
506788	502315	19711U	PARTICIPANT	\N	PRESENT	0
506789	502315	04086Q	PARTICIPANT	\N	PRESENT	0
506790	502315	04045F	PARTICIPANT	\N	PRESENT	0
506791	502315	19695N	PARTICIPANT	\N	PRESENT	0
506792	502315	20050V	PARTICIPANT	\N	PRESENT	0
506793	502315	19667J	PARTICIPANT	\N	PRESENT	0
506794	502315	14357A	PARTICIPANT	\N	PRESENT	0
506795	502315	11074Q	PARTICIPANT	\N	PRESENT	0
506796	502315	19719D	PARTICIPANT	\N	PRESENT	0
506797	502315	11048N	PARTICIPANT	\N	PRESENT	0
506798	502315	19689Q	PARTICIPANT	\N	PRESENT	0
506799	502315	11070L	PARTICIPANT	\N	PRESENT	0
506800	502315	20092G	PARTICIPANT	\N	PRESENT	0
506801	502315	14257W	PARTICIPANT	\N	PRESENT	0
506802	502315	11053K	PARTICIPANT	\N	PRESENT	0
506803	502315	20080C	PARTICIPANT	\N	PRESENT	0
506804	502315	01043Q	PARTICIPANT	\N	PRESENT	0
506805	502315	20090E	PARTICIPANT	\N	PRESENT	0
506806	502315	14327T	PARTICIPANT	\N	PRESENT	0
506807	502315	19515S	PARTICIPANT	\N	PRESENT	0
506808	502315	20124W	PARTICIPANT	\N	PRESENT	0
506809	502315	20070A	PARTICIPANT	\N	PRESENT	0
506810	502315	14169X	PARTICIPANT	\N	PRESENT	0
506811	502315	07029T	PARTICIPANT	\N	PRESENT	0
506812	502315	14083S	PARTICIPANT	\N	PRESENT	0
506813	502315	12016W	PARTICIPANT	\N	PRESENT	0
506814	502315	20038A	PARTICIPANT	\N	PRESENT	0
506815	502315	19647E	PARTICIPANT	\N	PRESENT	0
506816	502315	19575F	PARTICIPANT	\N	PRESENT	0
506817	502315	11012A	PARTICIPANT	\N	PRESENT	0
506818	502315	14225N	PARTICIPANT	\N	PRESENT	0
506819	502315	19651A	PARTICIPANT	\N	PRESENT	0
506820	502315	11072N	PARTICIPANT	\N	PRESENT	0
506821	502315	11040E	PARTICIPANT	\N	PRESENT	0
506822	502315	19631V	PARTICIPANT	\N	PRESENT	0
506823	502315	14021P	PARTICIPANT	\N	PRESENT	0
506824	502315	14329V	PARTICIPANT	\N	PRESENT	0
506825	502315	01048V	PARTICIPANT	\N	PRESENT	0
506826	502315	19713W	PARTICIPANT	\N	PRESENT	0
506827	502315	14253S	PARTICIPANT	\N	PRESENT	0
506828	502315	19691J	PARTICIPANT	\N	PRESENT	0
506829	502315	14275Y	PARTICIPANT	\N	PRESENT	0
506830	502315	20018V	PARTICIPANT	\N	PRESENT	0
506831	502315	08011M	PARTICIPANT	\N	PRESENT	0
506832	502315	19479G	PARTICIPANT	\N	PRESENT	0
506833	502315	19531S	PARTICIPANT	\N	PRESENT	0
506834	502315	95063L	PARTICIPANT	\N	PRESENT	0
506835	502315	19741B	PARTICIPANT	\N	PRESENT	0
506767	502315	99004R	PARTICIPANT	\N	PRESENT	0
506786	502315	19643A	PARTICIPANT	\N	PRESENT	0
506836	502315	14205J	PARTICIPANT	\N	PRESENT	0
506837	502315	11065P	PARTICIPANT	\N	PRESENT	0
506838	502315	20120S	PARTICIPANT	\N	PRESENT	0
506839	502315	20136B	PARTICIPANT	\N	PRESENT	0
506840	502315	11097X	PARTICIPANT	\N	PRESENT	0
506843	502315	07033P	PARTICIPANT	\N	PRESENT	0
506844	502315	04085P	PARTICIPANT	\N	PRESENT	0
506846	502315	19551W	PARTICIPANT	\N	PRESENT	0
506847	502315	19717B	PARTICIPANT	\N	PRESENT	0
506848	502315	20118Y	PARTICIPANT	\N	PRESENT	0
506849	502315	20024T	PARTICIPANT	\N	PRESENT	0
506850	502315	14331P	PARTICIPANT	\N	PRESENT	0
506854	502315	11099A	PARTICIPANT	\N	PRESENT	0
506858	502315	14041T	PARTICIPANT	\N	PRESENT	0
506861	502315	19747H	PARTICIPANT	\N	PRESENT	0
506862	502315	17367Q	PARTICIPANT	\N	PRESENT	0
506870	502315	14147R	PARTICIPANT	\N	PRESENT	0
506923	502316	11045K	PARTICIPANT	\N	PRESENT	0
506924	502316	11048N	PARTICIPANT	\N	PRESENT	0
506925	502316	14225N	PARTICIPANT	\N	PRESENT	0
506926	502316	19651A	PARTICIPANT	\N	PRESENT	0
506927	502316	04045F	PARTICIPANT	\N	PRESENT	0
506928	502316	19782L	PARTICIPANT	\N	PRESENT	0
506929	502316	19629C	PARTICIPANT	\N	PRESENT	0
506930	502316	20072C	PARTICIPANT	\N	PRESENT	0
506931	502316	19719D	PARTICIPANT	\N	PRESENT	0
506932	502316	20022R	PARTICIPANT	\N	PRESENT	0
506933	502316	11053K	PARTICIPANT	\N	PRESENT	0
506934	502316	19711U	PARTICIPANT	\N	PRESENT	0
506935	502316	20050V	PARTICIPANT	\N	PRESENT	0
506936	502316	20080C	PARTICIPANT	\N	PRESENT	0
506937	502316	14357A	PARTICIPANT	\N	PRESENT	0
506938	502316	20018V	PARTICIPANT	\N	PRESENT	0
506939	502316	11074Q	PARTICIPANT	\N	PRESENT	0
506940	502316	20034V	PARTICIPANT	\N	PRESENT	0
506941	502316	19691J	PARTICIPANT	\N	PRESENT	0
506942	502316	20124W	PARTICIPANT	\N	PRESENT	0
506943	502316	14083S	PARTICIPANT	\N	PRESENT	0
506944	502316	19503N	PARTICIPANT	\N	PRESENT	0
506945	502316	20092G	PARTICIPANT	\N	PRESENT	0
506946	502316	07029T	PARTICIPANT	\N	PRESENT	0
506947	502316	20090E	PARTICIPANT	\N	PRESENT	0
506948	502316	20038A	PARTICIPANT	\N	PRESENT	0
506949	502316	20044X	PARTICIPANT	\N	PRESENT	0
506950	502316	19747H	PARTICIPANT	\N	PRESENT	0
506951	502316	20136B	PARTICIPANT	\N	PRESENT	0
493499	493370	95063L	PARTICIPANT	\N	PRESENT	0
493500	493370	20074E	PARTICIPANT	\N	PRESENT	0
493501	493370	19673G	PARTICIPANT	\N	PRESENT	0
493502	493370	01028R	PARTICIPANT	\N	PRESENT	0
493503	493370	14089Y	PARTICIPANT	\N	PRESENT	0
493504	493370	11056N	PARTICIPANT	\N	PRESENT	0
493505	493370	19489J	PARTICIPANT	\N	PRESENT	0
493506	493370	20108W	PARTICIPANT	\N	PRESENT	0
493507	493370	14107H	PARTICIPANT	\N	PRESENT	0
493508	493370	05008E	PARTICIPANT	\N	PRESENT	0
493509	493370	14179A	PARTICIPANT	\N	PRESENT	0
493510	493370	11085T	PARTICIPANT	\N	PRESENT	0
493513	493357	11070L	PARTICIPANT	\N	PRESENT	0
493514	493357	14105F	PARTICIPANT	\N	PRESENT	0
493515	493357	14231L	PARTICIPANT	\N	PRESENT	0
493516	493357	20026V	PARTICIPANT	\N	PRESENT	0
493517	493357	14055N	PARTICIPANT	\N	PRESENT	0
493518	493357	20076G	PARTICIPANT	\N	PRESENT	0
493519	493357	20078J	PARTICIPANT	\N	PRESENT	0
493520	493357	19739H	PARTICIPANT	\N	PRESENT	0
493521	493357	20110Q	PARTICIPANT	\N	PRESENT	0
493522	493357	19515S	PARTICIPANT	\N	PRESENT	0
493523	493357	20126Y	PARTICIPANT	\N	PRESENT	0
493524	493357	04047H	PARTICIPANT	\N	PRESENT	0
493525	493357	14215L	PARTICIPANT	\N	PRESENT	0
493526	493357	19729F	PARTICIPANT	\N	PRESENT	0
493527	493357	18083K	PARTICIPANT	\N	PRESENT	0
493528	493357	20032T	PARTICIPANT	\N	PRESENT	0
493529	493357	19399H	PARTICIPANT	\N	PRESENT	0
493530	493357	11103C	PARTICIPANT	\N	PRESENT	0
493531	493357	95063L	PARTICIPANT	\N	PRESENT	0
493532	493357	08073C	PARTICIPANT	\N	PRESENT	0
493533	493357	19489J	PARTICIPANT	\N	PRESENT	0
493534	493357	19866P	PARTICIPANT	\N	PRESENT	0
493535	493357	19719D	PARTICIPANT	\N	PRESENT	0
493536	493357	20066E	PARTICIPANT	\N	PRESENT	0
493537	493357	20132W	PARTICIPANT	\N	PRESENT	0
493538	493357	19387D	PARTICIPANT	\N	PRESENT	0
493539	493357	20144B	PARTICIPANT	\N	PRESENT	0
493540	493357	19826F	PARTICIPANT	\N	PRESENT	0
493541	493357	19747H	PARTICIPANT	\N	PRESENT	0
493542	493357	14259Y	PARTICIPANT	\N	PRESENT	0
493543	493357	05008E	PARTICIPANT	\N	PRESENT	0
493544	493357	01057W	PARTICIPANT	\N	PRESENT	0
493545	493357	99004R	PARTICIPANT	\N	PRESENT	0
493546	493357	14021P	PARTICIPANT	\N	PRESENT	0
493547	493357	19383Y	PARTICIPANT	\N	PRESENT	0
493548	493357	12016W	PARTICIPANT	\N	PRESENT	0
493549	493357	20124W	PARTICIPANT	\N	PRESENT	0
493550	493357	20090E	PARTICIPANT	\N	PRESENT	0
493551	493357	08015R	PARTICIPANT	\N	PRESENT	0
493552	493357	19507S	PARTICIPANT	\N	PRESENT	0
493553	493357	01058X	PARTICIPANT	\N	PRESENT	0
493586	493357	19758L	PARTICIPANT	\N	PRESENT	0
493555	493357	11066Q	PARTICIPANT	\N	PRESENT	0
493556	493357	19749K	PARTICIPANT	\N	PRESENT	0
493557	493357	20096L	PARTICIPANT	\N	PRESENT	0
493558	493357	20034V	PARTICIPANT	\N	PRESENT	0
493563	493357	20042V	PARTICIPANT	\N	PRESENT	0
493560	493357	20040T	PARTICIPANT	\N	PRESENT	0
493561	493357	20054A	PARTICIPANT	\N	PRESENT	0
493562	493357	20140W	PARTICIPANT	\N	PRESENT	0
493564	493357	20024T	PARTICIPANT	\N	PRESENT	0
493565	493357	20136B	PARTICIPANT	\N	PRESENT	0
493566	493357	11012A	PARTICIPANT	\N	PRESENT	0
493567	493357	11056N	PARTICIPANT	\N	PRESENT	0
493568	493357	20058E	PARTICIPANT	\N	PRESENT	0
493569	493357	20044X	PARTICIPANT	\N	PRESENT	0
493570	493357	19447X	PARTICIPANT	\N	PRESENT	0
493571	493357	20038A	PARTICIPANT	\N	PRESENT	0
493572	493357	11101A	PARTICIPANT	\N	PRESENT	0
493573	493357	19301E	PARTICIPANT	\N	PRESENT	0
493574	493357	14059S	PARTICIPANT	\N	PRESENT	0
493575	493357	14107H	PARTICIPANT	\N	PRESENT	0
493576	493357	19798U	PARTICIPANT	\N	PRESENT	0
493577	493357	19467C	PARTICIPANT	\N	PRESENT	0
493595	493357	20022R	PARTICIPANT	\N	PRESENT	0
493579	493357	08069G	PARTICIPANT	\N	PRESENT	0
493580	493357	19703U	PARTICIPANT	\N	PRESENT	0
493581	493357	20098N	PARTICIPANT	\N	PRESENT	0
493582	493357	20148F	PARTICIPANT	\N	PRESENT	0
493583	493357	14169X	PARTICIPANT	\N	PRESENT	0
493584	493357	08028W	PARTICIPANT	\N	PRESENT	0
493585	493357	14179A	PARTICIPANT	\N	PRESENT	0
493587	493357	19643A	PARTICIPANT	\N	PRESENT	0
493588	493357	20138D	PARTICIPANT	\N	PRESENT	0
493589	493357	19565D	PARTICIPANT	\N	PRESENT	0
493590	493357	14042U	PARTICIPANT	\N	PRESENT	0
493591	493357	04042C	PARTICIPANT	\N	PRESENT	0
493592	493357	19762G	PARTICIPANT	\N	PRESENT	0
493593	493357	19621T	PARTICIPANT	\N	PRESENT	0
493594	493357	19581D	PARTICIPANT	\N	PRESENT	0
493596	493357	20108W	PARTICIPANT	\N	PRESENT	0
493597	493357	14133K	PARTICIPANT	\N	PRESENT	0
493598	493357	19741B	PARTICIPANT	\N	PRESENT	0
493599	493357	19333N	PARTICIPANT	\N	PRESENT	0
493600	493357	01028R	PARTICIPANT	\N	PRESENT	0
493601	493357	19701S	PARTICIPANT	\N	PRESENT	0
493602	493357	20122U	PARTICIPANT	\N	PRESENT	0
493603	493357	19585H	PARTICIPANT	\N	PRESENT	0
493604	493357	19549D	PARTICIPANT	\N	PRESENT	0
493605	493357	19954N	PARTICIPANT	\N	PRESENT	0
493606	493357	19441R	PARTICIPANT	\N	PRESENT	0
493607	493357	19531S	PARTICIPANT	\N	PRESENT	0
493608	493357	01024M	PARTICIPANT	\N	PRESENT	0
493609	493357	14331P	PARTICIPANT	\N	PRESENT	0
493610	493357	20112S	PARTICIPANT	\N	PRESENT	0
493611	493357	04008A	PARTICIPANT	\N	PRESENT	0
493612	493357	04085P	PARTICIPANT	\N	PRESENT	0
493613	493357	20130U	PARTICIPANT	\N	PRESENT	0
493614	493357	19667J	PARTICIPANT	\N	PRESENT	0
493615	493357	19711U	PARTICIPANT	\N	PRESENT	0
493616	493357	19679N	PARTICIPANT	\N	PRESENT	0
493617	493357	05012A	PARTICIPANT	\N	PRESENT	0
493621	493357	19575F	PARTICIPANT	\N	PRESENT	0
493619	493357	19349W	PARTICIPANT	\N	PRESENT	0
493620	493357	19573D	PARTICIPANT	\N	PRESENT	0
493622	493357	14073Q	PARTICIPANT	\N	PRESENT	0
493623	493357	19563B	PARTICIPANT	\N	PRESENT	0
493625	493357	20088L	PARTICIPANT	\N	PRESENT	0
493626	493357	20018V	PARTICIPANT	\N	PRESENT	0
493627	493357	19695N	PARTICIPANT	\N	PRESENT	0
493628	493357	19687N	PARTICIPANT	\N	PRESENT	0
493629	493357	19335Q	PARTICIPANT	\N	PRESENT	0
493630	493357	04059M	PARTICIPANT	\N	PRESENT	0
493631	493357	12028B	PARTICIPANT	\N	PRESENT	0
493632	493357	19479G	PARTICIPANT	\N	PRESENT	0
493633	493357	19683J	PARTICIPANT	\N	PRESENT	0
493634	493357	20102Q	PARTICIPANT	\N	PRESENT	0
493635	493357	20056C	PARTICIPANT	\N	PRESENT	0
493636	493357	14189C	PARTICIPANT	\N	PRESENT	0
493637	493357	14207L	PARTICIPANT	\N	PRESENT	0
493638	493357	14223L	PARTICIPANT	\N	PRESENT	0
493639	493357	20030R	PARTICIPANT	\N	PRESENT	0
493640	493357	19543W	PARTICIPANT	\N	PRESENT	0
493641	493357	19533U	PARTICIPANT	\N	PRESENT	0
493642	493357	19693L	PARTICIPANT	\N	PRESENT	0
493643	493357	20074E	PARTICIPANT	\N	PRESENT	0
493644	493357	14237S	PARTICIPANT	\N	PRESENT	0
493645	493357	14111D	PARTICIPANT	\N	PRESENT	0
493646	493357	08034U	PARTICIPANT	\N	PRESENT	0
493647	493357	14083S	PARTICIPANT	\N	PRESENT	0
493648	493357	14217N	PARTICIPANT	\N	PRESENT	0
493649	493357	14173T	PARTICIPANT	\N	PRESENT	0
493650	493357	20020P	PARTICIPANT	\N	PRESENT	0
493651	493357	17583W	PARTICIPANT	\N	PRESENT	0
493652	493357	14033T	PARTICIPANT	\N	PRESENT	0
493653	493357	11067R	PARTICIPANT	\N	PRESENT	0
493654	493357	04057K	PARTICIPANT	\N	PRESENT	0
493655	493357	10006L	PARTICIPANT	\N	PRESENT	0
493656	493357	19681G	PARTICIPANT	\N	PRESENT	0
493657	493357	14211G	PARTICIPANT	\N	PRESENT	0
493658	493357	14229S	PARTICIPANT	\N	PRESENT	0
493659	493357	14121F	PARTICIPANT	\N	PRESENT	0
493697	493696	14026U	PARTICIPANT	\N	PRESENT	0
493698	493696	19713W	PARTICIPANT	\N	PRESENT	0
493699	493694	14026U	PARTICIPANT	\N	PRESENT	0
493700	493694	19713W	PARTICIPANT	\N	PRESENT	0
493704	493408	14026U	PARTICIPANT	\N	PRESENT	0
493705	493408	19713W	PARTICIPANT	\N	PRESENT	0
493706	493690	14026U	PARTICIPANT	\N	PRESENT	0
493707	493690	19713W	PARTICIPANT	\N	PRESENT	0
493756	492924	19747H	PARTICIPANT	\N	PRESENT	0
494090	493367	20074E	PARTICIPANT	\N	EXCUSE	0
494535	494532	19693L	PARTICIPANT	\N	PRESENT	0
494536	494532	19709B	PARTICIPANT	\N	PRESENT	0
494537	494532	01048V	PRESIDENT	0	PRESENT	0
494538	494532	19533U	PARTICIPANT	\N	PRESENT	0
494539	494532	01058X	PARTICIPANT	\N	PRESENT	0
483487	483166	11040E	PARTICIPANT	\N	PRESENT	0
483488	483166	01057W	PARTICIPANT	\N	PRESENT	0
483489	483166	19349W	PARTICIPANT	\N	PRESENT	0
483490	483166	19741B	PARTICIPANT	\N	PRESENT	0
483491	483166	19667J	PARTICIPANT	\N	PRESENT	0
483492	483166	11074Q	PRESIDENT	0	PRESENT	0
483493	483166	14253S	PARTICIPANT	\N	PRESENT	0
483494	483166	14225N	PARTICIPANT	\N	PRESENT	0
483495	483166	19762G	PARTICIPANT	\N	PRESENT	0
483496	483166	14083S	PARTICIPANT	\N	PRESENT	0
483497	483166	19479G	PARTICIPANT	\N	PRESENT	0
483498	483166	19651A	PARTICIPANT	\N	PRESENT	0
483499	483166	07029T	PARTICIPANT	\N	PRESENT	0
483500	483166	11048N	PARTICIPANT	\N	PRESENT	0
483501	483166	08010L	PARTICIPANT	\N	PRESENT	0
483502	483166	11053K	PARTICIPANT	\N	PRESENT	0
483503	483166	08011M	PARTICIPANT	\N	PRESENT	0
483504	483166	19531S	PARTICIPANT	\N	PRESENT	0
483505	483166	11012A	PARTICIPANT	\N	PRESENT	0
483506	483231	19768N	PARTICIPANT	\N	PRESENT	0
483507	483231	10015M	PARTICIPANT	\N	PRESENT	0
483508	483231	19812Y	PARTICIPANT	\N	PRESENT	0
483509	483231	01025N	PARTICIPANT	\N	PRESENT	0
483510	483231	11090Q	PRESIDENT	0	PRESENT	0
483511	483231	80013X	PARTICIPANT	\N	PRESENT	0
483512	483231	19866P	PARTICIPANT	\N	PRESENT	0
483513	483231	19295A	PARTICIPANT	\N	PRESENT	0
483514	483231	19705W	PARTICIPANT	\N	PRESENT	0
483515	483231	11083R	PARTICIPANT	\N	PRESENT	0
483516	483231	19747H	PARTICIPANT	\N	PRESENT	0
483517	483231	04043D	PARTICIPANT	\N	PRESENT	0
483518	483231	08028W	PARTICIPANT	\N	PRESENT	0
483519	483231	14249W	PARTICIPANT	\N	PRESENT	0
483520	483231	14265W	PARTICIPANT	\N	PRESENT	0
483521	483231	19619A	PARTICIPANT	\N	PRESENT	0
483522	483166	04086Q	PARTICIPANT	\N	PRESENT	0
483523	483166	14085U	PARTICIPANT	\N	PRESENT	0
483524	483231	19569H	PARTICIPANT	\N	PRESENT	0
483525	483231	96004D	PARTICIPANT	\N	PRESENT	0
483526	483166	08014Q	PARTICIPANT	\N	PRESENT	0
483527	483387	98035U	PARTICIPANT	\N	PRESENT	0
483528	483387	14065Q	PARTICIPANT	\N	PRESENT	0
483529	483387	19253P	PARTICIPANT	\N	PRESENT	0
483530	483387	01024M	PARTICIPANT	\N	PRESENT	0
483531	483387	04038G	PARTICIPANT	\N	PRESENT	0
483532	483387	19673G	PARTICIPANT	\N	PRESENT	0
483533	483387	19719D	PARTICIPANT	\N	PRESENT	0
483534	483387	01028R	PARTICIPANT	\N	PRESENT	0
483535	483387	14231L	PARTICIPANT	\N	PRESENT	0
483536	483387	19447X	PARTICIPANT	\N	PRESENT	0
483537	483387	05008E	PRESIDENT	0	PRESENT	0
483538	483387	19930E	PARTICIPANT	\N	PRESENT	0
483539	483387	95063L	PARTICIPANT	\N	PRESENT	0
483540	483387	14041T	PARTICIPANT	\N	PRESENT	0
483541	483387	14147R	PARTICIPANT	\N	PRESENT	0
483542	483387	14069U	PARTICIPANT	\N	PRESENT	0
483543	483387	14215L	PARTICIPANT	\N	PRESENT	0
483544	483387	08018U	PARTICIPANT	\N	PRESENT	0
483545	483245	11067R	PARTICIPANT	\N	PRESENT	0
483546	483245	01034P	PARTICIPANT	\N	PRESENT	0
483547	483245	04092N	PRESIDENT	0	PRESENT	0
483548	483245	08052W	PARTICIPANT	\N	PRESENT	0
483549	483245	19663E	PARTICIPANT	\N	PRESENT	0
483550	483245	19691J	PARTICIPANT	\N	PRESENT	0
483551	483245	19926J	PARTICIPANT	\N	PRESENT	0
483552	483245	19703U	PARTICIPANT	\N	PRESENT	0
483553	483245	11031D	PARTICIPANT	\N	PRESENT	0
483554	483245	14042U	PARTICIPANT	\N	PRESENT	0
483555	483245	14071N	PARTICIPANT	\N	PRESENT	0
483556	483245	14217N	PARTICIPANT	\N	PRESENT	0
483557	483245	19683J	PARTICIPANT	\N	PRESENT	0
483558	483245	98024R	PARTICIPANT	\N	PRESENT	0
483559	483245	10006L	PARTICIPANT	\N	PRESENT	0
483560	483166	19711U	PARTICIPANT	\N	PRESENT	0
483561	483166	19689Q	PARTICIPANT	\N	PRESENT	0
483562	483231	14331P	PARTICIPANT	\N	PRESENT	0
483563	483231	19515S	PARTICIPANT	\N	PRESENT	0
483564	483231	01043Q	PARTICIPANT	\N	PRESENT	0
483565	483231	14357A	PARTICIPANT	\N	PRESENT	0
483566	483231	19413M	PARTICIPANT	\N	PRESENT	0
483567	483231	14081Q	PARTICIPANT	\N	PRESENT	0
483568	483231	19912C	PARTICIPANT	\N	PRESENT	0
483569	483231	11099A	PARTICIPANT	\N	PRESENT	0
483570	483231	04049K	PARTICIPANT	\N	PRESENT	0
483571	483231	14197C	PARTICIPANT	\N	PRESENT	0
483572	483231	08039A	PARTICIPANT	\N	PRESENT	0
483573	483231	19467C	PARTICIPANT	\N	PRESENT	0
483574	483231	11026G	PARTICIPANT	\N	PRESENT	0
483575	483231	19695N	PARTICIPANT	\N	PRESENT	0
483576	483231	04088S	PARTICIPANT	\N	PRESENT	0
483577	483231	14115H	PARTICIPANT	\N	PRESENT	0
483578	483231	19507S	PARTICIPANT	\N	PRESENT	0
483579	483231	04097T	PARTICIPANT	\N	PRESENT	0
483580	483231	11077T	PARTICIPANT	\N	PRESENT	0
483581	483387	19629C	PARTICIPANT	\N	PRESENT	0
483582	483387	14179A	PARTICIPANT	\N	PRESENT	0
483583	483166	08034U	PARTICIPANT	\N	PRESENT	0
483584	483166	04071H	PARTICIPANT	\N	PRESENT	0
483585	483166	11110B	PARTICIPANT	\N	PRESENT	0
483586	483166	19687N	PARTICIPANT	\N	PRESENT	0
483587	483387	19585H	PARTICIPANT	\N	PRESENT	0
483588	483387	14151M	PARTICIPANT	\N	PRESENT	0
483589	483387	11085T	PARTICIPANT	\N	PRESENT	0
483590	483387	19729F	PARTICIPANT	\N	EXCUSE	0
483591	483387	14053L	PARTICIPANT	\N	PRESENT	0
483592	483387	11026G	PARTICIPANT	\N	PRESENT	0
483593	483387	19489J	PARTICIPANT	\N	PRESENT	0
483594	483231	19441R	PARTICIPANT	\N	PRESENT	0
483595	483231	08038Y	PARTICIPANT	\N	PRESENT	0
483596	483231	14033T	PARTICIPANT	\N	PRESENT	0
483597	483166	19647E	PARTICIPANT	\N	PRESENT	0
483598	483166	14331P	PARTICIPANT	\N	PRESENT	0
483599	483166	14034U	PARTICIPANT	\N	EXCUSE	0
488408	488407	11053K	PARTICIPANT	\N	PRESENT	0
488409	488407	14159V	PARTICIPANT	\N	PRESENT	0
488410	488407	05012A	PARTICIPANT	\N	PRESENT	0
489719	489718	19447X	PARTICIPANT	\N	PRESENT	0
489721	489720	19447X	PARTICIPANT	\N	PRESENT	0
494286	491379	19479G	PARTICIPANT	\N	EXCUSE	0
494587	491379	20032T	PARTICIPANT	\N	PRESENT	0
494588	491379	19954N	PARTICIPANT	\N	PRESENT	0
494589	491379	19643A	PARTICIPANT	\N	PRESENT	0
494590	491379	14259Y	PRESIDENT	0	PRESENT	0
494591	491379	04071H	PARTICIPANT	\N	PRESENT	0
494592	491379	19711U	PARTICIPANT	\N	PRESENT	0
494599	491379	19747H	PARTICIPANT	\N	PRESENT	0
498217	498216	10006L	PARTICIPANT	\N	PRESENT	0
499628	498268	08012N	PARTICIPANT	\N	PRESENT	0
499630	498263	08012N	PARTICIPANT	\N	PRESENT	0
499632	498293	20134Y	PARTICIPANT	\N	PRESENT	0
499633	498293	20058E	PARTICIPANT	\N	PRESENT	0
499638	498234	04070G	PARTICIPANT	\N	PRESENT	0
499640	498244	19399H	PARTICIPANT	\N	PRESENT	0
499641	498244	19643A	PARTICIPANT	\N	PRESENT	0
499642	498244	20052X	PARTICIPANT	\N	PRESENT	0
499643	498244	04070G	PARTICIPANT	\N	PRESENT	0
499644	498244	08017T	PARTICIPANT	\N	PRESENT	0
499646	498245	19399H	PARTICIPANT	\N	PRESENT	0
499647	498245	20052X	PARTICIPANT	\N	PRESENT	0
499648	498245	08017T	PARTICIPANT	\N	PRESENT	0
500414	497987	19663E	PARTICIPANT	\N	PRESENT	0
500415	497987	19798U	PARTICIPANT	\N	PRESENT	0
500416	497988	19663E	PARTICIPANT	\N	PRESENT	0
500417	497991	19663E	PARTICIPANT	\N	PRESENT	0
500434	500431	04047H	PARTICIPANT	\N	PRESENT	0
500441	500431	11066Q	PARTICIPANT	\N	PRESENT	0
500442	500431	14053L	PARTICIPANT	\N	PRESENT	0
500456	500455	11056N	PARTICIPANT	\N	PRESENT	0
500464	500455	19489J	PARTICIPANT	\N	PRESENT	0
500467	500458	19679N	PARTICIPANT	\N	PRESENT	0
500468	500465	19691J	PARTICIPANT	\N	PRESENT	0
500469	500465	19798U	PARTICIPANT	\N	PRESENT	0
500470	500465	19713W	PARTICIPANT	\N	PRESENT	0
500471	500459	19679N	PARTICIPANT	\N	PRESENT	0
500472	500460	19679N	PARTICIPANT	\N	PRESENT	0
500473	500463	19679N	PARTICIPANT	\N	PRESENT	0
500480	500479	20036X	PARTICIPANT	\N	PRESENT	0
506059	501820	08010L	PARTICIPANT	\N	PRESENT	0
509257	506101	14105F	PARTICIPANT	\N	PRESENT	0
509258	506101	14041T	PARTICIPANT	\N	PRESENT	0
509259	506101	14195A	PARTICIPANT	\N	PRESENT	0
509260	506101	14083S	PARTICIPANT	\N	PRESENT	0
509261	506101	20040T	PARTICIPANT	\N	PRESENT	0
509262	506101	19695N	PARTICIPANT	\N	PRESENT	0
509263	506101	20126Y	PARTICIPANT	\N	PRESENT	0
509264	506101	14255U	PARTICIPANT	\N	PRESENT	0
509265	506101	04034C	PARTICIPANT	\N	PRESENT	0
509266	506101	11026G	PARTICIPANT	\N	PRESENT	0
509304	502325	12041X	PARTICIPANT	\N	PRESENT	0
509307	502325	20046A	PARTICIPANT	\N	PRESENT	0
509308	502325	11040E	PARTICIPANT	\N	PRESENT	0
509309	502325	20028X	PARTICIPANT	\N	PRESENT	0
509310	502325	14097Y	PARTICIPANT	\N	PRESENT	0
509311	502325	20080C	PARTICIPANT	\N	PRESENT	0
509312	502325	19647E	PARTICIPANT	\N	PRESENT	0
509313	502325	14021P	PARTICIPANT	\N	PRESENT	0
509314	502325	19689Q	PARTICIPANT	\N	PRESENT	0
509315	502325	20134Y	PARTICIPANT	\N	PRESENT	0
509316	502325	20100N	PARTICIPANT	\N	PRESENT	0
509317	502325	20072C	PARTICIPANT	\N	PRESENT	0
509318	502325	11012A	PARTICIPANT	\N	PRESENT	0
509319	502325	19563B	PARTICIPANT	\N	PRESENT	0
509320	502325	04085P	PARTICIPANT	\N	PRESENT	0
509321	502325	19565D	PARTICIPANT	\N	PRESENT	0
509322	502325	19758L	PARTICIPANT	\N	PRESENT	0
509323	502325	20102Q	PARTICIPANT	\N	PRESENT	0
509324	502325	19687N	PARTICIPANT	\N	PRESENT	0
509325	502325	19695N	PARTICIPANT	\N	PRESENT	0
509326	502325	20060X	PARTICIPANT	\N	PRESENT	0
509327	502325	20082E	PARTICIPANT	\N	PRESENT	0
509328	502325	19599P	PARTICIPANT	\N	PRESENT	0
509329	502325	20030R	PARTICIPANT	\N	PRESENT	0
509330	502325	20052X	PARTICIPANT	\N	PRESENT	0
509255	506101	19760E	PARTICIPANT	\N	PRESENT	0
509256	506101	19515S	PRESIDENT	0	PRESENT	0
509331	502325	14267Y	PARTICIPANT	\N	PRESENT	0
509332	502325	14257W	PARTICIPANT	\N	PRESENT	0
509333	502325	19441R	PARTICIPANT	\N	PRESENT	0
509334	502325	95063L	PARTICIPANT	\N	PRESENT	0
509335	502325	19651A	PARTICIPANT	\N	PRESENT	0
509336	502325	20106U	PARTICIPANT	\N	PRESENT	0
509337	502325	20144B	PARTICIPANT	\N	PRESENT	0
509338	502325	14083S	PARTICIPANT	\N	PRESENT	0
509339	502325	19479G	PARTICIPANT	\N	PRESENT	0
509340	502325	20042V	PARTICIPANT	\N	PRESENT	0
509344	502325	11048N	PARTICIPANT	\N	PRESENT	0
509342	502325	19671E	PARTICIPANT	\N	PRESENT	0
509343	502325	14215L	PARTICIPANT	\N	PRESENT	0
509345	502325	14225N	PARTICIPANT	\N	PRESENT	0
509346	502325	14053L	PARTICIPANT	\N	PRESENT	0
509347	502325	14187A	PARTICIPANT	\N	PRESENT	0
509348	502325	20124W	PARTICIPANT	\N	PRESENT	0
509349	502325	11085T	PARTICIPANT	\N	PRESENT	0
509350	502325	20062A	PARTICIPANT	\N	PRESENT	0
509351	502325	20040T	PARTICIPANT	\N	PRESENT	0
509352	502325	20090E	PARTICIPANT	\N	PRESENT	0
509353	502325	19711U	PARTICIPANT	\N	PRESENT	0
509354	502325	14329V	PARTICIPANT	\N	PRESENT	0
509355	502325	04033B	PARTICIPANT	\N	PRESENT	0
509356	502325	14223L	PARTICIPANT	\N	PRESENT	0
509357	502325	11090Q	PARTICIPANT	\N	PRESENT	0
509358	502325	08034U	PARTICIPANT	\N	PRESENT	0
509359	502325	20022R	PARTICIPANT	\N	PRESENT	0
509360	502325	20086J	PARTICIPANT	\N	PRESENT	0
509361	502325	19507S	PARTICIPANT	\N	PRESENT	0
509362	502325	20026V	PARTICIPANT	\N	PRESENT	0
509363	502325	20136B	PARTICIPANT	\N	PRESENT	0
509364	502325	20034V	PARTICIPANT	\N	PRESENT	0
509365	502325	20032T	PARTICIPANT	\N	PRESENT	0
509366	502325	01057W	PARTICIPANT	\N	PRESENT	0
509367	502325	19515S	PARTICIPANT	\N	PRESENT	0
509368	502325	99004R	PARTICIPANT	\N	PRESENT	0
509369	502325	01058X	PARTICIPANT	\N	PRESENT	0
509370	502325	20044X	PARTICIPANT	\N	PRESENT	0
509371	502325	20070A	PARTICIPANT	\N	PRESENT	0
509372	502325	19531S	PARTICIPANT	\N	PRESENT	0
509373	502325	14169X	PARTICIPANT	\N	PRESENT	0
509374	502325	14275Y	PARTICIPANT	\N	PRESENT	0
509375	502325	19549D	PARTICIPANT	\N	PRESENT	0
509376	502325	20116W	PARTICIPANT	\N	PRESENT	0
509377	502325	18083K	PARTICIPANT	\N	PRESENT	0
509378	502325	05012A	PARTICIPANT	\N	PRESENT	0
509379	502325	20110Q	PARTICIPANT	\N	PRESENT	0
509380	502325	19699S	PARTICIPANT	\N	PRESENT	0
509381	502325	11077T	PARTICIPANT	\N	PRESENT	0
509382	502325	14229S	PARTICIPANT	\N	PRESENT	0
509383	502325	19543W	PARTICIPANT	\N	PRESENT	0
509384	502325	11074Q	PARTICIPANT	\N	PRESENT	0
509385	502325	19335Q	PARTICIPANT	\N	PRESENT	0
509386	502325	20066E	PARTICIPANT	\N	PRESENT	0
509387	502325	19347U	PARTICIPANT	\N	PRESENT	0
509388	502325	20092G	PARTICIPANT	\N	PRESENT	0
509389	502325	14237S	PARTICIPANT	\N	PRESENT	0
509390	502325	19467C	PARTICIPANT	\N	PRESENT	0
509391	502325	19631V	PARTICIPANT	\N	PRESENT	0
509392	502325	04008A	PARTICIPANT	\N	PRESENT	0
509393	502325	19553Y	PARTICIPANT	\N	PRESENT	0
509394	502325	14030Q	PARTICIPANT	\N	PRESENT	0
509395	502325	20038A	PARTICIPANT	\N	PRESENT	0
509396	502325	14253S	PARTICIPANT	\N	PRESENT	0
509397	502325	11053K	PARTICIPANT	\N	PRESENT	0
509398	502325	14038Y	PARTICIPANT	\N	PRESENT	0
509399	502325	14219Q	PARTICIPANT	\N	PRESENT	0
509407	509406	04047H	PARTICIPANT	\N	PRESENT	0
509408	509406	14299H	PARTICIPANT	\N	PRESENT	0
509410	509406	11066Q	PARTICIPANT	\N	PRESENT	0
509419	509416	04047H	PARTICIPANT	\N	PRESENT	0
509420	509416	14053L	PARTICIPANT	\N	PRESENT	0
509421	509416	14299H	PARTICIPANT	\N	PRESENT	0
509424	509416	11066Q	PARTICIPANT	\N	PRESENT	0
509431	502325	11099A	PARTICIPANT	\N	PRESENT	0
509435	502325	19762G	PARTICIPANT	\N	PRESENT	0
509442	502325	11026G	PARTICIPANT	\N	PRESENT	0
509443	505939	12016W	PARTICIPANT	\N	PRESENT	0
509444	502325	19717B	PARTICIPANT	\N	PRESENT	0
509445	505939	19701S	PARTICIPANT	\N	PRESENT	1
509446	505939	14205J	PARTICIPANT	\N	PRESENT	1
509447	502325	14327T	PARTICIPANT	\N	PRESENT	0
509448	502325	19369B	PARTICIPANT	\N	PRESENT	0
509449	505939	04070G	PARTICIPANT	\N	PRESENT	1
509450	505939	19768N	PARTICIPANT	\N	PRESENT	1
509451	505939	20174H	PARTICIPANT	\N	PRESENT	1
509452	502325	19741B	PARTICIPANT	\N	PRESENT	0
509453	505939	19575F	PARTICIPANT	\N	PRESENT	1
509454	505939	20094J	PARTICIPANT	\N	PRESENT	1
509455	505939	14133K	PARTICIPANT	\N	PRESENT	1
509456	505939	19725B	PARTICIPANT	\N	PRESENT	1
509457	505939	04057K	PARTICIPANT	\N	PRESENT	1
509458	505939	19782L	PARTICIPANT	\N	PRESENT	1
509459	502325	14331P	PARTICIPANT	\N	PRESENT	0
509460	505939	08015R	PARTICIPANT	\N	PRESENT	1
509461	505939	14251Q	PARTICIPANT	\N	PRESENT	1
509462	505939	20054A	PARTICIPANT	\N	PRESENT	1
509463	505939	19251M	PARTICIPANT	\N	PRESENT	1
509464	505939	14033T	PARTICIPANT	\N	PRESENT	1
509465	502325	08010L	PARTICIPANT	\N	PRESENT	0
509466	505939	19369B	PARTICIPANT	\N	PRESENT	1
509467	505939	04045F	PARTICIPANT	\N	PRESENT	1
509468	505939	96004D	PARTICIPANT	\N	PRESENT	0
509469	505939	14331P	PRESIDENT	0	PRESENT	0
509470	502325	19551W	PARTICIPANT	\N	PRESENT	0
509474	502325	19387D	PARTICIPANT	\N	PRESENT	0
509472	502325	20058E	PARTICIPANT	\N	PRESENT	0
509473	505939	20098N	PARTICIPANT	\N	EXCUSE	0
509475	502325	14259Y	PARTICIPANT	\N	PRESENT	0
509477	502325	19745F	PARTICIPANT	\N	PRESENT	0
509479	502325	20142Y	PARTICIPANT	\N	PRESENT	0
509491	505939	19631V	PARTICIPANT	\N	PRESENT	0
509493	505939	20086J	PARTICIPANT	\N	PRESENT	0
509495	502325	07029T	PARTICIPANT	\N	PRESENT	0
509497	505939	14089Y	PARTICIPANT	\N	PRESENT	0
509498	505939	19747H	PARTICIPANT	\N	PRESENT	0
509501	505939	14207L	PARTICIPANT	\N	PRESENT	0
509503	505939	11101A	PARTICIPANT	\N	PRESENT	0
509505	505939	14038Y	PARTICIPANT	\N	PRESENT	0
483463	483164	11110B	PARTICIPANT	\N	PRESENT	0
483483	483482	08058D	PARTICIPANT	\N	PRESENT	0
488728	488687	11097X	PRESIDENT	0	PRESENT	0
488729	488687	19715Y	PARTICIPANT	\N	PRESENT	0
488730	488687	04092N	PARTICIPANT	\N	PRESENT	0
488731	488687	01034P	PARTICIPANT	\N	PRESENT	0
488732	488687	19479G	PARTICIPANT	\N	PRESENT	0
488733	488687	19703U	PARTICIPANT	\N	PRESENT	0
488734	488687	19766L	PARTICIPANT	\N	PRESENT	0
488735	488687	19503N	PARTICIPANT	\N	PRESENT	0
488736	488687	11012A	PARTICIPANT	\N	PRESENT	0
488737	488687	19683J	PARTICIPANT	\N	PRESENT	0
488738	488687	11067R	PARTICIPANT	\N	EXCUSE	0
488739	488687	11048N	PARTICIPANT	\N	PRESENT	0
488740	488687	19545Y	PARTICIPANT	\N	PRESENT	0
488741	488687	19667J	PARTICIPANT	\N	PRESENT	0
488742	488432	11031D	PARTICIPANT	\N	PRESENT	0
488743	488432	19697Q	PARTICIPANT	\N	PRESENT	0
488744	488687	19573D	PARTICIPANT	\N	PRESENT	0
488745	488687	19643A	PARTICIPANT	\N	PRESENT	0
488746	488687	04085P	PARTICIPANT	\N	PRESENT	0
488747	488687	10006L	PARTICIPANT	\N	PRESENT	0
488748	488687	14041T	PARTICIPANT	\N	PRESENT	0
488749	488687	19447X	PARTICIPANT	\N	PRESENT	0
488750	488687	19649G	PARTICIPANT	\N	PRESENT	0
488751	488687	19691J	PARTICIPANT	\N	PRESENT	0
488752	488693	11097X	PRESIDENT	0	PRESENT	0
488753	488693	08052W	PARTICIPANT	\N	PRESENT	0
488754	488693	14087W	PARTICIPANT	\N	PRESENT	0
488755	488693	19703U	PARTICIPANT	\N	PRESENT	0
488756	488693	19697Q	PARTICIPANT	\N	PRESENT	0
488757	488693	14042U	PARTICIPANT	\N	PRESENT	0
488758	488693	14119M	PARTICIPANT	\N	PRESENT	0
488759	488693	19715Y	PARTICIPANT	\N	PRESENT	0
488766	488693	19569H	PARTICIPANT	\N	PRESENT	0
488761	488693	01034P	PARTICIPANT	\N	PRESENT	0
488762	488693	10006L	PARTICIPANT	\N	PRESENT	0
488763	488693	19591F	PARTICIPANT	\N	PRESENT	0
488764	488693	19926J	PARTICIPANT	\N	PRESENT	0
488765	488693	19691J	PARTICIPANT	\N	PRESENT	0
488767	488693	11031D	PARTICIPANT	\N	PRESENT	0
488768	488693	19415P	PARTICIPANT	\N	PRESENT	0
488778	488693	19958S	PARTICIPANT	\N	PRESENT	0
488779	488693	04092N	PARTICIPANT	\N	EXCUSE	0
488780	488693	14071N	PARTICIPANT	\N	EXCUSE	0
488781	488693	11067R	PARTICIPANT	\N	EXCUSE	0
488782	488693	19565D	PARTICIPANT	\N	EXCUSE	0
488783	488693	14223L	PARTICIPANT	\N	EXCUSE	0
488784	488693	17779H	PARTICIPANT	\N	EXCUSE	0
488855	488690	11097X	PRESIDENT	0	PRESENT	0
488856	488690	10006L	PARTICIPANT	\N	PRESENT	0
488857	488690	19503N	PARTICIPANT	\N	PRESENT	0
488858	488690	19479G	PARTICIPANT	\N	PRESENT	0
488859	488690	19703U	PARTICIPANT	\N	PRESENT	0
488860	488690	19697Q	PARTICIPANT	\N	PRESENT	0
488861	488690	14331P	PARTICIPANT	\N	PRESENT	0
488862	488690	19766L	PARTICIPANT	\N	PRESENT	0
488863	488690	19447X	PARTICIPANT	\N	PRESENT	0
488864	488690	19691J	PARTICIPANT	\N	PRESENT	0
488865	488690	19715Y	PARTICIPANT	\N	PRESENT	0
488866	488690	19663E	PARTICIPANT	\N	EXCUSE	0
488867	488690	99004R	PARTICIPANT	\N	PRESENT	0
488868	488690	04092N	PARTICIPANT	\N	EXCUSE	0
488869	488690	19573D	PARTICIPANT	\N	PRESENT	0
488870	488690	01034P	PARTICIPANT	\N	EXCUSE	0
488871	488690	11067R	PARTICIPANT	\N	EXCUSE	0
488872	488690	11031D	PARTICIPANT	\N	EXCUSE	0
488873	488690	19545Y	PARTICIPANT	\N	EXCUSE	0
488918	488852	11097X	PRESIDENT	0	PRESENT	0
488919	488852	19503N	PARTICIPANT	\N	PRESENT	0
488920	488852	19703U	PARTICIPANT	\N	PRESENT	0
488921	488852	10006L	PARTICIPANT	\N	PRESENT	0
488922	488852	19479G	PARTICIPANT	\N	PRESENT	0
488923	488852	19766L	PARTICIPANT	\N	PRESENT	0
488924	488852	99004R	PARTICIPANT	\N	PRESENT	0
488925	488852	19691J	PARTICIPANT	\N	PRESENT	0
488926	488852	14331P	PARTICIPANT	\N	PRESENT	0
488927	488852	19447X	PARTICIPANT	\N	PRESENT	0
488928	488852	19545Y	PARTICIPANT	\N	EXCUSE	0
488929	488852	11031D	PARTICIPANT	\N	EXCUSE	0
488930	488852	19663E	PARTICIPANT	\N	EXCUSE	0
488931	488852	11067R	PARTICIPANT	\N	EXCUSE	0
488932	488852	04092N	PARTICIPANT	\N	EXCUSE	0
488933	488852	01034P	PARTICIPANT	\N	EXCUSE	0
491568	491507	20090E	PARTICIPANT	\N	PRESENT	0
491593	491507	19663E	PARTICIPANT	\N	EXCUSE	0
495278	494532	18003S	PARTICIPANT	\N	EXCUSE	0
495279	494532	14299H	PARTICIPANT	\N	EXCUSE	0
495347	495346	08010L	PARTICIPANT	\N	PRESENT	0
495349	495348	08010L	PARTICIPANT	\N	PRESENT	0
495351	495350	08010L	PARTICIPANT	\N	PRESENT	0
495353	495352	11048N	PARTICIPANT	\N	PRESENT	0
496854	493371	01028R	PARTICIPANT	\N	PRESENT	0
496313	495438	14259Y	PRESIDENT	0	PRESENT	0
496314	496311	14259Y	PRESIDENT	0	PRESENT	0
503260	503259	04035D	PARTICIPANT	\N	PRESENT	0
503261	503259	98022P	PARTICIPANT	\N	PRESENT	0
505612	504749	01058X	PARTICIPANT	0	PRESENT	0
505613	504749	19503N	PARTICIPANT	\N	PRESENT	0
505614	504749	19533U	PARTICIPANT	\N	PRESENT	0
505618	504749	04043D	PARTICIPANT	\N	PRESENT	0
505637	504749	01048V	PARTICIPANT	\N	PRESENT	0
506031	496311	11097X	PARTICIPANT	\N	PRESENT	0
506954	502316	20026V	PARTICIPANT	\N	PRESENT	0
506955	502316	19741B	PARTICIPANT	\N	PRESENT	0
506956	502316	14329V	PARTICIPANT	\N	PRESENT	0
506957	502316	20118Y	PARTICIPANT	\N	PRESENT	0
506958	502316	12016W	PARTICIPANT	\N	PRESENT	0
506959	502316	95063L	PARTICIPANT	\N	PRESENT	0
506960	502316	04086Q	PARTICIPANT	\N	PRESENT	0
506961	502316	11040E	PARTICIPANT	\N	PRESENT	0
506962	502316	19687N	PARTICIPANT	\N	PRESENT	0
506963	502316	19515S	PARTICIPANT	\N	PRESENT	0
506964	502316	19521Q	PARTICIPANT	\N	PRESENT	0
506965	502316	19713W	PARTICIPANT	\N	PRESENT	0
506966	502316	14327T	PARTICIPANT	\N	PRESENT	0
506967	502316	19479G	PARTICIPANT	\N	PRESENT	0
506968	502316	14187A	PARTICIPANT	\N	PRESENT	0
506969	502316	19575F	PARTICIPANT	\N	PRESENT	0
506970	502316	20126Y	PARTICIPANT	\N	PRESENT	0
506971	502316	19647E	PARTICIPANT	\N	PRESENT	0
506972	502316	20024T	PARTICIPANT	\N	PRESENT	0
506973	502316	14147R	PARTICIPANT	\N	PRESENT	0
506974	502316	11097X	PARTICIPANT	\N	PRESENT	0
506975	502316	20070A	PARTICIPANT	\N	PRESENT	0
506976	502316	14331P	PARTICIPANT	\N	PRESENT	0
506952	502316	20032T	PARTICIPANT	\N	PRESENT	0
506953	502316	08069G	PARTICIPANT	\N	PRESENT	0
506977	502316	08011M	PARTICIPANT	\N	PRESENT	0
506978	502316	04071H	PARTICIPANT	\N	PRESENT	0
506979	502316	17367Q	PARTICIPANT	\N	PRESENT	0
506980	502316	19551W	PARTICIPANT	\N	PRESENT	0
506981	502316	11065P	PARTICIPANT	\N	PRESENT	0
506982	502316	14215L	PARTICIPANT	\N	PRESENT	0
506983	502316	14069U	PARTICIPANT	\N	PRESENT	0
506984	502316	19631V	PARTICIPANT	\N	PRESENT	0
506985	502316	19621T	PARTICIPANT	\N	PRESENT	0
506986	502316	19573D	PARTICIPANT	\N	PRESENT	0
506987	502316	11099A	PARTICIPANT	\N	PRESENT	0
506988	502316	04085P	PARTICIPANT	\N	PRESENT	0
506989	502316	11056N	PARTICIPANT	\N	PRESENT	0
506990	502316	20086J	PARTICIPANT	\N	PRESENT	0
506991	502316	01057W	PARTICIPANT	\N	PRESENT	0
506992	502316	19739H	PARTICIPANT	\N	PRESENT	0
506993	502316	19569H	PARTICIPANT	\N	PRESENT	0
506994	502316	14257W	PARTICIPANT	\N	PRESENT	0
506995	502316	19369B	PARTICIPANT	\N	PRESENT	0
506996	502316	19531S	PARTICIPANT	\N	PRESENT	0
506997	502316	14219Q	PARTICIPANT	\N	PRESENT	0
494540	494532	19735D	PARTICIPANT	\N	EXCUSE	0
494541	494532	20072C	PARTICIPANT	\N	EXCUSE	0
494879	491608	20024T	PARTICIPANT	\N	PRESENT	0
494880	491608	14030Q	PRESIDENT	0	PRESENT	0
494881	491608	19621T	PARTICIPANT	\N	PRESENT	0
494882	491608	19681G	PARTICIPANT	\N	PRESENT	0
494883	491608	19693L	PARTICIPANT	\N	PRESENT	0
494884	491608	04035D	PARTICIPANT	\N	PRESENT	0
494885	491608	19715Y	PARTICIPANT	\N	PRESENT	0
494886	491608	07029T	PARTICIPANT	\N	PRESENT	0
494887	491608	14221J	PARTICIPANT	\N	PRESENT	0
494888	491608	20118Y	PARTICIPANT	\N	PRESENT	0
494889	491608	20130U	PARTICIPANT	\N	PRESENT	0
494890	491608	11045K	PARTICIPANT	\N	PRESENT	0
494891	491608	20098N	PARTICIPANT	\N	PRESENT	0
494892	491608	19749K	PARTICIPANT	\N	PRESENT	0
494893	491608	20138D	PARTICIPANT	\N	EXCUSE	0
494894	491608	11031D	PARTICIPANT	\N	EXCUSE	0
494895	491608	19599P	PARTICIPANT	\N	EXCUSE	0
494896	491608	20106U	PARTICIPANT	\N	EXCUSE	0
494897	491608	14179A	PARTICIPANT	\N	EXCUSE	0
494898	491608	20066E	PARTICIPANT	\N	EXCUSE	0
494899	491608	08017T	PARTICIPANT	\N	EXCUSE	0
494900	491608	19866P	PARTICIPANT	\N	EXCUSE	0
494901	491608	08061X	PARTICIPANT	\N	EXCUSE	0
494902	491608	19798U	PARTICIPANT	\N	EXCUSE	0
494903	491608	20046A	PARTICIPANT	\N	EXCUSE	0
494904	491608	14109K	PARTICIPANT	\N	EXCUSE	0
494905	491608	17737W	PARTICIPANT	\N	PRESENT	0
494914	493327	19447X	PARTICIPANT	\N	EXCUSE	0
494915	493327	11067R	PARTICIPANT	\N	EXCUSE	0
494916	493327	19683J	PARTICIPANT	\N	EXCUSE	0
494920	491185	19515S	PRESIDENT	0	PRESENT	0
494921	491185	19575F	PARTICIPANT	\N	PRESENT	0
494922	491185	14030Q	PARTICIPANT	\N	PRESENT	0
494923	491185	20094J	PARTICIPANT	\N	PRESENT	0
494924	491185	19545Y	PARTICIPANT	\N	PRESENT	0
494925	491185	20060X	PARTICIPANT	\N	PRESENT	0
494926	491185	19467C	PARTICIPANT	\N	PRESENT	0
494927	491185	14357A	PARTICIPANT	\N	PRESENT	0
494928	491185	14041T	PARTICIPANT	\N	PRESENT	0
494929	491185	20134Y	PARTICIPANT	\N	PRESENT	0
494930	491185	19695N	PARTICIPANT	\N	PRESENT	0
494931	491185	16685X	PARTICIPANT	\N	PRESENT	0
494932	491185	14031R	PARTICIPANT	\N	PRESENT	0
494933	491185	08073C	PARTICIPANT	\N	PRESENT	0
494934	491185	20092G	PARTICIPANT	\N	PRESENT	0
494935	491185	19762G	PARTICIPANT	\N	PRESENT	0
494936	491185	19760E	PARTICIPANT	\N	EXCUSE	0
494937	491185	19717B	PARTICIPANT	\N	EXCUSE	0
494938	491185	08060W	PARTICIPANT	\N	EXCUSE	0
494939	491185	14083S	PARTICIPANT	\N	EXCUSE	0
494940	491185	14105F	PARTICIPANT	\N	EXCUSE	0
494941	491185	19251M	PARTICIPANT	\N	EXCUSE	0
494942	491185	14026U	PARTICIPANT	\N	EXCUSE	0
494944	491185	08015R	PARTICIPANT	\N	EXCUSE	0
494945	491185	19671E	PARTICIPANT	\N	EXCUSE	0
494947	491185	19369B	PARTICIPANT	\N	EXCUSE	0
494948	491185	14253S	PARTICIPANT	\N	EXCUSE	0
494949	491185	20082E	PARTICIPANT	\N	EXCUSE	0
494950	491185	20054A	PARTICIPANT	\N	EXCUSE	0
494951	491185	19301E	PARTICIPANT	\N	EXCUSE	0
495011	494295	04085P	PARTICIPANT	\N	PRESENT	0
495216	495213	04057K	PARTICIPANT	\N	PRESENT	0
495217	495213	14331P	PRESIDENT	0	PRESENT	0
495219	495213	14073Q	PARTICIPANT	\N	PRESENT	0
495220	495213	11083R	PARTICIPANT	\N	PRESENT	0
495221	495213	12041X	PARTICIPANT	\N	PRESENT	0
495222	495213	19553Y	PARTICIPANT	\N	PRESENT	0
495223	495213	14357A	PARTICIPANT	\N	PRESENT	0
495224	495213	14033T	PARTICIPANT	\N	PRESENT	0
495287	494732	20134Y	PARTICIPANT	\N	PRESENT	0
495595	494847	19415P	PARTICIPANT	\N	PRESENT	0
495596	494847	11067R	PARTICIPANT	\N	PRESENT	0
495597	494846	19415P	PARTICIPANT	\N	PRESENT	0
495598	494846	11067R	PARTICIPANT	\N	PRESENT	0
495600	494848	19415P	PARTICIPANT	\N	PRESENT	0
495601	494848	11067R	PARTICIPANT	\N	PRESENT	0
495602	494849	19415P	PARTICIPANT	\N	PRESENT	0
495869	495266	19725B	PARTICIPANT	\N	PRESENT	0
495866	495266	20074E	PARTICIPANT	\N	PRESENT	0
495867	495266	19729F	PARTICIPANT	\N	PRESENT	0
495870	495266	07004J	PARTICIPANT	\N	PRESENT	0
495871	495266	14179A	PARTICIPANT	\N	PRESENT	0
496326	495268	20114U	PARTICIPANT	\N	PRESENT	0
496333	494918	19663E	PARTICIPANT	\N	PRESENT	0
496334	494918	01034P	PARTICIPANT	\N	PRESENT	0
496381	495038	04086Q	PARTICIPANT	\N	EXCUSE	0
496397	495038	11040E	PARTICIPANT	\N	PRESENT	0
496398	495038	11110B	PARTICIPANT	\N	PRESENT	0
496399	495038	08011M	PARTICIPANT	\N	PRESENT	0
496400	495038	19479G	PARTICIPANT	\N	PRESENT	0
497047	495107	01062T	PARTICIPANT	\N	EXCUSE	0
497787	495122	12041X	PARTICIPANT	\N	PRESENT	0
497788	495122	19649G	PARTICIPANT	\N	PRESENT	0
497789	495122	11026G	PARTICIPANT	\N	PRESENT	0
497790	495122	14257W	PARTICIPANT	\N	PRESENT	0
497791	495122	17779H	PARTICIPANT	\N	PRESENT	0
497792	495122	20106U	PARTICIPANT	\N	PRESENT	0
497793	495122	04085P	PARTICIPANT	\N	PRESENT	0
497794	495122	19629C	PARTICIPANT	\N	PRESENT	0
497795	495122	04047H	PARTICIPANT	\N	PRESENT	0
497796	495122	05008E	PARTICIPANT	\N	PRESENT	0
497797	495122	20050V	PARTICIPANT	\N	PRESENT	0
497798	495122	20110Q	PARTICIPANT	\N	PRESENT	0
497799	495122	19643A	PARTICIPANT	\N	PRESENT	0
497800	495122	19691J	PARTICIPANT	\N	PRESENT	0
497801	495122	19758L	PARTICIPANT	\N	PRESENT	0
497802	495122	14151M	PARTICIPANT	\N	PRESENT	0
497803	495122	19593H	PARTICIPANT	\N	PRESENT	0
497804	495122	07004J	PARTICIPANT	\N	PRESENT	0
497812	495122	20086J	PARTICIPANT	\N	PRESENT	0
497806	495122	14041T	PARTICIPANT	\N	PRESENT	0
497807	495122	19747H	PARTICIPANT	\N	PRESENT	0
497808	495122	14215L	PARTICIPANT	\N	PRESENT	0
497809	495122	19693L	PARTICIPANT	\N	PRESENT	0
497810	495122	19399H	PARTICIPANT	\N	PRESENT	0
497811	495122	14021P	PARTICIPANT	\N	PRESENT	0
497813	495122	19713W	PARTICIPANT	\N	PRESENT	0
497814	495122	19683J	PARTICIPANT	\N	PRESENT	0
497815	495122	12016W	PARTICIPANT	\N	PRESENT	0
497816	495122	14089Y	PARTICIPANT	\N	PRESENT	0
497818	495122	04043D	PARTICIPANT	\N	PRESENT	0
497819	495122	07029T	PARTICIPANT	\N	PRESENT	0
497820	495122	19611R	PARTICIPANT	\N	PRESENT	0
497821	495122	11090Q	PARTICIPANT	\N	PRESENT	0
497822	495122	19533U	PARTICIPANT	\N	PRESENT	0
497823	495122	11085T	PARTICIPANT	\N	PRESENT	0
497827	495122	04035D	PARTICIPANT	\N	PRESENT	0
497825	495122	14123H	PARTICIPANT	\N	PRESENT	0
497826	495122	14229S	PARTICIPANT	\N	PRESENT	0
497828	495122	19447X	PARTICIPANT	\N	PRESENT	0
497829	495122	19621T	PARTICIPANT	\N	PRESENT	0
497830	495122	19543W	PARTICIPANT	\N	PRESENT	0
497831	495122	19369B	PARTICIPANT	\N	PRESENT	0
497832	495122	19663E	PARTICIPANT	\N	PRESENT	0
497833	495122	20134Y	PARTICIPANT	\N	PRESENT	0
497837	495122	19647E	PARTICIPANT	\N	PRESENT	0
497838	495122	20152B	PARTICIPANT	\N	PRESENT	0
497841	495122	20142Y	PARTICIPANT	\N	PRESENT	0
503132	503131	11048N	PARTICIPANT	\N	PRESENT	0
503288	503286	01025N	PARTICIPANT	\N	PRESENT	0
503285	503284	04043D	PARTICIPANT	\N	PRESENT	0
503287	503286	19507S	PARTICIPANT	\N	PRESENT	0
503289	503286	19413M	PARTICIPANT	\N	PRESENT	0
503290	503286	08015R	PARTICIPANT	\N	PRESENT	0
503292	503291	19507S	PARTICIPANT	\N	PRESENT	0
503293	503291	01025N	PARTICIPANT	\N	PRESENT	0
503294	503291	19413M	PARTICIPANT	\N	PRESENT	0
503297	503295	19507S	PARTICIPANT	\N	PRESENT	0
503298	503295	01025N	PARTICIPANT	\N	PRESENT	0
503299	503295	19413M	PARTICIPANT	\N	PRESENT	0
503302	503301	19507S	PARTICIPANT	\N	PRESENT	0
503303	503301	01025N	PARTICIPANT	\N	PRESENT	0
503304	503301	19413M	PARTICIPANT	\N	PRESENT	0
503307	503305	19507S	PARTICIPANT	\N	PRESENT	0
503308	503305	01025N	PARTICIPANT	\N	PRESENT	0
503309	503305	19413M	PARTICIPANT	\N	PRESENT	0
503316	503315	01043Q	PARTICIPANT	\N	PRESENT	0
503317	503315	19631V	PARTICIPANT	\N	PRESENT	0
503318	503315	14187A	PARTICIPANT	\N	PRESENT	0
503447	503157	14237S	PARTICIPANT	\N	PRESENT	0
488995	488727	19671E	PARTICIPANT	\N	EXCUSE	0
484860	482484	19335Q	PARTICIPANT	\N	PRESENT	0
489161	489107	14259Y	PARTICIPANT	\N	EXCUSE	0
489160	489107	19629C	PARTICIPANT	\N	EXCUSE	0
489162	489107	14217N	PARTICIPANT	\N	EXCUSE	0
489163	489107	19715Y	PARTICIPANT	\N	EXCUSE	0
489164	489107	19729F	PARTICIPANT	\N	EXCUSE	0
489165	489107	19826F	PARTICIPANT	\N	EXCUSE	0
489166	489107	14059S	PARTICIPANT	\N	EXCUSE	0
489167	489107	19447X	PARTICIPANT	\N	EXCUSE	0
489168	489107	08045X	PARTICIPANT	\N	EXCUSE	0
494907	493327	11048N	PARTICIPANT	\N	PRESENT	0
494908	493327	19649G	PARTICIPANT	\N	PRESENT	0
494909	493327	19663E	PARTICIPANT	\N	PRESENT	0
494910	493327	04085P	PARTICIPANT	\N	PRESENT	0
494911	493327	19553Y	PARTICIPANT	\N	PRESENT	0
494912	493327	19503N	PARTICIPANT	\N	PRESENT	0
495039	493364	08073C	PARTICIPANT	\N	PRESENT	0
496110	495579	19387D	PARTICIPANT	\N	PRESENT	0
495041	493364	20092G	PARTICIPANT	\N	PRESENT	0
495042	493364	19507S	PARTICIPANT	\N	PRESENT	0
495043	493364	19709B	PARTICIPANT	\N	PRESENT	0
495044	493364	14205J	PARTICIPANT	\N	PRESENT	0
495045	493364	04070G	PARTICIPANT	\N	PRESENT	0
495046	493364	19782L	PARTICIPANT	\N	PRESENT	0
495047	493364	19441R	PARTICIPANT	\N	PRESENT	0
495048	493364	20032T	PARTICIPANT	\N	PRESENT	0
495049	493364	19611R	PARTICIPANT	\N	PRESENT	0
495050	493364	19333N	PARTICIPANT	\N	PRESENT	0
495051	493364	20060X	PARTICIPANT	\N	PRESENT	0
495052	493364	11012A	PARTICIPANT	\N	PRESENT	0
495053	493364	14030Q	PARTICIPANT	\N	PRESENT	0
495054	493364	19399H	PARTICIPANT	\N	PRESENT	0
495055	493364	07029T	PARTICIPANT	\N	PRESENT	0
495056	493364	19467C	PARTICIPANT	\N	PRESENT	0
495057	493364	14038Y	PARTICIPANT	\N	PRESENT	0
495058	493364	19447X	PARTICIPANT	\N	PRESENT	0
495059	493364	19515S	PARTICIPANT	\N	PRESENT	0
495060	493364	11090Q	PARTICIPANT	\N	PRESENT	0
495061	493364	19711U	PARTICIPANT	\N	PRESENT	0
495062	493364	19695N	PARTICIPANT	\N	PRESENT	0
495063	493364	20116W	PARTICIPANT	\N	PRESENT	0
495064	493364	20020P	PARTICIPANT	\N	PRESENT	0
495065	493364	11064N	PARTICIPANT	\N	PRESENT	0
495071	493364	19383Y	PARTICIPANT	\N	PRESENT	0
495084	493364	19687N	PARTICIPANT	\N	PRESENT	0
495090	493364	14147R	PARTICIPANT	\N	PRESENT	0
495091	493364	19503N	PARTICIPANT	\N	PRESENT	0
495092	493364	19758L	PARTICIPANT	\N	PRESENT	0
495094	493364	19479G	PARTICIPANT	\N	PRESENT	0
496107	495579	20068G	PARTICIPANT	\N	PRESENT	0
496108	495579	20076G	PARTICIPANT	\N	PRESENT	0
496109	495579	20022R	PARTICIPANT	\N	PRESENT	0
496111	495579	14169X	PARTICIPANT	\N	PRESENT	0
496112	495579	19599P	PARTICIPANT	\N	PRESENT	0
496113	495579	17229F	PARTICIPANT	\N	PRESENT	0
496114	495579	19826F	PARTICIPANT	\N	PRESENT	0
496115	495579	14237S	PARTICIPANT	\N	PRESENT	0
496130	495579	14031R	PARTICIPANT	\N	PRESENT	0
496117	495579	19503N	PARTICIPANT	\N	PRESENT	0
496118	495579	17367Q	PARTICIPANT	\N	PRESENT	0
496119	495579	20038A	PARTICIPANT	\N	PRESENT	0
496120	495579	19619A	PARTICIPANT	\N	PRESENT	0
496121	495579	19333N	PARTICIPANT	\N	PRESENT	0
496122	495579	20140W	PARTICIPANT	\N	PRESENT	0
496123	495579	14219Q	PARTICIPANT	\N	PRESENT	0
496124	495579	19820Y	PARTICIPANT	\N	PRESENT	0
496125	495579	20100N	PARTICIPANT	\N	PRESENT	0
496126	495579	20136B	PARTICIPANT	\N	PRESENT	0
496127	495579	19637C	PARTICIPANT	\N	PRESENT	0
496128	495579	19551W	PARTICIPANT	\N	PRESENT	0
496129	495579	17637T	PARTICIPANT	\N	PRESENT	0
496132	495579	18083K	PARTICIPANT	\N	PRESENT	0
496133	495038	14097Y	PARTICIPANT	\N	PRESENT	0
496134	495038	14331P	PARTICIPANT	\N	PRESENT	0
496135	495038	04071H	PARTICIPANT	\N	PRESENT	0
496136	495038	11048N	PARTICIPANT	\N	PRESENT	0
496137	495038	19711U	PARTICIPANT	\N	PRESENT	0
496138	495038	01048V	PARTICIPANT	\N	PRESENT	0
496139	495038	08034U	PARTICIPANT	\N	PRESENT	0
496140	495038	19531S	PARTICIPANT	\N	PRESENT	0
496141	495038	01057W	PARTICIPANT	\N	PRESENT	0
496142	495038	20080C	PARTICIPANT	\N	PRESENT	0
496143	495038	11074Q	PARTICIPANT	\N	PRESENT	0
496144	495038	20044X	PARTICIPANT	\N	PRESENT	0
496145	495038	19671E	PARTICIPANT	\N	PRESENT	0
496146	495038	14173T	PARTICIPANT	\N	PRESENT	0
496147	495038	96004D	PARTICIPANT	\N	PRESENT	0
496148	495038	19349W	PARTICIPANT	\N	PRESENT	0
496149	495038	14121F	PARTICIPANT	\N	PRESENT	0
496150	495038	08010L	PARTICIPANT	\N	PRESENT	0
496151	495038	99004R	PARTICIPANT	\N	PRESENT	0
496152	495038	14253S	PARTICIPANT	\N	PRESENT	0
496153	495038	20126Y	PARTICIPANT	\N	PRESENT	0
496154	495038	19762G	PARTICIPANT	\N	PRESENT	0
496155	495579	19549D	PARTICIPANT	\N	PRESENT	0
496156	495579	19739H	PARTICIPANT	\N	PRESENT	0
496157	495579	19745F	PARTICIPANT	\N	PRESENT	0
496158	495579	20106U	PARTICIPANT	\N	PRESENT	0
496336	493410	04070G	PARTICIPANT	\N	PRESENT	0
496337	493410	19699S	PARTICIPANT	\N	PRESENT	0
496338	493410	19533U	PARTICIPANT	\N	PRESENT	0
496339	493410	19329S	PARTICIPANT	\N	PRESENT	0
496340	493410	04033B	PARTICIPANT	\N	PRESENT	0
496341	493410	14229S	PARTICIPANT	\N	PRESENT	0
496342	493410	20098N	PARTICIPANT	\N	PRESENT	0
496343	493410	19573D	PARTICIPANT	\N	PRESENT	0
496344	493410	08017T	PARTICIPANT	\N	PRESENT	0
496345	493410	08061X	PARTICIPANT	\N	PRESENT	0
496346	493410	08012N	PARTICIPANT	\N	PRESENT	0
496347	493410	20026V	PARTICIPANT	\N	PRESENT	0
496348	493410	19593H	PARTICIPANT	\N	PRESENT	0
496349	493410	19643A	PARTICIPANT	\N	PRESENT	0
496350	493410	20132W	PARTICIPANT	\N	PRESENT	0
496351	493410	20134Y	PARTICIPANT	\N	PRESENT	0
496352	493410	14073Q	PARTICIPANT	\N	PRESENT	0
496353	493410	19651A	PARTICIPANT	\N	PRESENT	0
496354	493410	19611R	PRESIDENT	0	PRESENT	0
496355	493410	20138D	PARTICIPANT	\N	PRESENT	0
496356	493410	20142Y	PARTICIPANT	\N	PRESENT	0
496357	493410	20048C	PARTICIPANT	\N	PRESENT	0
496358	493410	19693L	PARTICIPANT	\N	PRESENT	0
496359	493410	19399H	PARTICIPANT	\N	PRESENT	0
496360	493410	20052X	PARTICIPANT	\N	PRESENT	0
496361	493410	20152B	PARTICIPANT	\N	PRESENT	0
496362	493410	19719D	PARTICIPANT	\N	PRESENT	0
496363	493410	20058E	PARTICIPANT	\N	PRESENT	0
496364	493410	14030Q	PARTICIPANT	\N	PRESENT	0
496365	493410	20056C	PARTICIPANT	\N	PRESENT	0
496366	493410	04059M	PARTICIPANT	\N	PRESENT	0
496367	493410	14109K	PARTICIPANT	\N	PRESENT	0
496368	493410	14123H	PARTICIPANT	\N	PRESENT	0
496369	493410	11043H	PARTICIPANT	\N	PRESENT	0
496370	493410	19758L	PARTICIPANT	\N	PRESENT	0
496371	493410	19621T	PARTICIPANT	\N	PRESENT	0
496372	493410	20084G	PARTICIPANT	\N	PRESENT	0
496373	493410	19735D	PARTICIPANT	\N	EXCUSE	0
496374	493410	20120S	PARTICIPANT	\N	EXCUSE	0
496384	493410	92040Q	PARTICIPANT	\N	EXCUSE	0
496385	493410	20124W	PARTICIPANT	\N	PRESENT	0
496891	495107	19443T	PARTICIPANT	\N	PRESENT	0
496892	495107	20072C	PARTICIPANT	\N	PRESENT	0
496893	495107	01058X	PARTICIPANT	\N	PRESENT	0
496894	495107	08047A	PARTICIPANT	\N	PRESENT	0
509506	505939	19467C	PARTICIPANT	\N	PRESENT	0
509507	505939	14357A	PARTICIPANT	\N	PRESENT	0
509508	505939	19507S	PARTICIPANT	\N	PRESENT	0
509509	502325	14073Q	PARTICIPANT	\N	PRESENT	0
509510	505939	20100N	PARTICIPANT	\N	PRESENT	0
509512	505939	19521Q	PARTICIPANT	\N	PRESENT	0
509513	505939	11083R	PARTICIPANT	\N	PRESENT	0
509514	505939	14026U	PARTICIPANT	\N	PRESENT	0
509515	505939	20128B	PARTICIPANT	\N	PRESENT	0
509516	505939	20034V	PARTICIPANT	\N	PRESENT	0
509517	505939	19531S	PARTICIPANT	\N	PRESENT	0
509518	505939	14097Y	PARTICIPANT	\N	PRESENT	0
509519	505939	14073Q	PARTICIPANT	\N	PRESENT	0
509520	505939	11099A	PARTICIPANT	\N	PRESENT	0
509522	505939	19441R	PARTICIPANT	\N	PRESENT	0
509525	505939	19563B	PARTICIPANT	\N	PRESENT	0
509527	505939	20028X	PARTICIPANT	\N	PRESENT	0
509529	505939	20018V	PARTICIPANT	\N	PRESENT	0
509530	505939	14257W	PARTICIPANT	\N	PRESENT	0
509532	505939	14169X	PARTICIPANT	\N	PRESENT	0
509533	505939	14237S	PARTICIPANT	\N	PRESENT	0
509534	505939	11090Q	PARTICIPANT	\N	PRESENT	0
509535	505939	20082E	PARTICIPANT	\N	PRESENT	0
509536	505939	20092G	PARTICIPANT	\N	PRESENT	0
509537	505939	20062A	PARTICIPANT	\N	PRESENT	0
509538	505939	19413M	PARTICIPANT	\N	PRESENT	0
509539	502325	19643A	PARTICIPANT	\N	PRESENT	0
509540	502325	14179A	PARTICIPANT	\N	PRESENT	0
509541	502325	19533U	PARTICIPANT	\N	PRESENT	0
509542	502325	19667J	PARTICIPANT	\N	PRESENT	0
509546	502325	19413M	PARTICIPANT	\N	PRESENT	0
509547	502325	12016W	PARTICIPANT	\N	PRESENT	0
509548	502325	11031D	PARTICIPANT	\N	PRESENT	0
509549	502325	19399H	PARTICIPANT	\N	PRESENT	0
509562	509561	14221J	PARTICIPANT	\N	PRESENT	0
509552	509551	14221J	PARTICIPANT	\N	PRESENT	0
509554	509553	14221J	PARTICIPANT	\N	PRESENT	0
509566	502325	19593H	PARTICIPANT	\N	PRESENT	0
509596	502325	14089Y	PARTICIPANT	\N	PRESENT	0
509597	502325	20140W	PARTICIPANT	\N	PRESENT	0
509598	502325	01048V	PARTICIPANT	\N	PRESENT	0
509599	502325	04086Q	PARTICIPANT	\N	PRESENT	0
509674	509671	14089Y	PARTICIPANT	\N	PRESENT	0
509675	509671	04047H	PARTICIPANT	\N	PRESENT	0
509676	509671	11056N	PARTICIPANT	\N	PRESENT	1
509677	509671	19489J	PARTICIPANT	\N	PRESENT	1
509678	509671	95063L	PARTICIPANT	\N	PRESENT	1
509679	509671	14107H	PARTICIPANT	\N	PRESENT	1
509680	502326	11045K	PARTICIPANT	\N	PRESENT	0
509681	502326	14225N	PARTICIPANT	\N	PRESENT	0
509682	502326	11048N	PARTICIPANT	\N	PRESENT	0
509683	502326	14257W	PARTICIPANT	\N	PRESENT	0
509684	502326	20030R	PARTICIPANT	\N	PRESENT	0
509685	502326	11077T	PARTICIPANT	\N	PRESENT	0
509686	502326	11040E	PARTICIPANT	\N	PRESENT	0
509687	502326	20046A	PARTICIPANT	\N	PRESENT	0
509688	502326	11031D	PARTICIPANT	\N	PRESENT	0
509689	502326	19593H	PARTICIPANT	\N	PRESENT	0
509690	502326	19565D	PARTICIPANT	\N	PRESENT	0
509691	502326	20102Q	PARTICIPANT	\N	PRESENT	0
509692	502326	20070A	PARTICIPANT	\N	PRESENT	0
509693	502326	14097Y	PARTICIPANT	\N	PRESENT	0
509694	502326	19503N	PARTICIPANT	\N	PRESENT	0
509695	502326	19531S	PARTICIPANT	\N	PRESENT	0
509696	502326	12016W	PARTICIPANT	\N	PRESENT	0
509697	502326	20080C	PARTICIPANT	\N	PRESENT	0
509698	502326	19647E	PARTICIPANT	\N	PRESENT	0
509699	502326	19631V	PARTICIPANT	\N	PRESENT	0
509700	502326	19689Q	PARTICIPANT	\N	PRESENT	0
509701	502326	20134Y	PARTICIPANT	\N	PRESENT	0
509702	502326	20110Q	PARTICIPANT	\N	PRESENT	0
509703	502326	20092G	PARTICIPANT	\N	PRESENT	0
509704	502326	20142Y	PARTICIPANT	\N	PRESENT	0
509705	502326	19347U	PARTICIPANT	\N	PRESENT	0
509706	502326	20100N	PARTICIPANT	\N	PRESENT	0
509707	502326	14169X	PARTICIPANT	\N	PRESENT	0
509708	502326	19387D	PARTICIPANT	\N	PRESENT	0
509709	502326	19563B	PARTICIPANT	\N	PRESENT	0
509710	502326	20116W	PARTICIPANT	\N	PRESENT	0
509711	502326	19369B	PARTICIPANT	\N	PRESENT	0
509712	502326	19515S	PARTICIPANT	\N	PRESENT	0
509713	502326	20052X	PARTICIPANT	\N	PRESENT	0
509714	502326	14219Q	PARTICIPANT	\N	PRESENT	0
509715	502326	19671E	PARTICIPANT	\N	PRESENT	0
509716	502326	20124W	PARTICIPANT	\N	PRESENT	0
509717	502326	14030Q	PARTICIPANT	\N	PRESENT	0
509718	502326	14331P	PARTICIPANT	\N	PRESENT	0
509719	502326	19762G	PARTICIPANT	\N	PRESENT	0
509720	502326	20038A	PARTICIPANT	\N	PRESENT	0
509721	502326	14053L	PARTICIPANT	\N	PRESENT	0
509722	502326	19667J	PARTICIPANT	\N	PRESENT	0
509723	502326	19711U	PARTICIPANT	\N	PRESENT	0
509724	502326	14329V	PARTICIPANT	\N	PRESENT	0
509725	502326	20136B	PARTICIPANT	\N	PRESENT	0
509726	502326	08034U	PARTICIPANT	\N	PRESENT	0
509727	502326	05012A	PARTICIPANT	\N	PRESENT	0
509728	502326	11099A	PARTICIPANT	\N	PRESENT	0
509729	502326	20032T	PARTICIPANT	\N	PRESENT	0
509730	502326	11090Q	PARTICIPANT	\N	PRESENT	0
509731	502326	07029T	PARTICIPANT	\N	PRESENT	0
509735	502326	20026V	PARTICIPANT	\N	PRESENT	0
509733	502326	20044X	PARTICIPANT	\N	PRESENT	0
509737	502326	19651A	PARTICIPANT	\N	PRESENT	0
509736	502326	14275Y	PARTICIPANT	\N	PRESENT	0
509738	502326	20034V	PARTICIPANT	\N	PRESENT	0
509739	502326	20140W	PARTICIPANT	\N	PRESENT	0
509740	502326	19549D	PARTICIPANT	\N	PRESENT	0
509741	502326	14083S	PARTICIPANT	\N	PRESENT	0
509742	502326	14253S	PARTICIPANT	\N	PRESENT	0
509743	502326	19621T	PARTICIPANT	\N	PRESENT	0
509744	502326	19643A	PARTICIPANT	\N	PRESENT	0
509745	502326	19479G	PARTICIPANT	\N	PRESENT	0
509746	502326	19551W	PARTICIPANT	\N	PRESENT	0
509672	509671	05008E	PARTICIPANT	\N	PRESENT	0
509673	509671	20110Q	PARTICIPANT	\N	PRESENT	0
509747	502326	19413M	PARTICIPANT	\N	PRESENT	0
509748	502326	20106U	PARTICIPANT	\N	PRESENT	0
509749	502326	14215L	PARTICIPANT	\N	PRESENT	0
509750	502326	19553Y	PARTICIPANT	\N	PRESENT	0
509751	502326	18083K	PARTICIPANT	\N	PRESENT	0
509752	502326	11065P	PARTICIPANT	\N	PRESENT	0
509753	502326	11074Q	PARTICIPANT	\N	PRESENT	0
509767	502327	11070L	PARTICIPANT	\N	PRESENT	0
509777	506631	14331P	PARTICIPANT	\N	PRESENT	0
509778	506631	11048N	PARTICIPANT	\N	PRESENT	0
509779	506631	19711U	PARTICIPANT	\N	PRESENT	0
509780	506631	01048V	PARTICIPANT	\N	PRESENT	0
509781	506631	19531S	PARTICIPANT	\N	PRESENT	0
509782	506631	19687N	PARTICIPANT	\N	PRESENT	0
509783	506631	12016W	PARTICIPANT	\N	PRESENT	0
509784	506631	20080C	PARTICIPANT	\N	PRESENT	0
509785	506631	11053K	PARTICIPANT	\N	PRESENT	0
509787	506631	14225N	PRESIDENT	0	PRESENT	0
509788	506631	11110B	PARTICIPANT	\N	PRESENT	0
509789	506631	14083S	PARTICIPANT	\N	PRESENT	0
509790	506631	20070A	PARTICIPANT	\N	PRESENT	0
509791	506631	96004D	PARTICIPANT	\N	PRESENT	0
509792	506631	14253S	PARTICIPANT	\N	PRESENT	0
509793	506631	20116W	PARTICIPANT	\N	PRESENT	0
509794	506631	19335Q	PARTICIPANT	\N	PRESENT	0
509796	502327	20044X	PARTICIPANT	\N	PRESENT	0
509797	502327	08009T	PARTICIPANT	\N	PRESENT	0
509798	502327	20032T	PARTICIPANT	\N	PRESENT	0
509799	502327	19637C	PARTICIPANT	\N	PRESENT	0
509800	502327	20046A	PARTICIPANT	\N	PRESENT	0
509801	502327	19515S	PARTICIPANT	\N	PRESENT	0
509802	502327	14097Y	PARTICIPANT	\N	PRESENT	0
509803	502327	19503N	PARTICIPANT	\N	PRESENT	0
509804	502327	14169X	PARTICIPANT	\N	PRESENT	0
509805	502327	19683J	PARTICIPANT	\N	PRESENT	0
509806	502327	20026V	PARTICIPANT	\N	PRESENT	0
509808	502327	20102Q	PARTICIPANT	\N	PRESENT	0
509809	502327	19687N	PARTICIPANT	\N	PRESENT	0
509810	502327	19713W	PARTICIPANT	\N	PRESENT	0
509811	502327	18083K	PARTICIPANT	\N	PRESENT	0
509814	502327	19745F	PARTICIPANT	\N	PRESENT	0
491093	490455	20032T	PARTICIPANT	\N	PRESENT	0
491094	490455	20076G	PARTICIPANT	\N	PRESENT	0
491095	490455	20024T	PARTICIPANT	\N	PRESENT	0
491096	490455	20022R	PARTICIPANT	\N	PRESENT	0
491097	490455	11065P	PARTICIPANT	\N	PRESENT	0
491098	490455	18083K	PARTICIPANT	\N	PRESENT	0
491099	490455	08060W	PARTICIPANT	\N	PRESENT	0
491100	490455	19549D	PARTICIPANT	\N	PRESENT	0
491101	490455	11101A	PARTICIPANT	\N	PRESENT	0
491102	490455	20140W	PARTICIPANT	\N	PRESENT	0
491103	490455	17229F	PARTICIPANT	\N	PRESENT	0
491104	490455	19251M	PARTICIPANT	\N	PRESENT	0
491105	490455	19525U	PARTICIPANT	\N	PRESENT	0
491106	490455	19577H	PARTICIPANT	\N	PRESENT	0
491595	491485	20074E	PARTICIPANT	\N	EXCUSE	0
491596	491485	19581D	PARTICIPANT	\N	EXCUSE	0
491109	490455	19701S	PARTICIPANT	\N	PRESENT	0
491110	490455	14031R	PARTICIPANT	\N	PRESENT	0
491111	490455	19826F	PARTICIPANT	\N	PRESENT	0
491112	490455	14219Q	PRESIDENT	1	PRESENT	0
491113	490455	19551W	PARTICIPANT	\N	PRESENT	0
491114	490455	19637C	PARTICIPANT	\N	PRESENT	0
491115	490455	19333N	PARTICIPANT	\N	PRESENT	0
491116	490455	20068G	PARTICIPANT	\N	PRESENT	0
491117	490455	20102Q	PARTICIPANT	\N	PRESENT	0
491118	490455	19387D	PARTICIPANT	\N	PRESENT	0
491119	490455	19820Y	PARTICIPANT	\N	PRESENT	0
491120	490455	19619A	PARTICIPANT	\N	PRESENT	0
491121	490455	20020P	PARTICIPANT	\N	PRESENT	0
491122	490455	20122U	PARTICIPANT	\N	PRESENT	0
494850	494845	19415P	PARTICIPANT	\N	PRESENT	0
491124	490455	19745F	PARTICIPANT	\N	PRESENT	0
491125	490455	05012A	PARTICIPANT	\N	PRESENT	0
491126	490455	14237S	PARTICIPANT	\N	PRESENT	0
491127	490455	20096L	PARTICIPANT	\N	PRESENT	0
494851	494845	11067R	PARTICIPANT	\N	PRESENT	0
491129	490455	20106U	PARTICIPANT	\N	PRESENT	0
491130	490455	20100N	PARTICIPANT	\N	PRESENT	0
491131	490455	20118Y	PARTICIPANT	\N	PRESENT	0
491132	490455	19599P	PARTICIPANT	\N	PRESENT	0
491133	490455	20038A	PARTICIPANT	\N	PRESENT	0
491134	490455	14221J	PARTICIPANT	\N	PRESENT	0
491135	490455	14169X	PARTICIPANT	\N	PRESENT	0
491136	490455	19681G	PARTICIPANT	\N	PRESENT	0
491137	490455	19739H	PRESIDENT	0	PRESENT	0
494852	493390	14133K	PARTICIPANT	\N	PRESENT	0
491139	490455	19503N	PARTICIPANT	\N	PRESENT	0
491140	490455	20046A	PARTICIPANT	\N	PRESENT	0
494853	493390	14189C	PARTICIPANT	\N	PRESENT	0
494854	493390	20112S	PARTICIPANT	\N	PRESENT	0
494855	493390	14207L	PARTICIPANT	\N	PRESENT	0
494856	493390	19701S	PARTICIPANT	\N	PRESENT	0
494857	493390	14357A	PARTICIPANT	\N	PRESENT	0
494858	493390	11101A	PARTICIPANT	\N	PRESENT	0
494859	493390	20100N	PARTICIPANT	\N	PRESENT	0
494860	493390	19521Q	PARTICIPANT	\N	PRESENT	0
494861	493390	04035D	PARTICIPANT	\N	PRESENT	0
494862	493390	11083R	PARTICIPANT	\N	PRESENT	0
494863	493390	14033T	PARTICIPANT	\N	PRESENT	0
494864	493390	14026U	PARTICIPANT	\N	PRESENT	0
494865	493390	19553Y	PARTICIPANT	\N	PRESENT	0
494866	493390	19725B	PARTICIPANT	\N	PRESENT	0
494867	493390	19531S	PARTICIPANT	\N	PRESENT	0
494868	493390	14097Y	PARTICIPANT	\N	PRESENT	0
494869	493390	14073Q	PARTICIPANT	\N	PRESENT	0
494870	493390	12041X	PARTICIPANT	\N	PRESENT	0
494871	493390	08034U	PARTICIPANT	\N	PRESENT	0
494872	493390	12016W	PARTICIPANT	\N	PRESENT	0
494873	493390	14221J	PARTICIPANT	\N	PRESENT	0
494874	493390	04057K	PARTICIPANT	\N	PRESENT	0
494875	493390	04070G	PARTICIPANT	\N	PRESENT	0
494876	493390	14169X	PARTICIPANT	\N	PRESENT	0
494877	493390	14331P	PRESIDENT	0	PRESENT	0
494878	493390	04034C	PARTICIPANT	\N	PRESENT	0
494981	493949	14231L	PARTICIPANT	\N	PRESENT	0
494982	493949	14053L	PARTICIPANT	\N	PRESENT	0
494983	493949	14069U	PARTICIPANT	\N	PRESENT	0
494984	493949	19333N	PARTICIPANT	\N	PRESENT	0
494985	493949	01057W	PARTICIPANT	\N	PRESENT	0
494986	493949	19565D	PARTICIPANT	\N	PRESENT	0
494987	493949	14281W	PARTICIPANT	\N	PRESENT	0
494988	493949	14215L	PARTICIPANT	\N	PRESENT	0
494989	493949	14327T	PARTICIPANT	\N	PRESENT	0
494990	493949	04086Q	PARTICIPANT	\N	PRESENT	0
494991	493949	19681G	PARTICIPANT	\N	PRESENT	0
494992	493949	20022R	PARTICIPANT	\N	PRESENT	0
494993	493949	20110Q	PARTICIPANT	\N	PRESENT	0
494996	493949	14257W	PARTICIPANT	\N	PRESENT	0
494997	493949	14071N	PARTICIPANT	\N	PRESENT	0
494998	493949	17637T	PARTICIPANT	\N	PRESENT	0
494999	493949	05012A	PARTICIPANT	\N	PRESENT	0
495000	493949	20122U	PARTICIPANT	\N	PRESENT	0
495001	493949	20058E	PARTICIPANT	\N	PRESENT	0
495002	493949	08010L	PARTICIPANT	\N	PRESENT	0
495003	493949	19758L	PARTICIPANT	\N	PRESENT	0
495004	493949	19826F	PARTICIPANT	\N	PRESENT	0
500560	500555	18083K	PARTICIPANT	\N	PRESENT	0
500561	500556	18083K	PARTICIPANT	\N	PRESENT	0
500569	500557	18083K	PARTICIPANT	\N	PRESENT	0
500570	500557	19739H	PARTICIPANT	\N	PRESENT	0
500575	500553	18083K	PARTICIPANT	\N	PRESENT	0
511543	509855	20106U	PARTICIPANT	\N	PRESENT	1
511544	509965	11040E	PARTICIPANT	\N	PRESENT	0
511545	509965	11048N	PARTICIPANT	\N	PRESENT	0
511546	509965	20070A	PARTICIPANT	\N	PRESENT	0
511547	509965	19349W	PARTICIPANT	\N	PRESENT	0
511548	509965	20022R	PARTICIPANT	\N	PRESENT	0
511549	509965	19671E	PARTICIPANT	\N	PRESENT	0
511550	509965	14083S	PARTICIPANT	\N	PRESENT	0
511551	509965	19531S	PARTICIPANT	\N	PRESENT	0
511552	509965	08009T	PARTICIPANT	\N	PRESENT	0
511553	509965	14253S	PARTICIPANT	\N	PRESENT	0
511554	509965	19711U	PARTICIPANT	\N	PRESENT	0
511555	509965	01057W	PARTICIPANT	\N	PRESENT	0
511556	509965	11074Q	PARTICIPANT	\N	PRESENT	0
511557	509965	08011M	PARTICIPANT	\N	PRESENT	0
511558	509965	19335Q	PARTICIPANT	\N	PRESENT	0
511559	509892	04070G	PARTICIPANT	\N	PRESENT	1
511560	509892	19699S	PARTICIPANT	\N	PRESENT	0
511561	509892	19533U	PARTICIPANT	\N	PRESENT	0
511562	509892	14229S	PARTICIPANT	\N	PRESENT	0
511563	509892	20098N	PARTICIPANT	\N	PRESENT	0
511564	509892	20112S	PARTICIPANT	\N	PRESENT	0
511565	509892	08012N	PARTICIPANT	\N	PRESENT	0
511566	509892	20124W	PARTICIPANT	\N	PRESENT	0
511541	509855	08060W	PARTICIPANT	\N	PRESENT	1
511542	509855	19701S	PARTICIPANT	\N	PRESENT	0
511567	509892	20026V	PARTICIPANT	\N	PRESENT	0
511568	509892	19527W	PARTICIPANT	\N	PRESENT	0
511569	509892	19593H	PARTICIPANT	\N	PRESENT	0
511570	509892	20132W	PARTICIPANT	\N	PRESENT	0
511571	509892	20134Y	PARTICIPANT	\N	PRESENT	1
511572	509892	14073Q	PARTICIPANT	\N	PRESENT	0
511573	509892	19651A	PARTICIPANT	\N	PRESENT	1
511574	509892	19611R	PRESIDENT	0	PRESENT	0
511575	509892	20142Y	PARTICIPANT	\N	PRESENT	0
511576	509892	20152B	PARTICIPANT	\N	PRESENT	1
511577	509892	20058E	PARTICIPANT	\N	PRESENT	0
511578	509892	14030Q	PARTICIPANT	\N	PRESENT	0
511579	509892	20056C	PARTICIPANT	\N	PRESENT	0
511580	509892	19735D	PARTICIPANT	\N	PRESENT	1
511581	509892	14109K	PARTICIPANT	\N	PRESENT	0
511582	509892	14123H	PARTICIPANT	\N	PRESENT	0
511583	509892	11104D	PARTICIPANT	\N	PRESENT	1
511584	509892	19758L	PARTICIPANT	\N	PRESENT	0
511585	509892	19621T	PARTICIPANT	\N	PRESENT	0
511589	509565	14111D	PARTICIPANT	\N	PRESENT	0
511590	509565	11026G	PARTICIPANT	\N	PRESENT	0
511591	509565	19543W	PARTICIPANT	\N	PRESENT	0
511592	509565	19585H	PARTICIPANT	\N	PRESENT	0
511593	509565	04047H	PARTICIPANT	\N	PRESENT	0
511594	509565	01028R	PARTICIPANT	\N	PRESENT	0
511595	509565	19675J	PARTICIPANT	\N	PRESENT	0
511596	509565	19447X	PARTICIPANT	\N	PRESENT	0
511597	509565	11056N	PARTICIPANT	\N	PRESENT	0
511598	509565	19954N	PARTICIPANT	\N	PRESENT	0
511599	509565	19489J	PARTICIPANT	\N	PRESENT	0
511600	509565	19729F	PARTICIPANT	\N	PRESENT	0
511601	509565	19629C	PARTICIPANT	\N	PRESENT	0
511602	509565	07004J	PARTICIPANT	\N	PRESENT	0
511603	509565	20108W	PARTICIPANT	\N	PRESENT	0
497896	496190	19611R	PARTICIPANT	\N	PRESENT	0
497897	496190	19693L	PARTICIPANT	\N	PRESENT	0
497898	496190	14257W	PARTICIPANT	\N	PRESENT	0
497899	496190	12016W	PARTICIPANT	\N	PRESENT	0
497900	496190	20134Y	PARTICIPANT	\N	PRESENT	0
497901	496190	19629C	PARTICIPANT	\N	PRESENT	0
497902	496190	20050V	PARTICIPANT	\N	PRESENT	0
497903	496190	19369B	PARTICIPANT	\N	PRESENT	0
497904	496190	19691J	PARTICIPANT	\N	PRESENT	0
497905	496190	19758L	PARTICIPANT	\N	PRESENT	0
497906	496190	19533U	PARTICIPANT	\N	PRESENT	0
497907	496190	04043D	PARTICIPANT	\N	PRESENT	0
497908	496190	20142Y	PARTICIPANT	\N	PRESENT	0
497909	496190	19663E	PARTICIPANT	\N	PRESENT	0
497910	496190	20152B	PARTICIPANT	\N	PRESENT	0
497911	496190	11090Q	PARTICIPANT	\N	PRESENT	0
497912	496190	19651A	PARTICIPANT	\N	PRESENT	0
497913	496190	20048C	PARTICIPANT	\N	PRESENT	0
497894	496190	12041X	PARTICIPANT	\N	PRESENT	0
497895	496190	14229S	PARTICIPANT	\N	PRESENT	0
497914	496190	14123H	PARTICIPANT	\N	PRESENT	0
497915	496190	04035D	PARTICIPANT	\N	PRESENT	0
497916	496190	19621T	PARTICIPANT	\N	PRESENT	0
497917	496190	19593H	PARTICIPANT	\N	PRESENT	0
497918	496190	14109K	PARTICIPANT	\N	PRESENT	0
497919	496190	19447X	PARTICIPANT	\N	PRESENT	0
497920	496190	07029T	PARTICIPANT	\N	PRESENT	0
497921	496190	14215L	PARTICIPANT	\N	PRESENT	0
497952	495130	19758L	PARTICIPANT	\N	PRESENT	0
497953	495130	11090Q	PARTICIPANT	\N	PRESENT	0
497954	495130	20142Y	PARTICIPANT	\N	PRESENT	0
497955	495130	20050V	PARTICIPANT	\N	PRESENT	0
497956	495130	14229S	PARTICIPANT	\N	PRESENT	0
497957	495130	19629C	PARTICIPANT	\N	PRESENT	0
497958	495130	08017T	PARTICIPANT	\N	PRESENT	0
497959	495130	14041T	PARTICIPANT	\N	PRESENT	0
497960	495130	19663E	PARTICIPANT	\N	PRESENT	0
497961	495130	19447X	PARTICIPANT	\N	PRESENT	0
497962	495130	14123H	PARTICIPANT	\N	PRESENT	0
497963	495130	19533U	PARTICIPANT	\N	PRESENT	0
497964	495130	19621T	PARTICIPANT	\N	PRESENT	0
497965	495130	20152B	PARTICIPANT	\N	PRESENT	0
497966	495130	19369B	PARTICIPANT	\N	PRESENT	0
497967	495130	19651A	PARTICIPANT	\N	PRESENT	0
497968	495130	20048C	PARTICIPANT	\N	PRESENT	0
497969	495130	14109K	PARTICIPANT	\N	PRESENT	0
497970	495130	12016W	PARTICIPANT	\N	PRESENT	0
497971	495130	20134Y	PARTICIPANT	\N	PRESENT	0
497972	495130	19693L	PARTICIPANT	\N	PRESENT	0
497973	495130	19611R	PARTICIPANT	\N	PRESENT	0
497974	495130	19667J	PARTICIPANT	\N	PRESENT	0
497975	495130	20138D	PARTICIPANT	\N	PRESENT	0
497976	495130	04043D	PARTICIPANT	\N	PRESENT	0
497977	495130	14215L	PARTICIPANT	\N	PRESENT	0
497978	495130	19643A	PARTICIPANT	\N	PRESENT	0
497989	495130	17637T	PARTICIPANT	\N	PRESENT	0
497950	495130	99004R	PARTICIPANT	\N	PRESENT	0
497951	495130	19593H	PARTICIPANT	\N	PRESENT	0
497990	495130	14251Q	PARTICIPANT	\N	PRESENT	0
498207	497087	04092N	PARTICIPANT	\N	PRESENT	0
498208	497087	19715Y	PARTICIPANT	\N	PRESENT	0
498209	497087	19657G	PARTICIPANT	\N	PRESENT	0
498210	497087	19295A	PARTICIPANT	\N	PRESENT	0
498212	498211	19703U	PARTICIPANT	\N	PRESENT	0
498213	498211	19657G	PARTICIPANT	\N	PRESENT	0
498215	498214	19703U	PARTICIPANT	\N	PRESENT	0
498219	498218	05008E	PARTICIPANT	\N	PRESENT	0
498220	498218	11053K	PARTICIPANT	\N	PRESENT	0
498221	498218	01028R	PARTICIPANT	\N	PRESENT	0
498679	498503	20076G	PARTICIPANT	\N	PRESENT	0
498680	498503	20024T	PARTICIPANT	\N	PRESENT	0
498681	498503	20022R	PARTICIPANT	\N	PRESENT	0
498682	498503	19549D	PARTICIPANT	\N	PRESENT	0
498683	498503	11101A	PARTICIPANT	\N	PRESENT	0
498684	498503	18083K	PARTICIPANT	\N	PRESENT	0
498685	498503	19681G	PARTICIPANT	\N	EXCUSE	0
498686	498503	19701S	PARTICIPANT	\N	PRESENT	0
498687	498503	20140W	PARTICIPANT	\N	PRESENT	0
498688	498503	17229F	PARTICIPANT	\N	PRESENT	0
498689	498503	19251M	PARTICIPANT	\N	PRESENT	0
498690	498503	19577H	PARTICIPANT	\N	PRESENT	0
498691	498503	20038A	PARTICIPANT	\N	PRESENT	0
498692	498503	20100N	PARTICIPANT	\N	PRESENT	0
498693	498503	19599P	PARTICIPANT	\N	PRESENT	0
498694	498503	19820Y	PARTICIPANT	\N	PRESENT	0
498695	498503	19387D	PARTICIPANT	\N	PRESENT	0
498696	498503	19333N	PARTICIPANT	\N	PRESENT	0
498697	498503	19551W	PARTICIPANT	\N	EXCUSE	0
498698	498503	14219Q	PARTICIPANT	\N	PRESENT	0
498699	498503	14031R	PARTICIPANT	\N	PRESENT	0
498700	498503	19637C	PARTICIPANT	\N	PRESENT	0
498701	498503	19826F	PARTICIPANT	\N	PRESENT	0
498702	498503	20096L	PARTICIPANT	\N	PRESENT	0
498703	498503	19745F	PARTICIPANT	\N	PRESENT	0
498704	498503	20118Y	PARTICIPANT	\N	PRESENT	0
498705	498503	19739H	PARTICIPANT	\N	PRESENT	0
498706	498503	20136B	PARTICIPANT	\N	PRESENT	0
498707	498503	20046A	PARTICIPANT	\N	EXCUSE	0
500171	500170	14255U	PARTICIPANT	\N	PRESENT	0
500172	500170	20064C	PARTICIPANT	\N	PRESENT	0
500183	500173	18193Q	PARTICIPANT	\N	PRESENT	0
500184	500173	14223L	PARTICIPANT	\N	PRESENT	0
500185	500173	19703U	PARTICIPANT	\N	PRESENT	0
500191	500190	01058X	PARTICIPANT	\N	PRESENT	0
500192	500190	19347U	PARTICIPANT	\N	PRESENT	0
500238	498010	14257W	PARTICIPANT	\N	PRESENT	0
500295	498634	19515S	PRESIDENT	0	PRESENT	0
500296	498634	19760E	PARTICIPANT	\N	PRESENT	0
500297	498634	19575F	PARTICIPANT	\N	PRESENT	0
500298	498634	20094J	PARTICIPANT	\N	PRESENT	0
500299	498634	08060W	PARTICIPANT	\N	PRESENT	0
500300	498634	20060X	PARTICIPANT	\N	PRESENT	0
500301	498634	14329V	PARTICIPANT	\N	PRESENT	0
500302	498634	19467C	PARTICIPANT	\N	PRESENT	0
500303	498634	14357A	PARTICIPANT	\N	PRESENT	0
500304	498634	14041T	PARTICIPANT	\N	PRESENT	0
500305	498634	19251M	PARTICIPANT	\N	PRESENT	0
500306	498634	20134Y	PARTICIPANT	\N	PRESENT	0
500307	498634	19695N	PARTICIPANT	\N	PRESENT	0
500308	498634	20048C	PARTICIPANT	\N	PRESENT	0
500309	498634	20126Y	PARTICIPANT	\N	PRESENT	0
500310	498634	08015R	PARTICIPANT	\N	PRESENT	0
500311	498634	16685X	PARTICIPANT	\N	PRESENT	0
500312	498634	14031R	PARTICIPANT	\N	PRESENT	0
500313	498634	19369B	PARTICIPANT	\N	PRESENT	0
500314	498634	19866P	PARTICIPANT	\N	PRESENT	0
500315	498634	19679N	PARTICIPANT	\N	PRESENT	0
500316	498634	20082E	PARTICIPANT	\N	PRESENT	0
500317	498634	19762G	PARTICIPANT	\N	PRESENT	0
500331	498634	14026U	PARTICIPANT	\N	EXCUSE	0
500332	498634	08028W	PARTICIPANT	\N	EXCUSE	0
500333	498634	14030Q	PARTICIPANT	\N	EXCUSE	0
500474	500457	11026G	PARTICIPANT	\N	PRESENT	0
500475	500462	11026G	PARTICIPANT	\N	PRESENT	0
500482	500481	19447X	PARTICIPANT	\N	PRESENT	0
500483	500481	14089Y	PARTICIPANT	\N	PRESENT	0
500484	500481	11026G	PARTICIPANT	\N	PRESENT	0
500486	500485	19447X	PARTICIPANT	\N	PRESENT	0
500487	500485	11026G	PARTICIPANT	\N	PRESENT	0
500488	500485	14089Y	PARTICIPANT	\N	PRESENT	0
500490	500489	19447X	PARTICIPANT	\N	PRESENT	0
500491	500489	11026G	PARTICIPANT	\N	PRESENT	0
500492	500489	11033F	PARTICIPANT	\N	PRESENT	0
500494	500493	19447X	PARTICIPANT	\N	PRESENT	0
500495	500493	11026G	PARTICIPANT	\N	PRESENT	0
500496	500493	11033F	PARTICIPANT	\N	PRESENT	0
500498	500497	19447X	PARTICIPANT	\N	PRESENT	0
500499	500497	11026G	PARTICIPANT	\N	PRESENT	0
500500	500497	11033F	PARTICIPANT	\N	PRESENT	0
500537	495438	04070G	PARTICIPANT	\N	EXCUSE	0
500562	495438	19669L	PARTICIPANT	\N	PRESENT	0
500668	500667	14033T	PARTICIPANT	\N	PRESENT	0
500670	500669	14033T	PARTICIPANT	\N	PRESENT	0
500672	500671	14033T	PARTICIPANT	\N	PRESENT	0
500674	500673	14033T	PARTICIPANT	\N	PRESENT	0
500676	500675	14033T	PARTICIPANT	\N	PRESENT	0
500678	500677	14033T	PARTICIPANT	\N	PRESENT	0
500687	500686	14033T	PARTICIPANT	\N	PRESENT	0
500691	500690	14033T	PARTICIPANT	\N	PRESENT	0
500696	500694	14033T	PARTICIPANT	\N	PRESENT	0
500701	500700	14329V	PARTICIPANT	\N	PRESENT	0
500712	500706	14329V	PARTICIPANT	\N	PRESENT	0
500715	500704	14329V	PARTICIPANT	\N	PRESENT	0
500724	500723	14033T	PARTICIPANT	\N	PRESENT	0
500732	500730	19551W	PARTICIPANT	\N	PRESENT	0
500797	500744	14257W	PARTICIPANT	\N	PRESENT	0
500799	500798	14257W	PARTICIPANT	\N	PRESENT	0
500802	500800	14257W	PARTICIPANT	\N	PRESENT	0
500804	500803	14257W	PARTICIPANT	\N	PRESENT	0
483371	483365	08012N	PARTICIPANT	\N	PRESENT	0
483372	483365	19349W	PARTICIPANT	\N	PRESENT	0
483373	483365	02002K	PARTICIPANT	\N	PRESENT	0
483374	483365	19251M	PARTICIPANT	\N	PRESENT	0
483375	483365	11043H	PARTICIPANT	\N	PRESENT	0
483376	483366	08012N	PRESIDENT	0	PRESENT	0
483377	483366	19251M	PARTICIPANT	\N	PRESENT	0
483378	483366	11043H	PARTICIPANT	\N	PRESENT	0
483379	483366	14147R	PARTICIPANT	\N	PRESENT	0
483380	483366	02002K	PARTICIPANT	\N	PRESENT	0
483381	483366	19399H	PARTICIPANT	\N	PRESENT	0
483382	483369	08012N	PARTICIPANT	\N	PRESENT	0
483383	483369	19251M	PARTICIPANT	\N	PRESENT	0
483384	483369	02002K	PARTICIPANT	\N	PRESENT	0
483385	483369	11043H	PARTICIPANT	\N	PRESENT	0
485167	484728	11070L	PARTICIPANT	\N	PRESENT	0
485168	484728	14121F	PRESIDENT	0	PRESENT	0
485169	484728	19711U	PARTICIPANT	\N	PRESENT	0
485170	484728	14069U	PARTICIPANT	\N	PRESENT	0
485171	484728	19741B	PARTICIPANT	\N	PRESENT	0
485172	484728	19525U	PARTICIPANT	\N	PRESENT	0
485173	484728	19737F	PARTICIPANT	\N	EXCUSE	0
485174	484728	19551W	PARTICIPANT	\N	EXCUSE	0
488567	488429	19766L	PARTICIPANT	\N	PRESENT	0
488568	488429	14331P	PARTICIPANT	\N	PRESENT	0
488569	488429	11067R	PARTICIPANT	\N	PRESENT	0
488570	488429	19479G	PARTICIPANT	\N	PRESENT	0
488571	488429	11048N	PARTICIPANT	\N	PRESENT	0
488572	488429	19545Y	PARTICIPANT	\N	PRESENT	0
488573	488429	11097X	PRESIDENT	0	PRESENT	0
488574	488429	14081Q	PARTICIPANT	\N	PRESENT	0
488575	488429	19663E	PARTICIPANT	\N	PRESENT	0
488576	488429	19667J	PARTICIPANT	\N	PRESENT	0
488577	488429	19715Y	PARTICIPANT	\N	PRESENT	0
488578	488429	19447X	PARTICIPANT	\N	PRESENT	0
488579	488429	19703U	PARTICIPANT	\N	PRESENT	0
488580	488429	11031D	PARTICIPANT	\N	PRESENT	0
488581	488429	19553Y	PARTICIPANT	\N	PRESENT	0
488582	488429	19573D	PARTICIPANT	\N	PRESENT	0
488583	488429	04059M	PARTICIPANT	\N	PRESENT	0
488584	488429	14041T	PARTICIPANT	\N	PRESENT	0
488585	488429	19503N	PARTICIPANT	\N	PRESENT	0
488586	488429	99004R	PARTICIPANT	\N	PRESENT	0
488587	488429	19683J	PARTICIPANT	\N	PRESENT	0
488588	488429	10006L	PARTICIPANT	\N	PRESENT	0
488589	488429	19643A	PARTICIPANT	\N	EXCUSE	0
488590	488429	01034P	PARTICIPANT	\N	EXCUSE	0
490055	489752	19679N	PARTICIPANT	\N	PRESENT	0
490058	490056	19415P	PARTICIPANT	\N	PRESENT	0
490059	490056	11067R	PARTICIPANT	\N	PRESENT	0
490060	490057	19415P	PARTICIPANT	\N	PRESENT	0
490061	490057	11067R	PARTICIPANT	\N	PRESENT	0
496954	495126	19621T	PARTICIPANT	\N	PRESENT	0
496955	495126	19693L	PARTICIPANT	\N	PRESENT	0
496952	495126	11070L	PARTICIPANT	\N	PRESENT	0
496953	495126	19611R	PARTICIPANT	\N	PRESENT	0
496956	495126	14169X	PARTICIPANT	\N	PRESENT	0
496957	495126	20114U	PARTICIPANT	\N	PRESENT	0
496958	495126	19667J	PARTICIPANT	\N	PRESENT	0
496959	495126	14109K	PARTICIPANT	\N	PRESENT	0
496960	495126	07029T	PARTICIPANT	\N	PRESENT	0
496961	495126	19503N	PARTICIPANT	\N	PRESENT	0
496962	495126	20134Y	PARTICIPANT	\N	PRESENT	0
496963	495126	19533U	PARTICIPANT	\N	PRESENT	0
496964	495126	20142Y	PARTICIPANT	\N	PRESENT	0
496965	495126	14331P	PARTICIPANT	\N	PRESENT	0
496966	495126	20084G	PARTICIPANT	\N	PRESENT	0
496967	495126	14069U	PARTICIPANT	\N	PRESENT	0
496968	495126	20082E	PARTICIPANT	\N	PRESENT	0
496969	495126	14215L	PARTICIPANT	\N	PRESENT	0
496970	495126	19593H	PARTICIPANT	\N	PRESENT	0
496971	495126	19758L	PARTICIPANT	\N	PRESENT	0
496972	495126	19691J	PARTICIPANT	\N	PRESENT	0
496973	495126	20026V	PARTICIPANT	\N	PRESENT	0
496974	495126	11099A	PARTICIPANT	\N	PRESENT	0
496975	495126	20126Y	PARTICIPANT	\N	PRESENT	0
496976	495126	20048C	PARTICIPANT	\N	PRESENT	0
496977	495126	19369B	PARTICIPANT	\N	PRESENT	0
496978	495126	19713W	PARTICIPANT	\N	PRESENT	0
496979	495126	14033T	PARTICIPANT	\N	PRESENT	0
496980	495126	19651A	PARTICIPANT	\N	PRESENT	0
496981	495126	14229S	PARTICIPANT	\N	PRESENT	0
496982	495126	20056C	PARTICIPANT	\N	PRESENT	0
496983	495126	17589D	PARTICIPANT	\N	PRESENT	0
496984	495126	19531S	PARTICIPANT	\N	PRESENT	0
496985	495126	14257W	PARTICIPANT	\N	PRESENT	0
496986	495126	19629C	PARTICIPANT	\N	PRESENT	0
496987	495126	20124W	PARTICIPANT	\N	PRESENT	0
496988	495126	20132W	PARTICIPANT	\N	PRESENT	0
496989	495126	19575F	PARTICIPANT	\N	PRESENT	0
496990	495126	14042U	PARTICIPANT	\N	PRESENT	0
496991	495126	20052X	PARTICIPANT	\N	PRESENT	0
496992	495126	11077T	PARTICIPANT	\N	PRESENT	0
496993	495126	17367Q	PARTICIPANT	\N	PRESENT	0
496994	495126	19565D	PARTICIPANT	\N	PRESENT	0
496995	495126	19489J	PARTICIPANT	\N	PRESENT	0
496996	495126	19349W	PARTICIPANT	\N	PRESENT	0
496997	495126	19741B	PARTICIPANT	\N	PRESENT	0
496998	495126	19447X	PARTICIPANT	\N	PRESENT	0
496999	495126	18083K	PARTICIPANT	\N	PRESENT	0
497000	495126	20058E	PARTICIPANT	\N	PRESENT	0
497001	495126	19399H	PARTICIPANT	\N	PRESENT	0
497002	495126	14147R	PARTICIPANT	\N	PRESENT	0
497003	495126	19347U	PARTICIPANT	\N	PRESENT	0
497004	495126	01028R	PARTICIPANT	\N	PRESENT	0
497005	495126	14213J	PARTICIPANT	\N	PRESENT	0
497006	495126	19701S	PARTICIPANT	\N	PRESENT	0
497012	495128	08073C	PARTICIPANT	\N	PRESENT	0
497014	495128	19593H	PARTICIPANT	\N	PRESENT	0
497015	495128	19693L	PARTICIPANT	\N	PRESENT	0
497049	495128	20124W	PARTICIPANT	\N	PRESENT	0
497017	495128	19715Y	PARTICIPANT	\N	PRESENT	0
497018	495128	14109K	PARTICIPANT	\N	PRESENT	0
497019	495128	14229S	PARTICIPANT	\N	PRESENT	0
497020	495128	20082E	PARTICIPANT	\N	PRESENT	0
497064	495128	20092G	PARTICIPANT	\N	PRESENT	0
497022	495128	17589D	PARTICIPANT	\N	PRESENT	0
497023	495128	19629C	PARTICIPANT	\N	PRESENT	0
497024	495128	19651A	PARTICIPANT	\N	PRESENT	0
497025	495128	20052X	PARTICIPANT	\N	PRESENT	0
497026	495128	20066E	PARTICIPANT	\N	PRESENT	0
497027	495128	19369B	PARTICIPANT	\N	PRESENT	0
497028	495128	14073Q	PARTICIPANT	\N	PRESENT	0
497029	495128	11099A	PARTICIPANT	\N	PRESENT	0
497030	495128	20026V	PARTICIPANT	\N	PRESENT	0
497031	495128	20056C	PARTICIPANT	\N	PRESENT	0
497032	495128	14147R	PARTICIPANT	\N	PRESENT	0
497033	495128	20090E	PARTICIPANT	\N	PRESENT	0
497034	495128	19866P	PARTICIPANT	\N	PRESENT	0
497035	495128	19621T	PARTICIPANT	\N	PRESENT	0
497036	495128	19954N	PARTICIPANT	\N	PRESENT	0
497037	495128	20152B	PARTICIPANT	\N	PRESENT	0
497038	495128	14038Y	PARTICIPANT	\N	PRESENT	0
497040	495128	04043D	PARTICIPANT	\N	PRESENT	0
497041	495128	19758L	PARTICIPANT	\N	PRESENT	0
497042	495128	20048C	PARTICIPANT	\N	PRESENT	0
497043	495128	20132W	PARTICIPANT	\N	PRESENT	0
497044	495128	14257W	PARTICIPANT	\N	PRESENT	0
497045	495128	19565D	PARTICIPANT	\N	PRESENT	0
497046	495128	19611R	PARTICIPANT	\N	PRESENT	0
497048	495128	19467C	PARTICIPANT	\N	PRESENT	0
497051	495128	20142Y	PARTICIPANT	\N	PRESENT	0
497063	495128	11077T	PARTICIPANT	\N	PRESENT	0
497065	495128	19399H	PARTICIPANT	\N	PRESENT	0
497066	495128	19533U	PARTICIPANT	\N	PRESENT	0
497067	495128	12016W	PARTICIPANT	\N	PRESENT	0
497068	495128	19489J	PARTICIPANT	\N	PRESENT	0
497069	495128	11090Q	PARTICIPANT	\N	PRESENT	0
497070	495128	08017T	PARTICIPANT	\N	PRESENT	0
497074	495128	19573D	PARTICIPANT	\N	PRESENT	0
497072	495128	20084G	PARTICIPANT	\N	PRESENT	0
497076	495128	19762G	PARTICIPANT	\N	PRESENT	0
497075	495128	11101A	PARTICIPANT	\N	PRESENT	0
497077	495128	07029T	PARTICIPANT	\N	PRESENT	0
497078	495128	14215L	PARTICIPANT	\N	PRESENT	0
497079	495128	20058E	PARTICIPANT	\N	PRESENT	0
497080	495128	20134Y	PARTICIPANT	\N	PRESENT	0
497081	495128	19741B	PARTICIPANT	\N	PRESENT	0
497082	495128	19447X	PARTICIPANT	\N	PRESENT	0
497083	495128	14331P	PARTICIPANT	\N	PRESENT	0
497086	495128	19747H	PARTICIPANT	\N	PRESENT	0
497088	495128	14069U	PARTICIPANT	\N	PRESENT	0
498471	497010	20070A	PARTICIPANT	\N	PRESENT	0
498472	497010	11074Q	PARTICIPANT	\N	PRESENT	0
498473	497010	11110B	PARTICIPANT	\N	PRESENT	0
498474	497010	01057W	PARTICIPANT	\N	PRESENT	0
498475	497010	01048V	PARTICIPANT	\N	PRESENT	0
498476	497010	20050V	PARTICIPANT	\N	PRESENT	0
498887	497984	04042C	PARTICIPANT	\N	EXCUSE	0
501532	500476	19741B	PARTICIPANT	\N	PRESENT	0
501533	500476	20080C	PARTICIPANT	\N	PRESENT	0
501534	500476	19545Y	PARTICIPANT	\N	PRESENT	0
501535	500476	11110B	PARTICIPANT	\N	PRESENT	0
501536	500476	01057W	PARTICIPANT	\N	PRESENT	0
501537	500476	14121F	PARTICIPANT	\N	PRESENT	0
501541	501540	19703U	PARTICIPANT	\N	PRESENT	0
501577	500502	14205J	PARTICIPANT	\N	PRESENT	0
501578	500502	19549D	PARTICIPANT	\N	PRESENT	0
501579	500502	20136B	PARTICIPANT	\N	PRESENT	0
501580	500502	19782L	PARTICIPANT	\N	PRESENT	0
502390	502380	11077T	PARTICIPANT	\N	PRESENT	0
502401	502396	01043Q	PARTICIPANT	\N	PRESENT	0
502402	502396	19631V	PARTICIPANT	\N	PRESENT	0
502405	502400	19631V	PARTICIPANT	\N	PRESENT	0
502406	502400	01043Q	PARTICIPANT	\N	PRESENT	0
509815	502327	14219Q	PARTICIPANT	\N	PRESENT	0
510527	502336	19719D	PARTICIPANT	\N	PRESENT	0
510535	509963	19479G	PARTICIPANT	\N	PRESENT	0
510536	509963	19711U	PARTICIPANT	\N	PRESENT	0
510537	509963	19531S	PARTICIPANT	\N	PRESENT	0
510538	509963	19689Q	PARTICIPANT	\N	PRESENT	0
510539	509963	20050V	PARTICIPANT	\N	PRESENT	0
510540	509963	11074Q	PARTICIPANT	\N	PRESENT	0
510541	509963	19667J	PARTICIPANT	\N	PRESENT	0
510542	509963	20044X	PARTICIPANT	\N	PRESENT	0
510543	509963	14225N	PRESIDENT	0	PRESENT	0
510544	509963	04086Q	PARTICIPANT	\N	PRESENT	0
510545	509963	11040E	PARTICIPANT	\N	PRESENT	0
510546	509963	07029T	PARTICIPANT	\N	PRESENT	0
510547	509963	19741B	PARTICIPANT	\N	PRESENT	0
510548	509963	08010L	PARTICIPANT	\N	PRESENT	0
510549	509963	99004R	PARTICIPANT	\N	PRESENT	0
510550	509963	14253S	PARTICIPANT	\N	PRESENT	0
510551	509963	20126Y	PARTICIPANT	\N	PRESENT	0
510552	509963	14327T	PARTICIPANT	\N	PRESENT	0
510553	509963	04071H	PARTICIPANT	\N	PRESENT	0
510554	509963	11048N	PARTICIPANT	\N	PRESENT	0
510555	509963	14189C	PARTICIPANT	\N	PRESENT	0
510556	509963	19762G	PARTICIPANT	\N	PRESENT	0
510557	509963	11012A	PARTICIPANT	\N	EXCUSE	0
510558	502336	14195A	PARTICIPANT	\N	PRESENT	0
510559	502336	18193Q	PARTICIPANT	\N	PRESENT	0
510560	502336	19593H	PARTICIPANT	\N	PRESENT	0
510561	509963	19647E	PARTICIPANT	\N	PRESENT	0
510562	509963	14331P	PARTICIPANT	\N	EXCUSE	0
510563	509963	19349W	PARTICIPANT	\N	EXCUSE	0
510564	502336	20050V	PARTICIPANT	\N	PRESENT	0
510565	502336	19621T	PARTICIPANT	\N	PRESENT	0
510566	502336	19369B	PARTICIPANT	\N	PRESENT	0
510567	502336	20142Y	PARTICIPANT	\N	PRESENT	0
510569	502336	20130U	PARTICIPANT	\N	PRESENT	0
510570	502336	20026V	PARTICIPANT	\N	PRESENT	0
510571	502336	20044X	PARTICIPANT	\N	PRESENT	0
510572	502336	19651A	PARTICIPANT	\N	PRESENT	0
510573	502336	19637C	PARTICIPANT	\N	PRESENT	0
510574	502336	19711U	PARTICIPANT	\N	PRESENT	0
510575	502336	19762G	PARTICIPANT	\N	PRESENT	0
510576	502336	20082E	PARTICIPANT	\N	PRESENT	0
510577	502336	04071H	PARTICIPANT	\N	PRESENT	0
510578	502336	19691J	PARTICIPANT	\N	PRESENT	0
510579	502336	19479G	PARTICIPANT	\N	PRESENT	0
510580	502336	14331P	PARTICIPANT	\N	PRESENT	0
510581	502336	14229S	PARTICIPANT	\N	PRESENT	0
510582	502336	04059M	PARTICIPANT	\N	PRESENT	0
510583	502336	20152B	PARTICIPANT	\N	PRESENT	0
510584	502336	20126Y	PARTICIPANT	\N	PRESENT	0
510585	502336	20048C	PARTICIPANT	\N	PRESENT	0
510586	502336	19611R	PARTICIPANT	\N	PRESENT	0
510587	502336	19533U	PARTICIPANT	\N	PRESENT	0
510588	502336	19693L	PARTICIPANT	\N	PRESENT	0
510589	502336	20132W	PARTICIPANT	\N	PRESENT	0
510590	502336	20056C	PARTICIPANT	\N	PRESENT	0
510591	502336	19581D	PARTICIPANT	\N	PRESENT	0
510592	502336	14042U	PARTICIPANT	\N	PRESENT	0
510593	502336	14327T	PARTICIPANT	\N	PRESENT	0
510594	502336	14109K	PARTICIPANT	\N	PRESENT	0
510595	502336	20134Y	PARTICIPANT	\N	PRESENT	0
510596	502336	11074Q	PARTICIPANT	\N	PRESENT	0
510597	502336	19760E	PARTICIPANT	\N	PRESENT	0
510598	502336	20124W	PARTICIPANT	\N	PRESENT	0
510612	502336	19717B	PARTICIPANT	\N	PRESENT	0
510600	502336	14225N	PARTICIPANT	\N	PRESENT	0
510601	502336	20034V	PARTICIPANT	\N	PRESENT	0
510602	502336	19697Q	PARTICIPANT	\N	PRESENT	0
510603	502336	20112S	PARTICIPANT	\N	PRESENT	0
510604	502336	08010L	PARTICIPANT	\N	PRESENT	0
510605	502336	20052X	PARTICIPANT	\N	PRESENT	0
510606	502336	14189C	PARTICIPANT	\N	PRESENT	0
510607	502336	19699S	PARTICIPANT	\N	PRESENT	0
510608	502336	19349W	PARTICIPANT	\N	PRESENT	0
510609	502336	19553Y	PARTICIPANT	\N	PRESENT	0
510610	502336	99004R	PARTICIPANT	\N	PRESENT	0
510611	502336	20058E	PARTICIPANT	\N	PRESENT	0
510613	502336	14021P	PARTICIPANT	\N	PRESENT	0
510614	502336	19703U	PARTICIPANT	\N	PRESENT	0
510615	502336	19741B	PARTICIPANT	\N	PRESENT	0
510616	502336	14253S	PARTICIPANT	\N	PRESENT	0
510617	502336	19667J	PARTICIPANT	\N	PRESENT	0
510618	502336	07029T	PARTICIPANT	\N	PRESENT	0
510619	502336	11040E	PARTICIPANT	\N	PRESENT	0
510620	502336	14030Q	PARTICIPANT	\N	PRESENT	0
510621	502336	11048N	PARTICIPANT	\N	PRESENT	0
510622	502336	20120S	PARTICIPANT	\N	PRESENT	0
510623	502336	19663E	PARTICIPANT	\N	PRESENT	0
510684	502337	14026U	PARTICIPANT	\N	PRESENT	0
510685	502337	20126Y	PARTICIPANT	\N	PRESENT	0
510686	502337	19663E	PARTICIPANT	\N	PRESENT	0
510687	502337	14195A	PARTICIPANT	\N	PRESENT	0
510688	502337	20130U	PARTICIPANT	\N	PRESENT	0
510689	502337	19697Q	PARTICIPANT	\N	PRESENT	0
510690	502337	19553Y	PARTICIPANT	\N	PRESENT	0
510691	502337	19760E	PARTICIPANT	\N	PRESENT	0
510692	502337	19691J	PARTICIPANT	\N	PRESENT	0
510693	502337	19683J	PARTICIPANT	\N	PRESENT	0
510694	502337	99004R	PARTICIPANT	\N	PRESENT	0
510695	502337	08010L	PARTICIPANT	\N	PRESENT	0
510696	502337	14042U	PARTICIPANT	\N	PRESENT	0
510697	502337	20040T	PARTICIPANT	\N	PRESENT	0
510698	502337	08061X	PARTICIPANT	\N	PRESENT	0
510699	502337	19717B	PARTICIPANT	\N	PRESENT	0
510700	502337	20152B	PARTICIPANT	\N	PRESENT	0
510701	502337	20120S	PARTICIPANT	\N	PRESENT	0
510702	502337	92040Q	PARTICIPANT	\N	PRESENT	0
510703	502337	14071N	PARTICIPANT	\N	PRESENT	0
510704	502337	18193Q	PARTICIPANT	\N	PRESENT	0
510705	502337	10006L	PARTICIPANT	\N	PRESENT	0
510706	502337	11074Q	PARTICIPANT	\N	PRESENT	0
510707	502337	19621T	PARTICIPANT	\N	PRESENT	0
510708	502337	19703U	PARTICIPANT	\N	PRESENT	0
510709	502337	14030Q	PARTICIPANT	\N	PRESENT	0
510710	502337	20124W	PARTICIPANT	\N	PRESENT	0
510711	502337	11040E	PARTICIPANT	\N	PRESENT	0
510713	502337	20132W	PARTICIPANT	\N	PRESENT	0
510714	502337	11045K	PARTICIPANT	\N	PRESENT	0
510715	510712	14253S	PARTICIPANT	\N	PRESENT	0
510717	510716	01057W	PARTICIPANT	\N	PRESENT	0
510718	510716	11048N	PARTICIPANT	\N	PRESENT	0
510719	510716	14225N	PARTICIPANT	\N	PRESENT	0
510720	502337	19693L	PARTICIPANT	\N	PRESENT	0
510721	502337	19711U	PARTICIPANT	\N	PRESENT	0
510722	502337	20044X	PARTICIPANT	\N	PRESENT	0
510723	502337	19591F	PARTICIPANT	\N	PRESENT	0
510724	502337	19349W	PARTICIPANT	\N	PRESENT	0
510725	502337	19399H	PARTICIPANT	\N	PRESENT	0
510726	502337	19573D	PARTICIPANT	\N	PRESENT	0
510727	502337	19533U	PARTICIPANT	\N	PRESENT	0
510728	502337	98022P	PARTICIPANT	\N	PRESENT	0
510729	502337	04070G	PARTICIPANT	\N	PRESENT	0
510730	502337	20058E	PARTICIPANT	\N	PRESENT	0
510731	502337	20142Y	PARTICIPANT	\N	PRESENT	0
510732	502337	19667J	PARTICIPANT	\N	PRESENT	0
510733	502337	04057K	PARTICIPANT	\N	PRESENT	0
510734	502337	14257W	PARTICIPANT	\N	PRESENT	0
510735	502337	14225N	PARTICIPANT	\N	PRESENT	0
510736	502337	19719D	PARTICIPANT	\N	PRESENT	0
510737	502337	20082E	PARTICIPANT	\N	PRESENT	0
510738	502337	20052X	PARTICIPANT	\N	PRESENT	0
510739	502337	14327T	PARTICIPANT	\N	PRESENT	0
510740	502337	20112S	PARTICIPANT	\N	PRESENT	0
510741	502337	17965H	PARTICIPANT	\N	PRESENT	0
486049	486047	19503N	PARTICIPANT	\N	PRESENT	0
486052	486050	19503N	PARTICIPANT	\N	PRESENT	0
486055	486053	19503N	PARTICIPANT	\N	PRESENT	0
488096	488095	11074Q	PARTICIPANT	\N	PRESENT	0
488097	488095	08011M	PARTICIPANT	\N	PRESENT	0
488098	488095	99004R	PARTICIPANT	\N	PRESENT	0
488099	488095	19711U	PARTICIPANT	\N	PRESENT	0
488100	488095	11053K	PARTICIPANT	\N	PRESENT	0
488101	488095	19531S	PARTICIPANT	\N	PRESENT	0
488102	488095	19651A	PARTICIPANT	\N	PRESENT	0
488103	488095	19741B	PARTICIPANT	\N	PRESENT	0
488104	488095	12016W	PARTICIPANT	\N	PRESENT	0
488991	488467	08049C	PARTICIPANT	\N	EXCUSE	0
489229	489228	19926J	PARTICIPANT	\N	PRESENT	0
489230	489228	19679N	PARTICIPANT	\N	PRESENT	0
489232	489231	19926J	PARTICIPANT	\N	PRESENT	0
489233	489231	19958S	PARTICIPANT	\N	PRESENT	0
489234	489231	19679N	PARTICIPANT	\N	PRESENT	0
490708	490449	14327T	PARTICIPANT	\N	PRESENT	0
490709	490449	14331P	PARTICIPANT	\N	PRESENT	0
490710	490449	04071H	PARTICIPANT	\N	PRESENT	0
490711	490449	01057W	PARTICIPANT	\N	PRESENT	0
490712	490449	20080C	PARTICIPANT	\N	PRESENT	0
490713	490449	11053K	PARTICIPANT	\N	PRESENT	0
490714	490449	19667J	PARTICIPANT	\N	PRESENT	0
490715	490449	11074Q	PARTICIPANT	\N	PRESENT	0
490716	490449	19671E	PARTICIPANT	\N	PRESENT	0
490717	490449	14225N	PRESIDENT	1	PRESENT	0
490718	490449	11070L	PARTICIPANT	\N	PRESENT	0
490719	490449	11110B	PARTICIPANT	\N	PRESENT	0
490720	490449	07029T	PARTICIPANT	\N	PRESENT	0
490721	490449	96004D	PARTICIPANT	\N	PRESENT	0
490722	490449	19349W	PARTICIPANT	\N	PRESENT	0
490723	490449	08010L	PARTICIPANT	\N	PRESENT	0
490724	490449	20116W	PARTICIPANT	\N	PRESENT	0
490725	490449	14253S	PRESIDENT	0	PRESENT	0
490726	490449	20126Y	PARTICIPANT	\N	PRESENT	0
490727	490449	11048N	PARTICIPANT	\N	PRESENT	0
490728	490449	19479G	PARTICIPANT	\N	PRESENT	0
490729	490449	19711U	PARTICIPANT	\N	PRESENT	0
490730	490449	20036X	PARTICIPANT	\N	PRESENT	0
490731	490449	08034U	PARTICIPANT	\N	PRESENT	0
490732	490449	19687N	PARTICIPANT	\N	PRESENT	0
490733	490449	19689Q	PARTICIPANT	\N	PRESENT	0
490734	490449	20050V	PARTICIPANT	\N	PRESENT	0
490735	490449	08011M	PARTICIPANT	\N	PRESENT	0
490736	490449	20044X	PARTICIPANT	\N	PRESENT	0
490737	490449	20150Y	PARTICIPANT	\N	PRESENT	0
490738	490449	14173T	PARTICIPANT	\N	PRESENT	0
490739	490449	11040E	PARTICIPANT	\N	PRESENT	0
490740	490449	14083S	PARTICIPANT	\N	PRESENT	0
490741	490449	11012A	PARTICIPANT	\N	PRESENT	0
490742	490449	08073C	PARTICIPANT	\N	PRESENT	0
490743	490449	08009T	PARTICIPANT	\N	PRESENT	0
490744	490449	19741B	PARTICIPANT	\N	PRESENT	0
490745	490449	14121F	PARTICIPANT	\N	PRESENT	0
490746	490449	99004R	PARTICIPANT	\N	PRESENT	0
490747	490449	19762G	PARTICIPANT	\N	PRESENT	0
490748	490448	19749K	PARTICIPANT	\N	PRESENT	0
490749	490448	14053L	PARTICIPANT	\N	PRESENT	0
490750	490448	20074E	PARTICIPANT	\N	PRESENT	0
490751	490448	19673G	PARTICIPANT	\N	PRESENT	0
490752	490448	05008E	PARTICIPANT	\N	PRESENT	0
490753	490448	19447X	PARTICIPANT	\N	PRESENT	0
490754	490448	19729F	PARTICIPANT	\N	PRESENT	0
490755	490448	07004J	PARTICIPANT	\N	PRESENT	0
490756	490448	14041T	PRESIDENT	0	PRESENT	0
490757	490448	14147R	PARTICIPANT	\N	PRESENT	0
490758	490448	08018U	PARTICIPANT	\N	PRESENT	0
490759	490448	04008A	PARTICIPANT	\N	PRESENT	0
490760	490448	14259Y	PARTICIPANT	\N	PRESENT	0
490761	490449	19335Q	PARTICIPANT	\N	PRESENT	0
490762	490449	19647E	PARTICIPANT	\N	PRESENT	0
490763	490449	19531S	PARTICIPANT	\N	PRESENT	0
490764	490449	14189C	PARTICIPANT	\N	PRESENT	0
490765	490449	12016W	PARTICIPANT	\N	PRESENT	0
490766	490449	20070A	PARTICIPANT	\N	PRESENT	0
490767	490448	20108W	PARTICIPANT	\N	PRESENT	0
490768	490448	14107H	PARTICIPANT	\N	PRESENT	0
490775	490448	14001X	PARTICIPANT	\N	PRESENT	0
490776	490448	19543W	PARTICIPANT	\N	PRESENT	0
490777	490448	19581D	PARTICIPANT	\N	PRESENT	0
490778	490448	04047H	PRESIDENT	1	PRESENT	0
490779	490448	01028R	PARTICIPANT	\N	PRESENT	0
490780	490448	14231L	PARTICIPANT	\N	PRESENT	0
490781	490448	19954N	PARTICIPANT	\N	PRESENT	0
490782	490448	19489J	PARTICIPANT	\N	PRESENT	0
490783	490448	17737W	PARTICIPANT	\N	PRESENT	0
490784	490448	14275Y	PARTICIPANT	\N	PRESENT	0
490785	490448	20110Q	PARTICIPANT	\N	PRESENT	0
490786	490448	14179A	PARTICIPANT	\N	PRESENT	0
490787	490448	14151M	PARTICIPANT	\N	PRESENT	0
490788	490448	20114U	PARTICIPANT	\N	PRESENT	0
490789	490448	14215L	PARTICIPANT	\N	PRESENT	0
490790	490448	11072N	PARTICIPANT	\N	PRESENT	0
490791	490448	19649G	PARTICIPANT	\N	PRESENT	0
490792	490448	11026G	PARTICIPANT	\N	PRESENT	0
490793	490448	10015M	PARTICIPANT	\N	PRESENT	0
490794	490448	11033F	PARTICIPANT	\N	PRESENT	0
490795	490448	04085P	PARTICIPANT	\N	PRESENT	0
490796	490448	14089Y	PARTICIPANT	\N	PRESENT	0
490797	490448	19725B	PARTICIPANT	\N	PRESENT	0
490798	490448	11056N	PARTICIPANT	\N	PRESENT	0
490799	490448	95063L	PARTICIPANT	\N	PRESENT	0
490800	490448	19629C	PARTICIPANT	\N	PRESENT	0
490801	490448	14069U	PARTICIPANT	\N	PRESENT	0
490802	490448	11085T	PARTICIPANT	\N	PRESENT	0
490803	490448	14021P	PARTICIPANT	\N	PRESENT	0
491186	490473	11067R	PARTICIPANT	\N	PRESENT	0
491187	490473	19569H	PARTICIPANT	\N	PRESENT	0
491188	490473	11066Q	PARTICIPANT	\N	PRESENT	0
491189	490473	19447X	PARTICIPANT	\N	PRESENT	0
491190	490473	11031D	PARTICIPANT	\N	PRESENT	0
491191	490473	17737W	PARTICIPANT	\N	PRESENT	0
491192	490473	14041T	PRESIDENT	0	PRESENT	0
491193	490473	14147R	PARTICIPANT	\N	PRESENT	0
491194	490473	14179A	PARTICIPANT	\N	PRESENT	0
491195	490473	19575F	PARTICIPANT	\N	PRESENT	0
491196	490473	14213J	PARTICIPANT	\N	PRESENT	0
491197	490473	14215L	PARTICIPANT	\N	PRESENT	0
491198	490473	99004R	PARTICIPANT	\N	PRESENT	0
491199	490473	14217N	PARTICIPANT	\N	PRESENT	0
491200	490473	10006L	PARTICIPANT	\N	PRESENT	0
491201	490473	19683J	PARTICIPANT	\N	PRESENT	0
491202	490473	04092N	PRESIDENT	1	PRESENT	0
491203	490473	20092G	PARTICIPANT	\N	PRESENT	0
491204	490473	08034U	PARTICIPANT	\N	PRESENT	0
491205	490473	14195A	PARTICIPANT	\N	EXCUSE	0
491206	490473	18083K	PARTICIPANT	\N	PRESENT	0
491241	490452	14059S	PARTICIPANT	\N	PRESENT	0
491242	490452	19701S	PARTICIPANT	\N	PRESENT	0
491243	490452	19711U	PARTICIPANT	\N	PRESENT	0
491244	490452	08034U	PARTICIPANT	\N	PRESENT	0
491245	490452	01058X	PARTICIPANT	\N	PRESENT	0
491246	490452	14033T	PARTICIPANT	\N	PRESENT	0
491247	490452	19399H	PARTICIPANT	\N	PRESENT	0
491248	490452	19631V	PARTICIPANT	\N	PRESENT	0
491249	490452	01028R	PRESIDENT	0	PRESENT	0
491250	490452	11056N	PARTICIPANT	\N	PRESENT	0
491251	490452	19703U	PARTICIPANT	\N	PRESENT	0
491252	490452	20110Q	PARTICIPANT	\N	PRESENT	0
491253	490452	19503N	PARTICIPANT	\N	PRESENT	0
491254	490452	19575F	PARTICIPANT	\N	PRESENT	0
491255	490452	14213J	PARTICIPANT	\N	PRESENT	0
491256	490452	14215L	PARTICIPANT	\N	PRESENT	0
491257	490452	19747H	PARTICIPANT	\N	PRESENT	0
491258	490452	19758L	PARTICIPANT	\N	PRESENT	0
491259	490452	19621T	PARTICIPANT	\N	PRESENT	0
491260	490452	14219Q	PARTICIPANT	\N	EXCUSE	0
491398	490471	19717B	PARTICIPANT	\N	PRESENT	0
491399	490471	01034P	PARTICIPANT	\N	PRESENT	0
491400	490471	19798U	PARTICIPANT	\N	PRESENT	0
491401	490471	19697Q	PARTICIPANT	\N	PRESENT	0
491402	490471	19683J	PARTICIPANT	\N	PRESENT	0
491403	490471	14042U	PARTICIPANT	\N	PRESENT	0
491404	490471	19713W	PARTICIPANT	\N	EXCUSE	0
491405	490471	14071N	PARTICIPANT	\N	EXCUSE	0
491406	490471	14195A	PARTICIPANT	\N	EXCUSE	0
491407	490471	19367Y	PARTICIPANT	\N	EXCUSE	0
491408	490471	19760E	PARTICIPANT	\N	EXCUSE	0
493488	493370	14053L	PARTICIPANT	\N	PRESENT	0
493489	493370	14041T	PARTICIPANT	\N	PRESENT	0
493490	493370	14259Y	PARTICIPANT	\N	PRESENT	0
493491	493370	20110Q	PARTICIPANT	\N	PRESENT	0
493492	493370	14147R	PARTICIPANT	\N	PRESENT	0
493493	493370	14215L	PARTICIPANT	\N	PRESENT	0
483168	481128	14135M	PARTICIPANT	\N	PRESENT	0
500839	500837	14257W	PARTICIPANT	\N	PRESENT	0
500842	500841	14257W	PARTICIPANT	\N	PRESENT	0
503448	503157	18083K	PARTICIPANT	\N	PRESENT	0
503449	503157	19739H	PARTICIPANT	\N	PRESENT	0
503450	503157	14219Q	PRESIDENT	0	PRESENT	0
503451	503157	19745F	PARTICIPANT	\N	PRESENT	0
503452	503157	20046A	PARTICIPANT	\N	PRESENT	0
503453	503157	17367Q	PARTICIPANT	\N	PRESENT	0
503454	503157	19599P	PARTICIPANT	\N	PRESENT	0
503455	503157	20096L	PARTICIPANT	\N	PRESENT	0
503456	503157	19681G	PARTICIPANT	\N	EXCUSE	0
503457	503157	14031R	PARTICIPANT	\N	PRESENT	0
503458	503157	20140W	PARTICIPANT	\N	PRESENT	0
503459	503157	19251M	PARTICIPANT	\N	PRESENT	0
503460	503157	19503N	PARTICIPANT	\N	PRESENT	0
503461	503157	20038A	PARTICIPANT	\N	PRESENT	0
503462	503157	19826F	PARTICIPANT	\N	PRESENT	0
503463	503157	14169X	PARTICIPANT	\N	PRESENT	0
503464	503157	20024T	PARTICIPANT	\N	PRESENT	0
503465	503157	20100N	PARTICIPANT	\N	PRESENT	0
503577	503264	10006L	PARTICIPANT	\N	PRESENT	0
503467	503157	11101A	PARTICIPANT	\N	PRESENT	0
503468	503157	19685L	PARTICIPANT	\N	PRESENT	0
503469	503157	20032T	PARTICIPANT	\N	PRESENT	0
503470	502447	04086Q	PARTICIPANT	\N	PRESENT	0
503471	502447	14331P	PARTICIPANT	\N	PRESENT	0
503472	502447	19349W	PARTICIPANT	\N	PRESENT	0
503473	502447	19741B	PARTICIPANT	\N	PRESENT	0
503474	502447	99004R	PARTICIPANT	\N	PRESENT	0
503475	502447	14225N	PRESIDENT	0	PRESENT	0
503476	502447	20126Y	PARTICIPANT	\N	PRESENT	0
503477	502447	08010L	PARTICIPANT	\N	PRESENT	0
503478	502447	07029T	PARTICIPANT	\N	PRESENT	0
503479	502447	11048N	PARTICIPANT	\N	PRESENT	0
503480	502447	19711U	PARTICIPANT	\N	PRESENT	0
503481	502447	14189C	PARTICIPANT	\N	PRESENT	0
503482	502447	14083S	PARTICIPANT	\N	PRESENT	0
503483	502447	19671E	PARTICIPANT	\N	PRESENT	0
503487	503157	20044X	PARTICIPANT	\N	PRESENT	0
503488	503157	19551W	PARTICIPANT	\N	PRESENT	0
503489	502447	11053K	PARTICIPANT	\N	PRESENT	0
503490	503157	05012A	PARTICIPANT	\N	PRESENT	0
503491	503157	20106U	PARTICIPANT	\N	PRESENT	0
503498	503133	04070G	PARTICIPANT	\N	PRESENT	0
503499	503133	19699S	PARTICIPANT	\N	PRESENT	0
503500	503133	19533U	PARTICIPANT	\N	PRESENT	0
503501	503133	14229S	PARTICIPANT	\N	PRESENT	0
503502	503133	19573D	PARTICIPANT	\N	PRESENT	0
503503	503133	08017T	PARTICIPANT	\N	PRESENT	0
503504	503133	20124W	PARTICIPANT	\N	PRESENT	0
503505	503133	20026V	PARTICIPANT	\N	PRESENT	0
503506	503133	19593H	PARTICIPANT	\N	PRESENT	0
503507	503133	20132W	PARTICIPANT	\N	PRESENT	0
503508	503133	20134Y	PARTICIPANT	\N	PRESENT	0
503509	503133	19651A	PARTICIPANT	\N	PRESENT	0
503510	503133	20138D	PARTICIPANT	\N	PRESENT	0
503511	503133	19611R	PRESIDENT	0	PRESENT	0
503512	503133	20048C	PARTICIPANT	\N	PRESENT	0
503513	503133	19693L	PARTICIPANT	\N	PRESENT	0
503514	503133	19399H	PARTICIPANT	\N	PRESENT	0
503515	503133	14030Q	PARTICIPANT	\N	PRESENT	0
503516	503133	20056C	PARTICIPANT	\N	PRESENT	0
503517	503133	04059M	PARTICIPANT	\N	PRESENT	0
503518	503133	19735D	PARTICIPANT	\N	PRESENT	0
503552	503264	86034E	PARTICIPANT	\N	PRESENT	0
503520	503133	11043H	PARTICIPANT	\N	PRESENT	0
503521	503133	19621T	PARTICIPANT	\N	PRESENT	0
503522	503133	19758L	PARTICIPANT	\N	PRESENT	0
503576	503264	10015M	PARTICIPANT	\N	PRESENT	0
503578	503264	19760E	PARTICIPANT	\N	PRESENT	0
503579	503264	14223L	PARTICIPANT	\N	PRESENT	0
503580	503264	18083K	PARTICIPANT	\N	PRESENT	0
503581	503264	19758L	PARTICIPANT	\N	PRESENT	0
503582	503264	11031D	PARTICIPANT	\N	PRESENT	0
503583	503264	14031R	PARTICIPANT	\N	PRESENT	0
503584	503264	19695N	PARTICIPANT	\N	PRESENT	0
503585	503264	20046A	PARTICIPANT	\N	PRESENT	0
503586	503264	20028X	PARTICIPANT	\N	PRESENT	0
503588	503264	19683J	PARTICIPANT	\N	PRESENT	0
503589	503264	17779H	PARTICIPANT	\N	PRESENT	0
503590	503264	17965H	PARTICIPANT	\N	PRESENT	0
503591	503264	11067R	PARTICIPANT	\N	PRESENT	0
503592	503264	18193Q	PARTICIPANT	\N	PRESENT	0
503593	503264	01058X	PARTICIPANT	\N	PRESENT	0
503594	503264	20114U	PARTICIPANT	\N	PRESENT	0
503595	503264	99004R	PARTICIPANT	\N	PRESENT	0
503596	503264	14026U	PARTICIPANT	\N	PRESENT	0
503597	503264	11066Q	PARTICIPANT	\N	PRESENT	0
503598	503264	20130U	PARTICIPANT	\N	PRESENT	0
503599	503264	19703U	PARTICIPANT	\N	PRESENT	0
503600	503264	20092G	PARTICIPANT	\N	PRESENT	0
503601	503264	19333N	PARTICIPANT	\N	PRESENT	0
503602	503264	04086Q	PARTICIPANT	\N	PRESENT	0
503603	503264	19525U	PARTICIPANT	\N	PRESENT	0
503604	503264	14071N	PARTICIPANT	\N	PRESENT	0
503605	503264	19725B	PARTICIPANT	\N	PRESENT	0
503606	503264	20080C	PARTICIPANT	\N	PRESENT	0
503607	503264	19415P	PARTICIPANT	\N	PRESENT	0
503608	503264	19631V	PARTICIPANT	\N	PRESENT	0
503609	503264	14225N	PARTICIPANT	\N	PRESENT	0
503610	503264	11097X	PARTICIPANT	\N	PRESENT	0
503611	503264	19531S	PARTICIPANT	\N	PRESENT	0
503612	503264	20064C	PARTICIPANT	\N	PRESENT	0
503613	503264	20030R	PARTICIPANT	\N	PRESENT	0
503615	503264	14030Q	PARTICIPANT	\N	PRESENT	0
503616	503264	20088L	PARTICIPANT	\N	PRESENT	0
503620	503264	20082E	PARTICIPANT	\N	PRESENT	0
503621	503264	08010L	PARTICIPANT	\N	PRESENT	0
503622	503264	20102Q	PARTICIPANT	\N	PRESENT	0
503623	503264	11043H	PARTICIPANT	\N	PRESENT	0
503624	503264	11033F	PARTICIPANT	\N	PRESENT	0
503625	503264	14257W	PARTICIPANT	\N	PRESENT	0
503626	503264	19413M	PARTICIPANT	\N	PRESENT	0
503627	503264	19679N	PARTICIPANT	\N	PRESENT	0
503628	503264	19649G	PARTICIPANT	\N	PRESENT	0
503629	503264	19515S	PARTICIPANT	\N	PRESENT	0
503630	503264	19766L	PARTICIPANT	\N	PRESENT	0
503634	503264	04035D	PARTICIPANT	\N	PRESENT	0
503636	503264	11054L	PARTICIPANT	\N	PRESENT	0
503637	503264	14281W	PARTICIPANT	\N	PRESENT	0
503638	503264	01025N	PARTICIPANT	\N	PRESENT	0
503642	503264	14105F	PARTICIPANT	\N	PRESENT	0
503640	503264	19503N	PARTICIPANT	\N	PRESENT	0
503641	503264	17737W	PARTICIPANT	\N	PRESENT	0
503643	503264	20070A	PARTICIPANT	\N	PRESENT	0
503644	503264	14109K	PARTICIPANT	\N	PRESENT	0
503645	503264	17367Q	PARTICIPANT	\N	PRESENT	0
503646	503264	14021P	PARTICIPANT	\N	PRESENT	0
503648	503264	19673G	PARTICIPANT	\N	PRESENT	0
503649	503264	19715Y	PARTICIPANT	\N	PRESENT	0
503652	503264	20018V	PARTICIPANT	\N	PRESENT	0
503655	503264	12028B	PARTICIPANT	\N	PRESENT	0
503656	503264	11045K	PARTICIPANT	\N	PRESENT	0
503657	503264	19782L	PARTICIPANT	\N	PRESENT	0
503658	503264	19697Q	PARTICIPANT	\N	PRESENT	0
503659	503264	11090Q	PARTICIPANT	\N	PRESENT	0
503660	503264	20146D	PARTICIPANT	\N	PRESENT	0
503661	503264	19349W	PARTICIPANT	\N	PRESENT	0
503662	503264	20106U	PARTICIPANT	\N	PRESENT	0
503663	503264	19301E	PARTICIPANT	\N	PRESENT	0
503664	503264	19591F	PARTICIPANT	\N	PRESENT	0
503665	503264	19575F	PARTICIPANT	\N	PRESENT	0
503666	503264	08061X	PARTICIPANT	\N	PRESENT	0
503667	503264	20052X	PARTICIPANT	\N	PRESENT	0
503668	503264	19954N	PARTICIPANT	\N	PRESENT	0
503669	503264	20048C	PARTICIPANT	\N	PRESENT	0
503671	503264	08069G	PARTICIPANT	\N	PRESENT	0
503672	503264	19619A	PARTICIPANT	\N	PRESENT	0
503673	503264	19693L	PARTICIPANT	\N	PRESENT	0
503674	503264	14042U	PARTICIPANT	\N	PRESENT	0
503675	503264	19599P	PARTICIPANT	\N	PRESENT	0
503676	503264	19569H	PARTICIPANT	\N	PRESENT	0
503677	503264	19701S	PARTICIPANT	\N	PRESENT	0
503678	503264	14219Q	PARTICIPANT	\N	PRESENT	0
503679	503264	20084G	PARTICIPANT	\N	PRESENT	0
503680	503264	01034P	PARTICIPANT	\N	PRESENT	0
503681	503264	01043Q	PARTICIPANT	\N	PRESENT	0
503682	503264	14121F	PARTICIPANT	\N	PRESENT	0
483270	481526	19629C	PARTICIPANT	\N	PRESENT	0
483271	481526	19611R	PRESIDENT	0	PRESENT	0
483272	481526	14097Y	PARTICIPANT	\N	PRESENT	0
483273	481526	19735D	PARTICIPANT	\N	PRESENT	0
483274	481575	14261S	PARTICIPANT	\N	PRESENT	0
483275	481575	08019V	PRESIDENT	0	PRESENT	0
483605	481565	14071N	PARTICIPANT	\N	EXCUSE	0
483606	481565	19335Q	PRESIDENT	0	PRESENT	0
484627	484626	08011M	PARTICIPANT	\N	PRESENT	0
484628	484626	99004R	PARTICIPANT	\N	PRESENT	0
484629	484626	11053K	PARTICIPANT	\N	PRESENT	0
484630	484626	14085U	PRESIDENT	0	PRESENT	0
484631	484626	19349W	PARTICIPANT	\N	PRESENT	0
484632	484626	14331P	PARTICIPANT	\N	PRESENT	0
484633	484626	19647E	PARTICIPANT	\N	PRESENT	0
484647	484645	05008E	PRESIDENT	0	PRESENT	0
484648	484645	11033F	PARTICIPANT	\N	PRESENT	0
484649	484645	14030Q	PARTICIPANT	\N	PRESENT	0
484664	484663	19577H	PARTICIPANT	\N	PRESENT	0
484665	484663	19717B	PARTICIPANT	\N	PRESENT	0
484666	484663	19631V	PARTICIPANT	\N	PRESENT	0
484667	484663	08019V	PARTICIPANT	\N	PRESENT	0
484668	484663	19319Q	PARTICIPANT	\N	PRESENT	0
484655	484645	19649G	PARTICIPANT	\N	PRESENT	0
484671	484663	19657G	PARTICIPANT	\N	PRESENT	0
484657	484645	14147R	PARTICIPANT	\N	PRESENT	0
484658	484645	11072N	PARTICIPANT	\N	PRESENT	0
484659	484645	11045K	PARTICIPANT	\N	PRESENT	0
484660	484645	19749K	PARTICIPANT	\N	PRESENT	0
494979	494978	01034P	PARTICIPANT	\N	PRESENT	0
494980	494978	11097X	PARTICIPANT	\N	PRESENT	0
494995	494994	11097X	PARTICIPANT	\N	PRESENT	0
495006	495005	01034P	PARTICIPANT	\N	PRESENT	0
495008	495007	14042U	PARTICIPANT	\N	PRESENT	0
495009	495007	19591F	PARTICIPANT	\N	PRESENT	0
495012	495010	04059M	PARTICIPANT	\N	PRESENT	0
495013	495010	14030Q	PARTICIPANT	\N	PRESENT	0
495014	495010	19643A	PARTICIPANT	\N	PRESENT	0
495015	495010	20138D	PARTICIPANT	\N	PRESENT	0
495016	495010	20152B	PARTICIPANT	\N	PRESENT	0
495017	495010	19621T	PARTICIPANT	\N	PRESENT	0
495018	495010	19758L	PARTICIPANT	\N	PRESENT	0
495019	495010	19693L	PARTICIPANT	\N	PRESENT	0
495020	495010	19719D	PARTICIPANT	\N	PRESENT	0
495021	495010	20134Y	PARTICIPANT	\N	PRESENT	0
495022	495010	20124W	PARTICIPANT	\N	PRESENT	0
495023	495010	14123H	PARTICIPANT	\N	PRESENT	0
495024	495010	19399H	PARTICIPANT	\N	PRESENT	0
495025	495010	19611R	PRESIDENT	0	PRESENT	0
495026	495010	20052X	PARTICIPANT	\N	PRESENT	0
495027	495010	04070G	PARTICIPANT	\N	PRESENT	0
495028	495010	19593H	PARTICIPANT	\N	PRESENT	0
495029	495010	92040Q	PARTICIPANT	\N	EXCUSE	0
495030	495010	19573D	PARTICIPANT	\N	PRESENT	0
495031	495010	19533U	PARTICIPANT	\N	PRESENT	0
495032	495010	19651A	PARTICIPANT	\N	PRESENT	0
495033	495010	20026V	PARTICIPANT	\N	PRESENT	0
495034	495010	20058E	PARTICIPANT	\N	PRESENT	0
498888	497979	96004D	PARTICIPANT	\N	PRESENT	0
498889	497979	14089Y	PARTICIPANT	\N	PRESENT	0
498890	497979	14207L	PARTICIPANT	\N	PRESENT	0
498891	497979	11101A	PARTICIPANT	\N	PRESENT	0
498892	497979	19701S	PARTICIPANT	\N	PRESENT	0
498893	497979	19251M	PARTICIPANT	\N	PRESENT	0
498894	497979	20100N	PARTICIPANT	\N	PRESENT	0
498895	497979	19521Q	PARTICIPANT	\N	PRESENT	0
498896	497979	08018U	PARTICIPANT	\N	PRESENT	0
498897	497979	11083R	PARTICIPANT	\N	PRESENT	0
498898	497979	19725B	PARTICIPANT	\N	PRESENT	0
498899	497979	20128B	PARTICIPANT	\N	PRESENT	0
498900	497979	19531S	PARTICIPANT	\N	PRESENT	0
498901	497979	14097Y	PARTICIPANT	\N	PRESENT	0
498902	497979	14073Q	PARTICIPANT	\N	PRESENT	0
498903	497979	11026G	PARTICIPANT	\N	PRESENT	0
498904	497979	08034U	PARTICIPANT	\N	PRESENT	0
498905	497979	19441R	PARTICIPANT	\N	PRESENT	0
498906	497979	12016W	PARTICIPANT	\N	PRESENT	0
498907	497979	14001X	PARTICIPANT	\N	PRESENT	0
498908	497979	14237S	PARTICIPANT	\N	PRESENT	0
498909	497979	14331P	PRESIDENT	0	PRESENT	0
498910	497979	20098N	PARTICIPANT	\N	EXCUSE	0
498911	497979	04034C	PARTICIPANT	\N	PRESENT	0
498966	498009	20100N	PARTICIPANT	\N	PRESENT	0
498970	498009	19503N	PARTICIPANT	\N	PRESENT	0
499409	499408	19515S	PARTICIPANT	\N	PRESENT	0
499410	499408	19741B	PARTICIPANT	\N	PRESENT	0
499411	499408	14030Q	PARTICIPANT	\N	PRESENT	0
499412	499408	17367Q	PARTICIPANT	\N	PRESENT	0
499413	499408	19367Y	PARTICIPANT	\N	PRESENT	0
499414	499408	20042V	PARTICIPANT	\N	PRESENT	0
499415	499408	17737W	PARTICIPANT	\N	PRESENT	0
499416	499408	04042C	PARTICIPANT	\N	PRESENT	0
499417	499408	19545Y	PARTICIPANT	\N	PRESENT	0
499420	499408	14041T	PARTICIPANT	\N	PRESENT	0
499421	499408	14215L	PARTICIPANT	\N	PRESENT	0
499422	499408	14021P	PARTICIPANT	\N	PRESENT	0
499423	499408	19447X	PARTICIPANT	\N	PRESENT	0
499424	499408	20056C	PARTICIPANT	\N	PRESENT	0
499425	499408	19333N	PARTICIPANT	\N	PRESENT	0
499426	499408	14179A	PARTICIPANT	\N	PRESENT	0
499427	499408	98022P	PARTICIPANT	\N	PRESENT	0
499428	499408	04035D	PARTICIPANT	\N	PRESENT	0
499429	499408	08018U	PARTICIPANT	\N	PRESENT	0
499430	499408	19647E	PARTICIPANT	\N	PRESENT	0
499431	499408	07033P	PARTICIPANT	\N	PRESENT	0
499432	499408	08034U	PARTICIPANT	\N	PRESENT	0
499436	499408	20108W	PARTICIPANT	\N	PRESENT	0
499437	499408	16685X	PARTICIPANT	\N	PRESENT	0
499438	499408	19711U	PARTICIPANT	\N	PRESENT	0
499439	499408	19503N	PARTICIPANT	\N	PRESENT	0
499440	499408	14169X	PARTICIPANT	\N	PRESENT	0
499441	499408	04070G	PARTICIPANT	\N	PRESENT	0
499442	499408	14223L	PARTICIPANT	\N	PRESENT	0
499443	499408	14147R	PARTICIPANT	\N	PRESENT	0
499444	499408	11085T	PARTICIPANT	\N	PRESENT	0
499445	499408	19713W	PARTICIPANT	\N	PRESENT	0
499446	499408	11041F	PARTICIPANT	\N	PRESENT	0
499447	499408	04033B	PARTICIPANT	\N	PRESENT	0
499448	499408	19798U	PARTICIPANT	\N	PRESENT	0
499449	499408	97011G	PARTICIPANT	\N	PRESENT	0
500051	500050	19703U	PARTICIPANT	\N	PRESENT	0
500052	500050	11067R	PARTICIPANT	\N	PRESENT	0
500053	500050	18193Q	PARTICIPANT	\N	PRESENT	0
500058	498010	11101A	PARTICIPANT	\N	PRESENT	0
500088	489917	20024T	PARTICIPANT	\N	PRESENT	0
500089	489917	14030Q	PARTICIPANT	\N	PRESENT	0
500090	489917	20138D	PARTICIPANT	\N	PRESENT	0
500091	489917	17737W	PARTICIPANT	\N	PRESENT	0
500092	489917	11031D	PARTICIPANT	\N	PRESENT	0
500093	489917	19693L	PARTICIPANT	\N	PRESENT	0
500094	489917	19599P	PARTICIPANT	\N	PRESENT	0
500095	489917	04035D	PARTICIPANT	\N	PRESENT	0
500096	489917	20106U	PARTICIPANT	\N	PRESENT	0
500097	489917	14179A	PARTICIPANT	\N	PRESENT	0
500098	489917	20066E	PARTICIPANT	\N	PRESENT	0
500099	489917	19715Y	PARTICIPANT	\N	PRESENT	0
500100	489917	20056C	PARTICIPANT	\N	PRESENT	0
500101	489917	07029T	PARTICIPANT	\N	PRESENT	0
500102	489917	08017T	PARTICIPANT	\N	PRESENT	0
500103	489917	19657G	PARTICIPANT	\N	PRESENT	0
500104	489917	14221J	PARTICIPANT	\N	PRESENT	0
500105	489917	14109K	PARTICIPANT	\N	PRESENT	0
500106	489917	19768N	PARTICIPANT	\N	PRESENT	0
500107	489917	19866P	PARTICIPANT	\N	PRESENT	0
500108	489917	20118Y	PARTICIPANT	\N	PRESENT	0
500109	489917	20130U	PARTICIPANT	\N	PRESENT	0
500110	489917	19798U	PARTICIPANT	\N	PRESENT	0
500111	489917	20098N	PARTICIPANT	\N	PRESENT	0
500112	489917	19527W	PARTICIPANT	\N	PRESENT	0
500113	489917	20046A	PARTICIPANT	\N	PRESENT	0
500114	489917	19749K	PARTICIPANT	\N	PRESENT	0
508190	506005	11041F	PARTICIPANT	\N	PRESENT	0
510744	502337	20134Y	PARTICIPANT	\N	PRESENT	0
510745	502337	19687N	PARTICIPANT	\N	PRESENT	0
510746	502337	19581D	PARTICIPANT	\N	PRESENT	0
510747	502337	14109K	PARTICIPANT	\N	PRESENT	0
510742	502337	19741B	PARTICIPANT	\N	PRESENT	0
510743	502337	14189C	PARTICIPANT	\N	PRESENT	0
510751	502337	14021P	PARTICIPANT	\N	PRESENT	0
510749	502337	11043H	PARTICIPANT	\N	PRESENT	0
510750	502337	19713W	PARTICIPANT	\N	PRESENT	0
510752	502337	20026V	PARTICIPANT	\N	PRESENT	0
510753	502337	19699S	PARTICIPANT	\N	PRESENT	0
510755	510754	11064N	PARTICIPANT	\N	PRESENT	0
510756	510754	12028B	PARTICIPANT	\N	PRESENT	0
510757	502337	19735D	PARTICIPANT	\N	PRESENT	0
510758	502337	19593H	PARTICIPANT	\N	PRESENT	0
510759	502337	19479G	PARTICIPANT	\N	PRESENT	0
510760	502337	17589D	PARTICIPANT	\N	PRESENT	0
510771	502337	11083R	PARTICIPANT	\N	PRESENT	0
510772	502337	20098N	PARTICIPANT	\N	PRESENT	0
510774	510773	20022R	PARTICIPANT	\N	PRESENT	0
510775	510773	20104S	PARTICIPANT	\N	PRESENT	0
510776	510773	19820Y	PARTICIPANT	\N	PRESENT	0
510777	510773	19521Q	PARTICIPANT	\N	PRESENT	0
510778	510773	19745F	PARTICIPANT	\N	PRESENT	0
510779	502337	14229S	PARTICIPANT	\N	PRESENT	0
510780	502337	14331P	PARTICIPANT	\N	PRESENT	0
510782	510781	20022R	PARTICIPANT	\N	PRESENT	0
510783	510781	20104S	PARTICIPANT	\N	PRESENT	0
510784	510781	19820Y	PARTICIPANT	\N	PRESENT	0
510785	510781	19521Q	PARTICIPANT	\N	PRESENT	0
510786	502337	08017T	PARTICIPANT	\N	PRESENT	0
510787	502337	19651A	PARTICIPANT	\N	PRESENT	0
510788	502337	20056C	PARTICIPANT	\N	PRESENT	0
510789	502337	01057W	PARTICIPANT	\N	PRESENT	0
510790	502337	20090E	PARTICIPANT	\N	PRESENT	0
510791	502337	11048N	PARTICIPANT	\N	PRESENT	0
510800	502337	19762G	PARTICIPANT	\N	PRESENT	0
510801	502337	04059M	PARTICIPANT	\N	PRESENT	0
510802	502337	14231L	PARTICIPANT	\N	PRESENT	0
510804	502337	19747H	PARTICIPANT	\N	PRESENT	0
510806	502337	20034V	PARTICIPANT	\N	PRESENT	0
510807	502337	19611R	PARTICIPANT	\N	PRESENT	0
510808	502337	14147R	PARTICIPANT	\N	PRESENT	0
510809	502337	19643A	PARTICIPANT	\N	PRESENT	0
510810	502337	14069U	PARTICIPANT	\N	PRESENT	0
510864	502338	19349W	PARTICIPANT	\N	PRESENT	0
510865	502338	14229S	PARTICIPANT	\N	PRESENT	0
510866	502338	19611R	PARTICIPANT	\N	PRESENT	0
510867	502338	19593H	PARTICIPANT	\N	PRESENT	0
510868	502338	20028X	PARTICIPANT	\N	PRESENT	0
510869	502338	20030R	PARTICIPANT	\N	PRESENT	0
510870	502338	17589D	PARTICIPANT	\N	PRESENT	0
510871	502338	19553Y	PARTICIPANT	\N	PRESENT	0
510872	502338	14030Q	PARTICIPANT	\N	PRESENT	0
510873	502338	19735D	PARTICIPANT	\N	PRESENT	0
510874	502338	14231L	PARTICIPANT	\N	PRESENT	0
510875	502338	08017T	PARTICIPANT	\N	PRESENT	0
510876	502338	14109K	PARTICIPANT	\N	PRESENT	0
510877	502338	19651A	PARTICIPANT	\N	PRESENT	0
510878	502338	19699S	PARTICIPANT	\N	PRESENT	0
510879	502338	20152B	PARTICIPANT	\N	PRESENT	0
510880	502338	19399H	PARTICIPANT	\N	PRESENT	0
510881	502338	19533U	PARTICIPANT	\N	PRESENT	0
510882	502338	20056C	PARTICIPANT	\N	PRESENT	0
510883	502338	20026V	PARTICIPANT	\N	PRESENT	0
510884	502338	20044X	PARTICIPANT	\N	PRESENT	0
510885	502338	19573D	PARTICIPANT	\N	PRESENT	0
510886	502338	92040Q	PARTICIPANT	\N	PRESENT	0
510887	502338	19693L	PARTICIPANT	\N	PRESENT	0
510888	502338	19581D	PARTICIPANT	\N	PRESENT	0
510889	502338	08015R	PARTICIPANT	\N	PRESENT	0
510890	502338	20090E	PARTICIPANT	\N	PRESENT	0
510891	502338	20034V	PARTICIPANT	\N	PRESENT	0
510892	502338	20134Y	PARTICIPANT	\N	PRESENT	0
510893	502338	19719D	PARTICIPANT	\N	PRESENT	0
510894	502338	20132W	PARTICIPANT	\N	PRESENT	0
510895	502338	20124W	PARTICIPANT	\N	PRESENT	0
510896	502338	07033P	PARTICIPANT	\N	PRESENT	0
510897	502338	19643A	PARTICIPANT	\N	PRESENT	0
510898	502338	19713W	PARTICIPANT	\N	PRESENT	0
510899	502338	14187A	PARTICIPANT	\N	PRESENT	0
510900	502338	20142Y	PARTICIPANT	\N	PRESENT	0
510901	502338	20126Y	PARTICIPANT	\N	PRESENT	0
510902	502338	20136B	PARTICIPANT	\N	PRESENT	0
510903	502338	19621T	PARTICIPANT	\N	PRESENT	0
510904	502338	20052X	PARTICIPANT	\N	PRESENT	0
510905	502338	98022P	PARTICIPANT	\N	PRESENT	0
510906	502338	20048C	PARTICIPANT	\N	PRESENT	0
510907	502338	11043H	PARTICIPANT	\N	PRESENT	0
510908	502338	20140W	PARTICIPANT	\N	PRESENT	0
510909	502338	19747H	PARTICIPANT	\N	PRESENT	0
510910	502338	19741B	PARTICIPANT	\N	PRESENT	0
510911	502338	01057W	PARTICIPANT	\N	PRESENT	0
510912	502338	14147R	PARTICIPANT	\N	PRESENT	0
510913	502338	20082E	PARTICIPANT	\N	PRESENT	0
510914	502338	20112S	PARTICIPANT	\N	PRESENT	0
510862	502338	08073C	PARTICIPANT	\N	PRESENT	0
510863	502338	11074Q	PARTICIPANT	\N	PRESENT	0
510915	502338	14071N	PARTICIPANT	\N	PRESENT	0
510916	502338	19739H	PARTICIPANT	\N	PRESENT	0
510917	502338	08061X	PARTICIPANT	\N	PRESENT	0
510918	502338	14083S	PARTICIPANT	\N	PRESENT	0
510919	502338	20120S	PARTICIPANT	\N	PRESENT	0
510927	502342	14026U	PARTICIPANT	\N	PRESENT	0
510928	509964	14327T	PARTICIPANT	\N	PRESENT	0
510929	509964	14083S	PARTICIPANT	\N	PRESENT	0
510930	509964	11048N	PARTICIPANT	\N	PRESENT	0
510931	509964	08034U	PARTICIPANT	\N	PRESENT	0
510932	509964	12016W	PARTICIPANT	\N	PRESENT	0
510933	509964	14225N	PRESIDENT	0	PRESENT	0
510934	509964	19671E	PARTICIPANT	\N	PRESENT	0
510935	509964	19762G	PARTICIPANT	\N	PRESENT	0
510936	509964	20044X	PARTICIPANT	\N	PRESENT	0
510937	509964	20126Y	PARTICIPANT	\N	PRESENT	0
510938	509964	08009T	PARTICIPANT	\N	PRESENT	0
510939	509964	19711U	PARTICIPANT	\N	PRESENT	0
510940	509964	01048V	PARTICIPANT	\N	PRESENT	0
510941	509964	04086Q	PARTICIPANT	\N	PRESENT	0
510942	509964	01057W	PARTICIPANT	\N	PRESENT	0
510943	509964	19349W	PARTICIPANT	\N	PRESENT	0
510944	509964	19531S	PARTICIPANT	\N	PRESENT	0
510945	509964	07029T	PARTICIPANT	\N	EXCUSE	0
510946	509964	08010L	PARTICIPANT	\N	PRESENT	0
510947	509964	11053K	PARTICIPANT	\N	PRESENT	0
510948	502342	20090E	PARTICIPANT	\N	PRESENT	0
510949	502342	19657G	PARTICIPANT	\N	PRESENT	0
510950	502342	19619A	PARTICIPANT	\N	PRESENT	0
510951	502342	20028X	PARTICIPANT	\N	PRESENT	0
510952	502342	20020P	PARTICIPANT	\N	PRESENT	0
510953	502342	14357A	PARTICIPANT	\N	PRESENT	0
510954	502342	08073C	PARTICIPANT	\N	PRESENT	0
510955	502342	20024T	PARTICIPANT	\N	PRESENT	0
510956	502342	20124W	PARTICIPANT	\N	PRESENT	0
510957	502342	04045F	PARTICIPANT	\N	PRESENT	0
510960	502342	19679N	PARTICIPANT	\N	PRESENT	0
510961	502342	19685L	PARTICIPANT	\N	PRESENT	0
510962	502342	14147R	PARTICIPANT	\N	PRESENT	0
510963	502342	20032T	PARTICIPANT	\N	PRESENT	0
510964	502342	01060R	PARTICIPANT	\N	PRESENT	0
510965	502342	14031R	PARTICIPANT	\N	PRESENT	0
510966	502342	01048V	PARTICIPANT	\N	PRESENT	0
510967	502342	19611R	PARTICIPANT	\N	PRESENT	0
510968	502342	19758L	PARTICIPANT	\N	PRESENT	0
510969	502342	11054L	PARTICIPANT	\N	PRESENT	0
510970	502342	19399H	PARTICIPANT	\N	PRESENT	0
510971	502342	11066Q	PARTICIPANT	\N	PRESENT	0
510972	502342	98022P	PARTICIPANT	\N	PRESENT	0
510974	510973	14041T	PARTICIPANT	\N	PRESENT	0
510975	510973	08018U	PARTICIPANT	\N	PRESENT	0
510976	510973	11026G	PARTICIPANT	\N	PRESENT	0
510977	502342	14267Y	PARTICIPANT	\N	PRESENT	0
510978	502342	19581D	PARTICIPANT	\N	PRESENT	0
510979	502342	14207L	PARTICIPANT	\N	PRESENT	0
510980	502342	19527W	PARTICIPANT	\N	PRESENT	0
510981	502342	19335Q	PARTICIPANT	\N	PRESENT	0
510982	502342	19565D	PARTICIPANT	\N	PRESENT	0
510983	502342	19599P	PARTICIPANT	\N	PRESENT	0
510984	502342	10015M	PARTICIPANT	\N	PRESENT	0
510985	502342	19383Y	PARTICIPANT	\N	PRESENT	0
483268	483267	04040A	PRESIDENT	0	PRESENT	0
483269	483267	14071N	PARTICIPANT	\N	EXCUSE	0
484793	484566	14097Y	PARTICIPANT	\N	PRESENT	0
484794	484566	12041X	PARTICIPANT	\N	PRESENT	0
484795	484566	01062T	PARTICIPANT	\N	PRESENT	0
484796	484566	04040A	PARTICIPANT	\N	PRESENT	0
484797	484566	01058X	PARTICIPANT	\N	PRESENT	0
484798	484566	11027H	PARTICIPANT	\N	PRESENT	0
484799	484566	04042C	PRESIDENT	0	PRESENT	0
484800	484566	14028W	PARTICIPANT	\N	PRESENT	0
484801	484566	11066Q	PARTICIPANT	\N	PRESENT	0
484802	484566	11115U	PARTICIPANT	\N	PRESENT	0
484803	484566	19421M	PARTICIPANT	\N	PRESENT	0
484804	484566	19709B	PARTICIPANT	\N	PRESENT	0
484805	484566	14267Y	PARTICIPANT	\N	PRESENT	0
484806	484566	14255U	PARTICIPANT	\N	PRESENT	0
484807	484747	14041T	PARTICIPANT	\N	PRESENT	0
484808	484747	14021P	PARTICIPANT	\N	PRESENT	0
484809	484747	14179A	PARTICIPANT	\N	PRESENT	0
484810	484747	19629C	PARTICIPANT	\N	EXCUSE	0
484811	484747	08018U	PARTICIPANT	\N	EXCUSE	0
484814	484566	95067Q	PARTICIPANT	\N	PRESENT	0
484815	484566	11041F	PARTICIPANT	\N	PRESENT	0
484816	484747	14069U	PARTICIPANT	\N	PRESENT	0
484817	484747	11085T	PARTICIPANT	\N	PRESENT	0
484819	484559	14237S	PARTICIPANT	\N	PRESENT	0
484820	484559	18083K	PARTICIPANT	\N	PRESENT	0
484821	484559	14031R	PRESIDENT	0	PRESENT	0
484822	484559	19503N	PARTICIPANT	\N	PRESENT	0
484823	484559	19387D	PARTICIPANT	\N	PRESENT	0
484824	484559	19599P	PARTICIPANT	\N	PRESENT	0
484825	484559	19794Q	PARTICIPANT	\N	PRESENT	0
484826	484559	19826F	PARTICIPANT	\N	PRESENT	0
484827	484559	19701S	PARTICIPANT	\N	PRESENT	0
484828	484559	19347U	PARTICIPANT	\N	PRESENT	0
484829	484559	14219Q	PARTICIPANT	\N	PRESENT	0
484871	484558	14034U	PARTICIPANT	\N	PRESENT	0
484903	484555	86034E	PARTICIPANT	\N	PRESENT	0
484911	484555	11033F	PARTICIPANT	\N	PRESENT	0
484912	484555	19593H	PARTICIPANT	\N	PRESENT	0
484913	484555	95063L	PARTICIPANT	\N	PRESENT	0
484914	484555	04045F	PARTICIPANT	\N	PRESENT	0
484915	484555	19543W	PARTICIPANT	\N	PRESENT	0
484916	484555	19651A	PARTICIPANT	\N	PRESENT	0
484917	484555	19697Q	PARTICIPANT	\N	PRESENT	0
484918	484555	04057K	PARTICIPANT	\N	PRESENT	0
484919	484555	19585H	PARTICIPANT	\N	PRESENT	0
484920	484555	19563B	PARTICIPANT	\N	PRESENT	0
484921	484555	14055N	PARTICIPANT	\N	PRESENT	0
484922	484555	19731Y	PARTICIPANT	\N	PRESENT	0
484923	484555	11072N	PARTICIPANT	\N	PRESENT	0
484924	484555	11012A	PARTICIPANT	\N	PRESENT	0
484925	484555	19387D	PARTICIPANT	\N	PRESENT	0
484926	484555	11074Q	PARTICIPANT	\N	PRESENT	0
484927	484555	04059M	PARTICIPANT	\N	PRESENT	0
484928	484555	08055A	PARTICIPANT	\N	PRESENT	0
484929	484555	14229S	PARTICIPANT	\N	PRESENT	0
484930	484555	08052W	PARTICIPANT	\N	PRESENT	0
484931	484555	19591F	PARTICIPANT	\N	PRESENT	0
484932	484555	19912C	PARTICIPANT	\N	PRESENT	0
484933	484555	19669L	PARTICIPANT	\N	PRESENT	0
484934	484555	08011M	PARTICIPANT	\N	PRESENT	0
484935	484555	14021P	PARTICIPANT	\N	PRESENT	0
484936	484555	19599P	PARTICIPANT	\N	PRESENT	0
484937	484555	19715Y	PARTICIPANT	\N	PRESENT	0
484938	484555	14151M	PARTICIPANT	\N	PRESENT	0
484939	484555	99004R	PARTICIPANT	\N	PRESENT	0
484940	484555	01062T	PARTICIPANT	\N	PRESENT	0
484941	484555	95030B	PARTICIPANT	\N	PRESENT	0
484942	484555	19689Q	PARTICIPANT	\N	PRESENT	0
484943	484555	04047H	PARTICIPANT	\N	PRESENT	0
484944	484555	14028W	PARTICIPANT	\N	PRESENT	0
484945	484555	04044E	PARTICIPANT	\N	PRESENT	0
484946	484555	12016W	PARTICIPANT	\N	PRESENT	0
484947	484555	11066Q	PARTICIPANT	\N	PRESENT	0
484948	484555	04092N	PARTICIPANT	\N	PRESENT	0
484949	484555	04086Q	PARTICIPANT	\N	PRESENT	0
484950	484555	08043V	PARTICIPANT	\N	PRESENT	0
484951	484555	11045K	PARTICIPANT	\N	PRESENT	0
484952	484555	04042C	PARTICIPANT	\N	PRESENT	0
484953	484555	19649G	PARTICIPANT	\N	PRESENT	0
484954	484555	19926J	PARTICIPANT	\N	PRESENT	0
484955	484555	14093U	PARTICIPANT	\N	PRESENT	0
484956	484555	08039A	PARTICIPANT	\N	PRESENT	0
484957	484555	14081Q	PARTICIPANT	\N	PRESENT	0
484958	484555	19525U	PARTICIPANT	\N	PRESENT	0
484959	484555	14085U	PARTICIPANT	\N	PRESENT	0
484960	484555	19549D	PARTICIPANT	\N	PRESENT	0
484961	484555	04043D	PARTICIPANT	\N	PRESENT	0
484962	484555	19333N	PARTICIPANT	\N	PRESENT	0
484963	484555	19683J	PARTICIPANT	\N	PRESENT	0
484964	484555	11109J	PARTICIPANT	\N	PRESENT	0
484965	484555	19295A	PARTICIPANT	\N	PRESENT	0
484966	484555	15447F	PARTICIPANT	\N	PRESENT	0
484967	484555	19695N	PARTICIPANT	\N	PRESENT	0
484968	484555	19347U	PARTICIPANT	\N	PRESENT	0
484969	484555	19643A	PARTICIPANT	\N	PRESENT	0
484970	484555	19413M	PARTICIPANT	\N	PRESENT	0
484971	484555	19631V	PARTICIPANT	\N	PRESENT	0
484972	484555	14225N	PARTICIPANT	\N	PRESENT	0
484973	484555	11067R	PARTICIPANT	\N	PRESENT	0
484974	484555	11080N	PARTICIPANT	\N	PRESENT	0
484975	484555	19503N	PARTICIPANT	\N	PRESENT	0
484976	484555	19251M	PARTICIPANT	\N	PRESENT	0
484977	484555	95067Q	PARTICIPANT	\N	PRESENT	0
484978	484555	12041X	PARTICIPANT	\N	PRESENT	0
484979	484555	14187A	PARTICIPANT	\N	PRESENT	0
484980	484555	05008E	PARTICIPANT	\N	PRESENT	0
484981	484555	19421M	PARTICIPANT	\N	PRESENT	0
484982	484555	14087W	PARTICIPANT	\N	PRESENT	0
484983	484555	14042U	PARTICIPANT	\N	PRESENT	0
484984	484555	14069U	PARTICIPANT	\N	PRESENT	0
484985	484555	14219Q	PARTICIPANT	\N	PRESENT	0
484986	484555	11090Q	PARTICIPANT	\N	PRESENT	0
484987	484555	87003B	PARTICIPANT	\N	PRESENT	0
484988	484555	19479G	PARTICIPANT	\N	PRESENT	0
484989	484555	01057W	PARTICIPANT	\N	PRESENT	0
484990	484555	19441R	PARTICIPANT	\N	PRESENT	0
484991	484555	19766L	PARTICIPANT	\N	PRESENT	0
484992	484555	19739H	PARTICIPANT	\N	PRESENT	0
484993	484555	19515S	PARTICIPANT	\N	PRESENT	0
484994	484555	19673G	PARTICIPANT	\N	PRESENT	0
484995	484555	11053K	PARTICIPANT	\N	PRESENT	0
484996	484555	19667J	PARTICIPANT	\N	PRESENT	0
484997	484555	19930E	PARTICIPANT	\N	PRESENT	0
484998	484555	11048N	PARTICIPANT	\N	PRESENT	0
484999	484555	05012A	PARTICIPANT	\N	PRESENT	0
485000	484555	19533U	PARTICIPANT	\N	PRESENT	0
485001	484555	14079W	PARTICIPANT	\N	PRESENT	0
485002	484555	19369B	PARTICIPANT	\N	PRESENT	0
485003	484555	14331P	PARTICIPANT	\N	PRESENT	0
485004	484555	19691J	PARTICIPANT	\N	PRESENT	0
485005	484555	19671E	PARTICIPANT	\N	PRESENT	0
485006	484555	19762G	PARTICIPANT	\N	PRESENT	0
485007	484555	14179A	PARTICIPANT	\N	PRESENT	0
485008	484555	14357A	PARTICIPANT	\N	PRESENT	0
485009	484555	19701S	PARTICIPANT	\N	PRESENT	0
485010	484555	14030Q	PARTICIPANT	\N	PRESENT	0
485011	484555	01024M	PARTICIPANT	\N	PRESENT	0
485012	484555	14327T	PARTICIPANT	\N	PRESENT	0
485013	484555	14329V	PARTICIPANT	\N	PRESENT	0
485014	484555	19693L	PARTICIPANT	\N	PRESENT	0
485015	484555	11085T	PARTICIPANT	\N	PRESENT	0
485016	484555	04070G	PARTICIPANT	\N	PRESENT	0
485017	484555	14255U	PARTICIPANT	\N	PRESENT	0
485018	484555	14119M	PARTICIPANT	\N	PRESENT	0
485019	484555	14083S	PARTICIPANT	\N	PRESENT	0
485020	484555	14033T	PARTICIPANT	\N	PRESENT	0
485021	484555	19399H	PARTICIPANT	\N	PRESENT	0
485022	484555	19749K	PARTICIPANT	\N	PRESENT	0
485023	484555	19467C	PARTICIPANT	\N	PRESENT	0
485024	484555	19335Q	PARTICIPANT	\N	PRESENT	0
485025	484555	19794Q	PARTICIPANT	\N	PRESENT	0
485026	484555	19447X	PARTICIPANT	\N	PRESENT	0
485027	484555	19741B	PARTICIPANT	\N	PRESENT	0
485028	484555	04088S	PARTICIPANT	\N	PRESENT	0
485029	484555	14133K	PARTICIPANT	\N	PRESENT	0
485030	484555	19954N	PARTICIPANT	\N	PRESENT	0
485035	484555	17583W	PARTICIPANT	\N	PRESENT	0
485032	484555	04018C	PARTICIPANT	\N	PRESENT	0
485033	484555	11110B	PARTICIPANT	\N	PRESENT	0
485034	484555	14034U	PARTICIPANT	\N	PRESENT	0
485036	484555	01058X	PARTICIPANT	\N	PRESENT	0
485037	484555	11097X	PARTICIPANT	\N	PRESENT	0
485038	484555	19621T	PARTICIPANT	\N	PRESENT	0
485039	484555	14217N	PARTICIPANT	\N	PRESENT	0
485040	484555	14193X	PARTICIPANT	\N	PRESENT	0
485041	484555	18083K	PARTICIPANT	\N	PRESENT	0
485042	484555	19709B	PARTICIPANT	\N	PRESENT	0
503821	503264	11027H	PARTICIPANT	\N	PRESENT	0
503686	503264	04085P	PARTICIPANT	\N	PRESENT	0
503699	503264	20118Y	PARTICIPANT	\N	PRESENT	0
503690	503264	20128B	PARTICIPANT	\N	PRESENT	0
503693	503264	20072C	PARTICIPANT	\N	PRESENT	0
503696	503264	19719D	PARTICIPANT	\N	PRESENT	0
503697	503264	19629C	PARTICIPANT	\N	PRESENT	0
503698	503264	19553Y	PARTICIPANT	\N	PRESENT	0
503823	503264	19866P	PARTICIPANT	\N	PRESENT	0
503703	503264	19671E	PARTICIPANT	\N	PRESENT	0
503819	503264	19669L	PARTICIPANT	\N	PRESENT	0
503706	503264	14053L	PARTICIPANT	\N	PRESENT	0
503708	503264	14207L	PARTICIPANT	\N	PRESENT	0
503709	503264	19798U	PARTICIPANT	\N	PRESENT	0
503711	503264	19387D	PARTICIPANT	\N	PRESENT	0
503713	503264	19717B	PARTICIPANT	\N	PRESENT	0
503715	503264	19533U	PARTICIPANT	\N	PRESENT	0
503716	503264	19563B	PARTICIPANT	\N	PRESENT	0
503720	503264	20150Y	PARTICIPANT	\N	PRESENT	0
503721	503264	20024T	PARTICIPANT	\N	PRESENT	0
503722	503264	19713W	PARTICIPANT	\N	PRESENT	0
503723	503264	14059S	PARTICIPANT	\N	PRESENT	0
503725	503264	19479G	PARTICIPANT	\N	PRESENT	0
503726	503264	19489J	PARTICIPANT	\N	PRESENT	0
503727	503264	19383Y	PARTICIPANT	\N	PRESENT	0
503729	503264	19699S	PARTICIPANT	\N	PRESENT	0
503730	503264	20124W	PARTICIPANT	\N	PRESENT	0
503734	503264	19335Q	PARTICIPANT	\N	PRESENT	0
503735	503264	19762G	PARTICIPANT	\N	PRESENT	0
503736	503264	20126Y	PARTICIPANT	\N	PRESENT	0
503737	503264	17589D	PARTICIPANT	\N	PRESENT	0
503738	503264	14133K	PARTICIPANT	\N	PRESENT	0
503739	503264	14275Y	PARTICIPANT	\N	PRESENT	0
503740	503264	04059M	PARTICIPANT	\N	PRESENT	0
503741	503264	19739H	PARTICIPANT	\N	PRESENT	0
503743	503264	19549D	PARTICIPANT	\N	PRESENT	0
503744	503264	19367Y	PARTICIPANT	\N	PRESENT	0
503745	503264	19421M	PARTICIPANT	\N	PRESENT	0
503746	503264	08034U	PARTICIPANT	\N	PRESENT	0
503747	503264	19723Y	PARTICIPANT	\N	PRESENT	0
503748	503264	20034V	PARTICIPANT	\N	PRESENT	0
503749	503264	14231L	PARTICIPANT	\N	PRESENT	0
503750	503742	20034V	PARTICIPANT	\N	PRESENT	0
503751	503264	19745F	PARTICIPANT	\N	PRESENT	0
503752	503264	14179A	PARTICIPANT	\N	PRESENT	0
503753	503264	20066E	PARTICIPANT	\N	PRESENT	0
503754	503700	20034V	PARTICIPANT	\N	PRESENT	0
503755	503264	20132W	PARTICIPANT	\N	PRESENT	0
503756	503264	19826F	PARTICIPANT	\N	PRESENT	0
503757	503702	20034V	PARTICIPANT	\N	PRESENT	0
503758	503264	07029T	PARTICIPANT	\N	PRESENT	0
503759	503264	19657G	PARTICIPANT	\N	PRESENT	0
503760	503264	08015R	PARTICIPANT	\N	PRESENT	0
503761	503264	14147R	PARTICIPANT	\N	PRESENT	0
503762	503264	19741B	PARTICIPANT	\N	PRESENT	0
503763	503264	14041T	PARTICIPANT	\N	PRESENT	0
503764	503704	20034V	PARTICIPANT	\N	PRESENT	0
503765	503264	20058E	PARTICIPANT	\N	PRESENT	0
503766	503264	11103C	PARTICIPANT	\N	PRESENT	0
503767	503264	20056C	PARTICIPANT	\N	PRESENT	0
503768	503264	14357A	PARTICIPANT	\N	PRESENT	0
503769	503264	20098N	PARTICIPANT	\N	PRESENT	0
503770	503264	14217N	PARTICIPANT	\N	PRESENT	0
503771	503264	14038Y	PARTICIPANT	\N	PRESENT	0
503772	503264	14229S	PARTICIPANT	\N	PRESENT	0
503773	503264	19675J	PARTICIPANT	\N	PRESENT	0
503774	503264	20044X	PARTICIPANT	\N	PRESENT	0
503775	503264	11085T	PARTICIPANT	\N	PRESENT	0
503776	503264	19543W	PARTICIPANT	\N	PRESENT	0
503777	503264	14213J	PARTICIPANT	\N	PRESENT	0
503781	503264	04033B	PARTICIPANT	\N	PRESENT	0
503779	503264	19729F	PARTICIPANT	\N	PRESENT	0
503780	503264	19507S	PARTICIPANT	\N	PRESENT	0
503782	503264	19527W	PARTICIPANT	\N	PRESENT	0
503783	503264	20026V	PARTICIPANT	\N	PRESENT	0
503784	503264	14249W	PARTICIPANT	\N	PRESENT	0
503785	503264	19447X	PARTICIPANT	\N	PRESENT	0
503786	503264	11012A	PARTICIPANT	\N	PRESENT	0
503787	503264	01057W	PARTICIPANT	\N	PRESENT	0
503810	503264	19647E	PARTICIPANT	\N	PRESENT	0
503789	503264	20090E	PARTICIPANT	\N	PRESENT	0
503790	503264	14055N	PARTICIPANT	\N	PRESENT	0
503792	503264	19768N	PARTICIPANT	\N	PRESENT	0
503793	503264	19709B	PARTICIPANT	\N	PRESENT	0
503795	503264	04043D	PARTICIPANT	\N	PRESENT	0
503796	503264	19573D	PARTICIPANT	\N	PRESENT	0
503797	503707	20034V	PARTICIPANT	\N	PRESENT	0
503798	503264	20068G	PARTICIPANT	\N	PRESENT	0
503799	503264	19691J	PARTICIPANT	\N	PRESENT	0
503800	503264	20172F	PARTICIPANT	\N	PRESENT	0
503801	503264	19820Y	PARTICIPANT	\N	PRESENT	0
503802	503710	20034V	PARTICIPANT	\N	PRESENT	0
503803	503264	14001X	PARTICIPANT	\N	PRESENT	0
503804	503264	04057K	PARTICIPANT	\N	PRESENT	0
503807	503264	20112S	PARTICIPANT	\N	PRESENT	0
503808	503264	20108W	PARTICIPANT	\N	PRESENT	0
503809	503264	19399H	PARTICIPANT	\N	PRESENT	0
503811	503264	19966S	PARTICIPANT	\N	PRESENT	0
503812	503264	20038A	PARTICIPANT	\N	PRESENT	0
503813	503264	97011G	PARTICIPANT	\N	PRESENT	0
503814	503264	20020P	PARTICIPANT	\N	PRESENT	0
503815	503264	14089Y	PARTICIPANT	\N	PRESENT	0
503816	503264	20140W	PARTICIPANT	\N	PRESENT	0
503817	503264	11072N	PARTICIPANT	\N	PRESENT	0
503818	503264	11040E	PARTICIPANT	\N	PRESENT	0
503820	503264	14097Y	PARTICIPANT	\N	PRESENT	0
503822	503264	14237S	PARTICIPANT	\N	PRESENT	0
503824	503264	14151M	PARTICIPANT	\N	PRESENT	0
503825	503264	14123H	PARTICIPANT	\N	PRESENT	0
503826	503264	19565D	PARTICIPANT	\N	PRESENT	0
503827	503264	20032T	PARTICIPANT	\N	PRESENT	0
503828	503264	20054A	PARTICIPANT	\N	PRESENT	0
503829	503264	19735D	PARTICIPANT	\N	PRESENT	0
503830	503264	19663E	PARTICIPANT	\N	PRESENT	0
503831	503264	20062A	PARTICIPANT	\N	PRESENT	0
503832	503264	14215L	PARTICIPANT	\N	PRESENT	0
503833	503264	20104S	PARTICIPANT	\N	PRESENT	0
503834	503264	19551W	PARTICIPANT	\N	PRESENT	0
503835	503264	19441R	PARTICIPANT	\N	PRESENT	0
503836	503264	20148F	PARTICIPANT	\N	PRESENT	0
503837	503264	20076G	PARTICIPANT	\N	PRESENT	0
503838	503264	08056B	PARTICIPANT	\N	PRESENT	0
503839	503264	01024M	PARTICIPANT	\N	PRESENT	0
503840	503264	19369B	PARTICIPANT	\N	PRESENT	0
503841	503264	20110Q	PARTICIPANT	\N	PRESENT	0
503842	503264	20078J	PARTICIPANT	\N	PRESENT	0
503843	503264	11070L	PARTICIPANT	\N	PRESENT	0
503844	503264	19467C	PARTICIPANT	\N	PRESENT	0
503847	503264	20138D	PARTICIPANT	\N	PRESENT	0
503848	503264	19687N	PARTICIPANT	\N	PRESENT	0
503849	503264	19251M	PARTICIPANT	\N	PRESENT	0
503850	503264	11026G	PARTICIPANT	\N	PRESENT	0
504067	501818	19719D	PARTICIPANT	\N	PRESENT	0
504068	502448	19647E	PARTICIPANT	\N	PRESENT	0
504069	502448	19531S	PARTICIPANT	\N	PRESENT	0
504070	502448	20080C	PARTICIPANT	\N	PRESENT	0
504071	502448	20044X	PARTICIPANT	\N	PRESENT	0
504072	502448	19671E	PARTICIPANT	\N	PRESENT	0
504073	502448	14225N	PRESIDENT	0	PRESENT	0
504074	502448	04086Q	PARTICIPANT	\N	PRESENT	0
504075	502448	19507S	PARTICIPANT	\N	PRESENT	0
504076	502448	20070A	PARTICIPANT	\N	PRESENT	0
504077	502448	96004D	PARTICIPANT	\N	PRESENT	0
504078	502448	19741B	PARTICIPANT	\N	PRESENT	0
504079	502448	14121F	PARTICIPANT	\N	PRESENT	0
504080	502448	08010L	PARTICIPANT	\N	PRESENT	0
504081	502448	19762G	PARTICIPANT	\N	PRESENT	0
504083	502448	19335Q	PARTICIPANT	\N	PRESENT	0
504086	501818	19349W	PARTICIPANT	\N	PRESENT	0
504087	501818	19637C	PARTICIPANT	\N	PRESENT	0
504088	501818	20128B	PARTICIPANT	\N	PRESENT	0
504089	501818	14207L	PARTICIPANT	\N	PRESENT	0
504090	501818	20018V	PARTICIPANT	\N	PRESENT	0
504092	501818	20110Q	PARTICIPANT	\N	PRESENT	0
504094	501818	11099A	PARTICIPANT	\N	PRESENT	0
504095	501818	19725B	PARTICIPANT	\N	PRESENT	0
504096	501818	19820Y	PARTICIPANT	\N	PRESENT	0
504097	501818	19565D	PARTICIPANT	\N	PRESENT	0
504098	501818	19758L	PARTICIPANT	\N	PRESENT	0
504099	501818	11056N	PARTICIPANT	\N	PRESENT	0
504100	501818	14097Y	PARTICIPANT	\N	PRESENT	0
486062	485907	14061L	PARTICIPANT	\N	EXCUSE	0
490478	489907	99004R	PARTICIPANT	\N	PRESENT	0
490479	489907	19667J	PARTICIPANT	\N	PRESENT	0
490480	489907	04086Q	PARTICIPANT	\N	PRESENT	0
490481	489907	04071H	PARTICIPANT	\N	PRESENT	0
490482	489907	11053K	PARTICIPANT	\N	PRESENT	0
490483	489907	19711U	PARTICIPANT	\N	PRESENT	0
490484	489907	19647E	PARTICIPANT	\N	PRESENT	0
491051	491050	14331P	PARTICIPANT	\N	PRESENT	0
492317	492316	11053K	PARTICIPANT	\N	PRESENT	0
492318	492316	19545Y	PARTICIPANT	\N	PRESENT	0
492319	492316	19687N	PARTICIPANT	\N	PRESENT	0
492320	492316	99004R	PARTICIPANT	\N	PRESENT	0
492321	492316	11074Q	PARTICIPANT	\N	PRESENT	0
492322	492316	19711U	PARTICIPANT	\N	PRESENT	0
492329	492316	19671E	PARTICIPANT	\N	PRESENT	0
492330	492316	04071H	PARTICIPANT	\N	PRESENT	0
492331	492316	19647E	PARTICIPANT	\N	PRESENT	0
492332	492316	11070L	PARTICIPANT	\N	PRESENT	0
492420	491472	11053K	PARTICIPANT	\N	PRESENT	0
492426	491472	11074Q	PARTICIPANT	\N	PRESENT	0
492427	491472	11110B	PARTICIPANT	\N	PRESENT	0
492428	491472	14121F	PARTICIPANT	\N	PRESENT	0
492429	491472	20150Y	PARTICIPANT	\N	PRESENT	0
492430	491472	20044X	PARTICIPANT	\N	PRESENT	0
492431	491472	19762G	PARTICIPANT	\N	PRESENT	0
492432	491472	19479G	PARTICIPANT	\N	PRESENT	0
493412	493365	19725B	PARTICIPANT	\N	PRESENT	0
493413	493365	20108W	PARTICIPANT	\N	PRESENT	0
493414	493365	14107H	PARTICIPANT	\N	PRESENT	0
493415	493365	11026G	PARTICIPANT	\N	PRESENT	0
493416	493365	14215L	PARTICIPANT	\N	PRESENT	0
493417	493365	08018U	PARTICIPANT	\N	PRESENT	0
493418	493365	04047H	PRESIDENT	0	PRESENT	0
493419	493365	19673G	PARTICIPANT	\N	PRESENT	0
493420	493365	01028R	PARTICIPANT	\N	PRESENT	0
493421	493365	19447X	PARTICIPANT	\N	PRESENT	0
493422	493365	05008E	PARTICIPANT	\N	PRESENT	0
493432	493355	05008E	PARTICIPANT	\N	PRESENT	0
493424	493355	99004R	PARTICIPANT	\N	PRESENT	0
493426	493355	11080N	PARTICIPANT	\N	PRESENT	0
493428	493355	19711U	PARTICIPANT	\N	PRESENT	0
493429	493355	19673G	PARTICIPANT	\N	PRESENT	0
493430	493355	19447X	PARTICIPANT	\N	PRESENT	0
493431	493355	17637T	PARTICIPANT	\N	PRESENT	0
493433	493355	20034V	PARTICIPANT	\N	PRESENT	0
493434	493355	14041T	PARTICIPANT	\N	PRESENT	0
493435	493355	19599P	PARTICIPANT	\N	PRESENT	0
493436	493355	11026G	PARTICIPANT	\N	PRESENT	0
493437	493355	19649G	PARTICIPANT	\N	PRESENT	0
493438	493355	08069G	PARTICIPANT	\N	PRESENT	0
493439	493355	14231L	PARTICIPANT	\N	PRESENT	0
493440	493355	01028R	PARTICIPANT	\N	PRESENT	0
493441	493355	07004J	PARTICIPANT	\N	PRESENT	0
493442	493355	14021P	PARTICIPANT	\N	PRESENT	0
493443	493355	19347U	PARTICIPANT	\N	PRESENT	0
493444	493355	14215L	PARTICIPANT	\N	PRESENT	0
493445	493355	08073C	PARTICIPANT	\N	PRESENT	0
493446	493355	04085P	PARTICIPANT	\N	PRESENT	0
493447	493355	11031D	PARTICIPANT	\N	PRESENT	0
493448	493355	14107H	PARTICIPANT	\N	PRESENT	0
493449	493355	19565D	PARTICIPANT	\N	PRESENT	0
493450	493355	14251Q	PARTICIPANT	\N	PRESENT	0
493451	493355	14111D	PARTICIPANT	\N	PRESENT	0
493452	493355	11101A	PARTICIPANT	\N	PRESENT	0
493453	493355	20108W	PARTICIPANT	\N	PRESENT	0
493454	493355	14255U	PARTICIPANT	\N	PRESENT	0
493455	493355	19543W	PARTICIPANT	\N	PRESENT	0
493456	493355	14055N	PARTICIPANT	\N	PRESENT	0
493457	493355	11085T	PARTICIPANT	\N	PRESENT	0
493458	493355	19719D	PARTICIPANT	\N	PRESENT	0
493459	493355	14187A	PARTICIPANT	\N	PRESENT	0
493460	493355	04033B	PARTICIPANT	\N	PRESENT	0
493461	493355	11103C	PARTICIPANT	\N	PRESENT	0
493462	493355	04047H	PARTICIPANT	\N	PRESENT	0
493463	493355	08018U	PARTICIPANT	\N	PRESENT	0
493464	493355	19573D	PARTICIPANT	\N	PRESENT	0
493465	493355	19581D	PARTICIPANT	\N	PRESENT	0
493466	493355	11072N	PARTICIPANT	\N	PRESENT	0
493467	493355	04042C	PARTICIPANT	\N	PRESENT	0
493468	493355	08061X	PARTICIPANT	\N	PRESENT	0
493469	493355	11033F	PARTICIPANT	\N	PRESENT	0
493470	493355	14073Q	PARTICIPANT	\N	PRESENT	0
493471	493355	11053K	PARTICIPANT	\N	PRESENT	0
493472	493355	19747H	PARTICIPANT	\N	PRESENT	0
493473	493355	14331P	PARTICIPANT	\N	PRESENT	0
494968	491185	20126Y	PARTICIPANT	\N	PRESENT	0
496935	495344	19693L	PARTICIPANT	\N	EXCUSE	0
496937	495344	11067R	PARTICIPANT	\N	EXCUSE	0
496938	495344	19735D	PARTICIPANT	\N	PRESENT	0
496939	495344	20066E	PARTICIPANT	\N	EXCUSE	0
500175	500174	19709B	PARTICIPANT	\N	PRESENT	0
500176	500174	11041F	PARTICIPANT	\N	PRESENT	0
500178	500177	19709B	PARTICIPANT	\N	PRESENT	0
500179	500177	11041F	PARTICIPANT	\N	PRESENT	0
500181	500180	19709B	PARTICIPANT	\N	PRESENT	0
500182	500180	11041F	PARTICIPANT	\N	PRESENT	0
500319	500318	20110Q	PARTICIPANT	\N	PRESENT	0
500321	500320	20110Q	PARTICIPANT	\N	PRESENT	0
500323	500322	20110Q	PARTICIPANT	\N	PRESENT	0
500325	500324	20110Q	PARTICIPANT	\N	PRESENT	0
500327	500326	20110Q	PARTICIPANT	\N	PRESENT	0
500329	500328	20110Q	PARTICIPANT	\N	PRESENT	0
502752	500288	19703U	PARTICIPANT	\N	PRESENT	0
502755	500288	19367Y	PARTICIPANT	\N	PRESENT	0
502759	500288	17737W	PARTICIPANT	\N	PRESENT	0
502760	500288	14281W	PARTICIPANT	\N	PRESENT	0
502761	500288	18193Q	PARTICIPANT	\N	PRESENT	0
502762	500288	14213J	PARTICIPANT	\N	PRESENT	0
502763	500288	11031D	PARTICIPANT	\N	PRESENT	0
502764	500288	11103C	PARTICIPANT	\N	PRESENT	0
502765	500288	19515S	PARTICIPANT	\N	PRESENT	0
502766	500288	19683J	PARTICIPANT	\N	PRESENT	0
502767	500288	11067R	PARTICIPANT	\N	PRESENT	0
502768	500288	17965H	PARTICIPANT	\N	PRESENT	0
502769	500288	19301E	PARTICIPANT	\N	PRESENT	0
502770	500288	19347U	PARTICIPANT	\N	PRESENT	0
502771	500288	19415P	PARTICIPANT	\N	PRESENT	0
502772	500288	07004J	PARTICIPANT	\N	PRESENT	0
502773	500288	20090E	PARTICIPANT	\N	PRESENT	0
502774	500288	20034V	PARTICIPANT	\N	PRESENT	0
502775	500288	19723Y	PARTICIPANT	\N	PRESENT	0
502776	500288	20152B	PARTICIPANT	\N	PRESENT	0
502777	500288	20126Y	PARTICIPANT	\N	PRESENT	0
502778	500288	14041T	PARTICIPANT	\N	PRESENT	0
502779	500288	04092N	PARTICIPANT	\N	PRESENT	0
502780	500288	20130U	PARTICIPANT	\N	PRESENT	0
502781	500288	14026U	PARTICIPANT	\N	PRESENT	0
502782	500288	19760E	PARTICIPANT	\N	PRESENT	0
502783	500288	12016W	PARTICIPANT	\N	PRESENT	0
502784	500288	14071N	PARTICIPANT	\N	PRESENT	0
502785	500288	14030Q	PARTICIPANT	\N	PRESENT	0
502786	500288	04057K	PARTICIPANT	\N	PRESENT	0
502787	500288	19715Y	PARTICIPANT	\N	PRESENT	0
502788	500288	19657G	PARTICIPANT	\N	PRESENT	0
502789	500288	14217N	PARTICIPANT	\N	PRESENT	0
502798	500288	19798U	PARTICIPANT	\N	PRESENT	0
502791	500288	19697Q	PARTICIPANT	\N	PRESENT	0
502792	500288	19673G	PARTICIPANT	\N	PRESENT	0
502793	500288	20086J	PARTICIPANT	\N	PRESENT	0
502794	500288	19553Y	PARTICIPANT	\N	PRESENT	0
502795	500288	17779H	PARTICIPANT	\N	PRESENT	0
502796	500288	10006L	PARTICIPANT	\N	PRESENT	0
502797	500288	11097X	PARTICIPANT	\N	PRESENT	0
502799	500288	19711U	PARTICIPANT	\N	PRESENT	0
502800	500288	19689Q	PARTICIPANT	\N	PRESENT	0
502801	500288	19531S	PARTICIPANT	\N	PRESENT	0
502802	500288	08045X	PARTICIPANT	\N	PRESENT	0
502803	500288	19591F	PARTICIPANT	\N	PRESENT	0
502804	500288	20148F	PARTICIPANT	\N	PRESENT	0
502805	500288	19679N	PARTICIPANT	\N	PRESENT	0
502806	500288	20052X	PARTICIPANT	\N	PRESENT	0
502807	500288	19649G	PARTICIPANT	\N	PRESENT	0
502749	500288	11070L	PARTICIPANT	\N	PRESENT	0
502751	500288	14042U	PARTICIPANT	\N	PRESENT	0
502808	500288	19575F	PARTICIPANT	\N	PRESENT	0
502809	500288	19569H	PARTICIPANT	\N	PRESENT	0
502811	500288	19687N	PARTICIPANT	\N	PRESENT	0
502812	500288	19599P	PARTICIPANT	\N	PRESENT	0
502814	500288	19691J	PARTICIPANT	\N	PRESENT	0
502817	500288	11045K	PARTICIPANT	\N	PRESENT	0
502821	500288	19663E	PARTICIPANT	\N	PRESENT	0
502825	500288	20098N	PARTICIPANT	\N	PRESENT	0
502827	500288	19713W	PARTICIPANT	\N	PRESENT	0
502828	500288	20066E	PARTICIPANT	\N	PRESENT	0
502839	500288	11077T	PARTICIPANT	\N	PRESENT	0
502844	500288	19717B	PARTICIPANT	\N	PRESENT	0
510986	502342	20136B	PARTICIPANT	\N	PRESENT	0
510997	502342	19441R	PARTICIPANT	\N	PRESENT	0
510988	502342	14069U	PARTICIPANT	\N	PRESENT	0
510989	502342	14083S	PARTICIPANT	\N	PRESENT	0
510990	502342	19693L	PARTICIPANT	\N	PRESENT	0
510991	502342	10006L	PARTICIPANT	\N	PRESENT	0
510992	502342	11027H	PARTICIPANT	\N	PRESENT	0
510993	502342	20142Y	PARTICIPANT	\N	PRESENT	0
510994	502342	11043H	PARTICIPANT	\N	PRESENT	0
510995	502342	17589D	PARTICIPANT	\N	PRESENT	0
510998	502342	14213J	PARTICIPANT	\N	PRESENT	0
510999	502342	14053L	PARTICIPANT	\N	PRESENT	0
511009	502343	20024T	PARTICIPANT	\N	PRESENT	0
511010	502343	14033T	PARTICIPANT	\N	PRESENT	0
511012	502343	19719D	PARTICIPANT	\N	PRESENT	0
511013	502343	19798U	PARTICIPANT	\N	PRESENT	0
511014	502343	20090E	PARTICIPANT	\N	PRESENT	0
511015	502343	14105F	PARTICIPANT	\N	PRESENT	0
511016	502343	19583F	PARTICIPANT	\N	PRESENT	0
511007	502343	01043Q	PARTICIPANT	\N	PRESENT	0
511008	502343	19511N	PARTICIPANT	\N	PRESENT	0
511017	502343	92040Q	PARTICIPANT	\N	PRESENT	0
511018	502343	20174H	PARTICIPANT	\N	PRESENT	0
511019	502343	14207L	PARTICIPANT	\N	PRESENT	0
511020	502343	19467C	PARTICIPANT	\N	PRESENT	0
511021	502343	20056C	PARTICIPANT	\N	PRESENT	0
511022	502343	11090Q	PARTICIPANT	\N	PRESENT	0
511023	502343	20076G	PARTICIPANT	\N	PRESENT	0
511024	502343	19569H	PARTICIPANT	\N	PRESENT	0
511025	502343	14193X	PARTICIPANT	\N	PRESENT	0
511026	502343	19399H	PARTICIPANT	\N	PRESENT	0
511027	502343	14329V	PARTICIPANT	\N	PRESENT	0
511028	502343	14231L	PARTICIPANT	\N	PRESENT	0
511029	502343	19503N	PARTICIPANT	\N	PRESENT	0
511030	502343	19593H	PARTICIPANT	\N	PRESENT	0
511031	502343	20132W	PARTICIPANT	\N	PRESENT	0
511032	502343	20032T	PARTICIPANT	\N	PRESENT	0
511033	502343	20172F	PARTICIPANT	\N	PRESENT	0
511034	502343	20044X	PARTICIPANT	\N	PRESENT	0
511035	502343	01025N	PARTICIPANT	\N	PRESENT	0
511036	502343	14205J	PARTICIPANT	\N	PRESENT	0
511037	502343	20142Y	PARTICIPANT	\N	PRESENT	0
511038	502343	19447X	PARTICIPANT	\N	PRESENT	0
511039	502343	08069G	PARTICIPANT	\N	PRESENT	0
511040	502343	19760E	PARTICIPANT	\N	PRESENT	0
511041	509563	19649G	PARTICIPANT	\N	PRESENT	0
511042	509563	10015M	PARTICIPANT	\N	PRESENT	0
511043	509563	11026G	PARTICIPANT	\N	PRESENT	0
511044	509563	04047H	PRESIDENT	0	PRESENT	0
511045	509563	19954N	PARTICIPANT	\N	PRESENT	0
511046	509563	19729F	PARTICIPANT	\N	PRESENT	0
511047	509563	19629C	PARTICIPANT	\N	PRESENT	0
511048	509563	14041T	PARTICIPANT	\N	PRESENT	0
511049	509563	14147R	PARTICIPANT	\N	PRESENT	0
511050	509563	14179A	PARTICIPANT	\N	PRESENT	0
511051	509563	14151M	PARTICIPANT	\N	PRESENT	0
511052	509563	14215L	PARTICIPANT	\N	PRESENT	0
511053	509563	08018U	PARTICIPANT	\N	PRESENT	0
511054	509563	19749K	PARTICIPANT	\N	PRESENT	0
511055	509563	04008A	PARTICIPANT	\N	PRESENT	0
511056	509563	11072N	PARTICIPANT	\N	PRESENT	0
511057	509563	14111D	PARTICIPANT	\N	PRESENT	0
511058	509563	19585H	PARTICIPANT	\N	PRESENT	0
511059	509563	05008E	PARTICIPANT	\N	PRESENT	0
511060	502343	19585H	PARTICIPANT	\N	PRESENT	0
511061	502343	19758L	PARTICIPANT	\N	PRESENT	0
511062	502343	14021P	PARTICIPANT	\N	PRESENT	0
511063	502343	01058X	PARTICIPANT	\N	PRESENT	0
511064	502343	19643A	PARTICIPANT	\N	PRESENT	0
511065	502343	19515S	PARTICIPANT	\N	PRESENT	0
511066	502343	20038A	PARTICIPANT	\N	PRESENT	0
511067	502343	04086Q	PARTICIPANT	\N	PRESENT	0
511068	502343	08010L	PARTICIPANT	\N	PRESENT	0
511069	502343	04033B	PARTICIPANT	\N	PRESENT	0
511070	502343	14071N	PARTICIPANT	\N	PRESENT	0
511071	502343	05008E	PARTICIPANT	\N	PRESENT	0
511072	502343	19711U	PARTICIPANT	\N	PRESENT	0
511073	502343	14053L	PARTICIPANT	\N	PRESENT	0
511074	502343	17737W	PARTICIPANT	\N	PRESENT	0
511075	502343	97011G	PARTICIPANT	\N	PRESENT	0
511076	502343	19673G	PARTICIPANT	\N	PRESENT	0
511077	502343	19667J	PARTICIPANT	\N	PRESENT	0
511078	502343	19573D	PARTICIPANT	\N	PRESENT	0
511079	502343	14038Y	PARTICIPANT	\N	PRESENT	0
511080	502343	19723Y	PARTICIPANT	\N	PRESENT	0
511081	502343	19507S	PARTICIPANT	\N	PRESENT	0
511082	502343	19762G	PARTICIPANT	\N	PRESENT	0
511083	502343	20026V	PARTICIPANT	\N	PRESENT	0
511084	502343	01028R	PARTICIPANT	\N	PRESENT	0
511085	502343	08061X	PARTICIPANT	\N	PRESENT	0
511086	502343	11074Q	PARTICIPANT	\N	PRESENT	0
511087	502343	20022R	PARTICIPANT	\N	PRESENT	0
511088	502343	19549D	PARTICIPANT	\N	PRESENT	0
511089	502343	08015R	PARTICIPANT	\N	PRESENT	0
511090	502343	14257W	PARTICIPANT	\N	PRESENT	0
511091	502343	19333N	PARTICIPANT	\N	PRESENT	0
511092	502343	20028X	PARTICIPANT	\N	PRESENT	0
511093	502343	14109K	PARTICIPANT	\N	PRESENT	0
511094	502343	20094J	PARTICIPANT	\N	PRESENT	0
511095	502343	20082E	PARTICIPANT	\N	PRESENT	0
511096	502343	20030R	PARTICIPANT	\N	PRESENT	0
511097	502343	19295A	PARTICIPANT	\N	PRESENT	0
511098	502343	20070A	PARTICIPANT	\N	PRESENT	0
511099	502343	20064C	PARTICIPANT	\N	PRESENT	0
511100	502343	19347U	PARTICIPANT	\N	PRESENT	0
511101	502343	08018U	PARTICIPANT	\N	PRESENT	0
511102	502343	20092G	PARTICIPANT	\N	PRESENT	0
511103	502343	08045X	PARTICIPANT	\N	PRESENT	0
511104	502343	19782L	PARTICIPANT	\N	PRESENT	0
511105	502343	19531S	PARTICIPANT	\N	PRESENT	0
511106	502343	11056N	PARTICIPANT	\N	PRESENT	0
511107	502343	19695N	PARTICIPANT	\N	PRESENT	0
511108	502343	20046A	PARTICIPANT	\N	PRESENT	0
511109	502343	20018V	PARTICIPANT	\N	PRESENT	0
511110	502343	20118Y	PARTICIPANT	\N	PRESENT	0
511111	502343	20060X	PARTICIPANT	\N	PRESENT	0
511112	502343	17965H	PARTICIPANT	\N	PRESENT	0
511115	502343	20034V	PARTICIPANT	\N	PRESENT	0
511181	509270	19319Q	PARTICIPANT	\N	EXCUSE	0
511199	505621	20128B	PARTICIPANT	\N	PRESENT	0
511200	505621	10015M	PARTICIPANT	\N	PRESENT	0
511203	511202	20128B	PARTICIPANT	\N	PRESENT	0
511204	511202	10015M	PARTICIPANT	\N	PRESENT	0
511274	509563	19565D	PARTICIPANT	\N	PRESENT	1
511275	509563	04045F	PARTICIPANT	\N	PRESENT	1
511278	509563	19333N	PARTICIPANT	\N	PRESENT	1
511279	509563	20120S	PARTICIPANT	\N	PRESENT	1
511280	509563	14229S	PARTICIPANT	\N	PRESENT	1
511281	509563	14107H	PARTICIPANT	\N	PRESENT	1
511283	509563	95063L	PARTICIPANT	\N	PRESENT	1
511284	509563	19675J	PARTICIPANT	\N	PRESENT	1
511286	511011	11026G	PARTICIPANT	\N	PRESENT	1
511287	511011	95063L	PARTICIPANT	\N	PRESENT	1
512529	512467	11045K	PARTICIPANT	\N	PRESENT	0
512530	512467	20098N	PARTICIPANT	\N	PRESENT	0
512531	512467	19749K	PARTICIPANT	\N	PRESENT	0
512635	507957	14031R	PARTICIPANT	\N	PRESENT	0
512636	507957	20054A	PARTICIPANT	\N	PRESENT	0
512637	507957	20092G	PARTICIPANT	\N	PRESENT	0
512640	507957	20082E	PARTICIPANT	\N	PRESENT	0
512641	507957	19575F	PARTICIPANT	\N	EXCUSE	0
512642	507957	14030Q	PARTICIPANT	\N	EXCUSE	0
512643	507957	08060W	PARTICIPANT	\N	EXCUSE	0
512644	507957	14195A	PARTICIPANT	\N	EXCUSE	0
512645	507957	14041T	PARTICIPANT	\N	EXCUSE	0
512646	507957	19251M	PARTICIPANT	\N	EXCUSE	0
512650	512647	19717B	PARTICIPANT	\N	PRESENT	0
512651	512647	20024T	PARTICIPANT	\N	PRESENT	0
512527	512467	20130U	PARTICIPANT	\N	PRESENT	0
512528	512467	19798U	PARTICIPANT	\N	PRESENT	0
512652	512647	20022R	PARTICIPANT	\N	PRESENT	0
512653	512647	19575F	PARTICIPANT	\N	PRESENT	0
512654	512647	14069U	PARTICIPANT	\N	PRESENT	0
512655	512647	14083S	PARTICIPANT	\N	PRESENT	0
512656	512647	14329V	PARTICIPANT	\N	PRESENT	0
512657	512647	19441R	PARTICIPANT	\N	PRESENT	0
512658	512647	08012N	PARTICIPANT	\N	PRESENT	0
512659	512647	20142Y	PARTICIPANT	\N	PRESENT	0
512660	512647	11067R	PARTICIPANT	\N	PRESENT	0
512661	512647	19768N	PARTICIPANT	\N	PRESENT	0
485043	484555	19711U	PARTICIPANT	\N	PRESENT	0
485044	484555	11031D	PARTICIPANT	\N	PRESENT	0
485045	484555	14251Q	PARTICIPANT	\N	PRESENT	0
485046	484555	19565D	PARTICIPANT	\N	PRESENT	0
485047	484555	11077T	PARTICIPANT	\N	PRESENT	0
485048	484555	11054L	PARTICIPANT	\N	PRESENT	0
485049	484555	14265W	PARTICIPANT	\N	PRESENT	0
485050	484555	19531S	PARTICIPANT	\N	PRESENT	0
485051	484555	19611R	PARTICIPANT	\N	PRESENT	0
485052	484555	19760E	PARTICIPANT	\N	PRESENT	0
485053	484555	04085P	PARTICIPANT	\N	PRESENT	0
485054	484555	19675J	PARTICIPANT	\N	PRESENT	0
485055	484555	14147R	PARTICIPANT	\N	PRESENT	0
485056	484555	08060W	PARTICIPANT	\N	PRESENT	0
485057	484555	08017T	PARTICIPANT	\N	PRESENT	0
485058	484555	11083R	PARTICIPANT	\N	PRESENT	0
485059	484555	04035D	PARTICIPANT	\N	PRESENT	0
485061	484555	96004D	PARTICIPANT	\N	PRESENT	0
485062	484555	14097Y	PARTICIPANT	\N	PRESENT	0
485063	484555	19553Y	PARTICIPANT	\N	PRESENT	0
485064	484555	04033B	PARTICIPANT	\N	PRESENT	0
485065	484555	10006L	PARTICIPANT	\N	PRESENT	0
485066	484555	02002K	PARTICIPANT	\N	PRESENT	0
485067	484555	19647E	PARTICIPANT	\N	PRESENT	0
485068	484555	01028R	PARTICIPANT	\N	PRESENT	0
485069	484555	16685X	PARTICIPANT	\N	PRESENT	0
485070	484555	88008L	PARTICIPANT	\N	PRESENT	0
485071	484555	01048V	PARTICIPANT	\N	PRESENT	0
485847	485846	19593H	PARTICIPANT	\N	PRESENT	0
485858	485857	19703U	PARTICIPANT	\N	PRESENT	0
485860	485859	19703U	PARTICIPANT	\N	PRESENT	0
486207	479199	11027H	PARTICIPANT	\N	PRESENT	0
486208	479199	08011M	PARTICIPANT	\N	PRESENT	0
486209	479199	11074Q	PARTICIPANT	\N	PRESENT	0
486210	479199	19687N	PARTICIPANT	\N	PRESENT	0
486211	479199	19760E	PARTICIPANT	\N	PRESENT	0
486212	479199	19565D	PARTICIPANT	\N	PRESENT	0
486213	479199	19651A	PARTICIPANT	\N	PRESENT	0
486214	479199	14225N	PARTICIPANT	\N	PRESENT	0
486215	479199	19599P	PARTICIPANT	\N	PRESENT	0
486216	479199	19549D	PARTICIPANT	\N	PRESENT	0
486217	479199	14085U	PARTICIPANT	\N	PRESENT	0
486218	479199	11109J	PARTICIPANT	\N	PRESENT	0
486219	479199	19695N	PARTICIPANT	\N	PRESENT	0
486220	479199	19593H	PARTICIPANT	\N	PRESENT	0
486221	479199	19766L	PARTICIPANT	\N	PRESENT	0
486222	479199	11072N	PARTICIPANT	\N	PRESENT	0
486223	479199	19719D	PARTICIPANT	\N	PRESENT	0
486224	479199	19667J	PARTICIPANT	\N	PRESENT	0
486225	479199	11012A	PARTICIPANT	\N	PRESENT	0
486226	479199	19531S	PARTICIPANT	\N	PRESENT	0
486227	479199	19741B	PARTICIPANT	\N	PRESENT	0
486228	479199	19794Q	PARTICIPANT	\N	PRESENT	0
486229	479199	16685X	PARTICIPANT	\N	PRESENT	0
486230	479199	14255U	PARTICIPANT	\N	PRESENT	0
486231	479199	01057W	PARTICIPANT	\N	PRESENT	0
486232	479199	19749K	PARTICIPANT	\N	PRESENT	0
486233	479199	07004J	PARTICIPANT	\N	PRESENT	0
486234	479199	19711U	PARTICIPANT	\N	PRESENT	0
486235	479199	19671E	PARTICIPANT	\N	PRESENT	0
486236	479199	11097X	PARTICIPANT	\N	PRESENT	0
486237	479199	04086Q	PARTICIPANT	\N	PRESENT	0
486238	479199	14357A	PARTICIPANT	\N	PRESENT	0
486239	479199	19533U	PARTICIPANT	\N	PRESENT	0
486240	479199	11090Q	PARTICIPANT	\N	PRESENT	0
486241	479199	19551W	PARTICIPANT	\N	PRESENT	0
486242	479199	14041T	PARTICIPANT	\N	PRESENT	0
486243	479199	04085P	PARTICIPANT	\N	PRESENT	0
486244	479199	99004R	PARTICIPANT	\N	PRESENT	0
486245	479199	19912C	PARTICIPANT	\N	PRESENT	0
486246	479199	11048N	PARTICIPANT	\N	PRESENT	0
486247	479199	14327T	PARTICIPANT	\N	PRESENT	0
486248	479199	08073C	PARTICIPANT	\N	PRESENT	0
486249	479199	19347U	PARTICIPANT	\N	PRESENT	0
486250	479199	12041X	PARTICIPANT	\N	PRESENT	0
486251	479199	12016W	PARTICIPANT	\N	PRESENT	0
486252	479199	04018C	PARTICIPANT	\N	PRESENT	0
486253	479199	19713W	PARTICIPANT	\N	PRESENT	0
486254	479199	07029T	PARTICIPANT	\N	PRESENT	0
486255	479199	19762G	PARTICIPANT	\N	PRESENT	0
486256	479199	14021P	PARTICIPANT	\N	PRESENT	0
486257	479199	19563B	PARTICIPANT	\N	PRESENT	0
486258	479199	19926J	PARTICIPANT	\N	PRESENT	0
486259	479199	19503N	PARTICIPANT	\N	PRESENT	0
486260	479199	19701S	PARTICIPANT	\N	PRESENT	0
486261	479199	11099A	PARTICIPANT	\N	PRESENT	0
486262	479199	14261S	PARTICIPANT	\N	PRESENT	0
486263	479199	14205J	PARTICIPANT	\N	PRESENT	0
486264	479199	19705W	PARTICIPANT	\N	PRESENT	0
486265	479199	19647E	PARTICIPANT	\N	PRESENT	0
486266	479199	19689Q	PARTICIPANT	\N	PRESENT	0
486267	479199	14229S	PARTICIPANT	\N	PRESENT	0
486268	479199	11085T	PARTICIPANT	\N	PRESENT	0
486269	479199	14217N	PARTICIPANT	\N	PRESENT	0
486270	479199	19295A	PARTICIPANT	\N	PRESENT	0
486271	479199	19663E	PARTICIPANT	\N	PRESENT	0
486272	479199	11026G	PARTICIPANT	\N	PRESENT	0
486334	479200	19912C	PARTICIPANT	\N	PRESENT	0
486335	479200	19711U	PARTICIPANT	\N	PRESENT	0
486336	479200	19599P	PARTICIPANT	\N	PRESENT	0
486337	479200	11090Q	PARTICIPANT	\N	PRESENT	0
486338	479200	19926J	PARTICIPANT	\N	PRESENT	0
486339	479200	19762G	PARTICIPANT	\N	PRESENT	0
486340	479200	14229S	PARTICIPANT	\N	PRESENT	0
486341	479200	08073C	PARTICIPANT	\N	PRESENT	0
486342	479200	14217N	PARTICIPANT	\N	PRESENT	0
486343	479200	19503N	PARTICIPANT	\N	PRESENT	0
486344	479200	11097X	PARTICIPANT	\N	PRESENT	0
486345	479200	14085U	PARTICIPANT	\N	PRESENT	0
486346	479200	19687N	PARTICIPANT	\N	PRESENT	0
486347	479200	19794Q	PARTICIPANT	\N	PRESENT	0
486348	479200	19565D	PARTICIPANT	\N	PRESENT	0
486349	479200	14041T	PARTICIPANT	\N	PRESENT	0
486350	479200	19347U	PARTICIPANT	\N	PRESENT	0
486351	479200	14331P	PARTICIPANT	\N	PRESENT	0
486352	479200	04085P	PARTICIPANT	\N	PRESENT	0
486353	479200	19671E	PARTICIPANT	\N	PRESENT	0
486354	479200	19760E	PARTICIPANT	\N	PRESENT	0
486355	479200	07004J	PARTICIPANT	\N	PRESENT	0
486356	479200	11012A	PARTICIPANT	\N	PRESENT	0
486357	479200	14021P	PARTICIPANT	\N	PRESENT	0
486358	479200	16685X	PARTICIPANT	\N	PRESENT	0
486359	479200	19713W	PARTICIPANT	\N	PRESENT	0
486360	479200	11053K	PARTICIPANT	\N	PRESENT	0
486361	479200	11099A	PARTICIPANT	\N	PRESENT	0
486362	479200	19719D	PARTICIPANT	\N	PRESENT	0
486363	479200	14261S	PARTICIPANT	\N	PRESENT	0
486364	479200	19749K	PARTICIPANT	\N	PRESENT	0
486365	479200	19651A	PARTICIPANT	\N	PRESENT	0
486366	479200	07033P	PARTICIPANT	\N	PRESENT	0
486367	479200	11048N	PARTICIPANT	\N	PRESENT	0
486368	479200	04086Q	PARTICIPANT	\N	PRESENT	0
486369	479200	99004R	PARTICIPANT	\N	PRESENT	0
486370	479200	19741B	PARTICIPANT	\N	PRESENT	0
486371	479200	19563B	PARTICIPANT	\N	PRESENT	0
486372	479200	19701S	PARTICIPANT	\N	PRESENT	0
486373	479200	19689Q	PARTICIPANT	\N	PRESENT	0
486374	479200	19663E	PARTICIPANT	\N	PRESENT	0
486375	479200	12016W	PARTICIPANT	\N	PRESENT	0
486376	479200	19715Y	PARTICIPANT	\N	PRESENT	0
486377	479200	19647E	PARTICIPANT	\N	PRESENT	0
486378	479200	19531S	PARTICIPANT	\N	PRESENT	0
486379	479200	11027H	PARTICIPANT	\N	PRESENT	0
486380	479200	19295A	PARTICIPANT	\N	PRESENT	0
486381	479200	11070L	PARTICIPANT	\N	PRESENT	0
486382	479200	07029T	PARTICIPANT	\N	PRESENT	0
486383	479200	19705W	PARTICIPANT	\N	PRESENT	0
486384	479200	19533U	PARTICIPANT	\N	PRESENT	0
486385	479200	14357A	PARTICIPANT	\N	PRESENT	0
486386	479200	11109J	PARTICIPANT	\N	PRESENT	0
486387	479200	14225N	PARTICIPANT	\N	PRESENT	0
486388	479200	11072N	PARTICIPANT	\N	PRESENT	0
486389	479200	19667J	PARTICIPANT	\N	PRESENT	0
486390	479200	12041X	PARTICIPANT	\N	PRESENT	0
486391	479200	19593H	PARTICIPANT	\N	PRESENT	0
486392	479200	11074Q	PARTICIPANT	\N	PRESENT	0
486332	479200	04059M	PARTICIPANT	\N	PRESENT	0
486333	479200	08011M	PARTICIPANT	\N	PRESENT	0
486393	479200	04018C	PARTICIPANT	\N	PRESENT	0
486394	479200	11026G	PARTICIPANT	\N	PRESENT	0
486395	479200	04035D	PARTICIPANT	\N	PRESENT	0
486397	479200	14255U	PARTICIPANT	\N	PRESENT	0
486398	479200	19695N	PARTICIPANT	\N	PRESENT	0
486399	479200	19551W	PARTICIPANT	\N	PRESENT	0
504101	501818	19691J	PARTICIPANT	\N	PRESENT	0
504102	501818	17589D	PARTICIPANT	\N	PRESENT	0
504103	501818	19563B	PARTICIPANT	\N	PRESENT	0
504104	501818	19782L	PARTICIPANT	\N	PRESENT	0
504105	501818	19553Y	PARTICIPANT	\N	PRESENT	0
504107	504106	08018U	PARTICIPANT	\N	PRESENT	0
504108	501818	14267Y	PARTICIPANT	\N	PRESENT	0
504109	501818	20066E	PARTICIPANT	\N	PRESENT	0
504110	501818	14205J	PARTICIPANT	\N	PRESENT	0
504111	501818	20118Y	PARTICIPANT	\N	PRESENT	0
504114	501818	19575F	PARTICIPANT	\N	PRESENT	0
504116	501818	19768N	PARTICIPANT	\N	PRESENT	0
504117	501818	20022R	PARTICIPANT	\N	PRESENT	0
504118	501818	20106U	PARTICIPANT	\N	PRESENT	0
504119	501818	20072C	PARTICIPANT	\N	PRESENT	0
504121	501818	14042U	PARTICIPANT	\N	PRESENT	0
504124	502448	07029T	PARTICIPANT	\N	PRESENT	0
504125	502448	99004R	PARTICIPANT	\N	PRESENT	0
504126	501818	11103C	PARTICIPANT	\N	PRESENT	0
504127	501818	14357A	PARTICIPANT	\N	PRESENT	0
504128	501818	05012A	PARTICIPANT	\N	PRESENT	0
504129	501818	20030R	PARTICIPANT	\N	PRESENT	0
504130	501818	19629C	PARTICIPANT	\N	PRESENT	0
504131	501818	20172F	PARTICIPANT	\N	PRESENT	0
504132	501818	20032T	PARTICIPANT	\N	PRESENT	0
504133	501818	20076G	PARTICIPANT	\N	PRESENT	0
504134	501818	20096L	PARTICIPANT	\N	PRESENT	0
504135	501818	19467C	PARTICIPANT	\N	PRESENT	0
504136	501818	19503N	PARTICIPANT	\N	PRESENT	0
504137	501818	20174H	PARTICIPANT	\N	PRESENT	0
504138	501818	19703U	PARTICIPANT	\N	PRESENT	0
504139	501818	19729F	PARTICIPANT	\N	PRESENT	0
504140	501818	19745F	PARTICIPANT	\N	PRESENT	0
504141	501818	14179A	PARTICIPANT	\N	PRESENT	0
504142	501818	14030Q	PARTICIPANT	\N	PRESENT	0
504143	501818	01024M	PARTICIPANT	\N	PRESENT	0
504144	501818	20028X	PARTICIPANT	\N	PRESENT	0
504145	501818	14055N	PARTICIPANT	\N	PRESENT	0
504146	501818	19533U	PARTICIPANT	\N	PRESENT	0
504147	501818	14123H	PARTICIPANT	\N	PRESENT	0
504148	501818	19521Q	PARTICIPANT	\N	PRESENT	0
504149	501818	19695N	PARTICIPANT	\N	PRESENT	0
504150	501818	20102Q	PARTICIPANT	\N	PRESENT	0
504151	501818	19599P	PARTICIPANT	\N	PRESENT	0
504165	501818	20024T	PARTICIPANT	\N	PRESENT	0
504153	501818	14059S	PARTICIPANT	\N	PRESENT	0
504154	501818	20124W	PARTICIPANT	\N	PRESENT	0
504155	501818	19515S	PARTICIPANT	\N	PRESENT	0
504156	501818	18083K	PARTICIPANT	\N	PRESENT	0
504157	501818	19679N	PARTICIPANT	\N	PRESENT	0
504158	501818	19866P	PARTICIPANT	\N	PRESENT	0
504159	501818	19798U	PARTICIPANT	\N	PRESENT	0
504160	501818	19701S	PARTICIPANT	\N	PRESENT	0
504161	501818	14038Y	PARTICIPANT	\N	PRESENT	0
504162	501818	14031R	PARTICIPANT	\N	PRESENT	0
504163	501818	08061X	PARTICIPANT	\N	PRESENT	0
504164	501818	11012A	PARTICIPANT	\N	PRESENT	0
504166	501818	20090E	PARTICIPANT	\N	PRESENT	0
504181	501780	20086J	PARTICIPANT	\N	PRESENT	0
504182	501780	19383Y	PARTICIPANT	\N	PRESENT	0
504183	501780	20088L	PARTICIPANT	\N	PRESENT	0
504184	501780	19768N	PARTICIPANT	\N	PRESENT	0
504185	501780	19515S	PARTICIPANT	\N	PRESENT	0
504186	501780	20092G	PARTICIPANT	\N	PRESENT	0
504187	501780	11077T	PARTICIPANT	\N	PRESENT	0
504188	501780	01043Q	PARTICIPANT	\N	PRESENT	0
504189	501780	20082E	PARTICIPANT	\N	PRESENT	0
504190	501780	20094J	PARTICIPANT	\N	PRESENT	0
504191	501780	04045F	PARTICIPANT	\N	PRESENT	1
504192	501780	20104S	PARTICIPANT	\N	PRESENT	1
504193	501780	19631V	PARTICIPANT	\N	PRESENT	0
504194	501780	19705W	PARTICIPANT	\N	PRESENT	0
504195	501780	19575F	PARTICIPANT	\N	PRESENT	0
504196	501780	19511N	PARTICIPANT	\N	PRESENT	0
504197	501780	19521Q	PARTICIPANT	\N	PRESENT	0
504198	501780	20030R	PARTICIPANT	\N	PRESENT	1
504199	501780	14038Y	PARTICIPANT	\N	PRESENT	1
504200	501780	19467C	PARTICIPANT	\N	PRESENT	0
504201	501780	14187A	PARTICIPANT	\N	PRESENT	0
504202	501780	11090Q	PRESIDENT	0	PRESENT	0
504203	501780	20054A	PARTICIPANT	\N	PRESENT	1
504204	501780	20174H	PARTICIPANT	\N	PRESENT	0
504205	501780	20062A	PARTICIPANT	\N	PRESENT	1
504206	501780	14257W	PARTICIPANT	\N	PRESENT	0
504210	501780	14251Q	PARTICIPANT	\N	PRESENT	0
504211	501780	08028W	PARTICIPANT	\N	EXCUSE	0
504217	501818	19507S	PARTICIPANT	\N	PRESENT	0
504218	501818	14147R	PARTICIPANT	\N	PRESENT	0
504219	501818	11104D	PARTICIPANT	\N	PRESENT	0
504220	501818	11115U	PARTICIPANT	\N	PRESENT	0
504221	501818	19954N	PARTICIPANT	\N	PRESENT	0
504225	501818	20104S	PARTICIPANT	\N	PRESENT	0
504227	502448	14327T	PARTICIPANT	\N	PRESENT	0
504228	502448	19569H	PARTICIPANT	\N	PRESENT	0
504229	502448	01057W	PARTICIPANT	\N	PRESENT	0
504230	502448	19369B	PARTICIPANT	\N	PRESENT	0
504231	502448	20126Y	PARTICIPANT	\N	PRESENT	0
504232	502448	19479G	PARTICIPANT	\N	PRESENT	0
504233	502448	19711U	PARTICIPANT	\N	PRESENT	0
504234	502448	08034U	PARTICIPANT	\N	PRESENT	0
504235	502448	08009T	PARTICIPANT	\N	PRESENT	0
504238	501818	14111D	PARTICIPANT	\N	PRESENT	0
504239	501818	19383Y	PARTICIPANT	\N	PRESENT	0
504240	501818	14069U	PARTICIPANT	\N	PRESENT	0
504242	501818	19399H	PARTICIPANT	\N	PRESENT	0
504244	503159	19333N	PARTICIPANT	\N	PRESENT	0
504245	503159	14237S	PARTICIPANT	\N	PRESENT	0
504246	503159	18083K	PARTICIPANT	\N	PRESENT	0
504247	503159	20032T	PARTICIPANT	\N	PRESENT	0
504248	503159	19701S	PARTICIPANT	\N	PRESENT	0
504249	503159	20076G	PARTICIPANT	\N	PRESENT	0
504250	503159	20140W	PARTICIPANT	\N	PRESENT	0
504251	503159	19549D	PARTICIPANT	\N	PRESENT	0
504252	503159	19387D	PARTICIPANT	\N	PRESENT	0
504253	503159	19826F	PARTICIPANT	\N	PRESENT	0
504254	503159	19685L	PARTICIPANT	\N	PRESENT	0
504255	503159	19525U	PARTICIPANT	\N	PRESENT	0
504257	501818	20068G	PARTICIPANT	\N	PRESENT	0
504258	501818	97011G	PARTICIPANT	\N	PRESENT	0
504259	501818	14083S	PARTICIPANT	\N	PRESENT	0
504261	503159	19820Y	PARTICIPANT	\N	PRESENT	0
504262	503159	19251M	PARTICIPANT	\N	PRESENT	1
504263	503159	20046A	PARTICIPANT	\N	PRESENT	0
504264	503159	19599P	PARTICIPANT	\N	PRESENT	0
504265	503159	17229F	PARTICIPANT	\N	PRESENT	1
504266	503159	08060W	PARTICIPANT	\N	PRESENT	1
504267	503159	20106U	PARTICIPANT	\N	PRESENT	0
504268	503159	19503N	PARTICIPANT	\N	PRESENT	0
504269	503159	20020P	PARTICIPANT	\N	PRESENT	0
504270	503159	19745F	PARTICIPANT	\N	PRESENT	0
504271	503159	20022R	PARTICIPANT	\N	PRESENT	0
504272	503159	19619A	PARTICIPANT	\N	PRESENT	0
504273	501780	19782L	PARTICIPANT	\N	PRESENT	0
504274	501780	19441R	PARTICIPANT	\N	PRESENT	0
504275	501780	20078J	PARTICIPANT	\N	PRESENT	0
504276	501780	19563B	PARTICIPANT	\N	PRESENT	0
504277	501780	20034V	PARTICIPANT	\N	PRESENT	0
504278	501780	19695N	PARTICIPANT	\N	PRESENT	1
504279	501780	14033T	PARTICIPANT	\N	PRESENT	1
504280	501780	14205J	PARTICIPANT	\N	PRESENT	0
504281	501780	20060X	PARTICIPANT	\N	PRESENT	1
504283	503159	05012A	PARTICIPANT	\N	PRESENT	0
504284	503159	17367Q	PARTICIPANT	\N	PRESENT	0
504286	502288	14053L	PARTICIPANT	\N	PRESENT	0
504287	502288	19725B	PARTICIPANT	\N	PRESENT	0
504288	502288	19954N	PARTICIPANT	\N	PRESENT	0
504289	502288	14111D	PARTICIPANT	\N	PRESENT	0
504290	502288	19649G	PARTICIPANT	\N	PRESENT	0
504291	502288	19629C	PARTICIPANT	\N	PRESENT	0
504292	502288	20074E	PARTICIPANT	\N	PRESENT	0
504293	502288	10015M	PARTICIPANT	\N	PRESENT	0
504294	502288	20114U	PARTICIPANT	\N	PRESENT	0
504295	502288	19749K	PARTICIPANT	\N	PRESENT	0
504296	502288	14231L	PARTICIPANT	\N	PRESENT	0
504298	503159	20136B	PARTICIPANT	\N	PRESENT	0
504299	503159	14169X	PARTICIPANT	\N	PRESENT	0
504301	503159	14031R	PARTICIPANT	\N	PRESENT	0
504302	502288	14147R	PARTICIPANT	\N	PRESENT	0
504303	502288	14215L	PARTICIPANT	\N	PRESENT	0
504304	502288	95063L	PARTICIPANT	\N	PRESENT	0
483193	481098	19693L	PARTICIPANT	\N	PRESENT	0
483194	481098	01048V	PARTICIPANT	\N	EXCUSE	0
483195	481098	19593H	PARTICIPANT	\N	PRESENT	0
483196	481098	19709B	PARTICIPANT	\N	PRESENT	0
483199	481098	14299H	PARTICIPANT	\N	EXCUSE	0
483247	483246	08058D	PARTICIPANT	\N	PRESENT	0
483347	482345	19631V	PARTICIPANT	\N	PRESENT	0
483354	483352	08058D	PARTICIPANT	\N	PRESENT	0
483350	482345	19387D	PARTICIPANT	\N	PRESENT	0
483353	483352	14133K	PARTICIPANT	\N	PRESENT	0
483356	483355	14133K	PARTICIPANT	\N	PRESENT	0
483357	483355	08058D	PARTICIPANT	\N	PRESENT	0
483359	483358	14133K	PARTICIPANT	\N	PRESENT	0
483360	483358	08058D	PARTICIPANT	\N	PRESENT	0
483362	483361	11026G	PARTICIPANT	\N	PRESENT	0
483364	483363	11070L	PARTICIPANT	\N	PRESENT	0
483368	483367	11070L	PARTICIPANT	\N	PRESENT	0
483673	483057	14133K	PARTICIPANT	\N	PRESENT	0
483674	483057	04040A	PARTICIPANT	\N	PRESENT	0
483675	483057	14105F	PARTICIPANT	\N	PRESENT	0
483676	483057	08058D	PARTICIPANT	\N	PRESENT	0
483677	483057	14255U	PARTICIPANT	\N	PRESENT	0
483678	483057	04042C	PRESIDENT	0	PRESENT	0
483679	483057	19721W	PARTICIPANT	\N	PRESENT	0
483680	483057	98029W	PARTICIPANT	\N	PRESENT	0
483681	483057	14267Y	PARTICIPANT	\N	PRESENT	0
483682	483057	11027H	PARTICIPANT	\N	PRESENT	0
483683	483057	19251M	PARTICIPANT	\N	PRESENT	0
483684	483057	95030B	PARTICIPANT	\N	PRESENT	0
483685	483057	97011G	PARTICIPANT	\N	PRESENT	0
483686	483057	14211G	PARTICIPANT	\N	PRESENT	0
483687	483057	95037J	PARTICIPANT	\N	PRESENT	0
483688	483057	12041X	PARTICIPANT	\N	PRESENT	0
483689	483057	19709B	PARTICIPANT	\N	PRESENT	0
483690	483057	16685X	PARTICIPANT	\N	PRESENT	0
483691	483057	08053X	PARTICIPANT	\N	PRESENT	0
483692	483057	14193X	PRESIDENT	1	PRESENT	0
483693	483057	14235Q	PARTICIPANT	\N	PRESENT	0
483694	483057	19421M	PARTICIPANT	\N	PRESENT	0
483695	483057	01058X	PARTICIPANT	\N	PRESENT	0
483696	483057	01062T	PARTICIPANT	\N	PRESENT	0
483697	483057	11041F	PARTICIPANT	\N	PRESENT	0
483698	483057	11066Q	PARTICIPANT	\N	PRESENT	0
483699	483057	95067Q	PARTICIPANT	\N	PRESENT	0
483700	483057	14079W	PARTICIPANT	\N	EXCUSE	0
483701	483057	98050T	PARTICIPANT	\N	EXCUSE	0
483702	483057	08049C	PARTICIPANT	\N	EXCUSE	0
483703	483057	04034C	PARTICIPANT	\N	EXCUSE	0
487167	486929	14241N	PARTICIPANT	\N	EXCUSE	0
487168	486929	19533U	PARTICIPANT	\N	EXCUSE	0
487171	487170	04070G	PARTICIPANT	\N	PRESENT	0
487172	487170	04018C	PARTICIPANT	\N	PRESENT	0
487173	487170	19593H	PARTICIPANT	\N	PRESENT	0
487174	487170	14059S	PARTICIPANT	\N	PRESENT	0
487175	487170	19731Y	PARTICIPANT	\N	PRESENT	0
487176	487170	08039A	PARTICIPANT	\N	PRESENT	0
487178	487177	04070G	PARTICIPANT	\N	PRESENT	0
487179	487177	04018C	PARTICIPANT	\N	PRESENT	0
487180	487177	19593H	PARTICIPANT	\N	PRESENT	0
487181	487177	19731Y	PARTICIPANT	\N	PRESENT	0
493752	493357	11048N	PARTICIPANT	\N	PRESENT	0
493661	493391	20038A	PARTICIPANT	\N	PRESENT	0
493662	493391	20076G	PARTICIPANT	\N	PRESENT	0
493663	493391	19549D	PARTICIPANT	\N	PRESENT	0
493664	493391	20140W	PARTICIPANT	\N	PRESENT	0
493665	493391	19387D	PARTICIPANT	\N	PRESENT	0
493666	493391	20102Q	PARTICIPANT	\N	PRESENT	0
493754	493357	08009T	PARTICIPANT	\N	PRESENT	0
493668	493391	18083K	PARTICIPANT	\N	PRESENT	0
493669	493391	20020P	PARTICIPANT	\N	PRESENT	0
493670	493391	20024T	PARTICIPANT	\N	PRESENT	0
493671	493391	11065P	PARTICIPANT	\N	PRESENT	0
493672	493391	14031R	PARTICIPANT	\N	PRESENT	0
493673	493391	19826F	PARTICIPANT	\N	PRESENT	0
493674	493391	19637C	PARTICIPANT	\N	PRESENT	0
493675	493391	20096L	PARTICIPANT	\N	PRESENT	0
493676	493391	17229F	PARTICIPANT	\N	PRESENT	0
493677	493391	20106U	PARTICIPANT	\N	PRESENT	0
493678	493391	14219Q	PARTICIPANT	\N	PRESENT	0
493679	493391	14221J	PARTICIPANT	\N	PRESENT	0
493680	493391	20022R	PARTICIPANT	\N	PRESENT	0
493681	493391	20068G	PARTICIPANT	\N	PRESENT	0
493682	493391	19619A	PARTICIPANT	\N	PRESENT	0
493683	493391	19745F	PARTICIPANT	\N	PRESENT	0
493684	493391	11101A	PARTICIPANT	\N	PRESENT	0
493685	493357	14053L	PARTICIPANT	\N	PRESENT	0
493686	493391	20118Y	PARTICIPANT	\N	PRESENT	0
493687	493391	20122U	PARTICIPANT	\N	PRESENT	0
493688	493391	20046A	PARTICIPANT	\N	EXCUSE	0
493689	493357	19713W	PARTICIPANT	\N	PRESENT	0
493691	493391	20100N	PARTICIPANT	\N	PRESENT	0
493692	493391	19551W	PARTICIPANT	\N	PRESENT	0
493693	493391	17637T	PARTICIPANT	\N	PRESENT	0
493695	493391	20032T	PARTICIPANT	\N	PRESENT	0
493701	493357	19545Y	PARTICIPANT	\N	PRESENT	0
493702	493357	11097X	PARTICIPANT	\N	PRESENT	0
493711	493357	14089Y	PARTICIPANT	\N	PRESENT	0
493708	493391	14237S	PARTICIPANT	\N	PRESENT	0
493709	493391	19739H	PARTICIPANT	\N	PRESENT	0
493710	493357	20116W	PARTICIPANT	\N	PRESENT	0
493712	492924	20086J	PARTICIPANT	\N	PRESENT	0
493713	492924	19383Y	PARTICIPANT	\N	PRESENT	0
493714	492924	19768N	PARTICIPANT	\N	PRESENT	0
493715	492924	19515S	PARTICIPANT	\N	PRESENT	0
493716	492924	20092G	PARTICIPANT	\N	PRESENT	0
493717	492924	01043Q	PARTICIPANT	\N	PRESENT	0
493718	492924	14357A	PARTICIPANT	\N	PRESENT	0
493719	492924	20078J	PARTICIPANT	\N	PRESENT	0
493720	492924	19441R	PARTICIPANT	\N	PRESENT	0
493721	492924	19866P	PARTICIPANT	\N	PRESENT	0
493722	492924	20104S	PARTICIPANT	\N	PRESENT	0
493723	492924	11099A	PARTICIPANT	\N	PRESENT	0
493724	492924	19705W	PARTICIPANT	\N	PRESENT	0
493725	492924	08015R	PARTICIPANT	\N	PRESENT	0
493726	492924	19575F	PARTICIPANT	\N	PRESENT	0
493727	492924	19369B	PARTICIPANT	\N	PRESENT	0
493728	492924	20018V	PARTICIPANT	\N	PRESENT	0
493729	492924	19511N	PARTICIPANT	\N	PRESENT	0
493730	492924	08028W	PARTICIPANT	\N	PRESENT	0
493731	492924	19563B	PARTICIPANT	\N	PRESENT	0
493732	492924	19521Q	PARTICIPANT	\N	PRESENT	0
493733	492924	14329V	PARTICIPANT	\N	PRESENT	0
493734	492924	20030R	PARTICIPANT	\N	PRESENT	0
493735	492924	19467C	PARTICIPANT	\N	PRESENT	0
493736	492924	14187A	PARTICIPANT	\N	PRESENT	0
493737	492924	20144B	PARTICIPANT	\N	PRESENT	0
493738	492924	19695N	PARTICIPANT	\N	PRESENT	0
493739	492924	14033T	PARTICIPANT	\N	PRESENT	0
493740	492924	11090Q	PRESIDENT	0	PRESENT	0
493741	492924	20054A	PARTICIPANT	\N	PRESENT	0
493742	492924	20062A	PARTICIPANT	\N	PRESENT	0
493743	492924	19507S	PARTICIPANT	\N	PRESENT	0
493744	492924	14257W	PARTICIPANT	\N	PRESENT	0
493745	492924	14205J	PARTICIPANT	\N	EXCUSE	0
493746	492924	11077T	PARTICIPANT	\N	EXCUSE	0
493747	493391	05012A	PARTICIPANT	\N	PRESENT	0
493748	493357	14030Q	PARTICIPANT	\N	PRESENT	0
493750	493357	14213J	PARTICIPANT	\N	PRESENT	0
493751	493357	20052X	PARTICIPANT	\N	PRESENT	0
493753	493357	11026G	PARTICIPANT	\N	PRESENT	0
493755	493357	19521Q	PARTICIPANT	\N	PRESENT	0
493757	493411	04070G	PARTICIPANT	\N	PRESENT	0
493758	493411	19699S	PARTICIPANT	\N	PRESENT	0
493759	493411	19533U	PARTICIPANT	\N	PRESENT	0
493760	493411	19329S	PARTICIPANT	\N	PRESENT	0
493761	493411	19573D	PARTICIPANT	\N	PRESENT	0
493762	493411	08017T	PARTICIPANT	\N	PRESENT	0
493763	493411	92040Q	PARTICIPANT	\N	PRESENT	0
493764	493411	07033P	PARTICIPANT	\N	PRESENT	0
493765	493411	08061X	PARTICIPANT	\N	PRESENT	0
493766	493411	20026V	PARTICIPANT	\N	PRESENT	0
493767	493411	19593H	PARTICIPANT	\N	PRESENT	0
493768	493411	20132W	PARTICIPANT	\N	PRESENT	0
493769	493411	19643A	PARTICIPANT	\N	PRESENT	0
493770	493411	20134Y	PARTICIPANT	\N	PRESENT	0
493771	493411	19651A	PARTICIPANT	\N	PRESENT	0
493772	493411	14073Q	PARTICIPANT	\N	PRESENT	0
493773	493411	19611R	PARTICIPANT	\N	PRESENT	0
493774	493411	20138D	PARTICIPANT	\N	PRESENT	0
493775	493411	19693L	PARTICIPANT	\N	PRESENT	0
493776	493411	19399H	PARTICIPANT	\N	PRESENT	0
493777	493411	20052X	PARTICIPANT	\N	PRESENT	0
493778	493411	14030Q	PARTICIPANT	\N	PRESENT	0
493779	493411	20058E	PARTICIPANT	\N	PRESENT	0
493780	493411	20056C	PARTICIPANT	\N	PRESENT	0
493781	493411	04059M	PARTICIPANT	\N	PRESENT	0
508068	505798	11033F	PARTICIPANT	\N	PRESENT	1
508069	505798	14069U	PARTICIPANT	\N	PRESENT	1
508070	505798	20114U	PARTICIPANT	\N	PRESENT	1
508071	505798	19629C	PARTICIPANT	\N	PRESENT	1
508072	505798	14041T	PARTICIPANT	\N	PRESENT	1
508073	505798	14215L	PARTICIPANT	\N	PRESENT	1
508074	505798	08018U	PARTICIPANT	\N	PRESENT	1
508075	505798	19489J	PARTICIPANT	\N	PRESENT	1
508076	505798	11072N	PARTICIPANT	\N	PRESENT	1
508077	505798	14107H	PARTICIPANT	\N	PRESENT	1
510247	502330	11070L	PARTICIPANT	\N	PRESENT	0
510248	502330	01048V	PARTICIPANT	\N	PRESENT	0
510249	502330	14123H	PARTICIPANT	\N	PRESENT	0
510250	502330	19719D	PARTICIPANT	\N	PRESENT	0
510251	502330	19758L	PARTICIPANT	\N	PRESENT	0
510252	502330	14030Q	PARTICIPANT	\N	PRESENT	0
510253	502330	14109K	PARTICIPANT	\N	PRESENT	0
510254	502330	17589D	PARTICIPANT	\N	PRESENT	0
510255	502330	20134Y	PARTICIPANT	\N	PRESENT	0
510256	502330	20106U	PARTICIPANT	\N	PRESENT	0
510257	502330	19866P	PARTICIPANT	\N	PRESENT	0
510258	502330	19621T	PARTICIPANT	\N	PRESENT	0
510259	502330	19533U	PARTICIPANT	\N	PRESENT	0
510260	502330	20120S	PARTICIPANT	\N	PRESENT	0
510261	502330	20024T	PARTICIPANT	\N	PRESENT	0
510262	502330	11043H	PARTICIPANT	\N	PRESENT	0
510263	502330	20116W	PARTICIPANT	\N	PRESENT	0
510264	502330	19593H	PARTICIPANT	\N	PRESENT	0
510265	502330	14229S	PARTICIPANT	\N	PRESENT	0
510266	502330	20142Y	PARTICIPANT	\N	PRESENT	0
510267	502330	19745F	PARTICIPANT	\N	PRESENT	0
510268	502330	20026V	PARTICIPANT	\N	PRESENT	0
510269	502330	20056C	PARTICIPANT	\N	PRESENT	0
510270	502330	20044X	PARTICIPANT	\N	PRESENT	0
510271	502330	14083S	PARTICIPANT	\N	PRESENT	0
510272	502330	11074Q	PARTICIPANT	\N	PRESENT	0
510273	502330	14215L	PARTICIPANT	\N	PRESENT	0
510274	502330	19671E	PARTICIPANT	\N	PRESENT	0
510275	502330	20038A	PARTICIPANT	\N	PRESENT	0
510276	502330	19687N	PARTICIPANT	\N	PRESENT	0
510277	502330	19531S	PARTICIPANT	\N	PRESENT	0
510278	502330	19735D	PARTICIPANT	\N	PRESENT	0
510279	502330	19515S	PARTICIPANT	\N	PRESENT	0
510280	502330	19599P	PARTICIPANT	\N	PRESENT	0
510281	502330	19611R	PARTICIPANT	\N	PRESENT	0
510282	502330	96004D	PARTICIPANT	\N	PRESENT	0
510283	502330	20092G	PARTICIPANT	\N	PRESENT	0
510284	502330	20114U	PARTICIPANT	\N	PRESENT	0
510285	502330	20070A	PARTICIPANT	\N	PRESENT	0
510286	502330	20124W	PARTICIPANT	\N	PRESENT	0
510287	502330	20098N	PARTICIPANT	\N	PRESENT	0
510288	502330	12016W	PARTICIPANT	\N	PRESENT	0
510289	502330	14038Y	PARTICIPANT	\N	PRESENT	0
510290	502330	20036X	PARTICIPANT	\N	PRESENT	0
510291	502330	01028R	PARTICIPANT	\N	PRESENT	0
510295	502330	14253S	PARTICIPANT	\N	PRESENT	0
510293	502330	19717B	PARTICIPANT	\N	PRESENT	0
510294	502330	19741B	PARTICIPANT	\N	PRESENT	0
510296	502330	19762G	PARTICIPANT	\N	PRESENT	0
510297	502330	11085T	PARTICIPANT	\N	PRESENT	0
510298	502330	07029T	PARTICIPANT	\N	PRESENT	0
510299	502330	07004J	PARTICIPANT	\N	PRESENT	0
510300	502330	20080C	PARTICIPANT	\N	PRESENT	0
510301	502330	19563B	PARTICIPANT	\N	PRESENT	0
510302	502330	14255U	PARTICIPANT	\N	PRESENT	0
510303	502330	04071H	PARTICIPANT	\N	PRESENT	0
510304	502330	20094J	PARTICIPANT	\N	PRESENT	0
510305	502330	19369B	PARTICIPANT	\N	PRESENT	0
510306	502330	19591F	PARTICIPANT	\N	PRESENT	0
510307	502330	11067R	PARTICIPANT	\N	PRESENT	0
510308	502330	10006L	PARTICIPANT	\N	PRESENT	0
510309	502330	20034V	PARTICIPANT	\N	PRESENT	0
510310	502330	20064C	PARTICIPANT	\N	PRESENT	0
510371	502331	20116W	PARTICIPANT	\N	PRESENT	0
510372	502331	20036X	PARTICIPANT	\N	PRESENT	0
510373	502331	14255U	PARTICIPANT	\N	PRESENT	0
510374	502331	20064C	PARTICIPANT	\N	PRESENT	0
510375	502331	10006L	PARTICIPANT	\N	PRESENT	0
510376	502331	01028R	PARTICIPANT	\N	PRESENT	0
510377	502331	20110Q	PARTICIPANT	\N	PRESENT	0
510378	502331	11026G	PARTICIPANT	\N	PRESENT	0
510379	502331	19563B	PARTICIPANT	\N	PRESENT	0
510380	502331	95063L	PARTICIPANT	\N	PRESENT	0
510381	502331	19695N	PARTICIPANT	\N	PRESENT	0
510382	502331	20080C	PARTICIPANT	\N	PRESENT	0
510383	502331	19741B	PARTICIPANT	\N	PRESENT	0
510384	502331	19717B	PARTICIPANT	\N	PRESENT	0
510385	502331	14083S	PARTICIPANT	\N	PRESENT	0
510386	502331	19711U	PARTICIPANT	\N	PRESENT	0
510387	502331	20034V	PARTICIPANT	\N	PRESENT	0
510388	502331	12016W	PARTICIPANT	\N	PRESENT	0
510389	502331	07004J	PARTICIPANT	\N	PRESENT	0
510390	502331	19866P	PARTICIPANT	\N	PRESENT	0
510391	502331	20124W	PARTICIPANT	\N	PRESENT	0
510392	502331	07029T	PARTICIPANT	\N	PRESENT	0
510393	502331	14038Y	PARTICIPANT	\N	PRESENT	0
510394	502331	19599P	PARTICIPANT	\N	PRESENT	0
510410	502331	14030Q	PARTICIPANT	\N	PRESENT	0
510396	502331	19671E	PARTICIPANT	\N	PRESENT	0
510397	502331	20038A	PARTICIPANT	\N	PRESENT	0
510398	502331	20070A	PARTICIPANT	\N	PRESENT	0
510399	502331	11072N	PARTICIPANT	\N	PRESENT	0
510400	502331	11090Q	PARTICIPANT	\N	PRESENT	0
510401	502331	20044X	PARTICIPANT	\N	PRESENT	0
510402	502331	19745F	PARTICIPANT	\N	PRESENT	0
510403	502331	11067R	PARTICIPANT	\N	PRESENT	0
510404	502331	96004D	PARTICIPANT	\N	PRESENT	0
510405	502331	14109K	PARTICIPANT	\N	PRESENT	0
510406	502331	19515S	PARTICIPANT	\N	PRESENT	0
510407	502331	19735D	PARTICIPANT	\N	PRESENT	0
510408	502331	19591F	PARTICIPANT	\N	PRESENT	0
510409	502331	20024T	PARTICIPANT	\N	PRESENT	0
510411	502331	20092G	PARTICIPANT	\N	PRESENT	0
510412	502331	14041T	PARTICIPANT	\N	PRESENT	0
510413	502331	19687N	PARTICIPANT	\N	PRESENT	0
510414	502331	19758L	PARTICIPANT	\N	PRESENT	0
510415	502331	14253S	PARTICIPANT	\N	PRESENT	0
510416	502331	11048N	PARTICIPANT	\N	PRESENT	0
510417	502331	14205J	PARTICIPANT	\N	PRESENT	0
510418	502331	11053K	PARTICIPANT	\N	PRESENT	0
510419	502331	11110B	PARTICIPANT	\N	PRESENT	0
510420	502331	05012A	PARTICIPANT	\N	PRESENT	0
510421	502331	20094J	PARTICIPANT	\N	PRESENT	0
510422	502331	19531S	PARTICIPANT	\N	PRESENT	0
510423	502331	14257W	PARTICIPANT	\N	PRESENT	0
510424	502331	19369B	PARTICIPANT	\N	PRESENT	0
510425	502331	19689Q	PARTICIPANT	\N	PRESENT	0
510426	502331	19647E	PARTICIPANT	\N	PRESENT	0
510427	502331	19533U	PARTICIPANT	\N	PRESENT	0
510428	502331	19593H	PARTICIPANT	\N	PRESENT	0
510429	502331	19762G	PARTICIPANT	\N	PRESENT	0
510369	502331	99004R	PARTICIPANT	\N	PRESENT	0
510370	502331	14189C	PARTICIPANT	\N	PRESENT	0
510430	502331	04042C	PARTICIPANT	\N	PRESENT	0
510431	502331	20106U	PARTICIPANT	\N	PRESENT	0
510432	502331	20114U	PARTICIPANT	\N	PRESENT	0
483206	483204	19503N	PARTICIPANT	\N	PRESENT	0
483209	483207	19503N	PARTICIPANT	\N	PRESENT	0
483213	483211	19503N	PARTICIPANT	\N	PRESENT	0
487952	487927	96004D	PARTICIPANT	\N	PRESENT	0
487953	487927	14083S	PARTICIPANT	\N	PRESENT	0
487954	487927	11053K	PARTICIPANT	\N	PRESENT	0
487955	487927	14041T	PARTICIPANT	\N	PRESENT	0
487956	487927	19333N	PARTICIPANT	\N	PRESENT	0
487957	487927	08031R	PARTICIPANT	\N	PRESENT	0
487958	487927	19611R	PARTICIPANT	\N	PRESENT	0
487959	487927	19671E	PARTICIPANT	\N	PRESENT	0
487960	487927	19349W	PARTICIPANT	\N	PRESENT	0
487976	487975	19701S	PARTICIPANT	\N	PRESENT	0
487977	487975	19549D	PARTICIPANT	\N	PRESENT	0
487978	487975	19794Q	PARTICIPANT	\N	PRESENT	0
487980	487979	19637C	PARTICIPANT	\N	PRESENT	0
487981	487979	14051J	PARTICIPANT	\N	PRESENT	0
488067	488066	19631V	PARTICIPANT	\N	PRESENT	0
488068	488066	08018U	PARTICIPANT	\N	PRESENT	0
488069	488066	14059S	PARTICIPANT	\N	PRESENT	0
488070	488066	14147R	PARTICIPANT	\N	PRESENT	0
488071	488066	14357A	PARTICIPANT	\N	PRESENT	0
488072	488066	18083K	PARTICIPANT	\N	PRESENT	0
489675	489344	11031D	PARTICIPANT	\N	PRESENT	0
489676	489344	19663E	PARTICIPANT	\N	PRESENT	0
489677	489344	10006L	PARTICIPANT	\N	PRESENT	0
489678	489344	14041T	PARTICIPANT	\N	PRESENT	0
489679	489344	19649G	PARTICIPANT	\N	PRESENT	0
489680	489344	19691J	PARTICIPANT	\N	PRESENT	0
489681	489344	14081Q	PARTICIPANT	\N	PRESENT	0
489682	489344	19569H	PARTICIPANT	\N	PRESENT	0
489683	489344	19715Y	PARTICIPANT	\N	PRESENT	0
489684	489344	19683J	PARTICIPANT	\N	PRESENT	0
489685	489344	19447X	PARTICIPANT	\N	PRESENT	0
489686	489344	99004R	PARTICIPANT	\N	PRESENT	0
489687	489344	11067R	PARTICIPANT	\N	PRESENT	0
489688	489344	04092N	PARTICIPANT	\N	EXCUSE	0
489689	489344	19667J	PARTICIPANT	\N	PRESENT	0
489690	489344	19573D	PARTICIPANT	\N	PRESENT	0
489691	489344	19503N	PARTICIPANT	\N	PRESENT	0
489692	489344	14331P	PARTICIPANT	\N	PRESENT	0
489693	489344	19766L	PARTICIPANT	\N	PRESENT	0
489694	489344	11097X	PARTICIPANT	\N	PRESENT	0
489695	489344	19703U	PARTICIPANT	\N	PRESENT	0
489696	489344	19479G	PARTICIPANT	\N	PRESENT	0
489697	489344	19553Y	PARTICIPANT	\N	PRESENT	0
489699	489344	19697Q	PARTICIPANT	\N	PRESENT	0
489702	489344	01034P	PARTICIPANT	\N	PRESENT	0
486451	479203	11070L	PARTICIPANT	\N	PRESENT	0
486452	479203	08011M	PARTICIPANT	\N	PRESENT	0
489747	489173	19521Q	PARTICIPANT	\N	PRESENT	0
489748	489173	14026U	PARTICIPANT	\N	PRESENT	0
490084	489867	14133K	PARTICIPANT	\N	PRESENT	0
490085	489867	20032T	PARTICIPANT	\N	PRESENT	0
490086	489867	11109J	PARTICIPANT	\N	PRESENT	0
490087	489867	19760E	PARTICIPANT	\N	PRESENT	0
490088	489867	14189C	PARTICIPANT	\N	PRESENT	0
490089	489867	19717B	PARTICIPANT	\N	PRESENT	0
490090	489867	19631V	PARTICIPANT	\N	PRESENT	0
490091	489867	04085P	PARTICIPANT	\N	PRESENT	0
490092	489867	04059M	PARTICIPANT	\N	PRESENT	0
490093	489867	19515S	PARTICIPANT	\N	PRESENT	0
490094	489867	20112S	PARTICIPANT	\N	PRESENT	0
490095	489867	20076G	PARTICIPANT	\N	PRESENT	0
490096	489867	19651A	PARTICIPANT	\N	PRESENT	0
490097	489867	19741B	PARTICIPANT	\N	PRESENT	0
490098	489867	05008E	PARTICIPANT	\N	PRESENT	0
490099	489867	19667J	PARTICIPANT	\N	PRESENT	0
490100	489867	19543W	PARTICIPANT	\N	PRESENT	0
490101	489867	20024T	PARTICIPANT	\N	PRESENT	0
490102	489867	20022R	PARTICIPANT	\N	PRESENT	0
490103	489867	19954N	PARTICIPANT	\N	PRESENT	0
490104	489867	20110Q	PARTICIPANT	\N	PRESENT	0
490105	489867	11033F	PARTICIPANT	\N	PRESENT	0
490106	489867	19575F	PARTICIPANT	\N	PRESENT	0
490107	489867	19549D	PARTICIPANT	\N	PRESENT	0
490108	489867	20116W	PARTICIPANT	\N	PRESENT	0
490109	489867	14030Q	PARTICIPANT	\N	PRESENT	0
490110	489867	96004D	PARTICIPANT	\N	PRESENT	0
490111	489867	17367Q	PARTICIPANT	\N	PRESENT	0
490112	489867	20086J	PARTICIPANT	\N	PRESENT	0
490113	489867	20094J	PARTICIPANT	\N	PRESENT	0
490114	489867	11040E	PARTICIPANT	\N	PRESENT	0
490115	489867	19367Y	PARTICIPANT	\N	PRESENT	0
490116	489867	14069U	PARTICIPANT	\N	PRESENT	0
490117	489867	19415P	PARTICIPANT	\N	PRESENT	0
490118	489867	20042V	PARTICIPANT	\N	PRESENT	0
490119	489867	14089Y	PARTICIPANT	\N	PRESENT	0
490120	489867	08060W	PARTICIPANT	\N	PRESENT	0
490121	489867	20078J	PARTICIPANT	\N	PRESENT	0
490122	489867	20138D	PARTICIPANT	\N	PRESENT	0
490123	489867	19966S	PARTICIPANT	\N	PRESENT	0
490124	489867	20088L	PARTICIPANT	\N	PRESENT	0
490125	489867	14105F	PARTICIPANT	\N	PRESENT	0
490127	489867	19747H	PARTICIPANT	\N	PRESENT	0
490128	489867	20114U	PARTICIPANT	\N	PRESENT	0
490129	489867	20152B	PARTICIPANT	\N	PRESENT	0
490130	489867	19383Y	PARTICIPANT	\N	PRESENT	0
490131	489867	17737W	PARTICIPANT	\N	PRESENT	0
490132	489867	20080C	PARTICIPANT	\N	PRESENT	0
490133	489867	19621T	PARTICIPANT	\N	PRESENT	0
490134	489867	19758L	PARTICIPANT	\N	PRESENT	0
490135	489867	04047H	PARTICIPANT	\N	PRESENT	0
490136	489867	19782L	PARTICIPANT	\N	PRESENT	0
490137	489867	20090E	PARTICIPANT	\N	PRESENT	0
490138	489867	14207L	PARTICIPANT	\N	PRESENT	0
490139	489867	20104S	PARTICIPANT	\N	PRESENT	0
490140	489867	14255U	PARTICIPANT	\N	PRESENT	0
490141	489867	11101A	PARTICIPANT	\N	PRESENT	0
490142	489867	04042C	PARTICIPANT	\N	PRESENT	0
490143	489867	14053L	PARTICIPANT	\N	PRESENT	0
490144	489867	14083S	PARTICIPANT	\N	PRESENT	0
490145	489867	11053K	PARTICIPANT	\N	PRESENT	0
490146	489867	19545Y	PARTICIPANT	\N	PRESENT	0
490147	489867	20060X	PARTICIPANT	\N	PRESENT	0
490148	489867	11103C	PARTICIPANT	\N	PRESENT	0
490149	489867	12028B	PARTICIPANT	\N	PRESENT	0
490150	489867	19629C	PARTICIPANT	\N	PRESENT	0
490152	489867	14329V	PARTICIPANT	\N	PRESENT	0
490153	489867	14038Y	PARTICIPANT	\N	PRESENT	0
490154	489867	11080N	PARTICIPANT	\N	PRESENT	0
490155	489867	14195A	PARTICIPANT	\N	PRESENT	0
490156	489867	08028W	PARTICIPANT	\N	PRESENT	0
490157	489867	20144B	PARTICIPANT	\N	PRESENT	0
490158	489867	19467C	PARTICIPANT	\N	PRESENT	0
490159	489867	18083K	PARTICIPANT	\N	PRESENT	0
490160	489867	19701S	PARTICIPANT	\N	PRESENT	0
490161	489867	14267Y	PARTICIPANT	\N	PRESENT	0
490162	489867	11031D	PARTICIPANT	\N	PRESENT	0
490163	489867	19295A	PARTICIPANT	\N	PRESENT	0
490164	489867	11027H	PARTICIPANT	\N	PRESENT	0
490165	489867	19681G	PARTICIPANT	\N	PRESENT	0
490167	489867	20070A	PARTICIPANT	\N	PRESENT	0
490168	489867	11056N	PARTICIPANT	\N	PRESENT	0
490169	489867	14357A	PARTICIPANT	\N	PRESENT	0
490170	489867	19525U	PARTICIPANT	\N	PRESENT	0
490171	489867	04086Q	PARTICIPANT	\N	PRESENT	0
490172	489867	11065P	PARTICIPANT	\N	PRESENT	0
490173	489867	19693L	PARTICIPANT	\N	PRESENT	0
490174	489867	14259Y	PARTICIPANT	\N	PRESENT	0
490175	489867	04008A	PARTICIPANT	\N	PRESENT	0
490176	489867	17589D	PARTICIPANT	\N	PRESENT	0
490177	489867	11070L	PARTICIPANT	\N	PRESENT	0
490178	489867	19719D	PARTICIPANT	\N	PRESENT	0
490179	489867	14327T	PARTICIPANT	\N	PRESENT	0
490180	489867	19663E	PARTICIPANT	\N	PRESENT	0
490182	489867	20140W	PARTICIPANT	\N	PRESENT	0
490183	489867	17229F	PARTICIPANT	\N	PRESENT	0
490184	489867	19659J	PARTICIPANT	\N	PRESENT	0
490185	489867	10006L	PARTICIPANT	\N	PRESENT	0
490186	489867	14041T	PARTICIPANT	\N	PRESENT	0
490187	489867	14217N	PARTICIPANT	\N	PRESENT	0
490188	489867	01024M	PARTICIPANT	\N	PRESENT	0
490189	489867	19251M	PARTICIPANT	\N	PRESENT	0
490190	489867	14215L	PARTICIPANT	\N	PRESENT	0
490191	489867	19577H	PARTICIPANT	\N	PRESENT	0
490192	489867	14042U	PARTICIPANT	\N	PRESENT	0
490193	489867	04071H	PARTICIPANT	\N	PRESENT	0
490194	489867	20134Y	PARTICIPANT	\N	PRESENT	0
490195	489867	20124W	PARTICIPANT	\N	PRESENT	0
490196	489867	20040T	PARTICIPANT	\N	PRESENT	0
504307	503159	20096L	PARTICIPANT	\N	PRESENT	0
504308	503159	20024T	PARTICIPANT	\N	PRESENT	0
504309	503159	20038A	PARTICIPANT	\N	PRESENT	0
504310	503159	14219Q	PRESIDENT	0	PRESENT	0
504311	503159	19739H	PARTICIPANT	\N	PRESENT	0
504312	502288	14275Y	PARTICIPANT	\N	PRESENT	0
504313	502288	20108W	PARTICIPANT	\N	PRESENT	0
504314	502288	14179A	PARTICIPANT	\N	PRESENT	0
504315	503159	11065P	PARTICIPANT	\N	PRESENT	1
504316	502288	01028R	PARTICIPANT	\N	PRESENT	0
504317	502288	19447X	PARTICIPANT	\N	PRESENT	0
504318	502288	14089Y	PARTICIPANT	\N	PRESENT	0
504355	502288	04085P	PARTICIPANT	\N	PRESENT	0
504356	502288	17737W	PARTICIPANT	\N	PRESENT	0
504357	502288	19729F	PARTICIPANT	\N	PRESENT	0
504359	503159	19637C	PARTICIPANT	\N	PRESENT	0
504360	503159	17637T	PARTICIPANT	\N	PRESENT	0
504361	503159	20118Y	PARTICIPANT	\N	PRESENT	0
504362	503159	11101A	PARTICIPANT	\N	EXCUSE	0
504363	503159	20100N	PARTICIPANT	\N	PRESENT	0
504364	503159	19681G	PARTICIPANT	\N	EXCUSE	0
504365	502448	14331P	PARTICIPANT	\N	PRESENT	0
504366	502448	20050V	PARTICIPANT	\N	PRESENT	0
504367	501780	11099A	PARTICIPANT	\N	PRESENT	1
504368	501780	08015R	PARTICIPANT	\N	PRESENT	0
504369	501780	20018V	PARTICIPANT	\N	PRESENT	1
504305	502288	08010L	PARTICIPANT	\N	PRESENT	0
504306	502288	04047H	PRESIDENT	0	PRESENT	0
504370	501780	04086Q	PARTICIPANT	\N	PRESENT	0
504371	501780	14207L	PARTICIPANT	\N	PRESENT	1
504372	501780	19413M	PARTICIPANT	\N	PRESENT	1
504380	503134	04070G	PARTICIPANT	\N	PRESENT	0
504381	503134	19699S	PARTICIPANT	\N	PRESENT	0
504382	503134	19533U	PARTICIPANT	\N	PRESENT	0
504383	503134	19329S	PARTICIPANT	\N	PRESENT	0
504384	503134	14229S	PARTICIPANT	\N	PRESENT	0
504385	503134	20098N	PARTICIPANT	\N	PRESENT	0
504386	503134	19573D	PARTICIPANT	\N	PRESENT	0
504387	503134	08012N	PARTICIPANT	\N	PRESENT	0
504388	503134	20124W	PARTICIPANT	\N	PRESENT	0
504389	503134	20026V	PARTICIPANT	\N	PRESENT	0
504390	503134	19527W	PARTICIPANT	\N	PRESENT	0
504391	503134	19593H	PARTICIPANT	\N	PRESENT	0
504392	503134	19643A	PARTICIPANT	\N	PRESENT	0
504393	503134	20132W	PARTICIPANT	\N	PRESENT	0
504394	503134	20134Y	PARTICIPANT	\N	PRESENT	0
504395	503134	19651A	PARTICIPANT	\N	PRESENT	0
504396	503134	20138D	PARTICIPANT	\N	PRESENT	0
504353	501819	08073C	PARTICIPANT	\N	PRESENT	0
504354	502288	11072N	PARTICIPANT	\N	PRESENT	0
504397	503134	19611R	PRESIDENT	0	PRESENT	0
504398	503134	20142Y	PARTICIPANT	\N	PRESENT	0
504399	503134	20048C	PARTICIPANT	\N	PRESENT	0
504400	503134	19693L	PARTICIPANT	\N	PRESENT	0
504401	503134	20052X	PARTICIPANT	\N	PRESENT	0
504402	503134	20058E	PARTICIPANT	\N	PRESENT	0
504403	503134	14030Q	PARTICIPANT	\N	PRESENT	0
504404	503134	20056C	PARTICIPANT	\N	PRESENT	0
504405	503134	19735D	PARTICIPANT	\N	PRESENT	0
504406	503134	14109K	PARTICIPANT	\N	PRESENT	0
504407	503134	14123H	PARTICIPANT	\N	PRESENT	0
504408	503134	11043H	PARTICIPANT	\N	PRESENT	0
504409	503134	11104D	PARTICIPANT	\N	PRESENT	0
504410	503134	19758L	PARTICIPANT	\N	PRESENT	0
504411	503134	19621T	PARTICIPANT	\N	PRESENT	0
504412	503134	20084G	PARTICIPANT	\N	PRESENT	0
504413	501819	14225N	PARTICIPANT	\N	PRESENT	0
504414	501819	96004D	PARTICIPANT	\N	PRESENT	0
504415	501819	11083R	PARTICIPANT	\N	PRESENT	0
504416	501819	20112S	PARTICIPANT	\N	PRESENT	0
504417	501819	20028X	PARTICIPANT	\N	PRESENT	0
504418	501819	19531S	PARTICIPANT	\N	PRESENT	0
504419	501819	19631V	PARTICIPANT	\N	PRESENT	0
504420	501819	04057K	PARTICIPANT	\N	PRESENT	0
504421	501819	19349W	PARTICIPANT	\N	PRESENT	0
504422	501819	19629C	PARTICIPANT	\N	PRESENT	0
504423	501819	20074E	PARTICIPANT	\N	PRESENT	0
504424	501819	14207L	PARTICIPANT	\N	PRESENT	0
504425	501819	11090Q	PARTICIPANT	\N	PRESENT	0
504426	501819	14083S	PARTICIPANT	\N	PRESENT	0
504427	501819	19760E	PARTICIPANT	\N	PRESENT	0
504428	501819	20172F	PARTICIPANT	\N	PRESENT	0
504429	501819	19701S	PARTICIPANT	\N	PRESENT	0
504430	501819	14038Y	PARTICIPANT	\N	PRESENT	0
504431	501819	20034V	PARTICIPANT	\N	PRESENT	0
504432	501819	20024T	PARTICIPANT	\N	PRESENT	0
504433	501819	19758L	PARTICIPANT	\N	PRESENT	0
504434	501819	20054A	PARTICIPANT	\N	PRESENT	0
504435	501819	19387D	PARTICIPANT	\N	PRESENT	0
504439	501819	19347U	PARTICIPANT	\N	PRESENT	0
504437	501819	19741B	PARTICIPANT	\N	PRESENT	0
504438	501819	18083K	PARTICIPANT	\N	PRESENT	0
504440	501819	20100N	PARTICIPANT	\N	PRESENT	0
504441	501819	19565D	PARTICIPANT	\N	PRESENT	0
504442	501819	19507S	PARTICIPANT	\N	PRESENT	0
504443	501819	20032T	PARTICIPANT	\N	PRESENT	0
504444	501819	19441R	PARTICIPANT	\N	PRESENT	0
504445	501819	14147R	PARTICIPANT	\N	PRESENT	0
504446	501819	20026V	PARTICIPANT	\N	PRESENT	0
504448	501819	19954N	PARTICIPANT	\N	PRESENT	0
504449	501819	20140W	PARTICIPANT	\N	PRESENT	0
504450	501819	19693L	PARTICIPANT	\N	PRESENT	0
504451	501819	20070A	PARTICIPANT	\N	PRESENT	0
504452	501819	14105F	PARTICIPANT	\N	PRESENT	0
504453	501819	20056C	PARTICIPANT	\N	PRESENT	0
504454	501819	20096L	PARTICIPANT	\N	PRESENT	0
504455	501819	20086J	PARTICIPANT	\N	PRESENT	0
504456	501819	19573D	PARTICIPANT	\N	PRESENT	0
504457	501819	20030R	PARTICIPANT	\N	PRESENT	0
504458	501819	20082E	PARTICIPANT	\N	PRESENT	0
504459	501819	01057W	PARTICIPANT	\N	PRESENT	0
504460	501819	14213J	PARTICIPANT	\N	PRESENT	0
504461	501819	07029T	PARTICIPANT	\N	PRESENT	0
504462	501819	19383Y	PARTICIPANT	\N	PRESENT	0
504477	499975	19399H	PARTICIPANT	\N	PRESENT	0
504478	499975	04059M	PARTICIPANT	\N	PRESENT	0
504479	499976	19399H	PARTICIPANT	\N	PRESENT	0
504480	499976	04059M	PARTICIPANT	\N	PRESENT	0
504481	499976	04070G	PARTICIPANT	\N	PRESENT	0
504537	504536	19399H	PARTICIPANT	\N	PRESENT	0
504682	503158	17637T	PARTICIPANT	\N	PRESENT	1
504798	501910	19760E	PARTICIPANT	\N	PRESENT	0
504799	501910	10006L	PRESIDENT	0	PRESENT	0
504800	501910	19591F	PARTICIPANT	\N	PRESENT	0
504801	501910	14042U	PARTICIPANT	\N	PRESENT	0
504802	501910	19715Y	PARTICIPANT	\N	PRESENT	0
504803	501910	11067R	PARTICIPANT	\N	PRESENT	0
504804	501910	19713W	PARTICIPANT	\N	PRESENT	0
504805	501910	19691J	PARTICIPANT	\N	PRESENT	0
504806	501910	18193Q	PARTICIPANT	\N	PRESENT	0
504807	501910	04057K	PARTICIPANT	\N	PRESENT	1
504808	501910	17779H	PARTICIPANT	\N	PRESENT	0
504809	501910	14223L	PARTICIPANT	\N	PRESENT	0
504810	501910	17965H	PARTICIPANT	\N	PRESENT	1
504811	501910	20090E	PARTICIPANT	\N	PRESENT	0
504812	501910	14217N	PARTICIPANT	\N	PRESENT	0
504813	501910	20040T	PARTICIPANT	\N	PRESENT	0
504814	501910	20066E	PARTICIPANT	\N	PRESENT	0
504815	501910	19663E	PARTICIPANT	\N	PRESENT	0
504816	501910	19657G	PARTICIPANT	\N	PRESENT	1
504817	501910	11103C	PARTICIPANT	\N	PRESENT	1
504818	501910	04043D	PARTICIPANT	\N	PRESENT	1
504819	501910	14281W	PARTICIPANT	\N	PRESENT	1
504820	501910	01034P	PARTICIPANT	\N	PRESENT	1
504821	501910	11097X	PARTICIPANT	\N	PRESENT	0
504822	501910	19703U	PARTICIPANT	\N	PRESENT	0
504823	501910	19798U	PARTICIPANT	\N	PRESENT	1
504824	501910	19679N	PARTICIPANT	\N	PRESENT	0
504825	501910	20130U	PARTICIPANT	\N	PRESENT	1
504826	501910	14071N	PARTICIPANT	\N	PRESENT	0
504827	501910	19697Q	PARTICIPANT	\N	PRESENT	1
504828	501910	19723Y	PARTICIPANT	\N	PRESENT	1
504829	501910	19569H	PARTICIPANT	\N	PRESENT	1
504830	501910	19553Y	PARTICIPANT	\N	PRESENT	0
504831	501910	14026U	PARTICIPANT	\N	PRESENT	1
504832	501910	19367Y	PARTICIPANT	\N	PRESENT	0
504833	501910	14355X	PARTICIPANT	\N	EXCUSE	0
504834	501910	14213J	PARTICIPANT	\N	PRESENT	0
504835	501910	19717B	PARTICIPANT	\N	PRESENT	1
504836	501910	19415P	PARTICIPANT	\N	PRESENT	1
504837	501910	19966S	PARTICIPANT	\N	PRESENT	0
485922	484505	11070L	PARTICIPANT	\N	PRESENT	0
485923	484506	11070L	PARTICIPANT	\N	PRESENT	0
487702	485910	10006L	PARTICIPANT	\N	PRESENT	0
487703	485910	19663E	PARTICIPANT	\N	PRESENT	0
487704	485910	19643A	PARTICIPANT	\N	PRESENT	0
487705	485910	19503N	PARTICIPANT	\N	PRESENT	0
487706	485910	04092N	PRESIDENT	0	PRESENT	0
487707	485910	11067R	PARTICIPANT	\N	PRESENT	0
487708	485910	99004R	PARTICIPANT	\N	PRESENT	0
487709	485910	19715Y	PARTICIPANT	\N	PRESENT	0
487710	485910	19683J	PARTICIPANT	\N	PRESENT	0
487711	485910	19447X	PARTICIPANT	\N	PRESENT	0
487712	485910	11097X	PARTICIPANT	\N	PRESENT	0
487713	485910	14331P	PARTICIPANT	\N	PRESENT	0
487714	485910	19766L	PARTICIPANT	\N	PRESENT	0
487715	485910	14081Q	PARTICIPANT	\N	PRESENT	0
487716	485910	19573D	PARTICIPANT	\N	PRESENT	0
487717	485910	19703U	PARTICIPANT	\N	PRESENT	0
487719	485910	19697Q	PARTICIPANT	\N	PRESENT	0
487720	485910	11031D	PARTICIPANT	\N	PRESENT	0
487721	485910	11048N	PARTICIPANT	\N	PRESENT	0
487775	485910	11072N	PARTICIPANT	\N	PRESENT	0
487791	485910	19545Y	PARTICIPANT	\N	EXCUSE	0
487793	485910	14041T	PARTICIPANT	\N	EXCUSE	0
487794	485910	01034P	PARTICIPANT	\N	PRESENT	0
489570	489341	19663E	PARTICIPANT	\N	EXCUSE	0
489571	489341	11067R	PARTICIPANT	\N	PRESENT	0
489572	489341	04092N	PARTICIPANT	\N	EXCUSE	0
489573	489341	10006L	PARTICIPANT	\N	PRESENT	0
489574	489341	19649G	PARTICIPANT	\N	PRESENT	0
489575	489341	19691J	PARTICIPANT	\N	PRESENT	0
489576	489341	19569H	PARTICIPANT	\N	PRESENT	0
489577	489341	11048N	PARTICIPANT	\N	PRESENT	0
489578	489341	14081Q	PARTICIPANT	\N	PRESENT	0
489579	489341	19715Y	PARTICIPANT	\N	PRESENT	0
489580	489341	19683J	PARTICIPANT	\N	PRESENT	0
489581	489341	99004R	PARTICIPANT	\N	PRESENT	0
489582	489341	19573D	PARTICIPANT	\N	PRESENT	0
489583	489341	19503N	PARTICIPANT	\N	PRESENT	0
489584	489341	14331P	PARTICIPANT	\N	PRESENT	0
489585	489341	19766L	PARTICIPANT	\N	PRESENT	0
489586	489341	11097X	PRESIDENT	0	PRESENT	0
489587	489341	19479G	PARTICIPANT	\N	PRESENT	0
489588	489341	19697Q	PARTICIPANT	\N	PRESENT	0
489589	489341	19703U	PARTICIPANT	\N	PRESENT	0
489590	489341	14041T	PARTICIPANT	\N	PRESENT	0
489591	489341	11031D	PARTICIPANT	\N	PRESENT	0
489610	489342	19643A	PARTICIPANT	\N	PRESENT	0
489611	489342	19663E	PARTICIPANT	\N	PRESENT	0
489612	489342	10006L	PARTICIPANT	\N	PRESENT	0
489613	489342	19691J	PARTICIPANT	\N	PRESENT	0
489614	489342	19715Y	PARTICIPANT	\N	PRESENT	0
489615	489342	04092N	PARTICIPANT	\N	EXCUSE	0
489616	489342	19573D	PARTICIPANT	\N	PRESENT	0
489617	489342	19503N	PARTICIPANT	\N	PRESENT	0
489618	489342	14331P	PARTICIPANT	\N	PRESENT	0
489619	489342	19766L	PARTICIPANT	\N	PRESENT	0
489620	489342	11097X	PRESIDENT	0	PRESENT	0
489621	489342	11067R	PARTICIPANT	\N	PRESENT	0
489622	489342	19447X	PARTICIPANT	\N	PRESENT	0
489623	489342	19703U	PARTICIPANT	\N	PRESENT	0
489624	489342	19479G	PARTICIPANT	\N	PRESENT	0
489888	489887	01028R	PARTICIPANT	\N	PRESENT	0
493210	493192	14071N	PARTICIPANT	\N	PRESENT	0
493211	493192	19798U	PARTICIPANT	\N	PRESENT	0
493215	493193	14071N	PARTICIPANT	\N	PRESENT	0
493217	493193	19798U	PARTICIPANT	\N	PRESENT	0
493220	493194	14071N	PARTICIPANT	\N	PRESENT	0
493221	493194	19798U	PARTICIPANT	\N	PRESENT	0
493264	491476	11012A	PARTICIPANT	\N	EXCUSE	0
493789	493357	19347U	PARTICIPANT	\N	PRESENT	0
493783	493411	11104D	PARTICIPANT	\N	PRESENT	0
493784	493411	19758L	PARTICIPANT	\N	PRESENT	0
493785	493411	17589D	PARTICIPANT	\N	PRESENT	0
493786	493411	19621T	PRESIDENT	0	PRESENT	0
493787	493357	14251Q	PARTICIPANT	\N	PRESENT	0
493788	493357	01043Q	PARTICIPANT	\N	PRESENT	0
493790	493357	14071N	PARTICIPANT	\N	PRESENT	0
495892	495035	96004D	PARTICIPANT	\N	PRESENT	0
495893	495035	11074Q	PARTICIPANT	\N	PRESENT	0
495894	495035	20036X	PARTICIPANT	\N	PRESENT	0
495895	495035	19479G	PARTICIPANT	\N	PRESENT	0
495897	495266	01028R	PARTICIPANT	\N	EXCUSE	0
499123	499122	04042C	PARTICIPANT	\N	PRESENT	0
499381	498009	14219Q	PARTICIPANT	\N	PRESENT	0
501271	495438	11056N	PARTICIPANT	\N	PRESENT	0
501272	495438	20042V	PARTICIPANT	\N	PRESENT	0
502926	500289	11045K	PARTICIPANT	\N	PRESENT	0
502927	500289	14213J	PARTICIPANT	\N	PRESENT	0
502928	500289	19591F	PARTICIPANT	\N	PRESENT	0
502929	500289	19760E	PARTICIPANT	\N	PRESENT	0
502930	500289	11031D	PARTICIPANT	\N	PRESENT	0
502931	500289	19649G	PARTICIPANT	\N	PRESENT	0
502932	500289	11067R	PARTICIPANT	\N	PRESENT	0
502933	500289	18193Q	PARTICIPANT	\N	PRESENT	0
502934	500289	19715Y	PARTICIPANT	\N	PRESENT	0
502935	500289	19599P	PARTICIPANT	\N	PRESENT	0
502936	500289	20106U	PARTICIPANT	\N	PRESENT	0
502937	500289	19301E	PARTICIPANT	\N	PRESENT	0
502938	500289	11065P	PARTICIPANT	\N	PRESENT	0
502939	500289	04092N	PARTICIPANT	\N	PRESENT	0
502940	500289	20130U	PARTICIPANT	\N	PRESENT	0
502941	500289	14071N	PARTICIPANT	\N	PRESENT	0
502942	500289	19347U	PARTICIPANT	\N	PRESENT	0
502943	500289	20034V	PARTICIPANT	\N	PRESENT	0
502944	500289	19713W	PARTICIPANT	\N	PRESENT	0
502945	500289	14042U	PARTICIPANT	\N	PRESENT	0
502946	500289	17737W	PARTICIPANT	\N	PRESENT	0
502947	500289	19717B	PARTICIPANT	\N	PRESENT	0
502948	500289	17637T	PARTICIPANT	\N	PRESENT	0
502949	500289	04057K	PARTICIPANT	\N	PRESENT	0
502950	500289	19691J	PARTICIPANT	\N	PRESENT	0
502951	500289	19569H	PARTICIPANT	\N	PRESENT	0
502952	500289	19657G	PARTICIPANT	\N	PRESENT	0
502953	500289	19711U	PARTICIPANT	\N	PRESENT	0
502954	500289	19663E	PARTICIPANT	\N	PRESENT	0
502955	500289	14026U	PARTICIPANT	\N	PRESENT	0
502956	500289	11097X	PARTICIPANT	\N	PRESENT	0
502957	500289	14217N	PARTICIPANT	\N	PRESENT	0
502958	500289	20126Y	PARTICIPANT	\N	PRESENT	0
502959	500289	20152B	PARTICIPANT	\N	PRESENT	0
502960	500289	19683J	PARTICIPANT	\N	PRESENT	0
502961	500289	19679N	PARTICIPANT	\N	PRESENT	0
502962	500289	17965H	PARTICIPANT	\N	PRESENT	0
502963	500289	20098N	PARTICIPANT	\N	PRESENT	0
502964	500289	08045X	PARTICIPANT	\N	PRESENT	0
502965	500289	10006L	PARTICIPANT	\N	PRESENT	0
502966	500289	14281W	PARTICIPANT	\N	PRESENT	0
502967	500289	19553Y	PARTICIPANT	\N	PRESENT	0
502968	500289	19798U	PARTICIPANT	\N	PRESENT	0
502969	500289	19575F	PARTICIPANT	\N	PRESENT	0
502970	500289	19697Q	PARTICIPANT	\N	PRESENT	0
502971	500289	19723Y	PARTICIPANT	\N	PRESENT	0
502972	500289	19687N	PARTICIPANT	\N	PRESENT	0
502973	500289	17779H	PARTICIPANT	\N	PRESENT	0
502974	500289	04043D	PARTICIPANT	\N	PRESENT	0
502975	500289	14123H	PARTICIPANT	\N	PRESENT	0
502976	500289	14069U	PARTICIPANT	\N	PRESENT	0
505733	505732	04043D	PARTICIPANT	\N	PRESENT	0
505736	505735	04043D	PARTICIPANT	\N	PRESENT	0
505739	505738	04043D	PARTICIPANT	\N	PRESENT	0
505741	505740	04043D	PARTICIPANT	\N	PRESENT	0
505749	502267	19717B	PARTICIPANT	\N	PRESENT	0
505750	502267	19515S	PARTICIPANT	\N	PRESENT	0
505751	502267	14105F	PARTICIPANT	\N	PRESENT	0
505752	502267	20060X	PARTICIPANT	\N	PRESENT	0
505753	502267	14041T	PARTICIPANT	\N	PRESENT	0
505754	502267	19695N	PARTICIPANT	\N	PRESENT	0
505755	502267	14026U	PARTICIPANT	\N	PRESENT	0
505756	502267	20126Y	PARTICIPANT	\N	PRESENT	0
505757	502267	08015R	PARTICIPANT	\N	PRESENT	0
505758	502267	16685X	PARTICIPANT	\N	PRESENT	0
505759	502267	14031R	PARTICIPANT	\N	PRESENT	0
505760	502267	20092G	PARTICIPANT	\N	PRESENT	0
505761	502267	19762G	PARTICIPANT	\N	PRESENT	0
505762	502267	14255U	PARTICIPANT	\N	PRESENT	0
505763	502267	11026G	PARTICIPANT	\N	PRESENT	0
505764	502267	04034C	PARTICIPANT	\N	PRESENT	0
505999	501820	20150Y	PARTICIPANT	\N	PRESENT	0
506845	496311	19651A	PARTICIPANT	\N	PRESENT	0
507873	496311	20018V	PARTICIPANT	\N	EXCUSE	0
507874	496311	04071H	PARTICIPANT	\N	EXCUSE	0
508411	496311	20032T	PARTICIPANT	\N	PRESENT	0
508412	496311	19643A	PARTICIPANT	\N	PRESENT	0
508413	496311	19399H	PARTICIPANT	\N	PRESENT	0
508415	496311	19711U	PARTICIPANT	\N	PRESENT	0
508419	496311	20044X	PARTICIPANT	\N	PRESENT	0
508805	496311	11040E	PARTICIPANT	\N	EXCUSE	0
510469	502332	19695N	PARTICIPANT	\N	PRESENT	0
510470	502332	19599P	PARTICIPANT	\N	PRESENT	0
510471	502332	20092G	PARTICIPANT	\N	PRESENT	0
510472	502332	19717B	PARTICIPANT	\N	PRESENT	0
510473	502332	20116W	PARTICIPANT	\N	PRESENT	0
510474	502332	19866P	PARTICIPANT	\N	PRESENT	0
510475	502332	14205J	PARTICIPANT	\N	PRESENT	0
510476	502332	19745F	PARTICIPANT	\N	PRESENT	0
510477	502332	07004J	PARTICIPANT	\N	PRESENT	0
510467	502332	14026U	PARTICIPANT	\N	PRESENT	0
510468	502332	19593H	PARTICIPANT	\N	PRESENT	0
510478	502332	19671E	PARTICIPANT	\N	PRESENT	0
510479	502332	19762G	PARTICIPANT	\N	PRESENT	0
510480	502332	20124W	PARTICIPANT	\N	PRESENT	0
510481	502332	19711U	PARTICIPANT	\N	PRESENT	0
510482	502332	11048N	PARTICIPANT	\N	PRESENT	0
510483	502332	20034V	PARTICIPANT	\N	PRESENT	0
510484	502332	11090Q	PARTICIPANT	\N	PRESENT	0
510485	502332	20044X	PARTICIPANT	\N	PRESENT	0
510486	502332	20094J	PARTICIPANT	\N	PRESENT	0
510487	502332	19687N	PARTICIPANT	\N	PRESENT	0
510488	502332	07029T	PARTICIPANT	\N	PRESENT	0
510489	502332	14041T	PARTICIPANT	\N	PRESENT	0
510490	502332	19515S	PARTICIPANT	\N	PRESENT	0
510491	502332	19741B	PARTICIPANT	\N	PRESENT	0
510492	502332	19643A	PARTICIPANT	\N	PRESENT	0
510493	502332	19621T	PARTICIPANT	\N	PRESENT	0
510494	502332	11026G	PARTICIPANT	\N	PRESENT	0
510495	502332	20070A	PARTICIPANT	\N	PRESENT	0
510496	502332	11110B	PARTICIPANT	\N	PRESENT	0
510497	502332	14257W	PARTICIPANT	\N	PRESENT	0
510498	502332	20114U	PARTICIPANT	\N	PRESENT	0
510499	502332	11065P	PARTICIPANT	\N	PRESENT	0
510500	502332	19369B	PARTICIPANT	\N	PRESENT	0
510501	502332	14038Y	PARTICIPANT	\N	PRESENT	0
510502	502332	19647E	PARTICIPANT	\N	PRESENT	0
510503	502332	20110Q	PARTICIPANT	\N	PRESENT	0
510504	502332	19689Q	PARTICIPANT	\N	PRESENT	0
510505	502332	20080C	PARTICIPANT	\N	PRESENT	0
510506	502332	14083S	PARTICIPANT	\N	PRESENT	0
510507	502332	04071H	PARTICIPANT	\N	PRESENT	0
510508	502332	19563B	PARTICIPANT	\N	PRESENT	0
510509	502332	05012A	PARTICIPANT	\N	PRESENT	0
510510	502332	20106U	PARTICIPANT	\N	PRESENT	0
511836	509268	19760E	PARTICIPANT	\N	PRESENT	0
511837	509268	11031D	PARTICIPANT	\N	PRESENT	0
511838	509268	19703U	PARTICIPANT	\N	PRESENT	0
511879	509268	19367Y	PARTICIPANT	\N	EXCUSE	0
511840	509268	20130U	PARTICIPANT	\N	PRESENT	0
511841	509268	04043D	PARTICIPANT	\N	PRESENT	0
511844	509268	18193Q	PARTICIPANT	\N	PRESENT	0
511845	509268	14042U	PARTICIPANT	\N	PRESENT	0
511846	509268	19691J	PARTICIPANT	\N	PRESENT	0
511847	509268	20090E	PARTICIPANT	\N	PRESENT	0
511848	509268	11103C	PARTICIPANT	\N	PRESENT	1
511849	509268	19663E	PARTICIPANT	\N	PRESENT	0
511850	509268	17779H	PARTICIPANT	\N	EXCUSE	0
511852	509268	14213J	PARTICIPANT	\N	PRESENT	0
511853	509268	11097X	PARTICIPANT	\N	PRESENT	0
511855	509268	14217N	PARTICIPANT	\N	PRESENT	0
511856	509268	10006L	PRESIDENT	0	PRESENT	0
511858	509268	20066E	PARTICIPANT	\N	PRESENT	0
511859	509268	14223L	PARTICIPANT	\N	PRESENT	1
511860	509268	19798U	PARTICIPANT	\N	PRESENT	0
511861	509268	14071N	PARTICIPANT	\N	PRESENT	0
511862	509268	11067R	PARTICIPANT	\N	PRESENT	0
511863	509268	14026U	PARTICIPANT	\N	PRESENT	1
511864	509268	19697Q	PARTICIPANT	\N	PRESENT	1
511866	509268	14281W	PARTICIPANT	\N	PRESENT	1
511867	509268	04057K	PARTICIPANT	\N	PRESENT	0
511868	509268	19301E	PARTICIPANT	\N	PRESENT	0
511869	509268	19569H	PARTICIPANT	\N	PRESENT	1
511870	509268	20040T	PARTICIPANT	\N	PRESENT	0
512110	512101	20094J	PARTICIPANT	\N	PRESENT	0
512111	512101	20104S	PARTICIPANT	\N	PRESENT	0
512112	512101	19521Q	PARTICIPANT	\N	PRESENT	0
512113	512101	19820Y	PARTICIPANT	\N	PRESENT	0
512114	512101	19745F	PARTICIPANT	\N	PRESENT	0
512235	509874	20128B	PARTICIPANT	\N	PRESENT	1
512236	502346	19479G	PARTICIPANT	\N	PRESENT	0
512238	509965	11070L	PARTICIPANT	\N	PRESENT	0
512469	509270	11109J	PARTICIPANT	\N	PRESENT	0
512470	509270	19631V	PARTICIPANT	\N	PRESENT	0
512471	509270	04085P	PARTICIPANT	\N	PRESENT	0
512472	509270	05008E	PARTICIPANT	\N	PRESENT	0
512473	509270	14259Y	PARTICIPANT	\N	PRESENT	0
512474	509270	19673G	PARTICIPANT	\N	PRESENT	0
512475	509270	97011G	PARTICIPANT	\N	PRESENT	0
512476	509270	19347U	PARTICIPANT	\N	PRESENT	0
512477	509270	19691J	PARTICIPANT	\N	PRESENT	0
512478	509270	20034V	PARTICIPANT	\N	PRESENT	0
512479	509270	19715Y	PARTICIPANT	\N	PRESENT	0
512480	509270	08034U	PARTICIPANT	\N	PRESENT	0
512481	509270	14059S	PARTICIPANT	\N	PRESENT	0
512482	509270	12016W	PARTICIPANT	\N	PRESENT	0
512483	509270	19657G	PARTICIPANT	\N	PRESENT	0
512484	509270	14147R	PARTICIPANT	\N	PRESENT	0
512485	509270	11072N	PARTICIPANT	\N	PRESENT	0
512486	509270	08073C	PARTICIPANT	\N	PRESENT	0
512487	509270	20148F	PARTICIPANT	\N	PRESENT	0
512488	509270	19301E	PARTICIPANT	\N	PRESENT	0
512489	509270	14275Y	PARTICIPANT	\N	PRESENT	0
512490	509270	20150Y	PARTICIPANT	\N	PRESENT	0
512491	509270	17023S	PARTICIPANT	\N	PRESENT	0
512493	510129	19735D	PARTICIPANT	\N	EXCUSE	0
512494	510129	01048V	PARTICIPANT	\N	PRESENT	0
512495	510129	19563B	PARTICIPANT	\N	PRESENT	0
512497	510129	01058X	PARTICIPANT	\N	PRESENT	0
512498	510129	04043D	PARTICIPANT	\N	PRESENT	0
512499	510129	19503N	PARTICIPANT	\N	PRESENT	0
512500	510129	19533U	PARTICIPANT	\N	PRESENT	0
512501	510129	11067R	PARTICIPANT	\N	PRESENT	0
512502	510129	19693L	PARTICIPANT	\N	EXCUSE	0
512503	510129	19723Y	PARTICIPANT	\N	PRESENT	0
512504	510129	20072C	PARTICIPANT	\N	PRESENT	0
512506	512505	95063L	PARTICIPANT	\N	PRESENT	0
512507	512505	14215L	PARTICIPANT	\N	PRESENT	0
512532	509966	19741B	PARTICIPANT	\N	PRESENT	0
512533	509966	20080C	PARTICIPANT	\N	PRESENT	0
512534	509966	11053K	PARTICIPANT	\N	PRESENT	0
512535	509966	20070A	PARTICIPANT	\N	PRESENT	0
512536	509966	04071H	PARTICIPANT	\N	PRESENT	0
512537	509966	11048N	PARTICIPANT	\N	PRESENT	0
512538	509966	14121F	PARTICIPANT	\N	PRESENT	0
512539	509966	99004R	PARTICIPANT	\N	PRESENT	0
512540	509966	07029T	PARTICIPANT	\N	PRESENT	0
512541	509966	19711U	PARTICIPANT	\N	PRESENT	0
512542	509966	08010L	PARTICIPANT	\N	PRESENT	0
512543	509966	08034U	PARTICIPANT	\N	PRESENT	0
512544	509966	19671E	PARTICIPANT	\N	PRESENT	0
512545	509966	14253S	PARTICIPANT	\N	PRESENT	0
512546	509966	08073C	PARTICIPANT	\N	PRESENT	0
512548	509966	14225N	PRESIDENT	0	PRESENT	0
512550	509966	20150Y	PARTICIPANT	\N	PRESENT	0
512552	509966	20044X	PARTICIPANT	\N	PRESENT	0
512553	509966	19762G	PARTICIPANT	\N	PRESENT	0
512555	509966	19689Q	PARTICIPANT	\N	PRESENT	0
512556	509966	19479G	PARTICIPANT	\N	PRESENT	0
512557	509966	14173T	PARTICIPANT	\N	PRESENT	0
512623	507957	19515S	PRESIDENT	0	PRESENT	0
512624	507957	20094J	PARTICIPANT	\N	PRESENT	0
512625	507957	14105F	PARTICIPANT	\N	PRESENT	0
512626	507957	14083S	PARTICIPANT	\N	PRESENT	0
512627	507957	14329V	PARTICIPANT	\N	PRESENT	0
512628	507957	19467C	PARTICIPANT	\N	PRESENT	0
512629	507957	14357A	PARTICIPANT	\N	PRESENT	0
512630	507957	20040T	PARTICIPANT	\N	PRESENT	0
512631	507957	14026U	PARTICIPANT	\N	PRESENT	0
512632	507957	20126Y	PARTICIPANT	\N	PRESENT	0
512633	507957	08015R	PARTICIPANT	\N	PRESENT	0
512634	507957	16685X	PARTICIPANT	\N	PRESENT	0
489074	489072	08012N	PRESIDENT	0	PRESENT	0
489075	489072	14030Q	PARTICIPANT	\N	EXCUSE	0
489076	489072	19758L	PARTICIPANT	\N	EXCUSE	0
489077	489072	14249W	PARTICIPANT	\N	EXCUSE	0
489078	489072	14241N	PARTICIPANT	\N	EXCUSE	0
489079	489072	14073Q	PARTICIPANT	\N	EXCUSE	0
489080	489072	19581D	PARTICIPANT	\N	EXCUSE	0
489081	489072	14147R	PARTICIPANT	\N	EXCUSE	0
489082	489072	14173T	PARTICIPANT	\N	EXCUSE	0
489083	489072	19251M	PARTICIPANT	\N	PRESENT	0
489084	489072	02002K	PARTICIPANT	\N	PRESENT	0
489085	489072	19399H	PARTICIPANT	\N	PRESENT	0
489086	489072	19533U	PARTICIPANT	\N	PRESENT	0
489087	489072	19349W	PARTICIPANT	\N	PRESENT	0
489088	489072	11043H	PARTICIPANT	\N	PRESENT	0
489089	489072	19711U	PARTICIPANT	\N	PRESENT	0
489090	489072	19721W	PARTICIPANT	\N	EXCUSE	0
489300	485176	87003B	PARTICIPANT	\N	EXCUSE	0
489301	485176	19525U	PARTICIPANT	\N	EXCUSE	0
489302	485176	14121F	PRESIDENT	0	PRESENT	0
489303	485176	19551W	PARTICIPANT	\N	PRESENT	0
489304	485176	19531S	PARTICIPANT	\N	PRESENT	0
489305	485176	19399H	PARTICIPANT	\N	PRESENT	0
489306	485176	02002K	PARTICIPANT	\N	PRESENT	0
489337	485176	19741B	PARTICIPANT	\N	PRESENT	0
489488	489487	19926J	PARTICIPANT	\N	PRESENT	0
489489	489487	19679N	PARTICIPANT	\N	PRESENT	0
489491	489490	19926J	PARTICIPANT	\N	PRESENT	0
489492	489490	19679N	PARTICIPANT	\N	PRESENT	0
489493	489490	01034P	PARTICIPANT	\N	PRESENT	0
489495	489494	19926J	PARTICIPANT	\N	PRESENT	0
489496	489494	19679N	PARTICIPANT	\N	PRESENT	0
489498	489497	19679N	PARTICIPANT	\N	PRESENT	0
489500	489499	19693L	PARTICIPANT	\N	PRESENT	0
489501	489499	19593H	PARTICIPANT	\N	PRESENT	0
489502	489499	19533U	PARTICIPANT	\N	PRESENT	0
489503	489499	19611R	PARTICIPANT	\N	PRESENT	0
489505	489504	19693L	PARTICIPANT	\N	PRESENT	0
489506	489504	19533U	PARTICIPANT	\N	PRESENT	0
489507	489504	19611R	PARTICIPANT	\N	PRESENT	0
489508	489504	11083R	PARTICIPANT	\N	PRESENT	0
489918	489749	19741B	PARTICIPANT	\N	PRESENT	0
489919	489749	11074Q	PRESIDENT	0	PRESENT	0
489920	489749	99004R	PARTICIPANT	\N	PRESENT	0
489921	489749	14225N	PARTICIPANT	\N	PRESENT	0
489922	489749	19762G	PARTICIPANT	\N	EXCUSE	0
489923	489749	04086Q	PARTICIPANT	\N	PRESENT	0
489924	489749	19479G	PARTICIPANT	\N	PRESENT	0
489925	489749	19711U	PARTICIPANT	\N	PRESENT	0
489926	489749	01057W	PARTICIPANT	\N	PRESENT	0
489927	489749	96004D	PARTICIPANT	\N	PRESENT	0
489928	489749	14327T	PARTICIPANT	\N	PRESENT	0
489929	489749	08011M	PARTICIPANT	\N	PRESENT	0
489930	489749	11048N	PARTICIPANT	\N	PRESENT	0
489931	489749	01048V	PARTICIPANT	\N	PRESENT	0
489940	489749	88008L	PARTICIPANT	\N	PRESENT	0
489934	489749	19687N	PARTICIPANT	\N	PRESENT	0
489942	489749	14083S	PARTICIPANT	\N	PRESENT	0
489936	489749	08010L	PARTICIPANT	\N	PRESENT	0
489937	489749	19531S	PARTICIPANT	\N	PRESENT	0
489941	489749	19647E	PARTICIPANT	\N	PRESENT	0
489967	489750	14331P	PARTICIPANT	\N	PRESENT	0
489968	489750	19647E	PARTICIPANT	\N	PRESENT	0
489969	489750	19711U	PARTICIPANT	\N	PRESENT	0
489970	489750	08069G	PARTICIPANT	\N	PRESENT	0
489971	489750	12016W	PARTICIPANT	\N	PRESENT	0
489972	489750	08011M	PARTICIPANT	\N	PRESENT	0
489973	489750	11074Q	PRESIDENT	0	PRESENT	0
489974	489750	14225N	PARTICIPANT	\N	PRESENT	0
489975	489750	19671E	PARTICIPANT	\N	PRESENT	0
489976	489750	11070L	PARTICIPANT	\N	PRESENT	0
489977	489750	04086Q	PARTICIPANT	\N	PRESENT	0
489978	489750	11040E	PARTICIPANT	\N	PRESENT	0
489979	489750	96004D	PARTICIPANT	\N	PRESENT	0
489980	489750	19741B	PARTICIPANT	\N	PRESENT	0
489981	489750	19762G	PARTICIPANT	\N	PRESENT	0
489982	489750	14083S	PARTICIPANT	\N	PRESENT	0
490197	489867	07033P	PARTICIPANT	\N	PRESENT	0
490198	489867	20074E	PARTICIPANT	\N	PRESENT	0
490199	489867	19507S	PARTICIPANT	\N	PRESENT	0
490200	489867	14151M	PARTICIPANT	\N	PRESENT	0
490201	489867	11074Q	PARTICIPANT	\N	PRESENT	0
490202	489867	11110B	PARTICIPANT	\N	PRESENT	0
490203	489867	14187A	PARTICIPANT	\N	PRESENT	0
490204	489867	19673G	PARTICIPANT	\N	PRESENT	0
490205	489867	20038A	PARTICIPANT	\N	PRESENT	0
490206	489867	01025N	PARTICIPANT	\N	PRESENT	0
490207	489867	19647E	PARTICIPANT	\N	PRESENT	0
490208	489867	14281W	PARTICIPANT	\N	PRESENT	0
490209	489867	20100N	PARTICIPANT	\N	PRESENT	0
490210	489867	20132W	PARTICIPANT	\N	PRESENT	0
490211	489867	08045X	PARTICIPANT	\N	PRESENT	0
490212	489867	19599P	PARTICIPANT	\N	PRESENT	0
490213	489867	17023S	PARTICIPANT	\N	PRESENT	0
490214	489867	19521Q	PARTICIPANT	\N	PRESENT	0
490215	489867	97011G	PARTICIPANT	\N	PRESENT	0
490216	489867	08018U	PARTICIPANT	\N	PRESENT	0
490218	489867	04035D	PARTICIPANT	\N	PRESENT	0
490219	489867	14231L	PARTICIPANT	\N	PRESENT	0
490220	489867	11083R	PARTICIPANT	\N	PRESENT	0
490221	489867	19695N	PARTICIPANT	\N	PRESENT	0
490222	489867	20120S	PARTICIPANT	\N	PRESENT	0
490223	489867	14355X	PARTICIPANT	\N	PRESENT	0
490224	489867	19820Y	PARTICIPANT	\N	PRESENT	0
490225	489867	19387D	PARTICIPANT	\N	PRESENT	0
490226	489867	19347U	PARTICIPANT	\N	PRESENT	0
490227	489867	19649G	PARTICIPANT	\N	PRESENT	0
490228	489867	07004J	PARTICIPANT	\N	PRESENT	0
490229	489867	08056B	PARTICIPANT	\N	PRESENT	0
490230	489867	14211G	PARTICIPANT	\N	PRESENT	0
490231	489867	19565D	PARTICIPANT	\N	PRESENT	0
490232	489867	14033T	PARTICIPANT	\N	PRESENT	0
490233	489867	14123H	PARTICIPANT	\N	PRESENT	0
490234	489867	14026U	PARTICIPANT	\N	PRESENT	0
490235	489867	01057W	PARTICIPANT	\N	PRESENT	0
490236	489867	20068G	PARTICIPANT	\N	PRESENT	0
490237	489867	98022P	PARTICIPANT	\N	PRESENT	0
490238	489867	11064N	PARTICIPANT	\N	PRESENT	0
490239	489867	19691J	PARTICIPANT	\N	PRESENT	0
490240	489867	19553Y	PARTICIPANT	\N	PRESENT	0
490241	489867	20072C	PARTICIPANT	\N	PRESENT	0
490242	489867	19725B	PARTICIPANT	\N	PRESENT	0
490243	489867	19329S	PARTICIPANT	\N	PRESENT	0
490244	489867	20106U	PARTICIPANT	\N	PRESENT	0
490245	489867	20128B	PARTICIPANT	\N	PRESENT	0
490246	489867	19569H	PARTICIPANT	\N	PRESENT	0
490247	489867	14179A	PARTICIPANT	\N	PRESENT	0
490248	489867	19685L	PARTICIPANT	\N	PRESENT	0
490249	489867	20048C	PARTICIPANT	\N	PRESENT	0
490250	489867	19333N	PARTICIPANT	\N	PRESENT	0
490251	489867	08069G	PARTICIPANT	\N	PRESENT	0
490252	489867	19399H	PARTICIPANT	\N	PRESENT	0
490253	489867	11048N	PARTICIPANT	\N	PRESENT	0
490254	489867	19591F	PARTICIPANT	\N	PRESENT	0
490255	489867	14213J	PARTICIPANT	\N	PRESENT	0
490256	489867	20066E	PARTICIPANT	\N	PRESENT	0
490257	489867	20034V	PARTICIPANT	\N	PRESENT	0
490258	489867	19551W	PARTICIPANT	\N	PRESENT	0
490259	489867	19511N	PARTICIPANT	\N	PRESENT	0
490260	489867	19715Y	PARTICIPANT	\N	PRESENT	0
490261	489867	14121F	PARTICIPANT	\N	PRESENT	0
490262	489867	19531S	PARTICIPANT	\N	PRESENT	0
490263	489867	19683J	PARTICIPANT	\N	PRESENT	0
490264	489867	20056C	PARTICIPANT	\N	PRESENT	0
490265	489867	14097Y	PARTICIPANT	\N	PRESENT	0
490266	489867	19447X	PARTICIPANT	\N	PRESENT	0
490267	489867	95041E	PARTICIPANT	\N	PRESENT	0
490268	489867	14021P	PARTICIPANT	\N	PRESENT	0
490269	489867	99004R	PARTICIPANT	\N	PRESENT	0
490270	489867	14073Q	PARTICIPANT	\N	PRESENT	0
490271	489867	19489J	PARTICIPANT	\N	PRESENT	0
490272	489867	20126Y	PARTICIPANT	\N	PRESENT	0
490274	489867	11099A	PARTICIPANT	\N	PRESENT	0
490275	489867	19611R	PARTICIPANT	\N	PRESENT	0
490276	489867	19583F	PARTICIPANT	\N	PRESENT	0
490277	489867	20102Q	PARTICIPANT	\N	PRESENT	0
490278	489867	07029T	PARTICIPANT	\N	PRESENT	0
490279	489867	86034E	PARTICIPANT	\N	PRESENT	0
490280	489867	19723Y	PARTICIPANT	\N	PRESENT	0
490281	489867	19699S	PARTICIPANT	\N	PRESENT	0
490282	489867	08015R	PARTICIPANT	\N	PRESENT	0
490283	489867	12041X	PARTICIPANT	\N	PRESENT	0
490284	489867	19711U	PARTICIPANT	\N	PRESENT	0
490285	489867	19709B	PARTICIPANT	\N	PRESENT	0
490286	489867	18193Q	PARTICIPANT	\N	PRESENT	0
490287	489867	16685X	PARTICIPANT	\N	PRESENT	0
490288	489867	20108W	PARTICIPANT	\N	PRESENT	0
504838	501910	11031D	PARTICIPANT	\N	PRESENT	1
504839	501910	08045X	PARTICIPANT	\N	PRESENT	1
504956	504955	14133K	PRESIDENT	1	PRESENT	0
504957	504955	20042V	PARTICIPANT	\N	PRESENT	0
504958	504955	12028B	PARTICIPANT	\N	PRESENT	0
504959	504955	04042C	PRESIDENT	0	PRESENT	0
504961	504955	14267Y	PARTICIPANT	\N	PRESENT	0
504962	504955	11027H	PARTICIPANT	\N	PRESENT	0
504963	504955	11115U	PARTICIPANT	\N	PRESENT	0
504964	504955	14249W	PARTICIPANT	\N	PRESENT	0
504965	504955	17023S	PARTICIPANT	\N	PRESENT	0
504966	504955	97011G	PARTICIPANT	\N	PRESENT	0
504967	504955	04035D	PARTICIPANT	\N	PRESENT	0
504968	504955	19347U	PARTICIPANT	\N	PRESENT	0
504969	504955	14211G	PARTICIPANT	\N	PRESENT	0
504970	504955	19565D	PARTICIPANT	\N	PRESENT	0
504971	504955	98022P	PARTICIPANT	\N	PRESENT	0
504972	504955	20072C	PARTICIPANT	\N	PRESENT	0
504973	504955	20128B	PARTICIPANT	\N	PRESENT	0
504974	504955	08069G	PARTICIPANT	\N	PRESENT	0
504975	504955	14097Y	PARTICIPANT	\N	PRESENT	0
504976	504955	19709B	PARTICIPANT	\N	PRESENT	0
504977	504955	08047A	PARTICIPANT	\N	PRESENT	0
504978	504955	14193X	PARTICIPANT	\N	PRESENT	0
504979	504955	11054L	PARTICIPANT	\N	PRESENT	0
504980	504955	01058X	PARTICIPANT	\N	PRESENT	0
504981	504955	20064C	PARTICIPANT	\N	PRESENT	0
504982	504955	11041F	PARTICIPANT	\N	PRESENT	0
504983	504955	11066Q	PARTICIPANT	\N	PRESENT	0
504984	504955	04034C	PARTICIPANT	\N	PRESENT	0
504986	504955	14105F	PARTICIPANT	\N	PRESENT	1
504987	504955	14255U	PARTICIPANT	\N	PRESENT	1
504989	504955	01024M	PARTICIPANT	\N	PRESENT	1
504990	504955	11083R	PARTICIPANT	\N	PRESENT	1
504991	504955	12041X	PARTICIPANT	\N	PRESENT	1
504992	504955	16685X	PARTICIPANT	\N	PRESENT	1
504993	504955	19319Q	PARTICIPANT	\N	PRESENT	1
504994	504955	19443T	PARTICIPANT	\N	PRESENT	1
504995	504955	19421M	PARTICIPANT	\N	PRESENT	1
505209	504955	08056B	PARTICIPANT	\N	PRESENT	0
505267	505264	20074E	PARTICIPANT	\N	PRESENT	0
505370	501779	14187A	PARTICIPANT	\N	PRESENT	1
505380	505379	04043D	PARTICIPANT	\N	PRESENT	0
505392	503492	04047H	PARTICIPANT	\N	PRESENT	0
505393	503492	19749K	PARTICIPANT	\N	PRESENT	0
505394	503492	19673G	PARTICIPANT	\N	PRESENT	0
505395	503492	19649G	PARTICIPANT	\N	PRESENT	0
505396	503492	11072N	PARTICIPANT	\N	PRESENT	0
505399	498252	19399H	PARTICIPANT	\N	PRESENT	0
505400	498252	19651A	PARTICIPANT	\N	PRESENT	0
505491	505490	14215L	PARTICIPANT	\N	PRESENT	0
505527	502678	14133K	PARTICIPANT	\N	PRESENT	0
505528	502678	14189C	PARTICIPANT	\N	PRESENT	0
505529	502678	20112S	PARTICIPANT	\N	PRESENT	0
505530	502678	96004D	PARTICIPANT	\N	PRESENT	0
505531	502678	14357A	PARTICIPANT	\N	PRESENT	0
505532	502678	19251M	PARTICIPANT	\N	PRESENT	1
505533	502678	20100N	PARTICIPANT	\N	PRESENT	0
505534	502678	19521Q	PARTICIPANT	\N	PRESENT	1
505535	502678	08018U	PARTICIPANT	\N	PRESENT	0
505536	502678	11083R	PARTICIPANT	\N	PRESENT	0
505537	502678	19725B	PARTICIPANT	\N	PRESENT	0
505538	502678	14073Q	PARTICIPANT	\N	PRESENT	0
505539	502678	12041X	PARTICIPANT	\N	PRESENT	0
505540	502678	11026G	PARTICIPANT	\N	PRESENT	0
505541	502678	19441R	PARTICIPANT	\N	PRESENT	1
505542	502678	14331P	PARTICIPANT	\N	PRESENT	0
505543	502678	10015M	PARTICIPANT	\N	PRESENT	0
505544	502678	20128B	PARTICIPANT	\N	PRESENT	0
505546	502678	19531S	PARTICIPANT	\N	PRESENT	1
505638	505633	20066E	PARTICIPANT	\N	PRESENT	0
505640	505633	20130U	PARTICIPANT	\N	PRESENT	0
505641	505633	19713W	PARTICIPANT	\N	PRESENT	0
505646	504749	11067R	PARTICIPANT	\N	EXCUSE	0
505647	504749	19735D	PARTICIPANT	\N	EXCUSE	0
505743	504749	19563B	PARTICIPANT	\N	EXCUSE	0
505925	505869	19735D	PARTICIPANT	\N	EXCUSE	0
505977	501761	20022R	PARTICIPANT	\N	PRESENT	0
505978	501761	14069U	PARTICIPANT	\N	PRESENT	0
505979	501761	19758L	PARTICIPANT	\N	PRESENT	0
505980	501761	14053L	PARTICIPANT	\N	PRESENT	0
505981	501761	19735D	PARTICIPANT	\N	PRESENT	0
505982	501761	14327T	PARTICIPANT	\N	PRESENT	0
505983	501761	14151M	PARTICIPANT	\N	PRESENT	0
505984	501761	14187A	PARTICIPANT	\N	PRESENT	0
505985	501761	14281W	PARTICIPANT	\N	PRESENT	0
505986	501761	20120S	PARTICIPANT	\N	PRESENT	0
505987	501761	19565D	PARTICIPANT	\N	PRESENT	0
505988	501761	19489J	PARTICIPANT	\N	PRESENT	0
505989	501761	19826F	PARTICIPANT	\N	PRESENT	0
505990	501761	14257W	PARTICIPANT	\N	PRESENT	0
505991	501761	14071N	PARTICIPANT	\N	PRESENT	0
505992	501761	05012A	PARTICIPANT	\N	PRESENT	0
505993	501761	19349W	PARTICIPANT	\N	PRESENT	0
505994	501761	14229S	PARTICIPANT	\N	PRESENT	0
505995	501761	14107H	PARTICIPANT	\N	PRESENT	0
505996	501761	04045F	PARTICIPANT	\N	PRESENT	0
505997	501761	20084G	PARTICIPANT	\N	PRESENT	0
505998	501761	20058E	PARTICIPANT	\N	PRESENT	0
506000	501761	19685L	PARTICIPANT	\N	PRESENT	0
506036	501835	99004R	PARTICIPANT	\N	PRESENT	0
506037	501835	19593H	PARTICIPANT	\N	PRESENT	0
506038	501835	19693L	PARTICIPANT	\N	PRESENT	0
506039	501835	19611R	PARTICIPANT	\N	PRESENT	0
506040	501835	19479G	PARTICIPANT	\N	PRESENT	0
506041	501835	20132W	PARTICIPANT	\N	PRESENT	0
506042	501835	04059M	PARTICIPANT	\N	PRESENT	0
506043	501835	19545Y	PARTICIPANT	\N	PRESENT	0
506044	501835	20142Y	PARTICIPANT	\N	PRESENT	0
506045	501835	19651A	PARTICIPANT	\N	PRESENT	0
506046	501835	19347U	PARTICIPANT	\N	PRESENT	0
506047	501835	08017T	PARTICIPANT	\N	PRESENT	0
506048	501835	14229S	PARTICIPANT	\N	PRESENT	0
506049	501835	14331P	PARTICIPANT	\N	PRESENT	0
506050	501835	20034V	PARTICIPANT	\N	PRESENT	0
506051	501835	19621T	PARTICIPANT	\N	PRESENT	0
506052	501835	19533U	PARTICIPANT	\N	PRESENT	0
506053	501835	14021P	PARTICIPANT	\N	PRESENT	0
506054	501835	20044X	PARTICIPANT	\N	PRESENT	0
506055	501835	20048C	PARTICIPANT	\N	PRESENT	0
506056	501835	20134Y	PARTICIPANT	\N	PRESENT	0
506057	501835	01028R	PARTICIPANT	\N	PRESENT	0
506058	501835	11012A	PARTICIPANT	\N	PRESENT	0
506060	501835	19503N	PARTICIPANT	\N	PRESENT	0
506061	501835	20020P	PARTICIPANT	\N	PRESENT	0
506063	506062	14211G	PARTICIPANT	\N	PRESENT	0
506064	506062	11083R	PARTICIPANT	\N	PRESENT	0
506066	506065	19565D	PARTICIPANT	\N	PRESENT	0
506067	506065	14267Y	PARTICIPANT	\N	PRESENT	0
506068	501835	11070L	PARTICIPANT	\N	PRESENT	0
506070	506069	11048N	PARTICIPANT	\N	PRESENT	0
506071	501835	14327T	PARTICIPANT	\N	PRESENT	0
506072	501835	07029T	PARTICIPANT	\N	PRESENT	0
506073	501835	14083S	PARTICIPANT	\N	PRESENT	0
506102	502453	14327T	PARTICIPANT	\N	PRESENT	0
506103	502453	14331P	PARTICIPANT	\N	PRESENT	0
506104	502453	04071H	PARTICIPANT	\N	PRESENT	0
506105	502453	11048N	PARTICIPANT	\N	PRESENT	0
506106	502453	19711U	PARTICIPANT	\N	PRESENT	0
506107	502453	08034U	PARTICIPANT	\N	PRESENT	0
506108	502453	01057W	PARTICIPANT	\N	PRESENT	0
506109	502453	11053K	PARTICIPANT	\N	PRESENT	0
506110	502453	11074Q	PARTICIPANT	\N	PRESENT	0
506111	502453	20044X	PARTICIPANT	\N	PRESENT	0
506112	502453	04086Q	PARTICIPANT	\N	PRESENT	0
506113	502453	14083S	PARTICIPANT	\N	PRESENT	0
506114	502453	07029T	PARTICIPANT	\N	PRESENT	0
506115	502453	20070A	PARTICIPANT	\N	PRESENT	0
506116	502453	19349W	PARTICIPANT	\N	PRESENT	0
506117	502453	19335Q	PARTICIPANT	\N	PRESENT	0
506118	502453	19762G	PARTICIPANT	\N	PRESENT	0
506119	502453	11070L	PARTICIPANT	\N	PRESENT	0
506120	502453	20150Y	PARTICIPANT	\N	PRESENT	0
506121	502453	11040E	PARTICIPANT	\N	PRESENT	0
506122	502453	19689Q	PARTICIPANT	\N	PRESENT	0
506123	502453	19741B	PARTICIPANT	\N	PRESENT	0
506124	502453	19647E	PARTICIPANT	\N	PRESENT	0
506125	502453	99004R	PARTICIPANT	\N	PRESENT	0
506126	502453	20080C	PARTICIPANT	\N	PRESENT	0
506127	502453	19545Y	PARTICIPANT	\N	PRESENT	0
506128	502453	14225N	PRESIDENT	0	PRESENT	0
483914	481565	19575F	PARTICIPANT	\N	PRESENT	0
484142	484141	11053K	PARTICIPANT	\N	PRESENT	0
484143	484141	14159V	PARTICIPANT	\N	PRESENT	0
484144	484141	05012A	PARTICIPANT	\N	PRESENT	0
489170	489169	19673G	PARTICIPANT	\N	PRESENT	0
489171	489169	11083R	PARTICIPANT	\N	PRESENT	0
489172	489169	14135M	PARTICIPANT	\N	PRESENT	0
489176	489031	04059M	PARTICIPANT	\N	PRESENT	0
489177	489031	19643A	PARTICIPANT	\N	PRESENT	0
489178	489031	19545Y	PARTICIPANT	\N	PRESENT	0
489179	489031	11031D	PARTICIPANT	\N	PRESENT	0
489180	489031	19663E	PARTICIPANT	\N	EXCUSE	0
489181	489031	10006L	PARTICIPANT	\N	PRESENT	0
489182	489031	19691J	PARTICIPANT	\N	PRESENT	0
489183	489031	19553Y	PARTICIPANT	\N	PRESENT	0
489184	489031	14081Q	PARTICIPANT	\N	PRESENT	0
489185	489031	19569H	PARTICIPANT	\N	PRESENT	0
489186	489031	19649G	PARTICIPANT	\N	PRESENT	0
489187	489031	11048N	PARTICIPANT	\N	PRESENT	0
489188	489031	19715Y	PARTICIPANT	\N	PRESENT	0
489189	489031	19683J	PARTICIPANT	\N	PRESENT	0
489190	489031	99004R	PARTICIPANT	\N	PRESENT	0
489191	489031	19697Q	PARTICIPANT	\N	PRESENT	0
489192	489031	11067R	PARTICIPANT	\N	EXCUSE	0
489193	489031	04092N	PARTICIPANT	\N	EXCUSE	0
489194	489031	19573D	PARTICIPANT	\N	PRESENT	0
489195	489031	19503N	PARTICIPANT	\N	PRESENT	0
489196	489031	14331P	PARTICIPANT	\N	PRESENT	0
489197	489031	11012A	PARTICIPANT	\N	EXCUSE	0
489198	489031	19703U	PARTICIPANT	\N	PRESENT	0
489199	489031	01034P	PARTICIPANT	\N	EXCUSE	0
489200	489031	19479G	PARTICIPANT	\N	PRESENT	0
489201	489031	11097X	PRESIDENT	0	PRESENT	0
489202	489031	19766L	PARTICIPANT	\N	PRESENT	0
489203	489031	14041T	PARTICIPANT	\N	PRESENT	0
489204	489031	19667J	PARTICIPANT	\N	PRESENT	0
489205	489032	11067R	PARTICIPANT	\N	EXCUSE	0
489206	489032	19703U	PARTICIPANT	\N	PRESENT	0
489207	489032	01034P	PARTICIPANT	\N	EXCUSE	0
489208	489032	19479G	PARTICIPANT	\N	PRESENT	0
489209	489032	11097X	PRESIDENT	0	PRESENT	0
489210	489032	11012A	PARTICIPANT	\N	EXCUSE	0
489211	489032	19766L	PARTICIPANT	\N	PRESENT	0
489212	489032	14331P	PARTICIPANT	\N	PRESENT	0
489213	489032	19503N	PARTICIPANT	\N	PRESENT	0
489214	489032	04092N	PARTICIPANT	\N	EXCUSE	0
489215	489032	19573D	PARTICIPANT	\N	PRESENT	0
489216	489032	19643A	PARTICIPANT	\N	PRESENT	0
489217	489032	19663E	PARTICIPANT	\N	EXCUSE	0
489218	489032	10006L	PARTICIPANT	\N	PRESENT	0
489219	489032	19691J	PARTICIPANT	\N	PRESENT	0
489220	489032	19683J	PARTICIPANT	\N	PRESENT	0
489221	489032	19715Y	PARTICIPANT	\N	PRESENT	0
489222	489032	19553Y	PARTICIPANT	\N	PRESENT	0
489223	489032	14081Q	PARTICIPANT	\N	PRESENT	0
489224	489032	19649G	PARTICIPANT	\N	PRESENT	0
489225	489032	11048N	PARTICIPANT	\N	PRESENT	0
489226	489032	99004R	PARTICIPANT	\N	PRESENT	0
489227	489032	19697Q	PARTICIPANT	\N	PRESENT	0
491380	491378	19551W	PARTICIPANT	\N	PRESENT	0
491381	491377	19551W	PARTICIPANT	\N	PRESENT	0
497675	495269	20074E	PARTICIPANT	\N	EXCUSE	0
499455	497672	20074E	PARTICIPANT	\N	EXCUSE	0
499456	497672	19585H	PARTICIPANT	\N	EXCUSE	0
505230	505228	11031D	PARTICIPANT	\N	PRESENT	0
505232	505228	19367Y	PARTICIPANT	\N	PRESENT	0
505233	505228	19760E	PARTICIPANT	\N	PRESENT	0
505234	505228	14213J	PARTICIPANT	\N	PRESENT	0
505241	505239	19760E	PARTICIPANT	\N	PRESENT	0
505242	505239	19367Y	PARTICIPANT	\N	PRESENT	0
505244	505239	11031D	PARTICIPANT	\N	PRESENT	0
505246	505239	11067R	PARTICIPANT	\N	PRESENT	0
505248	505239	19723Y	PARTICIPANT	\N	PRESENT	0
505249	505239	17965H	PARTICIPANT	\N	PRESENT	0
505250	505239	14213J	PARTICIPANT	\N	PRESENT	0
506842	506841	04043D	PARTICIPANT	\N	PRESENT	0
507038	507037	11031D	PARTICIPANT	\N	PRESENT	0
507039	507037	19367Y	PARTICIPANT	\N	PRESENT	0
507040	507037	14042U	PARTICIPANT	\N	PRESENT	0
507964	505869	14107H	PARTICIPANT	\N	EXCUSE	0
507967	505803	14207L	PARTICIPANT	\N	PRESENT	1
507988	502321	19647E	PARTICIPANT	\N	PRESENT	0
507989	502321	19649G	PARTICIPANT	\N	PRESENT	0
507990	502321	19768N	PARTICIPANT	\N	PRESENT	0
507991	502321	04045F	PARTICIPANT	\N	PRESENT	0
507992	502321	14083S	PARTICIPANT	\N	PRESENT	0
507993	502321	14073Q	PARTICIPANT	\N	PRESENT	0
507994	502321	14089Y	PARTICIPANT	\N	PRESENT	0
507995	502321	14107H	PARTICIPANT	\N	PRESENT	0
507996	502321	19966S	PARTICIPANT	\N	PRESENT	0
507997	502321	14041T	PARTICIPANT	\N	PRESENT	0
507998	502321	20044X	PARTICIPANT	\N	PRESENT	0
507999	502321	20070A	PARTICIPANT	\N	PRESENT	0
508000	502321	19507S	PARTICIPANT	\N	PRESENT	0
508001	502321	01057W	PARTICIPANT	\N	PRESENT	0
508002	502321	17367Q	PARTICIPANT	\N	PRESENT	0
508003	502321	11043H	PARTICIPANT	\N	PRESENT	0
508004	502321	14069U	PARTICIPANT	\N	PRESENT	0
508005	502321	99004R	PARTICIPANT	\N	PRESENT	0
508006	502321	14327T	PARTICIPANT	\N	PRESENT	0
508007	502321	11074Q	PARTICIPANT	\N	PRESENT	0
508008	502321	20126Y	PARTICIPANT	\N	PRESENT	0
508013	502321	19531S	PARTICIPANT	\N	PRESENT	0
508010	502321	19711U	PARTICIPANT	\N	PRESENT	0
508011	502321	20024T	PARTICIPANT	\N	PRESENT	0
508012	502321	14059S	PARTICIPANT	\N	PRESENT	0
508014	502321	19689Q	PARTICIPANT	\N	PRESENT	0
508015	502321	08034U	PARTICIPANT	\N	PRESENT	0
508016	502321	14225N	PARTICIPANT	\N	PRESENT	0
508017	502321	04033B	PARTICIPANT	\N	PRESENT	0
508018	505804	11090Q	PARTICIPANT	\N	EXCUSE	0
508019	502321	01043Q	PARTICIPANT	\N	PRESENT	0
508020	502321	11012A	PARTICIPANT	\N	PRESENT	0
508021	502321	19565D	PARTICIPANT	\N	PRESENT	0
508022	502321	19663E	PARTICIPANT	\N	PRESENT	0
508025	502321	14207L	PARTICIPANT	\N	PRESENT	0
508026	502321	14021P	PARTICIPANT	\N	PRESENT	0
508027	502321	04071H	PARTICIPANT	\N	PRESENT	0
508028	502321	14331P	PARTICIPANT	\N	PRESENT	0
508029	502321	20104S	PARTICIPANT	\N	PRESENT	0
508030	502321	20030R	PARTICIPANT	\N	PRESENT	0
508031	502321	08011M	PARTICIPANT	\N	PRESENT	0
508032	502321	14123H	PARTICIPANT	\N	PRESENT	0
508033	505804	19575F	PARTICIPANT	\N	PRESENT	1
508034	502321	19335Q	PARTICIPANT	\N	PRESENT	0
508035	502321	08010L	PARTICIPANT	\N	PRESENT	0
508036	502321	14329V	PARTICIPANT	\N	PRESENT	0
508039	502321	14121F	PARTICIPANT	\N	PRESENT	0
508040	502321	14223L	PARTICIPANT	\N	PRESENT	0
508041	502321	04034C	PARTICIPANT	\N	PRESENT	0
508048	502321	11097X	PARTICIPANT	\N	PRESENT	0
508051	507831	20120S	PARTICIPANT	\N	PRESENT	1
508056	502321	14195A	PARTICIPANT	\N	PRESENT	0
508062	502321	19619A	PARTICIPANT	\N	PRESENT	0
508067	502321	11083R	PARTICIPANT	\N	PRESENT	0
508078	502321	14213J	PARTICIPANT	\N	PRESENT	0
508080	502321	19679N	PARTICIPANT	\N	PRESENT	0
508097	502321	04059M	PARTICIPANT	\N	PRESENT	0
508098	502321	14147R	PARTICIPANT	\N	PRESENT	0
508099	502321	14179A	PARTICIPANT	\N	PRESENT	0
508100	502321	14189C	PARTICIPANT	\N	PRESENT	0
508101	502321	19521Q	PARTICIPANT	\N	PRESENT	0
508102	506005	11115U	PARTICIPANT	\N	PRESENT	0
508103	502321	19760E	PARTICIPANT	\N	PRESENT	0
508104	502321	20022R	PARTICIPANT	\N	PRESENT	0
508105	502321	20028X	PARTICIPANT	\N	PRESENT	0
508106	502321	18083K	PARTICIPANT	\N	PRESENT	0
508107	502321	14217N	PARTICIPANT	\N	PRESENT	0
508108	502321	19545Y	PARTICIPANT	\N	PRESENT	0
508109	502321	01025N	PARTICIPANT	\N	PRESENT	0
508110	502321	19467C	PARTICIPANT	\N	PRESENT	0
508111	503170	19333N	PARTICIPANT	\N	PRESENT	0
508112	503170	20032T	PARTICIPANT	\N	PRESENT	0
508113	503170	14031R	PARTICIPANT	\N	PRESENT	0
508114	503170	20038A	PARTICIPANT	\N	PRESENT	0
508115	503170	19549D	PARTICIPANT	\N	PRESENT	0
508116	503170	20076G	PARTICIPANT	\N	PRESENT	0
508117	503170	19820Y	PARTICIPANT	\N	PRESENT	0
508118	503170	14219Q	PRESIDENT	0	PRESENT	0
508119	503170	19826F	PARTICIPANT	\N	PRESENT	0
508120	503170	19599P	PARTICIPANT	\N	PRESENT	0
511911	509892	19693L	PARTICIPANT	\N	PRESENT	1
511912	509892	19399H	PARTICIPANT	\N	PRESENT	1
511913	509892	20052X	PARTICIPANT	\N	PRESENT	1
511914	509892	08061X	PARTICIPANT	\N	PRESENT	0
512158	512157	20114U	PARTICIPANT	\N	PRESENT	0
512159	512157	14030Q	PARTICIPANT	\N	PRESENT	0
512160	512157	14357A	PARTICIPANT	\N	PRESENT	0
512161	512157	19673G	PARTICIPANT	\N	PRESENT	0
512162	512157	14179A	PARTICIPANT	\N	PRESENT	0
512163	512157	19333N	PARTICIPANT	\N	PRESENT	0
512164	512157	19699S	PARTICIPANT	\N	PRESENT	0
512165	512157	11026G	PARTICIPANT	\N	PRESENT	0
512166	512157	04070G	PARTICIPANT	\N	PRESENT	0
512256	509270	14219Q	PARTICIPANT	\N	EXCUSE	0
512257	509270	18083K	PARTICIPANT	\N	PRESENT	0
512662	512647	05012A	PARTICIPANT	\N	PRESENT	0
512663	512647	20098N	PARTICIPANT	\N	PRESENT	0
512664	512647	20064C	PARTICIPANT	\N	PRESENT	0
512665	512647	97011G	PARTICIPANT	\N	PRESENT	0
512666	512647	11083R	PARTICIPANT	\N	PRESENT	0
512667	512647	14213J	PARTICIPANT	\N	PRESENT	0
512668	512647	19489J	PARTICIPANT	\N	PRESENT	0
512669	512647	19719D	PARTICIPANT	\N	PRESENT	0
512670	512647	20124W	PARTICIPANT	\N	PRESENT	0
512671	507957	19679N	PARTICIPANT	\N	EXCUSE	0
512672	502348	20020P	PARTICIPANT	\N	PRESENT	0
512673	502348	20024T	PARTICIPANT	\N	PRESENT	0
512674	502348	19631V	PARTICIPANT	\N	PRESENT	0
512675	502348	19721W	PARTICIPANT	\N	PRESENT	0
512676	502348	14219Q	PARTICIPANT	\N	PRESENT	0
512677	509891	17589D	PARTICIPANT	\N	PRESENT	1
512678	502348	12041X	PARTICIPANT	\N	PRESENT	0
512679	509306	14133K	PARTICIPANT	\N	PRESENT	0
512680	509306	20094J	PARTICIPANT	\N	PRESENT	0
512681	509306	19701S	PRESIDENT	0	PRESENT	0
512682	509306	20100N	PARTICIPANT	\N	PRESENT	0
512683	509306	08018U	PARTICIPANT	\N	PRESENT	0
512684	509891	19735D	PARTICIPANT	\N	PRESENT	1
512685	509306	11083R	PARTICIPANT	\N	PRESENT	0
512686	509306	14033T	PARTICIPANT	\N	PRESENT	1
512687	509306	20128B	PARTICIPANT	\N	PRESENT	1
512688	509891	14109K	PARTICIPANT	\N	PRESENT	1
512689	509306	11026G	PARTICIPANT	\N	PRESENT	0
512690	509306	14001X	PARTICIPANT	\N	PRESENT	1
512692	509306	04034C	PARTICIPANT	\N	PRESENT	0
512693	512691	19675J	PARTICIPANT	\N	PRESENT	0
512694	509306	19467C	PARTICIPANT	\N	PRESENT	0
512695	509306	01058X	PARTICIPANT	\N	PRESENT	0
512697	512696	19675J	PARTICIPANT	\N	PRESENT	0
512698	512696	07004J	PARTICIPANT	\N	PRESENT	0
512700	512699	19675J	PARTICIPANT	\N	PRESENT	0
512702	512701	19675J	PARTICIPANT	\N	PRESENT	0
512707	502348	14073Q	PARTICIPANT	\N	PRESENT	0
512708	502348	19782L	PARTICIPANT	\N	PRESENT	0
512709	502348	19673G	PARTICIPANT	\N	PRESENT	0
512710	502348	14217N	PARTICIPANT	\N	PRESENT	0
512711	502348	19701S	PARTICIPANT	\N	PRESENT	0
512712	502348	19467C	PARTICIPANT	\N	PRESENT	0
512713	502348	19543W	PARTICIPANT	\N	PRESENT	0
512715	512714	04047H	PARTICIPANT	\N	PRESENT	0
512716	512714	14299H	PARTICIPANT	\N	PRESENT	0
512717	512714	11066Q	PARTICIPANT	\N	PRESENT	0
512719	512718	04047H	PARTICIPANT	\N	PRESENT	0
512720	512718	14299H	PARTICIPANT	\N	PRESENT	0
512722	512718	11066Q	PARTICIPANT	\N	PRESENT	0
512723	502348	20066E	PARTICIPANT	\N	PRESENT	0
512724	502348	14071N	PARTICIPANT	\N	PRESENT	0
512725	502348	17737W	PARTICIPANT	\N	PRESENT	0
512781	502349	11109J	PARTICIPANT	\N	PRESENT	0
512782	502349	20072C	PARTICIPANT	\N	PRESENT	0
512783	502349	08073C	PARTICIPANT	\N	PRESENT	0
512784	502349	12016W	PARTICIPANT	\N	PRESENT	0
512785	502349	19295A	PARTICIPANT	\N	PRESENT	0
512786	502349	12028B	PARTICIPANT	\N	PRESENT	0
512787	502349	19583F	PARTICIPANT	\N	PRESENT	0
512788	502349	19721W	PARTICIPANT	\N	PRESENT	0
512789	502349	19301E	PARTICIPANT	\N	PRESENT	0
512795	502349	08034U	PARTICIPANT	\N	PRESENT	0
512796	502349	20150Y	PARTICIPANT	\N	PRESENT	0
512797	502349	19671E	PARTICIPANT	\N	PRESENT	0
512799	502349	14193X	PARTICIPANT	\N	PRESENT	0
512801	502349	19717B	PARTICIPANT	\N	PRESENT	0
512802	502349	19715Y	PARTICIPANT	\N	PRESENT	0
512804	502349	14267Y	PARTICIPANT	\N	PRESENT	0
512806	502349	04085P	PARTICIPANT	\N	PRESENT	0
512807	502349	14133K	PARTICIPANT	\N	PRESENT	0
512808	502349	19701S	PARTICIPANT	\N	PRESENT	0
512809	502349	19565D	PARTICIPANT	\N	PRESENT	0
512811	502349	11099A	PARTICIPANT	\N	PRESENT	0
512813	510129	14299H	PARTICIPANT	\N	EXCUSE	0
512814	502349	19711U	PARTICIPANT	\N	PRESENT	0
512815	502349	20080C	PARTICIPANT	\N	PRESENT	0
512816	502349	19629C	PARTICIPANT	\N	PRESENT	0
512817	502349	20042V	PARTICIPANT	\N	PRESENT	0
512821	502349	14053L	PARTICIPANT	\N	PRESENT	0
512822	502349	19347U	PARTICIPANT	\N	PRESENT	0
512823	502349	08045X	PARTICIPANT	\N	PRESENT	0
512824	502349	01024M	PARTICIPANT	\N	PRESENT	0
512825	502349	20124W	PARTICIPANT	\N	PRESENT	0
512826	502349	19533U	PARTICIPANT	\N	PRESENT	0
512827	502349	14097Y	PARTICIPANT	\N	PRESENT	0
512829	502349	08010L	PARTICIPANT	\N	PRESENT	0
512830	502349	11072N	PARTICIPANT	\N	PRESENT	0
512831	502349	19693L	PARTICIPANT	\N	PRESENT	0
512834	502349	14021P	PARTICIPANT	\N	PRESENT	0
512837	512836	16685X	PARTICIPANT	\N	PRESENT	0
512839	502349	98022P	PARTICIPANT	\N	PRESENT	0
512840	502349	04034C	PARTICIPANT	\N	PRESENT	0
512842	502349	19782L	PARTICIPANT	\N	PRESENT	0
512843	502349	20070A	PARTICIPANT	\N	PRESENT	0
512844	502349	19577H	PARTICIPANT	\N	PRESENT	0
512845	502349	12041X	PARTICIPANT	\N	PRESENT	0
512846	502349	17737W	PARTICIPANT	\N	PRESENT	0
512847	502349	11064N	PARTICIPANT	\N	PRESENT	0
512848	502349	20066E	PARTICIPANT	\N	PRESENT	0
512849	502349	07004J	PARTICIPANT	\N	PRESENT	0
512851	502349	11067R	PARTICIPANT	\N	PRESENT	0
512852	502349	14215L	PARTICIPANT	\N	PRESENT	0
512853	508794	19681G	PARTICIPANT	\N	EXCUSE	0
512858	502349	20074E	PARTICIPANT	\N	PRESENT	0
512859	508794	20022R	PARTICIPANT	\N	PRESENT	0
512860	508794	20110Q	PARTICIPANT	\N	PRESENT	0
512861	508794	14069U	PARTICIPANT	\N	PRESENT	0
512862	508794	19758L	PARTICIPANT	\N	PRESENT	0
512863	508794	20090E	PARTICIPANT	\N	PRESENT	0
512864	502349	20126Y	PARTICIPANT	\N	PRESENT	0
512865	508794	04086Q	PARTICIPANT	\N	PRESENT	0
512866	508794	19735D	PARTICIPANT	\N	PRESENT	0
512867	508794	14187A	PARTICIPANT	\N	PRESENT	0
512868	508794	14281W	PARTICIPANT	\N	PRESENT	0
512869	508794	19565D	PARTICIPANT	\N	PRESENT	0
512870	508794	01057W	PARTICIPANT	\N	PRESENT	0
512871	508794	19333N	PARTICIPANT	\N	PRESENT	0
512872	508794	19489J	PARTICIPANT	\N	PRESENT	0
512873	508794	19826F	PARTICIPANT	\N	PRESENT	0
512874	508794	14257W	PARTICIPANT	\N	PRESENT	0
512875	508794	14071N	PARTICIPANT	\N	PRESENT	0
484620	479638	19717B	PARTICIPANT	\N	PRESENT	0
484621	479638	19631V	PARTICIPANT	\N	PRESENT	0
484622	479638	19577H	PARTICIPANT	\N	PRESENT	0
484623	479638	19715Y	PARTICIPANT	\N	PRESENT	0
484624	479638	08019V	PRESIDENT	0	PRESENT	0
484625	479638	19657G	PARTICIPANT	\N	PRESENT	0
484634	479638	14059S	PARTICIPANT	\N	EXCUSE	0
484635	479638	19295A	PARTICIPANT	\N	PRESENT	0
484636	479638	11054L	PARTICIPANT	\N	PRESENT	0
484662	479638	19319Q	PARTICIPANT	\N	PRESENT	0
489265	489264	04086Q	PARTICIPANT	\N	PRESENT	0
489266	489264	19711U	PARTICIPANT	\N	PRESENT	0
489267	489264	11074Q	PARTICIPANT	\N	PRESENT	0
489268	489264	19647E	PARTICIPANT	\N	PRESENT	0
489269	489264	99004R	PARTICIPANT	\N	PRESENT	0
489270	489264	19687N	PARTICIPANT	\N	PRESENT	0
489271	489264	04071H	PARTICIPANT	\N	PRESENT	0
489272	489264	19689Q	PARTICIPANT	\N	PRESENT	0
489273	489264	19667J	PARTICIPANT	\N	PRESENT	0
489308	489033	19663E	PARTICIPANT	\N	EXCUSE	0
489309	489033	11067R	PARTICIPANT	\N	EXCUSE	0
489310	489033	04092N	PARTICIPANT	\N	EXCUSE	0
489311	489033	11012A	PARTICIPANT	\N	EXCUSE	0
489312	489034	04059M	PARTICIPANT	\N	PRESENT	0
489313	489034	19649G	PARTICIPANT	\N	PRESENT	0
489314	489034	14081Q	PARTICIPANT	\N	PRESENT	0
489315	489034	19503N	PARTICIPANT	\N	PRESENT	0
489316	489034	11067R	PARTICIPANT	\N	EXCUSE	0
489317	489034	04092N	PARTICIPANT	\N	EXCUSE	0
489318	489034	11012A	PARTICIPANT	\N	EXCUSE	0
489319	489034	11097X	PRESIDENT	0	PRESENT	0
489320	489034	19703U	PARTICIPANT	\N	PRESENT	0
489321	489034	19479G	PARTICIPANT	\N	PRESENT	0
489322	489034	14331P	PARTICIPANT	\N	PRESENT	0
489323	489034	19715Y	PARTICIPANT	\N	PRESENT	0
489324	489034	19683J	PARTICIPANT	\N	PRESENT	0
489325	489034	19663E	PARTICIPANT	\N	EXCUSE	0
489326	489034	11031D	PARTICIPANT	\N	PRESENT	0
489327	489034	10006L	PARTICIPANT	\N	PRESENT	0
489328	489034	11048N	PARTICIPANT	\N	PRESENT	0
489329	489034	19573D	PARTICIPANT	\N	PRESENT	0
489330	489034	19697Q	PARTICIPANT	\N	PRESENT	0
489331	489034	14041T	PARTICIPANT	\N	PRESENT	0
489332	489034	19643A	PARTICIPANT	\N	PRESENT	0
489333	489034	01034P	PARTICIPANT	\N	PRESENT	0
489334	489034	19553Y	PARTICIPANT	\N	PRESENT	0
489335	489034	04085P	PARTICIPANT	\N	PRESENT	0
489336	489034	19667J	PARTICIPANT	\N	PRESENT	0
489338	489034	99004R	PARTICIPANT	\N	PRESENT	0
490289	489867	11026G	PARTICIPANT	\N	PRESENT	0
490290	489867	19265T	PARTICIPANT	\N	PRESENT	0
490291	489867	08010L	PARTICIPANT	\N	PRESENT	0
490292	489867	08034U	PARTICIPANT	\N	PRESENT	0
490293	489867	14037X	PARTICIPANT	\N	PRESENT	0
490295	489867	08017T	PARTICIPANT	\N	PRESENT	0
490296	489867	19729F	PARTICIPANT	\N	PRESENT	0
490297	489867	01043Q	PARTICIPANT	\N	PRESENT	0
490298	489867	20052X	PARTICIPANT	\N	PRESENT	0
490299	489867	19697Q	PARTICIPANT	\N	PRESENT	0
490300	489867	19581D	PARTICIPANT	\N	PRESENT	0
490301	489867	11077T	PARTICIPANT	\N	PRESENT	0
490302	489867	14205J	PARTICIPANT	\N	PRESENT	0
490303	489867	14219Q	PARTICIPANT	\N	PRESENT	0
490304	489867	01048V	PARTICIPANT	\N	PRESENT	0
490305	489867	14059S	PARTICIPANT	\N	PRESENT	0
490306	489867	19441R	PARTICIPANT	\N	PRESENT	0
490307	489867	08012N	PARTICIPANT	\N	PRESENT	0
490308	489867	17779H	PARTICIPANT	\N	PRESENT	0
490309	489867	12016W	PARTICIPANT	\N	PRESENT	0
490311	489867	19657G	PARTICIPANT	\N	PRESENT	0
490312	489867	14251Q	PARTICIPANT	\N	PRESENT	0
490313	489867	14031R	PARTICIPANT	\N	PRESENT	0
490314	489867	14111D	PARTICIPANT	\N	PRESENT	0
490315	489867	19637C	PARTICIPANT	\N	PRESENT	0
490316	489867	20142Y	PARTICIPANT	\N	PRESENT	0
490317	489867	14001X	PARTICIPANT	\N	PRESENT	0
490318	489867	11085T	PARTICIPANT	\N	PRESENT	0
490319	489867	19826F	PARTICIPANT	\N	PRESENT	0
490320	489867	01060R	PARTICIPANT	\N	PRESENT	0
490321	489867	08009T	PARTICIPANT	\N	PRESENT	0
490322	489867	14221J	PARTICIPANT	\N	PRESENT	0
490323	489867	04057K	PARTICIPANT	\N	PRESENT	0
490324	489867	19563B	PARTICIPANT	\N	PRESENT	0
490325	489867	14147R	PARTICIPANT	\N	PRESENT	0
490326	489867	20028X	PARTICIPANT	\N	PRESENT	0
490327	489867	11067R	PARTICIPANT	\N	PRESENT	0
490328	489867	19671E	PARTICIPANT	\N	PRESENT	0
490329	489867	20018V	PARTICIPANT	\N	PRESENT	0
490330	489867	14223L	PARTICIPANT	\N	PRESENT	0
490331	489867	04092N	PARTICIPANT	\N	PRESENT	0
490332	489867	19335Q	PARTICIPANT	\N	PRESENT	0
490333	489867	19369B	PARTICIPANT	\N	PRESENT	0
490334	489867	11072N	PARTICIPANT	\N	PRESENT	0
490335	489867	14109K	PARTICIPANT	\N	PRESENT	0
490336	489867	14257W	PARTICIPANT	\N	PRESENT	0
490337	489867	08011M	PARTICIPANT	\N	PRESENT	0
490338	489867	04070G	PARTICIPANT	\N	PRESENT	0
490339	489867	14071N	PARTICIPANT	\N	PRESENT	0
490340	489867	20096L	PARTICIPANT	\N	PRESENT	0
490341	489867	92040Q	PARTICIPANT	\N	PRESENT	0
490344	489867	14253S	PARTICIPANT	\N	PRESENT	0
490345	489867	19593H	PARTICIPANT	\N	PRESENT	0
490346	489867	19573D	PARTICIPANT	\N	PRESENT	0
490347	489867	19866P	PARTICIPANT	\N	PRESENT	0
490349	489867	20050V	PARTICIPANT	\N	PRESENT	0
490350	489867	20036X	PARTICIPANT	\N	PRESENT	0
490351	489867	08073C	PARTICIPANT	\N	PRESENT	0
490352	489867	08061X	PARTICIPANT	\N	PRESENT	0
490353	489867	08047A	PARTICIPANT	\N	PRESENT	0
490355	489867	17637T	PARTICIPANT	\N	PRESENT	0
490356	489867	14193X	PARTICIPANT	\N	PRESENT	0
490357	489867	19745F	PARTICIPANT	\N	PRESENT	0
490358	489867	20148F	PARTICIPANT	\N	PRESENT	0
490359	489867	20146D	PARTICIPANT	\N	PRESENT	0
490360	489867	19533U	PARTICIPANT	\N	PRESENT	0
490361	489867	20030R	PARTICIPANT	\N	PRESENT	0
490362	489867	20118Y	PARTICIPANT	\N	PRESENT	0
490364	489867	05012A	PARTICIPANT	\N	PRESENT	0
490365	489867	20130U	PARTICIPANT	\N	PRESENT	0
490366	489867	17965H	PARTICIPANT	\N	PRESENT	0
490367	489867	19503N	PARTICIPANT	\N	PRESENT	0
490368	489867	11090Q	PARTICIPANT	\N	PRESENT	0
490369	489867	19739H	PARTICIPANT	\N	PRESENT	0
490370	489867	17583W	PARTICIPANT	\N	PRESENT	0
490371	489867	04043D	PARTICIPANT	\N	PRESENT	0
490372	489867	19735D	PARTICIPANT	\N	PRESENT	0
490373	489867	19679N	PARTICIPANT	\N	PRESENT	0
490374	489867	19443T	PARTICIPANT	\N	PRESENT	0
490375	489867	19349W	PARTICIPANT	\N	PRESENT	0
490376	489867	14331P	PARTICIPANT	\N	PRESENT	0
490377	489867	14055N	PARTICIPANT	\N	PRESENT	0
490378	489867	14225N	PARTICIPANT	\N	PRESENT	0
490379	489867	20082E	PARTICIPANT	\N	PRESENT	0
490380	489867	19766L	PARTICIPANT	\N	PRESENT	0
490381	489867	10015M	PARTICIPANT	\N	PRESENT	0
490382	489867	19705W	PARTICIPANT	\N	PRESENT	0
490383	489867	11012A	PARTICIPANT	\N	PRESENT	0
490384	489867	04033B	PARTICIPANT	\N	PRESENT	0
490386	489867	19798U	PARTICIPANT	\N	PRESENT	0
490387	489867	20054A	PARTICIPANT	\N	PRESENT	0
490388	489867	14229S	PARTICIPANT	\N	PRESENT	0
490389	489867	11054L	PARTICIPANT	\N	PRESENT	0
490390	489867	20150Y	PARTICIPANT	\N	PRESENT	0
490391	489867	20020P	PARTICIPANT	\N	PRESENT	0
490392	489867	11045K	PARTICIPANT	\N	PRESENT	0
490393	489867	14107H	PARTICIPANT	\N	PRESENT	0
490394	489867	19619A	PARTICIPANT	\N	PRESENT	0
490395	489867	20092G	PARTICIPANT	\N	PRESENT	0
490396	489867	19421M	PARTICIPANT	\N	PRESENT	0
490397	489867	20044X	PARTICIPANT	\N	PRESENT	0
490398	489867	11097X	PARTICIPANT	\N	PRESENT	0
490399	489867	11043H	PARTICIPANT	\N	PRESENT	0
490400	489867	19687N	PARTICIPANT	\N	PRESENT	0
490401	489867	20098N	PARTICIPANT	\N	PRESENT	0
490402	489867	04045F	PARTICIPANT	\N	PRESENT	0
490403	489867	19762G	PARTICIPANT	\N	PRESENT	0
490404	489867	01058X	PARTICIPANT	\N	PRESENT	0
490405	489867	19703U	PARTICIPANT	\N	PRESENT	0
490406	489867	19713W	PARTICIPANT	\N	PRESENT	0
490407	489867	20062A	PARTICIPANT	\N	PRESENT	0
490408	489867	20084G	PARTICIPANT	\N	PRESENT	0
500858	500279	20102Q	PARTICIPANT	\N	PRESENT	0
500859	500279	20024T	PARTICIPANT	\N	PRESENT	0
501013	500280	11067R	PARTICIPANT	\N	PRESENT	0
501014	500280	19723Y	PARTICIPANT	\N	PRESENT	0
501015	500280	19683J	PARTICIPANT	\N	PRESENT	0
501016	500280	14071N	PARTICIPANT	\N	PRESENT	0
501017	500280	19715Y	PARTICIPANT	\N	PRESENT	0
501018	500280	19575F	PARTICIPANT	\N	PRESENT	0
501019	500280	20090E	PARTICIPANT	\N	PRESENT	0
501020	500280	20130U	PARTICIPANT	\N	PRESENT	0
501021	500280	19573D	PARTICIPANT	\N	PRESENT	0
501022	500280	19347U	PARTICIPANT	\N	PRESENT	0
501023	500280	20134Y	PARTICIPANT	\N	PRESENT	0
501024	500280	19415P	PARTICIPANT	\N	PRESENT	0
501025	500280	20152B	PARTICIPANT	\N	PRESENT	0
501026	500280	19679N	PARTICIPANT	\N	PRESENT	0
501027	500280	14217N	PARTICIPANT	\N	PRESENT	0
501028	500280	19301E	PARTICIPANT	\N	PRESENT	0
501029	500280	10006L	PARTICIPANT	\N	PRESENT	0
501030	500280	11012A	PARTICIPANT	\N	PRESENT	0
501031	500280	19719D	PARTICIPANT	\N	PRESENT	0
501032	500280	01034P	PARTICIPANT	\N	PRESENT	0
501033	500280	19387D	PARTICIPANT	\N	PRESENT	0
501034	500280	14195A	PARTICIPANT	\N	PRESENT	0
501035	500280	19563B	PARTICIPANT	\N	PRESENT	0
501036	500280	14213J	PARTICIPANT	\N	PRESENT	0
506129	496311	20050V	PARTICIPANT	\N	PRESENT	0
501038	500280	20112S	PARTICIPANT	\N	PRESENT	0
501039	500280	19383Y	PARTICIPANT	\N	PRESENT	0
501040	500280	19760E	PARTICIPANT	\N	PRESENT	0
501041	500280	11031D	PARTICIPANT	\N	PRESENT	0
501042	500280	19693L	PARTICIPANT	\N	PRESENT	0
501043	500280	14187A	PARTICIPANT	\N	PRESENT	0
501044	500280	20126Y	PARTICIPANT	\N	PRESENT	0
501045	500280	04092N	PARTICIPANT	\N	PRESENT	0
501046	500280	19691J	PARTICIPANT	\N	PRESENT	0
501047	500280	14042U	PARTICIPANT	\N	PRESENT	0
501048	500280	19569H	PARTICIPANT	\N	PRESENT	0
501049	500280	11097X	PARTICIPANT	\N	PRESENT	0
501050	500280	19697Q	PARTICIPANT	\N	PRESENT	0
501051	500280	14026U	PARTICIPANT	\N	PRESENT	0
501052	500280	14123H	PARTICIPANT	\N	PRESENT	0
501053	500280	19553Y	PARTICIPANT	\N	PRESENT	0
501054	500280	08045X	PARTICIPANT	\N	PRESENT	0
501055	500280	19703U	PARTICIPANT	\N	PRESENT	0
501056	500280	19663E	PARTICIPANT	\N	PRESENT	0
501057	500280	17737W	PARTICIPANT	\N	PRESENT	0
501058	500280	14073Q	PARTICIPANT	\N	PRESENT	0
501059	500280	20034V	PARTICIPANT	\N	PRESENT	0
501060	500280	19533U	PARTICIPANT	\N	PRESENT	0
501061	500280	14083S	PARTICIPANT	\N	PRESENT	0
501062	500280	19713W	PARTICIPANT	\N	PRESENT	0
501063	500280	11056N	PARTICIPANT	\N	PRESENT	0
501064	500280	19657G	PARTICIPANT	\N	PRESENT	0
501065	500280	18193Q	PARTICIPANT	\N	PRESENT	0
501066	500280	17965H	PARTICIPANT	\N	PRESENT	0
501067	500280	20024T	PARTICIPANT	\N	PRESENT	0
501068	500280	17779H	PARTICIPANT	\N	PRESENT	0
501069	500280	14281W	PARTICIPANT	\N	PRESENT	0
501070	500280	19717B	PARTICIPANT	\N	PRESENT	0
501071	500280	11043H	PARTICIPANT	\N	PRESENT	0
501072	500280	19782L	PARTICIPANT	\N	PRESENT	0
501073	500280	11085T	PARTICIPANT	\N	PRESENT	0
501074	500280	19591F	PARTICIPANT	\N	PRESENT	0
501075	500280	07029T	PARTICIPANT	\N	PRESENT	0
501076	500280	20086J	PARTICIPANT	\N	PRESENT	0
501077	500280	20114U	PARTICIPANT	\N	PRESENT	0
501078	500280	20028X	PARTICIPANT	\N	PRESENT	0
506130	501827	99004R	PARTICIPANT	\N	PRESENT	0
506131	496311	20144B	PARTICIPANT	\N	PRESENT	0
506132	501827	19711U	PARTICIPANT	\N	PRESENT	0
506133	501827	14225N	PARTICIPANT	\N	PRESENT	0
506134	501827	11048N	PARTICIPANT	\N	PRESENT	0
506135	502453	08010L	PARTICIPANT	\N	PRESENT	0
506136	501827	20022R	PARTICIPANT	\N	PRESENT	0
506137	501827	04045F	PARTICIPANT	\N	PRESENT	0
506138	501827	19669L	PARTICIPANT	\N	PRESENT	0
506139	501827	11033F	PARTICIPANT	\N	PRESENT	0
506145	501827	19631V	PARTICIPANT	\N	PRESENT	0
506146	501827	19687N	PARTICIPANT	\N	PRESENT	0
506147	501827	11040E	PARTICIPANT	\N	PRESENT	0
506148	501827	11070L	PARTICIPANT	\N	PRESENT	0
506149	501827	14357A	PARTICIPANT	\N	PRESENT	0
506150	501827	20044X	PARTICIPANT	\N	PRESENT	0
506151	501827	20080C	PARTICIPANT	\N	PRESENT	0
506152	501827	19667J	PARTICIPANT	\N	PRESENT	0
506153	501827	19503N	PARTICIPANT	\N	PRESENT	0
506154	501827	14327T	PARTICIPANT	\N	PRESENT	0
506155	501827	07029T	PARTICIPANT	\N	PRESENT	0
506156	501827	95063L	PARTICIPANT	\N	PRESENT	0
506157	501827	11053K	PARTICIPANT	\N	PRESENT	0
506158	501827	04086Q	PARTICIPANT	\N	PRESENT	0
506159	501827	19693L	PARTICIPANT	\N	PRESENT	0
506160	501827	19762G	PARTICIPANT	\N	PRESENT	0
506161	501827	01057W	PARTICIPANT	\N	PRESENT	0
506162	501827	07004J	PARTICIPANT	\N	PRESENT	0
506163	501827	19695N	PARTICIPANT	\N	PRESENT	0
506164	501827	11012A	PARTICIPANT	\N	PRESENT	0
506165	501827	19689Q	PARTICIPANT	\N	PRESENT	0
506166	501827	14083S	PARTICIPANT	\N	PRESENT	0
506167	501827	19741B	PARTICIPANT	\N	PRESENT	0
506168	501827	19349W	PARTICIPANT	\N	PRESENT	0
506169	501827	19593H	PARTICIPANT	\N	PRESENT	0
506170	501827	20150Y	PARTICIPANT	\N	PRESENT	0
506171	501827	19647E	PARTICIPANT	\N	PRESENT	0
506172	501827	20038A	PARTICIPANT	\N	PRESENT	0
506173	501827	08034U	PARTICIPANT	\N	PRESENT	0
506174	501827	19651A	PARTICIPANT	\N	PRESENT	0
506175	501827	19347U	PARTICIPANT	\N	PRESENT	0
506176	501827	11026G	PARTICIPANT	\N	PRESENT	0
506177	501827	19335Q	PARTICIPANT	\N	PRESENT	0
506178	501827	19545Y	PARTICIPANT	\N	PRESENT	0
506179	501827	11074Q	PARTICIPANT	\N	PRESENT	0
506180	501827	19717B	PARTICIPANT	\N	PRESENT	0
506181	501827	20036X	PARTICIPANT	\N	PRESENT	0
506182	501827	20070A	PARTICIPANT	\N	PRESENT	0
506183	501827	14021P	PARTICIPANT	\N	PRESENT	0
506184	501827	08010L	PARTICIPANT	\N	PRESENT	0
506185	501827	12016W	PARTICIPANT	\N	PRESENT	0
506186	501827	20120S	PARTICIPANT	\N	PRESENT	0
506187	501827	08011M	PARTICIPANT	\N	PRESENT	0
506197	501827	14001X	PARTICIPANT	\N	PRESENT	0
506200	501827	20132W	PARTICIPANT	\N	PRESENT	0
506201	501827	20098N	PARTICIPANT	\N	PRESENT	0
506202	501827	19591F	PARTICIPANT	\N	PRESENT	0
506203	501827	14041T	PARTICIPANT	\N	PRESENT	0
506204	501827	19701S	PARTICIPANT	\N	PRESENT	0
506205	501827	14259Y	PARTICIPANT	\N	PRESENT	0
506206	501827	19705W	PARTICIPANT	\N	PRESENT	0
506207	501827	14229S	PARTICIPANT	\N	PRESENT	0
506208	505768	19551W	PARTICIPANT	\N	PRESENT	0
506220	501827	14331P	PARTICIPANT	\N	PRESENT	0
506222	506221	19543W	PARTICIPANT	\N	PRESENT	0
506224	506223	19543W	PARTICIPANT	\N	PRESENT	0
506226	506225	19543W	PARTICIPANT	\N	PRESENT	0
506228	506227	19543W	PARTICIPANT	\N	PRESENT	0
506229	501827	04034C	PARTICIPANT	\N	PRESENT	0
506230	501827	14026U	PARTICIPANT	\N	PRESENT	0
506231	501827	19479G	PARTICIPANT	\N	PRESENT	0
485532	484727	19737F	PARTICIPANT	\N	EXCUSE	0
485533	484727	14121F	PRESIDENT	0	PRESENT	0
485534	484727	19551W	PARTICIPANT	\N	EXCUSE	0
485536	484727	11070L	PARTICIPANT	\N	PRESENT	0
485537	484727	19525U	PARTICIPANT	\N	PRESENT	0
485538	484727	11040E	PARTICIPANT	\N	PRESENT	0
490068	489908	19711U	PARTICIPANT	\N	PRESENT	0
490069	489908	99004R	PARTICIPANT	\N	PRESENT	0
490070	489908	19667J	PARTICIPANT	\N	PRESENT	0
490071	489908	19687N	PARTICIPANT	\N	PRESENT	0
490072	489908	04086Q	PARTICIPANT	\N	PRESENT	0
490073	489908	11053K	PARTICIPANT	\N	PRESENT	0
490074	489908	11070L	PARTICIPANT	\N	PRESENT	0
505227	501821	14231L	PARTICIPANT	\N	PRESENT	0
505229	501821	20020P	PARTICIPANT	\N	PRESENT	0
505231	501821	14069U	PARTICIPANT	\N	PRESENT	0
505256	501821	14059S	PARTICIPANT	\N	PRESENT	0
505260	501821	20046A	PARTICIPANT	\N	PRESENT	0
505269	501821	14147R	PARTICIPANT	\N	PRESENT	0
505274	501821	01058X	PARTICIPANT	\N	PRESENT	0
505276	501821	19954N	PARTICIPANT	\N	PRESENT	0
505282	501821	20024T	PARTICIPANT	\N	PRESENT	0
505776	492451	14189C	PARTICIPANT	\N	PRESENT	0
505777	492451	20138D	PARTICIPANT	\N	PRESENT	0
505778	492451	19681G	PARTICIPANT	\N	EXCUSE	0
505779	492451	19693L	PARTICIPANT	\N	PRESENT	0
505780	492451	19599P	PARTICIPANT	\N	PRESENT	0
505781	492451	20106U	PARTICIPANT	\N	PRESENT	0
505782	492451	14179A	PARTICIPANT	\N	PRESENT	0
505783	492451	20066E	PARTICIPANT	\N	PRESENT	0
505784	492451	20034V	PARTICIPANT	\N	PRESENT	0
505785	492451	19715Y	PARTICIPANT	\N	PRESENT	0
505786	492451	20056C	PARTICIPANT	\N	PRESENT	0
505787	492451	08017T	PARTICIPANT	\N	EXCUSE	0
505788	492451	19768N	PARTICIPANT	\N	PRESENT	0
505789	492451	20130U	PARTICIPANT	\N	EXCUSE	0
505790	492451	19798U	PARTICIPANT	\N	PRESENT	0
505791	492451	20098N	PARTICIPANT	\N	PRESENT	0
505792	492451	19527W	PARTICIPANT	\N	PRESENT	0
505793	492451	20046A	PARTICIPANT	\N	PRESENT	0
505794	492451	19749K	PARTICIPANT	\N	PRESENT	0
505795	492451	14030Q	PRESIDENT	0	PRESENT	0
505831	505830	19709B	PARTICIPANT	\N	PRESENT	0
505832	505830	11041F	PARTICIPANT	\N	PRESENT	0
505945	505944	11026G	PARTICIPANT	\N	PRESENT	0
505952	505951	20074E	PARTICIPANT	\N	PRESENT	0
505954	505950	20074E	PARTICIPANT	\N	PRESENT	0
506013	506012	19954N	PARTICIPANT	\N	PRESENT	0
506015	506014	19954N	PARTICIPANT	\N	PRESENT	0
506017	506016	19954N	PARTICIPANT	\N	PRESENT	0
506018	506016	01028R	PARTICIPANT	\N	PRESENT	0
506020	506019	19954N	PARTICIPANT	\N	PRESENT	0
508121	503170	20102Q	PARTICIPANT	\N	PRESENT	0
508122	503170	19637C	PARTICIPANT	\N	PRESENT	0
508123	503170	20096L	PARTICIPANT	\N	PRESENT	0
508124	503170	17229F	PARTICIPANT	\N	PRESENT	0
508125	503170	18083K	PARTICIPANT	\N	PRESENT	0
508126	503170	20106U	PARTICIPANT	\N	PRESENT	0
508127	503170	20118Y	PARTICIPANT	\N	PRESENT	0
508128	503170	20068G	PARTICIPANT	\N	PRESENT	0
508129	503170	11101A	PARTICIPANT	\N	PRESENT	0
508130	503170	11065P	PARTICIPANT	\N	PRESENT	0
508131	503170	19525U	PARTICIPANT	\N	PRESENT	0
508132	503170	05012A	PARTICIPANT	\N	PRESENT	0
508133	503170	08060W	PARTICIPANT	\N	PRESENT	1
508134	503170	20140W	PARTICIPANT	\N	PRESENT	1
508135	503170	19387D	PARTICIPANT	\N	PRESENT	1
508136	503170	19685L	PARTICIPANT	\N	PRESENT	0
508795	502322	19669L	PARTICIPANT	\N	PRESENT	0
508796	502322	19631V	PARTICIPANT	\N	PRESENT	0
508797	502322	12041X	PARTICIPANT	\N	PRESENT	0
508799	502322	14026U	PARTICIPANT	\N	PRESENT	0
508800	502322	08010L	PARTICIPANT	\N	PRESENT	0
508801	502322	20058E	PARTICIPANT	\N	PRESENT	0
508802	502322	19599P	PARTICIPANT	\N	PRESENT	0
508803	502322	19335Q	PARTICIPANT	\N	PRESENT	0
508804	502322	14249W	PARTICIPANT	\N	PRESENT	0
508940	502323	14026U	PARTICIPANT	\N	PRESENT	0
508941	502323	14225N	PARTICIPANT	\N	PRESENT	0
508942	502323	19599P	PARTICIPANT	\N	PRESENT	0
508943	502323	19349W	PARTICIPANT	\N	PRESENT	0
508944	502323	11012A	PARTICIPANT	\N	PRESENT	0
508945	502323	20050V	PARTICIPANT	\N	PRESENT	0
508946	502323	20122U	PARTICIPANT	\N	PRESENT	0
508947	502323	14195A	PARTICIPANT	\N	PRESENT	0
508948	502323	19689Q	PARTICIPANT	\N	PRESENT	0
508949	502323	19347U	PARTICIPANT	\N	PRESENT	0
508950	502323	20142Y	PARTICIPANT	\N	PRESENT	0
508951	502323	11067R	PARTICIPANT	\N	PRESENT	0
508952	502323	19531S	PARTICIPANT	\N	PRESENT	0
508953	502323	20094J	PARTICIPANT	\N	PRESENT	0
508954	502323	20070A	PARTICIPANT	\N	PRESENT	0
508955	502323	20082E	PARTICIPANT	\N	PRESENT	0
508956	502323	19691J	PARTICIPANT	\N	PRESENT	0
508957	502323	20066E	PARTICIPANT	\N	PRESENT	0
508958	502323	19369B	PARTICIPANT	\N	PRESENT	0
508959	502323	20052X	PARTICIPANT	\N	PRESENT	0
508960	502323	14083S	PARTICIPANT	\N	PRESENT	0
508961	502323	11053K	PARTICIPANT	\N	PRESENT	0
508962	502323	98022P	PARTICIPANT	\N	PRESENT	0
508963	502323	14055N	PARTICIPANT	\N	PRESENT	0
508964	502323	19671E	PARTICIPANT	\N	PRESENT	0
508965	502323	14237S	PARTICIPANT	\N	PRESENT	0
508966	502323	20062A	PARTICIPANT	\N	PRESENT	0
508967	502323	11097X	PARTICIPANT	\N	PRESENT	0
508968	502323	08010L	PARTICIPANT	\N	PRESENT	0
508969	502323	19515S	PARTICIPANT	\N	PRESENT	0
508970	502323	01057W	PARTICIPANT	\N	PRESENT	0
508971	502323	08034U	PARTICIPANT	\N	PRESENT	0
508972	502323	19711U	PARTICIPANT	\N	PRESENT	0
508973	502323	19762G	PARTICIPANT	\N	PRESENT	0
508995	502323	19621T	PARTICIPANT	\N	PRESENT	0
508975	502323	20126Y	PARTICIPANT	\N	PRESENT	0
508976	502323	19747H	PARTICIPANT	\N	PRESENT	0
508977	502323	19467C	PARTICIPANT	\N	PRESENT	0
508978	502323	14038Y	PARTICIPANT	\N	PRESENT	0
508979	502323	04071H	PARTICIPANT	\N	PRESENT	0
508980	502323	19399H	PARTICIPANT	\N	PRESENT	0
508981	502323	20044X	PARTICIPANT	\N	PRESENT	0
508982	502323	14327T	PARTICIPANT	\N	PRESENT	0
508787	506668	19563B	PARTICIPANT	\N	EXCUSE	0
508789	505799	14215L	PARTICIPANT	\N	PRESENT	0
508790	505799	04047H	PRESIDENT	0	PRESENT	0
508791	505799	19671E	PARTICIPANT	\N	PRESENT	0
508792	505799	19447X	PARTICIPANT	\N	PRESENT	0
508793	505799	05008E	PARTICIPANT	\N	PRESENT	0
508983	502323	19479G	PARTICIPANT	\N	PRESENT	0
508984	502323	18083K	PARTICIPANT	\N	PRESENT	0
508985	502323	19507S	PARTICIPANT	\N	PRESENT	0
508986	502323	08011M	PARTICIPANT	\N	PRESENT	0
508987	502323	14253S	PARTICIPANT	\N	PRESENT	0
508988	502323	20136B	PARTICIPANT	\N	PRESENT	0
508989	502323	20140W	PARTICIPANT	\N	PRESENT	0
508994	502323	20090E	PARTICIPANT	\N	PRESENT	0
508991	502323	19413M	PARTICIPANT	\N	PRESENT	0
508992	502323	14021P	PARTICIPANT	\N	PRESENT	0
508993	502323	20038A	PARTICIPANT	\N	PRESENT	0
508996	502323	19703U	PARTICIPANT	\N	PRESENT	0
508997	502323	19533U	PARTICIPANT	\N	PRESENT	0
508998	502323	19687N	PARTICIPANT	\N	PRESENT	0
508999	502323	20026V	PARTICIPANT	\N	PRESENT	0
509000	502323	14187A	PARTICIPANT	\N	PRESENT	0
509001	502323	19563B	PARTICIPANT	\N	PRESENT	0
509002	502323	19619A	PARTICIPANT	\N	PRESENT	0
509003	502323	14069U	PARTICIPANT	\N	PRESENT	0
509004	502323	20110Q	PARTICIPANT	\N	PRESENT	0
509005	502323	11048N	PARTICIPANT	\N	PRESENT	0
509006	502323	19651A	PARTICIPANT	\N	PRESENT	0
509007	502323	08061X	PARTICIPANT	\N	PRESENT	0
509008	502323	20080C	PARTICIPANT	\N	PRESENT	0
509009	502323	19647E	PARTICIPANT	\N	PRESENT	0
509010	502323	20106U	PARTICIPANT	\N	PRESENT	0
509011	502323	14213J	PARTICIPANT	\N	PRESENT	0
509012	502323	11101A	PARTICIPANT	\N	PRESENT	0
509013	502323	14357A	PARTICIPANT	\N	PRESENT	0
509014	505799	14053L	PARTICIPANT	\N	PRESENT	0
509015	505799	04071H	PARTICIPANT	\N	PRESENT	0
509016	505799	19649G	PARTICIPANT	\N	PRESENT	0
509017	505799	20074E	PARTICIPANT	\N	PRESENT	0
509018	505799	11026G	PARTICIPANT	\N	PRESENT	0
509019	505799	19581D	PARTICIPANT	\N	PRESENT	0
509573	509572	19741B	PARTICIPANT	\N	PRESENT	0
509574	509572	19667J	PARTICIPANT	\N	PRESENT	0
509575	509572	20116W	PARTICIPANT	\N	PRESENT	0
509576	509572	11040E	PARTICIPANT	\N	PRESENT	0
509577	509572	20080C	PARTICIPANT	\N	PRESENT	0
509578	509572	14083S	PARTICIPANT	\N	PRESENT	0
509579	509572	20070A	PARTICIPANT	\N	PRESENT	0
509580	509572	11074Q	PARTICIPANT	\N	PRESENT	0
509581	509572	19647E	PARTICIPANT	\N	PRESENT	0
509582	509572	11048N	PARTICIPANT	\N	PRESENT	0
509583	509572	19531S	PARTICIPANT	\N	PRESENT	0
509584	509572	99004R	PARTICIPANT	\N	PRESENT	0
509585	509572	07029T	PARTICIPANT	\N	PRESENT	0
509586	509572	19711U	PARTICIPANT	\N	PRESENT	0
509587	509572	08034U	PARTICIPANT	\N	PRESENT	0
509588	509572	12016W	PARTICIPANT	\N	PRESENT	0
509589	509572	19671E	PARTICIPANT	\N	PRESENT	0
509590	509572	19335Q	PARTICIPANT	\N	PRESENT	0
509591	509572	14331P	PARTICIPANT	\N	PRESENT	0
509592	509572	14225N	PRESIDENT	0	PRESENT	0
509593	509572	20044X	PARTICIPANT	\N	PRESENT	0
509594	509572	19762G	PARTICIPANT	\N	PRESENT	0
509595	509572	19689Q	PARTICIPANT	\N	PRESENT	0
511609	509270	14097Y	PARTICIPANT	\N	PRESENT	0
511629	511628	19745F	PARTICIPANT	\N	PRESENT	0
511630	511628	20094J	PARTICIPANT	\N	PRESENT	0
511632	511628	19521Q	PARTICIPANT	\N	PRESENT	0
511633	511628	19820Y	PARTICIPANT	\N	PRESENT	0
511634	511628	20104S	PARTICIPANT	\N	PRESENT	0
511667	511666	19745F	PARTICIPANT	\N	PRESENT	0
511668	511666	20094J	PARTICIPANT	\N	PRESENT	0
511669	511666	20022R	PARTICIPANT	\N	PRESENT	0
511670	511666	20104S	PARTICIPANT	\N	PRESENT	0
511681	509965	01048V	PARTICIPANT	\N	PRESENT	1
511682	509965	20050V	PARTICIPANT	\N	PRESENT	1
511683	509873	04035D	PARTICIPANT	\N	PRESENT	1
511684	509965	14331P	PARTICIPANT	\N	PRESENT	1
511679	509965	19479G	PARTICIPANT	\N	PRESENT	1
511680	509965	11110B	PARTICIPANT	\N	PRESENT	1
511719	502345	11045K	PARTICIPANT	\N	PRESENT	0
511720	502345	01057W	PARTICIPANT	\N	PRESENT	0
511721	502345	14225N	PARTICIPANT	\N	PRESENT	0
511722	502345	14179A	PARTICIPANT	\N	PRESENT	0
511723	509873	11054L	PARTICIPANT	\N	PRESENT	0
511724	509267	19697Q	PARTICIPANT	\N	PRESENT	1
511725	509267	20090E	PARTICIPANT	\N	PRESENT	0
511726	509267	19798U	PARTICIPANT	\N	PRESENT	0
511727	509267	19569H	PARTICIPANT	\N	PRESENT	0
511728	509267	11097X	PARTICIPANT	\N	PRESENT	0
511729	509267	14223L	PARTICIPANT	\N	PRESENT	1
511730	509267	18193Q	PARTICIPANT	\N	PRESENT	0
511731	509267	14026U	PARTICIPANT	\N	PRESENT	1
511732	509267	19553Y	PARTICIPANT	\N	PRESENT	1
511733	509267	11031D	PARTICIPANT	\N	PRESENT	0
511734	509267	19703U	PARTICIPANT	\N	PRESENT	0
511735	509267	14281W	PARTICIPANT	\N	PRESENT	1
511736	509267	14042U	PARTICIPANT	\N	PRESENT	0
511737	509267	19367Y	PARTICIPANT	\N	PRESENT	1
511738	509267	14213J	PARTICIPANT	\N	PRESENT	0
511739	509267	14217N	PARTICIPANT	\N	PRESENT	0
511740	509267	10006L	PRESIDENT	0	PRESENT	0
511741	509267	19683J	PARTICIPANT	\N	PRESENT	0
511742	509267	20130U	PARTICIPANT	\N	PRESENT	0
511743	509267	04092N	PARTICIPANT	\N	PRESENT	0
511744	509267	19713W	PARTICIPANT	\N	PRESENT	0
511745	509267	08045X	PARTICIPANT	\N	PRESENT	1
511746	509267	20040T	PARTICIPANT	\N	PRESENT	1
511747	509267	17965H	PARTICIPANT	\N	PRESENT	0
511748	509267	19301E	PARTICIPANT	\N	PRESENT	0
511749	509267	19691J	PARTICIPANT	\N	PRESENT	0
511750	509267	19717B	PARTICIPANT	\N	PRESENT	1
511751	509267	20172F	PARTICIPANT	\N	PRESENT	0
511752	509267	20066E	PARTICIPANT	\N	PRESENT	0
511753	509267	11103C	PARTICIPANT	\N	PRESENT	1
511754	509267	19657G	PARTICIPANT	\N	PRESENT	1
511755	509267	14071N	PARTICIPANT	\N	PRESENT	0
511756	509267	04043D	PARTICIPANT	\N	PRESENT	0
511757	509267	19760E	PARTICIPANT	\N	PRESENT	0
511758	509267	17779H	PARTICIPANT	\N	EXCUSE	0
511759	502345	11074Q	PARTICIPANT	\N	PRESENT	0
511760	502345	20028X	PARTICIPANT	\N	PRESENT	0
511761	502345	20018V	PARTICIPANT	\N	PRESENT	0
511762	502345	20082E	PARTICIPANT	\N	PRESENT	0
511763	502345	20030R	PARTICIPANT	\N	PRESENT	0
511764	502345	19489J	PARTICIPANT	\N	PRESENT	0
511765	502345	11056N	PARTICIPANT	\N	PRESENT	0
511766	502345	19575F	PARTICIPANT	\N	PRESENT	0
511767	502345	08069G	PARTICIPANT	\N	PRESENT	0
511768	502345	11040E	PARTICIPANT	\N	PRESENT	0
511769	502345	14001X	PARTICIPANT	\N	PRESENT	0
511770	502345	14038Y	PARTICIPANT	\N	PRESENT	0
511771	502345	20110Q	PARTICIPANT	\N	PRESENT	0
511772	502345	19782L	PARTICIPANT	\N	PRESENT	0
511774	502345	14121F	PARTICIPANT	\N	PRESENT	0
511775	502345	14033T	PARTICIPANT	\N	PRESENT	0
511777	502345	19349W	PARTICIPANT	\N	PRESENT	0
511779	502345	04045F	PARTICIPANT	\N	PRESENT	0
511781	502345	95063L	PARTICIPANT	\N	PRESENT	0
511784	502345	07029T	PARTICIPANT	\N	PRESENT	0
511787	502345	19729F	PARTICIPANT	\N	PRESENT	0
511789	502345	20024T	PARTICIPANT	\N	PRESENT	0
511791	502345	20108W	PARTICIPANT	\N	PRESENT	0
511792	502345	19866P	PARTICIPANT	\N	PRESENT	0
511793	502345	14147R	PARTICIPANT	\N	PRESENT	0
511794	502345	19711U	PARTICIPANT	\N	PRESENT	0
511795	502345	19629C	PARTICIPANT	\N	PRESENT	0
511796	502345	14111D	PARTICIPANT	\N	PRESENT	0
511797	502345	19543W	PARTICIPANT	\N	PRESENT	0
511798	502345	19671E	PARTICIPANT	\N	PRESENT	0
511799	502345	14327T	PARTICIPANT	\N	PRESENT	0
511800	502345	14231L	PARTICIPANT	\N	PRESENT	0
511801	502345	14205J	PARTICIPANT	\N	PRESENT	0
511802	502345	20054A	PARTICIPANT	\N	PRESENT	0
511803	502345	14055N	PARTICIPANT	\N	PRESENT	0
511804	502345	08028W	PARTICIPANT	\N	PRESENT	0
511805	502345	20044X	PARTICIPANT	\N	PRESENT	0
511806	502345	19467C	PARTICIPANT	\N	PRESENT	0
511807	502345	20116W	PARTICIPANT	\N	PRESENT	0
511808	502345	14031R	PARTICIPANT	\N	PRESENT	0
511809	502345	20126Y	PARTICIPANT	\N	PRESENT	0
511810	502345	08009T	PARTICIPANT	\N	PRESENT	0
511811	502345	20088L	PARTICIPANT	\N	PRESENT	0
511812	502345	19687N	PARTICIPANT	\N	PRESENT	0
511813	502345	18083K	PARTICIPANT	\N	PRESENT	0
511814	502345	19762G	PARTICIPANT	\N	PRESENT	0
511815	502345	19954N	PARTICIPANT	\N	PRESENT	0
484529	479638	07033P	PARTICIPANT	\N	EXCUSE	0
484530	479638	14135M	PARTICIPANT	\N	EXCUSE	0
484536	479638	96004D	PARTICIPANT	\N	EXCUSE	0
484537	479638	19729F	PARTICIPANT	\N	EXCUSE	0
484539	481608	14030Q	PRESIDENT	0	PRESENT	0
484540	481608	19621T	PARTICIPANT	\N	EXCUSE	0
484541	481608	08020N	PARTICIPANT	\N	EXCUSE	0
484542	481608	19701S	PARTICIPANT	\N	PRESENT	0
484543	481608	11031D	PARTICIPANT	\N	EXCUSE	0
484544	481608	80013X	PARTICIPANT	\N	PRESENT	0
484545	481608	08031R	PARTICIPANT	\N	PRESENT	0
484546	481608	07029T	PARTICIPANT	\N	PRESENT	0
484547	481608	08017T	PARTICIPANT	\N	PRESENT	0
484548	481608	11067R	PARTICIPANT	\N	EXCUSE	0
484549	481608	14235Q	PARTICIPANT	\N	EXCUSE	0
484550	481608	19269X	PARTICIPANT	\N	EXCUSE	0
484551	481608	19749K	PARTICIPANT	\N	PRESENT	0
486787	484737	04086Q	PARTICIPANT	\N	PRESENT	0
486788	484737	19758L	PARTICIPANT	\N	PRESENT	0
486789	484737	11045K	PARTICIPANT	\N	PRESENT	0
486790	484737	14205J	PARTICIPANT	\N	PRESENT	0
486791	484737	14079W	PARTICIPANT	\N	PRESENT	0
486792	484737	18083K	PARTICIPANT	\N	PRESENT	0
486793	484737	07004J	PARTICIPANT	\N	PRESENT	0
486794	484737	14267Y	PARTICIPANT	\N	PRESENT	0
486795	484737	10006L	PARTICIPANT	\N	PRESENT	0
486796	484737	19826F	PARTICIPANT	\N	PRESENT	0
486797	484737	08073C	PARTICIPANT	\N	PRESENT	0
486798	484737	19531S	PARTICIPANT	\N	PRESENT	0
486799	484737	19585H	PARTICIPANT	\N	PRESENT	0
489114	489030	11067R	PARTICIPANT	\N	EXCUSE	0
489115	489030	01034P	PARTICIPANT	\N	EXCUSE	0
489116	489030	19479G	PARTICIPANT	\N	PRESENT	0
489117	489030	11097X	PRESIDENT	0	PRESENT	0
489118	489030	11012A	PARTICIPANT	\N	EXCUSE	0
489119	489030	04092N	PARTICIPANT	\N	EXCUSE	0
489120	489030	19503N	PARTICIPANT	\N	PRESENT	0
489121	489030	14331P	PARTICIPANT	\N	PRESENT	0
489122	489030	19703U	PARTICIPANT	\N	PRESENT	0
489123	489030	19683J	PARTICIPANT	\N	PRESENT	0
489124	489030	19553Y	PARTICIPANT	\N	PRESENT	0
489125	489030	19643A	PARTICIPANT	\N	PRESENT	0
489130	489030	19569H	PARTICIPANT	\N	PRESENT	0
489127	489030	04085P	PARTICIPANT	\N	PRESENT	0
489128	489030	14081Q	PARTICIPANT	\N	PRESENT	0
489129	489030	10006L	PARTICIPANT	\N	PRESENT	0
489131	489030	19697Q	PARTICIPANT	\N	PRESENT	0
489132	489030	99004R	PARTICIPANT	\N	PRESENT	0
489136	489030	19649G	PARTICIPANT	\N	PRESENT	0
489134	489030	19691J	PARTICIPANT	\N	PRESENT	0
489135	489030	11031D	PARTICIPANT	\N	PRESENT	0
489137	489030	19573D	PARTICIPANT	\N	PRESENT	0
489138	489030	04059M	PARTICIPANT	\N	PRESENT	0
489139	489030	19545Y	PARTICIPANT	\N	PRESENT	0
489175	489030	19663E	PARTICIPANT	\N	EXCUSE	0
490409	489867	01028R	PARTICIPANT	\N	PRESENT	0
490410	489867	20136B	PARTICIPANT	\N	PRESENT	0
490411	489867	19689Q	PARTICIPANT	\N	PRESENT	0
490412	489867	19669L	PARTICIPANT	\N	PRESENT	0
490413	489867	14275Y	PARTICIPANT	\N	PRESENT	0
490414	489867	19301E	PARTICIPANT	\N	PRESENT	0
490415	489867	19675J	PARTICIPANT	\N	PRESENT	0
490416	489867	19413M	PARTICIPANT	\N	PRESENT	0
490417	489867	01062T	PARTICIPANT	\N	PRESENT	0
490418	489867	20064C	PARTICIPANT	\N	PRESENT	0
490419	489867	11041F	PARTICIPANT	\N	PRESENT	0
490420	489867	19527W	PARTICIPANT	\N	PRESENT	0
490421	489867	01034P	PARTICIPANT	\N	PRESENT	0
490422	489867	20046A	PARTICIPANT	\N	PRESENT	0
490423	489867	11066Q	PARTICIPANT	\N	PRESENT	0
490424	489867	20026V	PARTICIPANT	\N	PRESENT	0
490425	489867	19749K	PARTICIPANT	\N	PRESENT	0
490426	489867	19479G	PARTICIPANT	\N	PRESENT	0
490427	489867	20122U	PARTICIPANT	\N	PRESENT	0
490428	489867	20058E	PARTICIPANT	\N	PRESENT	0
490429	489867	14173T	PARTICIPANT	\N	PRESENT	0
490430	489867	19585H	PARTICIPANT	\N	PRESENT	0
491480	491479	14327T	PARTICIPANT	\N	PRESENT	0
491263	491262	14133K	PARTICIPANT	\N	PRESENT	0
491264	491262	20042V	PARTICIPANT	\N	PRESENT	0
491265	491262	14105F	PARTICIPANT	\N	PRESENT	0
491266	491262	14255U	PARTICIPANT	\N	PRESENT	0
491267	491262	04042C	PRESIDENT	0	PRESENT	0
491268	491262	12028B	PARTICIPANT	\N	PRESENT	0
491269	491262	19721W	PARTICIPANT	\N	PRESENT	0
491270	491262	11080N	PARTICIPANT	\N	PRESENT	0
491271	491262	14267Y	PARTICIPANT	\N	PRESENT	0
491272	491262	11027H	PARTICIPANT	\N	PRESENT	0
491481	491479	08009T	PARTICIPANT	\N	PRESENT	0
491483	491482	14327T	PARTICIPANT	\N	PRESENT	0
491275	491262	01024M	PARTICIPANT	\N	PRESENT	0
491276	491262	17023S	PARTICIPANT	\N	PRESENT	0
491277	491262	97011G	PARTICIPANT	\N	PRESENT	0
491278	491262	04035D	PARTICIPANT	\N	PRESENT	0
491279	491262	11083R	PARTICIPANT	\N	PRESENT	0
491280	491262	19347U	PARTICIPANT	\N	PRESENT	0
491281	491262	08056B	PARTICIPANT	\N	PRESENT	0
491282	491262	14211G	PARTICIPANT	\N	PRESENT	0
491283	491262	19565D	PARTICIPANT	\N	PRESENT	0
491284	491262	98022P	PARTICIPANT	\N	PRESENT	0
491285	491262	11064N	PARTICIPANT	\N	PRESENT	0
491286	491262	20072C	PARTICIPANT	\N	PRESENT	0
491287	491262	20128B	PARTICIPANT	\N	PRESENT	0
491288	491262	08069G	PARTICIPANT	\N	PRESENT	0
491289	491262	14097Y	PARTICIPANT	\N	PRESENT	0
491490	491473	04043D	PARTICIPANT	\N	PRESENT	0
491291	491262	19583F	PARTICIPANT	\N	PRESENT	0
491292	491262	12041X	PARTICIPANT	\N	PRESENT	0
491293	491262	19709B	PARTICIPANT	\N	PRESENT	0
491294	491262	16685X	PARTICIPANT	\N	PRESENT	0
491547	491507	20130U	PARTICIPANT	\N	PRESENT	0
491296	491262	14059S	PARTICIPANT	\N	PRESENT	0
491548	491507	19697Q	PARTICIPANT	\N	PRESENT	0
491298	491262	08047A	PARTICIPANT	\N	PRESENT	0
491299	491262	14193X	PARTICIPANT	\N	PRESENT	0
491549	491507	17965H	PARTICIPANT	\N	PRESENT	0
491301	491262	19443T	PARTICIPANT	\N	PRESENT	0
491302	491262	11054L	PARTICIPANT	\N	PRESENT	0
491303	491262	19421M	PARTICIPANT	\N	PRESENT	0
491304	491262	01058X	PARTICIPANT	\N	PRESENT	0
491305	491262	19669L	PARTICIPANT	\N	PRESENT	0
491306	491262	01062T	PARTICIPANT	\N	PRESENT	0
491307	491262	20064C	PARTICIPANT	\N	PRESENT	0
491308	491262	11041F	PARTICIPANT	\N	PRESENT	0
491309	491262	11066Q	PARTICIPANT	\N	PRESENT	0
491310	491262	04034C	PARTICIPANT	\N	PRESENT	0
491550	491507	19415P	PARTICIPANT	\N	PRESENT	0
491551	491507	19691J	PARTICIPANT	\N	PRESENT	0
491552	491507	14223L	PARTICIPANT	\N	PRESENT	0
491553	491507	20148F	PARTICIPANT	\N	PRESENT	0
491554	491507	17779H	PARTICIPANT	\N	PRESENT	0
491555	491507	19723Y	PARTICIPANT	\N	PRESENT	0
491556	491507	19703U	PARTICIPANT	\N	PRESENT	0
491557	491507	19679N	PARTICIPANT	\N	PRESENT	0
491558	491507	14042U	PARTICIPANT	\N	PRESENT	0
491559	491507	14213J	PARTICIPANT	\N	PRESENT	0
491560	491507	19367Y	PARTICIPANT	\N	PRESENT	0
491561	491507	19657G	PARTICIPANT	\N	PRESENT	0
491562	491507	10006L	PRESIDENT	0	PRESENT	0
491563	491507	19760E	PARTICIPANT	\N	PRESENT	0
491564	491507	19295A	PARTICIPANT	\N	EXCUSE	0
491565	491507	08045X	PARTICIPANT	\N	PRESENT	0
491566	491507	14217N	PARTICIPANT	\N	PRESENT	0
491567	491507	19591F	PARTICIPANT	\N	PRESENT	0
491569	491485	14111D	PARTICIPANT	\N	PRESENT	0
491570	491485	19649G	PARTICIPANT	\N	PRESENT	0
491571	491485	11026G	PARTICIPANT	\N	PRESENT	0
491572	491485	04047H	PRESIDENT	0	PRESENT	0
491573	491485	19673G	PARTICIPANT	\N	PRESENT	0
491574	491485	05008E	PARTICIPANT	\N	PRESENT	0
491575	491485	14089Y	PARTICIPANT	\N	PRESENT	0
491576	491485	11056N	PARTICIPANT	\N	PRESENT	0
491577	491485	17737W	PARTICIPANT	\N	PRESENT	0
491578	491485	95063L	PARTICIPANT	\N	PRESENT	0
491579	491485	19629C	PARTICIPANT	\N	PRESENT	0
491580	491485	20108W	PARTICIPANT	\N	PRESENT	0
491581	491485	14041T	PARTICIPANT	\N	PRESENT	0
491582	491485	14107H	PARTICIPANT	\N	PRESENT	0
491583	491485	20110Q	PARTICIPANT	\N	PRESENT	0
491584	491485	14147R	PARTICIPANT	\N	PRESENT	0
491585	491485	14069U	PARTICIPANT	\N	PRESENT	0
491586	491485	14151M	PARTICIPANT	\N	PRESENT	0
491587	491485	20114U	PARTICIPANT	\N	PRESENT	0
491588	491485	14215L	PARTICIPANT	\N	PRESENT	0
491589	491485	08018U	PARTICIPANT	\N	PRESENT	0
491590	491485	14259Y	PARTICIPANT	\N	PRESENT	0
491591	491485	11033F	PARTICIPANT	\N	PRESENT	0
491592	491485	19447X	PARTICIPANT	\N	PRESENT	0
506284	501828	11040E	PARTICIPANT	\N	PRESENT	0
506285	501828	19687N	PARTICIPANT	\N	PRESENT	0
506286	501828	19593H	PARTICIPANT	\N	PRESENT	0
506287	501828	12016W	PARTICIPANT	\N	PRESENT	0
506288	501828	20080C	PARTICIPANT	\N	PRESENT	0
506289	501828	19631V	PARTICIPANT	\N	PRESENT	0
506290	501828	19647E	PARTICIPANT	\N	PRESENT	0
506291	501828	19347U	PARTICIPANT	\N	PRESENT	0
506292	501828	19689Q	PARTICIPANT	\N	PRESENT	0
506293	501828	19545Y	PARTICIPANT	\N	PRESENT	0
506294	501828	19717B	PARTICIPANT	\N	PRESENT	0
506295	501828	20132W	PARTICIPANT	\N	PRESENT	0
506296	501828	14327T	PARTICIPANT	\N	PRESENT	0
506297	501828	11070L	PARTICIPANT	\N	PRESENT	0
506298	501828	19479G	PARTICIPANT	\N	PRESENT	0
506299	501828	14083S	PARTICIPANT	\N	PRESENT	0
506300	501828	19335Q	PARTICIPANT	\N	PRESENT	0
506301	501828	07004J	PARTICIPANT	\N	PRESENT	0
506302	501828	19621T	PARTICIPANT	\N	PRESENT	0
506303	501828	08034U	PARTICIPANT	\N	PRESENT	0
506304	501828	14357A	PARTICIPANT	\N	PRESENT	0
506305	501828	19711U	PARTICIPANT	\N	PRESENT	0
506306	501828	04086Q	PARTICIPANT	\N	PRESENT	0
506307	501828	20022R	PARTICIPANT	\N	PRESENT	0
506308	501828	20044X	PARTICIPANT	\N	PRESENT	0
506309	501828	19762G	PARTICIPANT	\N	PRESENT	0
506282	501828	14026U	PARTICIPANT	\N	PRESENT	0
506283	501828	11074Q	PARTICIPANT	\N	PRESENT	0
506310	501828	20034V	PARTICIPANT	\N	PRESENT	0
506311	501828	07029T	PARTICIPANT	\N	PRESENT	0
506312	501828	01057W	PARTICIPANT	\N	PRESENT	0
506313	501828	20038A	PARTICIPANT	\N	PRESENT	0
506314	501828	19693L	PARTICIPANT	\N	PRESENT	0
506315	501828	95063L	PARTICIPANT	\N	PRESENT	0
506317	501828	04045F	PARTICIPANT	\N	PRESENT	0
506318	501828	19651A	PARTICIPANT	\N	PRESENT	0
506319	501828	14229S	PARTICIPANT	\N	PRESENT	0
506321	501828	20070A	PARTICIPANT	\N	PRESENT	0
506322	501828	14225N	PARTICIPANT	\N	PRESENT	0
506323	501828	11048N	PARTICIPANT	\N	PRESENT	0
506324	501828	20120S	PARTICIPANT	\N	PRESENT	0
506325	501828	19701S	PARTICIPANT	\N	PRESENT	0
506326	501828	04071H	PARTICIPANT	\N	PRESENT	0
506327	501828	17023S	PARTICIPANT	\N	PRESENT	0
506328	501828	08011M	PARTICIPANT	\N	PRESENT	0
506329	501828	11077T	PARTICIPANT	\N	PRESENT	0
506330	501828	14331P	PARTICIPANT	\N	PRESENT	0
506331	501828	19741B	PARTICIPANT	\N	PRESENT	0
506332	501828	19349W	PARTICIPANT	\N	PRESENT	0
506333	501828	20036X	PARTICIPANT	\N	PRESENT	0
506334	501828	08010L	PARTICIPANT	\N	PRESENT	0
506347	501829	12041X	PARTICIPANT	\N	PRESENT	0
506348	501829	20080C	PARTICIPANT	\N	PRESENT	0
506349	501829	19631V	PARTICIPANT	\N	PRESENT	0
506350	501829	19667J	PARTICIPANT	\N	PRESENT	0
506351	501829	11048N	PARTICIPANT	\N	PRESENT	0
506352	501829	14225N	PARTICIPANT	\N	PRESENT	0
506353	501829	20034V	PARTICIPANT	\N	PRESENT	0
506354	501829	11040E	PARTICIPANT	\N	PRESENT	0
506355	501829	20022R	PARTICIPANT	\N	PRESENT	0
506356	501829	11012A	PARTICIPANT	\N	PRESENT	0
506360	501829	19349W	PARTICIPANT	\N	PRESENT	0
506358	501829	04086Q	PARTICIPANT	\N	PRESENT	0
506359	501829	20036X	PARTICIPANT	\N	PRESENT	0
506361	501829	14083S	PARTICIPANT	\N	PRESENT	0
506362	501829	04045F	PARTICIPANT	\N	PRESENT	0
506363	501829	07004J	PARTICIPANT	\N	PRESENT	0
506364	501829	20044X	PARTICIPANT	\N	PRESENT	0
506365	501829	19711U	PARTICIPANT	\N	PRESENT	0
506366	501829	95063L	PARTICIPANT	\N	PRESENT	0
506367	501829	14357A	PARTICIPANT	\N	PRESENT	0
506368	501829	08034U	PARTICIPANT	\N	PRESENT	0
506372	501829	19689Q	PARTICIPANT	\N	PRESENT	0
506370	501829	19693L	PARTICIPANT	\N	PRESENT	0
506371	501829	14331P	PARTICIPANT	\N	PRESENT	0
506373	501829	19671E	PARTICIPANT	\N	PRESENT	0
506374	501829	19741B	PARTICIPANT	\N	PRESENT	0
506375	501829	19335Q	PARTICIPANT	\N	PRESENT	0
506376	501829	14327T	PARTICIPANT	\N	PRESENT	0
506377	501829	19347U	PARTICIPANT	\N	PRESENT	0
506378	501829	19687N	PARTICIPANT	\N	PRESENT	0
506379	501829	19565D	PARTICIPANT	\N	PRESENT	0
506380	501829	11072N	PARTICIPANT	\N	PRESENT	0
506381	501829	19531S	PARTICIPANT	\N	PRESENT	0
506382	501829	20070A	PARTICIPANT	\N	PRESENT	0
506383	501829	11070L	PARTICIPANT	\N	PRESENT	0
506384	501829	19647E	PARTICIPANT	\N	PRESENT	0
506385	501829	11074Q	PARTICIPANT	\N	PRESENT	0
506386	501829	07029T	PARTICIPANT	\N	PRESENT	0
506387	501829	19545Y	PARTICIPANT	\N	PRESENT	0
506388	501829	19651A	PARTICIPANT	\N	PRESENT	0
506389	501829	08010L	PARTICIPANT	\N	PRESENT	0
506390	501829	19762G	PARTICIPANT	\N	PRESENT	0
506391	501829	08011M	PARTICIPANT	\N	PRESENT	0
506392	501829	20038A	PARTICIPANT	\N	PRESENT	0
506393	501829	20100N	PARTICIPANT	\N	PRESENT	0
506394	501829	19479G	PARTICIPANT	\N	PRESENT	0
506395	501829	14229S	PARTICIPANT	\N	PRESENT	0
506396	501829	19643A	PARTICIPANT	\N	PRESENT	0
506397	501829	19701S	PARTICIPANT	\N	PRESENT	0
506398	501829	19551W	PARTICIPANT	\N	PRESENT	0
506399	501829	19591F	PARTICIPANT	\N	PRESENT	0
506400	501829	04033B	PARTICIPANT	\N	PRESENT	0
506401	501829	12016W	PARTICIPANT	\N	PRESENT	0
506402	501829	20098N	PARTICIPANT	\N	PRESENT	0
506403	501829	19675J	PARTICIPANT	\N	PRESENT	0
506404	501829	19399H	PARTICIPANT	\N	PRESENT	0
506405	501829	04071H	PARTICIPANT	\N	PRESENT	0
506462	501830	11070L	PARTICIPANT	\N	PRESENT	0
506463	501830	14225N	PARTICIPANT	\N	PRESENT	0
506464	501830	11048N	PARTICIPANT	\N	PRESENT	0
506465	501830	11012A	PARTICIPANT	\N	PRESENT	0
506466	501830	19717B	PARTICIPANT	\N	PRESENT	0
506467	501830	20080C	PARTICIPANT	\N	PRESENT	0
506468	501830	12016W	PARTICIPANT	\N	PRESENT	0
506469	501830	19347U	PARTICIPANT	\N	PRESENT	0
506470	501830	20100N	PARTICIPANT	\N	PRESENT	0
506471	501830	11053K	PARTICIPANT	\N	PRESENT	0
506472	501830	14327T	PARTICIPANT	\N	PRESENT	0
506473	501830	19479G	PARTICIPANT	\N	PRESENT	0
506474	501830	14083S	PARTICIPANT	\N	PRESENT	0
506475	501830	19335Q	PARTICIPANT	\N	PRESENT	0
506476	501830	19349W	PARTICIPANT	\N	PRESENT	0
506477	501830	19687N	PARTICIPANT	\N	PRESENT	0
506478	501830	19565D	PARTICIPANT	\N	PRESENT	0
506479	501830	19667J	PARTICIPANT	\N	PRESENT	0
506480	501830	20038A	PARTICIPANT	\N	PRESENT	0
506481	501830	04045F	PARTICIPANT	\N	PRESENT	0
506482	501830	19651A	PARTICIPANT	\N	PRESENT	0
506483	501830	07029T	PARTICIPANT	\N	PRESENT	0
506484	501830	19675J	PARTICIPANT	\N	PRESENT	0
506485	501830	20044X	PARTICIPANT	\N	PRESENT	0
506486	501830	14357A	PARTICIPANT	\N	PRESENT	0
506487	501830	19711U	PARTICIPANT	\N	PRESENT	0
506488	501830	19399H	PARTICIPANT	\N	PRESENT	0
506489	501830	19762G	PARTICIPANT	\N	PRESENT	0
506490	501830	04086Q	PARTICIPANT	\N	PRESENT	0
506491	501830	08034U	PARTICIPANT	\N	PRESENT	0
506492	501830	19647E	PARTICIPANT	\N	PRESENT	0
506493	501830	20070A	PARTICIPANT	\N	PRESENT	0
506494	501830	19545Y	PARTICIPANT	\N	PRESENT	0
506495	501830	04071H	PARTICIPANT	\N	PRESENT	0
506496	501830	04033B	PARTICIPANT	\N	PRESENT	0
506497	501830	11074Q	PARTICIPANT	\N	PRESENT	0
506498	501830	19643A	PARTICIPANT	\N	PRESENT	0
506499	501830	14331P	PARTICIPANT	\N	PRESENT	0
506500	501830	19701S	PARTICIPANT	\N	PRESENT	0
506501	501830	11072N	PARTICIPANT	\N	PRESENT	0
506502	501830	08011M	PARTICIPANT	\N	PRESENT	0
506503	501830	19531S	PARTICIPANT	\N	PRESENT	0
506504	501830	20036X	PARTICIPANT	\N	PRESENT	0
506505	501830	20022R	PARTICIPANT	\N	PRESENT	0
506506	501830	08010L	PARTICIPANT	\N	PRESENT	0
506507	501830	19689Q	PARTICIPANT	\N	PRESENT	0
506508	501830	11040E	PARTICIPANT	\N	PRESENT	0
506509	501830	19671E	PARTICIPANT	\N	PRESENT	0
506510	501830	07004J	PARTICIPANT	\N	PRESENT	0
506511	501830	20034V	PARTICIPANT	\N	PRESENT	0
506512	501830	19593H	PARTICIPANT	\N	PRESENT	0
506513	501830	19741B	PARTICIPANT	\N	PRESENT	0
506514	501830	14259Y	PARTICIPANT	\N	PRESENT	0
488187	486981	19611R	PRESIDENT	0	PRESENT	0
488188	486981	14197C	PARTICIPANT	\N	PRESENT	0
488189	486981	19369B	PARTICIPANT	\N	PRESENT	0
488190	486981	19629C	PARTICIPANT	\N	PRESENT	0
488191	486981	19687N	PARTICIPANT	\N	PRESENT	0
488192	486981	19527W	PARTICIPANT	\N	PRESENT	0
488193	486981	14097Y	PARTICIPANT	\N	PRESENT	0
488347	487910	19766L	PARTICIPANT	\N	PRESENT	0
488348	487910	19697Q	PARTICIPANT	\N	PRESENT	0
488349	487910	19643A	PARTICIPANT	\N	PRESENT	0
488350	487910	19479G	PARTICIPANT	\N	PRESENT	0
488351	487910	11067R	PARTICIPANT	\N	PRESENT	0
488352	487910	19649G	PARTICIPANT	\N	PRESENT	0
488353	487910	04092N	PRESIDENT	0	PRESENT	0
488354	487910	11097X	PARTICIPANT	\N	PRESENT	0
488355	487910	14081Q	PARTICIPANT	\N	PRESENT	0
488356	487910	19715Y	PARTICIPANT	\N	PRESENT	0
488357	487910	19667J	PARTICIPANT	\N	PRESENT	0
488358	487910	11070L	PARTICIPANT	\N	PRESENT	0
488359	487910	19447X	PARTICIPANT	\N	PRESENT	0
488360	487910	19703U	PARTICIPANT	\N	PRESENT	0
488361	487910	19553Y	PARTICIPANT	\N	PRESENT	0
488362	487910	19573D	PARTICIPANT	\N	PRESENT	0
488363	487910	14041T	PARTICIPANT	\N	PRESENT	0
488364	487910	19503N	PARTICIPANT	\N	PRESENT	0
488365	487910	99004R	PARTICIPANT	\N	PRESENT	0
488366	487910	10006L	PARTICIPANT	\N	PRESENT	0
488367	487910	19683J	PARTICIPANT	\N	PRESENT	0
488368	487910	01034P	PARTICIPANT	\N	EXCUSE	0
488369	487910	11012A	PARTICIPANT	\N	EXCUSE	0
493396	493395	05008E	PARTICIPANT	\N	PRESENT	0
493397	493395	11053K	PARTICIPANT	\N	PRESENT	0
493398	493395	01028R	PARTICIPANT	\N	PRESENT	0
495985	495984	14042U	PARTICIPANT	\N	PRESENT	0
495986	495984	19569H	PARTICIPANT	\N	PRESENT	0
495987	495984	01034P	PARTICIPANT	\N	PRESENT	0
504877	501820	14257W	PARTICIPANT	\N	PRESENT	0
504878	501820	92040Q	PARTICIPANT	\N	PRESENT	0
504879	501820	20104S	PARTICIPANT	\N	PRESENT	0
504880	501820	19575F	PARTICIPANT	\N	PRESENT	0
504881	501820	20040T	PARTICIPANT	\N	PRESENT	0
504882	501820	14147R	PARTICIPANT	\N	PRESENT	0
504883	501820	19335Q	PARTICIPANT	\N	PRESENT	0
504884	501820	20126Y	PARTICIPANT	\N	PRESENT	0
504885	501820	19689Q	PARTICIPANT	\N	PRESENT	0
504886	501820	14179A	PARTICIPANT	\N	PRESENT	0
504887	501820	20020P	PARTICIPANT	\N	PRESENT	0
504888	501820	19611R	PARTICIPANT	\N	PRESENT	0
504889	501820	19581D	PARTICIPANT	\N	PRESENT	0
504890	501820	19367Y	PARTICIPANT	\N	PRESENT	0
504891	501820	19735D	PARTICIPANT	\N	PRESENT	0
504892	501820	19713W	PARTICIPANT	\N	PRESENT	0
504893	501820	11085T	PARTICIPANT	\N	PRESENT	0
504894	501820	19441R	PARTICIPANT	\N	PRESENT	0
504895	501820	14073Q	PARTICIPANT	\N	PRESENT	0
504896	501820	19619A	PARTICIPANT	\N	PRESENT	0
504897	501820	14267Y	PARTICIPANT	\N	PRESENT	0
504898	501820	19479G	PARTICIPANT	\N	PRESENT	0
504899	501820	14189C	PARTICIPANT	\N	PRESENT	0
504900	501820	14219Q	PARTICIPANT	\N	PRESENT	0
504901	501820	01024M	PARTICIPANT	\N	PRESENT	0
504902	501820	97011G	PARTICIPANT	\N	PRESENT	0
504903	501820	14327T	PARTICIPANT	\N	PRESENT	0
504904	501820	20058E	PARTICIPANT	\N	PRESENT	0
504905	501820	19621T	PARTICIPANT	\N	PRESENT	0
504906	501820	20144B	PARTICIPANT	\N	PRESENT	0
504907	501820	11048N	PARTICIPANT	\N	PRESENT	0
504908	501820	19543W	PARTICIPANT	\N	PRESENT	0
504909	501820	20026V	PARTICIPANT	\N	PRESENT	0
504910	501820	19954N	PARTICIPANT	\N	PRESENT	0
504911	501820	20096L	PARTICIPANT	\N	PRESENT	0
504912	501820	14038Y	PARTICIPANT	\N	PRESENT	0
504913	501820	19699S	PARTICIPANT	\N	PRESENT	0
504914	501820	20034V	PARTICIPANT	\N	PRESENT	0
504915	501820	19745F	PARTICIPANT	\N	PRESENT	0
504916	501820	19521Q	PARTICIPANT	\N	PRESENT	0
504917	501820	20024T	PARTICIPANT	\N	PRESENT	0
504918	501820	19399H	PARTICIPANT	\N	PRESENT	0
504919	501820	20128B	PARTICIPANT	\N	PRESENT	0
504920	501820	14213J	PARTICIPANT	\N	PRESENT	0
504921	501820	11043H	PARTICIPANT	\N	PRESENT	0
504922	501820	19723Y	PARTICIPANT	\N	PRESENT	0
504923	501820	20148F	PARTICIPANT	\N	PRESENT	0
504924	501820	19421M	PARTICIPANT	\N	PRESENT	0
504925	501820	14217N	PARTICIPANT	\N	PRESENT	0
504926	501820	14059S	PARTICIPANT	\N	PRESENT	0
504927	501820	19507S	PARTICIPANT	\N	PRESENT	0
504928	501820	14357A	PARTICIPANT	\N	PRESENT	0
504929	501820	19729F	PARTICIPANT	\N	PRESENT	0
504930	501820	01043Q	PARTICIPANT	\N	PRESENT	0
504931	501820	19657G	PARTICIPANT	\N	PRESENT	0
504932	501820	20044X	PARTICIPANT	\N	PRESENT	0
504933	501820	19762G	PARTICIPANT	\N	PRESENT	0
504934	501820	01025N	PARTICIPANT	\N	PRESENT	0
504935	501820	14231L	PARTICIPANT	\N	PRESENT	0
504948	501820	19467C	PARTICIPANT	\N	PRESENT	0
504953	501820	20084G	PARTICIPANT	\N	PRESENT	0
504938	501820	14001X	PARTICIPANT	\N	PRESENT	0
504939	501820	14030Q	PARTICIPANT	\N	PRESENT	0
504940	501820	19569H	PARTICIPANT	\N	PRESENT	0
504941	501820	14331P	PARTICIPANT	\N	PRESENT	0
504942	501820	14042U	PARTICIPANT	\N	PRESENT	0
504943	501820	19531S	PARTICIPANT	\N	PRESENT	0
504944	501820	14193X	PARTICIPANT	\N	PRESENT	0
504945	501820	20086J	PARTICIPANT	\N	PRESENT	0
504946	501820	19413M	PARTICIPANT	\N	PRESENT	0
504947	501820	11097X	PARTICIPANT	\N	PRESENT	0
504952	501820	20042V	PARTICIPANT	\N	PRESENT	0
504950	501820	19725B	PARTICIPANT	\N	PRESENT	0
504951	501820	14121F	PARTICIPANT	\N	PRESENT	0
504954	501820	08047A	PARTICIPANT	\N	PRESENT	0
504960	501820	11090Q	PARTICIPANT	\N	PRESENT	0
504997	501820	17023S	PARTICIPANT	\N	PRESENT	0
504988	501820	11053K	PARTICIPANT	\N	PRESENT	0
504996	501820	14151M	PARTICIPANT	\N	PRESENT	0
504998	501820	20116W	PARTICIPANT	\N	PRESENT	0
504999	501820	08009T	PARTICIPANT	\N	PRESENT	0
505208	501821	01043Q	PARTICIPANT	\N	PRESENT	0
505210	501821	20028X	PARTICIPANT	\N	PRESENT	0
505211	501821	19333N	PARTICIPANT	\N	PRESENT	0
505212	501821	19820Y	PARTICIPANT	\N	PRESENT	0
505213	501821	19251M	PARTICIPANT	\N	PRESENT	0
505214	501821	19599P	PARTICIPANT	\N	PRESENT	0
505215	501821	19866P	PARTICIPANT	\N	PRESENT	0
505216	501821	19629C	PARTICIPANT	\N	PRESENT	0
505217	501821	11012A	PARTICIPANT	\N	PRESENT	0
505218	501821	20072C	PARTICIPANT	\N	PRESENT	0
505219	501821	19745F	PARTICIPANT	\N	PRESENT	0
505220	501821	19739H	PARTICIPANT	\N	PRESENT	0
505221	501821	14221J	PARTICIPANT	\N	PRESENT	0
505222	501821	20092G	PARTICIPANT	\N	PRESENT	0
505223	501821	20110Q	PARTICIPANT	\N	PRESENT	0
505224	501821	20098N	PARTICIPANT	\N	PRESENT	0
505225	501821	20044X	PARTICIPANT	\N	PRESENT	0
505226	501821	19782L	PARTICIPANT	\N	PRESENT	0
505235	501821	14053L	PARTICIPANT	\N	PRESENT	0
505236	501821	14259Y	PARTICIPANT	\N	PRESENT	0
505237	501821	18083K	PARTICIPANT	\N	PRESENT	0
505243	501821	19387D	PARTICIPANT	\N	PRESENT	0
505245	501821	19758L	PARTICIPANT	\N	PRESENT	0
505247	501821	20116W	PARTICIPANT	\N	PRESENT	0
505251	501821	20068G	PARTICIPANT	\N	PRESENT	0
505252	501821	20096L	PARTICIPANT	\N	PRESENT	0
505253	501821	19503N	PARTICIPANT	\N	PRESENT	0
505283	502450	14327T	PARTICIPANT	\N	PRESENT	0
505284	502450	04071H	PARTICIPANT	\N	PRESENT	0
505285	502450	19711U	PRESIDENT	1	PRESENT	0
505286	502450	08034U	PARTICIPANT	\N	PRESENT	0
505287	502450	01048V	PARTICIPANT	\N	PRESENT	0
505288	502450	01057W	PARTICIPANT	\N	PRESENT	0
505289	502450	20080C	PARTICIPANT	\N	PRESENT	0
505290	502450	11074Q	PARTICIPANT	\N	PRESENT	0
505291	502450	19667J	PARTICIPANT	\N	PRESENT	0
505292	502450	19671E	PARTICIPANT	\N	PRESENT	0
505293	502450	11070L	PARTICIPANT	\N	PRESENT	0
505294	502450	14225N	PRESIDENT	0	PRESENT	0
505295	502450	14173T	PARTICIPANT	\N	PRESENT	0
505296	502450	04086Q	PARTICIPANT	\N	PRESENT	0
505297	502450	07029T	PARTICIPANT	\N	PRESENT	0
509544	509543	14267Y	PARTICIPANT	\N	PRESENT	1
509545	509543	19565D	PARTICIPANT	\N	PRESENT	1
509869	504772	04070G	PARTICIPANT	\N	PRESENT	0
509870	504772	08017T	PARTICIPANT	\N	PRESENT	0
509871	504772	20142Y	PARTICIPANT	\N	PRESENT	0
511262	511261	11026G	PARTICIPANT	\N	PRESENT	0
511263	511261	10015M	PARTICIPANT	\N	PRESENT	0
511610	509855	11065P	PARTICIPANT	\N	PRESENT	1
511611	509965	19687N	PARTICIPANT	\N	PRESENT	0
511612	509965	19551W	PARTICIPANT	\N	PRESENT	0
511613	509965	14121F	PARTICIPANT	\N	PRESENT	0
511614	509965	20126Y	PARTICIPANT	\N	PRESENT	0
511615	509565	14231L	PARTICIPANT	\N	PRESENT	0
511616	509565	14089Y	PARTICIPANT	\N	PRESENT	0
511617	509565	14179A	PARTICIPANT	\N	PRESENT	0
511618	509965	08034U	PARTICIPANT	\N	PRESENT	0
511619	509965	19689Q	PARTICIPANT	\N	PRESENT	0
511620	509965	14225N	PRESIDENT	0	PRESENT	0
511621	509965	07029T	PARTICIPANT	\N	PRESENT	0
511622	509965	08073C	PARTICIPANT	\N	PRESENT	0
511623	509965	19647E	PARTICIPANT	\N	PRESENT	0
511625	509892	11043H	PARTICIPANT	\N	PRESENT	0
511626	509892	20084G	PARTICIPANT	\N	PRESENT	0
511627	509565	08018U	PARTICIPANT	\N	PRESENT	0
511631	509565	14021P	PARTICIPANT	\N	PRESENT	0
511635	509873	14059S	PARTICIPANT	\N	PRESENT	0
511636	509873	14133K	PARTICIPANT	\N	PRESENT	0
511637	509873	19565D	PARTICIPANT	\N	PRESENT	0
511638	509873	20072C	PARTICIPANT	\N	PRESENT	0
511639	509873	01058X	PARTICIPANT	\N	PRESENT	0
511640	509873	11027H	PARTICIPANT	\N	PRESENT	0
511641	509873	04042C	PRESIDENT	0	PRESENT	0
511642	509873	11066Q	PARTICIPANT	\N	PRESENT	0
511643	509873	12028B	PARTICIPANT	\N	PRESENT	0
511644	509873	14105F	PARTICIPANT	\N	PRESENT	0
511645	509873	20064C	PARTICIPANT	\N	PRESENT	0
511646	509873	19421M	PARTICIPANT	\N	PRESENT	0
511647	509873	14193X	PARTICIPANT	\N	PRESENT	0
511648	509873	14267Y	PARTICIPANT	\N	PRESENT	0
511649	509873	11064N	PARTICIPANT	\N	PRESENT	0
511650	509873	97011G	PARTICIPANT	\N	PRESENT	0
511651	509873	14211G	PARTICIPANT	\N	PRESENT	0
511652	509873	14249W	PARTICIPANT	\N	PRESENT	0
511653	509873	20128B	PARTICIPANT	\N	PRESENT	0
511654	509855	14221J	PARTICIPANT	\N	PRESENT	1
511655	509873	19443T	PARTICIPANT	\N	PRESENT	1
511656	509873	04034C	PARTICIPANT	\N	PRESENT	1
511657	509873	08056B	PARTICIPANT	\N	PRESENT	1
511658	509873	19721W	PARTICIPANT	\N	PRESENT	1
511659	509873	11083R	PARTICIPANT	\N	PRESENT	1
511660	509873	14255U	PARTICIPANT	\N	PRESENT	1
511661	509965	11053K	PARTICIPANT	\N	PRESENT	0
511662	509965	04086Q	PARTICIPANT	\N	PRESENT	0
511663	509873	20042V	PARTICIPANT	\N	PRESENT	0
511665	509873	16685X	PARTICIPANT	\N	PRESENT	0
511671	509892	04059M	PARTICIPANT	\N	PRESENT	0
511672	509892	19643A	PARTICIPANT	\N	PRESENT	1
511673	509873	19347U	PARTICIPANT	\N	PRESENT	0
511674	509873	01024M	PARTICIPANT	\N	PRESENT	0
511816	502345	20070A	PARTICIPANT	\N	PRESENT	0
511817	502345	19503N	PARTICIPANT	\N	PRESENT	0
511818	502345	14107H	PARTICIPANT	\N	PRESENT	0
511819	502345	20092G	PARTICIPANT	\N	PRESENT	0
511820	502345	14219Q	PARTICIPANT	\N	PRESENT	0
511821	502345	19701S	PARTICIPANT	\N	PRESENT	0
511822	502345	97011G	PARTICIPANT	\N	PRESENT	0
511823	502345	14105F	PARTICIPANT	\N	PRESENT	0
511824	502345	08010L	PARTICIPANT	\N	PRESENT	0
511825	502345	20104S	PARTICIPANT	\N	PRESENT	0
511826	502345	20042V	PARTICIPANT	\N	PRESENT	0
511827	502345	20174H	PARTICIPANT	\N	PRESENT	0
511828	502345	14259Y	PARTICIPANT	\N	PRESENT	0
511829	502345	19447X	PARTICIPANT	\N	PRESENT	0
511830	502345	11101A	PARTICIPANT	\N	PRESENT	0
511831	502345	14083S	PARTICIPANT	\N	PRESENT	0
511832	502345	11053K	PARTICIPANT	\N	PRESENT	0
511833	502345	20072C	PARTICIPANT	\N	PRESENT	0
511834	502345	19747H	PARTICIPANT	\N	PRESENT	0
511835	502345	19421M	PARTICIPANT	\N	PRESENT	0
511842	502345	20020P	PARTICIPANT	\N	PRESENT	0
511843	502345	19573D	PARTICIPANT	\N	PRESENT	0
511851	502345	20068G	PARTICIPANT	\N	PRESENT	0
511854	502345	14053L	PARTICIPANT	\N	PRESENT	0
511857	502345	19719D	PARTICIPANT	\N	PRESENT	0
511865	502345	19820Y	PARTICIPANT	\N	PRESENT	0
511872	502345	04047H	PARTICIPANT	\N	PRESENT	0
511873	502345	19565D	PARTICIPANT	\N	PRESENT	0
511874	502345	14089Y	PARTICIPANT	\N	PRESENT	0
511875	502345	20150Y	PARTICIPANT	\N	PRESENT	0
511876	502345	08073C	PARTICIPANT	\N	PRESENT	0
511877	502345	19768N	PARTICIPANT	\N	PRESENT	0
511878	502345	14257W	PARTICIPANT	\N	PRESENT	0
511880	502345	05008E	PARTICIPANT	\N	PRESENT	0
511881	502345	01024M	PARTICIPANT	\N	PRESENT	0
511882	502345	19749K	PARTICIPANT	\N	PRESENT	0
511883	502345	19647E	PARTICIPANT	\N	PRESENT	0
511884	502345	14275Y	PARTICIPANT	\N	PRESENT	0
511885	502345	19826F	PARTICIPANT	\N	PRESENT	0
511886	502345	08034U	PARTICIPANT	\N	PRESENT	0
511887	502345	20032T	PARTICIPANT	\N	PRESENT	0
511888	502345	11085T	PARTICIPANT	\N	PRESENT	0
511889	502345	19441R	PARTICIPANT	\N	PRESENT	0
511890	502345	14189C	PARTICIPANT	\N	PRESENT	0
511891	502345	19415P	PARTICIPANT	\N	PRESENT	0
511892	502345	01028R	PARTICIPANT	\N	PRESENT	0
511893	502345	19758L	PARTICIPANT	\N	PRESENT	0
511894	502345	20120S	PARTICIPANT	\N	PRESENT	0
511895	502345	14069U	PARTICIPANT	\N	PRESENT	0
511896	502345	14215L	PARTICIPANT	\N	PRESENT	0
511897	502345	19479G	PARTICIPANT	\N	PRESENT	0
511898	502345	19531S	PARTICIPANT	\N	PRESENT	0
511899	502345	04086Q	PARTICIPANT	\N	PRESENT	0
511902	502345	19413M	PARTICIPANT	\N	PRESENT	0
511903	502345	05012A	PARTICIPANT	\N	PRESENT	0
511904	502345	20036X	PARTICIPANT	\N	PRESENT	0
511905	502345	14042U	PARTICIPANT	\N	PRESENT	0
511906	502345	20136B	PARTICIPANT	\N	PRESENT	0
511907	502345	11048N	PARTICIPANT	\N	PRESENT	0
511909	502345	19585H	PARTICIPANT	\N	PRESENT	0
511910	502345	14109K	PARTICIPANT	\N	PRESENT	0
511985	502346	11070L	PARTICIPANT	\N	PRESENT	0
511987	502346	19575F	PARTICIPANT	\N	PRESENT	0
511988	502346	04086Q	PARTICIPANT	\N	PRESENT	0
511989	502346	19711U	PARTICIPANT	\N	PRESENT	0
511990	502346	20024T	PARTICIPANT	\N	PRESENT	0
511991	502346	07029T	PARTICIPANT	\N	PRESENT	0
511992	502346	20044X	PARTICIPANT	\N	PRESENT	0
511993	502346	20028X	PARTICIPANT	\N	PRESENT	0
511994	502346	14147R	PARTICIPANT	\N	PRESENT	0
511995	502346	19758L	PARTICIPANT	\N	PRESENT	0
511996	502346	14053L	PARTICIPANT	\N	PRESENT	0
511997	502346	20088L	PARTICIPANT	\N	PRESENT	0
511998	502346	14105F	PARTICIPANT	\N	PRESENT	0
511999	502346	14001X	PARTICIPANT	\N	PRESENT	0
512000	502346	08073C	PARTICIPANT	\N	PRESENT	0
512001	502346	14225N	PARTICIPANT	\N	PRESENT	0
512002	502346	20046A	PARTICIPANT	\N	PRESENT	0
512004	502346	14211G	PARTICIPANT	\N	PRESENT	0
512005	502346	20030R	PARTICIPANT	\N	PRESENT	0
512006	502346	08009T	PARTICIPANT	\N	PRESENT	0
512007	502346	14083S	PARTICIPANT	\N	PRESENT	0
512008	502346	14205J	PARTICIPANT	\N	PRESENT	0
512009	502346	19349W	PARTICIPANT	\N	PRESENT	0
512010	502346	19629C	PARTICIPANT	\N	PRESENT	0
512011	502346	14231L	PARTICIPANT	\N	PRESENT	0
512012	502346	20116W	PARTICIPANT	\N	PRESENT	0
512013	502346	14327T	PARTICIPANT	\N	PRESENT	0
512014	502346	04057K	PARTICIPANT	\N	PRESENT	0
512015	502346	20052X	PARTICIPANT	\N	PRESENT	0
512016	502346	20122U	PARTICIPANT	\N	PRESENT	0
512017	502346	20072C	PARTICIPANT	\N	PRESENT	0
512018	502346	14267Y	PARTICIPANT	\N	PRESENT	0
512019	502346	19573D	PARTICIPANT	\N	PRESENT	0
512020	502346	14042U	PARTICIPANT	\N	PRESENT	0
512021	502346	20040T	PARTICIPANT	\N	PRESENT	0
512022	502346	14219Q	PARTICIPANT	\N	PRESENT	0
512023	502346	08034U	PARTICIPANT	\N	PRESENT	0
512024	502346	20022R	PARTICIPANT	\N	PRESENT	0
512025	502346	10015M	PARTICIPANT	\N	PRESENT	0
483917	483916	19507S	PARTICIPANT	\N	PRESENT	0
483918	483916	14033T	PARTICIPANT	\N	PRESENT	0
483919	483916	14357A	PARTICIPANT	\N	PRESENT	0
483920	483916	19515S	PARTICIPANT	\N	PRESENT	0
483921	483916	01025N	PARTICIPANT	\N	PRESENT	0
483922	483916	14265W	PARTICIPANT	\N	PRESENT	0
483923	483916	19269X	PARTICIPANT	\N	PRESENT	0
486822	484691	19549D	PARTICIPANT	\N	PRESENT	0
486826	484691	19611R	PRESIDENT	0	PRESENT	0
486827	484691	14097Y	PARTICIPANT	\N	PRESENT	0
486828	484691	19591F	PARTICIPANT	\N	PRESENT	0
486829	484691	14197C	PARTICIPANT	\N	PRESENT	0
486830	484691	19629C	PARTICIPANT	\N	PRESENT	0
486831	484691	14033T	PARTICIPANT	\N	PRESENT	0
486832	484691	14093U	PARTICIPANT	\N	EXCUSE	0
486833	484691	19369B	PARTICIPANT	\N	EXCUSE	0
486906	486880	19643A	PARTICIPANT	\N	PRESENT	0
486907	486880	19545Y	PARTICIPANT	\N	EXCUSE	0
486908	486880	19663E	PARTICIPANT	\N	PRESENT	0
486909	486880	10006L	PARTICIPANT	\N	PRESENT	0
486910	486880	14041T	PARTICIPANT	\N	PRESENT	0
486911	486880	14081Q	PARTICIPANT	\N	PRESENT	0
486912	486880	19715Y	PARTICIPANT	\N	PRESENT	0
486913	486880	19683J	PARTICIPANT	\N	PRESENT	0
486914	486880	19447X	PARTICIPANT	\N	PRESENT	0
486915	486880	19697Q	PARTICIPANT	\N	PRESENT	0
486916	486880	11067R	PARTICIPANT	\N	EXCUSE	0
486917	486880	04092N	PRESIDENT	0	PRESENT	0
486918	486880	19573D	PARTICIPANT	\N	PRESENT	0
486919	486880	19503N	PARTICIPANT	\N	PRESENT	0
486920	486880	19766L	PARTICIPANT	\N	PRESENT	0
486921	486880	01034P	PARTICIPANT	\N	EXCUSE	0
486924	486880	11097X	PARTICIPANT	\N	PRESENT	0
486925	486880	19479G	PARTICIPANT	\N	EXCUSE	0
486927	486880	14331P	PARTICIPANT	\N	EXCUSE	0
486928	486880	11012A	PARTICIPANT	\N	EXCUSE	0
486937	486880	19703U	PARTICIPANT	\N	PRESENT	0
488387	487910	11048N	PARTICIPANT	\N	PRESENT	0
491599	491412	14026U	PARTICIPANT	\N	PRESENT	0
491607	491471	11074Q	PARTICIPANT	\N	EXCUSE	0
491601	491412	14267Y	PARTICIPANT	\N	PRESENT	0
491602	491412	98022P	PARTICIPANT	\N	PRESENT	0
491609	491412	10006L	PARTICIPANT	\N	PRESENT	0
491610	491412	17737W	PARTICIPANT	\N	PRESENT	0
491611	491412	20026V	PARTICIPANT	\N	PRESENT	0
491612	491412	19679N	PARTICIPANT	\N	PRESENT	0
491613	491412	19467C	PARTICIPANT	\N	PRESENT	0
491614	491412	19599P	PARTICIPANT	\N	PRESENT	0
491615	491412	19758L	PARTICIPANT	\N	PRESENT	0
491616	491412	19565D	PARTICIPANT	\N	PRESENT	0
491617	491412	20056C	PARTICIPANT	\N	PRESENT	0
491618	491412	11067R	PARTICIPANT	\N	PRESENT	0
491619	491412	19683J	PARTICIPANT	\N	PRESENT	0
491620	491412	19573D	PARTICIPANT	\N	PRESENT	0
491621	491412	14229S	PARTICIPANT	\N	PRESENT	0
491622	491412	17779H	PARTICIPANT	\N	PRESENT	0
491623	491412	19673G	PARTICIPANT	\N	PRESENT	0
491624	491412	14281W	PARTICIPANT	\N	PRESENT	0
491625	491412	11080N	PARTICIPANT	\N	PRESENT	0
491626	491412	20142Y	PARTICIPANT	\N	PRESENT	0
491627	491412	20130U	PARTICIPANT	\N	PRESENT	0
491628	491412	20134Y	PARTICIPANT	\N	PRESENT	0
491629	491412	11065P	PARTICIPANT	\N	PRESENT	0
491630	491412	17965H	PARTICIPANT	\N	PRESENT	0
491631	491412	20078J	PARTICIPANT	\N	PRESENT	0
491632	491412	19637C	PARTICIPANT	\N	PRESENT	0
491633	491412	17367Q	PARTICIPANT	\N	PRESENT	0
491634	491412	19563B	PARTICIPANT	\N	PRESENT	0
491635	491412	19721W	PARTICIPANT	\N	PRESENT	0
491636	491412	19479G	PARTICIPANT	\N	PRESENT	0
491637	491412	18083K	PARTICIPANT	\N	PRESENT	0
491638	491412	20066E	PARTICIPANT	\N	PRESENT	0
491639	491412	14223L	PARTICIPANT	\N	PRESENT	0
491640	491412	20132W	PARTICIPANT	\N	PRESENT	0
491641	491412	20072C	PARTICIPANT	\N	PRESENT	0
491642	491412	19591F	PARTICIPANT	\N	PRESENT	0
491643	491412	19723Y	PARTICIPANT	\N	PRESENT	0
491644	491412	11012A	PARTICIPANT	\N	PRESENT	0
491645	491412	14097Y	PARTICIPANT	\N	PRESENT	0
491646	491412	20068G	PARTICIPANT	\N	PRESENT	0
491647	491412	18193Q	PARTICIPANT	\N	PRESENT	0
491648	491412	20148F	PARTICIPANT	\N	PRESENT	0
491649	491412	19367Y	PARTICIPANT	\N	PRESENT	0
491650	491412	19507S	PARTICIPANT	\N	PRESENT	0
491651	491412	20040T	PARTICIPANT	\N	PRESENT	0
491866	491412	19954N	PARTICIPANT	\N	PRESENT	0
491653	491412	19415P	PARTICIPANT	\N	PRESENT	0
491654	491412	01025N	PARTICIPANT	\N	PRESENT	0
491655	491412	08010L	PARTICIPANT	\N	PRESENT	0
491656	491412	08028W	PARTICIPANT	\N	PRESENT	0
491657	491412	20152B	PARTICIPANT	\N	PRESENT	0
491867	491412	20116W	PARTICIPANT	\N	PRESENT	0
491659	491412	20032T	PARTICIPANT	\N	PRESENT	0
491660	491412	08015R	PARTICIPANT	\N	PRESENT	0
491661	491412	20024T	PARTICIPANT	\N	PRESENT	0
491663	491412	14031R	PARTICIPANT	\N	PRESENT	0
491664	491412	20090E	PARTICIPANT	\N	PRESENT	0
491665	491412	97011G	PARTICIPANT	\N	PRESENT	0
491666	491412	14105F	PARTICIPANT	\N	PRESENT	0
491667	491412	14187A	PARTICIPANT	\N	PRESENT	0
491668	491412	05012A	PARTICIPANT	\N	PRESENT	0
491669	491412	12028B	PARTICIPANT	\N	PRESENT	0
491670	491412	11031D	PARTICIPANT	\N	PRESENT	0
491671	491412	14089Y	PARTICIPANT	\N	PRESENT	0
491672	491412	19515S	PARTICIPANT	\N	PRESENT	0
491673	491412	14042U	PARTICIPANT	\N	PRESENT	0
491674	491412	19657G	PARTICIPANT	\N	PRESENT	0
491675	491412	14033T	PARTICIPANT	\N	PRESENT	0
491676	491412	20102Q	PARTICIPANT	\N	PRESENT	0
491677	491412	20046A	PARTICIPANT	\N	PRESENT	0
491678	491412	04057K	PARTICIPANT	\N	PRESENT	0
491679	491412	20076G	PARTICIPANT	\N	PRESENT	0
491680	491412	20038A	PARTICIPANT	\N	PRESENT	0
491681	491412	19503N	PARTICIPANT	\N	PRESENT	0
491865	491412	19447X	PARTICIPANT	\N	PRESENT	0
491868	491412	20136B	PARTICIPANT	\N	PRESENT	0
491883	491881	11067R	PARTICIPANT	\N	PRESENT	0
491884	491881	14071N	PARTICIPANT	\N	PRESENT	0
491885	491881	19798U	PARTICIPANT	\N	PRESENT	0
491886	491881	01034P	PARTICIPANT	\N	PRESENT	0
491895	491487	19954N	PARTICIPANT	\N	PRESENT	0
491896	491487	20074E	PARTICIPANT	\N	PRESENT	0
491897	491487	14041T	PARTICIPANT	\N	PRESENT	0
491898	491487	14147R	PARTICIPANT	\N	PRESENT	0
491899	491487	14215L	PARTICIPANT	\N	PRESENT	0
491900	491487	04047H	PARTICIPANT	\N	PRESENT	0
491901	491412	14215L	PARTICIPANT	\N	PRESENT	0
491902	491412	20100N	PARTICIPANT	\N	PRESENT	0
491903	491412	19695N	PARTICIPANT	\N	PRESENT	0
491904	491412	19575F	PARTICIPANT	\N	PRESENT	0
491906	491905	08018U	PARTICIPANT	\N	PRESENT	0
491907	491905	20108W	PARTICIPANT	\N	PRESENT	0
491909	491908	08018U	PARTICIPANT	\N	PRESENT	0
491910	491908	20108W	PARTICIPANT	\N	PRESENT	0
492009	491414	11045K	PARTICIPANT	\N	PRESENT	0
492010	491414	05008E	PARTICIPANT	\N	PRESENT	0
492011	491414	11033F	PARTICIPANT	\N	PRESENT	0
492012	491414	19629C	PARTICIPANT	\N	PRESENT	0
492013	491414	20100N	PARTICIPANT	\N	PRESENT	0
492014	491414	14151M	PARTICIPANT	\N	PRESENT	0
492015	491414	04085P	PARTICIPANT	\N	PRESENT	0
492016	491414	19565D	PARTICIPANT	\N	PRESENT	0
492017	491414	19695N	PARTICIPANT	\N	PRESENT	0
492018	491414	20030R	PARTICIPANT	\N	PRESENT	0
492019	491414	20114U	PARTICIPANT	\N	PRESENT	0
492020	491414	20070A	PARTICIPANT	\N	PRESENT	0
492021	491414	19649G	PARTICIPANT	\N	PRESENT	0
492022	491414	11067R	PARTICIPANT	\N	PRESENT	0
492023	491414	19503N	PARTICIPANT	\N	PRESENT	0
492024	491414	20018V	PARTICIPANT	\N	PRESENT	0
492025	491414	14021P	PARTICIPANT	\N	PRESENT	0
492026	491414	04047H	PARTICIPANT	\N	PRESENT	0
492027	491414	11072N	PARTICIPANT	\N	PRESENT	0
492028	491414	19545Y	PARTICIPANT	\N	PRESENT	0
492029	491414	19749K	PARTICIPANT	\N	PRESENT	0
492030	491414	14089Y	PARTICIPANT	\N	PRESENT	0
492031	491414	14055N	PARTICIPANT	\N	PRESENT	0
492032	491414	19599P	PARTICIPANT	\N	PRESENT	0
492033	491414	19725B	PARTICIPANT	\N	PRESENT	0
492034	491414	19413M	PARTICIPANT	\N	PRESENT	0
492035	491414	01028R	PARTICIPANT	\N	PRESENT	0
492036	491414	14053L	PARTICIPANT	\N	PRESENT	0
492037	491414	14069U	PARTICIPANT	\N	PRESENT	0
492038	491414	14217N	PARTICIPANT	\N	PRESENT	0
492039	491414	14357A	PARTICIPANT	\N	PRESENT	0
492040	491414	20074E	PARTICIPANT	\N	PRESENT	0
506517	501830	07033P	PARTICIPANT	\N	PRESENT	0
506518	501830	19631V	PARTICIPANT	\N	PRESENT	0
506519	501830	19551W	PARTICIPANT	\N	PRESENT	0
506515	501830	19705W	PARTICIPANT	\N	PRESENT	0
506516	501830	14041T	PARTICIPANT	\N	PRESENT	0
506520	501830	19695N	PARTICIPANT	\N	PRESENT	0
506521	501830	14026U	PARTICIPANT	\N	PRESENT	0
506569	501831	19687N	PARTICIPANT	\N	PRESENT	0
506570	501831	20080C	PARTICIPANT	\N	PRESENT	0
506571	501831	19689Q	PARTICIPANT	\N	PRESENT	0
506572	501831	20100N	PARTICIPANT	\N	PRESENT	0
506573	501831	12016W	PARTICIPANT	\N	PRESENT	0
506574	501831	11012A	PARTICIPANT	\N	PRESENT	0
506575	501831	19717B	PARTICIPANT	\N	PRESENT	0
506576	501831	19651A	PARTICIPANT	\N	PRESENT	0
506577	501831	07004J	PARTICIPANT	\N	PRESENT	0
506578	501831	14357A	PARTICIPANT	\N	PRESENT	0
506579	501831	19711U	PARTICIPANT	\N	PRESENT	0
506580	501831	04086Q	PARTICIPANT	\N	PRESENT	0
506581	501831	19701S	PARTICIPANT	\N	PRESENT	0
506582	501831	20120S	PARTICIPANT	\N	PRESENT	0
506583	501831	19762G	PARTICIPANT	\N	PRESENT	0
506584	501831	20022R	PARTICIPANT	\N	PRESENT	0
506585	501831	20044X	PARTICIPANT	\N	PRESENT	0
506586	501831	19399H	PARTICIPANT	\N	PRESENT	0
506587	501831	07029T	PARTICIPANT	\N	PRESENT	0
506588	501831	19741B	PARTICIPANT	\N	PRESENT	0
506589	501831	20038A	PARTICIPANT	\N	PRESENT	0
506590	501831	19693L	PARTICIPANT	\N	PRESENT	0
506591	501831	11053K	PARTICIPANT	\N	PRESENT	0
506592	501831	11048N	PARTICIPANT	\N	PRESENT	0
506593	501831	14225N	PARTICIPANT	\N	PRESENT	0
506594	501831	19545Y	PARTICIPANT	\N	PRESENT	0
506595	501831	19671E	PARTICIPANT	\N	PRESENT	0
506596	501831	19695N	PARTICIPANT	\N	PRESENT	0
506597	501831	19593H	PARTICIPANT	\N	PRESENT	0
506598	501831	20034V	PARTICIPANT	\N	PRESENT	0
506599	501831	19551W	PARTICIPANT	\N	PRESENT	0
506600	501831	19631V	PARTICIPANT	\N	PRESENT	0
506601	501831	19647E	PARTICIPANT	\N	PRESENT	0
506602	501831	20070A	PARTICIPANT	\N	PRESENT	0
506603	501831	19531S	PARTICIPANT	\N	PRESENT	0
506604	501831	19335Q	PARTICIPANT	\N	PRESENT	0
506605	501831	04033B	PARTICIPANT	\N	PRESENT	0
506606	501831	19349W	PARTICIPANT	\N	PRESENT	0
506607	501831	14205J	PARTICIPANT	\N	PRESENT	0
506608	501831	19347U	PARTICIPANT	\N	PRESENT	0
506609	501831	04071H	PARTICIPANT	\N	PRESENT	0
506610	501831	08011M	PARTICIPANT	\N	PRESENT	0
506614	501831	19479G	PARTICIPANT	\N	PRESENT	0
506612	501831	95063L	PARTICIPANT	\N	PRESENT	0
506613	501831	08010L	PARTICIPANT	\N	PRESENT	0
506567	501831	14026U	PARTICIPANT	\N	PRESENT	0
506568	501831	11074Q	PARTICIPANT	\N	PRESENT	0
507023	507022	19709B	PARTICIPANT	\N	PRESENT	0
507024	507022	11041F	PARTICIPANT	\N	PRESENT	0
508798	508794	14231L	PRESIDENT	0	PRESENT	0
509088	496311	20042V	PARTICIPANT	\N	PRESENT	0
509089	496311	11056N	PARTICIPANT	\N	PRESENT	0
509090	496311	20132W	PARTICIPANT	\N	PRESENT	0
509091	496311	99004R	PARTICIPANT	\N	PRESENT	0
509092	496311	95063L	PARTICIPANT	\N	PRESENT	0
509172	506213	19551W	PARTICIPANT	\N	PRESENT	0
509178	505805	14073Q	PARTICIPANT	\N	PRESENT	0
509252	506628	11110B	PARTICIPANT	\N	PRESENT	1
509253	506628	14121F	PARTICIPANT	\N	PRESENT	1
509254	506628	19479G	PARTICIPANT	\N	PRESENT	1
509269	506628	08010L	PARTICIPANT	\N	PRESENT	0
509279	501273	14030Q	PRESIDENT	0	PRESENT	0
509280	501273	20138D	PARTICIPANT	\N	PRESENT	0
509281	501273	19621T	PARTICIPANT	\N	PRESENT	0
509282	501273	11031D	PARTICIPANT	\N	PRESENT	0
509283	501273	19681G	PARTICIPANT	\N	EXCUSE	0
509284	501273	19693L	PARTICIPANT	\N	PRESENT	0
509285	501273	19599P	PARTICIPANT	\N	PRESENT	0
509286	501273	20106U	PARTICIPANT	\N	PRESENT	0
509287	501273	14179A	PARTICIPANT	\N	PRESENT	0
509288	501273	20066E	PARTICIPANT	\N	PRESENT	0
509289	501273	19715Y	PARTICIPANT	\N	PRESENT	0
509290	501273	20056C	PARTICIPANT	\N	PRESENT	0
509291	501273	07029T	PARTICIPANT	\N	EXCUSE	0
509292	501273	19657G	PARTICIPANT	\N	PRESENT	0
509293	501273	14221J	PARTICIPANT	\N	PRESENT	0
509294	501273	14109K	PARTICIPANT	\N	PRESENT	0
509295	501273	19768N	PARTICIPANT	\N	EXCUSE	0
509296	501273	20130U	PARTICIPANT	\N	PRESENT	0
509297	501273	19798U	PARTICIPANT	\N	PRESENT	0
509298	501273	11045K	PARTICIPANT	\N	PRESENT	0
509299	501273	20098N	PARTICIPANT	\N	PRESENT	0
509300	501273	14275Y	PARTICIPANT	\N	PRESENT	0
509301	501273	19527W	PARTICIPANT	\N	PRESENT	0
509302	501273	20046A	PARTICIPANT	\N	PRESENT	0
509303	501273	19749K	PARTICIPANT	\N	PRESENT	0
509400	505869	20022R	PARTICIPANT	\N	PRESENT	0
509401	505869	19758L	PARTICIPANT	\N	PRESENT	0
509402	505869	20090E	PARTICIPANT	\N	PRESENT	0
509403	505869	04086Q	PARTICIPANT	\N	PRESENT	0
509404	505869	14215L	PARTICIPANT	\N	PRESENT	0
509405	505869	14151M	PARTICIPANT	\N	PRESENT	0
509411	505869	14187A	PARTICIPANT	\N	PRESENT	0
509412	505869	14281W	PARTICIPANT	\N	PRESENT	0
509413	505869	20120S	PARTICIPANT	\N	PRESENT	0
509414	505869	19565D	PARTICIPANT	\N	PRESENT	0
509415	505869	19333N	PARTICIPANT	\N	PRESENT	0
509418	505869	19489J	PARTICIPANT	\N	PRESENT	0
509425	505869	08010L	PARTICIPANT	\N	PRESENT	0
509426	505869	14071N	PARTICIPANT	\N	PRESENT	0
509427	505869	05012A	PARTICIPANT	\N	PRESENT	0
509429	509428	11027H	PARTICIPANT	\N	PRESENT	0
509430	509428	14193X	PARTICIPANT	\N	PRESENT	0
509433	509432	11027H	PARTICIPANT	\N	PRESENT	0
509434	509432	14193X	PARTICIPANT	\N	PRESENT	0
509436	505869	17637T	PARTICIPANT	\N	PRESENT	0
509437	505869	14229S	PARTICIPANT	\N	PRESENT	0
509438	505869	04045F	PARTICIPANT	\N	PRESENT	0
509439	505869	20084G	PARTICIPANT	\N	PRESENT	0
509440	505869	20058E	PARTICIPANT	\N	PRESENT	0
509441	505869	20122U	PARTICIPANT	\N	PRESENT	0
509769	509768	14133K	PARTICIPANT	\N	PRESENT	0
509770	509768	11066Q	PARTICIPANT	\N	PRESENT	0
509772	509771	14133K	PARTICIPANT	\N	PRESENT	0
509773	509771	11066Q	PARTICIPANT	\N	PRESENT	0
509775	509774	14133K	PARTICIPANT	\N	PRESENT	0
509776	509774	11066Q	PARTICIPANT	\N	PRESENT	0
509816	502327	20038A	PARTICIPANT	\N	PRESENT	0
509817	502327	19826F	PARTICIPANT	\N	PRESENT	0
509819	502327	14073Q	PARTICIPANT	\N	PRESENT	0
509820	502327	20092G	PARTICIPANT	\N	PRESENT	0
509821	502327	20034V	PARTICIPANT	\N	PRESENT	0
509822	502327	20100N	PARTICIPANT	\N	PRESENT	0
509824	502327	20124W	PARTICIPANT	\N	PRESENT	0
509825	502327	14031R	PARTICIPANT	\N	PRESENT	0
509827	502327	14033T	PARTICIPANT	\N	PRESENT	0
509829	502327	11090Q	PARTICIPANT	\N	PRESENT	0
509830	502327	11065P	PARTICIPANT	\N	PRESENT	0
509831	502327	19549D	PARTICIPANT	\N	PRESENT	0
509832	502327	19820Y	PARTICIPANT	\N	PRESENT	0
509833	502327	19531S	PARTICIPANT	\N	PRESENT	0
509835	502327	19599P	PARTICIPANT	\N	PRESENT	0
509836	502327	19711U	PARTICIPANT	\N	PRESENT	0
509837	502327	19387D	PARTICIPANT	\N	PRESENT	0
509839	502327	19335Q	PARTICIPANT	\N	PRESENT	0
509841	502327	08034U	PARTICIPANT	\N	PRESENT	0
509843	502327	20136B	PARTICIPANT	\N	PRESENT	0
509846	502327	19565D	PARTICIPANT	\N	PRESENT	0
509849	502327	19619A	PARTICIPANT	\N	PRESENT	0
509850	502327	19347U	PARTICIPANT	\N	PRESENT	0
509851	506631	20036X	PARTICIPANT	\N	PRESENT	0
509852	506631	08034U	PARTICIPANT	\N	PRESENT	0
509853	502327	14215L	PARTICIPANT	\N	PRESENT	0
485827	484556	04086Q	PARTICIPANT	\N	PRESENT	0
485828	484556	11040E	PARTICIPANT	\N	PRESENT	0
485829	484556	19711U	PARTICIPANT	\N	PRESENT	0
485830	484556	07004J	PARTICIPANT	\N	PRESENT	0
485831	484556	01057W	PARTICIPANT	\N	PRESENT	0
485832	484556	19741B	PARTICIPANT	\N	PRESENT	0
485833	484556	99004R	PARTICIPANT	\N	PRESENT	0
485834	484556	88008L	PARTICIPANT	\N	PRESENT	0
488246	486038	10006L	PARTICIPANT	\N	PRESENT	0
488247	486038	11067R	PARTICIPANT	\N	PRESENT	0
488248	486038	11097X	PARTICIPANT	\N	PRESENT	0
490067	489987	01057W	PARTICIPANT	\N	PRESENT	0
492904	491476	19667J	PARTICIPANT	\N	PRESENT	0
492905	491476	19766L	PARTICIPANT	\N	PRESENT	0
492906	491476	19703U	PARTICIPANT	\N	PRESENT	0
492907	491476	11097X	PARTICIPANT	\N	PRESENT	0
492908	491476	11031D	PARTICIPANT	\N	PRESENT	0
492909	491476	19503N	PARTICIPANT	\N	PRESENT	0
492910	491476	19715Y	PARTICIPANT	\N	PRESENT	0
492911	491476	11067R	PARTICIPANT	\N	PRESENT	0
492912	491476	20130U	PARTICIPANT	\N	PRESENT	0
492913	491476	19683J	PARTICIPANT	\N	PRESENT	0
492914	491476	10006L	PARTICIPANT	\N	PRESENT	0
492915	491476	19479G	PARTICIPANT	\N	PRESENT	0
492916	491476	19713W	PARTICIPANT	\N	PRESENT	0
492917	491476	19691J	PARTICIPANT	\N	PRESENT	0
492918	491476	19545Y	PARTICIPANT	\N	PRESENT	0
492919	491476	19643A	PARTICIPANT	\N	PRESENT	0
492927	491476	19663E	PARTICIPANT	\N	PRESENT	0
492996	491476	11048N	PARTICIPANT	\N	PRESENT	0
494051	493949	04045F	PARTICIPANT	\N	EXCUSE	0
494052	493949	20090E	PARTICIPANT	\N	EXCUSE	0
494053	493949	20084G	PARTICIPANT	\N	EXCUSE	0
494089	493949	14229S	PARTICIPANT	\N	EXCUSE	0
494101	493949	14107H	PARTICIPANT	\N	EXCUSE	0
494510	493949	08009T	PARTICIPANT	\N	EXCUSE	0
494511	493949	14187A	PARTICIPANT	\N	EXCUSE	0
494512	493949	20120S	PARTICIPANT	\N	EXCUSE	0
494513	493949	14173T	PARTICIPANT	\N	EXCUSE	0
494593	493949	14151M	PARTICIPANT	\N	EXCUSE	0
494595	493949	19489J	PARTICIPANT	\N	EXCUSE	0
494906	493949	19349W	PARTICIPANT	\N	EXCUSE	0
495388	495387	11077T	PARTICIPANT	\N	PRESENT	0
495389	495387	19631V	PARTICIPANT	\N	PRESENT	0
495391	495390	11077T	PARTICIPANT	\N	PRESENT	0
495392	495390	19631V	PARTICIPANT	\N	PRESENT	0
495394	495393	19631V	PARTICIPANT	\N	PRESENT	0
495395	495393	11077T	PARTICIPANT	\N	PRESENT	0
495439	495118	86034E	PARTICIPANT	\N	PRESENT	0
495440	495118	19798U	PARTICIPANT	\N	PRESENT	0
495441	495118	20052X	PARTICIPANT	\N	PRESENT	0
495442	495118	14041T	PARTICIPANT	\N	PRESENT	0
495443	495118	14105F	PARTICIPANT	\N	PRESENT	0
495444	494943	20030R	PARTICIPANT	\N	PRESENT	0
495445	494943	14038Y	PARTICIPANT	\N	PRESENT	0
495446	494943	19467C	PARTICIPANT	\N	PRESENT	0
495447	494943	19768N	PARTICIPANT	\N	PRESENT	0
495448	494943	19782L	PARTICIPANT	\N	PRESENT	0
495449	494943	14187A	PARTICIPANT	\N	PRESENT	0
495450	494943	14357A	PARTICIPANT	\N	PRESENT	0
495451	494943	19441R	PARTICIPANT	\N	PRESENT	0
495452	494943	19695N	PARTICIPANT	\N	PRESENT	0
495453	494943	20082E	PARTICIPANT	\N	PRESENT	0
495454	494943	11090Q	PRESIDENT	0	PRESENT	0
495455	494943	01025N	PARTICIPANT	\N	PRESENT	0
495456	494943	20094J	PARTICIPANT	\N	PRESENT	0
495457	494943	04045F	PARTICIPANT	\N	PRESENT	0
495458	494943	20054A	PARTICIPANT	\N	PRESENT	0
495459	494943	19631V	PARTICIPANT	\N	PRESENT	0
495460	494943	14205J	PARTICIPANT	\N	PRESENT	0
495461	494943	20062A	PARTICIPANT	\N	PRESENT	0
495462	494943	19705W	PARTICIPANT	\N	PRESENT	0
495463	494943	08015R	PARTICIPANT	\N	PRESENT	0
495464	494943	20018V	PARTICIPANT	\N	PRESENT	0
495465	494943	19511N	PARTICIPANT	\N	PRESENT	0
495466	494943	14257W	PARTICIPANT	\N	PRESENT	0
495467	494943	14329V	PARTICIPANT	\N	PRESENT	0
495468	494943	08028W	PARTICIPANT	\N	EXCUSE	0
495469	495118	20136B	PARTICIPANT	\N	PRESENT	0
495470	495118	20072C	PARTICIPANT	\N	PRESENT	0
495471	495118	14207L	PARTICIPANT	\N	PRESENT	0
495472	494943	20060X	PARTICIPANT	\N	PRESENT	0
495474	495118	14026U	PARTICIPANT	\N	PRESENT	0
495475	495118	01028R	PARTICIPANT	\N	PRESENT	0
495476	495118	20100N	PARTICIPANT	\N	PRESENT	0
495477	495118	19782L	PARTICIPANT	\N	PRESENT	0
495478	495118	19387D	PARTICIPANT	\N	PRESENT	0
495479	495118	19866P	PARTICIPANT	\N	PRESENT	0
495480	495118	19629C	PARTICIPANT	\N	PRESENT	0
495481	495118	11056N	PARTICIPANT	\N	PRESENT	0
495482	495118	04085P	PARTICIPANT	\N	PRESENT	0
495483	495118	19745F	PARTICIPANT	\N	PRESENT	0
495484	495118	19333N	PARTICIPANT	\N	PRESENT	0
495485	495118	19503N	PARTICIPANT	\N	PRESENT	0
495486	495118	19683J	PARTICIPANT	\N	PRESENT	0
495487	495118	14097Y	PARTICIPANT	\N	PRESENT	0
495488	495118	20066E	PARTICIPANT	\N	PRESENT	0
495489	495118	14030Q	PARTICIPANT	\N	PRESENT	0
495490	495118	20124W	PARTICIPANT	\N	PRESENT	0
495491	495118	20118Y	PARTICIPANT	\N	PRESENT	0
495492	495118	20062A	PARTICIPANT	\N	PRESENT	0
495493	495118	11103C	PARTICIPANT	\N	PRESENT	0
495494	495118	20078J	PARTICIPANT	\N	PRESENT	0
495495	495118	20076G	PARTICIPANT	\N	PRESENT	0
495496	495118	14038Y	PARTICIPANT	\N	PRESENT	0
495497	495118	19467C	PARTICIPANT	\N	PRESENT	0
495498	495118	14033T	PARTICIPANT	\N	PRESENT	0
495499	495118	20110Q	PARTICIPANT	\N	PRESENT	0
495500	495118	19575F	PARTICIPANT	\N	PRESENT	0
495546	495035	19647E	PARTICIPANT	\N	PRESENT	0
495548	495035	19689Q	PARTICIPANT	\N	PRESENT	0
495549	495035	19671E	PARTICIPANT	\N	PRESENT	0
495551	495035	14083S	PARTICIPANT	\N	PRESENT	0
495588	495118	19565D	PARTICIPANT	\N	PRESENT	0
495589	495118	19569H	PARTICIPANT	\N	PRESENT	0
495590	495118	01024M	PARTICIPANT	\N	PRESENT	0
495591	495118	19563B	PARTICIPANT	\N	PRESENT	0
495592	495118	14357A	PARTICIPANT	\N	PRESENT	0
495593	495118	20096L	PARTICIPANT	\N	PRESENT	0
495594	495118	20042V	PARTICIPANT	\N	PRESENT	0
495599	495118	08015R	PARTICIPANT	\N	PRESENT	0
495604	495118	19599P	PARTICIPANT	\N	PRESENT	0
495605	495118	19695N	PARTICIPANT	\N	PRESENT	0
495606	495118	08061X	PARTICIPANT	\N	PRESENT	0
495607	495118	20090E	PARTICIPANT	\N	PRESENT	0
495608	495118	19715Y	PARTICIPANT	\N	PRESENT	0
495609	495118	14237S	PARTICIPANT	\N	PRESENT	0
495610	495118	19703U	PARTICIPANT	\N	PRESENT	0
495611	495118	20030R	PARTICIPANT	\N	PRESENT	0
495612	495118	19251M	PARTICIPANT	\N	PRESENT	0
495613	495118	14069U	PARTICIPANT	\N	PRESENT	0
495684	495035	19667J	PARTICIPANT	\N	PRESENT	0
495685	495678	14026U	PARTICIPANT	\N	PRESENT	0
495686	495678	19565D	PARTICIPANT	\N	PRESENT	0
495687	495678	19503N	PARTICIPANT	\N	PRESENT	0
495688	495678	19413M	PARTICIPANT	\N	PRESENT	0
495689	495678	14097Y	PARTICIPANT	\N	PRESENT	0
495690	495678	20030R	PARTICIPANT	\N	PRESENT	0
495691	495678	01028R	PARTICIPANT	\N	PRESENT	0
495692	495678	11045K	PARTICIPANT	\N	PRESENT	0
495693	495678	19333N	PARTICIPANT	\N	PRESENT	0
495694	495678	19599P	PARTICIPANT	\N	PRESENT	0
495695	495678	20018V	PARTICIPANT	\N	PRESENT	0
495696	495678	11056N	PARTICIPANT	\N	PRESENT	0
495697	495678	20100N	PARTICIPANT	\N	PRESENT	0
495698	495678	20110Q	PARTICIPANT	\N	PRESENT	0
495699	495678	19349W	PARTICIPANT	\N	PRESENT	0
495700	495678	14107H	PARTICIPANT	\N	PRESENT	0
495701	495678	19387D	PARTICIPANT	\N	PRESENT	0
495702	495678	14207L	PARTICIPANT	\N	PRESENT	0
495703	495678	19866P	PARTICIPANT	\N	PRESENT	0
495704	495678	20106U	PARTICIPANT	\N	PRESENT	0
495705	495678	19637C	PARTICIPANT	\N	PRESENT	0
495706	495678	19629C	PARTICIPANT	\N	PRESENT	0
495707	495678	08061X	PARTICIPANT	\N	PRESENT	0
495708	495678	20024T	PARTICIPANT	\N	PRESENT	0
495709	495678	11090Q	PARTICIPANT	\N	PRESENT	0
495710	495678	20042V	PARTICIPANT	\N	PRESENT	0
495711	495678	19441R	PARTICIPANT	\N	PRESENT	0
495712	495678	19563B	PARTICIPANT	\N	PRESENT	0
495713	495678	14219Q	PARTICIPANT	\N	PRESENT	0
495714	495678	19745F	PARTICIPANT	\N	PRESENT	0
495715	495678	01024M	PARTICIPANT	\N	PRESENT	0
509555	505805	19701S	PARTICIPANT	\N	PRESENT	1
509556	505805	14205J	PARTICIPANT	\N	PRESENT	1
509557	505805	04070G	PARTICIPANT	\N	PRESENT	1
509558	505805	20174H	PARTICIPANT	\N	PRESENT	1
509559	505805	19768N	PARTICIPANT	\N	PRESENT	1
509560	505805	19575F	PARTICIPANT	\N	PRESENT	1
509567	505805	20054A	PARTICIPANT	\N	PRESENT	1
509568	505805	08015R	PARTICIPANT	\N	PRESENT	1
509569	505805	14133K	PARTICIPANT	\N	PRESENT	1
509570	505805	19725B	PARTICIPANT	\N	PRESENT	1
509571	505805	04057K	PARTICIPANT	\N	PRESENT	1
512468	502348	11070L	PARTICIPANT	\N	PRESENT	0
512547	502348	20150Y	PARTICIPANT	\N	PRESENT	0
512549	502348	01028R	PARTICIPANT	\N	PRESENT	0
512551	502348	14021P	PARTICIPANT	\N	PRESENT	0
512554	502348	08061X	PARTICIPANT	\N	PRESENT	0
512558	502348	11072N	PARTICIPANT	\N	PRESENT	0
512559	502348	95063L	PARTICIPANT	\N	PRESENT	0
512560	502348	12016W	PARTICIPANT	\N	PRESENT	0
512561	502348	19347U	PARTICIPANT	\N	PRESENT	0
512562	502348	19715Y	PARTICIPANT	\N	PRESENT	0
512563	502348	11067R	PARTICIPANT	\N	PRESENT	0
512564	502348	14097Y	PARTICIPANT	\N	PRESENT	0
512565	502348	20080C	PARTICIPANT	\N	PRESENT	0
512566	502348	20070A	PARTICIPANT	\N	PRESENT	0
512567	502348	19295A	PARTICIPANT	\N	PRESENT	0
512568	502348	11109J	PARTICIPANT	\N	PRESENT	0
512569	502348	11099A	PARTICIPANT	\N	PRESENT	0
512570	502348	20092G	PARTICIPANT	\N	PRESENT	0
512571	502348	19583F	PARTICIPANT	\N	PRESENT	0
512572	502348	19717B	PARTICIPANT	\N	PRESENT	0
512573	502348	20146D	PARTICIPANT	\N	PRESENT	0
512574	502348	04085P	PARTICIPANT	\N	PRESENT	0
512575	502348	19301E	PARTICIPANT	\N	PRESENT	0
512576	502348	14249W	PARTICIPANT	\N	PRESENT	0
512577	502348	11056N	PARTICIPANT	\N	PRESENT	0
512578	502348	19565D	PARTICIPANT	\N	PRESENT	0
512579	502348	20042V	PARTICIPANT	\N	PRESENT	0
512580	502348	19479G	PARTICIPANT	\N	PRESENT	0
512581	502348	14275Y	PARTICIPANT	\N	PRESENT	0
512582	502348	14267Y	PARTICIPANT	\N	PRESENT	0
512583	502348	14083S	PARTICIPANT	\N	PRESENT	0
512584	502348	14189C	PARTICIPANT	\N	PRESENT	0
512585	502348	19866P	PARTICIPANT	\N	PRESENT	0
512586	502348	98022P	PARTICIPANT	\N	PRESENT	0
512587	502348	20072C	PARTICIPANT	\N	PRESENT	0
512588	502348	20044X	PARTICIPANT	\N	PRESENT	0
512589	502348	01043Q	PARTICIPANT	\N	PRESENT	0
512590	502348	01024M	PARTICIPANT	\N	PRESENT	0
512591	502348	19691J	PARTICIPANT	\N	PRESENT	0
512592	502348	19671E	PARTICIPANT	\N	PRESENT	0
512593	502348	19577H	PARTICIPANT	\N	PRESENT	0
512594	502348	20086J	PARTICIPANT	\N	PRESENT	0
512595	502348	20148F	PARTICIPANT	\N	PRESENT	0
512596	502348	08034U	PARTICIPANT	\N	PRESENT	0
512597	502348	07029T	PARTICIPANT	\N	PRESENT	0
512598	502348	14059S	PARTICIPANT	\N	PRESENT	0
512599	502348	20054A	PARTICIPANT	\N	PRESENT	0
512600	502348	19729F	PARTICIPANT	\N	PRESENT	0
512601	502348	19657G	PARTICIPANT	\N	PRESENT	0
512602	502348	19711U	PARTICIPANT	\N	PRESENT	0
512603	502348	10006L	PARTICIPANT	\N	PRESENT	0
512604	502348	20136B	PARTICIPANT	\N	PRESENT	0
512605	502348	19693L	PARTICIPANT	\N	PRESENT	0
512606	502348	14031R	PARTICIPANT	\N	PRESENT	0
512616	502348	04035D	PARTICIPANT	\N	PRESENT	0
512608	502348	20038A	PARTICIPANT	\N	PRESENT	0
512609	502348	01057W	PARTICIPANT	\N	PRESENT	0
512610	502348	20032T	PARTICIPANT	\N	PRESENT	0
512611	502348	20034V	PARTICIPANT	\N	PRESENT	0
512614	502348	18083K	PARTICIPANT	\N	PRESENT	0
512613	502348	14255U	PARTICIPANT	\N	PRESENT	0
512615	502348	20074E	PARTICIPANT	\N	PRESENT	0
512617	502348	04092N	PARTICIPANT	\N	PRESENT	0
512618	502348	11090Q	PARTICIPANT	\N	PRESENT	0
512619	502348	14147R	PARTICIPANT	\N	PRESENT	0
512620	502348	08015R	PARTICIPANT	\N	PRESENT	0
512621	502348	19749K	PARTICIPANT	\N	PRESENT	0
512622	502348	99004R	PARTICIPANT	\N	PRESENT	0
512639	502348	08073C	PARTICIPANT	\N	PRESENT	0
512648	502348	86034E	PARTICIPANT	\N	PRESENT	0
512649	502348	19747H	PARTICIPANT	\N	PRESENT	0
512857	512856	14121F	PARTICIPANT	\N	PRESENT	0
512876	508794	19349W	PARTICIPANT	\N	PRESENT	0
512877	502349	20128B	PARTICIPANT	\N	PRESENT	0
512878	508794	14229S	PARTICIPANT	\N	PRESENT	0
512879	508794	14107H	PARTICIPANT	\N	PRESENT	0
512880	508794	04045F	PARTICIPANT	\N	PRESENT	0
512881	508794	20084G	PARTICIPANT	\N	PRESENT	0
512882	508794	20122U	PARTICIPANT	\N	PRESENT	0
512884	512883	14147R	PARTICIPANT	\N	EXCUSE	0
512885	512883	14331P	PARTICIPANT	\N	EXCUSE	0
512886	502349	11054L	PARTICIPANT	\N	PRESENT	0
512887	512883	05008E	PARTICIPANT	\N	EXCUSE	0
512888	512883	14275Y	PARTICIPANT	\N	EXCUSE	0
512899	502349	14069U	PARTICIPANT	\N	PRESENT	0
512891	502349	14038Y	PARTICIPANT	\N	PRESENT	0
512892	502349	14225N	PARTICIPANT	\N	PRESENT	0
512893	502349	11027H	PARTICIPANT	\N	PRESENT	0
512894	502349	11083R	PARTICIPANT	\N	PRESENT	0
512895	502349	14173T	PARTICIPANT	\N	PRESENT	0
512896	502349	19747H	PARTICIPANT	\N	PRESENT	0
512897	502349	04035D	PARTICIPANT	\N	PRESENT	0
512898	502349	20038A	PARTICIPANT	\N	PRESENT	0
512900	502349	01057W	PARTICIPANT	\N	PRESENT	0
512901	502349	14071N	PARTICIPANT	\N	PRESENT	0
512902	502349	01058X	PARTICIPANT	\N	PRESENT	0
512903	502349	04042C	PARTICIPANT	\N	PRESENT	0
512904	502349	08047A	PARTICIPANT	\N	PRESENT	0
512905	502349	07029T	PARTICIPANT	\N	PRESENT	0
512906	502349	19866P	PARTICIPANT	\N	PRESENT	0
512907	502349	20054A	PARTICIPANT	\N	PRESENT	0
512908	502349	14055N	PARTICIPANT	\N	PRESENT	0
512909	502349	17023S	PARTICIPANT	\N	PRESENT	0
512911	512910	05008E	PARTICIPANT	\N	PRESENT	0
512912	512910	01028R	PARTICIPANT	\N	PRESENT	0
512913	512910	11053K	PARTICIPANT	\N	PRESENT	0
512914	502349	19447X	PARTICIPANT	\N	PRESENT	0
512915	502349	19647E	PARTICIPANT	\N	PRESENT	0
512916	502349	14211G	PARTICIPANT	\N	PRESENT	0
512918	502349	11066Q	PARTICIPANT	\N	PRESENT	0
512919	512917	01028R	PARTICIPANT	\N	PRESENT	0
512920	502349	20100N	PARTICIPANT	\N	PRESENT	0
512921	502349	14089Y	PARTICIPANT	\N	PRESENT	0
512922	502349	14253S	PARTICIPANT	\N	PRESENT	0
512923	502349	11053K	PARTICIPANT	\N	PRESENT	0
512924	502349	11033F	PARTICIPANT	\N	PRESENT	0
512925	502349	11012A	PARTICIPANT	\N	PRESENT	0
512926	502349	14073Q	PARTICIPANT	\N	PRESENT	0
512927	502349	19762G	PARTICIPANT	\N	PRESENT	0
512928	502349	19649G	PARTICIPANT	\N	PRESENT	0
512929	502349	14249W	PARTICIPANT	\N	PRESENT	0
512930	502349	19543W	PARTICIPANT	\N	PRESENT	0
512931	502349	14151M	PARTICIPANT	\N	PRESENT	0
512932	502349	04071H	PARTICIPANT	\N	PRESENT	0
512933	502349	14327T	PARTICIPANT	\N	PRESENT	0
512934	502349	19479G	PARTICIPANT	\N	PRESENT	0
512935	502349	20022R	PARTICIPANT	\N	PRESENT	0
512936	502349	19749K	PARTICIPANT	\N	PRESENT	0
512937	502349	11026G	PARTICIPANT	\N	PRESENT	0
512938	502349	20114U	PARTICIPANT	\N	PRESENT	0
512939	502349	01028R	PARTICIPANT	\N	PRESENT	0
512940	502349	20110Q	PARTICIPANT	\N	PRESENT	0
512941	502349	14026U	PARTICIPANT	\N	PRESENT	0
512942	502349	19687N	PARTICIPANT	\N	PRESENT	0
512943	509961	05008E	PARTICIPANT	\N	PRESENT	0
512944	509961	20110Q	PARTICIPANT	\N	PRESENT	0
512945	509961	04047H	PARTICIPANT	\N	PRESENT	0
512946	509961	14089Y	PARTICIPANT	\N	PRESENT	0
512947	509961	11056N	PARTICIPANT	\N	PRESENT	0
512948	509961	14021P	PARTICIPANT	\N	PRESENT	0
512949	509961	95063L	PARTICIPANT	\N	PRESENT	0
512950	509961	19749K	PARTICIPANT	\N	PRESENT	1
512951	509961	14179A	PARTICIPANT	\N	PRESENT	1
483600	483245	11097X	PARTICIPANT	\N	PRESENT	0
483601	483245	19591F	PARTICIPANT	\N	PRESENT	0
483602	483245	19565D	PARTICIPANT	\N	EXCUSE	0
483604	483166	89017R	PARTICIPANT	\N	PRESENT	0
483704	479260	19715Y	PARTICIPANT	\N	PRESENT	0
483705	479260	14039A	PARTICIPANT	\N	PRESENT	0
483706	479260	98029W	PARTICIPANT	\N	PRESENT	0
483707	479260	07004J	PARTICIPANT	\N	PRESENT	0
483708	479260	08017T	PARTICIPANT	\N	PRESENT	0
483709	479260	97011G	PARTICIPANT	\N	PRESENT	0
483710	479260	04097T	PARTICIPANT	\N	PRESENT	0
483711	479260	14053L	PARTICIPANT	\N	PRESENT	0
483712	479260	14041T	PARTICIPANT	\N	PRESENT	0
483713	479260	14115H	PARTICIPANT	\N	PRESENT	0
483714	479260	04071H	PARTICIPANT	\N	PRESENT	0
483715	479260	19651A	PARTICIPANT	\N	PRESENT	0
483716	479260	18083K	PARTICIPANT	\N	PRESENT	0
483717	479260	08018U	PARTICIPANT	\N	PRESENT	0
483718	479260	19369B	PARTICIPANT	\N	PRESENT	0
483719	479260	08052W	PARTICIPANT	\N	PRESENT	0
483720	479260	19794Q	PARTICIPANT	\N	PRESENT	0
483721	479260	86034E	PARTICIPANT	\N	PRESENT	0
483722	479260	19826F	PARTICIPANT	\N	PRESENT	0
483723	479260	11085T	PARTICIPANT	\N	PRESENT	0
483724	479260	14267Y	PARTICIPANT	\N	PRESENT	0
483725	479260	12041X	PARTICIPANT	\N	PRESENT	0
483726	479260	14231L	PARTICIPANT	\N	PRESENT	0
483727	479260	19693L	PARTICIPANT	\N	PRESENT	0
483728	479260	14103D	PARTICIPANT	\N	PRESENT	0
483729	479260	14211G	PARTICIPANT	\N	PRESENT	0
483730	479260	11045K	PARTICIPANT	\N	PRESENT	0
483731	479260	98035U	PARTICIPANT	\N	PRESENT	0
483732	479260	08014Q	PARTICIPANT	\N	PRESENT	0
483733	479260	19731Y	PARTICIPANT	\N	PRESENT	0
483734	479260	19711U	PARTICIPANT	\N	PRESENT	0
483735	479260	19637C	PARTICIPANT	\N	PRESENT	0
483736	479260	19569H	PARTICIPANT	\N	PRESENT	0
483737	479260	14063N	PARTICIPANT	\N	PRESENT	0
483738	479260	11027H	PARTICIPANT	\N	PRESENT	0
483739	479260	19383Y	PARTICIPANT	\N	PRESENT	0
483740	479260	19671E	PARTICIPANT	\N	PRESENT	0
483741	479260	14259Y	PARTICIPANT	\N	PRESENT	0
483742	479260	08031R	PARTICIPANT	\N	PRESENT	0
483743	479260	19549D	PARTICIPANT	\N	PRESENT	0
483744	479260	19489J	PARTICIPANT	\N	PRESENT	0
483745	479260	14073Q	PARTICIPANT	\N	PRESENT	0
483746	479260	19745F	PARTICIPANT	\N	PRESENT	0
483747	479260	19699S	PARTICIPANT	\N	PRESENT	0
483748	479260	19926J	PARTICIPANT	\N	PRESENT	0
483749	479260	11067R	PARTICIPANT	\N	PRESENT	0
483750	479260	19333N	PARTICIPANT	\N	PRESENT	0
483751	479260	19912C	PARTICIPANT	\N	PRESENT	0
483752	479260	11074Q	PARTICIPANT	\N	PRESENT	0
483753	479260	11066Q	PARTICIPANT	\N	PRESENT	0
483754	479260	04059M	PARTICIPANT	\N	PRESENT	0
483755	479260	11041F	PARTICIPANT	\N	PRESENT	0
483756	479260	14235Q	PARTICIPANT	\N	PRESENT	0
483757	479260	17779H	PARTICIPANT	\N	PRESENT	0
483758	479260	14197C	PARTICIPANT	\N	PRESENT	0
483759	479260	14051J	PARTICIPANT	\N	PRESENT	0
483760	479260	08058D	PARTICIPANT	\N	PRESENT	0
483761	479260	19683J	PARTICIPANT	\N	PRESENT	0
483762	479260	19503N	PARTICIPANT	\N	PRESENT	0
483763	479260	08053X	PARTICIPANT	\N	PRESENT	0
483764	479260	19479G	PARTICIPANT	\N	PRESENT	0
483765	479260	19685L	PARTICIPANT	\N	PRESENT	0
483766	479260	11104D	PARTICIPANT	\N	PRESENT	0
483767	479260	11077T	PARTICIPANT	\N	PRESENT	0
483768	479260	19593H	PARTICIPANT	\N	PRESENT	0
483769	479260	19758L	PARTICIPANT	\N	PRESENT	0
483770	479260	19697Q	PARTICIPANT	\N	PRESENT	0
483771	479260	19737F	PARTICIPANT	\N	PRESENT	0
483772	479260	14147R	PARTICIPANT	\N	PRESENT	0
483773	479260	19421M	PARTICIPANT	\N	PRESENT	0
483774	479260	04040A	PARTICIPANT	\N	PRESENT	0
483775	479260	14030Q	PARTICIPANT	\N	PRESENT	0
483776	479260	14195A	PARTICIPANT	\N	PRESENT	0
483777	479260	04057K	PARTICIPANT	\N	PRESENT	0
483778	479260	11012A	PARTICIPANT	\N	PRESENT	0
483779	479260	19629C	PARTICIPANT	\N	PRESENT	0
483780	479260	19719D	PARTICIPANT	\N	PRESENT	0
483781	479260	16685X	PARTICIPANT	\N	PRESENT	0
483782	479260	19441R	PARTICIPANT	\N	PRESENT	0
483783	479260	11053K	PARTICIPANT	\N	PRESENT	0
483784	479260	19687N	PARTICIPANT	\N	PRESENT	0
483785	479260	19649G	PARTICIPANT	\N	PRESENT	0
483786	479260	14081Q	PARTICIPANT	\N	PRESENT	0
483787	479260	01028R	PARTICIPANT	\N	PRESENT	0
483788	479260	19631V	PARTICIPANT	\N	PRESENT	0
483789	479260	19349W	PARTICIPANT	\N	PRESENT	0
483790	479260	11040E	PARTICIPANT	\N	PRESENT	0
483791	479260	04085P	PARTICIPANT	\N	PRESENT	0
483792	479260	14085U	PARTICIPANT	\N	PRESENT	0
483793	479260	19253P	PARTICIPANT	\N	PRESENT	0
483794	479260	11065P	PARTICIPANT	\N	PRESENT	0
483795	479260	01034P	PARTICIPANT	\N	PRESENT	0
483796	479260	95037J	PARTICIPANT	\N	PRESENT	0
483797	479260	11109J	PARTICIPANT	\N	PRESENT	0
483798	479260	19269X	PARTICIPANT	\N	PRESENT	0
483799	479260	19563B	PARTICIPANT	\N	PRESENT	0
483800	479260	19735D	PARTICIPANT	\N	PRESENT	0
483801	479260	01043Q	PARTICIPANT	\N	PRESENT	0
483802	479260	19599P	PARTICIPANT	\N	PRESENT	0
483803	479260	14225N	PARTICIPANT	\N	PRESENT	0
483804	479260	14151M	PARTICIPANT	\N	PRESENT	0
483805	479260	19251M	PARTICIPANT	\N	PRESENT	0
483806	479260	19295A	PARTICIPANT	\N	PRESENT	0
483807	479260	19527W	PARTICIPANT	\N	PRESENT	0
483808	479260	14229S	PARTICIPANT	\N	PRESENT	0
483809	479260	19695N	PARTICIPANT	\N	PRESENT	0
483810	479260	11031D	PARTICIPANT	\N	PRESENT	0
483811	479260	04034C	PARTICIPANT	\N	PRESENT	0
483812	479260	11083R	PARTICIPANT	\N	PRESENT	0
483813	479260	19543W	PARTICIPANT	\N	PRESENT	0
483814	479260	01058X	PARTICIPANT	\N	PRESENT	0
483815	479260	19301E	PARTICIPANT	\N	PRESENT	0
483816	479260	19914E	PARTICIPANT	\N	PRESENT	0
483817	479260	08011M	PARTICIPANT	\N	PRESENT	0
483818	479260	14121F	PARTICIPANT	\N	PRESENT	0
483819	479260	14157T	PARTICIPANT	\N	PRESENT	0
483820	479260	88008L	PARTICIPANT	\N	PRESENT	0
483821	479260	96004D	PARTICIPANT	\N	PRESENT	0
483822	479260	99004R	PARTICIPANT	\N	PRESENT	0
483823	479260	11099A	PARTICIPANT	\N	PRESENT	0
483824	479260	14207L	PARTICIPANT	\N	PRESENT	0
483825	479260	19515S	PARTICIPANT	\N	PRESENT	0
483826	479260	14034U	PARTICIPANT	\N	PRESENT	0
483827	479260	14029X	PARTICIPANT	\N	PRESENT	0
483828	479260	14093U	PARTICIPANT	\N	PRESENT	0
483829	479260	14251Q	PARTICIPANT	\N	PRESENT	0
483830	479260	19663E	PARTICIPANT	\N	PRESENT	0
483831	479260	04088S	PARTICIPANT	\N	PRESENT	0
483832	479260	07029T	PARTICIPANT	\N	PRESENT	0
483833	479260	08055A	PARTICIPANT	\N	PRESENT	0
483834	479260	14061L	PARTICIPANT	\N	PRESENT	0
483835	479260	11097X	PARTICIPANT	\N	PRESENT	0
483836	479260	14059S	PARTICIPANT	\N	PRESENT	0
483837	479260	14021P	PARTICIPANT	\N	PRESENT	0
483838	479260	19689Q	PARTICIPANT	\N	PRESENT	0
483839	479260	11072N	PARTICIPANT	\N	PRESENT	0
483840	479260	19447X	PARTICIPANT	\N	PRESENT	0
483841	479260	14065Q	PARTICIPANT	\N	PRESENT	0
483842	479260	19531S	PARTICIPANT	\N	PRESENT	0
483843	479260	19507S	PARTICIPANT	\N	PRESENT	0
483844	479260	14001X	PARTICIPANT	\N	PRESENT	0
483845	479260	19573D	PARTICIPANT	\N	PRESENT	0
483846	479260	19399H	PARTICIPANT	\N	PRESENT	0
483847	479260	19413M	PARTICIPANT	\N	PRESENT	0
483848	479260	14357A	PARTICIPANT	\N	PRESENT	0
483849	479260	19647E	PARTICIPANT	\N	PRESENT	0
483850	479260	19675J	PARTICIPANT	\N	PRESENT	0
483851	479260	04018C	PARTICIPANT	\N	PRESENT	0
483852	479260	14179A	PARTICIPANT	\N	PRESENT	0
483853	479260	19611R	PARTICIPANT	\N	PRESENT	0
483854	479260	19721W	PARTICIPANT	\N	PRESENT	0
483855	479260	14217N	PARTICIPANT	\N	PRESENT	0
483856	479260	19701S	PARTICIPANT	\N	PRESENT	0
483857	479260	19739H	PARTICIPANT	\N	PRESENT	0
483858	479260	14042U	PARTICIPANT	\N	PRESENT	0
483859	479260	10006L	PARTICIPANT	\N	PRESENT	0
483860	479260	14219Q	PARTICIPANT	\N	PRESENT	0
483861	479260	19749K	PARTICIPANT	\N	PRESENT	0
483863	479260	11070L	PARTICIPANT	\N	PRESENT	0
483864	479260	14083S	PARTICIPANT	\N	PRESENT	0
483865	479260	05012A	PARTICIPANT	\N	PRESENT	0
483866	479260	04049K	PARTICIPANT	\N	PRESENT	0
483867	479260	14255U	PARTICIPANT	\N	PRESENT	0
509038	505799	19954N	PARTICIPANT	\N	PRESENT	1
509039	505799	07004J	PARTICIPANT	\N	PRESENT	1
509040	505799	14147R	PARTICIPANT	\N	PRESENT	1
509042	505799	19543W	PARTICIPANT	\N	PRESENT	1
509476	509029	20058E	PARTICIPANT	\N	PRESENT	0
509478	509029	20098N	PARTICIPANT	\N	PRESENT	1
509480	509029	20048C	PARTICIPANT	\N	PRESENT	1
509481	509029	20120S	PARTICIPANT	\N	PRESENT	1
509856	502327	12016W	PARTICIPANT	\N	PRESENT	0
510076	502328	20102Q	PARTICIPANT	\N	PRESENT	0
509859	509270	11010L	PARTICIPANT	\N	EXCUSE	0
509860	509270	14331P	PARTICIPANT	\N	EXCUSE	0
509862	509270	19659J	PARTICIPANT	\N	EXCUSE	0
509863	509270	19577H	PARTICIPANT	\N	PRESENT	0
509875	502327	19553Y	PARTICIPANT	\N	PRESENT	0
509865	509270	20146D	PARTICIPANT	\N	PRESENT	0
509866	509270	19717B	PARTICIPANT	\N	PRESENT	0
510077	502328	19593H	PARTICIPANT	\N	PRESENT	0
510078	502328	08017T	PARTICIPANT	\N	PRESENT	0
510079	502328	19715Y	PARTICIPANT	\N	PRESENT	0
509876	502327	20106U	PARTICIPANT	\N	PRESENT	0
509877	502327	98022P	PARTICIPANT	\N	PRESENT	0
509879	509878	11031D	PARTICIPANT	\N	PRESENT	0
509880	509878	18193Q	PARTICIPANT	\N	PRESENT	0
509881	509878	14213J	PARTICIPANT	\N	PRESENT	0
509882	502327	01058X	PARTICIPANT	\N	PRESENT	0
509883	502327	14211G	PARTICIPANT	\N	PRESENT	0
509884	502327	04043D	PARTICIPANT	\N	PRESENT	0
510080	502328	19599P	PARTICIPANT	\N	PRESENT	0
509886	502327	19413M	PARTICIPANT	\N	PRESENT	0
510081	502328	20070A	PARTICIPANT	\N	PRESENT	0
510082	502328	19551W	PARTICIPANT	\N	PRESENT	0
509889	502327	19741B	PARTICIPANT	\N	PRESENT	0
509894	502327	19611R	PARTICIPANT	\N	PRESENT	0
509895	502327	19643A	PARTICIPANT	\N	PRESENT	0
509896	502327	11077T	PARTICIPANT	\N	PRESENT	0
510083	502328	14257W	PARTICIPANT	\N	PRESENT	0
509899	502327	04071H	PARTICIPANT	\N	PRESENT	0
509900	502327	19699S	PARTICIPANT	\N	PRESENT	0
509901	502327	20110Q	PARTICIPANT	\N	PRESENT	0
509902	506631	19479G	PARTICIPANT	\N	PRESENT	0
510084	502328	04034C	PARTICIPANT	\N	PRESENT	0
510085	502328	19717B	PARTICIPANT	\N	PRESENT	0
510086	502328	11083R	PARTICIPANT	\N	PRESENT	0
510087	502328	20092G	PARTICIPANT	\N	PRESENT	0
510088	502328	19347U	PARTICIPANT	\N	PRESENT	0
510089	502328	16685X	PARTICIPANT	\N	PRESENT	0
510090	502328	19369B	PARTICIPANT	\N	PRESENT	0
510091	502328	19745F	PARTICIPANT	\N	PRESENT	0
510092	502328	07004J	PARTICIPANT	\N	PRESENT	0
510093	502328	11053K	PARTICIPANT	\N	PRESENT	0
510094	502328	14083S	PARTICIPANT	\N	PRESENT	0
510095	502328	95063L	PARTICIPANT	\N	PRESENT	0
510096	502328	19621T	PARTICIPANT	\N	PRESENT	0
510097	502328	19671E	PARTICIPANT	\N	PRESENT	0
510098	502328	19515S	PARTICIPANT	\N	PRESENT	0
510099	502328	08034U	PARTICIPANT	\N	PRESENT	0
510100	502328	14041T	PARTICIPANT	\N	PRESENT	0
510101	502328	19565D	PARTICIPANT	\N	PRESENT	0
510102	502328	20038A	PARTICIPANT	\N	PRESENT	0
510103	502328	05012A	PARTICIPANT	\N	PRESENT	0
510104	502328	14253S	PARTICIPANT	\N	PRESENT	0
510105	502328	11027H	PARTICIPANT	\N	PRESENT	0
510106	502328	11064N	PARTICIPANT	\N	PRESENT	0
510107	502328	19687N	PARTICIPANT	\N	PRESENT	0
510108	502328	19826F	PARTICIPANT	\N	PRESENT	0
510109	502328	14073Q	PARTICIPANT	\N	PRESENT	0
510110	502328	20124W	PARTICIPANT	\N	PRESENT	0
510111	502328	04043D	PARTICIPANT	\N	PRESENT	0
510112	502328	11041F	PARTICIPANT	\N	PRESENT	0
510113	502328	20080C	PARTICIPANT	\N	PRESENT	0
510114	502328	19709B	PARTICIPANT	\N	PRESENT	0
510115	502328	98022P	PARTICIPANT	\N	PRESENT	0
510116	502328	20044X	PARTICIPANT	\N	PRESENT	0
510117	502328	20110Q	PARTICIPANT	\N	PRESENT	0
510118	502328	14255U	PARTICIPANT	\N	PRESENT	0
510119	502328	19669L	PARTICIPANT	\N	PRESENT	0
510120	502328	20116W	PARTICIPANT	\N	PRESENT	0
510121	502328	20024T	PARTICIPANT	\N	PRESENT	0
510122	502328	05008E	PARTICIPANT	\N	PRESENT	0
510123	502328	19553Y	PARTICIPANT	\N	PRESENT	0
510124	502328	04042C	PARTICIPANT	\N	PRESENT	0
510125	502328	19647E	PARTICIPANT	\N	PRESENT	0
510126	502328	19741B	PARTICIPANT	\N	PRESENT	0
510127	502328	20026V	PARTICIPANT	\N	PRESENT	0
510128	502328	20034V	PARTICIPANT	\N	PRESENT	0
510130	502328	11012A	PARTICIPANT	\N	PRESENT	0
510131	502328	19421M	PARTICIPANT	\N	PRESENT	0
510132	502328	14249W	PARTICIPANT	\N	PRESENT	0
510133	502328	19335Q	PARTICIPANT	\N	PRESENT	0
510134	502328	19611R	PARTICIPANT	\N	PRESENT	0
510135	502328	01058X	PARTICIPANT	\N	PRESENT	0
510136	502328	14211G	PARTICIPANT	\N	PRESENT	0
510137	502328	14215L	PARTICIPANT	\N	PRESENT	0
510138	502328	12041X	PARTICIPANT	\N	PRESENT	0
510139	502328	11110B	PARTICIPANT	\N	PRESENT	0
510140	502328	14031R	PARTICIPANT	\N	PRESENT	0
510141	502328	14030Q	PARTICIPANT	\N	PRESENT	0
510142	502328	20140W	PARTICIPANT	\N	PRESENT	0
510143	502328	07029T	PARTICIPANT	\N	PRESENT	0
510144	502328	11085T	PARTICIPANT	\N	PRESENT	0
510040	510039	04071H	PARTICIPANT	\N	PRESENT	0
510042	510041	14225N	PARTICIPANT	\N	PRESENT	0
510145	502328	11065P	PARTICIPANT	\N	PRESENT	0
510146	502328	20114U	PARTICIPANT	\N	PRESENT	0
510046	510044	14189C	PARTICIPANT	\N	PRESENT	0
510147	502328	14026U	PARTICIPANT	\N	PRESENT	0
510199	502329	14026U	PARTICIPANT	\N	PRESENT	0
510200	502329	11012A	PARTICIPANT	\N	PRESENT	0
510201	502329	19669L	PARTICIPANT	\N	PRESENT	0
510052	510051	14083S	PARTICIPANT	\N	PRESENT	0
510053	510051	11012A	PARTICIPANT	\N	PRESENT	0
510055	510054	14083S	PARTICIPANT	\N	PRESENT	0
510056	510054	11012A	PARTICIPANT	\N	PRESENT	0
510202	502329	11041F	PARTICIPANT	\N	PRESENT	0
510203	502329	19599P	PARTICIPANT	\N	PRESENT	0
510060	510059	14253S	PARTICIPANT	\N	PRESENT	0
510062	510061	14253S	PARTICIPANT	\N	PRESENT	0
510204	502329	20114U	PARTICIPANT	\N	PRESENT	0
510205	502329	12041X	PARTICIPANT	\N	PRESENT	0
510206	502329	20034V	PARTICIPANT	\N	PRESENT	0
510207	502329	19565D	PARTICIPANT	\N	PRESENT	0
510208	502329	19719D	PARTICIPANT	\N	PRESENT	0
510069	510068	14331P	PARTICIPANT	\N	PRESENT	0
510209	502329	14249W	PARTICIPANT	\N	PRESENT	0
510210	502329	19762G	PARTICIPANT	\N	PRESENT	0
510211	502329	19671E	PARTICIPANT	\N	PRESENT	0
510212	502329	19421M	PARTICIPANT	\N	PRESENT	0
510074	502328	99004R	PARTICIPANT	\N	PRESENT	0
510075	502328	11070L	PARTICIPANT	\N	PRESENT	0
510213	502329	20124W	PARTICIPANT	\N	PRESENT	0
510214	502329	20024T	PARTICIPANT	\N	PRESENT	0
510215	502329	14030Q	PARTICIPANT	\N	PRESENT	0
510216	502329	20038A	PARTICIPANT	\N	PRESENT	0
510217	502329	14253S	PARTICIPANT	\N	PRESENT	0
510218	502329	14031R	PARTICIPANT	\N	PRESENT	0
510219	502329	19709B	PARTICIPANT	\N	PRESENT	0
510220	502329	16685X	PARTICIPANT	\N	PRESENT	0
510221	502329	14083S	PARTICIPANT	\N	PRESENT	0
510222	502329	04042C	PARTICIPANT	\N	PRESENT	0
510223	502329	20092G	PARTICIPANT	\N	PRESENT	0
510224	502329	19347U	PARTICIPANT	\N	PRESENT	0
510225	502329	14211G	PARTICIPANT	\N	PRESENT	0
510226	502329	19741B	PARTICIPANT	\N	PRESENT	0
510227	502329	20094J	PARTICIPANT	\N	PRESENT	0
510228	502329	11064N	PARTICIPANT	\N	PRESENT	0
510229	502329	20044X	PARTICIPANT	\N	PRESENT	0
510230	502329	19647E	PARTICIPANT	\N	PRESENT	0
510231	502329	20070A	PARTICIPANT	\N	PRESENT	0
510232	502329	19531S	PARTICIPANT	\N	PRESENT	0
510233	502329	19687N	PARTICIPANT	\N	PRESENT	0
510234	502329	14255U	PARTICIPANT	\N	PRESENT	0
510792	509898	05008E	PARTICIPANT	\N	PRESENT	0
510793	509898	14089Y	PARTICIPANT	\N	PRESENT	1
510794	509898	04047H	PARTICIPANT	\N	PRESENT	0
483301	483300	19549D	PARTICIPANT	\N	PRESENT	0
483302	483300	19611R	PRESIDENT	0	PRESENT	0
483303	483300	14097Y	PARTICIPANT	\N	PRESENT	0
483304	483300	14031R	PARTICIPANT	\N	PRESENT	0
483305	483300	19687N	PARTICIPANT	\N	PRESENT	0
483316	483314	19415P	PARTICIPANT	\N	PRESENT	0
483317	483314	11067R	PARTICIPANT	\N	PRESENT	0
483318	483314	19798U	PARTICIPANT	\N	PRESENT	0
483319	483315	19415P	PARTICIPANT	\N	PRESENT	0
483320	483315	14213J	PARTICIPANT	\N	PRESENT	0
483321	483315	11067R	PARTICIPANT	\N	PRESENT	0
483323	483322	19415P	PARTICIPANT	\N	PRESENT	0
483324	483322	11067R	PARTICIPANT	\N	PRESENT	0
483326	483325	14097Y	PARTICIPANT	\N	PRESENT	0
483327	483325	19611R	PARTICIPANT	\N	PRESENT	0
483328	483325	19629C	PARTICIPANT	\N	PRESENT	0
483473	483349	19667J	PRESIDENT	0	PRESENT	0
483474	483349	11056N	PARTICIPANT	\N	PRESENT	0
483475	483349	19679N	PARTICIPANT	\N	PRESENT	0
483476	483349	14001X	PARTICIPANT	\N	PRESENT	0
483477	483349	19563B	PARTICIPANT	\N	PRESENT	0
483478	483349	19349W	PARTICIPANT	\N	PRESENT	0
483479	483349	19820Y	PARTICIPANT	\N	EXCUSE	0
483480	483349	14213J	PARTICIPANT	\N	EXCUSE	0
483481	483349	19387D	PARTICIPANT	\N	PRESENT	0
489109	489108	14267Y	PARTICIPANT	\N	PRESENT	0
489110	489108	14039A	PARTICIPANT	\N	PRESENT	0
489111	489108	04086Q	PARTICIPANT	\N	PRESENT	0
489112	489108	19525U	PARTICIPANT	\N	PRESENT	0
489113	489108	19715Y	PARTICIPANT	\N	PRESENT	0
489140	489107	19695N	PARTICIPANT	\N	PRESENT	0
489141	489107	14039A	PARTICIPANT	\N	PRESENT	0
489142	489107	14267Y	PRESIDENT	0	PRESENT	0
489143	489107	04086Q	PARTICIPANT	\N	PRESENT	0
489144	489107	19525U	PARTICIPANT	\N	PRESENT	0
489145	489107	95067Q	PARTICIPANT	\N	PRESENT	0
489146	489107	11026G	PARTICIPANT	\N	PRESENT	0
489147	489107	19295A	PARTICIPANT	\N	PRESENT	0
489148	489107	11064N	PARTICIPANT	\N	PRESENT	0
489149	489039	11056N	PARTICIPANT	\N	PRESENT	0
489150	489039	19415P	PARTICIPANT	\N	PRESENT	0
489151	489039	19667J	PRESIDENT	0	PRESENT	0
489152	489039	19621T	PARTICIPANT	\N	PRESENT	0
489153	489039	19725B	PARTICIPANT	\N	EXCUSE	0
489154	489039	14061L	PARTICIPANT	\N	EXCUSE	0
489155	489039	10015M	PARTICIPANT	\N	EXCUSE	0
489156	489039	19679N	PARTICIPANT	\N	EXCUSE	0
489157	489039	19387D	PARTICIPANT	\N	EXCUSE	0
489158	489039	04097T	PARTICIPANT	\N	EXCUSE	0
489159	489039	14213J	PARTICIPANT	\N	EXCUSE	0
489174	489039	14001X	PARTICIPANT	\N	EXCUSE	0
490459	489831	19679N	PARTICIPANT	\N	PRESENT	0
490460	489831	14071N	PARTICIPANT	\N	PRESENT	0
493165	491420	01043Q	PARTICIPANT	\N	PRESENT	0
493232	491420	14147R	PARTICIPANT	\N	PRESENT	0
493233	491420	19711U	PARTICIPANT	\N	PRESENT	0
493234	491420	14105F	PARTICIPANT	\N	PRESENT	0
493235	491420	19701S	PARTICIPANT	\N	PRESENT	0
493237	491420	14253S	PARTICIPANT	\N	PRESENT	0
493238	491420	19515S	PARTICIPANT	\N	PRESENT	0
493239	491420	19301E	PARTICIPANT	\N	PRESENT	0
493240	491420	11012A	PARTICIPANT	\N	PRESENT	0
493257	491420	20100N	PARTICIPANT	\N	PRESENT	0
493242	491420	20092G	PARTICIPANT	\N	PRESENT	0
493243	491420	11099A	PARTICIPANT	\N	PRESENT	0
493244	491420	20110Q	PARTICIPANT	\N	PRESENT	0
493245	491420	20034V	PARTICIPANT	\N	PRESENT	0
493246	491420	11077T	PARTICIPANT	\N	PRESENT	0
493247	491420	19447X	PARTICIPANT	\N	PRESENT	0
493248	491420	19583F	PARTICIPANT	\N	PRESENT	0
493249	491420	19543W	PARTICIPANT	\N	PRESENT	0
493250	491420	11026G	PARTICIPANT	\N	PRESENT	0
493251	491420	14038Y	PARTICIPANT	\N	PRESENT	0
493252	491420	19399H	PARTICIPANT	\N	PRESENT	0
493266	491420	19715Y	PARTICIPANT	\N	PRESENT	0
493254	491420	14097Y	PARTICIPANT	\N	PRESENT	0
493255	491420	20142Y	PARTICIPANT	\N	PRESENT	0
493256	491420	20134Y	PARTICIPANT	\N	PRESENT	0
493258	491420	04047H	PARTICIPANT	\N	PRESENT	0
493259	491420	01028R	PARTICIPANT	\N	PRESENT	0
493260	491420	11072N	PARTICIPANT	\N	PRESENT	0
493261	491420	14151M	PARTICIPANT	\N	PRESENT	0
493262	491420	14069U	PARTICIPANT	\N	PRESENT	0
493265	491420	19333N	PARTICIPANT	\N	PRESENT	0
493267	491420	05008E	PARTICIPANT	\N	PRESENT	0
493268	491420	08018U	PARTICIPANT	\N	PRESENT	0
493269	491420	99004R	PARTICIPANT	\N	PRESENT	0
493270	491420	14089Y	PARTICIPANT	\N	PRESENT	0
493274	491420	04085P	PARTICIPANT	\N	PRESENT	0
493275	491420	20090E	PARTICIPANT	\N	PRESENT	0
493276	491420	20022R	PARTICIPANT	\N	PRESENT	0
493277	491420	14217N	PARTICIPANT	\N	PRESENT	0
493278	491420	20058E	PARTICIPANT	\N	PRESENT	0
493279	491420	20098N	PARTICIPANT	\N	PRESENT	0
493280	491420	11048N	PARTICIPANT	\N	PRESENT	0
493281	491420	08034U	PARTICIPANT	\N	PRESENT	0
493282	491420	10006L	PARTICIPANT	\N	PRESENT	0
493283	491420	14033T	PARTICIPANT	\N	PRESENT	0
493284	491420	07029T	PARTICIPANT	\N	PRESENT	0
493285	491420	14021P	PARTICIPANT	\N	PRESENT	0
493286	491420	19762G	PARTICIPANT	\N	PRESENT	0
493287	491420	19503N	PARTICIPANT	\N	PRESENT	0
493288	491420	19415P	PARTICIPANT	\N	PRESENT	0
493291	491420	14231L	PARTICIPANT	\N	PRESENT	0
493292	491420	14083S	PARTICIPANT	\N	PRESENT	0
493293	491420	11085T	PARTICIPANT	\N	PRESENT	0
494098	493272	98022P	PARTICIPANT	\N	EXCUSE	0
494100	494099	19741B	PARTICIPANT	\N	PRESENT	0
495718	495678	19543W	PARTICIPANT	\N	PRESENT	0
495719	495678	19826F	PARTICIPANT	\N	PRESENT	0
495720	495678	19367Y	PARTICIPANT	\N	PRESENT	0
495721	495678	19421M	PARTICIPANT	\N	PRESENT	0
495722	495678	14237S	PARTICIPANT	\N	PRESENT	0
495723	495678	11097X	PARTICIPANT	\N	PRESENT	0
495724	495678	19747H	PARTICIPANT	\N	PRESENT	0
495725	495678	19798U	PARTICIPANT	\N	PRESENT	0
495726	495678	19762G	PARTICIPANT	\N	PRESENT	0
495727	495678	20020P	PARTICIPANT	\N	PRESENT	0
495728	495678	20124W	PARTICIPANT	\N	PRESENT	0
495729	495678	14329V	PARTICIPANT	\N	PRESENT	0
495730	495678	14357A	PARTICIPANT	\N	PRESENT	0
495731	495678	14217N	PARTICIPANT	\N	PRESENT	0
495732	495678	14069U	PARTICIPANT	\N	PRESENT	0
495733	495678	01058X	PARTICIPANT	\N	PRESENT	0
495734	495678	19703U	PARTICIPANT	\N	PRESENT	0
495735	495678	19575F	PARTICIPANT	\N	PRESENT	0
495736	495678	20062A	PARTICIPANT	\N	PRESENT	0
495737	495678	08015R	PARTICIPANT	\N	PRESENT	0
495738	495678	18193Q	PARTICIPANT	\N	PRESENT	0
495739	495678	19251M	PARTICIPANT	\N	PRESENT	0
495740	495678	20038A	PARTICIPANT	\N	PRESENT	0
495741	495678	20044X	PARTICIPANT	\N	PRESENT	0
495742	495678	19467C	PARTICIPANT	\N	PRESENT	0
495716	495678	20066E	PARTICIPANT	\N	PRESENT	0
495717	495678	19369B	PARTICIPANT	\N	PRESENT	0
495743	495678	14033T	PARTICIPANT	\N	PRESENT	0
495744	495678	18083K	PARTICIPANT	\N	PRESENT	0
495745	495678	20032T	PARTICIPANT	\N	PRESENT	0
495746	495678	20096L	PARTICIPANT	\N	PRESENT	0
495747	495678	14031R	PARTICIPANT	\N	PRESENT	0
495748	495678	14038Y	PARTICIPANT	\N	PRESENT	0
495749	495678	20076G	PARTICIPANT	\N	PRESENT	0
495750	495678	20136B	PARTICIPANT	\N	PRESENT	0
495751	495678	20140W	PARTICIPANT	\N	PRESENT	0
495752	495678	19711U	PARTICIPANT	\N	PRESENT	0
495753	495678	19739H	PARTICIPANT	\N	PRESENT	0
495754	495678	14083S	PARTICIPANT	\N	PRESENT	0
495755	495678	20118Y	PARTICIPANT	\N	PRESENT	0
495756	495678	19549D	PARTICIPANT	\N	PRESENT	0
495757	495678	11099A	PARTICIPANT	\N	PRESENT	0
495758	495678	20092G	PARTICIPANT	\N	PRESENT	0
495759	495678	14257W	PARTICIPANT	\N	PRESENT	0
495760	495678	19347U	PARTICIPANT	\N	PRESENT	0
495761	495678	14021P	PARTICIPANT	\N	PRESENT	0
495762	495678	19671E	PARTICIPANT	\N	PRESENT	0
495763	495678	04085P	PARTICIPANT	\N	PRESENT	0
495764	495678	19695N	PARTICIPANT	\N	PRESENT	0
495765	495678	20064C	PARTICIPANT	\N	PRESENT	0
495766	495678	17229F	PARTICIPANT	\N	PRESENT	0
495767	495678	20128B	PARTICIPANT	\N	PRESENT	0
495768	495678	14121F	PARTICIPANT	\N	PRESENT	0
495769	495678	19551W	PARTICIPANT	\N	PRESENT	0
495770	495678	20094J	PARTICIPANT	\N	PRESENT	0
495771	495678	14327T	PARTICIPANT	\N	PRESENT	0
495772	495678	20054A	PARTICIPANT	\N	PRESENT	0
495773	495678	20126Y	PARTICIPANT	\N	PRESENT	0
495774	495678	14105F	PARTICIPANT	\N	PRESENT	0
495775	495678	19591F	PARTICIPANT	\N	PRESENT	0
495776	495678	11065P	PARTICIPANT	\N	PRESENT	0
509483	508038	14331P	PARTICIPANT	\N	PRESENT	0
509484	508038	96004D	PARTICIPANT	\N	PRESENT	0
509485	508038	14033T	PARTICIPANT	\N	PRESENT	0
509486	508038	14026U	PARTICIPANT	\N	PRESENT	0
509487	508038	20128B	PARTICIPANT	\N	PRESENT	0
509488	508038	14097Y	PARTICIPANT	\N	PRESENT	0
509489	508038	19441R	PARTICIPANT	\N	PRESENT	0
509490	508038	14207L	PARTICIPANT	\N	PRESENT	0
509492	508038	11090Q	PARTICIPANT	\N	PRESENT	0
509494	508038	14357A	PARTICIPANT	\N	PRESENT	0
509496	508038	19507S	PARTICIPANT	\N	PRESENT	0
509499	508038	20054A	PARTICIPANT	\N	PRESENT	0
509500	508038	14257W	PARTICIPANT	\N	PRESENT	0
509502	508038	19563B	PARTICIPANT	\N	PRESENT	0
509504	508038	11099A	PARTICIPANT	\N	PRESENT	0
511773	509565	20074E	PARTICIPANT	\N	EXCUSE	0
511776	509565	11033F	PARTICIPANT	\N	PRESENT	1
511778	509565	14053L	PARTICIPANT	\N	PRESENT	1
511780	509565	19673G	PARTICIPANT	\N	PRESENT	1
511782	509565	19725B	PARTICIPANT	\N	PRESENT	1
511783	509565	11072N	PARTICIPANT	\N	PRESENT	1
511785	509565	14107H	PARTICIPANT	\N	PRESENT	1
511786	509565	19749K	PARTICIPANT	\N	PRESENT	1
511788	509565	05008E	PARTICIPANT	\N	PRESENT	1
511790	509565	14069U	PARTICIPANT	\N	PRESENT	1
512045	502346	14038Y	PARTICIPANT	\N	PRESENT	0
512046	502346	11097X	PARTICIPANT	\N	PRESENT	0
512047	502346	01057W	PARTICIPANT	\N	PRESENT	0
512048	502346	19671E	PARTICIPANT	\N	PRESENT	0
512049	502346	14033T	PARTICIPANT	\N	PRESENT	0
512050	502346	20032T	PARTICIPANT	\N	PRESENT	0
512051	502346	99004R	PARTICIPANT	\N	PRESENT	0
512052	502346	19687N	PARTICIPANT	\N	PRESENT	0
512053	502346	19301E	PARTICIPANT	\N	PRESENT	0
512054	502346	19621T	PARTICIPANT	\N	PRESENT	0
512055	502346	20126Y	PARTICIPANT	\N	PRESENT	0
512056	502346	20066E	PARTICIPANT	\N	PRESENT	0
512057	502346	20120S	PARTICIPANT	\N	PRESENT	0
512058	502346	20118Y	PARTICIPANT	\N	PRESENT	0
512059	502346	19399H	PARTICIPANT	\N	PRESENT	0
512060	502346	20082E	PARTICIPANT	\N	PRESENT	0
512061	502346	08010L	PARTICIPANT	\N	PRESENT	0
512062	502346	20036X	PARTICIPANT	\N	PRESENT	0
512063	502346	14107H	PARTICIPANT	\N	PRESENT	0
512064	502346	19782L	PARTICIPANT	\N	PRESENT	0
512065	502346	07004J	PARTICIPANT	\N	PRESENT	0
512066	502346	05008E	PARTICIPANT	\N	PRESENT	0
512067	502346	14030Q	PARTICIPANT	\N	PRESENT	0
512068	502346	14123H	PARTICIPANT	\N	PRESENT	0
512069	502346	01048V	PARTICIPANT	\N	PRESENT	0
512070	502346	19866P	PARTICIPANT	\N	PRESENT	0
512071	502346	01028R	PARTICIPANT	\N	PRESENT	0
512072	502346	19749K	PARTICIPANT	\N	PRESENT	0
512073	502346	20054A	PARTICIPANT	\N	PRESENT	0
512074	502346	19745F	PARTICIPANT	\N	PRESENT	0
512075	502346	14073Q	PARTICIPANT	\N	PRESENT	0
512076	502346	14189C	PARTICIPANT	\N	PRESENT	0
512077	502346	19631V	PARTICIPANT	\N	PRESENT	0
512078	502346	19701S	PARTICIPANT	\N	PRESENT	0
512079	502346	19669L	PARTICIPANT	\N	PRESENT	0
512080	502346	14259Y	PARTICIPANT	\N	PRESENT	0
512081	502346	20110Q	PARTICIPANT	\N	PRESENT	0
512082	502346	14069U	PARTICIPANT	\N	PRESENT	0
512083	502346	19768N	PARTICIPANT	\N	PRESENT	0
512084	502346	19533U	PARTICIPANT	\N	PRESENT	0
512091	502346	14187A	PARTICIPANT	\N	PRESENT	0
512086	502346	08015R	PARTICIPANT	\N	PRESENT	0
512087	502346	19441R	PARTICIPANT	\N	PRESENT	0
512088	502346	14059S	PARTICIPANT	\N	PRESENT	0
512089	502346	14071N	PARTICIPANT	\N	PRESENT	0
512090	502346	19611R	PARTICIPANT	\N	PRESENT	0
512092	502346	14257W	PARTICIPANT	\N	PRESENT	0
512093	502346	19503N	PARTICIPANT	\N	PRESENT	0
512094	502346	11067R	PARTICIPANT	\N	PRESENT	0
512095	502346	14281W	PARTICIPANT	\N	PRESENT	0
512096	502346	19647E	PARTICIPANT	\N	PRESENT	0
512097	502346	20080C	PARTICIPANT	\N	PRESENT	0
512098	502346	19521Q	PARTICIPANT	\N	PRESENT	0
512100	502346	19551W	PARTICIPANT	\N	PRESENT	0
512102	509857	19333N	PARTICIPANT	\N	PRESENT	0
512103	509857	14038Y	PARTICIPANT	\N	PRESENT	0
512104	509857	18083K	PARTICIPANT	\N	PRESENT	0
512105	509857	14219Q	PRESIDENT	0	PRESENT	0
512106	509857	20046A	PARTICIPANT	\N	PRESENT	0
512107	509857	19826F	PARTICIPANT	\N	PRESENT	0
512108	509857	20102Q	PARTICIPANT	\N	PRESENT	0
512109	509857	17229F	PARTICIPANT	\N	PRESENT	0
512115	502346	19447X	PARTICIPANT	\N	PRESENT	0
512116	509857	19503N	PARTICIPANT	\N	PRESENT	0
512117	509857	19739H	PARTICIPANT	\N	PRESENT	0
512118	509857	19820Y	PARTICIPANT	\N	PRESENT	0
512119	509857	19745F	PARTICIPANT	\N	PRESENT	0
512120	502346	14193X	PARTICIPANT	\N	PRESENT	0
512121	509857	19701S	PARTICIPANT	\N	PRESENT	0
512122	509857	19599P	PARTICIPANT	\N	PRESENT	0
512123	509857	20100N	PARTICIPANT	\N	PRESENT	0
512124	502346	20124W	PARTICIPANT	\N	PRESENT	0
512125	502346	97011G	PARTICIPANT	\N	PRESENT	0
512126	502346	11048N	PARTICIPANT	\N	PRESENT	0
512127	502346	20098N	PARTICIPANT	\N	PRESENT	0
512128	509857	20020P	PARTICIPANT	\N	PRESENT	0
512129	509857	20068G	PARTICIPANT	\N	PRESENT	1
512130	509857	19387D	PARTICIPANT	\N	PRESENT	1
512131	509857	19637C	PARTICIPANT	\N	PRESENT	1
512132	502346	01024M	PARTICIPANT	\N	PRESENT	0
512133	509848	14038Y	PARTICIPANT	\N	PRESENT	0
512134	509848	19515S	PARTICIPANT	\N	PRESENT	0
512135	509848	20092G	PARTICIPANT	\N	PRESENT	0
512136	509848	19705W	PARTICIPANT	\N	PRESENT	0
512137	509848	19441R	PARTICIPANT	\N	PRESENT	0
512138	509848	19413M	PARTICIPANT	\N	PRESENT	0
512139	509848	20082E	PARTICIPANT	\N	PRESENT	0
512140	509848	14033T	PARTICIPANT	\N	PRESENT	0
512141	509848	20094J	PARTICIPANT	\N	PRESENT	0
512142	509848	11090Q	PRESIDENT	0	PRESENT	0
512143	509848	20018V	PARTICIPANT	\N	PRESENT	0
512144	509848	19631V	PARTICIPANT	\N	PRESENT	0
512145	509857	20038A	PARTICIPANT	\N	PRESENT	0
512146	509857	19413M	PARTICIPANT	\N	PRESENT	0
512147	509857	17367Q	PARTICIPANT	\N	PRESENT	0
512148	509857	14257W	PARTICIPANT	\N	PRESENT	0
512149	502346	20058E	PARTICIPANT	\N	PRESENT	0
512150	502346	20070A	PARTICIPANT	\N	PRESENT	0
512151	509857	20122U	PARTICIPANT	\N	PRESENT	0
512152	509857	20060X	PARTICIPANT	\N	PRESENT	1
512153	509857	19619A	PARTICIPANT	\N	PRESENT	0
512154	509857	19631V	PARTICIPANT	\N	PRESENT	0
512155	509857	14237S	PARTICIPANT	\N	PRESENT	1
512156	502346	20056C	PARTICIPANT	\N	PRESENT	0
512167	509848	20086J	PARTICIPANT	\N	PRESENT	0
512168	509848	19826F	PARTICIPANT	\N	PRESENT	0
512169	509848	19866P	PARTICIPANT	\N	PRESENT	0
512171	509848	19563B	PARTICIPANT	\N	PRESENT	1
512172	509848	14329V	PARTICIPANT	\N	PRESENT	0
512173	509848	20034V	PARTICIPANT	\N	PRESENT	0
512174	509848	20144B	PARTICIPANT	\N	PRESENT	0
512175	509848	20054A	PARTICIPANT	\N	PRESENT	1
512176	509848	20174H	PARTICIPANT	\N	PRESENT	0
512177	509848	14205J	PARTICIPANT	\N	PRESENT	0
512178	509848	20060X	PARTICIPANT	\N	PRESENT	1
512179	509848	20062A	PARTICIPANT	\N	PRESENT	1
512180	509848	14207L	PARTICIPANT	\N	PRESENT	1
512181	509848	14257W	PARTICIPANT	\N	PRESENT	0
512183	509874	19421M	PARTICIPANT	\N	PRESENT	0
512184	502346	14195A	PARTICIPANT	\N	PRESENT	0
512185	509874	14059S	PARTICIPANT	\N	PRESENT	0
512186	509874	14255U	PARTICIPANT	\N	PRESENT	0
512187	509848	19333N	PARTICIPANT	\N	PRESENT	0
512188	509848	19387D	PARTICIPANT	\N	PRESENT	1
512189	509848	18083K	PARTICIPANT	\N	PRESENT	0
512190	509848	20106U	PARTICIPANT	\N	PRESENT	0
512191	509848	19503N	PARTICIPANT	\N	PRESENT	0
512192	509848	20068G	PARTICIPANT	\N	PRESENT	1
512193	509848	19745F	PARTICIPANT	\N	PRESENT	0
512194	502346	20172F	PARTICIPANT	\N	PRESENT	0
512195	509874	14133K	PRESIDENT	0	PRESENT	0
512196	509874	19583F	PARTICIPANT	\N	PRESENT	0
512197	502346	19531S	PARTICIPANT	\N	PRESENT	0
512198	509874	97011G	PARTICIPANT	\N	PRESENT	0
483609	483243	96004D	PRESIDENT	0	PRESENT	0
483610	483243	14357A	PARTICIPANT	\N	PRESENT	0
483611	483243	14249W	PARTICIPANT	\N	PRESENT	0
483612	483243	11083R	PARTICIPANT	\N	PRESENT	0
483613	483243	14033T	PARTICIPANT	\N	PRESENT	0
483614	483243	19569H	PARTICIPANT	\N	PRESENT	0
483615	483243	04097T	PARTICIPANT	\N	PRESENT	0
483616	483243	11026G	PARTICIPANT	\N	PRESENT	0
483617	483243	08039A	PARTICIPANT	\N	PRESENT	0
483618	483243	14331P	PARTICIPANT	\N	PRESENT	0
483619	483243	10015M	PARTICIPANT	\N	PRESENT	0
483620	483243	98035U	PARTICIPANT	\N	PRESENT	0
483868	479260	19551W	PARTICIPANT	\N	PRESENT	0
483869	479260	11048N	PARTICIPANT	\N	PRESENT	0
483870	479260	02002K	PARTICIPANT	\N	PRESENT	0
483871	479260	17583W	PARTICIPANT	\N	PRESENT	0
483872	479260	01024M	PARTICIPANT	\N	PRESENT	0
483873	479260	19691J	PARTICIPANT	\N	PRESENT	0
483874	479260	92040Q	PARTICIPANT	\N	PRESENT	0
483875	479260	14133K	PARTICIPANT	\N	PRESENT	0
483876	479260	19467C	PARTICIPANT	\N	PRESENT	0
483877	479260	19703U	PARTICIPANT	\N	PRESENT	0
483878	479260	19673G	PARTICIPANT	\N	PRESENT	0
483879	479260	19667J	PARTICIPANT	\N	PRESENT	0
483880	479260	19930E	PARTICIPANT	\N	PRESENT	0
483881	479260	14069U	PARTICIPANT	\N	PRESENT	0
483882	479260	08039A	PARTICIPANT	\N	PRESENT	0
483883	479260	11080N	PARTICIPANT	\N	PRESENT	0
483884	479260	01057W	PARTICIPANT	\N	PRESENT	0
483885	479260	08034U	PARTICIPANT	\N	PRESENT	0
483886	479260	19347U	PARTICIPANT	\N	PRESENT	0
483887	479260	14123H	PARTICIPANT	\N	PRESENT	0
483888	479260	04043D	PARTICIPANT	\N	PRESENT	0
483889	479260	14215L	PARTICIPANT	\N	PRESENT	0
483890	479260	05008E	PARTICIPANT	\N	PRESENT	0
483891	479260	14071N	PARTICIPANT	\N	PRESENT	0
483892	479260	04033B	PARTICIPANT	\N	PRESENT	0
483893	479260	10015M	PARTICIPANT	\N	PRESENT	0
483894	479260	04047H	PARTICIPANT	\N	PRESENT	0
483895	479260	14031R	PARTICIPANT	\N	PRESENT	0
483896	479260	19643A	PARTICIPANT	\N	PRESENT	0
483897	479260	08020N	PARTICIPANT	\N	PRESENT	0
483898	479260	08010L	PARTICIPANT	\N	PRESENT	0
483899	479260	08038Y	PARTICIPANT	\N	PRESENT	0
483900	479260	04042C	PARTICIPANT	\N	PRESENT	0
483901	479260	04092N	PARTICIPANT	\N	PRESENT	0
483902	479260	19591F	PARTICIPANT	\N	PRESENT	0
483903	479260	95030B	PARTICIPANT	\N	PRESENT	0
483904	479260	14026U	PARTICIPANT	\N	PRESENT	0
483905	479260	17637T	PARTICIPANT	\N	PRESENT	0
483906	479260	19762G	PARTICIPANT	\N	PRESENT	0
484133	479193	11070L	PARTICIPANT	\N	PRESENT	0
483908	479260	11090Q	PARTICIPANT	\N	PRESENT	0
483909	479260	14227Q	PARTICIPANT	\N	PRESENT	0
483910	479260	04086Q	PARTICIPANT	\N	PRESENT	0
483911	479260	14331P	PARTICIPANT	\N	PRESENT	0
483912	479260	14193X	PARTICIPANT	\N	PRESENT	0
483913	479260	89017R	PARTICIPANT	\N	PRESENT	0
483915	479260	11026G	PARTICIPANT	\N	PRESENT	0
484134	479193	10015M	PARTICIPANT	\N	PRESENT	0
484135	479193	11065P	PARTICIPANT	\N	PRESENT	0
484136	479193	19697Q	PARTICIPANT	\N	PRESENT	0
484137	479193	19479G	PARTICIPANT	\N	PRESENT	0
484138	479193	14029X	PARTICIPANT	\N	PRESENT	0
484139	479193	97011G	PARTICIPANT	\N	PRESENT	0
484140	479193	19794Q	PARTICIPANT	\N	PRESENT	0
484145	479193	19629C	PARTICIPANT	\N	PRESENT	0
484146	479193	14121F	PARTICIPANT	\N	PRESENT	0
484147	479193	19253P	PARTICIPANT	\N	PRESENT	0
484148	479193	19711U	PARTICIPANT	\N	PRESENT	0
484149	479193	14065Q	PARTICIPANT	\N	PRESENT	0
484150	479193	14085U	PARTICIPANT	\N	PRESENT	0
484151	479193	19593H	PARTICIPANT	\N	PRESENT	0
484152	479193	11040E	PARTICIPANT	\N	PRESENT	0
484153	479193	01028R	PARTICIPANT	\N	PRESENT	0
484154	479193	05008E	PARTICIPANT	\N	PRESENT	0
484155	479193	11077T	PARTICIPANT	\N	PRESENT	0
484156	479193	02002K	PARTICIPANT	\N	PRESENT	0
484157	479193	11048N	PARTICIPANT	\N	PRESENT	0
484158	479193	14331P	PARTICIPANT	\N	PRESENT	0
484165	479193	14063N	PARTICIPANT	\N	PRESENT	0
484178	479193	19599P	PARTICIPANT	\N	PRESENT	0
484179	479193	14219Q	PARTICIPANT	\N	PRESENT	0
484180	479193	19693L	PARTICIPANT	\N	PRESENT	0
484181	479193	19413M	PARTICIPANT	\N	PRESENT	0
484182	479193	04018C	PARTICIPANT	\N	PRESENT	0
484183	479193	14147R	PARTICIPANT	\N	PRESENT	0
484184	479193	14030Q	PARTICIPANT	\N	PRESENT	0
484185	479193	19441R	PARTICIPANT	\N	PRESENT	0
484186	479193	19762G	PARTICIPANT	\N	PRESENT	0
484187	479193	19349W	PARTICIPANT	\N	PRESENT	0
484188	479193	19914E	PARTICIPANT	\N	PRESENT	0
484189	479193	18083K	PARTICIPANT	\N	PRESENT	0
484190	479193	19399H	PARTICIPANT	\N	PRESENT	0
484211	479193	04086Q	PARTICIPANT	\N	PRESENT	0
484212	479193	14069U	PARTICIPANT	\N	PRESENT	0
484213	479193	01024M	PARTICIPANT	\N	PRESENT	0
484214	479193	11012A	PARTICIPANT	\N	PRESENT	0
484254	479195	19349W	PARTICIPANT	\N	PRESENT	0
484255	479195	19253P	PARTICIPANT	\N	PRESENT	0
484256	479195	19543W	PARTICIPANT	\N	PRESENT	0
484257	479195	08011M	PARTICIPANT	\N	PRESENT	0
484258	479195	14197C	PARTICIPANT	\N	PRESENT	0
484259	479195	14085U	PARTICIPANT	\N	PRESENT	0
484261	479195	19441R	PARTICIPANT	\N	PRESENT	0
484263	479195	19479G	PARTICIPANT	\N	PRESENT	0
484264	479195	19369B	PARTICIPANT	\N	PRESENT	0
484265	479195	14030Q	PARTICIPANT	\N	PRESENT	0
484266	479195	01024M	PARTICIPANT	\N	PRESENT	0
484267	479195	11012A	PARTICIPANT	\N	PRESENT	0
484268	479195	19563B	PARTICIPANT	\N	PRESENT	0
484269	479195	19629C	PARTICIPANT	\N	PRESENT	0
484270	479195	19914E	PARTICIPANT	\N	PRESENT	0
484271	479195	19762G	PARTICIPANT	\N	PRESENT	0
484272	479195	14147R	PARTICIPANT	\N	PRESENT	0
484273	479195	17583W	PARTICIPANT	\N	PRESENT	0
484274	479195	19399H	PARTICIPANT	\N	PRESENT	0
484275	479195	07029T	PARTICIPANT	\N	PRESENT	0
484276	479195	14121F	PARTICIPANT	\N	PRESENT	0
484277	479195	19507S	PARTICIPANT	\N	PRESENT	0
484278	479195	19794Q	PARTICIPANT	\N	PRESENT	0
484279	479195	10015M	PARTICIPANT	\N	PRESENT	0
484280	479195	04086Q	PARTICIPANT	\N	PRESENT	0
484281	479195	14069U	PARTICIPANT	\N	PRESENT	0
484282	479195	14029X	PARTICIPANT	\N	PRESENT	0
484283	479195	19447X	PARTICIPANT	\N	PRESENT	0
484284	479195	11040E	PARTICIPANT	\N	PRESENT	0
484285	479195	19711U	PARTICIPANT	\N	PRESENT	0
484286	479195	19701S	PARTICIPANT	\N	PRESENT	0
484287	479195	14331P	PARTICIPANT	\N	PRESENT	0
484288	479195	04018C	PARTICIPANT	\N	PRESENT	0
484289	479195	96004D	PARTICIPANT	\N	PRESENT	0
484290	479195	19531S	PARTICIPANT	\N	PRESENT	0
484291	479195	08039A	PARTICIPANT	\N	PRESENT	0
484292	479195	14083S	PARTICIPANT	\N	PRESENT	0
484252	479195	11070L	PARTICIPANT	\N	PRESENT	0
484253	479195	19697Q	PARTICIPANT	\N	PRESENT	0
484293	479195	19631V	PARTICIPANT	\N	PRESENT	0
484294	479195	11083R	PARTICIPANT	\N	PRESENT	0
484295	479195	04057K	PARTICIPANT	\N	PRESENT	0
501587	495438	99004R	PARTICIPANT	\N	PRESENT	0
501588	495438	20044X	PARTICIPANT	\N	EXCUSE	0
501589	495438	19651A	PARTICIPANT	\N	PRESENT	0
501590	495438	19543W	PARTICIPANT	\N	PRESENT	0
501591	495438	20132W	PARTICIPANT	\N	PRESENT	0
501592	495438	19747H	PARTICIPANT	\N	PRESENT	0
501593	495438	19725B	PARTICIPANT	\N	PRESENT	0
501626	500501	01025N	PARTICIPANT	\N	PRESENT	0
501627	500501	14033T	PARTICIPANT	\N	PRESENT	0
501630	500501	20144B	PARTICIPANT	\N	PRESENT	0
501663	500502	19631V	PARTICIPANT	\N	PRESENT	0
501664	500502	20024T	PARTICIPANT	\N	PRESENT	0
501665	500502	20022R	PARTICIPANT	\N	PRESENT	0
501666	500502	19251M	PARTICIPANT	\N	PRESENT	0
501667	500502	20038A	PARTICIPANT	\N	PRESENT	0
501668	500502	19820Y	PARTICIPANT	\N	PRESENT	0
501669	500502	20068G	PARTICIPANT	\N	PRESENT	0
501670	500502	14031R	PARTICIPANT	\N	PRESENT	0
501671	500502	19826F	PARTICIPANT	\N	PRESENT	0
501672	500502	17637T	PARTICIPANT	\N	PRESENT	0
501673	500502	20122U	PARTICIPANT	\N	PRESENT	0
501674	500502	20030R	PARTICIPANT	\N	PRESENT	0
503110	503109	14053L	PARTICIPANT	\N	PRESENT	0
503111	503109	19749K	PARTICIPANT	\N	PRESENT	0
503113	503112	14053L	PARTICIPANT	\N	PRESENT	0
503114	503112	19749K	PARTICIPANT	\N	PRESENT	0
503128	503127	20080C	PARTICIPANT	\N	PRESENT	0
503130	503129	20080C	PARTICIPANT	\N	PRESENT	0
510797	509898	95063L	PARTICIPANT	\N	PRESENT	1
510798	509898	14107H	PARTICIPANT	\N	PRESENT	1
510799	509898	19749K	PARTICIPANT	\N	PRESENT	1
510958	509964	19647E	PARTICIPANT	\N	PRESENT	1
510959	509964	19479G	PARTICIPANT	\N	PRESENT	1
511113	509563	14053L	PARTICIPANT	\N	PRESENT	0
511114	509563	14231L	PARTICIPANT	\N	PRESENT	0
510795	509898	11056N	PARTICIPANT	\N	PRESENT	1
510796	509898	19489J	PARTICIPANT	\N	PRESENT	1
511116	509563	17737W	PARTICIPANT	\N	PRESENT	0
511117	502343	19866P	PARTICIPANT	\N	PRESENT	0
511118	502343	19563B	PARTICIPANT	\N	PRESENT	0
511119	502343	14195A	PARTICIPANT	\N	PRESENT	0
511120	502343	19413M	PARTICIPANT	\N	PRESENT	0
511121	502343	19631V	PARTICIPANT	\N	PRESENT	0
511122	502343	20052X	PARTICIPANT	\N	PRESENT	0
511123	502343	19369B	PARTICIPANT	\N	PRESENT	0
511124	502343	19441R	PARTICIPANT	\N	PRESENT	0
511125	502343	14327T	PARTICIPANT	\N	PRESENT	0
511126	502343	20138D	PARTICIPANT	\N	PRESENT	0
511127	502343	19735D	PARTICIPANT	\N	PRESENT	0
511128	502343	19739H	PARTICIPANT	\N	PRESENT	0
511129	502343	04057K	PARTICIPANT	\N	PRESENT	0
511130	502343	01034P	PARTICIPANT	\N	PRESENT	0
511131	502343	14217N	PARTICIPANT	\N	PRESENT	0
511132	502343	19715Y	PARTICIPANT	\N	PRESENT	0
511133	502343	19551W	PARTICIPANT	\N	PRESENT	0
511134	502343	14026U	PARTICIPANT	\N	PRESENT	0
511135	502343	19826F	PARTICIPANT	\N	PRESENT	0
511136	502343	19703U	PARTICIPANT	\N	PRESENT	0
511137	502343	14357A	PARTICIPANT	\N	PRESENT	0
511138	502343	14030Q	PARTICIPANT	\N	PRESENT	0
511139	502343	19685L	PARTICIPANT	\N	PRESENT	0
511140	502343	20020P	PARTICIPANT	\N	PRESENT	0
511141	502343	20126Y	PARTICIPANT	\N	PRESENT	0
511142	502343	08034U	PARTICIPANT	\N	PRESENT	0
511143	502343	20120S	PARTICIPANT	\N	PRESENT	0
511144	502343	19383Y	PARTICIPANT	\N	PRESENT	0
511145	502343	14189C	PARTICIPANT	\N	PRESENT	0
511146	509563	01028R	PARTICIPANT	\N	PRESENT	0
511147	502343	19533U	PARTICIPANT	\N	PRESENT	0
511148	502343	20054A	PARTICIPANT	\N	PRESENT	0
511149	502343	19671E	PARTICIPANT	\N	PRESENT	0
511150	502343	19599P	PARTICIPANT	\N	PRESENT	0
511151	502343	14133K	PARTICIPANT	\N	PRESENT	0
511152	502343	20124W	PARTICIPANT	\N	PRESENT	0
511153	502343	20062A	PARTICIPANT	\N	PRESENT	0
511154	502343	14059S	PARTICIPANT	\N	PRESENT	0
511155	502343	99004R	PARTICIPANT	\N	PRESENT	0
511156	502343	11099A	PARTICIPANT	\N	PRESENT	0
511157	502343	14107H	PARTICIPANT	\N	PRESENT	0
511158	502343	20072C	PARTICIPANT	\N	PRESENT	0
511159	502343	05012A	PARTICIPANT	\N	PRESENT	0
511160	502343	14069U	PARTICIPANT	\N	PRESENT	0
511161	502343	20136B	PARTICIPANT	\N	PRESENT	0
511162	502343	18083K	PARTICIPANT	\N	PRESENT	0
511163	502343	11103C	PARTICIPANT	\N	PRESENT	0
511164	502343	08028W	PARTICIPANT	\N	PRESENT	0
511165	502343	11101A	PARTICIPANT	\N	PRESENT	0
511166	502343	14169X	PARTICIPANT	\N	PRESENT	0
511167	502343	19701S	PARTICIPANT	\N	PRESENT	0
511168	502343	11067R	PARTICIPANT	\N	PRESENT	0
511169	502343	11048N	PARTICIPANT	\N	PRESENT	0
511170	502343	19747H	PARTICIPANT	\N	PRESENT	0
511171	502343	20102Q	PARTICIPANT	\N	PRESENT	0
511172	502343	20040T	PARTICIPANT	\N	PRESENT	0
511173	502343	19479G	PARTICIPANT	\N	PRESENT	0
511174	502343	19693L	PARTICIPANT	\N	PRESENT	0
511175	509563	14069U	PARTICIPANT	\N	PRESENT	0
511176	502343	20144B	PARTICIPANT	\N	PRESENT	0
511177	502343	19349W	PARTICIPANT	\N	PRESENT	0
511178	502343	14042U	PARTICIPANT	\N	PRESENT	0
511179	502343	04045F	PARTICIPANT	\N	PRESENT	0
511180	502343	14083S	PARTICIPANT	\N	PRESENT	0
511182	509563	19447X	PARTICIPANT	\N	PRESENT	0
511183	509563	18083K	PARTICIPANT	\N	PRESENT	0
511184	509563	05012A	PARTICIPANT	\N	PRESENT	0
511185	509563	19489J	PARTICIPANT	\N	PRESENT	0
511186	509563	20022R	PARTICIPANT	\N	PRESENT	0
511187	502343	14249W	PARTICIPANT	\N	PRESENT	0
511188	502343	20106U	PARTICIPANT	\N	PRESENT	0
511189	502343	19577H	PARTICIPANT	\N	PRESENT	0
511190	502343	14219Q	PARTICIPANT	\N	PRESENT	0
511191	502343	19691J	PARTICIPANT	\N	PRESENT	0
511192	502343	01024M	PARTICIPANT	\N	PRESENT	0
511193	509563	14281W	PARTICIPANT	\N	PRESENT	0
511194	509563	19735D	PARTICIPANT	\N	PRESENT	0
511195	502343	14331P	PARTICIPANT	\N	PRESENT	0
511196	502343	20140W	PARTICIPANT	\N	PRESENT	0
511198	502343	20128B	PARTICIPANT	\N	PRESENT	0
511201	502343	11097X	PARTICIPANT	\N	PRESENT	0
511205	502343	12016W	PARTICIPANT	\N	PRESENT	0
511206	502343	11109J	PARTICIPANT	\N	PRESENT	0
511208	511207	14109K	PARTICIPANT	\N	PRESENT	1
511209	511207	08017T	PARTICIPANT	\N	PRESENT	1
511210	511207	19593H	PARTICIPANT	\N	PRESENT	0
511211	511207	19735D	PARTICIPANT	\N	PRESENT	1
511212	511207	19621T	PARTICIPANT	\N	PRESENT	1
511213	511207	04070G	PARTICIPANT	\N	PRESENT	1
511215	511214	04070G	PARTICIPANT	\N	PRESENT	0
511216	511214	19621T	PARTICIPANT	\N	PRESENT	0
511217	511214	14109K	PARTICIPANT	\N	PRESENT	0
511218	511214	19735D	PARTICIPANT	\N	PRESENT	0
511219	511214	19593H	PARTICIPANT	\N	PRESENT	0
511220	511214	08017T	PARTICIPANT	\N	PRESENT	0
511222	502343	20112S	PARTICIPANT	\N	PRESENT	0
511223	511221	04070G	PARTICIPANT	\N	PRESENT	0
511224	502343	19657G	PARTICIPANT	\N	PRESENT	0
511225	502343	14225N	PARTICIPANT	\N	PRESENT	0
511226	502343	14213J	PARTICIPANT	\N	PRESENT	0
511227	502343	19749K	PARTICIPANT	\N	PRESENT	0
511228	502343	11053K	PARTICIPANT	\N	PRESENT	0
511230	511229	01048V	PARTICIPANT	\N	PRESENT	0
511232	511231	01048V	PARTICIPANT	\N	PRESENT	0
511233	502343	19527W	PARTICIPANT	\N	PRESENT	0
511234	509563	19543W	PARTICIPANT	\N	PRESENT	0
511235	502343	19575F	PARTICIPANT	\N	PRESENT	0
511236	502343	19629C	PARTICIPANT	\N	PRESENT	0
511237	502343	14111D	PARTICIPANT	\N	PRESENT	0
511238	502343	14187A	PARTICIPANT	\N	PRESENT	0
511239	502343	14147R	PARTICIPANT	\N	PRESENT	0
511240	502343	11077T	PARTICIPANT	\N	PRESENT	0
511241	502343	19713W	PARTICIPANT	\N	PRESENT	0
511243	511011	14053L	PARTICIPANT	\N	PRESENT	0
511244	511011	19954N	PARTICIPANT	\N	PRESENT	0
511245	511011	17737W	PARTICIPANT	\N	PRESENT	0
511246	511011	14179A	PARTICIPANT	\N	PRESENT	0
511247	511011	14147R	PARTICIPANT	\N	PRESENT	0
511248	511011	14215L	PARTICIPANT	\N	PRESENT	0
511249	511011	04047H	PRESIDENT	0	PRESENT	0
511250	511011	19749K	PARTICIPANT	\N	PRESENT	0
511251	511011	19673G	PARTICIPANT	\N	PRESENT	0
511252	511011	19447X	PARTICIPANT	\N	PRESENT	0
511253	502343	14281W	PARTICIPANT	\N	PRESENT	0
511254	511011	14231L	PARTICIPANT	\N	PRESENT	0
511255	511011	11072N	PARTICIPANT	\N	PRESENT	0
511257	511256	14205J	PARTICIPANT	\N	PRESENT	0
511259	511258	20060X	PARTICIPANT	\N	PRESENT	0
511260	511258	14205J	PARTICIPANT	\N	PRESENT	0
511264	502343	19768N	PARTICIPANT	\N	PRESENT	0
511265	511011	10015M	PARTICIPANT	\N	PRESENT	0
511266	511011	19543W	PARTICIPANT	\N	PRESENT	0
511267	511011	05008E	PARTICIPANT	\N	PRESENT	0
511268	511011	14151M	PARTICIPANT	\N	PRESENT	0
511269	502343	20088L	PARTICIPANT	\N	PRESENT	0
511270	502343	14031R	PARTICIPANT	\N	PRESENT	0
511271	502343	19729F	PARTICIPANT	\N	PRESENT	0
511272	502343	14121F	PARTICIPANT	\N	PRESENT	0
511273	511011	04008A	PARTICIPANT	\N	PRESENT	0
511276	502343	19301E	PARTICIPANT	\N	PRESENT	0
511277	502343	10006L	PARTICIPANT	\N	PRESENT	0
511282	511011	08018U	PARTICIPANT	\N	PRESENT	0
511285	502343	20116W	PARTICIPANT	\N	PRESENT	0
511288	502343	19954N	PARTICIPANT	\N	PRESENT	0
484484	483229	04040A	PARTICIPANT	\N	PRESENT	0
484486	483229	08058D	PARTICIPANT	\N	PRESENT	0
484487	483229	14255U	PARTICIPANT	\N	PRESENT	0
484488	483229	04042C	PRESIDENT	0	PRESENT	0
484489	483229	98029W	PARTICIPANT	\N	PRESENT	0
484491	483229	14267Y	PARTICIPANT	\N	PRESENT	0
484492	483229	98018T	PARTICIPANT	\N	PRESENT	0
484493	483229	95037J	PARTICIPANT	\N	PRESENT	0
484494	483229	12041X	PARTICIPANT	\N	PRESENT	0
484495	483229	19709B	PARTICIPANT	\N	PRESENT	0
484496	483229	16685X	PARTICIPANT	\N	PRESENT	0
484497	483229	14193X	PARTICIPANT	\N	PRESENT	0
484498	483229	01058X	PARTICIPANT	\N	PRESENT	0
484499	483229	11066Q	PARTICIPANT	\N	PRESENT	0
484500	483229	95067Q	PARTICIPANT	\N	PRESENT	0
484501	483229	14079W	PARTICIPANT	\N	EXCUSE	0
484502	483229	98050T	PARTICIPANT	\N	EXCUSE	0
484503	483229	14235Q	PARTICIPANT	\N	EXCUSE	0
484504	483229	08049C	PARTICIPANT	\N	EXCUSE	0
487228	485907	14327T	PARTICIPANT	\N	EXCUSE	0
487482	485542	19581D	PARTICIPANT	\N	EXCUSE	0
487483	485540	19581D	PARTICIPANT	\N	EXCUSE	0
492089	491474	20086J	PARTICIPANT	\N	PRESENT	0
492090	491474	19383Y	PARTICIPANT	\N	PRESENT	0
492091	491474	20088L	PARTICIPANT	\N	PRESENT	0
492092	491474	19768N	PARTICIPANT	\N	PRESENT	0
492093	491474	19515S	PARTICIPANT	\N	PRESENT	0
492094	491474	20092G	PARTICIPANT	\N	PRESENT	0
492095	491474	01043Q	PARTICIPANT	\N	PRESENT	0
492096	491474	14357A	PARTICIPANT	\N	PRESENT	0
492097	491474	20078J	PARTICIPANT	\N	PRESENT	0
492098	491474	19413M	PARTICIPANT	\N	PRESENT	0
492099	491474	20082E	PARTICIPANT	\N	PRESENT	0
492100	491474	20094J	PARTICIPANT	\N	PRESENT	0
492101	491474	04045F	PARTICIPANT	\N	PRESENT	0
492102	491474	20104S	PARTICIPANT	\N	PRESENT	0
492103	491474	19631V	PARTICIPANT	\N	PRESENT	0
492104	491474	11099A	PARTICIPANT	\N	PRESENT	0
492105	491474	19575F	PARTICIPANT	\N	PRESENT	0
492106	491474	20018V	PARTICIPANT	\N	PRESENT	0
492107	491474	19563B	PARTICIPANT	\N	PRESENT	0
492108	491474	14329V	PARTICIPANT	\N	PRESENT	0
492109	491474	19467C	PARTICIPANT	\N	PRESENT	0
492110	491474	20034V	PARTICIPANT	\N	PRESENT	0
492111	491474	14187A	PARTICIPANT	\N	PRESENT	0
492112	491474	19695N	PARTICIPANT	\N	PRESENT	0
492113	491474	11090Q	PRESIDENT	0	PRESENT	0
492114	491474	01025N	PARTICIPANT	\N	PRESENT	0
492115	491474	14033T	PARTICIPANT	\N	PRESENT	0
492116	491474	20054A	PARTICIPANT	\N	PRESENT	0
492117	491474	14205J	PARTICIPANT	\N	PRESENT	0
492118	491474	19507S	PARTICIPANT	\N	PRESENT	0
492119	491474	14207L	PARTICIPANT	\N	PRESENT	0
492120	491474	14257W	PARTICIPANT	\N	PRESENT	0
492121	491488	14147R	PARTICIPANT	\N	PRESENT	0
492122	491488	19673G	PARTICIPANT	\N	PRESENT	0
492123	491488	19447X	PARTICIPANT	\N	PRESENT	0
492147	491510	20090E	PARTICIPANT	\N	PRESENT	0
492148	491510	04092N	PARTICIPANT	0	PRESENT	0
492149	491510	19713W	PARTICIPANT	\N	PRESENT	0
492150	491510	11097X	PARTICIPANT	\N	PRESENT	0
492152	491510	20040T	PARTICIPANT	\N	PRESENT	0
492153	491510	19301E	PARTICIPANT	\N	PRESENT	0
492154	491510	19691J	PARTICIPANT	\N	PRESENT	0
492155	491510	14223L	PARTICIPANT	\N	PRESENT	0
492156	491510	17779H	PARTICIPANT	\N	PRESENT	0
492324	491472	14083S	PARTICIPANT	\N	PRESENT	0
492158	491510	19703U	PARTICIPANT	\N	PRESENT	0
492159	491510	11031D	PARTICIPANT	\N	PRESENT	0
492160	491510	19553Y	PARTICIPANT	\N	PRESENT	0
492161	491510	20066E	PARTICIPANT	\N	PRESENT	0
492162	491510	19679N	PARTICIPANT	\N	PRESENT	0
492163	491510	14042U	PARTICIPANT	\N	PRESENT	0
492325	491472	19349W	PARTICIPANT	\N	PRESENT	0
492165	491510	14213J	PARTICIPANT	\N	PRESENT	0
492166	491510	19367Y	PARTICIPANT	\N	PRESENT	0
492167	491510	19657G	PARTICIPANT	\N	PRESENT	0
492168	491510	04043D	PARTICIPANT	\N	PRESENT	0
492169	491510	10006L	PRESIDENT	0	PRESENT	0
492287	491488	20108W	PARTICIPANT	\N	PRESENT	0
492288	491510	08045X	PARTICIPANT	\N	PRESENT	0
492326	491472	12016W	PARTICIPANT	\N	PRESENT	0
492327	491472	19671E	PARTICIPANT	\N	PRESENT	0
492328	491472	99004R	PARTICIPANT	\N	PRESENT	0
492433	491261	19551W	PARTICIPANT	\N	EXCUSE	0
493348	493347	01043Q	PARTICIPANT	\N	PRESENT	0
493349	493347	19631V	PARTICIPANT	\N	PRESENT	0
493351	493350	01043Q	PARTICIPANT	\N	PRESENT	0
493352	493350	19631V	PARTICIPANT	\N	PRESENT	0
495255	495254	14187A	PARTICIPANT	\N	PRESENT	0
495256	495254	11077T	PARTICIPANT	\N	PRESENT	0
495257	495254	19631V	PARTICIPANT	\N	PRESENT	0
495258	495254	01043Q	PARTICIPANT	\N	PRESENT	0
495260	495259	01043Q	PARTICIPANT	\N	PRESENT	0
495261	495259	11077T	PARTICIPANT	\N	PRESENT	0
495262	495259	19631V	PARTICIPANT	\N	PRESENT	0
495263	495259	14187A	PARTICIPANT	\N	PRESENT	0
495270	495264	14187A	PARTICIPANT	\N	PRESENT	0
495271	495264	19631V	PARTICIPANT	\N	PRESENT	0
495272	495264	01043Q	PARTICIPANT	\N	PRESENT	0
495274	495273	11077T	PARTICIPANT	\N	PRESENT	0
495275	495273	14187A	PARTICIPANT	\N	PRESENT	0
495276	495273	01043Q	PARTICIPANT	\N	PRESENT	0
495277	495273	19631V	PARTICIPANT	\N	PRESENT	0
495777	495678	14030Q	PARTICIPANT	\N	PRESENT	0
498883	497011	11074Q	PARTICIPANT	\N	PRESENT	0
498884	497011	01057W	PARTICIPANT	\N	PRESENT	0
498885	497011	01048V	PARTICIPANT	\N	PRESENT	0
498886	497011	20050V	PARTICIPANT	\N	PRESENT	0
500392	497255	20038A	PARTICIPANT	\N	PRESENT	0
500393	497255	11045K	PARTICIPANT	\N	PRESENT	0
500394	497255	11085T	PARTICIPANT	\N	PRESENT	0
500395	497255	14259Y	PARTICIPANT	\N	PRESENT	0
500396	497255	01048V	PARTICIPANT	\N	PRESENT	0
504684	502289	11033F	PARTICIPANT	\N	PRESENT	1
504685	502289	14259Y	PARTICIPANT	\N	PRESENT	0
504686	502289	20074E	PARTICIPANT	\N	PRESENT	1
504687	502289	14151M	PARTICIPANT	\N	PRESENT	1
504688	502289	14179A	PARTICIPANT	\N	PRESENT	1
504689	502289	19649G	PARTICIPANT	\N	PRESENT	1
504690	502289	14111D	PARTICIPANT	\N	PRESENT	0
504691	502289	14107H	PARTICIPANT	\N	PRESENT	1
505298	502450	20070A	PARTICIPANT	\N	PRESENT	0
505299	502450	19349W	PARTICIPANT	\N	PRESENT	0
505300	502450	19741B	PARTICIPANT	\N	PRESENT	0
505301	502450	14121F	PARTICIPANT	\N	PRESENT	0
505302	502450	99004R	PARTICIPANT	\N	PRESENT	0
505303	502450	19335Q	PARTICIPANT	\N	PRESENT	0
505304	502450	20126Y	PARTICIPANT	\N	PRESENT	0
505306	501821	20042V	PARTICIPANT	\N	PRESENT	0
505308	501821	20132W	PARTICIPANT	\N	PRESENT	0
505310	501821	19549D	PARTICIPANT	\N	PRESENT	0
505314	501821	14219Q	PARTICIPANT	\N	PRESENT	0
505316	501821	14189C	PARTICIPANT	\N	PRESENT	0
505317	501821	01024M	PARTICIPANT	\N	PRESENT	0
498881	497011	19447X	PARTICIPANT	\N	PRESENT	0
505318	501821	11056N	PARTICIPANT	\N	PRESENT	0
505319	502450	11048N	PARTICIPANT	\N	PRESENT	0
505320	502450	08010L	PARTICIPANT	\N	PRESENT	0
505321	501779	19768N	PARTICIPANT	\N	PRESENT	0
505322	501779	20092G	PARTICIPANT	\N	PRESENT	0
505323	501779	14357A	PARTICIPANT	\N	PRESENT	0
505324	501779	19441R	PARTICIPANT	\N	PRESENT	0
505325	501779	19413M	PARTICIPANT	\N	PRESENT	0
505326	501779	04045F	PARTICIPANT	\N	PRESENT	0
505327	501779	19631V	PARTICIPANT	\N	PRESENT	1
505328	501779	11099A	PARTICIPANT	\N	PRESENT	0
505329	501779	08015R	PARTICIPANT	\N	PRESENT	0
505330	501779	19369B	PARTICIPANT	\N	PRESENT	0
505331	501779	20018V	PARTICIPANT	\N	PRESENT	0
505332	501779	19511N	PARTICIPANT	\N	PRESENT	0
505333	501779	19563B	PARTICIPANT	\N	PRESENT	0
498882	497011	11040E	PARTICIPANT	\N	PRESENT	0
505334	501779	20028X	PARTICIPANT	\N	PRESENT	0
505335	501779	20030R	PARTICIPANT	\N	PRESENT	0
505336	501779	14038Y	PARTICIPANT	\N	PRESENT	0
505337	501779	19467C	PARTICIPANT	\N	PRESENT	0
505338	501779	20034V	PARTICIPANT	\N	PRESENT	0
505339	501779	19531S	PARTICIPANT	\N	PRESENT	0
505340	501779	20144B	PARTICIPANT	\N	PRESENT	0
507762	505963	19333N	PARTICIPANT	\N	PRESENT	0
507763	505963	20032T	PARTICIPANT	\N	PRESENT	0
507764	505963	14031R	PARTICIPANT	\N	PRESENT	0
507765	505963	20038A	PARTICIPANT	\N	PRESENT	0
507766	505963	20076G	PARTICIPANT	\N	PRESENT	0
507767	505963	19820Y	PARTICIPANT	\N	PRESENT	0
507768	505963	14219Q	PRESIDENT	0	PRESENT	0
507769	505963	19826F	PARTICIPANT	\N	PRESENT	0
507770	505963	20046A	PARTICIPANT	\N	PRESENT	0
507771	505963	14221J	PARTICIPANT	\N	PRESENT	0
507772	505963	20102Q	PARTICIPANT	\N	PRESENT	0
507773	505963	19599P	PARTICIPANT	\N	PRESENT	0
507774	505963	19637C	PARTICIPANT	\N	PRESENT	0
507775	505963	14169X	PARTICIPANT	\N	PRESENT	0
507776	505963	14237S	PARTICIPANT	\N	PRESENT	0
507777	505963	11101A	PARTICIPANT	\N	PRESENT	0
507778	505963	19503N	PARTICIPANT	\N	PRESENT	0
507779	505963	17367Q	PARTICIPANT	\N	PRESENT	0
507780	505963	20024T	PARTICIPANT	\N	PRESENT	0
507781	505963	19619A	PARTICIPANT	\N	PRESENT	0
507782	505963	20020P	PARTICIPANT	\N	PRESENT	1
507783	505963	05012A	PARTICIPANT	\N	PRESENT	0
507784	505963	08060W	PARTICIPANT	\N	PRESENT	1
507785	505963	20140W	PARTICIPANT	\N	PRESENT	1
507786	505963	19387D	PARTICIPANT	\N	PRESENT	1
507787	505963	17637T	PARTICIPANT	\N	PRESENT	1
507788	505963	19251M	PARTICIPANT	\N	PRESENT	1
507789	505963	14327T	PARTICIPANT	\N	PRESENT	0
507790	505963	19685L	PARTICIPANT	\N	PRESENT	0
507791	505798	19649G	PARTICIPANT	\N	PRESENT	0
507792	505798	11026G	PARTICIPANT	\N	PRESENT	0
507793	505798	01028R	PARTICIPANT	\N	PRESENT	0
507794	505798	04085P	PARTICIPANT	\N	PRESENT	0
507795	505798	20108W	PARTICIPANT	\N	PRESENT	0
507796	505798	14179A	PARTICIPANT	\N	PRESENT	0
507797	505963	20118Y	PARTICIPANT	\N	PRESENT	0
507798	505963	19739H	PARTICIPANT	\N	PRESENT	1
507952	507831	14030Q	PARTICIPANT	\N	PRESENT	1
507953	507831	20132W	PARTICIPANT	\N	PRESENT	0
507954	506005	14249W	PARTICIPANT	\N	PRESENT	0
507955	506005	98022P	PARTICIPANT	\N	PRESENT	0
507956	505804	20086J	PARTICIPANT	\N	PRESENT	0
507959	505804	20028X	PARTICIPANT	\N	PRESENT	1
507960	505804	20174H	PARTICIPANT	\N	PRESENT	1
507961	505798	11056N	PARTICIPANT	\N	PRESENT	0
507962	507831	20134Y	PARTICIPANT	\N	PRESENT	1
508204	508189	14331P	PARTICIPANT	\N	PRESENT	0
507965	502321	11070L	PARTICIPANT	\N	PRESENT	0
507966	506005	14193X	PARTICIPANT	\N	PRESENT	1
507968	505804	08015R	PARTICIPANT	\N	PRESENT	1
507970	502321	11048N	PARTICIPANT	\N	PRESENT	0
507971	502321	19515S	PARTICIPANT	\N	PRESENT	0
507972	502321	04086Q	PARTICIPANT	\N	PRESENT	0
507973	502321	19671E	PARTICIPANT	\N	PRESENT	0
508191	508189	08034U	PARTICIPANT	\N	PRESENT	0
508192	508189	19531S	PARTICIPANT	\N	PRESENT	0
508193	508189	11053K	PARTICIPANT	\N	PRESENT	0
508194	508189	11074Q	PARTICIPANT	\N	PRESENT	0
508195	508189	08011M	PARTICIPANT	\N	PRESENT	0
508196	508189	20044X	PARTICIPANT	\N	PRESENT	0
508197	508189	19671E	PARTICIPANT	\N	PRESENT	0
508198	508189	04086Q	PARTICIPANT	\N	PRESENT	0
508199	508189	11040E	PARTICIPANT	\N	PRESENT	0
508200	508189	08009T	PARTICIPANT	\N	PRESENT	0
508201	508189	19349W	PARTICIPANT	\N	PRESENT	0
508202	508189	99004R	PARTICIPANT	\N	PRESENT	0
508203	508189	19762G	PARTICIPANT	\N	PRESENT	0
508205	508189	04071H	PARTICIPANT	\N	PRESENT	0
508206	508189	19711U	PARTICIPANT	\N	PRESENT	0
508207	508189	01057W	PARTICIPANT	\N	PRESENT	0
508208	508189	20080C	PARTICIPANT	\N	PRESENT	0
508209	508189	20116W	PARTICIPANT	\N	PRESENT	0
508210	502340	19569H	PARTICIPANT	\N	PRESENT	0
508211	502340	19629C	PARTICIPANT	\N	PRESENT	0
508212	502340	20028X	PARTICIPANT	\N	PRESENT	0
508213	502340	11041F	PARTICIPANT	\N	PRESENT	0
508214	502340	20090E	PARTICIPANT	\N	PRESENT	0
508215	502340	20032T	PARTICIPANT	\N	PRESENT	0
508216	508189	19545Y	PARTICIPANT	\N	PRESENT	0
508217	508189	14225N	PRESIDENT	0	PRESENT	0
508218	508189	08010L	PARTICIPANT	\N	PRESENT	0
508219	508189	11048N	PARTICIPANT	\N	PRESENT	0
508220	508189	19647E	PARTICIPANT	\N	PRESENT	0
508221	508189	14189C	PARTICIPANT	\N	PRESENT	0
508222	508189	19689Q	PARTICIPANT	\N	PRESENT	0
508223	508189	20070A	PARTICIPANT	\N	PRESENT	0
508224	502340	14231L	PARTICIPANT	\N	PRESENT	0
508225	502340	20106U	PARTICIPANT	\N	PRESENT	0
508226	502340	20056C	PARTICIPANT	\N	PRESENT	0
508227	502340	19525U	PARTICIPANT	\N	PRESENT	0
508228	502340	20052X	PARTICIPANT	\N	PRESENT	0
508229	502340	98022P	PARTICIPANT	\N	PRESENT	0
508230	502340	04085P	PARTICIPANT	\N	PRESENT	0
508231	502340	19565D	PARTICIPANT	\N	PRESENT	0
508232	502340	20102Q	PARTICIPANT	\N	PRESENT	0
508233	502340	20024T	PARTICIPANT	\N	PRESENT	0
508234	502340	19695N	PARTICIPANT	\N	PRESENT	0
508235	502340	20072C	PARTICIPANT	\N	PRESENT	0
508236	502340	20172F	PARTICIPANT	\N	PRESENT	0
508237	502340	20136B	PARTICIPANT	\N	PRESENT	0
508238	502340	19729F	PARTICIPANT	\N	PRESENT	0
508239	502340	19413M	PARTICIPANT	\N	PRESENT	0
508240	502340	14123H	PARTICIPANT	\N	PRESENT	0
508241	502340	11101A	PARTICIPANT	\N	PRESENT	0
508242	502340	19527W	PARTICIPANT	\N	PRESENT	0
508243	502340	14053L	PARTICIPANT	\N	PRESENT	0
508244	502340	14275Y	PARTICIPANT	\N	PRESENT	0
508245	502340	19593H	PARTICIPANT	\N	PRESENT	0
508246	502340	20030R	PARTICIPANT	\N	PRESENT	0
508247	502340	20088L	PARTICIPANT	\N	PRESENT	0
508248	502340	18193Q	PARTICIPANT	\N	PRESENT	0
508249	502340	14207L	PARTICIPANT	\N	PRESENT	0
508250	502340	17229F	PARTICIPANT	\N	PRESENT	0
508251	502340	20068G	PARTICIPANT	\N	PRESENT	0
508252	502340	20086J	PARTICIPANT	\N	PRESENT	0
508253	502340	14223L	PARTICIPANT	\N	PRESENT	0
508254	502340	14217N	PARTICIPANT	\N	PRESENT	0
508255	502340	11103C	PARTICIPANT	\N	PRESENT	0
508256	502340	14030Q	PARTICIPANT	\N	PRESENT	0
508257	502340	14147R	PARTICIPANT	\N	PRESENT	0
508258	502340	11080N	PARTICIPANT	\N	PRESENT	0
508259	502340	20138D	PARTICIPANT	\N	PRESENT	0
508260	502340	19673G	PARTICIPANT	\N	PRESENT	0
508261	502340	20082E	PARTICIPANT	\N	PRESENT	0
508262	502340	19479G	PARTICIPANT	\N	PRESENT	0
508263	502340	20026V	PARTICIPANT	\N	PRESENT	0
508264	502340	14211G	PARTICIPANT	\N	PRESENT	0
508265	502340	20092G	PARTICIPANT	\N	PRESENT	0
508266	502340	14151M	PARTICIPANT	\N	PRESENT	0
508267	502340	19415P	PARTICIPANT	\N	PRESENT	0
508268	502340	20152B	PARTICIPANT	\N	PRESENT	0
508269	502340	19563B	PARTICIPANT	\N	PRESENT	0
508270	502340	14267Y	PARTICIPANT	\N	PRESENT	0
508271	502340	14221J	PARTICIPANT	\N	PRESENT	0
508272	502340	18083K	PARTICIPANT	\N	PRESENT	0
508273	502340	20062A	PARTICIPANT	\N	PRESENT	0
508274	502340	19333N	PARTICIPANT	\N	PRESENT	0
508275	502340	20120S	PARTICIPANT	\N	PRESENT	0
508276	508189	19687N	PARTICIPANT	\N	PRESENT	0
508277	508189	07029T	PARTICIPANT	\N	EXCUSE	0
508278	502340	19581D	PARTICIPANT	\N	PRESENT	0
508279	502340	19611R	PARTICIPANT	\N	PRESENT	0
508280	502340	19441R	PARTICIPANT	\N	PRESENT	0
508281	502340	20134Y	PARTICIPANT	\N	PRESENT	0
508282	502340	11066Q	PARTICIPANT	\N	PRESENT	0
508283	502340	14229S	PARTICIPANT	\N	PRESENT	0
508284	502340	20104S	PARTICIPANT	\N	PRESENT	0
508285	502340	20044X	PARTICIPANT	\N	PRESENT	0
508286	502340	97011G	PARTICIPANT	\N	PRESENT	0
508287	502340	14195A	PARTICIPANT	\N	PRESENT	0
508288	502340	19671E	PARTICIPANT	\N	PRESENT	0
508289	502340	19717B	PARTICIPANT	\N	PRESENT	0
508290	502340	20142Y	PARTICIPANT	\N	PRESENT	0
508291	502340	19503N	PARTICIPANT	\N	PRESENT	0
508292	502340	08034U	PARTICIPANT	\N	PRESENT	0
508293	502340	99004R	PARTICIPANT	\N	PRESENT	0
508294	502340	19719D	PARTICIPANT	\N	PRESENT	0
508295	502340	08010L	PARTICIPANT	\N	PRESENT	0
508296	502340	14179A	PARTICIPANT	\N	PRESENT	0
508297	502340	14026U	PARTICIPANT	\N	PRESENT	0
508298	502340	04086Q	PARTICIPANT	\N	PRESENT	0
483621	483603	14033T	PARTICIPANT	\N	PRESENT	0
483622	483603	08038Y	PARTICIPANT	\N	PRESENT	0
483623	483603	19441R	PARTICIPANT	\N	PRESENT	0
484340	479198	19531S	PARTICIPANT	\N	PRESENT	0
483625	483603	01043Q	PARTICIPANT	\N	PRESENT	0
483626	483603	19515S	PARTICIPANT	\N	PRESENT	0
484341	479198	96004D	PARTICIPANT	\N	PRESENT	0
483628	483603	19812Y	PARTICIPANT	\N	PRESENT	0
484342	479198	19507S	PARTICIPANT	\N	PRESENT	0
484343	479198	11083R	PARTICIPANT	\N	PRESENT	0
483631	483603	14197C	PARTICIPANT	\N	PRESENT	0
483632	483603	19768N	PARTICIPANT	\N	PRESENT	0
483633	483603	04049K	PARTICIPANT	\N	PRESENT	0
483634	483603	11099A	PARTICIPANT	\N	PRESENT	0
483635	483603	19912C	PARTICIPANT	\N	PRESENT	0
483636	483603	14081Q	PARTICIPANT	\N	PRESENT	0
483637	483603	19413M	PARTICIPANT	\N	PRESENT	0
483638	483603	14357A	PARTICIPANT	\N	PRESENT	0
483639	483603	19747H	PARTICIPANT	\N	PRESENT	0
483640	483603	11077T	PARTICIPANT	\N	PRESENT	0
484344	479198	19631V	PARTICIPANT	\N	PRESENT	0
484345	479198	04057K	PARTICIPANT	\N	PRESENT	0
483643	483603	19705W	PARTICIPANT	\N	PRESENT	0
483644	483603	19507S	PARTICIPANT	\N	PRESENT	0
483645	483603	19295A	PARTICIPANT	\N	PRESENT	0
483646	483603	14115H	PARTICIPANT	\N	PRESENT	0
483647	483603	19866P	PARTICIPANT	\N	PRESENT	0
483648	483603	04088S	PARTICIPANT	\N	PRESENT	0
483649	483603	80013X	PARTICIPANT	\N	PRESENT	0
483650	483603	19695N	PARTICIPANT	\N	PRESENT	0
483651	483603	11090Q	PRESIDENT	\N	PRESENT	0
484346	479198	19629C	PARTICIPANT	\N	PRESENT	0
483653	483603	01025N	PARTICIPANT	\N	PRESENT	0
483654	483603	19467C	PARTICIPANT	\N	PRESENT	0
484347	479198	19253P	PARTICIPANT	\N	PRESENT	0
483656	483603	19619A	PARTICIPANT	\N	PRESENT	0
483657	483603	14265W	PARTICIPANT	\N	PRESENT	0
484348	483351	19643A	PARTICIPANT	\N	PRESENT	0
483659	483603	08028W	PARTICIPANT	\N	PRESENT	0
483660	483603	04043D	PARTICIPANT	\N	PRESENT	0
484338	479198	11070L	PARTICIPANT	\N	PRESENT	0
484339	479198	14085U	PARTICIPANT	\N	PRESENT	0
484349	483351	11048N	PARTICIPANT	\N	PRESENT	0
484350	483351	19663E	PARTICIPANT	\N	PRESENT	0
484351	483351	10006L	PARTICIPANT	\N	PRESENT	0
484352	483351	01034P	PARTICIPANT	\N	PRESENT	0
484353	483351	14041T	PARTICIPANT	\N	PRESENT	0
484354	479198	11012A	PARTICIPANT	\N	PRESENT	0
484355	479198	14083S	PARTICIPANT	\N	PRESENT	0
484356	479198	01024M	PARTICIPANT	\N	PRESENT	0
484357	479198	19914E	PARTICIPANT	\N	PRESENT	0
484358	479198	19563B	PARTICIPANT	\N	PRESENT	0
484359	479198	19441R	PARTICIPANT	\N	PRESENT	0
484360	483351	14331P	PARTICIPANT	\N	PRESENT	0
484361	483351	19697Q	PARTICIPANT	\N	PRESENT	0
484362	483351	11067R	PARTICIPANT	\N	PRESENT	0
484363	483351	04092N	PRESIDENT	0	PRESENT	0
484364	483351	19569H	PARTICIPANT	\N	PRESENT	0
484365	483351	11097X	PARTICIPANT	\N	PRESENT	0
484366	483351	14081Q	PARTICIPANT	\N	PRESENT	0
484367	483351	19715Y	PARTICIPANT	\N	PRESENT	0
484368	483351	04085P	PARTICIPANT	\N	PRESENT	0
484369	483351	19703U	PARTICIPANT	\N	PRESENT	0
484370	483351	11031D	PARTICIPANT	\N	PRESENT	0
484371	483351	19553Y	PARTICIPANT	\N	PRESENT	0
484372	483351	19573D	PARTICIPANT	\N	PRESENT	0
484373	483351	19503N	PARTICIPANT	\N	PRESENT	0
484374	483351	99004R	PARTICIPANT	\N	PRESENT	0
484375	483351	19683J	PARTICIPANT	\N	PRESENT	0
484376	479198	19593H	PARTICIPANT	\N	PRESENT	0
484377	479198	07029T	PARTICIPANT	\N	PRESENT	0
484378	479198	19794Q	PARTICIPANT	\N	PRESENT	0
484379	479198	14029X	PARTICIPANT	\N	PRESENT	0
484380	479198	08039A	PARTICIPANT	\N	PRESENT	0
484381	479198	19711U	PARTICIPANT	\N	PRESENT	0
484382	479198	19675J	PARTICIPANT	\N	PRESENT	0
484383	479198	19693L	PARTICIPANT	\N	PRESENT	0
484396	479198	04086Q	PARTICIPANT	\N	PRESENT	0
484397	479198	14217N	PARTICIPANT	\N	PRESENT	0
484398	479198	14331P	PARTICIPANT	\N	PRESENT	0
484399	479198	19399H	PARTICIPANT	\N	PRESENT	0
484430	484400	11090Q	PARTICIPANT	\N	PRESENT	0
484431	484400	19507S	PARTICIPANT	\N	PRESENT	0
484432	484400	19531S	PARTICIPANT	\N	PRESENT	0
484433	484400	19333N	PARTICIPANT	\N	PRESENT	0
484434	484400	19631V	PARTICIPANT	\N	PRESENT	0
484435	484400	19563B	PARTICIPANT	\N	PRESENT	0
484436	484400	19593H	PARTICIPANT	\N	PRESENT	0
484437	484400	04070G	PARTICIPANT	\N	PRESENT	0
484438	484400	14217N	PARTICIPANT	\N	PRESENT	0
484439	484400	19693L	PARTICIPANT	\N	PRESENT	0
484440	484400	08039A	PARTICIPANT	\N	PRESENT	0
484441	484400	19711U	PARTICIPANT	\N	PRESENT	0
484442	484400	19447X	PARTICIPANT	\N	PRESENT	0
484443	484400	11083R	PARTICIPANT	\N	PRESENT	0
484444	484400	14331P	PARTICIPANT	\N	PRESENT	0
484445	484400	11097X	PARTICIPANT	\N	PRESENT	0
484446	484400	08031R	PARTICIPANT	\N	PRESENT	0
484447	484400	19543W	PARTICIPANT	\N	PRESENT	0
484448	484400	19253P	PARTICIPANT	\N	PRESENT	0
484449	484400	19441R	PARTICIPANT	\N	PRESENT	0
484450	484400	04059M	PARTICIPANT	\N	PRESENT	0
484451	484400	07029T	PARTICIPANT	\N	PRESENT	0
484452	484400	10006L	PARTICIPANT	\N	PRESENT	0
484453	484400	19629C	PARTICIPANT	\N	PRESENT	0
484454	484400	19479G	PARTICIPANT	\N	PRESENT	0
484455	484400	14147R	PARTICIPANT	\N	PRESENT	0
484456	484400	14029X	PARTICIPANT	\N	PRESENT	0
484428	484400	14034U	PARTICIPANT	\N	PRESENT	0
484429	484400	96004D	PARTICIPANT	\N	PRESENT	0
484457	484400	14069U	PARTICIPANT	\N	PRESENT	0
484473	483370	14331P	PARTICIPANT	\N	PRESENT	0
484459	484400	19749K	PARTICIPANT	\N	PRESENT	0
484467	483370	14065Q	PARTICIPANT	\N	PRESENT	0
484598	483672	19525U	PARTICIPANT	\N	PRESENT	0
484469	483370	19675J	PARTICIPANT	\N	PRESENT	0
484470	483370	19447X	PARTICIPANT	\N	PRESENT	0
484471	483370	11072N	PARTICIPANT	\N	PRESENT	0
484472	483370	05008E	PRESIDENT	0	PRESENT	0
484474	483370	95063L	PARTICIPANT	\N	PRESENT	0
484475	483370	14147R	PARTICIPANT	\N	PRESENT	0
484476	483370	19729F	PARTICIPANT	\N	EXCUSE	0
484507	483276	19766L	PARTICIPANT	\N	PRESENT	0
484508	483276	19643A	PARTICIPANT	\N	PRESENT	0
484509	483276	14331P	PARTICIPANT	\N	PRESENT	0
484510	483276	19697Q	PARTICIPANT	\N	PRESENT	0
484511	483276	11048N	PARTICIPANT	\N	PRESENT	0
484512	483276	11067R	PARTICIPANT	\N	PRESENT	0
484513	483276	19479G	PARTICIPANT	\N	PRESENT	0
484514	483276	19649G	PARTICIPANT	\N	PRESENT	0
484515	483276	04092N	PRESIDENT	0	PRESENT	0
484516	483276	14081Q	PARTICIPANT	\N	PRESENT	0
484517	483276	19667J	PARTICIPANT	\N	PRESENT	0
484518	483276	19715Y	PARTICIPANT	\N	PRESENT	0
484519	483276	19703U	PARTICIPANT	\N	PRESENT	0
484520	483276	19553Y	PARTICIPANT	\N	PRESENT	0
484521	483276	19573D	PARTICIPANT	\N	PRESENT	0
484522	483276	19503N	PARTICIPANT	\N	PRESENT	0
484523	483276	99004R	PARTICIPANT	\N	PRESENT	0
484524	483276	10006L	PARTICIPANT	\N	PRESENT	0
484525	483276	19683J	PARTICIPANT	\N	PRESENT	0
484526	483276	01034P	PARTICIPANT	\N	EXCUSE	0
484527	483276	19545Y	PARTICIPANT	\N	EXCUSE	0
484528	483276	14041T	PARTICIPANT	\N	EXCUSE	0
484531	483276	11097X	PARTICIPANT	\N	PRESENT	0
484532	483276	19663E	PARTICIPANT	\N	PRESENT	0
484533	483276	19447X	PARTICIPANT	\N	PRESENT	0
484534	483276	04059M	PARTICIPANT	\N	PRESENT	0
484535	483276	19349W	PARTICIPANT	\N	PRESENT	0
484599	483672	87003B	PARTICIPANT	\N	EXCUSE	0
484618	483672	19711U	PARTICIPANT	\N	PRESENT	0
484619	483672	19741B	PARTICIPANT	\N	PRESENT	0
484669	483672	19399H	PARTICIPANT	\N	PRESENT	0
484670	483672	19551W	PARTICIPANT	\N	EXCUSE	0
484694	484693	19725B	PARTICIPANT	\N	PRESENT	0
484874	484566	98022P	PARTICIPANT	\N	EXCUSE	0
484875	481610	14030Q	PRESIDENT	0	PRESENT	0
484876	481610	08043V	PARTICIPANT	\N	PRESENT	0
484877	481610	19643A	PARTICIPANT	\N	PRESENT	0
484878	481610	19621T	PARTICIPANT	\N	PRESENT	0
484879	481610	08020N	PARTICIPANT	\N	EXCUSE	0
484880	481610	08024S	PARTICIPANT	\N	EXCUSE	0
484881	481610	19701S	PARTICIPANT	\N	PRESENT	0
484882	481610	11031D	PARTICIPANT	\N	PRESENT	0
484883	481610	19693L	PARTICIPANT	\N	EXCUSE	0
484884	481610	19599P	PARTICIPANT	\N	PRESENT	0
484885	481610	04035D	PARTICIPANT	\N	EXCUSE	0
484886	481610	14179A	PARTICIPANT	\N	PRESENT	0
484887	481610	19715Y	PARTICIPANT	\N	PRESENT	0
484888	481610	19731Y	PARTICIPANT	\N	PRESENT	0
509271	506101	19575F	PARTICIPANT	\N	EXCUSE	0
509272	506101	14030Q	PARTICIPANT	\N	EXCUSE	0
509273	506101	08060W	PARTICIPANT	\N	EXCUSE	0
509274	506101	19545Y	PARTICIPANT	\N	EXCUSE	0
509275	506101	14329V	PARTICIPANT	\N	EXCUSE	0
509276	506101	16685X	PARTICIPANT	\N	EXCUSE	0
509277	506101	20082E	PARTICIPANT	\N	EXCUSE	0
509278	506101	20054A	PARTICIPANT	\N	EXCUSE	0
511392	502344	04086Q	PARTICIPANT	\N	PRESENT	0
511393	502344	19333N	PARTICIPANT	\N	PRESENT	0
511394	502344	19631V	PARTICIPANT	\N	PRESENT	0
511395	502344	19599P	PARTICIPANT	\N	PRESENT	0
511396	502344	19503N	PARTICIPANT	\N	PRESENT	0
511397	502344	14169X	PARTICIPANT	\N	PRESENT	0
511398	502344	20030R	PARTICIPANT	\N	PRESENT	0
511399	502344	20032T	PARTICIPANT	\N	PRESENT	0
511400	502344	20028X	PARTICIPANT	\N	PRESENT	0
511401	502344	19747H	PARTICIPANT	\N	PRESENT	0
511402	502344	20102Q	PARTICIPANT	\N	PRESENT	0
511403	502344	11077T	PARTICIPANT	\N	PRESENT	0
511404	502344	14133K	PARTICIPANT	\N	PRESENT	0
511405	502344	19866P	PARTICIPANT	\N	PRESENT	0
511406	502344	11097X	PARTICIPANT	\N	PRESENT	0
511407	502344	19629C	PARTICIPANT	\N	PRESENT	0
511408	502344	14187A	PARTICIPANT	\N	PRESENT	0
511409	502344	20174H	PARTICIPANT	\N	PRESENT	0
511410	502344	19782L	PARTICIPANT	\N	PRESENT	0
511411	502344	14053L	PARTICIPANT	\N	PRESENT	0
511412	502344	11065P	PARTICIPANT	\N	PRESENT	0
511413	502344	14193X	PARTICIPANT	\N	PRESENT	0
511414	502344	14107H	PARTICIPANT	\N	PRESENT	0
511415	502344	20116W	PARTICIPANT	\N	PRESENT	0
511416	502344	19798U	PARTICIPANT	\N	PRESENT	0
511417	502344	14195A	PARTICIPANT	\N	PRESENT	0
511418	502344	14042U	PARTICIPANT	\N	PRESENT	0
511419	502344	14105F	PARTICIPANT	\N	PRESENT	0
511420	502344	19569H	PARTICIPANT	\N	PRESENT	0
511421	502344	14071N	PARTICIPANT	\N	PRESENT	0
511422	502344	19441R	PARTICIPANT	\N	PRESENT	0
511423	502344	01043Q	PARTICIPANT	\N	PRESENT	0
511424	502344	20026V	PARTICIPANT	\N	PRESENT	0
511425	502344	01025N	PARTICIPANT	\N	PRESENT	0
511426	502344	19749K	PARTICIPANT	\N	PRESENT	0
511427	502344	19954N	PARTICIPANT	\N	PRESENT	0
511428	502344	19826F	PARTICIPANT	\N	PRESENT	0
511429	502344	14231L	PARTICIPANT	\N	PRESENT	0
511430	502344	20056C	PARTICIPANT	\N	PRESENT	0
511431	502344	20124W	PARTICIPANT	\N	PRESENT	0
511432	502344	11090Q	PARTICIPANT	\N	PRESENT	0
511433	502344	20062A	PARTICIPANT	\N	PRESENT	0
511434	502344	20090E	PARTICIPANT	\N	PRESENT	0
511435	502344	19383Y	PARTICIPANT	\N	PRESENT	0
511436	502344	19719D	PARTICIPANT	\N	PRESENT	0
511437	502344	19703U	PARTICIPANT	\N	PRESENT	0
511438	502344	20054A	PARTICIPANT	\N	PRESENT	0
511442	502344	14207L	PARTICIPANT	\N	PRESENT	0
511440	502344	20126Y	PARTICIPANT	\N	PRESENT	0
511441	502344	19467C	PARTICIPANT	\N	PRESENT	0
511443	502344	07029T	PARTICIPANT	\N	PRESENT	0
511444	502344	20092G	PARTICIPANT	\N	PRESENT	0
511445	502344	08028W	PARTICIPANT	\N	PRESENT	0
511446	502344	19413M	PARTICIPANT	\N	PRESENT	0
511447	502344	19399H	PARTICIPANT	\N	PRESENT	0
511448	502344	20024T	PARTICIPANT	\N	PRESENT	0
511449	502344	20044X	PARTICIPANT	\N	PRESENT	0
511450	502344	14147R	PARTICIPANT	\N	PRESENT	0
511451	502344	20138D	PARTICIPANT	\N	PRESENT	0
511452	502344	14217N	PARTICIPANT	\N	PRESENT	0
511453	502344	14069U	PARTICIPANT	\N	PRESENT	0
511454	502344	11043H	PARTICIPANT	\N	PRESENT	0
511455	502344	20144B	PARTICIPANT	\N	PRESENT	0
511456	502344	19713W	PARTICIPANT	\N	PRESENT	0
511457	502344	19479G	PARTICIPANT	\N	PRESENT	0
511458	502344	14259Y	PARTICIPANT	\N	PRESENT	0
511459	502344	19575F	PARTICIPANT	\N	PRESENT	0
511460	502344	19691J	PARTICIPANT	\N	PRESENT	0
511461	502344	01057W	PARTICIPANT	\N	PRESENT	0
511462	502344	19347U	PARTICIPANT	\N	PRESENT	0
511463	502344	20100N	PARTICIPANT	\N	PRESENT	0
511464	502344	14257W	PARTICIPANT	\N	PRESENT	0
511465	502344	20082E	PARTICIPANT	\N	PRESENT	0
511466	502344	20018V	PARTICIPANT	\N	PRESENT	0
511467	502344	20070A	PARTICIPANT	\N	PRESENT	0
511468	502344	19565D	PARTICIPANT	\N	PRESENT	0
511469	502344	20046A	PARTICIPANT	\N	PRESENT	0
511470	502344	10006L	PARTICIPANT	\N	PRESENT	0
511471	502344	08015R	PARTICIPANT	\N	PRESENT	0
511472	502344	14251Q	PARTICIPANT	\N	PRESENT	0
511473	502344	19715Y	PARTICIPANT	\N	PRESENT	0
511474	502344	18083K	PARTICIPANT	\N	PRESENT	0
511475	502344	11099A	PARTICIPANT	\N	PRESENT	0
511476	502344	19531S	PARTICIPANT	\N	PRESENT	0
511477	502344	14030Q	PARTICIPANT	\N	PRESENT	0
511478	502344	14189C	PARTICIPANT	\N	PRESENT	0
511479	502344	14083S	PARTICIPANT	\N	PRESENT	0
511480	502344	20036X	PARTICIPANT	\N	PRESENT	0
511481	502344	19762G	PARTICIPANT	\N	PRESENT	0
511482	502344	20132W	PARTICIPANT	\N	PRESENT	0
511483	502344	04045F	PARTICIPANT	\N	PRESENT	0
511484	502344	18193Q	PARTICIPANT	\N	PRESENT	0
511485	502344	20114U	PARTICIPANT	\N	PRESENT	0
511486	502344	14073Q	PARTICIPANT	\N	PRESENT	0
511390	502344	12041X	PARTICIPANT	\N	PRESENT	0
511391	502344	14327T	PARTICIPANT	\N	PRESENT	0
511487	502344	05012A	PARTICIPANT	\N	PRESENT	0
511488	502344	14215L	PARTICIPANT	\N	PRESENT	0
511489	502344	11109J	PARTICIPANT	\N	PRESENT	0
511490	502344	19549D	PARTICIPANT	\N	PRESENT	0
511491	502344	19349W	PARTICIPANT	\N	PRESENT	0
511492	502344	11048N	PARTICIPANT	\N	PRESENT	0
511493	502344	14213J	PARTICIPANT	\N	PRESENT	0
511494	502344	20086J	PARTICIPANT	\N	PRESENT	0
511495	502344	19507S	PARTICIPANT	\N	PRESENT	0
511496	502344	20106U	PARTICIPANT	\N	PRESENT	0
511497	502344	19695N	PARTICIPANT	\N	PRESENT	0
511498	502344	19760E	PARTICIPANT	\N	PRESENT	0
511499	502344	14357A	PARTICIPANT	\N	PRESENT	0
511586	509270	11090Q	PARTICIPANT	\N	EXCUSE	0
511587	509270	14053L	PARTICIPANT	\N	PRESENT	0
511588	509270	14033T	PARTICIPANT	\N	EXCUSE	0
511604	509565	20110Q	PARTICIPANT	\N	PRESENT	0
511605	509565	14147R	PARTICIPANT	\N	PRESENT	0
511606	509565	14151M	PARTICIPANT	\N	PRESENT	0
511607	509565	14215L	PARTICIPANT	\N	PRESENT	0
511608	509565	04008A	PARTICIPANT	\N	PRESENT	0
512199	509848	19701S	PARTICIPANT	\N	PRESENT	0
512200	509848	14219Q	PARTICIPANT	\N	PRESENT	0
512201	509848	19820Y	PARTICIPANT	\N	PRESENT	0
512202	509848	20102Q	PARTICIPANT	\N	PRESENT	0
512203	509848	19599P	PARTICIPANT	\N	PRESENT	0
512204	509848	20100N	PARTICIPANT	\N	PRESENT	0
512205	509848	20020P	PARTICIPANT	\N	PRESENT	0
512206	509848	17367Q	PARTICIPANT	\N	PRESENT	0
512207	509848	20046A	PARTICIPANT	\N	PRESENT	0
512208	509848	19619A	PARTICIPANT	\N	PRESENT	0
512209	509848	19768N	PARTICIPANT	\N	PRESENT	1
512210	509848	08015R	PARTICIPANT	\N	PRESENT	1
512211	509848	19467C	PARTICIPANT	\N	PRESENT	0
512212	502346	19713W	PARTICIPANT	\N	PRESENT	0
512213	509848	19637C	PARTICIPANT	\N	PRESENT	1
512214	509848	14237S	PARTICIPANT	\N	PRESENT	1
512215	509874	12041X	PARTICIPANT	\N	PRESENT	0
512216	509874	01058X	PARTICIPANT	\N	PRESENT	0
512217	509874	14193X	PARTICIPANT	\N	PRESENT	0
512218	509874	11083R	PARTICIPANT	\N	PRESENT	0
512219	509874	11054L	PARTICIPANT	\N	PRESENT	0
512220	509848	20030R	PARTICIPANT	\N	PRESENT	0
512221	509848	20038A	PARTICIPANT	\N	PRESENT	0
512222	509848	20122U	PARTICIPANT	\N	PRESENT	0
512223	509848	19739H	PARTICIPANT	\N	PRESENT	0
512224	509874	16685X	PARTICIPANT	\N	PRESENT	0
512225	509874	20042V	PARTICIPANT	\N	PRESENT	1
512227	509874	14267Y	PARTICIPANT	\N	PRESENT	1
512228	509874	19347U	PARTICIPANT	\N	PRESENT	0
512229	509874	14249W	PARTICIPANT	\N	PRESENT	0
512230	509874	04035D	PARTICIPANT	\N	PRESENT	1
512231	509874	19443T	PARTICIPANT	\N	PRESENT	1
512232	509874	19565D	PARTICIPANT	\N	PRESENT	1
512233	509874	04034C	PARTICIPANT	\N	PRESENT	1
512234	509874	98018T	PARTICIPANT	\N	PRESENT	1
483661	483603	04089T	PARTICIPANT	\N	EXCUSE	0
483662	483603	14205J	PARTICIPANT	\N	EXCUSE	0
483663	483603	14135M	PARTICIPANT	\N	EXCUSE	0
483664	483603	19631V	PARTICIPANT	\N	PRESENT	0
483665	483231	19631V	PARTICIPANT	\N	PRESENT	0
483666	483231	04089T	PARTICIPANT	\N	EXCUSE	0
483667	483231	14205J	PARTICIPANT	\N	EXCUSE	0
483668	483231	14135M	PARTICIPANT	\N	EXCUSE	0
485314	484872	96004D	PRESIDENT	0	PRESENT	0
485315	484872	14079W	PARTICIPANT	\N	PRESENT	0
485316	484872	04035D	PARTICIPANT	\N	PRESENT	0
485317	484872	11083R	PARTICIPANT	\N	PRESENT	0
485318	484872	14026U	PARTICIPANT	\N	PRESENT	0
485319	484872	19553Y	PARTICIPANT	\N	PRESENT	0
485320	484872	19725B	PARTICIPANT	\N	PRESENT	0
485321	484872	14097Y	PARTICIPANT	\N	PRESENT	0
485322	484872	14073Q	PARTICIPANT	\N	PRESENT	0
485323	484872	08039A	PARTICIPANT	\N	PRESENT	0
485324	484872	14237S	PARTICIPANT	\N	PRESENT	0
485325	484872	14331P	PARTICIPANT	\N	PRESENT	0
485326	484872	98035U	PARTICIPANT	\N	PRESENT	0
488203	488198	19683J	PARTICIPANT	\N	PRESENT	0
488204	488198	19723Y	PARTICIPANT	\N	PRESENT	0
488205	488199	19683J	PARTICIPANT	\N	PRESENT	0
488206	488199	19723Y	PARTICIPANT	\N	PRESENT	0
488207	488200	19683J	PARTICIPANT	\N	PRESENT	0
488208	488200	19723Y	PARTICIPANT	\N	PRESENT	0
488209	488201	19683J	PARTICIPANT	\N	PRESENT	0
488210	488202	19683J	PARTICIPANT	\N	PRESENT	0
488214	488195	19415P	PARTICIPANT	\N	PRESENT	0
488212	488194	19415P	PARTICIPANT	\N	PRESENT	0
488213	488194	11067R	PARTICIPANT	\N	PRESENT	0
488215	488195	11067R	PARTICIPANT	\N	PRESENT	0
488216	488196	19415P	PARTICIPANT	\N	PRESENT	0
488217	488196	11067R	PARTICIPANT	\N	PRESENT	0
488218	488197	19415P	PARTICIPANT	\N	PRESENT	0
488219	488197	11067R	PARTICIPANT	\N	PRESENT	0
492435	491509	19966S	PARTICIPANT	\N	EXCUSE	0
492436	491509	19295A	PARTICIPANT	\N	EXCUSE	0
492437	491509	19663E	PARTICIPANT	\N	EXCUSE	0
492489	491509	14026U	PARTICIPANT	\N	EXCUSE	0
492491	491509	11067R	PARTICIPANT	\N	EXCUSE	0
492495	491510	19966S	PARTICIPANT	\N	EXCUSE	0
492496	491510	19295A	PARTICIPANT	\N	EXCUSE	0
498253	497671	19629C	PARTICIPANT	\N	PRESENT	0
498258	497172	14053L	PARTICIPANT	\N	PRESENT	0
498259	497172	14231L	PARTICIPANT	\N	PRESENT	0
498260	497172	14259Y	PARTICIPANT	\N	PRESENT	0
498261	497172	11056N	PARTICIPANT	\N	PRESENT	0
498262	497172	19749K	PARTICIPANT	\N	PRESENT	0
498266	497172	19820Y	PARTICIPANT	\N	PRESENT	0
498269	497172	04085P	PARTICIPANT	\N	PRESENT	0
498270	497172	04045F	PARTICIPANT	\N	PRESENT	0
498271	497172	19729F	PARTICIPANT	\N	PRESENT	0
498272	497172	20026V	PARTICIPANT	\N	PRESENT	0
498273	497172	19629C	PARTICIPANT	\N	PRESENT	0
498274	497172	19489J	PARTICIPANT	\N	PRESENT	0
498275	497172	19866P	PARTICIPANT	\N	PRESENT	0
498276	497172	95063L	PARTICIPANT	\N	PRESENT	0
498277	497172	04047H	PARTICIPANT	\N	PRESENT	0
498278	497172	20076G	PARTICIPANT	\N	PRESENT	0
498279	497172	11103C	PARTICIPANT	\N	PRESENT	0
498280	497172	19725B	PARTICIPANT	\N	PRESENT	0
498281	497172	20072C	PARTICIPANT	\N	PRESENT	0
498282	497172	19543W	PARTICIPANT	\N	PRESENT	0
498283	497172	14179A	PARTICIPANT	\N	PRESENT	0
498284	497172	14069U	PARTICIPANT	\N	PRESENT	0
498285	497172	20128B	PARTICIPANT	\N	PRESENT	0
498286	497172	20110Q	PARTICIPANT	\N	PRESENT	0
498287	497172	19441R	PARTICIPANT	\N	PRESENT	0
498288	497172	20112S	PARTICIPANT	\N	PRESENT	0
498290	497172	20124W	PARTICIPANT	\N	PRESENT	0
498291	497172	14038Y	PARTICIPANT	\N	PRESENT	0
498292	497172	19447X	PARTICIPANT	\N	PRESENT	0
498294	497172	14111D	PARTICIPANT	\N	PRESENT	0
498296	497172	20132W	PARTICIPANT	\N	PRESENT	0
498297	497172	20032T	PARTICIPANT	\N	PRESENT	0
498298	497172	14215L	PARTICIPANT	\N	PRESENT	0
502089	500501	20034V	PARTICIPANT	\N	PRESENT	0
498300	497172	20174H	PARTICIPANT	\N	PRESENT	0
498301	497172	14021P	PARTICIPANT	\N	PRESENT	0
498302	497172	14033T	PARTICIPANT	\N	PRESENT	0
498303	497172	18083K	PARTICIPANT	\N	PRESENT	0
498304	497172	20024T	PARTICIPANT	\N	PRESENT	0
498305	497172	19687N	PARTICIPANT	\N	PRESENT	0
498308	497172	20172F	PARTICIPANT	\N	PRESENT	0
498309	497172	19563B	PARTICIPANT	\N	PRESENT	0
498310	497172	20036X	PARTICIPANT	\N	PRESENT	0
498315	497172	01024M	PARTICIPANT	\N	PRESENT	0
498316	497172	20090E	PARTICIPANT	\N	PRESENT	0
498317	497172	20058E	PARTICIPANT	\N	PRESENT	0
498318	497172	14229S	PARTICIPANT	\N	PRESENT	0
498319	497172	20030R	PARTICIPANT	\N	PRESENT	0
502090	500501	19768N	PARTICIPANT	\N	PRESENT	0
498321	497817	20106U	PARTICIPANT	\N	PRESENT	0
498322	497817	20038A	PARTICIPANT	\N	PRESENT	0
498323	497817	19739H	PARTICIPANT	\N	PRESENT	0
498324	497817	11090Q	PARTICIPANT	\N	PRESENT	0
498325	497817	19826F	PARTICIPANT	\N	PRESENT	0
498326	497817	20022R	PARTICIPANT	\N	PRESENT	0
502091	500501	20088L	PARTICIPANT	\N	PRESENT	0
495909	495093	19699S	PARTICIPANT	\N	PRESENT	0
495910	495093	19533U	PARTICIPANT	\N	PRESENT	0
495911	495093	14229S	PARTICIPANT	\N	PRESENT	0
495912	495093	19573D	PARTICIPANT	\N	PRESENT	0
495913	495093	20112S	PARTICIPANT	\N	PRESENT	0
495914	495093	08012N	PARTICIPANT	\N	PRESENT	0
495915	495093	20026V	PARTICIPANT	\N	PRESENT	0
495916	495093	20132W	PARTICIPANT	\N	PRESENT	0
495917	495093	20134Y	PARTICIPANT	\N	PRESENT	0
495918	495093	14073Q	PARTICIPANT	\N	PRESENT	0
495919	495093	19611R	PRESIDENT	0	PRESENT	0
495920	495093	19693L	PARTICIPANT	\N	PRESENT	0
495921	495093	19399H	PARTICIPANT	\N	PRESENT	0
495922	495093	20152B	PARTICIPANT	\N	PRESENT	0
495923	495093	20052X	PARTICIPANT	\N	PRESENT	0
495924	495093	20058E	PARTICIPANT	\N	PRESENT	0
495925	495093	14030Q	PARTICIPANT	\N	PRESENT	0
495926	495093	20056C	PARTICIPANT	\N	PRESENT	0
495927	495093	04059M	PARTICIPANT	\N	PRESENT	0
495957	494919	20130U	PARTICIPANT	\N	PRESENT	0
495929	495093	14123H	PARTICIPANT	\N	PRESENT	0
495930	495093	11043H	PARTICIPANT	\N	PRESENT	0
495931	495093	20084G	PARTICIPANT	\N	PRESENT	0
495958	494919	11067R	PARTICIPANT	\N	PRESENT	0
495933	495093	20120S	PARTICIPANT	\N	EXCUSE	0
495934	494838	04070G	PARTICIPANT	\N	PRESENT	0
495935	494838	20132W	PARTICIPANT	\N	PRESENT	0
495936	494838	19699S	PARTICIPANT	\N	PRESENT	0
495937	494838	19611R	PRESIDENT	0	PRESENT	0
495938	494838	20142Y	PARTICIPANT	\N	PRESENT	0
495939	494838	19693L	PARTICIPANT	\N	PRESENT	0
495940	494838	19399H	PARTICIPANT	\N	PRESENT	0
495941	494838	20052X	PARTICIPANT	\N	PRESENT	0
495942	494838	14229S	PARTICIPANT	\N	PRESENT	0
495943	494838	20098N	PARTICIPANT	\N	PRESENT	0
495944	494838	20056C	PARTICIPANT	\N	PRESENT	0
495945	494838	20112S	PARTICIPANT	\N	PRESENT	0
495946	494838	07033P	PARTICIPANT	\N	PRESENT	0
495947	494838	20026V	PARTICIPANT	\N	PRESENT	0
495948	494838	19621T	PARTICIPANT	\N	PRESENT	0
495949	494838	20084G	PARTICIPANT	\N	PRESENT	0
495950	494838	20120S	PARTICIPANT	\N	EXCUSE	0
495959	494919	01034P	PARTICIPANT	\N	PRESENT	0
495960	494919	04092N	PARTICIPANT	\N	PRESENT	0
495961	494919	19798U	PARTICIPANT	\N	PRESENT	0
495962	494919	19569H	PARTICIPANT	\N	PRESENT	0
495963	494919	17965H	PARTICIPANT	\N	PRESENT	0
495964	494919	19691J	PARTICIPANT	\N	PRESENT	0
495965	494919	18193Q	PARTICIPANT	\N	PRESENT	0
495966	494919	14223L	PARTICIPANT	\N	PRESENT	0
495967	494919	19723Y	PARTICIPANT	\N	PRESENT	0
495968	494919	17779H	PARTICIPANT	\N	PRESENT	0
495969	494919	19553Y	PARTICIPANT	\N	PRESENT	0
495970	494919	19703U	PARTICIPANT	\N	PRESENT	0
495971	494919	11103C	PARTICIPANT	\N	PRESENT	0
495972	494919	14042U	PARTICIPANT	\N	PRESENT	0
495973	494919	14195A	PARTICIPANT	\N	PRESENT	0
495974	494919	14213J	PARTICIPANT	\N	PRESENT	0
495975	494919	14071N	PARTICIPANT	\N	PRESENT	0
495976	494919	19657G	PARTICIPANT	\N	PRESENT	0
495977	494919	04043D	PARTICIPANT	\N	PRESENT	0
495978	494919	10006L	PRESIDENT	0	PRESENT	0
495979	494919	19367Y	PARTICIPANT	\N	EXCUSE	0
508299	502340	19649G	PARTICIPANT	\N	PRESENT	0
508300	502340	14249W	PARTICIPANT	\N	PRESENT	0
508301	502340	04059M	PARTICIPANT	\N	PRESENT	0
508302	502340	20146D	PARTICIPANT	\N	PRESENT	0
508303	502340	20060X	PARTICIPANT	\N	PRESENT	0
508304	502340	12028B	PARTICIPANT	\N	PRESENT	0
508305	502340	17779H	PARTICIPANT	\N	PRESENT	0
508306	502340	20074E	PARTICIPANT	\N	PRESENT	0
508307	502340	08069G	PARTICIPANT	\N	PRESENT	0
508308	502340	04045F	PARTICIPANT	\N	PRESENT	0
508309	502340	11012A	PARTICIPANT	\N	PRESENT	0
508310	502340	01057W	PARTICIPANT	\N	PRESENT	0
508311	502340	14257W	PARTICIPANT	\N	PRESENT	0
508327	502340	20046A	PARTICIPANT	\N	PRESENT	0
508313	502340	14042U	PARTICIPANT	\N	PRESENT	0
508314	502340	19954N	PARTICIPANT	\N	PRESENT	0
508315	502340	19689Q	PARTICIPANT	\N	PRESENT	0
508316	502340	11056N	PARTICIPANT	\N	PRESENT	0
508317	502340	19758L	PARTICIPANT	\N	PRESENT	0
508318	502340	12041X	PARTICIPANT	\N	PRESENT	0
508319	502340	20018V	PARTICIPANT	\N	PRESENT	0
508320	502340	11040E	PARTICIPANT	\N	PRESENT	0
508321	502340	01034P	PARTICIPANT	\N	PRESENT	0
508322	502340	14083S	PARTICIPANT	\N	PRESENT	0
508323	502340	19826F	PARTICIPANT	\N	PRESENT	0
508324	502340	20130U	PARTICIPANT	\N	PRESENT	0
508325	502340	19515S	PARTICIPANT	\N	PRESENT	0
508326	502340	11031D	PARTICIPANT	\N	PRESENT	0
508328	502340	04042C	PARTICIPANT	\N	PRESENT	0
508329	502340	19347U	PARTICIPANT	\N	PRESENT	0
508330	502340	08061X	PARTICIPANT	\N	PRESENT	0
508331	502340	20128B	PARTICIPANT	\N	PRESENT	0
508332	502340	17367Q	PARTICIPANT	\N	PRESENT	0
508333	502340	19651A	PARTICIPANT	\N	PRESENT	0
508334	502340	19643A	PARTICIPANT	\N	PRESENT	0
508335	502340	11083R	PARTICIPANT	\N	PRESENT	0
508336	502340	19349W	PARTICIPANT	\N	PRESENT	0
508337	502340	20174H	PARTICIPANT	\N	PRESENT	0
508338	502340	19766L	PARTICIPANT	\N	PRESENT	0
508339	502340	19782L	PARTICIPANT	\N	PRESENT	0
508340	502340	04033B	PARTICIPANT	\N	PRESENT	0
508341	502340	19703U	PARTICIPANT	\N	PRESENT	0
508342	502340	19685L	PARTICIPANT	\N	PRESENT	0
508343	502340	14187A	PARTICIPANT	\N	PRESENT	0
508344	502340	20116W	PARTICIPANT	\N	PRESENT	0
508345	502340	20132W	PARTICIPANT	\N	PRESENT	0
508346	502340	19545Y	PARTICIPANT	\N	PRESENT	0
508347	502340	14251Q	PARTICIPANT	\N	PRESENT	0
508348	502340	95041E	PARTICIPANT	\N	PRESENT	0
508349	502340	04057K	PARTICIPANT	\N	PRESENT	0
508350	502340	14215L	PARTICIPANT	\N	PRESENT	0
508351	502340	11064N	PARTICIPANT	\N	PRESENT	0
508352	502340	01028R	PARTICIPANT	\N	PRESENT	0
508353	502340	04008A	PARTICIPANT	\N	PRESENT	0
508354	502340	19599P	PARTICIPANT	\N	PRESENT	0
508355	502340	14069U	PARTICIPANT	\N	PRESENT	0
508356	502340	14021P	PARTICIPANT	\N	PRESENT	0
508357	502340	19621T	PARTICIPANT	\N	PRESENT	0
508358	502340	19367Y	PARTICIPANT	\N	PRESENT	0
508359	502340	20126Y	PARTICIPANT	\N	PRESENT	0
508360	502340	19820Y	PARTICIPANT	\N	PRESENT	0
508361	502340	08017T	PARTICIPANT	\N	PRESENT	0
508362	502340	20124W	PARTICIPANT	\N	PRESENT	0
508363	502340	20070A	PARTICIPANT	\N	PRESENT	0
508364	502340	14121F	PARTICIPANT	\N	PRESENT	0
508365	502340	20094J	PARTICIPANT	\N	PRESENT	0
508366	502340	19762G	PARTICIPANT	\N	PRESENT	0
508367	502340	14329V	PARTICIPANT	\N	PRESENT	0
508368	502340	11026G	PARTICIPANT	\N	PRESENT	0
508369	502340	11033F	PARTICIPANT	\N	PRESENT	0
508370	502340	14213J	PARTICIPANT	\N	PRESENT	0
508371	502340	10006L	PARTICIPANT	\N	PRESENT	0
508372	502340	14357A	PARTICIPANT	\N	PRESENT	0
508373	502340	19687N	PARTICIPANT	\N	PRESENT	0
508374	502340	20022R	PARTICIPANT	\N	PRESENT	0
508441	502340	14097Y	PARTICIPANT	\N	PRESENT	0
508376	502340	11085T	PARTICIPANT	\N	PRESENT	0
508377	502340	14259Y	PARTICIPANT	\N	PRESENT	0
508378	502340	19723Y	PARTICIPANT	\N	PRESENT	0
508379	502340	19573D	PARTICIPANT	\N	PRESENT	0
508380	502340	19467C	PARTICIPANT	\N	PRESENT	0
508381	502340	20144B	PARTICIPANT	\N	PRESENT	0
508382	502340	14038Y	PARTICIPANT	\N	PRESENT	0
508383	502340	20050V	PARTICIPANT	\N	PRESENT	0
508384	502340	19591F	PARTICIPANT	\N	PRESENT	0
508385	502340	20058E	PARTICIPANT	\N	PRESENT	0
508386	502340	16685X	PARTICIPANT	\N	PRESENT	0
508387	502340	14219Q	PARTICIPANT	\N	PRESENT	0
508388	502340	14189C	PARTICIPANT	\N	PRESENT	0
508389	502340	19691J	PARTICIPANT	\N	PRESENT	0
508390	502340	20048C	PARTICIPANT	\N	PRESENT	0
508391	502340	20042V	PARTICIPANT	\N	PRESENT	0
508392	502340	11067R	PARTICIPANT	\N	PRESENT	0
508393	502340	19531S	PARTICIPANT	\N	PRESENT	0
508394	502340	11065P	PARTICIPANT	\N	PRESENT	0
508395	502340	19543W	PARTICIPANT	\N	PRESENT	0
508396	502340	14073Q	PARTICIPANT	\N	PRESENT	0
508397	502340	08009T	PARTICIPANT	\N	PRESENT	0
508398	502340	19549D	PARTICIPANT	\N	PRESENT	0
508399	502340	14255U	PARTICIPANT	\N	PRESENT	0
508400	502340	19749K	PARTICIPANT	\N	PRESENT	0
508401	502340	04092N	PARTICIPANT	\N	PRESENT	0
508402	502340	20066E	PARTICIPANT	\N	PRESENT	0
508403	502340	19533U	PARTICIPANT	\N	PRESENT	0
508404	502340	14327T	PARTICIPANT	\N	PRESENT	0
508405	502340	20096L	PARTICIPANT	\N	PRESENT	0
508406	502340	08015R	PARTICIPANT	\N	PRESENT	0
508407	502340	19711U	PARTICIPANT	\N	PRESENT	0
508408	502340	86034E	PARTICIPANT	\N	PRESENT	0
508409	502340	11090Q	PARTICIPANT	\N	PRESENT	0
508410	502340	19966S	PARTICIPANT	\N	PRESENT	0
508414	502340	19619A	PARTICIPANT	\N	PRESENT	0
508416	502340	14205J	PARTICIPANT	\N	PRESENT	0
508417	502340	05012A	PARTICIPANT	\N	PRESENT	0
508418	502340	11097X	PARTICIPANT	\N	PRESENT	0
508420	502340	19399H	PARTICIPANT	\N	PRESENT	0
508421	502340	20140W	PARTICIPANT	\N	PRESENT	0
508422	502340	19747H	PARTICIPANT	\N	PRESENT	0
508423	502340	19705W	PARTICIPANT	\N	PRESENT	0
508424	502340	20040T	PARTICIPANT	\N	PRESENT	0
508425	502340	01043Q	PARTICIPANT	\N	PRESENT	0
508426	502340	08047A	PARTICIPANT	\N	PRESENT	0
508427	502340	20054A	PARTICIPANT	\N	PRESENT	0
508428	502340	19760E	PARTICIPANT	\N	PRESENT	0
508429	502340	11053K	PARTICIPANT	\N	PRESENT	0
508433	502340	19507S	PARTICIPANT	\N	PRESENT	0
508431	502340	14059S	PARTICIPANT	\N	PRESENT	0
508432	502340	20084G	PARTICIPANT	\N	PRESENT	0
508435	502340	05008E	PARTICIPANT	\N	PRESENT	0
508436	502340	14331P	PARTICIPANT	\N	PRESENT	0
508437	502340	19667J	PARTICIPANT	\N	PRESENT	0
508438	502340	96004D	PARTICIPANT	\N	PRESENT	0
508439	502340	14041T	PARTICIPANT	\N	PRESENT	0
508443	502340	19383Y	PARTICIPANT	\N	PRESENT	0
508442	502340	17737W	PARTICIPANT	\N	PRESENT	0
484889	481610	08031R	PARTICIPANT	\N	EXCUSE	0
484890	481610	07029T	PARTICIPANT	\N	EXCUSE	0
484891	481610	08017T	PARTICIPANT	\N	EXCUSE	0
484892	481610	01043Q	PARTICIPANT	\N	EXCUSE	0
484893	481610	14251Q	PARTICIPANT	\N	EXCUSE	0
484894	481610	11067R	PARTICIPANT	\N	PRESENT	0
484895	481610	14109K	PARTICIPANT	\N	EXCUSE	0
484896	481610	11045K	PARTICIPANT	\N	EXCUSE	0
484897	481610	19749K	PARTICIPANT	\N	PRESENT	0
485547	484687	19717B	PARTICIPANT	\N	PRESENT	0
485549	484687	19631V	PARTICIPANT	\N	PRESENT	0
485551	484687	19577H	PARTICIPANT	\N	PRESENT	0
485553	484687	11010L	PARTICIPANT	\N	EXCUSE	0
485556	484687	19715Y	PARTICIPANT	\N	EXCUSE	0
485559	484687	14059S	PARTICIPANT	\N	PRESENT	0
485560	484687	12016W	PARTICIPANT	\N	PRESENT	0
485561	484687	08019V	PRESIDENT	0	PRESENT	0
485565	484687	11054L	PARTICIPANT	\N	PRESENT	0
485566	484687	19301E	PARTICIPANT	\N	PRESENT	0
485567	484687	14135M	PARTICIPANT	\N	EXCUSE	0
485631	484873	96004D	PRESIDENT	0	PRESENT	0
485632	484873	14073Q	PARTICIPANT	\N	PRESENT	0
485633	484873	04057K	PARTICIPANT	\N	PRESENT	0
485634	484873	98035U	PARTICIPANT	\N	PRESENT	0
485635	484873	19553Y	PARTICIPANT	\N	PRESENT	0
485636	484873	11026G	PARTICIPANT	\N	PRESENT	0
485637	484873	11083R	PARTICIPANT	\N	PRESENT	0
485638	484873	14331P	PARTICIPANT	\N	PRESENT	0
486453	479203	11074Q	PARTICIPANT	\N	PRESENT	0
486454	479203	19687N	PARTICIPANT	\N	PRESENT	0
486455	479203	19565D	PARTICIPANT	\N	PRESENT	0
486456	479203	14225N	PARTICIPANT	\N	PRESENT	0
486488	479203	11072N	PARTICIPANT	\N	PRESENT	0
486458	479203	19531S	PARTICIPANT	\N	PRESENT	0
486459	479203	14085U	PARTICIPANT	\N	PRESENT	0
486460	479203	19503N	PARTICIPANT	\N	PRESENT	0
486461	479203	19651A	PARTICIPANT	\N	PRESENT	0
486462	479203	19713W	PARTICIPANT	\N	PRESENT	0
486463	479203	19711U	PARTICIPANT	\N	PRESENT	0
486464	479203	14255U	PARTICIPANT	\N	PRESENT	0
486465	479203	11053K	PARTICIPANT	\N	PRESENT	0
486466	479203	04018C	PARTICIPANT	\N	PRESENT	0
486467	479203	19563B	PARTICIPANT	\N	PRESENT	0
486468	479203	14331P	PARTICIPANT	\N	PRESENT	0
486469	479203	07004J	PARTICIPANT	\N	PRESENT	0
486470	479203	14041T	PARTICIPANT	\N	PRESENT	0
486471	479203	11012A	PARTICIPANT	\N	PRESENT	0
486472	479203	19741B	PARTICIPANT	\N	PRESENT	0
486473	479203	19760E	PARTICIPANT	\N	PRESENT	0
486474	479203	14357A	PARTICIPANT	\N	PRESENT	0
486475	479203	19593H	PARTICIPANT	\N	PRESENT	0
486476	479203	04035D	PARTICIPANT	\N	PRESENT	0
486477	479203	19347U	PARTICIPANT	\N	PRESENT	0
486478	479203	19671E	PARTICIPANT	\N	PRESENT	0
486479	479203	14217N	PARTICIPANT	\N	PRESENT	0
486480	479203	19705W	PARTICIPANT	\N	PRESENT	0
486481	479203	19701S	PARTICIPANT	\N	PRESENT	0
486482	479203	19689Q	PARTICIPANT	\N	PRESENT	0
486483	479203	04086Q	PARTICIPANT	\N	PRESENT	0
486484	479203	19719D	PARTICIPANT	\N	PRESENT	0
486485	479203	12016W	PARTICIPANT	\N	PRESENT	0
486486	479203	11026G	PARTICIPANT	\N	PRESENT	0
486487	479203	14229S	PARTICIPANT	\N	PRESENT	0
486489	479203	19647E	PARTICIPANT	\N	PRESENT	0
486490	479203	04085P	PARTICIPANT	\N	PRESENT	0
486491	479203	12041X	PARTICIPANT	\N	PRESENT	0
486492	479203	19295A	PARTICIPANT	\N	PRESENT	0
486493	479203	07029T	PARTICIPANT	\N	PRESENT	0
486494	479203	19695N	PARTICIPANT	\N	PRESENT	0
486495	479203	11048N	PARTICIPANT	\N	PRESENT	0
486496	479203	19762G	PARTICIPANT	\N	PRESENT	0
486497	479203	11090Q	PARTICIPANT	\N	PRESENT	0
486498	479203	11099A	PARTICIPANT	\N	PRESENT	0
486499	479203	08024S	PARTICIPANT	\N	PRESENT	0
486500	486396	14331P	PARTICIPANT	\N	PRESENT	0
486501	486396	19647E	PARTICIPANT	\N	PRESENT	0
486502	486396	11048N	PARTICIPANT	\N	PRESENT	0
486503	486396	19711U	PARTICIPANT	\N	PRESENT	0
486504	486396	19651A	PARTICIPANT	\N	PRESENT	0
486505	486396	19531S	PARTICIPANT	\N	PRESENT	0
486506	486396	19689Q	PARTICIPANT	\N	PRESENT	0
486507	486396	12016W	PARTICIPANT	\N	PRESENT	0
486508	486396	19667J	PARTICIPANT	\N	PRESENT	0
486509	486396	11074Q	PRESIDENT	0	PRESENT	0
486510	486396	08011M	PARTICIPANT	\N	PRESENT	0
486511	486396	11070L	PARTICIPANT	\N	PRESENT	0
486512	486396	19671E	PARTICIPANT	\N	PRESENT	0
486513	486396	14225N	PARTICIPANT	\N	PRESENT	0
486514	486396	04086Q	PARTICIPANT	\N	PRESENT	0
486515	486396	07029T	PARTICIPANT	\N	PRESENT	0
486516	486396	11012A	PARTICIPANT	\N	PRESENT	0
486517	486396	14085U	PARTICIPANT	\N	PRESENT	0
486518	486396	19741B	PARTICIPANT	\N	PRESENT	0
486519	486396	19762G	PARTICIPANT	\N	PRESENT	0
486520	479203	19551W	PARTICIPANT	\N	PRESENT	0
487930	485911	19545Y	PARTICIPANT	\N	EXCUSE	0
487931	485911	14041T	PARTICIPANT	\N	EXCUSE	0
487932	485911	14331P	PARTICIPANT	\N	EXCUSE	0
487933	485911	04092N	PARTICIPANT	\N	EXCUSE	0
487934	485911	19479G	PARTICIPANT	\N	EXCUSE	0
487935	485911	19766L	PARTICIPANT	\N	PRESENT	0
487936	485911	11097X	PRESIDENT	0	PRESENT	0
487937	485911	19703U	PARTICIPANT	\N	PRESENT	0
487938	485911	19503N	PARTICIPANT	\N	PRESENT	0
487939	485911	19573D	PARTICIPANT	\N	PRESENT	0
487940	485911	11031D	PARTICIPANT	\N	PRESENT	0
487941	485911	10006L	PARTICIPANT	\N	PRESENT	0
487942	485911	19683J	PARTICIPANT	\N	PRESENT	0
487943	485911	19715Y	PARTICIPANT	\N	PRESENT	0
487944	485911	19553Y	PARTICIPANT	\N	PRESENT	0
487945	485911	99004R	PARTICIPANT	\N	PRESENT	0
487946	485911	19447X	PARTICIPANT	\N	PRESENT	0
487947	485911	19649G	PARTICIPANT	\N	PRESENT	0
487948	485911	19663E	PARTICIPANT	\N	PRESENT	0
487949	485911	19643A	PARTICIPANT	\N	PRESENT	0
487950	485911	14081Q	PARTICIPANT	\N	PRESENT	0
487951	485911	19697Q	PARTICIPANT	\N	PRESENT	0
487961	485911	01034P	PARTICIPANT	\N	PRESENT	0
487988	485911	11067R	PARTICIPANT	\N	PRESENT	0
489307	485176	19711U	PARTICIPANT	\N	PRESENT	0
489298	485176	11070L	PARTICIPANT	\N	PRESENT	0
489299	485176	11040E	PARTICIPANT	\N	PRESENT	0
489445	489444	19415P	PARTICIPANT	\N	PRESENT	0
489447	489446	19415P	PARTICIPANT	\N	PRESENT	0
489468	489467	08058D	PARTICIPANT	\N	PRESENT	0
489527	489339	04059M	PARTICIPANT	\N	PRESENT	0
489528	489339	19643A	PARTICIPANT	\N	PRESENT	0
489529	489339	11031D	PARTICIPANT	\N	PRESENT	0
489530	489339	19663E	PARTICIPANT	\N	EXCUSE	0
489531	489339	10006L	PARTICIPANT	\N	PRESENT	0
489532	489339	19649G	PARTICIPANT	\N	PRESENT	0
489533	489339	19569H	PARTICIPANT	\N	PRESENT	0
489534	489339	11048N	PARTICIPANT	\N	PRESENT	0
489535	489339	19715Y	PARTICIPANT	\N	PRESENT	0
489536	489339	19683J	PARTICIPANT	\N	PRESENT	0
489537	489339	19447X	PARTICIPANT	\N	PRESENT	0
489538	489339	95041E	PARTICIPANT	\N	PRESENT	0
489539	489339	19697Q	PARTICIPANT	\N	PRESENT	0
489540	489339	11067R	PARTICIPANT	\N	PRESENT	0
489541	489339	04092N	PARTICIPANT	\N	EXCUSE	0
489542	489339	19573D	PARTICIPANT	\N	PRESENT	0
489543	489339	19503N	PARTICIPANT	\N	PRESENT	0
489544	489339	14331P	PARTICIPANT	\N	PRESENT	0
489545	489339	19766L	PARTICIPANT	\N	PRESENT	0
489546	489339	11097X	PRESIDENT	0	PRESENT	0
489547	489339	19703U	PARTICIPANT	\N	PRESENT	0
489548	489339	19479G	PARTICIPANT	\N	PRESENT	0
489549	489339	19691J	PARTICIPANT	\N	PRESENT	0
489552	489339	01034P	PARTICIPANT	\N	PRESENT	0
489833	489832	19683J	PARTICIPANT	\N	PRESENT	0
489835	489834	19683J	PARTICIPANT	\N	PRESENT	0
489989	489988	19679N	PARTICIPANT	\N	PRESENT	0
489991	489990	19679N	PARTICIPANT	\N	PRESENT	0
490005	489938	19693L	PARTICIPANT	\N	PRESENT	0
490006	489938	19593H	PARTICIPANT	\N	PRESENT	0
490014	489938	11109J	PARTICIPANT	\N	PRESENT	0
490008	489938	19611R	PARTICIPANT	\N	PRESENT	0
490012	489938	14229S	PARTICIPANT	\N	PRESENT	0
490013	489938	14109K	PARTICIPANT	\N	PRESENT	0
491368	491367	14231L	PARTICIPANT	\N	PRESENT	0
491369	491367	14259Y	PARTICIPANT	\N	PRESENT	0
491370	491367	14053L	PARTICIPANT	\N	PRESENT	0
491371	491367	19954N	PARTICIPANT	\N	PRESENT	0
491373	491372	14231L	PARTICIPANT	\N	PRESENT	0
491374	491372	14259Y	PARTICIPANT	\N	PRESENT	0
491375	491372	19954N	PARTICIPANT	\N	PRESENT	0
491376	491372	14053L	PARTICIPANT	\N	PRESENT	0
509521	509511	14089Y	PARTICIPANT	\N	PRESENT	1
509523	509511	11056N	PARTICIPANT	\N	PRESENT	1
509524	509511	14107H	PARTICIPANT	\N	PRESENT	1
509526	509511	04047H	PARTICIPANT	\N	PRESENT	0
509528	509511	20110Q	PARTICIPANT	\N	PRESENT	1
509531	509511	05008E	PARTICIPANT	\N	PRESENT	1
512028	502346	20090E	PARTICIPANT	\N	PRESENT	0
512029	502346	19747H	PARTICIPANT	\N	PRESENT	0
512030	502346	14179A	PARTICIPANT	\N	PRESENT	0
512031	502346	14121F	PARTICIPANT	\N	PRESENT	0
512032	502346	08045X	PARTICIPANT	\N	PRESENT	0
512033	502346	19667J	PARTICIPANT	\N	PRESENT	0
512034	502346	19691J	PARTICIPANT	\N	PRESENT	0
512035	502346	20112S	PARTICIPANT	\N	PRESENT	0
512036	502346	19729F	PARTICIPANT	\N	PRESENT	0
512037	502346	19467C	PARTICIPANT	\N	PRESENT	0
512038	502346	19760E	PARTICIPANT	\N	PRESENT	0
512039	502346	19703U	PARTICIPANT	\N	PRESENT	0
512040	502346	11074Q	PARTICIPANT	\N	PRESENT	0
512041	502346	20026V	PARTICIPANT	\N	PRESENT	0
512042	502346	20174H	PARTICIPANT	\N	PRESENT	0
512043	502346	01043Q	PARTICIPANT	\N	PRESENT	0
512044	502346	19565D	PARTICIPANT	\N	PRESENT	0
512237	502346	14213J	PARTICIPANT	\N	PRESENT	0
512239	502346	04092N	PARTICIPANT	\N	PRESENT	0
512240	502346	19415P	PARTICIPANT	\N	PRESENT	0
512241	502346	95063L	PARTICIPANT	\N	PRESENT	0
512242	502346	19673G	PARTICIPANT	\N	PRESENT	0
512243	502346	19643A	PARTICIPANT	\N	PRESENT	0
512244	502346	19489J	PARTICIPANT	\N	PRESENT	0
512246	512245	14133K	PARTICIPANT	\N	PRESENT	0
512247	512245	11066Q	PARTICIPANT	\N	PRESENT	0
512248	502346	14249W	PARTICIPANT	\N	PRESENT	0
512249	509874	04042C	PRESIDENT	1	PRESENT	0
512250	502346	14253S	PARTICIPANT	\N	PRESENT	0
512251	509857	20106U	PARTICIPANT	\N	PRESENT	0
512026	502346	11056N	PARTICIPANT	\N	PRESENT	0
512027	502346	19739H	PARTICIPANT	\N	PRESENT	0
512252	509857	19251M	PARTICIPANT	\N	PRESENT	1
512253	509857	19681G	PARTICIPANT	\N	EXCUSE	0
512254	509848	19251M	PARTICIPANT	\N	PRESENT	1
512255	502346	08061X	PARTICIPANT	\N	PRESENT	0
512258	502346	14133K	PARTICIPANT	\N	PRESENT	0
512259	502346	20038A	PARTICIPANT	\N	PRESENT	0
512260	502346	14215L	PARTICIPANT	\N	PRESENT	0
512261	502346	18083K	PARTICIPANT	\N	PRESENT	0
512262	502346	20086J	PARTICIPANT	\N	PRESENT	0
512266	502346	04085P	PARTICIPANT	\N	PRESENT	0
512267	502346	19593H	PARTICIPANT	\N	PRESENT	0
512269	502346	19715Y	PARTICIPANT	\N	PRESENT	0
512270	509891	19593H	PARTICIPANT	\N	PRESENT	0
512271	509891	04070G	PARTICIPANT	\N	PRESENT	1
512272	509891	19699S	PARTICIPANT	\N	PRESENT	0
512273	509891	20134Y	PARTICIPANT	\N	PRESENT	1
512274	509891	14073Q	PARTICIPANT	\N	PRESENT	0
512275	509891	19611R	PRESIDENT	0	PRESENT	0
512276	509891	20142Y	PARTICIPANT	\N	PRESENT	0
512277	509891	20048C	PARTICIPANT	\N	PRESENT	1
512278	509891	19693L	PARTICIPANT	\N	PRESENT	0
512279	509891	19399H	PARTICIPANT	\N	PRESENT	0
512280	509891	20052X	PARTICIPANT	\N	PRESENT	0
512281	509891	14229S	PARTICIPANT	\N	PRESENT	0
512282	509891	14030Q	PARTICIPANT	\N	PRESENT	0
512283	509891	20098N	PARTICIPANT	\N	PRESENT	0
512284	509891	20056C	PARTICIPANT	\N	PRESENT	0
512285	509891	08017T	PARTICIPANT	\N	PRESENT	0
512286	509891	20112S	PARTICIPANT	\N	PRESENT	0
512287	509891	07033P	PARTICIPANT	\N	PRESENT	0
512288	509891	11104D	PARTICIPANT	\N	PRESENT	1
512289	509891	20124W	PARTICIPANT	\N	PRESENT	0
512290	509891	20026V	PARTICIPANT	\N	PRESENT	0
512291	509891	19621T	PARTICIPANT	\N	PRESENT	0
512292	509891	20084G	PARTICIPANT	\N	PRESENT	0
512293	502346	19693L	PARTICIPANT	\N	PRESENT	0
512294	502346	19369B	PARTICIPANT	\N	PRESENT	0
512295	502346	20102Q	PARTICIPANT	\N	PRESENT	0
512296	502346	14217N	PARTICIPANT	\N	PRESENT	0
512297	502346	05012A	PARTICIPANT	\N	PRESENT	0
512298	502346	20092G	PARTICIPANT	\N	PRESENT	0
512299	502346	19599P	PARTICIPANT	\N	PRESENT	0
512300	502346	14089Y	PARTICIPANT	\N	PRESENT	0
512301	502346	01058X	PARTICIPANT	\N	PRESENT	0
512302	502346	11101A	PARTICIPANT	\N	PRESENT	0
512303	502346	04059M	PARTICIPANT	\N	PRESENT	0
512304	502346	11012A	PARTICIPANT	\N	PRESENT	0
512305	502346	04042C	PARTICIPANT	\N	PRESENT	0
512397	502347	11045K	PARTICIPANT	\N	PRESENT	0
512398	502347	99004R	PARTICIPANT	\N	PRESENT	0
512399	502347	04035D	PARTICIPANT	\N	PRESENT	0
512451	502347	19347U	PARTICIPANT	\N	PRESENT	0
512401	502347	19399H	PARTICIPANT	\N	PRESENT	0
512402	502347	19699S	PARTICIPANT	\N	PRESENT	0
512403	502347	20112S	PARTICIPANT	\N	PRESENT	0
512404	502347	19651A	PARTICIPANT	\N	PRESENT	0
512405	502347	19581D	PARTICIPANT	\N	PRESENT	0
512406	502347	20142Y	PARTICIPANT	\N	PRESENT	0
512407	502347	20024T	PARTICIPANT	\N	PRESENT	0
512408	502347	08017T	PARTICIPANT	\N	PRESENT	0
512409	502347	20100N	PARTICIPANT	\N	PRESENT	0
512410	502347	19715Y	PARTICIPANT	\N	PRESENT	0
512411	502347	20072C	PARTICIPANT	\N	PRESENT	0
512412	502347	04059M	PARTICIPANT	\N	PRESENT	0
512413	502347	19593H	PARTICIPANT	\N	PRESENT	0
512414	502347	20124W	PARTICIPANT	\N	PRESENT	0
512415	502347	14147R	PARTICIPANT	\N	PRESENT	0
512416	502347	20054A	PARTICIPANT	\N	PRESENT	0
512417	502347	20056C	PARTICIPANT	\N	PRESENT	0
512418	502347	20026V	PARTICIPANT	\N	PRESENT	0
512419	502347	19621T	PARTICIPANT	\N	PRESENT	0
512420	502347	11056N	PARTICIPANT	\N	PRESENT	0
512421	502347	20030R	PARTICIPANT	\N	PRESENT	0
512422	502347	19719D	PARTICIPANT	\N	PRESENT	0
512423	502347	20122U	PARTICIPANT	\N	PRESENT	0
512424	502347	14073Q	PARTICIPANT	\N	PRESENT	0
512425	502347	14030Q	PARTICIPANT	\N	PRESENT	0
512426	502347	14275Y	PARTICIPANT	\N	PRESENT	0
512427	502347	04070G	PARTICIPANT	\N	PRESENT	0
512428	502347	20126Y	PARTICIPANT	\N	PRESENT	0
512429	502347	19747H	PARTICIPANT	\N	PRESENT	0
512430	502347	19415P	PARTICIPANT	\N	PRESENT	0
512431	502347	07029T	PARTICIPANT	\N	PRESENT	0
512432	502347	20052X	PARTICIPANT	\N	PRESENT	0
512433	502347	19447X	PARTICIPANT	\N	PRESENT	0
512434	502347	19643A	PARTICIPANT	\N	PRESENT	0
512435	502347	19575F	PARTICIPANT	\N	PRESENT	0
512436	502347	19693L	PARTICIPANT	\N	PRESENT	0
512437	502347	19657G	PARTICIPANT	\N	PRESENT	0
512438	502347	20058E	PARTICIPANT	\N	PRESENT	0
512439	502347	19521Q	PARTICIPANT	\N	PRESENT	0
512440	502347	20070A	PARTICIPANT	\N	PRESENT	0
512441	502347	19611R	PARTICIPANT	\N	PRESENT	0
512442	502347	14357A	PARTICIPANT	\N	PRESENT	0
512443	502347	19782L	PARTICIPANT	\N	PRESENT	0
512444	502347	08061X	PARTICIPANT	\N	PRESENT	0
512445	502347	20116W	PARTICIPANT	\N	PRESENT	0
512446	502347	14229S	PARTICIPANT	\N	PRESENT	0
512447	502347	20114U	PARTICIPANT	\N	PRESENT	0
512448	502347	20110Q	PARTICIPANT	\N	PRESENT	0
512449	502347	14021P	PARTICIPANT	\N	PRESENT	0
512450	502347	14179A	PARTICIPANT	\N	PRESENT	0
512452	502347	18083K	PARTICIPANT	\N	PRESENT	0
512453	502347	20086J	PARTICIPANT	\N	PRESENT	0
512508	512467	20024T	PARTICIPANT	\N	PRESENT	0
512509	512467	14030Q	PRESIDENT	0	PRESENT	0
512510	512467	20138D	PARTICIPANT	\N	PRESENT	0
512511	512467	17737W	PARTICIPANT	\N	PRESENT	0
512512	512467	19621T	PARTICIPANT	\N	PRESENT	0
512513	512467	11031D	PARTICIPANT	\N	PRESENT	0
512514	512467	19693L	PARTICIPANT	\N	PRESENT	0
512515	512467	19599P	PARTICIPANT	\N	PRESENT	0
512516	512467	04035D	PARTICIPANT	\N	PRESENT	0
512517	512467	20106U	PARTICIPANT	\N	PRESENT	0
512518	512467	14179A	PARTICIPANT	\N	PRESENT	0
512519	512467	20066E	PARTICIPANT	\N	PRESENT	0
512520	512467	20034V	PARTICIPANT	\N	EXCUSE	0
512521	512467	19715Y	PARTICIPANT	\N	EXCUSE	0
512522	512467	07029T	PARTICIPANT	\N	PRESENT	0
512523	512467	08017T	PARTICIPANT	\N	PRESENT	0
512524	512467	14109K	PARTICIPANT	\N	PRESENT	0
512525	512467	19768N	PARTICIPANT	\N	PRESENT	0
512526	512467	20118Y	PARTICIPANT	\N	EXCUSE	0
485073	485072	96004D	PARTICIPANT	\N	PRESENT	0
485074	485072	11083R	PARTICIPANT	\N	PRESENT	0
485075	485072	19553Y	PARTICIPANT	\N	PRESENT	0
485076	485072	11026G	PARTICIPANT	\N	PRESENT	0
485085	485084	19673G	PARTICIPANT	\N	PRESENT	0
485086	485084	19649G	PARTICIPANT	\N	PRESENT	0
485087	485084	11026G	PARTICIPANT	\N	PRESENT	0
485089	485088	19673G	PARTICIPANT	\N	PRESENT	0
485090	485088	19649G	PARTICIPANT	\N	PRESENT	0
485091	485088	11026G	PARTICIPANT	\N	PRESENT	0
485092	485088	04044E	PARTICIPANT	\N	PRESENT	0
485096	485095	19673G	PARTICIPANT	\N	PRESENT	0
485097	485095	11026G	PARTICIPANT	\N	PRESENT	0
485098	485095	04044E	PARTICIPANT	\N	PRESENT	0
485100	485099	19673G	PARTICIPANT	\N	PRESENT	0
485101	485099	19649G	PARTICIPANT	\N	PRESENT	0
485103	485102	19673G	PARTICIPANT	\N	PRESENT	0
485104	485102	11026G	PARTICIPANT	\N	PRESENT	0
485107	485106	19593H	PARTICIPANT	\N	PRESENT	0
485109	485106	19693L	PARTICIPANT	\N	PRESENT	0
485111	485110	19593H	PARTICIPANT	\N	PRESENT	0
485113	476432	19593H	PARTICIPANT	\N	PRESENT	0
485115	476433	19593H	PARTICIPANT	\N	PRESENT	0
485116	476433	19693L	PARTICIPANT	\N	PRESENT	0
485117	476434	19693L	PARTICIPANT	\N	PRESENT	0
485118	476434	19593H	PARTICIPANT	\N	PRESENT	0
485119	476435	19693L	PARTICIPANT	\N	PRESENT	0
485120	476435	19593H	PARTICIPANT	\N	PRESENT	0
485124	485123	19593H	PARTICIPANT	\N	PRESENT	0
491409	490471	11031D	PARTICIPANT	\N	PRESENT	0
491443	491442	19711U	PARTICIPANT	\N	PRESENT	0
491444	491442	08018U	PARTICIPANT	\N	PRESENT	0
491445	491442	04070G	PARTICIPANT	\N	PRESENT	0
491446	491442	97011G	PARTICIPANT	\N	PRESENT	0
491447	491442	08056B	PARTICIPANT	\N	PRESENT	0
491448	491442	19591F	PARTICIPANT	\N	PRESENT	0
493312	493309	19551W	PARTICIPANT	\N	PRESENT	0
493313	493311	01028R	PARTICIPANT	\N	PRESENT	0
493512	493511	04086Q	PARTICIPANT	\N	PRESENT	0
493624	493310	19551W	PARTICIPANT	\N	PRESENT	0
493749	491379	01028R	PARTICIPANT	\N	EXCUSE	0
493891	491379	14193X	PARTICIPANT	\N	EXCUSE	0
493909	491379	11065P	PARTICIPANT	\N	PRESENT	0
493910	491379	20044X	PARTICIPANT	\N	PRESENT	0
494012	491379	11056N	PARTICIPANT	\N	PRESENT	0
494013	491379	19399H	PARTICIPANT	\N	PRESENT	0
494016	491379	99004R	PARTICIPANT	\N	EXCUSE	0
494037	491379	11097X	PARTICIPANT	\N	PRESENT	0
494041	491379	19725B	PARTICIPANT	\N	EXCUSE	0
494102	493392	20038A	PARTICIPANT	\N	PRESENT	0
496335	496330	19679N	PARTICIPANT	\N	PRESENT	0
496331	496328	19679N	PARTICIPANT	\N	PRESENT	0
496332	496329	19679N	PARTICIPANT	\N	PRESENT	0
496389	495579	20046A	PARTICIPANT	\N	EXCUSE	0
496377	496375	04043D	PARTICIPANT	\N	PRESENT	0
496378	496375	19723Y	PARTICIPANT	\N	PRESENT	0
496379	496375	01034P	PARTICIPANT	\N	PRESENT	0
496380	496375	14213J	PARTICIPANT	\N	PRESENT	0
496383	496382	14071N	PARTICIPANT	\N	PRESENT	0
496387	495579	19701S	PARTICIPANT	\N	EXCUSE	0
496388	495579	19251M	PARTICIPANT	\N	EXCUSE	0
503155	501761	19681G	PARTICIPANT	\N	EXCUSE	0
503169	501761	20062A	PARTICIPANT	\N	PRESENT	0
503266	501761	17637T	PARTICIPANT	\N	EXCUSE	0
505341	501779	19695N	PARTICIPANT	\N	PRESENT	0
505342	501779	01025N	PARTICIPANT	\N	PRESENT	0
505343	501779	11090Q	PRESIDENT	0	PRESENT	0
505344	501779	14033T	PARTICIPANT	\N	PRESENT	1
505345	501779	20054A	PARTICIPANT	\N	PRESENT	0
505346	501779	20174H	PARTICIPANT	\N	PRESENT	0
505347	501779	14205J	PARTICIPANT	\N	PRESENT	0
505348	501779	20060X	PARTICIPANT	\N	PRESENT	1
505349	501779	20062A	PARTICIPANT	\N	PRESENT	0
505350	501779	19507S	PARTICIPANT	\N	PRESENT	0
505351	501779	14207L	PARTICIPANT	\N	PRESENT	1
505352	501779	14257W	PARTICIPANT	\N	PRESENT	0
505353	501779	19762G	PARTICIPANT	\N	PRESENT	0
505354	501779	08028W	PARTICIPANT	\N	EXCUSE	0
505355	501821	14169X	PARTICIPANT	\N	PRESENT	0
505356	501821	19573D	PARTICIPANT	\N	PRESENT	0
505357	501779	20082E	PARTICIPANT	\N	PRESENT	0
505358	501779	19575F	PARTICIPANT	\N	PRESENT	1
505360	501821	20102Q	PARTICIPANT	\N	PRESENT	0
505361	501821	19347U	PARTICIPANT	\N	PRESENT	0
505362	501821	19701S	PARTICIPANT	\N	PRESENT	0
505364	502450	14179A	PARTICIPANT	\N	PRESENT	0
505365	502450	19479G	PARTICIPANT	\N	PRESENT	0
505366	502450	19687N	PARTICIPANT	\N	PRESENT	0
505367	502450	14083S	PARTICIPANT	\N	PRESENT	0
505368	501821	95063L	PARTICIPANT	\N	PRESENT	0
505369	501821	20074E	PARTICIPANT	\N	PRESENT	0
505371	501821	19619A	PARTICIPANT	\N	PRESENT	0
505372	501821	20056C	PARTICIPANT	\N	PRESENT	0
505383	501821	20026V	PARTICIPANT	\N	PRESENT	0
505386	501821	19521Q	PARTICIPANT	\N	PRESENT	0
505387	501821	11115U	PARTICIPANT	\N	PRESENT	0
505391	501821	20038A	PARTICIPANT	\N	PRESENT	0
505397	501821	19563B	PARTICIPANT	\N	PRESENT	0
505398	501821	14073Q	PARTICIPANT	\N	PRESENT	0
505401	501821	19695N	PARTICIPANT	\N	PRESENT	0
505451	501822	19717B	PARTICIPANT	\N	PRESENT	0
505452	501822	19782L	PARTICIPANT	\N	PRESENT	0
505453	501822	19631V	PARTICIPANT	\N	PRESENT	0
505454	502450	19647E	PARTICIPANT	\N	PRESENT	0
505455	502450	12016W	PARTICIPANT	\N	PRESENT	0
505456	502450	20044X	PARTICIPANT	\N	PRESENT	0
505457	501822	11056N	PARTICIPANT	\N	PRESENT	0
505458	501822	19695N	PARTICIPANT	\N	PRESENT	0
505459	501822	19333N	PARTICIPANT	\N	PRESENT	0
505460	501822	19503N	PARTICIPANT	\N	PRESENT	0
505461	501822	19549D	PARTICIPANT	\N	PRESENT	0
505462	501822	11012A	PARTICIPANT	\N	PRESENT	0
505463	501822	20132W	PARTICIPANT	\N	PRESENT	0
505464	501822	19629C	PARTICIPANT	\N	PRESENT	0
505465	501822	19866P	PARTICIPANT	\N	PRESENT	0
505466	501822	20072C	PARTICIPANT	\N	PRESENT	0
505467	501822	20116W	PARTICIPANT	\N	PRESENT	0
505468	501822	19637C	PARTICIPANT	\N	PRESENT	0
505469	501822	20038A	PARTICIPANT	\N	PRESENT	0
505470	501822	20068G	PARTICIPANT	\N	PRESENT	0
505471	501822	20074E	PARTICIPANT	\N	PRESENT	0
505472	501822	18083K	PARTICIPANT	\N	PRESENT	0
505473	501822	17367Q	PARTICIPANT	\N	PRESENT	0
505474	501822	19533U	PARTICIPANT	\N	PRESENT	0
505475	501822	19521Q	PARTICIPANT	\N	PRESENT	0
505476	501822	19745F	PARTICIPANT	\N	PRESENT	0
505477	501822	19619A	PARTICIPANT	\N	PRESENT	0
505478	501822	01024M	PARTICIPANT	\N	PRESENT	0
505479	501822	14053L	PARTICIPANT	\N	PRESENT	0
505480	501822	19347U	PARTICIPANT	\N	PRESENT	0
505481	501822	19349W	PARTICIPANT	\N	PRESENT	0
505485	501822	19758L	PARTICIPANT	\N	PRESENT	0
505486	501822	14031R	PARTICIPANT	\N	PRESENT	0
505487	501822	19739H	PARTICIPANT	\N	PRESENT	0
505488	501822	14223L	PARTICIPANT	\N	PRESENT	0
505489	501822	20092G	PARTICIPANT	\N	PRESENT	0
505492	501822	19479G	PARTICIPANT	\N	PRESENT	0
505493	501822	14083S	PARTICIPANT	\N	PRESENT	0
505494	501822	19467C	PARTICIPANT	\N	PRESENT	0
505495	501822	14221J	PARTICIPANT	\N	PRESENT	0
505496	501822	19441R	PARTICIPANT	\N	PRESENT	0
505497	501822	20028X	PARTICIPANT	\N	PRESENT	0
505498	501822	14193X	PARTICIPANT	\N	PRESENT	0
505499	501822	14069U	PARTICIPANT	\N	PRESENT	0
505449	501822	01043Q	PARTICIPANT	\N	PRESENT	0
505450	501822	19387D	PARTICIPANT	\N	PRESENT	0
505500	501822	01057W	PARTICIPANT	\N	PRESENT	0
505501	501822	14357A	PARTICIPANT	\N	PRESENT	0
505505	501822	08015R	PARTICIPANT	\N	PRESENT	0
505506	501822	14021P	PARTICIPANT	\N	PRESENT	0
505507	501822	19553Y	PARTICIPANT	\N	PRESENT	0
505508	501822	14207L	PARTICIPANT	\N	PRESENT	0
505509	501822	19413M	PARTICIPANT	\N	PRESENT	0
505510	501822	14179A	PARTICIPANT	\N	PRESENT	0
505511	501822	19954N	PARTICIPANT	\N	PRESENT	0
505512	501822	20128B	PARTICIPANT	\N	PRESENT	0
505547	503724	20034V	PARTICIPANT	\N	PRESENT	0
508660	502322	20070A	PARTICIPANT	\N	PRESENT	0
508658	502322	86034E	PARTICIPANT	\N	PRESENT	0
508659	502322	01028R	PARTICIPANT	\N	PRESENT	0
508661	502322	14021P	PARTICIPANT	\N	PRESENT	0
508662	502322	19421M	PARTICIPANT	\N	PRESENT	0
508663	502322	19826F	PARTICIPANT	\N	PRESENT	0
508664	502322	11054L	PARTICIPANT	\N	PRESENT	0
508665	502322	19717B	PARTICIPANT	\N	PRESENT	0
508666	502322	20132W	PARTICIPANT	\N	PRESENT	0
508667	502322	19629C	PARTICIPANT	\N	PRESENT	0
508668	502322	20046A	PARTICIPANT	\N	PRESENT	0
508669	502322	97011G	PARTICIPANT	\N	PRESENT	0
508670	502322	95063L	PARTICIPANT	\N	PRESENT	0
508671	502322	18193Q	PARTICIPANT	\N	PRESENT	0
508675	502322	04034C	PARTICIPANT	\N	PRESENT	0
508673	502322	11033F	PARTICIPANT	\N	PRESENT	0
508674	502322	19251M	PARTICIPANT	\N	PRESENT	0
508676	502322	08015R	PARTICIPANT	\N	PRESENT	0
508677	502322	19758L	PARTICIPANT	\N	PRESENT	0
508678	502322	04085P	PARTICIPANT	\N	PRESENT	0
508679	502322	20028X	PARTICIPANT	\N	PRESENT	0
508680	502322	19565D	PARTICIPANT	\N	PRESENT	0
508681	502322	19695N	PARTICIPANT	\N	PRESENT	0
508682	502322	19593H	PARTICIPANT	\N	PRESENT	0
508683	502322	20018V	PARTICIPANT	\N	PRESENT	0
508684	502322	20082E	PARTICIPANT	\N	PRESENT	0
508685	502322	20092G	PARTICIPANT	\N	PRESENT	0
508686	502322	19347U	PARTICIPANT	\N	PRESENT	0
508687	502322	19689Q	PARTICIPANT	\N	PRESENT	0
508688	502322	20084G	PARTICIPANT	\N	PRESENT	0
508689	502322	19647E	PARTICIPANT	\N	PRESENT	0
508785	502322	05012A	PARTICIPANT	\N	PRESENT	0
508691	502322	11064N	PARTICIPANT	\N	PRESENT	0
508692	502322	19545Y	PARTICIPANT	\N	PRESENT	0
508693	502322	14195A	PARTICIPANT	\N	PRESENT	0
508694	502322	14221J	PARTICIPANT	\N	PRESENT	0
508695	502322	04057K	PARTICIPANT	\N	PRESENT	0
508696	502322	19369B	PARTICIPANT	\N	PRESENT	0
508697	502322	20066E	PARTICIPANT	\N	PRESENT	0
508698	502322	20052X	PARTICIPANT	\N	PRESENT	0
508699	502322	14030Q	PARTICIPANT	\N	PRESENT	0
508700	502322	19569H	PARTICIPANT	\N	PRESENT	0
508701	502322	20144B	PARTICIPANT	\N	PRESENT	0
508702	502322	08009T	PARTICIPANT	\N	PRESENT	0
508703	502322	98022P	PARTICIPANT	\N	PRESENT	0
508704	502322	20072C	PARTICIPANT	\N	PRESENT	0
508705	502322	11083R	PARTICIPANT	\N	PRESENT	0
508706	502322	19333N	PARTICIPANT	\N	PRESENT	0
508707	502322	19503N	PARTICIPANT	\N	PRESENT	0
508708	502322	11074Q	PARTICIPANT	\N	PRESENT	0
508709	502322	08061X	PARTICIPANT	\N	PRESENT	0
508710	502322	19691J	PARTICIPANT	\N	PRESENT	0
508711	502322	20040T	PARTICIPANT	\N	PRESENT	0
508712	502322	14255U	PARTICIPANT	\N	PRESENT	0
508713	502322	14267Y	PARTICIPANT	\N	PRESENT	0
508714	502322	14055N	PARTICIPANT	\N	PRESENT	0
508715	502322	20116W	PARTICIPANT	\N	PRESENT	0
508716	502322	19415P	PARTICIPANT	\N	PRESENT	0
508717	502322	19747H	PARTICIPANT	\N	PRESENT	0
508718	502322	04092N	PARTICIPANT	\N	PRESENT	0
508719	502322	11066Q	PARTICIPANT	\N	PRESENT	0
508720	502322	20134Y	PARTICIPANT	\N	PRESENT	0
508721	502322	14237S	PARTICIPANT	\N	PRESENT	0
508722	502322	19533U	PARTICIPANT	\N	PRESENT	0
508723	502322	19621T	PARTICIPANT	\N	PRESENT	0
508724	502322	10006L	PARTICIPANT	\N	PRESENT	0
508725	502322	11097X	PARTICIPANT	\N	PRESENT	0
508726	502322	14217N	PARTICIPANT	\N	PRESENT	0
508727	502322	14329V	PARTICIPANT	\N	PRESENT	0
508728	502322	14059S	PARTICIPANT	\N	PRESENT	0
508729	502322	14187A	PARTICIPANT	\N	PRESENT	0
508730	502322	20090E	PARTICIPANT	\N	PRESENT	0
508731	502322	20062A	PARTICIPANT	\N	PRESENT	0
508732	502322	19591F	PARTICIPANT	\N	PRESENT	0
508733	502322	19966S	PARTICIPANT	\N	PRESENT	0
508734	502322	19399H	PARTICIPANT	\N	PRESENT	0
508735	502322	18083K	PARTICIPANT	\N	PRESENT	0
508736	502322	20106U	PARTICIPANT	\N	PRESENT	0
508737	502322	19543W	PARTICIPANT	\N	PRESENT	0
508738	502322	20136B	PARTICIPANT	\N	PRESENT	0
508739	502322	17737W	PARTICIPANT	\N	PRESENT	0
508740	502322	20022R	PARTICIPANT	\N	PRESENT	0
508741	502322	14259Y	PARTICIPANT	\N	PRESENT	0
508742	502322	20140W	PARTICIPANT	\N	PRESENT	0
508743	502322	14223L	PARTICIPANT	\N	PRESENT	0
508744	502322	04042C	PARTICIPANT	\N	PRESENT	0
508745	502322	01058X	PARTICIPANT	\N	PRESENT	0
508746	502322	99004R	PARTICIPANT	\N	PRESENT	0
508747	502322	14211G	PARTICIPANT	\N	PRESENT	0
508748	502322	04033B	PARTICIPANT	\N	PRESENT	0
508749	502322	17367Q	PARTICIPANT	\N	PRESENT	0
508750	502322	14083S	PARTICIPANT	\N	PRESENT	0
508751	502322	01057W	PARTICIPANT	\N	PRESENT	0
508752	502322	19766L	PARTICIPANT	\N	PRESENT	0
508753	502322	19515S	PARTICIPANT	\N	PRESENT	0
508754	502322	19643A	PARTICIPANT	\N	PRESENT	0
508755	502322	20038A	PARTICIPANT	\N	PRESENT	0
508756	502322	19673G	PARTICIPANT	\N	PRESENT	0
508757	502322	20032T	PARTICIPANT	\N	PRESENT	0
508758	502322	20096L	PARTICIPANT	\N	PRESENT	0
508762	502322	19467C	PARTICIPANT	\N	PRESENT	0
508760	502322	14038Y	PARTICIPANT	\N	PRESENT	0
508761	502322	19675J	PARTICIPANT	\N	PRESENT	0
508763	502322	20026V	PARTICIPANT	\N	PRESENT	0
508764	502322	20056C	PARTICIPANT	\N	PRESENT	0
508765	502322	14169X	PARTICIPANT	\N	PRESENT	0
508766	502322	20174H	PARTICIPANT	\N	PRESENT	0
508767	502322	19709B	PARTICIPANT	\N	PRESENT	0
508768	502322	20086J	PARTICIPANT	\N	PRESENT	0
508769	502322	20044X	PARTICIPANT	\N	PRESENT	0
508770	502322	19711U	PARTICIPANT	\N	PRESENT	0
508771	502322	14042U	PARTICIPANT	\N	PRESENT	0
508772	502322	14073Q	PARTICIPANT	\N	PRESENT	0
508773	502322	20102Q	PARTICIPANT	\N	PRESENT	0
508774	502322	19760E	PARTICIPANT	\N	PRESENT	0
508775	502322	08017T	PARTICIPANT	\N	PRESENT	0
508776	502322	14253S	PARTICIPANT	\N	PRESENT	0
508777	502322	11012A	PARTICIPANT	\N	PRESENT	0
508778	502322	19703U	PARTICIPANT	\N	PRESENT	0
508779	502322	20094J	PARTICIPANT	\N	PRESENT	0
508780	502322	11027H	PARTICIPANT	\N	PRESENT	0
508781	502322	08034U	PARTICIPANT	\N	PRESENT	0
508782	502322	19549D	PARTICIPANT	\N	PRESENT	0
508783	502322	20050V	PARTICIPANT	\N	PRESENT	0
508784	502322	20122U	PARTICIPANT	\N	PRESENT	0
508786	502322	11067R	PARTICIPANT	\N	PRESENT	0
508788	502322	14213J	PARTICIPANT	\N	PRESENT	0
511507	509855	19333N	PARTICIPANT	\N	PRESENT	0
511508	509855	20136B	PARTICIPANT	\N	PRESENT	0
511509	509855	14031R	PARTICIPANT	\N	PRESENT	0
511510	509855	19549D	PARTICIPANT	\N	PRESENT	0
511511	509855	20076G	PARTICIPANT	\N	PRESENT	0
511512	509855	14219Q	PRESIDENT	0	PRESENT	0
511513	509855	19826F	PARTICIPANT	\N	PRESENT	0
511514	509855	20102Q	PARTICIPANT	\N	PRESENT	0
511515	509855	14169X	PARTICIPANT	\N	PRESENT	0
511516	509855	20020P	PARTICIPANT	\N	PRESENT	0
511517	509855	17367Q	PARTICIPANT	\N	PRESENT	0
511518	509855	20024T	PARTICIPANT	\N	PRESENT	0
511519	509855	17637T	PARTICIPANT	\N	PRESENT	0
511520	509855	20068G	PARTICIPANT	\N	PRESENT	0
511521	509855	19739H	PARTICIPANT	\N	PRESENT	0
511522	509855	20032T	PARTICIPANT	\N	PRESENT	0
511523	509855	17229F	PARTICIPANT	\N	PRESENT	0
511524	509855	20046A	PARTICIPANT	\N	PRESENT	0
511525	509855	19820Y	PARTICIPANT	\N	PRESENT	0
511526	509855	18083K	PARTICIPANT	\N	PRESENT	0
511527	509855	19551W	PARTICIPANT	\N	PRESENT	0
511528	509855	20100N	PARTICIPANT	\N	PRESENT	0
511529	509855	19503N	PARTICIPANT	\N	PRESENT	0
511530	509855	20038A	PARTICIPANT	\N	PRESENT	0
511531	509855	19251M	PARTICIPANT	\N	PRESENT	0
511532	509855	11101A	PARTICIPANT	\N	PRESENT	0
511533	509855	19745F	PARTICIPANT	\N	PRESENT	0
511534	509855	19619A	PARTICIPANT	\N	PRESENT	0
511535	509855	19659J	PARTICIPANT	\N	PRESENT	1
511536	509855	19577H	PARTICIPANT	\N	PRESENT	1
511537	509855	19637C	PARTICIPANT	\N	PRESENT	1
511538	509855	19681G	PARTICIPANT	\N	EXCUSE	0
511539	509855	19387D	PARTICIPANT	\N	PRESENT	1
511540	509855	19525U	PARTICIPANT	\N	PRESENT	1
483409	483408	11026G	PARTICIPANT	\N	PRESENT	0
483410	483386	11070L	PARTICIPANT	\N	PRESENT	0
483412	483411	19705W	PARTICIPANT	\N	PRESENT	0
483413	483411	19631V	PARTICIPANT	\N	PRESENT	0
483414	483411	19866P	PARTICIPANT	\N	PRESENT	0
483416	483415	19631V	PARTICIPANT	\N	PRESENT	0
483417	483415	19705W	PARTICIPANT	\N	PRESENT	0
483418	483415	19866P	PARTICIPANT	\N	PRESENT	0
483419	483415	14135M	PARTICIPANT	\N	PRESENT	0
483421	483420	19705W	PARTICIPANT	\N	PRESENT	0
483422	483420	14135M	PARTICIPANT	\N	PRESENT	0
483423	483420	19631V	PARTICIPANT	\N	PRESENT	0
483425	483424	19631V	PARTICIPANT	\N	PRESENT	0
483426	483424	19705W	PARTICIPANT	\N	PRESENT	0
483427	483424	14135M	PARTICIPANT	\N	PRESENT	0
483429	483428	04043D	PARTICIPANT	\N	PRESENT	0
483431	483430	04043D	PARTICIPANT	\N	PRESENT	0
483432	483430	14205J	PARTICIPANT	\N	PRESENT	0
483434	483164	19479G	PARTICIPANT	\N	PRESENT	0
483435	483164	07004J	PARTICIPANT	\N	PRESENT	0
483436	483164	96004D	PARTICIPANT	\N	PRESENT	0
483437	483164	19671E	PARTICIPANT	\N	PRESENT	0
483438	483164	14225N	PARTICIPANT	\N	PRESENT	0
483439	483164	04086Q	PARTICIPANT	\N	PRESENT	0
483440	483164	14331P	PARTICIPANT	\N	PRESENT	0
483441	483164	19711U	PARTICIPANT	\N	PRESENT	0
483442	483164	19545Y	PARTICIPANT	\N	PRESENT	0
483443	483164	11074Q	PRESIDENT	0	PRESENT	0
483444	483164	08011M	PARTICIPANT	\N	PRESENT	0
483445	483164	08014Q	PARTICIPANT	\N	PRESENT	0
483446	483164	11048N	PARTICIPANT	\N	PRESENT	0
483447	483164	19531S	PARTICIPANT	\N	PRESENT	0
483448	483164	01057W	PARTICIPANT	\N	PRESENT	0
483449	483164	14085U	PARTICIPANT	\N	PRESENT	0
483450	481561	11080N	PARTICIPANT	\N	PRESENT	0
483451	481561	19421M	PARTICIPANT	\N	PRESENT	0
483452	481561	07004J	PARTICIPANT	\N	PRESENT	0
483453	481561	11026G	PARTICIPANT	\N	PRESENT	0
483454	481561	04040A	PARTICIPANT	\N	PRESENT	0
483455	481561	08010L	PARTICIPANT	\N	PRESENT	0
483456	481561	08053X	PARTICIPANT	\N	PRESENT	0
483457	481561	04044E	PARTICIPANT	\N	PRESENT	0
483458	481561	19671E	PARTICIPANT	\N	PRESENT	0
483459	481561	19673G	PARTICIPANT	\N	PRESENT	0
483460	481561	19719D	PRESIDENT	0	PRESENT	0
483461	481561	14249W	PARTICIPANT	\N	PRESENT	0
483462	481561	19669L	PARTICIPANT	\N	PRESENT	0
483466	481561	19721W	PARTICIPANT	\N	PRESENT	0
488591	488430	11097X	PRESIDENT	0	PRESENT	0
488592	488430	10006L	PARTICIPANT	\N	PRESENT	0
488593	488430	19715Y	PARTICIPANT	\N	PRESENT	0
488594	488430	11067R	PARTICIPANT	\N	PRESENT	0
488595	488430	19683J	PARTICIPANT	\N	PRESENT	0
488596	488430	11031D	PARTICIPANT	\N	PRESENT	0
488597	488430	04059M	PARTICIPANT	\N	PRESENT	0
488598	488430	19503N	PARTICIPANT	\N	PRESENT	0
488599	488430	19703U	PARTICIPANT	\N	PRESENT	0
488600	488430	19553Y	PARTICIPANT	\N	PRESENT	0
488601	488430	19691J	PARTICIPANT	\N	PRESENT	0
488602	488430	04092N	PARTICIPANT	\N	EXCUSE	0
488603	488430	19479G	PARTICIPANT	\N	PRESENT	0
488604	488430	11012A	PARTICIPANT	\N	EXCUSE	0
488605	488430	19573D	PARTICIPANT	\N	PRESENT	0
488606	488430	19643A	PARTICIPANT	\N	EXCUSE	0
488607	488430	89017R	PARTICIPANT	\N	EXCUSE	0
488608	488430	19667J	PARTICIPANT	0	PRESENT	0
488609	488430	11048N	PARTICIPANT	\N	PRESENT	0
488610	488430	14081Q	PARTICIPANT	\N	PRESENT	0
488611	488430	19545Y	PARTICIPANT	\N	PRESENT	0
488612	488430	14331P	PARTICIPANT	\N	PRESENT	0
488613	488430	19663E	PARTICIPANT	\N	PRESENT	0
488614	488430	19649G	PARTICIPANT	\N	PRESENT	0
488615	488430	19447X	PARTICIPANT	\N	PRESENT	0
492043	491414	20024T	PARTICIPANT	\N	PRESENT	0
492044	491414	19766L	PARTICIPANT	\N	PRESENT	0
492045	491414	19515S	PARTICIPANT	\N	PRESENT	0
492046	491414	20076G	PARTICIPANT	\N	PRESENT	0
492047	491414	19703U	PARTICIPANT	\N	PRESENT	0
492048	491414	19447X	PARTICIPANT	\N	PRESENT	0
492049	491414	14041T	PARTICIPANT	\N	PRESENT	0
492050	491414	20056C	PARTICIPANT	\N	PRESENT	0
492051	491414	14033T	PARTICIPANT	\N	PRESENT	0
492052	491414	20038A	PARTICIPANT	\N	PRESENT	0
492053	491414	14215L	PARTICIPANT	\N	PRESENT	0
492054	491414	20044X	PARTICIPANT	\N	PRESENT	0
492055	491414	20120S	PARTICIPANT	\N	PRESENT	0
492056	491414	19621T	PARTICIPANT	\N	PRESENT	0
492057	491414	20068G	PARTICIPANT	\N	PRESENT	0
492058	491414	11043H	PARTICIPANT	\N	PRESENT	0
492059	491414	19647E	PARTICIPANT	\N	PRESENT	0
492060	491414	11056N	PARTICIPANT	\N	PRESENT	0
492061	491414	20034V	PARTICIPANT	\N	PRESENT	0
492062	491414	14187A	PARTICIPANT	\N	PRESENT	0
492063	491414	19383Y	PARTICIPANT	\N	PRESENT	0
492064	491414	19507S	PARTICIPANT	\N	PRESENT	0
492065	491414	04033B	PARTICIPANT	\N	PRESENT	0
492066	491414	19489J	PARTICIPANT	\N	PRESENT	0
492067	491414	19415P	PARTICIPANT	\N	PRESENT	0
492068	491414	14111D	PARTICIPANT	\N	PRESENT	0
492069	491414	08069G	PARTICIPANT	\N	PRESENT	0
492070	491414	14213J	PARTICIPANT	\N	PRESENT	0
492071	491414	19701S	PARTICIPANT	\N	PRESENT	0
492072	491414	11090Q	PARTICIPANT	\N	PRESENT	0
492073	491414	14255U	PARTICIPANT	\N	PRESENT	0
492074	491414	11026G	PARTICIPANT	\N	PRESENT	0
492492	491475	14038Y	PARTICIPANT	\N	PRESENT	0
492494	491475	19549D	PARTICIPANT	\N	PRESENT	0
492896	491469	14133K	PARTICIPANT	\N	PRESENT	0
492897	491469	14267Y	PARTICIPANT	\N	PRESENT	0
492898	491469	11083R	PARTICIPANT	\N	PRESENT	0
492899	491469	14211G	PARTICIPANT	\N	PRESENT	0
492900	491469	20128B	PARTICIPANT	\N	PRESENT	0
492901	491469	16685X	PARTICIPANT	\N	PRESENT	0
492902	491469	01058X	PARTICIPANT	\N	PRESENT	0
492960	491475	17367Q	PARTICIPANT	\N	PRESENT	0
492961	491475	11101A	PARTICIPANT	\N	PRESENT	0
492962	491475	20038A	PARTICIPANT	\N	PRESENT	0
492965	491475	20118Y	PARTICIPANT	\N	PRESENT	0
493021	493017	14042U	PARTICIPANT	\N	PRESENT	0
493162	493161	05008E	PARTICIPANT	\N	PRESENT	0
493163	493161	11053K	PARTICIPANT	\N	PRESENT	0
493164	493161	01028R	PARTICIPANT	\N	PRESENT	0
493167	493166	11053K	PARTICIPANT	\N	PRESENT	0
493168	493166	14159V	PARTICIPANT	\N	PRESENT	0
493169	493166	05012A	PARTICIPANT	\N	PRESENT	0
493171	493170	05008E	PARTICIPANT	\N	PRESENT	0
493172	493170	11053K	PARTICIPANT	\N	PRESENT	0
493173	493170	01028R	PARTICIPANT	\N	PRESENT	0
493271	492088	19699S	PARTICIPANT	\N	EXCUSE	0
493296	491478	04092N	PRESIDENT	0	PRESENT	0
493297	491478	19479G	PARTICIPANT	\N	PRESENT	0
493298	491478	10006L	PARTICIPANT	\N	PRESENT	0
493299	491478	11031D	PARTICIPANT	\N	PRESENT	0
493300	491478	99004R	PARTICIPANT	\N	PRESENT	0
492041	491414	19741B	PARTICIPANT	\N	PRESENT	0
492042	491414	14147R	PARTICIPANT	\N	PRESENT	0
493301	491478	19713W	PARTICIPANT	\N	PRESENT	0
493302	491478	19503N	PARTICIPANT	\N	PRESENT	0
493303	491478	20130U	PARTICIPANT	\N	PRESENT	0
493304	491478	11067R	PARTICIPANT	\N	PRESENT	0
493305	491478	19447X	PARTICIPANT	\N	PRESENT	0
493306	491478	11097X	PARTICIPANT	\N	PRESENT	0
493307	491478	19683J	PARTICIPANT	\N	PRESENT	0
493308	491478	19697Q	PARTICIPANT	\N	PRESENT	0
493314	491478	11012A	PARTICIPANT	\N	EXCUSE	0
493320	492088	19643A	PARTICIPANT	\N	PRESENT	0
493321	492088	19719D	PARTICIPANT	\N	PRESENT	0
493322	492088	20134Y	PARTICIPANT	\N	PRESENT	0
493323	492088	20124W	PARTICIPANT	\N	PRESENT	0
493324	492088	11104D	PARTICIPANT	\N	PRESENT	0
493325	492088	20084G	PARTICIPANT	\N	PRESENT	0
493326	492088	19527W	PARTICIPANT	\N	PRESENT	0
493331	493330	14255U	PARTICIPANT	\N	PRESENT	0
493333	493332	01034P	PARTICIPANT	\N	PRESENT	0
493334	493332	11097X	PARTICIPANT	\N	PRESENT	0
493336	493335	14042U	PARTICIPANT	\N	PRESENT	0
493354	493353	08010L	PARTICIPANT	\N	PRESENT	0
493373	493372	11053K	PARTICIPANT	\N	PRESENT	0
493375	493374	11053K	PARTICIPANT	\N	PRESENT	0
493389	493388	04071H	PARTICIPANT	\N	PRESENT	0
493400	493399	04070G	PARTICIPANT	\N	PRESENT	0
493494	493370	19749K	PARTICIPANT	\N	PRESENT	0
493495	493370	19954N	PARTICIPANT	\N	PRESENT	0
493496	493370	04047H	PRESIDENT	0	PRESENT	0
493497	493370	19447X	PARTICIPANT	\N	PRESENT	0
493498	493370	19585H	PARTICIPANT	\N	PRESENT	0
507799	505798	14001X	PARTICIPANT	\N	PRESENT	0
507800	505798	04008A	PARTICIPANT	\N	PRESENT	0
507801	505798	19543W	PARTICIPANT	\N	PRESENT	0
507802	505963	19549D	PARTICIPANT	\N	PRESENT	0
507803	505963	18083K	PARTICIPANT	\N	PRESENT	0
507804	505963	20106U	PARTICIPANT	\N	PRESENT	0
507805	505963	20100N	PARTICIPANT	\N	PRESENT	1
507806	506033	19697Q	PARTICIPANT	\N	PRESENT	1
507807	506033	20090E	PARTICIPANT	\N	PRESENT	0
507808	506033	19798U	PARTICIPANT	\N	PRESENT	1
507809	506033	19569H	PARTICIPANT	\N	PRESENT	0
507810	506033	11097X	PARTICIPANT	\N	PRESENT	0
507811	506033	14223L	PARTICIPANT	\N	PRESENT	0
507812	506033	17779H	PARTICIPANT	\N	PRESENT	0
507813	506033	19703U	PARTICIPANT	\N	PRESENT	0
507814	506033	14281W	PARTICIPANT	\N	PRESENT	1
507815	506033	19679N	PARTICIPANT	\N	PRESENT	0
507816	506033	14042U	PARTICIPANT	\N	PRESENT	0
507817	506033	14213J	PARTICIPANT	\N	PRESENT	0
507818	506033	19367Y	PARTICIPANT	\N	PRESENT	0
507819	506033	14217N	PARTICIPANT	0	PRESENT	0
507820	506033	19683J	PARTICIPANT	\N	PRESENT	0
507821	506033	10006L	PRESIDENT	0	PRESENT	0
507822	506033	20130U	PARTICIPANT	\N	PRESENT	1
507823	506033	01034P	PARTICIPANT	\N	PRESENT	0
507824	506033	04092N	PARTICIPANT	\N	PRESENT	0
507825	506033	19713W	PARTICIPANT	\N	PRESENT	0
507826	506033	19691J	PARTICIPANT	\N	PRESENT	0
507827	506033	19717B	PARTICIPANT	\N	PRESENT	1
507828	506033	11103C	PARTICIPANT	\N	PRESENT	0
507829	506033	04043D	PARTICIPANT	\N	PRESENT	0
507830	506033	19760E	PARTICIPANT	\N	PRESENT	0
507832	506005	14097Y	PARTICIPANT	\N	PRESENT	0
507833	506005	01058X	PARTICIPANT	\N	PRESENT	0
507834	506005	11027H	PARTICIPANT	\N	PRESENT	0
507836	506005	04042C	PRESIDENT	0	PRESENT	0
507837	506005	97011G	PARTICIPANT	\N	PRESENT	0
507838	506005	19669L	PARTICIPANT	\N	PRESENT	0
507839	506005	11066Q	PARTICIPANT	\N	PRESENT	0
507840	506005	14211G	PARTICIPANT	\N	PRESENT	0
507841	506005	08047A	PARTICIPANT	\N	PRESENT	0
507842	506005	19721W	PARTICIPANT	\N	PRESENT	0
507843	506005	20128B	PARTICIPANT	\N	PRESENT	0
507844	506005	19421M	PARTICIPANT	\N	PRESENT	0
507846	506005	19565D	PARTICIPANT	\N	PRESENT	0
507848	506005	14255U	PARTICIPANT	\N	PRESENT	0
507849	506005	19709B	PARTICIPANT	\N	PRESENT	0
507850	506005	19347U	PARTICIPANT	\N	PRESENT	0
507851	505798	17737W	PARTICIPANT	\N	PRESENT	0
507852	505798	14259Y	PARTICIPANT	\N	PRESENT	0
507853	506005	20072C	PARTICIPANT	\N	PRESENT	1
507854	506005	14105F	PARTICIPANT	\N	PRESENT	1
507855	506005	14059S	PARTICIPANT	\N	PRESENT	0
507856	506005	19443T	PARTICIPANT	\N	PRESENT	1
507857	505963	11065P	PARTICIPANT	\N	PRESENT	0
507858	506033	19415P	PARTICIPANT	\N	PRESENT	0
507859	506033	19553Y	PARTICIPANT	\N	PRESENT	1
507860	506033	14195A	PARTICIPANT	\N	PRESENT	0
507861	506033	11045K	PARTICIPANT	\N	PRESENT	1
507862	506033	08045X	PARTICIPANT	\N	PRESENT	1
507863	506033	19715Y	PARTICIPANT	\N	PRESENT	1
507864	506033	20172F	PARTICIPANT	\N	PRESENT	0
507865	506033	19723Y	PARTICIPANT	\N	PRESENT	0
507866	506033	20066E	PARTICIPANT	\N	PRESENT	0
507867	506033	14071N	PARTICIPANT	\N	PRESENT	0
507868	506033	19657G	PARTICIPANT	\N	PRESENT	1
507869	506005	01024M	PARTICIPANT	\N	PRESENT	0
507870	506005	11064N	PARTICIPANT	\N	PRESENT	0
507875	507831	19766L	PARTICIPANT	\N	PRESENT	0
507876	507831	04070G	PARTICIPANT	\N	PRESENT	0
507877	507831	19699S	PARTICIPANT	\N	PRESENT	1
507878	507831	19533U	PARTICIPANT	\N	PRESENT	0
507879	507831	04033B	PARTICIPANT	\N	PRESENT	0
507880	507831	14229S	PARTICIPANT	\N	PRESENT	0
507881	507831	20098N	PARTICIPANT	\N	PRESENT	1
507882	507831	08017T	PARTICIPANT	\N	PRESENT	0
507883	507831	20112S	PARTICIPANT	\N	PRESENT	0
507884	507831	07033P	PARTICIPANT	\N	PRESENT	0
507885	507831	08061X	PARTICIPANT	\N	PRESENT	0
507886	507831	20124W	PARTICIPANT	\N	PRESENT	1
507887	507831	20026V	PARTICIPANT	\N	PRESENT	0
507888	507831	19593H	PARTICIPANT	\N	PRESENT	0
507889	507831	19527W	PARTICIPANT	\N	PRESENT	1
507890	507831	19643A	PARTICIPANT	\N	PRESENT	1
507891	507831	14073Q	PARTICIPANT	\N	PRESENT	0
507892	507831	19651A	PARTICIPANT	\N	PRESENT	0
507893	507831	20138D	PARTICIPANT	\N	PRESENT	0
507894	507831	19611R	PRESIDENT	0	PRESENT	0
507895	507831	20142Y	PARTICIPANT	\N	PRESENT	0
507896	507831	19693L	PARTICIPANT	\N	PRESENT	1
507897	507831	19399H	PARTICIPANT	\N	PRESENT	1
507898	507831	20152B	PARTICIPANT	\N	PRESENT	0
507899	507831	19719D	PARTICIPANT	\N	PRESENT	1
507900	507831	20052X	PARTICIPANT	\N	PRESENT	0
507901	507831	20056C	PARTICIPANT	\N	PRESENT	0
507902	507831	19735D	PARTICIPANT	\N	PRESENT	1
507903	507831	14109K	PARTICIPANT	\N	PRESENT	1
507904	507831	14123H	PARTICIPANT	\N	PRESENT	0
507905	507831	11043H	PARTICIPANT	\N	PRESENT	0
507906	507831	11104D	PARTICIPANT	\N	PRESENT	1
507907	507831	19758L	PARTICIPANT	\N	PRESENT	0
507908	507831	20084G	PARTICIPANT	\N	PRESENT	0
507909	507831	19621T	PARTICIPANT	\N	PRESENT	1
507911	505963	17229F	PARTICIPANT	\N	PRESENT	0
507912	506005	16685X	PARTICIPANT	\N	PRESENT	0
507913	507831	04059M	PARTICIPANT	\N	PRESENT	0
507914	506005	04034C	PARTICIPANT	\N	PRESENT	1
507915	505804	20088L	PARTICIPANT	\N	PRESENT	1
507916	505804	19515S	PARTICIPANT	\N	PRESENT	0
507917	505804	19782L	PARTICIPANT	\N	PRESENT	0
507918	505804	11077T	PARTICIPANT	\N	PRESENT	1
507919	505804	20092G	PARTICIPANT	\N	PRESENT	1
507920	505804	01043Q	PARTICIPANT	\N	PRESENT	0
507921	505804	19441R	PARTICIPANT	\N	PRESENT	1
507922	505804	19413M	PARTICIPANT	\N	PRESENT	1
507923	505804	20082E	PARTICIPANT	\N	PRESENT	1
507924	505804	20094J	PARTICIPANT	\N	PRESENT	0
507925	505804	04045F	PARTICIPANT	\N	PRESENT	0
507926	505804	20104S	PARTICIPANT	\N	PRESENT	0
507927	505804	19631V	PARTICIPANT	\N	PRESENT	0
507928	505804	11099A	PARTICIPANT	\N	PRESENT	0
507929	505804	19705W	PARTICIPANT	\N	PRESENT	0
507930	505804	20018V	PARTICIPANT	\N	PRESENT	0
507931	505804	08028W	PARTICIPANT	\N	PRESENT	1
507932	505804	19563B	PARTICIPANT	\N	PRESENT	0
507933	505804	19521Q	PARTICIPANT	\N	PRESENT	0
507934	505804	19467C	PARTICIPANT	\N	PRESENT	0
507935	505804	20034V	PARTICIPANT	\N	PRESENT	0
507936	505804	14187A	PRESIDENT	0	PRESENT	0
507937	505804	20144B	PARTICIPANT	\N	PRESENT	0
507938	505804	19695N	PARTICIPANT	\N	PRESENT	0
507939	505804	01025N	PARTICIPANT	\N	PRESENT	0
507940	505804	20054A	PARTICIPANT	\N	PRESENT	0
507941	505804	14205J	PARTICIPANT	\N	PRESENT	0
507942	505804	20060X	PARTICIPANT	\N	PRESENT	1
507943	505804	20062A	PARTICIPANT	\N	PRESENT	1
507944	505804	14251Q	PARTICIPANT	\N	PRESENT	1
507945	505804	19747H	PARTICIPANT	\N	PRESENT	0
507946	505804	14207L	PARTICIPANT	\N	PRESENT	0
507947	505804	14257W	PARTICIPANT	\N	PRESENT	0
507948	506005	20042V	PARTICIPANT	\N	PRESENT	1
507949	505804	19383Y	PARTICIPANT	\N	PRESENT	0
507950	505804	19768N	PARTICIPANT	\N	PRESENT	1
507951	505804	14033T	PARTICIPANT	\N	PRESENT	1
507974	502321	19349W	PARTICIPANT	\N	PRESENT	0
507975	502321	14357A	PARTICIPANT	\N	PRESENT	0
507976	502321	19669L	PARTICIPANT	\N	PRESENT	0
507977	502321	07029T	PARTICIPANT	\N	PRESENT	0
507978	502321	20080C	PARTICIPANT	\N	PRESENT	0
507979	502321	19503N	PARTICIPANT	\N	PRESENT	0
507980	502321	11040E	PARTICIPANT	\N	PRESENT	0
507981	502321	19687N	PARTICIPANT	\N	PRESENT	0
507982	502321	08009T	PARTICIPANT	\N	PRESENT	0
507983	502321	07004J	PARTICIPANT	\N	PRESENT	0
507984	502321	11053K	PARTICIPANT	\N	PRESENT	0
507985	502321	19479G	PARTICIPANT	\N	PRESENT	0
507986	502321	19713W	PARTICIPANT	\N	PRESENT	0
507987	502321	20050V	PARTICIPANT	\N	PRESENT	0
485078	484729	19711U	PARTICIPANT	\N	PRESENT	0
485079	484729	19399H	PARTICIPANT	\N	PRESENT	0
485080	484729	11070L	PARTICIPANT	\N	PRESENT	0
485081	484729	19525U	PARTICIPANT	\N	PRESENT	0
485082	484729	19741B	PARTICIPANT	\N	PRESENT	0
485083	484729	14121F	PRESIDENT	0	PRESENT	0
485093	484729	19551W	PARTICIPANT	\N	EXCUSE	0
485094	484729	19737F	PARTICIPANT	\N	EXCUSE	0
485105	484729	14069U	PARTICIPANT	\N	PRESENT	0
488769	488447	19527W	PARTICIPANT	\N	PRESENT	0
488770	488447	14097Y	PARTICIPANT	\N	PRESENT	0
488771	488447	14093U	PARTICIPANT	\N	PRESENT	0
488772	488447	11048N	PARTICIPANT	\N	PRESENT	0
488773	488447	19611R	PRESIDENT	0	PRESENT	0
488774	488447	19549D	PARTICIPANT	\N	PRESENT	0
488775	488447	19687N	PARTICIPANT	\N	PRESENT	0
488776	488447	14197C	PARTICIPANT	\N	PRESENT	0
488777	488447	19369B	PARTICIPANT	\N	PRESENT	0
489655	489408	18083K	PARTICIPANT	\N	PRESENT	0
489656	489408	11040E	PARTICIPANT	\N	PRESENT	0
489657	489408	04086Q	PARTICIPANT	\N	PRESENT	0
489658	489408	11048N	PARTICIPANT	\N	PRESENT	0
489659	489408	19711U	PARTICIPANT	\N	PRESENT	0
489660	489408	14085U	PARTICIPANT	\N	PRESENT	0
489661	489408	01057W	PARTICIPANT	\N	PRESENT	0
489662	489408	11074Q	PRESIDENT	0	PRESENT	0
489663	489408	88008L	PARTICIPANT	\N	PRESENT	0
489664	489408	19479G	PARTICIPANT	\N	PRESENT	0
489665	489408	14327T	PARTICIPANT	\N	EXCUSE	0
489666	489408	07029T	PARTICIPANT	\N	EXCUSE	0
489667	489408	11012A	PARTICIPANT	\N	EXCUSE	0
489668	489408	08069G	PARTICIPANT	\N	EXCUSE	0
489669	489408	96004D	PARTICIPANT	\N	EXCUSE	0
489670	489408	08010L	PARTICIPANT	\N	EXCUSE	0
489671	489408	89017R	PARTICIPANT	\N	EXCUSE	0
489672	489408	08011M	PARTICIPANT	\N	EXCUSE	0
489673	489408	14034U	PARTICIPANT	\N	EXCUSE	0
489674	489408	14225N	PARTICIPANT	\N	EXCUSE	0
489698	489408	19741B	PARTICIPANT	\N	PRESENT	0
489700	489408	19651A	PARTICIPANT	\N	PRESENT	0
489701	489408	19647E	PARTICIPANT	\N	PRESENT	0
491603	491485	19954N	PARTICIPANT	\N	PRESENT	0
491604	491485	04008A	PARTICIPANT	\N	PRESENT	0
491605	491485	14179A	PARTICIPANT	\N	PRESENT	0
491606	491485	19749K	PARTICIPANT	\N	PRESENT	0
493290	493289	14173T	PARTICIPANT	\N	PRESENT	0
493295	493294	14042U	PARTICIPANT	\N	PRESENT	0
502660	500287	19687N	PARTICIPANT	\N	PRESENT	0
502661	500287	17367Q	PARTICIPANT	\N	PRESENT	0
502662	500287	19719D	PARTICIPANT	\N	PRESENT	0
502663	500287	20052X	PARTICIPANT	\N	PRESENT	0
502664	500287	19673G	PARTICIPANT	\N	PRESENT	0
502665	500287	19599P	PARTICIPANT	\N	PRESENT	0
502666	500287	20034V	PARTICIPANT	\N	PRESENT	0
502667	500287	19758L	PARTICIPANT	\N	PRESENT	0
502668	500287	04085P	PARTICIPANT	\N	PRESENT	0
502669	500287	19715Y	PARTICIPANT	\N	PRESENT	0
502670	500287	20106U	PARTICIPANT	\N	PRESENT	0
502671	500287	19347U	PARTICIPANT	\N	PRESENT	0
502672	500287	01028R	PARTICIPANT	\N	PRESENT	0
502673	500287	12016W	PARTICIPANT	\N	PRESENT	0
502674	500287	19531S	PARTICIPANT	\N	PRESENT	0
502682	500287	17737W	PARTICIPANT	\N	PRESENT	0
503485	503484	14111D	PARTICIPANT	\N	PRESENT	0
503486	503484	19649G	PARTICIPANT	\N	PRESENT	0
503619	503614	01028R	PARTICIPANT	\N	PRESENT	0
505769	502451	11110B	PARTICIPANT	\N	PRESENT	1
503617	503614	05008E	PARTICIPANT	\N	PRESENT	0
503618	503614	11053K	PARTICIPANT	\N	PRESENT	0
505770	502451	14121F	PARTICIPANT	\N	PRESENT	1
505923	505921	11027H	PARTICIPANT	\N	PRESENT	0
505924	505921	14193X	PARTICIPANT	\N	PRESENT	0
505926	505920	11027H	PARTICIPANT	\N	PRESENT	0
505928	505920	14193X	PARTICIPANT	\N	PRESENT	0
505930	505929	11027H	PARTICIPANT	\N	PRESENT	0
505931	505929	14193X	PARTICIPANT	\N	PRESENT	1
505958	505957	04043D	PARTICIPANT	\N	PRESENT	0
505960	505959	04043D	PARTICIPANT	\N	PRESENT	0
505968	505967	18083K	PARTICIPANT	\N	PRESENT	0
505969	505967	19333N	PARTICIPANT	\N	PRESENT	0
505971	505970	19333N	PARTICIPANT	\N	PRESENT	0
505972	505970	18083K	PARTICIPANT	\N	PRESENT	0
505973	505970	14205J	PARTICIPANT	\N	PRESENT	0
506029	506028	12028B	PARTICIPANT	\N	PRESENT	0
506030	506028	11064N	PARTICIPANT	\N	PRESENT	0
506035	506034	19954N	PARTICIPANT	\N	PRESENT	0
506140	502453	11110B	PARTICIPANT	\N	PRESENT	1
506141	502453	20126Y	PARTICIPANT	\N	PRESENT	1
506142	502453	01048V	PARTICIPANT	\N	PRESENT	1
506143	502453	11012A	PARTICIPANT	\N	PRESENT	1
506144	502453	19479G	PARTICIPANT	\N	PRESENT	1
506769	506768	11031D	PARTICIPANT	\N	PRESENT	0
506770	506768	14213J	PARTICIPANT	\N	PRESENT	0
506771	506768	18193Q	PARTICIPANT	\N	PRESENT	0
506773	506772	11031D	PARTICIPANT	\N	PRESENT	0
506774	506772	17965H	PARTICIPANT	\N	PRESENT	0
506776	506775	11031D	PARTICIPANT	\N	PRESENT	0
506777	506775	17965H	PARTICIPANT	\N	PRESENT	0
506778	506775	18193Q	PARTICIPANT	\N	PRESENT	0
506779	506775	14213J	PARTICIPANT	\N	PRESENT	0
506781	506780	11031D	PARTICIPANT	\N	PRESENT	0
506782	506780	17965H	PARTICIPANT	\N	PRESENT	0
506783	506780	18193Q	PARTICIPANT	\N	PRESENT	0
506784	506780	19723Y	PARTICIPANT	\N	PRESENT	0
506785	506780	14213J	PARTICIPANT	\N	PRESENT	0
507388	505797	20074E	PARTICIPANT	\N	PRESENT	1
507387	505797	14225N	PARTICIPANT	\N	PRESENT	1
509020	505799	14231L	PARTICIPANT	\N	PRESENT	0
509021	505799	14089Y	PARTICIPANT	\N	PRESENT	0
509022	505799	11056N	PARTICIPANT	\N	PRESENT	0
509023	505799	20108W	PARTICIPANT	\N	PRESENT	0
509024	505799	14151M	PARTICIPANT	\N	PRESENT	0
509025	505799	19749K	PARTICIPANT	\N	PRESENT	0
509026	505799	11072N	PARTICIPANT	\N	PRESENT	0
509027	505799	14179A	PARTICIPANT	\N	PRESENT	0
509028	505799	01028R	PARTICIPANT	\N	PRESENT	0
509030	502323	11074Q	PARTICIPANT	\N	PRESENT	0
509031	502323	20028X	PARTICIPANT	\N	PRESENT	0
509032	502323	20030R	PARTICIPANT	\N	PRESENT	0
509033	502323	19749K	PARTICIPANT	\N	PRESENT	0
509034	502323	20116W	PARTICIPANT	\N	PRESENT	0
509035	502323	14215L	PARTICIPANT	\N	PRESENT	0
509036	502323	05008E	PARTICIPANT	\N	PRESENT	0
509037	502323	19335Q	PARTICIPANT	\N	PRESENT	0
509041	502323	20092G	PARTICIPANT	\N	PRESENT	0
509043	502323	19521Q	PARTICIPANT	\N	PRESENT	0
509044	502323	14217N	PARTICIPANT	\N	PRESENT	0
509045	502323	14331P	PARTICIPANT	\N	PRESENT	0
509047	496311	19553Y	PARTICIPANT	\N	PRESENT	0
509048	496311	01028R	PARTICIPANT	\N	EXCUSE	0
509049	505805	20086J	PARTICIPANT	\N	PRESENT	0
509050	505805	19782L	PARTICIPANT	\N	PRESENT	1
509051	505805	20092G	PARTICIPANT	\N	PRESENT	0
509052	505805	14357A	PARTICIPANT	\N	PRESENT	0
509053	505805	19441R	PARTICIPANT	\N	PRESENT	0
509054	505805	19413M	PARTICIPANT	\N	PRESENT	0
509055	505805	20082E	PARTICIPANT	\N	PRESENT	0
509056	505805	20094J	PARTICIPANT	\N	PRESENT	1
509057	505805	04045F	PARTICIPANT	\N	PRESENT	1
509058	505805	19631V	PARTICIPANT	\N	PRESENT	0
509059	505805	11099A	PARTICIPANT	\N	PRESENT	0
509060	505805	19369B	PARTICIPANT	\N	PRESENT	1
509061	505805	20018V	PARTICIPANT	\N	PRESENT	0
509062	505805	19563B	PARTICIPANT	\N	PRESENT	0
509063	505805	19521Q	PARTICIPANT	\N	PRESENT	0
509064	505805	20028X	PARTICIPANT	\N	PRESENT	0
509065	505805	14038Y	PARTICIPANT	\N	PRESENT	0
509066	505805	19467C	PARTICIPANT	\N	PRESENT	0
509067	505805	20034V	PARTICIPANT	\N	PRESENT	0
509068	505805	14033T	PARTICIPANT	\N	PRESENT	1
509069	505805	11090Q	PRESIDENT	0	PRESENT	0
509070	505805	20062A	PARTICIPANT	\N	PRESENT	0
509071	505805	14251Q	PARTICIPANT	\N	PRESENT	1
509072	505805	19507S	PARTICIPANT	\N	PRESENT	0
509073	505805	19747H	PARTICIPANT	\N	PRESENT	0
509074	505805	14207L	PARTICIPANT	\N	PRESENT	0
509075	505805	14257W	PARTICIPANT	\N	PRESENT	0
509077	506668	01048V	PARTICIPANT	\N	PRESENT	0
509078	506668	19503N	PARTICIPANT	\N	PRESENT	0
509079	506668	19533U	PARTICIPANT	\N	PRESENT	0
519309	519307	19735D	PARTICIPANT	\N	PRESENT	0
519372	519368	04086Q	PARTICIPANT	\N	PRESENT	0
519624	519307	19563B	PARTICIPANT	\N	PRESENT	0
519678	519307	19503N	PARTICIPANT	\N	PRESENT	0
519679	519307	20128B	PARTICIPANT	\N	PRESENT	0
526515	526514	19717B	PARTICIPANT	\N	PRESENT	0
526516	526514	20094J	PARTICIPANT	\N	PRESENT	0
526517	526514	14069U	PARTICIPANT	\N	PRESENT	0
526518	526514	14255U	PARTICIPANT	\N	PRESENT	0
526519	526514	14083S	PARTICIPANT	\N	PRESENT	0
526520	526514	11027H	PARTICIPANT	\N	PRESENT	0
526521	526514	14357A	PARTICIPANT	\N	PRESENT	0
526523	526514	14187A	PARTICIPANT	\N	PRESENT	0
526524	526514	11083R	PARTICIPANT	\N	PRESENT	0
526525	526514	08017T	PARTICIPANT	\N	PRESENT	0
526526	526514	19826F	PARTICIPANT	\N	PRESENT	0
526527	526514	08009T	PARTICIPANT	\N	PRESENT	0
526528	526514	04070G	PARTICIPANT	\N	PRESENT	0
526529	526514	05012A	PARTICIPANT	\N	PRESENT	0
526530	526514	20098N	PARTICIPANT	\N	PRESENT	0
526531	526514	20064C	PARTICIPANT	\N	PRESENT	0
526532	526514	20046A	PARTICIPANT	\N	PRESENT	0
526533	526514	19749K	PARTICIPANT	\N	PRESENT	0
530039	529013	19657G	PARTICIPANT	\N	PRESENT	1
530040	529013	19591F	PARTICIPANT	\N	PRESENT	1
530041	529013	19717B	PARTICIPANT	\N	PRESENT	1
530042	529013	19663E	PARTICIPANT	\N	PRESENT	1
530043	529013	19697Q	PARTICIPANT	\N	PRESENT	0
530184	529013	20040T	PARTICIPANT	\N	PRESENT	1
530186	529013	08045X	PARTICIPANT	\N	PRESENT	1
532387	532383	04033B	PARTICIPANT	\N	PRESENT	0
532388	532383	14147R	PARTICIPANT	\N	PRESENT	0
532389	532383	08015R	PARTICIPANT	\N	PRESENT	0
532390	532383	20086J	PARTICIPANT	\N	PRESENT	0
532391	532383	17367Q	PARTICIPANT	\N	PRESENT	0
532392	532383	19447X	PARTICIPANT	\N	PRESENT	0
532393	532383	11041F	PARTICIPANT	\N	PRESENT	0
532395	532383	08034U	PARTICIPANT	\N	PRESENT	0
532396	532383	14357A	PARTICIPANT	\N	PRESENT	0
532397	532383	04070G	PARTICIPANT	\N	PRESENT	0
532398	532383	20042V	PARTICIPANT	\N	PRESENT	0
532399	532383	14217N	PARTICIPANT	\N	PRESENT	0
532400	532383	97011G	PARTICIPANT	\N	PRESENT	0
532401	532383	14041T	PARTICIPANT	\N	PRESENT	0
532402	532383	04035D	PARTICIPANT	\N	PRESENT	0
532403	532383	20140W	PARTICIPANT	\N	PRESENT	0
532404	532383	19798U	PARTICIPANT	\N	PRESENT	0
532405	532383	19503N	PARTICIPANT	\N	PRESENT	0
532406	532383	14215L	PARTICIPANT	\N	PRESENT	0
532407	532383	19515S	PARTICIPANT	\N	PRESENT	0
532408	532383	04042C	PARTICIPANT	\N	PRESENT	0
532409	532383	10015M	PARTICIPANT	\N	PRESENT	0
532410	532383	01058X	PARTICIPANT	\N	PRESENT	0
532411	532383	14249W	PARTICIPANT	\N	PRESENT	0
532441	532438	08015R	PARTICIPANT	\N	PRESENT	0
532413	532383	17737W	PARTICIPANT	\N	PRESENT	0
532419	532383	17637T	PARTICIPANT	\N	PRESENT	0
532420	532383	16685X	PARTICIPANT	\N	PRESENT	0
532422	532383	19723Y	PARTICIPANT	\N	PRESENT	0
532428	532383	19711U	PARTICIPANT	\N	PRESENT	0
532429	532383	20056C	PARTICIPANT	\N	PRESENT	0
532439	532438	04033B	PARTICIPANT	\N	PRESENT	0
532440	532438	14147R	PARTICIPANT	\N	PRESENT	0
532442	532438	17367Q	PARTICIPANT	\N	PRESENT	0
532443	532438	20086J	PARTICIPANT	\N	PRESENT	0
532444	532438	19447X	PARTICIPANT	\N	PRESENT	0
532445	532438	11041F	PARTICIPANT	\N	PRESENT	0
532446	532438	08034U	PARTICIPANT	\N	PRESENT	0
532447	532438	14357A	PARTICIPANT	\N	PRESENT	0
532457	532438	04070G	PARTICIPANT	\N	PRESENT	0
532458	532438	20042V	PARTICIPANT	\N	PRESENT	0
532459	532438	14217N	PARTICIPANT	\N	PRESENT	0
532460	532438	97011G	PARTICIPANT	\N	PRESENT	0
532462	532438	14041T	PARTICIPANT	\N	PRESENT	0
532464	532438	04035D	PARTICIPANT	\N	PRESENT	0
532465	532438	20140W	PARTICIPANT	\N	PRESENT	0
532467	532438	19798U	PARTICIPANT	\N	PRESENT	0
532468	532438	19503N	PARTICIPANT	\N	PRESENT	0
532469	532438	14215L	PARTICIPANT	\N	PRESENT	0
532470	532438	19515S	PARTICIPANT	\N	PRESENT	0
532472	532438	04042C	PARTICIPANT	\N	PRESENT	0
532473	532438	10015M	PARTICIPANT	\N	PRESENT	0
532474	532438	14249W	PARTICIPANT	\N	PRESENT	0
532475	532438	19711U	PARTICIPANT	\N	PRESENT	0
532476	532438	17737W	PARTICIPANT	\N	PRESENT	0
532477	532438	17637T	PARTICIPANT	\N	PRESENT	0
532478	532438	16685X	PARTICIPANT	\N	PRESENT	0
532480	532438	19723Y	PARTICIPANT	\N	PRESENT	0
532482	532438	20056C	PARTICIPANT	\N	PRESENT	0
532486	532438	01058X	PARTICIPANT	\N	PRESENT	0
534361	534276	19701S	PARTICIPANT	\N	PRESENT	0
534362	534276	20136B	PARTICIPANT	\N	PRESENT	0
534363	534276	14031R	PARTICIPANT	\N	PRESENT	0
534364	534276	20076G	PARTICIPANT	\N	PRESENT	0
534365	534276	20140W	PARTICIPANT	\N	PRESENT	0
534366	534276	19503N	PARTICIPANT	\N	PRESENT	0
534367	534276	19251M	PARTICIPANT	\N	PRESENT	0
534368	534276	19745F	PARTICIPANT	\N	PRESENT	0
534369	534276	19826F	PARTICIPANT	\N	PRESENT	0
534370	534276	17367Q	PARTICIPANT	\N	PRESENT	0
534371	534276	20024T	PARTICIPANT	\N	PRESENT	0
534372	534276	19619A	PARTICIPANT	\N	PRESENT	0
534373	534276	20100N	PARTICIPANT	\N	PRESENT	0
534374	534276	19685L	PARTICIPANT	\N	PRESENT	0
534375	534276	14221J	PARTICIPANT	\N	PRESENT	0
534376	534276	20118Y	PARTICIPANT	\N	PRESENT	0
534377	534276	18083K	PARTICIPANT	\N	PRESENT	0
534378	534276	19577H	PARTICIPANT	\N	PRESENT	1
534379	534276	19637C	PARTICIPANT	\N	PRESENT	1
534380	534276	14179A	PARTICIPANT	\N	PRESENT	1
534381	534276	14219Q	PRESIDENT	0	PRESENT	0
534382	534276	19525U	PARTICIPANT	\N	PRESENT	1
534383	534276	20038A	PARTICIPANT	\N	EXCUSE	0
534384	534276	20020P	PARTICIPANT	\N	EXCUSE	0
534385	534276	19387D	PARTICIPANT	\N	PRESENT	1
534387	534276	20068G	PARTICIPANT	\N	PRESENT	0
534388	534165	19954N	PARTICIPANT	\N	PRESENT	0
534389	534165	20074E	PARTICIPANT	\N	PRESENT	0
534390	534165	14041T	PARTICIPANT	\N	PRESENT	0
534391	534165	20108W	PARTICIPANT	\N	PRESENT	0
534392	534165	01028R	PARTICIPANT	\N	PRESENT	0
534393	534165	19729F	PARTICIPANT	\N	PRESENT	0
534394	534165	14151M	PARTICIPANT	\N	PRESENT	0
534395	534165	04047H	PRESIDENT	0	PRESENT	0
534396	534165	11072N	PARTICIPANT	\N	PRESENT	0
534397	534165	19447X	PARTICIPANT	\N	PRESENT	0
534398	534165	14021P	PARTICIPANT	\N	PRESENT	0
534399	534165	14259Y	PARTICIPANT	\N	PRESENT	0
534400	534165	19543W	PARTICIPANT	\N	PRESENT	0
534401	534165	05008E	PARTICIPANT	\N	PRESENT	0
534402	534165	14179A	PARTICIPANT	\N	PRESENT	0
534403	534165	19581D	PARTICIPANT	\N	PRESENT	0
534404	534165	14111D	PARTICIPANT	\N	PRESENT	0
534405	534165	17737W	PARTICIPANT	\N	PRESENT	0
534406	534165	20110Q	PARTICIPANT	\N	PRESENT	0
534407	534165	14069U	PARTICIPANT	\N	PRESENT	0
534424	534252	14026U	PARTICIPANT	\N	PRESENT	0
534425	534252	20142Y	PARTICIPANT	\N	PRESENT	0
534426	534252	20174H	PARTICIPANT	\N	PRESENT	0
534427	534252	19651A	PARTICIPANT	\N	PRESENT	0
534428	534252	11083R	PARTICIPANT	\N	PRESENT	0
534429	534252	17589D	PARTICIPANT	\N	PRESENT	0
534430	534252	19593H	PARTICIPANT	\N	PRESENT	0
534431	534252	20106U	PARTICIPANT	\N	PRESENT	0
534432	534252	14207L	PARTICIPANT	\N	PRESENT	0
534433	534252	20132W	PARTICIPANT	\N	PRESENT	0
534434	534252	19671E	PARTICIPANT	\N	PRESENT	0
534435	534252	99004R	PARTICIPANT	\N	PRESENT	0
534436	534252	19749K	PARTICIPANT	\N	PRESENT	0
534437	534252	20124W	PARTICIPANT	\N	PRESENT	0
534438	534252	19611R	PARTICIPANT	\N	PRESENT	0
534439	534252	19758L	PARTICIPANT	\N	PRESENT	0
534440	534252	19565D	PARTICIPANT	\N	PRESENT	0
534441	534252	92040Q	PARTICIPANT	\N	PRESENT	0
534442	534252	20180F	PARTICIPANT	\N	PRESENT	0
534443	534252	19515S	PARTICIPANT	\N	PRESENT	0
520582	518951	19367Y	PARTICIPANT	\N	PRESENT	0
520583	518951	19581D	PARTICIPANT	\N	PRESENT	0
520584	518951	19671E	PARTICIPANT	\N	PRESENT	0
520585	518951	19413M	PARTICIPANT	\N	PRESENT	0
520586	518951	19687N	PARTICIPANT	\N	PRESENT	0
520587	518951	14193X	PARTICIPANT	\N	PRESENT	0
520588	518951	11099A	PARTICIPANT	\N	PRESENT	0
520589	518951	14069U	PARTICIPANT	\N	PRESENT	0
520590	518951	14217N	PARTICIPANT	\N	PRESENT	0
520591	518951	14187A	PARTICIPANT	\N	PRESENT	0
520592	518951	11048N	PARTICIPANT	\N	PRESENT	0
520593	518951	20080C	PARTICIPANT	\N	PRESENT	0
520594	518951	14213J	PARTICIPANT	\N	PRESENT	0
520595	518951	20096L	PARTICIPANT	\N	PRESENT	0
520596	518951	20092G	PARTICIPANT	\N	PRESENT	0
520597	518951	20026V	PARTICIPANT	\N	PRESENT	0
520598	518951	19631V	PARTICIPANT	\N	PRESENT	0
520599	518951	20028X	PARTICIPANT	\N	PRESENT	0
520600	518951	19741B	PARTICIPANT	\N	PRESENT	0
520601	518951	11066Q	PARTICIPANT	\N	PRESENT	0
520602	518951	14195A	PARTICIPANT	\N	PRESENT	0
520603	518951	19545Y	PARTICIPANT	\N	PRESENT	0
520604	518951	14147R	PARTICIPANT	\N	PRESENT	0
520605	518951	04057K	PARTICIPANT	\N	PRESENT	0
520606	518951	19347U	PARTICIPANT	\N	PRESENT	0
520607	518951	19575F	PARTICIPANT	\N	PRESENT	0
520608	518951	19768N	PARTICIPANT	\N	PRESENT	0
520609	518951	20140W	PARTICIPANT	\N	PRESENT	0
520610	518951	19723Y	PARTICIPANT	\N	PRESENT	0
520611	518951	19621T	PARTICIPANT	\N	PRESENT	0
520612	518951	20136B	PARTICIPANT	\N	PRESENT	0
520613	518951	19447X	PARTICIPANT	\N	PRESENT	0
520614	518951	20124W	PARTICIPANT	\N	PRESENT	0
520615	518951	14026U	PARTICIPANT	\N	PRESENT	0
520616	518951	05012A	PARTICIPANT	\N	PRESENT	0
520617	518951	19693L	PARTICIPANT	\N	PRESENT	0
520618	518951	20138D	PARTICIPANT	\N	PRESENT	0
520619	518951	20172F	PARTICIPANT	\N	PRESENT	0
520679	518951	19798U	PARTICIPANT	\N	PRESENT	0
520621	518951	20066E	PARTICIPANT	\N	PRESENT	0
520622	518951	19739H	PARTICIPANT	\N	PRESENT	0
520623	518951	19619A	PARTICIPANT	\N	PRESENT	0
520624	518951	11064N	PARTICIPANT	\N	PRESENT	0
520625	518951	19699S	PARTICIPANT	\N	PRESENT	0
520626	518951	01043Q	PARTICIPANT	\N	PRESENT	0
520627	518951	19611R	PARTICIPANT	\N	PRESENT	0
520628	518951	19691J	PARTICIPANT	\N	PRESENT	0
520629	518951	14042U	PARTICIPANT	\N	PRESENT	0
520630	518951	19511N	PARTICIPANT	\N	PRESENT	0
520631	518951	20118Y	PARTICIPANT	\N	PRESENT	0
520632	518951	20132W	PARTICIPANT	\N	PRESENT	0
520635	518951	20048C	PARTICIPANT	\N	PRESENT	0
520636	518951	20040T	PARTICIPANT	\N	PRESENT	0
520638	518951	11053K	PARTICIPANT	\N	PRESENT	0
520640	518951	01024M	PARTICIPANT	\N	PRESENT	0
520643	518951	08047A	PARTICIPANT	\N	PRESENT	0
520644	518951	19577H	PARTICIPANT	\N	PRESENT	0
520646	518951	19441R	PARTICIPANT	\N	PRESENT	0
520647	518951	19745F	PARTICIPANT	\N	PRESENT	0
520648	518951	14030Q	PARTICIPANT	\N	PRESENT	0
520649	518951	11043H	PARTICIPANT	\N	PRESENT	0
520650	518951	19479G	PARTICIPANT	\N	PRESENT	0
520651	518951	08010L	PARTICIPANT	\N	PRESENT	0
520652	518951	20074E	PARTICIPANT	\N	PRESENT	0
520653	518951	19679N	PARTICIPANT	\N	PRESENT	0
520654	518951	19565D	PARTICIPANT	\N	PRESENT	0
520655	518951	14249W	PARTICIPANT	\N	PRESENT	0
520656	518951	19527W	PARTICIPANT	\N	PRESENT	0
520657	518951	19591F	PARTICIPANT	\N	PRESENT	0
520658	518951	17367Q	PARTICIPANT	\N	PRESENT	0
520659	518951	14189C	PARTICIPANT	\N	PRESENT	0
520660	518951	20042V	PARTICIPANT	\N	PRESENT	0
520661	518951	14179A	PARTICIPANT	\N	PRESENT	0
520663	518951	14073Q	PARTICIPANT	\N	PRESENT	0
520664	518951	16685X	PARTICIPANT	\N	PRESENT	0
520665	518951	19713W	PARTICIPANT	\N	PRESENT	0
520667	518951	19647E	PARTICIPANT	\N	PRESENT	0
520669	518951	19683J	PARTICIPANT	\N	PRESENT	0
520671	518951	19685L	PARTICIPANT	\N	PRESENT	0
520683	518951	19349W	PARTICIPANT	\N	PRESENT	0
520680	518951	19701S	PARTICIPANT	\N	PRESENT	0
520684	518951	14097Y	PARTICIPANT	\N	PRESENT	0
520685	519227	14053L	PARTICIPANT	\N	PRESENT	0
520686	519227	19954N	PARTICIPANT	\N	PRESENT	0
520687	519227	19649G	PARTICIPANT	\N	PRESENT	0
520688	519227	04047H	PRESIDENT	0	PRESENT	0
520689	519227	19673G	PARTICIPANT	\N	PRESENT	0
520923	519227	19581D	PARTICIPANT	\N	PRESENT	0
520924	519227	19749K	PARTICIPANT	\N	PRESENT	0
520925	519227	14147R	PARTICIPANT	\N	PRESENT	0
520926	519227	01028R	PARTICIPANT	\N	PRESENT	0
520927	519227	10015M	PARTICIPANT	\N	PRESENT	0
520928	519227	05008E	PARTICIPANT	\N	PRESENT	0
520929	519227	14111D	PARTICIPANT	\N	PRESENT	0
520930	518952	20124W	PARTICIPANT	\N	PRESENT	0
520931	518952	20090E	PARTICIPANT	\N	PRESENT	0
520932	518952	01048V	PARTICIPANT	\N	PRESENT	0
520933	518952	14033T	PARTICIPANT	\N	PRESENT	0
520934	518952	19467C	PARTICIPANT	\N	PRESENT	0
520935	518952	19515S	PARTICIPANT	\N	PRESENT	0
520936	518952	19479G	PARTICIPANT	\N	PRESENT	0
520937	518952	19387D	PARTICIPANT	\N	PRESENT	0
520938	518952	19629C	PARTICIPANT	\N	PRESENT	0
520939	518952	14207L	PARTICIPANT	\N	PRESENT	0
520940	518952	20018V	PARTICIPANT	\N	PRESENT	0
520941	518952	19758L	PARTICIPANT	\N	PRESENT	0
520942	518952	19687N	PARTICIPANT	\N	PRESENT	0
520943	518952	11031D	PARTICIPANT	\N	PRESENT	0
520944	518952	11099A	PARTICIPANT	\N	PRESENT	0
520945	518952	19549D	PARTICIPANT	\N	PRESENT	0
520946	518952	20082E	PARTICIPANT	\N	PRESENT	0
520947	518952	20046A	PARTICIPANT	\N	PRESENT	0
520948	518952	19565D	PARTICIPANT	\N	PRESENT	0
520949	518952	19527W	PARTICIPANT	\N	PRESENT	0
520950	518952	04045F	PARTICIPANT	\N	PRESENT	0
520951	518952	20174H	PARTICIPANT	\N	PRESENT	0
520952	518952	19563B	PARTICIPANT	\N	PRESENT	0
520953	518952	19369B	PARTICIPANT	\N	PRESENT	0
520954	518952	20144B	PARTICIPANT	\N	PRESENT	0
520955	518952	14237S	PARTICIPANT	\N	PRESENT	0
520956	518952	20120S	PARTICIPANT	\N	PRESENT	0
520957	519227	17737W	PARTICIPANT	\N	PRESENT	0
520958	519227	14215L	PARTICIPANT	\N	PRESENT	0
520959	518952	20062A	PARTICIPANT	\N	PRESENT	0
520960	518952	19533U	PARTICIPANT	\N	PRESENT	0
520961	518952	19701S	PARTICIPANT	\N	PRESENT	0
520962	518952	17367Q	PARTICIPANT	\N	PRESENT	0
520963	518952	20100N	PARTICIPANT	\N	PRESENT	0
520964	518952	19611R	PARTICIPANT	\N	PRESENT	0
520965	518952	14097Y	PARTICIPANT	\N	PRESENT	0
520966	518952	20032T	PARTICIPANT	\N	PRESENT	0
520967	518952	19735D	PARTICIPANT	\N	PRESENT	0
520968	518952	14083S	PARTICIPANT	\N	PRESENT	0
520969	518952	19577H	PARTICIPANT	\N	PRESENT	0
520970	518952	19798U	PARTICIPANT	\N	PRESENT	0
520971	518952	11012A	PARTICIPANT	\N	PRESENT	0
520972	518952	19826F	PARTICIPANT	\N	PRESENT	0
520973	518952	20112S	PARTICIPANT	\N	PRESENT	0
520974	518952	20086J	PARTICIPANT	\N	PRESENT	0
520975	519227	14231L	PARTICIPANT	\N	PRESENT	0
520976	518952	19599P	PARTICIPANT	\N	PRESENT	0
520977	518952	19349W	PARTICIPANT	\N	PRESENT	0
520978	518952	20020P	PARTICIPANT	\N	PRESENT	0
520979	518952	14038Y	PARTICIPANT	\N	PRESENT	0
520980	518952	20056C	PARTICIPANT	\N	PRESENT	0
520981	518952	20024T	PARTICIPANT	\N	PRESENT	0
520982	518952	20028X	PARTICIPANT	\N	PRESENT	0
520983	518952	19671E	PARTICIPANT	\N	PRESENT	0
520984	518952	20102Q	PARTICIPANT	\N	PRESENT	0
520985	518952	19631V	PARTICIPANT	\N	PRESENT	0
520986	518952	19503N	PARTICIPANT	\N	PRESENT	0
520987	518952	19820Y	PARTICIPANT	\N	PRESENT	0
521011	518952	11048N	PARTICIPANT	\N	PRESENT	0
521012	518952	14257W	PARTICIPANT	\N	PRESENT	0
521013	518952	14111D	PARTICIPANT	\N	PRESENT	0
521014	520136	11067R	PARTICIPANT	\N	PRESENT	0
521015	520136	20092G	PARTICIPANT	\N	PRESENT	0
521016	520136	04092N	PRESIDENT	0	PRESENT	0
521017	520136	19569H	PARTICIPANT	\N	PRESENT	0
521018	520136	19415P	PARTICIPANT	\N	PRESENT	0
520922	518952	19719D	PARTICIPANT	\N	PRESENT	0
516895	516381	19954N	PARTICIPANT	\N	PRESENT	0
516896	516381	95063L	PARTICIPANT	\N	PRESENT	0
516897	516381	11026G	PARTICIPANT	\N	PRESENT	0
516898	516381	19543W	PARTICIPANT	\N	PRESENT	0
516899	516381	04047H	PRESIDENT	0	PRESENT	0
516900	516381	04008A	PARTICIPANT	\N	PRESENT	0
516901	516381	01028R	PARTICIPANT	\N	PRESENT	0
516902	516381	19447X	PARTICIPANT	\N	PRESENT	0
516903	516381	11072N	PARTICIPANT	\N	PRESENT	0
516904	512952	99004R	PARTICIPANT	\N	PRESENT	0
516905	516381	20110Q	PARTICIPANT	\N	PRESENT	0
516909	512952	20110Q	PARTICIPANT	\N	PRESENT	0
516910	512952	19719D	PARTICIPANT	\N	PRESENT	0
516911	512952	11072N	PARTICIPANT	\N	PRESENT	0
516912	512952	11077T	PARTICIPANT	\N	PRESENT	0
516913	512952	19447X	PARTICIPANT	\N	PRESENT	0
516914	512952	19954N	PARTICIPANT	\N	PRESENT	0
516915	512952	19543W	PARTICIPANT	\N	PRESENT	0
516916	512952	11026G	PARTICIPANT	\N	PRESENT	0
516917	512952	19585H	PARTICIPANT	\N	PRESENT	0
516918	512952	14041T	PARTICIPANT	\N	PRESENT	0
516919	512952	04047H	PARTICIPANT	\N	PRESENT	0
516920	512952	04085P	PARTICIPANT	\N	PRESENT	0
516921	512952	01028R	PARTICIPANT	\N	PRESENT	0
516922	512952	19741B	PARTICIPANT	\N	PRESENT	0
516923	512952	95063L	PARTICIPANT	\N	PRESENT	0
516942	512953	01028R	PARTICIPANT	\N	PRESENT	0
516943	512953	04008A	PARTICIPANT	\N	PRESENT	0
516944	512953	19719D	PARTICIPANT	\N	PRESENT	0
516945	512953	19585H	PARTICIPANT	\N	PRESENT	0
516946	512953	95063L	PARTICIPANT	\N	PRESENT	0
516947	512953	11033F	PARTICIPANT	\N	PRESENT	0
516948	512953	19447X	PARTICIPANT	\N	PRESENT	0
516949	512953	19741B	PARTICIPANT	\N	PRESENT	0
516950	512953	04085P	PARTICIPANT	\N	PRESENT	0
516951	512953	20110Q	PARTICIPANT	\N	PRESENT	0
516952	512953	11077T	PARTICIPANT	\N	PRESENT	0
516953	512953	04047H	PARTICIPANT	\N	PRESENT	0
516954	512953	19954N	PARTICIPANT	\N	PRESENT	0
516955	512953	20042V	PARTICIPANT	\N	PRESENT	0
516956	512953	14089Y	PARTICIPANT	\N	PRESENT	0
516957	512953	19643A	PARTICIPANT	\N	PRESENT	0
516940	512953	99004R	PARTICIPANT	\N	PRESENT	0
516941	512953	11026G	PARTICIPANT	\N	PRESENT	0
516958	512953	14147R	PARTICIPANT	\N	PRESENT	0
516981	512995	04085P	PARTICIPANT	\N	PRESENT	0
516982	512995	19719D	PARTICIPANT	\N	PRESENT	0
516983	512995	14089Y	PARTICIPANT	\N	PRESENT	0
516984	512995	19643A	PARTICIPANT	\N	PRESENT	0
516985	512995	11033F	PARTICIPANT	\N	PRESENT	0
516986	512995	20110Q	PARTICIPANT	\N	PRESENT	0
516987	512995	01028R	PARTICIPANT	\N	PRESENT	0
516988	512995	20146D	PARTICIPANT	\N	PRESENT	0
516989	512995	14147R	PARTICIPANT	\N	PRESENT	0
516990	512995	19447X	PARTICIPANT	\N	PRESENT	0
516992	512995	14021P	PARTICIPANT	\N	PRESENT	0
516993	512995	19741B	PARTICIPANT	\N	PRESENT	0
518416	518415	14073Q	PARTICIPANT	\N	PRESENT	0
518417	518415	08018U	PARTICIPANT	\N	PRESENT	0
518418	518415	04045F	PARTICIPANT	\N	PRESENT	0
518419	518415	14083S	PARTICIPANT	\N	PRESENT	0
518420	518415	11083R	PARTICIPANT	\N	PRESENT	0
518421	518415	14147R	PARTICIPANT	\N	PRESENT	0
518422	518415	14069U	PARTICIPANT	\N	PRESENT	0
516979	512995	99004R	PARTICIPANT	\N	PRESENT	0
516980	512995	19954N	PARTICIPANT	\N	PRESENT	0
518423	518415	14249W	PARTICIPANT	\N	PRESENT	0
518424	518415	20126Y	PARTICIPANT	\N	PRESENT	0
518425	518415	11026G	PARTICIPANT	\N	PRESENT	0
518441	517640	20114U	PARTICIPANT	\N	PRESENT	0
518442	517640	11033F	PARTICIPANT	\N	PRESENT	0
518443	517640	19649G	PARTICIPANT	\N	PRESENT	0
521236	518674	19565D	PARTICIPANT	\N	EXCUSE	0
521322	518674	01057W	PARTICIPANT	\N	PRESENT	0
521323	518674	14327T	PARTICIPANT	\N	PRESENT	0
521324	518674	04086Q	PARTICIPANT	\N	PRESENT	0
521360	518674	19735D	PARTICIPANT	\N	PRESENT	0
523929	523928	20086J	PARTICIPANT	\N	PRESENT	0
523933	523932	20086J	PARTICIPANT	\N	PRESENT	0
523935	523934	20086J	PARTICIPANT	\N	PRESENT	0
524048	524047	14255U	PARTICIPANT	\N	PRESENT	0
524049	524047	08009T	PARTICIPANT	\N	PRESENT	0
524051	524050	14255U	PARTICIPANT	\N	PRESENT	0
524052	524050	19719D	PARTICIPANT	\N	PRESENT	0
524054	524053	20024T	PARTICIPANT	\N	PRESENT	0
524055	524053	14255U	PARTICIPANT	\N	PRESENT	0
524056	524053	12028B	PARTICIPANT	\N	PRESENT	0
524057	524053	18083K	PARTICIPANT	\N	PRESENT	0
524058	524053	14267Y	PARTICIPANT	\N	PRESENT	0
524059	524053	11027H	PARTICIPANT	\N	PRESENT	0
524060	524053	20070A	PARTICIPANT	\N	PRESENT	0
524061	524053	11065P	PARTICIPANT	\N	PRESENT	0
524062	524053	07004J	PARTICIPANT	\N	PRESENT	0
524063	524053	19531S	PARTICIPANT	\N	PRESENT	0
524064	524053	11099A	PARTICIPANT	\N	PRESENT	0
524065	524053	10015M	PARTICIPANT	\N	PRESENT	0
524066	524053	20084G	PARTICIPANT	\N	PRESENT	0
524067	524053	19749K	PARTICIPANT	\N	PRESENT	0
524098	524097	20086J	PARTICIPANT	\N	PRESENT	0
530719	527033	08012N	PARTICIPANT	\N	EXCUSE	0
530802	530801	20074E	PARTICIPANT	\N	PRESENT	0
530803	530801	20110Q	PARTICIPANT	\N	PRESENT	0
530807	530805	20074E	PARTICIPANT	\N	PRESENT	0
530809	530805	20110Q	PARTICIPANT	\N	PRESENT	0
531084	529289	11026G	PARTICIPANT	\N	PRESENT	0
531086	531085	19673G	PARTICIPANT	\N	PRESENT	0
531087	531085	14179A	PARTICIPANT	\N	PRESENT	0
531088	531085	19749K	PARTICIPANT	\N	PRESENT	0
531090	531089	19673G	PARTICIPANT	\N	PRESENT	0
531091	531089	19749K	PARTICIPANT	\N	PRESENT	0
531093	531092	19673G	PARTICIPANT	\N	PRESENT	0
531094	531092	19749K	PARTICIPANT	\N	PRESENT	0
531095	531092	14179A	PARTICIPANT	\N	PRESENT	0
531096	531092	17737W	PARTICIPANT	\N	PRESENT	0
531097	531092	19649G	PARTICIPANT	\N	PRESENT	0
531165	531164	20124W	PARTICIPANT	\N	PRESENT	0
531166	531164	14109K	PARTICIPANT	\N	PRESENT	0
533306	531319	19643A	PARTICIPANT	\N	PRESENT	0
533307	531319	19611R	PARTICIPANT	\N	PRESENT	0
533308	531319	04047H	PRESIDENT	0	PRESENT	0
533309	531319	20052X	PARTICIPANT	\N	PRESENT	0
533310	531319	19673G	PARTICIPANT	\N	PRESENT	0
533312	531319	14053L	PARTICIPANT	\N	PRESENT	0
533313	531371	04092N	PARTICIPANT	\N	PRESENT	0
533314	531371	19553Y	PARTICIPANT	\N	PRESENT	0
533315	531371	20090E	PARTICIPANT	\N	PRESENT	0
533316	531371	20172F	PARTICIPANT	\N	PRESENT	0
533317	531371	14042U	PARTICIPANT	\N	PRESENT	0
533318	531371	20042V	PARTICIPANT	\N	PRESENT	0
533319	531371	19479G	PARTICIPANT	\N	PRESENT	0
533320	531371	14195A	PARTICIPANT	\N	PRESENT	0
533321	531371	19651A	PARTICIPANT	\N	PRESENT	0
533322	531371	11031D	PARTICIPANT	\N	PRESENT	0
533323	531371	17965H	PARTICIPANT	\N	PRESENT	0
533324	531371	19683J	PARTICIPANT	\N	PRESENT	0
533325	531371	17779H	PARTICIPANT	\N	PRESENT	0
533326	531371	01034P	PARTICIPANT	\N	PRESENT	0
533327	531371	14205J	PARTICIPANT	\N	PRESENT	0
533328	531371	14189C	PARTICIPANT	\N	PRESENT	0
533329	531371	19415P	PARTICIPANT	\N	PRESENT	0
533330	531371	20130U	PARTICIPANT	\N	PRESENT	0
533331	531371	19747H	PARTICIPANT	\N	PRESENT	0
533332	531371	19515S	PARTICIPANT	\N	PRESENT	0
533333	531371	20074E	PARTICIPANT	\N	PRESENT	0
533334	531371	19679N	PARTICIPANT	\N	PRESENT	0
533335	531371	19723Y	PARTICIPANT	\N	PRESENT	0
533336	531371	14213J	PARTICIPANT	\N	PRESENT	0
533337	531371	19671E	PARTICIPANT	\N	PRESENT	0
533338	531371	14357A	PARTICIPANT	\N	PRESENT	0
533339	531371	14147R	PARTICIPANT	\N	PRESENT	0
533340	531371	01058X	PARTICIPANT	\N	PRESENT	0
533341	531371	19383Y	PARTICIPANT	\N	PRESENT	0
533342	531371	19762G	PARTICIPANT	\N	PRESENT	0
533343	531371	14069U	PARTICIPANT	\N	PRESENT	0
533344	531371	20066E	PARTICIPANT	\N	PRESENT	0
533345	531371	14073Q	PARTICIPANT	\N	PRESENT	0
533346	531371	18193Q	PARTICIPANT	\N	PRESENT	0
533347	531371	10006L	PARTICIPANT	\N	PRESENT	0
533348	531371	19760E	PARTICIPANT	\N	PRESENT	0
533349	531371	20082E	PARTICIPANT	\N	PRESENT	0
518582	513056	19747H	PARTICIPANT	\N	PRESENT	0
518583	513056	14151M	PARTICIPANT	\N	PRESENT	0
518584	513056	19685L	PARTICIPANT	\N	PRESENT	0
518585	513056	19573D	PARTICIPANT	\N	PRESENT	0
518586	513056	19563B	PARTICIPANT	\N	PRESENT	0
518587	513056	19349W	PARTICIPANT	\N	PRESENT	0
518588	513056	19663E	PARTICIPANT	\N	PRESENT	0
518589	513056	20068G	PARTICIPANT	\N	PRESENT	0
518590	513056	19413M	PARTICIPANT	\N	PRESENT	0
518608	513056	14179A	PARTICIPANT	\N	PRESENT	0
518609	513056	19333N	PARTICIPANT	\N	PRESENT	0
518610	513056	11085T	PARTICIPANT	\N	PRESENT	0
518611	513056	19699S	PARTICIPANT	\N	PRESENT	0
519232	519231	14133K	PARTICIPANT	\N	PRESENT	0
519233	519231	14193X	PARTICIPANT	\N	PRESENT	0
519234	519231	04035D	PARTICIPANT	\N	PRESENT	0
519235	519231	14097Y	PARTICIPANT	\N	PRESENT	0
524491	522714	20030R	PARTICIPANT	\N	EXCUSE	0
524570	522714	11033F	PRESIDENT	0	PRESENT	0
524571	522714	19683J	PRESIDENT	1	PRESENT	0
524572	522714	11031D	PARTICIPANT	\N	PRESENT	0
524573	522714	14189C	PARTICIPANT	\N	PRESENT	0
524574	522714	19563B	PARTICIPANT	\N	PRESENT	0
524575	522714	19705W	PARTICIPANT	\N	PRESENT	0
524576	522714	14229S	PARTICIPANT	\N	PRESENT	0
524577	522714	19699S	PARTICIPANT	\N	PRESENT	0
524578	522714	19573D	PARTICIPANT	\N	PRESENT	0
524579	522714	20120S	PARTICIPANT	\N	PRESENT	0
524580	522714	99004R	PARTICIPANT	\N	PRESENT	0
524581	522714	10006L	PARTICIPANT	\N	PRESENT	0
524582	522714	11090Q	PARTICIPANT	\N	PRESENT	0
524583	522714	19447X	PARTICIPANT	\N	PRESENT	0
524584	522714	04092N	PARTICIPANT	\N	EXCUSE	0
524907	524076	14225N	PRESIDENT	0	PRESENT	0
524908	524076	07029T	PARTICIPANT	\N	EXCUSE	0
524909	524076	19671E	PARTICIPANT	\N	EXCUSE	0
524910	524076	20022R	PARTICIPANT	\N	PRESENT	0
524911	521656	18083K	PARTICIPANT	\N	PRESENT	0
524912	521656	19701S	PARTICIPANT	\N	PRESENT	0
524913	521656	20076G	PARTICIPANT	\N	PRESENT	0
524914	521656	20046A	PARTICIPANT	\N	PRESENT	0
524915	521656	19739H	PARTICIPANT	\N	PRESENT	0
524916	521656	19251M	PARTICIPANT	\N	PRESENT	0
524917	521656	19745F	PARTICIPANT	\N	PRESENT	0
524918	521656	08060W	PARTICIPANT	\N	PRESENT	1
524919	521656	17229F	PARTICIPANT	\N	PRESENT	0
524920	524076	11040E	PARTICIPANT	\N	PRESENT	0
524921	524076	11048N	PARTICIPANT	\N	PRESENT	0
524922	521656	20140W	PARTICIPANT	\N	PRESENT	0
524923	524076	14327T	PARTICIPANT	\N	PRESENT	0
524924	524076	01057W	PARTICIPANT	\N	PRESENT	0
524925	524076	08009T	PARTICIPANT	\N	PRESENT	0
524926	524076	14331P	PARTICIPANT	\N	PRESENT	0
524927	524076	20070A	PARTICIPANT	\N	PRESENT	0
524928	524076	14253S	PARTICIPANT	\N	PRESENT	0
524929	521656	14221J	PARTICIPANT	\N	PRESENT	0
524930	521656	19599P	PARTICIPANT	\N	PRESENT	0
524931	521656	19637C	PARTICIPANT	\N	PRESENT	1
524932	521656	19551W	PARTICIPANT	\N	PRESENT	0
524933	521656	14237S	PARTICIPANT	\N	PRESENT	0
524934	521656	19503N	PARTICIPANT	\N	PRESENT	0
524935	521656	19619A	PARTICIPANT	\N	PRESENT	0
524936	521656	19333N	PARTICIPANT	\N	PRESENT	1
524937	521656	20100N	PARTICIPANT	\N	PRESENT	1
524938	521656	19820Y	PARTICIPANT	\N	PRESENT	1
524939	521656	11065P	PARTICIPANT	\N	PRESENT	0
524940	521656	14169X	PARTICIPANT	\N	PRESENT	1
524941	524076	19762G	PARTICIPANT	\N	PRESENT	0
524943	524076	20116W	PARTICIPANT	\N	PRESENT	0
524944	524076	19335Q	PARTICIPANT	\N	PRESENT	0
524945	524076	19711U	PARTICIPANT	\N	PRESENT	0
524946	521656	14031R	PARTICIPANT	\N	PRESENT	0
524947	521656	19549D	PARTICIPANT	\N	PRESENT	0
524948	521656	14219Q	PRESIDENT	0	PRESENT	0
524949	521656	20120S	PARTICIPANT	\N	PRESENT	0
524950	521656	20136B	PARTICIPANT	\N	PRESENT	1
524951	524076	11074Q	PARTICIPANT	\N	PRESENT	0
524952	521656	17367Q	PARTICIPANT	\N	EXCUSE	0
524953	524076	01048V	PARTICIPANT	\N	PRESENT	0
524954	524076	04086Q	PARTICIPANT	\N	PRESENT	0
524955	524076	14083S	PARTICIPANT	\N	PRESENT	0
524956	524076	99004R	PARTICIPANT	\N	PRESENT	0
524957	524076	20126Y	PARTICIPANT	\N	PRESENT	0
524958	521656	20118Y	PARTICIPANT	\N	PRESENT	0
524959	524076	14189C	PARTICIPANT	\N	PRESENT	0
524960	524076	19689Q	PARTICIPANT	\N	PRESENT	0
524961	524076	19647E	PARTICIPANT	\N	PRESENT	0
524962	521656	20024T	PARTICIPANT	\N	PRESENT	0
524963	524108	20086J	PARTICIPANT	\N	PRESENT	0
524964	524108	19383Y	PARTICIPANT	\N	PRESENT	0
524965	524108	20088L	PARTICIPANT	\N	PRESENT	0
524966	524108	19768N	PARTICIPANT	\N	PRESENT	1
524967	524108	19515S	PARTICIPANT	\N	PRESENT	0
524968	524108	20090E	PARTICIPANT	\N	PRESENT	0
524969	524108	19782L	PARTICIPANT	\N	PRESENT	0
524970	524108	20092G	PARTICIPANT	\N	PRESENT	0
524971	524108	01043Q	PARTICIPANT	\N	PRESENT	0
524972	524108	14357A	PARTICIPANT	\N	PRESENT	0
524973	524108	19441R	PARTICIPANT	\N	PRESENT	0
524974	524108	20082E	PARTICIPANT	\N	PRESENT	0
524975	524108	20094J	PARTICIPANT	\N	PRESENT	0
524976	524108	04045F	PARTICIPANT	\N	PRESENT	1
524977	524108	19866P	PARTICIPANT	\N	PRESENT	0
524978	524108	19631V	PARTICIPANT	\N	PRESENT	0
524979	524108	05012A	PARTICIPANT	\N	PRESENT	0
524980	524108	11099A	PARTICIPANT	\N	PRESENT	0
524981	524108	19705W	PARTICIPANT	\N	PRESENT	1
524982	524108	19575F	PARTICIPANT	\N	PRESENT	0
524983	524108	19369B	PARTICIPANT	\N	PRESENT	0
524984	524108	20018V	PARTICIPANT	\N	PRESENT	0
524985	524108	19511N	PARTICIPANT	\N	PRESENT	0
524986	524108	19563B	PARTICIPANT	\N	PRESENT	0
524987	524108	20028X	PARTICIPANT	\N	PRESENT	0
524988	524108	14038Y	PARTICIPANT	\N	PRESENT	0
524989	524108	20032T	PARTICIPANT	\N	PRESENT	0
524990	524108	19467C	PARTICIPANT	\N	PRESENT	0
524991	524108	14187A	PARTICIPANT	\N	PRESENT	0
524992	524108	20144B	PARTICIPANT	\N	PRESENT	0
524993	524108	19695N	PARTICIPANT	\N	PRESENT	0
524994	524108	11090Q	PRESIDENT	0	PRESENT	0
524995	524108	01025N	PARTICIPANT	\N	PRESENT	0
524996	524108	14033T	PARTICIPANT	\N	PRESENT	0
524997	524108	20054A	PARTICIPANT	\N	PRESENT	0
524998	524108	20174H	PARTICIPANT	\N	PRESENT	0
524999	524108	14205J	PARTICIPANT	\N	PRESENT	0
525000	524108	20056C	PARTICIPANT	\N	PRESENT	1
525001	524108	20062A	PARTICIPANT	\N	PRESENT	0
525002	524108	20180F	PARTICIPANT	\N	PRESENT	1
525003	524108	19507S	PARTICIPANT	\N	PRESENT	0
525004	524108	14069U	PARTICIPANT	\N	PRESENT	1
525005	524108	19747H	PARTICIPANT	\N	PRESENT	0
525006	524108	14257W	PARTICIPANT	\N	PRESENT	1
525007	521656	20122U	PARTICIPANT	\N	PRESENT	1
525008	521656	19387D	PARTICIPANT	\N	PRESENT	1
525009	521656	17637T	PARTICIPANT	\N	PRESENT	0
525010	524076	11012A	PARTICIPANT	\N	PRESENT	0
525138	524077	20050V	PARTICIPANT	\N	PRESENT	0
525139	524077	11074Q	PARTICIPANT	\N	PRESENT	0
525140	524077	14253S	PARTICIPANT	\N	PRESENT	0
525141	524077	14225N	PRESIDENT	0	PRESENT	0
525142	524077	07029T	PARTICIPANT	\N	EXCUSE	0
525143	524077	19671E	PARTICIPANT	\N	EXCUSE	0
525144	524110	19766L	PARTICIPANT	\N	PRESENT	0
525145	524110	04070G	PARTICIPANT	\N	PRESENT	0
525146	524110	19699S	PARTICIPANT	\N	PRESENT	0
525147	524110	19533U	PARTICIPANT	\N	PRESENT	1
525148	524110	14229S	PARTICIPANT	\N	PRESENT	0
525149	524110	20098N	PARTICIPANT	\N	PRESENT	1
525150	524110	19573D	PARTICIPANT	\N	PRESENT	0
525151	524110	08017T	PARTICIPANT	\N	PRESENT	1
525152	524110	20112S	PARTICIPANT	\N	PRESENT	0
525153	524110	07033P	PARTICIPANT	\N	PRESENT	1
525154	524110	08012N	PARTICIPANT	\N	PRESENT	0
525155	524110	20026V	PARTICIPANT	\N	PRESENT	1
525156	524110	19593H	PARTICIPANT	\N	PRESENT	0
525157	524110	19527W	PARTICIPANT	\N	PRESENT	0
525158	524110	20132W	PARTICIPANT	\N	PRESENT	0
525159	524110	20134Y	PARTICIPANT	\N	PRESENT	1
525160	524110	19651A	PARTICIPANT	\N	PRESENT	1
525161	524110	19611R	PRESIDENT	0	PRESENT	0
518592	518591	19515S	PRESIDENT	0	PRESENT	0
518593	518591	19575F	PARTICIPANT	\N	PRESENT	0
518594	518591	14105F	PARTICIPANT	\N	PRESENT	0
518595	518591	14083S	PARTICIPANT	\N	PRESENT	0
518596	518591	14329V	PARTICIPANT	\N	PRESENT	0
518597	518591	08028W	PARTICIPANT	\N	PRESENT	0
518598	518591	14041T	PARTICIPANT	\N	PRESENT	0
518599	518591	20040T	PARTICIPANT	\N	PRESENT	0
518600	518591	20126Y	PARTICIPANT	\N	PRESENT	0
518601	518591	08015R	PARTICIPANT	\N	PRESENT	0
518602	518591	19671E	PARTICIPANT	\N	PRESENT	0
518603	518591	19369B	PARTICIPANT	\N	PRESENT	0
518604	518591	20082E	PARTICIPANT	\N	PRESENT	0
518605	518591	19301E	PARTICIPANT	\N	PRESENT	0
518612	514080	14189C	PARTICIPANT	\N	PRESENT	0
518613	514080	20024T	PARTICIPANT	\N	PRESENT	0
518614	514080	14030Q	PRESIDENT	0	PRESENT	0
518615	514080	20138D	PARTICIPANT	\N	PRESENT	0
518616	514080	20080C	PARTICIPANT	\N	PRESENT	0
518617	514080	19621T	PARTICIPANT	\N	EXCUSE	0
518618	514080	11031D	PARTICIPANT	\N	EXCUSE	0
518619	514080	19681G	PARTICIPANT	\N	EXCUSE	0
518620	514080	19693L	PARTICIPANT	\N	PRESENT	0
518621	514080	20106U	PARTICIPANT	\N	PRESENT	0
518622	514080	14179A	PARTICIPANT	\N	PRESENT	0
518623	514080	20066E	PARTICIPANT	\N	PRESENT	0
518624	514080	19715Y	PARTICIPANT	\N	PRESENT	0
518625	514080	07029T	PARTICIPANT	\N	EXCUSE	0
518626	514080	14109K	PARTICIPANT	\N	PRESENT	0
518627	514080	20118Y	PARTICIPANT	\N	EXCUSE	0
518628	514080	20130U	PARTICIPANT	\N	EXCUSE	0
518629	514080	19798U	PARTICIPANT	\N	PRESENT	0
518630	514080	20046A	PARTICIPANT	\N	PRESENT	0
518631	514080	19749K	PARTICIPANT	\N	PRESENT	0
518809	518808	20064C	PARTICIPANT	\N	PRESENT	0
518810	518808	01057W	PARTICIPANT	\N	PRESENT	0
518811	518808	11074Q	PARTICIPANT	\N	PRESENT	0
518814	518808	14147R	PARTICIPANT	\N	PRESENT	0
520339	519312	19747H	PARTICIPANT	\N	PRESENT	0
520340	519312	14259Y	PRESIDENT	0	PRESENT	0
520341	519312	04071H	PARTICIPANT	\N	EXCUSE	0
520342	519312	14237S	PARTICIPANT	\N	EXCUSE	0
520343	519312	19711U	PARTICIPANT	\N	PRESENT	0
520344	519312	20044X	PARTICIPANT	\N	PRESENT	0
520345	519312	14193X	PARTICIPANT	\N	EXCUSE	0
526451	526450	11026G	PARTICIPANT	\N	PRESENT	0
526452	526450	14069U	PARTICIPANT	\N	PRESENT	0
526453	526450	14255U	PARTICIPANT	\N	PRESENT	0
526454	526450	14042U	PARTICIPANT	\N	PRESENT	0
526455	526450	11083R	PARTICIPANT	\N	PRESENT	0
526475	526474	19651A	PARTICIPANT	\N	PRESENT	0
526476	526474	19782L	PARTICIPANT	\N	PRESENT	0
526477	524207	20066E	PARTICIPANT	\N	PRESENT	0
531203	531202	04047H	PARTICIPANT	\N	PRESENT	0
531204	531202	14299H	PARTICIPANT	\N	PRESENT	0
531206	531202	11066Q	PARTICIPANT	\N	PRESENT	0
533792	531507	20054A	PARTICIPANT	\N	PRESENT	0
534070	534069	19441R	PARTICIPANT	\N	PRESENT	0
534071	534069	20060X	PARTICIPANT	\N	PRESENT	0
534072	534069	14038Y	PARTICIPANT	\N	PRESENT	0
534074	534073	14038Y	PARTICIPANT	\N	PRESENT	0
534075	534073	19441R	PARTICIPANT	\N	PRESENT	0
534076	534073	20060X	PARTICIPANT	\N	PRESENT	0
534077	534073	14257W	PARTICIPANT	\N	PRESENT	0
534078	534073	14207L	PARTICIPANT	\N	PRESENT	0
534091	534090	11067R	PARTICIPANT	\N	PRESENT	0
534092	534090	08045X	PARTICIPANT	\N	PRESENT	0
534093	534090	11031D	PARTICIPANT	\N	PRESENT	0
534094	534090	19691J	PARTICIPANT	\N	PRESENT	0
534095	534090	19553Y	PARTICIPANT	\N	PRESENT	0
534096	534090	20130U	PARTICIPANT	\N	PRESENT	0
534099	534098	19745F	PARTICIPANT	\N	PRESENT	0
534100	534098	19369B	PARTICIPANT	\N	PRESENT	0
534102	534101	19745F	PARTICIPANT	\N	PRESENT	0
534103	534101	19369B	PARTICIPANT	\N	PRESENT	0
534105	534104	17367Q	PARTICIPANT	\N	PRESENT	0
534107	534106	17367Q	PARTICIPANT	\N	PRESENT	0
534444	534252	20148F	PARTICIPANT	\N	PRESENT	0
535150	534277	19333N	PARTICIPANT	\N	PRESENT	0
535151	534277	20032T	PARTICIPANT	\N	PRESENT	0
535152	534277	19701S	PARTICIPANT	\N	PRESENT	0
535153	534277	20038A	PARTICIPANT	\N	PRESENT	0
535154	534277	19387D	PARTICIPANT	\N	PRESENT	0
535155	534277	20046A	PARTICIPANT	\N	PRESENT	0
535156	534277	19826F	PARTICIPANT	\N	PRESENT	0
535157	534277	14221J	PARTICIPANT	\N	PRESENT	0
535158	534277	20102Q	PARTICIPANT	\N	PRESENT	0
535159	534277	19599P	PARTICIPANT	\N	PRESENT	0
535160	534277	18083K	PARTICIPANT	\N	PRESENT	0
535161	534277	19739H	PARTICIPANT	\N	PRESENT	0
535162	534277	19745F	PARTICIPANT	\N	PRESENT	0
535163	534277	19619A	PARTICIPANT	\N	PRESENT	0
535164	534277	20136B	PARTICIPANT	\N	PRESENT	0
535165	534277	14031R	PARTICIPANT	\N	PRESENT	0
535166	534277	19549D	PARTICIPANT	\N	PRESENT	0
535167	534277	14219Q	PRESIDENT	0	PRESENT	0
535168	534277	19251M	PARTICIPANT	\N	PRESENT	0
535169	534277	17229F	PARTICIPANT	\N	PRESENT	0
535170	534277	11101A	PARTICIPANT	\N	PRESENT	0
535171	534277	19503N	PARTICIPANT	\N	PRESENT	0
535172	534277	19637C	PARTICIPANT	\N	PRESENT	0
535173	534277	08060W	PARTICIPANT	\N	PRESENT	1
535174	534277	19820Y	PARTICIPANT	\N	PRESENT	0
535175	534277	20106U	PARTICIPANT	\N	PRESENT	0
535176	534277	20100N	PARTICIPANT	\N	PRESENT	0
535177	534277	17637T	PARTICIPANT	\N	PRESENT	0
535178	534353	11040E	PARTICIPANT	\N	PRESENT	0
535179	534353	14331P	PARTICIPANT	\N	PRESENT	0
535180	534353	11048N	PARTICIPANT	\N	PRESENT	0
535181	534353	20050V	PARTICIPANT	\N	PRESENT	0
535182	534353	14253S	PARTICIPANT	\N	PRESENT	0
535183	534353	14225N	PRESIDENT	0	PRESENT	0
535184	534353	19349W	PARTICIPANT	\N	PRESENT	0
535185	534353	19762G	PARTICIPANT	\N	PRESENT	0
535186	534353	11074Q	PARTICIPANT	\N	PRESENT	0
535187	534353	14083S	PARTICIPANT	\N	PRESENT	0
535188	534353	20022R	PARTICIPANT	\N	PRESENT	0
535189	534353	08009T	PARTICIPANT	\N	PRESENT	0
535190	534353	99004R	PARTICIPANT	\N	PRESENT	0
535191	534353	19335Q	PARTICIPANT	\N	PRESENT	0
535192	534353	20080C	PARTICIPANT	\N	PRESENT	0
535193	534353	19741B	PARTICIPANT	\N	PRESENT	0
535194	534353	08011M	PARTICIPANT	\N	PRESENT	0
535195	534353	20044X	PARTICIPANT	\N	PRESENT	0
535196	534353	19711U	PARTICIPANT	\N	PRESENT	0
535197	534353	01057W	PARTICIPANT	\N	PRESENT	0
535198	534277	20076G	PARTICIPANT	\N	PRESENT	0
535199	534277	14237S	PARTICIPANT	\N	PRESENT	0
535200	534277	05012A	PARTICIPANT	\N	PRESENT	0
535201	534277	19685L	PARTICIPANT	\N	PRESENT	0
535202	534277	20024T	PARTICIPANT	\N	PRESENT	0
535203	534277	20140W	PARTICIPANT	\N	PRESENT	0
535204	534353	14189C	PARTICIPANT	\N	PRESENT	0
535205	534277	19525U	PARTICIPANT	\N	PRESENT	0
535206	534277	20096L	PARTICIPANT	\N	PRESENT	0
535207	534277	20068G	PARTICIPANT	\N	PRESENT	0
535208	534353	20126Y	PARTICIPANT	\N	PRESENT	0
535209	534353	01048V	PARTICIPANT	\N	PRESENT	0
535210	534277	11065P	PARTICIPANT	\N	PRESENT	0
535211	530867	19593H	PARTICIPANT	\N	PRESENT	0
535212	530867	19651A	PARTICIPANT	\N	PRESENT	0
535213	530867	19611R	PRESIDENT	0	PRESENT	0
535214	530867	20142Y	PARTICIPANT	\N	PRESENT	0
535215	530867	19399H	PARTICIPANT	\N	PRESENT	0
535216	530867	20152B	PARTICIPANT	\N	PRESENT	0
535217	530867	20052X	PARTICIPANT	\N	PRESENT	0
535218	530867	14229S	PARTICIPANT	\N	PRESENT	0
535219	530867	14030Q	PARTICIPANT	\N	PRESENT	0
535220	530867	20056C	PARTICIPANT	\N	PRESENT	0
535221	530867	20180F	PARTICIPANT	\N	PRESENT	0
535222	530867	14109K	PARTICIPANT	\N	PRESENT	0
535223	530867	07033P	PARTICIPANT	\N	PRESENT	0
535224	530867	08061X	PARTICIPANT	\N	PRESENT	0
535225	530867	19758L	PARTICIPANT	\N	PRESENT	0
535226	530867	19621T	PARTICIPANT	\N	PRESENT	0
535235	530867	14073Q	PARTICIPANT	\N	PRESENT	0
535236	530867	19693L	PARTICIPANT	\N	PRESENT	0
535237	530867	04059M	PARTICIPANT	\N	PRESENT	0
535238	530867	14123H	PARTICIPANT	\N	PRESENT	0
535239	530867	20084G	PARTICIPANT	\N	PRESENT	0
521023	520136	18083K	PARTICIPANT	\N	PRESENT	0
521024	520136	19553Y	PARTICIPANT	\N	PRESENT	0
521025	520136	11031D	PARTICIPANT	\N	PRESENT	0
521026	520136	20066E	PARTICIPANT	\N	PRESENT	0
521027	520136	14041T	PARTICIPANT	\N	PRESENT	0
521028	520136	14195A	PARTICIPANT	\N	PRESENT	0
521029	520136	14213J	PARTICIPANT	\N	PRESENT	0
521030	520136	99004R	PARTICIPANT	\N	PRESENT	0
521031	520136	19683J	PARTICIPANT	\N	PRESENT	0
521032	520136	10006L	PARTICIPANT	\N	PRESENT	0
521033	520136	11072N	PARTICIPANT	\N	PRESENT	0
521034	520136	05008E	PARTICIPANT	\N	EXCUSE	0
521035	518952	19335Q	PARTICIPANT	\N	PRESENT	0
521036	518952	18083K	PARTICIPANT	\N	PRESENT	0
521037	518952	19441R	PARTICIPANT	\N	PRESENT	0
521041	518952	14147R	PARTICIPANT	\N	PRESENT	0
521042	518952	20092G	PARTICIPANT	\N	PRESENT	0
521043	518952	19689Q	PARTICIPANT	\N	PRESENT	0
521044	518952	14026U	PARTICIPANT	\N	PRESENT	0
521045	518952	14213J	PARTICIPANT	\N	PRESENT	0
521094	518953	20028X	PARTICIPANT	\N	PRESENT	0
521095	518953	20046A	PARTICIPANT	\N	PRESENT	0
521096	518953	19565D	PARTICIPANT	\N	PRESENT	0
521097	518953	19489J	PARTICIPANT	\N	PRESENT	0
521098	518953	19631V	PARTICIPANT	\N	PRESENT	0
521099	518953	20018V	PARTICIPANT	\N	PRESENT	0
521100	518953	19599P	PARTICIPANT	\N	PRESENT	0
521101	518953	20092G	PARTICIPANT	\N	PRESENT	0
521102	518953	19689Q	PARTICIPANT	\N	PRESENT	0
521103	518953	19629C	PARTICIPANT	\N	PRESENT	0
521104	518953	20144B	PARTICIPANT	\N	PRESENT	0
521105	518953	04045F	PARTICIPANT	\N	PRESENT	0
521106	518953	19335Q	PARTICIPANT	\N	PRESENT	0
521107	518953	20020P	PARTICIPANT	\N	PRESENT	0
521108	518953	20124W	PARTICIPANT	\N	PRESENT	0
521109	518953	20062A	PARTICIPANT	\N	PRESENT	0
521110	518953	20090E	PARTICIPANT	\N	PRESENT	0
521111	518953	14026U	PARTICIPANT	\N	PRESENT	0
521112	518953	14213J	PARTICIPANT	\N	PRESENT	0
521113	518953	20056C	PARTICIPANT	\N	PRESENT	0
521114	518953	14033T	PARTICIPANT	\N	PRESENT	0
521115	518953	14038Y	PARTICIPANT	\N	PRESENT	0
521116	518953	19798U	PARTICIPANT	\N	PRESENT	0
521117	518953	19577H	PARTICIPANT	\N	PRESENT	0
521118	518953	14237S	PARTICIPANT	\N	PRESENT	0
521119	518953	20122U	PARTICIPANT	\N	PRESENT	0
521120	518953	20106U	PARTICIPANT	\N	PRESENT	0
521121	518953	11012A	PARTICIPANT	\N	PRESENT	0
521122	518953	20128B	PARTICIPANT	\N	PRESENT	0
521123	518953	20140W	PARTICIPANT	\N	PRESENT	0
521124	518953	20102Q	PARTICIPANT	\N	PRESENT	0
521125	518953	14147R	PARTICIPANT	\N	PRESENT	0
521126	518953	19701S	PARTICIPANT	\N	PRESENT	0
521127	518953	19619A	PARTICIPANT	\N	PRESENT	0
521128	518953	20174H	PARTICIPANT	\N	PRESENT	0
521129	518953	19563B	PARTICIPANT	\N	PRESENT	0
521130	518953	07029T	PARTICIPANT	\N	PRESENT	0
521131	518953	19695N	PARTICIPANT	\N	PRESENT	0
521132	518953	19413M	PARTICIPANT	\N	PRESENT	0
521133	518953	14257W	PARTICIPANT	\N	PRESENT	0
521134	518953	01048V	PARTICIPANT	\N	PRESENT	0
521176	518954	19619A	PARTICIPANT	\N	PRESENT	0
521180	518954	19413M	PARTICIPANT	\N	PRESENT	0
521181	518954	14055N	PARTICIPANT	\N	PRESENT	0
521182	518954	01048V	PARTICIPANT	\N	PRESENT	0
521183	518954	19563B	PARTICIPANT	\N	PRESENT	0
521092	518953	19719D	PARTICIPANT	\N	PRESENT	0
521093	518953	19387D	PARTICIPANT	\N	PRESENT	0
521184	518954	20092G	PARTICIPANT	\N	PRESENT	0
521185	518954	20174H	PARTICIPANT	\N	PRESENT	0
521186	518954	11012A	PARTICIPANT	\N	PRESENT	0
521187	518954	20046A	PARTICIPANT	\N	PRESENT	0
521188	518954	20144B	PARTICIPANT	\N	PRESENT	0
521189	518954	20028X	PARTICIPANT	\N	PRESENT	0
521190	518954	14033T	PARTICIPANT	\N	PRESENT	0
521191	518954	20018V	PARTICIPANT	\N	PRESENT	0
521192	518954	11043H	PARTICIPANT	\N	PRESENT	0
521193	518954	19387D	PARTICIPANT	\N	PRESENT	0
521194	518954	04085P	PARTICIPANT	\N	PRESENT	0
521195	518954	20102Q	PARTICIPANT	\N	PRESENT	0
521196	518954	19758L	PARTICIPANT	\N	PRESENT	0
521197	518954	14257W	PARTICIPANT	\N	PRESENT	0
521198	518954	14038Y	PARTICIPANT	\N	PRESENT	0
521199	518954	20124W	PARTICIPANT	\N	PRESENT	0
521200	518954	19631V	PARTICIPANT	\N	PRESENT	0
521201	518954	19551W	PARTICIPANT	\N	PRESENT	0
521202	518954	20130U	PARTICIPANT	\N	PRESENT	0
521203	518954	19503N	PARTICIPANT	\N	PRESENT	0
521204	518954	14069U	PARTICIPANT	\N	PRESENT	0
521205	518954	14147R	PARTICIPANT	\N	PRESENT	0
523180	521235	08010L	PARTICIPANT	\N	EXCUSE	0
523181	521575	19383Y	PARTICIPANT	\N	PRESENT	0
523182	521575	20092G	PARTICIPANT	\N	PRESENT	0
523183	521575	14357A	PARTICIPANT	\N	PRESENT	0
523184	521575	20082E	PARTICIPANT	\N	PRESENT	1
523185	521575	11099A	PARTICIPANT	\N	PRESENT	0
523186	521575	19575F	PARTICIPANT	\N	PRESENT	0
521173	518954	12041X	PARTICIPANT	\N	PRESENT	0
521175	518954	19695N	PARTICIPANT	\N	PRESENT	0
523187	521575	19467C	PARTICIPANT	\N	PRESENT	1
523188	521575	19695N	PARTICIPANT	\N	PRESENT	1
523189	521476	19826F	PARTICIPANT	\N	PRESENT	0
523190	521476	19527W	PARTICIPANT	\N	PRESENT	0
523191	521476	19689Q	PARTICIPANT	\N	PRESENT	0
523192	521476	11067R	PARTICIPANT	\N	PRESENT	0
523193	521476	14151M	PARTICIPANT	\N	PRESENT	0
523194	521476	19649G	PARTICIPANT	\N	PRESENT	0
523195	521476	20112S	PARTICIPANT	\N	PRESENT	0
523196	521476	20038A	PARTICIPANT	\N	PRESENT	0
523198	521476	19713W	PARTICIPANT	\N	PRESENT	0
523199	521476	01024M	PARTICIPANT	\N	PRESENT	0
523200	521476	11053K	PARTICIPANT	\N	PRESENT	0
523201	521476	19301E	PARTICIPANT	\N	PRESENT	0
523202	521476	01048V	PARTICIPANT	\N	PRESENT	0
523203	521476	19467C	PARTICIPANT	\N	PRESENT	0
523204	521476	20096L	PARTICIPANT	\N	PRESENT	0
523205	521476	08034U	PARTICIPANT	\N	PRESENT	0
523206	521476	19563B	PARTICIPANT	\N	PRESENT	0
523207	521476	14251Q	PARTICIPANT	\N	PRESENT	0
523208	521476	14033T	PARTICIPANT	\N	PRESENT	0
523209	521476	19611R	PARTICIPANT	\N	PRESENT	0
523210	521476	19399H	PARTICIPANT	\N	PRESENT	0
523211	521476	97011G	PARTICIPANT	\N	PRESENT	0
523212	521476	20034V	PARTICIPANT	\N	PRESENT	0
523213	521476	14031R	PARTICIPANT	\N	PRESENT	0
523214	521476	19621T	PARTICIPANT	\N	PRESENT	0
523215	521476	20100N	PARTICIPANT	\N	PRESENT	0
523216	521476	20046A	PARTICIPANT	\N	PRESENT	0
523217	521476	11109J	PARTICIPANT	\N	PRESENT	0
523218	521476	19631V	PARTICIPANT	\N	PRESENT	0
523219	521476	08069G	PARTICIPANT	\N	PRESENT	0
523220	521476	20060X	PARTICIPANT	\N	PRESENT	0
523241	521476	19503N	PARTICIPANT	\N	PRESENT	0
523242	521476	19387D	PARTICIPANT	\N	PRESENT	0
523243	521476	19647E	PARTICIPANT	\N	PRESENT	0
523244	521476	20092G	PARTICIPANT	\N	PRESENT	0
523245	521476	19507S	PARTICIPANT	\N	PRESENT	0
523246	521476	19383Y	PARTICIPANT	\N	PRESENT	0
523247	521476	19739H	PARTICIPANT	\N	PRESENT	0
523248	521476	19447X	PARTICIPANT	\N	PRESENT	0
523249	521476	20126Y	PARTICIPANT	\N	PRESENT	0
523250	521476	07029T	PARTICIPANT	\N	PRESENT	0
523251	521235	19741B	PARTICIPANT	\N	PRESENT	0
521019	520136	19691J	PARTICIPANT	\N	PRESENT	0
521020	520136	19715Y	PARTICIPANT	\N	PRESENT	0
521021	520136	11066Q	PARTICIPANT	\N	PRESENT	0
521022	520136	19447X	PARTICIPANT	\N	PRESENT	0
513149	509848	17229F	PARTICIPANT	\N	PRESENT	0
516782	516781	05008E	PARTICIPANT	\N	PRESENT	0
516783	516781	11033F	PARTICIPANT	\N	PRESENT	0
516784	516781	11053K	PARTICIPANT	\N	PRESENT	0
516785	516781	14357A	PARTICIPANT	\N	PRESENT	0
516786	516781	11070L	PARTICIPANT	\N	PRESENT	0
516787	516781	19719D	PARTICIPANT	\N	PRESENT	0
516788	516781	19673G	PARTICIPANT	\N	PRESENT	0
516789	516781	01025N	PARTICIPANT	\N	PRESENT	0
516790	516781	14033T	PARTICIPANT	\N	PRESENT	0
516791	516781	14123H	PARTICIPANT	\N	PRESENT	0
516792	516781	14026U	PARTICIPANT	\N	PRESENT	0
516793	516781	14179A	PARTICIPANT	\N	PRESENT	0
516794	516781	14213J	PARTICIPANT	\N	PRESENT	0
516795	516781	19715Y	PARTICIPANT	\N	PRESENT	0
516796	516781	99004R	PARTICIPANT	\N	PRESENT	0
516797	516781	86034E	PARTICIPANT	\N	PRESENT	0
516798	516781	12041X	PARTICIPANT	\N	PRESENT	0
516799	516781	14147R	PARTICIPANT	\N	PRESENT	0
516800	516781	11045K	PARTICIPANT	\N	PRESENT	0
516801	516781	04045F	PARTICIPANT	\N	PRESENT	0
516802	516781	01028R	PARTICIPANT	\N	PRESENT	0
516803	516781	19413M	PARTICIPANT	\N	PRESENT	0
523563	523562	19820Y	PARTICIPANT	\N	PRESENT	0
523565	523562	19637C	PARTICIPANT	\N	PRESENT	0
523566	523562	20118Y	PARTICIPANT	\N	PRESENT	0
523567	523562	14205J	PARTICIPANT	\N	PRESENT	0
523568	523562	14033T	PARTICIPANT	\N	PRESENT	0
523569	523562	19507S	PARTICIPANT	\N	PRESENT	0
523751	521430	14331P	PRESIDENT	0	PRESENT	0
523752	521430	04034C	PARTICIPANT	\N	PRESENT	1
523753	521430	04070G	PARTICIPANT	\N	EXCUSE	0
523754	521430	14001X	PARTICIPANT	\N	PRESENT	0
523755	521430	19441R	PARTICIPANT	\N	PRESENT	1
523756	521430	08034U	PARTICIPANT	\N	PRESENT	0
523757	521430	11026G	PARTICIPANT	\N	PRESENT	0
523758	521430	19711U	PARTICIPANT	\N	PRESENT	0
523759	521430	12041X	PARTICIPANT	\N	PRESENT	0
523760	521430	14073Q	PARTICIPANT	\N	PRESENT	0
523761	521430	14097Y	PARTICIPANT	\N	PRESENT	1
523762	521430	19531S	PARTICIPANT	\N	PRESENT	0
523763	521430	19725B	PARTICIPANT	\N	PRESENT	1
523764	521430	14033T	PARTICIPANT	\N	PRESENT	1
523765	521430	11083R	PARTICIPANT	\N	PRESENT	0
523766	521430	19521Q	PARTICIPANT	\N	PRESENT	0
523767	521430	20100N	PARTICIPANT	\N	PRESENT	0
523768	521430	19507S	PARTICIPANT	\N	PRESENT	0
523769	521430	14357A	PARTICIPANT	\N	EXCUSE	0
523770	521430	19701S	PARTICIPANT	\N	PRESENT	1
523771	521430	20104S	PARTICIPANT	\N	PRESENT	1
523772	521430	14089Y	PARTICIPANT	\N	PRESENT	0
523773	521430	20094J	PARTICIPANT	\N	PRESENT	1
523774	521430	14189C	PARTICIPANT	\N	EXCUSE	0
523775	521430	14133K	PARTICIPANT	\N	PRESENT	1
524271	524270	11048N	PARTICIPANT	\N	PRESENT	0
528826	526653	14189C	PARTICIPANT	\N	PRESENT	0
528827	526653	11033F	PARTICIPANT	\N	PRESENT	0
528828	526653	19683J	PRESIDENT	0	PRESENT	0
528829	526653	99004R	PARTICIPANT	\N	PRESENT	0
528830	526653	19699S	PARTICIPANT	\N	PRESENT	0
528831	526653	19563B	PARTICIPANT	\N	PRESENT	0
528832	526653	19573D	PARTICIPANT	\N	PRESENT	0
528833	526653	20030R	PARTICIPANT	\N	PRESENT	0
525807	522571	20050V	PARTICIPANT	\N	EXCUSE	0
525853	522571	19551W	PARTICIPANT	\N	PRESENT	0
528834	526653	14229S	PARTICIPANT	\N	PRESENT	0
528920	527925	19798U	PARTICIPANT	\N	PRESENT	0
530752	529007	14331P	PARTICIPANT	\N	EXCUSE	0
533350	531371	19301E	PARTICIPANT	\N	PRESENT	0
533351	531371	19713W	PARTICIPANT	\N	PRESENT	0
533352	531371	19441R	PARTICIPANT	\N	PRESENT	0
533353	531371	20062A	PARTICIPANT	\N	PRESENT	0
533354	531371	19575F	PARTICIPANT	\N	PRESENT	0
533355	531371	20018V	PARTICIPANT	\N	PRESENT	0
533356	531319	11026G	PARTICIPANT	\N	PRESENT	0
533357	531319	19447X	PARTICIPANT	\N	PRESENT	0
533358	531319	05008E	PARTICIPANT	\N	PRESENT	0
533359	531319	19954N	PARTICIPANT	\N	PRESENT	0
533360	531319	19749K	PARTICIPANT	\N	PRESENT	0
533361	531371	04057K	PARTICIPANT	\N	PRESENT	0
533362	531371	11097X	PARTICIPANT	\N	PRESENT	0
533363	531371	14055N	PARTICIPANT	\N	PRESENT	0
533364	531371	20106U	PARTICIPANT	\N	PRESENT	0
533367	531371	11048N	PARTICIPANT	\N	PRESENT	0
533370	531371	19703U	PARTICIPANT	\N	PRESENT	0
533372	531371	19577H	PARTICIPANT	\N	PRESENT	0
533373	531371	19657G	PARTICIPANT	\N	PRESENT	0
533374	531371	20070A	PARTICIPANT	\N	PRESENT	0
533377	531371	11012A	PARTICIPANT	\N	PRESENT	0
533378	531319	14231L	PARTICIPANT	\N	PRESENT	0
533379	531319	14147R	PARTICIPANT	\N	PRESENT	0
533381	531371	14071N	PARTICIPANT	\N	PRESENT	0
533382	531371	19735D	PARTICIPANT	\N	PRESENT	0
533384	531371	14083S	PARTICIPANT	\N	PRESENT	0
533385	531371	19467C	PARTICIPANT	\N	PRESENT	0
533388	533383	14071N	PARTICIPANT	\N	PRESENT	0
533389	533383	19657G	PARTICIPANT	\N	PRESENT	0
533390	533383	11067R	PARTICIPANT	\N	PRESENT	0
533392	533386	14071N	PARTICIPANT	\N	PRESENT	0
533397	531319	04070G	PARTICIPANT	\N	PRESENT	0
533398	531319	19533U	PARTICIPANT	\N	PRESENT	0
533399	531319	14229S	PARTICIPANT	\N	PRESENT	0
533400	531319	20098N	PARTICIPANT	\N	PRESENT	0
533401	531319	20124W	PARTICIPANT	\N	PRESENT	0
533402	531319	20026V	PARTICIPANT	\N	PRESENT	0
533403	531319	20132W	PARTICIPANT	\N	PRESENT	0
533404	531319	19399H	PARTICIPANT	\N	PRESENT	0
533405	531319	20056C	PARTICIPANT	\N	PRESENT	0
533406	531319	20180F	PARTICIPANT	\N	PRESENT	0
533407	531319	14123H	PARTICIPANT	\N	PRESENT	0
533408	531319	19758L	PARTICIPANT	\N	PRESENT	0
533409	531319	19621T	PARTICIPANT	\N	PRESENT	0
533410	531319	20084G	PARTICIPANT	\N	PRESENT	0
533411	531319	07033P	PARTICIPANT	\N	PRESENT	0
533412	531319	14030Q	PARTICIPANT	\N	PRESENT	0
533417	531371	11101A	PARTICIPANT	\N	PRESENT	0
533448	531371	14219Q	PARTICIPANT	\N	PRESENT	0
533449	531371	19663E	PARTICIPANT	\N	PRESENT	0
533450	531371	20098N	PARTICIPANT	\N	PRESENT	0
533451	531371	20080C	PARTICIPANT	\N	PRESENT	0
533452	531371	19565D	PARTICIPANT	\N	PRESENT	0
533453	531371	19826F	PARTICIPANT	\N	PRESENT	0
533454	531371	20134Y	PARTICIPANT	\N	PRESENT	0
533455	531320	14053L	PARTICIPANT	\N	PRESENT	0
533456	531320	19954N	PARTICIPANT	\N	PRESENT	0
533457	531320	14147R	PARTICIPANT	\N	PRESENT	0
533458	531320	04047H	PRESIDENT	0	PRESENT	0
533459	531320	19749K	PARTICIPANT	\N	PRESENT	0
533460	531320	19673G	PARTICIPANT	\N	PRESENT	0
533461	531320	19447X	PARTICIPANT	\N	PRESENT	0
533462	531320	14231L	PARTICIPANT	\N	PRESENT	0
533463	531319	14069U	PARTICIPANT	\N	PRESENT	1
533464	531319	17737W	PARTICIPANT	\N	PRESENT	1
533465	531319	19725B	PARTICIPANT	\N	PRESENT	1
533466	530831	04070G	PARTICIPANT	\N	PRESENT	0
533467	530831	19533U	PARTICIPANT	\N	PRESENT	0
533468	530831	19673G	PARTICIPANT	\N	PRESENT	0
533469	530831	14229S	PARTICIPANT	\N	PRESENT	0
533470	530831	20098N	PARTICIPANT	\N	PRESENT	0
533471	530831	05008E	PARTICIPANT	\N	PRESENT	0
533472	530831	14231L	PARTICIPANT	\N	PRESENT	0
533473	530831	19954N	PARTICIPANT	\N	PRESENT	0
533474	530831	14147R	PARTICIPANT	\N	PRESENT	0
533475	530831	07033P	PARTICIPANT	\N	PRESENT	0
533476	530831	20124W	PARTICIPANT	\N	PRESENT	0
533477	530831	20026V	PARTICIPANT	\N	PRESENT	0
533478	530831	19593H	PARTICIPANT	\N	PRESENT	0
533479	530831	14053L	PARTICIPANT	\N	PRESENT	0
533480	530831	20132W	PARTICIPANT	\N	PRESENT	0
533481	530831	19643A	PARTICIPANT	\N	PRESENT	0
533482	530831	14097Y	PARTICIPANT	\N	PRESENT	0
533483	530831	20134Y	PARTICIPANT	\N	PRESENT	0
533484	530831	19611R	PRESIDENT	0	PRESENT	0
533485	530831	11026G	PARTICIPANT	\N	PRESENT	0
533486	530831	19693L	PARTICIPANT	\N	PRESENT	0
533487	530831	19399H	PARTICIPANT	\N	PRESENT	0
533488	530831	20052X	PARTICIPANT	\N	PRESENT	0
533489	530831	20152B	PARTICIPANT	\N	PRESENT	0
533490	530831	14030Q	PARTICIPANT	\N	PRESENT	0
533491	530831	20056C	PARTICIPANT	\N	PRESENT	0
533492	530831	20180F	PARTICIPANT	\N	PRESENT	0
525162	524110	20138D	PARTICIPANT	\N	PRESENT	0
525163	524110	20142Y	PARTICIPANT	\N	PRESENT	0
525164	524110	20048C	PARTICIPANT	\N	PRESENT	1
525165	524110	19693L	PARTICIPANT	\N	PRESENT	0
525166	524110	19399H	PARTICIPANT	\N	PRESENT	0
525167	524110	20052X	PARTICIPANT	\N	PRESENT	0
525168	524110	14030Q	PARTICIPANT	\N	PRESENT	0
525169	524110	20058E	PARTICIPANT	\N	PRESENT	0
525170	524110	20056C	PARTICIPANT	\N	PRESENT	0
525171	524110	20180F	PARTICIPANT	\N	PRESENT	1
525172	524110	04059M	PARTICIPANT	\N	PRESENT	0
525173	524110	19735D	PARTICIPANT	\N	PRESENT	1
525174	524110	11043H	PARTICIPANT	\N	PRESENT	0
525175	524110	11104D	PARTICIPANT	\N	PRESENT	1
525176	524110	19758L	PARTICIPANT	\N	PRESENT	0
525177	524110	17589D	PARTICIPANT	\N	PRESENT	1
525178	524077	01048V	PARTICIPANT	\N	PRESENT	0
525179	524077	01057W	PARTICIPANT	\N	PRESENT	0
525183	524077	14327T	PARTICIPANT	\N	PRESENT	0
525184	524077	11048N	PARTICIPANT	\N	PRESENT	0
525185	524077	19711U	PARTICIPANT	\N	PRESENT	0
525186	524077	19689Q	PARTICIPANT	\N	PRESENT	0
525187	524077	20044X	PARTICIPANT	\N	PRESENT	0
525188	524077	11040E	PARTICIPANT	\N	PRESENT	0
525189	524077	04086Q	PARTICIPANT	\N	PRESENT	0
525190	524077	14083S	PARTICIPANT	\N	PRESENT	0
525191	524077	08009T	PARTICIPANT	\N	PRESENT	0
525192	524077	20070A	PARTICIPANT	\N	PRESENT	0
525193	524077	19741B	PARTICIPANT	\N	PRESENT	0
525194	524077	99004R	PARTICIPANT	\N	PRESENT	0
525195	524077	20022R	PARTICIPANT	\N	PRESENT	0
525196	524077	20126Y	PARTICIPANT	\N	PRESENT	0
525197	524071	19543W	PARTICIPANT	\N	PRESENT	0
525198	521657	19333N	PARTICIPANT	\N	PRESENT	0
525199	521657	19701S	PARTICIPANT	\N	PRESENT	0
525200	521657	14031R	PARTICIPANT	\N	PRESENT	0
525201	521657	20038A	PARTICIPANT	\N	PRESENT	0
525202	521657	19549D	PARTICIPANT	\N	PRESENT	0
525203	521657	20076G	PARTICIPANT	\N	PRESENT	0
525204	521657	19387D	PARTICIPANT	\N	PRESENT	0
525205	521657	14219Q	PRESIDENT	0	PRESENT	0
525206	521657	19820Y	PARTICIPANT	\N	PRESENT	0
525207	521657	19826F	PARTICIPANT	\N	PRESENT	0
525208	521657	19599P	PARTICIPANT	\N	PRESENT	0
525209	521657	20102Q	PARTICIPANT	\N	PRESENT	0
525210	521657	20096L	PARTICIPANT	\N	PRESENT	0
525211	521657	18083K	PARTICIPANT	\N	PRESENT	0
525212	521657	19551W	PARTICIPANT	\N	PRESENT	0
525213	521657	20118Y	PARTICIPANT	\N	PRESENT	0
525214	521657	19503N	PARTICIPANT	\N	PRESENT	0
525215	521657	19739H	PARTICIPANT	\N	PRESENT	0
525216	521657	19745F	PARTICIPANT	\N	PRESENT	0
525217	521657	19619A	PARTICIPANT	\N	PRESENT	0
525218	521657	17637T	PARTICIPANT	\N	PRESENT	0
525219	521657	11065P	PARTICIPANT	\N	PRESENT	0
525220	521657	20120S	PARTICIPANT	\N	PRESENT	0
525221	521657	20100N	PARTICIPANT	\N	PRESENT	1
525222	521657	08060W	PARTICIPANT	\N	PRESENT	1
525223	521657	20136B	PARTICIPANT	\N	PRESENT	1
525224	521657	20020P	PARTICIPANT	\N	PRESENT	1
525225	521657	19251M	PARTICIPANT	\N	PRESENT	1
525226	521657	19637C	PARTICIPANT	\N	PRESENT	1
525227	521657	14169X	PARTICIPANT	\N	PRESENT	1
525228	524107	11041F	PARTICIPANT	\N	PRESENT	1
525229	524071	08018U	PARTICIPANT	\N	PRESENT	0
525238	521657	14237S	PARTICIPANT	\N	PRESENT	0
525249	524077	11053K	PARTICIPANT	\N	PRESENT	0
525250	524077	19335Q	PARTICIPANT	\N	PRESENT	0
525251	524077	19647E	PARTICIPANT	\N	PRESENT	0
525252	524077	14189C	PARTICIPANT	\N	PRESENT	0
525253	524077	11012A	PARTICIPANT	\N	PRESENT	0
525254	524077	19762G	PARTICIPANT	\N	PRESENT	0
525785	524078	14327T	PARTICIPANT	\N	PRESENT	0
525787	524119	14251Q	PARTICIPANT	\N	PRESENT	0
525789	524119	04085P	PARTICIPANT	\N	PRESENT	0
525790	524119	20112S	PARTICIPANT	\N	PRESENT	0
525791	524119	20086J	PARTICIPANT	\N	PRESENT	0
525792	524119	14187A	PARTICIPANT	\N	PRESENT	0
525793	524078	01048V	PARTICIPANT	\N	PRESENT	0
525794	524078	08011M	PARTICIPANT	\N	PRESENT	0
525795	524119	19515S	PARTICIPANT	\N	PRESENT	0
525796	524119	19387D	PARTICIPANT	\N	PRESENT	0
525797	524078	11012A	PARTICIPANT	\N	PRESENT	0
525798	524119	11097X	PARTICIPANT	\N	PRESENT	0
525799	524119	20088L	PARTICIPANT	\N	PRESENT	0
525800	524078	14083S	PARTICIPANT	\N	PRESENT	0
526168	526167	20032T	PARTICIPANT	\N	PRESENT	0
526169	526167	19383Y	PARTICIPANT	\N	PRESENT	0
526170	526167	19467C	PARTICIPANT	\N	PRESENT	0
526171	526167	19507S	PARTICIPANT	\N	PRESENT	0
526172	526167	19511N	PARTICIPANT	\N	PRESENT	0
526173	526167	14097Y	PARTICIPANT	\N	PRESENT	0
526174	526167	11099A	PARTICIPANT	\N	PRESENT	0
526175	526167	14205J	PARTICIPANT	\N	PRESENT	0
526176	526167	20018V	PARTICIPANT	\N	PRESENT	0
526177	526167	20054A	PARTICIPANT	\N	PRESENT	0
526178	526167	11097X	PARTICIPANT	\N	PRESENT	0
526179	526167	19713W	PARTICIPANT	\N	PRESENT	0
526180	526167	20062A	PARTICIPANT	\N	PRESENT	0
526181	526167	14173T	PARTICIPANT	\N	PRESENT	0
526182	526167	20038A	PARTICIPANT	\N	PRESENT	0
526185	526184	20086J	PARTICIPANT	\N	PRESENT	0
526187	526186	20086J	PARTICIPANT	\N	PRESENT	0
526198	522571	20032T	PARTICIPANT	\N	PRESENT	0
526199	522571	19543W	PARTICIPANT	\N	PRESENT	0
526200	522571	20042V	PARTICIPANT	\N	PRESENT	0
526201	522571	19643A	PARTICIPANT	\N	PRESENT	0
526202	522571	19747H	PARTICIPANT	\N	PRESENT	0
526203	522571	11056N	PARTICIPANT	\N	PRESENT	0
526204	522571	20132W	PARTICIPANT	\N	PRESENT	0
526205	522571	19553Y	PARTICIPANT	\N	PRESENT	0
526206	522571	99004R	PARTICIPANT	\N	PRESENT	0
526207	522571	19711U	PARTICIPANT	\N	PRESENT	0
526208	522571	20018V	PARTICIPANT	\N	PRESENT	0
526209	522571	20044X	PARTICIPANT	\N	PRESENT	0
526210	522571	11097X	PARTICIPANT	\N	PRESENT	0
526211	522571	19703U	PARTICIPANT	\N	PRESENT	0
526212	522571	19651A	PARTICIPANT	\N	PRESENT	0
526213	522571	11040E	PARTICIPANT	\N	PRESENT	0
526214	522571	95063L	PARTICIPANT	\N	PRESENT	0
526232	518916	19657G	PARTICIPANT	\N	PRESENT	0
526331	521467	08010L	PARTICIPANT	\N	PRESENT	0
526332	521467	14069U	PARTICIPANT	\N	PRESENT	0
526333	521467	19758L	PARTICIPANT	\N	PRESENT	0
526334	521467	20120S	PARTICIPANT	\N	PRESENT	0
526335	521467	19489J	PARTICIPANT	\N	PRESENT	0
526336	521467	14205J	PARTICIPANT	\N	PRESENT	0
526337	521467	19735D	PARTICIPANT	\N	PRESENT	0
526338	521467	20058E	PARTICIPANT	\N	PRESENT	0
526339	521467	04045F	PARTICIPANT	\N	PRESENT	0
526340	521467	14215L	PARTICIPANT	\N	PRESENT	0
526341	521467	20084G	PARTICIPANT	\N	PRESENT	0
526342	521467	14187A	PARTICIPANT	\N	PRESENT	0
526343	521467	01057W	PARTICIPANT	\N	PRESENT	0
526344	521467	04086Q	PARTICIPANT	\N	PRESENT	0
526345	521467	14327T	PARTICIPANT	\N	PRESENT	0
526346	521467	20090E	PARTICIPANT	\N	PRESENT	0
526347	521467	19826F	PARTICIPANT	\N	PRESENT	0
526348	521467	14151M	PARTICIPANT	\N	PRESENT	0
526349	521467	14257W	PARTICIPANT	\N	PRESENT	0
526350	521467	14071N	PARTICIPANT	\N	PRESENT	0
526351	521467	14229S	PARTICIPANT	\N	PRESENT	0
526352	521467	20022R	PARTICIPANT	\N	PRESENT	0
526353	521467	19565D	PARTICIPANT	\N	PRESENT	0
526354	521467	20110Q	PARTICIPANT	\N	PRESENT	0
526355	521467	19349W	PARTICIPANT	\N	PRESENT	0
526356	521467	05012A	PARTICIPANT	\N	PRESENT	0
526357	521467	17637T	PARTICIPANT	\N	PRESENT	0
526358	521467	14281W	PARTICIPANT	\N	PRESENT	0
527869	526540	20050V	PARTICIPANT	\N	PRESENT	0
527870	526540	19545Y	PARTICIPANT	\N	PRESENT	0
527874	526540	19798U	PARTICIPANT	\N	PRESENT	0
527876	526540	19629C	PARTICIPANT	\N	PRESENT	0
527877	526540	19621T	PARTICIPANT	\N	PRESENT	0
527878	526540	17229F	PARTICIPANT	\N	PRESENT	0
527879	526540	14179A	PARTICIPANT	\N	PRESENT	0
527880	526540	01025N	PARTICIPANT	\N	PRESENT	0
527881	526540	16685X	PARTICIPANT	\N	PRESENT	0
527882	526540	19619A	PARTICIPANT	\N	PRESENT	0
527883	526540	14205J	PARTICIPANT	\N	PRESENT	0
527884	526540	20144B	PARTICIPANT	\N	PRESENT	0
513727	502363	08073C	PARTICIPANT	\N	PRESENT	0
513728	502363	11048N	PARTICIPANT	\N	PRESENT	0
513729	502363	19651A	PARTICIPANT	\N	PRESENT	0
513730	502363	11099A	PARTICIPANT	\N	PRESENT	0
513731	502363	18083K	PARTICIPANT	\N	PRESENT	0
513732	502363	20070A	PARTICIPANT	\N	PRESENT	0
513733	502363	07029T	PARTICIPANT	\N	PRESENT	0
513734	502363	19503N	PARTICIPANT	\N	PRESENT	0
513735	502363	19711U	PARTICIPANT	\N	PRESENT	0
513736	502363	20050V	PARTICIPANT	\N	PRESENT	0
513737	502363	04086Q	PARTICIPANT	\N	PRESENT	0
513738	502363	19629C	PARTICIPANT	\N	PRESENT	0
513739	502363	11053K	PARTICIPANT	\N	PRESENT	0
513740	502363	14083S	PARTICIPANT	\N	PRESENT	0
513741	502363	14205J	PARTICIPANT	\N	PRESENT	0
513742	502363	19687N	PARTICIPANT	\N	PRESENT	0
513743	502363	19695N	PARTICIPANT	\N	PRESENT	0
513744	502363	20080C	PARTICIPANT	\N	PRESENT	0
513745	502363	19647E	PARTICIPANT	\N	PRESENT	0
513746	502363	14173T	PARTICIPANT	\N	PRESENT	0
513747	502363	17367Q	PARTICIPANT	\N	PRESENT	0
513748	502363	19693L	PARTICIPANT	\N	PRESENT	0
513749	502363	14327T	PARTICIPANT	\N	PRESENT	0
513750	502363	19741B	PARTICIPANT	\N	PRESENT	0
513751	502363	20022R	PARTICIPANT	\N	PRESENT	0
513752	502363	04059M	PARTICIPANT	\N	PRESENT	0
513753	502363	20034V	PARTICIPANT	\N	PRESENT	0
513754	502363	19551W	PARTICIPANT	\N	PRESENT	0
513755	502363	19657G	PARTICIPANT	\N	PRESENT	0
513756	502363	19667J	PARTICIPANT	\N	PRESENT	0
513757	502363	19683J	PARTICIPANT	\N	PRESENT	0
513782	502363	19762G	PARTICIPANT	\N	PRESENT	0
513783	502363	07033P	PARTICIPANT	\N	PRESENT	0
513784	502363	11012A	PARTICIPANT	\N	PRESENT	0
513785	502363	20150Y	PARTICIPANT	\N	PRESENT	0
513786	502363	19599P	PARTICIPANT	\N	PRESENT	0
513787	502363	19715Y	PARTICIPANT	\N	PRESENT	0
513788	502363	99004R	PARTICIPANT	\N	PRESENT	0
513789	502363	11074Q	PARTICIPANT	\N	PRESENT	0
513790	502363	08034U	PARTICIPANT	\N	PRESENT	0
513791	502363	20100N	PARTICIPANT	\N	PRESENT	0
513792	502363	14187A	PARTICIPANT	\N	PRESENT	0
513793	502363	11070L	PARTICIPANT	\N	PRESENT	0
513794	502363	04085P	PARTICIPANT	\N	PRESENT	0
513837	502364	11048N	PARTICIPANT	\N	PRESENT	0
513838	502364	20080C	PARTICIPANT	\N	PRESENT	0
513839	502364	19503N	PARTICIPANT	\N	PRESENT	0
513840	502364	11012A	PARTICIPANT	\N	PRESENT	0
513841	502364	20050V	PARTICIPANT	\N	PRESENT	0
513842	502364	20100N	PARTICIPANT	\N	PRESENT	0
513843	502364	19687N	PARTICIPANT	\N	PRESENT	0
513844	502364	11074Q	PARTICIPANT	\N	PRESENT	0
513845	502364	19711U	PARTICIPANT	\N	PRESENT	0
513846	502364	19651A	PARTICIPANT	\N	PRESENT	0
513847	502364	19667J	PARTICIPANT	\N	PRESENT	0
513848	502364	19741B	PARTICIPANT	\N	PRESENT	0
513849	502364	07029T	PARTICIPANT	\N	PRESENT	0
513850	502364	14083S	PARTICIPANT	\N	PRESENT	0
513851	502364	14327T	PARTICIPANT	\N	PRESENT	0
513852	502364	11053K	PARTICIPANT	\N	PRESENT	0
513853	502364	14187A	PARTICIPANT	\N	PRESENT	0
513854	502364	14173T	PARTICIPANT	\N	PRESENT	0
513857	502364	14225N	PARTICIPANT	\N	PRESENT	0
513859	502364	08061X	PARTICIPANT	\N	PRESENT	0
513858	502364	20022R	PARTICIPANT	\N	PRESENT	0
513860	502364	11031D	PARTICIPANT	\N	PRESENT	0
513861	502364	11065P	PARTICIPANT	\N	PRESENT	0
513862	502364	04086Q	PARTICIPANT	\N	PRESENT	0
513863	502364	19762G	PARTICIPANT	\N	PRESENT	0
513864	502364	19657G	PARTICIPANT	\N	PRESENT	0
513865	502364	11070L	PARTICIPANT	\N	PRESENT	0
513866	502364	08034U	PARTICIPANT	\N	PRESENT	0
513867	502364	14205J	PARTICIPANT	\N	PRESENT	0
513868	502364	07004J	PARTICIPANT	\N	PRESENT	0
513869	502364	19691J	PARTICIPANT	\N	PRESENT	0
513870	502364	19369B	PARTICIPANT	\N	PRESENT	0
513871	502364	11099A	PARTICIPANT	\N	PRESENT	0
513872	502364	07033P	PARTICIPANT	\N	PRESENT	0
513873	502364	19599P	PARTICIPANT	\N	PRESENT	0
513874	502364	99004R	PARTICIPANT	\N	PRESENT	0
513875	502364	04033B	PARTICIPANT	\N	PRESENT	0
513876	502364	14189C	PARTICIPANT	\N	PRESENT	0
513877	502364	19693L	PARTICIPANT	\N	PRESENT	0
513886	502364	01043Q	PARTICIPANT	\N	PRESENT	0
513835	502364	19719D	PARTICIPANT	\N	PRESENT	0
513836	502364	18083K	PARTICIPANT	\N	PRESENT	0
513887	502364	17367Q	PARTICIPANT	\N	PRESENT	0
513891	502364	19551W	PARTICIPANT	\N	PRESENT	0
513889	502364	19629C	PARTICIPANT	\N	PRESENT	0
513890	502364	20070A	PARTICIPANT	\N	PRESENT	0
513892	502364	19591F	PARTICIPANT	\N	PRESENT	0
513893	502364	19421M	PARTICIPANT	\N	PRESENT	0
513894	502364	01028R	PARTICIPANT	\N	PRESENT	0
513895	502364	04071H	PARTICIPANT	\N	PRESENT	0
513896	502364	20150Y	PARTICIPANT	\N	PRESENT	0
513897	502364	14331P	PARTICIPANT	\N	PRESENT	0
513898	502364	11026G	PARTICIPANT	\N	PRESENT	0
513900	502364	20026V	PARTICIPANT	\N	PRESENT	0
513901	502364	19782L	PARTICIPANT	\N	PRESENT	0
513902	502364	19647E	PARTICIPANT	\N	PRESENT	0
513903	502364	04034C	PARTICIPANT	\N	PRESENT	0
513904	502364	19766L	PARTICIPANT	\N	PRESENT	0
513905	502364	19705W	PARTICIPANT	\N	PRESENT	0
513906	502364	19717B	PARTICIPANT	\N	PRESENT	0
513907	502364	12041X	PARTICIPANT	\N	PRESENT	0
513908	502364	20046A	PARTICIPANT	\N	PRESENT	0
513909	502364	14255U	PARTICIPANT	\N	PRESENT	0
513910	502364	14249W	PARTICIPANT	\N	PRESENT	0
513911	502364	08010L	PARTICIPANT	\N	PRESENT	0
513955	502365	19717B	PARTICIPANT	\N	PRESENT	0
513956	502365	20050V	PARTICIPANT	\N	PRESENT	0
513957	502365	11026G	PARTICIPANT	\N	PRESENT	0
513958	502365	20100N	PARTICIPANT	\N	PRESENT	0
513959	502365	19503N	PARTICIPANT	\N	PRESENT	0
513960	502365	19629C	PARTICIPANT	\N	PRESENT	0
513961	502365	19705W	PARTICIPANT	\N	PRESENT	0
513962	502365	18083K	PARTICIPANT	\N	PRESENT	0
513963	502365	14147R	PARTICIPANT	\N	PRESENT	0
513964	502365	20034V	PARTICIPANT	\N	PRESENT	0
513965	502365	14187A	PARTICIPANT	\N	PRESENT	0
513966	502365	11090Q	PARTICIPANT	\N	PRESENT	0
513967	502365	11048N	PARTICIPANT	\N	PRESENT	0
513968	502365	14255U	PARTICIPANT	\N	PRESENT	0
513969	502365	20026V	PARTICIPANT	\N	PRESENT	0
513970	502365	20046A	PARTICIPANT	\N	PRESENT	0
513971	502365	20022R	PARTICIPANT	\N	PRESENT	0
513972	502365	19711U	PARTICIPANT	\N	PRESENT	0
513973	513912	14327T	PARTICIPANT	\N	PRESENT	0
513974	513912	14331P	PARTICIPANT	\N	PRESENT	0
513975	513912	11048N	PARTICIPANT	\N	PRESENT	0
513976	513912	19647E	PARTICIPANT	\N	PRESENT	0
513977	513912	19711U	PARTICIPANT	\N	PRESENT	0
513978	513912	08034U	PARTICIPANT	\N	PRESENT	0
513979	513912	19687N	PARTICIPANT	\N	PRESENT	0
513980	513912	19689Q	PARTICIPANT	\N	PRESENT	0
513981	513912	12016W	PARTICIPANT	\N	PRESENT	0
513982	513912	20080C	PARTICIPANT	\N	PRESENT	0
513983	513912	08011M	PARTICIPANT	\N	PRESENT	0
513984	513912	11074Q	PARTICIPANT	\N	PRESENT	0
513985	513912	19671E	PARTICIPANT	\N	PRESENT	0
513986	513912	20150Y	PARTICIPANT	\N	PRESENT	0
513987	513912	04086Q	PARTICIPANT	\N	PRESENT	0
513988	513912	07029T	PARTICIPANT	\N	PRESENT	0
513989	513912	14083S	PARTICIPANT	\N	PRESENT	0
513990	513912	20070A	PARTICIPANT	\N	PRESENT	0
513991	513912	08010L	PARTICIPANT	\N	PRESENT	0
513992	513912	19741B	PARTICIPANT	\N	PRESENT	0
513993	513912	20022R	PARTICIPANT	\N	PRESENT	0
513994	513912	19762G	PARTICIPANT	\N	PRESENT	0
513953	502365	12041X	PARTICIPANT	\N	PRESENT	0
513954	513912	14225N	PRESIDENT	0	PRESENT	0
513995	513912	19531S	PARTICIPANT	\N	EXCUSE	0
513996	502365	04086Q	PARTICIPANT	\N	PRESENT	0
513997	502365	19671E	PARTICIPANT	\N	PRESENT	0
513998	502365	08011M	PARTICIPANT	\N	PRESENT	0
513999	502365	14215L	PARTICIPANT	\N	PRESENT	0
514000	502365	07029T	PARTICIPANT	\N	PRESENT	0
514001	502365	19741B	PARTICIPANT	\N	PRESENT	0
514002	502365	14083S	PARTICIPANT	\N	PRESENT	0
514003	502365	14327T	PARTICIPANT	\N	PRESENT	0
514004	502365	19782L	PARTICIPANT	\N	PRESENT	0
523366	521477	14026U	PARTICIPANT	\N	PRESENT	0
523367	521477	17779H	PARTICIPANT	\N	PRESENT	0
523368	521477	20060X	PARTICIPANT	\N	PRESENT	0
523369	521477	19713W	PARTICIPANT	\N	PRESENT	0
523370	521477	19479G	PARTICIPANT	\N	PRESENT	0
523371	521477	19569H	PARTICIPANT	\N	PRESENT	0
523372	521477	19826F	PARTICIPANT	\N	PRESENT	0
523373	521477	19611R	PARTICIPANT	\N	PRESENT	0
523374	521477	14195A	PARTICIPANT	\N	PRESENT	0
523375	521477	19717B	PARTICIPANT	\N	PRESENT	0
523376	521477	19553Y	PARTICIPANT	\N	PRESENT	0
523377	521477	20134Y	PARTICIPANT	\N	PRESENT	0
523378	521477	20100N	PARTICIPANT	\N	PRESENT	0
523379	521477	20110Q	PARTICIPANT	\N	PRESENT	0
523380	521477	19301E	PARTICIPANT	\N	PRESENT	0
523381	521477	20130U	PARTICIPANT	\N	PRESENT	0
523382	521477	11033F	PARTICIPANT	\N	PRESENT	0
523383	521477	19689Q	PARTICIPANT	\N	PRESENT	0
523384	521477	14021P	PARTICIPANT	\N	PRESENT	0
523385	521477	01028R	PARTICIPANT	\N	PRESENT	0
523386	521477	19489J	PARTICIPANT	\N	PRESENT	0
523387	521477	19649G	PARTICIPANT	\N	PRESENT	0
523388	521477	19333N	PARTICIPANT	\N	PRESENT	0
523389	521477	14151M	PARTICIPANT	\N	PRESENT	0
523390	521477	19599P	PARTICIPANT	\N	PRESENT	0
523391	521477	14109K	PARTICIPANT	\N	PRESENT	0
523392	521477	11067R	PARTICIPANT	\N	PRESENT	0
523393	521477	18193Q	PARTICIPANT	\N	PRESENT	0
523394	521477	19551W	PARTICIPANT	\N	PRESENT	0
523395	521477	20080C	PARTICIPANT	\N	PRESENT	0
523396	521477	20070A	PARTICIPANT	\N	PRESENT	0
523397	521477	19647E	PARTICIPANT	\N	PRESENT	0
523398	521477	10006L	PARTICIPANT	\N	PRESENT	0
523399	521477	19760E	PARTICIPANT	\N	PRESENT	0
523400	521477	19758L	PARTICIPANT	\N	PRESENT	0
523401	521477	20046A	PARTICIPANT	\N	PRESENT	0
523402	521477	19687N	PARTICIPANT	\N	PRESENT	0
523403	521477	19739H	PARTICIPANT	\N	PRESENT	0
523404	521477	14083S	PARTICIPANT	\N	PRESENT	0
523405	521477	19691J	PARTICIPANT	\N	PRESENT	0
523406	521477	01024M	PARTICIPANT	\N	PRESENT	0
523407	521477	19621T	PARTICIPANT	\N	PRESENT	0
523408	521477	14059S	PARTICIPANT	\N	PRESENT	0
523409	521477	14213J	PARTICIPANT	\N	PRESENT	0
523410	521477	19349W	PARTICIPANT	\N	PRESENT	0
523411	521477	19741B	PARTICIPANT	\N	PRESENT	0
523412	521477	19798U	PARTICIPANT	\N	PRESENT	0
523413	521477	14053L	PARTICIPANT	\N	PRESENT	0
523414	521477	07029T	PARTICIPANT	\N	PRESENT	0
523415	521477	19507S	PARTICIPANT	\N	PRESENT	0
523416	521477	19467C	PARTICIPANT	\N	PRESENT	0
523417	521477	20034V	PARTICIPANT	\N	PRESENT	0
523418	521477	14069U	PARTICIPANT	\N	PRESENT	0
523419	521477	20058E	PARTICIPANT	\N	PRESENT	0
523420	521477	14071N	PARTICIPANT	\N	PRESENT	0
523421	521477	19629C	PARTICIPANT	\N	PRESENT	0
523422	521477	11099A	PARTICIPANT	\N	PRESENT	0
523423	521477	97011G	PARTICIPANT	\N	PRESENT	0
523424	521477	20082E	PARTICIPANT	\N	PRESENT	0
523425	521477	19631V	PARTICIPANT	\N	PRESENT	0
523426	521477	20114U	PARTICIPANT	\N	PRESENT	0
523427	521477	14229S	PARTICIPANT	\N	PRESENT	0
523428	521477	14225N	PARTICIPANT	\N	PRESENT	0
523429	521477	17965H	PARTICIPANT	\N	PRESENT	0
523430	521477	19503N	PARTICIPANT	\N	PRESENT	0
523431	521477	19533U	PARTICIPANT	\N	PRESENT	0
523549	521237	20116W	PARTICIPANT	\N	PRESENT	0
523550	521237	14225N	PRESIDENT	0	PRESENT	0
523551	521237	01048V	PARTICIPANT	\N	EXCUSE	0
523552	521237	14327T	PARTICIPANT	\N	PRESENT	0
523553	521237	04086Q	PARTICIPANT	\N	PRESENT	0
523554	521237	11048N	PARTICIPANT	\N	PRESENT	0
523555	521237	19711U	PARTICIPANT	\N	PRESENT	0
523556	521237	01057W	PARTICIPANT	\N	PRESENT	0
523557	521237	20080C	PARTICIPANT	\N	PRESENT	0
523558	521237	99004R	PARTICIPANT	\N	PRESENT	0
523560	521237	20022R	PARTICIPANT	\N	PRESENT	0
523561	521237	07029T	PARTICIPANT	\N	EXCUSE	0
523564	521237	19479G	PARTICIPANT	\N	PRESENT	0
523570	521237	19349W	PARTICIPANT	\N	PRESENT	0
523571	521237	20126Y	PARTICIPANT	\N	PRESENT	0
523572	521237	19689Q	PARTICIPANT	\N	PRESENT	0
523573	521237	19647E	PARTICIPANT	\N	PRESENT	0
523574	521237	19687N	PARTICIPANT	\N	PRESENT	0
523575	521237	04071H	PARTICIPANT	\N	PRESENT	0
523576	521237	14189C	PARTICIPANT	\N	PRESENT	0
523577	521479	11070L	PARTICIPANT	\N	PRESENT	0
523578	521479	12028B	PARTICIPANT	\N	PRESENT	0
523579	521479	19649G	PARTICIPANT	\N	PRESENT	0
523580	521479	20050V	PARTICIPANT	\N	PRESENT	0
523581	521479	19629C	PARTICIPANT	\N	PRESENT	0
523582	521479	19387D	PARTICIPANT	\N	PRESENT	0
523583	521479	14021P	PARTICIPANT	\N	PRESENT	0
523584	521479	04085P	PARTICIPANT	\N	PRESENT	0
523585	521479	14030Q	PARTICIPANT	\N	PRESENT	0
523586	521479	11085T	PARTICIPANT	\N	PRESENT	0
523587	521479	14089Y	PARTICIPANT	\N	PRESENT	0
523617	521479	01024M	PARTICIPANT	\N	PRESENT	0
523589	521479	19749K	PARTICIPANT	\N	PRESENT	0
523590	521479	14147R	PARTICIPANT	\N	PRESENT	0
523591	521479	14215L	PARTICIPANT	\N	PRESENT	0
523592	521479	17737W	PARTICIPANT	\N	PRESENT	0
523593	521479	11033F	PARTICIPANT	\N	PRESENT	0
523594	521479	18083K	PARTICIPANT	\N	PRESENT	0
523595	521479	14069U	PARTICIPANT	\N	PRESENT	0
523596	521479	14031R	PARTICIPANT	\N	PRESENT	0
523597	521479	08069G	PARTICIPANT	\N	PRESENT	0
523598	521479	19643A	PARTICIPANT	\N	PRESENT	0
523599	521479	14071N	PARTICIPANT	\N	PRESENT	0
523600	521479	11031D	PARTICIPANT	\N	PRESENT	0
523601	521479	19758L	PARTICIPANT	\N	PRESENT	0
523602	521479	17965H	PARTICIPANT	\N	PRESENT	0
523603	521479	20132W	PARTICIPANT	\N	PRESENT	0
523605	521479	11056N	PARTICIPANT	\N	PRESENT	0
523606	521479	19826F	PARTICIPANT	\N	PRESENT	0
523607	521479	19415P	PARTICIPANT	\N	PRESENT	0
523608	521479	19621T	PARTICIPANT	\N	PRESENT	0
523609	521479	20052X	PARTICIPANT	\N	PRESENT	0
523610	521479	19591F	PARTICIPANT	\N	PRESENT	0
523611	521479	14151M	PARTICIPANT	\N	PRESENT	0
523612	521479	08045X	PARTICIPANT	\N	PRESENT	0
523613	521479	14109K	PARTICIPANT	\N	PRESENT	0
523614	521479	11067R	PARTICIPANT	\N	PRESENT	0
523615	521479	19333N	PARTICIPANT	\N	PRESENT	0
523616	521479	14255U	PARTICIPANT	\N	PRESENT	0
523618	521479	19619A	PARTICIPANT	\N	PRESENT	0
523619	521479	20066E	PARTICIPANT	\N	PRESENT	0
523620	521479	19699S	PARTICIPANT	\N	PRESENT	0
523621	521479	14073Q	PARTICIPANT	\N	PRESENT	0
523622	521479	19745F	PARTICIPANT	\N	PRESENT	0
523623	521479	20124W	PARTICIPANT	\N	PRESENT	0
523624	521479	20142Y	PARTICIPANT	\N	PRESENT	0
523625	521479	20130U	PARTICIPANT	\N	PRESENT	0
523626	521479	19611R	PARTICIPANT	\N	PRESENT	0
523627	521479	19739H	PARTICIPANT	\N	PRESENT	0
523628	521479	17229F	PARTICIPANT	\N	PRESENT	0
523629	521479	20138D	PARTICIPANT	\N	PRESENT	0
523630	521479	19735D	PARTICIPANT	\N	PRESENT	0
523631	521479	14055N	PARTICIPANT	\N	PRESENT	0
523632	521479	14251Q	PARTICIPANT	\N	PRESENT	0
523633	521479	18193Q	PARTICIPANT	\N	PRESENT	0
523634	521479	20022R	PARTICIPANT	\N	PRESENT	0
523635	521479	19503N	PARTICIPANT	\N	PRESENT	0
523636	521479	17779H	PARTICIPANT	\N	PRESENT	0
523637	521479	20106U	PARTICIPANT	\N	PRESENT	0
523638	521479	19782L	PARTICIPANT	\N	PRESENT	0
523639	521479	20048C	PARTICIPANT	\N	PRESENT	0
523640	521479	20126Y	PARTICIPANT	\N	PRESENT	0
523642	521479	01057W	PARTICIPANT	\N	PRESENT	0
523649	521479	20114U	PARTICIPANT	\N	PRESENT	0
523650	521479	14189C	PARTICIPANT	\N	PRESENT	0
523651	521479	20080C	PARTICIPANT	\N	PRESENT	0
523652	521479	19533U	PARTICIPANT	\N	PRESENT	0
523653	521479	19467C	PARTICIPANT	\N	PRESENT	0
523654	521479	20038A	PARTICIPANT	\N	PRESENT	0
523655	521479	01028R	PARTICIPANT	\N	PRESENT	0
523656	521479	20116W	PARTICIPANT	\N	PRESENT	0
523657	521479	97011G	PARTICIPANT	\N	PRESENT	0
523658	521479	11045K	PARTICIPANT	\N	PRESENT	0
523659	521479	11053K	PARTICIPANT	\N	PRESENT	0
523660	521479	19543W	PARTICIPANT	\N	PRESENT	0
516523	516058	20022R	PARTICIPANT	\N	EXCUSE	0
519253	518915	05008E	PARTICIPANT	\N	EXCUSE	0
519255	519254	20052X	PARTICIPANT	\N	PRESENT	1
519256	519254	14109K	PARTICIPANT	\N	PRESENT	1
519257	519254	20124W	PARTICIPANT	\N	PRESENT	1
519258	519254	20058E	PARTICIPANT	\N	PRESENT	1
519259	519254	20132W	PARTICIPANT	\N	PRESENT	1
519261	519260	20052X	PARTICIPANT	\N	PRESENT	1
519262	519260	14109K	PARTICIPANT	\N	PRESENT	1
519263	519260	20124W	PARTICIPANT	\N	PRESENT	1
519265	519264	20052X	PARTICIPANT	\N	PRESENT	1
519266	519264	14109K	PARTICIPANT	\N	PRESENT	1
519267	519264	20124W	PARTICIPANT	\N	PRESENT	1
526655	526654	14083S	PARTICIPANT	\N	PRESENT	0
526651	526649	14133K	PARTICIPANT	\N	PRESENT	0
526652	526649	11012A	PARTICIPANT	\N	PRESENT	0
526656	526654	19721W	PARTICIPANT	\N	PRESENT	0
526657	526654	20144B	PARTICIPANT	\N	PRESENT	0
526658	526654	14357A	PARTICIPANT	\N	PRESENT	0
526659	526654	01024M	PARTICIPANT	\N	PRESENT	0
526660	526654	20040T	PARTICIPANT	\N	PRESENT	0
526661	526654	20174H	PARTICIPANT	\N	PRESENT	0
526662	526654	20038A	PARTICIPANT	\N	PRESENT	0
526663	526654	14033T	PARTICIPANT	\N	PRESENT	0
526664	526654	19333N	PARTICIPANT	\N	PRESENT	0
526665	526654	19551W	PARTICIPANT	\N	PRESENT	0
526666	526654	20126Y	PARTICIPANT	\N	PRESENT	0
526667	526654	19711U	PARTICIPANT	\N	PRESENT	0
526668	526654	14031R	PARTICIPANT	\N	PRESENT	0
526669	526654	14257W	PARTICIPANT	\N	PRESENT	0
526670	526654	14071N	PARTICIPANT	\N	PRESENT	0
526671	526654	92040Q	PARTICIPANT	\N	PRESENT	0
526672	526654	19503N	PARTICIPANT	\N	PRESENT	0
526673	526654	11012A	PARTICIPANT	\N	PRESENT	0
526674	526654	19619A	PARTICIPANT	\N	PRESENT	0
526675	526654	20092G	PARTICIPANT	\N	PRESENT	0
526701	526691	14033T	PARTICIPANT	\N	PRESENT	0
526706	526692	14033T	PARTICIPANT	\N	PRESENT	0
526704	526703	14033T	PARTICIPANT	\N	PRESENT	0
526705	526703	20034V	PARTICIPANT	\N	PRESENT	0
526707	526693	14033T	PARTICIPANT	\N	PRESENT	0
526708	526693	20062A	PARTICIPANT	\N	PRESENT	0
526710	526709	14033T	PARTICIPANT	\N	PRESENT	0
526711	526709	20062A	PARTICIPANT	\N	PRESENT	0
526712	526694	14033T	PARTICIPANT	\N	PRESENT	0
526713	526694	20062A	PARTICIPANT	\N	PRESENT	0
526714	526695	14033T	PARTICIPANT	\N	PRESENT	0
526715	526695	20062A	PARTICIPANT	\N	PRESENT	0
526718	526698	14033T	PARTICIPANT	\N	PRESENT	0
526719	526698	14205J	PARTICIPANT	\N	PRESENT	0
526720	526699	14033T	PARTICIPANT	\N	PRESENT	0
526721	526699	14205J	PARTICIPANT	\N	PRESENT	0
526722	526700	14033T	PARTICIPANT	\N	PRESENT	0
526723	526700	14205J	PARTICIPANT	\N	PRESENT	0
529048	528835	20094J	PARTICIPANT	\N	PRESENT	0
529049	528835	04070G	PARTICIPANT	\N	PRESENT	0
529050	528837	20094J	PARTICIPANT	\N	PRESENT	0
529051	528837	04070G	PARTICIPANT	\N	PRESENT	0
529052	528843	20094J	PARTICIPANT	\N	PRESENT	0
529053	528843	04070G	PARTICIPANT	\N	PRESENT	0
529055	529054	20112S	PARTICIPANT	\N	PRESENT	0
531351	531329	19679N	PARTICIPANT	\N	PRESENT	0
531354	531352	19683J	PARTICIPANT	\N	PRESENT	0
531355	531352	19723Y	PARTICIPANT	\N	PRESENT	0
531356	531353	19683J	PARTICIPANT	\N	PRESENT	0
531357	531353	19723Y	PARTICIPANT	\N	PRESENT	0
533493	530831	11083R	PARTICIPANT	\N	PRESENT	0
533494	530831	14123H	PARTICIPANT	\N	PRESENT	0
533495	530831	11104D	PARTICIPANT	\N	PRESENT	0
533496	530831	19749K	PARTICIPANT	\N	PRESENT	0
533497	530831	19758L	PARTICIPANT	\N	PRESENT	0
533498	530831	20084G	PARTICIPANT	\N	PRESENT	0
533499	530831	19621T	PARTICIPANT	\N	PRESENT	0
533500	530831	19735D	PARTICIPANT	\N	EXCUSE	0
533501	529296	11077T	PARTICIPANT	\N	PRESENT	1
533502	529296	20030R	PARTICIPANT	\N	PRESENT	1
533503	531319	19649G	PARTICIPANT	\N	PRESENT	1
533504	531319	14001X	PARTICIPANT	\N	PRESENT	1
533505	529296	19521Q	PARTICIPANT	\N	PRESENT	1
533506	531319	20152B	PARTICIPANT	\N	PRESENT	1
533507	531319	19693L	PARTICIPANT	\N	PRESENT	1
533508	531319	20134Y	PARTICIPANT	\N	PRESENT	1
533509	529296	19768N	PARTICIPANT	\N	PRESENT	1
533510	531371	19691J	PARTICIPANT	\N	PRESENT	0
533511	529296	20094J	PARTICIPANT	\N	PRESENT	1
533512	529296	19369B	PARTICIPANT	\N	PRESENT	1
533513	529296	20174H	PARTICIPANT	\N	PRESENT	1
533514	531371	19569H	PARTICIPANT	\N	PRESENT	0
533515	529296	14207L	PARTICIPANT	\N	PRESENT	1
533516	531371	97011G	PARTICIPANT	\N	PRESENT	0
533517	529296	14251Q	PARTICIPANT	\N	PRESENT	1
533518	529296	19467C	PARTICIPANT	\N	PRESENT	1
533519	529296	14038Y	PARTICIPANT	\N	PRESENT	0
533520	529296	20060X	PARTICIPANT	\N	PRESENT	1
533521	529296	11099A	PARTICIPANT	\N	PRESENT	1
533522	529296	19563B	PARTICIPANT	\N	PRESENT	1
533523	529296	14187A	PARTICIPANT	\N	PRESENT	1
533524	529296	04045F	PARTICIPANT	\N	PRESENT	1
533525	529296	19705W	PARTICIPANT	\N	PRESENT	1
533526	529296	19515S	PARTICIPANT	\N	PRESENT	1
533527	531371	20022R	PARTICIPANT	\N	PRESENT	0
533528	531371	19399H	PARTICIPANT	\N	PRESENT	0
533529	531371	19443T	PARTICIPANT	\N	PRESENT	0
533530	531371	19599P	PARTICIPANT	\N	PRESENT	0
533531	531371	11067R	PARTICIPANT	\N	PRESENT	0
533532	531371	20126Y	PARTICIPANT	\N	PRESENT	0
533533	531371	14331P	PARTICIPANT	\N	PRESENT	0
533534	531320	14179A	PARTICIPANT	\N	PRESENT	0
533535	531371	14215L	PARTICIPANT	\N	PRESENT	0
533536	531371	20052X	PARTICIPANT	\N	PRESENT	0
533537	531371	20132W	PARTICIPANT	\N	PRESENT	0
533538	531371	19507S	PARTICIPANT	\N	PRESENT	0
533539	531371	14030Q	PARTICIPANT	\N	PRESENT	0
533540	531371	20026V	PARTICIPANT	\N	PRESENT	0
533543	533542	19637C	PARTICIPANT	\N	PRESENT	0
533544	533542	14033T	PARTICIPANT	\N	PRESENT	0
533910	531196	14331P	PRESIDENT	0	PRESENT	0
533911	531196	14073Q	PARTICIPANT	\N	PRESENT	0
533912	531196	11083R	PARTICIPANT	\N	PRESENT	0
533913	531196	20128B	PARTICIPANT	\N	PRESENT	0
533914	531196	19441R	PARTICIPANT	\N	PRESENT	0
533915	531196	20100N	PARTICIPANT	\N	PRESENT	0
533916	531196	19711U	PARTICIPANT	\N	PRESENT	0
533917	531196	19563B	PARTICIPANT	\N	PRESENT	0
533918	531196	11101A	PARTICIPANT	\N	PRESENT	1
533919	531196	14097Y	PARTICIPANT	\N	PRESENT	1
533920	531196	14237S	PARTICIPANT	\N	PRESENT	1
533921	531196	20098N	PARTICIPANT	\N	PRESENT	1
533924	531196	04092N	PARTICIPANT	\N	PRESENT	0
533923	531196	19251M	PARTICIPANT	\N	EXCUSE	0
533925	531196	20126Y	PARTICIPANT	\N	PRESENT	0
534051	534050	20086J	PARTICIPANT	\N	PRESENT	0
534052	534050	14207L	PARTICIPANT	\N	PRESENT	0
534053	534050	20018V	PARTICIPANT	\N	PRESENT	0
534054	534050	14257W	PARTICIPANT	\N	PRESENT	0
534055	534050	20082E	PARTICIPANT	\N	PRESENT	0
534056	534050	20092G	PARTICIPANT	\N	PRESENT	0
534057	534050	20062A	PARTICIPANT	\N	PRESENT	0
534059	534058	20086J	PARTICIPANT	\N	PRESENT	0
534060	534058	14207L	PARTICIPANT	\N	PRESENT	0
534061	534058	01043Q	PARTICIPANT	\N	PRESENT	0
534062	534058	14205J	PARTICIPANT	\N	PRESENT	0
534064	534058	20018V	PARTICIPANT	\N	PRESENT	0
534065	534058	14257W	PARTICIPANT	\N	PRESENT	0
534066	534058	20082E	PARTICIPANT	\N	PRESENT	0
534067	534058	20062A	PARTICIPANT	\N	PRESENT	0
534206	534205	11040E	PARTICIPANT	\N	PRESENT	0
534207	534205	14255U	PARTICIPANT	\N	PRESENT	0
534208	534205	19521Q	PARTICIPANT	\N	PRESENT	0
534209	534205	19735D	PARTICIPANT	\N	PRESENT	0
534210	534205	01043Q	PARTICIPANT	\N	PRESENT	0
534211	534205	04057K	PARTICIPANT	\N	PRESENT	0
534212	534205	14147R	PARTICIPANT	\N	PRESENT	0
534213	534205	14109K	PARTICIPANT	\N	PRESENT	0
534214	534205	14331P	PARTICIPANT	\N	PRESENT	0
534215	534205	20026V	PARTICIPANT	\N	PRESENT	0
534216	534205	19643A	PARTICIPANT	\N	PRESENT	0
534220	534219	05008E	PARTICIPANT	\N	PRESENT	0
527885	526540	20128B	PARTICIPANT	\N	PRESENT	0
527886	526540	17637T	PARTICIPANT	\N	PRESENT	0
527887	526540	08017T	PARTICIPANT	\N	PRESENT	0
527888	526540	19701S	PARTICIPANT	\N	PRESENT	0
527889	526540	20092G	PARTICIPANT	\N	PRESENT	0
527890	526540	10006L	PARTICIPANT	\N	PRESENT	0
527891	526540	19553Y	PARTICIPANT	\N	PRESENT	0
527892	526540	04033B	PARTICIPANT	\N	PRESENT	0
527893	526540	08028W	PARTICIPANT	\N	PRESENT	0
527894	526540	05008E	PARTICIPANT	\N	PRESENT	0
527895	526540	19441R	PARTICIPANT	\N	PRESENT	0
527896	526540	14071N	PARTICIPANT	\N	PRESENT	0
527897	526540	19671E	PARTICIPANT	\N	PRESENT	0
527898	526540	11045K	PARTICIPANT	\N	PRESENT	0
527899	526540	19347U	PARTICIPANT	\N	PRESENT	0
527900	526540	04086Q	PARTICIPANT	\N	PRESENT	0
527901	526540	19747H	PARTICIPANT	\N	PRESENT	0
527902	526540	14219Q	PARTICIPANT	\N	PRESENT	0
527903	526540	14083S	PARTICIPANT	\N	PRESENT	0
527904	526540	11070L	PARTICIPANT	\N	PRESENT	0
527905	526540	14030Q	PARTICIPANT	\N	PRESENT	0
527911	526540	19954N	PARTICIPANT	\N	PRESENT	0
527907	526540	01048V	PARTICIPANT	\N	PRESENT	0
527908	526540	17367Q	PARTICIPANT	\N	PRESENT	0
527909	526540	04085P	PARTICIPANT	\N	PRESENT	0
527910	526540	20040T	PARTICIPANT	\N	PRESENT	0
527912	526540	14042U	PARTICIPANT	\N	PRESENT	0
527913	526540	19479G	PARTICIPANT	\N	PRESENT	0
527914	526540	11080N	PARTICIPANT	\N	PRESENT	0
527915	526540	11053K	PARTICIPANT	\N	PRESENT	0
527916	526540	08047A	PARTICIPANT	\N	PRESENT	0
527917	526540	14213J	PARTICIPANT	\N	PRESENT	0
527918	526540	14111D	PARTICIPANT	\N	PRESENT	0
527919	526540	20076G	PARTICIPANT	\N	PRESENT	0
527920	526540	19768N	PARTICIPANT	\N	PRESENT	0
527921	526540	20118Y	PARTICIPANT	\N	PRESENT	0
527922	526540	19533U	PARTICIPANT	\N	PRESENT	0
527924	526540	11085T	PARTICIPANT	\N	PRESENT	0
527977	526540	19569H	PARTICIPANT	\N	PRESENT	0
527951	526540	14133K	PARTICIPANT	\N	PRESENT	0
527961	526540	11097X	PARTICIPANT	\N	PRESENT	0
528006	526540	20058E	PARTICIPANT	\N	PRESENT	0
528008	526540	19717B	PARTICIPANT	\N	PRESENT	0
528016	526540	20048C	PARTICIPANT	\N	PRESENT	0
528011	526540	11043H	PARTICIPANT	\N	PRESENT	0
528012	526540	14169X	PARTICIPANT	\N	PRESENT	0
528014	526540	20136B	PARTICIPANT	\N	PRESENT	0
528015	526540	08018U	PARTICIPANT	\N	PRESENT	0
528017	526540	11065P	PARTICIPANT	\N	PRESENT	0
528018	526540	20100N	PARTICIPANT	\N	PRESENT	0
528019	526540	86034E	PARTICIPANT	\N	PRESENT	0
528020	526540	11012A	PARTICIPANT	\N	PRESENT	0
528021	526540	14089Y	PARTICIPANT	\N	PRESENT	0
528022	526540	04042C	PARTICIPANT	\N	PRESENT	0
528023	526540	20034V	PARTICIPANT	\N	PRESENT	0
528257	526541	99004R	PARTICIPANT	\N	PRESENT	0
528028	526540	14059S	PARTICIPANT	\N	PRESENT	0
528258	526541	11031D	PARTICIPANT	\N	PRESENT	0
528259	526541	19649G	PARTICIPANT	\N	PRESENT	0
528260	526541	14021P	PARTICIPANT	\N	PRESENT	0
528261	526541	19683J	PARTICIPANT	\N	PRESENT	0
528262	526541	11012A	PARTICIPANT	\N	PRESENT	0
528263	526541	19387D	PARTICIPANT	\N	PRESENT	0
528264	526541	19719D	PARTICIPANT	\N	PRESENT	0
528265	526541	14195A	PARTICIPANT	\N	PRESENT	0
528266	526541	17589D	PARTICIPANT	\N	PRESENT	0
528267	526541	19479G	PARTICIPANT	\N	PRESENT	0
528268	526541	19447X	PARTICIPANT	\N	PRESENT	0
528269	526541	14042U	PARTICIPANT	\N	PRESENT	0
528270	526541	19713W	PARTICIPANT	\N	PRESENT	0
528271	526541	20070A	PARTICIPANT	\N	PRESENT	0
528272	526541	19333N	PARTICIPANT	\N	PRESENT	0
528273	526541	19549D	PARTICIPANT	\N	PRESENT	0
528274	526541	11026G	PARTICIPANT	\N	PRESENT	0
528275	526541	08017T	PARTICIPANT	\N	PRESENT	0
528276	526541	19820Y	PARTICIPANT	\N	PRESENT	0
528277	526541	20092G	PARTICIPANT	\N	PRESENT	0
528278	526541	11033F	PARTICIPANT	\N	PRESENT	0
528279	526541	04034C	PARTICIPANT	\N	PRESENT	0
528280	526541	20142Y	PARTICIPANT	\N	PRESENT	0
528281	526541	17779H	PARTICIPANT	\N	PRESENT	0
528282	526541	19553Y	PARTICIPANT	\N	PRESENT	0
528283	526541	19593H	PARTICIPANT	\N	PRESENT	0
528284	526541	19715Y	PARTICIPANT	\N	PRESENT	0
528285	526541	11045K	PARTICIPANT	\N	PRESENT	0
528286	526541	10015M	PARTICIPANT	\N	PRESENT	0
528287	526541	20110Q	PARTICIPANT	\N	PRESENT	0
528288	526541	04057K	PARTICIPANT	\N	PRESENT	0
528289	526541	04045F	PARTICIPANT	\N	PRESENT	0
528290	526541	19569H	PARTICIPANT	\N	PRESENT	0
528291	526541	08034U	PARTICIPANT	\N	PRESENT	0
528292	526541	14225N	PARTICIPANT	\N	PRESENT	0
528293	526541	04033B	PARTICIPANT	\N	PRESENT	0
528294	526541	14179A	PARTICIPANT	\N	PRESENT	0
528295	526541	10006L	PARTICIPANT	\N	PRESENT	0
528296	526541	20066E	PARTICIPANT	\N	PRESENT	0
528297	526541	11097X	PARTICIPANT	\N	PRESENT	0
528298	526541	14030Q	PARTICIPANT	\N	PRESENT	0
528299	526541	19826F	PARTICIPANT	\N	PRESENT	0
528300	526541	01048V	PARTICIPANT	\N	PRESENT	0
528301	526541	14055N	PARTICIPANT	\N	PRESENT	0
528302	526541	19575F	PARTICIPANT	\N	PRESENT	0
528303	526541	19671E	PARTICIPANT	\N	PRESENT	0
528304	526541	19798U	PARTICIPANT	\N	PRESENT	0
528305	526541	19711U	PARTICIPANT	\N	PRESENT	0
528306	526541	19515S	PARTICIPANT	\N	PRESENT	0
528307	526541	18083K	PARTICIPANT	\N	PRESENT	0
528308	526541	97011G	PARTICIPANT	\N	PRESENT	0
528309	526541	14213J	PARTICIPANT	\N	PRESENT	0
528310	526541	14059S	PARTICIPANT	\N	PRESENT	0
528311	526541	20090E	PARTICIPANT	\N	PRESENT	0
528312	526541	20054A	PARTICIPANT	\N	PRESENT	0
528313	526541	11053K	PARTICIPANT	\N	PRESENT	0
528314	526541	11066Q	PARTICIPANT	\N	PRESENT	0
528315	526541	19347U	PARTICIPANT	\N	PRESENT	0
528316	526541	14147R	PARTICIPANT	\N	PRESENT	0
528317	526541	19415P	PARTICIPANT	\N	PRESENT	0
528318	526541	20056C	PARTICIPANT	\N	PRESENT	0
528319	526541	20180F	PARTICIPANT	\N	PRESENT	0
528320	526541	20034V	PARTICIPANT	\N	PRESENT	0
528321	526541	14033T	PARTICIPANT	\N	PRESENT	0
528322	526541	20116W	PARTICIPANT	\N	PRESENT	0
528323	526541	19651A	PARTICIPANT	\N	PRESENT	0
528324	526541	01058X	PARTICIPANT	\N	PRESENT	0
528325	526541	19399H	PARTICIPANT	\N	PRESENT	0
528326	526541	20138D	PARTICIPANT	\N	PRESENT	0
528327	526541	20172F	PARTICIPANT	\N	PRESENT	0
528328	526541	20026V	PARTICIPANT	\N	PRESENT	0
528329	526541	20140W	PARTICIPANT	\N	PRESENT	0
528330	526541	14041T	PARTICIPANT	\N	PRESENT	0
528331	526541	20044X	PARTICIPANT	\N	PRESENT	0
528332	526541	19335Q	PARTICIPANT	\N	PRESENT	0
528333	526541	20042V	PARTICIPANT	\N	PRESENT	0
528334	526541	20038A	PARTICIPANT	\N	PRESENT	0
528335	526541	14038Y	PARTICIPANT	\N	PRESENT	0
528336	526541	19741B	PARTICIPANT	\N	PRESENT	0
528337	526541	20058E	PARTICIPANT	\N	PRESENT	0
528338	526541	14169X	PARTICIPANT	\N	PRESENT	0
528339	526541	19697Q	PARTICIPANT	\N	PRESENT	0
528340	526541	01024M	PARTICIPANT	\N	PRESENT	0
528341	526541	20132W	PARTICIPANT	\N	PRESENT	0
528342	526541	05008E	PARTICIPANT	\N	PRESENT	0
528343	526541	14073Q	PARTICIPANT	\N	PRESENT	0
528344	526541	14089Y	PARTICIPANT	\N	PRESENT	0
528345	526541	04043D	PARTICIPANT	\N	PRESENT	0
528346	526541	14329V	PARTICIPANT	\N	PRESENT	0
528347	526541	19631V	PARTICIPANT	\N	PRESENT	0
528348	526541	20114U	PARTICIPANT	\N	PRESENT	0
528349	526541	04092N	PARTICIPANT	\N	PRESENT	0
528350	526541	14133K	PARTICIPANT	\N	PRESENT	0
528351	526541	20126Y	PARTICIPANT	\N	PRESENT	0
528352	526541	08061X	PARTICIPANT	\N	PRESENT	0
528353	526541	11048N	PARTICIPANT	\N	PRESENT	0
528354	526541	14053L	PARTICIPANT	\N	PRESENT	0
528355	526541	14249W	PARTICIPANT	\N	PRESENT	0
528356	526541	19599P	PARTICIPANT	\N	PRESENT	0
528357	526541	19573D	PARTICIPANT	\N	PRESENT	0
528358	526541	04047H	PARTICIPANT	\N	PRESENT	0
528359	526541	20018V	PARTICIPANT	\N	PRESENT	0
528360	526541	14189C	PARTICIPANT	\N	PRESENT	0
528361	526541	19768N	PARTICIPANT	\N	PRESENT	0
514005	502365	20150Y	PARTICIPANT	\N	PRESENT	0
514006	502365	11074Q	PARTICIPANT	\N	PRESENT	0
514007	502365	11056N	PARTICIPANT	\N	PRESENT	0
514008	502365	14030Q	PARTICIPANT	\N	PRESENT	0
514009	502365	19762G	PARTICIPANT	\N	PRESENT	0
514010	502365	19687N	PARTICIPANT	\N	PRESENT	0
514011	502365	20080C	PARTICIPANT	\N	PRESENT	0
514012	502365	12016W	PARTICIPANT	\N	PRESENT	0
514013	502365	19621T	PARTICIPANT	\N	PRESENT	0
514014	502365	19723Y	PARTICIPANT	\N	PRESENT	0
514015	502365	14225N	PARTICIPANT	\N	PRESENT	0
514016	502365	20070A	PARTICIPANT	\N	PRESENT	0
514017	502365	08010L	PARTICIPANT	\N	PRESENT	0
514018	502365	19551W	PARTICIPANT	\N	PRESENT	0
514019	502365	19447X	PARTICIPANT	\N	PRESENT	0
514020	502365	19647E	PARTICIPANT	\N	PRESENT	0
514021	502365	14021P	PARTICIPANT	\N	PRESENT	0
514022	502365	17367Q	PARTICIPANT	\N	PRESENT	0
514023	502365	14219Q	PARTICIPANT	\N	PRESENT	0
514024	502365	20106U	PARTICIPANT	\N	PRESENT	0
514025	502365	08034U	PARTICIPANT	\N	PRESENT	0
514026	502365	04033B	PARTICIPANT	\N	PRESENT	0
514027	502365	19689Q	PARTICIPANT	\N	PRESENT	0
514028	502365	01057W	PARTICIPANT	\N	PRESENT	0
514029	502365	20136B	PARTICIPANT	\N	PRESENT	0
515113	515112	20104S	PARTICIPANT	\N	PRESENT	0
515114	515112	19820Y	PARTICIPANT	\N	PRESENT	0
515115	515112	20038A	PARTICIPANT	\N	PRESENT	0
515116	515112	19521Q	PARTICIPANT	\N	PRESENT	0
515118	515112	20094J	PARTICIPANT	\N	PRESENT	0
515119	515112	19745F	PARTICIPANT	\N	PRESENT	0
515122	515121	20104S	PARTICIPANT	\N	PRESENT	0
515123	515121	19820Y	PARTICIPANT	\N	PRESENT	0
515124	515121	20038A	PARTICIPANT	\N	PRESENT	0
515125	515121	20094J	PARTICIPANT	\N	PRESENT	0
515126	515121	19745F	PARTICIPANT	\N	PRESENT	0
515127	515121	19521Q	PARTICIPANT	\N	PRESENT	0
518566	518565	19631V	PARTICIPANT	\N	PRESENT	0
518567	518565	20116W	PARTICIPANT	\N	PRESENT	0
518568	518565	20088L	PARTICIPANT	\N	PRESENT	0
518570	518565	20090E	PARTICIPANT	\N	PRESENT	0
518571	518565	14083S	PARTICIPANT	\N	PRESENT	0
518573	518565	01057W	PARTICIPANT	\N	PRESENT	0
518574	518565	20106U	PARTICIPANT	\N	PRESENT	0
518575	518565	11067R	PARTICIPANT	\N	PRESENT	0
518576	518565	19745F	PARTICIPANT	\N	PRESENT	0
518577	518565	20018V	PARTICIPANT	\N	PRESENT	0
518578	518565	14069U	PARTICIPANT	\N	PRESENT	0
518675	518674	14231L	PRESIDENT	0	PRESENT	0
518691	518687	19683J	PARTICIPANT	\N	PRESENT	0
518692	518687	19723Y	PARTICIPANT	\N	PRESENT	0
518693	518688	19591F	PARTICIPANT	\N	PRESENT	0
518694	518688	17965H	PARTICIPANT	\N	PRESENT	0
518695	518688	11045K	PARTICIPANT	\N	PRESENT	0
518696	518689	19591F	PARTICIPANT	\N	PRESENT	0
518697	518689	11045K	PARTICIPANT	\N	PRESENT	0
518698	518689	17965H	PARTICIPANT	\N	PRESENT	0
518716	518690	20130U	PARTICIPANT	\N	PRESENT	0
518732	518731	19683J	PARTICIPANT	\N	PRESENT	0
518714	518690	11045K	PARTICIPANT	\N	PRESENT	0
518733	518731	19723Y	PARTICIPANT	\N	PRESENT	0
519762	519210	20040T	PARTICIPANT	\N	PRESENT	0
518735	518731	20130U	PARTICIPANT	\N	PRESENT	0
518759	518758	19593H	PARTICIPANT	\N	PRESENT	0
519754	519210	19663E	PARTICIPANT	\N	PRESENT	0
520009	519212	19697Q	PARTICIPANT	\N	PRESENT	1
520010	519212	11067R	PARTICIPANT	\N	PRESENT	0
520011	519212	19798U	PARTICIPANT	\N	PRESENT	0
520012	519212	19569H	PARTICIPANT	\N	PRESENT	1
520013	519212	11097X	PARTICIPANT	\N	PRESENT	0
520014	519212	14223L	PARTICIPANT	\N	PRESENT	1
520015	519212	14026U	PARTICIPANT	\N	PRESENT	0
520016	519212	17779H	PARTICIPANT	\N	PRESENT	0
520017	519212	19703U	PARTICIPANT	\N	PRESENT	0
520018	519212	19553Y	PARTICIPANT	\N	PRESENT	1
520019	519212	19679N	PARTICIPANT	\N	PRESENT	0
520020	519212	14042U	PARTICIPANT	\N	PRESENT	0
520021	519212	14195A	PARTICIPANT	\N	PRESENT	0
520022	519212	19367Y	PARTICIPANT	\N	PRESENT	0
520023	519212	14213J	PARTICIPANT	\N	PRESENT	0
520024	519212	14217N	PARTICIPANT	\N	PRESENT	0
520025	519212	19683J	PARTICIPANT	\N	PRESENT	0
520026	519212	19591F	PARTICIPANT	\N	PRESENT	0
520027	519212	20130U	PARTICIPANT	\N	PRESENT	0
520028	519212	04057K	PARTICIPANT	\N	PRESENT	1
520029	519212	04092N	PARTICIPANT	0	PRESENT	0
520030	519212	11045K	PARTICIPANT	\N	PRESENT	0
520091	519225	19649G	PARTICIPANT	\N	PRESENT	0
520032	519212	19301E	PARTICIPANT	\N	PRESENT	0
520033	519212	19691J	PARTICIPANT	\N	PRESENT	0
520034	519212	20172F	PARTICIPANT	\N	PRESENT	1
520035	519212	20066E	PARTICIPANT	\N	PRESENT	1
520036	519212	11103C	PARTICIPANT	\N	PRESENT	1
520037	519212	19657G	PARTICIPANT	\N	PRESENT	1
520038	519212	19760E	PARTICIPANT	\N	PRESENT	0
520056	519230	14105F	PARTICIPANT	\N	PRESENT	1
520057	519230	08069G	PARTICIPANT	\N	PRESENT	0
520058	519230	11064N	PARTICIPANT	\N	PRESENT	0
520059	519230	14267Y	PARTICIPANT	\N	PRESENT	0
520060	519230	19347U	PARTICIPANT	\N	PRESENT	0
520061	519230	16685X	PARTICIPANT	\N	PRESENT	0
520062	519230	11083R	PARTICIPANT	\N	PRESENT	0
520063	519230	04042C	PRESIDENT	0	PRESENT	0
520064	519230	97011G	PARTICIPANT	\N	PRESENT	0
520065	519230	08047A	PARTICIPANT	\N	PRESENT	0
520066	519225	19543W	PARTICIPANT	\N	PRESENT	0
520067	519225	19585H	PARTICIPANT	\N	PRESENT	0
520068	519225	04047H	PRESIDENT	0	PRESENT	0
520069	519225	19673G	PARTICIPANT	\N	PRESENT	0
520070	519225	01028R	PARTICIPANT	\N	PRESENT	0
520071	519225	19447X	PARTICIPANT	\N	PRESENT	0
520072	519225	14231L	PARTICIPANT	\N	PRESENT	0
520073	519225	05008E	PARTICIPANT	\N	PRESENT	0
520074	519225	17737W	PARTICIPANT	\N	PRESENT	0
520075	519225	14147R	PARTICIPANT	\N	PRESENT	0
520076	519225	14179A	PARTICIPANT	\N	PRESENT	0
520077	519225	20114U	PARTICIPANT	\N	PRESENT	0
520078	519225	14151M	PARTICIPANT	\N	PRESENT	0
520079	519225	14215L	PRESIDENT	1	PRESENT	0
520080	519225	08018U	PARTICIPANT	\N	PRESENT	0
520081	519225	14259Y	PARTICIPANT	\N	PRESENT	0
520082	519225	11072N	PARTICIPANT	\N	PRESENT	0
520083	519225	14053L	PARTICIPANT	\N	PRESENT	0
520084	519225	14111D	PARTICIPANT	\N	PRESENT	0
520085	519225	11026G	PARTICIPANT	\N	PRESENT	0
520086	519225	10015M	PARTICIPANT	\N	PRESENT	0
520087	519225	19725B	PARTICIPANT	\N	PRESENT	0
520088	519225	11056N	PARTICIPANT	\N	PRESENT	0
520089	519225	11085T	PARTICIPANT	\N	PRESENT	0
520090	519225	19749K	PARTICIPANT	\N	PRESENT	0
520092	519230	12041X	PARTICIPANT	\N	PRESENT	1
520093	519230	19443T	PARTICIPANT	\N	PRESENT	1
520094	519230	01058X	PARTICIPANT	\N	PRESENT	0
520095	519230	11027H	PARTICIPANT	\N	PRESENT	0
520096	519230	11054L	PARTICIPANT	\N	PRESENT	0
520097	519230	11066Q	PARTICIPANT	\N	PRESENT	0
520098	519230	08056B	PARTICIPANT	\N	PRESENT	1
520099	519230	12028B	PARTICIPANT	\N	PRESENT	0
520100	519230	14193X	PARTICIPANT	\N	PRESENT	0
520101	519230	14249W	PARTICIPANT	\N	PRESENT	0
520102	519230	20128B	PARTICIPANT	\N	PRESENT	1
520103	519230	14097Y	PARTICIPANT	\N	PRESENT	1
520104	519230	04035D	PARTICIPANT	\N	PRESENT	1
520105	519230	20042V	PARTICIPANT	\N	PRESENT	0
520106	519230	14211G	PARTICIPANT	\N	PRESENT	0
520107	519230	14255U	PARTICIPANT	\N	PRESENT	0
520110	520007	19593H	PARTICIPANT	\N	PRESENT	0
520111	520007	20132W	PARTICIPANT	\N	PRESENT	0
520112	520007	19699S	PARTICIPANT	\N	PRESENT	0
520113	520007	19533U	PARTICIPANT	\N	PRESENT	0
520114	520007	14073Q	PARTICIPANT	\N	PRESENT	0
520115	520007	19611R	PRESIDENT	0	PRESENT	0
520116	520007	20142Y	PARTICIPANT	\N	PRESENT	0
520117	520007	19693L	PARTICIPANT	\N	PRESENT	0
520118	520007	19399H	PARTICIPANT	\N	PRESENT	0
520119	520007	20052X	PARTICIPANT	\N	PRESENT	0
520120	520007	14229S	PARTICIPANT	\N	PRESENT	0
520121	520007	20058E	PARTICIPANT	\N	PRESENT	0
520122	520007	14030Q	PARTICIPANT	\N	PRESENT	0
520123	520007	20056C	PARTICIPANT	\N	PRESENT	0
520124	520007	20180F	PARTICIPANT	\N	PRESENT	0
523661	521479	20042V	PARTICIPANT	\N	PRESENT	0
523662	521479	14249W	PARTICIPANT	\N	PRESENT	0
523663	521479	14083S	PARTICIPANT	\N	PRESENT	0
523664	521479	19673G	PARTICIPANT	\N	PRESENT	0
523665	521479	14213J	PARTICIPANT	\N	PRESENT	0
523667	521479	19693L	PARTICIPANT	\N	PRESENT	0
523668	521479	19599P	PARTICIPANT	\N	PRESENT	0
523669	521479	11109J	PARTICIPANT	\N	PRESENT	0
523681	521479	11012A	PARTICIPANT	\N	PRESENT	0
524139	521420	14187A	PARTICIPANT	\N	PRESENT	0
524140	521420	19705W	PARTICIPANT	\N	PRESENT	1
525334	524118	17779H	PARTICIPANT	\N	PRESENT	0
525335	524118	19503N	PARTICIPANT	\N	PRESENT	0
525336	524118	20100N	PARTICIPANT	\N	PRESENT	0
525337	524118	11033F	PARTICIPANT	\N	PRESENT	0
525338	524118	20092G	PARTICIPANT	\N	PRESENT	0
525339	524118	20142Y	PARTICIPANT	\N	PRESENT	0
525340	524118	20174H	PARTICIPANT	\N	PRESENT	0
525341	524118	19717B	PARTICIPANT	\N	PRESENT	0
525342	524118	11012A	PARTICIPANT	\N	PRESENT	0
525343	524118	14205J	PARTICIPANT	\N	PRESENT	0
525344	524118	14042U	PARTICIPANT	\N	PRESENT	0
525345	524118	19569H	PARTICIPANT	\N	PRESENT	0
525346	524118	19826F	PARTICIPANT	\N	PRESENT	0
525347	524118	11072N	PARTICIPANT	\N	PRESENT	0
525348	524118	14097Y	PARTICIPANT	\N	PRESENT	0
525349	524118	19866P	PARTICIPANT	\N	PRESENT	0
525350	524118	14207L	PARTICIPANT	\N	PRESENT	0
525351	524118	19563B	PARTICIPANT	\N	PRESENT	0
525352	524118	20050V	PARTICIPANT	\N	PRESENT	0
525353	524118	17589D	PARTICIPANT	\N	PRESENT	0
525354	524118	14021P	PARTICIPANT	\N	PRESENT	0
525355	524118	19651A	PARTICIPANT	\N	PRESENT	0
525356	524118	20152B	PARTICIPANT	\N	PRESENT	0
525357	524118	04085P	PARTICIPANT	\N	PRESENT	0
525358	524118	19565D	PARTICIPANT	\N	PRESENT	0
525359	524118	20046A	PARTICIPANT	\N	PRESENT	0
525360	524118	20102Q	PARTICIPANT	\N	PRESENT	0
525361	524118	11040E	PARTICIPANT	\N	PRESENT	0
525362	524118	19760E	PARTICIPANT	\N	PRESENT	0
525363	524118	14211G	PARTICIPANT	\N	PRESENT	0
525364	524118	11065P	PARTICIPANT	\N	PRESENT	0
525365	524118	11099A	PARTICIPANT	\N	PRESENT	0
525366	524118	19689Q	PARTICIPANT	\N	PRESENT	0
525367	524118	19711U	PARTICIPANT	\N	PRESENT	0
525368	524118	19575F	PARTICIPANT	\N	PRESENT	0
525369	524118	19687N	PARTICIPANT	\N	PRESENT	0
525370	524118	19347U	PARTICIPANT	\N	PRESENT	0
525371	524118	99004R	PARTICIPANT	\N	PRESENT	0
525372	524118	04034C	PARTICIPANT	\N	PRESENT	0
525373	524118	95063L	PARTICIPANT	\N	PRESENT	0
525374	524118	14071N	PARTICIPANT	\N	PRESENT	0
525375	524118	08061X	PARTICIPANT	\N	PRESENT	0
525376	524118	04033B	PARTICIPANT	\N	PRESENT	0
525377	524118	19685L	PARTICIPANT	\N	PRESENT	0
525378	524118	11043H	PARTICIPANT	\N	PRESENT	0
525379	524118	14251Q	PARTICIPANT	\N	PRESENT	0
525380	524118	10015M	PARTICIPANT	\N	PRESENT	0
525381	524118	14111D	PARTICIPANT	\N	PRESENT	0
525382	524118	11064N	PARTICIPANT	\N	PRESENT	0
525383	524118	01057W	PARTICIPANT	\N	PRESENT	0
525384	524118	19515S	PARTICIPANT	\N	PRESENT	0
525385	524118	04057K	PARTICIPANT	\N	PRESENT	0
525386	524118	20116W	PARTICIPANT	\N	PRESENT	0
525387	524118	19766L	PARTICIPANT	\N	PRESENT	0
525388	524118	19629C	PARTICIPANT	\N	PRESENT	0
525389	524118	11080N	PARTICIPANT	\N	PRESENT	0
525390	524118	14259Y	PARTICIPANT	\N	PRESENT	0
525391	524118	05012A	PARTICIPANT	\N	PRESENT	0
525392	524118	19701S	PARTICIPANT	\N	PRESENT	0
525393	524118	14187A	PARTICIPANT	\N	PRESENT	0
525394	524118	19301E	PARTICIPANT	\N	PRESENT	0
525414	524118	11045K	PARTICIPANT	\N	PRESENT	0
525396	524118	20132W	PARTICIPANT	\N	PRESENT	0
525397	524118	20118Y	PARTICIPANT	\N	PRESENT	0
525398	524118	01028R	PARTICIPANT	\N	PRESENT	0
525399	524118	11048N	PARTICIPANT	\N	PRESENT	0
525400	524118	04059M	PARTICIPANT	\N	PRESENT	0
525401	524118	19447X	PARTICIPANT	\N	PRESENT	0
525402	524118	14031R	PARTICIPANT	\N	PRESENT	0
525403	524118	20038A	PARTICIPANT	\N	PRESENT	0
525404	524118	14173T	PARTICIPANT	\N	PRESENT	0
525405	524118	19573D	PARTICIPANT	\N	PRESENT	0
525406	524118	20042V	PARTICIPANT	\N	PRESENT	0
525407	524118	20096L	PARTICIPANT	\N	PRESENT	0
525408	524118	92040Q	PARTICIPANT	\N	PRESENT	0
525409	524118	20026V	PARTICIPANT	\N	PRESENT	0
525410	524118	19739H	PARTICIPANT	\N	PRESENT	0
525411	524118	11090Q	PARTICIPANT	\N	PRESENT	0
525412	524118	19533U	PARTICIPANT	\N	PRESENT	0
525413	524118	20128B	PARTICIPANT	\N	PRESENT	0
525415	524118	19723Y	PARTICIPANT	\N	PRESENT	0
525416	524118	14151M	PARTICIPANT	\N	PRESENT	0
525417	524118	19683J	PARTICIPANT	\N	PRESENT	0
525418	524118	19621T	PARTICIPANT	\N	PRESENT	0
525419	524118	19549D	PARTICIPANT	\N	PRESENT	0
525420	524118	19820Y	PARTICIPANT	\N	PRESENT	0
525467	524118	20172F	PARTICIPANT	\N	PRESENT	0
525422	524118	14257W	PARTICIPANT	\N	PRESENT	0
525423	524118	14357A	PARTICIPANT	\N	PRESENT	0
525424	524118	14147R	PARTICIPANT	\N	PRESENT	0
525425	524118	14331P	PARTICIPANT	\N	PRESENT	0
525426	524118	19649G	PARTICIPANT	\N	PRESENT	0
525427	524118	19671E	PARTICIPANT	\N	PRESENT	0
525428	524118	11026G	PARTICIPANT	\N	PRESENT	0
525429	524118	19647E	PARTICIPANT	\N	PRESENT	0
525430	524118	14033T	PARTICIPANT	\N	PRESENT	0
525431	524118	14121F	PARTICIPANT	\N	PRESENT	0
525432	524118	19553Y	PARTICIPANT	\N	PRESENT	0
525433	524118	19467C	PARTICIPANT	\N	PRESENT	0
525434	524118	19725B	PARTICIPANT	\N	PRESENT	0
525435	524118	08012N	PARTICIPANT	\N	PRESENT	0
525436	524118	20126Y	PARTICIPANT	\N	PRESENT	0
525437	524118	19251M	PARTICIPANT	\N	PRESENT	0
525438	524118	19675J	PARTICIPANT	\N	PRESENT	0
525439	524118	20070A	PARTICIPANT	\N	PRESENT	0
525440	524118	18193Q	PARTICIPANT	\N	PRESENT	0
525441	524118	14329V	PARTICIPANT	\N	PRESENT	0
525442	524118	14213J	PARTICIPANT	\N	PRESENT	0
525443	524118	20094J	PARTICIPANT	\N	PRESENT	0
525444	524118	20024T	PARTICIPANT	\N	PRESENT	0
525445	524118	19399H	PARTICIPANT	\N	PRESENT	0
525446	524118	14169X	PARTICIPANT	\N	PRESENT	0
525447	524118	11066Q	PARTICIPANT	\N	PRESENT	0
525448	524118	20110Q	PARTICIPANT	\N	PRESENT	0
525449	524118	20062A	PARTICIPANT	\N	PRESENT	0
525450	524118	08015R	PARTICIPANT	\N	PRESENT	0
525451	524118	20088L	PARTICIPANT	\N	PRESENT	0
525452	524118	20084G	PARTICIPANT	\N	PRESENT	0
525453	524118	19531S	PARTICIPANT	\N	PRESENT	0
525454	524118	20098N	PARTICIPANT	\N	PRESENT	0
525455	524118	20056C	PARTICIPANT	\N	PRESENT	0
525456	524118	14225N	PARTICIPANT	\N	PRESENT	0
525457	524118	20034V	PARTICIPANT	\N	PRESENT	0
525458	524118	14189C	PARTICIPANT	\N	PRESENT	0
525460	524118	20032T	PARTICIPANT	\N	PRESENT	0
525461	524118	20044X	PARTICIPANT	\N	PRESENT	0
525462	524118	20060X	PARTICIPANT	\N	PRESENT	0
525463	524118	20048C	PARTICIPANT	\N	PRESENT	0
525464	524118	08034U	PARTICIPANT	\N	PRESENT	0
525465	524118	20058E	PARTICIPANT	\N	PRESENT	0
525466	524118	20144B	PARTICIPANT	\N	PRESENT	0
525468	524118	19441R	PARTICIPANT	\N	PRESENT	0
525469	524118	19369B	PARTICIPANT	\N	PRESENT	0
525470	524118	19611R	PARTICIPANT	\N	PRESENT	0
525471	524118	19691J	PARTICIPANT	\N	PRESENT	0
525472	524118	18083K	PARTICIPANT	\N	PRESENT	0
525473	524118	19479G	PARTICIPANT	\N	PRESENT	0
525474	524118	19507S	PARTICIPANT	\N	PRESENT	0
525475	524118	20052X	PARTICIPANT	\N	PRESENT	0
525476	524118	19619A	PARTICIPANT	\N	PRESENT	0
525477	524118	19511N	PARTICIPANT	\N	PRESENT	0
525478	524118	01043Q	PARTICIPANT	\N	PRESENT	0
525479	524118	14030Q	PARTICIPANT	\N	PRESENT	0
525480	524118	01025N	PARTICIPANT	\N	PRESENT	0
525481	524118	01024M	PARTICIPANT	\N	PRESENT	0
525482	524118	11085T	PARTICIPANT	\N	PRESENT	0
525483	524118	14089Y	PARTICIPANT	\N	PRESENT	0
525484	524118	20104S	PARTICIPANT	\N	PRESENT	0
525485	524118	14219Q	PARTICIPANT	\N	PRESENT	0
514999	513080	14038Y	PARTICIPANT	\N	PRESENT	0
515000	513080	14187A	PARTICIPANT	\N	PRESENT	0
515027	513080	20082E	PARTICIPANT	\N	PRESENT	1
515741	515740	14259Y	PARTICIPANT	\N	PRESENT	0
515742	515740	19335Q	PARTICIPANT	\N	PRESENT	0
515743	515740	14331P	PARTICIPANT	\N	PRESENT	0
515757	515756	14069U	PARTICIPANT	\N	PRESENT	0
515758	515756	20068G	PARTICIPANT	\N	PRESENT	0
515759	515756	20126Y	PARTICIPANT	\N	PRESENT	0
515760	515756	08017T	PARTICIPANT	\N	PRESENT	0
515761	515756	14147R	PARTICIPANT	\N	PRESENT	0
515762	515756	19671E	PARTICIPANT	\N	PRESENT	0
515763	515756	92040Q	PARTICIPANT	\N	PRESENT	0
515764	515756	14331P	PARTICIPANT	\N	PRESENT	0
515765	515756	20058E	PARTICIPANT	\N	PRESENT	0
516277	516276	20052X	PARTICIPANT	\N	PRESENT	0
516278	516276	19699S	PARTICIPANT	\N	PRESENT	0
516279	516276	08017T	PARTICIPANT	\N	PRESENT	0
516280	516276	20084G	PARTICIPANT	\N	PRESENT	0
516281	516276	20112S	PARTICIPANT	\N	PRESENT	0
516282	516276	19593H	PARTICIPANT	\N	PRESENT	0
516283	516276	19611R	PRESIDENT	0	PRESENT	0
516284	516276	19621T	PARTICIPANT	\N	PRESENT	0
516285	516276	14073Q	PARTICIPANT	\N	PRESENT	0
516286	516276	20124W	PARTICIPANT	\N	PRESENT	0
516287	516276	14229S	PARTICIPANT	\N	PRESENT	0
516288	516276	17589D	PARTICIPANT	\N	PRESENT	0
516289	516276	20142Y	PARTICIPANT	\N	PRESENT	0
516290	516276	20098N	PARTICIPANT	\N	PRESENT	0
516291	516276	19693L	PARTICIPANT	\N	PRESENT	0
517051	517047	14189C	PARTICIPANT	\N	PRESENT	0
517052	517047	19741B	PARTICIPANT	\N	PRESENT	0
517053	517047	20024T	PARTICIPANT	\N	PRESENT	0
517054	517047	19966S	PARTICIPANT	\N	PRESENT	0
517055	517047	14041T	PARTICIPANT	\N	PRESENT	0
517056	517047	97011G	PARTICIPANT	\N	PRESENT	0
517057	517047	19333N	PARTICIPANT	\N	PRESENT	0
517058	517047	19511N	PARTICIPANT	\N	PRESENT	0
517059	517047	08015R	PARTICIPANT	\N	PRESENT	0
517060	517047	08034U	PARTICIPANT	\N	PRESENT	0
517061	517047	11085T	PARTICIPANT	\N	PRESENT	0
517062	517047	14071N	PARTICIPANT	\N	PRESENT	0
517063	517047	20064C	PARTICIPANT	\N	PRESENT	0
517064	517047	11041F	PARTICIPANT	\N	PRESENT	0
521667	521666	20116W	PARTICIPANT	\N	PRESENT	0
521668	521666	20042V	PARTICIPANT	\N	PRESENT	0
521669	521666	19545Y	PARTICIPANT	\N	PRESENT	0
521670	521666	11080N	PRESIDENT	0	PRESENT	0
521671	521666	11074Q	PARTICIPANT	\N	PRESENT	0
521672	521666	19347U	PARTICIPANT	\N	PRESENT	0
521673	521666	01057W	PARTICIPANT	\N	PRESENT	0
521674	521666	14121F	PARTICIPANT	\N	PRESENT	0
521675	521666	19711U	PARTICIPANT	\N	PRESENT	0
521676	521666	05012A	PARTICIPANT	\N	PRESENT	0
521739	521401	19581D	PARTICIPANT	\N	EXCUSE	0
521740	521401	14231L	PARTICIPANT	\N	EXCUSE	0
521741	521401	14215L	PARTICIPANT	\N	EXCUSE	0
521815	521539	05008E	PARTICIPANT	\N	EXCUSE	0
528622	526785	14030Q	PARTICIPANT	\N	EXCUSE	0
528623	526785	14195A	PARTICIPANT	\N	EXCUSE	0
528624	526785	08028W	PARTICIPANT	\N	EXCUSE	0
528625	526785	19467C	PARTICIPANT	\N	EXCUSE	0
528626	526785	19251M	PARTICIPANT	\N	EXCUSE	0
528627	526785	19369B	PARTICIPANT	\N	EXCUSE	0
528635	528634	19575F	PARTICIPANT	\N	PRESENT	0
528636	528634	20094J	PARTICIPANT	\N	PRESENT	0
528637	528634	14083S	PARTICIPANT	\N	PRESENT	0
528638	528634	14038Y	PARTICIPANT	\N	PRESENT	0
528639	528634	20144B	PARTICIPANT	\N	PRESENT	0
528640	528634	14357A	PARTICIPANT	\N	PRESENT	0
528641	528634	20040T	PARTICIPANT	\N	PRESENT	0
528642	528634	20174H	PARTICIPANT	\N	PRESENT	0
528643	528634	20038A	PARTICIPANT	\N	PRESENT	0
528644	528634	14033T	PARTICIPANT	\N	PRESENT	0
528645	528634	19333N	PARTICIPANT	\N	PRESENT	0
528646	528634	19551W	PARTICIPANT	\N	PRESENT	0
528647	528634	20126Y	PARTICIPANT	\N	PRESENT	0
532316	532313	20034V	PARTICIPANT	\N	PRESENT	0
528649	528634	14031R	PARTICIPANT	\N	PRESENT	0
528650	528634	14257W	PARTICIPANT	\N	PRESENT	0
528651	528634	19533U	PARTICIPANT	\N	PRESENT	0
528652	528634	11012A	PARTICIPANT	\N	PRESENT	0
528653	528634	19619A	PARTICIPANT	\N	PRESENT	0
528654	528634	20092G	PARTICIPANT	\N	PRESENT	0
528655	528634	20062A	PARTICIPANT	\N	PRESENT	0
528656	528634	19413M	PARTICIPANT	\N	PRESENT	0
532314	532313	14033T	PARTICIPANT	\N	PRESENT	0
532315	532313	19369B	PARTICIPANT	\N	PRESENT	0
534221	534219	11053K	PARTICIPANT	\N	PRESENT	0
534222	534219	01028R	PARTICIPANT	\N	PRESENT	0
534232	534231	08060W	PARTICIPANT	\N	PRESENT	0
534233	534231	05012A	PARTICIPANT	\N	PRESENT	0
534234	534231	18083K	PARTICIPANT	\N	PRESENT	0
534235	534231	19525U	PARTICIPANT	\N	PRESENT	0
534236	534231	20100N	PARTICIPANT	\N	PRESENT	0
534237	534231	19387D	PARTICIPANT	\N	PRESENT	0
534238	534231	19551W	PARTICIPANT	\N	PRESENT	0
534239	534231	20102Q	PARTICIPANT	\N	PRESENT	0
534240	534231	20136B	PARTICIPANT	\N	PRESENT	0
534242	534241	08060W	PARTICIPANT	\N	PRESENT	0
534243	534241	05012A	PARTICIPANT	\N	PRESENT	0
534244	534241	18083K	PARTICIPANT	\N	PRESENT	0
534245	534241	19525U	PARTICIPANT	\N	PRESENT	0
534246	534241	20100N	PARTICIPANT	\N	PRESENT	0
534247	534241	19551W	PARTICIPANT	\N	PRESENT	0
534248	534241	20102Q	PARTICIPANT	\N	PRESENT	0
534249	534241	20136B	PARTICIPANT	\N	PRESENT	0
534320	534319	20074E	PARTICIPANT	\N	PRESENT	0
534322	534321	20074E	PARTICIPANT	\N	PRESENT	0
534325	534324	08018U	PARTICIPANT	\N	PRESENT	0
534326	534324	11033F	PARTICIPANT	\N	PRESENT	0
534328	534327	08018U	PARTICIPANT	\N	PRESENT	0
534329	534327	11033F	PARTICIPANT	\N	PRESENT	0
534330	534327	01028R	PARTICIPANT	\N	PRESENT	0
534340	534339	14219Q	PARTICIPANT	\N	PRESENT	0
534341	534339	17229F	PARTICIPANT	\N	PRESENT	0
534342	534339	19826F	PARTICIPANT	\N	PRESENT	0
534343	534339	19637C	PARTICIPANT	\N	PRESENT	0
534344	534339	19251M	PARTICIPANT	\N	PRESENT	0
534345	534339	19387D	PARTICIPANT	\N	PRESENT	0
534346	534339	20076G	PARTICIPANT	\N	PRESENT	0
534347	534339	19421M	PARTICIPANT	\N	PRESENT	0
534348	534339	20096L	PARTICIPANT	\N	PRESENT	0
534349	534339	20140W	PARTICIPANT	\N	PRESENT	0
534350	534339	19503N	PARTICIPANT	\N	PRESENT	0
534351	534339	11027H	PARTICIPANT	\N	PRESENT	0
534352	534339	18083K	PARTICIPANT	\N	PRESENT	0
534386	534115	11090Q	PARTICIPANT	\N	EXCUSE	0
534408	534276	20106U	PARTICIPANT	\N	EXCUSE	0
534445	534252	19621T	PARTICIPANT	\N	PRESENT	0
534446	534252	08069G	PARTICIPANT	\N	PRESENT	0
534447	534252	14147R	PARTICIPANT	\N	PRESENT	0
534448	534252	14109K	PARTICIPANT	\N	PRESENT	0
534449	534252	19782L	PARTICIPANT	\N	PRESENT	0
534451	534252	08061X	PARTICIPANT	\N	PRESENT	0
534452	534252	20064C	PARTICIPANT	\N	PRESENT	0
534455	534252	11103C	PARTICIPANT	\N	PRESENT	0
534458	534252	01024M	PARTICIPANT	\N	PRESENT	0
534463	534252	14069U	PARTICIPANT	\N	PRESENT	0
534464	534252	20070A	PARTICIPANT	\N	PRESENT	0
534465	534252	14031R	PARTICIPANT	\N	PRESENT	0
534466	534252	19713W	PARTICIPANT	\N	PRESENT	0
534467	534252	19387D	PARTICIPANT	\N	PRESENT	0
534468	534252	11077T	PARTICIPANT	\N	PRESENT	0
534469	534252	19563B	PARTICIPANT	\N	PRESENT	0
534471	534115	19563B	PARTICIPANT	\N	EXCUSE	0
534472	534252	20098N	PARTICIPANT	\N	PRESENT	0
534473	534252	20024T	PARTICIPANT	\N	PRESENT	0
534474	534252	20112S	PARTICIPANT	\N	PRESENT	0
534475	534252	19333N	PARTICIPANT	\N	PRESENT	0
534476	534252	19741B	PARTICIPANT	\N	PRESENT	0
534477	534252	19549D	PARTICIPANT	\N	PRESENT	0
534478	534252	19689Q	PARTICIPANT	\N	PRESENT	0
534479	534252	97011G	PARTICIPANT	\N	PRESENT	0
534480	534252	19415P	PARTICIPANT	\N	PRESENT	0
534481	534252	19687N	PARTICIPANT	\N	PRESENT	0
534490	534252	20088L	PARTICIPANT	\N	PRESENT	0
534491	534252	20090E	PARTICIPANT	\N	PRESENT	0
534492	534252	20048C	PARTICIPANT	\N	PRESENT	0
534493	534252	14189C	PARTICIPANT	\N	PRESENT	0
534494	534252	19739H	PARTICIPANT	\N	PRESENT	0
528365	526541	19629C	PARTICIPANT	\N	PRESENT	0
528366	526541	19421M	PARTICIPANT	\N	PRESENT	0
528367	526541	19691J	PARTICIPANT	\N	PRESENT	0
528368	526541	19611R	PARTICIPANT	\N	PRESENT	0
528369	526541	11072N	PARTICIPANT	\N	PRESENT	0
528370	526541	19543W	PARTICIPANT	\N	PRESENT	0
528371	526541	11067R	PARTICIPANT	\N	PRESENT	0
528372	526541	19369B	PARTICIPANT	\N	PRESENT	0
528373	526541	20096L	PARTICIPANT	\N	PRESENT	0
528374	526541	14231L	PARTICIPANT	\N	PRESENT	0
528375	526541	20124W	PARTICIPANT	\N	PRESENT	0
528376	526541	20052X	PARTICIPANT	\N	PRESENT	0
528377	526541	20082E	PARTICIPANT	\N	PRESENT	0
528378	526541	19565D	PARTICIPANT	\N	PRESENT	0
528379	526541	20112S	PARTICIPANT	\N	PRESENT	0
528380	526541	19441R	PARTICIPANT	\N	PRESENT	0
528381	526541	07029T	PARTICIPANT	\N	PRESENT	0
528382	526541	20062A	PARTICIPANT	\N	PRESENT	0
528383	526541	19531S	PARTICIPANT	\N	PRESENT	0
528384	526541	19521Q	PARTICIPANT	\N	PRESENT	0
528386	526541	11099A	PARTICIPANT	\N	PRESENT	0
528387	526541	14357A	PARTICIPANT	\N	PRESENT	0
528388	526541	20100N	PARTICIPANT	\N	PRESENT	0
528389	526541	20130U	PARTICIPANT	\N	PRESENT	0
528390	526541	05012A	PARTICIPANT	\N	PRESENT	0
528399	526541	20094J	PARTICIPANT	\N	PRESENT	0
528400	526541	14069U	PARTICIPANT	\N	PRESENT	0
528401	526541	04085P	PARTICIPANT	\N	PRESENT	0
528402	526541	19695N	PARTICIPANT	\N	PRESENT	0
528403	526541	19349W	PARTICIPANT	\N	PRESENT	0
528404	526541	14026U	PARTICIPANT	\N	PRESENT	0
528405	526541	14251Q	PARTICIPANT	\N	PRESENT	0
528406	526541	14215L	PARTICIPANT	\N	PRESENT	0
528407	526541	14193X	PARTICIPANT	\N	PRESENT	0
528408	526541	19533U	PARTICIPANT	\N	PRESENT	0
528409	526541	19782L	PARTICIPANT	\N	PRESENT	0
528410	526541	19673G	PARTICIPANT	\N	PRESENT	0
528506	526542	11031D	PARTICIPANT	\N	PRESENT	0
528507	526542	20070A	PARTICIPANT	\N	PRESENT	0
528508	526542	14071N	PARTICIPANT	\N	PRESENT	0
528509	526542	11067R	PARTICIPANT	\N	PRESENT	0
528510	526542	19575F	PARTICIPANT	\N	PRESENT	0
528511	526542	10015M	PARTICIPANT	\N	PRESENT	0
528512	526542	11097X	PARTICIPANT	\N	PRESENT	0
528513	526542	19333N	PARTICIPANT	\N	PRESENT	0
528514	526542	14213J	PARTICIPANT	\N	PRESENT	0
528515	526542	20100N	PARTICIPANT	\N	PRESENT	0
528516	526542	05008E	PARTICIPANT	\N	PRESENT	0
528517	526542	20092G	PARTICIPANT	\N	PRESENT	0
528518	526542	14357A	PARTICIPANT	\N	PRESENT	0
528519	526542	19347U	PARTICIPANT	\N	PRESENT	0
528520	526542	19683J	PARTICIPANT	\N	PRESENT	0
528521	526542	14215L	PARTICIPANT	\N	PRESENT	0
528522	526542	19651A	PARTICIPANT	\N	PRESENT	0
528523	526542	20034V	PARTICIPANT	\N	PRESENT	0
528524	526542	11072N	PARTICIPANT	\N	PRESENT	0
528525	526542	07029T	PARTICIPANT	\N	PRESENT	0
528526	526542	19629C	PARTICIPANT	\N	PRESENT	0
528527	526542	14195A	PARTICIPANT	\N	PRESENT	0
528528	526542	04033B	PARTICIPANT	\N	PRESENT	0
528529	526542	19387D	PARTICIPANT	\N	PRESENT	0
528530	526542	19553Y	PARTICIPANT	\N	PRESENT	0
528531	526542	20054A	PARTICIPANT	\N	PRESENT	0
528532	526542	20132W	PARTICIPANT	\N	PRESENT	0
528533	526542	20116W	PARTICIPANT	\N	PRESENT	0
528534	526542	20062A	PARTICIPANT	\N	PRESENT	0
528535	526542	20110Q	PARTICIPANT	\N	PRESENT	0
528536	526542	20090E	PARTICIPANT	\N	PRESENT	0
528537	526542	14169X	PARTICIPANT	\N	PRESENT	0
528538	526542	08034U	PARTICIPANT	\N	PRESENT	0
528539	526542	19741B	PARTICIPANT	\N	PRESENT	0
528540	526542	14038Y	PARTICIPANT	\N	PRESENT	0
528557	526542	19335Q	PARTICIPANT	\N	PRESENT	0
528542	526542	04092N	PARTICIPANT	\N	PRESENT	0
528543	526542	19715Y	PARTICIPANT	\N	PRESENT	0
528544	526542	19421M	PARTICIPANT	\N	PRESENT	0
528545	526542	20122U	PARTICIPANT	\N	PRESENT	0
528546	526542	19399H	PARTICIPANT	\N	PRESENT	0
528547	526542	14042U	PARTICIPANT	\N	PRESENT	0
528548	526542	19569H	PARTICIPANT	\N	PRESENT	0
528549	526542	01024M	PARTICIPANT	\N	PRESENT	0
528550	526542	19691J	PARTICIPANT	\N	PRESENT	0
528551	526542	20120S	PARTICIPANT	\N	PRESENT	0
528552	526542	20124W	PARTICIPANT	\N	PRESENT	0
528553	526542	19447X	PARTICIPANT	\N	PRESENT	0
528554	526542	11012A	PARTICIPANT	\N	PRESENT	0
528555	526542	14055N	PARTICIPANT	\N	PRESENT	0
528556	526542	19782L	PARTICIPANT	\N	PRESENT	0
528558	526542	18083K	PARTICIPANT	\N	PRESENT	0
528559	526542	20066E	PARTICIPANT	\N	PRESENT	0
528560	526542	14231L	PARTICIPANT	\N	PRESENT	0
528561	526542	20058E	PARTICIPANT	\N	PRESENT	0
528562	526542	20114U	PARTICIPANT	\N	PRESENT	0
528563	526542	10006L	PARTICIPANT	\N	PRESENT	0
528564	526542	14053L	PARTICIPANT	\N	PRESENT	0
528565	526542	20044X	PARTICIPANT	\N	PRESENT	0
528566	526542	05012A	PARTICIPANT	\N	PRESENT	0
528567	526542	04047H	PARTICIPANT	\N	PRESENT	0
528568	526542	14217N	PARTICIPANT	\N	PRESENT	0
528569	526542	20126Y	PARTICIPANT	\N	PRESENT	0
528570	526542	14026U	PARTICIPANT	\N	PRESENT	0
528571	526542	04043D	PARTICIPANT	\N	PRESENT	0
528572	526542	19621T	PARTICIPANT	\N	PRESENT	0
528573	526542	19747H	PARTICIPANT	\N	PRESENT	0
528574	526542	20094J	PARTICIPANT	\N	PRESENT	0
528575	526542	19713W	PARTICIPANT	\N	PRESENT	0
528576	526542	11099A	PARTICIPANT	\N	PRESENT	0
528362	526541	20098N	PARTICIPANT	\N	PRESENT	0
528364	526541	14083S	PARTICIPANT	\N	PRESENT	0
528577	526542	19531S	PARTICIPANT	\N	PRESENT	0
528578	526542	14069U	PARTICIPANT	\N	PRESENT	0
528579	526542	11026G	PARTICIPANT	\N	PRESENT	0
528580	526542	20082E	PARTICIPANT	\N	PRESENT	0
528581	526542	19647E	PARTICIPANT	\N	PRESENT	0
528582	526542	19563B	PARTICIPANT	\N	PRESENT	0
528583	526542	01057W	PARTICIPANT	\N	PRESENT	0
528584	526542	17637T	PARTICIPANT	\N	PRESENT	0
528585	526542	20106U	PARTICIPANT	\N	PRESENT	0
528586	526542	19573D	PARTICIPANT	\N	PRESENT	0
528587	526542	11048N	PARTICIPANT	\N	PRESENT	0
528588	526542	20052X	PARTICIPANT	\N	PRESENT	0
528589	526542	19671E	PARTICIPANT	\N	PRESENT	0
529024	529023	14111D	PARTICIPANT	\N	PRESENT	0
529026	529025	14111D	PARTICIPANT	\N	PRESENT	0
529027	529025	19954N	PARTICIPANT	\N	PRESENT	0
529029	529028	14111D	PARTICIPANT	\N	PRESENT	0
529031	529030	14111D	PARTICIPANT	\N	PRESENT	0
529036	529035	19673G	PARTICIPANT	\N	PRESENT	0
529037	529035	19749K	PARTICIPANT	\N	PRESENT	0
529038	529035	17737W	PARTICIPANT	\N	PRESENT	0
529039	529035	19954N	PARTICIPANT	\N	PRESENT	0
529040	529035	14069U	PARTICIPANT	\N	PRESENT	0
528504	526542	19719D	PARTICIPANT	\N	PRESENT	0
528505	526542	19593H	PARTICIPANT	\N	PRESENT	0
529041	529035	95063L	PARTICIPANT	\N	PRESENT	0
529042	529035	19533U	PARTICIPANT	\N	PRESENT	0
529462	529007	14097Y	PARTICIPANT	\N	EXCUSE	0
529481	529480	14147R	PARTICIPANT	\N	PRESENT	0
529482	529480	14357A	PARTICIPANT	\N	PRESENT	0
529483	529480	07033P	PARTICIPANT	\N	PRESENT	0
529572	529488	14147R	PARTICIPANT	\N	PRESENT	0
529887	529002	14111D	PARTICIPANT	\N	PRESENT	0
529888	529002	20108W	PARTICIPANT	\N	PRESENT	0
529889	529002	14041T	PARTICIPANT	\N	PRESENT	0
529890	529002	08018U	PRESIDENT	0	PRESENT	0
529891	529002	19673G	PARTICIPANT	\N	PRESENT	0
529892	529002	01028R	PARTICIPANT	\N	PRESENT	0
529893	529002	14231L	PARTICIPANT	\N	PRESENT	0
529894	529002	20114U	PARTICIPANT	\N	PRESENT	0
529895	529002	14147R	PARTICIPANT	\N	PRESENT	0
529896	529002	05008E	PARTICIPANT	\N	PRESENT	0
529897	529002	14053L	PARTICIPANT	\N	PRESENT	0
529898	529002	19749K	PARTICIPANT	\N	PRESENT	0
529899	529002	14151M	PARTICIPANT	\N	PRESENT	0
529900	529002	11056N	PARTICIPANT	\N	PRESENT	0
529901	529002	19729F	PARTICIPANT	\N	PRESENT	0
529902	529229	20086J	PARTICIPANT	\N	PRESENT	1
529903	529229	19768N	PARTICIPANT	\N	PRESENT	1
529904	529229	19515S	PARTICIPANT	\N	PRESENT	0
529905	529229	20092G	PARTICIPANT	\N	PRESENT	0
529906	529229	11077T	PARTICIPANT	\N	PRESENT	1
517478	511871	20076G	PARTICIPANT	\N	PRESENT	0
517479	511871	20046A	PARTICIPANT	\N	PRESENT	0
517480	511871	20102Q	PARTICIPANT	\N	PRESENT	0
517481	516877	19697Q	PARTICIPANT	\N	PRESENT	1
517482	516877	11067R	PARTICIPANT	\N	PRESENT	0
517483	516877	20090E	PARTICIPANT	\N	PRESENT	0
517484	516877	19569H	PARTICIPANT	\N	PRESENT	0
517485	516877	11097X	PARTICIPANT	0	PRESENT	0
517486	516877	19703U	PARTICIPANT	\N	PRESENT	0
517487	516877	19553Y	PARTICIPANT	\N	PRESENT	1
517488	516877	11031D	PARTICIPANT	\N	PRESENT	1
517489	516877	14281W	PARTICIPANT	\N	PRESENT	1
517490	516877	19679N	PARTICIPANT	\N	PRESENT	0
517491	516877	14042U	PARTICIPANT	\N	PRESENT	0
517492	516877	14195A	PARTICIPANT	\N	PRESENT	1
517493	516877	14213J	PARTICIPANT	\N	PRESENT	0
517494	516877	14217N	PARTICIPANT	\N	PRESENT	1
517495	516877	10006L	PRESIDENT	0	PRESENT	0
517496	516877	19683J	PARTICIPANT	\N	PRESENT	0
517497	516877	20130U	PARTICIPANT	\N	PRESENT	0
517498	516877	04057K	PARTICIPANT	\N	PRESENT	0
517499	516877	04092N	PARTICIPANT	\N	PRESENT	0
517500	516877	19301E	PARTICIPANT	\N	PRESENT	0
517501	516877	17965H	PARTICIPANT	\N	PRESENT	0
517502	516877	19691J	PARTICIPANT	\N	PRESENT	0
517503	516877	20172F	PARTICIPANT	\N	PRESENT	0
517504	516877	14071N	PARTICIPANT	\N	PRESENT	1
517505	516877	19760E	PARTICIPANT	\N	PRESENT	1
517506	516382	19954N	PARTICIPANT	\N	PRESENT	0
517507	516382	19649G	PARTICIPANT	\N	PRESENT	0
517508	516382	14041T	PARTICIPANT	\N	PRESENT	0
517509	516382	20108W	PARTICIPANT	\N	PRESENT	0
517510	516382	14147R	PARTICIPANT	\N	PRESENT	0
517511	516382	08018U	PRESIDENT	1	PRESENT	0
517512	516382	19749K	PARTICIPANT	\N	PRESENT	0
517513	511871	19503N	PARTICIPANT	\N	PRESENT	0
517514	511871	14221J	PARTICIPANT	\N	PRESENT	0
517515	511871	18083K	PARTICIPANT	\N	PRESENT	0
517516	511871	19333N	PARTICIPANT	\N	PRESENT	0
517517	511871	19739H	PARTICIPANT	\N	PRESENT	0
517518	511871	19745F	PARTICIPANT	\N	PRESENT	0
517519	511871	20032T	PARTICIPANT	\N	PRESENT	0
517520	511871	20038A	PARTICIPANT	\N	PRESENT	0
517521	511871	20096L	PARTICIPANT	\N	PRESENT	0
517522	511871	20024T	PARTICIPANT	\N	PRESENT	0
517524	511871	19387D	PARTICIPANT	\N	PRESENT	0
517525	511871	19599P	PARTICIPANT	\N	PRESENT	0
517526	511871	19637C	PARTICIPANT	\N	PRESENT	0
517527	511871	20100N	PARTICIPANT	\N	PRESENT	0
517528	511871	14038Y	PARTICIPANT	\N	PRESENT	0
517529	511871	14205J	PARTICIPANT	\N	PRESENT	0
517540	511871	19701S	PARTICIPANT	\N	PRESENT	0
517541	511871	14219Q	PRESIDENT	0	PRESENT	0
517542	511871	20020P	PARTICIPANT	\N	PRESENT	0
517543	511871	19685L	PARTICIPANT	\N	PRESENT	0
517544	511871	17367Q	PARTICIPANT	\N	PRESENT	0
517545	511871	20120S	PARTICIPANT	\N	PRESENT	0
517546	511871	14031R	PARTICIPANT	\N	PRESENT	0
517547	511871	20140W	PARTICIPANT	\N	PRESENT	0
517548	511871	19251M	PARTICIPANT	\N	PRESENT	0
517549	511871	14169X	PARTICIPANT	\N	PRESENT	0
517551	515076	20086J	PARTICIPANT	\N	PRESENT	1
517552	515076	19515S	PARTICIPANT	\N	PRESENT	0
517553	515076	19782L	PARTICIPANT	\N	PRESENT	0
517554	515076	20092G	PARTICIPANT	\N	PRESENT	0
517555	515076	20078J	PARTICIPANT	\N	PRESENT	1
517556	515076	19413M	PARTICIPANT	\N	PRESENT	0
517557	515076	20082E	PARTICIPANT	\N	PRESENT	0
517558	515076	20094J	PARTICIPANT	\N	PRESENT	0
517559	515076	04045F	PARTICIPANT	\N	PRESENT	1
517560	515076	20104S	PARTICIPANT	\N	PRESENT	0
517561	515076	19631V	PARTICIPANT	\N	PRESENT	0
517562	515076	11099A	PARTICIPANT	\N	PRESENT	1
517563	515076	19705W	PARTICIPANT	\N	PRESENT	0
517564	515076	08015R	PARTICIPANT	\N	PRESENT	0
517565	515076	19575F	PARTICIPANT	\N	PRESENT	1
517566	515076	19369B	PARTICIPANT	\N	PRESENT	1
517567	515076	19511N	PARTICIPANT	\N	PRESENT	0
517568	515076	08028W	PARTICIPANT	\N	PRESENT	0
517569	515076	19563B	PARTICIPANT	\N	PRESENT	1
517570	515076	20028X	PARTICIPANT	\N	PRESENT	0
517571	515076	20144B	PARTICIPANT	\N	PRESENT	0
517572	515076	19695N	PARTICIPANT	\N	PRESENT	0
517573	515076	11090Q	PRESIDENT	0	PRESENT	0
517574	515076	14033T	PARTICIPANT	\N	PRESENT	0
517575	515076	01025N	PARTICIPANT	\N	PRESENT	1
517576	515076	20054A	PARTICIPANT	\N	PRESENT	0
517577	515076	20174H	PARTICIPANT	\N	PRESENT	0
517578	515076	20062A	PARTICIPANT	\N	PRESENT	1
517579	515076	19507S	PARTICIPANT	\N	PRESENT	0
517580	515076	19747H	PARTICIPANT	\N	PRESENT	0
517581	515076	14207L	PARTICIPANT	\N	PRESENT	0
517582	515076	14257W	PARTICIPANT	\N	PRESENT	0
517587	511871	19820Y	PARTICIPANT	\N	PRESENT	0
517588	511871	20068G	PARTICIPANT	\N	PRESENT	0
517589	511871	08060W	PARTICIPANT	\N	PRESENT	1
517592	511871	19549D	PARTICIPANT	\N	PRESENT	1
517596	511871	14237S	PARTICIPANT	\N	PRESENT	0
517659	516877	19798U	PARTICIPANT	\N	PRESENT	0
517660	516877	17779H	PARTICIPANT	\N	PRESENT	0
517661	516877	19723Y	PARTICIPANT	\N	PRESENT	0
517662	516877	20066E	PARTICIPANT	\N	PRESENT	1
517663	516877	11103C	PARTICIPANT	\N	PRESENT	1
517664	516877	19657G	PARTICIPANT	\N	PRESENT	1
517665	516755	11048N	PARTICIPANT	\N	PRESENT	0
517666	516755	19711U	PARTICIPANT	\N	PRESENT	0
517667	516755	11012A	PARTICIPANT	\N	PRESENT	0
517668	516755	08009T	PARTICIPANT	\N	PRESENT	0
517669	516755	19687N	PARTICIPANT	\N	PRESENT	0
517670	516755	19689Q	PARTICIPANT	\N	PRESENT	0
517671	516755	19349W	PARTICIPANT	\N	PRESENT	0
517672	516755	20080C	PARTICIPANT	\N	PRESENT	0
517688	516755	19531S	PARTICIPANT	\N	PRESENT	0
517674	516755	20116W	PARTICIPANT	\N	PRESENT	0
517675	516755	20044X	PARTICIPANT	\N	PRESENT	0
517676	516755	19545Y	PARTICIPANT	\N	PRESENT	0
517677	516755	14327T	PARTICIPANT	\N	PRESENT	0
517678	516755	14331P	PARTICIPANT	\N	PRESENT	0
517679	516755	19479G	PARTICIPANT	\N	PRESENT	0
517680	516755	08034U	PARTICIPANT	\N	PRESENT	0
517681	516755	01057W	PARTICIPANT	\N	PRESENT	0
517682	516755	08011M	PARTICIPANT	\N	PRESENT	0
517683	516755	19667J	PARTICIPANT	\N	PRESENT	0
517684	516755	14225N	PRESIDENT	0	PRESENT	0
517685	516755	14083S	PARTICIPANT	\N	PRESENT	0
517686	516755	19741B	PARTICIPANT	\N	PRESENT	0
517687	516755	20126Y	PARTICIPANT	\N	PRESENT	0
517689	516755	14189C	PARTICIPANT	\N	PRESENT	0
517690	516755	11053K	PARTICIPANT	\N	PRESENT	0
517691	516755	07029T	PARTICIPANT	\N	PRESENT	0
517692	516755	19647E	PARTICIPANT	\N	PRESENT	0
517693	516755	11040E	PARTICIPANT	\N	PRESENT	0
517694	516755	20070A	PARTICIPANT	\N	PRESENT	0
517695	516755	20022R	PARTICIPANT	\N	PRESENT	0
517696	516382	14053L	PARTICIPANT	\N	PRESENT	0
517697	516382	14111D	PARTICIPANT	\N	PRESENT	0
517698	516382	20074E	PARTICIPANT	\N	PRESENT	0
517699	516382	11026G	PARTICIPANT	\N	PRESENT	0
517700	516382	19543W	PARTICIPANT	\N	PRESENT	0
517701	516382	04047H	PRESIDENT	0	PRESENT	0
517702	516382	01028R	PARTICIPANT	\N	PRESENT	0
517703	516382	14231L	PARTICIPANT	\N	PRESENT	0
517704	516382	05008E	PARTICIPANT	\N	PRESENT	0
517705	516382	19447X	PARTICIPANT	\N	PRESENT	0
517706	516382	11056N	PARTICIPANT	\N	PRESENT	0
517707	516382	19489J	PARTICIPANT	\N	PRESENT	0
517708	516382	95063L	PARTICIPANT	\N	PRESENT	0
517709	516382	14107H	PARTICIPANT	\N	PRESENT	0
517710	516382	20110Q	PARTICIPANT	\N	PRESENT	0
517711	516382	20114U	PARTICIPANT	\N	PRESENT	0
517712	516382	14089Y	PARTICIPANT	\N	PRESENT	0
517713	516382	11072N	PARTICIPANT	\N	PRESENT	0
517715	517467	04070G	PARTICIPANT	\N	PRESENT	0
517716	517467	19699S	PARTICIPANT	\N	PRESENT	0
517717	517467	14229S	PARTICIPANT	\N	PRESENT	0
517718	517467	19573D	PARTICIPANT	\N	PRESENT	0
517719	517467	92040Q	PARTICIPANT	\N	PRESENT	0
517720	517467	08012N	PARTICIPANT	\N	PRESENT	0
517721	517467	08061X	PARTICIPANT	\N	PRESENT	0
517722	517467	20124W	PARTICIPANT	\N	PRESENT	0
517723	517467	20026V	PARTICIPANT	\N	PRESENT	0
525486	524118	14083S	PARTICIPANT	\N	PRESENT	0
525487	524118	19705W	PARTICIPANT	\N	PRESENT	0
525488	524118	19543W	PARTICIPANT	\N	PRESENT	0
525489	524118	19713W	PARTICIPANT	\N	PRESENT	0
525490	524118	19966S	PARTICIPANT	\N	PRESENT	0
525491	524118	19699S	PARTICIPANT	\N	PRESENT	0
525492	524118	19335Q	PARTICIPANT	\N	PRESENT	0
525493	524118	19383Y	PARTICIPANT	\N	PRESENT	0
525494	524118	04043D	PARTICIPANT	\N	PRESENT	0
525495	524118	20054A	PARTICIPANT	\N	PRESENT	0
525496	524118	19741B	PARTICIPANT	\N	PRESENT	0
525497	524118	19758L	PARTICIPANT	\N	PRESENT	0
525498	524118	20138D	PARTICIPANT	\N	PRESENT	0
525499	524118	19679N	PARTICIPANT	\N	PRESENT	0
525500	524118	19591F	PARTICIPANT	\N	PRESENT	0
525501	524118	14069U	PARTICIPANT	\N	PRESENT	0
525502	524118	11097X	PARTICIPANT	\N	PRESENT	0
525503	524118	04092N	PARTICIPANT	\N	PRESENT	0
525504	524118	20040T	PARTICIPANT	\N	PRESENT	0
525505	524118	19747H	PARTICIPANT	\N	PRESENT	0
525506	524118	20112S	PARTICIPANT	\N	PRESENT	0
525508	524118	19421M	PARTICIPANT	\N	PRESENT	0
525509	524118	12041X	PARTICIPANT	\N	PRESENT	0
525512	524118	14179A	PARTICIPANT	\N	PRESENT	0
525514	524118	14231L	PARTICIPANT	\N	PRESENT	0
525518	524118	01048V	PARTICIPANT	\N	PRESENT	0
525516	524118	14221J	PARTICIPANT	\N	PRESENT	0
525537	524118	07004J	PARTICIPANT	\N	PRESENT	0
525741	524119	01043Q	PARTICIPANT	\N	PRESENT	0
525538	524118	20076G	PARTICIPANT	\N	PRESENT	0
525743	524078	04086Q	PARTICIPANT	\N	PRESENT	0
525744	524078	11040E	PARTICIPANT	\N	PRESENT	0
525745	524078	14331P	PARTICIPANT	\N	PRESENT	0
525746	524078	19479G	PARTICIPANT	\N	PRESENT	0
525747	524078	19687N	PARTICIPANT	\N	PRESENT	0
525748	524078	19689Q	PARTICIPANT	\N	PRESENT	0
525749	524078	20044X	PARTICIPANT	\N	PRESENT	0
525750	524078	14225N	PRESIDENT	0	PRESENT	0
525751	524078	19671E	PARTICIPANT	\N	PRESENT	0
525752	524078	07029T	PARTICIPANT	\N	EXCUSE	0
525753	524078	20022R	PARTICIPANT	\N	EXCUSE	0
525754	524119	05008E	PARTICIPANT	\N	PRESENT	0
525755	524119	04047H	PARTICIPANT	\N	PRESENT	0
525756	524119	19866P	PARTICIPANT	\N	PRESENT	0
525757	524119	19629C	PARTICIPANT	\N	PRESENT	0
525758	524119	20066E	PARTICIPANT	\N	PRESENT	0
525759	524119	19649G	PARTICIPANT	\N	PRESENT	0
525760	524119	20090E	PARTICIPANT	\N	PRESENT	0
525761	524119	14147R	PARTICIPANT	\N	PRESENT	0
525762	524119	11067R	PARTICIPANT	\N	PRESENT	0
525763	524119	20102Q	PARTICIPANT	\N	PRESENT	0
525764	524119	14089Y	PARTICIPANT	\N	PRESENT	0
525765	524078	01057W	PARTICIPANT	\N	PRESENT	0
525835	524119	19441R	PARTICIPANT	\N	PRESENT	0
525767	524078	99004R	PARTICIPANT	\N	PRESENT	0
525768	524078	20126Y	PARTICIPANT	\N	PRESENT	0
525769	524119	04043D	PARTICIPANT	\N	PRESENT	0
525770	524119	07004J	PARTICIPANT	\N	PRESENT	0
525771	524119	19447X	PARTICIPANT	\N	PRESENT	0
525772	524119	20074E	PARTICIPANT	\N	PRESENT	0
525773	524119	10015M	PARTICIPANT	\N	PRESENT	0
525774	524119	20076G	PARTICIPANT	\N	PRESENT	0
525775	524119	04057K	PARTICIPANT	\N	PRESENT	0
525776	524119	20084G	PARTICIPANT	\N	PRESENT	0
525777	524119	14069U	PARTICIPANT	\N	PRESENT	0
525778	524119	19533U	PARTICIPANT	\N	PRESENT	0
525779	524078	19647E	PARTICIPANT	\N	PRESENT	0
525780	524119	95063L	PARTICIPANT	\N	PRESENT	0
525781	524078	08034U	PARTICIPANT	\N	PRESENT	0
525782	524119	11033F	PARTICIPANT	\N	PRESENT	0
525783	524119	11072N	PARTICIPANT	\N	PRESENT	0
525784	524078	19762G	PARTICIPANT	\N	PRESENT	0
525786	524119	19966S	PARTICIPANT	\N	PRESENT	0
525801	524119	19673G	PARTICIPANT	\N	PRESENT	0
525802	524078	19741B	PARTICIPANT	\N	PRESENT	0
525803	524119	01028R	PARTICIPANT	\N	PRESENT	0
525804	524119	19543W	PARTICIPANT	\N	PRESENT	0
525805	524119	19766L	PARTICIPANT	\N	PRESENT	0
525806	524078	14189C	PARTICIPANT	\N	PRESENT	0
525808	524119	14151M	PARTICIPANT	\N	PRESENT	0
525809	524119	14055N	PARTICIPANT	\N	PRESENT	0
525810	524119	20172F	PARTICIPANT	\N	PRESENT	0
525811	524119	14179A	PARTICIPANT	\N	PRESENT	0
525812	524119	01024M	PARTICIPANT	\N	PRESENT	0
525813	524119	18083K	PARTICIPANT	\N	PRESENT	0
525814	524119	19565D	PARTICIPANT	\N	PRESENT	0
525815	524119	14021P	PARTICIPANT	\N	PRESENT	0
525816	524119	14097Y	PARTICIPANT	\N	PRESENT	0
525817	524119	11026G	PARTICIPANT	\N	PRESENT	0
525818	524119	19826F	PARTICIPANT	\N	PRESENT	0
525819	524119	19691J	PARTICIPANT	\N	PRESENT	0
525824	524119	19697Q	PARTICIPANT	\N	PRESENT	0
525825	524119	19760E	PARTICIPANT	\N	PRESENT	0
525826	524119	19725B	PARTICIPANT	\N	PRESENT	0
525827	524119	20110Q	PARTICIPANT	\N	PRESENT	0
525828	524119	11085T	PARTICIPANT	\N	PRESENT	0
525829	524119	14111D	PARTICIPANT	\N	PRESENT	0
525830	524119	20052X	PARTICIPANT	\N	PRESENT	0
525831	524078	11048N	PARTICIPANT	\N	PRESENT	0
525832	524078	20070A	PARTICIPANT	\N	PRESENT	0
525833	524119	20092G	PARTICIPANT	\N	PRESENT	0
525834	524119	20054A	PARTICIPANT	\N	PRESENT	0
525836	524119	11012A	PARTICIPANT	\N	PRESENT	0
525837	524119	19749K	PARTICIPANT	\N	PRESENT	0
525838	524119	19747H	PARTICIPANT	\N	PRESENT	0
525839	524119	19703U	PARTICIPANT	\N	PRESENT	0
525840	524119	20024T	PARTICIPANT	\N	PRESENT	0
525841	524119	19798U	PARTICIPANT	\N	PRESENT	0
525842	524119	19701S	PARTICIPANT	\N	PRESENT	0
525843	524119	20034V	PARTICIPANT	\N	PRESENT	0
525844	524119	20082E	PARTICIPANT	\N	PRESENT	0
525845	524119	20060X	PARTICIPANT	\N	PRESENT	0
525846	524119	20144B	PARTICIPANT	\N	PRESENT	0
525847	524119	20132W	PARTICIPANT	\N	PRESENT	0
525848	524119	19695N	PARTICIPANT	\N	PRESENT	0
525849	524119	20068G	PARTICIPANT	\N	PRESENT	0
525850	524119	20048C	PARTICIPANT	\N	PRESENT	0
525854	524119	17737W	PARTICIPANT	\N	PRESENT	0
525860	524074	17737W	PARTICIPANT	\N	PRESENT	0
525861	524074	19649G	PARTICIPANT	\N	PRESENT	0
525862	524074	10015M	PARTICIPANT	\N	PRESENT	0
525863	524074	11026G	PARTICIPANT	\N	PRESENT	0
525864	524074	04047H	PRESIDENT	0	PRESENT	0
525865	524074	19447X	PARTICIPANT	\N	PRESENT	0
525866	524074	11072N	PARTICIPANT	\N	PRESENT	0
525867	524074	14151M	PARTICIPANT	\N	PRESENT	0
525868	524074	11033F	PARTICIPANT	\N	PRESENT	0
525869	524074	01028R	PARTICIPANT	\N	PRESENT	0
525870	524074	14089Y	PARTICIPANT	\N	PRESENT	0
525871	524074	19543W	PARTICIPANT	\N	PRESENT	0
525872	524074	19725B	PARTICIPANT	\N	PRESENT	0
525873	524074	05008E	PARTICIPANT	\N	PRESENT	0
525874	524074	14179A	PARTICIPANT	\N	PRESENT	0
525875	524074	11085T	PARTICIPANT	\N	PRESENT	0
525892	524074	14147R	PARTICIPANT	\N	PRESENT	0
525893	524119	20100N	PARTICIPANT	\N	PRESENT	0
525894	524119	14189C	PARTICIPANT	\N	PRESENT	0
525895	524119	19651A	PARTICIPANT	\N	PRESENT	0
525896	524119	20044X	PARTICIPANT	\N	PRESENT	0
525900	524119	01048V	PARTICIPANT	\N	PRESENT	0
525901	524119	20058E	PARTICIPANT	\N	PRESENT	0
525902	524119	14357A	PARTICIPANT	\N	PRESENT	0
525903	524119	14031R	PARTICIPANT	\N	PRESENT	0
525904	524119	08015R	PARTICIPANT	\N	PRESENT	0
525906	525905	19251M	PARTICIPANT	\N	PRESENT	0
525907	525905	11064N	PARTICIPANT	\N	PRESENT	0
525908	525905	20084G	PARTICIPANT	\N	PRESENT	0
525909	524119	19762G	PARTICIPANT	\N	PRESENT	0
525910	524119	19671E	PARTICIPANT	\N	PRESENT	0
525911	524119	19347U	PARTICIPANT	\N	PRESENT	0
525912	524119	11031D	PARTICIPANT	\N	PRESENT	0
525913	524119	11056N	PARTICIPANT	\N	PRESENT	0
525914	524119	14053L	PARTICIPANT	\N	PRESENT	0
525915	524119	14001X	PARTICIPANT	\N	PRESENT	0
525916	524119	14030Q	PARTICIPANT	\N	PRESENT	0
525918	525917	14249W	PARTICIPANT	\N	PRESENT	0
525924	524119	11048N	PARTICIPANT	\N	PRESENT	0
516748	514891	19735D	PARTICIPANT	\N	PRESENT	0
516750	514891	19723Y	PARTICIPANT	\N	PRESENT	0
516751	514891	11067R	PARTICIPANT	\N	PRESENT	0
516752	514891	01058X	PARTICIPANT	\N	EXCUSE	0
516754	514891	01048V	PARTICIPANT	\N	EXCUSE	0
516759	516539	19735D	PARTICIPANT	\N	PRESENT	0
516760	516539	01048V	PARTICIPANT	\N	EXCUSE	0
516762	516539	19723Y	PARTICIPANT	\N	PRESENT	0
516764	516539	20128B	PARTICIPANT	\N	PRESENT	0
516765	516539	04043D	PARTICIPANT	\N	PRESENT	0
516769	516539	01058X	PARTICIPANT	\N	PRESENT	0
516771	514757	19593H	PARTICIPANT	\N	EXCUSE	0
516804	514891	20066E	PARTICIPANT	\N	PRESENT	0
522536	521402	04085P	PARTICIPANT	\N	PRESENT	1
522537	521402	11033F	PARTICIPANT	\N	PRESENT	1
522538	521402	17737W	PARTICIPANT	\N	PRESENT	1
522539	521402	19629C	PARTICIPANT	\N	PRESENT	1
522540	521402	14259Y	PARTICIPANT	\N	PRESENT	1
522541	521402	07004J	PARTICIPANT	\N	PRESENT	1
522542	521402	14179A	PARTICIPANT	\N	PRESENT	1
522543	521402	11026G	PARTICIPANT	\N	PRESENT	1
522544	521402	19581D	PARTICIPANT	\N	PRESENT	1
522545	521402	14001X	PARTICIPANT	\N	PRESENT	1
522546	521402	14147R	PARTICIPANT	\N	PRESENT	1
522547	521402	11072N	PARTICIPANT	\N	PRESENT	1
522548	521402	14107H	PARTICIPANT	\N	PRESENT	1
522549	521402	19675J	PARTICIPANT	\N	PRESENT	1
522863	522862	20094J	PARTICIPANT	\N	PRESENT	0
522864	522862	04070G	PARTICIPANT	\N	PRESENT	0
524288	524287	05008E	PARTICIPANT	\N	PRESENT	0
524289	524287	11053K	PARTICIPANT	\N	PRESENT	0
524290	524287	01028R	PARTICIPANT	\N	PRESENT	0
525031	524096	19760E	PARTICIPANT	\N	PRESENT	0
525032	524096	20090E	PARTICIPANT	\N	PRESENT	0
525033	524096	10006L	PRESIDENT	0	PRESENT	0
525034	524096	20040T	PARTICIPANT	\N	PRESENT	0
525035	524096	19691J	PARTICIPANT	\N	PRESENT	1
525036	524096	19569H	PARTICIPANT	\N	PRESENT	1
525037	524096	14213J	PARTICIPANT	\N	PRESENT	0
525038	524096	20066E	PARTICIPANT	\N	PRESENT	0
525039	524096	18193Q	PARTICIPANT	\N	PRESENT	0
525040	524096	14071N	PARTICIPANT	\N	PRESENT	0
525041	524096	20130U	PARTICIPANT	\N	PRESENT	1
525042	524096	04043D	PARTICIPANT	\N	PRESENT	1
525043	524096	19679N	PARTICIPANT	\N	PRESENT	0
525044	524096	19713W	PARTICIPANT	\N	PRESENT	0
525045	524096	01034P	PARTICIPANT	\N	PRESENT	1
525046	524096	19703U	PARTICIPANT	\N	PRESENT	0
525047	524096	19301E	PARTICIPANT	\N	PRESENT	1
525048	524096	20172F	PARTICIPANT	\N	PRESENT	1
525049	524096	14223L	PARTICIPANT	\N	PRESENT	0
525052	524096	19717B	PARTICIPANT	\N	PRESENT	1
525053	524096	11103C	PARTICIPANT	\N	PRESENT	1
525054	524096	04057K	PARTICIPANT	\N	PRESENT	1
525055	524096	17779H	PARTICIPANT	\N	PRESENT	0
525056	524096	17965H	PARTICIPANT	\N	PRESENT	1
525117	524096	08045X	PARTICIPANT	\N	PRESENT	0
525136	524096	14217N	PARTICIPANT	\N	PRESENT	1
526560	526559	14327T	PARTICIPANT	\N	PRESENT	0
526564	526563	14327T	PARTICIPANT	\N	PRESENT	0
526634	526633	08011M	PARTICIPANT	\N	PRESENT	0
526636	526635	08011M	PARTICIPANT	\N	PRESENT	0
526638	526637	08011M	PARTICIPANT	\N	PRESENT	0
526640	526639	08011M	PARTICIPANT	\N	PRESENT	0
526642	526641	08011M	PARTICIPANT	\N	PRESENT	0
526644	526643	08011M	PARTICIPANT	\N	PRESENT	0
527934	527931	19629C	PARTICIPANT	\N	PRESENT	0
527937	527931	14083S	PARTICIPANT	\N	PRESENT	0
527942	527931	19631V	PARTICIPANT	\N	PRESENT	0
527944	527931	19549D	PARTICIPANT	\N	PRESENT	0
527946	527931	20064C	PARTICIPANT	\N	PRESENT	0
527949	527931	20116W	PARTICIPANT	\N	PRESENT	0
527950	527931	04045F	PARTICIPANT	\N	PRESENT	0
527952	527931	20106U	PARTICIPANT	\N	PRESENT	0
527953	527931	08056B	PARTICIPANT	\N	PRESENT	0
527954	527931	20120S	PARTICIPANT	\N	PRESENT	0
527955	527931	14329V	PARTICIPANT	\N	PRESENT	0
527956	527931	11031D	PARTICIPANT	\N	PRESENT	0
527957	527931	20090E	PARTICIPANT	\N	PRESENT	0
527962	527931	12041X	PARTICIPANT	\N	PRESENT	0
533950	531098	20022R	PARTICIPANT	\N	EXCUSE	0
534224	534223	04070G	PARTICIPANT	\N	PRESENT	0
534226	534097	19745F	PARTICIPANT	\N	PRESENT	0
534227	534097	19369B	PARTICIPANT	\N	PRESENT	0
534496	534252	19531S	PARTICIPANT	\N	PRESENT	0
534497	534252	18083K	PARTICIPANT	\N	PRESENT	0
534498	534252	17779H	PARTICIPANT	\N	PRESENT	0
534499	534252	19507S	PARTICIPANT	\N	PRESENT	0
534500	534252	14123H	PARTICIPANT	\N	PRESENT	0
534501	534252	20126Y	PARTICIPANT	\N	PRESENT	0
534557	534253	20046A	PARTICIPANT	\N	PRESENT	0
534558	534253	19758L	PARTICIPANT	\N	PRESENT	0
534559	534253	19687N	PARTICIPANT	\N	PRESENT	0
534560	534253	19549D	PARTICIPANT	\N	PRESENT	0
534561	534253	20070A	PARTICIPANT	\N	PRESENT	0
534562	534253	19531S	PARTICIPANT	\N	PRESENT	0
534563	534253	19333N	PARTICIPANT	\N	PRESENT	0
534564	534253	14109K	PARTICIPANT	\N	PRESENT	0
534565	534253	19689Q	PARTICIPANT	\N	PRESENT	0
534566	534253	19782L	PARTICIPANT	\N	PRESENT	0
534568	534253	20174H	PARTICIPANT	\N	PRESENT	0
534569	534253	11067R	PARTICIPANT	\N	PRESENT	0
534570	534253	20080C	PARTICIPANT	\N	PRESENT	0
534581	534253	11083R	PARTICIPANT	\N	PRESENT	0
534572	534253	17589D	PARTICIPANT	\N	PRESENT	0
534573	534253	19387D	PARTICIPANT	\N	PRESENT	0
534574	534253	14207L	PARTICIPANT	\N	PRESENT	0
534576	534253	20132W	PARTICIPANT	\N	PRESENT	0
534579	534253	19349W	PARTICIPANT	\N	PRESENT	0
534584	534253	19651A	PARTICIPANT	\N	PRESENT	0
534586	534253	08061X	PARTICIPANT	\N	PRESENT	0
534588	534253	01025N	PARTICIPANT	\N	PRESENT	0
534590	534253	19739H	PARTICIPANT	\N	PRESENT	0
534591	534253	14225N	PARTICIPANT	\N	PRESENT	0
534592	534253	07004J	PARTICIPANT	\N	PRESENT	0
534593	534253	01024M	PARTICIPANT	\N	PRESENT	0
534594	534253	20148F	PARTICIPANT	\N	PRESENT	0
534595	534253	14189C	PARTICIPANT	\N	PRESENT	0
534596	534253	19671E	PARTICIPANT	\N	PRESENT	0
534597	534253	20126Y	PARTICIPANT	\N	PRESENT	0
534598	534253	19415P	PARTICIPANT	\N	PRESENT	0
534599	534253	20112S	PARTICIPANT	\N	PRESENT	0
534600	534253	20088L	PARTICIPANT	\N	PRESENT	0
534601	534253	11077T	PARTICIPANT	\N	PRESENT	0
534604	534253	19683J	PARTICIPANT	\N	PRESENT	0
534606	534253	14083S	PARTICIPANT	\N	PRESENT	0
534607	534253	20090E	PARTICIPANT	\N	PRESENT	0
534608	534253	19545Y	PARTICIPANT	\N	PRESENT	0
534609	534253	11103C	PARTICIPANT	\N	PRESENT	0
534610	534253	97011G	PARTICIPANT	\N	PRESENT	0
534611	534253	19711U	PARTICIPANT	\N	PRESENT	0
534612	534253	99004R	PARTICIPANT	\N	PRESENT	0
534613	534253	01058X	PARTICIPANT	\N	PRESENT	0
534614	534253	14123H	PARTICIPANT	\N	PRESENT	0
534615	534253	20022R	PARTICIPANT	\N	PRESENT	0
534616	534253	11048N	PARTICIPANT	\N	PRESENT	0
534617	534253	14147R	PARTICIPANT	\N	PRESENT	0
534618	534253	19441R	PARTICIPANT	\N	PRESENT	0
534619	534253	20024T	PARTICIPANT	\N	PRESENT	0
534620	534253	20062A	PARTICIPANT	\N	PRESENT	0
534621	534253	19507S	PARTICIPANT	\N	PRESENT	0
534623	534253	20076G	PARTICIPANT	\N	PRESENT	0
534624	534253	20044X	PARTICIPANT	\N	PRESENT	0
534555	534253	14026U	PARTICIPANT	\N	PRESENT	0
534556	534253	19741B	PARTICIPANT	\N	PRESENT	0
534625	534253	19467C	PARTICIPANT	\N	PRESENT	0
534626	534253	20180F	PARTICIPANT	\N	PRESENT	0
534627	534253	19447X	PARTICIPANT	\N	PRESENT	0
534628	534253	14031R	PARTICIPANT	\N	PRESENT	0
534629	534253	20032T	PARTICIPANT	\N	PRESENT	0
534630	534253	19954N	PARTICIPANT	\N	PRESENT	0
529907	529229	19782L	PARTICIPANT	\N	PRESENT	1
529908	529229	01043Q	PARTICIPANT	\N	PRESENT	0
529909	529229	14357A	PARTICIPANT	\N	PRESENT	0
529910	529229	19441R	PARTICIPANT	\N	PRESENT	1
529911	529229	20082E	PARTICIPANT	\N	PRESENT	0
529912	529229	20094J	PARTICIPANT	\N	PRESENT	0
529913	529229	19866P	PARTICIPANT	\N	PRESENT	1
529914	529229	20104S	PARTICIPANT	\N	PRESENT	1
529915	529229	11099A	PARTICIPANT	\N	PRESENT	1
529916	529229	19705W	PARTICIPANT	\N	PRESENT	0
529917	529229	08015R	PARTICIPANT	\N	PRESENT	0
529918	529229	19575F	PARTICIPANT	\N	PRESENT	0
529919	529229	19369B	PARTICIPANT	\N	PRESENT	1
529920	529229	20018V	PARTICIPANT	\N	PRESENT	0
529921	529229	19511N	PARTICIPANT	\N	PRESENT	0
529922	529229	19563B	PARTICIPANT	\N	PRESENT	0
529923	529229	19521Q	PARTICIPANT	\N	PRESENT	1
529924	529229	20028X	PARTICIPANT	\N	PRESENT	0
529925	529229	14038Y	PARTICIPANT	\N	PRESENT	1
529926	529229	20030R	PARTICIPANT	\N	PRESENT	1
529927	529229	19467C	PARTICIPANT	\N	PRESENT	0
529928	529229	20034V	PARTICIPANT	\N	PRESENT	1
529929	529229	14187A	PARTICIPANT	\N	PRESENT	0
529930	529229	20144B	PARTICIPANT	\N	PRESENT	0
529931	529229	19695N	PARTICIPANT	\N	PRESENT	0
529932	529229	14033T	PARTICIPANT	\N	PRESENT	0
529933	529229	11090Q	PRESIDENT	0	PRESENT	0
529934	529229	01025N	PARTICIPANT	\N	PRESENT	1
529935	529229	20054A	PARTICIPANT	\N	PRESENT	0
529936	529229	14205J	PARTICIPANT	\N	PRESENT	0
529937	529229	20060X	PARTICIPANT	\N	PRESENT	1
529938	529229	20062A	PARTICIPANT	\N	PRESENT	0
529939	529229	19747H	PARTICIPANT	\N	PRESENT	0
529940	529229	14207L	PARTICIPANT	\N	PRESENT	0
529941	529229	14257W	PARTICIPANT	\N	PRESENT	0
529942	529002	14089Y	PARTICIPANT	\N	PRESENT	0
529943	529002	19489J	PARTICIPANT	\N	PRESENT	0
529944	529229	19383Y	PARTICIPANT	\N	PRESENT	0
529945	529229	04045F	PARTICIPANT	\N	PRESENT	1
529947	529002	19585H	PARTICIPANT	\N	PRESENT	0
529948	529002	17737W	PARTICIPANT	\N	PRESENT	0
529976	529229	19507S	PARTICIPANT	\N	PRESENT	0
529977	529002	11026G	PARTICIPANT	\N	PRESENT	0
529978	529002	95063L	PARTICIPANT	\N	PRESENT	0
529979	529002	14021P	PARTICIPANT	\N	PRESENT	0
529982	529081	86034E	PARTICIPANT	\N	PRESENT	0
529991	529229	14251Q	PARTICIPANT	\N	PRESENT	1
530005	529013	11067R	PARTICIPANT	\N	PRESENT	0
530006	529013	20090E	PARTICIPANT	\N	PRESENT	0
530007	529013	19569H	PARTICIPANT	\N	PRESENT	0
530008	529013	19798U	PARTICIPANT	\N	PRESENT	1
530009	529013	11097X	PARTICIPANT	\N	PRESENT	1
530010	529013	19415P	PARTICIPANT	\N	PRESENT	0
530011	529013	18193Q	PARTICIPANT	\N	PRESENT	0
530012	529013	14223L	PARTICIPANT	\N	PRESENT	0
530013	529013	14026U	PARTICIPANT	\N	PRESENT	1
530014	529013	17779H	PARTICIPANT	\N	PRESENT	0
530015	529013	19703U	PARTICIPANT	\N	PRESENT	0
530016	529013	11031D	PARTICIPANT	\N	PRESENT	0
530017	529013	19553Y	PARTICIPANT	\N	PRESENT	1
530018	529013	19679N	PARTICIPANT	\N	PRESENT	0
530019	529013	14042U	PARTICIPANT	\N	PRESENT	0
530020	529013	14213J	PARTICIPANT	\N	PRESENT	0
530021	529013	19683J	PARTICIPANT	\N	PRESENT	0
530022	529013	10006L	PRESIDENT	0	PRESENT	0
530023	529013	20130U	PARTICIPANT	\N	PRESENT	0
530024	529013	04092N	PARTICIPANT	\N	PRESENT	0
530025	529013	19713W	PARTICIPANT	\N	PRESENT	0
530026	529013	19301E	PARTICIPANT	\N	PRESENT	1
530027	529013	17965H	PARTICIPANT	\N	PRESENT	1
530028	529013	19715Y	PARTICIPANT	\N	PRESENT	0
530029	529013	19691J	PARTICIPANT	\N	PRESENT	0
530030	529013	20148F	PARTICIPANT	\N	PRESENT	0
530031	529013	20172F	PARTICIPANT	\N	PRESENT	1
530032	529013	19723Y	PARTICIPANT	\N	PRESENT	0
530033	529013	20066E	PARTICIPANT	\N	PRESENT	1
530034	529013	11103C	PARTICIPANT	\N	PRESENT	1
530035	529013	14071N	PARTICIPANT	\N	PRESENT	0
530036	529013	04043D	PARTICIPANT	\N	PRESENT	0
530037	529013	19760E	PARTICIPANT	\N	PRESENT	0
530038	529013	04057K	PARTICIPANT	\N	PRESENT	0
530044	529002	04047H	PRESIDENT	1	PRESENT	0
530045	529002	19447X	PARTICIPANT	\N	PRESENT	0
530066	529004	19443T	PARTICIPANT	\N	PRESENT	0
530067	529004	12041X	PARTICIPANT	\N	PRESENT	0
530068	529004	19565D	PARTICIPANT	\N	PRESENT	1
530069	529004	20072C	PARTICIPANT	\N	PRESENT	1
530070	529004	04034C	PARTICIPANT	\N	PRESENT	0
530071	529004	01058X	PARTICIPANT	\N	PRESENT	1
530072	529004	11027H	PARTICIPANT	\N	PRESENT	1
530073	529004	11054L	PARTICIPANT	\N	PRESENT	0
530074	529004	12028B	PARTICIPANT	\N	PRESENT	1
530075	529004	19421M	PARTICIPANT	\N	PRESENT	1
530076	529004	19709B	PARTICIPANT	\N	PRESENT	0
530077	529004	19347U	PARTICIPANT	\N	PRESENT	0
530078	529004	97011G	PARTICIPANT	\N	PRESENT	0
530079	529004	08047A	PARTICIPANT	\N	PRESENT	0
530080	529004	20128B	PARTICIPANT	\N	PRESENT	1
530081	529004	14097Y	PARTICIPANT	\N	PRESENT	0
530082	529004	04035D	PARTICIPANT	\N	PRESENT	0
530083	529004	14133K	PRESIDENT	0	PRESENT	0
530084	529004	01062T	PARTICIPANT	\N	PRESENT	0
530085	529004	20042V	PARTICIPANT	\N	PRESENT	0
530086	529004	01024M	PARTICIPANT	\N	PRESENT	0
530087	529004	14105F	PARTICIPANT	\N	PRESENT	1
530088	529004	20064C	PARTICIPANT	\N	PRESENT	0
530089	529004	98022P	PARTICIPANT	\N	PRESENT	0
530090	529004	14267Y	PARTICIPANT	\N	PRESENT	0
530091	529004	11064N	PARTICIPANT	\N	PRESENT	0
530092	529004	11083R	PARTICIPANT	\N	PRESENT	0
530093	529004	14211G	PARTICIPANT	\N	PRESENT	0
530094	529004	14255U	PARTICIPANT	\N	PRESENT	1
530096	529004	11066Q	PARTICIPANT	\N	EXCUSE	0
530110	529004	16685X	PARTICIPANT	\N	PRESENT	0
530114	530112	04035D	PARTICIPANT	\N	PRESENT	0
530115	530112	98022P	PARTICIPANT	\N	PRESENT	0
530127	528657	11053K	PARTICIPANT	\N	PRESENT	0
530128	528657	08010L	PARTICIPANT	\N	PRESENT	0
530129	528657	20126Y	PARTICIPANT	\N	PRESENT	0
530130	528657	19647E	PARTICIPANT	\N	PRESENT	0
530131	528657	19711U	PARTICIPANT	\N	PRESENT	0
530132	528657	08034U	PARTICIPANT	\N	PRESENT	0
530133	528657	20044X	PARTICIPANT	\N	PRESENT	0
530134	528657	14121F	PARTICIPANT	\N	PRESENT	0
530135	528657	19762G	PARTICIPANT	\N	PRESENT	0
530136	529003	11026G	PARTICIPANT	\N	PRESENT	0
530137	529003	19585H	PARTICIPANT	\N	PRESENT	0
530138	529003	04047H	PRESIDENT	0	PRESENT	0
530139	529003	19673G	PARTICIPANT	\N	PRESENT	0
530140	529003	01028R	PARTICIPANT	\N	PRESENT	0
530141	529003	19954N	PARTICIPANT	\N	PRESENT	0
530142	529003	11056N	PARTICIPANT	\N	PRESENT	0
530143	529003	17737W	PARTICIPANT	\N	PRESENT	0
530144	529003	95063L	PARTICIPANT	\N	PRESENT	0
530145	529003	20108W	PARTICIPANT	\N	PRESENT	0
530147	529003	08018U	PARTICIPANT	\N	PRESENT	0
530148	529003	19749K	PARTICIPANT	\N	PRESENT	0
530149	528964	19333N	PARTICIPANT	\N	PRESENT	0
530150	528964	19549D	PARTICIPANT	\N	PRESENT	0
530151	528964	19387D	PARTICIPANT	\N	PRESENT	0
530152	528964	19820Y	PARTICIPANT	\N	PRESENT	0
530153	528964	14219Q	PRESIDENT	0	PRESENT	0
530154	528964	19826F	PARTICIPANT	\N	PRESENT	0
530155	528964	19599P	PARTICIPANT	\N	PRESENT	0
530156	528964	20102Q	PARTICIPANT	\N	PRESENT	0
530157	528964	20096L	PARTICIPANT	\N	PRESENT	0
530158	528964	19637C	PARTICIPANT	\N	PRESENT	0
530159	528964	18083K	PARTICIPANT	\N	PRESENT	0
530160	528964	19551W	PARTICIPANT	\N	PRESENT	0
530161	528964	20100N	PARTICIPANT	\N	PRESENT	0
530162	528964	05012A	PARTICIPANT	\N	PRESENT	0
530163	528964	20118Y	PARTICIPANT	\N	PRESENT	0
530164	528964	19503N	PARTICIPANT	\N	PRESENT	0
530165	528964	17367Q	PARTICIPANT	\N	PRESENT	0
530166	528964	20024T	PARTICIPANT	\N	PRESENT	0
530167	528964	20032T	PARTICIPANT	\N	PRESENT	0
530168	528964	20136B	PARTICIPANT	\N	PRESENT	0
530169	528964	20038A	PARTICIPANT	\N	PRESENT	0
530170	528964	14031R	PARTICIPANT	\N	PRESENT	0
514119	514118	20032T	PARTICIPANT	\N	PRESENT	0
514120	514118	19741B	PARTICIPANT	\N	PRESENT	0
514121	514118	20024T	PARTICIPANT	\N	PRESENT	0
514122	514118	20080C	PARTICIPANT	\N	PRESENT	0
514123	514118	14083S	PARTICIPANT	\N	PRESENT	0
514124	514118	12016W	PARTICIPANT	\N	PRESENT	0
514125	514118	14225N	PARTICIPANT	\N	PRESENT	0
514126	514118	19619A	PARTICIPANT	\N	PRESENT	0
515448	515440	19723Y	PARTICIPANT	\N	PRESENT	0
515449	515440	19735D	PARTICIPANT	\N	PRESENT	0
515451	515440	01058X	PARTICIPANT	\N	PRESENT	0
515754	515440	19563B	PARTICIPANT	\N	EXCUSE	0
515752	515440	01048V	PARTICIPANT	\N	EXCUSE	0
515753	515440	11067R	PARTICIPANT	\N	EXCUSE	0
515755	515440	19693L	PARTICIPANT	\N	EXCUSE	0
517724	517467	19593H	PARTICIPANT	\N	PRESENT	0
517725	517467	20132W	PARTICIPANT	\N	PRESENT	0
517726	517467	20134Y	PARTICIPANT	\N	PRESENT	0
517727	517467	14073Q	PARTICIPANT	\N	PRESENT	0
517728	517467	19611R	PRESIDENT	0	PRESENT	0
517729	517467	19399H	PARTICIPANT	\N	PRESENT	0
517730	517467	20052X	PARTICIPANT	\N	PRESENT	0
517731	517467	20152B	PARTICIPANT	\N	PRESENT	0
517732	517467	20058E	PARTICIPANT	\N	PRESENT	0
517733	517467	20056C	PARTICIPANT	\N	PRESENT	0
517734	517467	20180F	PARTICIPANT	\N	PRESENT	0
517790	517788	08056B	PARTICIPANT	\N	PRESENT	0
517736	517467	11043H	PARTICIPANT	\N	PRESENT	0
517737	517467	11104D	PARTICIPANT	\N	PRESENT	0
517738	517467	19758L	PARTICIPANT	\N	PRESENT	0
517739	517467	19621T	PARTICIPANT	\N	PRESENT	0
517740	516755	04086Q	PARTICIPANT	\N	PRESENT	0
517789	517788	08045X	PARTICIPANT	\N	PRESENT	0
517791	517788	19551W	PARTICIPANT	\N	PRESENT	0
517792	517788	20056C	PARTICIPANT	\N	PRESENT	0
517793	517788	14205J	PARTICIPANT	\N	PRESENT	0
517795	517788	20130U	PARTICIPANT	\N	PRESENT	0
517796	517788	20092G	PARTICIPANT	\N	PRESENT	0
517797	517788	19689Q	PARTICIPANT	\N	PRESENT	0
519132	519131	14053L	PARTICIPANT	\N	PRESENT	0
519133	519131	11033F	PARTICIPANT	\N	PRESENT	0
519134	519131	19749K	PARTICIPANT	\N	PRESENT	0
520125	520007	19573D	PARTICIPANT	\N	PRESENT	0
520126	520007	92040Q	PARTICIPANT	\N	PRESENT	0
520127	520007	14109K	PARTICIPANT	\N	PRESENT	0
520128	520007	14123H	PARTICIPANT	\N	PRESENT	0
520129	520007	08061X	PARTICIPANT	\N	PRESENT	0
520130	520007	11104D	PARTICIPANT	\N	PRESENT	0
520131	520007	19758L	PARTICIPANT	\N	PRESENT	0
520132	520007	20026V	PARTICIPANT	\N	PRESENT	0
520133	520007	20084G	PARTICIPANT	\N	PRESENT	0
520139	519230	14059S	PARTICIPANT	\N	PRESENT	0
520140	520007	19527W	PARTICIPANT	\N	PRESENT	0
520143	520007	04070G	PARTICIPANT	\N	PRESENT	1
520144	520007	20098N	PARTICIPANT	\N	PRESENT	1
520145	520007	20134Y	PARTICIPANT	\N	PRESENT	1
520146	520007	19651A	PARTICIPANT	\N	PRESENT	1
520147	520007	20138D	PARTICIPANT	\N	PRESENT	1
520148	520007	20048C	PARTICIPANT	\N	PRESENT	1
520149	520007	19719D	PARTICIPANT	\N	PRESENT	1
520150	520007	19735D	PARTICIPANT	\N	PRESENT	1
520151	519287	11048N	PARTICIPANT	\N	PRESENT	0
520152	519287	19687N	PARTICIPANT	\N	PRESENT	0
520153	519287	20080C	PARTICIPANT	\N	PRESENT	0
520155	519287	20044X	PARTICIPANT	\N	PRESENT	0
520156	519287	14225N	PRESIDENT	0	PRESENT	0
520157	519287	11070L	PARTICIPANT	\N	PRESENT	0
520158	519287	11040E	PARTICIPANT	\N	PRESENT	0
520159	519287	04086Q	PARTICIPANT	\N	PRESENT	0
520160	519287	20070A	PARTICIPANT	\N	PRESENT	0
520161	519287	08009T	PARTICIPANT	\N	PRESENT	0
520162	519287	19349W	PARTICIPANT	\N	PRESENT	0
520163	519287	19741B	PARTICIPANT	\N	PRESENT	0
520164	519287	99004R	PARTICIPANT	\N	PRESENT	0
520165	519287	19335Q	PARTICIPANT	\N	PRESENT	0
520166	519287	20022R	PARTICIPANT	\N	PRESENT	0
520167	519287	14327T	PARTICIPANT	\N	EXCUSE	0
520168	519287	08034U	PARTICIPANT	\N	EXCUSE	0
520169	519287	20116W	PARTICIPANT	\N	EXCUSE	0
520170	519230	19565D	PARTICIPANT	\N	PRESENT	0
520171	519230	01024M	PARTICIPANT	\N	PRESENT	0
520172	519230	20072C	PARTICIPANT	\N	PRESENT	1
520173	519162	20086J	PARTICIPANT	\N	PRESENT	0
520174	519162	19768N	PARTICIPANT	\N	PRESENT	0
520175	519162	20092G	PARTICIPANT	\N	PRESENT	0
520176	519162	19782L	PARTICIPANT	\N	PRESENT	0
520177	519162	20078J	PARTICIPANT	\N	PRESENT	0
520178	519162	19441R	PARTICIPANT	\N	PRESENT	0
520179	519162	19413M	PARTICIPANT	\N	PRESENT	0
520180	519162	20082E	PARTICIPANT	\N	PRESENT	0
520181	519162	20094J	PARTICIPANT	\N	PRESENT	0
520182	519162	04045F	PARTICIPANT	\N	PRESENT	0
520183	519162	19631V	PARTICIPANT	\N	PRESENT	0
520184	519162	11099A	PARTICIPANT	\N	PRESENT	0
520185	519162	19705W	PARTICIPANT	\N	PRESENT	0
520186	519162	08015R	PARTICIPANT	\N	PRESENT	0
520187	519162	19575F	PARTICIPANT	\N	PRESENT	0
520188	519162	19369B	PARTICIPANT	\N	PRESENT	0
520189	519162	08028W	PARTICIPANT	\N	PRESENT	0
520190	519162	19563B	PARTICIPANT	\N	PRESENT	0
520191	519162	20028X	PARTICIPANT	\N	PRESENT	1
520192	519162	19467C	PARTICIPANT	\N	PRESENT	0
520193	519162	14187A	PARTICIPANT	\N	PRESENT	0
520194	519162	19695N	PARTICIPANT	\N	PRESENT	0
520195	519162	11090Q	PRESIDENT	0	PRESENT	0
520196	519162	20054A	PARTICIPANT	\N	PRESENT	1
520197	519162	20174H	PARTICIPANT	\N	PRESENT	0
520198	519162	14205J	PARTICIPANT	\N	PRESENT	0
520199	519162	20062A	PARTICIPANT	\N	PRESENT	1
520200	519162	19507S	PARTICIPANT	\N	PRESENT	0
520201	519162	19747H	PARTICIPANT	\N	PRESENT	1
520202	519162	14207L	PARTICIPANT	\N	PRESENT	0
520203	519162	14257W	PARTICIPANT	\N	PRESENT	0
520204	519230	19421M	PARTICIPANT	\N	PRESENT	1
520205	520007	19643A	PARTICIPANT	\N	PRESENT	1
520206	520007	20124W	PARTICIPANT	\N	PRESENT	0
520208	520007	19621T	PARTICIPANT	\N	PRESENT	0
520210	519287	19531S	PARTICIPANT	\N	PRESENT	0
520211	519287	01057W	PARTICIPANT	\N	PRESENT	0
520212	519287	19689Q	PARTICIPANT	\N	PRESENT	0
520213	519287	11053K	PARTICIPANT	\N	PRESENT	0
520214	519287	19671E	PARTICIPANT	\N	PRESENT	0
520215	519287	14083S	PARTICIPANT	\N	PRESENT	0
520216	519287	07029T	PARTICIPANT	\N	PRESENT	0
520217	519287	19762G	PARTICIPANT	\N	PRESENT	0
520218	519287	14189C	PARTICIPANT	\N	PRESENT	0
520222	519304	19333N	PARTICIPANT	\N	PRESENT	0
520223	519304	19701S	PARTICIPANT	\N	PRESENT	0
520224	519304	20076G	PARTICIPANT	\N	PRESENT	0
520225	519304	19549D	PARTICIPANT	\N	PRESENT	0
520226	519304	19387D	PARTICIPANT	\N	PRESENT	0
520227	519304	19820Y	PARTICIPANT	\N	PRESENT	0
520228	519304	14219Q	PRESIDENT	0	PRESENT	0
520229	519304	19826F	PARTICIPANT	\N	PRESENT	0
520230	519304	14221J	PARTICIPANT	\N	PRESENT	0
520231	519304	19599P	PARTICIPANT	\N	PRESENT	0
520232	519304	20096L	PARTICIPANT	\N	PRESENT	0
520233	519304	19637C	PARTICIPANT	\N	PRESENT	0
520234	519304	18083K	PARTICIPANT	\N	PRESENT	0
520235	519304	20100N	PARTICIPANT	\N	PRESENT	0
520236	519304	14237S	PARTICIPANT	\N	PRESENT	0
520237	519304	05012A	PARTICIPANT	\N	PRESENT	0
520238	519304	20106U	PARTICIPANT	\N	PRESENT	0
520239	519304	20118Y	PARTICIPANT	\N	PRESENT	0
520240	519304	19503N	PARTICIPANT	\N	PRESENT	0
520241	519304	20020P	PARTICIPANT	\N	PRESENT	1
520242	519304	20024T	PARTICIPANT	\N	PRESENT	0
520243	519304	11065P	PARTICIPANT	\N	PRESENT	0
520244	519304	20120S	PARTICIPANT	\N	PRESENT	1
520245	519304	20032T	PARTICIPANT	\N	PRESENT	0
520246	519304	14031R	PARTICIPANT	\N	PRESENT	0
520247	519304	20140W	PARTICIPANT	\N	PRESENT	1
520248	519304	20046A	PARTICIPANT	\N	PRESENT	0
520249	519304	20068G	PARTICIPANT	\N	PRESENT	0
520250	519304	11101A	PARTICIPANT	\N	PRESENT	0
520251	519304	19739H	PARTICIPANT	\N	PRESENT	0
520252	519304	19619A	PARTICIPANT	\N	PRESENT	0
520253	519304	08060W	PARTICIPANT	\N	EXCUSE	0
525929	525928	16685X	PARTICIPANT	\N	PRESENT	0
525930	524119	20038A	PARTICIPANT	\N	PRESENT	0
525931	524119	11053K	PARTICIPANT	\N	PRESENT	0
525932	524119	14033T	PARTICIPANT	\N	PRESENT	0
525933	524119	14083S	PARTICIPANT	\N	PRESENT	0
526007	524121	05008E	PARTICIPANT	\N	PRESENT	0
526008	524121	19565D	PARTICIPANT	\N	PRESENT	0
526009	524121	01028R	PARTICIPANT	\N	PRESENT	0
526010	524121	19347U	PARTICIPANT	\N	PRESENT	0
526011	524121	20100N	PARTICIPANT	\N	PRESENT	0
526012	524121	11033F	PARTICIPANT	\N	PRESENT	0
526013	524121	14151M	PARTICIPANT	\N	PRESENT	0
526014	524121	19649G	PARTICIPANT	\N	PRESENT	0
526015	524121	19695N	PARTICIPANT	\N	PRESENT	0
526016	524121	19866P	PARTICIPANT	\N	PRESENT	0
526017	524121	19629C	PARTICIPANT	\N	PRESENT	0
526018	524121	19749K	PARTICIPANT	\N	PRESENT	0
526019	524121	20052X	PARTICIPANT	\N	PRESENT	0
526020	524121	14215L	PARTICIPANT	\N	PRESENT	0
526021	524121	19747H	PARTICIPANT	\N	PRESENT	0
526022	524121	20048C	PARTICIPANT	\N	PRESENT	0
526023	524121	20090E	PARTICIPANT	\N	PRESENT	0
526024	524121	20024T	PARTICIPANT	\N	PRESENT	0
526025	524121	20026V	PARTICIPANT	\N	PRESENT	0
526026	524121	14071N	PARTICIPANT	\N	PRESENT	0
526027	524121	20034V	PARTICIPANT	\N	PRESENT	0
526028	524121	20038A	PARTICIPANT	\N	PRESENT	0
526029	524121	11072N	PARTICIPANT	\N	PRESENT	0
526030	524121	19725B	PARTICIPANT	\N	PRESENT	0
526031	524121	14033T	PARTICIPANT	\N	PRESENT	0
526032	524121	20150Y	PARTICIPANT	\N	PRESENT	0
526033	524121	19691J	PARTICIPANT	\N	PRESENT	0
526034	524121	14089Y	PARTICIPANT	\N	PRESENT	0
526035	524121	14231L	PARTICIPANT	\N	PRESENT	0
526036	524121	20044X	PARTICIPANT	\N	PRESENT	0
526037	524121	19447X	PARTICIPANT	\N	PRESENT	0
526038	524121	19621T	PARTICIPANT	\N	PRESENT	0
526039	524121	19760E	PARTICIPANT	\N	PRESENT	0
526040	524121	04085P	PARTICIPANT	\N	PRESENT	0
526041	524121	20094J	PARTICIPANT	\N	PRESENT	0
526042	524121	14189C	PARTICIPANT	\N	PRESENT	0
526043	524121	14053L	PARTICIPANT	\N	PRESENT	0
526044	524121	95063L	PARTICIPANT	\N	PRESENT	0
526045	524121	14217N	PARTICIPANT	\N	PRESENT	0
526046	524121	14147R	PARTICIPANT	\N	PRESENT	0
526047	524121	11064N	PARTICIPANT	\N	PRESENT	0
526048	524121	14251Q	PARTICIPANT	\N	PRESENT	0
526049	524121	11026G	PARTICIPANT	\N	PRESENT	0
526050	524121	14357A	PARTICIPANT	\N	PRESENT	0
526051	524121	04045F	PARTICIPANT	\N	PRESENT	0
526052	524121	14179A	PARTICIPANT	\N	PRESENT	0
526053	524121	14097Y	PARTICIPANT	\N	PRESENT	0
526054	524121	19531S	PARTICIPANT	\N	PRESENT	0
526055	524121	14026U	PARTICIPANT	\N	PRESENT	0
526108	524122	14053L	PARTICIPANT	\N	PRESENT	0
526109	524122	19565D	PARTICIPANT	\N	PRESENT	0
526110	524122	14151M	PARTICIPANT	\N	PRESENT	0
526111	524122	01028R	PARTICIPANT	\N	PRESENT	0
526112	524122	11033F	PARTICIPANT	\N	PRESENT	0
526113	524122	19347U	PARTICIPANT	\N	PRESENT	0
526114	524122	19725B	PARTICIPANT	\N	PRESENT	0
526115	524122	19531S	PARTICIPANT	\N	PRESENT	0
526116	524122	20094J	PARTICIPANT	\N	PRESENT	0
526117	524122	19629C	PARTICIPANT	\N	PRESENT	0
526118	524122	19866P	PARTICIPANT	\N	PRESENT	0
526119	524122	14231L	PARTICIPANT	\N	PRESENT	0
526120	524122	19749K	PARTICIPANT	\N	PRESENT	0
525927	525926	16685X	PARTICIPANT	\N	PRESENT	0
526121	524122	14189C	PARTICIPANT	\N	PRESENT	0
526122	524122	14215L	PARTICIPANT	\N	PRESENT	0
526123	524122	19747H	PARTICIPANT	\N	PRESENT	0
526124	524122	04045F	PARTICIPANT	\N	PRESENT	0
526125	524122	20038A	PARTICIPANT	\N	PRESENT	0
526126	524122	20034V	PARTICIPANT	\N	PRESENT	0
526127	524122	20026V	PARTICIPANT	\N	PRESENT	0
526128	524122	20044X	PARTICIPANT	\N	PRESENT	0
526129	524122	19447X	PARTICIPANT	\N	PRESENT	0
526005	524121	19719D	PARTICIPANT	\N	PRESENT	0
526006	524121	04047H	PARTICIPANT	\N	PRESENT	0
526130	524122	14147R	PARTICIPANT	\N	PRESENT	0
526131	524122	20024T	PARTICIPANT	\N	PRESENT	0
526132	524122	14357A	PARTICIPANT	\N	PRESENT	0
526133	524122	14213J	PARTICIPANT	\N	PRESENT	0
526134	524122	20090E	PARTICIPANT	\N	PRESENT	0
526135	524122	14033T	PARTICIPANT	\N	PRESENT	0
526136	524122	19621T	PARTICIPANT	\N	PRESENT	0
526137	524122	14097Y	PARTICIPANT	\N	PRESENT	0
526138	524122	19649G	PARTICIPANT	\N	PRESENT	0
526139	524122	04085P	PARTICIPANT	\N	PRESENT	0
526140	524122	14179A	PARTICIPANT	\N	PRESENT	0
526141	524122	05008E	PARTICIPANT	\N	PRESENT	0
526142	524122	17737W	PARTICIPANT	\N	PRESENT	0
526143	524122	19760E	PARTICIPANT	\N	PRESENT	0
526144	524122	14026U	PARTICIPANT	\N	PRESENT	0
526145	524122	19695N	PARTICIPANT	\N	PRESENT	0
526146	524122	19553Y	PARTICIPANT	\N	PRESENT	0
526147	524122	11064N	PARTICIPANT	\N	PRESENT	0
526148	524122	14187A	PARTICIPANT	\N	PRESENT	0
526149	524122	11056N	PARTICIPANT	\N	PRESENT	0
526150	524122	20126Y	PARTICIPANT	\N	PRESENT	0
526151	524122	20054A	PARTICIPANT	\N	PRESENT	0
526152	524122	11072N	PARTICIPANT	\N	PRESENT	0
526153	524122	20058E	PARTICIPANT	\N	PRESENT	0
526183	524129	14026U	PARTICIPANT	\N	PRESENT	0
526188	518916	11109J	PARTICIPANT	\N	PRESENT	0
526189	518916	19631V	PARTICIPANT	\N	PRESENT	0
526190	518916	19295A	PARTICIPANT	\N	PRESENT	0
526106	524122	19719D	PARTICIPANT	\N	PRESENT	0
526107	524122	04047H	PARTICIPANT	\N	PRESENT	0
526191	518916	19659J	PARTICIPANT	\N	PRESENT	0
526192	518916	19577H	PARTICIPANT	\N	PRESENT	0
526193	518916	12016W	PARTICIPANT	\N	PRESENT	0
526194	518916	11072N	PARTICIPANT	\N	PRESENT	0
526195	518916	20148F	PARTICIPANT	\N	PRESENT	0
526196	518916	19319Q	PARTICIPANT	\N	PRESENT	0
526197	518916	11090Q	PARTICIPANT	\N	PRESENT	0
526215	524129	07004J	PARTICIPANT	\N	PRESENT	0
526216	524129	12041X	PARTICIPANT	\N	PRESENT	0
526217	524129	14225N	PARTICIPANT	\N	PRESENT	0
526218	524129	19741B	PARTICIPANT	\N	PRESENT	0
526219	524129	04034C	PARTICIPANT	\N	PRESENT	0
526220	524129	19782L	PARTICIPANT	\N	PRESENT	0
526221	524129	20048C	PARTICIPANT	\N	PRESENT	0
526223	526222	14231L	PRESIDENT	0	PRESENT	0
526224	524129	18083K	PARTICIPANT	\N	PRESENT	0
526225	524129	19711U	PARTICIPANT	\N	PRESENT	0
526226	524129	19347U	PARTICIPANT	\N	PRESENT	0
526227	524129	11074Q	PARTICIPANT	\N	PRESENT	0
526228	524129	19687N	PARTICIPANT	\N	PRESENT	0
526229	524129	11056N	PARTICIPANT	\N	PRESENT	0
526230	524129	20128B	PARTICIPANT	\N	PRESENT	0
526231	524129	19629C	PARTICIPANT	\N	PRESENT	0
526234	526233	01048V	PARTICIPANT	\N	PRESENT	0
526235	524129	19691J	PARTICIPANT	\N	PRESENT	0
526236	524129	11012A	PARTICIPANT	\N	PRESENT	0
526238	526237	01048V	PARTICIPANT	\N	PRESENT	0
526240	526239	01048V	PARTICIPANT	\N	PRESENT	0
526241	524129	11064N	PARTICIPANT	\N	PRESENT	0
526242	524129	04086Q	PARTICIPANT	\N	PRESENT	0
526243	524129	20022R	PARTICIPANT	\N	PRESENT	0
526244	524129	14147R	PARTICIPANT	\N	PRESENT	0
526245	524129	14041T	PARTICIPANT	\N	PRESENT	0
526246	524129	11026G	PARTICIPANT	\N	PRESENT	0
526247	524129	11070L	PARTICIPANT	\N	PRESENT	0
526248	524129	14189C	PARTICIPANT	\N	PRESENT	0
526265	524129	20024T	PARTICIPANT	\N	PRESENT	0
526267	524129	20044X	PARTICIPANT	\N	PRESENT	0
526270	524129	14069U	PARTICIPANT	\N	PRESENT	0
526271	524129	14083S	PARTICIPANT	\N	PRESENT	0
526274	524129	07029T	PARTICIPANT	\N	PRESENT	0
527132	526394	20034V	PARTICIPANT	\N	PRESENT	0
528773	528772	20042V	PARTICIPANT	\N	PRESENT	0
528774	528772	19643A	PARTICIPANT	\N	PRESENT	0
528775	528772	14083S	PARTICIPANT	\N	PRESENT	1
528776	528772	20060X	PARTICIPANT	\N	PRESENT	0
528777	528772	14038Y	PARTICIPANT	\N	PRESENT	0
528778	528772	19701S	PARTICIPANT	\N	PRESENT	0
528779	528772	20140W	PARTICIPANT	\N	PRESENT	0
528780	528772	20134Y	PARTICIPANT	\N	PRESENT	0
528781	528772	20100N	PARTICIPANT	\N	PRESENT	0
520048	520047	11026G	PARTICIPANT	\N	PRESENT	0
520049	520047	10015M	PARTICIPANT	\N	PRESENT	0
520053	520051	11026G	PARTICIPANT	\N	PRESENT	0
520054	520051	10015M	PARTICIPANT	\N	PRESENT	0
520109	520108	01048V	PARTICIPANT	\N	PRESENT	0
520135	520134	01048V	PARTICIPANT	\N	PRESENT	0
520138	520137	01048V	PARTICIPANT	\N	PRESENT	0
521268	521267	19507S	PARTICIPANT	\N	PRESENT	0
521269	521267	08028W	PARTICIPANT	\N	PRESENT	0
521270	521267	20174H	PARTICIPANT	\N	PRESENT	0
521272	521271	19507S	PARTICIPANT	\N	PRESENT	0
521273	521271	08028W	PARTICIPANT	\N	PRESENT	0
521292	521291	19507S	PARTICIPANT	\N	PRESENT	0
521326	521325	19515S	PARTICIPANT	\N	PRESENT	0
521327	521325	20022R	PARTICIPANT	\N	PRESENT	0
521328	521325	19575F	PARTICIPANT	\N	PRESENT	0
521329	521325	19549D	PARTICIPANT	\N	PRESENT	0
521330	521325	20086J	PARTICIPANT	\N	PRESENT	0
521331	521325	14069U	PARTICIPANT	\N	PRESENT	0
521332	521325	19782L	PARTICIPANT	\N	PRESENT	0
521333	521325	14329V	PARTICIPANT	\N	PRESENT	0
521334	521325	14038Y	PARTICIPANT	\N	PRESENT	0
521335	521325	19467C	PARTICIPANT	\N	PRESENT	0
521336	521325	11027H	PARTICIPANT	\N	PRESENT	0
521337	521325	19719D	PARTICIPANT	\N	PRESENT	0
521338	521325	01024M	PARTICIPANT	\N	PRESENT	0
521339	521325	20040T	PARTICIPANT	\N	PRESENT	0
521340	521325	20074E	PARTICIPANT	\N	PRESENT	0
521341	521325	20174H	PARTICIPANT	\N	PRESENT	0
521342	521325	01025N	PARTICIPANT	\N	PRESENT	0
521343	521325	20132W	PARTICIPANT	\N	PRESENT	0
521344	521325	19820Y	PARTICIPANT	\N	PRESENT	0
521345	521325	14026U	PARTICIPANT	\N	PRESENT	0
521346	521325	14213J	PARTICIPANT	\N	PRESENT	0
521347	521325	14073Q	PARTICIPANT	\N	PRESENT	0
521348	521325	20126Y	PARTICIPANT	\N	PRESENT	0
521349	521325	08015R	PARTICIPANT	\N	PRESENT	0
521353	521325	19745F	PARTICIPANT	\N	PRESENT	0
521351	521325	19441R	PARTICIPANT	\N	PRESENT	0
521352	521325	14257W	PARTICIPANT	\N	PRESENT	0
521354	521325	05012A	PARTICIPANT	\N	PRESENT	0
521355	521325	19798U	PARTICIPANT	\N	PRESENT	0
521356	521325	11097X	PARTICIPANT	\N	PRESENT	0
521357	521325	04045F	PARTICIPANT	\N	PRESENT	0
521358	521325	14207L	PARTICIPANT	\N	PRESENT	0
521359	521325	14211G	PARTICIPANT	\N	PRESENT	0
524200	524198	19679N	PARTICIPANT	\N	PRESENT	0
524201	524198	19697Q	PARTICIPANT	\N	PRESENT	0
524202	524199	20130U	PARTICIPANT	\N	PRESENT	0
524203	524199	19679N	PARTICIPANT	\N	PRESENT	0
524204	524197	19683J	PARTICIPANT	\N	PRESENT	0
524205	524197	19723Y	PARTICIPANT	\N	PRESENT	0
524274	524068	04008A	PARTICIPANT	\N	EXCUSE	0
524275	524068	19543W	PARTICIPANT	\N	PRESENT	1
524276	524068	14069U	PARTICIPANT	\N	PRESENT	1
524277	524068	20114U	PARTICIPANT	\N	PRESENT	1
524278	524068	19629C	PARTICIPANT	\N	PRESENT	1
524279	524068	19725B	PARTICIPANT	\N	PRESENT	1
524280	524068	14179A	PARTICIPANT	\N	PRESENT	1
524281	524068	19489J	PARTICIPANT	\N	PRESENT	1
524282	524068	14001X	PARTICIPANT	\N	PRESENT	1
524283	524068	14147R	PARTICIPANT	\N	PRESENT	1
524284	524068	14107H	PARTICIPANT	\N	PRESENT	1
524285	524068	19675J	PARTICIPANT	\N	PRESENT	1
524286	522571	01028R	PARTICIPANT	\N	EXCUSE	0
526276	526275	18083K	PARTICIPANT	\N	PRESENT	0
526277	526275	11065P	PARTICIPANT	\N	PRESENT	0
526278	526275	19701S	PARTICIPANT	\N	PRESENT	0
526279	526275	19387D	PARTICIPANT	\N	PRESENT	0
526280	526275	19637C	PARTICIPANT	\N	PRESENT	0
526281	526275	19826F	PARTICIPANT	\N	PRESENT	0
528985	519091	14033T	PARTICIPANT	\N	PRESENT	0
529008	529007	05008E	PARTICIPANT	\N	EXCUSE	0
529010	529009	01057W	PARTICIPANT	\N	PRESENT	0
529011	529009	14225N	PARTICIPANT	\N	PRESENT	0
529094	529093	14207L	PARTICIPANT	\N	PRESENT	0
529095	529093	01025N	PARTICIPANT	\N	PRESENT	0
529096	529093	14151M	PARTICIPANT	\N	PRESENT	0
529099	529098	01025N	PARTICIPANT	\N	PRESENT	0
529100	529098	14207L	PARTICIPANT	\N	PRESENT	0
529102	529101	14207L	PARTICIPANT	\N	PRESENT	0
529103	529101	14038Y	PARTICIPANT	\N	PRESENT	0
529104	529101	01025N	PARTICIPANT	\N	PRESENT	0
529105	529101	20094J	PARTICIPANT	\N	PRESENT	0
529106	529101	08056B	PARTICIPANT	\N	PRESENT	0
529108	529107	14207L	PARTICIPANT	\N	PRESENT	0
529109	529107	01025N	PARTICIPANT	\N	PRESENT	0
529110	529107	19747H	PARTICIPANT	\N	PRESENT	0
529111	529107	20144B	PARTICIPANT	\N	PRESENT	0
529112	529107	14357A	PARTICIPANT	\N	PRESENT	0
529113	529107	19511N	PARTICIPANT	\N	PRESENT	0
529114	529107	08015R	PARTICIPANT	\N	PRESENT	0
529115	529107	20082E	PARTICIPANT	\N	PRESENT	0
529116	529107	20062A	PARTICIPANT	\N	PRESENT	0
529455	528961	14205J	PARTICIPANT	\N	PRESENT	0
529456	528961	20066E	PARTICIPANT	\N	PRESENT	0
534631	534253	01057W	PARTICIPANT	\N	PRESENT	0
534632	534253	19515S	PARTICIPANT	\N	PRESENT	0
534633	534253	08011M	PARTICIPANT	\N	PRESENT	0
534634	534253	20108W	PARTICIPANT	\N	PRESENT	0
534635	534253	19399H	PARTICIPANT	\N	PRESENT	0
534636	534253	04086Q	PARTICIPANT	\N	PRESENT	0
534637	534253	19747H	PARTICIPANT	\N	PRESENT	0
534638	534253	20048C	PARTICIPANT	\N	PRESENT	0
534639	534253	14213J	PARTICIPANT	\N	PRESENT	0
534640	534253	17779H	PARTICIPANT	\N	PRESENT	0
534641	534253	14021P	PARTICIPANT	\N	PRESENT	0
534643	534253	14193X	PARTICIPANT	\N	PRESENT	0
534644	534253	11097X	PARTICIPANT	\N	PRESENT	0
534645	534253	14038Y	PARTICIPANT	\N	PRESENT	0
534646	534253	20068G	PARTICIPANT	\N	PRESENT	0
534647	534253	18083K	PARTICIPANT	\N	PRESENT	0
534648	534253	08015R	PARTICIPANT	\N	PRESENT	0
534649	534253	20100N	PARTICIPANT	\N	PRESENT	0
534650	534253	19383Y	PARTICIPANT	\N	PRESENT	0
534651	534253	19693L	PARTICIPANT	\N	PRESENT	0
534652	534253	14105F	PARTICIPANT	\N	PRESENT	0
534653	534253	20086J	PARTICIPANT	\N	PRESENT	0
534654	534253	14073Q	PARTICIPANT	\N	PRESENT	0
534655	534253	19762G	PARTICIPANT	\N	PRESENT	0
534656	534253	19629C	PARTICIPANT	\N	PRESENT	0
534657	534253	08034U	PARTICIPANT	\N	PRESENT	0
534658	534253	19563B	PARTICIPANT	\N	PRESENT	0
534659	534253	11090Q	PARTICIPANT	\N	PRESENT	0
534660	534253	20056C	PARTICIPANT	\N	PRESENT	0
534662	534253	14042U	PARTICIPANT	\N	PRESENT	0
534671	534253	14069U	PARTICIPANT	\N	PRESENT	0
534672	534253	14030Q	PARTICIPANT	\N	PRESENT	0
534673	534253	19647E	PARTICIPANT	\N	PRESENT	0
534674	534253	19335Q	PARTICIPANT	\N	PRESENT	0
534680	534253	19479G	PARTICIPANT	\N	PRESENT	0
534686	534253	20054A	PARTICIPANT	\N	PRESENT	0
534683	534253	14327T	PARTICIPANT	\N	PRESENT	0
534684	534253	20082E	PARTICIPANT	\N	PRESENT	0
534685	534253	19826F	PARTICIPANT	\N	PRESENT	0
534696	534253	01043Q	PARTICIPANT	\N	PRESENT	0
534698	534253	19543W	PARTICIPANT	\N	PRESENT	0
534700	534253	16685X	PARTICIPANT	\N	PRESENT	0
534707	534253	14187A	PARTICIPANT	\N	PRESENT	0
534714	534253	19631V	PARTICIPANT	\N	PRESENT	0
534715	534253	08069G	PARTICIPANT	\N	PRESENT	0
534716	534253	20124W	PARTICIPANT	\N	PRESENT	0
534719	534253	08010L	PARTICIPANT	\N	PRESENT	0
534720	534253	20028X	PARTICIPANT	\N	PRESENT	0
534721	534253	20146D	PARTICIPANT	\N	PRESENT	0
534722	534253	14205J	PARTICIPANT	\N	PRESENT	0
534723	534253	20092G	PARTICIPANT	\N	PRESENT	0
530171	528964	17229F	PARTICIPANT	\N	PRESENT	0
530172	528964	20068G	PARTICIPANT	\N	PRESENT	0
530173	528964	19619A	PARTICIPANT	\N	PRESENT	0
530174	528964	20106U	PARTICIPANT	\N	PRESENT	1
530175	528964	20122U	PARTICIPANT	\N	PRESENT	1
530176	528964	11101A	PARTICIPANT	\N	PRESENT	1
530177	528964	20076G	PARTICIPANT	\N	PRESENT	1
530178	528964	20020P	PARTICIPANT	\N	PRESENT	1
530179	528964	19251M	PARTICIPANT	\N	PRESENT	1
530180	528964	19745F	PARTICIPANT	\N	PRESENT	1
530181	528964	19525U	PARTICIPANT	\N	PRESENT	1
530182	529003	14147R	PARTICIPANT	\N	PRESENT	0
530214	529298	14179A	PARTICIPANT	\N	PRESENT	0
530215	529298	04008A	PARTICIPANT	\N	PRESENT	1
530217	529298	14151M	PARTICIPANT	\N	PRESENT	1
530218	529298	04085P	PARTICIPANT	\N	PRESENT	1
530220	530219	14179A	PARTICIPANT	\N	PRESENT	0
530228	530225	14179A	PARTICIPANT	\N	PRESENT	0
530229	529002	04085P	PARTICIPANT	\N	PRESENT	1
530230	529002	19543W	PARTICIPANT	\N	PRESENT	1
530231	529002	20110Q	PARTICIPANT	\N	PRESENT	1
530232	529002	11033F	PARTICIPANT	\N	PRESENT	1
530233	529002	19629C	PARTICIPANT	\N	PRESENT	1
530234	529002	14215L	PARTICIPANT	\N	PRESENT	1
530235	529002	20074E	PARTICIPANT	\N	PRESENT	1
530236	529002	19725B	PARTICIPANT	\N	PRESENT	1
530237	529002	14179A	PARTICIPANT	\N	PRESENT	1
530238	529002	19649G	PARTICIPANT	\N	PRESENT	1
530239	529002	11072N	PARTICIPANT	\N	PRESENT	1
530240	529002	14107H	PARTICIPANT	\N	PRESENT	1
530241	529002	19675J	PARTICIPANT	\N	PRESENT	1
530242	529003	04085P	PARTICIPANT	\N	PRESENT	1
530243	529003	11033F	PARTICIPANT	\N	PRESENT	1
530244	529003	14053L	PARTICIPANT	\N	PRESENT	1
530245	529003	19629C	PARTICIPANT	\N	PRESENT	1
530246	529003	14215L	PARTICIPANT	\N	PRESENT	1
530247	529003	20074E	PARTICIPANT	\N	PRESENT	1
530248	529003	14179A	PARTICIPANT	\N	PRESENT	1
530249	529003	11072N	PARTICIPANT	\N	PRESENT	1
530250	529004	11041F	PARTICIPANT	\N	PRESENT	1
530251	529004	04042C	PARTICIPANT	\N	EXCUSE	0
530252	529004	08069G	PARTICIPANT	\N	PRESENT	1
530266	529003	19675J	PARTICIPANT	\N	PRESENT	1
530267	529081	14107H	PARTICIPANT	\N	PRESENT	0
530268	529081	19511N	PARTICIPANT	\N	PRESENT	0
530269	529081	01060R	PARTICIPANT	\N	PRESENT	0
530270	529081	19798U	PARTICIPANT	\N	PRESENT	0
530271	529081	19954N	PARTICIPANT	\N	PRESENT	0
530272	529081	20098N	PARTICIPANT	\N	PRESENT	0
530273	529081	19766L	PARTICIPANT	\N	PRESENT	0
530274	529081	19593H	PARTICIPANT	\N	PRESENT	0
530275	529081	19826F	PARTICIPANT	\N	PRESENT	0
530276	529081	14211G	PARTICIPANT	\N	PRESENT	0
530277	529081	17637T	PARTICIPANT	\N	PRESENT	0
530278	529081	19711U	PARTICIPANT	\N	PRESENT	0
530279	529081	11031D	PARTICIPANT	\N	PRESENT	0
530280	529081	12041X	PARTICIPANT	\N	PRESENT	0
530281	529081	01058X	PARTICIPANT	\N	PRESENT	0
530282	529081	19758L	PARTICIPANT	\N	PRESENT	0
530283	529081	19760E	PARTICIPANT	\N	PRESENT	0
530284	529081	19565D	PARTICIPANT	\N	PRESENT	0
530285	529081	99004R	PARTICIPANT	\N	PRESENT	0
530286	529081	20046A	PARTICIPANT	\N	PRESENT	0
530287	529081	05012A	PARTICIPANT	\N	PRESENT	0
530288	529081	19695N	PARTICIPANT	\N	PRESENT	0
530289	529081	11099A	PARTICIPANT	\N	PRESENT	0
530290	529081	14123H	PARTICIPANT	\N	PRESENT	0
530291	529081	20092G	PARTICIPANT	\N	PRESENT	0
530292	529081	20142Y	PARTICIPANT	\N	PRESENT	0
530293	529081	20134Y	PARTICIPANT	\N	PRESENT	0
530294	529081	17367Q	PARTICIPANT	\N	PRESENT	0
530295	529081	19347U	PARTICIPANT	\N	PRESENT	0
530296	529081	18083K	PARTICIPANT	\N	PRESENT	0
530297	529081	20044X	PARTICIPANT	\N	PRESENT	0
530298	529081	20100N	PARTICIPANT	\N	PRESENT	0
530299	529081	20130U	PARTICIPANT	\N	PRESENT	0
530300	529081	19467C	PARTICIPANT	\N	PRESENT	0
530301	529081	11033F	PARTICIPANT	\N	PRESENT	0
530302	529081	19443T	PARTICIPANT	\N	PRESENT	0
530303	529081	95063L	PARTICIPANT	\N	PRESENT	0
530304	529081	08061X	PARTICIPANT	\N	PRESENT	0
530305	529081	20148F	PARTICIPANT	\N	PRESENT	0
530306	529081	20128B	PARTICIPANT	\N	PRESENT	0
530307	529081	19573D	PARTICIPANT	\N	PRESENT	0
530308	529081	19651A	PARTICIPANT	\N	PRESENT	0
530309	529081	20032T	PARTICIPANT	\N	PRESENT	0
530310	529081	14069U	PARTICIPANT	\N	PRESENT	0
530311	529081	14031R	PARTICIPANT	\N	PRESENT	0
530312	529081	20146D	PARTICIPANT	\N	PRESENT	0
530313	529081	11083R	PARTICIPANT	\N	PRESENT	0
530314	529081	20096L	PARTICIPANT	\N	PRESENT	0
530315	529081	19667J	PARTICIPANT	\N	PRESENT	0
530316	529081	92040Q	PARTICIPANT	\N	PRESENT	0
530317	529081	19349W	PARTICIPANT	\N	PRESENT	0
530318	529081	19697Q	PARTICIPANT	\N	PRESENT	0
530319	529081	19768N	PARTICIPANT	\N	PRESENT	0
530320	529081	14221J	PARTICIPANT	\N	PRESENT	0
530321	529081	08015R	PARTICIPANT	\N	PRESENT	0
530322	529081	19545Y	PARTICIPANT	\N	PRESENT	0
530323	529081	14251Q	PARTICIPANT	\N	PRESENT	0
530324	529081	20108W	PARTICIPANT	\N	PRESENT	0
530325	529081	17589D	PARTICIPANT	\N	PRESENT	0
530326	529081	19585H	PARTICIPANT	\N	PRESENT	0
530327	529081	14111D	PARTICIPANT	\N	PRESENT	0
530328	529081	20050V	PARTICIPANT	\N	PRESENT	0
530329	529081	19705W	PARTICIPANT	\N	PRESENT	0
530330	529081	19563B	PARTICIPANT	\N	PRESENT	0
530331	529081	20024T	PARTICIPANT	\N	PRESENT	0
530332	529081	04057K	PARTICIPANT	\N	PRESENT	0
530333	529081	14147R	PARTICIPANT	\N	PRESENT	0
530334	529081	20126Y	PARTICIPANT	\N	PRESENT	0
530335	529081	20090E	PARTICIPANT	\N	PRESENT	0
530336	529081	11012A	PARTICIPANT	\N	PRESENT	0
530337	529081	20062A	PARTICIPANT	\N	PRESENT	0
530338	529081	19866P	PARTICIPANT	\N	PRESENT	0
530339	529081	14059S	PARTICIPANT	\N	PRESENT	0
530340	529081	19387D	PARTICIPANT	\N	PRESENT	0
530341	529081	19762G	PARTICIPANT	\N	PRESENT	0
530342	529081	14331P	PARTICIPANT	\N	PRESENT	0
530343	529081	19719D	PARTICIPANT	\N	PRESENT	0
530344	529081	19421M	PARTICIPANT	\N	PRESENT	0
530345	529081	98022P	PARTICIPANT	\N	PRESENT	0
530346	529081	11048N	PARTICIPANT	\N	PRESENT	0
530347	529081	20072C	PARTICIPANT	\N	PRESENT	0
530348	529081	14237S	PARTICIPANT	\N	PRESENT	0
530349	529081	20116W	PARTICIPANT	\N	PRESENT	0
530350	529081	14207L	PARTICIPANT	\N	PRESENT	0
530351	529081	20172F	PARTICIPANT	\N	PRESENT	0
530352	529081	19681G	PARTICIPANT	\N	PRESENT	0
530353	529081	19671E	PARTICIPANT	\N	PRESENT	0
530354	529081	14357A	PARTICIPANT	\N	PRESENT	0
530355	529081	19637C	PARTICIPANT	\N	PRESENT	0
530357	529081	97011G	PARTICIPANT	\N	PRESENT	0
530358	529081	20022R	PARTICIPANT	\N	PRESENT	0
530359	529081	20068G	PARTICIPANT	\N	PRESENT	0
530360	529081	01028R	PARTICIPANT	\N	PRESENT	0
530361	529081	04059M	PARTICIPANT	\N	PRESENT	0
530362	529081	11080N	PARTICIPANT	\N	PRESENT	0
530363	529081	11045K	PARTICIPANT	\N	PRESENT	0
530364	529081	19515S	PARTICIPANT	\N	PRESENT	0
530365	529081	17779H	PARTICIPANT	\N	PRESENT	0
530366	529081	19507S	PARTICIPANT	\N	PRESENT	0
530367	529081	01057W	PARTICIPANT	\N	PRESENT	0
530368	529081	19649G	PARTICIPANT	\N	PRESENT	0
530369	529081	14223L	PARTICIPANT	\N	PRESENT	0
530370	529081	08060W	PARTICIPANT	\N	PRESENT	0
530371	529081	19533U	PARTICIPANT	\N	PRESENT	0
530372	529081	14021P	PARTICIPANT	\N	PRESENT	0
530373	529081	04033B	PARTICIPANT	\N	PRESENT	0
530374	529081	11041F	PARTICIPANT	\N	PRESENT	0
530375	529081	19669L	PARTICIPANT	\N	PRESENT	0
530376	529081	14187A	PARTICIPANT	\N	PRESENT	0
530377	529081	19549D	PARTICIPANT	\N	PRESENT	0
530378	529081	19715Y	PARTICIPANT	\N	PRESENT	0
530379	529081	04086Q	PARTICIPANT	\N	PRESENT	0
530380	529081	19415P	PARTICIPANT	\N	PRESENT	0
530381	529081	11066Q	PARTICIPANT	\N	PRESENT	0
530382	529081	04092N	PARTICIPANT	\N	PRESENT	0
530383	529081	08017T	PARTICIPANT	\N	PRESENT	0
515914	515913	14215L	PARTICIPANT	\N	PRESENT	0
515915	515913	08009T	PARTICIPANT	\N	PRESENT	0
515916	515913	14041T	PARTICIPANT	\N	PRESENT	0
515917	515913	04070G	PARTICIPANT	\N	PRESENT	0
515918	515913	19709B	PARTICIPANT	\N	PRESENT	0
515919	515913	19515S	PARTICIPANT	\N	PRESENT	0
515920	515913	14069U	PARTICIPANT	\N	PRESENT	0
515921	515913	11027H	PARTICIPANT	\N	PRESENT	0
515922	515913	19663E	PARTICIPANT	\N	PRESENT	0
515923	515913	95063L	PARTICIPANT	\N	PRESENT	0
515924	515913	14071N	PARTICIPANT	\N	PRESENT	0
515925	515913	19333N	PARTICIPANT	\N	PRESENT	0
515926	515913	20048C	PARTICIPANT	\N	PRESENT	0
515927	515913	14151M	PARTICIPANT	\N	PRESENT	0
515928	515913	19954N	PARTICIPANT	\N	PRESENT	0
515930	515929	19695N	PARTICIPANT	\N	PRESENT	0
515931	515929	08015R	PARTICIPANT	\N	PRESENT	0
515932	515929	08009T	PARTICIPANT	\N	PRESENT	0
515933	515929	10015M	PARTICIPANT	\N	PRESENT	0
515934	515929	20084G	PARTICIPANT	\N	PRESENT	0
515935	515929	11041F	PARTICIPANT	\N	PRESENT	0
516540	514757	19569H	PARTICIPANT	\N	PRESENT	0
516541	514757	19709B	PARTICIPANT	\N	PRESENT	0
516542	514757	19503N	PARTICIPANT	\N	PRESENT	0
517094	513047	19329S	PARTICIPANT	\N	PRESENT	0
517095	513047	14069U	PARTICIPANT	\N	PRESENT	0
517096	513047	19725B	PARTICIPANT	\N	PRESENT	0
517097	513047	11083R	PARTICIPANT	\N	PRESENT	0
517098	513047	20124W	PARTICIPANT	\N	PRESENT	0
517099	513047	14030Q	PARTICIPANT	\N	PRESENT	0
517100	513047	19251M	PARTICIPANT	\N	PRESENT	0
517101	513047	20136B	PARTICIPANT	\N	PRESENT	0
517106	513047	20100N	PARTICIPANT	\N	PRESENT	0
517107	513047	20024T	PARTICIPANT	\N	PRESENT	0
520254	519304	19681G	PARTICIPANT	\N	EXCUSE	0
520255	519287	01048V	PARTICIPANT	\N	PRESENT	0
520256	519230	19333N	PARTICIPANT	\N	PRESENT	0
520257	519230	19549D	PARTICIPANT	\N	PRESENT	0
520258	519230	19820Y	PARTICIPANT	\N	PRESENT	0
520259	519230	19826F	PARTICIPANT	\N	PRESENT	0
520260	519230	20020P	PARTICIPANT	\N	PRESENT	0
520261	519230	20024T	PARTICIPANT	\N	PRESENT	0
520262	519230	11065P	PARTICIPANT	\N	PRESENT	0
520263	519230	20032T	PARTICIPANT	\N	PRESENT	0
520264	519230	20046A	PARTICIPANT	\N	PRESENT	0
520265	519230	98018T	PARTICIPANT	\N	PRESENT	1
520266	519230	20068G	PARTICIPANT	\N	PRESENT	0
520267	519230	19701S	PARTICIPANT	\N	PRESENT	0
520268	519230	20076G	PARTICIPANT	\N	PRESENT	0
520269	519230	19387D	PARTICIPANT	\N	PRESENT	0
520270	519230	14219Q	PARTICIPANT	\N	PRESENT	0
520271	519230	14221J	PARTICIPANT	\N	PRESENT	0
520272	519230	19599P	PARTICIPANT	\N	PRESENT	0
520273	519230	19637C	PARTICIPANT	\N	PRESENT	0
520274	519230	20096L	PARTICIPANT	\N	PRESENT	0
520275	519230	18083K	PARTICIPANT	\N	PRESENT	0
520276	519230	20100N	PARTICIPANT	\N	PRESENT	0
520277	519230	14237S	PARTICIPANT	\N	PRESENT	0
520278	519230	05012A	PARTICIPANT	\N	PRESENT	0
520279	519230	20106U	PARTICIPANT	\N	PRESENT	0
520280	519230	20118Y	PARTICIPANT	\N	PRESENT	0
520281	519230	19503N	PARTICIPANT	\N	PRESENT	0
520282	519230	20120S	PARTICIPANT	\N	PRESENT	0
520283	519230	14031R	PARTICIPANT	\N	PRESENT	0
520284	519230	20140W	PARTICIPANT	\N	PRESENT	0
520285	519230	11101A	PARTICIPANT	\N	PRESENT	0
520286	519230	19739H	PARTICIPANT	\N	PRESENT	0
520287	519230	19745F	PARTICIPANT	\N	PRESENT	0
520288	519230	19619A	PARTICIPANT	\N	PRESENT	0
520290	519162	19383Y	PARTICIPANT	\N	PRESENT	0
520291	519162	19515S	PARTICIPANT	\N	PRESENT	0
520292	519162	14357A	PARTICIPANT	\N	PRESENT	1
520293	519162	20104S	PARTICIPANT	\N	PRESENT	1
520294	519162	20018V	PARTICIPANT	\N	PRESENT	1
520295	519162	19521Q	PARTICIPANT	\N	PRESENT	1
520296	519162	14038Y	PARTICIPANT	\N	PRESENT	1
520297	519162	14033T	PARTICIPANT	\N	PRESENT	0
520298	519162	20060X	PARTICIPANT	\N	PRESENT	1
520299	519162	14251Q	PARTICIPANT	\N	PRESENT	1
520300	519304	19443T	PARTICIPANT	\N	PRESENT	1
520301	519304	01058X	PARTICIPANT	\N	PRESENT	0
520302	519304	11027H	PARTICIPANT	\N	PRESENT	0
520303	519304	16685X	PARTICIPANT	\N	PRESENT	0
520304	519304	11054L	PARTICIPANT	\N	PRESENT	0
520305	519304	11066Q	PARTICIPANT	\N	PRESENT	0
520306	519304	08056B	PARTICIPANT	\N	PRESENT	1
520307	519304	19421M	PARTICIPANT	\N	PRESENT	1
520308	519304	19347U	PARTICIPANT	\N	PRESENT	0
520309	519304	19521Q	PARTICIPANT	\N	PRESENT	0
520310	519304	08047A	PARTICIPANT	\N	PRESENT	0
520311	519304	14059S	PARTICIPANT	\N	PRESENT	0
520312	519304	04035D	PARTICIPANT	\N	PRESENT	1
520313	519304	08069G	PARTICIPANT	\N	PRESENT	0
520314	519304	20042V	PARTICIPANT	\N	PRESENT	0
520315	519304	01024M	PARTICIPANT	\N	PRESENT	0
520316	519304	14105F	PARTICIPANT	\N	PRESENT	1
520317	519304	98018T	PARTICIPANT	\N	PRESENT	1
520318	519304	14211G	PARTICIPANT	\N	PRESENT	0
520319	519304	14255U	PARTICIPANT	\N	PRESENT	0
520320	519304	12041X	PARTICIPANT	\N	PRESENT	1
520321	519304	19565D	PARTICIPANT	\N	PRESENT	0
520322	519304	20072C	PARTICIPANT	\N	PRESENT	1
520323	519304	04042C	PARTICIPANT	\N	PRESENT	0
520324	519304	12028B	PARTICIPANT	\N	PRESENT	0
520325	519304	14193X	PARTICIPANT	\N	PRESENT	0
520326	519304	14249W	PARTICIPANT	\N	PRESENT	0
520327	519304	20128B	PARTICIPANT	\N	PRESENT	1
520328	519304	14097Y	PARTICIPANT	\N	PRESENT	1
520329	519304	14267Y	PARTICIPANT	\N	PRESENT	0
520330	519304	11064N	PARTICIPANT	\N	PRESENT	0
520331	519304	11083R	PARTICIPANT	\N	PRESENT	0
520332	519304	19745F	PARTICIPANT	\N	PRESENT	0
520921	519227	11026G	PARTICIPANT	\N	PRESENT	0
521469	521325	20090E	PARTICIPANT	\N	PRESENT	0
521541	521540	05008E	PARTICIPANT	\N	PRESENT	0
521542	521540	20110Q	PARTICIPANT	\N	PRESENT	0
521544	521543	05008E	PARTICIPANT	\N	PRESENT	0
521546	521545	05008E	PARTICIPANT	\N	PRESENT	0
521547	521545	14179A	PARTICIPANT	\N	PRESENT	0
521549	521548	05008E	PARTICIPANT	\N	PRESENT	0
522489	521234	20022R	PARTICIPANT	\N	PRESENT	1
522490	521234	11040E	PARTICIPANT	\N	PRESENT	1
522491	521234	11053K	PARTICIPANT	\N	PRESENT	1
522492	521234	14121F	PARTICIPANT	\N	PRESENT	1
522493	521234	99004R	PARTICIPANT	\N	PRESENT	1
522494	521234	08010L	PARTICIPANT	\N	PRESENT	1
522495	521234	01048V	PARTICIPANT	\N	PRESENT	1
522496	521234	12016W	PARTICIPANT	\N	PRESENT	1
522497	521234	19671E	PARTICIPANT	\N	PRESENT	1
522498	521234	20150Y	PARTICIPANT	\N	PRESENT	1
522851	522157	08061X	PARTICIPANT	\N	PRESENT	0
522852	522157	19533U	PARTICIPANT	\N	PRESENT	0
524124	524123	19399H	PARTICIPANT	\N	PRESENT	0
524125	521611	20098N	PARTICIPANT	\N	PRESENT	0
524126	521611	20134Y	PARTICIPANT	\N	PRESENT	0
524127	521611	11043H	PARTICIPANT	\N	PRESENT	0
524128	521611	19399H	PARTICIPANT	\N	PRESENT	0
524130	521240	19399H	PARTICIPANT	\N	PRESENT	0
524131	521240	20180F	PARTICIPANT	\N	PRESENT	0
524133	521494	19399H	PARTICIPANT	\N	PRESENT	0
524134	521494	20180F	PARTICIPANT	\N	PRESENT	0
524333	524069	04085P	PARTICIPANT	\N	PRESENT	1
524334	524069	19629C	PARTICIPANT	\N	PRESENT	1
524335	524069	19729F	PARTICIPANT	\N	PRESENT	1
524336	524069	19581D	PARTICIPANT	\N	PRESENT	1
524338	524069	14107H	PARTICIPANT	\N	PRESENT	1
524340	524069	04008A	PARTICIPANT	\N	EXCUSE	0
525290	525289	19631V	PARTICIPANT	\N	PRESENT	0
525291	525289	19575F	PARTICIPANT	\N	PRESENT	0
525294	525289	20138D	PARTICIPANT	\N	PRESENT	0
525295	525289	14105F	PARTICIPANT	\N	PRESENT	0
525297	525289	19383Y	PARTICIPANT	\N	PRESENT	0
525298	525289	19621T	PARTICIPANT	\N	PRESENT	0
525299	525289	19629C	PARTICIPANT	\N	PRESENT	0
525300	525289	14327T	PARTICIPANT	\N	PRESENT	0
525301	525289	20140W	PARTICIPANT	\N	PRESENT	0
525302	525289	14187A	PARTICIPANT	\N	PRESENT	0
525303	525289	20048C	PARTICIPANT	\N	PRESENT	0
525304	525289	20056C	PARTICIPANT	\N	PRESENT	0
525305	525289	14097Y	PARTICIPANT	\N	PRESENT	0
528782	528772	11083R	PARTICIPANT	\N	PRESENT	0
528784	528772	19820Y	PARTICIPANT	\N	PRESENT	1
528785	528772	19387D	PARTICIPANT	\N	PRESENT	1
528786	528772	20128B	PARTICIPANT	\N	PRESENT	1
528788	528772	19611R	PARTICIPANT	\N	PRESENT	0
528789	528772	19723Y	PARTICIPANT	\N	PRESENT	1
528790	528772	11077T	PARTICIPANT	\N	PRESENT	0
528791	528772	01048V	PARTICIPANT	\N	PRESENT	0
528792	528772	04070G	PARTICIPANT	\N	PRESENT	1
528793	528772	19533U	PARTICIPANT	\N	PRESENT	0
528794	528772	19349W	PARTICIPANT	\N	PRESENT	0
528795	528772	19766L	PARTICIPANT	\N	PRESENT	0
528796	528772	19798U	PARTICIPANT	\N	PRESENT	1
528797	528772	19585H	PARTICIPANT	\N	PRESENT	0
529169	529168	08060W	PARTICIPANT	\N	PRESENT	0
529170	529168	05012A	PARTICIPANT	\N	PRESENT	0
529171	529168	19525U	PARTICIPANT	\N	PRESENT	0
529172	529168	17229F	PARTICIPANT	\N	PRESENT	0
529173	529168	20100N	PARTICIPANT	\N	PRESENT	0
529174	529168	20068G	PARTICIPANT	\N	PRESENT	0
529175	529168	19551W	PARTICIPANT	\N	PRESENT	0
529176	529168	20102Q	PARTICIPANT	\N	PRESENT	0
529177	529168	19637C	PARTICIPANT	\N	PRESENT	0
529178	529168	20136B	PARTICIPANT	\N	PRESENT	0
529180	529179	08060W	PARTICIPANT	\N	PRESENT	0
529181	529179	05012A	PARTICIPANT	\N	PRESENT	0
529182	529179	20100N	PARTICIPANT	\N	PRESENT	0
529183	529179	20068G	PARTICIPANT	\N	PRESENT	0
529184	529179	19551W	PARTICIPANT	\N	PRESENT	0
529185	529179	20102Q	PARTICIPANT	\N	PRESENT	0
529186	529179	19637C	PARTICIPANT	\N	PRESENT	0
529187	529179	20136B	PARTICIPANT	\N	PRESENT	0
529189	529188	08060W	PARTICIPANT	\N	PRESENT	0
529190	529188	05012A	PARTICIPANT	\N	PRESENT	0
529191	529188	17229F	PARTICIPANT	\N	PRESENT	0
529192	529188	19551W	PARTICIPANT	\N	PRESENT	0
529193	529188	20102Q	PARTICIPANT	\N	PRESENT	0
529194	529188	20136B	PARTICIPANT	\N	PRESENT	0
529195	529188	20100N	PARTICIPANT	\N	PRESENT	0
529197	529196	14089Y	PARTICIPANT	\N	PRESENT	0
529198	529196	11026G	PARTICIPANT	\N	PRESENT	0
529247	529070	11045K	PARTICIPANT	\N	PRESENT	0
529248	529070	19679N	PARTICIPANT	\N	PRESENT	0
529249	529070	19826F	PARTICIPANT	\N	PRESENT	0
529250	529070	19443T	PARTICIPANT	\N	PRESENT	0
529251	529070	20018V	PARTICIPANT	\N	PRESENT	0
529252	529070	19569H	PARTICIPANT	\N	PRESENT	0
529253	529070	19581D	PARTICIPANT	\N	PRESENT	0
529254	529070	04042C	PARTICIPANT	\N	PRESENT	0
529255	529070	14259Y	PARTICIPANT	\N	PRESENT	0
529256	529070	14038Y	PARTICIPANT	\N	PRESENT	0
529257	529070	11110B	PARTICIPANT	\N	PRESENT	0
529258	529070	19421M	PARTICIPANT	\N	PRESENT	0
529259	529070	14205J	PARTICIPANT	\N	PRESENT	0
529260	529070	19621T	PARTICIPANT	\N	PRESENT	0
529261	529070	19335Q	PARTICIPANT	\N	PRESENT	0
529262	529070	14031R	PARTICIPANT	\N	PRESENT	0
529263	529070	20110Q	PARTICIPANT	\N	PRESENT	0
529264	529070	19611R	PARTICIPANT	\N	PRESENT	0
529265	529070	08045X	PARTICIPANT	\N	PRESENT	0
529266	529070	19563B	PARTICIPANT	\N	PRESENT	0
529267	529070	20024T	PARTICIPANT	\N	PRESENT	0
529268	529070	19729F	PARTICIPANT	\N	PRESENT	0
529269	529070	20052X	PARTICIPANT	\N	PRESENT	0
529270	529070	14073Q	PARTICIPANT	\N	PRESENT	0
529271	529070	14053L	PARTICIPANT	\N	PRESENT	0
529272	529070	04043D	PARTICIPANT	\N	PRESENT	0
529273	529070	14147R	PARTICIPANT	\N	PRESENT	0
529274	529070	01062T	PARTICIPANT	\N	PRESENT	0
529275	529070	14097Y	PARTICIPANT	\N	PRESENT	0
529276	529070	19747H	PARTICIPANT	\N	PRESENT	0
529277	529070	14123H	PARTICIPANT	\N	PRESENT	0
529278	529070	18083K	PARTICIPANT	\N	PRESENT	0
529285	529070	11043H	PARTICIPANT	\N	PRESENT	0
529280	529070	14223L	PARTICIPANT	\N	PRESENT	0
529281	529070	14042U	PARTICIPANT	\N	PRESENT	0
529282	529070	08012N	PARTICIPANT	\N	PRESENT	0
529283	529070	19593H	PARTICIPANT	\N	PRESENT	0
529284	529070	01060R	PARTICIPANT	\N	PRESENT	0
529286	529070	04034C	PARTICIPANT	\N	PRESENT	0
529287	529070	04045F	PARTICIPANT	\N	PRESENT	0
529288	529070	19719D	PARTICIPANT	\N	PRESENT	0
529290	529070	19711U	PARTICIPANT	\N	PRESENT	0
529291	529070	19415P	PARTICIPANT	\N	PRESENT	0
529300	529071	14211G	PARTICIPANT	\N	PRESENT	0
529301	529071	19515S	PARTICIPANT	\N	PRESENT	0
529294	529071	86034E	PARTICIPANT	\N	PRESENT	0
529299	529071	99004R	PARTICIPANT	\N	PRESENT	0
529302	529071	18083K	PARTICIPANT	\N	PRESENT	0
529303	529071	20108W	PARTICIPANT	\N	PRESENT	0
529304	529071	20026V	PARTICIPANT	\N	PRESENT	0
529305	529071	19954N	PARTICIPANT	\N	PRESENT	0
529306	529071	19443T	PARTICIPANT	\N	PRESENT	0
529307	529071	19693L	PARTICIPANT	\N	PRESENT	0
529308	529071	14038Y	PARTICIPANT	\N	PRESENT	0
529309	529071	01048V	PARTICIPANT	\N	PRESENT	0
529310	529071	14223L	PARTICIPANT	\N	PRESENT	0
529311	529071	04047H	PARTICIPANT	\N	PRESENT	0
529312	529071	04086Q	PARTICIPANT	\N	PRESENT	0
529313	529071	14133K	PARTICIPANT	\N	PRESENT	0
529314	529071	19747H	PARTICIPANT	\N	PRESENT	0
529315	529071	08034U	PARTICIPANT	\N	PRESENT	0
529316	529071	19671E	PARTICIPANT	\N	PRESENT	0
529317	529071	12041X	PARTICIPANT	\N	PRESENT	0
529318	529071	20022R	PARTICIPANT	\N	PRESENT	0
529319	529071	12028B	PARTICIPANT	\N	PRESENT	0
529320	529071	11066Q	PARTICIPANT	\N	PRESENT	0
529321	529071	14097Y	PARTICIPANT	\N	PRESENT	0
529322	529071	19333N	PARTICIPANT	\N	PRESENT	0
529323	529071	11040E	PARTICIPANT	\N	PRESENT	0
529324	529071	19565D	PARTICIPANT	\N	PRESENT	0
529325	529071	20046A	PARTICIPANT	\N	PRESENT	0
529326	529071	19347U	PARTICIPANT	\N	PRESENT	0
529327	529071	11033F	PARTICIPANT	\N	PRESENT	0
529328	529071	14187A	PARTICIPANT	\N	PRESENT	0
529329	529071	11041F	PARTICIPANT	\N	PRESENT	0
529330	529071	19798U	PARTICIPANT	\N	PRESENT	0
529331	529071	01062T	PARTICIPANT	\N	PRESENT	0
529332	529071	11054L	PARTICIPANT	\N	PRESENT	0
529333	529071	19421M	PARTICIPANT	\N	PRESENT	0
529334	529071	20064C	PARTICIPANT	\N	PRESENT	0
529335	529071	14053L	PARTICIPANT	\N	PRESENT	0
529336	529071	20054A	PARTICIPANT	\N	PRESENT	0
529337	529071	11027H	PARTICIPANT	\N	PRESENT	0
529338	529071	14059S	PARTICIPANT	\N	PRESENT	0
529339	529071	14357A	PARTICIPANT	\N	PRESENT	0
529341	529071	20090E	PARTICIPANT	\N	PRESENT	0
529342	529071	20116W	PARTICIPANT	\N	PRESENT	0
529343	529071	14147R	PARTICIPANT	\N	PRESENT	0
529344	529071	14207L	PARTICIPANT	\N	PRESENT	0
529345	529071	04034C	PARTICIPANT	\N	PRESENT	0
529346	529071	20062A	PARTICIPANT	\N	PRESENT	0
529347	529071	11083R	PARTICIPANT	\N	PRESENT	0
529348	529071	19651A	PARTICIPANT	\N	PRESENT	0
529349	529071	14249W	PARTICIPANT	\N	PRESENT	0
529350	529071	20128B	PARTICIPANT	\N	PRESENT	0
529351	529071	20024T	PARTICIPANT	\N	PRESENT	0
529352	529071	95063L	PARTICIPANT	\N	PRESENT	0
529353	529071	19575F	PARTICIPANT	\N	PRESENT	0
529354	529071	01058X	PARTICIPANT	\N	PRESENT	0
529355	529071	14041T	PARTICIPANT	\N	PRESENT	0
529356	529071	20072C	PARTICIPANT	\N	PRESENT	0
529357	529071	98022P	PARTICIPANT	\N	PRESENT	0
529358	529071	19691J	PARTICIPANT	\N	PRESENT	0
529359	529071	14231L	PARTICIPANT	\N	PRESENT	0
529360	529071	20034V	PARTICIPANT	\N	PRESENT	0
529361	529071	19447X	PARTICIPANT	\N	PRESENT	0
529362	529071	19739H	PARTICIPANT	\N	PRESENT	0
529363	529071	20042V	PARTICIPANT	\N	PRESENT	0
529364	529071	14031R	PARTICIPANT	\N	PRESENT	0
529365	529071	14255U	PARTICIPANT	\N	PRESENT	0
529366	529071	14179A	PARTICIPANT	\N	PRESENT	0
529367	529071	19826F	PARTICIPANT	\N	PRESENT	0
529368	529071	14089Y	PARTICIPANT	\N	PRESENT	0
529369	529071	14267Y	PARTICIPANT	\N	PRESENT	0
529370	529071	01024M	PARTICIPANT	\N	PRESENT	0
529371	529071	14189C	PARTICIPANT	\N	PRESENT	0
529372	529071	08047A	PARTICIPANT	\N	PRESENT	0
529373	529071	97011G	PARTICIPANT	\N	PRESENT	0
529374	529071	20140W	PARTICIPANT	\N	PRESENT	0
514105	512703	04085P	PARTICIPANT	\N	PRESENT	1
514107	512703	19543W	PARTICIPANT	\N	PRESENT	1
514108	512703	14069U	PARTICIPANT	\N	PRESENT	1
514111	512703	14053L	PARTICIPANT	\N	PRESENT	1
514112	512703	19629C	PARTICIPANT	\N	PRESENT	1
514113	512703	04008A	PARTICIPANT	\N	PRESENT	1
514114	512703	14179A	PARTICIPANT	\N	PRESENT	1
514115	512703	11072N	PARTICIPANT	\N	PRESENT	1
514116	512703	14107H	PARTICIPANT	\N	PRESENT	1
514117	512703	19749K	PARTICIPANT	\N	PRESENT	1
515992	512883	97011G	PARTICIPANT	\N	PRESENT	1
517078	516991	08056B	PARTICIPANT	\N	PRESENT	0
517079	516991	19591F	PARTICIPANT	\N	PRESENT	0
517081	516991	14237S	PARTICIPANT	\N	PRESENT	0
521296	518915	04085P	PARTICIPANT	\N	PRESENT	0
517431	517007	19651A	PARTICIPANT	\N	PRESENT	1
517433	517007	20138D	PARTICIPANT	\N	PRESENT	1
517434	517007	20124W	PARTICIPANT	\N	PRESENT	1
517435	517007	19643A	PARTICIPANT	\N	PRESENT	1
517436	517007	20048C	PARTICIPANT	\N	PRESENT	1
517437	517007	20142Y	PARTICIPANT	\N	PRESENT	1
517438	517007	19533U	PARTICIPANT	\N	PRESENT	1
517439	517007	19527W	PARTICIPANT	\N	EXCUSE	0
517440	517007	19735D	PARTICIPANT	\N	EXCUSE	0
517850	510805	19741B	PARTICIPANT	\N	PRESENT	0
517851	510805	20024T	PARTICIPANT	\N	PRESENT	0
517852	510805	19966S	PARTICIPANT	\N	PRESENT	0
517853	510805	14357A	PARTICIPANT	\N	PRESENT	0
517854	510805	97011G	PARTICIPANT	\N	PRESENT	0
517855	510805	20120S	PARTICIPANT	\N	PRESENT	0
517856	510805	14179A	PARTICIPANT	\N	PRESENT	0
517857	510805	08015R	PARTICIPANT	\N	PRESENT	0
517858	510805	08034U	PARTICIPANT	\N	PRESENT	0
517859	510805	14147R	PARTICIPANT	\N	PRESENT	0
517860	510805	14169X	PARTICIPANT	\N	PRESENT	0
517861	510805	11041F	PARTICIPANT	\N	PRESENT	0
517862	510805	19333N	PARTICIPANT	\N	PRESENT	0
521294	518915	11109J	PARTICIPANT	\N	PRESENT	0
521295	518915	19717B	PRESIDENT	0	PRESENT	0
521297	518915	19295A	PARTICIPANT	\N	PRESENT	0
521298	518915	19659J	PARTICIPANT	\N	PRESENT	0
521299	518915	19577H	PARTICIPANT	\N	PRESENT	0
521300	518915	19691J	PARTICIPANT	\N	PRESENT	0
521301	518915	08034U	PARTICIPANT	\N	EXCUSE	0
521302	518915	12016W	PARTICIPANT	\N	PRESENT	0
521303	518915	20028X	PARTICIPANT	\N	PRESENT	0
521304	518915	19657G	PARTICIPANT	\N	PRESENT	0
521305	518915	11072N	PARTICIPANT	\N	PRESENT	0
521306	518915	08073C	PARTICIPANT	\N	PRESENT	0
521307	518915	19301E	PARTICIPANT	\N	PRESENT	0
521308	518915	19347U	PARTICIPANT	\N	PRESENT	0
521364	521363	20052X	PARTICIPANT	\N	PRESENT	0
521365	521363	20124W	PARTICIPANT	\N	PRESENT	0
521366	521363	14109K	PARTICIPANT	\N	PRESENT	0
521367	521363	14030Q	PARTICIPANT	\N	PRESENT	0
521369	521368	20052X	PARTICIPANT	\N	PRESENT	0
521468	521467	14231L	PRESIDENT	0	PRESENT	0
521482	521212	04059M	PARTICIPANT	\N	PRESENT	0
521483	521212	19399H	PARTICIPANT	\N	PRESENT	0
521484	521212	19651A	PARTICIPANT	\N	PRESENT	0
521485	521212	20180F	PARTICIPANT	\N	PRESENT	0
521486	521212	20142Y	PARTICIPANT	\N	PRESENT	0
521487	521213	19399H	PARTICIPANT	\N	PRESENT	0
521488	521213	20142Y	PARTICIPANT	\N	PRESENT	0
521490	521489	19651A	PARTICIPANT	\N	PRESENT	0
521491	521489	19399H	PARTICIPANT	\N	PRESENT	0
521492	521489	20180F	PARTICIPANT	\N	PRESENT	0
521503	521499	20098N	PARTICIPANT	\N	PRESENT	0
521504	521499	19533U	PARTICIPANT	\N	PRESENT	0
521505	521499	11043H	PARTICIPANT	\N	PRESENT	0
521506	521498	20098N	PARTICIPANT	\N	PRESENT	0
521507	521498	19533U	PARTICIPANT	\N	PRESENT	0
521508	521498	11043H	PARTICIPANT	\N	PRESENT	0
521509	521293	20098N	PARTICIPANT	\N	PRESENT	0
521510	521293	08012N	PARTICIPANT	\N	PRESENT	0
521511	521293	14073Q	PARTICIPANT	\N	PRESENT	0
521512	521293	11043H	PARTICIPANT	\N	PRESENT	0
521514	521513	20118Y	PARTICIPANT	\N	PRESENT	0
521515	521513	19820Y	PARTICIPANT	\N	PRESENT	0
521516	521513	19637C	PARTICIPANT	\N	PRESENT	0
521518	521517	20118Y	PARTICIPANT	\N	PRESENT	0
521519	521517	19820Y	PARTICIPANT	\N	PRESENT	0
521520	521517	19637C	PARTICIPANT	\N	PRESENT	0
521522	521435	19723Y	PARTICIPANT	\N	PRESENT	0
521523	521435	19683J	PARTICIPANT	\N	PRESENT	0
521524	521521	19683J	PARTICIPANT	\N	PRESENT	0
521842	521841	20110Q	PARTICIPANT	\N	PRESENT	0
521843	521841	11085T	PARTICIPANT	\N	PRESENT	0
521845	521844	19631V	PARTICIPANT	\N	PRESENT	0
521846	521844	14069U	PARTICIPANT	\N	PRESENT	0
521847	521844	14255U	PARTICIPANT	\N	PRESENT	0
521856	521844	19347U	PARTICIPANT	\N	PRESENT	0
521849	521844	14038Y	PARTICIPANT	\N	PRESENT	0
521850	521844	18083K	PARTICIPANT	\N	PRESENT	0
521851	521844	11065P	PARTICIPANT	\N	PRESENT	0
521852	521844	19577H	PARTICIPANT	\N	PRESENT	0
521853	521844	20038A	PARTICIPANT	\N	PRESENT	0
521857	521844	19531S	PARTICIPANT	\N	PRESENT	0
521858	521844	19699S	PARTICIPANT	\N	PRESENT	0
521859	521844	01043Q	PARTICIPANT	\N	PRESENT	0
521860	521844	18193Q	PARTICIPANT	\N	PRESENT	0
521862	521844	16685X	PARTICIPANT	\N	PRESENT	0
521863	521844	14059S	PARTICIPANT	\N	PRESENT	0
521865	521844	19657G	PARTICIPANT	\N	PRESENT	0
521866	521844	19826F	PARTICIPANT	\N	PRESENT	0
521867	521844	11072N	PARTICIPANT	\N	PRESENT	0
521868	521844	19421M	PARTICIPANT	\N	PRESENT	0
521869	521844	19413M	PARTICIPANT	\N	PRESENT	0
521872	521844	14083S	PARTICIPANT	\N	PRESENT	0
522819	522817	14255U	PARTICIPANT	\N	PRESENT	0
522820	522817	19629C	PARTICIPANT	\N	PRESENT	0
522821	522817	11065P	PARTICIPANT	\N	PRESENT	0
522823	522817	20132W	PARTICIPANT	\N	PRESENT	0
522825	522817	19387D	PARTICIPANT	\N	PRESENT	0
522828	522817	19553Y	PARTICIPANT	\N	PRESENT	0
524111	518916	14331P	PARTICIPANT	\N	EXCUSE	0
528633	528632	17023S	PARTICIPANT	\N	PRESENT	1
531321	531047	14331P	PARTICIPANT	\N	EXCUSE	0
532432	532431	19820Y	PARTICIPANT	\N	PRESENT	0
532433	532431	19637C	PARTICIPANT	\N	PRESENT	0
532434	532431	20118Y	PARTICIPANT	\N	PRESENT	0
532435	532431	19507S	PARTICIPANT	\N	PRESENT	0
532436	532431	14033T	PARTICIPANT	\N	PRESENT	0
532437	532431	14205J	PARTICIPANT	\N	PRESENT	0
534813	534254	14026U	PARTICIPANT	\N	PRESENT	0
534814	534254	20092G	PARTICIPANT	\N	PRESENT	0
534815	534254	20146D	PARTICIPANT	\N	PRESENT	0
534816	534254	19387D	PARTICIPANT	\N	PRESENT	0
534817	534254	11077T	PARTICIPANT	\N	PRESENT	0
534818	534228	14259Y	PRESIDENT	0	PRESENT	0
534819	534254	19631V	PARTICIPANT	\N	PRESENT	0
534820	534254	04086Q	PARTICIPANT	\N	PRESENT	0
534821	534254	19563B	PARTICIPANT	\N	PRESENT	0
534822	534254	20088L	PARTICIPANT	\N	PRESENT	0
534823	534254	20028X	PARTICIPANT	\N	PRESENT	0
534824	534254	20046A	PARTICIPANT	\N	PRESENT	0
534826	534254	20064C	PARTICIPANT	\N	PRESENT	0
534827	534254	20082E	PARTICIPANT	\N	PRESENT	0
534828	534254	19549D	PARTICIPANT	\N	PRESENT	0
534830	534254	20070A	PARTICIPANT	\N	PRESENT	0
534831	534254	19651A	PARTICIPANT	\N	PRESENT	0
534832	534254	14207L	PARTICIPANT	\N	PRESENT	0
534833	534254	01043Q	PARTICIPANT	\N	PRESENT	0
534834	534254	17589D	PARTICIPANT	\N	PRESENT	0
534835	534254	20132W	PARTICIPANT	\N	PRESENT	0
534836	534254	19826F	PARTICIPANT	\N	PRESENT	0
534837	534254	14205J	PARTICIPANT	\N	PRESENT	0
534838	534254	14189C	PARTICIPANT	\N	PRESENT	0
534839	534254	19747H	PARTICIPANT	\N	PRESENT	0
534840	534254	20126Y	PARTICIPANT	\N	PRESENT	0
534841	534254	19671E	PARTICIPANT	\N	PRESENT	0
534842	534254	11085T	PARTICIPANT	\N	PRESENT	0
534843	534254	01025N	PARTICIPANT	\N	PRESENT	0
534844	534254	11090Q	PARTICIPANT	\N	PRESENT	0
534845	534254	20054A	PARTICIPANT	\N	PRESENT	0
534846	534254	20124W	PARTICIPANT	\N	PRESENT	0
534847	534254	20090E	PARTICIPANT	\N	PRESENT	0
534848	534254	11097X	PARTICIPANT	\N	PRESENT	0
534849	534254	19383Y	PARTICIPANT	\N	PRESENT	0
534850	534254	20062A	PARTICIPANT	\N	PRESENT	0
534851	534254	20108W	PARTICIPANT	\N	PRESENT	0
530384	529081	14121F	PARTICIPANT	\N	PRESENT	0
530385	529081	08010L	PARTICIPANT	\N	PRESENT	0
530386	529081	19503N	PARTICIPANT	\N	PRESENT	0
530387	529081	08012N	PARTICIPANT	\N	PRESENT	0
530388	529081	19647E	PARTICIPANT	\N	PRESENT	0
530389	529081	20082E	PARTICIPANT	\N	PRESENT	0
530390	529081	19703U	PARTICIPANT	\N	PRESENT	0
530391	529081	04043D	PARTICIPANT	\N	PRESENT	0
530392	529081	20064C	PARTICIPANT	\N	PRESENT	0
530393	529081	19683J	PARTICIPANT	\N	PRESENT	0
530394	529081	11056N	PARTICIPANT	\N	PRESENT	0
530395	529081	14097Y	PARTICIPANT	\N	PRESENT	0
530396	529081	20104S	PARTICIPANT	\N	PRESENT	0
530397	529081	11067R	PARTICIPANT	\N	PRESENT	0
530398	529081	20054A	PARTICIPANT	\N	PRESENT	0
530399	529081	20114U	PARTICIPANT	\N	PRESENT	0
530400	529081	04085P	PARTICIPANT	\N	PRESENT	0
530401	529081	20026V	PARTICIPANT	\N	PRESENT	0
530402	529081	19820Y	PARTICIPANT	\N	PRESENT	0
530403	529081	12028B	PARTICIPANT	\N	PRESENT	0
530404	529081	19729F	PARTICIPANT	\N	PRESENT	0
530405	529081	14229S	PARTICIPANT	\N	PRESENT	0
530406	529081	20140W	PARTICIPANT	\N	PRESENT	0
530407	529081	20138D	PARTICIPANT	\N	PRESENT	0
530408	529081	19723Y	PARTICIPANT	\N	PRESENT	0
530410	529081	20118Y	PARTICIPANT	\N	PRESENT	0
530413	529081	07029T	PARTICIPANT	\N	PRESENT	0
530414	529081	14053L	PARTICIPANT	\N	PRESENT	0
530415	529081	08047A	PARTICIPANT	\N	PRESENT	0
530416	529081	14179A	PARTICIPANT	\N	PRESENT	0
530417	529081	20018V	PARTICIPANT	\N	PRESENT	0
530418	529081	20070A	PARTICIPANT	\N	PRESENT	0
530419	529081	18193Q	PARTICIPANT	\N	PRESENT	0
530420	529081	14225N	PARTICIPANT	\N	PRESENT	0
530502	529081	20060X	PARTICIPANT	\N	PRESENT	0
530422	529081	14189C	PARTICIPANT	\N	PRESENT	0
530423	529081	11090Q	PARTICIPANT	\N	PRESENT	0
530424	529081	19543W	PARTICIPANT	\N	PRESENT	0
530425	529081	14231L	PARTICIPANT	\N	PRESENT	0
530426	529081	19691J	PARTICIPANT	\N	PRESENT	0
530427	529081	19611R	PARTICIPANT	\N	PRESENT	0
530428	529081	19369B	PARTICIPANT	\N	PRESENT	0
530429	529081	11053K	PARTICIPANT	\N	PRESENT	0
530430	529081	11043H	PARTICIPANT	\N	PRESENT	0
530431	529081	19739H	PARTICIPANT	\N	PRESENT	0
530432	529081	14042U	PARTICIPANT	\N	PRESENT	0
530433	529081	20040T	PARTICIPANT	\N	PRESENT	0
530434	529081	19699S	PARTICIPANT	\N	PRESENT	0
530435	529081	20052X	PARTICIPANT	\N	PRESENT	0
530436	529081	19479G	PARTICIPANT	\N	PRESENT	0
530437	529081	19619A	PARTICIPANT	\N	PRESENT	0
530441	529081	20020P	PARTICIPANT	\N	PRESENT	0
530439	529081	20132W	PARTICIPANT	\N	PRESENT	0
530440	529081	19569H	PARTICIPANT	\N	PRESENT	0
530442	529081	16685X	PARTICIPANT	\N	PRESENT	0
530443	529081	01043Q	PARTICIPANT	\N	PRESENT	0
530444	529081	01024M	PARTICIPANT	\N	PRESENT	0
530445	529081	01025N	PARTICIPANT	\N	PRESENT	0
530446	529081	14030Q	PARTICIPANT	\N	PRESENT	0
530447	529081	20042V	PARTICIPANT	\N	PRESENT	0
530448	529081	11085T	PARTICIPANT	\N	PRESENT	0
530449	529081	14327T	PARTICIPANT	\N	PRESENT	0
530450	529081	14219Q	PARTICIPANT	\N	PRESENT	0
530451	529081	14267Y	PARTICIPANT	\N	PRESENT	0
530452	529081	14089Y	PARTICIPANT	\N	PRESENT	0
530453	529081	19685L	PARTICIPANT	\N	PRESENT	0
530499	529081	20066E	PARTICIPANT	\N	PRESENT	0
530456	529081	17737W	PARTICIPANT	\N	PRESENT	0
530459	529081	19335Q	PARTICIPANT	\N	PRESENT	0
530463	529081	14073Q	PARTICIPANT	\N	PRESENT	0
530467	529081	20144B	PARTICIPANT	\N	PRESENT	0
530470	529081	20084G	PARTICIPANT	\N	PRESENT	0
530474	529081	19383Y	PARTICIPANT	\N	PRESENT	0
530475	529081	14038Y	PARTICIPANT	\N	PRESENT	0
530482	529081	11040E	PARTICIPANT	\N	PRESENT	0
530483	529081	19621T	PARTICIPANT	\N	PRESENT	0
530484	529081	19441R	PARTICIPANT	\N	PRESENT	0
530485	529081	19629C	PARTICIPANT	\N	PRESENT	0
530486	529081	20136B	PARTICIPANT	\N	PRESENT	0
530487	529081	20102Q	PARTICIPANT	\N	PRESENT	0
530492	529081	19745F	PARTICIPANT	\N	PRESENT	0
530489	529081	14205J	PARTICIPANT	\N	PRESENT	0
530490	529081	19679N	PARTICIPANT	\N	PRESENT	0
530491	529081	14169X	PARTICIPANT	\N	PRESENT	0
530493	529081	20112S	PARTICIPANT	\N	PRESENT	0
530494	529081	19333N	PARTICIPANT	\N	PRESENT	0
530495	529081	20036X	PARTICIPANT	\N	PRESENT	0
530496	529081	19735D	PARTICIPANT	\N	PRESENT	0
530497	529081	20028X	PARTICIPANT	\N	PRESENT	0
530498	529081	14109K	PARTICIPANT	\N	PRESENT	0
530500	529081	19713W	PARTICIPANT	\N	PRESENT	0
530501	529081	19675J	PARTICIPANT	\N	PRESENT	0
530503	529081	14217N	PARTICIPANT	\N	PRESENT	0
530504	529081	20038A	PARTICIPANT	\N	PRESENT	0
532548	532547	05008E	PARTICIPANT	\N	PRESENT	0
532549	532547	11053K	PARTICIPANT	\N	PRESENT	0
532550	532547	01028R	PARTICIPANT	\N	PRESENT	0
533419	533418	19515S	PARTICIPANT	\N	PRESENT	0
533420	533418	20022R	PARTICIPANT	\N	PRESENT	0
533421	533418	20110Q	PARTICIPANT	\N	PRESENT	0
533422	533418	19575F	PARTICIPANT	\N	PRESENT	0
533424	533418	14105F	PARTICIPANT	\N	PRESENT	0
533425	533418	20114U	PARTICIPANT	\N	PRESENT	0
533426	533418	19782L	PARTICIPANT	\N	PRESENT	0
533427	533418	20090E	PARTICIPANT	\N	PRESENT	0
533428	533418	14207L	PARTICIPANT	\N	PRESENT	0
533429	533418	14038Y	PARTICIPANT	\N	PRESENT	0
533430	533418	19467C	PARTICIPANT	\N	PRESENT	0
533431	533418	20040T	PARTICIPANT	\N	PRESENT	0
533432	533418	14187A	PARTICIPANT	\N	PRESENT	0
533433	533418	01025N	PARTICIPANT	\N	PRESENT	0
533434	533418	20132W	PARTICIPANT	\N	PRESENT	0
533435	533418	20120S	PARTICIPANT	\N	PRESENT	0
533436	533418	14026U	PARTICIPANT	\N	PRESENT	0
533437	533418	14213J	PARTICIPANT	\N	PRESENT	0
533438	533418	20126Y	PARTICIPANT	\N	PRESENT	0
533440	533418	08015R	PARTICIPANT	\N	PRESENT	0
533441	533418	14257W	PARTICIPANT	\N	PRESENT	0
533442	533418	19533U	PARTICIPANT	\N	PRESENT	0
533443	533418	19503N	PARTICIPANT	\N	PRESENT	0
533444	533418	11097X	PARTICIPANT	\N	PRESENT	0
533445	533418	19713W	PARTICIPANT	\N	PRESENT	0
533446	533418	20058E	PARTICIPANT	\N	PRESENT	0
533551	531320	17737W	PARTICIPANT	\N	PRESENT	1
533552	531320	19725B	PARTICIPANT	\N	PRESENT	1
533553	531320	11026G	PARTICIPANT	\N	PRESENT	1
533554	531320	14001X	PARTICIPANT	\N	PRESENT	1
533555	531320	95063L	PARTICIPANT	\N	PRESENT	1
533687	531507	08060W	PARTICIPANT	\N	EXCUSE	0
533688	531507	19545Y	PARTICIPANT	\N	EXCUSE	0
533689	531507	14041T	PARTICIPANT	\N	EXCUSE	0
533690	531507	20040T	PARTICIPANT	\N	EXCUSE	0
533691	531507	19697Q	PARTICIPANT	\N	EXCUSE	0
533695	531507	19717B	PARTICIPANT	\N	PRESENT	0
533696	531507	19515S	PRESIDENT	0	PRESENT	0
533698	531507	19575F	PARTICIPANT	\N	PRESENT	0
533699	531507	14030Q	PARTICIPANT	\N	PRESENT	0
533700	531507	14105F	PARTICIPANT	\N	PRESENT	0
533701	531507	14083S	PARTICIPANT	\N	PRESENT	0
533702	531507	19467C	PARTICIPANT	\N	PRESENT	0
533703	531507	14357A	PARTICIPANT	\N	PRESENT	0
533711	531507	19251M	PARTICIPANT	\N	PRESENT	0
533712	531507	20134Y	PARTICIPANT	\N	PRESENT	0
533713	531507	19695N	PARTICIPANT	\N	PRESENT	0
533714	531507	08015R	PARTICIPANT	\N	PRESENT	0
533715	531507	16685X	PARTICIPANT	\N	PRESENT	0
533716	531507	19671E	PARTICIPANT	\N	PRESENT	0
533717	531507	20082E	PARTICIPANT	\N	PRESENT	0
533719	531507	20092G	PARTICIPANT	\N	PRESENT	0
533797	533796	20028X	PARTICIPANT	\N	PRESENT	0
533798	533796	19631V	PARTICIPANT	\N	PRESENT	0
533799	533796	20060X	PARTICIPANT	\N	PRESENT	0
533800	533796	14038Y	PARTICIPANT	\N	PRESENT	0
534182	534181	19651A	PARTICIPANT	\N	PRESENT	1
534183	534181	19621T	PARTICIPANT	\N	PRESENT	1
534184	534181	14109K	PARTICIPANT	\N	PRESENT	1
534185	534181	19735D	PARTICIPANT	\N	PRESENT	1
534190	534189	19651A	PARTICIPANT	\N	PRESENT	1
534191	534189	19621T	PARTICIPANT	\N	PRESENT	1
534192	534189	19533U	PARTICIPANT	\N	PRESENT	1
534193	534189	19735D	PARTICIPANT	\N	PRESENT	1
514923	512268	08045X	PARTICIPANT	\N	PRESENT	1
514924	512268	19723Y	PARTICIPANT	\N	PRESENT	1
516821	516820	04008A	PARTICIPANT	\N	PRESENT	0
516822	516820	14179A	PARTICIPANT	\N	PRESENT	0
515064	512268	10006L	PRESIDENT	0	PRESENT	0
516823	516820	19649G	PARTICIPANT	\N	PRESENT	0
516824	516820	19629C	PARTICIPANT	\N	PRESENT	0
516825	516820	19749K	PARTICIPANT	\N	PRESENT	0
516827	516826	14179A	PARTICIPANT	\N	PRESENT	0
516828	516826	04008A	PARTICIPANT	\N	PRESENT	0
516829	516826	04085P	PARTICIPANT	\N	PRESENT	0
516830	516826	19629C	PARTICIPANT	\N	PRESENT	0
516831	516826	19649G	PARTICIPANT	\N	PRESENT	0
516832	516826	19749K	PARTICIPANT	\N	PRESENT	0
516833	516826	14021P	PARTICIPANT	\N	PRESENT	0
516835	516834	14179A	PARTICIPANT	\N	PRESENT	0
516836	516834	19729F	PARTICIPANT	\N	PRESENT	0
516838	516837	14179A	PARTICIPANT	\N	PRESENT	0
516839	516837	04008A	PARTICIPANT	\N	PRESENT	0
516840	516837	19649G	PARTICIPANT	\N	PRESENT	1
516842	516841	14179A	PARTICIPANT	\N	PRESENT	0
516843	516841	04008A	PARTICIPANT	\N	PRESENT	0
516844	516841	19649G	PARTICIPANT	\N	PRESENT	0
516845	516841	19749K	PARTICIPANT	\N	PRESENT	0
516846	516841	01028R	PARTICIPANT	\N	PRESENT	0
516848	516847	04008A	PARTICIPANT	\N	PRESENT	0
516849	516847	14179A	PARTICIPANT	\N	PRESENT	0
516850	516847	20114U	PARTICIPANT	\N	PRESENT	0
516852	516851	14179A	PARTICIPANT	\N	PRESENT	0
516853	516851	04008A	PARTICIPANT	\N	PRESENT	0
516857	516856	20138D	PARTICIPANT	\N	PRESENT	0
516858	516856	20114U	PARTICIPANT	\N	PRESENT	0
516859	516856	19545Y	PARTICIPANT	\N	PRESENT	0
516860	516856	14187A	PARTICIPANT	\N	PRESENT	0
516861	516856	19647E	PARTICIPANT	\N	PRESENT	1
516862	516856	20132W	PARTICIPANT	\N	PRESENT	0
516863	516856	97011G	PARTICIPANT	\N	PRESENT	0
516865	516856	08056B	PARTICIPANT	\N	PRESENT	0
516866	516856	14179A	PARTICIPANT	\N	PRESENT	0
516867	516856	19591F	PARTICIPANT	\N	PRESENT	0
516868	516856	19649G	PARTICIPANT	\N	PRESENT	1
516869	516856	19699S	PARTICIPANT	\N	PRESENT	0
516870	516856	19711U	PARTICIPANT	\N	PRESENT	0
516871	516856	08010L	PARTICIPANT	\N	PRESENT	0
516872	516856	04070G	PARTICIPANT	\N	PRESENT	0
516873	516856	19593H	PARTICIPANT	\N	PRESENT	0
516874	516856	14237S	PARTICIPANT	\N	PRESENT	0
516875	516856	20058E	PARTICIPANT	\N	PRESENT	0
523682	521400	11056N	PARTICIPANT	\N	PRESENT	0
523683	521400	95063L	PARTICIPANT	\N	PRESENT	0
523684	521400	20074E	PARTICIPANT	\N	PRESENT	0
523685	521400	20108W	PARTICIPANT	\N	PRESENT	0
523686	521400	14041T	PARTICIPANT	\N	PRESENT	0
523687	521400	11026G	PARTICIPANT	\N	PRESENT	0
523688	521400	20110Q	PARTICIPANT	\N	PRESENT	0
523689	521400	14151M	PARTICIPANT	\N	PRESENT	0
523690	521400	04047H	PRESIDENT	0	PRESENT	0
523691	521400	01028R	PARTICIPANT	\N	PRESENT	0
523692	521400	19447X	PARTICIPANT	\N	PRESENT	0
523693	521400	05008E	PARTICIPANT	\N	PRESENT	0
523694	521479	20070A	PARTICIPANT	\N	PRESENT	0
523698	521479	14041T	PARTICIPANT	\N	PRESENT	0
523700	521479	04047H	PARTICIPANT	\N	PRESENT	0
523701	521479	04035D	PARTICIPANT	\N	PRESENT	0
523702	521479	20074E	PARTICIPANT	\N	PRESENT	0
523703	521479	19447X	PARTICIPANT	\N	PRESENT	0
523713	521479	19349W	PARTICIPANT	\N	PRESENT	0
523714	521479	19647E	PARTICIPANT	\N	PRESENT	0
523728	521479	14053L	PARTICIPANT	\N	PRESENT	0
523748	521479	05008E	PARTICIPANT	\N	PRESENT	0
523749	521479	14229S	PARTICIPANT	\N	PRESENT	0
523858	521480	11031D	PARTICIPANT	\N	PRESENT	0
523859	521480	19649G	PARTICIPANT	\N	PRESENT	0
523860	521480	11067R	PARTICIPANT	\N	PRESENT	0
523861	521480	19503N	PARTICIPANT	\N	PRESENT	0
523865	521480	11045K	PARTICIPANT	\N	PRESENT	0
523863	521480	19758L	PARTICIPANT	\N	PRESENT	0
523864	521480	19693L	PARTICIPANT	\N	PRESENT	0
523866	521480	17737W	PARTICIPANT	\N	PRESENT	0
523867	521480	20050V	PARTICIPANT	\N	PRESENT	0
523868	521480	20132W	PARTICIPANT	\N	PRESENT	0
523869	521480	19621T	PARTICIPANT	\N	PRESENT	0
523870	521480	19629C	PARTICIPANT	\N	PRESENT	0
523871	521480	19447X	PARTICIPANT	\N	PRESENT	0
523872	521480	11012A	PARTICIPANT	\N	PRESENT	0
523873	521480	20116W	PARTICIPANT	\N	PRESENT	0
523874	521480	19749K	PARTICIPANT	\N	PRESENT	0
523875	521480	20052X	PARTICIPANT	\N	PRESENT	0
523876	521480	19739H	PARTICIPANT	\N	PRESENT	0
523877	521480	20066E	PARTICIPANT	\N	PRESENT	0
523878	521480	14030Q	PARTICIPANT	\N	PRESENT	0
523879	521480	19611R	PARTICIPANT	\N	PRESENT	0
523880	521480	14147R	PARTICIPANT	\N	PRESENT	0
523881	521480	04047H	PARTICIPANT	\N	PRESENT	0
523882	521480	19699S	PARTICIPANT	\N	PRESENT	0
523883	521480	20142Y	PARTICIPANT	\N	PRESENT	0
523884	521480	11033F	PARTICIPANT	\N	PRESENT	0
523885	521480	19593H	PARTICIPANT	\N	PRESENT	0
523886	521480	01028R	PARTICIPANT	\N	PRESENT	0
523887	521480	04085P	PARTICIPANT	\N	PRESENT	0
523888	521480	20080C	PARTICIPANT	\N	PRESENT	0
523889	521480	17229F	PARTICIPANT	\N	PRESENT	0
523890	521480	17589D	PARTICIPANT	\N	PRESENT	0
523891	521480	14109K	PARTICIPANT	\N	PRESENT	0
523892	521480	20114U	PARTICIPANT	\N	PRESENT	0
523893	521480	14053L	PARTICIPANT	\N	PRESENT	0
523894	521480	19467C	PARTICIPANT	\N	PRESENT	0
523895	521480	19735D	PARTICIPANT	\N	PRESENT	0
523907	521480	19333N	PARTICIPANT	\N	PRESENT	0
523908	521480	20106U	PARTICIPANT	\N	PRESENT	0
523909	521480	19533U	PARTICIPANT	\N	PRESENT	0
523910	521480	19543W	PARTICIPANT	\N	PRESENT	0
523918	521480	05008E	PARTICIPANT	\N	PRESENT	0
523919	521480	19709B	PARTICIPANT	\N	PRESENT	0
523920	521480	14213J	PARTICIPANT	\N	PRESENT	0
523921	521480	14041T	PARTICIPANT	\N	PRESENT	0
523922	521480	19507S	PARTICIPANT	\N	PRESENT	0
523923	521480	19573D	PARTICIPANT	\N	PRESENT	0
523924	521480	14083S	PARTICIPANT	\N	PRESENT	0
523930	521480	20038A	PARTICIPANT	\N	PRESENT	0
523931	521480	20134Y	PARTICIPANT	\N	PRESENT	0
523936	521480	11056N	PARTICIPANT	\N	PRESENT	0
523937	521480	14055N	PARTICIPANT	\N	PRESENT	0
523938	521480	04086Q	PARTICIPANT	\N	PRESENT	0
523939	521480	14251Q	PARTICIPANT	\N	PRESENT	0
523990	521478	08073C	PARTICIPANT	\N	PRESENT	0
523991	521478	20106U	PARTICIPANT	\N	PRESENT	0
523992	521478	11045K	PARTICIPANT	\N	PRESENT	0
523993	521478	19649G	PARTICIPANT	\N	PRESENT	0
523994	521478	19503N	PARTICIPANT	\N	PRESENT	0
523995	521478	19333N	PARTICIPANT	\N	PRESENT	0
523996	521478	19593H	PARTICIPANT	\N	PRESENT	0
523997	521478	19758L	PARTICIPANT	\N	PRESENT	0
523998	521478	04085P	PARTICIPANT	\N	PRESENT	0
523999	521478	11031D	PARTICIPANT	\N	PRESENT	0
524000	521478	11056N	PARTICIPANT	\N	PRESENT	0
524001	521478	11067R	PARTICIPANT	\N	PRESENT	0
524002	521478	14109K	PARTICIPANT	\N	PRESENT	0
524003	521478	20080C	PARTICIPANT	\N	PRESENT	0
524004	521478	20142Y	PARTICIPANT	\N	PRESENT	0
524005	521478	17589D	PARTICIPANT	\N	PRESENT	0
524006	521478	19629C	PARTICIPANT	\N	PRESENT	0
524007	521478	11012A	PARTICIPANT	\N	PRESENT	0
523854	521480	08073C	PARTICIPANT	\N	PRESENT	0
523855	521480	08069G	PARTICIPANT	\N	PRESENT	0
524008	521478	20116W	PARTICIPANT	\N	PRESENT	0
524009	521478	20066E	PARTICIPANT	\N	PRESENT	0
524010	521478	01028R	PARTICIPANT	\N	PRESENT	0
524011	521478	19543W	PARTICIPANT	\N	PRESENT	0
524012	521478	19739H	PARTICIPANT	\N	PRESENT	0
524013	521478	14030Q	PARTICIPANT	\N	PRESENT	0
524014	521478	19749K	PARTICIPANT	\N	PRESENT	0
524015	521478	14083S	PARTICIPANT	\N	PRESENT	0
524016	521478	19735D	PARTICIPANT	\N	PRESENT	0
524017	521478	19699S	PARTICIPANT	\N	PRESENT	0
524018	521478	14055N	PARTICIPANT	\N	PRESENT	0
524019	521478	14251Q	PARTICIPANT	\N	PRESENT	0
524020	521478	19573D	PARTICIPANT	\N	PRESENT	0
524021	521478	14147R	PARTICIPANT	\N	PRESENT	0
524022	521478	14259Y	PARTICIPANT	\N	PRESENT	0
524023	521478	19693L	PARTICIPANT	\N	PRESENT	0
529375	529071	19573D	PARTICIPANT	\N	PRESENT	0
529376	529071	04033B	PARTICIPANT	\N	PRESENT	0
529377	529071	19711U	PARTICIPANT	\N	PRESENT	0
529378	529071	14105F	PARTICIPANT	\N	PRESENT	0
529379	529071	11103C	PARTICIPANT	\N	PRESENT	0
529380	529071	01028R	PARTICIPANT	\N	PRESENT	0
529381	529071	14033T	PARTICIPANT	\N	PRESENT	0
529382	529071	19766L	PARTICIPANT	\N	PRESENT	0
529383	529071	14259Y	PARTICIPANT	\N	PRESENT	0
529384	529071	19503N	PARTICIPANT	\N	PRESENT	0
529385	529071	14213J	PARTICIPANT	\N	PRESENT	0
529386	529071	04042C	PARTICIPANT	\N	PRESENT	0
529387	529071	19415P	PARTICIPANT	\N	PRESENT	0
529388	529071	08015R	PARTICIPANT	\N	PRESENT	0
529389	529071	19758L	PARTICIPANT	\N	PRESENT	0
529390	529071	20096L	PARTICIPANT	\N	PRESENT	0
529391	529071	20032T	PARTICIPANT	\N	PRESENT	0
529392	529071	14217N	PARTICIPANT	\N	PRESENT	0
529393	529071	14021P	PARTICIPANT	\N	PRESENT	0
529394	529071	20148F	PARTICIPANT	\N	PRESENT	0
529395	529071	19669L	PARTICIPANT	\N	PRESENT	0
529396	529071	19709B	PARTICIPANT	\N	PRESENT	0
529397	529071	19543W	PARTICIPANT	\N	PRESENT	0
529398	529071	20122U	PARTICIPANT	\N	PRESENT	0
529399	529071	19715Y	PARTICIPANT	\N	PRESENT	0
529400	529071	20068G	PARTICIPANT	\N	PRESENT	0
529407	529071	11101A	PARTICIPANT	\N	PRESENT	0
529402	529071	19383Y	PARTICIPANT	\N	PRESENT	0
529403	529071	11070L	PARTICIPANT	\N	PRESENT	0
529404	529071	19729F	PARTICIPANT	\N	PRESENT	0
529405	529071	19768N	PARTICIPANT	\N	PRESENT	0
529406	529071	17737W	PARTICIPANT	\N	PRESENT	0
529408	529071	20124W	PARTICIPANT	\N	PRESENT	0
529409	529071	08069G	PARTICIPANT	\N	PRESENT	0
529410	529071	17637T	PARTICIPANT	\N	PRESENT	0
529411	529071	14219Q	PARTICIPANT	\N	PRESENT	0
529412	529071	19695N	PARTICIPANT	\N	PRESENT	0
529413	529071	11056N	PARTICIPANT	\N	PRESENT	0
529414	529071	20120S	PARTICIPANT	\N	PRESENT	0
529415	529071	14026U	PARTICIPANT	\N	PRESENT	0
529416	529071	20066E	PARTICIPANT	\N	PRESENT	0
529417	529071	20028X	PARTICIPANT	\N	PRESENT	0
529418	529071	14123H	PARTICIPANT	\N	PRESENT	0
529419	529071	14205J	PARTICIPANT	\N	PRESENT	0
529420	529071	19563B	PARTICIPANT	\N	PRESENT	0
529421	529071	19621T	PARTICIPANT	\N	PRESENT	0
529422	529071	04045F	PARTICIPANT	\N	PRESENT	0
529423	529071	19387D	PARTICIPANT	\N	PRESENT	0
529424	529071	14257W	PARTICIPANT	\N	PRESENT	0
529425	529071	19569H	PARTICIPANT	\N	PRESENT	0
529426	529071	20044X	PARTICIPANT	\N	PRESENT	0
529427	529071	20086J	PARTICIPANT	\N	PRESENT	0
529428	529071	19467C	PARTICIPANT	\N	PRESENT	0
529429	529071	14073Q	PARTICIPANT	\N	PRESENT	0
529430	529071	08061X	PARTICIPANT	\N	PRESENT	0
529431	529071	19545Y	PARTICIPANT	\N	PRESENT	0
529432	529071	19399H	PARTICIPANT	\N	PRESENT	0
529433	529071	19369B	PARTICIPANT	\N	PRESENT	0
529434	529071	19585H	PARTICIPANT	\N	PRESENT	0
529435	529071	19441R	PARTICIPANT	\N	PRESENT	0
529436	529071	14111D	PARTICIPANT	\N	PRESENT	0
529437	529071	04057K	PARTICIPANT	\N	PRESENT	0
529438	529071	20020P	PARTICIPANT	\N	PRESENT	0
529439	529071	19703U	PARTICIPANT	\N	PRESENT	0
529440	529071	20172F	PARTICIPANT	\N	PRESENT	0
529441	528961	20040T	PARTICIPANT	\N	PRESENT	0
529442	528961	11053K	PARTICIPANT	\N	PRESENT	0
529443	528961	17965H	PARTICIPANT	\N	PRESENT	1
529444	528961	19667J	PARTICIPANT	\N	PRESENT	0
529445	528961	18193Q	PRESIDENT	0	PRESENT	0
529446	528961	20044X	PARTICIPANT	\N	PRESENT	0
529447	528961	19585H	PARTICIPANT	\N	PRESENT	0
529448	528961	20098N	PARTICIPANT	\N	PRESENT	1
529449	528961	19703U	PARTICIPANT	\N	PRESENT	0
529450	528961	19679N	PARTICIPANT	\N	PRESENT	0
529451	528961	19367Y	PARTICIPANT	\N	PRESENT	1
529452	528961	14071N	PARTICIPANT	\N	PRESENT	0
529453	528961	19657G	PARTICIPANT	\N	PRESENT	1
529454	528961	20018V	PARTICIPANT	\N	PRESENT	0
529457	529071	05012A	PARTICIPANT	\N	PRESENT	0
529461	529071	20082E	PARTICIPANT	\N	PRESENT	0
529459	529071	20126Y	PARTICIPANT	\N	PRESENT	0
529460	529071	04035D	PARTICIPANT	\N	PRESENT	0
529463	529071	11067R	PARTICIPANT	\N	PRESENT	0
529464	529071	01025N	PARTICIPANT	\N	PRESENT	0
529465	529071	19479G	PARTICIPANT	\N	PRESENT	0
529466	529071	14042U	PARTICIPANT	\N	PRESENT	0
529467	529071	20144B	PARTICIPANT	\N	PRESENT	0
529468	529071	11090Q	PARTICIPANT	\N	PRESENT	0
529469	529071	11064N	PARTICIPANT	\N	PRESENT	0
529470	529071	14107H	PARTICIPANT	\N	PRESENT	0
529472	529071	19713W	PARTICIPANT	\N	PRESENT	0
529473	529071	14121F	PARTICIPANT	\N	PRESENT	0
529474	529071	19599P	PARTICIPANT	\N	PRESENT	0
529475	529071	11085T	PARTICIPANT	\N	PRESENT	0
529476	529071	14030Q	PARTICIPANT	\N	PRESENT	0
529477	529071	19631V	PARTICIPANT	\N	PRESENT	0
529478	529071	20098N	PARTICIPANT	\N	PRESENT	0
529479	529071	95041E	PARTICIPANT	\N	PRESENT	0
529573	529076	11070L	PARTICIPANT	\N	PRESENT	0
529574	529076	20086J	PARTICIPANT	\N	PRESENT	0
529575	529076	14033T	PARTICIPANT	\N	PRESENT	0
529576	529076	14257W	PARTICIPANT	\N	PRESENT	0
529577	529076	20082E	PARTICIPANT	\N	PRESENT	0
529578	529076	19599P	PARTICIPANT	\N	PRESENT	0
529579	529076	19715Y	PARTICIPANT	\N	PRESENT	0
529580	529076	11067R	PARTICIPANT	\N	PRESENT	0
529581	529076	14121F	PARTICIPANT	\N	PRESENT	0
529582	529076	04045F	PARTICIPANT	\N	PRESENT	0
529583	529076	11090Q	PARTICIPANT	\N	PRESENT	0
529584	529076	19507S	PARTICIPANT	\N	PRESENT	0
529585	529076	20038A	PARTICIPANT	\N	PRESENT	0
529586	529076	19651A	PARTICIPANT	\N	PRESENT	0
529587	529076	20128B	PARTICIPANT	\N	PRESENT	0
529588	529076	20072C	PARTICIPANT	\N	PRESENT	0
529589	529076	14207L	PARTICIPANT	\N	PRESENT	0
529590	529076	19369B	PARTICIPANT	\N	PRESENT	0
529591	529076	20144B	PARTICIPANT	\N	PRESENT	0
529592	529076	19691J	PARTICIPANT	\N	PRESENT	0
529593	529076	20092G	PARTICIPANT	\N	PRESENT	0
529594	529076	19479G	PARTICIPANT	\N	PRESENT	0
529595	529076	19713W	PARTICIPANT	\N	PRESENT	0
529596	529076	01024M	PARTICIPANT	\N	PRESENT	0
529597	529076	11064N	PARTICIPANT	\N	PRESENT	0
529598	529076	19563B	PARTICIPANT	\N	PRESENT	0
529599	529076	14107H	PARTICIPANT	\N	PRESENT	0
529600	529076	19387D	PARTICIPANT	\N	PRESENT	0
529601	529076	98022P	PARTICIPANT	\N	PRESENT	0
529602	529076	14083S	PARTICIPANT	\N	PRESENT	0
529603	529076	19695N	PARTICIPANT	\N	PRESENT	0
529604	529076	20046A	PARTICIPANT	\N	PRESENT	0
529605	529076	19565D	PARTICIPANT	\N	PRESENT	0
529606	529076	04085P	PARTICIPANT	\N	PRESENT	0
529607	529076	14030Q	PARTICIPANT	\N	PRESENT	0
529608	529076	95041E	PARTICIPANT	\N	PRESENT	0
529609	529076	10006L	PARTICIPANT	\N	PRESENT	0
529610	529076	19711U	PARTICIPANT	\N	PRESENT	0
529611	529076	14187A	PARTICIPANT	\N	PRESENT	0
529612	529076	05012A	PARTICIPANT	\N	PRESENT	0
529613	529076	20098N	PARTICIPANT	\N	PRESENT	0
529614	529076	19693L	PARTICIPANT	\N	PRESENT	0
529615	529076	20032T	PARTICIPANT	\N	PRESENT	0
529616	529076	14217N	PARTICIPANT	\N	PRESENT	0
529617	529076	20028X	PARTICIPANT	\N	PRESENT	0
529618	529076	19739H	PARTICIPANT	\N	PRESENT	0
529619	529076	14053L	PARTICIPANT	\N	PRESENT	0
529620	529076	19415P	PARTICIPANT	\N	PRESENT	0
529622	529167	19798U	PARTICIPANT	\N	PRESENT	0
529623	529167	20038A	PARTICIPANT	\N	PRESENT	0
529624	529167	20140W	PARTICIPANT	\N	PRESENT	0
529625	529167	01025N	PRESIDENT	0	PRESENT	0
529626	529167	14026U	PARTICIPANT	\N	PRESENT	0
529627	529167	14030Q	PARTICIPANT	\N	PRESENT	0
529628	529076	20090E	PARTICIPANT	\N	PRESENT	0
529630	529076	19679N	PARTICIPANT	\N	PRESENT	0
529631	529076	08061X	PARTICIPANT	\N	PRESENT	0
529632	529076	20126Y	PARTICIPANT	\N	PRESENT	0
529633	529076	20044X	PARTICIPANT	\N	PRESENT	0
529634	529076	19703U	PARTICIPANT	\N	PRESENT	0
529635	529076	19671E	PARTICIPANT	\N	PRESENT	0
529636	529076	20022R	PARTICIPANT	\N	PRESENT	0
513759	513758	14179A	PARTICIPANT	\N	PRESENT	0
513760	513758	04008A	PARTICIPANT	\N	PRESENT	0
513771	513768	04008A	PARTICIPANT	\N	PRESENT	0
513772	513768	14179A	PARTICIPANT	\N	PRESENT	0
513774	513773	04008A	PARTICIPANT	\N	PRESENT	0
513775	513773	14151M	PARTICIPANT	\N	PRESENT	1
513776	513773	19489J	PARTICIPANT	\N	PRESENT	1
513777	513773	19649G	PARTICIPANT	\N	PRESENT	1
513779	513778	14179A	PARTICIPANT	\N	PRESENT	0
513780	513778	17737W	PARTICIPANT	\N	PRESENT	0
514128	514127	14215L	PARTICIPANT	\N	PRESENT	0
518014	516805	19723Y	PARTICIPANT	\N	PRESENT	0
518015	516805	19735D	PARTICIPANT	\N	PRESENT	0
518018	516805	01048V	PARTICIPANT	\N	PRESENT	0
518019	516805	04043D	PARTICIPANT	\N	PRESENT	0
518020	516805	19503N	PARTICIPANT	\N	PRESENT	0
518021	516805	11067R	PARTICIPANT	\N	PRESENT	0
518026	516805	18003S	PARTICIPANT	\N	EXCUSE	0
518027	516805	19563B	PARTICIPANT	\N	EXCUSE	0
518028	516805	19693L	PARTICIPANT	\N	EXCUSE	0
518678	518677	04070G	PARTICIPANT	\N	PRESENT	0
518679	518677	19621T	PARTICIPANT	\N	PRESENT	0
518680	518677	19593H	PARTICIPANT	\N	PRESENT	0
518681	518677	19399H	PARTICIPANT	\N	PRESENT	0
518682	518677	08017T	PARTICIPANT	\N	PRESENT	0
521038	520136	08034U	PARTICIPANT	\N	PRESENT	1
521039	520136	19575F	PARTICIPANT	\N	PRESENT	1
521040	520136	14217N	PARTICIPANT	\N	PRESENT	1
521579	521578	05008E	PARTICIPANT	\N	PRESENT	0
521580	521578	11053K	PARTICIPANT	\N	PRESENT	0
521581	521578	01028R	PARTICIPANT	\N	PRESENT	0
521582	521539	14331P	PARTICIPANT	\N	EXCUSE	0
521583	519602	19735D	PARTICIPANT	\N	PRESENT	0
521585	521584	14179A	PARTICIPANT	\N	PRESENT	0
521586	521584	04008A	PARTICIPANT	\N	PRESENT	0
521587	521584	19954N	PARTICIPANT	\N	PRESENT	0
521588	521584	14151M	PARTICIPANT	\N	PRESENT	0
521589	521584	20114U	PARTICIPANT	\N	PRESENT	0
521590	521584	19749K	PARTICIPANT	\N	PRESENT	0
521591	521584	14107H	PARTICIPANT	\N	PRESENT	0
521592	521584	04085P	PARTICIPANT	\N	PRESENT	0
521593	521584	19585H	PARTICIPANT	\N	PRESENT	0
521595	521594	14179A	PARTICIPANT	\N	PRESENT	0
521596	521594	04008A	PARTICIPANT	\N	PRESENT	0
521597	521594	19649G	PARTICIPANT	\N	PRESENT	0
521598	521594	20114U	PARTICIPANT	\N	PRESENT	0
521600	521599	14179A	PARTICIPANT	\N	PRESENT	0
521601	521599	04008A	PARTICIPANT	\N	PRESENT	0
521602	521599	14151M	PARTICIPANT	\N	PRESENT	0
521604	521603	14179A	PARTICIPANT	\N	PRESENT	0
523488	523487	17737W	PARTICIPANT	\N	PRESENT	0
523489	523487	19709B	PARTICIPANT	\N	PRESENT	0
523777	523776	14255U	PARTICIPANT	\N	PRESENT	0
523778	523776	19701S	PARTICIPANT	\N	PRESENT	0
523779	523776	14179A	PARTICIPANT	\N	PRESENT	0
523780	523776	01025N	PARTICIPANT	\N	PRESENT	0
523781	523776	97011G	PARTICIPANT	\N	PRESENT	0
525050	522571	19399H	PARTICIPANT	\N	PRESENT	0
525051	522571	08012N	PARTICIPANT	\N	EXCUSE	0
525124	524076	19741B	PARTICIPANT	\N	PRESENT	1
525125	524076	11053K	PARTICIPANT	\N	PRESENT	1
525126	524076	19545Y	PARTICIPANT	\N	PRESENT	1
525127	524076	11110B	PARTICIPANT	\N	PRESENT	1
525128	524076	14121F	PARTICIPANT	\N	PRESENT	1
525129	524076	08010L	PARTICIPANT	\N	PRESENT	1
525130	524076	12016W	PARTICIPANT	\N	PRESENT	1
525131	524076	20050V	PARTICIPANT	\N	PRESENT	1
525132	524076	19349W	PARTICIPANT	\N	PRESENT	1
525133	524076	20044X	PARTICIPANT	\N	PRESENT	1
525134	524076	19479G	PARTICIPANT	\N	PRESENT	1
525507	518916	05008E	PARTICIPANT	\N	EXCUSE	0
525510	525245	04092N	PARTICIPANT	\N	PRESENT	1
525511	525245	18193Q	PARTICIPANT	\N	PRESENT	1
525513	525245	19301E	PARTICIPANT	\N	PRESENT	1
525822	525820	20130U	PARTICIPANT	\N	PRESENT	0
525823	525820	19679N	PARTICIPANT	\N	PRESENT	0
526534	526522	04070G	PARTICIPANT	\N	PRESENT	0
526535	526522	20094J	PARTICIPANT	\N	PRESENT	0
527017	527015	18083K	PARTICIPANT	\N	PRESENT	0
527018	527015	19735D	PARTICIPANT	\N	PRESENT	0
527019	527015	01043Q	PARTICIPANT	\N	PRESENT	0
527020	527015	14205J	PARTICIPANT	\N	PRESENT	0
527021	527015	19762G	PARTICIPANT	\N	PRESENT	0
527022	527015	20062A	PARTICIPANT	\N	PRESENT	0
527023	527015	14173T	PARTICIPANT	\N	PRESENT	0
531379	531378	08010L	PARTICIPANT	\N	PRESENT	0
531381	531380	11048N	PARTICIPANT	\N	PRESENT	0
531383	531382	11048N	PARTICIPANT	\N	PRESENT	0
531384	531382	08011M	PARTICIPANT	\N	PRESENT	0
531386	531385	11048N	PARTICIPANT	\N	PRESENT	0
531387	531385	08011M	PARTICIPANT	\N	PRESENT	0
531389	531388	19599P	PARTICIPANT	\N	PRESENT	0
531390	531388	19503N	PARTICIPANT	\N	PRESENT	0
534854	534254	20086J	PARTICIPANT	\N	PRESENT	0
534855	534254	20024T	PARTICIPANT	\N	PRESENT	0
534856	534254	14147R	PARTICIPANT	\N	PRESENT	0
534857	534254	11048N	PARTICIPANT	\N	PRESENT	0
534858	534254	20022R	PARTICIPANT	\N	PRESENT	0
534859	534254	08010L	PARTICIPANT	\N	PRESENT	0
534860	534254	01057W	PARTICIPANT	\N	PRESENT	0
534861	534254	19711U	PARTICIPANT	\N	PRESENT	0
534862	534254	97011G	PARTICIPANT	\N	PRESENT	0
534863	534254	08034U	PARTICIPANT	\N	PRESENT	0
534864	534254	20032T	PARTICIPANT	\N	PRESENT	0
534865	534254	14187A	PARTICIPANT	\N	PRESENT	0
534866	534254	20180F	PARTICIPANT	\N	PRESENT	0
534867	534254	19447X	PARTICIPANT	\N	PRESENT	0
534868	534254	14031R	PARTICIPANT	\N	PRESENT	0
534869	534254	19441R	PARTICIPANT	\N	PRESENT	0
534874	534254	20080C	PARTICIPANT	\N	PRESENT	0
534875	534254	19347U	PARTICIPANT	\N	PRESENT	0
534876	534254	20056C	PARTICIPANT	\N	PRESENT	0
534877	534254	20026V	PARTICIPANT	\N	PRESENT	0
534878	534254	20100N	PARTICIPANT	\N	PRESENT	0
534879	534254	19611R	PARTICIPANT	\N	PRESENT	0
534880	534254	14249W	PARTICIPANT	\N	PRESENT	0
534881	534254	19762G	PARTICIPANT	\N	PRESENT	0
534882	534254	19507S	PARTICIPANT	\N	PRESENT	0
534883	534254	20136B	PARTICIPANT	\N	PRESENT	0
534884	534254	19758L	PARTICIPANT	\N	PRESENT	0
534885	534254	19593H	PARTICIPANT	\N	PRESENT	0
534886	534254	20084G	PARTICIPANT	\N	PRESENT	0
534887	534254	04008A	PARTICIPANT	\N	PRESENT	0
534888	534254	20134Y	PARTICIPANT	\N	PRESENT	0
534889	534254	19782L	PARTICIPANT	\N	PRESENT	0
534890	534254	14073Q	PARTICIPANT	\N	PRESENT	0
534891	534254	14030Q	PARTICIPANT	\N	PRESENT	0
534892	534254	07029T	PARTICIPANT	\N	PRESENT	0
534893	534254	17637T	PARTICIPANT	\N	PRESENT	0
534894	534166	19954N	PARTICIPANT	\N	PRESENT	0
534895	534166	19729F	PARTICIPANT	\N	PRESENT	0
534852	534254	08015R	PARTICIPANT	\N	PRESENT	0
534853	534254	19479G	PARTICIPANT	\N	PRESENT	0
534896	534166	20074E	PARTICIPANT	\N	PRESENT	0
534897	534166	14147R	PARTICIPANT	\N	PRESENT	0
534898	534166	04047H	PRESIDENT	0	PRESENT	0
534899	534166	19749K	PARTICIPANT	\N	PRESENT	0
534900	534166	19673G	PARTICIPANT	\N	PRESENT	0
534901	534166	05008E	PARTICIPANT	\N	PRESENT	0
534902	534166	19447X	PARTICIPANT	\N	PRESENT	0
534903	534254	14069U	PARTICIPANT	\N	PRESENT	0
534904	534254	19703U	PARTICIPANT	\N	PRESENT	0
534906	534254	19798U	PARTICIPANT	\N	PRESENT	0
534907	534254	19333N	PARTICIPANT	\N	PRESENT	0
534908	534254	19467C	PARTICIPANT	\N	PRESENT	0
534909	534254	14109K	PARTICIPANT	\N	PRESENT	0
534910	534166	14179A	PARTICIPANT	\N	PRESENT	0
534911	534166	14215L	PARTICIPANT	\N	PRESENT	0
534912	534254	20142Y	PARTICIPANT	\N	PRESENT	0
534913	534254	14071N	PARTICIPANT	\N	PRESENT	0
534914	534254	11043H	PARTICIPANT	\N	PRESENT	0
534916	534254	11053K	PARTICIPANT	\N	PRESENT	0
534917	534254	19349W	PARTICIPANT	\N	PRESENT	0
536626	536625	20086J	PARTICIPANT	\N	PRESENT	0
536627	536625	14205J	PARTICIPANT	\N	PRESENT	0
536628	536625	20082E	PARTICIPANT	\N	PRESENT	0
536630	536629	20086J	PARTICIPANT	\N	PRESENT	0
536631	536629	14205J	PARTICIPANT	\N	PRESENT	0
536633	536632	20086J	PARTICIPANT	\N	PRESENT	0
536634	536632	14205J	PARTICIPANT	\N	PRESENT	0
536635	536632	20082E	PARTICIPANT	\N	PRESENT	0
536637	536636	08009T	PARTICIPANT	\N	PRESENT	0
536638	536636	19563B	PARTICIPANT	\N	PRESENT	0
536640	536639	08009T	PARTICIPANT	\N	PRESENT	0
536641	536639	19695N	PARTICIPANT	\N	PRESENT	0
536643	536642	04070G	PARTICIPANT	\N	PRESENT	0
536842	536841	19413M	PARTICIPANT	\N	PRESENT	0
536843	536841	20018V	PARTICIPANT	\N	PRESENT	0
536844	536841	19782L	PARTICIPANT	\N	PRESENT	0
536845	536841	14257W	PARTICIPANT	\N	PRESENT	0
536846	536841	14331P	PARTICIPANT	\N	PRESENT	0
536847	536841	14357A	PARTICIPANT	\N	PRESENT	0
536848	536841	11090Q	PARTICIPANT	\N	PRESENT	0
536849	536841	19503N	PARTICIPANT	\N	PRESENT	0
536850	536841	14097Y	PARTICIPANT	\N	PRESENT	0
536851	536841	14026U	PARTICIPANT	\N	PRESENT	0
536852	536841	11099A	PARTICIPANT	\N	PRESENT	0
537403	537402	14255U	PARTICIPANT	\N	PRESENT	0
537404	537402	20022R	PARTICIPANT	\N	PRESENT	0
537405	537402	10015M	PARTICIPANT	\N	PRESENT	0
537406	537402	14169X	PARTICIPANT	\N	PRESENT	0
537407	537402	19826F	PARTICIPANT	\N	PRESENT	0
537408	537402	19585H	PARTICIPANT	\N	PRESENT	0
537913	537912	17737W	PARTICIPANT	\N	PRESENT	0
537914	537912	19749K	PARTICIPANT	\N	PRESENT	0
537916	537915	19673G	PARTICIPANT	\N	PRESENT	0
537917	537915	19749K	PARTICIPANT	\N	PRESENT	0
537919	537918	19673G	PARTICIPANT	\N	PRESENT	0
537920	537918	14179A	PARTICIPANT	\N	PRESENT	0
537921	537918	19749K	PARTICIPANT	\N	PRESENT	0
539187	536833	14059S	PARTICIPANT	\N	PRESENT	0
539191	536833	19585H	PARTICIPANT	\N	PRESENT	0
539192	536833	01048V	PARTICIPANT	\N	PRESENT	0
539193	536834	99004R	PARTICIPANT	\N	PRESENT	0
539194	536834	20046A	PARTICIPANT	\N	PRESENT	0
539195	536834	20102Q	PARTICIPANT	\N	PRESENT	0
539196	536834	08060W	PARTICIPANT	\N	PRESENT	0
539197	536834	20106U	PARTICIPANT	\N	PRESENT	0
539198	536834	19637C	PARTICIPANT	\N	PRESENT	0
539199	536834	19387D	PARTICIPANT	\N	PRESENT	0
539200	536834	19251M	PARTICIPANT	\N	PRESENT	0
539201	536834	20100N	PARTICIPANT	\N	PRESENT	0
539202	536834	19489J	PARTICIPANT	\N	PRESENT	0
539203	536834	19711U	PARTICIPANT	\N	PRESENT	0
539204	536834	14031R	PARTICIPANT	\N	PRESENT	0
539262	538149	18193Q	PARTICIPANT	\N	PRESENT	1
539263	538149	14071N	PARTICIPANT	\N	PRESENT	1
539264	538149	04045F	PARTICIPANT	\N	PRESENT	1
539265	538149	19679N	PARTICIPANT	\N	PRESENT	1
539291	530851	14030Q	PARTICIPANT	\N	PRESENT	0
539292	530851	20026V	PARTICIPANT	\N	PRESENT	1
539293	530851	20132W	PARTICIPANT	\N	PRESENT	0
539294	530851	08012N	PARTICIPANT	\N	PRESENT	1
539295	530851	20180F	PARTICIPANT	\N	PRESENT	0
539296	530851	20142Y	PARTICIPANT	\N	PRESENT	1
539297	530851	19651A	PARTICIPANT	\N	PRESENT	0
539298	530851	20048C	PARTICIPANT	\N	PRESENT	1
539299	530851	19735D	PARTICIPANT	\N	PRESENT	0
539301	530851	20052X	PARTICIPANT	\N	PRESENT	1
539309	534423	14231L	PRESIDENT	0	PRESENT	0
539319	534423	08010L	PARTICIPANT	\N	PRESENT	0
539320	534423	14107H	PARTICIPANT	\N	PRESENT	0
539184	536833	19695N	PARTICIPANT	\N	PRESENT	0
539185	536833	19667J	PARTICIPANT	\N	PRESENT	0
539321	534423	14327T	PARTICIPANT	\N	PRESENT	0
539322	534423	04045F	PARTICIPANT	\N	PRESENT	0
539323	534423	20122U	PARTICIPANT	\N	PRESENT	0
539324	534423	14069U	PARTICIPANT	\N	PRESENT	0
539325	534423	20120S	PARTICIPANT	\N	PRESENT	0
539326	534423	19735D	PARTICIPANT	\N	PRESENT	0
539327	534423	01057W	PARTICIPANT	\N	PRESENT	0
539328	534423	20022R	PARTICIPANT	\N	PRESENT	0
539329	534423	20058E	PARTICIPANT	\N	PRESENT	0
539330	534423	19758L	PARTICIPANT	\N	PRESENT	0
539331	534423	19565D	PARTICIPANT	\N	PRESENT	0
539332	534423	20090E	PARTICIPANT	\N	PRESENT	0
539333	534423	04086Q	PARTICIPANT	\N	PRESENT	0
539334	534423	14071N	PARTICIPANT	\N	PRESENT	0
539335	534423	05012A	PARTICIPANT	\N	PRESENT	0
539336	534423	19349W	PARTICIPANT	\N	PRESENT	0
539337	534423	14187A	PARTICIPANT	\N	PRESENT	0
539339	534423	20110Q	PARTICIPANT	\N	PRESENT	0
539240	536834	01048V	PARTICIPANT	\N	PRESENT	0
539241	536834	19369B	PARTICIPANT	\N	PRESENT	0
539242	536834	14219Q	PARTICIPANT	\N	PRESENT	0
539340	534423	17637T	PARTICIPANT	\N	PRESENT	0
539341	534423	20040T	PARTICIPANT	\N	PRESENT	0
539342	534423	11097X	PARTICIPANT	\N	PRESENT	0
539343	534423	14213J	PARTICIPANT	\N	PRESENT	0
539344	534423	14219Q	PARTICIPANT	\N	PRESENT	0
539345	534423	19713W	PARTICIPANT	\N	PRESENT	0
539346	534423	18193Q	PARTICIPANT	\N	PRESENT	0
539347	534423	10006L	PARTICIPANT	\N	PRESENT	0
539348	534423	14042U	PARTICIPANT	\N	PRESENT	0
539349	534423	19657G	PARTICIPANT	\N	PRESENT	0
539350	534423	14205J	PARTICIPANT	\N	PRESENT	0
539351	534423	19387D	PARTICIPANT	\N	PRESENT	0
539352	534423	19577H	PARTICIPANT	\N	PRESENT	0
539353	534423	20038A	PARTICIPANT	\N	PRESENT	0
539440	534423	20084G	PARTICIPANT	\N	EXCUSE	0
539695	539694	04057K	PARTICIPANT	\N	PRESENT	0
539696	539694	11083R	PARTICIPANT	\N	PRESENT	0
539697	539694	11064N	PARTICIPANT	\N	PRESENT	0
539698	539694	20062A	PARTICIPANT	\N	PRESENT	0
539699	539694	19585H	PARTICIPANT	\N	PRESENT	0
539720	539682	14001X	PARTICIPANT	\N	PRESENT	0
539721	539682	04047H	PRESIDENT	0	PRESENT	0
539722	539682	01028R	PARTICIPANT	\N	PRESENT	0
539723	539682	05008E	PARTICIPANT	\N	PRESENT	0
539724	539682	19447X	PARTICIPANT	\N	PRESENT	0
539725	539682	14089Y	PARTICIPANT	\N	PRESENT	0
539726	539682	19954N	PARTICIPANT	\N	PRESENT	0
539727	539682	19729F	PARTICIPANT	\N	PRESENT	0
539728	539682	95063L	PARTICIPANT	\N	PRESENT	0
539729	539682	14041T	PARTICIPANT	\N	PRESENT	0
539730	539682	20110Q	PARTICIPANT	\N	PRESENT	0
539731	539682	14179A	PARTICIPANT	\N	PRESENT	0
539732	539682	14151M	PARTICIPANT	\N	PRESENT	0
539733	539682	14215L	PARTICIPANT	\N	PRESENT	0
539734	539682	04008A	PARTICIPANT	\N	PRESENT	0
539735	539682	14259Y	PARTICIPANT	\N	PRESENT	0
539736	539682	11072N	PARTICIPANT	\N	PRESENT	0
539737	539682	14069U	PARTICIPANT	\N	PRESENT	0
539754	534228	04070G	PARTICIPANT	\N	EXCUSE	0
539756	539755	11031D	PARTICIPANT	\N	PRESENT	0
539758	539757	14255U	PARTICIPANT	\N	PRESENT	0
539759	539757	14083S	PARTICIPANT	\N	PRESENT	0
539760	539757	11031D	PARTICIPANT	\N	PRESENT	0
539761	539757	14169X	PARTICIPANT	\N	PRESENT	0
539762	539757	19585H	PARTICIPANT	\N	PRESENT	0
539763	539757	08073C	PARTICIPANT	\N	PRESENT	0
539773	539548	20090E	PARTICIPANT	\N	PRESENT	0
539766	535603	19347U	PARTICIPANT	\N	EXCUSE	0
539767	535603	11109J	PARTICIPANT	\N	EXCUSE	0
539768	535603	19659J	PARTICIPANT	\N	EXCUSE	0
539769	535603	19717B	PARTICIPANT	\N	PRESENT	0
539770	535603	19691J	PARTICIPANT	\N	PRESENT	0
539772	539548	14026U	PARTICIPANT	\N	PRESENT	0
539774	539548	19399H	PARTICIPANT	\N	PRESENT	0
539775	539548	19629C	PARTICIPANT	\N	PRESENT	0
539776	539548	20054A	PARTICIPANT	\N	PRESENT	0
539777	539548	20076G	PARTICIPANT	\N	PRESENT	0
539778	539548	20180F	PARTICIPANT	\N	PRESENT	0
539779	539548	20032T	PARTICIPANT	\N	PRESENT	0
539780	539548	14041T	PARTICIPANT	\N	PRESENT	0
539781	539548	11066Q	PARTICIPANT	\N	PRESENT	0
539782	529005	19735D	PARTICIPANT	\N	EXCUSE	0
539783	539548	04085P	PARTICIPANT	\N	PRESENT	0
539784	539548	04008A	PARTICIPANT	\N	PRESENT	0
539785	539548	14223L	PARTICIPANT	\N	PRESENT	0
539786	539548	19507S	PARTICIPANT	\N	PRESENT	0
539787	539548	99004R	PARTICIPANT	\N	PRESENT	0
539788	539548	19798U	PARTICIPANT	\N	PRESENT	0
539789	539548	14147R	PARTICIPANT	\N	PRESENT	0
518872	518866	14189C	PARTICIPANT	\N	PRESENT	0
518874	518866	20138D	PARTICIPANT	\N	PRESENT	0
518875	518866	19966S	PARTICIPANT	\N	PRESENT	0
518876	518866	14105F	PARTICIPANT	\N	PRESENT	0
518877	518866	20140W	PARTICIPANT	\N	PRESENT	0
518878	518866	14041T	PARTICIPANT	\N	PRESENT	0
518879	518866	14187A	PARTICIPANT	\N	PRESENT	0
518880	518866	08018U	PARTICIPANT	\N	PRESENT	0
518881	518866	20048C	PARTICIPANT	\N	PRESENT	0
518882	518866	19399H	PARTICIPANT	\N	PRESENT	0
518883	518866	08010L	PARTICIPANT	\N	PRESENT	0
518884	518866	20052X	PARTICIPANT	\N	PRESENT	0
518885	518866	14147R	PARTICIPANT	\N	PRESENT	0
518886	518866	19703U	PARTICIPANT	\N	PRESENT	0
518887	518866	20136B	PARTICIPANT	\N	PRESENT	0
518890	518888	17965H	PARTICIPANT	\N	PRESENT	0
518891	518888	11045K	PARTICIPANT	\N	PRESENT	0
518892	518889	11045K	PARTICIPANT	\N	PRESENT	0
518893	518889	17965H	PARTICIPANT	\N	PRESENT	0
521795	521473	20084G	PARTICIPANT	\N	PRESENT	0
521796	521473	19798U	PARTICIPANT	\N	PRESENT	0
521797	521473	19725B	PARTICIPANT	\N	PRESENT	0
521798	521473	19629C	PARTICIPANT	\N	PRESENT	0
521799	521473	11033F	PARTICIPANT	\N	PRESENT	0
521800	521473	14069U	PARTICIPANT	\N	PRESENT	0
521801	521473	08056B	PARTICIPANT	\N	PRESENT	0
521802	521473	14031R	PARTICIPANT	\N	PRESENT	0
521803	521473	19383Y	PARTICIPANT	\N	PRESENT	0
521804	521473	08015R	PARTICIPANT	\N	PRESENT	0
521805	521473	14033T	PARTICIPANT	\N	PRESENT	0
521806	521473	19760E	PARTICIPANT	\N	PRESENT	0
521807	521473	14021P	PARTICIPANT	\N	PRESENT	0
521808	521473	01028R	PARTICIPANT	\N	PRESENT	0
521809	521473	19741B	PARTICIPANT	\N	PRESENT	0
521810	521473	14055N	PARTICIPANT	\N	PRESENT	0
521811	521473	11109J	PARTICIPANT	\N	PRESENT	0
521812	521473	19367Y	PARTICIPANT	\N	PRESENT	0
521813	521473	19671E	PARTICIPANT	\N	PRESENT	0
521814	521473	19599P	PARTICIPANT	\N	PRESENT	0
521816	521473	20128B	PARTICIPANT	\N	PRESENT	0
521817	521473	19749K	PARTICIPANT	\N	PRESENT	0
521818	521473	14083S	PARTICIPANT	\N	PRESENT	0
521819	521473	14231L	PARTICIPANT	\N	PRESENT	0
521820	521473	14026U	PARTICIPANT	\N	PRESENT	0
521821	521473	05008E	PARTICIPANT	\N	PRESENT	0
521822	521473	20136B	PARTICIPANT	\N	PRESENT	0
521823	521473	14133K	PARTICIPANT	\N	PRESENT	0
521824	521473	08061X	PARTICIPANT	\N	PRESENT	0
521825	521473	19573D	PARTICIPANT	\N	PRESENT	0
524026	521478	20038A	PARTICIPANT	\N	PRESENT	0
524027	521478	19621T	PARTICIPANT	\N	PRESENT	0
524028	521478	19611R	PARTICIPANT	\N	PRESENT	0
524029	521478	20052X	PARTICIPANT	\N	PRESENT	0
524030	521478	19533U	PARTICIPANT	\N	PRESENT	0
524031	521478	14021P	PARTICIPANT	\N	PRESENT	0
524208	522571	19479G	PARTICIPANT	\N	PRESENT	0
524246	522571	04070G	PARTICIPANT	\N	PRESENT	0
525306	525289	14221J	PARTICIPANT	\N	PRESENT	0
525307	525289	20018V	PARTICIPANT	\N	PRESENT	0
525308	525289	19768N	PARTICIPANT	\N	PRESENT	0
525309	525289	19503N	PARTICIPANT	\N	PRESENT	0
525310	525289	14107H	PARTICIPANT	\N	PRESENT	0
525311	525289	20044X	PARTICIPANT	\N	PRESENT	0
525312	525289	11043H	PARTICIPANT	\N	PRESENT	0
525313	525289	20058E	PARTICIPANT	\N	PRESENT	0
524024	521478	14069U	PARTICIPANT	\N	PRESENT	0
524025	521478	19467C	PARTICIPANT	\N	PRESENT	0
525882	525881	20042V	PARTICIPANT	\N	PRESENT	0
525883	525881	14267Y	PARTICIPANT	\N	PRESENT	0
525884	525881	20070A	PARTICIPANT	\N	PRESENT	0
525885	525881	17229F	PARTICIPANT	\N	PRESENT	0
525886	525881	04035D	PARTICIPANT	\N	PRESENT	0
525887	525881	19347U	PARTICIPANT	\N	PRESENT	0
525888	525881	20084G	PARTICIPANT	\N	PRESENT	0
525889	525881	19687N	PARTICIPANT	\N	PRESENT	0
525890	525881	10015M	PARTICIPANT	\N	PRESENT	0
525891	525881	11026G	PARTICIPANT	\N	PRESENT	0
526284	526282	14169X	PARTICIPANT	\N	PRESENT	0
526285	526282	04070G	PARTICIPANT	\N	PRESENT	0
526406	526405	14225N	PARTICIPANT	\N	PRESENT	0
526407	526405	19531S	PARTICIPANT	\N	PRESENT	0
526408	526405	14257W	PARTICIPANT	\N	PRESENT	0
526409	526405	20050V	PARTICIPANT	\N	PRESENT	0
526410	526405	95063L	PARTICIPANT	\N	PRESENT	0
526411	526405	19760E	PARTICIPANT	\N	PRESENT	0
526412	526405	18083K	PARTICIPANT	\N	PRESENT	0
526493	526492	86034E	PARTICIPANT	\N	PRESENT	0
526494	526492	99004R	PARTICIPANT	\N	PRESENT	0
526495	526492	11045K	PARTICIPANT	\N	PRESENT	0
526496	526492	01043Q	PARTICIPANT	\N	PRESENT	0
526497	526492	08073C	PARTICIPANT	\N	PRESENT	0
526498	526492	12041X	PARTICIPANT	\N	PRESENT	0
526499	526492	14026U	PARTICIPANT	\N	PRESENT	0
526500	526492	11070L	PARTICIPANT	\N	PRESENT	0
526501	526492	05008E	PARTICIPANT	\N	PRESENT	0
526502	526492	11053K	PARTICIPANT	\N	PRESENT	0
526503	526492	11033F	PARTICIPANT	\N	PRESENT	0
526504	526492	19673G	PARTICIPANT	\N	PRESENT	0
526505	526492	19599P	PARTICIPANT	\N	PRESENT	0
526506	526492	14033T	PARTICIPANT	\N	PRESENT	0
526507	526492	14123H	PARTICIPANT	\N	PRESENT	0
526508	526492	11064N	PARTICIPANT	\N	PRESENT	0
526509	526492	14179A	PARTICIPANT	\N	PRESENT	0
526510	526492	14213J	PARTICIPANT	\N	PRESENT	0
526733	524591	18193Q	PARTICIPANT	\N	PRESENT	1
526512	526492	14147R	PARTICIPANT	\N	PRESENT	0
526513	526492	04045F	PARTICIPANT	\N	PRESENT	0
526732	526653	19697Q	PARTICIPANT	\N	EXCUSE	0
528668	526543	11045K	PARTICIPANT	\N	PRESENT	0
528708	528706	19701S	PARTICIPANT	\N	PRESENT	0
528709	528706	14213J	PARTICIPANT	\N	PRESENT	0
528710	528706	19577H	PARTICIPANT	\N	PRESENT	0
528711	528706	20106U	PARTICIPANT	\N	PRESENT	0
528712	528706	19549D	PARTICIPANT	\N	PRESENT	0
528713	528706	20124W	PARTICIPANT	\N	PRESENT	0
528714	528706	19387D	PARTICIPANT	\N	PRESENT	0
528715	528706	14069U	PARTICIPANT	\N	PRESENT	0
528716	528706	19347U	PARTICIPANT	\N	PRESENT	0
528717	528706	19820Y	PARTICIPANT	\N	PRESENT	0
528718	528706	14073Q	PARTICIPANT	\N	PRESENT	0
528719	528706	20100N	PARTICIPANT	\N	PRESENT	0
528721	526543	11040E	PARTICIPANT	\N	PRESENT	0
528722	526543	12041X	PARTICIPANT	\N	PRESENT	0
528723	526543	14001X	PARTICIPANT	\N	PRESENT	0
528724	526543	20100N	PARTICIPANT	\N	PRESENT	0
528725	526543	11083R	PARTICIPANT	\N	PRESENT	0
528726	526543	20128B	PARTICIPANT	\N	PRESENT	0
528727	526543	08061X	PARTICIPANT	\N	PRESENT	0
528728	526543	04057K	PARTICIPANT	\N	PRESENT	0
528729	526543	19531S	PARTICIPANT	\N	PRESENT	0
528730	526543	19399H	PARTICIPANT	\N	PRESENT	0
528731	526543	18083K	PARTICIPANT	\N	PRESENT	0
528732	526543	14331P	PARTICIPANT	\N	PRESENT	0
528733	526543	19335Q	PARTICIPANT	\N	PRESENT	0
528734	526543	11048N	PARTICIPANT	\N	PRESENT	0
528735	526543	14225N	PARTICIPANT	\N	PRESENT	0
528736	526543	20070A	PARTICIPANT	\N	PRESENT	0
528737	526543	14041T	PARTICIPANT	\N	PRESENT	0
528738	526543	20126Y	PARTICIPANT	\N	PRESENT	0
528739	526543	19711U	PARTICIPANT	\N	PRESENT	0
528740	526543	14133K	PARTICIPANT	\N	PRESENT	0
528741	526543	01048V	PARTICIPANT	\N	PRESENT	0
528742	526543	10015M	PARTICIPANT	\N	PRESENT	0
528743	526543	19689Q	PARTICIPANT	\N	PRESENT	0
528744	526543	11070L	PARTICIPANT	\N	PRESENT	0
528745	526543	19709B	PARTICIPANT	\N	PRESENT	0
528746	526543	19747H	PARTICIPANT	\N	PRESENT	0
528752	526543	20036X	PARTICIPANT	\N	PRESENT	0
528764	526543	11012A	PARTICIPANT	\N	PRESENT	0
528765	526543	19701S	PARTICIPANT	\N	PRESENT	0
528766	526543	14026U	PARTICIPANT	\N	PRESENT	0
528767	526543	14030Q	PARTICIPANT	\N	PRESENT	0
528768	526543	14073Q	PARTICIPANT	\N	PRESENT	0
528770	526543	20116W	PARTICIPANT	\N	PRESENT	0
528771	526543	19441R	PARTICIPANT	\N	PRESENT	0
528783	526543	20090E	PARTICIPANT	\N	PRESENT	0
528787	526543	11026G	PARTICIPANT	\N	PRESENT	0
528798	526543	14053L	PARTICIPANT	\N	PRESENT	0
528799	526543	14249W	PARTICIPANT	\N	PRESENT	0
528800	526543	11053K	PARTICIPANT	\N	PRESENT	0
528801	526543	19333N	PARTICIPANT	\N	PRESENT	0
529639	529076	20024T	PARTICIPANT	\N	PRESENT	0
529640	529076	14073Q	PARTICIPANT	\N	PRESENT	0
529641	529076	14069U	PARTICIPANT	\N	PRESENT	0
529642	529076	08015R	PARTICIPANT	\N	PRESENT	0
529643	529076	14213J	PARTICIPANT	\N	PRESENT	0
529644	529076	11033F	PARTICIPANT	\N	PRESENT	0
529645	529167	19383Y	PRESIDENT	1	PRESENT	0
529646	529167	19467C	PARTICIPANT	\N	PRESENT	0
529647	529167	14133K	PARTICIPANT	\N	PRESENT	0
529648	529167	19713W	PARTICIPANT	\N	PRESENT	0
529649	529167	19441R	PARTICIPANT	\N	PRESENT	0
529650	529167	19719D	PARTICIPANT	\N	PRESENT	0
529651	529167	19637C	PARTICIPANT	\N	PRESENT	1
529652	529167	11099A	PARTICIPANT	\N	PRESENT	0
529653	529167	14109K	PARTICIPANT	\N	PRESENT	1
529654	529167	19758L	PARTICIPANT	\N	PRESENT	0
529655	529167	20026V	PARTICIPANT	\N	PRESENT	0
529656	529167	17589D	PARTICIPANT	\N	PRESENT	0
529657	529167	19621T	PARTICIPANT	\N	PRESENT	0
529658	529167	20028X	PARTICIPANT	\N	PRESENT	0
529659	529167	19762G	PARTICIPANT	\N	PRESENT	0
529660	529076	19820Y	PARTICIPANT	\N	PRESENT	0
529661	529076	20048C	PARTICIPANT	\N	PRESENT	0
529662	529076	14042U	PARTICIPANT	\N	PRESENT	0
529663	529076	19447X	PARTICIPANT	\N	PRESENT	0
529637	529076	18083K	PARTICIPANT	\N	PRESENT	0
529638	529076	20062A	PARTICIPANT	\N	PRESENT	0
529664	529076	20034V	PARTICIPANT	\N	PRESENT	0
529665	529076	14038Y	PARTICIPANT	\N	PRESENT	0
529666	529076	19741B	PARTICIPANT	\N	PRESENT	0
529667	529076	19685L	PARTICIPANT	\N	PRESENT	0
529668	529076	20100N	PARTICIPANT	\N	PRESENT	0
529670	529076	14147R	PARTICIPANT	\N	PRESENT	0
529671	529076	20104S	PARTICIPANT	\N	PRESENT	0
529672	529076	20096L	PARTICIPANT	\N	PRESENT	0
529673	529076	19667J	PARTICIPANT	\N	PRESENT	0
529674	529076	20066E	PARTICIPANT	\N	PRESENT	0
529741	529077	11056N	PARTICIPANT	\N	PRESENT	0
529742	529077	04085P	PARTICIPANT	\N	PRESENT	0
529743	529077	19565D	PARTICIPANT	\N	PRESENT	0
529744	529077	20046A	PARTICIPANT	\N	PRESENT	0
529745	529077	20100N	PARTICIPANT	\N	PRESENT	0
529746	529077	20092G	PARTICIPANT	\N	PRESENT	0
529747	529077	11033F	PARTICIPANT	\N	PRESENT	0
529748	529077	14121F	PARTICIPANT	\N	PRESENT	0
529749	529077	19820Y	PARTICIPANT	\N	PRESENT	0
529750	529077	20082E	PARTICIPANT	\N	PRESENT	0
529751	529077	19715Y	PARTICIPANT	\N	PRESENT	0
529752	529077	11067R	PARTICIPANT	\N	PRESENT	0
529753	529077	20114U	PARTICIPANT	\N	PRESENT	0
529754	529077	04045F	PARTICIPANT	\N	PRESENT	0
529755	529077	19651A	PARTICIPANT	\N	PRESENT	0
529756	529077	11072N	PARTICIPANT	\N	PRESENT	0
529757	529077	11064N	PARTICIPANT	\N	PRESENT	0
529758	529077	01024M	PARTICIPANT	\N	PRESENT	0
529759	529077	19691J	PARTICIPANT	\N	PRESENT	0
529760	529077	20066E	PARTICIPANT	\N	PRESENT	0
529761	529077	14042U	PARTICIPANT	\N	PRESENT	0
529762	529077	19826F	PARTICIPANT	\N	PRESENT	0
529763	529077	14083S	PARTICIPANT	\N	PRESENT	0
529764	529077	19685L	PARTICIPANT	\N	PRESENT	0
529765	529077	19671E	PARTICIPANT	\N	PRESENT	0
529766	529077	19533U	PARTICIPANT	\N	PRESENT	0
529767	529077	20024T	PARTICIPANT	\N	PRESENT	0
529768	529077	20062A	PARTICIPANT	\N	PRESENT	0
529769	529077	08015R	PARTICIPANT	\N	PRESENT	0
529770	529077	19573D	PARTICIPANT	\N	PRESENT	0
529771	529077	20104S	PARTICIPANT	\N	PRESENT	0
529772	529077	14213J	PARTICIPANT	\N	PRESENT	0
529773	529077	19703U	PARTICIPANT	\N	PRESENT	0
529774	529077	14147R	PARTICIPANT	\N	PRESENT	0
529775	529077	19693L	PARTICIPANT	\N	PRESENT	0
529776	529077	19679N	PARTICIPANT	\N	PRESENT	0
529777	529077	19415P	PARTICIPANT	\N	PRESENT	0
529778	529077	19711U	PARTICIPANT	\N	PRESENT	0
529779	529077	10006L	PARTICIPANT	\N	PRESENT	0
529780	529077	20038A	PARTICIPANT	\N	PRESENT	0
529781	529077	19667J	PARTICIPANT	\N	PRESENT	0
529782	529077	19447X	PARTICIPANT	\N	PRESENT	0
529787	529077	18083K	PARTICIPANT	\N	PRESENT	0
529784	529077	20096L	PARTICIPANT	\N	PRESENT	0
529785	529077	14187A	PARTICIPANT	\N	PRESENT	0
529789	529077	19543W	PARTICIPANT	\N	PRESENT	0
529788	529077	20034V	PARTICIPANT	\N	PRESENT	0
529790	529077	20044X	PARTICIPANT	\N	PRESENT	0
529791	529077	20032T	PARTICIPANT	\N	PRESENT	0
529792	529077	19369B	PARTICIPANT	\N	PRESENT	0
529793	529077	20018V	PARTICIPANT	\N	PRESENT	0
529794	529077	20086J	PARTICIPANT	\N	PRESENT	0
529795	529077	14069U	PARTICIPANT	\N	PRESENT	0
529796	529077	20052X	PARTICIPANT	\N	PRESENT	0
529797	529077	19349W	PARTICIPANT	\N	PRESENT	0
529798	529077	19507S	PARTICIPANT	\N	PRESENT	0
529799	529077	14217N	PARTICIPANT	\N	PRESENT	0
529800	529077	20142Y	PARTICIPANT	\N	PRESENT	0
529801	529077	19467C	PARTICIPANT	\N	PRESENT	0
529802	529077	19798U	PARTICIPANT	\N	PRESENT	0
529803	529077	11012A	PARTICIPANT	\N	PRESENT	0
529804	529077	14030Q	PARTICIPANT	\N	PRESENT	0
529805	529077	19719D	PARTICIPANT	\N	PRESENT	0
529806	529077	19383Y	PARTICIPANT	\N	PRESENT	0
529739	529077	20090E	PARTICIPANT	\N	PRESENT	0
529740	529077	11070L	PARTICIPANT	\N	PRESENT	0
529809	529077	19629C	PARTICIPANT	\N	PRESENT	0
529810	529077	20028X	PARTICIPANT	\N	PRESENT	0
529811	529077	20116W	PARTICIPANT	\N	PRESENT	0
529812	529077	19687N	PARTICIPANT	\N	PRESENT	0
529813	529077	19758L	PARTICIPANT	\N	PRESENT	0
529814	529077	12041X	PARTICIPANT	\N	PRESENT	0
529844	529080	19669L	PARTICIPANT	\N	PRESENT	0
529845	529080	11074Q	PARTICIPANT	\N	PRESENT	0
529846	529080	11054L	PARTICIPANT	\N	PRESENT	0
529847	529080	11053K	PARTICIPANT	\N	PRESENT	0
529848	529080	19611R	PARTICIPANT	\N	PRESENT	0
529849	529080	14231L	PARTICIPANT	\N	PRESENT	0
529850	529080	19647E	PARTICIPANT	\N	PRESENT	0
529851	529080	19349W	PARTICIPANT	\N	PRESENT	0
529852	529080	19651A	PARTICIPANT	\N	PRESENT	0
529853	529080	11012A	PARTICIPANT	\N	PRESENT	0
529854	529080	17637T	PARTICIPANT	\N	PRESENT	0
529855	529080	04071H	PARTICIPANT	\N	PRESENT	0
529856	529080	19399H	PARTICIPANT	\N	PRESENT	0
529857	529080	20044X	PARTICIPANT	\N	PRESENT	0
529858	529080	20086J	PARTICIPANT	\N	PRESENT	0
529859	529080	14033T	PARTICIPANT	\N	PRESENT	0
529860	529080	11090Q	PARTICIPANT	\N	PRESENT	0
529861	529080	20024T	PARTICIPANT	\N	PRESENT	0
529862	529080	11048N	PARTICIPANT	\N	PRESENT	0
529863	529080	19741B	PARTICIPANT	\N	PRESENT	0
529864	529080	04086Q	PARTICIPANT	\N	PRESENT	0
529865	529080	14213J	PARTICIPANT	\N	PRESENT	0
529866	529080	20122U	PARTICIPANT	\N	PRESENT	0
529867	529080	19689Q	PARTICIPANT	\N	PRESENT	0
529868	529080	19543W	PARTICIPANT	\N	PRESENT	0
529869	529080	19687N	PARTICIPANT	\N	PRESENT	0
529870	529080	20048C	PARTICIPANT	\N	PRESENT	0
529842	529080	99004R	PARTICIPANT	\N	PRESENT	0
529843	529080	08015R	PARTICIPANT	\N	PRESENT	0
529871	529080	19551W	PARTICIPANT	\N	PRESENT	0
529872	529080	19711U	PARTICIPANT	\N	PRESENT	0
529873	529080	12041X	PARTICIPANT	\N	PRESENT	0
529874	529080	07029T	PARTICIPANT	\N	PRESENT	0
529949	529946	08060W	PARTICIPANT	\N	PRESENT	0
529950	529946	05012A	PARTICIPANT	\N	PRESENT	0
529951	529946	19525U	PARTICIPANT	\N	PRESENT	0
529952	529946	17229F	PARTICIPANT	\N	PRESENT	0
529953	529946	20038A	PARTICIPANT	\N	PRESENT	0
529954	529946	19387D	PARTICIPANT	\N	PRESENT	0
529955	529946	19551W	PARTICIPANT	\N	PRESENT	0
529956	529946	20102Q	PARTICIPANT	\N	PRESENT	0
529957	529946	19637C	PARTICIPANT	\N	PRESENT	0
529958	529946	20136B	PARTICIPANT	\N	PRESENT	0
529960	529959	08060W	PARTICIPANT	\N	PRESENT	0
529961	529959	05012A	PARTICIPANT	\N	PRESENT	0
529962	529959	19525U	PARTICIPANT	\N	PRESENT	0
529963	529959	17229F	PARTICIPANT	\N	PRESENT	0
529964	529959	20038A	PARTICIPANT	\N	PRESENT	0
529965	529959	20100N	PARTICIPANT	\N	PRESENT	0
529966	529959	19387D	PARTICIPANT	\N	PRESENT	0
529967	529959	19551W	PARTICIPANT	\N	PRESENT	0
529968	529959	20102Q	PARTICIPANT	\N	PRESENT	0
523641	521237	19667J	PARTICIPANT	\N	PRESENT	1
523643	521237	11040E	PARTICIPANT	\N	PRESENT	1
523644	521237	20070A	PARTICIPANT	\N	PRESENT	1
523645	521237	14121F	PARTICIPANT	\N	PRESENT	1
523646	521237	08010L	PARTICIPANT	\N	PRESENT	1
523647	521237	19671E	PARTICIPANT	\N	PRESENT	1
523648	521237	20044X	PARTICIPANT	\N	PRESENT	1
523750	521237	11074Q	PARTICIPANT	\N	PRESENT	1
523856	521575	08028W	PARTICIPANT	\N	EXCUSE	0
523857	521575	19511N	PARTICIPANT	\N	PRESENT	0
524079	521432	14030Q	PARTICIPANT	\N	EXCUSE	0
524080	521432	19760E	PARTICIPANT	\N	EXCUSE	0
524081	521432	14195A	PARTICIPANT	\N	EXCUSE	0
524082	521432	08028W	PARTICIPANT	\N	EXCUSE	0
524083	521432	20040T	PARTICIPANT	\N	EXCUSE	0
524084	521432	16685X	PARTICIPANT	\N	EXCUSE	0
524085	521432	19697Q	PARTICIPANT	\N	EXCUSE	0
524099	522571	04008A	PARTICIPANT	\N	EXCUSE	0
525878	524078	19545Y	PARTICIPANT	\N	PRESENT	1
525879	524078	11110B	PARTICIPANT	\N	PRESENT	1
525880	524078	12016W	PARTICIPANT	\N	PRESENT	1
533655	529296	14237S	PARTICIPANT	\N	EXCUSE	0
533656	529296	19251M	PARTICIPANT	\N	PRESENT	0
533657	529296	19575F	PARTICIPANT	\N	PRESENT	0
533658	529296	20086J	PARTICIPANT	\N	PRESENT	0
533659	529296	19747H	PARTICIPANT	\N	PRESENT	0
533660	529296	11090Q	PARTICIPANT	\N	PRESENT	0
525876	524078	20080C	PARTICIPANT	\N	PRESENT	1
525877	524078	11053K	PARTICIPANT	\N	PRESENT	1
533685	531288	11065P	PARTICIPANT	\N	PRESENT	0
533686	531288	19333N	PARTICIPANT	\N	PRESENT	0
533861	531098	14107H	PARTICIPANT	\N	PRESENT	0
533862	531098	19489J	PARTICIPANT	\N	PRESENT	0
533863	531098	01057W	PARTICIPANT	\N	PRESENT	0
533864	531098	19735D	PARTICIPANT	\N	PRESENT	0
533865	531098	14069U	PARTICIPANT	\N	PRESENT	0
533866	531098	14257W	PARTICIPANT	\N	PRESENT	0
533867	531098	20120S	PARTICIPANT	\N	PRESENT	0
533868	531098	04086Q	PARTICIPANT	\N	PRESENT	0
533869	531098	14215L	PARTICIPANT	\N	PRESENT	0
533870	531098	17637T	PARTICIPANT	\N	PRESENT	0
533871	531098	19333N	PARTICIPANT	\N	PRESENT	0
533872	531098	14327T	PARTICIPANT	\N	PRESENT	0
533873	531098	14231L	PRESIDENT	0	PRESENT	0
533874	531098	05012A	PARTICIPANT	\N	PRESENT	0
533875	531098	19826F	PARTICIPANT	\N	PRESENT	0
533876	531098	14053L	PARTICIPANT	\N	PRESENT	0
533877	531098	20090E	PARTICIPANT	\N	PRESENT	0
533878	531098	20084G	PARTICIPANT	\N	PRESENT	0
533879	531098	20110Q	PARTICIPANT	\N	PRESENT	0
533880	531098	20058E	PARTICIPANT	\N	PRESENT	0
533881	531098	14187A	PARTICIPANT	\N	PRESENT	0
533882	531098	19758L	PARTICIPANT	\N	PRESENT	0
533883	531098	14071N	PARTICIPANT	\N	EXCUSE	0
534450	534287	18193Q	PRESIDENT	0	PRESENT	0
534453	534287	04045F	PARTICIPANT	\N	PRESENT	1
534454	534287	19367Y	PARTICIPANT	\N	PRESENT	0
534456	534287	19679N	PARTICIPANT	\N	PRESENT	0
534457	534287	20018V	PRESIDENT	1	PRESENT	0
534459	534287	19760E	PARTICIPANT	\N	PRESENT	0
534460	534287	14187A	PARTICIPANT	\N	PRESENT	0
534461	534287	20066E	PARTICIPANT	\N	PRESENT	0
534462	534287	20040T	PARTICIPANT	\N	PRESENT	0
534470	534287	19657G	PARTICIPANT	\N	PRESENT	1
534495	534287	17965H	PARTICIPANT	\N	PRESENT	1
534567	534287	20130U	PARTICIPANT	\N	PRESENT	0
534622	534287	19703U	PARTICIPANT	\N	PRESENT	0
534642	534287	20098N	PARTICIPANT	\N	PRESENT	0
534661	534287	11053K	PARTICIPANT	\N	PRESENT	0
534681	534287	19631V	PARTICIPANT	\N	PRESENT	1
534987	534255	19565D	PARTICIPANT	\N	PRESENT	0
534988	534255	19651A	PARTICIPANT	\N	PRESENT	0
534989	534255	19349W	PARTICIPANT	\N	PRESENT	0
534990	534255	20134Y	PARTICIPANT	\N	PRESENT	0
534991	534255	19347U	PARTICIPANT	\N	PRESENT	0
534992	534255	20092G	PARTICIPANT	\N	PRESENT	0
534993	534255	20142Y	PARTICIPANT	\N	PRESENT	0
534994	534255	19527W	PARTICIPANT	\N	PRESENT	0
534995	534255	20100N	PARTICIPANT	\N	PRESENT	0
534996	534255	19631V	PARTICIPANT	\N	PRESENT	0
534997	534255	20080C	PARTICIPANT	\N	PRESENT	0
534998	534255	20084G	PARTICIPANT	\N	PRESENT	0
534999	534255	14109K	PARTICIPANT	\N	PRESENT	0
535000	534255	19333N	PARTICIPANT	\N	PRESENT	0
535001	534255	20112S	PARTICIPANT	\N	PRESENT	0
535002	534255	19629C	PARTICIPANT	\N	PRESENT	0
535003	534255	19387D	PARTICIPANT	\N	PRESENT	0
535004	534255	14042U	PARTICIPANT	\N	PRESENT	0
535005	534255	14030Q	PARTICIPANT	\N	PRESENT	0
535006	534166	01028R	PARTICIPANT	\N	PRESENT	0
535007	534255	19611R	PARTICIPANT	\N	PRESENT	0
535008	534255	19479G	PARTICIPANT	\N	PRESENT	0
535009	534255	19563B	PARTICIPANT	\N	PRESENT	0
535010	534255	20132W	PARTICIPANT	\N	PRESENT	0
535011	534255	20052X	PARTICIPANT	\N	PRESENT	0
535012	534255	19735D	PARTICIPANT	\N	PRESENT	0
535013	534255	20054A	PARTICIPANT	\N	PRESENT	0
535014	534255	20124W	PARTICIPANT	\N	PRESENT	0
535015	534255	19762G	PARTICIPANT	\N	PRESENT	0
535016	534255	14357A	PARTICIPANT	\N	PRESENT	0
535017	534255	19798U	PARTICIPANT	\N	PRESENT	0
535018	534255	19621T	PARTICIPANT	\N	PRESENT	0
535019	534255	17637T	PARTICIPANT	\N	PRESENT	0
535020	534255	19679N	PARTICIPANT	\N	PRESENT	0
535021	534255	97011G	PARTICIPANT	\N	PRESENT	0
535022	534255	07029T	PARTICIPANT	\N	PRESENT	0
535023	534255	20056C	PARTICIPANT	\N	PRESENT	0
535024	534255	19593H	PARTICIPANT	\N	PRESENT	0
535025	534255	20046A	PARTICIPANT	\N	PRESENT	0
535026	534255	20064C	PARTICIPANT	\N	PRESENT	0
535027	534255	20028X	PARTICIPANT	\N	PRESENT	0
535028	534255	11067R	PARTICIPANT	\N	PRESENT	0
535029	534255	19782L	PARTICIPANT	\N	PRESENT	0
535030	534255	11012A	PARTICIPANT	\N	PRESENT	0
535031	534255	14205J	PARTICIPANT	\N	PRESENT	0
535032	534255	01024M	PARTICIPANT	\N	PRESENT	0
535033	534255	19467C	PARTICIPANT	\N	PRESENT	0
535034	534255	19383Y	PARTICIPANT	\N	PRESENT	0
535035	534255	19507S	PARTICIPANT	\N	PRESENT	0
535036	534255	11031D	PARTICIPANT	\N	PRESENT	0
535037	534255	20026V	PARTICIPANT	\N	PRESENT	0
535038	534255	17589D	PARTICIPANT	\N	PRESENT	0
535039	534255	20086J	PARTICIPANT	\N	PRESENT	0
535040	534255	20090E	PARTICIPANT	\N	PRESENT	0
535041	534255	19703U	PARTICIPANT	\N	PRESENT	0
535044	534255	19573D	PARTICIPANT	\N	PRESENT	0
535050	534255	20066E	PARTICIPANT	\N	PRESENT	0
535051	534255	20174H	PARTICIPANT	\N	PRESENT	0
535052	534255	14147R	PARTICIPANT	\N	PRESENT	0
535053	534255	20130U	PARTICIPANT	\N	PRESENT	0
535054	534255	14033T	PARTICIPANT	\N	PRESENT	0
535055	534255	19701S	PARTICIPANT	\N	PRESENT	0
534985	534255	14026U	PARTICIPANT	\N	PRESENT	0
534986	534255	19758L	PARTICIPANT	\N	PRESENT	0
535242	534353	11012A	PARTICIPANT	\N	PRESENT	0
535243	534353	20070A	PARTICIPANT	\N	PRESENT	0
535244	534353	19671E	PARTICIPANT	\N	PRESENT	1
535315	534168	19649G	PARTICIPANT	\N	PRESENT	0
535316	534168	19585H	PARTICIPANT	\N	PRESENT	0
535317	534168	04047H	PRESIDENT	0	PRESENT	0
535318	534168	01028R	PARTICIPANT	\N	PRESENT	0
535319	534168	19447X	PARTICIPANT	\N	PRESENT	0
535320	534168	05008E	PARTICIPANT	\N	PRESENT	0
535321	534168	17737W	PARTICIPANT	\N	PRESENT	0
535322	534168	19729F	PARTICIPANT	\N	PRESENT	0
535323	534168	20108W	PARTICIPANT	\N	PRESENT	0
535324	534168	14179A	PARTICIPANT	\N	PRESENT	0
535325	534168	14147R	PARTICIPANT	\N	PRESENT	0
535326	534168	14151M	PARTICIPANT	\N	PRESENT	0
535327	534168	20114U	PARTICIPANT	\N	PRESENT	0
535328	534168	14215L	PARTICIPANT	\N	PRESENT	0
535329	534168	17367Q	PARTICIPANT	\N	PRESENT	0
535330	534168	04008A	PARTICIPANT	\N	PRESENT	0
535331	534168	14111D	PARTICIPANT	\N	PRESENT	0
535332	534168	20074E	PARTICIPANT	\N	PRESENT	0
535333	534168	11026G	PARTICIPANT	\N	PRESENT	0
535334	534168	14001X	PARTICIPANT	\N	PRESENT	0
535335	534168	14231L	PARTICIPANT	\N	PRESENT	0
535336	534168	19725B	PARTICIPANT	\N	PRESENT	0
535337	534168	11056N	PARTICIPANT	\N	PRESENT	0
535338	534168	19954N	PARTICIPANT	\N	PRESENT	0
535339	534168	95063L	PARTICIPANT	\N	PRESENT	0
535340	534168	19629C	PARTICIPANT	\N	PRESENT	0
535341	534168	14041T	PARTICIPANT	\N	PRESENT	0
535342	534168	20110Q	PARTICIPANT	\N	PRESENT	0
535343	534168	11085T	PARTICIPANT	\N	PRESENT	0
535344	534168	08018U	PARTICIPANT	\N	PRESENT	0
535345	534168	14259Y	PARTICIPANT	\N	PRESENT	0
535346	534168	19749K	PARTICIPANT	\N	PRESENT	0
535347	534168	14021P	PARTICIPANT	\N	PRESENT	0
535348	533081	11067R	PARTICIPANT	\N	PRESENT	0
535349	533081	20090E	PARTICIPANT	\N	PRESENT	0
535350	533081	19798U	PARTICIPANT	\N	PRESENT	0
535351	533081	11097X	PARTICIPANT	\N	PRESENT	0
535352	533081	19415P	PARTICIPANT	\N	PRESENT	0
535353	533081	18193Q	PARTICIPANT	\N	PRESENT	0
535354	533081	14026U	PARTICIPANT	\N	PRESENT	0
535355	533081	17779H	PARTICIPANT	\N	PRESENT	0
535356	533081	11031D	PARTICIPANT	\N	PRESENT	0
535357	533081	19553Y	PRESIDENT	1	PRESENT	0
535358	533081	19703U	PARTICIPANT	\N	PRESENT	0
535359	533081	19679N	PARTICIPANT	\N	PRESENT	0
535360	533081	14195A	PARTICIPANT	\N	PRESENT	0
535361	533081	19367Y	PARTICIPANT	\N	PRESENT	0
535362	533081	14213J	PARTICIPANT	\N	PRESENT	0
535363	533081	19683J	PARTICIPANT	\N	PRESENT	0
535364	533081	10006L	PRESIDENT	0	PRESENT	0
535365	533081	19591F	PARTICIPANT	\N	PRESENT	0
535366	533081	20130U	PARTICIPANT	\N	PRESENT	0
535367	533081	01034P	PARTICIPANT	\N	PRESENT	0
535368	533081	19713W	PARTICIPANT	\N	PRESENT	0
535369	533081	08045X	PARTICIPANT	\N	PRESENT	0
535370	533081	19691J	PARTICIPANT	\N	PRESENT	0
535371	533081	20148F	PARTICIPANT	\N	PRESENT	0
535372	533081	19723Y	PARTICIPANT	\N	PRESENT	0
535373	533081	20066E	PARTICIPANT	\N	PRESENT	0
535374	533081	14071N	PARTICIPANT	\N	PRESENT	0
535375	533081	04092N	PARTICIPANT	\N	EXCUSE	0
535517	534257	19725B	PARTICIPANT	\N	PRESENT	0
536979	536978	11048N	PARTICIPANT	\N	PRESENT	0
536980	536978	08011M	PARTICIPANT	\N	PRESENT	0
536982	536981	08011M	PARTICIPANT	\N	PRESENT	0
536985	536608	08018U	PARTICIPANT	\N	PRESENT	0
536986	536608	01028R	PARTICIPANT	\N	PRESENT	0
536987	536608	14111D	PARTICIPANT	\N	PRESENT	0
536988	536608	04047H	PRESIDENT	0	PRESENT	0
536989	536824	12041X	PARTICIPANT	\N	PRESENT	0
536990	536608	19447X	PARTICIPANT	\N	PRESENT	0
536993	536824	01028R	PARTICIPANT	\N	PRESENT	0
536994	536824	99004R	PARTICIPANT	\N	PRESENT	0
536995	536824	11033F	PARTICIPANT	\N	PRESENT	0
536996	536824	19333N	PARTICIPANT	\N	PRESENT	0
536997	536824	04047H	PARTICIPANT	\N	PRESENT	0
536998	536824	08018U	PARTICIPANT	\N	PRESENT	0
536999	536824	20130U	PARTICIPANT	\N	PRESENT	0
537000	536824	19711U	PARTICIPANT	\N	PRESENT	0
537001	536824	14111D	PARTICIPANT	\N	PRESENT	0
537002	536824	11072N	PARTICIPANT	\N	PRESENT	0
537003	536824	19447X	PARTICIPANT	\N	PRESENT	0
537004	536824	01024M	PARTICIPANT	\N	PRESENT	0
537005	536824	04085P	PARTICIPANT	\N	PRESENT	0
537006	536824	19629C	PARTICIPANT	\N	PRESENT	0
537007	536824	14069U	PARTICIPANT	\N	PRESENT	0
537008	536824	19581D	PARTICIPANT	\N	PRESENT	0
537010	536824	19649G	PARTICIPANT	\N	PRESENT	0
537011	536824	14021P	PARTICIPANT	\N	PRESENT	0
537012	536824	14259Y	PARTICIPANT	\N	PRESENT	0
537013	536824	19954N	PARTICIPANT	\N	PRESENT	0
537022	536824	14211G	PARTICIPANT	\N	PRESENT	0
537023	536824	19443T	PARTICIPANT	\N	PRESENT	0
537024	536824	17737W	PARTICIPANT	\N	PRESENT	0
538472	528026	20174H	PARTICIPANT	\N	PRESENT	0
538473	528026	14073Q	PARTICIPANT	\N	PRESENT	0
538474	528026	19647E	PARTICIPANT	\N	PRESENT	0
538483	531687	19717B	PARTICIPANT	\N	EXCUSE	0
538484	531687	11010L	PARTICIPANT	\N	EXCUSE	0
538485	531687	20146D	PARTICIPANT	\N	EXCUSE	0
538487	531687	14331P	PARTICIPANT	\N	EXCUSE	0
538546	531688	20146D	PARTICIPANT	\N	EXCUSE	0
538547	531688	14331P	PARTICIPANT	\N	EXCUSE	0
538548	531688	11010L	PARTICIPANT	\N	EXCUSE	0
539158	536895	20130U	PARTICIPANT	\N	PRESENT	1
539159	536895	04045F	PARTICIPANT	\N	PRESENT	1
539161	536895	19631V	PARTICIPANT	\N	PRESENT	1
539164	536895	20098N	PARTICIPANT	\N	PRESENT	1
539165	536895	19367Y	PARTICIPANT	\N	PRESENT	1
539166	536895	20066E	PARTICIPANT	\N	PRESENT	0
539168	536895	19657G	PARTICIPANT	\N	PRESENT	0
539169	536895	20044X	PARTICIPANT	\N	PRESENT	0
539245	536834	19747H	PARTICIPANT	\N	PRESENT	0
539443	534228	20144B	PARTICIPANT	\N	EXCUSE	0
539537	539536	14357A	PARTICIPANT	\N	PRESENT	0
539538	539536	14041T	PARTICIPANT	\N	PRESENT	0
539539	539536	97011G	PARTICIPANT	\N	PRESENT	0
539540	539536	04035D	PARTICIPANT	\N	PRESENT	1
539541	539536	19333N	PARTICIPANT	\N	PRESENT	0
539542	539536	08034U	PARTICIPANT	\N	PRESENT	0
539543	539536	04045F	PARTICIPANT	\N	PRESENT	1
539544	539536	11041F	PARTICIPANT	\N	PRESENT	0
539620	539619	20086J	PARTICIPANT	\N	PRESENT	0
539621	539619	14205J	PARTICIPANT	\N	PRESENT	0
539622	539619	20082E	PARTICIPANT	\N	PRESENT	0
539623	539619	19768N	PARTICIPANT	\N	PRESENT	0
539624	539619	14033T	PARTICIPANT	\N	PRESENT	0
539626	539625	20086J	PARTICIPANT	\N	PRESENT	0
539627	539625	14205J	PARTICIPANT	\N	PRESENT	0
539628	539625	20082E	PARTICIPANT	\N	PRESENT	0
539629	539625	14207L	PARTICIPANT	\N	PRESENT	0
539631	539630	20086J	PARTICIPANT	\N	PRESENT	0
539632	539630	14205J	PARTICIPANT	\N	PRESENT	0
539633	539630	20082E	PARTICIPANT	\N	PRESENT	0
539635	539634	20086J	PARTICIPANT	\N	PRESENT	0
539636	539634	14205J	PARTICIPANT	\N	PRESENT	0
539637	539634	20082E	PARTICIPANT	\N	PRESENT	0
539639	539638	20086J	PARTICIPANT	\N	PRESENT	0
539640	539638	14205J	PARTICIPANT	\N	PRESENT	0
539642	539641	20086J	PARTICIPANT	\N	PRESENT	0
539643	539641	14205J	PARTICIPANT	\N	PRESENT	0
539644	539641	20082E	PARTICIPANT	\N	PRESENT	0
539645	539641	14033T	PARTICIPANT	\N	PRESENT	0
539647	539646	20086J	PARTICIPANT	\N	PRESENT	0
539648	539646	14205J	PARTICIPANT	\N	PRESENT	0
539649	539646	20082E	PARTICIPANT	\N	PRESENT	0
539650	539646	14033T	PARTICIPANT	\N	PRESENT	0
539656	539654	19679N	PARTICIPANT	\N	PRESENT	0
539657	539655	19679N	PARTICIPANT	\N	PRESENT	0
539790	539548	18193Q	PARTICIPANT	\N	PRESENT	0
540023	539548	97011G	PARTICIPANT	\N	PRESENT	0
540025	530857	19527W	PARTICIPANT	\N	PRESENT	0
540026	539548	19723Y	PARTICIPANT	\N	PRESENT	0
540027	539548	14205J	PARTICIPANT	\N	PRESENT	0
540028	539548	07033P	PARTICIPANT	\N	PRESENT	0
540029	539548	14217N	PARTICIPANT	\N	PRESENT	0
540030	530857	14109K	PARTICIPANT	\N	PRESENT	0
540031	539548	17779H	PARTICIPANT	\N	PRESENT	0
514081	513168	14133K	PARTICIPANT	\N	PRESENT	1
514082	513168	14189C	PARTICIPANT	\N	PRESENT	0
514083	513168	11101A	PARTICIPANT	\N	PRESENT	0
514084	513168	19701S	PARTICIPANT	\N	PRESENT	1
514085	513168	20100N	PARTICIPANT	\N	PRESENT	0
514086	513168	19521Q	PARTICIPANT	\N	PRESENT	0
514087	513168	11083R	PARTICIPANT	\N	PRESENT	0
514088	513168	14026U	PARTICIPANT	\N	PRESENT	1
514089	513168	20128B	PARTICIPANT	\N	PRESENT	1
514090	513168	19531S	PARTICIPANT	\N	PRESENT	0
514091	513168	19711U	PARTICIPANT	\N	PRESENT	1
514092	513168	12041X	PARTICIPANT	\N	PRESENT	0
514093	513168	12016W	PARTICIPANT	\N	PRESENT	0
514094	513168	04070G	PARTICIPANT	\N	PRESENT	1
514095	513168	14169X	PARTICIPANT	\N	PRESENT	1
514096	513168	14331P	PRESIDENT	0	PRESENT	0
514097	513168	10015M	PARTICIPANT	\N	PRESENT	0
514098	513168	04034C	PARTICIPANT	\N	PRESENT	1
514099	513168	14225N	PARTICIPANT	\N	PRESENT	0
514100	513168	95063L	PARTICIPANT	\N	PRESENT	1
514101	513168	14255U	PARTICIPANT	\N	PRESENT	0
514102	513168	11012A	PARTICIPANT	\N	PRESENT	0
514103	513168	20122U	PARTICIPANT	\N	PRESENT	0
514104	513168	20044X	PARTICIPANT	\N	PRESENT	0
514106	513168	17367Q	PARTICIPANT	\N	PRESENT	0
514109	513168	20174H	PARTICIPANT	\N	PRESENT	1
514110	513168	19387D	PARTICIPANT	\N	PRESENT	1
516364	502387	19347U	PARTICIPANT	\N	PRESENT	0
516365	502387	20100N	PARTICIPANT	\N	PRESENT	0
516366	502387	14257W	PARTICIPANT	\N	PRESENT	0
516367	502387	19447X	PARTICIPANT	\N	PRESENT	0
516368	502387	19782L	PARTICIPANT	\N	PRESENT	0
516369	502387	14033T	PARTICIPANT	\N	PRESENT	0
516370	502387	08060W	PARTICIPANT	\N	PRESENT	0
516371	502387	20074E	PARTICIPANT	\N	PRESENT	0
516372	502387	20064C	PARTICIPANT	\N	PRESENT	0
516383	502387	18083K	PARTICIPANT	\N	PRESENT	0
516384	502387	20126Y	PARTICIPANT	\N	PRESENT	0
516385	502387	20042V	PARTICIPANT	\N	PRESENT	0
516445	502381	04047H	PARTICIPANT	\N	PRESENT	0
516446	502381	08060W	PARTICIPANT	\N	PRESENT	0
516447	502381	18083K	PARTICIPANT	\N	PRESENT	0
516448	502381	19585H	PARTICIPANT	\N	PRESENT	0
516449	502381	20110Q	PARTICIPANT	\N	PRESENT	0
516450	502381	14249W	PARTICIPANT	\N	PRESENT	0
516457	502381	19629C	PARTICIPANT	\N	PRESENT	0
516459	502381	20046A	PARTICIPANT	\N	PRESENT	0
516461	502381	14151M	PARTICIPANT	\N	PRESENT	0
516463	502381	14231L	PARTICIPANT	\N	PRESENT	0
516465	502381	19701S	PARTICIPANT	\N	PRESENT	0
516466	502381	19447X	PARTICIPANT	\N	PRESENT	0
516468	502381	20152B	PARTICIPANT	\N	PRESENT	0
516469	502381	11074Q	PARTICIPANT	\N	PRESENT	0
516471	502381	14021P	PARTICIPANT	\N	PRESENT	0
516472	502381	20124W	PARTICIPANT	\N	PRESENT	0
516475	502381	20098N	PARTICIPANT	\N	PRESENT	0
516480	502381	08017T	PARTICIPANT	\N	PRESENT	0
516481	502381	11067R	PARTICIPANT	\N	PRESENT	0
516483	502381	19333N	PARTICIPANT	\N	PRESENT	0
516484	502381	19820Y	PARTICIPANT	\N	PRESENT	0
516486	502381	20082E	PARTICIPANT	\N	PRESENT	0
516488	502381	19503N	PARTICIPANT	\N	PRESENT	0
516489	502381	19631V	PARTICIPANT	\N	PRESENT	0
516491	502381	19525U	PARTICIPANT	\N	PRESENT	0
516492	502381	19549D	PARTICIPANT	\N	PRESENT	0
516493	502381	19413M	PARTICIPANT	\N	PRESENT	0
516494	502381	14257W	PARTICIPANT	\N	PRESENT	0
516496	502381	20064C	PARTICIPANT	\N	PRESENT	0
516497	502381	17965H	PARTICIPANT	\N	PRESENT	0
516498	502381	14237S	PARTICIPANT	\N	PRESENT	0
516499	502381	20096L	PARTICIPANT	\N	PRESENT	0
516500	502381	14253S	PARTICIPANT	\N	PRESENT	0
516501	502381	11040E	PARTICIPANT	\N	PRESENT	0
516502	502381	17023S	PARTICIPANT	\N	PRESENT	0
516503	502381	20116W	PARTICIPANT	\N	PRESENT	0
516504	502381	20074E	PARTICIPANT	\N	PRESENT	0
516505	502381	19551W	PARTICIPANT	\N	PRESENT	0
516506	502381	20042V	PARTICIPANT	\N	PRESENT	0
516513	502381	14026U	PARTICIPANT	\N	PRESENT	0
516514	502381	11033F	PARTICIPANT	\N	PRESENT	0
516516	502381	11026G	PARTICIPANT	\N	PRESENT	0
516527	502381	19695N	PARTICIPANT	\N	PRESENT	0
516525	502381	01028R	PARTICIPANT	\N	PRESENT	0
516526	502381	14229S	PARTICIPANT	\N	PRESENT	0
516528	502381	19717B	PARTICIPANT	\N	PRESENT	0
516529	502381	14225N	PARTICIPANT	\N	PRESENT	0
516530	502381	14147R	PARTICIPANT	\N	PRESENT	0
516531	502381	20150Y	PARTICIPANT	\N	PRESENT	0
516532	502381	20070A	PARTICIPANT	\N	PRESENT	0
516533	502381	19399H	PARTICIPANT	\N	PRESENT	0
516535	502381	19531S	PARTICIPANT	\N	PRESENT	0
516538	502381	20092G	PARTICIPANT	\N	PRESENT	0
516543	502381	20134Y	PARTICIPANT	\N	PRESENT	0
516544	502381	11085T	PARTICIPANT	\N	PRESENT	0
516545	502381	14215L	PARTICIPANT	\N	PRESENT	0
516546	502381	04085P	PARTICIPANT	\N	PRESENT	0
516443	502381	11070L	PARTICIPANT	\N	PRESENT	0
516444	502381	19543W	PARTICIPANT	\N	PRESENT	0
516548	502381	19762G	PARTICIPANT	\N	PRESENT	0
516549	502381	14179A	PARTICIPANT	\N	PRESENT	0
516550	502381	19689Q	PARTICIPANT	\N	PRESENT	0
516551	502381	20018V	PARTICIPANT	\N	PRESENT	0
516602	502386	14253S	PARTICIPANT	\N	PRESENT	0
516603	502386	19413M	PARTICIPANT	\N	PRESENT	0
516604	502386	19531S	PARTICIPANT	\N	PRESENT	0
516605	502386	20018V	PARTICIPANT	\N	PRESENT	0
516606	502386	20046A	PARTICIPANT	\N	PRESENT	0
516607	502386	11040E	PARTICIPANT	\N	PRESENT	0
516608	502386	20082E	PARTICIPANT	\N	PRESENT	0
516609	502386	19503N	PARTICIPANT	\N	PRESENT	0
516610	502386	20070A	PARTICIPANT	\N	PRESENT	0
516611	502386	19820Y	PARTICIPANT	\N	PRESENT	0
516612	502386	19333N	PARTICIPANT	\N	PRESENT	0
516613	502386	14021P	PARTICIPANT	\N	PRESENT	0
516614	502386	08060W	PARTICIPANT	\N	PRESENT	0
516615	502386	19689Q	PARTICIPANT	\N	PRESENT	0
516616	502386	20092G	PARTICIPANT	\N	PRESENT	0
516617	502386	14151M	PARTICIPANT	\N	PRESENT	0
516618	502386	19717B	PARTICIPANT	\N	PRESENT	0
516619	502386	19543W	PARTICIPANT	\N	PRESENT	0
516620	502386	17023S	PARTICIPANT	\N	PRESENT	0
516621	502386	14231L	PARTICIPANT	\N	PRESENT	0
516622	502386	14083S	PARTICIPANT	\N	PRESENT	0
516623	502386	14179A	PARTICIPANT	\N	PRESENT	0
516624	502386	14215L	PARTICIPANT	\N	PRESENT	0
516625	502386	14237S	PARTICIPANT	\N	PRESENT	0
516626	502386	14026U	PARTICIPANT	\N	PRESENT	0
516627	502386	18083K	PARTICIPANT	\N	PRESENT	0
516628	502386	20074E	PARTICIPANT	\N	PRESENT	0
516635	502386	20150Y	PARTICIPANT	\N	PRESENT	0
516636	502386	19629C	PARTICIPANT	\N	PRESENT	0
516637	502386	20050V	PARTICIPANT	\N	PRESENT	0
516650	502386	19762G	PARTICIPANT	\N	PRESENT	0
516651	502386	19631V	PARTICIPANT	\N	PRESENT	0
516670	502386	11074Q	PARTICIPANT	\N	PRESENT	0
516671	502386	17965H	PARTICIPANT	\N	PRESENT	0
516672	502386	19711U	PARTICIPANT	\N	PRESENT	0
516673	502386	04047H	PARTICIPANT	\N	PRESENT	0
516683	502386	14041T	PARTICIPANT	\N	PRESENT	0
516600	502386	11070L	PARTICIPANT	\N	PRESENT	0
516601	502386	19551W	PARTICIPANT	\N	PRESENT	0
529969	529959	19637C	PARTICIPANT	\N	PRESENT	0
529970	529959	20136B	PARTICIPANT	\N	PRESENT	0
529972	529971	08060W	PARTICIPANT	\N	PRESENT	0
529973	529971	20100N	PARTICIPANT	\N	PRESENT	0
529974	529971	19551W	PARTICIPANT	\N	PRESENT	0
529975	529971	20136B	PARTICIPANT	\N	PRESENT	0
530046	528657	11048N	PARTICIPANT	\N	PRESENT	0
530047	528657	19479G	PARTICIPANT	\N	PRESENT	0
530048	528657	14189C	PARTICIPANT	\N	PRESENT	0
530049	528657	19531S	PARTICIPANT	\N	PRESENT	0
530050	528657	01057W	PARTICIPANT	\N	PRESENT	0
530051	528657	19689Q	PARTICIPANT	\N	PRESENT	0
530052	528657	20050V	PARTICIPANT	\N	PRESENT	0
530053	528657	19667J	PARTICIPANT	\N	PRESENT	0
530054	528657	14225N	PRESIDENT	0	PRESENT	0
530055	528657	11040E	PARTICIPANT	\N	PRESENT	0
530056	528657	04086Q	PARTICIPANT	\N	PRESENT	0
530057	528657	14083S	PARTICIPANT	\N	PRESENT	0
530058	528657	11012A	PARTICIPANT	\N	PRESENT	0
530059	528657	20070A	PARTICIPANT	\N	PRESENT	0
530060	528657	19349W	PARTICIPANT	\N	PRESENT	0
530061	528657	19741B	PARTICIPANT	\N	PRESENT	0
530062	528657	99004R	PARTICIPANT	\N	PRESENT	0
530063	528657	20116W	PARTICIPANT	\N	PRESENT	0
530064	528657	20022R	PARTICIPANT	\N	PRESENT	0
530065	529229	19631V	PARTICIPANT	\N	PRESENT	1
530108	519130	01028R	PARTICIPANT	\N	PRESENT	0
530109	526731	01028R	PARTICIPANT	\N	PRESENT	0
530183	529003	20114U	PARTICIPANT	\N	PRESENT	0
530185	529003	14259Y	PARTICIPANT	\N	PRESENT	0
530190	528657	19545Y	PARTICIPANT	\N	PRESENT	0
530191	528657	07029T	PARTICIPANT	\N	PRESENT	0
530192	528657	19687N	PARTICIPANT	\N	PRESENT	0
530257	528657	20080C	PARTICIPANT	\N	PRESENT	1
530258	528657	14327T	PARTICIPANT	\N	PRESENT	1
530259	528657	04071H	PARTICIPANT	\N	PRESENT	1
530260	528657	11074Q	PARTICIPANT	\N	PRESENT	1
530261	528657	11110B	PARTICIPANT	\N	PRESENT	1
530262	528657	12016W	PARTICIPANT	\N	PRESENT	1
530263	528657	19671E	PARTICIPANT	\N	PRESENT	1
530264	528657	19335Q	PARTICIPANT	\N	PRESENT	1
530265	528657	14253S	PARTICIPANT	\N	PRESENT	1
530411	530409	20052X	PARTICIPANT	\N	PRESENT	0
530412	530409	20036X	PARTICIPANT	\N	PRESENT	0
530457	530455	20032T	PARTICIPANT	\N	PRESENT	0
530458	530455	20024T	PARTICIPANT	\N	PRESENT	0
530460	530455	20116W	PARTICIPANT	\N	PRESENT	0
530461	530455	20090E	PARTICIPANT	\N	PRESENT	0
530462	530455	11103C	PARTICIPANT	\N	PRESENT	0
530464	530455	14329V	PARTICIPANT	\N	PRESENT	0
530465	530455	19467C	PARTICIPANT	\N	PRESENT	0
530466	530455	17589D	PARTICIPANT	\N	PRESENT	0
530468	530455	20038A	PARTICIPANT	\N	PRESENT	0
530469	530455	14213J	PARTICIPANT	\N	PRESENT	0
530471	530455	20126Y	PARTICIPANT	\N	PRESENT	0
530472	530455	19723Y	PARTICIPANT	\N	PRESENT	0
530473	530455	14221J	PARTICIPANT	\N	PRESENT	0
530476	530455	11090Q	PARTICIPANT	\N	PRESENT	0
530477	530455	19679N	PARTICIPANT	\N	PRESENT	0
530478	530455	19619A	PARTICIPANT	\N	PRESENT	0
530479	530455	20092G	PARTICIPANT	\N	PRESENT	0
530480	530455	19713W	PARTICIPANT	\N	PRESENT	0
530481	530455	20064C	PARTICIPANT	\N	PRESENT	0
530718	529082	12041X	PARTICIPANT	\N	PRESENT	0
530727	529082	08060W	PARTICIPANT	\N	PRESENT	0
530728	529082	20142Y	PARTICIPANT	\N	PRESENT	0
530729	529082	20130U	PARTICIPANT	\N	PRESENT	0
530730	529082	11067R	PARTICIPANT	\N	PRESENT	0
530731	529082	19820Y	PARTICIPANT	\N	PRESENT	0
530732	529082	04092N	PARTICIPANT	\N	PRESENT	0
530733	529082	19866P	PARTICIPANT	\N	PRESENT	0
530734	529082	19553Y	PARTICIPANT	\N	PRESENT	0
530735	529082	20132W	PARTICIPANT	\N	PRESENT	0
530736	529082	19545Y	PARTICIPANT	\N	PRESENT	0
530737	529082	19479G	PARTICIPANT	\N	PRESENT	0
530738	529082	19441R	PARTICIPANT	\N	PRESENT	0
530739	529082	19713W	PARTICIPANT	\N	PRESENT	0
530740	529082	19503N	PARTICIPANT	\N	PRESENT	0
530741	529082	19683J	PARTICIPANT	\N	PRESENT	0
530742	529082	11031D	PARTICIPANT	\N	PRESENT	0
530743	529082	19593H	PARTICIPANT	\N	PRESENT	0
530744	529082	20046A	PARTICIPANT	\N	PRESENT	0
530745	529082	01024M	PARTICIPANT	\N	PRESENT	0
530746	529082	19691J	PARTICIPANT	\N	PRESENT	0
530747	529082	19415P	PARTICIPANT	\N	PRESENT	0
530748	529082	19703U	PARTICIPANT	\N	PRESENT	0
530749	529082	14147R	PARTICIPANT	\N	PRESENT	0
530750	529082	19954N	PARTICIPANT	\N	PRESENT	0
530751	529082	10006L	PARTICIPANT	\N	PRESENT	0
530753	529082	14069U	PARTICIPANT	\N	PRESENT	0
530754	529082	97011G	PARTICIPANT	\N	PRESENT	0
530755	529082	20020P	PARTICIPANT	\N	PRESENT	0
530756	529082	20068G	PARTICIPANT	\N	PRESENT	0
530757	529082	19766L	PARTICIPANT	\N	PRESENT	0
530758	529082	19515S	PARTICIPANT	\N	PRESENT	0
530759	529082	17367Q	PARTICIPANT	\N	PRESENT	0
530760	529082	19467C	PARTICIPANT	\N	PRESENT	0
530761	529082	18083K	PARTICIPANT	\N	PRESENT	0
530763	529082	19347U	PARTICIPANT	\N	PRESENT	0
530764	529082	99004R	PARTICIPANT	\N	PRESENT	0
530765	529082	19575F	PARTICIPANT	\N	PRESENT	0
530766	529082	20084G	PARTICIPANT	\N	PRESENT	0
530767	529082	08061X	PARTICIPANT	\N	PRESENT	0
530768	529082	19629C	PARTICIPANT	\N	PRESENT	0
530769	529082	20122U	PARTICIPANT	\N	PRESENT	0
530770	529082	19747H	PARTICIPANT	\N	PRESENT	0
530771	529082	20028X	PARTICIPANT	\N	PRESENT	0
530772	529082	11070L	PARTICIPANT	\N	PRESENT	0
530773	529082	01058X	PARTICIPANT	\N	PRESENT	0
530774	529082	19507S	PARTICIPANT	\N	PRESENT	0
530775	529082	19651A	PARTICIPANT	\N	PRESENT	0
530776	529082	19383Y	PARTICIPANT	\N	PRESENT	0
530777	529082	19681G	PARTICIPANT	\N	PRESENT	0
530779	529082	04057K	PARTICIPANT	\N	PRESENT	0
530784	529082	19760E	PARTICIPANT	\N	PRESENT	0
530835	529082	11056N	PARTICIPANT	\N	PRESENT	0
530837	529082	20082E	PARTICIPANT	\N	PRESENT	0
530804	529082	19443T	PARTICIPANT	\N	PRESENT	0
530808	529082	19715Y	PARTICIPANT	\N	PRESENT	0
530810	529082	20136B	PARTICIPANT	\N	PRESENT	0
530811	529082	14031R	PARTICIPANT	\N	PRESENT	0
530812	529082	19671E	PARTICIPANT	\N	PRESENT	0
530813	529082	11012A	PARTICIPANT	\N	PRESENT	0
530814	529082	19565D	PARTICIPANT	\N	PRESENT	0
530815	529082	18193Q	PARTICIPANT	\N	PRESENT	0
530816	529082	20066E	PARTICIPANT	\N	PRESENT	0
530817	529082	20024T	PARTICIPANT	\N	PRESENT	0
530822	529297	14179A	PARTICIPANT	\N	PRESENT	0
530823	529297	04008A	PARTICIPANT	\N	PRESENT	1
530824	529297	14151M	PARTICIPANT	\N	PRESENT	1
530825	529082	19543W	PARTICIPANT	\N	PRESENT	0
530827	530782	14237S	PARTICIPANT	\N	PRESENT	0
530828	530782	20136B	PARTICIPANT	\N	PRESENT	0
530829	530782	20068G	PARTICIPANT	\N	PRESENT	0
530830	530782	14169X	PARTICIPANT	\N	PRESENT	0
530833	530782	14031R	PARTICIPANT	\N	PRESENT	0
530834	530782	14219Q	PRESIDENT	0	PRESENT	0
530838	529082	14229S	PARTICIPANT	\N	PRESENT	0
530839	529082	19573D	PARTICIPANT	\N	PRESENT	0
530842	529082	14083S	PARTICIPANT	\N	PRESENT	0
530843	529082	14189C	PARTICIPANT	\N	PRESENT	0
530845	530844	11064N	PARTICIPANT	\N	PRESENT	0
530846	530844	14038Y	PARTICIPANT	\N	PRESENT	0
530847	529082	11048N	PARTICIPANT	\N	PRESENT	0
530849	530848	11064N	PARTICIPANT	\N	PRESENT	0
530850	530848	14038Y	PARTICIPANT	\N	PRESENT	0
530854	529082	20050V	PARTICIPANT	\N	PRESENT	0
530855	529082	20098N	PARTICIPANT	\N	PRESENT	0
530856	529082	20138D	PARTICIPANT	\N	PRESENT	0
530859	529082	01048V	PARTICIPANT	\N	PRESENT	0
530870	530782	19333N	PARTICIPANT	\N	PRESENT	0
530871	530782	20038A	PARTICIPANT	\N	PRESENT	0
530872	530782	19826F	PARTICIPANT	\N	PRESENT	0
530873	530782	18083K	PARTICIPANT	\N	PRESENT	0
530874	530782	19551W	PARTICIPANT	\N	PRESENT	0
530875	530782	20100N	PARTICIPANT	\N	PRESENT	0
530876	530782	05012A	PARTICIPANT	\N	PRESENT	0
530877	530782	17367Q	PARTICIPANT	\N	PRESENT	0
530878	530782	20024T	PARTICIPANT	\N	PRESENT	0
530879	530782	17637T	PARTICIPANT	\N	PRESENT	0
530880	530782	19701S	PARTICIPANT	\N	PRESENT	0
516536	516534	14089Y	PARTICIPANT	\N	PRESENT	0
516537	516534	11026G	PARTICIPANT	\N	PRESENT	0
519190	519098	19569H	PARTICIPANT	\N	PRESENT	0
519191	519098	19735D	PARTICIPANT	\N	PRESENT	0
519193	519098	19503N	PARTICIPANT	\N	PRESENT	0
519194	519098	01058X	PARTICIPANT	\N	PRESENT	0
519198	519098	01048V	PARTICIPANT	\N	PRESENT	0
519200	519098	04043D	PARTICIPANT	\N	PRESENT	0
519202	519098	20128B	PARTICIPANT	\N	PRESENT	0
519204	519098	14299H	PARTICIPANT	\N	PRESENT	0
519206	519205	17737W	PARTICIPANT	\N	PRESENT	0
519207	519205	14053L	PARTICIPANT	\N	PRESENT	0
519208	519205	14147R	PARTICIPANT	\N	PRESENT	0
519209	519205	19749K	PARTICIPANT	\N	PRESENT	0
524087	524086	19701S	PARTICIPANT	\N	PRESENT	0
524088	524086	20124W	PARTICIPANT	\N	PRESENT	0
524089	524086	19820Y	PARTICIPANT	\N	PRESENT	0
524090	524086	20100N	PARTICIPANT	\N	PRESENT	0
524091	524086	14213J	PARTICIPANT	\N	PRESENT	0
524092	524086	19549D	PARTICIPANT	\N	PRESENT	0
524093	524086	01024M	PARTICIPANT	\N	PRESENT	0
524094	524086	14219Q	PARTICIPANT	\N	PRESENT	0
524095	524086	19387D	PARTICIPANT	\N	PRESENT	0
530762	529007	11109J	PARTICIPANT	\N	EXCUSE	0
530778	527033	19747H	PARTICIPANT	\N	PRESENT	0
530902	527033	20050V	PARTICIPANT	\N	PRESENT	0
532986	532981	19667J	PARTICIPANT	\N	PRESENT	0
532987	532981	20138D	PARTICIPANT	\N	PRESENT	0
532988	532981	19663E	PARTICIPANT	\N	PRESENT	0
532989	532981	10006L	PARTICIPANT	\N	PRESENT	0
532990	532981	14041T	PARTICIPANT	\N	PRESENT	0
532991	532981	04092N	PARTICIPANT	\N	PRESENT	0
532992	532981	19703U	PARTICIPANT	\N	PRESENT	0
533078	533019	19679N	PARTICIPANT	\N	PRESENT	0
533079	533028	19679N	PARTICIPANT	\N	PRESENT	0
534290	531161	20124W	PARTICIPANT	\N	PRESENT	0
534291	531161	20152B	PARTICIPANT	\N	PRESENT	0
534292	531161	14123H	PARTICIPANT	\N	PRESENT	0
534293	531161	20180F	PARTICIPANT	\N	PRESENT	0
534294	531161	19749K	PARTICIPANT	\N	PRESENT	0
534296	534295	19533U	PARTICIPANT	\N	PRESENT	0
534297	534295	20180F	PARTICIPANT	\N	PRESENT	0
534298	534295	14229S	PARTICIPANT	\N	PRESENT	0
534299	531551	11010L	PARTICIPANT	\N	EXCUSE	0
534300	531551	14331P	PARTICIPANT	\N	EXCUSE	0
535108	534256	20100N	PARTICIPANT	\N	PRESENT	0
535109	534256	20092G	PARTICIPANT	\N	PRESENT	0
535110	534256	19347U	PARTICIPANT	\N	PRESENT	0
535111	534256	11033F	PARTICIPANT	\N	PRESENT	0
535112	534256	19333N	PARTICIPANT	\N	PRESENT	0
535113	534256	20094J	PARTICIPANT	\N	PRESENT	0
535114	534256	18193Q	PARTICIPANT	\N	PRESENT	0
535115	534256	19503N	PARTICIPANT	\N	PRESENT	0
535116	534256	14195A	PARTICIPANT	\N	PRESENT	0
535117	534256	14207L	PARTICIPANT	\N	PRESENT	0
535118	534256	19387D	PARTICIPANT	\N	PRESENT	0
535119	534256	20132W	PARTICIPANT	\N	PRESENT	0
535120	534256	19629C	PARTICIPANT	\N	PRESENT	0
535121	534256	14083S	PARTICIPANT	\N	PRESENT	0
535122	534256	14189C	PARTICIPANT	\N	PRESENT	0
535123	534256	19565D	PARTICIPANT	\N	PRESENT	0
535124	534256	19760E	PARTICIPANT	\N	PRESENT	0
535125	534256	11077T	PARTICIPANT	\N	PRESENT	0
535126	534256	20024T	PARTICIPANT	\N	PRESENT	0
535127	534256	20086J	PARTICIPANT	\N	PRESENT	0
535128	534256	14213J	PARTICIPANT	\N	PRESENT	0
535129	534256	20060X	PARTICIPANT	\N	PRESENT	0
535130	534256	19549D	PARTICIPANT	\N	PRESENT	0
535106	534256	11070L	PARTICIPANT	\N	PRESENT	0
535107	534256	20110Q	PARTICIPANT	\N	PRESENT	0
535131	534256	11012A	PARTICIPANT	\N	PRESENT	0
535132	534256	19701S	PARTICIPANT	\N	PRESENT	0
535133	534256	20038A	PARTICIPANT	\N	PRESENT	0
535134	534256	20106U	PARTICIPANT	\N	PRESENT	0
535135	534256	19679N	PARTICIPANT	\N	PRESENT	0
535136	534256	14257W	PARTICIPANT	\N	PRESENT	0
535137	534256	14147R	PARTICIPANT	\N	PRESENT	0
535138	534256	14069U	PARTICIPANT	\N	PRESENT	0
535139	534256	18083K	PARTICIPANT	\N	PRESENT	0
535140	534256	14033T	PARTICIPANT	\N	PRESENT	0
535141	534256	19413M	PARTICIPANT	\N	PRESENT	0
535142	534256	20124W	PARTICIPANT	\N	PRESENT	0
535143	534256	19383Y	PARTICIPANT	\N	PRESENT	0
535144	534256	19762G	PARTICIPANT	\N	PRESENT	0
535145	534256	19507S	PARTICIPANT	\N	PRESENT	0
535146	534256	20054A	PARTICIPANT	\N	PRESENT	0
535147	534256	19551W	PARTICIPANT	\N	PRESENT	0
535148	534256	20070A	PARTICIPANT	\N	PRESENT	0
535149	534256	07029T	PARTICIPANT	\N	PRESENT	0
535240	530867	19527W	PARTICIPANT	\N	PRESENT	0
535241	530867	19735D	PARTICIPANT	\N	PRESENT	0
538559	536656	20112S	PARTICIPANT	\N	EXCUSE	0
538959	536832	11083R	PARTICIPANT	\N	PRESENT	0
538960	536832	14255U	PARTICIPANT	\N	PRESENT	0
538961	536832	19347U	PARTICIPANT	\N	PRESENT	0
538962	536832	14038Y	PARTICIPANT	\N	PRESENT	0
538964	536832	11099A	PARTICIPANT	\N	PRESENT	0
538965	536832	19549D	PARTICIPANT	\N	PRESENT	0
538966	536832	19349W	PARTICIPANT	\N	PRESENT	0
538967	536832	20046A	PARTICIPANT	\N	PRESENT	0
539051	536833	99004R	PARTICIPANT	\N	PRESENT	0
539072	536833	20046A	PARTICIPANT	\N	PRESENT	0
539073	536833	20102Q	PARTICIPANT	\N	PRESENT	0
539076	539075	01048V	PARTICIPANT	\N	PRESENT	0
539090	536833	08060W	PARTICIPANT	\N	PRESENT	0
539112	536833	20106U	PARTICIPANT	\N	PRESENT	0
539113	536833	19637C	PARTICIPANT	\N	PRESENT	0
539114	536833	19387D	PARTICIPANT	\N	PRESENT	0
539115	536833	19251M	PARTICIPANT	\N	PRESENT	0
539119	536833	19711U	PARTICIPANT	\N	PRESENT	0
539117	536833	20100N	PARTICIPANT	\N	PRESENT	0
539118	536833	19489J	PARTICIPANT	\N	PRESENT	0
539120	536833	14031R	PARTICIPANT	\N	PRESENT	0
539121	536833	19549D	PARTICIPANT	\N	PRESENT	0
539122	536833	19701S	PARTICIPANT	\N	PRESENT	0
539123	536833	14219Q	PARTICIPANT	\N	PRESENT	0
539124	536833	19599P	PARTICIPANT	\N	PRESENT	0
539125	536833	19739H	PARTICIPANT	\N	PRESENT	0
539126	536833	14267Y	PARTICIPANT	\N	PRESENT	0
539132	536833	11027H	PARTICIPANT	\N	PRESENT	0
539128	536833	20090E	PARTICIPANT	\N	PRESENT	0
539129	536833	19369B	PARTICIPANT	\N	PRESENT	0
539130	536833	19413M	PARTICIPANT	\N	PRESENT	0
539131	536833	14069U	PARTICIPANT	\N	PRESENT	0
539133	536833	14221J	PARTICIPANT	\N	PRESENT	0
539134	536833	19333N	PARTICIPANT	\N	PRESENT	0
539135	536833	11033F	PARTICIPANT	\N	PRESENT	0
539137	536833	19551W	PARTICIPANT	\N	PRESENT	0
539138	536833	20038A	PARTICIPANT	\N	PRESENT	0
539140	536833	14189C	PARTICIPANT	\N	PRESENT	0
539141	536833	11067R	PARTICIPANT	\N	PRESENT	0
539142	536833	19503N	PARTICIPANT	\N	PRESENT	0
539143	536833	14021P	PARTICIPANT	\N	PRESENT	0
539145	536833	20066E	PARTICIPANT	\N	PRESENT	0
539146	536833	19533U	PARTICIPANT	\N	PRESENT	0
539148	539147	04086Q	PARTICIPANT	\N	PRESENT	0
539149	536833	20070A	PARTICIPANT	\N	PRESENT	0
539150	536833	19467C	PARTICIPANT	\N	PRESENT	0
539152	539151	04086Q	PARTICIPANT	\N	PRESENT	0
539153	536833	14038Y	PARTICIPANT	\N	PRESENT	0
539154	536833	19441R	PARTICIPANT	\N	PRESENT	0
539155	536833	97011G	PARTICIPANT	\N	PRESENT	0
539156	536833	01024M	PARTICIPANT	\N	PRESENT	0
539157	536833	14041T	PARTICIPANT	\N	PRESENT	0
539162	539160	08009T	PARTICIPANT	\N	PRESENT	0
539163	539160	20044X	PARTICIPANT	\N	PRESENT	0
539167	536833	11065P	PARTICIPANT	\N	PRESENT	0
539174	539173	11053K	PARTICIPANT	\N	PRESENT	0
539180	536833	07004J	PARTICIPANT	\N	PRESENT	0
539182	539181	11048N	PARTICIPANT	\N	PRESENT	0
539183	536833	14257W	PARTICIPANT	\N	PRESENT	0
535404	533081	11103C	PARTICIPANT	\N	PRESENT	1
535405	533081	04057K	PARTICIPANT	\N	PRESENT	1
535406	533081	19295A	PARTICIPANT	\N	EXCUSE	0
535407	533081	19569H	PARTICIPANT	\N	PRESENT	1
535408	533081	11045K	PARTICIPANT	\N	PRESENT	1
535409	533081	14042U	PARTICIPANT	\N	PRESENT	1
535410	533081	19663E	PARTICIPANT	\N	PRESENT	1
535411	533081	04043D	PARTICIPANT	\N	PRESENT	1
535412	533081	17965H	PARTICIPANT	\N	PRESENT	1
535413	533081	19715Y	PARTICIPANT	\N	PRESENT	1
535414	533081	20040T	PARTICIPANT	\N	PRESENT	1
535415	533081	19697Q	PARTICIPANT	\N	PRESENT	1
535416	533081	14223L	PARTICIPANT	\N	PRESENT	1
537156	537151	08010L	PARTICIPANT	\N	PRESENT	0
537157	537151	14041T	PARTICIPANT	\N	PRESENT	0
537158	537151	19693L	PARTICIPANT	\N	PRESENT	0
537159	537151	11083R	PARTICIPANT	\N	PRESENT	0
537160	537151	19766L	PARTICIPANT	\N	PRESENT	0
537333	536110	14083S	PARTICIPANT	\N	PRESENT	0
539674	539673	14038Y	PARTICIPANT	\N	PRESENT	0
539675	539673	19441R	PARTICIPANT	\N	PRESENT	0
539676	539673	20174H	PARTICIPANT	\N	PRESENT	0
539678	539677	14038Y	PARTICIPANT	\N	PRESENT	0
539679	539677	19441R	PARTICIPANT	\N	PRESENT	0
539680	539677	19631V	PARTICIPANT	\N	PRESENT	0
539681	539677	20060X	PARTICIPANT	\N	PRESENT	0
540032	539548	01043Q	PARTICIPANT	\N	PRESENT	0
540085	540081	19507S	PARTICIPANT	\N	PRESENT	0
540086	540081	14205J	PARTICIPANT	\N	PRESENT	0
540087	540081	20118Y	PARTICIPANT	\N	PRESENT	0
540088	540081	19820Y	PARTICIPANT	\N	PRESENT	0
540089	540081	11099A	PARTICIPANT	\N	PRESENT	0
540090	539548	14237S	PARTICIPANT	\N	PRESENT	0
540092	540091	14249W	PARTICIPANT	\N	PRESENT	0
540093	540091	14073Q	PARTICIPANT	\N	PRESENT	0
540095	540094	16685X	PARTICIPANT	\N	PRESENT	0
540096	539548	11099A	PARTICIPANT	\N	PRESENT	0
540098	539548	19691J	PARTICIPANT	\N	PRESENT	0
540099	539548	19681G	PARTICIPANT	\N	PRESENT	0
540100	539548	14193X	PARTICIPANT	\N	PRESENT	0
540101	539548	19715Y	PARTICIPANT	\N	PRESENT	0
540102	539548	17637T	PARTICIPANT	\N	PRESENT	0
540103	539548	20130U	PARTICIPANT	\N	PRESENT	0
540104	539548	20092G	PARTICIPANT	\N	PRESENT	0
540105	539548	20118Y	PARTICIPANT	\N	PRESENT	0
540106	539548	14357A	PARTICIPANT	\N	PRESENT	0
540107	539586	14205J	PARTICIPANT	\N	PRESENT	0
540108	539586	20066E	PARTICIPANT	\N	EXCUSE	0
540109	539586	19367Y	PARTICIPANT	\N	EXCUSE	0
540114	539548	20038A	PARTICIPANT	\N	PRESENT	0
540115	539548	19713W	PARTICIPANT	\N	PRESENT	0
540116	539548	20100N	PARTICIPANT	\N	PRESENT	0
540117	539548	11090Q	PARTICIPANT	\N	PRESENT	0
540118	539548	14109K	PARTICIPANT	\N	PRESENT	0
540119	539548	19679N	PARTICIPANT	\N	PRESENT	0
540121	540120	14187A	PARTICIPANT	\N	PRESENT	0
540122	540120	01043Q	PARTICIPANT	\N	PRESENT	0
540124	540123	19575F	PARTICIPANT	\N	PRESENT	0
540125	540123	08015R	PARTICIPANT	\N	PRESENT	0
540126	540123	20082E	PARTICIPANT	\N	PRESENT	0
540127	540123	20062A	PARTICIPANT	\N	PRESENT	0
540128	540123	19563B	PARTICIPANT	\N	PRESENT	0
540129	540123	14207L	PARTICIPANT	\N	PRESENT	0
540130	540123	01025N	PARTICIPANT	\N	PRESENT	0
540132	530857	08017T	PARTICIPANT	\N	PRESENT	1
540133	530857	11109J	PARTICIPANT	\N	EXCUSE	0
540134	530857	19651A	PARTICIPANT	\N	PRESENT	1
540135	530857	19643A	PARTICIPANT	\N	PRESENT	1
540136	530857	20052X	PARTICIPANT	\N	PRESENT	0
540137	530857	20084G	PARTICIPANT	\N	PRESENT	1
540138	530857	20138D	PARTICIPANT	\N	PRESENT	1
540254	539549	04047H	PARTICIPANT	\N	PRESENT	0
540252	539549	01043Q	PARTICIPANT	\N	PRESENT	0
540253	539549	04008A	PARTICIPANT	\N	PRESENT	0
540255	539549	19629C	PARTICIPANT	\N	PRESENT	0
540256	539549	14107H	PARTICIPANT	\N	PRESENT	0
540257	539549	11056N	PARTICIPANT	\N	PRESENT	0
540258	539549	20028X	PARTICIPANT	\N	PRESENT	0
540259	539549	18193Q	PARTICIPANT	\N	PRESENT	0
540260	539549	20088L	PARTICIPANT	\N	PRESENT	0
540261	539549	20092G	PARTICIPANT	\N	PRESENT	0
540262	539549	20080C	PARTICIPANT	\N	PRESENT	0
540263	539549	19725B	PARTICIPANT	\N	PRESENT	0
540264	539549	14097Y	PARTICIPANT	\N	PRESENT	0
540265	539549	14151M	PARTICIPANT	\N	PRESENT	0
540266	539549	11067R	PARTICIPANT	\N	PRESENT	0
540267	539549	11033F	PARTICIPANT	\N	PRESENT	0
540268	539549	19689Q	PARTICIPANT	\N	PRESENT	0
540269	539549	19782L	PARTICIPANT	\N	PRESENT	0
540270	539549	20116W	PARTICIPANT	\N	PRESENT	0
540271	539549	20076G	PARTICIPANT	\N	PRESENT	0
540272	539549	20090E	PARTICIPANT	\N	PRESENT	0
540273	539549	14147R	PARTICIPANT	\N	PRESENT	0
540274	539549	14211G	PARTICIPANT	\N	PRESENT	0
540275	539549	19798U	PARTICIPANT	\N	PRESENT	0
540276	539549	20038A	PARTICIPANT	\N	PRESENT	0
540277	539549	20022R	PARTICIPANT	\N	PRESENT	0
540278	539549	14001X	PARTICIPANT	\N	PRESENT	0
540279	539549	20026V	PARTICIPANT	\N	PRESENT	0
540280	539549	20142Y	PARTICIPANT	\N	PRESENT	0
540281	539549	20032T	PARTICIPANT	\N	PRESENT	0
540282	539549	20100N	PARTICIPANT	\N	PRESENT	0
540283	539549	20034V	PARTICIPANT	\N	PRESENT	0
540284	539549	20108W	PARTICIPANT	\N	PRESENT	0
540285	539549	19515S	PARTICIPANT	\N	PRESENT	0
540286	539549	20056C	PARTICIPANT	\N	PRESENT	0
540287	539549	19443T	PARTICIPANT	\N	PRESENT	0
540288	539549	20136B	PARTICIPANT	\N	PRESENT	0
540289	539549	20180F	PARTICIPANT	\N	PRESENT	0
540290	539549	19467C	PARTICIPANT	\N	PRESENT	0
540291	539549	20140W	PARTICIPANT	\N	PRESENT	0
540292	539549	20044X	PARTICIPANT	\N	PRESENT	0
540293	539549	20122U	PARTICIPANT	\N	PRESENT	0
540294	539549	19503N	PARTICIPANT	\N	PRESENT	0
540295	539549	04085P	PARTICIPANT	\N	PRESENT	0
540296	539549	12041X	PARTICIPANT	\N	PRESENT	0
540297	539549	19758L	PARTICIPANT	\N	PRESENT	0
540298	539549	20172F	PARTICIPANT	\N	PRESENT	0
540299	539549	20082E	PARTICIPANT	\N	PRESENT	0
540300	539549	19333N	PARTICIPANT	\N	PRESENT	0
540301	539549	19575F	PARTICIPANT	\N	PRESENT	0
540302	539549	19649G	PARTICIPANT	\N	PRESENT	0
540303	539549	14231L	PARTICIPANT	\N	PRESENT	0
540304	539549	19729F	PARTICIPANT	\N	PRESENT	0
540305	539549	14055N	PARTICIPANT	\N	PRESENT	0
540306	539549	20098N	PARTICIPANT	\N	PRESENT	0
540311	539549	11048N	PARTICIPANT	\N	PRESENT	0
540308	539549	20096L	PARTICIPANT	\N	PRESENT	0
540309	539549	14069U	PARTICIPANT	\N	PRESENT	0
540310	539549	20138D	PARTICIPANT	\N	PRESENT	0
540312	539549	20152B	PARTICIPANT	\N	PRESENT	0
540313	539549	19701S	PARTICIPANT	\N	PRESENT	0
540314	539549	19621T	PARTICIPANT	\N	PRESENT	0
540315	539549	17367Q	PARTICIPANT	\N	PRESENT	0
540316	539549	19549D	PARTICIPANT	\N	PRESENT	0
540317	539549	95063L	PARTICIPANT	\N	PRESENT	0
540318	539549	19768N	PARTICIPANT	\N	PRESENT	0
540319	539549	14215L	PARTICIPANT	\N	PRESENT	0
540320	539549	20062A	PARTICIPANT	\N	PRESENT	0
540321	539549	14033T	PARTICIPANT	\N	PRESENT	0
540322	539549	14223L	PARTICIPANT	\N	PRESENT	0
540323	539549	20024T	PARTICIPANT	\N	PRESENT	0
540324	539549	04033B	PARTICIPANT	\N	PRESENT	0
540325	539549	07033P	PARTICIPANT	\N	PRESENT	0
540326	539549	19563B	PARTICIPANT	\N	PRESENT	0
540330	539549	20126Y	PARTICIPANT	\N	PRESENT	0
540328	539549	19719D	PARTICIPANT	\N	PRESENT	0
540329	539549	20118Y	PARTICIPANT	\N	PRESENT	0
540331	539549	20124W	PARTICIPANT	\N	PRESENT	0
540332	539549	14026U	PARTICIPANT	\N	PRESENT	0
540333	539549	05012A	PARTICIPANT	\N	PRESENT	0
540334	539549	20054A	PARTICIPANT	\N	PRESENT	0
540335	539549	14187A	PARTICIPANT	\N	PRESENT	0
540336	539549	19507S	PARTICIPANT	\N	PRESENT	0
540337	539549	11090Q	PARTICIPANT	\N	PRESENT	0
540338	539549	11080N	PARTICIPANT	\N	PRESENT	0
540339	539549	08015R	PARTICIPANT	\N	PRESENT	0
540340	539549	19447X	PARTICIPANT	\N	PRESENT	0
540341	539549	17637T	PARTICIPANT	\N	PRESENT	0
540342	539549	19703U	PARTICIPANT	\N	PRESENT	0
540343	539549	05008E	PARTICIPANT	\N	PRESENT	0
516723	516132	19629C	PARTICIPANT	\N	PRESENT	0
516724	516132	20116W	PARTICIPANT	\N	PRESENT	0
516725	516132	14041T	PARTICIPANT	\N	PRESENT	0
516726	516132	14251Q	PARTICIPANT	\N	PRESENT	0
516727	516132	11072N	PARTICIPANT	\N	PRESENT	0
516728	516132	14179A	PARTICIPANT	\N	PRESENT	0
516729	516132	14237S	PARTICIPANT	\N	PRESENT	0
516730	516132	19621T	PARTICIPANT	\N	PRESENT	0
516731	516132	04047H	PARTICIPANT	\N	PRESENT	0
516732	516132	14021P	PARTICIPANT	\N	PRESENT	0
516736	516132	19503N	PARTICIPANT	\N	PRESENT	0
516734	516132	04085P	PARTICIPANT	\N	PRESENT	0
516735	516132	20114U	PARTICIPANT	\N	PRESENT	0
516737	516132	01028R	PARTICIPANT	\N	PRESENT	0
516815	514130	19735D	PARTICIPANT	\N	PRESENT	0
516816	514130	19723Y	PARTICIPANT	\N	PRESENT	0
516721	516132	14215L	PARTICIPANT	\N	PRESENT	0
516722	516132	19717B	PARTICIPANT	\N	PRESENT	0
516819	514130	01058X	PARTICIPANT	\N	EXCUSE	0
516864	514130	01048V	PARTICIPANT	\N	EXCUSE	0
518812	518778	11099A	PARTICIPANT	\N	PRESENT	0
518813	518778	20028X	PARTICIPANT	\N	PRESENT	0
518815	518778	08028W	PARTICIPANT	\N	PRESENT	0
518816	518778	14207L	PARTICIPANT	\N	PRESENT	0
518817	518778	19383Y	PARTICIPANT	\N	PRESENT	0
518818	518778	19441R	PARTICIPANT	\N	PRESENT	0
518819	518778	20082E	PARTICIPANT	\N	PRESENT	0
518820	518778	01025N	PARTICIPANT	\N	PRESENT	0
519247	518915	20146D	PARTICIPANT	\N	PRESENT	0
521433	521431	14053L	PARTICIPANT	\N	PRESENT	0
521434	521431	19725B	PARTICIPANT	\N	PRESENT	0
525282	524108	20104S	PARTICIPANT	\N	PRESENT	1
525283	524108	19521Q	PARTICIPANT	\N	PRESENT	0
525284	524108	14251Q	PARTICIPANT	\N	PRESENT	1
525285	524108	08015R	PARTICIPANT	\N	PRESENT	1
525286	524108	14219Q	PARTICIPANT	\N	PRESENT	1
525287	524108	20048C	PARTICIPANT	\N	PRESENT	1
525288	524108	14179A	PARTICIPANT	\N	PRESENT	1
525292	524108	16685X	PARTICIPANT	\N	PRESENT	1
525293	524108	19387D	PARTICIPANT	\N	PRESENT	1
525296	524108	14207L	PARTICIPANT	\N	PRESENT	1
525519	524599	19717B	PARTICIPANT	\N	PRESENT	0
525520	524599	20024T	PARTICIPANT	\N	PRESENT	0
525521	524599	20138D	PARTICIPANT	\N	PRESENT	0
525522	524599	20090E	PARTICIPANT	\N	PRESENT	0
525523	524599	19663E	PARTICIPANT	\N	PRESENT	0
525524	524599	10006L	PARTICIPANT	\N	PRESENT	0
525525	524599	14041T	PARTICIPANT	\N	PRESENT	0
525526	524599	19553Y	PARTICIPANT	\N	PRESENT	0
525527	524599	14213J	PARTICIPANT	\N	PRESENT	0
525528	524599	19723Y	PARTICIPANT	\N	PRESENT	0
525529	524599	14223L	PARTICIPANT	\N	PRESENT	0
525530	524599	04092N	PARTICIPANT	\N	PRESENT	0
525531	524599	14331P	PARTICIPANT	\N	PRESENT	0
525532	524599	19798U	PARTICIPANT	\N	PRESENT	0
525533	524599	11097X	PARTICIPANT	\N	PRESENT	0
525534	524599	19703U	PARTICIPANT	\N	PRESENT	0
525535	524599	19749K	PARTICIPANT	\N	PRESENT	0
525897	524074	04008A	PARTICIPANT	\N	EXCUSE	0
525898	524074	19581D	PARTICIPANT	\N	EXCUSE	0
525899	524074	19585H	PARTICIPANT	\N	EXCUSE	0
526395	518916	14033T	PARTICIPANT	\N	EXCUSE	0
526445	526370	19663E	PARTICIPANT	\N	PRESENT	1
526446	526370	20130U	PARTICIPANT	\N	PRESENT	1
526447	526370	17965H	PARTICIPANT	\N	PRESENT	1
526537	526536	11048N	PARTICIPANT	\N	PRESENT	0
526729	522158	19631V	PARTICIPANT	\N	PRESENT	0
526734	526653	19447X	PARTICIPANT	\N	PRESENT	0
526736	526735	19699S	PARTICIPANT	\N	PRESENT	0
526740	525108	20114U	PARTICIPANT	\N	PRESENT	0
526741	525108	17589D	PARTICIPANT	\N	PRESENT	0
526742	525108	01024M	PARTICIPANT	\N	PRESENT	0
526743	525108	19691J	PARTICIPANT	\N	PRESENT	0
526744	525108	07029T	PARTICIPANT	\N	PRESENT	0
526745	525108	19657G	PARTICIPANT	\N	PRESENT	0
526746	525108	08047A	PARTICIPANT	\N	PRESENT	0
526747	525108	19745F	PARTICIPANT	\N	PRESENT	0
526748	525108	19349W	PARTICIPANT	\N	PRESENT	0
526749	525108	19798U	PARTICIPANT	\N	PRESENT	0
528802	526543	19521Q	PARTICIPANT	\N	PRESENT	0
528816	526543	20034V	PARTICIPANT	\N	PRESENT	0
528817	526543	19387D	PARTICIPANT	\N	PRESENT	0
528818	526543	19563B	PARTICIPANT	\N	PRESENT	0
528821	526543	99004R	PARTICIPANT	\N	PRESENT	0
528822	526543	20098N	PARTICIPANT	\N	PRESENT	0
528823	526543	14179A	PARTICIPANT	\N	PRESENT	0
528824	526543	20042V	PARTICIPANT	\N	PRESENT	0
528825	526543	14189C	PARTICIPANT	\N	PRESENT	0
528836	526543	11065P	PARTICIPANT	\N	PRESENT	0
528838	526543	19565D	PARTICIPANT	\N	PRESENT	0
528839	526543	14327T	PARTICIPANT	\N	PRESENT	0
528840	526543	19349W	PARTICIPANT	\N	PRESENT	0
528841	526543	20110Q	PARTICIPANT	\N	PRESENT	0
528842	526543	14069U	PARTICIPANT	\N	PRESENT	0
528844	526543	19629C	PARTICIPANT	\N	PRESENT	0
528845	526543	19683J	PARTICIPANT	\N	PRESENT	0
528846	526543	14083S	PARTICIPANT	\N	PRESENT	0
528902	526544	19565D	PARTICIPANT	\N	PRESENT	0
528903	526544	14001X	PARTICIPANT	\N	PRESENT	0
528904	526544	20036X	PARTICIPANT	\N	PRESENT	0
528905	526544	20116W	PARTICIPANT	\N	PRESENT	0
528906	526544	04057K	PARTICIPANT	\N	PRESENT	0
528907	526544	20128B	PARTICIPANT	\N	PRESENT	0
528908	526544	14249W	PARTICIPANT	\N	PRESENT	0
528909	526544	14327T	PARTICIPANT	\N	PRESENT	0
528910	526544	19521Q	PARTICIPANT	\N	PRESENT	0
528911	526544	20042V	PARTICIPANT	\N	PRESENT	0
528912	526544	14083S	PARTICIPANT	\N	PRESENT	0
528913	526544	14069U	PARTICIPANT	\N	PRESENT	0
528914	526544	20070A	PARTICIPANT	\N	PRESENT	0
528915	526544	14041T	PARTICIPANT	\N	PRESENT	0
528916	526544	11070L	PARTICIPANT	\N	PRESENT	0
528917	526544	08073C	PARTICIPANT	\N	PRESENT	0
528918	526544	11065P	PARTICIPANT	\N	PRESENT	0
528919	526544	19399H	PARTICIPANT	\N	PRESENT	0
528921	526544	11012A	PARTICIPANT	\N	PRESENT	0
528947	526545	11033F	PARTICIPANT	\N	PRESENT	0
528948	526545	11072N	PARTICIPANT	\N	PRESENT	0
528949	526545	19629C	PARTICIPANT	\N	PRESENT	0
528950	526545	04085P	PARTICIPANT	\N	PRESENT	0
528951	526545	14089Y	PARTICIPANT	\N	PRESENT	0
528952	526545	11026G	PARTICIPANT	\N	PRESENT	0
528953	526545	20050V	PARTICIPANT	\N	PRESENT	0
528954	526545	20108W	PARTICIPANT	\N	PRESENT	0
528955	526545	19649G	PARTICIPANT	\N	PRESENT	0
528956	526545	20090E	PARTICIPANT	\N	PRESENT	0
528958	526545	14053L	PARTICIPANT	\N	PRESENT	0
528959	526545	20070A	PARTICIPANT	\N	PRESENT	0
528960	526545	19333N	PARTICIPANT	\N	PRESENT	0
528962	526545	14041T	PARTICIPANT	\N	PRESENT	0
528963	526545	19399H	PARTICIPANT	\N	PRESENT	0
528965	526545	01028R	PARTICIPANT	\N	PRESENT	0
528966	526545	19651A	PARTICIPANT	\N	PRESENT	0
528967	526545	20132W	PARTICIPANT	\N	PRESENT	0
528968	526545	14231L	PARTICIPANT	\N	PRESENT	0
528969	526545	19531S	PARTICIPANT	\N	PRESENT	0
528970	526545	11045K	PARTICIPANT	\N	PRESENT	0
528943	526545	14026U	PARTICIPANT	\N	PRESENT	0
528946	526545	05008E	PARTICIPANT	\N	PRESENT	0
528971	526545	04047H	PARTICIPANT	\N	PRESENT	0
528972	526545	19447X	PARTICIPANT	\N	PRESENT	0
528973	526545	19565D	PARTICIPANT	\N	PRESENT	0
528974	526545	99004R	PARTICIPANT	\N	PRESENT	0
528975	526545	19747H	PARTICIPANT	\N	PRESENT	0
528976	526545	14069U	PARTICIPANT	\N	PRESENT	0
528977	526545	14259Y	PARTICIPANT	\N	PRESENT	0
528978	526545	20098N	PARTICIPANT	\N	PRESENT	0
528979	526545	19553Y	PARTICIPANT	\N	PRESENT	0
528980	526545	20116W	PARTICIPANT	\N	PRESENT	0
528981	526545	19441R	PARTICIPANT	\N	PRESENT	0
528900	526544	11045K	PARTICIPANT	\N	PRESENT	0
528901	526544	11040E	PARTICIPANT	\N	PRESENT	0
528982	526545	14083S	PARTICIPANT	\N	PRESENT	0
528983	526545	19667J	PARTICIPANT	\N	PRESENT	0
528984	526545	11085T	PARTICIPANT	\N	PRESENT	0
528986	526545	14021P	PARTICIPANT	\N	PRESENT	0
528999	526545	19533U	PARTICIPANT	\N	PRESENT	0
530885	529082	19762G	PARTICIPANT	\N	PRESENT	0
530886	529082	11033F	PARTICIPANT	\N	PRESENT	0
530947	529083	19621T	PARTICIPANT	\N	PRESENT	0
530948	529083	20050V	PARTICIPANT	\N	PRESENT	0
530949	529083	20134Y	PARTICIPANT	\N	PRESENT	0
530950	529083	19651A	PARTICIPANT	\N	PRESENT	0
530951	529083	19719D	PARTICIPANT	\N	PRESENT	0
530952	529083	19593H	PARTICIPANT	\N	PRESENT	0
530953	529083	20052X	PARTICIPANT	\N	PRESENT	0
530954	529083	14229S	PARTICIPANT	\N	PRESENT	0
530955	529083	20138D	PARTICIPANT	\N	PRESENT	0
530956	529083	20048C	PARTICIPANT	\N	PRESENT	0
530957	529083	14123H	PARTICIPANT	\N	PRESENT	0
530958	529083	19533U	PARTICIPANT	\N	PRESENT	0
530959	529083	19747H	PARTICIPANT	\N	PRESENT	0
530960	529083	19553Y	PARTICIPANT	\N	PRESENT	0
530961	529083	20132W	PARTICIPANT	\N	PRESENT	0
530962	529083	19715Y	PARTICIPANT	\N	PRESENT	0
530963	529083	11067R	PARTICIPANT	\N	PRESENT	0
530964	529083	18193Q	PARTICIPANT	\N	PRESENT	0
530965	529083	19599P	PARTICIPANT	\N	PRESENT	0
530966	529083	20130U	PARTICIPANT	\N	PRESENT	0
530967	529083	19347U	PARTICIPANT	\N	PRESENT	0
530968	529083	11033F	PARTICIPANT	\N	PRESENT	0
530969	529083	01024M	PARTICIPANT	\N	PRESENT	0
530970	529083	19479G	PARTICIPANT	\N	PRESENT	0
530971	529083	11031D	PARTICIPANT	\N	PRESENT	0
530972	529083	14179A	PARTICIPANT	\N	PRESENT	0
530973	529083	20024T	PARTICIPANT	\N	PRESENT	0
530974	529083	19681G	PARTICIPANT	\N	PRESENT	0
530975	529083	14069U	PARTICIPANT	\N	PRESENT	0
530976	529083	18083K	PARTICIPANT	\N	PRESENT	0
530977	529083	14109K	PARTICIPANT	\N	PRESENT	0
530978	529083	20100N	PARTICIPANT	\N	PRESENT	0
530979	529083	20108W	PARTICIPANT	\N	PRESENT	0
530980	529083	14073Q	PARTICIPANT	\N	PRESENT	0
530981	529083	19611R	PARTICIPANT	\N	PRESENT	0
530982	529083	20086J	PARTICIPANT	\N	PRESENT	0
531017	529084	04085P	PARTICIPANT	\N	PRESENT	0
531018	529084	18193Q	PARTICIPANT	\N	PRESENT	0
531019	529084	20036X	PARTICIPANT	\N	PRESENT	0
531020	529084	20134Y	PARTICIPANT	\N	PRESENT	0
531021	529084	20100N	PARTICIPANT	\N	PRESENT	0
531022	529084	11033F	PARTICIPANT	\N	PRESENT	0
530945	529083	20142Y	PARTICIPANT	\N	PRESENT	0
530946	529083	12041X	PARTICIPANT	\N	PRESENT	0
531023	529084	14151M	PARTICIPANT	\N	PRESENT	0
531024	529084	14069U	PARTICIPANT	\N	PRESENT	0
531025	529084	20052X	PARTICIPANT	\N	PRESENT	0
531026	529084	19629C	PARTICIPANT	\N	PRESENT	0
531027	529084	20122U	PARTICIPANT	\N	PRESENT	0
531028	529084	19747H	PARTICIPANT	\N	PRESENT	0
531029	529084	20086J	PARTICIPANT	\N	PRESENT	0
531030	529084	20136B	PARTICIPANT	\N	PRESENT	0
531031	529084	14179A	PARTICIPANT	\N	PRESENT	0
531032	529084	19621T	PARTICIPANT	\N	PRESENT	0
531033	529084	20070A	PARTICIPANT	\N	PRESENT	0
531034	529084	14249W	PARTICIPANT	\N	PRESENT	0
531049	531048	20100N	PARTICIPANT	\N	PRESENT	0
531053	531048	14073Q	PARTICIPANT	\N	PRESENT	0
531051	531048	11083R	PARTICIPANT	\N	PRESENT	0
531052	531048	19725B	PARTICIPANT	\N	PRESENT	1
531054	531048	14331P	PARTICIPANT	\N	PRESENT	0
531055	531048	04057K	PARTICIPANT	\N	PRESENT	0
531056	531048	19553Y	PARTICIPANT	\N	PRESENT	1
531068	529007	97011G	PARTICIPANT	\N	PRESENT	0
531069	529007	19657G	PARTICIPANT	\N	PRESENT	0
531070	529007	08073C	PARTICIPANT	\N	PRESENT	0
531076	531075	19599P	PARTICIPANT	\N	PRESENT	0
531078	531077	20042V	PARTICIPANT	\N	PRESENT	0
531079	531077	11080N	PRESIDENT	0	PRESENT	0
531080	531077	01057W	PARTICIPANT	\N	PRESENT	0
531015	529084	14026U	PARTICIPANT	\N	PRESENT	0
531016	529084	19760E	PARTICIPANT	\N	PRESENT	0
531081	531077	14121F	PARTICIPANT	\N	PRESENT	0
531082	531077	19711U	PARTICIPANT	\N	PRESENT	0
531083	531077	05012A	PARTICIPANT	\N	PRESENT	0
531116	531115	14041T	PARTICIPANT	\N	PRESENT	0
531117	531115	14097Y	PARTICIPANT	\N	PRESENT	0
531118	531115	08069G	PARTICIPANT	\N	PRESENT	0
531119	531115	14147R	PARTICIPANT	\N	PRESENT	0
531120	531115	19647E	PARTICIPANT	\N	PRESENT	0
531121	531115	04035D	PARTICIPANT	\N	PRESENT	0
531122	531115	14215L	PARTICIPANT	\N	PRESENT	0
531152	531148	14033T	PARTICIPANT	\N	PRESENT	0
531153	531148	14257W	PARTICIPANT	\N	PRESENT	0
531154	531149	14033T	PARTICIPANT	\N	PRESENT	0
531155	531149	14257W	PARTICIPANT	\N	PRESENT	0
531156	531149	20174H	PARTICIPANT	\N	PRESENT	0
531157	531150	14033T	PARTICIPANT	\N	PRESENT	0
531158	531151	14033T	PARTICIPANT	\N	PRESENT	0
531167	526817	14133K	PARTICIPANT	\N	PRESENT	1
531168	526817	14189C	PARTICIPANT	\N	PRESENT	0
531169	526817	20094J	PARTICIPANT	\N	PRESENT	0
531170	526817	20104S	PARTICIPANT	\N	EXCUSE	0
531171	526817	19701S	PARTICIPANT	\N	PRESENT	1
531172	526817	14357A	PARTICIPANT	\N	PRESENT	1
531173	526817	19251M	PARTICIPANT	\N	PRESENT	1
531174	526817	20100N	PARTICIPANT	\N	PRESENT	0
531175	526817	08018U	PARTICIPANT	\N	PRESENT	0
531176	526817	11083R	PARTICIPANT	\N	PRESENT	0
531177	526817	14033T	PARTICIPANT	\N	PRESENT	1
531178	526817	14026U	PARTICIPANT	\N	PRESENT	1
531179	526817	19725B	PARTICIPANT	\N	PRESENT	1
531180	526817	20128B	PARTICIPANT	\N	PRESENT	0
531181	526817	19531S	PARTICIPANT	\N	PRESENT	0
531182	526817	14097Y	PARTICIPANT	\N	PRESENT	0
531183	526817	14073Q	PARTICIPANT	\N	PRESENT	0
531184	526817	08034U	PARTICIPANT	\N	PRESENT	0
531185	526817	19441R	PARTICIPANT	\N	PRESENT	1
531186	526817	14001X	PARTICIPANT	\N	PRESENT	1
531187	526817	04057K	PARTICIPANT	\N	PRESENT	0
531188	526817	04070G	PARTICIPANT	\N	PRESENT	1
531189	526817	14169X	PARTICIPANT	\N	PRESENT	0
531190	526817	14331P	PRESIDENT	0	PRESENT	0
530881	530782	20106U	PARTICIPANT	\N	PRESENT	0
530882	530782	20076G	PARTICIPANT	\N	PRESENT	0
530883	530782	19251M	PARTICIPANT	\N	PRESENT	0
530884	529082	14123H	PARTICIPANT	\N	PRESENT	0
531191	526817	04034C	PARTICIPANT	\N	PRESENT	1
531214	531213	14133K	PARTICIPANT	\N	PRESENT	0
531215	531213	04085P	PARTICIPANT	\N	PRESENT	0
531216	531213	04047H	PARTICIPANT	\N	PRESENT	0
531217	531213	19719D	PARTICIPANT	\N	PRESENT	0
531218	531213	10006L	PARTICIPANT	\N	PRESENT	0
531219	531213	19347U	PARTICIPANT	\N	PRESENT	0
531220	531213	14026U	PARTICIPANT	\N	PRESENT	0
531221	531213	11048N	PARTICIPANT	\N	PRESENT	0
531222	531213	14021P	PARTICIPANT	\N	PRESENT	0
531223	531213	99004R	PARTICIPANT	\N	PRESENT	0
531224	531213	19611R	PARTICIPANT	\N	PRESENT	0
531225	531213	12041X	PARTICIPANT	\N	PRESENT	0
531226	531213	01043Q	PARTICIPANT	\N	PRESENT	0
531227	531213	14219Q	PARTICIPANT	\N	PRESENT	0
531228	531213	01060R	PARTICIPANT	\N	PRESENT	0
531229	531213	11090Q	PARTICIPANT	\N	PRESENT	0
531230	531213	14331P	PARTICIPANT	\N	PRESENT	0
531231	531213	14225N	PARTICIPANT	\N	PRESENT	0
531232	531213	11012A	PARTICIPANT	\N	PRESENT	0
531233	531213	04033B	PARTICIPANT	\N	PRESENT	0
531234	531213	11045K	PARTICIPANT	\N	PRESENT	0
531235	531213	01028R	PARTICIPANT	\N	PRESENT	0
531237	531236	14030Q	PARTICIPANT	\N	EXCUSE	0
531238	531236	08060W	PARTICIPANT	\N	EXCUSE	0
531239	531236	14357A	PARTICIPANT	\N	EXCUSE	0
531240	531236	14026U	PARTICIPANT	\N	EXCUSE	0
531241	531236	19697Q	PARTICIPANT	\N	EXCUSE	0
531242	531236	20092G	PARTICIPANT	\N	EXCUSE	0
531243	531236	19760E	PARTICIPANT	\N	PRESENT	0
531244	531236	19515S	PRESIDENT	0	PRESENT	0
531251	531236	14105F	PARTICIPANT	\N	PRESENT	0
531252	531236	19467C	PARTICIPANT	\N	PRESENT	0
531253	531236	14083S	PARTICIPANT	\N	PRESENT	0
531254	531236	14041T	PARTICIPANT	\N	PRESENT	0
531255	531236	20040T	PARTICIPANT	\N	PRESENT	0
531256	531236	20126Y	PARTICIPANT	\N	PRESENT	0
531257	531236	08015R	PARTICIPANT	\N	PRESENT	0
531258	531236	16685X	PARTICIPANT	\N	PRESENT	0
531259	531236	14031R	PARTICIPANT	\N	PRESENT	0
531260	531236	20054A	PARTICIPANT	\N	PRESENT	0
531262	531236	19575F	PARTICIPANT	\N	PRESENT	0
514684	514683	19515S	PARTICIPANT	\N	PRESENT	0
514685	514683	20174H	PARTICIPANT	\N	PRESENT	0
514688	514687	19515S	PARTICIPANT	\N	PRESENT	0
514689	514687	19521Q	PARTICIPANT	\N	PRESENT	0
520207	518915	14259Y	PARTICIPANT	\N	EXCUSE	0
520209	518915	14219Q	PARTICIPANT	\N	EXCUSE	0
520219	518915	19631V	PARTICIPANT	\N	PRESENT	0
520220	518915	18083K	PARTICIPANT	\N	PRESENT	0
520221	518915	19715Y	PARTICIPANT	\N	PRESENT	0
524273	524053	19719D	PARTICIPANT	\N	PRESENT	0
526554	526553	19683J	PARTICIPANT	\N	PRESENT	0
526555	526553	19723Y	PARTICIPANT	\N	PRESENT	0
526556	526552	19683J	PARTICIPANT	\N	PRESENT	0
526557	526552	19723Y	PARTICIPANT	\N	PRESENT	0
526561	522155	19760E	PARTICIPANT	\N	PRESENT	0
526562	522155	19367Y	PARTICIPANT	\N	PRESENT	0
526565	522155	20090E	PARTICIPANT	\N	PRESENT	0
526566	522155	14195A	PARTICIPANT	\N	PRESENT	0
526567	522155	11031D	PARTICIPANT	\N	PRESENT	0
526568	522155	10006L	PRESIDENT	0	PRESENT	0
526569	522155	14217N	PARTICIPANT	\N	PRESENT	0
526570	522155	20040T	PARTICIPANT	\N	PRESENT	0
526571	522155	20172F	PARTICIPANT	\N	PRESENT	0
526572	522155	19691J	PARTICIPANT	\N	PRESENT	0
526573	522155	19553Y	PARTICIPANT	\N	PRESENT	0
526574	522155	19569H	PARTICIPANT	\N	PRESENT	0
526575	522155	20066E	PARTICIPANT	\N	PRESENT	0
526576	522155	19591F	PARTICIPANT	\N	PRESENT	0
526577	522155	19683J	PARTICIPANT	\N	PRESENT	0
526578	522155	19723Y	PARTICIPANT	\N	PRESENT	0
526579	522155	18193Q	PARTICIPANT	\N	PRESENT	0
526580	522155	04057K	PARTICIPANT	\N	PRESENT	0
526581	522155	11067R	PARTICIPANT	\N	PRESENT	0
526582	522155	20148F	PARTICIPANT	\N	PRESENT	0
526583	522155	20130U	PARTICIPANT	\N	PRESENT	0
526584	522155	17965H	PARTICIPANT	\N	PRESENT	0
526585	522155	19679N	PARTICIPANT	\N	PRESENT	0
526586	522155	19798U	PARTICIPANT	\N	PRESENT	0
526587	522155	11097X	PARTICIPANT	\N	PRESENT	0
526588	522155	19703U	PARTICIPANT	\N	PRESENT	0
526589	522155	19717B	PARTICIPANT	\N	PRESENT	1
526590	522155	19415P	PARTICIPANT	\N	PRESENT	1
526591	522155	11103C	PARTICIPANT	\N	PRESENT	1
526592	522155	14042U	PARTICIPANT	\N	PRESENT	1
526593	522155	08045X	PARTICIPANT	\N	PRESENT	1
526594	522155	14026U	PARTICIPANT	\N	PRESENT	1
526595	522155	14213J	PARTICIPANT	\N	PRESENT	1
526596	522155	19697Q	PARTICIPANT	\N	PRESENT	1
526597	522155	19657G	PARTICIPANT	\N	PRESENT	1
526598	522155	14223L	PARTICIPANT	\N	PRESENT	1
526599	522155	04092N	PARTICIPANT	\N	PRESENT	1
526600	522155	19301E	PARTICIPANT	\N	PRESENT	1
526601	522155	01034P	PARTICIPANT	\N	PRESENT	1
526602	522155	14030Q	PARTICIPANT	\N	PRESENT	0
526603	522155	20138D	PARTICIPANT	\N	PRESENT	0
526604	522155	20152B	PARTICIPANT	\N	PRESENT	0
526605	522155	19758L	PARTICIPANT	\N	PRESENT	0
526606	522155	20124W	PARTICIPANT	\N	PRESENT	0
526607	522155	20132W	PARTICIPANT	\N	PRESENT	0
526608	522155	14123H	PARTICIPANT	\N	PRESENT	0
526609	522155	20180F	PARTICIPANT	\N	PRESENT	0
526610	522155	19399H	PARTICIPANT	\N	PRESENT	0
526611	522155	20056C	PARTICIPANT	\N	PRESENT	0
526612	522155	14073Q	PARTICIPANT	\N	PRESENT	0
526613	522155	19611R	PARTICIPANT	\N	PRESENT	0
526614	522155	19699S	PARTICIPANT	\N	PRESENT	0
526615	522155	20052X	PARTICIPANT	\N	PRESENT	0
526616	522155	08012N	PARTICIPANT	\N	PRESENT	0
526617	522155	19573D	PARTICIPANT	\N	PRESENT	0
526618	522155	08061X	PARTICIPANT	\N	PRESENT	0
526619	522155	19533U	PARTICIPANT	\N	PRESENT	0
526620	522155	11043H	PARTICIPANT	\N	PRESENT	0
526621	522155	19527W	PARTICIPANT	\N	PRESENT	0
526622	522155	20026V	PARTICIPANT	\N	PRESENT	0
526623	522155	19693L	PARTICIPANT	\N	PRESENT	1
526624	522155	20134Y	PARTICIPANT	\N	PRESENT	0
526625	522155	19329S	PARTICIPANT	\N	PRESENT	1
526626	522155	20048C	PARTICIPANT	\N	PRESENT	1
526627	522155	19735D	PARTICIPANT	\N	PRESENT	1
526628	522155	11104D	PARTICIPANT	\N	PRESENT	1
526629	522155	14109K	PARTICIPANT	\N	PRESENT	1
526630	522155	04070G	PARTICIPANT	\N	PRESENT	0
526631	522155	14229S	PARTICIPANT	\N	PRESENT	1
526632	522155	20098N	PARTICIPANT	\N	PRESENT	1
527566	526491	20080C	PARTICIPANT	\N	PRESENT	0
527584	526393	20136B	PARTICIPANT	\N	PRESENT	0
527585	526690	19443T	PARTICIPANT	\N	PRESENT	1
527586	526690	12041X	PARTICIPANT	\N	PRESENT	1
527587	526690	19565D	PARTICIPANT	\N	PRESENT	0
527588	526690	20072C	PARTICIPANT	\N	PRESENT	1
527589	526690	04034C	PARTICIPANT	\N	PRESENT	1
527590	526690	01058X	PARTICIPANT	\N	PRESENT	1
527591	526690	16685X	PARTICIPANT	\N	PRESENT	0
527592	526690	04042C	PRESIDENT	0	PRESENT	0
527593	526690	11054L	PARTICIPANT	\N	PRESENT	0
527594	526690	11066Q	PARTICIPANT	\N	PRESENT	0
527595	526690	08056B	PARTICIPANT	\N	PRESENT	0
527596	526690	12028B	PARTICIPANT	\N	PRESENT	0
527597	526690	19421M	PARTICIPANT	\N	PRESENT	0
527598	526690	19347U	PARTICIPANT	\N	PRESENT	0
527599	526690	14249W	PARTICIPANT	\N	PRESENT	0
527600	526690	08047A	PARTICIPANT	\N	PRESENT	1
527601	526690	14059S	PARTICIPANT	\N	PRESENT	0
527602	526690	14097Y	PARTICIPANT	\N	PRESENT	1
527603	526690	04035D	PARTICIPANT	\N	PRESENT	1
527604	526690	14133K	PARTICIPANT	\N	PRESENT	0
527605	526690	01062T	PARTICIPANT	\N	PRESENT	1
527606	526690	11041F	PARTICIPANT	\N	PRESENT	1
527607	526690	20042V	PARTICIPANT	\N	PRESENT	0
527608	526690	14105F	PARTICIPANT	\N	PRESENT	0
527609	526690	20064C	PARTICIPANT	\N	PRESENT	0
527610	526690	98022P	PARTICIPANT	\N	PRESENT	0
527611	526690	14267Y	PARTICIPANT	\N	PRESENT	0
527612	526690	11083R	PARTICIPANT	\N	PRESENT	1
527613	526690	14255U	PARTICIPANT	\N	PRESENT	1
527686	526490	14111D	PARTICIPANT	\N	PRESENT	0
527718	526489	19447X	PARTICIPANT	\N	PRESENT	0
527687	526490	10015M	PARTICIPANT	\N	PRESENT	0
527659	526549	19533U	PARTICIPANT	\N	PRESENT	0
527660	526549	20124W	PARTICIPANT	\N	PRESENT	0
527661	526549	20058E	PARTICIPANT	\N	PRESENT	0
527662	526549	14123H	PARTICIPANT	\N	PRESENT	0
527663	526549	11043H	PARTICIPANT	\N	PRESENT	0
527664	526549	14229S	PARTICIPANT	\N	PRESENT	0
527665	526549	08012N	PARTICIPANT	\N	PRESENT	0
527666	526549	08061X	PARTICIPANT	\N	PRESENT	0
527667	526549	19527W	PARTICIPANT	\N	PRESENT	1
527668	526549	19593H	PARTICIPANT	\N	PRESENT	0
527669	526549	20134Y	PARTICIPANT	\N	PRESENT	0
527670	526549	19719D	PARTICIPANT	\N	PRESENT	1
527688	526490	11026G	PARTICIPANT	\N	PRESENT	0
527689	526490	19543W	PARTICIPANT	\N	PRESENT	0
527690	526490	04047H	PRESIDENT	0	PRESENT	0
527691	526490	01028R	PARTICIPANT	\N	PRESENT	0
527692	526490	19447X	PARTICIPANT	\N	PRESENT	0
527693	526490	05008E	PARTICIPANT	\N	PRESENT	0
527694	526490	11056N	PARTICIPANT	\N	PRESENT	0
527695	526490	19954N	PARTICIPANT	\N	PRESENT	0
527696	526490	19729F	PARTICIPANT	\N	PRESENT	0
527697	526490	95063L	PARTICIPANT	\N	PRESENT	0
527698	526490	14147R	PARTICIPANT	\N	PRESENT	0
527699	526490	14179A	PARTICIPANT	\N	PRESENT	0
527700	526490	14151M	PARTICIPANT	\N	PRESENT	0
527701	526490	08018U	PARTICIPANT	\N	PRESENT	0
527702	526490	19749K	PARTICIPANT	\N	PRESENT	0
527711	526489	20074E	PARTICIPANT	\N	PRESENT	0
527712	526489	04047H	PRESIDENT	0	PRESENT	0
527713	526489	14053L	PARTICIPANT	\N	PRESENT	0
527714	526489	11026G	PARTICIPANT	\N	PRESENT	0
527715	526489	14147R	PARTICIPANT	\N	PRESENT	0
527716	526489	05008E	PARTICIPANT	\N	PRESENT	0
527717	526489	14089Y	PARTICIPANT	\N	PRESENT	0
527719	526489	14179A	PARTICIPANT	\N	PRESENT	0
527720	526489	10015M	PARTICIPANT	\N	PRESENT	0
527721	526540	08069G	PARTICIPANT	\N	PRESENT	0
527722	526540	19543W	PARTICIPANT	\N	PRESENT	0
527723	526540	19826F	PARTICIPANT	\N	PRESENT	0
527724	526540	14105F	PARTICIPANT	\N	PRESENT	0
527725	526540	14073Q	PARTICIPANT	\N	PRESENT	0
527726	526540	19593H	PARTICIPANT	\N	PRESENT	0
536501	534355	14133K	PARTICIPANT	\N	EXCUSE	0
536502	534355	14030Q	PARTICIPANT	\N	PRESENT	0
536503	534355	19383Y	PRESIDENT	0	PRESENT	0
536504	534355	19621T	PARTICIPANT	\N	PRESENT	0
536505	534355	19758L	PARTICIPANT	\N	PRESENT	0
536506	534355	19467C	PARTICIPANT	\N	PRESENT	0
536507	534355	17589D	PARTICIPANT	\N	PRESENT	0
536508	534355	19719D	PARTICIPANT	\N	PRESENT	0
536509	534355	20140W	PARTICIPANT	\N	PRESENT	0
536510	534355	14026U	PARTICIPANT	\N	PRESENT	0
536511	534355	01025N	PARTICIPANT	\N	PRESENT	0
536512	534355	19551W	PARTICIPANT	\N	PRESENT	1
536513	534355	11099A	PARTICIPANT	\N	PRESENT	0
536514	534355	19441R	PARTICIPANT	\N	PRESENT	0
536515	534355	19637C	PARTICIPANT	\N	PRESENT	0
536516	534355	20028X	PARTICIPANT	\N	PRESENT	0
536517	534355	14109K	PARTICIPANT	\N	PRESENT	1
536518	534355	19798U	PARTICIPANT	\N	PRESENT	0
536519	534355	19762G	PARTICIPANT	\N	PRESENT	0
536520	534355	20026V	PARTICIPANT	\N	PRESENT	0
536559	536558	19673G	PARTICIPANT	\N	PRESENT	0
536560	536558	19749K	PARTICIPANT	\N	PRESENT	0
536562	536561	19673G	PARTICIPANT	\N	PRESENT	0
536563	536561	20074E	PARTICIPANT	\N	PRESENT	0
536565	536564	19673G	PARTICIPANT	\N	PRESENT	0
536566	536564	19749K	PARTICIPANT	\N	PRESENT	0
536567	536564	95063L	PARTICIPANT	\N	PRESENT	0
536569	536568	19954N	PARTICIPANT	\N	PRESENT	0
536570	536568	19673G	PARTICIPANT	\N	PRESENT	0
536571	536568	19749K	PARTICIPANT	\N	PRESENT	0
536574	536573	19749K	PARTICIPANT	\N	PRESENT	0
536576	536575	19673G	PARTICIPANT	\N	PRESENT	0
536577	536575	19749K	PARTICIPANT	\N	PRESENT	0
536578	536575	07004J	PARTICIPANT	\N	PRESENT	0
536579	536575	08011M	PARTICIPANT	\N	PRESENT	0
536581	536580	19673G	PARTICIPANT	\N	PRESENT	0
536582	536580	19749K	PARTICIPANT	\N	PRESENT	0
536585	534275	14030Q	PARTICIPANT	\N	EXCUSE	0
536586	534275	08060W	PARTICIPANT	\N	EXCUSE	0
536587	534275	19545Y	PARTICIPANT	\N	EXCUSE	0
536588	534275	20082E	PARTICIPANT	\N	EXCUSE	0
536589	534275	20092G	PARTICIPANT	\N	EXCUSE	0
536854	536853	07033P	PARTICIPANT	\N	PRESENT	0
538663	538662	19599P	PARTICIPANT	\N	PRESENT	0
540344	539549	19723Y	PARTICIPANT	\N	PRESENT	0
540346	539549	14213J	PARTICIPANT	\N	PRESENT	0
540347	539549	14073Q	PARTICIPANT	\N	PRESENT	0
540348	539549	04071H	PARTICIPANT	\N	PRESENT	0
540349	539549	20048C	PARTICIPANT	\N	PRESENT	0
540350	539549	20134Y	PARTICIPANT	\N	PRESENT	0
540351	539549	14111D	PARTICIPANT	\N	PRESENT	0
540352	539549	20042V	PARTICIPANT	\N	PRESENT	0
540353	539549	20052X	PARTICIPANT	\N	PRESENT	0
540354	539549	95041E	PARTICIPANT	\N	PRESENT	0
540355	539549	14083S	PARTICIPANT	\N	PRESENT	0
540356	539549	14053L	PARTICIPANT	\N	PRESENT	0
540357	539549	17737W	PARTICIPANT	\N	PRESENT	0
540358	539549	20086J	PARTICIPANT	\N	PRESENT	0
540359	539549	14219Q	PARTICIPANT	\N	PRESENT	0
540360	539549	19691J	PARTICIPANT	\N	PRESENT	0
540361	539549	20058E	PARTICIPANT	\N	PRESENT	0
540362	539549	19741B	PARTICIPANT	\N	PRESENT	0
540363	539549	19681G	PARTICIPANT	\N	PRESENT	0
540364	539549	19347U	PARTICIPANT	\N	PRESENT	0
540365	539549	18083K	PARTICIPANT	\N	PRESENT	0
540366	539549	01028R	PARTICIPANT	\N	PRESENT	0
540367	539549	20114U	PARTICIPANT	\N	PRESENT	0
540345	539549	14179A	PARTICIPANT	\N	PRESENT	0
540368	539549	19573D	PARTICIPANT	\N	PRESENT	0
540369	539549	07029T	PARTICIPANT	\N	PRESENT	0
540370	539549	19383Y	PARTICIPANT	\N	PRESENT	0
540371	539549	08010L	PARTICIPANT	\N	PRESENT	0
540372	539549	20110Q	PARTICIPANT	\N	PRESENT	0
540467	539688	97011G	PARTICIPANT	\N	PRESENT	0
540468	539688	20128B	PARTICIPANT	\N	PRESENT	0
540469	539688	16685X	PARTICIPANT	\N	PRESENT	0
540470	539688	01058X	PARTICIPANT	\N	PRESENT	1
540507	540503	20126Y	PARTICIPANT	\N	PRESENT	0
540508	540503	19739H	PARTICIPANT	\N	PRESENT	0
540509	540503	19619A	PARTICIPANT	\N	PRESENT	0
540510	540503	20092G	PARTICIPANT	\N	PRESENT	0
540545	540544	20126Y	PARTICIPANT	\N	PRESENT	0
540546	540544	19739H	PARTICIPANT	\N	PRESENT	0
540547	540544	19619A	PARTICIPANT	\N	PRESENT	0
540548	540544	20092G	PARTICIPANT	\N	PRESENT	0
540558	540557	14357A	PARTICIPANT	\N	PRESENT	0
540559	540557	20126Y	PARTICIPANT	\N	PRESENT	0
540560	540557	19739H	PARTICIPANT	\N	PRESENT	0
540561	540557	19619A	PARTICIPANT	\N	PRESENT	0
540562	540557	20092G	PARTICIPANT	\N	PRESENT	0
540564	536885	19533U	PARTICIPANT	\N	PRESENT	0
541386	539057	19525U	PARTICIPANT	\N	PRESENT	1
541387	539057	14221J	PARTICIPANT	\N	PRESENT	0
541388	539057	19739H	PARTICIPANT	\N	PRESENT	1
541392	541391	20094J	PARTICIPANT	\N	PRESENT	0
541393	541391	20104S	PARTICIPANT	\N	PRESENT	0
541394	541391	20038A	PARTICIPANT	\N	PRESENT	0
541395	541391	97011G	PARTICIPANT	\N	PRESENT	0
541396	541391	19745F	PARTICIPANT	\N	PRESENT	0
541397	541391	19820Y	PARTICIPANT	\N	PRESENT	0
541399	541398	20094J	PARTICIPANT	\N	PRESENT	0
541400	541398	20104S	PARTICIPANT	\N	PRESENT	0
541401	541398	20038A	PARTICIPANT	\N	PRESENT	0
541402	541398	97011G	PARTICIPANT	\N	PRESENT	0
541403	541398	19745F	PARTICIPANT	\N	PRESENT	0
541404	541398	19820Y	PARTICIPANT	\N	PRESENT	0
541434	537784	19966S	PARTICIPANT	\N	PRESENT	1
541436	537784	10006L	PARTICIPANT	\N	PRESENT	0
541437	537784	14042U	PARTICIPANT	\N	PRESENT	0
541438	537784	20172F	PARTICIPANT	\N	PRESENT	1
541439	537784	20066E	PARTICIPANT	\N	PRESENT	1
541447	537784	14026U	PARTICIPANT	\N	PRESENT	1
541458	537784	01025N	PARTICIPANT	\N	PRESENT	0
541577	539550	19533U	PARTICIPANT	\N	PRESENT	0
541578	539550	19563B	PARTICIPANT	\N	PRESENT	0
541579	539550	19511N	PARTICIPANT	\N	PRESENT	0
541580	539550	16685X	PARTICIPANT	\N	PRESENT	0
541581	539550	19739H	PARTICIPANT	\N	PRESENT	0
541582	539550	20144B	PARTICIPANT	\N	PRESENT	0
541583	539550	20124W	PARTICIPANT	\N	PRESENT	0
541584	539550	20132W	PARTICIPANT	\N	PRESENT	0
541585	539550	14053L	PARTICIPANT	\N	PRESENT	0
541586	539550	14207L	PARTICIPANT	\N	PRESENT	0
541587	539550	19347U	PARTICIPANT	\N	PRESENT	0
541588	539550	14187A	PARTICIPANT	\N	PRESENT	0
541589	539550	19637C	PARTICIPANT	\N	PRESENT	0
541590	539550	19415P	PARTICIPANT	\N	PRESENT	0
541591	539550	20072C	PARTICIPANT	\N	PRESENT	0
541592	539550	14071N	PARTICIPANT	\N	PRESENT	0
541593	539550	11070L	PARTICIPANT	\N	PRESENT	0
541594	539550	04035D	PARTICIPANT	\N	PRESENT	0
541595	539550	14219Q	PARTICIPANT	\N	PRESENT	0
541596	539550	05012A	PARTICIPANT	\N	PRESENT	0
541597	539550	20116W	PARTICIPANT	\N	PRESENT	0
541598	539550	14169X	PARTICIPANT	\N	PRESENT	0
541599	539550	11083R	PARTICIPANT	\N	PRESENT	0
541600	539550	20128B	PARTICIPANT	\N	PRESENT	0
541601	539550	19611R	PARTICIPANT	\N	PRESENT	0
541602	539550	11045K	PARTICIPANT	\N	PRESENT	0
541603	539550	08010L	PARTICIPANT	\N	PRESENT	0
541604	539550	08061X	PARTICIPANT	\N	PRESENT	0
541605	539550	19703U	PARTICIPANT	\N	PRESENT	0
541606	539550	14231L	PARTICIPANT	\N	PRESENT	0
541607	539550	14327T	PARTICIPANT	\N	PRESENT	0
541608	539550	19699S	PARTICIPANT	\N	PRESENT	0
541609	539550	19685L	PARTICIPANT	\N	PRESENT	0
541610	539550	14179A	PARTICIPANT	\N	PRESENT	0
541611	539550	17023S	PARTICIPANT	\N	PRESENT	0
541612	539550	19826F	PARTICIPANT	\N	PRESENT	0
522359	522358	19621T	PARTICIPANT	\N	PRESENT	0
522360	522358	14255U	PARTICIPANT	\N	PRESENT	0
522361	522358	11083R	PARTICIPANT	\N	PRESENT	0
522362	522358	08056B	PARTICIPANT	\N	PRESENT	0
522363	522358	19683J	PARTICIPANT	\N	PRESENT	0
522364	522358	04034C	PARTICIPANT	\N	PRESENT	0
522365	522358	11041F	PARTICIPANT	\N	PRESENT	0
522366	522358	95063L	PARTICIPANT	\N	PRESENT	0
522367	522358	11072N	PARTICIPANT	\N	PRESENT	0
522368	522358	14073Q	PARTICIPANT	\N	PRESENT	0
522369	522358	20056C	PARTICIPANT	\N	PRESENT	0
522375	522374	19621T	PARTICIPANT	\N	PRESENT	0
522376	522374	14255U	PARTICIPANT	\N	PRESENT	0
522377	522374	11083R	PARTICIPANT	\N	PRESENT	0
522378	522374	08056B	PARTICIPANT	\N	PRESENT	0
522380	522374	19683J	PARTICIPANT	\N	PRESENT	0
522381	522374	20056C	PARTICIPANT	\N	PRESENT	0
522382	522374	14073Q	PARTICIPANT	\N	PRESENT	0
522383	522374	11072N	PARTICIPANT	\N	PRESENT	0
522384	522374	95063L	PARTICIPANT	\N	PRESENT	0
522385	522374	11041F	PARTICIPANT	\N	PRESENT	0
522386	522374	04034C	PARTICIPANT	\N	PRESENT	0
522455	521539	19717B	PRESIDENT	0	PRESENT	0
522456	521539	18083K	PARTICIPANT	\N	PRESENT	0
522457	521539	19673G	PARTICIPANT	\N	PRESENT	0
522458	521539	97011G	PARTICIPANT	\N	PRESENT	0
522459	521539	11010L	PARTICIPANT	\N	EXCUSE	0
522460	521539	20034V	PARTICIPANT	\N	PRESENT	0
522461	521539	14059S	PARTICIPANT	\N	PRESENT	0
522462	521539	20148F	PARTICIPANT	\N	PRESENT	0
522464	521539	08034U	PARTICIPANT	\N	EXCUSE	0
524138	524137	01048V	PARTICIPANT	\N	PRESENT	0
524142	524141	04085P	PARTICIPANT	\N	PRESENT	0
524143	524141	05008E	PARTICIPANT	\N	PRESENT	0
524144	524141	04047H	PARTICIPANT	\N	PRESENT	0
524145	524141	04042C	PARTICIPANT	\N	PRESENT	0
524146	524141	11070L	PARTICIPANT	\N	PRESENT	0
524147	524141	19719D	PARTICIPANT	\N	PRESENT	0
524148	524141	10006L	PARTICIPANT	\N	PRESENT	0
524149	524141	19347U	PARTICIPANT	\N	PRESENT	0
524150	524141	14026U	PARTICIPANT	\N	PRESENT	0
524151	524141	11048N	PARTICIPANT	\N	PRESENT	0
524152	524141	14021P	PARTICIPANT	\N	PRESENT	0
524153	524141	99004R	PARTICIPANT	\N	PRESENT	0
524154	524141	19611R	PARTICIPANT	\N	PRESENT	0
524155	524141	12041X	PARTICIPANT	\N	PRESENT	0
524156	524141	01043Q	PARTICIPANT	\N	PRESENT	0
524157	524141	14219Q	PARTICIPANT	\N	PRESENT	0
524158	524141	14251Q	PARTICIPANT	\N	PRESENT	0
524159	524141	11085T	PARTICIPANT	\N	PRESENT	0
524160	524141	01060R	PARTICIPANT	\N	PRESENT	0
524161	524141	08073C	PARTICIPANT	\N	PRESENT	0
524162	524141	11090Q	PARTICIPANT	\N	PRESENT	0
524163	524141	14331P	PARTICIPANT	\N	PRESENT	0
524164	524141	14225N	PARTICIPANT	\N	PRESENT	0
524165	524141	11012A	PARTICIPANT	\N	PRESENT	0
524166	524141	04033B	PARTICIPANT	\N	PRESENT	0
524167	524141	11045K	PARTICIPANT	\N	PRESENT	0
524169	524168	08018U	PARTICIPANT	\N	PRESENT	0
524171	524170	08018U	PARTICIPANT	\N	PRESENT	0
524172	524170	18083K	PARTICIPANT	\N	PRESENT	0
524173	524170	11026G	PARTICIPANT	\N	PRESENT	0
524174	524170	19333N	PARTICIPANT	\N	PRESENT	0
524176	524175	08018U	PARTICIPANT	\N	PRESENT	0
524177	524175	18083K	PARTICIPANT	\N	PRESENT	0
524178	524175	11026G	PARTICIPANT	\N	PRESENT	0
524179	524175	19333N	PARTICIPANT	\N	PRESENT	0
525011	524096	19697Q	PARTICIPANT	\N	PRESENT	1
525057	521656	20038A	PARTICIPANT	\N	PRESENT	0
525058	524071	14053L	PARTICIPANT	\N	PRESENT	0
525014	524096	19798U	PARTICIPANT	\N	PRESENT	0
525059	524071	20074E	PARTICIPANT	\N	PRESENT	0
525016	524096	11097X	PARTICIPANT	0	PRESENT	0
525060	524071	19581D	PARTICIPANT	\N	PRESENT	0
525061	524071	04047H	PRESIDENT	0	PRESENT	0
525062	524071	19673G	PARTICIPANT	\N	PRESENT	0
525020	524096	19553Y	PARTICIPANT	\N	PRESENT	1
525021	524096	11031D	PARTICIPANT	\N	PRESENT	1
525063	524071	19447X	PARTICIPANT	\N	PRESENT	0
525064	524071	14231L	PARTICIPANT	\N	PRESENT	0
525024	524096	14042U	PARTICIPANT	\N	PRESENT	0
525065	524071	11056N	PARTICIPANT	\N	PRESENT	0
525066	524071	14041T	PARTICIPANT	\N	PRESENT	0
525027	524096	19367Y	PARTICIPANT	\N	PRESENT	0
525028	524096	19657G	PARTICIPANT	\N	PRESENT	1
525067	524071	20108W	PARTICIPANT	\N	PRESENT	0
525030	524096	11067R	PARTICIPANT	\N	PRESENT	0
525068	524071	14151M	PARTICIPANT	\N	PRESENT	0
525069	524071	14215L	PARTICIPANT	\N	PRESENT	0
525070	524071	19749K	PARTICIPANT	\N	PRESENT	0
525071	521656	19826F	PARTICIPANT	\N	PRESENT	0
525072	521656	05012A	PARTICIPANT	\N	PRESENT	0
525073	524071	01028R	PARTICIPANT	\N	PRESENT	0
525074	524071	11033F	PARTICIPANT	\N	PRESENT	0
525075	524107	95041E	PARTICIPANT	\N	PRESENT	0
525076	524107	19443T	PARTICIPANT	\N	PRESENT	1
525077	524107	12041X	PARTICIPANT	\N	PRESENT	0
525078	524107	20072C	PARTICIPANT	\N	PRESENT	1
525079	524107	04034C	PARTICIPANT	\N	PRESENT	0
525080	524107	11027H	PARTICIPANT	\N	PRESENT	0
525081	524107	16685X	PARTICIPANT	\N	PRESENT	1
525082	524107	04042C	PRESIDENT	0	PRESENT	0
525083	524107	11066Q	PARTICIPANT	\N	PRESENT	0
525084	524107	12028B	PARTICIPANT	\N	PRESENT	1
525085	524107	11115U	PARTICIPANT	\N	PRESENT	0
525086	524107	19421M	PARTICIPANT	\N	PRESENT	1
525087	524107	14193X	PARTICIPANT	\N	PRESENT	0
525088	524107	19347U	PARTICIPANT	\N	PRESENT	0
525089	524107	97011G	PARTICIPANT	\N	PRESENT	0
525090	524107	08047A	PARTICIPANT	\N	PRESENT	0
525091	524107	14097Y	PARTICIPANT	\N	PRESENT	0
525092	524107	04035D	PARTICIPANT	\N	PRESENT	0
525093	524107	14133K	PARTICIPANT	\N	PRESENT	0
525094	524107	01062T	PARTICIPANT	\N	PRESENT	1
525095	524107	08069G	PARTICIPANT	\N	PRESENT	0
525096	524107	20042V	PARTICIPANT	\N	PRESENT	0
525097	524107	01024M	PARTICIPANT	\N	PRESENT	0
525098	524107	19319Q	PARTICIPANT	\N	PRESENT	1
525099	524107	14105F	PARTICIPANT	\N	PRESENT	1
525100	524107	20064C	PARTICIPANT	\N	PRESENT	1
525101	524107	98018T	PARTICIPANT	\N	PRESENT	1
525102	524107	98022P	PARTICIPANT	\N	PRESENT	0
525103	524107	14267Y	PARTICIPANT	\N	PRESENT	0
525104	524107	14211G	PARTICIPANT	\N	PRESENT	0
525105	524107	14255U	PARTICIPANT	\N	PRESENT	1
525106	524107	19565D	PARTICIPANT	\N	PRESENT	1
525107	524107	11054L	PARTICIPANT	\N	PRESENT	0
525109	524071	14111D	PARTICIPANT	\N	PRESENT	0
525110	524071	11026G	PARTICIPANT	\N	PRESENT	0
525111	524071	10015M	PARTICIPANT	\N	PRESENT	0
525112	524071	20110Q	PARTICIPANT	\N	PRESENT	0
525113	524071	14147R	PARTICIPANT	\N	PRESENT	0
525114	524071	11085T	PARTICIPANT	\N	PRESENT	0
525115	524071	14259Y	PARTICIPANT	\N	PRESENT	0
525116	524071	05008E	PARTICIPANT	\N	PRESENT	0
525118	524071	14089Y	PARTICIPANT	\N	PRESENT	0
525119	524107	20128B	PARTICIPANT	\N	PRESENT	0
525120	524107	11064N	PARTICIPANT	\N	PRESENT	0
525121	524107	01058X	PARTICIPANT	\N	PRESENT	1
525122	524076	19531S	PARTICIPANT	\N	PRESENT	0
525314	524118	20090E	PARTICIPANT	\N	PRESENT	0
525135	524118	86034E	PARTICIPANT	\N	PRESENT	0
525315	524118	19703U	PARTICIPANT	\N	PRESENT	0
525316	524118	20068G	PARTICIPANT	\N	PRESENT	0
525317	524118	19762G	PARTICIPANT	\N	PRESENT	0
525318	524118	19798U	PARTICIPANT	\N	PRESENT	0
525319	524118	14253S	PARTICIPANT	\N	PRESENT	0
525320	524118	11067R	PARTICIPANT	\N	PRESENT	0
525321	524118	98022P	PARTICIPANT	\N	PRESENT	0
525322	524118	19387D	PARTICIPANT	\N	PRESENT	0
525323	524118	14267Y	PARTICIPANT	\N	PRESENT	0
525324	524118	14123H	PARTICIPANT	\N	PRESENT	0
525325	524118	20028X	PARTICIPANT	\N	PRESENT	0
525326	524118	20020P	PARTICIPANT	\N	PRESENT	0
525327	524118	14223L	PARTICIPANT	\N	PRESENT	0
525328	524118	20086J	PARTICIPANT	\N	PRESENT	0
525329	524118	14053L	PARTICIPANT	\N	PRESENT	0
525330	524118	20082E	PARTICIPANT	\N	PRESENT	0
525331	524118	11027H	PARTICIPANT	\N	PRESENT	0
525332	524118	14229S	PARTICIPANT	\N	PRESENT	0
525333	524118	19599P	PARTICIPANT	\N	PRESENT	0
531264	531236	20060X	PARTICIPANT	\N	PRESENT	0
531265	531236	19369B	PARTICIPANT	\N	PRESENT	0
531267	531236	19717B	PARTICIPANT	\N	PRESENT	0
531269	531236	20048C	PARTICIPANT	\N	PRESENT	0
531270	531236	19251M	PARTICIPANT	\N	PRESENT	0
531271	531236	19671E	PARTICIPANT	\N	PRESENT	0
531348	531347	20124W	PARTICIPANT	\N	PRESENT	0
531350	531349	20124W	PARTICIPANT	\N	PRESENT	0
531466	531047	19631V	PARTICIPANT	\N	EXCUSE	0
531468	531047	11010L	PARTICIPANT	\N	EXCUSE	0
531475	531474	19673G	PARTICIPANT	\N	PRESENT	0
531476	531474	19749K	PARTICIPANT	\N	PRESENT	0
531477	531474	19533U	PARTICIPANT	\N	PRESENT	0
531479	531478	19673G	PARTICIPANT	\N	PRESENT	0
531480	531478	19749K	PARTICIPANT	\N	PRESENT	0
531481	531478	19533U	PARTICIPANT	\N	PRESENT	0
531482	531478	14030Q	PARTICIPANT	\N	PRESENT	0
531483	531478	19593H	PARTICIPANT	\N	PRESENT	0
531484	531478	20056C	PARTICIPANT	\N	PRESENT	0
531485	531478	20134Y	PARTICIPANT	\N	PRESENT	0
531487	531486	19673G	PARTICIPANT	\N	PRESENT	0
531488	531486	19749K	PARTICIPANT	\N	PRESENT	0
531489	531486	11033F	PARTICIPANT	\N	PRESENT	0
531490	531486	14030Q	PARTICIPANT	\N	PRESENT	0
531491	531486	19593H	PARTICIPANT	\N	PRESENT	0
531492	531486	20056C	PARTICIPANT	\N	PRESENT	0
531493	531486	20134Y	PARTICIPANT	\N	PRESENT	0
531494	531486	19611R	PARTICIPANT	\N	PRESENT	0
531496	531495	19673G	PARTICIPANT	\N	PRESENT	0
531497	531495	19749K	PARTICIPANT	\N	PRESENT	0
531498	531495	17737W	PARTICIPANT	\N	PRESENT	0
531499	531495	19649G	PARTICIPANT	\N	PRESENT	0
531500	531495	19533U	PARTICIPANT	\N	PRESENT	0
531501	531486	19533U	PARTICIPANT	\N	PRESENT	0
531502	497174	19565D	PARTICIPANT	\N	PRESENT	0
531503	500284	19565D	PARTICIPANT	\N	PRESENT	0
531504	501820	19565D	PARTICIPANT	\N	PRESENT	0
531505	502343	19565D	PARTICIPANT	\N	PRESENT	0
531506	524115	19565D	PARTICIPANT	\N	PRESENT	0
531555	531554	19691J	PARTICIPANT	\N	PRESENT	0
531556	531554	19703U	PARTICIPANT	\N	PRESENT	0
531557	531554	14107H	PARTICIPANT	\N	PRESENT	0
531558	530832	20026V	PARTICIPANT	\N	PRESENT	0
531559	530832	20098N	PARTICIPANT	\N	PRESENT	0
531560	531363	08073C	PARTICIPANT	\N	PRESENT	0
531561	530832	19766L	PARTICIPANT	\N	PRESENT	0
531562	530832	19593H	PARTICIPANT	\N	PRESENT	0
531563	530832	20132W	PARTICIPANT	\N	PRESENT	0
531564	530832	19699S	PARTICIPANT	\N	PRESENT	0
531565	530832	20134Y	PARTICIPANT	\N	PRESENT	1
531566	530832	14073Q	PARTICIPANT	\N	PRESENT	0
531567	530832	19651A	PARTICIPANT	\N	PRESENT	1
531568	530832	20152B	PARTICIPANT	\N	PRESENT	0
531569	530832	14229S	PARTICIPANT	\N	PRESENT	0
531570	530832	14030Q	PARTICIPANT	\N	PRESENT	0
531571	530832	20180F	PARTICIPANT	\N	PRESENT	0
531572	530832	20112S	PARTICIPANT	\N	PRESENT	0
531573	530832	08012N	PARTICIPANT	\N	PRESENT	0
531574	530832	11043H	PARTICIPANT	\N	PRESENT	0
531575	530832	19621T	PARTICIPANT	\N	PRESENT	0
531576	530832	17589D	PARTICIPANT	\N	PRESENT	0
531577	530806	11067R	PARTICIPANT	\N	PRESENT	0
531578	530806	20078J	PARTICIPANT	\N	PRESENT	0
531579	530806	20048C	PARTICIPANT	\N	PRESENT	0
531580	530806	19543W	PARTICIPANT	\N	PRESENT	0
531581	530806	19581D	PARTICIPANT	\N	PRESENT	0
531582	530806	19866P	PARTICIPANT	\N	PRESENT	0
531583	530806	20052X	PARTICIPANT	\N	PRESENT	0
531584	530806	17779H	PARTICIPANT	\N	PRESENT	0
531585	530806	20056C	PARTICIPANT	\N	PRESENT	0
531586	530806	20060X	PARTICIPANT	\N	PRESENT	0
531587	530806	20062A	PARTICIPANT	\N	PRESENT	0
531588	530806	14179A	PARTICIPANT	\N	PRESENT	1
531589	530806	20084G	PRESIDENT	0	PRESENT	0
531590	530806	19689Q	PARTICIPANT	\N	EXCUSE	0
531591	530806	14053L	PARTICIPANT	\N	PRESENT	0
531592	530806	20058E	PARTICIPANT	\N	PRESENT	0
531593	530806	14123H	PARTICIPANT	\N	PRESENT	0
531594	531363	20132W	PARTICIPANT	\N	PRESENT	0
531595	531363	20054A	PARTICIPANT	\N	PRESENT	0
531596	531363	14073Q	PARTICIPANT	\N	PRESENT	0
531597	531363	19593H	PARTICIPANT	\N	PRESENT	0
531598	531363	20180F	PARTICIPANT	\N	PRESENT	0
531599	531363	20098N	PARTICIPANT	\N	PRESENT	0
531600	531363	14030Q	PARTICIPANT	\N	PRESENT	0
531601	531363	19621T	PARTICIPANT	\N	PRESENT	0
531602	531363	19507S	PARTICIPANT	\N	PRESENT	0
531603	531363	20026V	PARTICIPANT	\N	PRESENT	0
531604	531363	14259Y	PARTICIPANT	\N	PRESENT	0
531605	531363	14105F	PARTICIPANT	\N	PRESENT	0
531606	531363	19349W	PARTICIPANT	\N	PRESENT	0
531607	531363	97011G	PARTICIPANT	\N	PRESENT	0
531608	531363	08012N	PARTICIPANT	\N	PRESENT	0
531609	531363	11043H	PARTICIPANT	\N	PRESENT	0
531610	531363	19611R	PARTICIPANT	\N	PRESENT	0
531611	531146	19711U	PARTICIPANT	\N	PRESENT	0
531612	531146	08034U	PARTICIPANT	\N	PRESENT	0
531613	531146	20080C	PARTICIPANT	\N	PRESENT	0
531614	531146	99004R	PARTICIPANT	\N	PRESENT	0
531615	531146	20116W	PARTICIPANT	\N	PRESENT	0
531616	531146	19762G	PARTICIPANT	\N	PRESENT	0
531617	531363	19782L	PARTICIPANT	\N	PRESENT	0
531618	531363	20134Y	PARTICIPANT	\N	PRESENT	0
531619	531363	19758L	PARTICIPANT	\N	PRESENT	0
531620	531363	11104D	PARTICIPANT	\N	PRESENT	0
531621	531363	20112S	PARTICIPANT	\N	PRESENT	0
531622	531363	19565D	PARTICIPANT	\N	PRESENT	0
531623	531363	19651A	PARTICIPANT	\N	PRESENT	0
531624	531363	20090E	PARTICIPANT	\N	PRESENT	0
531625	531363	18083K	PARTICIPANT	\N	PRESENT	0
531626	531363	20056C	PARTICIPANT	\N	PRESENT	0
531627	531363	11067R	PARTICIPANT	\N	PRESENT	0
531628	531363	20058E	PARTICIPANT	\N	PRESENT	0
531629	531363	11103C	PARTICIPANT	\N	PRESENT	0
531630	531363	20074E	PARTICIPANT	\N	PRESENT	0
531631	531146	19479G	PARTICIPANT	\N	PRESENT	0
531632	531146	19647E	PARTICIPANT	\N	PRESENT	0
531633	531146	11048N	PARTICIPANT	\N	PRESENT	0
531634	531146	14189C	PARTICIPANT	\N	PRESENT	0
531635	531146	19545Y	PARTICIPANT	\N	PRESENT	0
531636	531146	19687N	PARTICIPANT	\N	PRESENT	0
531637	531146	20044X	PARTICIPANT	\N	PRESENT	0
531638	531146	14225N	PARTICIPANT	\N	PRESENT	0
531639	531146	04086Q	PARTICIPANT	\N	PRESENT	0
531640	531146	11040E	PARTICIPANT	\N	PRESENT	0
531641	531146	14083S	PARTICIPANT	\N	PRESENT	0
531642	531146	20070A	PARTICIPANT	\N	PRESENT	0
531643	531146	19335Q	PARTICIPANT	\N	PRESENT	0
531644	531363	14069U	PARTICIPANT	\N	PRESENT	0
531645	531146	01057W	PARTICIPANT	\N	PRESENT	0
531646	531146	20022R	PARTICIPANT	\N	PRESENT	0
531647	531363	17589D	PARTICIPANT	\N	PRESENT	0
531648	531363	20042V	PARTICIPANT	\N	PRESENT	0
531649	531363	20084G	PARTICIPANT	\N	PRESENT	0
531650	531363	19441R	PARTICIPANT	\N	PRESENT	0
531651	531363	20138D	PARTICIPANT	\N	PRESENT	0
531652	531363	20124W	PARTICIPANT	\N	PRESENT	0
531653	531363	19533U	PARTICIPANT	\N	PRESENT	0
531654	531363	20062A	PARTICIPANT	\N	PRESENT	0
531655	531363	20048C	PARTICIPANT	\N	PRESENT	0
531656	531363	14147R	PARTICIPANT	\N	PRESENT	0
531657	531363	20152B	PARTICIPANT	\N	PRESENT	0
531660	531363	08061X	PARTICIPANT	\N	PRESENT	0
531661	531363	08015R	PARTICIPANT	\N	PRESENT	0
531662	531363	19699S	PARTICIPANT	\N	PRESENT	0
531664	531663	01028R	PARTICIPANT	\N	PRESENT	0
531665	531363	20036X	PARTICIPANT	\N	PRESENT	0
531666	531663	11031D	PARTICIPANT	\N	PRESENT	0
531667	531663	19647E	PARTICIPANT	\N	PRESENT	0
531668	531663	04035D	PARTICIPANT	\N	PRESENT	0
531669	531663	01057W	PARTICIPANT	\N	PRESENT	0
531670	531663	14073Q	PARTICIPANT	\N	PRESENT	0
531671	531663	04070G	PARTICIPANT	\N	PRESENT	0
531678	531363	14089Y	PARTICIPANT	\N	PRESENT	0
531673	531663	19687N	PARTICIPANT	\N	PRESENT	0
531674	531663	04034C	PARTICIPANT	\N	PRESENT	0
531675	531363	20116W	PARTICIPANT	\N	PRESENT	0
531676	531363	19333N	PARTICIPANT	\N	PRESENT	0
531677	531363	20052X	PARTICIPANT	\N	PRESENT	0
531685	531663	11026G	PARTICIPANT	\N	PRESENT	0
531689	531363	01024M	PARTICIPANT	\N	PRESENT	0
514951	514950	04070G	PARTICIPANT	\N	PRESENT	1
514952	514950	08017T	PARTICIPANT	\N	PRESENT	1
514953	514950	19621T	PARTICIPANT	\N	PRESENT	1
514954	514950	19593H	PARTICIPANT	\N	PRESENT	1
514955	514950	14109K	PARTICIPANT	\N	PRESENT	1
518364	516991	14097Y	PARTICIPANT	\N	PRESENT	0
518748	518747	04008A	PARTICIPANT	\N	PRESENT	0
518749	518747	14179A	PARTICIPANT	\N	PRESENT	0
518751	518750	14179A	PARTICIPANT	\N	PRESENT	0
518753	518752	19673G	PARTICIPANT	\N	PRESENT	0
518754	518752	14179A	PARTICIPANT	\N	PRESENT	0
518756	518755	19673G	PARTICIPANT	\N	PRESENT	0
518908	518907	14249W	PARTICIPANT	\N	PRESENT	0
518909	518907	14073Q	PARTICIPANT	\N	PRESENT	0
518910	518907	14069U	PARTICIPANT	\N	PRESENT	0
518911	518907	11083R	PARTICIPANT	\N	PRESENT	0
518912	518907	20174H	PARTICIPANT	\N	PRESENT	0
518913	518907	16685X	PARTICIPANT	\N	PRESENT	0
518914	518907	19647E	PARTICIPANT	\N	PRESENT	0
518917	517072	18083K	PARTICIPANT	\N	PRESENT	0
518918	517072	19667J	PARTICIPANT	\N	PRESENT	0
518919	517072	19599P	PARTICIPANT	\N	PRESENT	0
518920	517072	14033T	PARTICIPANT	\N	PRESENT	0
518921	517072	19685L	PARTICIPANT	\N	PRESENT	0
518922	517072	08015R	PARTICIPANT	\N	PRESENT	0
518923	517072	19533U	PARTICIPANT	\N	PRESENT	0
518924	517072	11090Q	PARTICIPANT	\N	PRESENT	0
518988	518987	04059M	PARTICIPANT	\N	PRESENT	0
518989	518987	20024T	PARTICIPANT	\N	PRESENT	0
518990	518987	17367Q	PARTICIPANT	\N	PRESENT	0
518991	518987	20088L	PARTICIPANT	\N	PRESENT	0
518992	518987	20114U	PARTICIPANT	\N	PRESENT	0
518993	518987	19621T	PARTICIPANT	\N	PRESENT	0
518994	518987	19758L	PARTICIPANT	\N	PRESENT	0
518995	518987	04042C	PARTICIPANT	\N	PRESENT	0
518996	518987	11053K	PARTICIPANT	\N	PRESENT	0
518997	518987	11080N	PARTICIPANT	\N	PRESENT	0
518998	518987	19721W	PARTICIPANT	\N	PRESENT	0
518999	518987	11115U	PARTICIPANT	\N	PRESENT	0
519000	518987	19693L	PARTICIPANT	\N	PRESENT	0
519001	518987	14327T	PARTICIPANT	\N	PRESENT	0
519002	518987	19663E	PARTICIPANT	\N	PRESENT	0
519003	518987	07033P	PARTICIPANT	\N	PRESENT	0
519004	518987	14187A	PARTICIPANT	\N	PRESENT	0
519005	518987	14281W	PARTICIPANT	\N	PRESENT	0
519006	518987	19347U	PARTICIPANT	\N	PRESENT	0
519007	518987	19565D	PARTICIPANT	\N	PRESENT	0
519008	518987	98022P	PARTICIPANT	\N	PRESENT	0
519009	518987	99004R	PARTICIPANT	\N	PRESENT	0
519010	518987	14073Q	PARTICIPANT	\N	PRESENT	0
519011	518987	08010L	PARTICIPANT	\N	PRESENT	0
519012	518987	19699S	PARTICIPANT	\N	PRESENT	0
519013	518987	20018V	PARTICIPANT	\N	PRESENT	0
519014	518987	04070G	PARTICIPANT	\N	PRESENT	0
519015	518987	19503N	PARTICIPANT	\N	PRESENT	0
519016	518987	19443T	PARTICIPANT	\N	PRESENT	0
519017	518987	11041F	PARTICIPANT	\N	PRESENT	0
519018	518987	20046A	PARTICIPANT	\N	PRESENT	0
519020	519019	19667J	PARTICIPANT	\N	PRESENT	0
519021	519019	20152B	PARTICIPANT	\N	PRESENT	0
519022	519019	19701S	PARTICIPANT	\N	PRESENT	0
519023	519019	19699S	PARTICIPANT	\N	PRESENT	0
519024	519019	11026G	PARTICIPANT	\N	PRESENT	0
519025	519019	19671E	PARTICIPANT	\N	PRESENT	0
519026	519019	95063L	PARTICIPANT	\N	PRESENT	0
519027	519019	20064C	PARTICIPANT	\N	PRESENT	0
519029	519028	20112S	PARTICIPANT	\N	PRESENT	0
521577	521436	20136B	PARTICIPANT	\N	PRESENT	0
519031	519028	19782L	PARTICIPANT	\N	PRESENT	0
519032	519028	10006L	PARTICIPANT	\N	PRESENT	0
519033	519028	14041T	PARTICIPANT	\N	PRESENT	0
519034	519028	14217N	PARTICIPANT	\N	PRESENT	0
519035	519028	14073Q	PARTICIPANT	\N	PRESENT	0
519036	519028	20126Y	PARTICIPANT	\N	PRESENT	0
519037	519028	19723Y	PARTICIPANT	\N	PRESENT	0
519038	519028	12041X	PARTICIPANT	\N	PRESENT	0
519039	519028	18193Q	PARTICIPANT	\N	PRESENT	0
519048	519047	19729F	PARTICIPANT	\N	PRESENT	1
519041	519028	20096L	PARTICIPANT	\N	PRESENT	0
519042	519028	19745F	PARTICIPANT	\N	PRESENT	0
521576	521436	19367Y	PARTICIPANT	\N	PRESENT	0
519044	519028	01058X	PARTICIPANT	\N	PRESENT	0
521903	521902	04034C	PARTICIPANT	\N	PRESENT	0
522102	522101	04008A	PARTICIPANT	\N	PRESENT	0
522104	522101	14179A	PARTICIPANT	\N	PRESENT	0
522105	522101	14151M	PARTICIPANT	\N	PRESENT	0
522107	522106	04008A	PARTICIPANT	\N	PRESENT	0
522108	522106	14179A	PARTICIPANT	\N	PRESENT	0
522109	522106	14151M	PARTICIPANT	\N	PRESENT	0
522135	522134	04092N	PARTICIPANT	\N	PRESENT	0
522136	522134	19697Q	PARTICIPANT	\N	PRESENT	1
522137	522134	11031D	PARTICIPANT	\N	PRESENT	1
522138	522134	14071N	PARTICIPANT	\N	PRESENT	1
524547	524546	20112S	PARTICIPANT	\N	PRESENT	0
524548	524546	19647E	PARTICIPANT	\N	PRESENT	0
524549	524546	19591F	PARTICIPANT	\N	PRESENT	0
524765	524764	10015M	PARTICIPANT	\N	PRESENT	0
524766	524764	20024T	PARTICIPANT	\N	PRESENT	0
524767	524764	20042V	PARTICIPANT	\N	PRESENT	0
524768	524764	18083K	PARTICIPANT	\N	PRESENT	0
524769	524764	14267Y	PARTICIPANT	\N	PRESENT	0
524770	524764	20070A	PARTICIPANT	\N	PRESENT	0
524771	524764	14071N	PARTICIPANT	\N	PRESENT	0
524772	524764	19703U	PARTICIPANT	\N	PRESENT	0
524773	524764	20084G	PARTICIPANT	\N	PRESENT	0
527727	526540	20132W	PARTICIPANT	\N	PRESENT	0
527728	526540	20072C	PARTICIPANT	\N	PRESENT	0
527729	526540	11041F	PARTICIPANT	\N	PRESENT	0
527730	526540	19749K	PARTICIPANT	\N	PRESENT	0
527731	526540	98022P	PARTICIPANT	\N	PRESENT	0
527732	526540	20078J	PARTICIPANT	\N	PRESENT	0
527733	526540	20042V	PARTICIPANT	\N	PRESENT	0
527734	526540	20102Q	PARTICIPANT	\N	PRESENT	0
527735	526540	20056C	PARTICIPANT	\N	PRESENT	0
527736	526540	20180F	PARTICIPANT	\N	PRESENT	0
527737	526540	20152B	PARTICIPANT	\N	PRESENT	0
527738	526540	20138D	PARTICIPANT	\N	PRESENT	0
527739	526540	20090E	PARTICIPANT	\N	PRESENT	0
527740	526540	19413M	PARTICIPANT	\N	PRESENT	0
527741	526540	19531S	PARTICIPANT	\N	PRESENT	0
527742	526540	20130U	PARTICIPANT	\N	PRESENT	0
527743	526540	20018V	PARTICIPANT	\N	PRESENT	0
527744	526540	20074E	PARTICIPANT	\N	PRESENT	0
527745	526540	14327T	PARTICIPANT	\N	PRESENT	0
527746	526540	20114U	PARTICIPANT	\N	PRESENT	0
527747	526540	14221J	PARTICIPANT	\N	PRESENT	0
527748	526540	19565D	PARTICIPANT	\N	PRESENT	0
527749	526540	20134Y	PARTICIPANT	\N	PRESENT	0
527750	526540	08009T	PARTICIPANT	\N	PRESENT	0
527751	526540	19511N	PARTICIPANT	\N	PRESENT	0
527752	526540	10015M	PARTICIPANT	\N	PRESENT	0
527753	526540	19563B	PARTICIPANT	\N	PRESENT	0
527754	526540	14041T	PARTICIPANT	\N	PRESENT	0
527755	526540	19333N	PARTICIPANT	\N	PRESENT	0
527756	526540	99004R	PARTICIPANT	\N	PRESENT	0
527757	526540	20172F	PARTICIPANT	\N	PRESENT	0
527758	526540	97011G	PARTICIPANT	\N	PRESENT	0
527759	526540	14123H	PARTICIPANT	\N	PRESENT	0
527760	526540	01043Q	PARTICIPANT	\N	PRESENT	0
527761	526540	14229S	PARTICIPANT	\N	PRESENT	0
527762	526540	14225N	PARTICIPANT	\N	PRESENT	0
527763	526540	04045F	PARTICIPANT	\N	PRESENT	0
527765	526540	20082E	PARTICIPANT	\N	PRESENT	0
527766	526540	19369B	PARTICIPANT	\N	PRESENT	0
527767	526540	19667J	PARTICIPANT	\N	PRESENT	0
527768	526540	19399H	PARTICIPANT	\N	PRESENT	0
527769	526540	14195A	PARTICIPANT	\N	PRESENT	0
527770	526540	20142Y	PARTICIPANT	\N	PRESENT	0
527771	526540	20106U	PARTICIPANT	\N	PRESENT	0
527772	526540	14357A	PARTICIPANT	\N	PRESENT	0
527773	526540	19367Y	PARTICIPANT	\N	PRESENT	0
527774	526540	08056B	PARTICIPANT	\N	PRESENT	0
527775	526540	14193X	PARTICIPANT	\N	PRESENT	0
527776	526540	14069U	PARTICIPANT	\N	PRESENT	0
527777	526540	11066Q	PARTICIPANT	\N	PRESENT	0
527778	526540	14231L	PARTICIPANT	\N	PRESENT	0
527779	526540	19611R	PARTICIPANT	\N	PRESENT	0
527780	526540	19575F	PARTICIPANT	\N	PRESENT	0
527781	526540	20104S	PARTICIPANT	\N	PRESENT	0
527782	526540	04092N	PARTICIPANT	\N	PRESENT	0
536330	536312	19631V	PARTICIPANT	\N	PRESENT	0
536331	536312	19575F	PARTICIPANT	\N	PRESENT	0
536332	536312	20088L	PARTICIPANT	\N	PRESENT	0
536333	536312	19782L	PARTICIPANT	\N	PRESENT	0
536334	536312	20114U	PARTICIPANT	\N	PRESENT	0
536337	536312	20090E	PARTICIPANT	\N	PRESENT	0
536339	536312	01024M	PARTICIPANT	\N	PRESENT	0
536342	536312	14213J	PARTICIPANT	\N	PRESENT	0
536343	536312	14097Y	PARTICIPANT	\N	PRESENT	0
536345	536312	20028X	PARTICIPANT	\N	PRESENT	0
536347	536312	20018V	PARTICIPANT	\N	PRESENT	0
536350	536312	19369B	PARTICIPANT	\N	PRESENT	0
536352	536312	14109K	PARTICIPANT	\N	PRESENT	0
536353	536312	14169X	PARTICIPANT	\N	PRESENT	0
536355	536312	19503N	PARTICIPANT	\N	PRESENT	0
536471	536469	19441R	PARTICIPANT	\N	PRESENT	0
536359	536312	20062A	PARTICIPANT	\N	PRESENT	0
536470	536469	14038Y	PARTICIPANT	\N	PRESENT	0
536472	536469	20060X	PARTICIPANT	\N	PRESENT	0
536473	536469	19631V	PARTICIPANT	\N	PRESENT	0
536474	536469	20018V	PARTICIPANT	\N	PRESENT	0
536477	536469	14207L	PARTICIPANT	\N	PRESENT	0
536478	536469	20174H	PARTICIPANT	\N	PRESENT	0
536479	536469	08015R	PARTICIPANT	\N	PRESENT	0
536484	536483	14038Y	PARTICIPANT	\N	PRESENT	0
536485	536483	19441R	PARTICIPANT	\N	PRESENT	0
536486	536483	20060X	PARTICIPANT	\N	PRESENT	0
536497	536496	14038Y	PARTICIPANT	\N	PRESENT	0
536498	536496	19441R	PARTICIPANT	\N	PRESENT	0
536499	536496	20060X	PARTICIPANT	\N	PRESENT	0
536549	536548	20038A	PARTICIPANT	\N	PRESENT	0
536550	536548	14169X	PARTICIPANT	\N	PRESENT	0
536551	536548	19713W	PARTICIPANT	\N	PRESENT	0
536552	536548	11065P	PARTICIPANT	\N	PRESENT	0
536553	536548	14031R	PARTICIPANT	\N	PRESENT	0
536554	536548	19739H	PARTICIPANT	\N	PRESENT	0
536555	536548	20046A	PARTICIPANT	\N	PRESENT	0
536556	536548	20096L	PARTICIPANT	\N	PRESENT	0
536557	536548	18083K	PARTICIPANT	\N	PRESENT	0
536592	531687	05008E	PARTICIPANT	\N	EXCUSE	0
536593	531687	19659J	PARTICIPANT	\N	EXCUSE	0
536594	531688	05008E	PARTICIPANT	\N	EXCUSE	0
536595	531688	19659J	PARTICIPANT	\N	EXCUSE	0
536596	531688	20148F	PRESIDENT	0	PRESENT	0
536597	531687	20148F	PRESIDENT	0	PRESENT	0
536600	534194	12016W	PARTICIPANT	\N	PRESENT	1
536601	534194	08018U	PARTICIPANT	\N	EXCUSE	0
536644	534354	20022R	PARTICIPANT	\N	PRESENT	1
536645	534354	11040E	PARTICIPANT	\N	PRESENT	1
536646	534354	14083S	PARTICIPANT	\N	PRESENT	1
536647	534354	11074Q	PARTICIPANT	\N	PRESENT	1
536648	534354	99004R	PARTICIPANT	\N	PRESENT	1
536649	534354	19671E	PARTICIPANT	\N	PRESENT	1
536650	534354	12016W	PARTICIPANT	\N	PRESENT	1
536651	534354	04070G	PARTICIPANT	\N	PRESENT	1
536652	534354	19251M	PARTICIPANT	\N	PRESENT	1
536919	536918	14069U	PARTICIPANT	\N	PRESENT	0
536920	536918	11072N	PARTICIPANT	\N	PRESENT	0
536922	536921	14069U	PARTICIPANT	\N	PRESENT	0
536923	536921	11072N	PARTICIPANT	\N	PRESENT	0
536925	536924	11072N	PARTICIPANT	\N	PRESENT	0
536926	536924	14069U	PARTICIPANT	\N	PRESENT	0
536928	536927	11072N	PARTICIPANT	\N	PRESENT	0
536929	536927	14069U	PARTICIPANT	\N	PRESENT	0
536931	536930	11072N	PARTICIPANT	\N	PRESENT	0
536932	536930	14069U	PARTICIPANT	\N	PRESENT	0
537867	530868	20112S	PARTICIPANT	\N	EXCUSE	0
537868	530868	20138D	PARTICIPANT	\N	PRESENT	1
537869	530868	17589D	PARTICIPANT	\N	PRESENT	1
537870	530868	20134Y	PARTICIPANT	\N	PRESENT	1
537871	530868	20132W	PARTICIPANT	\N	PRESENT	1
537872	530868	14123H	PARTICIPANT	\N	PRESENT	1
537873	530868	20056C	PARTICIPANT	\N	PRESENT	1
537874	530868	14073Q	PARTICIPANT	\N	PRESENT	1
537875	530868	20048C	PARTICIPANT	\N	PRESENT	1
537876	530868	08017T	PARTICIPANT	\N	PRESENT	1
537877	530868	11104D	PARTICIPANT	\N	PRESENT	1
537878	530868	08061X	PARTICIPANT	\N	PRESENT	0
537879	530868	11043H	PARTICIPANT	\N	PRESENT	1
537880	530868	20098N	PARTICIPANT	\N	PRESENT	1
537881	530868	19527W	PARTICIPANT	\N	PRESENT	1
537882	530868	20026V	PARTICIPANT	\N	PRESENT	1
537883	530868	20124W	PARTICIPANT	\N	PRESENT	0
537911	530868	19749K	PARTICIPANT	\N	PRESENT	1
538428	537178	14030Q	PARTICIPANT	\N	PRESENT	0
538429	537178	19383Y	PRESIDENT	0	PRESENT	0
538430	537178	19467C	PARTICIPANT	\N	PRESENT	0
538431	537178	19719D	PARTICIPANT	\N	PRESENT	0
538432	537178	14026U	PARTICIPANT	\N	PRESENT	0
538433	537178	11099A	PARTICIPANT	\N	PRESENT	0
538434	537178	19441R	PARTICIPANT	\N	PRESENT	0
538435	537178	19637C	PARTICIPANT	\N	PRESENT	1
538436	537178	20028X	PARTICIPANT	\N	PRESENT	0
538437	537178	14109K	PARTICIPANT	\N	PRESENT	1
538438	537178	19762G	PARTICIPANT	\N	PRESENT	0
538439	537178	20026V	PARTICIPANT	\N	PRESENT	0
538454	537178	19798U	PARTICIPANT	\N	PRESENT	0
538617	538612	08060W	PARTICIPANT	\N	PRESENT	0
538618	538612	05012A	PARTICIPANT	\N	PRESENT	0
538619	538612	18083K	PARTICIPANT	\N	PRESENT	0
538620	538612	19525U	PARTICIPANT	\N	PRESENT	0
538621	538612	17229F	PARTICIPANT	\N	PRESENT	0
538622	538612	20038A	PARTICIPANT	\N	PRESENT	0
538623	538612	20100N	PARTICIPANT	\N	PRESENT	0
538624	538612	19551W	PARTICIPANT	\N	PRESENT	0
538625	538612	20136B	PARTICIPANT	\N	PRESENT	0
538626	538613	08060W	PARTICIPANT	\N	PRESENT	0
538627	538613	05012A	PARTICIPANT	\N	PRESENT	0
538628	538613	19525U	PARTICIPANT	\N	PRESENT	0
538629	538613	17229F	PARTICIPANT	\N	PRESENT	0
538630	538613	20038A	PARTICIPANT	\N	PRESENT	0
538631	538613	20100N	PARTICIPANT	\N	PRESENT	0
538632	538613	19387D	PARTICIPANT	\N	PRESENT	0
538633	538613	19551W	PARTICIPANT	\N	PRESENT	0
538634	538613	20136B	PARTICIPANT	\N	PRESENT	0
538635	538614	08060W	PARTICIPANT	\N	PRESENT	0
538636	538614	05012A	PARTICIPANT	\N	PRESENT	0
538637	538614	17229F	PARTICIPANT	\N	PRESENT	0
538638	538614	19551W	PARTICIPANT	\N	PRESENT	0
538639	538614	20136B	PARTICIPANT	\N	PRESENT	0
538642	538641	14033T	PARTICIPANT	\N	PRESENT	0
538643	538641	19413M	PARTICIPANT	\N	PRESENT	0
538644	538641	20144B	PARTICIPANT	\N	PRESENT	0
538645	538641	14357A	PARTICIPANT	\N	PRESENT	0
538647	538646	20144B	PARTICIPANT	\N	PRESENT	0
538648	538646	14257W	PARTICIPANT	\N	PRESENT	0
538650	538649	20144B	PARTICIPANT	\N	PRESENT	0
538652	538649	14257W	PARTICIPANT	\N	PRESENT	0
538653	538649	14033T	PARTICIPANT	\N	PRESENT	0
538654	538646	14033T	PARTICIPANT	\N	PRESENT	0
538656	538655	14033T	PARTICIPANT	\N	PRESENT	0
538657	538655	20144B	PARTICIPANT	\N	PRESENT	0
538658	538655	14257W	PARTICIPANT	\N	PRESENT	0
538660	538659	14033T	PARTICIPANT	\N	PRESENT	0
538854	531687	12016W	PARTICIPANT	\N	PRESENT	0
538914	531687	97011G	PARTICIPANT	\N	PRESENT	0
513284	513283	14215L	PARTICIPANT	\N	PRESENT	0
514205	514194	11026G	PARTICIPANT	\N	PRESENT	0
514210	514194	10015M	PARTICIPANT	\N	PRESENT	0
514300	514298	10015M	PARTICIPANT	\N	PRESENT	0
514301	514298	11026G	PARTICIPANT	\N	PRESENT	0
518448	518447	19954N	PARTICIPANT	\N	PRESENT	0
518449	518447	19575F	PARTICIPANT	\N	PRESENT	0
518450	518447	14105F	PARTICIPANT	\N	PRESENT	0
518451	518447	20114U	PARTICIPANT	\N	PRESENT	0
518452	518447	19782L	PARTICIPANT	\N	PRESENT	0
518453	518447	20074E	PARTICIPANT	\N	PRESENT	0
518454	518447	20100N	PARTICIPANT	\N	PRESENT	0
518455	518447	20132W	PARTICIPANT	\N	PRESENT	0
518456	518447	08018U	PARTICIPANT	\N	PRESENT	0
518457	518447	19820Y	PARTICIPANT	\N	PRESENT	0
518458	518447	19565D	PARTICIPANT	\N	PRESENT	0
518459	518447	20068G	PARTICIPANT	\N	PRESENT	0
518460	518447	20128B	PARTICIPANT	\N	PRESENT	0
518461	518447	14073Q	PARTICIPANT	\N	PRESENT	0
518462	518447	20126Y	PARTICIPANT	\N	PRESENT	0
518463	518447	19709B	PARTICIPANT	\N	PRESENT	0
518464	518447	08010L	PARTICIPANT	\N	PRESENT	0
518469	518447	19749K	PARTICIPANT	\N	PRESENT	0
518466	518447	04057K	PARTICIPANT	\N	PRESENT	0
518467	518447	20096L	PARTICIPANT	\N	PRESENT	0
518468	518447	04045F	PARTICIPANT	\N	PRESENT	0
518470	518447	20098N	PARTICIPANT	\N	PRESENT	0
518471	518447	19503N	PARTICIPANT	\N	PRESENT	0
518472	518447	20038A	PARTICIPANT	\N	PRESENT	0
520426	520425	19741B	PARTICIPANT	\N	PRESENT	0
520682	520681	14121F	PARTICIPANT	\N	PRESENT	0
522148	522147	19553Y	PARTICIPANT	\N	PRESENT	1
522149	522147	14213J	PARTICIPANT	\N	PRESENT	0
522150	522147	14071N	PARTICIPANT	\N	PRESENT	0
522151	522147	19717B	PARTICIPANT	\N	PRESENT	1
522152	522147	14217N	PARTICIPANT	\N	PRESENT	0
522153	522147	10006L	PRESIDENT	0	PRESENT	0
522154	522147	17779H	PARTICIPANT	\N	PRESENT	0
522159	522147	19697Q	PARTICIPANT	\N	PRESENT	0
522160	522147	11067R	PARTICIPANT	\N	PRESENT	0
522161	522147	19798U	PARTICIPANT	\N	PRESENT	0
522162	522147	19569H	PARTICIPANT	\N	PRESENT	0
522163	522147	11097X	PARTICIPANT	\N	PRESENT	0
522164	522147	14223L	PARTICIPANT	\N	PRESENT	1
522165	522147	18193Q	PARTICIPANT	\N	PRESENT	1
522166	522147	14026U	PARTICIPANT	\N	PRESENT	0
522167	522147	19703U	PARTICIPANT	\N	PRESENT	0
522168	522147	19679N	PARTICIPANT	\N	PRESENT	1
522169	522147	14195A	PARTICIPANT	\N	PRESENT	0
522170	522147	19367Y	PARTICIPANT	\N	PRESENT	0
522171	522147	19591F	PARTICIPANT	\N	PRESENT	1
522172	522147	20130U	PARTICIPANT	\N	PRESENT	0
522173	522147	11045K	PARTICIPANT	\N	PRESENT	0
522174	522147	08045X	PARTICIPANT	\N	PRESENT	1
522175	522147	20040T	PARTICIPANT	\N	PRESENT	0
522176	522147	17965H	PARTICIPANT	\N	PRESENT	0
522177	522147	19301E	PARTICIPANT	\N	PRESENT	1
522178	522147	20148F	PARTICIPANT	\N	PRESENT	0
522179	522147	20172F	PARTICIPANT	\N	PRESENT	0
522180	522147	19723Y	PARTICIPANT	\N	PRESENT	0
522181	522147	20066E	PARTICIPANT	\N	PRESENT	0
522182	522147	19760E	PARTICIPANT	\N	PRESENT	0
522183	522147	11031D	PARTICIPANT	\N	PRESENT	0
522184	522147	19691J	PARTICIPANT	\N	PRESENT	0
522187	521420	19333N	PARTICIPANT	\N	PRESENT	0
522188	521420	19701S	PARTICIPANT	\N	PRESENT	1
522189	521420	20076G	PARTICIPANT	\N	PRESENT	0
522190	521420	19549D	PARTICIPANT	\N	PRESENT	0
522191	521420	19387D	PARTICIPANT	\N	PRESENT	0
522192	521420	14219Q	PRESIDENT	0	PRESENT	0
522193	521420	19820Y	PARTICIPANT	\N	PRESENT	0
522194	521420	19826F	PARTICIPANT	\N	PRESENT	0
522195	521420	14221J	PARTICIPANT	\N	PRESENT	0
522196	521420	19599P	PARTICIPANT	\N	PRESENT	0
522197	521420	20102Q	PARTICIPANT	\N	PRESENT	0
522198	521420	19637C	PARTICIPANT	\N	PRESENT	1
522199	521420	20096L	PARTICIPANT	\N	PRESENT	0
522200	521420	18083K	PARTICIPANT	\N	PRESENT	0
522201	521420	14237S	PARTICIPANT	\N	PRESENT	0
522202	521420	20100N	PARTICIPANT	\N	PRESENT	0
522203	521420	05012A	PARTICIPANT	\N	PRESENT	0
522204	521420	20106U	PARTICIPANT	\N	PRESENT	0
522205	521420	19503N	PARTICIPANT	\N	PRESENT	0
522206	521420	20020P	PARTICIPANT	\N	PRESENT	1
522207	521420	20024T	PARTICIPANT	\N	PRESENT	0
522208	521420	17637T	PARTICIPANT	\N	PRESENT	0
522209	521420	20032T	PARTICIPANT	\N	PRESENT	1
522210	521420	14031R	PARTICIPANT	\N	PRESENT	0
522211	521420	20038A	PARTICIPANT	\N	PRESENT	0
522212	521420	20046A	PARTICIPANT	\N	PRESENT	0
522253	521574	20086J	PARTICIPANT	\N	PRESENT	0
522214	521420	20068G	PARTICIPANT	\N	PRESENT	0
522215	521420	19745F	PARTICIPANT	\N	PRESENT	0
522216	521420	08060W	PARTICIPANT	\N	EXCUSE	0
522217	521420	20118Y	PARTICIPANT	\N	PRESENT	0
522218	521420	11101A	PARTICIPANT	\N	PRESENT	0
522219	521420	19619A	PARTICIPANT	\N	PRESENT	0
522235	521420	19383Y	PARTICIPANT	\N	PRESENT	0
522236	521420	14038Y	PARTICIPANT	\N	PRESENT	0
522237	521420	19467C	PARTICIPANT	\N	PRESENT	0
522238	521420	19413M	PARTICIPANT	\N	PRESENT	0
522239	521420	11090Q	PARTICIPANT	\N	PRESENT	0
522240	521420	19866P	PARTICIPANT	\N	PRESENT	0
522241	521420	19631V	PARTICIPANT	\N	PRESENT	0
522254	521574	19383Y	PARTICIPANT	\N	PRESENT	0
522255	521574	19768N	PARTICIPANT	\N	PRESENT	0
522256	521574	20088L	PARTICIPANT	\N	PRESENT	0
522257	521574	19515S	PARTICIPANT	\N	PRESENT	0
522258	521574	19782L	PARTICIPANT	\N	PRESENT	0
522259	521574	20092G	PARTICIPANT	\N	PRESENT	0
522260	521574	01043Q	PARTICIPANT	\N	PRESENT	0
522261	521574	14357A	PARTICIPANT	\N	PRESENT	0
522262	521574	19413M	PARTICIPANT	\N	PRESENT	0
522263	521574	20082E	PARTICIPANT	\N	PRESENT	0
522264	521574	20094J	PARTICIPANT	\N	PRESENT	0
522265	521574	04045F	PARTICIPANT	\N	PRESENT	0
522266	521574	20104S	PARTICIPANT	\N	PRESENT	0
522267	521574	19575F	PARTICIPANT	\N	PRESENT	0
522268	521574	20018V	PARTICIPANT	\N	PRESENT	0
522269	521574	19511N	PARTICIPANT	\N	PRESENT	0
522270	521574	19563B	PARTICIPANT	\N	PRESENT	0
522271	521574	19521Q	PARTICIPANT	\N	PRESENT	0
522272	521574	20028X	PARTICIPANT	\N	PRESENT	0
522273	521574	14038Y	PARTICIPANT	\N	PRESENT	0
522274	521574	20034V	PARTICIPANT	\N	PRESENT	0
522275	521574	19695N	PARTICIPANT	\N	PRESENT	0
522276	521574	14033T	PARTICIPANT	\N	PRESENT	0
522277	521574	11090Q	PRESIDENT	0	PRESENT	0
522278	521574	20174H	PARTICIPANT	\N	PRESENT	0
522279	521574	14205J	PARTICIPANT	\N	PRESENT	0
522280	521574	20062A	PARTICIPANT	\N	PRESENT	0
522281	521574	19507S	PARTICIPANT	\N	PRESENT	0
522282	521574	14257W	PARTICIPANT	\N	PRESENT	0
522283	521420	19768N	PARTICIPANT	\N	PRESENT	0
522284	521420	20088L	PARTICIPANT	\N	PRESENT	0
522285	521420	19515S	PARTICIPANT	\N	PRESENT	0
522286	521420	01043Q	PARTICIPANT	\N	PRESENT	0
522287	521420	20082E	PARTICIPANT	\N	PRESENT	0
522288	521420	20104S	PARTICIPANT	\N	PRESENT	0
522289	521420	19575F	PARTICIPANT	\N	PRESENT	0
522290	521420	11065P	PARTICIPANT	\N	PRESENT	0
522291	521420	19521Q	PARTICIPANT	\N	PRESENT	0
522292	521420	19507S	PARTICIPANT	\N	PRESENT	0
522294	521420	04045F	PARTICIPANT	\N	PRESENT	0
522297	521420	19782L	PARTICIPANT	\N	PRESENT	0
522298	521420	14357A	PARTICIPANT	\N	PRESENT	0
522299	521420	20018V	PARTICIPANT	\N	PRESENT	0
522300	521420	19511N	PARTICIPANT	\N	PRESENT	0
522301	521420	19563B	PARTICIPANT	\N	PRESENT	0
522302	521420	14033T	PARTICIPANT	\N	PRESENT	0
522310	521420	20028X	PARTICIPANT	\N	PRESENT	0
522311	521420	20034V	PARTICIPANT	\N	PRESENT	0
522312	521420	19695N	PARTICIPANT	\N	PRESENT	0
522313	521420	20062A	PARTICIPANT	\N	PRESENT	0
522314	521420	14257W	PARTICIPANT	\N	PRESENT	0
522315	521420	20092G	PARTICIPANT	\N	PRESENT	0
522316	521420	20094J	PARTICIPANT	\N	PRESENT	0
522317	521420	20174H	PARTICIPANT	\N	PRESENT	0
522318	521420	14205J	PARTICIPANT	\N	PRESENT	0
522319	521420	20086J	PARTICIPANT	\N	PRESENT	0
522321	521574	19333N	PARTICIPANT	\N	PRESENT	0
531691	531690	20074E	PARTICIPANT	\N	PRESENT	0
531692	531363	14111D	PARTICIPANT	\N	PRESENT	0
531693	531363	19467C	PARTICIPANT	\N	PRESENT	0
531694	531363	14249W	PARTICIPANT	\N	PRESENT	0
531695	531363	19573D	PARTICIPANT	\N	PRESENT	0
531696	531363	07004J	PARTICIPANT	\N	PRESENT	0
531697	531363	14021P	PARTICIPANT	\N	PRESENT	0
531698	531363	14331P	PARTICIPANT	\N	PRESENT	0
531699	531363	11040E	PARTICIPANT	\N	PRESENT	0
531700	531363	19687N	PARTICIPANT	\N	PRESENT	0
531701	531363	19479G	PARTICIPANT	\N	PRESENT	0
531702	531363	19747H	PARTICIPANT	\N	PRESENT	0
531703	531363	20092G	PARTICIPANT	\N	PRESENT	0
531704	531363	19543W	PARTICIPANT	\N	PRESENT	0
531705	531099	20130U	PARTICIPANT	\N	PRESENT	1
531706	531099	19703U	PARTICIPANT	\N	PRESENT	0
531707	531099	14187A	PARTICIPANT	\N	PRESENT	0
531708	531099	19679N	PARTICIPANT	\N	PRESENT	0
531709	531099	20040T	PARTICIPANT	\N	PRESENT	0
531710	531099	17965H	PARTICIPANT	\N	PRESENT	1
531711	531099	18193Q	PRESIDENT	0	PRESENT	0
531712	531099	04045F	PARTICIPANT	\N	PRESENT	1
531713	531099	19631V	PARTICIPANT	\N	PRESENT	1
531714	531099	19760E	PARTICIPANT	\N	PRESENT	0
531716	531363	14221J	PARTICIPANT	\N	PRESENT	0
531717	531363	11012A	PARTICIPANT	\N	PRESENT	0
531718	531099	20018V	PARTICIPANT	\N	PRESENT	1
531719	531363	19762G	PARTICIPANT	\N	PRESENT	0
531720	531363	20044X	PARTICIPANT	\N	PRESENT	0
531721	531322	11067R	PARTICIPANT	\N	EXCUSE	0
531772	531364	14327T	PARTICIPANT	\N	PRESENT	0
531773	531364	20036X	PARTICIPANT	\N	PRESENT	0
531774	531364	19782L	PARTICIPANT	\N	PRESENT	0
531775	531364	11012A	PARTICIPANT	\N	PRESENT	0
531776	531364	19687N	PARTICIPANT	\N	PRESENT	0
531777	531364	20070A	PARTICIPANT	\N	PRESENT	0
531778	531364	20044X	PARTICIPANT	\N	PRESENT	0
531779	531364	14221J	PARTICIPANT	\N	PRESENT	0
531780	531364	19479G	PARTICIPANT	\N	PRESENT	0
531781	531364	20132W	PARTICIPANT	\N	PRESENT	0
531782	531364	20092G	PARTICIPANT	\N	PRESENT	0
531783	531364	19651A	PARTICIPANT	\N	PRESENT	0
531784	531364	08061X	PARTICIPANT	\N	PRESENT	0
531785	531364	07004J	PARTICIPANT	\N	PRESENT	0
531786	531364	20026V	PARTICIPANT	\N	PRESENT	0
531787	531364	20180F	PARTICIPANT	\N	PRESENT	0
531788	531364	19467C	PARTICIPANT	\N	PRESENT	0
531789	531364	01057W	PARTICIPANT	\N	PRESENT	0
531790	531364	14259Y	PARTICIPANT	\N	PRESENT	0
531791	531364	20058E	PARTICIPANT	\N	PRESENT	0
531792	531364	14105F	PARTICIPANT	\N	PRESENT	0
531793	531364	19762G	PARTICIPANT	\N	PRESENT	0
531794	531364	20152B	PARTICIPANT	\N	PRESENT	0
531795	531364	20124W	PARTICIPANT	\N	PRESENT	0
531796	531364	20054A	PARTICIPANT	\N	PRESENT	0
531797	531364	19747H	PARTICIPANT	\N	PRESENT	0
531798	531364	01024M	PARTICIPANT	\N	PRESENT	0
531799	531364	19543W	PARTICIPANT	\N	PRESENT	0
531800	531364	19441R	PARTICIPANT	\N	PRESENT	0
531801	531364	17589D	PARTICIPANT	\N	PRESENT	0
531802	531364	20080C	PARTICIPANT	\N	PRESENT	0
531803	531364	19758L	PARTICIPANT	\N	PRESENT	0
531804	531364	19565D	PARTICIPANT	\N	PRESENT	0
531805	531364	14225N	PARTICIPANT	\N	PRESENT	0
531806	531364	20074E	PARTICIPANT	\N	PRESENT	0
531807	531364	20172F	PARTICIPANT	\N	PRESENT	0
531808	531364	20116W	PARTICIPANT	\N	PRESENT	0
531812	531364	14133K	PARTICIPANT	\N	PRESENT	0
531815	531364	01043Q	PARTICIPANT	\N	PRESENT	0
531816	531364	20134Y	PARTICIPANT	\N	PRESENT	0
531817	531364	19699S	PARTICIPANT	\N	PRESENT	0
531818	531364	19251M	PARTICIPANT	\N	PRESENT	0
531819	531364	19647E	PARTICIPANT	\N	PRESENT	0
531820	531364	19349W	PARTICIPANT	\N	PRESENT	0
531821	531364	20062A	PARTICIPANT	\N	PRESENT	0
531822	531364	14089Y	PARTICIPANT	\N	PRESENT	0
531823	529295	20136B	PARTICIPANT	\N	PRESENT	0
531824	529295	20102Q	PARTICIPANT	\N	PRESENT	0
531770	531364	08073C	PARTICIPANT	\N	PRESENT	0
531771	531364	20084G	PARTICIPANT	\N	PRESENT	0
531825	529295	20120S	PARTICIPANT	\N	PRESENT	1
531826	531364	11085T	PARTICIPANT	\N	PRESENT	0
531827	531364	14189C	PARTICIPANT	\N	PRESENT	0
531831	529295	19333N	PARTICIPANT	\N	PRESENT	0
531829	531364	19741B	PARTICIPANT	\N	PRESENT	0
531830	531364	07033P	PARTICIPANT	\N	PRESENT	0
531832	529295	19826F	PARTICIPANT	\N	PRESENT	0
531833	529295	19599P	PARTICIPANT	\N	PRESENT	0
531834	531364	20046A	PARTICIPANT	\N	PRESENT	0
531835	529295	20106U	PARTICIPANT	\N	PRESENT	0
531836	529295	14219Q	PARTICIPANT	\N	PRESENT	0
531837	529295	20020P	PARTICIPANT	\N	PRESENT	0
531838	529295	19525U	PARTICIPANT	\N	PRESENT	0
531839	531364	14073Q	PARTICIPANT	\N	PRESENT	0
531840	529295	14031R	PARTICIPANT	\N	PRESENT	0
531841	531364	04043D	PARTICIPANT	\N	PRESENT	0
531842	531099	19667J	PARTICIPANT	\N	PRESENT	0
531843	531364	08069G	PARTICIPANT	\N	PRESENT	0
531844	531364	14083S	PARTICIPANT	\N	PRESENT	0
531845	531364	14038Y	PARTICIPANT	\N	PRESENT	0
531846	531364	19443T	PARTICIPANT	\N	PRESENT	0
531847	529295	19549D	PARTICIPANT	\N	PRESENT	0
531848	529295	20076G	PARTICIPANT	\N	PRESENT	1
531849	529295	19820Y	PARTICIPANT	\N	PRESENT	0
531850	529295	17229F	PARTICIPANT	\N	PRESENT	0
531851	529295	19637C	PARTICIPANT	\N	PRESENT	0
531852	529295	20096L	PARTICIPANT	\N	PRESENT	0
531853	529295	19551W	PARTICIPANT	\N	PRESENT	0
531854	529295	05012A	PARTICIPANT	\N	PRESENT	0
531855	529295	08060W	PARTICIPANT	\N	PRESENT	0
531856	529295	20068G	PARTICIPANT	\N	PRESENT	0
531857	529295	11101A	PARTICIPANT	\N	PRESENT	0
531858	529295	19745F	PARTICIPANT	\N	PRESENT	0
531859	529295	19577H	PARTICIPANT	\N	PRESENT	0
531860	529295	18083K	PARTICIPANT	\N	PRESENT	1
531861	529295	20140W	PARTICIPANT	\N	PRESENT	1
531862	529295	19387D	PARTICIPANT	\N	PRESENT	1
531863	531364	01048V	PARTICIPANT	\N	PRESENT	0
531864	531364	14121F	PARTICIPANT	\N	PRESENT	0
531865	531364	20022R	PARTICIPANT	\N	PRESENT	0
531866	531099	20066E	PARTICIPANT	\N	PRESENT	1
531867	531099	20098N	PARTICIPANT	\N	PRESENT	1
531868	531364	11072N	PARTICIPANT	\N	PRESENT	0
531869	531364	20090E	PARTICIPANT	\N	PRESENT	0
531872	529295	20038A	PARTICIPANT	\N	PRESENT	0
531873	531364	14033T	PARTICIPANT	\N	PRESENT	0
531874	531364	19507S	PARTICIPANT	\N	PRESENT	0
531875	531364	11048N	PARTICIPANT	\N	PRESENT	0
531876	531364	14147R	PARTICIPANT	\N	PRESENT	0
531877	531296	14097Y	PARTICIPANT	\N	PRESENT	1
531878	531296	14059S	PARTICIPANT	\N	PRESENT	0
531879	531296	04035D	PARTICIPANT	\N	PRESENT	0
531880	531296	14133K	PARTICIPANT	\N	PRESENT	0
531881	531296	01062T	PARTICIPANT	\N	PRESENT	1
531882	531296	19565D	PARTICIPANT	\N	PRESENT	1
531883	531296	04034C	PARTICIPANT	\N	PRESENT	0
531884	531296	08069G	PARTICIPANT	\N	PRESENT	0
531885	531296	20042V	PARTICIPANT	\N	PRESENT	0
531886	531296	04042C	PRESIDENT	0	PRESENT	0
531887	531296	11066Q	PARTICIPANT	\N	PRESENT	0
531888	531296	19421M	PARTICIPANT	\N	PRESENT	1
531889	531296	98022P	PARTICIPANT	\N	PRESENT	1
531890	531296	11083R	PARTICIPANT	\N	PRESENT	0
531891	531296	14249W	PARTICIPANT	\N	PRESENT	0
531892	531296	14255U	PARTICIPANT	\N	PRESENT	0
531893	531296	08047A	PARTICIPANT	\N	PRESENT	0
531894	531296	20128B	PARTICIPANT	\N	PRESENT	0
531895	531364	20096L	PARTICIPANT	\N	PRESENT	0
531896	531364	14217N	PARTICIPANT	\N	PRESENT	0
531897	531364	19954N	PARTICIPANT	\N	PRESENT	0
531898	531364	11040E	PARTICIPANT	\N	PRESENT	0
531899	531296	16685X	PARTICIPANT	\N	PRESENT	1
531900	531296	08056B	PARTICIPANT	\N	PRESENT	1
531901	531296	19347U	PARTICIPANT	\N	PRESENT	0
531902	531364	97011G	PARTICIPANT	\N	PRESENT	0
531903	531364	19545Y	PARTICIPANT	\N	PRESENT	0
512994	502350	14026U	PARTICIPANT	\N	PRESENT	0
512996	502350	04071H	PARTICIPANT	\N	PRESENT	0
512997	502350	19649G	PARTICIPANT	\N	PRESENT	0
512998	502350	14151M	PARTICIPANT	\N	PRESENT	0
512999	502350	11033F	PARTICIPANT	\N	PRESENT	0
513000	502350	20100N	PARTICIPANT	\N	PRESENT	0
513001	502350	20038A	PARTICIPANT	\N	PRESENT	0
513002	502350	14071N	PARTICIPANT	\N	PRESENT	0
513003	502350	19866P	PARTICIPANT	\N	PRESENT	0
513004	502350	19415P	PARTICIPANT	\N	PRESENT	0
513005	502350	19629C	PARTICIPANT	\N	PRESENT	0
513006	502350	19583F	PARTICIPANT	\N	PRESENT	0
513007	502350	19671E	PARTICIPANT	\N	PRESENT	0
513008	502350	11072N	PARTICIPANT	\N	PRESENT	0
513009	502350	19747H	PARTICIPANT	\N	PRESENT	0
513010	502350	04085P	PARTICIPANT	\N	PRESENT	0
513011	502350	14055N	PARTICIPANT	\N	PRESENT	0
513012	502350	14069U	PARTICIPANT	\N	PRESENT	0
513013	502350	07029T	PARTICIPANT	\N	PRESENT	0
513014	502350	20058E	PARTICIPANT	\N	PRESENT	0
513015	502350	14053L	PARTICIPANT	\N	PRESENT	0
513016	502350	19762G	PARTICIPANT	\N	PRESENT	0
513017	502350	11056N	PARTICIPANT	\N	PRESENT	0
513018	502350	20054A	PARTICIPANT	\N	PRESENT	0
513019	502350	19711U	PARTICIPANT	\N	PRESENT	0
513020	502350	07004J	PARTICIPANT	\N	PRESENT	0
513021	502350	20124W	PARTICIPANT	\N	PRESENT	0
513022	502350	14215L	PARTICIPANT	\N	PRESENT	0
513023	502350	20126Y	PARTICIPANT	\N	PRESENT	0
513024	502350	19447X	PARTICIPANT	\N	PRESENT	0
513025	502350	20110Q	PARTICIPANT	\N	PRESENT	0
513026	502350	19335Q	PARTICIPANT	\N	PRESENT	0
513027	502350	20114U	PARTICIPANT	\N	PRESENT	0
513028	502350	19643A	PARTICIPANT	\N	PRESENT	0
513029	502350	14089Y	PARTICIPANT	\N	PRESENT	0
513030	502350	19347U	PARTICIPANT	\N	PRESENT	0
513031	502350	14253S	PARTICIPANT	\N	PRESENT	0
513032	502350	19693L	PARTICIPANT	\N	PRESENT	0
513033	502350	11026G	PARTICIPANT	\N	PRESENT	0
513034	502350	19489J	PARTICIPANT	\N	PRESENT	0
513035	502350	19741B	PARTICIPANT	\N	PRESENT	0
513036	502350	08010L	PARTICIPANT	\N	PRESENT	0
513037	502350	17737W	PARTICIPANT	\N	PRESENT	0
513038	502350	01057W	PARTICIPANT	\N	PRESENT	0
513039	502350	19569H	PARTICIPANT	\N	PRESENT	0
513040	502350	19749K	PARTICIPANT	\N	PRESENT	0
513041	502350	19543W	PARTICIPANT	\N	PRESENT	0
513042	502350	20094J	PARTICIPANT	\N	PRESENT	0
513043	502350	01028R	PARTICIPANT	\N	PRESENT	0
513046	502350	11115U	PARTICIPANT	\N	PRESENT	0
513057	502350	20070A	PARTICIPANT	\N	PRESENT	0
513058	502350	20080C	PARTICIPANT	\N	PRESENT	0
513059	502350	11048N	PARTICIPANT	\N	PRESENT	0
513060	502350	19647E	PARTICIPANT	\N	PRESENT	0
519094	519093	19673G	PARTICIPANT	\N	PRESENT	0
519095	519093	20110Q	PARTICIPANT	\N	PRESENT	0
519096	519093	14179A	PARTICIPANT	\N	PRESENT	0
519097	519093	11026G	PARTICIPANT	\N	PRESENT	0
519099	519098	11067R	PARTICIPANT	\N	PRESENT	0
519100	519098	19533U	PARTICIPANT	\N	EXCUSE	0
519101	519098	19563B	PARTICIPANT	\N	EXCUSE	0
523897	523896	08060W	PARTICIPANT	\N	PRESENT	0
523898	523896	05012A	PARTICIPANT	\N	PRESENT	0
523899	523896	19525U	PARTICIPANT	\N	PRESENT	0
523900	523896	17229F	PARTICIPANT	\N	PRESENT	0
523901	523896	20038A	PARTICIPANT	\N	PRESENT	0
523902	523896	20100N	PARTICIPANT	\N	PRESENT	0
523903	523896	19387D	PARTICIPANT	\N	PRESENT	0
523904	523896	19551W	PARTICIPANT	\N	PRESENT	0
523905	523896	19619A	PARTICIPANT	\N	PRESENT	0
523906	523896	20136B	PARTICIPANT	\N	PRESENT	0
523912	523911	08060W	PARTICIPANT	\N	PRESENT	0
523913	523911	05012A	PARTICIPANT	\N	PRESENT	0
523914	523911	18083K	PARTICIPANT	\N	PRESENT	0
523915	523911	20102Q	PARTICIPANT	\N	PRESENT	0
523916	523911	19637C	PARTICIPANT	\N	PRESENT	0
523917	523911	19619A	PARTICIPANT	\N	PRESENT	0
527783	526540	20066E	PARTICIPANT	\N	PRESENT	0
527784	526540	20052X	PARTICIPANT	\N	PRESENT	0
527785	526540	19699S	PARTICIPANT	\N	PRESENT	0
527786	526540	14329V	PARTICIPANT	\N	PRESENT	0
527787	526540	14026U	PARTICIPANT	\N	PRESENT	0
527788	526540	19711U	PARTICIPANT	\N	PRESENT	0
527789	526540	18083K	PARTICIPANT	\N	PRESENT	0
527790	526540	19741B	PARTICIPANT	\N	PRESENT	0
527791	526540	11056N	PARTICIPANT	\N	PRESENT	0
527792	526540	19820Y	PARTICIPANT	\N	PRESENT	0
527793	526540	20126Y	PARTICIPANT	\N	PRESENT	0
527794	526540	19467C	PARTICIPANT	\N	PRESENT	0
527795	526540	14053L	PARTICIPANT	\N	PRESENT	0
527796	526540	19387D	PARTICIPANT	\N	PRESENT	0
527797	526540	19719D	PARTICIPANT	\N	PRESENT	0
527798	526540	17589D	PARTICIPANT	\N	PRESENT	0
527799	526540	04059M	PARTICIPANT	\N	PRESENT	0
527800	526540	11083R	PARTICIPANT	\N	PRESENT	0
527801	526540	19503N	PARTICIPANT	\N	PRESENT	0
527802	526540	01057W	PARTICIPANT	\N	PRESENT	0
527803	526540	08015R	PARTICIPANT	\N	PRESENT	0
527804	526540	14033T	PARTICIPANT	\N	PRESENT	0
527805	526540	05012A	PARTICIPANT	\N	PRESENT	0
527806	526540	14207L	PARTICIPANT	\N	PRESENT	0
527807	526540	04034C	PARTICIPANT	\N	PRESENT	0
527808	526540	20174H	PARTICIPANT	\N	PRESENT	0
527809	526540	20080C	PARTICIPANT	\N	PRESENT	0
527810	526540	19415P	PARTICIPANT	\N	PRESENT	0
527811	526540	20044X	PARTICIPANT	\N	PRESENT	0
527812	526540	20116W	PARTICIPANT	\N	PRESENT	0
527813	526540	20120S	PARTICIPANT	\N	PRESENT	0
527814	526540	11072N	PARTICIPANT	\N	PRESENT	0
527815	526540	14249W	PARTICIPANT	\N	PRESENT	0
527816	526540	01028R	PARTICIPANT	\N	PRESENT	0
527817	526540	17779H	PARTICIPANT	\N	PRESENT	0
527818	526540	08012N	PARTICIPANT	\N	PRESENT	0
527819	526540	14257W	PARTICIPANT	\N	PRESENT	0
527820	526540	08073C	PARTICIPANT	\N	PRESENT	0
527821	526540	12041X	PARTICIPANT	\N	PRESENT	0
527822	526540	19685L	PARTICIPANT	\N	PRESENT	0
527823	526540	20124W	PARTICIPANT	\N	PRESENT	0
527824	526540	20054A	PARTICIPANT	\N	PRESENT	0
527825	526540	14211G	PARTICIPANT	\N	PRESENT	0
527826	526540	19695N	PARTICIPANT	\N	PRESENT	0
527827	526540	20112S	PARTICIPANT	\N	PRESENT	0
527828	526540	04047H	PARTICIPANT	\N	PRESENT	0
527830	526540	19758L	PARTICIPANT	\N	PRESENT	0
527831	526540	11031D	PARTICIPANT	\N	PRESENT	0
527832	526540	04071H	PARTICIPANT	\N	PRESENT	0
527833	526540	19715Y	PARTICIPANT	\N	PRESENT	0
527834	526540	19515S	PARTICIPANT	\N	PRESENT	0
527835	526540	19599P	PARTICIPANT	\N	PRESENT	0
527836	526540	08011M	PARTICIPANT	\N	PRESENT	0
527837	526540	19573D	PARTICIPANT	\N	PRESENT	0
527838	526540	14021P	PARTICIPANT	\N	PRESENT	0
527839	526540	20086J	PARTICIPANT	\N	PRESENT	0
527840	526540	20038A	PARTICIPANT	\N	PRESENT	0
527841	526540	14001X	PARTICIPANT	\N	PRESENT	0
527842	526540	11067R	PARTICIPANT	\N	PRESENT	0
527843	526540	19549D	PARTICIPANT	\N	PRESENT	0
527844	526540	20026V	PARTICIPANT	\N	PRESENT	0
527845	526540	14038Y	PARTICIPANT	\N	PRESENT	0
527846	526540	20032T	PARTICIPANT	\N	PRESENT	0
527847	526540	19723Y	PARTICIPANT	\N	PRESENT	0
527848	526540	20088L	PARTICIPANT	\N	PRESENT	0
527849	526540	20064C	PARTICIPANT	\N	PRESENT	0
527850	526540	17965H	PARTICIPANT	\N	PRESENT	0
527851	526540	19631V	PARTICIPANT	\N	PRESENT	0
527852	526540	14147R	PARTICIPANT	\N	PRESENT	0
527853	526540	20070A	PARTICIPANT	\N	PRESENT	0
527854	526540	11033F	PARTICIPANT	\N	PRESENT	0
527855	526540	20036X	PARTICIPANT	\N	PRESENT	0
527856	526540	20140W	PARTICIPANT	\N	PRESENT	0
527857	526540	19689Q	PARTICIPANT	\N	PRESENT	0
527859	526540	95063L	PARTICIPANT	\N	PRESENT	0
527860	526540	08061X	PARTICIPANT	\N	PRESENT	0
527861	526540	20062A	PARTICIPANT	\N	PRESENT	0
527862	526540	19651A	PARTICIPANT	\N	PRESENT	0
527863	526540	19349W	PARTICIPANT	\N	PRESENT	0
527864	526540	19697Q	PARTICIPANT	\N	PRESENT	0
527865	526540	19762G	PARTICIPANT	\N	PRESENT	0
527866	526540	04057K	PARTICIPANT	\N	PRESENT	0
527867	526540	14251Q	PARTICIPANT	\N	PRESENT	0
536049	536048	08060W	PARTICIPANT	\N	PRESENT	0
536050	536048	05012A	PARTICIPANT	\N	PRESENT	0
536051	536048	19525U	PARTICIPANT	\N	PRESENT	0
536052	536048	17229F	PARTICIPANT	\N	PRESENT	0
536053	536048	20100N	PARTICIPANT	\N	PRESENT	0
536054	536048	19387D	PARTICIPANT	\N	PRESENT	0
536055	536048	20068G	PARTICIPANT	\N	PRESENT	0
536056	536048	19551W	PARTICIPANT	\N	PRESENT	0
536057	536048	20102Q	PARTICIPANT	\N	PRESENT	0
536058	536048	19637C	PARTICIPANT	\N	PRESENT	0
536059	536048	20136B	PARTICIPANT	\N	PRESENT	0
536062	536061	08060W	PARTICIPANT	\N	PRESENT	0
536063	536061	05012A	PARTICIPANT	\N	PRESENT	0
536064	536061	19525U	PARTICIPANT	\N	PRESENT	0
536065	536061	17229F	PARTICIPANT	\N	PRESENT	0
536066	536061	19387D	PARTICIPANT	\N	PRESENT	0
536067	536061	19551W	PARTICIPANT	\N	PRESENT	0
536068	536061	20102Q	PARTICIPANT	\N	PRESENT	0
536069	536061	19637C	PARTICIPANT	\N	PRESENT	0
536070	536061	20136B	PARTICIPANT	\N	PRESENT	0
536079	536072	08060W	PARTICIPANT	\N	PRESENT	0
536081	536072	05012A	PARTICIPANT	\N	PRESENT	0
536082	536072	19551W	PARTICIPANT	\N	PRESENT	0
536111	536110	16685X	PARTICIPANT	\N	PRESENT	0
536114	536112	14249W	PARTICIPANT	\N	PRESENT	0
536115	525928	14083S	PARTICIPANT	\N	PRESENT	0
536116	525926	14073Q	PARTICIPANT	\N	PRESENT	0
536899	536496	14257W	PARTICIPANT	\N	PRESENT	0
536901	536900	14038Y	PARTICIPANT	\N	PRESENT	0
536902	536900	19441R	PARTICIPANT	\N	PRESENT	0
536903	536900	20060X	PARTICIPANT	\N	PRESENT	0
536905	536904	14038Y	PARTICIPANT	\N	PRESENT	0
536906	536904	19441R	PARTICIPANT	\N	PRESENT	0
536907	536904	19631V	PARTICIPANT	\N	PRESENT	0
536908	536904	14257W	PARTICIPANT	\N	PRESENT	0
538937	537512	19515S	PRESIDENT	0	PRESENT	0
538938	537512	19575F	PARTICIPANT	\N	PRESENT	0
538939	537512	19760E	PARTICIPANT	\N	PRESENT	0
538940	537512	14105F	PARTICIPANT	\N	PRESENT	0
538941	537512	14083S	PARTICIPANT	\N	PRESENT	0
538942	537512	14329V	PARTICIPANT	\N	PRESENT	0
538943	537512	19467C	PARTICIPANT	\N	PRESENT	0
538944	537512	14041T	PARTICIPANT	\N	PRESENT	0
538945	537512	19695N	PARTICIPANT	\N	PRESENT	0
538946	537512	14026U	PARTICIPANT	\N	PRESENT	0
538947	537512	20126Y	PARTICIPANT	\N	PRESENT	0
538948	537512	08015R	PARTICIPANT	\N	PRESENT	0
538949	537512	14031R	PARTICIPANT	\N	PRESENT	0
538950	537512	20054A	PARTICIPANT	\N	PRESENT	0
538951	537512	19301E	PARTICIPANT	\N	PRESENT	0
539449	536886	19533U	PARTICIPANT	\N	PRESENT	0
539450	536886	19593H	PARTICIPANT	\N	PRESENT	0
539451	536887	14030Q	PARTICIPANT	\N	PRESENT	0
539452	536887	19533U	PARTICIPANT	\N	PRESENT	0
539453	534295	14030Q	PARTICIPANT	\N	PRESENT	0
539454	536888	19533U	PARTICIPANT	\N	PRESENT	0
539456	536880	19593H	PARTICIPANT	\N	PRESENT	0
539457	536873	08012N	PARTICIPANT	\N	PRESENT	0
539458	536873	11043H	PARTICIPANT	\N	PRESENT	0
539459	536873	19399H	PARTICIPANT	\N	PRESENT	0
539460	536873	20152B	PARTICIPANT	\N	PRESENT	0
539461	536873	14229S	PARTICIPANT	\N	PRESENT	0
539462	536873	14030Q	PARTICIPANT	\N	PRESENT	0
539463	536864	14030Q	PARTICIPANT	\N	PRESENT	0
539464	536864	19693L	PARTICIPANT	\N	PRESENT	0
539465	536864	14229S	PARTICIPANT	\N	PRESENT	0
539466	536882	08012N	PARTICIPANT	\N	PRESENT	0
539467	536882	11043H	PARTICIPANT	\N	PRESENT	0
539468	536882	19533U	PARTICIPANT	\N	PRESENT	0
539469	536882	19699S	PARTICIPANT	\N	PRESENT	0
539471	536883	19533U	PARTICIPANT	\N	PRESENT	0
539472	536883	11043H	PARTICIPANT	\N	PRESENT	0
539473	536883	20152B	PARTICIPANT	\N	PRESENT	0
539476	539474	20132W	PARTICIPANT	\N	PRESENT	0
539477	539474	20180F	PARTICIPANT	\N	PRESENT	0
539478	539474	20048C	PARTICIPANT	\N	PRESENT	0
539479	539474	20152B	PARTICIPANT	\N	PRESENT	0
539480	539474	19693L	PARTICIPANT	\N	PRESENT	0
539481	539474	19643A	PARTICIPANT	\N	PRESENT	0
539482	539474	20138D	PARTICIPANT	\N	PRESENT	0
539483	539474	19533U	PARTICIPANT	\N	PRESENT	0
539487	536884	19593H	PARTICIPANT	\N	PRESENT	0
539485	536884	19533U	PARTICIPANT	\N	PRESENT	0
539486	536884	14229S	PARTICIPANT	\N	PRESENT	0
539488	536884	19693L	PARTICIPANT	\N	PRESENT	0
539791	539548	14231L	PARTICIPANT	\N	PRESENT	0
539792	539548	11040E	PARTICIPANT	\N	PRESENT	0
539793	539548	19687N	PARTICIPANT	\N	PRESENT	0
539794	539548	19695N	PARTICIPANT	\N	PRESENT	0
539795	539548	14151M	PARTICIPANT	\N	PRESENT	0
539796	539548	17965H	PARTICIPANT	\N	PRESENT	0
539797	539548	11033F	PARTICIPANT	\N	PRESENT	0
539798	539548	04057K	PARTICIPANT	\N	PRESENT	0
539799	539548	17367Q	PARTICIPANT	\N	PRESENT	0
539800	539548	14107H	PARTICIPANT	\N	PRESENT	0
539801	539548	19515S	PARTICIPANT	\N	PRESENT	0
539802	539548	14179A	PARTICIPANT	\N	PRESENT	0
539803	539548	04047H	PARTICIPANT	\N	PRESENT	0
539804	539548	14030Q	PARTICIPANT	\N	PRESENT	0
539805	539548	14089Y	PARTICIPANT	\N	PRESENT	0
539806	539548	19581D	PARTICIPANT	\N	PRESENT	0
539807	539548	14215L	PARTICIPANT	\N	PRESENT	0
539808	539548	14187A	PARTICIPANT	\N	PRESENT	0
539809	539548	19415P	PARTICIPANT	\N	PRESENT	0
539810	539548	20026V	PARTICIPANT	\N	PRESENT	0
539811	539548	95063L	PARTICIPANT	\N	PRESENT	0
539812	539548	01057W	PARTICIPANT	\N	PRESENT	0
539813	539548	20128B	PARTICIPANT	\N	PRESENT	0
539814	539548	11072N	PARTICIPANT	\N	PRESENT	0
539815	539548	08034U	PARTICIPANT	\N	PRESENT	0
539816	539548	20152B	PARTICIPANT	\N	PRESENT	0
539817	539548	11103C	PARTICIPANT	\N	PRESENT	0
539818	539548	14105F	PARTICIPANT	\N	PRESENT	0
539819	539548	14069U	PARTICIPANT	\N	PRESENT	0
539820	539548	08010L	PARTICIPANT	\N	PRESENT	0
539821	539548	08028W	PARTICIPANT	\N	PRESENT	0
539822	539548	10015M	PARTICIPANT	\N	PRESENT	0
539823	539548	04033B	PARTICIPANT	\N	PRESENT	0
539824	539548	20098N	PARTICIPANT	\N	PRESENT	0
539825	539548	19729F	PARTICIPANT	\N	PRESENT	0
539826	539548	19447X	PARTICIPANT	\N	PRESENT	0
539827	539548	19741B	PARTICIPANT	\N	PRESENT	0
539828	539548	20056C	PARTICIPANT	\N	PRESENT	0
539829	539548	20096L	PARTICIPANT	\N	PRESENT	0
539830	539548	20110Q	PARTICIPANT	\N	PRESENT	0
539831	539548	08045X	PARTICIPANT	\N	PRESENT	0
539832	539548	14211G	PARTICIPANT	\N	PRESENT	0
539833	539548	20172F	PARTICIPANT	\N	PRESENT	0
539834	539548	20140W	PARTICIPANT	\N	PRESENT	0
539835	539548	19667J	PARTICIPANT	\N	PRESENT	0
539836	539548	19954N	PARTICIPANT	\N	PRESENT	0
539837	539548	19649G	PARTICIPANT	\N	PRESENT	0
539838	539548	19643A	PARTICIPANT	\N	PRESENT	0
539839	539548	20132W	PARTICIPANT	\N	PRESENT	0
539840	539548	19333N	PARTICIPANT	\N	PRESENT	0
539841	539548	04071H	PARTICIPANT	\N	PRESENT	0
539842	539548	19651A	PARTICIPANT	\N	PRESENT	0
539843	539548	19721W	PARTICIPANT	\N	PRESENT	0
539844	539548	05008E	PARTICIPANT	\N	PRESENT	0
539845	539548	20020P	PARTICIPANT	\N	PRESENT	0
539846	539548	08056B	PARTICIPANT	\N	PRESENT	0
539847	539548	20062A	PARTICIPANT	\N	PRESENT	0
539848	539548	19762G	PARTICIPANT	\N	PRESENT	0
539849	539548	14031R	PARTICIPANT	\N	PRESENT	0
539850	539548	04034C	PARTICIPANT	\N	PRESENT	0
539851	539548	14021P	PARTICIPANT	\N	PRESENT	0
539852	539548	20040T	PARTICIPANT	\N	PRESENT	0
539853	539548	08061X	PARTICIPANT	\N	PRESENT	0
539854	539548	19758L	PARTICIPANT	\N	PRESENT	0
539855	539548	20080C	PARTICIPANT	\N	PRESENT	0
539856	539548	19347U	PARTICIPANT	\N	PRESENT	0
539857	539548	04043D	PARTICIPANT	\N	PRESENT	0
539861	539548	19826F	PARTICIPANT	\N	PRESENT	0
539859	539548	20124W	PARTICIPANT	\N	PRESENT	0
539860	539548	19383Y	PARTICIPANT	\N	PRESENT	0
539862	539548	04059M	PARTICIPANT	\N	PRESENT	0
539863	539548	11056N	PARTICIPANT	\N	PRESENT	0
539864	539548	19503N	PARTICIPANT	\N	PRESENT	0
539865	539548	11067R	PARTICIPANT	\N	PRESENT	0
539866	539548	19747H	PARTICIPANT	\N	PRESENT	0
539867	539548	14111D	PARTICIPANT	\N	PRESENT	0
517287	517286	18193Q	PARTICIPANT	\N	PRESENT	0
517288	517286	11045K	PARTICIPANT	\N	PRESENT	0
517291	515230	19383Y	PARTICIPANT	\N	PRESENT	0
517768	517767	14071N	PARTICIPANT	\N	PRESENT	0
517769	517767	19826F	PARTICIPANT	\N	PRESENT	0
517770	517767	14151M	PARTICIPANT	\N	PRESENT	0
517771	517767	19575F	PARTICIPANT	\N	PRESENT	0
517772	517767	20084G	PARTICIPANT	\N	PRESENT	0
517773	517767	20038A	PARTICIPANT	\N	PRESENT	0
517774	517767	14097Y	PARTICIPANT	\N	PRESENT	0
517800	517779	17229F	PARTICIPANT	\N	PRESENT	0
517801	517779	20038A	PARTICIPANT	\N	PRESENT	0
517802	517779	08018U	PARTICIPANT	\N	PRESENT	0
517803	517779	19347U	PARTICIPANT	\N	PRESENT	0
517804	517779	14211G	PARTICIPANT	\N	PRESENT	0
517805	517779	14073Q	PARTICIPANT	\N	PRESENT	0
517798	517779	19543W	PARTICIPANT	\N	PRESENT	0
517799	517779	18083K	PARTICIPANT	\N	PRESENT	0
517806	517779	19709B	PARTICIPANT	\N	PRESENT	0
517807	517779	11026G	PARTICIPANT	\N	PRESENT	0
517808	517779	20092G	PARTICIPANT	\N	PRESENT	0
517841	517840	20114U	PARTICIPANT	\N	PRESENT	0
517842	517840	19599P	PARTICIPANT	\N	PRESENT	0
517843	517840	97011G	PARTICIPANT	\N	PRESENT	0
517844	517840	19551W	PARTICIPANT	\N	PRESENT	0
517846	517840	14097Y	PARTICIPANT	\N	PRESENT	0
517847	517840	20130U	PARTICIPANT	\N	PRESENT	0
517848	517840	11054L	PARTICIPANT	\N	PRESENT	0
517849	517840	01028R	PARTICIPANT	\N	PRESENT	0
522322	521574	19549D	PARTICIPANT	\N	PRESENT	0
522323	521574	19820Y	PARTICIPANT	\N	PRESENT	0
522324	521574	19826F	PARTICIPANT	\N	PRESENT	0
522325	521574	20024T	PARTICIPANT	\N	PRESENT	0
522326	521574	11065P	PARTICIPANT	\N	PRESENT	0
522327	521574	20038A	PARTICIPANT	\N	PRESENT	0
522328	521574	17229F	PARTICIPANT	\N	PRESENT	0
522329	521574	20068G	PARTICIPANT	\N	PRESENT	0
522330	521574	14219Q	PARTICIPANT	\N	PRESENT	0
522331	521574	14221J	PARTICIPANT	\N	PRESENT	0
522332	521574	20102Q	PARTICIPANT	\N	PRESENT	0
522333	521574	20096L	PARTICIPANT	\N	PRESENT	0
522334	521574	20100N	PARTICIPANT	\N	PRESENT	0
522335	521574	14237S	PARTICIPANT	\N	PRESENT	0
522336	521574	05012A	PARTICIPANT	\N	PRESENT	0
522337	521574	20106U	PARTICIPANT	\N	PRESENT	0
522338	521574	20118Y	PARTICIPANT	\N	PRESENT	0
522339	521574	17637T	PARTICIPANT	\N	PRESENT	0
522340	521574	14031R	PARTICIPANT	\N	PRESENT	0
522341	521574	19619A	PARTICIPANT	\N	PRESENT	0
522342	521574	08028W	PARTICIPANT	\N	EXCUSE	0
522343	521420	17229F	PARTICIPANT	\N	PRESENT	0
522344	521574	20020P	PARTICIPANT	\N	PRESENT	1
522345	521574	19525U	PARTICIPANT	\N	PRESENT	1
522346	521574	19701S	PARTICIPANT	\N	PRESENT	1
522347	521574	19631V	PARTICIPANT	\N	PRESENT	1
522348	521574	19637C	PARTICIPANT	\N	PRESENT	1
522349	521574	19705W	PARTICIPANT	\N	PRESENT	1
522350	521574	19467C	PARTICIPANT	\N	PRESENT	1
522351	521574	19747H	PARTICIPANT	\N	PRESENT	1
522356	521420	19251M	PARTICIPANT	\N	PRESENT	1
522357	521420	19747H	PARTICIPANT	\N	PRESENT	0
522371	521574	20032T	PARTICIPANT	\N	PRESENT	1
522372	521574	19251M	PARTICIPANT	\N	PRESENT	1
522387	521234	04086Q	PARTICIPANT	\N	PRESENT	0
522388	521234	11048N	PARTICIPANT	\N	PRESENT	0
522389	521234	19711U	PARTICIPANT	\N	PRESENT	0
522390	521234	19545Y	PARTICIPANT	\N	PRESENT	0
522391	521234	20050V	PARTICIPANT	\N	PRESENT	0
522392	521234	19741B	PARTICIPANT	\N	PRESENT	0
522393	521234	11074Q	PARTICIPANT	\N	PRESENT	0
522394	521234	20116W	PARTICIPANT	\N	PRESENT	0
522395	521234	14253S	PARTICIPANT	\N	PRESENT	0
522396	521234	20126Y	PARTICIPANT	\N	PRESENT	0
522397	521234	19349W	PARTICIPANT	\N	PRESENT	0
522398	521234	08034U	PARTICIPANT	\N	PRESENT	0
522399	521574	14187A	PARTICIPANT	\N	PRESENT	0
522400	521234	19687N	PARTICIPANT	\N	PRESENT	0
522401	521234	20070A	PARTICIPANT	\N	PRESENT	0
522402	521234	19647E	PARTICIPANT	\N	PRESENT	0
522403	521234	14189C	PARTICIPANT	\N	PRESENT	0
522404	521234	14331P	PARTICIPANT	\N	PRESENT	0
522405	521234	20044X	PARTICIPANT	\N	PRESENT	0
522406	521234	19479G	PARTICIPANT	\N	PRESENT	0
522407	521234	01057W	PARTICIPANT	\N	PRESENT	0
522408	521234	08011M	PARTICIPANT	\N	PRESENT	0
522412	521234	19689Q	PARTICIPANT	\N	PRESENT	0
522414	521234	19335Q	PARTICIPANT	\N	PRESENT	0
522415	521234	14083S	PARTICIPANT	\N	PRESENT	0
522416	521574	11099A	PARTICIPANT	\N	PRESENT	0
522707	521481	19527W	PARTICIPANT	\N	PRESENT	0
522708	521481	14257W	PARTICIPANT	\N	PRESENT	0
522709	521481	04047H	PARTICIPANT	\N	PRESENT	0
522710	521481	11033F	PARTICIPANT	\N	PRESENT	0
522711	521481	14133K	PARTICIPANT	\N	PRESENT	0
522712	521481	14069U	PARTICIPANT	\N	PRESENT	0
522713	521481	19649G	PARTICIPANT	\N	PRESENT	0
522715	521481	04033B	PARTICIPANT	\N	PRESENT	0
522716	521481	20064C	PARTICIPANT	\N	PRESENT	0
522717	521481	14187A	PARTICIPANT	\N	PRESENT	0
522718	521481	05008E	PARTICIPANT	\N	PRESENT	0
522719	521481	20128B	PARTICIPANT	\N	PRESENT	0
522720	521481	14053L	PARTICIPANT	\N	PRESENT	0
522721	521481	14071N	PARTICIPANT	\N	PRESENT	0
522722	521481	14179A	PARTICIPANT	\N	PRESENT	0
522723	521481	11090Q	PARTICIPANT	\N	PRESENT	0
522724	521481	20048C	PARTICIPANT	\N	PRESENT	0
522725	521481	14259Y	PARTICIPANT	\N	PRESENT	0
522726	521481	14089Y	PARTICIPANT	\N	PRESENT	0
522727	521481	14219Q	PARTICIPANT	\N	PRESENT	0
522728	521481	19671E	PARTICIPANT	\N	PRESENT	0
522729	521481	20066E	PARTICIPANT	\N	PRESENT	0
522730	521481	19749K	PARTICIPANT	\N	PRESENT	0
522731	521481	19619A	PARTICIPANT	\N	PRESENT	0
522732	521481	12041X	PARTICIPANT	\N	PRESENT	0
522733	521481	20114U	PARTICIPANT	\N	PRESENT	0
522734	521481	19621T	PARTICIPANT	\N	PRESENT	0
522735	521481	04057K	PARTICIPANT	\N	PRESENT	0
522736	521481	20126Y	PARTICIPANT	\N	PRESENT	0
522737	521481	19699S	PARTICIPANT	\N	PRESENT	0
522739	521481	01043Q	PARTICIPANT	\N	PRESENT	0
522741	521481	11085T	PARTICIPANT	\N	PRESENT	0
522742	521481	14357A	PARTICIPANT	\N	PRESENT	0
522743	521481	04070G	PARTICIPANT	\N	PRESENT	0
522744	521481	14327T	PARTICIPANT	\N	PRESENT	0
522745	521481	11103C	PARTICIPANT	\N	PRESENT	0
522746	521481	11045K	PARTICIPANT	\N	PRESENT	0
522747	521481	20152B	PARTICIPANT	\N	PRESENT	0
522748	521481	20040T	PARTICIPANT	\N	PRESENT	0
522749	521481	08015R	PARTICIPANT	\N	PRESENT	0
522751	521481	07029T	PARTICIPANT	\N	PRESENT	0
522752	521481	20024T	PARTICIPANT	\N	PRESENT	0
522753	521481	20172F	PARTICIPANT	\N	PRESENT	0
522758	521481	14205J	PARTICIPANT	\N	PRESENT	0
522756	521481	20056C	PARTICIPANT	\N	PRESENT	0
522757	521481	08034U	PARTICIPANT	\N	PRESENT	0
522759	521481	11097X	PARTICIPANT	\N	PRESENT	0
522760	521481	14105F	PARTICIPANT	\N	PRESENT	0
522761	521481	20044X	PARTICIPANT	\N	PRESENT	0
522762	521481	20026V	PARTICIPANT	\N	PRESENT	0
522763	521481	04092N	PARTICIPANT	\N	PRESENT	0
522765	521481	19573D	PARTICIPANT	\N	PRESENT	0
522766	521481	20042V	PARTICIPANT	\N	PRESENT	0
522767	521481	14213J	PARTICIPANT	\N	PRESENT	0
522768	521481	04034C	PARTICIPANT	\N	PRESENT	0
522769	521481	20180F	PARTICIPANT	\N	PRESENT	0
522770	521481	11040E	PARTICIPANT	\N	PRESENT	0
522771	521481	17737W	PARTICIPANT	\N	PRESENT	0
522772	521481	19954N	PARTICIPANT	\N	PRESENT	0
522773	521481	19629C	PARTICIPANT	\N	PRESENT	0
522775	521481	19335Q	PARTICIPANT	\N	PRESENT	0
522776	521481	19543W	PARTICIPANT	\N	PRESENT	0
522777	521481	19711U	PARTICIPANT	\N	PRESENT	0
522778	521481	20090E	PARTICIPANT	\N	PRESENT	0
522779	521481	20050V	PARTICIPANT	\N	PRESENT	0
522780	521481	19663E	PARTICIPANT	\N	PRESENT	0
531946	531365	11072N	PARTICIPANT	\N	PRESENT	0
531947	531365	20116W	PARTICIPANT	\N	PRESENT	0
531948	531365	11040E	PARTICIPANT	\N	PRESENT	0
531949	531365	14189C	PARTICIPANT	\N	PRESENT	0
531950	531365	01024M	PARTICIPANT	\N	PRESENT	0
531951	531365	20080C	PARTICIPANT	\N	PRESENT	0
531952	531365	20036X	PARTICIPANT	\N	PRESENT	0
531953	531365	19762G	PARTICIPANT	\N	PRESENT	0
531954	531365	19545Y	PARTICIPANT	\N	PRESENT	0
531955	531365	07029T	PARTICIPANT	\N	PRESENT	0
531956	531365	20122U	PARTICIPANT	\N	PRESENT	0
531957	531365	20054A	PARTICIPANT	\N	PRESENT	0
531958	531365	07033P	PARTICIPANT	\N	PRESENT	0
531959	531365	97011G	PARTICIPANT	\N	PRESENT	0
531960	531365	14105F	PARTICIPANT	\N	PRESENT	0
531961	531365	04043D	PARTICIPANT	\N	PRESENT	0
531962	531365	19711U	PARTICIPANT	\N	PRESENT	0
531963	531365	14147R	PARTICIPANT	\N	PRESENT	0
531964	531365	20096L	PARTICIPANT	\N	PRESENT	0
531965	531365	19954N	PARTICIPANT	\N	PRESENT	0
531966	531365	20022R	PARTICIPANT	\N	PRESENT	0
531967	531365	14225N	PARTICIPANT	\N	PRESENT	0
531968	531365	19443T	PARTICIPANT	\N	PRESENT	0
531984	531365	19399H	PARTICIPANT	\N	PRESENT	0
531985	531365	14031R	PARTICIPANT	\N	PRESENT	0
531986	531365	20136B	PARTICIPANT	\N	PRESENT	0
531972	531365	20090E	PARTICIPANT	\N	PRESENT	0
531973	531365	20068G	PARTICIPANT	\N	PRESENT	0
531974	531365	20074E	PARTICIPANT	\N	PRESENT	0
531975	531365	14083S	PARTICIPANT	\N	PRESENT	0
531976	531365	14327T	PARTICIPANT	\N	PRESENT	0
531977	531365	19479G	PARTICIPANT	\N	PRESENT	0
531978	531365	11012A	PARTICIPANT	\N	PRESENT	0
531979	531365	19647E	PARTICIPANT	\N	PRESENT	0
531980	531365	14121F	PARTICIPANT	\N	PRESENT	0
531944	531365	08073C	PARTICIPANT	\N	PRESENT	0
531945	531365	11048N	PARTICIPANT	\N	PRESENT	0
531981	531365	19758L	PARTICIPANT	\N	PRESENT	0
531982	531365	20070A	PARTICIPANT	\N	PRESENT	0
531983	531365	19507S	PARTICIPANT	\N	PRESENT	0
531987	531286	19383Y	PARTICIPANT	\N	PRESENT	0
531988	531286	19467C	PARTICIPANT	\N	PRESENT	0
531989	531286	19515S	PARTICIPANT	\N	PRESENT	0
531990	531286	19782L	PARTICIPANT	\N	PRESENT	0
531991	531286	20092G	PARTICIPANT	\N	PRESENT	0
531992	531286	01043Q	PARTICIPANT	\N	PRESENT	0
531993	531286	14357A	PARTICIPANT	\N	PRESENT	0
531994	531286	19441R	PARTICIPANT	\N	PRESENT	0
531995	531286	19413M	PARTICIPANT	\N	PRESENT	0
531996	531286	14033T	PARTICIPANT	\N	PRESENT	0
531997	531286	11090Q	PRESIDENT	0	PRESENT	0
531998	531286	14205J	PARTICIPANT	\N	PRESENT	0
531999	531286	08015R	PARTICIPANT	\N	PRESENT	0
532000	531286	19575F	PARTICIPANT	\N	PRESENT	0
532001	531286	19747H	PARTICIPANT	\N	PRESENT	0
532002	531286	20018V	PARTICIPANT	\N	PRESENT	0
532003	531286	08028W	PARTICIPANT	\N	PRESENT	0
532004	531286	19563B	PARTICIPANT	\N	PRESENT	0
532005	531286	14257W	PARTICIPANT	\N	PRESENT	0
532006	531365	19687N	PARTICIPANT	\N	PRESENT	0
532008	531099	19367Y	PARTICIPANT	\N	EXCUSE	0
532009	531365	08061X	PARTICIPANT	\N	PRESENT	0
532010	531296	01058X	PARTICIPANT	\N	PRESENT	0
532013	531296	12041X	PARTICIPANT	\N	PRESENT	1
532019	531365	20142Y	PARTICIPANT	\N	PRESENT	0
532026	531365	14042U	PARTICIPANT	\N	PRESENT	0
532027	531365	20140W	PARTICIPANT	\N	PRESENT	0
532031	531365	14030Q	PARTICIPANT	\N	PRESENT	0
532032	531365	14033T	PARTICIPANT	\N	PRESENT	0
532033	531365	20134Y	PARTICIPANT	\N	PRESENT	0
532034	531365	19741B	PARTICIPANT	\N	PRESENT	0
532045	531365	19679N	PARTICIPANT	\N	PRESENT	0
532046	531365	20066E	PARTICIPANT	\N	PRESENT	0
532047	531365	19447X	PARTICIPANT	\N	PRESENT	0
532048	531286	04070G	PARTICIPANT	\N	PRESENT	0
532049	531286	12041X	PARTICIPANT	\N	PRESENT	1
532050	531286	19565D	PARTICIPANT	\N	PRESENT	1
532051	531286	04034C	PARTICIPANT	\N	PRESENT	0
532052	531286	01058X	PARTICIPANT	\N	PRESENT	0
532053	531286	14026U	PARTICIPANT	\N	PRESENT	0
532054	531286	20100N	PARTICIPANT	\N	PRESENT	0
532055	531286	19347U	PARTICIPANT	\N	PRESENT	0
532056	531286	20128B	PARTICIPANT	\N	PRESENT	0
532057	531286	08047A	PARTICIPANT	\N	PRESENT	0
532058	531286	20030R	PARTICIPANT	\N	PRESENT	1
532059	531286	20034V	PARTICIPANT	\N	PRESENT	1
532060	531286	04035D	PARTICIPANT	\N	PRESENT	0
532061	531286	14073Q	PARTICIPANT	\N	PRESENT	0
532062	531286	08034U	PARTICIPANT	\N	PRESENT	0
532063	531286	08069G	PARTICIPANT	\N	PRESENT	0
532064	531286	20042V	PARTICIPANT	\N	PRESENT	0
532065	531286	10015M	PARTICIPANT	\N	PRESENT	0
532066	531286	11026G	PARTICIPANT	\N	PRESENT	0
532067	531286	19251M	PARTICIPANT	\N	PRESENT	0
532068	531286	14089Y	PARTICIPANT	\N	PRESENT	0
532069	531286	20062A	PARTICIPANT	\N	PRESENT	1
532070	531286	98022P	PARTICIPANT	\N	PRESENT	1
532071	531286	14255U	PARTICIPANT	\N	PRESENT	0
532072	531286	20094J	PARTICIPANT	\N	PRESENT	1
532073	531286	19521Q	PARTICIPANT	\N	PRESENT	1
532074	531286	20174H	PARTICIPANT	\N	PRESENT	1
532075	531286	14251Q	PARTICIPANT	\N	PRESENT	1
532076	531286	14169X	PARTICIPANT	\N	PRESENT	1
532077	531286	19701S	PARTICIPANT	\N	PRESENT	1
532078	531286	11066Q	PARTICIPANT	\N	PRESENT	0
532079	531286	14207L	PARTICIPANT	\N	PRESENT	0
532080	531286	16685X	PARTICIPANT	\N	PRESENT	1
532081	531286	19421M	PARTICIPANT	\N	PRESENT	1
532082	531286	01062T	PARTICIPANT	\N	PRESENT	1
532083	531286	11101A	PARTICIPANT	\N	PRESENT	0
532084	531286	14331P	PARTICIPANT	\N	PRESENT	0
532085	531286	04042C	PARTICIPANT	\N	PRESENT	0
532086	531286	14059S	PARTICIPANT	\N	PRESENT	0
532087	531286	11083R	PARTICIPANT	\N	PRESENT	0
532088	531365	14053L	PARTICIPANT	\N	PRESENT	0
532089	531286	19768N	PARTICIPANT	\N	PRESENT	1
532090	531286	14133K	PARTICIPANT	\N	PRESENT	0
532091	531286	19725B	PARTICIPANT	\N	PRESENT	1
532092	531365	19467C	PARTICIPANT	\N	PRESENT	0
532094	531195	14331P	PRESIDENT	0	PRESENT	0
532095	531195	19768N	PARTICIPANT	\N	PRESENT	1
532096	531195	19515S	PARTICIPANT	\N	PRESENT	0
532097	531195	19782L	PARTICIPANT	\N	PRESENT	0
532098	531195	19441R	PARTICIPANT	\N	PRESENT	0
532099	531195	01058X	PARTICIPANT	\N	PRESENT	0
532100	531195	16685X	PARTICIPANT	\N	PRESENT	1
532101	531195	11066Q	PARTICIPANT	\N	PRESENT	0
532102	531195	19421M	PARTICIPANT	\N	PRESENT	1
532103	531195	19347U	PARTICIPANT	\N	PRESENT	0
532105	531195	20018V	PARTICIPANT	\N	PRESENT	0
532106	531195	19521Q	PARTICIPANT	\N	PRESENT	1
532107	531195	08047A	PARTICIPANT	\N	PRESENT	0
532108	531195	20030R	PARTICIPANT	\N	PRESENT	0
532109	531195	14059S	PARTICIPANT	\N	PRESENT	0
532110	531195	04035D	PARTICIPANT	\N	PRESENT	0
532111	531195	20034V	PARTICIPANT	\N	PRESENT	1
532112	531195	04057K	PARTICIPANT	\N	PRESENT	1
532113	531195	14073Q	PARTICIPANT	\N	PRESENT	0
532114	531195	08069G	PARTICIPANT	\N	PRESENT	0
532115	531195	10015M	PARTICIPANT	\N	PRESENT	0
532116	531195	20042V	PARTICIPANT	\N	PRESENT	0
532117	531195	11090Q	PARTICIPANT	\N	PRESENT	0
532118	531195	14089Y	PARTICIPANT	\N	PRESENT	0
532119	531195	20062A	PARTICIPANT	\N	PRESENT	1
532120	531195	14251Q	PARTICIPANT	\N	PRESENT	1
532121	531195	98022P	PARTICIPANT	\N	PRESENT	1
532122	531195	14207L	PARTICIPANT	\N	PRESENT	1
532123	531195	14255U	PARTICIPANT	\N	PRESENT	0
532124	531195	14257W	PARTICIPANT	\N	PRESENT	0
532125	531195	19383Y	PARTICIPANT	\N	PRESENT	0
532126	531195	04070G	PARTICIPANT	\N	PRESENT	0
532127	531195	19701S	PARTICIPANT	\N	PRESENT	1
532128	531195	12041X	PARTICIPANT	\N	PRESENT	1
532129	531195	20092G	PARTICIPANT	\N	PRESENT	0
532130	531195	01043Q	PARTICIPANT	\N	PRESENT	0
532131	531195	19565D	PARTICIPANT	\N	PRESENT	0
532132	531195	14357A	PARTICIPANT	\N	PRESENT	0
532133	531195	04034C	PARTICIPANT	\N	PRESENT	0
532134	531195	14001X	PARTICIPANT	\N	PRESENT	1
532135	531195	19413M	PARTICIPANT	\N	PRESENT	0
517013	502327	11053K	PARTICIPANT	\N	PRESENT	0
517014	502327	19551W	PARTICIPANT	\N	PRESENT	0
517015	502327	14221J	PARTICIPANT	\N	PRESENT	0
517016	502327	19369B	PARTICIPANT	\N	PRESENT	0
517017	502327	14083S	PARTICIPANT	\N	PRESENT	0
517018	502327	20024T	PARTICIPANT	\N	PRESENT	0
517019	502327	14331P	PARTICIPANT	\N	PRESENT	0
517020	502327	11101A	PARTICIPANT	\N	PRESENT	0
517021	502327	19479G	PARTICIPANT	\N	PRESENT	0
517022	502327	20116W	PARTICIPANT	\N	PRESENT	0
517023	502327	11048N	PARTICIPANT	\N	PRESENT	0
517024	502327	14253S	PARTICIPANT	\N	PRESENT	0
517025	502327	01048V	PARTICIPANT	\N	PRESENT	0
517026	502327	14327T	PARTICIPANT	\N	PRESENT	0
517027	502327	14030Q	PARTICIPANT	\N	PRESENT	0
517028	502327	20142Y	PARTICIPANT	\N	PRESENT	0
517029	502327	11110B	PARTICIPANT	\N	PRESENT	0
517030	502327	14225N	PARTICIPANT	\N	PRESENT	0
517031	502327	19647E	PARTICIPANT	\N	PRESENT	0
517032	502327	14089Y	PARTICIPANT	\N	PRESENT	0
517033	502327	19667J	PARTICIPANT	\N	PRESENT	0
517034	502327	99004R	PARTICIPANT	\N	PRESENT	0
517035	502327	19631V	PARTICIPANT	\N	PRESENT	0
517040	513047	14026U	PARTICIPANT	\N	PRESENT	0
517041	513047	01060R	PARTICIPANT	\N	PRESENT	0
517042	513047	19565D	PARTICIPANT	\N	PRESENT	0
517043	513047	04070G	PARTICIPANT	\N	PRESENT	0
517044	513047	20132W	PARTICIPANT	\N	PRESENT	0
517045	513047	19593H	PARTICIPANT	\N	PRESENT	0
517046	513047	20134Y	PARTICIPANT	\N	PRESENT	0
517048	513047	08017T	PARTICIPANT	\N	PRESENT	0
517049	513047	19621T	PARTICIPANT	\N	PRESENT	0
517050	513047	17589D	PARTICIPANT	\N	PRESENT	0
517065	513047	20048C	PARTICIPANT	\N	PRESENT	0
517066	513047	19758L	PARTICIPANT	\N	PRESENT	0
517068	513047	08056B	PARTICIPANT	\N	PRESENT	0
517069	513047	20062A	PARTICIPANT	\N	PRESENT	0
517070	513047	11012A	PARTICIPANT	\N	PRESENT	0
517071	513047	20174H	PARTICIPANT	\N	PRESENT	0
517073	513047	14109K	PARTICIPANT	\N	PRESENT	0
517074	513047	20056C	PARTICIPANT	\N	PRESENT	0
517075	513047	20098N	PARTICIPANT	\N	PRESENT	0
517076	513047	19954N	PARTICIPANT	\N	PRESENT	0
517077	513047	19782L	PARTICIPANT	\N	PRESENT	0
517080	513047	08061X	PARTICIPANT	\N	PRESENT	0
517082	513047	97011G	PARTICIPANT	\N	PRESENT	0
517083	513047	19611R	PARTICIPANT	\N	PRESENT	0
517084	513047	19573D	PARTICIPANT	\N	PRESENT	0
517085	513047	19693L	PARTICIPANT	\N	PRESENT	0
517086	513047	14105F	PARTICIPANT	\N	PRESENT	0
517087	513047	19699S	PARTICIPANT	\N	PRESENT	0
517088	513047	12041X	PARTICIPANT	\N	PRESENT	0
517089	513047	20074E	PARTICIPANT	\N	PRESENT	0
517091	513047	20052X	PARTICIPANT	\N	PRESENT	0
517092	513047	14147R	PARTICIPANT	\N	PRESENT	0
517093	513047	14189C	PARTICIPANT	\N	PRESENT	0
517108	515230	20086J	PARTICIPANT	\N	PRESENT	0
517109	515230	14038Y	PARTICIPANT	\N	PRESENT	0
517110	515230	19515S	PARTICIPANT	\N	PRESENT	1
517111	515230	20092G	PARTICIPANT	\N	PRESENT	0
517112	515230	19782L	PARTICIPANT	\N	PRESENT	0
517113	515230	20078J	PARTICIPANT	\N	PRESENT	1
517114	515230	20082E	PARTICIPANT	\N	PRESENT	1
517115	515230	14033T	PARTICIPANT	\N	PRESENT	0
517116	515230	01025N	PARTICIPANT	\N	PRESENT	0
517117	515230	20094J	PARTICIPANT	\N	PRESENT	0
517118	515230	11090Q	PRESIDENT	0	PRESENT	0
517119	515230	19631V	PARTICIPANT	\N	PRESENT	1
517120	515230	20174H	PARTICIPANT	\N	PRESENT	0
517121	515230	14205J	PARTICIPANT	\N	PRESENT	0
517122	515230	20060X	PARTICIPANT	\N	PRESENT	0
517123	515230	19507S	PARTICIPANT	\N	PRESENT	0
517124	515230	08015R	PARTICIPANT	\N	PRESENT	0
517125	515230	19369B	PARTICIPANT	\N	PRESENT	0
517126	515230	20018V	PARTICIPANT	\N	PRESENT	0
517127	515230	14207L	PARTICIPANT	\N	PRESENT	0
517128	515230	19511N	PARTICIPANT	\N	PRESENT	0
517129	515230	14257W	PARTICIPANT	\N	PRESENT	0
517130	513047	01058X	PARTICIPANT	\N	PRESENT	0
517131	515230	19563B	PARTICIPANT	\N	PRESENT	1
517132	513047	14133K	PARTICIPANT	\N	PRESENT	0
517133	515230	14187A	PARTICIPANT	\N	PRESENT	0
517149	513047	04057K	PARTICIPANT	\N	PRESENT	0
517150	513047	20138D	PARTICIPANT	\N	PRESENT	0
517151	513047	14229S	PARTICIPANT	\N	PRESENT	0
517152	513047	14331P	PARTICIPANT	\N	PRESENT	0
517153	513047	20026V	PARTICIPANT	\N	PRESENT	0
517154	513047	20046A	PARTICIPANT	\N	PRESENT	0
517155	513047	19723Y	PARTICIPANT	\N	PRESENT	0
517156	515230	19768N	PARTICIPANT	\N	PRESENT	1
517157	513047	14073Q	PARTICIPANT	\N	PRESENT	0
517175	513047	19347U	PARTICIPANT	\N	PRESENT	0
517176	513047	19441R	PARTICIPANT	\N	PRESENT	0
517177	513047	18083K	PARTICIPANT	\N	PRESENT	0
517181	515230	11099A	PARTICIPANT	\N	PRESENT	1
517232	513048	12041X	PARTICIPANT	\N	PRESENT	0
517233	513048	19725B	PARTICIPANT	\N	PRESENT	0
517234	513048	14331P	PARTICIPANT	\N	PRESENT	0
517235	513048	20134Y	PARTICIPANT	\N	PRESENT	0
517236	513048	19347U	PARTICIPANT	\N	PRESENT	0
517237	513048	20100N	PARTICIPANT	\N	PRESENT	0
517238	513048	11083R	PARTICIPANT	\N	PRESENT	0
517239	513048	08061X	PARTICIPANT	\N	PRESENT	0
517240	513048	17589D	PARTICIPANT	\N	PRESENT	0
517241	513048	04057K	PARTICIPANT	\N	PRESENT	0
517242	513048	19553Y	PARTICIPANT	\N	PRESENT	0
517243	513048	19441R	PARTICIPANT	\N	PRESENT	0
517244	513048	14073Q	PARTICIPANT	\N	PRESENT	0
517245	513048	14030Q	PARTICIPANT	\N	PRESENT	0
517246	513048	95063L	PARTICIPANT	\N	PRESENT	0
517247	513048	14229S	PARTICIPANT	\N	PRESENT	0
517248	513048	14189C	PARTICIPANT	\N	PRESENT	0
517249	513048	19421M	PARTICIPANT	\N	PRESENT	0
517250	513048	01058X	PARTICIPANT	\N	PRESENT	0
517251	513048	20024T	PARTICIPANT	\N	PRESENT	0
517252	513048	14147R	PARTICIPANT	\N	PRESENT	0
517253	513048	11043H	PARTICIPANT	\N	PRESENT	0
517254	513048	20056C	PARTICIPANT	\N	PRESENT	0
517255	513048	20026V	PARTICIPANT	\N	PRESENT	0
517256	513048	20074E	PARTICIPANT	\N	PRESENT	0
517257	513048	14219Q	PARTICIPANT	\N	PRESENT	0
517258	513048	11103C	PARTICIPANT	\N	PRESENT	0
517259	513048	19723Y	PARTICIPANT	\N	PRESENT	0
517260	513048	19711U	PARTICIPANT	\N	PRESENT	0
517271	513048	20124W	PARTICIPANT	\N	PRESENT	0
517262	513048	11048N	PARTICIPANT	\N	PRESENT	0
517263	513048	19701S	PARTICIPANT	\N	PRESENT	0
517265	513048	14133K	PARTICIPANT	\N	PRESENT	0
517274	513048	01048V	PARTICIPANT	\N	PRESENT	0
517275	513048	19251M	PARTICIPANT	\N	PRESENT	0
517276	513048	19533U	PARTICIPANT	\N	PRESENT	0
517277	513048	08056B	PARTICIPANT	\N	PRESENT	0
517278	513048	11012A	PARTICIPANT	\N	PRESENT	0
517279	513048	11026G	PARTICIPANT	\N	PRESENT	0
517280	513048	19739H	PARTICIPANT	\N	PRESENT	0
517281	513048	97011G	PARTICIPANT	\N	PRESENT	0
517282	513048	14357A	PARTICIPANT	\N	PRESENT	0
517283	513048	14031R	PARTICIPANT	\N	PRESENT	0
517284	513048	14259Y	PARTICIPANT	\N	PRESENT	0
517285	513048	01024M	PARTICIPANT	\N	PRESENT	0
517289	513048	04070G	PARTICIPANT	\N	PRESENT	0
517290	513048	01060R	PARTICIPANT	\N	PRESENT	0
517292	513048	20038A	PARTICIPANT	\N	PRESENT	0
517230	513048	14026U	PARTICIPANT	\N	PRESENT	0
517231	513048	19758L	PARTICIPANT	\N	PRESENT	0
517293	513048	19507S	PARTICIPANT	\N	PRESENT	0
517294	513048	20058E	PARTICIPANT	\N	PRESENT	0
517295	513048	14205J	PARTICIPANT	\N	PRESENT	0
517296	513048	14069U	PARTICIPANT	\N	PRESENT	0
517297	513048	19599P	PARTICIPANT	\N	PRESENT	0
517298	513048	14083S	PARTICIPANT	\N	PRESENT	0
517299	513048	11053K	PARTICIPANT	\N	PRESENT	0
517300	513048	19741B	PARTICIPANT	\N	PRESENT	0
517301	513048	20130U	PARTICIPANT	\N	PRESENT	0
517302	513048	19479G	PARTICIPANT	\N	PRESENT	0
517303	513048	14231L	PARTICIPANT	\N	PRESENT	0
517304	513048	20172F	PARTICIPANT	\N	PRESENT	0
517305	513048	19569H	PARTICIPANT	\N	PRESENT	0
517306	513048	14217N	PARTICIPANT	\N	PRESENT	0
517307	513048	14033T	PARTICIPANT	\N	PRESENT	0
517308	513048	19333N	PARTICIPANT	\N	PRESENT	0
536030	536029	14189C	PARTICIPANT	\N	PRESENT	0
536031	536029	20024T	PARTICIPANT	\N	PRESENT	0
536032	536029	14357A	PARTICIPANT	\N	PRESENT	0
536033	536029	97011G	PARTICIPANT	\N	PRESENT	0
536034	536029	19333N	PARTICIPANT	\N	PRESENT	0
536035	536029	14147R	PARTICIPANT	\N	PRESENT	0
536036	536029	14223L	PARTICIPANT	\N	PRESENT	0
536037	536029	11041F	PARTICIPANT	\N	PRESENT	0
537073	537071	05008E	PARTICIPANT	\N	PRESENT	0
537074	537071	11053K	PARTICIPANT	\N	PRESENT	0
537075	537071	01028R	PARTICIPANT	\N	PRESENT	0
539584	539583	14069U	PARTICIPANT	\N	PRESENT	0
539585	539583	11072N	PARTICIPANT	\N	PRESENT	0
539587	535603	05008E	PARTICIPANT	\N	EXCUSE	0
539589	539588	05008E	PARTICIPANT	\N	EXCUSE	0
539868	539548	20134Y	PARTICIPANT	\N	PRESENT	0
539869	539548	01060R	PARTICIPANT	\N	PRESENT	0
539870	539548	20126Y	PARTICIPANT	\N	PRESENT	0
539871	539548	19782L	PARTICIPANT	\N	PRESENT	0
539872	539548	20116W	PARTICIPANT	\N	PRESENT	0
539873	539548	11083R	PARTICIPANT	\N	PRESENT	0
539874	539548	14133K	PARTICIPANT	\N	PRESENT	0
539875	539548	19599P	PARTICIPANT	\N	PRESENT	0
539876	539548	19543W	PARTICIPANT	\N	PRESENT	0
539877	539548	14189C	PARTICIPANT	\N	PRESENT	0
539878	539548	20072C	PARTICIPANT	\N	PRESENT	0
539879	539548	14038Y	PARTICIPANT	\N	PRESENT	0
539880	539548	11012A	PARTICIPANT	\N	PRESENT	0
539881	539548	20064C	PARTICIPANT	\N	PRESENT	0
539882	539548	19739H	PARTICIPANT	\N	PRESENT	0
539886	539548	19719D	PARTICIPANT	\N	PRESENT	0
539884	539548	01025N	PARTICIPANT	\N	PRESENT	0
539885	539548	14097Y	PARTICIPANT	\N	PRESENT	0
539887	539548	20142Y	PARTICIPANT	\N	PRESENT	0
539888	539548	19689Q	PARTICIPANT	\N	PRESENT	0
539889	539548	20138D	PARTICIPANT	\N	PRESENT	0
539890	539548	20108W	PARTICIPANT	\N	PRESENT	0
539891	539548	20088L	PARTICIPANT	\N	PRESENT	0
539892	539548	19725B	PARTICIPANT	\N	PRESENT	0
539893	539548	19703U	PARTICIPANT	\N	PRESENT	0
539894	539548	19697Q	PARTICIPANT	\N	PRESENT	0
539895	539548	14055N	PARTICIPANT	\N	PRESENT	0
539897	539896	20102Q	PARTICIPANT	\N	PRESENT	0
539898	539548	01034P	PARTICIPANT	\N	PRESENT	0
539899	539548	20114U	PARTICIPANT	\N	PRESENT	0
539900	539548	14267Y	PARTICIPANT	\N	PRESENT	0
539901	539548	20028X	PARTICIPANT	\N	PRESENT	0
539902	539548	20058E	PARTICIPANT	\N	PRESENT	0
539903	539548	18083K	PARTICIPANT	\N	PRESENT	0
539904	539548	11048N	PARTICIPANT	\N	PRESENT	0
539906	539548	14042U	PARTICIPANT	\N	PRESENT	0
539907	539548	12041X	PARTICIPANT	\N	PRESENT	0
539908	539548	14001X	PARTICIPANT	\N	PRESENT	0
539909	539548	19533U	PARTICIPANT	\N	PRESENT	0
539910	539548	11053K	PARTICIPANT	\N	PRESENT	0
539912	539911	05008E	PARTICIPANT	\N	PRESENT	0
539913	539911	11053K	PARTICIPANT	\N	PRESENT	0
539914	539911	01028R	PARTICIPANT	\N	PRESENT	0
539915	539548	17737W	PARTICIPANT	\N	PRESENT	0
539916	539548	20104S	PARTICIPANT	\N	PRESENT	0
539917	539548	20136B	PARTICIPANT	\N	PRESENT	0
539918	539548	20034V	PARTICIPANT	\N	PRESENT	0
539919	539548	19467C	PARTICIPANT	\N	PRESENT	0
539920	539548	20022R	PARTICIPANT	\N	PRESENT	0
539921	539548	19575F	PARTICIPANT	\N	PRESENT	0
539922	539548	19335Q	PARTICIPANT	\N	PRESENT	0
539923	539548	11104D	PARTICIPANT	\N	PRESENT	0
539924	539548	14083S	PARTICIPANT	\N	PRESENT	0
539925	539548	19701S	PARTICIPANT	\N	PRESENT	0
539926	539548	14331P	PARTICIPANT	\N	PRESENT	0
539927	539548	14059S	PARTICIPANT	\N	PRESENT	0
539928	539548	14229S	PARTICIPANT	\N	PRESENT	0
539929	539548	01028R	PARTICIPANT	\N	PRESENT	0
539930	539548	14123H	PARTICIPANT	\N	PRESENT	0
539931	539548	19563B	PARTICIPANT	\N	PRESENT	0
539932	539548	14249W	PARTICIPANT	\N	PRESENT	0
539933	539548	19699S	PARTICIPANT	\N	PRESENT	0
539934	539548	11043H	PARTICIPANT	\N	PRESENT	0
539935	539548	14053L	PARTICIPANT	\N	PRESENT	0
539947	530857	14073Q	PARTICIPANT	\N	PRESENT	0
539937	539548	19683J	PARTICIPANT	\N	PRESENT	0
539938	539548	19441R	PARTICIPANT	\N	PRESENT	0
539939	539548	14213J	PARTICIPANT	\N	PRESENT	0
539940	539548	08015R	PARTICIPANT	\N	PRESENT	0
539941	539548	20048C	PARTICIPANT	\N	PRESENT	0
539942	539548	20052X	PARTICIPANT	\N	PRESENT	0
539944	539943	20092G	PARTICIPANT	\N	PRESENT	0
539945	539943	20102Q	PARTICIPANT	\N	PRESENT	0
539946	539943	19619A	PARTICIPANT	\N	PRESENT	0
539948	530857	19399H	PARTICIPANT	\N	PRESENT	0
539949	530857	19621T	PARTICIPANT	\N	PRESENT	0
539950	530857	19593H	PARTICIPANT	\N	PRESENT	0
539951	530857	19699S	PARTICIPANT	\N	PRESENT	0
539952	530857	19533U	PARTICIPANT	\N	PRESENT	0
539953	530857	20152B	PARTICIPANT	\N	PRESENT	0
539954	530857	20142Y	PARTICIPANT	\N	PRESENT	0
539955	539943	19739H	PARTICIPANT	\N	PRESENT	0
539956	539548	20086J	PARTICIPANT	\N	PRESENT	0
539957	539943	19503N	PARTICIPANT	\N	PRESENT	0
539958	539943	19820Y	PARTICIPANT	\N	PRESENT	1
539959	539548	11070L	PARTICIPANT	\N	PRESENT	0
539960	539586	20130U	PARTICIPANT	\N	PRESENT	0
539961	539586	14187A	PARTICIPANT	\N	PRESENT	0
539962	539586	19679N	PARTICIPANT	\N	PRESENT	0
539963	539586	20040T	PARTICIPANT	\N	PRESENT	0
539964	539586	11053K	PARTICIPANT	\N	PRESENT	0
539965	539586	18193Q	PARTICIPANT	\N	PRESENT	0
539966	539063	11048N	PARTICIPANT	\N	PRESENT	0
539967	539063	19647E	PARTICIPANT	\N	PRESENT	0
539968	539063	14189C	PARTICIPANT	\N	PRESENT	0
539969	539063	08034U	PARTICIPANT	\N	PRESENT	0
539970	539063	20080C	PARTICIPANT	\N	PRESENT	0
539971	539063	19667J	PARTICIPANT	\N	PRESENT	0
539972	539063	08011M	PARTICIPANT	\N	PRESENT	0
539973	539063	04086Q	PARTICIPANT	\N	PRESENT	0
539974	539063	14083S	PARTICIPANT	\N	PRESENT	0
539975	539063	11012A	PARTICIPANT	\N	PRESENT	0
539976	539063	19335Q	PARTICIPANT	\N	PRESENT	0
539977	539063	20022R	PARTICIPANT	\N	PRESENT	0
539978	539063	19762G	PARTICIPANT	\N	PRESENT	0
539979	539943	20050V	PARTICIPANT	\N	PRESENT	0
539980	539943	20054A	PARTICIPANT	\N	PRESENT	0
539981	539943	20126Y	PARTICIPANT	\N	PRESENT	0
539982	539943	20032T	PARTICIPANT	\N	PRESENT	0
539983	530857	19611R	PRESIDENT	0	PRESENT	0
539984	530857	04033B	PARTICIPANT	\N	PRESENT	0
539985	530857	19693L	PARTICIPANT	\N	PRESENT	0
539986	530857	14229S	PARTICIPANT	\N	PRESENT	0
539987	530857	14030Q	PARTICIPANT	\N	PRESENT	0
539988	530857	20056C	PARTICIPANT	\N	PRESENT	0
539989	530857	20180F	PARTICIPANT	\N	PRESENT	0
539990	530857	08061X	PARTICIPANT	\N	PRESENT	0
539991	530857	08012N	PARTICIPANT	\N	PRESENT	0
539992	530857	11104D	PARTICIPANT	\N	PRESENT	0
539993	530857	11043H	PARTICIPANT	\N	PRESENT	0
539994	530857	20124W	PARTICIPANT	\N	PRESENT	0
539995	530857	19758L	PARTICIPANT	\N	PRESENT	0
539996	530857	20026V	PARTICIPANT	\N	PRESENT	0
539997	539943	19711U	PARTICIPANT	\N	PRESENT	0
539998	539548	05012A	PARTICIPANT	\N	PRESENT	0
539999	539063	14331P	PARTICIPANT	\N	PRESENT	0
540000	539063	19545Y	PARTICIPANT	\N	PRESENT	0
540001	539063	01057W	PARTICIPANT	\N	PRESENT	0
540002	539063	19687N	PARTICIPANT	\N	PRESENT	0
540003	539063	20044X	PARTICIPANT	\N	PRESENT	0
540004	539063	11040E	PARTICIPANT	\N	PRESENT	0
540005	530857	19573D	PARTICIPANT	\N	PRESENT	0
540006	530857	20132W	PARTICIPANT	\N	PRESENT	0
540007	530857	04059M	PARTICIPANT	\N	PRESENT	0
540008	530857	14123H	PARTICIPANT	\N	PRESENT	0
540009	539548	11097X	PARTICIPANT	\N	PRESENT	0
540010	530857	20058E	PARTICIPANT	\N	PRESENT	0
540011	539943	19782L	PARTICIPANT	\N	PRESENT	0
540012	539943	20144B	PARTICIPANT	\N	PRESENT	0
540013	539943	17229F	PARTICIPANT	\N	PRESENT	0
540014	530857	19735D	PARTICIPANT	\N	PRESENT	0
540015	539943	14033T	PARTICIPANT	\N	PRESENT	0
540016	539063	19741B	PARTICIPANT	\N	PRESENT	0
540017	539063	07029T	PARTICIPANT	\N	EXCUSE	0
540018	539063	14225N	PRESIDENT	0	PRESENT	0
540019	539063	08010L	PARTICIPANT	\N	PRESENT	0
518433	517779	17023S	PARTICIPANT	\N	PRESENT	0
521241	518930	20104S	PARTICIPANT	\N	PRESENT	1
521242	518930	11101A	PARTICIPANT	\N	PRESENT	0
521243	518930	11083R	PARTICIPANT	\N	PRESENT	0
521244	518930	19725B	PARTICIPANT	\N	PRESENT	1
521245	518930	20128B	PARTICIPANT	\N	PRESENT	1
521246	518930	19531S	PARTICIPANT	\N	PRESENT	0
521247	518930	14097Y	PARTICIPANT	\N	PRESENT	1
521248	518930	12041X	PARTICIPANT	\N	PRESENT	0
521249	518930	08034U	PARTICIPANT	\N	EXCUSE	0
522550	521420	19525U	PARTICIPANT	\N	PRESENT	1
521251	518930	04070G	PARTICIPANT	\N	PRESENT	1
521252	518930	14237S	PARTICIPANT	\N	PRESENT	0
521253	518930	14331P	PARTICIPANT	\N	PRESENT	0
521254	518930	10015M	PARTICIPANT	\N	PRESENT	0
521255	518930	11026G	PARTICIPANT	\N	PRESENT	0
521256	518930	14073Q	PARTICIPANT	\N	PRESENT	0
522588	522587	20076G	PARTICIPANT	\N	PRESENT	0
522589	522587	20110Q	PARTICIPANT	\N	PRESENT	0
522590	522587	14038Y	PARTICIPANT	\N	PRESENT	0
522592	522587	14033T	PARTICIPANT	\N	PRESENT	0
522594	522587	19725B	PARTICIPANT	\N	PRESENT	0
522596	522587	19551W	PARTICIPANT	\N	PRESENT	0
522598	522587	19723Y	PARTICIPANT	\N	PRESENT	0
522600	522587	19563B	PARTICIPANT	\N	PRESENT	0
522603	522587	20028X	PARTICIPANT	\N	PRESENT	0
522608	522587	20082E	PARTICIPANT	\N	PRESENT	0
522610	522587	04045F	PARTICIPANT	\N	PRESENT	0
522613	522587	19713W	PARTICIPANT	\N	PRESENT	0
522614	522587	20062A	PARTICIPANT	\N	PRESENT	0
522615	522587	20058E	PARTICIPANT	\N	PRESENT	0
522781	521481	11053K	PARTICIPANT	\N	PRESENT	0
522782	521481	08011M	PARTICIPANT	\N	PRESENT	0
522783	521481	19415P	PARTICIPANT	\N	PRESENT	0
522784	521481	20038A	PARTICIPANT	\N	PRESENT	0
522785	521481	11101A	PARTICIPANT	\N	PRESENT	0
522786	521481	04071H	PARTICIPANT	\N	PRESENT	0
522787	521481	14237S	PARTICIPANT	\N	PRESENT	0
522788	521481	20130U	PARTICIPANT	\N	PRESENT	0
522789	521481	19479G	PARTICIPANT	\N	PRESENT	0
522790	521481	20070A	PARTICIPANT	\N	PRESENT	0
522791	521481	01060R	PARTICIPANT	\N	PRESENT	0
522792	521481	19685L	PARTICIPANT	\N	PRESENT	0
522793	521481	19683J	PARTICIPANT	\N	PRESENT	0
522794	521481	11064N	PARTICIPANT	\N	PRESENT	0
522798	521481	14329V	PARTICIPANT	\N	PRESENT	0
522800	521481	08056B	PARTICIPANT	\N	PRESENT	0
522809	521481	86034E	PARTICIPANT	\N	PRESENT	0
522839	521481	19533U	PARTICIPANT	\N	PRESENT	0
522840	521481	19675J	PARTICIPANT	\N	PRESENT	0
522841	521481	19679N	PARTICIPANT	\N	PRESENT	0
522842	521481	14042U	PARTICIPANT	\N	PRESENT	0
522843	521481	20034V	PARTICIPANT	\N	PRESENT	0
522853	521481	20104S	PARTICIPANT	\N	PRESENT	0
522849	521481	04045F	PARTICIPANT	\N	PRESENT	0
522850	521481	19741B	PARTICIPANT	\N	PRESENT	0
522854	521481	20138D	PARTICIPANT	\N	PRESENT	0
522855	521481	14031R	PARTICIPANT	\N	PRESENT	0
522856	521481	19768N	PARTICIPANT	\N	PRESENT	0
522857	521481	08047A	PARTICIPANT	\N	PRESENT	0
522858	521481	19447X	PARTICIPANT	\N	PRESENT	0
522859	521481	20076G	PARTICIPANT	\N	PRESENT	0
522860	521481	20086J	PARTICIPANT	\N	PRESENT	0
522861	521481	14189C	PARTICIPANT	\N	PRESENT	0
523079	521476	14026U	PARTICIPANT	\N	PRESENT	0
523080	521476	11045K	PARTICIPANT	\N	PRESENT	0
523081	521476	19723Y	PARTICIPANT	\N	PRESENT	0
523082	521476	04057K	PARTICIPANT	\N	PRESENT	0
523083	521476	20130U	PARTICIPANT	\N	PRESENT	0
523084	521476	19591F	PARTICIPANT	\N	PRESENT	0
523085	521476	19717B	PARTICIPANT	\N	PRESENT	0
523086	521476	11031D	PARTICIPANT	\N	PRESENT	0
523087	521476	20074E	PARTICIPANT	\N	PRESENT	0
523088	521476	14042U	PARTICIPANT	\N	PRESENT	0
523089	521476	19798U	PARTICIPANT	\N	PRESENT	0
523090	521476	14055N	PARTICIPANT	\N	PRESENT	0
523091	521476	17965H	PARTICIPANT	\N	PRESENT	0
523092	521476	11080N	PARTICIPANT	\N	PRESENT	0
523093	521575	14038Y	PARTICIPANT	\N	PRESENT	0
523094	521575	19768N	PARTICIPANT	\N	PRESENT	1
523095	521575	19515S	PARTICIPANT	\N	PRESENT	0
523096	521575	20034V	PARTICIPANT	\N	PRESENT	0
523097	521575	14187A	PARTICIPANT	\N	PRESENT	0
523098	521575	14033T	PARTICIPANT	\N	PRESENT	0
523099	521575	11090Q	PRESIDENT	0	PRESENT	0
523100	521575	04045F	PARTICIPANT	\N	PRESENT	0
523101	521575	20054A	PARTICIPANT	\N	PRESENT	1
523102	521575	19631V	PARTICIPANT	\N	PRESENT	0
523103	521575	14205J	PARTICIPANT	\N	PRESENT	0
523104	521575	20060X	PARTICIPANT	\N	PRESENT	0
523105	521575	20062A	PARTICIPANT	\N	PRESENT	0
523106	521575	14251Q	PARTICIPANT	\N	PRESENT	0
523107	521575	19507S	PARTICIPANT	\N	PRESENT	0
523108	521575	14207L	PARTICIPANT	\N	PRESENT	0
523109	521575	14257W	PARTICIPANT	\N	PRESENT	0
523110	521476	19683J	PARTICIPANT	\N	PRESENT	0
523111	521476	20106U	PARTICIPANT	\N	PRESENT	0
523112	521476	14041T	PARTICIPANT	\N	PRESENT	0
523113	521476	17779H	PARTICIPANT	\N	PRESENT	0
523152	521476	19691J	PARTICIPANT	\N	PRESENT	0
523115	521476	19820Y	PARTICIPANT	\N	PRESENT	0
523116	521476	20172F	PARTICIPANT	\N	PRESENT	0
523117	521476	19333N	PARTICIPANT	\N	PRESENT	0
523118	521476	19599P	PARTICIPANT	\N	PRESENT	0
523119	521476	10006L	PARTICIPANT	\N	PRESENT	0
523145	521476	20134Y	PARTICIPANT	\N	PRESENT	0
523121	521476	18193Q	PARTICIPANT	\N	PRESENT	0
523122	521476	19545Y	PARTICIPANT	\N	PRESENT	0
523123	521476	14195A	PARTICIPANT	\N	PRESENT	0
523124	521476	14189C	PARTICIPANT	\N	PRESENT	0
523125	521476	20066E	PARTICIPANT	\N	PRESENT	0
523126	521476	19954N	PARTICIPANT	\N	PRESENT	0
523127	521476	19533U	PARTICIPANT	\N	PRESENT	0
523128	521476	11012A	PARTICIPANT	\N	PRESENT	0
523129	521476	19671E	PARTICIPANT	\N	PRESENT	0
523131	521476	19651A	PARTICIPANT	\N	PRESENT	0
523133	521476	19569H	PARTICIPANT	\N	PRESENT	0
523134	521476	11097X	PARTICIPANT	\N	PRESENT	0
523135	521476	20024T	PARTICIPANT	\N	PRESENT	0
523136	521476	14213J	PARTICIPANT	\N	PRESENT	0
523137	521476	11033F	PARTICIPANT	\N	PRESENT	0
523138	521476	20110Q	PARTICIPANT	\N	PRESENT	0
523139	521476	19629C	PARTICIPANT	\N	PRESENT	0
523140	521476	20132W	PARTICIPANT	\N	PRESENT	0
523141	521476	20116W	PARTICIPANT	\N	PRESENT	0
523142	521476	14021P	PARTICIPANT	\N	PRESENT	0
523143	521476	14109K	PARTICIPANT	\N	PRESENT	0
523144	521476	20070A	PARTICIPANT	\N	PRESENT	0
523146	521476	14001X	PARTICIPANT	\N	PRESENT	0
523147	521476	19415P	PARTICIPANT	\N	PRESENT	0
523148	521476	20114U	PARTICIPANT	\N	PRESENT	0
523149	521476	19866P	PARTICIPANT	\N	PRESENT	0
523150	521476	19697Q	PARTICIPANT	\N	PRESENT	0
523151	521476	14073Q	PARTICIPANT	\N	PRESENT	0
523153	521476	20138D	PARTICIPANT	\N	PRESENT	0
523154	521476	14071N	PARTICIPANT	\N	PRESENT	0
523155	521476	19760E	PARTICIPANT	\N	PRESENT	0
523156	521476	04043D	PARTICIPANT	\N	PRESENT	0
523157	521476	19693L	PARTICIPANT	\N	PRESENT	0
523158	521476	14053L	PARTICIPANT	\N	PRESENT	0
523159	521476	19565D	PARTICIPANT	\N	PRESENT	0
523160	521476	19489J	PARTICIPANT	\N	PRESENT	0
523161	521476	04092N	PARTICIPANT	\N	PRESENT	0
523162	521476	19703U	PARTICIPANT	\N	PRESENT	0
523163	521476	19758L	PARTICIPANT	\N	PRESENT	0
523164	521476	08017T	PARTICIPANT	\N	PRESENT	0
523165	521476	20142Y	PARTICIPANT	\N	PRESENT	0
523166	521235	04086Q	PARTICIPANT	\N	PRESENT	0
523167	521235	14083S	PARTICIPANT	\N	PRESENT	0
523168	521235	11048N	PARTICIPANT	\N	PRESENT	0
523169	521235	19479G	PARTICIPANT	\N	PRESENT	0
523170	521235	20080C	PARTICIPANT	\N	PRESENT	0
523171	521235	19349W	PARTICIPANT	\N	PRESENT	0
523172	521235	11074Q	PARTICIPANT	\N	PRESENT	0
523173	521235	20044X	PARTICIPANT	\N	PRESENT	0
523174	521235	14225N	PRESIDENT	0	PRESENT	0
523175	521235	20126Y	PARTICIPANT	\N	PRESENT	0
523176	521235	14229S	PARTICIPANT	\N	PRESENT	0
523177	521235	19711U	PARTICIPANT	\N	PRESENT	0
523178	521235	11053K	PARTICIPANT	\N	PRESENT	0
523179	521235	07029T	PARTICIPANT	\N	EXCUSE	0
532136	531195	04042C	PARTICIPANT	\N	PRESENT	0
532137	531195	20094J	PARTICIPANT	\N	PRESENT	1
532138	531195	14026U	PARTICIPANT	\N	PRESENT	0
532139	531195	20100N	PARTICIPANT	\N	PRESENT	0
532140	531195	19575F	PARTICIPANT	\N	PRESENT	0
532141	531195	19563B	PARTICIPANT	\N	PRESENT	0
532142	531195	08028W	PARTICIPANT	\N	PRESENT	0
532143	531195	20128B	PARTICIPANT	\N	PRESENT	0
532144	531195	14097Y	PARTICIPANT	\N	PRESENT	1
532145	531195	19467C	PARTICIPANT	\N	PRESENT	0
532146	531195	14133K	PARTICIPANT	\N	PRESENT	0
532147	531195	08034U	PARTICIPANT	\N	PRESENT	0
532148	531195	19531S	PARTICIPANT	\N	PRESENT	1
532149	531195	01062T	PARTICIPANT	\N	PRESENT	0
532150	531195	11026G	PARTICIPANT	\N	PRESENT	0
532151	531195	19251M	PARTICIPANT	\N	PRESENT	0
532152	531195	14033T	PARTICIPANT	\N	PRESENT	0
532153	531195	14169X	PARTICIPANT	\N	PRESENT	1
532154	531195	20174H	PARTICIPANT	\N	PRESENT	1
532155	531195	19725B	PARTICIPANT	\N	PRESENT	1
532156	531195	14205J	PARTICIPANT	\N	PRESENT	0
532157	531195	11101A	PARTICIPANT	\N	PRESENT	0
532158	531195	11083R	PARTICIPANT	\N	PRESENT	0
532159	531195	19747H	PARTICIPANT	\N	PRESENT	0
532160	531195	14237S	PARTICIPANT	\N	EXCUSE	0
532209	531372	95063L	PARTICIPANT	\N	PRESENT	0
532210	531372	19866P	PARTICIPANT	\N	PRESENT	0
532211	531372	19629C	PARTICIPANT	\N	PRESENT	0
532212	531372	19349W	PARTICIPANT	\N	PRESENT	0
532213	531372	11056N	PARTICIPANT	\N	PRESENT	0
532214	531372	14105F	PARTICIPANT	\N	PRESENT	0
532215	531372	20090E	PARTICIPANT	\N	PRESENT	0
532216	531372	14147R	PARTICIPANT	\N	PRESENT	0
532217	531372	19447X	PARTICIPANT	\N	PRESENT	0
532218	531372	19651A	PARTICIPANT	\N	PRESENT	0
532219	531372	11033F	PARTICIPANT	\N	PRESENT	0
532220	531372	19565D	PARTICIPANT	\N	PRESENT	0
532221	531372	20074E	PARTICIPANT	\N	PRESENT	0
532222	531372	14111D	PARTICIPANT	\N	PRESENT	0
532223	531372	19489J	PARTICIPANT	\N	PRESENT	0
532224	531372	01060R	PARTICIPANT	\N	PRESENT	0
532225	531372	14215L	PARTICIPANT	\N	PRESENT	0
532226	531372	19399H	PARTICIPANT	\N	PRESENT	0
532227	531372	14053L	PARTICIPANT	\N	PRESENT	0
532228	531372	20110Q	PARTICIPANT	\N	PRESENT	0
532229	531372	04047H	PARTICIPANT	\N	PRESENT	0
532230	531372	19443T	PARTICIPANT	\N	PRESENT	0
532231	531372	20134Y	PARTICIPANT	\N	PRESENT	0
532232	531372	11072N	PARTICIPANT	\N	PRESENT	0
532233	531372	19543W	PARTICIPANT	\N	PRESENT	0
532234	531372	20100N	PARTICIPANT	\N	PRESENT	0
532235	531372	14231L	PARTICIPANT	\N	PRESENT	0
532236	531372	19347U	PARTICIPANT	\N	PRESENT	0
532237	531372	20054A	PARTICIPANT	\N	PRESENT	0
532238	531372	19551W	PARTICIPANT	\N	PRESENT	0
532239	531372	01028R	PARTICIPANT	\N	PRESENT	0
532240	531372	20068G	PARTICIPANT	\N	PRESENT	0
532241	531372	19749K	PARTICIPANT	\N	PRESENT	0
532242	531372	20070A	PARTICIPANT	\N	PRESENT	0
532243	531372	14033T	PARTICIPANT	\N	PRESENT	0
532244	531372	07029T	PARTICIPANT	\N	PRESENT	0
532285	531373	19749K	PARTICIPANT	\N	PRESENT	0
532286	531373	01028R	PARTICIPANT	\N	PRESENT	0
532287	531373	14111D	PARTICIPANT	\N	PRESENT	0
532288	531373	11033F	PARTICIPANT	\N	PRESENT	0
532289	531373	11072N	PARTICIPANT	\N	PRESENT	0
532290	531373	95063L	PARTICIPANT	\N	PRESENT	0
532291	531373	19629C	PARTICIPANT	\N	PRESENT	0
532292	531373	11056N	PARTICIPANT	\N	PRESENT	0
532293	531373	19399H	PARTICIPANT	\N	PRESENT	0
532294	531373	20134Y	PARTICIPANT	\N	PRESENT	0
532207	531372	01043Q	PARTICIPANT	\N	PRESENT	0
532208	531372	05008E	PARTICIPANT	\N	PRESENT	0
532295	531373	20110Q	PARTICIPANT	\N	PRESENT	0
532296	531373	19651A	PARTICIPANT	\N	PRESENT	0
532297	531373	19866P	PARTICIPANT	\N	PRESENT	0
532298	531373	20070A	PARTICIPANT	\N	PRESENT	0
532299	531373	19489J	PARTICIPANT	\N	PRESENT	0
532300	531373	04047H	PARTICIPANT	\N	PRESENT	0
532301	531373	14021P	PARTICIPANT	\N	PRESENT	0
532302	531373	14231L	PARTICIPANT	\N	PRESENT	0
532303	531373	14215L	PARTICIPANT	\N	PRESENT	0
532304	531373	19347U	PARTICIPANT	\N	PRESENT	0
532305	531373	20068G	PARTICIPANT	\N	PRESENT	0
532306	531373	07029T	PARTICIPANT	\N	PRESENT	0
532307	531373	14033T	PARTICIPANT	\N	PRESENT	0
532308	531373	14147R	PARTICIPANT	\N	PRESENT	0
532309	531373	19443T	PARTICIPANT	\N	PRESENT	0
532310	531373	19447X	PARTICIPANT	\N	PRESENT	0
532311	531373	19565D	PARTICIPANT	\N	PRESENT	0
532312	531373	14213J	PARTICIPANT	\N	PRESENT	0
532448	531287	20092G	PARTICIPANT	\N	PRESENT	0
532449	531287	01025N	PARTICIPANT	\N	PRESENT	0
532450	531317	10015M	PARTICIPANT	\N	PRESENT	0
532451	531317	01028R	PARTICIPANT	\N	PRESENT	0
532452	531317	19447X	PARTICIPANT	\N	PRESENT	0
532453	531317	11056N	PARTICIPANT	\N	PRESENT	0
532454	531317	95063L	PARTICIPANT	\N	PRESENT	0
532455	531317	20110Q	PARTICIPANT	\N	PRESENT	0
532456	531317	14147R	PARTICIPANT	\N	PRESENT	0
532461	531317	14259Y	PARTICIPANT	\N	PRESENT	0
532283	531373	01043Q	PARTICIPANT	\N	PRESENT	0
532284	531373	14053L	PARTICIPANT	\N	PRESENT	0
532463	531317	19489J	PARTICIPANT	\N	PRESENT	0
532466	531317	05008E	PARTICIPANT	\N	PRESENT	0
532471	531317	14089Y	PARTICIPANT	\N	PRESENT	0
532479	531317	20114U	PARTICIPANT	\N	PRESENT	0
532483	531317	11072N	PARTICIPANT	\N	PRESENT	0
532484	531317	14021P	PARTICIPANT	\N	PRESENT	0
532487	531147	04086Q	PARTICIPANT	\N	PRESENT	0
532488	531288	20086J	PARTICIPANT	\N	PRESENT	0
532489	531288	19383Y	PARTICIPANT	\N	PRESENT	0
532490	531288	19782L	PARTICIPANT	\N	PRESENT	0
532491	531288	20092G	PARTICIPANT	\N	PRESENT	0
532492	531288	01043Q	PARTICIPANT	\N	PRESENT	0
532493	531288	14357A	PARTICIPANT	\N	PRESENT	0
532494	531288	19441R	PARTICIPANT	\N	PRESENT	0
532495	531288	19413M	PARTICIPANT	\N	PRESENT	0
532496	531288	20082E	PARTICIPANT	\N	PRESENT	0
532497	531288	20094J	PARTICIPANT	\N	PRESENT	1
532498	531288	19631V	PARTICIPANT	\N	PRESENT	0
532499	531288	11099A	PARTICIPANT	\N	PRESENT	1
532500	531288	08015R	PARTICIPANT	\N	PRESENT	0
532501	531288	19575F	PARTICIPANT	\N	PRESENT	0
532502	531288	19369B	PARTICIPANT	\N	PRESENT	1
532503	531288	20018V	PARTICIPANT	\N	PRESENT	0
532504	531288	08028W	PARTICIPANT	\N	PRESENT	0
532505	531288	19563B	PARTICIPANT	\N	PRESENT	1
532506	531288	19521Q	PARTICIPANT	\N	PRESENT	1
532507	531288	14038Y	PARTICIPANT	\N	PRESENT	1
532508	531288	20030R	PARTICIPANT	\N	PRESENT	1
532509	531288	19467C	PARTICIPANT	\N	PRESENT	1
532510	531288	19695N	PARTICIPANT	\N	PRESENT	0
532511	531288	14033T	PARTICIPANT	\N	PRESENT	0
532512	531288	11090Q	PRESIDENT	0	PRESENT	0
532513	531288	01025N	PARTICIPANT	\N	PRESENT	0
532514	531288	20054A	PARTICIPANT	\N	PRESENT	0
532515	531288	20174H	PARTICIPANT	\N	PRESENT	1
532516	531288	14205J	PARTICIPANT	\N	PRESENT	0
532517	531288	20060X	PARTICIPANT	\N	PRESENT	1
532518	531288	20062A	PARTICIPANT	\N	PRESENT	0
532519	531288	14251Q	PARTICIPANT	\N	PRESENT	1
532520	531288	14207L	PARTICIPANT	\N	PRESENT	1
532521	531288	14257W	PARTICIPANT	\N	PRESENT	0
532522	531288	19549D	PARTICIPANT	\N	PRESENT	0
532523	531288	19820Y	PARTICIPANT	\N	PRESENT	0
532524	531288	19826F	PARTICIPANT	\N	PRESENT	0
532525	531288	19525U	PARTICIPANT	\N	PRESENT	0
532526	531288	20038A	PARTICIPANT	\N	PRESENT	0
532527	531288	20046A	PARTICIPANT	\N	PRESENT	0
532528	531288	17229F	PARTICIPANT	\N	PRESENT	0
532529	531288	20068G	PARTICIPANT	\N	PRESENT	0
532530	531288	19599P	PARTICIPANT	\N	PRESENT	0
532531	531288	20102Q	PARTICIPANT	\N	PRESENT	0
532532	531288	18083K	PARTICIPANT	\N	PRESENT	1
532533	531288	20118Y	PARTICIPANT	\N	PRESENT	0
532534	531288	19503N	PARTICIPANT	\N	PRESENT	0
532535	531288	17637T	PARTICIPANT	\N	PRESENT	0
532536	531288	14031R	PARTICIPANT	\N	PRESENT	0
532537	531288	19251M	PARTICIPANT	\N	PRESENT	0
532538	531288	19739H	PARTICIPANT	\N	PRESENT	0
513762	513761	19631V	PARTICIPANT	\N	PRESENT	0
513763	513761	20024T	PARTICIPANT	\N	PRESENT	0
513764	513761	19782L	PARTICIPANT	\N	PRESENT	0
513765	513761	11101A	PARTICIPANT	\N	PRESENT	0
513766	513761	08028W	PARTICIPANT	\N	PRESENT	0
513767	513761	20052X	PARTICIPANT	\N	PRESENT	0
513769	513761	20018V	PARTICIPANT	\N	PRESENT	0
513770	513761	19703U	PARTICIPANT	\N	PRESENT	0
517309	513048	20022R	PARTICIPANT	\N	PRESENT	0
517310	513048	19782L	PARTICIPANT	\N	PRESENT	0
517311	513048	19671E	PARTICIPANT	\N	PRESENT	0
517312	513048	19747H	PARTICIPANT	\N	PRESENT	0
517313	513048	04045F	PARTICIPANT	\N	PRESENT	0
517314	513048	01057W	PARTICIPANT	\N	PRESENT	0
517329	513048	14105F	PARTICIPANT	\N	PRESENT	0
517373	513055	19725B	PARTICIPANT	\N	PRESENT	0
517374	513055	20172F	PARTICIPANT	\N	PRESENT	0
517375	513055	19479G	PARTICIPANT	\N	PRESENT	0
517376	513055	20140W	PARTICIPANT	\N	PRESENT	0
517377	513055	14069U	PARTICIPANT	\N	PRESENT	0
517378	513055	20044X	PARTICIPANT	\N	PRESENT	0
517379	513055	19826F	PARTICIPANT	\N	PRESENT	0
517380	513055	20024T	PARTICIPANT	\N	PRESENT	0
517381	513055	14041T	PARTICIPANT	\N	PRESENT	0
517382	513055	97011G	PARTICIPANT	\N	PRESENT	0
517383	513055	20174H	PARTICIPANT	\N	PRESENT	0
517384	513055	12041X	PARTICIPANT	\N	PRESENT	0
517385	513055	19507S	PARTICIPANT	\N	PRESENT	0
517386	513055	19747H	PARTICIPANT	\N	PRESENT	0
517387	513055	14327T	PARTICIPANT	\N	PRESENT	0
517388	513055	20038A	PARTICIPANT	\N	PRESENT	0
517389	513055	20076G	PARTICIPANT	\N	PRESENT	0
517390	513055	20130U	PARTICIPANT	\N	PRESENT	0
517391	513055	20144B	PARTICIPANT	\N	PRESENT	0
517392	513055	19383Y	PARTICIPANT	\N	PRESENT	0
517393	513055	20048C	PARTICIPANT	\N	PRESENT	0
517394	513055	14089Y	PARTICIPANT	\N	PRESENT	0
517395	513055	20090E	PARTICIPANT	\N	PRESENT	0
517396	513055	11115U	PARTICIPANT	\N	PRESENT	0
517397	513055	01034P	PARTICIPANT	\N	PRESENT	0
517398	513055	14187A	PARTICIPANT	\N	PRESENT	0
517399	513055	19713W	PARTICIPANT	\N	PRESENT	0
517400	513055	14059S	PARTICIPANT	\N	PRESENT	0
517401	513055	20062A	PARTICIPANT	\N	PRESENT	0
517402	513055	17229F	PARTICIPANT	\N	PRESENT	0
517403	513055	19637C	PARTICIPANT	\N	PRESENT	0
517404	513055	19441R	PARTICIPANT	\N	PRESENT	0
517405	513055	11097X	PARTICIPANT	\N	PRESENT	0
517406	513055	01057W	PARTICIPANT	\N	PRESENT	0
517407	513055	19723Y	PARTICIPANT	\N	PRESENT	0
517408	513055	20080C	PARTICIPANT	\N	PRESENT	0
517409	513055	20068G	PARTICIPANT	\N	PRESENT	0
517410	513055	19701S	PARTICIPANT	\N	PRESENT	0
517411	517007	19593H	PARTICIPANT	\N	PRESENT	0
517412	517007	04070G	PARTICIPANT	\N	PRESENT	0
517413	517007	20132W	PARTICIPANT	\N	PRESENT	0
517371	513055	14026U	PARTICIPANT	\N	PRESENT	0
517372	513055	11110B	PARTICIPANT	\N	PRESENT	0
517414	517007	19699S	PARTICIPANT	\N	PRESENT	0
517415	517007	20134Y	PARTICIPANT	\N	PRESENT	0
517416	517007	14073Q	PARTICIPANT	\N	PRESENT	0
517417	517007	19611R	PRESIDENT	0	PRESENT	0
517418	517007	19693L	PARTICIPANT	\N	PRESENT	0
517419	517007	19399H	PARTICIPANT	\N	PRESENT	0
517420	517007	20152B	PARTICIPANT	\N	PRESENT	0
517421	517007	14229S	PARTICIPANT	\N	PRESENT	0
517422	517007	20058E	PARTICIPANT	\N	PRESENT	0
517423	517007	14030Q	PARTICIPANT	\N	PRESENT	0
517424	517007	20098N	PARTICIPANT	\N	PRESENT	0
517425	517007	20180F	PARTICIPANT	\N	PRESENT	0
517426	517007	04059M	PARTICIPANT	\N	PRESENT	0
517427	517007	08012N	PARTICIPANT	\N	PRESENT	0
517428	517007	08061X	PARTICIPANT	\N	PRESENT	0
517429	517007	11104D	PARTICIPANT	\N	PRESENT	0
517430	517007	19758L	PARTICIPANT	\N	PRESENT	0
517432	513055	19399H	PARTICIPANT	\N	PRESENT	0
517441	513055	14083S	PARTICIPANT	\N	PRESENT	0
517442	513055	14147R	PARTICIPANT	\N	PRESENT	0
517443	513055	20052X	PARTICIPANT	\N	PRESENT	0
517444	513055	20100N	PARTICIPANT	\N	PRESENT	0
517445	513055	19531S	PARTICIPANT	\N	PRESENT	0
517446	513055	14071N	PARTICIPANT	\N	PRESENT	0
517447	513055	20146D	PARTICIPANT	\N	PRESENT	0
517448	513055	14205J	PARTICIPANT	\N	PRESENT	0
517449	513055	19575F	PARTICIPANT	\N	PRESENT	0
517450	513055	19553Y	PARTICIPANT	\N	PRESENT	0
518474	513056	86034E	PARTICIPANT	\N	PRESENT	0
518488	513056	08061X	PARTICIPANT	\N	PRESENT	0
518489	513056	95063L	PARTICIPANT	\N	PRESENT	0
518490	513056	20106U	PARTICIPANT	\N	PRESENT	0
518491	513056	19697Q	PARTICIPANT	\N	PRESENT	0
518492	513056	19447X	PARTICIPANT	\N	PRESENT	0
518493	513056	20132W	PARTICIPANT	\N	PRESENT	0
518494	513056	20050V	PARTICIPANT	\N	PRESENT	0
518495	513056	18083K	PARTICIPANT	\N	PRESENT	0
518496	513056	20130U	PARTICIPANT	\N	PRESENT	0
518497	513056	11033F	PARTICIPANT	\N	PRESENT	0
518498	513056	19347U	PARTICIPANT	\N	PRESENT	0
518499	513056	11066Q	PARTICIPANT	\N	PRESENT	0
518500	513056	01028R	PARTICIPANT	\N	PRESENT	0
518501	513056	11099A	PARTICIPANT	\N	PRESENT	0
518502	513056	20092G	PARTICIPANT	\N	PRESENT	0
518503	513056	19503N	PARTICIPANT	\N	PRESENT	0
518504	513056	99004R	PARTICIPANT	\N	PRESENT	0
518505	513056	20082E	PARTICIPANT	\N	PRESENT	0
518506	513056	19711U	PARTICIPANT	\N	PRESENT	0
518507	513056	14121F	PARTICIPANT	\N	PRESENT	0
518508	513056	04092N	PARTICIPANT	\N	PRESENT	0
518509	513056	08069G	PARTICIPANT	\N	PRESENT	0
518510	513056	20080C	PARTICIPANT	\N	PRESENT	0
518511	513056	19683J	PARTICIPANT	\N	PRESENT	0
518512	513056	04033B	PARTICIPANT	\N	PRESENT	0
518513	513056	11067R	PARTICIPANT	\N	PRESENT	0
518514	513056	14071N	PARTICIPANT	\N	PRESENT	0
518515	513056	19649G	PARTICIPANT	\N	PRESENT	0
518516	513056	14217N	PARTICIPANT	\N	PRESENT	0
518517	513056	14187A	PARTICIPANT	\N	PRESENT	0
518518	513056	19631V	PARTICIPANT	\N	PRESENT	0
518519	513056	04085P	PARTICIPANT	\N	PRESENT	0
518520	513056	19723Y	PARTICIPANT	\N	PRESENT	0
518521	513056	14147R	PARTICIPANT	\N	PRESENT	0
518522	513056	11031D	PARTICIPANT	\N	PRESENT	0
518523	513056	19745F	PARTICIPANT	\N	PRESENT	0
518524	513056	20024T	PARTICIPANT	\N	PRESENT	0
518525	513056	20052X	PARTICIPANT	\N	PRESENT	0
518526	513056	14042U	PARTICIPANT	\N	PRESENT	0
518527	513056	05008E	PARTICIPANT	\N	PRESENT	0
518528	513056	20144B	PARTICIPANT	\N	PRESENT	0
518529	513056	11012A	PARTICIPANT	\N	PRESENT	0
518530	513056	07029T	PARTICIPANT	\N	PRESENT	0
518531	513056	04057K	PARTICIPANT	\N	PRESENT	0
518532	513056	20098N	PARTICIPANT	\N	PRESENT	0
518533	513056	19545Y	PARTICIPANT	\N	PRESENT	0
518534	513056	14033T	PARTICIPANT	\N	PRESENT	0
518535	513056	14267Y	PARTICIPANT	\N	PRESENT	0
518536	513056	20044X	PARTICIPANT	\N	PRESENT	0
518537	513056	17023S	PARTICIPANT	\N	PRESENT	0
518538	513056	19399H	PARTICIPANT	\N	PRESENT	0
518539	513056	19735D	PARTICIPANT	\N	PRESENT	0
518540	513056	14021P	PARTICIPANT	\N	PRESENT	0
518541	513056	14251Q	PARTICIPANT	\N	PRESENT	0
518542	513056	19643A	PARTICIPANT	\N	PRESENT	0
518543	513056	20086J	PARTICIPANT	\N	PRESENT	0
518544	513056	20018V	PARTICIPANT	\N	PRESENT	0
518545	513056	20060X	PARTICIPANT	\N	PRESENT	0
518546	513056	19575F	PARTICIPANT	\N	PRESENT	0
518547	513056	01058X	PARTICIPANT	\N	PRESENT	0
518548	513056	11053K	PARTICIPANT	\N	PRESENT	0
518549	513056	19415P	PARTICIPANT	\N	PRESENT	0
518550	513056	10006L	PARTICIPANT	\N	PRESENT	0
518551	513056	19703U	PARTICIPANT	\N	PRESENT	0
518552	513056	11097X	PARTICIPANT	\N	PRESENT	0
518554	513056	11056N	PARTICIPANT	\N	PRESENT	0
518555	513056	19695N	PARTICIPANT	\N	PRESENT	0
518560	513056	14073Q	PARTICIPANT	\N	PRESENT	0
518562	513056	14189C	PARTICIPANT	\N	PRESENT	0
518564	513056	14123H	PARTICIPANT	\N	PRESENT	0
518569	513056	04043D	PARTICIPANT	\N	PRESENT	0
518572	513056	19749K	PARTICIPANT	\N	PRESENT	0
518580	513056	20040T	PARTICIPANT	\N	PRESENT	0
518581	513056	19651A	PARTICIPANT	\N	PRESENT	0
536310	534115	11033F	PARTICIPANT	\N	EXCUSE	0
536538	534115	19683J	PRESIDENT	0	PRESENT	0
536539	534115	14189C	PARTICIPANT	\N	PRESENT	0
536540	534115	99004R	PARTICIPANT	\N	PRESENT	0
536541	534115	14229S	PARTICIPANT	\N	PRESENT	0
536542	534115	19705W	PARTICIPANT	\N	PRESENT	0
536543	534115	11031D	PARTICIPANT	\N	PRESENT	0
536544	534115	20030R	PARTICIPANT	\N	PRESENT	0
536545	534115	19699S	PARTICIPANT	\N	PRESENT	0
536546	534115	10006L	PARTICIPANT	\N	PRESENT	0
536547	534115	20120S	PARTICIPANT	\N	PRESENT	0
537546	536609	19543W	PARTICIPANT	\N	PRESENT	1
537547	536609	17737W	PARTICIPANT	\N	PRESENT	1
537548	536609	19629C	PARTICIPANT	\N	PRESENT	1
537549	536609	04008A	PARTICIPANT	\N	PRESENT	1
537550	536609	14179A	PARTICIPANT	\N	PRESENT	1
537551	536609	19581D	PARTICIPANT	\N	PRESENT	1
537552	536609	19675J	PARTICIPANT	\N	PRESENT	1
537553	536609	19760E	PARTICIPANT	\N	PRESENT	1
537554	536609	19717B	PARTICIPANT	\N	PRESENT	1
537555	536609	11103C	PARTICIPANT	\N	PRESENT	1
537556	536609	20172F	PARTICIPANT	\N	PRESENT	1
537557	536609	19591F	PARTICIPANT	\N	PRESENT	1
537558	536609	19697Q	PARTICIPANT	\N	PRESENT	1
537559	536609	19657G	PARTICIPANT	\N	PRESENT	1
537560	536609	04057K	PARTICIPANT	\N	PRESENT	1
537561	536609	19798U	PARTICIPANT	\N	PRESENT	1
537562	536609	19301E	PARTICIPANT	\N	PRESENT	1
537563	536611	19543W	PARTICIPANT	\N	PRESENT	1
537564	536611	19581D	PARTICIPANT	\N	PRESENT	1
537565	536611	19675J	PARTICIPANT	\N	PRESENT	1
537570	536611	14231L	PARTICIPANT	\N	EXCUSE	0
537788	537787	14069U	PARTICIPANT	\N	PRESENT	0
537789	537787	11072N	PARTICIPANT	\N	PRESENT	0
537820	536613	19725B	PARTICIPANT	\N	PRESENT	1
537824	536613	19675J	PARTICIPANT	\N	PRESENT	1
537822	536613	14179A	PARTICIPANT	\N	PRESENT	1
537823	536613	11026G	PARTICIPANT	\N	PRESENT	1
537905	536614	14069U	PARTICIPANT	\N	PRESENT	1
537906	536614	19725B	PARTICIPANT	\N	PRESENT	1
537907	536614	11026G	PARTICIPANT	\N	PRESENT	1
537908	536614	19675J	PARTICIPANT	\N	PRESENT	1
538774	531687	18083K	PARTICIPANT	\N	PRESENT	0
538775	531687	19347U	PARTICIPANT	\N	PRESENT	0
538776	531687	20034V	PARTICIPANT	\N	PRESENT	0
538777	531687	14059S	PARTICIPANT	\N	PRESENT	0
538778	531687	14147R	PARTICIPANT	\N	PRESENT	0
538779	531687	11072N	PARTICIPANT	\N	PRESENT	0
538801	536583	14189C	PARTICIPANT	\N	PRESENT	0
538802	536583	14030Q	PARTICIPANT	\N	PRESENT	0
538803	536583	17737W	PARTICIPANT	\N	EXCUSE	0
538805	536583	20080C	PARTICIPANT	\N	EXCUSE	0
538807	536583	19693L	PARTICIPANT	\N	PRESENT	0
538808	536583	19599P	PARTICIPANT	\N	PRESENT	0
538810	536583	20106U	PARTICIPANT	\N	PRESENT	0
538812	536583	14179A	PARTICIPANT	\N	PRESENT	0
538813	536583	20066E	PARTICIPANT	\N	PRESENT	0
538815	536583	19715Y	PARTICIPANT	\N	PRESENT	0
538817	536583	20056C	PARTICIPANT	\N	PRESENT	0
538818	536583	07029T	PARTICIPANT	\N	EXCUSE	0
538821	536583	14109K	PARTICIPANT	\N	PRESENT	0
538823	536583	19866P	PARTICIPANT	\N	PRESENT	0
538826	536583	20118Y	PARTICIPANT	\N	EXCUSE	0
538828	536583	19798U	PARTICIPANT	\N	PRESENT	0
538831	536583	20098N	PARTICIPANT	\N	PRESENT	0
538833	536583	19527W	PARTICIPANT	\N	PRESENT	0
538834	536583	20046A	PARTICIPANT	\N	PRESENT	0
538835	536583	19749K	PARTICIPANT	\N	PRESENT	0
538912	538911	19673G	PARTICIPANT	\N	PRESENT	0
538913	538911	19749K	PARTICIPANT	\N	PRESENT	0
539052	537380	19611R	PARTICIPANT	\N	PRESENT	0
539053	537380	14059S	PARTICIPANT	\N	PRESENT	0
539054	537380	20082E	PARTICIPANT	\N	PRESENT	0
539055	537380	20096L	PARTICIPANT	\N	PRESENT	0
539058	537380	19593H	PRESIDENT	0	PRESENT	0
539059	537380	19533U	PARTICIPANT	\N	PRESENT	0
539060	537380	19591F	PARTICIPANT	\N	PRESENT	0
539064	537380	19715Y	PARTICIPANT	\N	PRESENT	1
539065	537380	19643A	PARTICIPANT	\N	PRESENT	1
539066	537380	20172F	PARTICIPANT	\N	PRESENT	1
539067	537380	20142Y	PARTICIPANT	\N	PRESENT	1
539068	537380	14147R	PARTICIPANT	\N	PRESENT	1
539070	537380	19745F	PARTICIPANT	\N	PRESENT	1
539071	537380	20132W	PARTICIPANT	\N	PRESENT	1
539074	537380	20114U	PARTICIPANT	\N	PRESENT	0
539136	537380	19735D	PARTICIPANT	\N	PRESENT	1
539258	539257	14038Y	PARTICIPANT	\N	PRESENT	0
539259	539257	20060X	PARTICIPANT	\N	PRESENT	0
539260	539257	19441R	PARTICIPANT	\N	PRESENT	0
539276	539275	19701S	PARTICIPANT	\N	PRESENT	0
539277	539275	19387D	PARTICIPANT	\N	PRESENT	0
539278	539275	20100N	PARTICIPANT	\N	PRESENT	0
539279	539275	19820Y	PARTICIPANT	\N	PRESENT	0
539280	539275	19575F	PARTICIPANT	\N	PRESENT	0
539281	539275	19739H	PARTICIPANT	\N	PRESENT	0
539282	539275	01024M	PARTICIPANT	\N	PRESENT	0
539284	539283	18083K	PARTICIPANT	\N	PRESENT	0
539285	539283	20038A	PARTICIPANT	\N	PRESENT	0
539286	539283	19713W	PARTICIPANT	\N	PRESENT	0
539287	539283	14169X	PARTICIPANT	\N	PRESENT	0
539288	539283	20096L	PARTICIPANT	\N	PRESENT	0
539289	539283	19251M	PARTICIPANT	\N	PRESENT	0
539310	539308	19768N	PARTICIPANT	\N	PRESENT	0
539311	539308	20034V	PARTICIPANT	\N	PRESENT	0
539312	539308	20078J	PARTICIPANT	\N	PRESENT	0
539313	539308	19631V	PARTICIPANT	\N	PRESENT	0
539314	539308	19515S	PARTICIPANT	\N	PRESENT	0
539315	539308	19747H	PARTICIPANT	\N	PRESENT	0
539316	539308	19383Y	PARTICIPANT	\N	PRESENT	0
539668	539667	17737W	PARTICIPANT	\N	PRESENT	0
539670	539669	14193X	PARTICIPANT	\N	PRESENT	0
539671	539669	14267Y	PARTICIPANT	\N	PRESENT	0
539700	529005	19503N	PARTICIPANT	\N	PRESENT	0
539701	529005	19693L	PARTICIPANT	\N	EXCUSE	0
540020	539063	20050V	PARTICIPANT	\N	EXCUSE	0
540021	539943	14357A	PRESIDENT	0	PRESENT	0
540022	530857	20098N	PARTICIPANT	\N	PRESENT	0
540033	539548	20024T	PARTICIPANT	\N	PRESENT	0
540034	539548	11085T	PARTICIPANT	\N	PRESENT	0
540035	539548	04070G	PARTICIPANT	\N	PRESENT	0
540036	539943	19507S	PARTICIPANT	\N	PRESENT	0
540037	539548	19549D	PARTICIPANT	\N	PRESENT	0
540038	539548	14173T	PARTICIPANT	\N	PRESENT	0
540039	539548	19545Y	PARTICIPANT	\N	PRESENT	0
540040	539548	19413M	PARTICIPANT	\N	PRESENT	0
540041	539548	11101A	PARTICIPANT	\N	PRESENT	0
540042	539548	14121F	PARTICIPANT	\N	PRESENT	0
540050	539548	20082E	PARTICIPANT	\N	PRESENT	0
540051	539548	08060W	PARTICIPANT	\N	PRESENT	0
540052	539688	12041X	PARTICIPANT	\N	PRESENT	0
540053	539688	19565D	PARTICIPANT	\N	PRESENT	1
540054	539688	20072C	PARTICIPANT	\N	PRESENT	0
540055	539688	04034C	PARTICIPANT	\N	PRESENT	0
540056	539688	11027H	PARTICIPANT	\N	PRESENT	1
540057	539688	04042C	PRESIDENT	0	PRESENT	0
540058	539688	11054L	PARTICIPANT	\N	PRESENT	0
540059	539688	11066Q	PARTICIPANT	\N	PRESENT	0
540060	539688	08056B	PARTICIPANT	\N	PRESENT	0
540061	539688	19421M	PARTICIPANT	\N	PRESENT	1
540062	539688	19709B	PARTICIPANT	\N	PRESENT	0
540063	539688	14193X	PRESIDENT	1	PRESENT	0
540064	539688	14249W	PARTICIPANT	\N	PRESENT	0
540065	539688	08047A	PARTICIPANT	\N	PRESENT	0
540066	539688	14059S	PARTICIPANT	\N	PRESENT	0
540067	539688	04035D	PARTICIPANT	\N	PRESENT	0
540068	539688	14133K	PARTICIPANT	\N	PRESENT	1
540069	539688	01062T	PARTICIPANT	\N	PRESENT	1
540070	539688	11041F	PARTICIPANT	\N	PRESENT	1
540071	539688	08069G	PARTICIPANT	\N	PRESENT	0
540072	539688	20042V	PARTICIPANT	\N	PRESENT	1
540073	539688	19721W	PARTICIPANT	\N	PRESENT	0
540074	539688	14105F	PARTICIPANT	\N	PRESENT	1
540075	539688	20064C	PARTICIPANT	\N	PRESENT	0
540076	539688	98018T	PARTICIPANT	\N	PRESENT	1
540077	539688	14267Y	PARTICIPANT	\N	PRESENT	0
540078	539688	11083R	PARTICIPANT	\N	PRESENT	0
540079	539688	19583F	PARTICIPANT	\N	PRESENT	1
540080	539688	14255U	PARTICIPANT	\N	PRESENT	0
540083	540081	19637C	PARTICIPANT	\N	PRESENT	0
540084	540081	14033T	PARTICIPANT	\N	PRESENT	0
516809	516808	19735D	PARTICIPANT	\N	PRESENT	0
516810	516808	19723Y	PARTICIPANT	\N	PRESENT	0
518865	518863	14069U	PARTICIPANT	\N	PRESENT	0
518867	518863	20104S	PARTICIPANT	\N	PRESENT	0
518868	518863	11031D	PARTICIPANT	\N	PRESENT	0
518869	518863	19565D	PARTICIPANT	\N	PRESENT	0
518870	518863	20052X	PARTICIPANT	\N	PRESENT	0
518871	518863	20146D	PARTICIPANT	\N	PRESENT	0
518873	518863	19585H	PARTICIPANT	\N	PRESENT	0
520424	518951	86034E	PARTICIPANT	\N	PRESENT	0
520427	518951	20114U	PARTICIPANT	\N	PRESENT	0
520428	518951	14229S	PARTICIPANT	\N	PRESENT	0
520429	518951	11054L	PARTICIPANT	\N	PRESENT	0
520430	518951	20174H	PARTICIPANT	\N	PRESENT	0
520431	518951	20072C	PARTICIPANT	\N	PRESENT	0
520432	518951	19585H	PARTICIPANT	\N	PRESENT	0
520433	518951	11041F	PARTICIPANT	\N	PRESENT	0
520434	518951	98022P	PARTICIPANT	\N	PRESENT	0
520435	518951	20116W	PARTICIPANT	\N	PRESENT	0
520436	518951	19826F	PARTICIPANT	\N	PRESENT	0
520437	518951	19569H	PARTICIPANT	\N	PRESENT	0
520438	518951	14111D	PARTICIPANT	\N	PRESENT	0
520439	518951	20142Y	PARTICIPANT	\N	PRESENT	0
520440	518951	14109K	PARTICIPANT	\N	PRESENT	0
520441	518951	11085T	PARTICIPANT	\N	PRESENT	0
520442	518951	19543W	PARTICIPANT	\N	PRESENT	0
520443	518951	14231L	PARTICIPANT	\N	PRESENT	0
520444	518951	01025N	PARTICIPANT	\N	PRESENT	0
520445	518951	20144B	PARTICIPANT	\N	PRESENT	0
520446	518951	20064C	PARTICIPANT	\N	PRESENT	0
520447	518951	20052X	PARTICIPANT	\N	PRESENT	0
520448	518951	14267Y	PARTICIPANT	\N	PRESENT	0
520449	518951	17965H	PARTICIPANT	\N	PRESENT	0
520450	518951	20094J	PARTICIPANT	\N	PRESENT	0
520451	518951	08017T	PARTICIPANT	\N	PRESENT	0
520452	518951	04045F	PARTICIPANT	\N	PRESENT	0
520453	518951	20106U	PARTICIPANT	\N	PRESENT	0
520454	518951	08061X	PARTICIPANT	\N	PRESENT	0
520455	518951	19549D	PARTICIPANT	\N	PRESENT	0
520456	518951	19503N	PARTICIPANT	\N	PRESENT	0
520457	518951	20082E	PARTICIPANT	\N	PRESENT	0
520458	518951	08009T	PARTICIPANT	\N	PRESENT	0
520459	518951	19369B	PARTICIPANT	\N	PRESENT	0
520460	518951	14219Q	PARTICIPANT	\N	PRESENT	0
520461	518951	19387D	PARTICIPANT	\N	PRESENT	0
520462	518951	11012A	PARTICIPANT	\N	PRESENT	0
520463	518951	12028B	PARTICIPANT	\N	PRESENT	0
520464	518951	18193Q	PARTICIPANT	\N	PRESENT	0
520465	518951	11040E	PARTICIPANT	\N	PRESENT	0
520466	518951	19599P	PARTICIPANT	\N	PRESENT	0
520467	518951	19593H	PARTICIPANT	\N	PRESENT	0
520468	518951	20112S	PARTICIPANT	\N	PRESENT	0
520469	518951	11031D	PARTICIPANT	\N	PRESENT	0
520470	518951	19758L	PARTICIPANT	\N	PRESENT	0
520471	518951	20046A	PARTICIPANT	\N	PRESENT	0
520472	518951	20102Q	PARTICIPANT	\N	PRESENT	0
520473	518951	19695N	PARTICIPANT	\N	PRESENT	0
520474	518951	04085P	PARTICIPANT	\N	PRESENT	0
520475	518951	11056N	PARTICIPANT	\N	PRESENT	0
520476	518951	19760E	PARTICIPANT	\N	PRESENT	0
520477	518951	20134Y	PARTICIPANT	\N	PRESENT	0
520478	518951	20130U	PARTICIPANT	\N	PRESENT	0
520479	518951	20100N	PARTICIPANT	\N	PRESENT	0
520480	518951	11033F	PARTICIPANT	\N	PRESENT	0
520481	518951	11065P	PARTICIPANT	\N	PRESENT	0
520506	518951	19954N	PARTICIPANT	\N	PRESENT	0
520483	518951	20146D	PARTICIPANT	\N	PRESENT	0
520484	518951	11072N	PARTICIPANT	\N	PRESENT	0
520485	518951	19637C	PARTICIPANT	\N	PRESENT	0
520486	518951	20058E	PARTICIPANT	\N	PRESENT	0
520487	518951	20044X	PARTICIPANT	\N	PRESENT	0
520488	518951	14038Y	PARTICIPANT	\N	PRESENT	0
520489	518951	19782L	PARTICIPANT	\N	PRESENT	0
520490	518951	19697Q	PARTICIPANT	\N	PRESENT	0
520491	518951	19717B	PARTICIPANT	\N	PRESENT	0
520492	518951	14207L	PARTICIPANT	\N	PRESENT	0
520493	518951	19719D	PARTICIPANT	\N	PRESENT	0
520494	518951	19629C	PARTICIPANT	\N	PRESENT	0
520495	518951	19399H	PARTICIPANT	\N	PRESENT	0
520496	518951	19563B	PARTICIPANT	\N	PRESENT	0
520497	518951	19507S	PARTICIPANT	\N	PRESENT	0
520498	518951	19657G	PARTICIPANT	\N	PRESENT	0
520499	518951	20128B	PARTICIPANT	\N	PRESENT	0
520500	518951	20038A	PARTICIPANT	\N	PRESENT	0
520501	518951	19467C	PARTICIPANT	\N	PRESENT	0
520502	518951	19573D	PARTICIPANT	\N	PRESENT	0
520503	518951	11083R	PARTICIPANT	\N	PRESENT	0
520504	518951	20056C	PARTICIPANT	\N	PRESENT	0
520505	518951	92040Q	PARTICIPANT	\N	PRESENT	0
520508	518951	19729F	PARTICIPANT	\N	PRESENT	0
520510	518951	08015R	PARTICIPANT	\N	PRESENT	0
520511	518951	14251Q	PARTICIPANT	\N	PRESENT	0
520512	518951	01057W	PARTICIPANT	\N	PRESENT	0
520513	518951	20050V	PARTICIPANT	\N	PRESENT	0
520515	518951	19515S	PARTICIPANT	\N	PRESENT	0
520518	518951	01058X	PARTICIPANT	\N	PRESENT	0
520520	518951	14211G	PARTICIPANT	\N	PRESENT	0
520521	518951	14221J	PARTICIPANT	\N	PRESENT	0
520522	518951	19415P	PARTICIPANT	\N	PRESENT	0
520523	518951	14031R	PARTICIPANT	\N	PRESENT	0
520524	518951	20032T	PARTICIPANT	\N	PRESENT	0
520525	518951	14169X	PARTICIPANT	\N	PRESENT	0
520526	518951	11045K	PARTICIPANT	\N	PRESENT	0
520527	518951	01028R	PARTICIPANT	\N	PRESENT	0
520528	518951	19705W	PARTICIPANT	\N	PRESENT	0
520529	518951	12041X	PARTICIPANT	\N	PRESENT	0
520530	518951	19762G	PARTICIPANT	\N	PRESENT	0
520531	518951	19689Q	PARTICIPANT	\N	PRESENT	0
520532	518951	14059S	PARTICIPANT	\N	PRESENT	0
520533	518951	19383Y	PARTICIPANT	\N	PRESENT	0
520534	518951	11067R	PARTICIPANT	\N	PRESENT	0
520535	518951	97011G	PARTICIPANT	\N	PRESENT	0
520536	518951	19725B	PARTICIPANT	\N	PRESENT	0
520537	518951	20126Y	PARTICIPANT	\N	PRESENT	0
520538	518951	19551W	PARTICIPANT	\N	PRESENT	0
520539	518951	14033T	PARTICIPANT	\N	PRESENT	0
520540	518951	08012N	PARTICIPANT	\N	PRESENT	0
520541	518951	20018V	PARTICIPANT	\N	PRESENT	0
520542	518951	20054A	PARTICIPANT	\N	PRESENT	0
520543	518951	20070A	PARTICIPANT	\N	PRESENT	0
520544	518951	19966S	PARTICIPANT	\N	PRESENT	0
520545	518951	14151M	PARTICIPANT	\N	PRESENT	0
520546	518951	17737W	PARTICIPANT	\N	PRESENT	0
520547	518951	19531S	PARTICIPANT	\N	PRESENT	0
520548	518951	20024T	PARTICIPANT	\N	PRESENT	0
520549	518951	17779H	PARTICIPANT	\N	PRESENT	0
520550	518951	14021P	PARTICIPANT	\N	PRESENT	0
520551	518951	20108W	PARTICIPANT	\N	PRESENT	0
520552	518951	04059M	PARTICIPANT	\N	PRESENT	0
520553	518951	19533U	PARTICIPANT	\N	PRESENT	0
520554	518951	20062A	PARTICIPANT	\N	PRESENT	0
520555	518951	08069G	PARTICIPANT	\N	PRESENT	0
520556	518951	04033B	PARTICIPANT	\N	PRESENT	0
520557	518951	20068G	PARTICIPANT	\N	PRESENT	0
520558	518951	20120S	PARTICIPANT	\N	PRESENT	0
520559	518951	14071N	PARTICIPANT	\N	PRESENT	0
520560	518951	20022R	PARTICIPANT	\N	PRESENT	0
520561	518951	01048V	PARTICIPANT	\N	PRESENT	0
520562	518951	10015M	PARTICIPANT	\N	PRESENT	0
520563	518951	11097X	PARTICIPANT	\N	PRESENT	0
520564	518951	20060X	PARTICIPANT	\N	PRESENT	0
520565	518951	04092N	PARTICIPANT	\N	PRESENT	0
520566	518951	19711U	PARTICIPANT	\N	PRESENT	0
520567	518951	19747H	PARTICIPANT	\N	PRESENT	0
520568	518951	99004R	PARTICIPANT	\N	PRESENT	0
520569	518951	18083K	PARTICIPANT	\N	PRESENT	0
520570	518951	11101A	PARTICIPANT	\N	PRESENT	0
520571	518951	17637T	PARTICIPANT	\N	PRESENT	0
520572	518951	04008A	PARTICIPANT	\N	PRESENT	0
520573	518951	20084G	PARTICIPANT	\N	PRESENT	0
520574	518951	19703U	PARTICIPANT	\N	PRESENT	0
520575	518951	04043D	PARTICIPANT	\N	PRESENT	0
520576	518951	14121F	PARTICIPANT	\N	PRESENT	0
520577	518951	14257W	PARTICIPANT	\N	PRESENT	0
520578	518951	20148F	PARTICIPANT	\N	PRESENT	0
520579	518951	19820Y	PARTICIPANT	\N	PRESENT	0
520580	518951	19333N	PARTICIPANT	\N	PRESENT	0
520581	518951	20020P	PARTICIPANT	\N	PRESENT	0
532539	531288	19745F	PARTICIPANT	\N	PRESENT	0
532540	531288	20020P	PARTICIPANT	\N	PRESENT	1
532541	531288	20076G	PARTICIPANT	\N	PRESENT	1
532542	531288	20106U	PARTICIPANT	\N	PRESENT	1
532543	531147	19762G	PARTICIPANT	\N	PRESENT	0
532544	531288	14187A	PARTICIPANT	\N	PRESENT	1
532545	531288	19387D	PARTICIPANT	\N	PRESENT	1
532546	531288	19701S	PARTICIPANT	\N	PRESENT	1
532555	531317	14179A	PARTICIPANT	\N	PRESENT	0
532556	531147	19349W	PARTICIPANT	\N	PRESENT	0
532686	532685	19575F	PARTICIPANT	\N	PRESENT	0
532687	532685	20116W	PARTICIPANT	\N	PRESENT	0
532688	532685	14105F	PARTICIPANT	\N	PRESENT	0
532692	532685	11103C	PARTICIPANT	\N	PRESENT	0
532690	532685	19383Y	PARTICIPANT	\N	PRESENT	0
532691	532685	14329V	PARTICIPANT	\N	PRESENT	0
532693	532685	20090E	PARTICIPANT	\N	PRESENT	0
532694	532685	19782L	PARTICIPANT	\N	PRESENT	0
532695	532685	18083K	PARTICIPANT	\N	PRESENT	0
532696	532685	14357A	PARTICIPANT	\N	PRESENT	0
532697	532685	17589D	PARTICIPANT	\N	PRESENT	0
532698	532685	14187A	PARTICIPANT	\N	PRESENT	0
532699	532685	20038A	PARTICIPANT	\N	PRESENT	0
532700	532685	14033T	PARTICIPANT	\N	PRESENT	0
532701	532685	14213J	PARTICIPANT	\N	PRESENT	0
532702	532685	20126Y	PARTICIPANT	\N	PRESENT	0
532703	532685	19723Y	PARTICIPANT	\N	PRESENT	0
532705	532685	14221J	PARTICIPANT	\N	PRESENT	0
532706	532685	08061X	PARTICIPANT	\N	PRESENT	0
532707	532685	20118Y	PARTICIPANT	\N	PRESENT	0
532708	532685	19739H	PARTICIPANT	\N	PRESENT	0
532709	532685	14331P	PARTICIPANT	\N	PRESENT	0
532710	532685	19713W	PARTICIPANT	\N	PRESENT	0
532896	531369	07029T	PARTICIPANT	\N	PRESENT	0
532897	531369	14219Q	PARTICIPANT	\N	PRESENT	0
532898	531369	19577H	PARTICIPANT	\N	PRESENT	0
532899	531369	20044X	PARTICIPANT	\N	PRESENT	0
532900	531369	14253S	PARTICIPANT	\N	PRESENT	0
532901	531369	20108W	PARTICIPANT	\N	PRESENT	0
532902	531369	11012A	PARTICIPANT	\N	PRESENT	0
532903	531369	04035D	PARTICIPANT	\N	PRESENT	0
532904	531369	11101A	PARTICIPANT	\N	PRESENT	0
532905	531369	17737W	PARTICIPANT	\N	PRESENT	0
532906	531369	20022R	PARTICIPANT	\N	PRESENT	0
532907	531369	20138D	PARTICIPANT	\N	PRESENT	0
532908	531369	19679N	PARTICIPANT	\N	PRESENT	0
532909	526730	19593H	PARTICIPANT	\N	PRESENT	0
532910	526730	20132W	PARTICIPANT	\N	PRESENT	0
532911	526730	19643A	PARTICIPANT	\N	PRESENT	1
532912	526730	20134Y	PARTICIPANT	\N	PRESENT	1
532913	526730	19533U	PARTICIPANT	\N	PRESENT	0
532914	526730	14073Q	PARTICIPANT	\N	PRESENT	1
532915	526730	19611R	PRESIDENT	0	PRESENT	0
532916	526730	20142Y	PARTICIPANT	\N	PRESENT	0
532917	526730	19693L	PARTICIPANT	\N	PRESENT	1
532918	526730	19399H	PARTICIPANT	\N	PRESENT	0
532919	526730	20098N	PARTICIPANT	\N	PRESENT	1
532920	526730	20056C	PARTICIPANT	\N	PRESENT	0
532921	526730	20180F	PARTICIPANT	\N	PRESENT	0
532922	526730	14109K	PARTICIPANT	\N	PRESENT	0
532923	526730	92040Q	PARTICIPANT	\N	PRESENT	0
532924	526730	07033P	PARTICIPANT	\N	PRESENT	0
532925	526730	11043H	PARTICIPANT	\N	PRESENT	0
532926	526730	11104D	PARTICIPANT	\N	PRESENT	1
532927	526730	20124W	PARTICIPANT	\N	PRESENT	0
532928	526730	19758L	PARTICIPANT	\N	PRESENT	0
532929	526730	17589D	PARTICIPANT	\N	PRESENT	0
532930	526730	20026V	PARTICIPANT	\N	PRESENT	0
532931	526730	19621T	PARTICIPANT	\N	PRESENT	0
532932	531369	20068G	PARTICIPANT	\N	PRESENT	0
532933	531369	19563B	PARTICIPANT	\N	PRESENT	0
532934	531369	19581D	PARTICIPANT	\N	PRESENT	0
532935	531369	19657G	PARTICIPANT	\N	PRESENT	0
532936	531369	19333N	PARTICIPANT	\N	PRESENT	0
532937	531369	19549D	PARTICIPANT	\N	PRESENT	0
532938	531369	19569H	PARTICIPANT	\N	PRESENT	0
532939	526730	20072C	PARTICIPANT	\N	PRESENT	1
532940	526730	19954N	PARTICIPANT	\N	PRESENT	1
532941	526730	14147R	PARTICIPANT	\N	PRESENT	0
532942	526730	04035D	PARTICIPANT	\N	PRESENT	1
532943	526730	20122U	PARTICIPANT	\N	PRESENT	1
532944	526730	20038A	PARTICIPANT	\N	PRESENT	0
532945	526730	20042V	PARTICIPANT	\N	PRESENT	0
532946	526730	14169X	PARTICIPANT	\N	PRESENT	0
532947	531369	01043Q	PARTICIPANT	\N	PRESENT	0
532948	530836	19533U	PARTICIPANT	\N	PRESENT	0
532949	530836	14229S	PARTICIPANT	\N	PRESENT	0
532950	530836	20098N	PARTICIPANT	\N	PRESENT	0
532951	530836	92040Q	PARTICIPANT	\N	PRESENT	0
532952	530836	07033P	PARTICIPANT	\N	PRESENT	0
532953	530836	08012N	PARTICIPANT	\N	PRESENT	0
532954	530836	20124W	PARTICIPANT	\N	PRESENT	0
532955	530836	20026V	PARTICIPANT	\N	PRESENT	0
532956	530836	19593H	PARTICIPANT	\N	PRESENT	0
532957	530836	20132W	PARTICIPANT	\N	PRESENT	0
532958	530836	19643A	PARTICIPANT	\N	PRESENT	0
532959	530836	20134Y	PARTICIPANT	\N	PRESENT	0
532960	530836	14073Q	PARTICIPANT	\N	PRESENT	0
532961	530836	19611R	PRESIDENT	0	PRESENT	0
532962	530836	20142Y	PARTICIPANT	\N	PRESENT	0
532963	530836	19693L	PARTICIPANT	\N	PRESENT	0
532964	530836	19399H	PARTICIPANT	\N	PRESENT	0
532965	530836	20056C	PARTICIPANT	\N	PRESENT	0
532966	530836	20180F	PARTICIPANT	\N	PRESENT	0
532967	530836	14109K	PARTICIPANT	\N	PRESENT	0
532968	530836	11104D	PARTICIPANT	\N	PRESENT	0
532969	530836	11043H	PARTICIPANT	\N	PRESENT	0
532970	530836	19758L	PARTICIPANT	\N	PRESENT	0
532971	530836	17589D	PARTICIPANT	\N	PRESENT	0
532972	530836	19621T	PARTICIPANT	\N	PRESENT	0
532974	532973	19673G	PARTICIPANT	\N	PRESENT	0
532975	531369	17229F	PARTICIPANT	\N	PRESENT	0
532976	532973	19749K	PARTICIPANT	\N	PRESENT	0
532977	532973	19954N	PARTICIPANT	\N	PRESENT	0
532978	532973	19725B	PARTICIPANT	\N	PRESENT	0
532979	531369	19301E	PARTICIPANT	\N	PRESENT	0
532980	531369	19565D	PARTICIPANT	\N	PRESENT	0
532983	531369	14189C	PARTICIPANT	\N	PRESENT	0
532984	531369	14089Y	PARTICIPANT	\N	PRESENT	0
532985	531369	14255U	PARTICIPANT	\N	PRESENT	0
532993	531369	19747H	PARTICIPANT	\N	PRESENT	0
532999	531369	14179A	PARTICIPANT	\N	PRESENT	0
533000	532982	19673G	PARTICIPANT	\N	PRESENT	0
533001	532982	19954N	PARTICIPANT	\N	PRESENT	0
533003	532982	19749K	PARTICIPANT	\N	PRESENT	0
533004	531369	17367Q	PARTICIPANT	\N	PRESENT	0
533006	533005	19954N	PARTICIPANT	\N	PRESENT	0
533007	533005	19673G	PARTICIPANT	\N	PRESENT	0
533008	533005	19749K	PARTICIPANT	\N	PRESENT	0
533010	533009	19673G	PARTICIPANT	\N	PRESENT	0
533011	533009	19749K	PARTICIPANT	\N	PRESENT	0
533013	533012	19954N	PARTICIPANT	\N	PRESENT	0
533014	533012	19673G	PARTICIPANT	\N	PRESENT	0
533015	533012	10015M	PARTICIPANT	\N	PRESENT	0
533016	533012	19749K	PARTICIPANT	\N	PRESENT	0
533018	533017	19673G	PARTICIPANT	\N	PRESENT	0
533022	533021	19673G	PARTICIPANT	\N	PRESENT	0
533023	533021	19749K	PARTICIPANT	\N	PRESENT	0
533024	531369	19479G	PARTICIPANT	\N	PRESENT	0
533026	531369	19671E	PARTICIPANT	\N	PRESENT	0
533061	526730	19735D	PARTICIPANT	\N	EXCUSE	0
533029	531369	14042U	PARTICIPANT	\N	PRESENT	0
533060	526730	14030Q	PARTICIPANT	\N	EXCUSE	0
533062	531317	04085P	PARTICIPANT	\N	PRESENT	1
533063	531317	19543W	PARTICIPANT	\N	PRESENT	1
533064	531317	11033F	PARTICIPANT	\N	PRESENT	1
533065	531317	17737W	PARTICIPANT	\N	PRESENT	1
533066	531317	19629C	PARTICIPANT	\N	PRESENT	1
533067	531317	14041T	PARTICIPANT	\N	PRESENT	1
533068	531317	14151M	PARTICIPANT	\N	PRESENT	1
533069	531317	19673G	PARTICIPANT	\N	EXCUSE	0
533070	531317	19725B	PARTICIPANT	\N	PRESENT	1
533071	531317	11026G	PARTICIPANT	\N	PRESENT	1
533072	531317	19729F	PARTICIPANT	\N	PRESENT	1
533073	531317	19581D	PARTICIPANT	\N	PRESENT	1
533074	531317	14001X	PARTICIPANT	\N	PRESENT	1
533075	531317	19675J	PARTICIPANT	\N	PRESENT	1
533076	531317	19749K	PARTICIPANT	\N	PRESENT	1
533077	531317	14107H	PARTICIPANT	\N	PRESENT	1
533301	531371	11045K	PARTICIPANT	\N	PRESENT	0
533305	531319	19593H	PARTICIPANT	\N	PRESENT	0
515870	502374	14195A	PARTICIPANT	\N	PRESENT	0
515871	502374	17589D	PARTICIPANT	\N	PRESENT	0
515872	502374	19713W	PARTICIPANT	\N	PRESENT	0
515873	502374	14219Q	PARTICIPANT	\N	PRESENT	0
515874	502374	01024M	PARTICIPANT	\N	PRESENT	0
515875	502374	20116W	PARTICIPANT	\N	PRESENT	0
515876	502374	19387D	PARTICIPANT	\N	PRESENT	0
515877	502374	19349W	PARTICIPANT	\N	PRESENT	0
515878	502374	19782L	PARTICIPANT	\N	PRESENT	0
515879	502374	20092G	PARTICIPANT	\N	PRESENT	0
515880	502374	18193Q	PARTICIPANT	\N	PRESENT	0
515881	502374	19333N	PARTICIPANT	\N	PRESENT	0
515882	502374	19820Y	PARTICIPANT	\N	PRESENT	0
515883	502374	19631V	PARTICIPANT	\N	PRESENT	0
515884	502374	19413M	PARTICIPANT	\N	PRESENT	0
515885	502374	19687N	PARTICIPANT	\N	PRESENT	0
515886	502374	19637C	PARTICIPANT	\N	PRESENT	0
515887	502374	04085P	PARTICIPANT	\N	PRESENT	0
515888	502374	12041X	PARTICIPANT	\N	PRESENT	0
515889	502374	19758L	PARTICIPANT	\N	PRESENT	0
515890	502374	19695N	PARTICIPANT	\N	PRESENT	0
515891	502374	19565D	PARTICIPANT	\N	PRESENT	0
515892	502374	11077T	PARTICIPANT	\N	PRESENT	0
515893	502374	20102Q	PARTICIPANT	\N	PRESENT	0
515894	502374	19760E	PARTICIPANT	\N	PRESENT	0
515895	502374	19691J	PARTICIPANT	\N	PRESENT	0
515896	502374	19521Q	PARTICIPANT	\N	PRESENT	0
515897	502374	14083S	PARTICIPANT	\N	PRESENT	0
515898	502374	14215L	PARTICIPANT	\N	PRESENT	0
515899	502374	14147R	PARTICIPANT	\N	PRESENT	0
515900	502374	19747H	PARTICIPANT	\N	PRESENT	0
515901	502374	19399H	PARTICIPANT	\N	PRESENT	0
515902	502374	19798U	PARTICIPANT	\N	PRESENT	0
515903	502374	20020P	PARTICIPANT	\N	PRESENT	0
515904	502374	14217N	PARTICIPANT	\N	PRESENT	0
515905	502374	19383Y	PARTICIPANT	\N	PRESENT	0
515906	502374	20034V	PARTICIPANT	\N	PRESENT	0
515907	502374	20140W	PARTICIPANT	\N	PRESENT	0
515908	502374	18083K	PARTICIPANT	\N	PRESENT	0
515909	502374	14038Y	PARTICIPANT	\N	PRESENT	0
515910	502374	19447X	PARTICIPANT	\N	PRESENT	0
515911	502374	20120S	PARTICIPANT	\N	PRESENT	0
515912	502374	11031D	PARTICIPANT	\N	PRESENT	0
515936	502374	19549D	PARTICIPANT	\N	PRESENT	0
515937	502374	07029T	PARTICIPANT	\N	PRESENT	0
515993	502377	14026U	PARTICIPANT	\N	PRESENT	0
515999	502377	04047H	PARTICIPANT	\N	PRESENT	0
516001	502377	19675J	PARTICIPANT	\N	PRESENT	0
516005	502377	20092G	PARTICIPANT	\N	PRESENT	0
516012	502377	11033F	PARTICIPANT	\N	PRESENT	0
516014	502377	11065P	PARTICIPANT	\N	PRESENT	0
516016	502377	20110Q	PARTICIPANT	\N	PRESENT	0
516019	502377	20142Y	PARTICIPANT	\N	PRESENT	0
516021	502377	20134Y	PARTICIPANT	\N	PRESENT	0
516022	502377	20100N	PARTICIPANT	\N	PRESENT	0
516023	502377	19347U	PARTICIPANT	\N	PRESENT	0
516028	502377	20036X	PARTICIPANT	\N	PRESENT	0
516029	502377	19585H	PARTICIPANT	\N	PRESENT	0
516030	502377	19629C	PARTICIPANT	\N	PRESENT	0
516032	502377	11072N	PARTICIPANT	\N	PRESENT	0
516034	502377	20112S	PARTICIPANT	\N	PRESENT	0
516035	502377	20064C	PARTICIPANT	\N	PRESENT	0
516036	502377	20084G	PARTICIPANT	\N	PRESENT	0
516037	502377	14215L	PARTICIPANT	\N	PRESENT	0
516038	502377	07004J	PARTICIPANT	\N	PRESENT	0
515868	502374	11045K	PARTICIPANT	\N	PRESENT	0
515869	502374	20122U	PARTICIPANT	\N	PRESENT	0
516039	502377	19367Y	PARTICIPANT	\N	PRESENT	0
516040	502377	14237S	PARTICIPANT	\N	PRESENT	0
516041	502377	19543W	PARTICIPANT	\N	PRESENT	0
516042	502377	14219Q	PARTICIPANT	\N	PRESENT	0
516043	502377	19689Q	PARTICIPANT	\N	PRESENT	0
516044	502377	07029T	PARTICIPANT	\N	PRESENT	0
516045	502377	11099A	PARTICIPANT	\N	PRESENT	0
516046	502377	20116W	PARTICIPANT	\N	PRESENT	0
516047	502377	19711U	PARTICIPANT	\N	PRESENT	0
516048	502377	08061X	PARTICIPANT	\N	PRESENT	0
516049	502377	19695N	PARTICIPANT	\N	PRESENT	0
516050	502377	19798U	PARTICIPANT	\N	PRESENT	0
516051	502377	20098N	PARTICIPANT	\N	PRESENT	0
516052	502377	14083S	PARTICIPANT	\N	PRESENT	0
516053	502377	19467C	PARTICIPANT	\N	PRESENT	0
516054	502377	20130U	PARTICIPANT	\N	PRESENT	0
516055	502377	20052X	PARTICIPANT	\N	PRESENT	0
516056	502377	20082E	PARTICIPANT	\N	PRESENT	0
516057	502377	18193Q	PARTICIPANT	\N	PRESENT	0
516060	502377	19762G	PARTICIPANT	\N	PRESENT	0
516061	502377	01028R	PARTICIPANT	\N	PRESENT	0
516074	502377	19749K	PARTICIPANT	\N	PRESENT	0
516085	502377	19699S	PARTICIPANT	\N	PRESENT	0
516086	502377	19399H	PARTICIPANT	\N	PRESENT	0
516087	502377	14021P	PARTICIPANT	\N	PRESENT	0
516091	502377	11110B	PARTICIPANT	\N	PRESENT	0
516101	502377	19621T	PARTICIPANT	\N	PRESENT	0
516109	502377	20066E	PARTICIPANT	\N	PRESENT	0
516117	502377	14195A	PARTICIPANT	\N	PRESENT	0
516118	502377	11115U	PARTICIPANT	\N	PRESENT	0
516119	502377	20046A	PARTICIPANT	\N	PRESENT	0
516120	502377	19747H	PARTICIPANT	\N	PRESENT	0
516121	502377	19515S	PARTICIPANT	\N	PRESENT	0
516122	502377	19671E	PARTICIPANT	\N	PRESENT	0
516127	502377	08017T	PARTICIPANT	\N	PRESENT	0
516130	502377	19782L	PARTICIPANT	\N	PRESENT	0
516133	502377	19966S	PARTICIPANT	\N	PRESENT	0
516149	502377	11040E	PARTICIPANT	\N	PRESENT	0
516136	502377	19693L	PARTICIPANT	\N	PRESENT	0
516140	502377	20124W	PARTICIPANT	\N	PRESENT	0
516141	502377	11056N	PARTICIPANT	\N	PRESENT	0
516142	502377	19709B	PARTICIPANT	\N	PRESENT	0
516143	502377	17589D	PARTICIPANT	\N	PRESENT	0
516144	502377	10015M	PARTICIPANT	\N	PRESENT	0
516145	502377	14147R	PARTICIPANT	\N	PRESENT	0
516146	502377	14229S	PARTICIPANT	\N	PRESENT	0
516147	502377	14033T	PARTICIPANT	\N	PRESENT	0
516148	502377	20104S	PARTICIPANT	\N	PRESENT	0
516210	502378	14026U	PARTICIPANT	\N	PRESENT	0
516211	502378	20142Y	PARTICIPANT	\N	PRESENT	0
516212	502378	19611R	PARTICIPANT	\N	PRESENT	0
516213	502378	11040E	PARTICIPANT	\N	PRESENT	0
516214	502378	11056N	PARTICIPANT	\N	PRESENT	0
516215	502378	20082E	PARTICIPANT	\N	PRESENT	0
516216	502378	19631V	PARTICIPANT	\N	PRESENT	0
516217	502378	11110B	PARTICIPANT	\N	PRESENT	0
516218	502378	20064C	PARTICIPANT	\N	PRESENT	0
516219	502378	18193Q	PARTICIPANT	\N	PRESENT	0
516220	502378	08017T	PARTICIPANT	\N	PRESENT	0
516221	502378	14229S	PARTICIPANT	\N	PRESENT	0
516222	502378	20134Y	PARTICIPANT	\N	PRESENT	0
516223	502378	19689Q	PARTICIPANT	\N	PRESENT	0
516224	502378	11033F	PARTICIPANT	\N	PRESENT	0
516225	502378	20100N	PARTICIPANT	\N	PRESENT	0
516226	502378	19347U	PARTICIPANT	\N	PRESENT	0
516227	502378	20036X	PARTICIPANT	\N	PRESENT	0
516228	502378	20092G	PARTICIPANT	\N	PRESENT	0
516229	502378	11065P	PARTICIPANT	\N	PRESENT	0
516230	502378	11099A	PARTICIPANT	\N	PRESENT	0
516231	502378	20130U	PARTICIPANT	\N	PRESENT	0
516232	502378	20110Q	PARTICIPANT	\N	PRESENT	0
516233	502378	19329S	PARTICIPANT	\N	PRESENT	0
516234	502378	20106U	PARTICIPANT	\N	PRESENT	0
516235	502378	08061X	PARTICIPANT	\N	PRESENT	0
516236	502378	20116W	PARTICIPANT	\N	PRESENT	0
516237	502378	17589D	PARTICIPANT	\N	PRESENT	0
516238	502378	14195A	PARTICIPANT	\N	PRESENT	0
516239	502378	20052X	PARTICIPANT	\N	PRESENT	0
516240	502378	19699S	PARTICIPANT	\N	PRESENT	0
516241	502378	14073Q	PARTICIPANT	\N	PRESENT	0
516242	502378	20042V	PARTICIPANT	\N	PRESENT	0
516243	502378	14083S	PARTICIPANT	\N	PRESENT	0
516244	502378	14215L	PARTICIPANT	\N	PRESENT	0
516245	502378	19671E	PARTICIPANT	\N	PRESENT	0
516246	502378	19367Y	PARTICIPANT	\N	PRESENT	0
516247	502378	19693L	PARTICIPANT	\N	PRESENT	0
516248	502378	14055N	PARTICIPANT	\N	PRESENT	0
516249	502378	17965H	PARTICIPANT	\N	PRESENT	0
516250	502378	19629C	PARTICIPANT	\N	PRESENT	0
516251	502378	19762G	PARTICIPANT	\N	PRESENT	0
516252	502378	19399H	PARTICIPANT	\N	PRESENT	0
516253	502378	07029T	PARTICIPANT	\N	PRESENT	0
516254	502378	20096L	PARTICIPANT	\N	PRESENT	0
516255	502378	19621T	PARTICIPANT	\N	PRESENT	0
513427	502356	12041X	PARTICIPANT	\N	PRESENT	0
513428	502356	19479G	PARTICIPANT	\N	PRESENT	0
513429	502356	14253S	PARTICIPANT	\N	PRESENT	0
513430	502356	08011M	PARTICIPANT	\N	PRESENT	0
513431	502356	19399H	PARTICIPANT	\N	PRESENT	0
513432	502356	19301E	PARTICIPANT	\N	PRESENT	0
513433	502356	20070A	PARTICIPANT	\N	PRESENT	0
513434	502356	18083K	PARTICIPANT	\N	PRESENT	0
513435	502356	11040E	PARTICIPANT	\N	PRESENT	0
513436	502356	17779H	PARTICIPANT	\N	PRESENT	0
513437	502356	20022R	PARTICIPANT	\N	PRESENT	0
513438	502356	20110Q	PARTICIPANT	\N	PRESENT	0
513439	502356	19717B	PARTICIPANT	\N	PRESENT	0
513440	502356	19711U	PARTICIPANT	\N	PRESENT	0
513441	502356	19713W	PARTICIPANT	\N	PRESENT	0
513442	502356	11097X	PARTICIPANT	\N	PRESENT	0
513443	502356	19762G	PARTICIPANT	\N	PRESENT	0
513444	502356	14331P	PARTICIPANT	\N	PRESENT	0
513445	502356	07004J	PARTICIPANT	\N	PRESENT	0
513449	502356	20036X	PARTICIPANT	\N	PRESENT	0
513447	502356	14215L	PARTICIPANT	\N	PRESENT	0
513448	502356	11099A	PARTICIPANT	\N	PRESENT	0
513450	502356	20094J	PARTICIPANT	\N	PRESENT	0
513451	502356	20062A	PARTICIPANT	\N	PRESENT	0
513452	502356	11012A	PARTICIPANT	\N	PRESENT	0
513453	502356	20126Y	PARTICIPANT	\N	PRESENT	0
513454	502356	19565D	PARTICIPANT	\N	PRESENT	0
513455	502356	19687N	PARTICIPANT	\N	PRESENT	0
513456	502356	14071N	PARTICIPANT	\N	PRESENT	0
513457	502356	14053L	PARTICIPANT	\N	PRESENT	0
513458	502356	20122U	PARTICIPANT	\N	PRESENT	0
513459	502356	20080C	PARTICIPANT	\N	PRESENT	0
513460	502356	19747H	PARTICIPANT	\N	PRESENT	0
513461	502356	11072N	PARTICIPANT	\N	PRESENT	0
513462	502356	20058E	PARTICIPANT	\N	PRESENT	0
513463	502356	19723Y	PARTICIPANT	\N	PRESENT	0
513464	502356	19577H	PARTICIPANT	\N	PRESENT	0
513465	502356	19749K	PARTICIPANT	\N	PRESENT	0
513466	502356	19954N	PARTICIPANT	\N	PRESENT	0
513467	502356	20152B	PARTICIPANT	\N	PRESENT	0
513469	502356	20034V	PARTICIPANT	\N	PRESENT	0
513470	502356	14213J	PARTICIPANT	\N	PRESENT	0
513471	502356	11074Q	PARTICIPANT	\N	PRESENT	0
513472	502356	07029T	PARTICIPANT	\N	PRESENT	0
513473	502356	14225N	PARTICIPANT	\N	PRESENT	0
513474	502356	11053K	PARTICIPANT	\N	PRESENT	0
513475	502356	19657G	PARTICIPANT	\N	PRESENT	0
513476	502356	11085T	PARTICIPANT	\N	PRESENT	0
513477	502356	19531S	PARTICIPANT	\N	PRESENT	0
513478	502356	12016W	PARTICIPANT	\N	PRESENT	0
513479	502356	11048N	PARTICIPANT	\N	PRESENT	0
513480	502356	20054A	PARTICIPANT	\N	PRESENT	0
513481	502356	01057W	PARTICIPANT	\N	PRESENT	0
513482	502356	19503N	PARTICIPANT	\N	PRESENT	0
513483	502356	19583F	PARTICIPANT	\N	PRESENT	0
513484	502356	19663E	PARTICIPANT	\N	PRESENT	0
513485	502356	08010L	PARTICIPANT	\N	PRESENT	0
513486	502356	04033B	PARTICIPANT	\N	PRESENT	0
513487	502356	08034U	PARTICIPANT	\N	PRESENT	0
513488	502356	19741B	PARTICIPANT	\N	PRESENT	0
513489	502356	20050V	PARTICIPANT	\N	PRESENT	0
513490	502356	19647E	PARTICIPANT	\N	PRESENT	0
513491	502356	11077T	PARTICIPANT	\N	PRESENT	0
513492	502356	20124W	PARTICIPANT	\N	PRESENT	0
513493	502356	19335Q	PARTICIPANT	\N	PRESENT	0
513494	502356	20150Y	PARTICIPANT	\N	PRESENT	0
513495	502356	04071H	PARTICIPANT	\N	PRESENT	0
513496	502356	11090Q	PARTICIPANT	\N	PRESENT	0
513497	502356	19826F	PARTICIPANT	\N	PRESENT	0
513498	502356	11026G	PARTICIPANT	\N	PRESENT	0
513499	502356	19629C	PARTICIPANT	\N	PRESENT	0
513502	502356	19701S	PARTICIPANT	\N	PRESENT	0
513503	502356	01048V	PARTICIPANT	\N	PRESENT	0
513504	502356	04086Q	PARTICIPANT	\N	PRESENT	0
513505	502356	14069U	PARTICIPANT	\N	PRESENT	0
513577	502357	19711U	PARTICIPANT	\N	PRESENT	0
513578	502357	04086Q	PARTICIPANT	\N	PRESENT	0
513579	502357	12016W	PARTICIPANT	\N	PRESENT	0
513580	502357	19693L	PARTICIPANT	\N	PRESENT	0
513581	502357	20054A	PARTICIPANT	\N	PRESENT	0
513582	502357	08034U	PARTICIPANT	\N	PRESENT	0
513583	502357	19399H	PARTICIPANT	\N	PRESENT	0
513584	502357	19667J	PARTICIPANT	\N	PRESENT	0
513585	502357	11048N	PARTICIPANT	\N	PRESENT	0
513586	502357	20070A	PARTICIPANT	\N	PRESENT	0
513587	502357	19647E	PARTICIPANT	\N	PRESENT	0
513588	502357	20080C	PARTICIPANT	\N	PRESENT	0
513589	502357	14225N	PARTICIPANT	\N	PRESENT	0
513590	502357	20036X	PARTICIPANT	\N	PRESENT	0
513591	502357	11074Q	PARTICIPANT	\N	PRESENT	0
513592	502357	11040E	PARTICIPANT	\N	PRESENT	0
513593	502357	19717B	PARTICIPANT	\N	PRESENT	0
513594	502357	19629C	PARTICIPANT	\N	PRESENT	0
513595	502357	07004J	PARTICIPANT	\N	PRESENT	0
513596	502357	19335Q	PARTICIPANT	\N	PRESENT	0
513597	502357	11053K	PARTICIPANT	\N	PRESENT	0
513598	502357	20062A	PARTICIPANT	\N	PRESENT	0
513599	502357	19723Y	PARTICIPANT	\N	PRESENT	0
513600	502357	04033B	PARTICIPANT	\N	PRESENT	0
513601	502357	07029T	PARTICIPANT	\N	PRESENT	0
513602	502357	19747H	PARTICIPANT	\N	PRESENT	0
513603	502357	19685L	PARTICIPANT	\N	PRESENT	0
513604	502357	20022R	PARTICIPANT	\N	PRESENT	0
513605	502357	20094J	PARTICIPANT	\N	PRESENT	0
513606	502357	19671E	PARTICIPANT	\N	PRESENT	0
513607	502357	20150Y	PARTICIPANT	\N	PRESENT	0
513608	502357	20050V	PARTICIPANT	\N	PRESENT	0
513609	502357	11012A	PARTICIPANT	\N	PRESENT	0
513610	502357	11090Q	PARTICIPANT	\N	PRESENT	0
513611	502357	20034V	PARTICIPANT	\N	PRESENT	0
513612	502357	20058E	PARTICIPANT	\N	PRESENT	0
513613	502357	19749K	PARTICIPANT	\N	PRESENT	0
513614	502357	19651A	PARTICIPANT	\N	PRESENT	0
513615	502357	19575F	PARTICIPANT	\N	PRESENT	0
513616	502357	19565D	PARTICIPANT	\N	PRESENT	0
516000	513170	14133K	PARTICIPANT	\N	PRESENT	1
516002	513170	14189C	PARTICIPANT	\N	PRESENT	0
516003	513170	20094J	PARTICIPANT	\N	PRESENT	1
516004	513170	14089Y	PARTICIPANT	\N	PRESENT	1
516006	513170	20104S	PARTICIPANT	\N	PRESENT	0
516007	513170	14357A	PARTICIPANT	\N	PRESENT	0
516008	513170	20100N	PARTICIPANT	\N	PRESENT	0
516009	513170	04035D	PARTICIPANT	\N	PRESENT	0
516010	513170	11083R	PARTICIPANT	\N	PRESENT	0
516011	513170	19531S	PARTICIPANT	\N	PRESENT	0
516013	513170	14097Y	PARTICIPANT	\N	PRESENT	1
516015	513170	14073Q	PARTICIPANT	\N	PRESENT	0
516017	513170	19711U	PARTICIPANT	\N	PRESENT	0
516018	513170	11026G	PARTICIPANT	\N	PRESENT	0
516020	513170	19441R	PARTICIPANT	\N	PRESENT	0
516024	513170	04057K	PARTICIPANT	\N	PRESENT	0
516025	513170	14169X	PARTICIPANT	\N	PRESENT	1
516026	513170	14237S	PARTICIPANT	\N	PRESENT	0
516027	513170	14331P	PRESIDENT	0	PRESENT	0
516031	513170	10015M	PARTICIPANT	\N	PRESENT	0
516033	513170	20098N	PARTICIPANT	\N	PRESENT	0
516059	516058	14231L	PRESIDENT	0	PRESENT	0
516088	512838	19760E	PARTICIPANT	\N	PRESENT	0
516089	512838	19515S	PRESIDENT	0	PRESENT	0
516090	512838	19575F	PARTICIPANT	\N	PRESENT	0
516092	512838	20094J	PARTICIPANT	\N	PRESENT	0
516093	512838	14105F	PARTICIPANT	\N	PRESENT	0
516094	512838	14083S	PARTICIPANT	\N	PRESENT	0
516095	512838	14329V	PARTICIPANT	\N	PRESENT	0
513575	502357	08073C	PARTICIPANT	\N	PRESENT	0
513576	502357	19954N	PARTICIPANT	\N	PRESENT	0
516096	512838	14195A	PARTICIPANT	\N	PRESENT	0
516097	512838	19467C	PARTICIPANT	\N	PRESENT	0
516098	512838	14041T	PARTICIPANT	\N	PRESENT	0
516099	512838	20040T	PARTICIPANT	\N	PRESENT	0
516100	512838	19695N	PARTICIPANT	\N	PRESENT	0
516102	512838	20126Y	PARTICIPANT	\N	PRESENT	0
516103	512838	08015R	PARTICIPANT	\N	PRESENT	0
516104	512838	16685X	PARTICIPANT	\N	PRESENT	0
516105	512838	19697Q	PARTICIPANT	\N	PRESENT	0
516106	512838	19671E	PARTICIPANT	\N	PRESENT	0
516107	512838	20082E	PARTICIPANT	\N	PRESENT	0
516108	512838	19762G	PARTICIPANT	\N	PRESENT	0
516110	512838	08060W	PARTICIPANT	\N	EXCUSE	0
516111	512838	08028W	PARTICIPANT	\N	EXCUSE	0
516112	512838	14357A	PARTICIPANT	\N	EXCUSE	0
527464	526487	19543W	PARTICIPANT	\N	PRESENT	0
527469	526487	14179A	PARTICIPANT	\N	PRESENT	0
527470	526491	14327T	PARTICIPANT	\N	PRESENT	0
527471	526491	19479G	PARTICIPANT	\N	PRESENT	0
527472	526491	11048N	PARTICIPANT	\N	PRESENT	0
527473	526491	20036X	PARTICIPANT	\N	PRESENT	0
527474	526491	19711U	PARTICIPANT	\N	PRESENT	0
527475	526491	11053K	PARTICIPANT	\N	PRESENT	0
527476	526491	19667J	PARTICIPANT	\N	PRESENT	0
527477	526491	14225N	PRESIDENT	0	PRESENT	0
527478	526491	11012A	PARTICIPANT	\N	PRESENT	0
527479	526491	19349W	PARTICIPANT	\N	PRESENT	0
527480	526491	14253S	PARTICIPANT	\N	PRESENT	0
527481	526491	20022R	PARTICIPANT	\N	PRESENT	0
527482	526491	20126Y	PARTICIPANT	\N	PRESENT	0
527483	526491	19762G	PARTICIPANT	\N	PRESENT	0
527974	527925	20120S	PARTICIPANT	\N	PRESENT	0
527485	526491	14331P	PARTICIPANT	\N	PRESENT	0
527486	526491	14189C	PARTICIPANT	\N	PRESENT	0
527487	526491	01057W	PARTICIPANT	\N	PRESENT	0
527488	526491	08011M	PARTICIPANT	\N	PRESENT	0
527489	526491	11040E	PARTICIPANT	\N	PRESENT	0
527490	526491	20070A	PARTICIPANT	\N	PRESENT	0
527491	526491	19335Q	PARTICIPANT	\N	PRESENT	0
527493	526491	19689Q	PARTICIPANT	\N	PRESENT	0
527494	526393	19333N	PARTICIPANT	\N	PRESENT	0
527495	526393	19701S	PARTICIPANT	\N	PRESENT	0
527496	526393	20076G	PARTICIPANT	\N	PRESENT	0
527497	526393	19549D	PARTICIPANT	\N	PRESENT	0
527498	526393	19387D	PARTICIPANT	\N	PRESENT	0
527499	526393	14219Q	PRESIDENT	0	PRESENT	0
527500	526393	19820Y	PARTICIPANT	\N	PRESENT	0
527501	526393	19826F	PARTICIPANT	\N	PRESENT	0
527502	526393	14221J	PARTICIPANT	\N	PRESENT	1
527503	526393	20102Q	PARTICIPANT	\N	PRESENT	0
527504	526393	19599P	PARTICIPANT	\N	PRESENT	0
527505	526393	19637C	PARTICIPANT	\N	PRESENT	1
527506	526393	20096L	PARTICIPANT	\N	PRESENT	0
527507	526393	18083K	PARTICIPANT	\N	PRESENT	0
527508	526393	19551W	PARTICIPANT	\N	PRESENT	0
527509	526393	14237S	PARTICIPANT	\N	PRESENT	0
527510	526393	20100N	PARTICIPANT	\N	PRESENT	0
527511	526393	05012A	PARTICIPANT	\N	PRESENT	0
527512	526393	20106U	PARTICIPANT	\N	PRESENT	0
527513	526393	08060W	PARTICIPANT	\N	PRESENT	1
527514	526393	20118Y	PARTICIPANT	\N	PRESENT	0
527515	526393	19503N	PARTICIPANT	\N	PRESENT	0
527516	526393	20020P	PARTICIPANT	\N	PRESENT	0
527517	526393	17367Q	PARTICIPANT	\N	PRESENT	0
527518	526393	19681G	PARTICIPANT	\N	PRESENT	1
527519	526393	20024T	PARTICIPANT	\N	PRESENT	0
527520	526393	11065P	PARTICIPANT	\N	PRESENT	0
527521	526393	20120S	PARTICIPANT	\N	PRESENT	1
527522	526393	19525U	PARTICIPANT	\N	PRESENT	0
527523	526393	20032T	PARTICIPANT	\N	PRESENT	0
527524	526393	20122U	PARTICIPANT	\N	PRESENT	1
527525	526393	20038A	PARTICIPANT	\N	PRESENT	0
527526	526393	14031R	PARTICIPANT	\N	PRESENT	0
527527	526393	20140W	PARTICIPANT	\N	PRESENT	0
527528	526393	14169X	PARTICIPANT	\N	PRESENT	0
527529	526393	17229F	PARTICIPANT	\N	PRESENT	0
527530	526393	20068G	PARTICIPANT	\N	PRESENT	0
527531	526393	19739H	PARTICIPANT	\N	PRESENT	1
527532	526393	19745F	PARTICIPANT	\N	PRESENT	0
527533	526393	19577H	PARTICIPANT	\N	PRESENT	1
527534	526393	19619A	PARTICIPANT	\N	PRESENT	0
527615	526549	04070G	PARTICIPANT	\N	PRESENT	1
527616	526549	19699S	PARTICIPANT	\N	PRESENT	0
527975	527925	14033T	PARTICIPANT	\N	PRESENT	0
527976	527925	19725B	PARTICIPANT	\N	PRESENT	0
527619	526549	20098N	PARTICIPANT	\N	PRESENT	0
527620	526549	19573D	PARTICIPANT	\N	PRESENT	0
527621	526549	08017T	PARTICIPANT	\N	PRESENT	1
527622	526549	20112S	PARTICIPANT	\N	PRESENT	0
527978	527925	19551W	PARTICIPANT	\N	PRESENT	0
527979	527925	19511N	PARTICIPANT	\N	PRESENT	0
527980	527925	19531S	PARTICIPANT	\N	PRESENT	0
527981	527925	14097Y	PARTICIPANT	\N	PRESENT	0
527627	526549	20026V	PARTICIPANT	\N	PRESENT	0
527982	527925	20126Y	PARTICIPANT	\N	PRESENT	0
527983	527925	11099A	PARTICIPANT	\N	PRESENT	0
527630	526549	20132W	PARTICIPANT	\N	PRESENT	1
527984	527925	19723Y	PARTICIPANT	\N	PRESENT	0
527985	527925	08015R	PARTICIPANT	\N	PRESENT	0
527633	526549	14073Q	PARTICIPANT	\N	PRESENT	0
527634	526549	19651A	PARTICIPANT	\N	PRESENT	1
527635	526549	20138D	PARTICIPANT	\N	PRESENT	0
527636	526549	19611R	PRESIDENT	0	PRESENT	0
527637	526549	20142Y	PARTICIPANT	\N	PRESENT	1
527638	526549	20048C	PARTICIPANT	\N	PRESENT	1
527639	526549	19693L	PARTICIPANT	\N	PRESENT	1
527640	526549	19399H	PARTICIPANT	\N	PRESENT	0
527641	526549	20152B	PARTICIPANT	\N	PRESENT	0
527642	526549	20052X	PARTICIPANT	\N	PRESENT	0
527986	527925	19711U	PARTICIPANT	\N	PRESENT	0
527987	527925	19441R	PARTICIPANT	\N	PRESENT	0
527645	526549	14030Q	PARTICIPANT	\N	PRESENT	0
527646	526549	20056C	PARTICIPANT	\N	PRESENT	0
527647	526549	20180F	PARTICIPANT	\N	PRESENT	1
527648	526549	04059M	PARTICIPANT	\N	PRESENT	0
527649	526549	19735D	PARTICIPANT	\N	PRESENT	0
527988	527925	19637C	PARTICIPANT	\N	PRESENT	0
527989	527925	19563B	PARTICIPANT	\N	PRESENT	0
527990	527925	20018V	PARTICIPANT	\N	PRESENT	0
527653	526549	11104D	PARTICIPANT	\N	PRESENT	0
527654	526549	20084G	PARTICIPANT	\N	PRESENT	1
527655	526549	19621T	PARTICIPANT	\N	PRESENT	0
527991	527925	19369B	PARTICIPANT	\N	PRESENT	0
527992	527925	14109K	PARTICIPANT	\N	PRESENT	0
527993	527925	14257W	PARTICIPANT	\N	PRESENT	0
527994	527925	14169X	PARTICIPANT	\N	PRESENT	0
527995	527925	19768N	PARTICIPANT	\N	PRESENT	0
527996	527925	14237S	PARTICIPANT	\N	PRESENT	0
527997	527925	19503N	PARTICIPANT	\N	PRESENT	0
527998	527925	11090Q	PARTICIPANT	\N	PRESENT	0
527999	527925	14331P	PARTICIPANT	\N	PRESENT	0
528000	527925	20082E	PARTICIPANT	\N	PRESENT	0
528001	527925	20054A	PARTICIPANT	\N	PRESENT	0
528002	527925	11097X	PARTICIPANT	\N	PRESENT	0
528003	527925	04045F	PARTICIPANT	\N	PRESENT	0
528004	527925	19762G	PARTICIPANT	\N	PRESENT	0
528005	527925	20062A	PARTICIPANT	\N	PRESENT	0
528007	527925	20026V	PARTICIPANT	\N	PRESENT	0
528009	527925	19701S	PARTICIPANT	\N	PRESENT	0
528363	526393	19251M	PARTICIPANT	\N	EXCUSE	0
528392	528391	08056B	PARTICIPANT	\N	PRESENT	0
528393	528391	08069G	PARTICIPANT	\N	PRESENT	0
528394	528391	10015M	PARTICIPANT	\N	PRESENT	0
528395	528391	20136B	PARTICIPANT	\N	PRESENT	0
528396	528391	20064C	PARTICIPANT	\N	PRESENT	0
528398	528397	19713W	PARTICIPANT	\N	PRESENT	0
529629	529621	11026G	PARTICIPANT	\N	PRESENT	0
530193	529239	14179A	PARTICIPANT	\N	PRESENT	0
530194	529239	04008A	PARTICIPANT	\N	PRESENT	1
530195	529239	19649G	PARTICIPANT	\N	PRESENT	1
530196	529239	14151M	PARTICIPANT	\N	PRESENT	1
530197	529239	14107H	PARTICIPANT	\N	PRESENT	1
530198	529240	14179A	PARTICIPANT	\N	PRESENT	0
530199	529240	04008A	PARTICIPANT	\N	PRESENT	1
530200	529240	14151M	PARTICIPANT	\N	PRESENT	1
530254	530253	01043Q	PARTICIPANT	\N	PRESENT	0
530255	530253	19631V	PARTICIPANT	\N	PRESENT	0
530256	530253	14187A	PARTICIPANT	\N	PRESENT	0
530721	530720	14069U	PARTICIPANT	\N	PRESENT	0
530722	530720	11072N	PARTICIPANT	\N	PRESENT	0
530724	530723	14069U	PARTICIPANT	\N	PRESENT	0
530726	530723	11072N	PARTICIPANT	\N	PRESENT	0
531419	531159	19533U	PARTICIPANT	\N	PRESENT	0
531420	531159	19593H	PARTICIPANT	\N	PRESENT	0
531421	531159	14123H	PARTICIPANT	\N	PRESENT	0
531422	531159	14030Q	PARTICIPANT	\N	PRESENT	0
531423	531159	19621T	PARTICIPANT	\N	PRESENT	0
531424	531160	20134Y	PARTICIPANT	\N	PRESENT	0
531425	531160	19399H	PARTICIPANT	\N	PRESENT	0
531426	531160	19593H	PARTICIPANT	\N	PRESENT	0
531427	531160	08012N	PARTICIPANT	\N	PRESENT	0
531428	531160	11043H	PARTICIPANT	\N	PRESENT	0
531430	531429	19593H	PARTICIPANT	\N	PRESENT	0
531431	531429	20052X	PARTICIPANT	\N	PRESENT	0
531432	531429	20134Y	PARTICIPANT	\N	PRESENT	0
531433	531429	20138D	PARTICIPANT	\N	PRESENT	0
521568	521567	14207L	PARTICIPANT	\N	PRESENT	0
521569	521567	01025N	PARTICIPANT	\N	PRESENT	0
521570	521567	11099A	PARTICIPANT	\N	PRESENT	0
521571	521567	11090Q	PARTICIPANT	\N	PRESENT	0
521572	521567	19447X	PARTICIPANT	\N	PRESENT	0
521573	521567	16685X	PARTICIPANT	\N	PRESENT	0
529200	529199	01024M	PARTICIPANT	\N	PRESENT	0
529206	529205	20152B	PARTICIPANT	\N	PRESENT	0
529207	529205	20134Y	PARTICIPANT	\N	PRESENT	0
529208	529205	19593H	PARTICIPANT	\N	PRESENT	0
529209	529205	19533U	PARTICIPANT	\N	PRESENT	0
529210	529205	19621T	PARTICIPANT	\N	PRESENT	0
529211	529205	14030Q	PARTICIPANT	\N	PRESENT	0
529212	529205	20052X	PARTICIPANT	\N	PRESENT	0
529214	529213	20134Y	PARTICIPANT	\N	PRESENT	0
529215	529213	20152B	PARTICIPANT	\N	PRESENT	0
529216	529213	19621T	PARTICIPANT	\N	PRESENT	0
529217	529213	19533U	PARTICIPANT	\N	PRESENT	0
529218	529213	19593H	PARTICIPANT	\N	PRESENT	0
529220	529219	20152B	PARTICIPANT	\N	PRESENT	0
529221	529219	20134Y	PARTICIPANT	\N	PRESENT	0
529222	529219	19621T	PARTICIPANT	\N	PRESENT	0
529223	529219	19533U	PARTICIPANT	\N	PRESENT	0
529224	529219	20052X	PARTICIPANT	\N	PRESENT	0
529225	529219	14030Q	PARTICIPANT	\N	PRESENT	0
529226	527033	01028R	PARTICIPANT	\N	EXCUSE	0
529227	527033	04070G	PARTICIPANT	\N	PRESENT	0
531140	530840	19691J	PARTICIPANT	\N	PRESENT	0
533661	530826	11067R	PARTICIPANT	\N	PRESENT	0
533662	530826	04057K	PARTICIPANT	\N	PRESENT	1
533663	530826	19798U	PARTICIPANT	\N	PRESENT	1
533664	530826	19713W	PARTICIPANT	\N	PRESENT	1
533665	530826	11097X	PARTICIPANT	\N	PRESENT	0
533666	530826	08045X	PARTICIPANT	\N	PRESENT	1
533667	530826	20040T	PARTICIPANT	\N	PRESENT	0
533668	530826	19301E	PARTICIPANT	\N	PRESENT	1
533669	530826	14223L	PARTICIPANT	\N	PRESENT	1
533670	530826	19703U	PARTICIPANT	\N	PRESENT	0
533671	530826	11031D	PARTICIPANT	\N	PRESENT	1
533672	530826	20066E	PARTICIPANT	\N	PRESENT	1
533673	530826	19679N	PARTICIPANT	\N	PRESENT	1
533674	530826	11103C	PARTICIPANT	\N	PRESENT	1
533675	530826	14042U	PARTICIPANT	\N	PRESENT	0
533676	530826	14195A	PARTICIPANT	\N	PRESENT	0
533677	530826	14213J	PARTICIPANT	\N	PRESENT	1
533678	530826	14071N	PARTICIPANT	\N	PRESENT	0
533679	530826	14217N	PARTICIPANT	\N	PRESENT	0
533680	530826	10006L	PRESIDENT	0	PRESENT	0
533681	530826	19760E	PARTICIPANT	\N	PRESENT	1
533682	530826	19591F	PARTICIPANT	\N	PRESENT	1
533697	531659	11070L	PARTICIPANT	\N	PRESENT	0
533733	531659	18193Q	PARTICIPANT	\N	PRESENT	0
533734	531659	14195A	PARTICIPANT	\N	PRESENT	0
533735	531659	20130U	PARTICIPANT	\N	PRESENT	0
533736	531659	20100N	PARTICIPANT	\N	PRESENT	0
533737	531659	17779H	PARTICIPANT	\N	PRESENT	0
533738	531659	14042U	PARTICIPANT	\N	PRESENT	0
533739	531659	20048C	PARTICIPANT	\N	PRESENT	0
533740	531659	20066E	PARTICIPANT	\N	PRESENT	0
533741	531659	14073Q	PARTICIPANT	\N	PRESENT	0
533742	531659	19301E	PARTICIPANT	\N	PRESENT	0
533743	531659	14041T	PARTICIPANT	\N	PRESENT	0
533744	531659	20090E	PARTICIPANT	\N	PRESENT	0
533745	531659	19711U	PARTICIPANT	\N	PRESENT	0
533746	531659	19569H	PARTICIPANT	\N	PRESENT	0
533747	531659	20128B	PARTICIPANT	\N	PRESENT	0
533748	531659	17965H	PARTICIPANT	\N	PRESENT	0
533749	531659	14219Q	PARTICIPANT	\N	PRESENT	0
533750	531659	04092N	PARTICIPANT	\N	PRESENT	0
533751	531659	14147R	PARTICIPANT	\N	PRESENT	0
533752	531659	19747H	PARTICIPANT	\N	PRESENT	0
533753	531659	11083R	PARTICIPANT	\N	PRESENT	0
533754	531659	14217N	PARTICIPANT	\N	PRESENT	0
533755	531659	14059S	PARTICIPANT	\N	PRESENT	0
533756	531659	19683J	PARTICIPANT	\N	PRESENT	0
533757	531659	19760E	PARTICIPANT	\N	PRESENT	0
533758	531659	19553Y	PARTICIPANT	\N	PRESENT	0
533759	531659	10006L	PARTICIPANT	\N	PRESENT	0
533760	531659	11067R	PARTICIPANT	\N	PRESENT	0
533761	531659	19723Y	PARTICIPANT	\N	PRESENT	0
533762	531659	20070A	PARTICIPANT	\N	PRESENT	0
533763	531659	08034U	PARTICIPANT	\N	PRESENT	0
533764	531659	11031D	PARTICIPANT	\N	PRESENT	0
533765	531659	97011G	PARTICIPANT	\N	PRESENT	0
533766	531659	19503N	PARTICIPANT	\N	PRESENT	0
533767	531659	20132W	PARTICIPANT	\N	PRESENT	0
533768	531659	14215L	PARTICIPANT	\N	PRESENT	0
533769	531659	19467C	PARTICIPANT	\N	PRESENT	0
533770	531659	19657G	PARTICIPANT	\N	PRESENT	0
533771	531659	19533U	PARTICIPANT	\N	PRESENT	0
533772	531659	14071N	PARTICIPANT	\N	PRESENT	0
533773	531659	11097X	PARTICIPANT	\N	PRESENT	0
533775	531659	99004R	PARTICIPANT	\N	PRESENT	0
533776	531659	19447X	PARTICIPANT	\N	PRESENT	0
533777	531659	14123H	PARTICIPANT	\N	PRESENT	0
533778	531659	14021P	PARTICIPANT	\N	PRESENT	0
533780	531659	19713W	PARTICIPANT	\N	PRESENT	0
533781	531659	14069U	PARTICIPANT	\N	PRESENT	0
533782	531659	19441R	PARTICIPANT	\N	PRESENT	0
533783	531659	20028X	PARTICIPANT	\N	PRESENT	0
533784	531659	20022R	PARTICIPANT	\N	PRESENT	0
533785	531659	08018U	PARTICIPANT	\N	PRESENT	0
533786	531659	14225N	PARTICIPANT	\N	PRESENT	0
533787	531659	20052X	PARTICIPANT	\N	PRESENT	0
533788	531659	20098N	PARTICIPANT	\N	PRESENT	0
533789	531659	08010L	PARTICIPANT	\N	PRESENT	0
533791	531659	19709B	PARTICIPANT	\N	PRESENT	0
533801	531659	14083S	PARTICIPANT	\N	PRESENT	0
533802	531659	14089Y	PARTICIPANT	\N	PRESENT	0
533803	531659	11012A	PARTICIPANT	\N	PRESENT	0
533850	531374	20114U	PARTICIPANT	\N	PRESENT	0
533851	531374	14055N	PARTICIPANT	\N	PRESENT	0
533852	531374	19581D	PARTICIPANT	\N	PRESENT	0
533853	531374	11033F	PARTICIPANT	\N	PRESENT	0
533854	531374	11072N	PARTICIPANT	\N	PRESENT	0
533855	531374	11012A	PARTICIPANT	\N	PRESENT	0
533856	531374	11056N	PARTICIPANT	\N	PRESENT	0
533857	531374	14089Y	PARTICIPANT	\N	PRESENT	0
533858	531374	20050V	PARTICIPANT	\N	PRESENT	0
533859	531374	20086J	PARTICIPANT	\N	PRESENT	0
533860	531374	19399H	PARTICIPANT	\N	PRESENT	0
533884	531374	19333N	PARTICIPANT	\N	PRESENT	0
533885	531374	20082E	PARTICIPANT	\N	PRESENT	0
533886	531374	20040T	PARTICIPANT	\N	PRESENT	0
533887	531374	20090E	PARTICIPANT	\N	PRESENT	0
533888	531374	97011G	PARTICIPANT	\N	PRESENT	0
533889	531374	14215L	PARTICIPANT	\N	PRESENT	0
533890	531374	20080C	PARTICIPANT	\N	PRESENT	0
533891	531374	19651A	PARTICIPANT	\N	PRESENT	0
533892	531374	95063L	PARTICIPANT	\N	PRESENT	0
533893	531374	04085P	PARTICIPANT	\N	PRESENT	0
533894	531374	17637T	PARTICIPANT	\N	PRESENT	0
533895	531374	19711U	PARTICIPANT	\N	PRESENT	0
533896	531374	11067R	PARTICIPANT	\N	PRESENT	0
533897	531374	14147R	PARTICIPANT	\N	PRESENT	0
533898	531374	19467C	PARTICIPANT	\N	PRESENT	0
533899	531374	17737W	PARTICIPANT	\N	PRESENT	0
533900	531374	19747H	PARTICIPANT	\N	PRESENT	0
533901	531374	08010L	PARTICIPANT	\N	PRESENT	0
533902	531374	19643A	PARTICIPANT	\N	PRESENT	0
533903	531374	14041T	PARTICIPANT	\N	PRESENT	0
533904	531374	20098N	PARTICIPANT	\N	PRESENT	0
533905	531374	19649G	PARTICIPANT	\N	PRESENT	0
533906	531374	20108W	PARTICIPANT	\N	PRESENT	0
533907	531374	04047H	PARTICIPANT	\N	PRESENT	0
533908	531374	20028X	PARTICIPANT	\N	PRESENT	0
533909	531374	99004R	PARTICIPANT	\N	PRESENT	0
533926	531374	19611R	PARTICIPANT	\N	PRESENT	0
533933	531374	19695N	PARTICIPANT	\N	PRESENT	0
533947	531374	19585H	PARTICIPANT	\N	PRESENT	0
533948	531374	20048C	PARTICIPANT	\N	PRESENT	0
533949	531374	19573D	PARTICIPANT	\N	PRESENT	0
533951	531374	19447X	PARTICIPANT	\N	PRESENT	0
533961	531374	19489J	PARTICIPANT	\N	PRESENT	0
533848	531374	14026U	PARTICIPANT	\N	PRESENT	0
533849	531374	14111D	PARTICIPANT	\N	PRESENT	0
533962	531374	19709B	PARTICIPANT	\N	PRESENT	0
533963	531374	20110Q	PARTICIPANT	\N	PRESENT	0
533964	531374	05008E	PARTICIPANT	\N	PRESENT	0
516258	502378	20098N	PARTICIPANT	\N	PRESENT	0
516259	502378	20084G	PARTICIPANT	\N	PRESENT	0
516260	502378	19593H	PARTICIPANT	\N	PRESENT	0
516261	502378	20046A	PARTICIPANT	\N	PRESENT	0
516262	502378	20112S	PARTICIPANT	\N	PRESENT	0
516263	502378	14179A	PARTICIPANT	\N	PRESENT	0
516264	502378	20114U	PARTICIPANT	\N	PRESENT	0
516265	502378	19820Y	PARTICIPANT	\N	PRESENT	0
516266	502378	14021P	PARTICIPANT	\N	PRESENT	0
516267	502378	11027H	PARTICIPANT	\N	PRESENT	0
516270	502378	14069U	PARTICIPANT	\N	PRESENT	0
516271	502378	19447X	PARTICIPANT	\N	PRESENT	0
516256	502378	10015M	PARTICIPANT	\N	PRESENT	0
516257	502378	20124W	PARTICIPANT	\N	PRESENT	0
516272	502378	20104S	PARTICIPANT	\N	PRESENT	0
516273	502378	14030Q	PARTICIPANT	\N	PRESENT	0
516274	502378	11072N	PARTICIPANT	\N	PRESENT	0
516275	502378	19569H	PARTICIPANT	\N	PRESENT	0
516358	502387	11065P	PARTICIPANT	\N	PRESENT	0
516359	502387	14229S	PARTICIPANT	\N	PRESENT	0
516360	502387	20096L	PARTICIPANT	\N	PRESENT	0
516361	502387	20124W	PARTICIPANT	\N	PRESENT	0
516362	502387	20112S	PARTICIPANT	\N	PRESENT	0
516374	516373	14083S	PARTICIPANT	\N	PRESENT	0
516375	516373	19701S	PARTICIPANT	\N	PRESENT	0
516376	516373	11056N	PARTICIPANT	\N	PRESENT	0
516377	516373	14179A	PARTICIPANT	\N	PRESENT	0
516378	516373	11026G	PARTICIPANT	\N	PRESENT	0
516452	513468	20070A	PARTICIPANT	\N	PRESENT	0
516380	516373	19585H	PARTICIPANT	\N	PRESENT	0
516451	513468	20022R	PARTICIPANT	\N	PRESENT	0
516453	513468	19671E	PARTICIPANT	\N	PRESENT	0
516454	513468	99004R	PARTICIPANT	\N	PRESENT	0
516455	513468	20126Y	PARTICIPANT	\N	PRESENT	0
516456	513468	19667J	PARTICIPANT	\N	PRESENT	0
516458	513468	19687N	PARTICIPANT	\N	PRESENT	0
516460	513468	20150Y	PARTICIPANT	\N	PRESENT	0
516462	513468	19711U	PARTICIPANT	\N	PRESENT	0
516464	513468	19647E	PARTICIPANT	\N	PRESENT	0
516467	513468	14225N	PRESIDENT	0	PRESENT	0
516470	513468	01048V	PARTICIPANT	\N	PRESENT	0
516473	513468	11048N	PARTICIPANT	\N	PRESENT	1
516474	513468	19741B	PARTICIPANT	\N	PRESENT	1
516476	513468	11053K	PARTICIPANT	\N	PRESENT	1
516477	513468	04086Q	PARTICIPANT	\N	PRESENT	1
516478	513468	12016W	PARTICIPANT	\N	PRESENT	1
516479	513468	19349W	PARTICIPANT	\N	PRESENT	1
516482	513468	19762G	PARTICIPANT	\N	PRESENT	1
516485	513468	20050V	PARTICIPANT	\N	EXCUSE	0
516487	513468	19545Y	PARTICIPANT	\N	EXCUSE	0
516490	513468	20080C	PARTICIPANT	\N	EXCUSE	0
516495	513468	14123H	PARTICIPANT	\N	PRESENT	0
516508	516507	19735D	PARTICIPANT	\N	PRESENT	0
516509	516507	19723Y	PARTICIPANT	\N	PRESENT	0
516515	502356	19651A	PARTICIPANT	\N	PRESENT	0
516519	516517	19735D	PARTICIPANT	\N	PRESENT	0
516520	516517	19723Y	PARTICIPANT	\N	PRESENT	0
516646	516644	19735D	PARTICIPANT	\N	PRESENT	0
516647	516644	19723Y	PARTICIPANT	\N	PRESENT	0
516654	516652	19735D	PARTICIPANT	\N	PRESENT	0
516655	516652	19723Y	PARTICIPANT	\N	PRESENT	0
516356	502387	11070L	PARTICIPANT	\N	PRESENT	0
516357	502387	14073Q	PARTICIPANT	\N	PRESENT	0
516660	516658	19735D	PARTICIPANT	\N	PRESENT	0
516661	516658	19723Y	PARTICIPANT	\N	PRESENT	0
516666	516664	19735D	PARTICIPANT	\N	PRESENT	0
516667	516664	19723Y	PARTICIPANT	\N	PRESENT	0
516675	516674	20110Q	PARTICIPANT	\N	PRESENT	0
516907	516381	14231L	PARTICIPANT	\N	EXCUSE	0
516677	516674	19565D	PARTICIPANT	\N	PRESENT	0
516678	516674	08012N	PARTICIPANT	\N	PRESENT	0
516679	516674	20034V	PARTICIPANT	\N	PRESENT	0
516680	516674	19585H	PARTICIPANT	\N	PRESENT	0
516681	516674	04043D	PARTICIPANT	\N	PRESENT	0
516682	516674	20150Y	PARTICIPANT	\N	PRESENT	0
516906	516381	19489J	PARTICIPANT	\N	PRESENT	1
516908	516381	07004J	PARTICIPANT	\N	EXCUSE	0
517598	515076	19383Y	PARTICIPANT	\N	PRESENT	0
517599	515076	19768N	PARTICIPANT	\N	PRESENT	1
517608	511871	20106U	PARTICIPANT	\N	PRESENT	0
517622	511871	05012A	PARTICIPANT	\N	PRESENT	0
517657	511871	19551W	PARTICIPANT	\N	PRESENT	0
517658	511871	17229F	PARTICIPANT	\N	PRESENT	0
517751	516382	11033F	PARTICIPANT	\N	PRESENT	1
517752	516382	14069U	PARTICIPANT	\N	PRESENT	1
517753	516382	19629C	PARTICIPANT	\N	PRESENT	1
517754	516382	04008A	PARTICIPANT	\N	PRESENT	0
517755	516382	14215L	PARTICIPANT	\N	PRESENT	1
517756	516382	14151M	PARTICIPANT	\N	PRESENT	1
517757	516382	19725B	PARTICIPANT	\N	PRESENT	1
517758	516382	14179A	PARTICIPANT	\N	PRESENT	1
517759	516382	04085P	PARTICIPANT	\N	PRESENT	1
518636	518635	14133K	PARTICIPANT	\N	PRESENT	0
518644	516058	19758L	PARTICIPANT	\N	PRESENT	0
518645	516058	19333N	PARTICIPANT	\N	PRESENT	0
518646	516058	05012A	PARTICIPANT	\N	PRESENT	0
518647	516058	19349W	PARTICIPANT	\N	PRESENT	0
518648	516058	14281W	PARTICIPANT	\N	PRESENT	0
518649	516058	01057W	PARTICIPANT	\N	PRESENT	0
518650	516058	19826F	PARTICIPANT	\N	PRESENT	0
518651	516058	14053L	PARTICIPANT	\N	PRESENT	0
518652	516058	04086Q	PARTICIPANT	\N	PRESENT	0
518653	516058	08010L	PARTICIPANT	\N	PRESENT	0
518654	516058	20090E	PARTICIPANT	\N	PRESENT	0
518655	516058	14215L	PARTICIPANT	\N	PRESENT	0
518656	516058	20084G	PARTICIPANT	\N	PRESENT	0
518657	516058	19489J	PARTICIPANT	\N	PRESENT	0
518658	516058	14229S	PARTICIPANT	\N	PRESENT	0
518659	516058	14257W	PARTICIPANT	\N	PRESENT	0
518660	516058	14205J	PARTICIPANT	\N	PRESENT	0
518661	516058	19565D	PARTICIPANT	\N	PRESENT	0
518662	516058	04045F	PARTICIPANT	\N	PRESENT	0
518663	516058	14327T	PARTICIPANT	\N	PRESENT	0
518664	516058	14069U	PARTICIPANT	\N	PRESENT	0
518665	516058	20120S	PARTICIPANT	\N	PRESENT	0
518666	516058	14107H	PARTICIPANT	\N	PRESENT	0
518667	516058	20058E	PARTICIPANT	\N	PRESENT	0
518669	516547	08012N	PARTICIPANT	\N	PRESENT	0
518670	516547	17589D	PARTICIPANT	\N	PRESENT	0
518671	516547	20056C	PARTICIPANT	\N	PRESENT	0
518672	516547	20026V	PARTICIPANT	\N	PRESENT	0
518676	513049	08010L	PARTICIPANT	\N	PRESENT	0
518761	518760	19669L	PARTICIPANT	\N	PRESENT	0
518762	518760	19687N	PARTICIPANT	\N	PRESENT	0
518763	518760	19591F	PARTICIPANT	\N	PRESENT	0
518764	518760	19347U	PARTICIPANT	\N	PRESENT	0
518765	518760	18083K	PARTICIPANT	\N	PRESENT	0
518766	518760	20114U	PARTICIPANT	\N	PRESENT	0
518768	518767	19729F	PARTICIPANT	\N	PRESENT	1
518770	518769	19729F	PARTICIPANT	\N	PRESENT	1
518772	518771	19729F	PARTICIPANT	\N	PRESENT	1
518774	518773	11072N	PARTICIPANT	\N	PRESENT	0
518775	518773	19503N	PARTICIPANT	\N	PRESENT	0
516113	512838	14026U	PARTICIPANT	\N	EXCUSE	0
516114	512838	20048C	PARTICIPANT	\N	EXCUSE	0
516115	512838	19369B	PARTICIPANT	\N	EXCUSE	0
516116	512838	20092G	PARTICIPANT	\N	EXCUSE	0
519250	519248	17779H	PARTICIPANT	\N	PRESENT	0
519251	519249	17779H	PARTICIPANT	\N	PRESENT	0
519252	519249	17965H	PARTICIPANT	\N	PRESENT	0
519269	519268	19711U	PARTICIPANT	\N	PRESENT	0
519270	519268	19647E	PARTICIPANT	\N	PRESENT	0
519271	519268	04033B	PARTICIPANT	\N	PRESENT	0
519272	519268	20132W	PARTICIPANT	\N	PRESENT	0
519273	519268	97011G	PARTICIPANT	\N	PRESENT	0
519274	519268	20058E	PARTICIPANT	\N	PRESENT	0
519275	519268	14187A	PARTICIPANT	\N	PRESENT	0
519276	519268	20114U	PARTICIPANT	\N	PRESENT	0
519277	519268	19591F	PARTICIPANT	\N	PRESENT	0
519278	519268	14255U	PARTICIPANT	\N	PRESENT	0
524210	524209	08012N	PARTICIPANT	\N	PRESENT	0
524212	524211	11074Q	PARTICIPANT	\N	PRESENT	0
524215	524214	04086Q	PARTICIPANT	\N	PRESENT	0
524217	524216	11048N	PARTICIPANT	\N	PRESENT	0
524238	524235	11048N	PARTICIPANT	\N	PRESENT	0
524244	524243	11048N	PARTICIPANT	\N	PRESENT	0
525256	525255	14089Y	PARTICIPANT	\N	PRESENT	0
525257	525255	11026G	PARTICIPANT	\N	PRESENT	0
526935	526689	19443T	PARTICIPANT	\N	PRESENT	1
526936	526689	20072C	PARTICIPANT	\N	PRESENT	0
526937	526689	19565D	PARTICIPANT	\N	PRESENT	1
526938	526689	04034C	PARTICIPANT	\N	PRESENT	1
526939	526689	01058X	PARTICIPANT	\N	PRESENT	1
526940	526689	16685X	PARTICIPANT	\N	PRESENT	0
526941	526689	11027H	PARTICIPANT	\N	PRESENT	0
526942	526689	04042C	PRESIDENT	0	PRESENT	0
526943	526689	11054L	PARTICIPANT	\N	PRESENT	0
526944	526689	19421M	PARTICIPANT	\N	PRESENT	0
526945	526689	19709B	PARTICIPANT	\N	PRESENT	0
526946	526689	19347U	PARTICIPANT	\N	PRESENT	0
526947	526689	97011G	PARTICIPANT	\N	PRESENT	0
526948	526689	14249W	PARTICIPANT	\N	PRESENT	0
526949	526689	08047A	PARTICIPANT	\N	PRESENT	0
526950	526689	20128B	PARTICIPANT	\N	PRESENT	1
526951	526689	04035D	PARTICIPANT	\N	PRESENT	1
526952	526689	14133K	PARTICIPANT	\N	PRESENT	0
526953	526689	01062T	PARTICIPANT	\N	PRESENT	1
526954	526689	01024M	PARTICIPANT	\N	PRESENT	0
526955	526689	14105F	PARTICIPANT	\N	PRESENT	0
526956	526689	20064C	PARTICIPANT	\N	PRESENT	0
526957	526689	14267Y	PARTICIPANT	\N	PRESENT	0
526958	526689	11083R	PARTICIPANT	\N	PRESENT	0
526959	526689	14255U	PARTICIPANT	\N	PRESENT	1
526960	526538	11033F	PARTICIPANT	\N	PRESENT	0
526961	526538	19507S	PARTICIPANT	\N	PRESENT	0
526962	526538	19383Y	PARTICIPANT	\N	PRESENT	0
526963	526538	14053L	PARTICIPANT	\N	PRESENT	0
526964	526538	04071H	PARTICIPANT	\N	PRESENT	0
526965	526538	04059M	PARTICIPANT	\N	PRESENT	0
526966	526538	19699S	PARTICIPANT	\N	PRESENT	0
526967	526538	19762G	PARTICIPANT	\N	PRESENT	0
526968	526538	19467C	PARTICIPANT	\N	PRESENT	0
526969	526538	08028W	PARTICIPANT	\N	PRESENT	0
526970	526538	19543W	PARTICIPANT	\N	PRESENT	0
526971	526538	19621T	PARTICIPANT	\N	PRESENT	0
526972	526538	19533U	PARTICIPANT	\N	PRESENT	0
526973	526538	14083S	PARTICIPANT	\N	PRESENT	0
526974	526538	19713W	PARTICIPANT	\N	PRESENT	0
526975	526538	14089Y	PARTICIPANT	\N	PRESENT	0
526976	526538	08056B	PARTICIPANT	\N	PRESENT	0
526977	526538	14059S	PARTICIPANT	\N	PRESENT	0
526978	526538	19735D	PARTICIPANT	\N	PRESENT	0
526979	526538	20104S	PARTICIPANT	\N	PRESENT	0
526980	526538	14071N	PARTICIPANT	\N	PRESENT	0
526985	526538	19747H	PARTICIPANT	\N	PRESENT	0
526986	526538	20098N	PARTICIPANT	\N	PRESENT	0
526987	526538	19441R	PARTICIPANT	\N	PRESENT	0
526988	526538	14073Q	PARTICIPANT	\N	PRESENT	0
526989	526538	11097X	PARTICIPANT	\N	PRESENT	0
526990	526538	19591F	PARTICIPANT	\N	PRESENT	0
526991	526689	12041X	PARTICIPANT	\N	PRESENT	0
526992	526689	08056B	PARTICIPANT	\N	PRESENT	0
526993	526689	14193X	PARTICIPANT	\N	PRESENT	0
526994	526689	14097Y	PARTICIPANT	\N	PRESENT	1
526995	526689	11066Q	PARTICIPANT	\N	EXCUSE	0
526996	526538	19768N	PARTICIPANT	\N	PRESENT	0
526997	526538	20172F	PARTICIPANT	\N	PRESENT	0
526998	526538	20122U	PARTICIPANT	\N	PRESENT	0
526999	526538	01048V	PARTICIPANT	\N	PRESENT	0
527000	526538	20110Q	PARTICIPANT	\N	PRESENT	0
527001	526538	11065P	PARTICIPANT	\N	PRESENT	0
527005	526538	19515S	PARTICIPANT	\N	PRESENT	0
527011	526538	19349W	PARTICIPANT	\N	PRESENT	0
527012	526538	11048N	PARTICIPANT	\N	PRESENT	0
527013	526538	20020P	PARTICIPANT	\N	PRESENT	0
527014	526538	08015R	PARTICIPANT	\N	PRESENT	0
527016	526538	20068G	PARTICIPANT	\N	PRESENT	0
527024	526538	19695N	PARTICIPANT	\N	PRESENT	0
527025	526538	17779H	PARTICIPANT	\N	PRESENT	0
527027	526538	19749K	PARTICIPANT	\N	PRESENT	0
527028	526538	01043Q	PARTICIPANT	\N	PRESENT	0
527029	526538	20118Y	PARTICIPANT	\N	PRESENT	0
527030	526538	20064C	PARTICIPANT	\N	PRESENT	0
527031	526538	19691J	PARTICIPANT	\N	PRESENT	0
527032	526538	19421M	PARTICIPANT	\N	PRESENT	0
527034	526538	14221J	PARTICIPANT	\N	PRESENT	0
527035	526538	20048C	PARTICIPANT	\N	PRESENT	0
527036	526538	19479G	PARTICIPANT	\N	PRESENT	0
527037	526538	08061X	PARTICIPANT	\N	PRESENT	0
527038	526538	14257W	PARTICIPANT	\N	PRESENT	0
527039	526538	19347U	PARTICIPANT	\N	PRESENT	0
527040	526538	14189C	PARTICIPANT	\N	PRESENT	0
527041	526538	14133K	PARTICIPANT	\N	PRESENT	0
527042	526538	14251Q	PARTICIPANT	\N	PRESENT	0
527043	526538	05008E	PARTICIPANT	\N	PRESENT	0
527044	526538	20082E	PARTICIPANT	\N	PRESENT	0
527045	526538	19545Y	PARTICIPANT	\N	PRESENT	0
527049	526538	19563B	PARTICIPANT	\N	PRESENT	0
527050	526538	01028R	PARTICIPANT	\N	PRESENT	0
527051	526538	20038A	PARTICIPANT	\N	PRESENT	0
527052	526538	14151M	PARTICIPANT	\N	PRESENT	0
527053	526538	14179A	PARTICIPANT	\N	PRESENT	0
527054	526538	20100N	PARTICIPANT	\N	PRESENT	0
527055	526538	14249W	PARTICIPANT	\N	PRESENT	0
527056	526538	20136B	PARTICIPANT	\N	PRESENT	0
527057	526538	14211G	PARTICIPANT	\N	PRESENT	0
527103	526551	04070G	PARTICIPANT	\N	PRESENT	0
527104	526551	19699S	PARTICIPANT	\N	PRESENT	0
527105	526551	14229S	PARTICIPANT	\N	PRESENT	0
527106	526551	19573D	PARTICIPANT	\N	PRESENT	0
527107	526551	08017T	PARTICIPANT	\N	PRESENT	1
527108	526551	92040Q	PARTICIPANT	\N	PRESENT	0
527109	526551	20124W	PARTICIPANT	\N	PRESENT	0
527110	526551	20026V	PARTICIPANT	\N	PRESENT	0
527111	526551	19643A	PARTICIPANT	\N	PRESENT	0
527112	526551	14073Q	PARTICIPANT	\N	PRESENT	0
527113	526551	20138D	PARTICIPANT	\N	PRESENT	0
527114	526551	19611R	PRESIDENT	0	PRESENT	0
527115	526551	20142Y	PARTICIPANT	\N	PRESENT	0
527116	526551	19693L	PARTICIPANT	\N	PRESENT	1
527117	526551	19399H	PARTICIPANT	\N	PRESENT	0
527118	526551	20152B	PARTICIPANT	\N	PRESENT	0
527119	526551	20052X	PARTICIPANT	\N	PRESENT	0
527120	526551	14030Q	PARTICIPANT	\N	PRESENT	0
527121	526551	20056C	PARTICIPANT	\N	PRESENT	0
527122	526551	20180F	PARTICIPANT	\N	PRESENT	0
527123	526551	04059M	PARTICIPANT	\N	PRESENT	0
527124	526551	19735D	PARTICIPANT	\N	PRESENT	0
527125	526551	14109K	PARTICIPANT	\N	PRESENT	1
527126	526551	11104D	PARTICIPANT	\N	PRESENT	1
527127	526551	11043H	PARTICIPANT	\N	PRESENT	0
527128	526551	19621T	PARTICIPANT	\N	PRESENT	0
527129	526538	04070G	PARTICIPANT	\N	PRESENT	0
527130	526538	17367Q	PARTICIPANT	\N	PRESENT	0
527133	526538	07029T	PARTICIPANT	\N	PRESENT	0
527134	526538	20150Y	PARTICIPANT	\N	PRESENT	0
527136	526538	19709B	PARTICIPANT	\N	PRESENT	0
527137	526538	14217N	PARTICIPANT	\N	PRESENT	0
527138	526538	14215L	PARTICIPANT	\N	PRESENT	0
527139	526538	14193X	PARTICIPANT	\N	PRESENT	0
527140	526538	08069G	PARTICIPANT	\N	PRESENT	0
531434	531429	14030Q	PARTICIPANT	\N	PRESENT	0
531509	531508	12028B	PARTICIPANT	\N	PRESENT	0
532029	532028	14259Y	PARTICIPANT	\N	PRESENT	0
532030	532028	19551W	PARTICIPANT	\N	PRESENT	0
534080	534079	19631V	PARTICIPANT	\N	PRESENT	0
534081	534079	14255U	PARTICIPANT	\N	PRESENT	0
534082	534079	18193Q	PARTICIPANT	\N	PRESENT	0
534083	534079	19329S	PARTICIPANT	\N	PRESENT	0
534084	534079	14059S	PARTICIPANT	\N	PRESENT	0
534085	534079	19585H	PARTICIPANT	\N	PRESENT	0
534086	534079	19577H	PARTICIPANT	\N	PRESENT	0
534087	534079	11065P	PARTICIPANT	\N	PRESENT	0
534088	534079	01043Q	PARTICIPANT	\N	PRESENT	0
534089	534079	19657G	PARTICIPANT	\N	PRESENT	0
534280	534279	14179A	PARTICIPANT	\N	PRESENT	0
534281	534279	14255U	PARTICIPANT	\N	PRESENT	0
534318	531551	05008E	PARTICIPANT	\N	EXCUSE	0
535299	535298	14071N	PARTICIPANT	\N	PRESENT	1
535518	533082	19565D	PARTICIPANT	\N	PRESENT	0
535519	533082	19798U	PARTICIPANT	\N	PRESENT	0
535520	533082	19713W	PARTICIPANT	\N	PRESENT	0
535521	533082	08045X	PARTICIPANT	\N	PRESENT	0
535522	533082	20040T	PARTICIPANT	\N	PRESENT	0
535523	533082	19691J	PARTICIPANT	\N	PRESENT	0
535524	533082	18193Q	PARTICIPANT	\N	PRESENT	0
535525	533082	20148F	PARTICIPANT	\N	PRESENT	0
535526	533082	14223L	PARTICIPANT	\N	PRESENT	0
535527	533082	19723Y	PARTICIPANT	\N	PRESENT	0
535528	533082	19703U	PARTICIPANT	\N	PRESENT	0
535529	533082	19553Y	PARTICIPANT	\N	PRESENT	0
535530	533082	20066E	PARTICIPANT	\N	PRESENT	0
535531	533082	19679N	PARTICIPANT	\N	PRESENT	0
535532	533082	14195A	PARTICIPANT	\N	PRESENT	0
535533	533082	14213J	PARTICIPANT	\N	PRESENT	0
535534	533082	14071N	PARTICIPANT	\N	PRESENT	0
535535	533082	10006L	PRESIDENT	0	PRESENT	0
535536	533082	08047A	PARTICIPANT	\N	PRESENT	0
535537	533082	17589D	PARTICIPANT	\N	PRESENT	0
536278	536276	20128B	PARTICIPANT	\N	PRESENT	0
536280	536276	19723Y	PARTICIPANT	\N	PRESENT	0
536281	536276	19593H	PARTICIPANT	\N	PRESENT	0
536282	536276	20066E	PARTICIPANT	\N	EXCUSE	0
536283	536276	11067R	PARTICIPANT	\N	EXCUSE	0
536284	536276	19735D	PARTICIPANT	\N	PRESENT	0
536292	536289	14041T	PARTICIPANT	\N	PRESENT	0
536296	536289	20084G	PARTICIPANT	\N	PRESENT	0
536298	536289	14071N	PARTICIPANT	\N	PRESENT	0
536300	536289	11083R	PARTICIPANT	\N	PRESENT	0
536303	536289	19671E	PARTICIPANT	\N	PRESENT	0
536315	534170	04085P	PARTICIPANT	\N	PRESENT	1
536316	534170	11033F	PARTICIPANT	\N	PRESENT	1
536317	534170	11026G	PARTICIPANT	\N	PRESENT	1
536318	534170	14147R	PARTICIPANT	\N	PRESENT	1
536319	534170	11072N	PARTICIPANT	\N	PRESENT	1
536320	534170	14107H	PARTICIPANT	\N	PRESENT	1
536321	534170	19675J	PARTICIPANT	\N	PRESENT	1
536375	534171	14151M	PARTICIPANT	\N	PRESENT	0
536376	534171	20074E	PARTICIPANT	\N	PRESENT	0
536377	534171	20108W	PARTICIPANT	\N	PRESENT	0
536378	534171	19581D	PARTICIPANT	\N	PRESENT	0
536379	534171	19543W	PARTICIPANT	\N	PRESENT	0
536380	534171	14215L	PARTICIPANT	\N	PRESENT	0
536381	534171	19725B	PARTICIPANT	\N	PRESENT	0
536382	534171	19585H	PARTICIPANT	\N	PRESENT	0
536383	534171	19954N	PARTICIPANT	\N	PRESENT	0
536384	534171	04047H	PARTICIPANT	\N	PRESENT	0
536385	534171	14179A	PARTICIPANT	\N	PRESENT	0
536386	534171	19673G	PARTICIPANT	\N	PRESENT	0
536387	534171	19447X	PARTICIPANT	\N	PRESENT	0
536388	534171	14231L	PARTICIPANT	\N	PRESENT	0
536389	534171	01028R	PARTICIPANT	\N	PRESENT	0
536390	534171	17737W	PARTICIPANT	\N	PRESENT	0
536391	534171	19649G	PARTICIPANT	\N	PRESENT	0
536392	534171	19749K	PARTICIPANT	\N	PRESENT	0
536393	534171	05008E	PARTICIPANT	\N	PRESENT	0
536394	534171	11026G	PARTICIPANT	\N	PRESENT	1
536395	534171	14147R	PARTICIPANT	\N	PRESENT	1
536396	534171	11072N	PARTICIPANT	\N	PRESENT	1
536397	534171	14107H	PARTICIPANT	\N	PRESENT	1
536398	534171	19675J	PARTICIPANT	\N	PRESENT	1
536399	534171	14111D	PARTICIPANT	\N	PRESENT	0
536400	534171	19629C	PARTICIPANT	\N	PRESENT	0
536401	534171	04085P	PARTICIPANT	\N	PRESENT	1
536402	534171	11033F	PARTICIPANT	\N	PRESENT	1
536865	536864	19651A	PARTICIPANT	\N	PRESENT	0
536866	536864	19533U	PARTICIPANT	\N	PRESENT	0
536867	536864	20124W	PARTICIPANT	\N	PRESENT	0
536868	536864	19621T	PARTICIPANT	\N	PRESENT	0
536869	536864	20180F	PARTICIPANT	\N	PRESENT	0
536870	536864	14123H	PARTICIPANT	\N	PRESENT	0
536871	536864	20152B	PARTICIPANT	\N	PRESENT	0
536872	536864	19593H	PARTICIPANT	\N	PRESENT	0
536874	536873	19651A	PARTICIPANT	\N	PRESENT	0
536875	536873	20180F	PARTICIPANT	\N	PRESENT	0
536876	536873	19533U	PARTICIPANT	\N	PRESENT	0
536877	536873	19593H	PARTICIPANT	\N	PRESENT	0
536878	536873	20138D	PARTICIPANT	\N	PRESENT	0
536879	536873	14123H	PARTICIPANT	\N	PRESENT	0
536881	536880	19533U	PARTICIPANT	\N	PRESENT	0
536890	536889	19533U	PARTICIPANT	\N	PRESENT	0
536891	536889	14109K	PARTICIPANT	\N	PRESENT	0
537015	534230	14069U	PARTICIPANT	\N	PRESENT	0
537016	534230	14001X	PARTICIPANT	\N	PRESENT	0
537017	534230	11067R	PARTICIPANT	\N	PRESENT	0
537018	534230	01057W	PARTICIPANT	\N	PRESENT	0
537019	534230	20116W	PARTICIPANT	\N	PRESENT	0
537020	534230	20090E	PARTICIPANT	\N	PRESENT	0
537021	534230	20064C	PARTICIPANT	\N	PRESENT	0
537029	536826	14026U	PARTICIPANT	\N	PRESENT	0
537034	536826	01048V	PARTICIPANT	\N	PRESENT	0
537035	536826	20100N	PARTICIPANT	\N	PRESENT	0
537039	536826	14173T	PARTICIPANT	\N	PRESENT	0
537040	536826	10015M	PARTICIPANT	\N	PRESENT	0
537041	536826	04057K	PARTICIPANT	\N	PRESENT	0
537042	536826	20136B	PARTICIPANT	\N	PRESENT	0
537043	536826	19741B	PARTICIPANT	\N	PRESENT	0
537044	536826	19637C	PARTICIPANT	\N	PRESENT	0
537045	536826	14327T	PARTICIPANT	\N	PRESENT	0
537046	536826	14083S	PARTICIPANT	\N	PRESENT	0
537047	536826	17367Q	PARTICIPANT	\N	PRESENT	0
537048	536826	20032T	PARTICIPANT	\N	PRESENT	0
537049	536826	14089Y	PARTICIPANT	\N	PRESENT	0
537050	536826	08009T	PARTICIPANT	\N	PRESENT	0
537052	536826	11045K	PARTICIPANT	\N	PRESENT	0
537053	536826	19413M	PARTICIPANT	\N	PRESENT	0
537054	536826	19569H	PARTICIPANT	\N	PRESENT	0
537055	536826	11067R	PARTICIPANT	\N	PRESENT	0
537056	536826	14213J	PARTICIPANT	\N	PRESENT	0
537057	536826	19301E	PARTICIPANT	\N	PRESENT	0
537058	536826	19399H	PARTICIPANT	\N	PRESENT	0
537059	536826	07029T	PARTICIPANT	\N	PRESENT	0
537060	536826	20044X	PARTICIPANT	\N	PRESENT	0
537061	536826	19758L	PARTICIPANT	\N	PRESENT	0
537065	536826	11027H	PARTICIPANT	\N	PRESENT	0
537063	536826	14147R	PARTICIPANT	\N	PRESENT	0
537064	536826	11066Q	PARTICIPANT	\N	PRESENT	0
537067	536826	11031D	PARTICIPANT	\N	PRESENT	0
537068	536826	19693L	PARTICIPANT	\N	PRESENT	0
537070	536826	19515S	PARTICIPANT	\N	PRESENT	0
537072	536826	19599P	PARTICIPANT	\N	PRESENT	0
537076	536826	20096L	PARTICIPANT	\N	PRESENT	0
537077	536826	19954N	PARTICIPANT	\N	PRESENT	0
537078	536826	11115U	PARTICIPANT	\N	PRESENT	0
537082	536826	14187A	PARTICIPANT	\N	PRESENT	0
537100	536269	20130U	PARTICIPANT	\N	PRESENT	0
537101	536269	20090E	PARTICIPANT	\N	PRESENT	1
537102	536269	17965H	PARTICIPANT	\N	PRESENT	0
537103	536269	19301E	PARTICIPANT	\N	PRESENT	0
537104	536269	14071N	PARTICIPANT	\N	PRESENT	0
537105	536269	14223L	PARTICIPANT	\N	PRESENT	0
537096	536827	11045K	PARTICIPANT	\N	PRESENT	0
537097	536269	19798U	PARTICIPANT	\N	PRESENT	0
537098	536269	10006L	PRESIDENT	0	PRESENT	0
537099	536269	19683J	PARTICIPANT	\N	PRESENT	0
537106	536269	20172F	PARTICIPANT	\N	PRESENT	0
514291	513781	04008A	PARTICIPANT	\N	PRESENT	1
514292	513781	14179A	PARTICIPANT	\N	PRESENT	0
514322	514320	05012A	PARTICIPANT	\N	PRESENT	0
514323	514320	08060W	PARTICIPANT	\N	PRESENT	0
514324	514320	18083K	PARTICIPANT	\N	PRESENT	0
514326	514320	19387D	PARTICIPANT	\N	PRESENT	0
514327	514320	19525U	PARTICIPANT	\N	PRESENT	0
514328	514320	20136B	PARTICIPANT	\N	PRESENT	0
514329	514320	19619A	PARTICIPANT	\N	PRESENT	0
514331	514320	20100N	PARTICIPANT	\N	PRESENT	0
514332	514320	17229F	PARTICIPANT	\N	PRESENT	0
514333	514320	19637C	PARTICIPANT	\N	PRESENT	0
514334	514320	20038A	PARTICIPANT	\N	PRESENT	0
514582	512883	19715Y	PARTICIPANT	\N	EXCUSE	0
514583	512883	19583F	PARTICIPANT	\N	EXCUSE	0
514584	512883	08034U	PARTICIPANT	\N	PRESENT	0
514585	512883	11090Q	PARTICIPANT	\N	PRESENT	1
514586	512883	19673G	PARTICIPANT	\N	EXCUSE	0
514587	512883	18083K	PARTICIPANT	\N	PRESENT	0
514588	512883	11010L	PARTICIPANT	\N	EXCUSE	0
514589	512883	19717B	PRESIDENT	0	PRESENT	0
514654	514653	14255U	PARTICIPANT	\N	PRESENT	0
514655	514653	18083K	PARTICIPANT	\N	PRESENT	0
514656	514653	11074Q	PARTICIPANT	\N	PRESENT	0
514657	514653	98022P	PARTICIPANT	\N	PRESENT	0
514659	514653	19333N	PARTICIPANT	\N	PRESENT	0
514660	514653	19591F	PARTICIPANT	\N	PRESENT	0
514662	514653	14073Q	PARTICIPANT	\N	PRESENT	0
514663	514653	01043Q	PARTICIPANT	\N	PRESENT	0
514664	514653	19826F	PARTICIPANT	\N	PRESENT	0
514665	514653	08009T	PARTICIPANT	\N	PRESENT	0
514666	514653	14221J	PARTICIPANT	\N	PRESENT	0
514667	514653	04070G	PARTICIPANT	\N	PRESENT	0
514668	514653	10015M	PARTICIPANT	\N	PRESENT	0
514669	514653	19585H	PARTICIPANT	\N	PRESENT	0
514671	514670	07033P	PARTICIPANT	\N	PRESENT	0
514672	514670	14255U	PARTICIPANT	\N	PRESENT	0
514673	514670	97011G	PARTICIPANT	\N	PRESENT	0
514674	514670	19551W	PARTICIPANT	\N	PRESENT	0
514675	514670	08010L	PARTICIPANT	\N	PRESENT	0
514676	514670	14059S	PARTICIPANT	\N	PRESENT	0
514677	514670	14147R	PARTICIPANT	\N	PRESENT	0
514678	514670	19745F	PARTICIPANT	\N	PRESENT	0
514723	511986	04085P	PARTICIPANT	\N	EXCUSE	0
514724	511986	19649G	PARTICIPANT	\N	PRESENT	0
519289	519288	19741B	PARTICIPANT	\N	PRESENT	0
519291	519290	19741B	PARTICIPANT	\N	PRESENT	0
519295	519294	19515S	PARTICIPANT	\N	PRESENT	0
519296	519294	19747H	PARTICIPANT	\N	PRESENT	0
519297	519294	19521Q	PARTICIPANT	\N	PRESENT	0
519298	519294	20092G	PARTICIPANT	\N	PRESENT	0
519299	519225	19729F	PARTICIPANT	\N	PRESENT	0
519301	519300	19553Y	PARTICIPANT	\N	PRESENT	0
519303	519302	11072N	PARTICIPANT	\N	PRESENT	0
519415	518947	20100N	PARTICIPANT	\N	PRESENT	0
519416	518947	14189C	PARTICIPANT	\N	PRESENT	0
519417	518947	20062A	PARTICIPANT	\N	PRESENT	0
519418	518947	20032T	PARTICIPANT	\N	PRESENT	0
519419	518947	19798U	PARTICIPANT	\N	PRESENT	0
519420	518947	14107H	PARTICIPANT	\N	PRESENT	0
519421	518947	14219Q	PARTICIPANT	\N	PRESENT	0
519422	518947	19745F	PARTICIPANT	\N	PRESENT	0
519423	518947	19629C	PARTICIPANT	\N	PRESENT	0
519424	518947	19387D	PARTICIPANT	\N	PRESENT	0
519425	518947	14147R	PARTICIPANT	\N	PRESENT	0
519426	518947	19701S	PARTICIPANT	\N	PRESENT	0
519427	518947	19703U	PARTICIPANT	\N	PRESENT	0
519428	518947	20112S	PARTICIPANT	\N	PRESENT	0
519429	518947	20174H	PARTICIPANT	\N	PRESENT	0
519430	518947	19553Y	PARTICIPANT	\N	PRESENT	0
519431	518947	01025N	PARTICIPANT	\N	PRESENT	0
519432	518947	01024M	PARTICIPANT	\N	PRESENT	0
519433	518947	14069U	PARTICIPANT	\N	PRESENT	0
519434	518947	19467C	PARTICIPANT	\N	PRESENT	0
519435	518947	20096L	PARTICIPANT	\N	PRESENT	0
519436	518947	20044X	PARTICIPANT	\N	PRESENT	0
519437	518947	14033T	PARTICIPANT	\N	PRESENT	0
519438	518947	08015R	PARTICIPANT	\N	PRESENT	0
519439	518947	11040E	PARTICIPANT	\N	PRESENT	0
519440	518947	19503N	PARTICIPANT	\N	PRESENT	0
519441	518947	19333N	PARTICIPANT	\N	PRESENT	0
519442	518947	20030R	PARTICIPANT	\N	PRESENT	0
519443	518947	19820Y	PARTICIPANT	\N	PRESENT	0
519444	518947	11104D	PARTICIPANT	\N	PRESENT	0
519445	518947	14083S	PARTICIPANT	\N	PRESENT	0
519446	518947	20052X	PARTICIPANT	\N	PRESENT	0
519447	518947	20144B	PARTICIPANT	\N	PRESENT	0
519448	518947	14267Y	PARTICIPANT	\N	PRESENT	0
519449	518947	19549D	PARTICIPANT	\N	PRESENT	0
519450	518947	20026V	PARTICIPANT	\N	PRESENT	0
519451	518947	97011G	PARTICIPANT	\N	PRESENT	0
519452	518947	19768N	PARTICIPANT	\N	PRESENT	0
519453	518947	19383Y	PARTICIPANT	\N	PRESENT	0
519454	518947	11067R	PARTICIPANT	\N	PRESENT	0
519455	518947	19347U	PARTICIPANT	\N	PRESENT	0
519539	518948	19820Y	PARTICIPANT	\N	PRESENT	0
519540	518948	19549D	PARTICIPANT	\N	PRESENT	0
519541	518948	19631V	PARTICIPANT	\N	PRESENT	0
519542	518948	11104D	PARTICIPANT	\N	PRESENT	0
519543	518948	20082E	PARTICIPANT	\N	PRESENT	0
519544	518948	20094J	PARTICIPANT	\N	PRESENT	0
519545	518948	11067R	PARTICIPANT	\N	PRESENT	0
519546	518948	20174H	PARTICIPANT	\N	PRESENT	0
519547	518948	19347U	PARTICIPANT	\N	PRESENT	0
519548	518948	20076G	PARTICIPANT	\N	PRESENT	0
519549	518948	04045F	PARTICIPANT	\N	PRESENT	0
519550	518948	19782L	PARTICIPANT	\N	PRESENT	0
519551	518948	20068G	PARTICIPANT	\N	PRESENT	0
519552	518948	19349W	PARTICIPANT	\N	PRESENT	0
519553	518948	08061X	PARTICIPANT	\N	PRESENT	0
519554	518948	11043H	PARTICIPANT	\N	PRESENT	0
519555	518948	20106U	PARTICIPANT	\N	PRESENT	0
519556	518948	14069U	PARTICIPANT	\N	PRESENT	0
519557	518948	11056N	PARTICIPANT	\N	PRESENT	0
519558	518948	19565D	PARTICIPANT	\N	PRESENT	0
519559	518948	19387D	PARTICIPANT	\N	PRESENT	0
519560	518948	14187A	PARTICIPANT	\N	PRESENT	0
519561	518948	20046A	PARTICIPANT	\N	PRESENT	0
519562	518948	11040E	PARTICIPANT	\N	PRESENT	0
519563	518948	19745F	PARTICIPANT	\N	PRESENT	0
519564	518948	19747H	PARTICIPANT	\N	PRESENT	0
519565	518948	20144B	PARTICIPANT	\N	PRESENT	0
519566	518948	14219Q	PARTICIPANT	\N	PRESENT	0
519567	518948	19798U	PARTICIPANT	\N	PRESENT	0
519568	518948	19441R	PARTICIPANT	\N	PRESENT	0
519569	518948	14105F	PARTICIPANT	\N	PRESENT	0
519570	518948	19479G	PARTICIPANT	\N	PRESENT	0
519571	518948	20052X	PARTICIPANT	\N	PRESENT	0
519572	518948	97011G	PARTICIPANT	\N	PRESENT	0
519573	518948	19333N	PARTICIPANT	\N	PRESENT	0
519574	518948	20018V	PARTICIPANT	\N	PRESENT	0
519575	518948	19399H	PARTICIPANT	\N	PRESENT	0
519576	518948	19619A	PARTICIPANT	\N	PRESENT	0
519577	518948	19826F	PARTICIPANT	\N	PRESENT	0
519578	518948	11101A	PARTICIPANT	\N	PRESENT	0
519579	518948	01024M	PARTICIPANT	\N	PRESENT	0
519580	518948	14083S	PARTICIPANT	\N	PRESENT	0
519581	518948	14267Y	PARTICIPANT	\N	PRESENT	0
519582	518948	14221J	PARTICIPANT	\N	PRESENT	0
519583	518948	19553Y	PARTICIPANT	\N	PRESENT	0
519584	518948	20062A	PARTICIPANT	\N	PRESENT	0
519585	518948	20090E	PARTICIPANT	\N	PRESENT	0
519586	518948	19768N	PARTICIPANT	\N	PRESENT	0
519587	518948	19383Y	PARTICIPANT	\N	PRESENT	0
519588	518948	20058E	PARTICIPANT	\N	PRESENT	0
519589	518948	20044X	PARTICIPANT	\N	PRESENT	0
519590	518948	08015R	PARTICIPANT	\N	PRESENT	0
519591	518948	18083K	PARTICIPANT	\N	PRESENT	0
519592	518948	20056C	PARTICIPANT	\N	PRESENT	0
519593	518948	20096L	PARTICIPANT	\N	PRESENT	0
519594	518948	19703U	PARTICIPANT	\N	PRESENT	0
519595	518948	14038Y	PARTICIPANT	\N	PRESENT	0
519596	518948	20026V	PARTICIPANT	\N	PRESENT	0
519597	518948	20020P	PARTICIPANT	\N	PRESENT	0
519598	518948	19573D	PARTICIPANT	\N	PRESENT	0
519599	518948	19467C	PARTICIPANT	\N	PRESENT	0
519600	518948	19701S	PARTICIPANT	\N	PRESENT	0
519601	518948	14189C	PARTICIPANT	\N	PRESENT	0
519603	518948	20028X	PARTICIPANT	\N	PRESENT	0
519604	518948	20032T	PARTICIPANT	\N	PRESENT	0
519605	518948	20104S	PARTICIPANT	\N	PRESENT	0
518823	518821	20152B	PARTICIPANT	\N	PRESENT	0
518824	518821	19701S	PARTICIPANT	\N	PRESENT	0
518825	518821	19693L	PARTICIPANT	\N	PRESENT	0
518826	518821	19699S	PARTICIPANT	\N	PRESENT	0
518827	518821	11026G	PARTICIPANT	\N	PRESENT	0
518828	518821	19671E	PARTICIPANT	\N	PRESENT	0
518829	518821	95063L	PARTICIPANT	\N	PRESENT	0
518830	518821	20064C	PARTICIPANT	\N	PRESENT	0
518832	518831	04059M	PARTICIPANT	\N	PRESENT	0
518833	518831	20024T	PARTICIPANT	\N	PRESENT	0
518834	518831	17367Q	PARTICIPANT	\N	PRESENT	0
518835	518831	20088L	PARTICIPANT	\N	PRESENT	0
518836	518831	20114U	PARTICIPANT	\N	PRESENT	0
518777	518776	11072N	PARTICIPANT	\N	PRESENT	0
518822	518821	19667J	PARTICIPANT	\N	PRESENT	0
518837	518831	19621T	PARTICIPANT	\N	PRESENT	0
518838	518831	19758L	PARTICIPANT	\N	PRESENT	0
518839	518831	04042C	PARTICIPANT	\N	PRESENT	0
518840	518831	11053K	PARTICIPANT	\N	PRESENT	0
518841	518831	11080N	PARTICIPANT	\N	PRESENT	0
518842	518831	11115U	PARTICIPANT	\N	PRESENT	0
518843	518831	19693L	PARTICIPANT	\N	PRESENT	0
518844	518831	14327T	PARTICIPANT	\N	PRESENT	0
518845	518831	19663E	PARTICIPANT	\N	PRESENT	0
518846	518831	07033P	PARTICIPANT	\N	PRESENT	0
518847	518831	14187A	PARTICIPANT	\N	PRESENT	0
518848	518831	14281W	PARTICIPANT	\N	PRESENT	0
518849	518831	19347U	PARTICIPANT	\N	PRESENT	0
518850	518831	19565D	PARTICIPANT	\N	PRESENT	0
518851	518831	98022P	PARTICIPANT	\N	PRESENT	0
518852	518831	99004R	PARTICIPANT	\N	PRESENT	0
518853	518831	14073Q	PARTICIPANT	\N	PRESENT	0
518854	518831	08010L	PARTICIPANT	\N	PRESENT	0
518855	518831	19699S	PARTICIPANT	\N	PRESENT	0
518856	518831	20018V	PARTICIPANT	\N	PRESENT	0
518857	518831	04070G	PARTICIPANT	\N	PRESENT	0
518858	518831	19503N	PARTICIPANT	\N	PRESENT	0
518859	518831	19443T	PARTICIPANT	\N	PRESENT	0
519088	519087	05008E	PARTICIPANT	\N	PRESENT	0
518861	518831	11041F	PARTICIPANT	\N	PRESENT	0
518862	518831	20046A	PARTICIPANT	\N	PRESENT	0
519089	519087	11053K	PARTICIPANT	\N	PRESENT	0
519090	519087	01028R	PARTICIPANT	\N	PRESENT	0
519127	519098	19723Y	PARTICIPANT	\N	PRESENT	0
519129	519098	19693L	PARTICIPANT	\N	PRESENT	0
519158	519156	17965H	PARTICIPANT	\N	PRESENT	0
519159	519156	11045K	PARTICIPANT	\N	PRESENT	0
519160	519157	17965H	PARTICIPANT	\N	PRESENT	0
519161	519157	11045K	PARTICIPANT	\N	PRESENT	0
519166	519164	17779H	PARTICIPANT	\N	PRESENT	0
519167	519164	17965H	PARTICIPANT	\N	PRESENT	0
519168	519164	18193Q	PARTICIPANT	\N	PRESENT	0
519169	519164	11031D	PARTICIPANT	\N	PRESENT	0
519170	519163	17779H	PARTICIPANT	\N	PRESENT	0
519171	519163	17965H	PARTICIPANT	\N	PRESENT	0
519172	519165	18193Q	PARTICIPANT	\N	PRESENT	0
519173	519165	17779H	PARTICIPANT	\N	PRESENT	0
519174	519165	17965H	PARTICIPANT	\N	PRESENT	0
519789	519307	19533U	PARTICIPANT	\N	PRESENT	0
519790	519307	01058X	PARTICIPANT	\N	PRESENT	0
520039	519212	10006L	PRESIDENT	0	PRESENT	0
520040	519212	11031D	PARTICIPANT	\N	PRESENT	0
520041	519212	19717B	PARTICIPANT	\N	PRESENT	1
520042	519212	04043D	PARTICIPANT	\N	PRESENT	1
520043	519212	17965H	PARTICIPANT	\N	PRESENT	0
520044	519212	18193Q	PARTICIPANT	\N	PRESENT	0
520045	519212	19415P	PARTICIPANT	\N	PRESENT	1
520046	519212	19723Y	PARTICIPANT	\N	PRESENT	0
520050	519212	08045X	PARTICIPANT	\N	PRESENT	1
520052	519212	19713W	PARTICIPANT	\N	PRESENT	1
520055	519212	20090E	PARTICIPANT	\N	PRESENT	1
520141	519212	01034P	PARTICIPANT	\N	PRESENT	0
520142	519212	20040T	PARTICIPANT	\N	PRESENT	0
520289	519212	14071N	PARTICIPANT	\N	PRESENT	0
520333	519212	20148F	PARTICIPANT	\N	PRESENT	0
520335	520334	19735D	PARTICIPANT	\N	PRESENT	0
520337	520334	19723Y	PARTICIPANT	\N	PRESENT	0
520673	520672	14041T	PARTICIPANT	\N	PRESENT	0
520674	520672	04043D	PARTICIPANT	\N	PRESENT	0
520675	520672	20110Q	PARTICIPANT	\N	PRESENT	0
520676	520672	14213J	PARTICIPANT	\N	PRESENT	0
520677	520672	14147R	PARTICIPANT	\N	PRESENT	0
521309	519312	19651A	PARTICIPANT	\N	PRESENT	0
521310	519312	20042V	PARTICIPANT	\N	PRESENT	0
521311	519312	11040E	PARTICIPANT	\N	PRESENT	0
521312	519312	11056N	PARTICIPANT	\N	PRESENT	0
521313	519312	04008A	PARTICIPANT	\N	PRESENT	0
521314	519312	20132W	PARTICIPANT	\N	PRESENT	0
521315	519312	19725B	PARTICIPANT	\N	PRESENT	0
521316	519312	19551W	PARTICIPANT	\N	PRESENT	0
521317	519312	04070G	PARTICIPANT	\N	PRESENT	0
521318	519312	11097X	PARTICIPANT	\N	PRESENT	0
521319	519312	95063L	PARTICIPANT	\N	PRESENT	0
521320	519312	19643A	PARTICIPANT	\N	PRESENT	0
521362	521361	19533U	PARTICIPANT	\N	PRESENT	0
521526	521525	19575F	PARTICIPANT	\N	PRESENT	0
521527	521525	18083K	PARTICIPANT	\N	PRESENT	0
521528	521525	11065P	PARTICIPANT	\N	PRESENT	0
521530	521529	20114U	PARTICIPANT	\N	PRESENT	0
521531	521529	14255U	PARTICIPANT	\N	PRESENT	0
521532	521529	11083R	PARTICIPANT	\N	PRESENT	0
521533	521529	20068G	PARTICIPANT	\N	PRESENT	0
521534	521529	20106U	PARTICIPANT	\N	PRESENT	0
521535	521529	19723Y	PARTICIPANT	\N	PRESENT	0
521536	521529	14059S	PARTICIPANT	\N	PRESENT	0
521537	521529	19503N	PARTICIPANT	\N	PRESENT	0
521538	521529	20058E	PARTICIPANT	\N	PRESENT	0
521627	521472	19719D	PARTICIPANT	\N	PRESENT	0
521628	521472	20088L	PARTICIPANT	\N	PRESENT	0
521629	521472	19527W	PARTICIPANT	\N	PRESENT	0
521630	521472	19349W	PARTICIPANT	\N	PRESENT	0
521631	521472	14331P	PARTICIPANT	\N	PRESENT	0
521632	521472	20148F	PARTICIPANT	\N	PRESENT	0
521633	521472	19709B	PARTICIPANT	\N	PRESENT	0
521634	521472	14237S	PARTICIPANT	\N	PRESENT	0
521635	521472	11027H	PARTICIPANT	\N	PRESENT	0
521636	521472	19479G	PARTICIPANT	\N	PRESENT	0
521637	521472	20024T	PARTICIPANT	\N	PRESENT	0
521638	521472	14219Q	PARTICIPANT	\N	PRESENT	0
521639	521472	19573D	PARTICIPANT	\N	PRESENT	0
521640	521472	01025N	PARTICIPANT	\N	PRESENT	0
521641	521472	08015R	PARTICIPANT	\N	PRESENT	0
521642	521472	14030Q	PARTICIPANT	\N	PRESENT	0
521643	521472	14213J	PARTICIPANT	\N	PRESENT	0
521644	521472	04070G	PARTICIPANT	\N	PRESENT	0
521645	521472	20062A	PARTICIPANT	\N	PRESENT	0
521646	521472	14173T	PARTICIPANT	\N	PRESENT	0
521647	521472	20066E	PARTICIPANT	\N	PRESENT	0
521648	521472	20122U	PARTICIPANT	\N	PRESENT	0
521649	521472	19695N	PARTICIPANT	\N	PRESENT	0
521650	521472	14069U	PARTICIPANT	\N	PRESENT	0
521652	521472	19367Y	PARTICIPANT	\N	PRESENT	0
521653	521472	19729F	PARTICIPANT	\N	PRESENT	0
521654	521472	19415P	PARTICIPANT	\N	PRESENT	0
521655	521472	11045K	PARTICIPANT	\N	PRESENT	0
521658	521472	14257W	PARTICIPANT	\N	PRESENT	0
521659	521472	20172F	PARTICIPANT	\N	PRESENT	0
521660	521472	19531S	PARTICIPANT	\N	PRESENT	0
521661	521472	19671E	PARTICIPANT	\N	PRESENT	0
521662	521472	11054L	PARTICIPANT	\N	PRESENT	0
521663	521472	19685L	PARTICIPANT	\N	PRESENT	0
521664	521472	19760E	PARTICIPANT	\N	PRESENT	0
521665	521472	20054A	PARTICIPANT	\N	PRESENT	0
521677	521472	20020P	PARTICIPANT	\N	PRESENT	0
521678	521472	14107H	PARTICIPANT	\N	PRESENT	0
521679	521472	14083S	PARTICIPANT	\N	PRESENT	0
521680	521472	19533U	PARTICIPANT	\N	PRESENT	0
521681	521472	20026V	PARTICIPANT	\N	PRESENT	0
521682	521472	20028X	PARTICIPANT	\N	PRESENT	0
521698	519786	11066Q	PARTICIPANT	\N	PRESENT	0
521690	521473	99004R	PARTICIPANT	\N	PRESENT	0
521691	519786	18083K	PARTICIPANT	\N	PRESENT	0
521692	519786	01048V	PARTICIPANT	\N	PRESENT	0
521693	519786	04092N	PRESIDENT	0	PRESENT	0
521694	519786	19569H	PARTICIPANT	\N	PRESENT	0
521695	519786	14195A	PARTICIPANT	\N	PRESENT	0
521696	519786	14213J	PARTICIPANT	\N	PRESENT	0
521697	519786	99004R	PARTICIPANT	\N	PRESENT	0
513123	509857	19515S	PARTICIPANT	\N	PRESENT	0
513124	509857	20086J	PARTICIPANT	\N	PRESENT	0
513125	509857	20094J	PARTICIPANT	\N	PRESENT	0
513126	509857	14329V	PARTICIPANT	\N	PRESENT	0
513127	509857	20144B	PARTICIPANT	\N	PRESENT	0
513128	509857	19467C	PARTICIPANT	\N	PRESENT	0
513129	509857	20174H	PARTICIPANT	\N	PRESENT	0
513130	509857	14033T	PARTICIPANT	\N	PRESENT	0
513131	509857	20034V	PARTICIPANT	\N	PRESENT	0
513132	509857	14205J	PARTICIPANT	\N	PRESENT	0
513133	509857	19441R	PARTICIPANT	\N	PRESENT	0
513134	509857	20018V	PARTICIPANT	\N	PRESENT	0
513135	509857	19866P	PARTICIPANT	\N	PRESENT	0
513136	509857	20030R	PARTICIPANT	\N	PRESENT	0
513137	509857	11090Q	PARTICIPANT	\N	PRESENT	0
513138	509857	20082E	PARTICIPANT	\N	PRESENT	0
513139	509857	19705W	PARTICIPANT	\N	PRESENT	0
513140	509857	20092G	PARTICIPANT	\N	PRESENT	0
513141	509857	14207L	PARTICIPANT	\N	PRESENT	1
513142	509857	08015R	PARTICIPANT	\N	PRESENT	1
513143	509857	19563B	PARTICIPANT	\N	PRESENT	1
513144	509857	19768N	PARTICIPANT	\N	PRESENT	1
513145	509857	20054A	PARTICIPANT	\N	PRESENT	1
513146	509857	20062A	PARTICIPANT	\N	PRESENT	1
517470	517469	19673G	PARTICIPANT	\N	PRESENT	0
517471	517469	19667J	PARTICIPANT	\N	PRESENT	0
517472	517469	11083R	PARTICIPANT	\N	PRESENT	0
517473	517469	14179A	PARTICIPANT	\N	PRESENT	0
517741	517467	08017T	PARTICIPANT	\N	PRESENT	1
517742	517467	14109K	PARTICIPANT	\N	PRESENT	1
517743	517467	19533U	PARTICIPANT	\N	PRESENT	1
517744	517467	20048C	PARTICIPANT	\N	PRESENT	1
517745	517467	20142Y	PARTICIPANT	\N	PRESENT	1
517746	517467	20084G	PARTICIPANT	\N	PRESENT	1
517747	517467	19643A	PARTICIPANT	\N	PRESENT	1
518477	518473	08015R	PARTICIPANT	\N	PRESENT	0
518479	518473	19685L	PARTICIPANT	\N	PRESENT	0
518478	518473	08056B	PARTICIPANT	\N	PRESENT	0
518480	518473	11026G	PARTICIPANT	\N	PRESENT	0
518481	518473	20052X	PARTICIPANT	\N	PRESENT	0
518482	518473	14225N	PARTICIPANT	\N	PRESENT	0
518483	518473	20054A	PARTICIPANT	\N	PRESENT	0
518484	518473	19585H	PARTICIPANT	\N	PRESENT	0
518485	518473	14069U	PARTICIPANT	\N	PRESENT	0
518486	518473	20070A	PARTICIPANT	\N	PRESENT	0
518487	518473	08018U	PARTICIPANT	\N	PRESENT	0
521371	518915	19319Q	PARTICIPANT	\N	EXCUSE	0
522220	522157	14030Q	PARTICIPANT	\N	PRESENT	0
522221	522157	20138D	PARTICIPANT	\N	PRESENT	0
522222	522157	20152B	PARTICIPANT	\N	PRESENT	0
522223	522157	19758L	PARTICIPANT	\N	PRESENT	0
522224	522157	20134Y	PARTICIPANT	\N	PRESENT	1
522225	522157	20124W	PARTICIPANT	\N	PRESENT	0
522226	522157	20132W	PARTICIPANT	\N	PRESENT	0
522227	522157	20180F	PARTICIPANT	\N	PRESENT	0
522228	522157	14123H	PARTICIPANT	\N	PRESENT	0
522229	522157	20048C	PARTICIPANT	\N	PRESENT	1
522230	522157	19399H	PARTICIPANT	\N	PRESENT	0
522231	522157	20056C	PARTICIPANT	\N	PRESENT	0
522232	522157	14073Q	PARTICIPANT	\N	PRESENT	0
522233	522157	19611R	PRESIDENT	0	PRESENT	0
522234	522157	19699S	PARTICIPANT	\N	PRESENT	0
522242	522157	20052X	PARTICIPANT	\N	PRESENT	0
522243	522157	08012N	PARTICIPANT	\N	PRESENT	0
522244	522157	11104D	PARTICIPANT	\N	PRESENT	1
522245	522157	14109K	PARTICIPANT	\N	PRESENT	1
522246	522157	04070G	PARTICIPANT	\N	PRESENT	1
522247	522157	19573D	PARTICIPANT	\N	PRESENT	0
522248	522157	11043H	PARTICIPANT	\N	PRESENT	0
522249	522157	20098N	PARTICIPANT	\N	PRESENT	1
522250	522157	19527W	PARTICIPANT	\N	PRESENT	0
522251	522157	20026V	PARTICIPANT	\N	PRESENT	0
522252	522157	19735D	PARTICIPANT	\N	PRESENT	1
522293	522157	14223L	PARTICIPANT	\N	PRESENT	1
522295	522157	19301E	PARTICIPANT	\N	PRESENT	1
522296	522157	19415P	PARTICIPANT	\N	PRESENT	1
522303	522157	19657G	PARTICIPANT	\N	PRESENT	1
522304	522157	01034P	PARTICIPANT	\N	PRESENT	1
522305	522157	04092N	PARTICIPANT	\N	PRESENT	1
522306	522157	11103C	PARTICIPANT	\N	PRESENT	1
522307	522157	08045X	PARTICIPANT	\N	PRESENT	1
522308	522157	14213J	PARTICIPANT	\N	PRESENT	1
522309	522157	19697Q	PARTICIPANT	\N	PRESENT	1
522320	522157	19717B	PARTICIPANT	\N	PRESENT	1
522352	522157	18193Q	PARTICIPANT	\N	PRESENT	0
522353	522157	20130U	PARTICIPANT	\N	PRESENT	0
522354	522157	11031D	PARTICIPANT	\N	PRESENT	0
522355	522157	17965H	PARTICIPANT	\N	PRESENT	0
522409	522157	19329S	PARTICIPANT	\N	PRESENT	1
522421	522157	14026U	PARTICIPANT	\N	PRESENT	1
522379	522157	11067R	PARTICIPANT	\N	PRESENT	0
522410	522157	14229S	PARTICIPANT	\N	PRESENT	1
522411	522157	19693L	PARTICIPANT	\N	PRESENT	1
522413	522157	92040Q	PARTICIPANT	\N	EXCUSE	0
522422	522157	19691J	PARTICIPANT	\N	PRESENT	0
522419	522157	10006L	PARTICIPANT	\N	PRESENT	0
522420	522157	14042U	PARTICIPANT	\N	PRESENT	1
522423	522157	20172F	PARTICIPANT	\N	PRESENT	0
522425	522157	19367Y	PARTICIPANT	\N	PRESENT	0
522426	522157	20090E	PARTICIPANT	\N	PRESENT	0
522427	522157	20040T	PARTICIPANT	\N	PRESENT	0
522453	522157	14217N	PARTICIPANT	\N	PRESENT	0
522454	522157	19683J	PARTICIPANT	\N	PRESENT	0
522463	522157	14195A	PARTICIPANT	\N	PRESENT	0
526467	526466	14089Y	PARTICIPANT	\N	PRESENT	0
526468	526466	11026G	PARTICIPANT	\N	PRESENT	0
526470	526469	19569H	PARTICIPANT	\N	PRESENT	0
526471	526469	20082E	PARTICIPANT	\N	PRESENT	0
526472	526469	20058E	PARTICIPANT	\N	PRESENT	0
527252	526539	01043Q	PARTICIPANT	\N	PRESENT	0
527253	526539	04092N	PARTICIPANT	\N	PRESENT	0
527254	526539	19447X	PARTICIPANT	\N	PRESENT	0
527255	526539	19593H	PARTICIPANT	\N	PRESENT	0
527256	526539	11031D	PARTICIPANT	\N	PRESENT	0
527257	526539	19565D	PARTICIPANT	\N	PRESENT	0
527258	526539	04045F	PARTICIPANT	\N	PRESENT	0
527259	526539	19651A	PARTICIPANT	\N	PRESENT	0
527260	526539	19349W	PARTICIPANT	\N	PRESENT	0
527261	526539	19782L	PARTICIPANT	\N	PRESENT	0
527262	526539	14195A	PARTICIPANT	\N	PRESENT	0
527263	526539	20132W	PARTICIPANT	\N	PRESENT	0
527264	526539	19683J	PARTICIPANT	\N	PRESENT	0
527265	526539	11045K	PARTICIPANT	\N	PRESENT	0
527266	526539	20092G	PARTICIPANT	\N	PRESENT	0
527267	526539	20142Y	PARTICIPANT	\N	PRESENT	0
527268	526539	20134Y	PARTICIPANT	\N	PRESENT	0
527269	526539	20082E	PARTICIPANT	\N	PRESENT	0
527270	526539	20100N	PARTICIPANT	\N	PRESENT	0
527271	526539	19525U	PARTICIPANT	\N	PRESENT	0
527272	526539	20070A	PARTICIPANT	\N	PRESENT	0
527273	526539	20094J	PARTICIPANT	\N	PRESENT	0
527274	526539	19333N	PARTICIPANT	\N	PRESENT	0
527275	526539	19649G	PARTICIPANT	\N	PRESENT	0
527276	526539	11067R	PARTICIPANT	\N	PRESENT	0
527277	526539	20114U	PARTICIPANT	\N	PRESENT	0
527278	526539	19758L	PARTICIPANT	\N	PRESENT	0
527279	526539	19679N	PARTICIPANT	\N	PRESENT	0
527280	526539	11072N	PARTICIPANT	\N	PRESENT	0
527281	526539	19553Y	PARTICIPANT	\N	PRESENT	0
527282	526539	19575F	PARTICIPANT	\N	PRESENT	0
527283	526539	01024M	PARTICIPANT	\N	PRESENT	0
527284	526539	19713W	PARTICIPANT	\N	PRESENT	0
527285	526539	14042U	PARTICIPANT	\N	PRESENT	0
527286	526539	19569H	PARTICIPANT	\N	PRESENT	0
527287	526539	14105F	PARTICIPANT	\N	PRESENT	0
527288	526539	20066E	PARTICIPANT	\N	PRESENT	0
527289	526539	14231L	PARTICIPANT	\N	PRESENT	0
527290	526539	08069G	PARTICIPANT	\N	PRESENT	0
527291	526539	19691J	PARTICIPANT	\N	PRESENT	0
527292	526539	04047H	PARTICIPANT	\N	PRESENT	0
527293	526539	19335Q	PARTICIPANT	\N	PRESENT	0
527294	526539	14055N	PARTICIPANT	\N	PRESENT	0
527295	526539	19415P	PARTICIPANT	\N	PRESENT	0
527296	526539	19621T	PARTICIPANT	\N	PRESENT	0
527297	526539	19421M	PARTICIPANT	\N	PRESENT	0
527298	526539	10006L	PARTICIPANT	\N	PRESENT	0
527299	526539	08034U	PARTICIPANT	\N	PRESENT	0
527300	526539	05008E	PARTICIPANT	\N	PRESENT	0
527301	526539	14215L	PARTICIPANT	\N	PRESENT	0
527302	526539	14169X	PARTICIPANT	\N	PRESENT	0
537274	536828	19760E	PARTICIPANT	\N	PRESENT	0
537275	536828	19758L	PARTICIPANT	\N	PRESENT	0
537276	536828	19333N	PARTICIPANT	\N	PRESENT	0
537277	536828	20130U	PARTICIPANT	\N	PRESENT	0
537278	536828	19782L	PARTICIPANT	\N	PRESENT	0
537279	536828	20174H	PARTICIPANT	\N	PRESENT	0
537280	536828	14195A	PARTICIPANT	\N	PRESENT	0
537281	536828	14071N	PARTICIPANT	\N	PRESENT	0
537282	536828	04057K	PARTICIPANT	\N	PRESENT	0
537283	536828	17589D	PARTICIPANT	\N	PRESENT	0
537284	536828	19629C	PARTICIPANT	\N	PRESENT	0
537285	536828	19569H	PARTICIPANT	\N	PRESENT	0
537286	536828	20128B	PARTICIPANT	\N	PRESENT	0
537287	536828	11067R	PARTICIPANT	\N	PRESENT	0
537288	536828	20090E	PARTICIPANT	\N	PRESENT	0
537289	536828	20066E	PARTICIPANT	\N	PRESENT	0
537290	536828	07029T	PARTICIPANT	\N	PRESENT	0
537291	536828	14042U	PARTICIPANT	\N	PRESENT	0
537292	536828	14107H	PARTICIPANT	\N	PRESENT	0
537293	536828	19387D	PARTICIPANT	\N	PRESENT	0
537294	536828	20072C	PARTICIPANT	\N	PRESENT	0
537295	536828	19699S	PARTICIPANT	\N	PRESENT	0
537296	536828	17779H	PARTICIPANT	\N	PRESENT	0
537297	536828	19479G	PARTICIPANT	\N	PRESENT	0
537298	536828	19683J	PARTICIPANT	\N	PRESENT	0
537299	536828	19577H	PARTICIPANT	\N	PRESENT	0
537300	536828	20042V	PARTICIPANT	\N	PRESENT	0
537301	536828	20124W	PARTICIPANT	\N	PRESENT	0
537302	536828	19367Y	PARTICIPANT	\N	PRESENT	0
537303	536828	95063L	PARTICIPANT	\N	PRESENT	0
537304	536828	19798U	PARTICIPANT	\N	PRESENT	0
537305	536828	14217N	PARTICIPANT	\N	PRESENT	0
537306	536828	04043D	PARTICIPANT	\N	PRESENT	0
537307	536828	14121F	PARTICIPANT	\N	PRESENT	0
537308	536828	20062A	PARTICIPANT	\N	PRESENT	0
537309	536828	14147R	PARTICIPANT	\N	PRESENT	0
537310	536828	14213J	PARTICIPANT	\N	PRESENT	0
537311	536828	20172F	PARTICIPANT	\N	PRESENT	0
537312	536828	97011G	PARTICIPANT	\N	PRESENT	0
537313	536828	14133K	PARTICIPANT	\N	PRESENT	0
537314	536828	08010L	PARTICIPANT	\N	PRESENT	0
537315	536828	19703U	PARTICIPANT	\N	PRESENT	0
537316	536828	19441R	PARTICIPANT	\N	PRESENT	0
537317	536828	14026U	PARTICIPANT	\N	PRESENT	0
537318	536828	18083K	PARTICIPANT	\N	PRESENT	0
537319	536828	14259Y	PARTICIPANT	\N	PRESENT	0
537320	536828	20026V	PARTICIPANT	\N	PRESENT	0
537321	536828	19954N	PARTICIPANT	\N	PRESENT	0
537322	536828	20056C	PARTICIPANT	\N	PRESENT	0
537323	536828	20098N	PARTICIPANT	\N	PRESENT	0
537324	536828	19467C	PARTICIPANT	\N	PRESENT	0
537325	536828	12028B	PARTICIPANT	\N	PRESENT	0
537326	536828	20064C	PARTICIPANT	\N	PRESENT	0
537327	536828	20086J	PARTICIPANT	\N	PRESENT	0
537328	536828	20138D	PARTICIPANT	\N	PRESENT	0
537329	536828	19691J	PARTICIPANT	\N	PRESENT	0
537330	536828	01024M	PARTICIPANT	\N	PRESENT	0
537331	536828	20140W	PARTICIPANT	\N	PRESENT	0
537332	536828	08069G	PARTICIPANT	\N	PRESENT	0
537334	536828	20020P	PARTICIPANT	\N	PRESENT	0
537272	536828	11045K	PARTICIPANT	\N	PRESENT	0
537273	536828	11031D	PARTICIPANT	\N	PRESENT	0
537335	536828	08056B	PARTICIPANT	\N	PRESENT	0
537336	536828	20054A	PARTICIPANT	\N	PRESENT	0
537337	536828	19717B	PARTICIPANT	\N	PRESENT	0
537339	536828	19715Y	PARTICIPANT	\N	PRESENT	0
537340	536828	20116W	PARTICIPANT	\N	PRESENT	0
537341	536828	19443T	PARTICIPANT	\N	PRESENT	0
537342	536828	14105F	PARTICIPANT	\N	PRESENT	0
537343	536828	19747H	PARTICIPANT	\N	PRESENT	0
537344	536828	19591F	PARTICIPANT	\N	PRESENT	0
537345	536828	19768N	PARTICIPANT	\N	PRESENT	0
537346	536828	19657G	PARTICIPANT	\N	PRESENT	0
537347	536828	10006L	PARTICIPANT	\N	PRESENT	0
537348	536828	14030Q	PARTICIPANT	\N	PRESENT	0
537349	536828	11097X	PARTICIPANT	\N	PRESENT	0
537350	536828	11103C	PARTICIPANT	\N	PRESENT	0
537351	536828	19581D	PARTICIPANT	\N	PRESENT	0
537352	536828	20126Y	PARTICIPANT	\N	PRESENT	0
537353	536828	20046A	PARTICIPANT	\N	PRESENT	0
537354	536828	14031R	PARTICIPANT	\N	PRESENT	0
537355	536828	11043H	PARTICIPANT	\N	PRESENT	0
537356	536828	14173T	PARTICIPANT	\N	PRESENT	0
537357	536828	14223L	PARTICIPANT	\N	PRESENT	0
537358	536828	08015R	PARTICIPANT	\N	PRESENT	0
537367	536828	19335Q	PARTICIPANT	\N	PRESENT	0
537360	536828	08061X	PARTICIPANT	\N	PRESENT	0
537361	536895	14205J	PARTICIPANT	\N	PRESENT	0
537362	536895	14187A	PARTICIPANT	\N	PRESENT	0
537363	536895	19679N	PARTICIPANT	\N	PRESENT	0
537364	536895	11053K	PARTICIPANT	\N	PRESENT	0
537365	536895	17965H	PARTICIPANT	\N	PRESENT	0
537366	536895	18193Q	PRESIDENT	0	PRESENT	0
537368	536828	19399H	PARTICIPANT	\N	PRESENT	0
537369	536828	14211G	PARTICIPANT	\N	PRESENT	0
537370	536828	14331P	PARTICIPANT	\N	PRESENT	0
537371	536828	14083S	PARTICIPANT	\N	PRESENT	0
537372	536828	19695N	PARTICIPANT	\N	PRESENT	0
537373	536828	19563B	PARTICIPANT	\N	PRESENT	0
537397	536828	20104S	PARTICIPANT	\N	PRESENT	0
537398	536828	14249W	PARTICIPANT	\N	PRESENT	0
537400	536828	10015M	PARTICIPANT	\N	PRESENT	0
537401	536828	11083R	PARTICIPANT	\N	PRESENT	0
537412	537026	11067R	PARTICIPANT	\N	EXCUSE	0
537414	537413	08009T	PARTICIPANT	\N	PRESENT	0
537415	537413	20084G	PARTICIPANT	\N	PRESENT	0
537416	537413	14169X	PARTICIPANT	\N	PRESENT	0
537417	537413	19713W	PARTICIPANT	\N	PRESENT	0
537418	537413	19739H	PARTICIPANT	\N	PRESENT	0
537419	537413	10015M	PARTICIPANT	\N	PRESENT	0
537420	537413	20064C	PARTICIPANT	\N	PRESENT	0
537438	536609	19703U	PARTICIPANT	\N	PRESENT	0
537439	536609	11067R	PARTICIPANT	\N	PRESENT	0
537440	536609	20074E	PARTICIPANT	\N	PRESENT	0
537441	536609	14215L	PRESIDENT	0	PRESENT	0
537442	536607	14253S	PARTICIPANT	\N	PRESENT	0
537443	536607	20116W	PARTICIPANT	\N	PRESENT	0
537444	536607	14225N	PRESIDENT	0	PRESENT	0
537445	536609	17965H	PARTICIPANT	\N	PRESENT	0
537446	536609	19691J	PARTICIPANT	\N	PRESENT	0
537447	536609	14223L	PARTICIPANT	\N	PRESENT	0
537448	536609	19585H	PARTICIPANT	\N	PRESENT	0
537449	536609	01028R	PARTICIPANT	\N	PRESENT	0
537450	536609	19725B	PARTICIPANT	\N	PRESENT	0
537451	536609	14107H	PARTICIPANT	\N	PRESENT	0
537452	536609	14041T	PARTICIPANT	\N	PRESENT	0
537453	536609	20110Q	PARTICIPANT	\N	PRESENT	0
537454	536609	10006L	PARTICIPANT	\N	PRESENT	0
537456	536270	19725B	PARTICIPANT	\N	PRESENT	0
537457	536270	20074E	PARTICIPANT	\N	PRESENT	0
537458	536270	14041T	PARTICIPANT	\N	PRESENT	0
537459	536270	14107H	PARTICIPANT	\N	PRESENT	0
537460	536270	20110Q	PARTICIPANT	\N	PRESENT	0
537461	536270	14215L	PARTICIPANT	\N	PRESENT	0
537462	536270	19585H	PARTICIPANT	\N	PRESENT	0
537463	536270	01028R	PARTICIPANT	\N	PRESENT	0
537464	536607	11048N	PARTICIPANT	\N	PRESENT	0
537465	536607	19711U	PARTICIPANT	\N	PRESENT	0
537466	536607	01057W	PARTICIPANT	\N	PRESENT	0
537467	536607	20080C	PARTICIPANT	\N	PRESENT	0
537468	536607	20050V	PARTICIPANT	\N	PRESENT	0
537469	536607	11074Q	PARTICIPANT	\N	PRESENT	0
537470	536607	04086Q	PARTICIPANT	\N	PRESENT	0
537471	536607	11040E	PARTICIPANT	\N	PRESENT	0
537472	536607	08009T	PARTICIPANT	\N	PRESENT	0
537473	536607	20070A	PARTICIPANT	\N	PRESENT	0
537474	536607	19349W	PARTICIPANT	\N	PRESENT	0
537475	536607	14121F	PARTICIPANT	\N	PRESENT	0
537476	536607	19741B	PARTICIPANT	\N	PRESENT	0
537477	536607	07029T	PARTICIPANT	\N	EXCUSE	0
537478	536607	19671E	PARTICIPANT	\N	PRESENT	0
537479	536607	20044X	PARTICIPANT	\N	PRESENT	0
537480	536607	19335Q	PARTICIPANT	\N	PRESENT	0
537481	536607	14189C	PARTICIPANT	\N	PRESENT	0
537482	536607	19687N	PARTICIPANT	\N	PRESENT	0
537483	536609	11097X	PARTICIPANT	\N	PRESENT	0
537484	536609	19415P	PARTICIPANT	\N	PRESENT	0
537485	536609	18193Q	PARTICIPANT	\N	PRESENT	0
537486	536609	14231L	PARTICIPANT	\N	PRESENT	0
537487	536609	05008E	PARTICIPANT	\N	PRESENT	0
516773	516772	20116W	PARTICIPANT	\N	PRESENT	0
516774	516772	20042V	PARTICIPANT	\N	PRESENT	0
516775	516772	11080N	PARTICIPANT	\N	PRESENT	0
516776	516772	01057W	PARTICIPANT	\N	PRESENT	0
516777	516772	14121F	PARTICIPANT	\N	PRESENT	0
516778	516772	19711U	PARTICIPANT	\N	PRESENT	0
516779	516772	19335Q	PARTICIPANT	\N	PRESENT	0
516780	516772	05012A	PARTICIPANT	\N	PRESENT	0
519140	519137	17779H	PARTICIPANT	\N	PRESENT	0
519141	519138	17779H	PARTICIPANT	\N	PRESENT	0
519142	519138	11067R	PARTICIPANT	\N	PRESENT	0
519322	519321	18083K	PARTICIPANT	\N	PRESENT	0
519323	519321	20136B	PARTICIPANT	\N	PRESENT	0
519324	519321	20076G	PARTICIPANT	\N	PRESENT	0
519325	519321	14219Q	PRESIDENT	0	PRESENT	0
519326	519321	17229F	PARTICIPANT	\N	PRESENT	0
519327	519321	19503N	PARTICIPANT	\N	EXCUSE	0
519328	519321	14237S	PARTICIPANT	\N	PRESENT	0
519329	519321	14031R	PARTICIPANT	\N	PRESENT	0
519330	519321	19739H	PARTICIPANT	\N	PRESENT	0
519331	519321	19826F	PARTICIPANT	\N	PRESENT	0
519332	519321	19599P	PARTICIPANT	\N	PRESENT	0
519333	519321	19619A	PARTICIPANT	\N	PRESENT	0
519334	519321	14038Y	PARTICIPANT	\N	PRESENT	1
519335	519321	20020P	PARTICIPANT	\N	PRESENT	1
519336	519321	19637C	PARTICIPANT	\N	PRESENT	1
519337	519321	20038A	PARTICIPANT	\N	PRESENT	0
519338	519321	19745F	PARTICIPANT	\N	PRESENT	0
519339	519321	19387D	PARTICIPANT	\N	PRESENT	1
519340	519321	20120S	PARTICIPANT	\N	PRESENT	1
519341	519321	19333N	PARTICIPANT	\N	PRESENT	0
519342	519321	08060W	PARTICIPANT	\N	EXCUSE	0
519343	519321	19681G	PARTICIPANT	\N	EXCUSE	0
519344	519321	20140W	PARTICIPANT	\N	PRESENT	0
519345	519321	19251M	PARTICIPANT	\N	PRESENT	0
519346	519321	20102Q	PARTICIPANT	\N	PRESENT	0
519347	519321	20100N	PARTICIPANT	\N	PRESENT	0
519348	519321	20068G	PARTICIPANT	\N	PRESENT	0
519349	519321	17367Q	PARTICIPANT	\N	PRESENT	0
519350	519321	20024T	PARTICIPANT	\N	PRESENT	0
519351	519321	20032T	PARTICIPANT	\N	PRESENT	0
519352	519321	14205J	PARTICIPANT	\N	PRESENT	1
519353	519321	19549D	PARTICIPANT	\N	PRESENT	1
519354	519321	19820Y	PARTICIPANT	\N	PRESENT	0
519355	519321	19577H	PARTICIPANT	\N	PRESENT	0
519356	519321	20046A	PARTICIPANT	\N	PRESENT	0
519357	519321	19701S	PARTICIPANT	\N	PRESENT	0
519358	518947	11045K	PARTICIPANT	\N	PRESENT	0
519359	518947	20074E	PARTICIPANT	\N	PRESENT	0
519360	518947	14031R	PARTICIPANT	\N	PRESENT	0
519361	518947	20020P	PARTICIPANT	\N	PRESENT	0
519362	518947	20054A	PARTICIPANT	\N	PRESENT	0
519363	518947	20068G	PARTICIPANT	\N	PRESENT	0
519364	518947	14105F	PARTICIPANT	\N	PRESENT	0
519365	518947	18083K	PARTICIPANT	\N	PRESENT	0
519366	518947	20076G	PARTICIPANT	\N	PRESENT	0
519367	518947	11056N	PARTICIPANT	\N	PRESENT	0
519369	518947	19758L	PARTICIPANT	\N	PRESENT	0
519370	518947	19695N	PARTICIPANT	\N	PRESENT	0
519371	518947	20134Y	PARTICIPANT	\N	PRESENT	0
519373	518947	19782L	PARTICIPANT	\N	PRESENT	0
519374	518947	20072C	PARTICIPANT	\N	PRESENT	0
519375	518947	20106U	PARTICIPANT	\N	PRESENT	0
519376	518947	19349W	PARTICIPANT	\N	PRESENT	0
519377	518947	20124W	PARTICIPANT	\N	PRESENT	0
519378	518947	19711U	PARTICIPANT	\N	PRESENT	0
519379	518947	01058X	PARTICIPANT	\N	PRESENT	0
519380	518947	20024T	PARTICIPANT	\N	PRESENT	0
519381	518947	11101A	PARTICIPANT	\N	PRESENT	0
519382	518947	14257W	PARTICIPANT	\N	PRESENT	0
519383	518947	20082E	PARTICIPANT	\N	PRESENT	0
519384	518947	19954N	PARTICIPANT	\N	PRESENT	0
519385	518947	20056C	PARTICIPANT	\N	PRESENT	0
519386	518947	20126Y	PARTICIPANT	\N	PRESENT	0
519387	518947	19533U	PARTICIPANT	\N	PRESENT	0
519388	518947	14038Y	PARTICIPANT	\N	PRESENT	0
519389	518947	14221J	PARTICIPANT	\N	PRESENT	0
519390	518947	20098N	PARTICIPANT	\N	PRESENT	0
519391	518947	20138D	PARTICIPANT	\N	PRESENT	0
519392	518947	14179A	PARTICIPANT	\N	PRESENT	0
519393	518947	20136B	PARTICIPANT	\N	PRESENT	0
519394	518947	19826F	PARTICIPANT	\N	PRESENT	0
519395	518947	19631V	PARTICIPANT	\N	PRESENT	0
519396	518947	19399H	PARTICIPANT	\N	PRESENT	0
519397	518947	20018V	PARTICIPANT	\N	PRESENT	0
519398	518947	20094J	PARTICIPANT	\N	PRESENT	0
519399	518947	11103C	PARTICIPANT	\N	PRESENT	0
519400	518947	19760E	PARTICIPANT	\N	PRESENT	0
519401	518947	20066E	PARTICIPANT	\N	PRESENT	0
519402	518947	14073Q	PARTICIPANT	\N	PRESENT	0
519403	518947	11012A	PARTICIPANT	\N	PRESENT	0
519404	518947	14211G	PARTICIPANT	\N	PRESENT	0
519405	518947	20078J	PARTICIPANT	\N	PRESENT	0
519406	518947	11043H	PARTICIPANT	\N	PRESENT	0
519407	518947	14071N	PARTICIPANT	\N	PRESENT	0
519408	518947	20028X	PARTICIPANT	\N	PRESENT	0
519409	518947	19565D	PARTICIPANT	\N	PRESENT	0
519410	518947	19619A	PARTICIPANT	\N	PRESENT	0
519411	518947	04045F	PARTICIPANT	\N	PRESENT	0
519412	518947	19671E	PARTICIPANT	\N	PRESENT	0
519413	518947	20046A	PARTICIPANT	\N	PRESENT	0
519414	518947	19413M	PARTICIPANT	\N	PRESENT	0
519608	518948	20140W	PARTICIPANT	\N	PRESENT	0
519609	518948	19415P	PARTICIPANT	\N	PRESENT	0
519610	518948	20124W	PARTICIPANT	\N	PRESENT	0
519611	518948	14107H	PARTICIPANT	\N	PRESENT	0
519612	518948	20066E	PARTICIPANT	\N	PRESENT	0
519613	518948	14179A	PARTICIPANT	\N	PRESENT	0
519614	518948	19531S	PARTICIPANT	\N	PRESENT	0
519615	518948	20054A	PARTICIPANT	\N	PRESENT	0
519616	518948	14147R	PARTICIPANT	\N	PRESENT	0
519617	518948	19657G	PARTICIPANT	\N	PRESENT	0
519618	518948	20024T	PARTICIPANT	\N	PRESENT	0
519619	518948	19629C	PARTICIPANT	\N	PRESENT	0
519620	518948	20138D	PARTICIPANT	\N	PRESENT	0
519621	518948	19575F	PARTICIPANT	\N	PRESENT	0
519622	518948	19599P	PARTICIPANT	\N	PRESENT	0
519627	518948	14237S	PARTICIPANT	\N	PRESENT	0
519628	518948	20136B	PARTICIPANT	\N	PRESENT	0
519606	518948	19739H	PARTICIPANT	\N	PRESENT	0
519607	518948	20098N	PARTICIPANT	\N	PRESENT	0
519629	518948	19507S	PARTICIPANT	\N	PRESENT	0
519630	518948	14257W	PARTICIPANT	\N	PRESENT	0
519631	518948	20092G	PARTICIPANT	\N	PRESENT	0
519632	518948	05012A	PARTICIPANT	\N	PRESENT	0
519633	519210	19697Q	PARTICIPANT	\N	PRESENT	1
519634	519210	11067R	PARTICIPANT	\N	PRESENT	0
519635	519210	14355X	PARTICIPANT	\N	PRESENT	1
519636	519210	19569H	PARTICIPANT	\N	PRESENT	0
519637	519210	19798U	PARTICIPANT	\N	PRESENT	0
519638	519210	11097X	PARTICIPANT	\N	PRESENT	0
519639	519210	19415P	PARTICIPANT	\N	PRESENT	0
519640	519210	18193Q	PARTICIPANT	\N	PRESENT	0
519641	519210	14223L	PARTICIPANT	\N	PRESENT	0
519642	519210	14026U	PARTICIPANT	\N	PRESENT	0
519643	519210	17779H	PARTICIPANT	\N	PRESENT	0
519644	519210	11031D	PARTICIPANT	\N	PRESENT	0
519645	519210	19553Y	PARTICIPANT	\N	PRESENT	0
519646	519210	19703U	PARTICIPANT	\N	PRESENT	0
519647	519210	19966S	PARTICIPANT	\N	PRESENT	0
519648	519210	14281W	PARTICIPANT	\N	PRESENT	1
519649	519210	19679N	PARTICIPANT	\N	PRESENT	1
519650	519210	14042U	PARTICIPANT	\N	PRESENT	0
519651	519210	14195A	PARTICIPANT	\N	PRESENT	0
519652	519210	14213J	PARTICIPANT	\N	PRESENT	0
519653	519210	19367Y	PARTICIPANT	\N	PRESENT	0
519654	519210	14217N	PARTICIPANT	\N	PRESENT	0
519655	519210	19683J	PARTICIPANT	\N	PRESENT	0
519656	519210	10006L	PRESIDENT	0	PRESENT	0
519657	519210	19591F	PARTICIPANT	\N	PRESENT	1
519658	519210	20130U	PARTICIPANT	\N	PRESENT	0
519659	519210	01034P	PARTICIPANT	\N	PRESENT	0
519660	519210	04057K	PARTICIPANT	\N	PRESENT	0
519661	519210	04092N	PARTICIPANT	0	PRESENT	0
519662	519210	19713W	PARTICIPANT	\N	PRESENT	0
519663	519210	19301E	PARTICIPANT	\N	PRESENT	1
519664	519210	17965H	PARTICIPANT	\N	PRESENT	0
519665	519210	19715Y	PARTICIPANT	\N	PRESENT	0
519666	519210	19691J	PARTICIPANT	\N	PRESENT	0
519667	519210	19717B	PARTICIPANT	\N	PRESENT	0
519668	519210	20148F	PARTICIPANT	\N	PRESENT	0
521699	519786	19683J	PARTICIPANT	\N	PRESENT	0
521700	519786	19447X	PARTICIPANT	\N	PRESENT	0
521701	519786	17737W	PARTICIPANT	\N	PRESENT	0
521702	519786	20132W	PARTICIPANT	\N	PRESENT	0
521703	519786	11067R	PARTICIPANT	\N	PRESENT	0
521704	519786	20092G	PARTICIPANT	\N	PRESENT	0
521705	519786	08034U	PARTICIPANT	\N	PRESENT	0
521706	519786	11026G	PARTICIPANT	\N	PRESENT	0
521707	519786	04045F	PARTICIPANT	\N	PRESENT	0
521708	519786	20066E	PARTICIPANT	\N	PRESENT	0
521709	519786	14041T	PARTICIPANT	\N	PRESENT	0
521710	519786	14042U	PARTICIPANT	\N	PRESENT	0
521711	519786	14179A	PARTICIPANT	\N	PRESENT	0
521712	519786	10006L	PARTICIPANT	\N	PRESENT	0
521713	521401	19729F	PARTICIPANT	\N	PRESENT	0
521714	519786	19415P	PARTICIPANT	\N	PRESENT	0
521715	519786	19691J	PARTICIPANT	\N	PRESENT	0
521716	519786	11031D	PARTICIPANT	\N	PRESENT	0
521717	519786	19575F	PARTICIPANT	\N	PRESENT	0
521718	521401	17737W	PARTICIPANT	\N	PRESENT	0
521719	521401	19954N	PARTICIPANT	\N	PRESENT	0
521720	521401	19673G	PARTICIPANT	\N	PRESENT	0
521721	521401	20074E	PARTICIPANT	\N	PRESENT	0
521722	521401	10015M	PARTICIPANT	\N	PRESENT	0
521723	521401	14053L	PARTICIPANT	\N	PRESENT	0
521724	521401	04047H	PRESIDENT	0	PRESENT	0
521725	521401	14111D	PARTICIPANT	\N	PRESENT	0
521726	521401	19585H	PARTICIPANT	\N	PRESENT	0
521727	521401	14179A	PARTICIPANT	\N	PRESENT	0
521728	521401	05008E	PARTICIPANT	\N	PRESENT	0
521729	521401	14089Y	PARTICIPANT	\N	PRESENT	0
521730	521401	11072N	PARTICIPANT	\N	PRESENT	0
521731	521473	20068G	PARTICIPANT	\N	PRESENT	0
521732	521401	19675J	PARTICIPANT	\N	PRESENT	1
521733	521401	01028R	PARTICIPANT	\N	PRESENT	1
521734	521401	14107H	PARTICIPANT	\N	PRESENT	1
521735	521401	20110Q	PARTICIPANT	\N	PRESENT	1
521736	521401	14147R	PARTICIPANT	\N	PRESENT	1
521737	521401	19749K	PARTICIPANT	\N	PRESENT	1
521738	521473	20034V	PARTICIPANT	\N	PRESENT	0
521742	521473	20090E	PARTICIPANT	\N	PRESENT	0
521743	521473	20074E	PARTICIPANT	\N	PRESENT	0
521744	521473	20052X	PARTICIPANT	\N	PRESENT	0
521745	521473	19729F	PARTICIPANT	\N	PRESENT	0
521746	521473	20138D	PARTICIPANT	\N	PRESENT	0
521747	521473	19673G	PARTICIPANT	\N	PRESENT	0
521748	521473	17737W	PARTICIPANT	\N	PRESENT	0
521749	521473	19954N	PARTICIPANT	\N	PRESENT	0
521750	521473	04047H	PARTICIPANT	\N	PRESENT	0
521751	521473	19543W	PARTICIPANT	\N	PRESENT	0
521752	521473	14111D	PARTICIPANT	\N	PRESENT	0
521753	521473	19585H	PARTICIPANT	\N	PRESENT	0
521754	521473	14107H	PARTICIPANT	\N	PRESENT	0
521755	521473	20174H	PARTICIPANT	\N	PRESENT	0
521756	521473	11072N	PARTICIPANT	\N	PRESENT	0
521757	521473	20046A	PARTICIPANT	\N	PRESENT	0
521758	521473	19826F	PARTICIPANT	\N	PRESENT	0
521759	521473	14089Y	PARTICIPANT	\N	PRESENT	0
521760	521473	14331P	PARTICIPANT	\N	PRESENT	0
521761	521473	20054A	PARTICIPANT	\N	PRESENT	0
521762	521473	14053L	PARTICIPANT	\N	PRESENT	0
521763	521473	04043D	PARTICIPANT	\N	PRESENT	0
521764	521473	11090Q	PARTICIPANT	\N	PRESENT	0
521765	521473	20024T	PARTICIPANT	\N	PRESENT	0
521766	521473	20172F	PARTICIPANT	\N	PRESENT	0
521767	521473	20056C	PARTICIPANT	\N	PRESENT	0
521768	521473	20140W	PARTICIPANT	\N	PRESENT	0
521769	521473	10015M	PARTICIPANT	\N	PRESENT	0
521770	521473	20076G	PARTICIPANT	\N	PRESENT	0
521771	521473	19467C	PARTICIPANT	\N	PRESENT	0
521772	521473	20032T	PARTICIPANT	\N	PRESENT	0
521773	521473	19507S	PARTICIPANT	\N	PRESENT	0
521774	521473	14038Y	PARTICIPANT	\N	PRESENT	0
521775	521473	19533U	PARTICIPANT	\N	PRESENT	0
521776	521473	11103C	PARTICIPANT	\N	PRESENT	0
521777	521473	20062A	PARTICIPANT	\N	PRESENT	0
521778	521473	20148F	PARTICIPANT	\N	PRESENT	0
521779	521473	20072C	PARTICIPANT	\N	PRESENT	0
521780	521473	19349W	PARTICIPANT	\N	PRESENT	0
521781	521473	20114U	PARTICIPANT	\N	PRESENT	0
521782	521473	20112S	PARTICIPANT	\N	PRESENT	0
521786	521473	14121F	PARTICIPANT	\N	PRESENT	0
521784	521473	14109K	PARTICIPANT	\N	PRESENT	0
521785	521473	20110Q	PARTICIPANT	\N	PRESENT	0
521787	521473	14187A	PARTICIPANT	\N	PRESENT	0
521788	521473	95063L	PARTICIPANT	\N	PRESENT	0
521789	521473	14267Y	PARTICIPANT	\N	PRESENT	0
521790	519786	11045K	PARTICIPANT	\N	PRESENT	0
521791	521473	01058X	PARTICIPANT	\N	PRESENT	0
521792	521473	97011G	PARTICIPANT	\N	PRESENT	0
521793	521473	19415P	PARTICIPANT	\N	PRESENT	0
521794	521473	19703U	PARTICIPANT	\N	PRESENT	0
521826	521473	11115U	PARTICIPANT	\N	PRESENT	0
521827	521473	20082E	PARTICIPANT	\N	PRESENT	0
521828	521473	14105F	PARTICIPANT	\N	PRESENT	0
521831	521473	20028X	PARTICIPANT	\N	PRESENT	0
521832	521473	11012A	PARTICIPANT	\N	PRESENT	0
521833	521473	14179A	PARTICIPANT	\N	PRESENT	0
521834	521473	14123H	PARTICIPANT	\N	PRESENT	0
521835	521473	19719D	PARTICIPANT	\N	PRESENT	0
521836	521473	19687N	PARTICIPANT	\N	PRESENT	0
521837	521473	20026V	PARTICIPANT	\N	PRESENT	0
521838	521473	19569H	PARTICIPANT	\N	PRESENT	0
521839	521473	19621T	PARTICIPANT	\N	PRESENT	0
521861	521473	14213J	PARTICIPANT	\N	PRESENT	0
521864	521473	20088L	PARTICIPANT	\N	PRESENT	0
521870	521473	11026G	PARTICIPANT	\N	PRESENT	0
521871	521473	20038A	PARTICIPANT	\N	PRESENT	0
521873	521473	20044X	PARTICIPANT	\N	PRESENT	0
521874	521473	20104S	PARTICIPANT	\N	PRESENT	0
521876	521473	14249W	PARTICIPANT	\N	PRESENT	0
521877	521473	19611R	PARTICIPANT	\N	PRESENT	0
521881	521473	20100N	PARTICIPANT	\N	PRESENT	0
521891	521473	19768N	PARTICIPANT	\N	PRESENT	0
521892	521473	19762G	PARTICIPANT	\N	PRESENT	0
521893	521473	19695N	PARTICIPANT	\N	PRESENT	0
521894	521473	20066E	PARTICIPANT	\N	PRESENT	0
521895	521473	01024M	PARTICIPANT	\N	PRESENT	0
521896	521473	14237S	PARTICIPANT	\N	PRESENT	0
521897	521473	14189C	PARTICIPANT	\N	PRESENT	0
521898	521473	18083K	PARTICIPANT	\N	PRESENT	0
521899	521473	14001X	PARTICIPANT	\N	PRESENT	0
521900	521473	19387D	PARTICIPANT	\N	PRESENT	0
521901	521473	19747H	PARTICIPANT	\N	PRESENT	0
521904	521473	19685L	PARTICIPANT	\N	PRESENT	0
521905	521473	11067R	PARTICIPANT	\N	PRESENT	0
521906	521473	19631V	PARTICIPANT	\N	PRESENT	0
521907	521473	19479G	PARTICIPANT	\N	PRESENT	0
521908	521473	04045F	PARTICIPANT	\N	PRESENT	0
521998	521475	99004R	PARTICIPANT	\N	PRESENT	0
521999	521475	19673G	PARTICIPANT	\N	PRESENT	0
522000	521475	14038Y	PARTICIPANT	\N	PRESENT	0
522001	521475	14055N	PARTICIPANT	\N	PRESENT	0
522002	521475	19585H	PARTICIPANT	\N	PRESENT	0
522003	521475	20110Q	PARTICIPANT	\N	PRESENT	0
522004	521475	14249W	PARTICIPANT	\N	PRESENT	0
522005	521475	19629C	PARTICIPANT	\N	PRESENT	0
522006	521475	04085P	PARTICIPANT	\N	PRESENT	0
522007	521475	14179A	PARTICIPANT	\N	PRESENT	0
522008	521475	11026G	PARTICIPANT	\N	PRESENT	0
522009	521475	14237S	PARTICIPANT	\N	PRESENT	0
522010	521475	14133K	PARTICIPANT	\N	PRESENT	0
522011	521475	19768N	PARTICIPANT	\N	PRESENT	0
522012	521475	19671E	PARTICIPANT	\N	PRESENT	0
522013	521475	01024M	PARTICIPANT	\N	PRESENT	0
522014	521475	14042U	PARTICIPANT	\N	PRESENT	0
522015	521475	19479G	PARTICIPANT	\N	PRESENT	0
522016	521475	11012A	PARTICIPANT	\N	PRESENT	0
522017	521475	19387D	PARTICIPANT	\N	PRESENT	0
522018	521475	20132W	PARTICIPANT	\N	PRESENT	0
522019	521475	19467C	PARTICIPANT	\N	PRESENT	0
522020	521475	20054A	PARTICIPANT	\N	PRESENT	0
522021	521475	19685L	PARTICIPANT	\N	PRESENT	0
522022	521475	19762G	PARTICIPANT	\N	PRESENT	0
522023	521475	20062A	PARTICIPANT	\N	PRESENT	0
522024	521475	20046A	PARTICIPANT	\N	PRESENT	0
522025	521475	20092G	PARTICIPANT	\N	PRESENT	0
522026	521475	20174H	PARTICIPANT	\N	PRESENT	0
522027	521475	20100N	PARTICIPANT	\N	PRESENT	0
522028	521475	08061X	PARTICIPANT	\N	PRESENT	0
522029	521475	04047H	PARTICIPANT	\N	PRESENT	0
517530	517067	20116W	PARTICIPANT	\N	PRESENT	0
517531	517067	14105F	PARTICIPANT	\N	PRESENT	0
517532	517067	20090E	PARTICIPANT	\N	PRESENT	0
517533	517067	11103C	PARTICIPANT	\N	PRESENT	0
517534	517067	14329V	PARTICIPANT	\N	PRESENT	0
517535	517067	18083K	PARTICIPANT	\N	PRESENT	0
517536	517067	17589D	PARTICIPANT	\N	PRESENT	0
517537	517067	14357A	PARTICIPANT	\N	PRESENT	0
517538	517067	14187A	PARTICIPANT	\N	PRESENT	0
517539	517067	19507S	PARTICIPANT	\N	PRESENT	0
517550	517067	11090Q	PARTICIPANT	\N	PRESENT	0
517583	517067	14169X	PARTICIPANT	\N	PRESENT	0
517584	517067	08061X	PARTICIPANT	\N	PRESENT	0
517585	517067	14237S	PARTICIPANT	\N	PRESENT	0
517586	517067	05012A	PARTICIPANT	\N	PRESENT	0
517590	517067	14221J	PARTICIPANT	\N	PRESENT	0
517591	517067	19563B	PARTICIPANT	\N	PRESENT	0
517593	517067	19739H	PARTICIPANT	\N	PRESENT	0
517594	517067	20038A	PARTICIPANT	\N	PRESENT	0
517606	517067	20044X	PARTICIPANT	\N	PRESENT	0
517602	517067	20076G	PARTICIPANT	\N	PRESENT	0
517600	517067	20118Y	PARTICIPANT	\N	PRESENT	0
517601	517067	19760E	PARTICIPANT	\N	PRESENT	0
517604	517067	19681G	PARTICIPANT	\N	PRESENT	0
517605	517067	19723Y	PARTICIPANT	\N	PRESENT	0
517616	517067	14097Y	PARTICIPANT	\N	PRESENT	0
517641	517640	14179A	PARTICIPANT	\N	PRESENT	0
517642	517640	04008A	PARTICIPANT	\N	PRESENT	0
518607	518606	11048N	PARTICIPANT	\N	PRESENT	0
523260	521235	14121F	PARTICIPANT	\N	PRESENT	1
523261	521235	99004R	PARTICIPANT	\N	PRESENT	1
523262	521235	20050V	PARTICIPANT	\N	PRESENT	1
523263	521235	20022R	PARTICIPANT	\N	EXCUSE	0
523264	521235	11012A	PARTICIPANT	\N	EXCUSE	0
523463	523462	14189C	PARTICIPANT	\N	PRESENT	0
523464	523462	19543W	PARTICIPANT	\N	PRESENT	0
523465	523462	20024T	PARTICIPANT	\N	PRESENT	0
523466	523462	11040E	PARTICIPANT	\N	PRESENT	0
523467	523462	19367Y	PARTICIPANT	\N	PRESENT	0
523468	523462	19966S	PARTICIPANT	\N	PRESENT	0
523469	523462	11101A	PARTICIPANT	\N	PRESENT	0
523470	523462	19545Y	PARTICIPANT	\N	PRESENT	0
523471	523462	14357A	PARTICIPANT	\N	PRESENT	0
523472	523462	14041T	PARTICIPANT	\N	PRESENT	0
523473	523462	97011G	PARTICIPANT	\N	PRESENT	0
523475	523462	04035D	PARTICIPANT	\N	PRESENT	0
523476	523462	14123H	PARTICIPANT	\N	PRESENT	0
523478	523462	20106U	PARTICIPANT	\N	PRESENT	0
523480	523462	14179A	PARTICIPANT	\N	PRESENT	0
523481	523462	19333N	PARTICIPANT	\N	PRESENT	0
523482	523462	08015R	PARTICIPANT	\N	PRESENT	0
523483	523462	08034U	PARTICIPANT	\N	PRESENT	0
523484	523462	19563B	PARTICIPANT	\N	PRESENT	0
523485	523462	20062A	PARTICIPANT	\N	PRESENT	0
523486	523462	11041F	PARTICIPANT	\N	PRESENT	0
527305	526539	19798U	PARTICIPANT	\N	PRESENT	0
527306	526539	20124W	PARTICIPANT	\N	PRESENT	0
527307	526539	20090E	PARTICIPANT	\N	PRESENT	0
527308	526539	20056C	PARTICIPANT	\N	PRESENT	0
527309	526539	19768N	PARTICIPANT	\N	PRESENT	0
527310	526539	20026V	PARTICIPANT	\N	PRESENT	0
527311	526539	20180F	PARTICIPANT	\N	PRESENT	0
527312	526539	20032T	PARTICIPANT	\N	PRESENT	0
527313	526539	14329V	PARTICIPANT	\N	PRESENT	0
527314	526539	19954N	PARTICIPANT	\N	PRESENT	0
527315	526539	04033B	PARTICIPANT	\N	PRESENT	0
527316	526539	20140W	PARTICIPANT	\N	PRESENT	0
527317	526539	20062A	PARTICIPANT	\N	PRESENT	0
527318	526539	20024T	PARTICIPANT	\N	PRESENT	0
527319	526539	14147R	PARTICIPANT	\N	PRESENT	0
527320	526539	14213J	PARTICIPANT	\N	PRESENT	0
527321	526539	10015M	PARTICIPANT	\N	PRESENT	0
527322	526539	19729F	PARTICIPANT	\N	PRESENT	0
527323	526539	08015R	PARTICIPANT	\N	PRESENT	0
527324	526539	20044X	PARTICIPANT	\N	PRESENT	0
527325	526539	20034V	PARTICIPANT	\N	PRESENT	0
527326	526539	20104S	PARTICIPANT	\N	PRESENT	0
527327	526539	14038Y	PARTICIPANT	\N	PRESENT	0
527328	526539	19723Y	PARTICIPANT	\N	PRESENT	0
527329	526539	20076G	PARTICIPANT	\N	PRESENT	0
527330	526539	17367Q	PARTICIPANT	\N	PRESENT	0
527331	526539	07029T	PARTICIPANT	\N	PRESENT	0
527332	526539	19467C	PARTICIPANT	\N	PRESENT	0
527333	526539	14026U	PARTICIPANT	\N	PRESENT	0
527334	526539	20110Q	PARTICIPANT	\N	PRESENT	0
527335	526539	14033T	PARTICIPANT	\N	PRESENT	0
527336	526539	19697Q	PARTICIPANT	\N	PRESENT	0
527340	526539	20138D	PARTICIPANT	\N	PRESENT	0
527338	526539	20058E	PARTICIPANT	\N	PRESENT	0
527339	526539	20096L	PARTICIPANT	\N	PRESENT	0
527341	526539	20172F	PARTICIPANT	\N	PRESENT	0
527342	526539	20118Y	PARTICIPANT	\N	PRESENT	0
527343	526539	19549D	PARTICIPANT	\N	PRESENT	0
527344	526539	11066Q	PARTICIPANT	\N	PRESENT	0
527345	526539	19551W	PARTICIPANT	\N	PRESENT	0
527346	526539	19826F	PARTICIPANT	\N	PRESENT	0
527347	526539	20048C	PARTICIPANT	\N	PRESENT	0
527348	526539	14217N	PARTICIPANT	\N	PRESENT	0
527349	526539	14193X	PARTICIPANT	\N	PRESENT	0
527350	526539	20086J	PARTICIPANT	\N	PRESENT	0
527351	526539	19507S	PARTICIPANT	\N	PRESENT	0
527352	526539	19573D	PARTICIPANT	\N	PRESENT	0
527353	526539	20054A	PARTICIPANT	\N	PRESENT	0
527354	526539	20126Y	PARTICIPANT	\N	PRESENT	0
527355	526539	14133K	PARTICIPANT	\N	PRESENT	0
527356	526539	14071N	PARTICIPANT	\N	PRESENT	0
527357	526539	19545Y	PARTICIPANT	\N	PRESENT	0
527358	526539	14357A	PARTICIPANT	\N	PRESENT	0
527359	526539	19762G	PARTICIPANT	\N	PRESENT	0
527360	526539	14179A	PARTICIPANT	\N	PRESENT	0
527361	526539	19747H	PARTICIPANT	\N	PRESENT	0
527362	526539	20052X	PARTICIPANT	\N	PRESENT	0
527303	526539	14053L	PARTICIPANT	\N	PRESENT	0
527304	526539	18083K	PARTICIPANT	\N	PRESENT	0
527363	526539	19347U	PARTICIPANT	\N	PRESENT	0
527364	526539	20106U	PARTICIPANT	\N	PRESENT	0
527365	526539	17637T	PARTICIPANT	\N	PRESENT	0
527366	526539	14219Q	PARTICIPANT	\N	PRESENT	0
527367	526539	11065P	PARTICIPANT	\N	PRESENT	0
527368	526539	19367Y	PARTICIPANT	\N	PRESENT	0
527369	526539	19647E	PARTICIPANT	\N	PRESENT	0
527370	526539	11026G	PARTICIPANT	\N	PRESENT	0
527371	526539	19715Y	PARTICIPANT	\N	PRESENT	0
527372	526539	19387D	PARTICIPANT	\N	PRESENT	0
527424	525852	20066E	PARTICIPANT	\N	PRESENT	1
527428	525852	08045X	PARTICIPANT	\N	PRESENT	1
527429	525852	19697Q	PARTICIPANT	\N	PRESENT	1
527430	525852	19760E	PARTICIPANT	\N	PRESENT	1
527438	525852	19591F	PARTICIPANT	\N	PRESENT	1
527432	525852	20040T	PARTICIPANT	\N	PRESENT	0
527436	525852	19663E	PARTICIPANT	\N	PRESENT	1
527437	525852	19657G	PARTICIPANT	\N	PRESENT	1
527462	525852	04057K	PARTICIPANT	\N	PRESENT	0
527465	525852	11031D	PARTICIPANT	\N	PRESENT	0
527466	525852	19569H	PARTICIPANT	\N	PRESENT	1
527467	525852	19713W	PARTICIPANT	\N	PRESENT	1
527468	525852	01034P	PARTICIPANT	\N	PRESENT	0
527492	525852	17965H	PARTICIPANT	\N	PRESENT	0
527535	525852	20172F	PARTICIPANT	\N	PRESENT	1
527536	525852	19415P	PARTICIPANT	\N	PRESENT	0
527537	526558	14042U	PARTICIPANT	\N	PRESENT	0
527538	526558	11097X	PRESIDENT	0	PRESENT	0
527539	526558	11103C	PARTICIPANT	\N	PRESENT	0
527540	526558	19697Q	PARTICIPANT	\N	PRESENT	0
527541	526558	14071N	PARTICIPANT	\N	PRESENT	0
527542	526558	01034P	PARTICIPANT	\N	PRESENT	0
527543	526558	14026U	PARTICIPANT	\N	PRESENT	0
527544	526558	19703U	PARTICIPANT	\N	PRESENT	0
527545	526558	08045X	PARTICIPANT	\N	PRESENT	0
527546	526558	19657G	PARTICIPANT	\N	PRESENT	0
527547	526558	19591F	PARTICIPANT	\N	PRESENT	0
527548	526558	20066E	PARTICIPANT	\N	PRESENT	0
527549	526558	20172F	PARTICIPANT	\N	PRESENT	0
527563	526558	04092N	PARTICIPANT	\N	PRESENT	0
527564	526558	17779H	PARTICIPANT	\N	PRESENT	0
527565	526558	14213J	PARTICIPANT	\N	PRESENT	0
527567	526558	19713W	PARTICIPANT	\N	PRESENT	0
527569	527568	01048V	PARTICIPANT	\N	PRESENT	0
527571	527570	01048V	PARTICIPANT	\N	PRESENT	0
527614	526558	18193Q	PARTICIPANT	\N	EXCUSE	0
527672	526549	07033P	PARTICIPANT	\N	PRESENT	1
537488	536609	11031D	PARTICIPANT	\N	PRESENT	0
537489	536609	19679N	PARTICIPANT	\N	PRESENT	0
537490	536609	14042U	PARTICIPANT	\N	PRESENT	0
537491	536609	14147R	PARTICIPANT	\N	PRESENT	0
537492	536609	14195A	PARTICIPANT	\N	PRESENT	0
537493	536609	20114U	PARTICIPANT	\N	PRESENT	0
537494	536609	19367Y	PARTICIPANT	\N	PRESENT	0
537495	536609	14213J	PARTICIPANT	\N	PRESENT	0
537496	536609	14217N	PARTICIPANT	\N	PRESENT	0
537497	536609	08045X	PARTICIPANT	\N	PRESENT	0
537498	536609	20148F	PARTICIPANT	\N	PRESENT	0
537499	536609	19719D	PARTICIPANT	\N	PRESENT	0
537500	536609	19723Y	PARTICIPANT	\N	PRESENT	0
537501	536609	14069U	PARTICIPANT	\N	PRESENT	0
537502	536609	14071N	PARTICIPANT	\N	PRESENT	0
537504	536607	19762G	PARTICIPANT	\N	PRESENT	0
537511	536607	20022R	PARTICIPANT	\N	PRESENT	0
537518	536609	04047H	PARTICIPANT	\N	PRESENT	0
537519	536609	19447X	PARTICIPANT	\N	PRESENT	0
537520	536609	14111D	PARTICIPANT	\N	PRESENT	0
537526	537524	11054L	PARTICIPANT	\N	PRESENT	0
537527	537524	01058X	PARTICIPANT	\N	PRESENT	0
537528	537524	20042V	PARTICIPANT	\N	PRESENT	0
537529	536611	20074E	PARTICIPANT	\N	PRESENT	0
537530	536611	04047H	PRESIDENT	0	PRESENT	0
537531	536611	01028R	PARTICIPANT	\N	PRESENT	0
537532	536611	19447X	PARTICIPANT	\N	PRESENT	0
537533	536611	05008E	PARTICIPANT	\N	PRESENT	0
537534	536611	19725B	PARTICIPANT	\N	PRESENT	0
537535	536611	11056N	PARTICIPANT	\N	PRESENT	0
537536	536611	19954N	PARTICIPANT	\N	PRESENT	0
537537	536611	17737W	PARTICIPANT	\N	PRESENT	0
537538	536611	95063L	PARTICIPANT	\N	PRESENT	0
537539	536611	14041T	PARTICIPANT	\N	PRESENT	0
537540	536611	20108W	PARTICIPANT	\N	PRESENT	0
537541	536611	20110Q	PARTICIPANT	\N	PRESENT	0
537542	536611	14147R	PARTICIPANT	\N	PRESENT	0
537543	536611	20114U	PARTICIPANT	\N	PRESENT	0
537544	536611	14215L	PARTICIPANT	\N	PRESENT	0
537545	536611	11072N	PARTICIPANT	\N	PRESENT	0
537566	536275	11067R	PARTICIPANT	\N	PRESENT	0
537567	536275	08045X	PARTICIPANT	\N	PRESENT	0
537568	536275	14195A	PARTICIPANT	\N	PRESENT	0
537569	536275	19301E	PARTICIPANT	\N	PRESENT	0
537571	536286	19383Y	PARTICIPANT	\N	PRESENT	0
537572	536286	19768N	PARTICIPANT	\N	PRESENT	0
537573	536286	20088L	PARTICIPANT	\N	PRESENT	0
537574	536286	19515S	PARTICIPANT	\N	PRESENT	0
537575	536286	19782L	PARTICIPANT	\N	PRESENT	0
537576	536286	11077T	PARTICIPANT	\N	PRESENT	1
537577	536286	01043Q	PARTICIPANT	\N	PRESENT	0
537578	536286	14357A	PARTICIPANT	\N	PRESENT	0
537579	536286	19441R	PARTICIPANT	\N	PRESENT	1
537580	536286	20078J	PARTICIPANT	\N	PRESENT	1
537581	536286	19413M	PARTICIPANT	\N	PRESENT	0
537582	536286	20082E	PARTICIPANT	\N	PRESENT	1
537583	536286	20094J	PARTICIPANT	\N	PRESENT	1
537584	536286	04045F	PARTICIPANT	\N	PRESENT	1
537585	536286	19631V	PARTICIPANT	\N	PRESENT	0
537586	536286	20104S	PARTICIPANT	\N	PRESENT	1
537587	536286	11099A	PARTICIPANT	\N	PRESENT	0
537588	536286	19705W	PARTICIPANT	\N	PRESENT	1
537589	536286	19575F	PARTICIPANT	\N	PRESENT	0
537590	536286	19369B	PARTICIPANT	\N	PRESENT	1
537591	536286	20018V	PARTICIPANT	\N	PRESENT	1
537592	536286	19511N	PARTICIPANT	\N	PRESENT	0
537593	536286	19563B	PARTICIPANT	\N	PRESENT	0
537594	536286	20028X	PARTICIPANT	\N	PRESENT	0
537595	536286	14038Y	PARTICIPANT	\N	PRESENT	1
537596	536286	20030R	PARTICIPANT	\N	PRESENT	1
537597	536286	19467C	PARTICIPANT	\N	PRESENT	1
537598	536286	14187A	PARTICIPANT	\N	PRESENT	0
537599	536286	19695N	PARTICIPANT	\N	PRESENT	0
537600	536286	14033T	PARTICIPANT	\N	PRESENT	0
537601	536286	11090Q	PRESIDENT	0	PRESENT	0
537602	536286	01025N	PARTICIPANT	\N	PRESENT	1
537603	536286	20054A	PARTICIPANT	\N	PRESENT	0
537604	536286	20174H	PARTICIPANT	\N	PRESENT	0
537605	536286	14205J	PARTICIPANT	\N	PRESENT	0
537606	536286	20060X	PARTICIPANT	\N	PRESENT	1
537607	536286	20062A	PARTICIPANT	\N	PRESENT	0
537608	536286	19507S	PARTICIPANT	\N	PRESENT	0
537609	536286	14207L	PARTICIPANT	\N	PRESENT	0
537610	536286	19747H	PARTICIPANT	\N	PRESENT	1
537611	536286	14257W	PARTICIPANT	\N	PRESENT	0
537612	536837	14105F	PARTICIPANT	\N	PRESENT	0
537613	536837	14133K	PARTICIPANT	\N	PRESENT	1
537614	536837	04042C	PRESIDENT	0	PRESENT	0
537615	536607	14083S	PARTICIPANT	\N	PRESENT	0
537616	536837	19443T	PARTICIPANT	\N	PRESENT	0
537617	536837	12041X	PARTICIPANT	\N	PRESENT	1
537618	536837	20072C	PARTICIPANT	\N	PRESENT	1
537619	536837	04034C	PARTICIPANT	\N	PRESENT	0
537620	536837	01058X	PARTICIPANT	\N	PRESENT	1
537621	536837	11027H	PARTICIPANT	\N	PRESENT	0
537622	536837	08056B	PARTICIPANT	\N	PRESENT	0
537623	536837	11115U	PARTICIPANT	\N	PRESENT	0
537624	536837	19421M	PARTICIPANT	\N	PRESENT	0
537625	536837	19709B	PARTICIPANT	\N	PRESENT	1
537626	536837	14193X	PARTICIPANT	\N	PRESENT	1
537627	536837	19347U	PARTICIPANT	\N	PRESENT	0
537628	536837	97011G	PARTICIPANT	\N	PRESENT	0
537629	536837	14249W	PARTICIPANT	\N	PRESENT	0
537630	536837	08047A	PARTICIPANT	\N	PRESENT	0
537631	536837	20128B	PARTICIPANT	\N	PRESENT	1
537632	536837	14097Y	PARTICIPANT	\N	PRESENT	1
537633	536837	01062T	PARTICIPANT	\N	PRESENT	0
537634	536837	08069G	PARTICIPANT	\N	PRESENT	1
537635	536837	11041F	PARTICIPANT	\N	PRESENT	1
537636	536837	20042V	PARTICIPANT	\N	PRESENT	0
537637	536837	01024M	PARTICIPANT	\N	PRESENT	0
537639	536837	20064C	PARTICIPANT	\N	PRESENT	0
537640	536837	98022P	PARTICIPANT	\N	PRESENT	0
537641	536837	14267Y	PARTICIPANT	\N	PRESENT	0
537642	536837	11083R	PARTICIPANT	\N	PRESENT	1
537643	536837	19583F	PARTICIPANT	\N	PRESENT	1
537644	536837	14255U	PARTICIPANT	\N	PRESENT	0
537645	530868	19593H	PARTICIPANT	\N	PRESENT	0
537646	530868	19643A	PARTICIPANT	\N	PRESENT	0
537647	530868	19699S	PARTICIPANT	\N	PRESENT	0
537648	530868	19533U	PARTICIPANT	\N	PRESENT	0
537649	530868	19651A	PARTICIPANT	\N	PRESENT	0
537650	530868	19611R	PRESIDENT	0	PRESENT	0
537651	530868	20142Y	PARTICIPANT	\N	PRESENT	0
537652	530868	19693L	PARTICIPANT	\N	PRESENT	0
537653	530868	19399H	PARTICIPANT	\N	PRESENT	0
537654	530868	19719D	PARTICIPANT	\N	PRESENT	0
537655	530868	20052X	PARTICIPANT	\N	PRESENT	1
537656	530868	20152B	PARTICIPANT	\N	PRESENT	0
537657	530868	14229S	PARTICIPANT	\N	PRESENT	0
537658	530868	14030Q	PARTICIPANT	\N	PRESENT	0
537659	530868	20058E	PARTICIPANT	\N	PRESENT	0
537660	530868	20180F	PARTICIPANT	\N	PRESENT	0
537661	530868	19573D	PARTICIPANT	\N	PRESENT	0
537662	530868	04059M	PARTICIPANT	\N	PRESENT	0
537663	530868	19735D	PARTICIPANT	\N	PRESENT	0
537664	530868	14109K	PARTICIPANT	\N	PRESENT	1
537665	530868	19758L	PARTICIPANT	\N	PRESENT	0
537666	530868	20084G	PARTICIPANT	\N	PRESENT	0
537667	530868	19621T	PARTICIPANT	\N	PRESENT	0
537668	530868	11109J	PARTICIPANT	\N	EXCUSE	0
537669	536607	14331P	PARTICIPANT	\N	PRESENT	0
537670	536607	11053K	PARTICIPANT	\N	PRESENT	0
537671	536607	11012A	PARTICIPANT	\N	PRESENT	0
537672	536607	14187A	PARTICIPANT	\N	PRESENT	0
537673	536613	19954N	PARTICIPANT	\N	PRESENT	0
537674	536613	17737W	PARTICIPANT	\N	PRESENT	0
537675	536613	20074E	PARTICIPANT	\N	PRESENT	0
537676	536613	20108W	PARTICIPANT	\N	PRESENT	0
537677	536613	20114U	PARTICIPANT	\N	PRESENT	0
537679	536613	04047H	PRESIDENT	0	PRESENT	0
537680	536613	01028R	PARTICIPANT	\N	PRESENT	0
537681	536613	19447X	PARTICIPANT	\N	PRESENT	0
537682	536837	19565D	PARTICIPANT	\N	PRESENT	1
537683	536837	11054L	PARTICIPANT	\N	PRESENT	1
537684	536837	19669L	PARTICIPANT	\N	PRESENT	1
537685	536837	04035D	PARTICIPANT	\N	PRESENT	1
537686	534915	19333N	PARTICIPANT	\N	PRESENT	0
537687	534915	19549D	PARTICIPANT	\N	PRESENT	0
515117	501820	19798U	PARTICIPANT	\N	PRESENT	0
515120	502367	19798U	PARTICIPANT	\N	PRESENT	0
518684	518683	14221J	PARTICIPANT	\N	PRESENT	0
518686	518685	14221J	PARTICIPANT	\N	PRESENT	0
518699	516854	14331P	PRESIDENT	0	PRESENT	0
518700	516854	20128B	PARTICIPANT	\N	PRESENT	0
518701	516854	11026G	PARTICIPANT	\N	PRESENT	0
518702	516854	20094J	PARTICIPANT	\N	PRESENT	0
518703	516854	14133K	PARTICIPANT	\N	PRESENT	0
518704	516854	14357A	PARTICIPANT	\N	PRESENT	0
518705	516854	14033T	PARTICIPANT	\N	PRESENT	0
518706	516854	14189C	PARTICIPANT	\N	PRESENT	0
518707	516854	14073Q	PARTICIPANT	\N	PRESENT	0
518710	516854	11083R	PARTICIPANT	\N	PRESENT	0
518711	516854	19521Q	PARTICIPANT	\N	PRESENT	0
518712	516854	14207L	PARTICIPANT	\N	PRESENT	0
518713	516854	19441R	PARTICIPANT	\N	PRESENT	0
518715	516854	19711U	PARTICIPANT	\N	PRESENT	0
518717	516854	20098N	PARTICIPANT	\N	PRESENT	1
518718	516854	14097Y	PARTICIPANT	\N	PRESENT	1
518719	516854	04034C	PARTICIPANT	\N	PRESENT	1
518720	516854	19251M	PARTICIPANT	\N	PRESENT	1
518721	516854	20100N	PARTICIPANT	\N	PRESENT	1
518722	516854	10015M	PARTICIPANT	\N	PRESENT	1
518723	516854	14169X	PARTICIPANT	\N	PRESENT	1
518724	516854	19701S	PARTICIPANT	\N	PRESENT	1
518725	516854	04070G	PARTICIPANT	\N	PRESENT	1
518726	516854	19709B	PARTICIPANT	\N	PRESENT	0
518727	516854	11101A	PARTICIPANT	\N	EXCUSE	0
518728	516854	14026U	PARTICIPANT	\N	EXCUSE	0
518729	516854	20104S	PARTICIPANT	\N	EXCUSE	0
518730	516854	14237S	PARTICIPANT	\N	EXCUSE	0
519313	519312	19703U	PARTICIPANT	\N	EXCUSE	0
519314	519312	19479G	PARTICIPANT	\N	PRESENT	0
519315	519312	99004R	PARTICIPANT	\N	PRESENT	0
519316	519312	19399H	PARTICIPANT	\N	PRESENT	0
519317	519312	01028R	PARTICIPANT	\N	EXCUSE	0
519318	519312	20144B	PARTICIPANT	\N	PRESENT	0
519319	519312	08012N	PARTICIPANT	\N	EXCUSE	0
519623	519312	20050V	PARTICIPANT	\N	EXCUSE	0
519669	519210	20172F	PARTICIPANT	\N	PRESENT	0
519670	519210	19723Y	PARTICIPANT	\N	PRESENT	0
519671	519210	20066E	PARTICIPANT	\N	PRESENT	0
519672	519210	11103C	PARTICIPANT	\N	PRESENT	0
519673	519210	19657G	PARTICIPANT	\N	PRESENT	0
519674	519210	14071N	PARTICIPANT	\N	PRESENT	0
519675	519210	04043D	PARTICIPANT	\N	PRESENT	0
519676	519210	19760E	PARTICIPANT	\N	PRESENT	0
519680	518948	14205J	PARTICIPANT	\N	PRESENT	0
519681	518948	19671E	PARTICIPANT	\N	PRESENT	0
519682	518948	14031R	PARTICIPANT	\N	PRESENT	0
519683	518948	19637C	PARTICIPANT	\N	PRESENT	0
519684	518948	19581D	PARTICIPANT	\N	PRESENT	0
519743	518949	19333N	PARTICIPANT	\N	PRESENT	0
519744	518949	14205J	PARTICIPANT	\N	PRESENT	0
519745	518949	19820Y	PARTICIPANT	\N	PRESENT	0
519746	518949	14257W	PARTICIPANT	\N	PRESENT	0
519747	518949	19631V	PARTICIPANT	\N	PRESENT	0
519748	518949	19599P	PARTICIPANT	\N	PRESENT	0
519749	518949	19387D	PARTICIPANT	\N	PRESENT	0
519750	518949	19637C	PARTICIPANT	\N	PRESENT	0
519751	518949	19347U	PARTICIPANT	\N	PRESENT	0
519752	518949	20092G	PARTICIPANT	\N	PRESENT	0
519753	518949	20100N	PARTICIPANT	\N	PRESENT	0
519755	518949	14219Q	PARTICIPANT	\N	PRESENT	0
519756	518949	20046A	PARTICIPANT	\N	PRESENT	0
519757	518949	19745F	PARTICIPANT	\N	PRESENT	0
519758	518949	19479G	PARTICIPANT	\N	PRESENT	0
519759	518949	19739H	PARTICIPANT	\N	PRESENT	0
519760	518949	08009T	PARTICIPANT	\N	PRESENT	0
519761	518949	14083S	PARTICIPANT	\N	PRESENT	0
519763	518949	19671E	PARTICIPANT	\N	PRESENT	0
519764	518949	14189C	PARTICIPANT	\N	PRESENT	0
519765	518949	19747H	PARTICIPANT	\N	PRESENT	0
519766	518949	20124W	PARTICIPANT	\N	PRESENT	0
519767	518949	19762G	PARTICIPANT	\N	PRESENT	0
519768	518949	19383Y	PARTICIPANT	\N	PRESENT	0
519769	518949	20062A	PARTICIPANT	\N	PRESENT	0
519770	518949	05012A	PARTICIPANT	\N	PRESENT	0
519771	518949	20122U	PARTICIPANT	\N	PRESENT	0
519772	518949	14187A	PARTICIPANT	\N	PRESENT	0
519773	518949	11043H	PARTICIPANT	\N	PRESENT	0
519774	518949	11090Q	PARTICIPANT	\N	PRESENT	0
519775	518949	19575F	PARTICIPANT	\N	PRESENT	0
519776	518949	20076G	PARTICIPANT	\N	PRESENT	0
519777	518949	20032T	PARTICIPANT	\N	PRESENT	0
519778	518949	14031R	PARTICIPANT	\N	PRESENT	0
519779	518949	20044X	PARTICIPANT	\N	PRESENT	0
519780	518949	19467C	PARTICIPANT	\N	PRESENT	0
519781	518949	19741B	PARTICIPANT	\N	PRESENT	0
519782	518949	20136B	PARTICIPANT	\N	PRESENT	0
519783	518949	14069U	PARTICIPANT	\N	PRESENT	0
519784	518949	11065P	PARTICIPANT	\N	PRESENT	0
519785	518949	20140W	PARTICIPANT	\N	PRESENT	0
519788	518949	19549D	PARTICIPANT	\N	PRESENT	0
519791	518949	19565D	PARTICIPANT	\N	PRESENT	0
519792	518949	19551W	PARTICIPANT	\N	PRESENT	0
519793	518949	19251M	PARTICIPANT	\N	PRESENT	0
519794	518949	19503N	PARTICIPANT	\N	PRESENT	0
519795	518949	19798U	PARTICIPANT	\N	PRESENT	0
519796	518949	20054A	PARTICIPANT	\N	PRESENT	0
519797	518949	20090E	PARTICIPANT	\N	PRESENT	0
519798	518949	19713W	PARTICIPANT	\N	PRESENT	0
519799	518949	11099A	PARTICIPANT	\N	PRESENT	0
519800	518949	19782L	PARTICIPANT	\N	PRESENT	0
519801	518949	20060X	PARTICIPANT	\N	PRESENT	0
519802	518949	01024M	PARTICIPANT	\N	PRESENT	0
519803	518949	20126Y	PARTICIPANT	\N	PRESENT	0
519804	518949	20072C	PARTICIPANT	\N	PRESENT	0
519741	518949	11045K	PARTICIPANT	\N	PRESENT	0
519742	518949	18083K	PARTICIPANT	\N	PRESENT	0
519805	519223	19649G	PARTICIPANT	\N	PRESENT	0
519806	519223	19581D	PARTICIPANT	\N	PRESENT	0
519807	519223	04047H	PRESIDENT	0	PRESENT	0
519808	519223	01028R	PARTICIPANT	\N	PRESENT	0
519809	519223	11033F	PARTICIPANT	\N	PRESENT	0
519810	519223	14231L	PARTICIPANT	\N	PRESENT	0
519811	519223	04085P	PARTICIPANT	\N	PRESENT	0
519812	519223	19725B	PARTICIPANT	\N	PRESENT	0
519813	519223	17737W	PARTICIPANT	\N	PRESENT	0
519814	519223	20108W	PARTICIPANT	\N	PRESENT	0
519815	519223	14147R	PARTICIPANT	\N	PRESENT	0
519816	519223	20114U	PARTICIPANT	\N	PRESENT	0
519817	519223	04008A	PARTICIPANT	\N	PRESENT	0
519818	519223	19749K	PARTICIPANT	\N	PRESENT	0
519819	518949	08061X	PARTICIPANT	\N	PRESENT	0
519820	518949	11067R	PARTICIPANT	\N	PRESENT	0
519821	519223	05008E	PARTICIPANT	\N	PRESENT	0
519822	519223	14215L	PARTICIPANT	\N	PRESENT	0
519823	519223	20074E	PARTICIPANT	\N	PRESENT	0
519824	519223	19447X	PARTICIPANT	\N	PRESENT	0
519825	519223	19489J	PARTICIPANT	\N	PRESENT	1
519826	519223	95063L	PARTICIPANT	\N	PRESENT	1
519827	519223	14151M	PARTICIPANT	\N	PRESENT	0
519828	519223	11072N	PARTICIPANT	\N	PRESENT	1
519829	519223	14021P	PARTICIPANT	\N	PRESENT	0
519830	519223	10015M	PARTICIPANT	\N	PRESENT	0
519831	519223	14179A	PARTICIPANT	\N	PRESENT	0
519832	519223	19954N	PARTICIPANT	\N	PRESENT	0
519833	518949	20048C	PARTICIPANT	\N	PRESENT	0
519834	518949	19563B	PARTICIPANT	\N	PRESENT	0
519835	518949	19723Y	PARTICIPANT	\N	PRESENT	0
519836	519223	14053L	PARTICIPANT	\N	PRESENT	0
519837	519229	14059S	PARTICIPANT	\N	PRESENT	0
519838	519229	04035D	PARTICIPANT	\N	PRESENT	1
519839	519229	19443T	PARTICIPANT	\N	PRESENT	1
519840	519229	14133K	PARTICIPANT	\N	PRESENT	1
519841	519229	20072C	PARTICIPANT	\N	PRESENT	0
519842	519229	01058X	PARTICIPANT	\N	PRESENT	1
519843	519229	04042C	PRESIDENT	0	PRESENT	0
519844	519229	11066Q	PARTICIPANT	\N	PRESENT	0
519845	519229	14105F	PARTICIPANT	\N	PRESENT	1
519846	519229	20064C	PARTICIPANT	\N	PRESENT	1
519847	519229	19709B	PARTICIPANT	\N	PRESENT	0
519848	519229	14267Y	PARTICIPANT	\N	PRESENT	0
519849	519229	11064N	PARTICIPANT	\N	PRESENT	0
519850	519229	14193X	PARTICIPANT	\N	PRESENT	0
519851	519229	11083R	PARTICIPANT	\N	PRESENT	0
519852	519229	97011G	PARTICIPANT	\N	PRESENT	0
519853	519229	14249W	PARTICIPANT	\N	PRESENT	0
519854	519229	14211G	PARTICIPANT	\N	PRESENT	0
522032	521475	19798U	PARTICIPANT	\N	PRESENT	0
522033	521475	20090E	PARTICIPANT	\N	PRESENT	0
522034	521475	97011G	PARTICIPANT	\N	PRESENT	0
522035	521475	11103C	PARTICIPANT	\N	PRESENT	0
522036	521475	14105F	PARTICIPANT	\N	PRESENT	0
522037	521475	17737W	PARTICIPANT	\N	PRESENT	0
522038	521475	08015R	PARTICIPANT	\N	PRESENT	0
522039	521475	14031R	PARTICIPANT	\N	PRESENT	0
522040	521475	20058E	PARTICIPANT	\N	PRESENT	0
522041	521475	20074E	PARTICIPANT	\N	PRESENT	0
522042	521475	20088L	PARTICIPANT	\N	PRESENT	0
522043	521475	11067R	PARTICIPANT	\N	PRESENT	0
522044	521475	14123H	PARTICIPANT	\N	PRESENT	0
522045	521475	20044X	PARTICIPANT	\N	PRESENT	0
522046	521475	19599P	PARTICIPANT	\N	PRESENT	0
522047	521475	19739H	PARTICIPANT	\N	PRESENT	0
522048	521475	14083S	PARTICIPANT	\N	PRESENT	0
522049	521475	20138D	PARTICIPANT	\N	PRESENT	0
522050	521475	20034V	PARTICIPANT	\N	PRESENT	0
522051	521475	20140W	PARTICIPANT	\N	PRESENT	0
522052	521475	19415P	PARTICIPANT	\N	PRESENT	0
522053	521475	20052X	PARTICIPANT	\N	PRESENT	0
522054	521475	19563B	PARTICIPANT	\N	PRESENT	0
522055	521475	19349W	PARTICIPANT	\N	PRESENT	0
522056	521475	14109K	PARTICIPANT	\N	PRESENT	0
522057	521475	19631V	PARTICIPANT	\N	PRESENT	0
522058	521475	19725B	PARTICIPANT	\N	PRESENT	0
522059	521475	14001X	PARTICIPANT	\N	PRESENT	0
522060	521475	14187A	PARTICIPANT	\N	PRESENT	0
522061	521475	19741B	PARTICIPANT	\N	PRESENT	0
522062	521475	19515S	PARTICIPANT	\N	PRESENT	0
522063	521475	20096L	PARTICIPANT	\N	PRESENT	0
522064	521475	14329V	PARTICIPANT	\N	PRESENT	0
522065	521475	20136B	PARTICIPANT	\N	PRESENT	0
522066	521475	19703U	PARTICIPANT	\N	PRESENT	0
522067	521475	19760E	PARTICIPANT	\N	PRESENT	0
522068	521475	01028R	PARTICIPANT	\N	PRESENT	0
522069	521475	20114U	PARTICIPANT	\N	PRESENT	0
522070	521475	19573D	PARTICIPANT	\N	PRESENT	0
522071	521475	19383Y	PARTICIPANT	\N	PRESENT	0
522072	521475	20124W	PARTICIPANT	\N	PRESENT	0
522073	521475	12041X	PARTICIPANT	\N	PRESENT	0
522074	521475	20056C	PARTICIPANT	\N	PRESENT	0
522075	521475	19399H	PARTICIPANT	\N	PRESENT	0
522076	521475	14021P	PARTICIPANT	\N	PRESENT	0
522077	521475	20076G	PARTICIPANT	\N	PRESENT	0
522078	521475	19533U	PARTICIPANT	\N	PRESENT	0
522079	521475	04034C	PARTICIPANT	\N	PRESENT	0
522080	521475	19507S	PARTICIPANT	\N	PRESENT	0
522081	521475	14211G	PARTICIPANT	\N	PRESENT	0
522082	521475	14069U	PARTICIPANT	\N	PRESENT	0
522083	521475	14121F	PARTICIPANT	\N	PRESENT	0
522084	521475	20032T	PARTICIPANT	\N	PRESENT	0
522085	521475	19565D	PARTICIPANT	\N	PRESENT	0
522086	521475	19691J	PARTICIPANT	\N	PRESENT	0
522087	521475	19782L	PARTICIPANT	\N	PRESENT	0
522088	521475	20038A	PARTICIPANT	\N	PRESENT	0
522030	521475	19367Y	PARTICIPANT	\N	PRESENT	0
522031	521475	19747H	PARTICIPANT	\N	PRESENT	0
522089	521475	20082E	PARTICIPANT	\N	PRESENT	0
522090	521475	08056B	PARTICIPANT	\N	PRESENT	0
522091	521475	14215L	PARTICIPANT	\N	PRESENT	0
522092	521475	19335Q	PARTICIPANT	\N	PRESENT	0
522093	521475	14219Q	PARTICIPANT	\N	PRESENT	0
522094	521475	95063L	PARTICIPANT	\N	PRESENT	0
522095	521475	19447X	PARTICIPANT	\N	PRESENT	0
522096	521475	20128B	PARTICIPANT	\N	PRESENT	0
522097	521475	11056N	PARTICIPANT	\N	PRESENT	0
522098	521475	14073Q	PARTICIPANT	\N	PRESENT	0
522099	521475	19729F	PARTICIPANT	\N	PRESENT	0
522100	521475	19695N	PARTICIPANT	\N	PRESENT	0
522103	521475	19820Y	PARTICIPANT	\N	PRESENT	0
522110	521475	11101A	PARTICIPANT	\N	PRESENT	0
522111	521475	14217N	PARTICIPANT	\N	PRESENT	0
522112	521475	11097X	PARTICIPANT	\N	PRESENT	0
522113	521475	20066E	PARTICIPANT	\N	PRESENT	0
522116	522115	10015M	PARTICIPANT	\N	PRESENT	0
522117	522115	07004J	PARTICIPANT	\N	PRESENT	0
522118	522115	20024T	PARTICIPANT	\N	PRESENT	0
522119	522115	11099A	PARTICIPANT	\N	PRESENT	0
522120	522115	12028B	PARTICIPANT	\N	PRESENT	0
522121	522115	18083K	PARTICIPANT	\N	PRESENT	0
522122	522115	14267Y	PARTICIPANT	\N	PRESENT	0
522123	522115	20084G	PARTICIPANT	\N	PRESENT	0
522124	522115	19749K	PARTICIPANT	\N	PRESENT	0
522125	522115	14255U	PARTICIPANT	\N	PRESENT	0
522126	522115	19531S	PARTICIPANT	\N	PRESENT	0
522127	522115	11027H	PARTICIPANT	\N	PRESENT	0
522128	522115	11065P	PARTICIPANT	\N	PRESENT	0
522129	522115	20070A	PARTICIPANT	\N	PRESENT	0
522130	521475	20026V	PARTICIPANT	\N	PRESENT	0
522131	521475	14231L	PARTICIPANT	\N	PRESENT	0
522132	521475	14331P	PARTICIPANT	\N	PRESENT	0
522133	521475	01034P	PARTICIPANT	\N	PRESENT	0
522418	521234	07029T	PARTICIPANT	\N	PRESENT	0
522424	521234	14225N	PRESIDENT	0	PRESENT	0
522428	521402	14053L	PARTICIPANT	\N	PRESENT	0
522429	521402	14111D	PARTICIPANT	\N	PRESENT	0
522430	521402	19649G	PARTICIPANT	\N	PRESENT	0
522431	521402	20074E	PARTICIPANT	\N	PRESENT	0
522432	521402	10015M	PARTICIPANT	\N	PRESENT	0
522433	521402	19543W	PARTICIPANT	\N	PRESENT	0
522434	521402	04047H	PRESIDENT	0	PRESENT	0
522435	521402	19673G	PARTICIPANT	\N	PRESENT	0
522436	521402	01028R	PARTICIPANT	\N	PRESENT	0
522437	521402	14231L	PARTICIPANT	\N	PRESENT	0
522438	521402	19447X	PARTICIPANT	\N	PRESENT	0
522439	521402	05008E	PARTICIPANT	\N	PRESENT	0
522440	521402	14089Y	PARTICIPANT	\N	PRESENT	0
522441	521402	11056N	PARTICIPANT	\N	PRESENT	0
522442	521402	19729F	PARTICIPANT	\N	PRESENT	0
522443	521402	19489J	PARTICIPANT	\N	PRESENT	0
522444	521402	95063L	PARTICIPANT	\N	PRESENT	0
522445	521402	20110Q	PARTICIPANT	\N	PRESENT	0
522446	521402	20114U	PARTICIPANT	\N	PRESENT	0
522447	521402	14069U	PARTICIPANT	\N	PRESENT	0
522448	521402	14151M	PARTICIPANT	\N	PRESENT	0
522449	521402	14215L	PARTICIPANT	\N	PRESENT	0
522450	521402	19749K	PARTICIPANT	\N	PRESENT	0
522451	521402	14021P	PARTICIPANT	\N	PRESENT	0
522452	521402	19725B	PARTICIPANT	\N	PRESENT	0
522465	521402	19954N	PARTICIPANT	\N	PRESENT	0
522466	521402	14041T	PARTICIPANT	\N	PRESENT	0
522468	521501	20098N	PARTICIPANT	\N	PRESENT	0
522469	521501	11043H	PARTICIPANT	\N	PRESENT	0
522472	521501	19399H	PARTICIPANT	\N	PRESENT	0
522473	521501	08012N	PARTICIPANT	\N	PRESENT	0
522474	521501	14073Q	PARTICIPANT	\N	PRESENT	0
522478	521502	20098N	PARTICIPANT	\N	PRESENT	0
522479	521502	08012N	PARTICIPANT	\N	PRESENT	0
522480	521502	20180F	PARTICIPANT	\N	PRESENT	0
522481	521502	19399H	PARTICIPANT	\N	PRESENT	0
522482	521502	11043H	PARTICIPANT	\N	PRESENT	0
522483	521610	20098N	PARTICIPANT	\N	PRESENT	0
522500	521470	12041X	PARTICIPANT	\N	PRESENT	1
522501	521470	19443T	PARTICIPANT	\N	PRESENT	1
522502	521470	19565D	PARTICIPANT	\N	PRESENT	0
522503	521470	20072C	PARTICIPANT	\N	PRESENT	1
522504	521470	04034C	PARTICIPANT	\N	PRESENT	0
522505	521470	01058X	PARTICIPANT	\N	PRESENT	1
522506	521470	11027H	PARTICIPANT	\N	PRESENT	0
522507	521470	16685X	PARTICIPANT	\N	PRESENT	0
522508	521470	04042C	PRESIDENT	0	PRESENT	0
522509	521470	11054L	PARTICIPANT	\N	PRESENT	0
522510	521470	11066Q	PARTICIPANT	\N	PRESENT	0
522511	521470	08056B	PARTICIPANT	\N	PRESENT	0
522512	521470	11115U	PARTICIPANT	\N	PRESENT	0
522513	521470	19421M	PARTICIPANT	\N	PRESENT	1
522514	521470	19709B	PARTICIPANT	\N	PRESENT	0
522515	521470	19347U	PARTICIPANT	\N	PRESENT	0
522516	521470	14193X	PARTICIPANT	\N	PRESENT	0
522517	521470	20128B	PARTICIPANT	\N	PRESENT	0
522518	521470	14097Y	PARTICIPANT	\N	PRESENT	1
522519	521470	14059S	PARTICIPANT	\N	PRESENT	0
522520	521470	04035D	PARTICIPANT	\N	PRESENT	0
522521	521470	14133K	PARTICIPANT	\N	PRESENT	0
522522	521470	01062T	PARTICIPANT	\N	PRESENT	1
522523	521470	08069G	PARTICIPANT	\N	PRESENT	0
522524	521470	20042V	PARTICIPANT	\N	PRESENT	1
522525	521470	01024M	PARTICIPANT	\N	PRESENT	0
522526	521470	19319Q	PARTICIPANT	\N	PRESENT	1
513617	502357	08010L	PARTICIPANT	\N	PRESENT	0
513618	502357	19741B	PARTICIPANT	\N	PRESENT	0
513619	502357	19713W	PARTICIPANT	\N	PRESENT	0
513620	502357	14331P	PARTICIPANT	\N	PRESENT	0
513621	502357	19531S	PARTICIPANT	\N	PRESENT	0
513622	502357	08011M	PARTICIPANT	\N	PRESENT	0
513623	502357	19701S	PARTICIPANT	\N	PRESENT	0
513624	502357	20126Y	PARTICIPANT	\N	PRESENT	0
513625	502357	20124W	PARTICIPANT	\N	PRESENT	0
513626	502357	20152B	PARTICIPANT	\N	PRESENT	0
513627	502357	19762G	PARTICIPANT	\N	PRESENT	0
513628	502357	19643A	PARTICIPANT	\N	PRESENT	0
513629	502357	11099A	PARTICIPANT	\N	PRESENT	0
513630	502357	14213J	PARTICIPANT	\N	PRESENT	0
513631	502357	01057W	PARTICIPANT	\N	PRESENT	0
513632	502357	19503N	PARTICIPANT	\N	PRESENT	0
513633	502357	04085P	PARTICIPANT	\N	PRESENT	0
513634	502357	19551W	PARTICIPANT	\N	PRESENT	0
513635	502357	01048V	PARTICIPANT	\N	PRESENT	0
513682	502359	19747H	PARTICIPANT	\N	PRESENT	0
513683	502359	19711U	PARTICIPANT	\N	PRESENT	0
513684	502359	20022R	PARTICIPANT	\N	PRESENT	0
513685	502359	19713W	PARTICIPANT	\N	PRESENT	0
513686	502359	20034V	PARTICIPANT	\N	PRESENT	0
513687	502359	19629C	PARTICIPANT	\N	PRESENT	0
513688	502359	19717B	PARTICIPANT	\N	PRESENT	0
513689	502359	19667J	PARTICIPANT	\N	PRESENT	0
513690	502359	11099A	PARTICIPANT	\N	PRESENT	0
513691	502359	20080C	PARTICIPANT	\N	PRESENT	0
513692	502359	19399H	PARTICIPANT	\N	PRESENT	0
513693	502359	19503N	PARTICIPANT	\N	PRESENT	0
513694	502359	07029T	PARTICIPANT	\N	PRESENT	0
513695	502359	19551W	PARTICIPANT	\N	PRESENT	0
513696	502359	11048N	PARTICIPANT	\N	PRESENT	0
513697	502359	19651A	PARTICIPANT	\N	PRESENT	0
513701	502359	04042C	PARTICIPANT	\N	PRESENT	0
513699	502359	04086Q	PARTICIPANT	\N	PRESENT	0
513700	502359	19335Q	PARTICIPANT	\N	PRESENT	0
513702	502359	19693L	PARTICIPANT	\N	PRESENT	0
513703	502359	20050V	PARTICIPANT	\N	PRESENT	0
513704	502359	04071H	PARTICIPANT	\N	PRESENT	0
513705	502359	01048V	PARTICIPANT	\N	PRESENT	0
513706	502359	19685L	PARTICIPANT	\N	PRESENT	0
513707	502359	04033B	PARTICIPANT	\N	PRESENT	0
513708	502359	19701S	PARTICIPANT	\N	PRESENT	0
513709	502359	20058E	PARTICIPANT	\N	PRESENT	0
513710	502359	20152B	PARTICIPANT	\N	PRESENT	0
513711	502359	14331P	PARTICIPANT	\N	PRESENT	0
513712	502359	11053K	PARTICIPANT	\N	PRESENT	0
513713	502359	19565D	PARTICIPANT	\N	PRESENT	0
513714	502359	19671E	PARTICIPANT	\N	PRESENT	0
513715	502359	11090Q	PARTICIPANT	\N	PRESENT	0
513716	502359	19762G	PARTICIPANT	\N	PRESENT	0
513717	502359	08010L	PARTICIPANT	\N	PRESENT	0
513718	502359	19741B	PARTICIPANT	\N	PRESENT	0
513719	502359	08011M	PARTICIPANT	\N	PRESENT	0
517603	515076	20060X	PARTICIPANT	\N	PRESENT	1
517620	515076	19441R	PARTICIPANT	\N	PRESENT	0
517631	515076	20018V	PARTICIPANT	\N	PRESENT	1
517656	515076	14357A	PARTICIPANT	\N	PRESENT	0
517714	515076	14205J	PARTICIPANT	\N	EXCUSE	0
518633	518632	04047H	PARTICIPANT	\N	PRESENT	0
518634	518632	11066Q	PARTICIPANT	\N	PRESENT	0
513680	502359	14026U	PARTICIPANT	\N	PRESENT	0
513681	502359	19575F	PARTICIPANT	\N	PRESENT	0
518640	518591	14195A	PARTICIPANT	\N	EXCUSE	0
518638	518591	19760E	PARTICIPANT	\N	EXCUSE	0
518639	518591	14030Q	PARTICIPANT	\N	EXCUSE	0
518641	518591	19251M	PARTICIPANT	\N	EXCUSE	0
518642	518591	14253S	PARTICIPANT	\N	EXCUSE	0
518643	518591	19762G	PARTICIPANT	\N	EXCUSE	0
523729	521370	14189C	PARTICIPANT	\N	EXCUSE	0
523730	521370	14030Q	PRESIDENT	0	PRESENT	0
523731	521370	20138D	PARTICIPANT	\N	PRESENT	0
523732	521370	11031D	PARTICIPANT	\N	EXCUSE	0
523733	521370	19693L	PARTICIPANT	\N	PRESENT	0
523734	521370	19599P	PARTICIPANT	\N	PRESENT	0
523735	521370	04035D	PARTICIPANT	\N	PRESENT	0
523736	521370	14179A	PARTICIPANT	\N	PRESENT	0
523737	521370	20056C	PARTICIPANT	\N	PRESENT	0
523738	521370	07029T	PARTICIPANT	\N	EXCUSE	0
523739	521370	14221J	PARTICIPANT	\N	PRESENT	0
523740	521370	14109K	PARTICIPANT	\N	PRESENT	0
523741	521370	20118Y	PARTICIPANT	\N	EXCUSE	0
523742	521370	20130U	PARTICIPANT	\N	PRESENT	0
523743	521370	19798U	PARTICIPANT	\N	PRESENT	0
523744	521370	20098N	PARTICIPANT	\N	PRESENT	0
523745	521370	19527W	PARTICIPANT	\N	PRESENT	0
523746	521370	20046A	PARTICIPANT	\N	PRESENT	0
523747	521370	19749K	PARTICIPANT	\N	PRESENT	0
526685	526653	10006L	PARTICIPANT	\N	EXCUSE	0
526796	526727	14147R	PARTICIPANT	\N	PRESENT	1
526797	526727	14179A	PARTICIPANT	\N	PRESENT	1
527674	526549	14109K	PARTICIPANT	\N	PRESENT	1
528607	525740	20094J	PARTICIPANT	\N	PRESENT	0
528608	525740	19531S	PARTICIPANT	\N	PRESENT	0
528609	525740	14001X	PARTICIPANT	\N	PRESENT	0
528610	525740	12041X	PARTICIPANT	\N	PRESENT	0
528611	525740	19711U	PARTICIPANT	\N	PRESENT	0
528612	525740	14073Q	PARTICIPANT	\N	PRESENT	0
528613	525740	19521Q	PARTICIPANT	\N	PRESENT	0
528614	525740	14221J	PARTICIPANT	\N	PRESENT	0
528615	525740	20100N	PARTICIPANT	\N	PRESENT	0
528616	525740	04035D	PARTICIPANT	\N	PRESENT	0
528617	525740	10015M	PARTICIPANT	\N	PRESENT	0
528618	525740	14026U	PARTICIPANT	\N	PRESENT	0
528619	525740	19441R	PARTICIPANT	\N	PRESENT	0
528620	525740	04057K	PARTICIPANT	\N	PRESENT	0
528621	525740	19701S	PARTICIPANT	\N	PRESENT	0
528631	525740	14331P	PRESIDENT	0	PRESENT	0
528659	525740	14033T	PARTICIPANT	\N	PRESENT	1
528660	525740	20098N	PARTICIPANT	\N	PRESENT	1
528661	525740	19553Y	PARTICIPANT	\N	PRESENT	1
528662	525740	14097Y	PARTICIPANT	\N	PRESENT	1
528663	525740	20128B	PARTICIPANT	\N	PRESENT	1
528664	525740	19725B	PARTICIPANT	\N	PRESENT	1
528665	525740	20104S	PARTICIPANT	\N	PRESENT	1
528666	525740	14207L	PARTICIPANT	\N	EXCUSE	0
528667	525740	08018U	PARTICIPANT	\N	EXCUSE	0
528680	519091	19717B	PRESIDENT	0	PRESENT	0
528681	519091	19631V	PARTICIPANT	\N	PRESENT	0
528682	519091	14053L	PARTICIPANT	\N	PRESENT	0
528683	519091	18083K	PARTICIPANT	\N	PRESENT	0
528684	519091	14259Y	PARTICIPANT	\N	PRESENT	0
528685	519091	19659J	PARTICIPANT	\N	PRESENT	0
528686	519091	19347U	PARTICIPANT	\N	PRESENT	0
528687	519091	19691J	PARTICIPANT	\N	PRESENT	0
528688	519091	20034V	PARTICIPANT	\N	PRESENT	0
528689	519091	19715Y	PARTICIPANT	\N	PRESENT	0
528690	519091	14059S	PARTICIPANT	\N	PRESENT	0
528691	519091	12016W	PARTICIPANT	\N	PRESENT	0
528692	519091	19657G	PARTICIPANT	\N	PRESENT	0
528693	519091	14147R	PARTICIPANT	\N	PRESENT	0
528694	519091	20146D	PARTICIPANT	\N	PRESENT	0
528695	519091	20148F	PARTICIPANT	\N	PRESENT	0
528707	528705	14071N	PARTICIPANT	\N	PRESENT	0
528747	526785	19671E	PARTICIPANT	\N	PRESENT	0
528748	526785	08015R	PARTICIPANT	\N	PRESENT	0
528749	526785	20092G	PARTICIPANT	\N	PRESENT	0
528750	526785	14031R	PARTICIPANT	\N	PRESENT	0
528751	526785	20126Y	PARTICIPANT	\N	PRESENT	0
528753	526785	20060X	PARTICIPANT	\N	PRESENT	0
528754	526785	19575F	PARTICIPANT	\N	PRESENT	0
528755	526785	14083S	PARTICIPANT	\N	PRESENT	0
528756	526785	19695N	PARTICIPANT	\N	PRESENT	0
528757	526785	14357A	PARTICIPANT	\N	PRESENT	0
528758	526785	16685X	PARTICIPANT	\N	PRESENT	0
528759	526785	14041T	PARTICIPANT	\N	PRESENT	0
528760	526785	19515S	PRESIDENT	0	PRESENT	0
528761	526785	19762G	PARTICIPANT	\N	PRESENT	0
528762	526785	14105F	PARTICIPANT	\N	PRESENT	0
528763	526785	20082E	PARTICIPANT	\N	PRESENT	0
530209	528964	14237S	PARTICIPANT	\N	PRESENT	0
530852	529013	19367Y	PARTICIPANT	\N	EXCUSE	0
530853	528961	19631V	PARTICIPANT	\N	EXCUSE	0
531100	527033	20032T	PARTICIPANT	\N	PRESENT	0
531101	527033	19651A	PARTICIPANT	\N	PRESENT	0
531102	527033	11040E	PARTICIPANT	\N	PRESENT	0
531103	527033	20042V	PARTICIPANT	\N	PRESENT	0
531104	527033	11056N	PARTICIPANT	\N	PRESENT	0
531105	527033	04071H	PARTICIPANT	\N	PRESENT	0
537688	534915	20076G	PARTICIPANT	\N	PRESENT	0
537689	534915	19387D	PARTICIPANT	\N	PRESENT	0
537690	534915	19820Y	PARTICIPANT	\N	PRESENT	0
537691	534915	19826F	PARTICIPANT	\N	PRESENT	0
537692	534915	14221J	PARTICIPANT	\N	PRESENT	0
537693	534915	20102Q	PARTICIPANT	\N	PRESENT	0
537694	534915	19599P	PARTICIPANT	\N	PRESENT	0
537695	534915	19637C	PARTICIPANT	\N	PRESENT	1
537696	534915	20096L	PARTICIPANT	\N	PRESENT	0
537697	534915	18083K	PARTICIPANT	\N	PRESENT	0
537698	534915	20100N	PARTICIPANT	\N	PRESENT	0
537699	534915	19551W	PARTICIPANT	\N	PRESENT	0
537700	534915	14237S	PARTICIPANT	\N	PRESENT	0
537701	534915	05012A	PARTICIPANT	\N	PRESENT	0
537702	534915	08060W	PARTICIPANT	\N	PRESENT	0
537703	534915	20106U	PARTICIPANT	\N	PRESENT	0
537704	534915	20118Y	PARTICIPANT	\N	PRESENT	0
537705	534915	19503N	PARTICIPANT	\N	PRESENT	0
537706	534915	20020P	PARTICIPANT	\N	PRESENT	0
537707	534915	19685L	PARTICIPANT	\N	PRESENT	0
537708	534915	17367Q	PARTICIPANT	\N	PRESENT	0
537709	534915	20024T	PARTICIPANT	\N	PRESENT	0
537710	534915	17637T	PARTICIPANT	\N	PRESENT	0
537711	534915	11065P	PARTICIPANT	\N	PRESENT	0
537712	534915	20120S	PARTICIPANT	\N	PRESENT	0
537713	534915	19525U	PARTICIPANT	\N	PRESENT	1
537714	534915	20032T	PARTICIPANT	\N	PRESENT	0
537715	534915	20038A	PARTICIPANT	\N	PRESENT	0
537716	534915	14031R	PRESIDENT	0	PRESENT	0
537717	534915	20140W	PARTICIPANT	\N	PRESENT	0
537718	534915	19251M	PARTICIPANT	\N	PRESENT	1
537719	534915	20046A	PARTICIPANT	\N	PRESENT	0
537720	534915	14169X	PARTICIPANT	\N	PRESENT	0
537721	534915	17229F	PARTICIPANT	\N	PRESENT	0
537722	534915	20068G	PARTICIPANT	\N	PRESENT	0
537723	534915	19739H	PARTICIPANT	\N	PRESENT	0
537724	534915	19619A	PARTICIPANT	\N	PRESENT	0
537725	534915	14219Q	PARTICIPANT	\N	EXCUSE	0
540565	537910	19697Q	PARTICIPANT	\N	PRESENT	1
540566	537910	11067R	PARTICIPANT	\N	PRESENT	0
540567	537910	20090E	PARTICIPANT	\N	PRESENT	0
540568	537910	19798U	PARTICIPANT	\N	PRESENT	0
540569	537910	19569H	PARTICIPANT	\N	PRESENT	0
540570	537910	11097X	PARTICIPANT	0	PRESENT	0
540571	537910	19415P	PARTICIPANT	\N	PRESENT	0
540572	537910	14223L	PARTICIPANT	\N	PRESENT	0
540573	537910	18193Q	PARTICIPANT	\N	PRESENT	0
540574	537910	17779H	PARTICIPANT	\N	PRESENT	0
540575	537910	11031D	PARTICIPANT	\N	PRESENT	0
540576	537910	19966S	PARTICIPANT	\N	PRESENT	1
540577	537910	19679N	PARTICIPANT	\N	PRESENT	0
540578	537910	14042U	PARTICIPANT	\N	PRESENT	0
540579	537910	14213J	PARTICIPANT	\N	PRESENT	0
540580	537910	19683J	PARTICIPANT	\N	PRESENT	0
540581	537910	10006L	PRESIDENT	0	PRESENT	0
540582	537910	20130U	PARTICIPANT	\N	PRESENT	0
540583	537910	19713W	PARTICIPANT	\N	PRESENT	0
540584	537910	19663E	PARTICIPANT	\N	PRESENT	0
540585	537910	19301E	PARTICIPANT	\N	PRESENT	1
540586	537910	17965H	PARTICIPANT	\N	PRESENT	0
540587	537910	19691J	PARTICIPANT	\N	PRESENT	0
540588	537910	19717B	PARTICIPANT	\N	PRESENT	1
540589	537910	20172F	PARTICIPANT	\N	PRESENT	1
540590	537910	19723Y	PARTICIPANT	\N	PRESENT	0
540591	537910	20066E	PARTICIPANT	\N	PRESENT	1
540592	537910	11103C	PARTICIPANT	\N	PRESENT	1
540593	537910	19657G	PARTICIPANT	\N	PRESENT	0
540594	537910	14071N	PARTICIPANT	\N	PRESENT	0
540595	537910	19760E	PARTICIPANT	\N	PRESENT	0
540600	539069	04086Q	PARTICIPANT	\N	PRESENT	0
540601	539069	11040E	PARTICIPANT	\N	PRESENT	0
540602	539069	07029T	PARTICIPANT	\N	PRESENT	0
540603	539069	14331P	PARTICIPANT	\N	PRESENT	0
540604	539069	11048N	PARTICIPANT	\N	PRESENT	0
540605	539069	19479G	PARTICIPANT	\N	PRESENT	0
540606	539069	08034U	PARTICIPANT	\N	PRESENT	0
540607	539069	19349W	PARTICIPANT	\N	PRESENT	0
540608	539069	19667J	PARTICIPANT	\N	PRESENT	0
540923	539069	19545Y	PARTICIPANT	\N	PRESENT	0
540924	539069	14173T	PARTICIPANT	\N	PRESENT	0
540925	539069	20116W	PARTICIPANT	\N	PRESENT	0
541258	537784	19383Y	PARTICIPANT	\N	PRESENT	0
541259	537784	19768N	PARTICIPANT	\N	PRESENT	0
541260	537784	20034V	PARTICIPANT	\N	PRESENT	0
541261	537784	20092G	PARTICIPANT	\N	PRESENT	0
541262	537784	19782L	PARTICIPANT	\N	PRESENT	0
541263	537784	19441R	PARTICIPANT	\N	PRESENT	0
541264	537784	19413M	PARTICIPANT	\N	PRESENT	0
541265	537784	11090Q	PRESIDENT	0	PRESENT	0
541266	537784	14033T	PARTICIPANT	\N	PRESENT	1
541267	537784	20054A	PARTICIPANT	\N	PRESENT	0
541268	537784	20104S	PARTICIPANT	\N	PRESENT	0
541269	537784	19631V	PARTICIPANT	\N	PRESENT	1
541270	537784	20174H	PARTICIPANT	\N	PRESENT	0
541271	537784	20060X	PARTICIPANT	\N	PRESENT	0
541272	537784	20062A	PARTICIPANT	\N	PRESENT	0
541273	537784	19705W	PARTICIPANT	\N	PRESENT	0
541274	537784	19369B	PARTICIPANT	\N	PRESENT	0
541275	537784	19563B	PARTICIPANT	\N	PRESENT	0
541276	537784	08028W	PARTICIPANT	\N	PRESENT	0
541277	537784	14257W	PARTICIPANT	\N	PRESENT	0
541278	537784	14329V	PARTICIPANT	\N	PRESENT	0
541279	537910	19563B	PARTICIPANT	\N	PRESENT	0
541280	539069	19647E	PARTICIPANT	\N	PRESENT	0
541281	539069	11074Q	PARTICIPANT	\N	PRESENT	0
541282	537784	11067R	PARTICIPANT	\N	PRESENT	0
541283	537784	19798U	PARTICIPANT	\N	PRESENT	0
541284	537784	19569H	PARTICIPANT	\N	PRESENT	0
541285	537784	11097X	PARTICIPANT	\N	PRESENT	0
541286	537784	18193Q	PARTICIPANT	\N	PRESENT	0
541287	537784	14223L	PARTICIPANT	\N	PRESENT	0
541288	537784	19679N	PARTICIPANT	\N	PRESENT	0
541289	537784	20130U	PARTICIPANT	\N	PRESENT	0
541290	537784	17965H	PARTICIPANT	\N	PRESENT	0
541291	537784	19691J	PARTICIPANT	\N	PRESENT	0
541292	537784	19723Y	PARTICIPANT	\N	PRESENT	0
541293	537784	14071N	PARTICIPANT	\N	PRESENT	0
541294	537784	20090E	PARTICIPANT	\N	PRESENT	0
541295	537784	19415P	PARTICIPANT	\N	PRESENT	0
541296	537784	17779H	PARTICIPANT	\N	PRESENT	0
541297	537784	11031D	PARTICIPANT	\N	PRESENT	0
541298	537784	14213J	PARTICIPANT	\N	PRESENT	0
541299	537784	19683J	PARTICIPANT	\N	PRESENT	0
541300	537784	19713W	PARTICIPANT	\N	PRESENT	0
541301	539069	11053K	PARTICIPANT	\N	PRESENT	0
541302	537784	14357A	PARTICIPANT	\N	PRESENT	1
541303	537784	14187A	PARTICIPANT	\N	PRESENT	1
541304	537784	14205J	PARTICIPANT	\N	PRESENT	1
541305	537784	20088L	PARTICIPANT	\N	PRESENT	1
541306	537784	04045F	PARTICIPANT	\N	PRESENT	1
541307	537784	20030R	PARTICIPANT	\N	PRESENT	1
541308	537784	19695N	PARTICIPANT	\N	PRESENT	1
541309	539069	14189C	PARTICIPANT	\N	PRESENT	0
541231	537910	19768N	PARTICIPANT	\N	PRESENT	0
541232	537910	19782L	PARTICIPANT	\N	PRESENT	0
541233	537910	19441R	PARTICIPANT	\N	PRESENT	0
541234	537910	20030R	PARTICIPANT	\N	PRESENT	1
541235	537910	20034V	PARTICIPANT	\N	PRESENT	0
541236	537910	14187A	PARTICIPANT	\N	PRESENT	1
541237	537910	19695N	PARTICIPANT	\N	PRESENT	1
541238	537910	01025N	PARTICIPANT	\N	PRESENT	0
541239	537910	20060X	PARTICIPANT	\N	PRESENT	0
541240	537910	20062A	PARTICIPANT	\N	PRESENT	0
541241	537910	14257W	PARTICIPANT	\N	PRESENT	0
541242	537910	20088L	PARTICIPANT	\N	PRESENT	1
541243	537910	20092G	PARTICIPANT	\N	PRESENT	0
541244	537910	14357A	PARTICIPANT	\N	PRESENT	1
541245	537910	19413M	PARTICIPANT	\N	PRESENT	0
541246	537910	20094J	PARTICIPANT	\N	PRESENT	1
541247	537910	04045F	PARTICIPANT	\N	PRESENT	1
541248	537910	20104S	PARTICIPANT	\N	PRESENT	0
541249	537910	19631V	PARTICIPANT	\N	PRESENT	1
541250	537910	19705W	PARTICIPANT	\N	PRESENT	0
541251	537910	19369B	PARTICIPANT	\N	PRESENT	0
541252	537910	08028W	PARTICIPANT	\N	PRESENT	0
541253	537910	14329V	PARTICIPANT	\N	PRESENT	0
541254	537910	19467C	PARTICIPANT	\N	PRESENT	0
541255	537910	14033T	PARTICIPANT	\N	PRESENT	1
541256	537910	20174H	PARTICIPANT	\N	PRESENT	0
541257	537910	14205J	PARTICIPANT	\N	PRESENT	1
519855	519229	14255U	PARTICIPANT	\N	PRESENT	0
519856	519229	20128B	PARTICIPANT	\N	PRESENT	1
519857	519229	08047A	PARTICIPANT	\N	PRESENT	0
519858	518949	14030Q	PARTICIPANT	\N	PRESENT	0
519859	519223	14069U	PARTICIPANT	\N	PRESENT	1
519860	519223	14107H	PARTICIPANT	\N	PRESENT	0
519861	519223	11026G	PARTICIPANT	\N	PRESENT	0
519862	518949	14193X	PARTICIPANT	\N	PRESENT	0
519863	518949	19533U	PARTICIPANT	\N	PRESENT	0
519864	518949	18193Q	PARTICIPANT	\N	PRESENT	0
519865	518949	11012A	PARTICIPANT	\N	PRESENT	0
519866	518949	19629C	PARTICIPANT	\N	PRESENT	0
519867	518949	20102Q	PARTICIPANT	\N	PRESENT	0
519868	519223	19729F	PARTICIPANT	\N	PRESENT	0
519869	518949	20106U	PARTICIPANT	\N	PRESENT	0
519870	518949	20024T	PARTICIPANT	\N	PRESENT	0
519871	518949	19693L	PARTICIPANT	\N	PRESENT	0
519872	518949	20096L	PARTICIPANT	\N	PRESENT	0
519873	518949	19701S	PARTICIPANT	\N	PRESENT	0
519874	518949	01043Q	PARTICIPANT	\N	PRESENT	0
519875	518949	14073Q	PARTICIPANT	\N	PRESENT	0
519876	518949	20094J	PARTICIPANT	\N	PRESENT	0
519877	518949	20132W	PARTICIPANT	\N	PRESENT	0
519878	518949	14147R	PARTICIPANT	\N	PRESENT	0
519879	518949	14038Y	PARTICIPANT	\N	PRESENT	0
519880	518949	14033T	PARTICIPANT	\N	PRESENT	0
519881	518949	19826F	PARTICIPANT	\N	PRESENT	0
519882	518949	19621T	PARTICIPANT	\N	PRESENT	0
519938	518950	19629C	PARTICIPANT	\N	PRESENT	0
519939	518950	19387D	PARTICIPANT	\N	PRESENT	0
519940	518950	19637C	PARTICIPANT	\N	PRESENT	0
519941	518950	19782L	PARTICIPANT	\N	PRESENT	0
519942	518950	19333N	PARTICIPANT	\N	PRESENT	0
519943	518950	14038Y	PARTICIPANT	\N	PRESENT	0
519944	518950	18083K	PARTICIPANT	\N	PRESENT	0
519945	518950	19599P	PARTICIPANT	\N	PRESENT	0
519946	518950	19447X	PARTICIPANT	\N	PRESENT	0
519947	518950	19820Y	PARTICIPANT	\N	PRESENT	0
519948	518950	20094J	PARTICIPANT	\N	PRESENT	0
519949	518950	19798U	PARTICIPANT	\N	PRESENT	0
519950	518950	20100N	PARTICIPANT	\N	PRESENT	0
519951	518950	19347U	PARTICIPANT	\N	PRESENT	0
519952	518950	14069U	PARTICIPANT	\N	PRESENT	0
519953	518950	08009T	PARTICIPANT	\N	PRESENT	0
519954	518950	14205J	PARTICIPANT	\N	PRESENT	0
519955	518950	20102Q	PARTICIPANT	\N	PRESENT	0
519956	518950	20046A	PARTICIPANT	\N	PRESENT	0
519957	518950	14257W	PARTICIPANT	\N	PRESENT	0
519958	518950	19747H	PARTICIPANT	\N	PRESENT	0
519959	518950	20032T	PARTICIPANT	\N	PRESENT	0
519960	518950	19565D	PARTICIPANT	\N	PRESENT	0
519961	518950	19251M	PARTICIPANT	\N	PRESENT	0
519962	518950	14193X	PARTICIPANT	\N	PRESENT	0
519963	518950	20076G	PARTICIPANT	\N	PRESENT	0
519964	518950	20044X	PARTICIPANT	\N	PRESENT	0
519965	518950	19383Y	PARTICIPANT	\N	PRESENT	0
519966	518950	20122U	PARTICIPANT	\N	PRESENT	0
519967	518950	14187A	PARTICIPANT	\N	PRESENT	0
519968	518950	20090E	PARTICIPANT	\N	PRESENT	0
519969	518950	04045F	PARTICIPANT	\N	PRESENT	0
519970	518950	19549D	PARTICIPANT	\N	PRESENT	0
519971	518950	14031R	PARTICIPANT	\N	PRESENT	0
519972	518950	11099A	PARTICIPANT	\N	PRESENT	0
519973	518950	20092G	PARTICIPANT	\N	PRESENT	0
519974	518950	14033T	PARTICIPANT	\N	PRESENT	0
519975	518950	11090Q	PARTICIPANT	\N	PRESENT	0
519976	518950	20062A	PARTICIPANT	\N	PRESENT	0
519977	518950	19693L	PARTICIPANT	\N	PRESENT	0
519978	518950	19551W	PARTICIPANT	\N	PRESENT	0
519979	518950	20140W	PARTICIPANT	\N	PRESENT	0
519980	518950	20124W	PARTICIPANT	\N	PRESENT	0
519981	518950	11065P	PARTICIPANT	\N	PRESENT	0
519982	518950	19762G	PARTICIPANT	\N	PRESENT	0
519983	518950	20054A	PARTICIPANT	\N	PRESENT	0
519984	518950	14219Q	PARTICIPANT	\N	PRESENT	0
519985	518950	19760E	PARTICIPANT	\N	PRESENT	0
519986	518950	19758L	PARTICIPANT	\N	PRESENT	0
519987	518950	20126Y	PARTICIPANT	\N	PRESENT	0
519988	518950	20058E	PARTICIPANT	\N	PRESENT	0
519989	518950	14213J	PARTICIPANT	\N	PRESENT	0
519990	518950	14083S	PARTICIPANT	\N	PRESENT	0
519936	518950	01043Q	PARTICIPANT	\N	PRESENT	0
519937	518950	19713W	PARTICIPANT	\N	PRESENT	0
519991	518950	07029T	PARTICIPANT	\N	PRESENT	0
521321	519128	01028R	PARTICIPANT	\N	PRESENT	0
522185	522147	20090E	PARTICIPANT	\N	PRESENT	0
522186	522147	19657G	PARTICIPANT	\N	PRESENT	1
523507	521432	19515S	PRESIDENT	0	PRESENT	0
523508	521432	19575F	PARTICIPANT	\N	PRESENT	0
523509	521432	14105F	PARTICIPANT	\N	PRESENT	0
523510	521432	14083S	PARTICIPANT	\N	PRESENT	0
523511	521432	19467C	PARTICIPANT	\N	PRESENT	0
523513	521432	19251M	PARTICIPANT	\N	PRESENT	0
523514	521432	08015R	PARTICIPANT	\N	PRESENT	0
523516	521432	19671E	PARTICIPANT	\N	PRESENT	0
523518	521432	20082E	PARTICIPANT	\N	PRESENT	0
523520	521432	20134Y	PARTICIPANT	\N	PRESENT	0
523521	521432	20092G	PARTICIPANT	\N	PRESENT	0
523666	521420	11099A	PARTICIPANT	\N	PRESENT	0
523695	521400	19725B	PARTICIPANT	\N	PRESENT	1
523696	521400	14231L	PARTICIPANT	\N	EXCUSE	0
523697	521400	14107H	PARTICIPANT	\N	PRESENT	1
523699	521400	14179A	PARTICIPANT	\N	PRESENT	1
524113	522571	20144B	PARTICIPANT	\N	PRESENT	0
524114	522571	14259Y	PRESIDENT	0	PRESENT	0
525539	521656	20020P	PARTICIPANT	\N	PRESENT	1
525742	521657	14221J	PARTICIPANT	\N	PRESENT	0
526404	526403	14179A	PARTICIPANT	\N	PRESENT	0
526419	524207	19735D	PARTICIPANT	\N	PRESENT	0
526422	524207	11067R	PARTICIPANT	\N	PRESENT	0
526424	524207	01048V	PARTICIPANT	\N	PRESENT	0
526425	524207	04043D	PARTICIPANT	\N	PRESENT	0
526426	524207	19503N	PARTICIPANT	\N	PRESENT	0
526429	524207	19569H	PARTICIPANT	\N	PRESENT	0
526431	524207	01058X	PARTICIPANT	\N	PRESENT	0
526432	524207	19533U	PARTICIPANT	\N	PRESENT	0
526433	524207	20072C	PARTICIPANT	\N	PRESENT	0
526441	524207	19693L	PARTICIPANT	\N	PRESENT	0
526442	524207	19563B	PARTICIPANT	\N	PRESENT	0
526444	524207	18003S	PARTICIPANT	\N	PRESENT	0
526786	522158	08073C	PARTICIPANT	\N	EXCUSE	0
526795	522158	19717B	PRESIDENT	0	PRESENT	0
526981	525917	14073Q	PARTICIPANT	\N	PRESENT	0
526982	525917	16685X	PARTICIPANT	\N	PRESENT	0
531209	531207	20094J	PARTICIPANT	\N	PRESENT	0
531210	531200	04070G	PARTICIPANT	\N	PRESENT	0
527003	527002	20024T	PARTICIPANT	\N	PRESENT	0
527004	527002	11027H	PARTICIPANT	\N	PRESENT	0
527006	527002	19565D	PARTICIPANT	\N	PRESENT	0
527007	527002	19301E	PARTICIPANT	\N	PRESENT	0
527008	527002	20046A	PARTICIPANT	\N	PRESENT	0
527009	527002	19585H	PARTICIPANT	\N	PRESENT	0
527010	527002	20034V	PARTICIPANT	\N	PRESENT	0
527102	526394	14357A	PARTICIPANT	\N	PRESENT	0
527131	526394	14205J	PARTICIPANT	\N	PRESENT	1
527135	526394	20104S	PARTICIPANT	\N	PRESENT	0
529471	527033	19399H	PARTICIPANT	\N	PRESENT	0
531208	531207	04070G	PARTICIPANT	\N	PRESENT	0
531211	531201	04070G	PARTICIPANT	\N	PRESENT	0
531212	531201	20094J	PARTICIPANT	\N	PRESENT	0
531247	531245	14033T	PARTICIPANT	\N	PRESENT	0
522527	521470	14105F	PARTICIPANT	\N	PRESENT	0
522528	521470	20064C	PARTICIPANT	\N	PRESENT	0
522529	521470	98018T	PARTICIPANT	\N	PRESENT	1
522530	521470	98022P	PARTICIPANT	\N	PRESENT	0
522531	521470	14267Y	PARTICIPANT	\N	PRESENT	0
522532	521470	11064N	PARTICIPANT	\N	PRESENT	0
522533	521470	11083R	PARTICIPANT	\N	PRESENT	0
522534	521470	14211G	PARTICIPANT	\N	PRESENT	0
522535	521470	14255U	PARTICIPANT	\N	PRESENT	1
522570	521481	98022P	PARTICIPANT	\N	PRESENT	0
522572	521481	20100N	PARTICIPANT	\N	PRESENT	0
522573	521481	19511N	PARTICIPANT	\N	PRESENT	0
522574	521481	19719D	PARTICIPANT	\N	PRESENT	0
522575	521481	20102Q	PARTICIPANT	\N	PRESENT	0
522576	521481	20046A	PARTICIPANT	\N	PRESENT	0
522577	521481	19593H	PARTICIPANT	\N	PRESENT	0
522578	521481	10006L	PARTICIPANT	\N	PRESENT	0
522579	521481	20074E	PARTICIPANT	\N	PRESENT	0
522580	521481	14123H	PARTICIPANT	\N	PRESENT	0
522581	521481	19333N	PARTICIPANT	\N	PRESENT	0
522582	521481	19367Y	PARTICIPANT	\N	PRESENT	0
522583	521481	20174H	PARTICIPANT	\N	PRESENT	0
522584	521481	19565D	PARTICIPANT	\N	PRESENT	0
522585	521481	14041T	PARTICIPANT	\N	PRESENT	0
522586	521481	20118Y	PARTICIPANT	\N	PRESENT	0
522591	521481	20092G	PARTICIPANT	\N	PRESENT	0
522593	521481	19503N	PARTICIPANT	\N	PRESENT	0
522595	521481	17229F	PARTICIPANT	\N	PRESENT	0
522597	521481	14109K	PARTICIPANT	\N	PRESENT	0
522599	521481	14073Q	PARTICIPANT	\N	PRESENT	0
522601	521481	14121F	PARTICIPANT	\N	PRESENT	0
522602	521481	20088L	PARTICIPANT	\N	PRESENT	0
522604	521481	19687N	PARTICIPANT	\N	PRESENT	0
522605	521481	20112S	PARTICIPANT	\N	PRESENT	0
522606	521481	14083S	PARTICIPANT	\N	PRESENT	0
522607	521481	19611R	PARTICIPANT	\N	PRESENT	0
522609	521481	14231L	PARTICIPANT	\N	PRESENT	0
522611	521481	19545Y	PARTICIPANT	\N	PRESENT	0
522612	521481	19563B	PARTICIPANT	\N	PRESENT	0
522616	521481	20082E	PARTICIPANT	\N	PRESENT	0
522617	521481	14331P	PARTICIPANT	\N	PRESENT	0
522618	521481	01048V	PARTICIPANT	\N	PRESENT	0
522619	521481	20062A	PARTICIPANT	\N	PRESENT	0
522620	521481	19798U	PARTICIPANT	\N	PRESENT	0
522621	521481	19826F	PARTICIPANT	\N	PRESENT	0
522622	521481	19383Y	PARTICIPANT	\N	PRESENT	0
522623	521481	97011G	PARTICIPANT	\N	PRESENT	0
522624	521481	19739H	PARTICIPANT	\N	PRESENT	0
522625	521481	19966S	PARTICIPANT	\N	PRESENT	0
522626	521481	14195A	PARTICIPANT	\N	PRESENT	0
522627	521481	08061X	PARTICIPANT	\N	PRESENT	0
522628	521481	08073C	PARTICIPANT	\N	PRESENT	0
522629	521481	11012A	PARTICIPANT	\N	PRESENT	0
522631	521481	19820Y	PARTICIPANT	\N	PRESENT	0
522632	521481	19760E	PARTICIPANT	\N	PRESENT	0
522633	521481	04085P	PARTICIPANT	\N	PRESENT	0
522634	521481	14229S	PARTICIPANT	\N	PRESENT	0
522635	521481	19549D	PARTICIPANT	\N	PRESENT	0
522636	521481	14111D	PARTICIPANT	\N	PRESENT	0
522637	521481	19758L	PARTICIPANT	\N	PRESENT	0
522638	521481	11066Q	PARTICIPANT	\N	PRESENT	0
522639	521481	08009T	PARTICIPANT	\N	PRESENT	0
522640	521481	14207L	PARTICIPANT	\N	PRESENT	0
522641	521481	20132W	PARTICIPANT	\N	PRESENT	0
522642	521481	11065P	PARTICIPANT	\N	PRESENT	0
522643	521481	19599P	PARTICIPANT	\N	PRESENT	0
522644	521481	14001X	PARTICIPANT	\N	PRESENT	0
522645	521481	04059M	PARTICIPANT	\N	PRESENT	0
522646	521481	19329S	PARTICIPANT	\N	PRESENT	0
522647	521481	19489J	PARTICIPANT	\N	PRESENT	0
522648	521481	19531S	PARTICIPANT	\N	PRESENT	0
522649	521481	19651A	PARTICIPANT	\N	PRESENT	0
522650	521481	11083R	PARTICIPANT	\N	PRESENT	0
522651	521481	14030Q	PARTICIPANT	\N	PRESENT	0
522652	521481	19569H	PARTICIPANT	\N	PRESENT	0
522653	521481	20052X	PARTICIPANT	\N	PRESENT	0
522654	521481	14151M	PARTICIPANT	\N	PRESENT	0
522655	521481	19717B	PARTICIPANT	\N	PRESENT	0
522656	521481	19387D	PARTICIPANT	\N	PRESENT	0
522657	521481	19349W	PARTICIPANT	\N	PRESENT	0
522658	521481	17965H	PARTICIPANT	\N	PRESENT	0
522660	521481	11031D	PARTICIPANT	\N	PRESENT	0
522661	521481	19347U	PARTICIPANT	\N	PRESENT	0
522662	521481	95063L	PARTICIPANT	\N	PRESENT	0
522663	521481	19697Q	PARTICIPANT	\N	PRESENT	0
522664	521481	19301E	PARTICIPANT	\N	PRESENT	0
522665	521481	14249W	PARTICIPANT	\N	PRESENT	0
522666	521481	20072C	PARTICIPANT	\N	PRESENT	0
522668	521481	19701S	PARTICIPANT	\N	PRESENT	0
522669	521481	20116W	PARTICIPANT	\N	PRESENT	0
522670	521481	14026U	PARTICIPANT	\N	PRESENT	0
522672	521481	14211G	PARTICIPANT	\N	PRESENT	0
522673	521481	19866P	PARTICIPANT	\N	PRESENT	0
522674	521481	14038Y	PARTICIPANT	\N	PRESENT	0
522675	521481	19467C	PARTICIPANT	\N	PRESENT	0
522676	521481	19399H	PARTICIPANT	\N	PRESENT	0
522677	521481	14251Q	PARTICIPANT	\N	PRESENT	0
522678	521481	19507S	PARTICIPANT	\N	PRESENT	0
522679	521481	14221J	PARTICIPANT	\N	PRESENT	0
522680	521481	19673G	PARTICIPANT	\N	PRESENT	0
522681	521481	20140W	PARTICIPANT	\N	PRESENT	0
522682	521481	14033T	PARTICIPANT	\N	PRESENT	0
522683	521481	20032T	PARTICIPANT	\N	PRESENT	0
522684	521481	14021P	PARTICIPANT	\N	PRESENT	0
522685	521481	20028X	PARTICIPANT	\N	PRESENT	0
522686	521481	19515S	PARTICIPANT	\N	PRESENT	0
522687	521481	04042C	PARTICIPANT	\N	PRESENT	0
522688	521481	11080N	PARTICIPANT	\N	PRESENT	0
522689	521481	01057W	PARTICIPANT	\N	PRESENT	0
522690	521481	19647E	PARTICIPANT	\N	PRESENT	0
522691	521481	20142Y	PARTICIPANT	\N	PRESENT	0
523222	523221	19515S	PARTICIPANT	\N	PRESENT	0
522693	521481	08012N	PARTICIPANT	\N	PRESENT	0
522694	521481	11067R	PARTICIPANT	\N	PRESENT	0
522695	521481	19693L	PARTICIPANT	\N	PRESENT	0
522696	521481	18083K	PARTICIPANT	\N	PRESENT	0
522697	521481	20080C	PARTICIPANT	\N	PRESENT	0
522698	521481	08069G	PARTICIPANT	\N	PRESENT	0
522699	521481	08017T	PARTICIPANT	\N	PRESENT	0
522700	521481	19575F	PARTICIPANT	\N	PRESENT	0
522701	521481	19725B	PARTICIPANT	\N	PRESENT	0
522702	521481	18193Q	PARTICIPANT	\N	PRESENT	0
522703	521481	11056N	PARTICIPANT	\N	PRESENT	0
522704	521481	04035D	PARTICIPANT	\N	PRESENT	0
522705	521481	14225N	PARTICIPANT	\N	PRESENT	0
523223	523221	19954N	PARTICIPANT	\N	PRESENT	0
523224	523221	19575F	PARTICIPANT	\N	PRESENT	0
523225	523221	14105F	PARTICIPANT	\N	PRESENT	0
523226	523221	17737W	PARTICIPANT	\N	PRESENT	0
523227	523221	20074E	PARTICIPANT	\N	PRESENT	0
523228	523221	20038A	PARTICIPANT	\N	PRESENT	0
523229	523221	20132W	PARTICIPANT	\N	PRESENT	0
523230	523221	19820Y	PARTICIPANT	\N	PRESENT	0
523231	523221	19565D	PARTICIPANT	\N	PRESENT	0
523232	523221	20128B	PARTICIPANT	\N	PRESENT	0
523233	523221	20126Y	PARTICIPANT	\N	PRESENT	0
523234	523221	19709B	PARTICIPANT	\N	PRESENT	0
523235	523221	04092N	PARTICIPANT	\N	PRESENT	0
523236	523221	20096L	PARTICIPANT	\N	PRESENT	0
523237	523221	19533U	PARTICIPANT	\N	PRESENT	0
523238	523221	19503N	PARTICIPANT	\N	PRESENT	0
523239	523221	20098N	PARTICIPANT	\N	PRESENT	0
523240	523221	04034C	PARTICIPANT	\N	PRESENT	0
523432	521471	12041X	PARTICIPANT	\N	PRESENT	0
523433	521471	19443T	PARTICIPANT	\N	PRESENT	1
523434	521471	04034C	PARTICIPANT	\N	PRESENT	0
523435	521471	01058X	PARTICIPANT	\N	PRESENT	0
523436	521471	11027H	PARTICIPANT	\N	PRESENT	0
523437	521471	16685X	PARTICIPANT	\N	PRESENT	0
523438	521471	04042C	PRESIDENT	0	PRESENT	0
523439	521471	11054L	PARTICIPANT	\N	PRESENT	0
523440	521471	11066Q	PARTICIPANT	\N	PRESENT	0
523441	521471	19421M	PARTICIPANT	\N	PRESENT	1
523442	521471	19709B	PARTICIPANT	\N	PRESENT	0
523443	521471	19347U	PARTICIPANT	\N	PRESENT	0
523444	521471	14193X	PARTICIPANT	\N	PRESENT	0
523445	521471	97011G	PARTICIPANT	\N	PRESENT	0
523446	521471	14249W	PARTICIPANT	\N	PRESENT	0
523447	521471	20128B	PARTICIPANT	\N	PRESENT	0
523448	521471	08047A	PARTICIPANT	\N	PRESENT	0
515128	512268	14213J	PARTICIPANT	\N	PRESENT	1
515129	512264	19703U	PARTICIPANT	\N	PRESENT	0
515130	512264	11031D	PARTICIPANT	\N	PRESENT	0
515131	512264	17779H	PARTICIPANT	\N	PRESENT	0
515132	512264	18193Q	PARTICIPANT	\N	PRESENT	0
515133	512264	19415P	PARTICIPANT	\N	PRESENT	0
515134	512264	19798U	PARTICIPANT	\N	PRESENT	0
515135	512264	20090E	PARTICIPANT	\N	PRESENT	0
515136	512264	11067R	PARTICIPANT	\N	PRESENT	0
515137	512264	19713W	PARTICIPANT	\N	PRESENT	0
515138	512264	04057K	PARTICIPANT	\N	PRESENT	0
515139	512264	19591F	PARTICIPANT	\N	PRESENT	0
515140	512264	19683J	PARTICIPANT	\N	PRESENT	0
515141	512264	19367Y	PARTICIPANT	\N	PRESENT	0
515142	512264	14042U	PARTICIPANT	\N	PRESENT	0
515143	512264	19679N	PARTICIPANT	\N	PRESENT	0
515144	512264	19966S	PARTICIPANT	\N	PRESENT	0
515145	512264	19697Q	PARTICIPANT	\N	PRESENT	0
515146	512264	14071N	PARTICIPANT	\N	PRESENT	0
515147	512264	20130U	PARTICIPANT	\N	PRESENT	0
515148	512264	20066E	PARTICIPANT	\N	PRESENT	0
515149	512264	20172F	PARTICIPANT	\N	PRESENT	0
515150	512264	20148F	PARTICIPANT	\N	PRESENT	0
515151	512264	17965H	PARTICIPANT	\N	PRESENT	0
515152	512264	19663E	PARTICIPANT	\N	PRESENT	0
515153	512264	11045K	PARTICIPANT	\N	PRESENT	0
515154	512264	19553Y	PARTICIPANT	\N	PRESENT	0
515155	512264	19295A	PARTICIPANT	\N	PRESENT	0
515156	512264	19691J	PARTICIPANT	\N	PRESENT	0
515157	512264	19301E	PARTICIPANT	\N	PRESENT	0
515158	512264	20040T	PARTICIPANT	\N	PRESENT	0
515159	512264	11097X	PARTICIPANT	\N	PRESENT	0
515160	512264	19569H	PARTICIPANT	\N	PRESENT	0
515161	512264	04092N	PARTICIPANT	\N	PRESENT	0
515162	512264	19723Y	PARTICIPANT	\N	PRESENT	0
515163	512264	08045X	PARTICIPANT	\N	PRESENT	0
515164	512264	19760E	PARTICIPANT	\N	PRESENT	0
515165	512264	04043D	PARTICIPANT	\N	PRESENT	0
515166	512264	14217N	PARTICIPANT	\N	PRESENT	0
515167	512264	19657G	PARTICIPANT	\N	PRESENT	0
515168	512264	14223L	PARTICIPANT	\N	PRESENT	0
515169	512264	11103C	PARTICIPANT	\N	PRESENT	0
515170	512264	14281W	PARTICIPANT	\N	PRESENT	0
515171	512264	10006L	PRESIDENT	\N	PRESENT	0
515172	512264	14213J	PARTICIPANT	\N	PRESENT	0
515997	515996	01048V	PARTICIPANT	\N	PRESENT	0
516888	516887	20024T	PARTICIPANT	\N	PRESENT	0
516889	516887	17737W	PARTICIPANT	\N	PRESENT	0
516890	516887	11026G	PARTICIPANT	\N	PRESENT	0
516891	516887	04070G	PARTICIPANT	\N	PRESENT	0
516892	516887	19745F	PARTICIPANT	\N	PRESENT	0
516894	516893	17737W	PARTICIPANT	\N	PRESENT	0
523523	523497	19663E	PARTICIPANT	\N	PRESENT	1
523524	523497	19697Q	PARTICIPANT	\N	PRESENT	1
523525	523497	11097X	PARTICIPANT	\N	PRESENT	1
523526	523497	04092N	PARTICIPANT	\N	PRESENT	0
523704	521539	11109J	PARTICIPANT	\N	PRESENT	0
523705	521539	19631V	PARTICIPANT	\N	PRESENT	0
523706	521539	19347U	PARTICIPANT	\N	PRESENT	0
523707	521539	14219Q	PARTICIPANT	\N	PRESENT	0
523708	521539	12016W	PARTICIPANT	\N	PRESENT	0
523709	521539	19657G	PARTICIPANT	\N	PRESENT	0
523710	521539	08073C	PARTICIPANT	\N	PRESENT	0
523711	521539	19319Q	PARTICIPANT	\N	PRESENT	0
523712	521539	11090Q	PARTICIPANT	\N	PRESENT	0
529085	529043	20108W	PARTICIPANT	\N	PRESENT	0
529086	529044	20108W	PARTICIPANT	\N	PRESENT	0
529087	529045	20108W	PARTICIPANT	\N	PRESENT	0
529089	529088	14089Y	PARTICIPANT	\N	PRESENT	0
529090	529088	20104S	PARTICIPANT	\N	PRESENT	0
529118	529117	19553Y	PARTICIPANT	\N	PRESENT	0
529123	529122	19711U	PARTICIPANT	\N	PRESENT	0
529124	529122	97011G	PARTICIPANT	\N	PRESENT	0
529125	529122	17367Q	PARTICIPANT	\N	PRESENT	1
529126	529122	20132W	PARTICIPANT	\N	PRESENT	1
529128	529127	19711U	PARTICIPANT	\N	PRESENT	0
529129	529127	04033B	PARTICIPANT	\N	PRESENT	1
529130	529127	14179A	PARTICIPANT	\N	PRESENT	1
529131	529127	19647E	PARTICIPANT	\N	PRESENT	1
529133	529132	19711U	PARTICIPANT	\N	PRESENT	0
529134	529132	04033B	PARTICIPANT	\N	PRESENT	0
529135	529132	14179A	PARTICIPANT	\N	PRESENT	1
529136	529132	19647E	PARTICIPANT	\N	PRESENT	1
529138	529137	19711U	PARTICIPANT	\N	PRESENT	0
529139	529137	04033B	PARTICIPANT	\N	PRESENT	1
529140	529137	14179A	PARTICIPANT	\N	PRESENT	1
529141	529137	19647E	PARTICIPANT	\N	PRESENT	1
529143	529142	19711U	PARTICIPANT	\N	PRESENT	0
529144	529142	04033B	PARTICIPANT	\N	PRESENT	1
529145	529142	14179A	PARTICIPANT	\N	PRESENT	1
529146	529142	19647E	PARTICIPANT	\N	PRESENT	1
529148	529147	19711U	PARTICIPANT	\N	PRESENT	0
529150	529149	19711U	PARTICIPANT	\N	PRESENT	0
529152	529151	19711U	PARTICIPANT	\N	PRESENT	0
529154	529153	19711U	PARTICIPANT	\N	PRESENT	0
531106	527033	20132W	PARTICIPANT	\N	PRESENT	0
531107	527033	19551W	PARTICIPANT	\N	PRESENT	0
531108	527033	99004R	PARTICIPANT	\N	PRESENT	0
531109	527033	19711U	PARTICIPANT	\N	PRESENT	0
531110	527033	95063L	PARTICIPANT	\N	PRESENT	0
531111	527033	19703U	PARTICIPANT	\N	PRESENT	0
531112	527033	19479G	PARTICIPANT	\N	PRESENT	0
531113	527033	20018V	PARTICIPANT	\N	PRESENT	0
531114	527033	19553Y	PARTICIPANT	\N	EXCUSE	0
531124	524291	20024T	PARTICIPANT	\N	PRESENT	0
531125	524291	14030Q	PRESIDENT	0	PRESENT	0
531126	524291	20080C	PARTICIPANT	\N	PRESENT	0
531127	524291	11031D	PARTICIPANT	\N	PRESENT	0
531128	524291	19681G	PARTICIPANT	\N	PRESENT	0
531129	524291	19693L	PARTICIPANT	\N	PRESENT	0
531130	524291	19599P	PARTICIPANT	\N	EXCUSE	0
531131	524291	20106U	PARTICIPANT	\N	PRESENT	0
531132	524291	14179A	PARTICIPANT	\N	PRESENT	0
531133	524291	20066E	PARTICIPANT	\N	PRESENT	0
531134	524291	20056C	PARTICIPANT	\N	PRESENT	0
531135	524291	14221J	PARTICIPANT	\N	PRESENT	0
531136	524291	14109K	PARTICIPANT	\N	PRESENT	0
531137	524291	19768N	PARTICIPANT	\N	PRESENT	0
531138	524291	19866P	PARTICIPANT	\N	PRESENT	0
531139	524291	20118Y	PARTICIPANT	\N	EXCUSE	0
531141	524291	20130U	PARTICIPANT	\N	PRESENT	0
531142	524291	19798U	PARTICIPANT	\N	PRESENT	0
531143	524291	20098N	PARTICIPANT	\N	PRESENT	0
531144	524291	20046A	PARTICIPANT	\N	PRESENT	0
531145	524291	19749K	PARTICIPANT	\N	PRESENT	0
531315	531314	14069U	PARTICIPANT	\N	PRESENT	0
531316	531314	11072N	PARTICIPANT	\N	PRESENT	1
531324	531323	14089Y	PARTICIPANT	\N	PRESENT	0
531325	531323	11026G	PARTICIPANT	\N	PRESENT	0
531327	531326	14089Y	PARTICIPANT	\N	PRESENT	0
531328	531326	11026G	PARTICIPANT	\N	PRESENT	0
531359	531358	14221J	PARTICIPANT	\N	PRESENT	0
531361	531360	11026G	PARTICIPANT	\N	PRESENT	0
531362	531360	14089Y	PARTICIPANT	\N	PRESENT	0
531679	531146	11110B	PARTICIPANT	\N	PRESENT	1
531680	531146	14121F	PARTICIPANT	\N	PRESENT	1
531681	531146	20126Y	PARTICIPANT	\N	PRESENT	1
531682	531146	07029T	PARTICIPANT	\N	EXCUSE	0
531683	531146	12016W	PARTICIPANT	\N	PRESENT	1
531684	531146	20050V	PARTICIPANT	\N	PRESENT	1
531686	531146	14331P	PARTICIPANT	\N	PRESENT	1
531809	531146	14327T	PARTICIPANT	\N	PRESENT	0
531810	531146	08009T	PARTICIPANT	\N	PRESENT	0
531811	531146	08011M	PARTICIPANT	\N	EXCUSE	0
532014	532011	11067R	PARTICIPANT	\N	PRESENT	0
532015	532011	19553Y	PARTICIPANT	\N	PRESENT	0
532016	532011	19723Y	PARTICIPANT	\N	PRESENT	0
532017	532011	19691J	PARTICIPANT	\N	PRESENT	0
532018	532011	20066E	PARTICIPANT	\N	PRESENT	0
532020	532012	11031D	PARTICIPANT	\N	PRESENT	0
532021	532012	20172F	PARTICIPANT	\N	PRESENT	0
532022	532012	19691J	PARTICIPANT	\N	PRESENT	0
532023	532012	19553Y	PARTICIPANT	\N	PRESENT	0
532024	532012	19723Y	PARTICIPANT	\N	PRESENT	0
532025	532012	11067R	PARTICIPANT	\N	PRESENT	0
532093	531286	19531S	PARTICIPANT	\N	PRESENT	1
532551	530832	19611R	PRESIDENT	0	PRESENT	0
532552	530832	19735D	PARTICIPANT	\N	PRESENT	1
532553	530832	20124W	PARTICIPANT	\N	PRESENT	1
532554	530832	19693L	PARTICIPANT	\N	PRESENT	1
537726	536607	01048V	PARTICIPANT	\N	PRESENT	0
537727	536607	19545Y	PARTICIPANT	\N	PRESENT	0
537728	536607	08034U	PARTICIPANT	\N	PRESENT	0
537734	536613	14111D	PARTICIPANT	\N	PRESENT	0
537735	536613	19585H	PARTICIPANT	\N	PRESENT	0
537736	536613	19673G	PARTICIPANT	\N	PRESENT	0
537737	536613	11056N	PARTICIPANT	\N	PRESENT	0
537738	536613	19489J	PARTICIPANT	\N	PRESENT	0
537739	536613	95063L	PARTICIPANT	\N	PRESENT	0
537740	536613	14107H	PARTICIPANT	\N	PRESENT	0
537741	536613	14215L	PARTICIPANT	\N	PRESENT	0
537742	536613	14259Y	PARTICIPANT	\N	PRESENT	0
537743	536613	19749K	PARTICIPANT	\N	PRESENT	0
537744	536613	11072N	PARTICIPANT	\N	PRESENT	0
537746	534915	19745F	PARTICIPANT	\N	PRESENT	1
537795	536275	20090E	PARTICIPANT	\N	PRESENT	0
537796	536275	19798U	PARTICIPANT	\N	PRESENT	0
537797	536275	11097X	PARTICIPANT	\N	PRESENT	0
537798	536275	19415P	PARTICIPANT	\N	PRESENT	0
537799	536275	14223L	PARTICIPANT	\N	PRESENT	0
537800	536275	18193Q	PARTICIPANT	\N	PRESENT	0
537801	536275	17779H	PARTICIPANT	\N	PRESENT	0
537802	536275	11031D	PARTICIPANT	\N	PRESENT	0
537803	536275	19703U	PARTICIPANT	\N	PRESENT	0
537804	536275	19679N	PARTICIPANT	\N	PRESENT	0
537805	536275	14042U	PARTICIPANT	\N	PRESENT	0
537806	536275	19367Y	PARTICIPANT	\N	PRESENT	0
537807	536275	14213J	PARTICIPANT	\N	PRESENT	0
537808	536275	14217N	PARTICIPANT	\N	PRESENT	0
537809	536275	10006L	PRESIDENT	0	PRESENT	0
537810	536275	20130U	PARTICIPANT	\N	PRESENT	0
537811	536275	01034P	PARTICIPANT	\N	PRESENT	0
537812	536275	19713W	PARTICIPANT	\N	PRESENT	0
537813	536275	20040T	PARTICIPANT	\N	PRESENT	0
537814	536275	19691J	PARTICIPANT	\N	PRESENT	0
537815	536275	19723Y	PARTICIPANT	\N	PRESENT	0
537816	536275	19760E	PARTICIPANT	\N	PRESENT	0
537817	536613	05008E	PARTICIPANT	\N	PRESENT	0
537818	536613	14147R	PARTICIPANT	\N	PRESENT	0
537819	536613	14231L	PARTICIPANT	\N	EXCUSE	0
537825	536614	20074E	PARTICIPANT	\N	PRESENT	0
537826	536614	04047H	PRESIDENT	0	PRESENT	0
537827	536614	19673G	PARTICIPANT	\N	PRESENT	0
537828	536614	01028R	PARTICIPANT	\N	PRESENT	0
537829	536614	05008E	PARTICIPANT	\N	PRESENT	0
537830	536614	14231L	PARTICIPANT	\N	PRESENT	0
537831	536614	19954N	PARTICIPANT	\N	PRESENT	0
537832	536614	17737W	PARTICIPANT	\N	PRESENT	0
537833	536614	19489J	PARTICIPANT	\N	PRESENT	0
537834	536614	95063L	PARTICIPANT	\N	PRESENT	0
537835	536614	14147R	PARTICIPANT	\N	PRESENT	0
537836	536614	20114U	PARTICIPANT	\N	PRESENT	0
537837	536614	14215L	PRESIDENT	1	PRESENT	0
537838	536614	19749K	PARTICIPANT	\N	PRESENT	0
537839	536614	11072N	PARTICIPANT	\N	PRESENT	0
537840	536614	20108W	PARTICIPANT	\N	PRESENT	0
537922	536837	19721W	PARTICIPANT	\N	PRESENT	1
537923	536829	12041X	PARTICIPANT	\N	PRESENT	0
537924	536829	98022P	PARTICIPANT	\N	PRESENT	0
537925	536829	19866P	PARTICIPANT	\N	PRESENT	0
537926	536829	17229F	PARTICIPANT	\N	PRESENT	0
537927	536829	14151M	PARTICIPANT	\N	PRESENT	0
537928	536829	11054L	PARTICIPANT	\N	PRESENT	0
537929	536829	19349W	PARTICIPANT	\N	PRESENT	0
537930	536829	20042V	PARTICIPANT	\N	PRESENT	0
537931	536829	20072C	PARTICIPANT	\N	PRESENT	0
537932	536829	20082E	PARTICIPANT	\N	PRESENT	0
537933	536829	11085T	PARTICIPANT	\N	PRESENT	0
537934	536829	20144B	PARTICIPANT	\N	PRESENT	0
537935	536829	19826F	PARTICIPANT	\N	PRESENT	0
537936	536829	14267Y	PARTICIPANT	\N	PRESENT	0
537937	536829	08045X	PARTICIPANT	\N	PRESENT	0
537938	536829	12028B	PARTICIPANT	\N	PRESENT	0
537939	536829	19549D	PARTICIPANT	\N	PRESENT	0
537940	536829	19591F	PARTICIPANT	\N	PRESENT	0
537941	536829	04059M	PARTICIPANT	\N	PRESENT	0
537942	536829	11066Q	PARTICIPANT	\N	PRESENT	0
537943	536829	17965H	PARTICIPANT	\N	PRESENT	0
537944	536829	19758L	PARTICIPANT	\N	PRESENT	0
537945	536829	14211G	PARTICIPANT	\N	PRESENT	0
537946	536829	11031D	PARTICIPANT	\N	PRESENT	0
537947	536829	19565D	PARTICIPANT	\N	PRESENT	0
537948	536829	19711U	PARTICIPANT	\N	PRESENT	0
537949	536829	20046A	PARTICIPANT	\N	PRESENT	0
537950	536829	11040E	PARTICIPANT	\N	PRESENT	0
537951	536829	19593H	PARTICIPANT	\N	PRESENT	0
537952	536829	01058X	PARTICIPANT	\N	PRESENT	0
537953	536829	19575F	PARTICIPANT	\N	PRESENT	0
537954	536829	19760E	PARTICIPANT	\N	PRESENT	0
537955	536829	11077T	PARTICIPANT	\N	PRESENT	0
537956	536829	99004R	PARTICIPANT	\N	PRESENT	0
537957	536829	19695N	PARTICIPANT	\N	PRESENT	0
537958	536829	04047H	PARTICIPANT	\N	PRESENT	0
537959	536829	20134Y	PARTICIPANT	\N	PRESENT	0
537960	536829	20142Y	PARTICIPANT	\N	PRESENT	0
537961	536829	20100N	PARTICIPANT	\N	PRESENT	0
537962	536829	19689Q	PARTICIPANT	\N	PRESENT	0
537963	536829	11033F	PARTICIPANT	\N	PRESENT	0
537964	536829	19347U	PARTICIPANT	\N	PRESENT	0
537965	536829	19782L	PARTICIPANT	\N	PRESENT	0
537966	536829	20174H	PARTICIPANT	\N	PRESENT	0
537967	536829	11083R	PARTICIPANT	\N	PRESENT	0
537968	536829	11072N	PARTICIPANT	\N	PRESENT	0
537969	536829	04034C	PARTICIPANT	\N	PRESENT	0
537970	536829	19651A	PARTICIPANT	\N	PRESENT	0
537971	536829	20106U	PARTICIPANT	\N	PRESENT	0
537972	536829	95063L	PARTICIPANT	\N	PRESENT	0
537973	536829	14133K	PARTICIPANT	\N	PRESENT	0
537974	536829	08061X	PARTICIPANT	\N	PRESENT	0
537975	536829	14026U	PARTICIPANT	\N	PRESENT	0
537976	536829	20128B	PARTICIPANT	\N	PRESENT	0
537977	536829	05012A	PARTICIPANT	\N	PRESENT	0
537978	536829	11101A	PARTICIPANT	\N	PRESENT	0
537979	536829	20130U	PARTICIPANT	\N	PRESENT	0
537980	536829	19629C	PARTICIPANT	\N	PRESENT	0
537981	536829	19717B	PARTICIPANT	\N	PRESENT	0
537982	536829	19719D	PARTICIPANT	\N	PRESENT	0
537983	536829	19747H	PARTICIPANT	\N	PRESENT	0
537984	536829	14107H	PARTICIPANT	\N	PRESENT	0
537985	536829	19387D	PARTICIPANT	\N	PRESENT	0
537986	536829	11012A	PARTICIPANT	\N	PRESENT	0
537987	536829	04042C	PARTICIPANT	\N	PRESENT	0
537988	536829	08069G	PARTICIPANT	\N	PRESENT	0
537989	536829	14207L	PARTICIPANT	\N	PRESENT	0
537990	536829	20074E	PARTICIPANT	\N	PRESENT	0
537991	536829	19643A	PARTICIPANT	\N	PRESENT	0
537992	536829	10015M	PARTICIPANT	\N	PRESENT	0
537993	536829	14221J	PARTICIPANT	\N	PRESENT	0
537994	536829	17589D	PARTICIPANT	\N	PRESENT	0
537995	536829	20032T	PARTICIPANT	\N	PRESENT	0
537996	536829	20116W	PARTICIPANT	\N	PRESENT	0
537997	536829	19687N	PARTICIPANT	\N	PRESENT	0
537998	536829	14223L	PARTICIPANT	\N	PRESENT	0
537999	536829	14251Q	PARTICIPANT	\N	PRESENT	0
538000	536829	14071N	PARTICIPANT	\N	PRESENT	0
538001	536829	19415P	PARTICIPANT	\N	PRESENT	0
538002	536829	04057K	PARTICIPANT	\N	PRESENT	0
538003	536829	14195A	PARTICIPANT	\N	PRESENT	0
538004	536829	19545Y	PARTICIPANT	\N	PRESENT	0
538005	536829	14053L	PARTICIPANT	\N	PRESENT	0
538006	536829	14187A	PARTICIPANT	\N	PRESENT	0
538007	536829	14259Y	PARTICIPANT	\N	PRESENT	0
538008	536829	19563B	PARTICIPANT	\N	PRESENT	0
538009	536829	20022R	PARTICIPANT	\N	PRESENT	0
538010	536829	11045K	PARTICIPANT	\N	PRESENT	0
538011	536829	01057W	PARTICIPANT	\N	PRESENT	0
538012	536829	20094J	PARTICIPANT	\N	PRESENT	0
538013	536829	19443T	PARTICIPANT	\N	PRESENT	0
538014	536829	14257W	PARTICIPANT	\N	PRESENT	0
538015	536829	11080N	PARTICIPANT	\N	PRESENT	0
538016	536829	20084G	PARTICIPANT	\N	PRESENT	0
538017	536829	19515S	PARTICIPANT	\N	PRESENT	0
538018	536829	08012N	PARTICIPANT	\N	PRESENT	0
538019	536829	14069U	PARTICIPANT	\N	PRESENT	0
538020	536829	20038A	PARTICIPANT	\N	PRESENT	0
538021	536829	11067R	PARTICIPANT	\N	PRESENT	0
538022	536829	19820Y	PARTICIPANT	\N	PRESENT	0
538023	536829	20026V	PARTICIPANT	\N	PRESENT	0
538024	536829	20070A	PARTICIPANT	\N	PRESENT	0
538025	536829	20180F	PARTICIPANT	\N	PRESENT	0
538026	536829	19649G	PARTICIPANT	\N	PRESENT	0
516062	492691	20024T	PARTICIPANT	\N	EXCUSE	0
516063	492691	14030Q	PRESIDENT	0	PRESENT	0
516064	492691	20138D	PARTICIPANT	\N	PRESENT	0
516065	492691	17737W	PARTICIPANT	\N	PRESENT	0
516066	492691	20080C	PARTICIPANT	\N	PRESENT	0
516067	492691	19621T	PARTICIPANT	\N	PRESENT	0
516068	492691	11031D	PARTICIPANT	\N	PRESENT	0
516069	492691	19693L	PARTICIPANT	\N	PRESENT	0
516070	492691	19599P	PARTICIPANT	\N	PRESENT	0
516071	492691	20106U	PARTICIPANT	\N	PRESENT	0
516072	492691	20034V	PARTICIPANT	\N	EXCUSE	0
516073	492691	19715Y	PARTICIPANT	\N	EXCUSE	0
516075	492691	07029T	PARTICIPANT	\N	PRESENT	0
516076	492691	08017T	PARTICIPANT	\N	PRESENT	0
516077	492691	14109K	PARTICIPANT	\N	PRESENT	0
516078	492691	19768N	PARTICIPANT	\N	PRESENT	0
516079	492691	20118Y	PARTICIPANT	\N	PRESENT	0
516080	492691	20130U	PARTICIPANT	\N	PRESENT	0
516081	492691	19798U	PARTICIPANT	\N	PRESENT	0
516082	492691	19527W	PARTICIPANT	\N	PRESENT	0
516083	492691	20046A	PARTICIPANT	\N	PRESENT	0
516084	492691	19749K	PARTICIPANT	\N	PRESENT	0
517644	517643	14069U	PARTICIPANT	\N	PRESENT	0
517645	517643	19643A	PARTICIPANT	\N	PRESENT	0
517646	517643	19693L	PARTICIPANT	\N	PRESENT	0
517647	517643	17229F	PARTICIPANT	\N	PRESENT	0
517648	517643	14041T	PARTICIPANT	\N	PRESENT	0
517649	517643	11083R	PARTICIPANT	\N	PRESENT	0
517650	517643	20120S	PARTICIPANT	\N	PRESENT	0
517651	517643	20056C	PARTICIPANT	\N	PRESENT	0
517652	517643	08010L	PARTICIPANT	\N	PRESENT	0
517653	517643	20052X	PARTICIPANT	\N	PRESENT	0
517654	517643	04057K	PARTICIPANT	\N	PRESENT	0
517655	517643	20054A	PARTICIPANT	\N	PRESENT	0
520347	520346	20024T	PARTICIPANT	\N	PRESENT	0
520348	520346	20042V	PARTICIPANT	\N	PRESENT	0
520349	520346	20114U	PARTICIPANT	\N	PRESENT	0
520350	520346	20090E	PARTICIPANT	\N	PRESENT	0
520351	520346	14255U	PARTICIPANT	\N	PRESENT	0
520352	520346	14053L	PARTICIPANT	\N	PRESENT	0
520353	520346	12028B	PARTICIPANT	\N	PRESENT	0
520354	520346	19721W	PARTICIPANT	\N	PRESENT	0
520355	520346	18083K	PARTICIPANT	\N	PRESENT	0
520356	520346	14267Y	PARTICIPANT	\N	PRESENT	0
520357	520346	20070A	PARTICIPANT	\N	PRESENT	0
520358	520346	11064N	PARTICIPANT	\N	PRESENT	0
520359	520346	19329S	PARTICIPANT	\N	PRESENT	0
520360	520346	19531S	PARTICIPANT	\N	PRESENT	0
520361	520346	11099A	PARTICIPANT	\N	PRESENT	0
520362	520346	18193Q	PARTICIPANT	\N	PRESENT	0
520363	520346	11026G	PARTICIPANT	\N	PRESENT	0
520364	520346	20084G	PARTICIPANT	\N	PRESENT	0
520365	520346	19687N	PARTICIPANT	\N	PRESENT	0
520366	520346	10015M	PARTICIPANT	\N	PRESENT	0
520367	520346	20148F	PARTICIPANT	\N	PRESENT	0
520368	519287	19667J	PARTICIPANT	\N	PRESENT	1
520369	519287	19545Y	PARTICIPANT	\N	PRESENT	1
520370	519287	11074Q	PARTICIPANT	\N	PRESENT	1
520371	519287	11110B	PARTICIPANT	\N	PRESENT	1
520372	519287	19647E	PARTICIPANT	\N	PRESENT	1
520373	519287	14121F	PARTICIPANT	\N	PRESENT	1
520374	519287	20126Y	PARTICIPANT	\N	PRESENT	1
520375	519287	19711U	PARTICIPANT	\N	PRESENT	1
520376	519287	08010L	PARTICIPANT	\N	PRESENT	1
520377	519287	12016W	PARTICIPANT	\N	PRESENT	1
520378	519287	20050V	PARTICIPANT	\N	PRESENT	1
520379	519287	14331P	PARTICIPANT	\N	PRESENT	1
520380	519287	11012A	PARTICIPANT	\N	PRESENT	1
520381	519287	19479G	PARTICIPANT	\N	PRESENT	1
520395	519067	11109J	PARTICIPANT	\N	PRESENT	1
520396	519067	20112S	PARTICIPANT	\N	PRESENT	0
520397	519067	04059M	PARTICIPANT	\N	PRESENT	0
520398	519067	19651A	PARTICIPANT	\N	PRESENT	1
520399	519067	14030Q	PARTICIPANT	\N	PRESENT	0
520400	519067	19621T	PARTICIPANT	\N	PRESENT	0
520401	519067	19758L	PARTICIPANT	\N	PRESENT	0
520402	519067	19693L	PARTICIPANT	\N	PRESENT	0
520403	519067	20134Y	PARTICIPANT	\N	PRESENT	0
520404	519067	20132W	PARTICIPANT	\N	PRESENT	0
520405	519067	20180F	PARTICIPANT	\N	PRESENT	0
520406	519067	20048C	PARTICIPANT	\N	PRESENT	1
520407	519067	19399H	PARTICIPANT	\N	PRESENT	0
520408	519067	20056C	PARTICIPANT	\N	PRESENT	0
520409	519067	14073Q	PARTICIPANT	\N	PRESENT	0
520410	519067	19611R	PRESIDENT	0	PRESENT	0
520411	519067	19735D	PARTICIPANT	\N	EXCUSE	0
520412	519067	19699S	PARTICIPANT	\N	PRESENT	0
520413	519067	08017T	PARTICIPANT	\N	PRESENT	1
520414	519067	20052X	PARTICIPANT	\N	PRESENT	0
520415	519067	11104D	PARTICIPANT	\N	PRESENT	0
520416	519067	20142Y	PARTICIPANT	\N	PRESENT	0
520417	519067	04070G	PARTICIPANT	\N	PRESENT	1
520418	519067	19573D	PARTICIPANT	\N	PRESENT	0
520419	519067	11043H	PARTICIPANT	\N	PRESENT	0
520420	519067	20084G	PARTICIPANT	\N	PRESENT	0
520421	519067	20026V	PARTICIPANT	\N	PRESENT	0
520422	519067	20098N	PARTICIPANT	\N	PRESENT	1
520423	519067	20138D	PARTICIPANT	\N	PRESENT	1
521424	521423	04047H	PARTICIPANT	\N	PRESENT	0
521425	521423	04042C	PARTICIPANT	\N	PRESENT	0
521426	521423	14053L	PARTICIPANT	\N	PRESENT	0
521427	521423	14299H	PARTICIPANT	\N	PRESENT	0
521429	521423	11066Q	PARTICIPANT	\N	PRESENT	0
524032	523498	19663E	PARTICIPANT	\N	PRESENT	1
524033	523498	04092N	PARTICIPANT	\N	PRESENT	0
524034	523498	19697Q	PARTICIPANT	\N	PRESENT	1
524035	523498	11097X	PARTICIPANT	\N	PRESENT	1
524037	524036	04092N	PARTICIPANT	\N	PRESENT	0
524038	524036	19697Q	PARTICIPANT	\N	PRESENT	1
524039	524036	19663E	PARTICIPANT	\N	PRESENT	1
524040	524036	11097X	PARTICIPANT	\N	PRESENT	1
524043	524042	10006L	PARTICIPANT	\N	PRESENT	1
524044	524042	19663E	PARTICIPANT	\N	PRESENT	1
524045	524042	11097X	PARTICIPANT	\N	PRESENT	1
524046	524042	20130U	PARTICIPANT	\N	PRESENT	1
524442	524073	20080C	PARTICIPANT	\N	PRESENT	1
524443	524073	11074Q	PARTICIPANT	\N	PRESENT	1
524444	524073	11110B	PARTICIPANT	\N	PRESENT	1
524445	524073	19531S	PARTICIPANT	\N	PRESENT	1
524446	524073	20126Y	PARTICIPANT	\N	PRESENT	1
524447	524073	08010L	PARTICIPANT	\N	PRESENT	1
524448	524073	20150Y	PARTICIPANT	\N	PRESENT	1
524449	524073	19762G	PARTICIPANT	\N	PRESENT	1
524506	524505	14030Q	PARTICIPANT	\N	PRESENT	0
524507	524505	19599P	PARTICIPANT	\N	PRESENT	0
524508	524505	20040T	PARTICIPANT	\N	PRESENT	0
524509	524505	14179A	PARTICIPANT	\N	PRESENT	0
524510	524505	11054L	PARTICIPANT	\N	PRESENT	0
524543	524245	19657G	PARTICIPANT	\N	PRESENT	1
524544	524245	17965H	PARTICIPANT	\N	PRESENT	1
524545	524245	04045F	PARTICIPANT	\N	PRESENT	1
524586	524585	14071N	PARTICIPANT	\N	PRESENT	0
524588	524587	14071N	PARTICIPANT	\N	PRESENT	0
524589	524587	20130U	PARTICIPANT	\N	PRESENT	0
524590	524587	11067R	PARTICIPANT	\N	PRESENT	0
524592	524591	14042U	PARTICIPANT	\N	PRESENT	1
524593	524591	20130U	PARTICIPANT	\N	PRESENT	1
524594	524591	19723Y	PARTICIPANT	\N	PRESENT	1
524595	524591	11067R	PARTICIPANT	\N	PRESENT	1
524596	524591	04092N	PARTICIPANT	\N	PRESENT	0
524607	524606	04092N	PARTICIPANT	\N	PRESENT	0
524608	524606	19663E	PARTICIPANT	\N	PRESENT	1
524609	524606	20130U	PARTICIPANT	\N	PRESENT	1
526249	523130	14133K	PARTICIPANT	\N	PRESENT	1
526250	523130	19251M	PARTICIPANT	\N	PRESENT	1
526251	523130	19701S	PARTICIPANT	\N	PRESENT	1
526252	523130	20128B	PARTICIPANT	\N	PRESENT	1
526253	523130	20104S	PARTICIPANT	\N	PRESENT	1
526254	523130	04034C	PARTICIPANT	\N	PRESENT	1
526255	523130	04057K	PARTICIPANT	\N	PRESENT	0
526256	523130	14001X	PARTICIPANT	\N	PRESENT	0
526257	523130	14331P	PRESIDENT	0	PRESENT	0
526258	523130	14169X	PARTICIPANT	\N	PRESENT	1
526259	523130	14097Y	PARTICIPANT	\N	PRESENT	0
526260	523130	20100N	PARTICIPANT	\N	PRESENT	0
526261	523130	08034U	PARTICIPANT	\N	PRESENT	0
526262	523130	19531S	PARTICIPANT	\N	PRESENT	0
526263	523130	19521Q	PARTICIPANT	\N	PRESENT	0
526264	523130	20094J	PARTICIPANT	\N	PRESENT	0
523449	521471	14097Y	PARTICIPANT	\N	PRESENT	1
523450	521471	14059S	PARTICIPANT	\N	PRESENT	0
523451	521471	14133K	PARTICIPANT	\N	PRESENT	0
523452	521471	01062T	PARTICIPANT	\N	PRESENT	1
523453	521471	20042V	PARTICIPANT	\N	PRESENT	0
523454	521471	14105F	PARTICIPANT	\N	PRESENT	1
523455	521471	20064C	PARTICIPANT	\N	PRESENT	0
523456	521471	98018T	PARTICIPANT	\N	PRESENT	1
523457	521471	14267Y	PARTICIPANT	\N	PRESENT	0
523458	521471	11064N	PARTICIPANT	\N	PRESENT	0
523459	521471	14255U	PARTICIPANT	\N	PRESENT	0
523460	521477	11056N	PARTICIPANT	\N	PRESENT	0
523461	521477	19387D	PARTICIPANT	\N	PRESENT	0
523474	521477	20048C	PARTICIPANT	\N	PRESENT	0
523477	521477	19447X	PARTICIPANT	\N	PRESENT	0
523479	521477	14217N	PARTICIPANT	\N	PRESENT	0
523490	521477	19866P	PARTICIPANT	\N	PRESENT	0
523491	521477	11027H	PARTICIPANT	\N	PRESENT	0
523492	521477	19347U	PARTICIPANT	\N	PRESENT	0
523493	521477	20142Y	PARTICIPANT	\N	PRESENT	0
523494	521477	11109J	PARTICIPANT	\N	PRESENT	0
523495	521477	20132W	PARTICIPANT	\N	PRESENT	0
523496	521477	18083K	PARTICIPANT	\N	PRESENT	0
523527	521421	20076G	PARTICIPANT	\N	PRESENT	0
523528	521421	19549D	PARTICIPANT	\N	PRESENT	0
523529	521421	08060W	PARTICIPANT	\N	EXCUSE	0
523530	521421	18083K	PARTICIPANT	\N	PRESENT	1
523531	521421	11065P	PARTICIPANT	\N	PRESENT	0
523532	521421	17229F	PARTICIPANT	\N	PRESENT	0
523533	521421	19251M	PARTICIPANT	\N	PRESENT	1
523534	521421	20100N	PARTICIPANT	\N	PRESENT	0
523535	521421	19387D	PARTICIPANT	\N	PRESENT	0
523536	521421	20068G	PARTICIPANT	\N	PRESENT	0
523537	521421	20102Q	PARTICIPANT	\N	PRESENT	0
523538	521421	14219Q	PRESIDENT	0	PRESENT	0
523539	521421	14031R	PARTICIPANT	\N	PRESENT	0
523540	521421	19637C	PARTICIPANT	\N	PRESENT	1
523541	521421	14237S	PARTICIPANT	\N	PRESENT	0
523542	521421	17637T	PARTICIPANT	\N	PRESENT	0
523543	521421	19503N	PARTICIPANT	\N	PRESENT	0
523544	521421	19739H	PARTICIPANT	\N	PRESENT	0
523545	521421	20020P	PARTICIPANT	\N	PRESENT	1
523546	521421	19619A	PARTICIPANT	\N	PRESENT	0
523547	521421	20046A	PARTICIPANT	\N	PRESENT	0
523671	523670	20042V	PARTICIPANT	\N	PRESENT	0
523672	523670	11080N	PARTICIPANT	\N	PRESENT	0
523673	523670	18083K	PARTICIPANT	\N	PRESENT	0
523674	523670	11026G	PARTICIPANT	\N	PRESENT	0
523675	523670	01048V	PARTICIPANT	\N	PRESENT	0
523676	523670	14059S	PARTICIPANT	\N	PRESENT	0
523677	523670	19503N	PARTICIPANT	\N	PRESENT	0
523678	523670	19349W	PARTICIPANT	\N	PRESENT	0
523679	523670	19713W	PARTICIPANT	\N	PRESENT	0
523680	523670	20064C	PARTICIPANT	\N	PRESENT	0
523716	519602	20072C	PARTICIPANT	\N	PRESENT	0
523717	519602	20128B	PARTICIPANT	\N	PRESENT	0
523719	519602	20066E	PARTICIPANT	\N	PRESENT	0
523720	519602	19723Y	PARTICIPANT	\N	PRESENT	0
523721	519602	11067R	PARTICIPANT	\N	PRESENT	0
523722	519602	19533U	PARTICIPANT	\N	PRESENT	0
523723	519602	04043D	PARTICIPANT	\N	PRESENT	0
523724	519602	01058X	PARTICIPANT	\N	PRESENT	0
523727	519602	19503N	PARTICIPANT	\N	PRESENT	0
524181	524180	14071N	PARTICIPANT	\N	PRESENT	0
524183	524182	14207L	PARTICIPANT	\N	PRESENT	0
524184	524182	01025N	PARTICIPANT	\N	PRESENT	0
524185	524182	19747H	PARTICIPANT	\N	PRESENT	0
524196	524194	19747H	PARTICIPANT	\N	PRESENT	0
524187	524182	20024T	PARTICIPANT	\N	PRESENT	0
524189	524188	14207L	PARTICIPANT	\N	PRESENT	0
524190	524188	01025N	PARTICIPANT	\N	PRESENT	0
524191	524188	19441R	PARTICIPANT	\N	PRESENT	0
524192	524188	19515S	PARTICIPANT	\N	PRESENT	0
524193	524188	19443T	PARTICIPANT	\N	PRESENT	0
524195	524194	19515S	PARTICIPANT	\N	PRESENT	0
524219	524218	18083K	PARTICIPANT	\N	PRESENT	0
524220	524218	19667J	PARTICIPANT	\N	PRESENT	0
524221	524218	19599P	PARTICIPANT	\N	PRESENT	0
524222	524218	14033T	PARTICIPANT	\N	PRESENT	0
524223	524218	19685L	PARTICIPANT	\N	PRESENT	0
524224	524218	08015R	PARTICIPANT	\N	PRESENT	0
524225	524218	19533U	PARTICIPANT	\N	PRESENT	0
524226	524218	11090Q	PARTICIPANT	\N	PRESENT	0
524228	524227	19333N	PARTICIPANT	\N	PRESENT	0
524229	524227	20094J	PARTICIPANT	\N	PRESENT	0
524230	524227	17229F	PARTICIPANT	\N	PRESENT	0
524231	524227	11083R	PARTICIPANT	\N	PRESENT	0
524232	524227	04043D	PARTICIPANT	\N	PRESENT	0
524233	524227	20062A	PARTICIPANT	\N	PRESENT	0
524236	524234	04008A	PARTICIPANT	\N	PRESENT	0
524237	524234	20110Q	PARTICIPANT	\N	PRESENT	0
524239	524234	14041T	PARTICIPANT	\N	PRESENT	0
524240	524234	14213J	PARTICIPANT	\N	PRESENT	0
524241	524234	14147R	PARTICIPANT	\N	PRESENT	0
524242	524234	04043D	PARTICIPANT	\N	PRESENT	0
525181	525137	19679N	PARTICIPANT	\N	PRESENT	0
525182	525180	19679N	PARTICIPANT	\N	PRESENT	0
525230	518916	18083K	PARTICIPANT	\N	PRESENT	0
525231	518916	97011G	PARTICIPANT	\N	PRESENT	0
525232	518916	11010L	PARTICIPANT	\N	EXCUSE	0
525233	518916	20034V	PARTICIPANT	\N	PRESENT	0
525234	518916	19717B	PRESIDENT	0	PRESENT	0
525235	518916	19347U	PARTICIPANT	\N	PRESENT	0
525236	518916	08034U	PARTICIPANT	\N	PRESENT	0
526268	522158	05008E	PARTICIPANT	\N	EXCUSE	0
525246	524110	19643A	PARTICIPANT	\N	PRESENT	1
525247	524110	20084G	PARTICIPANT	\N	PRESENT	0
526266	518916	14147R	PARTICIPANT	\N	PRESENT	0
526269	519091	05008E	PARTICIPANT	\N	EXCUSE	0
526287	526286	19723Y	PARTICIPANT	\N	PRESENT	0
526289	526288	14207L	PARTICIPANT	\N	PRESENT	0
526290	526288	01025N	PARTICIPANT	\N	PRESENT	0
526291	526288	19575F	PARTICIPANT	\N	PRESENT	0
526292	526288	19369B	PARTICIPANT	\N	PRESENT	0
526298	524041	14189C	PARTICIPANT	\N	PRESENT	0
526299	524041	20024T	PARTICIPANT	\N	PRESENT	0
526300	524041	14030Q	PRESIDENT	0	PRESENT	0
526301	524041	20080C	PARTICIPANT	\N	PRESENT	0
526302	524041	11031D	PARTICIPANT	\N	PRESENT	0
526303	524041	19693L	PARTICIPANT	\N	PRESENT	0
526304	524041	19599P	PARTICIPANT	\N	EXCUSE	0
526305	524041	14179A	PARTICIPANT	\N	PRESENT	0
526306	524041	20056C	PARTICIPANT	\N	PRESENT	0
526307	524041	19657G	PARTICIPANT	\N	PRESENT	0
526308	524041	14221J	PARTICIPANT	\N	PRESENT	0
526309	524041	14109K	PARTICIPANT	\N	PRESENT	0
526310	524041	19768N	PARTICIPANT	\N	PRESENT	0
526311	524041	19866P	PARTICIPANT	\N	PRESENT	0
526312	524041	20118Y	PARTICIPANT	\N	EXCUSE	0
526313	524041	20130U	PARTICIPANT	\N	PRESENT	0
526314	524041	19798U	PARTICIPANT	\N	PRESENT	0
526315	524041	20046A	PARTICIPANT	\N	PRESENT	0
526316	524041	19749K	PARTICIPANT	\N	PRESENT	0
526319	526317	04047H	PARTICIPANT	\N	PRESENT	0
526320	526317	14053L	PARTICIPANT	\N	PRESENT	0
526321	526317	14299H	PARTICIPANT	\N	PRESENT	0
526324	526317	11066Q	PARTICIPANT	\N	PRESENT	0
526326	526325	04092N	PARTICIPANT	\N	PRESENT	0
526327	526325	20130U	PARTICIPANT	\N	PRESENT	1
526328	526325	11031D	PARTICIPANT	\N	PRESENT	1
526329	526325	11067R	PARTICIPANT	\N	PRESENT	0
526330	526325	14042U	PARTICIPANT	\N	PRESENT	1
526360	526359	20042V	PARTICIPANT	\N	PRESENT	0
526361	526359	11074Q	PARTICIPANT	\N	PRESENT	0
526362	526359	11080N	PRESIDENT	0	PRESENT	0
526363	526359	19347U	PARTICIPANT	\N	PRESENT	0
526364	526359	14121F	PARTICIPANT	\N	PRESENT	0
526365	526359	19335Q	PARTICIPANT	\N	PRESENT	0
526366	526359	05012A	PARTICIPANT	\N	PRESENT	0
526372	526222	19565D	PARTICIPANT	\N	PRESENT	0
526799	526798	08060W	PARTICIPANT	\N	PRESENT	0
526800	526798	05012A	PARTICIPANT	\N	PRESENT	0
526801	526798	17229F	PARTICIPANT	\N	PRESENT	0
526802	526798	20100N	PARTICIPANT	\N	PRESENT	0
518035	518034	98022P	PARTICIPANT	\N	PRESENT	0
518036	518034	08056B	PARTICIPANT	\N	PRESENT	0
518037	518034	08015R	PARTICIPANT	\N	PRESENT	0
518038	518034	11026G	PARTICIPANT	\N	PRESENT	0
518039	518034	08009T	PARTICIPANT	\N	PRESENT	0
518040	518034	08045X	PARTICIPANT	\N	PRESENT	0
518043	518034	20026V	PARTICIPANT	\N	PRESENT	0
520634	520633	19713W	PARTICIPANT	\N	PRESENT	0
520637	520633	11026G	PARTICIPANT	\N	PRESENT	0
520639	520633	08009T	PARTICIPANT	\N	PRESENT	0
520641	520633	14147R	PARTICIPANT	\N	PRESENT	0
520642	520633	19745F	PARTICIPANT	\N	PRESENT	0
520645	520633	19739H	PARTICIPANT	\N	PRESENT	0
520666	520662	14053L	PARTICIPANT	\N	PRESENT	0
520668	520662	19954N	PARTICIPANT	\N	PRESENT	0
520670	520662	19749K	PARTICIPANT	\N	PRESENT	0
524213	524207	19723Y	PARTICIPANT	\N	PRESENT	0
525855	525248	14042U	PARTICIPANT	\N	PRESENT	1
525856	525248	04092N	PARTICIPANT	\N	PRESENT	0
525857	525248	19301E	PARTICIPANT	\N	PRESENT	1
525858	525248	20130U	PARTICIPANT	\N	PRESENT	1
525859	525248	19663E	PARTICIPANT	\N	PRESENT	1
529016	529014	04092N	PARTICIPANT	\N	PRESENT	0
529017	529014	19553Y	PARTICIPANT	\N	PRESENT	0
529018	529014	20130U	PARTICIPANT	\N	PRESENT	0
529019	529014	17965H	PARTICIPANT	\N	PRESENT	0
529020	529014	19663E	PARTICIPANT	\N	PRESENT	0
529021	529014	19798U	PARTICIPANT	\N	PRESENT	0
529022	529014	11097X	PARTICIPANT	\N	PRESENT	0
530207	530201	14107H	PARTICIPANT	\N	PRESENT	0
530203	530201	04085P	PARTICIPANT	\N	PRESENT	0
530204	530201	19629C	PARTICIPANT	\N	PRESENT	0
530205	530201	19673G	PARTICIPANT	\N	PRESENT	0
530206	530201	19749K	PARTICIPANT	\N	PRESENT	0
530208	530201	19533U	PARTICIPANT	\N	PRESENT	0
530211	530210	19673G	PARTICIPANT	\N	PRESENT	0
530212	530210	19749K	PARTICIPANT	\N	PRESENT	0
530213	530210	11026G	PARTICIPANT	\N	PRESENT	0
530216	530210	19533U	PARTICIPANT	\N	PRESENT	0
530222	530221	19673G	PARTICIPANT	\N	PRESENT	0
530223	530221	19749K	PARTICIPANT	\N	PRESENT	0
530224	530221	11026G	PARTICIPANT	\N	PRESENT	0
530226	530221	04047H	PARTICIPANT	\N	PRESENT	0
530227	530221	19533U	PARTICIPANT	\N	PRESENT	0
532647	532640	14105F	PARTICIPANT	\N	PRESENT	0
532648	532640	20098N	PARTICIPANT	\N	PRESENT	1
532650	532640	11043H	PARTICIPANT	\N	PRESENT	0
532651	532640	19631V	PARTICIPANT	\N	PRESENT	1
532652	532640	19954N	PARTICIPANT	\N	PRESENT	0
532653	532640	19575F	PARTICIPANT	\N	PRESENT	0
532654	532640	20138D	PARTICIPANT	\N	PRESENT	0
532655	532640	19629C	PARTICIPANT	\N	PRESENT	1
532672	532640	14147R	PARTICIPANT	\N	PRESENT	0
532657	532640	17589D	PARTICIPANT	\N	PRESENT	0
532658	532640	19251M	PARTICIPANT	\N	PRESENT	0
532659	532640	20134Y	PARTICIPANT	\N	PRESENT	0
532660	532640	20132W	PARTICIPANT	\N	PRESENT	0
532661	532640	19725B	PARTICIPANT	\N	PRESENT	1
532662	532640	19399H	PARTICIPANT	\N	PRESENT	0
532663	532640	14213J	PARTICIPANT	\N	PRESENT	0
532665	532640	14073Q	PARTICIPANT	\N	PRESENT	0
532666	532640	19699S	PARTICIPANT	\N	PRESENT	0
532670	532640	20026V	PARTICIPANT	\N	PRESENT	0
532668	532640	20052X	PARTICIPANT	\N	PRESENT	0
532669	532640	19349W	PARTICIPANT	\N	PRESENT	0
532671	532640	08012N	PARTICIPANT	\N	PRESENT	0
533365	531286	04045F	PARTICIPANT	\N	PRESENT	1
533366	531286	19369B	PARTICIPANT	\N	PRESENT	1
533368	531286	08056B	PARTICIPANT	\N	PRESENT	1
533369	531286	14249W	PARTICIPANT	\N	PRESENT	0
533371	531286	14001X	PARTICIPANT	\N	PRESENT	1
533375	531286	01025N	PARTICIPANT	\N	PRESENT	1
533376	531286	04057K	PARTICIPANT	\N	PRESENT	1
533387	531287	19369B	PARTICIPANT	\N	PRESENT	1
533391	531287	19575F	PARTICIPANT	\N	EXCUSE	0
533393	531288	11077T	PARTICIPANT	\N	PRESENT	1
533394	531288	19747H	PARTICIPANT	\N	PRESENT	0
533395	531288	19705W	PARTICIPANT	\N	PRESENT	1
533396	531288	19768N	PARTICIPANT	\N	PRESENT	1
533413	531288	20144B	PARTICIPANT	\N	PRESENT	0
533414	531288	14221J	PARTICIPANT	\N	PRESENT	0
533415	531288	04045F	PARTICIPANT	\N	PRESENT	0
533416	531288	19511N	PARTICIPANT	\N	PRESENT	0
533423	531288	14219Q	PARTICIPANT	\N	PRESENT	0
533439	531288	14169X	PARTICIPANT	\N	PRESENT	0
533447	531288	19515S	PARTICIPANT	\N	PRESENT	1
534031	534030	20038A	PARTICIPANT	\N	PRESENT	0
534032	534030	19820Y	PARTICIPANT	\N	PRESENT	0
534033	534030	20104S	PARTICIPANT	\N	PRESENT	0
534035	534034	14033T	PARTICIPANT	\N	PRESENT	0
534036	534034	19413M	PARTICIPANT	\N	PRESENT	0
534037	534034	20092G	PARTICIPANT	\N	PRESENT	0
534038	534034	20034V	PARTICIPANT	\N	PRESENT	0
534040	534039	14033T	PARTICIPANT	\N	PRESENT	0
534041	534039	20144B	PARTICIPANT	\N	PRESENT	0
534042	534039	20034V	PARTICIPANT	\N	PRESENT	0
534043	534039	14257W	PARTICIPANT	\N	PRESENT	0
534113	534111	01034P	PARTICIPANT	\N	PRESENT	0
534114	534112	01034P	PARTICIPANT	\N	PRESENT	0
534126	534125	19673G	PARTICIPANT	\N	PRESENT	0
534127	534125	07004J	PARTICIPANT	\N	PRESENT	0
534128	534125	19749K	PARTICIPANT	\N	PRESENT	0
534130	534129	19673G	PARTICIPANT	\N	PRESENT	0
534131	534129	07004J	PARTICIPANT	\N	PRESENT	0
534132	534129	19749K	PARTICIPANT	\N	PRESENT	0
534134	534133	19673G	PARTICIPANT	\N	PRESENT	0
534135	534133	07004J	PARTICIPANT	\N	PRESENT	0
534136	534133	19749K	PARTICIPANT	\N	PRESENT	0
534138	534137	19673G	PARTICIPANT	\N	PRESENT	0
534139	534137	07004J	PARTICIPANT	\N	PRESENT	0
534140	534137	19749K	PARTICIPANT	\N	PRESENT	0
534142	534141	19673G	PARTICIPANT	\N	PRESENT	0
534143	534141	07004J	PARTICIPANT	\N	PRESENT	0
534144	534141	19749K	PARTICIPANT	\N	PRESENT	0
534146	534145	19673G	PARTICIPANT	\N	PRESENT	0
534147	534145	07004J	PARTICIPANT	\N	PRESENT	0
534148	534145	19749K	PARTICIPANT	\N	PRESENT	0
534149	534145	14001X	PARTICIPANT	\N	PRESENT	0
534150	534145	14179A	PARTICIPANT	\N	PRESENT	0
534152	534151	19673G	PARTICIPANT	\N	PRESENT	0
534157	534156	19673G	PARTICIPANT	\N	PRESENT	0
534154	534151	07004J	PARTICIPANT	\N	PRESENT	0
534155	534151	19749K	PARTICIPANT	\N	PRESENT	0
534158	534156	07004J	PARTICIPANT	\N	PRESENT	0
534159	534156	14001X	PARTICIPANT	\N	PRESENT	0
534160	534156	19749K	PARTICIPANT	\N	PRESENT	0
534162	534161	19673G	PARTICIPANT	\N	PRESENT	0
534163	534161	07004J	PARTICIPANT	\N	PRESENT	0
534164	534161	19749K	PARTICIPANT	\N	PRESENT	0
534187	534186	04057K	PARTICIPANT	\N	PRESENT	0
534188	534186	11083R	PARTICIPANT	\N	PRESENT	0
534357	534356	01034P	PARTICIPANT	\N	PRESENT	1
534358	502367	19583F	PARTICIPANT	\N	PRESENT	0
535228	535227	14033T	PARTICIPANT	\N	PRESENT	0
535229	535227	19447X	PARTICIPANT	\N	PRESENT	0
535230	535227	19735D	PARTICIPANT	\N	PRESENT	0
535231	535227	08034U	PARTICIPANT	\N	PRESENT	0
535232	535227	14205J	PARTICIPANT	\N	PRESENT	0
535233	535227	11097X	PARTICIPANT	\N	PRESENT	0
535234	535227	14173T	PARTICIPANT	\N	PRESENT	0
535914	534225	14133K	PARTICIPANT	\N	PRESENT	1
535915	534225	20042V	PARTICIPANT	\N	PRESENT	0
535916	534225	14105F	PARTICIPANT	\N	PRESENT	1
535917	534225	14255U	PARTICIPANT	\N	PRESENT	1
535918	534225	04042C	PARTICIPANT	\N	PRESENT	0
535919	534225	11080N	PARTICIPANT	\N	PRESENT	0
535920	534225	14267Y	PARTICIPANT	\N	PRESENT	0
535921	534225	11027H	PARTICIPANT	\N	PRESENT	1
535922	534225	14249W	PARTICIPANT	\N	PRESENT	0
535931	534225	17023S	PARTICIPANT	\N	PRESENT	0
535933	534225	97011G	PARTICIPANT	\N	PRESENT	0
535937	534225	11083R	PARTICIPANT	\N	PRESENT	1
535950	534225	19347U	PARTICIPANT	\N	PRESENT	0
535952	534225	08056B	PARTICIPANT	\N	PRESENT	1
535955	534225	14211G	PARTICIPANT	\N	PRESENT	0
535958	534225	19565D	PARTICIPANT	\N	PRESENT	0
535960	534225	98022P	PARTICIPANT	\N	PRESENT	0
535965	534225	11064N	PARTICIPANT	\N	PRESENT	0
535968	534225	20072C	PARTICIPANT	\N	PRESENT	1
533683	530826	18193Q	PARTICIPANT	\N	PRESENT	0
533684	530826	17779H	PARTICIPANT	\N	PRESENT	0
533705	533704	07033P	PARTICIPANT	\N	PRESENT	1
533706	533704	14109K	PARTICIPANT	\N	PRESENT	1
533708	533707	19651A	PARTICIPANT	\N	PRESENT	1
533709	533707	20180F	PARTICIPANT	\N	PRESENT	1
533710	533707	20124W	PARTICIPANT	\N	PRESENT	1
533720	533718	19651A	PARTICIPANT	\N	PRESENT	1
533721	533718	20124W	PARTICIPANT	\N	PRESENT	1
533722	533718	19621T	PARTICIPANT	\N	PRESENT	1
533723	533718	20180F	PARTICIPANT	\N	PRESENT	1
533725	533724	19651A	PARTICIPANT	\N	PRESENT	1
533726	533724	20124W	PARTICIPANT	\N	PRESENT	1
533727	533724	20180F	PARTICIPANT	\N	PRESENT	1
533728	533724	19621T	PARTICIPANT	\N	PRESENT	1
538780	536913	14033T	PARTICIPANT	\N	PRESENT	1
538765	536913	10015M	PARTICIPANT	\N	PRESENT	0
538766	536913	04034C	PARTICIPANT	\N	PRESENT	1
538771	536913	11027H	PARTICIPANT	\N	PRESENT	1
538772	536913	19709B	PARTICIPANT	\N	PRESENT	0
538773	536913	12016W	PARTICIPANT	\N	EXCUSE	0
538781	536913	20128B	PARTICIPANT	\N	PRESENT	1
538782	536913	11083R	PARTICIPANT	\N	PRESENT	0
538789	536832	11045K	PARTICIPANT	\N	PRESENT	0
538804	536832	11067R	PARTICIPANT	\N	PRESENT	0
538806	536832	19637C	PARTICIPANT	\N	PRESENT	0
538809	536832	08045X	PARTICIPANT	\N	PRESENT	0
538811	536832	14109K	PARTICIPANT	\N	PRESENT	0
538814	536832	11104D	PARTICIPANT	\N	PRESENT	0
538816	536832	14207L	PARTICIPANT	\N	PRESENT	0
538819	536832	19715Y	PARTICIPANT	\N	PRESENT	0
538820	536832	11097X	PARTICIPANT	\N	PRESENT	0
538822	536832	12028B	PARTICIPANT	\N	PRESENT	0
538824	536832	10006L	PARTICIPANT	\N	PRESENT	0
538825	536832	19415P	PARTICIPANT	\N	PRESENT	0
538827	536832	19593H	PARTICIPANT	\N	PRESENT	0
538829	536832	19467C	PARTICIPANT	\N	PRESENT	0
538830	536832	11031D	PARTICIPANT	\N	PRESENT	0
538832	536832	04085P	PARTICIPANT	\N	PRESENT	0
538836	536832	04059M	PARTICIPANT	\N	PRESENT	0
538837	536832	14021P	PARTICIPANT	\N	PRESENT	0
538838	536832	19669L	PARTICIPANT	\N	PRESENT	0
538839	536832	08069G	PARTICIPANT	\N	PRESENT	0
538840	536832	11033F	PARTICIPANT	\N	PRESENT	0
538841	536832	20130U	PARTICIPANT	\N	PRESENT	0
538842	536832	19503N	PARTICIPANT	\N	PRESENT	0
538843	536832	14267Y	PARTICIPANT	\N	PRESENT	0
538844	536832	19251M	PARTICIPANT	\N	PRESENT	0
538845	536832	10015M	PARTICIPANT	\N	PRESENT	0
538846	536832	19591F	PARTICIPANT	\N	PRESENT	0
538847	536832	08061X	PARTICIPANT	\N	PRESENT	0
538848	536832	95063L	PARTICIPANT	\N	PRESENT	0
538849	536832	20060X	PARTICIPANT	\N	PRESENT	0
538850	536832	19760E	PARTICIPANT	\N	PRESENT	0
538851	536832	11077T	PARTICIPANT	\N	PRESENT	0
538852	536832	20064C	PARTICIPANT	\N	PRESENT	0
538853	536832	19866P	PARTICIPANT	\N	PRESENT	0
538855	536832	14221J	PARTICIPANT	\N	PRESENT	0
538856	536832	19691J	PARTICIPANT	\N	PRESENT	0
538857	536832	14123H	PARTICIPANT	\N	PRESENT	0
538863	536832	08060W	PARTICIPANT	\N	PRESENT	0
538864	536832	14042U	PARTICIPANT	\N	PRESENT	0
538865	536832	14073Q	PARTICIPANT	\N	PRESENT	0
538866	536832	20066E	PARTICIPANT	\N	PRESENT	0
538867	536832	19413M	PARTICIPANT	\N	PRESENT	0
538868	536832	19599P	PARTICIPANT	\N	PRESENT	0
538869	536832	19489J	PARTICIPANT	\N	PRESENT	0
538870	536832	19387D	PARTICIPANT	\N	PRESENT	0
538871	536832	19643A	PARTICIPANT	\N	PRESENT	0
538872	536832	19647E	PARTICIPANT	\N	PRESENT	0
538873	536832	19333N	PARTICIPANT	\N	PRESENT	0
538874	536832	20080C	PARTICIPANT	\N	PRESENT	0
538875	536832	14331P	PARTICIPANT	\N	PRESENT	0
538876	536832	19551W	PARTICIPANT	\N	PRESENT	0
538877	536832	14225N	PARTICIPANT	\N	PRESENT	0
538878	536832	20058E	PARTICIPANT	\N	PRESENT	0
538879	536832	14213J	PARTICIPANT	\N	PRESENT	0
538880	536832	19701S	PARTICIPANT	\N	PRESENT	0
538881	536832	14219Q	PARTICIPANT	\N	PRESENT	0
538882	536832	20082E	PARTICIPANT	\N	PRESENT	0
538883	536832	19739H	PARTICIPANT	\N	PRESENT	0
538884	536832	14189C	PARTICIPANT	\N	PRESENT	0
538885	536832	19713W	PARTICIPANT	\N	PRESENT	0
538886	536832	19563B	PARTICIPANT	\N	PRESENT	0
538887	536832	17779H	PARTICIPANT	\N	PRESENT	0
538888	536832	01024M	PARTICIPANT	\N	PRESENT	0
538889	536832	19527W	PARTICIPANT	\N	PRESENT	0
538890	536832	19711U	PARTICIPANT	\N	PRESENT	0
538891	536832	14055N	PARTICIPANT	\N	PRESENT	0
538892	536832	19649G	PARTICIPANT	\N	PRESENT	0
538893	536832	14001X	PARTICIPANT	\N	PRESENT	0
538894	536832	19673G	PARTICIPANT	\N	PRESENT	0
538895	536832	20100N	PARTICIPANT	\N	PRESENT	0
538896	536832	19553Y	PARTICIPANT	\N	PRESENT	0
538897	536832	14069U	PARTICIPANT	\N	PRESENT	0
538898	536832	20070A	PARTICIPANT	\N	PRESENT	0
538899	536832	04043D	PARTICIPANT	\N	PRESENT	0
538900	536832	05012A	PARTICIPANT	\N	PRESENT	0
538901	536832	20090E	PARTICIPANT	\N	PRESENT	0
538902	536832	14041T	PARTICIPANT	\N	PRESENT	0
538903	536832	08034U	PARTICIPANT	\N	PRESENT	0
538904	536832	19747H	PARTICIPANT	\N	PRESENT	0
538905	536832	14031R	PARTICIPANT	\N	PRESENT	0
538906	536832	14083S	PARTICIPANT	\N	PRESENT	0
538907	536832	20174H	PARTICIPANT	\N	PRESENT	0
538909	536832	19565D	PARTICIPANT	\N	PRESENT	0
538915	530851	19766L	PARTICIPANT	\N	PRESENT	0
538916	530851	19643A	PARTICIPANT	\N	PRESENT	0
538917	530851	19699S	PARTICIPANT	\N	PRESENT	0
538918	530851	20134Y	PARTICIPANT	\N	PRESENT	0
538919	530851	19533U	PARTICIPANT	\N	PRESENT	0
538920	530851	14073Q	PARTICIPANT	\N	PRESENT	0
538921	530851	19611R	PRESIDENT	0	PRESENT	0
538922	530851	19693L	PARTICIPANT	\N	PRESENT	0
538923	530851	19399H	PARTICIPANT	\N	PRESENT	0
538924	530851	20152B	PARTICIPANT	\N	PRESENT	0
538925	530851	20058E	PARTICIPANT	\N	PRESENT	0
538927	530851	14123H	PARTICIPANT	\N	PRESENT	0
538928	530851	08061X	PARTICIPANT	\N	PRESENT	0
538929	530851	11104D	PARTICIPANT	\N	PRESENT	0
538930	530851	19758L	PARTICIPANT	\N	PRESENT	0
538931	530851	19621T	PARTICIPANT	\N	PRESENT	0
538932	530851	11109J	PARTICIPANT	\N	EXCUSE	0
538933	536832	14215L	PARTICIPANT	\N	PRESENT	0
538934	536832	14071N	PARTICIPANT	\N	PRESENT	0
538935	536832	20108W	PARTICIPANT	\N	PRESENT	0
538936	536832	12016W	PARTICIPANT	\N	PRESENT	0
538952	536832	19577H	PARTICIPANT	\N	PRESENT	0
538953	536832	19657G	PARTICIPANT	\N	PRESENT	0
538954	536832	14257W	PARTICIPANT	\N	PRESENT	0
538955	536832	14111D	PARTICIPANT	\N	PRESENT	0
538956	536832	19479G	PARTICIPANT	\N	PRESENT	0
538957	536832	11012A	PARTICIPANT	\N	PRESENT	0
538958	536832	20114U	PARTICIPANT	\N	PRESENT	0
539077	538963	20032T	PARTICIPANT	\N	PRESENT	0
539078	538963	20076G	PARTICIPANT	\N	PRESENT	0
539091	539088	20076G	PARTICIPANT	\N	PRESENT	0
539080	538963	14357A	PARTICIPANT	\N	PRESENT	0
539081	538963	19820Y	PARTICIPANT	\N	PRESENT	0
539082	538963	20126Y	PARTICIPANT	\N	PRESENT	0
539083	538963	19503N	PARTICIPANT	\N	PRESENT	0
539084	538963	19739H	PARTICIPANT	\N	PRESENT	0
539085	538963	19619A	PARTICIPANT	\N	PRESENT	0
539086	538963	20092G	PARTICIPANT	\N	PRESENT	0
539087	538963	20070A	PARTICIPANT	\N	PRESENT	0
539093	539088	14357A	PARTICIPANT	\N	PRESENT	0
539092	539088	20070A	PARTICIPANT	\N	PRESENT	0
539094	539088	20126Y	PARTICIPANT	\N	PRESENT	0
539095	539088	19739H	PARTICIPANT	\N	PRESENT	0
539096	539088	19619A	PARTICIPANT	\N	PRESENT	0
539097	539088	20092G	PARTICIPANT	\N	PRESENT	0
539099	539098	19782L	PARTICIPANT	\N	PRESENT	0
539100	539098	20070A	PARTICIPANT	\N	PRESENT	0
539101	539098	14357A	PARTICIPANT	\N	PRESENT	0
539102	539098	19820Y	PARTICIPANT	\N	PRESENT	0
539103	539098	20126Y	PARTICIPANT	\N	PRESENT	0
539104	539098	19739H	PARTICIPANT	\N	PRESENT	0
539105	539098	19619A	PARTICIPANT	\N	PRESENT	0
539106	539098	20092G	PARTICIPANT	\N	PRESENT	0
539107	531688	19717B	PARTICIPANT	\N	EXCUSE	0
513882	513881	19515S	PARTICIPANT	\N	PRESENT	0
513883	513881	20174H	PARTICIPANT	\N	PRESENT	0
513884	513881	19521Q	PARTICIPANT	\N	PRESENT	0
513885	513881	11090Q	PARTICIPANT	\N	PRESENT	0
515035	512705	20074E	PARTICIPANT	\N	PRESENT	0
515036	512705	19585H	PARTICIPANT	\N	PRESENT	0
515037	512705	04047H	PRESIDENT	0	PRESENT	0
515038	512705	19673G	PARTICIPANT	\N	PRESENT	0
515039	512705	19675J	PARTICIPANT	\N	PRESENT	0
515040	512705	01028R	PARTICIPANT	\N	PRESENT	0
515041	512705	19447X	PARTICIPANT	\N	PRESENT	0
515042	512705	14231L	PARTICIPANT	\N	PRESENT	0
515043	512705	05008E	PARTICIPANT	\N	PRESENT	0
515044	512705	19954N	PARTICIPANT	\N	PRESENT	0
515045	512705	19489J	PARTICIPANT	\N	PRESENT	0
515046	512705	17737W	PARTICIPANT	\N	PRESENT	0
515047	512705	07004J	PARTICIPANT	\N	PRESENT	0
515048	512705	14041T	PARTICIPANT	\N	PRESENT	0
515049	512705	20108W	PARTICIPANT	\N	PRESENT	0
515050	512705	20110Q	PARTICIPANT	\N	PRESENT	0
515051	512705	14147R	PARTICIPANT	\N	PRESENT	0
515052	512705	20114U	PARTICIPANT	\N	PRESENT	0
515053	512705	14215L	PARTICIPANT	\N	PRESENT	0
515054	512705	14259Y	PARTICIPANT	\N	PRESENT	0
515055	512705	14053L	PARTICIPANT	\N	PRESENT	0
515056	512705	11026G	PARTICIPANT	\N	PRESENT	0
515057	512705	10015M	PARTICIPANT	\N	PRESENT	0
515058	512705	14089Y	PARTICIPANT	\N	PRESENT	0
515059	512705	11056N	PARTICIPANT	\N	PRESENT	0
515060	512705	95063L	PARTICIPANT	\N	PRESENT	0
515061	512705	14069U	PARTICIPANT	\N	PRESENT	0
515062	512705	19749K	PARTICIPANT	\N	PRESENT	0
515063	512705	04008A	PARTICIPANT	\N	PRESENT	0
515072	513088	17023S	PARTICIPANT	\N	PRESENT	0
515073	511901	20096L	PARTICIPANT	\N	PRESENT	0
515074	511901	19551W	PARTICIPANT	\N	PRESENT	1
515075	511901	19701S	PARTICIPANT	\N	PRESENT	1
515077	512268	11067R	PARTICIPANT	\N	PRESENT	0
515078	512268	20090E	PARTICIPANT	\N	PRESENT	0
515079	512268	19798U	PARTICIPANT	\N	PRESENT	0
515080	512268	19415P	PARTICIPANT	\N	PRESENT	0
515081	512268	18193Q	PARTICIPANT	\N	PRESENT	0
515082	512268	17779H	PARTICIPANT	\N	PRESENT	0
515083	512268	11031D	PARTICIPANT	\N	PRESENT	0
515084	512268	19703U	PARTICIPANT	\N	PRESENT	0
515085	512268	19966S	PARTICIPANT	\N	PRESENT	0
515086	512268	19679N	PARTICIPANT	\N	PRESENT	0
515087	512268	14042U	PARTICIPANT	\N	PRESENT	0
515088	512268	19367Y	PARTICIPANT	\N	PRESENT	0
515089	512268	19683J	PARTICIPANT	\N	PRESENT	0
515090	512268	19591F	PARTICIPANT	\N	PRESENT	0
515091	512268	04057K	PARTICIPANT	\N	PRESENT	0
515092	512268	19713W	PARTICIPANT	\N	PRESENT	0
515093	512268	11045K	PARTICIPANT	\N	PRESENT	0
515094	512268	19663E	PARTICIPANT	\N	PRESENT	0
515095	512268	17965H	PARTICIPANT	\N	PRESENT	0
515096	512268	20148F	PARTICIPANT	\N	PRESENT	0
515097	512268	20172F	PARTICIPANT	\N	PRESENT	0
515098	512268	20066E	PARTICIPANT	\N	PRESENT	0
515099	512268	14071N	PARTICIPANT	\N	PRESENT	0
515110	512268	14223L	PARTICIPANT	\N	PRESENT	0
515173	513088	19443T	PARTICIPANT	\N	PRESENT	1
515174	514131	19766L	PARTICIPANT	\N	PRESENT	0
515175	514131	04070G	PARTICIPANT	\N	PRESENT	0
515176	514131	19699S	PARTICIPANT	\N	PRESENT	0
515177	514131	19533U	PARTICIPANT	\N	PRESENT	0
515178	514131	14229S	PARTICIPANT	\N	PRESENT	0
515179	514131	20098N	PARTICIPANT	\N	PRESENT	0
515180	514131	19573D	PARTICIPANT	\N	PRESENT	0
515181	514131	08017T	PARTICIPANT	\N	PRESENT	0
515182	514131	20112S	PARTICIPANT	\N	PRESENT	0
515183	514131	92040Q	PARTICIPANT	\N	PRESENT	0
515184	514131	08061X	PARTICIPANT	\N	PRESENT	0
515185	514131	08012N	PARTICIPANT	\N	PRESENT	0
515186	514131	20124W	PARTICIPANT	\N	PRESENT	0
515187	514131	20026V	PARTICIPANT	\N	PRESENT	0
515188	514131	19593H	PARTICIPANT	\N	PRESENT	0
515189	514131	19527W	PARTICIPANT	\N	PRESENT	0
515190	514131	20132W	PARTICIPANT	\N	PRESENT	0
515191	514131	19643A	PARTICIPANT	\N	PRESENT	1
515192	514131	20134Y	PARTICIPANT	\N	PRESENT	0
515193	514131	14073Q	PARTICIPANT	\N	PRESENT	0
515194	514131	19611R	PRESIDENT	0	PRESENT	0
515195	514131	20138D	PARTICIPANT	\N	PRESENT	0
515196	514131	20142Y	PARTICIPANT	\N	PRESENT	0
515197	514131	19693L	PARTICIPANT	\N	PRESENT	0
515198	514131	19399H	PARTICIPANT	\N	PRESENT	0
515199	514131	20052X	PARTICIPANT	\N	PRESENT	0
515200	514131	20152B	PARTICIPANT	\N	PRESENT	0
515201	514131	14030Q	PARTICIPANT	\N	PRESENT	0
515202	514131	20058E	PARTICIPANT	\N	PRESENT	0
515203	514131	20056C	PARTICIPANT	\N	PRESENT	0
515220	502370	19413M	PARTICIPANT	\N	PRESENT	0
515205	514131	11083R	PARTICIPANT	\N	PRESENT	0
515206	514131	14109K	PARTICIPANT	\N	PRESENT	0
515207	514131	14123H	PARTICIPANT	\N	PRESENT	0
515208	514131	11104D	PARTICIPANT	\N	PRESENT	1
515209	514131	11043H	PARTICIPANT	\N	PRESENT	0
515210	514131	19758L	PARTICIPANT	\N	PRESENT	0
515211	514131	17589D	PARTICIPANT	\N	PRESENT	1
515212	514131	20084G	PARTICIPANT	\N	PRESENT	0
515213	514131	19621T	PARTICIPANT	\N	PRESENT	0
515221	502370	19333N	PARTICIPANT	\N	PRESENT	0
515222	502370	14042U	PARTICIPANT	\N	PRESENT	0
515223	502370	14053L	PARTICIPANT	\N	PRESENT	0
515224	502370	20100N	PARTICIPANT	\N	PRESENT	0
515225	502370	19525U	PARTICIPANT	\N	PRESENT	0
515226	502370	20148F	PARTICIPANT	\N	PRESENT	0
515228	502370	19954N	PARTICIPANT	\N	PRESENT	0
515229	502370	20082E	PARTICIPANT	\N	PRESENT	0
515231	502370	20124W	PARTICIPANT	\N	PRESENT	0
515232	502370	11115U	PARTICIPANT	\N	PRESENT	0
515233	502370	19798U	PARTICIPANT	\N	PRESENT	0
515234	502370	14105F	PARTICIPANT	\N	PRESENT	0
515235	502370	20114U	PARTICIPANT	\N	PRESENT	0
515236	502370	14026U	PARTICIPANT	\N	PRESENT	0
515237	502370	08028W	PARTICIPANT	\N	PRESENT	0
515238	502370	20108W	PARTICIPANT	\N	PRESENT	0
515239	502370	20068G	PARTICIPANT	\N	PRESENT	0
515240	502370	19549D	PARTICIPANT	\N	PRESENT	0
515241	502370	20056C	PARTICIPANT	\N	PRESENT	0
515242	502370	20174H	PARTICIPANT	\N	PRESENT	0
515243	502370	99004R	PARTICIPANT	\N	PRESENT	0
515244	502370	98022P	PARTICIPANT	\N	PRESENT	0
515245	502370	20152B	PARTICIPANT	\N	PRESENT	0
515246	502370	19766L	PARTICIPANT	\N	PRESENT	0
515247	502370	08010L	PARTICIPANT	\N	PRESENT	0
515248	502370	19729F	PARTICIPANT	\N	PRESENT	0
515249	502370	20028X	PARTICIPANT	\N	PRESENT	0
515250	502370	19745F	PARTICIPANT	\N	PRESENT	0
515251	502370	19415P	PARTICIPANT	\N	PRESENT	0
515252	502370	20062A	PARTICIPANT	\N	PRESENT	0
515253	502370	20102Q	PARTICIPANT	\N	PRESENT	0
515254	502370	19695N	PARTICIPANT	\N	PRESENT	0
515255	502370	14073Q	PARTICIPANT	\N	PRESENT	0
515256	502370	19511N	PARTICIPANT	\N	PRESENT	0
515257	502370	19367Y	PARTICIPANT	\N	PRESENT	0
515258	502370	20020P	PARTICIPANT	\N	PRESENT	0
515259	502370	08056B	PARTICIPANT	\N	PRESENT	0
515260	502370	20024T	PARTICIPANT	\N	PRESENT	0
515261	502370	20142Y	PARTICIPANT	\N	PRESENT	0
515262	502370	12041X	PARTICIPANT	\N	PRESENT	0
515263	502370	11056N	PARTICIPANT	\N	PRESENT	0
515264	502370	19565D	PARTICIPANT	\N	PRESENT	0
515265	502370	08017T	PARTICIPANT	\N	PRESENT	0
515266	502370	14237S	PARTICIPANT	\N	PRESENT	0
515267	502370	14267Y	PARTICIPANT	\N	PRESENT	0
515268	502370	19820Y	PARTICIPANT	\N	PRESENT	0
515269	502370	20112S	PARTICIPANT	\N	PRESENT	0
515270	502370	11027H	PARTICIPANT	\N	PRESENT	0
515271	502370	19545Y	PARTICIPANT	\N	PRESENT	0
515272	502370	14195A	PARTICIPANT	\N	PRESENT	0
515273	502370	20072C	PARTICIPANT	\N	PRESENT	0
515274	502370	11053K	PARTICIPANT	\N	PRESENT	0
515275	502370	14231L	PARTICIPANT	\N	PRESENT	0
515276	502370	14257W	PARTICIPANT	\N	PRESENT	0
515277	502370	19717B	PARTICIPANT	\N	PRESENT	0
515278	502370	20030R	PARTICIPANT	\N	PRESENT	0
515279	502370	19760E	PARTICIPANT	\N	PRESENT	0
515280	502370	20046A	PARTICIPANT	\N	PRESENT	0
515281	502370	20084G	PARTICIPANT	\N	PRESENT	0
526803	526798	19387D	PARTICIPANT	\N	PRESENT	0
526804	526798	19551W	PARTICIPANT	\N	PRESENT	0
526805	526798	20102Q	PARTICIPANT	\N	PRESENT	0
526806	526798	20136B	PARTICIPANT	\N	PRESENT	0
526808	526807	08060W	PARTICIPANT	\N	PRESENT	0
526809	526807	05012A	PARTICIPANT	\N	PRESENT	0
526810	526807	20100N	PARTICIPANT	\N	PRESENT	0
526811	526807	19551W	PARTICIPANT	\N	PRESENT	0
526812	526807	20102Q	PARTICIPANT	\N	PRESENT	0
526813	526807	20136B	PARTICIPANT	\N	PRESENT	0
526814	526739	19699S	PARTICIPANT	\N	PRESENT	0
526816	526815	19651A	PARTICIPANT	\N	PRESENT	0
526922	526921	05008E	PARTICIPANT	\N	PRESENT	0
526923	526921	11053K	PARTICIPANT	\N	PRESENT	0
527047	527046	07033P	PARTICIPANT	\N	PRESENT	1
527048	527046	14109K	PARTICIPANT	\N	PRESENT	1
527091	522158	11109J	PARTICIPANT	\N	PRESENT	0
527092	522158	19577H	PARTICIPANT	\N	PRESENT	0
527093	522158	97011G	PARTICIPANT	\N	PRESENT	0
527094	522158	20034V	PARTICIPANT	\N	PRESENT	0
527095	522158	19715Y	PARTICIPANT	\N	PRESENT	0
527096	522158	14097Y	PARTICIPANT	\N	PRESENT	0
527097	522158	14059S	PARTICIPANT	\N	EXCUSE	0
527098	522158	19657G	PARTICIPANT	\N	PRESENT	0
527099	522158	14147R	PARTICIPANT	\N	PRESENT	0
527100	522158	19301E	PARTICIPANT	\N	PRESENT	0
527574	526491	19545Y	PARTICIPANT	\N	PRESENT	1
527575	526491	04086Q	PARTICIPANT	\N	PRESENT	1
527576	526491	19647E	PARTICIPANT	\N	PRESENT	1
527577	526491	14121F	PARTICIPANT	\N	PRESENT	1
527578	526491	19531S	PARTICIPANT	\N	PRESENT	1
527579	526491	99004R	PARTICIPANT	\N	PRESENT	1
527580	526491	08010L	PARTICIPANT	\N	PRESENT	1
527581	526491	19671E	PARTICIPANT	\N	PRESENT	1
527582	526491	20050V	PARTICIPANT	\N	PRESENT	1
527583	526491	20150Y	PARTICIPANT	\N	PRESENT	1
527675	526487	11033F	PARTICIPANT	\N	PRESENT	1
527676	526487	20114U	PARTICIPANT	\N	PRESENT	1
527677	526487	14053L	PARTICIPANT	\N	PRESENT	1
527572	526491	19741B	PARTICIPANT	\N	PRESENT	1
527573	526491	14083S	PARTICIPANT	\N	PRESENT	1
527678	526487	19629C	PARTICIPANT	\N	PRESENT	1
527679	526487	14215L	PARTICIPANT	\N	PRESENT	1
527680	526487	19489J	PARTICIPANT	\N	PRESENT	1
527681	526487	19649G	PARTICIPANT	\N	PRESENT	1
527682	526487	11072N	PARTICIPANT	\N	PRESENT	1
527683	526487	14107H	PARTICIPANT	\N	PRESENT	1
527684	526487	19675J	PARTICIPANT	\N	PRESENT	1
527685	526487	14069U	PARTICIPANT	\N	PRESENT	1
527703	526490	04085P	PARTICIPANT	\N	PRESENT	1
527704	526490	11033F	PARTICIPANT	\N	PRESENT	1
527705	526490	04008A	PARTICIPANT	\N	PRESENT	1
527706	526490	19649G	PARTICIPANT	\N	PRESENT	1
527707	526490	19675J	PARTICIPANT	\N	PRESENT	1
527708	526490	19585H	PARTICIPANT	\N	PRESENT	1
527709	526490	14229S	PARTICIPANT	\N	PRESENT	1
527829	526489	04085P	PARTICIPANT	\N	PRESENT	1
527868	526489	20110Q	PARTICIPANT	\N	PRESENT	1
527871	526489	14069U	PARTICIPANT	\N	PRESENT	1
527872	526489	14151M	PARTICIPANT	\N	PRESENT	1
527873	526489	19649G	PARTICIPANT	\N	PRESENT	1
527875	526489	01028R	PARTICIPANT	\N	PRESENT	1
527923	526489	04008A	PARTICIPANT	\N	EXCUSE	0
527926	526487	04008A	PARTICIPANT	\N	EXCUSE	0
528027	528026	14249W	PARTICIPANT	\N	PRESENT	0
528628	526222	05012A	PARTICIPANT	\N	EXCUSE	0
528629	526222	19489J	PARTICIPANT	\N	EXCUSE	0
528630	526222	14257W	PARTICIPANT	\N	EXCUSE	0
528671	528669	14033T	PARTICIPANT	\N	PRESENT	0
528672	528669	14205J	PARTICIPANT	\N	PRESENT	0
528673	528669	20062A	PARTICIPANT	\N	PRESENT	0
528674	528669	14207L	PARTICIPANT	\N	PRESENT	0
528675	528669	20174H	PARTICIPANT	\N	PRESENT	0
528677	528670	14033T	PARTICIPANT	\N	PRESENT	0
528678	528670	14205J	PARTICIPANT	\N	PRESENT	0
528679	528670	14207L	PARTICIPANT	\N	PRESENT	0
528699	528696	14033T	PARTICIPANT	\N	PRESENT	0
528700	528696	14038Y	PARTICIPANT	\N	PRESENT	0
528701	528697	14033T	PARTICIPANT	\N	PRESENT	0
528702	528697	04045F	PARTICIPANT	\N	PRESENT	0
528703	528697	20018V	PARTICIPANT	\N	PRESENT	0
528704	528698	14033T	PARTICIPANT	\N	PRESENT	0
528720	526222	08010L	PARTICIPANT	\N	EXCUSE	0
528803	519136	14189C	PARTICIPANT	\N	PRESENT	0
528804	519136	14030Q	PRESIDENT	0	PRESENT	0
528805	519136	20080C	PARTICIPANT	\N	EXCUSE	0
528806	519136	11031D	PARTICIPANT	\N	EXCUSE	0
528807	519136	19693L	PARTICIPANT	\N	PRESENT	0
528808	519136	20106U	PARTICIPANT	\N	PRESENT	0
528809	519136	14179A	PARTICIPANT	\N	PRESENT	0
528810	519136	20066E	PARTICIPANT	\N	PRESENT	0
528811	519136	20056C	PARTICIPANT	\N	PRESENT	0
528812	519136	14109K	PARTICIPANT	\N	PRESENT	0
528813	519136	20130U	PARTICIPANT	\N	PRESENT	0
528814	519136	19798U	PARTICIPANT	\N	PRESENT	0
528815	519136	19749K	PARTICIPANT	\N	PRESENT	0
528820	528819	14331P	PARTICIPANT	\N	PRESENT	0
528987	526222	20122U	PARTICIPANT	\N	PRESENT	0
528988	526222	20022R	PARTICIPANT	\N	PRESENT	0
528989	526222	19735D	PARTICIPANT	\N	PRESENT	0
528990	526222	14069U	PARTICIPANT	\N	PRESENT	0
528991	526222	19349W	PARTICIPANT	\N	PRESENT	0
528992	526222	14229S	PARTICIPANT	\N	PRESENT	0
528993	526222	04086Q	PARTICIPANT	\N	PRESENT	0
528994	526222	20090E	PARTICIPANT	\N	PRESENT	0
528995	526222	01057W	PARTICIPANT	\N	PRESENT	0
528996	526222	17637T	PARTICIPANT	\N	PRESENT	0
528997	526222	20110Q	PARTICIPANT	\N	PRESENT	0
528998	526222	14071N	PARTICIPANT	\N	EXCUSE	0
529001	529000	20108W	PARTICIPANT	\N	PRESENT	0
529033	529032	14193X	PARTICIPANT	\N	PRESENT	0
529034	529032	11027H	PARTICIPANT	\N	PRESENT	0
529046	527026	04070G	PARTICIPANT	\N	PRESENT	0
529047	527026	14169X	PARTICIPANT	\N	PRESENT	0
529067	529007	11010L	PARTICIPANT	\N	EXCUSE	0
529068	519320	01028R	PARTICIPANT	\N	PRESENT	0
529069	522659	01028R	PARTICIPANT	\N	PRESENT	0
529073	529072	01048V	PARTICIPANT	\N	PRESENT	0
529075	529074	01048V	PARTICIPANT	\N	PRESENT	0
529079	529078	01048V	PARTICIPANT	\N	PRESENT	0
529091	527033	14259Y	PRESIDENT	0	PRESENT	0
529092	527033	11097X	PARTICIPANT	\N	PRESENT	0
529097	527033	14237S	PARTICIPANT	\N	EXCUSE	0
529120	529119	04042C	PARTICIPANT	\N	PRESENT	0
529121	529119	12028B	PARTICIPANT	\N	PRESENT	0
529155	527033	20144B	PARTICIPANT	\N	PRESENT	0
529202	529201	05008E	PARTICIPANT	\N	PRESENT	0
529203	529201	11053K	PARTICIPANT	\N	PRESENT	0
529204	529201	01028R	PARTICIPANT	\N	PRESENT	0
529231	529230	11072N	PARTICIPANT	\N	PRESENT	0
529232	529230	14069U	PARTICIPANT	\N	PRESENT	0
529234	529233	14069U	PARTICIPANT	\N	PRESENT	0
529235	529233	11072N	PARTICIPANT	\N	PRESENT	0
529237	529236	14069U	PARTICIPANT	\N	PRESENT	0
529238	529236	11072N	PARTICIPANT	\N	PRESENT	0
529807	529167	19295A	PARTICIPANT	\N	EXCUSE	0
529808	529167	19551W	PARTICIPANT	\N	EXCUSE	0
529980	529228	19593H	PARTICIPANT	\N	PRESENT	0
529981	529228	17589D	PARTICIPANT	\N	PRESENT	0
529983	529228	19399H	PARTICIPANT	\N	PRESENT	0
529984	529228	14073Q	PARTICIPANT	\N	PRESENT	0
529985	529228	14030Q	PARTICIPANT	\N	PRESENT	0
529986	529228	20098N	PARTICIPANT	\N	PRESENT	0
529987	529228	19693L	PARTICIPANT	\N	PRESENT	0
529988	529228	19611R	PRESIDENT	0	PRESENT	0
529989	529228	08012N	PARTICIPANT	\N	PRESENT	0
529990	529228	19651A	PARTICIPANT	\N	PRESENT	0
529994	529993	20104S	PARTICIPANT	\N	PRESENT	0
529995	529993	19521Q	PARTICIPANT	\N	PRESENT	0
529996	529993	19820Y	PARTICIPANT	\N	PRESENT	0
529997	529993	20038A	PARTICIPANT	\N	PRESENT	0
529998	529993	20094J	PARTICIPANT	\N	PRESENT	0
530000	529999	20104S	PARTICIPANT	\N	PRESENT	0
530001	529999	19521Q	PARTICIPANT	\N	PRESENT	0
530002	529999	19820Y	PARTICIPANT	\N	PRESENT	0
530003	529999	20038A	PARTICIPANT	\N	PRESENT	0
530004	529999	20094J	PARTICIPANT	\N	PRESENT	0
530097	529228	08061X	PARTICIPANT	\N	PRESENT	0
530098	529228	11043H	PARTICIPANT	\N	PRESENT	0
530099	529228	14229S	PARTICIPANT	\N	PRESENT	0
530100	529228	19573D	PARTICIPANT	\N	PRESENT	0
515101	514758	04043D	PARTICIPANT	\N	PRESENT	0
515103	514758	19723Y	PARTICIPANT	\N	PRESENT	0
515104	514758	19735D	PARTICIPANT	\N	PRESENT	0
515107	514758	20128B	PARTICIPANT	\N	PRESENT	0
515108	514758	01058X	PARTICIPANT	\N	PRESENT	0
515109	514758	11067R	PARTICIPANT	\N	EXCUSE	0
515216	514758	19563B	PARTICIPANT	\N	EXCUSE	0
515217	514758	19693L	PARTICIPANT	\N	EXCUSE	0
515218	514758	01048V	PARTICIPANT	\N	EXCUSE	0
515948	514129	19533U	PARTICIPANT	\N	PRESENT	0
515949	514129	01058X	PARTICIPANT	\N	PRESENT	0
515951	514129	01048V	PARTICIPANT	\N	PRESENT	0
515953	514129	19503N	PARTICIPANT	\N	PRESENT	0
515954	514129	04043D	PARTICIPANT	\N	PRESENT	0
515961	514129	19593H	PARTICIPANT	\N	PRESENT	0
515962	514129	11067R	PARTICIPANT	\N	PRESENT	0
515963	514129	20066E	PARTICIPANT	\N	PRESENT	0
515964	514129	19569H	PARTICIPANT	\N	PRESENT	0
515968	514129	19693L	PARTICIPANT	\N	EXCUSE	0
515969	514129	19563B	PARTICIPANT	\N	EXCUSE	0
515976	514129	19735D	PARTICIPANT	\N	PRESENT	0
515990	514129	20128B	PARTICIPANT	\N	PRESENT	0
515998	514129	19709B	PARTICIPANT	\N	PRESENT	0
516123	514757	19723Y	PARTICIPANT	\N	PRESENT	0
516126	514757	19735D	PARTICIPANT	\N	PRESENT	0
516128	514757	19533U	PARTICIPANT	\N	PRESENT	0
516129	514757	01048V	PARTICIPANT	\N	PRESENT	0
516134	514757	20066E	PARTICIPANT	\N	PRESENT	0
516139	514757	01058X	PARTICIPANT	\N	PRESENT	0
516150	514757	19693L	PARTICIPANT	\N	EXCUSE	0
516151	514757	19563B	PARTICIPANT	\N	EXCUSE	0
517103	517102	05008E	PARTICIPANT	\N	PRESENT	0
517104	517102	11053K	PARTICIPANT	\N	PRESENT	0
517105	517102	01028R	PARTICIPANT	\N	PRESENT	0
518385	518384	11040E	PARTICIPANT	\N	PRESENT	0
518387	518384	14069U	PARTICIPANT	\N	PRESENT	0
518388	518384	19643A	PARTICIPANT	\N	PRESENT	0
518389	518384	14147R	PARTICIPANT	\N	PRESENT	0
518390	518384	92040Q	PARTICIPANT	\N	PRESENT	0
521403	518674	20022R	PARTICIPANT	\N	PRESENT	0
521404	518674	20110Q	PARTICIPANT	\N	PRESENT	0
521405	518674	19758L	PARTICIPANT	\N	PRESENT	0
521406	518674	20090E	PARTICIPANT	\N	PRESENT	0
521407	518674	14187A	PARTICIPANT	\N	PRESENT	0
521408	518674	19333N	PARTICIPANT	\N	PRESENT	0
521409	518674	08010L	PARTICIPANT	\N	PRESENT	0
521410	518674	14071N	PARTICIPANT	\N	PRESENT	0
521411	518674	17637T	PARTICIPANT	\N	PRESENT	0
521412	518674	05012A	PARTICIPANT	\N	PRESENT	0
521413	518674	19349W	PARTICIPANT	\N	PRESENT	0
521414	518674	14229S	PARTICIPANT	\N	PRESENT	0
521415	518674	14107H	PARTICIPANT	\N	PRESENT	0
521416	518674	20084G	PARTICIPANT	\N	PRESENT	0
521417	518674	20122U	PARTICIPANT	\N	PRESENT	0
521418	518674	20058E	PARTICIPANT	\N	PRESENT	0
521419	518674	19711U	PARTICIPANT	\N	PRESENT	0
521422	518674	04045F	PARTICIPANT	\N	PRESENT	0
521437	521436	19954N	PARTICIPANT	\N	PRESENT	0
521438	521436	14030Q	PARTICIPANT	\N	PRESENT	0
521439	521436	20138D	PARTICIPANT	\N	PRESENT	0
521440	521436	19643A	PARTICIPANT	\N	PRESENT	0
521441	521436	20114U	PARTICIPANT	\N	PRESENT	0
521442	521436	19621T	PARTICIPANT	\N	PRESENT	0
521443	521436	14255U	PARTICIPANT	\N	PRESENT	0
521444	521436	04086Q	PARTICIPANT	\N	PRESENT	0
521445	521436	10006L	PARTICIPANT	\N	PRESENT	0
521446	521436	14231L	PARTICIPANT	\N	PRESENT	0
521447	521436	11083R	PARTICIPANT	\N	PRESENT	0
521448	521436	14179A	PARTICIPANT	\N	PRESENT	0
521449	521436	19591F	PARTICIPANT	\N	PRESENT	0
521450	521436	99004R	PARTICIPANT	\N	PRESENT	0
521451	521436	19611R	PARTICIPANT	\N	PRESENT	0
521452	521436	08015R	PARTICIPANT	\N	PRESENT	0
521453	521436	19711U	PARTICIPANT	\N	PRESENT	0
521454	521436	19709B	PARTICIPANT	\N	PRESENT	0
521455	521436	20052X	PARTICIPANT	\N	PRESENT	0
521456	521436	19573D	PARTICIPANT	\N	PRESENT	0
521457	521436	14225N	PARTICIPANT	\N	PRESENT	0
521458	521436	10015M	PARTICIPANT	\N	PRESENT	0
521459	521436	19705W	PARTICIPANT	\N	PRESENT	0
521460	521436	11012A	PARTICIPANT	\N	PRESENT	0
521461	521436	11043H	PARTICIPANT	\N	PRESENT	0
521462	521436	04045F	PARTICIPANT	\N	PRESENT	0
521463	521436	01028R	PARTICIPANT	\N	PRESENT	0
521464	521436	20122U	PARTICIPANT	\N	PRESENT	0
521829	519786	19649G	PARTICIPANT	\N	PRESENT	1
521830	519786	14147R	PARTICIPANT	\N	PRESENT	1
521840	519602	01048V	PARTICIPANT	\N	PRESENT	0
521878	521875	19701S	PARTICIPANT	\N	PRESENT	0
521879	521875	19739H	PARTICIPANT	\N	PRESENT	0
521880	521875	19549D	PARTICIPANT	\N	PRESENT	0
521882	521875	19387D	PARTICIPANT	\N	PRESENT	0
521883	521875	19820Y	PARTICIPANT	\N	PRESENT	0
521884	521875	14031R	PARTICIPANT	\N	PRESENT	0
521885	521875	20124W	PARTICIPANT	\N	PRESENT	0
521886	521875	14073Q	PARTICIPANT	\N	PRESENT	0
521887	521875	20032T	PARTICIPANT	\N	PRESENT	0
521888	521875	01024M	PARTICIPANT	\N	PRESENT	0
521889	521875	20100N	PARTICIPANT	\N	PRESENT	0
521890	521875	20038A	PARTICIPANT	\N	PRESENT	0
522667	521574	19866P	PARTICIPANT	\N	PRESENT	1
522671	521574	19745F	PARTICIPANT	\N	PRESENT	0
526293	521651	08060W	PARTICIPANT	\N	EXCUSE	0
526294	521651	08028W	PARTICIPANT	\N	EXCUSE	0
526295	521651	20040T	PARTICIPANT	\N	EXCUSE	0
526296	521651	14026U	PARTICIPANT	\N	EXCUSE	0
526297	521651	20054A	PARTICIPANT	\N	EXCUSE	0
534332	534331	08018U	PARTICIPANT	\N	PRESENT	0
534333	534331	01028R	PARTICIPANT	\N	PRESENT	0
534335	534334	08018U	PARTICIPANT	\N	PRESENT	0
534336	534282	01028R	PARTICIPANT	\N	PRESENT	0
534409	534229	19631V	PARTICIPANT	\N	PRESENT	0
534410	534229	14069U	PARTICIPANT	\N	PRESENT	0
534411	534229	20088L	PARTICIPANT	\N	PRESENT	0
534412	534229	14083S	PARTICIPANT	\N	PRESENT	0
534413	534229	14327T	PARTICIPANT	\N	PRESENT	0
534414	534229	20066E	PARTICIPANT	\N	PRESENT	0
534415	534229	11067R	PARTICIPANT	\N	PRESENT	0
534416	534229	19479G	PARTICIPANT	\N	PRESENT	0
534417	534229	20064C	PARTICIPANT	\N	PRESENT	0
535971	534225	20128B	PARTICIPANT	\N	PRESENT	1
535976	534225	14097Y	PARTICIPANT	\N	PRESENT	1
535982	534225	95041E	PARTICIPANT	\N	PRESENT	0
535986	534225	16685X	PARTICIPANT	\N	PRESENT	0
535993	534225	08047A	PARTICIPANT	\N	PRESENT	0
535995	534225	14193X	PARTICIPANT	\N	PRESENT	0
535999	534225	19443T	PARTICIPANT	\N	PRESENT	1
536004	534225	11054L	PARTICIPANT	\N	PRESENT	0
536005	534225	19421M	PARTICIPANT	\N	PRESENT	1
536011	534225	01058X	PARTICIPANT	\N	PRESENT	0
536012	534225	19669L	PARTICIPANT	\N	PRESENT	1
536014	534225	01062T	PARTICIPANT	\N	PRESENT	1
536015	534225	20064C	PARTICIPANT	\N	PRESENT	0
536016	534225	11041F	PARTICIPANT	\N	PRESENT	1
536017	534225	11066Q	PARTICIPANT	\N	PRESENT	0
536018	534225	04034C	PARTICIPANT	\N	PRESENT	1
536045	531551	20148F	PRESIDENT	0	PRESENT	0
536046	531551	11090Q	PARTICIPANT	\N	PRESENT	0
536076	536075	20032T	PARTICIPANT	\N	PRESENT	0
536077	536075	14189C	PARTICIPANT	\N	PRESENT	0
536078	536075	20076G	PARTICIPANT	\N	PRESENT	0
536080	536075	20024T	PARTICIPANT	\N	PRESENT	0
536083	536075	20110Q	PARTICIPANT	\N	PRESENT	0
536084	536075	19575F	PARTICIPANT	\N	PRESENT	0
536085	536075	14033T	PARTICIPANT	\N	PRESENT	0
536086	536075	14179A	PARTICIPANT	\N	PRESENT	0
536087	536075	19551W	PARTICIPANT	\N	PRESENT	0
536088	536075	19723Y	PARTICIPANT	\N	PRESENT	0
533304	531322	19735D	PARTICIPANT	\N	EXCUSE	0
539547	538123	11033F	PARTICIPANT	\N	EXCUSE	0
539557	539556	14038Y	PARTICIPANT	\N	PRESENT	0
539558	539556	20060X	PARTICIPANT	\N	PRESENT	0
539560	539559	14038Y	PARTICIPANT	\N	PRESENT	0
539562	539561	14038Y	PARTICIPANT	\N	PRESENT	0
539563	539561	19441R	PARTICIPANT	\N	PRESENT	0
539565	539564	14038Y	PARTICIPANT	\N	PRESENT	0
539566	539564	19441R	PARTICIPANT	\N	PRESENT	0
539574	539573	11040E	PARTICIPANT	\N	PRESENT	0
539575	539573	19295A	PARTICIPANT	\N	PRESENT	0
539576	539573	11027H	PARTICIPANT	\N	PRESENT	0
539577	539573	19565D	PARTICIPANT	\N	PRESENT	0
539578	539573	20148F	PARTICIPANT	\N	PRESENT	0
539579	539573	20046A	PARTICIPANT	\N	PRESENT	0
539580	539573	19585H	PARTICIPANT	\N	PRESENT	0
539582	539581	11027H	PARTICIPANT	\N	PRESENT	0
540466	537909	19679N	PARTICIPANT	\N	PRESENT	0
540504	537909	04057K	PARTICIPANT	\N	PRESENT	0
540505	537909	19657G	PARTICIPANT	\N	PRESENT	0
540549	535603	18083K	PARTICIPANT	\N	PRESENT	0
540550	535603	20034V	PARTICIPANT	\N	PRESENT	0
540551	535603	19715Y	PARTICIPANT	\N	PRESENT	0
540552	535603	08034U	PARTICIPANT	\N	PRESENT	0
540553	535603	14147R	PARTICIPANT	\N	PRESENT	0
540554	535603	19301E	PARTICIPANT	\N	PRESENT	0
540555	535603	12016W	PARTICIPANT	\N	PRESENT	0
540556	535603	08073C	PARTICIPANT	\N	PRESENT	0
540563	535603	17023S	PARTICIPANT	\N	PRESENT	0
541316	537784	20094J	PARTICIPANT	\N	PRESENT	1
541317	537784	19301E	PARTICIPANT	\N	PRESENT	1
541318	537784	11103C	PARTICIPANT	\N	PRESENT	1
541319	537784	04043D	PARTICIPANT	\N	PRESENT	1
541320	537910	11090Q	PARTICIPANT	\N	PRESENT	0
541321	539069	20080C	PARTICIPANT	\N	PRESENT	0
541322	539069	01048V	PARTICIPANT	\N	PRESENT	0
541323	537784	19575F	PARTICIPANT	\N	PRESENT	1
541324	537784	19747H	PARTICIPANT	\N	PRESENT	0
541325	538375	18193Q	PARTICIPANT	\N	PRESENT	1
541326	538375	19679N	PARTICIPANT	\N	PRESENT	1
541327	537910	19575F	PARTICIPANT	\N	PRESENT	1
541333	538123	19699S	PARTICIPANT	\N	PRESENT	1
541334	539069	14225N	PRESIDENT	0	PRESENT	0
541335	539069	11012A	PARTICIPANT	\N	EXCUSE	0
541344	539685	04085P	PARTICIPANT	\N	PRESENT	1
541345	539685	11033F	PARTICIPANT	\N	PRESENT	1
541346	539685	19954N	PARTICIPANT	\N	PRESENT	1
541347	539685	14069U	PARTICIPANT	\N	PRESENT	1
541348	539685	20114U	PARTICIPANT	\N	PRESENT	1
541349	539685	19489J	PARTICIPANT	\N	PRESENT	1
541350	539685	11026G	PARTICIPANT	\N	PRESENT	1
541351	539685	19581D	PARTICIPANT	\N	PRESENT	1
541352	539685	14107H	PARTICIPANT	\N	PRESENT	1
541353	539685	19675J	PARTICIPANT	\N	PRESENT	1
541354	539057	19333N	PARTICIPANT	\N	PRESENT	0
541355	539057	19701S	PARTICIPANT	\N	PRESENT	0
541356	539057	20076G	PARTICIPANT	\N	PRESENT	0
541357	539057	19549D	PARTICIPANT	\N	PRESENT	0
541358	539057	19387D	PARTICIPANT	\N	PRESENT	1
541359	539057	14219Q	PRESIDENT	0	PRESENT	0
541360	539057	19820Y	PARTICIPANT	\N	PRESENT	0
541361	539057	19826F	PARTICIPANT	\N	PRESENT	0
541362	539057	19599P	PARTICIPANT	\N	PRESENT	0
541363	539057	20096L	PARTICIPANT	\N	PRESENT	0
541364	539057	19637C	PARTICIPANT	\N	PRESENT	0
541365	539057	18083K	PARTICIPANT	\N	PRESENT	1
541366	539057	19551W	PARTICIPANT	\N	PRESENT	0
541367	539057	20100N	PARTICIPANT	\N	PRESENT	1
541368	539057	14237S	PARTICIPANT	\N	PRESENT	0
541369	539057	20106U	PARTICIPANT	\N	PRESENT	1
541370	539057	20118Y	PARTICIPANT	\N	PRESENT	0
541371	539057	19503N	PARTICIPANT	\N	PRESENT	0
541372	539057	20020P	PARTICIPANT	\N	PRESENT	0
541373	539057	19685L	PARTICIPANT	\N	PRESENT	0
541374	539057	17367Q	PARTICIPANT	\N	PRESENT	0
541375	539057	19681G	PARTICIPANT	\N	PRESENT	0
541376	539057	20024T	PARTICIPANT	\N	PRESENT	0
541377	539057	11065P	PARTICIPANT	\N	PRESENT	0
541378	539057	20032T	PARTICIPANT	\N	PRESENT	1
541379	539057	20136B	PARTICIPANT	\N	PRESENT	0
541380	539057	14031R	PARTICIPANT	\N	PRESENT	0
541381	539057	20140W	PARTICIPANT	\N	PRESENT	1
541382	539057	14169X	PARTICIPANT	\N	PRESENT	0
541383	539057	17229F	PARTICIPANT	\N	PRESENT	0
541384	539057	20068G	PARTICIPANT	\N	PRESENT	1
541385	539057	20038A	PARTICIPANT	\N	EXCUSE	0
541390	539685	20074E	PARTICIPANT	\N	EXCUSE	0
541405	539550	20108W	PARTICIPANT	\N	PRESENT	0
541426	539550	19479G	PARTICIPANT	\N	PRESENT	0
541407	539686	10015M	PARTICIPANT	\N	PRESENT	0
541408	539686	19543W	PARTICIPANT	\N	PRESENT	0
541409	539686	04047H	PRESIDENT	0	PRESENT	0
541410	539686	19673G	PARTICIPANT	\N	PRESENT	0
541411	539686	11033F	PARTICIPANT	\N	PRESENT	0
541412	539686	01028R	PARTICIPANT	\N	PRESENT	0
541413	539686	19447X	PARTICIPANT	\N	PRESENT	0
541414	539686	14231L	PARTICIPANT	\N	PRESENT	0
541415	539686	95063L	PARTICIPANT	\N	PRESENT	0
541416	539686	20110Q	PARTICIPANT	\N	PRESENT	0
541417	539686	14147R	PARTICIPANT	\N	PRESENT	0
541418	539686	14179A	PARTICIPANT	\N	PRESENT	0
541419	539686	14151M	PARTICIPANT	\N	PRESENT	0
541420	539686	14215L	PARTICIPANT	\N	PRESENT	0
541421	539686	08018U	PARTICIPANT	\N	PRESENT	0
541422	539686	04008A	PARTICIPANT	\N	PRESENT	0
541423	539686	19749K	PARTICIPANT	\N	PRESENT	0
541424	539686	11072N	PARTICIPANT	\N	PRESENT	0
541425	539550	20024T	PARTICIPANT	\N	PRESENT	0
541427	539550	20056C	PARTICIPANT	\N	PRESENT	0
541428	539550	20180F	PARTICIPANT	\N	PRESENT	0
541429	539550	20032T	PARTICIPANT	\N	PRESENT	0
541430	539550	20052X	PARTICIPANT	\N	PRESENT	0
541431	539550	19966S	PARTICIPANT	\N	PRESENT	0
541432	539550	20136B	PARTICIPANT	\N	PRESENT	0
541433	539550	92040Q	PARTICIPANT	\N	PRESENT	0
541435	539550	14267Y	PARTICIPANT	\N	PRESENT	0
541440	539550	17737W	PARTICIPANT	\N	PRESENT	0
541441	539550	20020P	PARTICIPANT	\N	PRESENT	0
541442	539550	19593H	PARTICIPANT	\N	PRESENT	0
541443	539550	08056B	PARTICIPANT	\N	PRESENT	0
541444	539550	14223L	PARTICIPANT	\N	PRESENT	0
541445	539550	20098N	PARTICIPANT	\N	PRESENT	0
541446	539550	01048V	PARTICIPANT	\N	PRESENT	0
541448	539550	19681G	PARTICIPANT	\N	PRESENT	0
541449	539550	20102Q	PARTICIPANT	\N	PRESENT	0
541450	539550	19413M	PARTICIPANT	\N	PRESENT	0
541451	539550	20092G	PARTICIPANT	\N	PRESENT	0
541452	539550	11041F	PARTICIPANT	\N	PRESENT	0
541453	539550	19711U	PARTICIPANT	\N	PRESENT	0
541454	539550	19719D	PARTICIPANT	\N	PRESENT	0
541455	539550	14033T	PARTICIPANT	\N	PRESENT	0
541456	539550	14038Y	PARTICIPANT	\N	PRESENT	0
541459	539550	14221J	PARTICIPANT	\N	PRESENT	0
541461	539550	08073C	PARTICIPANT	\N	PRESENT	0
541462	539550	20084G	PARTICIPANT	\N	PRESENT	0
541464	539550	19333N	PARTICIPANT	\N	PRESENT	0
541465	539550	14257W	PARTICIPANT	\N	PRESENT	0
541466	539550	12016W	PARTICIPANT	\N	PRESENT	0
541467	539550	19697Q	PARTICIPANT	\N	PRESENT	0
541468	539550	11072N	PARTICIPANT	\N	PRESENT	0
541469	539550	11012A	PARTICIPANT	\N	PRESENT	0
541470	539550	19651A	PARTICIPANT	\N	PRESENT	0
541471	539550	19717B	PARTICIPANT	\N	PRESENT	0
541472	539550	19549D	PARTICIPANT	\N	PRESENT	0
541473	539550	08060W	PARTICIPANT	\N	PRESENT	0
541474	539550	12028B	PARTICIPANT	\N	PRESENT	0
541475	539550	11027H	PARTICIPANT	\N	PRESENT	0
541476	539550	14229S	PARTICIPANT	\N	PRESENT	0
541477	539550	20142Y	PARTICIPANT	\N	PRESENT	0
541478	539550	19531S	PARTICIPANT	\N	PRESENT	0
541479	539550	14121F	PARTICIPANT	\N	PRESENT	0
541480	539550	11080N	PARTICIPANT	\N	PRESENT	0
541481	539550	08028W	PARTICIPANT	\N	PRESENT	0
541482	539550	08069G	PARTICIPANT	\N	PRESENT	0
541310	537784	04057K	PARTICIPANT	\N	PRESENT	1
541311	537784	19663E	PARTICIPANT	\N	PRESENT	1
541312	537784	19697Q	PARTICIPANT	\N	PRESENT	1
541313	537784	19717B	PARTICIPANT	\N	PRESENT	1
541314	537784	19657G	PARTICIPANT	\N	PRESENT	1
541315	537784	19760E	PARTICIPANT	\N	PRESENT	1
515282	502370	19826F	PARTICIPANT	\N	PRESENT	0
515283	502370	11066Q	PARTICIPANT	\N	PRESENT	0
515284	502370	19503N	PARTICIPANT	\N	PRESENT	0
515285	502370	14225N	PARTICIPANT	\N	PRESENT	0
515286	502370	20116W	PARTICIPANT	\N	PRESENT	0
515287	502370	11097X	PARTICIPANT	\N	PRESENT	0
515288	502370	19621T	PARTICIPANT	\N	PRESENT	0
515289	502370	20104S	PARTICIPANT	\N	PRESENT	0
515290	502370	19715Y	PARTICIPANT	\N	PRESENT	0
515291	502370	14151M	PARTICIPANT	\N	PRESENT	0
515292	502370	19649G	PARTICIPANT	\N	PRESENT	0
515293	502370	20144B	PARTICIPANT	\N	PRESENT	0
515294	502370	20018V	PARTICIPANT	\N	PRESENT	0
515295	502370	20022R	PARTICIPANT	\N	PRESENT	0
515296	502370	14217N	PARTICIPANT	\N	PRESENT	0
515297	502370	08034U	PARTICIPANT	\N	PRESENT	0
515298	502370	19768N	PARTICIPANT	\N	PRESENT	0
515299	502370	19443T	PARTICIPANT	\N	PRESENT	0
515300	502370	19599P	PARTICIPANT	\N	PRESENT	0
515301	502370	19521Q	PARTICIPANT	\N	PRESENT	0
515302	502370	19569H	PARTICIPANT	\N	PRESENT	0
515303	502370	04085P	PARTICIPANT	\N	PRESENT	0
515304	502370	08061X	PARTICIPANT	\N	PRESENT	0
515305	502370	19531S	PARTICIPANT	\N	PRESENT	0
515306	502370	08060W	PARTICIPANT	\N	PRESENT	0
515307	502370	19747H	PARTICIPANT	\N	PRESENT	0
515308	502370	01058X	PARTICIPANT	\N	PRESENT	0
515309	502370	19673G	PARTICIPANT	\N	PRESENT	0
515310	502370	19543W	PARTICIPANT	\N	PRESENT	0
515311	502370	04070G	PARTICIPANT	\N	PRESENT	0
515312	502370	19719D	PARTICIPANT	\N	PRESENT	0
515313	502370	01028R	PARTICIPANT	\N	PRESENT	0
515314	502370	20092G	PARTICIPANT	\N	PRESENT	0
515315	502370	04034C	PARTICIPANT	\N	PRESENT	0
515316	502370	17779H	PARTICIPANT	\N	PRESENT	0
515317	502370	95063L	PARTICIPANT	\N	PRESENT	0
515318	502370	20128B	PARTICIPANT	\N	PRESENT	0
515319	502370	20106U	PARTICIPANT	\N	PRESENT	0
515320	502370	11083R	PARTICIPANT	\N	PRESENT	0
515321	502370	19782L	PARTICIPANT	\N	PRESENT	0
515322	502370	20110Q	PARTICIPANT	\N	PRESENT	0
515323	502370	20132W	PARTICIPANT	\N	PRESENT	0
515324	502370	19387D	PARTICIPANT	\N	PRESENT	0
515325	502370	19966S	PARTICIPANT	\N	PRESENT	0
515326	502370	20150Y	PARTICIPANT	\N	PRESENT	0
515327	502370	14038Y	PARTICIPANT	\N	PRESENT	0
515328	502370	19563B	PARTICIPANT	\N	PRESENT	0
515329	502370	19585H	PARTICIPANT	\N	PRESENT	0
515330	502370	04008A	PARTICIPANT	\N	PRESENT	0
515331	502370	04092N	PARTICIPANT	\N	PRESENT	0
515332	502370	14069U	PARTICIPANT	\N	PRESENT	0
515333	502370	14211G	PARTICIPANT	\N	PRESENT	0
515334	502370	19711U	PARTICIPANT	\N	PRESENT	0
515335	502370	04059M	PARTICIPANT	\N	PRESENT	0
515336	502370	04047H	PARTICIPANT	\N	PRESENT	0
515337	502370	20060X	PARTICIPANT	\N	PRESENT	0
515338	502370	11041F	PARTICIPANT	\N	PRESENT	0
515339	502370	11067R	PARTICIPANT	\N	PRESENT	0
515340	502370	19687N	PARTICIPANT	\N	PRESENT	0
515341	502370	04042C	PARTICIPANT	\N	PRESENT	0
515342	502370	14123H	PARTICIPANT	\N	PRESENT	0
515343	502370	17965H	PARTICIPANT	\N	PRESENT	0
515344	502370	14109K	PARTICIPANT	\N	PRESENT	0
515345	502370	01057W	PARTICIPANT	\N	PRESENT	0
515346	502370	10015M	PARTICIPANT	\N	PRESENT	0
515347	502370	14021P	PARTICIPANT	\N	PRESENT	0
515348	502370	04033B	PARTICIPANT	\N	PRESENT	0
515349	502370	14187A	PARTICIPANT	\N	PRESENT	0
515350	502370	20140W	PARTICIPANT	\N	PRESENT	0
515351	502370	01048V	PARTICIPANT	\N	PRESENT	0
515352	502370	14071N	PARTICIPANT	\N	PRESENT	0
515353	502370	19647E	PARTICIPANT	\N	PRESENT	0
515354	502370	20080C	PARTICIPANT	\N	PRESENT	0
515355	502370	14121F	PARTICIPANT	\N	PRESENT	0
515356	502370	04043D	PARTICIPANT	\N	PRESENT	0
515357	502370	11080N	PARTICIPANT	\N	PRESENT	0
515358	502370	19527W	PARTICIPANT	\N	PRESENT	0
515359	502370	14219Q	PARTICIPANT	\N	PRESENT	0
515360	502370	20088L	PARTICIPANT	\N	PRESENT	0
515361	502370	19515S	PARTICIPANT	\N	PRESENT	0
515362	502370	14189C	PARTICIPANT	\N	PRESENT	0
515363	502370	14179A	PARTICIPANT	\N	PRESENT	0
515364	502370	19611R	PARTICIPANT	\N	PRESENT	0
515365	502370	01024M	PARTICIPANT	\N	PRESENT	0
515366	502370	14031R	PARTICIPANT	\N	PRESENT	0
515367	502370	16685X	PARTICIPANT	\N	PRESENT	0
515368	502370	14253S	PARTICIPANT	\N	PRESENT	0
515369	502370	19479G	PARTICIPANT	\N	PRESENT	0
515370	502370	11048N	PARTICIPANT	\N	PRESENT	0
515371	502370	14083S	PARTICIPANT	\N	PRESENT	0
515372	502370	19441R	PARTICIPANT	\N	PRESENT	0
515373	502370	19347U	PARTICIPANT	\N	PRESENT	0
515374	502370	19591F	PARTICIPANT	\N	PRESENT	0
515375	502370	20048C	PARTICIPANT	\N	PRESENT	0
515376	502370	20052X	PARTICIPANT	\N	PRESENT	0
515377	502370	19671E	PARTICIPANT	\N	PRESENT	0
515378	502370	20070A	PARTICIPANT	\N	PRESENT	0
515379	502370	19762G	PARTICIPANT	\N	PRESENT	0
515380	502370	14089Y	PARTICIPANT	\N	PRESENT	0
515381	502370	14147R	PARTICIPANT	\N	PRESENT	0
515382	502370	19699S	PARTICIPANT	\N	PRESENT	0
515383	502370	11085T	PARTICIPANT	\N	PRESENT	0
515384	502370	14030Q	PARTICIPANT	\N	PRESENT	0
515385	502370	20172F	PARTICIPANT	\N	PRESENT	0
515386	502370	20040T	PARTICIPANT	\N	PRESENT	0
515427	502370	18083K	PARTICIPANT	\N	PRESENT	0
515388	502370	14169X	PARTICIPANT	\N	PRESENT	0
515389	502370	19741B	PARTICIPANT	\N	PRESENT	0
515390	502370	20066E	PARTICIPANT	\N	PRESENT	0
515391	502370	19573D	PARTICIPANT	\N	PRESENT	0
515418	502370	20044X	PARTICIPANT	\N	PRESENT	0
515416	502370	19575F	PARTICIPANT	\N	PRESENT	0
515394	502370	19447X	PARTICIPANT	\N	PRESENT	0
515417	502370	19691J	PARTICIPANT	\N	PRESENT	0
515396	502370	04045F	PARTICIPANT	\N	PRESENT	0
515397	502370	19679N	PARTICIPANT	\N	PRESENT	0
515398	502370	19467C	PARTICIPANT	\N	PRESENT	0
515399	502370	17589D	PARTICIPANT	\N	PRESENT	0
515400	502370	20026V	PARTICIPANT	\N	PRESENT	0
515401	502370	19399H	PARTICIPANT	\N	PRESENT	0
515402	502370	97011G	PARTICIPANT	\N	PRESENT	0
515403	502370	19383Y	PARTICIPANT	\N	PRESENT	0
515404	502370	20054A	PARTICIPANT	\N	PRESENT	0
515405	502370	20126Y	PARTICIPANT	\N	PRESENT	0
515406	502370	14059S	PARTICIPANT	\N	PRESENT	0
515407	502370	08015R	PARTICIPANT	\N	PRESENT	0
515408	502370	07029T	PARTICIPANT	\N	PRESENT	0
515409	502370	19657G	PARTICIPANT	\N	PRESENT	0
515410	502370	19709B	PARTICIPANT	\N	PRESENT	0
515411	502370	20058E	PARTICIPANT	\N	PRESENT	0
515412	502370	04057K	PARTICIPANT	\N	PRESENT	0
515413	502370	14033T	PARTICIPANT	\N	PRESENT	0
515414	502370	11031D	PARTICIPANT	\N	PRESENT	0
515415	502370	20086J	PARTICIPANT	\N	PRESENT	0
515419	502370	20096L	PARTICIPANT	\N	PRESENT	0
515420	502370	05012A	PARTICIPANT	\N	PRESENT	0
515421	502370	19683J	PARTICIPANT	\N	PRESENT	0
515422	502370	14213J	PARTICIPANT	\N	PRESENT	0
515423	502370	20050V	PARTICIPANT	\N	PRESENT	0
515424	502370	18193Q	PARTICIPANT	\N	PRESENT	0
515425	502370	20042V	PARTICIPANT	\N	PRESENT	0
515426	502370	19553Y	PARTICIPANT	\N	PRESENT	0
515428	502370	20090E	PARTICIPANT	\N	PRESENT	0
515429	502370	20138D	PARTICIPANT	\N	PRESENT	0
515430	502370	19577H	PARTICIPANT	\N	PRESENT	0
515431	502370	19685L	PARTICIPANT	\N	PRESENT	0
515436	502370	86034E	PARTICIPANT	\N	PRESENT	0
515433	502370	20118Y	PARTICIPANT	\N	PRESENT	0
515434	502370	20098N	PARTICIPANT	\N	PRESENT	0
515435	502370	14251Q	PARTICIPANT	\N	PRESENT	0
515437	502370	14215L	PARTICIPANT	\N	PRESENT	0
515438	502370	19335Q	PARTICIPANT	\N	PRESENT	0
515447	502370	19713W	PARTICIPANT	\N	PRESENT	0
515453	502370	20038A	PARTICIPANT	\N	PRESENT	0
530101	529228	19621T	PARTICIPANT	\N	PRESENT	0
530102	529228	19758L	PARTICIPANT	\N	PRESENT	0
530103	529228	20124W	PARTICIPANT	\N	PRESENT	0
530104	529228	14123H	PARTICIPANT	\N	PRESENT	0
530105	529228	19735D	PARTICIPANT	\N	PRESENT	0
530106	529228	20052X	PARTICIPANT	\N	PRESENT	0
530107	529228	20142Y	PARTICIPANT	\N	PRESENT	0
530111	529228	19699S	PARTICIPANT	\N	PRESENT	0
530113	529228	20026V	PARTICIPANT	\N	PRESENT	1
530116	529228	20180F	PARTICIPANT	\N	PRESENT	1
530117	529228	20048C	PARTICIPANT	\N	PRESENT	1
530118	529228	20132W	PARTICIPANT	\N	PRESENT	1
530119	529228	14109K	PARTICIPANT	\N	PRESENT	1
530120	529228	11104D	PARTICIPANT	\N	PRESENT	1
530121	529228	04070G	PARTICIPANT	\N	PRESENT	1
530122	529228	20084G	PARTICIPANT	\N	PRESENT	1
530123	529228	19533U	PARTICIPANT	\N	PRESENT	1
530124	529228	04059M	PARTICIPANT	\N	PRESENT	1
530125	529228	08017T	PARTICIPANT	\N	PRESENT	1
530126	529228	20056C	PARTICIPANT	\N	PRESENT	1
530781	530780	14357A	PARTICIPANT	\N	PRESENT	0
530783	530780	14147R	PARTICIPANT	\N	PRESENT	0
530785	530780	19575F	PARTICIPANT	\N	PRESENT	0
530786	530780	20044X	PARTICIPANT	\N	PRESENT	0
530790	530780	19711U	PARTICIPANT	\N	PRESENT	0
530788	530780	08015R	PARTICIPANT	\N	PRESENT	0
530789	530780	08018U	PARTICIPANT	\N	PRESENT	0
530791	530780	20024T	PARTICIPANT	\N	PRESENT	0
530792	530780	14059S	PARTICIPANT	\N	PRESENT	0
530793	530780	19503N	PARTICIPANT	\N	PRESENT	0
530794	530780	19631V	PARTICIPANT	\N	PRESENT	0
530795	530780	14097Y	PARTICIPANT	\N	PRESENT	0
530798	530780	11083R	PARTICIPANT	\N	PRESENT	0
530799	530780	17023S	PARTICIPANT	\N	PRESENT	0
530800	530780	14179A	PARTICIPANT	\N	PRESENT	0
530860	530858	19515S	PARTICIPANT	\N	PRESENT	0
530861	530858	11090Q	PARTICIPANT	\N	PRESENT	0
530862	530858	19747H	PARTICIPANT	\N	PRESENT	0
530863	530858	19631V	PARTICIPANT	\N	PRESENT	0
530864	530858	19511N	PARTICIPANT	\N	PRESENT	0
530888	530887	14041T	PARTICIPANT	\N	PRESENT	0
530889	530887	08018U	PARTICIPANT	\N	PRESENT	0
530890	530887	11026G	PARTICIPANT	\N	PRESENT	0
530891	530887	19709B	PARTICIPANT	\N	PRESENT	0
530892	530887	14331P	PARTICIPANT	\N	PRESENT	0
530893	530887	11027H	PARTICIPANT	\N	PRESENT	0
530894	530887	08017T	PARTICIPANT	\N	PRESENT	0
530895	530887	04034C	PARTICIPANT	\N	PRESENT	0
530896	530887	04043D	PARTICIPANT	\N	PRESENT	0
530897	530887	14147R	PARTICIPANT	\N	PRESENT	0
530898	530887	20174H	PARTICIPANT	\N	PRESENT	0
530899	530887	14255U	PARTICIPANT	\N	PRESENT	0
530900	530887	14357A	PARTICIPANT	\N	PRESENT	0
530901	530887	04035D	PARTICIPANT	\N	PRESENT	0
531057	529007	19717B	PARTICIPANT	\N	PRESENT	0
531058	529007	19577H	PARTICIPANT	\N	PRESENT	0
531059	529007	19347U	PARTICIPANT	\N	PRESENT	0
531060	529007	20034V	PRESIDENT	0	PRESENT	0
531061	529007	19715Y	PARTICIPANT	\N	PRESENT	0
531062	529007	14059S	PARTICIPANT	\N	EXCUSE	0
531063	529007	12016W	PARTICIPANT	\N	PRESENT	0
531064	529007	14147R	PARTICIPANT	\N	PRESENT	0
531065	529007	20146D	PARTICIPANT	\N	PRESENT	0
531066	529007	19631V	PARTICIPANT	\N	PRESENT	0
531067	529007	18083K	PARTICIPANT	\N	PRESENT	0
531072	531071	11067R	PARTICIPANT	\N	EXCUSE	0
531073	531071	19735D	PARTICIPANT	\N	EXCUSE	0
531074	529007	20028X	PARTICIPANT	\N	PRESENT	0
531248	531245	20144B	PARTICIPANT	\N	PRESENT	0
531249	531246	20144B	PARTICIPANT	\N	PRESENT	0
531250	531246	14033T	PARTICIPANT	\N	PRESENT	0
531266	531263	20144B	PARTICIPANT	\N	PRESENT	0
531268	531263	14033T	PARTICIPANT	\N	PRESENT	0
531273	531272	19575F	PARTICIPANT	\N	PRESENT	0
531274	531272	10006L	PARTICIPANT	\N	PRESENT	0
531275	531272	20038A	PARTICIPANT	\N	PRESENT	0
531276	531272	08018U	PARTICIPANT	\N	PRESENT	0
531277	531272	19565D	PARTICIPANT	\N	PRESENT	0
531278	531272	14219Q	PARTICIPANT	\N	PRESENT	0
531279	531272	08012N	PARTICIPANT	\N	PRESENT	0
531280	531272	14001X	PARTICIPANT	\N	PRESENT	0
531281	531272	14071N	PARTICIPANT	\N	PRESENT	0
531282	531272	04043D	PARTICIPANT	\N	PRESENT	0
531283	531272	20084G	PARTICIPANT	\N	PRESENT	0
531284	531272	20122U	PARTICIPANT	\N	PRESENT	0
531285	531272	01058X	PARTICIPANT	\N	PRESENT	0
531290	531289	20118Y	PARTICIPANT	\N	PRESENT	0
531291	531289	19637C	PARTICIPANT	\N	PRESENT	0
531292	531289	19820Y	PARTICIPANT	\N	PRESENT	0
531293	531289	14033T	PARTICIPANT	\N	PRESENT	0
531294	531289	19507S	PARTICIPANT	\N	PRESENT	0
531295	531289	14205J	PARTICIPANT	\N	PRESENT	0
531299	531298	01025N	PARTICIPANT	\N	PRESENT	0
531300	531298	14207L	PARTICIPANT	\N	PRESENT	0
531301	531298	19507S	PARTICIPANT	\N	PRESENT	0
531302	531298	19747H	PARTICIPANT	\N	PRESENT	0
531303	531298	19782L	PARTICIPANT	\N	PRESENT	0
531304	531298	11099A	PARTICIPANT	\N	PRESENT	0
531305	531298	20028X	PARTICIPANT	\N	PRESENT	0
531306	531298	20062A	PARTICIPANT	\N	PRESENT	0
531308	531307	14207L	PARTICIPANT	\N	PRESENT	0
531309	531307	01025N	PARTICIPANT	\N	PRESENT	0
531310	531307	08015R	PARTICIPANT	\N	PRESENT	0
531311	531307	20062A	PARTICIPANT	\N	PRESENT	0
531313	531312	17367Q	PARTICIPANT	\N	PRESENT	0
531392	531391	14071N	PARTICIPANT	\N	PRESENT	0
531394	531393	14071N	PARTICIPANT	\N	PRESENT	0
531395	531391	19760E	PARTICIPANT	\N	PRESENT	0
531397	531396	07033P	PARTICIPANT	\N	PRESENT	0
531398	531396	14109K	PARTICIPANT	\N	PRESENT	0
531399	531396	20180F	PARTICIPANT	\N	PRESENT	0
531401	531400	07033P	PARTICIPANT	\N	PRESENT	0
531402	531400	14109K	PARTICIPANT	\N	PRESENT	0
531404	531403	14109K	PARTICIPANT	\N	PRESENT	0
531406	531405	07033P	PARTICIPANT	\N	PRESENT	0
531407	531405	14109K	PARTICIPANT	\N	PRESENT	0
531409	531408	19760E	PARTICIPANT	\N	PRESENT	0
531410	531408	01034P	PARTICIPANT	\N	PRESENT	0
531412	531411	20130U	PARTICIPANT	\N	PRESENT	0
531413	531411	01034P	PARTICIPANT	\N	PRESENT	0
531416	531414	11067R	PARTICIPANT	\N	PRESENT	0
531417	531415	18193Q	PARTICIPANT	\N	PRESENT	0
531418	531415	11067R	PARTICIPANT	\N	PRESENT	0
531438	531160	19533U	PARTICIPANT	\N	PRESENT	0
531436	531429	14123H	PARTICIPANT	\N	PRESENT	0
531437	531429	19533U	PARTICIPANT	\N	PRESENT	0
531439	531162	19621T	PARTICIPANT	\N	PRESENT	0
531440	531162	19533U	PARTICIPANT	\N	PRESENT	0
531441	531162	11104D	PARTICIPANT	\N	PRESENT	0
531442	531162	20098N	PARTICIPANT	\N	PRESENT	0
531443	531162	14123H	PARTICIPANT	\N	PRESENT	0
531444	531162	20152B	PARTICIPANT	\N	PRESENT	0
531445	531162	20180F	PARTICIPANT	\N	PRESENT	0
531446	531162	20124W	PARTICIPANT	\N	PRESENT	0
531447	531162	20138D	PARTICIPANT	\N	PRESENT	0
531448	531163	19593H	PARTICIPANT	\N	PRESENT	0
531449	531163	19533U	PARTICIPANT	\N	PRESENT	0
531451	531450	19533U	PARTICIPANT	\N	PRESENT	0
531452	531450	19593H	PARTICIPANT	\N	PRESENT	0
531453	531450	20098N	PARTICIPANT	\N	PRESENT	0
531454	531450	14229S	PARTICIPANT	\N	PRESENT	0
531455	531450	14030Q	PARTICIPANT	\N	PRESENT	0
531456	531450	20134Y	PARTICIPANT	\N	PRESENT	0
531457	531450	19651A	PARTICIPANT	\N	PRESENT	0
531458	531450	20056C	PARTICIPANT	\N	PRESENT	0
531460	531459	19533U	PARTICIPANT	\N	PRESENT	0
531461	531459	19593H	PARTICIPANT	\N	PRESENT	0
531462	531459	14229S	PARTICIPANT	\N	PRESENT	0
531463	531459	19611R	PARTICIPANT	\N	PRESENT	0
531464	531459	14030Q	PARTICIPANT	\N	PRESENT	0
531465	531459	19651A	PARTICIPANT	\N	PRESENT	0
531469	531467	19533U	PARTICIPANT	\N	PRESENT	0
531471	531470	14030Q	PARTICIPANT	\N	PRESENT	0
531472	531470	19533U	PARTICIPANT	\N	PRESENT	0
531473	531161	19533U	PARTICIPANT	\N	PRESENT	0
516268	514757	11067R	PARTICIPANT	\N	PRESENT	0
516269	514757	04043D	PARTICIPANT	\N	PRESENT	0
517475	517474	01048V	PARTICIPANT	\N	PRESENT	0
517477	517476	01048V	PARTICIPANT	\N	PRESENT	0
517609	517607	19782L	PARTICIPANT	\N	PRESENT	0
517610	517607	14207L	PARTICIPANT	\N	PRESENT	0
517611	517607	01025N	PARTICIPANT	\N	PRESENT	0
517612	517607	19511N	PARTICIPANT	\N	PRESENT	0
517613	517607	20144B	PARTICIPANT	\N	PRESENT	0
517614	517607	19383Y	PARTICIPANT	\N	PRESENT	0
517615	517607	14033T	PARTICIPANT	\N	PRESENT	0
517617	517607	11099A	PARTICIPANT	\N	PRESENT	0
517618	517607	19369B	PARTICIPANT	\N	PRESENT	0
517619	517607	20062A	PARTICIPANT	\N	PRESENT	0
517623	517621	19782L	PARTICIPANT	\N	PRESENT	0
517624	517621	01025N	PARTICIPANT	\N	PRESENT	0
517625	517621	14207L	PARTICIPANT	\N	PRESENT	0
517626	517621	19511N	PARTICIPANT	\N	PRESENT	0
517627	517621	11099A	PARTICIPANT	\N	PRESENT	0
517628	517621	20144B	PARTICIPANT	\N	PRESENT	0
517629	517621	14033T	PARTICIPANT	\N	PRESENT	0
517630	517621	20062A	PARTICIPANT	\N	PRESENT	0
517633	517632	01025N	PARTICIPANT	\N	PRESENT	0
517634	517632	14207L	PARTICIPANT	\N	PRESENT	0
517636	517635	19515S	PARTICIPANT	\N	PRESENT	0
517637	517635	19521Q	PARTICIPANT	\N	PRESENT	0
517639	517638	19515S	PARTICIPANT	\N	PRESENT	0
517748	517467	20138D	PARTICIPANT	\N	PRESENT	1
517749	517467	19527W	PARTICIPANT	\N	EXCUSE	0
517750	517467	19735D	PARTICIPANT	\N	EXCUSE	0
517764	516382	07004J	PARTICIPANT	\N	EXCUSE	0
517765	516382	19585H	PARTICIPANT	\N	EXCUSE	0
518556	518553	14225N	PARTICIPANT	\N	PRESENT	0
518557	518553	07033P	PARTICIPANT	\N	PRESENT	0
518558	518553	20050V	PARTICIPANT	\N	PRESENT	0
518559	518553	14151M	PARTICIPANT	\N	PRESENT	0
518561	518553	14053L	PARTICIPANT	\N	PRESENT	0
518563	518553	18083K	PARTICIPANT	\N	PRESENT	0
518780	518779	04085P	PARTICIPANT	\N	PRESENT	0
518781	518779	19515S	PARTICIPANT	\N	PRESENT	0
518782	518779	05008E	PARTICIPANT	\N	PRESENT	0
518783	518779	14030Q	PARTICIPANT	\N	PRESENT	0
518784	518779	04047H	PARTICIPANT	\N	PRESENT	0
518785	518779	04042C	PARTICIPANT	\N	PRESENT	0
518786	518779	19545Y	PARTICIPANT	\N	PRESENT	0
518787	518779	14259Y	PARTICIPANT	\N	PRESENT	0
518788	518779	11070L	PARTICIPANT	\N	PRESENT	0
518789	518779	10006L	PARTICIPANT	\N	PRESENT	0
518790	518779	19719D	PARTICIPANT	\N	PRESENT	0
518791	518779	14231L	PARTICIPANT	\N	PRESENT	0
518792	518779	19347U	PARTICIPANT	\N	PRESENT	0
518793	518779	14026U	PARTICIPANT	\N	PRESENT	0
518794	518779	11048N	PARTICIPANT	\N	PRESENT	0
518795	518779	14021P	PARTICIPANT	\N	PRESENT	0
518796	518779	99004R	PARTICIPANT	\N	PRESENT	0
518797	518779	19611R	PARTICIPANT	\N	PRESENT	0
518798	518779	14219Q	PARTICIPANT	\N	PRESENT	0
518799	518779	01060R	PARTICIPANT	\N	PRESENT	0
518800	518779	11072N	PARTICIPANT	\N	PRESENT	0
518801	518779	11090Q	PARTICIPANT	\N	PRESENT	0
518802	518779	04043D	PARTICIPANT	\N	PRESENT	0
518803	518779	14331P	PARTICIPANT	\N	PRESENT	0
518804	518779	14225N	PARTICIPANT	\N	PRESENT	0
518805	518779	11012A	PARTICIPANT	\N	PRESENT	0
518806	518779	04033B	PARTICIPANT	\N	PRESENT	0
518807	518779	11045K	PARTICIPANT	\N	PRESENT	0
520507	518915	19673G	PARTICIPANT	\N	PRESENT	0
520509	518915	97011G	PARTICIPANT	\N	PRESENT	0
520514	518915	20034V	PARTICIPANT	\N	PRESENT	0
520516	518915	14059S	PARTICIPANT	\N	PRESENT	0
520517	518915	14147R	PARTICIPANT	\N	PRESENT	0
520519	518915	20148F	PARTICIPANT	\N	PRESENT	0
521605	519602	19563B	PARTICIPANT	\N	EXCUSE	0
526373	521651	19515S	PRESIDENT	0	PRESENT	0
526374	521651	19575F	PARTICIPANT	\N	PRESENT	0
526375	521651	14083S	PARTICIPANT	\N	PRESENT	0
526376	521651	19760E	PARTICIPANT	\N	PRESENT	0
526377	521651	20092G	PARTICIPANT	\N	PRESENT	0
526378	521651	19762G	PARTICIPANT	\N	PRESENT	0
526379	521651	14031R	PARTICIPANT	\N	PRESENT	0
526380	521651	19369B	PARTICIPANT	\N	PRESENT	0
526381	521651	14041T	PARTICIPANT	\N	PRESENT	0
526382	521651	16685X	PARTICIPANT	\N	PRESENT	0
526383	521651	19251M	PARTICIPANT	\N	PRESENT	0
526384	521651	14105F	PARTICIPANT	\N	PRESENT	0
526385	521651	19695N	PARTICIPANT	\N	PRESENT	0
526386	521651	20048C	PARTICIPANT	\N	PRESENT	0
526387	521651	19671E	PARTICIPANT	\N	PRESENT	0
526388	521651	19467C	PARTICIPANT	\N	PRESENT	0
526389	521651	20134Y	PARTICIPANT	\N	PRESENT	0
526390	521651	20082E	PARTICIPANT	\N	PRESENT	0
526391	521651	19301E	PARTICIPANT	\N	PRESENT	0
526392	523130	14033T	PARTICIPANT	\N	EXCUSE	0
526396	526288	11099A	PARTICIPANT	\N	PRESENT	0
526397	526288	20062A	PARTICIPANT	\N	PRESENT	0
526398	526288	20028X	PARTICIPANT	\N	PRESENT	0
526399	526288	20094J	PARTICIPANT	\N	PRESENT	0
526400	526288	20144B	PARTICIPANT	\N	PRESENT	0
526401	526288	19511N	PARTICIPANT	\N	PRESENT	0
526402	526288	20082E	PARTICIPANT	\N	PRESENT	0
533927	531047	11109J	PARTICIPANT	\N	EXCUSE	0
533929	531047	19717B	PARTICIPANT	\N	PRESENT	0
533930	531047	18083K	PARTICIPANT	\N	PRESENT	0
533932	531047	19577H	PARTICIPANT	\N	PRESENT	0
533934	531047	97011G	PARTICIPANT	\N	PRESENT	0
533935	531047	19347U	PARTICIPANT	\N	PRESENT	0
533936	531047	19329S	PARTICIPANT	\N	PRESENT	0
533937	531047	20034V	PARTICIPANT	\N	PRESENT	0
533938	531047	19715Y	PRESIDENT	0	PRESENT	0
533939	531047	14097Y	PARTICIPANT	\N	PRESENT	0
533940	531047	12016W	PARTICIPANT	\N	PRESENT	0
533941	531047	19657G	PARTICIPANT	\N	PRESENT	0
533942	531047	14147R	PARTICIPANT	\N	PRESENT	0
533943	531047	20028X	PARTICIPANT	\N	PRESENT	0
533944	531047	11072N	PARTICIPANT	\N	PRESENT	0
533945	531047	08073C	PARTICIPANT	\N	EXCUSE	0
533946	531047	19691J	PARTICIPANT	\N	EXCUSE	0
533955	531322	14221J	PARTICIPANT	\N	PRESENT	0
533956	531322	01048V	PARTICIPANT	\N	PRESENT	0
533957	531322	19723Y	PARTICIPANT	\N	PRESENT	0
533958	531322	04043D	PARTICIPANT	\N	PRESENT	0
533959	531322	19503N	PARTICIPANT	\N	PRESENT	0
533960	531322	01058X	PARTICIPANT	\N	PRESENT	0
536089	536075	14219Q	PARTICIPANT	\N	PRESENT	0
536090	536075	20028X	PARTICIPANT	\N	PRESENT	0
536121	536075	92040Q	PARTICIPANT	\N	PRESENT	0
536122	536075	20118Y	PARTICIPANT	\N	PRESENT	0
536123	536075	20082E	PARTICIPANT	\N	PRESENT	0
536124	536075	20054A	PARTICIPANT	\N	PRESENT	0
536125	536075	20044X	PARTICIPANT	\N	PRESENT	0
536126	536075	11097X	PARTICIPANT	\N	PRESENT	0
536127	536075	11043H	PARTICIPANT	\N	PRESENT	0
536128	536075	04045F	PARTICIPANT	\N	PRESENT	0
536129	536075	19713W	PARTICIPANT	\N	PRESENT	0
536130	536075	20058E	PARTICIPANT	\N	PRESENT	0
536133	536132	20104S	PARTICIPANT	\N	PRESENT	0
536134	536132	19820Y	PARTICIPANT	\N	PRESENT	0
536135	536132	20038A	PARTICIPANT	\N	PRESENT	0
536136	536132	20094J	PARTICIPANT	\N	PRESENT	0
536137	536132	19745F	PARTICIPANT	\N	PRESENT	0
536139	536138	19820Y	PARTICIPANT	\N	PRESENT	0
536141	536138	20104S	PARTICIPANT	\N	PRESENT	0
536142	536138	20038A	PARTICIPANT	\N	PRESENT	0
536143	536138	19745F	PARTICIPANT	\N	PRESENT	0
536145	536144	20104S	PARTICIPANT	\N	PRESENT	0
536146	536144	20038A	PARTICIPANT	\N	PRESENT	0
536433	536276	19663E	PARTICIPANT	\N	PRESENT	0
536435	536276	01048V	PARTICIPANT	\N	PRESENT	0
536436	536276	19503N	PARTICIPANT	\N	PRESENT	0
536437	536276	01058X	PARTICIPANT	\N	PRESENT	0
536438	536276	04043D	PARTICIPANT	\N	PRESENT	0
536439	536434	19583F	PARTICIPANT	\N	PRESENT	0
536440	536434	08056B	PARTICIPANT	\N	PRESENT	0
536441	536434	04042C	PARTICIPANT	\N	PRESENT	0
536442	536434	11080N	PARTICIPANT	\N	PRESENT	0
536443	536434	04070G	PARTICIPANT	\N	PRESENT	0
536444	536434	19443T	PARTICIPANT	\N	PRESENT	0
536445	536434	19347U	PARTICIPANT	\N	PRESENT	0
533779	533774	20074E	PARTICIPANT	\N	PRESENT	0
537841	534905	20032T	PARTICIPANT	\N	PRESENT	0
537846	534905	19701S	PARTICIPANT	\N	PRESENT	1
537843	534905	11101A	PARTICIPANT	\N	PRESENT	0
537844	534905	20076G	PARTICIPANT	\N	PRESENT	0
537845	534905	18083K	PARTICIPANT	\N	PRESENT	0
537847	534905	17229F	PARTICIPANT	\N	PRESENT	0
537848	534905	19251M	PARTICIPANT	\N	PRESENT	1
537849	534905	20038A	PARTICIPANT	\N	EXCUSE	0
537850	534905	20100N	PARTICIPANT	\N	PRESENT	0
537851	534905	19599P	PARTICIPANT	\N	PRESENT	0
537852	534905	19820Y	PARTICIPANT	\N	PRESENT	1
537853	534905	19387D	PARTICIPANT	\N	PRESENT	1
537854	534905	20106U	PARTICIPANT	\N	PRESENT	1
537855	534905	19551W	PARTICIPANT	\N	PRESENT	0
537856	534905	20102Q	PARTICIPANT	\N	PRESENT	0
537857	534905	14219Q	PRESIDENT	0	PRESENT	0
537858	534905	14031R	PARTICIPANT	\N	PRESENT	0
537859	534905	19637C	PARTICIPANT	\N	PRESENT	0
537860	534905	19826F	PARTICIPANT	\N	PRESENT	0
537861	534905	14237S	PARTICIPANT	\N	PRESENT	0
537862	534905	19739H	PARTICIPANT	\N	PRESENT	0
537863	534905	20136B	PARTICIPANT	\N	PRESENT	0
537864	534905	20046A	PARTICIPANT	\N	PRESENT	1
537865	534905	19745F	PARTICIPANT	0	PRESENT	1
537866	534915	19369B	PARTICIPANT	\N	PRESENT	0
537894	536275	14026U	PARTICIPANT	\N	PRESENT	1
537895	536275	19683J	PARTICIPANT	\N	PRESENT	1
537896	536275	11103C	PARTICIPANT	\N	PRESENT	1
537897	536275	19717B	PARTICIPANT	\N	PRESENT	1
537898	536275	19697Q	PARTICIPANT	\N	PRESENT	1
537899	536275	14071N	PARTICIPANT	\N	PRESENT	0
537900	536275	20172F	PARTICIPANT	\N	PRESENT	1
537901	536275	20066E	PARTICIPANT	\N	PRESENT	1
537902	536275	04043D	PARTICIPANT	\N	PRESENT	1
537903	536275	04057K	PARTICIPANT	\N	PRESENT	1
537904	536275	19657G	PARTICIPANT	\N	PRESENT	1
538027	536829	18083K	PARTICIPANT	\N	PRESENT	0
538028	536829	17737W	PARTICIPANT	\N	PRESENT	0
538029	536829	14059S	PARTICIPANT	\N	PRESENT	0
538030	536829	11065P	PARTICIPANT	\N	PRESENT	0
538031	536829	05008E	PARTICIPANT	\N	PRESENT	0
538032	536829	14217N	PARTICIPANT	\N	PRESENT	0
538033	536829	14105F	PARTICIPANT	\N	PRESENT	0
538034	536829	18193Q	PARTICIPANT	\N	PRESENT	0
538035	536829	11097X	PARTICIPANT	\N	PRESENT	0
538036	536829	11104D	PARTICIPANT	\N	PRESENT	0
538037	536829	19421M	PARTICIPANT	\N	PRESENT	0
538038	536829	11027H	PARTICIPANT	\N	PRESENT	0
538039	536829	19671E	PARTICIPANT	\N	PRESENT	0
538040	536829	01028R	PARTICIPANT	\N	PRESENT	0
538041	536829	04033B	PARTICIPANT	\N	PRESENT	0
538042	536829	14021P	PARTICIPANT	\N	PRESENT	0
538043	536829	14331P	PARTICIPANT	\N	PRESENT	0
538044	536829	19621T	PARTICIPANT	\N	PRESENT	0
538045	536829	19762G	PARTICIPANT	\N	PRESENT	0
538046	536829	08060W	PARTICIPANT	\N	PRESENT	0
538047	536829	20090E	PARTICIPANT	\N	PRESENT	0
538048	536829	11041F	PARTICIPANT	\N	PRESENT	0
538049	536829	08056B	PARTICIPANT	\N	PRESENT	0
538050	536829	14121F	PARTICIPANT	\N	PRESENT	0
538051	536829	20104S	PARTICIPANT	\N	PRESENT	0
538052	536829	19725B	PARTICIPANT	\N	PRESENT	0
538053	536829	20062A	PARTICIPANT	\N	PRESENT	0
538054	536829	19798U	PARTICIPANT	\N	PRESENT	0
538055	536829	08047A	PARTICIPANT	\N	PRESENT	0
538056	536829	19503N	PARTICIPANT	\N	PRESENT	0
538057	536829	20064C	PARTICIPANT	\N	PRESENT	0
538058	536829	97011G	PARTICIPANT	\N	PRESENT	0
538059	536829	20108W	PARTICIPANT	\N	PRESENT	0
538060	536829	20172F	PARTICIPANT	\N	PRESENT	0
538061	536829	11056N	PARTICIPANT	\N	PRESENT	0
538062	536829	20102Q	PARTICIPANT	\N	PRESENT	0
538063	536829	20098N	PARTICIPANT	\N	PRESENT	0
538064	536829	14089Y	PARTICIPANT	\N	PRESENT	0
538065	536829	14031R	PARTICIPANT	\N	PRESENT	0
538066	536829	19691J	PARTICIPANT	\N	PRESENT	0
538067	536829	19611R	PARTICIPANT	\N	PRESENT	0
538068	536829	20056C	PARTICIPANT	\N	PRESENT	0
538069	536829	20096L	PARTICIPANT	\N	PRESENT	0
538070	536829	14249W	PARTICIPANT	\N	PRESENT	0
538071	536829	19573D	PARTICIPANT	\N	PRESENT	0
538072	536829	08034U	PARTICIPANT	\N	PRESENT	0
538073	536829	04071H	PARTICIPANT	\N	PRESENT	0
538074	536829	08009T	PARTICIPANT	\N	PRESENT	0
538075	536829	19507S	PARTICIPANT	\N	PRESENT	0
538076	536829	01034P	PARTICIPANT	\N	PRESENT	0
538077	536829	19569H	PARTICIPANT	\N	PRESENT	0
538078	536829	20138D	PARTICIPANT	\N	PRESENT	0
538079	536829	14205J	PARTICIPANT	\N	PRESENT	0
538080	536829	14033T	PARTICIPANT	\N	PRESENT	0
538081	536829	19399H	PARTICIPANT	\N	PRESENT	0
538082	536829	20052X	PARTICIPANT	\N	PRESENT	0
538083	536829	19441R	PARTICIPANT	\N	PRESENT	0
538084	536829	20078J	PARTICIPANT	\N	PRESENT	0
538085	536829	14073Q	PARTICIPANT	\N	PRESENT	0
538086	536829	19954N	PARTICIPANT	\N	PRESENT	0
538087	536829	20044X	PARTICIPANT	\N	PRESENT	0
538088	536829	19619A	PARTICIPANT	\N	PRESENT	0
538089	536829	19768N	PARTICIPANT	\N	PRESENT	0
538090	536829	14147R	PARTICIPANT	\N	PRESENT	0
538091	536829	20048C	PARTICIPANT	\N	PRESENT	0
538092	536829	20024T	PARTICIPANT	\N	PRESENT	0
538093	536829	14357A	PARTICIPANT	\N	PRESENT	0
538094	536829	14042U	PARTICIPANT	\N	PRESENT	0
538095	536829	14329V	PARTICIPANT	\N	PRESENT	0
538096	536829	14083S	PARTICIPANT	\N	PRESENT	0
538097	536829	19543W	PARTICIPANT	\N	PRESENT	0
538098	536829	20126Y	PARTICIPANT	\N	PRESENT	0
538099	536829	19369B	PARTICIPANT	\N	PRESENT	0
538100	536829	19577H	PARTICIPANT	\N	PRESENT	0
538101	536829	19383Y	PARTICIPANT	\N	PRESENT	0
538102	536829	14231L	PARTICIPANT	\N	PRESENT	0
538103	536829	14030Q	PARTICIPANT	\N	PRESENT	0
538104	536829	20152B	PARTICIPANT	\N	PRESENT	0
538105	536829	20040T	PARTICIPANT	\N	PRESENT	0
538106	536829	20054A	PARTICIPANT	\N	PRESENT	0
538107	536829	20124W	PARTICIPANT	\N	PRESENT	0
538108	536829	11103C	PARTICIPANT	\N	PRESENT	0
538109	536829	14215L	PARTICIPANT	\N	PRESENT	0
538110	536829	19467C	PARTICIPANT	\N	PRESENT	0
538111	536829	19333N	PARTICIPANT	\N	PRESENT	0
538112	536829	19657G	PARTICIPANT	\N	PRESENT	0
538113	536829	20080C	PARTICIPANT	\N	PRESENT	0
538114	536829	20028X	PARTICIPANT	\N	PRESENT	0
538115	536829	19663E	PARTICIPANT	\N	PRESENT	0
538116	536829	11099A	PARTICIPANT	\N	PRESENT	0
538117	536829	20140W	PARTICIPANT	\N	PRESENT	0
538118	536829	20086J	PARTICIPANT	\N	PRESENT	0
538119	536829	14041T	PARTICIPANT	\N	PRESENT	0
538120	536829	20120S	PARTICIPANT	\N	PRESENT	0
538121	536829	19679N	PARTICIPANT	\N	PRESENT	0
538122	536829	19673G	PARTICIPANT	\N	PRESENT	0
538124	536829	14111D	PARTICIPANT	\N	PRESENT	0
538125	536829	14213J	PARTICIPANT	\N	PRESENT	0
538126	536829	19335Q	PARTICIPANT	\N	PRESENT	0
538127	536829	19685L	PARTICIPANT	\N	PRESENT	0
538128	536829	14229S	PARTICIPANT	\N	PRESENT	0
538130	538129	19709B	PARTICIPANT	\N	PRESENT	0
538131	536829	14038Y	PARTICIPANT	\N	PRESENT	0
538132	536829	14179A	PARTICIPANT	\N	PRESENT	0
538133	536829	14189C	PARTICIPANT	\N	PRESENT	0
538134	536829	16685X	PARTICIPANT	\N	PRESENT	0
538135	536829	19599P	PARTICIPANT	\N	PRESENT	0
538136	536829	19413M	PARTICIPANT	\N	PRESENT	0
538137	536829	19511N	PARTICIPANT	\N	PRESENT	0
538138	536829	19699S	PARTICIPANT	\N	PRESENT	0
538139	536829	19551W	PARTICIPANT	\N	PRESENT	0
538140	536829	19741B	PARTICIPANT	\N	PRESENT	0
538141	536829	19581D	PARTICIPANT	\N	PRESENT	0
538142	536829	19367Y	PARTICIPANT	\N	PRESENT	0
538143	536829	11090Q	PARTICIPANT	\N	PRESENT	0
538148	536829	04070G	PARTICIPANT	\N	PRESENT	0
538145	536829	19479G	PARTICIPANT	\N	PRESENT	0
538146	536829	19715Y	PARTICIPANT	\N	PRESENT	0
538151	536829	19533U	PARTICIPANT	\N	PRESENT	0
514893	514892	01028R	PARTICIPANT	\N	PRESENT	0
514894	514892	14255U	PARTICIPANT	\N	PRESENT	0
514895	514892	01057W	PARTICIPANT	\N	PRESENT	0
514896	514892	14073Q	PARTICIPANT	\N	PRESENT	0
514897	514892	14229S	PARTICIPANT	\N	PRESENT	0
514898	514892	04070G	PARTICIPANT	\N	PRESENT	0
514899	514892	04034C	PARTICIPANT	\N	PRESENT	0
514900	514892	14179A	PARTICIPANT	\N	PRESENT	0
515668	502371	11045K	PARTICIPANT	\N	PRESENT	0
515669	502371	11067R	PARTICIPANT	\N	PRESENT	0
515670	502371	14281W	PARTICIPANT	\N	PRESENT	0
515671	502371	19683J	PARTICIPANT	\N	PRESENT	0
515672	502371	17965H	PARTICIPANT	\N	PRESENT	0
515673	502371	11031D	PARTICIPANT	\N	PRESENT	0
515674	502371	10006L	PARTICIPANT	\N	PRESENT	0
515675	502371	20130U	PARTICIPANT	\N	PRESENT	0
515676	502371	20082E	PARTICIPANT	\N	PRESENT	0
515677	502371	19760E	PARTICIPANT	\N	PRESENT	0
515678	502371	19593H	PARTICIPANT	\N	PRESENT	0
515679	502371	14195A	PARTICIPANT	\N	PRESENT	0
515680	502371	17589D	PARTICIPANT	\N	PRESENT	0
515681	502371	18193Q	PARTICIPANT	\N	PRESENT	0
515682	502371	19387D	PARTICIPANT	\N	PRESENT	0
515683	502371	14042U	PARTICIPANT	\N	PRESENT	0
515684	502371	20020P	PARTICIPANT	\N	PRESENT	0
515685	502371	19521Q	PARTICIPANT	\N	PRESENT	0
515686	502371	19691J	PARTICIPANT	\N	PRESENT	0
515687	502371	19479G	PARTICIPANT	\N	PRESENT	0
515688	502371	19713W	PARTICIPANT	\N	PRESENT	0
515689	502371	19758L	PARTICIPANT	\N	PRESENT	0
515690	502371	19687N	PARTICIPANT	\N	PRESENT	0
515691	502371	19367Y	PARTICIPANT	\N	PRESENT	0
515692	502371	20062A	PARTICIPANT	\N	PRESENT	0
515693	502371	20038A	PARTICIPANT	\N	PRESENT	0
515694	502371	20172F	PARTICIPANT	\N	PRESENT	0
515695	502371	18083K	PARTICIPANT	\N	PRESENT	0
515696	502371	14213J	PARTICIPANT	\N	PRESENT	0
515697	502371	14069U	PARTICIPANT	\N	PRESENT	0
515698	502371	14089Y	PARTICIPANT	\N	PRESENT	0
515699	502371	19745F	PARTICIPANT	\N	PRESENT	0
515700	502371	19697Q	PARTICIPANT	\N	PRESENT	0
515701	502371	19820Y	PARTICIPANT	\N	PRESENT	0
515702	502371	20122U	PARTICIPANT	\N	PRESENT	0
515703	502371	14038Y	PARTICIPANT	\N	PRESENT	0
515704	502371	20112S	PARTICIPANT	\N	PRESENT	0
515705	502371	20102Q	PARTICIPANT	\N	PRESENT	0
515706	502371	11077T	PARTICIPANT	\N	PRESENT	0
515707	513095	14059S	PARTICIPANT	\N	PRESENT	0
515708	513095	20064C	PARTICIPANT	\N	PRESENT	0
515709	513095	12041X	PARTICIPANT	\N	PRESENT	0
515710	513095	19347U	PARTICIPANT	\N	PRESENT	0
515711	513095	16685X	PARTICIPANT	\N	PRESENT	0
515712	513095	04042C	PRESIDENT	0	PRESENT	0
515713	513095	11054L	PARTICIPANT	\N	PRESENT	0
515714	513095	01024M	PARTICIPANT	\N	PRESENT	0
515715	513095	97011G	PARTICIPANT	\N	PRESENT	0
515716	513095	11066Q	PARTICIPANT	\N	PRESENT	0
515717	513095	19443T	PARTICIPANT	\N	PRESENT	0
515718	502371	14071N	PARTICIPANT	\N	PRESENT	0
515719	502371	04092N	PARTICIPANT	\N	PRESENT	0
515720	502371	11097X	PARTICIPANT	\N	PRESENT	0
515721	502371	19569H	PARTICIPANT	\N	PRESENT	0
515722	502371	11056N	PARTICIPANT	\N	PRESENT	0
515723	502371	04085P	PARTICIPANT	\N	PRESENT	0
515724	513095	04035D	PARTICIPANT	\N	PRESENT	1
515725	513095	19565D	PARTICIPANT	\N	PRESENT	1
515726	513095	04034C	PARTICIPANT	\N	PRESENT	1
515727	513095	01058X	PARTICIPANT	\N	PRESENT	1
515728	513095	19421M	PARTICIPANT	\N	PRESENT	1
515729	502371	20046A	PARTICIPANT	\N	PRESENT	0
515730	502371	19553Y	PARTICIPANT	\N	PRESENT	0
515731	502371	19798U	PARTICIPANT	\N	PRESENT	0
515732	502371	19695N	PARTICIPANT	\N	PRESENT	0
515733	502371	19782L	PARTICIPANT	\N	PRESENT	0
515734	502371	19383Y	PARTICIPANT	\N	PRESENT	0
515735	502371	20024T	PARTICIPANT	\N	PRESENT	0
515736	502371	08056B	PARTICIPANT	\N	PRESENT	0
515737	502371	14147R	PARTICIPANT	\N	PRESENT	0
515738	502371	20100N	PARTICIPANT	\N	PRESENT	0
515739	502371	17779H	PARTICIPANT	\N	PRESENT	0
515744	502371	14083S	PARTICIPANT	\N	PRESENT	0
515745	502371	19543W	PARTICIPANT	\N	PRESENT	0
515746	502371	19333N	PARTICIPANT	\N	PRESENT	0
517135	517134	20110Q	PARTICIPANT	\N	PRESENT	0
517136	517134	20114U	PARTICIPANT	\N	PRESENT	0
517137	517134	17737W	PARTICIPANT	\N	PRESENT	0
517138	517134	19782L	PARTICIPANT	\N	PRESENT	0
517139	517134	12028B	PARTICIPANT	\N	PRESENT	0
517140	517134	19251M	PARTICIPANT	\N	PRESENT	0
517141	517134	97011G	PARTICIPANT	\N	PRESENT	0
517142	517134	14179A	PARTICIPANT	\N	PRESENT	0
517143	517134	20048C	PARTICIPANT	\N	PRESENT	0
517144	517134	19711U	PARTICIPANT	\N	PRESENT	0
517145	517134	14109K	PARTICIPANT	\N	PRESENT	0
517146	517134	19593H	PARTICIPANT	\N	PRESENT	0
517147	517134	19689Q	PARTICIPANT	\N	PRESENT	0
517148	517134	20064C	PARTICIPANT	\N	PRESENT	0
517159	517158	04059M	PARTICIPANT	\N	PRESENT	0
517160	517158	19347U	PARTICIPANT	\N	PRESENT	0
517161	517158	14229S	PARTICIPANT	\N	PRESENT	0
517179	517158	20144B	PARTICIPANT	\N	PRESENT	0
517163	517158	19575F	PARTICIPANT	\N	PRESENT	0
517164	517158	20138D	PARTICIPANT	\N	PRESENT	0
517165	517158	18083K	PARTICIPANT	\N	PRESENT	0
517166	517158	19719D	PARTICIPANT	\N	PRESENT	0
517167	517158	14187A	PARTICIPANT	\N	PRESENT	0
517168	517158	14213J	PARTICIPANT	\N	PRESENT	0
517169	517158	14021P	PARTICIPANT	\N	PRESENT	0
517170	517158	19489J	PARTICIPANT	\N	PRESENT	0
517171	517158	14193X	PARTICIPANT	\N	PRESENT	0
517172	517158	19745F	PARTICIPANT	\N	PRESENT	0
517173	517158	20064C	PARTICIPANT	\N	PRESENT	0
517174	517158	14105F	PARTICIPANT	\N	PRESENT	0
517178	517158	14189C	PARTICIPANT	\N	PRESENT	0
517180	517158	17229F	PARTICIPANT	\N	PRESENT	0
517266	517264	14221J	PARTICIPANT	\N	PRESENT	0
517267	517264	11040E	PARTICIPANT	\N	PRESENT	0
517268	517264	20044X	PARTICIPANT	\N	PRESENT	0
517269	517264	20062A	PARTICIPANT	\N	PRESENT	0
517270	517264	14229S	PARTICIPANT	\N	PRESENT	0
517272	517264	17023S	PARTICIPANT	\N	PRESENT	0
517273	517264	20048C	PARTICIPANT	\N	PRESENT	0
517468	516058	19735D	PARTICIPANT	\N	EXCUSE	0
517760	516755	11074Q	PARTICIPANT	\N	PRESENT	1
517761	516755	11110B	PARTICIPANT	\N	PRESENT	1
517762	516755	19671E	PARTICIPANT	\N	PRESENT	1
517763	516755	20050V	PARTICIPANT	\N	PRESENT	1
517766	513049	86034E	PARTICIPANT	\N	PRESENT	0
517775	513049	98022P	PARTICIPANT	\N	PRESENT	0
517776	513049	20174H	PARTICIPANT	\N	PRESENT	0
517777	513049	11041F	PARTICIPANT	\N	PRESENT	0
517778	513049	20052X	PARTICIPANT	\N	PRESENT	0
517781	513049	19629C	PARTICIPANT	\N	PRESENT	0
517785	513049	19565D	PARTICIPANT	\N	PRESENT	0
517794	513049	20070A	PARTICIPANT	\N	PRESENT	0
517809	513049	11040E	PARTICIPANT	\N	PRESENT	0
517810	513049	20028X	PARTICIPANT	\N	PRESENT	0
517811	513049	19551W	PARTICIPANT	\N	PRESENT	0
517812	513049	04045F	PARTICIPANT	\N	PRESENT	0
517813	513049	19725B	PARTICIPANT	\N	PRESENT	0
517814	513049	19820Y	PARTICIPANT	\N	PRESENT	0
517815	513049	19683J	PARTICIPANT	\N	PRESENT	0
517816	513049	19549D	PARTICIPANT	\N	PRESENT	0
517817	513049	19695N	PARTICIPANT	\N	PRESENT	0
517818	513049	20102Q	PARTICIPANT	\N	PRESENT	0
517819	513049	14042U	PARTICIPANT	\N	PRESENT	0
517820	513049	14073Q	PARTICIPANT	\N	PRESENT	0
517821	513049	19651A	PARTICIPANT	\N	PRESENT	0
517822	513049	20084G	PARTICIPANT	\N	PRESENT	0
517823	513049	11031D	PARTICIPANT	\N	PRESENT	0
517824	513049	20114U	PARTICIPANT	\N	PRESENT	0
517825	513049	19333N	PARTICIPANT	\N	PRESENT	0
517826	513049	20100N	PARTICIPANT	\N	PRESENT	0
517827	513049	19503N	PARTICIPANT	\N	PRESENT	0
517828	513049	14121F	PARTICIPANT	\N	PRESENT	0
517829	513049	14249W	PARTICIPANT	\N	PRESENT	0
517830	513049	20106U	PARTICIPANT	\N	PRESENT	0
517831	513049	19782L	PARTICIPANT	\N	PRESENT	0
517832	513049	20130U	PARTICIPANT	\N	PRESENT	0
517833	513049	19387D	PARTICIPANT	\N	PRESENT	0
517834	513049	14111D	PARTICIPANT	\N	PRESENT	0
531526	531525	19515S	PARTICIPANT	\N	PRESENT	0
531527	531525	19741B	PARTICIPANT	\N	PRESENT	0
531528	531525	19954N	PARTICIPANT	\N	PRESENT	0
531529	531525	19575F	PARTICIPANT	\N	PRESENT	0
531530	531525	14069U	PARTICIPANT	\N	PRESENT	0
531813	531715	19760E	PARTICIPANT	\N	PRESENT	0
532007	529295	17637T	PARTICIPANT	\N	PRESENT	0
531533	531525	19747H	PARTICIPANT	\N	PRESENT	0
531534	531525	20152B	PARTICIPANT	\N	PRESENT	0
531535	531525	14255U	PARTICIPANT	\N	PRESENT	0
531536	531525	11101A	PARTICIPANT	\N	PRESENT	0
531537	531525	04042C	PARTICIPANT	\N	PRESENT	0
531538	531525	19693L	PARTICIPANT	\N	PRESENT	0
531539	531525	20140W	PARTICIPANT	\N	PRESENT	0
531540	531525	14187A	PARTICIPANT	\N	PRESENT	0
531541	531525	19647E	PARTICIPANT	\N	PRESENT	0
531542	531525	19521Q	PARTICIPANT	\N	PRESENT	0
531543	531525	04035D	PARTICIPANT	\N	PRESENT	0
531544	531525	14179A	PARTICIPANT	\N	PRESENT	0
531545	531525	11026G	PARTICIPANT	\N	PRESENT	0
531546	531525	19637C	PARTICIPANT	\N	PRESENT	0
531547	531525	11085T	PARTICIPANT	\N	PRESENT	0
531548	531525	19798U	PARTICIPANT	\N	PRESENT	0
531549	531525	01062T	PARTICIPANT	\N	PRESENT	0
531550	531525	19749K	PARTICIPANT	\N	PRESENT	0
531814	531715	14071N	PARTICIPANT	\N	PRESENT	0
532039	532038	19631V	PARTICIPANT	\N	PRESENT	0
532041	532038	20114U	PARTICIPANT	\N	PRESENT	0
532042	532038	18083K	PARTICIPANT	\N	PRESENT	0
532043	532038	14179A	PARTICIPANT	\N	PRESENT	0
532044	532038	19669L	PARTICIPANT	\N	PRESENT	0
532683	531195	19369B	PARTICIPANT	\N	PRESENT	1
532684	531195	04045F	PARTICIPANT	\N	PRESENT	1
532704	531195	01025N	PARTICIPANT	\N	PRESENT	1
533996	531375	14055N	PARTICIPANT	\N	PRESENT	0
533997	531375	19585H	PARTICIPANT	\N	PRESENT	0
533998	531375	20110Q	PARTICIPANT	\N	PRESENT	0
533999	531375	20106U	PARTICIPANT	\N	PRESENT	0
534000	531375	11012A	PARTICIPANT	\N	PRESENT	0
534001	531375	04085P	PARTICIPANT	\N	PRESENT	0
534002	531375	14089Y	PARTICIPANT	\N	PRESENT	0
534003	531375	19489J	PARTICIPANT	\N	PRESENT	0
534004	531375	08018U	PARTICIPANT	\N	PRESENT	0
534005	531375	19651A	PARTICIPANT	\N	PRESENT	0
534006	531375	04047H	PARTICIPANT	\N	PRESENT	0
534007	531375	19649G	PARTICIPANT	\N	PRESENT	0
534008	531375	20028X	PARTICIPANT	\N	PRESENT	0
534009	531375	20114U	PARTICIPANT	\N	PRESENT	0
534010	531375	14147R	PARTICIPANT	\N	PRESENT	0
534011	531375	19399H	PARTICIPANT	\N	PRESENT	0
534012	531375	08010L	PARTICIPANT	\N	PRESENT	0
534013	531375	19573D	PARTICIPANT	\N	PRESENT	0
534014	531375	99004R	PARTICIPANT	\N	PRESENT	0
534015	531375	19447X	PARTICIPANT	\N	PRESENT	0
534016	531375	14041T	PARTICIPANT	\N	PRESENT	0
534017	531375	14215L	PARTICIPANT	\N	PRESENT	0
534018	531375	05008E	PARTICIPANT	\N	PRESENT	0
534019	531375	19643A	PARTICIPANT	\N	PRESENT	0
534020	531375	19711U	PARTICIPANT	\N	PRESENT	0
534021	531375	17637T	PARTICIPANT	\N	PRESENT	0
534022	531375	14071N	PARTICIPANT	\N	PRESENT	0
533994	531375	14026U	PARTICIPANT	\N	PRESENT	0
533995	531375	20108W	PARTICIPANT	\N	PRESENT	0
534023	531375	17737W	PARTICIPANT	\N	PRESENT	0
534024	531375	20134Y	PARTICIPANT	\N	PRESENT	0
534025	531375	11056N	PARTICIPANT	\N	PRESENT	0
534026	531375	19695N	PARTICIPANT	\N	PRESENT	0
534027	531375	19687N	PARTICIPANT	\N	PRESENT	0
534028	531375	19611R	PARTICIPANT	\N	PRESENT	0
534029	531375	19669L	PARTICIPANT	\N	PRESENT	0
534044	531375	14083S	PARTICIPANT	\N	PRESENT	0
534045	531375	11083R	PARTICIPANT	\N	PRESENT	0
534108	531525	19443T	PARTICIPANT	\N	PRESENT	0
534047	531375	11085T	PARTICIPANT	\N	PRESENT	0
534048	531375	08069G	PARTICIPANT	\N	PRESENT	0
534049	531375	11026G	PARTICIPANT	\N	PRESENT	0
534063	531375	19657G	PARTICIPANT	\N	PRESENT	0
534122	534121	14173T	PARTICIPANT	\N	PRESENT	0
534124	534123	14173T	PARTICIPANT	\N	PRESENT	0
534173	534172	19673G	PARTICIPANT	\N	PRESENT	0
534174	534172	07004J	PARTICIPANT	\N	PRESENT	0
534175	534172	19749K	PARTICIPANT	\N	PRESENT	0
534177	534176	14237S	PARTICIPANT	\N	PRESENT	0
534178	534176	04070G	PARTICIPANT	\N	PRESENT	0
534179	534176	19826F	PARTICIPANT	\N	PRESENT	0
534180	534176	14255U	PARTICIPANT	\N	PRESENT	0
534198	534196	11031D	PARTICIPANT	\N	PRESENT	0
534199	534196	11067R	PARTICIPANT	\N	PRESENT	0
534200	534196	20130U	PARTICIPANT	\N	PRESENT	0
534201	534197	11031D	PARTICIPANT	\N	PRESENT	0
534202	534197	08045X	PARTICIPANT	\N	PRESENT	0
534203	534197	11067R	PARTICIPANT	\N	PRESENT	0
534204	534197	20130U	PARTICIPANT	\N	PRESENT	0
534271	534270	19701S	PARTICIPANT	\N	PRESENT	0
534272	534270	14255U	PARTICIPANT	\N	PRESENT	0
534273	534270	04035D	PARTICIPANT	\N	PRESENT	0
534274	534270	14179A	PARTICIPANT	\N	PRESENT	0
534284	534283	20074E	PARTICIPANT	\N	PRESENT	0
534286	534285	20074E	PARTICIPANT	\N	PRESENT	0
534418	534165	19629C	PARTICIPANT	\N	PRESENT	1
534419	534165	11056N	PARTICIPANT	\N	PRESENT	1
534420	534165	14147R	PARTICIPANT	\N	PRESENT	1
534421	534165	14107H	PARTICIPANT	\N	PRESENT	1
534422	534165	19675J	PARTICIPANT	\N	PRESENT	1
534483	534482	14255U	PARTICIPANT	\N	PRESENT	0
534484	534482	08015R	PARTICIPANT	\N	PRESENT	0
534485	534482	14111D	PARTICIPANT	\N	PRESENT	0
534486	534482	08009T	PARTICIPANT	\N	PRESENT	0
534487	534482	19585H	PARTICIPANT	\N	PRESENT	0
534488	534482	20022R	PARTICIPANT	\N	PRESENT	0
534489	534482	14221J	PARTICIPANT	\N	PRESENT	0
534577	534575	11033F	PARTICIPANT	\N	PRESENT	0
534578	534575	11031D	PARTICIPANT	\N	PRESENT	0
534580	534575	19647E	PARTICIPANT	\N	PRESENT	0
515215	511900	20046A	PARTICIPANT	\N	PRESENT	0
515219	511901	19251M	PARTICIPANT	\N	PRESENT	1
515441	512883	14219Q	PARTICIPANT	\N	EXCUSE	0
518308	513050	20086J	PARTICIPANT	\N	PRESENT	0
521607	521239	19399H	PARTICIPANT	\N	PRESENT	0
515444	512883	14059S	PARTICIPANT	\N	PRESENT	0
515445	512883	19657G	PARTICIPANT	\N	PRESENT	0
515446	512883	20148F	PARTICIPANT	\N	PRESENT	0
521606	521239	20138D	PARTICIPANT	\N	PRESENT	0
521608	521495	20138D	PARTICIPANT	\N	PRESENT	0
521609	521495	19399H	PARTICIPANT	\N	PRESENT	0
525240	525239	08009T	PARTICIPANT	\N	PRESENT	0
525241	525239	19739H	PARTICIPANT	\N	PRESENT	0
525243	525242	08009T	PARTICIPANT	\N	PRESENT	0
525244	525242	19739H	PARTICIPANT	\N	PRESENT	0
534251	534250	01034P	PARTICIPANT	\N	PRESENT	1
534261	534260	14189C	PARTICIPANT	\N	PRESENT	0
534262	534260	14030Q	PARTICIPANT	\N	PRESENT	0
534263	534260	20106U	PARTICIPANT	\N	PRESENT	0
534264	534260	14109K	PARTICIPANT	\N	PRESENT	0
534265	534260	19866P	PARTICIPANT	\N	PRESENT	0
536523	536521	11074Q	PARTICIPANT	\N	PRESENT	0
534267	534260	20046A	PARTICIPANT	\N	PRESENT	0
536446	536434	20064C	PARTICIPANT	\N	PRESENT	0
536447	536434	11083R	PARTICIPANT	\N	PRESENT	0
536524	536521	01057W	PARTICIPANT	\N	PRESENT	0
536525	536521	20064C	PARTICIPANT	\N	PRESENT	0
536526	536521	14225N	PARTICIPANT	\N	PRESENT	0
536535	534269	14179A	PARTICIPANT	\N	PRESENT	1
536528	534269	20052X	PARTICIPANT	\N	PRESENT	0
536529	534269	17779H	PARTICIPANT	\N	PRESENT	0
536530	534269	19866P	PARTICIPANT	\N	PRESENT	0
536522	536521	20024T	PARTICIPANT	\N	PRESENT	0
536531	534269	20048C	PRESIDENT	0	PRESENT	0
536532	534269	11067R	PARTICIPANT	\N	PRESENT	0
536533	534269	20060X	PARTICIPANT	\N	PRESENT	0
536534	534269	20090E	PARTICIPANT	\N	PRESENT	1
536536	534269	20062A	PARTICIPANT	\N	PRESENT	1
536856	536855	14030Q	PARTICIPANT	\N	PRESENT	0
536857	536855	20106U	PARTICIPANT	\N	PRESENT	0
536858	536855	19866P	PARTICIPANT	\N	PRESENT	0
536859	536855	20130U	PARTICIPANT	\N	PRESENT	0
536860	536855	11045K	PARTICIPANT	\N	PRESENT	0
536861	536855	14109K	PARTICIPANT	\N	PRESENT	0
537028	537027	19709B	PARTICIPANT	\N	PRESENT	0
537031	537030	19709B	PARTICIPANT	\N	PRESENT	0
537033	537032	19709B	PARTICIPANT	\N	PRESENT	0
537037	537036	04070G	PARTICIPANT	\N	PRESENT	0
537038	537036	14169X	PARTICIPANT	\N	PRESENT	0
537107	536269	01034P	PARTICIPANT	\N	PRESENT	1
537108	536269	19723Y	PARTICIPANT	\N	PRESENT	0
537109	536269	19703U	PARTICIPANT	\N	PRESENT	0
537110	536269	19679N	PARTICIPANT	\N	PRESENT	0
537111	536269	14195A	PARTICIPANT	\N	PRESENT	0
537112	536269	08045X	PARTICIPANT	\N	PRESENT	0
537113	536269	18193Q	PARTICIPANT	\N	PRESENT	0
537114	536269	19553Y	PARTICIPANT	\N	PRESENT	1
537115	536827	20130U	PARTICIPANT	\N	PRESENT	0
537116	536827	19798U	PARTICIPANT	\N	PRESENT	0
537117	536827	18083K	PARTICIPANT	\N	PRESENT	0
537118	536827	20090E	PARTICIPANT	\N	PRESENT	0
537119	536827	19691J	PARTICIPANT	\N	PRESENT	0
537120	536827	19697Q	PARTICIPANT	\N	PRESENT	0
537121	536827	20128B	PARTICIPANT	\N	PRESENT	0
537122	536827	19387D	PARTICIPANT	\N	PRESENT	0
537123	536827	17589D	PARTICIPANT	\N	PRESENT	0
537124	536827	01062T	PARTICIPANT	\N	PRESENT	0
537125	536827	19715Y	PARTICIPANT	\N	PRESENT	0
537126	536827	20174H	PARTICIPANT	\N	PRESENT	0
537127	536827	14042U	PARTICIPANT	\N	PRESENT	0
537128	536827	20040T	PARTICIPANT	\N	PRESENT	0
537129	536827	20042V	PARTICIPANT	\N	PRESENT	0
537130	536827	20048C	PARTICIPANT	\N	PRESENT	0
537131	536827	20116W	PARTICIPANT	\N	PRESENT	0
537132	536827	20054A	PARTICIPANT	\N	PRESENT	0
537133	536827	04043D	PARTICIPANT	\N	PRESENT	0
537134	536827	14223L	PARTICIPANT	\N	PRESENT	0
537135	536827	20172F	PARTICIPANT	\N	PRESENT	0
537136	536827	19443T	PARTICIPANT	\N	PRESENT	0
537137	536827	19507S	PARTICIPANT	\N	PRESENT	0
537138	536827	20044X	PARTICIPANT	\N	PRESENT	0
537139	536827	19723Y	PARTICIPANT	\N	PRESENT	0
537140	536827	19679N	PARTICIPANT	\N	PRESENT	0
537141	536827	11031D	PARTICIPANT	\N	PRESENT	0
537142	536827	19760E	PARTICIPANT	\N	PRESENT	0
537143	536827	10006L	PARTICIPANT	\N	PRESENT	0
537144	536827	19347U	PARTICIPANT	\N	PRESENT	0
537145	536827	14195A	PARTICIPANT	\N	PRESENT	0
537146	536827	14179A	PARTICIPANT	\N	PRESENT	0
537147	536827	08047A	PARTICIPANT	\N	PRESENT	0
537148	536827	08056B	PARTICIPANT	\N	PRESENT	0
537149	536827	19657G	PARTICIPANT	\N	PRESENT	0
537150	536827	19758L	PARTICIPANT	\N	PRESENT	0
537152	536827	19565D	PARTICIPANT	\N	PRESENT	0
537153	536827	99004R	PARTICIPANT	\N	PRESENT	0
537154	536827	11103C	PARTICIPANT	\N	PRESENT	0
537155	536827	01058X	PARTICIPANT	\N	PRESENT	0
537161	536827	20072C	PARTICIPANT	\N	PRESENT	0
537162	536827	14026U	PARTICIPANT	\N	PRESENT	0
537163	536827	14189C	PARTICIPANT	\N	PRESENT	0
537164	536827	11067R	PARTICIPANT	\N	PRESENT	0
537165	536827	19367Y	PARTICIPANT	\N	PRESENT	0
537166	536827	19703U	PARTICIPANT	\N	PRESENT	0
537167	536827	14237S	PARTICIPANT	\N	PRESENT	0
537168	536827	11043H	PARTICIPANT	\N	PRESENT	0
537169	536827	07029T	PARTICIPANT	\N	PRESENT	0
537170	536827	14331P	PARTICIPANT	\N	PRESENT	0
537171	536827	08069G	PARTICIPANT	\N	PRESENT	0
537172	536827	14071N	PARTICIPANT	\N	PRESENT	0
537173	536827	14030Q	PARTICIPANT	\N	PRESENT	0
537174	536827	19699S	PARTICIPANT	\N	PRESENT	0
537175	536827	19713W	PARTICIPANT	\N	PRESENT	0
537176	536827	19569H	PARTICIPANT	\N	PRESENT	0
537177	536827	20062A	PARTICIPANT	\N	PRESENT	0
537179	536827	19333N	PARTICIPANT	\N	PRESENT	0
537180	536827	14213J	PARTICIPANT	\N	PRESENT	0
537181	536827	11097X	PARTICIPANT	\N	PRESENT	0
537182	536827	14147R	PARTICIPANT	\N	PRESENT	0
537183	536827	20098N	PARTICIPANT	\N	PRESENT	0
537184	536827	19629C	PARTICIPANT	\N	PRESENT	0
537185	536827	20066E	PARTICIPANT	\N	PRESENT	0
537186	536827	20124W	PARTICIPANT	\N	PRESENT	0
537190	536827	97011G	PARTICIPANT	\N	PRESENT	0
537188	536827	08010L	PARTICIPANT	\N	PRESENT	0
537189	536827	19683J	PARTICIPANT	\N	PRESENT	0
537191	536827	20056C	PARTICIPANT	\N	PRESENT	0
537192	536827	14217N	PARTICIPANT	\N	PRESENT	0
537193	536827	19479G	PARTICIPANT	\N	PRESENT	0
537194	536827	19467C	PARTICIPANT	\N	PRESENT	0
537195	536827	14133K	PARTICIPANT	\N	PRESENT	0
537196	536827	19782L	PARTICIPANT	\N	PRESENT	0
537197	536827	20026V	PARTICIPANT	\N	PRESENT	0
537198	536827	19577H	PARTICIPANT	\N	PRESENT	0
537199	536827	19954N	PARTICIPANT	\N	PRESENT	0
537200	536827	14107H	PARTICIPANT	\N	PRESENT	0
537201	536827	01024M	PARTICIPANT	\N	PRESENT	0
532711	531369	86034E	PARTICIPANT	\N	PRESENT	0
532712	531369	14121F	PARTICIPANT	\N	PRESENT	0
532713	531369	14267Y	PARTICIPANT	\N	PRESENT	0
532714	531369	20082E	PARTICIPANT	\N	PRESENT	0
532715	531369	20046A	PARTICIPANT	\N	PRESENT	0
532716	531369	20102Q	PARTICIPANT	\N	PRESENT	0
532717	531369	18193Q	PARTICIPANT	\N	PRESENT	0
532718	531369	19695N	PARTICIPANT	\N	PRESENT	0
532719	531369	19413M	PARTICIPANT	\N	PRESENT	0
532720	531369	14195A	PARTICIPANT	\N	PRESENT	0
532721	531369	19585H	PARTICIPANT	\N	PRESENT	0
532722	531369	20132W	PARTICIPANT	\N	PRESENT	0
532723	531369	20018V	PARTICIPANT	\N	PRESENT	0
532724	531369	14123H	PARTICIPANT	\N	PRESENT	0
532725	531369	08028W	PARTICIPANT	\N	PRESENT	0
532726	531369	10006L	PARTICIPANT	\N	PRESENT	0
532727	531369	14133K	PARTICIPANT	\N	PRESENT	0
532728	531369	14147R	PARTICIPANT	\N	PRESENT	0
532729	531369	14041T	PARTICIPANT	\N	PRESENT	0
532730	531369	19383Y	PARTICIPANT	\N	PRESENT	0
532731	531369	97011G	PARTICIPANT	\N	PRESENT	0
532732	531369	14105F	PARTICIPANT	\N	PRESENT	0
532733	531369	19399H	PARTICIPANT	\N	PRESENT	0
532734	531369	07033P	PARTICIPANT	\N	PRESENT	0
532735	531369	14187A	PARTICIPANT	\N	PRESENT	0
532736	531369	14038Y	PARTICIPANT	\N	PRESENT	0
532737	531369	19573D	PARTICIPANT	\N	PRESENT	0
532738	531369	99004R	PARTICIPANT	\N	PRESENT	0
532739	531369	18083K	PARTICIPANT	\N	PRESENT	0
532740	531369	19741B	PARTICIPANT	\N	PRESENT	0
532741	531369	20086J	PARTICIPANT	\N	PRESENT	0
532742	531369	20056C	PARTICIPANT	\N	PRESENT	0
532744	531369	20098N	PARTICIPANT	\N	PRESENT	0
532745	531369	04092N	PARTICIPANT	\N	PRESENT	0
532746	531369	19758L	PARTICIPANT	\N	PRESENT	0
532747	531369	20120S	PARTICIPANT	\N	PRESENT	0
532748	531369	11031D	PARTICIPANT	\N	PRESENT	0
532749	531369	11040E	PARTICIPANT	\N	PRESENT	0
532750	531369	19251M	PARTICIPANT	\N	PRESENT	0
532751	531369	20070A	PARTICIPANT	\N	PRESENT	0
532752	531369	20172F	PARTICIPANT	\N	PRESENT	0
532753	531369	08060W	PARTICIPANT	\N	PRESENT	0
532754	531369	10015M	PARTICIPANT	\N	PRESENT	0
532755	531369	19525U	PARTICIPANT	\N	PRESENT	0
532756	531369	11066Q	PARTICIPANT	\N	PRESENT	0
532757	531369	11041F	PARTICIPANT	\N	PRESENT	0
532758	531369	17965H	PARTICIPANT	\N	PRESENT	0
532759	531369	08012N	PARTICIPANT	\N	PRESENT	0
532760	531369	14225N	PARTICIPANT	\N	PRESENT	0
532761	531369	11067R	PARTICIPANT	\N	PRESENT	0
532762	531369	08017T	PARTICIPANT	\N	PRESENT	0
532763	531369	19820Y	PARTICIPANT	\N	PRESENT	0
532764	531369	19503N	PARTICIPANT	\N	PRESENT	0
532765	531369	04085P	PARTICIPANT	\N	PRESENT	0
532766	531369	20112S	PARTICIPANT	\N	PRESENT	0
532767	531369	19760E	PARTICIPANT	\N	PRESENT	0
532768	531369	19593H	PARTICIPANT	\N	PRESENT	0
532769	531369	19687N	PARTICIPANT	\N	PRESENT	0
532770	531369	19575F	PARTICIPANT	\N	PRESENT	0
532771	531369	20092G	PARTICIPANT	\N	PRESENT	0
532772	531369	19711U	PARTICIPANT	\N	PRESENT	0
532773	531369	20142Y	PARTICIPANT	\N	PRESENT	0
532774	531369	19347U	PARTICIPANT	\N	PRESENT	0
532775	531369	14211G	PARTICIPANT	\N	PRESENT	0
532776	531369	20100N	PARTICIPANT	\N	PRESENT	0
532777	531369	01058X	PARTICIPANT	\N	PRESENT	0
532778	531369	95063L	PARTICIPANT	\N	PRESENT	0
532779	531369	14026U	PARTICIPANT	\N	PRESENT	0
532780	531369	19651A	PARTICIPANT	\N	PRESENT	0
532781	531369	04034C	PARTICIPANT	\N	PRESENT	0
532782	531369	08061X	PARTICIPANT	\N	PRESENT	0
532783	531369	08069G	PARTICIPANT	\N	PRESENT	0
532784	531369	19637C	PARTICIPANT	\N	PRESENT	0
532785	531369	19329S	PARTICIPANT	\N	PRESENT	0
532786	531369	11083R	PARTICIPANT	\N	PRESENT	0
532787	531369	20128B	PARTICIPANT	\N	PRESENT	0
532788	531369	19782L	PARTICIPANT	\N	PRESENT	0
532789	531369	19349W	PARTICIPANT	\N	PRESENT	0
532790	531369	20074E	PARTICIPANT	\N	PRESENT	0
532791	531369	20106U	PARTICIPANT	\N	PRESENT	0
532792	531369	20116W	PARTICIPANT	\N	PRESENT	0
532793	531369	19866P	PARTICIPANT	\N	PRESENT	0
532794	531369	19629C	PARTICIPANT	\N	PRESENT	0
532795	531369	14207L	PARTICIPANT	\N	PRESENT	0
532796	531369	19553Y	PARTICIPANT	\N	PRESENT	0
532797	531369	19591F	PARTICIPANT	\N	PRESENT	0
532798	531369	04042C	PARTICIPANT	\N	PRESENT	0
532799	531369	17589D	PARTICIPANT	\N	PRESENT	0
532800	531369	20050V	PARTICIPANT	\N	PRESENT	0
532801	531369	04057K	PARTICIPANT	\N	PRESENT	0
532803	531369	04086Q	PARTICIPANT	\N	PRESENT	0
532804	531369	14251Q	PARTICIPANT	\N	PRESENT	0
532805	531369	20110Q	PARTICIPANT	\N	PRESENT	0
532806	531369	04059M	PARTICIPANT	\N	PRESENT	0
532807	531369	14257W	PARTICIPANT	\N	PRESENT	0
532808	531369	11045K	PARTICIPANT	\N	PRESENT	0
532809	531369	14229S	PARTICIPANT	\N	PRESENT	0
532810	531369	14021P	PARTICIPANT	\N	PRESENT	0
532811	531369	11043H	PARTICIPANT	\N	PRESENT	0
532812	531369	20084G	PARTICIPANT	\N	PRESENT	0
532813	531369	04033B	PARTICIPANT	\N	PRESENT	0
532814	531369	20080C	PARTICIPANT	\N	PRESENT	0
532815	531369	19415P	PARTICIPANT	\N	PRESENT	0
532816	531369	11097X	PARTICIPANT	\N	PRESENT	0
532817	531369	14071N	PARTICIPANT	\N	PRESENT	0
532818	531369	05008E	PARTICIPANT	\N	PRESENT	0
532819	531369	19621T	PARTICIPANT	\N	PRESENT	0
532820	531369	19489J	PARTICIPANT	\N	PRESENT	0
532821	531369	19367Y	PARTICIPANT	\N	PRESENT	0
532822	531369	12028B	PARTICIPANT	\N	PRESENT	0
532823	531369	19631V	PARTICIPANT	\N	PRESENT	0
532824	531369	19515S	PARTICIPANT	\N	PRESENT	0
532825	531369	19647E	PARTICIPANT	\N	PRESENT	0
532826	531369	01057W	PARTICIPANT	\N	PRESENT	0
532827	531369	14259Y	PARTICIPANT	\N	PRESENT	0
532828	531369	19599P	PARTICIPANT	\N	PRESENT	0
532829	531369	19543W	PARTICIPANT	\N	PRESENT	0
532830	531369	14069U	PARTICIPANT	\N	PRESENT	0
532831	531369	20066E	PARTICIPANT	\N	PRESENT	0
532832	531369	19762G	PARTICIPANT	\N	PRESENT	0
532833	531369	14073Q	PARTICIPANT	\N	PRESENT	0
532834	531369	20124W	PARTICIPANT	\N	PRESENT	0
532835	531369	20060X	PARTICIPANT	\N	PRESENT	0
532836	531369	20126Y	PARTICIPANT	\N	PRESENT	0
532837	531369	20054A	PARTICIPANT	\N	PRESENT	0
532838	531369	19441R	PARTICIPANT	\N	PRESENT	0
532839	531369	11103C	PARTICIPANT	\N	PRESENT	0
532840	531369	20052X	PARTICIPANT	\N	PRESENT	0
532841	531369	14357A	PARTICIPANT	\N	PRESENT	0
532842	531369	14217N	PARTICIPANT	\N	PRESENT	0
532843	531369	98022P	PARTICIPANT	\N	PRESENT	0
532844	531369	19545Y	PARTICIPANT	\N	PRESENT	0
532845	531369	20090E	PARTICIPANT	\N	PRESENT	0
532846	531369	19703U	PARTICIPANT	\N	PRESENT	0
532847	531369	20042V	PARTICIPANT	\N	PRESENT	0
532848	531369	19699S	PARTICIPANT	\N	PRESENT	0
532849	531369	14033T	PARTICIPANT	\N	PRESENT	0
532850	531369	19511N	PARTICIPANT	\N	PRESENT	0
532851	531369	19739H	PARTICIPANT	\N	PRESENT	0
532852	531369	11053K	PARTICIPANT	\N	PRESENT	0
532853	531369	08015R	PARTICIPANT	\N	PRESENT	0
532854	531369	14205J	PARTICIPANT	\N	PRESENT	0
532855	531369	08009T	PARTICIPANT	\N	PRESENT	0
532856	531369	01034P	PARTICIPANT	\N	PRESENT	0
532857	531369	20072C	PARTICIPANT	\N	PRESENT	0
532858	531369	19611R	PARTICIPANT	\N	PRESENT	0
532859	531369	14231L	PARTICIPANT	\N	PRESENT	0
532860	531369	19723Y	PARTICIPANT	\N	PRESENT	0
532861	531369	19745F	PARTICIPANT	\N	PRESENT	0
532862	531369	19467C	PARTICIPANT	\N	PRESENT	0
532863	531369	11072N	PARTICIPANT	\N	PRESENT	0
532864	531369	19954N	PARTICIPANT	\N	PRESENT	0
532865	531369	20180F	PARTICIPANT	\N	PRESENT	0
532866	531369	20026V	PARTICIPANT	\N	PRESENT	0
532867	531369	20144B	PARTICIPANT	\N	PRESENT	0
532868	531369	20140W	PARTICIPANT	\N	PRESENT	0
532869	531369	14083S	PARTICIPANT	\N	PRESENT	0
532870	531369	19673G	PARTICIPANT	\N	PRESENT	0
532871	531369	20038A	PARTICIPANT	\N	PRESENT	0
515065	512705	19629C	PARTICIPANT	\N	PRESENT	1
515066	512705	08018U	PARTICIPANT	\N	PRESENT	1
515067	512705	19725B	PARTICIPANT	\N	PRESENT	1
515068	512705	14179A	PARTICIPANT	\N	PRESENT	1
515069	512705	19581D	PARTICIPANT	\N	PRESENT	1
515070	512705	11072N	PARTICIPANT	\N	PRESENT	1
515071	512705	14107H	PARTICIPANT	\N	PRESENT	1
515439	502367	11103C	PARTICIPANT	\N	PRESENT	0
517837	513049	19511N	PARTICIPANT	\N	PRESENT	0
517838	513049	04070G	PARTICIPANT	\N	PRESENT	0
517839	513049	19745F	PARTICIPANT	\N	PRESENT	0
517845	513049	19758L	PARTICIPANT	\N	PRESENT	0
517863	513049	04085P	PARTICIPANT	\N	PRESENT	0
517864	513049	20092G	PARTICIPANT	\N	PRESENT	0
517865	513049	20134Y	PARTICIPANT	\N	PRESENT	0
517866	513049	19347U	PARTICIPANT	\N	PRESENT	0
517867	513049	11072N	PARTICIPANT	\N	PRESENT	0
517868	513049	19301E	PARTICIPANT	\N	PRESENT	0
517869	513049	08061X	PARTICIPANT	\N	PRESENT	0
517870	513049	19685L	PARTICIPANT	\N	PRESENT	0
517871	513049	20110Q	PARTICIPANT	\N	PRESENT	0
517872	513049	14038Y	PARTICIPANT	\N	PRESENT	0
517873	513049	20044X	PARTICIPANT	\N	PRESENT	0
517874	513049	19545Y	PARTICIPANT	\N	PRESENT	0
517875	513049	20086J	PARTICIPANT	\N	PRESENT	0
517876	513049	04057K	PARTICIPANT	\N	PRESENT	0
517877	513049	19966S	PARTICIPANT	\N	PRESENT	0
517878	513049	14031R	PARTICIPANT	\N	PRESENT	0
517879	513049	11012A	PARTICIPANT	\N	PRESENT	0
517880	513049	14041T	PARTICIPANT	\N	PRESENT	0
517881	513049	19553Y	PARTICIPANT	\N	PRESENT	0
517882	513049	14107H	PARTICIPANT	\N	PRESENT	0
517883	513049	19573D	PARTICIPANT	\N	PRESENT	0
517884	513049	11083R	PARTICIPANT	\N	PRESENT	0
517885	513049	20132W	PARTICIPANT	\N	PRESENT	0
517886	513049	19507S	PARTICIPANT	\N	PRESENT	0
517887	513049	11080N	PARTICIPANT	\N	PRESENT	0
517888	513049	20050V	PARTICIPANT	\N	PRESENT	0
517889	513049	19515S	PARTICIPANT	\N	PRESENT	0
517890	513049	20140W	PARTICIPANT	\N	PRESENT	0
517891	513049	20056C	PARTICIPANT	\N	PRESENT	0
517892	513049	19673G	PARTICIPANT	\N	PRESENT	0
517893	513049	01028R	PARTICIPANT	\N	PRESENT	0
517894	513049	11045K	PARTICIPANT	\N	PRESENT	0
517895	513049	20180F	PARTICIPANT	\N	PRESENT	0
517896	513049	19599P	PARTICIPANT	\N	PRESENT	0
517897	513049	14257W	PARTICIPANT	\N	PRESENT	0
517898	513049	19954N	PARTICIPANT	\N	PRESENT	0
517899	513049	04059M	PARTICIPANT	\N	PRESENT	0
517900	513049	14021P	PARTICIPANT	\N	PRESENT	0
517901	513049	08015R	PARTICIPANT	\N	PRESENT	0
517902	513049	07029T	PARTICIPANT	\N	PRESENT	0
517903	513049	14229S	PARTICIPANT	\N	PRESENT	0
517904	513049	19399H	PARTICIPANT	\N	PRESENT	0
517905	513049	20018V	PARTICIPANT	\N	PRESENT	0
517906	513049	11066Q	PARTICIPANT	\N	PRESENT	0
517907	513049	20098N	PARTICIPANT	\N	PRESENT	0
517908	513049	08045X	PARTICIPANT	\N	PRESENT	0
517909	513049	20138D	PARTICIPANT	\N	PRESENT	0
517910	513049	20128B	PARTICIPANT	\N	PRESENT	0
517911	513049	20172F	PARTICIPANT	\N	PRESENT	0
517912	513049	11065P	PARTICIPANT	\N	PRESENT	0
517835	513049	19563B	PARTICIPANT	\N	PRESENT	0
517836	513049	11067R	PARTICIPANT	\N	PRESENT	0
517913	513049	01057W	PARTICIPANT	\N	PRESENT	0
517914	513049	17367Q	PARTICIPANT	\N	PRESENT	0
517915	513049	14147R	PARTICIPANT	\N	PRESENT	0
517916	513049	19591F	PARTICIPANT	\N	PRESENT	0
517917	513049	20032T	PARTICIPANT	\N	PRESENT	0
517918	513049	14225N	PARTICIPANT	\N	PRESENT	0
517919	513049	19631V	PARTICIPANT	\N	PRESENT	0
517920	513049	20068G	PARTICIPANT	\N	PRESENT	0
517921	513049	20024T	PARTICIPANT	\N	PRESENT	0
517922	513049	20082E	PARTICIPANT	\N	PRESENT	0
517923	513049	19383Y	PARTICIPANT	\N	PRESENT	0
517924	513049	12028B	PARTICIPANT	\N	PRESENT	0
517934	513049	19762G	PARTICIPANT	\N	PRESENT	0
517926	513049	20090E	PARTICIPANT	\N	PRESENT	0
517927	513049	20094J	PARTICIPANT	\N	PRESENT	0
517928	513049	19705W	PARTICIPANT	\N	PRESENT	0
517929	513049	11090Q	PARTICIPANT	\N	PRESENT	0
517930	513049	20108W	PARTICIPANT	\N	PRESENT	0
517931	513049	20060X	PARTICIPANT	\N	PRESENT	0
517932	513049	20104S	PARTICIPANT	\N	PRESENT	0
517933	513049	11033F	PARTICIPANT	\N	PRESENT	0
517935	513049	14097Y	PARTICIPANT	\N	PRESENT	0
517936	513049	14151M	PARTICIPANT	\N	PRESENT	0
517937	513049	08069G	PARTICIPANT	\N	PRESENT	0
517938	513049	20118Y	PARTICIPANT	\N	PRESENT	0
517939	513049	19621T	PARTICIPANT	\N	PRESENT	0
517940	513049	14217N	PARTICIPANT	\N	PRESENT	0
517941	513049	10006L	PARTICIPANT	\N	PRESENT	0
517942	513049	08056B	PARTICIPANT	\N	PRESENT	0
517943	513049	08028W	PARTICIPANT	\N	PRESENT	0
517944	513049	14069U	PARTICIPANT	\N	PRESENT	0
517945	513049	19413M	PARTICIPANT	\N	PRESENT	0
517946	513049	19739H	PARTICIPANT	\N	PRESENT	0
517947	513049	19415P	PARTICIPANT	\N	PRESENT	0
517948	513049	14267Y	PARTICIPANT	\N	PRESENT	0
517949	513049	11097X	PARTICIPANT	\N	PRESENT	0
517950	513049	01043Q	PARTICIPANT	\N	PRESENT	0
517951	513049	14259Y	PARTICIPANT	\N	PRESENT	0
517952	513049	14237S	PARTICIPANT	\N	PRESENT	0
517953	513049	14187A	PARTICIPANT	\N	PRESENT	0
517954	513049	04092N	PARTICIPANT	\N	PRESENT	0
517955	513049	11099A	PARTICIPANT	\N	PRESENT	0
517956	513049	08011M	PARTICIPANT	\N	PRESENT	0
517957	513049	14083S	PARTICIPANT	\N	PRESENT	0
517958	513049	14026U	PARTICIPANT	\N	PRESENT	0
517959	513049	11054L	PARTICIPANT	\N	PRESENT	0
517960	513049	19703U	PARTICIPANT	\N	PRESENT	0
517961	513049	19575F	PARTICIPANT	\N	PRESENT	0
517962	513049	01058X	PARTICIPANT	\N	PRESENT	0
517963	513049	19711U	PARTICIPANT	\N	PRESENT	0
517964	513049	17637T	PARTICIPANT	\N	PRESENT	0
517965	513049	18083K	PARTICIPANT	\N	PRESENT	0
517966	513049	14123H	PARTICIPANT	\N	PRESENT	0
517967	513049	14219Q	PARTICIPANT	\N	PRESENT	0
517968	513049	04086Q	PARTICIPANT	\N	PRESENT	0
517969	513049	19826F	PARTICIPANT	\N	PRESENT	0
517970	513049	20078J	PARTICIPANT	\N	PRESENT	0
517971	513049	20074E	PARTICIPANT	\N	PRESENT	0
517972	513049	14231L	PARTICIPANT	\N	PRESENT	0
517973	513049	14030Q	PARTICIPANT	\N	PRESENT	0
517974	513049	05012A	PARTICIPANT	\N	PRESENT	0
517975	513049	20022R	PARTICIPANT	\N	PRESENT	0
517976	513049	20040T	PARTICIPANT	\N	PRESENT	0
517977	513049	20120S	PARTICIPANT	\N	PRESENT	0
517978	513049	14189C	PARTICIPANT	\N	PRESENT	0
517979	513049	19679N	PARTICIPANT	\N	PRESENT	0
517980	513049	17229F	PARTICIPANT	\N	PRESENT	0
517981	513049	14105F	PARTICIPANT	\N	PRESENT	0
517982	513049	04033B	PARTICIPANT	\N	PRESENT	0
517983	513049	01024M	PARTICIPANT	\N	PRESENT	0
517984	513049	11053K	PARTICIPANT	\N	PRESENT	0
517985	513049	19667J	PARTICIPANT	\N	PRESENT	0
517986	513049	19691J	PARTICIPANT	\N	PRESENT	0
517987	513049	20116W	PARTICIPANT	\N	PRESENT	0
517988	513049	19611R	PARTICIPANT	\N	PRESENT	0
517989	513049	20144B	PARTICIPANT	\N	PRESENT	0
517990	513049	19749K	PARTICIPANT	\N	PRESENT	0
517991	513049	14207L	PARTICIPANT	\N	PRESENT	0
517992	513049	14205J	PARTICIPANT	\N	PRESENT	0
517993	513049	19693L	PARTICIPANT	\N	PRESENT	0
517994	513049	14331P	PARTICIPANT	\N	PRESENT	0
517995	513049	04008A	PARTICIPANT	\N	PRESENT	0
517996	513049	97011G	PARTICIPANT	\N	PRESENT	0
517997	513049	19441R	PARTICIPANT	\N	PRESENT	0
517998	513049	08018U	PARTICIPANT	\N	PRESENT	0
517999	513049	19723Y	PARTICIPANT	\N	PRESENT	0
518000	513049	19663E	PARTICIPANT	\N	PRESENT	0
518001	513049	20026V	PARTICIPANT	\N	PRESENT	0
518002	513049	11043H	PARTICIPANT	\N	PRESENT	0
518003	513049	11085T	PARTICIPANT	\N	PRESENT	0
518004	513049	14213J	PARTICIPANT	\N	PRESENT	0
518005	513049	14133K	PARTICIPANT	\N	PRESENT	0
518006	513049	14251Q	PARTICIPANT	\N	PRESENT	0
518007	513049	04042C	PARTICIPANT	\N	PRESENT	0
518008	513049	14357A	PARTICIPANT	\N	PRESENT	0
518009	513049	01060R	PARTICIPANT	\N	PRESENT	0
518010	513049	19479G	PARTICIPANT	\N	PRESENT	0
534582	534575	19599P	PARTICIPANT	\N	PRESENT	0
534583	534575	97011G	PARTICIPANT	\N	PRESENT	0
534585	534575	14179A	PARTICIPANT	\N	PRESENT	0
534587	534575	20130U	PARTICIPANT	\N	PRESENT	0
534589	534575	11054L	PARTICIPANT	\N	PRESENT	0
534603	534602	19599P	PARTICIPANT	\N	PRESENT	0
534605	534602	11054L	PARTICIPANT	\N	PRESENT	0
534664	534663	19663E	PARTICIPANT	\N	PRESENT	0
534665	534663	10006L	PARTICIPANT	\N	PRESENT	0
534666	534663	20090E	PARTICIPANT	\N	PRESENT	0
534667	534663	19693L	PARTICIPANT	\N	PRESENT	0
534668	534663	20138D	PARTICIPANT	\N	PRESENT	0
534669	534663	19667J	PARTICIPANT	\N	PRESENT	0
534670	534663	14213J	PARTICIPANT	\N	PRESENT	0
534675	534663	14223L	PARTICIPANT	\N	PRESENT	0
534676	534663	19798U	PARTICIPANT	\N	PRESENT	0
534677	534663	11097X	PARTICIPANT	\N	PRESENT	0
534678	534663	19723Y	PARTICIPANT	\N	PRESENT	0
534679	534663	14041T	PARTICIPANT	\N	PRESENT	0
534688	534289	14189C	PARTICIPANT	\N	PRESENT	0
534689	534289	20024T	PARTICIPANT	\N	PRESENT	0
534690	534289	19631V	PARTICIPANT	\N	PRESENT	0
534691	534289	14105F	PARTICIPANT	\N	PRESENT	0
534692	534289	08012N	PARTICIPANT	\N	PRESENT	0
534693	534289	11043H	PARTICIPANT	\N	PRESENT	0
534694	534289	19629C	PARTICIPANT	\N	PRESENT	0
534695	534289	08028W	PARTICIPANT	\N	PRESENT	0
534697	534289	20134Y	PARTICIPANT	\N	PRESENT	0
534699	534289	14073Q	PARTICIPANT	\N	PRESENT	0
534701	534289	19711U	PARTICIPANT	\N	PRESENT	0
534702	534289	20052X	PARTICIPANT	\N	PRESENT	0
534703	534289	14147R	PARTICIPANT	\N	PRESENT	0
534704	534289	20096L	PARTICIPANT	\N	PRESENT	0
534705	534289	19585H	PARTICIPANT	\N	PRESENT	0
534706	534289	19725B	PARTICIPANT	\N	PRESENT	0
534708	534289	20112S	PARTICIPANT	\N	PRESENT	0
534709	534289	20058E	PARTICIPANT	\N	PRESENT	0
534710	534289	19699S	PARTICIPANT	\N	PRESENT	0
534711	534289	20098N	PARTICIPANT	\N	PRESENT	0
534712	534289	20138D	PARTICIPANT	\N	PRESENT	0
534713	534289	19611R	PARTICIPANT	\N	PRESENT	0
534717	534289	19954N	PARTICIPANT	\N	PRESENT	0
534718	534289	20152B	PARTICIPANT	\N	PRESENT	0
534825	534228	19399H	PARTICIPANT	\N	PRESENT	0
534829	534228	20050V	PARTICIPANT	\N	PRESENT	0
534871	534870	14259Y	PRESIDENT	0	PRESENT	0
534872	534870	19399H	PARTICIPANT	\N	EXCUSE	0
534873	534870	20050V	PARTICIPANT	\N	EXCUSE	0
535042	534166	04085P	PARTICIPANT	\N	PRESENT	1
535043	534166	17737W	PARTICIPANT	\N	PRESENT	1
535045	534166	19725B	PARTICIPANT	\N	PRESENT	1
535046	534166	19489J	PARTICIPANT	\N	PRESENT	1
535047	534166	19649G	PARTICIPANT	\N	PRESENT	1
535048	534166	11026G	PARTICIPANT	\N	PRESENT	1
535049	534166	14001X	PARTICIPANT	\N	PRESENT	1
535245	534323	20086J	PARTICIPANT	\N	PRESENT	0
535246	534323	19383Y	PARTICIPANT	\N	PRESENT	0
535247	534323	19768N	PARTICIPANT	\N	PRESENT	0
535248	534323	20088L	PARTICIPANT	\N	PRESENT	1
535249	534323	19782L	PARTICIPANT	\N	PRESENT	0
535250	534323	11077T	PARTICIPANT	\N	PRESENT	1
535251	534323	20092G	PARTICIPANT	\N	PRESENT	0
535252	534323	14357A	PARTICIPANT	\N	PRESENT	0
535253	534323	19413M	PARTICIPANT	\N	PRESENT	0
535254	534323	20082E	PARTICIPANT	\N	PRESENT	0
535255	534323	20094J	PARTICIPANT	\N	PRESENT	1
535256	534323	04045F	PARTICIPANT	\N	PRESENT	1
535257	534323	20104S	PARTICIPANT	\N	PRESENT	0
535258	534323	19631V	PARTICIPANT	\N	PRESENT	0
535259	534323	11099A	PARTICIPANT	\N	PRESENT	0
535260	534323	19705W	PARTICIPANT	\N	PRESENT	0
535261	534323	08015R	PARTICIPANT	\N	PRESENT	0
535262	534323	19575F	PARTICIPANT	\N	PRESENT	1
535263	534323	20018V	PARTICIPANT	\N	PRESENT	0
535264	534323	08028W	PARTICIPANT	\N	PRESENT	0
535265	534323	19563B	PARTICIPANT	\N	PRESENT	0
535266	534323	20028X	PARTICIPANT	\N	PRESENT	0
535267	534323	14038Y	PARTICIPANT	\N	PRESENT	0
535268	534323	20030R	PARTICIPANT	\N	PRESENT	1
535269	534323	19467C	PARTICIPANT	\N	PRESENT	0
535270	534323	14187A	PARTICIPANT	\N	PRESENT	0
535271	534323	20144B	PARTICIPANT	\N	PRESENT	0
535272	534323	19695N	PARTICIPANT	\N	PRESENT	0
535273	534323	14033T	PARTICIPANT	\N	PRESENT	0
535274	534323	11090Q	PRESIDENT	0	PRESENT	0
535275	534323	01025N	PARTICIPANT	\N	PRESENT	0
535276	534323	20054A	PARTICIPANT	\N	PRESENT	0
535277	534323	20174H	PARTICIPANT	\N	PRESENT	1
535278	534323	20062A	PARTICIPANT	\N	PRESENT	1
535279	534323	14251Q	PARTICIPANT	\N	PRESENT	1
535280	534323	19507S	PARTICIPANT	\N	PRESENT	0
535281	534323	19747H	PARTICIPANT	\N	PRESENT	1
535282	534323	14207L	PARTICIPANT	\N	PRESENT	0
535283	534323	14257W	PARTICIPANT	\N	PRESENT	0
535284	534277	20118Y	PARTICIPANT	\N	PRESENT	0
535285	534277	20020P	PARTICIPANT	\N	EXCUSE	0
535286	534323	19441R	PARTICIPANT	\N	PRESENT	0
535287	534323	20038A	PARTICIPANT	\N	PRESENT	0
535288	530867	19533U	PARTICIPANT	\N	PRESENT	0
535289	530867	11043H	PARTICIPANT	\N	PRESENT	0
535290	534323	01043Q	PARTICIPANT	\N	PRESENT	0
535291	534353	07029T	PARTICIPANT	\N	PRESENT	0
535292	534353	19531S	PARTICIPANT	\N	PRESENT	0
535293	534323	14205J	PARTICIPANT	\N	PRESENT	1
535294	534353	11053K	PARTICIPANT	\N	PRESENT	0
535295	534353	20116W	PARTICIPANT	\N	PRESENT	0
535296	534353	08034U	PARTICIPANT	\N	PRESENT	0
535297	534353	19647E	PARTICIPANT	\N	PRESENT	0
535300	530867	04070G	PARTICIPANT	\N	PRESENT	1
535301	530867	20098N	PARTICIPANT	\N	PRESENT	1
535302	530867	19573D	PARTICIPANT	\N	PRESENT	1
535303	530867	08017T	PARTICIPANT	\N	PRESENT	1
535304	530867	20124W	PARTICIPANT	\N	PRESENT	1
535305	530867	20026V	PARTICIPANT	\N	PRESENT	1
535306	530867	20132W	PARTICIPANT	\N	PRESENT	0
535307	530867	19643A	PARTICIPANT	\N	PRESENT	1
535309	530867	20058E	PARTICIPANT	\N	PRESENT	1
535310	530867	11109J	PARTICIPANT	\N	EXCUSE	0
535312	530867	11104D	PARTICIPANT	\N	PRESENT	1
535313	530867	17589D	PARTICIPANT	\N	PRESENT	1
535314	534277	19369B	PARTICIPANT	\N	PRESENT	0
535417	534168	04085P	PARTICIPANT	\N	PRESENT	1
535418	534168	19543W	PARTICIPANT	\N	PRESENT	1
535419	534168	11033F	PARTICIPANT	\N	PRESENT	1
535420	534168	14069U	PARTICIPANT	\N	PRESENT	1
535421	534168	14053L	PARTICIPANT	\N	PRESENT	1
535422	534168	07004J	PARTICIPANT	\N	PRESENT	1
535423	534168	19489J	PARTICIPANT	\N	PRESENT	1
535424	534168	19581D	PARTICIPANT	\N	PRESENT	1
535425	534168	11072N	PARTICIPANT	\N	PRESENT	1
535426	534168	14107H	PARTICIPANT	\N	PRESENT	1
535427	534168	19675J	PARTICIPANT	\N	PRESENT	1
535428	534169	19581D	PARTICIPANT	\N	PRESENT	0
535429	534169	04047H	PRESIDENT	0	PRESENT	0
535430	534169	01028R	PARTICIPANT	\N	PRESENT	0
535431	534169	19447X	PARTICIPANT	\N	PRESENT	0
535432	534169	14231L	PARTICIPANT	\N	PRESENT	0
535433	534169	05008E	PARTICIPANT	\N	PRESENT	0
535434	534169	19489J	PARTICIPANT	\N	PRESENT	0
535435	534169	17737W	PARTICIPANT	\N	PRESENT	0
535436	534169	20108W	PARTICIPANT	\N	PRESENT	0
535437	534169	14147R	PARTICIPANT	\N	PRESENT	0
535438	534169	14151M	PARTICIPANT	\N	PRESENT	0
535439	534169	14215L	PARTICIPANT	\N	PRESENT	0
535440	534169	08018U	PARTICIPANT	\N	PRESENT	0
535441	534353	19545Y	PARTICIPANT	\N	PRESENT	1
535442	534353	04086Q	PARTICIPANT	\N	PRESENT	1
535443	534353	14327T	PARTICIPANT	\N	PRESENT	1
535444	534353	04071H	PARTICIPANT	\N	PRESENT	1
535445	534353	11110B	PARTICIPANT	\N	PRESENT	1
535446	534353	08010L	PARTICIPANT	\N	PRESENT	1
535447	534353	12016W	PARTICIPANT	\N	PRESENT	1
535448	534353	19479G	PARTICIPANT	\N	PRESENT	1
535449	534353	19667J	PARTICIPANT	\N	PRESENT	0
535450	534257	01043Q	PARTICIPANT	\N	PRESENT	0
535451	534257	14211G	PARTICIPANT	\N	PRESENT	0
535452	534257	20068G	PARTICIPANT	\N	PRESENT	0
535453	534257	14193X	PARTICIPANT	\N	PRESENT	0
515956	515955	20100N	PARTICIPANT	\N	PRESENT	0
515957	515955	11083R	PARTICIPANT	\N	PRESENT	0
515958	515955	14073Q	PARTICIPANT	\N	PRESENT	0
515959	515955	04057K	PARTICIPANT	\N	PRESENT	0
515960	515955	14331P	PARTICIPANT	\N	PRESENT	0
515965	512883	19631V	PARTICIPANT	\N	PRESENT	0
515966	512883	19577H	PARTICIPANT	\N	PRESENT	0
515967	512883	17023S	PARTICIPANT	\N	PRESENT	0
515970	512883	19347U	PARTICIPANT	\N	PRESENT	0
515971	512883	19691J	PARTICIPANT	\N	PRESENT	0
515972	512883	19329S	PARTICIPANT	\N	PRESENT	0
515973	512883	20034V	PARTICIPANT	\N	PRESENT	0
515974	512883	11072N	PARTICIPANT	\N	PRESENT	0
515975	512883	20150Y	PARTICIPANT	\N	PRESENT	0
515978	515740	20024T	PARTICIPANT	\N	PRESENT	0
515979	515740	20114U	PARTICIPANT	\N	PRESENT	0
515980	515740	19553Y	PARTICIPANT	\N	PRESENT	0
515981	515740	14147R	PARTICIPANT	\N	PRESENT	0
515982	515740	92040Q	PARTICIPANT	\N	PRESENT	0
515983	509962	05008E	PARTICIPANT	\N	PRESENT	0
515984	509962	04047H	PARTICIPANT	\N	PRESENT	0
515985	509962	11056N	PARTICIPANT	\N	PRESENT	0
515986	509962	20110Q	PARTICIPANT	\N	PRESENT	1
515987	509962	95063L	PARTICIPANT	\N	PRESENT	0
515988	509962	14107H	PARTICIPANT	\N	PRESENT	1
515989	509962	19489J	PARTICIPANT	\N	PRESENT	0
517009	517008	20024T	PARTICIPANT	\N	PRESENT	0
517010	517008	19531S	PARTICIPANT	\N	PRESENT	0
517011	517008	08010L	PARTICIPANT	\N	PRESENT	0
517012	517008	97011G	PARTICIPANT	\N	PRESENT	0
517037	517036	19683J	PARTICIPANT	\N	PRESENT	0
517038	517036	19723Y	PARTICIPANT	\N	PRESENT	0
517039	517036	04092N	PARTICIPANT	\N	PRESENT	0
520382	519225	04085P	PARTICIPANT	\N	PRESENT	1
520383	519225	19954N	PARTICIPANT	\N	PRESENT	1
520384	519225	20110Q	PARTICIPANT	\N	PRESENT	1
520385	519225	11033F	PARTICIPANT	\N	PRESENT	1
520386	519225	14069U	PARTICIPANT	\N	PRESENT	1
520387	519225	14089Y	PARTICIPANT	\N	PRESENT	1
520388	519225	19629C	PARTICIPANT	\N	PRESENT	1
520389	519225	20074E	PARTICIPANT	\N	PRESENT	1
520390	519225	19489J	PARTICIPANT	\N	PRESENT	1
520391	519225	19581D	PARTICIPANT	\N	PRESENT	1
520392	519225	95063L	PARTICIPANT	\N	PRESENT	1
520393	519225	14107H	PARTICIPANT	\N	PRESENT	1
521135	519227	14069U	PARTICIPANT	\N	PRESENT	0
521136	519227	19489J	PARTICIPANT	\N	PRESENT	0
521137	519227	19729F	PARTICIPANT	\N	EXCUSE	0
521138	519227	11085T	PARTICIPANT	\N	PRESENT	0
521174	519227	04085P	PARTICIPANT	\N	PRESENT	1
521177	519227	19629C	PARTICIPANT	\N	PRESENT	1
521178	519227	11056N	PARTICIPANT	\N	PRESENT	1
521179	519227	20074E	PARTICIPANT	\N	PRESENT	1
521372	519135	14189C	PARTICIPANT	\N	PRESENT	0
521373	519135	20024T	PARTICIPANT	\N	PRESENT	0
521374	519135	14030Q	PRESIDENT	0	PRESENT	0
521375	519135	20138D	PARTICIPANT	\N	PRESENT	0
521376	519135	17737W	PARTICIPANT	\N	EXCUSE	0
521377	519135	20080C	PARTICIPANT	\N	EXCUSE	0
521378	519135	19621T	PARTICIPANT	\N	PRESENT	0
521379	519135	11031D	PARTICIPANT	\N	PRESENT	0
521380	519135	19693L	PARTICIPANT	\N	PRESENT	0
521381	519135	19599P	PARTICIPANT	\N	PRESENT	0
521382	519135	20106U	PARTICIPANT	\N	PRESENT	0
521383	519135	14179A	PARTICIPANT	\N	PRESENT	0
521384	519135	20066E	PARTICIPANT	\N	PRESENT	0
521385	519135	19715Y	PARTICIPANT	\N	PRESENT	0
521386	519135	20056C	PARTICIPANT	\N	PRESENT	0
521387	519135	07029T	PARTICIPANT	\N	EXCUSE	0
521388	519135	08017T	PARTICIPANT	\N	PRESENT	0
521389	519135	14109K	PARTICIPANT	\N	PRESENT	0
521390	519135	20118Y	PARTICIPANT	\N	PRESENT	0
521391	519135	20130U	PARTICIPANT	\N	PRESENT	0
521392	519135	19798U	PARTICIPANT	\N	PRESENT	0
521393	519135	11045K	PARTICIPANT	\N	EXCUSE	0
521394	519135	20098N	PARTICIPANT	\N	PRESENT	0
521395	519135	19527W	PARTICIPANT	\N	PRESENT	0
521396	519135	20046A	PARTICIPANT	\N	PRESENT	0
521397	519135	19749K	PARTICIPANT	\N	PRESENT	0
525258	524071	04008A	PARTICIPANT	\N	EXCUSE	0
525259	524071	14021P	PARTICIPANT	\N	EXCUSE	0
525260	524071	19585H	PARTICIPANT	\N	EXCUSE	0
525261	524071	04085P	PARTICIPANT	\N	PRESENT	1
525262	524071	14069U	PARTICIPANT	\N	PRESENT	1
525263	524071	20114U	PARTICIPANT	\N	PRESENT	1
525264	524071	19629C	PARTICIPANT	\N	PRESENT	1
525265	524071	19725B	PARTICIPANT	\N	PRESENT	1
525266	524071	14179A	PARTICIPANT	\N	PRESENT	1
525267	524071	19489J	PARTICIPANT	\N	PRESENT	1
525268	524071	19649G	PARTICIPANT	\N	PRESENT	1
525269	524071	19729F	PARTICIPANT	\N	PRESENT	1
525270	524071	11072N	PARTICIPANT	\N	PRESENT	1
525271	524071	14107H	PARTICIPANT	\N	PRESENT	1
525272	524071	19675J	PARTICIPANT	\N	PRESENT	1
526435	526434	14357A	PARTICIPANT	\N	PRESENT	0
526436	526434	19647E	PARTICIPANT	\N	PRESENT	0
526437	526434	14179A	PARTICIPANT	\N	PRESENT	0
526438	526434	19711U	PARTICIPANT	\N	PRESENT	0
526439	526434	14071N	PARTICIPANT	\N	PRESENT	0
526440	526434	19762G	PARTICIPANT	\N	PRESENT	0
526448	526371	17965H	PARTICIPANT	\N	PRESENT	1
526457	526456	01034P	PARTICIPANT	\N	PRESENT	0
526458	526456	04043D	PARTICIPANT	\N	PRESENT	0
526459	526456	04035D	PARTICIPANT	\N	PRESENT	0
526460	526456	14121F	PARTICIPANT	\N	PRESENT	0
526461	526456	14031R	PARTICIPANT	\N	PRESENT	0
526462	526456	20062A	PARTICIPANT	\N	PRESENT	0
526463	526456	20084G	PARTICIPANT	\N	PRESENT	0
526464	526456	19369B	PARTICIPANT	\N	PRESENT	0
526465	526456	20082E	PARTICIPANT	\N	PRESENT	0
527440	527439	20076G	PARTICIPANT	\N	PRESENT	0
527441	527439	20032T	PARTICIPANT	\N	PRESENT	0
527442	527439	14189C	PARTICIPANT	\N	PRESENT	0
527443	527439	20024T	PARTICIPANT	\N	PRESENT	0
527444	527439	14207L	PARTICIPANT	\N	PRESENT	0
527445	527439	11043H	PARTICIPANT	\N	PRESENT	0
527446	527439	19563B	PARTICIPANT	\N	PRESENT	0
527447	527439	19762G	PARTICIPANT	\N	PRESENT	0
527448	527439	20118Y	PARTICIPANT	\N	PRESENT	0
527449	527439	19713W	PARTICIPANT	\N	PRESENT	0
527450	527439	14179A	PARTICIPANT	\N	PRESENT	0
527451	527439	20044X	PARTICIPANT	\N	PRESENT	0
527452	527439	14205J	PARTICIPANT	\N	PRESENT	0
527453	527439	20082E	PARTICIPANT	\N	PRESENT	0
527454	527439	04045F	PARTICIPANT	\N	PRESENT	0
527455	527439	20058E	PARTICIPANT	\N	PRESENT	0
527456	527439	11099A	PARTICIPANT	\N	PRESENT	0
527457	527439	19745F	PARTICIPANT	\N	PRESENT	0
527458	527439	16685X	PARTICIPANT	\N	PRESENT	0
527459	527439	19723Y	PARTICIPANT	\N	PRESENT	0
527460	527439	11097X	PARTICIPANT	\N	PRESENT	0
527927	527925	20032T	PARTICIPANT	\N	PRESENT	0
527928	527925	19631V	PARTICIPANT	\N	PRESENT	0
527929	527925	19515S	PARTICIPANT	\N	PRESENT	0
527930	527925	19954N	PARTICIPANT	\N	PRESENT	0
527932	527925	14069U	PARTICIPANT	\N	PRESENT	0
527933	527925	20088L	PARTICIPANT	\N	PRESENT	0
527935	527925	14105F	PARTICIPANT	\N	PRESENT	0
527936	527925	19747H	PARTICIPANT	\N	PRESENT	0
527938	527925	20090E	PARTICIPANT	\N	PRESENT	0
527939	527925	14207L	PARTICIPANT	\N	PRESENT	0
527940	527925	20104S	PARTICIPANT	\N	PRESENT	0
527941	527925	14083S	PARTICIPANT	\N	PRESENT	0
527943	527925	14329V	PARTICIPANT	\N	PRESENT	0
527945	527925	08028W	PARTICIPANT	\N	PRESENT	0
527948	527925	14038Y	PARTICIPANT	\N	PRESENT	0
527958	527925	20144B	PARTICIPANT	\N	PRESENT	0
527959	527925	19467C	PARTICIPANT	\N	PRESENT	0
527960	527925	18083K	PARTICIPANT	\N	PRESENT	0
527964	527925	14357A	PARTICIPANT	\N	PRESENT	0
527965	527925	19693L	PARTICIPANT	\N	PRESENT	0
527966	527925	17589D	PARTICIPANT	\N	PRESENT	0
527967	527925	19719D	PARTICIPANT	\N	PRESENT	0
527968	527925	20140W	PARTICIPANT	\N	PRESENT	0
527969	527925	01024M	PARTICIPANT	\N	PRESENT	0
527970	527925	19507S	PARTICIPANT	\N	PRESENT	0
527971	527925	20174H	PARTICIPANT	\N	PRESENT	0
527972	527925	01025N	PARTICIPANT	\N	PRESENT	0
527973	527925	97011G	PARTICIPANT	\N	PRESENT	0
532317	531287	20086J	PARTICIPANT	\N	PRESENT	0
532318	531287	14038Y	PARTICIPANT	\N	PRESENT	0
532319	531287	19782L	PARTICIPANT	\N	PRESENT	0
532320	531287	19695N	PARTICIPANT	\N	PRESENT	0
532321	531287	14033T	PARTICIPANT	\N	PRESENT	0
532322	531287	11090Q	PRESIDENT	0	PRESENT	0
532323	531287	20054A	PARTICIPANT	\N	PRESENT	0
532324	531287	19631V	PARTICIPANT	\N	PRESENT	0
532325	531287	20062A	PARTICIPANT	\N	PRESENT	0
532326	531287	19507S	PARTICIPANT	\N	PRESENT	0
532327	531287	08015R	PARTICIPANT	\N	PRESENT	0
532328	531287	19511N	PARTICIPANT	\N	PRESENT	0
532329	531287	08028W	PARTICIPANT	\N	PRESENT	0
532330	531287	14257W	PARTICIPANT	\N	PRESENT	0
532331	530821	19697Q	PARTICIPANT	\N	PRESENT	1
532332	530821	11067R	PARTICIPANT	\N	PRESENT	0
532333	530821	20090E	PARTICIPANT	\N	PRESENT	0
532334	530821	19798U	PARTICIPANT	\N	PRESENT	1
532335	530821	19569H	PARTICIPANT	\N	PRESENT	1
532336	530821	11097X	PARTICIPANT	\N	PRESENT	0
532337	530821	14223L	PARTICIPANT	\N	PRESENT	1
532338	530821	19703U	PARTICIPANT	\N	PRESENT	0
532339	530821	19553Y	PARTICIPANT	\N	PRESENT	0
532340	530821	11031D	PARTICIPANT	\N	PRESENT	1
532341	530821	19679N	PARTICIPANT	\N	PRESENT	0
532342	530821	14042U	PARTICIPANT	\N	PRESENT	0
532343	530821	14195A	PARTICIPANT	\N	PRESENT	0
532344	530821	14213J	PARTICIPANT	\N	PRESENT	0
532345	530821	14217N	PARTICIPANT	\N	PRESENT	0
532346	530821	19683J	PARTICIPANT	\N	PRESENT	0
532347	530821	10006L	PRESIDENT	0	PRESENT	0
532348	530821	20130U	PARTICIPANT	\N	PRESENT	0
532349	530821	04057K	PARTICIPANT	\N	PRESENT	1
532350	530821	04092N	PARTICIPANT	0	PRESENT	0
532351	530821	17965H	PARTICIPANT	\N	PRESENT	0
532352	530821	19691J	PARTICIPANT	\N	PRESENT	0
532353	530821	20172F	PARTICIPANT	\N	PRESENT	1
532354	530821	14071N	PARTICIPANT	\N	PRESENT	0
532355	530821	19657G	PARTICIPANT	\N	PRESENT	1
532356	530821	19760E	PARTICIPANT	\N	PRESENT	1
532359	531287	19413M	PARTICIPANT	\N	PRESENT	0
532360	531147	11040E	PARTICIPANT	\N	PRESENT	0
532361	531147	19741B	PARTICIPANT	\N	PRESENT	0
532362	531147	14225N	PRESIDENT	0	PRESENT	0
532363	531287	19768N	PARTICIPANT	\N	PRESENT	1
532364	531287	04045F	PARTICIPANT	\N	PRESENT	1
532365	531287	20174H	PARTICIPANT	\N	PRESENT	1
532366	531287	11099A	PARTICIPANT	\N	PRESENT	1
532367	531287	14207L	PARTICIPANT	\N	PRESENT	1
532368	531147	01048V	PARTICIPANT	\N	PRESENT	0
532369	531147	19647E	PARTICIPANT	\N	PRESENT	0
532370	531147	19335Q	PARTICIPANT	\N	PRESENT	0
532371	531147	14083S	PARTICIPANT	\N	PRESENT	0
532372	531147	19711U	PARTICIPANT	\N	PRESENT	0
532373	531147	01057W	PARTICIPANT	\N	PRESENT	0
532374	531147	20126Y	PARTICIPANT	\N	PRESENT	0
532375	531147	20070A	PARTICIPANT	\N	PRESENT	0
532376	531147	20116W	PARTICIPANT	\N	PRESENT	0
532377	531147	08009T	PARTICIPANT	\N	PRESENT	0
532378	531147	14331P	PARTICIPANT	\N	PRESENT	0
532379	531147	11048N	PARTICIPANT	\N	PRESENT	0
532381	531147	14121F	PARTICIPANT	\N	PRESENT	0
532382	531147	20080C	PARTICIPANT	\N	PRESENT	0
532385	531147	20022R	PARTICIPANT	\N	PRESENT	0
532414	531317	14053L	PARTICIPANT	\N	PRESENT	0
532415	531317	19954N	PARTICIPANT	\N	PRESENT	0
532416	531317	14111D	PARTICIPANT	\N	PRESENT	0
532417	531317	14215L	PARTICIPANT	\N	PRESENT	0
532418	531317	14231L	PARTICIPANT	\N	PRESENT	0
532421	531317	11085T	PARTICIPANT	\N	PRESENT	0
532424	531317	20074E	PARTICIPANT	\N	PRESENT	0
532425	531317	20108W	PARTICIPANT	\N	PRESENT	0
532427	531317	04047H	PRESIDENT	0	PRESENT	0
532430	531147	07029T	PARTICIPANT	\N	PRESENT	0
533080	531369	19533U	PARTICIPANT	\N	PRESENT	0
532558	531147	19687N	PARTICIPANT	\N	PRESENT	0
532559	531147	20044X	PARTICIPANT	\N	PRESENT	0
532560	531147	11012A	PARTICIPANT	\N	PRESENT	0
533083	531369	19551W	PARTICIPANT	\N	PRESENT	0
532562	529296	19333N	PARTICIPANT	\N	PRESENT	0
532563	529296	19782L	PARTICIPANT	\N	PRESENT	0
532564	529296	19549D	PARTICIPANT	\N	PRESENT	0
532565	529296	19441R	PARTICIPANT	\N	PRESENT	0
532566	529296	19820Y	PARTICIPANT	\N	PRESENT	0
532567	529296	19826F	PARTICIPANT	\N	PRESENT	0
532568	529296	20020P	PARTICIPANT	\N	PRESENT	1
532569	529296	20018V	PARTICIPANT	\N	PRESENT	1
532570	529296	11065P	PARTICIPANT	\N	PRESENT	0
532571	529296	19525U	PARTICIPANT	\N	PRESENT	0
532572	529296	20038A	PARTICIPANT	\N	PRESENT	0
532573	529296	19695N	PARTICIPANT	\N	PRESENT	0
532574	529296	20046A	PARTICIPANT	\N	PRESENT	0
532575	529296	01025N	PARTICIPANT	\N	PRESENT	0
532576	529296	20054A	PARTICIPANT	\N	PRESENT	0
532577	529296	17229F	PARTICIPANT	\N	PRESENT	0
532578	529296	20062A	PARTICIPANT	\N	PRESENT	0
532579	529296	20068G	PARTICIPANT	\N	PRESENT	0
532580	529296	14257W	PARTICIPANT	\N	PRESENT	0
532581	529296	19383Y	PARTICIPANT	\N	PRESENT	0
532582	529296	19701S	PARTICIPANT	\N	PRESENT	1
532583	529296	20092G	PARTICIPANT	\N	PRESENT	0
532584	529296	01043Q	PARTICIPANT	\N	PRESENT	0
532585	529296	14357A	PARTICIPANT	\N	PRESENT	0
532586	529296	20076G	PARTICIPANT	\N	PRESENT	1
532587	529296	19387D	PARTICIPANT	\N	PRESENT	1
532589	529296	19413M	PARTICIPANT	\N	PRESENT	0
532590	529296	14219Q	PRESIDENT	0	PRESENT	0
532591	529296	20082E	PARTICIPANT	\N	PRESENT	0
532592	529296	14221J	PARTICIPANT	\N	PRESENT	0
532593	529296	19599P	PARTICIPANT	\N	PRESENT	0
532594	529296	20102Q	PARTICIPANT	\N	PRESENT	0
532595	529296	19631V	PARTICIPANT	\N	PRESENT	0
532596	529296	18083K	PARTICIPANT	\N	PRESENT	0
532597	529296	20106U	PARTICIPANT	\N	PRESENT	1
532598	529296	20118Y	PARTICIPANT	\N	PRESENT	0
532599	529296	08015R	PARTICIPANT	\N	PRESENT	0
532600	529296	19503N	PARTICIPANT	\N	PRESENT	0
532601	529296	19511N	PARTICIPANT	\N	PRESENT	0
532602	529296	08028W	PARTICIPANT	\N	PRESENT	0
532603	529296	17637T	PARTICIPANT	\N	PRESENT	0
532604	529296	14031R	PARTICIPANT	\N	PRESENT	0
532605	529296	20144B	PARTICIPANT	\N	PRESENT	0
532606	529296	14033T	PARTICIPANT	\N	PRESENT	0
532607	529296	14169X	PARTICIPANT	\N	PRESENT	0
532608	529296	14205J	PARTICIPANT	\N	PRESENT	0
532610	529296	19739H	PARTICIPANT	\N	PRESENT	0
532611	529296	19745F	PARTICIPANT	\N	PRESENT	0
532612	531147	11053K	PARTICIPANT	\N	PRESENT	0
532664	531147	20050V	PARTICIPANT	\N	PRESENT	0
532675	531147	19545Y	PARTICIPANT	\N	PRESENT	0
532677	531147	08034U	PARTICIPANT	\N	PRESENT	0
532682	531147	19671E	PARTICIPANT	\N	PRESENT	0
532872	531369	16685X	PARTICIPANT	\N	PRESENT	0
532873	531369	14213J	PARTICIPANT	\N	PRESENT	0
532874	531369	19826F	PARTICIPANT	\N	PRESENT	0
532875	531369	19749K	PARTICIPANT	\N	PRESENT	0
532876	531369	11085T	PARTICIPANT	\N	PRESENT	0
532877	531369	04070G	PARTICIPANT	\N	PRESENT	0
532878	531369	14327T	PARTICIPANT	\N	PRESENT	0
532879	531369	19369B	PARTICIPANT	\N	PRESENT	0
532880	531369	14030Q	PARTICIPANT	\N	PRESENT	0
532881	531369	08034U	PARTICIPANT	\N	PRESENT	0
532882	531369	19443T	PARTICIPANT	\N	PRESENT	0
532883	531369	14031R	PARTICIPANT	\N	PRESENT	0
532884	531369	19507S	PARTICIPANT	\N	PRESENT	0
532885	531369	20040T	PARTICIPANT	\N	PRESENT	0
532886	531369	11033F	PARTICIPANT	\N	PRESENT	0
532887	531369	08047A	PARTICIPANT	\N	PRESENT	0
532889	531369	14109K	PARTICIPANT	\N	PRESENT	0
532890	531369	14329V	PARTICIPANT	\N	PRESENT	0
532891	531369	12041X	PARTICIPANT	\N	PRESENT	0
532892	531369	04047H	PARTICIPANT	\N	PRESENT	0
532893	531369	14215L	PARTICIPANT	\N	PRESENT	0
532894	531369	20062A	PARTICIPANT	\N	PRESENT	0
532895	531369	14331P	PARTICIPANT	\N	PRESENT	0
518011	513049	17737W	PARTICIPANT	\N	PRESENT	0
518012	513049	19701S	PARTICIPANT	\N	PRESENT	0
518022	513049	19349W	PARTICIPANT	\N	PRESENT	0
518025	513049	19569H	PARTICIPANT	\N	PRESENT	0
518029	513049	20054A	PARTICIPANT	\N	PRESENT	0
518030	513049	20126Y	PARTICIPANT	\N	PRESENT	0
518031	513049	11101A	PARTICIPANT	\N	PRESENT	0
518032	513049	19543W	PARTICIPANT	\N	PRESENT	0
518033	513049	17023S	PARTICIPANT	\N	PRESENT	0
518045	513049	20042V	PARTICIPANT	\N	PRESENT	0
518042	513049	20048C	PARTICIPANT	\N	PRESENT	0
518044	513049	11056N	PARTICIPANT	\N	PRESENT	0
518046	513049	19531S	PARTICIPANT	\N	PRESENT	0
518047	513049	11026G	PARTICIPANT	\N	PRESENT	0
518249	513050	11045K	PARTICIPANT	\N	PRESENT	0
518250	513050	14089Y	PARTICIPANT	\N	PRESENT	0
518251	513050	20090E	PARTICIPANT	\N	PRESENT	0
518252	513050	20074E	PARTICIPANT	\N	PRESENT	0
518253	513050	19758L	PARTICIPANT	\N	PRESENT	0
518254	513050	20102Q	PARTICIPANT	\N	PRESENT	0
518255	513050	11056N	PARTICIPANT	\N	PRESENT	0
518256	513050	11033F	PARTICIPANT	\N	PRESENT	0
518257	513050	20130U	PARTICIPANT	\N	PRESENT	0
518258	513050	11026G	PARTICIPANT	\N	PRESENT	0
518259	513050	14111D	PARTICIPANT	\N	PRESENT	0
518260	513050	14107H	PARTICIPANT	\N	PRESENT	0
518261	513050	14275Y	PARTICIPANT	\N	PRESENT	0
518262	516756	07029T	PARTICIPANT	\N	PRESENT	0
518263	516756	11048N	PARTICIPANT	\N	PRESENT	0
518264	516756	19711U	PARTICIPANT	\N	PRESENT	0
518265	516756	01057W	PARTICIPANT	\N	PRESENT	0
518266	516756	19741B	PARTICIPANT	\N	PRESENT	0
518267	513050	19565D	PARTICIPANT	\N	PRESENT	0
518268	513050	20048C	PARTICIPANT	\N	PRESENT	0
518269	513050	20052X	PARTICIPANT	\N	PRESENT	0
518270	513050	01024M	PARTICIPANT	\N	PRESENT	0
518271	513050	19447X	PARTICIPANT	\N	PRESENT	0
518272	513050	04047H	PARTICIPANT	\N	PRESENT	0
518273	516756	04086Q	PARTICIPANT	\N	PRESENT	0
518274	516756	19479G	PARTICIPANT	\N	PRESENT	0
518275	516756	19349W	PARTICIPANT	\N	PRESENT	0
518276	513050	19725B	PARTICIPANT	\N	PRESENT	0
518277	516756	20080C	PARTICIPANT	\N	PRESENT	0
518278	513050	19749K	PARTICIPANT	\N	PRESENT	0
518279	516756	20070A	PARTICIPANT	\N	PRESENT	0
518280	516756	99004R	PARTICIPANT	\N	PRESENT	0
518281	516756	20022R	PARTICIPANT	\N	PRESENT	0
518282	513050	14069U	PARTICIPANT	\N	PRESENT	0
518283	513050	17023S	PARTICIPANT	\N	PRESENT	0
518284	513050	20024T	PARTICIPANT	\N	PRESENT	0
518285	516756	14331P	PARTICIPANT	\N	PRESENT	0
518286	516756	14225N	PRESIDENT	0	PRESENT	0
518287	516756	11012A	PARTICIPANT	\N	PRESENT	0
518288	516756	20116W	PARTICIPANT	\N	PRESENT	0
518289	516756	20126Y	PARTICIPANT	\N	PRESENT	0
518290	516756	08010L	PARTICIPANT	\N	PRESENT	0
518291	513050	19713W	PARTICIPANT	\N	PRESENT	0
518292	513050	18083K	PARTICIPANT	\N	PRESENT	0
518293	513050	14038Y	PARTICIPANT	\N	PRESENT	0
518294	516756	11074Q	PARTICIPANT	\N	PRESENT	0
518295	513050	14147R	PARTICIPANT	\N	PRESENT	0
518296	516756	08011M	PARTICIPANT	\N	PRESENT	0
518297	516756	20044X	PARTICIPANT	\N	PRESENT	0
518298	513050	01058X	PARTICIPANT	\N	PRESENT	0
518299	516756	19687N	PARTICIPANT	\N	PRESENT	0
518300	513050	14030Q	PARTICIPANT	\N	PRESENT	0
518301	513050	07029T	PARTICIPANT	\N	PRESENT	0
518302	513050	19679N	PARTICIPANT	\N	PRESENT	0
518303	513050	19415P	PARTICIPANT	\N	PRESENT	0
518304	513050	11072N	PARTICIPANT	\N	PRESENT	0
518305	513050	19543W	PARTICIPANT	\N	PRESENT	0
518306	513050	14151M	PARTICIPANT	\N	PRESENT	0
518307	513050	19711U	PARTICIPANT	\N	PRESENT	0
518309	513050	14026U	PARTICIPANT	\N	PRESENT	0
518310	513050	11012A	PARTICIPANT	\N	PRESENT	0
518311	513050	19631V	PARTICIPANT	\N	PRESENT	0
518312	513050	19741B	PARTICIPANT	\N	PRESENT	0
518313	513050	19421M	PARTICIPANT	\N	PRESENT	0
518314	513050	19349W	PARTICIPANT	\N	PRESENT	0
518315	513050	11048N	PARTICIPANT	\N	PRESENT	0
518316	513050	14327T	PARTICIPANT	\N	PRESENT	0
518317	513050	20126Y	PARTICIPANT	\N	PRESENT	0
518318	513050	20080C	PARTICIPANT	\N	PRESENT	0
518354	513051	20080C	PARTICIPANT	\N	PRESENT	0
518355	513051	19631V	PARTICIPANT	\N	PRESENT	0
518356	513051	19713W	PARTICIPANT	\N	PRESENT	0
518357	513051	14327T	PARTICIPANT	\N	PRESENT	0
518358	513051	19543W	PARTICIPANT	\N	PRESENT	0
518359	513051	01024M	PARTICIPANT	\N	PRESENT	0
518360	513051	19749K	PARTICIPANT	\N	PRESENT	0
518361	513051	07029T	PARTICIPANT	\N	PRESENT	0
518362	513051	19741B	PARTICIPANT	\N	PRESENT	0
518363	513051	14147R	PARTICIPANT	\N	PRESENT	0
518365	513051	01058X	PARTICIPANT	\N	PRESENT	0
518366	513051	20086J	PARTICIPANT	\N	PRESENT	0
518367	513051	20126Y	PARTICIPANT	\N	PRESENT	0
518368	513051	19711U	PARTICIPANT	\N	PRESENT	0
518369	513051	20022R	PARTICIPANT	\N	PRESENT	0
518370	513051	14107H	PARTICIPANT	\N	PRESENT	0
518371	513051	19349W	PARTICIPANT	\N	PRESENT	0
518372	513051	19565D	PARTICIPANT	\N	PRESENT	0
518373	513051	19687N	PARTICIPANT	\N	PRESENT	0
518374	513051	11040E	PARTICIPANT	\N	PRESENT	0
518375	513051	19758L	PARTICIPANT	\N	PRESENT	0
518376	513051	19689Q	PARTICIPANT	\N	PRESENT	0
518377	513051	14225N	PARTICIPANT	\N	PRESENT	0
518378	513051	19415P	PARTICIPANT	\N	PRESENT	0
518379	513051	04086Q	PARTICIPANT	\N	PRESENT	0
518380	513051	20044X	PARTICIPANT	\N	PRESENT	0
518381	513051	14038Y	PARTICIPANT	\N	PRESENT	0
518382	513051	20074E	PARTICIPANT	\N	PRESENT	0
518383	513051	01057W	PARTICIPANT	\N	PRESENT	0
518386	513051	19421M	PARTICIPANT	\N	PRESENT	0
518391	513051	19747H	PARTICIPANT	\N	PRESENT	0
518392	513051	19647E	PARTICIPANT	\N	PRESENT	0
518393	513051	08061X	PARTICIPANT	\N	PRESENT	0
518352	513051	11045K	PARTICIPANT	\N	PRESENT	0
518353	513051	11048N	PARTICIPANT	\N	PRESENT	0
518394	513051	20070A	PARTICIPANT	\N	PRESENT	0
518395	513051	11056N	PARTICIPANT	\N	PRESENT	0
518396	513051	11012A	PARTICIPANT	\N	PRESENT	0
518397	513051	20092G	PARTICIPANT	\N	PRESENT	0
518398	516876	20130U	PARTICIPANT	\N	PRESENT	0
518399	516876	20090E	PARTICIPANT	\N	PRESENT	0
518400	516876	19798U	PARTICIPANT	\N	PRESENT	1
518401	516876	19569H	PARTICIPANT	\N	PRESENT	0
518402	516876	11097X	PARTICIPANT	\N	PRESENT	0
518403	516876	19301E	PARTICIPANT	\N	PRESENT	1
518404	516876	19691J	PARTICIPANT	\N	PRESENT	0
518405	516876	19295A	PARTICIPANT	\N	PRESENT	1
518406	516876	17779H	PARTICIPANT	\N	PRESENT	0
518407	516876	19679N	PARTICIPANT	\N	PRESENT	0
518408	516876	14213J	PARTICIPANT	\N	PRESENT	0
518409	516876	14071N	PARTICIPANT	\N	PRESENT	0
518410	516876	14217N	PARTICIPANT	\N	PRESENT	0
518411	516876	04043D	PARTICIPANT	\N	PRESENT	0
518412	516876	10006L	PRESIDENT	0	PRESENT	0
518413	516876	19367Y	PARTICIPANT	\N	EXCUSE	0
518414	516876	19760E	PARTICIPANT	\N	EXCUSE	0
518426	513051	20116W	PARTICIPANT	\N	PRESENT	0
518427	513051	19531S	PARTICIPANT	\N	PRESENT	0
518428	513051	20050V	PARTICIPANT	\N	PRESENT	0
518429	513051	20082E	PARTICIPANT	\N	PRESENT	0
518430	513051	11067R	PARTICIPANT	\N	PRESENT	0
518431	513051	14189C	PARTICIPANT	\N	PRESENT	0
518432	513051	14021P	PARTICIPANT	\N	PRESENT	0
518434	513051	99004R	PARTICIPANT	\N	PRESENT	0
518435	513051	14083S	PARTICIPANT	\N	PRESENT	0
518436	513051	20058E	PARTICIPANT	\N	PRESENT	0
518437	513051	14030Q	PARTICIPANT	\N	PRESENT	0
518438	513051	20090E	PARTICIPANT	\N	PRESENT	0
518439	513051	19347U	PARTICIPANT	\N	PRESENT	0
518440	513051	14033T	PARTICIPANT	\N	PRESENT	0
519092	518907	19782L	PARTICIPANT	\N	PRESENT	0
519148	519147	14147R	PARTICIPANT	\N	PRESENT	0
519150	519149	14147R	PARTICIPANT	\N	PRESENT	0
519151	519149	19749K	PARTICIPANT	\N	PRESENT	0
519152	519139	14042U	PARTICIPANT	\N	PRESENT	0
519153	519139	19760E	PARTICIPANT	\N	PRESENT	0
519154	519139	17779H	PARTICIPANT	\N	PRESENT	0
519155	519139	20130U	PARTICIPANT	\N	PRESENT	0
535454	534257	19683J	PARTICIPANT	\N	PRESENT	0
535455	534257	11054L	PARTICIPANT	\N	PRESENT	0
535456	534257	14195A	PARTICIPANT	\N	PRESENT	0
535457	534257	19866P	PARTICIPANT	\N	PRESENT	0
535458	534257	11066Q	PARTICIPANT	\N	PRESENT	0
535459	534257	14223L	PARTICIPANT	\N	PRESENT	0
535460	534257	20056C	PARTICIPANT	\N	PRESENT	0
535461	534257	20024T	PARTICIPANT	\N	PRESENT	0
535462	534257	97011G	PARTICIPANT	\N	PRESENT	0
535463	534257	14267Y	PARTICIPANT	\N	PRESENT	0
535464	534257	20040T	PARTICIPANT	\N	PRESENT	0
535465	534257	20052X	PARTICIPANT	\N	PRESENT	0
535466	534257	19367Y	PARTICIPANT	\N	PRESENT	0
535467	534257	20116W	PARTICIPANT	\N	PRESENT	0
535468	534257	11040E	PARTICIPANT	\N	PRESENT	0
535469	534257	19820Y	PARTICIPANT	\N	PRESENT	0
535470	534257	14229S	PARTICIPANT	\N	PRESENT	0
535471	534257	19629C	PARTICIPANT	\N	PRESENT	0
535472	534257	19651A	PARTICIPANT	\N	PRESENT	0
535473	534257	20112S	PARTICIPANT	\N	PRESENT	0
535474	534257	19695N	PARTICIPANT	\N	PRESENT	0
535475	534257	19565D	PARTICIPANT	\N	PRESENT	0
535476	534257	19415P	PARTICIPANT	\N	PRESENT	0
535477	534257	19798U	PARTICIPANT	\N	PRESENT	0
535478	534257	11080N	PARTICIPANT	\N	PRESENT	0
535479	534257	11041F	PARTICIPANT	\N	PRESENT	0
535480	534257	19563B	PARTICIPANT	\N	PRESENT	0
535481	534257	19585H	PARTICIPANT	\N	PRESENT	0
535482	534257	98022P	PARTICIPANT	\N	PRESENT	0
535483	534257	14111D	PARTICIPANT	\N	PRESENT	0
535484	534257	14189C	PARTICIPANT	\N	PRESENT	0
535485	534257	20104S	PARTICIPANT	\N	PRESENT	0
535486	534257	19507S	PARTICIPANT	\N	PRESENT	0
535487	534257	20090E	PARTICIPANT	\N	PRESENT	0
535488	534257	19383Y	PARTICIPANT	\N	PRESENT	0
535489	534257	20082E	PARTICIPANT	\N	PRESENT	0
535490	534257	11097X	PARTICIPANT	\N	PRESENT	0
535491	534257	19399H	PARTICIPANT	\N	PRESENT	0
535492	534257	01025N	PARTICIPANT	\N	PRESENT	0
535493	534257	20026V	PARTICIPANT	\N	PRESENT	0
535494	534257	19643A	PARTICIPANT	\N	PRESENT	0
535495	534257	14357A	PARTICIPANT	\N	PRESENT	0
535496	534257	14073Q	PARTICIPANT	\N	PRESENT	0
535497	534257	11077T	PARTICIPANT	\N	PRESENT	0
535498	534257	14207L	PARTICIPANT	\N	PRESENT	0
535499	534257	20048C	PARTICIPANT	\N	PRESENT	0
535500	534257	19421M	PARTICIPANT	\N	PRESENT	0
535501	534257	20080C	PARTICIPANT	\N	PRESENT	0
535502	534257	18083K	PARTICIPANT	\N	PRESENT	0
535503	534257	14253S	PARTICIPANT	\N	PRESENT	0
535504	534257	20044X	PARTICIPANT	\N	PRESENT	0
535505	534257	14123H	PARTICIPANT	\N	PRESENT	0
535506	534257	99004R	PARTICIPANT	\N	PRESENT	0
535507	534257	20032T	PARTICIPANT	\N	PRESENT	0
535508	534257	20084G	PARTICIPANT	\N	PRESENT	0
535509	534257	19413M	PARTICIPANT	\N	PRESENT	0
535510	534257	14231L	PARTICIPANT	\N	PRESENT	0
535511	534257	19713W	PARTICIPANT	\N	PRESENT	0
535512	534257	16685X	PARTICIPANT	\N	PRESENT	0
535513	534257	14042U	PARTICIPANT	\N	PRESENT	0
535514	534257	20136B	PARTICIPANT	\N	PRESENT	0
535515	534257	05012A	PARTICIPANT	\N	PRESENT	0
535516	534257	19515S	PARTICIPANT	\N	PRESENT	0
535538	534257	19251M	PARTICIPANT	\N	PRESENT	0
535539	534257	19685L	PARTICIPANT	\N	PRESENT	0
535540	534257	20054A	PARTICIPANT	\N	PRESENT	0
535541	534257	92040Q	PARTICIPANT	\N	PRESENT	0
535542	534257	20042V	PARTICIPANT	\N	PRESENT	0
535543	534257	11012A	PARTICIPANT	\N	PRESENT	0
535544	534257	20134Y	PARTICIPANT	\N	PRESENT	0
535545	533082	04057K	PARTICIPANT	\N	PRESENT	1
535546	533082	17965H	PARTICIPANT	\N	PRESENT	1
535547	534257	20126Y	PARTICIPANT	\N	PRESENT	0
535548	534257	14147R	PARTICIPANT	\N	PRESENT	0
535549	533082	19697Q	PARTICIPANT	\N	PRESENT	1
535550	534257	08010L	PARTICIPANT	\N	PRESENT	0
535551	533082	19569H	PARTICIPANT	\N	PRESENT	1
535552	534257	14187A	PARTICIPANT	\N	PRESENT	0
535553	534257	17589D	PARTICIPANT	\N	PRESENT	0
535554	533082	19715Y	PARTICIPANT	\N	PRESENT	1
535555	534257	19739H	PARTICIPANT	\N	PRESENT	0
535556	533082	19657G	PARTICIPANT	\N	PRESENT	1
535557	534257	19527W	PARTICIPANT	\N	PRESENT	0
535558	534257	08012N	PARTICIPANT	\N	PRESENT	0
535559	534257	14071N	PARTICIPANT	\N	PRESENT	0
535560	534257	04071H	PARTICIPANT	\N	PRESENT	0
535561	534257	20038A	PARTICIPANT	\N	PRESENT	0
535562	534257	20130U	PARTICIPANT	\N	PRESENT	0
535563	534257	04057K	PARTICIPANT	\N	PRESENT	0
535564	534257	19766L	PARTICIPANT	\N	PRESENT	0
535565	534257	11083R	PARTICIPANT	\N	PRESENT	0
535566	534257	14225N	PARTICIPANT	\N	PRESENT	0
535567	534257	11048N	PARTICIPANT	\N	PRESENT	0
535568	534257	04033B	PARTICIPANT	\N	PRESENT	0
535569	534257	20066E	PARTICIPANT	\N	PRESENT	0
535570	534257	20142Y	PARTICIPANT	\N	PRESENT	0
535571	534257	19758L	PARTICIPANT	\N	PRESENT	0
535572	534257	11085T	PARTICIPANT	\N	PRESENT	0
535573	534257	19782L	PARTICIPANT	\N	PRESENT	0
535574	534257	19619A	PARTICIPANT	\N	PRESENT	0
535575	534257	20060X	PARTICIPANT	\N	PRESENT	0
535576	534257	19479G	PARTICIPANT	\N	PRESENT	0
535577	534257	19503N	PARTICIPANT	\N	PRESENT	0
535578	534257	11056N	PARTICIPANT	\N	PRESENT	0
535579	534257	04085P	PARTICIPANT	\N	PRESENT	0
535580	534257	20102Q	PARTICIPANT	\N	PRESENT	0
535581	534257	20092G	PARTICIPANT	\N	PRESENT	0
535582	534257	08061X	PARTICIPANT	\N	PRESENT	0
535583	534257	20128B	PARTICIPANT	\N	PRESENT	0
535584	534257	19591F	PARTICIPANT	\N	PRESENT	0
535585	534257	19349W	PARTICIPANT	\N	PRESENT	0
535586	534257	14249W	PARTICIPANT	\N	PRESENT	0
535587	534169	19954N	PARTICIPANT	\N	PRESENT	0
535588	534257	20050V	PARTICIPANT	\N	PRESENT	0
535589	534257	14169X	PARTICIPANT	\N	PRESENT	0
535590	534257	08034U	PARTICIPANT	\N	PRESENT	0
535591	534257	11065P	PARTICIPANT	\N	PRESENT	0
535592	534257	19573D	PARTICIPANT	\N	PRESENT	0
535593	534257	19599P	PARTICIPANT	\N	PRESENT	0
535594	534257	04059M	PARTICIPANT	\N	PRESENT	0
535595	534257	17779H	PARTICIPANT	\N	PRESENT	0
535596	534257	14069U	PARTICIPANT	\N	PRESENT	0
535597	534257	19760E	PARTICIPANT	\N	PRESENT	0
535598	534257	14021P	PARTICIPANT	\N	PRESENT	0
535599	534257	14097Y	PARTICIPANT	\N	PRESENT	0
535600	534257	20148F	PARTICIPANT	\N	PRESENT	0
535601	534257	20114U	PARTICIPANT	\N	PRESENT	0
535602	534257	14259Y	PARTICIPANT	\N	PRESENT	0
535604	534257	11043H	PARTICIPANT	\N	PRESENT	0
535605	534257	08017T	PARTICIPANT	\N	PRESENT	0
535606	534257	20096L	PARTICIPANT	\N	PRESENT	0
535607	534257	19649G	PARTICIPANT	\N	PRESENT	0
535608	534257	11045K	PARTICIPANT	\N	PRESENT	0
535609	534257	19637C	PARTICIPANT	\N	PRESENT	0
535610	534257	19621T	PARTICIPANT	\N	PRESENT	0
535611	534257	19467C	PARTICIPANT	\N	PRESENT	0
535612	534257	20180F	PARTICIPANT	\N	PRESENT	0
535613	534257	08045X	PARTICIPANT	\N	PRESENT	0
535614	534257	19768N	PARTICIPANT	\N	PRESENT	0
535615	534257	19549D	PARTICIPANT	\N	PRESENT	0
535616	534257	20070A	PARTICIPANT	\N	PRESENT	0
535617	534257	07029T	PARTICIPANT	\N	PRESENT	0
535618	534257	11067R	PARTICIPANT	\N	PRESENT	0
535619	534257	20018V	PARTICIPANT	\N	PRESENT	0
535620	534169	11033F	PARTICIPANT	\N	PRESENT	1
535621	534257	11090Q	PARTICIPANT	\N	PRESENT	0
535622	534169	14053L	PARTICIPANT	\N	PRESENT	1
535623	534257	14251Q	PARTICIPANT	\N	PRESENT	0
535624	534257	19705W	PARTICIPANT	\N	PRESENT	0
535625	534257	14221J	PARTICIPANT	\N	PRESENT	0
535626	534257	14033T	PARTICIPANT	\N	PRESENT	0
535627	534169	19629C	PARTICIPANT	\N	PRESENT	1
535628	534257	19447X	PARTICIPANT	\N	PRESENT	0
535629	534257	20100N	PARTICIPANT	\N	PRESENT	0
535630	534169	11072N	PARTICIPANT	\N	PRESENT	1
535631	534169	14107H	PARTICIPANT	\N	PRESENT	1
535632	534257	19387D	PARTICIPANT	\N	PRESENT	0
535633	534169	19675J	PARTICIPANT	\N	PRESENT	1
535634	534257	17737W	PARTICIPANT	\N	PRESENT	0
535635	534257	19689Q	PARTICIPANT	\N	PRESENT	0
535636	534257	20028X	PARTICIPANT	\N	PRESENT	0
513073	509967	11053K	PARTICIPANT	\N	PRESENT	1
513074	509967	19545Y	PARTICIPANT	\N	PRESENT	1
513075	509967	04086Q	PARTICIPANT	\N	PRESENT	1
513076	509967	11110B	PARTICIPANT	\N	PRESENT	1
513077	509967	14121F	PARTICIPANT	\N	PRESENT	1
513078	509967	20050V	PARTICIPANT	\N	PRESENT	1
513079	509967	19479G	PARTICIPANT	\N	PRESENT	1
517316	517090	19760E	PARTICIPANT	\N	PRESENT	0
517317	517090	10006L	PARTICIPANT	\N	EXCUSE	0
517318	517090	11103C	PARTICIPANT	\N	PRESENT	0
517319	517090	14042U	PARTICIPANT	\N	PRESENT	0
517320	517090	19553Y	PARTICIPANT	\N	PRESENT	0
517321	517090	14213J	PARTICIPANT	\N	PRESENT	0
517322	517090	19697Q	PARTICIPANT	\N	PRESENT	0
517323	517090	17779H	PARTICIPANT	\N	PRESENT	0
517324	517090	04092N	PARTICIPANT	\N	PRESENT	0
517325	517090	14071N	PARTICIPANT	\N	PRESENT	0
517326	517090	11097X	PRESIDENT	1	PRESENT	0
517327	517090	01034P	PRESIDENT	0	PRESENT	0
517328	517090	20130U	PARTICIPANT	\N	PRESENT	0
518967	502378	14147R	PARTICIPANT	\N	PRESENT	0
518968	502387	14147R	PARTICIPANT	\N	PRESENT	0
522467	522157	20066E	PARTICIPANT	\N	PRESENT	0
522470	522157	19569H	PARTICIPANT	\N	PRESENT	0
522471	522157	11097X	PARTICIPANT	\N	PRESENT	0
522475	522157	19723Y	PARTICIPANT	\N	PRESENT	0
522476	522157	19679N	PARTICIPANT	\N	PRESENT	0
522477	522157	20148F	PARTICIPANT	\N	PRESENT	0
522484	522157	19703U	PARTICIPANT	\N	PRESENT	0
522485	522157	04057K	PARTICIPANT	\N	PRESENT	0
522486	522157	19553Y	PARTICIPANT	\N	PRESENT	0
522487	522157	19760E	PARTICIPANT	\N	PRESENT	0
522488	522157	19798U	PARTICIPANT	\N	PRESENT	0
522499	522157	20084G	PARTICIPANT	\N	EXCUSE	0
522552	522551	20042V	PARTICIPANT	\N	PRESENT	0
522553	522551	14069U	PARTICIPANT	\N	PRESENT	0
522554	522551	20088L	PARTICIPANT	\N	PRESENT	0
522555	522551	20114U	PARTICIPANT	\N	PRESENT	0
522556	522551	11031D	PARTICIPANT	\N	PRESENT	0
522557	522551	20074E	PARTICIPANT	\N	PRESENT	0
522558	522551	20038A	PARTICIPANT	\N	PRESENT	0
522559	522551	11083R	PARTICIPANT	\N	PRESENT	0
522560	522551	20056C	PARTICIPANT	\N	PRESENT	0
522561	522551	14001X	PARTICIPANT	\N	PRESENT	0
522562	522551	14255U	PARTICIPANT	\N	PRESENT	0
522563	521574	20076G	PARTICIPANT	\N	PRESENT	0
522564	521574	11101A	PARTICIPANT	\N	PRESENT	0
522565	521574	18083K	PARTICIPANT	\N	PRESENT	0
522566	521574	19599P	PARTICIPANT	\N	PRESENT	0
522567	521574	19387D	PARTICIPANT	\N	PRESENT	0
522568	521574	19503N	PARTICIPANT	\N	PRESENT	0
522569	521574	20046A	PARTICIPANT	\N	PRESENT	0
524247	524068	20108W	PARTICIPANT	\N	PRESENT	0
524248	524068	14053L	PARTICIPANT	\N	PRESENT	0
524249	524068	14111D	PARTICIPANT	\N	PRESENT	0
524250	524068	04047H	PRESIDENT	0	PRESENT	0
524251	524068	19649G	PARTICIPANT	\N	PRESENT	0
524252	524068	20074E	PARTICIPANT	\N	PRESENT	0
524253	524068	11026G	PARTICIPANT	\N	PRESENT	0
524254	524068	19585H	PARTICIPANT	\N	PRESENT	0
524255	524068	01028R	PARTICIPANT	\N	PRESENT	0
524256	524068	11033F	PARTICIPANT	\N	PRESENT	0
524257	524068	19447X	PARTICIPANT	\N	PRESENT	0
524258	524068	05008E	PARTICIPANT	\N	PRESENT	0
524259	524068	95063L	PARTICIPANT	\N	PRESENT	0
524260	524068	14041T	PARTICIPANT	\N	PRESENT	0
524261	524068	20110Q	PARTICIPANT	\N	PRESENT	0
524262	524068	14151M	PARTICIPANT	\N	PRESENT	0
524263	524068	11085T	PARTICIPANT	\N	PRESENT	0
524264	524068	19749K	PARTICIPANT	\N	PRESENT	0
524265	524068	14021P	PARTICIPANT	\N	PRESENT	0
524266	524068	11072N	PARTICIPANT	\N	PRESENT	0
524267	524068	17737W	PARTICIPANT	\N	PRESENT	0
524268	524068	14215L	PARTICIPANT	\N	PRESENT	0
524269	524068	11056N	PARTICIPANT	\N	PRESENT	0
524292	524073	14225N	PRESIDENT	0	PRESENT	0
524293	524073	19671E	PARTICIPANT	\N	EXCUSE	0
524294	524115	14026U	PARTICIPANT	\N	PRESENT	0
524295	524069	14053L	PARTICIPANT	\N	PRESENT	0
524296	524069	19725B	PARTICIPANT	\N	PRESENT	0
524297	524069	20108W	PARTICIPANT	\N	PRESENT	0
524298	524069	14041T	PARTICIPANT	\N	PRESENT	0
524299	524069	19447X	PARTICIPANT	\N	PRESENT	0
524300	524069	11056N	PARTICIPANT	\N	PRESENT	0
524301	524069	14111D	PARTICIPANT	\N	PRESENT	0
524302	524069	20074E	PARTICIPANT	\N	PRESENT	0
524303	524069	14151M	PARTICIPANT	\N	PRESENT	0
524304	524069	14215L	PARTICIPANT	\N	PRESENT	0
524305	524069	04047H	PRESIDENT	0	PRESENT	0
524306	524069	19673G	PARTICIPANT	\N	PRESENT	0
524307	524069	14179A	PARTICIPANT	\N	PRESENT	0
524308	524069	19543W	PARTICIPANT	\N	PRESENT	0
524309	524069	14089Y	PARTICIPANT	\N	PRESENT	0
524310	524073	11040E	PARTICIPANT	\N	PRESENT	0
524311	524073	14331P	PARTICIPANT	\N	PRESENT	0
524312	524073	14083S	PARTICIPANT	\N	PRESENT	0
524313	524073	11048N	PARTICIPANT	\N	PRESENT	0
524314	524073	04071H	PARTICIPANT	\N	PRESENT	0
524315	524073	08009T	PARTICIPANT	\N	PRESENT	0
524316	524073	19689Q	PARTICIPANT	\N	PRESENT	0
524317	524073	99004R	PARTICIPANT	\N	PRESENT	0
524318	524073	20022R	PARTICIPANT	\N	PRESENT	0
524319	524069	19749K	PARTICIPANT	\N	PRESENT	0
524320	524115	14105F	PARTICIPANT	\N	PRESENT	0
524321	524115	20090E	PARTICIPANT	\N	PRESENT	0
524322	524069	14147R	PARTICIPANT	\N	PRESENT	0
524323	524115	20052X	PARTICIPANT	\N	PRESENT	0
524324	524115	11056N	PARTICIPANT	\N	PRESENT	0
524325	524115	19725B	PARTICIPANT	\N	PRESENT	0
524326	524115	14041T	PARTICIPANT	\N	PRESENT	0
524327	524115	19447X	PARTICIPANT	\N	PRESENT	0
524328	524115	20108W	PARTICIPANT	\N	PRESENT	0
524329	524115	14267Y	PARTICIPANT	\N	PRESENT	0
524330	524115	20074E	PARTICIPANT	\N	PRESENT	0
524331	524115	19669L	PARTICIPANT	\N	PRESENT	0
524332	524115	14053L	PARTICIPANT	\N	PRESENT	0
524337	524115	14107H	PARTICIPANT	\N	PRESENT	0
524339	524115	12028B	PARTICIPANT	\N	PRESENT	0
524341	524115	14257W	PARTICIPANT	\N	PRESENT	0
524342	524115	11066Q	PARTICIPANT	\N	PRESENT	0
524343	524115	20082E	PARTICIPANT	\N	PRESENT	0
524344	524115	17779H	PARTICIPANT	\N	PRESENT	0
524345	524115	14111D	PARTICIPANT	\N	PRESENT	0
524346	524115	08045X	PARTICIPANT	\N	PRESENT	0
524347	524115	08017T	PARTICIPANT	\N	PRESENT	0
524348	524115	19333N	PARTICIPANT	\N	PRESENT	0
524349	524115	19629C	PARTICIPANT	\N	PRESENT	0
524350	524115	19489J	PARTICIPANT	\N	PRESENT	0
524351	524115	20094J	PARTICIPANT	\N	PRESENT	0
524352	524115	11067R	PARTICIPANT	\N	PRESENT	0
524353	524115	11070L	PARTICIPANT	\N	PRESENT	0
524354	524115	04047H	PARTICIPANT	\N	PRESENT	0
524355	524115	05008E	PARTICIPANT	\N	PRESENT	0
524356	524115	19826F	PARTICIPANT	\N	PRESENT	0
524357	524115	20116W	PARTICIPANT	\N	PRESENT	0
524358	524115	20132W	PARTICIPANT	\N	PRESENT	0
524359	524115	14179A	PARTICIPANT	\N	PRESENT	0
524361	524115	20028X	PARTICIPANT	\N	PRESENT	0
524362	524115	18193Q	PARTICIPANT	\N	PRESENT	0
524363	524115	14225N	PARTICIPANT	\N	PRESENT	0
524364	524115	19503N	PARTICIPANT	\N	PRESENT	0
524365	524115	04085P	PARTICIPANT	\N	PRESENT	0
524366	524115	20018V	PARTICIPANT	\N	PRESENT	0
524367	524115	11027H	PARTICIPANT	\N	PRESENT	0
524368	524115	14021P	PARTICIPANT	\N	PRESENT	0
524369	524115	08028W	PARTICIPANT	\N	PRESENT	0
524370	524115	20022R	PARTICIPANT	\N	PRESENT	0
524371	524115	19549D	PARTICIPANT	\N	PRESENT	0
524372	524115	19711U	PARTICIPANT	\N	PRESENT	0
524373	524115	20070A	PARTICIPANT	\N	PRESENT	0
524374	524115	14147R	PARTICIPANT	\N	PRESENT	0
524375	524115	20174H	PARTICIPANT	\N	PRESENT	0
524376	524115	19543W	PARTICIPANT	\N	PRESENT	0
524377	524115	20048C	PARTICIPANT	\N	PRESENT	0
524378	524115	14083S	PARTICIPANT	\N	PRESENT	0
524379	524115	14089Y	PARTICIPANT	\N	PRESENT	0
524380	524115	20110Q	PARTICIPANT	\N	PRESENT	0
524381	524115	14215L	PARTICIPANT	\N	PRESENT	0
524382	524115	20054A	PARTICIPANT	\N	PRESENT	0
524383	524115	11103C	PARTICIPANT	\N	PRESENT	0
533545	531371	19347U	PARTICIPANT	\N	PRESENT	0
533546	531371	19533U	PARTICIPANT	\N	PRESENT	0
533547	531371	14217N	PARTICIPANT	\N	PRESENT	0
533548	531371	19503N	PARTICIPANT	\N	PRESENT	0
533549	531371	19758L	PARTICIPANT	\N	PRESENT	0
533550	531371	20044X	PARTICIPANT	\N	PRESENT	0
533556	531371	14187A	PARTICIPANT	\N	PRESENT	0
533557	531371	08061X	PARTICIPANT	\N	PRESENT	0
533558	531371	19447X	PARTICIPANT	\N	PRESENT	0
533559	531371	20038A	PARTICIPANT	\N	PRESENT	0
533605	533380	20130U	PARTICIPANT	\N	PRESENT	0
533606	533380	19301E	PARTICIPANT	\N	PRESENT	0
533607	533380	19683J	PARTICIPANT	\N	PRESENT	0
533608	533380	18193Q	PARTICIPANT	\N	PRESENT	0
533609	533380	14187A	PARTICIPANT	\N	PRESENT	0
533610	533380	20070A	PARTICIPANT	\N	PRESENT	0
533611	533380	20080C	PARTICIPANT	\N	PRESENT	0
533612	533380	14071N	PARTICIPANT	\N	PRESENT	0
533613	533380	19347U	PARTICIPANT	\N	PRESENT	0
533614	533380	11097X	PARTICIPANT	\N	PRESENT	0
533615	533380	11067R	PARTICIPANT	\N	PRESENT	0
533616	533380	19679N	PARTICIPANT	\N	PRESENT	0
533617	533380	11031D	PARTICIPANT	\N	PRESENT	0
533618	533380	20038A	PARTICIPANT	\N	PRESENT	0
533619	533380	19621T	PARTICIPANT	\N	PRESENT	0
533620	533380	14217N	PARTICIPANT	\N	PRESENT	0
533621	533380	14213J	PARTICIPANT	\N	PRESENT	0
533622	533380	19760E	PARTICIPANT	\N	PRESENT	0
533623	533380	19657G	PARTICIPANT	\N	PRESENT	0
533624	533380	20090E	PARTICIPANT	\N	PRESENT	0
533625	533380	19553Y	PARTICIPANT	\N	PRESENT	0
533626	533380	19569H	PARTICIPANT	\N	PRESENT	0
533627	533380	14195A	PARTICIPANT	\N	PRESENT	0
533628	533380	14042U	PARTICIPANT	\N	PRESENT	0
533629	533380	19691J	PARTICIPANT	\N	PRESENT	0
533630	533380	20132W	PARTICIPANT	\N	PRESENT	0
533634	533380	14147R	PARTICIPANT	\N	PRESENT	0
533632	533380	20066E	PARTICIPANT	\N	PRESENT	0
533633	533380	20106U	PARTICIPANT	\N	PRESENT	0
533635	533380	14215L	PARTICIPANT	\N	PRESENT	0
533636	533380	19723Y	PARTICIPANT	\N	PRESENT	0
533637	533380	19747H	PARTICIPANT	\N	PRESENT	0
533638	533380	10006L	PARTICIPANT	\N	PRESENT	0
533639	533380	19663E	PARTICIPANT	\N	PRESENT	0
533640	533380	17965H	PARTICIPANT	\N	PRESENT	0
533641	533380	20082E	PARTICIPANT	\N	PRESENT	0
533642	533380	19713W	PARTICIPANT	\N	PRESENT	0
533643	533380	17637T	PARTICIPANT	\N	PRESENT	0
533644	533380	14357A	PARTICIPANT	\N	PRESENT	0
533645	533380	19447X	PARTICIPANT	\N	PRESENT	0
533646	533380	17779H	PARTICIPANT	\N	PRESENT	0
533647	533380	20114U	PARTICIPANT	\N	PRESENT	0
533648	533380	14073Q	PARTICIPANT	\N	PRESENT	0
533603	533380	99004R	PARTICIPANT	\N	PRESENT	0
533604	533380	04092N	PARTICIPANT	\N	PRESENT	0
533649	533380	20052X	PARTICIPANT	\N	PRESENT	0
533650	533380	19591F	PARTICIPANT	\N	PRESENT	0
533651	533380	20134Y	PARTICIPANT	\N	PRESENT	0
533652	533380	11056N	PARTICIPANT	\N	PRESENT	0
533653	533380	19369B	PARTICIPANT	\N	PRESENT	0
533654	533380	14219Q	PARTICIPANT	\N	PRESENT	0
538374	536830	12041X	PARTICIPANT	\N	PRESENT	0
538376	536830	19301E	PARTICIPANT	\N	PRESENT	0
538377	536830	17589D	PARTICIPANT	\N	PRESENT	0
538378	536830	20110Q	PARTICIPANT	\N	PRESENT	0
538379	536830	19715Y	PARTICIPANT	\N	PRESENT	0
538380	536830	20070A	PARTICIPANT	\N	PRESENT	0
538381	536830	20046A	PARTICIPANT	\N	PRESENT	0
538382	536830	20102Q	PARTICIPANT	\N	PRESENT	0
538383	536830	20174H	PARTICIPANT	\N	PRESENT	0
538384	536830	19349W	PARTICIPANT	\N	PRESENT	0
538385	536830	19717B	PARTICIPANT	\N	PRESENT	0
538386	536830	19387D	PARTICIPANT	\N	PRESENT	0
538387	536830	19479G	PARTICIPANT	\N	PRESENT	0
538388	536830	14205J	PARTICIPANT	\N	PRESENT	0
538389	536830	14089Y	PARTICIPANT	\N	PRESENT	0
538390	536830	19758L	PARTICIPANT	\N	PRESENT	0
538391	536830	04070G	PARTICIPANT	\N	PRESENT	0
538392	536830	20148F	PARTICIPANT	\N	PRESENT	0
538393	536830	14215L	PARTICIPANT	\N	PRESENT	0
538394	536830	04047H	PARTICIPANT	\N	PRESENT	0
538395	536830	20074E	PARTICIPANT	\N	PRESENT	0
538396	536830	14189C	PARTICIPANT	\N	PRESENT	0
538397	536830	14069U	PARTICIPANT	\N	PRESENT	0
538398	536830	97011G	PARTICIPANT	\N	PRESENT	0
538399	536830	20062A	PARTICIPANT	\N	PRESENT	0
538400	536830	20172F	PARTICIPANT	\N	PRESENT	0
538401	536830	20180F	PARTICIPANT	\N	PRESENT	0
538402	536830	20034V	PARTICIPANT	\N	PRESENT	0
538403	536830	14259Y	PARTICIPANT	\N	PRESENT	0
538404	536830	19399H	PARTICIPANT	\N	PRESENT	0
538405	536830	11072N	PARTICIPANT	\N	PRESENT	0
538406	536830	12016W	PARTICIPANT	\N	PRESENT	0
538407	536830	19565D	PARTICIPANT	\N	PRESENT	0
538408	536830	19657G	PARTICIPANT	\N	PRESENT	0
538409	536830	08061X	PARTICIPANT	\N	PRESENT	0
538410	536830	19629C	PARTICIPANT	\N	PRESENT	0
538411	536830	19866P	PARTICIPANT	\N	PRESENT	0
538412	536830	14147R	PARTICIPANT	\N	PRESENT	0
538413	536830	19651A	PARTICIPANT	\N	PRESENT	0
538414	536830	19447X	PARTICIPANT	\N	PRESENT	0
538415	536830	20020P	PARTICIPANT	\N	PRESENT	0
538417	536830	19711U	PARTICIPANT	\N	PRESENT	0
538418	536830	20090E	PARTICIPANT	\N	PRESENT	0
538419	536830	01024M	PARTICIPANT	\N	PRESENT	0
538420	536830	14042U	PARTICIPANT	\N	PRESENT	0
538421	536830	14073Q	PARTICIPANT	\N	PRESENT	0
538422	536830	11012A	PARTICIPANT	\N	PRESENT	0
538423	536830	19593H	PARTICIPANT	\N	PRESENT	0
538424	536830	14059S	PARTICIPANT	\N	PRESENT	0
538425	536830	20152B	PARTICIPANT	\N	PRESENT	0
538426	536830	19695N	PARTICIPANT	\N	PRESENT	0
538427	536830	11056N	PARTICIPANT	\N	PRESENT	0
538440	536830	04034C	PARTICIPANT	\N	PRESENT	0
538441	536656	20056C	PARTICIPANT	\N	PRESENT	1
538442	536656	20060X	PARTICIPANT	\N	PRESENT	0
538443	536656	11067R	PARTICIPANT	\N	PRESENT	0
538444	536656	20062A	PARTICIPANT	\N	PRESENT	0
538445	536656	20090E	PARTICIPANT	\N	PRESENT	0
538446	536656	19701S	PARTICIPANT	\N	PRESENT	1
538447	536656	19689Q	PARTICIPANT	\N	PRESENT	1
538448	536656	20048C	PRESIDENT	0	PRESENT	0
538449	536656	19581D	PARTICIPANT	\N	PRESENT	0
538450	536656	20052X	PARTICIPANT	\N	PRESENT	0
538451	536656	17779H	PARTICIPANT	\N	PRESENT	0
538452	536656	20058E	PARTICIPANT	\N	PRESENT	1
538453	536830	19599P	PARTICIPANT	\N	PRESENT	0
538455	536830	20124W	PARTICIPANT	\N	PRESENT	0
538456	536830	19467C	PARTICIPANT	\N	PRESENT	0
538457	536830	19503N	PARTICIPANT	\N	PRESENT	0
538458	536830	20106U	PARTICIPANT	\N	PRESENT	0
538459	536830	20142Y	PARTICIPANT	\N	PRESENT	0
538460	536830	19507S	PARTICIPANT	\N	PRESENT	0
538461	536830	19691J	PARTICIPANT	\N	PRESENT	0
538478	536830	20058E	PARTICIPANT	\N	PRESENT	0
538463	536830	19515S	PARTICIPANT	\N	PRESENT	0
538464	536830	20054A	PARTICIPANT	\N	PRESENT	0
538465	536830	20126Y	PARTICIPANT	\N	PRESENT	0
538466	536830	19553Y	PARTICIPANT	\N	PRESENT	0
538467	536830	20134Y	PARTICIPANT	\N	PRESENT	0
538468	536830	19621T	PARTICIPANT	\N	PRESENT	0
538469	536830	14231L	PARTICIPANT	\N	PRESENT	0
538470	536830	14109K	PARTICIPANT	\N	PRESENT	0
538471	536830	19533U	PARTICIPANT	\N	PRESENT	0
538475	536830	19747H	PARTICIPANT	\N	PRESENT	0
538476	536830	19735D	PARTICIPANT	\N	PRESENT	0
538477	536830	20038A	PARTICIPANT	\N	PRESENT	0
538479	536830	20044X	PARTICIPANT	\N	PRESENT	0
538480	536830	19693L	PARTICIPANT	\N	PRESENT	0
538481	536830	11104D	PARTICIPANT	\N	PRESENT	0
538482	536830	18083K	PARTICIPANT	\N	PRESENT	0
538486	536830	19713W	PARTICIPANT	\N	PRESENT	0
514047	511900	18083K	PARTICIPANT	\N	PRESENT	0
514048	511900	20136B	PARTICIPANT	\N	PRESENT	0
514049	511900	20038A	PARTICIPANT	\N	PRESENT	0
514050	511900	14031R	PARTICIPANT	\N	PRESENT	0
514051	511900	11101A	PARTICIPANT	\N	PRESENT	0
514052	511900	20140W	PARTICIPANT	\N	PRESENT	0
514053	511900	19503N	PARTICIPANT	\N	PRESENT	0
514054	511900	20020P	PARTICIPANT	\N	PRESENT	0
514055	511900	19826F	PARTICIPANT	\N	PRESENT	0
514056	511900	17367Q	PARTICIPANT	\N	PRESENT	0
514057	511900	19599P	PARTICIPANT	\N	PRESENT	0
514058	511900	20102Q	PARTICIPANT	\N	PRESENT	0
514059	511900	14219Q	PRESIDENT	0	PRESENT	0
514060	511900	17637T	PARTICIPANT	\N	PRESENT	0
514061	511900	19333N	PARTICIPANT	\N	PRESENT	1
514062	511900	19820Y	PARTICIPANT	\N	PRESENT	1
514063	511900	19659J	PARTICIPANT	\N	PRESENT	1
514064	511900	19637C	PARTICIPANT	\N	PRESENT	1
514065	511900	11065P	PARTICIPANT	\N	PRESENT	1
514066	512703	14111D	PARTICIPANT	\N	PRESENT	0
514067	512703	20074E	PARTICIPANT	\N	PRESENT	0
514068	512703	14001X	PARTICIPANT	\N	PRESENT	0
514069	512703	04047H	PARTICIPANT	\N	PRESENT	0
514070	512703	01028R	PARTICIPANT	\N	PRESENT	0
514071	512703	19447X	PARTICIPANT	\N	PRESENT	0
514072	512703	05008E	PARTICIPANT	\N	PRESENT	0
514073	512703	14231L	PARTICIPANT	\N	PRESENT	0
514074	512703	14089Y	PARTICIPANT	\N	PRESENT	0
514075	512703	11056N	PARTICIPANT	\N	PRESENT	0
514076	512703	20108W	PARTICIPANT	\N	PRESENT	0
514077	512703	20110Q	PARTICIPANT	\N	PRESENT	0
514078	512703	14147R	PARTICIPANT	\N	PRESENT	0
514079	512703	14215L	PARTICIPANT	\N	PRESENT	0
514133	502367	86034E	PARTICIPANT	\N	PRESENT	0
514134	502367	11048N	PARTICIPANT	\N	PRESENT	0
514135	502367	14225N	PARTICIPANT	\N	PRESENT	0
514136	502367	11074Q	PARTICIPANT	\N	PRESENT	0
514137	502367	11040E	PARTICIPANT	\N	PRESENT	0
514138	502367	19758L	PARTICIPANT	\N	PRESENT	0
514139	502367	11056N	PARTICIPANT	\N	PRESENT	0
514140	502367	11031D	PARTICIPANT	\N	PRESENT	0
514141	502367	19695N	PARTICIPANT	\N	PRESENT	0
514142	502367	20102Q	PARTICIPANT	\N	PRESENT	0
514143	502367	12041X	PARTICIPANT	\N	PRESENT	0
514144	502367	19593H	PARTICIPANT	\N	PRESENT	0
514145	502367	19687N	PARTICIPANT	\N	PRESENT	0
514146	502367	19333N	PARTICIPANT	\N	PRESENT	0
514147	502367	11067R	PARTICIPANT	\N	PRESENT	0
514148	502367	14109K	PARTICIPANT	\N	PRESENT	0
514149	502367	20080C	PARTICIPANT	\N	PRESENT	0
514150	502367	19503N	PARTICIPANT	\N	PRESENT	0
514151	502367	14041T	PARTICIPANT	\N	PRESENT	0
514152	502367	19820Y	PARTICIPANT	\N	PRESENT	0
514153	502367	18193Q	PARTICIPANT	\N	PRESENT	0
514154	502367	19647E	PARTICIPANT	\N	PRESENT	0
514155	502367	11045K	PARTICIPANT	\N	PRESENT	0
514156	502367	14281W	PARTICIPANT	\N	PRESENT	0
514157	502367	19525U	PARTICIPANT	\N	PRESENT	0
514158	502367	19489J	PARTICIPANT	\N	PRESENT	0
514159	502367	14121F	PARTICIPANT	\N	PRESENT	0
514160	502367	17965H	PARTICIPANT	\N	PRESENT	0
514161	502367	14211G	PARTICIPANT	\N	PRESENT	0
514162	502367	11066Q	PARTICIPANT	\N	PRESENT	0
514163	502367	18083K	PARTICIPANT	\N	PRESENT	0
514164	502367	20092G	PARTICIPANT	\N	PRESENT	0
514165	502367	20134Y	PARTICIPANT	\N	PRESENT	0
514166	502367	19782L	PARTICIPANT	\N	PRESENT	0
514167	502367	20174H	PARTICIPANT	\N	PRESENT	0
514168	502367	08073C	PARTICIPANT	\N	PRESENT	0
514169	502367	20070A	PARTICIPANT	\N	PRESENT	0
514170	502367	14021P	PARTICIPANT	\N	PRESENT	0
514171	502367	17779H	PARTICIPANT	\N	PRESENT	0
514172	502367	19651A	PARTICIPANT	\N	PRESENT	0
514173	502367	19301E	PARTICIPANT	\N	PRESENT	0
514174	502367	04034C	PARTICIPANT	\N	PRESENT	0
514175	502367	19693L	PARTICIPANT	\N	PRESENT	0
514176	502367	99004R	PARTICIPANT	\N	PRESENT	0
514177	502367	20106U	PARTICIPANT	\N	PRESENT	0
514178	502367	08061X	PARTICIPANT	\N	PRESENT	0
514179	502367	11012A	PARTICIPANT	\N	PRESENT	0
514180	502367	04035D	PARTICIPANT	\N	PRESENT	0
514181	502367	20116W	PARTICIPANT	\N	PRESENT	0
514182	502367	19415P	PARTICIPANT	\N	PRESENT	0
514183	502367	19551W	PARTICIPANT	\N	PRESENT	0
514184	502367	19717B	PARTICIPANT	\N	PRESENT	0
514185	502367	14071N	PARTICIPANT	\N	PRESENT	0
514186	502367	20132W	PARTICIPANT	\N	PRESENT	0
514187	502367	20050V	PARTICIPANT	\N	PRESENT	0
514188	502367	14053L	PARTICIPANT	\N	PRESENT	0
514189	502367	19563B	PARTICIPANT	\N	PRESENT	0
514190	502367	08028W	PARTICIPANT	\N	PRESENT	0
514191	502367	20150Y	PARTICIPANT	\N	PRESENT	0
514192	502367	10015M	PARTICIPANT	\N	PRESENT	0
514193	502367	14221J	PARTICIPANT	\N	PRESENT	0
514195	502367	20052X	PARTICIPANT	\N	PRESENT	0
514196	502367	14267Y	PARTICIPANT	\N	PRESENT	0
514197	502367	19515S	PARTICIPANT	\N	PRESENT	0
514198	502367	19673G	PARTICIPANT	\N	PRESENT	0
514199	502367	14107H	PARTICIPANT	\N	PRESENT	0
514200	502367	19719D	PARTICIPANT	\N	PRESENT	0
514201	502367	14031R	PARTICIPANT	\N	PRESENT	0
514203	502367	19553Y	PARTICIPANT	\N	PRESENT	0
514204	502367	20136B	PARTICIPANT	\N	PRESENT	0
514206	502367	14229S	PARTICIPANT	\N	PRESENT	0
514207	502367	16685X	PARTICIPANT	\N	PRESENT	0
514208	502367	14253S	PARTICIPANT	\N	PRESENT	0
514209	502367	14083S	PARTICIPANT	\N	PRESENT	0
514211	502367	19347U	PARTICIPANT	\N	PRESENT	0
514212	502367	14147R	PARTICIPANT	\N	PRESENT	0
514213	502367	19715Y	PARTICIPANT	\N	PRESENT	0
514214	502367	01034P	PARTICIPANT	\N	PRESENT	0
514215	502367	08047A	PARTICIPANT	\N	PRESENT	0
514216	502367	14073Q	PARTICIPANT	\N	PRESENT	0
514217	502367	19443T	PARTICIPANT	\N	PRESENT	0
514218	502367	19543W	PARTICIPANT	\N	PRESENT	0
514219	502367	19573D	PARTICIPANT	\N	PRESENT	0
514220	502367	19745F	PARTICIPANT	\N	PRESENT	0
514221	502367	20098N	PARTICIPANT	\N	PRESENT	0
514222	502367	19367Y	PARTICIPANT	\N	PRESENT	0
514223	502367	07029T	PARTICIPANT	\N	PRESENT	0
514224	502367	19671E	PARTICIPANT	\N	PRESENT	0
514225	502367	19729F	PARTICIPANT	\N	PRESENT	0
514226	502367	19685L	PARTICIPANT	\N	PRESENT	0
514227	502367	20172F	PARTICIPANT	\N	PRESENT	0
514228	502367	20126Y	PARTICIPANT	\N	PRESENT	0
514229	502367	08056B	PARTICIPANT	\N	PRESENT	0
514230	502367	20090E	PARTICIPANT	\N	PRESENT	0
514231	502367	19621T	PARTICIPANT	\N	PRESENT	0
514232	502367	14059S	PARTICIPANT	\N	PRESENT	0
514233	502367	97011G	PARTICIPANT	\N	PRESENT	0
514234	502367	04033B	PARTICIPANT	\N	PRESENT	0
514235	502367	14105F	PARTICIPANT	\N	PRESENT	0
514236	502367	14069U	PARTICIPANT	\N	PRESENT	0
514237	502367	07033P	PARTICIPANT	\N	PRESENT	0
514238	502367	14217N	PARTICIPANT	\N	PRESENT	0
514239	502367	20128B	PARTICIPANT	\N	PRESENT	0
514252	502367	19966S	PARTICIPANT	\N	PRESENT	0
514241	502367	19591F	PARTICIPANT	\N	PRESENT	0
514242	502367	19611R	PARTICIPANT	\N	PRESENT	0
514243	502367	01043Q	PARTICIPANT	\N	PRESENT	0
514244	502367	14030Q	PARTICIPANT	\N	PRESENT	0
514245	502367	04070G	PARTICIPANT	\N	PRESENT	0
514246	502367	14259Y	PARTICIPANT	\N	PRESENT	0
514247	502367	19565D	PARTICIPANT	\N	PRESENT	0
514248	502367	05012A	PARTICIPANT	\N	PRESENT	0
514249	502367	19669L	PARTICIPANT	\N	PRESENT	0
514250	502367	20028X	PARTICIPANT	\N	PRESENT	0
514251	502367	20038A	PARTICIPANT	\N	PRESENT	0
514253	502367	04057K	PARTICIPANT	\N	PRESENT	0
514254	502367	14123H	PARTICIPANT	\N	PRESENT	0
514255	502367	20138D	PARTICIPANT	\N	PRESENT	0
514256	502367	08069G	PARTICIPANT	\N	PRESENT	0
514257	502367	11090Q	PARTICIPANT	\N	PRESENT	0
514258	502367	20022R	PARTICIPANT	\N	PRESENT	0
514259	502367	17023S	PARTICIPANT	\N	PRESENT	0
514260	502367	20040T	PARTICIPANT	\N	PRESENT	0
514261	502367	04043D	PARTICIPANT	\N	PRESENT	0
514262	502367	08010L	PARTICIPANT	\N	PRESENT	0
514263	502367	01057W	PARTICIPANT	\N	PRESENT	0
514264	502367	19619A	PARTICIPANT	\N	PRESENT	0
535638	534257	19333N	PARTICIPANT	\N	PRESENT	0
535639	534257	19691J	PARTICIPANT	\N	PRESENT	0
535640	534257	19611R	PARTICIPANT	\N	PRESENT	0
535641	534257	01034P	PARTICIPANT	\N	PRESENT	0
535642	534257	20144B	PARTICIPANT	\N	PRESENT	0
535643	534257	20140W	PARTICIPANT	\N	PRESENT	0
535644	534257	20118Y	PARTICIPANT	\N	PRESENT	0
535645	534257	20132W	PARTICIPANT	\N	PRESENT	0
535646	534257	20046A	PARTICIPANT	\N	PRESENT	0
535647	534257	14219Q	PARTICIPANT	\N	PRESENT	0
535648	534257	19335Q	PARTICIPANT	\N	PRESENT	0
535649	534257	19543W	PARTICIPANT	\N	PRESENT	0
535650	534257	19545Y	PARTICIPANT	\N	PRESENT	0
535651	534257	19441R	PARTICIPANT	\N	PRESENT	0
535652	534257	04070G	PARTICIPANT	\N	PRESENT	0
535653	534257	01024M	PARTICIPANT	\N	PRESENT	0
535654	534257	14030Q	PARTICIPANT	\N	PRESENT	0
535655	534257	04008A	PARTICIPANT	\N	PRESENT	0
535656	534257	19762G	PARTICIPANT	\N	PRESENT	0
535657	534257	19701S	PARTICIPANT	\N	PRESENT	0
535658	534257	04043D	PARTICIPANT	\N	PRESENT	0
535659	534257	19679N	PARTICIPANT	\N	PRESENT	0
535660	534257	01057W	PARTICIPANT	\N	PRESENT	0
535661	534257	20076G	PARTICIPANT	\N	PRESENT	0
535662	534257	19533U	PARTICIPANT	\N	PRESENT	0
535663	534257	01048V	PARTICIPANT	\N	PRESENT	0
535664	534257	19711U	PARTICIPANT	\N	PRESENT	0
535665	534257	01058X	PARTICIPANT	\N	PRESENT	0
535666	534257	17637T	PARTICIPANT	\N	PRESENT	0
535667	534257	08011M	PARTICIPANT	\N	PRESENT	0
535668	534257	01028R	PARTICIPANT	\N	PRESENT	0
535669	534257	14213J	PARTICIPANT	\N	PRESENT	0
535670	534257	19671E	PARTICIPANT	\N	PRESENT	0
535671	534257	20062A	PARTICIPANT	\N	PRESENT	0
535637	534257	19703U	PARTICIPANT	\N	PRESENT	0
535672	534257	20108W	PARTICIPANT	\N	PRESENT	0
535676	534257	11031D	PARTICIPANT	\N	PRESENT	0
535674	534257	20086J	PARTICIPANT	\N	PRESENT	0
535675	534257	19954N	PARTICIPANT	\N	PRESENT	0
535677	534257	19729F	PARTICIPANT	\N	PRESENT	0
535678	534257	14331P	PARTICIPANT	\N	PRESENT	0
535679	534257	14237S	PARTICIPANT	\N	PRESENT	0
535680	534257	14257W	PARTICIPANT	\N	PRESENT	0
535681	534257	19347U	PARTICIPANT	\N	PRESENT	0
535682	534257	19581D	PARTICIPANT	\N	PRESENT	0
535683	534257	18193Q	PARTICIPANT	\N	PRESENT	0
535684	534257	14179A	PARTICIPANT	\N	PRESENT	0
535685	534257	08009T	PARTICIPANT	\N	PRESENT	0
535686	534257	14031R	PARTICIPANT	\N	PRESENT	0
535687	534257	08015R	PARTICIPANT	\N	PRESENT	0
535690	534257	19687N	PARTICIPANT	\N	PRESENT	0
535692	534257	19647E	PARTICIPANT	\N	PRESENT	0
535691	534257	14151M	PARTICIPANT	\N	PRESENT	0
535696	534257	19693L	PARTICIPANT	\N	PRESENT	0
535694	534257	19553Y	PARTICIPANT	\N	PRESENT	0
535695	534257	19747H	PARTICIPANT	\N	PRESENT	0
535697	534257	19531S	PARTICIPANT	\N	PRESENT	0
535913	534258	01043Q	PARTICIPANT	\N	PRESENT	0
535699	534257	17023S	PARTICIPANT	\N	PRESENT	0
535700	534257	08047A	PARTICIPANT	\N	PRESENT	0
535923	534218	20032T	PARTICIPANT	\N	PRESENT	0
535924	534218	11048N	PARTICIPANT	\N	PRESENT	0
535925	534218	19711U	PARTICIPANT	\N	PRESENT	0
535926	534218	20076G	PARTICIPANT	\N	PRESENT	0
535927	534218	19503N	PARTICIPANT	\N	PRESENT	0
535928	534218	19413M	PARTICIPANT	\N	PRESENT	0
535929	534218	14033T	PARTICIPANT	\N	PRESENT	0
535930	534218	20126Y	PARTICIPANT	\N	PRESENT	0
535932	534258	11040E	PARTICIPANT	\N	PRESENT	0
535934	534258	08017T	PARTICIPANT	\N	PRESENT	0
535935	534258	14097Y	PARTICIPANT	\N	PRESENT	0
535936	534258	19347U	PARTICIPANT	\N	PRESENT	0
535938	534258	04042C	PARTICIPANT	\N	PRESENT	0
535939	534170	14111D	PARTICIPANT	\N	PRESENT	0
535940	534170	19629C	PARTICIPANT	\N	PRESENT	0
535941	534170	20108W	PARTICIPANT	\N	PRESENT	0
535942	534170	19581D	PARTICIPANT	\N	PRESENT	0
535943	534170	14215L	PARTICIPANT	\N	PRESENT	0
535944	534170	19585H	PARTICIPANT	\N	PRESENT	0
535945	534170	04047H	PARTICIPANT	\N	PRESENT	0
535946	534170	19673G	PARTICIPANT	\N	PRESENT	0
535947	534170	19447X	PARTICIPANT	\N	PRESENT	0
535948	534170	14231L	PARTICIPANT	\N	PRESENT	0
535949	534258	14001X	PARTICIPANT	\N	PRESENT	0
535951	534258	20100N	PARTICIPANT	\N	PRESENT	0
535953	534258	19479G	PARTICIPANT	\N	PRESENT	0
535954	534258	19251M	PARTICIPANT	\N	PRESENT	0
535956	534170	20074E	PARTICIPANT	\N	PRESENT	0
535957	534258	19565D	PARTICIPANT	\N	PRESENT	0
535959	534258	19387D	PARTICIPANT	\N	PRESENT	0
535961	534218	19782L	PARTICIPANT	\N	PRESENT	0
535962	534218	20144B	PARTICIPANT	\N	PRESENT	0
535963	534218	19619A	PARTICIPANT	\N	PRESENT	0
535964	534218	19739H	PARTICIPANT	\N	EXCUSE	0
535966	534258	14331P	PARTICIPANT	\N	PRESENT	0
535967	534258	11066Q	PARTICIPANT	\N	PRESENT	0
535969	534258	20128B	PARTICIPANT	\N	PRESENT	0
535970	534258	04034C	PARTICIPANT	\N	PRESENT	0
535972	534258	18193Q	PARTICIPANT	\N	PRESENT	0
535973	534218	20070A	PARTICIPANT	\N	PRESENT	0
535974	534218	20054A	PARTICIPANT	\N	PRESENT	0
535975	534258	20102Q	PARTICIPANT	\N	PRESENT	0
535977	534170	19649G	PARTICIPANT	\N	PRESENT	0
535978	534170	19749K	PARTICIPANT	\N	PRESENT	0
535979	534258	20042V	PARTICIPANT	\N	PRESENT	0
535980	534218	14237S	PARTICIPANT	\N	PRESENT	0
535981	534258	01024M	PARTICIPANT	\N	PRESENT	0
535983	534258	11064N	PARTICIPANT	\N	PRESENT	0
535984	534258	14133K	PARTICIPANT	\N	PRESENT	0
535985	534258	14187A	PARTICIPANT	\N	PRESENT	0
535987	534258	19798U	PARTICIPANT	\N	PRESENT	0
535988	534258	04070G	PARTICIPANT	\N	PRESENT	0
535989	534258	19399H	PARTICIPANT	\N	PRESENT	0
535990	534218	20092G	PARTICIPANT	\N	PRESENT	0
535991	534218	20050V	PARTICIPANT	\N	PRESENT	0
535992	534218	19507S	PARTICIPANT	\N	PRESENT	0
535994	534258	20180F	PARTICIPANT	\N	PRESENT	0
535996	534258	20056C	PARTICIPANT	\N	PRESENT	0
535997	534258	08047A	PARTICIPANT	\N	PRESENT	0
535998	534258	11054L	PARTICIPANT	\N	PRESENT	0
536000	534258	19333N	PARTICIPANT	\N	PRESENT	0
536001	534258	98022P	PARTICIPANT	\N	PRESENT	0
536002	534218	19820Y	PARTICIPANT	\N	PRESENT	0
536003	534258	04057K	PARTICIPANT	\N	PRESENT	0
536006	534170	19543W	PARTICIPANT	\N	PRESENT	0
536007	534170	19725B	PARTICIPANT	\N	PRESENT	0
536008	534170	19954N	PARTICIPANT	\N	PRESENT	0
536009	534170	14179A	PARTICIPANT	\N	PRESENT	0
536010	534218	14357A	PARTICIPANT	\N	PRESENT	0
536013	534170	14151M	PARTICIPANT	\N	PRESENT	0
536019	534258	14147R	PARTICIPANT	\N	PRESENT	0
536020	534258	14249W	PARTICIPANT	\N	PRESENT	0
536021	534258	14069U	PARTICIPANT	\N	PRESENT	0
536022	534258	14193X	PARTICIPANT	\N	PRESENT	0
536023	534258	14031R	PARTICIPANT	\N	PRESENT	0
536024	534258	17023S	PARTICIPANT	\N	PRESENT	0
536025	534258	20044X	PARTICIPANT	\N	PRESENT	0
536026	534258	14255U	PARTICIPANT	\N	PRESENT	0
536027	534258	14189C	PARTICIPANT	\N	PRESENT	0
536028	534170	01028R	PARTICIPANT	\N	PRESENT	0
536038	534258	20048C	PARTICIPANT	\N	PRESENT	0
536039	534258	14259Y	PARTICIPANT	\N	PRESENT	0
536040	534258	20022R	PARTICIPANT	\N	PRESENT	0
536041	534258	19747H	PARTICIPANT	\N	PRESENT	0
536042	534258	19709B	PARTICIPANT	\N	PRESENT	0
536043	534170	05008E	PARTICIPANT	\N	PRESENT	0
536047	534170	17737W	PARTICIPANT	\N	PRESENT	0
536060	534258	19599P	PARTICIPANT	\N	PRESENT	0
536071	534258	14237S	PARTICIPANT	\N	PRESENT	0
536073	534258	14033T	PARTICIPANT	\N	PRESENT	0
536074	534258	11012A	PARTICIPANT	\N	PRESENT	0
536091	534258	20104S	PARTICIPANT	\N	PRESENT	0
536092	534258	20024T	PARTICIPANT	\N	PRESENT	0
536093	534258	19553Y	PARTICIPANT	\N	PRESENT	0
536094	534258	19507S	PARTICIPANT	\N	PRESENT	0
536095	534258	20068G	PARTICIPANT	\N	PRESENT	0
536096	534258	07029T	PARTICIPANT	\N	PRESENT	0
536097	534268	20056C	PARTICIPANT	\N	PRESENT	0
536098	534268	11067R	PARTICIPANT	\N	PRESENT	0
536099	534268	20062A	PARTICIPANT	\N	PRESENT	1
536100	534268	19701S	PARTICIPANT	\N	PRESENT	0
524384	524115	19966S	PARTICIPANT	\N	PRESENT	0
524385	524115	14121F	PARTICIPANT	\N	PRESENT	0
524386	524115	14151M	PARTICIPANT	\N	PRESENT	0
524387	524115	19575F	PARTICIPANT	\N	PRESENT	0
524388	524115	01058X	PARTICIPANT	\N	PRESENT	0
524389	524115	19415P	PARTICIPANT	\N	PRESENT	0
524390	524115	19749K	PARTICIPANT	\N	PRESENT	0
524391	524115	95063L	PARTICIPANT	\N	PRESENT	0
524392	524115	01060R	PARTICIPANT	\N	PRESENT	0
524393	524115	20042V	PARTICIPANT	\N	PRESENT	0
524394	524115	01028R	PARTICIPANT	\N	PRESENT	0
524395	524115	19679N	PARTICIPANT	\N	PRESENT	0
524396	524115	20134Y	PARTICIPANT	\N	PRESENT	0
524397	524115	19758L	PARTICIPANT	\N	PRESENT	0
524398	524115	19695N	PARTICIPANT	\N	PRESENT	0
524399	524115	19798U	PARTICIPANT	\N	PRESENT	0
524400	524115	19441R	PARTICIPANT	\N	PRESENT	0
524401	524115	04033B	PARTICIPANT	\N	PRESENT	0
524402	524115	19687N	PARTICIPANT	\N	PRESENT	0
524403	524115	11040E	PARTICIPANT	\N	PRESENT	0
524404	524115	11045K	PARTICIPANT	\N	PRESENT	0
524405	524115	19739H	PARTICIPANT	\N	PRESENT	0
524406	524115	20112S	PARTICIPANT	\N	PRESENT	0
524407	524115	19611R	PARTICIPANT	\N	PRESENT	0
524411	524115	20138D	PARTICIPANT	\N	PRESENT	0
524417	524115	01034P	PARTICIPANT	\N	PRESENT	0
524418	524115	08069G	PARTICIPANT	\N	PRESENT	0
524419	524115	19741B	PARTICIPANT	\N	PRESENT	0
524420	524115	14038Y	PARTICIPANT	\N	PRESENT	0
524421	524115	11043H	PARTICIPANT	\N	PRESENT	0
524422	524115	19760E	PARTICIPANT	\N	PRESENT	0
524423	524115	20126Y	PARTICIPANT	\N	PRESENT	0
524424	524115	14069U	PARTICIPANT	\N	PRESENT	0
524425	524115	19533U	PARTICIPANT	\N	PRESENT	0
524426	524115	20066E	PARTICIPANT	\N	PRESENT	0
524427	524115	19621T	PARTICIPANT	\N	PRESENT	0
524428	524115	19593H	PARTICIPANT	\N	PRESENT	0
524429	524115	19507S	PARTICIPANT	\N	PRESENT	0
524430	524073	14327T	PARTICIPANT	\N	PRESENT	0
524431	524073	19647E	PARTICIPANT	\N	PRESENT	0
524432	524073	19711U	PARTICIPANT	\N	PRESENT	0
524433	524073	14189C	PARTICIPANT	\N	PRESENT	0
524434	524073	19687N	PARTICIPANT	\N	PRESENT	0
524435	524073	08011M	PARTICIPANT	\N	PRESENT	0
524436	524073	11070L	PARTICIPANT	\N	PRESENT	0
524437	524073	07029T	PARTICIPANT	\N	PRESENT	0
524438	524073	20070A	PARTICIPANT	\N	PRESENT	0
524439	524073	20116W	PARTICIPANT	\N	PRESENT	0
524440	524073	19335Q	PARTICIPANT	\N	PRESENT	0
524441	524073	19741B	PARTICIPANT	\N	EXCUSE	0
524450	524115	04059M	PARTICIPANT	\N	PRESENT	0
524451	524115	19367Y	PARTICIPANT	\N	PRESENT	0
524452	524115	19467C	PARTICIPANT	\N	PRESENT	0
524453	524115	14001X	PARTICIPANT	\N	PRESENT	0
524454	524115	11012A	PARTICIPANT	\N	PRESENT	0
524455	524115	98022P	PARTICIPANT	\N	PRESENT	0
524456	524115	20118Y	PARTICIPANT	\N	PRESENT	0
524457	524115	14253S	PARTICIPANT	\N	PRESENT	0
524458	524115	19747H	PARTICIPANT	\N	PRESENT	0
524459	524115	20084G	PARTICIPANT	\N	PRESENT	0
524460	524115	14223L	PARTICIPANT	\N	PRESENT	0
524461	524115	19703U	PARTICIPANT	\N	PRESENT	0
524462	524115	19693L	PARTICIPANT	\N	PRESENT	0
524463	524115	08061X	PARTICIPANT	\N	PRESENT	0
524464	524115	19369B	PARTICIPANT	\N	PRESENT	0
524465	524115	20044X	PARTICIPANT	\N	PRESENT	0
524466	524115	11097X	PARTICIPANT	\N	PRESENT	0
524467	524115	19387D	PARTICIPANT	\N	PRESENT	0
524468	524115	20150Y	PARTICIPANT	\N	PRESENT	0
524469	524115	19573D	PARTICIPANT	\N	PRESENT	0
524470	524115	11033F	PARTICIPANT	\N	PRESENT	0
524471	524115	19699S	PARTICIPANT	\N	PRESENT	0
524472	524115	19782L	PARTICIPANT	\N	PRESENT	0
524473	524115	19563B	PARTICIPANT	\N	PRESENT	0
524474	524115	14059S	PARTICIPANT	\N	PRESENT	0
524475	524115	14219Q	PARTICIPANT	\N	PRESENT	0
524476	524115	14189C	PARTICIPANT	\N	PRESENT	0
524477	524115	99004R	PARTICIPANT	\N	PRESENT	0
524478	524115	14211G	PARTICIPANT	\N	PRESENT	0
524479	524115	14187A	PARTICIPANT	\N	PRESENT	0
524480	524115	20140W	PARTICIPANT	\N	PRESENT	0
524481	524115	20076G	PARTICIPANT	\N	PRESENT	0
524482	524115	08015R	PARTICIPANT	\N	PRESENT	0
524483	524115	20104S	PARTICIPANT	\N	PRESENT	0
524484	524115	14217N	PARTICIPANT	\N	PRESENT	0
524485	524115	20026V	PARTICIPANT	\N	PRESENT	0
524486	524115	19581D	PARTICIPANT	\N	PRESENT	0
524487	524115	19762G	PARTICIPANT	\N	PRESENT	0
524488	524115	20032T	PARTICIPANT	\N	PRESENT	0
524489	524115	20020P	PARTICIPANT	\N	PRESENT	0
524490	524115	14031R	PARTICIPANT	\N	PRESENT	0
524492	524115	20024T	PARTICIPANT	\N	PRESENT	0
524493	524115	20124W	PARTICIPANT	\N	PRESENT	0
524494	524115	14221J	PARTICIPANT	\N	PRESENT	0
524495	524115	19383Y	PARTICIPANT	\N	PRESENT	0
524496	524115	20098N	PARTICIPANT	\N	PRESENT	0
524497	524115	19479G	PARTICIPANT	\N	PRESENT	0
524498	524115	20046A	PARTICIPANT	\N	PRESENT	0
524499	524115	14231L	PARTICIPANT	\N	PRESENT	0
524500	524115	19599P	PARTICIPANT	\N	PRESENT	0
524501	524115	19651A	PARTICIPANT	\N	PRESENT	0
524502	524115	19631V	PARTICIPANT	\N	PRESENT	0
524503	524115	17637T	PARTICIPANT	\N	PRESENT	0
524504	524115	01025N	PARTICIPANT	\N	PRESENT	0
524511	524115	19673G	PARTICIPANT	\N	PRESENT	0
524512	524115	19745F	PARTICIPANT	\N	PRESENT	0
524513	524115	20058E	PARTICIPANT	\N	PRESENT	0
524514	524115	19954N	PARTICIPANT	\N	PRESENT	0
524515	524115	19251M	PARTICIPANT	\N	PRESENT	0
524516	524115	19301E	PARTICIPANT	\N	PRESENT	0
524517	524115	14329V	PARTICIPANT	\N	PRESENT	0
524518	524115	20144B	PARTICIPANT	\N	PRESENT	0
524519	524115	01057W	PARTICIPANT	\N	PRESENT	0
524520	524115	20142Y	PARTICIPANT	\N	PRESENT	0
524521	524115	20068G	PARTICIPANT	\N	PRESENT	0
524522	524115	07029T	PARTICIPANT	\N	PRESENT	0
524523	524115	20096L	PARTICIPANT	\N	PRESENT	0
524524	524245	20130U	PARTICIPANT	\N	PRESENT	0
524525	524245	19515S	PRESIDENT	0	PRESENT	0
524526	524245	14187A	PARTICIPANT	\N	PRESENT	0
524527	524245	20040T	PARTICIPANT	\N	PRESENT	0
524528	524245	11053K	PARTICIPANT	\N	PRESENT	0
524529	524245	19717B	PARTICIPANT	\N	PRESENT	0
524530	524245	18193Q	PRESIDENT	1	PRESENT	0
524531	524245	20044X	PARTICIPANT	\N	PRESENT	0
524532	524245	19631V	PARTICIPANT	\N	PRESENT	0
524533	524245	20098N	PARTICIPANT	\N	PRESENT	0
524534	524245	14205J	PARTICIPANT	\N	PRESENT	0
524535	524245	19703U	PARTICIPANT	\N	PRESENT	0
524536	524245	19679N	PARTICIPANT	\N	PRESENT	0
524537	524245	19367Y	PARTICIPANT	\N	PRESENT	0
524538	524245	14071N	PARTICIPANT	\N	PRESENT	0
524539	524245	20018V	PARTICIPANT	\N	PRESENT	0
524540	524245	19760E	PARTICIPANT	\N	PRESENT	0
524541	524245	19667J	PARTICIPANT	\N	EXCUSE	0
524542	524245	19585H	PARTICIPANT	\N	EXCUSE	0
524550	524115	11080N	PARTICIPANT	\N	PRESENT	0
524551	524115	19713W	PARTICIPANT	\N	PRESENT	0
524552	524115	20102Q	PARTICIPANT	\N	PRESENT	0
524597	524115	20100N	PARTICIPANT	\N	PRESENT	0
524598	524115	20078J	PARTICIPANT	\N	PRESENT	0
524600	524115	19347U	PARTICIPANT	\N	PRESENT	0
524601	524115	19551W	PARTICIPANT	\N	PRESENT	0
524602	524115	14071N	PARTICIPANT	\N	PRESENT	0
524603	524115	14133K	PARTICIPANT	\N	PRESENT	0
524604	524115	20034V	PARTICIPANT	\N	PRESENT	0
524605	524115	19399H	PARTICIPANT	\N	PRESENT	0
537886	536607	11110B	PARTICIPANT	\N	PRESENT	1
537887	536607	99004R	PARTICIPANT	\N	PRESENT	1
537888	536607	20126Y	PARTICIPANT	\N	PRESENT	1
537889	536607	08010L	PARTICIPANT	\N	PRESENT	1
537890	536607	12016W	PARTICIPANT	\N	PRESENT	1
537891	536607	08011M	PARTICIPANT	\N	PRESENT	1
537892	536607	19479G	PARTICIPANT	\N	PRESENT	1
537893	536607	14173T	PARTICIPANT	\N	PRESENT	1
538147	536837	11066Q	PARTICIPANT	\N	PRESENT	0
539108	531688	19631V	PARTICIPANT	\N	PRESENT	0
539109	531688	19347U	PARTICIPANT	\N	PRESENT	0
539110	531688	20034V	PARTICIPANT	\N	PRESENT	0
539111	531688	12016W	PARTICIPANT	\N	PRESENT	0
539189	539188	19421M	PARTICIPANT	\N	PRESENT	0
539190	539188	19669L	PARTICIPANT	\N	PRESENT	0
539246	536834	19691J	PARTICIPANT	\N	PRESENT	0
539247	536834	20108W	PARTICIPANT	\N	PRESENT	0
539250	536834	19563B	PARTICIPANT	\N	PRESENT	0
539252	536834	14213J	PARTICIPANT	\N	PRESENT	0
539253	536834	11012A	PARTICIPANT	\N	PRESENT	0
539261	536834	19399H	PARTICIPANT	\N	PRESENT	0
539269	536834	19713W	PARTICIPANT	\N	PRESENT	0
539270	536834	11067R	PARTICIPANT	\N	PRESENT	0
539271	536834	14042U	PARTICIPANT	\N	PRESENT	0
539272	536834	08069G	PARTICIPANT	\N	PRESENT	0
539273	536834	14089Y	PARTICIPANT	\N	PRESENT	0
539274	536834	07004J	PARTICIPANT	\N	PRESENT	0
539290	536834	14083S	PARTICIPANT	\N	PRESENT	0
539300	536834	19760E	PARTICIPANT	\N	PRESENT	0
539302	536834	14030Q	PARTICIPANT	\N	PRESENT	0
539303	536834	14038Y	PARTICIPANT	\N	PRESENT	0
539304	536834	19593H	PARTICIPANT	\N	PRESENT	0
539305	536834	20048C	PARTICIPANT	\N	PRESENT	0
539306	536834	19701S	PARTICIPANT	\N	PRESENT	0
539307	536834	17779H	PARTICIPANT	\N	PRESENT	0
539317	531688	19657G	PARTICIPANT	\N	EXCUSE	0
539318	531688	19577H	PARTICIPANT	\N	EXCUSE	0
539338	536834	20110Q	PARTICIPANT	\N	PRESENT	0
539354	536834	11053K	PARTICIPANT	\N	PRESENT	0
539355	536834	19441R	PARTICIPANT	\N	PRESENT	0
539356	536834	01034P	PARTICIPANT	\N	PRESENT	0
539357	536834	19301E	PARTICIPANT	\N	PRESENT	0
539406	536835	19301E	PARTICIPANT	\N	PRESENT	0
539407	536835	11012A	PARTICIPANT	\N	PRESENT	0
539408	536835	20130U	PARTICIPANT	\N	PRESENT	0
539410	536835	19711U	PARTICIPANT	\N	PRESENT	0
539411	536835	19701S	PARTICIPANT	\N	PRESENT	0
539412	536835	20110Q	PARTICIPANT	\N	PRESENT	0
539413	536835	20102Q	PARTICIPANT	\N	PRESENT	0
539414	536835	14030Q	PARTICIPANT	\N	PRESENT	0
539415	536835	14042U	PARTICIPANT	\N	PRESENT	0
539416	536835	19441R	PARTICIPANT	\N	PRESENT	0
537884	536607	19667J	PARTICIPANT	\N	PRESENT	1
537885	536607	14327T	PARTICIPANT	\N	PRESENT	1
539417	536835	19713W	PARTICIPANT	\N	PRESENT	0
539418	536835	08069G	PARTICIPANT	\N	PRESENT	0
539419	536835	20066E	PARTICIPANT	\N	PRESENT	0
539420	536835	14221J	PARTICIPANT	\N	PRESENT	0
539421	536835	19747H	PARTICIPANT	\N	PRESENT	0
539422	536835	19563B	PARTICIPANT	\N	PRESENT	0
539423	536835	19369B	PARTICIPANT	\N	PRESENT	0
539425	536835	14083S	PARTICIPANT	\N	PRESENT	0
539426	536835	14213J	PARTICIPANT	\N	PRESENT	0
539428	536835	01024M	PARTICIPANT	\N	PRESENT	0
539429	536835	19760E	PARTICIPANT	\N	PRESENT	0
539430	536835	11031D	PARTICIPANT	\N	PRESENT	0
539431	536835	07004J	PARTICIPANT	\N	PRESENT	0
539432	536835	20048C	PARTICIPANT	\N	PRESENT	0
539433	536835	14041T	PARTICIPANT	\N	PRESENT	0
539434	536835	14089Y	PARTICIPANT	\N	PRESENT	0
539435	536835	14189C	PARTICIPANT	\N	PRESENT	0
539436	536835	19399H	PARTICIPANT	\N	PRESENT	0
539437	536835	20108W	PARTICIPANT	\N	PRESENT	0
539444	536835	10015M	PARTICIPANT	\N	PRESENT	0
539439	536835	17779H	PARTICIPANT	\N	PRESENT	0
539441	536835	10006L	PARTICIPANT	\N	PRESENT	0
539442	536835	19691J	PARTICIPANT	\N	PRESENT	0
539445	536835	01048V	PARTICIPANT	\N	PRESENT	0
539447	536835	19693L	PARTICIPANT	\N	PRESENT	0
539448	536835	19667J	PARTICIPANT	\N	PRESENT	0
539455	536835	14219Q	PARTICIPANT	\N	PRESENT	0
539470	536835	19503N	PARTICIPANT	\N	PRESENT	0
539475	536835	19489J	PARTICIPANT	\N	PRESENT	0
539489	536835	11072N	PARTICIPANT	\N	PRESENT	0
539521	536836	04047H	PARTICIPANT	\N	PRESENT	0
539522	536836	19489J	PARTICIPANT	\N	PRESENT	0
539523	536836	19585H	PARTICIPANT	\N	PRESENT	0
539524	536836	20110Q	PARTICIPANT	\N	PRESENT	0
539525	536836	11012A	PARTICIPANT	\N	PRESENT	0
539526	536836	11072N	PARTICIPANT	\N	PRESENT	0
539404	536835	99004R	PARTICIPANT	\N	PRESENT	0
539405	536835	01034P	PARTICIPANT	\N	PRESENT	0
539527	536836	19503N	PARTICIPANT	\N	PRESENT	0
539528	536836	19691J	PARTICIPANT	\N	PRESENT	0
539529	536836	20066E	PARTICIPANT	\N	PRESENT	0
539530	536836	19369B	PARTICIPANT	\N	PRESENT	0
539531	536836	14219Q	PARTICIPANT	\N	PRESENT	0
539532	536836	14041T	PARTICIPANT	\N	PRESENT	0
539533	536836	19693L	PARTICIPANT	\N	PRESENT	0
539534	536836	04085P	PARTICIPANT	\N	PRESENT	0
539535	536836	11031D	PARTICIPANT	\N	PRESENT	0
539545	536836	19543W	PARTICIPANT	\N	PRESENT	0
539546	536836	14213J	PARTICIPANT	\N	PRESENT	0
539568	539567	14225N	PARTICIPANT	\N	PRESENT	0
539569	539567	20050V	PARTICIPANT	\N	PRESENT	0
539570	539567	95063L	PARTICIPANT	\N	PRESENT	0
539571	539567	19747H	PARTICIPANT	\N	PRESENT	0
539572	539567	04035D	PARTICIPANT	\N	PRESENT	0
539590	538123	11090Q	PARTICIPANT	\N	EXCUSE	0
539592	539591	04042C	PRESIDENT	0	PRESENT	0
539593	539591	14331P	PRESIDENT	1	PRESENT	0
539594	539591	14133K	PARTICIPANT	\N	PRESENT	0
539595	539591	19709B	PARTICIPANT	\N	PRESENT	0
539596	539591	04034C	PARTICIPANT	\N	PRESENT	0
539597	539591	14001X	PARTICIPANT	\N	PRESENT	0
539519	536836	99004R	PARTICIPANT	\N	PRESENT	0
539520	536836	20108W	PARTICIPANT	\N	PRESENT	0
539598	539591	14073Q	PARTICIPANT	\N	PRESENT	0
539599	538783	04070G	PARTICIPANT	\N	PRESENT	0
539600	538783	14169X	PARTICIPANT	\N	PRESENT	0
539603	539602	19673G	PARTICIPANT	\N	PRESENT	0
539604	539602	19749K	PARTICIPANT	\N	PRESENT	0
539606	539605	08017T	PARTICIPANT	\N	PRESENT	0
539607	539605	14187A	PARTICIPANT	\N	PRESENT	1
539608	539605	14069U	PARTICIPANT	\N	PRESENT	0
539609	539605	20064C	PARTICIPANT	\N	PRESENT	0
539610	539605	14357A	PARTICIPANT	\N	PRESENT	0
539611	539605	11083R	PARTICIPANT	\N	PRESENT	0
539612	539605	19749K	PARTICIPANT	\N	PRESENT	0
539613	539605	19575F	PARTICIPANT	\N	PRESENT	1
539614	539605	19525U	PARTICIPANT	\N	PRESENT	1
539615	539605	19637C	PARTICIPANT	\N	PRESENT	1
539616	539605	04057K	PARTICIPANT	\N	PRESENT	1
539617	539605	14255U	PARTICIPANT	\N	PRESENT	1
539618	539605	19301E	PARTICIPANT	\N	PRESENT	0
539664	535603	19631V	PARTICIPANT	\N	EXCUSE	0
539687	534228	01028R	PARTICIPANT	\N	EXCUSE	0
539745	539682	11033F	PARTICIPANT	\N	PRESENT	1
539746	539682	20114U	PARTICIPANT	\N	PRESENT	1
539747	539682	19629C	PARTICIPANT	\N	PRESENT	1
539748	539682	19489J	PARTICIPANT	\N	PRESENT	1
539749	539682	14147R	PARTICIPANT	\N	PRESENT	1
539750	539682	14107H	PARTICIPANT	\N	PRESENT	1
539751	539682	19675J	PARTICIPANT	\N	PRESENT	1
539752	539682	14231L	PARTICIPANT	\N	EXCUSE	0
540024	538123	19563B	PARTICIPANT	\N	PRESENT	1
540043	539063	14327T	PARTICIPANT	\N	PRESENT	1
540044	539063	11110B	PARTICIPANT	\N	PRESENT	1
540045	539063	99004R	PARTICIPANT	\N	PRESENT	1
540046	539063	20126Y	PARTICIPANT	\N	PRESENT	1
540047	539063	12016W	PARTICIPANT	\N	PRESENT	1
540048	539063	19349W	PARTICIPANT	\N	PRESENT	1
540049	539063	19479G	PARTICIPANT	\N	PRESENT	1
540110	539586	19631V	PARTICIPANT	\N	PRESENT	1
540111	539586	19760E	PARTICIPANT	\N	PRESENT	1
540112	539586	19717B	PARTICIPANT	\N	PRESENT	1
540113	539586	04045F	PARTICIPANT	\N	PRESENT	1
540373	537783	19383Y	PARTICIPANT	\N	PRESENT	0
540374	537783	19515S	PARTICIPANT	\N	PRESENT	0
540375	537783	20092G	PARTICIPANT	\N	PRESENT	0
513061	509967	11040E	PARTICIPANT	\N	PRESENT	0
513062	509967	14327T	PARTICIPANT	\N	PRESENT	0
513063	509967	14331P	PARTICIPANT	\N	PRESENT	0
513064	509967	07029T	PARTICIPANT	\N	PRESENT	0
513065	509967	11048N	PARTICIPANT	\N	PRESENT	0
513066	509967	19531S	PARTICIPANT	\N	PRESENT	0
513067	509967	19335Q	PARTICIPANT	\N	PRESENT	0
513068	509967	20022R	PARTICIPANT	\N	PRESENT	0
513069	509967	20126Y	PARTICIPANT	\N	PRESENT	0
513070	509967	19762G	PARTICIPANT	\N	PRESENT	0
513071	509967	19741B	PARTICIPANT	\N	PRESENT	0
513072	509967	14225N	PRESIDENT	0	PRESENT	0
513081	502352	11045K	PARTICIPANT	\N	PRESENT	0
513083	502352	14281W	PARTICIPANT	\N	PRESENT	0
513084	502352	19715Y	PARTICIPANT	\N	PRESENT	0
513085	502352	19545Y	PARTICIPANT	\N	PRESENT	0
513086	502352	19689Q	PARTICIPANT	\N	PRESENT	0
513087	502352	19679N	PARTICIPANT	\N	PRESENT	0
513089	502352	14026U	PARTICIPANT	\N	PRESENT	0
513090	502352	14053L	PARTICIPANT	\N	PRESENT	0
513091	502352	14331P	PARTICIPANT	\N	PRESENT	0
513092	502352	19691J	PARTICIPANT	\N	PRESENT	0
513093	502352	19697Q	PARTICIPANT	\N	PRESENT	0
513094	502352	19569H	PARTICIPANT	\N	PRESENT	0
513096	502352	20130U	PARTICIPANT	\N	PRESENT	0
513097	502352	19583F	PARTICIPANT	\N	PRESENT	0
513098	502352	19415P	PARTICIPANT	\N	PRESENT	0
513099	502352	19741B	PARTICIPANT	\N	PRESENT	0
513100	502352	19719D	PARTICIPANT	\N	PRESENT	0
513101	502352	07029T	PARTICIPANT	\N	PRESENT	0
513102	502352	11040E	PARTICIPANT	\N	PRESENT	0
513103	502352	19760E	PARTICIPANT	\N	PRESENT	0
513104	502352	19693L	PARTICIPANT	\N	PRESENT	0
513105	502352	14071N	PARTICIPANT	\N	PRESENT	0
513106	502352	20152B	PARTICIPANT	\N	PRESENT	0
513107	502352	19585H	PARTICIPANT	\N	PRESENT	0
513108	502352	11031D	PARTICIPANT	\N	PRESENT	0
513109	502352	19687N	PARTICIPANT	\N	PRESENT	0
513110	502352	20062A	PARTICIPANT	\N	PRESENT	0
513111	502352	11012A	PARTICIPANT	\N	PRESENT	0
513112	502352	19349W	PARTICIPANT	\N	PRESENT	0
513113	502352	10006L	PARTICIPANT	\N	PRESENT	0
513114	502352	19747H	PARTICIPANT	\N	PRESENT	0
513115	502352	01057W	PARTICIPANT	\N	PRESENT	0
513116	502352	20058E	PARTICIPANT	\N	PRESENT	0
513117	502352	19713W	PARTICIPANT	\N	PRESENT	0
513118	502352	14225N	PARTICIPANT	\N	PRESENT	0
513119	502352	04043D	PARTICIPANT	\N	PRESENT	0
513120	502352	19717B	PARTICIPANT	\N	PRESENT	0
513121	502352	11097X	PARTICIPANT	\N	PRESENT	0
513122	502352	19657G	PARTICIPANT	\N	PRESENT	0
513147	502352	19593H	PARTICIPANT	\N	PRESENT	0
513148	502352	14021P	PARTICIPANT	\N	PRESENT	0
513150	502352	14073Q	PARTICIPANT	\N	PRESENT	0
513151	502352	07004J	PARTICIPANT	\N	PRESENT	0
513152	502352	20080C	PARTICIPANT	\N	PRESENT	0
513153	502352	20070A	PARTICIPANT	\N	PRESENT	0
513154	502352	20054A	PARTICIPANT	\N	PRESENT	0
513155	502352	20126Y	PARTICIPANT	\N	PRESENT	0
513156	502352	08010L	PARTICIPANT	\N	PRESENT	0
513157	502352	14111D	PARTICIPANT	\N	PRESENT	0
513158	502352	19479G	PARTICIPANT	\N	PRESENT	0
513159	502352	19643A	PARTICIPANT	\N	PRESENT	0
513163	502352	14215L	PARTICIPANT	\N	PRESENT	0
513230	502354	14281W	PARTICIPANT	\N	PRESENT	0
513162	502352	20098N	PARTICIPANT	\N	PRESENT	0
513164	502352	11026G	PARTICIPANT	\N	PRESENT	0
513165	502352	19749K	PARTICIPANT	\N	PRESENT	0
513166	502352	14179A	PARTICIPANT	\N	PRESENT	0
513167	502352	19527W	PARTICIPANT	\N	PRESENT	0
513231	502354	19583F	PARTICIPANT	\N	PRESENT	0
513232	502354	11012A	PARTICIPANT	\N	PRESENT	0
513233	502354	14073Q	PARTICIPANT	\N	PRESENT	0
513234	502354	14026U	PARTICIPANT	\N	PRESENT	0
513235	502354	07029T	PARTICIPANT	\N	PRESENT	0
513236	502354	19691J	PARTICIPANT	\N	PRESENT	0
513237	502354	14249W	PARTICIPANT	\N	PRESENT	0
513238	502354	19301E	PARTICIPANT	\N	PRESENT	0
513239	502354	19347U	PARTICIPANT	\N	PRESENT	0
513240	502354	19713W	PARTICIPANT	\N	PRESENT	0
513241	502354	19629C	PARTICIPANT	\N	PRESENT	0
513242	502354	19693L	PARTICIPANT	\N	PRESENT	0
513243	502354	14071N	PARTICIPANT	\N	PRESENT	0
513244	502354	20152B	PARTICIPANT	\N	PRESENT	0
513245	502354	11056N	PARTICIPANT	\N	PRESENT	0
513246	502354	19717B	PARTICIPANT	\N	PRESENT	0
513247	502354	19349W	PARTICIPANT	\N	PRESENT	0
513248	502354	19758L	PARTICIPANT	\N	PRESENT	0
513249	502354	11040E	PARTICIPANT	\N	PRESENT	0
513250	502354	19711U	PARTICIPANT	\N	PRESENT	0
513251	502354	19581D	PARTICIPANT	\N	PRESENT	0
513252	502354	20062A	PARTICIPANT	\N	PRESENT	0
513253	502354	17023S	PARTICIPANT	\N	PRESENT	0
513254	502354	11097X	PARTICIPANT	\N	PRESENT	0
513255	502354	14021P	PARTICIPANT	\N	PRESENT	0
513256	502354	19747H	PARTICIPANT	\N	PRESENT	0
513257	502354	20058E	PARTICIPANT	\N	PRESENT	0
513258	502354	04043D	PARTICIPANT	\N	PRESENT	0
513259	502354	14121F	PARTICIPANT	\N	PRESENT	0
513260	502354	11090Q	PARTICIPANT	\N	PRESENT	0
513261	502354	11033F	PARTICIPANT	\N	PRESENT	0
513262	502354	20134Y	PARTICIPANT	\N	PRESENT	0
513263	502354	19657G	PARTICIPANT	\N	PRESENT	0
513264	502354	20054A	PARTICIPANT	\N	PRESENT	0
513265	502354	19527W	PARTICIPANT	\N	PRESENT	0
513266	502354	08010L	PARTICIPANT	\N	PRESENT	0
513267	502354	20098N	PARTICIPANT	\N	PRESENT	0
513268	502354	11043H	PARTICIPANT	\N	PRESENT	0
513269	502354	14179A	PARTICIPANT	\N	PRESENT	0
513270	502354	14253S	PARTICIPANT	\N	PRESENT	0
513271	502354	19667J	PARTICIPANT	\N	PRESENT	0
513272	502354	19611R	PARTICIPANT	\N	PRESENT	0
513273	502354	20126Y	PARTICIPANT	\N	PRESENT	0
513274	502354	14053L	PARTICIPANT	\N	PRESENT	0
513275	502354	14089Y	PARTICIPANT	\N	PRESENT	0
513276	502354	19573D	PARTICIPANT	\N	PRESENT	0
513277	502354	19593H	PARTICIPANT	\N	PRESENT	0
513278	502354	20070A	PARTICIPANT	\N	PRESENT	0
513279	502354	14215L	PARTICIPANT	\N	PRESENT	0
513280	502354	07004J	PARTICIPANT	\N	PRESENT	0
513281	502354	14111D	PARTICIPANT	\N	PRESENT	0
513282	502354	11053K	PARTICIPANT	\N	PRESENT	0
513285	502354	08012N	PARTICIPANT	\N	PRESENT	0
513228	502354	99004R	PARTICIPANT	\N	PRESENT	0
513229	502354	19715Y	PARTICIPANT	\N	PRESENT	0
513286	502354	19585H	PARTICIPANT	\N	PRESENT	0
513287	502354	19749K	PARTICIPANT	\N	PRESENT	0
513288	502354	20124W	PARTICIPANT	\N	PRESENT	0
513289	502354	19687N	PARTICIPANT	\N	PRESENT	0
513290	502354	19741B	PARTICIPANT	\N	PRESENT	0
513291	502354	19577H	PARTICIPANT	\N	PRESENT	0
513292	502354	14331P	PARTICIPANT	\N	PRESENT	0
513293	502354	19479G	PARTICIPANT	\N	PRESENT	0
513294	502354	20080C	PARTICIPANT	\N	PRESENT	0
513295	502354	01057W	PARTICIPANT	\N	PRESENT	0
513296	502354	11109J	PARTICIPANT	\N	PRESENT	0
513297	502354	19531S	PARTICIPANT	\N	PRESENT	0
513298	502354	11099A	PARTICIPANT	\N	PRESENT	0
513299	502354	19649G	PARTICIPANT	\N	PRESENT	0
513300	502354	11072N	PARTICIPANT	\N	PRESENT	0
513301	502354	11085T	PARTICIPANT	\N	PRESENT	0
513302	502354	20034V	PARTICIPANT	\N	PRESENT	0
513304	502354	11077T	PARTICIPANT	\N	PRESENT	0
513305	502354	14225N	PARTICIPANT	\N	PRESENT	0
531870	530806	20090E	PARTICIPANT	\N	PRESENT	0
531871	530806	19701S	PARTICIPANT	\N	PRESENT	1
533692	530841	19691J	PARTICIPANT	\N	PRESENT	0
533693	530841	19697Q	PARTICIPANT	\N	PRESENT	1
533694	530841	19798U	PARTICIPANT	\N	PRESENT	1
536109	534258	19782L	PARTICIPANT	\N	PRESENT	0
536113	534258	19551W	PARTICIPANT	\N	PRESENT	0
536117	534258	01057W	PARTICIPANT	\N	PRESENT	0
536118	534258	19503N	PARTICIPANT	\N	PRESENT	0
536119	534258	11115U	PARTICIPANT	\N	PRESENT	0
536120	534258	20132W	PARTICIPANT	\N	PRESENT	0
536131	534258	14026U	PARTICIPANT	\N	PRESENT	0
536140	534258	19954N	PARTICIPANT	\N	PRESENT	0
536147	534258	20026V	PARTICIPANT	\N	PRESENT	0
536148	534258	11053K	PARTICIPANT	\N	PRESENT	0
536149	534258	14030Q	PARTICIPANT	\N	PRESENT	0
536150	534258	05012A	PARTICIPANT	\N	PRESENT	0
536151	534258	14357A	PARTICIPANT	\N	PRESENT	0
536152	534258	20046A	PARTICIPANT	\N	PRESENT	0
536153	534258	20062A	PARTICIPANT	\N	PRESENT	0
536154	534258	20136B	PARTICIPANT	\N	PRESENT	0
536202	534259	19347U	PARTICIPANT	\N	PRESENT	0
536203	534259	20132W	PARTICIPANT	\N	PRESENT	0
536204	534259	20050V	PARTICIPANT	\N	PRESENT	0
536205	534259	19553Y	PARTICIPANT	\N	PRESENT	0
536206	534259	20042V	PARTICIPANT	\N	PRESENT	0
536207	534259	19479G	PARTICIPANT	\N	PRESENT	0
536208	534259	19551W	PARTICIPANT	\N	PRESENT	0
536209	534259	20180F	PARTICIPANT	\N	PRESENT	0
536210	534259	20056C	PARTICIPANT	\N	PRESENT	0
536211	534259	20026V	PARTICIPANT	\N	PRESENT	0
536212	534259	20136B	PARTICIPANT	\N	PRESENT	0
536213	534259	19503N	PARTICIPANT	\N	PRESENT	0
536214	534259	07029T	PARTICIPANT	\N	PRESENT	0
536215	534259	14069U	PARTICIPANT	\N	PRESENT	0
536216	534259	20100N	PARTICIPANT	\N	PRESENT	0
536217	534259	19413M	PARTICIPANT	\N	PRESENT	0
536218	534259	19637C	PARTICIPANT	\N	PRESENT	0
536219	534259	20046A	PARTICIPANT	\N	PRESENT	0
536220	534259	20102Q	PARTICIPANT	\N	PRESENT	0
536221	534259	01057W	PARTICIPANT	\N	PRESENT	0
536222	534259	20062A	PARTICIPANT	\N	PRESENT	0
536223	534259	14357A	PARTICIPANT	\N	PRESENT	0
536224	534259	14033T	PARTICIPANT	\N	PRESENT	0
536225	534259	19599P	PARTICIPANT	\N	PRESENT	0
536226	534259	19333N	PARTICIPANT	\N	PRESENT	0
536227	534259	20024T	PARTICIPANT	\N	PRESENT	0
536228	534259	11048N	PARTICIPANT	\N	PRESENT	0
536229	534259	01043Q	PARTICIPANT	\N	PRESENT	0
536230	534259	19747H	PARTICIPANT	\N	PRESENT	0
536231	534259	20086J	PARTICIPANT	\N	PRESENT	0
536232	534259	05012A	PARTICIPANT	\N	PRESENT	0
536233	534259	01024M	PARTICIPANT	\N	PRESENT	0
536234	534259	19467C	PARTICIPANT	\N	PRESENT	0
536236	536235	20114U	PARTICIPANT	\N	PRESENT	0
536237	536235	19721W	PARTICIPANT	\N	PRESENT	0
536238	536235	19693L	PARTICIPANT	\N	PRESENT	0
536239	536235	20132W	PARTICIPANT	\N	PRESENT	0
536240	536235	19715Y	PARTICIPANT	\N	PRESENT	1
536241	536235	19735D	PARTICIPANT	\N	PRESENT	1
536242	536235	19611R	PARTICIPANT	\N	PRESENT	0
536243	536235	14059S	PARTICIPANT	\N	PRESENT	1
536244	536235	20142Y	PARTICIPANT	\N	PRESENT	0
536245	536235	14147R	PARTICIPANT	\N	PRESENT	1
536246	536235	19593H	PRESIDENT	0	PRESENT	0
536247	536235	19745F	PARTICIPANT	\N	PRESENT	0
536200	534259	14026U	PARTICIPANT	\N	PRESENT	0
536201	534259	14259Y	PARTICIPANT	\N	PRESENT	0
536248	536235	19533U	PARTICIPANT	\N	PRESENT	0
536249	536235	20082E	PARTICIPANT	\N	PRESENT	0
536250	536235	19643A	PARTICIPANT	\N	PRESENT	0
536251	536235	20050V	PARTICIPANT	\N	PRESENT	0
536252	530867	19699S	PARTICIPANT	\N	PRESENT	1
536253	534275	19515S	PRESIDENT	0	PRESENT	0
536254	534275	19575F	PARTICIPANT	\N	PRESENT	0
536255	534275	14105F	PARTICIPANT	\N	PRESENT	0
536256	534275	19467C	PARTICIPANT	\N	PRESENT	0
536257	534275	14041T	PARTICIPANT	\N	PRESENT	0
536258	534275	19251M	PARTICIPANT	\N	PRESENT	0
536259	534275	14026U	PARTICIPANT	\N	PRESENT	0
536260	534275	08015R	PARTICIPANT	\N	PRESENT	0
536261	534275	16685X	PARTICIPANT	\N	PRESENT	0
536262	534275	19762G	PARTICIPANT	\N	PRESENT	0
536263	534275	14357A	PARTICIPANT	\N	PRESENT	0
536264	534275	19695N	PARTICIPANT	\N	PRESENT	0
536265	534275	20048C	PARTICIPANT	\N	PRESENT	0
536266	534275	14031R	PARTICIPANT	\N	PRESENT	0
536267	534275	14083S	PARTICIPANT	\N	PRESENT	0
536268	534275	19671E	PARTICIPANT	\N	PRESENT	0
536273	534275	20060X	PARTICIPANT	\N	PRESENT	0
536288	531551	19717B	PARTICIPANT	\N	PRESENT	0
536290	531551	19631V	PARTICIPANT	\N	PRESENT	0
536291	531551	18083K	PARTICIPANT	\N	PRESENT	0
536293	531551	19659J	PARTICIPANT	\N	EXCUSE	0
536294	531551	19347U	PARTICIPANT	\N	PRESENT	0
536295	531551	14033T	PARTICIPANT	\N	PRESENT	0
536297	531551	19691J	PARTICIPANT	\N	PRESENT	0
536299	531551	19329S	PARTICIPANT	\N	PRESENT	0
536301	531551	20034V	PARTICIPANT	\N	PRESENT	0
536302	531551	14097Y	PARTICIPANT	\N	PRESENT	0
536304	531551	19583F	PARTICIPANT	\N	PRESENT	0
536305	531551	14059S	PARTICIPANT	\N	EXCUSE	0
536306	531551	12016W	PARTICIPANT	\N	PRESENT	0
536307	531551	14147R	PARTICIPANT	\N	PRESENT	0
536308	531551	20146D	PARTICIPANT	\N	PRESENT	0
536309	531551	11109J	PARTICIPANT	\N	EXCUSE	0
536322	536314	11083R	PARTICIPANT	\N	PRESENT	0
536323	536314	14033T	PARTICIPANT	\N	PRESENT	0
536324	536314	19553Y	PARTICIPANT	\N	PRESENT	1
536335	534195	20104S	PARTICIPANT	\N	PRESENT	0
536326	536314	12041X	PARTICIPANT	\N	PRESENT	0
536327	536314	14001X	PARTICIPANT	\N	PRESENT	0
536328	536314	04057K	PARTICIPANT	\N	PRESENT	0
536329	536314	14331P	PARTICIPANT	\N	PRESENT	0
536336	534195	19701S	PARTICIPANT	\N	PRESENT	0
536101	534268	19651A	PARTICIPANT	\N	PRESENT	1
536102	534268	19689Q	PARTICIPANT	\N	PRESENT	1
536103	534268	20048C	PRESIDENT	0	PRESENT	0
536104	534268	14123H	PARTICIPANT	\N	PRESENT	0
536105	534268	19866P	PARTICIPANT	\N	PRESENT	0
536106	534268	20052X	PARTICIPANT	\N	PRESENT	0
536107	534268	17779H	PARTICIPANT	\N	PRESENT	0
536108	534258	20064C	PARTICIPANT	\N	PRESENT	0
536338	534195	20100N	PARTICIPANT	\N	PRESENT	0
536340	534195	11083R	PARTICIPANT	\N	PRESENT	0
536341	534195	14033T	PARTICIPANT	\N	PRESENT	0
536344	534195	20128B	PARTICIPANT	\N	PRESENT	1
536346	534195	12041X	PARTICIPANT	\N	PRESENT	0
536348	534195	19441R	PARTICIPANT	\N	PRESENT	0
536349	534195	14001X	PARTICIPANT	\N	PRESENT	0
536351	534195	04057K	PARTICIPANT	\N	PRESENT	0
536354	534195	04070G	PARTICIPANT	\N	PRESENT	1
536356	534195	14237S	PARTICIPANT	\N	PRESENT	0
536357	534195	14331P	PRESIDENT	0	PRESENT	0
536361	536360	14189C	PARTICIPANT	\N	PRESENT	0
536362	536360	20024T	PARTICIPANT	\N	PRESENT	0
536363	536360	14030Q	PRESIDENT	0	PRESENT	0
536364	536360	20080C	PARTICIPANT	\N	PRESENT	0
536365	536360	11031D	PARTICIPANT	\N	PRESENT	0
536366	536360	19693L	PARTICIPANT	\N	EXCUSE	0
536367	536360	19599P	PARTICIPANT	\N	PRESENT	0
536368	536360	20106U	PARTICIPANT	\N	PRESENT	0
536369	536360	14179A	PARTICIPANT	\N	PRESENT	0
536370	536360	20066E	PARTICIPANT	\N	PRESENT	0
536371	536360	19715Y	PARTICIPANT	\N	PRESENT	0
536372	536360	20056C	PARTICIPANT	\N	PRESENT	0
536373	536360	14109K	PARTICIPANT	\N	PRESENT	0
536374	536360	19768N	PARTICIPANT	\N	PRESENT	0
536403	536360	19866P	PARTICIPANT	\N	PRESENT	0
536404	536360	20118Y	PARTICIPANT	\N	PRESENT	0
536405	536360	19798U	PARTICIPANT	\N	PRESENT	0
536406	536360	20098N	PARTICIPANT	\N	PRESENT	0
536407	536360	19527W	PARTICIPANT	\N	PRESENT	0
536408	536360	20046A	PARTICIPANT	\N	PRESENT	0
536409	536360	19749K	PARTICIPANT	\N	EXCUSE	0
536410	536360	20022R	PARTICIPANT	\N	PRESENT	0
536411	536360	04045F	PARTICIPANT	\N	PRESENT	0
536412	536360	14229S	PARTICIPANT	\N	PRESENT	0
536413	536360	08010L	PARTICIPANT	\N	PRESENT	0
536414	536360	19489J	PARTICIPANT	\N	PRESENT	0
536415	534354	04086Q	PARTICIPANT	\N	PRESENT	0
519103	519102	14255U	PARTICIPANT	\N	PRESENT	0
519104	519102	18083K	PARTICIPANT	\N	PRESENT	0
519105	519102	14267Y	PARTICIPANT	\N	PRESENT	0
519215	519213	01028R	PARTICIPANT	\N	PRESENT	0
519107	519102	19685L	PARTICIPANT	\N	PRESENT	0
519108	519102	14059S	PARTICIPANT	\N	PRESENT	0
519109	519102	14071N	PARTICIPANT	\N	PRESENT	0
519110	519102	14193X	PARTICIPANT	\N	PRESENT	0
519111	519102	20054A	PARTICIPANT	\N	PRESENT	0
519112	519102	14107H	PARTICIPANT	\N	PRESENT	0
519113	519102	19421M	PARTICIPANT	\N	PRESENT	0
519214	519213	14053L	PARTICIPANT	\N	PRESENT	0
519216	519213	19749K	PARTICIPANT	\N	PRESENT	0
519217	519213	19725B	PARTICIPANT	\N	PRESENT	0
519219	519218	14053L	PARTICIPANT	\N	PRESENT	0
519220	519218	04085P	PARTICIPANT	\N	PRESENT	0
519221	519218	19725B	PARTICIPANT	\N	PRESENT	1
519222	519218	01028R	PARTICIPANT	\N	PRESENT	1
519228	519218	19749K	PARTICIPANT	\N	PRESENT	0
521232	521211	19399H	PARTICIPANT	\N	PRESENT	0
521258	518673	11074Q	PARTICIPANT	\N	PRESENT	0
521259	518673	08045X	PARTICIPANT	\N	PRESENT	0
521260	518673	20120S	PARTICIPANT	\N	PRESENT	0
521261	518673	08015R	PARTICIPANT	\N	PRESENT	0
521262	518673	18193Q	PARTICIPANT	\N	PRESENT	0
521263	518673	20028X	PARTICIPANT	\N	PRESENT	0
521264	518673	19745F	PARTICIPANT	\N	PRESENT	0
524698	524116	01028R	PARTICIPANT	\N	PRESENT	0
524699	524116	11033F	PARTICIPANT	\N	PRESENT	0
524700	524116	20142Y	PARTICIPANT	\N	PRESENT	0
524701	524116	19347U	PARTICIPANT	\N	PRESENT	0
524702	524116	19387D	PARTICIPANT	\N	PRESENT	0
524703	524116	95063L	PARTICIPANT	\N	PRESENT	0
524704	524116	19651A	PARTICIPANT	\N	PRESENT	0
524705	524116	08061X	PARTICIPANT	\N	PRESENT	0
524706	524116	19749K	PARTICIPANT	\N	PRESENT	0
524707	524116	19441R	PARTICIPANT	\N	PRESENT	0
524708	524116	14053L	PARTICIPANT	\N	PRESENT	0
524709	524116	20094J	PARTICIPANT	\N	PRESENT	0
524710	524116	11067R	PARTICIPANT	\N	PRESENT	0
524711	524116	19725B	PARTICIPANT	\N	PRESENT	0
524712	524116	20028X	PARTICIPANT	\N	PRESENT	0
524713	524116	19549D	PARTICIPANT	\N	PRESENT	0
524714	524116	14215L	PARTICIPANT	\N	PRESENT	0
524715	524116	14189C	PARTICIPANT	\N	PRESENT	0
524716	524116	11056N	PARTICIPANT	\N	PRESENT	0
524717	524116	19565D	PARTICIPANT	\N	PRESENT	0
524718	524116	19367Y	PARTICIPANT	\N	PRESENT	0
524719	524116	14331P	PARTICIPANT	\N	PRESENT	0
524720	524116	19762G	PARTICIPANT	\N	PRESENT	0
524721	524116	19798U	PARTICIPANT	\N	PRESENT	0
524722	524116	19693L	PARTICIPANT	\N	PRESENT	0
524723	524116	20074E	PARTICIPANT	\N	PRESENT	0
524724	524116	19563B	PARTICIPANT	\N	PRESENT	0
524725	524116	14221J	PARTICIPANT	\N	PRESENT	0
524726	524116	14069U	PARTICIPANT	\N	PRESENT	0
524727	524116	14187A	PARTICIPANT	\N	PRESENT	0
524728	524116	14030Q	PARTICIPANT	\N	PRESENT	0
524729	524116	20090E	PARTICIPANT	\N	PRESENT	0
524730	524116	20078J	PARTICIPANT	\N	PRESENT	0
524731	524116	14059S	PARTICIPANT	\N	PRESENT	0
524732	524116	14133K	PARTICIPANT	\N	PRESENT	0
524733	524116	19673G	PARTICIPANT	\N	PRESENT	0
524734	524116	19760E	PARTICIPANT	\N	PRESENT	0
524735	524116	04085P	PARTICIPANT	\N	PRESENT	0
524758	524116	20052X	PARTICIPANT	\N	PRESENT	0
524737	524116	11072N	PARTICIPANT	\N	PRESENT	0
524738	524116	20024T	PARTICIPANT	\N	PRESENT	0
524739	524116	19383Y	PARTICIPANT	\N	PRESENT	0
524740	524116	14231L	PARTICIPANT	\N	PRESENT	0
524741	524116	14329V	PARTICIPANT	\N	PRESENT	0
524742	524116	14071N	PARTICIPANT	\N	PRESENT	0
524749	524116	19507S	PARTICIPANT	\N	PRESENT	0
524744	524116	14033T	PARTICIPANT	\N	PRESENT	0
524745	524116	19703U	PARTICIPANT	\N	PRESENT	0
524746	524116	18193Q	PARTICIPANT	\N	PRESENT	0
524747	524116	20100N	PARTICIPANT	\N	PRESENT	0
524748	524116	19533U	PARTICIPANT	\N	PRESENT	0
524750	524116	19467C	PARTICIPANT	\N	PRESENT	0
524751	524116	14151M	PARTICIPANT	\N	PRESENT	0
524752	524116	19631V	PARTICIPANT	\N	PRESENT	0
524753	524116	19591F	PARTICIPANT	\N	PRESENT	0
524754	524116	20034V	PARTICIPANT	\N	PRESENT	0
524755	524116	20096L	PARTICIPANT	\N	PRESENT	0
524756	524116	19758L	PARTICIPANT	\N	PRESENT	0
524757	524116	19447X	PARTICIPANT	\N	PRESENT	0
524759	524116	11012A	PARTICIPANT	\N	PRESENT	0
524760	524116	19629C	PARTICIPANT	\N	PRESENT	0
524761	524116	20116W	PARTICIPANT	\N	PRESENT	0
524762	524116	14217N	PARTICIPANT	\N	PRESENT	0
524763	524116	14213J	PARTICIPANT	\N	PRESENT	0
524841	524117	14053L	PARTICIPANT	\N	PRESENT	0
524842	524117	19725B	PARTICIPANT	\N	PRESENT	0
524843	524117	11033F	PARTICIPANT	\N	PRESENT	0
524844	524117	19347U	PARTICIPANT	\N	PRESENT	0
524845	524117	14151M	PARTICIPANT	\N	PRESENT	0
524846	524117	11056N	PARTICIPANT	\N	PRESENT	0
524847	524117	19691J	PARTICIPANT	\N	PRESENT	0
524848	524117	19749K	PARTICIPANT	\N	PRESENT	0
524696	524116	14026U	PARTICIPANT	\N	PRESENT	0
524697	524116	04047H	PARTICIPANT	\N	PRESENT	0
524849	524117	14231L	PARTICIPANT	\N	PRESENT	0
524850	524117	20116W	PARTICIPANT	\N	PRESENT	0
524851	524117	19629C	PARTICIPANT	\N	PRESENT	0
524852	524117	19651A	PARTICIPANT	\N	PRESENT	0
524853	524117	11072N	PARTICIPANT	\N	PRESENT	0
524854	524117	19826F	PARTICIPANT	\N	PRESENT	0
524855	524117	20090E	PARTICIPANT	\N	PRESENT	0
524856	524117	14147R	PARTICIPANT	\N	PRESENT	0
524857	524117	18083K	PARTICIPANT	\N	PRESENT	0
524858	524117	20034V	PARTICIPANT	\N	PRESENT	0
524859	524117	20044X	PARTICIPANT	\N	PRESENT	0
524860	524117	19798U	PARTICIPANT	\N	PRESENT	0
524861	524117	19447X	PARTICIPANT	\N	PRESENT	0
524862	524117	19565D	PARTICIPANT	\N	PRESENT	0
524863	524117	19758L	PARTICIPANT	\N	PRESENT	0
524868	524117	05008E	PARTICIPANT	\N	PRESENT	0
524865	524117	14221J	PARTICIPANT	\N	PRESENT	0
524866	524117	19563B	PARTICIPANT	\N	PRESENT	0
524867	524117	20058E	PARTICIPANT	\N	PRESENT	0
524869	524117	14071N	PARTICIPANT	\N	PRESENT	0
524870	524117	14033T	PARTICIPANT	\N	PRESENT	0
524871	524117	14107H	PARTICIPANT	\N	PRESENT	0
524872	524117	20052X	PARTICIPANT	\N	PRESENT	0
524873	524117	11026G	PARTICIPANT	\N	PRESENT	0
524874	524117	14253S	PARTICIPANT	\N	PRESENT	0
524875	524117	01028R	PARTICIPANT	\N	PRESENT	0
524876	524117	11090Q	PARTICIPANT	\N	PRESENT	0
524877	524117	20066E	PARTICIPANT	\N	PRESENT	0
524878	524117	14069U	PARTICIPANT	\N	PRESENT	0
524879	524117	17737W	PARTICIPANT	\N	PRESENT	0
524880	524117	20024T	PARTICIPANT	\N	PRESENT	0
524881	524117	14213J	PARTICIPANT	\N	PRESENT	0
524882	524117	20110Q	PARTICIPANT	\N	PRESENT	0
524883	524117	04085P	PARTICIPANT	\N	PRESENT	0
524884	524117	19760E	PARTICIPANT	\N	PRESENT	0
524885	524117	14215L	PARTICIPANT	\N	PRESENT	0
524886	524117	20054A	PARTICIPANT	\N	PRESENT	0
525788	524116	14147R	PARTICIPANT	\N	PRESENT	0
524888	524117	19387D	PARTICIPANT	\N	PRESENT	0
524889	524117	20070A	PARTICIPANT	\N	PRESENT	0
526368	526367	04070G	PARTICIPANT	\N	PRESENT	0
526369	526367	14169X	PARTICIPANT	\N	PRESENT	0
526414	526413	04070G	PARTICIPANT	\N	PRESENT	0
526415	526413	14169X	PARTICIPANT	\N	PRESENT	0
526416	526370	04092N	PARTICIPANT	\N	PRESENT	0
526417	526371	04092N	PARTICIPANT	\N	PRESENT	0
526418	526371	20130U	PARTICIPANT	\N	PRESENT	1
526647	526646	07033P	PARTICIPANT	\N	PRESENT	1
526648	526646	14109K	PARTICIPANT	\N	PRESENT	1
526677	526676	07033P	PARTICIPANT	\N	PRESENT	1
526678	526676	14109K	PARTICIPANT	\N	PRESENT	1
526680	526679	07033P	PARTICIPANT	\N	PRESENT	1
526681	526679	14109K	PARTICIPANT	\N	PRESENT	1
526683	526682	07033P	PARTICIPANT	\N	PRESENT	1
526684	526682	14109K	PARTICIPANT	\N	PRESENT	1
526687	526686	07033P	PARTICIPANT	\N	PRESENT	1
526688	526686	14109K	PARTICIPANT	\N	PRESENT	1
524839	524117	11045K	PARTICIPANT	\N	PRESENT	0
524840	524117	04047H	PARTICIPANT	\N	PRESENT	0
538769	538768	20144B	PARTICIPANT	\N	PRESENT	0
538770	538768	14033T	PARTICIPANT	\N	PRESENT	0
538785	538784	14189C	PARTICIPANT	\N	PRESENT	0
538786	538784	19575F	PARTICIPANT	\N	PRESENT	0
538787	538784	19549D	PARTICIPANT	\N	PRESENT	0
538788	538784	20094J	PARTICIPANT	\N	PRESENT	0
538790	538784	20060X	PARTICIPANT	\N	PRESENT	0
538791	538784	14195A	PARTICIPANT	\N	PRESENT	0
538792	538784	11099A	PARTICIPANT	\N	PRESENT	0
538793	538784	20018V	PARTICIPANT	\N	PRESENT	0
538794	538784	14257W	PARTICIPANT	\N	PRESENT	0
538795	538784	20044X	PARTICIPANT	\N	PRESENT	0
538796	538784	19689Q	PARTICIPANT	\N	PRESENT	0
539171	539170	14255U	PARTICIPANT	\N	PRESENT	0
539172	539170	20064C	PARTICIPANT	\N	PRESENT	0
539175	536896	08012N	PARTICIPANT	\N	PRESENT	0
539176	536896	19333N	PARTICIPANT	\N	PRESENT	0
539177	536896	11083R	PARTICIPANT	\N	PRESENT	0
539178	536896	20056C	PARTICIPANT	\N	PRESENT	0
539179	536896	14255U	PARTICIPANT	\N	PRESENT	0
539186	537512	20040T	PARTICIPANT	\N	EXCUSE	0
539424	531687	19577H	PARTICIPANT	\N	PRESENT	0
539427	531687	19657G	PARTICIPANT	\N	PRESENT	0
539659	539658	14255U	PARTICIPANT	\N	PRESENT	0
539660	539658	12016W	PARTICIPANT	\N	PRESENT	0
539661	539658	14001X	PARTICIPANT	\N	PRESENT	0
539662	539658	11012A	PARTICIPANT	\N	PRESENT	0
539663	539658	19619A	PARTICIPANT	\N	PRESENT	0
539703	539702	19643A	PARTICIPANT	\N	PRESENT	1
539704	539702	19735D	PARTICIPANT	\N	PRESENT	1
539705	539702	14147R	PARTICIPANT	\N	PRESENT	1
539706	539702	20142Y	PARTICIPANT	\N	PRESENT	1
539707	539702	19721W	PARTICIPANT	\N	PRESENT	1
539708	539702	19593H	PARTICIPANT	\N	PRESENT	0
539709	539702	19611R	PARTICIPANT	\N	PRESENT	0
539712	539710	19954N	PARTICIPANT	\N	PRESENT	1
539713	539710	19643A	PARTICIPANT	\N	PRESENT	1
539714	539710	19721W	PARTICIPANT	\N	PRESENT	1
539715	539710	19735D	PARTICIPANT	\N	PRESENT	1
539716	539710	19611R	PARTICIPANT	\N	PRESENT	0
539717	539710	20142Y	PARTICIPANT	\N	PRESENT	1
539718	539710	19593H	PARTICIPANT	\N	PRESENT	0
539719	539710	14147R	PARTICIPANT	\N	PRESENT	1
539741	539738	14109K	PARTICIPANT	\N	PRESENT	1
539742	539738	07033P	PARTICIPANT	\N	PRESENT	1
539743	539739	07033P	PARTICIPANT	\N	PRESENT	0
539744	539739	14109K	PARTICIPANT	\N	PRESENT	0
539771	539740	14109K	PARTICIPANT	\N	PRESENT	1
541223	539069	20044X	PARTICIPANT	\N	PRESENT	0
541224	539069	14083S	PARTICIPANT	\N	PRESENT	0
541225	539069	19741B	PARTICIPANT	\N	PRESENT	0
541226	539069	20126Y	PARTICIPANT	\N	PRESENT	0
541227	539069	19762G	PARTICIPANT	\N	PRESENT	0
541228	539069	01057W	PARTICIPANT	\N	PRESENT	0
541229	539069	20022R	PARTICIPANT	\N	PRESENT	0
541328	538123	14189C	PARTICIPANT	\N	PRESENT	1
541230	539069	19711U	PARTICIPANT	\N	PRESENT	0
541330	541329	14193X	PARTICIPANT	\N	PRESENT	0
541331	541329	11054L	PARTICIPANT	\N	PRESENT	0
541332	541329	01058X	PARTICIPANT	\N	PRESENT	0
541336	539069	20050V	PARTICIPANT	\N	PRESENT	1
541337	539069	19671E	PARTICIPANT	\N	PRESENT	1
541338	539069	99004R	PARTICIPANT	\N	PRESENT	1
541339	539069	19531S	PARTICIPANT	\N	PRESENT	1
541340	539069	14121F	PARTICIPANT	\N	PRESENT	1
541341	539069	11110B	PARTICIPANT	\N	PRESENT	1
541483	539550	14195A	PARTICIPANT	\N	PRESENT	0
540922	539069	19335Q	PARTICIPANT	\N	PRESENT	0
541484	539550	11067R	PARTICIPANT	\N	PRESENT	0
541485	539550	14357A	PARTICIPANT	\N	PRESENT	0
541486	539550	20054A	PARTICIPANT	\N	PRESENT	0
541487	539550	20126Y	PARTICIPANT	\N	PRESENT	0
541488	539550	19421M	PARTICIPANT	\N	PRESENT	0
541489	539550	14193X	PARTICIPANT	\N	PRESENT	0
541490	539550	20060X	PARTICIPANT	\N	PRESENT	0
541491	539550	14151M	PARTICIPANT	\N	PRESENT	0
541492	539550	20100N	PARTICIPANT	\N	PRESENT	0
541493	539550	20134Y	PARTICIPANT	\N	PRESENT	0
541494	539686	19675J	PARTICIPANT	\N	PRESENT	1
541495	539686	20074E	PARTICIPANT	\N	EXCUSE	0
541496	539550	14211G	PARTICIPANT	\N	PRESENT	0
541497	539550	04008A	PARTICIPANT	\N	PRESENT	0
541498	539550	01058X	PARTICIPANT	\N	PRESENT	0
541499	539550	17637T	PARTICIPANT	\N	PRESENT	0
541500	539550	20090E	PARTICIPANT	\N	PRESENT	0
541501	539550	99004R	PARTICIPANT	\N	PRESENT	0
541502	539550	20076G	PARTICIPANT	\N	PRESENT	0
541503	539550	07029T	PARTICIPANT	\N	PRESENT	0
541504	539550	20044X	PARTICIPANT	\N	PRESENT	0
541505	539550	01028R	PARTICIPANT	\N	PRESENT	0
541506	539550	19723Y	PARTICIPANT	\N	PRESENT	0
541507	539550	14225N	PARTICIPANT	\N	PRESENT	0
541508	539550	19443T	PARTICIPANT	\N	PRESENT	0
541509	539550	08045X	PARTICIPANT	\N	PRESENT	0
541510	539550	11040E	PARTICIPANT	\N	PRESENT	0
541511	539550	19758L	PARTICIPANT	\N	PRESENT	0
541512	539550	19709B	PARTICIPANT	\N	PRESENT	0
541513	539550	19573D	PARTICIPANT	\N	PRESENT	0
541515	539550	19467C	PARTICIPANT	\N	PRESENT	0
541516	539550	14031R	PARTICIPANT	\N	PRESENT	0
541517	539550	20038A	PARTICIPANT	\N	PRESENT	0
541518	539550	04059M	PARTICIPANT	\N	PRESENT	0
541519	539550	20140W	PARTICIPANT	\N	PRESENT	0
541520	539550	14021P	PARTICIPANT	\N	PRESENT	0
541521	539550	19683J	PARTICIPANT	\N	PRESENT	0
541522	539550	19729F	PARTICIPANT	\N	PRESENT	0
541523	539550	04085P	PARTICIPANT	\N	PRESENT	0
541524	539550	19687N	PARTICIPANT	\N	PRESENT	0
541525	539550	14123H	PARTICIPANT	\N	PRESENT	0
541526	539550	20028X	PARTICIPANT	\N	PRESENT	0
541527	539550	20096L	PARTICIPANT	\N	PRESENT	0
541528	539550	19399H	PARTICIPANT	\N	PRESENT	0
541529	539550	14253S	PARTICIPANT	\N	PRESENT	0
541530	539550	19647E	PARTICIPANT	\N	PRESENT	0
541531	539550	17965H	PARTICIPANT	\N	PRESENT	0
541532	539550	01057W	PARTICIPANT	\N	PRESENT	0
541533	539550	14109K	PARTICIPANT	\N	PRESENT	0
541534	539550	19820Y	PARTICIPANT	\N	PRESENT	0
541535	539550	20026V	PARTICIPANT	\N	PRESENT	0
541536	539550	12041X	PARTICIPANT	\N	PRESENT	0
541537	539550	14001X	PARTICIPANT	\N	PRESENT	0
541538	539550	08012N	PARTICIPANT	\N	PRESENT	0
541539	539550	08017T	PARTICIPANT	\N	PRESENT	0
541540	539550	19643A	PARTICIPANT	\N	PRESENT	0
541541	539550	11048N	PARTICIPANT	\N	PRESENT	0
541542	539550	19383Y	PARTICIPANT	\N	PRESENT	0
541543	539550	97011G	PARTICIPANT	\N	PRESENT	0
541544	539550	07033P	PARTICIPANT	\N	PRESENT	0
541545	539550	19503N	PARTICIPANT	\N	PRESENT	0
541546	539550	14059S	PARTICIPANT	\N	PRESENT	0
541547	539550	20062A	PARTICIPANT	\N	PRESENT	0
541548	539550	19705W	PARTICIPANT	\N	PRESENT	0
541549	539550	11056N	PARTICIPANT	\N	PRESENT	0
541550	539550	20112S	PARTICIPANT	\N	PRESENT	0
541551	539550	11031D	PARTICIPANT	\N	PRESENT	0
541552	539550	11077T	PARTICIPANT	\N	PRESENT	0
541553	539550	19715Y	PARTICIPANT	\N	PRESENT	0
541554	539550	19527W	PARTICIPANT	\N	PRESENT	0
541555	539550	10015M	PARTICIPANT	\N	PRESENT	0
541556	539550	19725B	PARTICIPANT	\N	PRESENT	0
541557	539550	11065P	PARTICIPANT	\N	PRESENT	0
541558	539550	20036X	PARTICIPANT	\N	PRESENT	0
541559	539550	19782L	PARTICIPANT	\N	PRESENT	0
541560	539550	20174H	PARTICIPANT	\N	PRESENT	0
541561	539550	20022R	PARTICIPANT	\N	PRESENT	0
541562	539550	20172F	PARTICIPANT	\N	PRESENT	0
541563	539550	20042V	PARTICIPANT	\N	PRESENT	0
541564	539550	19447X	PARTICIPANT	\N	PRESENT	0
541565	539550	14073Q	PARTICIPANT	\N	PRESENT	0
541566	539550	04070G	PARTICIPANT	\N	PRESENT	0
541567	539550	19515S	PARTICIPANT	\N	PRESENT	0
541568	539550	11053K	PARTICIPANT	\N	PRESENT	0
541569	539550	19543W	PARTICIPANT	\N	PRESENT	0
541570	539550	04057K	PARTICIPANT	\N	PRESENT	0
541571	539550	14251Q	PARTICIPANT	\N	PRESENT	0
541572	539550	19671E	PARTICIPANT	\N	PRESENT	0
541573	539550	20050V	PARTICIPANT	\N	PRESENT	0
541574	539550	04033B	PARTICIPANT	\N	PRESENT	0
541575	539550	14249W	PARTICIPANT	\N	PRESENT	0
541576	539550	19798U	PARTICIPANT	\N	PRESENT	0
513364	502355	14111D	PARTICIPANT	\N	PRESENT	0
513365	502355	14053L	PARTICIPANT	\N	PRESENT	0
513366	502355	19749K	PARTICIPANT	\N	PRESENT	0
513367	502355	19629C	PARTICIPANT	\N	PRESENT	0
513368	502355	11056N	PARTICIPANT	\N	PRESENT	0
513369	502355	20080C	PARTICIPANT	\N	PRESENT	0
513370	502355	19649G	PARTICIPANT	\N	PRESENT	0
513371	502355	01028R	PARTICIPANT	\N	PRESENT	0
513372	502355	11033F	PARTICIPANT	\N	PRESENT	0
513373	502355	11012A	PARTICIPANT	\N	PRESENT	0
513374	502355	19585H	PARTICIPANT	\N	PRESENT	0
513375	502355	20034V	PARTICIPANT	\N	PRESENT	0
513376	502355	17737W	PARTICIPANT	\N	PRESENT	0
513377	502355	08034U	PARTICIPANT	\N	PRESENT	0
513378	502355	11097X	PARTICIPANT	\N	PRESENT	0
513379	502355	11072N	PARTICIPANT	\N	PRESENT	0
513380	502355	19581D	PARTICIPANT	\N	PRESENT	0
513381	502355	20062A	PARTICIPANT	\N	PRESENT	0
513382	502355	14215L	PARTICIPANT	\N	PRESENT	0
513383	502355	19747H	PARTICIPANT	\N	PRESENT	0
513384	502355	20134Y	PARTICIPANT	\N	PRESENT	0
513385	502355	20122U	PARTICIPANT	\N	PRESENT	0
513386	502355	11090Q	PARTICIPANT	\N	PRESENT	0
513387	502355	19301E	PARTICIPANT	\N	PRESENT	0
513388	502355	14069U	PARTICIPANT	\N	PRESENT	0
513389	502355	20124W	PARTICIPANT	\N	PRESENT	0
513390	502355	20152B	PARTICIPANT	\N	PRESENT	0
513391	502355	20070A	PARTICIPANT	\N	PRESENT	0
513392	502355	19503N	PARTICIPANT	\N	PRESENT	0
513393	502355	20054A	PARTICIPANT	\N	PRESENT	0
513394	502355	20126Y	PARTICIPANT	\N	PRESENT	0
513395	502355	20058E	PARTICIPANT	\N	PRESENT	0
513396	502355	20098N	PARTICIPANT	\N	PRESENT	0
513397	502355	19531S	PARTICIPANT	\N	PRESENT	0
513398	502355	19693L	PARTICIPANT	\N	PRESENT	0
513399	502355	11040E	PARTICIPANT	\N	PRESENT	0
513400	502355	01057W	PARTICIPANT	\N	PRESENT	0
513401	502355	19713W	PARTICIPANT	\N	PRESENT	0
513402	502355	11048N	PARTICIPANT	\N	PRESENT	0
513362	502355	11070L	PARTICIPANT	\N	PRESENT	0
513363	502355	08010L	PARTICIPANT	\N	PRESENT	0
513403	502355	19479G	PARTICIPANT	\N	PRESENT	0
513404	502355	14089Y	PARTICIPANT	\N	PRESENT	0
513405	502355	11077T	PARTICIPANT	\N	PRESENT	0
513406	502355	07029T	PARTICIPANT	\N	PRESENT	0
513407	502355	19591F	PARTICIPANT	\N	PRESENT	0
513501	513500	11048N	PARTICIPANT	\N	PRESENT	0
514265	502367	19711U	PARTICIPANT	\N	PRESENT	0
514266	502367	11070L	PARTICIPANT	\N	PRESENT	0
514267	502367	11097X	PARTICIPANT	\N	PRESENT	0
514268	502367	11083R	PARTICIPANT	\N	PRESENT	0
514269	502367	19689Q	PARTICIPANT	\N	PRESENT	0
514270	502367	20104S	PARTICIPANT	\N	PRESENT	0
514271	502367	20030R	PARTICIPANT	\N	PRESENT	0
514272	502367	11054L	PARTICIPANT	\N	PRESENT	0
514273	502367	04059M	PARTICIPANT	\N	PRESENT	0
514274	502367	19826F	PARTICIPANT	\N	PRESENT	0
514275	502367	14257W	PARTICIPANT	\N	PRESENT	0
514276	502367	19413M	PARTICIPANT	\N	PRESENT	0
514277	502367	19585H	PARTICIPANT	\N	PRESENT	0
514278	502367	19954N	PARTICIPANT	\N	PRESENT	0
514279	502367	20044X	PARTICIPANT	\N	PRESENT	0
514280	502367	98022P	PARTICIPANT	\N	PRESENT	0
514281	502367	95063L	PARTICIPANT	\N	PRESENT	0
514282	502367	19531S	PARTICIPANT	\N	PRESENT	0
514283	502367	20056C	PARTICIPANT	\N	PRESENT	0
514284	502367	14219Q	PARTICIPANT	\N	PRESENT	0
514285	502367	19713W	PARTICIPANT	\N	PRESENT	0
514286	502367	19399H	PARTICIPANT	\N	PRESENT	0
514287	502367	19533U	PARTICIPANT	\N	PRESENT	0
514288	502367	20096L	PARTICIPANT	\N	PRESENT	0
514289	502367	19467C	PARTICIPANT	\N	PRESENT	0
514290	502367	19387D	PARTICIPANT	\N	PRESENT	0
514293	502367	20082E	PARTICIPANT	\N	PRESENT	0
514294	502367	20068G	PARTICIPANT	\N	PRESENT	0
514295	502367	11026G	PARTICIPANT	\N	PRESENT	0
514296	502367	19569H	PARTICIPANT	\N	PRESENT	0
514297	502367	20066E	PARTICIPANT	\N	PRESENT	0
514299	502367	14169X	PARTICIPANT	\N	PRESENT	0
514302	502367	20108W	PARTICIPANT	\N	PRESENT	0
514303	502367	04085P	PARTICIPANT	\N	PRESENT	0
514304	502367	20088L	PARTICIPANT	\N	PRESENT	0
514305	502367	08009T	PARTICIPANT	\N	PRESENT	0
514306	502367	01024M	PARTICIPANT	\N	PRESENT	0
514307	502367	14042U	PARTICIPANT	\N	PRESENT	0
514308	502367	11109J	PARTICIPANT	\N	PRESENT	0
514309	502367	11064N	PARTICIPANT	\N	PRESENT	0
514310	502367	19575F	PARTICIPANT	\N	PRESENT	0
514311	502367	20018V	PARTICIPANT	\N	PRESENT	0
514313	502367	19703U	PARTICIPANT	\N	PRESENT	0
514315	502367	14187A	PARTICIPANT	\N	PRESENT	0
514316	502367	19577H	PARTICIPANT	\N	PRESENT	0
514317	502367	11027H	PARTICIPANT	\N	PRESENT	0
514318	502367	20020P	PARTICIPANT	\N	PRESENT	0
514319	502367	19723Y	PARTICIPANT	\N	PRESENT	0
514321	502367	19631V	PARTICIPANT	\N	PRESENT	0
514325	502367	04086Q	PARTICIPANT	\N	PRESENT	0
514330	502367	01058X	PARTICIPANT	\N	PRESENT	0
514335	502367	20078J	PARTICIPANT	\N	PRESENT	0
514336	502367	14038Y	PARTICIPANT	\N	PRESENT	0
514337	502367	20118Y	PARTICIPANT	\N	PRESENT	0
514338	502367	20152B	PARTICIPANT	\N	PRESENT	0
514339	502367	19762G	PARTICIPANT	\N	PRESENT	0
514340	502367	20076G	PARTICIPANT	\N	PRESENT	0
514341	502367	19747H	PARTICIPANT	\N	PRESENT	0
514342	502367	20024T	PARTICIPANT	\N	PRESENT	0
514343	502367	20062A	PARTICIPANT	\N	PRESENT	0
514344	502367	14133K	PARTICIPANT	\N	PRESENT	0
514345	502367	20032T	PARTICIPANT	\N	PRESENT	0
514346	502367	20124W	PARTICIPANT	\N	PRESENT	0
514347	502367	14033T	PARTICIPANT	\N	PRESENT	0
514348	502367	19768N	PARTICIPANT	\N	PRESENT	0
514349	502367	14215L	PARTICIPANT	\N	PRESENT	0
514350	502367	14026U	PARTICIPANT	\N	PRESENT	0
514351	502367	20086J	PARTICIPANT	\N	PRESENT	0
514352	502367	19441R	PARTICIPANT	\N	PRESENT	0
514353	502367	19657G	PARTICIPANT	\N	PRESENT	0
514354	502367	14193X	PARTICIPANT	\N	PRESENT	0
514355	502367	20048C	PARTICIPANT	\N	PRESENT	0
514356	502367	04042C	PARTICIPANT	\N	PRESENT	0
514357	502367	14357A	PARTICIPANT	\N	PRESENT	0
514358	502367	20054A	PARTICIPANT	\N	PRESENT	0
514366	502367	14213J	PARTICIPANT	\N	PRESENT	0
514360	502367	08012N	PARTICIPANT	\N	PRESENT	0
514361	502367	14231L	PARTICIPANT	\N	PRESENT	0
514362	502367	19741B	PARTICIPANT	\N	PRESENT	0
514363	502367	19383Y	PARTICIPANT	\N	PRESENT	0
514367	502367	19549D	PARTICIPANT	\N	PRESENT	0
514365	502367	20026V	PARTICIPANT	\N	PRESENT	0
514368	502367	14111D	PARTICIPANT	\N	PRESENT	0
514369	502367	12016W	PARTICIPANT	\N	PRESENT	0
514581	502368	01043Q	PARTICIPANT	\N	PRESENT	0
514590	502368	19758L	PARTICIPANT	\N	PRESENT	0
514591	502368	20046A	PARTICIPANT	\N	PRESENT	0
514592	502368	20102Q	PARTICIPANT	\N	PRESENT	0
514593	502368	19637C	PARTICIPANT	\N	PRESENT	0
514594	502368	19599P	PARTICIPANT	\N	PRESENT	0
514595	502368	11066Q	PARTICIPANT	\N	PRESENT	0
514596	502368	20028X	PARTICIPANT	\N	PRESENT	0
514597	502368	20092G	PARTICIPANT	\N	PRESENT	0
514598	502368	20100N	PARTICIPANT	\N	PRESENT	0
514599	502368	14121F	PARTICIPANT	\N	PRESENT	0
514600	502368	11109J	PARTICIPANT	\N	PRESENT	0
514601	502368	20082E	PARTICIPANT	\N	PRESENT	0
514602	502368	20030R	PARTICIPANT	\N	PRESENT	0
514603	502368	11064N	PARTICIPANT	\N	PRESENT	0
514604	502368	14111D	PARTICIPANT	\N	PRESENT	0
514605	502368	14221J	PARTICIPANT	\N	PRESENT	0
514606	502368	19563B	PARTICIPANT	\N	PRESENT	0
514607	502368	11012A	PARTICIPANT	\N	PRESENT	0
514608	502368	14107H	PARTICIPANT	\N	PRESENT	0
514609	502368	08061X	PARTICIPANT	\N	PRESENT	0
514610	502368	20066E	PARTICIPANT	\N	PRESENT	0
514611	502368	14083S	PARTICIPANT	\N	PRESENT	0
514612	502368	20144B	PARTICIPANT	\N	PRESENT	0
514613	502368	19619A	PARTICIPANT	\N	PRESENT	0
514614	502368	20106U	PARTICIPANT	\N	PRESENT	0
514615	502368	19826F	PARTICIPANT	\N	PRESENT	0
514616	502368	19533U	PARTICIPANT	\N	PRESENT	0
514617	502368	14215L	PARTICIPANT	\N	PRESENT	0
514618	502368	14059S	PARTICIPANT	\N	PRESENT	0
532994	531147	11110B	PARTICIPANT	\N	PRESENT	1
532995	531147	99004R	PARTICIPANT	\N	PRESENT	1
532996	531147	12016W	PARTICIPANT	\N	PRESENT	1
532997	531147	08073C	PARTICIPANT	\N	PRESENT	1
532998	531147	19479G	PARTICIPANT	\N	PRESENT	1
533002	531147	14253S	PARTICIPANT	\N	PRESENT	0
533030	531297	20042V	PARTICIPANT	\N	PRESENT	1
533031	531297	14105F	PARTICIPANT	\N	PRESENT	0
533032	531297	14255U	PARTICIPANT	\N	PRESENT	1
533033	531297	04042C	PRESIDENT	0	PRESENT	0
533034	531297	19721W	PARTICIPANT	\N	PRESENT	1
533035	531297	14267Y	PARTICIPANT	\N	PRESENT	0
533036	531297	11027H	PARTICIPANT	\N	PRESENT	0
533037	531297	14249W	PARTICIPANT	\N	PRESENT	1
533038	531297	97011G	PARTICIPANT	\N	PRESENT	0
533039	531297	04035D	PARTICIPANT	\N	PRESENT	1
533040	531297	11083R	PARTICIPANT	\N	PRESENT	0
533041	531297	19347U	PARTICIPANT	\N	PRESENT	0
533042	531297	08056B	PARTICIPANT	\N	PRESENT	1
533043	531297	14211G	PARTICIPANT	\N	PRESENT	0
533044	531297	19565D	PARTICIPANT	\N	PRESENT	0
533045	531297	98022P	PARTICIPANT	\N	PRESENT	0
533046	531297	20072C	PARTICIPANT	\N	PRESENT	1
533047	531297	20128B	PARTICIPANT	\N	PRESENT	1
533048	531297	08069G	PARTICIPANT	\N	PRESENT	0
533049	531297	14097Y	PARTICIPANT	\N	PRESENT	1
533050	531297	16685X	PARTICIPANT	\N	PRESENT	0
533051	531297	14059S	PARTICIPANT	\N	PRESENT	0
533052	531297	08047A	PARTICIPANT	\N	PRESENT	1
533053	531297	11054L	PARTICIPANT	\N	PRESENT	0
533054	531297	19421M	PARTICIPANT	\N	PRESENT	0
533055	531297	01058X	PARTICIPANT	\N	PRESENT	0
533056	531297	19669L	PARTICIPANT	\N	PRESENT	1
533057	531297	01062T	PARTICIPANT	\N	PRESENT	1
533058	531297	11066Q	PARTICIPANT	\N	PRESENT	0
533059	531297	04034C	PARTICIPANT	\N	PRESENT	0
533302	531195	14249W	PARTICIPANT	\N	PRESENT	0
533303	531195	08056B	PARTICIPANT	\N	PRESENT	0
536416	534354	14237S	PARTICIPANT	\N	PRESENT	0
536417	534354	14331P	PRESIDENT	1	PRESENT	0
536418	534354	11048N	PARTICIPANT	\N	PRESENT	0
536419	534354	19701S	PARTICIPANT	\N	PRESENT	0
536420	534354	04034C	PARTICIPANT	\N	PRESENT	0
536421	534354	19441R	PARTICIPANT	\N	PRESENT	0
536422	534354	14001X	PARTICIPANT	\N	PRESENT	0
536423	534354	11083R	PARTICIPANT	\N	PRESENT	0
536424	534354	20126Y	PARTICIPANT	\N	PRESENT	0
536425	534354	20104S	PARTICIPANT	\N	PRESENT	0
536456	534194	14237S	PARTICIPANT	\N	PRESENT	0
536427	534354	14327T	PARTICIPANT	\N	EXCUSE	0
536428	534354	07029T	PARTICIPANT	\N	EXCUSE	0
536429	534354	19545Y	PARTICIPANT	\N	EXCUSE	0
536457	534194	04070G	PARTICIPANT	\N	PRESENT	1
536431	534354	14225N	PRESIDENT	0	PRESENT	0
536458	534194	19701S	PARTICIPANT	\N	PRESENT	0
536459	534194	04034C	PARTICIPANT	\N	PRESENT	0
536460	534194	19441R	PARTICIPANT	\N	PRESENT	0
536461	534194	11083R	PARTICIPANT	\N	PRESENT	0
536462	534194	14001X	PARTICIPANT	\N	PRESENT	0
536463	534194	19251M	PARTICIPANT	\N	PRESENT	1
536464	534194	20104S	PARTICIPANT	\N	PRESENT	0
536475	534194	14331P	PRESIDENT	0	PRESENT	0
536476	534194	19563B	PARTICIPANT	\N	EXCUSE	0
536487	534194	11048N	PARTICIPANT	\N	PRESENT	0
536488	534194	11074Q	PARTICIPANT	\N	PRESENT	1
536489	534194	14225N	PARTICIPANT	\N	PRESENT	0
536490	534194	04086Q	PARTICIPANT	\N	PRESENT	0
536491	534194	11040E	PARTICIPANT	\N	PRESENT	1
536492	534194	14083S	PARTICIPANT	\N	PRESENT	1
536493	534194	99004R	PARTICIPANT	\N	PRESENT	1
536494	534194	20022R	PARTICIPANT	\N	PRESENT	1
536495	534194	20126Y	PARTICIPANT	\N	PRESENT	0
536603	536602	19669L	PARTICIPANT	\N	PRESENT	0
536604	536602	11026G	PARTICIPANT	\N	PRESENT	0
536605	536602	19413M	PARTICIPANT	\N	PRESENT	0
536606	536602	19531S	PARTICIPANT	\N	PRESENT	0
536616	536615	19679N	PARTICIPANT	\N	PRESENT	0
536617	536615	18193Q	PARTICIPANT	\N	PRESENT	0
536618	536615	20018V	PARTICIPANT	\N	PRESENT	0
536619	536615	20130U	PARTICIPANT	\N	PRESENT	0
536620	536615	14071N	PARTICIPANT	\N	PRESENT	0
536622	536621	19679N	PARTICIPANT	\N	PRESENT	0
536623	536621	18193Q	PARTICIPANT	\N	PRESENT	0
536624	536621	20130U	PARTICIPANT	\N	PRESENT	0
536654	536653	19673G	PARTICIPANT	\N	PRESENT	0
536655	536653	19749K	PARTICIPANT	\N	PRESENT	0
536672	491410	14213J	PARTICIPANT	\N	PRESENT	0
536673	491410	20084G	PARTICIPANT	\N	PRESENT	0
536674	491410	14021P	PARTICIPANT	\N	PRESENT	0
536675	491410	19669L	PARTICIPANT	\N	PRESENT	0
536676	491410	14055N	PARTICIPANT	\N	PRESENT	0
536677	491410	20086J	PARTICIPANT	\N	PRESENT	0
536678	491410	11077T	PARTICIPANT	\N	PRESENT	0
536679	491410	19703U	PARTICIPANT	\N	PRESENT	0
536680	491410	19619A	PARTICIPANT	\N	PRESENT	0
536681	491410	14189C	PARTICIPANT	\N	PRESENT	0
536682	491410	14030Q	PARTICIPANT	\N	PRESENT	0
536683	491410	14073Q	PARTICIPANT	\N	PRESENT	0
536684	491410	19820Y	PARTICIPANT	\N	PRESENT	0
536685	491410	08017T	PARTICIPANT	\N	PRESENT	0
536686	491410	19659J	PARTICIPANT	\N	PRESENT	0
536687	491410	14217N	PARTICIPANT	\N	PRESENT	0
536688	491410	19735D	PARTICIPANT	\N	PRESENT	0
536689	491410	08056B	PARTICIPANT	\N	PRESENT	0
536690	491410	19629C	PARTICIPANT	\N	PRESENT	0
536691	491410	14211G	PARTICIPANT	\N	PRESENT	0
536692	491410	19693L	PARTICIPANT	\N	PRESENT	0
536693	491410	14083S	PARTICIPANT	\N	PRESENT	0
536694	491410	14133K	PARTICIPANT	\N	PRESENT	0
536695	491410	95063L	PARTICIPANT	\N	PRESENT	0
536696	491410	11066Q	PARTICIPANT	\N	PRESENT	0
536697	491410	14069U	PARTICIPANT	\N	PRESENT	0
536698	491410	20058E	PARTICIPANT	\N	PRESENT	0
536699	491410	20034V	PARTICIPANT	\N	PRESENT	0
536700	491410	19383Y	PARTICIPANT	\N	PRESENT	0
536701	491410	20018V	PARTICIPANT	\N	PRESENT	0
536702	491410	19701S	PARTICIPANT	\N	PRESENT	0
536703	491410	14123H	PARTICIPANT	\N	PRESENT	0
536704	491410	14173T	PARTICIPANT	\N	PRESENT	0
536705	491410	20044X	PARTICIPANT	\N	PRESENT	0
536706	491410	19631V	PARTICIPANT	\N	PRESENT	0
536707	491410	04059M	PARTICIPANT	\N	PRESENT	0
536708	491410	14053L	PARTICIPANT	\N	PRESENT	0
536709	491410	19413M	PARTICIPANT	\N	PRESENT	0
536710	491410	98022P	PARTICIPANT	\N	PRESENT	0
536711	491410	11110B	PARTICIPANT	\N	PRESENT	0
536712	491410	14267Y	PARTICIPANT	\N	PRESENT	0
536713	491410	19689Q	PARTICIPANT	\N	PRESENT	0
536714	491410	19349W	PARTICIPANT	\N	PRESENT	0
536715	491410	14026U	PARTICIPANT	\N	PRESENT	0
536716	491410	14121F	PARTICIPANT	\N	PRESENT	0
536717	491410	20036X	PARTICIPANT	\N	PRESENT	0
536718	491410	19679N	PARTICIPANT	\N	PRESENT	0
536719	491410	20136B	PARTICIPANT	\N	PRESENT	0
536720	491410	20026V	PARTICIPANT	\N	PRESENT	0
536721	491410	20116W	PARTICIPANT	\N	PRESENT	0
536722	491410	17737W	PARTICIPANT	\N	PRESENT	0
536723	491410	19954N	PARTICIPANT	\N	PRESENT	0
536724	491410	10006L	PARTICIPANT	\N	PRESENT	0
536725	491410	19447X	PARTICIPANT	\N	PRESENT	0
536726	491410	11097X	PARTICIPANT	\N	PRESENT	0
536727	491410	19573D	PARTICIPANT	\N	PRESENT	0
536728	491410	19782L	PARTICIPANT	\N	PRESENT	0
536729	491410	19683J	PARTICIPANT	\N	PRESENT	0
536730	491410	19521Q	PARTICIPANT	\N	PRESENT	0
536731	491410	11067R	PARTICIPANT	\N	PRESENT	0
536732	491410	20022R	PARTICIPANT	\N	PRESENT	0
536733	491410	20056C	PARTICIPANT	\N	PRESENT	0
536734	491410	20064C	PARTICIPANT	\N	PRESENT	0
536735	491410	19565D	PARTICIPANT	\N	PRESENT	0
536736	491410	20082E	PARTICIPANT	\N	PRESENT	0
536737	491410	19758L	PARTICIPANT	\N	PRESENT	0
536738	491410	19599P	PARTICIPANT	\N	PRESENT	0
536739	491410	19467C	PARTICIPANT	\N	PRESENT	0
536740	491410	20134Y	PARTICIPANT	\N	PRESENT	0
536741	491410	20130U	PARTICIPANT	\N	PRESENT	0
536742	491410	14147R	PARTICIPANT	\N	PRESENT	0
536743	491410	20142Y	PARTICIPANT	\N	PRESENT	0
536744	491410	11080N	PARTICIPANT	\N	PRESENT	0
521208	521207	11083R	PARTICIPANT	\N	PRESENT	0
521209	521207	14073Q	PARTICIPANT	\N	PRESENT	0
521210	521207	14331P	PARTICIPANT	\N	PRESENT	1
521215	521214	19515S	PARTICIPANT	\N	PRESENT	0
521216	521214	19575F	PARTICIPANT	\N	PRESENT	0
521217	521214	14105F	PARTICIPANT	\N	PRESENT	0
521218	521214	14083S	PARTICIPANT	\N	PRESENT	0
521219	521214	19467C	PARTICIPANT	\N	PRESENT	0
521220	521214	14041T	PARTICIPANT	\N	PRESENT	0
521221	521214	19251M	PARTICIPANT	\N	PRESENT	0
521222	521214	20040T	PARTICIPANT	\N	PRESENT	0
521223	521214	19695N	PARTICIPANT	\N	PRESENT	0
521224	521214	14026U	PARTICIPANT	\N	PRESENT	0
521225	521214	20126Y	PARTICIPANT	\N	PRESENT	0
521226	521214	14031R	PARTICIPANT	\N	PRESENT	0
521227	521214	19671E	PARTICIPANT	\N	PRESENT	0
521228	521214	19369B	PARTICIPANT	\N	PRESENT	0
521229	521214	20082E	PARTICIPANT	\N	PRESENT	0
521230	521214	20092G	PARTICIPANT	\N	PRESENT	0
521231	521214	19760E	PARTICIPANT	\N	PRESENT	0
521238	521214	20060X	PARTICIPANT	\N	PRESENT	0
521275	521274	14041T	PARTICIPANT	\N	PRESENT	0
521276	521274	19369B	PARTICIPANT	\N	PRESENT	0
521277	521274	20040T	PARTICIPANT	\N	PRESENT	0
521278	521274	19575F	PARTICIPANT	\N	PRESENT	0
521279	521274	19515S	PARTICIPANT	\N	PRESENT	0
521280	521274	14083S	PARTICIPANT	\N	PRESENT	0
521281	521274	19467C	PARTICIPANT	\N	PRESENT	0
521282	521274	14031R	PARTICIPANT	\N	PRESENT	0
521283	521274	14026U	PARTICIPANT	\N	PRESENT	0
521284	521274	20060X	PARTICIPANT	\N	PRESENT	0
521285	521274	20082E	PARTICIPANT	\N	PRESENT	0
521286	521274	19760E	PARTICIPANT	\N	PRESENT	0
521287	521274	19251M	PARTICIPANT	\N	PRESENT	0
521288	521274	19695N	PARTICIPANT	\N	PRESENT	0
521289	521274	20092G	PARTICIPANT	\N	PRESENT	0
521290	521274	14105F	PARTICIPANT	\N	PRESENT	0
526767	526727	20132W	PARTICIPANT	\N	PRESENT	0
526768	526727	20092G	PARTICIPANT	\N	PRESENT	0
526769	526727	04092N	PRESIDENT	0	PRESENT	0
526770	526727	08034U	PARTICIPANT	\N	PRESENT	0
526771	526727	19569H	PARTICIPANT	\N	PRESENT	0
526772	526727	11026G	PARTICIPANT	\N	PRESENT	0
526773	526727	19691J	PARTICIPANT	\N	PRESENT	0
526774	526727	04045F	PARTICIPANT	\N	PRESENT	0
526775	526727	19447X	PARTICIPANT	\N	PRESENT	0
526776	526727	18083K	PARTICIPANT	\N	PRESENT	0
526777	526727	14042U	PARTICIPANT	\N	PRESENT	0
526778	526727	14195A	PARTICIPANT	\N	PRESENT	0
526779	526727	14213J	PARTICIPANT	\N	PRESENT	0
526780	526727	14215L	PARTICIPANT	\N	PRESENT	0
526781	526727	99004R	PARTICIPANT	\N	PRESENT	0
526782	526727	19683J	PARTICIPANT	\N	PRESENT	0
526783	526727	10006L	PARTICIPANT	\N	PRESENT	0
526784	526727	11072N	PARTICIPANT	\N	PRESENT	0
526787	526727	11067R	PARTICIPANT	\N	PRESENT	0
526788	526727	19553Y	PARTICIPANT	\N	PRESENT	0
526789	526727	11031D	PARTICIPANT	\N	PRESENT	0
526790	526727	20066E	PARTICIPANT	\N	PRESENT	0
526791	526727	19575F	PARTICIPANT	\N	PRESENT	0
526792	526727	19335Q	PARTICIPANT	\N	PRESENT	0
526793	526727	14041T	PARTICIPANT	\N	EXCUSE	0
526794	526727	11066Q	PARTICIPANT	\N	EXCUSE	0
526818	526538	08073C	PARTICIPANT	\N	PRESENT	0
526819	526538	20180F	PARTICIPANT	\N	PRESENT	0
526820	526538	92040Q	PARTICIPANT	\N	PRESENT	0
526821	526538	20034V	PARTICIPANT	\N	PRESENT	0
526822	526538	19447X	PARTICIPANT	\N	PRESENT	0
526823	526538	19593H	PARTICIPANT	\N	PRESENT	0
526824	526538	19826F	PARTICIPANT	\N	PRESENT	0
526825	526538	20144B	PARTICIPANT	\N	PRESENT	0
526826	526538	14195A	PARTICIPANT	\N	PRESENT	0
526827	526538	20132W	PARTICIPANT	\N	PRESENT	0
526828	526538	19683J	PARTICIPANT	\N	PRESENT	0
526829	526538	19565D	PARTICIPANT	\N	PRESENT	0
526830	526538	99004R	PARTICIPANT	\N	PRESENT	0
526831	526538	20026V	PARTICIPANT	\N	PRESENT	0
526832	526538	19335Q	PARTICIPANT	\N	PRESENT	0
526833	526538	14033T	PARTICIPANT	\N	PRESENT	0
526834	526538	14329V	PARTICIPANT	\N	PRESENT	0
526835	526538	14357A	PARTICIPANT	\N	PRESENT	0
526836	526538	20052X	PARTICIPANT	\N	PRESENT	0
526837	526538	20032T	PARTICIPANT	\N	PRESENT	0
526838	526538	19569H	PARTICIPANT	\N	PRESENT	0
526839	526538	04045F	PARTICIPANT	\N	PRESENT	0
526840	526538	19399H	PARTICIPANT	\N	PRESENT	0
526841	526538	20054A	PARTICIPANT	\N	PRESENT	0
526842	526538	20090E	PARTICIPANT	\N	PRESENT	0
526843	526538	14042U	PARTICIPANT	\N	PRESENT	0
526844	526538	20072C	PARTICIPANT	\N	PRESENT	0
526845	526538	14031R	PARTICIPANT	\N	PRESENT	0
526846	526538	14169X	PARTICIPANT	\N	PRESENT	0
526847	526538	20044X	PARTICIPANT	\N	PRESENT	0
526848	526538	19766L	PARTICIPANT	\N	PRESENT	0
526849	526538	19703U	PARTICIPANT	\N	PRESENT	0
526850	526538	19798U	PARTICIPANT	\N	PRESENT	0
526851	526538	20066E	PARTICIPANT	\N	PRESENT	0
526852	526538	12041X	PARTICIPANT	\N	PRESENT	0
526853	526538	11031D	PARTICIPANT	\N	PRESENT	0
526854	526538	19954N	PARTICIPANT	\N	PRESENT	0
526855	526538	19758L	PARTICIPANT	\N	PRESENT	0
526856	526538	19333N	PARTICIPANT	\N	PRESENT	0
526857	526538	14147R	PARTICIPANT	\N	PRESENT	0
526858	526538	11066Q	PARTICIPANT	\N	PRESENT	0
526859	526538	20130U	PARTICIPANT	\N	PRESENT	0
526860	526538	20092G	PARTICIPANT	\N	PRESENT	0
526861	526538	19649G	PARTICIPANT	\N	PRESENT	0
526862	526538	14207L	PARTICIPANT	\N	PRESENT	0
526863	526538	14267Y	PARTICIPANT	\N	PRESENT	0
526864	526538	19367Y	PARTICIPANT	\N	PRESENT	0
526865	526538	04033B	PARTICIPANT	\N	PRESENT	0
526866	526538	95063L	PARTICIPANT	\N	PRESENT	0
526867	526538	19671E	PARTICIPANT	\N	PRESENT	0
526868	526538	14069U	PARTICIPANT	\N	PRESENT	0
526869	526538	11103C	PARTICIPANT	\N	PRESENT	0
526870	526538	19675J	PARTICIPANT	\N	PRESENT	0
526871	526538	08034U	PARTICIPANT	\N	PRESENT	0
526872	526538	97011G	PARTICIPANT	\N	PRESENT	0
526873	526538	19715Y	PARTICIPANT	\N	PRESENT	0
526874	526538	11045K	PARTICIPANT	\N	PRESENT	0
526875	526538	04092N	PARTICIPANT	\N	PRESENT	0
526876	526538	20152B	PARTICIPANT	\N	PRESENT	0
526877	526538	19723Y	PARTICIPANT	\N	PRESENT	0
526878	526538	10006L	PARTICIPANT	\N	PRESENT	0
526879	526538	10015M	PARTICIPANT	\N	PRESENT	0
526880	526538	19553Y	PARTICIPANT	\N	PRESENT	0
526881	526538	11040E	PARTICIPANT	\N	PRESENT	0
526882	526538	14055N	PARTICIPANT	\N	PRESENT	0
526883	526538	14213J	PARTICIPANT	\N	PRESENT	0
526884	526538	19741B	PARTICIPANT	\N	PRESENT	0
526885	526538	20096L	PARTICIPANT	\N	PRESENT	0
526886	526538	20140W	PARTICIPANT	\N	PRESENT	0
526887	526538	20070A	PARTICIPANT	\N	PRESENT	0
526888	526538	20134Y	PARTICIPANT	\N	PRESENT	0
526889	526538	20174H	PARTICIPANT	\N	PRESENT	0
526890	526538	20138D	PARTICIPANT	\N	PRESENT	0
526891	526538	19651A	PARTICIPANT	\N	PRESENT	0
526892	526538	20062A	PARTICIPANT	\N	PRESENT	0
526893	526538	17965H	PARTICIPANT	\N	PRESENT	0
526894	526538	14030Q	PARTICIPANT	\N	PRESENT	0
526895	526538	14021P	PARTICIPANT	\N	PRESENT	0
526896	526538	20024T	PARTICIPANT	\N	PRESENT	0
526897	526538	20126Y	PARTICIPANT	\N	PRESENT	0
526898	526538	01058X	PARTICIPANT	\N	PRESENT	0
526899	526538	14105F	PARTICIPANT	\N	PRESENT	0
526900	526538	18083K	PARTICIPANT	\N	PRESENT	0
526901	526538	19679N	PARTICIPANT	\N	PRESENT	0
526902	526538	14038Y	PARTICIPANT	\N	PRESENT	0
526903	526538	14205J	PARTICIPANT	\N	PRESENT	0
526904	526538	20058E	PARTICIPANT	\N	PRESENT	0
526905	526538	11072N	PARTICIPANT	\N	PRESENT	0
526906	526538	19415P	PARTICIPANT	\N	PRESENT	0
526907	526538	20142Y	PARTICIPANT	\N	PRESENT	0
526908	526538	19575F	PARTICIPANT	\N	PRESENT	0
526909	526538	19643A	PARTICIPANT	\N	PRESENT	0
526910	526538	14231L	PARTICIPANT	\N	PRESENT	0
526911	526538	20056C	PARTICIPANT	\N	PRESENT	0
526912	526538	19573D	PARTICIPANT	\N	PRESENT	0
526913	526538	11026G	PARTICIPANT	\N	PRESENT	0
526914	526538	19549D	PARTICIPANT	\N	PRESENT	0
526915	526538	14107H	PARTICIPANT	\N	PRESENT	0
537747	536270	19760E	PARTICIPANT	\N	PRESENT	1
537748	536270	19717B	PARTICIPANT	\N	PRESENT	1
537749	536270	11103C	PARTICIPANT	\N	PRESENT	1
537750	536270	20172F	PARTICIPANT	\N	PRESENT	1
537751	536270	19591F	PARTICIPANT	\N	PRESENT	1
537752	536270	19697Q	PARTICIPANT	\N	PRESENT	1
537753	536270	19657G	PARTICIPANT	\N	PRESENT	1
537754	536270	04057K	PARTICIPANT	\N	PRESENT	1
537755	536270	19798U	PARTICIPANT	\N	PRESENT	1
537756	536270	19301E	PARTICIPANT	\N	PRESENT	1
537757	536270	11067R	PARTICIPANT	\N	PRESENT	0
537758	536270	14223L	PARTICIPANT	\N	PRESENT	0
537759	536270	14071N	PARTICIPANT	\N	PRESENT	0
537760	536270	20148F	PARTICIPANT	\N	PRESENT	0
537761	536270	17965H	PARTICIPANT	\N	PRESENT	0
537762	536270	19679N	PARTICIPANT	\N	PRESENT	0
537763	536270	11097X	PARTICIPANT	\N	PRESENT	0
537764	536270	19703U	PARTICIPANT	\N	PRESENT	0
537765	536270	19713W	PARTICIPANT	\N	PRESENT	0
537766	536270	01034P	PARTICIPANT	\N	PRESENT	0
537767	536270	17779H	PARTICIPANT	\N	PRESENT	0
537768	536270	19367Y	PARTICIPANT	\N	PRESENT	0
537769	536270	19415P	PARTICIPANT	\N	PRESENT	0
537770	536270	14195A	PARTICIPANT	\N	PRESENT	0
537771	536270	11031D	PARTICIPANT	\N	PRESENT	0
537772	536270	10006L	PRESIDENT	0	PRESENT	0
537773	536270	14217N	PARTICIPANT	\N	PRESENT	0
537774	536270	14042U	PARTICIPANT	\N	PRESENT	0
537775	536270	20040T	PARTICIPANT	\N	PRESENT	0
537776	536270	08045X	PARTICIPANT	\N	PRESENT	0
537777	536270	19691J	PARTICIPANT	\N	PRESENT	0
537778	536270	19569H	PARTICIPANT	\N	PRESENT	0
537779	536270	14213J	PARTICIPANT	\N	PRESENT	0
537780	536270	19683J	PARTICIPANT	\N	PRESENT	0
537781	536270	19723Y	PARTICIPANT	\N	PRESENT	0
537782	536270	18193Q	PARTICIPANT	\N	PRESENT	0
537785	536270	19543W	PARTICIPANT	\N	PRESENT	1
537786	536270	17737W	PARTICIPANT	\N	PRESENT	1
537790	536270	19629C	PARTICIPANT	\N	PRESENT	1
537791	536270	04008A	PARTICIPANT	\N	PRESENT	1
537792	536270	14179A	PARTICIPANT	\N	PRESENT	1
537793	536270	19581D	PARTICIPANT	\N	PRESENT	1
537794	536270	19675J	PARTICIPANT	\N	PRESENT	1
538551	536831	20102Q	PARTICIPANT	\N	PRESENT	0
538552	536831	20046A	PARTICIPANT	\N	PRESENT	0
538553	536831	19758L	PARTICIPANT	\N	PRESENT	0
538554	536831	19503N	PARTICIPANT	\N	PRESENT	0
538555	536831	14109K	PARTICIPANT	\N	PRESENT	0
538556	536831	12016W	PARTICIPANT	\N	PRESENT	0
538557	536831	19715Y	PARTICIPANT	\N	PRESENT	0
538558	536831	11104D	PARTICIPANT	\N	PRESENT	0
538560	536831	20142Y	PARTICIPANT	\N	PRESENT	0
538561	536831	20174H	PARTICIPANT	\N	PRESENT	0
538562	536831	17589D	PARTICIPANT	\N	PRESENT	0
538563	536831	20106U	PARTICIPANT	\N	PRESENT	0
538564	536831	11012A	PARTICIPANT	\N	PRESENT	0
538565	536831	19533U	PARTICIPANT	\N	PRESENT	0
538566	536831	19866P	PARTICIPANT	\N	PRESENT	0
538567	536831	19553Y	PARTICIPANT	\N	PRESENT	0
538568	536831	20148F	PARTICIPANT	\N	PRESENT	0
538569	536831	19713W	PARTICIPANT	\N	PRESENT	0
538570	536831	19515S	PARTICIPANT	\N	PRESENT	0
538571	536831	19691J	PARTICIPANT	\N	PRESENT	0
538572	536831	20044X	PARTICIPANT	\N	PRESENT	0
538573	536831	20058E	PARTICIPANT	\N	PRESENT	0
538574	536831	19735D	PARTICIPANT	\N	PRESENT	0
538575	536831	01024M	PARTICIPANT	\N	PRESENT	0
538576	536831	18083K	PARTICIPANT	\N	PRESENT	0
538577	536831	19593H	PARTICIPANT	\N	PRESENT	0
538578	536831	19711U	PARTICIPANT	\N	PRESENT	0
538579	536831	20124W	PARTICIPANT	\N	PRESENT	0
538580	536831	20152B	PARTICIPANT	\N	PRESENT	0
538581	536831	19621T	PARTICIPANT	\N	PRESENT	0
538582	536831	19693L	PARTICIPANT	\N	PRESENT	0
538583	536831	19747H	PARTICIPANT	\N	PRESENT	0
538584	536831	19467C	PARTICIPANT	\N	PRESENT	0
538585	536831	08061X	PARTICIPANT	\N	PRESENT	0
538586	536831	19573D	PARTICIPANT	\N	PRESENT	0
538587	536831	20054A	PARTICIPANT	\N	PRESENT	0
538588	536831	14073Q	PARTICIPANT	\N	PRESENT	0
538589	536831	14042U	PARTICIPANT	\N	PRESENT	0
538590	536831	19479G	PARTICIPANT	\N	PRESENT	0
538591	536831	20026V	PARTICIPANT	\N	PRESENT	0
538592	536831	14030Q	PARTICIPANT	\N	PRESENT	0
538593	536831	14231L	PARTICIPANT	\N	PRESENT	0
538594	536831	14071N	PARTICIPANT	\N	PRESENT	0
538595	536831	20074E	PARTICIPANT	\N	PRESENT	0
538596	536831	14229S	PARTICIPANT	\N	PRESENT	0
538597	536831	19631V	PARTICIPANT	\N	PRESENT	0
538598	536831	19415P	PARTICIPANT	\N	PRESENT	0
538599	536831	14249W	PARTICIPANT	\N	PRESENT	0
538549	536831	12041X	PARTICIPANT	\N	PRESENT	0
538550	536831	19565D	PARTICIPANT	\N	PRESENT	0
538600	536831	20034V	PARTICIPANT	\N	PRESENT	0
538601	536831	20090E	PARTICIPANT	\N	PRESENT	0
538602	536831	14187A	PARTICIPANT	\N	PRESENT	0
538603	536831	99004R	PARTICIPANT	\N	PRESENT	0
538604	536831	20082E	PARTICIPANT	\N	PRESENT	0
538605	536831	20126Y	PARTICIPANT	\N	PRESENT	0
538606	536831	19611R	PARTICIPANT	\N	PRESENT	0
538607	536831	19651A	PARTICIPANT	\N	PRESENT	0
538608	536831	04033B	PARTICIPANT	\N	PRESENT	0
538609	536831	20094J	PARTICIPANT	\N	PRESENT	0
538610	536831	14213J	PARTICIPANT	\N	PRESENT	0
538611	536831	19399H	PARTICIPANT	\N	PRESENT	0
538615	536831	11048N	PARTICIPANT	\N	PRESENT	0
538616	536831	20048C	PARTICIPANT	\N	PRESENT	0
538640	536831	19387D	PARTICIPANT	\N	PRESENT	0
538651	536831	20038A	PARTICIPANT	\N	PRESENT	0
538661	536831	19413M	PARTICIPANT	\N	PRESENT	0
538665	536831	20066E	PARTICIPANT	\N	PRESENT	0
538666	536831	19349W	PARTICIPANT	\N	PRESENT	0
538667	536831	11056N	PARTICIPANT	\N	PRESENT	0
538717	537410	99004R	PARTICIPANT	\N	PRESENT	0
538718	537410	20124W	PARTICIPANT	\N	PRESENT	0
538719	537410	20152B	PARTICIPANT	\N	PRESENT	0
538720	537410	20090E	PARTICIPANT	\N	PRESENT	0
538721	537410	20026V	PARTICIPANT	\N	PRESENT	0
538722	537410	20034V	PARTICIPANT	\N	PRESENT	0
538723	537410	19866P	PARTICIPANT	\N	PRESENT	0
538724	537410	20142Y	PARTICIPANT	\N	PRESENT	0
538725	537410	14109K	PARTICIPANT	\N	PRESENT	0
538726	537410	19651A	PARTICIPANT	\N	PRESENT	0
538727	537410	19611R	PARTICIPANT	\N	PRESENT	0
538728	537410	14229S	PARTICIPANT	\N	PRESENT	0
538729	537410	20044X	PARTICIPANT	\N	PRESENT	0
538730	537410	19593H	PARTICIPANT	\N	PRESENT	0
538731	537410	19621T	PARTICIPANT	\N	PRESENT	0
538732	537410	19758L	PARTICIPANT	\N	PRESENT	0
538733	537410	14073Q	PARTICIPANT	\N	PRESENT	0
538734	537410	14030Q	PARTICIPANT	\N	PRESENT	0
538735	537410	20054A	PARTICIPANT	\N	PRESENT	0
538736	537410	19693L	PARTICIPANT	\N	PRESENT	0
538737	537410	19349W	PARTICIPANT	\N	PRESENT	0
538738	537410	20106U	PARTICIPANT	\N	PRESENT	0
538739	537410	20058E	PARTICIPANT	\N	PRESENT	0
538740	537410	20100N	PARTICIPANT	\N	PRESENT	0
538741	537410	19347U	PARTICIPANT	\N	PRESENT	0
538742	537410	19747H	PARTICIPANT	\N	PRESENT	0
538743	537410	11065P	PARTICIPANT	\N	PRESENT	0
538744	537410	20070A	PARTICIPANT	\N	PRESENT	0
538745	537410	19573D	PARTICIPANT	\N	PRESENT	0
538746	537410	04033B	PARTICIPANT	\N	PRESENT	0
538747	537410	20110Q	PARTICIPANT	\N	PRESENT	0
538748	537410	17589D	PARTICIPANT	\N	PRESENT	0
538749	537410	14213J	PARTICIPANT	\N	PRESENT	0
538750	537410	20126Y	PARTICIPANT	\N	PRESENT	0
538751	537410	19762G	PARTICIPANT	\N	PRESENT	0
538752	536913	19701S	PARTICIPANT	\N	PRESENT	0
538753	536913	14357A	PARTICIPANT	\N	PRESENT	0
538754	536913	20100N	PARTICIPANT	\N	PRESENT	0
538755	536913	19553Y	PARTICIPANT	\N	PRESENT	1
538756	536913	14097Y	PARTICIPANT	\N	PRESENT	1
538757	536913	14073Q	PARTICIPANT	\N	PRESENT	0
538758	536913	19711U	PARTICIPANT	\N	PRESENT	0
538759	536913	08034U	PARTICIPANT	\N	PRESENT	0
538760	536913	19441R	PARTICIPANT	\N	PRESENT	0
538761	536913	14001X	PARTICIPANT	\N	PRESENT	1
538762	536913	19563B	PARTICIPANT	\N	PRESENT	0
538763	536913	04070G	PARTICIPANT	\N	PRESENT	1
538764	536913	14331P	PRESIDENT	0	PRESENT	0
514619	502368	20090E	PARTICIPANT	\N	PRESENT	0
514620	502368	19383Y	PARTICIPANT	\N	PRESENT	0
514621	502368	97011G	PARTICIPANT	\N	PRESENT	0
514622	502368	14053L	PARTICIPANT	\N	PRESENT	0
514623	502368	19798U	PARTICIPANT	\N	PRESENT	0
514624	502368	18083K	PARTICIPANT	\N	PRESENT	0
514625	502368	20078J	PARTICIPANT	\N	PRESENT	0
514641	502368	08009T	PARTICIPANT	\N	PRESENT	0
514627	502368	20140W	PARTICIPANT	\N	PRESENT	0
514628	502368	20136B	PARTICIPANT	\N	PRESENT	0
514629	502368	14147R	PARTICIPANT	\N	PRESENT	0
514630	502368	20024T	PARTICIPANT	\N	PRESENT	0
514631	502368	20062A	PARTICIPANT	\N	PRESENT	0
514632	502368	20108W	PARTICIPANT	\N	PRESENT	0
514633	502368	19399H	PARTICIPANT	\N	PRESENT	0
514634	502368	20088L	PARTICIPANT	\N	PRESENT	0
514635	502368	14187A	PARTICIPANT	\N	PRESENT	0
514636	502368	19333N	PARTICIPANT	\N	PRESENT	0
514637	502368	19719D	PARTICIPANT	\N	PRESENT	0
514638	502368	14169X	PARTICIPANT	\N	PRESENT	0
514639	502368	19671E	PARTICIPANT	\N	PRESENT	0
514640	502368	20138D	PARTICIPANT	\N	PRESENT	0
514642	502368	14219Q	PARTICIPANT	\N	PRESENT	0
514646	502368	19782L	PARTICIPANT	\N	PRESENT	0
514644	502368	01058X	PARTICIPANT	\N	PRESENT	0
514645	502368	14031R	PARTICIPANT	\N	PRESENT	0
514647	502368	20174H	PARTICIPANT	\N	PRESENT	0
514648	502368	19549D	PARTICIPANT	\N	PRESENT	0
514649	502368	11103C	PARTICIPANT	\N	PRESENT	0
514650	502368	14038Y	PARTICIPANT	\N	PRESENT	0
514651	502368	20096L	PARTICIPANT	\N	PRESENT	0
514652	502368	19565D	PARTICIPANT	\N	PRESENT	0
514658	502368	20116W	PARTICIPANT	\N	PRESENT	0
514661	502368	14189C	PARTICIPANT	\N	PRESENT	0
514680	502368	19551W	PARTICIPANT	\N	PRESENT	0
514682	502368	19631V	PARTICIPANT	\N	PRESENT	0
514686	502368	20112S	PARTICIPANT	\N	PRESENT	0
514690	502368	17229F	PARTICIPANT	\N	PRESENT	0
514691	502368	14073Q	PARTICIPANT	\N	PRESENT	0
514692	502368	14069U	PARTICIPANT	\N	PRESENT	0
514693	502368	19367Y	PARTICIPANT	\N	PRESENT	0
514694	511986	19766L	PARTICIPANT	\N	PRESENT	0
514695	511986	19697Q	PARTICIPANT	\N	PRESENT	0
514696	511986	14331P	PARTICIPANT	\N	PRESENT	0
514697	511986	11067R	PARTICIPANT	\N	PRESENT	0
514698	511986	19545Y	PARTICIPANT	\N	PRESENT	0
514699	511986	19569H	PARTICIPANT	\N	PRESENT	0
514700	511986	11097X	PARTICIPANT	\N	PRESENT	0
514701	511986	19667J	PARTICIPANT	\N	PRESENT	0
514702	511986	11070L	PARTICIPANT	\N	PRESENT	0
514703	511986	19447X	PARTICIPANT	\N	PRESENT	0
514704	511986	19553Y	PARTICIPANT	\N	PRESENT	0
514705	511986	11031D	PARTICIPANT	\N	PRESENT	0
514706	511986	19703U	PARTICIPANT	\N	PRESENT	0
514707	511986	19573D	PARTICIPANT	\N	PRESENT	0
514708	511986	14041T	PARTICIPANT	\N	PRESENT	0
514709	511986	19503N	PARTICIPANT	\N	PRESENT	0
514710	511986	19349W	PARTICIPANT	\N	PRESENT	1
514711	511986	19683J	PARTICIPANT	\N	PRESENT	0
514712	511986	10006L	PARTICIPANT	\N	PRESENT	0
514713	511986	20130U	PARTICIPANT	\N	PRESENT	0
514714	511986	19643A	PARTICIPANT	\N	PRESENT	0
514715	511986	01034P	PARTICIPANT	\N	PRESENT	0
514716	511986	19479G	PARTICIPANT	\N	PRESENT	0
514717	511986	04092N	PRESIDENT	0	PRESENT	0
514718	511986	19713W	PARTICIPANT	\N	PRESENT	0
514719	511986	19691J	PARTICIPANT	\N	PRESENT	0
514720	511986	19715Y	PARTICIPANT	\N	PRESENT	0
514721	511986	04059M	PARTICIPANT	\N	PRESENT	0
514722	511986	99004R	PARTICIPANT	\N	PRESENT	0
514725	502368	19729F	PARTICIPANT	\N	PRESENT	0
514726	502368	19387D	PARTICIPANT	\N	PRESENT	0
514727	502368	20068G	PARTICIPANT	\N	PRESENT	0
514728	502368	14267Y	PARTICIPANT	\N	PRESENT	0
514729	502368	19489J	PARTICIPANT	\N	PRESENT	0
514730	502368	16685X	PARTICIPANT	\N	PRESENT	0
514731	502368	20124W	PARTICIPANT	\N	PRESENT	0
514732	502368	14237S	PARTICIPANT	\N	PRESENT	0
514733	502368	19954N	PARTICIPANT	\N	PRESENT	0
514734	502368	20044X	PARTICIPANT	\N	PRESENT	0
514735	502368	19745F	PARTICIPANT	\N	PRESENT	0
514736	502368	19521Q	PARTICIPANT	\N	PRESENT	0
514751	502368	19621T	PARTICIPANT	\N	PRESENT	0
514738	502368	19467C	PARTICIPANT	\N	PRESENT	0
514739	502368	14105F	PARTICIPANT	\N	PRESENT	0
514740	502368	14217N	PARTICIPANT	\N	PRESENT	0
514741	502368	14033T	PARTICIPANT	\N	PRESENT	0
514742	502368	20052X	PARTICIPANT	\N	PRESENT	0
514743	502368	14089Y	PARTICIPANT	\N	PRESENT	0
514744	502368	14331P	PARTICIPANT	\N	PRESENT	0
514745	502368	05008E	PARTICIPANT	\N	PRESENT	0
514746	502368	14213J	PARTICIPANT	\N	PRESENT	0
514747	502368	20110Q	PARTICIPANT	\N	PRESENT	0
514748	502368	20042V	PARTICIPANT	\N	PRESENT	0
514749	502368	19749K	PARTICIPANT	\N	PRESENT	0
514750	502368	19629C	PARTICIPANT	\N	PRESENT	0
514752	502368	19415P	PARTICIPANT	\N	PRESENT	0
514753	502368	19413M	PARTICIPANT	\N	PRESENT	0
514754	502368	14211G	PARTICIPANT	\N	PRESENT	0
514755	502368	19447X	PARTICIPANT	\N	PRESENT	0
514756	502368	14021P	PARTICIPANT	\N	PRESENT	0
514760	502368	07029T	PARTICIPANT	\N	PRESENT	0
514761	502368	04085P	PARTICIPANT	\N	PRESENT	0
514826	502369	01043Q	PARTICIPANT	\N	PRESENT	0
514827	502369	04047H	PARTICIPANT	\N	PRESENT	0
514828	502369	14215L	PARTICIPANT	\N	PRESENT	0
514829	502369	20028X	PARTICIPANT	\N	PRESENT	0
514830	502369	19695N	PARTICIPANT	\N	PRESENT	0
514831	502369	11056N	PARTICIPANT	\N	PRESENT	0
514832	502369	04085P	PARTICIPANT	\N	PRESENT	0
514833	502369	19549D	PARTICIPANT	\N	PRESENT	0
514834	502369	19489J	PARTICIPANT	\N	PRESENT	0
514835	502369	19413M	PARTICIPANT	\N	PRESENT	0
514836	502369	20092G	PARTICIPANT	\N	PRESENT	0
514837	502369	20110Q	PARTICIPANT	\N	PRESENT	0
514838	502369	14021P	PARTICIPANT	\N	PRESENT	0
514839	502369	95063L	PARTICIPANT	\N	PRESENT	0
514840	502369	19387D	PARTICIPANT	\N	PRESENT	0
514841	502369	14111D	PARTICIPANT	\N	PRESENT	0
514842	502369	14107H	PARTICIPANT	\N	PRESENT	0
514843	502369	19629C	PARTICIPANT	\N	PRESENT	0
514844	502369	14083S	PARTICIPANT	\N	PRESENT	0
514845	502369	19367Y	PARTICIPANT	\N	PRESENT	0
514846	502369	19415P	PARTICIPANT	\N	PRESENT	0
514847	502369	14033T	PARTICIPANT	\N	PRESENT	0
514848	502369	19954N	PARTICIPANT	\N	PRESENT	0
514849	502369	07029T	PARTICIPANT	\N	PRESENT	0
514850	502369	19399H	PARTICIPANT	\N	PRESENT	0
514851	502369	20108W	PARTICIPANT	\N	PRESENT	0
514852	502369	20062A	PARTICIPANT	\N	PRESENT	0
514853	502369	20124W	PARTICIPANT	\N	PRESENT	0
514854	502369	20090E	PARTICIPANT	\N	PRESENT	0
514855	502369	14105F	PARTICIPANT	\N	PRESENT	0
514856	502369	14133K	PARTICIPANT	\N	PRESENT	0
514857	502369	11097X	PARTICIPANT	\N	PRESENT	0
514858	502369	05008E	PARTICIPANT	\N	PRESENT	0
514859	502369	19543W	PARTICIPANT	\N	PRESENT	0
514860	502369	20066E	PARTICIPANT	\N	PRESENT	0
514861	502369	19467C	PARTICIPANT	\N	PRESENT	0
514862	502369	14031R	PARTICIPANT	\N	PRESENT	0
514863	502369	19631V	PARTICIPANT	\N	PRESENT	0
514864	502369	20116W	PARTICIPANT	\N	PRESENT	0
514865	502369	14030Q	PARTICIPANT	\N	PRESENT	0
514866	502369	14147R	PARTICIPANT	\N	PRESENT	0
514867	502369	19621T	PARTICIPANT	\N	PRESENT	0
514868	502369	14179A	PARTICIPANT	\N	PRESENT	0
514869	502369	19798U	PARTICIPANT	\N	PRESENT	0
514870	502369	14053L	PARTICIPANT	\N	PRESENT	0
514871	502369	11048N	PARTICIPANT	\N	PRESENT	0
514872	502369	20142Y	PARTICIPANT	\N	PRESENT	0
514873	502369	19503N	PARTICIPANT	\N	PRESENT	0
514874	502369	19647E	PARTICIPANT	\N	PRESENT	0
514875	502369	14231L	PARTICIPANT	\N	PRESENT	0
514876	502369	19749K	PARTICIPANT	\N	PRESENT	0
514877	512704	11056N	PARTICIPANT	\N	PRESENT	0
514878	512704	19954N	PARTICIPANT	\N	PRESENT	0
514879	512704	19489J	PARTICIPANT	\N	PRESENT	0
514880	512704	14147R	PARTICIPANT	\N	PRESENT	0
514881	512704	19543W	PARTICIPANT	\N	PRESENT	0
514882	512704	14215L	PARTICIPANT	\N	PRESENT	0
514883	512704	04047H	PRESIDENT	0	PRESENT	0
532357	530821	19295A	PARTICIPANT	\N	EXCUSE	0
532358	530821	20066E	PARTICIPANT	\N	PRESENT	0
532380	530821	08045X	PARTICIPANT	\N	PRESENT	1
532384	530821	19663E	PARTICIPANT	\N	PRESENT	1
532386	530821	17779H	PARTICIPANT	\N	PRESENT	1
532394	530821	20040T	PARTICIPANT	\N	PRESENT	1
532426	530821	18193Q	PARTICIPANT	\N	PRESENT	0
532481	530821	11103C	PARTICIPANT	\N	PRESENT	1
532485	530821	19713W	PARTICIPANT	\N	PRESENT	0
533025	533020	01034P	PARTICIPANT	\N	PRESENT	0
533730	533729	04092N	PARTICIPANT	\N	PRESENT	1
533731	533729	20130U	PARTICIPANT	\N	PRESENT	1
533732	533729	19798U	PARTICIPANT	\N	PRESENT	1
536745	491410	01024M	PARTICIPANT	\N	PRESENT	0
536746	491410	14281W	PARTICIPANT	\N	PRESENT	0
536747	491410	19531S	PARTICIPANT	\N	PRESENT	0
536748	491410	19673G	PARTICIPANT	\N	PRESENT	0
536749	491410	01043Q	PARTICIPANT	\N	PRESENT	0
536750	491410	17779H	PARTICIPANT	\N	PRESENT	0
536751	491410	20108W	PARTICIPANT	\N	PRESENT	0
536752	491410	14229S	PARTICIPANT	\N	PRESENT	0
536753	491410	20080C	PARTICIPANT	\N	PRESENT	0
536754	491410	19479G	PARTICIPANT	\N	PRESENT	0
536755	491410	01057W	PARTICIPANT	\N	PRESENT	0
536756	491410	19721W	PARTICIPANT	\N	PRESENT	0
536757	491410	19549D	PARTICIPANT	\N	PRESENT	0
536758	491410	19563B	PARTICIPANT	\N	PRESENT	0
536759	491410	20094J	PARTICIPANT	\N	PRESENT	0
536760	491410	17367Q	PARTICIPANT	\N	PRESENT	0
536761	491410	19347U	PARTICIPANT	\N	PRESENT	0
536762	491410	19637C	PARTICIPANT	\N	PRESENT	0
536763	491410	14207L	PARTICIPANT	\N	PRESENT	0
536764	491410	20078J	PARTICIPANT	\N	PRESENT	0
536765	491410	17965H	PARTICIPANT	\N	PRESENT	0
536766	491410	11065P	PARTICIPANT	\N	PRESENT	0
536767	491410	11012A	PARTICIPANT	\N	PRESENT	0
536768	491410	19723Y	PARTICIPANT	\N	PRESENT	0
536769	491410	19591F	PARTICIPANT	\N	PRESENT	0
536770	491410	20072C	PARTICIPANT	\N	PRESENT	0
536771	491410	20132W	PARTICIPANT	\N	PRESENT	0
536772	491410	14223L	PARTICIPANT	\N	PRESENT	0
536773	491410	20110Q	PARTICIPANT	\N	PRESENT	0
536774	491410	20066E	PARTICIPANT	\N	PRESENT	0
536775	491410	11043H	PARTICIPANT	\N	PRESENT	0
536776	491410	18083K	PARTICIPANT	\N	PRESENT	0
536777	491410	20040T	PARTICIPANT	\N	PRESENT	0
536778	491410	19507S	PARTICIPANT	\N	PRESENT	0
536779	491410	19367Y	PARTICIPANT	\N	PRESENT	0
536780	491410	20148F	PARTICIPANT	\N	PRESENT	0
536781	491410	19575F	PARTICIPANT	\N	PRESENT	0
536782	491410	18193Q	PARTICIPANT	\N	PRESENT	0
536783	491410	19695N	PARTICIPANT	\N	PRESENT	0
536784	491410	20068G	PARTICIPANT	\N	PRESENT	0
536785	491410	20100N	PARTICIPANT	\N	PRESENT	0
536786	491410	14097Y	PARTICIPANT	\N	PRESENT	0
536787	491410	14215L	PARTICIPANT	\N	PRESENT	0
536788	491410	08015R	PARTICIPANT	\N	PRESENT	0
536789	491410	20032T	PARTICIPANT	\N	PRESENT	0
536790	491410	20152B	PARTICIPANT	\N	PRESENT	0
536791	491410	08028W	PARTICIPANT	\N	PRESENT	0
536792	491410	08010L	PARTICIPANT	\N	PRESENT	0
536793	491410	01025N	PARTICIPANT	\N	PRESENT	0
536794	491410	19415P	PARTICIPANT	\N	PRESENT	0
536795	491410	05012A	PARTICIPANT	\N	PRESENT	0
536796	491410	14187A	PARTICIPANT	\N	PRESENT	0
536797	491410	14105F	PARTICIPANT	\N	PRESENT	0
536798	491410	97011G	PARTICIPANT	\N	PRESENT	0
536799	491410	20090E	PARTICIPANT	\N	PRESENT	0
536800	491410	14031R	PARTICIPANT	\N	PRESENT	0
536801	491410	20024T	PARTICIPANT	\N	PRESENT	0
536802	491410	20102Q	PARTICIPANT	\N	PRESENT	0
536803	491410	14033T	PARTICIPANT	\N	PRESENT	0
536804	491410	19657G	PARTICIPANT	\N	PRESENT	0
536805	491410	14042U	PARTICIPANT	\N	PRESENT	0
536806	491410	19515S	PARTICIPANT	\N	PRESENT	0
536807	491410	14089Y	PARTICIPANT	\N	PRESENT	0
536808	491410	11031D	PARTICIPANT	\N	PRESENT	0
536809	491410	12028B	PARTICIPANT	\N	PRESENT	0
536810	491410	01058X	PARTICIPANT	\N	PRESENT	0
536811	491410	19713W	PARTICIPANT	\N	PRESENT	0
536812	491410	19503N	PARTICIPANT	\N	PRESENT	0
536813	491410	20038A	PARTICIPANT	\N	PRESENT	0
536814	491410	20076G	PARTICIPANT	\N	PRESENT	0
536815	491410	04057K	PARTICIPANT	\N	PRESENT	0
536816	491410	20046A	PARTICIPANT	\N	PRESENT	0
536817	491410	19866P	PARTICIPANT	\N	PRESENT	0
536818	491410	19691J	PARTICIPANT	\N	PRESENT	0
536819	491410	14107H	PARTICIPANT	\N	PRESENT	0
536820	491410	19569H	PARTICIPANT	\N	PRESENT	0
536821	491410	14109K	PARTICIPANT	\N	PRESENT	0
536822	491410	19333N	PARTICIPANT	\N	PRESENT	0
536823	491410	08045X	PARTICIPANT	\N	PRESENT	0
536863	536862	11115U	PARTICIPANT	\N	PRESENT	0
536940	536939	19631V	PARTICIPANT	\N	PRESENT	0
536941	536939	14033T	PARTICIPANT	\N	PRESENT	0
536942	536939	14207L	PARTICIPANT	\N	PRESENT	0
536943	536939	14357A	PARTICIPANT	\N	PRESENT	0
536945	536944	14033T	PARTICIPANT	\N	PRESENT	0
536946	536944	14357A	PARTICIPANT	\N	PRESENT	0
536947	536944	20034V	PARTICIPANT	\N	PRESENT	0
536948	536944	14257W	PARTICIPANT	\N	PRESENT	0
536949	536944	20144B	PARTICIPANT	\N	PRESENT	0
536951	536950	14033T	PARTICIPANT	\N	PRESENT	0
536952	536950	19413M	PARTICIPANT	\N	PRESENT	0
536953	536950	20144B	PARTICIPANT	\N	PRESENT	0
536954	536950	20034V	PARTICIPANT	\N	PRESENT	0
536955	536950	14257W	PARTICIPANT	\N	PRESENT	0
536957	536956	14033T	PARTICIPANT	\N	PRESENT	0
536958	536956	19413M	PARTICIPANT	\N	PRESENT	0
536959	536956	20174H	PARTICIPANT	\N	PRESENT	0
536960	536956	20144B	PARTICIPANT	\N	PRESENT	0
536962	536961	14033T	PARTICIPANT	\N	PRESENT	0
536963	536961	19413M	PARTICIPANT	\N	PRESENT	0
536965	536964	11070L	PARTICIPANT	\N	PRESENT	0
536966	536964	19647E	PARTICIPANT	\N	PRESENT	0
536968	536967	04086Q	PARTICIPANT	\N	PRESENT	0
536970	536969	11048N	PARTICIPANT	\N	PRESENT	0
536972	536971	11048N	PARTICIPANT	\N	PRESENT	0
536974	536973	11048N	PARTICIPANT	\N	PRESENT	0
536976	536975	11048N	PARTICIPANT	\N	PRESENT	0
536977	536975	08011M	PARTICIPANT	\N	PRESENT	0
536991	536608	14147R	PARTICIPANT	\N	PRESENT	1
536992	536608	14231L	PARTICIPANT	\N	EXCUSE	0
537085	537084	14038Y	PARTICIPANT	\N	PRESENT	0
537086	537084	20060X	PARTICIPANT	\N	PRESENT	0
537087	537084	20174H	PARTICIPANT	\N	PRESENT	0
537088	537084	19631V	PARTICIPANT	\N	PRESENT	0
537089	537026	20066E	PARTICIPANT	\N	PRESENT	0
537375	537374	17737W	PARTICIPANT	\N	PRESENT	0
537376	536590	14030Q	PARTICIPANT	\N	PRESENT	0
537377	536590	19383Y	PRESIDENT	0	PRESENT	0
537378	536590	19758L	PARTICIPANT	\N	PRESENT	0
537379	536590	19719D	PARTICIPANT	\N	PRESENT	0
537381	536590	20140W	PARTICIPANT	\N	PRESENT	0
537382	536590	20038A	PARTICIPANT	\N	PRESENT	0
537383	536590	01025N	PARTICIPANT	\N	PRESENT	1
537384	536590	14026U	PARTICIPANT	\N	PRESENT	0
537385	536590	19551W	PARTICIPANT	\N	EXCUSE	0
537386	536590	19441R	PARTICIPANT	\N	EXCUSE	0
537387	536590	19637C	PARTICIPANT	\N	PRESENT	1
537388	536590	20028X	PARTICIPANT	\N	PRESENT	0
537389	536590	14109K	PARTICIPANT	\N	PRESENT	1
537390	536590	19798U	PARTICIPANT	\N	PRESENT	0
537391	536590	19762G	PARTICIPANT	\N	PRESENT	0
537392	536590	19713W	PARTICIPANT	\N	PRESENT	0
537393	536590	20026V	PARTICIPANT	\N	PRESENT	0
537396	536590	17589D	PARTICIPANT	\N	PRESENT	1
537409	536590	19467C	PARTICIPANT	\N	PRESENT	0
537411	536590	11099A	PARTICIPANT	\N	PRESENT	0
537505	537503	14053L	PARTICIPANT	\N	PRESENT	0
537506	537503	19749K	PARTICIPANT	\N	PRESENT	0
537507	537503	11072N	PARTICIPANT	\N	PRESENT	0
537508	537503	04047H	PARTICIPANT	\N	PRESENT	0
537509	537503	14215L	PARTICIPANT	\N	PRESENT	0
537510	537503	11056N	PARTICIPANT	\N	PRESENT	0
537513	537512	14030Q	PARTICIPANT	\N	EXCUSE	0
537514	537512	20094J	PARTICIPANT	\N	EXCUSE	0
537515	537512	14195A	PARTICIPANT	\N	EXCUSE	0
537516	537512	20082E	PARTICIPANT	\N	EXCUSE	0
537517	537512	20092G	PARTICIPANT	\N	EXCUSE	0
537525	537524	14193X	PARTICIPANT	\N	PRESENT	0
513172	513171	20128B	PARTICIPANT	\N	PRESENT	0
513173	513171	10015M	PARTICIPANT	\N	PRESENT	0
520988	518927	14189C	PARTICIPANT	\N	PRESENT	0
520989	518927	14207L	PARTICIPANT	\N	PRESENT	0
520990	518927	20104S	PARTICIPANT	\N	PRESENT	0
520991	518927	11101A	PARTICIPANT	\N	PRESENT	0
520992	518927	19701S	PARTICIPANT	\N	PRESENT	0
520993	518927	20100N	PARTICIPANT	\N	PRESENT	0
520994	518927	19521Q	PARTICIPANT	\N	PRESENT	0
520995	518927	19507S	PARTICIPANT	\N	PRESENT	0
520996	518927	04035D	PARTICIPANT	\N	PRESENT	1
520997	518927	11083R	PARTICIPANT	\N	PRESENT	0
520998	518927	14033T	PARTICIPANT	\N	PRESENT	0
520999	518927	14026U	PARTICIPANT	\N	PRESENT	1
521000	518927	19725B	PARTICIPANT	\N	PRESENT	0
521001	518927	14097Y	PARTICIPANT	\N	PRESENT	1
521002	518927	12041X	PARTICIPANT	\N	PRESENT	0
521003	518927	19711U	PARTICIPANT	\N	PRESENT	0
521004	518927	19441R	PARTICIPANT	\N	PRESENT	0
521005	518927	14001X	PARTICIPANT	\N	PRESENT	0
521006	518927	04057K	PARTICIPANT	\N	PRESENT	0
521007	518927	04070G	PARTICIPANT	\N	PRESENT	1
521008	518927	14331P	PRESIDENT	0	PRESENT	1
521009	518927	10015M	PARTICIPANT	\N	PRESENT	0
521010	518927	20098N	PARTICIPANT	\N	PRESENT	1
522796	522795	19760E	PARTICIPANT	\N	PRESENT	0
522797	522795	20076G	PARTICIPANT	\N	PRESENT	0
522799	522795	20024T	PARTICIPANT	\N	PRESENT	0
522801	522795	19575F	PARTICIPANT	\N	PRESENT	0
522802	522795	20116W	PARTICIPANT	\N	PRESENT	0
522803	522795	14105F	PARTICIPANT	\N	PRESENT	0
522804	522795	19782L	PARTICIPANT	\N	PRESENT	0
522805	522795	20090E	PARTICIPANT	\N	PRESENT	0
522806	522795	11103C	PARTICIPANT	\N	PRESENT	0
523253	522844	14205J	PARTICIPANT	\N	PRESENT	0
522808	522795	14329V	PARTICIPANT	\N	PRESENT	0
522810	522795	19467C	PARTICIPANT	\N	PRESENT	0
522811	522795	18083K	PARTICIPANT	\N	PRESENT	0
522812	522795	14357A	PARTICIPANT	\N	PRESENT	0
522813	522795	17589D	PARTICIPANT	\N	PRESENT	0
522814	522795	19507S	PARTICIPANT	\N	PRESENT	0
522815	522795	14187A	PARTICIPANT	\N	PRESENT	0
522816	522795	20038A	PARTICIPANT	\N	PRESENT	0
522818	522795	14033T	PARTICIPANT	\N	PRESENT	0
522822	522795	14213J	PARTICIPANT	\N	PRESENT	0
522824	522795	20126Y	PARTICIPANT	\N	PRESENT	0
522826	522795	16685X	PARTICIPANT	\N	PRESENT	0
522827	522795	20018V	PARTICIPANT	\N	PRESENT	0
522829	522795	08061X	PARTICIPANT	\N	PRESENT	0
522830	522795	20118Y	PARTICIPANT	\N	PRESENT	0
522831	522795	05012A	PARTICIPANT	\N	PRESENT	0
522832	522795	19739H	PARTICIPANT	\N	PRESENT	0
522833	522795	14331P	PARTICIPANT	\N	PRESENT	0
522834	522795	19619A	PARTICIPANT	\N	PRESENT	0
522835	522795	20092G	PARTICIPANT	\N	PRESENT	0
522836	522795	20044X	PARTICIPANT	\N	PRESENT	0
522837	522795	20062A	PARTICIPANT	\N	PRESENT	0
522838	522795	20064C	PARTICIPANT	\N	PRESENT	0
523252	522844	14033T	PARTICIPANT	\N	PRESENT	0
523254	522845	14033T	PARTICIPANT	\N	PRESENT	0
523255	522845	14205J	PARTICIPANT	\N	PRESENT	0
523256	522845	14357A	PARTICIPANT	\N	PRESENT	0
523257	522846	14033T	PARTICIPANT	\N	PRESENT	0
523258	522846	14205J	PARTICIPANT	\N	PRESENT	0
523259	522846	14207L	PARTICIPANT	\N	PRESENT	0
523265	522847	14033T	PARTICIPANT	\N	PRESENT	0
523266	522847	14205J	PARTICIPANT	\N	PRESENT	0
526916	526538	19701S	PARTICIPANT	\N	PRESENT	0
526917	526538	19729F	PARTICIPANT	\N	PRESENT	0
526918	526538	19673G	PARTICIPANT	\N	PRESENT	0
526919	526538	14259Y	PARTICIPANT	\N	PRESENT	0
526920	526538	20112S	PARTICIPANT	\N	PRESENT	0
526924	526538	20106U	PARTICIPANT	\N	PRESENT	0
526925	526538	20124W	PARTICIPANT	\N	PRESENT	0
526926	526538	01024M	PARTICIPANT	\N	PRESENT	0
526927	526538	11067R	PARTICIPANT	\N	PRESENT	0
526928	526538	14219Q	PARTICIPANT	\N	PRESENT	0
526929	526538	20040T	PARTICIPANT	\N	PRESENT	0
527086	526538	20102Q	PARTICIPANT	\N	PRESENT	0
526931	526538	19619A	PARTICIPANT	\N	PRESENT	0
526932	526538	04057K	PARTICIPANT	\N	PRESENT	0
526933	526538	20086J	PARTICIPANT	\N	PRESENT	0
526934	526538	19525U	PARTICIPANT	\N	PRESENT	0
527058	526394	20086J	PARTICIPANT	\N	PRESENT	0
527059	526394	19383Y	PARTICIPANT	\N	PRESENT	0
527060	526394	20088L	PARTICIPANT	\N	PRESENT	0
527061	526394	19515S	PARTICIPANT	\N	PRESENT	0
527062	526394	20078J	PARTICIPANT	\N	PRESENT	0
527063	526394	19413M	PARTICIPANT	\N	PRESENT	0
527064	526394	20082E	PARTICIPANT	\N	PRESENT	0
527065	526394	11099A	PARTICIPANT	\N	PRESENT	0
527066	526394	19705W	PARTICIPANT	\N	PRESENT	0
527067	526394	08015R	PARTICIPANT	\N	PRESENT	0
527068	526394	20018V	PARTICIPANT	\N	PRESENT	0
527069	526394	19511N	PARTICIPANT	\N	PRESENT	0
527070	526394	19563B	PARTICIPANT	\N	PRESENT	0
527071	526394	08028W	PARTICIPANT	\N	PRESENT	0
527072	526394	14038Y	PARTICIPANT	\N	PRESENT	0
527073	526394	20030R	PARTICIPANT	\N	PRESENT	1
527074	526394	20144B	PARTICIPANT	\N	PRESENT	0
527075	526394	19695N	PARTICIPANT	\N	PRESENT	0
527076	526394	11090Q	PRESIDENT	0	PRESENT	0
527077	526394	14033T	PARTICIPANT	\N	PRESENT	0
527078	526394	20060X	PARTICIPANT	\N	PRESENT	0
527079	526394	20062A	PARTICIPANT	\N	PRESENT	0
527080	526394	14251Q	PARTICIPANT	\N	PRESENT	0
527081	526394	19507S	PARTICIPANT	\N	PRESENT	0
527082	526394	19747H	PARTICIPANT	\N	PRESENT	0
527083	526394	14207L	PARTICIPANT	\N	PRESENT	0
527084	526394	14257W	PARTICIPANT	\N	PRESENT	0
527085	526538	19631V	PARTICIPANT	\N	PRESENT	0
527087	526394	19768N	PARTICIPANT	\N	PRESENT	0
527088	526394	20094J	PARTICIPANT	\N	PRESENT	1
527089	526394	19369B	PARTICIPANT	\N	PRESENT	0
527090	526394	20174H	PARTICIPANT	\N	PRESENT	0
527101	526538	20114U	PARTICIPANT	\N	PRESENT	0
527387	526487	19729F	PARTICIPANT	\N	PRESENT	0
527388	526487	14111D	PARTICIPANT	\N	PRESENT	0
527389	526487	20074E	PARTICIPANT	\N	PRESENT	0
527390	526487	07004J	PARTICIPANT	\N	PRESENT	0
527391	526487	14041T	PARTICIPANT	\N	PRESENT	0
527392	526487	10015M	PARTICIPANT	\N	PRESENT	0
527393	526487	19749K	PARTICIPANT	\N	PRESENT	0
527394	526487	04047H	PRESIDENT	0	PRESENT	0
527395	526487	19673G	PARTICIPANT	\N	PRESENT	0
527396	526487	19447X	PARTICIPANT	\N	PRESENT	0
527397	526487	05008E	PARTICIPANT	\N	PRESENT	0
527398	526487	95063L	PARTICIPANT	\N	PRESENT	0
527399	526487	14147R	PARTICIPANT	\N	PRESENT	0
527400	525852	20130U	PARTICIPANT	\N	PRESENT	1
527401	525852	20090E	PARTICIPANT	\N	PRESENT	0
527402	525852	11067R	PARTICIPANT	\N	PRESENT	0
527403	525852	04092N	PARTICIPANT	\N	PRESENT	0
527404	525852	19798U	PARTICIPANT	\N	PRESENT	0
527405	525852	11097X	PARTICIPANT	\N	PRESENT	0
527406	525852	19691J	PARTICIPANT	\N	PRESENT	0
527407	525852	20148F	PARTICIPANT	\N	PRESENT	0
527408	525852	14223L	PARTICIPANT	\N	PRESENT	1
527409	525852	19717B	PARTICIPANT	\N	PRESENT	1
527410	525852	14026U	PARTICIPANT	\N	PRESENT	1
527411	525852	19723Y	PARTICIPANT	\N	PRESENT	0
527412	525852	17779H	PARTICIPANT	\N	PRESENT	0
527413	525852	19703U	PARTICIPANT	\N	PRESENT	0
527414	525852	19679N	PARTICIPANT	\N	PRESENT	0
527415	525852	11103C	PARTICIPANT	\N	PRESENT	1
527416	525852	14042U	PARTICIPANT	\N	PRESENT	0
527417	525852	19367Y	PARTICIPANT	\N	PRESENT	0
527418	525852	14213J	PARTICIPANT	\N	PRESENT	0
527419	525852	14071N	PARTICIPANT	\N	PRESENT	0
527420	525852	04043D	PARTICIPANT	\N	PRESENT	1
527421	525852	10006L	PRESIDENT	0	PRESENT	0
527422	526487	01028R	PARTICIPANT	\N	PRESENT	0
527423	526487	14231L	PARTICIPANT	\N	PRESENT	0
527425	526487	14001X	PARTICIPANT	\N	PRESENT	0
527426	526487	11056N	PARTICIPANT	\N	PRESENT	0
527427	526487	14151M	PARTICIPANT	\N	PRESENT	0
527433	526487	20110Q	PARTICIPANT	\N	PRESENT	0
527434	526487	14021P	PARTICIPANT	\N	PRESENT	0
527435	526487	19954N	PARTICIPANT	\N	PRESENT	0
527461	526487	14259Y	PARTICIPANT	\N	PRESENT	0
527463	526487	11026G	PARTICIPANT	\N	PRESENT	0
538859	538858	14071N	PARTICIPANT	\N	PRESENT	0
538860	538858	11083R	PARTICIPANT	\N	PRESENT	0
538861	538858	14041T	PARTICIPANT	\N	PRESENT	0
538862	538858	20038A	PARTICIPANT	\N	PRESENT	0
539248	539244	11048N	PARTICIPANT	\N	PRESENT	0
539249	539244	08011M	PARTICIPANT	\N	PRESENT	0
539254	539251	11048N	PARTICIPANT	\N	PRESENT	0
539255	539251	08011M	PARTICIPANT	\N	PRESENT	0
539267	539266	11048N	PARTICIPANT	\N	PRESENT	0
539268	539266	08011M	PARTICIPANT	\N	PRESENT	0
539665	535603	19583F	PARTICIPANT	\N	EXCUSE	0
540376	537783	19782L	PARTICIPANT	\N	PRESENT	0
540377	537783	19441R	PARTICIPANT	\N	PRESENT	0
540378	537783	19413M	PARTICIPANT	\N	PRESENT	0
540379	537783	04045F	PARTICIPANT	\N	PRESENT	1
540380	537783	11099A	PARTICIPANT	\N	PRESENT	0
540381	537783	19705W	PARTICIPANT	\N	PRESENT	0
540382	537783	08015R	PARTICIPANT	\N	PRESENT	0
540383	537783	19575F	PARTICIPANT	\N	PRESENT	1
540384	537783	19511N	PARTICIPANT	\N	PRESENT	0
540385	537783	08028W	PARTICIPANT	\N	PRESENT	0
540386	537783	19563B	PARTICIPANT	\N	PRESENT	0
540387	537783	20028X	PARTICIPANT	\N	PRESENT	0
540388	537783	14329V	PARTICIPANT	\N	PRESENT	0
540389	537783	14038Y	PARTICIPANT	\N	PRESENT	0
540390	537783	20030R	PARTICIPANT	\N	PRESENT	1
540391	537783	19467C	PARTICIPANT	\N	PRESENT	0
540392	537783	20034V	PARTICIPANT	\N	PRESENT	0
540393	537783	14187A	PARTICIPANT	\N	PRESENT	0
540394	537783	19695N	PARTICIPANT	\N	PRESENT	1
540395	537783	14033T	PARTICIPANT	\N	PRESENT	0
540396	537783	01025N	PARTICIPANT	\N	PRESENT	0
540397	537783	11090Q	PARTICIPANT	\N	PRESENT	0
540398	537783	20054A	PARTICIPANT	\N	PRESENT	0
540399	537783	20174H	PARTICIPANT	\N	PRESENT	0
540400	537783	20062A	PARTICIPANT	\N	PRESENT	0
540401	537783	14251Q	PARTICIPANT	\N	PRESENT	1
540402	537783	19507S	PARTICIPANT	\N	PRESENT	0
540403	537783	14207L	PARTICIPANT	\N	PRESENT	0
540404	537783	19747H	PARTICIPANT	\N	PRESENT	0
540405	539685	14053L	PARTICIPANT	\N	PRESENT	0
540406	539685	14111D	PARTICIPANT	\N	PRESENT	0
540407	539685	19649G	PARTICIPANT	\N	PRESENT	0
540408	539685	19533U	PARTICIPANT	\N	PRESENT	0
540409	539685	10015M	PARTICIPANT	\N	PRESENT	0
540410	539685	14001X	PARTICIPANT	\N	PRESENT	0
540411	539685	19543W	PARTICIPANT	\N	PRESENT	0
540412	539685	04047H	PRESIDENT	0	PRESENT	0
540413	539685	19673G	PARTICIPANT	\N	PRESENT	0
540414	539685	01028R	PARTICIPANT	\N	PRESENT	0
540415	539685	05008E	PARTICIPANT	\N	PRESENT	0
540416	539685	19447X	PARTICIPANT	\N	PRESENT	0
540417	539685	14231L	PARTICIPANT	\N	PRESENT	0
540418	539685	14089Y	PARTICIPANT	\N	PRESENT	0
540419	539685	11056N	PARTICIPANT	\N	PRESENT	0
540420	539685	17737W	PARTICIPANT	\N	PRESENT	0
540421	539685	95063L	PARTICIPANT	\N	PRESENT	0
540422	539685	19629C	PARTICIPANT	\N	PRESENT	0
540423	539685	07004J	PARTICIPANT	\N	PRESENT	0
540424	539685	14147R	PARTICIPANT	\N	PRESENT	0
540425	539685	14215L	PARTICIPANT	\N	PRESENT	0
540426	539685	19749K	PARTICIPANT	\N	PRESENT	0
540427	539685	11072N	PARTICIPANT	\N	PRESENT	0
540428	537783	19768N	PARTICIPANT	\N	PRESENT	0
540429	537783	20088L	PARTICIPANT	\N	PRESENT	1
540430	537783	19369B	PARTICIPANT	\N	PRESENT	0
540436	537783	14357A	PARTICIPANT	\N	PRESENT	1
540437	537909	19697Q	PARTICIPANT	\N	PRESENT	1
540438	537909	20090E	PARTICIPANT	\N	PRESENT	0
540439	537909	11067R	PARTICIPANT	\N	PRESENT	0
540440	537909	19798U	PARTICIPANT	\N	PRESENT	0
540441	537909	11097X	PARTICIPANT	\N	PRESENT	0
540442	537909	19415P	PARTICIPANT	\N	PRESENT	0
540443	537909	14223L	PARTICIPANT	\N	PRESENT	0
540444	537909	18193Q	PARTICIPANT	\N	PRESENT	0
540445	537909	17779H	PARTICIPANT	\N	PRESENT	0
540446	537909	11031D	PARTICIPANT	\N	PRESENT	0
540447	537909	19703U	PARTICIPANT	\N	PRESENT	0
540448	537909	14042U	PARTICIPANT	\N	PRESENT	0
540449	537909	14195A	PARTICIPANT	\N	PRESENT	0
540450	537909	14213J	PARTICIPANT	\N	PRESENT	0
540451	537909	14217N	PARTICIPANT	\N	PRESENT	1
540452	537909	10006L	PRESIDENT	0	PRESENT	0
540453	537909	20130U	PARTICIPANT	\N	PRESENT	1
540454	537909	01034P	PARTICIPANT	\N	PRESENT	1
540455	537909	08045X	PARTICIPANT	\N	PRESENT	0
540456	537909	20040T	PARTICIPANT	\N	PRESENT	1
540457	537909	19301E	PARTICIPANT	\N	PRESENT	1
540458	537909	19717B	PARTICIPANT	\N	PRESENT	1
540459	537909	20066E	PARTICIPANT	\N	PRESENT	1
540460	537909	11103C	PARTICIPANT	\N	PRESENT	1
540461	537909	19760E	PARTICIPANT	\N	PRESENT	1
540462	537909	17965H	PARTICIPANT	\N	PRESENT	0
540463	537909	19691J	PARTICIPANT	\N	PRESENT	0
540464	537909	20172F	PARTICIPANT	\N	PRESENT	1
540465	537909	19723Y	PARTICIPANT	\N	PRESENT	0
540472	540471	20056C	PARTICIPANT	\N	PRESENT	0
540473	540471	19399H	PARTICIPANT	\N	PRESENT	0
540474	540471	20026V	PARTICIPANT	\N	PRESENT	0
540475	540471	19593H	PARTICIPANT	\N	PRESENT	0
540476	540471	04070G	PARTICIPANT	\N	PRESENT	0
540477	540471	19699S	PARTICIPANT	\N	PRESENT	0
540478	540471	19611R	PRESIDENT	0	PRESENT	0
540479	540471	20142Y	PARTICIPANT	\N	PRESENT	0
540480	540471	14229S	PARTICIPANT	\N	PRESENT	0
540481	540471	14030Q	PARTICIPANT	\N	PRESENT	0
540482	540471	19735D	PARTICIPANT	\N	PRESENT	0
540483	540471	11104D	PARTICIPANT	\N	PRESENT	0
540484	540471	19758L	PARTICIPANT	\N	PRESENT	0
540485	540471	19693L	PARTICIPANT	\N	PRESENT	0
540486	540471	20180F	PARTICIPANT	\N	PRESENT	0
540487	540471	19527W	PARTICIPANT	\N	PRESENT	1
540488	540471	19643A	PARTICIPANT	\N	PRESENT	1
540489	540471	14073Q	PARTICIPANT	\N	PRESENT	1
540490	540471	19651A	PARTICIPANT	\N	PRESENT	1
540491	540471	20048C	PARTICIPANT	\N	PRESENT	1
540492	540471	20052X	PARTICIPANT	\N	PRESENT	1
540493	540471	20112S	PARTICIPANT	\N	PRESENT	1
540494	540471	20084G	PARTICIPANT	\N	PRESENT	1
540495	540471	11109J	PARTICIPANT	\N	EXCUSE	0
540496	540471	11043H	PARTICIPANT	\N	PRESENT	0
540497	539685	20110Q	PARTICIPANT	\N	PRESENT	0
540498	539685	14179A	PARTICIPANT	\N	PRESENT	0
540499	539685	08018U	PARTICIPANT	\N	PRESENT	0
540500	539685	08011M	PARTICIPANT	\N	PRESENT	0
540501	539685	19725B	PARTICIPANT	\N	PRESENT	0
540502	539685	19729F	PARTICIPANT	\N	PRESENT	0
540506	537783	14257W	PARTICIPANT	\N	PRESENT	0
540511	539689	19443T	PARTICIPANT	\N	PRESENT	0
540512	539689	12041X	PARTICIPANT	\N	PRESENT	0
540513	539689	19565D	PARTICIPANT	\N	PRESENT	1
540514	539689	20072C	PARTICIPANT	\N	PRESENT	0
540515	539689	04034C	PARTICIPANT	\N	PRESENT	0
540516	539689	01058X	PARTICIPANT	\N	PRESENT	1
540517	539689	11027H	PARTICIPANT	\N	PRESENT	0
540518	539689	16685X	PARTICIPANT	\N	PRESENT	1
540519	539689	04042C	PRESIDENT	0	PRESENT	0
540520	539689	11054L	PARTICIPANT	\N	PRESENT	1
540521	539689	11066Q	PARTICIPANT	\N	PRESENT	0
540522	539689	08056B	PARTICIPANT	\N	PRESENT	0
540523	539689	12028B	PARTICIPANT	\N	PRESENT	1
540524	539689	19709B	PARTICIPANT	\N	PRESENT	0
540525	539689	14193X	PARTICIPANT	\N	PRESENT	0
540526	539689	19347U	PARTICIPANT	\N	PRESENT	0
540527	539689	14249W	PARTICIPANT	\N	PRESENT	0
540528	539689	14059S	PARTICIPANT	\N	PRESENT	0
540529	539689	14097Y	PARTICIPANT	\N	PRESENT	0
540530	539689	04035D	PARTICIPANT	\N	PRESENT	0
540531	539689	01062T	PARTICIPANT	\N	PRESENT	1
540532	539689	08069G	PARTICIPANT	\N	PRESENT	0
540533	539689	11041F	PARTICIPANT	\N	PRESENT	0
540534	539689	20042V	PARTICIPANT	\N	PRESENT	0
540535	539689	01024M	PARTICIPANT	\N	PRESENT	0
540536	539689	14105F	PARTICIPANT	\N	PRESENT	1
540537	539689	20064C	PARTICIPANT	\N	PRESENT	0
540538	539689	14267Y	PARTICIPANT	\N	PRESENT	0
540539	539689	19583F	PARTICIPANT	\N	PRESENT	1
540540	539689	14255U	PARTICIPANT	\N	PRESENT	1
540541	539689	17023S	PARTICIPANT	\N	PRESENT	0
540542	540471	20098N	PARTICIPANT	\N	PRESENT	1
540543	540471	14123H	PARTICIPANT	\N	PRESENT	1
514884	512704	14053L	PARTICIPANT	\N	PRESENT	0
514885	512704	05008E	PARTICIPANT	\N	PRESENT	0
514886	512704	14231L	PARTICIPANT	\N	PRESENT	0
514887	502369	19599P	PARTICIPANT	\N	PRESENT	0
514888	502369	01057W	PARTICIPANT	\N	PRESENT	0
514889	502369	19521Q	PARTICIPANT	\N	PRESENT	0
514890	502369	20070A	PARTICIPANT	\N	PRESENT	0
514907	512268	20130U	PARTICIPANT	\N	PRESENT	1
514908	512268	19697Q	PARTICIPANT	\N	PRESENT	1
514909	512268	04092N	PARTICIPANT	\N	PRESENT	1
514910	512268	19569H	PARTICIPANT	\N	PRESENT	0
514911	512268	11097X	PARTICIPANT	\N	PRESENT	1
514912	512268	20040T	PARTICIPANT	\N	PRESENT	1
514913	512268	19301E	PARTICIPANT	\N	PRESENT	1
514914	512268	19691J	PARTICIPANT	\N	PRESENT	1
514915	512268	19295A	PARTICIPANT	\N	PRESENT	1
514916	512268	19553Y	PARTICIPANT	\N	PRESENT	1
514917	512268	14281W	PARTICIPANT	\N	PRESENT	1
514918	512268	11103C	PARTICIPANT	\N	PRESENT	1
514919	512268	19657G	PARTICIPANT	\N	PRESENT	1
514920	512268	14217N	PARTICIPANT	\N	PRESENT	1
514921	512268	04043D	PARTICIPANT	\N	PRESENT	1
514922	512268	19760E	PARTICIPANT	\N	PRESENT	1
514926	513088	14059S	PARTICIPANT	\N	PRESENT	0
514927	513088	14133K	PRESIDENT	0	PRESENT	0
514928	513088	19565D	PARTICIPANT	\N	PRESENT	0
514929	513088	20042V	PARTICIPANT	\N	PRESENT	0
514930	513088	01058X	PARTICIPANT	\N	PRESENT	0
514931	513088	11027H	PARTICIPANT	\N	PRESENT	0
514932	513088	16685X	PARTICIPANT	\N	PRESENT	0
514933	513088	11054L	PARTICIPANT	\N	PRESENT	0
514934	513088	11066Q	PARTICIPANT	\N	PRESENT	0
514935	513088	08056B	PARTICIPANT	\N	PRESENT	0
514936	513088	14105F	PARTICIPANT	\N	PRESENT	0
514937	513088	20064C	PARTICIPANT	\N	PRESENT	0
514938	513088	19709B	PARTICIPANT	\N	PRESENT	0
514939	513088	14267Y	PARTICIPANT	\N	PRESENT	0
514940	513088	97011G	PARTICIPANT	\N	PRESENT	0
514941	513088	14211G	PARTICIPANT	\N	PRESENT	0
514942	513088	08047A	PARTICIPANT	\N	PRESENT	0
514943	513088	04042C	PRESIDENT	1	PRESENT	0
514944	513088	04035D	PARTICIPANT	\N	PRESENT	1
514945	513088	19421M	PARTICIPANT	\N	PRESENT	1
514946	513088	20128B	PARTICIPANT	\N	PRESENT	1
514947	513088	19347U	PARTICIPANT	\N	PRESENT	0
514948	513088	14097Y	PARTICIPANT	\N	PRESENT	1
514949	513088	11041F	PARTICIPANT	\N	PRESENT	1
514957	513088	11083R	PARTICIPANT	\N	PRESENT	0
514958	513088	01024M	PARTICIPANT	\N	PRESENT	1
514959	513088	04034C	PARTICIPANT	\N	PRESENT	0
514960	513080	20086J	PARTICIPANT	\N	PRESENT	1
514961	513080	19383Y	PARTICIPANT	\N	PRESENT	0
514962	513080	19768N	PARTICIPANT	\N	PRESENT	1
514963	513080	20088L	PARTICIPANT	\N	PRESENT	1
514964	513080	19515S	PARTICIPANT	\N	PRESENT	0
514965	513080	19782L	PARTICIPANT	\N	PRESENT	0
514966	513080	20092G	PARTICIPANT	\N	PRESENT	0
514967	513080	20078J	PARTICIPANT	\N	PRESENT	0
514968	513080	19441R	PARTICIPANT	\N	PRESENT	0
514969	513080	19413M	PARTICIPANT	\N	PRESENT	0
514970	513080	20094J	PARTICIPANT	\N	PRESENT	1
514971	513080	04045F	PARTICIPANT	\N	PRESENT	1
514972	513080	19631V	PARTICIPANT	\N	PRESENT	0
514973	513080	19705W	PARTICIPANT	\N	PRESENT	0
514974	513080	08015R	PARTICIPANT	\N	PRESENT	1
514975	513080	19575F	PARTICIPANT	\N	PRESENT	0
514976	513080	20018V	PARTICIPANT	\N	PRESENT	1
514977	513080	19511N	PARTICIPANT	\N	PRESENT	0
514978	513080	08028W	PARTICIPANT	\N	PRESENT	0
514979	513080	19563B	PARTICIPANT	\N	PRESENT	0
514980	513080	19521Q	PARTICIPANT	\N	PRESENT	1
514981	513080	14329V	PARTICIPANT	\N	PRESENT	0
514982	513080	20028X	PARTICIPANT	\N	PRESENT	0
514983	513080	20030R	PARTICIPANT	\N	PRESENT	1
514984	513080	19467C	PARTICIPANT	\N	PRESENT	1
514985	513080	20034V	PARTICIPANT	\N	PRESENT	0
514986	513080	20144B	PARTICIPANT	\N	PRESENT	0
514987	513080	19695N	PARTICIPANT	\N	PRESENT	0
514988	513080	14033T	PARTICIPANT	\N	PRESENT	0
514989	513080	11090Q	PRESIDENT	0	PRESENT	0
514990	513080	01025N	PARTICIPANT	\N	PRESENT	1
514991	513080	20174H	PARTICIPANT	\N	PRESENT	1
514992	513080	14205J	PARTICIPANT	\N	PRESENT	1
514993	513080	20060X	PARTICIPANT	\N	PRESENT	1
514994	513080	20062A	PARTICIPANT	\N	PRESENT	1
514995	513080	19747H	PARTICIPANT	\N	PRESENT	1
514996	513080	14207L	PARTICIPANT	\N	PRESENT	1
514997	513080	14257W	PARTICIPANT	\N	PRESENT	0
514998	513080	20054A	PARTICIPANT	\N	PRESENT	1
515001	511901	14237S	PARTICIPANT	\N	PRESENT	0
515002	511901	20068G	PARTICIPANT	\N	PRESENT	0
515003	511901	20136B	PARTICIPANT	\N	PRESENT	0
515004	511901	14219Q	PRESIDENT	0	PRESENT	0
515005	511901	20046A	PARTICIPANT	\N	PRESENT	0
515006	511901	20102Q	PARTICIPANT	\N	PRESENT	0
515007	511901	19333N	PARTICIPANT	\N	PRESENT	0
515008	511901	14031R	PARTICIPANT	\N	PRESENT	0
515009	511901	19549D	PARTICIPANT	\N	PRESENT	0
515010	511901	19387D	PARTICIPANT	\N	PRESENT	0
515011	511901	19820Y	PARTICIPANT	\N	PRESENT	0
515012	511901	14221J	PARTICIPANT	\N	PRESENT	0
515013	511901	19826F	PARTICIPANT	\N	PRESENT	0
515014	511901	17229F	PARTICIPANT	\N	PRESENT	0
515015	511901	19637C	PARTICIPANT	\N	PRESENT	0
515016	511901	18083K	PARTICIPANT	\N	PRESENT	0
515017	511901	08060W	PARTICIPANT	\N	PRESENT	0
515018	511901	20106U	PARTICIPANT	\N	PRESENT	0
515019	511901	19745F	PARTICIPANT	\N	PRESENT	0
515020	511901	20024T	PARTICIPANT	\N	PRESENT	0
515021	511901	05012A	PARTICIPANT	\N	PRESENT	0
515022	511901	17367Q	PARTICIPANT	\N	PRESENT	0
515023	511901	19599P	PARTICIPANT	\N	PRESENT	0
515024	511901	20100N	PARTICIPANT	\N	PRESENT	0
515025	511901	20140W	PARTICIPANT	\N	PRESENT	0
515026	511901	14169X	PARTICIPANT	\N	PRESENT	0
515029	511901	20118Y	PARTICIPANT	\N	PRESENT	0
515030	511901	19503N	PARTICIPANT	\N	PRESENT	0
515031	511901	11101A	PARTICIPANT	\N	PRESENT	0
515032	511901	20038A	PARTICIPANT	\N	PRESENT	0
515033	511901	19685L	PARTICIPANT	\N	PRESENT	0
515034	511901	19619A	PARTICIPANT	\N	EXCUSE	0
515747	502371	99004R	PARTICIPANT	\N	PRESENT	0
515748	502371	14033T	PARTICIPANT	\N	PRESENT	0
515749	502371	19467C	PARTICIPANT	\N	PRESENT	0
515766	502371	20140W	PARTICIPANT	\N	PRESENT	0
515767	502371	01048V	PARTICIPANT	\N	PRESENT	0
515768	502371	04043D	PARTICIPANT	\N	PRESENT	0
515769	502371	14215L	PARTICIPANT	\N	PRESENT	0
515770	502371	19631V	PARTICIPANT	\N	PRESENT	0
515771	502371	12041X	PARTICIPANT	\N	PRESENT	0
515772	502371	19565D	PARTICIPANT	\N	PRESENT	0
515773	502371	19673G	PARTICIPANT	\N	PRESENT	0
515774	502371	20126Y	PARTICIPANT	\N	PRESENT	0
515775	502371	20034V	PARTICIPANT	\N	PRESENT	0
515776	502371	19447X	PARTICIPANT	\N	PRESENT	0
515777	502371	19621T	PARTICIPANT	\N	PRESENT	0
515778	502371	19663E	PARTICIPANT	\N	PRESENT	0
515779	502371	19399H	PARTICIPANT	\N	PRESENT	0
515780	502371	08015R	PARTICIPANT	\N	PRESENT	0
515781	502371	20052X	PARTICIPANT	\N	PRESENT	0
515782	502371	19747H	PARTICIPANT	\N	PRESENT	0
515783	502371	14219Q	PARTICIPANT	\N	PRESENT	0
515784	502371	20092G	PARTICIPANT	\N	PRESENT	0
515785	502371	20116W	PARTICIPANT	\N	PRESENT	0
515786	502371	01024M	PARTICIPANT	\N	PRESENT	0
515790	502371	14021P	PARTICIPANT	\N	PRESENT	0
515788	502371	14231L	PARTICIPANT	\N	PRESENT	0
515789	502371	19637C	PARTICIPANT	\N	PRESENT	0
515791	502371	19349W	PARTICIPANT	\N	PRESENT	0
542977	542976	14231L	PARTICIPANT	\N	PRESENT	0
542979	542978	19669L	PARTICIPANT	\N	PRESENT	0
542980	542978	19421M	PARTICIPANT	\N	PRESENT	0
542982	542981	19669L	PARTICIPANT	\N	PRESENT	0
543116	542822	14069U	PARTICIPANT	\N	PRESENT	1
542984	542981	19421M	PARTICIPANT	\N	PRESENT	0
543115	542822	19954N	PARTICIPANT	\N	PRESENT	1
543117	542822	11056N	PARTICIPANT	\N	PRESENT	1
543118	542822	14179A	PARTICIPANT	\N	PRESENT	1
543119	542822	19649G	PARTICIPANT	\N	PRESENT	1
543120	542822	95063L	PARTICIPANT	\N	PRESENT	1
543121	542822	14107H	PARTICIPANT	\N	PRESENT	1
543122	542822	19675J	PARTICIPANT	\N	PRESENT	1
543488	543487	20084G	PARTICIPANT	\N	PRESENT	0
543489	543487	19637C	PARTICIPANT	\N	PRESENT	0
543491	543487	14147R	PARTICIPANT	\N	PRESENT	0
544868	542828	19447X	PARTICIPANT	\N	PRESENT	1
544869	542828	14147R	PARTICIPANT	\N	PRESENT	1
544870	542828	19649G	PARTICIPANT	\N	PRESENT	1
551637	545943	19735D	PARTICIPANT	\N	PRESENT	0
555266	555265	07029T	PARTICIPANT	\N	EXCUSE	0
555267	555265	14225N	PRESIDENT	0	PRESENT	1
555268	555265	11048N	PARTICIPANT	\N	PRESENT	1
555269	555265	99004R	PARTICIPANT	\N	PRESENT	1
555272	555265	04086Q	PARTICIPANT	\N	PRESENT	1
555273	555265	19711U	PARTICIPANT	\N	PRESENT	1
555274	555265	19687N	PARTICIPANT	\N	PRESENT	1
555275	555265	20150Y	PARTICIPANT	\N	PRESENT	1
555277	555265	11110B	PARTICIPANT	\N	PRESENT	1
555282	555265	01057W	PARTICIPANT	\N	PRESENT	1
555283	555265	20080C	PARTICIPANT	\N	PRESENT	1
555285	555265	14357A	PARTICIPANT	\N	PRESENT	1
555286	555265	14327T	PARTICIPANT	\N	PRESENT	1
555287	555265	11053K	PARTICIPANT	\N	PRESENT	1
555288	555265	14173T	PARTICIPANT	\N	PRESENT	1
555289	555265	14083S	PARTICIPANT	\N	PRESENT	1
555290	555265	19762G	PARTICIPANT	\N	PRESENT	1
555293	555265	19647E	PARTICIPANT	\N	PRESENT	1
555294	555265	20126Y	PARTICIPANT	\N	PRESENT	1
555296	555265	08010L	PARTICIPANT	\N	PRESENT	1
555297	555265	19479G	PARTICIPANT	\N	PRESENT	1
555301	555265	20044X	PARTICIPANT	\N	PRESENT	1
555304	555265	20070A	PARTICIPANT	\N	PRESENT	1
555307	555265	20022R	PARTICIPANT	\N	PRESENT	1
555315	555265	19741B	PARTICIPANT	\N	PRESENT	1
559759	559758	19593H	PARTICIPANT	\N	PRESENT	0
559760	559758	19611R	PARTICIPANT	\N	PRESENT	0
559761	559758	19693L	PARTICIPANT	\N	PRESENT	0
559762	559758	14147R	PARTICIPANT	\N	PRESENT	1
559783	559758	19643A	PARTICIPANT	\N	PRESENT	1
559846	559845	11033F	PARTICIPANT	\N	EXCUSE	0
559847	559845	19563B	PARTICIPANT	\N	EXCUSE	0
559848	559845	19683J	PRESIDENT	0	PRESENT	0
559850	559849	19683J	PARTICIPANT	0	EXCUSE	0
569958	566531	19760E	PARTICIPANT	\N	PRESENT	0
569959	566531	19758L	PARTICIPANT	\N	PRESENT	0
569960	566531	11040E	PARTICIPANT	\N	PRESENT	0
569961	566531	20102Q	PARTICIPANT	\N	PRESENT	0
569962	566531	04057K	PARTICIPANT	\N	PRESENT	0
569963	566531	14249W	PARTICIPANT	\N	PRESENT	0
569964	566531	11083R	PARTICIPANT	\N	PRESENT	0
569965	566531	14211G	PARTICIPANT	\N	PRESENT	0
569966	566531	19693L	PARTICIPANT	\N	PRESENT	0
569967	566531	14111D	PARTICIPANT	\N	PRESENT	0
569968	566531	14195A	PARTICIPANT	\N	PRESENT	0
569969	566531	11064N	PARTICIPANT	\N	PRESENT	0
569970	566531	19719D	PARTICIPANT	\N	PRESENT	0
569971	566531	20132W	PARTICIPANT	\N	PRESENT	0
569972	566531	10015M	PARTICIPANT	\N	PRESENT	0
569973	566531	20142Y	PARTICIPANT	\N	PRESENT	0
569974	566531	19515S	PARTICIPANT	\N	PRESENT	0
569975	566531	11080N	PARTICIPANT	\N	PRESENT	0
569976	566531	20134Y	PARTICIPANT	\N	PRESENT	0
569977	566531	19637C	PARTICIPANT	\N	PRESENT	0
569978	566531	20080C	PARTICIPANT	\N	PRESENT	0
569979	566531	12041X	PARTICIPANT	\N	PRESENT	0
569980	566531	04043D	PARTICIPANT	\N	PRESENT	0
569981	566531	04085P	PARTICIPANT	\N	PRESENT	0
569982	566531	11031D	PARTICIPANT	\N	PRESENT	0
569983	566531	20038A	PARTICIPANT	\N	PRESENT	0
569984	566531	10006L	PARTICIPANT	\N	PRESENT	0
569985	566531	11085T	PARTICIPANT	\N	PRESENT	0
569986	566531	20172F	PARTICIPANT	\N	PRESENT	0
569987	566531	20180F	PARTICIPANT	\N	PRESENT	0
569988	566531	19251M	PARTICIPANT	\N	PRESENT	0
569989	566531	20140W	PARTICIPANT	\N	PRESENT	0
569990	566531	07033P	PARTICIPANT	\N	PRESENT	0
569991	566531	17023S	PARTICIPANT	\N	PRESENT	0
569992	566531	20070A	PARTICIPANT	\N	PRESENT	0
569993	566531	19671E	PARTICIPANT	\N	PRESENT	0
569994	566531	14331P	PARTICIPANT	\N	PRESENT	0
569995	566531	19591F	PARTICIPANT	\N	PRESENT	0
569996	566531	11033F	PARTICIPANT	\N	PRESENT	0
569997	566531	14219Q	PARTICIPANT	\N	PRESENT	0
569998	566531	19369B	PARTICIPANT	\N	PRESENT	0
569999	566531	14357A	PARTICIPANT	\N	PRESENT	0
570000	566531	19507S	PARTICIPANT	\N	PRESENT	0
570001	566531	01028R	PARTICIPANT	\N	PRESENT	0
570002	566531	19701S	PARTICIPANT	\N	PRESENT	0
570003	566531	20104S	PARTICIPANT	\N	PRESENT	0
570004	566531	08015R	PARTICIPANT	\N	PRESENT	0
570005	566531	08018U	PARTICIPANT	\N	PRESENT	0
570006	566531	14041T	PARTICIPANT	\N	PRESENT	0
570007	566531	19467C	PARTICIPANT	\N	PRESENT	0
570008	566531	14038Y	PARTICIPANT	\N	PRESENT	0
570026	566531	20068G	PARTICIPANT	\N	PRESENT	0
570010	566531	17367Q	PARTICIPANT	\N	PRESENT	0
570011	566531	20124W	PARTICIPANT	\N	PRESENT	0
570012	566531	07029T	PARTICIPANT	\N	PRESENT	0
570013	566531	86034E	PARTICIPANT	\N	PRESENT	0
570014	566531	20126Y	PARTICIPANT	\N	PRESENT	0
570015	566531	19631V	PARTICIPANT	\N	PRESENT	0
570016	566531	11027H	PARTICIPANT	\N	PRESENT	0
570017	566531	14083S	PARTICIPANT	\N	PRESENT	0
570018	566531	19762G	PARTICIPANT	\N	PRESENT	0
570019	566531	19663E	PARTICIPANT	\N	PRESENT	0
570020	566531	19729F	PARTICIPANT	\N	PRESENT	0
570021	566531	14187A	PARTICIPANT	\N	PRESENT	0
570022	566531	04035D	PARTICIPANT	\N	PRESENT	0
570024	566531	04092N	PARTICIPANT	\N	PRESENT	0
570025	566531	14059S	PARTICIPANT	\N	PRESENT	0
570027	566531	95063L	PARTICIPANT	\N	PRESENT	0
570028	566531	14123H	PARTICIPANT	\N	PRESENT	0
570029	566531	01058X	PARTICIPANT	\N	PRESENT	0
570030	566531	08047A	PARTICIPANT	\N	PRESENT	0
570031	566531	19335Q	PARTICIPANT	\N	PRESENT	0
570032	566531	11066Q	PARTICIPANT	\N	PRESENT	0
570033	566531	11065P	PARTICIPANT	\N	PRESENT	0
570037	566531	19611R	PARTICIPANT	\N	PRESENT	0
570035	566531	14205J	PARTICIPANT	\N	PRESENT	0
570036	566531	19747H	PARTICIPANT	\N	PRESENT	0
570038	566531	20076G	PARTICIPANT	\N	PRESENT	0
570039	566531	19711U	PARTICIPANT	\N	PRESENT	0
570040	566531	04033B	PARTICIPANT	\N	PRESENT	0
570041	566531	20098N	PARTICIPANT	\N	PRESENT	0
570043	570042	17737W	PARTICIPANT	\N	PRESENT	0
570044	566531	07004J	PARTICIPANT	\N	PRESENT	0
548284	548279	19637C	PARTICIPANT	\N	PRESENT	0
548552	545415	99004R	PARTICIPANT	\N	PRESENT	0
548553	545415	20112S	PARTICIPANT	\N	PRESENT	0
548554	545415	19503N	PARTICIPANT	\N	PRESENT	0
548555	545415	19649G	PARTICIPANT	\N	PRESENT	0
548556	545415	19651A	PARTICIPANT	\N	PRESENT	0
548557	545415	19629C	PARTICIPANT	\N	PRESENT	0
548558	545415	07004J	PARTICIPANT	\N	PRESENT	0
548559	545415	14042U	PARTICIPANT	\N	PRESENT	0
548560	545415	19713W	PARTICIPANT	\N	PRESENT	0
548561	545415	19593H	PARTICIPANT	\N	PRESENT	0
548562	545415	04043D	PARTICIPANT	\N	PRESENT	0
548563	545415	19711U	PARTICIPANT	\N	PRESENT	0
548564	545415	14055N	PARTICIPANT	\N	PRESENT	0
548565	545415	19367Y	PARTICIPANT	\N	PRESENT	0
548566	545415	19581D	PARTICIPANT	\N	PRESENT	0
548567	545415	20074E	PARTICIPANT	\N	PRESENT	0
548568	545415	20152B	PARTICIPANT	\N	PRESENT	0
548569	545415	19447X	PARTICIPANT	\N	PRESENT	0
548570	545415	07029T	PARTICIPANT	\N	PRESENT	0
548571	545415	20108W	PARTICIPANT	\N	PRESENT	0
548572	545415	04047H	PARTICIPANT	\N	PRESENT	0
548573	545415	19749K	PARTICIPANT	\N	PRESENT	0
548574	545415	19673G	PARTICIPANT	\N	PRESENT	0
548575	545415	14215L	PARTICIPANT	\N	PRESENT	0
548576	545415	11033F	PARTICIPANT	\N	PRESENT	0
548577	545415	19689Q	PARTICIPANT	\N	PRESENT	0
548578	545415	20130U	PARTICIPANT	\N	PRESENT	0
548579	545415	11027H	PARTICIPANT	\N	PRESENT	0
548580	545415	14021P	PARTICIPANT	\N	PRESENT	0
548581	545415	01028R	PARTICIPANT	\N	PRESENT	0
548582	545415	11031D	PARTICIPANT	\N	PRESENT	0
548583	545415	19758L	PARTICIPANT	\N	PRESENT	0
548584	545415	20122U	PARTICIPANT	\N	PRESENT	0
548585	545415	19741B	PARTICIPANT	\N	PRESENT	0
548586	545415	17737W	PARTICIPANT	\N	PRESENT	0
548587	545415	19621T	PARTICIPANT	\N	PRESENT	0
548588	545415	19565D	PARTICIPANT	\N	PRESENT	0
548589	545415	11012A	PARTICIPANT	\N	PRESENT	0
548590	545415	14219Q	PARTICIPANT	\N	PRESENT	0
548591	545415	14053L	PARTICIPANT	\N	PRESENT	0
548592	545415	19671E	PARTICIPANT	\N	PRESENT	0
548593	545415	20022R	PARTICIPANT	\N	PRESENT	0
548594	545415	14109K	PARTICIPANT	\N	PRESENT	0
548595	545415	05008E	PARTICIPANT	\N	PRESENT	0
548596	545415	04086Q	PARTICIPANT	\N	PRESENT	0
548597	545415	08010L	PARTICIPANT	\N	PRESENT	0
548598	545415	19533U	PARTICIPANT	\N	PRESENT	0
548599	545415	01048V	PARTICIPANT	\N	PRESENT	0
548600	545415	20058E	PARTICIPANT	\N	PRESENT	0
548601	545415	08034U	PARTICIPANT	\N	PRESENT	0
548602	545415	04085P	PARTICIPANT	\N	PRESENT	0
548603	545415	19687N	PARTICIPANT	\N	PRESENT	0
548652	548649	19739H	PARTICIPANT	\N	PRESENT	0
548653	548649	19619A	PARTICIPANT	\N	PRESENT	0
548654	548649	20070A	PARTICIPANT	\N	PRESENT	0
548655	548649	19820Y	PARTICIPANT	\N	PRESENT	0
548656	548649	19503N	PARTICIPANT	\N	PRESENT	0
548657	548649	19782L	PARTICIPANT	\N	PRESENT	0
548658	548649	20092G	PARTICIPANT	\N	PRESENT	0
548659	545414	11070L	PARTICIPANT	\N	PRESENT	0
548660	545414	19503N	PARTICIPANT	\N	PRESENT	0
548661	545414	19649G	PARTICIPANT	\N	PRESENT	0
548662	545414	04047H	PARTICIPANT	\N	PRESENT	0
548663	545414	19749K	PARTICIPANT	\N	PRESENT	0
548664	545414	19673G	PARTICIPANT	\N	PRESENT	0
548665	545414	11033F	PARTICIPANT	\N	PRESENT	0
548666	545414	20112S	PARTICIPANT	\N	PRESENT	0
548667	545414	11031D	PARTICIPANT	\N	PRESENT	0
548668	545414	19717B	PARTICIPANT	\N	PRESENT	0
548669	545414	11012A	PARTICIPANT	\N	PRESENT	0
548670	545414	19629C	PARTICIPANT	\N	PRESENT	0
548671	545414	20034V	PARTICIPANT	\N	PRESENT	0
548672	545414	19543W	PARTICIPANT	\N	PRESENT	0
548673	545414	20074E	PARTICIPANT	\N	PRESENT	0
548674	545414	07004J	PARTICIPANT	\N	PRESENT	0
548675	545414	20022R	PARTICIPANT	\N	PRESENT	0
548676	545414	19671E	PARTICIPANT	\N	PRESENT	0
548677	545414	20152B	PARTICIPANT	\N	PRESENT	0
548678	545414	14055N	PARTICIPANT	\N	PRESENT	0
548679	545414	17737W	PARTICIPANT	\N	PRESENT	0
548680	545414	19533U	PARTICIPANT	\N	PRESENT	0
548681	545414	20108W	PARTICIPANT	\N	PRESENT	0
548682	545414	19447X	PARTICIPANT	\N	PRESENT	0
548683	545414	19741B	PARTICIPANT	\N	PRESENT	0
548684	545414	19621T	PARTICIPANT	\N	PRESENT	0
548685	545414	14219Q	PARTICIPANT	\N	PRESENT	0
548686	545414	14053L	PARTICIPANT	\N	PRESENT	0
548687	545414	19647E	PARTICIPANT	\N	PRESENT	0
548688	545414	19651A	PARTICIPANT	\N	PRESENT	0
548689	545414	19758L	PARTICIPANT	\N	PRESENT	0
548690	545414	20130U	PARTICIPANT	\N	PRESENT	0
548691	545414	11027H	PARTICIPANT	\N	PRESENT	0
548692	545414	20124W	PARTICIPANT	\N	PRESENT	0
548693	545414	20122U	PARTICIPANT	\N	PRESENT	0
548694	545414	05008E	PARTICIPANT	\N	PRESENT	0
548695	545414	19687N	PARTICIPANT	\N	PRESENT	0
548696	545414	04085P	PARTICIPANT	\N	PRESENT	0
548650	548649	14357A	PARTICIPANT	\N	PRESENT	0
548651	548649	19711U	PARTICIPANT	\N	PRESENT	0
548697	545414	11077T	PARTICIPANT	\N	PRESENT	0
548519	545412	07029T	PARTICIPANT	\N	PRESENT	0
548698	545414	19689Q	PARTICIPANT	\N	PRESENT	0
548699	545414	20114U	PARTICIPANT	\N	PRESENT	0
548700	545414	14215L	PARTICIPANT	\N	PRESENT	0
548701	545414	14109K	PARTICIPANT	\N	PRESENT	0
548702	545414	01028R	PARTICIPANT	\N	PRESENT	0
548703	545414	14231L	PARTICIPANT	\N	PRESENT	0
548704	545414	17637T	PARTICIPANT	\N	PRESENT	0
548705	545414	08011M	PARTICIPANT	\N	PRESENT	0
548706	545414	14021P	PARTICIPANT	\N	PRESENT	0
548707	545414	19599P	PARTICIPANT	\N	PRESENT	0
548708	545414	20058E	PARTICIPANT	\N	PRESENT	0
548709	545414	14259Y	PARTICIPANT	\N	PRESENT	0
548785	545942	19723Y	PARTICIPANT	\N	PRESENT	0
549317	549315	20114U	PARTICIPANT	\N	PRESENT	0
549318	549315	14255U	PARTICIPANT	\N	PRESENT	0
549319	549315	04042C	PARTICIPANT	\N	PRESENT	0
549320	549315	07033P	PARTICIPANT	\N	PRESENT	0
549321	549315	14327T	PARTICIPANT	\N	PRESENT	0
549322	549315	14281W	PARTICIPANT	\N	PRESENT	0
549323	549315	08056B	PARTICIPANT	\N	PRESENT	0
549324	549315	19565D	PARTICIPANT	\N	PRESENT	0
549325	549315	04070G	PARTICIPANT	\N	PRESENT	0
549326	549315	14073Q	PARTICIPANT	\N	PRESENT	0
549327	549315	99004R	PARTICIPANT	\N	PRESENT	0
549328	549315	14179A	PARTICIPANT	\N	PRESENT	0
549329	549315	11026G	PARTICIPANT	\N	PRESENT	0
550017	547779	19543W	PARTICIPANT	\N	PRESENT	1
550020	547779	20110Q	PARTICIPANT	\N	PRESENT	1
550021	547779	20114U	PARTICIPANT	\N	PRESENT	1
550024	547779	04008A	PARTICIPANT	\N	PRESENT	1
550026	547779	14151M	PARTICIPANT	\N	PRESENT	1
550028	547779	19489J	PARTICIPANT	\N	PRESENT	1
550029	547779	19581D	PARTICIPANT	\N	PRESENT	1
550030	547779	14107H	PARTICIPANT	\N	PRESENT	1
550032	547779	19749K	PARTICIPANT	\N	PRESENT	1
550060	547780	20110Q	PARTICIPANT	\N	PRESENT	1
550061	547780	14069U	PARTICIPANT	\N	PRESENT	1
550064	547780	20114U	PARTICIPANT	\N	PRESENT	1
550066	547780	14053L	PARTICIPANT	\N	PRESENT	1
550068	547780	04008A	PARTICIPANT	\N	PRESENT	1
550070	547780	20074E	PARTICIPANT	\N	PRESENT	1
550073	547780	14179A	PARTICIPANT	\N	PRESENT	1
550077	547780	19749K	PARTICIPANT	\N	PRESENT	1
550085	547779	20074E	PARTICIPANT	\N	EXCUSE	0
550136	547780	19581D	PARTICIPANT	\N	PRESENT	1
551061	545745	20094J	PARTICIPANT	\N	PRESENT	0
551062	545745	14207L	PARTICIPANT	\N	PRESENT	1
551063	545745	14357A	PARTICIPANT	\N	PRESENT	0
551064	545745	14189C	PARTICIPANT	\N	PRESENT	0
551065	545745	20100N	PARTICIPANT	\N	PRESENT	0
551066	545745	04035D	PARTICIPANT	\N	PRESENT	1
551067	545745	11083R	PARTICIPANT	\N	PRESENT	1
551068	545745	14033T	PARTICIPANT	\N	PRESENT	1
551069	545745	19725B	PARTICIPANT	\N	PRESENT	1
551070	545745	20128B	PARTICIPANT	\N	PRESENT	1
551071	545745	14073Q	PARTICIPANT	\N	PRESENT	0
551072	545745	11026G	PARTICIPANT	\N	PRESENT	0
551073	545745	14001X	PARTICIPANT	\N	PRESENT	0
551074	545745	04057K	PARTICIPANT	\N	PRESENT	0
549814	549253	11109J	PARTICIPANT	\N	EXCUSE	0
549815	549253	14109K	PARTICIPANT	\N	PRESENT	0
549816	549253	11043H	PARTICIPANT	\N	PRESENT	0
550113	550112	14193X	PARTICIPANT	\N	PRESENT	0
550114	550112	11054L	PARTICIPANT	\N	PRESENT	0
550115	550112	01058X	PARTICIPANT	\N	PRESENT	0
550116	550112	20042V	PARTICIPANT	\N	PRESENT	0
551521	551520	14267Y	PARTICIPANT	\N	PRESENT	0
551522	551520	12028B	PARTICIPANT	\N	PRESENT	0
551523	551520	97011G	PARTICIPANT	\N	PRESENT	0
551524	551520	14105F	PARTICIPANT	\N	PRESENT	0
551529	551528	99004R	PARTICIPANT	\N	PRESENT	0
551531	551530	20070A	PARTICIPANT	\N	PRESENT	0
551533	551532	20070A	PARTICIPANT	\N	PRESENT	0
551535	551534	20070A	PARTICIPANT	\N	PRESENT	0
551648	551647	04047H	PARTICIPANT	\N	PRESENT	0
551650	551649	04047H	PARTICIPANT	\N	PRESENT	0
556160	554923	20130U	PARTICIPANT	\N	PRESENT	1
556161	554923	19553Y	PARTICIPANT	\N	PRESENT	1
556162	554923	01034P	PARTICIPANT	\N	PRESENT	1
556163	554923	04057K	PARTICIPANT	\N	PRESENT	1
556164	554923	19569H	PARTICIPANT	\N	PRESENT	1
556165	554923	20066E	PARTICIPANT	\N	PRESENT	1
556166	554923	11103C	PARTICIPANT	\N	PRESENT	1
556167	554923	14213J	PARTICIPANT	\N	PRESENT	1
556168	554923	19657G	PARTICIPANT	\N	PRESENT	1
556169	554923	18193Q	PARTICIPANT	\N	PRESENT	1
556190	554670	20074E	PARTICIPANT	\N	PRESENT	0
556191	554670	14215L	PRESIDENT	1	PRESENT	0
556192	554670	14231L	PARTICIPANT	\N	PRESENT	0
556193	554670	14147R	PARTICIPANT	\N	PRESENT	0
556194	554670	14053L	PARTICIPANT	\N	PRESENT	0
556195	554670	19749K	PARTICIPANT	\N	PRESENT	0
556196	554670	18083K	PARTICIPANT	\N	PRESENT	0
556197	554670	14259Y	PARTICIPANT	\N	PRESENT	0
556198	554670	14021P	PARTICIPANT	\N	PRESENT	0
556199	554670	19954N	PARTICIPANT	\N	PRESENT	0
556201	554670	04047H	PRESIDENT	0	PRESENT	0
556202	554670	01028R	PARTICIPANT	\N	PRESENT	0
556203	554670	20110Q	PARTICIPANT	\N	PRESENT	0
556207	554670	19447X	PARTICIPANT	\N	PRESENT	0
556208	554670	14089Y	PARTICIPANT	\N	PRESENT	0
556209	554670	14111D	PARTICIPANT	\N	PRESENT	0
556210	554670	19543W	PARTICIPANT	\N	PRESENT	0
556211	554670	05008E	PARTICIPANT	\N	PRESENT	0
556212	554670	20114U	PARTICIPANT	\N	PRESENT	0
556213	555342	11040E	PARTICIPANT	\N	PRESENT	0
556214	555342	04086Q	PARTICIPANT	\N	PRESENT	0
556215	555342	14331P	PARTICIPANT	\N	PRESENT	0
556216	555342	14083S	PARTICIPANT	\N	PRESENT	0
556217	555342	11048N	PARTICIPANT	\N	PRESENT	0
556218	555342	01048V	PARTICIPANT	\N	PRESENT	0
556219	555342	08009T	PARTICIPANT	\N	PRESENT	0
556220	555342	20080C	PARTICIPANT	\N	PRESENT	0
556221	555342	19667J	PARTICIPANT	\N	PRESENT	0
556222	555342	14225N	PRESIDENT	0	PRESENT	0
556223	555342	19671E	PARTICIPANT	\N	PRESENT	0
556224	555342	20116W	PARTICIPANT	\N	PRESENT	0
556225	555342	19762G	PARTICIPANT	\N	PRESENT	0
556226	554670	11085T	PARTICIPANT	\N	PRESENT	0
556227	554670	95063L	PARTICIPANT	\N	PRESENT	0
556228	554670	19729F	PARTICIPANT	\N	PRESENT	0
556229	554670	14151M	PARTICIPANT	\N	PRESENT	0
556230	554670	11026G	PARTICIPANT	\N	PRESENT	0
556231	554670	19725B	PARTICIPANT	\N	PRESENT	0
556232	555342	19647E	PARTICIPANT	\N	PRESENT	0
556233	555342	14189C	PARTICIPANT	\N	PRESENT	0
556234	555342	01057W	PARTICIPANT	\N	PRESENT	0
556235	555342	20070A	PARTICIPANT	\N	PRESENT	0
556236	555342	19349W	PARTICIPANT	\N	PRESENT	0
556237	555342	14253S	PARTICIPANT	\N	PRESENT	0
556238	555342	19335Q	PARTICIPANT	\N	PRESENT	0
556239	555342	19479G	PARTICIPANT	\N	PRESENT	0
556240	555342	20044X	PARTICIPANT	\N	PRESENT	0
556241	555354	19383Y	PARTICIPANT	\N	PRESENT	0
556242	555354	20088L	PARTICIPANT	\N	PRESENT	1
556243	555354	19768N	PARTICIPANT	\N	PRESENT	1
556244	555354	19515S	PARTICIPANT	\N	PRESENT	1
556245	555354	19782L	PARTICIPANT	\N	PRESENT	1
556246	555354	14357A	PARTICIPANT	\N	PRESENT	0
556247	555354	20078J	PARTICIPANT	\N	PRESENT	0
556248	555354	19441R	PARTICIPANT	\N	PRESENT	1
556249	555354	20082E	PARTICIPANT	\N	PRESENT	0
556250	555354	04045F	PARTICIPANT	\N	PRESENT	0
556251	555354	19631V	PARTICIPANT	\N	PRESENT	0
556252	555354	19705W	PARTICIPANT	\N	PRESENT	0
556253	555354	08015R	PARTICIPANT	\N	PRESENT	0
556254	555354	19575F	PARTICIPANT	\N	PRESENT	0
556255	555354	19369B	PARTICIPANT	\N	PRESENT	1
556256	555354	19511N	PARTICIPANT	\N	PRESENT	0
556257	555354	08028W	PARTICIPANT	\N	PRESENT	0
556258	555354	14329V	PARTICIPANT	\N	PRESENT	1
556259	555354	14038Y	PARTICIPANT	\N	PRESENT	1
556260	555354	19467C	PARTICIPANT	\N	PRESENT	0
556261	555354	14187A	PARTICIPANT	\N	PRESENT	0
556262	555354	20144B	PARTICIPANT	\N	PRESENT	0
556263	555354	19695N	PARTICIPANT	\N	PRESENT	0
556264	555354	14033T	PARTICIPANT	\N	PRESENT	1
556265	555354	11090Q	PRESIDENT	0	PRESENT	0
556266	555354	01025N	PARTICIPANT	\N	PRESENT	1
556267	555354	20174H	PARTICIPANT	\N	PRESENT	1
556268	555354	20062A	PARTICIPANT	\N	PRESENT	0
556269	555354	14251Q	PARTICIPANT	\N	PRESENT	1
556270	555354	19507S	PARTICIPANT	\N	PRESENT	0
556271	555354	14207L	PARTICIPANT	\N	PRESENT	1
556272	555354	19747H	PARTICIPANT	\N	PRESENT	1
556273	555354	14257W	PARTICIPANT	\N	PRESENT	1
556274	554670	11056N	PARTICIPANT	\N	PRESENT	0
556275	555354	19413M	PARTICIPANT	\N	PRESENT	1
556276	555354	20060X	PARTICIPANT	\N	PRESENT	1
556279	555857	19333N	PARTICIPANT	\N	PRESENT	0
556280	555857	19701S	PARTICIPANT	\N	PRESENT	0
556281	555857	20076G	PARTICIPANT	\N	PRESENT	0
556282	555857	19549D	PARTICIPANT	\N	PRESENT	0
556283	555857	19820Y	PARTICIPANT	\N	PRESENT	0
556284	555857	19826F	PARTICIPANT	\N	PRESENT	0
556285	555857	14221J	PARTICIPANT	\N	PRESENT	0
556286	555857	20102Q	PARTICIPANT	\N	PRESENT	0
556287	555857	19599P	PARTICIPANT	\N	PRESENT	0
556288	555857	20096L	PARTICIPANT	\N	PRESENT	0
556289	555857	14237S	PARTICIPANT	\N	PRESENT	0
556290	555857	20100N	PARTICIPANT	\N	PRESENT	0
556291	555857	05012A	PARTICIPANT	\N	PRESENT	0
556292	555857	20118Y	PARTICIPANT	\N	PRESENT	0
556293	555857	19503N	PARTICIPANT	\N	PRESENT	0
556294	555857	20020P	PARTICIPANT	\N	PRESENT	0
556295	555857	20024T	PARTICIPANT	\N	PRESENT	0
556296	555857	14031R	PARTICIPANT	\N	PRESENT	0
556297	555857	20038A	PARTICIPANT	\N	PRESENT	0
556298	555857	20140W	PARTICIPANT	\N	PRESENT	0
556299	555857	19251M	PARTICIPANT	\N	PRESENT	0
556300	555857	20046A	PARTICIPANT	\N	PRESENT	0
556301	555857	17229F	PARTICIPANT	\N	PRESENT	0
556302	555857	14169X	PARTICIPANT	\N	PRESENT	0
556303	555857	20068G	PARTICIPANT	\N	PRESENT	0
556304	555857	19745F	PARTICIPANT	\N	PRESENT	0
556305	555857	19619A	PARTICIPANT	\N	PRESENT	0
556307	555857	19551W	PARTICIPANT	\N	PRESENT	1
556308	555857	20032T	PARTICIPANT	\N	PRESENT	1
556309	554670	08018U	PARTICIPANT	\N	PRESENT	0
556310	555342	11070L	PARTICIPANT	\N	PRESENT	0
556311	555342	19687N	PARTICIPANT	\N	PRESENT	0
556312	555342	19689Q	PARTICIPANT	\N	PRESENT	0
556313	555342	08034U	PARTICIPANT	\N	PRESENT	0
556321	555857	14219Q	PRESIDENT	0	PRESENT	0
556322	555857	20136B	PARTICIPANT	\N	PRESENT	0
556326	555354	11099A	PARTICIPANT	\N	PRESENT	0
556327	555354	14205J	PARTICIPANT	\N	PRESENT	0
556328	555342	20126Y	PARTICIPANT	\N	PRESENT	0
556329	555354	01043Q	PARTICIPANT	\N	PRESENT	1
556330	555354	20094J	PARTICIPANT	\N	PRESENT	0
556332	554670	14179A	PARTICIPANT	\N	PRESENT	0
556363	555354	20018V	PARTICIPANT	\N	PRESENT	1
556391	555398	12041X	PARTICIPANT	\N	PRESENT	0
556392	555398	19443T	PARTICIPANT	\N	PRESENT	1
556393	555398	19565D	PARTICIPANT	\N	PRESENT	0
556394	555398	20072C	PARTICIPANT	\N	PRESENT	1
556395	555398	04034C	PARTICIPANT	\N	PRESENT	0
556396	555398	01058X	PARTICIPANT	\N	PRESENT	0
556397	555398	16685X	PARTICIPANT	\N	PRESENT	0
556398	555398	04042C	PRESIDENT	0	PRESENT	0
560888	559728	14223L	PARTICIPANT	\N	PRESENT	0
560889	559728	14026U	PARTICIPANT	\N	PRESENT	0
560890	559728	17779H	PARTICIPANT	\N	PRESENT	0
560891	559728	19551W	PARTICIPANT	\N	PRESENT	0
560892	559728	11031D	PARTICIPANT	\N	PRESENT	0
560893	559728	19553Y	PARTICIPANT	\N	PRESENT	0
560894	559728	19679N	PARTICIPANT	\N	PRESENT	0
560895	559728	14042U	PARTICIPANT	\N	PRESENT	0
560896	559728	17965H	PARTICIPANT	\N	PRESENT	0
560897	559728	19691J	PARTICIPANT	\N	PRESENT	0
560898	559728	20172F	PARTICIPANT	\N	PRESENT	0
560899	559728	20066E	PARTICIPANT	\N	PRESENT	0
560900	559728	11103C	PARTICIPANT	\N	PRESENT	0
560901	559728	14071N	PARTICIPANT	0	PRESENT	0
560902	559728	19657G	PARTICIPANT	\N	PRESENT	0
560903	559728	04043D	PARTICIPANT	\N	PRESENT	0
560904	559728	01034P	PARTICIPANT	\N	PRESENT	0
560905	559728	04057K	PARTICIPANT	\N	PRESENT	0
560906	559728	04092N	PARTICIPANT	\N	PRESENT	0
560907	559728	19713W	PARTICIPANT	\N	PRESENT	0
560908	559728	08045X	PARTICIPANT	\N	PRESENT	0
560909	559728	20040T	PARTICIPANT	\N	PRESENT	0
560910	559728	19663E	PARTICIPANT	\N	PRESENT	0
560911	559728	19301E	PARTICIPANT	\N	PRESENT	0
560912	559728	19760E	PARTICIPANT	\N	PRESENT	0
560913	559728	18193Q	PARTICIPANT	\N	EXCUSE	0
560914	559728	19295A	PARTICIPANT	\N	EXCUSE	0
561187	561186	14205J	PARTICIPANT	\N	PRESENT	0
561189	561186	04045F	PARTICIPANT	\N	PRESENT	0
561192	561190	14205J	PARTICIPANT	\N	PRESENT	0
561604	561567	14255U	PARTICIPANT	\N	PRESENT	0
561605	558912	14193X	PARTICIPANT	\N	PRESENT	0
561606	561567	14041T	PARTICIPANT	\N	PRESENT	0
561607	558912	14267Y	PARTICIPANT	\N	PRESENT	0
561608	561567	19735D	PARTICIPANT	\N	EXCUSE	0
561609	558912	16685X	PARTICIPANT	\N	PRESENT	0
561610	558912	19575F	PARTICIPANT	\N	PRESENT	0
561611	558912	14033T	PARTICIPANT	\N	PRESENT	0
561614	561613	19251M	PARTICIPANT	\N	PRESENT	0
561615	561613	19515S	PARTICIPANT	\N	PRESENT	0
561616	561613	19782L	PARTICIPANT	\N	PRESENT	0
561617	561613	11064N	PARTICIPANT	\N	PRESENT	0
561620	561619	08069G	PARTICIPANT	\N	PRESENT	0
561621	561619	14133K	PARTICIPANT	\N	PRESENT	0
561622	561619	10015M	PARTICIPANT	\N	PRESENT	0
561623	561619	17367Q	PARTICIPANT	\N	PRESENT	0
561641	559635	20112S	PARTICIPANT	\N	EXCUSE	0
561642	559635	11109J	PARTICIPANT	\N	EXCUSE	0
561643	559635	19758L	PARTICIPANT	\N	EXCUSE	0
561644	559635	19593H	PARTICIPANT	\N	EXCUSE	0
561651	558912	14105F	PARTICIPANT	\N	PRESENT	1
561652	558912	19421M	PARTICIPANT	\N	PRESENT	1
561653	558912	19782L	PARTICIPANT	\N	PRESENT	1
561654	558912	01058X	PARTICIPANT	\N	PRESENT	1
561655	558912	11077T	PARTICIPANT	\N	PRESENT	1
561656	558912	19721W	PARTICIPANT	\N	PRESENT	1
561657	558912	19467C	PARTICIPANT	\N	PRESENT	1
561658	558912	20174H	PARTICIPANT	\N	PRESENT	1
561659	558912	20030R	PARTICIPANT	\N	PRESENT	1
561660	558912	01024M	PARTICIPANT	\N	PRESENT	1
561661	558912	20062A	PARTICIPANT	\N	PRESENT	0
561662	558912	19705W	PARTICIPANT	\N	PRESENT	0
561663	558912	01025N	PARTICIPANT	\N	PRESENT	0
561664	558912	20144B	PARTICIPANT	\N	PRESENT	0
561665	558912	19441R	PARTICIPANT	\N	PRESENT	0
561676	558912	19747H	PARTICIPANT	\N	PRESENT	0
561679	558912	19515S	PARTICIPANT	\N	PRESENT	0
561706	558912	14205J	PARTICIPANT	\N	PRESENT	1
561758	559657	11045K	PARTICIPANT	\N	PRESENT	0
561767	559657	14215L	PARTICIPANT	\N	PRESENT	0
561768	559657	19673G	PARTICIPANT	\N	PRESENT	0
561769	559657	19629C	PARTICIPANT	\N	PRESENT	0
561770	559657	20052X	PARTICIPANT	\N	PRESENT	0
561771	559657	19553Y	PARTICIPANT	\N	PRESENT	0
561772	559657	17589D	PARTICIPANT	\N	PRESENT	0
561773	559657	14073Q	PARTICIPANT	\N	PRESENT	0
561774	559657	19415P	PARTICIPANT	\N	PRESENT	0
561775	559657	19649G	PARTICIPANT	\N	PRESENT	0
561776	559657	20084G	PARTICIPANT	\N	PRESENT	0
561777	559657	19758L	PARTICIPANT	\N	PRESENT	0
561778	559657	20110Q	PARTICIPANT	\N	PRESENT	0
561779	559657	20180F	PARTICIPANT	\N	PRESENT	0
561780	559657	19954N	PARTICIPANT	\N	PRESENT	0
561781	559657	19699S	PARTICIPANT	\N	PRESENT	0
561782	559657	20134Y	PARTICIPANT	\N	PRESENT	0
561783	559657	04045F	PARTICIPANT	\N	PRESENT	0
561784	559657	19533U	PARTICIPANT	\N	PRESENT	0
561785	559657	20116W	PARTICIPANT	\N	PRESENT	0
561786	559657	14089Y	PARTICIPANT	\N	PRESENT	0
561787	559657	04047H	PARTICIPANT	\N	PRESENT	0
561788	559657	19667J	PARTICIPANT	\N	PRESENT	0
561789	559657	19747H	PARTICIPANT	\N	PRESENT	0
561806	559657	20132W	PARTICIPANT	\N	PRESENT	0
561791	559657	20106U	PARTICIPANT	\N	PRESENT	0
561792	559657	19611R	PARTICIPANT	\N	PRESENT	0
561839	559658	19699S	PARTICIPANT	\N	PRESENT	0
561841	559658	20084G	PARTICIPANT	\N	PRESENT	0
561844	559658	19593H	PARTICIPANT	\N	PRESENT	0
561847	559658	19611R	PARTICIPANT	\N	PRESENT	0
561848	559658	20110Q	PARTICIPANT	\N	PRESENT	0
561850	559658	20134Y	PARTICIPANT	\N	PRESENT	0
561852	559658	19758L	PARTICIPANT	\N	PRESENT	0
561854	559658	20106U	PARTICIPANT	\N	PRESENT	0
561856	559658	19629C	PARTICIPANT	\N	PRESENT	0
561858	559658	19553Y	PARTICIPANT	\N	PRESENT	0
561860	559658	20132W	PARTICIPANT	\N	PRESENT	0
561861	559658	20116W	PARTICIPANT	\N	PRESENT	0
561862	559658	20058E	PARTICIPANT	\N	PRESENT	0
561863	559658	19711U	PARTICIPANT	\N	PRESENT	0
561864	559658	20180F	PARTICIPANT	\N	PRESENT	0
561865	559658	19954N	PARTICIPANT	\N	PRESENT	0
561866	559658	14073Q	PARTICIPANT	\N	PRESENT	0
561867	559658	18083K	PARTICIPANT	\N	PRESENT	0
561868	559658	19667J	PARTICIPANT	\N	PRESENT	0
561869	559658	19415P	PARTICIPANT	\N	PRESENT	0
561870	559658	20152B	PARTICIPANT	\N	PRESENT	0
561871	559658	11026G	PARTICIPANT	\N	PRESENT	0
561872	559658	14229S	PARTICIPANT	\N	PRESENT	0
561873	559658	19747H	PARTICIPANT	\N	PRESENT	0
561874	559658	20142Y	PARTICIPANT	\N	PRESENT	0
561877	559658	19621T	PARTICIPANT	\N	PRESENT	0
561833	559658	11045K	PARTICIPANT	\N	PRESENT	0
561834	559658	20052X	PARTICIPANT	\N	PRESENT	0
561878	559658	11043H	PARTICIPANT	\N	PRESENT	0
561879	559658	19399H	PARTICIPANT	\N	PRESENT	0
561880	559658	04059M	PARTICIPANT	\N	PRESENT	0
561881	559658	14259Y	PARTICIPANT	\N	PRESENT	0
561882	559658	11085T	PARTICIPANT	\N	PRESENT	0
561885	559658	17589D	PARTICIPANT	\N	PRESENT	0
561888	559658	14147R	PARTICIPANT	\N	PRESENT	0
561891	559658	19651A	PARTICIPANT	\N	PRESENT	0
561894	559658	14030Q	PARTICIPANT	\N	PRESENT	0
561895	559658	20112S	PARTICIPANT	\N	PRESENT	0
561925	559661	20084G	PARTICIPANT	\N	PRESENT	0
561926	559661	20142Y	PARTICIPANT	\N	PRESENT	0
561927	559661	20134Y	PARTICIPANT	\N	PRESENT	0
561928	559661	17589D	PARTICIPANT	\N	PRESENT	0
561929	559661	19651A	PARTICIPANT	\N	PRESENT	0
561930	559661	20116W	PARTICIPANT	\N	PRESENT	0
561931	559661	20132W	PARTICIPANT	\N	PRESENT	0
561932	559661	19553Y	PARTICIPANT	\N	PRESENT	0
561933	559661	19699S	PARTICIPANT	\N	PRESENT	0
561934	559661	04070G	PARTICIPANT	\N	PRESENT	0
561935	559661	20152B	PARTICIPANT	\N	PRESENT	0
561936	559661	11043H	PARTICIPANT	\N	PRESENT	0
561937	559661	19621T	PARTICIPANT	\N	PRESENT	0
561938	559661	14147R	PARTICIPANT	\N	PRESENT	0
561939	559661	19711U	PARTICIPANT	\N	PRESENT	0
561940	559661	20058E	PARTICIPANT	\N	PRESENT	0
561941	559661	19611R	PARTICIPANT	\N	PRESENT	0
561942	559661	19399H	PARTICIPANT	\N	PRESENT	0
561944	559661	19629C	PARTICIPANT	\N	PRESENT	0
561945	559661	19747H	PARTICIPANT	\N	PRESENT	0
561972	559661	20112S	PARTICIPANT	\N	PRESENT	0
561973	559661	19593H	PARTICIPANT	\N	PRESENT	0
561974	559661	04059M	PARTICIPANT	\N	PRESENT	0
561975	559661	14207L	PARTICIPANT	\N	PRESENT	0
561976	559661	20048C	PARTICIPANT	\N	PRESENT	0
561923	559661	11045K	PARTICIPANT	\N	PRESENT	0
561924	559661	14229S	PARTICIPANT	\N	PRESENT	0
542929	537066	14219Q	PARTICIPANT	\N	EXCUSE	0
542931	537066	11010L	PARTICIPANT	\N	EXCUSE	0
542932	537069	11010L	PARTICIPANT	\N	EXCUSE	0
542933	537069	14219Q	PARTICIPANT	\N	EXCUSE	0
542944	537069	05008E	PARTICIPANT	\N	EXCUSE	0
542946	537066	05008E	PARTICIPANT	\N	EXCUSE	0
543202	543201	19251M	PARTICIPANT	\N	PRESENT	0
543203	543201	97011G	PARTICIPANT	\N	PRESENT	0
543204	543201	19711U	PARTICIPANT	\N	PRESENT	0
543205	543201	19593H	PARTICIPANT	\N	PRESENT	0
543206	543201	20064C	PARTICIPANT	\N	PRESENT	0
543269	543268	11072N	PARTICIPANT	\N	PRESENT	0
543278	543274	11072N	PARTICIPANT	\N	PRESENT	0
545082	542443	14231L	PRESIDENT	0	PRESENT	0
545083	542443	14069U	PARTICIPANT	\N	PRESENT	1
545085	542443	20120S	PARTICIPANT	\N	PRESENT	1
545086	542443	14257W	PARTICIPANT	\N	PRESENT	1
545087	542443	19826F	PARTICIPANT	\N	PRESENT	1
545088	542443	04045F	PARTICIPANT	\N	PRESENT	1
545090	542443	20122U	PARTICIPANT	\N	PRESENT	1
545091	542443	14107H	PARTICIPANT	\N	PRESENT	1
545092	542443	19565D	PARTICIPANT	\N	PRESENT	1
545093	542443	19735D	PARTICIPANT	\N	PRESENT	1
545095	542443	14205J	PARTICIPANT	\N	PRESENT	1
545096	542443	20058E	PARTICIPANT	\N	PRESENT	0
545097	542443	19758L	PARTICIPANT	\N	PRESENT	0
545099	542443	20090E	PARTICIPANT	\N	PRESENT	0
545100	542443	01057W	PARTICIPANT	\N	PRESENT	0
545101	542443	20022R	PARTICIPANT	\N	PRESENT	0
545102	542443	05012A	PARTICIPANT	\N	PRESENT	0
545103	542443	19349W	PARTICIPANT	\N	PRESENT	0
545104	542443	08010L	PARTICIPANT	\N	PRESENT	0
545105	542443	20110Q	PARTICIPANT	\N	PRESENT	0
545106	542443	17637T	PARTICIPANT	\N	PRESENT	0
545107	542443	14327T	PARTICIPANT	\N	EXCUSE	0
545108	542443	14215L	PARTICIPANT	\N	EXCUSE	0
545109	542443	04086Q	PARTICIPANT	\N	EXCUSE	0
545110	542443	14071N	PARTICIPANT	\N	EXCUSE	0
545111	542443	14229S	PARTICIPANT	\N	EXCUSE	0
548869	548867	19531S	PARTICIPANT	\N	PRESENT	0
548870	548867	19762G	PARTICIPANT	\N	PRESENT	0
548871	548868	19531S	PARTICIPANT	\N	PRESENT	0
548872	548868	19762G	PARTICIPANT	\N	PRESENT	0
548876	548874	19531S	PARTICIPANT	\N	PRESENT	0
548877	548874	19762G	PARTICIPANT	\N	PRESENT	0
548884	548883	11053K	PARTICIPANT	\N	PRESENT	0
555848	555847	17779H	PARTICIPANT	\N	PRESENT	1
556004	555847	11067R	PARTICIPANT	\N	PRESENT	1
556515	553250	01028R	PARTICIPANT	\N	EXCUSE	0
557085	553250	19399H	PARTICIPANT	\N	PRESENT	0
557216	557215	19701S	PARTICIPANT	\N	PRESENT	0
557218	557215	14169X	PARTICIPANT	\N	PRESENT	1
557219	557215	20020P	PARTICIPANT	\N	PRESENT	1
557230	557229	19826F	PARTICIPANT	\N	PRESENT	0
557232	557231	19826F	PARTICIPANT	\N	PRESENT	0
557233	557231	14205J	PARTICIPANT	\N	PRESENT	0
557524	555123	10006L	PRESIDENT	0	PRESENT	0
557525	555123	14217N	PARTICIPANT	\N	PRESENT	0
557526	555123	19415P	PARTICIPANT	\N	PRESENT	0
557528	555123	11097X	PARTICIPANT	\N	PRESENT	0
557529	555123	11067R	PARTICIPANT	\N	PRESENT	0
557530	555123	04086Q	PARTICIPANT	\N	PRESENT	0
557532	555123	19713W	PARTICIPANT	\N	PRESENT	0
557533	555123	14213J	PARTICIPANT	\N	PRESENT	1
557534	555123	04043D	PARTICIPANT	\N	PRESENT	1
557535	555123	11031D	PARTICIPANT	\N	PRESENT	1
557593	555123	14042U	PARTICIPANT	\N	PRESENT	1
557594	555123	19697Q	PARTICIPANT	\N	PRESENT	1
557625	555123	18193Q	PARTICIPANT	\N	PRESENT	1
557626	555123	11043H	PARTICIPANT	\N	PRESENT	1
557627	555123	20138D	PARTICIPANT	\N	PRESENT	1
557628	555123	08015R	PARTICIPANT	\N	PRESENT	1
557631	555123	99004R	PARTICIPANT	\N	PRESENT	1
558018	557677	86034E	PARTICIPANT	\N	PRESENT	0
558020	557883	19649G	PARTICIPANT	\N	PRESENT	0
558021	557883	20108W	PARTICIPANT	\N	PRESENT	0
558022	557883	19447X	PARTICIPANT	\N	PRESENT	0
558023	557883	14215L	PRESIDENT	1	PRESENT	0
558026	557883	14111D	PARTICIPANT	\N	PRESENT	0
558027	557883	14041T	PARTICIPANT	\N	PRESENT	0
558028	557883	20110Q	PARTICIPANT	\N	PRESENT	0
558029	557883	11085T	PARTICIPANT	\N	PRESENT	0
558030	557883	04047H	PRESIDENT	0	PRESENT	0
558040	557677	14215L	PARTICIPANT	\N	PRESENT	0
558041	557677	19681G	PARTICIPANT	\N	PRESENT	0
558042	557677	04047H	PARTICIPANT	\N	PRESENT	0
558043	557677	18083K	PARTICIPANT	\N	PRESENT	0
558046	557677	14219Q	PARTICIPANT	\N	PRESENT	0
558049	557677	20108W	PARTICIPANT	\N	PRESENT	0
558050	557677	19447X	PARTICIPANT	\N	PRESENT	0
558051	557677	20072C	PARTICIPANT	\N	PRESENT	0
558052	557677	14253S	PARTICIPANT	\N	PRESENT	0
558053	557677	19657G	PARTICIPANT	\N	PRESENT	0
558054	557677	19399H	PARTICIPANT	\N	PRESENT	0
558056	557677	14031R	PARTICIPANT	\N	PRESENT	0
558057	557677	17229F	PARTICIPANT	\N	PRESENT	0
558058	557677	08061X	PARTICIPANT	\N	PRESENT	0
558064	557677	19251M	PARTICIPANT	\N	PRESENT	0
558065	557677	20076G	PARTICIPANT	\N	PRESENT	0
558066	557677	20110Q	PARTICIPANT	\N	PRESENT	0
558067	557677	20080C	PARTICIPANT	\N	PRESENT	0
558068	557677	19695N	PARTICIPANT	\N	PRESENT	0
558069	557677	19820Y	PARTICIPANT	\N	PRESENT	0
558070	557677	95063L	PARTICIPANT	\N	PRESENT	0
558071	557677	08060W	PARTICIPANT	\N	PRESENT	0
558072	557677	19599P	PARTICIPANT	\N	PRESENT	0
558073	557677	19549D	PARTICIPANT	\N	PRESENT	0
558074	557677	19693L	PARTICIPANT	\N	PRESENT	0
558075	557677	14089Y	PARTICIPANT	\N	PRESENT	0
558076	557677	11072N	PARTICIPANT	\N	PRESENT	0
558077	557677	04085P	PARTICIPANT	\N	PRESENT	0
558078	557677	20046A	PARTICIPANT	\N	PRESENT	0
558079	557677	19593H	PARTICIPANT	\N	PRESENT	0
558080	557677	11045K	PARTICIPANT	\N	PRESENT	0
558081	557677	19649G	PARTICIPANT	\N	PRESENT	0
558082	557677	14021P	PARTICIPANT	\N	PRESENT	0
558083	557677	19503N	PARTICIPANT	\N	PRESENT	0
558084	557677	14121F	PARTICIPANT	\N	PRESENT	0
558085	557677	11026G	PARTICIPANT	\N	PRESENT	0
558086	557677	19347U	PARTICIPANT	\N	PRESENT	0
558087	557677	14231L	PARTICIPANT	\N	PRESENT	0
558088	557677	14111D	PARTICIPANT	\N	PRESENT	0
558089	557677	14327T	PARTICIPANT	\N	PRESENT	0
558090	557677	19443T	PARTICIPANT	\N	PRESENT	0
558091	557677	11053K	PARTICIPANT	\N	PRESENT	0
558092	557677	01024M	PARTICIPANT	\N	PRESENT	0
558093	557677	14147R	PARTICIPANT	\N	PRESENT	0
558094	557677	11097X	PARTICIPANT	\N	PRESENT	0
558095	557677	04033B	PARTICIPANT	\N	PRESENT	0
558096	557677	19349W	PARTICIPANT	\N	PRESENT	0
558097	557677	05008E	PARTICIPANT	\N	PRESENT	0
558098	557677	08010L	PARTICIPANT	\N	PRESENT	0
558099	557677	20038A	PARTICIPANT	\N	PRESENT	0
558100	557677	08018U	PARTICIPANT	\N	PRESENT	0
558101	557677	17737W	PARTICIPANT	\N	PRESENT	0
558102	557677	11099A	PARTICIPANT	\N	PRESENT	0
558103	557677	20106U	PARTICIPANT	\N	PRESENT	0
558104	557677	99004R	PARTICIPANT	\N	PRESENT	0
558105	557677	11064N	PARTICIPANT	\N	PRESENT	0
558106	557677	20090E	PARTICIPANT	\N	PRESENT	0
558107	557677	20134Y	PARTICIPANT	\N	PRESENT	0
558108	557677	19489J	PARTICIPANT	\N	PRESENT	0
558109	557677	14151M	PARTICIPANT	\N	PRESENT	0
558110	557677	11010L	PARTICIPANT	\N	PRESENT	0
558111	557677	01058X	PARTICIPANT	\N	PRESENT	0
558112	557677	20068G	PARTICIPANT	\N	PRESENT	0
558113	557677	11085T	PARTICIPANT	\N	PRESENT	0
558114	557677	14030Q	PARTICIPANT	\N	PRESENT	0
558115	557677	11033F	PARTICIPANT	\N	PRESENT	0
558116	557677	14055N	PARTICIPANT	\N	PRESENT	0
558119	557677	19749K	PARTICIPANT	\N	PRESENT	0
558120	557677	11065P	PARTICIPANT	\N	PRESENT	0
558121	557677	19367Y	PARTICIPANT	\N	PRESENT	0
558122	557677	19369B	PARTICIPANT	\N	PRESENT	0
558123	557677	14053L	PARTICIPANT	\N	PRESENT	0
558124	557677	17637T	PARTICIPANT	\N	PRESENT	0
558125	557677	14097Y	PARTICIPANT	\N	PRESENT	0
551075	545745	19563B	PARTICIPANT	\N	PRESENT	0
551076	545745	14331P	PRESIDENT	0	PRESENT	0
551077	545745	10015M	PARTICIPANT	\N	PRESENT	0
551078	545745	20098N	PARTICIPANT	\N	PRESENT	1
551080	551079	19575F	PARTICIPANT	\N	PRESENT	0
551081	551079	14083S	PARTICIPANT	\N	PRESENT	0
551082	551079	19369B	PARTICIPANT	\N	PRESENT	0
551083	551079	20126Y	PARTICIPANT	\N	PRESENT	0
551084	551079	19695N	PARTICIPANT	\N	PRESENT	0
551085	551079	14026U	PARTICIPANT	\N	PRESENT	0
551086	551079	19467C	PARTICIPANT	\N	PRESENT	0
551087	551079	20082E	PARTICIPANT	\N	PRESENT	0
551088	551079	14105F	PARTICIPANT	\N	PRESENT	0
551089	551079	20134Y	PARTICIPANT	\N	PRESENT	0
551090	551079	14041T	PARTICIPANT	\N	PRESENT	0
551091	551079	14030Q	PARTICIPANT	\N	EXCUSE	0
551092	551079	14329V	PARTICIPANT	\N	EXCUSE	0
551093	551079	08028W	PARTICIPANT	\N	EXCUSE	0
551094	551079	19251M	PARTICIPANT	\N	EXCUSE	0
551095	551079	20054A	PARTICIPANT	\N	EXCUSE	0
551096	551079	19515S	PRESIDENT	0	PRESENT	0
551173	548798	05008E	PARTICIPANT	\N	PRESENT	0
551174	548798	19741B	PARTICIPANT	\N	PRESENT	0
551175	548798	01048V	PARTICIPANT	\N	PRESENT	0
551176	548798	08017T	PARTICIPANT	\N	PRESENT	0
551177	548798	19563B	PARTICIPANT	\N	PRESENT	0
551178	548798	20116W	PARTICIPANT	\N	PRESENT	0
551179	550892	20090E	PARTICIPANT	\N	PRESENT	0
551180	550892	11067R	PARTICIPANT	\N	PRESENT	0
551181	550892	20048C	PRESIDENT	0	PRESENT	0
551182	550892	14179A	PARTICIPANT	\N	PRESENT	1
551183	550892	17779H	PARTICIPANT	\N	PRESENT	0
551184	548798	11026G	PARTICIPANT	\N	PRESENT	0
551185	548798	19687N	PARTICIPANT	\N	PRESENT	0
551186	548798	14071N	PARTICIPANT	\N	PRESENT	0
551187	548798	10015M	PARTICIPANT	\N	PRESENT	0
551197	548798	20048C	PARTICIPANT	\N	PRESENT	0
551198	548798	14207L	PARTICIPANT	\N	PRESENT	0
551200	548798	19631V	PARTICIPANT	\N	PRESENT	0
551220	548798	20050V	PARTICIPANT	\N	PRESENT	0
551226	548798	19489J	PARTICIPANT	\N	PRESENT	0
551230	548798	20082E	PARTICIPANT	\N	PRESENT	0
551236	548798	19333N	PARTICIPANT	\N	PRESENT	0
551245	548798	11085T	PARTICIPANT	\N	PRESENT	0
551248	548798	19399H	PARTICIPANT	\N	PRESENT	0
551253	548798	14073Q	PARTICIPANT	\N	PRESENT	0
551257	548798	19553Y	PARTICIPANT	\N	PRESENT	0
551261	548798	20038A	PARTICIPANT	\N	PRESENT	0
551273	548798	20100N	PARTICIPANT	\N	PRESENT	0
551274	548798	11053K	PARTICIPANT	\N	PRESENT	0
551279	548798	11056N	PARTICIPANT	\N	PRESENT	0
551280	548798	99004R	PARTICIPANT	\N	PRESENT	0
551281	548798	19583F	PARTICIPANT	\N	PRESENT	0
551282	548798	19347U	PARTICIPANT	\N	PRESENT	0
551288	548798	19551W	PARTICIPANT	\N	PRESENT	0
551332	548798	19866P	PARTICIPANT	\N	PRESENT	0
551368	548798	14357A	PARTICIPANT	\N	PRESENT	0
551404	548799	19749K	PARTICIPANT	\N	PRESENT	0
551405	548799	11072N	PARTICIPANT	\N	PRESENT	0
551406	548799	14207L	PARTICIPANT	\N	PRESENT	0
551407	548799	19719D	PARTICIPANT	\N	PRESENT	0
551408	548799	19583F	PARTICIPANT	\N	PRESENT	0
551409	548799	20062A	PARTICIPANT	\N	PRESENT	0
551410	548799	19479G	PARTICIPANT	\N	PRESENT	0
551411	548799	14071N	PARTICIPANT	\N	PRESENT	0
551412	548799	11033F	PARTICIPANT	\N	PRESENT	0
551413	548799	11090Q	PARTICIPANT	\N	PRESENT	0
551414	548799	19649G	PARTICIPANT	\N	PRESENT	0
551415	548799	14329V	PARTICIPANT	\N	PRESENT	0
551416	548799	04086Q	PARTICIPANT	\N	PRESENT	0
551417	548799	11027H	PARTICIPANT	\N	PRESENT	0
551418	548799	19447X	PARTICIPANT	\N	PRESENT	0
551419	548799	14089Y	PARTICIPANT	\N	PRESENT	0
551420	548799	19693L	PARTICIPANT	\N	PRESENT	0
551421	548799	14357A	PARTICIPANT	\N	PRESENT	0
551422	548799	19593H	PARTICIPANT	\N	PRESENT	0
551423	548799	05008E	PARTICIPANT	\N	PRESENT	0
551424	548799	19347U	PARTICIPANT	\N	PRESENT	0
551425	548799	14055N	PARTICIPANT	\N	PRESENT	0
551426	548799	20100N	PARTICIPANT	\N	PRESENT	0
551427	548799	17737W	PARTICIPANT	\N	PRESENT	0
551428	548799	19673G	PARTICIPANT	\N	PRESENT	0
551429	548799	14215L	PARTICIPANT	\N	PRESENT	0
551430	548799	10015M	PARTICIPANT	\N	PRESENT	0
551431	548799	19651A	PARTICIPANT	\N	PRESENT	0
551432	548799	19866P	PARTICIPANT	\N	PRESENT	0
551433	548799	19543W	PARTICIPANT	\N	PRESENT	0
551434	548799	01028R	PARTICIPANT	\N	PRESENT	0
551435	548799	19747H	PARTICIPANT	\N	PRESENT	0
551436	548799	11026G	PARTICIPANT	\N	PRESENT	0
551402	548799	01043Q	PARTICIPANT	\N	PRESENT	0
551403	548799	04047H	PARTICIPANT	\N	PRESENT	0
551437	548799	07004J	PARTICIPANT	\N	PRESENT	0
551438	548799	19553Y	PARTICIPANT	\N	PRESENT	0
551439	548799	17637T	PARTICIPANT	\N	PRESENT	0
551440	548799	19647E	PARTICIPANT	\N	PRESENT	0
551441	548799	19687N	PARTICIPANT	\N	PRESENT	0
551442	548799	19551W	PARTICIPANT	\N	PRESENT	0
551715	549309	14189C	PARTICIPANT	\N	PRESENT	0
551716	549309	11031D	PARTICIPANT	\N	PRESENT	0
551717	549309	19683J	PRESIDENT	0	PRESENT	0
551718	549309	19447X	PARTICIPANT	\N	PRESENT	0
551719	549309	19699S	PARTICIPANT	\N	PRESENT	0
551720	549309	99004R	PARTICIPANT	\N	PRESENT	0
551721	549309	19563B	PARTICIPANT	\N	PRESENT	1
551722	549309	20030R	PARTICIPANT	\N	PRESENT	1
551723	549309	14229S	PARTICIPANT	\N	PRESENT	0
551749	551743	14357A	PARTICIPANT	\N	PRESENT	0
551750	551743	19711U	PARTICIPANT	\N	PRESENT	0
551751	551743	20070A	PARTICIPANT	\N	PRESENT	0
551752	551743	19820Y	PARTICIPANT	\N	PRESENT	0
551753	551743	19503N	PARTICIPANT	\N	PRESENT	0
551754	551743	20092G	PARTICIPANT	\N	PRESENT	0
551755	551744	14357A	PARTICIPANT	\N	PRESENT	0
551756	551744	19711U	PARTICIPANT	\N	PRESENT	0
551757	551744	20070A	PARTICIPANT	\N	PRESENT	0
551758	551744	19820Y	PARTICIPANT	\N	PRESENT	0
551759	551744	19503N	PARTICIPANT	\N	PRESENT	0
551760	551744	20092G	PARTICIPANT	\N	PRESENT	0
551761	551745	14357A	PARTICIPANT	\N	PRESENT	0
551762	551745	19711U	PARTICIPANT	\N	PRESENT	0
551763	551745	20070A	PARTICIPANT	\N	PRESENT	0
551764	551745	19820Y	PARTICIPANT	\N	PRESENT	0
551765	551745	19503N	PARTICIPANT	\N	PRESENT	0
551766	551745	14033T	PARTICIPANT	\N	PRESENT	0
551767	551745	20092G	PARTICIPANT	\N	PRESENT	0
551768	551746	14357A	PARTICIPANT	\N	PRESENT	0
551769	551746	19711U	PARTICIPANT	\N	PRESENT	0
551770	551746	20070A	PARTICIPANT	\N	PRESENT	0
551771	551746	19820Y	PARTICIPANT	\N	PRESENT	0
551772	551746	19503N	PARTICIPANT	\N	PRESENT	0
551773	551746	14033T	PARTICIPANT	\N	PRESENT	0
551774	551746	20092G	PARTICIPANT	\N	PRESENT	0
551776	551747	14357A	PARTICIPANT	\N	PRESENT	0
551777	551747	20070A	PARTICIPANT	\N	PRESENT	0
551778	551747	19820Y	PARTICIPANT	\N	PRESENT	0
551779	551747	19503N	PARTICIPANT	\N	PRESENT	0
551780	551747	14033T	PARTICIPANT	\N	PRESENT	0
551781	551747	20092G	PARTICIPANT	\N	PRESENT	0
551787	551782	14357A	PARTICIPANT	\N	PRESENT	0
551788	551782	20126Y	PARTICIPANT	\N	PRESENT	0
551789	551782	19503N	PARTICIPANT	\N	PRESENT	0
551790	551782	20092G	PARTICIPANT	\N	PRESENT	0
551791	551783	14357A	PARTICIPANT	\N	PRESENT	0
551792	551783	20126Y	PARTICIPANT	\N	PRESENT	0
551793	551783	19503N	PARTICIPANT	\N	PRESENT	0
551794	551783	20092G	PARTICIPANT	\N	PRESENT	0
551795	551783	20050V	PARTICIPANT	\N	PRESENT	0
551796	551784	14357A	PARTICIPANT	\N	PRESENT	0
551797	551784	20070A	PARTICIPANT	\N	PRESENT	0
551798	551784	19503N	PARTICIPANT	\N	PRESENT	0
551799	551784	20126Y	PARTICIPANT	\N	PRESENT	0
551800	551784	20092G	PARTICIPANT	\N	PRESENT	0
551801	551785	14357A	PARTICIPANT	\N	PRESENT	0
551802	551785	20070A	PARTICIPANT	\N	PRESENT	0
551803	551785	20092G	PARTICIPANT	\N	PRESENT	0
551804	551786	14357A	PARTICIPANT	\N	PRESENT	0
551805	551786	20070A	PARTICIPANT	\N	PRESENT	0
551806	551786	20092G	PARTICIPANT	\N	PRESENT	0
551898	549183	20046A	PARTICIPANT	\N	PRESENT	1
551922	549183	20038A	PARTICIPANT	\N	EXCUSE	0
556399	555398	11066Q	PARTICIPANT	\N	PRESENT	0
556400	555398	08056B	PARTICIPANT	\N	PRESENT	0
556401	555398	19421M	PARTICIPANT	\N	PRESENT	1
556402	555398	19709B	PARTICIPANT	\N	PRESENT	0
556403	555398	14193X	PARTICIPANT	\N	PRESENT	0
556404	555398	19347U	PARTICIPANT	\N	PRESENT	0
556405	555398	97011G	PARTICIPANT	\N	PRESENT	0
556406	555398	14249W	PARTICIPANT	\N	PRESENT	0
556407	555398	20128B	PARTICIPANT	\N	PRESENT	0
556408	555398	14059S	PARTICIPANT	\N	PRESENT	0
556409	555398	14097Y	PARTICIPANT	\N	PRESENT	0
556410	555398	14133K	PARTICIPANT	\N	PRESENT	0
556411	555398	01062T	PARTICIPANT	\N	PRESENT	0
556412	555398	08069G	PARTICIPANT	\N	PRESENT	0
556413	555398	11041F	PARTICIPANT	\N	PRESENT	1
556414	555398	20042V	PARTICIPANT	\N	PRESENT	0
556415	555398	19721W	PARTICIPANT	\N	PRESENT	1
556416	555398	14105F	PARTICIPANT	\N	PRESENT	0
556417	555398	20064C	PARTICIPANT	\N	PRESENT	0
556418	555398	14267Y	PARTICIPANT	\N	PRESENT	0
556419	555398	11064N	PARTICIPANT	\N	PRESENT	0
556420	555398	11083R	PARTICIPANT	\N	PRESENT	1
556421	555398	14255U	PARTICIPANT	\N	PRESENT	1
557058	556980	19551W	PARTICIPANT	\N	PRESENT	0
557059	556980	19637C	PARTICIPANT	\N	PRESENT	0
557060	556980	19699S	PARTICIPANT	\N	PRESENT	0
557061	556980	14205J	PARTICIPANT	\N	PRESENT	0
557062	555036	20132W	PARTICIPANT	\N	PRESENT	0
557063	556980	19543W	PARTICIPANT	\N	PRESENT	0
557064	556980	19503N	PARTICIPANT	\N	PRESENT	0
557065	556980	17367Q	PARTICIPANT	\N	PRESENT	0
557066	556980	19619A	PARTICIPANT	\N	PRESENT	0
557067	556980	18083K	PARTICIPANT	\N	PRESENT	0
557068	556980	14169X	PARTICIPANT	\N	PRESENT	0
557078	555036	11097X	PARTICIPANT	\N	PRESENT	0
557079	555036	20108W	PARTICIPANT	\N	PRESENT	0
557080	556980	20106U	PARTICIPANT	\N	PRESENT	0
557081	555036	19745F	PARTICIPANT	\N	PRESENT	0
557082	555036	14147R	PARTICIPANT	\N	PRESENT	0
557083	555036	14217N	PARTICIPANT	\N	PRESENT	0
557084	555036	11056N	PARTICIPANT	\N	PRESENT	0
557086	555036	20104S	PARTICIPANT	\N	PRESENT	0
557087	555036	19689Q	PARTICIPANT	\N	PRESENT	0
557088	555036	11048N	PARTICIPANT	\N	PRESENT	0
557090	556980	19745F	PARTICIPANT	\N	PRESENT	0
557091	556980	19525U	PARTICIPANT	\N	PRESENT	0
557092	555036	20018V	PARTICIPANT	\N	PRESENT	0
557093	555036	20090E	PARTICIPANT	\N	PRESENT	0
557094	555036	11012A	PARTICIPANT	\N	PRESENT	0
557095	555036	19387D	PARTICIPANT	\N	PRESENT	0
557096	555036	20056C	PARTICIPANT	\N	PRESENT	0
557097	555036	19515S	PARTICIPANT	\N	PRESENT	0
557098	555036	19467C	PARTICIPANT	\N	PRESENT	0
557099	555036	19711U	PARTICIPANT	\N	PRESENT	0
557100	555036	20092G	PARTICIPANT	\N	PRESENT	0
557102	555036	20082E	PARTICIPANT	\N	PRESENT	0
557106	555858	19333N	PARTICIPANT	\N	PRESENT	0
557107	555858	19699S	PARTICIPANT	\N	PRESENT	0
557108	555858	19701S	PARTICIPANT	\N	PRESENT	0
557109	555858	20076G	PARTICIPANT	\N	PRESENT	0
557110	555858	19549D	PARTICIPANT	\N	PRESENT	0
557111	555858	19820Y	PARTICIPANT	\N	PRESENT	0
557112	555858	14219Q	PRESIDENT	0	PRESENT	0
557113	555858	19543W	PARTICIPANT	\N	PRESENT	0
557114	555858	19826F	PARTICIPANT	\N	PRESENT	0
557115	555858	14221J	PARTICIPANT	\N	PRESENT	0
557116	555858	19599P	PARTICIPANT	\N	PRESENT	0
557117	555858	20102Q	PARTICIPANT	\N	PRESENT	0
557118	555858	20096L	PARTICIPANT	\N	PRESENT	0
557119	555858	19637C	PARTICIPANT	\N	PRESENT	1
557120	555858	18083K	PARTICIPANT	\N	PRESENT	0
557121	555858	14237S	PARTICIPANT	\N	PRESENT	0
557122	555858	19551W	PARTICIPANT	\N	PRESENT	1
557123	555858	05012A	PARTICIPANT	\N	PRESENT	0
557124	555858	08060W	PARTICIPANT	\N	PRESENT	1
557125	555858	20106U	PARTICIPANT	\N	PRESENT	0
557126	555858	20118Y	PARTICIPANT	\N	PRESENT	0
557127	555858	19503N	PARTICIPANT	\N	PRESENT	0
557128	555858	20020P	PARTICIPANT	\N	PRESENT	0
557129	555858	17367Q	PARTICIPANT	\N	PRESENT	0
557130	555858	19681G	PARTICIPANT	\N	PRESENT	0
557131	555858	17637T	PARTICIPANT	\N	PRESENT	0
557132	555858	11065P	PARTICIPANT	\N	PRESENT	0
557133	555858	20120S	PARTICIPANT	\N	PRESENT	0
557134	555858	19525U	PARTICIPANT	\N	PRESENT	1
557135	555858	20136B	PARTICIPANT	\N	PRESENT	0
557136	555858	14031R	PARTICIPANT	\N	PRESENT	0
557137	555858	20038A	PARTICIPANT	\N	PRESENT	0
557138	555858	19251M	PARTICIPANT	\N	PRESENT	0
557139	555858	20046A	PARTICIPANT	\N	PRESENT	0
557140	555858	14169X	PARTICIPANT	\N	PRESENT	0
557141	555858	17229F	PARTICIPANT	\N	PRESENT	0
557142	555858	14205J	PARTICIPANT	\N	PRESENT	0
557143	555858	20068G	PARTICIPANT	\N	PRESENT	0
557144	555858	19739H	PARTICIPANT	\N	PRESENT	0
557145	555858	19745F	PARTICIPANT	\N	PRESENT	1
557146	555858	19619A	PARTICIPANT	\N	PRESENT	0
557147	555858	20024T	PARTICIPANT	\N	EXCUSE	0
557180	555037	20090E	PARTICIPANT	\N	PRESENT	0
557181	555037	19711U	PARTICIPANT	\N	PRESENT	0
557182	555037	97011G	PARTICIPANT	\N	PRESENT	0
557183	555037	19467C	PARTICIPANT	\N	PRESENT	0
557184	555037	20056C	PARTICIPANT	\N	PRESENT	0
557185	555037	20180F	PARTICIPANT	\N	PRESENT	0
557186	555037	19515S	PARTICIPANT	\N	PRESENT	0
557187	555037	11033F	PARTICIPANT	\N	PRESENT	0
557188	555037	14195A	PARTICIPANT	\N	PRESENT	0
557189	555037	19725B	PARTICIPANT	\N	PRESENT	0
557190	555037	20082E	PARTICIPANT	\N	PRESENT	0
557191	555037	14097Y	PARTICIPANT	\N	PRESENT	0
557192	555037	19553Y	PARTICIPANT	\N	PRESENT	0
557193	555037	19387D	PARTICIPANT	\N	PRESENT	0
557194	555037	19745F	PARTICIPANT	\N	PRESENT	0
557195	555037	19739H	PARTICIPANT	\N	PRESENT	0
557196	555037	19689Q	PARTICIPANT	\N	PRESENT	0
557197	555037	11056N	PARTICIPANT	\N	PRESENT	0
557198	555037	19687N	PARTICIPANT	\N	PRESENT	0
557200	555037	20110Q	PARTICIPANT	\N	PRESENT	0
557201	555037	20092G	PARTICIPANT	\N	PRESENT	0
557202	555037	11097X	PARTICIPANT	\N	PRESENT	0
557203	555037	20060X	PARTICIPANT	\N	PRESENT	0
557204	555037	04045F	PARTICIPANT	\N	PRESENT	0
557205	555037	20058E	PARTICIPANT	\N	PRESENT	0
557206	555037	19251M	PARTICIPANT	\N	PRESENT	0
557207	555037	19549D	PARTICIPANT	\N	PRESENT	0
557209	555037	14169X	PARTICIPANT	\N	PRESENT	0
557211	555037	11031D	PARTICIPANT	\N	PRESENT	0
557212	555037	20044X	PARTICIPANT	\N	PRESENT	0
557178	555037	99004R	PARTICIPANT	\N	PRESENT	0
557179	555037	11065P	PARTICIPANT	\N	PRESENT	0
557213	555037	01057W	PARTICIPANT	\N	PRESENT	0
557214	555037	19681G	PARTICIPANT	\N	PRESENT	0
557217	555037	19565D	PARTICIPANT	\N	PRESENT	0
557227	555037	01048V	PARTICIPANT	\N	PRESENT	0
557228	555037	20026V	PARTICIPANT	\N	PRESENT	0
557234	555037	14147R	PARTICIPANT	\N	PRESENT	0
557235	555037	19347U	PARTICIPANT	\N	PRESENT	0
557236	555037	14031R	PARTICIPANT	\N	PRESENT	0
557244	555037	14083S	PARTICIPANT	\N	PRESENT	0
557252	555037	19399H	PARTICIPANT	\N	PRESENT	0
557253	555037	11048N	PARTICIPANT	\N	PRESENT	0
562001	559662	19611R	PARTICIPANT	\N	PRESENT	0
562002	559662	19399H	PARTICIPANT	\N	PRESENT	0
562003	559662	20112S	PARTICIPANT	\N	PRESENT	0
562004	559662	19527W	PARTICIPANT	\N	PRESENT	0
562005	559662	19333N	PARTICIPANT	\N	PRESENT	0
562006	559662	19651A	PARTICIPANT	\N	PRESENT	0
562007	559662	14229S	PARTICIPANT	\N	PRESENT	0
562008	559662	04059M	PARTICIPANT	\N	PRESENT	0
562009	559662	20142Y	PARTICIPANT	\N	PRESENT	0
562010	559662	19593H	PARTICIPANT	\N	PRESENT	0
562011	559662	11043H	PARTICIPANT	\N	PRESENT	0
562012	559662	19621T	PARTICIPANT	\N	PRESENT	0
562013	559662	14069U	PARTICIPANT	\N	PRESENT	0
562014	559662	20152B	PARTICIPANT	\N	PRESENT	0
562015	559662	19699S	PARTICIPANT	\N	PRESENT	0
562016	559662	19693L	PARTICIPANT	\N	PRESENT	0
561999	559662	11070L	PARTICIPANT	\N	PRESENT	0
562000	559662	04070G	PARTICIPANT	\N	PRESENT	0
562017	559662	19367Y	PARTICIPANT	\N	PRESENT	0
562018	559662	19533U	PARTICIPANT	\N	PRESENT	0
562019	559662	20082E	PARTICIPANT	\N	PRESENT	0
562020	559662	20052X	PARTICIPANT	\N	PRESENT	0
562021	559662	20180F	PARTICIPANT	\N	PRESENT	0
562023	559662	14021P	PARTICIPANT	\N	PRESENT	0
562026	559662	19667J	PARTICIPANT	\N	PRESENT	0
562027	559662	20058E	PARTICIPANT	\N	PRESENT	0
562028	559662	14179A	PARTICIPANT	\N	PRESENT	0
562029	559662	14073Q	PARTICIPANT	\N	PRESENT	0
562030	559662	19643A	PARTICIPANT	\N	PRESENT	0
562031	559662	17589D	PARTICIPANT	\N	PRESENT	0
562032	559662	19553Y	PARTICIPANT	\N	PRESENT	0
562033	559662	14026U	PARTICIPANT	\N	PRESENT	0
562034	559662	20092G	PARTICIPANT	\N	PRESENT	0
562035	559662	11085T	PARTICIPANT	\N	PRESENT	0
562039	559662	14251Q	PARTICIPANT	\N	PRESENT	0
562078	559662	04085P	PARTICIPANT	\N	PRESENT	0
562113	559662	14030Q	PARTICIPANT	\N	PRESENT	0
562115	559662	08010L	PARTICIPANT	\N	PRESENT	0
562119	545945	19693L	PARTICIPANT	\N	PRESENT	0
562121	545945	01048V	PARTICIPANT	\N	PRESENT	0
562122	545945	19735D	PARTICIPANT	\N	PRESENT	0
562123	545945	20066E	PARTICIPANT	\N	PRESENT	0
562127	545945	01058X	PARTICIPANT	\N	EXCUSE	0
562128	545945	04043D	PARTICIPANT	\N	PRESENT	0
562129	545945	19533U	PARTICIPANT	\N	PRESENT	0
562130	545945	20128B	PARTICIPANT	\N	EXCUSE	0
562131	545945	20072C	PARTICIPANT	\N	EXCUSE	0
562132	545945	19503N	PARTICIPANT	\N	EXCUSE	0
562179	562178	19709B	PARTICIPANT	\N	PRESENT	0
562180	562178	11027H	PARTICIPANT	\N	PRESENT	0
562182	562181	14249W	PARTICIPANT	\N	PRESENT	0
562183	562181	19709B	PARTICIPANT	\N	PRESENT	0
562184	562181	11027H	PARTICIPANT	\N	PRESENT	0
562214	562213	19711U	PARTICIPANT	\N	PRESENT	0
562215	562213	20132W	PARTICIPANT	\N	PRESENT	0
562216	562213	14041T	PARTICIPANT	\N	PRESENT	0
562217	562213	14255U	PARTICIPANT	\N	PRESENT	1
562218	562213	08018U	PARTICIPANT	\N	PRESENT	0
562219	562213	11026G	PARTICIPANT	\N	PRESENT	0
562318	561977	07004J	PARTICIPANT	\N	PRESENT	0
562319	561977	14215L	PARTICIPANT	\N	PRESENT	0
562320	561977	04047H	PRESIDENT	0	PRESENT	0
562321	561977	14041T	PARTICIPANT	\N	PRESENT	0
562322	561977	19447X	PARTICIPANT	\N	PRESENT	0
562323	561977	05008E	PARTICIPANT	\N	PRESENT	0
562324	561977	11056N	PARTICIPANT	\N	PRESENT	0
562325	561977	95063L	PARTICIPANT	\N	PRESENT	0
562326	561977	20038A	PARTICIPANT	\N	PRESENT	0
562327	561977	11070L	PARTICIPANT	\N	PRESENT	0
562328	561977	14030Q	PARTICIPANT	\N	PRESENT	0
562329	561977	14259Y	PARTICIPANT	\N	PRESENT	0
562345	561978	19447X	PARTICIPANT	\N	PRESENT	0
562346	561978	07004J	PARTICIPANT	\N	PRESENT	0
562354	561978	19673G	PARTICIPANT	\N	PRESENT	0
562355	561978	10015M	PARTICIPANT	\N	PRESENT	0
562356	561978	14215L	PRESIDENT	0	PRESENT	0
562357	561978	01028R	PARTICIPANT	\N	PRESENT	0
562358	561978	14231L	PARTICIPANT	\N	PRESENT	0
562359	561978	14275Y	PARTICIPANT	\N	PRESENT	0
562360	561978	20108W	PARTICIPANT	\N	PRESENT	0
562361	561978	14147R	PARTICIPANT	\N	PRESENT	0
562362	561978	20128B	PARTICIPANT	\N	PRESENT	0
562363	561978	95063L	PARTICIPANT	\N	PRESENT	0
562364	562198	19719D	PARTICIPANT	\N	PRESENT	0
562365	561978	14021P	PARTICIPANT	\N	PRESENT	0
562366	561978	19729F	PARTICIPANT	\N	PRESENT	0
562367	561978	19581D	PARTICIPANT	\N	PRESENT	0
562368	562198	20052X	PARTICIPANT	\N	PRESENT	0
562369	562198	19699S	PARTICIPANT	\N	PRESENT	0
562370	562198	20090E	PARTICIPANT	\N	PRESENT	0
562371	562198	20054A	PARTICIPANT	\N	PRESENT	0
562372	562198	14249W	PARTICIPANT	\N	PRESENT	0
562373	562198	19691J	PARTICIPANT	\N	PRESENT	0
562374	562198	10006L	PARTICIPANT	\N	PRESENT	0
562375	562198	19760E	PARTICIPANT	\N	PRESENT	0
562376	562198	14105F	PARTICIPANT	\N	PRESENT	0
562377	562198	97011G	PARTICIPANT	\N	PRESENT	0
562378	562198	14217N	PARTICIPANT	\N	PRESENT	0
562379	562198	14211G	PARTICIPANT	\N	PRESENT	0
562380	562198	19683J	PARTICIPANT	\N	PRESENT	0
562381	562198	01043Q	PARTICIPANT	\N	PRESENT	0
562382	562198	14147R	PARTICIPANT	\N	PRESENT	0
562383	562198	20130U	PARTICIPANT	\N	PRESENT	0
562386	562198	20108W	PARTICIPANT	\N	PRESENT	0
562390	562198	19729F	PARTICIPANT	\N	PRESENT	0
562392	562198	20140W	PARTICIPANT	\N	PRESENT	0
562393	562198	19553Y	PARTICIPANT	\N	PRESENT	0
562394	562198	19739H	PARTICIPANT	\N	PRESENT	0
562395	562198	19685L	PARTICIPANT	\N	PRESENT	0
562396	562198	14111D	PARTICIPANT	\N	PRESENT	0
562397	562198	19349W	PARTICIPANT	\N	PRESENT	0
562398	562198	19367Y	PARTICIPANT	\N	PRESENT	0
562399	562198	08061X	PARTICIPANT	\N	PRESENT	0
562406	562198	11101A	PARTICIPANT	\N	PRESENT	0
562415	562198	11067R	PARTICIPANT	\N	PRESENT	0
562408	562198	11031D	PARTICIPANT	\N	PRESENT	0
562409	562198	20128B	PARTICIPANT	\N	PRESENT	0
562410	562198	18083K	PARTICIPANT	\N	PRESENT	0
562412	562198	11033F	PARTICIPANT	\N	PRESENT	0
562413	562198	07004J	PARTICIPANT	\N	PRESENT	0
562414	562198	19703U	PARTICIPANT	\N	PRESENT	0
562416	562198	19697Q	PARTICIPANT	\N	PRESENT	0
562417	562198	19629C	PARTICIPANT	\N	PRESENT	0
562418	562198	19447X	PARTICIPANT	\N	PRESENT	0
562419	562198	19581D	PARTICIPANT	\N	PRESENT	0
562420	562198	04085P	PARTICIPANT	\N	PRESENT	0
562421	562198	19747H	PARTICIPANT	\N	PRESENT	0
562422	562198	19711U	PARTICIPANT	\N	PRESENT	0
562423	562198	19563B	PARTICIPANT	\N	PRESENT	0
562424	562198	01024M	PARTICIPANT	\N	PRESENT	0
562469	562199	19719D	PARTICIPANT	\N	PRESENT	0
562470	562199	04047H	PARTICIPANT	\N	PRESENT	0
562471	562199	19447X	PARTICIPANT	\N	PRESENT	0
562472	562199	19563B	PARTICIPANT	\N	PRESENT	0
562473	562199	11033F	PARTICIPANT	\N	PRESENT	0
562474	562199	95063L	PARTICIPANT	\N	PRESENT	0
562475	562199	04085P	PARTICIPANT	\N	PRESENT	0
562476	562199	07004J	PARTICIPANT	\N	PRESENT	0
562477	562199	14105F	PARTICIPANT	\N	PRESENT	0
562478	562199	19629C	PARTICIPANT	\N	PRESENT	0
562479	562199	11026G	PARTICIPANT	\N	PRESENT	0
562480	562199	20052X	PARTICIPANT	\N	PRESENT	0
562481	562199	19739H	PARTICIPANT	\N	PRESENT	0
562482	562199	19685L	PARTICIPANT	\N	PRESENT	0
562483	562199	19697Q	PARTICIPANT	\N	PRESENT	0
562484	562199	19349W	PARTICIPANT	\N	PRESENT	0
562485	562199	08061X	PARTICIPANT	\N	PRESENT	0
562486	562199	01024M	PARTICIPANT	\N	PRESENT	0
562487	562199	20054A	PARTICIPANT	\N	PRESENT	0
562488	562199	20116W	PARTICIPANT	\N	PRESENT	0
562489	562199	19367Y	PARTICIPANT	\N	PRESENT	0
562490	562199	19553Y	PARTICIPANT	\N	PRESENT	0
562491	562199	19581D	PARTICIPANT	\N	PRESENT	0
562492	562199	20172F	PARTICIPANT	\N	PRESENT	0
562493	562199	19729F	PARTICIPANT	\N	PRESENT	0
562494	562199	19565D	PARTICIPANT	\N	PRESENT	0
562495	562199	19711U	PARTICIPANT	\N	PRESENT	0
562496	562199	04033B	PARTICIPANT	\N	PRESENT	0
562497	562199	20140W	PARTICIPANT	\N	PRESENT	0
546296	545738	14069U	PARTICIPANT	\N	PRESENT	1
546297	545738	14147R	PARTICIPANT	\N	PRESENT	1
546298	545738	95063L	PARTICIPANT	\N	EXCUSE	0
548999	548998	20070A	PARTICIPANT	\N	PRESENT	0
549000	548998	11110B	PARTICIPANT	\N	PRESENT	0
549009	549008	11012A	PARTICIPANT	\N	PRESENT	0
549010	549008	14083S	PARTICIPANT	\N	PRESENT	0
549012	549011	14083S	PARTICIPANT	\N	PRESENT	0
549013	549011	11012A	PARTICIPANT	\N	PRESENT	0
549015	549014	14083S	PARTICIPANT	\N	PRESENT	0
549016	549014	11012A	PARTICIPANT	\N	PRESENT	0
550480	549666	20072C	PARTICIPANT	\N	EXCUSE	0
551462	551461	19741B	PARTICIPANT	\N	PRESENT	0
551465	551464	19768N	PARTICIPANT	\N	PRESENT	0
551466	551464	20034V	PARTICIPANT	\N	PRESENT	0
551467	551464	19383Y	PARTICIPANT	\N	PRESENT	0
551468	551464	14033T	PARTICIPANT	\N	PRESENT	0
551469	551464	19705W	PARTICIPANT	\N	PRESENT	0
551470	551464	19575F	PARTICIPANT	\N	PRESENT	0
551471	551464	19631V	PARTICIPANT	\N	PRESENT	0
551472	551464	19747H	PARTICIPANT	\N	PRESENT	0
551476	551464	20078J	PARTICIPANT	\N	PRESENT	0
551474	551464	19467C	PARTICIPANT	\N	PRESENT	0
551475	551464	19369B	PARTICIPANT	\N	PRESENT	0
551477	545943	20066E	PARTICIPANT	\N	EXCUSE	0
551478	545943	11067R	PARTICIPANT	\N	PRESENT	0
551480	551479	19701S	PARTICIPANT	\N	PRESENT	0
551481	551479	19745F	PARTICIPANT	\N	PRESENT	0
551482	551479	19387D	PARTICIPANT	\N	PRESENT	0
551483	551479	14205J	PARTICIPANT	\N	PRESENT	0
551484	551479	19549D	PARTICIPANT	\N	PRESENT	0
551485	551479	20122U	PARTICIPANT	\N	PRESENT	0
551486	551479	20120S	PARTICIPANT	\N	PRESENT	0
551488	551487	19701S	PARTICIPANT	\N	PRESENT	0
551489	551487	20122U	PARTICIPANT	\N	PRESENT	0
551490	551487	14205J	PARTICIPANT	\N	PRESENT	0
551492	551491	19701S	PARTICIPANT	\N	PRESENT	0
551493	551491	19549D	PARTICIPANT	\N	PRESENT	0
551494	551491	20120S	PARTICIPANT	\N	PRESENT	0
551495	551491	20122U	PARTICIPANT	\N	PRESENT	0
551496	551491	14205J	PARTICIPANT	\N	PRESENT	0
551498	551497	19701S	PARTICIPANT	\N	PRESENT	0
551525	548970	14231L	PRESIDENT	0	PRESENT	0
551526	548970	19735D	PARTICIPANT	\N	EXCUSE	0
551527	548970	19826F	PARTICIPANT	\N	EXCUSE	0
551916	551505	18193Q	PARTICIPANT	\N	PRESENT	0
551920	551505	19679N	PARTICIPANT	\N	PRESENT	0
551925	551505	20130U	PARTICIPANT	\N	PRESENT	1
551956	551505	19631V	PARTICIPANT	\N	EXCUSE	0
552059	549006	11109J	PARTICIPANT	\N	EXCUSE	0
553603	551161	20050V	PARTICIPANT	\N	PRESENT	0
558193	557684	14215L	PARTICIPANT	\N	PRESENT	0
558194	557684	19489J	PARTICIPANT	\N	PRESENT	0
558195	557684	19820Y	PARTICIPANT	\N	PRESENT	0
558196	557684	19599P	PARTICIPANT	\N	PRESENT	0
558197	557684	20076G	PARTICIPANT	\N	PRESENT	0
558198	557684	11026G	PARTICIPANT	\N	PRESENT	0
558199	557684	14187A	PARTICIPANT	\N	PRESENT	0
558200	557684	20080C	PARTICIPANT	\N	PRESENT	0
558201	557684	05008E	PARTICIPANT	\N	PRESENT	0
558202	557684	19503N	PARTICIPANT	\N	PRESENT	0
558203	557684	04033B	PARTICIPANT	\N	PRESENT	0
558204	557684	14111D	PARTICIPANT	\N	PRESENT	0
558205	557684	10006L	PARTICIPANT	\N	PRESENT	0
558206	557684	19563B	PARTICIPANT	\N	PRESENT	0
558207	557684	17737W	PARTICIPANT	\N	PRESENT	0
558208	557684	20110Q	PARTICIPANT	\N	PRESENT	0
558209	557684	20134Y	PARTICIPANT	\N	PRESENT	0
558210	557684	11099A	PARTICIPANT	\N	PRESENT	0
558211	557684	20068G	PARTICIPANT	\N	PRESENT	0
558212	557684	14253S	PARTICIPANT	\N	PRESENT	0
558213	557684	11033F	PARTICIPANT	\N	PRESENT	0
558214	557684	19693L	PARTICIPANT	\N	PRESENT	0
558215	557684	20038A	PARTICIPANT	\N	PRESENT	0
558216	557684	19447X	PARTICIPANT	\N	PRESENT	0
558217	557684	01058X	PARTICIPANT	\N	PRESENT	0
558218	557684	19681G	PARTICIPANT	\N	PRESENT	0
558219	557684	20108W	PARTICIPANT	\N	PRESENT	0
558220	557684	20072C	PARTICIPANT	\N	PRESENT	0
558221	557684	14147R	PARTICIPANT	\N	PRESENT	0
558222	557684	19629C	PARTICIPANT	\N	PRESENT	0
558223	557684	19399H	PARTICIPANT	\N	PRESENT	0
558224	557684	11012A	PARTICIPANT	\N	PRESENT	0
558225	557684	14231L	PARTICIPANT	\N	PRESENT	0
558226	557684	19349W	PARTICIPANT	\N	PRESENT	0
558227	557684	11097X	PARTICIPANT	\N	PRESENT	0
558228	557684	08061X	PARTICIPANT	\N	PRESENT	0
558229	557684	95063L	PARTICIPANT	\N	PRESENT	0
558230	557684	14031R	PARTICIPANT	\N	PRESENT	0
558231	557684	19443T	PARTICIPANT	\N	PRESENT	0
558232	557684	20044X	PARTICIPANT	\N	PRESENT	0
558233	557684	19657G	PARTICIPANT	\N	PRESENT	0
558234	557684	19549D	PARTICIPANT	\N	PRESENT	0
558235	557684	14089Y	PARTICIPANT	\N	PRESENT	0
558236	557684	20090E	PARTICIPANT	\N	PRESENT	0
558237	557684	04085P	PARTICIPANT	\N	PRESENT	0
558238	557684	19695N	PARTICIPANT	\N	PRESENT	0
558239	557684	20054A	PARTICIPANT	\N	PRESENT	0
558240	557684	08060W	PARTICIPANT	\N	PRESENT	0
558241	557684	20046A	PARTICIPANT	\N	PRESENT	0
558242	557684	18083K	PARTICIPANT	\N	PRESENT	0
558243	557684	19649G	PARTICIPANT	\N	PRESENT	0
558244	557684	20034V	PARTICIPANT	\N	PRESENT	0
558245	557684	17023S	PARTICIPANT	\N	PRESENT	0
558246	557684	11072N	PARTICIPANT	\N	PRESENT	0
558247	557684	01028R	PARTICIPANT	\N	PRESENT	0
558248	557684	19573D	PARTICIPANT	\N	PRESENT	0
558249	557684	14021P	PARTICIPANT	\N	PRESENT	0
558250	557684	20106U	PARTICIPANT	\N	PRESENT	0
558251	557684	14053L	PARTICIPANT	\N	PRESENT	0
558252	557684	19251M	PARTICIPANT	\N	PRESENT	0
558253	557684	19369B	PARTICIPANT	\N	PRESENT	0
558254	557684	14219Q	PARTICIPANT	\N	PRESENT	0
558191	557684	11070L	PARTICIPANT	\N	PRESENT	0
558192	557684	04047H	PARTICIPANT	\N	PRESENT	0
558255	557684	14073Q	PARTICIPANT	\N	PRESENT	0
558256	557684	20120S	PARTICIPANT	\N	PRESENT	0
558257	557684	14179A	PARTICIPANT	\N	PRESENT	0
558258	557684	14151M	PARTICIPANT	\N	PRESENT	0
558953	557977	19629C	PARTICIPANT	\N	PRESENT	1
558954	557977	14123H	PARTICIPANT	\N	PRESENT	0
559765	559764	19711U	PARTICIPANT	\N	PRESENT	0
559799	559798	08018U	PARTICIPANT	\N	PRESENT	0
559800	559798	11027H	PARTICIPANT	\N	PRESENT	0
559801	559798	11026G	PARTICIPANT	\N	PRESENT	0
562256	562254	11054L	PARTICIPANT	\N	PRESENT	0
562253	548265	01048V	PARTICIPANT	\N	EXCUSE	0
562255	562254	01058X	PARTICIPANT	\N	PRESENT	0
562257	562254	14193X	PARTICIPANT	\N	PRESENT	0
562259	562258	11064N	PARTICIPANT	\N	PRESENT	0
563222	563221	14147R	PARTICIPANT	\N	PRESENT	0
563778	558019	20120S	PARTICIPANT	\N	EXCUSE	0
563780	559849	20120S	PARTICIPANT	\N	EXCUSE	0
563781	558019	19826F	PARTICIPANT	\N	EXCUSE	0
563969	558019	20084G	PARTICIPANT	\N	PRESENT	0
563970	558019	01057W	PARTICIPANT	\N	PRESENT	0
563971	558019	14327T	PARTICIPANT	\N	PRESENT	0
563972	558019	08010L	PARTICIPANT	\N	PRESENT	1
563973	558019	14257W	PARTICIPANT	\N	PRESENT	1
563975	558019	19565D	PARTICIPANT	\N	PRESENT	1
563978	558019	20022R	PARTICIPANT	\N	PRESENT	1
563979	558019	04045F	PARTICIPANT	\N	PRESENT	1
563980	558019	14107H	PARTICIPANT	\N	PRESENT	1
563981	558019	14205J	PARTICIPANT	\N	PRESENT	1
563993	558264	14189C	PARTICIPANT	\N	EXCUSE	0
563994	558264	20024T	PARTICIPANT	\N	PRESENT	1
563995	558264	14030Q	PRESIDENT	0	PRESENT	0
563996	558264	17737W	PARTICIPANT	\N	EXCUSE	0
563997	558264	11031D	PARTICIPANT	\N	PRESENT	0
563998	558264	19693L	PARTICIPANT	\N	EXCUSE	0
563999	558264	19599P	PARTICIPANT	\N	PRESENT	0
564000	558264	20066E	PARTICIPANT	\N	PRESENT	1
564001	558264	20034V	PARTICIPANT	\N	PRESENT	1
564002	558264	20056C	PARTICIPANT	\N	PRESENT	1
564003	558264	07029T	PARTICIPANT	\N	PRESENT	0
564004	558264	08017T	PARTICIPANT	\N	PRESENT	1
564005	558264	14109K	PARTICIPANT	\N	PRESENT	1
564006	558264	20118Y	PARTICIPANT	\N	EXCUSE	0
564007	558264	19798U	PARTICIPANT	\N	PRESENT	1
564008	558264	11045K	PARTICIPANT	\N	PRESENT	0
564009	558264	19527W	PARTICIPANT	\N	PRESENT	1
551936	549006	19717B	PARTICIPANT	\N	EXCUSE	0
551937	549006	19347U	PARTICIPANT	\N	EXCUSE	0
551938	549006	20034V	PARTICIPANT	\N	PRESENT	0
551939	549006	19715Y	PARTICIPANT	\N	PRESENT	0
551940	549006	19583F	PARTICIPANT	\N	PRESENT	0
551941	549006	14059S	PARTICIPANT	\N	EXCUSE	0
551942	549006	12016W	PARTICIPANT	\N	PRESENT	0
551943	549006	19657G	PARTICIPANT	\N	PRESENT	0
551944	549006	14147R	PARTICIPANT	\N	PRESENT	0
551945	549006	11072N	PARTICIPANT	\N	PRESENT	0
551987	545943	01048V	PARTICIPANT	\N	PRESENT	0
551994	551955	11109J	PARTICIPANT	\N	EXCUSE	0
552328	549184	05012A	PARTICIPANT	\N	PRESENT	0
552329	549184	19685L	PARTICIPANT	\N	PRESENT	0
552330	549184	20120S	PARTICIPANT	\N	PRESENT	1
552331	551256	19735D	PARTICIPANT	\N	PRESENT	0
552332	551284	14327T	PARTICIPANT	\N	PRESENT	0
552333	551284	11048N	PARTICIPANT	\N	PRESENT	0
552334	551284	19711U	PARTICIPANT	\N	PRESENT	0
552335	551284	08034U	PARTICIPANT	\N	PRESENT	0
552336	551284	01048V	PARTICIPANT	\N	PRESENT	0
552337	551284	19531S	PARTICIPANT	\N	PRESENT	0
552338	551284	01057W	PARTICIPANT	\N	PRESENT	0
552339	551284	19687N	PARTICIPANT	\N	PRESENT	0
552340	551284	20080C	PARTICIPANT	\N	PRESENT	0
552341	551284	20050V	PARTICIPANT	\N	PRESENT	0
552342	551284	19667J	PARTICIPANT	\N	PRESENT	0
552343	551284	20044X	PARTICIPANT	\N	PRESENT	0
552344	551284	04086Q	PARTICIPANT	\N	PRESENT	0
552345	551284	07029T	PARTICIPANT	\N	PRESENT	0
552346	551284	14083S	PARTICIPANT	\N	PRESENT	0
552347	551284	08009T	PARTICIPANT	\N	PRESENT	0
552348	551284	19349W	PARTICIPANT	\N	PRESENT	0
552349	551284	19741B	PARTICIPANT	\N	PRESENT	0
552350	551284	08010L	PARTICIPANT	\N	PRESENT	0
552351	551284	99004R	PARTICIPANT	\N	PRESENT	0
552352	551284	20116W	PARTICIPANT	\N	PRESENT	0
552353	551284	20022R	PARTICIPANT	\N	PRESENT	0
552354	551284	19762G	PARTICIPANT	\N	PRESENT	0
552355	551284	19335Q	PARTICIPANT	\N	PRESENT	0
552356	551161	14038Y	PARTICIPANT	\N	PRESENT	0
552357	551161	20088L	PARTICIPANT	\N	PRESENT	0
552358	551161	19515S	PARTICIPANT	\N	PRESENT	0
552359	551161	19782L	PARTICIPANT	\N	PRESENT	0
552360	551161	01043Q	PARTICIPANT	\N	PRESENT	0
552361	551161	14187A	PARTICIPANT	\N	PRESENT	0
552362	551161	19441R	PARTICIPANT	\N	PRESENT	0
552363	551161	19695N	PARTICIPANT	\N	PRESENT	0
552364	551161	20082E	PARTICIPANT	\N	PRESENT	0
552365	551161	11090Q	PRESIDENT	0	PRESENT	0
552366	551161	20094J	PARTICIPANT	\N	PRESENT	0
552367	551161	19631V	PARTICIPANT	\N	PRESENT	0
552368	551161	20104S	PARTICIPANT	\N	PRESENT	0
552369	551161	14205J	PARTICIPANT	\N	PRESENT	0
552370	551161	20060X	PARTICIPANT	\N	PRESENT	0
552371	551161	19507S	PARTICIPANT	\N	PRESENT	0
552372	551161	19575F	PARTICIPANT	\N	PRESENT	0
552373	551161	19747H	PARTICIPANT	\N	PRESENT	0
552374	551161	20018V	PARTICIPANT	\N	PRESENT	0
552375	551161	19511N	PARTICIPANT	\N	PRESENT	0
552376	551161	19563B	PARTICIPANT	\N	PRESENT	0
552377	551161	14257W	PARTICIPANT	\N	PRESENT	0
552378	551161	20028X	PARTICIPANT	\N	PRESENT	0
552379	551161	14329V	PARTICIPANT	\N	PRESENT	0
552380	551161	19705W	PARTICIPANT	\N	PRESENT	0
552381	551161	19369B	PARTICIPANT	\N	PRESENT	0
552382	551161	14033T	PARTICIPANT	\N	PRESENT	0
552384	552383	20024T	PARTICIPANT	\N	PRESENT	0
552385	552383	14357A	PARTICIPANT	\N	PRESENT	0
552386	552383	14041T	PARTICIPANT	\N	PRESENT	0
552387	552383	97011G	PARTICIPANT	\N	PRESENT	0
552388	552383	14179A	PARTICIPANT	\N	PRESENT	0
552389	552383	19333N	PARTICIPANT	\N	PRESENT	0
552390	552383	19511N	PARTICIPANT	\N	PRESENT	0
552391	552383	08015R	PARTICIPANT	\N	PRESENT	0
552392	552383	08034U	PARTICIPANT	\N	PRESENT	0
552393	552383	14147R	PARTICIPANT	\N	PRESENT	0
552394	552383	14169X	PARTICIPANT	\N	PRESENT	0
552395	552383	11041F	PARTICIPANT	\N	PRESENT	0
552397	551161	08015R	PARTICIPANT	\N	PRESENT	0
552398	551161	19467C	PARTICIPANT	\N	PRESENT	0
552399	551161	20054A	PARTICIPANT	\N	PRESENT	0
552400	551284	19479G	PARTICIPANT	\N	PRESENT	0
552401	551161	19768N	PARTICIPANT	\N	PRESENT	0
552402	550473	08045X	PARTICIPANT	\N	PRESENT	1
552403	550473	19697Q	PARTICIPANT	\N	PRESENT	1
552404	550473	01034P	PARTICIPANT	\N	PRESENT	1
552405	550473	20066E	PARTICIPANT	\N	PRESENT	0
552406	551161	14357A	PARTICIPANT	\N	PRESENT	0
552414	549184	20024T	PARTICIPANT	\N	PRESENT	1
552422	551284	11053K	PARTICIPANT	\N	PRESENT	0
552423	551256	04070G	PARTICIPANT	\N	PRESENT	1
552425	551161	11077T	PARTICIPANT	\N	PRESENT	1
552426	551161	04045F	PARTICIPANT	\N	PRESENT	1
552427	551161	20174H	PARTICIPANT	\N	PRESENT	1
552428	551161	20062A	PARTICIPANT	\N	PRESENT	1
552429	551161	14251Q	PARTICIPANT	\N	PRESENT	1
552430	551161	14207L	PARTICIPANT	\N	PRESENT	1
552431	551161	11074Q	PARTICIPANT	\N	PRESENT	1
552432	551161	20126Y	PARTICIPANT	\N	PRESENT	1
552433	551161	19521Q	PARTICIPANT	\N	PRESENT	1
552434	551161	19647E	PARTICIPANT	\N	PRESENT	1
552435	551161	20070A	PARTICIPANT	\N	PRESENT	1
552436	551161	19741B	PARTICIPANT	\N	PRESENT	0
552438	551161	14327T	PARTICIPANT	\N	PRESENT	0
552439	551161	01048V	PARTICIPANT	\N	PRESENT	0
552440	551161	01057W	PARTICIPANT	\N	PRESENT	0
552441	551161	19667J	PARTICIPANT	\N	PRESENT	0
552442	551161	07029T	PARTICIPANT	\N	PRESENT	0
552443	551161	19349W	PARTICIPANT	\N	PRESENT	0
552444	551161	19335Q	PARTICIPANT	\N	PRESENT	0
552445	551161	20022R	PARTICIPANT	\N	PRESENT	0
552446	551161	11048N	PARTICIPANT	\N	PRESENT	0
552447	551161	19687N	PARTICIPANT	\N	PRESENT	0
552448	551161	20044X	PARTICIPANT	\N	PRESENT	0
552449	551161	14083S	PARTICIPANT	\N	PRESENT	0
552450	551161	99004R	PARTICIPANT	\N	PRESENT	0
552451	551161	14225N	PARTICIPANT	\N	PRESENT	0
552452	551161	08010L	PARTICIPANT	\N	PRESENT	0
552453	551161	20116W	PARTICIPANT	\N	PRESENT	0
552454	551161	19479G	PARTICIPANT	\N	PRESENT	0
552455	551161	19711U	PARTICIPANT	\N	PRESENT	0
552456	551161	08034U	PARTICIPANT	\N	PRESENT	0
552457	551161	04086Q	PARTICIPANT	\N	PRESENT	0
552458	551161	08009T	PARTICIPANT	\N	PRESENT	0
552459	551161	20080C	PARTICIPANT	\N	PRESENT	0
552460	551161	19531S	PARTICIPANT	\N	PRESENT	0
552461	551161	19762G	PARTICIPANT	\N	PRESENT	0
552462	551161	14121F	PARTICIPANT	\N	PRESENT	1
552463	551161	11053K	PARTICIPANT	\N	PRESENT	0
552600	551161	08073C	PARTICIPANT	\N	PRESENT	1
552710	551735	08015R	PARTICIPANT	\N	PRESENT	0
552711	551735	19701S	PARTICIPANT	\N	PRESENT	0
552712	551735	86034E	PARTICIPANT	\N	PRESENT	0
553554	551451	19387D	PARTICIPANT	\N	PRESENT	0
553555	551451	20122U	PARTICIPANT	\N	PRESENT	0
553556	551451	17589D	PARTICIPANT	\N	PRESENT	0
553557	551451	20132W	PARTICIPANT	\N	PRESENT	0
553558	551451	20066E	PARTICIPANT	\N	PRESENT	0
553559	551451	19593H	PARTICIPANT	\N	PRESENT	0
553583	551451	19954N	PARTICIPANT	\N	PRESENT	0
553561	551451	20142Y	PARTICIPANT	\N	PRESENT	0
553562	551451	11033F	PARTICIPANT	\N	PRESENT	0
553563	551451	20116W	PARTICIPANT	\N	PRESENT	0
553564	551451	17023S	PARTICIPANT	\N	PRESENT	0
553565	551451	14215L	PARTICIPANT	\N	PRESENT	0
553566	551451	17737W	PARTICIPANT	\N	PRESENT	0
553568	551451	20108W	PARTICIPANT	\N	PRESENT	0
553570	551451	04047H	PARTICIPANT	\N	PRESENT	0
553572	551451	19575F	PARTICIPANT	\N	PRESENT	0
553576	551451	20102Q	PARTICIPANT	\N	PRESENT	0
553577	551451	20046A	PARTICIPANT	\N	PRESENT	0
553579	551451	19599P	PARTICIPANT	\N	PRESENT	0
553580	551451	20110Q	PARTICIPANT	\N	PRESENT	0
553581	551451	20072C	PARTICIPANT	\N	PRESENT	0
553584	551451	14147R	PARTICIPANT	\N	PRESENT	0
553585	551451	14038Y	PARTICIPANT	\N	PRESENT	0
553586	551451	19503N	PARTICIPANT	\N	PRESENT	0
553588	551451	20048C	PARTICIPANT	\N	PRESENT	0
542572	542571	17737W	PARTICIPANT	\N	PRESENT	0
542697	542592	14041T	PARTICIPANT	\N	PRESENT	0
542698	542592	14215L	PRESIDENT	0	PRESENT	0
542699	542592	14151M	PARTICIPANT	\N	PRESENT	0
542700	542592	11056N	PARTICIPANT	\N	EXCUSE	0
542701	542592	19447X	PARTICIPANT	\N	PRESENT	0
542702	542592	11072N	PARTICIPANT	\N	PRESENT	0
545956	536572	20114U	PARTICIPANT	\N	PRESENT	0
545957	536572	20180F	PARTICIPANT	\N	PRESENT	0
545958	536572	20056C	PARTICIPANT	\N	PRESENT	0
545959	536572	19735D	PARTICIPANT	\N	PRESENT	0
545960	536572	20052X	PARTICIPANT	\N	PRESENT	0
545961	536572	20142Y	PARTICIPANT	\N	PRESENT	0
545962	536572	14147R	PARTICIPANT	\N	PRESENT	0
545963	536572	14229S	PARTICIPANT	\N	PRESENT	0
545964	536572	20058E	PARTICIPANT	\N	PRESENT	1
546821	546820	05008E	PARTICIPANT	\N	PRESENT	0
546822	546820	11053K	PARTICIPANT	\N	PRESENT	0
546823	546820	01028R	PARTICIPANT	\N	PRESENT	0
548816	548814	14331P	PARTICIPANT	\N	EXCUSE	0
548822	543175	19515S	PARTICIPANT	\N	PRESENT	0
548823	543175	19747H	PARTICIPANT	\N	PRESENT	0
548824	543175	19383Y	PARTICIPANT	\N	PRESENT	0
548825	543175	14329V	PARTICIPANT	\N	PRESENT	0
548826	543175	14038Y	PARTICIPANT	\N	PRESENT	0
548827	543175	20144B	PARTICIPANT	\N	PRESENT	0
548828	543175	14187A	PARTICIPANT	\N	PRESENT	0
548829	543175	20034V	PARTICIPANT	\N	PRESENT	0
548830	543175	19511N	PARTICIPANT	\N	PRESENT	0
548831	543175	01043Q	PARTICIPANT	\N	PRESENT	0
548832	543175	20018V	PARTICIPANT	\N	PRESENT	0
548833	543175	14257W	PARTICIPANT	\N	PRESENT	0
548834	543175	19768N	PARTICIPANT	\N	PRESENT	0
548835	543175	11090Q	PARTICIPANT	\N	PRESENT	0
548836	543175	19631V	PARTICIPANT	\N	PRESENT	1
548837	543175	19575F	PARTICIPANT	\N	PRESENT	1
548838	543175	20088L	PARTICIPANT	\N	PRESENT	1
548839	543175	08028W	PARTICIPANT	\N	PRESENT	1
548840	543175	20174H	PARTICIPANT	\N	PRESENT	1
548841	543175	19369B	PARTICIPANT	\N	PRESENT	1
548842	543175	20030R	PARTICIPANT	\N	PRESENT	1
548843	543175	19705W	PARTICIPANT	\N	PRESENT	1
548844	543175	04045F	PARTICIPANT	\N	PRESENT	1
548846	543175	20062A	PARTICIPANT	\N	PRESENT	1
548847	543175	14123H	PARTICIPANT	\N	PRESENT	0
548848	543175	20048C	PARTICIPANT	\N	PRESENT	0
548849	543175	19399H	PARTICIPANT	\N	PRESENT	0
548850	543175	19735D	PARTICIPANT	\N	PRESENT	0
548851	543175	19611R	PARTICIPANT	\N	PRESENT	0
548852	543175	19699S	PARTICIPANT	\N	PRESENT	0
548853	543175	20052X	PARTICIPANT	\N	PRESENT	0
548854	543175	14109K	PARTICIPANT	\N	PRESENT	1
548855	543175	14229S	PARTICIPANT	\N	PRESENT	0
548856	543175	20058E	PARTICIPANT	\N	PRESENT	0
552818	551256	19651A	PARTICIPANT	\N	PRESENT	1
552819	551256	19643A	PARTICIPANT	\N	PRESENT	1
552821	551256	20134Y	PARTICIPANT	\N	PRESENT	1
552824	551256	19527W	PARTICIPANT	\N	PRESENT	1
552825	551256	20026V	PARTICIPANT	\N	PRESENT	1
552826	551256	20084G	PARTICIPANT	\N	PRESENT	1
552829	551256	11104D	PARTICIPANT	\N	PRESENT	1
552830	551256	20142Y	PARTICIPANT	\N	PRESENT	1
552831	551256	20098N	PARTICIPANT	\N	PRESENT	0
552835	552424	20084G	PARTICIPANT	\N	PRESENT	0
552836	552424	20114U	PARTICIPANT	\N	PRESENT	0
552837	552424	20056C	PARTICIPANT	\N	PRESENT	0
552838	552424	20052X	PARTICIPANT	\N	PRESENT	0
552839	552424	14229S	PARTICIPANT	\N	PRESENT	0
552840	552424	20058E	PARTICIPANT	\N	PRESENT	0
552841	552424	19735D	PARTICIPANT	\N	PRESENT	0
552842	552424	20180F	PARTICIPANT	\N	PRESENT	0
552843	552424	20142Y	PARTICIPANT	\N	PRESENT	0
552844	552424	04070G	PARTICIPANT	\N	PRESENT	0
552845	552424	14147R	PARTICIPANT	\N	PRESENT	0
552847	552424	19611R	PARTICIPANT	\N	PRESENT	0
552848	552424	19643A	PARTICIPANT	\N	PRESENT	0
552853	552424	19693L	PARTICIPANT	\N	PRESENT	0
553916	551287	19741B	PARTICIPANT	\N	PRESENT	1
553917	551287	11040E	PARTICIPANT	\N	PRESENT	1
553919	551287	14121F	PARTICIPANT	\N	PRESENT	1
553921	551287	08010L	PARTICIPANT	\N	PRESENT	1
553922	551287	20050V	PARTICIPANT	\N	PRESENT	1
553923	551287	20150Y	PARTICIPANT	\N	PRESENT	1
553924	551287	19479G	PARTICIPANT	\N	PRESENT	1
553938	551260	14189C	PARTICIPANT	\N	PRESENT	1
553939	551260	20024T	PARTICIPANT	\N	PRESENT	0
553940	551260	14030Q	PRESIDENT	0	PRESENT	0
553941	551260	20080C	PARTICIPANT	\N	EXCUSE	0
553942	551260	19621T	PARTICIPANT	\N	EXCUSE	0
553943	551260	11031D	PARTICIPANT	\N	PRESENT	0
553944	551260	20106U	PARTICIPANT	\N	PRESENT	1
553945	551260	20066E	PARTICIPANT	\N	PRESENT	1
553946	551260	20034V	PARTICIPANT	\N	EXCUSE	0
553947	551260	19715Y	PARTICIPANT	\N	EXCUSE	0
553948	551260	20056C	PARTICIPANT	\N	PRESENT	1
553949	551260	07029T	PARTICIPANT	\N	EXCUSE	0
553950	551260	08017T	PARTICIPANT	\N	PRESENT	1
553951	551260	14109K	PARTICIPANT	\N	PRESENT	1
553952	551260	19866P	PARTICIPANT	\N	PRESENT	0
553953	551260	20118Y	PARTICIPANT	\N	EXCUSE	0
553954	551260	20130U	PARTICIPANT	\N	PRESENT	1
553955	551260	19798U	PARTICIPANT	\N	PRESENT	1
553956	551260	20098N	PARTICIPANT	\N	PRESENT	1
553957	551260	19527W	PARTICIPANT	\N	PRESENT	1
553958	551260	20046A	PARTICIPANT	\N	PRESENT	0
553959	551260	19749K	PARTICIPANT	\N	PRESENT	1
553978	553976	19768N	PARTICIPANT	\N	PRESENT	0
553979	553976	19383Y	PARTICIPANT	\N	PRESENT	0
553980	553976	19705W	PARTICIPANT	\N	PRESENT	0
553981	553976	20034V	PARTICIPANT	\N	PRESENT	0
553983	553982	19768N	PARTICIPANT	\N	PRESENT	0
553984	553982	19383Y	PARTICIPANT	\N	PRESENT	0
553985	553982	19705W	PARTICIPANT	\N	PRESENT	0
553986	553982	20034V	PARTICIPANT	\N	PRESENT	0
553987	553982	19631V	PARTICIPANT	\N	PRESENT	0
553988	553982	19575F	PARTICIPANT	\N	PRESENT	0
554016	554015	19667J	PARTICIPANT	\N	PRESENT	0
554017	554015	20022R	PARTICIPANT	\N	PRESENT	0
554018	554015	11033F	PARTICIPANT	\N	PRESENT	0
554019	554015	19643A	PARTICIPANT	\N	PRESENT	0
554020	554015	20090E	PARTICIPANT	\N	PRESENT	0
554021	554015	14329V	PARTICIPANT	\N	PRESENT	0
554022	554015	19467C	PARTICIPANT	\N	PRESENT	0
554023	554015	20124W	PARTICIPANT	\N	PRESENT	0
554024	554015	19333N	PARTICIPANT	\N	PRESENT	0
554025	554015	14059S	PARTICIPANT	\N	PRESENT	0
554026	554015	19745F	PARTICIPANT	\N	PRESENT	0
554027	554015	11090Q	PARTICIPANT	\N	PRESENT	0
554028	554015	20054A	PARTICIPANT	\N	PRESENT	0
554029	554015	19713W	PARTICIPANT	\N	PRESENT	0
554033	554032	20136B	PARTICIPANT	\N	PRESENT	0
554034	554032	19701S	PARTICIPANT	\N	PRESENT	0
554038	554032	19549D	PARTICIPANT	\N	PRESENT	0
554036	554032	19826F	PARTICIPANT	\N	PRESENT	0
554037	554032	19637C	PARTICIPANT	\N	PRESENT	0
554039	554032	20120S	PARTICIPANT	\N	PRESENT	0
554040	554032	14205J	PARTICIPANT	\N	PRESENT	0
554042	554041	20136B	PARTICIPANT	\N	PRESENT	0
554043	554041	19701S	PARTICIPANT	\N	PRESENT	0
554044	554041	20120S	PARTICIPANT	\N	PRESENT	0
554045	554041	17367Q	PARTICIPANT	\N	PRESENT	0
554046	554041	19637C	PARTICIPANT	\N	PRESENT	0
554047	554041	20046A	PARTICIPANT	\N	PRESENT	0
554048	554041	19387D	PARTICIPANT	\N	PRESENT	0
554050	554049	20136B	PARTICIPANT	\N	PRESENT	0
554054	554049	19387D	PARTICIPANT	\N	PRESENT	0
554052	554049	19826F	PARTICIPANT	\N	PRESENT	0
554053	554049	20120S	PARTICIPANT	\N	PRESENT	0
554058	554056	19701S	PARTICIPANT	\N	PRESENT	0
554060	554056	19739H	PARTICIPANT	\N	PRESENT	0
554061	554056	20122U	PARTICIPANT	\N	PRESENT	0
554066	554064	19701S	PARTICIPANT	\N	PRESENT	0
554063	554056	19631V	PARTICIPANT	\N	PRESENT	0
554065	554064	20136B	PARTICIPANT	\N	PRESENT	0
554067	554064	19739H	PARTICIPANT	\N	PRESENT	0
554068	554064	20122U	PARTICIPANT	\N	PRESENT	0
554069	554064	19251M	PARTICIPANT	\N	PRESENT	0
554070	554064	19551W	PARTICIPANT	\N	PRESENT	0
554071	554064	20120S	PARTICIPANT	\N	PRESENT	0
554074	554072	20136B	PARTICIPANT	\N	PRESENT	0
562500	562199	20138D	PARTICIPANT	\N	PRESENT	0
562501	562199	14215L	PARTICIPANT	\N	PRESENT	0
562502	562199	14038Y	PARTICIPANT	\N	PRESENT	0
562503	562199	11031D	PARTICIPANT	\N	PRESENT	0
562504	562199	20036X	PARTICIPANT	\N	PRESENT	0
562505	562199	19573D	PARTICIPANT	\N	PRESENT	0
562506	562199	14111D	PARTICIPANT	\N	PRESENT	0
562507	562199	19479G	PARTICIPANT	\N	PRESENT	0
562508	562199	19673G	PARTICIPANT	\N	PRESENT	0
562509	562199	20056C	PARTICIPANT	\N	PRESENT	0
562510	562199	19749K	PARTICIPANT	\N	PRESENT	0
562511	562199	99004R	PARTICIPANT	\N	PRESENT	0
562512	562199	19691J	PARTICIPANT	\N	PRESENT	0
562513	562199	20044X	PARTICIPANT	\N	PRESENT	0
562514	562199	20152B	PARTICIPANT	\N	PRESENT	0
562498	562199	20108W	PARTICIPANT	\N	PRESENT	0
562499	562199	19703U	PARTICIPANT	\N	PRESENT	0
562515	562199	19647E	PARTICIPANT	\N	PRESENT	0
562516	562199	18083K	PARTICIPANT	\N	PRESENT	0
562517	562199	19741B	PARTICIPANT	\N	PRESENT	0
562518	562199	20062A	PARTICIPANT	\N	PRESENT	0
562519	562199	01048V	PARTICIPANT	\N	PRESENT	0
562520	562199	19747H	PARTICIPANT	\N	PRESENT	0
562521	562199	19533U	PARTICIPANT	\N	PRESENT	0
562522	562199	08045X	PARTICIPANT	\N	PRESENT	0
562523	562199	14055N	PARTICIPANT	\N	PRESENT	0
562524	562199	14033T	PARTICIPANT	\N	PRESENT	0
562525	562199	20048C	PARTICIPANT	\N	PRESENT	0
562527	562199	14089Y	PARTICIPANT	\N	PRESENT	0
562531	562199	19333N	PARTICIPANT	\N	PRESENT	0
562544	562199	20144B	PARTICIPANT	\N	PRESENT	0
562545	562199	19649G	PARTICIPANT	\N	PRESENT	0
562546	562199	19549D	PARTICIPANT	\N	PRESENT	0
562547	561762	01048V	PARTICIPANT	\N	PRESENT	0
562548	561762	20070A	PARTICIPANT	\N	PRESENT	0
562549	561762	19349W	PARTICIPANT	\N	PRESENT	0
562550	561762	14225N	PRESIDENT	0	PRESENT	0
562551	561762	07029T	PARTICIPANT	\N	EXCUSE	0
562552	562199	20058E	PARTICIPANT	\N	PRESENT	0
562553	561762	20136B	PARTICIPANT	\N	PRESENT	0
562557	562556	18193Q	PARTICIPANT	\N	PRESENT	0
562558	561762	14327T	PARTICIPANT	\N	PRESENT	0
562559	561762	14083S	PARTICIPANT	\N	PRESENT	0
562560	561762	11048N	PARTICIPANT	\N	PRESENT	0
562561	561762	19479G	PARTICIPANT	\N	PRESENT	0
562562	561762	01057W	PARTICIPANT	\N	PRESENT	0
562563	561762	19335Q	PARTICIPANT	\N	PRESENT	0
562564	561762	20126Y	PARTICIPANT	\N	PRESENT	0
562565	561762	20022R	PARTICIPANT	\N	PRESENT	0
562566	561762	19647E	PARTICIPANT	\N	PRESENT	0
562567	561762	19711U	PARTICIPANT	\N	PRESENT	0
562568	561762	20116W	PARTICIPANT	\N	PRESENT	0
562569	562199	14147R	PARTICIPANT	\N	PRESENT	0
562570	561762	20044X	PARTICIPANT	\N	PRESENT	0
562571	561762	08009T	PARTICIPANT	\N	PRESENT	0
562572	562199	04008A	PARTICIPANT	\N	PRESENT	0
562575	562199	10015M	PARTICIPANT	\N	PRESENT	0
562577	562199	14031R	PARTICIPANT	\N	PRESENT	0
562578	562199	14219Q	PARTICIPANT	\N	PRESENT	0
562580	562199	20090E	PARTICIPANT	\N	PRESENT	0
562581	561762	19667J	PARTICIPANT	\N	PRESENT	0
562582	562199	19383Y	PARTICIPANT	\N	PRESENT	0
562583	562199	20026V	PARTICIPANT	\N	PRESENT	0
562584	562199	19507S	PARTICIPANT	\N	PRESENT	0
562636	562340	18193Q	PARTICIPANT	\N	PRESENT	1
562637	562200	19673G	PARTICIPANT	\N	PRESENT	0
562638	562200	99004R	PARTICIPANT	\N	PRESENT	0
562639	562200	07004J	PARTICIPANT	\N	PRESENT	0
562640	562200	19703U	PARTICIPANT	\N	PRESENT	0
562641	562200	04047H	PARTICIPANT	\N	PRESENT	0
562642	562200	20110Q	PARTICIPANT	\N	PRESENT	0
562643	562200	20128B	PARTICIPANT	\N	PRESENT	0
562644	562200	19719D	PARTICIPANT	\N	PRESENT	0
562645	562200	01028R	PARTICIPANT	\N	PRESENT	0
562647	562646	11097X	PARTICIPANT	\N	PRESENT	1
562648	562200	04085P	PARTICIPANT	\N	PRESENT	0
562650	562200	14055N	PARTICIPANT	\N	PRESENT	0
562651	562200	14111D	PARTICIPANT	\N	PRESENT	0
562652	562200	19749K	PARTICIPANT	\N	PRESENT	0
562653	562200	10006L	PARTICIPANT	\N	PRESENT	0
562655	562200	14053L	PARTICIPANT	\N	PRESENT	0
562656	562200	14147R	PARTICIPANT	\N	PRESENT	0
562657	562200	14083S	PARTICIPANT	\N	PRESENT	0
562658	562200	19479G	PARTICIPANT	\N	PRESENT	0
562673	562200	20138D	PARTICIPANT	\N	PRESENT	0
562674	562200	97011G	PARTICIPANT	\N	PRESENT	0
562675	562200	19507S	PARTICIPANT	\N	PRESENT	0
562676	562200	20108W	PARTICIPANT	\N	PRESENT	0
562677	562200	19383Y	PARTICIPANT	\N	PRESENT	0
562678	562200	19447X	PARTICIPANT	\N	PRESENT	0
562679	562200	19565D	PARTICIPANT	\N	PRESENT	0
562680	562200	20062A	PARTICIPANT	\N	PRESENT	0
562681	562200	19649G	PARTICIPANT	\N	PRESENT	0
562682	562200	11033F	PARTICIPANT	\N	PRESENT	0
562683	562200	19629C	PARTICIPANT	\N	PRESENT	0
562684	562200	20054A	PARTICIPANT	\N	PRESENT	0
562685	562200	19399H	PARTICIPANT	\N	PRESENT	0
562686	562200	04033B	PARTICIPANT	\N	PRESENT	0
562687	562200	10015M	PARTICIPANT	\N	PRESENT	0
562688	562200	20140W	PARTICIPANT	\N	PRESENT	0
562689	562200	20090E	PARTICIPANT	\N	PRESENT	0
562690	562200	14217N	PARTICIPANT	\N	PRESENT	0
562691	562200	20092G	PARTICIPANT	\N	PRESENT	0
562692	562200	17737W	PARTICIPANT	\N	PRESENT	0
562693	562200	20142Y	PARTICIPANT	\N	PRESENT	0
562695	562200	20052X	PARTICIPANT	\N	PRESENT	0
562696	562200	19333N	PARTICIPANT	\N	PRESENT	0
562697	562200	14121F	PARTICIPANT	\N	PRESENT	0
562698	562200	11012A	PARTICIPANT	\N	PRESENT	0
562699	562200	08010L	PARTICIPANT	\N	PRESENT	0
562700	562200	20116W	PARTICIPANT	\N	PRESENT	0
562701	562200	14133K	PARTICIPANT	\N	PRESENT	0
562702	562200	11104D	PARTICIPANT	\N	PRESENT	0
562634	562200	14215L	PARTICIPANT	\N	PRESENT	0
562635	562340	19679N	PARTICIPANT	\N	PRESENT	1
562703	562200	19729F	PARTICIPANT	\N	PRESENT	0
562704	562649	11097X	PARTICIPANT	\N	PRESENT	1
562705	562649	17779H	PARTICIPANT	\N	PRESENT	1
562706	562649	20130U	PARTICIPANT	\N	PRESENT	1
562707	562200	01024M	PARTICIPANT	\N	PRESENT	0
562709	562200	11067R	PARTICIPANT	\N	PRESENT	0
562710	562200	14213J	PARTICIPANT	\N	PRESENT	0
562711	562708	18193Q	PARTICIPANT	\N	PRESENT	1
562712	562708	20130U	PARTICIPANT	\N	PRESENT	1
562713	562200	20098N	PARTICIPANT	\N	PRESENT	0
562714	562200	14026U	PARTICIPANT	\N	PRESENT	0
562715	562200	14187A	PARTICIPANT	\N	PRESENT	0
562716	562200	11048N	PARTICIPANT	\N	PRESENT	0
562717	562200	14259Y	PARTICIPANT	\N	PRESENT	0
562718	562200	14030Q	PARTICIPANT	\N	PRESENT	0
562719	562200	19349W	PARTICIPANT	\N	PRESENT	0
562721	562200	19760E	PARTICIPANT	\N	PRESENT	0
562723	562200	19747H	PARTICIPANT	\N	PRESENT	0
562724	562200	20026V	PARTICIPANT	\N	PRESENT	0
562725	562200	14219Q	PARTICIPANT	\N	PRESENT	0
562726	562200	20126Y	PARTICIPANT	\N	PRESENT	0
562727	562200	20056C	PARTICIPANT	\N	PRESENT	0
562728	562200	20070A	PARTICIPANT	\N	PRESENT	0
562729	562200	14021P	PARTICIPANT	\N	PRESENT	0
562730	562200	19533U	PARTICIPANT	\N	PRESENT	0
562731	562200	01048V	PARTICIPANT	\N	PRESENT	0
562733	562200	14179A	PARTICIPANT	\N	PRESENT	0
562734	562200	01043Q	PARTICIPANT	\N	PRESENT	0
562735	562200	14089Y	PARTICIPANT	\N	PRESENT	0
562736	562200	19621T	PARTICIPANT	\N	PRESENT	0
562737	562200	18083K	PARTICIPANT	\N	PRESENT	0
562738	562200	11097X	PARTICIPANT	\N	PRESENT	0
562739	562200	14073Q	PARTICIPANT	\N	PRESENT	0
562861	562859	14331P	PARTICIPANT	\N	PRESENT	0
562862	562859	10015M	PARTICIPANT	\N	PRESENT	0
562863	562859	04057K	PARTICIPANT	\N	PRESENT	0
562867	562770	14169X	PARTICIPANT	\N	PRESENT	1
562943	562942	05008E	PARTICIPANT	\N	PRESENT	0
562944	562942	11053K	PARTICIPANT	\N	PRESENT	0
562945	562942	01028R	PARTICIPANT	\N	PRESENT	0
562993	562554	20138D	PARTICIPANT	\N	PRESENT	0
562994	561763	19741B	PARTICIPANT	\N	PRESENT	1
562995	561763	19545Y	PARTICIPANT	\N	PRESENT	1
562996	561763	19647E	PARTICIPANT	\N	PRESENT	1
562997	561763	14121F	PARTICIPANT	\N	PRESENT	1
562998	561763	99004R	PARTICIPANT	\N	PRESENT	1
562999	561763	08010L	PARTICIPANT	\N	PRESENT	1
563000	561763	19671E	PARTICIPANT	\N	PRESENT	1
542292	539552	17023S	PARTICIPANT	\N	PRESENT	0
542293	539552	20126Y	PARTICIPANT	\N	PRESENT	0
542294	539552	20090E	PARTICIPANT	\N	PRESENT	0
542295	539552	17737W	PARTICIPANT	\N	PRESENT	0
542296	539552	05008E	PARTICIPANT	\N	PRESENT	0
542297	539552	19687N	PARTICIPANT	\N	PRESENT	0
542298	539552	19749K	PARTICIPANT	\N	PRESENT	0
542299	539552	07029T	PARTICIPANT	\N	PRESENT	0
542300	539552	20056C	PARTICIPANT	\N	PRESENT	0
542301	539552	20032T	PARTICIPANT	\N	PRESENT	0
542302	539552	20180F	PARTICIPANT	\N	PRESENT	0
542303	539552	10015M	PARTICIPANT	\N	PRESENT	0
542304	539552	20136B	PARTICIPANT	\N	PRESENT	0
542305	539552	20098N	PARTICIPANT	\N	PRESENT	0
542306	539552	17367Q	PARTICIPANT	\N	PRESENT	0
542307	539552	19447X	PARTICIPANT	\N	PRESENT	0
542308	539552	20034V	PARTICIPANT	\N	PRESENT	0
542309	539552	20044X	PARTICIPANT	\N	PRESENT	0
542310	539552	11048N	PARTICIPANT	\N	PRESENT	0
542311	539552	14038Y	PARTICIPANT	\N	PRESENT	0
542312	539552	14187A	PARTICIPANT	\N	PRESENT	0
542313	539552	11097X	PARTICIPANT	\N	PRESENT	0
542315	539552	04085P	PARTICIPANT	\N	PRESENT	0
542316	539552	11056N	PARTICIPANT	\N	PRESENT	0
542317	539552	14053L	PARTICIPANT	\N	PRESENT	0
542318	539552	14071N	PARTICIPANT	\N	PRESENT	0
542319	539552	20022R	PARTICIPANT	\N	PRESENT	0
542323	539552	20130U	PARTICIPANT	\N	PRESENT	0
542324	539552	04071H	PARTICIPANT	\N	PRESENT	0
542325	539552	20062A	PARTICIPANT	\N	PRESENT	0
542326	539552	20124W	PARTICIPANT	\N	PRESENT	0
542327	539552	14213J	PARTICIPANT	\N	PRESENT	0
542328	539552	14231L	PARTICIPANT	\N	PRESENT	0
542330	539552	14217N	PARTICIPANT	\N	PRESENT	0
542331	539552	19527W	PARTICIPANT	\N	PRESENT	0
542332	539552	19333N	PARTICIPANT	\N	PRESENT	0
542333	539552	18083K	PARTICIPANT	\N	PRESENT	0
542334	539552	19647E	PARTICIPANT	\N	PRESENT	0
542335	539552	19741B	PARTICIPANT	\N	PRESENT	0
542336	539552	01028R	PARTICIPANT	\N	PRESENT	0
542337	539552	14211G	PARTICIPANT	\N	PRESENT	0
542338	539552	20086J	PARTICIPANT	\N	PRESENT	0
542339	539552	19347U	PARTICIPANT	\N	PRESENT	0
542340	539552	14259Y	PARTICIPANT	\N	PRESENT	0
542341	539552	04033B	PARTICIPANT	\N	PRESENT	0
542342	539552	95063L	PARTICIPANT	\N	PRESENT	0
542343	539552	19693L	PARTICIPANT	\N	PRESENT	0
542344	539552	14111D	PARTICIPANT	\N	PRESENT	0
542345	539552	20070A	PARTICIPANT	\N	PRESENT	0
542346	539552	14069U	PARTICIPANT	\N	PRESENT	0
542347	539552	14357A	PARTICIPANT	\N	PRESENT	0
542348	539552	20134Y	PARTICIPANT	\N	PRESENT	0
542349	539552	14083S	PARTICIPANT	\N	PRESENT	0
542350	539552	20092G	PARTICIPANT	\N	PRESENT	0
546041	544112	19631V	PARTICIPANT	\N	PRESENT	1
546042	544112	18193Q	PRESIDENT	0	PRESENT	0
546043	544112	20130U	PARTICIPANT	\N	PRESENT	1
546045	544112	19679N	PARTICIPANT	\N	PRESENT	0
546046	544112	20066E	PARTICIPANT	\N	PRESENT	0
546047	544112	20040T	PARTICIPANT	\N	PRESENT	0
546048	544112	19760E	PARTICIPANT	\N	PRESENT	1
546050	544112	11053K	PARTICIPANT	\N	PRESENT	0
555439	555438	19711U	PARTICIPANT	\N	PRESENT	0
555441	555440	19711U	PARTICIPANT	\N	PRESENT	0
555443	555442	19711U	PARTICIPANT	\N	PRESENT	0
556331	555857	19739H	PARTICIPANT	\N	PRESENT	0
556334	556333	19251M	PARTICIPANT	\N	PRESENT	0
556335	556333	19593H	PARTICIPANT	\N	PRESENT	0
556336	556333	14109K	PARTICIPANT	\N	PRESENT	0
556337	556333	19349W	PARTICIPANT	\N	PRESENT	0
556338	556333	20110Q	PARTICIPANT	\N	PRESENT	0
556339	556333	04035D	PARTICIPANT	\N	PRESENT	0
556340	556333	19515S	PARTICIPANT	\N	PRESENT	0
556341	556333	14179A	PARTICIPANT	\N	PRESENT	0
556342	556333	17737W	PARTICIPANT	\N	PRESENT	0
556344	556343	19575F	PARTICIPANT	\N	PRESENT	0
556345	556343	20114U	PARTICIPANT	\N	PRESENT	0
556346	556343	14255U	PARTICIPANT	\N	PRESENT	0
556347	556343	19681G	PARTICIPANT	\N	PRESENT	0
556348	556343	17589D	PARTICIPANT	\N	PRESENT	0
556349	556343	01024M	PARTICIPANT	\N	PRESENT	0
556350	556343	19691J	PARTICIPANT	\N	PRESENT	0
556351	556343	14179A	PARTICIPANT	\N	PRESENT	0
556352	556343	19333N	PARTICIPANT	\N	PRESENT	0
556353	556343	14213J	PARTICIPANT	\N	PRESENT	0
556354	556343	07029T	PARTICIPANT	\N	PRESENT	0
556355	556343	08047A	PARTICIPANT	\N	PRESENT	0
556356	556343	19745F	PARTICIPANT	\N	PRESENT	0
556357	556343	19349W	PARTICIPANT	\N	PRESENT	0
556358	556343	19798U	PARTICIPANT	\N	PRESENT	0
556359	556343	04045F	PARTICIPANT	\N	PRESENT	0
556360	556343	19713W	PARTICIPANT	\N	PRESENT	0
557457	557456	14069U	PARTICIPANT	\N	PRESENT	0
557458	557456	11072N	PARTICIPANT	\N	PRESENT	0
557460	557459	14069U	PARTICIPANT	\N	PRESENT	0
557461	557459	11072N	PARTICIPANT	\N	PRESENT	0
557464	557463	11072N	PARTICIPANT	\N	PRESENT	0
557465	557463	14069U	PARTICIPANT	\N	PRESENT	0
557467	557466	14069U	PARTICIPANT	\N	PRESENT	0
557468	557466	11072N	PARTICIPANT	\N	PRESENT	0
560621	560614	20094J	PARTICIPANT	\N	PRESENT	0
560623	560622	20094J	PARTICIPANT	\N	PRESENT	0
560624	560622	04070G	PARTICIPANT	\N	PRESENT	0
564013	559526	14189C	PARTICIPANT	\N	EXCUSE	0
564014	559526	20024T	PARTICIPANT	\N	PRESENT	1
564015	559526	14030Q	PRESIDENT	0	PRESENT	0
564016	559526	17737W	PARTICIPANT	\N	EXCUSE	0
564017	559526	11031D	PARTICIPANT	\N	PRESENT	0
564018	559526	19693L	PARTICIPANT	\N	EXCUSE	0
564019	559526	19599P	PARTICIPANT	\N	PRESENT	0
564020	559526	20066E	PARTICIPANT	\N	PRESENT	1
564021	559526	20034V	PARTICIPANT	\N	PRESENT	1
564022	559526	20056C	PARTICIPANT	\N	PRESENT	0
564023	559526	07029T	PARTICIPANT	\N	PRESENT	0
564024	559526	08017T	PARTICIPANT	\N	PRESENT	1
564025	559526	14109K	PARTICIPANT	\N	PRESENT	1
564026	559526	20118Y	PARTICIPANT	\N	EXCUSE	0
564027	559526	19798U	PARTICIPANT	\N	PRESENT	1
564028	559526	11045K	PARTICIPANT	\N	PRESENT	0
564029	559526	19527W	PARTICIPANT	\N	PRESENT	1
564131	560332	12016W	PARTICIPANT	\N	EXCUSE	0
564132	560332	14331P	PARTICIPANT	\N	EXCUSE	0
564133	560332	19631V	PARTICIPANT	\N	EXCUSE	0
564134	560332	18083K	PARTICIPANT	\N	PRESENT	0
564135	560332	19691J	PARTICIPANT	\N	PRESENT	1
564136	560332	20034V	PARTICIPANT	\N	PRESENT	1
564137	560332	08034U	PARTICIPANT	\N	PRESENT	0
564138	560332	14147R	PARTICIPANT	\N	PRESENT	1
564139	560332	20028X	PARTICIPANT	\N	PRESENT	1
564328	564327	14097Y	PARTICIPANT	\N	PRESENT	0
564329	564327	14133K	PARTICIPANT	\N	PRESENT	0
564330	564327	11083R	PARTICIPANT	\N	PRESENT	0
564332	564331	14097Y	PARTICIPANT	\N	PRESENT	0
564333	564331	14133K	PARTICIPANT	\N	PRESENT	0
564334	564331	11083R	PARTICIPANT	\N	PRESENT	0
564353	561876	14189C	PARTICIPANT	\N	EXCUSE	0
564358	564357	14147R	PARTICIPANT	\N	PRESENT	0
565120	564254	20086J	PARTICIPANT	\N	PRESENT	0
565121	564254	14033T	PARTICIPANT	\N	PRESENT	0
565122	564254	20174H	PARTICIPANT	\N	PRESENT	1
565129	563961	14111D	PARTICIPANT	\N	PRESENT	0
565130	563961	04092N	PARTICIPANT	\N	PRESENT	0
565131	563961	04047H	PRESIDENT	0	PRESENT	0
565132	563961	01028R	PARTICIPANT	\N	PRESENT	0
565133	563961	19447X	PARTICIPANT	\N	PRESENT	0
565134	563961	05008E	PARTICIPANT	\N	PRESENT	0
565135	563961	14231L	PARTICIPANT	\N	PRESENT	0
565136	563961	11056N	PARTICIPANT	\N	PRESENT	0
565137	563961	95063L	PARTICIPANT	\N	PRESENT	0
565138	563961	20068G	PARTICIPANT	\N	PRESENT	0
565139	563961	14041T	PARTICIPANT	\N	PRESENT	0
565140	563961	20108W	PARTICIPANT	\N	PRESENT	0
565141	563961	20110Q	PARTICIPANT	\N	PRESENT	0
565142	563961	14147R	PARTICIPANT	\N	PRESENT	0
565143	563961	14151M	PARTICIPANT	\N	PRESENT	0
565144	563961	14215L	PARTICIPANT	\N	PRESENT	0
565145	563961	08018U	PARTICIPANT	\N	PRESENT	0
565146	563961	19749K	PARTICIPANT	\N	PRESENT	0
565147	563961	14259Y	PARTICIPANT	\N	PRESENT	0
565148	563961	11072N	PARTICIPANT	\N	PRESENT	0
565149	563961	14001X	PARTICIPANT	\N	PRESENT	0
553589	551451	20060X	PARTICIPANT	\N	PRESENT	0
553590	551451	01024M	PARTICIPANT	\N	PRESENT	0
553591	551451	14030Q	PARTICIPANT	\N	PRESENT	0
553592	551451	14071N	PARTICIPANT	\N	PRESENT	0
553593	551451	20024T	PARTICIPANT	\N	PRESENT	0
553594	551451	20090E	PARTICIPANT	\N	PRESENT	0
553595	551451	19760E	PARTICIPANT	\N	PRESENT	0
553596	551451	14097Y	PARTICIPANT	\N	PRESENT	0
553597	551451	14021P	PARTICIPANT	\N	PRESENT	0
553598	551451	19747H	PARTICIPANT	\N	PRESENT	0
553599	551284	20070A	PARTICIPANT	\N	PRESENT	1
553600	551451	18083K	PARTICIPANT	\N	PRESENT	0
553601	551451	14169X	PARTICIPANT	\N	PRESENT	0
553602	551451	01028R	PARTICIPANT	\N	PRESENT	0
553604	551451	19415P	PARTICIPANT	\N	PRESENT	0
553605	551451	19467C	PARTICIPANT	\N	PRESENT	0
553606	551451	19643A	PARTICIPANT	\N	PRESENT	0
553609	551451	19369B	PARTICIPANT	\N	PRESENT	0
553610	551451	20054A	PARTICIPANT	\N	PRESENT	0
553613	551451	20100N	PARTICIPANT	\N	PRESENT	0
553648	551285	14121F	PARTICIPANT	\N	PRESENT	1
553649	551285	12016W	PARTICIPANT	\N	PRESENT	1
553650	551285	19671E	PARTICIPANT	\N	PRESENT	1
553651	551285	14173T	PARTICIPANT	\N	PRESENT	1
553652	551285	01034P	PARTICIPANT	\N	PRESENT	1
553653	551285	20130U	PARTICIPANT	\N	PRESENT	1
553654	551285	14179A	PARTICIPANT	\N	PRESENT	1
553655	551285	20042V	PARTICIPANT	\N	PRESENT	1
553656	551285	20082E	PARTICIPANT	\N	PRESENT	1
553657	551285	14207L	PARTICIPANT	\N	PRESENT	1
553658	551285	19301E	PARTICIPANT	\N	PRESENT	1
553659	551285	19563B	PARTICIPANT	\N	PRESENT	1
553878	551543	19651A	PARTICIPANT	\N	PRESENT	0
553879	551543	11040E	PARTICIPANT	\N	PRESENT	0
553880	551543	20042V	PARTICIPANT	\N	PRESENT	0
553881	551543	19747H	PARTICIPANT	\N	PRESENT	0
553882	551543	20144B	PARTICIPANT	\N	PRESENT	0
553883	551543	11056N	PARTICIPANT	\N	PRESENT	0
553884	551543	20132W	PARTICIPANT	\N	PRESENT	0
553886	551543	99004R	PARTICIPANT	\N	EXCUSE	0
553894	551543	19711U	PARTICIPANT	\N	PRESENT	0
553895	551543	19479G	PARTICIPANT	\N	PRESENT	0
553896	551543	19553Y	PARTICIPANT	\N	PRESENT	0
554252	554250	04047H	PARTICIPANT	\N	PRESENT	0
554253	554250	14053L	PARTICIPANT	\N	PRESENT	0
554254	554250	14299H	PARTICIPANT	\N	PRESENT	0
554257	554250	11066Q	PARTICIPANT	\N	PRESENT	0
554304	554244	19593H	PRESIDENT	0	PRESENT	0
554377	554244	20142Y	PARTICIPANT	\N	PRESENT	1
554378	554244	19611R	PARTICIPANT	\N	PRESENT	0
554379	554244	19735D	PARTICIPANT	\N	EXCUSE	0
554380	554244	14059S	PARTICIPANT	\N	PRESENT	0
554381	554244	19721W	PARTICIPANT	\N	PRESENT	1
554382	554244	20082E	PARTICIPANT	\N	PRESENT	1
554383	554244	20034V	PARTICIPANT	\N	PRESENT	0
554384	554244	19717B	PARTICIPANT	\N	PRESENT	1
554385	554244	11072N	PARTICIPANT	\N	PRESENT	1
554386	554244	19319Q	PARTICIPANT	\N	PRESENT	1
554387	554244	97011G	PARTICIPANT	\N	PRESENT	1
554390	554389	19611R	PARTICIPANT	\N	PRESENT	0
554391	554389	19735D	PARTICIPANT	\N	PRESENT	1
554392	554389	19593H	PRESIDENT	0	PRESENT	0
554393	554389	19715Y	PARTICIPANT	\N	PRESENT	0
554394	554389	20114U	PARTICIPANT	\N	PRESENT	1
554395	554389	20132W	PARTICIPANT	\N	PRESENT	1
554396	554389	19643A	PARTICIPANT	\N	PRESENT	1
554397	554389	20082E	PARTICIPANT	\N	PRESENT	1
554906	553338	19679N	PARTICIPANT	\N	PRESENT	0
554554	553250	14259Y	PRESIDENT	0	PRESENT	0
554905	553338	18193Q	PARTICIPANT	\N	PRESENT	0
554907	551738	18193Q	PARTICIPANT	\N	PRESENT	0
554908	551738	19679N	PARTICIPANT	\N	PRESENT	0
554909	551739	19679N	PARTICIPANT	\N	PRESENT	0
554910	551739	18193Q	PARTICIPANT	\N	PRESENT	0
554911	551739	20130U	PARTICIPANT	\N	PRESENT	0
554912	551739	20098N	PARTICIPANT	\N	PRESENT	0
554913	551740	19679N	PARTICIPANT	\N	PRESENT	0
554914	551740	20130U	PARTICIPANT	\N	PRESENT	0
554915	551740	18193Q	PARTICIPANT	\N	PRESENT	0
554916	551741	18193Q	PARTICIPANT	\N	PRESENT	0
554917	551741	20130U	PARTICIPANT	\N	PRESENT	0
554918	551741	19679N	PARTICIPANT	\N	PRESENT	0
555223	555222	14205J	PARTICIPANT	\N	PRESENT	0
555224	555219	20136B	PARTICIPANT	\N	PRESENT	0
555225	555219	19637C	PARTICIPANT	\N	PRESENT	0
555227	555226	19467C	PARTICIPANT	\N	PRESENT	0
555228	555226	11033F	PARTICIPANT	\N	PRESENT	0
555229	555219	19711U	PARTICIPANT	\N	PRESENT	0
555231	555230	14205J	PARTICIPANT	\N	PRESENT	0
555232	555230	11033F	PARTICIPANT	\N	PRESENT	0
555234	555233	20136B	PARTICIPANT	\N	PRESENT	0
555235	555233	20100N	PARTICIPANT	\N	PRESENT	0
555236	555219	20100N	PARTICIPANT	\N	PRESENT	0
555237	555221	20136B	PARTICIPANT	\N	PRESENT	0
555238	555221	20100N	PARTICIPANT	\N	PRESENT	0
555240	555239	20136B	PARTICIPANT	\N	PRESENT	0
555241	555239	20100N	PARTICIPANT	\N	PRESENT	0
555242	555239	19251M	PARTICIPANT	\N	PRESENT	0
555244	555243	20136B	PARTICIPANT	\N	PRESENT	0
555245	555243	20100N	PARTICIPANT	\N	PRESENT	0
555247	555246	05008E	PARTICIPANT	\N	PRESENT	0
555248	555246	11053K	PARTICIPANT	\N	PRESENT	0
555249	555246	01028R	PARTICIPANT	\N	PRESENT	0
555271	555270	14205J	PARTICIPANT	\N	PRESENT	1
555278	555276	14205J	PARTICIPANT	\N	PRESENT	0
555280	555279	14205J	PARTICIPANT	\N	PRESENT	0
555284	555281	14205J	PARTICIPANT	\N	PRESENT	0
555295	555291	14205J	PARTICIPANT	\N	PRESENT	0
555298	555292	14205J	PARTICIPANT	\N	PRESENT	0
555347	555346	19826F	PARTICIPANT	\N	PRESENT	0
555349	555348	99004R	PARTICIPANT	\N	PRESENT	1
555350	555348	19683J	PARTICIPANT	\N	PRESENT	1
555352	555351	14231L	PRESIDENT	0	PRESENT	0
555369	555069	19679N	PARTICIPANT	\N	PRESENT	0
555370	555069	18193Q	PARTICIPANT	\N	PRESENT	0
555404	545944	20066E	PARTICIPANT	\N	PRESENT	0
555406	555405	19383Y	PARTICIPANT	\N	PRESENT	0
555407	555405	19719D	PARTICIPANT	\N	PRESENT	0
555409	555408	14033T	PARTICIPANT	\N	PRESENT	0
555411	555410	14033T	PARTICIPANT	\N	PRESENT	0
555435	553250	04070G	PARTICIPANT	\N	EXCUSE	0
555436	553250	20144B	PARTICIPANT	\N	EXCUSE	0
556170	554923	10006L	PRESIDENT	0	PRESENT	0
556171	554923	14042U	PARTICIPANT	\N	PRESENT	0
556172	554923	19683J	PARTICIPANT	\N	PRESENT	0
556173	554923	11067R	PARTICIPANT	\N	PRESENT	0
556174	554923	19301E	PARTICIPANT	\N	PRESENT	0
556175	554923	11031D	PARTICIPANT	\N	PRESENT	0
556176	554923	19760E	PARTICIPANT	\N	PRESENT	0
556177	554923	20040T	PARTICIPANT	\N	PRESENT	0
556178	554923	14223L	PARTICIPANT	\N	PRESENT	0
556179	554923	19415P	PARTICIPANT	\N	PRESENT	0
556180	554923	19367Y	PARTICIPANT	\N	PRESENT	0
556181	554923	14355X	PARTICIPANT	\N	PRESENT	0
556182	554923	19798U	PARTICIPANT	\N	PRESENT	0
556183	554923	19691J	PARTICIPANT	\N	PRESENT	0
556184	554923	14071N	PARTICIPANT	\N	PRESENT	0
556185	554923	04092N	PARTICIPANT	\N	PRESENT	0
556186	554923	14217N	PARTICIPANT	\N	PRESENT	0
556187	554923	20090E	PARTICIPANT	\N	PRESENT	0
556200	554923	14195A	PARTICIPANT	\N	PRESENT	0
556204	554923	20172F	PARTICIPANT	\N	PRESENT	0
556205	554923	08045X	PARTICIPANT	\N	PRESENT	1
556206	554923	14026U	PARTICIPANT	\N	PRESENT	1
556314	554923	19713W	PARTICIPANT	\N	PRESENT	0
556315	554923	11097X	PARTICIPANT	\N	PRESENT	0
556316	554923	19715Y	PARTICIPANT	\N	PRESENT	1
556317	554923	19697Q	PARTICIPANT	\N	PRESENT	1
556318	554923	17965H	PARTICIPANT	\N	PRESENT	1
556325	554659	14059S	PARTICIPANT	\N	EXCUSE	0
556365	556364	08045X	PARTICIPANT	\N	PRESENT	0
556371	554670	04085P	PARTICIPANT	\N	PRESENT	1
556372	554670	11033F	PARTICIPANT	\N	PRESENT	1
556373	554670	17737W	PARTICIPANT	\N	PRESENT	1
556374	554670	19629C	PARTICIPANT	\N	PRESENT	1
556375	554670	04008A	PARTICIPANT	\N	PRESENT	1
547519	534870	19643A	PARTICIPANT	\N	PRESENT	0
547520	534870	11056N	PARTICIPANT	\N	PRESENT	0
547644	547643	19715Y	PARTICIPANT	\N	PRESENT	1
547645	547643	14109K	PARTICIPANT	\N	PRESENT	1
547646	547643	19798U	PARTICIPANT	\N	PRESENT	1
547647	547643	19693L	PARTICIPANT	\N	PRESENT	1
547648	547643	14030Q	PARTICIPANT	\N	PRESENT	0
547649	547643	19599P	PARTICIPANT	\N	PRESENT	0
547650	547643	04035D	PARTICIPANT	\N	PRESENT	0
547651	547643	20130U	PARTICIPANT	\N	PRESENT	0
554075	554072	20120S	PARTICIPANT	\N	PRESENT	0
554077	554076	20136B	PARTICIPANT	\N	PRESENT	0
554078	554076	19701S	PARTICIPANT	\N	PRESENT	0
554079	554076	14205J	PARTICIPANT	\N	PRESENT	0
554081	554080	14205J	PARTICIPANT	\N	PRESENT	0
554082	554080	19551W	PARTICIPANT	\N	PRESENT	0
554178	554080	17367Q	PARTICIPANT	\N	PRESENT	0
554739	554738	20052X	PARTICIPANT	\N	PRESENT	1
554741	554740	20052X	PARTICIPANT	\N	PRESENT	1
554742	554740	17589D	PARTICIPANT	\N	PRESENT	1
554743	554740	20134Y	PARTICIPANT	\N	PRESENT	1
554745	554744	19693L	PARTICIPANT	\N	PRESENT	1
554746	554744	19399H	PARTICIPANT	\N	PRESENT	1
554747	554744	20142Y	PARTICIPANT	\N	PRESENT	1
554749	554748	19399H	PARTICIPANT	\N	PRESENT	1
554750	554748	19693L	PARTICIPANT	\N	PRESENT	1
554751	554748	19651A	PARTICIPANT	\N	PRESENT	1
554752	554748	20142Y	PARTICIPANT	\N	PRESENT	1
554754	554753	19399H	PARTICIPANT	\N	PRESENT	1
554755	554753	14073Q	PARTICIPANT	\N	PRESENT	1
554756	554753	20048C	PARTICIPANT	\N	PRESENT	1
554757	554753	11043H	PARTICIPANT	\N	PRESENT	1
554759	554758	19399H	PARTICIPANT	\N	PRESENT	1
554761	554760	20132W	PARTICIPANT	\N	PRESENT	1
554762	554760	19643A	PARTICIPANT	\N	PRESENT	1
554763	554760	20052X	PARTICIPANT	\N	PRESENT	1
554765	554764	20132W	PARTICIPANT	\N	PRESENT	1
554766	554764	20048C	PARTICIPANT	\N	PRESENT	1
554767	554764	19643A	PARTICIPANT	\N	PRESENT	1
554769	554768	20132W	PARTICIPANT	\N	PRESENT	1
554770	554768	19643A	PARTICIPANT	\N	PRESENT	1
554771	554768	20180F	PARTICIPANT	\N	PRESENT	1
555254	555253	19826F	PARTICIPANT	\N	PRESENT	0
555256	555255	14205J	PARTICIPANT	\N	PRESENT	0
555257	555255	19826F	PARTICIPANT	\N	PRESENT	0
555576	536112	20174H	PARTICIPANT	\N	PRESENT	0
555577	536112	11083R	PARTICIPANT	\N	PRESENT	0
555578	536112	14073Q	PARTICIPANT	\N	PRESENT	0
556008	549007	20024T	PARTICIPANT	\N	PRESENT	0
556009	549007	14030Q	PRESIDENT	0	PRESENT	0
556010	549007	11031D	PARTICIPANT	\N	PRESENT	0
556011	549007	20106U	PARTICIPANT	\N	PRESENT	1
556012	549007	14179A	PARTICIPANT	\N	PRESENT	1
556013	549007	08017T	PARTICIPANT	\N	PRESENT	0
556014	549007	14109K	PARTICIPANT	\N	PRESENT	1
556015	549007	20118Y	PARTICIPANT	\N	EXCUSE	0
556016	549007	20130U	PARTICIPANT	\N	PRESENT	1
556017	549007	19798U	PARTICIPANT	\N	PRESENT	0
556021	549007	19693L	PARTICIPANT	\N	EXCUSE	0
556022	549007	07029T	PARTICIPANT	\N	EXCUSE	0
556367	556366	20042V	PARTICIPANT	\N	PRESENT	0
556368	556366	01058X	PARTICIPANT	\N	PRESENT	0
556369	556366	11054L	PARTICIPANT	\N	PRESENT	0
556370	556366	14193X	PARTICIPANT	\N	PRESENT	0
556382	556379	14255U	PARTICIPANT	\N	PRESENT	1
556385	556379	20064C	PARTICIPANT	\N	PRESENT	1
556454	554775	20058E	PARTICIPANT	\N	PRESENT	1
556455	554775	19533U	PARTICIPANT	\N	PRESENT	1
557282	555038	14187A	PARTICIPANT	\N	PRESENT	0
557283	555038	11077T	PARTICIPANT	\N	PRESENT	0
557284	555038	19563B	PARTICIPANT	\N	PRESENT	0
557285	555038	19689Q	PARTICIPANT	\N	PRESENT	0
557286	555038	04045F	PARTICIPANT	\N	PRESENT	0
557287	555038	19681G	PARTICIPANT	\N	PRESENT	0
557280	555038	19719D	PARTICIPANT	\N	PRESENT	0
557281	555038	20088L	PARTICIPANT	\N	PRESENT	0
557288	555038	20046A	PARTICIPANT	\N	PRESENT	0
557289	555038	01043Q	PARTICIPANT	\N	PRESENT	0
557290	555038	19631V	PARTICIPANT	\N	PRESENT	0
557291	555038	04086Q	PARTICIPANT	\N	PRESENT	0
557292	555038	19747H	PARTICIPANT	\N	PRESENT	0
557293	555038	20090E	PARTICIPANT	\N	PRESENT	0
557294	555038	20026V	PARTICIPANT	\N	PRESENT	0
557295	555038	19413M	PARTICIPANT	\N	PRESENT	0
557296	555038	14147R	PARTICIPANT	\N	PRESENT	0
557297	555038	14021P	PARTICIPANT	\N	PRESENT	0
557298	555038	19741B	PARTICIPANT	\N	PRESENT	0
557299	555038	17637T	PARTICIPANT	\N	PRESENT	0
557300	555038	20092G	PARTICIPANT	\N	PRESENT	0
557301	555038	14257W	PARTICIPANT	\N	PRESENT	0
557302	555038	18193Q	PARTICIPANT	\N	PRESENT	0
557538	554659	19717B	PARTICIPANT	\N	PRESENT	1
557539	554659	19631V	PARTICIPANT	\N	PRESENT	1
557540	554659	97011G	PARTICIPANT	\N	PRESENT	0
557541	554659	11010L	PARTICIPANT	\N	PRESENT	0
557542	554659	19347U	PARTICIPANT	\N	PRESENT	0
557543	554659	20034V	PARTICIPANT	\N	PRESENT	0
557544	554659	08034U	PARTICIPANT	\N	PRESENT	0
557545	554659	12016W	PARTICIPANT	\N	PRESENT	1
557546	554659	14147R	PARTICIPANT	\N	PRESENT	1
557547	554659	20148F	PRESIDENT	0	PRESENT	0
557548	554659	19319Q	PARTICIPANT	\N	PRESENT	0
557572	555399	14189C	PARTICIPANT	\N	PRESENT	0
557573	555399	11031D	PARTICIPANT	\N	PRESENT	1
557574	555399	10006L	PARTICIPANT	\N	PRESENT	0
557575	555399	99004R	PARTICIPANT	\N	PRESENT	0
557576	555399	19699S	PARTICIPANT	\N	PRESENT	0
557577	555399	19697Q	PARTICIPANT	\N	PRESENT	1
557578	555399	19563B	PARTICIPANT	\N	PRESENT	0
557579	555399	20030R	PARTICIPANT	\N	PRESENT	1
557580	555399	19705W	PARTICIPANT	\N	PRESENT	1
557582	555399	14229S	PARTICIPANT	\N	PRESENT	0
557719	555046	14042U	PARTICIPANT	\N	PRESENT	1
557720	555046	19697Q	PARTICIPANT	\N	PRESENT	1
557721	555046	20130U	PARTICIPANT	\N	PRESENT	1
557814	555047	14042U	PARTICIPANT	\N	PRESENT	1
557815	555047	19697Q	PARTICIPANT	\N	PRESENT	1
557817	555047	20130U	PARTICIPANT	\N	PRESENT	1
557865	557864	04070G	PARTICIPANT	\N	PRESENT	0
557866	557864	14169X	PARTICIPANT	\N	PRESENT	0
558377	557688	20058E	PARTICIPANT	\N	PRESENT	0
558378	557688	08010L	PARTICIPANT	\N	PRESENT	0
558379	557688	20108W	PARTICIPANT	\N	PRESENT	0
558380	557697	19383Y	PARTICIPANT	\N	PRESENT	0
558381	557697	19515S	PARTICIPANT	\N	PRESENT	0
558382	557697	11077T	PARTICIPANT	\N	PRESENT	1
558383	557697	20092G	PARTICIPANT	\N	PRESENT	0
558384	557697	01043Q	PARTICIPANT	\N	PRESENT	0
558385	557697	19441R	PARTICIPANT	\N	PRESENT	0
558386	557697	20082E	PARTICIPANT	\N	PRESENT	0
558387	557697	04045F	PARTICIPANT	\N	PRESENT	1
558388	557697	20104S	PARTICIPANT	\N	PRESENT	0
558389	557697	11099A	PARTICIPANT	\N	PRESENT	0
558390	557697	08015R	PARTICIPANT	\N	PRESENT	0
558391	557697	19575F	PARTICIPANT	\N	PRESENT	0
558392	557697	19369B	PARTICIPANT	\N	PRESENT	0
558393	557697	19563B	PARTICIPANT	\N	PRESENT	0
558394	557697	14329V	PARTICIPANT	\N	PRESENT	0
558395	557697	20028X	PARTICIPANT	\N	PRESENT	0
558396	557697	20034V	PARTICIPANT	\N	PRESENT	0
558397	557697	14187A	PARTICIPANT	\N	PRESENT	0
558398	557697	20144B	PARTICIPANT	\N	PRESENT	0
558399	557697	14033T	PARTICIPANT	\N	PRESENT	0
558400	557697	11090Q	PRESIDENT	0	PRESENT	0
558401	557697	20054A	PARTICIPANT	\N	PRESENT	0
558402	557697	20174H	PARTICIPANT	\N	PRESENT	0
558403	557697	14205J	PARTICIPANT	\N	PRESENT	0
558404	557697	20062A	PARTICIPANT	\N	PRESENT	0
558405	557697	19507S	PARTICIPANT	\N	PRESENT	0
558406	557697	14207L	PARTICIPANT	\N	PRESENT	0
558407	557697	20086J	PARTICIPANT	\N	EXCUSE	0
558408	557697	19768N	PARTICIPANT	\N	PRESENT	1
558409	557697	19782L	PARTICIPANT	\N	PRESENT	1
558410	557697	19413M	PARTICIPANT	\N	PRESENT	1
558411	557697	19631V	PARTICIPANT	\N	PRESENT	1
558412	557697	20030R	PARTICIPANT	\N	PRESENT	1
558413	557697	19747H	PARTICIPANT	\N	PRESENT	1
558414	557688	17023S	PARTICIPANT	\N	PRESENT	0
558428	557688	20024T	PARTICIPANT	\N	PRESENT	0
558435	557688	19367Y	PARTICIPANT	\N	PRESENT	0
563001	561763	08011M	PARTICIPANT	\N	PRESENT	1
563002	561763	20050V	PARTICIPANT	\N	PRESENT	1
563003	561763	14331P	PARTICIPANT	\N	PRESENT	1
563004	561763	19479G	PARTICIPANT	\N	PRESENT	1
563005	561763	14173T	PARTICIPANT	\N	PRESENT	1
563006	562758	14229S	PARTICIPANT	\N	PRESENT	1
563007	562758	20142Y	PARTICIPANT	\N	PRESENT	1
563008	562758	20098N	PARTICIPANT	\N	PRESENT	1
563009	562758	20048C	PARTICIPANT	\N	PRESENT	1
563010	562758	19693L	PARTICIPANT	\N	PRESENT	1
563011	562759	14229S	PARTICIPANT	\N	PRESENT	1
563012	562759	20142Y	PARTICIPANT	\N	PRESENT	1
563013	562759	20098N	PARTICIPANT	\N	PRESENT	1
563014	562759	19693L	PARTICIPANT	\N	PRESENT	1
563015	562759	20132W	PARTICIPANT	\N	PRESENT	1
563016	562759	20048C	PARTICIPANT	\N	PRESENT	1
563017	562760	14229S	PARTICIPANT	\N	PRESENT	1
563018	562760	20098N	PARTICIPANT	\N	PRESENT	1
563020	562760	20142Y	PARTICIPANT	\N	PRESENT	1
563021	562760	20132W	PARTICIPANT	\N	PRESENT	1
563022	562760	19693L	PARTICIPANT	\N	PRESENT	1
563038	562574	11097X	PARTICIPANT	\N	PRESENT	1
563039	562574	17779H	PARTICIPANT	\N	PRESENT	1
563040	562574	14213J	PARTICIPANT	\N	PRESENT	1
563119	562554	19527W	PARTICIPANT	\N	PRESENT	0
563236	563235	10015M	PARTICIPANT	\N	PRESENT	0
563237	563235	14053L	PARTICIPANT	\N	PRESENT	0
563238	563235	20084G	PARTICIPANT	\N	PRESENT	0
563239	563235	18193Q	PARTICIPANT	\N	PRESENT	0
563240	563235	11026G	PARTICIPANT	\N	PRESENT	0
563252	563251	14217N	PARTICIPANT	\N	PRESENT	0
563253	563251	14041T	PARTICIPANT	\N	PRESENT	0
563254	563251	14357A	PARTICIPANT	\N	PRESENT	0
563263	563262	19954N	PARTICIPANT	\N	PRESENT	0
563264	563262	14030Q	PARTICIPANT	\N	PRESENT	0
563265	563262	18083K	PARTICIPANT	\N	PRESENT	0
563266	563262	20134Y	PARTICIPANT	\N	PRESENT	0
563267	563262	20124W	PARTICIPANT	\N	PRESENT	0
563268	563262	19673G	PARTICIPANT	\N	PRESENT	0
563269	563262	04035D	PARTICIPANT	\N	PRESENT	0
563270	563262	19553Y	PARTICIPANT	\N	PRESENT	1
563271	563262	19691J	PARTICIPANT	\N	PRESENT	0
563272	563262	20034V	PARTICIPANT	\N	PRESENT	1
563273	563262	14073Q	PARTICIPANT	\N	PRESENT	0
563274	563262	08017T	PARTICIPANT	\N	PRESENT	0
563275	563262	04057K	PARTICIPANT	\N	PRESENT	0
563276	563262	04070G	PARTICIPANT	\N	EXCUSE	0
563277	563262	20098N	PARTICIPANT	\N	PRESENT	0
563278	563262	19527W	PRESIDENT	0	PRESENT	0
563562	562720	19715Y	PARTICIPANT	\N	PRESENT	1
563563	562720	19703U	PARTICIPANT	\N	PRESENT	1
563564	562720	11031D	PARTICIPANT	\N	PRESENT	1
563685	562722	19703U	PARTICIPANT	\N	PRESENT	1
563686	562722	19715Y	PARTICIPANT	\N	PRESENT	1
563783	562654	11097X	PARTICIPANT	\N	PRESENT	1
563784	562654	17779H	PARTICIPANT	\N	PRESENT	1
563809	561875	14331P	PRESIDENT	0	PRESENT	0
563810	561875	19725B	PARTICIPANT	\N	PRESENT	0
563811	561875	20104S	PARTICIPANT	\N	PRESENT	0
563812	561875	14073Q	PARTICIPANT	\N	PRESENT	0
563813	561875	10015M	PARTICIPANT	\N	PRESENT	0
563814	561875	11026G	PARTICIPANT	\N	PRESENT	0
563815	561875	14026U	PARTICIPANT	\N	PRESENT	1
563816	561875	04057K	PARTICIPANT	\N	PRESENT	1
563817	561875	20100N	PARTICIPANT	\N	PRESENT	0
563818	561875	19701S	PARTICIPANT	\N	PRESENT	0
563819	561875	14357A	PARTICIPANT	\N	PRESENT	0
563820	561875	14001X	PARTICIPANT	\N	PRESENT	1
563823	561875	04070G	PARTICIPANT	\N	PRESENT	1
563824	562576	11097X	PARTICIPANT	\N	PRESENT	1
563825	562576	20130U	PARTICIPANT	\N	PRESENT	1
563826	563785	19671E	PARTICIPANT	\N	PRESENT	0
563827	563785	08015R	PARTICIPANT	\N	PRESENT	0
563828	562576	17779H	PARTICIPANT	\N	PRESENT	1
563829	559849	99004R	PRESIDENT	0	PRESENT	0
563830	559849	14189C	PARTICIPANT	\N	PRESENT	0
563831	559849	19447X	PARTICIPANT	\N	PRESENT	0
563832	559849	19705W	PARTICIPANT	\N	PRESENT	0
563833	559849	14229S	PARTICIPANT	\N	PRESENT	0
563834	559849	20030R	PARTICIPANT	\N	PRESENT	0
563835	559849	10006L	PARTICIPANT	\N	PRESENT	0
563836	559849	19697Q	PARTICIPANT	\N	PRESENT	0
563837	561875	08034U	PARTICIPANT	\N	PRESENT	0
563838	559849	11033F	PARTICIPANT	\N	EXCUSE	0
563839	559849	14207L	PARTICIPANT	\N	PRESENT	0
563840	559849	11031D	PARTICIPANT	\N	EXCUSE	0
563841	559849	19563B	PARTICIPANT	\N	EXCUSE	0
563842	559849	11090Q	PARTICIPANT	\N	EXCUSE	0
563843	561876	04070G	PARTICIPANT	\N	PRESENT	1
563844	561876	10015M	PARTICIPANT	\N	PRESENT	0
563898	561876	20128B	PARTICIPANT	\N	PRESENT	1
563846	561876	14026U	PARTICIPANT	\N	PRESENT	1
563847	561876	04057K	PARTICIPANT	\N	PRESENT	1
563848	561876	20100N	PARTICIPANT	\N	PRESENT	0
563849	561876	19701S	PARTICIPANT	\N	PRESENT	0
563850	561876	14357A	PARTICIPANT	\N	PRESENT	0
563851	561876	14001X	PARTICIPANT	\N	PRESENT	1
563852	561876	08034U	PARTICIPANT	\N	PRESENT	0
563853	561876	14331P	PRESIDENT	\N	PRESENT	0
563854	561876	19725B	PARTICIPANT	\N	PRESENT	0
563855	561876	20104S	PARTICIPANT	\N	PRESENT	0
563921	563920	19741B	PARTICIPANT	\N	PRESENT	0
563860	561875	14133K	PARTICIPANT	\N	PRESENT	0
563922	563920	14255U	PARTICIPANT	\N	PRESENT	0
563923	563920	10006L	PARTICIPANT	\N	PRESENT	0
563924	563920	14041T	PARTICIPANT	\N	PRESENT	0
563925	563920	20066E	PARTICIPANT	\N	PRESENT	0
563926	563920	20056C	PARTICIPANT	\N	PRESENT	0
563927	563920	14073Q	PARTICIPANT	\N	PRESENT	0
563928	563920	20126Y	PARTICIPANT	\N	PRESENT	0
563929	563920	19745F	PARTICIPANT	\N	PRESENT	0
563930	563920	01058X	PARTICIPANT	\N	PRESENT	0
563932	562025	20030R	PARTICIPANT	\N	PRESENT	1
563941	563940	04070G	PARTICIPANT	\N	PRESENT	0
563942	563940	14041T	PARTICIPANT	\N	PRESENT	0
563943	563940	14255U	PARTICIPANT	\N	PRESENT	0
563944	563940	11026G	PARTICIPANT	\N	PRESENT	0
563945	563940	19421M	PARTICIPANT	\N	PRESENT	0
563946	563940	17737W	PARTICIPANT	\N	PRESENT	0
563947	563940	14030Q	PARTICIPANT	\N	PRESENT	0
563949	563948	08009T	PARTICIPANT	\N	PRESENT	0
563950	563948	19713W	PARTICIPANT	\N	PRESENT	0
563953	563948	01048V	PARTICIPANT	\N	PRESENT	0
563954	563948	14147R	PARTICIPANT	\N	PRESENT	0
563956	563948	11026G	PARTICIPANT	\N	PRESENT	0
563957	563948	19745F	PARTICIPANT	\N	PRESENT	0
563966	563962	19826F	PARTICIPANT	\N	PRESENT	0
563976	563974	19826F	PARTICIPANT	\N	PRESENT	0
563984	563983	19826F	PARTICIPANT	\N	PRESENT	0
563988	563987	19701S	PARTICIPANT	\N	PRESENT	0
563990	563989	20136B	PARTICIPANT	\N	PRESENT	0
563992	563991	19701S	PARTICIPANT	\N	PRESENT	0
564039	564038	14267Y	PARTICIPANT	\N	PRESENT	0
564040	564038	97011G	PARTICIPANT	\N	PRESENT	0
564043	564042	14267Y	PARTICIPANT	\N	PRESENT	0
564044	564042	97011G	PARTICIPANT	\N	PRESENT	0
564045	564042	12028B	PARTICIPANT	\N	PRESENT	1
564048	564047	14267Y	PARTICIPANT	\N	PRESENT	0
564049	562227	19643A	PARTICIPANT	\N	PRESENT	1
564050	562227	20082E	PARTICIPANT	\N	PRESENT	0
564051	562227	19735D	PARTICIPANT	\N	EXCUSE	0
564052	562227	20132W	PARTICIPANT	\N	PRESENT	1
564053	562227	19611R	PARTICIPANT	\N	PRESENT	0
564054	562227	14059S	PARTICIPANT	\N	PRESENT	0
564055	562227	19593H	PRESIDENT	0	PRESENT	0
564056	562227	14147R	PARTICIPANT	\N	PRESENT	1
564391	564390	11070L	PARTICIPANT	\N	PRESENT	0
564392	564390	19647E	PARTICIPANT	\N	PRESENT	0
564394	564393	20070A	PARTICIPANT	\N	PRESENT	0
564396	564395	11053K	PARTICIPANT	\N	PRESENT	0
564397	559011	20116W	PARTICIPANT	\N	PRESENT	0
564398	559011	20090E	PARTICIPANT	\N	PRESENT	0
564399	559011	14083S	PARTICIPANT	\N	PRESENT	0
564400	559011	11053K	PARTICIPANT	\N	PRESENT	0
564401	559011	17229F	PARTICIPANT	\N	PRESENT	0
564402	559011	19333N	PARTICIPANT	\N	PRESENT	0
564403	559011	20056C	PARTICIPANT	\N	PRESENT	0
564404	559011	20052X	PARTICIPANT	\N	PRESENT	0
564405	559011	19671E	PARTICIPANT	\N	PRESENT	0
564406	559011	14169X	PARTICIPANT	\N	PRESENT	0
542385	542314	20110Q	PARTICIPANT	\N	PRESENT	1
542386	542314	20114U	PARTICIPANT	\N	PRESENT	1
542387	542314	14053L	PARTICIPANT	\N	PRESENT	1
542388	542314	14179A	PARTICIPANT	\N	PRESENT	1
542389	542314	19581D	PARTICIPANT	\N	PRESENT	1
542390	542314	14147R	PARTICIPANT	\N	PRESENT	1
542391	542314	14107H	PARTICIPANT	\N	PRESENT	1
542392	542314	20074E	PARTICIPANT	\N	EXCUSE	0
542393	542314	14231L	PARTICIPANT	\N	EXCUSE	0
542397	542396	19741B	PARTICIPANT	\N	PRESENT	0
542500	537394	14030Q	PARTICIPANT	\N	PRESENT	0
542501	537394	07029T	PARTICIPANT	\N	PRESENT	0
542502	537394	14109K	PARTICIPANT	\N	PRESENT	0
542503	537394	20066E	PARTICIPANT	\N	PRESENT	0
542505	537394	20056C	PARTICIPANT	\N	PRESENT	0
542507	537394	20118Y	PARTICIPANT	\N	PRESENT	0
542508	537394	14179A	PARTICIPANT	\N	PRESENT	0
542509	537394	20130U	PARTICIPANT	\N	PRESENT	0
542510	537394	19715Y	PARTICIPANT	\N	PRESENT	0
542511	537394	20098N	PARTICIPANT	\N	PRESENT	0
542512	537394	19798U	PARTICIPANT	\N	PRESENT	0
542514	537394	14189C	PARTICIPANT	\N	EXCUSE	0
542515	537394	20024T	PARTICIPANT	\N	EXCUSE	0
542516	537394	17737W	PARTICIPANT	\N	EXCUSE	0
542517	537394	19599P	PARTICIPANT	\N	EXCUSE	0
542530	542529	14038Y	PARTICIPANT	\N	PRESENT	0
542531	542529	20060X	PARTICIPANT	\N	PRESENT	0
542532	542529	19441R	PARTICIPANT	\N	PRESENT	0
542533	542529	14257W	PARTICIPANT	\N	PRESENT	0
542911	534228	19798U	PARTICIPANT	\N	PRESENT	0
542912	534228	19333N	PARTICIPANT	\N	PRESENT	0
542913	534228	18193Q	PARTICIPANT	\N	PRESENT	0
542914	534228	20056C	PARTICIPANT	\N	PRESENT	0
542915	534228	19533U	PARTICIPANT	\N	PRESENT	0
542916	534228	19349W	PARTICIPANT	\N	PRESENT	0
542917	534228	14169X	PARTICIPANT	\N	PRESENT	0
542918	534228	19820Y	PARTICIPANT	\N	PRESENT	0
542919	534228	19489J	PARTICIPANT	\N	PRESENT	0
542920	534228	14257W	PARTICIPANT	\N	PRESENT	0
542921	534228	20106U	PARTICIPANT	\N	PRESENT	0
542922	534228	20140W	PARTICIPANT	\N	PRESENT	0
542923	534228	14229S	PARTICIPANT	\N	PRESENT	0
542924	534228	20060X	PARTICIPANT	\N	PRESENT	0
542925	534228	19585H	PARTICIPANT	\N	PRESENT	0
551518	549006	19631V	PARTICIPANT	\N	EXCUSE	0
551519	549005	19631V	PARTICIPANT	\N	PRESENT	0
554662	554661	19679N	PARTICIPANT	\N	PRESENT	0
554663	554660	19679N	PARTICIPANT	\N	PRESENT	0
554664	554657	20056C	PARTICIPANT	\N	PRESENT	0
554665	554657	17779H	PARTICIPANT	\N	PRESENT	0
554666	554657	11067R	PARTICIPANT	\N	PRESENT	0
554667	554658	17779H	PARTICIPANT	\N	PRESENT	0
554668	554658	11067R	PARTICIPANT	\N	PRESENT	0
560578	559209	07004J	PARTICIPANT	\N	PRESENT	0
560579	559209	20108W	PARTICIPANT	\N	PRESENT	0
560580	559209	14041T	PARTICIPANT	\N	PRESENT	0
560581	559209	19749K	PARTICIPANT	\N	PRESENT	0
560582	559209	19673G	PARTICIPANT	\N	PRESENT	0
560583	559209	20110Q	PARTICIPANT	\N	PRESENT	0
560584	559209	14111D	PARTICIPANT	\N	PRESENT	0
560585	559209	10015M	PARTICIPANT	\N	PRESENT	0
560586	559209	04047H	PRESIDENT	0	PRESENT	0
560587	559209	14021P	PARTICIPANT	\N	PRESENT	0
560590	560588	20038A	PARTICIPANT	\N	PRESENT	0
560591	560588	20140W	PARTICIPANT	\N	PRESENT	0
560592	560588	19549D	PARTICIPANT	\N	PRESENT	0
560593	560588	20076G	PARTICIPANT	\N	PRESENT	0
560594	560588	14219Q	PRESIDENT	0	PRESENT	0
560595	560588	19251M	PARTICIPANT	\N	PRESENT	0
560596	560588	19820Y	PARTICIPANT	\N	PRESENT	0
560597	560588	19826F	PARTICIPANT	\N	PRESENT	0
560598	560588	14221J	PARTICIPANT	\N	PRESENT	0
560599	560588	19599P	PARTICIPANT	\N	PRESENT	0
560600	560588	19637C	PARTICIPANT	\N	PRESENT	0
560601	560588	14237S	PARTICIPANT	\N	PRESENT	0
560602	560588	05012A	PARTICIPANT	\N	PRESENT	0
560603	560588	20118Y	PARTICIPANT	\N	PRESENT	0
560604	560588	11101A	PARTICIPANT	\N	PRESENT	0
560605	560588	19503N	PARTICIPANT	\N	PRESENT	0
560606	560588	14031R	PARTICIPANT	\N	PRESENT	0
560607	560588	17367Q	PARTICIPANT	\N	PRESENT	0
560608	560588	19387D	PARTICIPANT	\N	PRESENT	0
560609	560588	17229F	PARTICIPANT	\N	PRESENT	0
560610	560588	18083K	PARTICIPANT	\N	PRESENT	0
560611	560588	20100N	PARTICIPANT	\N	PRESENT	0
560612	560588	19619A	PARTICIPANT	\N	PRESENT	0
560613	560588	08060W	PARTICIPANT	\N	PRESENT	1
560615	560588	11065P	PARTICIPANT	\N	PRESENT	0
560616	560588	20032T	PARTICIPANT	\N	PRESENT	0
560617	560588	19577H	PARTICIPANT	\N	PRESENT	1
560618	560588	19525U	PARTICIPANT	\N	PRESENT	1
560619	560588	19681G	PARTICIPANT	\N	PRESENT	1
560625	559635	19527W	PARTICIPANT	\N	PRESENT	0
560626	559635	20132W	PARTICIPANT	\N	PRESENT	0
560627	559635	19699S	PARTICIPANT	\N	PRESENT	0
560628	559635	14073Q	PARTICIPANT	\N	PRESENT	0
560629	559635	19611R	PRESIDENT	0	PRESENT	0
560630	559635	20142Y	PARTICIPANT	\N	PRESENT	0
560631	559635	19399H	PARTICIPANT	\N	PRESENT	0
560632	559635	14229S	PARTICIPANT	\N	PRESENT	0
560633	559635	14030Q	PARTICIPANT	\N	PRESENT	0
560634	559635	20056C	PARTICIPANT	\N	PRESENT	0
560635	559635	04059M	PARTICIPANT	\N	PRESENT	0
560636	559635	14109K	PARTICIPANT	\N	PRESENT	0
560637	559635	07033P	PARTICIPANT	\N	PRESENT	0
560638	559635	11043H	PARTICIPANT	\N	PRESENT	0
560639	559635	20124W	PARTICIPANT	\N	PRESENT	0
560640	559635	20026V	PARTICIPANT	\N	PRESENT	0
560641	559635	20084G	PARTICIPANT	\N	PRESENT	0
560642	560588	19333N	PARTICIPANT	\N	PRESENT	0
560643	560588	20068G	PARTICIPANT	\N	PRESENT	0
560644	559635	19643A	PARTICIPANT	\N	PRESENT	1
560645	559635	19533U	PARTICIPANT	\N	PRESENT	1
560646	559635	19693L	PARTICIPANT	\N	PRESENT	1
560647	559635	20052X	PARTICIPANT	\N	PRESENT	1
560648	559635	08017T	PARTICIPANT	\N	PRESENT	1
560649	559635	20098N	PARTICIPANT	\N	PRESENT	1
560653	559209	01028R	PARTICIPANT	\N	PRESENT	0
560654	559209	05008E	PARTICIPANT	\N	PRESENT	0
560655	559209	14231L	PARTICIPANT	\N	PRESENT	0
560656	559209	19489J	PARTICIPANT	\N	PRESENT	0
560657	559209	14179A	PARTICIPANT	\N	PRESENT	0
560658	559209	14151M	PARTICIPANT	\N	PRESENT	0
560659	559209	11072N	PARTICIPANT	\N	PRESENT	0
560660	559209	14053L	PARTICIPANT	\N	PRESENT	0
560661	559209	11026G	PARTICIPANT	\N	PRESENT	0
560662	559209	19725B	PARTICIPANT	\N	PRESENT	0
560663	559209	14089Y	PARTICIPANT	\N	PRESENT	0
560664	559209	11056N	PARTICIPANT	\N	PRESENT	0
560665	559209	19729F	PARTICIPANT	\N	PRESENT	0
560666	559209	95063L	PARTICIPANT	\N	PRESENT	0
560667	559209	04008A	PARTICIPANT	\N	PRESENT	0
560668	560588	20106U	PARTICIPANT	\N	PRESENT	1
560673	559541	04071H	PARTICIPANT	\N	PRESENT	0
560674	559541	14189C	PARTICIPANT	\N	PRESENT	0
560675	559541	01057W	PARTICIPANT	\N	PRESENT	0
560676	559541	20050V	PARTICIPANT	\N	PRESENT	0
560677	559541	11074Q	PARTICIPANT	\N	PRESENT	0
560678	559541	20044X	PARTICIPANT	\N	PRESENT	0
560679	559541	14225N	PRESIDENT	0	PRESENT	0
560680	559541	11040E	PARTICIPANT	\N	PRESENT	0
560681	559541	04086Q	PARTICIPANT	\N	PRESENT	0
560682	559541	19349W	PARTICIPANT	\N	PRESENT	0
560683	559541	19741B	PARTICIPANT	\N	PRESENT	0
560684	559541	20116W	PARTICIPANT	\N	PRESENT	0
560685	559541	14253S	PARTICIPANT	\N	PRESENT	0
560686	559541	19335Q	PARTICIPANT	\N	PRESENT	0
560687	559485	19383Y	PARTICIPANT	\N	PRESENT	0
560688	559485	20088L	PARTICIPANT	\N	PRESENT	0
560689	559485	19768N	PARTICIPANT	\N	PRESENT	0
560690	559485	19515S	PARTICIPANT	\N	PRESENT	0
560691	559485	01043Q	PARTICIPANT	\N	PRESENT	0
560692	559485	14187A	PARTICIPANT	\N	PRESENT	0
560693	559485	20078J	PARTICIPANT	\N	PRESENT	0
560694	559485	11090Q	PRESIDENT	0	PRESENT	0
560695	559485	04045F	PARTICIPANT	\N	PRESENT	0
560696	559485	19631V	PARTICIPANT	\N	PRESENT	0
560697	559485	19575F	PARTICIPANT	\N	PRESENT	0
560698	559485	19369B	PARTICIPANT	\N	PRESENT	0
560699	559485	19747H	PARTICIPANT	\N	PRESENT	0
560700	559485	19511N	PARTICIPANT	\N	PRESENT	0
556376	554670	14041T	PARTICIPANT	\N	PRESENT	1
556377	554670	19673G	PARTICIPANT	\N	PRESENT	1
556378	554670	07004J	PARTICIPANT	\N	PRESENT	1
556380	554670	19489J	PARTICIPANT	\N	PRESENT	1
556381	554670	20108W	PARTICIPANT	\N	PRESENT	1
556383	554670	19581D	PARTICIPANT	\N	PRESENT	1
556384	554670	11072N	PARTICIPANT	\N	PRESENT	1
556386	554670	10015M	PARTICIPANT	\N	PRESENT	1
556387	554670	14107H	PARTICIPANT	\N	PRESENT	1
556388	554670	19675J	PARTICIPANT	\N	PRESENT	1
556422	554775	04070G	PARTICIPANT	\N	PRESENT	0
556423	554775	19699S	PARTICIPANT	\N	PRESENT	0
556424	554775	14229S	PARTICIPANT	\N	PRESENT	0
556425	554775	20098N	PARTICIPANT	\N	PRESENT	0
556426	554775	08017T	PARTICIPANT	\N	PRESENT	0
556427	554775	20112S	PARTICIPANT	\N	PRESENT	0
556428	554775	20124W	PARTICIPANT	\N	PRESENT	0
556429	554775	20026V	PARTICIPANT	\N	PRESENT	0
556430	554775	19527W	PARTICIPANT	\N	PRESENT	1
556431	554775	19593H	PARTICIPANT	\N	PRESENT	0
556432	554775	19643A	PARTICIPANT	\N	PRESENT	0
556433	554775	20132W	PARTICIPANT	\N	PRESENT	0
556434	554775	14073Q	PARTICIPANT	\N	PRESENT	0
556435	554775	19651A	PARTICIPANT	\N	PRESENT	1
556436	554775	20138D	PARTICIPANT	\N	PRESENT	0
556437	554775	19611R	PRESIDENT	0	PRESENT	0
556438	554775	20142Y	PARTICIPANT	\N	PRESENT	0
556439	554775	20048C	PARTICIPANT	\N	PRESENT	1
556440	554775	19693L	PARTICIPANT	\N	PRESENT	0
556441	554775	19399H	PARTICIPANT	\N	PRESENT	0
556442	554775	20052X	PARTICIPANT	\N	PRESENT	0
556443	554775	20056C	PARTICIPANT	\N	PRESENT	0
556444	554775	20180F	PARTICIPANT	\N	PRESENT	0
556445	554775	04059M	PARTICIPANT	\N	PRESENT	0
556446	554775	19735D	PARTICIPANT	\N	PRESENT	1
556447	554775	11043H	PARTICIPANT	\N	PRESENT	0
556448	554775	11104D	PARTICIPANT	\N	PRESENT	0
556449	554775	19758L	PARTICIPANT	\N	PRESENT	0
556450	554775	17589D	PARTICIPANT	\N	PRESENT	1
556451	554775	19621T	PARTICIPANT	\N	PRESENT	1
556452	554775	20084G	PARTICIPANT	\N	PRESENT	0
556453	554775	11109J	PARTICIPANT	\N	EXCUSE	0
556483	555035	98022P	PARTICIPANT	\N	PRESENT	0
556484	555035	11041F	PARTICIPANT	\N	PRESENT	0
556485	555035	11056N	PARTICIPANT	\N	PRESENT	0
556486	555035	20102Q	PARTICIPANT	\N	PRESENT	0
556487	555035	14111D	PARTICIPANT	\N	PRESENT	0
556488	555035	20046A	PARTICIPANT	\N	PRESENT	0
556492	555035	19599P	PARTICIPANT	\N	PRESENT	0
556490	555035	20052X	PARTICIPANT	\N	PRESENT	0
556491	555035	11066Q	PARTICIPANT	\N	PRESENT	0
556494	555035	19413M	PARTICIPANT	\N	PRESENT	0
556495	555035	19651A	PARTICIPANT	\N	PRESENT	0
556496	555035	11085T	PARTICIPANT	\N	PRESENT	0
556497	555035	14042U	PARTICIPANT	\N	PRESENT	0
556498	555035	14231L	PARTICIPANT	\N	PRESENT	0
556499	555035	19745F	PARTICIPANT	\N	PRESENT	0
556500	555035	20048C	PARTICIPANT	\N	PRESENT	0
556501	555035	08009T	PARTICIPANT	\N	PRESENT	0
556502	555035	14221J	PARTICIPANT	\N	PRESENT	0
556503	555035	20050V	PARTICIPANT	\N	PRESENT	0
556504	555035	20100N	PARTICIPANT	\N	PRESENT	0
556505	555035	08045X	PARTICIPANT	\N	PRESENT	0
556506	555035	11040E	PARTICIPANT	\N	PRESENT	0
556507	555035	19549D	PARTICIPANT	\N	PRESENT	0
556508	555035	19333N	PARTICIPANT	\N	PRESENT	0
556509	555035	20028X	PARTICIPANT	\N	PRESENT	0
556510	555035	11104D	PARTICIPANT	\N	PRESENT	0
556511	555035	20116W	PARTICIPANT	\N	PRESENT	0
556512	555035	19687N	PARTICIPANT	\N	PRESENT	0
556513	555035	19695N	PARTICIPANT	\N	PRESENT	0
556514	555035	14207L	PARTICIPANT	\N	PRESENT	0
556516	555035	19683J	PARTICIPANT	\N	PRESENT	0
556517	555035	11064N	PARTICIPANT	\N	PRESENT	0
556518	555035	20174H	PARTICIPANT	\N	PRESENT	0
556519	555035	19349W	PARTICIPANT	\N	PRESENT	0
556520	555035	20080C	PARTICIPANT	\N	PRESENT	0
556521	555035	11067R	PARTICIPANT	\N	PRESENT	0
556522	555035	14229S	PARTICIPANT	\N	PRESENT	0
556523	555035	19725B	PARTICIPANT	\N	PRESENT	0
556524	555035	19681G	PARTICIPANT	\N	PRESENT	0
556525	555035	19739H	PARTICIPANT	\N	PRESENT	0
556526	555035	14030Q	PARTICIPANT	\N	PRESENT	0
556527	555035	19649G	PARTICIPANT	\N	PRESENT	0
556528	555035	20134Y	PARTICIPANT	\N	PRESENT	0
556529	555035	20092G	PARTICIPANT	\N	PRESENT	0
556530	555035	20084G	PARTICIPANT	\N	PRESENT	0
556531	555035	01062T	PARTICIPANT	\N	PRESENT	0
556532	555035	19760E	PARTICIPANT	\N	PRESENT	0
556533	555035	14257W	PARTICIPANT	\N	PRESENT	0
556534	555035	14121F	PARTICIPANT	\N	PRESENT	0
556535	555035	20130U	PARTICIPANT	\N	PRESENT	0
556536	555035	19551W	PARTICIPANT	\N	PRESENT	0
556537	555035	04057K	PARTICIPANT	\N	PRESENT	0
556538	555035	19619A	PARTICIPANT	\N	PRESENT	0
556539	555035	11077T	PARTICIPANT	\N	PRESENT	0
556540	555035	20132W	PARTICIPANT	\N	PRESENT	0
556541	555035	95063L	PARTICIPANT	\N	PRESENT	0
556542	555035	04045F	PARTICIPANT	\N	PRESENT	0
556543	555035	04059M	PARTICIPANT	\N	PRESENT	0
556544	555035	11031D	PARTICIPANT	\N	PRESENT	0
556545	555035	19758L	PARTICIPANT	\N	PRESENT	0
556546	555035	20128B	PARTICIPANT	\N	PRESENT	0
556547	555035	19251M	PARTICIPANT	\N	PRESENT	0
556548	555035	19503N	PARTICIPANT	\N	PRESENT	0
556549	555035	14219Q	PARTICIPANT	\N	PRESENT	0
556550	555035	14211G	PARTICIPANT	\N	PRESENT	0
556551	555035	14026U	PARTICIPANT	\N	PRESENT	0
556552	555035	08034U	PARTICIPANT	\N	PRESENT	0
556553	555035	14123H	PARTICIPANT	\N	PRESENT	0
556554	555035	19693L	PARTICIPANT	\N	PRESENT	0
556555	555035	01058X	PARTICIPANT	\N	PRESENT	0
556556	555035	04092N	PARTICIPANT	\N	PRESENT	0
556557	555035	20076G	PARTICIPANT	\N	PRESENT	0
556558	555035	04042C	PARTICIPANT	\N	PRESENT	0
556559	555035	12041X	PARTICIPANT	\N	PRESENT	0
556560	555035	04047H	PARTICIPANT	\N	PRESENT	0
556561	555035	04085P	PARTICIPANT	\N	PRESENT	0
556562	555035	20078J	PARTICIPANT	\N	PRESENT	0
556563	555035	11033F	PARTICIPANT	\N	PRESENT	0
556564	555035	01048V	PARTICIPANT	\N	PRESENT	0
556565	555035	14071N	PARTICIPANT	\N	PRESENT	0
556566	555035	14133K	PARTICIPANT	\N	PRESENT	0
556567	555035	19347U	PARTICIPANT	\N	PRESENT	0
556568	555035	14223L	PARTICIPANT	\N	PRESENT	0
556569	555035	14169X	PARTICIPANT	\N	PRESENT	0
556570	555035	11090Q	PARTICIPANT	\N	PRESENT	0
556571	555035	19415P	PARTICIPANT	\N	PRESENT	0
556572	555035	14187A	PARTICIPANT	\N	PRESENT	0
556573	555035	04033B	PARTICIPANT	\N	PRESENT	0
556574	555035	08028W	PARTICIPANT	\N	PRESENT	0
556575	555035	08061X	PARTICIPANT	\N	PRESENT	0
556576	555035	20074E	PARTICIPANT	\N	PRESENT	0
556577	555035	18083K	PARTICIPANT	\N	PRESENT	0
556578	555035	19515S	PARTICIPANT	\N	PRESENT	0
556579	555035	11080N	PARTICIPANT	\N	PRESENT	0
556580	555035	19591F	PARTICIPANT	\N	PRESENT	0
556581	555035	14259Y	PARTICIPANT	\N	PRESENT	0
556582	555035	20106U	PARTICIPANT	\N	PRESENT	0
556583	555035	19301E	PARTICIPANT	\N	PRESENT	0
556584	555035	20068G	PARTICIPANT	\N	PRESENT	0
556585	555035	05012A	PARTICIPANT	\N	PRESENT	0
556586	555035	05008E	PARTICIPANT	\N	PRESENT	0
556587	555035	14249W	PARTICIPANT	\N	PRESENT	0
556588	555035	14053L	PARTICIPANT	\N	PRESENT	0
556589	555035	14215L	PARTICIPANT	\N	PRESENT	0
556590	555035	11097X	PARTICIPANT	\N	PRESENT	0
556591	555035	19689Q	PARTICIPANT	\N	PRESENT	0
556592	555035	20142Y	PARTICIPANT	\N	PRESENT	0
556593	555035	20110Q	PARTICIPANT	\N	PRESENT	0
556594	555035	19673G	PARTICIPANT	\N	PRESENT	0
556595	555035	19798U	PARTICIPANT	\N	PRESENT	0
556596	555035	20112S	PARTICIPANT	\N	PRESENT	0
556597	555035	14225N	PARTICIPANT	\N	PRESENT	0
556598	555035	14105F	PARTICIPANT	\N	PRESENT	0
556599	555035	20118Y	PARTICIPANT	\N	PRESENT	0
556600	555035	19966S	PARTICIPANT	\N	PRESENT	0
556601	555035	20136B	PARTICIPANT	\N	PRESENT	0
556602	555035	19719D	PARTICIPANT	\N	PRESENT	0
556603	555035	20180F	PARTICIPANT	\N	PRESENT	0
556604	555035	11083R	PARTICIPANT	\N	PRESENT	0
545725	545724	11040E	PARTICIPANT	\N	PRESENT	0
545726	545724	14255U	PARTICIPANT	\N	PRESENT	0
545727	545724	14221J	PARTICIPANT	\N	PRESENT	0
545728	545724	14111D	PARTICIPANT	\N	PRESENT	0
545729	545724	11027H	PARTICIPANT	\N	PRESENT	0
545730	545724	19369B	PARTICIPANT	\N	PRESENT	0
545731	545724	19575F	PARTICIPANT	\N	PRESENT	0
545732	545724	04035D	PARTICIPANT	\N	PRESENT	0
545740	545739	14329V	PARTICIPANT	\N	PRESENT	0
545744	545737	14329V	PARTICIPANT	\N	PRESENT	0
550841	550481	14105F	PARTICIPANT	\N	PRESENT	1
550842	550481	14255U	PARTICIPANT	\N	PRESENT	0
550843	550481	04042C	PRESIDENT	0	PRESENT	0
550844	550481	12028B	PARTICIPANT	\N	PRESENT	0
550845	550481	11027H	PARTICIPANT	\N	PRESENT	1
550846	550481	01024M	PARTICIPANT	\N	PRESENT	0
550847	550481	14249W	PARTICIPANT	\N	PRESENT	0
550848	550481	17023S	PARTICIPANT	\N	PRESENT	0
550849	550481	04035D	PARTICIPANT	\N	PRESENT	0
550850	550481	11083R	PARTICIPANT	\N	PRESENT	0
550851	550481	19347U	PARTICIPANT	\N	PRESENT	1
550852	550481	20072C	PARTICIPANT	\N	PRESENT	1
550853	550481	14097Y	PARTICIPANT	\N	PRESENT	1
550854	550481	12041X	PARTICIPANT	\N	PRESENT	0
550855	550481	16685X	PARTICIPANT	\N	PRESENT	0
550856	550481	08047A	PARTICIPANT	\N	PRESENT	0
550857	550481	19443T	PARTICIPANT	\N	PRESENT	1
550858	550481	19421M	PARTICIPANT	\N	PRESENT	0
550859	550481	01058X	PARTICIPANT	\N	PRESENT	0
550860	550481	19669L	PARTICIPANT	\N	PRESENT	1
550861	550481	11041F	PARTICIPANT	\N	PRESENT	1
550862	550481	04034C	PARTICIPANT	\N	PRESENT	0
550863	550481	11012A	PARTICIPANT	\N	PRESENT	1
550864	550481	14083S	PARTICIPANT	\N	PRESENT	1
552601	551124	19669L	PARTICIPANT	\N	PRESENT	0
552771	552769	08018U	PARTICIPANT	\N	PRESENT	0
552774	552769	11026G	PARTICIPANT	\N	PRESENT	0
552777	552769	20038A	PARTICIPANT	\N	PRESENT	0
552779	552769	20084G	PARTICIPANT	\N	PRESENT	0
552780	552769	14255U	PARTICIPANT	\N	PRESENT	0
552783	552769	14237S	PARTICIPANT	\N	PRESENT	0
552786	552769	18083K	PARTICIPANT	\N	PRESENT	0
552788	552769	14073Q	PARTICIPANT	\N	PRESENT	0
552849	552846	20024T	PARTICIPANT	\N	PRESENT	0
552851	552846	20042V	PARTICIPANT	\N	PRESENT	0
552852	552846	11027H	PARTICIPANT	\N	PRESENT	0
552854	552846	19531S	PARTICIPANT	\N	PRESENT	0
552855	552846	19697Q	PARTICIPANT	\N	PRESENT	0
552856	552846	20084G	PARTICIPANT	\N	PRESENT	0
552857	552846	10015M	PARTICIPANT	\N	PRESENT	0
553312	553311	20094J	PARTICIPANT	\N	PRESENT	0
553313	553311	14189C	PARTICIPANT	\N	PRESENT	0
553314	553311	19575F	PARTICIPANT	\N	PRESENT	0
554824	554823	11074Q	PARTICIPANT	\N	PRESENT	0
554825	554823	19349W	PARTICIPANT	\N	PRESENT	0
554827	554826	11074Q	PARTICIPANT	\N	PRESENT	0
554829	554828	11074Q	PARTICIPANT	\N	PRESENT	0
554830	554828	19349W	PARTICIPANT	\N	PRESENT	0
554832	554831	11053K	PARTICIPANT	\N	PRESENT	0
554834	554833	11053K	PARTICIPANT	\N	PRESENT	0
554836	554835	11048N	PARTICIPANT	\N	PRESENT	0
554838	554837	11048N	PARTICIPANT	\N	PRESENT	0
554840	554839	08073C	PARTICIPANT	\N	PRESENT	0
554841	554839	20150Y	PARTICIPANT	\N	PRESENT	0
554843	554842	08034U	PARTICIPANT	\N	PRESENT	0
554845	554844	19711U	PARTICIPANT	\N	PRESENT	0
554847	554846	11070L	PARTICIPANT	\N	PRESENT	0
555363	555359	14237S	PARTICIPANT	\N	PRESENT	0
555364	555360	14237S	PARTICIPANT	\N	PRESENT	0
555365	555361	14237S	PARTICIPANT	\N	PRESENT	0
555366	555362	14237S	PARTICIPANT	\N	PRESENT	0
555375	555374	14237S	PARTICIPANT	\N	PRESENT	0
558325	558324	08018U	PARTICIPANT	\N	PRESENT	0
558436	557688	19543W	PARTICIPANT	\N	PRESENT	0
558437	557688	19599P	PARTICIPANT	\N	PRESENT	0
558438	557688	19479G	PARTICIPANT	\N	PRESENT	0
558439	557688	19533U	PARTICIPANT	\N	PRESENT	0
558440	557688	11043H	PARTICIPANT	\N	PRESENT	0
558441	557688	20048C	PARTICIPANT	\N	PRESENT	0
558442	557688	19691J	PARTICIPANT	\N	PRESENT	0
558444	557688	19741B	PARTICIPANT	\N	PRESENT	0
558445	557688	14031R	PARTICIPANT	\N	PRESENT	0
558446	557688	20042V	PARTICIPANT	\N	PRESENT	0
558447	557688	14083S	PARTICIPANT	\N	PRESENT	0
558448	557688	11031D	PARTICIPANT	\N	PRESENT	0
558453	557688	14021P	PARTICIPANT	\N	PRESENT	0
558454	557688	20028X	PARTICIPANT	\N	PRESENT	0
558456	557688	14033T	PARTICIPANT	\N	PRESENT	0
558457	557688	01058X	PARTICIPANT	\N	PRESENT	0
558458	557688	14151M	PARTICIPANT	\N	PRESENT	0
558459	557688	11048N	PARTICIPANT	\N	PRESENT	0
558460	557688	14221J	PARTICIPANT	\N	PRESENT	0
558461	557688	20080C	PARTICIPANT	\N	PRESENT	0
558462	557688	20096L	PARTICIPANT	\N	PRESENT	0
558463	557688	19507S	PARTICIPANT	\N	PRESENT	0
558464	557688	01024M	PARTICIPANT	\N	PRESENT	0
558471	557688	20174H	PARTICIPANT	\N	PRESENT	0
558473	557688	14215L	PARTICIPANT	\N	PRESENT	0
558476	557688	11097X	PARTICIPANT	\N	PRESENT	0
558479	557688	20098N	PARTICIPANT	\N	PRESENT	0
558483	557688	20066E	PARTICIPANT	\N	PRESENT	0
558484	557688	14207L	PARTICIPANT	\N	PRESENT	0
558485	557688	20054A	PARTICIPANT	\N	PRESENT	0
558487	557688	20062A	PARTICIPANT	\N	PRESENT	0
558489	557688	20034V	PARTICIPANT	\N	PRESENT	0
558493	557688	11065P	PARTICIPANT	\N	PRESENT	0
558497	557688	14071N	PARTICIPANT	\N	PRESENT	0
558498	557688	14193X	PARTICIPANT	\N	PRESENT	0
558499	557688	20092G	PARTICIPANT	\N	PRESENT	0
558500	557976	19699S	PARTICIPANT	\N	PRESENT	0
558501	557976	19533U	PARTICIPANT	\N	PRESENT	0
558536	557688	19441R	PARTICIPANT	\N	PRESENT	0
558503	557976	19573D	PARTICIPANT	\N	PRESENT	0
558504	557976	08012N	PARTICIPANT	\N	PRESENT	0
558505	557976	08061X	PARTICIPANT	\N	PRESENT	0
558506	557976	20124W	PARTICIPANT	\N	PRESENT	1
558507	557976	20026V	PARTICIPANT	\N	PRESENT	1
558508	557976	19643A	PARTICIPANT	\N	PRESENT	1
558509	557976	20132W	PARTICIPANT	\N	PRESENT	1
558510	557976	20134Y	PARTICIPANT	\N	PRESENT	0
558511	557976	19651A	PARTICIPANT	\N	PRESENT	1
558512	557976	14073Q	PARTICIPANT	\N	PRESENT	0
558513	557976	20138D	PARTICIPANT	\N	PRESENT	1
558514	557976	19611R	PRESIDENT	0	PRESENT	0
558515	557976	20142Y	PARTICIPANT	\N	PRESENT	1
558516	557976	19693L	PARTICIPANT	\N	PRESENT	0
558517	557976	19399H	PARTICIPANT	\N	PRESENT	0
558518	557976	20052X	PARTICIPANT	\N	PRESENT	1
558519	557976	20058E	PARTICIPANT	\N	PRESENT	0
558520	557976	20056C	PARTICIPANT	\N	PRESENT	0
558521	557976	20180F	PARTICIPANT	\N	PRESENT	1
558522	557976	19735D	PARTICIPANT	\N	PRESENT	0
558523	557976	14123H	PARTICIPANT	\N	PRESENT	0
558524	557976	19758L	PARTICIPANT	\N	PRESENT	1
558525	557976	19621T	PARTICIPANT	\N	PRESENT	0
558526	557976	11109J	PARTICIPANT	\N	EXCUSE	0
558528	557688	19713W	PARTICIPANT	\N	PRESENT	0
558530	557976	11043H	PARTICIPANT	\N	PRESENT	0
558531	557688	14217N	PARTICIPANT	\N	PRESENT	0
558532	557688	19681G	PARTICIPANT	\N	PRESENT	0
558533	557976	19527W	PARTICIPANT	\N	PRESENT	0
558534	557976	20098N	PARTICIPANT	\N	PRESENT	1
558535	557688	14213J	PARTICIPANT	\N	PRESENT	0
558537	557303	14327T	PARTICIPANT	\N	PRESENT	0
558538	557303	14083S	PARTICIPANT	\N	PRESENT	0
558539	557303	11048N	PARTICIPANT	\N	PRESENT	0
558540	557303	19711U	PARTICIPANT	\N	PRESENT	0
558541	557303	01057W	PARTICIPANT	\N	PRESENT	0
558542	557303	19689Q	PARTICIPANT	\N	PRESENT	0
558543	557303	20080C	PARTICIPANT	\N	PRESENT	0
558544	557303	19741B	PARTICIPANT	\N	PRESENT	0
558545	557303	14253S	PARTICIPANT	\N	PRESENT	0
558546	557303	99004R	PARTICIPANT	\N	PRESENT	0
558547	557303	20044X	PARTICIPANT	\N	PRESENT	0
558548	557303	14225N	PRESIDENT	0	PRESENT	0
558549	557303	14189C	PARTICIPANT	\N	EXCUSE	0
558550	557303	19479G	PARTICIPANT	\N	PRESENT	0
558551	557303	19335Q	PARTICIPANT	\N	PRESENT	0
558556	557688	19747H	PARTICIPANT	\N	PRESENT	0
558558	558557	19447X	PARTICIPANT	\N	PRESENT	0
558559	558557	11026G	PARTICIPANT	\N	PRESENT	0
564407	559011	19349W	PARTICIPANT	\N	PRESENT	0
564408	559011	20044X	PARTICIPANT	\N	PRESENT	0
564409	559011	11097X	PARTICIPANT	\N	PRESENT	0
564411	564410	19711U	PARTICIPANT	\N	PRESENT	0
564413	564412	20022R	PARTICIPANT	\N	PRESENT	0
564414	564412	14331P	PARTICIPANT	\N	PRESENT	0
564416	564415	19711U	PARTICIPANT	\N	PRESENT	0
564418	564417	19711U	PARTICIPANT	\N	PRESENT	0
564420	564419	11048N	PARTICIPANT	\N	PRESENT	0
564421	545946	11067R	PARTICIPANT	\N	EXCUSE	0
564422	545946	19503N	PARTICIPANT	\N	EXCUSE	0
564423	545946	19723Y	PARTICIPANT	\N	PRESENT	0
564424	559959	01028R	PARTICIPANT	\N	EXCUSE	0
564425	559959	14038Y	PARTICIPANT	\N	PRESENT	0
564426	559959	19551W	PARTICIPANT	\N	EXCUSE	0
564427	564250	20086J	PARTICIPANT	\N	PRESENT	0
564428	564250	19699S	PARTICIPANT	\N	PRESENT	0
564429	564250	20092G	PARTICIPANT	\N	PRESENT	0
564430	564250	14187A	PARTICIPANT	\N	PRESENT	0
564431	564250	14357A	PARTICIPANT	\N	PRESENT	0
564432	564250	14033T	PARTICIPANT	\N	PRESENT	0
564433	564250	11090Q	PRESIDENT	0	PRESENT	0
564434	564250	04045F	PARTICIPANT	\N	PRESENT	0
564435	564250	19631V	PARTICIPANT	\N	PRESENT	0
564436	564250	11099A	PARTICIPANT	\N	PRESENT	0
564437	564250	19705W	PARTICIPANT	\N	PRESENT	0
564438	564250	14251Q	PARTICIPANT	\N	PRESENT	0
564439	564250	19507S	PARTICIPANT	\N	PRESENT	0
564440	564250	14257W	PARTICIPANT	\N	PRESENT	0
564442	564441	20042V	PARTICIPANT	\N	PRESENT	0
564443	564441	11054L	PARTICIPANT	\N	PRESENT	0
564444	564441	01058X	PARTICIPANT	\N	PRESENT	0
564445	564441	14193X	PARTICIPANT	\N	PRESENT	0
564447	564446	14219Q	PARTICIPANT	\N	PRESENT	0
564448	564446	20038A	PARTICIPANT	\N	PRESENT	0
564449	564446	20084G	PARTICIPANT	\N	PRESENT	0
564450	564446	20150Y	PARTICIPANT	\N	PRESENT	0
564451	564446	04043D	PARTICIPANT	\N	PRESENT	0
564452	564446	14001X	PARTICIPANT	\N	PRESENT	0
564453	564446	01058X	PARTICIPANT	\N	PRESENT	0
564454	564446	08012N	PARTICIPANT	\N	PRESENT	0
564455	564250	14038Y	PARTICIPANT	\N	PRESENT	1
564456	564250	19515S	PARTICIPANT	\N	PRESENT	1
564457	564250	19711U	PARTICIPANT	\N	PRESENT	1
564458	564250	19782L	PARTICIPANT	\N	PRESENT	1
564459	564250	19695N	PARTICIPANT	\N	PRESENT	1
564460	564250	20082E	PARTICIPANT	\N	PRESENT	1
564461	564250	01025N	PARTICIPANT	\N	PRESENT	1
564462	564250	19747H	PARTICIPANT	\N	PRESENT	1
564489	564251	14038Y	PARTICIPANT	\N	PRESENT	0
564490	564251	20086J	PARTICIPANT	\N	PRESENT	0
564491	564251	19515S	PARTICIPANT	\N	PRESENT	0
564492	564251	20034V	PARTICIPANT	\N	PRESENT	1
564493	564251	20092G	PARTICIPANT	\N	PRESENT	0
564494	564251	14357A	PARTICIPANT	\N	PRESENT	0
564495	564251	14187A	PARTICIPANT	\N	PRESENT	0
564496	564251	20082E	PARTICIPANT	\N	PRESENT	0
564497	564251	14033T	PARTICIPANT	\N	PRESENT	0
564498	564251	11090Q	PRESIDENT	0	PRESENT	0
564499	564251	04045F	PARTICIPANT	\N	PRESENT	0
564500	564251	19631V	PARTICIPANT	\N	PRESENT	0
564501	564251	20060X	PARTICIPANT	\N	PRESENT	0
564502	564251	19705W	PARTICIPANT	\N	PRESENT	1
564503	564251	19507S	PARTICIPANT	\N	PRESENT	0
564504	564251	08015R	PARTICIPANT	\N	PRESENT	0
564505	564251	19575F	PARTICIPANT	\N	PRESENT	0
564506	564251	20018V	PARTICIPANT	\N	PRESENT	0
564507	564251	19747H	PARTICIPANT	\N	PRESENT	0
564508	564251	19511N	PARTICIPANT	\N	PRESENT	0
564509	564251	14257W	PARTICIPANT	\N	PRESENT	0
564510	564251	14329V	PARTICIPANT	\N	PRESENT	0
564511	564251	20088L	PARTICIPANT	\N	PRESENT	1
564512	564251	01043Q	PARTICIPANT	\N	PRESENT	1
564513	564251	19563B	PARTICIPANT	\N	PRESENT	1
564514	564251	20030R	PARTICIPANT	\N	PRESENT	1
564515	564251	20174H	PARTICIPANT	\N	PRESENT	1
564516	564251	14207L	PARTICIPANT	\N	PRESENT	1
564517	564251	08028W	PARTICIPANT	\N	EXCUSE	0
564518	564251	20078J	PARTICIPANT	\N	PRESENT	1
564519	564251	20054A	PARTICIPANT	\N	PRESENT	1
564525	564335	19719D	PARTICIPANT	\N	PRESENT	0
564533	563959	19489J	PARTICIPANT	\N	PRESENT	0
564534	563959	20074E	PARTICIPANT	\N	PRESENT	0
564535	563959	14041T	PARTICIPANT	\N	PRESENT	0
564536	563959	20108W	PARTICIPANT	\N	PRESENT	0
564537	563959	14147R	PARTICIPANT	\N	PRESENT	0
564538	563959	14215L	PRESIDENT	0	PRESENT	0
564539	563959	19585H	PARTICIPANT	\N	PRESENT	0
564540	563959	04047H	PARTICIPANT	\N	PRESENT	0
564541	563959	01028R	PARTICIPANT	\N	PRESENT	0
564542	563959	05008E	PARTICIPANT	\N	PRESENT	0
564546	564335	14259Y	PARTICIPANT	\N	PRESENT	0
564547	564335	20068G	PARTICIPANT	\N	PRESENT	0
564548	564335	20096L	PARTICIPANT	\N	PRESENT	0
564549	564335	20180F	PARTICIPANT	\N	PRESENT	0
564550	564335	20026V	PARTICIPANT	\N	PRESENT	0
564551	564335	20020P	PARTICIPANT	\N	PRESENT	0
564552	564335	97011G	PARTICIPANT	\N	PRESENT	0
564553	564335	11103C	PARTICIPANT	\N	PRESENT	0
564554	564335	19333N	PARTICIPANT	\N	PRESENT	0
564555	564335	20114U	PARTICIPANT	\N	PRESENT	0
564556	564335	11040E	PARTICIPANT	\N	PRESENT	0
564557	564335	95063L	PARTICIPANT	\N	PRESENT	0
564558	564335	19349W	PARTICIPANT	\N	PRESENT	0
564559	564335	18083K	PARTICIPANT	\N	PRESENT	0
564560	564335	20124W	PARTICIPANT	\N	PRESENT	0
564561	564335	20098N	PARTICIPANT	\N	PRESENT	0
564562	564335	19683J	PARTICIPANT	\N	PRESENT	0
564563	564335	14281W	PARTICIPANT	\N	PRESENT	0
564564	564335	14151M	PARTICIPANT	\N	PRESENT	0
564565	564335	14195A	PARTICIPANT	\N	PRESENT	0
564566	564335	11048N	PARTICIPANT	\N	PRESENT	0
564567	564335	20108W	PARTICIPANT	\N	PRESENT	0
564568	564335	19667J	PARTICIPANT	\N	PRESENT	0
564569	564335	20066E	PARTICIPANT	\N	PRESENT	0
564570	564335	14231L	PARTICIPANT	\N	PRESENT	0
564571	564335	20116W	PARTICIPANT	\N	PRESENT	0
564572	564335	20076G	PARTICIPANT	\N	PRESENT	0
564573	564335	20138D	PARTICIPANT	\N	PRESENT	0
564574	564335	14327T	PARTICIPANT	\N	PRESENT	0
564575	564335	14105F	PARTICIPANT	\N	PRESENT	0
564576	564335	19687N	PARTICIPANT	\N	PRESENT	0
564577	564252	19515S	PARTICIPANT	\N	PRESENT	0
564612	564335	01058X	PARTICIPANT	\N	PRESENT	0
564613	564252	14038Y	PARTICIPANT	\N	PRESENT	0
564615	564252	20082E	PARTICIPANT	\N	PRESENT	0
564581	564252	14357A	PARTICIPANT	\N	PRESENT	0
564582	564252	19441R	PARTICIPANT	\N	PRESENT	0
564583	564252	04045F	PARTICIPANT	\N	PRESENT	0
564584	564252	19631V	PARTICIPANT	\N	PRESENT	0
564585	564252	11099A	PARTICIPANT	\N	PRESENT	0
564587	564252	08015R	PARTICIPANT	\N	PRESENT	0
564617	564252	01043Q	PARTICIPANT	\N	PRESENT	0
564614	564335	20092G	PARTICIPANT	\N	PRESENT	0
564590	564252	19467C	PARTICIPANT	\N	PRESENT	1
564618	564252	20144B	PARTICIPANT	\N	PRESENT	0
564616	564335	19745F	PARTICIPANT	\N	PRESENT	0
564593	564252	11090Q	PRESIDENT	0	PRESENT	0
564594	564252	01025N	PARTICIPANT	\N	PRESENT	0
564595	564252	14033T	PARTICIPANT	\N	PRESENT	0
564597	564252	14205J	PARTICIPANT	\N	PRESENT	0
564619	564335	20044X	PARTICIPANT	\N	PRESENT	0
564601	564252	19747H	PARTICIPANT	\N	PRESENT	0
564602	564252	14207L	PARTICIPANT	\N	PRESENT	0
564604	564252	14257W	PARTICIPANT	\N	PRESENT	0
564605	564252	14329V	PARTICIPANT	\N	PRESENT	0
564606	564335	19335Q	PARTICIPANT	\N	PRESENT	0
564607	564252	20086J	PARTICIPANT	\N	PRESENT	0
564608	564252	20088L	PARTICIPANT	\N	PRESENT	1
564609	564252	20104S	PARTICIPANT	\N	PRESENT	0
564610	564335	20042V	PARTICIPANT	\N	PRESENT	0
564611	564335	20024T	PARTICIPANT	\N	PRESENT	0
564620	564335	05008E	PARTICIPANT	\N	PRESENT	0
564621	564335	08061X	PARTICIPANT	\N	PRESENT	0
564622	564335	20056C	PARTICIPANT	\N	PRESENT	0
564623	564335	17367Q	PARTICIPANT	\N	PRESENT	0
542775	542774	14357A	PARTICIPANT	\N	PRESENT	0
542776	542774	14041T	PARTICIPANT	\N	PRESENT	0
542777	542774	14071N	PARTICIPANT	\N	PRESENT	0
542778	542774	19762G	PARTICIPANT	\N	PRESENT	0
542779	542774	19443T	PARTICIPANT	\N	PRESENT	0
542798	542797	14089Y	PARTICIPANT	\N	PRESENT	0
542799	542797	20122U	PARTICIPANT	\N	PRESENT	0
542800	542797	11026G	PARTICIPANT	\N	PRESENT	0
548286	548285	14189C	PARTICIPANT	\N	PRESENT	0
548287	548285	04057K	PARTICIPANT	\N	PRESENT	0
557981	557980	08018U	PARTICIPANT	\N	PRESENT	0
557982	557980	20038A	PARTICIPANT	\N	PRESENT	0
557984	557983	20088L	PARTICIPANT	\N	PRESENT	0
557985	557983	14105F	PARTICIPANT	\N	PRESENT	0
557986	557983	19782L	PARTICIPANT	\N	PRESENT	1
557987	557983	20090E	PARTICIPANT	\N	PRESENT	0
557988	557983	14207L	PARTICIPANT	\N	PRESENT	0
557989	557983	14357A	PARTICIPANT	\N	PRESENT	0
557990	557983	01024M	PARTICIPANT	\N	PRESENT	0
557991	557983	01025N	PARTICIPANT	\N	PRESENT	0
557992	557983	20132W	PARTICIPANT	\N	PRESENT	0
557993	557983	19820Y	PARTICIPANT	\N	PRESENT	1
557994	557983	20128B	PARTICIPANT	\N	PRESENT	0
557995	557983	14097Y	PARTICIPANT	\N	PRESENT	1
557996	557983	19723Y	PARTICIPANT	\N	PRESENT	0
557997	557983	19611R	PARTICIPANT	\N	PRESENT	0
557998	557983	19441R	PARTICIPANT	\N	PRESENT	0
557999	557983	20028X	PARTICIPANT	\N	PRESENT	0
558000	557983	14109K	PARTICIPANT	\N	PRESENT	1
558001	557983	14257W	PARTICIPANT	\N	PRESENT	1
558002	557983	05012A	PARTICIPANT	\N	PRESENT	0
558003	557983	19503N	PARTICIPANT	\N	PRESENT	0
558004	557983	04045F	PARTICIPANT	\N	PRESENT	1
558005	557983	19713W	PARTICIPANT	\N	PRESENT	0
558006	557983	20058E	PARTICIPANT	\N	PRESENT	1
558972	558971	20042V	PARTICIPANT	\N	PRESENT	0
558973	558971	14193X	PARTICIPANT	\N	PRESENT	0
559000	557978	19383Y	PRESIDENT	0	PRESENT	0
559001	557978	19719D	PARTICIPANT	\N	PRESENT	1
559002	557978	14026U	PARTICIPANT	\N	PRESENT	0
559003	557978	20028X	PARTICIPANT	\N	PRESENT	0
559004	557978	14109K	PARTICIPANT	\N	PRESENT	1
559005	557978	19798U	PARTICIPANT	\N	PRESENT	1
559006	557978	19713W	PARTICIPANT	\N	PRESENT	0
559007	557978	20026V	PARTICIPANT	\N	PRESENT	1
559010	557978	19551W	PARTICIPANT	\N	EXCUSE	0
559967	559965	14187A	PARTICIPANT	\N	PRESENT	0
559968	559966	14187A	PARTICIPANT	\N	PRESENT	0
559975	559969	14187A	PARTICIPANT	\N	PRESENT	0
559976	559971	14187A	PARTICIPANT	\N	PRESENT	0
559977	559972	14187A	PARTICIPANT	\N	PRESENT	0
559978	559972	19631V	PARTICIPANT	\N	PRESENT	0
559979	559973	14187A	PARTICIPANT	\N	PRESENT	0
559980	559974	14187A	PARTICIPANT	\N	PRESENT	0
559982	559981	14187A	PARTICIPANT	\N	PRESENT	0
559987	559986	14033T	PARTICIPANT	\N	PRESENT	0
559993	559988	14033T	PARTICIPANT	\N	PRESENT	0
559994	559989	14033T	PARTICIPANT	\N	PRESENT	0
559995	559990	14033T	PARTICIPANT	\N	PRESENT	0
559996	559991	14033T	PARTICIPANT	\N	PRESENT	0
559997	559992	14033T	PARTICIPANT	\N	PRESENT	0
560000	559998	14033T	PARTICIPANT	\N	PRESENT	0
560001	559999	14033T	PARTICIPANT	\N	PRESENT	0
560022	560005	14033T	PARTICIPANT	\N	PRESENT	0
560025	560006	14033T	PARTICIPANT	\N	PRESENT	0
560028	560008	14033T	PARTICIPANT	\N	PRESENT	0
560030	560010	14033T	PARTICIPANT	\N	PRESENT	0
560130	560066	14033T	PARTICIPANT	\N	PRESENT	0
560131	560068	14033T	PARTICIPANT	\N	PRESENT	0
560135	560069	14033T	PARTICIPANT	\N	PRESENT	0
560136	560071	14033T	PARTICIPANT	\N	PRESENT	0
560139	560137	14033T	PARTICIPANT	\N	PRESENT	0
560159	560138	14033T	PARTICIPANT	\N	PRESENT	0
560217	560216	19543W	PARTICIPANT	\N	PRESENT	0
560701	559485	08028W	PARTICIPANT	\N	PRESENT	0
560702	559485	14257W	PARTICIPANT	\N	PRESENT	0
560703	559485	20030R	PARTICIPANT	\N	PRESENT	1
560704	559485	20092G	PARTICIPANT	\N	PRESENT	1
560705	559485	14033T	PARTICIPANT	\N	PRESENT	1
560706	559485	20174H	PARTICIPANT	\N	PRESENT	1
560707	559485	20062A	PARTICIPANT	\N	PRESENT	1
560708	559485	14251Q	PARTICIPANT	\N	PRESENT	1
560709	559485	14207L	PARTICIPANT	\N	PRESENT	1
560710	559485	19563B	PARTICIPANT	\N	PRESENT	0
560711	559485	19441R	PARTICIPANT	\N	PRESENT	0
560712	559485	14038Y	PARTICIPANT	\N	PRESENT	1
560713	560588	19685L	PARTICIPANT	\N	PRESENT	0
560714	560588	14169X	PARTICIPANT	\N	PRESENT	1
560715	559485	20144B	PARTICIPANT	\N	PRESENT	0
560716	559485	19695N	PARTICIPANT	\N	PRESENT	0
560717	559541	11048N	PARTICIPANT	\N	PRESENT	0
560718	559541	19687N	PARTICIPANT	\N	PRESENT	0
560719	559541	20080C	PARTICIPANT	\N	PRESENT	0
560720	559541	19667J	PARTICIPANT	\N	PRESENT	0
560721	559541	14083S	PARTICIPANT	\N	PRESENT	0
560722	559541	20070A	PARTICIPANT	\N	PRESENT	0
560723	559541	20022R	PARTICIPANT	\N	PRESENT	0
560724	559635	19735D	PARTICIPANT	\N	PRESENT	1
560725	559485	20082E	PARTICIPANT	\N	PRESENT	1
560726	559485	19782L	PARTICIPANT	\N	PRESENT	0
560727	559485	20104S	PARTICIPANT	\N	PRESENT	0
560728	559485	19507S	PARTICIPANT	\N	PRESENT	0
560729	559541	08009T	PARTICIPANT	\N	PRESENT	0
560730	559541	19711U	PARTICIPANT	\N	PRESENT	0
560731	559541	11070L	PARTICIPANT	\N	PRESENT	0
560732	559209	08018U	PARTICIPANT	\N	PRESENT	0
560733	559209	14069U	PARTICIPANT	\N	PRESENT	0
560734	559209	14259Y	PARTICIPANT	\N	PRESENT	0
560735	560588	19551W	PARTICIPANT	\N	PRESENT	0
560736	559541	11053K	PARTICIPANT	\N	PRESENT	0
560737	559485	11099A	PARTICIPANT	\N	PRESENT	0
560738	559485	19705W	PARTICIPANT	\N	PRESENT	1
560782	559727	19697Q	PARTICIPANT	\N	PRESENT	0
560783	559727	11067R	PARTICIPANT	\N	PRESENT	0
560784	559727	20090E	PARTICIPANT	\N	PRESENT	0
560785	559727	19569H	PARTICIPANT	\N	PRESENT	0
560786	559727	19798U	PARTICIPANT	\N	PRESENT	0
560787	559727	11097X	PARTICIPANT	\N	PRESENT	0
560788	559727	19415P	PARTICIPANT	\N	PRESENT	1
560789	559727	14223L	PARTICIPANT	\N	PRESENT	0
560790	559727	14026U	PARTICIPANT	\N	PRESENT	1
560791	559727	17779H	PARTICIPANT	\N	PRESENT	0
560792	559727	19551W	PARTICIPANT	\N	PRESENT	0
560793	559727	11031D	PARTICIPANT	\N	PRESENT	1
560794	559727	19553Y	PARTICIPANT	\N	PRESENT	1
560795	559727	19679N	PARTICIPANT	\N	PRESENT	0
560796	559727	14042U	PARTICIPANT	\N	PRESENT	0
560797	559727	14195A	PARTICIPANT	\N	PRESENT	0
560798	559727	14213J	PARTICIPANT	\N	PRESENT	0
560799	559727	19367Y	PARTICIPANT	\N	PRESENT	0
560800	559727	14217N	PARTICIPANT	\N	PRESENT	0
560801	559727	19683J	PARTICIPANT	\N	PRESENT	0
560802	559727	10006L	PARTICIPANT	\N	PRESENT	0
560803	559727	19591F	PARTICIPANT	\N	PRESENT	0
560804	559727	20130U	PARTICIPANT	\N	PRESENT	1
560805	559727	01034P	PARTICIPANT	\N	PRESENT	0
560806	559727	04057K	PARTICIPANT	\N	PRESENT	0
560807	559727	04092N	PARTICIPANT	\N	PRESENT	0
560808	559727	19713W	PARTICIPANT	\N	PRESENT	1
560809	559727	08045X	PARTICIPANT	\N	PRESENT	0
560810	559727	20040T	PARTICIPANT	\N	PRESENT	0
560811	559727	19663E	PARTICIPANT	\N	PRESENT	1
560812	559727	19301E	PARTICIPANT	\N	PRESENT	1
560813	559727	17965H	PARTICIPANT	\N	PRESENT	0
560814	559727	19691J	PARTICIPANT	\N	PRESENT	0
560815	559727	20172F	PARTICIPANT	\N	PRESENT	1
560816	559727	20066E	PARTICIPANT	\N	PRESENT	1
560817	559727	11103C	PARTICIPANT	\N	PRESENT	1
560818	559727	14071N	PRESIDENT	0	PRESENT	0
560819	559727	19657G	PARTICIPANT	\N	PRESENT	0
560820	559727	04043D	PARTICIPANT	\N	PRESENT	1
560821	559727	19760E	PARTICIPANT	\N	PRESENT	0
560822	559727	18193Q	PARTICIPANT	\N	EXCUSE	0
560823	559727	19295A	PARTICIPANT	\N	EXCUSE	0
560928	559486	20174H	PARTICIPANT	\N	PRESENT	1
560937	560589	14038Y	PARTICIPANT	\N	PRESENT	1
560938	560589	20030R	PARTICIPANT	\N	PRESENT	1
560939	560589	19515S	PARTICIPANT	\N	PRESENT	1
560940	560589	20174H	PARTICIPANT	\N	PRESENT	1
560941	560589	20062A	PARTICIPANT	\N	PRESENT	1
556605	555035	14195A	PARTICIPANT	\N	PRESENT	0
556606	555035	17737W	PARTICIPANT	\N	PRESENT	0
556607	555035	14251Q	PARTICIPANT	\N	PRESENT	0
556608	555035	19667J	PARTICIPANT	\N	PRESENT	0
556609	555035	19573D	PARTICIPANT	\N	PRESENT	0
556610	555035	01028R	PARTICIPANT	\N	PRESENT	0
556611	555035	20140W	PARTICIPANT	\N	PRESENT	0
556612	555035	11045K	PARTICIPANT	\N	PRESENT	0
556613	555035	20026V	PARTICIPANT	\N	PRESENT	0
556614	555035	20056C	PARTICIPANT	\N	PRESENT	0
556615	555035	01057W	PARTICIPANT	\N	PRESENT	0
556616	555035	14021P	PARTICIPANT	\N	PRESENT	0
556617	555035	20098N	PARTICIPANT	\N	PRESENT	0
556618	555035	14151M	PARTICIPANT	\N	PRESENT	0
556619	555035	20172F	PARTICIPANT	\N	PRESENT	0
556620	555035	14097Y	PARTICIPANT	\N	PRESENT	0
556621	555035	19762G	PARTICIPANT	\N	PRESENT	0
556622	555035	07033P	PARTICIPANT	\N	PRESENT	0
556623	555035	20108W	PARTICIPANT	\N	PRESENT	0
556624	555035	14109K	PARTICIPANT	\N	PRESENT	0
556625	555035	19820Y	PARTICIPANT	\N	PRESENT	0
556626	555035	14217N	PARTICIPANT	\N	PRESENT	0
556627	555035	19581D	PARTICIPANT	\N	PRESENT	0
556628	555035	08017T	PARTICIPANT	\N	PRESENT	0
556629	555035	19467C	PARTICIPANT	\N	PRESENT	0
556630	555035	20088L	PARTICIPANT	\N	PRESENT	0
556631	555035	19367Y	PARTICIPANT	\N	PRESENT	0
556632	555035	20152B	PARTICIPANT	\N	PRESENT	0
556633	555035	18193Q	PARTICIPANT	\N	PRESENT	0
556634	555035	20018V	PARTICIPANT	\N	PRESENT	0
556635	555035	14357A	PARTICIPANT	\N	PRESENT	0
556636	555035	20024T	PARTICIPANT	\N	PRESENT	0
556637	555035	14193X	PARTICIPANT	\N	PRESENT	0
556638	555035	20104S	PARTICIPANT	\N	PRESENT	0
556639	555035	20040T	PARTICIPANT	\N	PRESENT	0
556640	555035	17229F	PARTICIPANT	\N	PRESENT	0
556641	555035	14083S	PARTICIPANT	\N	PRESENT	0
556642	555035	20090E	PARTICIPANT	\N	PRESENT	0
556643	555035	20066E	PARTICIPANT	\N	PRESENT	0
556644	555035	08015R	PARTICIPANT	\N	PRESENT	0
556645	555035	20120S	PARTICIPANT	\N	PRESENT	0
556646	555035	19441R	PARTICIPANT	\N	PRESENT	0
556647	555035	08018U	PARTICIPANT	\N	PRESENT	0
556648	555035	14041T	PARTICIPANT	\N	PRESENT	0
556649	555035	19699S	PARTICIPANT	\N	PRESENT	0
556650	555035	14038Y	PARTICIPANT	\N	PRESENT	0
556651	555035	20042V	PARTICIPANT	\N	PRESENT	0
556652	555035	19575F	PARTICIPANT	\N	PRESENT	0
556653	555035	14267Y	PARTICIPANT	\N	PRESENT	0
556654	555035	19543W	PARTICIPANT	\N	PRESENT	0
556655	555035	19685L	PARTICIPANT	\N	PRESENT	0
556656	555035	14073Q	PARTICIPANT	\N	PRESENT	0
556657	555035	14089Y	PARTICIPANT	\N	PRESENT	0
556658	555035	19749K	PARTICIPANT	\N	PRESENT	0
556659	555035	19826F	PARTICIPANT	\N	PRESENT	0
556660	555035	14255U	PARTICIPANT	\N	PRESENT	0
556661	555035	19611R	PARTICIPANT	\N	PRESENT	0
556662	555035	14189C	PARTICIPANT	\N	PRESENT	0
556663	555035	19643A	PARTICIPANT	\N	PRESENT	0
556664	555035	19723Y	PARTICIPANT	\N	PRESENT	0
556665	555035	20034V	PARTICIPANT	\N	PRESENT	0
556666	555035	11048N	PARTICIPANT	\N	PRESENT	0
556667	555035	19565D	PARTICIPANT	\N	PRESENT	0
556668	555035	11103C	PARTICIPANT	\N	PRESENT	0
556669	555035	14147R	PARTICIPANT	\N	PRESENT	0
556670	555035	19479G	PARTICIPANT	\N	PRESENT	0
556671	555035	19729F	PARTICIPANT	\N	PRESENT	0
556672	555035	19711U	PARTICIPANT	\N	PRESENT	0
556673	555035	19741B	PARTICIPANT	\N	PRESENT	0
556674	555035	20016T	PARTICIPANT	\N	PRESENT	0
556675	555035	08056B	PARTICIPANT	\N	PRESENT	0
556676	555035	20126Y	PARTICIPANT	\N	PRESENT	0
556677	555035	19701S	PARTICIPANT	\N	PRESENT	0
556678	555035	20124W	PARTICIPANT	\N	PRESENT	0
556679	555035	20064C	PARTICIPANT	\N	PRESENT	0
556680	555035	20044X	PARTICIPANT	\N	PRESENT	0
556681	555035	20138D	PARTICIPANT	\N	PRESENT	0
556682	555035	20070A	PARTICIPANT	\N	PRESENT	0
556683	555035	19647E	PARTICIPANT	\N	PRESENT	0
556684	555035	19679N	PARTICIPANT	\N	PRESENT	0
556685	555035	19399H	PARTICIPANT	\N	PRESENT	0
556686	555035	19533U	PARTICIPANT	\N	PRESENT	0
556687	555035	08047A	PARTICIPANT	\N	PRESENT	0
556688	555035	17367Q	PARTICIPANT	\N	PRESENT	0
556689	555035	97011G	PARTICIPANT	\N	PRESENT	0
556690	555035	14331P	PARTICIPANT	\N	PRESENT	0
556691	555035	14031R	PARTICIPANT	\N	PRESENT	0
556692	555035	14205J	PARTICIPANT	\N	PRESENT	0
556693	555035	11043H	PARTICIPANT	\N	PRESENT	0
556694	555035	11099A	PARTICIPANT	\N	PRESENT	0
556696	555035	86034E	PARTICIPANT	\N	PRESENT	0
556697	555035	99004R	PARTICIPANT	\N	PRESENT	0
556698	555035	20038A	PARTICIPANT	\N	PRESENT	0
556699	556695	14331P	PARTICIPANT	\N	PRESENT	0
556700	556695	14207L	PARTICIPANT	\N	PRESENT	0
556701	556695	20128B	PARTICIPANT	\N	PRESENT	0
556702	556695	14097Y	PARTICIPANT	\N	PRESENT	0
556703	556695	19441R	PARTICIPANT	\N	PRESENT	0
556704	556695	14169X	PARTICIPANT	\N	PRESENT	0
556705	556695	11090Q	PARTICIPANT	\N	PRESENT	0
556706	556695	20144B	PARTICIPANT	\N	PRESENT	0
556707	556695	14357A	PARTICIPANT	\N	PRESENT	0
556708	556695	19507S	PARTICIPANT	\N	PRESENT	0
556709	556695	11099A	PARTICIPANT	\N	PRESENT	0
556710	556695	19563B	PARTICIPANT	\N	PRESENT	0
556711	556695	14257W	PARTICIPANT	\N	PRESENT	0
556712	556695	20054A	PARTICIPANT	\N	PRESENT	0
556713	555035	19747H	PARTICIPANT	\N	PRESENT	0
556714	555035	17023S	PARTICIPANT	\N	PRESENT	0
556726	555035	19489J	PARTICIPANT	\N	PRESENT	0
556727	555035	19671E	PARTICIPANT	\N	PRESENT	0
556728	555035	20060X	PARTICIPANT	\N	PRESENT	0
556729	555035	19563B	PARTICIPANT	\N	PRESENT	0
556743	555342	20022R	PARTICIPANT	\N	PRESENT	1
556732	555035	19663E	PARTICIPANT	\N	PRESENT	0
556742	555342	19741B	PARTICIPANT	\N	PRESENT	1
556744	555342	11053K	PARTICIPANT	\N	PRESENT	1
556745	555342	19545Y	PARTICIPANT	\N	PRESENT	1
556746	555342	14327T	PARTICIPANT	\N	PRESENT	1
556747	555342	11110B	PARTICIPANT	\N	PRESENT	1
556748	555342	14121F	PARTICIPANT	\N	PRESENT	1
556749	555342	99004R	PARTICIPANT	\N	PRESENT	1
556750	555342	19711U	PARTICIPANT	\N	PRESENT	1
556751	555342	08010L	PARTICIPANT	\N	PRESENT	1
556752	555342	12016W	PARTICIPANT	\N	PRESENT	1
556753	555342	20050V	PARTICIPANT	\N	PRESENT	1
556754	555342	14173T	PARTICIPANT	\N	PRESENT	1
556755	555035	01060R	PARTICIPANT	\N	PRESENT	0
556756	555035	19507S	PARTICIPANT	\N	PRESENT	0
556978	555036	99004R	PARTICIPANT	\N	PRESENT	0
556979	555036	11031D	PARTICIPANT	\N	PRESENT	0
556981	556980	19701S	PARTICIPANT	\N	PRESENT	0
556983	555036	20076G	PARTICIPANT	\N	PRESENT	0
556984	555036	19762G	PARTICIPANT	\N	PRESENT	0
556985	555036	14357A	PARTICIPANT	\N	PRESENT	0
556987	555036	20152B	PARTICIPANT	\N	PRESENT	0
556988	555036	19507S	PARTICIPANT	\N	PRESENT	0
556990	555036	20066E	PARTICIPANT	\N	PRESENT	0
556991	555036	19725B	PARTICIPANT	\N	PRESENT	0
556992	555036	14331P	PARTICIPANT	\N	PRESENT	0
556993	555036	14121F	PARTICIPANT	\N	PRESENT	0
556994	555036	14207L	PARTICIPANT	\N	PRESENT	0
556995	555036	20120S	PARTICIPANT	\N	PRESENT	0
556996	555036	19681G	PARTICIPANT	\N	PRESENT	0
556997	555036	04057K	PARTICIPANT	\N	PRESENT	0
556998	555036	19479G	PARTICIPANT	\N	PRESENT	0
556999	555036	19441R	PARTICIPANT	\N	PRESENT	0
557002	555036	20100N	PARTICIPANT	\N	PRESENT	0
557003	555036	14195A	PARTICIPANT	\N	PRESENT	0
557004	555036	14055N	PARTICIPANT	\N	PRESENT	0
557005	555036	14089Y	PARTICIPANT	\N	PRESENT	0
557006	555036	20180F	PARTICIPANT	\N	PRESENT	0
557007	555036	19766L	PARTICIPANT	\N	PRESENT	0
557008	555036	20026V	PARTICIPANT	\N	PRESENT	0
557009	555036	11026G	PARTICIPANT	\N	PRESENT	0
557010	555036	19581D	PARTICIPANT	\N	PRESENT	0
557011	555036	08056B	PARTICIPANT	\N	PRESENT	0
557012	555036	19553Y	PARTICIPANT	\N	PRESENT	0
557013	555036	20094J	PARTICIPANT	\N	PRESENT	0
557014	555036	97011G	PARTICIPANT	\N	PRESENT	0
542769	539554	20022R	PARTICIPANT	\N	PRESENT	0
542770	539554	11045K	PARTICIPANT	\N	PRESENT	0
542771	539554	11027H	PARTICIPANT	\N	PRESENT	0
542772	539554	19747H	PARTICIPANT	\N	PRESENT	0
542773	539554	19347U	PARTICIPANT	\N	PRESENT	0
542780	539554	05012A	PARTICIPANT	\N	PRESENT	0
542781	539554	04033B	PARTICIPANT	\N	PRESENT	0
542782	539554	08034U	PARTICIPANT	\N	PRESENT	0
542783	539554	14259Y	PARTICIPANT	\N	PRESENT	0
542784	539554	11031D	PARTICIPANT	\N	PRESENT	0
542785	539554	20126Y	PARTICIPANT	\N	PRESENT	0
542786	539554	19611R	PARTICIPANT	\N	PRESENT	0
542787	539554	11012A	PARTICIPANT	\N	PRESENT	0
542788	539554	17023S	PARTICIPANT	\N	PRESENT	0
542789	539554	19749K	PARTICIPANT	\N	PRESENT	0
542790	539554	19467C	PARTICIPANT	\N	PRESENT	0
542791	539554	01048V	PARTICIPANT	\N	PRESENT	0
542792	539554	14055N	PARTICIPANT	\N	PRESENT	0
542793	539554	11072N	PARTICIPANT	\N	PRESENT	0
542794	539554	12041X	PARTICIPANT	\N	PRESENT	0
542795	539554	14179A	PARTICIPANT	\N	PRESENT	0
542802	539554	20102Q	PARTICIPANT	\N	PRESENT	0
542803	539554	19333N	PARTICIPANT	\N	PRESENT	0
542804	539554	17367Q	PARTICIPANT	\N	PRESENT	0
542805	539554	20096L	PARTICIPANT	\N	PRESENT	0
542806	539554	14083S	PARTICIPANT	\N	PRESENT	0
542807	539554	19762G	PARTICIPANT	\N	PRESENT	0
542810	539554	19715Y	PARTICIPANT	\N	PRESENT	0
542811	539554	19719D	PARTICIPANT	\N	PRESENT	0
542817	539554	19295A	PARTICIPANT	\N	PRESENT	0
542818	539554	11065P	PARTICIPANT	\N	PRESENT	0
542819	539554	11077T	PARTICIPANT	\N	PRESENT	0
542820	539554	11056N	PARTICIPANT	\N	PRESENT	0
542840	539554	20092G	PARTICIPANT	\N	PRESENT	0
542841	539554	95063L	PARTICIPANT	\N	PRESENT	0
542842	539554	11085T	PARTICIPANT	\N	PRESENT	0
542845	539554	19399H	PARTICIPANT	\N	PRESENT	0
542846	539554	19503N	PARTICIPANT	\N	PRESENT	0
542847	539554	19701S	PARTICIPANT	\N	PRESENT	0
545469	545466	17779H	PARTICIPANT	\N	PRESENT	0
545470	545466	20060X	PARTICIPANT	\N	PRESENT	0
545471	545466	11067R	PARTICIPANT	\N	PRESENT	0
545472	545466	20052X	PARTICIPANT	\N	PRESENT	0
545473	545467	17779H	PARTICIPANT	\N	PRESENT	0
545474	545467	11067R	PARTICIPANT	\N	PRESENT	0
545475	545468	17779H	PARTICIPANT	\N	PRESENT	0
545476	545468	14123H	PARTICIPANT	\N	PRESENT	0
554896	554895	19735D	PARTICIPANT	\N	PRESENT	1
554897	550939	19735D	PARTICIPANT	\N	PRESENT	1
554898	550939	20180F	PARTICIPANT	\N	PRESENT	1
554963	554962	11048N	PARTICIPANT	\N	PRESENT	0
554965	554964	11048N	PARTICIPANT	\N	PRESENT	0
554974	554972	11048N	PARTICIPANT	\N	PRESENT	0
555014	554944	19399H	PARTICIPANT	\N	PRESENT	1
555015	554943	19399H	PARTICIPANT	\N	PRESENT	1
555016	554942	19399H	PARTICIPANT	\N	PRESENT	1
555017	554937	19693L	PARTICIPANT	\N	PRESENT	1
555018	554937	19399H	PARTICIPANT	\N	PRESENT	1
555019	554938	19399H	PARTICIPANT	\N	PRESENT	1
555020	554939	19693L	PARTICIPANT	\N	PRESENT	1
555021	554939	19399H	PARTICIPANT	\N	PRESENT	1
555022	554940	19693L	PARTICIPANT	\N	PRESENT	1
555023	554940	19399H	PARTICIPANT	\N	PRESENT	1
555024	554941	19693L	PARTICIPANT	\N	PRESENT	0
555025	554941	19399H	PARTICIPANT	\N	PRESENT	0
555029	550937	19735D	PARTICIPANT	\N	PRESENT	1
555030	550938	19735D	PARTICIPANT	\N	PRESENT	1
555084	555082	19826F	PARTICIPANT	\N	PRESENT	0
555085	555083	19826F	PARTICIPANT	\N	PRESENT	0
555087	555086	19826F	PARTICIPANT	\N	PRESENT	0
555089	555088	19826F	PARTICIPANT	\N	PRESENT	0
555090	555088	19820Y	PARTICIPANT	\N	PRESENT	0
555091	555088	14219Q	PARTICIPANT	\N	PRESENT	0
555093	555092	19826F	PARTICIPANT	\N	PRESENT	0
555097	555096	19826F	PARTICIPANT	\N	PRESENT	0
555099	555098	19826F	PARTICIPANT	\N	PRESENT	0
555100	555098	18083K	PARTICIPANT	\N	PRESENT	0
555102	555101	19826F	PARTICIPANT	\N	PRESENT	0
556456	555351	14327T	PARTICIPANT	\N	EXCUSE	0
556457	555351	19826F	PARTICIPANT	\N	EXCUSE	0
556459	556458	20094J	PARTICIPANT	\N	PRESENT	0
556460	556458	19575F	PARTICIPANT	\N	PRESENT	0
556461	556458	19549D	PARTICIPANT	\N	PRESENT	0
556462	556458	20018V	PARTICIPANT	\N	PRESENT	0
556463	556458	14189C	PARTICIPANT	\N	PRESENT	0
556464	556458	19637C	PARTICIPANT	\N	PRESENT	0
556465	556458	19689Q	PARTICIPANT	\N	PRESENT	0
556466	556458	14195A	PARTICIPANT	\N	PRESENT	0
556467	556458	20110Q	PARTICIPANT	\N	PRESENT	0
556469	556468	14205J	PARTICIPANT	\N	PRESENT	0
556470	556468	20076G	PARTICIPANT	\N	PRESENT	0
556471	556468	14195A	PARTICIPANT	\N	PRESENT	0
556472	556468	20128B	PARTICIPANT	\N	PRESENT	0
556473	556468	14097Y	PARTICIPANT	\N	PRESENT	0
556474	556468	11099A	PARTICIPANT	\N	PRESENT	0
556475	556468	14059S	PARTICIPANT	\N	PRESENT	0
556476	556468	20028X	PARTICIPANT	\N	PRESENT	0
556477	556468	14169X	PARTICIPANT	\N	PRESENT	0
556478	556468	20082E	PARTICIPANT	\N	PRESENT	0
556479	556468	11097X	PARTICIPANT	\N	PRESENT	0
556480	556468	04045F	PARTICIPANT	\N	PRESENT	0
556481	556468	19762G	PARTICIPANT	\N	PRESENT	0
556482	556468	19713W	PARTICIPANT	\N	PRESENT	0
557199	555858	20100N	PARTICIPANT	\N	PRESENT	0
558282	558281	14042U	PARTICIPANT	\N	PRESENT	0
558283	558281	19591F	PARTICIPANT	\N	PRESENT	0
558284	558281	20130U	PARTICIPANT	\N	PRESENT	0
558293	557729	14133K	PARTICIPANT	\N	PRESENT	0
558294	557729	20042V	PARTICIPANT	\N	PRESENT	0
558295	557729	14105F	PARTICIPANT	\N	PRESENT	0
558296	557729	14255U	PARTICIPANT	\N	PRESENT	1
558297	557729	04042C	PRESIDENT	0	PRESENT	0
558298	557729	12028B	PARTICIPANT	\N	PRESENT	0
558299	557729	11027H	PARTICIPANT	\N	PRESENT	0
558300	557729	14249W	PARTICIPANT	\N	PRESENT	0
558301	557729	17023S	PARTICIPANT	\N	PRESENT	0
558302	557729	97011G	PARTICIPANT	\N	PRESENT	0
558303	557729	19347U	PARTICIPANT	\N	PRESENT	0
558304	557729	11083R	PARTICIPANT	\N	PRESENT	1
558305	557729	20128B	PARTICIPANT	\N	PRESENT	1
558306	557729	14097Y	PARTICIPANT	\N	PRESENT	0
558307	557729	19583F	PARTICIPANT	\N	PRESENT	0
558308	557729	19709B	PARTICIPANT	\N	PRESENT	0
558309	557729	16685X	PARTICIPANT	\N	PRESENT	0
558310	557729	14059S	PARTICIPANT	\N	PRESENT	0
558311	557729	14193X	PARTICIPANT	\N	PRESENT	0
558312	557729	19319Q	PARTICIPANT	\N	PRESENT	1
558313	557729	19443T	PARTICIPANT	\N	PRESENT	0
558314	557729	11054L	PARTICIPANT	\N	PRESENT	0
558315	557729	19421M	PARTICIPANT	\N	PRESENT	0
558316	557729	01058X	PARTICIPANT	\N	PRESENT	1
558317	557729	19669L	PARTICIPANT	\N	PRESENT	1
558318	557729	01062T	PARTICIPANT	\N	PRESENT	0
558319	557729	11041F	PARTICIPANT	\N	PRESENT	0
558320	557729	11066Q	PARTICIPANT	\N	PRESENT	1
558321	557729	04034C	PARTICIPANT	\N	PRESENT	0
558560	557688	19563B	PARTICIPANT	\N	PRESENT	0
558561	557688	14073Q	PARTICIPANT	\N	PRESENT	0
558563	558562	19447X	PARTICIPANT	\N	PRESENT	0
558564	557303	14331P	PARTICIPANT	\N	PRESENT	0
558565	557303	19647E	PARTICIPANT	\N	PRESENT	0
558566	557303	20116W	PARTICIPANT	\N	PRESENT	0
558567	557688	19383Y	PARTICIPANT	\N	PRESENT	0
558578	558577	08009T	PARTICIPANT	\N	PRESENT	0
558579	558577	14169X	PARTICIPANT	\N	PRESENT	0
558580	558577	20118Y	PARTICIPANT	\N	PRESENT	0
558581	558577	19739H	PARTICIPANT	\N	PRESENT	0
558582	558577	19713W	PARTICIPANT	\N	PRESENT	0
558583	558577	10015M	PARTICIPANT	\N	PRESENT	0
558584	558577	20084G	PARTICIPANT	\N	PRESENT	0
558586	558585	04033B	PARTICIPANT	\N	PRESENT	0
558587	558585	04035D	PARTICIPANT	\N	PRESENT	0
558588	558585	19713W	PARTICIPANT	\N	PRESENT	0
558589	558585	20118Y	PARTICIPANT	\N	PRESENT	0
558590	558585	20056C	PARTICIPANT	\N	PRESENT	0
558591	558585	19447X	PARTICIPANT	\N	PRESENT	0
558592	558585	19333N	PARTICIPANT	\N	PRESENT	0
558593	558585	19367Y	PARTICIPANT	\N	PRESENT	0
558594	558585	14041T	PARTICIPANT	\N	PRESENT	0
558595	558585	19515S	PARTICIPANT	\N	PRESENT	0
558596	558585	14030Q	PARTICIPANT	\N	PRESENT	0
564624	564335	20140W	PARTICIPANT	\N	PRESENT	0
564625	564335	11097X	PARTICIPANT	\N	PRESENT	0
564626	564252	19383Y	PARTICIPANT	\N	PRESENT	0
564627	564252	14187A	PARTICIPANT	\N	PRESENT	0
564628	564252	19507S	PARTICIPANT	\N	PRESENT	0
564629	564335	19699S	PARTICIPANT	\N	PRESENT	0
564630	564335	14026U	PARTICIPANT	\N	PRESENT	0
564631	564252	19413M	PARTICIPANT	\N	PRESENT	1
564632	564335	19739H	PARTICIPANT	\N	PRESENT	0
564633	564335	20052X	PARTICIPANT	\N	PRESENT	0
564634	564335	19760E	PARTICIPANT	\N	PRESENT	0
564635	564335	20046A	PARTICIPANT	\N	PRESENT	0
564636	564335	14071N	PARTICIPANT	\N	PRESENT	0
564637	564335	19798U	PARTICIPANT	\N	PRESENT	0
564638	564335	14031R	PARTICIPANT	\N	PRESENT	0
564639	564335	01024M	PARTICIPANT	\N	PRESENT	0
564640	564335	14179A	PARTICIPANT	\N	PRESENT	0
564641	564335	19593H	PARTICIPANT	\N	PRESENT	0
564642	564335	14083S	PARTICIPANT	\N	PRESENT	0
564643	564335	14147R	PARTICIPANT	\N	PRESENT	0
564644	564335	20102Q	PARTICIPANT	\N	PRESENT	0
564645	564335	19565D	PARTICIPANT	\N	PRESENT	0
564646	564335	19387D	PARTICIPANT	\N	PRESENT	0
564647	564335	20028X	PARTICIPANT	\N	PRESENT	0
564648	564335	01048V	PARTICIPANT	\N	PRESENT	0
564651	564335	14121F	PARTICIPANT	\N	PRESENT	0
564652	564335	14219Q	PARTICIPANT	\N	PRESENT	0
564653	564335	19711U	PARTICIPANT	\N	PRESENT	0
564654	564335	14030Q	PARTICIPANT	\N	PRESENT	0
564655	564335	14217N	PARTICIPANT	\N	PRESENT	0
564656	564335	19533U	PARTICIPANT	\N	PRESENT	0
564657	564335	20038A	PARTICIPANT	\N	PRESENT	0
564658	564335	19467C	PARTICIPANT	\N	PRESENT	0
564659	564335	07004J	PARTICIPANT	\N	PRESENT	0
564660	564335	19575F	PARTICIPANT	\N	PRESENT	0
564661	564335	14042U	PARTICIPANT	\N	PRESENT	0
564662	564335	20022R	PARTICIPANT	\N	PRESENT	0
564663	564335	20048C	PARTICIPANT	\N	PRESENT	0
564664	564335	19479G	PARTICIPANT	\N	PRESENT	0
564665	564335	19826F	PARTICIPANT	\N	PRESENT	0
564666	564335	19489J	PARTICIPANT	\N	PRESENT	0
564733	564336	04085P	PARTICIPANT	\N	PRESENT	0
564734	564336	20114U	PARTICIPANT	\N	PRESENT	0
564735	564336	19593H	PARTICIPANT	\N	PRESENT	0
564736	564336	14121F	PARTICIPANT	\N	PRESENT	0
564737	564336	19387D	PARTICIPANT	\N	PRESENT	0
564738	564336	04047H	PARTICIPANT	\N	PRESENT	0
564739	564336	20116W	PARTICIPANT	\N	PRESENT	0
564740	564336	19479G	PARTICIPANT	\N	PRESENT	0
564741	564336	14030Q	PARTICIPANT	\N	PRESENT	0
564742	564336	19745F	PARTICIPANT	\N	PRESENT	0
564743	564336	14042U	PARTICIPANT	\N	PRESENT	0
564744	564336	14219Q	PARTICIPANT	\N	PRESENT	0
564745	564336	19335Q	PARTICIPANT	\N	PRESENT	0
564746	564336	20042V	PARTICIPANT	\N	PRESENT	0
564747	564336	19826F	PARTICIPANT	\N	PRESENT	0
564748	564336	01024M	PARTICIPANT	\N	PRESENT	0
564749	564336	14327T	PARTICIPANT	\N	PRESENT	0
564750	564336	07004J	PARTICIPANT	\N	PRESENT	0
564751	564336	95063L	PARTICIPANT	\N	PRESENT	0
564752	564336	19347U	PARTICIPANT	\N	PRESENT	0
564753	564336	14217N	PARTICIPANT	\N	PRESENT	0
564754	564336	08010L	PARTICIPANT	\N	PRESENT	0
564755	564336	14215L	PARTICIPANT	\N	PRESENT	0
564756	564336	14329V	PARTICIPANT	\N	PRESENT	0
564757	564336	14026U	PARTICIPANT	\N	PRESENT	0
564758	564336	14179A	PARTICIPANT	\N	PRESENT	0
564759	564336	20124W	PARTICIPANT	\N	PRESENT	0
564760	564336	20020P	PARTICIPANT	\N	PRESENT	0
564761	564336	18083K	PARTICIPANT	\N	PRESENT	0
564762	564336	19711U	PARTICIPANT	\N	PRESENT	0
564763	564336	14031R	PARTICIPANT	\N	PRESENT	0
564764	564336	01048V	PARTICIPANT	\N	PRESENT	0
564765	564336	19798U	PARTICIPANT	\N	PRESENT	0
564766	564336	20180F	PARTICIPANT	\N	PRESENT	0
564767	564336	19467C	PARTICIPANT	\N	PRESENT	0
564768	564336	20038A	PARTICIPANT	\N	PRESENT	0
564769	564336	19760E	PARTICIPANT	\N	PRESENT	0
564770	564336	20044X	PARTICIPANT	\N	PRESENT	0
564771	564336	20140W	PARTICIPANT	\N	PRESENT	0
564772	564336	20046A	PARTICIPANT	\N	PRESENT	0
564773	564336	14109K	PARTICIPANT	\N	PRESENT	0
564774	564336	11033F	PARTICIPANT	\N	PRESENT	0
564775	564336	19565D	PARTICIPANT	\N	PRESENT	0
564776	564336	17367Q	PARTICIPANT	\N	PRESENT	0
564777	564336	20102Q	PARTICIPANT	\N	PRESENT	0
564778	564336	11103C	PARTICIPANT	\N	PRESENT	0
564779	564336	97011G	PARTICIPANT	\N	PRESENT	0
564780	564336	20098N	PARTICIPANT	\N	PRESENT	0
564781	564336	20108W	PARTICIPANT	\N	PRESENT	0
564782	564336	20022R	PARTICIPANT	\N	PRESENT	0
564783	564336	11012A	PARTICIPANT	\N	PRESENT	0
564784	564336	01028R	PARTICIPANT	\N	PRESENT	0
564785	564336	19673G	PARTICIPANT	\N	PRESENT	0
564786	564336	20028X	PARTICIPANT	\N	PRESENT	0
564795	564336	01058X	PARTICIPANT	\N	PRESENT	0
564800	564336	20096L	PARTICIPANT	\N	PRESENT	0
564802	564336	19599P	PARTICIPANT	\N	PRESENT	0
564804	564336	20050V	PARTICIPANT	\N	PRESENT	0
564805	564336	19533U	PARTICIPANT	\N	PRESENT	0
564806	564336	20052X	PARTICIPANT	\N	PRESENT	0
564807	564336	20066E	PARTICIPANT	\N	PRESENT	0
564808	564385	11048N	PARTICIPANT	\N	PRESENT	0
564809	564385	19479G	PARTICIPANT	\N	PRESENT	0
564810	564385	04071H	PARTICIPANT	\N	PRESENT	0
564731	564336	19719D	PARTICIPANT	\N	PRESENT	0
564732	564336	19489J	PARTICIPANT	\N	PRESENT	0
564811	564385	19711U	PARTICIPANT	\N	PRESENT	0
564812	564385	01048V	PARTICIPANT	\N	PRESENT	0
564813	564385	19689Q	PARTICIPANT	\N	PRESENT	0
564814	564385	11053K	PARTICIPANT	\N	PRESENT	0
564815	564385	19667J	PARTICIPANT	\N	PRESENT	0
564816	564385	20044X	PARTICIPANT	\N	PRESENT	0
564817	564385	14083S	PARTICIPANT	\N	PRESENT	0
564818	564385	08009T	PARTICIPANT	\N	PRESENT	0
564819	564385	20070A	PARTICIPANT	\N	PRESENT	0
564820	564385	19349W	PARTICIPANT	\N	PRESENT	0
564821	564385	08010L	PARTICIPANT	\N	PRESENT	0
564822	564385	20116W	PARTICIPANT	\N	PRESENT	0
564823	564385	19335Q	PARTICIPANT	\N	PRESENT	0
564824	564385	20022R	PARTICIPANT	\N	PRESENT	0
564825	564336	20132W	PARTICIPANT	\N	PRESENT	0
564826	564336	14195A	PARTICIPANT	\N	PRESENT	0
564849	564336	14038Y	PARTICIPANT	\N	PRESENT	0
564828	564385	19741B	PARTICIPANT	\N	PRESENT	0
564829	564385	14189C	PARTICIPANT	\N	PRESENT	0
564830	564385	01057W	PARTICIPANT	\N	PRESENT	0
564831	564336	19333N	PARTICIPANT	\N	PRESENT	0
564832	564336	04034C	PARTICIPANT	\N	PRESENT	0
564833	564336	20018V	PARTICIPANT	\N	PRESENT	0
564834	564336	20024T	PARTICIPANT	\N	PRESENT	0
564835	564336	19739H	PARTICIPANT	\N	PRESENT	0
564836	564336	20062A	PARTICIPANT	\N	PRESENT	0
564837	564336	19413M	PARTICIPANT	\N	PRESENT	0
564838	564336	10006L	PARTICIPANT	\N	PRESENT	0
564839	564336	08061X	PARTICIPANT	\N	PRESENT	0
564840	564336	19399H	PARTICIPANT	\N	PRESENT	0
564841	564336	20026V	PARTICIPANT	\N	PRESENT	0
564842	564336	11097X	PARTICIPANT	\N	PRESENT	0
564843	564336	19549D	PARTICIPANT	\N	PRESENT	0
564844	564336	05008E	PARTICIPANT	\N	PRESENT	0
564845	564385	08034U	PARTICIPANT	\N	PRESENT	0
564846	564385	20080C	PARTICIPANT	\N	PRESENT	0
564847	564385	14225N	PRESIDENT	0	PRESENT	0
564848	564336	14251Q	PARTICIPANT	\N	PRESENT	0
564851	564336	99004R	PARTICIPANT	\N	PRESENT	0
564852	564336	04033B	PARTICIPANT	\N	PRESENT	0
564853	564336	19447X	PARTICIPANT	\N	PRESENT	0
564854	564336	20048C	PARTICIPANT	\N	PRESENT	0
564855	564336	14147R	PARTICIPANT	\N	PRESENT	0
564858	564336	19741B	PARTICIPANT	\N	PRESENT	0
564860	564336	11101A	PARTICIPANT	\N	PRESENT	0
564861	564336	08034U	PARTICIPANT	\N	PRESENT	0
564871	564336	14211G	PARTICIPANT	\N	PRESENT	0
564872	564336	19575F	PARTICIPANT	\N	PRESENT	0
564873	564336	01057W	PARTICIPANT	\N	PRESENT	0
564874	564336	14021P	PARTICIPANT	\N	PRESENT	0
564875	564336	19349W	PARTICIPANT	\N	PRESENT	0
564876	564336	19367Y	PARTICIPANT	\N	PRESENT	0
564877	564336	14151M	PARTICIPANT	\N	PRESENT	0
564878	564336	11048N	PARTICIPANT	\N	PRESENT	0
541655	539550	01062T	PARTICIPANT	\N	PRESENT	0
541674	539550	14107H	PARTICIPANT	\N	PRESENT	0
541900	539551	11045K	PARTICIPANT	\N	PRESENT	0
541915	539551	08060W	PARTICIPANT	\N	PRESENT	0
541916	539551	19629C	PARTICIPANT	\N	PRESENT	0
541917	539551	14107H	PARTICIPANT	\N	PRESENT	0
541918	539551	19479G	PARTICIPANT	\N	PRESENT	0
541919	539551	20108W	PARTICIPANT	\N	PRESENT	0
541920	539551	20062A	PARTICIPANT	\N	PRESENT	0
541921	539551	20116W	PARTICIPANT	\N	PRESENT	0
541922	539551	07029T	PARTICIPANT	\N	PRESENT	0
541923	539551	20172F	PARTICIPANT	\N	PRESENT	0
541924	539551	19533U	PARTICIPANT	\N	PRESENT	0
541925	539551	19691J	PARTICIPANT	\N	PRESENT	0
541926	539551	01024M	PARTICIPANT	\N	PRESENT	0
541927	539551	14042U	PARTICIPANT	\N	PRESENT	0
541928	539551	19820Y	PARTICIPANT	\N	PRESENT	0
541929	539551	19725B	PARTICIPANT	\N	PRESENT	0
541930	539551	19515S	PARTICIPANT	\N	PRESENT	0
541931	539551	20076G	PARTICIPANT	\N	PRESENT	0
541932	539551	97011G	PARTICIPANT	\N	PRESENT	0
541933	539551	19681G	PARTICIPANT	\N	PRESENT	0
541934	539551	01062T	PARTICIPANT	\N	PRESENT	0
541939	539551	11027H	PARTICIPANT	\N	PRESENT	0
541946	539551	19527W	PARTICIPANT	\N	PRESENT	0
541947	539551	95063L	PARTICIPANT	\N	PRESENT	0
541948	539551	14179A	PARTICIPANT	\N	PRESENT	0
541949	539551	04047H	PARTICIPANT	\N	PRESENT	0
541951	539551	14267Y	PARTICIPANT	\N	PRESENT	0
541952	539551	14111D	PARTICIPANT	\N	PRESENT	0
541953	539551	19581D	PARTICIPANT	\N	PRESENT	0
541954	539551	14223L	PARTICIPANT	\N	PRESENT	0
541955	539551	20034V	PARTICIPANT	\N	PRESENT	0
541956	539551	19447X	PARTICIPANT	\N	PRESENT	0
542070	539551	08034U	PARTICIPANT	\N	PRESENT	0
541958	539551	11101A	PARTICIPANT	\N	PRESENT	0
541959	539551	19415P	PARTICIPANT	\N	PRESENT	0
541960	539551	20110Q	PARTICIPANT	\N	PRESENT	0
541961	539551	11033F	PARTICIPANT	\N	PRESENT	0
541962	539551	14151M	PARTICIPANT	\N	PRESENT	0
541963	539551	14097Y	PARTICIPANT	\N	PRESENT	0
541964	539551	11067R	PARTICIPANT	\N	PRESENT	0
541965	539551	04043D	PARTICIPANT	\N	PRESENT	0
541966	539551	14217N	PARTICIPANT	\N	PRESENT	0
541967	539551	11031D	PARTICIPANT	\N	PRESENT	0
541968	539551	11056N	PARTICIPANT	\N	PRESENT	0
541969	539551	04085P	PARTICIPANT	\N	PRESENT	0
541970	539551	20102Q	PARTICIPANT	\N	PRESENT	0
541971	539551	04008A	PARTICIPANT	\N	PRESENT	0
541972	539551	14073Q	PARTICIPANT	\N	PRESENT	0
541973	539551	14147R	PARTICIPANT	\N	PRESENT	0
541974	539551	20180F	PARTICIPANT	\N	PRESENT	0
541975	539551	20136B	PARTICIPANT	\N	PRESENT	0
541976	539551	19747H	PARTICIPANT	\N	PRESENT	0
541977	539551	20138D	PARTICIPANT	\N	PRESENT	0
541978	539551	01048V	PARTICIPANT	\N	PRESENT	0
541982	539551	18193Q	PARTICIPANT	\N	PRESENT	0
541983	539551	04057K	PARTICIPANT	\N	PRESENT	0
541985	539551	20044X	PARTICIPANT	\N	PRESENT	0
541987	539551	20022R	PARTICIPANT	\N	PRESENT	0
541989	539551	20048C	PARTICIPANT	\N	PRESENT	0
541990	539551	14071N	PARTICIPANT	\N	PRESENT	0
541991	539551	20080C	PARTICIPANT	\N	PRESENT	0
541992	539551	14215L	PARTICIPANT	\N	PRESENT	0
541993	539551	17737W	PARTICIPANT	\N	PRESENT	0
541995	539551	19741B	PARTICIPANT	\N	PRESENT	0
541996	539551	14001X	PARTICIPANT	\N	PRESENT	0
541997	539551	20124W	PARTICIPANT	\N	PRESENT	0
542001	539551	19467C	PARTICIPANT	\N	PRESENT	0
542003	539551	17367Q	PARTICIPANT	\N	PRESENT	0
542004	539551	10015M	PARTICIPANT	\N	PRESENT	0
542005	539551	19673G	PARTICIPANT	\N	PRESENT	0
542006	539551	14031R	PARTICIPANT	\N	PRESENT	0
542007	539551	08061X	PARTICIPANT	\N	PRESENT	0
542008	539551	19687N	PARTICIPANT	\N	PRESENT	0
542009	539551	17779H	PARTICIPANT	\N	PRESENT	0
542014	539551	19729F	PARTICIPANT	\N	PRESENT	0
542025	539551	14213J	PARTICIPANT	\N	PRESENT	0
542026	539551	20090E	PARTICIPANT	\N	PRESENT	0
542027	539551	20024T	PARTICIPANT	\N	PRESENT	0
542028	539551	14069U	PARTICIPANT	\N	PRESENT	0
542029	539551	20056C	PARTICIPANT	\N	PRESENT	0
542030	539551	19651A	PARTICIPANT	\N	PRESENT	0
542031	539551	11072N	PARTICIPANT	\N	PRESENT	0
542032	539551	11097X	PARTICIPANT	\N	PRESENT	0
542048	539551	19369B	PARTICIPANT	\N	PRESENT	0
542051	539551	14083S	PARTICIPANT	\N	PRESENT	0
542054	539551	14231L	PARTICIPANT	\N	PRESENT	0
542056	539551	19749K	PARTICIPANT	\N	PRESENT	0
542057	539551	19703U	PARTICIPANT	\N	PRESENT	0
542058	539551	19333N	PARTICIPANT	\N	PRESENT	0
542059	539551	11070L	PARTICIPANT	\N	PRESENT	0
542060	539551	14053L	PARTICIPANT	\N	PRESENT	0
542061	539551	14211G	PARTICIPANT	\N	PRESENT	0
542062	539551	14225N	PARTICIPANT	\N	PRESENT	0
542063	539551	19826F	PARTICIPANT	\N	PRESENT	0
542064	539551	11053K	PARTICIPANT	\N	PRESENT	0
542065	539551	20036X	PARTICIPANT	\N	PRESENT	0
542066	539551	14195A	PARTICIPANT	\N	PRESENT	0
542067	539551	19543W	PARTICIPANT	\N	PRESENT	0
542068	539551	18083K	PARTICIPANT	\N	PRESENT	0
542069	539551	14187A	PARTICIPANT	\N	PRESENT	0
542071	539551	08010L	PARTICIPANT	\N	PRESENT	0
542072	539551	19649G	PARTICIPANT	\N	PRESENT	0
542073	539551	19599P	PARTICIPANT	\N	PRESENT	0
542074	539551	11012A	PARTICIPANT	\N	PRESENT	0
542075	539551	20126Y	PARTICIPANT	\N	PRESENT	0
542076	539551	20032T	PARTICIPANT	\N	PRESENT	0
542077	539551	20098N	PARTICIPANT	\N	PRESENT	0
542078	539551	14205J	PARTICIPANT	\N	PRESENT	0
542079	539551	19507S	PARTICIPANT	\N	PRESENT	0
542080	539551	20130U	PARTICIPANT	\N	PRESENT	0
542081	539551	14030Q	PARTICIPANT	\N	PRESENT	0
542082	539551	20114U	PARTICIPANT	\N	PRESENT	0
542083	539551	20042V	PARTICIPANT	\N	PRESENT	0
542084	539551	14169X	PARTICIPANT	\N	PRESENT	0
542085	539551	19413M	PARTICIPANT	\N	PRESENT	0
542086	539551	20082E	PARTICIPANT	\N	PRESENT	0
542087	539551	19399H	PARTICIPANT	\N	PRESENT	0
542088	539551	14109K	PARTICIPANT	\N	PRESENT	0
542089	539551	14251Q	PARTICIPANT	\N	PRESENT	0
542101	539551	19693L	PARTICIPANT	\N	PRESENT	0
542118	539551	19441R	PARTICIPANT	\N	PRESENT	0
542119	539551	20092G	PARTICIPANT	\N	PRESENT	0
542136	539551	20100N	PARTICIPANT	\N	PRESENT	0
542137	539551	14055N	PARTICIPANT	\N	PRESENT	0
542159	539551	11048N	PARTICIPANT	\N	PRESENT	0
542246	541389	19543W	PARTICIPANT	\N	PRESENT	0
542247	541389	14215L	PARTICIPANT	\N	PRESENT	0
542248	541389	19749K	PARTICIPANT	\N	PRESENT	0
542249	541389	04047H	PRESIDENT	0	PRESENT	0
542250	541389	19673G	PARTICIPANT	\N	PRESENT	0
542251	541389	19447X	PARTICIPANT	\N	PRESENT	0
542252	541389	05008E	PARTICIPANT	\N	PRESENT	0
542253	541389	17737W	PARTICIPANT	\N	PRESENT	0
542254	541389	19649G	PARTICIPANT	\N	PRESENT	0
542255	541389	01028R	PARTICIPANT	\N	PRESENT	0
542256	541389	11072N	PARTICIPANT	\N	PRESENT	0
542257	541389	14231L	PARTICIPANT	\N	PRESENT	0
542258	541389	07004J	PARTICIPANT	\N	PRESENT	0
542259	541389	10015M	PARTICIPANT	\N	PRESENT	0
542260	541389	14179A	PARTICIPANT	\N	PRESENT	0
542261	541389	14089Y	PARTICIPANT	\N	PRESENT	0
542262	541389	20114U	PARTICIPANT	\N	PRESENT	0
542263	539552	11070L	PARTICIPANT	\N	PRESENT	0
542264	539552	19725B	PARTICIPANT	\N	PRESENT	0
542265	539552	14151M	PARTICIPANT	\N	PRESENT	0
542266	539552	14097Y	PARTICIPANT	\N	PRESENT	0
542267	539552	11067R	PARTICIPANT	\N	PRESENT	0
542268	539552	20114U	PARTICIPANT	\N	PRESENT	0
542269	539552	19503N	PARTICIPANT	\N	PRESENT	0
542270	539552	19649G	PARTICIPANT	\N	PRESENT	0
542271	539552	19413M	PARTICIPANT	\N	PRESENT	0
542272	539552	19629C	PARTICIPANT	\N	PRESENT	0
542273	539552	04047H	PARTICIPANT	\N	PRESENT	0
542274	539552	14179A	PARTICIPANT	\N	PRESENT	0
542275	539552	19689Q	PARTICIPANT	\N	PRESENT	0
542276	539552	11072N	PARTICIPANT	\N	PRESENT	0
542277	539552	14107H	PARTICIPANT	\N	PRESENT	0
542278	539552	14195A	PARTICIPANT	\N	PRESENT	0
542279	539552	11053K	PARTICIPANT	\N	PRESENT	0
557015	556980	14031R	PARTICIPANT	\N	PRESENT	0
557016	556980	20038A	PARTICIPANT	\N	PRESENT	0
557017	556980	20076G	PARTICIPANT	\N	PRESENT	0
557018	556980	19820Y	PARTICIPANT	\N	PRESENT	0
557019	556980	19251M	PARTICIPANT	\N	PRESENT	0
557020	556980	20046A	PARTICIPANT	\N	PRESENT	0
557021	556980	19599P	PARTICIPANT	\N	PRESENT	0
557022	556980	20102Q	PARTICIPANT	\N	PRESENT	0
557023	556980	17229F	PARTICIPANT	\N	PRESENT	0
557024	556980	14237S	PARTICIPANT	\N	PRESENT	0
557025	556980	20068G	PARTICIPANT	\N	PRESENT	0
557026	556980	19681G	PARTICIPANT	\N	PRESENT	0
557027	556980	20096L	PARTICIPANT	\N	PRESENT	0
557028	555036	14073Q	PARTICIPANT	\N	PRESENT	0
557029	555036	19563B	PARTICIPANT	\N	PRESENT	0
557030	555036	10006L	PARTICIPANT	\N	PRESENT	0
557031	555036	14189C	PARTICIPANT	\N	PRESENT	0
557032	555036	14026U	PARTICIPANT	\N	PRESENT	0
557033	555036	20128B	PARTICIPANT	\N	PRESENT	0
557034	555036	14042U	PARTICIPANT	\N	PRESENT	0
557035	555036	19749K	PARTICIPANT	\N	PRESENT	0
557036	555036	19415P	PARTICIPANT	\N	PRESENT	0
557037	555036	14097Y	PARTICIPANT	\N	PRESENT	0
557038	556980	19333N	PARTICIPANT	\N	PRESENT	0
557039	556980	19549D	PARTICIPANT	\N	PRESENT	0
557040	556980	14219Q	PARTICIPANT	\N	PRESENT	0
557041	556980	19826F	PARTICIPANT	\N	PRESENT	0
557042	556980	20020P	PARTICIPANT	\N	PRESENT	0
557043	556980	11065P	PARTICIPANT	\N	PRESENT	0
557044	556980	20120S	PARTICIPANT	\N	PRESENT	0
557045	556980	20024T	PARTICIPANT	\N	EXCUSE	0
557046	556980	14221J	PARTICIPANT	\N	PRESENT	0
557047	556980	05012A	PARTICIPANT	\N	PRESENT	0
557048	556980	20118Y	PARTICIPANT	\N	PRESENT	0
557049	556980	20136B	PARTICIPANT	\N	PRESENT	0
557050	556980	19739H	PARTICIPANT	\N	PRESENT	0
557052	556980	08060W	PARTICIPANT	\N	PRESENT	0
557352	553250	19651A	PARTICIPANT	\N	PRESENT	0
557353	553250	11040E	PARTICIPANT	\N	PRESENT	0
557354	553250	20042V	PARTICIPANT	\N	PRESENT	0
557355	553250	14038Y	PARTICIPANT	\N	PRESENT	0
557356	553250	11056N	PARTICIPANT	\N	PRESENT	0
557357	553250	20132W	PARTICIPANT	\N	PRESENT	0
557358	553250	19553Y	PARTICIPANT	\N	PRESENT	0
557359	553250	99004R	PARTICIPANT	\N	PRESENT	0
557360	553250	19711U	PARTICIPANT	\N	PRESENT	0
557361	553250	20050V	PARTICIPANT	\N	PRESENT	0
557362	553250	95063L	PARTICIPANT	\N	PRESENT	0
557363	553250	19479G	PARTICIPANT	\N	PRESENT	0
557700	557699	19515S	PRESIDENT	0	PRESENT	0
557701	557699	14083S	PARTICIPANT	\N	PRESENT	0
557702	557699	14030Q	PARTICIPANT	\N	PRESENT	0
557703	557699	19467C	PARTICIPANT	\N	PRESENT	0
557704	557699	19551W	PARTICIPANT	\N	PRESENT	0
557705	557699	08045X	PARTICIPANT	\N	PRESENT	0
557706	557699	19575F	PARTICIPANT	\N	PRESENT	0
557707	557699	19695N	PARTICIPANT	\N	PRESENT	0
557708	557699	14105F	PARTICIPANT	\N	PRESENT	0
557709	557699	14041T	PARTICIPANT	\N	PRESENT	0
557713	557699	20092G	PARTICIPANT	\N	PRESENT	0
557714	557699	20082E	PARTICIPANT	\N	PRESENT	0
557716	557699	14026U	PARTICIPANT	\N	PRESENT	0
557717	557699	19717B	PARTICIPANT	\N	EXCUSE	0
557718	557699	20060X	PARTICIPANT	\N	EXCUSE	0
557722	557699	14329V	PARTICIPANT	\N	EXCUSE	0
557723	557699	20040T	PARTICIPANT	\N	EXCUSE	0
557724	557699	08015R	PARTICIPANT	\N	EXCUSE	0
557725	557699	19369B	PARTICIPANT	\N	EXCUSE	0
557726	557699	20054A	PARTICIPANT	\N	EXCUSE	0
557823	555345	19643A	PARTICIPANT	\N	PRESENT	1
557824	555345	20082E	PARTICIPANT	\N	PRESENT	1
557825	555345	19693L	PARTICIPANT	\N	PRESENT	1
557826	555345	20142Y	PARTICIPANT	\N	PRESENT	1
557827	555345	19721W	PARTICIPANT	\N	PRESENT	1
557828	555345	19715Y	PARTICIPANT	\N	PRESENT	1
557829	555345	14147R	PARTICIPANT	\N	PRESENT	1
557830	555345	19611R	PARTICIPANT	\N	PRESENT	0
557831	555345	19593H	PRESIDENT	0	PRESENT	0
557832	555345	20132W	PARTICIPANT	\N	PRESENT	0
557833	555345	19735D	PARTICIPANT	\N	EXCUSE	0
557834	555345	19533U	PRESIDENT	1	PRESENT	0
557836	554659	20146D	PARTICIPANT	\N	EXCUSE	0
557868	557867	19667J	PARTICIPANT	\N	PRESENT	0
557869	557867	14083S	PARTICIPANT	\N	PRESENT	0
557870	557867	19701S	PARTICIPANT	\N	PRESENT	0
557871	557867	14255U	PARTICIPANT	\N	PRESENT	0
557872	557867	19693L	PARTICIPANT	\N	PRESENT	0
557873	557867	14179A	PARTICIPANT	\N	PRESENT	0
557874	557867	95063L	PARTICIPANT	\N	PRESENT	0
557875	557867	20064C	PARTICIPANT	\N	PRESENT	0
557877	557876	19667J	PARTICIPANT	\N	PRESENT	0
557878	557876	14255U	PARTICIPANT	\N	PRESENT	0
557879	557876	20064C	PARTICIPANT	\N	PRESENT	0
557880	557876	19701S	PARTICIPANT	\N	PRESENT	0
557881	557876	14179A	PARTICIPANT	\N	PRESENT	0
557882	557876	11026G	PARTICIPANT	\N	PRESENT	0
558261	558260	14187A	PARTICIPANT	\N	PRESENT	0
558262	558260	20090E	PARTICIPANT	\N	PRESENT	0
558263	558259	14187A	PARTICIPANT	\N	PRESENT	0
558285	557975	19954N	PARTICIPANT	\N	PRESENT	1
558286	557975	14053L	PARTICIPANT	\N	PRESENT	1
558287	557975	19725B	PARTICIPANT	\N	PRESENT	1
558291	557975	10015M	PARTICIPANT	\N	PRESENT	1
558289	557975	14179A	PARTICIPANT	\N	PRESENT	1
558290	557975	11072N	PARTICIPANT	\N	PRESENT	1
558292	557975	19749K	PARTICIPANT	\N	PRESENT	1
558323	557975	14231L	PARTICIPANT	\N	EXCUSE	0
558475	558474	20036X	PARTICIPANT	\N	PRESENT	0
558478	558477	19711U	PARTICIPANT	\N	PRESENT	0
558481	558480	19711U	PARTICIPANT	\N	PRESENT	0
558482	558480	11053K	PARTICIPANT	\N	PRESENT	0
558488	558486	19711U	PARTICIPANT	\N	PRESENT	0
558491	558490	19711U	PARTICIPANT	\N	PRESENT	0
558492	558490	20044X	PARTICIPANT	\N	PRESENT	0
558495	558494	08009T	PARTICIPANT	\N	PRESENT	0
558496	558494	20044X	PARTICIPANT	\N	PRESENT	0
558568	557303	20022R	PARTICIPANT	\N	PRESENT	1
558569	557303	19545Y	PARTICIPANT	\N	PRESENT	1
558570	557303	04086Q	PARTICIPANT	\N	PRESENT	1
558571	557303	11110B	PARTICIPANT	\N	PRESENT	1
558572	557303	14121F	PARTICIPANT	\N	PRESENT	1
558573	557303	20126Y	PARTICIPANT	\N	PRESENT	1
558574	557303	01048V	PARTICIPANT	\N	PRESENT	1
558575	557303	19671E	PARTICIPANT	\N	PRESENT	1
558576	557303	14173T	PARTICIPANT	\N	PRESENT	1
558975	556389	11067R	PARTICIPANT	\N	PRESENT	0
558976	556389	04092N	PARTICIPANT	\N	EXCUSE	0
558977	556389	20134Y	PARTICIPANT	\N	PRESENT	0
558979	556389	14083S	PARTICIPANT	\N	PRESENT	0
559013	559012	12041X	PARTICIPANT	\N	PRESENT	0
559033	557089	14331P	PRESIDENT	0	PRESENT	0
559036	557089	14237S	PARTICIPANT	\N	PRESENT	0
559037	557089	11026G	PARTICIPANT	\N	PRESENT	0
559040	557089	08034U	PARTICIPANT	\N	PRESENT	0
559043	557089	19251M	PARTICIPANT	\N	PRESENT	0
559044	557089	19711U	PARTICIPANT	\N	PRESENT	0
559045	557089	11083R	PARTICIPANT	\N	PRESENT	0
559046	557089	14097Y	PARTICIPANT	\N	PRESENT	0
559048	557089	14189C	PARTICIPANT	\N	EXCUSE	0
559050	557089	04070G	PARTICIPANT	\N	EXCUSE	0
559056	557089	14089Y	PARTICIPANT	\N	PRESENT	1
559059	557089	14001X	PARTICIPANT	\N	PRESENT	1
559062	557089	04034C	PARTICIPANT	\N	PRESENT	1
559065	557089	19725B	PARTICIPANT	\N	PRESENT	1
559069	557089	20128B	PARTICIPANT	\N	PRESENT	1
559075	557089	97011G	PARTICIPANT	\N	PRESENT	1
559638	559637	14205J	PARTICIPANT	\N	PRESENT	0
559640	559639	14205J	PARTICIPANT	\N	PRESENT	0
559644	559643	14205J	PARTICIPANT	\N	PRESENT	0
559647	557251	19820Y	PARTICIPANT	\N	PRESENT	1
559983	556324	14193X	PARTICIPANT	\N	EXCUSE	0
560002	556324	01028R	PARTICIPANT	\N	EXCUSE	0
560650	555371	14026U	PARTICIPANT	\N	PRESENT	0
560651	555371	19717B	PARTICIPANT	\N	PRESENT	0
560652	555371	20130U	PARTICIPANT	\N	PRESENT	0
560669	555372	19717B	PARTICIPANT	\N	PRESENT	0
560670	555372	14026U	PARTICIPANT	\N	PRESENT	0
560671	555373	19717B	PARTICIPANT	\N	PRESENT	0
560672	555373	14026U	PARTICIPANT	\N	PRESENT	0
560739	560589	20100N	PARTICIPANT	\N	PRESENT	0
560740	560589	19333N	PARTICIPANT	\N	PRESENT	0
557745	557744	08017T	PARTICIPANT	\N	PRESENT	0
557746	557744	20126Y	PARTICIPANT	\N	PRESENT	0
557811	557810	05008E	PARTICIPANT	\N	PRESENT	0
557812	557810	11053K	PARTICIPANT	\N	PRESENT	0
557813	557810	01028R	PARTICIPANT	\N	PRESENT	0
557837	557835	04085P	PARTICIPANT	\N	PRESENT	0
557838	557835	04047H	PARTICIPANT	\N	PRESENT	0
557839	557835	04042C	PARTICIPANT	\N	PRESENT	0
557840	557835	19719D	PARTICIPANT	\N	PRESENT	0
557841	557835	10006L	PARTICIPANT	\N	PRESENT	0
557842	557835	19347U	PARTICIPANT	\N	PRESENT	0
557843	557835	14026U	PARTICIPANT	\N	PRESENT	0
557844	557835	11048N	PARTICIPANT	\N	PRESENT	0
557845	557835	14021P	PARTICIPANT	\N	PRESENT	0
557846	557835	99004R	PARTICIPANT	\N	PRESENT	0
557847	557835	19611R	PARTICIPANT	\N	PRESENT	0
557848	557835	12041X	PARTICIPANT	\N	PRESENT	0
557849	557835	01043Q	PARTICIPANT	\N	PRESENT	0
557850	557835	14219Q	PARTICIPANT	\N	PRESENT	0
557851	557835	14251Q	PARTICIPANT	\N	PRESENT	0
557852	557835	01060R	PARTICIPANT	\N	PRESENT	0
557853	557835	08061X	PARTICIPANT	\N	PRESENT	0
557854	557835	11090Q	PARTICIPANT	\N	PRESENT	0
557855	557835	14331P	PARTICIPANT	\N	PRESENT	0
557856	557835	14225N	PARTICIPANT	\N	PRESENT	0
557857	557835	04033B	PARTICIPANT	\N	PRESENT	0
557858	557835	11045K	PARTICIPANT	\N	PRESENT	0
557859	557835	01028R	PARTICIPANT	\N	PRESENT	0
557862	557861	14187A	PARTICIPANT	\N	PRESENT	0
558597	558585	10006L	PARTICIPANT	\N	PRESENT	0
558598	558585	19741B	PARTICIPANT	\N	PRESENT	0
558599	558585	14217N	PARTICIPANT	\N	PRESENT	0
558600	558585	20038A	PARTICIPANT	\N	PRESENT	0
558601	558585	14179A	PARTICIPANT	\N	PRESENT	0
558602	558585	14031R	PARTICIPANT	\N	PRESENT	0
558603	558585	19798U	PARTICIPANT	\N	PRESENT	0
558850	557697	14257W	PARTICIPANT	\N	PRESENT	1
558981	557305	20022R	PARTICIPANT	\N	PRESENT	1
558982	557305	11074Q	PARTICIPANT	\N	PRESENT	1
558983	557305	19647E	PARTICIPANT	\N	PRESENT	1
558984	557305	14121F	PARTICIPANT	\N	PRESENT	1
558985	557305	08010L	PARTICIPANT	\N	PRESENT	1
558986	557305	08011M	PARTICIPANT	\N	PRESENT	1
558987	557305	20050V	PARTICIPANT	\N	PRESENT	1
558988	557305	19349W	PARTICIPANT	\N	PRESENT	1
558989	557305	11012A	PARTICIPANT	\N	PRESENT	1
558990	557305	19687N	PARTICIPANT	\N	PRESENT	1
558991	557305	19479G	PARTICIPANT	\N	PRESENT	1
558992	557305	14173T	PARTICIPANT	\N	PRESENT	1
558993	557305	14189C	PARTICIPANT	\N	EXCUSE	0
559009	559008	01057W	PARTICIPANT	\N	PRESENT	0
559673	557251	11031D	PARTICIPANT	\N	PRESENT	0
559674	557251	99004R	PARTICIPANT	\N	PRESENT	0
559675	557251	19447X	PARTICIPANT	\N	PRESENT	0
559687	559686	20116W	PARTICIPANT	\N	PRESENT	0
559688	559686	11080N	PARTICIPANT	\N	PRESENT	0
559689	559686	01057W	PARTICIPANT	\N	PRESENT	0
559690	559686	14121F	PARTICIPANT	\N	PRESENT	0
559691	559686	19711U	PARTICIPANT	\N	PRESENT	0
559692	559686	05012A	PARTICIPANT	\N	PRESENT	0
559693	559686	19687N	PARTICIPANT	\N	PRESENT	0
559695	559694	20116W	PARTICIPANT	\N	PRESENT	0
559696	559694	20042V	PARTICIPANT	\N	PRESENT	0
559697	559694	11080N	PARTICIPANT	\N	PRESENT	0
559698	559694	01057W	PARTICIPANT	\N	PRESENT	0
559699	559694	14121F	PARTICIPANT	\N	PRESENT	0
559700	559694	19711U	PARTICIPANT	\N	PRESENT	0
559701	559694	19335Q	PARTICIPANT	\N	PRESENT	0
559702	559694	05012A	PARTICIPANT	\N	PRESENT	0
559704	559703	20116W	PARTICIPANT	\N	PRESENT	0
559705	559703	11080N	PARTICIPANT	\N	PRESENT	0
559706	559703	01057W	PARTICIPANT	\N	PRESENT	0
559707	559703	14121F	PARTICIPANT	\N	PRESENT	0
559708	559703	19711U	PARTICIPANT	\N	PRESENT	0
559709	559703	19335Q	PARTICIPANT	\N	PRESENT	0
559710	559703	05012A	PARTICIPANT	\N	PRESENT	0
559711	559703	19687N	PARTICIPANT	\N	PRESENT	0
559713	559712	20042V	PARTICIPANT	\N	PRESENT	0
559714	559712	11080N	PARTICIPANT	\N	PRESENT	0
559715	559712	01057W	PARTICIPANT	\N	PRESENT	0
559716	559712	14121F	PARTICIPANT	\N	PRESENT	0
559717	559712	19711U	PARTICIPANT	\N	PRESENT	0
559718	559712	19335Q	PARTICIPANT	\N	PRESENT	0
559723	559722	14041T	PARTICIPANT	\N	PRESENT	0
559725	559724	14041T	PARTICIPANT	\N	PRESENT	0
559731	559730	19367Y	PARTICIPANT	\N	PRESENT	0
559732	559730	19553Y	PARTICIPANT	\N	PRESENT	0
559733	559730	14213J	PARTICIPANT	\N	PRESENT	0
559734	559730	11067R	PARTICIPANT	\N	PRESENT	0
559735	559730	19798U	PARTICIPANT	\N	PRESENT	0
559738	559736	14217N	PARTICIPANT	\N	PRESENT	0
559739	559736	19663E	PARTICIPANT	\N	PRESENT	0
559740	559736	19553Y	PARTICIPANT	\N	PRESENT	0
559741	559737	19663E	PARTICIPANT	\N	PRESENT	0
559742	559737	19553Y	PARTICIPANT	\N	PRESENT	0
559743	559737	11097X	PARTICIPANT	\N	PRESENT	0
559745	559744	19679N	PARTICIPANT	\N	PRESENT	0
559747	559746	19717B	PARTICIPANT	\N	PRESENT	0
559748	559746	19663E	PARTICIPANT	\N	PRESENT	0
559749	559746	14223L	PARTICIPANT	\N	PRESENT	0
559750	559746	19798U	PARTICIPANT	\N	PRESENT	0
559751	559746	11097X	PARTICIPANT	\N	PRESENT	0
559962	555070	19697Q	PARTICIPANT	\N	PRESENT	0
559963	555070	11067R	PARTICIPANT	\N	PRESENT	0
559964	555070	20130U	PARTICIPANT	\N	PRESENT	0
560236	559634	14073Q	PARTICIPANT	\N	EXCUSE	0
560306	560274	14133K	PARTICIPANT	\N	EXCUSE	0
560307	560274	19467C	PARTICIPANT	\N	EXCUSE	0
560308	560274	19762G	PARTICIPANT	\N	EXCUSE	0
560309	560274	19441R	PARTICIPANT	\N	PRESENT	0
560310	560274	19798U	PARTICIPANT	\N	PRESENT	0
560311	560274	14109K	PARTICIPANT	\N	PRESENT	1
560314	560274	19383Y	PRESIDENT	0	PRESENT	0
560313	560274	11099A	PARTICIPANT	\N	PRESENT	0
560315	560274	19719D	PARTICIPANT	\N	PRESENT	0
560330	560274	19637C	PARTICIPANT	\N	EXCUSE	0
560331	560274	20038A	PARTICIPANT	\N	PRESENT	0
560364	560363	07004J	PARTICIPANT	\N	PRESENT	0
560365	560363	19703U	PARTICIPANT	\N	PRESENT	0
560374	560366	07004J	PARTICIPANT	\N	PRESENT	0
560378	558014	20110Q	PARTICIPANT	\N	PRESENT	0
560379	558016	20110Q	PARTICIPANT	\N	PRESENT	0
560382	560381	07004J	PARTICIPANT	\N	PRESENT	0
560383	560381	19703U	PARTICIPANT	\N	PRESENT	0
560384	558014	19703U	PARTICIPANT	\N	PRESENT	0
560385	558016	19703U	PARTICIPANT	\N	PRESENT	0
560392	560391	20110Q	PARTICIPANT	\N	PRESENT	0
560393	560391	19649G	PARTICIPANT	\N	PRESENT	0
560394	560391	19703U	PARTICIPANT	\N	PRESENT	0
560395	560391	19749K	PARTICIPANT	\N	PRESENT	0
560396	560391	07004J	PARTICIPANT	\N	PRESENT	0
560398	560397	07004J	PARTICIPANT	\N	PRESENT	0
560399	560397	19749K	PARTICIPANT	\N	PRESENT	0
560401	560400	07004J	PARTICIPANT	\N	PRESENT	0
560402	560400	20110Q	PARTICIPANT	\N	PRESENT	0
560404	560400	19649G	PARTICIPANT	\N	PRESENT	0
560405	560400	19749K	PARTICIPANT	\N	PRESENT	0
560406	560400	19703U	PARTICIPANT	\N	PRESENT	0
560924	559209	04085P	PARTICIPANT	\N	PRESENT	1
560925	559209	11033F	PARTICIPANT	\N	PRESENT	1
560926	559209	19543W	PARTICIPANT	\N	PRESENT	1
560927	559209	17737W	PARTICIPANT	\N	PRESENT	1
560929	559209	19629C	PARTICIPANT	\N	PRESENT	1
560930	559209	14215L	PARTICIPANT	\N	PRESENT	1
560931	559209	19649G	PARTICIPANT	\N	PRESENT	1
560932	559209	19447X	PARTICIPANT	\N	PRESENT	1
560933	559209	19581D	PARTICIPANT	\N	PRESENT	1
560934	559209	14147R	PARTICIPANT	\N	PRESENT	1
560935	559209	14107H	PARTICIPANT	\N	PRESENT	1
560936	559209	19675J	PARTICIPANT	\N	PRESENT	1
560957	560952	14187A	PARTICIPANT	\N	PRESENT	0
560958	560953	14187A	PARTICIPANT	\N	PRESENT	0
561259	560955	14187A	PARTICIPANT	\N	PRESENT	0
561260	560956	14187A	PARTICIPANT	\N	PRESENT	0
561264	561262	19575F	PARTICIPANT	\N	PRESENT	0
561258	560954	14187A	PARTICIPANT	\N	PRESENT	0
561263	561262	20094J	PARTICIPANT	\N	PRESENT	0
561266	561265	14033T	PARTICIPANT	\N	PRESENT	0
561267	561265	19503N	PARTICIPANT	\N	PRESENT	0
561269	561265	20144B	PARTICIPANT	\N	PRESENT	0
561270	561265	20062A	PARTICIPANT	\N	PRESENT	0
564879	564336	11067R	PARTICIPANT	\N	PRESENT	0
564880	564336	01025N	PARTICIPANT	\N	PRESENT	0
564881	564336	20104S	PARTICIPANT	\N	PRESENT	0
564882	564336	20070A	PARTICIPANT	\N	PRESENT	0
564883	564336	20080C	PARTICIPANT	\N	PRESENT	0
564884	564336	19563B	PARTICIPANT	\N	PRESENT	0
564885	564336	19749K	PARTICIPANT	\N	PRESENT	0
564886	564336	20056C	PARTICIPANT	\N	PRESENT	0
564888	564336	19441R	PARTICIPANT	\N	PRESENT	0
564889	564336	11065P	PARTICIPANT	\N	PRESENT	0
564890	564336	14169X	PARTICIPANT	\N	PRESENT	0
564891	564336	14213J	PARTICIPANT	\N	PRESENT	0
564892	564336	14001X	PARTICIPANT	\N	PRESENT	0
564893	564336	14059S	PARTICIPANT	\N	PRESENT	0
564894	564336	19507S	PARTICIPANT	\N	PRESENT	0
564895	564336	14033T	PARTICIPANT	\N	PRESENT	0
564896	564336	19747H	PARTICIPANT	\N	PRESENT	0
564897	564336	14257W	PARTICIPANT	\N	PRESENT	0
564898	564336	20082E	PARTICIPANT	\N	PRESENT	0
564899	564336	14357A	PARTICIPANT	\N	PRESENT	0
564900	564336	17023S	PARTICIPANT	\N	PRESENT	0
564901	564336	14187A	PARTICIPANT	\N	PRESENT	0
564902	564336	11026G	PARTICIPANT	\N	PRESENT	0
564903	564336	11085T	PARTICIPANT	\N	PRESENT	0
564904	564336	20076G	PARTICIPANT	\N	PRESENT	0
564905	564255	14038Y	PARTICIPANT	\N	PRESENT	0
564906	564255	19383Y	PARTICIPANT	\N	PRESENT	0
564907	564255	19515S	PARTICIPANT	\N	PRESENT	0
564908	564255	14357A	PARTICIPANT	\N	PRESENT	0
564909	564255	19441R	PARTICIPANT	\N	PRESENT	0
564910	564255	19575F	PARTICIPANT	\N	PRESENT	0
564911	564255	19695N	PARTICIPANT	\N	PRESENT	0
564912	564255	11090Q	PRESIDENT	0	PRESENT	0
564913	564255	14257W	PARTICIPANT	\N	PRESENT	0
564914	564255	14329V	PARTICIPANT	\N	PRESENT	0
564915	564255	01025N	PARTICIPANT	\N	PRESENT	0
564916	563261	04070G	PARTICIPANT	\N	PRESENT	0
564917	563261	19533U	PARTICIPANT	\N	PRESENT	0
564918	563261	14229S	PARTICIPANT	\N	PRESENT	0
564919	563261	20098N	PARTICIPANT	\N	PRESENT	0
564920	563261	08017T	PARTICIPANT	\N	PRESENT	1
564923	563261	20124W	PARTICIPANT	\N	PRESENT	1
564924	563261	20026V	PARTICIPANT	\N	PRESENT	0
564925	563261	19593H	PARTICIPANT	\N	PRESENT	0
564926	563261	19527W	PARTICIPANT	\N	PRESENT	0
564927	563261	20132W	PARTICIPANT	\N	PRESENT	0
564928	563261	19643A	PARTICIPANT	\N	PRESENT	0
564929	563261	19651A	PARTICIPANT	\N	PRESENT	1
564931	563261	19611R	PRESIDENT	0	PRESENT	0
564933	563261	20142Y	PARTICIPANT	\N	PRESENT	0
564934	563261	20048C	PARTICIPANT	\N	PRESENT	0
564935	563261	19693L	PARTICIPANT	\N	PRESENT	0
564936	563261	19399H	PARTICIPANT	\N	EXCUSE	0
564937	563261	20152B	PARTICIPANT	\N	PRESENT	0
564938	563261	20052X	PARTICIPANT	\N	PRESENT	0
564939	563261	14030Q	PARTICIPANT	\N	PRESENT	0
564941	563261	20180F	PARTICIPANT	\N	PRESENT	0
564942	563261	04059M	PARTICIPANT	\N	PRESENT	0
564943	563261	19735D	PARTICIPANT	\N	PRESENT	0
564944	563261	11109J	PARTICIPANT	\N	EXCUSE	0
564946	563261	14109K	PARTICIPANT	\N	PRESENT	0
564948	563261	11104D	PARTICIPANT	\N	PRESENT	1
564952	563261	19621T	PARTICIPANT	\N	PRESENT	0
564953	563261	20084G	PARTICIPANT	\N	PRESENT	0
564955	564954	20086J	PARTICIPANT	\N	PRESENT	0
564956	564954	19699S	PARTICIPANT	\N	PRESENT	0
564957	564954	19701S	PARTICIPANT	\N	PRESENT	0
564958	564954	20076G	PARTICIPANT	\N	PRESENT	0
564959	564954	19549D	PARTICIPANT	\N	PRESENT	0
564960	564954	19387D	PARTICIPANT	\N	PRESENT	0
564961	564954	14219Q	PRESIDENT	0	PRESENT	0
564962	564954	19826F	PARTICIPANT	\N	PRESENT	0
564963	564954	20102Q	PARTICIPANT	\N	PRESENT	0
564964	564954	19599P	PARTICIPANT	\N	PRESENT	0
564965	564954	20096L	PARTICIPANT	\N	PRESENT	0
564966	564954	19637C	PARTICIPANT	\N	PRESENT	0
564967	564954	14237S	PARTICIPANT	\N	PRESENT	0
564968	564954	18083K	PARTICIPANT	\N	PRESENT	0
564969	564954	20100N	PARTICIPANT	\N	PRESENT	0
564970	564954	19551W	PARTICIPANT	\N	PRESENT	0
564971	564954	20108W	PARTICIPANT	\N	PRESENT	0
564972	564954	20020P	PARTICIPANT	\N	PRESENT	0
564973	564954	17367Q	PARTICIPANT	\N	PRESENT	0
564974	564954	19681G	PARTICIPANT	\N	PRESENT	0
564975	564954	20024T	PARTICIPANT	\N	PRESENT	0
564976	564954	11065P	PARTICIPANT	\N	PRESENT	0
564977	564954	17637T	PARTICIPANT	\N	PRESENT	0
564978	564954	20136B	PARTICIPANT	\N	PRESENT	0
564979	564954	14031R	PARTICIPANT	\N	PRESENT	0
564980	564954	20038A	PARTICIPANT	\N	PRESENT	0
564981	564954	20140W	PARTICIPANT	\N	PRESENT	0
564982	564954	19251M	PARTICIPANT	\N	PRESENT	0
564983	564954	20046A	PARTICIPANT	\N	PRESENT	0
564984	564954	14033T	PARTICIPANT	\N	PRESENT	0
564985	564954	14169X	PARTICIPANT	\N	PRESENT	0
564986	564954	17229F	PARTICIPANT	\N	PRESENT	0
564987	564954	20068G	PARTICIPANT	\N	PRESENT	0
564988	564954	19739H	PARTICIPANT	\N	PRESENT	0
564989	564954	19745F	PARTICIPANT	\N	PRESENT	0
564990	564954	19619A	PARTICIPANT	\N	PRESENT	0
564991	564954	19333N	PARTICIPANT	\N	EXCUSE	0
564992	564255	20030R	PARTICIPANT	\N	PRESENT	1
564993	564255	19768N	PARTICIPANT	\N	PRESENT	1
564994	564255	14187A	PARTICIPANT	\N	PRESENT	0
564995	564255	04045F	PARTICIPANT	\N	PRESENT	1
564996	564255	20104S	PARTICIPANT	\N	PRESENT	0
564997	564255	19631V	PARTICIPANT	\N	PRESENT	1
564998	564255	20062A	PARTICIPANT	\N	PRESENT	1
564999	564255	19705W	PARTICIPANT	\N	PRESENT	1
565000	564255	19507S	PARTICIPANT	\N	PRESENT	0
565001	564255	19369B	PARTICIPANT	\N	PRESENT	0
565002	564255	19747H	PARTICIPANT	\N	PRESENT	0
565003	564255	20018V	PARTICIPANT	\N	PRESENT	1
565004	564255	19563B	PARTICIPANT	\N	PRESENT	0
565005	564954	19820Y	PARTICIPANT	\N	PRESENT	1
565006	564954	20032T	PARTICIPANT	\N	PRESENT	0
565007	564954	20106U	PARTICIPANT	\N	PRESENT	0
565008	564254	14038Y	PARTICIPANT	\N	PRESENT	0
565009	564254	19383Y	PARTICIPANT	\N	PRESENT	0
565010	564254	20030R	PARTICIPANT	\N	PRESENT	1
565011	564254	19768N	PARTICIPANT	\N	PRESENT	1
565012	564254	19515S	PARTICIPANT	\N	PRESENT	0
565013	564254	14357A	PARTICIPANT	\N	PRESENT	0
565014	564254	14187A	PARTICIPANT	\N	PRESENT	0
565015	564254	19441R	PARTICIPANT	\N	PRESENT	0
565016	564254	19695N	PARTICIPANT	\N	PRESENT	0
565017	564254	11090Q	PRESIDENT	0	PRESENT	0
565018	564254	01025N	PARTICIPANT	\N	PRESENT	0
565019	564254	04045F	PARTICIPANT	\N	PRESENT	1
565020	564254	20104S	PARTICIPANT	\N	PRESENT	0
565021	564254	19631V	PARTICIPANT	\N	PRESENT	1
565022	564254	20062A	PARTICIPANT	\N	PRESENT	1
565023	564254	19705W	PARTICIPANT	\N	PRESENT	1
565024	564254	19507S	PARTICIPANT	\N	PRESENT	0
565025	564254	19575F	PARTICIPANT	\N	PRESENT	0
565026	564254	19369B	PARTICIPANT	\N	PRESENT	0
565027	564254	19747H	PARTICIPANT	\N	PRESENT	0
565028	564254	20018V	PARTICIPANT	\N	PRESENT	1
565029	564254	19563B	PARTICIPANT	\N	PRESENT	0
565030	564254	14257W	PARTICIPANT	\N	PRESENT	0
565031	564254	14329V	PARTICIPANT	\N	PRESENT	0
565032	564954	19503N	PARTICIPANT	\N	PRESENT	0
565033	564954	20118Y	PARTICIPANT	\N	PRESENT	0
565034	564254	19413M	PARTICIPANT	\N	PRESENT	0
565037	564254	19467C	PARTICIPANT	\N	PRESENT	1
565038	564254	20144B	PARTICIPANT	\N	PRESENT	0
565039	564254	14207L	PARTICIPANT	\N	PRESENT	1
565040	564254	20028X	PARTICIPANT	\N	PRESENT	0
565041	564254	20060X	PARTICIPANT	\N	PRESENT	0
565042	564386	11040E	PARTICIPANT	\N	PRESENT	0
565043	564386	20074E	PARTICIPANT	\N	PRESENT	0
542280	539552	20110Q	PARTICIPANT	\N	PRESENT	0
542281	539552	20080C	PARTICIPANT	\N	PRESENT	0
542282	539552	19441R	PARTICIPANT	\N	PRESENT	0
542283	539552	14089Y	PARTICIPANT	\N	PRESENT	0
542284	539552	20100N	PARTICIPANT	\N	PRESENT	0
542285	539552	07004J	PARTICIPANT	\N	PRESENT	0
542286	539552	19543W	PARTICIPANT	\N	PRESENT	0
542287	539552	11033F	PARTICIPANT	\N	PRESENT	0
542288	539552	14215L	PARTICIPANT	\N	PRESENT	0
542289	539552	20128B	PARTICIPANT	\N	PRESENT	0
542290	539552	19747H	PARTICIPANT	\N	PRESENT	0
542291	539552	14055N	PARTICIPANT	\N	PRESENT	0
542365	537080	20094J	PARTICIPANT	\N	PRESENT	0
542366	537080	14089Y	PARTICIPANT	\N	PRESENT	0
542367	537080	20100N	PARTICIPANT	\N	PRESENT	0
542369	537080	04035D	PARTICIPANT	\N	PRESENT	0
542370	537080	11083R	PARTICIPANT	\N	PRESENT	0
542371	537080	14033T	PARTICIPANT	\N	PRESENT	1
542372	537080	19725B	PARTICIPANT	\N	PRESENT	1
542373	537080	20128B	PARTICIPANT	\N	PRESENT	1
542374	537080	14097Y	PARTICIPANT	\N	PRESENT	1
542375	537080	14073Q	PARTICIPANT	\N	PRESENT	0
542376	537080	11026G	PARTICIPANT	\N	PRESENT	1
542377	537080	12016W	PARTICIPANT	\N	PRESENT	1
542378	537080	08034U	PARTICIPANT	\N	EXCUSE	0
542379	537080	04070G	PARTICIPANT	\N	PRESENT	0
542380	537080	14237S	PRESIDENT	1	PRESENT	0
542381	537080	14331P	PRESIDENT	0	PRESENT	0
542382	537080	14001X	PARTICIPANT	\N	PRESENT	0
542383	537080	19441R	PARTICIPANT	\N	PRESENT	0
542384	537080	10015M	PARTICIPANT	\N	PRESENT	0
542394	537080	04057K	PARTICIPANT	\N	PRESENT	0
542987	542986	14329V	PARTICIPANT	\N	PRESENT	0
542989	542988	14329V	PARTICIPANT	\N	PRESENT	0
542991	542990	20032T	PARTICIPANT	\N	PRESENT	0
542992	542990	19667J	PARTICIPANT	\N	PRESENT	0
542993	542990	20144B	PARTICIPANT	\N	PRESENT	0
542994	542990	19467C	PARTICIPANT	\N	PRESENT	0
542995	542990	20040T	PARTICIPANT	\N	PRESENT	0
542996	542990	19507S	PARTICIPANT	\N	PRESENT	0
542997	542990	19511N	PARTICIPANT	\N	PRESENT	0
542998	542990	11099A	PARTICIPANT	\N	PRESENT	0
542999	542990	14109K	PARTICIPANT	\N	PRESENT	0
543000	542990	20082E	PARTICIPANT	\N	PRESENT	0
543001	542990	20054A	PARTICIPANT	\N	PRESENT	0
543002	542990	19762G	PARTICIPANT	\N	PRESENT	0
543003	542990	14257W	PARTICIPANT	\N	PRESENT	0
543004	542990	14033T	PARTICIPANT	\N	PRESENT	0
543024	543023	20096L	PARTICIPANT	\N	PRESENT	0
543026	543025	20102Q	PARTICIPANT	\N	PRESENT	0
543028	543027	20102Q	PARTICIPANT	\N	PRESENT	0
543032	543031	20022R	PARTICIPANT	\N	PRESENT	0
543034	543033	20022R	PARTICIPANT	\N	PRESENT	0
543036	543035	11048N	PARTICIPANT	\N	PRESENT	0
543038	543037	04086Q	PARTICIPANT	\N	PRESENT	0
543576	543574	97011G	PARTICIPANT	\N	PRESENT	0
543578	543574	08010L	PARTICIPANT	\N	PRESENT	0
543579	543574	19531S	PARTICIPANT	\N	PRESENT	0
543581	543574	19798U	PARTICIPANT	\N	PRESENT	0
543583	543574	20024T	PARTICIPANT	\N	PRESENT	0
543584	543574	14213J	PARTICIPANT	\N	PRESENT	0
547768	547767	14267Y	PARTICIPANT	\N	PRESENT	0
547769	547767	12028B	PARTICIPANT	\N	PRESENT	0
547770	547767	97011G	PARTICIPANT	\N	PRESENT	0
547771	547767	11064N	PARTICIPANT	\N	PRESENT	1
548514	548512	04043D	PARTICIPANT	\N	PRESENT	0
548972	548971	14193X	PARTICIPANT	\N	PRESENT	0
548973	548971	11054L	PARTICIPANT	\N	PRESENT	0
548974	548971	01058X	PARTICIPANT	\N	PRESENT	0
548975	548971	20042V	PARTICIPANT	\N	PRESENT	0
550814	548794	11070L	PARTICIPANT	\N	PRESENT	0
550895	548794	19585H	PARTICIPANT	\N	PRESENT	0
550896	548794	19583F	PARTICIPANT	\N	PRESENT	0
550897	548794	20084G	PARTICIPANT	\N	PRESENT	0
550898	548794	20092G	PARTICIPANT	\N	PRESENT	0
550899	548794	20046A	PARTICIPANT	\N	PRESENT	0
550900	548794	14215L	PARTICIPANT	\N	PRESENT	0
550901	548794	14107H	PARTICIPANT	\N	PRESENT	0
550902	548794	19629C	PARTICIPANT	\N	PRESENT	0
550903	548794	14231L	PARTICIPANT	\N	PRESENT	0
550904	548794	20090E	PARTICIPANT	\N	PRESENT	0
550912	548794	01060R	PARTICIPANT	\N	PRESENT	0
550913	548794	19301E	PARTICIPANT	\N	PRESENT	0
550914	548794	20074E	PARTICIPANT	\N	PRESENT	0
550915	548794	12016W	PARTICIPANT	\N	PRESENT	0
550916	548794	14089Y	PARTICIPANT	\N	PRESENT	0
550917	548794	20062A	PARTICIPANT	\N	PRESENT	0
550918	548794	19565D	PARTICIPANT	\N	PRESENT	0
550919	548794	19467C	PARTICIPANT	\N	PRESENT	0
550920	548794	20118Y	PARTICIPANT	\N	PRESENT	0
550921	548794	08069G	PARTICIPANT	\N	PRESENT	0
550922	548794	19866P	PARTICIPANT	\N	PRESENT	0
550925	548794	14259Y	PARTICIPANT	\N	PRESENT	0
550932	548794	14225N	PARTICIPANT	\N	PRESENT	0
550940	548794	11072N	PARTICIPANT	\N	PRESENT	0
550948	548794	19673G	PARTICIPANT	\N	PRESENT	0
550949	548794	14211G	PARTICIPANT	\N	PRESENT	0
550950	548794	20098N	PARTICIPANT	\N	PRESENT	0
550951	548794	19479G	PARTICIPANT	\N	PRESENT	0
550952	548794	20126Y	PARTICIPANT	\N	PRESENT	0
550953	548794	20130U	PARTICIPANT	\N	PRESENT	0
550966	548794	20052X	PARTICIPANT	\N	PRESENT	0
550967	548794	07004J	PARTICIPANT	\N	PRESENT	0
550968	548794	01028R	PARTICIPANT	\N	PRESENT	0
550969	548794	19489J	PARTICIPANT	\N	PRESENT	0
550970	548794	08034U	PARTICIPANT	\N	PRESENT	0
550971	548794	14329V	PARTICIPANT	\N	PRESENT	0
551010	548795	19629C	PARTICIPANT	\N	PRESENT	0
551011	548795	19585H	PARTICIPANT	\N	PRESENT	0
551012	548795	19583F	PARTICIPANT	\N	PRESENT	0
551013	548795	19479G	PARTICIPANT	\N	PRESENT	0
551014	548795	20052X	PARTICIPANT	\N	PRESENT	0
551015	548795	14089Y	PARTICIPANT	\N	PRESENT	0
551016	548795	19719D	PARTICIPANT	\N	PRESENT	0
551017	548795	20130U	PARTICIPANT	\N	PRESENT	0
551018	548795	14225N	PARTICIPANT	\N	PRESENT	0
551019	548795	01028R	PARTICIPANT	\N	PRESENT	0
551020	548795	20084G	PARTICIPANT	\N	PRESENT	0
551021	548795	12016W	PARTICIPANT	\N	PRESENT	0
551022	548795	14215L	PARTICIPANT	\N	PRESENT	0
551023	548795	14231L	PARTICIPANT	\N	PRESENT	0
551024	548795	19565D	PARTICIPANT	\N	PRESENT	0
551025	548795	20046A	PARTICIPANT	\N	PRESENT	0
551026	548795	19489J	PARTICIPANT	\N	PRESENT	0
551027	548795	11027H	PARTICIPANT	\N	PRESENT	0
551028	548795	20090E	PARTICIPANT	\N	PRESENT	0
551029	548795	14329V	PARTICIPANT	\N	PRESENT	0
551030	548795	20062A	PARTICIPANT	\N	PRESENT	0
551031	548795	20108W	PARTICIPANT	\N	PRESENT	0
551032	548795	10015M	PARTICIPANT	\N	PRESENT	0
551033	548795	20118Y	PARTICIPANT	\N	PRESENT	0
551034	548795	20098N	PARTICIPANT	\N	PRESENT	0
551035	548795	19673G	PARTICIPANT	\N	PRESENT	0
551036	548795	14211G	PARTICIPANT	\N	PRESENT	0
551037	548795	08010L	PARTICIPANT	\N	PRESENT	0
551038	548795	20116W	PARTICIPANT	\N	PRESENT	0
551039	548795	19866P	PARTICIPANT	\N	PRESENT	0
551040	548795	11072N	PARTICIPANT	\N	PRESENT	0
551041	548795	95063L	PARTICIPANT	\N	PRESENT	0
551042	548795	20126Y	PARTICIPANT	\N	PRESENT	0
551043	548795	19467C	PARTICIPANT	\N	PRESENT	0
551044	548795	20096L	PARTICIPANT	\N	PRESENT	0
551045	548795	19447X	PARTICIPANT	\N	PRESENT	0
551008	548795	11070L	PARTICIPANT	\N	PRESENT	0
551009	548795	14107H	PARTICIPANT	\N	PRESENT	0
551046	548795	20048C	PARTICIPANT	\N	PRESENT	0
551052	548795	19553Y	PARTICIPANT	\N	PRESENT	0
551053	548795	11056N	PARTICIPANT	\N	PRESENT	0
551054	548795	04086Q	PARTICIPANT	\N	PRESENT	0
551055	548795	04047H	PARTICIPANT	\N	PRESENT	0
551056	548795	14069U	PARTICIPANT	\N	PRESENT	0
551057	548795	14083S	PARTICIPANT	\N	PRESENT	0
551058	548795	19551W	PARTICIPANT	\N	PRESENT	0
551059	548795	19693L	PARTICIPANT	\N	PRESENT	0
551060	548795	14053L	PARTICIPANT	\N	PRESENT	0
560758	559486	19383Y	PARTICIPANT	\N	PRESENT	0
560759	559486	20030R	PARTICIPANT	\N	PRESENT	1
560760	559486	19768N	PARTICIPANT	\N	PRESENT	0
560761	559486	19515S	PARTICIPANT	\N	PRESENT	1
560762	559486	19782L	PARTICIPANT	\N	PRESENT	0
560763	559486	20092G	PARTICIPANT	\N	PRESENT	0
560764	559486	19441R	PARTICIPANT	\N	PRESENT	0
560765	559486	20144B	PARTICIPANT	\N	PRESENT	0
560766	559486	11090Q	PRESIDENT	0	PRESENT	0
560767	559486	01025N	PARTICIPANT	\N	PRESENT	0
560768	559486	14033T	PARTICIPANT	\N	PRESENT	0
560769	559486	04045F	PARTICIPANT	\N	PRESENT	0
560770	559486	14205J	PARTICIPANT	\N	PRESENT	0
560771	559486	11099A	PARTICIPANT	\N	PRESENT	0
560772	559486	20062A	PARTICIPANT	\N	PRESENT	1
560773	559486	14251Q	PARTICIPANT	\N	PRESENT	1
560774	559486	19705W	PARTICIPANT	\N	PRESENT	1
560775	559486	19507S	PARTICIPANT	\N	PRESENT	0
560776	559486	19575F	PARTICIPANT	\N	PRESENT	0
560777	559486	14207L	PARTICIPANT	\N	PRESENT	0
560778	559486	19747H	PARTICIPANT	\N	PRESENT	1
560779	559486	19511N	PARTICIPANT	\N	PRESENT	0
560780	559486	08028W	PARTICIPANT	\N	PRESENT	0
560781	559486	14257W	PARTICIPANT	\N	PRESENT	0
560866	559486	19563B	PARTICIPANT	\N	EXCUSE	0
560872	560589	19551W	PARTICIPANT	\N	PRESENT	0
560915	559486	20082E	PARTICIPANT	\N	PRESENT	0
560942	560589	19705W	PARTICIPANT	\N	PRESENT	1
560741	560589	18083K	PARTICIPANT	\N	PRESENT	0
560742	560589	20032T	PARTICIPANT	\N	PRESENT	0
560743	560589	20136B	PARTICIPANT	\N	PRESENT	0
560744	560589	20118Y	PARTICIPANT	\N	PRESENT	0
560745	560589	14031R	PARTICIPANT	\N	PRESENT	0
560746	560589	20140W	PARTICIPANT	\N	PRESENT	0
560747	560589	19503N	PARTICIPANT	\N	PRESENT	0
560748	560589	19820Y	PARTICIPANT	\N	PRESENT	0
560749	560589	14219Q	PRESIDENT	0	PRESENT	0
560750	560589	19637C	PARTICIPANT	\N	PRESENT	0
560751	560589	20106U	PARTICIPANT	\N	PRESENT	1
560752	560589	19387D	PARTICIPANT	\N	PRESENT	1
560753	560589	19577H	PARTICIPANT	\N	PRESENT	1
560754	560589	19383Y	PARTICIPANT	\N	PRESENT	0
560755	560589	20092G	PARTICIPANT	\N	PRESENT	0
560756	560589	11099A	PARTICIPANT	\N	PRESENT	0
560757	560589	19681G	PARTICIPANT	\N	PRESENT	1
560943	560589	14251Q	PARTICIPANT	\N	PRESENT	1
560944	560589	19747H	PARTICIPANT	\N	PRESENT	1
560945	560589	11090Q	PARTICIPANT	\N	PRESENT	0
560946	560589	14205J	PARTICIPANT	\N	PRESENT	0
560947	560589	19507S	PARTICIPANT	\N	PRESENT	0
560948	560589	14033T	PARTICIPANT	\N	PRESENT	0
560949	559486	14038Y	PARTICIPANT	\N	PRESENT	1
560980	559653	86034E	PARTICIPANT	\N	PRESENT	0
560988	559653	98022P	PARTICIPANT	\N	PRESENT	0
560989	559653	19511N	PARTICIPANT	\N	PRESENT	0
560990	559653	19729F	PARTICIPANT	\N	PRESENT	0
560991	559653	14105F	PARTICIPANT	\N	PRESENT	0
560992	559653	20098N	PARTICIPANT	\N	PRESENT	0
560993	559653	20032T	PARTICIPANT	\N	PRESENT	0
560994	559653	11101A	PARTICIPANT	\N	PRESENT	0
560995	559653	19367Y	PARTICIPANT	\N	PRESENT	0
560996	559653	14221J	PARTICIPANT	\N	PRESENT	0
560997	559653	19683J	PARTICIPANT	\N	PRESENT	0
560998	559653	19387D	PARTICIPANT	\N	PRESENT	0
560999	559653	14109K	PARTICIPANT	\N	PRESENT	0
561000	559653	20072C	PARTICIPANT	\N	PRESENT	0
561001	559653	20084G	PARTICIPANT	\N	PRESENT	0
561002	559653	19826F	PARTICIPANT	\N	PRESENT	0
561003	559653	04085P	PARTICIPANT	\N	PRESENT	0
561004	559653	11027H	PARTICIPANT	\N	PRESENT	0
561005	559653	19697Q	PARTICIPANT	\N	PRESENT	0
561006	559653	19347U	PARTICIPANT	\N	PRESENT	0
561007	559653	14111D	PARTICIPANT	\N	PRESENT	0
561008	559653	14187A	PARTICIPANT	\N	PRESENT	0
561009	559653	04042C	PARTICIPANT	\N	PRESENT	0
561010	559653	19531S	PARTICIPANT	\N	PRESENT	0
561011	559653	14073Q	PARTICIPANT	\N	PRESENT	0
561012	559653	19533U	PARTICIPANT	\N	PRESENT	0
561013	559653	19621T	PARTICIPANT	\N	PRESENT	0
561014	559653	19735D	PARTICIPANT	\N	PRESENT	0
561015	559653	14253S	PARTICIPANT	\N	PRESENT	0
561016	559653	11103C	PARTICIPANT	\N	PRESENT	0
561017	559653	19699S	PARTICIPANT	\N	PRESENT	0
561018	559653	20060X	PARTICIPANT	\N	PRESENT	0
561019	559653	14213J	PARTICIPANT	\N	PRESENT	0
561020	559653	11041F	PARTICIPANT	\N	PRESENT	0
561021	559653	20150Y	PARTICIPANT	\N	PRESENT	0
561023	559653	20180F	PARTICIPANT	\N	PRESENT	0
561025	559653	19798U	PARTICIPANT	\N	PRESENT	0
561026	559653	10006L	PARTICIPANT	\N	PRESENT	0
561029	559653	19629C	PARTICIPANT	\N	PRESENT	0
561031	559653	19599P	PARTICIPANT	\N	PRESENT	0
561032	559653	11054L	PARTICIPANT	\N	PRESENT	0
561034	559653	14207L	PARTICIPANT	\N	PRESENT	0
561036	559653	20172F	PARTICIPANT	\N	PRESENT	0
561038	559653	14195A	PARTICIPANT	\N	PRESENT	0
561040	559653	14030Q	PARTICIPANT	\N	PRESENT	0
561041	559653	20056C	PARTICIPANT	\N	PRESENT	0
561044	559653	20140W	PARTICIPANT	\N	PRESENT	0
561045	559653	14267Y	PARTICIPANT	\N	PRESENT	0
561047	559653	20090E	PARTICIPANT	\N	PRESENT	0
561048	559653	18083K	PARTICIPANT	\N	PRESENT	0
561049	559653	14211G	PARTICIPANT	\N	PRESENT	0
561050	559653	11010L	PARTICIPANT	\N	PRESENT	0
561051	559653	08034U	PARTICIPANT	\N	PRESENT	0
561052	559653	20016T	PARTICIPANT	\N	PRESENT	0
561053	559653	08045X	PARTICIPANT	\N	PRESENT	0
561054	559653	19441R	PARTICIPANT	\N	PRESENT	0
561055	559653	19649G	PARTICIPANT	\N	PRESENT	0
561056	559653	12028B	PARTICIPANT	\N	PRESENT	0
561057	559653	12041X	PARTICIPANT	\N	PRESENT	0
561058	559653	11040E	PARTICIPANT	\N	PRESENT	0
561059	559653	20052X	PARTICIPANT	\N	PRESENT	0
561060	559653	14121F	PARTICIPANT	\N	PRESENT	0
561061	559653	19717B	PARTICIPANT	\N	PRESENT	0
561062	559653	19687N	PARTICIPANT	\N	PRESENT	0
561063	559653	19782L	PARTICIPANT	\N	PRESENT	0
561064	559653	04045F	PARTICIPANT	\N	PRESENT	0
561065	559653	20042V	PARTICIPANT	\N	PRESENT	0
561066	559653	19689Q	PARTICIPANT	\N	PRESENT	0
561067	559653	19637C	PARTICIPANT	\N	PRESENT	0
561068	559653	19760E	PARTICIPANT	\N	PRESENT	0
561069	559653	14042U	PARTICIPANT	\N	PRESENT	0
561070	559653	19651A	PARTICIPANT	\N	PRESENT	0
561071	559653	04047H	PARTICIPANT	\N	PRESENT	0
561072	559653	14071N	PARTICIPANT	\N	PRESENT	0
561073	559653	11066Q	PARTICIPANT	\N	PRESENT	0
561074	559653	11067R	PARTICIPANT	\N	PRESENT	0
561075	559653	11012A	PARTICIPANT	\N	PRESENT	0
561076	559653	19647E	PARTICIPANT	\N	PRESENT	0
561077	559653	17965H	PARTICIPANT	\N	PRESENT	0
561078	559653	20142Y	PARTICIPANT	\N	PRESENT	0
561079	559653	19349W	PARTICIPANT	\N	PRESENT	0
561080	559653	19583F	PARTICIPANT	\N	PRESENT	0
561081	559653	20116W	PARTICIPANT	\N	PRESENT	0
561082	559653	14257W	PARTICIPANT	\N	PRESENT	0
561083	559653	19333N	PARTICIPANT	\N	PRESENT	0
561084	559653	14231L	PARTICIPANT	\N	PRESENT	0
561085	559653	20100N	PARTICIPANT	\N	PRESENT	0
561086	559653	04034C	PARTICIPANT	\N	PRESENT	0
561087	559653	19413M	PARTICIPANT	\N	PRESENT	0
561088	559653	19503N	PARTICIPANT	\N	PRESENT	0
561089	559653	14229S	PARTICIPANT	\N	PRESENT	0
561090	559653	11056N	PARTICIPANT	\N	PRESENT	0
561091	559653	11031D	PARTICIPANT	\N	PRESENT	0
561092	559653	11077T	PARTICIPANT	\N	PRESENT	0
561093	559653	19695N	PARTICIPANT	\N	PRESENT	0
561094	559653	19575F	PARTICIPANT	\N	PRESENT	0
561095	559653	01058X	PARTICIPANT	\N	PRESENT	0
561096	559653	20076G	PARTICIPANT	\N	PRESENT	0
561097	559653	19643A	PARTICIPANT	\N	PRESENT	0
561098	559653	05012A	PARTICIPANT	\N	PRESENT	0
561099	559653	14249W	PARTICIPANT	\N	PRESENT	0
561100	559653	04033B	PARTICIPANT	\N	PRESENT	0
561101	559653	19515S	PARTICIPANT	\N	PRESENT	0
561102	559653	11033F	PARTICIPANT	\N	PRESENT	0
561103	559653	20068G	PARTICIPANT	\N	PRESENT	0
561104	559653	04057K	PARTICIPANT	\N	PRESENT	0
561105	559653	14251Q	PARTICIPANT	\N	PRESENT	0
561106	559653	11080N	PARTICIPANT	\N	PRESENT	0
561107	559653	19719D	PARTICIPANT	\N	PRESENT	0
542329	541389	20074E	PARTICIPANT	\N	EXCUSE	0
542665	542664	08060W	PARTICIPANT	\N	PRESENT	0
542666	542664	05012A	PARTICIPANT	\N	PRESENT	0
542667	542664	19525U	PARTICIPANT	\N	PRESENT	0
542668	542664	17229F	PARTICIPANT	\N	PRESENT	0
542669	542664	20100N	PARTICIPANT	\N	PRESENT	0
542670	542664	19387D	PARTICIPANT	\N	PRESENT	0
542671	542664	19551W	PARTICIPANT	\N	PRESENT	0
542672	542664	19637C	PARTICIPANT	\N	PRESENT	0
542673	542664	19619A	PARTICIPANT	\N	PRESENT	0
542674	542664	20136B	PARTICIPANT	\N	PRESENT	0
542676	542675	08060W	PARTICIPANT	\N	PRESENT	0
542677	542675	05012A	PARTICIPANT	\N	PRESENT	0
542678	542675	17229F	PARTICIPANT	\N	PRESENT	0
542679	542675	20100N	PARTICIPANT	\N	PRESENT	0
542680	542675	19387D	PARTICIPANT	\N	PRESENT	0
542681	542675	19551W	PARTICIPANT	\N	PRESENT	0
542682	542675	19619A	PARTICIPANT	\N	PRESENT	0
542683	542675	20136B	PARTICIPANT	\N	PRESENT	0
542686	542685	08060W	PARTICIPANT	\N	PRESENT	0
542688	542685	05012A	PARTICIPANT	\N	PRESENT	0
542690	542685	20100N	PARTICIPANT	\N	PRESENT	0
542691	542685	19387D	PARTICIPANT	\N	PRESENT	0
542693	542685	19551W	PARTICIPANT	\N	PRESENT	0
542695	534228	20018V	PARTICIPANT	\N	PRESENT	0
542709	542592	14231L	PARTICIPANT	\N	EXCUSE	0
542710	542592	07004J	PARTICIPANT	\N	EXCUSE	0
542711	542592	20074E	PARTICIPANT	\N	EXCUSE	0
542712	542592	14021P	PARTICIPANT	\N	EXCUSE	0
543091	543088	19593H	PARTICIPANT	\N	PRESENT	0
544958	542985	11067R	PARTICIPANT	\N	PRESENT	0
544946	542985	01058X	PARTICIPANT	\N	PRESENT	0
544948	542985	20072C	PARTICIPANT	\N	PRESENT	0
544950	542985	04043D	PARTICIPANT	\N	PRESENT	0
544951	542985	19503N	PARTICIPANT	\N	PRESENT	0
544952	542985	19533U	PARTICIPANT	\N	PRESENT	0
548861	545942	11067R	PARTICIPANT	\N	EXCUSE	0
549510	549253	20056C	PARTICIPANT	\N	PRESENT	0
549511	549253	19611R	PRESIDENT	0	PRESENT	0
549512	549253	20112S	PARTICIPANT	\N	PRESENT	0
549513	549253	14123H	PARTICIPANT	\N	PRESENT	0
549514	549253	11104D	PARTICIPANT	\N	PRESENT	1
549515	549253	19399H	PARTICIPANT	\N	PRESENT	0
549516	549253	20052X	PARTICIPANT	\N	PRESENT	0
549517	547779	11056N	PARTICIPANT	\N	PRESENT	0
549518	547779	14111D	PARTICIPANT	\N	PRESENT	0
549519	547779	14041T	PARTICIPANT	\N	PRESENT	0
549520	547779	10015M	PARTICIPANT	\N	PRESENT	0
549521	547779	14147R	PARTICIPANT	\N	PRESENT	0
549522	547779	11085T	PARTICIPANT	\N	PRESENT	0
549523	547779	14215L	PARTICIPANT	\N	PRESENT	0
549524	547779	04047H	PRESIDENT	0	PRESENT	0
549525	547779	19673G	PARTICIPANT	\N	PRESENT	0
549526	547779	14231L	PARTICIPANT	\N	PRESENT	0
549527	547779	19447X	PARTICIPANT	\N	PRESENT	0
549528	547779	05008E	PARTICIPANT	\N	PRESENT	0
549529	547779	14259Y	PARTICIPANT	\N	PRESENT	0
549530	549253	19643A	PARTICIPANT	\N	PRESENT	1
549531	549253	20180F	PARTICIPANT	\N	PRESENT	0
549532	549253	20134Y	PARTICIPANT	\N	PRESENT	1
549533	549253	20142Y	PARTICIPANT	\N	PRESENT	1
549534	549253	19699S	PARTICIPANT	\N	PRESENT	1
549535	547779	01028R	PARTICIPANT	\N	PRESENT	0
549536	547779	19954N	PARTICIPANT	\N	PRESENT	0
549537	547779	14069U	PARTICIPANT	\N	PRESENT	0
549538	547779	14021P	PARTICIPANT	\N	PRESENT	0
549539	549253	20048C	PARTICIPANT	\N	PRESENT	0
549540	549253	19693L	PARTICIPANT	\N	PRESENT	0
549732	547779	11026G	PARTICIPANT	\N	PRESENT	0
549733	547779	14179A	PARTICIPANT	\N	PRESENT	0
549734	547780	18083K	PARTICIPANT	\N	PRESENT	0
549735	547780	11056N	PARTICIPANT	\N	PRESENT	0
549736	547780	19954N	PARTICIPANT	\N	PRESENT	0
549737	547780	14111D	PARTICIPANT	\N	PRESENT	0
549738	547780	11026G	PARTICIPANT	\N	PRESENT	0
549739	547780	14147R	PARTICIPANT	\N	PRESENT	0
549740	547780	14215L	PARTICIPANT	\N	PRESENT	0
549741	547780	04047H	PRESIDENT	0	PRESENT	0
549742	547780	14259Y	PARTICIPANT	\N	PRESENT	0
549743	547780	01028R	PARTICIPANT	\N	PRESENT	0
549744	547780	14231L	PARTICIPANT	\N	PRESENT	0
549745	547780	19447X	PARTICIPANT	\N	PRESENT	0
549746	549004	19383Y	PARTICIPANT	\N	PRESENT	0
549747	549004	19768N	PARTICIPANT	\N	PRESENT	0
549748	549004	20088L	PARTICIPANT	\N	PRESENT	1
549749	549004	19515S	PARTICIPANT	\N	PRESENT	0
549750	549004	19782L	PARTICIPANT	\N	PRESENT	1
549751	549004	11077T	PARTICIPANT	\N	PRESENT	1
549752	549004	14357A	PARTICIPANT	\N	PRESENT	0
549753	549004	19441R	PARTICIPANT	\N	PRESENT	0
549754	549004	19413M	PARTICIPANT	\N	PRESENT	1
549755	549004	20082E	PARTICIPANT	\N	PRESENT	0
549756	549004	19866P	PARTICIPANT	\N	PRESENT	0
549757	549004	04045F	PARTICIPANT	\N	PRESENT	1
549758	549004	20104S	PARTICIPANT	\N	PRESENT	0
549759	549004	19631V	PARTICIPANT	\N	PRESENT	0
549760	549004	19705W	PARTICIPANT	\N	PRESENT	0
549762	549004	19575F	PARTICIPANT	\N	PRESENT	0
549763	549004	19369B	PARTICIPANT	\N	PRESENT	0
549764	549004	20018V	PARTICIPANT	\N	PRESENT	0
549765	549004	19511N	PARTICIPANT	\N	PRESENT	0
549766	549004	08028W	PARTICIPANT	\N	PRESENT	0
549767	549004	19563B	PARTICIPANT	\N	PRESENT	0
549768	549004	14329V	PARTICIPANT	\N	PRESENT	0
549769	549004	20028X	PARTICIPANT	\N	PRESENT	0
549770	549004	14038Y	PARTICIPANT	\N	PRESENT	0
549771	549004	20030R	PARTICIPANT	\N	PRESENT	1
549772	549004	19467C	PARTICIPANT	\N	PRESENT	0
549773	549004	14187A	PARTICIPANT	\N	PRESENT	0
549774	549004	20144B	PARTICIPANT	\N	PRESENT	0
549775	549004	19695N	PARTICIPANT	\N	PRESENT	0
549776	549004	14033T	PARTICIPANT	\N	PRESENT	0
549777	549004	11090Q	PRESIDENT	0	PRESENT	0
549778	549004	01025N	PARTICIPANT	\N	PRESENT	1
549779	549004	20054A	PARTICIPANT	\N	PRESENT	0
549780	549004	20174H	PARTICIPANT	\N	PRESENT	0
549781	549004	14205J	PARTICIPANT	\N	PRESENT	0
549782	549004	20062A	PARTICIPANT	\N	PRESENT	0
549783	549004	14251Q	PARTICIPANT	\N	PRESENT	0
549784	549004	19507S	PARTICIPANT	\N	PRESENT	0
549785	549004	19747H	PARTICIPANT	\N	PRESENT	0
549786	549004	14207L	PARTICIPANT	\N	PRESENT	0
549787	549004	14257W	PARTICIPANT	\N	PRESENT	0
549788	547780	10015M	PARTICIPANT	\N	PRESENT	0
549796	549004	20092G	PARTICIPANT	\N	PRESENT	0
549797	549004	20094J	PARTICIPANT	\N	PRESENT	0
550644	548793	14357A	PARTICIPANT	\N	PRESENT	0
550645	548793	20096L	PARTICIPANT	\N	PRESENT	0
550646	548793	19575F	PARTICIPANT	\N	PRESENT	0
550647	548793	11067R	PARTICIPANT	\N	PRESENT	0
550648	548793	19563B	PARTICIPANT	\N	PRESENT	0
550649	548793	14231L	PARTICIPANT	\N	PRESENT	0
550650	548793	20058E	PARTICIPANT	\N	PRESENT	0
550651	548793	08010L	PARTICIPANT	\N	PRESENT	0
550652	548793	14211G	PARTICIPANT	\N	PRESENT	0
550653	548793	20092G	PARTICIPANT	\N	PRESENT	0
550654	548793	14187A	PARTICIPANT	\N	PRESENT	0
550655	548793	20052X	PARTICIPANT	\N	PRESENT	0
550656	548793	11027H	PARTICIPANT	\N	PRESENT	0
550657	548793	20082E	PARTICIPANT	\N	PRESENT	0
550658	548793	14073Q	PARTICIPANT	\N	PRESENT	0
565044	564386	99004R	PARTICIPANT	\N	PRESENT	0
565045	564386	14253S	PARTICIPANT	\N	PRESENT	0
565046	564386	14173T	PARTICIPANT	\N	PRESENT	0
565048	564386	04086Q	PARTICIPANT	\N	PRESENT	0
565049	564386	19711U	PARTICIPANT	\N	PRESENT	0
565050	564386	20070A	PARTICIPANT	\N	PRESENT	0
565051	564386	19349W	PARTICIPANT	\N	PRESENT	0
565052	564386	19741B	PARTICIPANT	\N	PRESENT	0
565053	564386	20044X	PARTICIPANT	\N	PRESENT	0
565054	564386	14225N	PRESIDENT	0	PRESENT	0
565078	563967	14111D	PARTICIPANT	\N	PRESENT	0
565079	563967	04047H	PRESIDENT	0	PRESENT	0
565080	563967	19673G	PARTICIPANT	\N	PRESENT	0
565081	563967	19447X	PARTICIPANT	\N	PRESENT	0
565082	563967	05008E	PARTICIPANT	\N	PRESENT	0
565083	563967	14231L	PARTICIPANT	\N	PRESENT	0
565084	563967	11056N	PARTICIPANT	\N	PRESENT	0
565085	563967	95063L	PARTICIPANT	\N	PRESENT	0
565086	563967	14041T	PARTICIPANT	\N	PRESENT	0
565087	563967	20110Q	PARTICIPANT	\N	PRESENT	0
565088	563967	14147R	PARTICIPANT	\N	PRESENT	0
565089	563967	14215L	PARTICIPANT	\N	PRESENT	0
565090	563967	19749K	PARTICIPANT	\N	PRESENT	0
565091	563967	14259Y	PARTICIPANT	\N	PRESENT	0
565092	563967	11072N	PARTICIPANT	\N	PRESENT	0
565102	564386	01057W	PARTICIPANT	\N	PRESENT	0
565103	564386	20080C	PARTICIPANT	\N	PRESENT	0
565104	564386	11053K	PARTICIPANT	\N	PRESENT	0
565105	564386	14083S	PARTICIPANT	\N	PRESENT	0
565106	564386	08010L	PARTICIPANT	\N	PRESENT	0
565107	564386	20116W	PARTICIPANT	\N	PRESENT	0
565109	563967	11033F	PARTICIPANT	\N	PRESENT	1
565110	563967	20114U	PARTICIPANT	\N	PRESENT	1
565111	563967	19725B	PARTICIPANT	\N	PRESENT	1
565112	563967	20128B	PARTICIPANT	\N	PRESENT	1
565113	563967	14179A	PARTICIPANT	\N	PRESENT	1
565114	563967	19649G	PARTICIPANT	\N	PRESENT	1
565115	563967	19729F	PARTICIPANT	\N	PRESENT	1
565116	563967	19581D	PARTICIPANT	\N	PRESENT	1
565117	563967	10015M	PARTICIPANT	\N	PRESENT	1
565118	563967	14107H	PARTICIPANT	\N	PRESENT	1
565119	563967	19675J	PARTICIPANT	\N	PRESENT	1
565190	564259	19443T	PARTICIPANT	\N	PRESENT	1
565191	564259	12041X	PARTICIPANT	\N	PRESENT	0
565192	564259	01058X	PARTICIPANT	\N	PRESENT	0
565193	564259	16685X	PARTICIPANT	\N	PRESENT	0
565194	564259	11054L	PARTICIPANT	\N	PRESENT	0
565195	564259	11066Q	PARTICIPANT	\N	PRESENT	0
565196	564259	19421M	PARTICIPANT	\N	PRESENT	0
565197	564259	19709B	PARTICIPANT	\N	PRESENT	0
565198	564259	14193X	PRESIDENT	0	PRESENT	0
565199	564259	19347U	PARTICIPANT	\N	PRESENT	0
565200	564259	97011G	PARTICIPANT	\N	PRESENT	0
565201	564259	14249W	PARTICIPANT	\N	PRESENT	0
565202	564259	08047A	PARTICIPANT	\N	PRESENT	1
565203	564259	14059S	PARTICIPANT	\N	PRESENT	0
565204	564259	14097Y	PARTICIPANT	\N	PRESENT	0
565205	564259	14133K	PARTICIPANT	\N	PRESENT	0
565206	564259	01062T	PARTICIPANT	\N	PRESENT	0
565207	564259	08069G	PARTICIPANT	\N	PRESENT	0
565208	564259	01024M	PARTICIPANT	\N	PRESENT	0
565209	564259	14105F	PARTICIPANT	\N	PRESENT	1
565210	564259	14267Y	PARTICIPANT	\N	PRESENT	1
565211	564259	11083R	PARTICIPANT	\N	PRESENT	0
565212	564259	19583F	PARTICIPANT	\N	PRESENT	0
565213	564259	14255U	PARTICIPANT	\N	PRESENT	1
565214	564259	17023S	PARTICIPANT	\N	PRESENT	1
565215	564259	04042C	PARTICIPANT	\N	EXCUSE	0
565216	564259	19565D	PARTICIPANT	\N	PRESENT	1
565217	564259	08056B	PARTICIPANT	\N	PRESENT	1
565270	564338	19585H	PARTICIPANT	\N	PRESENT	0
565271	564338	20052X	PARTICIPANT	\N	PRESENT	0
565225	563261	19329S	PARTICIPANT	\N	PRESENT	1
565226	563261	19573D	PARTICIPANT	\N	PRESENT	0
565227	563261	20112S	PARTICIPANT	\N	PRESENT	0
565228	563261	20134Y	PARTICIPANT	\N	PRESENT	0
565229	563261	19699S	PARTICIPANT	\N	EXCUSE	0
565230	563261	20056C	PARTICIPANT	\N	PRESENT	0
565232	563961	04085P	PARTICIPANT	\N	PRESENT	1
565233	563961	11033F	PARTICIPANT	\N	PRESENT	1
565234	563961	20114U	PARTICIPANT	\N	PRESENT	1
565235	563961	19629C	PARTICIPANT	\N	PRESENT	1
565236	563961	19725B	PARTICIPANT	\N	PRESENT	1
565237	563961	20128B	PARTICIPANT	\N	PRESENT	1
565238	563961	14179A	PARTICIPANT	\N	PRESENT	1
565239	563961	19581D	PARTICIPANT	\N	PRESENT	1
565240	563961	10015M	PARTICIPANT	\N	PRESENT	1
565241	563961	14107H	PARTICIPANT	\N	PRESENT	1
565242	563961	19675J	PARTICIPANT	\N	PRESENT	1
565243	563961	07004J	PARTICIPANT	\N	EXCUSE	0
565244	563967	07004J	PARTICIPANT	\N	EXCUSE	0
565266	564338	20068G	PARTICIPANT	\N	PRESENT	0
565272	564338	20016T	PARTICIPANT	\N	PRESENT	0
565273	564338	19741B	PARTICIPANT	\N	PRESENT	0
565275	564338	14191V	PARTICIPANT	\N	PRESENT	0
565277	564338	20028X	PARTICIPANT	\N	PRESENT	0
565278	564338	11115U	PARTICIPANT	\N	PRESENT	0
565279	564338	14193X	PARTICIPANT	\N	PRESENT	0
565280	564338	14267Y	PARTICIPANT	\N	PRESENT	0
565281	564338	14217N	PARTICIPANT	\N	PRESENT	0
565282	564338	19798U	PARTICIPANT	\N	PRESENT	0
565283	564338	14173T	PARTICIPANT	\N	PRESENT	0
565284	564338	19695N	PARTICIPANT	\N	PRESENT	0
565285	564338	20046A	PARTICIPANT	\N	PRESENT	0
565286	564338	20102Q	PARTICIPANT	\N	PRESENT	0
565287	564338	20026V	PARTICIPANT	\N	PRESENT	0
565288	564338	20062A	PARTICIPANT	\N	PRESENT	0
565289	564338	19383Y	PARTICIPANT	\N	PRESENT	0
565290	564338	19766L	PARTICIPANT	\N	PRESENT	0
565291	564338	14097Y	PARTICIPANT	\N	PRESENT	0
565292	564338	19739H	PARTICIPANT	\N	PRESENT	0
565293	564338	19683J	PARTICIPANT	\N	PRESENT	0
565294	564338	20108W	PARTICIPANT	\N	PRESENT	0
565295	564338	14121F	PARTICIPANT	\N	PRESENT	0
565296	564338	19826F	PARTICIPANT	\N	PRESENT	0
565297	564338	14109K	PARTICIPANT	\N	PRESENT	0
565298	564338	19527W	PARTICIPANT	\N	PRESENT	0
565299	564338	11054L	PARTICIPANT	\N	PRESENT	0
565300	564338	04047H	PARTICIPANT	\N	PRESENT	0
565301	564338	19413M	PARTICIPANT	\N	PRESENT	0
565302	564338	19507S	PARTICIPANT	\N	PRESENT	0
565303	564338	19415P	PARTICIPANT	\N	PRESENT	0
565304	564338	10006L	PARTICIPANT	\N	PRESENT	0
565305	564338	14355X	PARTICIPANT	\N	PRESENT	0
565306	564338	19479G	PARTICIPANT	\N	PRESENT	0
565307	564338	19581D	PARTICIPANT	\N	PRESENT	0
565308	564338	20048C	PARTICIPANT	\N	PRESENT	0
565309	564338	11090Q	PARTICIPANT	\N	PRESENT	0
565310	564338	97011G	PARTICIPANT	\N	PRESENT	0
565311	564338	11103C	PARTICIPANT	\N	PRESENT	0
565312	564338	20056C	PARTICIPANT	\N	PRESENT	0
565313	564338	19367Y	PARTICIPANT	\N	PRESENT	0
565314	564338	99004R	PARTICIPANT	\N	PRESENT	0
565315	564338	14030Q	PARTICIPANT	\N	PRESENT	0
565316	564338	20058E	PARTICIPANT	\N	PRESENT	0
565317	564338	20018V	PARTICIPANT	\N	PRESENT	0
565318	564338	17229F	PARTICIPANT	\N	PRESENT	0
565319	564338	19467C	PARTICIPANT	\N	PRESENT	0
565320	564338	14259Y	PARTICIPANT	\N	PRESENT	0
565321	564338	20098N	PARTICIPANT	\N	PRESENT	0
565322	564338	20180F	PARTICIPANT	\N	PRESENT	0
565323	564338	19349W	PARTICIPANT	\N	PRESENT	0
565324	564338	19637C	PARTICIPANT	\N	PRESENT	0
565325	564338	14107H	PARTICIPANT	\N	PRESENT	0
565326	564338	04070G	PARTICIPANT	\N	PRESENT	0
565327	564338	16685X	PARTICIPANT	\N	PRESENT	0
565328	564338	14038Y	PARTICIPANT	\N	PRESENT	0
565329	564338	19643A	PARTICIPANT	\N	PRESENT	0
565330	564338	14031R	PARTICIPANT	\N	PRESENT	0
565331	564338	19747H	PARTICIPANT	\N	PRESENT	0
565332	564338	19745F	PARTICIPANT	\N	PRESENT	0
565333	564338	01048V	PARTICIPANT	\N	PRESENT	0
565334	564338	20132W	PARTICIPANT	\N	PRESENT	0
565335	564338	20152B	PARTICIPANT	\N	PRESENT	0
565336	564338	14331P	PARTICIPANT	\N	PRESENT	0
565337	564338	19735D	PARTICIPANT	\N	PRESENT	0
565338	564338	20060X	PARTICIPANT	\N	PRESENT	0
565339	564338	14195A	PARTICIPANT	\N	PRESENT	0
565340	564338	14327T	PARTICIPANT	\N	PRESENT	0
565341	564338	11067R	PARTICIPANT	\N	PRESENT	0
544938	544620	19629C	PARTICIPANT	\N	PRESENT	1
544939	544620	19637C	PARTICIPANT	\N	PRESENT	1
544940	544620	01028R	PARTICIPANT	\N	PRESENT	0
544941	544620	20102Q	PARTICIPANT	\N	PRESENT	0
544942	544620	17637T	PARTICIPANT	\N	PRESENT	0
544943	544620	19739H	PARTICIPANT	\N	PRESENT	0
545068	542938	12041X	PARTICIPANT	\N	PRESENT	0
545069	542938	19820Y	PARTICIPANT	\N	PRESENT	0
545070	542938	19585H	PARTICIPANT	\N	PRESENT	0
545071	542938	20090E	PARTICIPANT	\N	PRESENT	0
545072	542938	19629C	PARTICIPANT	\N	PRESENT	0
545073	542938	14021P	PARTICIPANT	\N	PRESENT	0
545074	542938	19739H	PARTICIPANT	\N	PRESENT	0
545075	542938	20094J	PARTICIPANT	\N	PRESENT	0
545076	542938	11090Q	PARTICIPANT	\N	PRESENT	0
545077	542938	19689Q	PARTICIPANT	\N	PRESENT	0
545078	542938	19651A	PARTICIPANT	\N	PRESENT	0
545079	542938	19369B	PARTICIPANT	\N	PRESENT	0
545080	542938	19669L	PARTICIPANT	\N	PRESENT	0
545081	542938	20102Q	PARTICIPANT	\N	PRESENT	0
545084	542938	20044X	PARTICIPANT	\N	PRESENT	0
545089	542938	97011G	PARTICIPANT	\N	PRESENT	0
545094	542938	19631V	PARTICIPANT	\N	PRESENT	0
545098	542938	19333N	PARTICIPANT	\N	PRESENT	0
545113	542938	20034V	PARTICIPANT	\N	PRESENT	0
545114	542938	20086J	PARTICIPANT	\N	PRESENT	0
545120	542938	19479G	PARTICIPANT	\N	PRESENT	0
545146	542938	11115U	PARTICIPANT	\N	PRESENT	0
545147	542938	20038A	PARTICIPANT	\N	PRESENT	0
545148	542938	20104S	PARTICIPANT	\N	PRESENT	0
545149	542938	19549D	PARTICIPANT	\N	PRESENT	0
545150	542938	14030Q	PARTICIPANT	\N	PRESENT	0
545151	542938	16685X	PARTICIPANT	\N	PRESENT	0
545154	542938	14179A	PARTICIPANT	\N	PRESENT	0
545165	542938	08010L	PARTICIPANT	\N	PRESENT	0
545156	542938	14147R	PARTICIPANT	\N	PRESENT	0
545157	542938	11067R	PARTICIPANT	\N	PRESENT	0
545158	542938	19413M	PARTICIPANT	\N	PRESENT	0
545163	542938	19467C	PARTICIPANT	\N	PRESENT	0
545164	542938	14041T	PARTICIPANT	\N	PRESENT	0
545177	542938	17737W	PARTICIPANT	\N	PRESENT	0
545196	542938	11031D	PARTICIPANT	\N	PRESENT	0
545197	542938	19347U	PARTICIPANT	\N	PRESENT	0
545198	542938	19954N	PARTICIPANT	\N	PRESENT	0
545199	542938	11033F	PARTICIPANT	\N	PRESENT	0
545200	542938	19749K	PARTICIPANT	\N	PRESENT	0
545201	542938	19649G	PARTICIPANT	\N	PRESENT	0
545202	542938	11045K	PARTICIPANT	\N	PRESENT	0
545203	542938	20108W	PARTICIPANT	\N	PRESENT	0
545204	542938	20066E	PARTICIPANT	\N	PRESENT	0
545205	542938	20024T	PARTICIPANT	\N	PRESENT	0
545206	542938	19591F	PARTICIPANT	\N	PRESENT	0
545253	542945	20050V	PARTICIPANT	\N	PRESENT	0
545254	542945	14055N	PARTICIPANT	\N	PRESENT	0
545255	542945	11033F	PARTICIPANT	\N	PRESENT	0
545256	542945	19591F	PARTICIPANT	\N	PRESENT	0
545257	542945	19651A	PARTICIPANT	\N	PRESENT	0
545258	542945	20034V	PARTICIPANT	\N	PRESENT	0
545259	542945	04047H	PARTICIPANT	\N	PRESENT	0
545260	542945	19954N	PARTICIPANT	\N	PRESENT	0
545261	542945	19629C	PARTICIPANT	\N	PRESENT	0
545262	542945	19479G	PARTICIPANT	\N	PRESENT	0
545263	542945	20066E	PARTICIPANT	\N	PRESENT	0
545264	542945	19749K	PARTICIPANT	\N	PRESENT	0
545265	542945	20108W	PARTICIPANT	\N	PRESENT	0
545266	542945	14030Q	PARTICIPANT	\N	PRESENT	0
545267	542945	19467C	PARTICIPANT	\N	PRESENT	0
545269	542945	11067R	PARTICIPANT	\N	PRESENT	0
545271	542945	19820Y	PARTICIPANT	\N	PRESENT	0
545272	542945	14041T	PARTICIPANT	\N	PRESENT	0
545273	542945	11045K	PARTICIPANT	\N	PRESENT	0
545274	542945	19649G	PARTICIPANT	\N	PRESENT	0
545275	542945	17737W	PARTICIPANT	\N	PRESENT	0
545280	542945	08010L	PARTICIPANT	\N	PRESENT	0
545277	542945	11031D	PARTICIPANT	\N	PRESENT	0
545278	542945	19347U	PARTICIPANT	\N	PRESENT	0
545279	542945	14109K	PARTICIPANT	\N	PRESENT	0
545281	542945	20024T	PARTICIPANT	\N	PRESENT	0
545282	542945	14021P	PARTICIPANT	\N	PRESENT	0
545283	542945	20022R	PARTICIPANT	\N	PRESENT	0
545284	542945	14083S	PARTICIPANT	\N	PRESENT	0
545285	542945	19543W	PARTICIPANT	\N	PRESENT	0
545289	542945	14179A	PARTICIPANT	\N	PRESENT	0
545298	542945	01028R	PARTICIPANT	\N	PRESENT	0
545299	542945	11083R	PARTICIPANT	\N	PRESENT	0
545314	542975	19954N	PARTICIPANT	\N	PRESENT	0
545315	542975	19649G	PARTICIPANT	\N	PRESENT	0
545316	542975	14041T	PARTICIPANT	\N	PRESENT	0
545317	542975	20108W	PARTICIPANT	\N	PRESENT	0
545318	542975	14147R	PARTICIPANT	\N	PRESENT	0
545319	542975	14179A	PARTICIPANT	\N	PRESENT	0
545320	542975	04047H	PRESIDENT	0	PRESENT	0
545321	542975	19749K	PARTICIPANT	\N	PRESENT	0
545322	542975	11033F	PARTICIPANT	\N	PRESENT	0
545323	542975	19543W	PARTICIPANT	\N	PRESENT	0
545326	542945	19717B	PARTICIPANT	\N	PRESENT	0
545251	542945	12041X	PARTICIPANT	\N	PRESENT	0
545252	542945	14147R	PARTICIPANT	\N	PRESENT	0
545327	542945	19695N	PARTICIPANT	\N	PRESENT	0
545329	542945	08018U	PARTICIPANT	\N	PRESENT	0
545332	542945	19503N	PARTICIPANT	\N	PRESENT	0
545359	542947	11072N	PARTICIPANT	\N	PRESENT	0
545360	542947	19651A	PARTICIPANT	\N	PRESENT	0
545361	542947	20050V	PARTICIPANT	\N	PRESENT	0
545362	542947	20110Q	PARTICIPANT	\N	PRESENT	0
545363	542947	04047H	PARTICIPANT	\N	PRESENT	0
545364	542947	19954N	PARTICIPANT	\N	PRESENT	0
545365	542947	14041T	PARTICIPANT	\N	PRESENT	0
545366	542947	19749K	PARTICIPANT	\N	PRESENT	0
545367	542947	14030Q	PARTICIPANT	\N	PRESENT	0
545368	542947	11033F	PARTICIPANT	\N	PRESENT	0
545369	542947	14147R	PARTICIPANT	\N	PRESENT	0
545370	542947	19629C	PARTICIPANT	\N	PRESENT	0
545371	542947	08010L	PARTICIPANT	\N	PRESENT	0
545372	542947	01028R	PARTICIPANT	\N	PRESENT	0
545373	542947	19695N	PARTICIPANT	\N	PRESENT	0
551126	548798	19651A	PARTICIPANT	\N	PRESENT	0
551127	548798	19593H	PARTICIPANT	\N	PRESENT	0
551128	548798	14055N	PARTICIPANT	\N	PRESENT	0
551130	548798	19629C	PARTICIPANT	\N	PRESENT	0
551131	548798	19719D	PARTICIPANT	\N	PRESENT	0
551132	548798	08034U	PARTICIPANT	\N	PRESENT	0
551133	548798	19673G	PARTICIPANT	\N	PRESENT	0
551134	548798	19749K	PARTICIPANT	\N	PRESENT	0
545357	542947	12041X	PARTICIPANT	\N	PRESENT	0
545358	542947	08018U	PARTICIPANT	\N	PRESENT	0
551135	548798	14215L	PARTICIPANT	\N	PRESENT	0
551137	548798	14329V	PARTICIPANT	\N	PRESENT	0
551138	548798	20062A	PARTICIPANT	\N	PRESENT	0
551139	548798	04086Q	PARTICIPANT	\N	PRESENT	0
551142	548798	19649G	PARTICIPANT	\N	PRESENT	0
551144	548798	20066E	PARTICIPANT	\N	PRESENT	0
551145	548798	19479G	PARTICIPANT	\N	PRESENT	0
551146	548798	11033F	PARTICIPANT	\N	PRESENT	0
551147	548798	04047H	PARTICIPANT	\N	PRESENT	0
551148	548798	20090E	PARTICIPANT	\N	PRESENT	0
551149	548798	01028R	PARTICIPANT	\N	PRESENT	0
551150	548798	19693L	PARTICIPANT	\N	PRESENT	0
551123	548798	12041X	PARTICIPANT	\N	PRESENT	0
551125	548798	07004J	PARTICIPANT	\N	PRESENT	0
551151	548798	20180F	PARTICIPANT	\N	PRESENT	0
551152	548798	17737W	PARTICIPANT	\N	PRESENT	0
551153	548798	19725B	PARTICIPANT	\N	PRESENT	0
551154	548798	17965H	PARTICIPANT	\N	PRESENT	0
551155	548798	11072N	PARTICIPANT	\N	PRESENT	0
551156	548798	14211G	PARTICIPANT	\N	PRESENT	0
551157	548798	19447X	PARTICIPANT	\N	PRESENT	0
551158	548798	04043D	PARTICIPANT	\N	PRESENT	0
551159	548798	04085P	PARTICIPANT	\N	PRESENT	0
551160	548798	20112S	PARTICIPANT	\N	PRESENT	0
551162	548798	19565D	PARTICIPANT	\N	PRESENT	0
551163	548798	04057K	PARTICIPANT	\N	PRESENT	0
551164	548798	19643A	PARTICIPANT	\N	PRESENT	0
551165	548798	14229S	PARTICIPANT	\N	PRESENT	0
551166	548798	19747H	PARTICIPANT	\N	PRESENT	0
551167	548798	19543W	PARTICIPANT	\N	PRESENT	0
551168	548798	14053L	PARTICIPANT	\N	PRESENT	0
551169	548798	19467C	PARTICIPANT	\N	PRESENT	0
551170	548798	19533U	PARTICIPANT	\N	PRESENT	0
551171	548798	11027H	PARTICIPANT	\N	PRESENT	0
551172	548798	14231L	PARTICIPANT	\N	PRESENT	0
561108	559653	20132W	PARTICIPANT	\N	PRESENT	0
561109	559653	01043Q	PARTICIPANT	\N	PRESENT	0
561110	559653	20066E	PARTICIPANT	\N	PRESENT	0
561111	559653	19611R	PARTICIPANT	\N	PRESENT	0
561112	559653	19415P	PARTICIPANT	\N	PRESENT	0
561113	559653	11085T	PARTICIPANT	\N	PRESENT	0
561114	559653	04070G	PARTICIPANT	\N	PRESENT	0
561115	559653	14089Y	PARTICIPANT	\N	PRESENT	0
561116	559653	08056B	PARTICIPANT	\N	PRESENT	0
561117	559653	08061X	PARTICIPANT	\N	PRESENT	0
561118	559653	19383Y	PARTICIPANT	\N	PRESENT	0
561119	559653	14357A	PARTICIPANT	\N	PRESENT	0
561120	559653	11053K	PARTICIPANT	\N	PRESENT	0
561121	559653	11070L	PARTICIPANT	\N	PRESENT	0
561122	559653	14147R	PARTICIPANT	\N	PRESENT	0
561123	559653	19399H	PARTICIPANT	\N	PRESENT	0
561124	559653	14219Q	PARTICIPANT	\N	PRESENT	0
561125	559653	14169X	PARTICIPANT	\N	PRESENT	0
561126	559653	19741B	PARTICIPANT	\N	PRESENT	0
561127	559653	01025N	PARTICIPANT	\N	PRESENT	0
561128	559653	19681G	PARTICIPANT	\N	PRESENT	0
561129	559653	14259Y	PARTICIPANT	\N	PRESENT	0
561130	559653	20144B	PARTICIPANT	\N	PRESENT	0
561131	559653	20026V	PARTICIPANT	\N	PRESENT	0
561132	559653	14031R	PARTICIPANT	\N	PRESENT	0
561133	559653	14038Y	PARTICIPANT	\N	PRESENT	0
561134	559653	20044X	PARTICIPANT	\N	PRESENT	0
561135	559653	01034P	PARTICIPANT	\N	PRESENT	0
561136	559653	19507S	PARTICIPANT	\N	PRESENT	0
561137	559653	08018U	PARTICIPANT	\N	PRESENT	0
561138	559653	19747H	PARTICIPANT	\N	PRESENT	0
561139	559653	11097X	PARTICIPANT	\N	PRESENT	0
561140	559653	19679N	PARTICIPANT	\N	PRESENT	0
561141	559653	16685X	PARTICIPANT	\N	PRESENT	0
561142	559653	20124W	PARTICIPANT	\N	PRESENT	0
561143	559653	20126Y	PARTICIPANT	\N	PRESENT	0
561144	559653	20120S	PARTICIPANT	\N	PRESENT	0
561145	559653	20104S	PARTICIPANT	\N	PRESENT	0
561146	559653	20040T	PARTICIPANT	\N	PRESENT	0
561147	559653	14215L	PARTICIPANT	\N	PRESENT	0
561148	559653	19966S	PARTICIPANT	\N	PRESENT	0
561149	559653	04092N	PARTICIPANT	\N	PRESENT	0
561150	559653	04059M	PARTICIPANT	\N	PRESENT	0
561151	559653	14026U	PARTICIPANT	\N	PRESENT	0
561152	559653	20070A	PARTICIPANT	\N	PRESENT	0
561153	559653	14021P	PARTICIPANT	\N	PRESENT	0
561154	559653	20086J	PARTICIPANT	\N	PRESENT	0
561155	559653	19820Y	PARTICIPANT	\N	PRESENT	0
561156	559653	19565D	PARTICIPANT	\N	PRESENT	0
561157	559653	20092G	PARTICIPANT	\N	PRESENT	0
561158	559653	04086Q	PARTICIPANT	\N	PRESENT	0
561159	559653	11074Q	PARTICIPANT	\N	PRESENT	0
561160	559653	01028R	PARTICIPANT	\N	PRESENT	0
561161	559653	20108W	PARTICIPANT	\N	PRESENT	0
561162	559653	11064N	PARTICIPANT	\N	PRESENT	0
561163	559653	14033T	PARTICIPANT	\N	PRESENT	0
561164	559653	19549D	PARTICIPANT	\N	PRESENT	0
561165	559653	20082E	PARTICIPANT	\N	PRESENT	0
561166	559653	14053L	PARTICIPANT	\N	PRESENT	0
561167	559653	17737W	PARTICIPANT	\N	PRESENT	0
561168	559653	08017T	PARTICIPANT	\N	PRESENT	0
561169	559653	19725B	PARTICIPANT	\N	PRESENT	0
561170	559653	19573D	PARTICIPANT	\N	PRESENT	0
561171	559653	17367Q	PARTICIPANT	\N	PRESENT	0
561172	559653	14281W	PARTICIPANT	\N	PRESENT	0
561173	559653	20018V	PARTICIPANT	\N	PRESENT	0
561174	559653	19619A	PARTICIPANT	\N	PRESENT	0
561175	559653	14205J	PARTICIPANT	\N	PRESENT	0
561176	559653	20138D	PARTICIPANT	\N	PRESENT	0
561177	559653	14193X	PARTICIPANT	\N	PRESENT	0
561178	559653	04071H	PARTICIPANT	\N	PRESENT	0
561179	559653	05008E	PARTICIPANT	\N	PRESENT	0
561180	559653	14189C	PARTICIPANT	\N	PRESENT	0
561181	559653	19319Q	PARTICIPANT	\N	PRESENT	0
561182	559653	14179A	PARTICIPANT	\N	PRESENT	0
561183	559653	08047A	PARTICIPANT	\N	PRESENT	0
561184	559653	19711U	PARTICIPANT	\N	PRESENT	0
561185	559653	11048N	PARTICIPANT	\N	PRESENT	0
561188	559653	08009T	PARTICIPANT	\N	PRESENT	0
561191	559653	19685L	PARTICIPANT	\N	PRESENT	0
561193	559653	19663E	PARTICIPANT	\N	PRESENT	0
561194	559653	14041T	PARTICIPANT	\N	PRESENT	0
561196	559653	11045K	PARTICIPANT	\N	PRESENT	0
561198	559653	14069U	PARTICIPANT	\N	PRESENT	0
561199	559653	04008A	PARTICIPANT	\N	PRESENT	0
561200	559653	14217N	PARTICIPANT	\N	PRESENT	0
561201	559653	20062A	PARTICIPANT	\N	PRESENT	0
561205	559653	19335Q	PARTICIPANT	\N	PRESENT	0
561208	559653	20080C	PARTICIPANT	\N	PRESENT	0
561239	559653	20048C	PARTICIPANT	\N	PRESENT	0
561245	559653	20094J	PARTICIPANT	\N	PRESENT	0
561255	559653	11043H	PARTICIPANT	\N	PRESENT	0
561256	559653	19593H	PARTICIPANT	\N	PRESENT	0
561257	559653	20130U	PARTICIPANT	\N	PRESENT	0
561261	559653	10015M	PARTICIPANT	\N	PRESENT	0
561268	559653	14055N	PARTICIPANT	\N	PRESENT	0
561485	559655	14026U	PARTICIPANT	\N	PRESENT	0
561489	559655	14237S	PARTICIPANT	\N	PRESENT	0
561491	559655	19251M	PARTICIPANT	\N	PRESENT	0
561490	559655	08009T	PARTICIPANT	\N	PRESENT	0
561492	559655	20100N	PARTICIPANT	\N	PRESENT	0
561493	559655	20042V	PARTICIPANT	\N	PRESENT	0
561494	559655	14205J	PARTICIPANT	\N	PRESENT	0
561495	559655	19685L	PARTICIPANT	\N	PRESENT	0
561496	559655	19699S	PARTICIPANT	\N	PRESENT	0
561497	559655	11056N	PARTICIPANT	\N	PRESENT	0
561498	559655	14055N	PARTICIPANT	\N	PRESENT	0
561499	559655	20022R	PARTICIPANT	\N	PRESENT	0
561501	559655	14031R	PARTICIPANT	\N	PRESENT	0
561502	559655	14219Q	PARTICIPANT	\N	PRESENT	0
561503	559655	19521Q	PARTICIPANT	\N	PRESENT	0
561504	559655	19507S	PARTICIPANT	\N	PRESENT	0
561505	559655	11053K	PARTICIPANT	\N	PRESENT	0
561506	559655	04045F	PARTICIPANT	\N	PRESENT	0
561508	559655	14121F	PARTICIPANT	\N	PRESENT	0
561509	559655	20082E	PARTICIPANT	\N	PRESENT	0
561510	559655	19549D	PARTICIPANT	\N	PRESENT	0
561511	559655	20080C	PARTICIPANT	\N	PRESENT	0
561512	559655	20102Q	PARTICIPANT	\N	PRESENT	0
561513	559655	14147R	PARTICIPANT	\N	PRESENT	0
561514	559655	11012A	PARTICIPANT	\N	PRESENT	0
561515	559487	20086J	PARTICIPANT	\N	PRESENT	0
561516	559487	19515S	PARTICIPANT	\N	PRESENT	0
561517	559487	14357A	PARTICIPANT	\N	PRESENT	0
561518	559487	19413M	PARTICIPANT	\N	PRESENT	0
561519	559487	20144B	PARTICIPANT	\N	PRESENT	0
561520	559487	19695N	PARTICIPANT	\N	PRESENT	0
561521	559487	14033T	PARTICIPANT	\N	PRESENT	0
561522	559487	11090Q	PRESIDENT	0	PRESENT	0
561523	559487	11099A	PARTICIPANT	\N	PRESENT	0
561524	559487	20062A	PARTICIPANT	\N	PRESENT	0
561525	559487	19705W	PARTICIPANT	\N	PRESENT	0
561526	559487	19575F	PARTICIPANT	\N	PRESENT	0
561527	559487	19747H	PARTICIPANT	\N	PRESENT	0
561528	559487	14207L	PARTICIPANT	\N	PRESENT	0
561529	559487	19511N	PARTICIPANT	\N	PRESENT	0
561530	559655	14221J	PARTICIPANT	\N	PRESENT	0
561531	559487	12041X	PARTICIPANT	\N	PRESENT	0
561532	559487	04034C	PARTICIPANT	\N	PRESENT	0
561533	559487	19447X	PARTICIPANT	\N	PRESENT	0
561534	559487	14193X	PARTICIPANT	\N	PRESENT	0
561535	559487	19711U	PARTICIPANT	\N	PRESENT	0
561536	559487	04057K	PARTICIPANT	\N	PRESENT	0
561537	559487	14189C	PARTICIPANT	\N	PRESENT	0
561538	559487	14073Q	PARTICIPANT	\N	PRESENT	0
561539	559487	11026G	PARTICIPANT	\N	PRESENT	0
561540	559487	19721W	PARTICIPANT	\N	PRESENT	1
561541	559487	14267Y	PARTICIPANT	\N	PRESENT	0
561542	559487	14255U	PARTICIPANT	\N	PRESENT	0
561543	559655	19691J	PARTICIPANT	\N	PRESENT	0
561544	559655	14069U	PARTICIPANT	\N	PRESENT	0
561547	559487	11077T	PARTICIPANT	\N	PRESENT	1
561548	559487	01058X	PARTICIPANT	\N	PRESENT	1
561549	559487	20030R	PARTICIPANT	\N	PRESENT	1
561550	559487	19467C	PARTICIPANT	\N	PRESENT	1
561551	559487	14169X	PARTICIPANT	\N	PRESENT	1
561552	559487	20174H	PARTICIPANT	\N	PRESENT	1
561554	559487	17023S	PARTICIPANT	\N	PRESENT	0
561556	559655	20068G	PARTICIPANT	\N	PRESENT	0
561557	559487	19782L	PARTICIPANT	\N	PRESENT	0
547782	547781	19421M	PARTICIPANT	\N	PRESENT	0
547783	547781	04034C	PARTICIPANT	\N	PRESENT	0
547784	547781	20128B	PARTICIPANT	\N	PRESENT	0
547785	547781	16685X	PARTICIPANT	\N	PRESENT	0
547819	547801	17779H	PARTICIPANT	\N	PRESENT	0
547820	547801	11067R	PARTICIPANT	\N	PRESENT	0
547821	547801	20048C	PARTICIPANT	\N	PRESENT	0
547890	547886	11054L	PARTICIPANT	\N	PRESENT	0
547891	547886	14193X	PARTICIPANT	\N	PRESENT	0
548229	548223	19709B	PARTICIPANT	\N	PRESENT	0
548231	548223	11027H	PARTICIPANT	\N	PRESENT	0
548232	548223	12041X	PARTICIPANT	\N	PRESENT	0
548237	548236	19709B	PARTICIPANT	\N	PRESENT	0
548238	548236	11027H	PARTICIPANT	\N	PRESENT	0
548239	548236	14249W	PARTICIPANT	\N	PRESENT	0
550731	548792	19866P	PARTICIPANT	\N	PRESENT	0
550732	548792	19585H	PARTICIPANT	\N	PRESENT	0
550733	548792	19621T	PARTICIPANT	\N	PRESENT	0
550734	548792	19563B	PARTICIPANT	\N	PRESENT	0
550735	548792	20090E	PARTICIPANT	\N	PRESENT	0
550736	548792	19649G	PARTICIPANT	\N	PRESENT	0
550788	548792	20054A	PARTICIPANT	\N	PRESENT	0
550738	548792	20046A	PARTICIPANT	\N	PRESENT	0
550739	548792	20112S	PARTICIPANT	\N	PRESENT	0
550740	548792	19725B	PARTICIPANT	\N	PRESENT	0
550741	548792	19631V	PARTICIPANT	\N	PRESENT	0
550742	548792	08012N	PARTICIPANT	\N	PRESENT	0
550743	548792	11056N	PARTICIPANT	\N	PRESENT	0
550744	548792	19593H	PARTICIPANT	\N	PRESENT	0
550745	548792	19695N	PARTICIPANT	\N	PRESENT	0
550746	548792	11067R	PARTICIPANT	\N	PRESENT	0
550747	548792	20094J	PARTICIPANT	\N	PRESENT	0
550748	548792	14229S	PARTICIPANT	\N	PRESENT	0
550749	548792	19333N	PARTICIPANT	\N	PRESENT	0
550750	548792	20130U	PARTICIPANT	\N	PRESENT	0
550751	548792	11033F	PARTICIPANT	\N	PRESENT	0
550752	548792	14207L	PARTICIPANT	\N	PRESENT	0
550753	548792	14073Q	PARTICIPANT	\N	PRESENT	0
550754	548792	19749K	PARTICIPANT	\N	PRESENT	0
550755	548792	20124W	PARTICIPANT	\N	PRESENT	0
550756	548792	11043H	PARTICIPANT	\N	PRESENT	0
550757	548792	14357A	PARTICIPANT	\N	PRESENT	0
550758	548792	10015M	PARTICIPANT	\N	PRESENT	0
550759	548792	20026V	PARTICIPANT	\N	PRESENT	0
550760	548792	20180F	PARTICIPANT	\N	PRESENT	0
550761	548792	18083K	PARTICIPANT	\N	PRESENT	0
550762	548792	07029T	PARTICIPANT	\N	PRESENT	0
550763	548792	14038Y	PARTICIPANT	\N	PRESENT	0
550764	548792	19543W	PARTICIPANT	\N	PRESENT	0
550765	548792	07004J	PARTICIPANT	\N	PRESENT	0
550766	548792	19651A	PARTICIPANT	\N	PRESENT	0
550767	548792	20092G	PARTICIPANT	\N	PRESENT	0
550768	548792	20106U	PARTICIPANT	\N	PRESENT	0
550769	548792	19629C	PARTICIPANT	\N	PRESENT	0
550770	548792	19489J	PARTICIPANT	\N	PRESENT	0
550771	548792	19553Y	PARTICIPANT	\N	PRESENT	0
550772	548792	19467C	PARTICIPANT	\N	PRESENT	0
550773	548792	19447X	PARTICIPANT	\N	PRESENT	0
550774	548792	19673G	PARTICIPANT	\N	PRESENT	0
550775	548792	14195A	PARTICIPANT	\N	PRESENT	0
550776	548792	20100N	PARTICIPANT	\N	PRESENT	0
550777	548792	17965H	PARTICIPANT	\N	PRESENT	0
550778	548792	19719D	PARTICIPANT	\N	PRESENT	0
550779	548792	20102Q	PARTICIPANT	\N	PRESENT	0
550780	548792	20116W	PARTICIPANT	\N	PRESENT	0
550781	548792	20152B	PARTICIPANT	\N	PRESENT	0
550782	548792	20062A	PARTICIPANT	\N	PRESENT	0
550783	548792	11027H	PARTICIPANT	\N	PRESENT	0
550784	548792	14089Y	PARTICIPANT	\N	PRESENT	0
550785	548792	19611R	PARTICIPANT	\N	PRESENT	0
550729	548792	99004R	PARTICIPANT	\N	PRESENT	0
550730	548792	20096L	PARTICIPANT	\N	PRESENT	0
550786	548792	19533U	PARTICIPANT	\N	PRESENT	0
550787	548792	19741B	PARTICIPANT	\N	PRESENT	0
550789	548792	14211G	PARTICIPANT	\N	PRESENT	0
550790	548792	04033B	PARTICIPANT	\N	PRESENT	0
550791	548792	14329V	PARTICIPANT	\N	PRESENT	0
550792	548792	14123H	PARTICIPANT	\N	PRESENT	0
550793	548792	05008E	PARTICIPANT	\N	PRESENT	0
550794	548792	20082E	PARTICIPANT	\N	PRESENT	0
550795	548792	20126Y	PARTICIPANT	\N	PRESENT	0
550796	548792	14030Q	PARTICIPANT	\N	PRESENT	0
550797	548792	04047H	PARTICIPANT	\N	PRESENT	0
550798	548792	20086J	PARTICIPANT	\N	PRESENT	0
550799	548792	14231L	PARTICIPANT	\N	PRESENT	0
550800	548792	19647E	PARTICIPANT	\N	PRESENT	0
550801	548792	19421M	PARTICIPANT	\N	PRESENT	0
550802	548792	14187A	PARTICIPANT	\N	PRESENT	0
550803	548792	14053L	PARTICIPANT	\N	PRESENT	0
550804	548792	14069U	PARTICIPANT	\N	PRESENT	0
550805	548792	14215L	PARTICIPANT	\N	PRESENT	0
550806	548792	14055N	PARTICIPANT	\N	PRESENT	0
550807	548792	19347U	PARTICIPANT	\N	PRESENT	0
550808	548792	01028R	PARTICIPANT	\N	PRESENT	0
550809	548792	20058E	PARTICIPANT	\N	PRESENT	0
550810	548792	20098N	PARTICIPANT	\N	PRESENT	0
550811	548792	14083S	PARTICIPANT	\N	PRESENT	0
550812	548792	17637T	PARTICIPANT	\N	PRESENT	0
550813	548792	14179A	PARTICIPANT	\N	PRESENT	0
554899	553222	19531S	PARTICIPANT	\N	PRESENT	0
554904	553222	10006L	PARTICIPANT	\N	PRESENT	0
555251	555068	19679N	PARTICIPANT	\N	PRESENT	0
555250	555068	18193Q	PARTICIPANT	\N	PRESENT	0
554903	553222	20096L	PARTICIPANT	\N	PRESENT	0
555400	555399	19683J	PRESIDENT	0	PRESENT	0
555401	555399	11033F	PARTICIPANT	\N	EXCUSE	0
557797	557794	19709B	PARTICIPANT	\N	PRESENT	0
557799	557794	11027H	PARTICIPANT	\N	PRESENT	0
557819	557818	19709B	PARTICIPANT	\N	PRESENT	0
557820	557818	14249W	PARTICIPANT	\N	PRESENT	0
558062	558061	08045X	PARTICIPANT	\N	PRESENT	0
558063	558061	20130U	PARTICIPANT	\N	PRESENT	0
558118	558117	19679N	PARTICIPANT	\N	PRESENT	0
560620	556324	14038Y	PARTICIPANT	\N	EXCUSE	0
561271	561265	14257W	PARTICIPANT	\N	PRESENT	0
561272	561265	20174H	PARTICIPANT	\N	PRESENT	0
561273	561265	19533U	PARTICIPANT	\N	PRESENT	0
561274	561265	01024M	PARTICIPANT	\N	PRESENT	0
561275	561265	19721W	PARTICIPANT	\N	PRESENT	0
561336	561265	19575F	PARTICIPANT	\N	PRESENT	0
561482	561265	19681G	PARTICIPANT	\N	PRESENT	0
561483	561265	14357A	PARTICIPANT	\N	PRESENT	0
561484	561265	14083S	PARTICIPANT	\N	PRESENT	0
561486	561265	20120S	PARTICIPANT	\N	PRESENT	0
561563	558912	14189C	PARTICIPANT	\N	PRESENT	0
561564	558912	14207L	PARTICIPANT	\N	PRESENT	0
561565	558912	14133K	PARTICIPANT	\N	EXCUSE	0
561566	558912	20104S	PARTICIPANT	\N	EXCUSE	0
561568	558912	14357A	PARTICIPANT	\N	PRESENT	0
561571	558912	14097Y	PARTICIPANT	\N	PRESENT	0
561572	558912	14073Q	PARTICIPANT	\N	PRESENT	0
561573	558912	12041X	PARTICIPANT	\N	PRESENT	0
561574	558912	19711U	PARTICIPANT	\N	PRESENT	0
561575	558912	11026G	PARTICIPANT	\N	PRESENT	0
561576	558912	14001X	PARTICIPANT	\N	PRESENT	1
561577	558912	04057K	PARTICIPANT	\N	PRESENT	0
561578	558912	14169X	PARTICIPANT	\N	PRESENT	1
561579	558912	10015M	PRESIDENT	0	PRESENT	0
561581	558912	04034C	PARTICIPANT	\N	PRESENT	0
561582	561567	19593H	PRESIDENT	0	PRESENT	0
561583	561567	19611R	PARTICIPANT	\N	PRESENT	0
561584	558912	14331P	PARTICIPANT	\N	EXCUSE	0
561585	561567	14059S	PARTICIPANT	\N	PRESENT	0
561586	561567	20132W	PARTICIPANT	\N	PRESENT	1
561587	561567	19721W	PARTICIPANT	\N	PRESENT	1
561588	561567	14147R	PARTICIPANT	\N	PRESENT	1
561589	561567	19643A	PARTICIPANT	\N	PRESENT	1
561590	558912	08034U	PARTICIPANT	\N	PRESENT	0
561591	561567	20174H	PARTICIPANT	\N	PRESENT	0
561592	558912	04042C	PARTICIPANT	\N	PRESENT	0
561593	558912	11090Q	PARTICIPANT	\N	PRESENT	0
561594	561567	08018U	PARTICIPANT	\N	PRESENT	0
561595	558912	17023S	PARTICIPANT	\N	PRESENT	0
561596	558912	11099A	PARTICIPANT	\N	PRESENT	0
561597	561567	04034C	PARTICIPANT	\N	PRESENT	0
561598	558912	19695N	PARTICIPANT	\N	PRESENT	0
561599	561567	14215L	PARTICIPANT	\N	PRESENT	0
561600	561567	08017T	PARTICIPANT	\N	PRESENT	0
561601	558912	14255U	PARTICIPANT	\N	PRESENT	0
561602	561567	04043D	PARTICIPANT	\N	PRESENT	0
561603	558912	19413M	PARTICIPANT	\N	PRESENT	0
565342	564338	14187A	PARTICIPANT	\N	PRESENT	0
565343	564338	20172F	PARTICIPANT	\N	PRESENT	0
565344	564338	19333N	PARTICIPANT	\N	PRESENT	0
565345	564338	01058X	PARTICIPANT	\N	PRESENT	0
565346	564338	11101A	PARTICIPANT	\N	PRESENT	0
565347	564338	14133K	PARTICIPANT	\N	PRESENT	0
565348	564338	04092N	PARTICIPANT	\N	PRESENT	0
565349	564338	86034E	PARTICIPANT	\N	PRESENT	0
565350	564338	19711U	PARTICIPANT	\N	PRESENT	0
565351	564338	19533U	PARTICIPANT	\N	PRESENT	0
565352	564338	14213J	PARTICIPANT	\N	PRESENT	0
565353	564338	14251Q	PARTICIPANT	\N	PRESENT	0
565354	564338	14257W	PARTICIPANT	\N	PRESENT	0
565355	564338	19599P	PARTICIPANT	\N	PRESENT	0
565356	564338	08061X	PARTICIPANT	\N	PRESENT	0
565357	564338	19673G	PARTICIPANT	\N	PRESENT	0
565358	564338	14357A	PARTICIPANT	\N	PRESENT	0
565359	564338	20144B	PARTICIPANT	\N	PRESENT	0
565360	564338	20084G	PARTICIPANT	\N	PRESENT	0
565361	564338	08045X	PARTICIPANT	\N	PRESENT	0
565362	564338	19719D	PARTICIPANT	\N	PRESENT	0
565363	564338	19681G	PARTICIPANT	\N	PRESENT	0
565364	564338	20076G	PARTICIPANT	\N	PRESENT	0
565365	564338	04033B	PARTICIPANT	\N	PRESENT	0
565366	564338	14189C	PARTICIPANT	\N	PRESENT	0
565367	564338	19611R	PARTICIPANT	\N	PRESENT	0
565368	564338	20120S	PARTICIPANT	\N	PRESENT	0
565369	564338	20040T	PARTICIPANT	\N	PRESENT	0
565370	564338	14207L	PARTICIPANT	\N	PRESENT	0
565371	564338	11045K	PARTICIPANT	\N	PRESENT	0
565372	564338	19687N	PARTICIPANT	\N	PRESENT	0
565373	564338	19760E	PARTICIPANT	\N	PRESENT	0
565374	564338	14211G	PARTICIPANT	\N	PRESENT	0
565375	564338	11040E	PARTICIPANT	\N	PRESENT	0
565376	564338	19758L	PARTICIPANT	\N	PRESENT	0
565456	564338	08047A	PARTICIPANT	\N	PRESENT	0
565378	564338	19575F	PARTICIPANT	\N	PRESENT	0
565379	564338	20142Y	PARTICIPANT	\N	PRESENT	0
565380	564338	19347U	PARTICIPANT	\N	PRESENT	0
565381	564338	19693L	PARTICIPANT	\N	PRESENT	0
565382	564338	20110Q	PARTICIPANT	\N	PRESENT	0
565383	564338	11065P	PARTICIPANT	\N	PRESENT	0
565384	564338	11083R	PARTICIPANT	\N	PRESENT	0
565385	564338	19515S	PARTICIPANT	\N	PRESENT	0
565386	564338	19651A	PARTICIPANT	\N	PRESENT	0
565387	564338	04045F	PARTICIPANT	\N	PRESENT	0
565388	564338	04071H	PARTICIPANT	\N	PRESENT	0
565389	564338	19573D	PARTICIPANT	\N	PRESENT	0
565390	564338	20116W	PARTICIPANT	\N	PRESENT	0
565391	564338	11080N	PARTICIPANT	\N	PRESENT	0
565392	564338	19553Y	PARTICIPANT	\N	PRESENT	0
565393	564338	14033T	PARTICIPANT	\N	PRESENT	0
565394	564338	19721W	PARTICIPANT	\N	PRESENT	0
565395	564338	20134Y	PARTICIPANT	\N	PRESENT	0
565396	564338	19697Q	PARTICIPANT	\N	PRESENT	0
565397	564338	11099A	PARTICIPANT	\N	PRESENT	0
565398	564338	19621T	PARTICIPANT	\N	PRESENT	0
565399	564338	19671E	PARTICIPANT	\N	PRESENT	0
565400	564338	04057K	PARTICIPANT	\N	PRESENT	0
565401	564338	14111D	PARTICIPANT	\N	PRESENT	0
565402	564338	20024T	PARTICIPANT	\N	PRESENT	0
565403	564338	08017T	PARTICIPANT	\N	PRESENT	0
565404	564338	20080C	PARTICIPANT	\N	PRESENT	0
565405	564338	08034U	PARTICIPANT	\N	PRESENT	0
565406	564338	20104S	PARTICIPANT	\N	PRESENT	0
565407	564338	20114U	PARTICIPANT	\N	PRESENT	0
565408	564338	20070A	PARTICIPANT	\N	PRESENT	0
565409	564338	18083K	PARTICIPANT	\N	PRESENT	0
565410	564338	11074Q	PARTICIPANT	\N	PRESENT	0
565411	564338	11027H	PARTICIPANT	\N	PRESENT	0
565412	564338	04059M	PARTICIPANT	\N	PRESENT	0
565413	564338	01028R	PARTICIPANT	\N	PRESENT	0
565414	564338	14225N	PARTICIPANT	\N	PRESENT	0
565415	564338	11072N	PARTICIPANT	\N	PRESENT	0
565416	564338	19649G	PARTICIPANT	\N	PRESENT	0
565417	564338	14021P	PARTICIPANT	\N	PRESENT	0
565418	564338	20086J	PARTICIPANT	\N	PRESENT	0
565419	564338	01062T	PARTICIPANT	\N	PRESENT	0
565420	564338	11066Q	PARTICIPANT	\N	PRESENT	0
565421	564338	14001X	PARTICIPANT	\N	PRESENT	0
565422	564338	20124W	PARTICIPANT	\N	PRESENT	0
565423	564338	14229S	PARTICIPANT	\N	PRESENT	0
565424	564338	20126Y	PARTICIPANT	\N	PRESENT	0
565425	564338	18193Q	PARTICIPANT	\N	PRESENT	0
565426	564338	11097X	PARTICIPANT	\N	PRESENT	0
565427	564338	05008E	PARTICIPANT	\N	PRESENT	0
565428	564338	20082E	PARTICIPANT	\N	PRESENT	0
565429	564338	14071N	PARTICIPANT	\N	PRESENT	0
565430	564338	14151M	PARTICIPANT	\N	PRESENT	0
565431	564338	19503N	PARTICIPANT	\N	PRESENT	0
565432	564338	04043D	PARTICIPANT	\N	PRESENT	0
565433	564338	20038A	PARTICIPANT	\N	PRESENT	0
565434	564338	20050V	PARTICIPANT	\N	PRESENT	0
565435	564338	20064C	PARTICIPANT	\N	PRESENT	0
565436	564338	20118Y	PARTICIPANT	\N	PRESENT	0
565437	564338	14042U	PARTICIPANT	\N	PRESENT	0
565438	564338	14147R	PARTICIPANT	\N	PRESENT	0
565439	564338	19619A	PARTICIPANT	\N	PRESENT	0
565440	564338	19441R	PARTICIPANT	\N	PRESENT	0
565441	564338	20066E	PARTICIPANT	\N	PRESENT	0
565442	564338	14215L	PARTICIPANT	\N	PRESENT	0
565469	564338	95063L	PARTICIPANT	\N	PRESENT	0
565444	564338	04086Q	PARTICIPANT	\N	PRESENT	0
565445	564338	14231L	PARTICIPANT	\N	PRESENT	0
565446	564338	11010L	PARTICIPANT	\N	PRESENT	0
565447	564338	14253S	PARTICIPANT	\N	PRESENT	0
565448	564338	11085T	PARTICIPANT	\N	PRESENT	0
565449	564338	14041T	PARTICIPANT	\N	PRESENT	0
565450	564338	19701S	PARTICIPANT	\N	PRESENT	0
565451	564338	19369B	PARTICIPANT	\N	PRESENT	0
565452	564338	14205J	PARTICIPANT	\N	PRESENT	0
565453	564338	14026U	PARTICIPANT	\N	PRESENT	0
565454	564338	19685L	PARTICIPANT	\N	PRESENT	0
565455	564338	20032T	PARTICIPANT	\N	PRESENT	0
565465	564338	11031D	PARTICIPANT	\N	PRESENT	0
565466	564338	14219Q	PARTICIPANT	\N	PRESENT	0
565467	564338	01034P	PARTICIPANT	\N	PRESENT	0
565468	564338	04085P	PARTICIPANT	\N	PRESENT	0
565470	564338	17589D	PARTICIPANT	\N	PRESENT	0
565472	564338	20112S	PARTICIPANT	\N	PRESENT	0
565473	564338	20140W	PARTICIPANT	\N	PRESENT	0
565474	564338	01043Q	PARTICIPANT	\N	PRESENT	0
565475	564338	20136B	PARTICIPANT	\N	PRESENT	0
565476	564338	14083S	PARTICIPANT	\N	PRESENT	0
565477	564338	20042V	PARTICIPANT	\N	PRESENT	0
565478	564338	19631V	PARTICIPANT	\N	PRESENT	0
565479	564338	19591F	PARTICIPANT	\N	PRESENT	0
565487	564338	19251M	PARTICIPANT	\N	PRESENT	0
565493	564338	11053K	PARTICIPANT	\N	PRESENT	0
565496	564338	01057W	PARTICIPANT	\N	PRESENT	0
565497	564338	20100N	PARTICIPANT	\N	PRESENT	0
565498	564338	19551W	PARTICIPANT	\N	PRESENT	0
565704	564339	86034E	PARTICIPANT	\N	PRESENT	0
565705	564339	14026U	PARTICIPANT	\N	PRESENT	0
565706	564339	11090Q	PARTICIPANT	\N	PRESENT	0
565707	564339	08047A	PARTICIPANT	\N	PRESENT	0
565708	564339	10006L	PARTICIPANT	\N	PRESENT	0
565710	564339	14237S	PARTICIPANT	\N	PRESENT	0
565711	564339	19611R	PARTICIPANT	\N	PRESENT	0
565712	564339	04047H	PARTICIPANT	\N	PRESENT	0
565713	564339	14331P	PARTICIPANT	\N	PRESENT	0
565715	564339	14107H	PARTICIPANT	\N	PRESENT	0
565718	564339	11056N	PARTICIPANT	\N	PRESENT	0
565719	564339	20106U	PARTICIPANT	\N	PRESENT	0
565720	564339	19585H	PARTICIPANT	\N	PRESENT	0
565721	564339	19347U	PARTICIPANT	\N	PRESENT	0
565722	564339	20042V	PARTICIPANT	\N	PRESENT	0
565723	564339	14151M	PARTICIPANT	\N	PRESENT	0
565724	564339	14169X	PARTICIPANT	\N	PRESENT	0
565730	564339	14033T	PARTICIPANT	\N	PRESENT	0
565731	564339	12041X	PARTICIPANT	\N	PRESENT	0
565732	565714	19333N	PARTICIPANT	\N	PRESENT	0
565733	565714	19701S	PARTICIPANT	\N	PRESENT	0
565734	565714	20136B	PARTICIPANT	\N	PRESENT	0
565735	565714	14031R	PARTICIPANT	\N	PRESENT	0
565736	565714	20038A	PARTICIPANT	\N	PRESENT	0
565737	565714	20076G	PARTICIPANT	\N	PRESENT	0
565738	565714	19549D	PARTICIPANT	\N	PRESENT	0
542844	542843	08017T	PARTICIPANT	\N	PRESENT	1
542850	542848	19679N	PARTICIPANT	\N	PRESENT	0
542851	542849	19679N	PARTICIPANT	\N	PRESENT	0
542853	542852	14189C	PARTICIPANT	\N	PRESENT	0
542854	542852	19515S	PARTICIPANT	\N	PRESENT	0
542855	542852	14069U	PARTICIPANT	\N	PRESENT	0
542856	542852	19747H	PARTICIPANT	\N	PRESENT	0
542857	542852	19383Y	PARTICIPANT	\N	PRESENT	0
542858	542852	20090E	PARTICIPANT	\N	PRESENT	0
542859	542852	19782L	PARTICIPANT	\N	PRESENT	0
542860	542852	14083S	PARTICIPANT	\N	PRESENT	0
542861	542852	20144B	PARTICIPANT	\N	PRESENT	0
542862	542852	19467C	PARTICIPANT	\N	PRESENT	0
542863	542852	18083K	PARTICIPANT	\N	PRESENT	0
542864	542852	20140W	PARTICIPANT	\N	PRESENT	0
542865	542852	14041T	PARTICIPANT	\N	PRESENT	0
542866	542852	01024M	PARTICIPANT	\N	PRESENT	0
542867	542852	19507S	PARTICIPANT	\N	PRESENT	0
542868	542852	01025N	PARTICIPANT	\N	PRESENT	0
542869	542852	20172F	PARTICIPANT	\N	PRESENT	0
542870	542852	19399H	PARTICIPANT	\N	PRESENT	0
542871	542852	19511N	PARTICIPANT	\N	PRESENT	0
542872	542852	19531S	PARTICIPANT	\N	PRESENT	0
542873	542852	07029T	PARTICIPANT	\N	PRESENT	0
542874	542852	19441R	PARTICIPANT	\N	PRESENT	0
542875	542852	19637C	PARTICIPANT	\N	PRESENT	0
542876	542852	20018V	PARTICIPANT	\N	PRESENT	0
542877	542852	20096L	PARTICIPANT	\N	PRESENT	0
542878	542852	14169X	PARTICIPANT	\N	PRESENT	0
542879	542852	20118Y	PARTICIPANT	\N	PRESENT	0
542880	542852	19798U	PARTICIPANT	\N	PRESENT	0
542881	542852	20054A	PARTICIPANT	\N	PRESENT	0
542882	542852	04045F	PARTICIPANT	\N	PRESENT	0
542883	542852	19762G	PARTICIPANT	\N	PRESENT	0
542884	542852	20026V	PARTICIPANT	\N	PRESENT	0
542885	542852	16685X	PARTICIPANT	\N	PRESENT	0
542886	542852	14059S	PARTICIPANT	\N	PRESENT	0
545017	545015	14195A	PARTICIPANT	\N	PRESENT	0
545018	545015	20130U	PARTICIPANT	\N	PRESENT	0
545019	545015	19679N	PARTICIPANT	\N	PRESENT	0
545021	545020	14195A	PARTICIPANT	\N	PRESENT	0
545022	545020	20066E	PARTICIPANT	\N	PRESENT	0
545023	545020	19679N	PARTICIPANT	\N	PRESENT	0
545024	545020	20130U	PARTICIPANT	\N	PRESENT	0
545025	545016	14195A	PARTICIPANT	\N	PRESENT	0
545035	545033	14195A	PARTICIPANT	\N	PRESENT	0
545036	545033	20130U	PARTICIPANT	\N	PRESENT	0
545050	545048	14195A	PARTICIPANT	\N	PRESENT	0
545051	545048	19553Y	PARTICIPANT	\N	PRESENT	0
545052	545048	20130U	PARTICIPANT	\N	PRESENT	0
545054	544995	14195A	PARTICIPANT	\N	PRESENT	0
545055	544995	19553Y	PARTICIPANT	\N	PRESENT	0
545056	544995	20130U	PARTICIPANT	\N	PRESENT	0
545577	545576	19503N	PARTICIPANT	\N	PRESENT	0
545578	545576	19820Y	PARTICIPANT	\N	PRESENT	0
545579	545576	19619A	PARTICIPANT	\N	PRESENT	0
545580	545576	14357A	PARTICIPANT	\N	PRESENT	0
545583	545582	08017T	PARTICIPANT	\N	PRESENT	1
545584	545581	19503N	PARTICIPANT	\N	PRESENT	0
545585	545581	19820Y	PARTICIPANT	\N	PRESENT	0
545586	545581	19619A	PARTICIPANT	\N	PRESENT	0
545587	545581	14357A	PARTICIPANT	\N	PRESENT	0
545588	545581	20092G	PARTICIPANT	\N	PRESENT	0
545589	545576	20092G	PARTICIPANT	\N	PRESENT	0
545591	545590	19503N	PARTICIPANT	\N	PRESENT	0
545592	545590	19820Y	PARTICIPANT	\N	PRESENT	0
545593	545590	19619A	PARTICIPANT	\N	PRESENT	0
545594	545590	14357A	PARTICIPANT	\N	PRESENT	0
545595	545590	20092G	PARTICIPANT	\N	PRESENT	0
545596	545590	20126Y	PARTICIPANT	\N	PRESENT	0
545598	545597	08017T	PARTICIPANT	\N	PRESENT	1
547777	545409	12041X	PARTICIPANT	\N	PRESENT	0
547786	545409	11070L	PARTICIPANT	\N	PRESENT	0
547787	545409	14225N	PARTICIPANT	\N	PRESENT	0
547788	545409	20084G	PARTICIPANT	\N	PRESENT	0
547789	545409	11040E	PARTICIPANT	\N	PRESENT	0
547790	545409	14111D	PARTICIPANT	\N	PRESENT	0
547791	545409	14083S	PARTICIPANT	\N	PRESENT	0
547792	545409	14189C	PARTICIPANT	\N	PRESENT	0
547793	545409	20150Y	PARTICIPANT	\N	PRESENT	0
547794	545409	04034C	PARTICIPANT	\N	PRESENT	0
547795	545409	19443T	PARTICIPANT	\N	PRESENT	0
547796	545409	08010L	PARTICIPANT	\N	PRESENT	0
547797	545409	19581D	PARTICIPANT	\N	PRESENT	0
547798	545409	08069G	PARTICIPANT	\N	PRESENT	0
547813	545409	19599P	PARTICIPANT	\N	PRESENT	0
547800	545409	20080C	PARTICIPANT	\N	PRESENT	0
547802	545409	20036X	PARTICIPANT	\N	PRESENT	0
547803	545409	20090E	PARTICIPANT	\N	PRESENT	0
547804	545409	20122U	PARTICIPANT	\N	PRESENT	0
547805	545409	11012A	PARTICIPANT	\N	PRESENT	0
547806	545409	20116W	PARTICIPANT	\N	PRESENT	0
547807	545409	18083K	PARTICIPANT	\N	PRESENT	0
547808	545409	19629C	PARTICIPANT	\N	PRESENT	0
547809	545409	19687N	PARTICIPANT	\N	PRESENT	0
547810	545409	19543W	PARTICIPANT	\N	PRESENT	0
547811	545409	19531S	PARTICIPANT	\N	PRESENT	0
547812	545409	20070A	PARTICIPANT	\N	PRESENT	0
547814	545409	19762G	PARTICIPANT	\N	PRESENT	0
547815	545409	01048V	PARTICIPANT	\N	PRESENT	0
547816	545409	19367Y	PARTICIPANT	\N	PRESENT	0
547817	545409	20048C	PARTICIPANT	\N	PRESENT	0
547822	545409	14123H	PARTICIPANT	\N	PRESENT	0
547823	545409	19741B	PARTICIPANT	\N	PRESENT	0
547824	545409	01024M	PARTICIPANT	\N	PRESENT	0
547825	545409	11048N	PARTICIPANT	\N	PRESENT	0
547832	547818	20090E	PARTICIPANT	\N	PRESENT	0
547833	547818	11067R	PARTICIPANT	\N	PRESENT	0
547834	547818	20048C	PRESIDENT	0	PRESENT	0
547835	547818	17779H	PARTICIPANT	\N	PRESENT	0
547847	545409	20152B	PARTICIPANT	\N	PRESENT	0
547848	545409	20034V	PARTICIPANT	\N	PRESENT	0
547849	545409	19565D	PARTICIPANT	\N	PRESENT	0
547888	545410	04034C	PARTICIPANT	\N	PRESENT	0
547889	545410	20150Y	PARTICIPANT	\N	PRESENT	0
547894	545410	20116W	PARTICIPANT	\N	PRESENT	0
547895	545410	14111D	PARTICIPANT	\N	PRESENT	0
547896	545410	20122U	PARTICIPANT	\N	PRESENT	0
547897	545410	11040E	PARTICIPANT	\N	PRESENT	0
547898	545410	14189C	PARTICIPANT	\N	PRESENT	0
547899	545410	01024M	PARTICIPANT	\N	PRESENT	0
547900	545410	20036X	PARTICIPANT	\N	PRESENT	0
547901	545410	19762G	PARTICIPANT	\N	PRESENT	0
547902	545410	11048N	PARTICIPANT	\N	PRESENT	0
547903	545410	20152B	PARTICIPANT	\N	PRESENT	0
547904	545410	19367Y	PARTICIPANT	\N	PRESENT	0
547905	545410	19581D	PARTICIPANT	\N	PRESENT	0
547906	545410	01048V	PARTICIPANT	\N	PRESENT	0
547907	545410	20034V	PARTICIPANT	\N	PRESENT	0
547908	545410	14225N	PARTICIPANT	\N	PRESENT	0
547920	545410	11012A	PARTICIPANT	\N	PRESENT	0
547910	545410	20080C	PARTICIPANT	\N	PRESENT	0
547912	545410	19565D	PARTICIPANT	\N	PRESENT	0
547915	545410	20082E	PARTICIPANT	\N	PRESENT	0
547916	545410	14123H	PARTICIPANT	\N	PRESENT	0
547919	545410	14030Q	PARTICIPANT	\N	PRESENT	0
547921	545410	14073Q	PARTICIPANT	\N	PRESENT	0
547922	545410	14083S	PARTICIPANT	\N	PRESENT	0
547923	547818	20062A	PARTICIPANT	\N	PRESENT	1
547924	547818	19651A	PARTICIPANT	\N	PRESENT	1
547925	547818	20052X	PARTICIPANT	\N	PRESENT	1
547926	547818	20084G	PARTICIPANT	\N	PRESENT	0
547885	545410	12041X	PARTICIPANT	\N	PRESENT	0
547887	545410	08011M	PARTICIPANT	\N	PRESENT	0
561560	559655	14179A	PARTICIPANT	\N	PRESENT	0
561561	559487	14205J	PARTICIPANT	\N	PRESENT	1
561562	559655	20126Y	PARTICIPANT	\N	PRESENT	0
561569	559487	04042C	PARTICIPANT	\N	PRESENT	0
561570	559487	10015M	PARTICIPANT	\N	PRESENT	0
561580	559655	20086J	PARTICIPANT	\N	PRESENT	0
561612	559655	19673G	PARTICIPANT	\N	PRESENT	0
561618	559487	08034U	PARTICIPANT	\N	PRESENT	0
561624	559678	14097Y	PARTICIPANT	\N	PRESENT	0
561625	559678	12041X	PARTICIPANT	\N	PRESENT	0
561626	559678	04034C	PARTICIPANT	\N	PRESENT	0
561627	559678	14267Y	PARTICIPANT	\N	PRESENT	0
561628	559678	14193X	PARTICIPANT	\N	PRESENT	0
561629	559678	01058X	PARTICIPANT	\N	PRESENT	1
561630	559678	16685X	PARTICIPANT	\N	PRESENT	0
561631	559678	04042C	PRESIDENT	0	PRESENT	0
561632	559678	14255U	PARTICIPANT	\N	PRESENT	0
561633	559678	19721W	PARTICIPANT	\N	PRESENT	1
561634	559678	17023S	PARTICIPANT	\N	PRESENT	0
561635	559655	11064N	PARTICIPANT	\N	PRESENT	0
561636	559655	19681G	PARTICIPANT	\N	PRESENT	0
561637	559655	20132W	PARTICIPANT	\N	PRESENT	0
561646	559539	14225N	PRESIDENT	0	PRESENT	0
561639	559655	18083K	PARTICIPANT	\N	PRESENT	0
561640	559655	20070A	PARTICIPANT	\N	PRESENT	0
561645	559487	14105F	PARTICIPANT	\N	PRESENT	1
561647	559539	14189C	PARTICIPANT	\N	EXCUSE	0
561648	559539	20050V	PARTICIPANT	\N	EXCUSE	0
561650	559655	14083S	PARTICIPANT	\N	PRESENT	0
561666	559539	04086Q	PARTICIPANT	\N	PRESENT	0
561667	559539	14083S	PARTICIPANT	\N	PRESENT	0
561668	559539	11048N	PARTICIPANT	\N	PRESENT	0
561669	559539	20070A	PARTICIPANT	\N	PRESENT	0
561670	559539	14121F	PARTICIPANT	\N	PRESENT	0
561671	559539	99004R	PARTICIPANT	\N	PRESENT	0
561672	559539	20116W	PARTICIPANT	\N	PRESENT	0
561673	559539	19667J	PARTICIPANT	\N	PRESENT	0
561674	559539	20044X	PARTICIPANT	\N	PRESENT	0
561675	559539	20022R	PARTICIPANT	\N	PRESENT	0
561677	559655	14033T	PARTICIPANT	\N	PRESENT	0
561678	559655	14123H	PARTICIPANT	\N	PRESENT	0
561684	559678	19515S	PARTICIPANT	\N	PRESENT	0
561685	559678	14357A	PARTICIPANT	\N	PRESENT	0
561686	559678	19441R	PARTICIPANT	\N	PRESENT	0
561687	559678	19413M	PARTICIPANT	\N	PRESENT	0
561688	559678	11099A	PARTICIPANT	\N	PRESENT	0
561689	559678	19705W	PARTICIPANT	\N	PRESENT	0
561690	559678	19575F	PARTICIPANT	\N	PRESENT	0
561691	559678	19711U	PARTICIPANT	\N	PRESENT	0
561692	559678	04057K	PARTICIPANT	\N	PRESENT	0
561693	559678	14189C	PARTICIPANT	\N	PRESENT	0
561694	559678	08034U	PARTICIPANT	\N	PRESENT	0
561695	559678	14073Q	PARTICIPANT	\N	PRESENT	0
561696	559678	11026G	PARTICIPANT	\N	PRESENT	0
561697	559678	10015M	PARTICIPANT	\N	PRESENT	0
561698	559678	20144B	PARTICIPANT	\N	PRESENT	0
561699	559678	19695N	PARTICIPANT	\N	PRESENT	0
561700	559678	14033T	PARTICIPANT	\N	PRESENT	0
561701	559678	01025N	PARTICIPANT	\N	PRESENT	0
561702	559678	11090Q	PARTICIPANT	\N	PRESENT	0
561703	559678	20062A	PARTICIPANT	\N	PRESENT	0
561704	559678	14207L	PARTICIPANT	\N	PRESENT	0
561705	559678	19747H	PARTICIPANT	\N	PRESENT	0
561725	559539	19647E	PARTICIPANT	\N	PRESENT	0
561726	559539	08034U	PARTICIPANT	\N	PRESENT	0
561727	559539	01057W	PARTICIPANT	\N	PRESENT	0
561728	559539	08010L	PARTICIPANT	\N	PRESENT	0
561729	559539	20126Y	PARTICIPANT	\N	PRESENT	0
561730	559655	19333N	PARTICIPANT	\N	PRESENT	0
561731	559655	19551W	PARTICIPANT	\N	PRESENT	0
561733	559655	19747H	PARTICIPANT	\N	PRESENT	0
561734	559655	14357A	PARTICIPANT	\N	PRESENT	0
561741	559655	19695N	PARTICIPANT	\N	PRESENT	0
561745	559655	20116W	PARTICIPANT	\N	PRESENT	0
561746	559655	20142Y	PARTICIPANT	\N	PRESENT	0
561747	559655	20048C	PARTICIPANT	\N	PRESENT	0
561748	559655	11065P	PARTICIPANT	\N	PRESENT	0
561749	559655	14215L	PARTICIPANT	\N	PRESENT	0
561751	559655	05008E	PARTICIPANT	\N	PRESENT	0
561752	559655	14021P	PARTICIPANT	\N	PRESENT	0
561793	556324	19651A	PARTICIPANT	\N	PRESENT	0
561794	556324	11040E	PARTICIPANT	\N	PRESENT	0
561795	556324	20042V	PARTICIPANT	\N	PRESENT	0
561796	556324	19643A	PARTICIPANT	\N	PRESENT	0
561797	556324	11056N	PARTICIPANT	\N	PRESENT	0
561798	556324	04071H	PARTICIPANT	\N	PRESENT	0
561799	556324	20132W	PARTICIPANT	\N	PRESENT	0
561800	556324	19551W	PARTICIPANT	\N	PRESENT	0
561801	556324	19711U	PARTICIPANT	\N	PRESENT	0
561802	556324	20018V	PARTICIPANT	\N	PRESENT	0
561803	556324	20050V	PARTICIPANT	\N	PRESENT	0
561804	556324	20044X	PARTICIPANT	\N	PRESENT	0
561805	556324	19479G	PARTICIPANT	\N	PRESENT	0
561835	559960	19515S	PARTICIPANT	\N	PRESENT	0
561836	559960	14105F	PARTICIPANT	\N	PRESENT	0
561837	559960	20060X	PARTICIPANT	\N	PRESENT	0
561838	559960	19467C	PARTICIPANT	\N	PRESENT	0
561840	559960	19695N	PARTICIPANT	\N	PRESENT	0
561842	559960	14031R	PARTICIPANT	\N	PRESENT	0
561843	559960	19671E	PARTICIPANT	\N	PRESENT	0
561845	559960	20082E	PARTICIPANT	\N	PRESENT	0
561846	559960	20092G	PARTICIPANT	\N	PRESENT	0
561849	559960	19760E	PARTICIPANT	\N	EXCUSE	0
561851	559960	14030Q	PARTICIPANT	\N	EXCUSE	0
561853	559960	08028W	PARTICIPANT	\N	EXCUSE	0
561855	559960	20126Y	PARTICIPANT	\N	EXCUSE	0
561857	559960	08015R	PARTICIPANT	\N	EXCUSE	0
561859	559960	20054A	PARTICIPANT	\N	EXCUSE	0
561884	561883	19711U	PARTICIPANT	\N	PRESENT	0
561889	561886	20022R	PARTICIPANT	\N	PRESENT	0
561890	561886	14331P	PARTICIPANT	\N	PRESENT	0
561892	561887	20022R	PARTICIPANT	\N	PRESENT	0
561893	561887	14331P	PARTICIPANT	\N	PRESENT	0
561946	561943	05008E	PARTICIPANT	\N	PRESENT	0
561947	561943	11033F	PARTICIPANT	\N	PRESENT	0
561948	561943	11053K	PARTICIPANT	\N	PRESENT	0
561949	561943	14357A	PARTICIPANT	\N	PRESENT	0
561950	561943	11070L	PARTICIPANT	\N	PRESENT	0
561951	561943	19719D	PARTICIPANT	\N	PRESENT	0
561952	561943	19673G	PARTICIPANT	\N	PRESENT	0
561953	561943	01025N	PARTICIPANT	\N	PRESENT	0
561954	561943	19599P	PARTICIPANT	\N	PRESENT	0
561955	561943	14033T	PARTICIPANT	\N	PRESENT	0
561956	561943	14123H	PARTICIPANT	\N	PRESENT	0
561957	561943	14026U	PARTICIPANT	\N	PRESENT	0
561958	561943	11064N	PARTICIPANT	\N	PRESENT	0
561959	561943	14179A	PARTICIPANT	\N	PRESENT	0
561960	561943	14213J	PARTICIPANT	\N	PRESENT	0
562081	559845	19447X	PARTICIPANT	\N	PRESENT	1
561962	561943	99004R	PARTICIPANT	\N	PRESENT	0
561963	561943	86034E	PARTICIPANT	\N	PRESENT	0
561964	561943	12041X	PARTICIPANT	\N	PRESENT	0
562079	559845	14189C	PARTICIPANT	\N	PRESENT	0
561966	561943	14147R	PARTICIPANT	\N	PRESENT	0
562080	559845	14207L	PARTICIPANT	\N	PRESENT	1
561968	561943	11045K	PARTICIPANT	\N	PRESENT	0
561969	561943	04045F	PARTICIPANT	\N	PRESENT	0
561970	561943	01028R	PARTICIPANT	\N	PRESENT	0
561971	561943	19413M	PARTICIPANT	\N	PRESENT	0
562082	559845	99004R	PARTICIPANT	\N	PRESENT	0
561558	559655	11097X	PARTICIPANT	\N	PRESENT	0
561559	559487	16685X	PARTICIPANT	\N	PRESENT	0
562083	559845	19705W	PARTICIPANT	\N	PRESENT	1
562084	559845	20030R	PARTICIPANT	\N	PRESENT	1
562102	562101	14097Y	PARTICIPANT	\N	PRESENT	0
562103	562101	14133K	PARTICIPANT	\N	PRESENT	0
562104	562101	11083R	PARTICIPANT	\N	PRESENT	0
562105	562101	98022P	PARTICIPANT	\N	PRESENT	0
562107	562106	14097Y	PARTICIPANT	\N	PRESENT	0
562108	562106	14133K	PARTICIPANT	\N	PRESENT	0
562109	562106	11083R	PARTICIPANT	\N	PRESENT	0
562111	562110	11048N	PARTICIPANT	\N	PRESENT	0
562112	562110	14225N	PARTICIPANT	\N	PRESENT	0
562114	558019	14215L	PARTICIPANT	\N	EXCUSE	0
562117	562116	19545Y	PARTICIPANT	\N	PRESENT	0
562118	562116	19689Q	PARTICIPANT	\N	PRESENT	0
562124	562120	14225N	PARTICIPANT	\N	PRESENT	0
562125	562120	01057W	PARTICIPANT	\N	PRESENT	0
562162	562057	20060X	PARTICIPANT	\N	PRESENT	0
562163	562057	19671E	PARTICIPANT	\N	PRESENT	0
544963	542826	08060W	PARTICIPANT	\N	PRESENT	1
544964	542826	19701S	PARTICIPANT	\N	PRESENT	1
544965	542826	19387D	PARTICIPANT	\N	PRESENT	1
544966	542826	20106U	PARTICIPANT	\N	PRESENT	1
544967	542826	19551W	PARTICIPANT	\N	PRESENT	1
544968	542826	19637C	PARTICIPANT	\N	PRESENT	1
544971	542826	14169X	PARTICIPANT	\N	PRESENT	1
544972	542826	19745F	PARTICIPANT	\N	PRESENT	1
544973	542826	19619A	PARTICIPANT	\N	PRESENT	1
544980	542826	04085P	PARTICIPANT	\N	PRESENT	1
544981	542826	19629C	PARTICIPANT	\N	PRESENT	1
544982	542826	19447X	PARTICIPANT	\N	PRESENT	1
544983	542826	19649G	PARTICIPANT	\N	PRESENT	1
544984	542826	11026G	PARTICIPANT	\N	PRESENT	1
544985	542826	95063L	PARTICIPANT	\N	PRESENT	1
545527	545526	04085P	PARTICIPANT	\N	PRESENT	0
545528	545526	04047H	PARTICIPANT	\N	PRESENT	0
545529	545526	04042C	PARTICIPANT	\N	PRESENT	0
545530	545526	14038Y	PARTICIPANT	\N	PRESENT	0
545531	545526	11070L	PARTICIPANT	\N	PRESENT	0
545532	545526	19719D	PARTICIPANT	\N	PRESENT	0
545533	545526	10006L	PARTICIPANT	\N	PRESENT	0
545534	545526	14215L	PARTICIPANT	\N	PRESENT	0
545535	545526	19347U	PARTICIPANT	\N	PRESENT	0
545536	545526	14026U	PARTICIPANT	\N	PRESENT	0
545537	545526	11048N	PARTICIPANT	\N	PRESENT	0
545538	545526	19591F	PARTICIPANT	\N	PRESENT	0
545539	545526	14021P	PARTICIPANT	\N	PRESENT	0
545540	545526	99004R	PARTICIPANT	\N	PRESENT	0
545541	545526	19611R	PARTICIPANT	\N	PRESENT	0
545542	545526	12041X	PARTICIPANT	\N	PRESENT	0
545543	545526	01043Q	PARTICIPANT	\N	PRESENT	0
545544	545526	14219Q	PARTICIPANT	\N	PRESENT	0
545545	545526	14251Q	PARTICIPANT	\N	PRESENT	0
545546	545526	14071N	PARTICIPANT	\N	PRESENT	0
545547	545526	08073C	PARTICIPANT	\N	PRESENT	0
545548	545526	14331P	PARTICIPANT	\N	PRESENT	0
545549	545526	14225N	PARTICIPANT	\N	PRESENT	0
545550	545526	11012A	PARTICIPANT	\N	PRESENT	0
545551	545526	11045K	PARTICIPANT	\N	PRESENT	0
545552	545526	01028R	PARTICIPANT	\N	PRESENT	0
545553	545526	01034P	PARTICIPANT	\N	PRESENT	0
545563	545562	08034U	PARTICIPANT	\N	PRESENT	0
545565	545564	08034U	PARTICIPANT	\N	PRESENT	0
545567	545566	11074Q	PARTICIPANT	\N	PRESENT	0
545568	545566	19349W	PARTICIPANT	\N	PRESENT	0
545570	545569	20050V	PARTICIPANT	\N	PRESENT	0
545572	545571	01048V	PARTICIPANT	\N	PRESENT	0
545611	545610	20116W	PARTICIPANT	\N	PRESENT	0
545612	545610	11040E	PARTICIPANT	\N	PRESENT	0
545613	545610	11048N	PARTICIPANT	\N	PRESENT	0
545614	545610	20126Y	PARTICIPANT	\N	PRESENT	0
545615	545610	12016W	PARTICIPANT	\N	PRESENT	0
545616	545610	20050V	PARTICIPANT	\N	PRESENT	0
545617	545610	08073C	PARTICIPANT	\N	PRESENT	0
545618	545610	14225N	PARTICIPANT	\N	PRESENT	0
545619	545610	19689Q	PARTICIPANT	\N	PRESENT	0
545620	545610	19479G	PARTICIPANT	\N	PRESENT	0
546536	546514	14133K	PARTICIPANT	\N	PRESENT	0
546537	546514	20042V	PARTICIPANT	\N	PRESENT	0
546538	546514	18083K	PARTICIPANT	\N	PRESENT	0
546539	546514	14097Y	PARTICIPANT	\N	PRESENT	0
546540	546514	19709B	PARTICIPANT	\N	PRESENT	0
546557	546514	14059S	PARTICIPANT	\N	PRESENT	0
546558	546514	19503N	PARTICIPANT	\N	PRESENT	0
546559	546514	19713W	PARTICIPANT	\N	PRESENT	0
546560	546514	20064C	PARTICIPANT	\N	PRESENT	0
546825	544339	20076G	PARTICIPANT	\N	PRESENT	0
546826	544339	20024T	PARTICIPANT	\N	PRESENT	0
546827	544339	19549D	PARTICIPANT	\N	PRESENT	0
546828	544339	17367Q	PARTICIPANT	\N	PRESENT	0
546829	544339	08060W	PARTICIPANT	\N	PRESENT	1
546830	544339	18083K	PARTICIPANT	\N	PRESENT	0
546831	544339	11065P	PARTICIPANT	\N	PRESENT	0
546832	544339	20140W	PARTICIPANT	\N	PRESENT	0
546833	544339	17229F	PARTICIPANT	\N	PRESENT	0
546834	544339	19251M	PARTICIPANT	\N	PRESENT	1
546835	544339	20038A	PARTICIPANT	\N	PRESENT	0
546836	544339	20100N	PARTICIPANT	\N	PRESENT	0
546837	544339	19599P	PARTICIPANT	\N	PRESENT	0
546838	544339	20120S	PARTICIPANT	\N	PRESENT	1
546839	544339	19820Y	PARTICIPANT	\N	PRESENT	0
546840	544339	19387D	PARTICIPANT	\N	PRESENT	0
546841	544339	20068G	PARTICIPANT	\N	PRESENT	0
546842	544339	19685L	PARTICIPANT	\N	PRESENT	0
546843	544339	19551W	PARTICIPANT	\N	PRESENT	0
546844	544339	20102Q	PARTICIPANT	\N	PRESENT	0
546845	544339	19333N	PARTICIPANT	\N	PRESENT	0
546846	544339	20106U	PARTICIPANT	\N	PRESENT	1
546847	544339	14219Q	PRESIDENT	0	PRESENT	0
546848	544339	19826F	PARTICIPANT	\N	PRESENT	0
546849	544339	14221J	PARTICIPANT	\N	PRESENT	0
546850	544339	20096L	PARTICIPANT	\N	PRESENT	0
546851	544339	14169X	PARTICIPANT	\N	PRESENT	0
546852	544339	19637C	PARTICIPANT	\N	PRESENT	0
546853	544339	14031R	PARTICIPANT	\N	PRESENT	0
546854	544339	17637T	PARTICIPANT	\N	PRESENT	0
546855	544339	19745F	PARTICIPANT	\N	PRESENT	0
546856	544339	20118Y	PARTICIPANT	\N	PRESENT	0
546857	544339	05012A	PARTICIPANT	\N	PRESENT	0
546858	544339	19503N	PARTICIPANT	\N	PRESENT	0
546859	544339	19739H	PARTICIPANT	\N	PRESENT	0
546860	544339	20020P	PARTICIPANT	\N	PRESENT	0
546861	544339	20136B	PARTICIPANT	\N	PRESENT	0
546862	544339	20046A	PARTICIPANT	\N	PRESENT	0
549589	547892	14223L	PARTICIPANT	\N	PRESENT	1
549590	547892	19591F	PARTICIPANT	\N	PRESENT	1
549591	547892	08045X	PARTICIPANT	\N	PRESENT	1
549592	547892	19798U	PARTICIPANT	\N	PRESENT	1
549645	547892	20066E	PARTICIPANT	\N	PRESENT	0
549656	547892	14026U	PARTICIPANT	\N	PRESENT	0
549657	547892	19715Y	PARTICIPANT	\N	PRESENT	1
549658	547892	19657G	PARTICIPANT	\N	PRESENT	1
549665	547892	04057K	PARTICIPANT	\N	PRESENT	0
549693	547892	19415P	PARTICIPANT	\N	PRESENT	1
549695	547893	14223L	PARTICIPANT	\N	PRESENT	1
549696	547893	19569H	PARTICIPANT	\N	PRESENT	1
549697	547893	20148F	PARTICIPANT	\N	PRESENT	1
549698	547893	19697Q	PARTICIPANT	\N	PRESENT	1
549699	547893	14213J	PARTICIPANT	\N	PRESENT	1
549700	547893	14042U	PARTICIPANT	\N	PRESENT	1
549701	547893	20130U	PARTICIPANT	\N	PRESENT	1
549702	547893	11103C	PARTICIPANT	\N	PRESENT	1
549703	547893	20172F	PARTICIPANT	\N	PRESENT	1
549704	547893	19553Y	PARTICIPANT	\N	PRESENT	1
549705	547893	08045X	PARTICIPANT	\N	PRESENT	1
549706	547893	19591F	PARTICIPANT	\N	PRESENT	1
549707	547893	19657G	PARTICIPANT	\N	PRESENT	1
549708	547893	19715Y	PARTICIPANT	\N	PRESENT	1
549709	547893	19415P	PARTICIPANT	\N	PRESENT	1
549710	547893	19679N	PARTICIPANT	\N	PRESENT	1
549711	547893	19717B	PARTICIPANT	\N	PRESENT	1
549712	547893	19367Y	PARTICIPANT	\N	EXCUSE	0
549713	547893	20090E	PARTICIPANT	\N	PRESENT	0
549714	547893	14195A	PARTICIPANT	\N	PRESENT	0
549715	547893	10006L	PRESIDENT	0	PRESENT	0
549716	547893	14217N	PARTICIPANT	\N	PRESENT	0
549717	547893	20040T	PARTICIPANT	\N	PRESENT	0
549718	547893	14026U	PARTICIPANT	\N	PRESENT	0
549719	547893	19691J	PARTICIPANT	\N	PRESENT	0
549720	547893	19723Y	PARTICIPANT	\N	PRESENT	0
549721	547893	04057K	PARTICIPANT	\N	PRESENT	0
549722	547893	11067R	PARTICIPANT	\N	PRESENT	0
549723	547893	14071N	PARTICIPANT	\N	PRESENT	0
549724	547893	19301E	PARTICIPANT	\N	PRESENT	0
549725	547893	19713W	PARTICIPANT	\N	PRESENT	0
549726	547893	19703U	PARTICIPANT	\N	PRESENT	0
549727	547893	11097X	PARTICIPANT	\N	PRESENT	0
549728	547892	19301E	PARTICIPANT	\N	PRESENT	0
549729	547893	18193Q	PARTICIPANT	\N	PRESENT	0
549730	547893	17779H	PARTICIPANT	\N	PRESENT	0
549731	547892	17779H	PARTICIPANT	\N	PRESENT	0
549794	547893	20066E	PARTICIPANT	\N	PRESENT	0
549795	547893	14355X	PARTICIPANT	\N	PRESENT	1
550142	550141	08060W	PARTICIPANT	\N	PRESENT	0
550143	550141	18083K	PARTICIPANT	\N	PRESENT	0
550145	550141	17229F	PARTICIPANT	\N	PRESENT	0
550146	550141	20038A	PARTICIPANT	\N	PRESENT	0
550147	550141	19387D	PARTICIPANT	\N	PRESENT	0
565739	565714	14219Q	PRESIDENT	0	PRESENT	0
565740	565714	19826F	PARTICIPANT	\N	PRESENT	0
565741	565714	19599P	PARTICIPANT	\N	PRESENT	0
565742	565714	17229F	PARTICIPANT	\N	PRESENT	0
565743	565714	19637C	PARTICIPANT	\N	PRESENT	0
565744	565714	19551W	PARTICIPANT	\N	PRESENT	0
565745	565714	20100N	PARTICIPANT	\N	PRESENT	0
565746	565714	18083K	PARTICIPANT	\N	PRESENT	0
565747	565714	19503N	PARTICIPANT	\N	PRESENT	0
565748	565714	20020P	PARTICIPANT	\N	PRESENT	0
565749	565714	19745F	PARTICIPANT	\N	PRESENT	0
565751	565714	19251M	PARTICIPANT	\N	PRESENT	0
565752	565714	20046A	PARTICIPANT	\N	PRESENT	0
565753	565714	20102Q	PARTICIPANT	\N	PRESENT	0
565754	565714	17367Q	PARTICIPANT	\N	PRESENT	0
565755	565714	11065P	PARTICIPANT	\N	PRESENT	0
565756	565714	19619A	PARTICIPANT	\N	PRESENT	0
565757	565714	20106U	PARTICIPANT	\N	PRESENT	0
565758	564339	14189C	PARTICIPANT	\N	PRESENT	0
565759	564339	01043Q	PARTICIPANT	\N	PRESENT	0
565760	564339	20180F	PARTICIPANT	\N	PRESENT	0
565761	564339	14147R	PARTICIPANT	\N	PRESENT	0
565762	564339	14207L	PARTICIPANT	\N	PRESENT	0
565763	564339	11074Q	PARTICIPANT	\N	PRESENT	0
565764	564339	19467C	PARTICIPANT	\N	PRESENT	0
565765	564339	01058X	PARTICIPANT	\N	PRESENT	0
565766	564339	20048C	PARTICIPANT	\N	PRESENT	0
565767	564339	20062A	PARTICIPANT	\N	PRESENT	0
565768	564339	20024T	PARTICIPANT	\N	PRESENT	0
565769	564339	01024M	PARTICIPANT	\N	PRESENT	0
565770	564339	19631V	PARTICIPANT	\N	PRESENT	0
565772	565771	08034U	PARTICIPANT	\N	PRESENT	0
565773	564339	17589D	PARTICIPANT	\N	PRESENT	0
565774	564339	11097X	PARTICIPANT	\N	PRESENT	0
565775	564339	20082E	PARTICIPANT	\N	PRESENT	0
565776	564339	20028X	PARTICIPANT	\N	PRESENT	0
565777	564387	14327T	PARTICIPANT	\N	PRESENT	0
565778	564387	19479G	PARTICIPANT	\N	PRESENT	0
565779	564387	11048N	PARTICIPANT	\N	PRESENT	0
565780	564387	19711U	PRESIDENT	0	PRESENT	0
565781	564387	14189C	PARTICIPANT	\N	PRESENT	0
565782	564387	01048V	PARTICIPANT	\N	PRESENT	0
565783	564387	08034U	PARTICIPANT	\N	PRESENT	0
565784	564387	19687N	PARTICIPANT	\N	PRESENT	0
565785	564387	01057W	PARTICIPANT	\N	PRESENT	0
565786	564387	19689Q	PARTICIPANT	\N	PRESENT	0
565787	564387	11053K	PARTICIPANT	\N	PRESENT	0
565788	564387	19667J	PARTICIPANT	\N	PRESENT	0
565789	564387	11070L	PARTICIPANT	\N	PRESENT	0
565790	564387	19671E	PARTICIPANT	\N	PRESENT	0
565791	564387	04086Q	PARTICIPANT	\N	PRESENT	0
565792	564387	07029T	PARTICIPANT	\N	PRESENT	0
565793	564387	20070A	PARTICIPANT	\N	PRESENT	0
565794	564387	19349W	PARTICIPANT	\N	PRESENT	0
565795	564387	08010L	PARTICIPANT	\N	PRESENT	0
565796	564387	19741B	PARTICIPANT	\N	PRESENT	0
565797	564387	19335Q	PARTICIPANT	\N	PRESENT	0
565798	564387	20126Y	PARTICIPANT	\N	PRESENT	0
565799	564339	20066E	PARTICIPANT	\N	PRESENT	0
565802	559959	20144B	PARTICIPANT	\N	EXCUSE	0
565803	565714	20096L	PARTICIPANT	\N	PRESENT	0
565804	565714	19681G	PARTICIPANT	\N	PRESENT	0
565805	565714	17637T	PARTICIPANT	\N	PRESENT	0
565806	565714	20140W	PARTICIPANT	\N	PRESENT	0
565812	564339	20124W	PARTICIPANT	\N	PRESENT	0
565808	565714	20120S	PARTICIPANT	\N	PRESENT	0
565809	564339	14217N	PARTICIPANT	\N	PRESENT	0
565810	564339	97011G	PARTICIPANT	\N	PRESENT	0
565811	564339	19747H	PARTICIPANT	\N	PRESENT	0
565813	564339	14097Y	PARTICIPANT	\N	PRESENT	0
565814	565714	08060W	PARTICIPANT	\N	PRESENT	0
565815	565714	20118Y	PARTICIPANT	\N	PRESENT	0
565816	565714	20068G	PARTICIPANT	\N	PRESENT	0
565817	564339	20056C	PARTICIPANT	\N	PRESENT	0
565820	564339	19711U	PARTICIPANT	\N	PRESENT	0
565821	564339	99004R	PARTICIPANT	\N	PRESENT	0
565853	565714	20024T	PARTICIPANT	\N	PRESENT	0
565854	565714	14169X	PARTICIPANT	\N	PRESENT	0
565855	564340	17589D	PARTICIPANT	\N	PRESENT	0
565856	564340	11083R	PARTICIPANT	\N	PRESENT	0
565857	564340	19619A	PARTICIPANT	\N	PRESENT	0
565858	564340	14237S	PARTICIPANT	\N	PRESENT	0
565859	564340	14217N	PARTICIPANT	\N	PRESENT	0
565860	564340	97011G	PARTICIPANT	\N	PRESENT	0
565861	564340	20056C	PARTICIPANT	\N	PRESENT	0
565862	564340	19467C	PARTICIPANT	\N	PRESENT	0
565863	564340	20180F	PARTICIPANT	\N	PRESENT	0
565864	564340	20124W	PARTICIPANT	\N	PRESENT	0
565865	564340	12041X	PARTICIPANT	\N	PRESENT	0
565866	564340	01024M	PARTICIPANT	\N	PRESENT	0
565867	564340	19747H	PARTICIPANT	\N	PRESENT	0
565868	564340	14331P	PARTICIPANT	\N	PRESENT	0
565869	564340	01048V	PARTICIPANT	\N	PRESENT	0
565870	564340	14207L	PARTICIPANT	\N	PRESENT	0
565871	564340	20050V	PARTICIPANT	\N	PRESENT	0
565872	564340	11026G	PARTICIPANT	\N	PRESENT	0
565873	564340	19711U	PARTICIPANT	\N	PRESENT	0
565874	564340	20100N	PARTICIPANT	\N	PRESENT	0
565875	564340	19533U	PARTICIPANT	\N	PRESENT	0
565876	564340	14189C	PARTICIPANT	\N	PRESENT	0
565877	564340	14357A	PARTICIPANT	\N	PRESENT	0
565885	564340	20026V	PARTICIPANT	\N	PRESENT	0
565887	564340	14147R	PARTICIPANT	\N	PRESENT	0
565888	564340	20024T	PARTICIPANT	\N	PRESENT	0
565889	564340	20126Y	PARTICIPANT	\N	PRESENT	0
565851	564340	99004R	PARTICIPANT	\N	PRESENT	0
565852	564340	14097Y	PARTICIPANT	\N	PRESENT	0
565890	564340	19349W	PARTICIPANT	\N	PRESENT	0
565892	565891	14225N	PARTICIPANT	\N	PRESENT	0
565893	565891	19747H	PARTICIPANT	\N	PRESENT	0
565894	565891	19515S	PARTICIPANT	\N	PRESENT	0
565895	565891	95063L	PARTICIPANT	\N	PRESENT	0
565896	565891	11026G	PARTICIPANT	\N	PRESENT	0
565897	564340	18083K	PARTICIPANT	\N	PRESENT	0
565898	564340	19479G	PARTICIPANT	\N	PRESENT	0
565899	564340	14257W	PARTICIPANT	\N	PRESENT	0
565900	564340	14030Q	PARTICIPANT	\N	PRESENT	0
565901	564340	19441R	PARTICIPANT	\N	PRESENT	0
565902	564340	19760E	PARTICIPANT	\N	PRESENT	0
565903	564340	11065P	PARTICIPANT	\N	PRESENT	0
565904	564340	20140W	PARTICIPANT	\N	PRESENT	0
565928	565925	20084G	PARTICIPANT	\N	PRESENT	0
565932	564341	14026U	PARTICIPANT	\N	PRESENT	0
565933	564341	14229S	PARTICIPANT	\N	PRESENT	0
565934	564341	19758L	PARTICIPANT	\N	PRESENT	0
565935	564341	14030Q	PARTICIPANT	\N	PRESENT	0
565936	564341	19527W	PARTICIPANT	\N	PRESENT	0
565937	564341	99004R	PARTICIPANT	\N	PRESENT	0
565938	564341	17589D	PARTICIPANT	\N	PRESENT	0
565939	564341	20134Y	PARTICIPANT	\N	PRESENT	0
565940	564341	19651A	PARTICIPANT	\N	PRESENT	0
565941	564341	20132W	PARTICIPANT	\N	PRESENT	0
565942	564341	19735D	PARTICIPANT	\N	PRESENT	0
565943	564341	20084G	PARTICIPANT	\N	PRESENT	0
565944	564341	19621T	PARTICIPANT	\N	PRESENT	0
565945	564341	14109K	PARTICIPANT	\N	PRESENT	0
565946	564341	20056C	PARTICIPANT	\N	PRESENT	0
565947	564341	20026V	PARTICIPANT	\N	PRESENT	0
565948	564341	20096L	PARTICIPANT	\N	PRESENT	0
565949	564341	20172F	PARTICIPANT	\N	PRESENT	0
565950	564341	19760E	PARTICIPANT	\N	PRESENT	0
565926	565925	19251M	PARTICIPANT	\N	PRESENT	0
565927	565925	19515S	PARTICIPANT	\N	PRESENT	0
565951	564341	20142Y	PARTICIPANT	\N	PRESENT	0
565952	564341	19349W	PARTICIPANT	\N	PRESENT	0
565953	564341	14021P	PARTICIPANT	\N	PRESENT	0
565954	564341	20124W	PARTICIPANT	\N	PRESENT	0
565955	564341	14357A	PARTICIPANT	\N	PRESENT	0
565956	564341	20180F	PARTICIPANT	\N	PRESENT	0
565957	564341	18083K	PARTICIPANT	\N	PRESENT	0
565958	564341	20110Q	PARTICIPANT	\N	PRESENT	0
565959	564341	14071N	PARTICIPANT	\N	PRESENT	0
565960	564341	17023S	PARTICIPANT	\N	PRESENT	0
565961	564341	20058E	PARTICIPANT	\N	PRESENT	0
565962	564341	20070A	PARTICIPANT	\N	PRESENT	0
565996	562146	19575F	PARTICIPANT	\N	PRESENT	0
565998	562146	14083S	PARTICIPANT	\N	PRESENT	0
565999	562146	19695N	PARTICIPANT	\N	PRESENT	0
541644	541642	19820Y	PARTICIPANT	\N	PRESENT	1
541649	541642	19575F	PARTICIPANT	\N	PRESENT	1
541650	541642	20022R	PARTICIPANT	\N	PRESENT	0
541652	541642	20042V	PARTICIPANT	\N	PRESENT	0
541667	541666	14173T	PARTICIPANT	\N	PRESENT	0
541669	541668	14173T	PARTICIPANT	\N	PRESENT	0
541671	541670	19711U	PARTICIPANT	\N	PRESENT	0
542033	539446	20024T	PARTICIPANT	\N	PRESENT	0
542034	539446	14069U	PARTICIPANT	\N	PRESENT	0
542035	539446	20090E	PARTICIPANT	\N	PRESENT	0
542036	539446	14083S	PARTICIPANT	\N	PRESENT	0
542037	539446	11053K	PARTICIPANT	\N	PRESENT	0
542038	539446	17229F	PARTICIPANT	\N	PRESENT	0
542039	539446	20106U	PARTICIPANT	\N	PRESENT	1
542040	539446	19333N	PARTICIPANT	\N	PRESENT	0
542041	539446	20056C	PARTICIPANT	\N	PRESENT	0
542042	539446	19611R	PARTICIPANT	\N	PRESENT	0
542043	539446	20052X	PARTICIPANT	\N	PRESENT	0
542044	539446	14221J	PARTICIPANT	\N	PRESENT	0
542045	539446	19671E	PARTICIPANT	\N	PRESENT	0
542046	539446	14169X	PARTICIPANT	\N	PRESENT	0
542047	539446	19739H	PARTICIPANT	\N	PRESENT	0
542049	539446	19349W	PARTICIPANT	\N	PRESENT	0
542050	539446	14225N	PARTICIPANT	\N	PRESENT	0
542052	539446	20150Y	PARTICIPANT	\N	PRESENT	1
542053	539446	20044X	PARTICIPANT	\N	PRESENT	0
542055	539446	11097X	PARTICIPANT	\N	PRESENT	0
544988	544987	14331P	PARTICIPANT	\N	PRESENT	0
544989	544987	04057K	PARTICIPANT	\N	PRESENT	0
544990	544987	19725B	PARTICIPANT	\N	PRESENT	0
544991	544987	12041X	PARTICIPANT	\N	PRESENT	0
544992	544987	11083R	PARTICIPANT	\N	PRESENT	0
545122	545118	11064N	PARTICIPANT	\N	PRESENT	0
545125	545118	14038Y	PARTICIPANT	\N	PRESENT	0
545130	545118	20066E	PARTICIPANT	\N	PRESENT	0
545132	545118	19585H	PARTICIPANT	\N	PRESENT	0
545135	545118	19565D	PARTICIPANT	\N	PRESENT	0
547956	545411	11012A	PARTICIPANT	\N	PRESENT	0
547957	545411	11056N	PARTICIPANT	\N	PRESENT	0
547958	545411	19581D	PARTICIPANT	\N	PRESENT	0
547959	545411	19367Y	PARTICIPANT	\N	PRESENT	0
547960	545411	19565D	PARTICIPANT	\N	PRESENT	0
547961	545411	14215L	PARTICIPANT	\N	PRESENT	0
547962	545411	20122U	PARTICIPANT	\N	PRESENT	0
547963	545411	14249W	PARTICIPANT	\N	PRESENT	0
547964	545411	11033F	PARTICIPANT	\N	PRESENT	0
547965	545411	19447X	PARTICIPANT	\N	PRESENT	0
547966	545411	20114U	PARTICIPANT	\N	PRESENT	0
547971	545411	11097X	PARTICIPANT	\N	PRESENT	0
547972	545411	19415P	PARTICIPANT	\N	PRESENT	0
547973	545411	14089Y	PARTICIPANT	\N	PRESENT	0
547979	545411	14033T	PARTICIPANT	\N	PRESENT	0
547981	545411	20050V	PARTICIPANT	\N	PRESENT	0
547983	545411	19695N	PARTICIPANT	\N	PRESENT	0
547991	545411	14069U	PARTICIPANT	\N	PRESENT	0
547954	545411	12041X	PARTICIPANT	\N	PRESENT	0
547955	545411	14111D	PARTICIPANT	\N	PRESENT	0
547992	545411	01048V	PARTICIPANT	\N	PRESENT	0
548039	547406	20112S	PARTICIPANT	\N	PRESENT	0
548040	547406	11077T	PARTICIPANT	\N	PRESENT	0
548041	547406	12041X	PARTICIPANT	\N	PRESENT	0
548042	547406	19687N	PARTICIPANT	\N	PRESENT	0
548043	547406	19593H	PARTICIPANT	\N	PRESENT	0
548044	547406	04085P	PARTICIPANT	\N	PRESENT	0
548045	547406	14211G	PARTICIPANT	\N	PRESENT	0
548046	547406	17637T	PARTICIPANT	\N	PRESENT	0
548048	547406	19711U	PARTICIPANT	\N	PRESENT	0
548068	547406	14123H	PARTICIPANT	\N	PRESENT	0
548052	547406	04047H	PARTICIPANT	\N	PRESENT	0
548054	547406	11033F	PARTICIPANT	\N	PRESENT	0
548055	547406	08010L	PARTICIPANT	\N	PRESENT	0
548057	547406	99004R	PARTICIPANT	\N	PRESENT	0
548058	547406	08011M	PARTICIPANT	\N	PRESENT	0
548060	547406	20134Y	PARTICIPANT	\N	PRESENT	0
548061	547406	08034U	PARTICIPANT	\N	PRESENT	0
548065	547406	20092G	PARTICIPANT	\N	PRESENT	0
548034	547406	86034E	PARTICIPANT	\N	PRESENT	0
548038	547406	11056N	PARTICIPANT	\N	PRESENT	0
548066	547406	20074E	PARTICIPANT	\N	PRESENT	0
548071	547406	20110Q	PARTICIPANT	\N	PRESENT	0
548072	547406	04042C	PARTICIPANT	\N	PRESENT	0
548073	547406	20130U	PARTICIPANT	\N	PRESENT	0
548075	547406	14071N	PARTICIPANT	\N	PRESENT	0
548077	547406	04092N	PARTICIPANT	\N	PRESENT	0
548079	547406	08061X	PARTICIPANT	\N	PRESENT	0
548080	547406	19747H	PARTICIPANT	\N	PRESENT	0
548081	547406	20150Y	PARTICIPANT	\N	PRESENT	0
548082	547406	11083R	PARTICIPANT	\N	PRESENT	0
548083	547406	19415P	PARTICIPANT	\N	PRESENT	0
548084	547406	19591F	PARTICIPANT	\N	PRESENT	0
548085	547406	19697Q	PARTICIPANT	\N	PRESENT	0
548087	547406	19651A	PARTICIPANT	\N	PRESENT	0
548088	547406	14187A	PARTICIPANT	\N	PRESENT	0
548089	547406	14249W	PARTICIPANT	\N	PRESENT	0
548090	547406	04033B	PARTICIPANT	\N	PRESENT	0
548092	547406	04034C	PARTICIPANT	\N	PRESENT	0
548093	547406	01048V	PARTICIPANT	\N	PRESENT	0
548095	547406	20106U	PARTICIPANT	\N	PRESENT	0
548101	547406	19329S	PARTICIPANT	\N	PRESENT	0
548102	547406	08069G	PARTICIPANT	\N	PRESENT	0
548111	547406	19515S	PARTICIPANT	\N	PRESENT	0
548106	547406	11080N	PARTICIPANT	\N	PRESENT	0
548107	547406	14069U	PARTICIPANT	\N	PRESENT	0
548109	547406	19643A	PARTICIPANT	\N	PRESENT	0
548110	547406	11012A	PARTICIPANT	\N	PRESENT	0
548112	547406	19629C	PARTICIPANT	\N	PRESENT	0
548114	547406	19719D	PARTICIPANT	\N	PRESENT	0
548115	547406	20180F	PARTICIPANT	\N	PRESENT	0
548116	547406	19347U	PARTICIPANT	\N	PRESENT	0
548117	547406	14259Y	PARTICIPANT	\N	PRESENT	0
548118	547406	19758L	PARTICIPANT	\N	PRESENT	0
548119	547406	04057K	PARTICIPANT	\N	PRESENT	0
548120	547406	19563B	PARTICIPANT	\N	PRESENT	0
548123	547406	01028R	PARTICIPANT	\N	PRESENT	0
548126	547406	20068G	PARTICIPANT	\N	PRESENT	0
548127	547406	20094J	PARTICIPANT	\N	PRESENT	0
548128	547406	20022R	PARTICIPANT	\N	PRESENT	0
548129	547406	04043D	PARTICIPANT	\N	PRESENT	0
548130	547406	11045K	PARTICIPANT	\N	PRESENT	0
548131	547406	20070A	PARTICIPANT	\N	PRESENT	0
548132	547406	19701S	PARTICIPANT	\N	PRESENT	0
548133	547406	14215L	PARTICIPANT	\N	PRESENT	0
548134	547406	19503N	PARTICIPANT	\N	PRESENT	0
548135	547406	20080C	PARTICIPANT	\N	PRESENT	0
548136	547406	11097X	PARTICIPANT	\N	PRESENT	0
548137	547406	20084G	PARTICIPANT	\N	PRESENT	0
548138	547406	20060X	PARTICIPANT	\N	PRESENT	0
548140	547406	19671E	PARTICIPANT	\N	PRESENT	0
548141	547406	08017T	PARTICIPANT	\N	PRESENT	0
548142	547406	11067R	PARTICIPANT	\N	PRESENT	0
548143	547406	14109K	PARTICIPANT	\N	PRESENT	0
548145	547406	14001X	PARTICIPANT	\N	PRESENT	0
548146	547406	20114U	PARTICIPANT	\N	PRESENT	0
548147	547406	19489J	PARTICIPANT	\N	PRESENT	0
548148	547406	19647E	PARTICIPANT	\N	PRESENT	0
548149	547406	11074Q	PARTICIPANT	\N	PRESENT	0
548150	547406	19649G	PARTICIPANT	\N	PRESENT	0
548151	547406	19669L	PARTICIPANT	\N	PRESENT	0
548152	547406	14021P	PARTICIPANT	\N	PRESENT	0
548153	547406	19683J	PARTICIPANT	\N	PRESENT	0
548154	547406	17779H	PARTICIPANT	\N	PRESENT	0
548155	547406	19820Y	PARTICIPANT	\N	PRESENT	0
548156	547406	11027H	PARTICIPANT	\N	PRESENT	0
548157	547406	18193Q	PARTICIPANT	\N	PRESENT	0
548158	547406	19421M	PARTICIPANT	\N	PRESENT	0
548159	547406	12016W	PARTICIPANT	\N	PRESENT	0
548160	547406	19333N	PARTICIPANT	\N	PRESENT	0
548161	547406	19533U	PARTICIPANT	\N	PRESENT	0
548162	547406	11048N	PARTICIPANT	\N	PRESENT	0
548163	547406	19599P	PARTICIPANT	\N	PRESENT	0
548164	547406	14225N	PARTICIPANT	\N	PRESENT	0
548165	547406	17737W	PARTICIPANT	\N	PRESENT	0
548167	547406	11031D	PARTICIPANT	\N	PRESENT	0
548168	547406	18083K	PARTICIPANT	\N	PRESENT	0
548169	547406	14031R	PARTICIPANT	\N	PRESENT	0
548170	547406	19673G	PARTICIPANT	\N	PRESENT	0
548171	547406	14179A	PARTICIPANT	\N	PRESENT	0
548172	547406	20038A	PARTICIPANT	\N	PRESENT	0
548173	547406	20052X	PARTICIPANT	\N	PRESENT	0
548174	547406	14219Q	PARTICIPANT	\N	PRESENT	0
548175	547406	19573D	PARTICIPANT	\N	PRESENT	0
562167	562055	19575F	PARTICIPANT	\N	PRESENT	0
562165	562058	20060X	PARTICIPANT	\N	PRESENT	0
562389	562387	20034V	PARTICIPANT	\N	PRESENT	1
562168	562055	14083S	PARTICIPANT	\N	PRESENT	0
562169	562055	19695N	PARTICIPANT	\N	PRESENT	0
562170	562058	19671E	PARTICIPANT	\N	PRESENT	0
562388	562387	19347U	PARTICIPANT	\N	PRESENT	1
562391	562387	12016W	PARTICIPANT	\N	PRESENT	1
562661	561762	11040E	PARTICIPANT	\N	PRESENT	1
562662	561762	04086Q	PARTICIPANT	\N	PRESENT	1
562663	561762	11110B	PARTICIPANT	\N	PRESENT	1
562664	561762	14121F	PARTICIPANT	\N	PRESENT	1
562665	561762	99004R	PARTICIPANT	\N	PRESENT	1
562666	561762	08010L	PARTICIPANT	\N	PRESENT	1
562667	561762	20050V	PARTICIPANT	\N	PRESENT	1
562668	561762	19762G	PARTICIPANT	\N	PRESENT	1
562669	561762	14173T	PARTICIPANT	\N	PRESENT	1
562935	562866	19713W	PARTICIPANT	\N	PRESENT	0
562936	562866	19697Q	PARTICIPANT	\N	PRESENT	1
562946	562941	14187A	PARTICIPANT	\N	PRESENT	0
562949	562939	14187A	PARTICIPANT	\N	PRESENT	0
562951	562940	14187A	PARTICIPANT	\N	PRESENT	0
562991	562866	20040T	PARTICIPANT	\N	PRESENT	0
562992	562866	19591F	PARTICIPANT	\N	PRESENT	0
563634	562204	19689Q	PARTICIPANT	\N	PRESENT	0
563635	562204	19347U	PARTICIPANT	\N	PRESENT	0
563636	562204	20130U	PARTICIPANT	\N	PRESENT	0
563637	562204	14059S	PARTICIPANT	\N	PRESENT	0
563638	562204	14329V	PARTICIPANT	\N	PRESENT	0
563639	562204	97011G	PARTICIPANT	\N	PRESENT	0
563640	562204	19507S	PARTICIPANT	\N	PRESENT	0
563641	562204	11099A	PARTICIPANT	\N	PRESENT	0
563642	562204	19667J	PARTICIPANT	\N	PRESENT	0
563643	562204	19515S	PARTICIPANT	\N	PRESENT	0
563644	562204	14038Y	PARTICIPANT	\N	PRESENT	0
563645	562204	20142Y	PARTICIPANT	\N	PRESENT	0
563646	562204	11033F	PARTICIPANT	\N	PRESENT	0
563647	562204	19747H	PARTICIPANT	\N	PRESENT	0
563648	561764	14327T	PARTICIPANT	\N	PRESENT	0
563649	561764	07029T	PARTICIPANT	\N	PRESENT	0
563650	561764	11048N	PARTICIPANT	\N	PRESENT	0
563651	561764	19711U	PARTICIPANT	\N	PRESENT	0
563652	561764	01057W	PARTICIPANT	\N	PRESENT	0
563653	561764	20044X	PARTICIPANT	\N	PRESENT	0
563654	561764	14225N	PRESIDENT	0	PRESENT	0
563655	561764	20022R	PARTICIPANT	\N	PRESENT	0
563656	561764	20126Y	PARTICIPANT	\N	PRESENT	0
563657	562204	20100N	PARTICIPANT	\N	PRESENT	0
563658	562204	20110Q	PARTICIPANT	\N	PRESENT	0
563659	562204	19695N	PARTICIPANT	\N	PRESENT	0
563660	562204	14217N	PARTICIPANT	\N	PRESENT	0
563661	561980	01028R	PARTICIPANT	\N	PRESENT	0
563662	561764	08009T	PARTICIPANT	\N	PRESENT	0
563663	561764	11053K	PARTICIPANT	\N	PRESENT	0
563664	561764	14083S	PARTICIPANT	\N	PRESENT	0
563699	562204	20048C	PARTICIPANT	\N	PRESENT	0
563666	562204	19415P	PARTICIPANT	\N	PRESENT	0
563667	562204	14357A	PARTICIPANT	\N	PRESENT	0
563668	562204	18083K	PARTICIPANT	\N	PRESENT	0
563669	562204	19679N	PARTICIPANT	\N	PRESENT	0
563670	561764	08034U	PARTICIPANT	\N	PRESENT	0
563671	561764	08010L	PARTICIPANT	\N	PRESENT	0
563672	561764	19335Q	PARTICIPANT	\N	PRESENT	0
563673	562204	19441R	PARTICIPANT	\N	PRESENT	0
563674	562204	11067R	PARTICIPANT	\N	PRESENT	0
563675	562204	20054A	PARTICIPANT	\N	PRESENT	0
563679	562204	20174H	PARTICIPANT	\N	PRESENT	0
563680	562204	14187A	PARTICIPANT	\N	PRESENT	0
563681	562204	14147R	PARTICIPANT	\N	PRESENT	0
563682	562204	20104S	PARTICIPANT	\N	PRESENT	0
563683	561764	20080C	PARTICIPANT	\N	PRESENT	0
563684	562204	17023S	PARTICIPANT	\N	PRESENT	0
563687	562204	11097X	PARTICIPANT	\N	PRESENT	0
563701	562204	19713W	PARTICIPANT	\N	PRESENT	0
563703	562204	05008E	PARTICIPANT	\N	PRESENT	0
563716	563715	20094J	PARTICIPANT	\N	PRESENT	0
563717	563715	14189C	PARTICIPANT	\N	PRESENT	0
563718	563715	14097Y	PARTICIPANT	\N	PRESENT	0
563719	563715	20092G	PARTICIPANT	\N	PRESENT	0
563720	563715	19575F	PARTICIPANT	\N	PRESENT	0
563723	563715	19637C	PARTICIPANT	\N	PRESENT	0
563726	563715	20110Q	PARTICIPANT	\N	PRESENT	0
563727	562204	19533U	PARTICIPANT	\N	PRESENT	0
563737	562204	14215L	PARTICIPANT	\N	PRESENT	0
563745	563742	19717B	PARTICIPANT	\N	PRESENT	1
563746	563742	14026U	PARTICIPANT	\N	PRESENT	1
563747	562204	14030Q	PARTICIPANT	\N	PRESENT	0
563757	562204	20126Y	PARTICIPANT	\N	PRESENT	0
563758	562204	14255U	PARTICIPANT	\N	PRESENT	0
563759	562204	20038A	PARTICIPANT	\N	PRESENT	0
563760	562204	19447X	PARTICIPANT	\N	PRESENT	0
563761	562204	07029T	PARTICIPANT	\N	PRESENT	0
563857	561981	19954N	PARTICIPANT	\N	PRESENT	0
563858	561981	14041T	PARTICIPANT	\N	PRESENT	0
563859	561981	20110Q	PARTICIPANT	\N	PRESENT	0
563871	561981	10015M	PARTICIPANT	\N	PRESENT	0
563872	561981	14215L	PARTICIPANT	\N	PRESENT	0
563873	561981	04047H	PRESIDENT	0	PRESENT	0
563874	561981	14021P	PARTICIPANT	\N	PRESENT	0
564060	562206	99004R	PARTICIPANT	\N	PRESENT	0
564061	562206	19551W	PARTICIPANT	\N	PRESENT	0
564062	562206	08045X	PARTICIPANT	\N	PRESENT	0
564063	562206	14083S	PARTICIPANT	\N	PRESENT	0
564064	562206	19515S	PARTICIPANT	\N	PRESENT	0
564065	562206	20122U	PARTICIPANT	\N	PRESENT	0
564066	562206	20130U	PARTICIPANT	\N	PRESENT	0
564067	562206	19301E	PARTICIPANT	\N	PRESENT	0
564068	562206	14207L	PARTICIPANT	\N	PRESENT	0
564069	562206	19687N	PARTICIPANT	\N	PRESENT	0
564070	562206	17779H	PARTICIPANT	\N	PRESENT	0
564071	562206	19679N	PARTICIPANT	\N	PRESENT	0
564072	562206	20082E	PARTICIPANT	\N	PRESENT	0
564073	562206	19599P	PARTICIPANT	\N	PRESENT	0
564074	562206	11067R	PARTICIPANT	\N	PRESENT	0
564075	562207	99004R	PARTICIPANT	\N	PRESENT	0
564076	562207	19551W	PARTICIPANT	\N	PRESENT	0
564077	562207	08045X	PARTICIPANT	\N	PRESENT	0
564078	562207	14083S	PARTICIPANT	\N	PRESENT	0
564079	562207	19515S	PARTICIPANT	\N	PRESENT	0
564080	562207	20122U	PARTICIPANT	\N	PRESENT	0
564081	562207	20130U	PARTICIPANT	\N	PRESENT	0
564095	562207	19693L	PARTICIPANT	\N	PRESENT	0
564083	562207	14207L	PARTICIPANT	\N	PRESENT	0
564084	562207	19687N	PARTICIPANT	\N	PRESENT	0
564085	562207	17779H	PARTICIPANT	\N	PRESENT	0
564086	562207	19679N	PARTICIPANT	\N	PRESENT	0
564087	562207	20082E	PARTICIPANT	\N	PRESENT	0
564088	562207	19599P	PARTICIPANT	\N	PRESENT	0
564089	562207	11067R	PARTICIPANT	\N	PRESENT	0
564090	562207	14021P	PARTICIPANT	\N	PRESENT	0
564091	562207	19631V	PARTICIPANT	\N	PRESENT	0
564092	562207	10006L	PARTICIPANT	\N	PRESENT	0
564093	562207	19301E	PARTICIPANT	\N	PRESENT	0
564094	562207	14038Y	PARTICIPANT	\N	PRESENT	0
564104	562207	14257W	PARTICIPANT	\N	PRESENT	0
564105	562207	14231L	PARTICIPANT	\N	PRESENT	0
564106	562207	14030Q	PARTICIPANT	\N	PRESENT	0
564107	562207	19467C	PARTICIPANT	\N	PRESENT	0
564113	562207	11097X	PARTICIPANT	\N	PRESENT	0
564109	562207	11031D	PARTICIPANT	\N	PRESENT	0
564112	562207	11027H	PARTICIPANT	\N	PRESENT	0
564010	563025	19295A	PARTICIPANT	\N	EXCUSE	0
564011	563025	20066E	PARTICIPANT	\N	PRESENT	1
564012	563025	11097X	PARTICIPANT	\N	PRESENT	0
564114	562207	19697Q	PARTICIPANT	\N	PRESENT	0
564115	562207	19629C	PARTICIPANT	\N	PRESENT	0
564116	562207	14042U	PARTICIPANT	\N	PRESENT	0
564117	562207	07029T	PARTICIPANT	\N	PRESENT	0
564118	562207	20180F	PARTICIPANT	\N	PRESENT	0
564119	563785	14030Q	PARTICIPANT	\N	EXCUSE	0
564120	563785	19575F	PARTICIPANT	\N	EXCUSE	0
564121	563785	19251M	PARTICIPANT	\N	EXCUSE	0
564122	563785	14026U	PARTICIPANT	\N	EXCUSE	0
564123	563785	20048C	PARTICIPANT	\N	EXCUSE	0
564058	564057	19709B	PARTICIPANT	\N	PRESENT	0
564059	564057	11027H	PARTICIPANT	\N	PRESENT	0
564124	563785	16685X	PARTICIPANT	\N	EXCUSE	0
564125	563785	19369B	PARTICIPANT	\N	EXCUSE	0
543441	543399	18193Q	PRESIDENT	0	PRESENT	0
543443	543399	19679N	PARTICIPANT	\N	PRESENT	0
543444	543399	19515S	PARTICIPANT	\N	PRESENT	0
543445	543399	19760E	PARTICIPANT	\N	PRESENT	0
543446	543399	19667J	PARTICIPANT	\N	PRESENT	0
543447	543399	19367Y	PARTICIPANT	\N	PRESENT	0
543449	543399	19631V	PARTICIPANT	\N	PRESENT	1
543450	543399	20130U	PARTICIPANT	\N	PRESENT	1
543451	543399	20066E	PARTICIPANT	\N	PRESENT	1
545112	542938	14257W	PARTICIPANT	\N	PRESENT	0
550148	550141	20068G	PARTICIPANT	\N	PRESENT	0
550149	550141	19551W	PARTICIPANT	\N	PRESENT	0
550151	550141	20102Q	PARTICIPANT	\N	PRESENT	0
550152	550141	19637C	PARTICIPANT	\N	PRESENT	0
550153	550141	20136B	PARTICIPANT	\N	PRESENT	0
550155	550154	08060W	PARTICIPANT	\N	PRESENT	0
550157	550154	17229F	PARTICIPANT	\N	PRESENT	0
550158	550154	20038A	PARTICIPANT	\N	PRESENT	0
550159	550154	19387D	PARTICIPANT	\N	PRESENT	0
550160	550154	19551W	PARTICIPANT	\N	PRESENT	0
550162	550154	19637C	PARTICIPANT	\N	PRESENT	0
550164	550154	20136B	PARTICIPANT	\N	PRESENT	0
551998	551283	11040E	PARTICIPANT	\N	PRESENT	1
551999	551283	11110B	PARTICIPANT	\N	PRESENT	1
552000	551283	20126Y	PARTICIPANT	\N	PRESENT	1
552001	551283	19335Q	PARTICIPANT	\N	PRESENT	1
552002	551283	20050V	PARTICIPANT	\N	PRESENT	1
552003	551283	14331P	PARTICIPANT	\N	PRESENT	1
552130	552129	20136B	PARTICIPANT	\N	PRESENT	0
552131	552129	19826F	PARTICIPANT	\N	PRESENT	0
552132	552129	19701S	PARTICIPANT	\N	PRESENT	0
552133	552129	19387D	PARTICIPANT	\N	PRESENT	0
552134	552129	19333N	PARTICIPANT	\N	PRESENT	0
552135	552129	19549D	PARTICIPANT	\N	PRESENT	0
552136	552129	20120S	PARTICIPANT	\N	PRESENT	0
552137	552129	19739H	PARTICIPANT	\N	PRESENT	0
552145	551707	14030Q	PARTICIPANT	\N	PRESENT	0
552146	551707	19383Y	PRESIDENT	0	PRESENT	0
552147	551707	20028X	PARTICIPANT	\N	PRESENT	0
552148	551707	19758L	PARTICIPANT	\N	PRESENT	0
552149	551707	17589D	PARTICIPANT	\N	PRESENT	1
552150	551707	19719D	PARTICIPANT	\N	PRESENT	0
552151	551707	19551W	PARTICIPANT	\N	PRESENT	1
552152	551707	19441R	PARTICIPANT	\N	PRESENT	0
552153	551707	19637C	PARTICIPANT	\N	PRESENT	1
552154	551707	14109K	PARTICIPANT	\N	PRESENT	1
552155	551707	19798U	PARTICIPANT	\N	PRESENT	1
552156	551707	19762G	PARTICIPANT	\N	PRESENT	0
552164	551707	20026V	PARTICIPANT	\N	PRESENT	1
552208	551707	14026U	PARTICIPANT	\N	EXCUSE	0
553823	551287	04086Q	PARTICIPANT	\N	PRESENT	0
553824	551287	07029T	PARTICIPANT	\N	PRESENT	0
553825	551287	11048N	PARTICIPANT	\N	PRESENT	0
553826	551287	04071H	PARTICIPANT	\N	PRESENT	0
553827	551287	19711U	PARTICIPANT	\N	PRESENT	0
553828	551287	19687N	PARTICIPANT	\N	PRESENT	0
553829	551287	20080C	PARTICIPANT	\N	PRESENT	0
553830	551287	20116W	PARTICIPANT	\N	PRESENT	0
553831	551287	20022R	PARTICIPANT	\N	PRESENT	0
553832	551287	20126Y	PARTICIPANT	\N	PRESENT	0
553833	551287	19647E	PARTICIPANT	\N	PRESENT	0
553834	551287	01048V	PARTICIPANT	\N	PRESENT	0
553835	551287	14225N	PRESIDENT	0	PRESENT	0
553836	551287	19762G	PARTICIPANT	\N	PRESENT	0
553837	551287	01057W	PARTICIPANT	\N	PRESENT	0
553862	551287	19545Y	PARTICIPANT	\N	PRESENT	0
553863	551287	20070A	PARTICIPANT	\N	PRESENT	0
553877	551455	12041X	PARTICIPANT	\N	PRESENT	0
553885	551287	19671E	PARTICIPANT	\N	EXCUSE	0
553887	551455	04086Q	PARTICIPANT	\N	PRESENT	0
553888	551455	19545Y	PARTICIPANT	\N	PRESENT	0
553889	551455	19583F	PARTICIPANT	\N	PRESENT	0
553890	551455	20050V	PARTICIPANT	\N	PRESENT	0
553891	551455	19711U	PARTICIPANT	\N	PRESENT	0
553892	551455	20022R	PARTICIPANT	\N	PRESENT	0
553893	551455	19515S	PARTICIPANT	\N	PRESENT	0
553897	551455	14041T	PARTICIPANT	\N	PRESENT	0
553898	551455	14225N	PARTICIPANT	\N	PRESENT	0
553899	551455	19531S	PARTICIPANT	\N	PRESENT	0
553900	551455	20070A	PARTICIPANT	\N	PRESENT	0
553901	551455	20024T	PARTICIPANT	\N	PRESENT	0
553902	551455	20080C	PARTICIPANT	\N	PRESENT	0
553903	551455	07029T	PARTICIPANT	\N	PRESENT	0
553904	551455	17589D	PARTICIPANT	\N	PRESENT	0
553905	551455	20116W	PARTICIPANT	\N	PRESENT	0
553906	551455	19689Q	PARTICIPANT	\N	PRESENT	0
553907	551455	14251Q	PARTICIPANT	\N	PRESENT	0
553908	551455	19479G	PARTICIPANT	\N	PRESENT	0
553909	551455	19467C	PARTICIPANT	\N	PRESENT	0
553910	551455	19687N	PARTICIPANT	\N	PRESENT	0
553911	551455	19762G	PARTICIPANT	\N	PRESENT	0
553912	551455	14237S	PARTICIPANT	\N	PRESENT	0
553913	551455	20122U	PARTICIPANT	\N	PRESENT	0
553914	551455	14195A	PARTICIPANT	\N	PRESENT	0
553915	551455	08045X	PARTICIPANT	\N	PRESENT	0
553918	551455	19349W	PARTICIPANT	\N	PRESENT	0
553920	551455	11048N	PARTICIPANT	\N	PRESENT	0
553925	551455	04057K	PARTICIPANT	\N	PRESENT	0
553926	551455	20052X	PARTICIPANT	\N	PRESENT	0
553927	551455	19760E	PARTICIPANT	\N	PRESENT	0
553928	551455	18193Q	PARTICIPANT	\N	PRESENT	0
553929	551455	14207L	PARTICIPANT	\N	PRESENT	0
553930	551455	14083S	PARTICIPANT	\N	PRESENT	0
553931	551455	19647E	PARTICIPANT	\N	PRESENT	0
553932	551455	14219Q	PARTICIPANT	\N	PRESENT	0
553933	551455	01057W	PARTICIPANT	\N	PRESENT	0
553934	551455	14147R	PARTICIPANT	\N	PRESENT	0
553935	551455	14123H	PARTICIPANT	\N	PRESENT	0
553936	551455	19507S	PARTICIPANT	\N	PRESENT	0
553937	551455	11064N	PARTICIPANT	\N	PRESENT	0
553961	551455	19563B	PARTICIPANT	\N	PRESENT	0
553962	551455	20066E	PARTICIPANT	\N	PRESENT	0
553963	551455	19569H	PARTICIPANT	\N	PRESENT	0
553964	551455	14021P	PARTICIPANT	\N	PRESENT	0
553965	551455	18083K	PARTICIPANT	\N	PRESENT	0
553966	551455	19441R	PARTICIPANT	\N	PRESENT	0
553967	551455	14179A	PARTICIPANT	\N	PRESENT	0
553968	551455	19413M	PARTICIPANT	\N	PRESENT	0
553969	551455	20020P	PARTICIPANT	\N	PRESENT	0
553970	551455	19741B	PARTICIPANT	\N	PRESENT	0
553973	551455	20090E	PARTICIPANT	\N	PRESENT	0
553974	551455	19697Q	PARTICIPANT	\N	PRESENT	0
553975	551455	20126Y	PARTICIPANT	\N	PRESENT	0
553977	551455	14217N	PARTICIPANT	\N	PRESENT	0
554030	551455	20130U	PARTICIPANT	\N	PRESENT	0
554031	551455	14038Y	PARTICIPANT	\N	PRESENT	0
554055	551455	14026U	PARTICIPANT	\N	PRESENT	0
554057	551455	11097X	PARTICIPANT	\N	PRESENT	0
554059	551455	14213J	PARTICIPANT	\N	PRESENT	0
554073	551455	14069U	PARTICIPANT	\N	PRESENT	0
554083	551455	14042U	PARTICIPANT	\N	PRESENT	0
554116	551455	08034U	PARTICIPANT	\N	PRESENT	0
554174	551456	12041X	PARTICIPANT	\N	PRESENT	0
554175	551456	14195A	PARTICIPANT	\N	PRESENT	0
554176	551456	14251Q	PARTICIPANT	\N	PRESENT	0
554177	551456	19569H	PARTICIPANT	\N	PRESENT	0
554179	551456	20090E	PARTICIPANT	\N	PRESENT	0
554180	551456	14213J	PARTICIPANT	\N	PRESENT	0
554181	551456	20126Y	PARTICIPANT	\N	PRESENT	0
554182	551456	20130U	PARTICIPANT	\N	PRESENT	0
554183	551456	19697Q	PARTICIPANT	\N	PRESENT	0
554184	551456	19349W	PARTICIPANT	\N	PRESENT	0
554185	551456	20116W	PARTICIPANT	\N	PRESENT	0
554186	551456	04057K	PARTICIPANT	\N	PRESENT	0
554187	551456	14207L	PARTICIPANT	\N	PRESENT	0
554188	551456	17589D	PARTICIPANT	\N	PRESENT	0
554189	551456	20122U	PARTICIPANT	\N	PRESENT	0
554190	551456	19441R	PARTICIPANT	\N	PRESENT	0
554191	551456	20066E	PARTICIPANT	\N	PRESENT	0
554192	551456	14083S	PARTICIPANT	\N	PRESENT	0
554193	551456	14042U	PARTICIPANT	\N	PRESENT	0
554194	551456	19760E	PARTICIPANT	\N	PRESENT	0
554195	551456	18193Q	PARTICIPANT	\N	PRESENT	0
554196	551456	11064N	PARTICIPANT	\N	PRESENT	0
554197	551456	19545Y	PARTICIPANT	\N	PRESENT	0
554198	551456	19583F	PARTICIPANT	\N	PRESENT	0
554199	551456	20050V	PARTICIPANT	\N	PRESENT	0
554200	551456	19479G	PARTICIPANT	\N	PRESENT	0
554201	551456	20052X	PARTICIPANT	\N	PRESENT	0
554202	551456	14071N	PARTICIPANT	\N	PRESENT	0
554203	551456	14217N	PARTICIPANT	\N	PRESENT	0
566007	562152	19695N	PARTICIPANT	\N	PRESENT	0
566067	562141	20060X	PARTICIPANT	\N	PRESENT	0
566068	562141	19671E	PARTICIPANT	\N	PRESENT	0
566069	562142	20060X	PARTICIPANT	\N	PRESENT	0
566070	562142	19671E	PARTICIPANT	\N	PRESENT	0
566071	562137	20060X	PARTICIPANT	\N	PRESENT	0
566072	562137	19671E	PARTICIPANT	\N	PRESENT	0
566073	562138	20060X	PARTICIPANT	\N	PRESENT	0
566074	562138	19671E	PARTICIPANT	\N	PRESENT	0
566075	562139	20060X	PARTICIPANT	\N	PRESENT	0
566076	562139	19671E	PARTICIPANT	\N	PRESENT	0
566079	562136	20060X	PARTICIPANT	\N	PRESENT	0
566081	562136	19671E	PARTICIPANT	\N	PRESENT	0
566005	562152	19575F	PARTICIPANT	\N	PRESENT	0
566006	562152	14083S	PARTICIPANT	\N	PRESENT	0
566108	560227	20024T	PARTICIPANT	\N	PRESENT	0
566109	560227	14030Q	PRESIDENT	0	PRESENT	0
566110	560227	20080C	PARTICIPANT	\N	EXCUSE	0
566111	560227	19693L	PARTICIPANT	\N	PRESENT	0
566112	560227	20106U	PARTICIPANT	\N	PRESENT	1
566113	560227	14179A	PARTICIPANT	\N	PRESENT	1
566114	560227	19715Y	PARTICIPANT	\N	PRESENT	1
566115	560227	20056C	PARTICIPANT	\N	PRESENT	1
566116	560227	19657G	PARTICIPANT	\N	PRESENT	1
566117	560227	14109K	PARTICIPANT	\N	PRESENT	0
566118	560227	19866P	PARTICIPANT	\N	PRESENT	1
566119	560227	20118Y	PARTICIPANT	\N	PRESENT	1
566120	560227	19798U	PARTICIPANT	\N	PRESENT	1
566121	560227	19527W	PARTICIPANT	\N	PRESENT	1
566122	560227	20046A	PARTICIPANT	\N	PRESENT	0
566123	560227	19749K	PARTICIPANT	\N	PRESENT	1
566134	564388	20116W	PARTICIPANT	\N	PRESENT	1
566135	564388	04086Q	PARTICIPANT	\N	PRESENT	1
566136	564388	20126Y	PARTICIPANT	\N	PRESENT	1
566137	564388	19671E	PARTICIPANT	\N	PRESENT	1
566138	564388	19335Q	PARTICIPANT	\N	PRESENT	1
566139	564388	20050V	PARTICIPANT	\N	PRESENT	1
566140	564388	19479G	PARTICIPANT	\N	PRESENT	1
566284	566282	19349W	PARTICIPANT	\N	PRESENT	0
566285	566282	14071N	PARTICIPANT	\N	PRESENT	0
566286	566282	14215L	PARTICIPANT	\N	PRESENT	0
566287	566282	20110Q	PARTICIPANT	\N	PRESENT	0
566288	566282	08010L	PARTICIPANT	\N	PRESENT	0
566289	566282	14231L	PRESIDENT	0	PRESENT	0
566290	566282	14327T	PARTICIPANT	\N	PRESENT	0
566291	566282	19333N	PARTICIPANT	\N	PRESENT	0
566292	566282	17637T	PARTICIPANT	\N	PRESENT	0
566293	566282	14107H	PARTICIPANT	\N	PRESENT	0
566294	566282	04045F	PARTICIPANT	\N	PRESENT	1
566295	566282	14281W	PARTICIPANT	\N	PRESENT	1
566296	566282	04086Q	PARTICIPANT	\N	PRESENT	1
566297	566282	19565D	PARTICIPANT	\N	PRESENT	1
566298	566282	20084G	PARTICIPANT	\N	PRESENT	1
566299	566282	14257W	PARTICIPANT	\N	PRESENT	1
566300	566282	14205J	PARTICIPANT	\N	PRESENT	1
566301	566282	19447X	PARTICIPANT	\N	PRESENT	0
566302	566282	14147R	PARTICIPANT	\N	PRESENT	0
566303	566282	19749K	PARTICIPANT	\N	PRESENT	0
566305	566282	14179A	PARTICIPANT	\N	PRESENT	0
566353	565173	04092N	PARTICIPANT	\N	PRESENT	1
566356	565173	14042U	PARTICIPANT	\N	PRESENT	1
566357	565173	19715Y	PARTICIPANT	\N	PRESENT	1
566359	565173	11031D	PARTICIPANT	\N	PRESENT	1
566360	565173	01034P	PARTICIPANT	\N	PRESENT	1
566362	565173	19697Q	PARTICIPANT	\N	PRESENT	1
566365	565247	19715Y	PARTICIPANT	\N	PRESENT	1
566413	566412	14097Y	PARTICIPANT	\N	PRESENT	0
566414	566412	14133K	PARTICIPANT	\N	PRESENT	0
566415	566412	11083R	PARTICIPANT	\N	PRESENT	0
566417	566416	14097Y	PARTICIPANT	\N	PRESENT	0
566418	566416	14133K	PARTICIPANT	\N	PRESENT	0
566419	566416	11115U	PARTICIPANT	\N	PRESENT	0
566420	566416	11083R	PARTICIPANT	\N	PRESENT	0
566422	566421	14097Y	PARTICIPANT	\N	PRESENT	0
566423	566421	14133K	PARTICIPANT	\N	PRESENT	0
566424	566421	11115U	PARTICIPANT	\N	PRESENT	0
566426	566425	14097Y	PARTICIPANT	\N	PRESENT	0
566427	566425	14133K	PARTICIPANT	\N	PRESENT	0
566429	566428	14133K	PARTICIPANT	\N	PRESENT	0
566430	566428	11066Q	PARTICIPANT	\N	PRESENT	0
566432	566431	14267Y	PARTICIPANT	\N	PRESENT	0
566633	566632	14097Y	PARTICIPANT	\N	PRESENT	0
566634	566632	14237S	PARTICIPANT	\N	PRESENT	0
566671	565265	19717B	PARTICIPANT	\N	PRESENT	1
566672	565265	14026U	PARTICIPANT	\N	PRESENT	1
566679	566124	19717B	PARTICIPANT	\N	PRESENT	1
566680	566124	14026U	PARTICIPANT	\N	PRESENT	1
566696	566156	19717B	PARTICIPANT	\N	PRESENT	1
566697	566156	14026U	PARTICIPANT	\N	PRESENT	1
566706	566156	20130U	PARTICIPANT	\N	PRESENT	1
566708	566540	04092N	PARTICIPANT	\N	PRESENT	1
566709	566540	20130U	PARTICIPANT	\N	PRESENT	1
566860	566541	14213J	PARTICIPANT	\N	PRESENT	1
566766	566539	20130U	PARTICIPANT	\N	PRESENT	1
566712	566540	14213J	PARTICIPANT	\N	PRESENT	1
566713	566540	19415P	PARTICIPANT	\N	PRESENT	1
566714	566540	01034P	PARTICIPANT	\N	PRESENT	1
566762	566540	19715Y	PARTICIPANT	\N	PRESENT	1
566764	566539	04092N	PARTICIPANT	\N	PRESENT	1
566767	566539	10006L	PARTICIPANT	\N	PRESENT	1
566770	566539	14042U	PARTICIPANT	\N	PRESENT	1
566772	566539	14213J	PARTICIPANT	\N	PRESENT	1
566774	566539	19415P	PARTICIPANT	\N	PRESENT	1
566776	566539	01034P	PARTICIPANT	\N	PRESENT	1
566778	566539	19715Y	PARTICIPANT	\N	PRESENT	1
566858	566541	04092N	PARTICIPANT	\N	PRESENT	1
566859	566541	19715Y	PARTICIPANT	\N	PRESENT	1
566861	566541	20130U	PARTICIPANT	\N	PRESENT	1
566863	566541	01034P	PARTICIPANT	\N	PRESENT	1
566865	566541	19415P	PARTICIPANT	\N	PRESENT	1
566866	566541	10006L	PARTICIPANT	\N	PRESENT	1
567163	567162	20022R	PARTICIPANT	\N	PRESENT	0
567164	567162	14331P	PARTICIPANT	\N	PRESENT	0
567169	567168	19741B	PARTICIPANT	\N	PRESENT	0
567170	567168	05008E	PARTICIPANT	\N	PRESENT	0
567171	567168	14089Y	PARTICIPANT	\N	PRESENT	0
567172	567168	14357A	PARTICIPANT	\N	PRESENT	0
567173	567168	97011G	PARTICIPANT	\N	PRESENT	0
567174	567168	14179A	PARTICIPANT	\N	PRESENT	0
567175	567168	19333N	PARTICIPANT	\N	PRESENT	0
567176	567168	08015R	PARTICIPANT	\N	PRESENT	0
567177	567168	08034U	PARTICIPANT	\N	PRESENT	0
567178	567168	14147R	PARTICIPANT	\N	PRESENT	0
567179	567168	14223L	PARTICIPANT	\N	PRESENT	0
567180	567168	04045F	PARTICIPANT	\N	PRESENT	0
567924	567923	11048N	PARTICIPANT	\N	PRESENT	0
567848	567847	08017T	PARTICIPANT	\N	PRESENT	0
567918	567917	08009T	PARTICIPANT	\N	PRESENT	0
567919	567917	20044X	PARTICIPANT	\N	PRESENT	0
567939	567927	14357A	PARTICIPANT	\N	PRESENT	0
567940	567927	20092G	PARTICIPANT	\N	PRESENT	0
567957	566440	19611R	PARTICIPANT	\N	PRESENT	0
567987	566443	19369B	PARTICIPANT	\N	PRESENT	0
567988	566443	19599P	PARTICIPANT	\N	PRESENT	0
567989	566443	20020P	PARTICIPANT	\N	PRESENT	0
567990	566443	20050V	PARTICIPANT	\N	PRESENT	0
567991	566443	20092G	PARTICIPANT	\N	PRESENT	0
567992	566443	20106U	PARTICIPANT	\N	PRESENT	0
567993	566443	11012A	PARTICIPANT	\N	PRESENT	0
567994	566443	19565D	PARTICIPANT	\N	PRESENT	0
567995	566443	19335Q	PARTICIPANT	\N	PRESENT	0
567996	566443	19503N	PARTICIPANT	\N	PRESENT	0
567997	566443	19747H	PARTICIPANT	\N	PRESENT	0
567998	566443	14257W	PARTICIPANT	\N	PRESENT	0
567999	566443	19741B	PARTICIPANT	\N	PRESENT	0
568000	566443	19399H	PARTICIPANT	\N	PRESENT	0
568001	566443	18083K	PARTICIPANT	\N	PRESENT	0
568002	566443	19515S	PARTICIPANT	\N	PRESENT	0
568003	566443	14169X	PARTICIPANT	\N	PRESENT	0
568004	566443	20114U	PARTICIPANT	\N	PRESENT	0
568005	566443	11040E	PARTICIPANT	\N	PRESENT	0
568061	566443	19671E	PARTICIPANT	\N	PRESENT	0
568065	566443	19711U	PARTICIPANT	\N	PRESENT	0
568067	566443	14231L	PARTICIPANT	\N	PRESENT	0
568085	566443	11070L	PARTICIPANT	\N	PRESENT	0
568086	566443	19687N	PARTICIPANT	\N	PRESENT	0
568087	566443	19593H	PARTICIPANT	\N	PRESENT	0
568088	566443	07029T	PARTICIPANT	\N	PRESENT	0
567985	566443	99004R	PARTICIPANT	\N	PRESENT	0
567986	566443	05012A	PARTICIPANT	\N	PRESENT	0
542958	542957	14327T	PARTICIPANT	\N	PRESENT	0
543008	543007	19711U	PARTICIPANT	\N	PRESENT	0
543014	543013	11012A	PARTICIPANT	\N	PRESENT	0
543015	543013	14083S	PARTICIPANT	\N	PRESENT	0
543017	543016	11048N	PARTICIPANT	\N	PRESENT	0
543018	543016	08011M	PARTICIPANT	\N	PRESENT	0
543020	543019	04086Q	PARTICIPANT	\N	PRESENT	0
543022	543021	04086Q	PARTICIPANT	\N	PRESENT	0
543030	543029	04086Q	PARTICIPANT	\N	PRESENT	0
543749	543748	19711U	PARTICIPANT	\N	PRESENT	0
543754	543753	19711U	PARTICIPANT	\N	PRESENT	0
543757	543755	11074Q	PARTICIPANT	\N	PRESENT	0
543759	543758	19741B	PARTICIPANT	\N	PRESENT	0
546665	546664	20042V	PARTICIPANT	\N	PRESENT	0
546666	546664	14193X	PARTICIPANT	\N	PRESENT	0
546667	546664	11054L	PARTICIPANT	\N	PRESENT	0
546668	546664	01058X	PARTICIPANT	\N	PRESENT	0
547756	534870	19651A	PARTICIPANT	\N	PRESENT	0
547757	534870	19703U	PARTICIPANT	\N	PRESENT	0
547758	534870	19479G	PARTICIPANT	\N	PRESENT	0
547759	534870	19575F	PARTICIPANT	\N	PRESENT	0
547760	534870	19717B	PARTICIPANT	\N	PRESENT	0
547761	534870	19467C	PARTICIPANT	\N	PRESENT	0
547762	534870	19760E	PARTICIPANT	\N	PRESENT	0
547763	534870	19697Q	PARTICIPANT	\N	PRESENT	0
547764	534870	19251M	PARTICIPANT	\N	PRESENT	0
547765	534870	20092G	PARTICIPANT	\N	PRESENT	0
547766	534870	19954N	PARTICIPANT	\N	PRESENT	0
547772	534870	99004R	PARTICIPANT	\N	PRESENT	0
547773	534870	14105F	PARTICIPANT	\N	PRESENT	0
547774	534870	14083S	PARTICIPANT	\N	PRESENT	0
547775	534870	19695N	PARTICIPANT	\N	PRESENT	0
547776	534870	20134Y	PARTICIPANT	\N	PRESENT	0
548139	534870	11097X	PARTICIPANT	\N	PRESENT	0
548144	534870	19551W	PARTICIPANT	\N	EXCUSE	0
548166	534870	20132W	PARTICIPANT	\N	PRESENT	0
548176	547406	14042U	PARTICIPANT	\N	PRESENT	0
548177	547406	20042V	PARTICIPANT	\N	PRESENT	0
548178	547406	19447X	PARTICIPANT	\N	PRESENT	0
548179	547406	19543W	PARTICIPANT	\N	PRESENT	0
548214	547406	20058E	PARTICIPANT	\N	PRESENT	0
548181	547406	11070L	PARTICIPANT	\N	PRESENT	0
548182	547406	19611R	PARTICIPANT	\N	PRESENT	0
548183	547406	20086J	PARTICIPANT	\N	PRESENT	0
548184	547406	19369B	PARTICIPANT	\N	PRESENT	0
548185	547406	20056C	PARTICIPANT	\N	PRESENT	0
548186	547406	20108W	PARTICIPANT	\N	PRESENT	0
548187	547406	20040T	PARTICIPANT	\N	PRESENT	0
548188	547406	14053L	PARTICIPANT	\N	PRESENT	0
548189	547406	05008E	PARTICIPANT	\N	PRESENT	0
548190	547406	11053K	PARTICIPANT	\N	PRESENT	0
548226	547406	20054A	PARTICIPANT	\N	PRESENT	0
548192	547406	14231L	PARTICIPANT	\N	PRESENT	0
548193	547406	19467C	PARTICIPANT	\N	PRESENT	0
548194	547406	14073Q	PARTICIPANT	\N	PRESENT	0
548195	547406	19367Y	PARTICIPANT	\N	PRESENT	0
548196	547406	20036X	PARTICIPANT	\N	PRESENT	0
548197	547406	19621T	PARTICIPANT	\N	PRESENT	0
548198	547406	14255U	PARTICIPANT	\N	PRESENT	0
548199	547406	01024M	PARTICIPANT	\N	PRESENT	0
548200	547406	20062A	PARTICIPANT	\N	PRESENT	0
548201	547406	19749K	PARTICIPANT	\N	PRESENT	0
548202	547406	11085T	PARTICIPANT	\N	PRESENT	0
548203	547406	04070G	PARTICIPANT	\N	PRESENT	0
548204	547406	20152B	PARTICIPANT	\N	PRESENT	0
548205	547406	14030Q	PARTICIPANT	\N	PRESENT	0
548206	547406	20148F	PARTICIPANT	\N	PRESENT	0
548207	547406	01043Q	PARTICIPANT	\N	PRESENT	0
548208	547406	14357A	PARTICIPANT	\N	PRESENT	0
548209	547406	19762G	PARTICIPANT	\N	PRESENT	0
548210	547406	14083S	PARTICIPANT	\N	PRESENT	0
548211	547406	14213J	PARTICIPANT	\N	PRESENT	0
548212	547406	19399H	PARTICIPANT	\N	PRESENT	0
548213	547406	20098N	PARTICIPANT	\N	PRESENT	0
548215	547406	20044X	PARTICIPANT	\N	PRESENT	0
548216	547406	19443T	PARTICIPANT	\N	PRESENT	0
548217	547406	07029T	PARTICIPANT	\N	PRESENT	0
548218	547406	01058X	PARTICIPANT	\N	PRESENT	0
548219	547406	14033T	PARTICIPANT	\N	PRESENT	0
548220	547406	19966S	PARTICIPANT	\N	PRESENT	0
548221	547406	14059S	PARTICIPANT	\N	PRESENT	0
548222	547406	14041T	PARTICIPANT	\N	PRESENT	0
548241	547406	20122U	PARTICIPANT	\N	PRESENT	0
548225	547406	07033P	PARTICIPANT	\N	PRESENT	0
548227	547406	14217N	PARTICIPANT	\N	PRESENT	0
548228	547406	10006L	PARTICIPANT	\N	PRESENT	0
548230	547406	20120S	PARTICIPANT	\N	PRESENT	0
548233	547406	20090E	PARTICIPANT	\N	PRESENT	0
548234	547406	19581D	PARTICIPANT	\N	PRESENT	0
548235	547406	20082E	PARTICIPANT	\N	PRESENT	0
548242	547406	20048C	PARTICIPANT	\N	PRESENT	0
548246	547406	20124W	PARTICIPANT	\N	PRESENT	0
548244	547406	14251Q	PARTICIPANT	\N	PRESENT	0
548245	547406	14055N	PARTICIPANT	\N	PRESENT	0
548247	547406	19695N	PARTICIPANT	\N	PRESENT	0
548256	547406	20050V	PARTICIPANT	\N	PRESENT	0
548257	547406	04086Q	PARTICIPANT	\N	PRESENT	0
548452	545412	99004R	PARTICIPANT	\N	PRESENT	0
548453	545412	20114U	PARTICIPANT	\N	PRESENT	0
548454	545412	19820Y	PARTICIPANT	\N	PRESENT	0
548455	545412	18193Q	PARTICIPANT	\N	PRESENT	0
548456	545412	20130U	PARTICIPANT	\N	PRESENT	0
548457	545412	14249W	PARTICIPANT	\N	PRESENT	0
548458	545412	19629C	PARTICIPANT	\N	PRESENT	0
548459	545412	19713W	PARTICIPANT	\N	PRESENT	0
548460	545412	12041X	PARTICIPANT	\N	PRESENT	0
548461	545412	19758L	PARTICIPANT	\N	PRESENT	0
548462	545412	19651A	PARTICIPANT	\N	PRESENT	0
548463	545412	14189C	PARTICIPANT	\N	PRESENT	0
548464	545412	11031D	PARTICIPANT	\N	PRESENT	0
548465	545412	14042U	PARTICIPANT	\N	PRESENT	0
548466	545412	14213J	PARTICIPANT	\N	PRESENT	0
548467	545412	04092N	PARTICIPANT	\N	PRESENT	0
548468	545412	10006L	PARTICIPANT	\N	PRESENT	0
548469	545412	11097X	PARTICIPANT	\N	PRESENT	0
548470	545412	14071N	PARTICIPANT	\N	PRESENT	0
548471	545412	14219Q	PARTICIPANT	\N	PRESENT	0
548472	545412	19711U	PARTICIPANT	\N	PRESENT	0
548473	545412	07004J	PARTICIPANT	\N	PRESENT	0
548474	545412	17637T	PARTICIPANT	\N	PRESENT	0
548475	545412	19671E	PARTICIPANT	\N	PRESENT	0
548476	545412	04043D	PARTICIPANT	\N	PRESENT	0
548477	545412	19367Y	PARTICIPANT	\N	PRESENT	0
548478	545412	04057K	PARTICIPANT	\N	PRESENT	0
548479	545412	20152B	PARTICIPANT	\N	PRESENT	0
548480	545412	20062A	PARTICIPANT	\N	PRESENT	0
548481	545412	19747H	PARTICIPANT	\N	PRESENT	0
548482	545412	14231L	PARTICIPANT	\N	PRESENT	0
548483	545412	19683J	PARTICIPANT	\N	PRESENT	0
548484	545412	19581D	PARTICIPANT	\N	PRESENT	0
548485	545412	17737W	PARTICIPANT	\N	PRESENT	0
548486	545412	20074E	PARTICIPANT	\N	PRESENT	0
548487	545412	20110Q	PARTICIPANT	\N	PRESENT	0
548489	548488	19667J	PARTICIPANT	\N	PRESENT	0
548490	548488	19575F	PARTICIPANT	\N	PRESENT	0
548491	548488	20090E	PARTICIPANT	\N	PRESENT	0
548492	548488	19467C	PARTICIPANT	\N	PRESENT	0
548493	548488	18083K	PARTICIPANT	\N	PRESENT	0
548494	548488	20040T	PARTICIPANT	\N	PRESENT	0
548495	548488	19507S	PARTICIPANT	\N	PRESENT	0
548496	548488	20120S	PARTICIPANT	\N	PRESENT	0
548497	548488	14033T	PARTICIPANT	\N	PRESENT	0
548498	548488	14205J	PARTICIPANT	\N	PRESENT	0
548499	548488	14059S	PARTICIPANT	\N	PRESENT	0
548500	548488	14109K	PARTICIPANT	\N	PRESENT	0
548501	548488	14257W	PARTICIPANT	\N	PRESENT	0
548502	548488	05012A	PARTICIPANT	\N	PRESENT	0
548503	548488	20082E	PARTICIPANT	\N	PRESENT	0
548504	548488	20054A	PARTICIPANT	\N	PRESENT	0
548505	548488	19713W	PARTICIPANT	\N	PRESENT	0
548506	548488	20062A	PARTICIPANT	\N	PRESENT	0
548507	548488	20066E	PARTICIPANT	\N	PRESENT	0
548508	548488	97011G	PARTICIPANT	\N	PRESENT	0
548509	545412	11012A	PARTICIPANT	\N	PRESENT	0
548510	545412	14083S	PARTICIPANT	\N	PRESENT	0
548511	545412	19673G	PARTICIPANT	\N	PRESENT	0
548513	545412	14055N	PARTICIPANT	\N	PRESENT	0
548515	545412	20112S	PARTICIPANT	\N	PRESENT	0
548516	545412	19649G	PARTICIPANT	\N	PRESENT	0
548517	545412	19749K	PARTICIPANT	\N	PRESENT	0
548518	545412	19503N	PARTICIPANT	\N	PRESENT	0
564126	563785	20054A	PARTICIPANT	\N	EXCUSE	0
564127	562207	20126Y	PARTICIPANT	\N	PRESENT	0
564130	562207	20132W	PARTICIPANT	\N	PRESENT	0
564176	562208	11031D	PARTICIPANT	\N	PRESENT	0
564177	562208	11067R	PARTICIPANT	\N	PRESENT	0
564178	562208	19599P	PARTICIPANT	\N	PRESENT	0
564179	562208	19301E	PARTICIPANT	\N	PRESENT	0
564181	562208	19629C	PARTICIPANT	\N	PRESENT	0
564182	562208	14207L	PARTICIPANT	\N	PRESENT	0
564183	562208	20132W	PARTICIPANT	\N	PRESENT	0
564184	562208	04057K	PARTICIPANT	\N	PRESENT	0
564185	562208	18083K	PARTICIPANT	\N	PRESENT	0
564186	562208	11097X	PARTICIPANT	\N	PRESENT	0
564187	562208	19467C	PARTICIPANT	\N	PRESENT	0
564188	562208	19693L	PARTICIPANT	\N	PRESENT	0
564189	562208	20180F	PARTICIPANT	\N	PRESENT	0
564190	562208	19782L	PARTICIPANT	\N	PRESENT	0
564191	562208	10006L	PARTICIPANT	\N	PRESENT	0
564192	562208	20130U	PARTICIPANT	\N	PRESENT	0
564193	562208	14083S	PARTICIPANT	\N	PRESENT	0
564194	562208	14042U	PARTICIPANT	\N	PRESENT	0
564195	562208	14231L	PARTICIPANT	\N	PRESENT	0
564196	562208	20092G	PARTICIPANT	\N	PRESENT	0
564197	562208	11012A	PARTICIPANT	\N	PRESENT	0
564198	562208	19591F	PARTICIPANT	\N	PRESENT	0
564199	562208	20100N	PARTICIPANT	\N	PRESENT	0
564200	562208	20126Y	PARTICIPANT	\N	PRESENT	0
564201	562208	07029T	PARTICIPANT	\N	PRESENT	0
564203	562208	19683J	PARTICIPANT	\N	PRESENT	0
564229	562209	19683J	PARTICIPANT	\N	PRESENT	0
564230	562209	19599P	PARTICIPANT	\N	PRESENT	0
564231	562209	20100N	PARTICIPANT	\N	PRESENT	0
564232	562209	20130U	PARTICIPANT	\N	PRESENT	0
564233	562209	19301E	PARTICIPANT	\N	PRESENT	0
564234	562209	19782L	PARTICIPANT	\N	PRESENT	0
564235	562209	19629C	PARTICIPANT	\N	PRESENT	0
564236	562209	20132W	PARTICIPANT	\N	PRESENT	0
564174	562208	99004R	PARTICIPANT	\N	PRESENT	0
564175	562208	19697Q	PARTICIPANT	\N	PRESENT	0
564237	562209	14042U	PARTICIPANT	\N	PRESENT	0
564238	562209	14083S	PARTICIPANT	\N	PRESENT	0
564239	562209	19591F	PARTICIPANT	\N	PRESENT	0
564240	562209	20126Y	PARTICIPANT	\N	PRESENT	0
564241	562209	10006L	PARTICIPANT	\N	PRESENT	0
564242	562209	18083K	PARTICIPANT	\N	PRESENT	0
564243	562209	20180F	PARTICIPANT	\N	PRESENT	0
564244	562209	07029T	PARTICIPANT	\N	PRESENT	0
564245	562209	11097X	PARTICIPANT	\N	PRESENT	0
564246	562209	19693L	PARTICIPANT	\N	PRESENT	0
564247	562209	04057K	PARTICIPANT	\N	PRESENT	0
564248	562209	19713W	PARTICIPANT	\N	PRESENT	0
564249	562209	08018U	PARTICIPANT	\N	PRESENT	0
564253	562209	14259Y	PARTICIPANT	\N	PRESENT	0
564227	562209	99004R	PARTICIPANT	\N	PRESENT	0
564228	562209	11031D	PARTICIPANT	\N	PRESENT	0
564258	562209	19643A	PARTICIPANT	\N	PRESENT	0
564260	562209	07004J	PARTICIPANT	\N	PRESENT	0
564261	562209	19697Q	PARTICIPANT	\N	PRESENT	0
564265	562209	14021P	PARTICIPANT	\N	PRESENT	0
564290	562210	05008E	PARTICIPANT	\N	PRESENT	0
564292	562210	19782L	PARTICIPANT	\N	PRESENT	0
564293	562210	11026G	PARTICIPANT	\N	PRESENT	0
564294	562210	08018U	PARTICIPANT	\N	PRESENT	0
564295	562210	10006L	PARTICIPANT	\N	PRESENT	0
564296	562210	04057K	PARTICIPANT	\N	PRESENT	0
564297	562210	20132W	PARTICIPANT	\N	PRESENT	0
564298	562210	19954N	PARTICIPANT	\N	PRESENT	0
564299	562210	19693L	PARTICIPANT	\N	PRESENT	0
564300	562210	19599P	PARTICIPANT	\N	PRESENT	0
564301	562210	14215L	PARTICIPANT	\N	PRESENT	0
564303	562210	14041T	PARTICIPANT	\N	PRESENT	0
564304	562210	04047H	PARTICIPANT	\N	PRESENT	0
564326	562210	11033F	PARTICIPANT	\N	PRESENT	0
564380	564379	04070G	PARTICIPANT	\N	PRESENT	0
564381	564379	14169X	PARTICIPANT	\N	PRESENT	0
564383	564382	04070G	PARTICIPANT	\N	PRESENT	0
564384	564382	14169X	PARTICIPANT	\N	PRESENT	0
564389	564264	18193Q	PARTICIPANT	\N	PRESENT	0
565035	564954	19685L	PARTICIPANT	\N	PRESENT	0
565036	564954	14205J	PARTICIPANT	\N	PRESENT	0
564288	562210	99004R	PARTICIPANT	\N	PRESENT	0
564289	562210	14021P	PARTICIPANT	\N	PRESENT	0
565099	564954	08060W	PARTICIPANT	\N	PRESENT	0
565250	565248	19447X	PARTICIPANT	\N	PRESENT	0
565170	563961	19585H	PARTICIPANT	\N	PRESENT	0
565249	565248	04008A	PARTICIPANT	\N	PRESENT	0
565251	565248	19749K	PARTICIPANT	\N	PRESENT	0
565252	565248	11026G	PARTICIPANT	\N	PRESENT	0
565254	565253	04008A	PARTICIPANT	\N	PRESENT	0
565255	565253	19581D	PARTICIPANT	\N	PRESENT	0
565259	565258	04086Q	PARTICIPANT	\N	PRESENT	0
565260	565258	04045F	PARTICIPANT	\N	PRESENT	0
565261	565258	14179A	PARTICIPANT	\N	PRESENT	0
565262	565258	14030Q	PARTICIPANT	\N	PRESENT	0
565263	565258	20124W	PARTICIPANT	\N	PRESENT	0
565264	565258	99004R	PARTICIPANT	\N	PRESENT	0
565482	565481	19251M	PARTICIPANT	\N	PRESENT	0
565484	565483	04033B	PARTICIPANT	\N	PRESENT	0
565485	565483	14021P	PARTICIPANT	\N	PRESENT	0
565486	565483	11085T	PARTICIPANT	\N	PRESENT	0
565489	565488	14041T	PARTICIPANT	\N	PRESENT	0
565490	565488	14133K	PARTICIPANT	\N	PRESENT	0
565491	565488	14357A	PARTICIPANT	\N	PRESENT	0
565492	565488	14071N	PARTICIPANT	\N	PRESENT	0
565499	564251	19768N	PARTICIPANT	\N	PRESENT	1
565703	564254	08028W	PARTICIPANT	\N	EXCUSE	0
565709	564255	08028W	PARTICIPANT	\N	EXCUSE	0
565716	564252	20062A	PARTICIPANT	\N	PRESENT	1
565717	564252	20030R	PARTICIPANT	\N	PRESENT	1
565728	564252	19575F	PARTICIPANT	\N	PRESENT	1
565729	564252	20018V	PARTICIPANT	\N	PRESENT	1
565750	564252	08028W	PARTICIPANT	\N	EXCUSE	0
566078	564859	16685X	PARTICIPANT	\N	PRESENT	0
566080	564859	19575F	PARTICIPANT	\N	PRESENT	0
566082	564859	14041T	PARTICIPANT	\N	PRESENT	0
566083	564859	19467C	PARTICIPANT	\N	PRESENT	0
566084	564859	19515S	PRESIDENT	0	PRESENT	0
566085	564859	14083S	PARTICIPANT	\N	PRESENT	0
566086	564859	19369B	PARTICIPANT	\N	PRESENT	0
566087	564859	14031R	PARTICIPANT	\N	PRESENT	0
566088	564859	08015R	PARTICIPANT	\N	PRESENT	0
566089	564859	20082E	PARTICIPANT	\N	PRESENT	0
566090	564859	20126Y	PARTICIPANT	\N	PRESENT	0
566091	564859	19695N	PARTICIPANT	\N	PRESENT	0
566092	564859	14105F	PARTICIPANT	\N	PRESENT	0
566093	564859	19697Q	PARTICIPANT	\N	PRESENT	0
566094	564859	14030Q	PARTICIPANT	\N	EXCUSE	0
566095	564859	08060W	PARTICIPANT	\N	EXCUSE	0
566096	564859	19545Y	PARTICIPANT	\N	EXCUSE	0
566097	564859	14329V	PARTICIPANT	\N	EXCUSE	0
566098	564859	08028W	PARTICIPANT	\N	EXCUSE	0
566099	564859	14026U	PARTICIPANT	\N	EXCUSE	0
566100	564859	20048C	PARTICIPANT	\N	EXCUSE	0
566101	564859	19671E	PARTICIPANT	\N	EXCUSE	0
566102	564859	20054A	PARTICIPANT	\N	EXCUSE	0
566103	564859	20092G	PARTICIPANT	\N	EXCUSE	0
566145	559959	11056N	PARTICIPANT	\N	PRESENT	0
566146	559959	19399H	PARTICIPANT	\N	PRESENT	0
566147	559959	99004R	PARTICIPANT	\N	PRESENT	0
566148	559959	11040E	PARTICIPANT	\N	PRESENT	0
566149	559959	19479G	PARTICIPANT	\N	PRESENT	0
566150	559959	19643A	PARTICIPANT	\N	PRESENT	0
566151	559959	20042V	PARTICIPANT	\N	PRESENT	0
566152	559959	19651A	PARTICIPANT	\N	PRESENT	0
566155	566154	04008A	PARTICIPANT	\N	PRESENT	0
566157	563779	11097X	PARTICIPANT	\N	PRESENT	0
566158	563779	20130U	PARTICIPANT	\N	PRESENT	0
566159	563779	17779H	PARTICIPANT	\N	PRESENT	0
566161	563782	17779H	PARTICIPANT	\N	PRESENT	0
566162	563782	20130U	PARTICIPANT	\N	PRESENT	0
566164	563782	11097X	PARTICIPANT	\N	PRESENT	0
566183	545946	04043D	PARTICIPANT	\N	PRESENT	0
566185	545946	01058X	PARTICIPANT	\N	PRESENT	0
566187	545946	19533U	PARTICIPANT	\N	PRESENT	0
566188	545946	20128B	PARTICIPANT	\N	PRESENT	0
566189	545946	20066E	PARTICIPANT	\N	PRESENT	0
566190	545946	20072C	PARTICIPANT	\N	PRESENT	0
542684	539588	17023S	PARTICIPANT	\N	PRESENT	0
542687	539588	19717B	PRESIDENT	0	PRESENT	0
542689	539588	11109J	PARTICIPANT	\N	EXCUSE	0
542692	539588	19659J	PARTICIPANT	\N	EXCUSE	0
542694	539588	97011G	PARTICIPANT	\N	PRESENT	0
542696	539588	19301E	PARTICIPANT	\N	PRESENT	0
542757	539588	19631V	PARTICIPANT	\N	PRESENT	0
542759	539588	19583F	PARTICIPANT	\N	PRESENT	0
542760	539588	08034U	PARTICIPANT	\N	PRESENT	0
542763	539588	12016W	PARTICIPANT	\N	PRESENT	0
542764	539588	19657G	PARTICIPANT	\N	PRESENT	0
542765	539588	11072N	PARTICIPANT	\N	PRESENT	0
542766	539588	08073C	PARTICIPANT	\N	PRESENT	0
545424	545423	11072N	PARTICIPANT	\N	PRESENT	0
545426	545425	19679N	PARTICIPANT	\N	PRESENT	0
545427	545425	18193Q	PARTICIPANT	\N	PRESENT	0
545428	545425	20130U	PARTICIPANT	\N	PRESENT	0
545429	545425	04045F	PARTICIPANT	\N	PRESENT	0
545431	545430	19679N	PARTICIPANT	\N	PRESENT	0
545432	545430	18193Q	PARTICIPANT	\N	PRESENT	0
545433	545430	20130U	PARTICIPANT	\N	PRESENT	0
545435	545434	19679N	PARTICIPANT	\N	PRESENT	0
545436	534870	20044X	PARTICIPANT	\N	PRESENT	0
545454	536584	19553Y	PARTICIPANT	\N	PRESENT	0
545449	542537	19711U	PARTICIPANT	\N	PRESENT	0
545450	542537	11097X	PARTICIPANT	\N	PRESENT	0
545456	536584	11097X	PARTICIPANT	\N	PRESENT	0
545452	539651	19711U	PARTICIPANT	\N	PRESENT	0
545453	539651	11097X	PARTICIPANT	\N	PRESENT	0
545455	536584	19711U	PARTICIPANT	\N	PRESENT	0
545457	538910	19553Y	PARTICIPANT	\N	PRESENT	0
545458	538910	19711U	PARTICIPANT	\N	PRESENT	0
545459	538910	11097X	PARTICIPANT	\N	PRESENT	0
545460	537051	19553Y	PARTICIPANT	\N	PRESENT	0
545461	537051	19711U	PARTICIPANT	\N	PRESENT	0
545462	537051	11097X	PARTICIPANT	\N	PRESENT	0
545463	541514	19553Y	PARTICIPANT	\N	PRESENT	0
545464	541514	19711U	PARTICIPANT	\N	PRESENT	0
545465	541514	11097X	PARTICIPANT	\N	PRESENT	0
548738	548736	14327T	PARTICIPANT	\N	PRESENT	0
548744	548742	20050V	PARTICIPANT	\N	PRESENT	0
548746	548745	20050V	PARTICIPANT	\N	PRESENT	0
548750	548748	14083S	PARTICIPANT	\N	PRESENT	0
548751	548748	11012A	PARTICIPANT	\N	PRESENT	0
548752	548749	14083S	PARTICIPANT	\N	PRESENT	0
548754	548749	11012A	PARTICIPANT	\N	PRESENT	0
548780	548779	14083S	PARTICIPANT	\N	PRESENT	0
548781	548779	11012A	PARTICIPANT	\N	PRESENT	0
548784	548783	19711U	PARTICIPANT	\N	PRESENT	0
548789	548788	11053K	PARTICIPANT	\N	PRESENT	0
548801	548800	11048N	PARTICIPANT	\N	PRESENT	0
548804	548803	11048N	PARTICIPANT	\N	PRESENT	0
548806	548805	11048N	PARTICIPANT	\N	PRESENT	0
548807	548805	19741B	PARTICIPANT	\N	PRESENT	0
548808	548805	19667J	PARTICIPANT	\N	PRESENT	0
548809	548805	20080C	PARTICIPANT	\N	PRESENT	0
548810	548805	11053K	PARTICIPANT	\N	PRESENT	0
548811	548805	04086Q	PARTICIPANT	\N	PRESENT	0
548812	548805	19687N	PARTICIPANT	\N	PRESENT	0
548864	548862	11048N	PARTICIPANT	\N	PRESENT	0
548866	548865	11048N	PARTICIPANT	\N	PRESENT	0
554206	551456	19762G	PARTICIPANT	\N	PRESENT	0
554207	551456	14038Y	PARTICIPANT	\N	PRESENT	0
554208	551456	11097X	PARTICIPANT	\N	PRESENT	0
554209	551456	19467C	PARTICIPANT	\N	PRESENT	0
554210	551456	20024T	PARTICIPANT	\N	PRESENT	0
554211	551456	08034U	PARTICIPANT	\N	PRESENT	0
554212	551456	14026U	PARTICIPANT	\N	PRESENT	0
554213	551456	11067R	PARTICIPANT	\N	PRESENT	0
554214	551456	19683J	PARTICIPANT	\N	PRESENT	0
554215	551456	08045X	PARTICIPANT	\N	PRESENT	0
554216	551456	17779H	PARTICIPANT	\N	PRESENT	0
554217	551456	19563B	PARTICIPANT	\N	PRESENT	0
554218	551456	07029T	PARTICIPANT	\N	PRESENT	0
554220	551456	14147R	PARTICIPANT	\N	PRESENT	0
554233	551456	19657G	PARTICIPANT	\N	PRESENT	0
554234	551456	11033F	PARTICIPANT	\N	PRESENT	0
554235	551456	20132W	PARTICIPANT	\N	PRESENT	0
554237	551456	14021P	PARTICIPANT	\N	PRESENT	0
554238	551456	19687N	PARTICIPANT	\N	PRESENT	0
554239	551456	11031D	PARTICIPANT	\N	PRESENT	0
554240	551456	20100N	PARTICIPANT	\N	PRESENT	0
554241	551456	19415P	PARTICIPANT	\N	PRESENT	0
554242	551456	19507S	PARTICIPANT	\N	PRESENT	0
554243	551456	20058E	PARTICIPANT	\N	PRESENT	0
554314	551458	11097X	PARTICIPANT	\N	PRESENT	0
554315	551458	14237S	PARTICIPANT	\N	PRESENT	0
554316	551458	07029T	PARTICIPANT	\N	PRESENT	0
554204	551456	20020P	PARTICIPANT	\N	PRESENT	0
554205	551456	18083K	PARTICIPANT	\N	PRESENT	0
554317	551458	19760E	PARTICIPANT	\N	PRESENT	0
554318	551458	20086J	PARTICIPANT	\N	PRESENT	0
554319	551458	11031D	PARTICIPANT	\N	PRESENT	0
554320	551458	14026U	PARTICIPANT	\N	PRESENT	0
554321	551458	11067R	PARTICIPANT	\N	PRESENT	0
554322	551458	18193Q	PARTICIPANT	\N	PRESENT	0
554323	551458	14071N	PARTICIPANT	\N	PRESENT	0
554324	551458	19683J	PARTICIPANT	\N	PRESENT	0
554325	551458	08010L	PARTICIPANT	\N	PRESENT	0
554326	551458	17779H	PARTICIPANT	\N	PRESENT	0
554327	551458	19583F	PARTICIPANT	\N	PRESENT	0
554328	551458	20066E	PARTICIPANT	\N	PRESENT	0
554329	551458	14251Q	PARTICIPANT	\N	PRESENT	0
554330	551458	14207L	PARTICIPANT	\N	PRESENT	0
554331	551458	20132W	PARTICIPANT	\N	PRESENT	0
554332	551458	20052X	PARTICIPANT	\N	PRESENT	0
554333	551458	19569H	PARTICIPANT	\N	PRESENT	0
554334	551458	14083S	PARTICIPANT	\N	PRESENT	0
554335	551458	20020P	PARTICIPANT	\N	PRESENT	0
554336	551458	19657G	PARTICIPANT	\N	PRESENT	0
554337	551458	19697Q	PARTICIPANT	\N	PRESENT	0
554338	551458	10006L	PARTICIPANT	\N	PRESENT	0
554339	551458	14195A	PARTICIPANT	\N	PRESENT	0
554340	551458	19563B	PARTICIPANT	\N	PRESENT	0
554341	551458	20130U	PARTICIPANT	\N	PRESENT	0
554342	551458	20102Q	PARTICIPANT	\N	PRESENT	0
554343	551458	19545Y	PARTICIPANT	\N	PRESENT	0
554344	551458	14217N	PARTICIPANT	\N	PRESENT	0
554346	551458	08045X	PARTICIPANT	\N	PRESENT	0
554347	551458	04057K	PARTICIPANT	\N	PRESENT	0
554363	551458	14219Q	PARTICIPANT	\N	PRESENT	0
554366	551458	20046A	PARTICIPANT	\N	PRESENT	0
554367	551458	14205J	PARTICIPANT	\N	PRESENT	0
554301	551458	08073C	PARTICIPANT	\N	PRESENT	0
554313	551458	20090E	PARTICIPANT	\N	PRESENT	0
554368	551458	19507S	PARTICIPANT	\N	PRESENT	0
554369	551458	20050V	PARTICIPANT	\N	PRESENT	0
554370	551458	14030Q	PARTICIPANT	\N	PRESENT	0
554374	551458	20106U	PARTICIPANT	\N	PRESENT	0
554375	551458	20116W	PARTICIPANT	\N	PRESENT	0
554376	551458	14213J	PARTICIPANT	\N	PRESENT	0
554388	551458	19687N	PARTICIPANT	\N	PRESENT	0
554398	551458	19467C	PARTICIPANT	\N	PRESENT	0
554399	551458	19739H	PARTICIPANT	\N	PRESENT	0
554400	551458	17589D	PARTICIPANT	\N	PRESENT	0
554401	551458	14331P	PARTICIPANT	\N	PRESENT	0
554402	551458	20048C	PARTICIPANT	\N	PRESENT	0
554403	551458	19741B	PARTICIPANT	\N	PRESENT	0
554404	551458	20024T	PARTICIPANT	\N	PRESENT	0
554425	551458	19669L	PARTICIPANT	\N	PRESENT	0
554426	551458	19713W	PARTICIPANT	\N	PRESENT	0
554427	551458	11056N	PARTICIPANT	\N	PRESENT	0
554428	551458	19695N	PARTICIPANT	\N	PRESENT	0
554429	551458	12041X	PARTICIPANT	\N	PRESENT	0
554430	551458	20100N	PARTICIPANT	\N	PRESENT	0
554431	551458	04034C	PARTICIPANT	\N	PRESENT	0
554432	551458	14259Y	PARTICIPANT	\N	PRESENT	0
568089	566443	19651A	PARTICIPANT	\N	PRESENT	0
568090	566443	01048V	PARTICIPANT	\N	PRESENT	0
568091	566443	19647E	PARTICIPANT	\N	PRESENT	0
568120	566444	11040E	PARTICIPANT	\N	PRESENT	0
568133	566444	19689Q	PARTICIPANT	\N	PRESENT	0
568122	566444	19647E	PARTICIPANT	\N	PRESENT	0
568123	566444	20114U	PARTICIPANT	\N	PRESENT	0
568124	566444	20050V	PARTICIPANT	\N	PRESENT	0
568125	566444	11070L	PARTICIPANT	\N	PRESENT	0
568126	566444	07029T	PARTICIPANT	\N	PRESENT	0
568127	566444	19711U	PARTICIPANT	\N	PRESENT	0
568128	566444	01048V	PARTICIPANT	\N	PRESENT	0
568129	566444	05012A	PARTICIPANT	\N	PRESENT	0
568130	566444	11012A	PARTICIPANT	\N	PRESENT	0
568131	566444	19651A	PARTICIPANT	\N	PRESENT	0
568132	566444	19741B	PARTICIPANT	\N	PRESENT	0
568134	566444	14225N	PARTICIPANT	\N	PRESENT	0
568135	566444	04085P	PARTICIPANT	\N	PRESENT	0
568138	566444	19593H	PARTICIPANT	\N	PRESENT	0
568139	566444	19747H	PARTICIPANT	\N	PRESENT	0
568174	566444	19671E	PARTICIPANT	\N	PRESENT	0
568229	566542	04092N	PARTICIPANT	\N	PRESENT	1
568230	566542	14213J	PARTICIPANT	\N	PRESENT	0
568231	566542	19798U	PARTICIPANT	\N	PRESENT	1
568232	566542	01034P	PARTICIPANT	\N	PRESENT	1
568233	566638	14097Y	PARTICIPANT	\N	PRESENT	0
568235	566636	14097Y	PARTICIPANT	\N	PRESENT	0
568236	566636	14237S	PARTICIPANT	\N	PRESENT	0
568118	566444	99004R	PARTICIPANT	\N	PRESENT	0
568119	566444	19687N	PARTICIPANT	\N	PRESENT	0
568237	566637	14097Y	PARTICIPANT	\N	PRESENT	0
568238	566637	14237S	PARTICIPANT	\N	PRESENT	0
568246	568245	14053L	PARTICIPANT	\N	PRESENT	0
568241	568239	19729F	PARTICIPANT	\N	PRESENT	0
568242	568239	19591F	PARTICIPANT	\N	PRESENT	0
568243	568239	20090E	PARTICIPANT	\N	PRESENT	0
568244	568239	20114U	PARTICIPANT	\N	PRESENT	0
568247	568245	07004J	PARTICIPANT	\N	PRESENT	0
568248	568245	11026G	PARTICIPANT	\N	PRESENT	0
568250	568249	14053L	PARTICIPANT	\N	PRESENT	0
568251	568249	07004J	PARTICIPANT	\N	PRESENT	0
568253	568252	14053L	PARTICIPANT	\N	PRESENT	0
568321	567711	14038Y	PARTICIPANT	\N	PRESENT	0
568322	567711	14187A	PARTICIPANT	\N	PRESENT	0
568302	567376	19549D	PARTICIPANT	\N	PRESENT	0
568303	567376	20020P	PARTICIPANT	\N	PRESENT	0
568304	567376	17367Q	PARTICIPANT	\N	PRESENT	0
568305	567376	19599P	PARTICIPANT	\N	PRESENT	0
568306	567376	19637C	PARTICIPANT	\N	PRESENT	0
568307	567376	17229F	PARTICIPANT	\N	PRESENT	0
568308	567376	19251M	PARTICIPANT	\N	PRESENT	0
568309	567376	11065P	PARTICIPANT	\N	PRESENT	0
568310	567376	19681G	PARTICIPANT	\N	PRESENT	0
568311	567376	14219Q	PRESIDENT	0	PRESENT	0
568312	567376	19826F	PARTICIPANT	\N	PRESENT	0
568360	566526	14329V	PARTICIPANT	\N	PRESENT	0
568314	567376	20106U	PARTICIPANT	\N	PRESENT	0
568315	567376	19503N	PARTICIPANT	\N	PRESENT	0
568361	566526	20130U	PARTICIPANT	\N	PRESENT	0
568317	567376	19701S	PARTICIPANT	\N	PRESENT	0
568318	567376	20136B	PARTICIPANT	\N	PRESENT	0
568319	567376	19551W	PARTICIPANT	\N	PRESENT	1
568320	567376	19333N	PARTICIPANT	\N	PRESENT	0
568323	567711	19507S	PARTICIPANT	\N	PRESENT	0
568324	567711	14033T	PARTICIPANT	\N	PRESENT	0
568325	567711	11090Q	PRESIDENT	0	PRESENT	0
568326	567711	14207L	PARTICIPANT	\N	PRESENT	0
568327	567711	19747H	PARTICIPANT	\N	PRESENT	0
568328	567711	04045F	PARTICIPANT	\N	PRESENT	1
568329	567711	19631V	PARTICIPANT	\N	PRESENT	0
568330	567711	14257W	PARTICIPANT	\N	PRESENT	0
568331	567711	14329V	PARTICIPANT	\N	PRESENT	0
568332	567711	20174H	PARTICIPANT	\N	PRESENT	1
568333	567711	19515S	PARTICIPANT	\N	PRESENT	1
568334	566526	99004R	PARTICIPANT	\N	PRESENT	0
568335	566526	19701S	PARTICIPANT	\N	PRESENT	0
568336	566526	19826F	PARTICIPANT	\N	PRESENT	0
568337	566526	20136B	PARTICIPANT	\N	PRESENT	0
568338	566526	11090Q	PARTICIPANT	\N	PRESENT	0
568339	566526	19699S	PARTICIPANT	\N	PRESENT	0
568340	566526	19711U	PARTICIPANT	\N	PRESENT	0
568341	566526	20108W	PARTICIPANT	\N	PRESENT	0
568342	566526	14251Q	PARTICIPANT	\N	PRESENT	0
568343	566526	11065P	PARTICIPANT	\N	PRESENT	0
568344	566526	19637C	PARTICIPANT	\N	PRESENT	0
568345	566526	19681G	PARTICIPANT	\N	PRESENT	0
568346	566526	20046A	PARTICIPANT	\N	PRESENT	0
568347	566526	19549D	PARTICIPANT	\N	PRESENT	0
568348	566526	14031R	PARTICIPANT	\N	PRESENT	0
568349	566526	17229F	PARTICIPANT	\N	PRESENT	0
568350	566526	19747H	PARTICIPANT	\N	PRESENT	0
568351	566526	20106U	PARTICIPANT	\N	PRESENT	0
568352	566526	19369B	PARTICIPANT	\N	PRESENT	0
568353	566526	14257W	PARTICIPANT	\N	PRESENT	0
568354	566526	17367Q	PARTICIPANT	\N	PRESENT	0
568355	566526	19507S	PARTICIPANT	\N	PRESENT	0
568362	566526	14033T	PARTICIPANT	\N	PRESENT	0
568363	566526	19683J	PARTICIPANT	\N	PRESENT	0
568364	566526	14038Y	PARTICIPANT	\N	PRESENT	0
568365	566526	20020P	PARTICIPANT	\N	PRESENT	0
568366	566526	14207L	PARTICIPANT	\N	PRESENT	0
568367	566526	20100N	PARTICIPANT	\N	PRESENT	0
568368	566526	20102Q	PARTICIPANT	\N	PRESENT	0
568369	566526	19695N	PARTICIPANT	\N	PRESENT	0
568370	566526	19251M	PARTICIPANT	\N	PRESENT	0
568371	566526	19503N	PARTICIPANT	\N	PRESENT	0
568372	566526	19333N	PARTICIPANT	\N	PRESENT	0
568373	566526	19599P	PARTICIPANT	\N	PRESENT	0
568374	566526	19631V	PARTICIPANT	\N	PRESENT	0
568375	566526	95063L	PARTICIPANT	\N	PRESENT	0
568376	566526	14205J	PARTICIPANT	\N	PRESENT	0
568377	566526	14187A	PARTICIPANT	\N	PRESENT	0
568378	566526	14219Q	PARTICIPANT	\N	PRESENT	0
568379	566526	20076G	PARTICIPANT	\N	PRESENT	0
568380	566526	11099A	PARTICIPANT	\N	PRESENT	0
568381	566526	04059M	PARTICIPANT	\N	PRESENT	0
568382	566526	07033P	PARTICIPANT	\N	PRESENT	0
568383	566526	20112S	PARTICIPANT	\N	PRESENT	0
568384	566526	08018U	PARTICIPANT	\N	PRESENT	0
568385	566526	20142Y	PARTICIPANT	\N	PRESENT	0
568386	566526	19347U	PARTICIPANT	\N	PRESENT	0
568387	566526	19687N	PARTICIPANT	\N	PRESENT	0
568388	566526	14215L	PARTICIPANT	\N	PRESENT	0
568389	566526	16685X	PARTICIPANT	\N	PRESENT	0
568392	566526	11033F	PARTICIPANT	\N	PRESENT	0
568393	566526	20134Y	PARTICIPANT	\N	PRESENT	0
568394	566526	04085P	PARTICIPANT	\N	PRESENT	0
568395	566526	11064N	PARTICIPANT	\N	PRESENT	0
568396	566526	19533U	PARTICIPANT	\N	PRESENT	0
568397	566526	19413M	PARTICIPANT	\N	PRESENT	0
568444	567377	20106U	PARTICIPANT	\N	PRESENT	0
568445	567377	19503N	PARTICIPANT	\N	PRESENT	0
568446	567377	14219Q	PRESIDENT	0	PRESENT	0
568447	567377	19826F	PARTICIPANT	\N	PRESENT	0
568448	567377	19637C	PARTICIPANT	\N	PRESENT	0
568449	567377	19333N	PARTICIPANT	\N	PRESENT	0
568450	567377	14031R	PARTICIPANT	\N	PRESENT	0
568451	567377	19251M	PARTICIPANT	\N	PRESENT	0
568452	567377	19599P	PARTICIPANT	\N	PRESENT	0
568453	567377	20100N	PARTICIPANT	\N	PRESENT	0
568454	567377	20020P	PARTICIPANT	\N	PRESENT	0
568455	567377	17367Q	PARTICIPANT	\N	PRESENT	0
568456	567377	11065P	PARTICIPANT	\N	PRESENT	0
568457	567377	19701S	PARTICIPANT	\N	PRESENT	0
568458	567377	20136B	PARTICIPANT	\N	PRESENT	0
568459	567377	17229F	PARTICIPANT	\N	PRESENT	0
568460	567377	19549D	PARTICIPANT	\N	PRESENT	0
568461	567377	20046A	PARTICIPANT	\N	PRESENT	0
568462	567377	19681G	PARTICIPANT	\N	PRESENT	0
568463	566527	11045K	PARTICIPANT	\N	PRESENT	0
568464	566527	19701S	PARTICIPANT	\N	PRESENT	0
568465	566527	20136B	PARTICIPANT	\N	PRESENT	0
568466	566527	14219Q	PARTICIPANT	\N	PRESENT	0
568467	566527	17229F	PARTICIPANT	\N	PRESENT	0
568468	566527	19251M	PARTICIPANT	\N	PRESENT	0
568469	566527	20134Y	PARTICIPANT	\N	PRESENT	0
568470	566527	20142Y	PARTICIPANT	\N	PRESENT	0
568471	566527	20100N	PARTICIPANT	\N	PRESENT	0
568472	566527	20130U	PARTICIPANT	\N	PRESENT	0
568473	566527	19549D	PARTICIPANT	\N	PRESENT	0
541935	541460	14030Q	PARTICIPANT	\N	PRESENT	0
541936	541460	19383Y	PRESIDENT	0	PRESENT	0
541937	541460	19758L	PARTICIPANT	\N	PRESENT	0
541938	541460	19719D	PARTICIPANT	\N	PRESENT	0
541940	541460	20038A	PARTICIPANT	\N	PRESENT	0
541941	541460	14026U	PARTICIPANT	\N	PRESENT	0
541942	541460	20028X	PARTICIPANT	\N	PRESENT	0
541943	541460	14109K	PARTICIPANT	\N	PRESENT	0
541944	541460	19762G	PARTICIPANT	\N	PRESENT	0
541945	541460	19713W	PARTICIPANT	\N	PRESENT	0
541950	541460	19798U	PARTICIPANT	\N	PRESENT	1
541988	541460	20026V	PARTICIPANT	\N	PRESENT	0
541999	541460	19441R	PARTICIPANT	\N	PRESENT	0
546660	545160	17737W	PARTICIPANT	\N	PRESENT	0
546661	544625	19647E	PARTICIPANT	\N	PRESENT	0
546662	544625	08034U	PARTICIPANT	\N	PRESENT	0
546663	544625	20070A	PARTICIPANT	\N	PRESENT	0
546669	544625	14083S	PARTICIPANT	\N	PRESENT	0
546683	545160	20110Q	PARTICIPANT	\N	PRESENT	0
546686	545331	11067R	PARTICIPANT	\N	PRESENT	0
546687	545331	20090E	PARTICIPANT	\N	PRESENT	0
546688	545331	19569H	PARTICIPANT	\N	PRESENT	0
546689	545331	19798U	PARTICIPANT	\N	PRESENT	0
546690	545331	11097X	PARTICIPANT	\N	PRESENT	0
546691	545331	19415P	PARTICIPANT	\N	PRESENT	0
546692	545331	18193Q	PARTICIPANT	\N	PRESENT	0
546693	545331	14223L	PARTICIPANT	\N	PRESENT	0
546694	545331	14026U	PARTICIPANT	\N	PRESENT	0
546695	545331	17779H	PARTICIPANT	\N	PRESENT	0
546696	545331	19703U	PARTICIPANT	\N	PRESENT	0
546697	545331	19679N	PARTICIPANT	\N	PRESENT	0
546698	545331	19367Y	PARTICIPANT	\N	PRESENT	0
546699	545331	14213J	PARTICIPANT	\N	PRESENT	0
546700	545331	14217N	PARTICIPANT	\N	PRESENT	0
546701	545331	19713W	PARTICIPANT	\N	PRESENT	0
546702	545331	20066E	PARTICIPANT	\N	PRESENT	0
546703	545331	14071N	PARTICIPANT	\N	PRESENT	0
546704	545331	19295A	PARTICIPANT	\N	EXCUSE	0
546757	544625	19531S	PARTICIPANT	\N	PRESENT	0
546758	544625	20144B	PARTICIPANT	\N	PRESENT	0
546759	544625	07029T	PARTICIPANT	\N	PRESENT	0
546763	545160	19543W	PARTICIPANT	\N	PRESENT	0
546764	543958	19383Y	PARTICIPANT	\N	PRESENT	0
546765	543958	19768N	PARTICIPANT	\N	PRESENT	0
546766	543958	19515S	PARTICIPANT	\N	PRESENT	0
546767	543958	20092G	PARTICIPANT	\N	PRESENT	0
546768	543958	19782L	PARTICIPANT	\N	PRESENT	1
546769	543958	01043Q	PARTICIPANT	\N	PRESENT	1
546770	543958	14357A	PARTICIPANT	\N	PRESENT	0
546771	543958	19441R	PARTICIPANT	\N	PRESENT	0
546772	543958	20078J	PARTICIPANT	\N	PRESENT	0
546773	543958	19413M	PARTICIPANT	\N	PRESENT	1
546774	543958	20082E	PARTICIPANT	\N	PRESENT	0
546775	543958	20094J	PARTICIPANT	\N	PRESENT	0
546776	543958	04045F	PARTICIPANT	\N	PRESENT	1
546777	543958	19631V	PARTICIPANT	\N	PRESENT	0
546778	543958	19705W	PARTICIPANT	\N	PRESENT	0
546779	543958	08015R	PARTICIPANT	\N	PRESENT	1
546780	543958	19575F	PARTICIPANT	\N	PRESENT	1
546781	543958	19369B	PARTICIPANT	\N	PRESENT	0
546782	543958	20018V	PARTICIPANT	\N	PRESENT	0
546783	543958	19563B	PARTICIPANT	\N	PRESENT	0
546784	543958	08028W	PARTICIPANT	\N	PRESENT	1
546785	543958	14329V	PARTICIPANT	\N	PRESENT	0
546786	543958	14038Y	PARTICIPANT	\N	PRESENT	0
546787	543958	20030R	PARTICIPANT	\N	PRESENT	1
546788	543958	19467C	PARTICIPANT	\N	PRESENT	1
546789	543958	20034V	PARTICIPANT	\N	PRESENT	0
546790	543958	14187A	PARTICIPANT	\N	PRESENT	0
546791	543958	20144B	PARTICIPANT	\N	PRESENT	0
546792	543958	19695N	PARTICIPANT	\N	PRESENT	0
546793	543958	01025N	PARTICIPANT	\N	PRESENT	0
546794	543958	11090Q	PRESIDENT	0	PRESENT	0
546795	543958	14033T	PARTICIPANT	\N	PRESENT	0
546796	543958	20174H	PARTICIPANT	\N	PRESENT	1
546797	543958	14205J	PARTICIPANT	\N	PRESENT	1
546798	543958	20060X	PARTICIPANT	\N	PRESENT	0
546799	543958	20062A	PARTICIPANT	\N	PRESENT	0
546800	543958	14251Q	PARTICIPANT	\N	PRESENT	1
546801	543958	19507S	PARTICIPANT	\N	PRESENT	0
546802	543958	14207L	PARTICIPANT	\N	PRESENT	0
546803	543958	19747H	PARTICIPANT	\N	PRESENT	1
546804	543958	14257W	PARTICIPANT	\N	PRESENT	0
546872	545161	10015M	PARTICIPANT	\N	PRESENT	0
546873	545161	14147R	PARTICIPANT	\N	PRESENT	0
546874	545161	19585H	PARTICIPANT	\N	PRESENT	0
546875	545161	14053L	PARTICIPANT	\N	PRESENT	0
546876	545161	14041T	PARTICIPANT	\N	PRESENT	0
546877	545161	14215L	PARTICIPANT	\N	PRESENT	0
546878	545161	04047H	PRESIDENT	0	PRESENT	0
546879	545161	05008E	PARTICIPANT	\N	PRESENT	0
546880	545161	19447X	PARTICIPANT	\N	PRESENT	0
546881	545161	19543W	PARTICIPANT	\N	PRESENT	0
546882	545161	19749K	PARTICIPANT	\N	PRESENT	0
546883	545161	19673G	PARTICIPANT	\N	PRESENT	0
546903	545406	86034E	PARTICIPANT	\N	PRESENT	0
546904	545406	19569H	PARTICIPANT	\N	PRESENT	0
546905	545406	19511N	PARTICIPANT	\N	PRESENT	0
546906	545406	01025N	PARTICIPANT	\N	PRESENT	0
546907	545406	20090E	PARTICIPANT	\N	PRESENT	0
546908	545406	08069G	PARTICIPANT	\N	PRESENT	0
546909	545406	20108W	PARTICIPANT	\N	PRESENT	0
546910	545406	19798U	PARTICIPANT	\N	PRESENT	0
546911	545406	14231L	PARTICIPANT	\N	PRESENT	0
546912	545406	19593H	PARTICIPANT	\N	PRESENT	0
546913	545406	14275Y	PARTICIPANT	\N	PRESENT	0
546914	545406	14030Q	PARTICIPANT	\N	PRESENT	0
546915	545406	14253S	PARTICIPANT	\N	PRESENT	0
546918	545406	11054L	PARTICIPANT	\N	PRESENT	0
546919	545406	14111D	PARTICIPANT	\N	PRESENT	0
546920	545406	19415P	PARTICIPANT	\N	PRESENT	0
546921	545406	92040Q	PARTICIPANT	\N	PRESENT	0
546922	545406	20150Y	PARTICIPANT	\N	PRESENT	0
546923	545406	19762G	PARTICIPANT	\N	PRESENT	0
546924	545406	04092N	PARTICIPANT	\N	PRESENT	0
546925	545406	19443T	PARTICIPANT	\N	PRESENT	0
546926	545406	19966S	PARTICIPANT	\N	PRESENT	0
546927	545406	20112S	PARTICIPANT	\N	PRESENT	0
546928	545406	99004R	PARTICIPANT	\N	PRESENT	0
546929	545406	11097X	PARTICIPANT	\N	PRESENT	0
546930	545406	14031R	PARTICIPANT	\N	PRESENT	0
546931	545406	20144B	PARTICIPANT	\N	PRESENT	0
546932	545161	01028R	PARTICIPANT	\N	PRESENT	0
546933	545161	14179A	PARTICIPANT	\N	PRESENT	0
546934	545406	20046A	PARTICIPANT	\N	PRESENT	0
546935	545406	19705W	PARTICIPANT	\N	PRESENT	0
546936	545406	19369B	PARTICIPANT	\N	PRESENT	0
546937	545406	19611R	PARTICIPANT	\N	PRESENT	0
546938	545406	20034V	PARTICIPANT	\N	PRESENT	0
546943	545406	14055N	PARTICIPANT	\N	PRESENT	0
546940	545406	11080N	PARTICIPANT	\N	PRESENT	0
546941	545406	20132W	PARTICIPANT	\N	PRESENT	0
546942	545406	14107H	PARTICIPANT	\N	PRESENT	0
546944	545406	19637C	PARTICIPANT	\N	PRESENT	0
546945	545406	19782L	PARTICIPANT	\N	PRESENT	0
546946	545406	16685X	PARTICIPANT	\N	PRESENT	0
566191	545946	01048V	PARTICIPANT	\N	PRESENT	0
566193	545946	19735D	PARTICIPANT	\N	PRESENT	0
566201	559959	19747H	PARTICIPANT	\N	PRESENT	0
566202	559959	20132W	PARTICIPANT	\N	PRESENT	0
566591	566433	11045K	PARTICIPANT	\N	PRESENT	0
566604	566433	11103C	PARTICIPANT	\N	PRESENT	0
566605	566433	14133K	PARTICIPANT	\N	PRESENT	0
566606	566433	11048N	PARTICIPANT	\N	PRESENT	0
566607	566433	14331P	PARTICIPANT	\N	PRESENT	0
566608	566433	20090E	PARTICIPANT	\N	PRESENT	0
566609	566433	19581D	PARTICIPANT	\N	PRESENT	0
566610	566433	19563B	PARTICIPANT	\N	PRESENT	0
566611	566433	20100N	PARTICIPANT	\N	PRESENT	0
566612	566433	11083R	PARTICIPANT	\N	PRESENT	0
566613	566433	14207L	PARTICIPANT	\N	PRESENT	0
566614	566433	08015R	PARTICIPANT	\N	PRESENT	0
566615	566433	19441R	PARTICIPANT	\N	PRESENT	0
566616	566433	19725B	PARTICIPANT	\N	PRESENT	0
566617	566433	14237S	PARTICIPANT	\N	PRESENT	0
566618	566433	14089Y	PARTICIPANT	\N	PRESENT	0
566619	566433	19711U	PARTICIPANT	\N	PRESENT	0
566620	566433	19507S	PARTICIPANT	\N	PRESENT	0
566621	566433	19667J	PARTICIPANT	\N	PRESENT	0
566622	566433	12041X	PARTICIPANT	\N	PRESENT	0
566623	566433	20048C	PARTICIPANT	\N	PRESENT	0
566624	566433	20072C	PARTICIPANT	\N	PRESENT	0
566625	566433	95063L	PARTICIPANT	\N	PRESENT	0
566626	566433	20076G	PARTICIPANT	\N	PRESENT	0
566627	566433	97011G	PARTICIPANT	\N	PRESENT	0
566628	566433	20180F	PARTICIPANT	\N	PRESENT	0
566629	566433	20022R	PARTICIPANT	\N	PRESENT	0
566630	566433	01058X	PARTICIPANT	\N	PRESENT	0
566631	566433	11012A	PARTICIPANT	\N	PRESENT	0
566635	566433	20062A	PARTICIPANT	\N	PRESENT	0
566639	566433	14147R	PARTICIPANT	\N	PRESENT	0
566640	566433	19741B	PARTICIPANT	\N	PRESENT	0
566642	566433	18083K	PARTICIPANT	\N	PRESENT	0
566643	566433	08061X	PARTICIPANT	\N	PRESENT	0
566644	566433	01048V	PARTICIPANT	\N	PRESENT	0
566645	566433	20126Y	PARTICIPANT	\N	PRESENT	0
566646	566433	20044X	PARTICIPANT	\N	PRESENT	0
566647	566433	14038Y	PARTICIPANT	\N	PRESENT	0
566648	566433	20124W	PARTICIPANT	\N	PRESENT	0
566649	566433	20056C	PARTICIPANT	\N	PRESENT	0
566650	566433	20098N	PARTICIPANT	\N	PRESENT	0
566651	566433	20024T	PARTICIPANT	\N	PRESENT	0
566652	566433	20144B	PARTICIPANT	\N	PRESENT	0
566653	566433	19467C	PARTICIPANT	\N	PRESENT	0
566654	566433	14031R	PARTICIPANT	\N	PRESENT	0
566655	566433	14217N	PARTICIPANT	\N	PRESENT	0
566656	566433	14042U	PARTICIPANT	\N	PRESENT	0
566657	566433	19479G	PARTICIPANT	\N	PRESENT	0
566658	566433	19575F	PARTICIPANT	\N	PRESENT	0
566659	566433	20066E	PARTICIPANT	\N	PRESENT	0
566660	566433	19399H	PARTICIPANT	\N	PRESENT	0
566661	566433	19798U	PARTICIPANT	\N	PRESENT	0
566662	566433	01024M	PARTICIPANT	\N	PRESENT	0
566663	566433	20140W	PARTICIPANT	\N	PRESENT	0
566664	566433	14059S	PARTICIPANT	\N	PRESENT	0
566665	566433	14030Q	PARTICIPANT	\N	PRESENT	0
566666	566433	19533U	PARTICIPANT	\N	PRESENT	0
566667	566433	19762G	PARTICIPANT	\N	PRESENT	0
566668	566433	17589D	PARTICIPANT	\N	PRESENT	0
566669	566433	14223L	PARTICIPANT	\N	PRESENT	0
566695	566433	14109K	PARTICIPANT	\N	PRESENT	0
566699	566433	11085T	PARTICIPANT	\N	PRESENT	0
566700	566433	20132W	PARTICIPANT	\N	PRESENT	0
566701	566433	19651A	PARTICIPANT	\N	PRESENT	0
566702	566433	11090Q	PARTICIPANT	\N	PRESENT	0
566703	566433	14229S	PARTICIPANT	\N	PRESENT	0
566704	566433	20134Y	PARTICIPANT	\N	PRESENT	0
566705	566433	20152B	PARTICIPANT	\N	PRESENT	0
566707	566433	14083S	PARTICIPANT	\N	PRESENT	0
566768	566434	19643A	PARTICIPANT	\N	PRESENT	0
566769	566434	19575F	PARTICIPANT	\N	PRESENT	0
566771	566434	17589D	PARTICIPANT	\N	PRESENT	0
566773	566434	20134Y	PARTICIPANT	\N	PRESENT	0
566775	566434	19651A	PARTICIPANT	\N	PRESENT	0
566777	566434	20132W	PARTICIPANT	\N	PRESENT	0
566779	566434	20112S	PARTICIPANT	\N	PRESENT	0
566780	566434	04070G	PARTICIPANT	\N	PRESENT	0
566781	566434	19593H	PARTICIPANT	\N	PRESENT	0
566782	566434	14109K	PARTICIPANT	\N	PRESENT	0
566783	566434	14229S	PARTICIPANT	\N	PRESENT	0
566784	566434	20180F	PARTICIPANT	\N	PRESENT	0
566785	566434	20056C	PARTICIPANT	\N	PRESENT	0
566786	566434	19747H	PARTICIPANT	\N	PRESENT	0
566787	566434	19741B	PARTICIPANT	\N	PRESENT	0
566788	566434	14237S	PARTICIPANT	\N	PRESENT	0
566789	566434	19467C	PARTICIPANT	\N	PRESENT	0
566790	566434	11090Q	PARTICIPANT	\N	PRESENT	0
566791	566434	19399H	PARTICIPANT	\N	PRESENT	0
566792	566434	18083K	PARTICIPANT	\N	PRESENT	0
566793	566434	08015R	PARTICIPANT	\N	PRESENT	0
566794	566434	20062A	PARTICIPANT	\N	PRESENT	0
566795	566434	20124W	PARTICIPANT	\N	PRESENT	0
566796	566434	20152B	PARTICIPANT	\N	PRESENT	0
566797	566434	14217N	PARTICIPANT	\N	PRESENT	0
566798	566434	19798U	PARTICIPANT	\N	PRESENT	0
566799	566434	14223L	PARTICIPANT	\N	PRESENT	0
566800	566434	19699S	PARTICIPANT	\N	PRESENT	0
566801	566434	14083S	PARTICIPANT	\N	PRESENT	0
566802	566434	14042U	PARTICIPANT	\N	PRESENT	0
566803	566434	14030Q	PARTICIPANT	\N	PRESENT	0
566804	566434	20140W	PARTICIPANT	\N	PRESENT	0
566805	566434	14267Y	PARTICIPANT	\N	PRESENT	0
566806	566434	20142Y	PARTICIPANT	\N	PRESENT	0
566862	566573	20048C	PARTICIPANT	\N	PRESENT	1
566864	566573	20026V	PARTICIPANT	\N	PRESENT	1
566890	566434	20058E	PARTICIPANT	\N	PRESENT	0
566891	566434	19631V	PARTICIPANT	\N	PRESENT	0
566892	566434	20052X	PARTICIPANT	\N	PRESENT	0
566937	566936	14133K	PARTICIPANT	\N	PRESENT	0
566938	564488	19681G	PARTICIPANT	\N	PRESENT	0
566939	564488	17367Q	PARTICIPANT	\N	PRESENT	0
566940	564488	19826F	PARTICIPANT	\N	PRESENT	0
566958	564488	11065P	PARTICIPANT	\N	PRESENT	0
566960	565471	20180F	PARTICIPANT	\N	PRESENT	0
566961	565471	19611R	PRESIDENT	0	PRESENT	0
566962	565471	92040Q	PARTICIPANT	\N	PRESENT	0
566763	566434	11045K	PARTICIPANT	\N	PRESENT	0
566765	566434	19693L	PARTICIPANT	\N	PRESENT	0
566963	565471	11104D	PARTICIPANT	\N	PRESENT	0
566964	565471	11109J	PARTICIPANT	\N	EXCUSE	0
566965	566525	19715Y	PARTICIPANT	\N	PRESENT	0
566969	566525	11031D	PARTICIPANT	\N	PRESENT	0
566970	566525	19703U	PARTICIPANT	\N	PRESENT	0
567057	565268	19798U	PARTICIPANT	\N	PRESENT	0
567058	566306	20062A	PARTICIPANT	\N	PRESENT	0
567059	566306	14251Q	PARTICIPANT	\N	PRESENT	1
567060	565268	19760E	PARTICIPANT	\N	PRESENT	1
567061	565268	19657G	PARTICIPANT	\N	PRESENT	0
567062	566306	14033T	PARTICIPANT	\N	EXCUSE	0
567063	566306	08028W	PARTICIPANT	\N	EXCUSE	0
567064	566306	19563B	PARTICIPANT	\N	EXCUSE	0
567065	566306	19441R	PARTICIPANT	\N	PRESENT	1
567066	566306	20018V	PARTICIPANT	\N	PRESENT	1
567067	566016	20108W	PARTICIPANT	\N	PRESENT	0
567068	566016	20110Q	PARTICIPANT	\N	PRESENT	0
567069	565268	19679N	PARTICIPANT	\N	PRESENT	0
567070	566306	20094J	PARTICIPANT	\N	PRESENT	1
567071	566306	20082E	PARTICIPANT	\N	PRESENT	0
567077	566016	19585H	PARTICIPANT	\N	PRESENT	0
567097	566153	14327T	PARTICIPANT	\N	PRESENT	0
567098	566153	11048N	PARTICIPANT	\N	PRESENT	0
567099	566153	19647E	PARTICIPANT	\N	PRESENT	0
567100	566153	20036X	PARTICIPANT	\N	PRESENT	0
567101	566153	19711U	PARTICIPANT	\N	PRESENT	0
567102	566153	01048V	PARTICIPANT	\N	PRESENT	0
567103	566153	01057W	PARTICIPANT	\N	PRESENT	0
567104	566153	20080C	PARTICIPANT	\N	PRESENT	0
567105	566153	20044X	PARTICIPANT	\N	PRESENT	0
567106	566153	14225N	PRESIDENT	0	PRESENT	0
567107	566153	14083S	PARTICIPANT	\N	PRESENT	0
567108	566153	07029T	PARTICIPANT	\N	PRESENT	0
567109	566153	11012A	PARTICIPANT	\N	PRESENT	0
567110	566153	08009T	PARTICIPANT	\N	PRESENT	0
567111	566153	20070A	PARTICIPANT	\N	PRESENT	0
542010	542002	08017T	PARTICIPANT	\N	PRESENT	0
542011	542002	14041T	PARTICIPANT	\N	PRESENT	0
542012	542002	10006L	PARTICIPANT	\N	PRESENT	0
542013	542002	04070G	PARTICIPANT	\N	PRESENT	0
542015	542002	04035D	PARTICIPANT	\N	PRESENT	0
542016	542002	14255U	PARTICIPANT	\N	PRESENT	0
542017	542002	08018U	PARTICIPANT	\N	PRESENT	0
542018	542002	19709B	PARTICIPANT	\N	PRESENT	0
542019	542002	08010L	PARTICIPANT	\N	PRESENT	0
542020	542002	08034U	PARTICIPANT	\N	PRESENT	0
542021	542002	20174H	PARTICIPANT	\N	PRESENT	0
542022	542002	14147R	PARTICIPANT	\N	PRESENT	0
542023	542002	19693L	PARTICIPANT	\N	PRESENT	0
542024	542002	14331P	PARTICIPANT	\N	PRESENT	0
549647	549646	11053K	PARTICIPANT	\N	PRESENT	0
549648	549646	01028R	PARTICIPANT	\N	PRESENT	0
549867	548814	19583F	PARTICIPANT	\N	EXCUSE	0
549868	548814	20148F	PRESIDENT	0	PRESENT	0
550877	548814	18083K	PARTICIPANT	\N	PRESENT	0
550876	548814	19717B	PARTICIPANT	\N	PRESENT	0
550878	548814	97011G	PARTICIPANT	\N	PRESENT	0
550879	548814	19347U	PARTICIPANT	\N	PRESENT	0
550880	548814	20034V	PARTICIPANT	\N	PRESENT	0
550881	548814	19691J	PARTICIPANT	\N	PRESENT	0
550882	548814	19715Y	PARTICIPANT	\N	PRESENT	0
550883	548814	12016W	PARTICIPANT	\N	PRESENT	0
550884	548814	19657G	PARTICIPANT	\N	PRESENT	0
550885	548814	14147R	PARTICIPANT	\N	PRESENT	0
550886	548814	11090Q	PARTICIPANT	\N	PRESENT	0
550887	548814	05008E	PARTICIPANT	\N	EXCUSE	0
550888	549006	05008E	PARTICIPANT	\N	EXCUSE	0
550889	549005	05008E	PARTICIPANT	\N	EXCUSE	0
550890	549006	20148F	PRESIDENT	0	PRESENT	0
551571	543601	14357A	PARTICIPANT	\N	PRESENT	0
551633	551632	08015R	PARTICIPANT	\N	PRESENT	0
551634	551632	20028X	PARTICIPANT	\N	PRESENT	0
551635	551632	19369B	PARTICIPANT	\N	PRESENT	0
551636	551632	14109K	PARTICIPANT	\N	PRESENT	0
551642	551641	19711U	PARTICIPANT	\N	PRESENT	0
551643	551641	14255U	PARTICIPANT	\N	PRESENT	0
551644	551641	11026G	PARTICIPANT	\N	PRESENT	0
551645	551641	14041T	PARTICIPANT	\N	PRESENT	0
551646	551641	19591F	PARTICIPANT	\N	PRESENT	0
551653	550933	19735D	PARTICIPANT	\N	PRESENT	1
551654	550933	20142Y	PARTICIPANT	\N	PRESENT	1
551655	550934	19735D	PARTICIPANT	\N	PRESENT	1
551656	550934	19533U	PARTICIPANT	\N	PRESENT	1
551657	550935	19735D	PARTICIPANT	\N	PRESENT	0
551658	550936	19735D	PARTICIPANT	\N	PRESENT	1
551659	550936	20180F	PARTICIPANT	\N	PRESENT	1
552860	552859	11103C	PARTICIPANT	\N	PRESENT	0
552861	552859	18193Q	PARTICIPANT	\N	PRESENT	0
552862	552859	17779H	PARTICIPANT	\N	PRESENT	0
552863	552859	20130U	PARTICIPANT	\N	PRESENT	0
552864	552859	11097X	PARTICIPANT	\N	PRESENT	0
552865	552859	01034P	PARTICIPANT	\N	PRESENT	0
553850	553848	12028B	PARTICIPANT	\N	PRESENT	1
553851	553848	11064N	PARTICIPANT	\N	PRESENT	1
553856	553855	12028B	PARTICIPANT	\N	PRESENT	0
553857	553855	11064N	PARTICIPANT	\N	PRESENT	0
553858	553855	14105F	PARTICIPANT	\N	PRESENT	0
553859	553855	97011G	PARTICIPANT	\N	PRESENT	0
554489	551459	19669L	PARTICIPANT	\N	PRESENT	0
554490	551459	19507S	PARTICIPANT	\N	PRESENT	0
554491	551459	04057K	PARTICIPANT	\N	PRESENT	0
554492	551459	19347U	PARTICIPANT	\N	PRESENT	0
554493	551459	20100N	PARTICIPANT	\N	PRESENT	0
554494	551459	19583F	PARTICIPANT	\N	PRESENT	0
554495	551459	14001X	PARTICIPANT	\N	PRESENT	0
554496	551459	12041X	PARTICIPANT	\N	PRESENT	0
554497	551459	11031D	PARTICIPANT	\N	PRESENT	0
554498	551459	11056N	PARTICIPANT	\N	PRESENT	0
554499	551459	20046A	PARTICIPANT	\N	PRESENT	0
554500	551459	20102Q	PARTICIPANT	\N	PRESENT	0
554501	551459	19820Y	PARTICIPANT	\N	PRESENT	0
554502	551459	14207L	PARTICIPANT	\N	PRESENT	0
554503	551459	19713W	PARTICIPANT	\N	PRESENT	0
554504	551459	14205J	PARTICIPANT	\N	PRESENT	0
554505	551459	14030Q	PARTICIPANT	\N	PRESENT	0
554506	551459	20066E	PARTICIPANT	\N	PRESENT	0
554507	551459	14083S	PARTICIPANT	\N	PRESENT	0
554508	551459	19739H	PARTICIPANT	\N	PRESENT	0
554509	551459	14331P	PARTICIPANT	\N	PRESENT	0
554510	551459	14259Y	PARTICIPANT	\N	PRESENT	0
554511	551459	19747H	PARTICIPANT	\N	PRESENT	0
554512	551459	07029T	PARTICIPANT	\N	PRESENT	0
554513	551459	19467C	PARTICIPANT	\N	PRESENT	0
554514	551459	18083K	PARTICIPANT	\N	PRESENT	0
554515	551459	20024T	PARTICIPANT	\N	PRESENT	0
554516	551459	04034C	PARTICIPANT	\N	PRESENT	0
554517	551459	14021P	PARTICIPANT	\N	PRESENT	0
554518	551459	19657G	PARTICIPANT	\N	PRESENT	0
554520	551459	14255U	PARTICIPANT	\N	PRESENT	0
554526	551459	20130U	PARTICIPANT	\N	PRESENT	0
554533	551459	14033T	PARTICIPANT	\N	PRESENT	0
554534	551459	20116W	PARTICIPANT	\N	PRESENT	0
554535	551459	04085P	PARTICIPANT	\N	PRESENT	0
554540	551459	14219Q	PARTICIPANT	\N	PRESENT	0
554555	551459	11026G	PARTICIPANT	\N	PRESENT	0
554556	551459	19689Q	PARTICIPANT	\N	PRESENT	0
554557	551459	20106U	PARTICIPANT	\N	PRESENT	0
554586	551460	19695N	PARTICIPANT	\N	PRESENT	0
554487	551459	08073C	PARTICIPANT	\N	PRESENT	0
554488	551459	19695N	PARTICIPANT	\N	PRESENT	0
554587	551460	04085P	PARTICIPANT	\N	PRESENT	0
554588	551460	12041X	PARTICIPANT	\N	PRESENT	0
554589	551460	11031D	PARTICIPANT	\N	PRESENT	0
554590	551460	19820Y	PARTICIPANT	\N	PRESENT	0
554591	551460	14219Q	PARTICIPANT	\N	PRESENT	0
554592	551460	20102Q	PARTICIPANT	\N	PRESENT	0
554593	551460	20106U	PARTICIPANT	\N	PRESENT	0
554594	551460	14205J	PARTICIPANT	\N	PRESENT	0
554595	551460	19739H	PARTICIPANT	\N	PRESENT	0
554596	551460	07029T	PARTICIPANT	\N	PRESENT	0
554597	551460	19689Q	PARTICIPANT	\N	PRESENT	0
554598	551460	18083K	PARTICIPANT	\N	PRESENT	0
554599	551460	19583F	PARTICIPANT	\N	PRESENT	0
554600	551460	14259Y	PARTICIPANT	\N	PRESENT	0
554601	551460	19507S	PARTICIPANT	\N	PRESENT	0
554602	551460	19657G	PARTICIPANT	\N	PRESENT	0
554603	551460	20116W	PARTICIPANT	\N	PRESENT	0
554604	551460	14207L	PARTICIPANT	\N	PRESENT	0
554605	551460	19687N	PARTICIPANT	\N	PRESENT	0
554647	551460	19503N	PARTICIPANT	\N	PRESENT	0
555072	555071	19575F	PARTICIPANT	\N	PRESENT	1
555073	555071	19525U	PARTICIPANT	\N	PRESENT	1
555074	555071	08017T	PARTICIPANT	\N	PRESENT	1
555075	555071	11027H	PARTICIPANT	\N	PRESENT	1
555076	555071	14255U	PARTICIPANT	\N	PRESENT	1
554584	551460	08073C	PARTICIPANT	\N	PRESENT	0
554585	551460	20046A	PARTICIPANT	\N	PRESENT	0
555077	555071	19637C	PARTICIPANT	\N	PRESENT	1
555078	555071	19369B	PARTICIPANT	\N	PRESENT	1
555079	555071	04070G	PARTICIPANT	\N	PRESENT	1
555080	555071	14083S	PARTICIPANT	\N	PRESENT	1
555081	555071	04057K	PARTICIPANT	\N	PRESENT	1
555476	555475	19711U	PARTICIPANT	\N	PRESENT	0
555478	555477	19711U	PARTICIPANT	\N	PRESENT	0
555772	555341	11053K	PARTICIPANT	\N	PRESENT	1
555773	555341	11110B	PARTICIPANT	\N	PRESENT	1
555774	555341	14121F	PARTICIPANT	\N	PRESENT	1
555775	555341	19335Q	PARTICIPANT	\N	PRESENT	1
555776	555341	20050V	PARTICIPANT	\N	PRESENT	1
556323	554659	19673G	PARTICIPANT	\N	EXCUSE	0
557306	555039	11045K	PARTICIPANT	\N	PRESENT	0
557313	555039	18193Q	PARTICIPANT	\N	PRESENT	0
557314	555039	19527W	PARTICIPANT	\N	PRESENT	0
557315	555039	20106U	PARTICIPANT	\N	PRESENT	0
557316	555039	19533U	PARTICIPANT	\N	PRESENT	0
557317	555039	19319Q	PARTICIPANT	\N	PRESENT	0
557318	555039	07033P	PARTICIPANT	\N	PRESENT	0
557319	555039	20046A	PARTICIPANT	\N	PRESENT	0
557320	555039	19747H	PARTICIPANT	\N	PRESENT	0
557321	555039	19745F	PARTICIPANT	\N	PRESENT	0
557322	555039	12028B	PARTICIPANT	\N	PRESENT	0
557323	555039	14147R	PARTICIPANT	\N	PRESENT	0
557324	555039	14267Y	PARTICIPANT	\N	PRESENT	0
557325	555039	19387D	PARTICIPANT	\N	PRESENT	0
557327	555039	14237S	PARTICIPANT	\N	PRESENT	0
557332	555039	19581D	PARTICIPANT	\N	PRESENT	0
557333	555039	19768N	PARTICIPANT	\N	PRESENT	0
568476	566527	19637C	PARTICIPANT	\N	PRESENT	0
568477	566527	19681G	PARTICIPANT	\N	PRESENT	0
568478	566527	14207L	PARTICIPANT	\N	PRESENT	0
568479	566527	07033P	PARTICIPANT	\N	PRESENT	0
568480	566527	20020P	PARTICIPANT	\N	PRESENT	0
568481	566527	19533U	PARTICIPANT	\N	PRESENT	0
568482	566527	14187A	PARTICIPANT	\N	PRESENT	0
568483	566527	20076G	PARTICIPANT	\N	PRESENT	0
568484	566527	17367Q	PARTICIPANT	\N	PRESENT	0
568485	566527	14031R	PARTICIPANT	\N	PRESENT	0
568486	566527	14033T	PARTICIPANT	\N	PRESENT	0
568487	566527	19507S	PARTICIPANT	\N	PRESENT	0
568488	566527	11012A	PARTICIPANT	\N	PRESENT	0
568489	566527	14257W	PARTICIPANT	\N	PRESENT	0
568490	566527	19333N	PARTICIPANT	\N	PRESENT	0
568491	566527	19503N	PARTICIPANT	\N	PRESENT	0
568474	566527	11065P	PARTICIPANT	\N	PRESENT	0
568475	566527	20106U	PARTICIPANT	\N	PRESENT	0
568492	566527	14195A	PARTICIPANT	\N	PRESENT	0
568493	566527	11033F	PARTICIPANT	\N	PRESENT	0
568494	566527	19413M	PARTICIPANT	\N	PRESENT	0
568495	566527	19631V	PARTICIPANT	\N	PRESENT	0
568496	566527	19599P	PARTICIPANT	\N	PRESENT	0
568497	566527	19699S	PARTICIPANT	\N	PRESENT	0
568498	566527	14030Q	PARTICIPANT	\N	PRESENT	0
568499	566527	20102Q	PARTICIPANT	\N	PRESENT	0
568500	566527	20046A	PARTICIPANT	\N	PRESENT	0
568501	566527	19826F	PARTICIPANT	\N	PRESENT	0
568502	566527	11064N	PARTICIPANT	\N	PRESENT	0
568503	566527	19747H	PARTICIPANT	\N	PRESENT	0
568504	566527	14038Y	PARTICIPANT	\N	PRESENT	0
568505	566527	20140W	PARTICIPANT	\N	PRESENT	0
568506	566527	19369B	PARTICIPANT	\N	PRESENT	0
568507	566527	14205J	PARTICIPANT	\N	PRESENT	0
568508	566527	14329V	PARTICIPANT	\N	PRESENT	0
568509	566527	07029T	PARTICIPANT	\N	PRESENT	0
568510	566527	19447X	PARTICIPANT	\N	PRESENT	0
568511	566527	19719D	PARTICIPANT	\N	PRESENT	0
568512	566527	04085P	PARTICIPANT	\N	PRESENT	0
568513	566527	20112S	PARTICIPANT	\N	PRESENT	0
568514	566527	19695N	PARTICIPANT	\N	PRESENT	0
568515	566527	19551W	PARTICIPANT	\N	PRESENT	0
568516	566527	19347U	PARTICIPANT	\N	PRESENT	0
568517	566527	17023S	PARTICIPANT	\N	PRESENT	0
568518	566527	20124W	PARTICIPANT	\N	PRESENT	0
568519	566527	11099A	PARTICIPANT	\N	PRESENT	0
568520	566527	17637T	PARTICIPANT	\N	PRESENT	0
568521	566527	14215L	PARTICIPANT	\N	PRESENT	0
568522	566527	14053L	PARTICIPANT	\N	PRESENT	0
568523	566527	14179A	PARTICIPANT	\N	PRESENT	0
568524	567709	19515S	PARTICIPANT	\N	PRESENT	0
568525	567709	20092G	PARTICIPANT	\N	PRESENT	0
568526	567709	14187A	PARTICIPANT	\N	PRESENT	0
568527	567709	20144B	PARTICIPANT	\N	PRESENT	0
568528	567709	14033T	PARTICIPANT	\N	PRESENT	0
568529	567709	11090Q	PRESIDENT	0	PRESENT	0
568530	567709	19631V	PARTICIPANT	\N	PRESENT	1
568531	567709	11099A	PARTICIPANT	\N	PRESENT	0
568532	567709	19705W	PARTICIPANT	\N	PRESENT	0
568533	567709	19507S	PARTICIPANT	\N	PRESENT	0
568534	567709	08015R	PARTICIPANT	\N	PRESENT	0
568535	567709	19369B	PARTICIPANT	\N	PRESENT	0
568536	567709	14207L	PARTICIPANT	\N	PRESENT	0
568537	567709	14257W	PARTICIPANT	\N	PRESENT	0
568566	568565	17737W	PARTICIPANT	\N	PRESENT	0
568568	568567	17737W	PARTICIPANT	\N	PRESENT	0
568569	568567	14255U	PARTICIPANT	\N	PRESENT	0
568570	568567	14217N	PARTICIPANT	\N	PRESENT	0
568571	568567	11026G	PARTICIPANT	\N	PRESENT	0
568572	566878	04092N	PRESIDENT	0	PRESENT	0
568573	566878	14195A	PARTICIPANT	\N	PRESENT	0
568574	566878	99004R	PARTICIPANT	\N	PRESENT	0
568575	566878	04045F	PARTICIPANT	\N	PRESENT	0
568576	566878	19447X	PARTICIPANT	\N	PRESENT	0
568863	566529	19333N	PARTICIPANT	\N	PRESENT	0
568864	566529	14097Y	PARTICIPANT	\N	PRESENT	0
568865	566529	19599P	PARTICIPANT	\N	PRESENT	0
568580	568170	04047H	PRESIDENT	0	PRESENT	0
568581	568170	19673G	PARTICIPANT	\N	PRESENT	0
568582	568170	19729F	PARTICIPANT	\N	PRESENT	0
568866	566529	19631V	PARTICIPANT	\N	PRESENT	0
568867	566529	20018V	PARTICIPANT	\N	PRESENT	0
568585	566878	20132W	PARTICIPANT	\N	PRESENT	0
568586	566878	11067R	PARTICIPANT	\N	PRESENT	0
568587	566878	11045K	PARTICIPANT	\N	PRESENT	0
568588	566878	11066Q	PARTICIPANT	\N	PRESENT	0
568589	566878	14179A	PARTICIPANT	\N	PRESENT	0
568590	566878	19575F	PARTICIPANT	\N	PRESENT	0
568591	566878	14147R	PARTICIPANT	\N	PRESENT	0
568592	566878	14213J	PARTICIPANT	\N	PRESENT	0
568593	566878	14215L	PARTICIPANT	\N	PRESENT	0
568594	566878	19335Q	PARTICIPANT	\N	PRESENT	0
568595	566878	10006L	PARTICIPANT	\N	PRESENT	0
568596	566878	19683J	PARTICIPANT	\N	PRESENT	0
568597	566878	11026G	PARTICIPANT	\N	PRESENT	0
568598	566878	14217N	PARTICIPANT	\N	PRESENT	0
568868	566529	18193Q	PARTICIPANT	\N	PRESENT	0
568600	566878	20092G	PARTICIPANT	\N	PRESENT	0
568601	566878	11031D	PARTICIPANT	\N	PRESENT	0
568602	568170	14089Y	PARTICIPANT	\N	PRESENT	0
568603	568170	95063L	PARTICIPANT	\N	PRESENT	0
568604	568170	20108W	PARTICIPANT	\N	PRESENT	0
568605	566878	20066E	PARTICIPANT	\N	PRESENT	0
568869	566529	19347U	PARTICIPANT	\N	PRESENT	0
568870	566529	20142Y	PARTICIPANT	\N	PRESENT	0
568871	566529	19503N	PARTICIPANT	\N	PRESENT	0
568872	566529	19760E	PARTICIPANT	\N	PRESENT	0
568873	566529	19251M	PARTICIPANT	\N	PRESENT	0
568874	566529	14195A	PARTICIPANT	\N	PRESENT	0
568875	566529	19719D	PARTICIPANT	\N	PRESENT	0
568876	566529	14257W	PARTICIPANT	\N	PRESENT	0
568877	566529	19549D	PARTICIPANT	\N	PRESENT	0
568878	566529	19820Y	PARTICIPANT	\N	PRESENT	0
568879	566528	14133K	PARTICIPANT	\N	PRESENT	0
568880	566529	20072C	PARTICIPANT	\N	PRESENT	0
568881	566529	14267Y	PARTICIPANT	\N	PRESENT	0
568882	566529	19735D	PARTICIPANT	\N	PRESENT	0
568883	566529	19369B	PARTICIPANT	\N	PRESENT	0
568884	566528	19760E	PARTICIPANT	\N	PRESENT	0
568885	566528	14189C	PARTICIPANT	\N	PRESENT	0
568886	566528	19631V	PARTICIPANT	\N	PRESENT	0
568887	566528	04085P	PARTICIPANT	\N	PRESENT	0
568888	566529	14327T	PARTICIPANT	\N	PRESENT	0
568889	566528	04059M	PARTICIPANT	\N	PRESENT	0
568890	566528	19515S	PARTICIPANT	\N	PRESENT	0
568891	566529	20134Y	PARTICIPANT	\N	PRESENT	0
568892	566528	20076G	PARTICIPANT	\N	PRESENT	0
568893	566529	20106U	PARTICIPANT	\N	PRESENT	0
568894	566529	04045F	PARTICIPANT	\N	PRESENT	0
568895	566528	05008E	PARTICIPANT	\N	PRESENT	0
568896	566529	20100N	PARTICIPANT	\N	PRESENT	0
568897	566528	11033F	PARTICIPANT	\N	PRESENT	0
568898	566528	19575F	PARTICIPANT	\N	PRESENT	0
568899	566528	19549D	PARTICIPANT	\N	PRESENT	0
568900	566529	17229F	PARTICIPANT	\N	PRESENT	0
568901	566528	14030Q	PARTICIPANT	\N	PRESENT	0
568902	566528	17367Q	PARTICIPANT	\N	PRESENT	0
568903	566528	20094J	PARTICIPANT	\N	PRESENT	0
568904	566529	14205J	PARTICIPANT	\N	PRESENT	0
568905	566528	19367Y	PARTICIPANT	\N	PRESENT	0
568906	566529	19798U	PARTICIPANT	\N	PRESENT	0
568907	566528	14089Y	PARTICIPANT	\N	PRESENT	0
568908	566528	14105F	PARTICIPANT	\N	PRESENT	0
568909	566528	19643A	PARTICIPANT	\N	PRESENT	0
568910	566529	20062A	PARTICIPANT	\N	PRESENT	0
568649	568170	14231L	PARTICIPANT	\N	PRESENT	0
568911	566528	19747H	PARTICIPANT	\N	PRESENT	0
568912	566529	20108W	PARTICIPANT	\N	PRESENT	0
568913	566529	11090Q	PARTICIPANT	\N	PRESENT	0
568914	566529	05008E	PARTICIPANT	\N	PRESENT	0
568915	566529	14053L	PARTICIPANT	\N	PRESENT	0
568916	566529	19367Y	PARTICIPANT	\N	PRESENT	0
568917	566529	11097X	PARTICIPANT	\N	PRESENT	0
568918	566529	20056C	PARTICIPANT	\N	PRESENT	0
568658	568170	14179A	PARTICIPANT	\N	PRESENT	0
568919	566528	20080C	PARTICIPANT	\N	PRESENT	0
568920	566529	19467C	PARTICIPANT	\N	PRESENT	0
568921	566528	19758L	PARTICIPANT	\N	PRESENT	0
568922	566529	20076G	PARTICIPANT	\N	PRESENT	0
568923	566528	20090E	PARTICIPANT	\N	PRESENT	0
568862	566529	14026U	PARTICIPANT	\N	PRESENT	0
545442	545441	14038Y	PARTICIPANT	\N	PRESENT	0
545443	545441	19441R	PARTICIPANT	\N	PRESENT	0
545503	545502	11110B	PARTICIPANT	\N	PRESENT	0
545504	545502	20070A	PARTICIPANT	\N	PRESENT	0
545507	545506	20044X	PARTICIPANT	\N	PRESENT	0
545508	545506	08009T	PARTICIPANT	\N	PRESENT	0
545510	545509	08009T	PARTICIPANT	\N	PRESENT	0
545511	545509	20044X	PARTICIPANT	\N	PRESENT	0
545513	545512	11053K	PARTICIPANT	\N	PRESENT	0
546947	545406	19826F	PARTICIPANT	\N	PRESENT	0
546948	545406	19697Q	PARTICIPANT	\N	PRESENT	0
546949	545406	20024T	PARTICIPANT	\N	PRESENT	0
546950	545406	14259Y	PARTICIPANT	\N	PRESENT	0
546951	545406	20098N	PARTICIPANT	\N	PRESENT	0
546952	545406	20056C	PARTICIPANT	\N	PRESENT	0
546953	545406	20042V	PARTICIPANT	\N	PRESENT	0
546954	545406	19585H	PARTICIPANT	\N	PRESENT	0
546955	545406	19599P	PARTICIPANT	\N	PRESENT	0
546956	545406	19683J	PARTICIPANT	\N	PRESENT	0
546957	545406	20122U	PARTICIPANT	\N	PRESENT	0
546958	545406	20062A	PARTICIPANT	\N	PRESENT	0
546959	545406	19691J	PARTICIPANT	\N	PRESENT	0
546960	545406	19667J	PARTICIPANT	\N	PRESENT	0
546961	545406	11040E	PARTICIPANT	\N	PRESENT	0
546962	545406	04034C	PARTICIPANT	\N	PRESENT	0
546963	545406	11027H	PARTICIPANT	\N	PRESENT	0
546964	545406	11085T	PARTICIPANT	\N	PRESENT	0
546965	545406	18083K	PARTICIPANT	\N	PRESENT	0
546966	545406	11012A	PARTICIPANT	\N	PRESENT	0
546967	545406	19643A	PARTICIPANT	\N	PRESENT	0
546968	545406	14257W	PARTICIPANT	\N	PRESENT	0
546969	545406	20116W	PARTICIPANT	\N	PRESENT	0
546970	545406	20148F	PARTICIPANT	\N	PRESENT	0
546971	545406	14179A	PARTICIPANT	\N	PRESENT	0
546972	545406	19447X	PARTICIPANT	\N	PRESENT	0
546973	545406	14205J	PARTICIPANT	\N	PRESENT	0
546974	545406	14267Y	PARTICIPANT	\N	PRESENT	0
546975	545406	14221J	PARTICIPANT	\N	PRESENT	0
546976	545406	11033F	PARTICIPANT	\N	PRESENT	0
546977	545406	19685L	PARTICIPANT	\N	PRESENT	0
546978	545406	20048C	PARTICIPANT	\N	PRESENT	0
546979	545406	11104D	PARTICIPANT	\N	PRESENT	0
546980	545406	19695N	PARTICIPANT	\N	PRESENT	0
546981	545406	20082E	PARTICIPANT	\N	PRESENT	0
546982	545406	19768N	PARTICIPANT	\N	PRESENT	0
546983	545406	11066Q	PARTICIPANT	\N	PRESENT	0
546984	545406	11056N	PARTICIPANT	\N	PRESENT	0
546985	545406	14357A	PARTICIPANT	\N	PRESENT	0
546986	545406	08009T	PARTICIPANT	\N	PRESENT	0
546987	545406	19333N	PARTICIPANT	\N	PRESENT	0
546988	545406	14207L	PARTICIPANT	\N	PRESENT	0
546989	545406	20018V	PARTICIPANT	\N	PRESENT	0
546990	545406	20050V	PARTICIPANT	\N	PRESENT	0
546991	545406	11077T	PARTICIPANT	\N	PRESENT	0
546992	545406	19503N	PARTICIPANT	\N	PRESENT	0
546993	545406	14083S	PARTICIPANT	\N	PRESENT	0
546994	545406	19549D	PARTICIPANT	\N	PRESENT	0
546995	545406	17779H	PARTICIPANT	\N	PRESENT	0
546996	545406	19820Y	PARTICIPANT	\N	PRESENT	0
547003	545406	17637T	PARTICIPANT	\N	PRESENT	0
547004	545406	19711U	PARTICIPANT	\N	PRESENT	0
547005	545406	20106U	PARTICIPANT	\N	PRESENT	0
547006	545406	11048N	PARTICIPANT	\N	PRESENT	0
547007	545406	19591F	PARTICIPANT	\N	PRESENT	0
547008	545406	20076G	PARTICIPANT	\N	PRESENT	0
547009	545406	14097Y	PARTICIPANT	\N	PRESENT	0
547010	545406	19758L	PARTICIPANT	\N	PRESENT	0
547011	545406	20078J	PARTICIPANT	\N	PRESENT	0
547012	545406	12041X	PARTICIPANT	\N	PRESENT	0
547013	545406	20102Q	PARTICIPANT	\N	PRESENT	0
547014	545406	20100N	PARTICIPANT	\N	PRESENT	0
547015	545406	20128B	PARTICIPANT	\N	PRESENT	0
547016	545406	11083R	PARTICIPANT	\N	PRESENT	0
547017	545406	14249W	PARTICIPANT	\N	PRESENT	0
547018	545406	01057W	PARTICIPANT	\N	PRESENT	0
547019	545406	10015M	PARTICIPANT	\N	PRESENT	0
547020	545406	19703U	PARTICIPANT	\N	PRESENT	0
547021	545406	19563B	PARTICIPANT	\N	PRESENT	0
547022	545406	04057K	PARTICIPANT	\N	PRESENT	0
547023	545406	04035D	PARTICIPANT	\N	PRESENT	0
547024	545406	20130U	PARTICIPANT	\N	PRESENT	0
547025	545406	19347U	PARTICIPANT	\N	PRESENT	0
547026	545406	08010L	PARTICIPANT	\N	PRESENT	0
547027	545406	20072C	PARTICIPANT	\N	PRESENT	0
547028	545406	19681G	PARTICIPANT	\N	PRESENT	0
547029	545406	11031D	PARTICIPANT	\N	PRESENT	0
547030	545406	08061X	PARTICIPANT	\N	PRESENT	0
547031	545406	04033B	PARTICIPANT	\N	PRESENT	0
547032	545406	14187A	PARTICIPANT	\N	PRESENT	0
547033	545406	19387D	PARTICIPANT	\N	PRESENT	0
547034	545406	01043Q	PARTICIPANT	\N	PRESENT	0
547035	545406	14053L	PARTICIPANT	\N	PRESENT	0
547036	545406	20092G	PARTICIPANT	\N	PRESENT	0
547037	545406	19565D	PARTICIPANT	\N	PRESENT	0
547038	545406	05012A	PARTICIPANT	\N	PRESENT	0
547040	545406	11045K	PARTICIPANT	\N	PRESENT	0
547041	545406	14225N	PARTICIPANT	\N	PRESENT	0
547042	545406	04059M	PARTICIPANT	\N	PRESENT	0
547043	545406	14021P	PARTICIPANT	\N	PRESENT	0
547044	545406	11067R	PARTICIPANT	\N	PRESENT	0
547045	545406	20138D	PARTICIPANT	\N	PRESENT	0
547047	545406	19647E	PARTICIPANT	\N	PRESENT	0
547048	545406	20038A	PARTICIPANT	\N	PRESENT	0
547049	545406	11065P	PARTICIPANT	\N	PRESENT	0
547051	545406	19251M	PARTICIPANT	\N	PRESENT	0
547052	545406	19689Q	PARTICIPANT	\N	PRESENT	0
547053	545406	14069U	PARTICIPANT	\N	PRESENT	0
547054	545406	19533U	PARTICIPANT	\N	PRESENT	0
547055	545406	19531S	PARTICIPANT	\N	PRESENT	0
547056	545406	08012N	PARTICIPANT	\N	PRESENT	0
547057	545406	14217N	PARTICIPANT	\N	PRESENT	0
547058	545406	20080C	PARTICIPANT	\N	PRESENT	0
547059	545406	19725B	PARTICIPANT	\N	PRESENT	0
547060	545406	19581D	PARTICIPANT	\N	PRESENT	0
547061	545406	08017T	PARTICIPANT	\N	PRESENT	0
547062	545406	19367Y	PARTICIPANT	\N	PRESENT	0
547063	545406	19671E	PARTICIPANT	\N	PRESENT	0
547064	545406	14229S	PARTICIPANT	\N	PRESENT	0
547065	545406	20094J	PARTICIPANT	\N	PRESENT	0
547066	545406	20126Y	PARTICIPANT	\N	PRESENT	0
547067	545406	20054A	PARTICIPANT	\N	PRESENT	0
547068	545406	20040T	PARTICIPANT	\N	PRESENT	0
547069	545406	14329V	PARTICIPANT	\N	PRESENT	0
547070	545406	14089Y	PARTICIPANT	\N	PRESENT	0
547071	545406	20020P	PARTICIPANT	\N	PRESENT	0
547072	545406	14251Q	PARTICIPANT	\N	PRESENT	0
547073	545406	20172F	PARTICIPANT	\N	PRESENT	0
547074	545406	19699S	PARTICIPANT	\N	PRESENT	0
547075	545406	19479G	PARTICIPANT	\N	PRESENT	0
547076	545406	19441R	PARTICIPANT	\N	PRESENT	0
547077	545406	14219Q	PARTICIPANT	\N	PRESENT	0
547078	545406	19954N	PARTICIPANT	\N	PRESENT	0
547079	545406	19713W	PARTICIPANT	\N	PRESENT	0
547080	545406	20140W	PARTICIPANT	\N	PRESENT	0
547081	545406	14213J	PARTICIPANT	\N	PRESENT	0
547082	545406	14073Q	PARTICIPANT	\N	PRESENT	0
547083	545406	11053K	PARTICIPANT	\N	PRESENT	0
547084	545406	19399H	PARTICIPANT	\N	PRESENT	0
547085	545406	04070G	PARTICIPANT	\N	PRESENT	0
547086	545406	19701S	PARTICIPANT	\N	PRESENT	0
547087	545406	19573D	PARTICIPANT	\N	PRESENT	0
547088	545406	20096L	PARTICIPANT	\N	PRESENT	0
547089	545406	01058X	PARTICIPANT	\N	PRESENT	0
547090	545406	20058E	PARTICIPANT	\N	PRESENT	0
547091	545406	20044X	PARTICIPANT	\N	PRESENT	0
547092	545406	20026V	PARTICIPANT	\N	PRESENT	0
547093	545406	01024M	PARTICIPANT	\N	PRESENT	0
547094	545406	20180F	PARTICIPANT	\N	PRESENT	0
547095	545406	19739H	PARTICIPANT	\N	PRESENT	0
547096	545406	14033T	PARTICIPANT	\N	PRESENT	0
547103	545406	01028R	PARTICIPANT	\N	PRESENT	0
547098	545406	14331P	PARTICIPANT	\N	PRESENT	0
547099	545406	12028B	PARTICIPANT	\N	PRESENT	0
547100	545406	20070A	PARTICIPANT	\N	PRESENT	0
547101	545406	14042U	PARTICIPANT	\N	PRESENT	0
547102	545406	19747H	PARTICIPANT	\N	PRESENT	0
547104	545406	08034U	PARTICIPANT	\N	PRESENT	0
547105	545406	97011G	PARTICIPANT	\N	PRESENT	0
547106	545406	19515S	PARTICIPANT	\N	PRESENT	0
547107	545406	20136B	PARTICIPANT	\N	PRESENT	0
547108	545406	20104S	PARTICIPANT	\N	PRESENT	0
567112	566153	99004R	PARTICIPANT	\N	PRESENT	0
567113	566153	20116W	PARTICIPANT	\N	PRESENT	0
567114	566153	19335Q	PARTICIPANT	\N	PRESENT	0
567115	566153	20126Y	PARTICIPANT	\N	PRESENT	0
567116	566153	14189C	PARTICIPANT	\N	EXCUSE	0
567117	566153	20022R	PARTICIPANT	\N	EXCUSE	0
567118	565268	19723Y	PARTICIPANT	\N	PRESENT	1
567119	565268	19717B	PARTICIPANT	\N	PRESENT	1
567165	566453	20072C	PARTICIPANT	\N	PRESENT	0
567181	566556	14030Q	PARTICIPANT	\N	PRESENT	0
567182	566556	20038A	PARTICIPANT	\N	PRESENT	0
567183	566556	14109K	PARTICIPANT	\N	PRESENT	0
567705	567703	14187A	PARTICIPANT	\N	PRESENT	0
567185	566556	19798U	PARTICIPANT	\N	PRESENT	0
567704	567703	01043Q	PARTICIPANT	\N	PRESENT	0
567706	567703	19631V	PARTICIPANT	\N	PRESENT	0
567770	566018	14147R	PARTICIPANT	\N	PRESENT	0
567771	566018	08018U	PRESIDENT	0	PRESENT	0
567772	566018	95063L	PARTICIPANT	\N	PRESENT	0
567773	566018	11026G	PARTICIPANT	\N	PRESENT	0
567777	567776	19643A	PARTICIPANT	\N	PRESENT	1
567778	567776	18083K	PARTICIPANT	\N	PRESENT	0
567779	567776	20124W	PARTICIPANT	\N	PRESENT	1
567780	567776	19673G	PARTICIPANT	\N	PRESENT	0
567781	567776	04035D	PARTICIPANT	\N	PRESENT	1
567782	567776	14123H	PARTICIPANT	\N	PRESENT	0
567783	567776	19691J	PARTICIPANT	\N	PRESENT	0
567784	567776	20106U	PARTICIPANT	\N	PRESENT	0
567785	567776	08017T	PARTICIPANT	\N	PRESENT	0
567786	567776	04057K	PARTICIPANT	\N	PRESENT	0
567787	567776	19527W	PARTICIPANT	\N	PRESENT	0
567788	565256	20100N	PARTICIPANT	\N	PRESENT	0
567789	565256	19711U	PARTICIPANT	\N	PRESENT	0
567790	565256	14357A	PARTICIPANT	\N	PRESENT	0
567791	565256	11026G	PARTICIPANT	\N	PRESENT	0
567915	566440	14030Q	PARTICIPANT	\N	PRESENT	0
567793	565256	08018U	PARTICIPANT	\N	PRESENT	0
567794	566439	12041X	PARTICIPANT	\N	PRESENT	0
567795	565256	14089Y	PARTICIPANT	\N	PRESENT	1
567796	565256	14331P	PRESIDENT	0	PRESENT	0
567797	565256	04070G	PARTICIPANT	\N	PRESENT	1
567798	565256	14147R	PARTICIPANT	\N	PRESENT	0
567799	565256	04057K	PARTICIPANT	\N	EXCUSE	0
567800	566439	14030Q	PARTICIPANT	\N	PRESENT	0
567801	566439	20048C	PARTICIPANT	\N	PRESENT	0
567802	566439	19611R	PARTICIPANT	\N	PRESENT	0
567803	566439	20132W	PARTICIPANT	\N	PRESENT	0
567804	566439	19593H	PARTICIPANT	\N	PRESENT	0
567805	566439	19527W	PARTICIPANT	\N	PRESENT	0
567806	566439	19643A	PARTICIPANT	\N	PRESENT	0
567807	566439	20050V	PARTICIPANT	\N	PRESENT	0
567808	566439	20142Y	PARTICIPANT	\N	PRESENT	0
567809	566439	19651A	PARTICIPANT	\N	PRESENT	0
567810	566439	19533U	PARTICIPANT	\N	PRESENT	0
567811	566439	20052X	PARTICIPANT	\N	PRESENT	0
567812	566439	17229F	PARTICIPANT	\N	PRESENT	0
567813	566439	19399H	PARTICIPANT	\N	PRESENT	0
567814	566439	19667J	PARTICIPANT	\N	PRESENT	0
567815	566439	14041T	PARTICIPANT	\N	PRESENT	0
567816	566439	20066E	PARTICIPANT	\N	PRESENT	0
567817	566439	19599P	PARTICIPANT	\N	PRESENT	0
567818	566439	19739H	PARTICIPANT	\N	PRESENT	0
567819	566439	19629C	PARTICIPANT	\N	PRESENT	0
567820	565256	04035D	PARTICIPANT	\N	PRESENT	1
567821	565256	11101A	PARTICIPANT	\N	PRESENT	1
567822	566439	14021P	PARTICIPANT	\N	PRESENT	0
567823	566439	14147R	PARTICIPANT	\N	PRESENT	0
567824	566439	20114U	PARTICIPANT	\N	PRESENT	0
567825	566439	11012A	PARTICIPANT	\N	PRESENT	0
567826	566439	19369B	PARTICIPANT	\N	PRESENT	0
567827	566455	14059S	PARTICIPANT	\N	PRESENT	0
567828	566455	14097Y	PARTICIPANT	\N	PRESENT	0
567829	566455	14105F	PARTICIPANT	\N	PRESENT	1
567830	566455	14133K	PARTICIPANT	\N	PRESENT	0
567831	566455	08069G	PARTICIPANT	\N	PRESENT	0
567832	566455	19421M	PARTICIPANT	\N	PRESENT	1
567833	566455	20042V	PARTICIPANT	\N	PRESENT	1
567834	566455	19347U	PARTICIPANT	\N	PRESENT	1
567835	566455	11083R	PARTICIPANT	\N	PRESENT	0
567836	566455	04042C	PRESIDENT	0	PRESENT	0
567837	566455	14255U	PARTICIPANT	\N	PRESENT	0
567838	566455	16685X	PARTICIPANT	\N	EXCUSE	0
567839	566455	11054L	PARTICIPANT	\N	EXCUSE	0
567840	566439	20152B	PARTICIPANT	\N	PRESENT	0
567841	566439	19415P	PARTICIPANT	\N	PRESENT	0
567842	566455	01058X	PARTICIPANT	\N	PRESENT	0
567843	565256	95063L	PARTICIPANT	\N	PRESENT	0
567844	565256	14179A	PARTICIPANT	\N	PRESENT	1
567845	565256	14069U	PARTICIPANT	\N	PRESENT	1
567846	566439	14259Y	PARTICIPANT	\N	PRESENT	0
567849	566439	14205J	PARTICIPANT	\N	PRESENT	0
567850	566439	14215L	PARTICIPANT	\N	PRESENT	0
567851	566439	19711U	PARTICIPANT	\N	PRESENT	0
567857	566439	04045F	PARTICIPANT	\N	PRESENT	0
567858	566439	07029T	PARTICIPANT	\N	PRESENT	0
567859	566439	19649G	PARTICIPANT	\N	PRESENT	0
567894	566440	19649G	PARTICIPANT	\N	PRESENT	0
567914	566440	20066E	PARTICIPANT	\N	PRESENT	0
567896	566440	19599P	PARTICIPANT	\N	PRESENT	0
567897	566440	19591F	PARTICIPANT	\N	PRESENT	0
567898	566440	14215L	PARTICIPANT	\N	PRESENT	0
567899	566440	19711U	PARTICIPANT	\N	PRESENT	0
567900	566440	14147R	PARTICIPANT	\N	PRESENT	0
567901	566440	07029T	PARTICIPANT	\N	PRESENT	0
567916	566440	19415P	PARTICIPANT	\N	PRESENT	0
567903	566440	14205J	PARTICIPANT	\N	PRESENT	0
567904	566440	04085P	PARTICIPANT	\N	PRESENT	0
567922	566440	20052X	PARTICIPANT	\N	PRESENT	0
567906	566440	20050V	PARTICIPANT	\N	PRESENT	0
567907	566440	11033F	PARTICIPANT	\N	PRESENT	0
567908	566440	11012A	PARTICIPANT	\N	PRESENT	0
567920	566440	04047H	PARTICIPANT	\N	PRESENT	0
567910	566440	19643A	PARTICIPANT	\N	PRESENT	0
567911	566440	04045F	PARTICIPANT	\N	PRESENT	0
567921	566440	19749K	PARTICIPANT	\N	PRESENT	0
567913	566440	19629C	PARTICIPANT	\N	PRESENT	0
567925	566440	14217N	PARTICIPANT	\N	PRESENT	0
567928	567926	20092G	PARTICIPANT	\N	PRESENT	0
567929	567926	14357A	PARTICIPANT	\N	PRESENT	0
567930	566440	18083K	PARTICIPANT	\N	PRESENT	0
567931	559961	20024T	PARTICIPANT	\N	EXCUSE	0
567932	559961	14030Q	PRESIDENT	0	PRESENT	0
567933	559961	17737W	PARTICIPANT	\N	PRESENT	0
567934	559961	11031D	PARTICIPANT	\N	PRESENT	0
567935	559961	19599P	PARTICIPANT	\N	EXCUSE	0
567936	559961	04035D	PARTICIPANT	\N	PRESENT	1
567937	566440	11067R	PARTICIPANT	\N	PRESENT	0
567938	559961	20130U	PARTICIPANT	\N	EXCUSE	0
567892	566440	12041X	PARTICIPANT	\N	PRESENT	0
567893	566440	20114U	PARTICIPANT	\N	PRESENT	0
567941	559961	20118Y	PARTICIPANT	\N	EXCUSE	0
567942	559961	14109K	PARTICIPANT	\N	EXCUSE	0
567943	559961	20106U	PARTICIPANT	\N	EXCUSE	0
567944	566440	14042U	PARTICIPANT	\N	PRESENT	0
567947	567946	14053L	PARTICIPANT	\N	PRESENT	0
567948	567946	14299H	PARTICIPANT	\N	PRESENT	0
567950	567946	11066Q	PARTICIPANT	\N	PRESENT	0
567952	567946	04047H	PARTICIPANT	\N	PRESENT	0
568160	568159	11048N	PARTICIPANT	\N	PRESENT	0
568178	566553	20110Q	PARTICIPANT	\N	PRESENT	0
568182	568181	14231L	PARTICIPANT	\N	PRESENT	0
568183	568181	14259Y	PARTICIPANT	\N	PRESENT	0
568184	568181	19629C	PARTICIPANT	\N	PRESENT	0
568185	568181	20110Q	PARTICIPANT	\N	PRESENT	0
568188	568186	19515S	PARTICIPANT	\N	PRESENT	0
568189	568186	20084G	PARTICIPANT	\N	PRESENT	0
568191	568190	14259Y	PARTICIPANT	\N	PRESENT	0
568192	568190	14231L	PARTICIPANT	\N	PRESENT	0
568193	568190	20110Q	PARTICIPANT	\N	PRESENT	0
568194	568190	19749K	PARTICIPANT	\N	PRESENT	0
568196	568195	14259Y	PARTICIPANT	\N	PRESENT	0
568197	568195	14231L	PARTICIPANT	\N	PRESENT	0
568198	568195	20110Q	PARTICIPANT	\N	PRESENT	0
568199	568195	11056N	PARTICIPANT	\N	PRESENT	0
568201	568200	14259Y	PARTICIPANT	\N	PRESENT	0
568202	568200	14231L	PARTICIPANT	\N	PRESENT	0
568203	568200	20110Q	PARTICIPANT	\N	PRESENT	0
568204	568200	11056N	PARTICIPANT	\N	PRESENT	0
568205	568200	19749K	PARTICIPANT	\N	PRESENT	0
568206	568200	19489J	PARTICIPANT	\N	PRESENT	0
544042	544000	19503N	PARTICIPANT	\N	PRESENT	0
544043	544000	19820Y	PARTICIPANT	\N	PRESENT	0
544044	544000	19619A	PARTICIPANT	\N	PRESENT	0
544045	544000	20092G	PARTICIPANT	\N	PRESENT	0
544047	544046	19503N	PARTICIPANT	\N	PRESENT	0
544048	544046	19820Y	PARTICIPANT	\N	PRESENT	0
544049	544046	19619A	PARTICIPANT	\N	PRESENT	0
544050	544046	20092G	PARTICIPANT	\N	PRESENT	0
544052	544051	19820Y	PARTICIPANT	\N	PRESENT	0
544053	544051	19619A	PARTICIPANT	\N	PRESENT	0
544054	544051	20092G	PARTICIPANT	\N	PRESENT	0
544116	542823	20110Q	PARTICIPANT	\N	PRESENT	1
544117	542823	11033F	PARTICIPANT	\N	PRESENT	0
544119	542823	14053L	PARTICIPANT	\N	PRESENT	1
544120	542823	19629C	PARTICIPANT	\N	PRESENT	1
544121	542823	04008A	PARTICIPANT	\N	PRESENT	1
544122	542823	14179A	PARTICIPANT	\N	PRESENT	1
544123	542823	19447X	PARTICIPANT	\N	PRESENT	1
544124	542823	19489J	PARTICIPANT	\N	PRESENT	1
544125	542823	11026G	PARTICIPANT	\N	PRESENT	1
544126	542823	14147R	PARTICIPANT	\N	PRESENT	1
544127	542823	11072N	PARTICIPANT	\N	PRESENT	1
544128	542823	95063L	PARTICIPANT	\N	PRESENT	1
544129	542823	14107H	PARTICIPANT	\N	PRESENT	1
544130	542823	19675J	PARTICIPANT	\N	PRESENT	1
544131	542823	19749K	PARTICIPANT	\N	PRESENT	1
545168	542713	20132W	PARTICIPANT	\N	PRESENT	0
545169	542713	19735D	PARTICIPANT	\N	PRESENT	0
545170	542713	14147R	PARTICIPANT	\N	EXCUSE	0
545171	542713	19593H	PRESIDENT	0	PRESENT	0
545172	542713	20050V	PARTICIPANT	\N	PRESENT	1
545173	542713	19954N	PARTICIPANT	\N	PRESENT	0
545174	542713	19611R	PARTICIPANT	\N	PRESENT	0
545175	542713	20142Y	PARTICIPANT	\N	PRESENT	0
545176	542703	19954N	PARTICIPANT	\N	PRESENT	0
545178	542703	20132W	PARTICIPANT	\N	PRESENT	0
545179	542703	19593H	PRESIDENT	0	PRESENT	0
545180	542703	19611R	PARTICIPANT	\N	PRESENT	0
545181	542703	19715Y	PARTICIPANT	\N	PRESENT	0
545182	542703	19745F	PARTICIPANT	\N	PRESENT	0
545166	542713	19721W	PARTICIPANT	\N	PRESENT	0
545167	542713	19693L	PARTICIPANT	\N	PRESENT	0
545183	542703	19533U	PARTICIPANT	\N	PRESENT	0
545184	542703	20082E	PARTICIPANT	\N	PRESENT	0
545185	542703	20180F	PARTICIPANT	\N	PRESENT	0
545186	542703	19735D	PARTICIPANT	\N	PRESENT	0
545187	542703	20142Y	PARTICIPANT	\N	PRESENT	0
555759	555758	19798U	PARTICIPANT	\N	PRESENT	1
555760	555758	14042U	PARTICIPANT	\N	PRESENT	1
555762	555758	18193Q	PARTICIPANT	\N	PRESENT	1
555763	555758	04092N	PARTICIPANT	\N	PRESENT	1
555765	555758	14213J	PARTICIPANT	\N	PRESENT	1
555767	555758	19367Y	PARTICIPANT	\N	PRESENT	1
555768	555758	11067R	PARTICIPANT	\N	PRESENT	1
557347	555039	20052X	PARTICIPANT	\N	PRESENT	0
557349	555039	04043D	PARTICIPANT	\N	PRESENT	0
557350	555039	19621T	PARTICIPANT	\N	PRESENT	0
557351	555039	19689Q	PARTICIPANT	\N	PRESENT	0
557364	555039	19691J	PARTICIPANT	\N	PRESENT	0
557365	555039	19966S	PARTICIPANT	\N	PRESENT	0
557366	555039	11115U	PARTICIPANT	\N	PRESENT	0
557373	555039	14223L	PARTICIPANT	\N	PRESENT	0
557375	555039	19415P	PARTICIPANT	\N	PRESENT	0
557379	555039	14097Y	PARTICIPANT	\N	PRESENT	0
557382	555039	19563B	PARTICIPANT	\N	PRESENT	0
557395	555039	11056N	PARTICIPANT	\N	PRESENT	0
557396	555039	20092G	PARTICIPANT	\N	PRESENT	0
557397	555039	20026V	PARTICIPANT	\N	PRESENT	0
557398	555039	18083K	PARTICIPANT	\N	PRESENT	0
557399	555039	20048C	PARTICIPANT	\N	PRESENT	0
557400	555039	14205J	PARTICIPANT	\N	PRESENT	0
557417	555039	14073Q	PARTICIPANT	\N	PRESENT	0
557418	555039	14217N	PARTICIPANT	\N	PRESENT	0
557419	555039	19723Y	PARTICIPANT	\N	PRESENT	0
557420	555039	19713W	PARTICIPANT	\N	PRESENT	0
557429	555039	20122U	PARTICIPANT	\N	PRESENT	0
557484	555040	19711U	PARTICIPANT	\N	PRESENT	0
557485	555040	11070L	PARTICIPANT	\N	PRESENT	0
557486	555040	14121F	PARTICIPANT	\N	PRESENT	0
557487	555040	04045F	PARTICIPANT	\N	PRESENT	0
557488	555040	19525U	PARTICIPANT	\N	PRESENT	0
557489	555040	19551W	PARTICIPANT	\N	PRESENT	0
557490	555040	11040E	PARTICIPANT	\N	PRESENT	0
557491	555040	14221J	PARTICIPANT	\N	PRESENT	0
557455	555040	14026U	PARTICIPANT	\N	PRESENT	0
557483	555040	19681G	PARTICIPANT	\N	PRESENT	0
557492	555040	20090E	PARTICIPANT	\N	PRESENT	0
557493	555040	20038A	PARTICIPANT	\N	PRESENT	0
557494	555040	19399H	PARTICIPANT	\N	PRESENT	0
557495	555040	14169X	PARTICIPANT	\N	PRESENT	0
557496	555040	14031R	PARTICIPANT	\N	PRESENT	0
557497	555040	14038Y	PARTICIPANT	\N	PRESENT	0
557498	555040	11041F	PARTICIPANT	\N	PRESENT	0
557499	555040	20100N	PARTICIPANT	\N	PRESENT	0
557500	555040	14211G	PARTICIPANT	\N	PRESENT	0
557501	555040	11027H	PARTICIPANT	\N	PRESENT	0
557502	555040	11067R	PARTICIPANT	\N	PRESENT	0
557503	555040	14219Q	PARTICIPANT	\N	PRESENT	0
557504	555040	19691J	PARTICIPANT	\N	PRESENT	0
557505	555040	20092G	PARTICIPANT	\N	PRESENT	0
557514	555040	19415P	PARTICIPANT	\N	PRESENT	0
557522	555040	20134Y	PARTICIPANT	\N	PRESENT	0
557523	555040	14267Y	PARTICIPANT	\N	PRESENT	0
557527	555040	11012A	PARTICIPANT	\N	PRESENT	0
557531	555040	11085T	PARTICIPANT	\N	PRESENT	0
557536	555040	19467C	PARTICIPANT	\N	PRESENT	0
557537	555040	17589D	PARTICIPANT	\N	PRESENT	0
557549	555040	20026V	PARTICIPANT	\N	PRESENT	0
557550	555040	14083S	PARTICIPANT	\N	PRESENT	0
557551	555040	14030Q	PARTICIPANT	\N	PRESENT	0
557552	555040	19479G	PARTICIPANT	\N	PRESENT	0
557555	555040	19565D	PARTICIPANT	\N	PRESENT	0
557557	555040	19593H	PARTICIPANT	\N	PRESENT	0
557559	555040	20132W	PARTICIPANT	\N	PRESENT	0
557561	555040	20052X	PARTICIPANT	\N	PRESENT	0
557567	555040	19543W	PARTICIPANT	\N	PRESENT	0
557568	555040	19651A	PARTICIPANT	\N	PRESENT	0
557570	555040	20064C	PARTICIPANT	\N	PRESENT	0
557571	555040	11064N	PARTICIPANT	\N	PRESENT	0
557581	555040	19741B	PARTICIPANT	\N	PRESENT	0
557630	555041	20132W	PARTICIPANT	\N	PRESENT	0
557632	555041	11064N	PARTICIPANT	\N	PRESENT	0
557633	555041	19551W	PARTICIPANT	\N	PRESENT	0
557634	555041	11067R	PARTICIPANT	\N	PRESENT	0
557635	555041	17589D	PARTICIPANT	\N	PRESENT	0
557636	555041	20134Y	PARTICIPANT	\N	PRESENT	0
557637	555041	14109K	PARTICIPANT	\N	PRESENT	0
557638	555041	20052X	PARTICIPANT	\N	PRESENT	0
557639	555041	11041F	PARTICIPANT	\N	PRESENT	0
557641	555041	14251Q	PARTICIPANT	\N	PRESENT	0
557642	555041	08017T	PARTICIPANT	\N	PRESENT	0
557644	555041	19565D	PARTICIPANT	\N	PRESENT	0
557645	555041	19593H	PARTICIPANT	\N	PRESENT	0
557646	555041	20064C	PARTICIPANT	\N	PRESENT	0
557647	555041	11045K	PARTICIPANT	\N	PRESENT	0
557648	555041	14030Q	PARTICIPANT	\N	PRESENT	0
557649	555041	19651A	PARTICIPANT	\N	PRESENT	0
557650	555041	20034V	PARTICIPANT	\N	PRESENT	0
557651	555041	19543W	PARTICIPANT	\N	PRESENT	0
557652	555041	20026V	PARTICIPANT	\N	PRESENT	0
557653	555041	14038Y	PARTICIPANT	\N	PRESENT	0
557654	555041	19467C	PARTICIPANT	\N	PRESENT	0
557655	555041	04057K	PARTICIPANT	\N	PRESENT	0
557656	555041	19621T	PARTICIPANT	\N	PRESENT	0
557657	555041	08010L	PARTICIPANT	\N	PRESENT	0
557658	555041	11031D	PARTICIPANT	\N	PRESENT	0
557659	555041	01028R	PARTICIPANT	\N	PRESENT	0
557660	555041	14021P	PARTICIPANT	\N	PRESENT	0
557661	555041	14055N	PARTICIPANT	\N	PRESENT	0
557624	555041	14026U	PARTICIPANT	\N	PRESENT	0
557629	555041	19683J	PARTICIPANT	\N	PRESENT	0
557689	555041	19553Y	PARTICIPANT	\N	PRESENT	0
557691	555041	14221J	PARTICIPANT	\N	PRESENT	0
557692	555041	20050V	PARTICIPANT	\N	PRESENT	0
557698	555041	11012A	PARTICIPANT	\N	PRESENT	0
557710	555041	18193Q	PARTICIPANT	\N	PRESENT	0
557711	555041	19533U	PARTICIPANT	\N	PRESENT	0
557738	555041	19333N	PARTICIPANT	\N	PRESENT	0
557739	555041	11027H	PARTICIPANT	\N	PRESENT	0
557740	555041	11085T	PARTICIPANT	\N	PRESENT	0
557741	555041	95063L	PARTICIPANT	\N	PRESENT	0
568926	566528	14207L	PARTICIPANT	\N	PRESENT	0
568927	566528	14083S	PARTICIPANT	\N	PRESENT	0
568928	566529	14031R	PARTICIPANT	\N	PRESENT	0
568929	566529	20026V	PARTICIPANT	\N	PRESENT	0
568930	566528	11103C	PARTICIPANT	\N	PRESENT	0
568931	566529	20038A	PARTICIPANT	\N	PRESENT	0
568932	566528	14038Y	PARTICIPANT	\N	PRESENT	0
568933	566528	20144B	PARTICIPANT	\N	PRESENT	0
568934	566529	14219Q	PARTICIPANT	\N	PRESENT	0
568935	566528	19467C	PARTICIPANT	\N	PRESENT	0
568936	566528	19701S	PARTICIPANT	\N	PRESENT	0
568937	566529	19826F	PARTICIPANT	\N	PRESENT	0
568938	566528	14267Y	PARTICIPANT	\N	PRESENT	0
568939	566528	19681G	PARTICIPANT	\N	PRESENT	0
568940	566529	19701S	PARTICIPANT	\N	PRESENT	0
568941	566528	14357A	PARTICIPANT	\N	PRESENT	0
568942	566528	11065P	PARTICIPANT	\N	PRESENT	0
568943	566529	20046A	PARTICIPANT	\N	PRESENT	0
568944	566528	14259Y	PARTICIPANT	\N	PRESENT	0
568945	566528	11070L	PARTICIPANT	\N	PRESENT	0
568946	566529	20110Q	PARTICIPANT	\N	PRESENT	0
568947	566528	14327T	PARTICIPANT	\N	PRESENT	0
568948	566528	19663E	PARTICIPANT	\N	PRESENT	0
568949	566528	20140W	PARTICIPANT	\N	PRESENT	0
568950	566528	17229F	PARTICIPANT	\N	PRESENT	0
568951	566528	10006L	PARTICIPANT	\N	PRESENT	0
568952	566528	01024M	PARTICIPANT	\N	PRESENT	0
568953	566528	19251M	PARTICIPANT	\N	PRESENT	0
568954	566529	20094J	PARTICIPANT	\N	PRESENT	0
568955	566528	14215L	PARTICIPANT	\N	PRESENT	0
568956	566529	20080C	PARTICIPANT	\N	PRESENT	0
568957	566528	20134Y	PARTICIPANT	\N	PRESENT	0
568958	566528	20124W	PARTICIPANT	\N	PRESENT	0
568704	568170	19447X	PARTICIPANT	\N	PRESENT	0
568959	566528	07033P	PARTICIPANT	\N	PRESENT	0
568960	566528	19507S	PARTICIPANT	\N	PRESENT	0
568961	566528	14187A	PARTICIPANT	\N	PRESENT	0
568962	566528	19673G	PARTICIPANT	\N	PRESENT	0
568963	566528	20038A	PARTICIPANT	\N	PRESENT	0
568710	568170	04085P	PARTICIPANT	\N	PRESENT	1
568711	568170	20128B	PARTICIPANT	\N	PRESENT	1
568964	566528	01025N	PARTICIPANT	\N	PRESENT	0
568713	567611	19593H	PARTICIPANT	\N	PRESENT	0
568714	567611	04070G	PARTICIPANT	\N	PRESENT	0
568715	567611	20132W	PARTICIPANT	\N	PRESENT	0
568716	567611	19533U	PARTICIPANT	\N	PRESENT	0
568717	567611	19611R	PRESIDENT	0	PRESENT	0
568718	567611	20142Y	PARTICIPANT	\N	PRESENT	0
568719	567611	20048C	PARTICIPANT	\N	PRESENT	1
568720	567611	19693L	PARTICIPANT	\N	PRESENT	1
568721	567611	19399H	PARTICIPANT	\N	PRESENT	0
568722	567611	20152B	PARTICIPANT	\N	PRESENT	0
568723	567611	14229S	PARTICIPANT	\N	PRESENT	0
568724	567611	20098N	PARTICIPANT	\N	PRESENT	0
568725	567611	14030Q	PARTICIPANT	\N	PRESENT	1
568726	567611	20056C	PARTICIPANT	\N	PRESENT	0
568727	567611	20180F	PARTICIPANT	\N	PRESENT	0
568728	567611	19735D	PARTICIPANT	\N	PRESENT	0
568729	567611	08017T	PARTICIPANT	\N	PRESENT	0
568730	567611	14109K	PARTICIPANT	\N	PRESENT	1
568731	567611	20124W	PARTICIPANT	\N	PRESENT	0
568732	567611	19758L	PARTICIPANT	\N	PRESENT	0
568733	567611	20026V	PARTICIPANT	\N	PRESENT	0
568734	567611	19621T	PARTICIPANT	\N	PRESENT	1
568735	567611	11109J	PARTICIPANT	\N	EXCUSE	0
568965	566528	20100N	PARTICIPANT	\N	PRESENT	0
568966	566528	08045X	PARTICIPANT	\N	PRESENT	0
568967	566529	04092N	PARTICIPANT	\N	PRESENT	0
568968	566528	19599P	PARTICIPANT	\N	PRESENT	0
568969	566528	17023S	PARTICIPANT	\N	PRESENT	0
568970	566528	97011G	PARTICIPANT	\N	PRESENT	0
568971	566528	20172F	PARTICIPANT	\N	PRESENT	0
568972	566528	14231L	PARTICIPANT	\N	PRESENT	0
568973	566528	20120S	PARTICIPANT	\N	PRESENT	0
568974	566528	19820Y	PARTICIPANT	\N	PRESENT	0
568975	566528	19347U	PARTICIPANT	\N	PRESENT	0
568976	566528	20180F	PARTICIPANT	\N	PRESENT	0
568977	566528	14211G	PARTICIPANT	\N	PRESENT	0
568978	566528	19565D	PARTICIPANT	\N	PRESENT	0
568979	566528	14033T	PARTICIPANT	\N	PRESENT	0
568980	566528	01057W	PARTICIPANT	\N	PRESENT	0
568981	566528	11064N	PARTICIPANT	\N	PRESENT	0
568982	566528	19691J	PARTICIPANT	\N	PRESENT	0
568983	566528	20106U	PARTICIPANT	\N	PRESENT	0
568797	568171	14259Y	PARTICIPANT	\N	PRESENT	0
568798	568171	01028R	PARTICIPANT	\N	PRESENT	0
568799	568171	14231L	PARTICIPANT	\N	PRESENT	0
568800	568171	20108W	PARTICIPANT	\N	PRESENT	0
568801	568171	14147R	PARTICIPANT	\N	PRESENT	0
568802	568171	14089Y	PARTICIPANT	\N	PRESENT	0
568803	568171	14053L	PARTICIPANT	\N	PRESENT	0
568804	568136	14059S	PARTICIPANT	\N	PRESENT	0
568805	568136	14097Y	PARTICIPANT	\N	PRESENT	0
568806	568136	04035D	PARTICIPANT	\N	PRESENT	0
568807	568136	14133K	PRESIDENT	0	PRESENT	0
568808	568136	01062T	PARTICIPANT	\N	PRESENT	0
568809	568136	19565D	PARTICIPANT	\N	PRESENT	0
568810	568136	04034C	PARTICIPANT	\N	PRESENT	0
568811	568136	01058X	PARTICIPANT	\N	PRESENT	0
568812	568136	11027H	PARTICIPANT	\N	PRESENT	0
568813	568136	16685X	PARTICIPANT	\N	PRESENT	0
568814	568136	11054L	PARTICIPANT	\N	PRESENT	1
568815	568136	11066Q	PARTICIPANT	\N	PRESENT	0
568816	568136	12028B	PARTICIPANT	\N	PRESENT	0
568817	568136	14105F	PARTICIPANT	\N	PRESENT	0
568818	568136	19709B	PARTICIPANT	\N	PRESENT	0
568819	568136	14267Y	PARTICIPANT	\N	PRESENT	0
568820	568136	11064N	PARTICIPANT	\N	PRESENT	0
568821	568136	19347U	PARTICIPANT	\N	PRESENT	0
568822	568136	11083R	PARTICIPANT	\N	PRESENT	0
568823	568136	97011G	PARTICIPANT	\N	PRESENT	0
568824	568136	08061X	PARTICIPANT	\N	PRESENT	1
568825	568136	14211G	PARTICIPANT	\N	PRESENT	0
568827	568136	17023S	PARTICIPANT	\N	PRESENT	0
568828	568136	04042C	PARTICIPANT	\N	EXCUSE	0
568829	568171	95063L	PARTICIPANT	\N	PRESENT	0
568830	568171	14187A	PARTICIPANT	\N	PRESENT	0
568831	568171	04047H	PRESIDENT	0	PRESENT	0
568984	566528	20048C	PARTICIPANT	\N	PRESENT	0
568833	568171	14179A	PARTICIPANT	\N	PRESENT	0
568834	568171	05008E	PARTICIPANT	\N	PRESENT	0
568985	566528	19333N	PARTICIPANT	\N	PRESENT	0
568986	566528	19399H	PARTICIPANT	\N	PRESENT	0
568987	566529	20180F	PARTICIPANT	\N	PRESENT	0
568988	566528	20066E	PARTICIPANT	\N	PRESENT	0
568839	568171	20110Q	PARTICIPANT	\N	PRESENT	0
568989	566528	20056C	PARTICIPANT	\N	PRESENT	0
568991	566528	14097Y	PARTICIPANT	\N	PRESENT	0
568992	566529	19447X	PARTICIPANT	\N	PRESENT	0
568993	566528	99004R	PARTICIPANT	\N	PRESENT	0
568994	566529	14133K	PARTICIPANT	\N	PRESENT	0
568995	566528	20126Y	PARTICIPANT	\N	PRESENT	0
568996	566529	19507S	PARTICIPANT	\N	PRESENT	0
568997	566528	19735D	PARTICIPANT	\N	PRESENT	0
568998	566529	20140W	PARTICIPANT	\N	PRESENT	0
568999	566528	20102Q	PARTICIPANT	\N	PRESENT	0
569000	566528	19699S	PARTICIPANT	\N	PRESENT	0
569001	566529	14071N	PARTICIPANT	\N	PRESENT	0
569002	566528	08015R	PARTICIPANT	\N	PRESENT	0
569003	566528	19711U	PARTICIPANT	\N	PRESENT	0
568855	568171	19447X	PARTICIPANT	\N	PRESENT	1
568856	568171	14041T	PARTICIPANT	\N	PRESENT	1
568857	568171	10015M	PARTICIPANT	\N	PRESENT	1
568858	568171	11056N	PARTICIPANT	\N	PRESENT	1
569004	566528	18193Q	PARTICIPANT	\N	PRESENT	0
569005	566528	20108W	PARTICIPANT	\N	PRESENT	0
568924	566529	19515S	PARTICIPANT	\N	PRESENT	0
568925	566529	11067R	PARTICIPANT	\N	PRESENT	0
569006	566528	08010L	PARTICIPANT	\N	PRESENT	0
569007	566528	08017T	PARTICIPANT	\N	PRESENT	0
569008	566528	20052X	PARTICIPANT	\N	PRESENT	0
569009	566528	14205J	PARTICIPANT	\N	PRESENT	0
569010	566529	08015R	PARTICIPANT	\N	PRESENT	0
569011	566528	14219Q	PARTICIPANT	\N	PRESENT	0
569012	566528	01048V	PARTICIPANT	\N	PRESENT	0
569013	566528	14059S	PARTICIPANT	\N	PRESENT	0
569014	566529	20172F	PARTICIPANT	\N	PRESENT	0
569015	566528	19441R	PARTICIPANT	\N	PRESENT	0
569016	566528	14031R	PARTICIPANT	\N	PRESENT	0
542573	537784	19467C	PARTICIPANT	\N	PRESENT	0
542650	529005	20128B	PARTICIPANT	\N	PRESENT	0
542652	529005	01048V	PARTICIPANT	\N	PRESENT	0
542653	529005	14221J	PARTICIPANT	\N	PRESENT	0
542654	529005	19593H	PARTICIPANT	\N	PRESENT	0
542655	529005	11067R	PARTICIPANT	\N	PRESENT	0
542657	529005	01058X	PARTICIPANT	\N	PRESENT	0
542660	529005	04043D	PARTICIPANT	\N	PRESENT	0
542939	542937	20092G	PARTICIPANT	\N	PRESENT	0
542940	542937	20086J	PARTICIPANT	\N	PRESENT	0
542942	542941	20086J	PARTICIPANT	\N	PRESENT	0
542943	542941	14205J	PARTICIPANT	\N	PRESENT	0
542951	542950	20144B	PARTICIPANT	\N	PRESENT	0
542953	542952	20144B	PARTICIPANT	\N	PRESENT	0
542955	542954	20144B	PARTICIPANT	\N	PRESENT	0
542966	542965	14187A	PARTICIPANT	\N	PRESENT	0
542967	542965	01043Q	PARTICIPANT	\N	PRESENT	0
542969	542968	14187A	PARTICIPANT	\N	PRESENT	0
542970	542968	01043Q	PARTICIPANT	\N	PRESENT	0
547114	545406	19679N	PARTICIPANT	\N	PRESENT	0
547110	545406	20066E	PARTICIPANT	\N	PRESENT	0
547111	545406	19621T	PARTICIPANT	\N	PRESENT	0
547115	545406	19467C	PARTICIPANT	\N	PRESENT	0
547138	545406	14123H	PARTICIPANT	\N	PRESENT	0
547117	545406	14147R	PARTICIPANT	\N	PRESENT	0
547121	545406	14189C	PARTICIPANT	\N	PRESENT	0
547123	545406	04085P	PARTICIPANT	\N	PRESENT	0
547124	545406	20142Y	PARTICIPANT	\N	PRESENT	0
547125	545406	18193Q	PARTICIPANT	\N	PRESENT	0
547127	545406	19543W	PARTICIPANT	\N	PRESENT	0
547134	545406	04042C	PARTICIPANT	\N	PRESENT	0
547135	545406	20052X	PARTICIPANT	\N	PRESENT	0
547141	545406	14001X	PARTICIPANT	\N	PRESENT	0
547150	545406	19551W	PARTICIPANT	\N	PRESENT	0
547360	545407	01043Q	PARTICIPANT	\N	PRESENT	0
547370	545407	14001X	PARTICIPANT	\N	PRESENT	0
547371	545407	14097Y	PARTICIPANT	\N	PRESENT	0
547385	545407	19649G	PARTICIPANT	\N	PRESENT	0
547389	545407	14225N	PARTICIPANT	\N	PRESENT	0
547394	545407	11033F	PARTICIPANT	\N	PRESENT	0
547400	545407	19467C	PARTICIPANT	\N	PRESENT	0
547401	545407	14329V	PARTICIPANT	\N	PRESENT	0
547402	545407	20062A	PARTICIPANT	\N	PRESENT	0
547403	545407	19673G	PARTICIPANT	\N	PRESENT	0
547404	545407	11054L	PARTICIPANT	\N	PRESENT	0
547405	545407	19725B	PARTICIPANT	\N	PRESENT	0
547407	545407	11104D	PARTICIPANT	\N	PRESENT	0
547408	545407	19695N	PARTICIPANT	\N	PRESENT	0
547409	545407	19593H	PARTICIPANT	\N	PRESENT	0
547410	545407	20066E	PARTICIPANT	\N	PRESENT	0
547411	545407	11056N	PARTICIPANT	\N	PRESENT	0
547412	545407	20038A	PARTICIPANT	\N	PRESENT	0
547413	545407	07004J	PARTICIPANT	\N	PRESENT	0
547414	545407	14147R	PARTICIPANT	\N	PRESENT	0
547415	545407	19711U	PARTICIPANT	\N	PRESENT	0
547416	545407	19581D	PARTICIPANT	\N	PRESENT	0
547418	545407	19447X	PARTICIPANT	\N	PRESENT	0
547419	545407	04047H	PARTICIPANT	\N	PRESENT	0
547420	545407	20052X	PARTICIPANT	\N	PRESENT	0
547421	545407	14275Y	PARTICIPANT	\N	PRESENT	0
547422	545407	19441R	PARTICIPANT	\N	PRESENT	0
547423	545407	19621T	PARTICIPANT	\N	PRESENT	0
547424	545407	11012A	PARTICIPANT	\N	PRESENT	0
547425	545407	14041T	PARTICIPANT	\N	PRESENT	0
547426	545407	20116W	PARTICIPANT	\N	PRESENT	0
547429	545407	14059S	PARTICIPANT	\N	PRESENT	0
547430	545407	20022R	PARTICIPANT	\N	PRESENT	0
547431	545407	19367Y	PARTICIPANT	\N	PRESENT	0
547432	545407	20048C	PARTICIPANT	\N	PRESENT	0
547433	545407	19671E	PARTICIPANT	\N	PRESENT	0
547434	545407	14055N	PARTICIPANT	\N	PRESENT	0
547435	545407	14215L	PARTICIPANT	\N	PRESENT	0
547436	545407	20136B	PARTICIPANT	\N	PRESENT	0
547437	545407	20020P	PARTICIPANT	\N	PRESENT	0
547438	545407	04086Q	PARTICIPANT	\N	PRESENT	0
547439	545407	99004R	PARTICIPANT	\N	PRESENT	0
547440	545407	19651A	PARTICIPANT	\N	PRESENT	0
547441	545407	19479G	PARTICIPANT	\N	PRESENT	0
547442	545407	19515S	PARTICIPANT	\N	PRESENT	0
547443	545407	20082E	PARTICIPANT	\N	PRESENT	0
547444	545407	20072C	PARTICIPANT	\N	PRESENT	0
547445	545407	20054A	PARTICIPANT	\N	PRESENT	0
547446	545407	20098N	PARTICIPANT	\N	PRESENT	0
547447	545407	14042U	PARTICIPANT	\N	PRESENT	0
547449	545407	14089Y	PARTICIPANT	\N	PRESENT	0
547450	545407	19826F	PARTICIPANT	\N	PRESENT	0
547451	545407	19691J	PARTICIPANT	\N	PRESENT	0
547452	545407	08017T	PARTICIPANT	\N	PRESENT	0
547453	545407	19697Q	PARTICIPANT	\N	PRESENT	0
547454	545407	20138D	PARTICIPANT	\N	PRESENT	0
547455	545407	19533U	PARTICIPANT	\N	PRESENT	0
547456	545407	20090E	PARTICIPANT	\N	PRESENT	0
547457	545407	20172F	PARTICIPANT	\N	PRESENT	0
547458	545407	20180F	PARTICIPANT	\N	PRESENT	0
547459	545407	20112S	PARTICIPANT	\N	PRESENT	0
547460	545407	04057K	PARTICIPANT	\N	PRESENT	0
547461	545407	19703U	PARTICIPANT	\N	PRESENT	0
547462	545407	14189C	PARTICIPANT	\N	PRESENT	0
547463	545407	14179A	PARTICIPANT	\N	PRESENT	0
547464	545407	20110Q	PARTICIPANT	\N	PRESENT	0
547465	545407	11045K	PARTICIPANT	\N	PRESENT	0
547466	545407	19689Q	PARTICIPANT	\N	PRESENT	0
547467	545407	20070A	PARTICIPANT	\N	PRESENT	0
547468	545407	20044X	PARTICIPANT	\N	PRESENT	0
547472	545407	19749K	PARTICIPANT	\N	PRESENT	0
547470	545407	20084G	PARTICIPANT	\N	PRESENT	0
547471	545407	19954N	PARTICIPANT	\N	PRESENT	0
547473	545407	14357A	PARTICIPANT	\N	PRESENT	0
547474	545407	11097X	PARTICIPANT	\N	PRESENT	0
547475	545407	18083K	PARTICIPANT	\N	PRESENT	0
547476	545407	19573D	PARTICIPANT	\N	PRESENT	0
547477	545407	19399H	PARTICIPANT	\N	PRESENT	0
547478	545407	19768N	PARTICIPANT	\N	PRESENT	0
547479	545407	19443T	PARTICIPANT	\N	PRESENT	0
547480	545407	08010L	PARTICIPANT	\N	PRESENT	0
547481	545407	20106U	PARTICIPANT	\N	PRESENT	0
547482	545407	10015M	PARTICIPANT	\N	PRESENT	0
547483	545407	19387D	PARTICIPANT	\N	PRESENT	0
547484	545407	20140W	PARTICIPANT	\N	PRESENT	0
547485	545407	17737W	PARTICIPANT	\N	PRESENT	0
547486	545407	20108W	PARTICIPANT	\N	PRESENT	0
547487	545407	19758L	PARTICIPANT	\N	PRESENT	0
547488	545407	19563B	PARTICIPANT	\N	PRESENT	0
547489	545407	14213J	PARTICIPANT	\N	PRESENT	0
547490	545407	19569H	PARTICIPANT	\N	PRESENT	0
547495	545407	20100N	PARTICIPANT	\N	PRESENT	0
547496	545407	20126Y	PARTICIPANT	\N	PRESENT	0
547497	545407	19667J	PARTICIPANT	\N	PRESENT	0
547499	545407	20058E	PARTICIPANT	\N	PRESENT	0
547501	545407	05008E	PARTICIPANT	\N	PRESENT	0
547502	545407	14053L	PARTICIPANT	\N	PRESENT	0
547503	545407	11077T	PARTICIPANT	\N	PRESENT	0
547504	545407	14033T	PARTICIPANT	\N	PRESENT	0
547505	545407	20056C	PARTICIPANT	\N	PRESENT	0
547506	545407	20024T	PARTICIPANT	\N	PRESENT	0
547507	545407	19747H	PARTICIPANT	\N	PRESENT	0
547508	545407	20034V	PARTICIPANT	\N	PRESENT	0
547509	545407	08034U	PARTICIPANT	\N	PRESENT	0
547510	545407	14259Y	PARTICIPANT	\N	PRESENT	0
547511	545407	19503N	PARTICIPANT	\N	PRESENT	0
547512	545407	14231L	PARTICIPANT	\N	PRESENT	0
547513	545407	20102Q	PARTICIPANT	\N	PRESENT	0
547514	545407	19415P	PARTICIPANT	\N	PRESENT	0
547515	545407	14217N	PARTICIPANT	\N	PRESENT	0
547521	545407	14021P	PARTICIPANT	\N	PRESENT	0
547517	545407	18193Q	PARTICIPANT	\N	PRESENT	0
547518	545407	14073Q	PARTICIPANT	\N	PRESENT	0
547522	545407	14249W	PARTICIPANT	\N	PRESENT	0
547523	545407	01024M	PARTICIPANT	\N	PRESENT	0
547524	545407	20026V	PARTICIPANT	\N	PRESENT	0
547525	545407	08061X	PARTICIPANT	\N	PRESENT	0
547527	545407	19489J	PARTICIPANT	\N	PRESENT	0
547528	545407	19762G	PARTICIPANT	\N	PRESENT	0
547529	545407	20064C	PARTICIPANT	\N	PRESENT	0
547532	545407	19713W	PARTICIPANT	\N	PRESENT	0
547533	545407	20092G	PARTICIPANT	\N	PRESENT	0
568208	568207	14231L	PARTICIPANT	\N	PRESENT	0
568210	568209	14259Y	PARTICIPANT	\N	PRESENT	0
568211	568209	14231L	PARTICIPANT	\N	PRESENT	0
568212	568209	20110Q	PARTICIPANT	\N	PRESENT	0
568214	568213	14231L	PARTICIPANT	\N	PRESENT	0
568216	568215	14259Y	PARTICIPANT	\N	PRESENT	0
568217	568215	14231L	PARTICIPANT	\N	PRESENT	0
568218	568215	19749K	PARTICIPANT	\N	PRESENT	0
568219	568215	14001X	PARTICIPANT	\N	PRESENT	0
568221	568220	14259Y	PARTICIPANT	\N	PRESENT	0
568222	568220	14231L	PARTICIPANT	\N	PRESENT	0
568223	568220	19749K	PARTICIPANT	\N	PRESENT	0
568224	568220	19649G	PARTICIPANT	\N	PRESENT	0
568226	568225	14259Y	PARTICIPANT	\N	PRESENT	0
568227	568225	14231L	PARTICIPANT	\N	PRESENT	0
568228	568225	19749K	PARTICIPANT	\N	PRESENT	0
568257	568256	19367Y	PARTICIPANT	\N	PRESENT	0
568258	568256	14213J	PARTICIPANT	\N	PRESENT	0
568259	568256	11067R	PARTICIPANT	\N	PRESENT	0
568261	568260	19367Y	PARTICIPANT	\N	PRESENT	0
568262	568260	14213J	PARTICIPANT	\N	PRESENT	0
568263	568260	11067R	PARTICIPANT	\N	PRESENT	0
568267	568266	14267Y	PARTICIPANT	\N	PRESENT	0
568268	568266	12028B	PARTICIPANT	\N	PRESENT	0
568269	568266	11064N	PARTICIPANT	\N	PRESENT	0
568270	568266	14105F	PARTICIPANT	\N	PRESENT	1
568272	568271	14267Y	PARTICIPANT	\N	PRESENT	0
568273	568271	12028B	PARTICIPANT	\N	PRESENT	0
568274	568271	14105F	PARTICIPANT	\N	PRESENT	0
568275	568271	97011G	PARTICIPANT	\N	PRESENT	0
568277	568276	19667J	PARTICIPANT	\N	PRESENT	0
568278	568276	11040E	PARTICIPANT	\N	PRESENT	0
568280	568279	19667J	PARTICIPANT	\N	PRESENT	0
568281	568279	11040E	PARTICIPANT	\N	PRESENT	0
568283	568282	19667J	PARTICIPANT	\N	PRESENT	0
568284	568282	11040E	PARTICIPANT	\N	PRESENT	0
568299	568298	14133K	PARTICIPANT	\N	PRESENT	0
568356	567376	20100N	PARTICIPANT	\N	PRESENT	0
568357	567376	14031R	PARTICIPANT	\N	PRESENT	0
568358	567376	19619A	PARTICIPANT	\N	PRESENT	1
568359	567376	19699S	PARTICIPANT	\N	PRESENT	0
568391	568390	14259Y	PARTICIPANT	\N	PRESENT	0
568550	568549	08069G	PARTICIPANT	\N	PRESENT	0
568551	568549	20136B	PARTICIPANT	\N	PRESENT	0
568553	568552	14053L	PARTICIPANT	\N	PRESENT	0
568554	568552	04070G	PARTICIPANT	\N	PRESENT	0
568556	568555	14097Y	PARTICIPANT	\N	PRESENT	0
568557	568555	14041T	PARTICIPANT	\N	PRESENT	0
568558	568555	14357A	PARTICIPANT	\N	PRESENT	0
568560	568559	14357A	PARTICIPANT	\N	PRESENT	0
568561	568559	14041T	PARTICIPANT	\N	PRESENT	0
568562	568559	14071N	PARTICIPANT	\N	PRESENT	0
568563	568559	14133K	PARTICIPANT	\N	PRESENT	0
568564	568559	19647E	PARTICIPANT	\N	PRESENT	0
568700	566878	19553Y	PARTICIPANT	\N	PRESENT	1
568701	566878	18083K	PARTICIPANT	\N	PRESENT	1
568702	566878	14042U	PARTICIPANT	\N	PRESENT	1
568703	566878	19569H	PARTICIPANT	\N	EXCUSE	0
568739	567611	14053L	PARTICIPANT	\N	PRESENT	0
568743	568255	19715Y	PARTICIPANT	\N	PRESENT	1
568744	568255	20130U	PARTICIPANT	\N	PRESENT	1
568746	568255	11031D	PARTICIPANT	\N	PRESENT	1
568750	568748	19719D	PARTICIPANT	\N	PRESENT	0
568751	568748	14030Q	PARTICIPANT	\N	PRESENT	0
568752	568748	19383Y	PARTICIPANT	\N	PRESENT	1
568753	568748	14109K	PARTICIPANT	\N	PRESENT	1
568754	568748	19798U	PARTICIPANT	\N	PRESENT	1
568759	567596	10006L	PRESIDENT	0	PRESENT	0
568760	567596	20130U	PARTICIPANT	\N	EXCUSE	0
568761	567596	19367Y	PARTICIPANT	\N	PRESENT	0
568762	567596	14026U	PARTICIPANT	\N	PRESENT	0
568763	567596	19798U	PARTICIPANT	\N	PRESENT	0
568764	567596	01034P	PARTICIPANT	\N	PRESENT	1
568765	567596	14223L	PARTICIPANT	\N	PRESENT	1
568766	567596	11097X	PARTICIPANT	\N	PRESENT	0
568767	567596	19717B	PARTICIPANT	\N	PRESENT	1
568768	567596	11103C	PARTICIPANT	\N	PRESENT	1
568769	567596	19295A	PARTICIPANT	\N	EXCUSE	0
568770	567596	04043D	PARTICIPANT	\N	PRESENT	0
568771	567596	19697Q	PARTICIPANT	\N	PRESENT	0
568772	567596	14042U	PARTICIPANT	\N	PRESENT	0
568774	567596	14071N	PARTICIPANT	\N	PRESENT	0
568775	567596	20066E	PARTICIPANT	\N	PRESENT	0
568776	567596	17965H	PARTICIPANT	\N	PRESENT	0
568778	568777	14267Y	PARTICIPANT	\N	PRESENT	0
568779	568777	12028B	PARTICIPANT	\N	PRESENT	0
568780	568777	97011G	PARTICIPANT	\N	PRESENT	0
568781	568777	11064N	PARTICIPANT	\N	PRESENT	0
568783	568782	14267Y	PARTICIPANT	\N	PRESENT	0
568784	568782	12028B	PARTICIPANT	\N	PRESENT	0
568785	568782	97011G	PARTICIPANT	\N	PRESENT	0
568786	567596	19569H	PARTICIPANT	\N	PRESENT	0
568793	567596	19760E	PARTICIPANT	\N	PRESENT	0
568794	567596	11067R	PARTICIPANT	\N	PRESENT	0
568795	567596	14195A	PARTICIPANT	\N	PRESENT	0
568796	567596	14213J	PARTICIPANT	\N	PRESENT	0
569661	568172	14053L	PARTICIPANT	\N	PRESENT	0
569662	568172	14267Y	PARTICIPANT	\N	PRESENT	0
569664	568172	07004J	PARTICIPANT	\N	PRESENT	0
569665	568172	01028R	PARTICIPANT	\N	PRESENT	0
569663	568172	19593H	PARTICIPANT	\N	PRESENT	0
569666	568172	14089Y	PARTICIPANT	\N	PRESENT	0
569667	568172	14111D	PARTICIPANT	\N	PRESENT	0
569668	568172	11085T	PARTICIPANT	\N	PRESENT	0
569669	568172	04008A	PARTICIPANT	\N	PRESENT	0
569670	568172	04047H	PRESIDENT	0	PRESENT	0
569671	568172	11026G	PARTICIPANT	\N	PRESENT	0
569672	568172	95063L	PARTICIPANT	\N	PRESENT	0
569673	568172	14147R	PARTICIPANT	\N	PRESENT	0
569674	568172	19729F	PARTICIPANT	\N	PRESENT	0
569675	568172	19749K	PARTICIPANT	\N	PRESENT	0
569676	567379	20076G	PARTICIPANT	\N	PRESENT	0
569677	567379	19820Y	PARTICIPANT	\N	PRESENT	0
569678	567379	14219Q	PRESIDENT	0	PRESENT	0
569679	567379	20020P	PARTICIPANT	\N	PRESENT	0
569680	567379	14169X	PARTICIPANT	\N	PRESENT	0
569681	567613	10006L	PRESIDENT	0	PRESENT	0
569682	567613	14042U	PARTICIPANT	\N	PRESENT	0
569683	567613	19367Y	PARTICIPANT	\N	PRESENT	0
569684	567613	19691J	PARTICIPANT	\N	PRESENT	1
569685	567688	14327T	PARTICIPANT	\N	PRESENT	0
569686	567688	11048N	PARTICIPANT	\N	PRESENT	0
569687	567688	01048V	PARTICIPANT	\N	PRESENT	0
569688	567688	01057W	PARTICIPANT	\N	PRESENT	0
569689	567688	11074Q	PARTICIPANT	\N	PRESENT	0
569690	567688	14225N	PRESIDENT	0	PRESENT	0
569691	567688	14173T	PARTICIPANT	\N	PRESENT	0
569692	567688	14083S	PARTICIPANT	\N	PRESENT	0
569693	567688	11012A	PARTICIPANT	\N	PRESENT	0
569694	567688	99004R	PARTICIPANT	\N	PRESENT	0
569695	567688	14253S	PARTICIPANT	\N	PRESENT	0
569696	567688	20116W	PARTICIPANT	\N	PRESENT	0
569697	567688	20126Y	PARTICIPANT	\N	PRESENT	0
569698	567688	08034U	PARTICIPANT	\N	EXCUSE	0
569699	567688	08011M	PARTICIPANT	\N	PRESENT	0
569700	567688	19671E	PARTICIPANT	\N	PRESENT	0
569701	567688	19335Q	PARTICIPANT	\N	PRESENT	0
569702	567613	14071N	PARTICIPANT	\N	PRESENT	0
569703	567613	11067R	PARTICIPANT	\N	PRESENT	0
569704	567613	19798U	PARTICIPANT	\N	PRESENT	0
569705	567613	11097X	PARTICIPANT	\N	PRESENT	0
569706	567613	20172F	PARTICIPANT	\N	PRESENT	0
569707	567613	14195A	PARTICIPANT	\N	PRESENT	0
569708	567613	04092N	PARTICIPANT	\N	PRESENT	0
569709	567613	04043D	PARTICIPANT	\N	PRESENT	0
569710	567613	19569H	PARTICIPANT	\N	PRESENT	1
569711	567613	19697Q	PARTICIPANT	\N	PRESENT	1
569712	567379	19333N	PARTICIPANT	\N	PRESENT	0
569713	567379	20136B	PARTICIPANT	\N	PRESENT	0
569714	567379	14031R	PARTICIPANT	\N	PRESENT	0
569715	567379	20140W	PARTICIPANT	\N	PRESENT	0
569716	567379	19251M	PARTICIPANT	\N	PRESENT	0
569717	567379	19826F	PARTICIPANT	\N	PRESENT	0
569718	567379	20100N	PARTICIPANT	\N	PRESENT	0
569719	567379	20106U	PARTICIPANT	\N	PRESENT	0
569720	567379	20068G	PARTICIPANT	\N	PRESENT	0
569721	567379	20118Y	PARTICIPANT	\N	PRESENT	0
569722	567379	19503N	PARTICIPANT	\N	PRESENT	0
569723	567379	19739H	PARTICIPANT	\N	PRESENT	0
569724	567379	17367Q	PARTICIPANT	\N	PRESENT	0
569725	567379	19387D	PARTICIPANT	\N	PRESENT	1
545573	534870	01028R	PARTICIPANT	\N	EXCUSE	0
545627	539666	19553Y	PARTICIPANT	\N	PRESENT	0
545628	539666	19711U	PARTICIPANT	\N	PRESENT	0
545629	539666	11097X	PARTICIPANT	\N	PRESENT	0
545630	536983	19711U	PARTICIPANT	\N	PRESENT	0
545631	536983	11097X	PARTICIPANT	\N	PRESENT	0
545632	536984	19553Y	PARTICIPANT	\N	PRESENT	0
545633	536984	19711U	PARTICIPANT	\N	PRESENT	0
545634	543076	19711U	PARTICIPANT	\N	PRESENT	0
545635	543076	11097X	PARTICIPANT	\N	PRESENT	0
548103	534870	19515S	PARTICIPANT	\N	PRESENT	0
548108	534870	14030Q	PARTICIPANT	\N	PRESENT	0
548113	534870	20082E	PARTICIPANT	\N	PRESENT	0
548249	548248	14187A	PARTICIPANT	\N	PRESENT	0
548250	548248	01043Q	PARTICIPANT	\N	PRESENT	0
548252	548251	14187A	PARTICIPANT	\N	PRESENT	0
548254	548253	14187A	PARTICIPANT	\N	PRESENT	0
548255	548253	01043Q	PARTICIPANT	\N	PRESENT	0
548258	542796	19347U	PARTICIPANT	\N	PRESENT	0
548259	542796	20034V	PARTICIPANT	\N	PRESENT	0
548260	542796	19715Y	PARTICIPANT	\N	PRESENT	0
548261	542796	12016W	PARTICIPANT	\N	PRESENT	0
548262	542796	14147R	PARTICIPANT	\N	PRESENT	0
548263	542796	19657G	PARTICIPANT	\N	PRESENT	0
548264	542796	20150Y	PARTICIPANT	\N	PRESENT	0
551544	551543	14259Y	PRESIDENT	0	PRESENT	0
554673	554671	11027H	PARTICIPANT	\N	PRESENT	1
551546	551543	11097X	PARTICIPANT	\N	PRESENT	0
551547	542833	19711U	PARTICIPANT	\N	PRESENT	0
551548	542833	19553Y	PARTICIPANT	\N	PRESENT	0
551549	542833	11097X	PARTICIPANT	\N	PRESENT	0
551550	547140	19553Y	PARTICIPANT	\N	PRESENT	0
551551	547140	19711U	PARTICIPANT	\N	PRESENT	0
551552	547140	11097X	PARTICIPANT	\N	PRESENT	0
551554	551543	01028R	PARTICIPANT	\N	EXCUSE	0
554672	554671	19709B	PARTICIPANT	\N	PRESENT	1
554675	554674	14327T	PARTICIPANT	\N	PRESENT	0
554677	554676	14253S	PARTICIPANT	\N	PRESENT	0
554678	554676	08011M	PARTICIPANT	\N	PRESENT	0
554680	554679	14253S	PARTICIPANT	\N	PRESENT	0
554681	554679	08011M	PARTICIPANT	\N	PRESENT	0
554683	554682	14173T	PARTICIPANT	\N	PRESENT	0
554690	554689	19667J	PARTICIPANT	\N	PRESENT	0
554691	554689	11040E	PARTICIPANT	\N	PRESENT	0
554709	554708	20050V	PARTICIPANT	\N	PRESENT	0
556716	556715	19954N	PARTICIPANT	\N	PRESENT	0
556717	556715	19747H	PARTICIPANT	\N	PRESENT	0
556718	556715	19709B	PARTICIPANT	\N	PRESENT	0
556719	556715	08010L	PARTICIPANT	\N	PRESENT	0
556734	556731	14147R	PARTICIPANT	\N	PRESENT	0
556721	556715	08017T	PARTICIPANT	\N	PRESENT	0
556722	556715	04057K	PARTICIPANT	\N	PRESENT	0
556723	556715	20096L	PARTICIPANT	\N	PRESENT	0
556724	556715	20098N	PARTICIPANT	\N	PRESENT	0
556725	556715	04045F	PARTICIPANT	\N	PRESENT	0
556733	556731	14073Q	PARTICIPANT	\N	PRESENT	0
556735	556731	20126Y	PARTICIPANT	\N	PRESENT	0
556736	556731	19515S	PARTICIPANT	\N	PRESENT	0
556737	556731	14169X	PARTICIPANT	\N	PRESENT	0
556738	556731	20056C	PARTICIPANT	\N	PRESENT	0
556739	556731	16685X	PARTICIPANT	\N	PRESENT	0
556740	556731	11026G	PARTICIPANT	\N	PRESENT	0
556741	556731	14083S	PARTICIPANT	\N	PRESENT	0
557563	557562	11097X	PARTICIPANT	\N	PRESENT	0
557564	557562	20130U	PARTICIPANT	\N	PRESENT	0
557565	557562	17779H	PARTICIPANT	\N	PRESENT	0
557566	557562	14042U	PARTICIPANT	\N	PRESENT	0
557742	555041	04034C	PARTICIPANT	\N	PRESENT	0
557743	555041	11083R	PARTICIPANT	\N	PRESENT	0
557790	555042	04057K	PARTICIPANT	\N	PRESENT	0
557791	555042	14255U	PARTICIPANT	\N	PRESENT	0
557792	555042	14030Q	PARTICIPANT	\N	PRESENT	0
557793	555042	19543W	PARTICIPANT	\N	PRESENT	0
557795	555042	04034C	PARTICIPANT	\N	PRESENT	0
557796	555042	11083R	PARTICIPANT	\N	PRESENT	0
557798	555042	19651A	PARTICIPANT	\N	PRESENT	0
557800	555042	19683J	PARTICIPANT	\N	PRESENT	0
557801	555042	11027H	PARTICIPANT	\N	PRESENT	0
557802	555042	11041F	PARTICIPANT	\N	PRESENT	0
557803	555042	19347U	PARTICIPANT	\N	PRESENT	0
557804	555042	11031D	PARTICIPANT	\N	PRESENT	0
557805	555042	04035D	PARTICIPANT	\N	PRESENT	0
557806	555042	19621T	PARTICIPANT	\N	PRESENT	0
557807	555042	20034V	PARTICIPANT	\N	PRESENT	0
557808	555042	11064N	PARTICIPANT	\N	PRESENT	0
557809	555042	19565D	PARTICIPANT	\N	PRESENT	0
557821	555042	11012A	PARTICIPANT	\N	PRESENT	0
557822	555042	95063L	PARTICIPANT	\N	PRESENT	0
557860	555042	14083S	PARTICIPANT	\N	PRESENT	0
557863	555042	11010L	PARTICIPANT	\N	PRESENT	0
558430	558429	19826F	PARTICIPANT	\N	PRESENT	0
558431	558429	20038A	PARTICIPANT	\N	PRESENT	0
558432	558429	19503N	PARTICIPANT	\N	PRESENT	0
558433	558429	19820Y	PARTICIPANT	\N	PRESENT	0
558434	558429	19387D	PARTICIPANT	\N	PRESENT	0
558443	557697	14038Y	PARTICIPANT	\N	EXCUSE	0
558449	557816	20090E	PARTICIPANT	\N	PRESENT	0
558450	557816	17779H	PARTICIPANT	\N	PRESENT	0
558451	557816	20048C	PRESIDENT	0	PRESENT	0
558452	557816	14053L	PARTICIPANT	\N	PRESENT	0
558455	557816	14179A	PARTICIPANT	\N	PRESENT	1
558966	558965	14331P	PARTICIPANT	\N	PRESENT	0
558967	558965	20100N	PARTICIPANT	\N	PRESENT	0
558968	558965	19725B	PARTICIPANT	\N	PRESENT	0
559763	559649	11070L	PARTICIPANT	\N	PRESENT	0
559780	559649	08017T	PARTICIPANT	\N	PRESENT	0
559781	559649	12028B	PARTICIPANT	\N	PRESENT	0
559782	559649	11027H	PARTICIPANT	\N	PRESENT	0
559784	559649	11054L	PARTICIPANT	\N	PRESENT	0
559785	559649	08047A	PARTICIPANT	\N	PRESENT	0
557788	555042	14026U	PARTICIPANT	\N	PRESENT	0
557789	555042	14251Q	PARTICIPANT	\N	PRESENT	0
559786	559649	11083R	PARTICIPANT	\N	PRESENT	0
559787	559649	19583F	PARTICIPANT	\N	PRESENT	0
559788	559649	14041T	PARTICIPANT	\N	PRESENT	0
559789	559649	19709B	PARTICIPANT	\N	PRESENT	0
559790	559649	16685X	PARTICIPANT	\N	PRESENT	0
559791	559649	11012A	PARTICIPANT	\N	PRESENT	0
559792	559649	19421M	PARTICIPANT	\N	PRESENT	0
559793	559649	19669L	PARTICIPANT	\N	PRESENT	0
559794	559649	20130U	PARTICIPANT	\N	PRESENT	0
559795	559649	01062T	PARTICIPANT	\N	PRESENT	0
559796	559649	04034C	PARTICIPANT	\N	PRESENT	0
559797	559649	04042C	PARTICIPANT	\N	PRESENT	0
559803	559649	12041X	PARTICIPANT	\N	PRESENT	0
559804	559649	14083S	PARTICIPANT	\N	PRESENT	0
559806	559649	20070A	PARTICIPANT	\N	PRESENT	0
559807	559649	19695N	PARTICIPANT	\N	PRESENT	0
559808	559649	19693L	PARTICIPANT	\N	PRESENT	0
559811	559649	20108W	PARTICIPANT	\N	PRESENT	0
559813	559649	19657G	PARTICIPANT	\N	PRESENT	0
559815	559649	14179A	PARTICIPANT	\N	PRESENT	0
559816	559649	11072N	PARTICIPANT	\N	PRESENT	0
559818	559649	17023S	PARTICIPANT	\N	PRESENT	0
559822	559649	11115U	PARTICIPANT	\N	PRESENT	0
559824	559649	20034V	PARTICIPANT	\N	PRESENT	0
559840	559839	14041T	PARTICIPANT	\N	PRESENT	0
559842	559841	04047H	PARTICIPANT	\N	PRESENT	0
560299	559542	11110B	PARTICIPANT	\N	PRESENT	1
560300	559542	14121F	PARTICIPANT	\N	PRESENT	1
560301	559542	99004R	PARTICIPANT	\N	PRESENT	1
560302	559542	01048V	PARTICIPANT	\N	PRESENT	1
560303	559542	20050V	PARTICIPANT	\N	PRESENT	1
560304	559542	14173T	PARTICIPANT	\N	PRESENT	1
560316	559204	20074E	PARTICIPANT	\N	PRESENT	1
560317	559204	19489J	PARTICIPANT	\N	PRESENT	1
560873	559728	19697Q	PARTICIPANT	\N	PRESENT	0
560874	559728	11067R	PARTICIPANT	\N	PRESENT	0
560875	559728	20090E	PARTICIPANT	\N	PRESENT	0
560876	559728	19569H	PARTICIPANT	\N	PRESENT	0
560877	559728	19798U	PARTICIPANT	\N	PRESENT	0
560878	559728	11097X	PARTICIPANT	\N	PRESENT	0
560879	559728	19415P	PARTICIPANT	\N	PRESENT	0
560880	559728	14195A	PARTICIPANT	\N	PRESENT	0
560881	559728	14213J	PARTICIPANT	\N	PRESENT	0
560882	559728	19367Y	PARTICIPANT	\N	PRESENT	0
560883	559728	14217N	PARTICIPANT	\N	PRESENT	0
560884	559728	19683J	PARTICIPANT	\N	PRESENT	0
560885	559728	10006L	PRESIDENT	1	PRESENT	0
560886	559728	19591F	PARTICIPANT	\N	PRESENT	0
560887	559728	20130U	PARTICIPANT	\N	PRESENT	0
568538	567711	08028W	PARTICIPANT	\N	EXCUSE	0
568539	567711	14357A	PARTICIPANT	\N	EXCUSE	0
568540	567711	19575F	PARTICIPANT	\N	PRESENT	1
568541	567711	20018V	PARTICIPANT	\N	PRESENT	1
568542	567709	19575F	PARTICIPANT	\N	PRESENT	1
568543	567709	14205J	PARTICIPANT	\N	PRESENT	1
568544	567709	08028W	PARTICIPANT	\N	EXCUSE	0
568545	567709	14357A	PARTICIPANT	\N	EXCUSE	0
568546	567709	20174H	PARTICIPANT	\N	PRESENT	1
568547	567709	19747H	PARTICIPANT	\N	PRESENT	0
568548	567709	14038Y	PARTICIPANT	\N	PRESENT	0
569017	566528	19637C	PARTICIPANT	\N	PRESENT	0
569018	566529	20092G	PARTICIPANT	\N	PRESENT	0
569019	566528	20142Y	PARTICIPANT	\N	PRESENT	0
569020	566529	20102Q	PARTICIPANT	\N	PRESENT	0
569021	566529	19619A	PARTICIPANT	\N	PRESENT	0
569022	566528	11085T	PARTICIPANT	\N	PRESENT	0
569023	566528	19826F	PARTICIPANT	\N	PRESENT	0
569024	566528	04057K	PARTICIPANT	\N	PRESENT	0
569025	566529	14033T	PARTICIPANT	\N	PRESENT	0
569026	566528	14147R	PARTICIPANT	\N	PRESENT	0
569027	566529	04033B	PARTICIPANT	\N	PRESENT	0
569028	566528	19671E	PARTICIPANT	\N	PRESENT	0
569029	566529	14187A	PARTICIPANT	\N	PRESENT	0
569030	566528	11067R	PARTICIPANT	\N	PRESENT	0
569031	566528	20018V	PARTICIPANT	\N	PRESENT	0
569032	566528	04092N	PARTICIPANT	\N	PRESENT	0
569033	566529	20126Y	PARTICIPANT	\N	PRESENT	0
569034	566528	19335Q	PARTICIPANT	\N	PRESENT	0
569035	566529	20124W	PARTICIPANT	\N	PRESENT	0
569036	566528	19369B	PARTICIPANT	\N	PRESENT	0
569037	566528	14257W	PARTICIPANT	\N	PRESENT	0
569038	566529	01028R	PARTICIPANT	\N	PRESENT	0
569039	566528	04070G	PARTICIPANT	\N	PRESENT	0
569040	566529	19413M	PARTICIPANT	\N	PRESENT	0
569041	566528	14071N	PARTICIPANT	\N	PRESENT	0
569042	566528	14169X	PARTICIPANT	\N	PRESENT	0
569043	566529	14231L	PARTICIPANT	\N	PRESENT	0
569044	566528	20050V	PARTICIPANT	\N	PRESENT	0
569045	566529	19747H	PARTICIPANT	\N	PRESENT	0
569046	566528	08061X	PARTICIPANT	\N	PRESENT	0
569047	566528	17637T	PARTICIPANT	\N	PRESENT	0
569048	566528	19533U	PARTICIPANT	\N	PRESENT	0
569049	566529	14213J	PARTICIPANT	\N	PRESENT	0
569050	566528	20118Y	PARTICIPANT	\N	PRESENT	0
569051	566528	19503N	PARTICIPANT	\N	PRESENT	0
569052	566528	11090Q	PARTICIPANT	\N	PRESENT	0
569053	566528	19739H	PARTICIPANT	\N	PRESENT	0
569054	566528	20082E	PARTICIPANT	\N	PRESENT	0
569055	566528	11012A	PARTICIPANT	\N	PRESENT	0
569056	566528	04033B	PARTICIPANT	\N	PRESENT	0
569057	566528	14229S	PARTICIPANT	\N	PRESENT	0
569058	566528	20020P	PARTICIPANT	\N	PRESENT	0
569059	566528	14107H	PARTICIPANT	\N	PRESENT	0
569060	566528	19619A	PARTICIPANT	\N	PRESENT	0
569061	566528	20092G	PARTICIPANT	\N	PRESENT	0
569062	566528	11097X	PARTICIPANT	\N	PRESENT	0
569063	566528	11043H	PARTICIPANT	\N	PRESENT	0
569064	566528	19687N	PARTICIPANT	\N	PRESENT	0
569065	566528	20098N	PARTICIPANT	\N	PRESENT	0
569066	566528	04045F	PARTICIPANT	\N	PRESENT	0
569067	566528	01058X	PARTICIPANT	\N	PRESENT	0
569068	566528	20062A	PARTICIPANT	\N	PRESENT	0
569069	566528	20136B	PARTICIPANT	\N	PRESENT	0
569070	566528	19413M	PARTICIPANT	\N	PRESENT	0
569071	566528	20046A	PARTICIPANT	\N	PRESENT	0
569072	566528	20026V	PARTICIPANT	\N	PRESENT	0
569073	566528	19479G	PARTICIPANT	\N	PRESENT	0
569638	566529	11065P	PARTICIPANT	\N	PRESENT	0
569639	566529	08010L	PARTICIPANT	\N	PRESENT	0
569640	566529	19575F	PARTICIPANT	\N	PRESENT	0
569656	566529	14083S	PARTICIPANT	\N	PRESENT	0
569657	566529	19687N	PARTICIPANT	\N	PRESENT	0
569641	566529	17367Q	PARTICIPANT	\N	PRESENT	0
569658	566529	11099A	PARTICIPANT	\N	PRESENT	0
569811	567613	20130U	PARTICIPANT	\N	PRESENT	1
569660	566529	20136B	PARTICIPANT	\N	PRESENT	0
569804	567613	19760E	PARTICIPANT	\N	PRESENT	1
569645	566529	14059S	PARTICIPANT	\N	PRESENT	0
569812	567613	19591F	PARTICIPANT	\N	PRESENT	1
569813	567688	04086Q	PARTICIPANT	\N	PRESENT	1
569644	566529	17637T	PARTICIPANT	\N	PRESENT	0
569814	567688	14121F	PARTICIPANT	\N	PRESENT	1
569646	566529	20144B	PARTICIPANT	\N	PRESENT	0
569647	566529	14147R	PARTICIPANT	\N	PRESENT	0
569648	566529	14105F	PARTICIPANT	\N	PRESENT	0
569649	566529	14357A	PARTICIPANT	\N	PRESENT	0
569650	566529	20118Y	PARTICIPANT	\N	PRESENT	0
569815	567688	19711U	PARTICIPANT	\N	PRESENT	1
569816	567688	08010L	PARTICIPANT	\N	PRESENT	1
569817	567688	19349W	PARTICIPANT	\N	PRESENT	1
569818	567688	14331P	PARTICIPANT	\N	PRESENT	1
569652	566529	19399H	PARTICIPANT	\N	PRESENT	0
569819	567688	19479G	PARTICIPANT	\N	PRESENT	1
569820	567613	19723Y	PARTICIPANT	\N	PRESENT	1
569653	566529	19739H	PARTICIPANT	\N	PRESENT	0
569829	568172	04085P	PARTICIPANT	\N	PRESENT	1
569654	566529	20052X	PARTICIPANT	\N	PRESENT	0
569830	568172	20114U	PARTICIPANT	\N	PRESENT	1
569655	566529	20120S	PARTICIPANT	\N	PRESENT	0
569831	568172	11056N	PARTICIPANT	\N	PRESENT	1
569832	568172	19725B	PARTICIPANT	\N	PRESENT	1
569833	568172	20128B	PARTICIPANT	\N	PRESENT	1
569834	568172	14179A	PARTICIPANT	\N	PRESENT	1
569835	568172	19447X	PARTICIPANT	\N	PRESENT	1
569836	568172	19489J	PARTICIPANT	\N	PRESENT	1
569837	568172	19581D	PARTICIPANT	\N	PRESENT	1
569905	566531	19695N	PARTICIPANT	\N	PRESENT	0
569906	566531	08045X	PARTICIPANT	\N	PRESENT	0
569907	566531	17229F	PARTICIPANT	\N	PRESENT	0
569908	566531	08069G	PARTICIPANT	\N	PRESENT	0
569909	566531	19766L	PARTICIPANT	\N	PRESENT	0
569910	566531	20120S	PARTICIPANT	\N	PRESENT	0
569911	566531	19735D	PARTICIPANT	\N	PRESENT	0
569912	566531	97011G	PARTICIPANT	\N	PRESENT	0
569913	566531	14231L	PARTICIPANT	\N	PRESENT	0
569914	566531	20018V	PARTICIPANT	\N	PRESENT	0
569915	566531	20116W	PARTICIPANT	\N	PRESENT	0
569916	566531	11097X	PARTICIPANT	\N	PRESENT	0
569918	566531	18193Q	PARTICIPANT	\N	PRESENT	0
569919	566531	19413M	PARTICIPANT	\N	PRESENT	0
569920	566531	19619A	PARTICIPANT	\N	PRESENT	0
569921	566531	19673G	PARTICIPANT	\N	PRESENT	0
569922	566531	19479G	PARTICIPANT	\N	PRESENT	0
569923	566531	11067R	PARTICIPANT	\N	PRESENT	0
569924	566531	20066E	PARTICIPANT	\N	PRESENT	0
569925	566531	19441R	PARTICIPANT	\N	PRESENT	0
569926	566531	04070G	PARTICIPANT	\N	PRESENT	0
569927	566531	11045K	PARTICIPANT	\N	PRESENT	0
569928	566531	04059M	PARTICIPANT	\N	PRESENT	0
569929	566531	11012A	PARTICIPANT	\N	PRESENT	0
569930	566531	14031R	PARTICIPANT	\N	PRESENT	0
569931	566531	11090Q	PARTICIPANT	\N	PRESENT	0
569932	566531	99004R	PARTICIPANT	\N	PRESENT	0
569933	566531	20100N	PARTICIPANT	\N	PRESENT	0
569934	566531	08061X	PARTICIPANT	\N	PRESENT	0
569935	566531	04045F	PARTICIPANT	\N	PRESENT	0
569936	566531	20092G	PARTICIPANT	\N	PRESENT	0
569937	566531	14217N	PARTICIPANT	\N	PRESENT	0
569938	566531	19679N	PARTICIPANT	\N	PRESENT	0
569939	566531	19533U	PARTICIPANT	\N	PRESENT	0
569940	566531	01048V	PARTICIPANT	\N	PRESENT	0
569941	566531	11043H	PARTICIPANT	\N	PRESENT	0
569942	566531	14147R	PARTICIPANT	\N	PRESENT	0
569943	566531	14257W	PARTICIPANT	\N	PRESENT	0
569944	566531	19687N	PARTICIPANT	\N	PRESENT	0
569945	566531	14071N	PARTICIPANT	\N	PRESENT	0
569947	566531	01057W	PARTICIPANT	\N	PRESENT	0
569948	566531	19503N	PARTICIPANT	\N	PRESENT	0
569949	566531	19820Y	PARTICIPANT	\N	PRESENT	0
569950	566531	11053K	PARTICIPANT	\N	PRESENT	0
569951	566531	20082E	PARTICIPANT	\N	PRESENT	0
569952	566531	19699S	PARTICIPANT	\N	PRESENT	0
569953	566531	19826F	PARTICIPANT	\N	PRESENT	0
569954	566531	20052X	PARTICIPANT	\N	PRESENT	0
569955	566531	20048C	PARTICIPANT	\N	PRESENT	0
569956	566531	19333N	PARTICIPANT	\N	PRESENT	0
569957	566531	19565D	PARTICIPANT	\N	PRESENT	0
544969	537066	19717B	PRESIDENT	0	PRESENT	0
544970	537066	19631V	PARTICIPANT	\N	PRESENT	0
544974	537066	19347U	PARTICIPANT	\N	PRESENT	0
544975	537066	19583F	PARTICIPANT	\N	PRESENT	0
544976	537066	19659J	PARTICIPANT	\N	EXCUSE	0
544977	537066	12016W	PARTICIPANT	\N	PRESENT	0
544978	537066	14059S	PARTICIPANT	\N	PRESENT	0
544979	537066	20034V	PARTICIPANT	\N	PRESENT	0
545116	545115	05008E	PARTICIPANT	\N	PRESENT	0
545117	545115	11033F	PARTICIPANT	\N	PRESENT	0
545119	545115	11053K	PARTICIPANT	\N	PRESENT	0
545121	545115	14357A	PARTICIPANT	\N	PRESENT	0
545123	545115	11070L	PARTICIPANT	\N	PRESENT	0
545124	545115	19719D	PARTICIPANT	\N	PRESENT	0
545126	545115	19673G	PARTICIPANT	\N	PRESENT	0
545127	545115	01025N	PARTICIPANT	\N	PRESENT	0
545128	545115	19599P	PARTICIPANT	\N	PRESENT	0
545129	545115	14033T	PARTICIPANT	\N	PRESENT	0
545131	545115	14123H	PARTICIPANT	\N	PRESENT	0
545133	545115	14026U	PARTICIPANT	\N	PRESENT	0
545134	545115	14179A	PARTICIPANT	\N	PRESENT	0
545136	545115	19715Y	PARTICIPANT	\N	PRESENT	0
545137	545115	99004R	PARTICIPANT	\N	PRESENT	0
545138	545115	86034E	PARTICIPANT	\N	PRESENT	0
545139	545115	12041X	PARTICIPANT	\N	PRESENT	0
545140	545115	01043Q	PARTICIPANT	\N	PRESENT	0
545141	545115	14147R	PARTICIPANT	\N	PRESENT	0
545142	545115	08073C	PARTICIPANT	\N	PRESENT	0
545143	545115	11045K	PARTICIPANT	\N	PRESENT	0
545144	545115	01028R	PARTICIPANT	\N	PRESENT	0
545145	545115	19413M	PARTICIPANT	\N	PRESENT	0
547537	545407	14083S	PARTICIPANT	\N	PRESENT	0
547538	545407	17637T	PARTICIPANT	\N	PRESENT	0
547539	545407	04033B	PARTICIPANT	\N	PRESENT	0
547540	545407	14030Q	PARTICIPANT	\N	PRESENT	0
547541	545407	01028R	PARTICIPANT	\N	PRESENT	0
547542	545407	05012A	PARTICIPANT	\N	PRESENT	0
547543	545407	14187A	PARTICIPANT	\N	PRESENT	0
547544	545407	14071N	PARTICIPANT	\N	PRESENT	0
547545	545407	14026U	PARTICIPANT	\N	PRESENT	0
547546	545407	04085P	PARTICIPANT	\N	PRESENT	0
547653	545408	04047H	PARTICIPANT	\N	PRESENT	0
547654	545408	20074E	PARTICIPANT	\N	PRESENT	0
547655	545408	14001X	PARTICIPANT	\N	PRESENT	0
547656	545408	11033F	PARTICIPANT	\N	PRESENT	0
547657	545408	19629C	PARTICIPANT	\N	PRESENT	0
547658	545408	14053L	PARTICIPANT	\N	PRESENT	0
547659	545408	20116W	PARTICIPANT	\N	PRESENT	0
547660	545408	20072C	PARTICIPANT	\N	PRESENT	0
547661	545408	19671E	PARTICIPANT	\N	PRESENT	0
547662	545408	01024M	PARTICIPANT	\N	PRESENT	0
547663	545408	14331P	PARTICIPANT	\N	PRESENT	0
547664	545408	14275Y	PARTICIPANT	\N	PRESENT	0
547665	545408	07004J	PARTICIPANT	\N	PRESENT	0
547666	545408	19367Y	PARTICIPANT	\N	PRESENT	0
547667	545408	19621T	PARTICIPANT	\N	PRESENT	0
547668	545408	14187A	PARTICIPANT	\N	PRESENT	0
547669	545408	19593H	PARTICIPANT	\N	PRESENT	0
547670	545408	20022R	PARTICIPANT	\N	PRESENT	0
547671	545408	19695N	PARTICIPANT	\N	PRESENT	0
547672	545408	20090E	PARTICIPANT	\N	PRESENT	0
547673	545408	20140W	PARTICIPANT	\N	PRESENT	0
547674	545408	20026V	PARTICIPANT	\N	PRESENT	0
547675	545408	20180F	PARTICIPANT	\N	PRESENT	0
547676	545408	14357A	PARTICIPANT	\N	PRESENT	0
547677	545408	20044X	PARTICIPANT	\N	PRESENT	0
547678	545408	20034V	PARTICIPANT	\N	PRESENT	0
547679	545408	19447X	PARTICIPANT	\N	PRESENT	0
547680	545408	14030Q	PARTICIPANT	\N	PRESENT	0
547681	545408	11048N	PARTICIPANT	\N	PRESENT	0
547682	545408	20086J	PARTICIPANT	\N	PRESENT	0
547683	545408	19399H	PARTICIPANT	\N	PRESENT	0
547684	545408	19747H	PARTICIPANT	\N	PRESENT	0
547685	545408	14097Y	PARTICIPANT	\N	PRESENT	0
547686	545408	11067R	PARTICIPANT	\N	PRESENT	0
547706	545408	19611R	PARTICIPANT	\N	PRESENT	0
547688	545408	10015M	PARTICIPANT	\N	PRESENT	0
547689	545408	19631V	PARTICIPANT	\N	PRESENT	0
547690	545408	01028R	PARTICIPANT	\N	PRESENT	0
547691	545408	14215L	PARTICIPANT	\N	PRESENT	0
547692	545408	20106U	PARTICIPANT	\N	PRESENT	0
547693	545408	17637T	PARTICIPANT	\N	PRESENT	0
547694	545408	19651A	PARTICIPANT	\N	PRESENT	0
547695	545408	14055N	PARTICIPANT	\N	PRESENT	0
547696	545408	19758L	PARTICIPANT	\N	PRESENT	0
547697	545408	19649G	PARTICIPANT	\N	PRESENT	0
547698	545408	20112S	PARTICIPANT	\N	PRESENT	0
547699	545408	20102Q	PARTICIPANT	\N	PRESENT	0
547700	545408	19415P	PARTICIPANT	\N	PRESENT	0
547701	545408	11097X	PARTICIPANT	\N	PRESENT	0
547702	545408	14069U	PARTICIPANT	\N	PRESENT	0
547703	545408	14038Y	PARTICIPANT	\N	PRESENT	0
547704	545408	14111D	PARTICIPANT	\N	PRESENT	0
547705	545408	20062A	PARTICIPANT	\N	PRESENT	0
547707	545408	05008E	PARTICIPANT	\N	PRESENT	0
547708	545408	14071N	PARTICIPANT	\N	PRESENT	0
547709	545408	20082E	PARTICIPANT	\N	PRESENT	0
547710	545408	11104D	PARTICIPANT	\N	PRESENT	0
547711	545408	11077T	PARTICIPANT	\N	PRESENT	0
547712	545408	20054A	PARTICIPANT	\N	PRESENT	0
547713	545408	18193Q	PARTICIPANT	\N	PRESENT	0
547714	545408	14217N	PARTICIPANT	\N	PRESENT	0
547715	545408	19741B	PARTICIPANT	\N	PRESENT	0
547716	545408	14123H	PARTICIPANT	\N	PRESENT	0
547717	545408	19573D	PARTICIPANT	\N	PRESENT	0
547718	545408	14033T	PARTICIPANT	\N	PRESENT	0
547719	545408	20126Y	PARTICIPANT	\N	PRESENT	0
547720	545408	19387D	PARTICIPANT	\N	PRESENT	0
547721	545408	14179A	PARTICIPANT	\N	PRESENT	0
547722	545408	20042V	PARTICIPANT	\N	PRESENT	0
547723	545408	20134Y	PARTICIPANT	\N	PRESENT	0
547724	545408	19347U	PARTICIPANT	\N	PRESENT	0
547725	545408	19489J	PARTICIPANT	\N	PRESENT	0
547726	545408	14213J	PARTICIPANT	\N	PRESENT	0
547727	545408	20110Q	PARTICIPANT	\N	PRESENT	0
547535	545407	14229S	PARTICIPANT	\N	PRESENT	0
547536	545407	19701S	PARTICIPANT	\N	PRESENT	0
547728	545408	20092G	PARTICIPANT	\N	PRESENT	0
547729	545408	05012A	PARTICIPANT	\N	PRESENT	0
547730	545408	14231L	PARTICIPANT	\N	PRESENT	0
547731	545408	17737W	PARTICIPANT	\N	PRESENT	0
547735	545408	20080C	PARTICIPANT	\N	PRESENT	0
547733	545408	19820Y	PARTICIPANT	\N	PRESENT	0
547734	545408	11085T	PARTICIPANT	\N	PRESENT	0
547736	545408	20070A	PARTICIPANT	\N	PRESENT	0
547737	545408	20138D	PARTICIPANT	\N	PRESENT	0
547738	545408	19697Q	PARTICIPANT	\N	PRESENT	0
547739	545408	14089Y	PARTICIPANT	\N	PRESENT	0
547740	545408	20094J	PARTICIPANT	\N	PRESENT	0
547741	545408	20108W	PARTICIPANT	\N	PRESENT	0
547742	545408	08010L	PARTICIPANT	\N	PRESENT	0
547743	545408	19533U	PARTICIPANT	\N	PRESENT	0
547744	545408	18083K	PARTICIPANT	\N	PRESENT	0
547745	545408	19333N	PARTICIPANT	\N	PRESENT	0
547746	545408	19647E	PARTICIPANT	\N	PRESENT	0
547747	545408	19563B	PARTICIPANT	\N	PRESENT	0
547748	545408	19749K	PARTICIPANT	\N	PRESENT	0
547749	545408	20052X	PARTICIPANT	\N	PRESENT	0
547642	545408	14026U	PARTICIPANT	\N	PRESENT	0
547652	545408	19673G	PARTICIPANT	\N	PRESENT	0
547750	545408	08034U	PARTICIPANT	\N	PRESENT	0
547751	545408	14083S	PARTICIPANT	\N	PRESENT	0
547752	545408	20120S	PARTICIPANT	\N	PRESENT	0
547753	545408	20098N	PARTICIPANT	\N	PRESENT	0
547754	545408	20058E	PARTICIPANT	\N	PRESENT	0
547755	545408	20064C	PARTICIPANT	\N	PRESENT	0
548267	548266	08060W	PARTICIPANT	\N	PRESENT	0
548268	548266	05012A	PARTICIPANT	\N	PRESENT	0
548269	548266	19525U	PARTICIPANT	\N	PRESENT	0
548270	548266	17229F	PARTICIPANT	\N	PRESENT	0
548271	548266	20102Q	PARTICIPANT	\N	PRESENT	0
548273	548272	05012A	PARTICIPANT	\N	PRESENT	0
548274	548272	08060W	PARTICIPANT	\N	PRESENT	0
548275	548272	17229F	PARTICIPANT	\N	PRESENT	0
548276	548272	19387D	PARTICIPANT	\N	PRESENT	0
548277	548272	20102Q	PARTICIPANT	\N	PRESENT	0
548278	548272	19637C	PARTICIPANT	\N	PRESENT	0
548280	548279	08060W	PARTICIPANT	\N	PRESENT	0
548281	548279	05012A	PARTICIPANT	\N	PRESENT	0
548282	548279	17229F	PARTICIPANT	\N	PRESENT	0
548283	548279	19387D	PARTICIPANT	\N	PRESENT	0
569726	567613	20066E	PARTICIPANT	\N	PRESENT	0
569727	567613	14213J	PARTICIPANT	\N	PRESENT	0
569728	567613	18193Q	PARTICIPANT	\N	PRESENT	0
569729	567379	20038A	PARTICIPANT	\N	PRESENT	0
569730	567379	19549D	PARTICIPANT	\N	PRESENT	0
569731	567379	19619A	PARTICIPANT	\N	PRESENT	0
569732	567613	17965H	PARTICIPANT	\N	PRESENT	1
569733	567379	19637C	PARTICIPANT	\N	PRESENT	1
569734	567613	14026U	PARTICIPANT	\N	PRESENT	0
569735	567613	11103C	PARTICIPANT	\N	PRESENT	1
569736	567613	04057K	PARTICIPANT	\N	PRESENT	1
569737	567613	19295A	PARTICIPANT	\N	EXCUSE	0
569738	567710	20086J	PARTICIPANT	\N	PRESENT	0
569739	567710	19768N	PARTICIPANT	\N	PRESENT	1
569740	567710	19515S	PARTICIPANT	\N	PRESENT	0
569741	567710	20092G	PARTICIPANT	\N	PRESENT	0
569742	567710	14357A	PARTICIPANT	\N	PRESENT	1
569743	567710	19413M	PARTICIPANT	\N	PRESENT	0
569744	567710	20082E	PARTICIPANT	\N	PRESENT	0
569745	567710	19631V	PARTICIPANT	\N	PRESENT	0
569746	567710	11099A	PARTICIPANT	\N	PRESENT	0
569747	567710	19705W	PARTICIPANT	\N	PRESENT	0
569748	567710	08015R	PARTICIPANT	\N	PRESENT	0
569749	567710	19575F	PARTICIPANT	\N	PRESENT	0
569750	567710	19369B	PARTICIPANT	\N	PRESENT	0
569751	567710	20018V	PARTICIPANT	\N	PRESENT	1
569752	567710	14038Y	PARTICIPANT	\N	PRESENT	0
569753	567710	19467C	PARTICIPANT	\N	PRESENT	0
569754	567710	20034V	PARTICIPANT	\N	PRESENT	1
569755	567710	14187A	PARTICIPANT	\N	PRESENT	0
569756	567710	14033T	PARTICIPANT	\N	PRESENT	0
569757	567710	11090Q	PRESIDENT	0	PRESENT	0
569758	567710	01025N	PARTICIPANT	\N	PRESENT	0
569759	567710	14205J	PARTICIPANT	\N	PRESENT	0
569760	567710	20062A	PARTICIPANT	\N	PRESENT	1
569761	567710	19507S	PARTICIPANT	\N	PRESENT	0
569762	567710	19747H	PARTICIPANT	\N	PRESENT	0
569763	567710	14207L	PARTICIPANT	\N	PRESENT	0
569764	567710	14257W	PARTICIPANT	\N	PRESENT	0
569765	567710	08028W	PARTICIPANT	\N	EXCUSE	0
569766	567710	04045F	PARTICIPANT	\N	PRESENT	0
569767	567613	19679N	PARTICIPANT	\N	PRESENT	0
569768	567614	19527W	PARTICIPANT	\N	PRESENT	0
569769	567614	20132W	PARTICIPANT	\N	PRESENT	0
569770	567614	19699S	PARTICIPANT	\N	PRESENT	0
569771	567614	20134Y	PARTICIPANT	\N	PRESENT	0
569772	567614	19533U	PARTICIPANT	\N	PRESENT	0
569773	567614	19651A	PARTICIPANT	\N	PRESENT	0
569774	567614	19611R	PRESIDENT	0	PRESENT	0
569775	567614	20142Y	PARTICIPANT	\N	PRESENT	0
569776	567614	20048C	PARTICIPANT	\N	PRESENT	0
569777	567614	19399H	PARTICIPANT	\N	PRESENT	0
569778	567614	20152B	PARTICIPANT	\N	PRESENT	0
569779	567614	20052X	PARTICIPANT	\N	PRESENT	0
569780	567614	14229S	PARTICIPANT	\N	PRESENT	0
569781	567614	20056C	PARTICIPANT	\N	PRESENT	0
569782	567614	20180F	PARTICIPANT	\N	PRESENT	0
569783	567614	14123H	PARTICIPANT	\N	PRESENT	0
569784	567614	11043H	PARTICIPANT	\N	PRESENT	0
569785	567614	11104D	PARTICIPANT	\N	PRESENT	0
569786	567614	20124W	PARTICIPANT	\N	PRESENT	0
569787	567614	19758L	PARTICIPANT	\N	PRESENT	0
569788	567614	20026V	PARTICIPANT	\N	PRESENT	0
569789	567614	11109J	PARTICIPANT	\N	EXCUSE	0
569790	567379	19599P	PARTICIPANT	\N	PRESENT	0
569791	567379	19551W	PARTICIPANT	\N	PRESENT	0
569792	567379	14237S	PARTICIPANT	\N	PRESENT	0
569793	567379	11065P	PARTICIPANT	\N	PRESENT	0
569794	567614	04070G	PARTICIPANT	\N	PRESENT	0
569795	567614	14030Q	PARTICIPANT	\N	PRESENT	0
569796	567614	19735D	PARTICIPANT	\N	PRESENT	0
569797	567613	11031D	PARTICIPANT	\N	PRESENT	0
569798	568172	10015M	PARTICIPANT	\N	PRESENT	0
569799	568172	11033F	PARTICIPANT	\N	PRESENT	0
569800	568172	14231L	PARTICIPANT	\N	PRESENT	0
569801	568172	05008E	PARTICIPANT	\N	PRESENT	0
569802	568172	20108W	PARTICIPANT	\N	PRESENT	0
569803	568172	14259Y	PARTICIPANT	\N	PRESENT	0
569805	567688	14189C	PARTICIPANT	\N	PRESENT	0
569806	567688	20080C	PARTICIPANT	\N	PRESENT	0
569807	567688	07029T	PARTICIPANT	\N	PRESENT	0
569808	567688	20070A	PARTICIPANT	\N	PRESENT	0
569809	567688	19762G	PARTICIPANT	\N	PRESENT	0
569810	567688	11053K	PARTICIPANT	\N	PRESENT	0
569631	566529	14038Y	PARTICIPANT	\N	PRESENT	0
569821	567379	19701S	PARTICIPANT	\N	PRESENT	0
569633	566529	17023S	PARTICIPANT	\N	PRESENT	0
569634	566529	19637C	PARTICIPANT	\N	PRESENT	0
569635	566529	20082E	PARTICIPANT	\N	PRESENT	0
569636	566529	20066E	PARTICIPANT	\N	PRESENT	0
569637	566529	08061X	PARTICIPANT	\N	PRESENT	0
569822	568172	08018U	PARTICIPANT	\N	PRESENT	0
569824	569823	20094J	PARTICIPANT	\N	PRESENT	0
569825	569823	14189C	PARTICIPANT	\N	PRESENT	0
569826	569823	20018V	PARTICIPANT	\N	PRESENT	0
569827	569823	20110Q	PARTICIPANT	\N	PRESENT	0
569839	568137	14133K	PARTICIPANT	\N	PRESENT	0
569840	568137	20042V	PARTICIPANT	\N	PRESENT	0
569841	568137	14105F	PARTICIPANT	\N	PRESENT	0
569842	568137	04042C	PRESIDENT	0	PRESENT	0
569843	568137	19721W	PARTICIPANT	\N	PRESENT	1
569844	568137	11027H	PARTICIPANT	\N	PRESENT	0
569845	568137	11115U	PARTICIPANT	\N	PRESENT	0
569846	568137	98018T	PARTICIPANT	\N	PRESENT	1
569847	568137	01024M	PARTICIPANT	\N	PRESENT	0
569848	568137	14249W	PARTICIPANT	\N	PRESENT	0
569849	568137	17023S	PARTICIPANT	\N	PRESENT	0
569850	568137	97011G	PARTICIPANT	\N	EXCUSE	0
569851	568137	04035D	PARTICIPANT	\N	PRESENT	0
569852	568137	11083R	PARTICIPANT	\N	PRESENT	0
569853	568137	19347U	PARTICIPANT	\N	PRESENT	1
569854	568137	08056B	PARTICIPANT	\N	PRESENT	1
569855	568137	14211G	PARTICIPANT	\N	PRESENT	0
569856	568137	19565D	PARTICIPANT	\N	PRESENT	0
569857	568137	11064N	PARTICIPANT	\N	PRESENT	0
569858	568137	08069G	PARTICIPANT	\N	PRESENT	0
569859	568137	14097Y	PARTICIPANT	\N	PRESENT	0
569860	568137	12041X	PARTICIPANT	\N	PRESENT	1
569861	568137	16685X	PARTICIPANT	\N	PRESENT	0
569862	568137	14059S	PARTICIPANT	\N	PRESENT	0
569863	568137	08061X	PARTICIPANT	\N	PRESENT	0
569864	568137	08047A	PARTICIPANT	\N	PRESENT	0
569865	568137	14193X	PARTICIPANT	\N	PRESENT	1
569866	568137	19443T	PARTICIPANT	\N	PRESENT	1
569867	568137	11054L	PARTICIPANT	\N	PRESENT	1
569868	568137	19421M	PARTICIPANT	\N	PRESENT	0
569869	568137	01058X	PARTICIPANT	\N	PRESENT	0
569870	568137	01062T	PARTICIPANT	\N	PRESENT	0
569874	568136	08047A	PARTICIPANT	\N	PRESENT	1
569872	568137	11066Q	PARTICIPANT	\N	PRESENT	0
569873	568137	04034C	PARTICIPANT	\N	PRESENT	0
569875	566531	19643A	PARTICIPANT	\N	PRESENT	0
569876	566531	14042U	PARTICIPANT	\N	PRESENT	0
569877	566531	19798U	PARTICIPANT	\N	PRESENT	0
569878	566531	19593H	PARTICIPANT	\N	PRESENT	0
569879	566531	20046A	PARTICIPANT	\N	PRESENT	0
569880	566531	14259Y	PARTICIPANT	\N	PRESENT	0
569881	566531	01025N	PARTICIPANT	\N	PRESENT	0
569882	566531	14207L	PARTICIPANT	\N	PRESENT	0
569883	566531	04047H	PARTICIPANT	\N	PRESENT	0
569884	566531	20042V	PARTICIPANT	\N	PRESENT	0
569885	566531	19549D	PARTICIPANT	\N	PRESENT	0
569886	566531	20108W	PARTICIPANT	\N	PRESENT	0
569887	566531	14033T	PARTICIPANT	\N	PRESENT	0
569888	566531	20026V	PARTICIPANT	\N	PRESENT	0
569889	566531	14030Q	PARTICIPANT	\N	PRESENT	0
569890	566531	14267Y	PARTICIPANT	\N	PRESENT	0
569891	566531	20072C	PARTICIPANT	\N	PRESENT	0
569892	566531	14105F	PARTICIPANT	\N	PRESENT	0
569893	566531	20062A	PARTICIPANT	\N	PRESENT	0
569894	566531	19741B	PARTICIPANT	\N	PRESENT	0
569895	566531	20086J	PARTICIPANT	\N	PRESENT	0
569896	566531	14253S	PARTICIPANT	\N	PRESENT	0
569897	566531	19367Y	PARTICIPANT	\N	PRESENT	0
569898	566531	20144B	PARTICIPANT	\N	PRESENT	0
569899	566531	11103C	PARTICIPANT	\N	PRESENT	0
569900	566531	20112S	PARTICIPANT	\N	PRESENT	0
569901	566531	20050V	PARTICIPANT	\N	PRESENT	0
569902	566531	20152B	PARTICIPANT	\N	PRESENT	0
569903	566531	19399H	PARTICIPANT	\N	PRESENT	0
569904	566531	20056C	PARTICIPANT	\N	PRESENT	0
558031	557883	19543W	PARTICIPANT	\N	PRESENT	1
558032	557883	14179A	PARTICIPANT	\N	PRESENT	1
558033	557883	14147R	PARTICIPANT	\N	PRESENT	1
558034	557883	18083K	PARTICIPANT	\N	PRESENT	1
558035	557883	14231L	PARTICIPANT	\N	EXCUSE	0
558036	557883	01028R	PARTICIPANT	\N	EXCUSE	0
558771	556389	10006L	PRESIDENT	0	PRESENT	0
558914	556389	04043D	PARTICIPANT	\N	PRESENT	1
558773	556389	14195A	PARTICIPANT	\N	PRESENT	0
558775	556389	14071N	PARTICIPANT	\N	PRESENT	0
558861	556389	19715Y	PARTICIPANT	\N	PRESENT	1
558777	556389	19367Y	PARTICIPANT	\N	PRESENT	0
558778	556389	14042U	PARTICIPANT	\N	PRESENT	0
558779	556389	19691J	PARTICIPANT	\N	PRESENT	0
558780	556389	20066E	PARTICIPANT	\N	PRESENT	0
558781	556389	14217N	PARTICIPANT	\N	PRESENT	0
558782	556389	01034P	PARTICIPANT	\N	PRESENT	0
558783	556389	11097X	PARTICIPANT	\N	PRESENT	0
558784	556389	14213J	PARTICIPANT	\N	PRESENT	0
558785	556389	19415P	PARTICIPANT	\N	PRESENT	0
558786	556389	19703U	PARTICIPANT	\N	PRESENT	0
558915	556389	19798U	PARTICIPANT	\N	PRESENT	0
558788	556389	11103C	PARTICIPANT	\N	PRESENT	1
558789	556389	19760E	PARTICIPANT	\N	PRESENT	1
558790	556389	19697Q	PARTICIPANT	\N	PRESENT	1
558791	556389	14223L	PARTICIPANT	\N	PRESENT	1
558792	556389	20040T	PARTICIPANT	\N	PRESENT	1
558826	556389	11031D	PARTICIPANT	\N	PRESENT	0
558828	556389	19683J	PARTICIPANT	\N	PRESENT	0
558829	556389	08045X	PARTICIPANT	\N	PRESENT	0
558830	556389	19591F	PARTICIPANT	\N	PRESENT	1
558831	556389	20090E	PARTICIPANT	\N	PRESENT	1
558832	556389	19713W	PARTICIPANT	\N	PRESENT	1
558837	556389	19679N	PARTICIPANT	\N	PRESENT	1
558838	556389	19717B	PARTICIPANT	\N	PRESENT	1
558841	556389	19723Y	PARTICIPANT	\N	PRESENT	0
558847	556389	19569H	PARTICIPANT	\N	PRESENT	1
558848	556389	14026U	PARTICIPANT	\N	PRESENT	1
558877	556389	19966S	PARTICIPANT	\N	PRESENT	0
558851	556389	20148F	PARTICIPANT	\N	PRESENT	0
558852	556389	19663E	PARTICIPANT	\N	PRESENT	0
558878	556389	19295A	PARTICIPANT	\N	EXCUSE	0
558879	556389	14281W	PARTICIPANT	\N	PRESENT	0
558962	556389	17965H	PARTICIPANT	\N	PRESENT	0
558963	556389	19515S	PARTICIPANT	\N	PRESENT	1
559767	559766	19507S	PARTICIPANT	\N	PRESENT	0
559769	559766	19503N	PARTICIPANT	\N	PRESENT	0
559770	559766	20092G	PARTICIPANT	\N	PRESENT	0
558886	556389	19657G	PARTICIPANT	\N	PRESENT	0
559771	559766	19739H	PARTICIPANT	\N	PRESENT	0
559772	559766	20054A	PARTICIPANT	\N	PRESENT	0
558889	556389	20130U	PARTICIPANT	\N	PRESENT	0
559773	559766	19413M	PARTICIPANT	\N	PRESENT	0
559774	559766	20070A	PARTICIPANT	\N	PRESENT	0
559775	559766	20144B	PARTICIPANT	\N	PRESENT	0
559776	559766	19820Y	PARTICIPANT	\N	PRESENT	0
559777	559766	14237S	PARTICIPANT	\N	PRESENT	0
559778	559766	20126Y	PARTICIPANT	\N	PRESENT	0
559823	559802	14187A	PARTICIPANT	\N	PRESENT	0
559825	559805	14187A	PARTICIPANT	\N	PRESENT	0
559826	559814	14187A	PARTICIPANT	\N	PRESENT	0
559827	559817	14187A	PARTICIPANT	\N	PRESENT	0
559828	559819	14187A	PARTICIPANT	\N	PRESENT	0
559829	559819	20092G	PARTICIPANT	\N	PRESENT	0
559830	559820	14187A	PARTICIPANT	\N	PRESENT	0
559831	559820	20092G	PARTICIPANT	\N	PRESENT	0
559832	559821	14187A	PARTICIPANT	\N	PRESENT	0
559833	559821	20092G	PARTICIPANT	\N	PRESENT	0
560070	559651	14031R	PARTICIPANT	\N	PRESENT	0
560072	559651	19415P	PARTICIPANT	\N	PRESENT	0
560073	559729	19697Q	PARTICIPANT	\N	PRESENT	0
560074	559729	11067R	PARTICIPANT	\N	PRESENT	0
560075	559729	19569H	PARTICIPANT	\N	PRESENT	0
560076	559729	19798U	PARTICIPANT	\N	PRESENT	0
560077	559729	11097X	PARTICIPANT	\N	PRESENT	1
560078	559729	19415P	PARTICIPANT	\N	PRESENT	1
560079	559729	14223L	PARTICIPANT	\N	PRESENT	0
560080	559729	19703U	PARTICIPANT	\N	PRESENT	0
560081	559729	19553Y	PARTICIPANT	\N	PRESENT	1
560082	559729	11031D	PARTICIPANT	\N	PRESENT	1
560083	559729	19679N	PARTICIPANT	\N	PRESENT	0
560084	559729	14042U	PARTICIPANT	\N	PRESENT	1
560085	559729	19367Y	PARTICIPANT	\N	PRESENT	0
560086	559729	14213J	PARTICIPANT	\N	PRESENT	0
560087	559729	14217N	PARTICIPANT	\N	PRESENT	0
560088	559729	19683J	PARTICIPANT	\N	PRESENT	0
560089	559729	10006L	PRESIDENT	0	PRESENT	0
560090	559729	04092N	PARTICIPANT	\N	PRESENT	0
560091	559729	11045K	PARTICIPANT	\N	PRESENT	0
560092	559729	08045X	PARTICIPANT	\N	PRESENT	1
560093	559729	20040T	PARTICIPANT	\N	PRESENT	0
560094	559729	17965H	PARTICIPANT	\N	PRESENT	1
560095	559729	20066E	PARTICIPANT	\N	PRESENT	1
560096	559729	11103C	PARTICIPANT	\N	PRESENT	1
560097	559729	19657G	PARTICIPANT	\N	PRESENT	0
560098	559729	04043D	PARTICIPANT	\N	PRESENT	0
560099	559729	18193Q	PARTICIPANT	\N	EXCUSE	0
560100	559729	19295A	PARTICIPANT	\N	EXCUSE	0
560101	559651	14189C	PARTICIPANT	\N	PRESENT	0
560132	559651	01024M	PARTICIPANT	\N	PRESENT	0
560133	559651	19563B	PARTICIPANT	\N	PRESENT	0
560134	559651	14275Y	PARTICIPANT	\N	PRESENT	0
560140	559634	19593H	PARTICIPANT	\N	PRESENT	0
560141	559634	04070G	PARTICIPANT	\N	PRESENT	0
560142	559634	20132W	PARTICIPANT	\N	PRESENT	0
560143	559634	19643A	PARTICIPANT	\N	PRESENT	0
560144	559634	19699S	PARTICIPANT	\N	PRESENT	0
560145	559634	19611R	PRESIDENT	0	PRESENT	0
560146	559634	20142Y	PARTICIPANT	\N	PRESENT	0
560147	559634	19693L	PARTICIPANT	\N	PRESENT	0
560148	559634	19399H	PARTICIPANT	\N	PRESENT	1
560149	559634	20152B	PARTICIPANT	\N	PRESENT	0
560150	559634	20052X	PARTICIPANT	\N	PRESENT	0
560151	559634	20098N	PARTICIPANT	\N	PRESENT	0
560152	559634	20180F	PARTICIPANT	\N	PRESENT	0
560153	559634	19573D	PARTICIPANT	\N	PRESENT	0
560154	559634	04059M	PARTICIPANT	\N	PRESENT	0
560155	559634	19735D	PARTICIPANT	\N	PRESENT	0
560156	559634	08012N	PARTICIPANT	\N	PRESENT	0
560157	559634	11043H	PARTICIPANT	\N	PRESENT	0
560158	559651	19507S	PARTICIPANT	\N	PRESENT	0
560160	559651	14001X	PARTICIPANT	\N	PRESENT	0
560161	559651	11040E	PARTICIPANT	\N	PRESENT	0
560162	559651	20132W	PARTICIPANT	\N	PRESENT	0
560163	559542	04086Q	PARTICIPANT	\N	PRESENT	0
560164	559542	14327T	PARTICIPANT	\N	PRESENT	0
560165	559542	14331P	PARTICIPANT	\N	PRESENT	0
560166	559542	19479G	PARTICIPANT	\N	PRESENT	0
560167	559542	11048N	PARTICIPANT	\N	PRESENT	0
560168	559542	19711U	PARTICIPANT	\N	PRESENT	0
560169	559542	20044X	PARTICIPANT	\N	PRESENT	0
560170	559542	14225N	PRESIDENT	0	PRESENT	0
560171	559542	20022R	PARTICIPANT	\N	PRESENT	0
560172	559651	08056B	PARTICIPANT	\N	PRESENT	0
560173	559542	07029T	PARTICIPANT	\N	PRESENT	0
560174	559651	14021P	PARTICIPANT	\N	PRESENT	0
560175	559651	19768N	PARTICIPANT	\N	PRESENT	0
560176	559634	19527W	PARTICIPANT	\N	PRESENT	1
560177	559634	19651A	PARTICIPANT	\N	PRESENT	1
560178	559634	20048C	PARTICIPANT	\N	PRESENT	0
560179	559634	08017T	PARTICIPANT	\N	PRESENT	1
560180	559634	20026V	PARTICIPANT	\N	PRESENT	0
560181	559634	11109J	PARTICIPANT	\N	EXCUSE	0
560182	559634	20112S	PARTICIPANT	\N	EXCUSE	0
560183	559634	19758L	PARTICIPANT	\N	EXCUSE	0
560184	559634	20084G	PARTICIPANT	\N	EXCUSE	0
560185	559542	08009T	PARTICIPANT	\N	PRESENT	0
560186	559542	19543W	PARTICIPANT	\N	PRESENT	0
560187	559651	19399H	PARTICIPANT	\N	PRESENT	0
560188	559542	19667J	PARTICIPANT	\N	PRESENT	0
560189	559651	20056C	PARTICIPANT	\N	PRESENT	0
560190	559651	19521Q	PARTICIPANT	\N	PRESENT	0
560191	559542	19349W	PARTICIPANT	\N	PRESENT	0
560192	559651	19651A	PARTICIPANT	\N	PRESENT	0
560193	559651	14147R	PARTICIPANT	\N	PRESENT	0
560194	559542	11053K	PARTICIPANT	\N	PRESENT	0
560195	559542	20070A	PARTICIPANT	\N	PRESENT	0
560196	559542	01057W	PARTICIPANT	\N	PRESENT	0
560197	559542	08010L	PARTICIPANT	\N	PRESENT	0
541651	539685	20108W	PARTICIPANT	\N	PRESENT	0
541648	539685	14259Y	PARTICIPANT	\N	PRESENT	0
543010	543009	19709B	PARTICIPANT	\N	PRESENT	0
543012	543011	19709B	PARTICIPANT	\N	PRESENT	0
549032	548790	19651A	PARTICIPANT	\N	PRESENT	0
549033	547778	10015M	PARTICIPANT	\N	PRESENT	0
549034	547778	19543W	PARTICIPANT	\N	PRESENT	0
549035	547778	04047H	PRESIDENT	0	PRESENT	0
549036	547778	19673G	PARTICIPANT	\N	PRESENT	0
549037	547778	01028R	PARTICIPANT	\N	PRESENT	0
549038	547778	05008E	PARTICIPANT	\N	PRESENT	0
549039	547778	14231L	PARTICIPANT	\N	PRESENT	0
549040	547778	19447X	PARTICIPANT	\N	PRESENT	0
549041	547778	19954N	PARTICIPANT	\N	PRESENT	0
549042	547778	19489J	PARTICIPANT	\N	PRESENT	0
549043	547778	17737W	PARTICIPANT	\N	PRESENT	0
549044	547778	20108W	PARTICIPANT	\N	PRESENT	0
549045	547778	14041T	PARTICIPANT	\N	PRESENT	0
549046	547778	14147R	PARTICIPANT	\N	PRESENT	0
549047	547778	14179A	PARTICIPANT	\N	PRESENT	0
549048	547778	14215L	PARTICIPANT	\N	PRESENT	0
549049	547778	19749K	PARTICIPANT	\N	PRESENT	0
549050	547778	11072N	PARTICIPANT	\N	PRESENT	0
549051	548790	19507S	PARTICIPANT	\N	PRESENT	0
549052	548790	20056C	PARTICIPANT	\N	PRESENT	0
549053	548790	14073Q	PARTICIPANT	\N	PRESENT	0
549054	548790	14055N	PARTICIPANT	\N	PRESENT	0
549055	548790	19739H	PARTICIPANT	\N	PRESENT	0
549056	547148	04086Q	PARTICIPANT	\N	PRESENT	0
549057	547148	08009T	PARTICIPANT	\N	PRESENT	0
549058	547148	14253S	PARTICIPANT	\N	PRESENT	0
549059	547148	19335Q	PARTICIPANT	\N	PRESENT	0
549060	547148	14225N	PRESIDENT	0	PRESENT	0
549061	548790	20026V	PARTICIPANT	\N	PRESENT	0
549062	548790	19649G	PARTICIPANT	\N	PRESENT	0
549063	548790	11072N	PARTICIPANT	\N	PRESENT	0
549064	547148	14083S	PARTICIPANT	\N	PRESENT	0
549065	547148	08010L	PARTICIPANT	\N	PRESENT	0
549066	547148	20022R	PARTICIPANT	\N	PRESENT	0
549067	548790	08012N	PARTICIPANT	\N	PRESENT	0
549068	548790	17965H	PARTICIPANT	\N	PRESENT	0
549069	548790	19489J	PARTICIPANT	\N	PRESENT	0
549070	548790	04057K	PARTICIPANT	\N	PRESENT	0
549071	548790	14219Q	PARTICIPANT	\N	PRESENT	0
549072	548790	14215L	PARTICIPANT	\N	PRESENT	0
549073	548790	97011G	PARTICIPANT	\N	PRESENT	0
549074	548790	20086J	PARTICIPANT	\N	PRESENT	0
549075	548790	10015M	PARTICIPANT	\N	PRESENT	0
549076	548790	20108W	PARTICIPANT	\N	PRESENT	0
549077	548790	20180F	PARTICIPANT	\N	PRESENT	0
549078	548790	17737W	PARTICIPANT	\N	PRESENT	0
549079	548790	11033F	PARTICIPANT	\N	PRESENT	0
549080	548790	19573D	PARTICIPANT	\N	PRESENT	0
549081	548790	20130U	PARTICIPANT	\N	PRESENT	0
549082	548790	20058E	PARTICIPANT	\N	PRESENT	0
549083	548790	01028R	PARTICIPANT	\N	PRESENT	0
549084	548790	20044X	PARTICIPANT	\N	PRESENT	0
549085	548790	14231L	PARTICIPANT	\N	PRESENT	0
549086	548790	14275Y	PARTICIPANT	\N	PRESENT	0
549087	548790	14041T	PARTICIPANT	\N	PRESENT	0
549088	548790	14030Q	PARTICIPANT	\N	PRESENT	0
549089	548790	14033T	PARTICIPANT	\N	PRESENT	0
549090	548790	19693L	PARTICIPANT	\N	PRESENT	0
549091	548790	19719D	PARTICIPANT	\N	PRESENT	0
549092	548790	20098N	PARTICIPANT	\N	PRESENT	0
549093	548790	19399H	PARTICIPANT	\N	PRESENT	0
549094	548790	19954N	PARTICIPANT	\N	PRESENT	0
549095	548790	19673G	PARTICIPANT	\N	PRESENT	0
549096	548790	20032T	PARTICIPANT	\N	PRESENT	0
549097	548790	20132W	PARTICIPANT	\N	PRESENT	0
549098	548790	19749K	PARTICIPANT	\N	PRESENT	0
549099	548790	20084G	PARTICIPANT	\N	PRESENT	0
549100	548790	19643A	PARTICIPANT	\N	PRESENT	0
549101	548790	11056N	PARTICIPANT	\N	PRESENT	0
549102	548790	20112S	PARTICIPANT	\N	PRESENT	0
549103	548790	19503N	PARTICIPANT	\N	PRESENT	0
549104	548790	20124W	PARTICIPANT	\N	PRESENT	0
549105	547148	11048N	PARTICIPANT	\N	PRESENT	0
549106	548790	11043H	PARTICIPANT	\N	PRESENT	0
549107	548790	20052X	PARTICIPANT	\N	PRESENT	0
549108	548790	19735D	PARTICIPANT	\N	PRESENT	0
549109	548790	19721W	PARTICIPANT	\N	PRESENT	0
549110	548790	19447X	PARTICIPANT	\N	PRESENT	0
549111	548790	20062A	PARTICIPANT	\N	PRESENT	0
549112	548790	04033B	PARTICIPANT	\N	PRESENT	0
549113	548790	19747H	PARTICIPANT	\N	PRESENT	0
549114	548790	19782L	PARTICIPANT	\N	PRESENT	0
549115	548790	19333N	PARTICIPANT	\N	PRESENT	0
549116	548790	19725B	PARTICIPANT	\N	PRESENT	0
549117	548790	20048C	PARTICIPANT	\N	PRESENT	0
549118	548790	19543W	PARTICIPANT	\N	PRESENT	0
549119	548790	20092G	PARTICIPANT	\N	PRESENT	0
549120	548790	19525U	PARTICIPANT	\N	PRESENT	0
549121	548790	08017T	PARTICIPANT	\N	PRESENT	0
549122	548790	14021P	PARTICIPANT	\N	PRESENT	0
549123	548790	14109K	PARTICIPANT	\N	PRESENT	0
549124	548790	04059M	PARTICIPANT	\N	PRESENT	0
549125	548790	19515S	PARTICIPANT	\N	PRESENT	0
549126	548790	20140W	PARTICIPANT	\N	PRESENT	0
549127	548790	14038Y	PARTICIPANT	\N	PRESENT	0
549128	548790	14111D	PARTICIPANT	\N	PRESENT	0
549129	548790	19467C	PARTICIPANT	\N	PRESENT	0
549130	548790	11066Q	PARTICIPANT	\N	PRESENT	0
549131	548790	04085P	PARTICIPANT	\N	PRESENT	0
549132	548790	19713W	PARTICIPANT	\N	PRESENT	0
549133	548790	14053L	PARTICIPANT	\N	PRESENT	0
549134	548790	01024M	PARTICIPANT	\N	PRESENT	0
549135	548790	92040Q	PARTICIPANT	\N	PRESENT	0
549136	548790	14211G	PARTICIPANT	\N	PRESENT	0
549137	548790	19611R	PARTICIPANT	\N	PRESENT	0
549138	548790	04047H	PARTICIPANT	\N	PRESENT	0
549139	548790	19575F	PARTICIPANT	\N	PRESENT	0
549140	548790	19768N	PARTICIPANT	\N	PRESENT	0
549141	548790	19383Y	PARTICIPANT	\N	PRESENT	0
549142	548790	19631V	PARTICIPANT	\N	PRESENT	0
549143	548790	08034U	PARTICIPANT	\N	PRESENT	0
549144	548790	01048V	PARTICIPANT	\N	PRESENT	0
549145	548790	20078J	PARTICIPANT	\N	PRESENT	0
549146	548790	11045K	PARTICIPANT	\N	PRESENT	0
549149	548790	19745F	PARTICIPANT	\N	PRESENT	0
549150	548790	19441R	PARTICIPANT	\N	PRESENT	0
549151	548790	19697Q	PARTICIPANT	\N	PRESENT	0
549152	548790	18083K	PARTICIPANT	\N	PRESENT	0
549153	548790	16685X	PARTICIPANT	\N	PRESENT	0
549154	548790	14189C	PARTICIPANT	\N	PRESENT	0
549155	548790	14147R	PARTICIPANT	\N	PRESENT	0
549156	548790	20020P	PARTICIPANT	\N	PRESENT	0
549157	548790	11031D	PARTICIPANT	\N	PRESENT	0
549158	548790	19762G	PARTICIPANT	\N	PRESENT	0
549159	548790	19701S	PARTICIPANT	\N	PRESENT	0
549160	548790	14217N	PARTICIPANT	\N	PRESENT	0
549161	548790	14205J	PARTICIPANT	\N	PRESENT	0
549162	548790	14179A	PARTICIPANT	\N	PRESENT	0
549163	548790	11027H	PARTICIPANT	\N	PRESENT	0
549164	548790	14001X	PARTICIPANT	\N	PRESENT	0
549165	548790	19741B	PARTICIPANT	\N	PRESENT	0
549166	548790	19531S	PARTICIPANT	\N	PRESENT	0
549167	548790	14042U	PARTICIPANT	\N	PRESENT	0
549168	548790	19683J	PARTICIPANT	\N	PRESENT	0
549169	548790	08061X	PARTICIPANT	\N	PRESENT	0
549170	548790	14031R	PARTICIPANT	\N	PRESENT	0
549171	548790	17589D	PARTICIPANT	\N	PRESENT	0
549172	548790	19553Y	PARTICIPANT	\N	PRESENT	0
549173	548790	20018V	PARTICIPANT	\N	PRESENT	0
549174	548790	20172F	PARTICIPANT	\N	PRESENT	0
549175	548790	20082E	PARTICIPANT	\N	PRESENT	0
549176	548790	11067R	PARTICIPANT	\N	PRESENT	0
549177	548790	20028X	PARTICIPANT	\N	PRESENT	0
549178	548790	05008E	PARTICIPANT	\N	PRESENT	0
549179	548790	14267Y	PARTICIPANT	\N	PRESENT	0
549180	548790	11085T	PARTICIPANT	\N	PRESENT	0
549181	548790	19479G	PARTICIPANT	\N	PRESENT	0
549186	548790	17779H	PARTICIPANT	\N	PRESENT	0
549187	545497	20032T	PARTICIPANT	\N	PRESENT	0
549188	545497	20092G	PARTICIPANT	\N	PRESENT	0
549189	545497	14357A	PRESIDENT	0	PRESENT	0
549190	545497	20076G	PARTICIPANT	\N	PRESENT	0
549191	545497	20102Q	PARTICIPANT	\N	PRESENT	0
549192	548790	14083S	PARTICIPANT	\N	PRESENT	0
549193	548790	20096L	PARTICIPANT	\N	PRESENT	0
550092	548791	08047A	PARTICIPANT	\N	PRESENT	0
550093	548791	19762G	PARTICIPANT	\N	PRESENT	0
550094	548791	20104S	PARTICIPANT	\N	PRESENT	0
550095	548791	19399H	PARTICIPANT	\N	PRESENT	0
550098	548791	17023S	PARTICIPANT	\N	PRESENT	0
550100	548791	01057W	PARTICIPANT	\N	PRESENT	0
550101	548791	08028W	PARTICIPANT	\N	PRESENT	0
550102	548791	20180F	PARTICIPANT	\N	PRESENT	0
550103	548791	14042U	PARTICIPANT	\N	PRESENT	0
550104	548791	08061X	PARTICIPANT	\N	PRESENT	0
550105	548791	20128B	PARTICIPANT	\N	PRESENT	0
550111	548791	19671E	PARTICIPANT	\N	PRESENT	0
550117	548791	20082E	PARTICIPANT	\N	PRESENT	0
550110	548791	14147R	PARTICIPANT	\N	PRESENT	0
550118	548791	04057K	PARTICIPANT	\N	PRESENT	0
550119	548791	19543W	PARTICIPANT	\N	PRESENT	0
550120	548791	20040T	PARTICIPANT	\N	PRESENT	0
550121	548791	11031D	PARTICIPANT	\N	PRESENT	0
550122	548791	20028X	PARTICIPANT	\N	PRESENT	0
550123	548791	20018V	PARTICIPANT	\N	PRESENT	0
550124	548791	20066E	PARTICIPANT	\N	PRESENT	0
550137	548791	12016W	PARTICIPANT	\N	PRESENT	0
550140	548791	19563B	PARTICIPANT	\N	PRESENT	0
550172	548791	14089Y	PARTICIPANT	\N	PRESENT	0
550150	548791	11053K	PARTICIPANT	\N	PRESENT	0
550171	548791	08009T	PARTICIPANT	\N	PRESENT	0
550376	548802	04008A	PARTICIPANT	\N	PRESENT	0
550377	548802	19719D	PARTICIPANT	\N	PRESENT	0
550378	548802	14179A	PARTICIPANT	\N	PRESENT	0
550379	548802	19725B	PARTICIPANT	\N	PRESENT	0
550380	548802	14055N	PARTICIPANT	\N	PRESENT	0
550381	548802	19585H	PARTICIPANT	\N	PRESENT	0
550382	548802	11033F	PARTICIPANT	\N	PRESENT	0
550383	548802	95063L	PARTICIPANT	\N	PRESENT	0
550384	548802	14107H	PARTICIPANT	\N	PRESENT	0
550385	548802	04085P	PARTICIPANT	\N	PRESENT	0
550386	548802	20114U	PARTICIPANT	\N	PRESENT	0
550387	548802	19583F	PARTICIPANT	\N	PRESENT	0
550388	548802	20108W	PARTICIPANT	\N	PRESENT	0
550389	548802	14231L	PARTICIPANT	\N	PRESENT	0
550390	548802	20172F	PARTICIPANT	\N	PRESENT	0
550391	548802	19866P	PARTICIPANT	\N	PRESENT	0
550392	548802	19479G	PARTICIPANT	\N	PRESENT	0
550393	548802	20152B	PARTICIPANT	\N	PRESENT	0
550394	548802	19467C	PARTICIPANT	\N	PRESENT	0
550395	548802	19954N	PARTICIPANT	\N	PRESENT	0
550396	548802	14123H	PARTICIPANT	\N	PRESENT	0
550397	545505	19333N	PARTICIPANT	\N	PRESENT	0
550398	545505	14031R	PARTICIPANT	\N	PRESENT	0
550399	545505	20038A	PARTICIPANT	\N	PRESENT	0
550400	545505	19820Y	PARTICIPANT	\N	PRESENT	0
550401	545505	20046A	PARTICIPANT	\N	PRESENT	0
550402	545505	19826F	PARTICIPANT	\N	PRESENT	0
550403	545505	19599P	PARTICIPANT	\N	PRESENT	0
550404	545505	20102Q	PARTICIPANT	\N	PRESENT	0
550405	545505	20100N	PARTICIPANT	\N	PRESENT	0
550406	545505	20068G	PARTICIPANT	\N	PRESENT	0
550407	545505	20118Y	PARTICIPANT	\N	PRESENT	0
550408	545505	19503N	PARTICIPANT	\N	PRESENT	0
550409	545505	19745F	PARTICIPANT	\N	PRESENT	0
550410	548802	19447X	PARTICIPANT	\N	PRESENT	0
550411	548802	19565D	PARTICIPANT	\N	PRESENT	0
550412	548802	20112S	PARTICIPANT	\N	PRESENT	0
550413	548802	14001X	PARTICIPANT	\N	PRESENT	0
550414	545505	19549D	PARTICIPANT	\N	PRESENT	0
550415	545505	14219Q	PARTICIPANT	\N	PRESENT	0
550416	548802	20130U	PARTICIPANT	\N	PRESENT	0
550417	548802	20048C	PARTICIPANT	\N	PRESENT	0
550418	548802	20132W	PARTICIPANT	\N	PRESENT	0
550419	548802	20054A	PARTICIPANT	\N	PRESENT	0
550420	548802	20090E	PARTICIPANT	\N	PRESENT	0
550421	548802	11097X	PARTICIPANT	\N	PRESENT	0
550422	548802	19703U	PARTICIPANT	\N	PRESENT	0
550423	548802	20062A	PARTICIPANT	\N	PRESENT	0
550463	548802	14021P	PARTICIPANT	\N	PRESENT	0
550425	548802	20074E	PARTICIPANT	\N	PRESENT	0
550426	548802	20180F	PARTICIPANT	\N	PRESENT	0
550427	548802	19673G	PARTICIPANT	\N	PRESENT	0
550428	548802	04057K	PARTICIPANT	\N	PRESENT	0
550429	548802	14038Y	PARTICIPANT	\N	PRESENT	0
550430	548802	19553Y	PARTICIPANT	\N	PRESENT	0
550431	548802	11056N	PARTICIPANT	\N	PRESENT	0
550432	548802	19593H	PARTICIPANT	\N	PRESENT	0
550433	545505	20120S	PARTICIPANT	\N	PRESENT	0
550434	545505	19251M	PARTICIPANT	\N	PRESENT	0
550435	545505	14169X	PARTICIPANT	\N	PRESENT	0
550436	545505	19637C	PARTICIPANT	\N	PRESENT	0
550438	550437	19631V	PARTICIPANT	\N	PRESENT	0
550439	550437	20088L	PARTICIPANT	\N	PRESENT	0
550440	550437	14105F	PARTICIPANT	\N	PRESENT	0
550441	550437	19782L	PARTICIPANT	\N	PRESENT	0
550442	550437	20114U	PARTICIPANT	\N	PRESENT	0
550443	550437	20090E	PARTICIPANT	\N	PRESENT	0
550444	550437	14329V	PARTICIPANT	\N	PRESENT	0
550445	550437	14038Y	PARTICIPANT	\N	PRESENT	0
550446	550437	01024M	PARTICIPANT	\N	PRESENT	0
550447	550437	14187A	PARTICIPANT	\N	PRESENT	0
550448	550437	20174H	PARTICIPANT	\N	PRESENT	0
550449	550437	08056B	PARTICIPANT	\N	PRESENT	0
550450	550437	14213J	PARTICIPANT	\N	PRESENT	0
550451	550437	08015R	PARTICIPANT	\N	PRESENT	0
550452	550437	20028X	PARTICIPANT	\N	PRESENT	0
550453	550437	19369B	PARTICIPANT	\N	PRESENT	0
550454	550437	14109K	PARTICIPANT	\N	PRESENT	0
550455	550437	14169X	PARTICIPANT	\N	PRESENT	0
550456	550437	19745F	PARTICIPANT	\N	PRESENT	0
550457	550437	19503N	PARTICIPANT	\N	PRESENT	0
550458	550437	11097X	PARTICIPANT	\N	PRESENT	0
550459	550437	20064C	PARTICIPANT	\N	PRESENT	0
550460	550437	14357A	PARTICIPANT	\N	PRESENT	0
550461	548802	01048V	PARTICIPANT	\N	PRESENT	0
550462	548802	19441R	PARTICIPANT	\N	PRESENT	0
550464	548802	20084G	PARTICIPANT	\N	PRESENT	0
550465	548802	20088L	PARTICIPANT	\N	PRESENT	0
550466	548802	19631V	PARTICIPANT	\N	PRESENT	0
550467	548802	19335Q	PARTICIPANT	\N	PRESENT	0
550468	548802	20116W	PARTICIPANT	\N	PRESENT	0
550469	548802	19747H	PARTICIPANT	\N	PRESENT	0
550470	548802	04047H	PARTICIPANT	\N	PRESENT	0
550471	548802	20066E	PARTICIPANT	\N	PRESENT	0
550472	548802	17965H	PARTICIPANT	\N	PRESENT	0
550474	548802	11072N	PARTICIPANT	\N	PRESENT	0
550475	548802	20056C	PARTICIPANT	\N	PRESENT	0
550476	548802	19741B	PARTICIPANT	\N	PRESENT	0
550477	548802	19693L	PARTICIPANT	\N	PRESENT	0
550478	548802	20124W	PARTICIPANT	\N	PRESENT	0
550479	548802	14207L	PARTICIPANT	\N	PRESENT	0
550482	548802	08034U	PARTICIPANT	\N	PRESENT	0
550483	548802	19762G	PARTICIPANT	\N	PRESENT	0
550484	548802	11053K	PARTICIPANT	\N	PRESENT	0
550485	548802	19749K	PARTICIPANT	\N	PRESENT	0
550486	548802	19651A	PARTICIPANT	\N	PRESENT	0
550487	548802	19695N	PARTICIPANT	\N	PRESENT	0
550488	548802	14147R	PARTICIPANT	\N	PRESENT	0
550489	548802	19399H	PARTICIPANT	\N	PRESENT	0
550490	548802	11043H	PARTICIPANT	\N	PRESENT	0
550491	548802	19649G	PARTICIPANT	\N	PRESENT	0
550492	548802	20106U	PARTICIPANT	\N	PRESENT	0
550493	548802	19621T	PARTICIPANT	\N	PRESENT	0
550494	548802	14195A	PARTICIPANT	\N	PRESENT	0
550495	548802	20026V	PARTICIPANT	\N	PRESENT	0
550496	548802	19533U	PARTICIPANT	\N	PRESENT	0
544688	537066	19715Y	PARTICIPANT	\N	EXCUSE	0
551501	549006	19577H	PARTICIPANT	\N	EXCUSE	0
551502	549005	19577H	PARTICIPANT	\N	EXCUSE	0
551504	551503	08017T	PARTICIPANT	\N	PRESENT	1
551564	551563	19701S	PARTICIPANT	\N	PRESENT	0
551565	551563	14205J	PARTICIPANT	\N	PRESENT	0
551567	551566	19701S	PARTICIPANT	\N	PRESENT	0
551568	551566	20120S	PARTICIPANT	\N	PRESENT	0
551570	551569	19701S	PARTICIPANT	\N	PRESENT	0
551572	551569	20120S	PARTICIPANT	\N	PRESENT	0
551573	551569	19549D	PARTICIPANT	\N	PRESENT	0
551574	551569	14205J	PARTICIPANT	\N	PRESENT	0
551576	551575	19701S	PARTICIPANT	\N	PRESENT	0
551577	551575	19549D	PARTICIPANT	\N	PRESENT	0
552871	552870	04070G	PARTICIPANT	\N	PRESENT	0
552872	552870	11026G	PARTICIPANT	\N	PRESENT	0
552873	552870	20114U	PARTICIPANT	\N	PRESENT	0
552874	552870	14030Q	PARTICIPANT	\N	PRESENT	0
552875	552870	19421M	PARTICIPANT	\N	PRESENT	0
552876	552870	20084G	PARTICIPANT	\N	PRESENT	0
553645	553644	08012N	PARTICIPANT	\N	PRESENT	0
553646	553644	19593H	PARTICIPANT	\N	PRESENT	0
556493	545944	20072C	PARTICIPANT	\N	EXCUSE	0
559126	557693	19347U	PARTICIPANT	\N	PRESENT	0
559127	557693	20134Y	PARTICIPANT	\N	PRESENT	0
559128	557693	20106U	PARTICIPANT	\N	PRESENT	0
559129	557693	11033F	PARTICIPANT	\N	PRESENT	0
559130	557693	20128B	PARTICIPANT	\N	PRESENT	0
559131	557693	01058X	PARTICIPANT	\N	PRESENT	0
559132	557693	14251Q	PARTICIPANT	\N	PRESENT	0
559133	557693	19741B	PARTICIPANT	\N	PRESENT	0
559134	557693	11085T	PARTICIPANT	\N	PRESENT	0
559135	557693	14179A	PARTICIPANT	\N	PRESENT	0
559136	557693	19447X	PARTICIPANT	\N	PRESENT	0
559137	557693	14231L	PARTICIPANT	\N	PRESENT	0
559138	557693	20066E	PARTICIPANT	\N	PRESENT	0
559139	557693	20070A	PARTICIPANT	\N	PRESENT	0
559140	557693	19657G	PARTICIPANT	\N	PRESENT	0
559141	557693	19954N	PARTICIPANT	\N	PRESENT	0
559142	557693	11072N	PARTICIPANT	\N	PRESENT	0
559143	557693	20058E	PARTICIPANT	\N	PRESENT	0
559144	557693	14207L	PARTICIPANT	\N	PRESENT	0
559146	557693	19551W	PARTICIPANT	\N	PRESENT	0
559147	557693	19399H	PARTICIPANT	\N	PRESENT	0
559148	557693	19515S	PARTICIPANT	\N	PRESENT	0
559149	557693	20096L	PARTICIPANT	\N	PRESENT	0
559157	557693	19739H	PARTICIPANT	\N	PRESENT	0
559151	557693	08015R	PARTICIPANT	\N	PRESENT	0
559196	557693	14205J	PARTICIPANT	\N	PRESENT	0
559153	557693	19383Y	PARTICIPANT	\N	PRESENT	0
559154	557693	04043D	PARTICIPANT	\N	PRESENT	0
559155	557693	04033B	PARTICIPANT	\N	PRESENT	0
559156	557693	99004R	PARTICIPANT	\N	PRESENT	0
559158	557693	20144B	PARTICIPANT	\N	PRESENT	0
559159	557693	14042U	PARTICIPANT	\N	PRESENT	0
559160	557693	14193X	PARTICIPANT	\N	PRESENT	0
559161	557693	01024M	PARTICIPANT	\N	PRESENT	0
559162	557693	19543W	PARTICIPANT	\N	PRESENT	0
559163	557693	08017T	PARTICIPANT	\N	PRESENT	0
559164	557693	20084G	PARTICIPANT	\N	PRESENT	0
559165	557693	11043H	PARTICIPANT	\N	PRESENT	0
559166	557693	11031D	PARTICIPANT	\N	PRESENT	0
559167	557693	14071N	PARTICIPANT	\N	PRESENT	0
559168	557693	14257W	PARTICIPANT	\N	PRESENT	0
559169	557693	04042C	PARTICIPANT	\N	PRESENT	0
559170	557693	20054A	PARTICIPANT	\N	PRESENT	0
559171	557693	08010L	PARTICIPANT	\N	PRESENT	0
559172	557693	19335Q	PARTICIPANT	\N	PRESENT	0
559173	557693	19533U	PARTICIPANT	\N	PRESENT	0
559183	557693	19621T	PARTICIPANT	\N	PRESENT	0
559175	557693	19575F	PARTICIPANT	\N	PRESENT	0
559190	557693	14331P	PARTICIPANT	\N	PRESENT	0
559177	557693	20038A	PARTICIPANT	\N	PRESENT	0
559178	557693	20092G	PARTICIPANT	\N	PRESENT	0
559179	557693	19467C	PARTICIPANT	\N	PRESENT	0
559180	557693	20148F	PARTICIPANT	\N	PRESENT	0
559181	557693	20076G	PARTICIPANT	\N	PRESENT	0
559182	557693	14059S	PARTICIPANT	\N	PRESENT	0
559185	557693	19441R	PARTICIPANT	\N	PRESENT	0
559186	557693	19735D	PARTICIPANT	\N	PRESENT	0
559187	557693	20040T	PARTICIPANT	\N	PRESENT	0
559188	557693	14219Q	PARTICIPANT	\N	PRESENT	0
559189	557693	20062A	PARTICIPANT	\N	PRESENT	0
559191	557693	19651A	PARTICIPANT	\N	PRESENT	0
559197	557693	11053K	PARTICIPANT	\N	PRESENT	0
559193	557693	08047A	PARTICIPANT	\N	PRESENT	0
559194	557693	19507S	PARTICIPANT	\N	PRESENT	0
559195	557693	20100N	PARTICIPANT	\N	PRESENT	0
559198	557693	19747H	PARTICIPANT	\N	PRESENT	0
559199	557693	19647E	PARTICIPANT	\N	PRESENT	0
559200	557693	14123H	PARTICIPANT	\N	PRESENT	0
559201	557693	19703U	PARTICIPANT	\N	PRESENT	0
559202	557693	11065P	PARTICIPANT	\N	PRESENT	0
559206	559205	14205J	PARTICIPANT	\N	PRESENT	0
559211	559205	11099A	PARTICIPANT	\N	PRESENT	0
559212	559205	08015R	PARTICIPANT	\N	PRESENT	0
559213	559205	20076G	PARTICIPANT	\N	PRESENT	0
559215	559214	20076G	PARTICIPANT	\N	PRESENT	0
559216	559214	11099A	PARTICIPANT	\N	PRESENT	0
559217	559214	14205J	PARTICIPANT	\N	PRESENT	0
559384	557694	01043Q	PARTICIPANT	\N	PRESENT	0
559386	559385	20076G	PARTICIPANT	\N	PRESENT	0
559387	559385	14205J	PARTICIPANT	\N	PRESENT	0
559388	559385	11099A	PARTICIPANT	\N	PRESENT	0
559390	559389	14205J	PARTICIPANT	\N	PRESENT	0
559391	559389	20076G	PARTICIPANT	\N	PRESENT	0
559392	559389	11099A	PARTICIPANT	\N	PRESENT	0
559395	559394	20076G	PARTICIPANT	\N	PRESENT	0
559396	559394	14205J	PARTICIPANT	\N	PRESENT	0
559397	557251	14237S	PARTICIPANT	\N	PRESENT	0
559398	557251	20092G	PARTICIPANT	\N	PRESENT	0
559399	557251	20054A	PARTICIPANT	\N	PRESENT	0
559400	557251	20032T	PARTICIPANT	\N	PRESENT	1
559401	557251	20076G	PARTICIPANT	\N	EXCUSE	0
559402	557251	19503N	PARTICIPANT	\N	PRESENT	0
559403	557251	19739H	PARTICIPANT	\N	PRESENT	0
559405	557251	19681G	PARTICIPANT	\N	EXCUSE	0
559406	557251	20102Q	PARTICIPANT	\N	EXCUSE	0
559407	557251	19619A	PARTICIPANT	\N	PRESENT	0
559408	557251	17229F	PARTICIPANT	\N	EXCUSE	0
559409	557694	01062T	PARTICIPANT	\N	PRESENT	0
559410	557694	11041F	PARTICIPANT	\N	PRESENT	0
559411	557694	11054L	PARTICIPANT	\N	PRESENT	0
559412	557694	12028B	PARTICIPANT	\N	PRESENT	0
559413	557694	08017T	PARTICIPANT	\N	PRESENT	0
559414	557694	20128B	PARTICIPANT	\N	PRESENT	0
559415	557694	19421M	PARTICIPANT	\N	PRESENT	0
559416	557694	11012A	PARTICIPANT	\N	PRESENT	0
559417	557694	19629C	PARTICIPANT	\N	PRESENT	0
559418	557694	20072C	PARTICIPANT	\N	PRESENT	0
559419	557694	19583F	PARTICIPANT	\N	PRESENT	0
559420	557694	16685X	PARTICIPANT	\N	PRESENT	0
559422	557694	19347U	PARTICIPANT	\N	PRESENT	0
559423	557694	07029T	PARTICIPANT	\N	PRESENT	0
559424	557694	19673G	PARTICIPANT	\N	PRESENT	0
559427	557694	01024M	PARTICIPANT	\N	PRESENT	0
559429	557694	14041T	PARTICIPANT	\N	PRESENT	0
559430	557694	14147R	PARTICIPANT	\N	PRESENT	0
559431	557694	19565D	PARTICIPANT	\N	PRESENT	0
559432	557694	12041X	PARTICIPANT	\N	PRESENT	0
559433	559428	11074Q	PARTICIPANT	\N	PRESENT	0
559434	557694	11067R	PARTICIPANT	\N	PRESENT	0
559435	559428	19349W	PARTICIPANT	\N	PRESENT	0
559436	557694	14042U	PARTICIPANT	\N	PRESENT	0
559437	557694	11083R	PARTICIPANT	\N	PRESENT	0
559438	557694	04034C	PARTICIPANT	\N	PRESENT	0
559439	557694	08047A	PARTICIPANT	\N	PRESENT	0
559440	557694	20084G	PARTICIPANT	\N	PRESENT	0
559441	557734	20086J	PARTICIPANT	\N	PRESENT	0
559442	557734	19699S	PARTICIPANT	\N	PRESENT	0
559443	557734	20034V	PARTICIPANT	\N	PRESENT	0
559444	557734	11077T	PARTICIPANT	\N	PRESENT	1
559445	557734	14187A	PARTICIPANT	\N	PRESENT	0
559446	557734	20082E	PARTICIPANT	\N	PRESENT	0
559447	557734	14033T	PARTICIPANT	\N	PRESENT	1
559448	557734	11090Q	PRESIDENT	0	PRESENT	0
559449	557734	20094J	PARTICIPANT	\N	PRESENT	1
559450	557734	14205J	PARTICIPANT	\N	PRESENT	0
559451	557734	20062A	PARTICIPANT	\N	PRESENT	0
559452	557734	19575F	PARTICIPANT	\N	PRESENT	0
560198	559542	20126Y	PARTICIPANT	\N	PRESENT	0
560199	559651	17737W	PARTICIPANT	\N	PRESENT	0
560200	559542	19647E	PARTICIPANT	\N	PRESENT	0
560201	559542	20080C	PARTICIPANT	\N	PRESENT	0
560202	559651	20180F	PARTICIPANT	\N	PRESENT	0
560203	559651	19631V	PARTICIPANT	\N	PRESENT	0
560204	559651	20142Y	PARTICIPANT	\N	PRESENT	0
560205	559651	14151M	PARTICIPANT	\N	PRESENT	0
560206	559651	20098N	PARTICIPANT	\N	PRESENT	0
560207	559651	19533U	PARTICIPANT	\N	PRESENT	0
560208	559651	19611R	PARTICIPANT	\N	PRESENT	0
560209	559651	19735D	PARTICIPANT	\N	PRESENT	0
560210	559542	19687N	PARTICIPANT	\N	PRESENT	0
560211	559651	19367Y	PARTICIPANT	\N	PRESENT	0
560212	559542	19671E	PARTICIPANT	\N	PRESENT	0
560213	559651	19699S	PARTICIPANT	\N	PRESENT	0
560214	559651	20048C	PARTICIPANT	\N	PRESENT	0
560215	559651	14055N	PARTICIPANT	\N	PRESENT	0
560218	559651	08028W	PARTICIPANT	\N	PRESENT	0
560219	559651	20122U	PARTICIPANT	\N	PRESENT	0
560220	559651	14357A	PARTICIPANT	\N	PRESENT	0
560221	559651	20034V	PARTICIPANT	\N	PRESENT	0
560222	559651	20052X	PARTICIPANT	\N	PRESENT	0
560223	559651	14251Q	PARTICIPANT	\N	PRESENT	0
560224	559651	20110Q	PARTICIPANT	\N	PRESENT	0
560225	559651	14195A	PARTICIPANT	\N	PRESENT	0
560226	559651	20172F	PARTICIPANT	\N	PRESENT	0
560228	559651	14042U	PARTICIPANT	\N	PRESENT	0
560229	559651	14071N	PARTICIPANT	\N	PRESENT	0
560230	559651	08069G	PARTICIPANT	\N	PRESENT	0
560231	559542	19741B	PARTICIPANT	\N	PRESENT	0
560232	559651	20144B	PARTICIPANT	\N	PRESENT	0
560233	559651	19643A	PARTICIPANT	\N	PRESENT	0
560234	559651	14038Y	PARTICIPANT	\N	PRESENT	0
560235	559651	20082E	PARTICIPANT	\N	PRESENT	0
560237	559651	11010L	PARTICIPANT	\N	PRESENT	0
560238	559651	19347U	PARTICIPANT	\N	PRESENT	0
560239	559648	19701S	PARTICIPANT	\N	PRESENT	0
560240	559648	20136B	PARTICIPANT	\N	PRESENT	0
560241	559648	14031R	PARTICIPANT	\N	PRESENT	0
560242	559648	20140W	PARTICIPANT	\N	PRESENT	0
560243	559648	14219Q	PRESIDENT	0	PRESENT	0
560244	559648	14221J	PARTICIPANT	\N	PRESENT	0
560245	559648	19826F	PARTICIPANT	\N	PRESENT	0
560246	559648	19599P	PARTICIPANT	\N	PRESENT	0
560247	559648	14169X	PARTICIPANT	\N	PRESENT	0
560248	559648	17229F	PARTICIPANT	\N	PRESENT	0
560249	559648	14205J	PARTICIPANT	\N	PRESENT	0
560250	559648	18083K	PARTICIPANT	\N	PRESENT	0
560251	559648	05012A	PARTICIPANT	\N	PRESENT	0
560252	559648	20118Y	PARTICIPANT	\N	PRESENT	0
560253	559648	20068G	PARTICIPANT	\N	PRESENT	0
560254	559648	19503N	PARTICIPANT	\N	PRESENT	0
560255	559648	19745F	PARTICIPANT	\N	PRESENT	0
560256	559648	17367Q	PARTICIPANT	\N	PRESENT	0
560257	559648	19681G	PARTICIPANT	\N	PRESENT	1
560258	559648	19551W	PARTICIPANT	\N	PRESENT	1
560259	559648	20106U	PARTICIPANT	\N	PRESENT	1
560260	559648	19387D	PARTICIPANT	\N	PRESENT	1
560261	559648	19251M	PARTICIPANT	\N	PRESENT	1
560262	559648	19637C	PARTICIPANT	\N	PRESENT	1
560263	559648	19333N	PARTICIPANT	\N	PRESENT	0
560264	559648	19619A	PARTICIPANT	\N	PRESENT	0
560265	559648	19685L	PARTICIPANT	\N	PRESENT	0
560266	559651	14105F	PARTICIPANT	\N	PRESENT	0
560267	559542	20136B	PARTICIPANT	\N	PRESENT	0
560268	559651	11053K	PARTICIPANT	\N	PRESENT	0
560269	559648	20076G	PARTICIPANT	\N	PRESENT	0
560270	559651	19747H	PARTICIPANT	\N	PRESENT	0
560271	559651	14059S	PARTICIPANT	\N	PRESENT	0
560272	559651	19569H	PARTICIPANT	\N	PRESENT	0
560273	559651	19441R	PARTICIPANT	\N	PRESENT	0
560275	559970	19467C	PARTICIPANT	\N	EXCUSE	0
560276	559970	14133K	PARTICIPANT	\N	EXCUSE	0
560277	559970	19762G	PARTICIPANT	\N	EXCUSE	0
560278	559204	14041T	PARTICIPANT	\N	PRESENT	0
560279	559204	14215L	PARTICIPANT	\N	PRESENT	0
560280	559204	05008E	PARTICIPANT	\N	PRESENT	0
560281	559204	10015M	PARTICIPANT	\N	PRESENT	0
560282	559204	11026G	PARTICIPANT	\N	PRESENT	0
560283	559204	14151M	PARTICIPANT	\N	PRESENT	0
560284	559204	19447X	PARTICIPANT	\N	PRESENT	0
560285	559204	14053L	PARTICIPANT	\N	PRESENT	0
560286	559204	19649G	PARTICIPANT	\N	PRESENT	0
560287	559204	11033F	PARTICIPANT	\N	PRESENT	0
560288	559204	19729F	PARTICIPANT	\N	PRESENT	0
560289	559204	14275Y	PARTICIPANT	\N	PRESENT	0
560290	559204	95063L	PARTICIPANT	\N	PRESENT	0
560291	559204	19749K	PARTICIPANT	\N	PRESENT	0
560292	559204	14089Y	PARTICIPANT	\N	PRESENT	0
560293	559204	20108W	PARTICIPANT	\N	PRESENT	0
560294	559204	14179A	PARTICIPANT	\N	PRESENT	0
560295	559204	14147R	PARTICIPANT	\N	PRESENT	0
560296	559204	04047H	PRESIDENT	0	PRESENT	0
560297	559204	01028R	PARTICIPANT	\N	PRESENT	0
560298	559204	17737W	PARTICIPANT	\N	PRESENT	0
560318	559651	11067R	PARTICIPANT	\N	PRESENT	0
560319	559651	11012A	PARTICIPANT	\N	PRESENT	0
560320	559651	20130U	PARTICIPANT	\N	PRESENT	0
560321	559651	19489J	PARTICIPANT	\N	PRESENT	0
560322	559651	20026V	PARTICIPANT	\N	PRESENT	0
560323	559651	14041T	PARTICIPANT	\N	PRESENT	0
560324	559651	20138D	PARTICIPANT	\N	PRESENT	0
560325	559651	20136B	PARTICIPANT	\N	PRESENT	0
560326	559651	11101A	PARTICIPANT	\N	PRESENT	0
560327	559651	04092N	PARTICIPANT	\N	PRESENT	0
560328	559651	14255U	PARTICIPANT	\N	PRESENT	0
560329	559651	14030Q	PARTICIPANT	\N	PRESENT	0
560333	559651	19565D	PARTICIPANT	\N	PRESENT	0
560334	559651	19527W	PARTICIPANT	\N	PRESENT	0
560335	559651	20090E	PARTICIPANT	\N	PRESENT	0
560336	559651	20062A	PARTICIPANT	\N	PRESENT	0
560337	559651	19349W	PARTICIPANT	\N	PRESENT	0
560338	559651	14217N	PARTICIPANT	\N	PRESENT	0
560339	559651	08018U	PARTICIPANT	\N	PRESENT	0
560340	559651	19503N	PARTICIPANT	\N	PRESENT	0
560341	559651	20044X	PARTICIPANT	\N	PRESENT	0
560342	559651	14121F	PARTICIPANT	\N	PRESENT	0
560343	559651	20018V	PARTICIPANT	\N	PRESENT	0
560344	559651	20058E	PARTICIPANT	\N	PRESENT	0
560345	559651	19573D	PARTICIPANT	\N	PRESENT	0
560346	559651	14205J	PARTICIPANT	\N	PRESENT	0
560347	559651	14083S	PARTICIPANT	\N	PRESENT	0
560348	559651	14219Q	PARTICIPANT	\N	PRESENT	0
560349	559651	14249W	PARTICIPANT	\N	PRESENT	0
560350	559651	08045X	PARTICIPANT	\N	PRESENT	0
560351	559651	14169X	PARTICIPANT	\N	PRESENT	0
560352	559651	19369B	PARTICIPANT	\N	PRESENT	0
560353	559651	19413M	PARTICIPANT	\N	PRESENT	0
560354	559651	20070A	PARTICIPANT	\N	PRESENT	0
560355	559651	19741B	PARTICIPANT	\N	PRESENT	0
560358	559651	20080C	PARTICIPANT	\N	PRESENT	0
560359	559651	19717B	PARTICIPANT	\N	PRESENT	0
560360	559651	08010L	PARTICIPANT	\N	PRESENT	0
560361	559651	20104S	PARTICIPANT	\N	PRESENT	0
560362	559651	14173T	PARTICIPANT	\N	PRESENT	0
560367	559651	19383Y	PARTICIPANT	\N	PRESENT	0
560368	559651	19691J	PARTICIPANT	\N	PRESENT	0
560369	559651	20140W	PARTICIPANT	\N	PRESENT	0
560370	559651	19719D	PARTICIPANT	\N	PRESENT	0
560371	559651	01028R	PARTICIPANT	\N	PRESENT	0
560372	559651	19798U	PARTICIPANT	\N	PRESENT	0
560373	559651	19549D	PARTICIPANT	\N	PRESENT	0
560375	559651	97011G	PARTICIPANT	\N	PRESENT	0
560376	559651	19760E	PARTICIPANT	\N	PRESENT	0
560377	559651	14133K	PARTICIPANT	\N	PRESENT	0
560380	559651	19711U	PARTICIPANT	\N	PRESENT	0
560386	559651	14213J	PARTICIPANT	\N	PRESENT	0
560387	559651	01057W	PARTICIPANT	\N	PRESENT	0
560388	560305	08018U	PARTICIPANT	\N	PRESENT	0
560389	560305	14211G	PARTICIPANT	\N	PRESENT	0
560390	560305	14255U	PARTICIPANT	\N	PRESENT	0
560403	559651	19709B	PARTICIPANT	\N	PRESENT	0
560407	559651	14026U	PARTICIPANT	\N	PRESENT	0
560408	559651	19335Q	PARTICIPANT	\N	PRESENT	0
560409	559651	17637T	PARTICIPANT	\N	PRESENT	0
560410	559651	14097Y	PARTICIPANT	\N	PRESENT	0
549194	548790	08028W	PARTICIPANT	\N	PRESENT	0
549195	548790	19527W	PARTICIPANT	\N	PRESENT	0
549196	548790	19691J	PARTICIPANT	\N	PRESENT	0
549197	548790	01043Q	PARTICIPANT	\N	PRESENT	0
549198	548790	14121F	PARTICIPANT	\N	PRESENT	0
549199	548790	14225N	PARTICIPANT	\N	PRESENT	0
549200	548790	14213J	PARTICIPANT	\N	PRESENT	0
549201	548790	14069U	PARTICIPANT	\N	PRESENT	0
549202	548790	19335Q	PARTICIPANT	\N	PRESENT	0
549203	548790	19687N	PARTICIPANT	\N	PRESENT	0
549204	548790	11097X	PARTICIPANT	\N	PRESENT	0
549205	545497	14237S	PARTICIPANT	\N	PRESENT	0
549206	545497	19782L	PARTICIPANT	\N	PRESENT	1
549207	545497	19503N	PARTICIPANT	\N	PRESENT	0
549208	545497	19711U	PARTICIPANT	\N	PRESENT	1
549209	545497	19820Y	PARTICIPANT	\N	PRESENT	1
549210	545497	20126Y	PARTICIPANT	\N	PRESENT	1
549211	545497	19619A	PARTICIPANT	\N	PRESENT	1
549212	545497	20070A	PARTICIPANT	\N	PRESENT	0
549213	545497	11048N	PARTICIPANT	\N	PRESENT	0
549214	548790	20138D	PARTICIPANT	\N	PRESENT	0
549227	545497	19441R	PARTICIPANT	\N	PRESENT	0
549228	545497	20050V	PARTICIPANT	\N	PRESENT	1
549233	548790	08056B	PARTICIPANT	\N	PRESENT	0
549234	548790	19695N	PARTICIPANT	\N	PRESENT	0
549235	548790	99004R	PARTICIPANT	\N	PRESENT	0
549236	545500	19333N	PARTICIPANT	\N	PRESENT	0
549237	545500	19701S	PARTICIPANT	\N	PRESENT	0
549238	545500	14031R	PARTICIPANT	\N	PRESENT	0
549239	545500	20038A	PARTICIPANT	\N	PRESENT	0
549240	545500	19549D	PARTICIPANT	\N	PRESENT	0
549241	545500	14219Q	PRESIDENT	0	PRESENT	0
549242	545500	19826F	PARTICIPANT	\N	PRESENT	0
549243	545500	19599P	PARTICIPANT	\N	PRESENT	0
549244	545500	19637C	PARTICIPANT	\N	PRESENT	1
549245	545500	18083K	PARTICIPANT	\N	PRESENT	0
549246	545500	14237S	PARTICIPANT	\N	PRESENT	0
549247	545500	19503N	PARTICIPANT	\N	PRESENT	0
549248	545500	19739H	PARTICIPANT	\N	PRESENT	0
549249	545500	19745F	PARTICIPANT	\N	PRESENT	0
549250	548790	19703U	PARTICIPANT	\N	PRESENT	0
549251	548790	04043D	PARTICIPANT	\N	PRESENT	0
549254	548790	08010L	PARTICIPANT	\N	PRESENT	0
549255	548790	14259Y	PARTICIPANT	\N	PRESENT	0
549256	545500	20136B	PARTICIPANT	\N	PRESENT	0
549257	545500	17637T	PARTICIPANT	\N	PRESENT	0
550161	550156	19701S	PARTICIPANT	\N	PRESENT	0
550163	550156	19826F	PARTICIPANT	\N	PRESENT	0
550165	550156	20136B	PARTICIPANT	\N	PRESENT	0
550166	550156	19387D	PARTICIPANT	\N	PRESENT	1
550167	550156	19333N	PARTICIPANT	\N	PRESENT	1
550168	550156	20120S	PARTICIPANT	\N	PRESENT	1
550169	550156	19549D	PARTICIPANT	\N	PRESENT	1
550170	550156	19739H	PARTICIPANT	\N	PRESENT	1
552228	550473	11067R	PARTICIPANT	\N	PRESENT	0
552229	550473	20090E	PARTICIPANT	\N	PRESENT	0
552230	550473	04092N	PARTICIPANT	\N	PRESENT	0
552231	550473	19569H	PARTICIPANT	\N	PRESENT	0
552232	550473	19713W	PARTICIPANT	\N	PRESENT	0
552233	550473	11097X	PARTICIPANT	\N	PRESENT	0
552234	550473	20040T	PARTICIPANT	\N	PRESENT	0
552235	550473	17965H	PARTICIPANT	\N	PRESENT	0
552236	550473	18193Q	PARTICIPANT	\N	PRESENT	0
552237	550473	14026U	PARTICIPANT	\N	PRESENT	0
552238	550473	19723Y	PARTICIPANT	\N	PRESENT	0
552239	550473	17779H	PARTICIPANT	\N	PRESENT	0
552240	550473	19553Y	PARTICIPANT	\N	PRESENT	0
552241	550473	19679N	PARTICIPANT	\N	PRESENT	0
552242	550473	14213J	PARTICIPANT	\N	PRESENT	0
552243	550473	19657G	PARTICIPANT	\N	PRESENT	1
552244	550473	14071N	PARTICIPANT	\N	PRESENT	0
552245	550473	14217N	PARTICIPANT	\N	PRESENT	0
552246	550473	10006L	PRESIDENT	0	PRESENT	0
552247	550473	19760E	PARTICIPANT	\N	PRESENT	0
552259	549184	19333N	PARTICIPANT	\N	PRESENT	0
552260	549184	20140W	PARTICIPANT	\N	PRESENT	0
552261	549184	19549D	PARTICIPANT	\N	PRESENT	0
552262	549184	20076G	PARTICIPANT	\N	PRESENT	0
552263	549184	19387D	PARTICIPANT	\N	PRESENT	0
552264	549184	19820Y	PARTICIPANT	\N	PRESENT	0
552265	549184	19251M	PARTICIPANT	\N	PRESENT	0
552266	549184	20102Q	PARTICIPANT	\N	PRESENT	0
552267	549184	19599P	PARTICIPANT	\N	PRESENT	0
552268	549184	14237S	PARTICIPANT	\N	PRESENT	0
552269	549184	19503N	PARTICIPANT	\N	PRESENT	0
552270	549184	20020P	PARTICIPANT	\N	PRESENT	0
552271	549184	19745F	PARTICIPANT	\N	PRESENT	0
552272	551256	20056C	PARTICIPANT	\N	PRESENT	0
552273	551256	19699S	PARTICIPANT	\N	PRESENT	0
552274	551256	19573D	PARTICIPANT	\N	PRESENT	0
552275	551256	19611R	PRESIDENT	0	PRESENT	0
552276	551256	04059M	PARTICIPANT	\N	PRESENT	0
552277	551256	19399H	PARTICIPANT	\N	PRESENT	0
552278	551256	20052X	PARTICIPANT	\N	PRESENT	0
552279	551256	19621T	PARTICIPANT	\N	PRESENT	0
552280	551256	14030Q	PARTICIPANT	\N	PRESENT	0
552281	549184	20046A	PARTICIPANT	\N	PRESENT	0
552282	549184	19637C	PARTICIPANT	\N	PRESENT	0
552283	551256	19593H	PARTICIPANT	\N	PRESENT	0
552284	551256	20132W	PARTICIPANT	\N	PRESENT	0
552285	551256	19533U	PARTICIPANT	\N	PRESENT	0
552286	551256	19693L	PARTICIPANT	\N	PRESENT	0
552287	551256	14229S	PARTICIPANT	\N	PRESENT	0
552308	549184	19701S	PARTICIPANT	\N	PRESENT	0
552309	549184	14219Q	PRESIDENT	0	PRESENT	0
552310	549184	19826F	PARTICIPANT	\N	PRESENT	0
552311	549184	20096L	PARTICIPANT	\N	PRESENT	0
552312	549184	20100N	PARTICIPANT	\N	PRESENT	0
552313	549184	20118Y	PARTICIPANT	\N	PRESENT	0
552314	549184	20136B	PARTICIPANT	\N	PRESENT	0
552315	549184	14031R	PARTICIPANT	\N	PRESENT	0
552316	549184	20038A	PARTICIPANT	\N	PRESENT	0
552317	549184	19739H	PARTICIPANT	\N	PRESENT	0
552318	549184	18083K	PARTICIPANT	\N	PRESENT	1
552319	549184	17367Q	PARTICIPANT	\N	PRESENT	1
552320	551256	14073Q	PARTICIPANT	\N	PRESENT	0
552321	551256	20152B	PARTICIPANT	\N	PRESENT	1
552323	551256	92040Q	PARTICIPANT	\N	PRESENT	0
552324	551256	11109J	PARTICIPANT	\N	EXCUSE	0
552325	549184	17229F	PARTICIPANT	\N	PRESENT	0
552326	549184	14169X	PARTICIPANT	\N	PRESENT	0
552327	551284	14225N	PRESIDENT	0	PRESENT	0
552464	551124	19443T	PARTICIPANT	\N	PRESENT	0
552465	551124	12041X	PARTICIPANT	\N	PRESENT	0
552466	551124	19565D	PARTICIPANT	\N	PRESENT	1
552467	551124	20072C	PARTICIPANT	\N	PRESENT	0
552468	551124	04034C	PARTICIPANT	\N	PRESENT	0
552469	551124	01058X	PARTICIPANT	\N	PRESENT	1
552470	551124	11027H	PARTICIPANT	\N	PRESENT	0
552471	551124	16685X	PARTICIPANT	\N	PRESENT	0
552472	551124	04042C	PRESIDENT	0	PRESENT	0
552473	551124	11054L	PARTICIPANT	\N	PRESENT	0
552474	551124	11066Q	PARTICIPANT	\N	PRESENT	1
552475	551124	08056B	PARTICIPANT	\N	PRESENT	1
552476	551124	12028B	PARTICIPANT	\N	PRESENT	0
552477	551124	11115U	PARTICIPANT	\N	PRESENT	0
552478	551124	19421M	PARTICIPANT	\N	PRESENT	0
552479	551124	19709B	PARTICIPANT	\N	PRESENT	0
552480	551124	19347U	PARTICIPANT	\N	PRESENT	0
552481	551124	97011G	PARTICIPANT	\N	PRESENT	0
552482	551124	14249W	PARTICIPANT	\N	PRESENT	0
552483	551124	08047A	PARTICIPANT	\N	PRESENT	1
552484	551124	20128B	PARTICIPANT	\N	PRESENT	0
552485	551124	14059S	PARTICIPANT	\N	PRESENT	0
552486	551124	04035D	PARTICIPANT	\N	PRESENT	1
552487	551124	14133K	PARTICIPANT	\N	PRESENT	0
552488	551124	08069G	PARTICIPANT	\N	PRESENT	0
552489	551124	11041F	PARTICIPANT	\N	PRESENT	0
552490	551124	20042V	PARTICIPANT	\N	PRESENT	0
552491	551124	01024M	PARTICIPANT	\N	PRESENT	1
552492	551124	19721W	PARTICIPANT	\N	PRESENT	1
552493	551124	14083S	PARTICIPANT	\N	PRESENT	0
552494	551124	14105F	PARTICIPANT	\N	PRESENT	0
552495	551124	11012A	PARTICIPANT	\N	PRESENT	0
552496	551124	20064C	PARTICIPANT	\N	PRESENT	1
552497	551124	11083R	PARTICIPANT	\N	PRESENT	1
552498	551124	19583F	PARTICIPANT	\N	PRESENT	1
552499	551124	14255U	PARTICIPANT	\N	PRESENT	0
552500	551124	17023S	PARTICIPANT	\N	PRESENT	0
552501	551124	01062T	PARTICIPANT	\N	EXCUSE	0
550554	548793	19719D	PARTICIPANT	\N	PRESENT	0
550555	548793	20088L	PARTICIPANT	\N	PRESENT	0
550556	548793	19527W	PARTICIPANT	\N	PRESENT	0
550557	548793	17965H	PARTICIPANT	\N	PRESENT	0
550558	548793	14229S	PARTICIPANT	\N	PRESENT	0
550559	548793	19649G	PARTICIPANT	\N	PRESENT	0
550560	548793	14021P	PARTICIPANT	\N	PRESENT	0
550561	548793	20084G	PARTICIPANT	\N	PRESENT	0
550562	548793	19725B	PARTICIPANT	\N	PRESENT	0
550563	548793	11033F	PARTICIPANT	\N	PRESENT	0
550564	548793	20130U	PARTICIPANT	\N	PRESENT	0
550565	548793	14195A	PARTICIPANT	\N	PRESENT	0
550566	548793	19565D	PARTICIPANT	\N	PRESENT	0
550567	548793	19593H	PARTICIPANT	\N	PRESENT	0
550568	548793	20112S	PARTICIPANT	\N	PRESENT	0
550569	548793	19533U	PARTICIPANT	\N	PRESENT	0
550570	548793	20106U	PARTICIPANT	\N	PRESENT	0
550571	548793	11072N	PARTICIPANT	\N	PRESENT	0
550572	548793	19866P	PARTICIPANT	\N	PRESENT	0
550573	548793	20116W	PARTICIPANT	\N	PRESENT	0
550574	548793	14107H	PARTICIPANT	\N	PRESENT	0
550575	548793	14207L	PARTICIPANT	\N	PRESENT	0
550576	548793	20132W	PARTICIPANT	\N	PRESENT	0
550577	548793	19585H	PARTICIPANT	\N	PRESENT	0
550578	548793	04057K	PARTICIPANT	\N	PRESENT	0
550579	548793	19479G	PARTICIPANT	\N	PRESENT	0
550580	548793	14179A	PARTICIPANT	\N	PRESENT	0
550581	548793	14042U	PARTICIPANT	\N	PRESENT	0
550582	548793	19553Y	PARTICIPANT	\N	PRESENT	0
550583	548793	19749K	PARTICIPANT	\N	PRESENT	0
550584	548793	14147R	PARTICIPANT	\N	PRESENT	0
550585	548793	14215L	PARTICIPANT	\N	PRESENT	0
550586	548793	19747H	PARTICIPANT	\N	PRESENT	0
550587	548793	20152B	PARTICIPANT	\N	PRESENT	0
550588	548793	20124W	PARTICIPANT	\N	PRESENT	0
550589	548793	20090E	PARTICIPANT	\N	PRESENT	0
550590	548793	14069U	PARTICIPANT	\N	PRESENT	0
550591	548793	20062A	PARTICIPANT	\N	PRESENT	0
550592	548793	08034U	PARTICIPANT	\N	PRESENT	0
550593	548793	14053L	PARTICIPANT	\N	PRESENT	0
550594	548793	05008E	PARTICIPANT	\N	PRESENT	0
550595	548793	19621T	PARTICIPANT	\N	PRESENT	0
550596	548793	11043H	PARTICIPANT	\N	PRESENT	0
550597	548793	20022R	PARTICIPANT	\N	PRESENT	0
550598	548793	14123H	PARTICIPANT	\N	PRESENT	0
550599	548793	19741B	PARTICIPANT	\N	PRESENT	0
550600	548793	19399H	PARTICIPANT	\N	PRESENT	0
550601	548793	18083K	PARTICIPANT	\N	PRESENT	0
550602	548793	20056C	PARTICIPANT	\N	PRESENT	0
550603	548793	19447X	PARTICIPANT	\N	PRESENT	0
550604	548793	19673G	PARTICIPANT	\N	PRESENT	0
550605	548793	19693L	PARTICIPANT	\N	PRESENT	0
550606	548793	19525U	PARTICIPANT	\N	PRESENT	0
550607	548793	20026V	PARTICIPANT	\N	PRESENT	0
550608	548793	08017T	PARTICIPANT	\N	PRESENT	0
550609	548793	19631V	PARTICIPANT	\N	PRESENT	0
550610	548793	20180F	PARTICIPANT	\N	PRESENT	0
550611	548793	19467C	PARTICIPANT	\N	PRESENT	0
550612	548793	19691J	PARTICIPANT	\N	PRESENT	0
550613	548793	19611R	PARTICIPANT	\N	PRESENT	0
550614	548793	19543W	PARTICIPANT	\N	PRESENT	0
550615	548793	20100N	PARTICIPANT	\N	PRESENT	0
550616	548793	19333N	PARTICIPANT	\N	PRESENT	0
550617	548793	19489J	PARTICIPANT	\N	PRESENT	0
550618	548793	14217N	PARTICIPANT	\N	PRESENT	0
550619	548793	08012N	PARTICIPANT	\N	PRESENT	0
550620	548793	20054A	PARTICIPANT	\N	PRESENT	0
550621	548793	14038Y	PARTICIPANT	\N	PRESENT	0
550622	548793	01048V	PARTICIPANT	\N	PRESENT	0
550623	548793	19515S	PARTICIPANT	\N	PRESENT	0
550624	548793	10015M	PARTICIPANT	\N	PRESENT	0
550625	548793	04085P	PARTICIPANT	\N	PRESENT	0
550626	548793	19695N	PARTICIPANT	\N	PRESENT	0
550627	548793	20126Y	PARTICIPANT	\N	PRESENT	0
550628	548793	14071N	PARTICIPANT	\N	PRESENT	0
550629	548793	99004R	PARTICIPANT	\N	PRESENT	0
550630	548793	14055N	PARTICIPANT	\N	PRESENT	0
550631	545505	18083K	PARTICIPANT	\N	PRESENT	0
550632	545505	19387D	PARTICIPANT	\N	PRESENT	0
550633	545505	17367Q	PARTICIPANT	\N	PRESENT	0
550634	548793	04047H	PARTICIPANT	\N	PRESENT	0
550635	548793	19651A	PARTICIPANT	\N	PRESENT	0
550636	548793	14030Q	PARTICIPANT	\N	PRESENT	0
550637	548793	01028R	PARTICIPANT	\N	PRESENT	0
550638	548793	11045K	PARTICIPANT	\N	PRESENT	0
550639	548793	14041T	PARTICIPANT	\N	PRESENT	0
550641	548793	14001X	PARTICIPANT	\N	PRESENT	0
550642	548793	11056N	PARTICIPANT	\N	PRESENT	0
550643	548793	17737W	PARTICIPANT	\N	PRESENT	0
551201	533931	20024T	PARTICIPANT	\N	PRESENT	1
551202	533931	14030Q	PRESIDENT	0	PRESENT	0
551203	533931	20138D	PARTICIPANT	\N	PRESENT	1
551204	533931	17737W	PARTICIPANT	\N	PRESENT	1
551205	533931	20080C	PARTICIPANT	\N	PRESENT	1
551206	533931	11031D	PARTICIPANT	\N	PRESENT	0
551207	533931	20106U	PARTICIPANT	\N	PRESENT	1
551208	533931	20066E	PARTICIPANT	\N	EXCUSE	0
551209	533931	20056C	PARTICIPANT	\N	PRESENT	1
551210	533931	07029T	PARTICIPANT	\N	PRESENT	0
551211	533931	08017T	PARTICIPANT	\N	PRESENT	1
551212	533931	14109K	PARTICIPANT	\N	PRESENT	1
551213	533931	20118Y	PARTICIPANT	\N	PRESENT	1
551214	533931	19798U	PARTICIPANT	\N	PRESENT	1
551215	533931	11045K	PARTICIPANT	\N	PRESENT	1
551216	533931	19527W	PARTICIPANT	\N	PRESENT	1
551217	533931	20046A	PARTICIPANT	\N	PRESENT	1
551218	533931	19749K	PARTICIPANT	\N	PRESENT	1
551219	533931	11067R	PARTICIPANT	\N	PRESENT	0
551361	551359	14205J	PARTICIPANT	\N	PRESENT	0
551362	551359	20082E	PARTICIPANT	\N	PRESENT	0
551364	551363	20086J	PARTICIPANT	\N	PRESENT	0
551365	551363	14205J	PARTICIPANT	\N	PRESENT	0
551366	551363	20082E	PARTICIPANT	\N	PRESENT	0
551367	551363	14207L	PARTICIPANT	\N	PRESENT	0
551443	545745	08034U	PARTICIPANT	\N	PRESENT	0
551444	545745	14097Y	PARTICIPANT	\N	PRESENT	1
551452	551363	19575F	PARTICIPANT	\N	PRESENT	0
551454	551363	19768N	PARTICIPANT	\N	PRESENT	0
551499	549006	14331P	PARTICIPANT	\N	EXCUSE	0
551500	549005	14331P	PARTICIPANT	\N	EXCUSE	0
551507	551506	19709B	PARTICIPANT	\N	PRESENT	1
551508	551506	11027H	PARTICIPANT	\N	PRESENT	1
551555	551543	11065P	PARTICIPANT	\N	EXCUSE	0
551557	551556	19721W	PARTICIPANT	\N	PRESENT	1
551558	551556	19715Y	PARTICIPANT	\N	PRESENT	1
551559	551556	19611R	PARTICIPANT	\N	PRESENT	0
551560	551556	19735D	PARTICIPANT	\N	PRESENT	1
551561	551556	19593H	PRESIDENT	0	PRESENT	0
551562	551556	20082E	PARTICIPANT	\N	PRESENT	1
551578	551445	99004R	PARTICIPANT	\N	PRESENT	0
551579	551445	14073Q	PARTICIPANT	\N	PRESENT	0
551580	551445	19749K	PARTICIPANT	\N	PRESENT	0
551581	551445	19593H	PARTICIPANT	\N	PRESENT	0
551582	551445	19621T	PARTICIPANT	\N	PRESENT	0
551583	551445	14055N	PARTICIPANT	\N	PRESENT	0
551584	551445	19649G	PARTICIPANT	\N	PRESENT	0
551585	551445	04085P	PARTICIPANT	\N	PRESENT	0
551586	551445	20100N	PARTICIPANT	\N	PRESENT	0
551587	551445	14215L	PARTICIPANT	\N	PRESENT	0
551588	551445	14211G	PARTICIPANT	\N	PRESENT	0
551589	551445	17737W	PARTICIPANT	\N	PRESENT	0
551590	551445	14331P	PARTICIPANT	\N	PRESENT	0
551591	551445	19673G	PARTICIPANT	\N	PRESENT	0
551592	551445	19583F	PARTICIPANT	\N	PRESENT	0
551593	551445	19543W	PARTICIPANT	\N	PRESENT	0
551594	551445	10015M	PARTICIPANT	\N	PRESENT	0
551595	551445	20034V	PARTICIPANT	\N	PRESENT	0
551596	551445	14179A	PARTICIPANT	\N	PRESENT	0
551597	551445	19683J	PARTICIPANT	\N	PRESENT	0
551598	551445	19551W	PARTICIPANT	\N	PRESENT	0
551599	551445	19651A	PARTICIPANT	\N	PRESENT	0
551600	551445	14001X	PARTICIPANT	\N	PRESENT	0
551601	551445	11072N	PARTICIPANT	\N	PRESENT	0
551602	551445	20108W	PARTICIPANT	\N	PRESENT	0
551603	551445	19699S	PARTICIPANT	\N	PRESENT	0
551604	551445	11027H	PARTICIPANT	\N	PRESENT	0
551605	551445	20018V	PARTICIPANT	\N	PRESENT	0
551606	551445	19575F	PARTICIPANT	\N	PRESENT	0
551607	551445	08045X	PARTICIPANT	\N	PRESENT	0
541613	539550	19569H	PARTICIPANT	\N	PRESENT	0
541614	539550	01024M	PARTICIPANT	\N	PRESENT	0
541615	539550	11090Q	PARTICIPANT	\N	PRESENT	0
541616	539550	01025N	PARTICIPANT	\N	PRESENT	0
541617	539550	14030Q	PARTICIPANT	\N	PRESENT	0
541618	539550	19581D	PARTICIPANT	\N	PRESENT	0
541619	539550	01043Q	PARTICIPANT	\N	PRESENT	0
541620	539550	11066Q	PARTICIPANT	\N	PRESENT	0
541621	539550	20104S	PARTICIPANT	\N	PRESENT	0
541622	539550	14097Y	PARTICIPANT	\N	PRESENT	0
541623	539550	18193Q	PARTICIPANT	\N	PRESENT	0
541624	539550	08034U	PARTICIPANT	\N	PRESENT	0
541625	539550	20082E	PARTICIPANT	\N	PRESENT	0
541626	539550	19741B	PARTICIPANT	\N	PRESENT	0
541627	539550	19693L	PARTICIPANT	\N	PRESENT	0
541634	539550	19768N	PARTICIPANT	\N	PRESENT	0
541629	539550	19954N	PARTICIPANT	\N	PRESENT	0
541633	539550	08047A	PARTICIPANT	\N	PRESENT	0
541631	539550	20034V	PARTICIPANT	\N	PRESENT	0
541632	539550	14213J	PARTICIPANT	\N	PRESENT	0
541635	539550	14133K	PARTICIPANT	\N	PRESENT	0
541636	539550	08015R	PARTICIPANT	\N	PRESENT	0
541637	539550	20080C	PARTICIPANT	\N	PRESENT	0
541638	539550	11043H	PARTICIPANT	\N	PRESENT	0
541639	539550	20064C	PARTICIPANT	\N	PRESENT	0
541640	539550	11097X	PARTICIPANT	\N	PRESENT	0
541641	539550	14089Y	PARTICIPANT	\N	PRESENT	0
541643	539550	20040T	PARTICIPANT	\N	PRESENT	0
541646	539550	04043D	PARTICIPANT	\N	PRESENT	0
542704	538123	11031D	PARTICIPANT	\N	PRESENT	0
542705	538123	10006L	PARTICIPANT	\N	PRESENT	1
542706	538123	20120S	PARTICIPANT	\N	PRESENT	1
542707	538123	99004R	PARTICIPANT	\N	PRESENT	0
542708	538123	14229S	PARTICIPANT	\N	PRESENT	0
553960	549005	14059S	PRESIDENT	0	PRESENT	0
555338	555326	19826F	PARTICIPANT	\N	PRESENT	0
555426	555425	19593H	PARTICIPANT	\N	PRESENT	0
555427	555425	19611R	PARTICIPANT	\N	PRESENT	0
555428	555425	20082E	PARTICIPANT	\N	PRESENT	0
555429	555425	14147R	PARTICIPANT	\N	PRESENT	1
555430	555425	20142Y	PARTICIPANT	\N	PRESENT	1
555431	555425	19735D	PARTICIPANT	\N	PRESENT	1
559453	557734	20018V	PARTICIPANT	\N	PRESENT	1
559454	557734	14207L	PARTICIPANT	\N	PRESENT	1
559456	559455	18083K	PARTICIPANT	\N	PRESENT	0
559457	559455	20076G	PARTICIPANT	\N	PRESENT	0
559459	559455	14205J	PARTICIPANT	\N	PRESENT	0
559460	557734	19441R	PARTICIPANT	\N	PRESENT	0
559461	557694	19443T	PARTICIPANT	\N	PRESENT	0
559462	557734	20030R	PARTICIPANT	\N	PRESENT	1
559463	557734	19782L	PARTICIPANT	\N	PRESENT	1
559464	557734	04045F	PARTICIPANT	\N	PRESENT	1
559465	557734	20174H	PARTICIPANT	\N	PRESENT	1
559466	557694	14083S	PARTICIPANT	\N	PRESENT	0
559467	557694	11097X	PARTICIPANT	\N	PRESENT	0
559469	559468	14205J	PARTICIPANT	\N	PRESENT	0
559471	559470	14205J	PARTICIPANT	\N	PRESENT	0
559472	557694	20048C	PARTICIPANT	\N	PRESENT	0
559474	559473	19711U	PARTICIPANT	\N	PRESENT	0
559475	557694	11043H	PARTICIPANT	\N	PRESENT	0
559476	557734	19768N	PARTICIPANT	\N	PRESENT	1
559477	557251	11048N	PARTICIPANT	\N	PRESENT	0
559478	557251	14357A	PRESIDENT	0	PRESENT	0
559479	557251	19507S	PARTICIPANT	\N	PRESENT	0
559480	557251	20070A	PARTICIPANT	\N	PRESENT	0
559481	557251	20144B	PARTICIPANT	\N	PRESENT	0
559482	557251	19782L	PARTICIPANT	\N	PRESENT	1
559483	557251	19413M	PARTICIPANT	\N	PRESENT	1
559484	557251	20126Y	PARTICIPANT	\N	PRESENT	1
559488	557734	19631V	PARTICIPANT	\N	PRESENT	1
559489	559458	19333N	PARTICIPANT	\N	PRESENT	0
559490	559458	20136B	PARTICIPANT	\N	PRESENT	0
559491	559458	14031R	PARTICIPANT	\N	PRESENT	0
559492	559458	20076G	PARTICIPANT	\N	PRESENT	1
559493	559458	19549D	PARTICIPANT	\N	PRESENT	0
559494	559458	19387D	PARTICIPANT	\N	PRESENT	0
559495	559458	14219Q	PRESIDENT	0	PRESENT	0
559496	559458	19820Y	PARTICIPANT	\N	PRESENT	1
559497	559458	19826F	PARTICIPANT	\N	PRESENT	0
559498	559458	19599P	PARTICIPANT	\N	PRESENT	0
559499	559458	14169X	PARTICIPANT	\N	PRESENT	1
559500	559458	17229F	PARTICIPANT	\N	PRESENT	0
559501	559458	20100N	PARTICIPANT	\N	PRESENT	0
559502	559458	19551W	PARTICIPANT	\N	PRESENT	0
559503	559458	14237S	PARTICIPANT	\N	PRESENT	0
559504	559458	18083K	PARTICIPANT	\N	PRESENT	0
559505	559458	05012A	PARTICIPANT	\N	PRESENT	0
559506	559458	20106U	PARTICIPANT	\N	PRESENT	0
559507	559458	08060W	PARTICIPANT	\N	PRESENT	0
559508	559458	19745F	PARTICIPANT	\N	PRESENT	1
559509	559458	17367Q	PARTICIPANT	\N	PRESENT	0
559510	559458	20024T	PARTICIPANT	\N	PRESENT	0
559511	559458	20118Y	PARTICIPANT	\N	PRESENT	0
559512	557734	14038Y	PARTICIPANT	\N	EXCUSE	0
559513	557694	19657G	PARTICIPANT	\N	PRESENT	0
559514	557694	11048N	PARTICIPANT	\N	PRESENT	0
559515	557694	19749K	PARTICIPANT	\N	PRESENT	0
559516	557694	20038A	PARTICIPANT	\N	PRESENT	0
559517	557694	20024T	PARTICIPANT	\N	PRESENT	0
559518	557694	20108W	PARTICIPANT	\N	PRESENT	0
559519	557694	17023S	PARTICIPANT	\N	PRESENT	0
559520	557734	19705W	PARTICIPANT	\N	PRESENT	0
559521	557734	14257W	PARTICIPANT	\N	PRESENT	1
559523	557694	19711U	PARTICIPANT	\N	PRESENT	0
559524	557694	08034U	PARTICIPANT	\N	PRESENT	0
559525	557694	11027H	PARTICIPANT	\N	PRESENT	0
559527	557694	14193X	PARTICIPANT	\N	PRESENT	0
559528	557694	20044X	PARTICIPANT	\N	PRESENT	0
559529	557694	17637T	PARTICIPANT	\N	PRESENT	0
559530	557694	19709B	PARTICIPANT	\N	PRESENT	0
559531	557953	19713W	PARTICIPANT	\N	PRESENT	0
559532	557953	19719D	PARTICIPANT	\N	PRESENT	1
559533	557953	14109K	PARTICIPANT	\N	PRESENT	1
559534	557953	19798U	PARTICIPANT	\N	PRESENT	1
559535	557694	14021P	PARTICIPANT	\N	PRESENT	0
559536	557694	04042C	PARTICIPANT	\N	PRESENT	0
559537	557694	18083K	PARTICIPANT	\N	PRESENT	0
559538	557694	11065P	PARTICIPANT	\N	PRESENT	0
559543	557694	14059S	PARTICIPANT	\N	PRESENT	0
559544	557694	20068G	PARTICIPANT	\N	PRESENT	0
559545	557694	01058X	PARTICIPANT	\N	PRESENT	0
559546	557694	20082E	PARTICIPANT	\N	PRESENT	0
559547	557694	20100N	PARTICIPANT	\N	PRESENT	0
559548	557694	14031R	PARTICIPANT	\N	PRESENT	0
559549	557694	20172F	PARTICIPANT	\N	PRESENT	0
559550	557694	08010L	PARTICIPANT	\N	PRESENT	0
559551	557694	20034V	PARTICIPANT	\N	PRESENT	0
559553	557694	11090Q	PARTICIPANT	\N	PRESENT	0
559554	559552	19631V	PARTICIPANT	\N	PRESENT	0
559555	559552	19515S	PARTICIPANT	\N	PRESENT	0
559556	557694	19533U	PARTICIPANT	\N	PRESENT	0
559557	559552	20076G	PARTICIPANT	\N	PRESENT	0
559558	559552	19667J	PARTICIPANT	\N	PRESENT	0
559559	559552	20024T	PARTICIPANT	\N	PRESENT	0
559560	559552	20022R	PARTICIPANT	\N	PRESENT	0
559561	559552	19575F	PARTICIPANT	\N	PRESENT	0
559562	559552	14105F	PARTICIPANT	\N	PRESENT	0
559563	559552	19747H	PARTICIPANT	\N	PRESENT	0
559564	559552	19782L	PARTICIPANT	\N	PRESENT	0
559565	559552	20090E	PARTICIPANT	\N	PRESENT	0
559566	559552	14207L	PARTICIPANT	\N	PRESENT	0
559567	559552	14083S	PARTICIPANT	\N	PRESENT	0
559568	559552	11103C	PARTICIPANT	\N	PRESENT	0
559569	559552	14329V	PARTICIPANT	\N	PRESENT	0
559570	559552	14038Y	PARTICIPANT	\N	PRESENT	0
559571	559552	20144B	PARTICIPANT	\N	PRESENT	0
559572	559552	19467C	PARTICIPANT	\N	PRESENT	0
559425	559421	20042V	PARTICIPANT	\N	PRESENT	0
559426	559421	20084G	PARTICIPANT	\N	PRESENT	0
559573	557694	19621T	PARTICIPANT	\N	PRESENT	0
559574	559552	18083K	PARTICIPANT	\N	PRESENT	0
559575	559552	14357A	PARTICIPANT	\N	PRESENT	0
559576	559552	17589D	PARTICIPANT	\N	PRESENT	0
559577	559552	01024M	PARTICIPANT	\N	PRESENT	0
559578	559552	14215L	PARTICIPANT	\N	PRESENT	0
559579	559552	20124W	PARTICIPANT	\N	PRESENT	0
559580	559552	20040T	PARTICIPANT	\N	PRESENT	0
559581	559552	19507S	PARTICIPANT	\N	PRESENT	0
559582	559552	14187A	PARTICIPANT	\N	PRESENT	0
559583	559552	20174H	PARTICIPANT	\N	PRESENT	0
559584	559552	20038A	PARTICIPANT	\N	PRESENT	0
560488	559652	14097Y	PARTICIPANT	\N	PRESENT	0
560489	559652	14151M	PARTICIPANT	\N	PRESENT	0
560490	559652	20082E	PARTICIPANT	\N	PRESENT	0
560491	559652	19798U	PARTICIPANT	\N	PRESENT	0
560492	559652	95063L	PARTICIPANT	\N	PRESENT	0
560493	559652	19725B	PARTICIPANT	\N	PRESENT	0
560494	559652	14179A	PARTICIPANT	\N	PRESENT	0
560495	559652	19649G	PARTICIPANT	\N	PRESENT	0
560496	559652	10006L	PARTICIPANT	\N	PRESENT	0
560497	559652	14105F	PARTICIPANT	\N	PRESENT	0
560498	559652	19631V	PARTICIPANT	\N	PRESENT	0
560499	559652	11033F	PARTICIPANT	\N	PRESENT	0
560500	559652	14147R	PARTICIPANT	\N	PRESENT	0
560501	559652	14229S	PARTICIPANT	\N	PRESENT	0
560502	559652	19533U	PARTICIPANT	\N	PRESENT	0
560503	559652	14195A	PARTICIPANT	\N	PRESENT	0
560504	559652	95041E	PARTICIPANT	\N	PRESENT	0
560505	559652	20090E	PARTICIPANT	\N	PRESENT	0
560506	559652	20072C	PARTICIPANT	\N	PRESENT	0
560507	559652	20108W	PARTICIPANT	\N	PRESENT	0
560508	559652	18083K	PARTICIPANT	\N	PRESENT	0
560509	559652	20026V	PARTICIPANT	\N	PRESENT	0
560510	559652	20180F	PARTICIPANT	\N	PRESENT	0
560511	559652	20038A	PARTICIPANT	\N	PRESENT	0
560512	559652	19447X	PARTICIPANT	\N	PRESENT	0
560513	559652	11077T	PARTICIPANT	\N	PRESENT	0
560514	559652	19565D	PARTICIPANT	\N	PRESENT	0
560515	559652	19679N	PARTICIPANT	\N	PRESENT	0
560516	559652	20044X	PARTICIPANT	\N	PRESENT	0
560517	559652	01028R	PARTICIPANT	\N	PRESENT	0
560518	559652	14073Q	PARTICIPANT	\N	PRESENT	0
560519	559652	11056N	PARTICIPANT	\N	PRESENT	0
560520	559652	04085P	PARTICIPANT	\N	PRESENT	0
560521	559652	19760E	PARTICIPANT	\N	PRESENT	0
560522	559652	14231L	PARTICIPANT	\N	PRESENT	0
560523	559652	19489J	PARTICIPANT	\N	PRESENT	0
560524	559652	14215L	PARTICIPANT	\N	PRESENT	0
560525	559652	20034V	PARTICIPANT	\N	PRESENT	0
560526	559652	19729F	PARTICIPANT	\N	PRESENT	0
560527	559652	19575F	PARTICIPANT	\N	PRESENT	0
560528	559652	19747H	PARTICIPANT	\N	PRESENT	0
560529	559652	14187A	PARTICIPANT	\N	PRESENT	0
560530	559652	11097X	PARTICIPANT	\N	PRESENT	0
560531	559652	19629C	PARTICIPANT	\N	PRESENT	0
560532	559652	20132W	PARTICIPANT	\N	PRESENT	0
560533	559652	19349W	PARTICIPANT	\N	PRESENT	0
560534	559652	19782L	PARTICIPANT	\N	PRESENT	0
560535	559652	20142Y	PARTICIPANT	\N	PRESENT	0
560536	559652	19569H	PARTICIPANT	\N	PRESENT	0
560537	559652	14071N	PARTICIPANT	\N	PRESENT	0
560538	559652	20126Y	PARTICIPANT	\N	PRESENT	0
560539	559652	20080C	PARTICIPANT	\N	PRESENT	0
560540	559652	20118Y	PARTICIPANT	\N	PRESENT	0
560541	559652	14053L	PARTICIPANT	\N	PRESENT	0
560542	559652	14089Y	PARTICIPANT	\N	PRESENT	0
560543	559652	14217N	PARTICIPANT	\N	PRESENT	0
560544	559652	20110Q	PARTICIPANT	\N	PRESENT	0
560545	559652	20124W	PARTICIPANT	\N	PRESENT	0
560546	559652	19741B	PARTICIPANT	\N	PRESENT	0
560547	559652	14026U	PARTICIPANT	\N	PRESENT	0
560548	559652	19347U	PARTICIPANT	\N	PRESENT	0
560552	559652	19647E	PARTICIPANT	\N	PRESENT	0
560550	559652	14255U	PARTICIPANT	\N	PRESENT	0
560551	559652	20086J	PARTICIPANT	\N	PRESENT	0
560553	559652	14083S	PARTICIPANT	\N	PRESENT	0
560554	559652	14213J	PARTICIPANT	\N	PRESENT	0
560555	559652	04033B	PARTICIPANT	\N	PRESENT	0
560556	559652	20070A	PARTICIPANT	\N	PRESENT	0
560557	559652	11026G	PARTICIPANT	\N	PRESENT	0
560558	559652	20058E	PARTICIPANT	\N	PRESENT	0
560559	559652	11048N	PARTICIPANT	\N	PRESENT	0
560486	559652	04047H	PARTICIPANT	\N	PRESENT	0
560487	559652	05008E	PARTICIPANT	\N	PRESENT	0
560560	559652	19369B	PARTICIPANT	\N	PRESENT	0
560561	559652	19563B	PARTICIPANT	\N	PRESENT	0
560868	560867	14173T	PARTICIPANT	\N	PRESENT	0
560869	560867	19447X	PARTICIPANT	\N	PRESENT	0
560870	560867	18083K	PARTICIPANT	\N	PRESENT	0
560871	560867	20062A	PARTICIPANT	\N	PRESENT	0
560917	560916	20094J	PARTICIPANT	\N	PRESENT	0
560918	560916	14189C	PARTICIPANT	\N	PRESENT	0
560919	560916	14097Y	PARTICIPANT	\N	PRESENT	0
560920	560916	19549D	PARTICIPANT	\N	PRESENT	0
560921	560916	14257W	PARTICIPANT	\N	PRESENT	0
560922	560916	19575F	PARTICIPANT	\N	PRESENT	0
560923	560916	20018V	PARTICIPANT	\N	PRESENT	0
560951	560950	11048N	PARTICIPANT	\N	PRESENT	0
560959	559541	19545Y	PARTICIPANT	\N	PRESENT	1
560960	559541	11110B	PARTICIPANT	\N	PRESENT	1
560961	559541	19647E	PARTICIPANT	\N	PRESENT	1
560962	559541	14121F	PARTICIPANT	\N	PRESENT	1
560963	559541	99004R	PARTICIPANT	\N	PRESENT	1
560964	559541	20126Y	PARTICIPANT	\N	PRESENT	1
560965	559541	08010L	PARTICIPANT	\N	PRESENT	1
560966	559541	14331P	PARTICIPANT	\N	PRESENT	1
560967	559541	11012A	PARTICIPANT	\N	PRESENT	1
560968	559541	19479G	PARTICIPANT	\N	PRESENT	1
560969	559541	14173T	PARTICIPANT	\N	PRESENT	1
560974	560970	19719D	PARTICIPANT	\N	PRESENT	0
560972	560970	14030Q	PARTICIPANT	\N	PRESENT	0
560973	560970	19383Y	PARTICIPANT	\N	PRESENT	0
560975	560970	11099A	PARTICIPANT	\N	PRESENT	0
560976	560970	19637C	PARTICIPANT	\N	PRESENT	0
560977	560970	14109K	PARTICIPANT	\N	PRESENT	0
560978	560970	19798U	PARTICIPANT	\N	PRESENT	0
560979	560970	19713W	PARTICIPANT	\N	PRESENT	0
560981	559970	19719D	PARTICIPANT	\N	PRESENT	0
560982	559970	19383Y	PARTICIPANT	\N	PRESENT	0
560983	559970	14030Q	PARTICIPANT	\N	PRESENT	0
560984	559970	19758L	PARTICIPANT	\N	PRESENT	0
560985	559970	19798U	PARTICIPANT	\N	PRESENT	0
560986	559970	11099A	PARTICIPANT	\N	PRESENT	0
560987	559970	14109K	PARTICIPANT	\N	PRESENT	1
561022	560589	19575F	PARTICIPANT	\N	PRESENT	0
561024	560589	19782L	PARTICIPANT	\N	PRESENT	0
561027	560589	14207L	PARTICIPANT	\N	PRESENT	0
561028	560589	08028W	PARTICIPANT	\N	PRESENT	0
561030	560589	20144B	PARTICIPANT	\N	PRESENT	0
561033	560589	01025N	PARTICIPANT	\N	PRESENT	0
561035	560589	19511N	PARTICIPANT	\N	PRESENT	0
561037	560589	19441R	PARTICIPANT	\N	PRESENT	0
561039	560589	14257W	PARTICIPANT	\N	PRESENT	0
561042	560589	19768N	PARTICIPANT	\N	PRESENT	0
561043	560589	20082E	PARTICIPANT	\N	PRESENT	0
561046	560589	04045F	PARTICIPANT	\N	PRESENT	0
561197	561195	19335Q	PARTICIPANT	\N	PRESENT	0
561203	561202	19335Q	PARTICIPANT	\N	PRESENT	0
561206	561204	08009T	PARTICIPANT	\N	PRESENT	0
561207	561204	20044X	PARTICIPANT	\N	PRESENT	0
561210	561209	19711U	PARTICIPANT	\N	PRESENT	0
561211	559677	14133K	PRESIDENT	1	PRESENT	0
561212	559677	14105F	PARTICIPANT	\N	PRESENT	0
561213	559677	14255U	PARTICIPANT	\N	PRESENT	1
561214	559677	04042C	PRESIDENT	0	PRESENT	0
561215	559677	14267Y	PARTICIPANT	\N	PRESENT	0
561216	559677	11027H	PARTICIPANT	\N	PRESENT	0
561217	559677	01024M	PARTICIPANT	\N	PRESENT	0
561218	559677	14249W	PARTICIPANT	\N	PRESENT	0
561219	559677	11083R	PARTICIPANT	\N	PRESENT	0
561220	559677	19347U	PARTICIPANT	\N	PRESENT	0
561221	559677	08056B	PARTICIPANT	\N	PRESENT	0
561222	559677	14211G	PARTICIPANT	\N	PRESENT	0
561223	559677	19565D	PARTICIPANT	\N	PRESENT	0
561224	559677	98022P	PARTICIPANT	\N	PRESENT	0
561225	559677	20128B	PARTICIPANT	\N	EXCUSE	0
561226	559677	08069G	PARTICIPANT	\N	PRESENT	0
561227	559677	14097Y	PARTICIPANT	\N	PRESENT	0
561228	559677	19583F	PARTICIPANT	\N	PRESENT	0
561229	559677	12041X	PARTICIPANT	\N	PRESENT	0
561230	559677	19709B	PARTICIPANT	\N	PRESENT	0
561231	559677	16685X	PARTICIPANT	\N	PRESENT	0
561232	559677	14059S	PARTICIPANT	\N	PRESENT	0
561233	559677	14193X	PARTICIPANT	\N	PRESENT	0
561235	559677	11054L	PARTICIPANT	\N	PRESENT	0
561236	559677	19421M	PARTICIPANT	\N	PRESENT	0
561237	559677	01058X	PARTICIPANT	\N	PRESENT	0
561238	561234	11074Q	PARTICIPANT	\N	PRESENT	0
561240	559677	11066Q	PARTICIPANT	\N	PRESENT	0
561241	561234	19349W	PARTICIPANT	\N	PRESENT	0
561242	559677	12028B	PARTICIPANT	\N	PRESENT	1
561243	559677	19721W	PARTICIPANT	\N	PRESENT	1
543094	542822	14111D	PARTICIPANT	\N	PRESENT	0
543095	542822	14041T	PARTICIPANT	\N	PRESENT	0
543096	542822	14147R	PARTICIPANT	\N	PRESENT	0
543097	542822	14215L	PARTICIPANT	\N	PRESENT	0
543098	542822	19749K	PARTICIPANT	\N	PRESENT	0
543099	542822	11033F	PARTICIPANT	\N	PRESENT	0
543100	542822	19447X	PARTICIPANT	\N	PRESENT	0
543101	542822	20108W	PARTICIPANT	\N	PRESENT	0
543102	542822	04047H	PRESIDENT	0	PRESENT	0
543103	542822	11072N	PARTICIPANT	\N	PRESENT	0
543104	542822	05008E	PARTICIPANT	\N	PRESENT	0
543105	542822	17737W	PARTICIPANT	\N	PRESENT	0
543110	542985	19723Y	PARTICIPANT	\N	EXCUSE	0
543111	542985	19735D	PARTICIPANT	\N	EXCUSE	0
543112	542985	01048V	PARTICIPANT	\N	PRESENT	0
543114	542822	01028R	PARTICIPANT	\N	PRESENT	0
543189	542926	08073C	PARTICIPANT	\N	PRESENT	0
543194	542926	14179A	PARTICIPANT	\N	PRESENT	0
543195	542926	19413M	PARTICIPANT	\N	PRESENT	0
543196	542926	11101A	PARTICIPANT	\N	PRESENT	0
543197	542926	20090E	PARTICIPANT	\N	PRESENT	0
543198	542926	20098N	PARTICIPANT	\N	PRESENT	0
543199	542926	14033T	PARTICIPANT	\N	PRESENT	0
543200	542926	14221J	PARTICIPANT	\N	PRESENT	0
543207	542926	97011G	PARTICIPANT	\N	PRESENT	0
543208	542926	14169X	PARTICIPANT	\N	PRESENT	0
543209	542926	19619A	PARTICIPANT	\N	PRESENT	0
543210	542926	19826F	PARTICIPANT	\N	PRESENT	0
543211	542926	19565D	PARTICIPANT	\N	PRESENT	0
543223	542926	14038Y	PARTICIPANT	\N	PRESENT	0
543213	542926	19701S	PARTICIPANT	\N	PRESENT	0
543214	542926	19503N	PARTICIPANT	\N	PRESENT	0
543215	542926	19507S	PARTICIPANT	\N	PRESENT	0
543216	542926	20092G	PARTICIPANT	\N	PRESENT	0
543217	542926	20116W	PARTICIPANT	\N	PRESENT	0
543218	542926	20032T	PARTICIPANT	\N	PRESENT	0
543219	542926	19782L	PARTICIPANT	\N	PRESENT	0
543220	542926	10015M	PARTICIPANT	\N	PRESENT	0
543221	542926	19569H	PARTICIPANT	\N	PRESENT	0
543222	542926	19695N	PARTICIPANT	\N	PRESENT	0
543224	542926	20112S	PARTICIPANT	\N	PRESENT	0
543225	542926	20172F	PARTICIPANT	\N	PRESENT	0
543226	542926	19447X	PARTICIPANT	\N	PRESENT	0
543227	542926	20180F	PARTICIPANT	\N	PRESENT	0
543228	542926	14207L	PARTICIPANT	\N	PRESENT	0
543229	542926	01058X	PARTICIPANT	\N	PRESENT	0
543230	542926	18083K	PARTICIPANT	\N	PRESENT	0
543231	542926	19333N	PARTICIPANT	\N	PRESENT	0
543232	542926	14147R	PARTICIPANT	\N	PRESENT	0
543233	542926	11090Q	PARTICIPANT	\N	PRESENT	0
543234	542926	14187A	PARTICIPANT	\N	PRESENT	0
543235	542926	19515S	PARTICIPANT	\N	PRESENT	0
543236	542926	20144B	PARTICIPANT	\N	PRESENT	0
543237	542926	14257W	PARTICIPANT	\N	PRESENT	0
543238	542926	14267Y	PARTICIPANT	\N	PRESENT	0
543239	542926	20062A	PARTICIPANT	\N	PRESENT	0
543240	542926	20072C	PARTICIPANT	\N	PRESENT	0
543241	542926	19575F	PARTICIPANT	\N	PRESENT	0
543242	542926	19599P	PARTICIPANT	\N	PRESENT	0
543243	542926	19758L	PARTICIPANT	\N	PRESENT	0
543244	542926	04033B	PARTICIPANT	\N	PRESENT	0
543245	542926	11103C	PARTICIPANT	\N	PRESENT	0
543246	542926	19533U	PARTICIPANT	\N	PRESENT	0
543247	542926	14031R	PARTICIPANT	\N	PRESENT	0
543248	542926	20044X	PARTICIPANT	\N	PRESENT	0
543249	542926	20126Y	PARTICIPANT	\N	PRESENT	0
543250	542926	08056B	PARTICIPANT	\N	PRESENT	0
543251	542926	19954N	PARTICIPANT	\N	PRESENT	0
543252	542926	20124W	PARTICIPANT	\N	PRESENT	0
543253	542926	19651A	PARTICIPANT	\N	PRESENT	0
543254	542926	14083S	PARTICIPANT	\N	PRESENT	0
543255	542926	19543W	PARTICIPANT	\N	PRESENT	0
543256	542926	20024T	PARTICIPANT	\N	PRESENT	0
543257	542926	20054A	PARTICIPANT	\N	PRESENT	0
543258	542926	01024M	PARTICIPANT	\N	PRESENT	0
543259	542926	20076G	PARTICIPANT	\N	PRESENT	0
543260	542926	19479G	PARTICIPANT	\N	PRESENT	0
543261	542926	20034V	PARTICIPANT	\N	PRESENT	0
543262	542926	20074E	PARTICIPANT	\N	PRESENT	0
543263	542926	20022R	PARTICIPANT	\N	PRESENT	0
543264	542926	14071N	PARTICIPANT	\N	PRESENT	0
543265	542926	19347U	PARTICIPANT	\N	PRESENT	0
543266	542926	19563B	PARTICIPANT	\N	PRESENT	0
543267	542926	20118Y	PARTICIPANT	\N	PRESENT	0
543270	542926	20096L	PARTICIPANT	\N	PRESENT	0
543271	542926	14259Y	PARTICIPANT	\N	PRESENT	0
543272	542926	08028W	PARTICIPANT	\N	PRESENT	0
543273	542926	14205J	PARTICIPANT	\N	PRESENT	0
543275	542926	20052X	PARTICIPANT	\N	PRESENT	0
543276	542926	20048C	PARTICIPANT	\N	PRESENT	0
543277	542926	14217N	PARTICIPANT	\N	PRESENT	0
543279	542926	19553Y	PARTICIPANT	\N	PRESENT	0
543280	542926	19798U	PARTICIPANT	\N	PRESENT	0
543281	542926	19467C	PARTICIPANT	\N	PRESENT	0
543282	542926	19637C	PARTICIPANT	\N	PRESENT	0
543283	542926	19866P	PARTICIPANT	\N	PRESENT	0
543284	542926	20020P	PARTICIPANT	\N	PRESENT	0
543285	542926	20028X	PARTICIPANT	\N	PRESENT	0
543286	542926	19762G	PARTICIPANT	\N	PRESENT	0
543287	542926	04043D	PARTICIPANT	\N	PRESENT	0
543288	542926	19441R	PARTICIPANT	\N	PRESENT	0
543289	542926	14219Q	PARTICIPANT	\N	PRESENT	0
543290	542926	19525U	PARTICIPANT	\N	PRESENT	0
543291	542926	14105F	PARTICIPANT	\N	PRESENT	0
543292	542926	19251M	PARTICIPANT	\N	PRESENT	0
543293	542926	19521Q	PARTICIPANT	\N	PRESENT	0
543294	542926	20100N	PARTICIPANT	\N	PRESENT	0
543295	542926	11065P	PARTICIPANT	\N	PRESENT	0
543296	542926	20046A	PARTICIPANT	\N	PRESENT	0
543297	542926	19549D	PARTICIPANT	\N	PRESENT	0
543298	542926	20056C	PARTICIPANT	\N	PRESENT	0
543299	542926	19747H	PARTICIPANT	\N	PRESENT	0
543300	542926	19387D	PARTICIPANT	\N	PRESENT	0
543301	542926	19739H	PARTICIPANT	\N	PRESENT	0
543302	542926	14069U	PARTICIPANT	\N	PRESENT	0
543303	542926	14053L	PARTICIPANT	\N	PRESENT	0
543304	542926	20068G	PARTICIPANT	\N	PRESENT	0
543387	542927	08073C	PARTICIPANT	\N	PRESENT	0
543388	542927	19413M	PARTICIPANT	\N	PRESENT	0
543389	542927	19549D	PARTICIPANT	\N	PRESENT	0
543390	542927	19525U	PARTICIPANT	\N	PRESENT	0
543391	542927	11065P	PARTICIPANT	\N	PRESENT	0
543392	542927	20092G	PARTICIPANT	\N	PRESENT	0
543393	542927	19503N	PARTICIPANT	\N	PRESENT	0
543394	542927	20046A	PARTICIPANT	\N	PRESENT	0
543395	542927	19866P	PARTICIPANT	\N	PRESENT	0
543396	542927	19637C	PARTICIPANT	\N	PRESENT	0
543397	542927	20102Q	PARTICIPANT	\N	PRESENT	0
543398	542927	19758L	PARTICIPANT	\N	PRESENT	0
543400	542927	14219Q	PARTICIPANT	\N	PRESENT	0
543401	542927	19739H	PARTICIPANT	\N	PRESENT	0
543402	542927	08009T	PARTICIPANT	\N	PRESENT	0
543403	542927	20072C	PARTICIPANT	\N	PRESENT	0
543404	542927	19563B	PARTICIPANT	\N	PRESENT	0
543405	542927	20074E	PARTICIPANT	\N	PRESENT	0
543406	542927	19651A	PARTICIPANT	\N	PRESENT	0
543407	542927	19521Q	PARTICIPANT	\N	PRESENT	0
543408	542927	19747H	PARTICIPANT	\N	PRESENT	0
543409	542927	01024M	PARTICIPANT	\N	PRESENT	0
543410	542927	14169X	PARTICIPANT	\N	PRESENT	0
543411	542927	04043D	PARTICIPANT	\N	PRESENT	0
543412	542927	18083K	PARTICIPANT	\N	PRESENT	0
543413	542927	19701S	PARTICIPANT	\N	PRESENT	0
543414	542927	20076G	PARTICIPANT	\N	PRESENT	0
543415	542927	19533U	PARTICIPANT	\N	PRESENT	0
543416	542927	14053L	PARTICIPANT	\N	PRESENT	0
543417	542927	20172F	PARTICIPANT	\N	PRESENT	0
543418	542927	20124W	PARTICIPANT	\N	PRESENT	0
543419	542927	20090E	PARTICIPANT	\N	PRESENT	0
543420	542927	19954N	PARTICIPANT	\N	PRESENT	0
543421	542927	20020P	PARTICIPANT	\N	PRESENT	0
543422	542927	20068G	PARTICIPANT	\N	PRESENT	0
543423	542927	19619A	PARTICIPANT	\N	PRESENT	0
543424	542927	20096L	PARTICIPANT	\N	PRESENT	0
543425	542927	20062A	PARTICIPANT	\N	PRESENT	0
543426	542927	20056C	PARTICIPANT	\N	PRESENT	0
543427	542927	14033T	PARTICIPANT	\N	PRESENT	0
543428	542927	19467C	PARTICIPANT	\N	PRESENT	0
543429	542927	20044X	PARTICIPANT	\N	PRESENT	0
543430	542927	20140W	PARTICIPANT	\N	PRESENT	0
551608	551445	11033F	PARTICIPANT	\N	PRESENT	0
551609	551445	08061X	PARTICIPANT	\N	PRESENT	0
551610	551445	14030Q	PARTICIPANT	\N	PRESENT	0
551611	551445	19667J	PARTICIPANT	\N	PRESENT	0
551612	551445	12041X	PARTICIPANT	\N	PRESENT	0
551613	551445	11026G	PARTICIPANT	\N	PRESENT	0
551614	551445	19657G	PARTICIPANT	\N	PRESENT	0
551615	551445	14021P	PARTICIPANT	\N	PRESENT	0
551616	551445	05008E	PARTICIPANT	\N	PRESENT	0
551617	551445	11045K	PARTICIPANT	\N	PRESENT	0
551618	551445	04034C	PARTICIPANT	\N	PRESENT	0
551619	551445	19689Q	PARTICIPANT	\N	PRESENT	0
551620	551445	20094J	PARTICIPANT	\N	PRESENT	0
551621	551445	19573D	PARTICIPANT	\N	PRESENT	0
551622	551445	19954N	PARTICIPANT	\N	PRESENT	0
551623	551445	19719D	PARTICIPANT	\N	PRESENT	0
551624	551445	20134Y	PARTICIPANT	\N	PRESENT	0
551625	551445	20124W	PARTICIPANT	\N	PRESENT	0
551626	551445	04047H	PARTICIPANT	\N	PRESENT	0
551627	551445	19647E	PARTICIPANT	\N	PRESENT	0
551628	551445	20098N	PARTICIPANT	\N	PRESENT	0
551629	551445	19251M	PARTICIPANT	\N	PRESENT	0
551630	551445	17965H	PARTICIPANT	\N	PRESENT	0
551631	551445	19611R	PARTICIPANT	\N	PRESENT	0
551638	551445	19413M	PARTICIPANT	\N	PRESENT	0
551639	551445	14229S	PARTICIPANT	\N	PRESENT	0
551640	551445	19695N	PARTICIPANT	\N	PRESENT	0
551651	551445	20142Y	PARTICIPANT	\N	PRESENT	0
551652	551445	01028R	PARTICIPANT	\N	PRESENT	0
551660	551445	14026U	PARTICIPANT	\N	PRESENT	0
551661	551445	14089Y	PARTICIPANT	\N	PRESENT	0
551662	551445	11067R	PARTICIPANT	\N	PRESENT	0
551663	551445	19503N	PARTICIPANT	\N	PRESENT	0
551664	551445	14259Y	PARTICIPANT	\N	PRESENT	0
551665	551445	19347U	PARTICIPANT	\N	PRESENT	0
551666	551445	11012A	PARTICIPANT	\N	PRESENT	0
551667	551445	04033B	PARTICIPANT	\N	PRESENT	0
551668	551447	08073C	PARTICIPANT	\N	PRESENT	0
551669	551447	14059S	PARTICIPANT	\N	PRESENT	0
551670	551447	20054A	PARTICIPANT	\N	PRESENT	0
551671	551447	14237S	PARTICIPANT	\N	PRESENT	0
551672	551447	01025N	PARTICIPANT	\N	PRESENT	0
551673	551447	20088L	PARTICIPANT	\N	PRESENT	0
551674	551447	20090E	PARTICIPANT	\N	PRESENT	0
551675	551447	20082E	PARTICIPANT	\N	PRESENT	0
551676	551140	14038Y	PARTICIPANT	\N	PRESENT	0
551677	551140	19515S	PARTICIPANT	\N	PRESENT	0
551678	551140	20034V	PARTICIPANT	\N	PRESENT	0
551679	551140	20092G	PARTICIPANT	\N	PRESENT	0
551680	551140	19413M	PARTICIPANT	\N	PRESENT	0
551681	551140	20144B	PARTICIPANT	\N	PRESENT	0
551682	551140	19695N	PARTICIPANT	\N	PRESENT	0
551683	551140	11090Q	PRESIDENT	0	PRESENT	0
551684	551140	20018V	PARTICIPANT	\N	PRESENT	0
551685	551447	08015R	PARTICIPANT	\N	PRESENT	0
551686	551447	17229F	PARTICIPANT	\N	PRESENT	0
551687	551140	19768N	PARTICIPANT	\N	PRESENT	1
551688	551140	19782L	PARTICIPANT	\N	PRESENT	0
551689	551140	19631V	PARTICIPANT	\N	PRESENT	1
551690	551140	20174H	PARTICIPANT	\N	PRESENT	1
551691	551447	19347U	PARTICIPANT	\N	PRESENT	0
551692	551140	19747H	PARTICIPANT	\N	PRESENT	0
551693	551447	19507S	PARTICIPANT	\N	PRESENT	0
551694	551447	97011G	PARTICIPANT	\N	PRESENT	0
551695	551447	14211G	PARTICIPANT	\N	PRESENT	0
551696	551140	20030R	PARTICIPANT	\N	PRESENT	1
551697	551140	14357A	PARTICIPANT	\N	PRESENT	0
551698	551140	14187A	PARTICIPANT	\N	PRESENT	0
551699	551140	19575F	PARTICIPANT	\N	PRESENT	1
551700	551447	14189C	PARTICIPANT	\N	PRESENT	0
551701	551447	19782L	PARTICIPANT	\N	PRESENT	0
551702	551447	20034V	PARTICIPANT	\N	PRESENT	0
551703	551447	20126Y	PARTICIPANT	\N	PRESENT	0
551704	551447	20140W	PARTICIPANT	\N	PRESENT	0
551705	551447	14033T	PARTICIPANT	\N	PRESENT	0
551706	551447	14195A	PARTICIPANT	\N	PRESENT	0
551708	551447	11054L	PARTICIPANT	\N	PRESENT	0
551709	551447	20070A	PARTICIPANT	\N	PRESENT	0
551710	551447	14169X	PARTICIPANT	\N	PRESENT	0
551711	551447	17737W	PARTICIPANT	\N	PRESENT	0
551712	551447	19685L	PARTICIPANT	\N	PRESENT	0
551713	551447	19251M	PARTICIPANT	\N	PRESENT	0
551714	551447	19573D	PARTICIPANT	\N	PRESENT	0
551724	551447	19735D	PARTICIPANT	\N	PRESENT	0
551725	551447	04034C	PARTICIPANT	\N	PRESENT	0
551726	551447	14147R	PARTICIPANT	\N	PRESENT	0
551727	551447	14030Q	PARTICIPANT	\N	PRESENT	0
551737	551447	20098N	PARTICIPANT	\N	PRESENT	0
551729	551447	19531S	PARTICIPANT	\N	PRESENT	0
551730	551447	20146D	PARTICIPANT	\N	PRESENT	0
551731	551447	14207L	PARTICIPANT	\N	PRESENT	0
551732	551447	20056C	PARTICIPANT	\N	PRESENT	0
551733	551447	05008E	PARTICIPANT	\N	PRESENT	0
551734	551447	20074E	PARTICIPANT	\N	PRESENT	0
551742	551447	04085P	PARTICIPANT	\N	PRESENT	0
551748	551447	19565D	PARTICIPANT	\N	PRESENT	0
551775	551447	11026G	PARTICIPANT	\N	PRESENT	0
551819	549183	18083K	PARTICIPANT	\N	PRESENT	0
551820	549183	14237S	PARTICIPANT	\N	PRESENT	0
551811	551448	11045K	PARTICIPANT	\N	PRESENT	0
551821	549183	20032T	PARTICIPANT	\N	PRESENT	0
551822	549183	20140W	PARTICIPANT	\N	PRESENT	0
551823	549183	19387D	PARTICIPANT	\N	PRESENT	0
551824	549183	19739H	PARTICIPANT	\N	PRESENT	0
551825	549183	14219Q	PRESIDENT	0	PRESENT	0
551826	549183	20068G	PARTICIPANT	\N	PRESENT	1
551827	549183	19701S	PARTICIPANT	\N	PRESENT	0
551828	549183	14031R	PARTICIPANT	\N	PRESENT	0
551829	549183	19503N	PARTICIPANT	\N	PRESENT	0
551830	549183	19251M	PARTICIPANT	\N	PRESENT	0
551833	549183	19549D	PARTICIPANT	\N	PRESENT	1
551834	549183	19820Y	PARTICIPANT	\N	PRESENT	1
551835	549183	20096L	PARTICIPANT	\N	PRESENT	0
551836	549183	19685L	PARTICIPANT	\N	PRESENT	0
551837	549183	19619A	PARTICIPANT	\N	PRESENT	0
551838	549183	11101A	PARTICIPANT	\N	PRESENT	1
551839	549183	19637C	PARTICIPANT	\N	PRESENT	1
551855	551448	19565D	PARTICIPANT	\N	PRESENT	0
551856	551448	20102Q	PARTICIPANT	\N	PRESENT	0
551857	551448	20028X	PARTICIPANT	\N	PRESENT	0
551858	551448	20088L	PARTICIPANT	\N	PRESENT	0
551859	551448	19413M	PARTICIPANT	\N	PRESENT	0
551860	551448	19333N	PARTICIPANT	\N	PRESENT	0
551861	551448	19637C	PARTICIPANT	\N	PRESENT	0
551862	551448	20092G	PARTICIPANT	\N	PRESENT	0
551863	551448	14207L	PARTICIPANT	\N	PRESENT	0
551864	551448	19387D	PARTICIPANT	\N	PRESENT	0
551865	551448	20072C	PARTICIPANT	\N	PRESENT	0
551866	551448	19467C	PARTICIPANT	\N	PRESENT	0
551867	551448	19507S	PARTICIPANT	\N	PRESENT	0
551868	551448	18083K	PARTICIPANT	\N	PRESENT	0
551869	551448	19954N	PARTICIPANT	\N	PRESENT	0
551870	551448	14169X	PARTICIPANT	\N	PRESENT	0
551871	551448	11090Q	PARTICIPANT	\N	PRESENT	0
551872	551448	20022R	PARTICIPANT	\N	PRESENT	0
551873	551448	97011G	PARTICIPANT	\N	PRESENT	0
551874	551448	20062A	PARTICIPANT	\N	PRESENT	0
551875	551448	11103C	PARTICIPANT	\N	PRESENT	0
543937	542589	01043Q	PARTICIPANT	\N	PRESENT	1
543938	542823	14111D	PARTICIPANT	\N	PRESENT	0
543939	542823	10015M	PARTICIPANT	\N	PRESENT	0
543940	542823	19543W	PARTICIPANT	\N	PRESENT	0
543941	542823	19585H	PARTICIPANT	\N	PRESENT	0
543942	542823	04047H	PRESIDENT	0	PRESENT	0
543943	542823	19673G	PARTICIPANT	\N	PRESENT	0
543944	542823	14089Y	PARTICIPANT	\N	PRESENT	0
543945	542823	18083K	PARTICIPANT	\N	PRESENT	0
543946	542823	20108W	PARTICIPANT	\N	PRESENT	0
543947	542823	14041T	PARTICIPANT	\N	PRESENT	0
543948	542823	14215L	PARTICIPANT	\N	PRESENT	0
543949	542823	11085T	PARTICIPANT	\N	PRESENT	0
543950	542823	08018U	PARTICIPANT	\N	PRESENT	0
543954	539764	20100N	PARTICIPANT	\N	PRESENT	0
543959	543936	14327T	PARTICIPANT	\N	PRESENT	0
543960	543936	14331P	PARTICIPANT	\N	PRESENT	0
543961	543936	19479G	PARTICIPANT	\N	PRESENT	0
543962	543936	11048N	PARTICIPANT	\N	PRESENT	0
543963	543936	08034U	PARTICIPANT	\N	PRESENT	0
543964	543936	19687N	PARTICIPANT	\N	PRESENT	0
543965	543936	19689Q	PARTICIPANT	\N	PRESENT	0
543966	543936	11053K	PARTICIPANT	\N	PRESENT	0
543967	543936	19667J	PARTICIPANT	\N	PRESENT	0
543968	543936	20044X	PARTICIPANT	\N	PRESENT	0
543969	543936	11070L	PARTICIPANT	\N	PRESENT	0
543970	543936	14225N	PRESIDENT	0	PRESENT	0
543971	543936	11040E	PARTICIPANT	\N	PRESENT	0
543972	543936	04086Q	PARTICIPANT	\N	PRESENT	0
543973	543936	14083S	PARTICIPANT	\N	PRESENT	0
543995	542823	14231L	PARTICIPANT	\N	PRESENT	0
543975	543936	20070A	PARTICIPANT	\N	PRESENT	0
543976	543936	08009T	PARTICIPANT	\N	PRESENT	0
543977	543936	19741B	PARTICIPANT	\N	PRESENT	0
543978	543936	20116W	PARTICIPANT	\N	PRESENT	0
543979	543936	20022R	PARTICIPANT	\N	PRESENT	0
543980	543936	07029T	PARTICIPANT	\N	EXCUSE	0
543981	542823	20074E	PARTICIPANT	\N	PRESENT	0
543982	543936	19647E	PARTICIPANT	\N	PRESENT	0
543983	543936	19531S	PARTICIPANT	\N	PRESENT	0
543984	543936	01048V	PARTICIPANT	\N	PRESENT	0
543985	543936	14121F	PARTICIPANT	\N	PRESENT	0
543986	543936	19349W	PARTICIPANT	\N	PRESENT	0
543996	542823	11056N	PARTICIPANT	\N	PRESENT	0
543997	542823	05008E	PARTICIPANT	\N	PRESENT	0
543998	542823	17737W	PARTICIPANT	\N	PRESENT	0
544115	542823	01028R	PARTICIPANT	\N	PRESENT	0
544136	542930	86034E	PARTICIPANT	\N	PRESENT	0
544137	542930	19525U	PARTICIPANT	\N	PRESENT	0
544138	542930	14267Y	PARTICIPANT	\N	PRESENT	0
544139	542930	20102Q	PARTICIPANT	\N	PRESENT	0
544140	542930	19715Y	PARTICIPANT	\N	PRESENT	0
544141	542930	11027H	PARTICIPANT	\N	PRESENT	0
544142	542930	19413M	PARTICIPANT	\N	PRESENT	0
544143	542930	08017T	PARTICIPANT	\N	PRESENT	0
544145	542930	14231L	PARTICIPANT	\N	PRESENT	0
544147	542930	14121F	PARTICIPANT	\N	PRESENT	0
544148	542930	14111D	PARTICIPANT	\N	PRESENT	0
544149	542930	20052X	PARTICIPANT	\N	PRESENT	0
544150	542930	20128B	PARTICIPANT	\N	PRESENT	0
544151	542930	19820Y	PARTICIPANT	\N	PRESENT	0
544152	542930	11067R	PARTICIPANT	\N	PRESENT	0
544153	542930	20046A	PARTICIPANT	\N	PRESENT	0
544154	542930	19695N	PARTICIPANT	\N	PRESENT	0
544155	542930	20112S	PARTICIPANT	\N	PRESENT	0
544156	542930	11031D	PARTICIPANT	\N	PRESENT	0
544160	542930	11040E	PARTICIPANT	\N	PRESENT	0
544161	542930	04085P	PARTICIPANT	\N	PRESENT	0
544162	542930	19687N	PARTICIPANT	\N	PRESENT	0
544163	542930	11033F	PARTICIPANT	\N	PRESENT	0
544164	542930	11065P	PARTICIPANT	\N	PRESENT	0
544165	542930	19711U	PARTICIPANT	\N	PRESENT	0
544166	542930	01058X	PARTICIPANT	\N	PRESENT	0
544167	542930	19347U	PARTICIPANT	\N	PRESENT	0
544168	542930	19689Q	PARTICIPANT	\N	PRESENT	0
544169	542930	19575F	PARTICIPANT	\N	PRESENT	0
544170	542930	20100N	PARTICIPANT	\N	PRESENT	0
544171	542930	20142Y	PARTICIPANT	\N	PRESENT	0
544172	542930	20076G	PARTICIPANT	\N	PRESENT	0
544173	542930	08061X	PARTICIPANT	\N	PRESENT	0
544174	542930	20074E	PARTICIPANT	\N	PRESENT	0
544175	542930	11072N	PARTICIPANT	\N	PRESENT	0
544176	542930	11083R	PARTICIPANT	\N	PRESENT	0
544177	542930	14123H	PARTICIPANT	\N	PRESENT	0
544178	542930	19651A	PARTICIPANT	\N	PRESENT	0
544179	542930	04086Q	PARTICIPANT	\N	PRESENT	0
544180	542930	20146D	PARTICIPANT	\N	PRESENT	0
544181	542930	20174H	PARTICIPANT	\N	PRESENT	0
544182	542930	19329S	PARTICIPANT	\N	PRESENT	0
544183	542930	01057W	PARTICIPANT	\N	PRESENT	0
544184	542930	19515S	PARTICIPANT	\N	PRESENT	0
544185	542930	19673G	PARTICIPANT	\N	PRESENT	0
544186	542930	11080N	PARTICIPANT	\N	PRESENT	0
544187	542930	19758L	PARTICIPANT	\N	PRESENT	0
544188	542930	20072C	PARTICIPANT	\N	PRESENT	0
544189	542930	19866P	PARTICIPANT	\N	PRESENT	0
544190	542930	11012A	PARTICIPANT	\N	PRESENT	0
544191	542930	19719D	PARTICIPANT	\N	PRESENT	0
544192	542930	14207L	PARTICIPANT	\N	PRESENT	0
544193	542930	11043H	PARTICIPANT	\N	PRESENT	0
544194	542930	14107H	PARTICIPANT	\N	PRESENT	0
544195	542930	20022R	PARTICIPANT	\N	PRESENT	0
544196	542930	20116W	PARTICIPANT	\N	PRESENT	0
544197	542930	01048V	PARTICIPANT	\N	PRESENT	0
544198	542930	17589D	PARTICIPANT	\N	PRESENT	0
544199	542930	19545Y	PARTICIPANT	\N	PRESENT	0
544200	542930	14195A	PARTICIPANT	\N	PRESENT	0
544201	542930	14251Q	PARTICIPANT	\N	PRESENT	0
544202	542930	20038A	PARTICIPANT	\N	PRESENT	0
544203	542930	19563B	PARTICIPANT	\N	PRESENT	0
544204	542930	19585H	PARTICIPANT	\N	PRESENT	0
544205	542930	04057K	PARTICIPANT	\N	PRESENT	0
544206	542930	19573D	PARTICIPANT	\N	PRESENT	0
544207	542930	18083K	PARTICIPANT	\N	PRESENT	0
544208	542930	01028R	PARTICIPANT	\N	PRESENT	0
544209	542930	14021P	PARTICIPANT	\N	PRESENT	0
544210	542930	19683J	PARTICIPANT	\N	PRESENT	0
544211	542930	14187A	PARTICIPANT	\N	PRESENT	0
544212	542930	04033B	PARTICIPANT	\N	PRESENT	0
544213	542930	14229S	PARTICIPANT	\N	PRESENT	0
544214	542930	11066Q	PARTICIPANT	\N	PRESENT	0
544215	542930	20172F	PARTICIPANT	\N	PRESENT	0
544216	542930	19333N	PARTICIPANT	\N	PRESENT	0
544217	542930	14259Y	PARTICIPANT	\N	PRESENT	0
544218	542930	19399H	PARTICIPANT	\N	PRESENT	0
544219	542930	14249W	PARTICIPANT	\N	PRESENT	0
544220	542930	17737W	PARTICIPANT	\N	PRESENT	0
544221	542930	08012N	PARTICIPANT	\N	PRESENT	0
544222	542930	20032T	PARTICIPANT	\N	PRESENT	0
544223	542930	19631V	PARTICIPANT	\N	PRESENT	0
544224	542930	19723Y	PARTICIPANT	\N	PRESENT	0
544225	542930	19503N	PARTICIPANT	\N	PRESENT	0
544226	542930	14038Y	PARTICIPANT	\N	PRESENT	0
544227	542930	19251M	PARTICIPANT	\N	PRESENT	0
544228	542930	20064C	PARTICIPANT	\N	PRESENT	0
544229	542930	11045K	PARTICIPANT	\N	PRESENT	0
544230	542930	20056C	PARTICIPANT	\N	PRESENT	0
544231	542930	19599P	PARTICIPANT	\N	PRESENT	0
544239	542930	19467C	PARTICIPANT	\N	PRESENT	0
544233	542930	20082E	PARTICIPANT	\N	PRESENT	0
544234	542930	08018U	PARTICIPANT	\N	PRESENT	0
544235	542930	20118Y	PARTICIPANT	\N	PRESENT	0
544236	542930	20060X	PARTICIPANT	\N	PRESENT	0
544237	542930	19507S	PARTICIPANT	\N	PRESENT	0
544238	542930	18193Q	PARTICIPANT	\N	PRESENT	0
544240	542930	14041T	PARTICIPANT	\N	PRESENT	0
544241	542930	20042V	PARTICIPANT	\N	PRESENT	0
544242	542930	19543W	PARTICIPANT	\N	PRESENT	0
544243	542930	14026U	PARTICIPANT	\N	PRESENT	0
544244	542930	19747H	PARTICIPANT	\N	PRESENT	0
544245	542930	19441R	PARTICIPANT	\N	PRESENT	0
544246	542930	19741B	PARTICIPANT	\N	PRESENT	0
544247	542930	14030Q	PARTICIPANT	\N	PRESENT	0
544248	542930	19739H	PARTICIPANT	\N	PRESENT	0
544249	542930	19511N	PARTICIPANT	\N	PRESENT	0
544250	542930	20066E	PARTICIPANT	\N	PRESENT	0
544251	542930	14255U	PARTICIPANT	\N	PRESENT	0
544252	542930	01034P	PARTICIPANT	\N	PRESENT	0
544253	542930	19611R	PARTICIPANT	\N	PRESENT	0
544254	542930	19533U	PARTICIPANT	\N	PRESENT	0
544255	542930	19549D	PARTICIPANT	\N	PRESENT	0
561244	559677	17023S	PARTICIPANT	\N	PRESENT	1
561246	559677	04035D	PARTICIPANT	\N	PRESENT	1
561247	559677	20072C	PARTICIPANT	\N	PRESENT	1
561248	559677	08047A	PARTICIPANT	\N	PRESENT	1
561249	559677	19443T	PARTICIPANT	\N	PRESENT	1
561250	559677	11041F	PARTICIPANT	\N	PRESENT	1
561251	559677	04034C	PARTICIPANT	\N	PRESENT	1
561546	561545	11027H	PARTICIPANT	\N	PRESENT	0
561555	561553	11027H	PARTICIPANT	\N	PRESENT	0
561649	559487	19421M	PARTICIPANT	\N	PRESENT	1
561680	560356	14030Q	PARTICIPANT	\N	PRESENT	0
561681	560356	19719D	PARTICIPANT	\N	PRESENT	0
561682	560356	20038A	PARTICIPANT	\N	PRESENT	0
561683	560356	19798U	PARTICIPANT	\N	PRESENT	1
561707	559486	20032T	PARTICIPANT	\N	PRESENT	0
561708	559486	18083K	PARTICIPANT	\N	PRESENT	0
561709	559486	19681G	PARTICIPANT	\N	PRESENT	1
561710	559486	20140W	PARTICIPANT	\N	PRESENT	0
561711	559486	19577H	PARTICIPANT	\N	PRESENT	1
561712	559486	20100N	PARTICIPANT	\N	PRESENT	0
561713	559486	19820Y	PARTICIPANT	\N	PRESENT	0
561714	559486	19387D	PARTICIPANT	\N	PRESENT	1
561715	559486	20106U	PARTICIPANT	\N	PRESENT	1
561716	559486	19333N	PARTICIPANT	\N	PRESENT	0
561717	559486	19551W	PARTICIPANT	\N	PRESENT	0
561718	559486	14219Q	PARTICIPANT	\N	PRESENT	0
561719	559486	14031R	PARTICIPANT	\N	PRESENT	0
561720	559486	19637C	PARTICIPANT	\N	PRESENT	0
561721	559486	20118Y	PARTICIPANT	\N	PRESENT	0
561722	559486	19503N	PARTICIPANT	\N	PRESENT	0
561723	559486	20136B	PARTICIPANT	\N	PRESENT	0
561760	559678	19421M	PARTICIPANT	\N	PRESENT	1
561735	560357	19719D	PARTICIPANT	\N	PRESENT	0
561736	559539	19545Y	PARTICIPANT	\N	PRESENT	1
561737	559539	11110B	PARTICIPANT	\N	PRESENT	1
561738	559539	12016W	PARTICIPANT	\N	PRESENT	1
561739	559539	19671E	PARTICIPANT	\N	PRESENT	1
561740	559539	19479G	PARTICIPANT	\N	PRESENT	1
561742	560357	20038A	PARTICIPANT	\N	PRESENT	0
561743	560357	14109K	PARTICIPANT	\N	PRESENT	1
561744	560357	19798U	PARTICIPANT	\N	PRESENT	1
561750	559539	08009T	PARTICIPANT	\N	EXCUSE	0
561759	559678	14105F	PARTICIPANT	\N	PRESENT	1
561761	559678	20128B	PARTICIPANT	\N	EXCUSE	0
561766	561765	20086J	PARTICIPANT	\N	PRESENT	0
562037	562036	14215L	PARTICIPANT	\N	PRESENT	0
562041	562040	14215L	PARTICIPANT	\N	PRESENT	0
562042	562038	14329V	PARTICIPANT	\N	PRESENT	0
562044	562043	14173T	PARTICIPANT	\N	PRESENT	0
562045	562043	14329V	PARTICIPANT	\N	PRESENT	0
562048	562047	19701S	PARTICIPANT	\N	PRESENT	0
562049	562047	19826F	PARTICIPANT	\N	PRESENT	0
562050	562047	18083K	PARTICIPANT	\N	PRESENT	0
562051	562047	20120S	PARTICIPANT	\N	PRESENT	0
562053	562052	19701S	PARTICIPANT	\N	PRESENT	0
562054	562052	19826F	PARTICIPANT	\N	PRESENT	0
562059	562056	19551W	PARTICIPANT	\N	PRESENT	0
562060	562056	19701S	PARTICIPANT	\N	PRESENT	0
562061	562056	19826F	PARTICIPANT	\N	PRESENT	0
562067	562066	19551W	PARTICIPANT	\N	PRESENT	0
562068	562066	19701S	PARTICIPANT	\N	PRESENT	0
562069	562066	19826F	PARTICIPANT	\N	PRESENT	0
562072	562071	19826F	PARTICIPANT	\N	PRESENT	0
562074	562070	19701S	PARTICIPANT	\N	PRESENT	0
562075	562070	19826F	PARTICIPANT	\N	PRESENT	0
562076	562073	19711U	PARTICIPANT	\N	PRESENT	0
562085	539601	14189C	PARTICIPANT	\N	PRESENT	0
562086	539601	14030Q	PRESIDENT	0	PRESENT	0
562087	539601	20080C	PARTICIPANT	\N	EXCUSE	0
562088	539601	11031D	PARTICIPANT	\N	EXCUSE	0
562089	539601	19693L	PARTICIPANT	\N	PRESENT	0
562090	539601	20106U	PARTICIPANT	\N	PRESENT	0
562091	539601	20056C	PARTICIPANT	\N	PRESENT	1
562092	539601	14109K	PARTICIPANT	\N	PRESENT	0
562093	539601	20118Y	PARTICIPANT	\N	PRESENT	1
562094	539601	20130U	PARTICIPANT	\N	EXCUSE	0
562095	539601	20098N	PARTICIPANT	\N	PRESENT	0
562096	539601	19527W	PARTICIPANT	\N	PRESENT	1
562097	539601	14073Q	PARTICIPANT	\N	PRESENT	0
562098	539601	19533U	PARTICIPANT	\N	PRESENT	0
562099	539601	20052X	PARTICIPANT	\N	PRESENT	0
562100	539601	11043H	PARTICIPANT	\N	PRESENT	0
562186	562185	19717B	PARTICIPANT	\N	PRESENT	0
562187	562185	19631V	PARTICIPANT	\N	PRESENT	0
562188	562185	18083K	PARTICIPANT	\N	PRESENT	0
562189	562185	19691J	PARTICIPANT	\N	PRESENT	1
562190	562185	08034U	PARTICIPANT	\N	PRESENT	0
562191	562185	14147R	PARTICIPANT	\N	PRESENT	1
562192	562185	11072N	PARTICIPANT	\N	PRESENT	0
562193	562185	20150Y	PARTICIPANT	\N	PRESENT	0
562194	562185	14059S	PARTICIPANT	\N	PRESENT	0
562196	562195	14133K	PARTICIPANT	\N	PRESENT	0
562197	562195	11066Q	PARTICIPANT	\N	PRESENT	0
562221	562220	19709B	PARTICIPANT	\N	PRESENT	1
562222	562220	11027H	PARTICIPANT	\N	PRESENT	1
562223	562220	17023S	PARTICIPANT	\N	PRESENT	1
562225	562224	11027H	PARTICIPANT	\N	PRESENT	0
562226	562224	19709B	PARTICIPANT	\N	PRESENT	0
562230	562228	19593H	PARTICIPANT	\N	PRESENT	0
562231	562228	14059S	PARTICIPANT	\N	PRESENT	0
562232	562228	19611R	PARTICIPANT	\N	PRESENT	0
562233	562228	20132W	PARTICIPANT	\N	PRESENT	1
562234	562228	19721W	PARTICIPANT	\N	PRESENT	1
562235	562228	14147R	PARTICIPANT	\N	PRESENT	1
562236	562228	19643A	PARTICIPANT	\N	PRESENT	1
562237	562228	20174H	PARTICIPANT	\N	PRESENT	0
562238	562228	08018U	PARTICIPANT	\N	PRESENT	0
562239	562228	04034C	PARTICIPANT	\N	PRESENT	0
562240	562228	14215L	PARTICIPANT	\N	PRESENT	0
562241	562228	08017T	PARTICIPANT	\N	PRESENT	0
562242	562228	04043D	PARTICIPANT	\N	PRESENT	0
562243	562228	14255U	PARTICIPANT	\N	PRESENT	0
562244	562228	14041T	PARTICIPANT	\N	PRESENT	0
562245	561724	19593H	PRESIDENT	0	PRESENT	0
562246	561724	19611R	PARTICIPANT	\N	EXCUSE	0
562247	561724	19735D	PARTICIPANT	\N	EXCUSE	0
562248	561724	19721W	PARTICIPANT	\N	PRESENT	1
562249	561724	14147R	PARTICIPANT	\N	PRESENT	1
562250	561724	20082E	PARTICIPANT	\N	PRESENT	1
562261	562260	14213J	PARTICIPANT	\N	PRESENT	0
562262	562260	18193Q	PARTICIPANT	\N	PRESENT	0
562269	562268	19367Y	PARTICIPANT	\N	PRESENT	0
562270	562268	11031D	PARTICIPANT	\N	PRESENT	0
562271	562268	19691J	PARTICIPANT	\N	PRESENT	0
562272	562268	14213J	PARTICIPANT	\N	PRESENT	0
562273	562268	11067R	PARTICIPANT	\N	PRESENT	0
562274	562268	19798U	PARTICIPANT	\N	PRESENT	0
562277	562276	19663E	PARTICIPANT	\N	PRESENT	0
562278	562276	11031D	PARTICIPANT	\N	PRESENT	0
562279	562276	19553Y	PARTICIPANT	\N	PRESENT	0
562281	562280	19663E	PARTICIPANT	\N	PRESENT	0
562282	562280	11031D	PARTICIPANT	\N	PRESENT	0
562283	562280	14213J	PARTICIPANT	\N	PRESENT	0
562284	562280	19553Y	PARTICIPANT	\N	PRESENT	0
562285	562280	11097X	PARTICIPANT	\N	PRESENT	0
562287	562286	19663E	PARTICIPANT	\N	PRESENT	0
562288	562286	19553Y	PARTICIPANT	\N	PRESENT	0
562289	562286	14213J	PARTICIPANT	\N	PRESENT	0
562294	562293	17779H	PARTICIPANT	\N	PRESENT	0
562295	562292	17779H	PARTICIPANT	\N	PRESENT	0
562296	562292	19651A	PARTICIPANT	\N	PRESENT	0
562297	562291	19651A	PARTICIPANT	\N	PRESENT	0
562298	562291	14179A	PARTICIPANT	\N	PRESENT	0
562299	562291	17779H	PARTICIPANT	\N	PRESENT	0
562331	562330	14267Y	PARTICIPANT	\N	PRESENT	0
562332	562330	12028B	PARTICIPANT	\N	PRESENT	0
562333	561977	19575F	PARTICIPANT	\N	PRESENT	1
562334	561977	20128B	PARTICIPANT	\N	PRESENT	1
562335	561977	19697Q	PARTICIPANT	\N	PRESENT	1
562336	561977	20114U	PARTICIPANT	\N	PRESENT	1
562337	561977	14179A	PARTICIPANT	\N	PRESENT	1
562338	561977	14147R	PARTICIPANT	\N	PRESENT	1
562342	562341	14053L	PARTICIPANT	\N	PRESENT	0
562343	562339	18193Q	PARTICIPANT	\N	PRESENT	1
562344	562339	19679N	PARTICIPANT	\N	PRESENT	1
562347	559720	19703U	PARTICIPANT	\N	PRESENT	1
543433	542927	20180F	PARTICIPANT	\N	PRESENT	0
543434	542927	20118Y	PARTICIPANT	\N	PRESENT	0
543435	542927	19826F	PARTICIPANT	\N	PRESENT	0
543436	542927	07004J	PARTICIPANT	\N	PRESENT	0
543437	542927	14205J	PARTICIPANT	\N	PRESENT	0
543438	542927	20026V	PARTICIPANT	\N	PRESENT	0
543439	542927	19251M	PARTICIPANT	\N	PRESENT	0
543440	542927	14031R	PARTICIPANT	\N	PRESENT	0
543442	542927	01058X	PARTICIPANT	\N	PRESENT	0
543448	542927	19575F	PARTICIPANT	\N	PRESENT	0
543452	542927	20034V	PARTICIPANT	\N	PRESENT	0
543453	542927	14042U	PARTICIPANT	\N	PRESENT	0
543454	542927	19367Y	PARTICIPANT	\N	PRESENT	0
543455	542927	11101A	PARTICIPANT	\N	PRESENT	0
543456	542927	20142Y	PARTICIPANT	\N	PRESENT	0
543457	542927	19383Y	PARTICIPANT	\N	PRESENT	0
543458	542927	20116W	PARTICIPANT	\N	PRESENT	0
543459	542927	20028X	PARTICIPANT	\N	PRESENT	0
543460	542927	11103C	PARTICIPANT	\N	PRESENT	0
543461	542927	08034U	PARTICIPANT	\N	PRESENT	0
543462	542927	19507S	PARTICIPANT	\N	PRESENT	0
543463	542927	20100N	PARTICIPANT	\N	PRESENT	0
543464	542927	19333N	PARTICIPANT	\N	PRESENT	0
543465	542927	01057W	PARTICIPANT	\N	PRESENT	0
543466	542927	14121F	PARTICIPANT	\N	PRESENT	0
543467	542927	14173T	PARTICIPANT	\N	PRESENT	0
543468	542927	20106U	PARTICIPANT	\N	PRESENT	0
543469	542927	14133K	PARTICIPANT	\N	PRESENT	0
543470	542927	14331P	PARTICIPANT	\N	PRESENT	0
543471	542927	19569H	PARTICIPANT	\N	PRESENT	0
543472	542927	14001X	PARTICIPANT	\N	PRESENT	0
543473	542927	20070A	PARTICIPANT	\N	PRESENT	0
543474	542927	20022R	PARTICIPANT	\N	PRESENT	0
543475	542927	11097X	PARTICIPANT	\N	PRESENT	0
543476	542927	11066Q	PARTICIPANT	\N	PRESENT	0
543477	542927	19387D	PARTICIPANT	\N	PRESENT	0
543478	542927	20024T	PARTICIPANT	\N	PRESENT	0
543479	542927	14083S	PARTICIPANT	\N	PRESENT	0
543480	542927	14073Q	PARTICIPANT	\N	PRESENT	0
543431	542927	14038Y	PARTICIPANT	\N	PRESENT	0
543432	542927	20032T	PARTICIPANT	\N	PRESENT	0
543481	542927	19611R	PARTICIPANT	\N	PRESENT	0
543482	542927	97011G	PARTICIPANT	\N	PRESENT	0
543483	542927	19798U	PARTICIPANT	\N	PRESENT	0
543484	542927	14213J	PARTICIPANT	\N	PRESENT	0
543485	542927	20082E	PARTICIPANT	\N	PRESENT	0
543486	542927	08047A	PARTICIPANT	\N	PRESENT	0
543490	542927	08028W	PARTICIPANT	\N	PRESENT	0
543492	542927	20108W	PARTICIPANT	\N	PRESENT	0
543493	542927	07029T	PARTICIPANT	\N	PRESENT	0
543551	542928	20106U	PARTICIPANT	\N	PRESENT	0
543552	542928	20072C	PARTICIPANT	\N	PRESENT	0
543553	542928	19758L	PARTICIPANT	\N	PRESENT	0
543554	542928	20046A	PARTICIPANT	\N	PRESENT	0
543555	542928	19521Q	PARTICIPANT	\N	PRESENT	0
543556	542928	14073Q	PARTICIPANT	\N	PRESENT	0
543557	542928	19333N	PARTICIPANT	\N	PRESENT	0
543558	542928	19525U	PARTICIPANT	\N	PRESENT	0
543559	542928	14121F	PARTICIPANT	\N	PRESENT	0
543560	542928	19549D	PARTICIPANT	\N	PRESENT	0
543561	542928	20070A	PARTICIPANT	\N	PRESENT	0
543562	542928	20082E	PARTICIPANT	\N	PRESENT	0
543563	542928	20142Y	PARTICIPANT	\N	PRESENT	0
543564	542928	17589D	PARTICIPANT	\N	PRESENT	0
543565	542928	20116W	PARTICIPANT	\N	PRESENT	0
543566	542928	19651A	PARTICIPANT	\N	PRESENT	0
543567	542928	20102Q	PARTICIPANT	\N	PRESENT	0
543568	542928	07004J	PARTICIPANT	\N	PRESENT	0
543569	542928	11097X	PARTICIPANT	\N	PRESENT	0
543570	542928	19367Y	PARTICIPANT	\N	PRESENT	0
543571	542928	01024M	PARTICIPANT	\N	PRESENT	0
543572	542928	97011G	PARTICIPANT	\N	PRESENT	0
543573	542928	19798U	PARTICIPANT	\N	PRESENT	0
543575	542928	08028W	PARTICIPANT	\N	PRESENT	0
543577	542928	20090E	PARTICIPANT	\N	PRESENT	0
543580	542928	20180F	PARTICIPANT	\N	PRESENT	0
543582	542928	14213J	PARTICIPANT	\N	PRESENT	0
543585	542928	20062A	PARTICIPANT	\N	PRESENT	0
543586	542928	14031R	PARTICIPANT	\N	PRESENT	0
543587	542928	20108W	PARTICIPANT	\N	PRESENT	0
543588	542928	14033T	PARTICIPANT	\N	PRESENT	0
543589	542928	20026V	PARTICIPANT	\N	PRESENT	0
543590	542928	07029T	PARTICIPANT	\N	PRESENT	0
543591	542928	19467C	PARTICIPANT	\N	PRESENT	0
543592	542928	14038Y	PARTICIPANT	\N	PRESENT	0
543593	542928	08047A	PARTICIPANT	\N	PRESENT	0
543594	542928	14173T	PARTICIPANT	\N	PRESENT	0
543595	542928	14331P	PARTICIPANT	\N	PRESENT	0
543596	542928	14053L	PARTICIPANT	\N	PRESENT	0
543597	542928	19387D	PARTICIPANT	\N	PRESENT	0
543598	542928	20144B	PARTICIPANT	\N	PRESENT	0
543599	542928	14001X	PARTICIPANT	\N	PRESENT	0
543600	542928	14083S	PARTICIPANT	\N	PRESENT	0
543615	542928	19565D	PARTICIPANT	\N	PRESENT	0
543617	542928	19826F	PARTICIPANT	\N	PRESENT	0
543618	542928	08061X	PARTICIPANT	\N	PRESENT	0
543620	542928	20024T	PARTICIPANT	\N	PRESENT	0
543621	542928	20042V	PARTICIPANT	\N	PRESENT	0
543622	542928	19747H	PARTICIPANT	\N	PRESENT	0
543623	542928	19479G	PARTICIPANT	\N	PRESENT	0
543624	542928	14069U	PARTICIPANT	\N	PRESENT	0
543625	542928	20128B	PARTICIPANT	\N	PRESENT	0
543626	542928	11012A	PARTICIPANT	\N	PRESENT	0
543627	542928	19760E	PARTICIPANT	\N	PRESENT	0
543628	542928	20028X	PARTICIPANT	\N	PRESENT	0
543549	542928	08073C	PARTICIPANT	\N	PRESENT	0
543550	542928	20100N	PARTICIPANT	\N	PRESENT	0
543629	542928	19553Y	PARTICIPANT	\N	PRESENT	0
543630	542928	19701S	PARTICIPANT	\N	PRESENT	0
543631	542928	20092G	PARTICIPANT	\N	PRESENT	0
543632	542928	19441R	PARTICIPANT	\N	PRESENT	0
543633	542928	14105F	PARTICIPANT	\N	PRESENT	0
543634	542928	20104S	PARTICIPANT	\N	PRESENT	0
543635	542928	14133K	PARTICIPANT	\N	PRESENT	0
543636	542928	19507S	PARTICIPANT	\N	PRESENT	0
543637	542928	19383Y	PARTICIPANT	\N	PRESENT	0
543638	542928	19691J	PARTICIPANT	\N	PRESENT	0
543639	542928	14255U	PARTICIPANT	\N	PRESENT	0
543640	542928	14030Q	PARTICIPANT	\N	PRESENT	0
543684	543619	04042C	PARTICIPANT	\N	PRESENT	0
543685	543619	11083R	PARTICIPANT	\N	PRESENT	0
543686	543619	14001X	PARTICIPANT	\N	PRESENT	0
543687	543619	20094J	PARTICIPANT	\N	PRESENT	0
543688	543619	19333N	PARTICIPANT	\N	PRESENT	0
543689	543619	10015M	PARTICIPANT	\N	PRESENT	0
543690	543619	12041X	PARTICIPANT	\N	PRESENT	0
543691	543619	20034V	PARTICIPANT	\N	PRESENT	0
543692	543619	20028X	PARTICIPANT	\N	PRESENT	0
543693	543619	20116W	PARTICIPANT	\N	PRESENT	0
543694	543619	04070G	PARTICIPANT	\N	PRESENT	0
543695	543619	19563B	PARTICIPANT	\N	PRESENT	0
543696	543619	19441R	PARTICIPANT	\N	PRESENT	0
543697	543619	14105F	PARTICIPANT	\N	PRESENT	0
543698	543619	11048N	PARTICIPANT	\N	PRESENT	0
543707	543619	20082E	PARTICIPANT	\N	PRESENT	0
543700	543619	19701S	PARTICIPANT	\N	PRESENT	0
543701	543619	20048C	PARTICIPANT	\N	PRESENT	0
543702	543619	19565D	PARTICIPANT	\N	PRESENT	0
543703	543619	01058X	PARTICIPANT	\N	PRESENT	0
543704	543619	20070A	PARTICIPANT	\N	PRESENT	0
543705	543619	20100N	PARTICIPANT	\N	PRESENT	0
543706	543619	19760E	PARTICIPANT	\N	PRESENT	0
543708	543619	14073Q	PARTICIPANT	\N	PRESENT	0
543709	543619	14026U	PARTICIPANT	\N	PRESENT	0
543710	543619	20024T	PARTICIPANT	\N	PRESENT	0
543711	543619	19553Y	PARTICIPANT	\N	PRESENT	0
543712	543619	11012A	PARTICIPANT	\N	PRESENT	0
543713	543619	14213J	PARTICIPANT	\N	PRESENT	0
543714	543619	11097X	PARTICIPANT	\N	PRESENT	0
543715	543619	14237S	PARTICIPANT	\N	PRESENT	0
543716	543619	01028R	PARTICIPANT	\N	PRESENT	0
543717	543619	20052X	PARTICIPANT	\N	PRESENT	0
543718	543619	19507S	PARTICIPANT	\N	PRESENT	0
543719	543619	18083K	PARTICIPANT	\N	PRESENT	0
543720	543619	19383Y	PARTICIPANT	\N	PRESENT	0
544110	542816	97011G	PARTICIPANT	\N	PRESENT	0
544111	542816	19319Q	PARTICIPANT	\N	PRESENT	1
546080	543955	19631V	PARTICIPANT	\N	PRESENT	1
546082	543955	08028W	PARTICIPANT	\N	PRESENT	1
543682	543619	19719D	PARTICIPANT	\N	PRESENT	0
543683	543619	14331P	PARTICIPANT	\N	PRESENT	0
551876	551283	11048N	PARTICIPANT	\N	PRESENT	0
551877	551283	19479G	PARTICIPANT	\N	PRESENT	0
551878	551283	19711U	PARTICIPANT	\N	PRESENT	0
551879	551283	19531S	PARTICIPANT	\N	PRESENT	0
551880	551283	19687N	PARTICIPANT	\N	PRESENT	0
551881	551283	01057W	PARTICIPANT	\N	PRESENT	0
551882	551283	19689Q	PARTICIPANT	\N	PRESENT	0
551883	551283	20080C	PARTICIPANT	\N	PRESENT	0
551884	551283	14225N	PRESIDENT	0	PRESENT	0
551885	551283	14083S	PARTICIPANT	\N	PRESENT	0
551886	551283	11012A	PARTICIPANT	\N	PRESENT	0
551887	551283	20070A	PARTICIPANT	\N	PRESENT	0
551888	551283	08010L	PARTICIPANT	\N	PRESENT	0
551889	551283	99004R	PARTICIPANT	\N	PRESENT	0
551890	551283	19762G	PARTICIPANT	\N	PRESENT	0
551891	551283	14327T	PARTICIPANT	\N	EXCUSE	0
551892	551283	07029T	PARTICIPANT	\N	EXCUSE	0
551893	551283	14189C	PARTICIPANT	\N	EXCUSE	0
551894	551283	20116W	PARTICIPANT	\N	EXCUSE	0
551895	551283	19671E	PARTICIPANT	\N	EXCUSE	0
551896	551283	20022R	PARTICIPANT	\N	EXCUSE	0
551897	551448	20090E	PARTICIPANT	\N	PRESENT	0
551899	551448	20054A	PARTICIPANT	\N	PRESENT	0
551900	551448	19441R	PARTICIPANT	\N	PRESENT	0
551901	551448	20144B	PARTICIPANT	\N	PRESENT	0
551902	551448	14257W	PARTICIPANT	\N	PRESENT	0
551903	551448	08061X	PARTICIPANT	\N	PRESENT	0
551904	551448	20120S	PARTICIPANT	\N	PRESENT	0
551905	551448	20076G	PARTICIPANT	\N	PRESENT	0
551906	551448	20044X	PARTICIPANT	\N	PRESENT	0
551907	551448	19443T	PARTICIPANT	\N	PRESENT	0
551908	551448	14357A	PARTICIPANT	\N	PRESENT	0
551909	551448	08028W	PARTICIPANT	\N	PRESENT	0
551910	551448	20032T	PARTICIPANT	\N	PRESENT	0
551911	551448	19563B	PARTICIPANT	\N	PRESENT	0
551915	551448	19713W	PARTICIPANT	\N	PRESENT	0
551917	551448	19745F	PARTICIPANT	\N	PRESENT	0
551918	551448	19782L	PARTICIPANT	\N	PRESENT	0
551919	551448	14033T	PARTICIPANT	\N	PRESENT	0
551921	551283	11053K	PARTICIPANT	\N	PRESENT	0
551923	551448	14105F	PARTICIPANT	\N	PRESENT	0
551924	551448	14205J	PARTICIPANT	\N	PRESENT	0
551926	551448	01024M	PARTICIPANT	\N	PRESENT	0
551928	551283	08034U	PARTICIPANT	\N	PRESENT	0
551929	551283	19669L	PARTICIPANT	\N	PRESENT	0
551930	551283	19421M	PARTICIPANT	\N	PRESENT	0
551931	551448	11110B	PARTICIPANT	\N	PRESENT	0
551932	551448	19583F	PARTICIPANT	\N	PRESENT	0
551933	551448	14031R	PARTICIPANT	\N	PRESENT	0
551946	551448	14042U	PARTICIPANT	\N	PRESENT	0
551947	551448	14219Q	PARTICIPANT	\N	PRESENT	0
551948	551448	20048C	PARTICIPANT	\N	PRESENT	0
551949	551448	14147R	PARTICIPANT	\N	PRESENT	0
551950	551448	20020P	PARTICIPANT	\N	PRESENT	0
551951	551448	19747H	PARTICIPANT	\N	PRESENT	0
551952	551448	14211G	PARTICIPANT	\N	PRESENT	0
551953	551448	14038Y	PARTICIPANT	\N	PRESENT	0
551954	551448	19383Y	PARTICIPANT	\N	PRESENT	0
551957	551955	04070G	PARTICIPANT	\N	PRESENT	1
551958	551955	19699S	PARTICIPANT	\N	PRESENT	0
551959	551955	19533U	PARTICIPANT	\N	PRESENT	1
551960	551955	14229S	PARTICIPANT	\N	PRESENT	0
551961	551955	08017T	PARTICIPANT	\N	PRESENT	1
551962	551955	92040Q	PARTICIPANT	\N	PRESENT	0
551963	551955	20112S	PARTICIPANT	\N	PRESENT	1
551964	551955	20026V	PARTICIPANT	\N	PRESENT	0
551965	551955	19593H	PARTICIPANT	\N	PRESENT	0
551966	551955	19527W	PARTICIPANT	\N	PRESENT	1
551967	551955	20132W	PARTICIPANT	\N	PRESENT	0
551968	551955	19643A	PARTICIPANT	\N	PRESENT	1
551969	551955	20134Y	PARTICIPANT	\N	PRESENT	1
551970	551955	19651A	PARTICIPANT	\N	PRESENT	1
551971	551955	19611R	PRESIDENT	0	PRESENT	0
551972	551955	20138D	PARTICIPANT	\N	PRESENT	0
551973	551955	20142Y	PARTICIPANT	\N	PRESENT	0
551974	551955	19693L	PARTICIPANT	\N	PRESENT	0
551975	551955	19399H	PARTICIPANT	\N	PRESENT	0
551976	551955	14030Q	PARTICIPANT	\N	PRESENT	0
551977	551955	20056C	PARTICIPANT	\N	PRESENT	0
551978	551955	20180F	PARTICIPANT	\N	PRESENT	1
551979	551955	04059M	PARTICIPANT	\N	PRESENT	0
551980	551955	19735D	PARTICIPANT	\N	PRESENT	0
551989	551448	19369B	PARTICIPANT	\N	PRESENT	0
551982	551955	14109K	PARTICIPANT	\N	PRESENT	0
551983	551955	14123H	PARTICIPANT	\N	PRESENT	1
551984	551955	17589D	PARTICIPANT	\N	PRESENT	1
551985	551955	19621T	PARTICIPANT	\N	PRESENT	0
551986	551955	20084G	PARTICIPANT	\N	PRESENT	0
551995	551448	19533U	PARTICIPANT	\N	PRESENT	0
551990	551448	20080C	PARTICIPANT	\N	PRESENT	0
551991	551955	11083R	PARTICIPANT	\N	PRESENT	0
551992	551448	20126Y	PARTICIPANT	\N	PRESENT	0
551993	551448	19479G	PARTICIPANT	\N	PRESENT	0
551996	551448	19711U	PARTICIPANT	\N	PRESENT	0
551997	551448	01057W	PARTICIPANT	\N	PRESENT	0
552004	551448	20096L	PARTICIPANT	\N	PRESENT	0
552005	551448	11043H	PARTICIPANT	\N	PRESENT	0
552055	551449	20144B	PARTICIPANT	\N	PRESENT	0
552056	551449	20096L	PARTICIPANT	\N	PRESENT	0
552057	551449	19711U	PARTICIPANT	\N	PRESENT	0
552058	551449	20092G	PARTICIPANT	\N	PRESENT	0
552060	551449	14257W	PARTICIPANT	\N	PRESENT	0
552061	551449	19413M	PARTICIPANT	\N	PRESENT	0
552062	551449	20080C	PARTICIPANT	\N	PRESENT	0
552063	551449	11110B	PARTICIPANT	\N	PRESENT	0
552064	551449	19695N	PARTICIPANT	\N	PRESENT	0
552065	551449	19565D	PARTICIPANT	\N	PRESENT	0
552066	551449	20102Q	PARTICIPANT	\N	PRESENT	0
552067	551449	14111D	PARTICIPANT	\N	PRESENT	0
552068	551449	19745F	PARTICIPANT	\N	PRESENT	0
552069	551449	14073Q	PARTICIPANT	\N	PRESENT	0
552070	551449	16685X	PARTICIPANT	\N	PRESENT	0
552071	551449	19369B	PARTICIPANT	\N	PRESENT	0
552072	551449	11090Q	PARTICIPANT	\N	PRESENT	0
552073	551449	19713W	PARTICIPANT	\N	PRESENT	0
552074	551449	01024M	PARTICIPANT	\N	PRESENT	0
552075	551449	19782L	PARTICIPANT	\N	PRESENT	0
552076	551449	19333N	PARTICIPANT	\N	PRESENT	0
552077	551449	19549D	PARTICIPANT	\N	PRESENT	0
552078	551449	20062A	PARTICIPANT	\N	PRESENT	0
552079	551543	20050V	PARTICIPANT	\N	PRESENT	0
552080	551449	20090E	PARTICIPANT	\N	PRESENT	0
552081	551449	20120S	PARTICIPANT	\N	PRESENT	0
552082	551449	19533U	PARTICIPANT	\N	PRESENT	0
552083	551449	20022R	PARTICIPANT	\N	PRESENT	0
552084	551449	11043H	PARTICIPANT	\N	PRESENT	0
552085	551449	01057W	PARTICIPANT	\N	PRESENT	0
552086	551449	20032T	PARTICIPANT	\N	PRESENT	0
552087	551449	01048V	PARTICIPANT	\N	PRESENT	0
552088	551449	19563B	PARTICIPANT	\N	PRESENT	0
552089	551449	19619A	PARTICIPANT	\N	PRESENT	0
552090	551449	19685L	PARTICIPANT	\N	PRESENT	0
552091	551449	19251M	PARTICIPANT	\N	PRESENT	0
552092	551449	14207L	PARTICIPANT	\N	PRESENT	0
552093	551449	14038Y	PARTICIPANT	\N	PRESENT	0
552094	551449	20044X	PARTICIPANT	\N	PRESENT	0
552095	551449	20076G	PARTICIPANT	\N	PRESENT	0
552096	551449	19479G	PARTICIPANT	\N	PRESENT	0
552098	551449	19503N	PARTICIPANT	\N	PRESENT	0
552099	551449	19723Y	PARTICIPANT	\N	PRESENT	0
552100	551449	17023S	PARTICIPANT	\N	PRESENT	0
552116	551449	20126Y	PARTICIPANT	\N	PRESENT	0
552102	551449	14169X	PARTICIPANT	\N	PRESENT	0
552052	551449	11045K	PARTICIPANT	\N	PRESENT	0
552054	551449	14033T	PARTICIPANT	\N	PRESENT	0
552103	551449	19467C	PARTICIPANT	\N	PRESENT	0
552104	551449	19954N	PARTICIPANT	\N	PRESENT	0
552105	551449	20140W	PARTICIPANT	\N	PRESENT	0
552106	551449	20034V	PARTICIPANT	\N	PRESENT	0
552108	551449	11103C	PARTICIPANT	\N	PRESENT	0
552109	551449	20026V	PARTICIPANT	\N	PRESENT	0
552110	551449	18083K	PARTICIPANT	\N	PRESENT	0
552114	551449	19739H	PARTICIPANT	\N	PRESENT	0
552115	551449	20054A	PARTICIPANT	\N	PRESENT	0
552117	551449	14021P	PARTICIPANT	\N	PRESENT	0
543123	543088	19611R	PARTICIPANT	\N	PRESENT	0
543124	543088	19643A	PARTICIPANT	\N	PRESENT	1
543125	543088	19721W	PARTICIPANT	\N	PRESENT	1
543126	543088	20180F	PARTICIPANT	\N	PRESENT	1
543127	543088	19735D	PARTICIPANT	\N	PRESENT	1
543128	543088	20132W	PARTICIPANT	\N	PRESENT	1
543129	543088	19693L	PARTICIPANT	\N	PRESENT	1
543130	543088	20142Y	PARTICIPANT	\N	PRESENT	1
543131	543089	19643A	PARTICIPANT	\N	PRESENT	1
543136	543089	20180F	PARTICIPANT	\N	PRESENT	1
543133	543089	19721W	PARTICIPANT	\N	PRESENT	1
543134	543089	19693L	PARTICIPANT	\N	PRESENT	1
543135	543089	20132W	PARTICIPANT	\N	PRESENT	1
543137	543089	19735D	PARTICIPANT	\N	PRESENT	1
543138	543089	20142Y	PARTICIPANT	\N	PRESENT	1
543139	543089	19593H	PARTICIPANT	\N	PRESENT	0
543140	543089	19611R	PARTICIPANT	\N	PRESENT	0
543141	543090	19643A	PARTICIPANT	\N	PRESENT	1
543142	543090	19693L	PARTICIPANT	\N	PRESENT	0
543143	543090	19611R	PARTICIPANT	\N	PRESENT	0
543144	543090	19735D	PARTICIPANT	\N	PRESENT	1
543145	543090	20142Y	PARTICIPANT	\N	PRESENT	1
543146	543090	19593H	PARTICIPANT	\N	PRESENT	0
543147	543093	19643A	PARTICIPANT	\N	PRESENT	1
543148	543093	19693L	PARTICIPANT	\N	PRESENT	0
543149	543093	19611R	PARTICIPANT	\N	PRESENT	0
543150	543093	19593H	PARTICIPANT	\N	PRESENT	0
543151	543093	20142Y	PARTICIPANT	\N	PRESENT	1
544256	542930	20124W	PARTICIPANT	\N	PRESENT	0
544257	542930	17229F	PARTICIPANT	\N	PRESENT	0
544258	542930	01024M	PARTICIPANT	\N	PRESENT	0
544259	542930	05008E	PARTICIPANT	\N	PRESENT	0
544260	542930	11085T	PARTICIPANT	\N	PRESENT	0
544261	542930	14073Q	PARTICIPANT	\N	PRESENT	0
544262	542930	20110Q	PARTICIPANT	\N	PRESENT	0
544263	542930	20144B	PARTICIPANT	\N	PRESENT	0
544264	542930	05012A	PARTICIPANT	\N	PRESENT	0
544265	542930	14042U	PARTICIPANT	\N	PRESENT	0
544266	542930	14083S	PARTICIPANT	\N	PRESENT	0
544267	542930	14071N	PARTICIPANT	\N	PRESENT	0
544268	542930	14215L	PARTICIPANT	\N	PRESENT	0
544269	542930	19826F	PARTICIPANT	\N	PRESENT	0
544270	542930	14217N	PARTICIPANT	\N	PRESENT	0
544271	542930	01043Q	PARTICIPANT	\N	PRESENT	0
544272	542930	04042C	PARTICIPANT	\N	PRESENT	0
544273	542930	14327T	PARTICIPANT	\N	PRESENT	0
544274	542930	19367Y	PARTICIPANT	\N	PRESENT	0
544275	542930	20086J	PARTICIPANT	\N	PRESENT	0
544276	542930	19621T	PARTICIPANT	\N	PRESENT	0
544277	542930	20152B	PARTICIPANT	\N	PRESENT	0
544278	542930	14331P	PARTICIPANT	\N	PRESENT	0
544279	542930	19798U	PARTICIPANT	\N	PRESENT	0
544280	542930	19669L	PARTICIPANT	\N	PRESENT	0
544281	542930	10006L	PARTICIPANT	\N	PRESENT	0
544282	542930	20120S	PARTICIPANT	\N	PRESENT	0
544283	542930	14133K	PARTICIPANT	\N	PRESENT	0
544284	542930	19415P	PARTICIPANT	\N	PRESENT	0
544328	542930	19591F	PARTICIPANT	\N	PRESENT	0
544334	542930	11053K	PARTICIPANT	\N	PRESENT	0
544287	542930	11101A	PARTICIPANT	\N	PRESENT	0
544288	542930	17637T	PARTICIPANT	\N	PRESENT	0
544289	542930	14357A	PARTICIPANT	\N	PRESENT	0
544290	542930	20104S	PARTICIPANT	\N	PRESENT	0
544332	542930	14221J	PARTICIPANT	\N	PRESENT	0
544292	542930	20108W	PARTICIPANT	\N	PRESENT	0
544293	542930	20024T	PARTICIPANT	\N	PRESENT	0
544294	542930	97011G	PARTICIPANT	\N	PRESENT	0
544295	542930	19762G	PARTICIPANT	\N	PRESENT	0
544296	542930	20140W	PARTICIPANT	\N	PRESENT	0
544297	542930	08034U	PARTICIPANT	\N	PRESENT	0
544298	542930	20062A	PARTICIPANT	\N	PRESENT	0
544299	542930	08047A	PARTICIPANT	\N	PRESENT	0
544300	542930	20044X	PARTICIPANT	\N	PRESENT	0
544301	542930	14169X	PARTICIPANT	\N	PRESENT	0
544302	542930	14069U	PARTICIPANT	\N	PRESENT	0
544303	542930	11090Q	PARTICIPANT	\N	PRESENT	0
544304	542930	20026V	PARTICIPANT	\N	PRESENT	0
544305	542930	19581D	PARTICIPANT	\N	PRESENT	0
544306	542930	04047H	PARTICIPANT	\N	PRESENT	0
544307	542930	20034V	PARTICIPANT	\N	PRESENT	0
544308	542930	11097X	PARTICIPANT	\N	PRESENT	0
544309	542930	14059S	PARTICIPANT	\N	PRESENT	0
544310	542930	20054A	PARTICIPANT	\N	PRESENT	0
544322	542930	08010L	PARTICIPANT	\N	PRESENT	0
544312	542930	20090E	PARTICIPANT	\N	PRESENT	0
544313	542930	11103C	PARTICIPANT	\N	PRESENT	0
544314	542930	14105F	PARTICIPANT	\N	PRESENT	0
544315	542930	14147R	PARTICIPANT	\N	PRESENT	0
544316	542930	14219Q	PARTICIPANT	\N	PRESENT	0
544317	542930	14205J	PARTICIPANT	\N	PRESENT	0
544318	542930	14329V	PARTICIPANT	\N	PRESENT	0
544319	542930	08056B	PARTICIPANT	\N	PRESENT	0
544325	542930	14225N	PARTICIPANT	\N	PRESENT	0
544323	542930	19383Y	PARTICIPANT	\N	PRESENT	0
544324	542930	14089Y	PARTICIPANT	\N	PRESENT	0
544326	542930	01025N	PARTICIPANT	\N	PRESENT	0
544327	542930	20050V	PARTICIPANT	\N	PRESENT	0
544329	542930	19685L	PARTICIPANT	\N	PRESENT	0
544330	542930	16685X	PARTICIPANT	\N	PRESENT	0
544331	542930	20138D	PARTICIPANT	\N	PRESENT	0
544333	542930	20028X	PARTICIPANT	\N	PRESENT	0
544335	542930	19531S	PARTICIPANT	\N	PRESENT	0
544336	542930	19479G	PARTICIPANT	\N	PRESENT	0
544347	542930	19679N	PARTICIPANT	\N	PRESENT	0
544344	542930	14179A	PARTICIPANT	\N	PRESENT	0
544342	542930	08069G	PARTICIPANT	\N	PRESENT	0
544343	542930	17023S	PARTICIPANT	\N	PRESENT	0
544345	542930	14033T	PARTICIPANT	\N	PRESENT	0
544346	542930	14031R	PARTICIPANT	\N	PRESENT	0
544348	542930	20048C	PARTICIPANT	\N	PRESENT	0
544349	542930	14213J	PARTICIPANT	\N	PRESENT	0
544547	542934	86034E	PARTICIPANT	\N	PRESENT	0
544548	542934	08017T	PARTICIPANT	\N	PRESENT	0
544549	542934	19715Y	PARTICIPANT	\N	PRESENT	0
544550	542934	18193Q	PARTICIPANT	\N	PRESENT	0
544551	542934	19349W	PARTICIPANT	\N	PRESENT	0
544552	542934	19651A	PARTICIPANT	\N	PRESENT	0
544553	542934	19866P	PARTICIPANT	\N	PRESENT	0
544554	542934	14107H	PARTICIPANT	\N	PRESENT	0
544555	542934	20072C	PARTICIPANT	\N	PRESENT	0
544556	542934	11012A	PARTICIPANT	\N	PRESENT	0
544557	542934	19441R	PARTICIPANT	\N	PRESENT	0
544558	542934	11053K	PARTICIPANT	\N	PRESENT	0
544559	542934	20066E	PARTICIPANT	\N	PRESENT	0
544560	542934	14042U	PARTICIPANT	\N	PRESENT	0
544561	542934	20042V	PARTICIPANT	\N	PRESENT	0
544562	542934	19479G	PARTICIPANT	\N	PRESENT	0
544563	542934	01024M	PARTICIPANT	\N	PRESENT	0
544564	542934	19747H	PARTICIPANT	\N	PRESENT	0
544565	542934	11097X	PARTICIPANT	\N	PRESENT	0
544566	542934	20116W	PARTICIPANT	\N	PRESENT	0
544567	542934	19647E	PARTICIPANT	\N	PRESENT	0
544568	542934	19689Q	PARTICIPANT	\N	PRESENT	0
544569	542934	14026U	PARTICIPANT	\N	PRESENT	0
544570	542934	99004R	PARTICIPANT	\N	PRESENT	0
544571	542934	19711U	PARTICIPANT	\N	PRESENT	0
544572	542934	20062A	PARTICIPANT	\N	PRESENT	0
544573	542934	20090E	PARTICIPANT	\N	PRESENT	0
544574	542934	97011G	PARTICIPANT	\N	PRESENT	0
544575	542934	01058X	PARTICIPANT	\N	PRESENT	0
544576	542934	19399H	PARTICIPANT	\N	PRESENT	0
544577	542934	19741B	PARTICIPANT	\N	PRESENT	0
544578	542934	20086J	PARTICIPANT	\N	PRESENT	0
544579	542934	19687N	PARTICIPANT	\N	PRESENT	0
544580	542934	19695N	PARTICIPANT	\N	PRESENT	0
544581	542934	14021P	PARTICIPANT	\N	PRESENT	0
544582	542934	11074Q	PARTICIPANT	\N	PRESENT	0
544583	542934	01057W	PARTICIPANT	\N	PRESENT	0
544584	542934	19515S	PARTICIPANT	\N	PRESENT	0
544585	542934	19667J	PARTICIPANT	\N	PRESENT	0
544586	542934	10006L	PARTICIPANT	\N	PRESENT	0
544587	542934	14225N	PARTICIPANT	\N	PRESENT	0
544588	542934	01034P	PARTICIPANT	\N	PRESENT	0
544589	542934	11048N	PARTICIPANT	\N	PRESENT	0
544590	542934	08056B	PARTICIPANT	\N	PRESENT	0
544591	542934	11040E	PARTICIPANT	\N	PRESENT	0
544592	542934	20050V	PARTICIPANT	\N	PRESENT	0
544593	542934	20022R	PARTICIPANT	\N	PRESENT	0
544594	542934	14083S	PARTICIPANT	\N	PRESENT	0
544595	542934	01048V	PARTICIPANT	\N	PRESENT	0
544596	542934	14038Y	PARTICIPANT	\N	PRESENT	0
562348	559720	19715Y	PARTICIPANT	\N	PRESENT	1
562761	558019	14071N	PARTICIPANT	\N	EXCUSE	0
562762	558019	04086Q	PARTICIPANT	\N	EXCUSE	0
562769	558019	19735D	PARTICIPANT	\N	EXCUSE	0
563165	562202	19531S	PARTICIPANT	\N	PRESENT	0
563166	562202	08018U	PARTICIPANT	\N	PRESENT	0
563167	562202	20038A	PARTICIPANT	\N	PRESENT	0
563168	562202	20180F	PARTICIPANT	\N	PRESENT	0
563169	562202	14219Q	PARTICIPANT	\N	PRESENT	0
563170	562202	19399H	PARTICIPANT	\N	PRESENT	0
563171	562202	20050V	PARTICIPANT	\N	PRESENT	0
563172	562202	19507S	PARTICIPANT	\N	PRESENT	0
563173	562202	14251Q	PARTICIPANT	\N	PRESENT	0
563174	562202	20094J	PARTICIPANT	\N	PRESENT	0
563175	562202	07029T	PARTICIPANT	\N	PRESENT	0
563176	562202	08015R	PARTICIPANT	\N	PRESENT	0
563177	562202	20132W	PARTICIPANT	\N	PRESENT	0
563178	562202	20068G	PARTICIPANT	\N	PRESENT	0
563179	562202	19611R	PARTICIPANT	\N	PRESENT	0
563180	562202	19679N	PARTICIPANT	\N	PRESENT	0
563181	562202	14205J	PARTICIPANT	\N	PRESENT	0
563182	562202	19739H	PARTICIPANT	\N	PRESENT	0
563183	562202	17367Q	PARTICIPANT	\N	PRESENT	0
563184	562202	19441R	PARTICIPANT	\N	PRESENT	0
563185	562202	10015M	PARTICIPANT	\N	PRESENT	0
563186	562202	11070L	PARTICIPANT	\N	PRESENT	0
563187	562202	17737W	PARTICIPANT	\N	PRESENT	0
563188	562202	16685X	PARTICIPANT	\N	PRESENT	0
563189	562202	11053K	PARTICIPANT	\N	PRESENT	0
563190	562202	14083S	PARTICIPANT	\N	PRESENT	0
563191	562202	19369B	PARTICIPANT	\N	PRESENT	0
563192	562202	19826F	PARTICIPANT	\N	PRESENT	0
563193	562202	01025N	PARTICIPANT	\N	PRESENT	0
563194	562202	20062A	PARTICIPANT	\N	PRESENT	0
563195	562202	01024M	PARTICIPANT	\N	PRESENT	0
563196	562202	14059S	PARTICIPANT	\N	PRESENT	0
563197	562202	20040T	PARTICIPANT	\N	PRESENT	0
563198	562202	14329V	PARTICIPANT	\N	PRESENT	0
563199	562202	14357A	PARTICIPANT	\N	PRESENT	0
563200	562202	20172F	PARTICIPANT	\N	PRESENT	0
563201	562202	11077T	PARTICIPANT	\N	PRESENT	0
563202	562202	20126Y	PARTICIPANT	\N	PRESENT	0
563203	562202	20124W	PARTICIPANT	\N	PRESENT	0
563204	562202	19758L	PARTICIPANT	\N	PRESENT	0
563205	562202	19621T	PARTICIPANT	\N	PRESENT	0
563206	562202	11031D	PARTICIPANT	\N	PRESENT	0
563207	562202	19367Y	PARTICIPANT	\N	PRESENT	0
563208	562202	19533U	PARTICIPANT	\N	PRESENT	0
563209	562202	14055N	PARTICIPANT	\N	PRESENT	0
563210	562202	19421M	PARTICIPANT	\N	PRESENT	0
563211	562202	19685L	PARTICIPANT	\N	PRESENT	0
563212	562202	11097X	PARTICIPANT	\N	PRESENT	0
563213	562202	19415P	PARTICIPANT	\N	PRESENT	0
563214	562202	19747H	PARTICIPANT	\N	PRESENT	0
563215	562202	14193X	PARTICIPANT	\N	PRESENT	0
563216	562202	14179A	PARTICIPANT	\N	PRESENT	0
563217	562202	08047A	PARTICIPANT	\N	PRESENT	0
563245	562202	20048C	PARTICIPANT	\N	PRESENT	0
563219	562202	20136B	PARTICIPANT	\N	PRESENT	0
563220	562202	20054A	PARTICIPANT	\N	PRESENT	0
563223	562202	11048N	PARTICIPANT	\N	PRESENT	0
563224	562202	86034E	PARTICIPANT	\N	PRESENT	0
563225	562202	14217N	PARTICIPANT	\N	PRESENT	0
563226	562202	19383Y	PARTICIPANT	\N	PRESENT	0
563227	562202	20104S	PARTICIPANT	\N	PRESENT	0
563228	562202	20084G	PARTICIPANT	\N	PRESENT	0
563231	562202	19711U	PARTICIPANT	\N	PRESENT	0
563241	562202	14053L	PARTICIPANT	\N	PRESENT	0
563243	562202	20036X	PARTICIPANT	\N	PRESENT	0
563244	562202	14213J	PARTICIPANT	\N	PRESENT	0
563246	562202	01043Q	PARTICIPANT	\N	PRESENT	0
563247	562202	17023S	PARTICIPANT	\N	PRESENT	0
563248	562202	14042U	PARTICIPANT	\N	PRESENT	0
563249	562202	14189C	PARTICIPANT	\N	PRESENT	0
563250	562202	20052X	PARTICIPANT	\N	PRESENT	0
563255	562202	19701S	PARTICIPANT	\N	PRESENT	0
563256	562202	20118Y	PARTICIPANT	\N	PRESENT	0
563257	562202	20130U	PARTICIPANT	\N	PRESENT	0
563258	562202	01057W	PARTICIPANT	\N	PRESENT	0
563259	562202	19585H	PARTICIPANT	\N	PRESENT	0
563279	562202	20150Y	PARTICIPANT	\N	PRESENT	0
563480	562203	01043Q	PARTICIPANT	\N	PRESENT	0
563481	562203	20150Y	PARTICIPANT	\N	PRESENT	0
563482	562203	01025N	PARTICIPANT	\N	PRESENT	0
563483	562203	20036X	PARTICIPANT	\N	PRESENT	0
563484	562203	11040E	PARTICIPANT	\N	PRESENT	0
563485	562203	20080C	PARTICIPANT	\N	PRESENT	0
563486	562203	20130U	PARTICIPANT	\N	PRESENT	0
563487	562203	20174H	PARTICIPANT	\N	PRESENT	0
563488	562203	19713W	PARTICIPANT	\N	PRESENT	0
563489	562203	19479G	PARTICIPANT	\N	PRESENT	0
563490	562203	19691J	PARTICIPANT	\N	PRESENT	0
563491	562203	14189C	PARTICIPANT	\N	PRESENT	0
563492	562203	01024M	PARTICIPANT	\N	PRESENT	0
563493	562203	11033F	PARTICIPANT	\N	PRESENT	0
563494	562203	14225N	PARTICIPANT	\N	PRESENT	0
563495	562203	11099A	PARTICIPANT	\N	PRESENT	0
563496	562203	20092G	PARTICIPANT	\N	PRESENT	0
563497	562203	19689Q	PARTICIPANT	\N	PRESENT	0
563498	562203	01057W	PARTICIPANT	\N	PRESENT	0
563499	562203	14059S	PARTICIPANT	\N	PRESENT	0
563500	562203	19711U	PARTICIPANT	\N	PRESENT	0
563501	562203	20082E	PARTICIPANT	\N	PRESENT	0
563502	562203	07029T	PARTICIPANT	\N	PRESENT	0
563503	562203	19507S	PARTICIPANT	\N	PRESENT	0
563504	562203	19467C	PARTICIPANT	\N	PRESENT	0
563505	562203	19745F	PARTICIPANT	\N	PRESENT	0
563506	562203	19747H	PARTICIPANT	\N	PRESENT	0
563507	562203	20116W	PARTICIPANT	\N	PRESENT	0
563508	562203	14357A	PARTICIPANT	\N	PRESENT	0
563509	562203	20022R	PARTICIPANT	\N	PRESENT	0
563510	562203	19647E	PARTICIPANT	\N	PRESENT	0
563511	562203	14257W	PARTICIPANT	\N	PRESENT	0
563512	562203	20142Y	PARTICIPANT	\N	PRESENT	0
563513	562203	97011G	PARTICIPANT	\N	PRESENT	0
563514	562203	19599P	PARTICIPANT	\N	PRESENT	0
563515	562203	19347U	PARTICIPANT	\N	PRESENT	0
563516	562203	20110Q	PARTICIPANT	\N	PRESENT	0
563517	562203	19549D	PARTICIPANT	\N	PRESENT	0
563518	562203	20044X	PARTICIPANT	\N	PRESENT	0
563519	562203	14207L	PARTICIPANT	\N	PRESENT	0
563520	562203	20052X	PARTICIPANT	\N	PRESENT	0
563521	562203	18083K	PARTICIPANT	\N	PRESENT	0
563523	562203	20126Y	PARTICIPANT	\N	PRESENT	0
563524	562203	19629C	PARTICIPANT	\N	PRESENT	0
563525	562203	20054A	PARTICIPANT	\N	PRESENT	0
563526	562203	14038Y	PARTICIPANT	\N	PRESENT	0
563527	562203	11048N	PARTICIPANT	\N	PRESENT	0
563528	562203	19631V	PARTICIPANT	\N	PRESENT	0
563529	562203	20172F	PARTICIPANT	\N	PRESENT	0
563530	561980	19954N	PARTICIPANT	\N	PRESENT	0
563531	561980	95063L	PARTICIPANT	\N	PRESENT	0
563532	561980	20108W	PARTICIPANT	\N	PRESENT	0
563533	561980	11026G	PARTICIPANT	\N	PRESENT	0
563534	561980	14215L	PARTICIPANT	\N	PRESENT	0
563535	561980	19585H	PARTICIPANT	\N	PRESENT	0
563536	561980	04047H	PRESIDENT	0	PRESENT	0
563537	561980	19673G	PARTICIPANT	\N	PRESENT	0
563538	561980	19447X	PARTICIPANT	\N	PRESENT	0
563539	561980	14231L	PARTICIPANT	\N	PRESENT	0
563540	562203	19695N	PARTICIPANT	\N	PRESENT	0
563541	561980	05008E	PARTICIPANT	\N	PRESENT	0
563549	562203	20050V	PARTICIPANT	\N	PRESENT	0
563550	562203	14083S	PARTICIPANT	\N	PRESENT	0
563551	562203	20100N	PARTICIPANT	\N	PRESENT	0
563560	562203	19563B	PARTICIPANT	\N	PRESENT	0
563561	562203	19667J	PARTICIPANT	\N	PRESENT	0
563565	561980	14147R	PARTICIPANT	\N	PRESENT	0
563566	562203	08010L	PARTICIPANT	\N	PRESENT	0
563567	562203	19333N	PARTICIPANT	\N	PRESENT	0
563568	562203	14329V	PARTICIPANT	\N	PRESENT	0
563569	562203	14217N	PARTICIPANT	\N	PRESENT	0
542351	542314	19749K	PARTICIPANT	\N	PRESENT	0
542352	542314	19673G	PARTICIPANT	\N	PRESENT	0
542353	542314	20108W	PARTICIPANT	\N	PRESENT	0
542354	542314	19447X	PARTICIPANT	\N	PRESENT	0
542355	542314	10015M	PARTICIPANT	\N	PRESENT	0
542356	542314	19543W	PARTICIPANT	\N	PRESENT	0
542357	542314	04047H	PRESIDENT	0	PRESENT	0
542358	542314	11072N	PARTICIPANT	\N	PRESENT	0
542359	542314	05008E	PARTICIPANT	\N	PRESENT	0
542360	542314	01028R	PARTICIPANT	\N	PRESENT	0
542361	542314	11033F	PARTICIPANT	\N	PRESENT	0
542368	542314	14215L	PARTICIPANT	\N	PRESENT	0
542395	539553	19719D	PARTICIPANT	\N	PRESENT	0
542398	539553	04008A	PARTICIPANT	\N	PRESENT	0
542399	539553	04047H	PARTICIPANT	\N	PRESENT	0
542400	539553	14021P	PARTICIPANT	\N	PRESENT	0
542401	539553	14151M	PARTICIPANT	\N	PRESENT	0
542403	539553	19333N	PARTICIPANT	\N	PRESENT	0
542404	539553	19413M	PARTICIPANT	\N	PRESENT	0
542405	539553	14211G	PARTICIPANT	\N	PRESENT	0
542406	539553	14229S	PARTICIPANT	\N	PRESENT	0
542408	539553	11056N	PARTICIPANT	\N	PRESENT	0
542409	539553	18083K	PARTICIPANT	\N	PRESENT	0
542410	539553	20110Q	PARTICIPANT	\N	PRESENT	0
542411	539553	19585H	PARTICIPANT	\N	PRESENT	0
542412	539553	20042V	PARTICIPANT	\N	PRESENT	0
542413	539553	19729F	PARTICIPANT	\N	PRESENT	0
542415	539553	14042U	PARTICIPANT	\N	PRESENT	0
542416	539553	14231L	PARTICIPANT	\N	PRESENT	0
542417	539553	19629C	PARTICIPANT	\N	PRESENT	0
542419	539553	08034U	PARTICIPANT	\N	PRESENT	0
542420	539553	19347U	PARTICIPANT	\N	PRESENT	0
542421	539553	14107H	PARTICIPANT	\N	PRESENT	0
542423	539553	95063L	PARTICIPANT	\N	PRESENT	0
542424	539553	11072N	PARTICIPANT	\N	PRESENT	0
542427	539553	19543W	PARTICIPANT	\N	PRESENT	0
542428	539553	14055N	PARTICIPANT	\N	PRESENT	0
542430	539553	14215L	PARTICIPANT	\N	PRESENT	0
542431	539553	17637T	PARTICIPANT	\N	PRESENT	0
542434	539553	20152B	PARTICIPANT	\N	PRESENT	0
542436	539553	14217N	PARTICIPANT	\N	PRESENT	0
542437	539553	14257W	PARTICIPANT	\N	PRESENT	0
542439	539553	20108W	PARTICIPANT	\N	PRESENT	0
542442	539553	20098N	PARTICIPANT	\N	PRESENT	0
542444	539553	20138D	PARTICIPANT	\N	PRESENT	0
542446	539553	20032T	PARTICIPANT	\N	PRESENT	0
542447	539553	19447X	PARTICIPANT	\N	PRESENT	0
542448	539553	17737W	PARTICIPANT	\N	PRESENT	0
542461	539553	19581D	PARTICIPANT	\N	PRESENT	0
542462	539553	14097Y	PARTICIPANT	\N	PRESENT	0
542463	539553	19649G	PARTICIPANT	\N	PRESENT	0
542464	539553	19741B	PARTICIPANT	\N	PRESENT	0
542465	539553	20118Y	PARTICIPANT	\N	PRESENT	0
542466	539553	14225N	PARTICIPANT	\N	PRESENT	0
542467	539553	14071N	PARTICIPANT	\N	PRESENT	0
542468	539553	14259Y	PARTICIPANT	\N	PRESENT	0
542469	539553	11033F	PARTICIPANT	\N	PRESENT	0
542470	539553	19693L	PARTICIPANT	\N	PRESENT	0
542471	539553	04057K	PARTICIPANT	\N	PRESENT	0
542472	539753	20060X	PARTICIPANT	\N	PRESENT	1
542473	539753	20062A	PARTICIPANT	\N	PRESENT	0
542474	539753	20090E	PARTICIPANT	\N	PRESENT	0
542475	539753	11067R	PARTICIPANT	\N	PRESENT	0
542476	539753	20048C	PRESIDENT	0	PRESENT	0
542477	539753	14123H	PARTICIPANT	\N	PRESENT	1
542478	539753	20052X	PARTICIPANT	\N	PRESENT	0
542479	539753	17779H	PARTICIPANT	\N	PRESENT	0
542480	539553	20080C	PARTICIPANT	\N	PRESENT	0
542481	539553	19443T	PARTICIPANT	\N	PRESENT	0
542482	539553	14001X	PARTICIPANT	\N	PRESENT	0
542483	539553	11012A	PARTICIPANT	\N	PRESENT	0
542484	539553	19673G	PARTICIPANT	\N	PRESENT	0
542485	539553	19689Q	PARTICIPANT	\N	PRESENT	0
542486	539553	20070A	PARTICIPANT	\N	PRESENT	0
542487	539553	14187A	PARTICIPANT	\N	PRESENT	0
542488	539553	10015M	PARTICIPANT	\N	PRESENT	0
542489	539553	19467C	PARTICIPANT	\N	PRESENT	0
542490	539553	19667J	PARTICIPANT	\N	PRESENT	0
542491	539553	14069U	PARTICIPANT	\N	PRESENT	0
542492	539553	14089Y	PARTICIPANT	\N	PRESENT	0
542493	539553	19569H	PARTICIPANT	\N	PRESENT	0
542494	539553	04085P	PARTICIPANT	\N	PRESENT	0
542495	539553	20126Y	PARTICIPANT	\N	PRESENT	0
542496	539553	08010L	PARTICIPANT	\N	PRESENT	0
542497	539553	19749K	PARTICIPANT	\N	PRESENT	0
542498	539553	11048N	PARTICIPANT	\N	PRESENT	0
542499	539553	20096L	PARTICIPANT	\N	PRESENT	0
542504	539553	20022R	PARTICIPANT	\N	PRESENT	0
542506	539553	11097X	PARTICIPANT	\N	PRESENT	0
542513	539553	07029T	PARTICIPANT	\N	PRESENT	0
542518	539553	19747H	PARTICIPANT	\N	PRESENT	0
542519	539553	04086Q	PARTICIPANT	\N	PRESENT	0
542520	539553	14083S	PARTICIPANT	\N	PRESENT	0
542521	539553	19647E	PARTICIPANT	\N	PRESENT	0
542522	539553	19697Q	PARTICIPANT	\N	PRESENT	0
542523	539753	20084G	PARTICIPANT	\N	PRESENT	0
542524	539553	14030Q	PARTICIPANT	\N	PRESENT	0
542525	539753	20122U	PARTICIPANT	\N	PRESENT	1
542526	539553	17367Q	PARTICIPANT	\N	PRESENT	0
542528	539553	20064C	PARTICIPANT	\N	PRESENT	0
542534	539553	19762G	PARTICIPANT	\N	PRESENT	0
542535	539553	14213J	PARTICIPANT	\N	PRESENT	0
542536	539553	20134Y	PARTICIPANT	\N	PRESENT	0
542538	539553	20052X	PARTICIPANT	\N	PRESENT	0
542539	539553	14073Q	PARTICIPANT	\N	PRESENT	0
542540	539553	19687N	PARTICIPANT	\N	PRESENT	0
542541	539553	97011G	PARTICIPANT	\N	PRESENT	0
542554	539553	20136B	PARTICIPANT	\N	PRESENT	0
542558	539553	20090E	PARTICIPANT	\N	PRESENT	0
542561	539553	20062A	PARTICIPANT	\N	PRESENT	0
542566	539553	19503N	PARTICIPANT	\N	PRESENT	0
542574	539553	11045K	PARTICIPANT	\N	PRESENT	0
542581	539553	20124W	PARTICIPANT	\N	PRESENT	0
542590	539553	19295A	PARTICIPANT	\N	PRESENT	0
542591	539553	19725B	PARTICIPANT	\N	PRESENT	0
542593	539553	99004R	PARTICIPANT	\N	PRESENT	0
542594	539553	19399H	PARTICIPANT	\N	PRESENT	0
542595	539553	20100N	PARTICIPANT	\N	PRESENT	0
542596	539553	01028R	PARTICIPANT	\N	PRESENT	0
542648	539554	99004R	PARTICIPANT	\N	PRESENT	0
542714	539554	14151M	PARTICIPANT	\N	PRESENT	0
542715	539554	20070A	PARTICIPANT	\N	PRESENT	0
542716	539554	19725B	PARTICIPANT	\N	PRESENT	0
542717	539554	19649G	PARTICIPANT	\N	PRESENT	0
542718	539554	14021P	PARTICIPANT	\N	PRESENT	0
542719	539554	20062A	PARTICIPANT	\N	PRESENT	0
542720	539554	04008A	PARTICIPANT	\N	PRESENT	0
542721	539554	14215L	PARTICIPANT	\N	PRESENT	0
542722	539554	20090E	PARTICIPANT	\N	PRESENT	0
542723	539554	14107H	PARTICIPANT	\N	PRESENT	0
542724	539554	08056B	PARTICIPANT	\N	PRESENT	0
542725	539554	19585H	PARTICIPANT	\N	PRESENT	0
542726	539554	20110Q	PARTICIPANT	\N	PRESENT	0
542727	539554	20108W	PARTICIPANT	\N	PRESENT	0
542728	539554	20134Y	PARTICIPANT	\N	PRESENT	0
542729	539554	11033F	PARTICIPANT	\N	PRESENT	0
542730	539554	14097Y	PARTICIPANT	\N	PRESENT	0
542731	539554	04085P	PARTICIPANT	\N	PRESENT	0
542732	539554	14231L	PARTICIPANT	\N	PRESENT	0
542733	539554	07029T	PARTICIPANT	\N	PRESENT	0
542734	539554	19569H	PARTICIPANT	\N	PRESENT	0
542735	539554	19581D	PARTICIPANT	\N	PRESENT	0
542736	539554	19667J	PARTICIPANT	\N	PRESENT	0
542737	539554	19441R	PARTICIPANT	\N	PRESENT	0
542738	539554	11097X	PARTICIPANT	\N	PRESENT	0
542739	539554	19729F	PARTICIPANT	\N	PRESENT	0
542740	539554	19447X	PARTICIPANT	\N	PRESENT	0
542741	539554	14211G	PARTICIPANT	\N	PRESENT	0
542742	539554	14038Y	PARTICIPANT	\N	PRESENT	0
542743	539554	20094J	PARTICIPANT	\N	PRESENT	0
542744	539554	19741B	PARTICIPANT	\N	PRESENT	0
542745	539554	19689Q	PARTICIPANT	\N	PRESENT	0
542746	539554	01028R	PARTICIPANT	\N	PRESENT	0
542747	539554	19629C	PARTICIPANT	\N	PRESENT	0
542748	539554	19687N	PARTICIPANT	\N	PRESENT	0
542749	539554	14001X	PARTICIPANT	\N	PRESENT	0
542750	539554	20080C	PARTICIPANT	\N	PRESENT	0
542751	539554	14229S	PARTICIPANT	\N	PRESENT	0
542752	539554	05008E	PARTICIPANT	\N	PRESENT	0
542753	539554	14169X	PARTICIPANT	\N	PRESENT	0
542754	539554	14069U	PARTICIPANT	\N	PRESENT	0
552118	551449	19673G	PARTICIPANT	\N	PRESENT	0
552119	551449	14089Y	PARTICIPANT	\N	PRESENT	0
552120	551449	11033F	PARTICIPANT	\N	PRESENT	0
552121	551449	20020P	PARTICIPANT	\N	PRESENT	0
552122	551449	14031R	PARTICIPANT	\N	PRESENT	0
552123	551449	14083S	PARTICIPANT	\N	PRESENT	0
552124	551449	19507S	PARTICIPANT	\N	PRESENT	0
552125	551449	19701S	PARTICIPANT	\N	PRESENT	0
552126	551449	19657G	PARTICIPANT	\N	PRESENT	0
552127	551449	14187A	PARTICIPANT	\N	PRESENT	0
552128	551449	14195A	PARTICIPANT	\N	PRESENT	0
552138	551449	19768N	PARTICIPANT	\N	PRESENT	0
552139	551449	19387D	PARTICIPANT	\N	PRESENT	0
552140	551449	11012A	PARTICIPANT	\N	PRESENT	0
552141	551449	20072C	PARTICIPANT	\N	PRESENT	0
552142	551449	14357A	PARTICIPANT	\N	PRESENT	0
552143	551449	14219Q	PARTICIPANT	\N	PRESENT	0
552144	551449	20094J	PARTICIPANT	\N	PRESENT	0
552157	551449	19693L	PARTICIPANT	\N	PRESENT	0
552158	551449	20038A	PARTICIPANT	\N	PRESENT	0
552159	551449	11097X	PARTICIPANT	\N	PRESENT	0
552160	551449	19573D	PARTICIPANT	\N	PRESENT	0
552161	551449	20100N	PARTICIPANT	\N	PRESENT	0
552162	551449	19966S	PARTICIPANT	\N	PRESENT	0
552163	551449	14147R	PARTICIPANT	\N	PRESENT	0
552168	551449	14071N	PARTICIPANT	\N	PRESENT	0
552166	551449	20024T	PARTICIPANT	\N	PRESENT	0
552167	551449	20066E	PARTICIPANT	\N	PRESENT	0
552169	551449	19575F	PARTICIPANT	\N	PRESENT	0
552170	551449	19335Q	PARTICIPANT	\N	PRESENT	0
552171	551449	14217N	PARTICIPANT	\N	PRESENT	0
552172	551449	14105F	PARTICIPANT	\N	PRESENT	0
552173	551449	19741B	PARTICIPANT	\N	PRESENT	0
552174	551449	14225N	PARTICIPANT	\N	PRESENT	0
552175	551449	20082E	PARTICIPANT	\N	PRESENT	0
552176	551449	20142Y	PARTICIPANT	\N	PRESENT	0
552177	551449	11053K	PARTICIPANT	\N	PRESENT	0
552178	551449	14179A	PARTICIPANT	\N	PRESENT	0
552179	551449	14215L	PARTICIPANT	\N	PRESENT	0
552180	551449	14189C	PARTICIPANT	\N	PRESENT	0
552181	551449	14042U	PARTICIPANT	\N	PRESENT	0
552186	551449	19747H	PARTICIPANT	\N	PRESENT	0
552187	551449	14069U	PARTICIPANT	\N	PRESENT	0
552188	551449	19729F	PARTICIPANT	\N	PRESENT	0
552189	551449	19599P	PARTICIPANT	\N	PRESENT	0
552190	551449	19762G	PARTICIPANT	\N	PRESENT	0
552191	551449	14329V	PARTICIPANT	\N	PRESENT	0
552192	551449	19443T	PARTICIPANT	\N	PRESENT	0
552193	551449	14030Q	PARTICIPANT	\N	PRESENT	0
552194	551449	19441R	PARTICIPANT	\N	PRESENT	0
552195	551449	11067R	PARTICIPANT	\N	PRESENT	0
552196	551449	08010L	PARTICIPANT	\N	PRESENT	0
552197	551449	97011G	PARTICIPANT	\N	PRESENT	0
552198	551449	05012A	PARTICIPANT	\N	PRESENT	0
552199	551449	20056C	PARTICIPANT	\N	PRESENT	0
552200	551449	14133K	PARTICIPANT	\N	PRESENT	0
552201	551449	20068G	PARTICIPANT	\N	PRESENT	0
552202	551449	14097Y	PARTICIPANT	\N	PRESENT	0
552203	551449	19637C	PARTICIPANT	\N	PRESENT	0
552204	551449	20052X	PARTICIPANT	\N	PRESENT	0
552205	551449	20174H	PARTICIPANT	\N	PRESENT	0
552206	551449	19383Y	PARTICIPANT	\N	PRESENT	0
552207	551449	14213J	PARTICIPANT	\N	PRESENT	0
552209	551449	20086J	PARTICIPANT	\N	PRESENT	0
552210	551449	08015R	PARTICIPANT	\N	PRESENT	0
552211	551449	20104S	PARTICIPANT	\N	PRESENT	0
552212	551449	19447X	PARTICIPANT	\N	PRESENT	0
552213	551449	14026U	PARTICIPANT	\N	PRESENT	0
552214	551449	19679N	PARTICIPANT	\N	PRESENT	0
552215	551449	20028X	PARTICIPANT	\N	PRESENT	0
552216	551269	14217N	PARTICIPANT	\N	PRESENT	1
552217	551269	04043D	PARTICIPANT	\N	PRESENT	1
552218	551269	20130U	PARTICIPANT	\N	PRESENT	1
552219	551269	17965H	PARTICIPANT	\N	PRESENT	1
552220	551269	14026U	PARTICIPANT	\N	PRESENT	1
552291	552290	20024T	PARTICIPANT	\N	PRESENT	1
552292	552290	19782L	PARTICIPANT	\N	PRESENT	1
552293	552290	20090E	PARTICIPANT	\N	PRESENT	1
552294	552290	11103C	PARTICIPANT	\N	PRESENT	1
552295	552290	14329V	PARTICIPANT	\N	PRESENT	1
552296	552290	19467C	PARTICIPANT	\N	PRESENT	1
552297	552290	18083K	PARTICIPANT	\N	PRESENT	1
552298	552290	17589D	PARTICIPANT	\N	PRESENT	1
552299	552290	14179A	PARTICIPANT	\N	PRESENT	1
552300	552290	14213J	PARTICIPANT	\N	PRESENT	1
552301	552290	14097Y	PARTICIPANT	\N	PRESENT	1
552302	552290	19723Y	PARTICIPANT	\N	PRESENT	1
552303	552290	05012A	PARTICIPANT	\N	PRESENT	1
552304	552290	19739H	PARTICIPANT	\N	PRESENT	1
552305	552290	19679N	PARTICIPANT	\N	PRESENT	1
552306	552290	19619A	PARTICIPANT	\N	PRESENT	1
552307	552290	20062A	PARTICIPANT	\N	PRESENT	1
552408	552407	08060W	PARTICIPANT	\N	PRESENT	0
552409	552407	05012A	PARTICIPANT	\N	PRESENT	0
552410	552407	17229F	PARTICIPANT	\N	PRESENT	0
552411	552407	20100N	PARTICIPANT	\N	PRESENT	0
552412	552407	19387D	PARTICIPANT	\N	PRESENT	0
552413	552407	19551W	PARTICIPANT	\N	PRESENT	0
552416	552415	14219Q	PARTICIPANT	\N	PRESENT	0
552417	552415	08060W	PARTICIPANT	\N	PRESENT	0
552418	552415	05012A	PARTICIPANT	\N	PRESENT	0
552419	552415	17229F	PARTICIPANT	\N	PRESENT	0
552420	552415	20100N	PARTICIPANT	\N	PRESENT	0
552421	552415	19551W	PARTICIPANT	\N	PRESENT	0
552502	551124	14267Y	PARTICIPANT	\N	EXCUSE	0
552503	551124	14193X	PARTICIPANT	\N	EXCUSE	0
552504	551124	14097Y	PARTICIPANT	\N	PRESENT	0
552505	551265	19725B	PARTICIPANT	\N	PRESENT	1
552506	551265	17737W	PARTICIPANT	\N	PRESENT	1
552507	551265	19489J	PARTICIPANT	\N	PRESENT	1
552508	551265	20074E	PARTICIPANT	\N	PRESENT	1
552509	551265	14041T	PARTICIPANT	\N	PRESENT	1
552510	551265	14107H	PARTICIPANT	\N	PRESENT	1
552511	551265	14147R	PARTICIPANT	\N	PRESENT	0
552512	551265	19543W	PARTICIPANT	\N	PRESENT	1
552513	551265	04008A	PARTICIPANT	\N	PRESENT	1
552514	551265	19749K	PARTICIPANT	\N	PRESENT	1
552515	551265	11033F	PARTICIPANT	\N	PRESENT	1
552516	551265	19675J	PARTICIPANT	\N	PRESENT	1
552517	551270	19581D	PARTICIPANT	\N	PRESENT	1
552518	551270	11033F	PARTICIPANT	\N	PRESENT	1
552519	551270	19675J	PARTICIPANT	\N	PRESENT	1
552520	551270	04085P	PARTICIPANT	\N	PRESENT	1
552521	551270	19725B	PARTICIPANT	\N	PRESENT	1
552522	551270	17737W	PARTICIPANT	\N	PRESENT	1
552523	551270	19489J	PARTICIPANT	\N	PRESENT	1
552524	551270	95063L	PARTICIPANT	\N	PRESENT	1
552525	551270	14041T	PARTICIPANT	\N	PRESENT	1
552526	551270	14107H	PARTICIPANT	\N	PRESENT	1
552527	551270	14147R	PARTICIPANT	\N	PRESENT	0
552528	551270	14069U	PARTICIPANT	\N	PRESENT	0
552529	551270	14151M	PARTICIPANT	\N	PRESENT	1
552530	551270	04008A	PARTICIPANT	\N	PRESENT	1
552531	551270	19749K	PARTICIPANT	\N	PRESENT	1
552532	551265	04047H	PRESIDENT	0	PRESENT	0
552533	551265	19673G	PARTICIPANT	\N	PRESENT	0
552534	551265	01028R	PARTICIPANT	\N	PRESENT	0
552535	551265	19447X	PARTICIPANT	\N	PRESENT	0
552536	551265	05008E	PARTICIPANT	\N	PRESENT	0
552537	551265	14231L	PARTICIPANT	\N	PRESENT	0
552538	551265	19954N	PARTICIPANT	\N	PRESENT	0
552539	551265	20108W	PARTICIPANT	\N	PRESENT	0
552540	551265	20110Q	PARTICIPANT	\N	PRESENT	0
552541	551265	20114U	PARTICIPANT	\N	PRESENT	0
552542	551265	14215L	PARTICIPANT	\N	PRESENT	0
552543	551265	14259Y	PARTICIPANT	\N	PRESENT	0
552544	551265	11072N	PARTICIPANT	\N	PRESENT	0
552545	551265	14111D	PARTICIPANT	\N	PRESENT	0
552546	551265	14089Y	PARTICIPANT	\N	PRESENT	0
552547	551265	11056N	PARTICIPANT	\N	PRESENT	0
552548	551265	19729F	PARTICIPANT	\N	PRESENT	0
552549	551265	14069U	PARTICIPANT	\N	PRESENT	0
552550	551265	14021P	PARTICIPANT	\N	PRESENT	0
552551	551284	19768N	PARTICIPANT	\N	PRESENT	0
552552	551284	19515S	PARTICIPANT	\N	PRESENT	0
552553	551284	19782L	PARTICIPANT	\N	PRESENT	0
552554	551284	19441R	PARTICIPANT	\N	PRESENT	0
552555	551284	20018V	PARTICIPANT	\N	PRESENT	0
552556	551284	20028X	PARTICIPANT	\N	PRESENT	0
552557	551284	14038Y	PARTICIPANT	\N	PRESENT	0
544599	542934	19820Y	PARTICIPANT	\N	PRESENT	0
544600	542934	20132W	PARTICIPANT	\N	PRESENT	0
544601	542934	19467C	PARTICIPANT	\N	PRESENT	0
544602	542934	14073Q	PARTICIPANT	\N	PRESENT	0
544604	542934	20048C	PARTICIPANT	\N	PRESENT	0
544614	542934	20112S	PARTICIPANT	\N	PRESENT	0
544615	542934	11056N	PARTICIPANT	\N	PRESENT	0
544633	542934	14147R	PARTICIPANT	\N	PRESENT	0
544634	542934	19421M	PARTICIPANT	\N	PRESENT	0
544635	542934	14257W	PARTICIPANT	\N	PRESENT	0
544636	544620	19333N	PARTICIPANT	\N	PRESENT	0
544637	544620	19701S	PARTICIPANT	\N	PRESENT	0
544638	544620	19549D	PARTICIPANT	\N	PRESENT	0
544639	544620	19387D	PARTICIPANT	\N	PRESENT	0
544640	544620	14219Q	PRESIDENT	0	PRESENT	0
544641	544620	19820Y	PARTICIPANT	\N	PRESENT	1
544642	544620	19826F	PARTICIPANT	\N	PRESENT	0
544643	544620	19581D	PARTICIPANT	\N	PRESENT	0
544644	544620	19585H	PARTICIPANT	\N	PRESENT	0
544645	544620	19599P	PARTICIPANT	\N	PRESENT	0
544646	544620	04047H	PARTICIPANT	\N	PRESENT	0
544647	544620	19673G	PARTICIPANT	\N	PRESENT	0
544648	544620	20096L	PARTICIPANT	\N	PRESENT	0
544649	544620	05008E	PARTICIPANT	\N	PRESENT	0
544650	544620	14231L	PARTICIPANT	\N	PRESENT	0
544651	544620	19447X	PARTICIPANT	\N	PRESENT	1
544652	544620	18083K	PARTICIPANT	\N	PRESENT	0
544653	544620	14237S	PARTICIPANT	\N	PRESENT	0
544654	544620	19551W	PARTICIPANT	\N	PRESENT	1
544655	544620	05012A	PARTICIPANT	\N	PRESENT	0
544656	544620	19954N	PARTICIPANT	\N	PRESENT	0
544657	544620	17737W	PARTICIPANT	\N	PRESENT	0
544658	544620	08060W	PARTICIPANT	\N	PRESENT	1
544659	544620	20106U	PARTICIPANT	\N	PRESENT	1
544660	544620	20118Y	PARTICIPANT	\N	PRESENT	0
544661	544620	19503N	PARTICIPANT	\N	PRESENT	0
544662	544620	14179A	PARTICIPANT	\N	PRESENT	0
544663	544620	14147R	PARTICIPANT	\N	PRESENT	0
544664	544620	20024T	PARTICIPANT	\N	PRESENT	0
544665	544620	11065P	PARTICIPANT	\N	PRESENT	0
544666	544620	20120S	PARTICIPANT	\N	PRESENT	0
544667	544620	19525U	PARTICIPANT	\N	PRESENT	0
544668	544620	14053L	PARTICIPANT	\N	PRESENT	0
544669	544620	14111D	PARTICIPANT	\N	PRESENT	0
544670	544620	19649G	PARTICIPANT	\N	PRESENT	1
544671	544620	20136B	PARTICIPANT	\N	PRESENT	0
544672	544620	14031R	PARTICIPANT	\N	PRESENT	0
544673	544620	20038A	PARTICIPANT	\N	PRESENT	0
544674	544620	14169X	PARTICIPANT	\N	PRESENT	0
544675	544620	04085P	PARTICIPANT	\N	PRESENT	1
544676	544620	14089Y	PARTICIPANT	\N	PRESENT	0
544677	544620	95063L	PARTICIPANT	\N	PRESENT	1
544678	544620	14069U	PARTICIPANT	\N	PRESENT	0
544679	544620	19745F	PARTICIPANT	\N	PRESENT	1
544680	544620	19749K	PARTICIPANT	\N	PRESENT	0
544681	544620	19619A	PARTICIPANT	\N	PRESENT	1
544682	542934	14195A	PARTICIPANT	\N	PRESENT	0
544683	542934	19581D	PARTICIPANT	\N	PRESENT	0
544684	542934	19507S	PARTICIPANT	\N	PRESENT	0
544685	542934	20052X	PARTICIPANT	\N	PRESENT	0
544686	542934	20142Y	PARTICIPANT	\N	PRESENT	0
544687	542934	20044X	PARTICIPANT	\N	PRESENT	0
544689	542934	19413M	PARTICIPANT	\N	PRESENT	0
544690	544620	11026G	PARTICIPANT	\N	PRESENT	1
544691	542826	19333N	PARTICIPANT	\N	PRESENT	0
544692	542826	19549D	PARTICIPANT	\N	PRESENT	0
544693	542826	14219Q	PARTICIPANT	\N	PRESENT	0
544694	542826	19820Y	PARTICIPANT	\N	PRESENT	0
544695	542826	19581D	PARTICIPANT	\N	PRESENT	0
544696	542826	19826F	PARTICIPANT	\N	PRESENT	0
544697	542826	19585H	PARTICIPANT	\N	PRESENT	0
544698	542826	04047H	PRESIDENT	0	PRESENT	0
544699	542826	19599P	PARTICIPANT	\N	PRESENT	0
544700	542826	20102Q	PARTICIPANT	\N	PRESENT	0
544701	542826	19673G	PARTICIPANT	\N	PRESENT	0
544702	542826	01028R	PARTICIPANT	\N	PRESENT	0
544703	542826	20096L	PARTICIPANT	\N	PRESENT	0
544704	542826	05008E	PARTICIPANT	\N	PRESENT	0
544705	542826	14231L	PARTICIPANT	\N	PRESENT	0
544706	542826	18083K	PARTICIPANT	\N	PRESENT	0
544707	542826	14237S	PARTICIPANT	\N	PRESENT	0
544708	542826	05012A	PARTICIPANT	\N	PRESENT	0
544709	542826	19954N	PARTICIPANT	\N	PRESENT	0
544710	542826	17737W	PARTICIPANT	\N	PRESENT	0
544711	542826	20118Y	PARTICIPANT	\N	PRESENT	0
544712	542826	19503N	PARTICIPANT	\N	PRESENT	0
544713	542826	20024T	PARTICIPANT	\N	PRESENT	0
544714	542826	11065P	PARTICIPANT	\N	PRESENT	0
544715	542826	17637T	PARTICIPANT	\N	PRESENT	0
544716	542826	19525U	PARTICIPANT	\N	PRESENT	0
544717	542826	20120S	PARTICIPANT	\N	PRESENT	0
544718	542826	14053L	PARTICIPANT	\N	PRESENT	0
544719	542826	14111D	PARTICIPANT	\N	PRESENT	0
544720	542826	20136B	PARTICIPANT	\N	PRESENT	0
544721	542826	14031R	PARTICIPANT	\N	PRESENT	0
544722	542826	20038A	PARTICIPANT	\N	PRESENT	0
544723	542826	14089Y	PARTICIPANT	\N	PRESENT	0
544724	542826	19739H	PARTICIPANT	\N	PRESENT	0
544725	542826	14069U	PARTICIPANT	\N	PRESENT	0
544726	542826	19749K	PARTICIPANT	\N	PRESENT	0
544727	542826	14179A	PARTICIPANT	\N	PRESENT	0
544728	542826	14147R	PARTICIPANT	\N	PRESENT	0
544735	542934	20024T	PARTICIPANT	\N	PRESENT	0
544736	542934	14071N	PARTICIPANT	\N	PRESENT	0
544744	542934	19383Y	PARTICIPANT	\N	PRESENT	0
544746	542934	19954N	PARTICIPANT	\N	PRESENT	0
544747	542934	14033T	PARTICIPANT	\N	PRESENT	0
544748	542828	14053L	PARTICIPANT	\N	PRESENT	0
544749	542828	04047H	PRESIDENT	0	PRESENT	0
544750	542934	20056C	PARTICIPANT	\N	PRESENT	0
544752	542934	14069U	PARTICIPANT	\N	PRESENT	0
544753	542934	11067R	PARTICIPANT	\N	PRESENT	0
544754	542828	14069U	PARTICIPANT	\N	PRESENT	0
544755	542828	05008E	PARTICIPANT	\N	PRESENT	0
544756	542828	19489J	PARTICIPANT	\N	PRESENT	0
544757	542934	19758L	PARTICIPANT	\N	PRESENT	0
544758	542828	19585H	PARTICIPANT	\N	PRESENT	0
544759	542828	20108W	PARTICIPANT	\N	PRESENT	0
544760	542828	14231L	PARTICIPANT	\N	EXCUSE	0
544761	542828	01028R	PARTICIPANT	\N	PRESENT	0
544763	544762	19333N	PARTICIPANT	\N	PRESENT	0
544764	544762	14031R	PARTICIPANT	\N	PRESENT	0
544765	544762	19387D	PARTICIPANT	\N	PRESENT	0
544766	544762	14219Q	PRESIDENT	0	PRESENT	0
544767	544762	19599P	PARTICIPANT	\N	PRESENT	0
544768	544762	11065P	PARTICIPANT	\N	PRESENT	0
544769	544762	14237S	PARTICIPANT	\N	PRESENT	0
544770	544762	18083K	PARTICIPANT	\N	PRESENT	0
544771	544762	19701S	PARTICIPANT	\N	PRESENT	0
544772	544762	19549D	PARTICIPANT	\N	PRESENT	0
544773	544762	19739H	PARTICIPANT	\N	PRESENT	0
544774	544762	14169X	PARTICIPANT	\N	PRESENT	0
544775	544762	20136B	PARTICIPANT	\N	PRESENT	0
544776	544762	20102Q	PARTICIPANT	\N	PRESENT	0
544777	544762	19251M	PARTICIPANT	\N	PRESENT	0
544778	544762	19503N	PARTICIPANT	\N	PRESENT	0
544597	542934	19717B	PARTICIPANT	\N	PRESENT	0
544598	542934	01025N	PARTICIPANT	\N	PRESENT	0
563861	563025	14223L	PARTICIPANT	\N	PRESENT	1
563862	563025	01034P	PARTICIPANT	\N	PRESENT	1
563863	563025	14213J	PARTICIPANT	\N	PRESENT	1
563864	563025	19691J	PARTICIPANT	\N	PRESENT	1
563865	563025	11103C	PARTICIPANT	\N	PRESENT	1
563866	563025	19569H	PARTICIPANT	\N	PRESENT	1
563867	563025	04092N	PARTICIPANT	\N	PRESENT	1
563868	563025	20130U	PARTICIPANT	\N	PRESENT	1
563869	563025	11067R	PARTICIPANT	\N	PRESENT	0
563870	563025	19679N	PARTICIPANT	\N	PRESENT	0
563875	563025	14217N	PARTICIPANT	\N	PRESENT	0
563876	563025	10006L	PRESIDENT	0	PRESENT	0
563887	563025	19798U	PARTICIPANT	\N	PRESENT	1
563890	563025	14042U	PARTICIPANT	\N	PRESENT	0
563906	563025	18193Q	PARTICIPANT	\N	PRESENT	1
563914	563025	20172F	PARTICIPANT	\N	PRESENT	1
563916	563025	19760E	PARTICIPANT	\N	PRESENT	1
564543	563959	07004J	PARTICIPANT	\N	EXCUSE	0
564544	563959	20128B	PARTICIPANT	\N	PRESENT	1
564545	563959	19581D	PARTICIPANT	\N	PRESENT	1
565171	563024	19717B	PARTICIPANT	\N	PRESENT	1
565172	563024	14355X	PARTICIPANT	\N	PRESENT	0
565231	563261	19575F	PARTICIPANT	\N	PRESENT	0
565245	564954	20120S	PARTICIPANT	\N	PRESENT	0
565246	564954	14221J	PARTICIPANT	\N	EXCUSE	0
566142	566141	14083S	PARTICIPANT	\N	PRESENT	0
566143	566141	14249W	PARTICIPANT	\N	PRESENT	0
566144	566141	16685X	PARTICIPANT	\N	PRESENT	0
566240	564344	11070L	PARTICIPANT	\N	PRESENT	0
566241	564344	20134Y	PARTICIPANT	\N	PRESENT	0
566242	564344	20070A	PARTICIPANT	\N	PRESENT	0
566243	564344	19399H	PARTICIPANT	\N	PRESENT	0
566244	564344	19747H	PARTICIPANT	\N	PRESENT	0
566245	564344	20108W	PARTICIPANT	\N	PRESENT	0
566246	564344	20172F	PARTICIPANT	\N	PRESENT	0
566247	564344	19667J	PARTICIPANT	\N	PRESENT	0
566248	564344	20026V	PARTICIPANT	\N	PRESENT	0
566249	564344	19467C	PARTICIPANT	\N	PRESENT	0
566250	564344	18083K	PARTICIPANT	\N	PRESENT	0
566251	564344	01048V	PARTICIPANT	\N	PRESENT	0
566252	564344	19479G	PARTICIPANT	\N	PRESENT	0
566253	564344	14267Y	PARTICIPANT	\N	PRESENT	0
566254	564344	14083S	PARTICIPANT	\N	PRESENT	0
566255	564344	20132W	PARTICIPANT	\N	PRESENT	0
566256	564344	11083R	PARTICIPANT	\N	PRESENT	0
566257	564344	04085P	PARTICIPANT	\N	PRESENT	0
566261	564344	19762G	PARTICIPANT	\N	PRESENT	0
566258	564344	11040E	PARTICIPANT	\N	PRESENT	0
566259	564344	20122U	PARTICIPANT	\N	PRESENT	0
566262	564344	14205J	PARTICIPANT	\N	PRESENT	0
566263	564344	20060X	PARTICIPANT	\N	PRESENT	0
566264	564344	08017T	PARTICIPANT	\N	PRESENT	0
566265	564344	01024M	PARTICIPANT	\N	PRESENT	0
566266	564344	19369B	PARTICIPANT	\N	PRESENT	0
566267	564344	19515S	PARTICIPANT	\N	PRESENT	0
566268	564344	19415P	PARTICIPANT	\N	PRESENT	0
566269	564344	14030Q	PARTICIPANT	\N	PRESENT	0
566270	564344	11097X	PARTICIPANT	\N	PRESENT	0
566271	564344	11067R	PARTICIPANT	\N	PRESENT	0
566273	563808	20110Q	PARTICIPANT	\N	PRESENT	0
566274	563808	19349W	PARTICIPANT	\N	PRESENT	0
566275	563808	14231L	PRESIDENT	0	PRESENT	0
566276	563808	14281W	PARTICIPANT	\N	PRESENT	1
566280	564344	11033F	PARTICIPANT	\N	PRESENT	0
566278	563808	19447X	PARTICIPANT	\N	PRESENT	0
566279	564344	99004R	PARTICIPANT	\N	PRESENT	0
566281	564344	19643A	PARTICIPANT	\N	PRESENT	0
566283	564344	19631V	PARTICIPANT	\N	PRESENT	0
566304	564344	20130U	PARTICIPANT	\N	PRESENT	0
566307	564344	19689Q	PARTICIPANT	\N	PRESENT	0
566308	564344	07029T	PARTICIPANT	\N	PRESENT	0
566340	564345	07029T	PARTICIPANT	\N	PRESENT	0
566341	564345	20108W	PARTICIPANT	\N	PRESENT	0
566342	564345	19515S	PARTICIPANT	\N	PRESENT	0
566343	564345	14267Y	PARTICIPANT	\N	PRESENT	0
566344	564345	01024M	PARTICIPANT	\N	PRESENT	0
566345	564345	19689Q	PARTICIPANT	\N	PRESENT	0
566346	564345	20134Y	PARTICIPANT	\N	PRESENT	0
566347	564345	20132W	PARTICIPANT	\N	PRESENT	0
566348	564345	08017T	PARTICIPANT	\N	PRESENT	0
566349	564345	11026G	PARTICIPANT	\N	PRESENT	0
566350	564345	19631V	PARTICIPANT	\N	PRESENT	0
566351	564345	11033F	PARTICIPANT	\N	PRESENT	0
566352	564345	04085P	PARTICIPANT	\N	PRESENT	0
566354	564345	20130U	PARTICIPANT	\N	PRESENT	0
566355	564345	14030Q	PARTICIPANT	\N	PRESENT	0
566358	564345	20026V	PARTICIPANT	\N	PRESENT	0
566361	564345	11083R	PARTICIPANT	\N	PRESENT	0
566363	564345	99004R	PARTICIPANT	\N	PRESENT	0
566364	564345	14249W	PARTICIPANT	\N	PRESENT	0
566366	564345	20122U	PARTICIPANT	\N	PRESENT	0
566367	564345	19747H	PARTICIPANT	\N	PRESENT	0
566409	565714	20032T	PARTICIPANT	\N	PRESENT	0
566410	565714	19525U	PARTICIPANT	\N	EXCUSE	0
566411	565714	14221J	PARTICIPANT	\N	EXCUSE	0
566546	566545	14231L	PARTICIPANT	\N	PRESENT	0
566547	566545	14259Y	PARTICIPANT	\N	PRESENT	0
566549	566548	14259Y	PARTICIPANT	\N	PRESENT	0
566551	566550	14259Y	PARTICIPANT	\N	PRESENT	0
566552	566550	14231L	PARTICIPANT	\N	PRESENT	0
566338	564345	11070L	PARTICIPANT	\N	PRESENT	0
566339	564345	19643A	PARTICIPANT	\N	PRESENT	0
566554	566553	14231L	PARTICIPANT	\N	PRESENT	0
566884	566883	19735D	PARTICIPANT	\N	PRESENT	0
566885	566883	01048V	PARTICIPANT	\N	PRESENT	0
566886	566883	04043D	PARTICIPANT	\N	PRESENT	0
566888	566883	19533U	PARTICIPANT	\N	PRESENT	0
567007	565268	20148F	PARTICIPANT	\N	PRESENT	0
567008	565268	20172F	PARTICIPANT	\N	PRESENT	1
567009	565268	20066E	PARTICIPANT	\N	PRESENT	0
567010	565268	11103C	PARTICIPANT	\N	PRESENT	1
567011	565268	14213J	PARTICIPANT	\N	PRESENT	0
567012	565268	14071N	PARTICIPANT	\N	PRESENT	0
567013	565268	14217N	PARTICIPANT	\N	PRESENT	0
567014	565268	04043D	PARTICIPANT	\N	PRESENT	1
567015	565268	19683J	PARTICIPANT	\N	PRESENT	0
567016	565268	10006L	PRESIDENT	0	PRESENT	0
567017	565268	04057K	PARTICIPANT	\N	EXCUSE	0
567018	565268	19295A	PARTICIPANT	\N	EXCUSE	0
567019	565268	18193Q	PARTICIPANT	\N	PRESENT	0
567020	565268	11031D	PARTICIPANT	\N	PRESENT	1
567021	565268	14042U	PARTICIPANT	\N	PRESENT	1
567022	565268	01034P	PARTICIPANT	\N	PRESENT	1
567023	565268	11045K	PARTICIPANT	\N	PRESENT	1
567024	565268	17965H	PARTICIPANT	\N	PRESENT	0
567025	565471	20132W	PARTICIPANT	\N	PRESENT	0
567026	565471	14229S	PARTICIPANT	\N	PRESENT	0
567027	565471	20056C	PARTICIPANT	\N	PRESENT	0
567028	565471	04059M	PARTICIPANT	\N	PRESENT	0
567029	565471	20112S	PARTICIPANT	\N	PRESENT	0
567030	565471	20124W	PARTICIPANT	\N	PRESENT	0
567031	566306	20086J	PARTICIPANT	\N	PRESENT	1
567032	566306	20088L	PARTICIPANT	\N	PRESENT	1
567033	566306	19515S	PARTICIPANT	\N	PRESENT	0
567034	566306	20092G	PARTICIPANT	\N	PRESENT	0
567035	566306	01043Q	PARTICIPANT	\N	PRESENT	0
567036	566306	14357A	PARTICIPANT	\N	PRESENT	0
567037	566306	19413M	PARTICIPANT	\N	PRESENT	0
567038	566306	04045F	PARTICIPANT	\N	PRESENT	0
567039	566306	19631V	PARTICIPANT	\N	PRESENT	0
567040	566306	11099A	PARTICIPANT	\N	PRESENT	0
567041	566306	19705W	PARTICIPANT	\N	PRESENT	0
567042	566306	08015R	PARTICIPANT	\N	PRESENT	0
567043	566306	19575F	PARTICIPANT	\N	PRESENT	0
567044	566306	19369B	PARTICIPANT	\N	PRESENT	0
567045	566306	14038Y	PARTICIPANT	\N	PRESENT	1
567046	566306	19467C	PARTICIPANT	\N	PRESENT	0
567047	566306	14187A	PARTICIPANT	\N	PRESENT	0
567048	566306	20144B	PARTICIPANT	\N	PRESENT	0
567049	566306	19695N	PARTICIPANT	\N	PRESENT	0
567050	566306	11090Q	PRESIDENT	0	PRESENT	0
567051	566306	20174H	PARTICIPANT	\N	PRESENT	1
567052	566306	14205J	PARTICIPANT	\N	PRESENT	0
567053	566306	19507S	PARTICIPANT	\N	PRESENT	0
567054	566306	14207L	PARTICIPANT	\N	PRESENT	0
567055	566306	19747H	PARTICIPANT	\N	PRESENT	0
567056	566306	14257W	PARTICIPANT	\N	PRESENT	0
567072	565471	19651A	PARTICIPANT	\N	PRESENT	0
567073	565471	20152B	PARTICIPANT	\N	PRESENT	0
567074	565471	04070G	PARTICIPANT	\N	PRESENT	0
541654	539550	19621T	PARTICIPANT	\N	PRESENT	0
542755	539554	20048C	PARTICIPANT	\N	PRESENT	0
542756	539554	20152B	PARTICIPANT	\N	PRESENT	0
542758	539554	20042V	PARTICIPANT	\N	PRESENT	0
542761	539554	08010L	PARTICIPANT	\N	PRESENT	0
542762	539554	11048N	PARTICIPANT	\N	PRESENT	0
542767	539554	19697Q	PARTICIPANT	\N	PRESENT	0
542768	539554	04047H	PARTICIPANT	\N	PRESENT	0
542815	542814	14147R	PARTICIPANT	\N	PRESENT	0
542825	542824	14069U	PARTICIPANT	\N	PRESENT	0
542827	542824	11072N	PARTICIPANT	\N	PRESENT	0
542830	542829	14069U	PARTICIPANT	\N	PRESENT	0
542831	542829	11072N	PARTICIPANT	\N	PRESENT	0
542835	542834	14069U	PARTICIPANT	\N	PRESENT	0
542836	542834	11072N	PARTICIPANT	\N	PRESENT	0
542838	542837	14069U	PARTICIPANT	\N	PRESENT	0
542839	542837	11072N	PARTICIPANT	\N	PRESENT	0
543602	543601	14255U	PARTICIPANT	\N	PRESENT	0
543603	543601	04042C	PARTICIPANT	\N	PRESENT	0
543604	543601	19565D	PARTICIPANT	\N	PRESENT	0
543605	543601	98018T	PARTICIPANT	\N	PRESENT	0
543606	543601	14327T	PARTICIPANT	\N	PRESENT	0
543607	543601	19443T	PARTICIPANT	\N	PRESENT	0
543608	543601	11041F	PARTICIPANT	\N	PRESENT	0
543609	543601	20064C	PARTICIPANT	\N	PRESENT	0
543610	543601	19583F	PARTICIPANT	\N	PRESENT	0
543611	543601	14073Q	PARTICIPANT	\N	PRESENT	0
543612	543601	14179A	PARTICIPANT	\N	PRESENT	0
543613	543601	14211G	PARTICIPANT	\N	PRESENT	0
543614	543601	14281W	PARTICIPANT	\N	PRESENT	0
543616	543601	19721W	PARTICIPANT	\N	PRESENT	0
543750	542364	04043D	PARTICIPANT	\N	PRESENT	0
543751	542364	18193Q	PARTICIPANT	\N	PRESENT	0
543752	542364	19760E	PARTICIPANT	\N	PRESENT	0
543756	542364	19591F	PARTICIPANT	\N	PRESENT	1
543760	542364	11031D	PARTICIPANT	\N	PRESENT	0
543838	542364	19679N	PARTICIPANT	\N	PRESENT	0
543951	542364	19295A	PARTICIPANT	\N	EXCUSE	0
543952	542364	14026U	PARTICIPANT	\N	PRESENT	1
543953	542364	11103C	PARTICIPANT	\N	PRESENT	1
545380	543064	19745F	PARTICIPANT	\N	PRESENT	0
545381	543064	19533U	PARTICIPANT	\N	PRESENT	0
545382	543064	19735D	PARTICIPANT	\N	PRESENT	0
545383	543064	19593H	PRESIDENT	0	PRESENT	0
545384	543064	19721W	PARTICIPANT	\N	EXCUSE	0
545385	543064	20082E	PARTICIPANT	\N	PRESENT	0
545386	543064	19611R	PARTICIPANT	\N	PRESENT	0
545387	543064	20142Y	PARTICIPANT	\N	PRESENT	0
545388	543064	19715Y	PARTICIPANT	\N	PRESENT	0
545389	543064	20132W	PARTICIPANT	\N	PRESENT	0
545390	543064	19954N	PARTICIPANT	\N	PRESENT	0
545391	543064	20180F	PARTICIPANT	\N	PRESENT	0
545392	543064	14147R	PARTICIPANT	\N	EXCUSE	0
545396	542796	14331P	PARTICIPANT	\N	EXCUSE	0
546084	543955	20030R	PARTICIPANT	\N	PRESENT	1
546085	543955	19369B	PARTICIPANT	\N	PRESENT	1
546086	543955	04045F	PARTICIPANT	\N	PRESENT	1
546087	543955	19705W	PARTICIPANT	\N	PRESENT	1
546088	543955	20174H	PARTICIPANT	\N	PRESENT	1
546089	543955	20088L	PARTICIPANT	\N	PRESENT	1
546091	543955	20062A	PARTICIPANT	\N	PRESENT	1
546092	543955	14109K	PARTICIPANT	\N	PRESENT	1
546093	543955	19701S	PARTICIPANT	\N	PRESENT	1
546094	543955	19575F	PARTICIPANT	\N	PRESENT	1
546095	543955	14169X	PARTICIPANT	\N	PRESENT	1
546097	543955	04035D	PARTICIPANT	\N	PRESENT	1
546098	543955	14026U	PARTICIPANT	\N	PRESENT	1
546099	543955	19553Y	PARTICIPANT	\N	PRESENT	1
546100	543955	19711U	PARTICIPANT	\N	PRESENT	1
546101	543955	11026G	PARTICIPANT	\N	PRESENT	1
546107	546106	95063L	PARTICIPANT	\N	PRESENT	0
546108	546106	14041T	PARTICIPANT	\N	PRESENT	0
546109	546106	19954N	PARTICIPANT	\N	PRESENT	0
546110	546106	11083R	PARTICIPANT	\N	PRESENT	0
546111	546106	14255U	PARTICIPANT	\N	PRESENT	0
546112	546106	14147R	PARTICIPANT	\N	PRESENT	0
546113	546106	20126Y	PARTICIPANT	\N	PRESENT	0
546496	544112	19367Y	PARTICIPANT	\N	EXCUSE	0
546705	545330	19367Y	PARTICIPANT	\N	PRESENT	0
547492	547491	16685X	PARTICIPANT	\N	PRESENT	0
546707	545330	19295A	PARTICIPANT	\N	EXCUSE	0
546708	545330	18193Q	PARTICIPANT	\N	PRESENT	0
546709	545330	11067R	PARTICIPANT	\N	PRESENT	0
546710	545330	14071N	PARTICIPANT	\N	PRESENT	0
546711	545330	19703U	PARTICIPANT	\N	PRESENT	0
546712	545330	19569H	PARTICIPANT	\N	PRESENT	0
546713	545330	19798U	PARTICIPANT	\N	PRESENT	0
546714	545330	20090E	PARTICIPANT	\N	PRESENT	0
546715	545330	14217N	PARTICIPANT	\N	PRESENT	0
546716	545330	14213J	PARTICIPANT	\N	PRESENT	0
546717	545330	14223L	PARTICIPANT	\N	PRESENT	0
546718	545330	11097X	PARTICIPANT	\N	PRESENT	0
546719	545330	20066E	PARTICIPANT	\N	PRESENT	0
547119	547118	11048N	PARTICIPANT	\N	PRESENT	0
547120	547118	20118Y	PARTICIPANT	\N	PRESENT	0
547494	547493	16685X	PARTICIPANT	\N	PRESENT	0
547531	547526	19679N	PARTICIPANT	\N	PRESENT	0
547534	547530	19679N	PARTICIPANT	\N	PRESENT	0
549019	548790	14026U	PARTICIPANT	\N	PRESENT	0
549020	548790	20152B	PARTICIPANT	\N	PRESENT	0
549021	548790	19533U	PARTICIPANT	\N	PRESENT	0
549022	548790	19593H	PARTICIPANT	\N	PRESENT	0
549023	548790	11104D	PARTICIPANT	\N	PRESENT	0
549024	548790	14123H	PARTICIPANT	\N	PRESENT	0
549025	548790	11103C	PARTICIPANT	\N	PRESENT	0
549026	548790	14229S	PARTICIPANT	\N	PRESENT	0
549027	548790	20106U	PARTICIPANT	\N	PRESENT	0
549028	548790	20054A	PARTICIPANT	\N	PRESENT	0
549029	548790	20090E	PARTICIPANT	\N	PRESENT	0
549030	548790	19621T	PARTICIPANT	\N	PRESENT	0
549031	548790	19758L	PARTICIPANT	\N	PRESENT	0
549258	547500	19703U	PARTICIPANT	\N	PRESENT	1
549259	547500	20066E	PARTICIPANT	\N	PRESENT	0
549260	547500	19679N	PARTICIPANT	\N	PRESENT	0
549261	547500	04045F	PARTICIPANT	\N	PRESENT	1
549262	547500	18193Q	PRESIDENT	0	PRESENT	0
549263	547500	19760E	PARTICIPANT	\N	PRESENT	0
549264	547500	20098N	PARTICIPANT	\N	PRESENT	1
549266	545500	19387D	PARTICIPANT	\N	PRESENT	1
549267	548790	08015R	PARTICIPANT	\N	PRESENT	0
549268	548790	19421M	PARTICIPANT	\N	PRESENT	0
549269	548790	19760E	PARTICIPANT	\N	PRESENT	0
549270	548790	14187A	PARTICIPANT	\N	PRESENT	0
549271	548790	20066E	PARTICIPANT	\N	PRESENT	0
549272	548790	14249W	PARTICIPANT	\N	PRESENT	0
549273	548790	20136B	PARTICIPANT	\N	PRESENT	0
549274	548790	11026G	PARTICIPANT	\N	PRESENT	0
549275	548790	20094J	PARTICIPANT	\N	PRESENT	0
549276	548790	11012A	PARTICIPANT	\N	PRESENT	0
549277	548790	18193Q	PARTICIPANT	\N	PRESENT	0
549278	548790	20174H	PARTICIPANT	\N	PRESENT	0
549279	548790	20080C	PARTICIPANT	\N	PRESENT	0
549308	548790	20104S	PARTICIPANT	\N	PRESENT	0
549310	548790	04070G	PARTICIPANT	\N	PRESENT	0
549311	548790	19549D	PARTICIPANT	\N	PRESENT	0
549312	548790	19563B	PARTICIPANT	\N	PRESENT	0
549313	548790	14357A	PARTICIPANT	\N	PRESENT	0
549316	548790	20102Q	PARTICIPANT	\N	PRESENT	0
549332	548790	20042V	PARTICIPANT	\N	PRESENT	0
549333	548790	20070A	PARTICIPANT	\N	PRESENT	0
549334	548790	20038A	PARTICIPANT	\N	PRESENT	0
552558	551284	14187A	PARTICIPANT	\N	PRESENT	0
552559	551284	19695N	PARTICIPANT	\N	PRESENT	0
552560	551284	20054A	PARTICIPANT	\N	PRESENT	0
552561	551284	20060X	PARTICIPANT	\N	PRESENT	0
552562	551284	14257W	PARTICIPANT	\N	PRESENT	0
552563	551284	20088L	PARTICIPANT	\N	PRESENT	0
552564	551284	01043Q	PARTICIPANT	\N	PRESENT	0
552565	551284	14357A	PARTICIPANT	\N	PRESENT	0
552566	551284	20082E	PARTICIPANT	\N	PRESENT	0
552567	551284	20094J	PARTICIPANT	\N	PRESENT	0
552568	551284	19631V	PARTICIPANT	\N	PRESENT	0
552569	551284	08015R	PARTICIPANT	\N	PRESENT	0
552570	551284	19575F	PARTICIPANT	\N	PRESENT	0
552571	551284	19369B	PARTICIPANT	\N	PRESENT	0
552572	551284	19511N	PARTICIPANT	\N	PRESENT	0
552573	551284	19563B	PARTICIPANT	\N	PRESENT	0
552574	551284	14329V	PARTICIPANT	\N	PRESENT	0
552575	551284	19467C	PARTICIPANT	\N	PRESENT	0
552576	551284	14033T	PARTICIPANT	\N	PRESENT	0
552577	551284	14205J	PARTICIPANT	\N	PRESENT	0
552578	551284	19747H	PARTICIPANT	\N	PRESENT	0
552579	551270	04047H	PRESIDENT	0	PRESENT	0
552580	551270	19673G	PARTICIPANT	\N	PRESENT	0
552581	551270	01028R	PARTICIPANT	\N	PRESENT	0
552582	551270	19447X	PARTICIPANT	\N	PRESENT	0
552583	551270	14231L	PARTICIPANT	\N	PRESENT	0
552584	551270	19954N	PARTICIPANT	\N	PRESENT	0
552585	551270	20108W	PARTICIPANT	\N	PRESENT	0
552586	551270	20110Q	PARTICIPANT	\N	PRESENT	0
552587	551270	14179A	PARTICIPANT	\N	PRESENT	0
552588	551270	20114U	PARTICIPANT	\N	PRESENT	0
552589	551270	14215L	PARTICIPANT	\N	PRESENT	0
552590	551270	08018U	PARTICIPANT	\N	PRESENT	0
552591	551270	14259Y	PARTICIPANT	\N	PRESENT	0
552592	551270	11072N	PARTICIPANT	\N	PRESENT	0
552593	551270	14053L	PARTICIPANT	\N	PRESENT	0
552594	551270	11026G	PARTICIPANT	\N	PRESENT	0
552595	551270	14089Y	PARTICIPANT	\N	PRESENT	0
552596	551270	11056N	PARTICIPANT	\N	PRESENT	0
552597	551270	19729F	PARTICIPANT	\N	PRESENT	0
552598	551270	14021P	PARTICIPANT	\N	PRESENT	0
552599	551284	11090Q	PARTICIPANT	\N	PRESENT	0
552603	551735	20068G	PARTICIPANT	\N	PRESENT	0
552604	551735	14105F	PARTICIPANT	\N	PRESENT	0
552605	551735	20108W	PARTICIPANT	\N	PRESENT	0
552606	551735	19866P	PARTICIPANT	\N	PRESENT	0
552607	551735	20056C	PARTICIPANT	\N	PRESENT	0
552608	551735	92040Q	PARTICIPANT	\N	PRESENT	0
552609	551735	19251M	PARTICIPANT	\N	PRESENT	0
552610	551735	20046A	PARTICIPANT	\N	PRESENT	0
552611	551735	20102Q	PARTICIPANT	\N	PRESENT	0
552612	551735	12028B	PARTICIPANT	\N	PRESENT	0
552613	551735	14073Q	PARTICIPANT	\N	PRESENT	0
552614	551735	20098N	PARTICIPANT	\N	PRESENT	0
552615	551735	14147R	PARTICIPANT	\N	PRESENT	0
552616	551735	14259Y	PARTICIPANT	\N	PRESENT	0
552617	551735	19651A	PARTICIPANT	\N	PRESENT	0
552618	551735	14053L	PARTICIPANT	\N	PRESENT	0
552619	551735	20086J	PARTICIPANT	\N	PRESENT	0
552620	551735	14123H	PARTICIPANT	\N	PRESENT	0
552621	551735	18083K	PARTICIPANT	\N	PRESENT	0
552622	551735	14253S	PARTICIPANT	\N	PRESENT	0
552623	551735	11041F	PARTICIPANT	\N	PRESENT	0
552624	551735	19649G	PARTICIPANT	\N	PRESENT	0
552625	551735	11056N	PARTICIPANT	\N	PRESENT	0
552626	551735	11067R	PARTICIPANT	\N	PRESENT	0
552627	551735	19766L	PARTICIPANT	\N	PRESENT	0
552628	551735	19729F	PARTICIPANT	\N	PRESENT	0
552629	551735	20024T	PARTICIPANT	\N	PRESENT	0
552630	551735	14042U	PARTICIPANT	\N	PRESENT	0
552631	551735	19413M	PARTICIPANT	\N	PRESENT	0
552632	551735	19387D	PARTICIPANT	\N	PRESENT	0
552633	551735	20104S	PARTICIPANT	\N	PRESENT	0
552634	551735	20020P	PARTICIPANT	\N	PRESENT	0
552635	551735	20026V	PARTICIPANT	\N	PRESENT	0
552636	551735	20054A	PARTICIPANT	\N	PRESENT	0
552638	551735	19675J	PARTICIPANT	\N	PRESENT	0
552639	551735	19443T	PARTICIPANT	\N	PRESENT	0
552640	551735	14038Y	PARTICIPANT	\N	PRESENT	0
552641	551735	19563B	PARTICIPANT	\N	PRESENT	0
552642	551735	19695N	PARTICIPANT	\N	PRESENT	0
552643	551735	19511N	PARTICIPANT	\N	PRESENT	0
552644	551735	19657G	PARTICIPANT	\N	PRESENT	0
552645	551735	99004R	PARTICIPANT	\N	PRESENT	0
552646	551735	20136B	PARTICIPANT	\N	PRESENT	0
552647	551735	20076G	PARTICIPANT	\N	PRESENT	0
552648	551735	20052X	PARTICIPANT	\N	PRESENT	0
552649	551735	16685X	PARTICIPANT	\N	PRESENT	0
552650	551735	19691J	PARTICIPANT	\N	PRESENT	0
552651	551735	19565D	PARTICIPANT	\N	PRESENT	0
552652	551735	20082E	PARTICIPANT	\N	PRESENT	0
552653	551735	19503N	PARTICIPANT	\N	PRESENT	0
552654	551735	14031R	PARTICIPANT	\N	PRESENT	0
552655	551735	20144B	PARTICIPANT	\N	PRESENT	0
552656	551735	11040E	PARTICIPANT	\N	PRESENT	0
552657	551735	19760E	PARTICIPANT	\N	PRESENT	0
552658	551735	20092G	PARTICIPANT	\N	PRESENT	0
552659	551735	14195A	PARTICIPANT	\N	PRESENT	0
552660	551735	19599P	PARTICIPANT	\N	PRESENT	0
552661	551735	07029T	PARTICIPANT	\N	PRESENT	0
552662	551735	01057W	PARTICIPANT	\N	PRESENT	0
552663	551735	20072C	PARTICIPANT	\N	PRESENT	0
552664	551735	08061X	PARTICIPANT	\N	PRESENT	0
552665	551735	08045X	PARTICIPANT	\N	PRESENT	0
552666	551735	14225N	PARTICIPANT	\N	PRESENT	0
552667	551735	95063L	PARTICIPANT	\N	PRESENT	0
552668	551735	20022R	PARTICIPANT	\N	PRESENT	0
552669	551735	19719D	PARTICIPANT	\N	PRESENT	0
552670	551735	20040T	PARTICIPANT	\N	PRESENT	0
552671	551735	04059M	PARTICIPANT	\N	PRESENT	0
552672	551735	19637C	PARTICIPANT	\N	PRESENT	0
552673	551735	14249W	PARTICIPANT	\N	PRESENT	0
552674	551735	11097X	PARTICIPANT	\N	PRESENT	0
552675	551735	20090E	PARTICIPANT	\N	PRESENT	0
552676	551735	08010L	PARTICIPANT	\N	PRESENT	0
552677	551735	11085T	PARTICIPANT	\N	PRESENT	0
552678	551735	19549D	PARTICIPANT	\N	PRESENT	0
552679	551735	04085P	PARTICIPANT	\N	PRESENT	0
552680	551735	20142Y	PARTICIPANT	\N	PRESENT	0
552681	551735	11070L	PARTICIPANT	\N	PRESENT	0
552682	551735	19479G	PARTICIPANT	\N	PRESENT	0
552683	551735	11048N	PARTICIPANT	\N	PRESENT	0
552684	551735	20140W	PARTICIPANT	\N	PRESENT	0
552685	551735	20088L	PARTICIPANT	\N	PRESENT	0
552686	551735	19782L	PARTICIPANT	\N	PRESENT	0
552687	551735	19583F	PARTICIPANT	\N	PRESENT	0
552688	551735	11053K	PARTICIPANT	\N	PRESENT	0
552689	551735	97011G	PARTICIPANT	\N	PRESENT	0
552690	551735	20080C	PARTICIPANT	\N	PRESENT	0
552691	551735	14207L	PARTICIPANT	\N	PRESENT	0
552692	551735	20132W	PARTICIPANT	\N	PRESENT	0
552693	551735	04057K	PARTICIPANT	\N	PRESENT	0
552694	551735	14257W	PARTICIPANT	\N	PRESENT	0
552695	551735	19826F	PARTICIPANT	\N	PRESENT	0
552696	551735	08034U	PARTICIPANT	\N	PRESENT	0
552697	551735	19585H	PARTICIPANT	\N	PRESENT	0
552698	551735	01025N	PARTICIPANT	\N	PRESENT	0
552699	551735	11031D	PARTICIPANT	\N	PRESENT	0
552700	551735	19705W	PARTICIPANT	\N	PRESENT	0
552701	551735	20042V	PARTICIPANT	\N	PRESENT	0
552702	551735	19421M	PARTICIPANT	\N	PRESENT	0
552703	551735	19631V	PARTICIPANT	\N	PRESENT	0
552704	551735	19671E	PARTICIPANT	\N	PRESENT	0
552705	551735	19347U	PARTICIPANT	\N	PRESENT	0
552706	551735	14021P	PARTICIPANT	\N	PRESENT	0
552707	551735	01043Q	PARTICIPANT	\N	PRESENT	0
552708	551735	17779H	PARTICIPANT	\N	PRESENT	0
552709	551735	01028R	PARTICIPANT	\N	PRESENT	0
552713	551735	19723Y	PARTICIPANT	\N	PRESENT	0
552714	551735	20094J	PARTICIPANT	\N	PRESENT	0
552715	551735	20048C	PARTICIPANT	\N	PRESENT	0
552716	551735	08012N	PARTICIPANT	\N	PRESENT	0
552717	551735	20084G	PARTICIPANT	\N	PRESENT	0
552718	551735	19820Y	PARTICIPANT	\N	PRESENT	0
552719	551735	19758L	PARTICIPANT	\N	PRESENT	0
552720	551735	11077T	PARTICIPANT	\N	PRESENT	0
552721	551735	12041X	PARTICIPANT	\N	PRESENT	0
552722	551735	11033F	PARTICIPANT	\N	PRESENT	0
552723	551735	20100N	PARTICIPANT	\N	PRESENT	0
552724	551735	20128B	PARTICIPANT	\N	PRESENT	0
542402	539690	20042V	PARTICIPANT	\N	PRESENT	0
542407	539690	14105F	PARTICIPANT	\N	PRESENT	1
542414	539690	04042C	PRESIDENT	0	PRESENT	0
542418	539690	14267Y	PARTICIPANT	\N	PRESENT	0
542422	539690	11027H	PARTICIPANT	\N	PRESENT	0
542425	539690	98018T	PARTICIPANT	\N	PRESENT	1
542429	539690	01024M	PARTICIPANT	\N	PRESENT	0
542432	539690	14249W	PARTICIPANT	\N	PRESENT	0
542433	539690	17023S	PARTICIPANT	\N	PRESENT	0
542435	539690	04035D	PARTICIPANT	\N	PRESENT	1
542438	539690	19347U	PARTICIPANT	\N	PRESENT	0
542440	539690	08056B	PARTICIPANT	\N	PRESENT	0
542441	539690	19565D	PARTICIPANT	\N	PRESENT	1
542445	539690	11064N	PARTICIPANT	\N	PRESENT	1
542449	539690	20072C	PARTICIPANT	\N	PRESENT	0
542450	539690	20128B	PARTICIPANT	\N	PRESENT	0
542451	539690	16685X	PARTICIPANT	\N	PRESENT	1
542452	539690	14059S	PARTICIPANT	\N	PRESENT	0
542453	539690	08047A	PARTICIPANT	\N	PRESENT	0
542454	539690	14193X	PARTICIPANT	\N	PRESENT	0
542455	539690	19443T	PARTICIPANT	\N	PRESENT	0
542456	539690	19421M	PARTICIPANT	\N	PRESENT	1
542457	539690	01058X	PARTICIPANT	\N	PRESENT	0
542458	539690	01062T	PARTICIPANT	\N	PRESENT	0
542459	539690	20064C	PARTICIPANT	\N	PRESENT	0
542460	539690	11066Q	PARTICIPANT	\N	PRESENT	0
544830	542935	18193Q	PARTICIPANT	\N	PRESENT	0
544831	542935	19820Y	PARTICIPANT	\N	PRESENT	0
544832	542935	14249W	PARTICIPANT	\N	PRESENT	0
544833	542935	14195A	PARTICIPANT	\N	PRESENT	0
544834	542828	17737W	PARTICIPANT	\N	PRESENT	0
544835	542935	11012A	PARTICIPANT	\N	PRESENT	0
544836	542935	19717B	PARTICIPANT	\N	PRESENT	0
544837	542935	20072C	PARTICIPANT	\N	PRESENT	0
544838	542935	20132W	PARTICIPANT	\N	PRESENT	0
544839	542935	19715Y	PARTICIPANT	\N	PRESENT	0
544840	542935	19758L	PARTICIPANT	\N	PRESENT	0
544841	542935	11056N	PARTICIPANT	\N	PRESENT	0
544842	542935	19593H	PARTICIPANT	\N	PRESENT	0
544843	542935	19651A	PARTICIPANT	\N	PRESENT	0
544844	542935	19866P	PARTICIPANT	\N	PRESENT	0
544845	542935	14042U	PARTICIPANT	\N	PRESENT	0
544846	542935	14083S	PARTICIPANT	\N	PRESENT	0
544847	542935	01024M	PARTICIPANT	\N	PRESENT	0
544848	542935	20090E	PARTICIPANT	\N	PRESENT	0
544849	542935	20062A	PARTICIPANT	\N	PRESENT	0
544850	542935	20024T	PARTICIPANT	\N	PRESENT	0
544851	542935	14071N	PARTICIPANT	\N	PRESENT	0
544852	542935	20086J	PARTICIPANT	\N	PRESENT	0
544853	542935	19467C	PARTICIPANT	\N	PRESENT	0
544854	542935	20056C	PARTICIPANT	\N	PRESENT	0
544855	542935	19954N	PARTICIPANT	\N	PRESENT	0
544828	542935	14026U	PARTICIPANT	\N	PRESENT	0
544829	542935	11067R	PARTICIPANT	\N	PRESENT	0
544856	542935	14033T	PARTICIPANT	\N	PRESENT	0
544857	542935	19581D	PARTICIPANT	\N	PRESENT	0
544858	542935	20082E	PARTICIPANT	\N	PRESENT	0
544859	542935	14257W	PARTICIPANT	\N	PRESENT	0
544860	542935	19747H	PARTICIPANT	\N	PRESENT	0
544861	542935	19689Q	PARTICIPANT	\N	PRESENT	0
544862	542935	14107H	PARTICIPANT	\N	PRESENT	0
544863	542935	14030Q	PARTICIPANT	\N	PRESENT	0
544864	542935	14179A	PARTICIPANT	\N	PRESENT	0
544865	542935	14123H	PARTICIPANT	\N	PRESENT	0
544866	542935	20134Y	PARTICIPANT	\N	PRESENT	0
544867	542935	20174H	PARTICIPANT	\N	PRESENT	0
544871	542935	20026V	PARTICIPANT	\N	PRESENT	0
544872	542935	14147R	PARTICIPANT	\N	PRESENT	0
544873	542935	19479G	PARTICIPANT	\N	PRESENT	0
544874	542935	01043Q	PARTICIPANT	\N	PRESENT	0
544875	542935	19387D	PARTICIPANT	\N	PRESENT	0
544906	542936	14073Q	PARTICIPANT	\N	PRESENT	0
544907	542936	08012N	PARTICIPANT	\N	PRESENT	0
544908	542936	11043H	PARTICIPANT	\N	PRESENT	0
544909	542936	19585H	PARTICIPANT	\N	PRESENT	0
544910	542936	20134Y	PARTICIPANT	\N	PRESENT	0
544911	542936	20174H	PARTICIPANT	\N	PRESENT	0
544912	542936	19387D	PARTICIPANT	\N	PRESENT	0
544913	542936	19758L	PARTICIPANT	\N	PRESENT	0
544914	542936	17023S	PARTICIPANT	\N	PRESENT	0
544915	542936	14237S	PARTICIPANT	\N	PRESENT	0
544916	542936	20026V	PARTICIPANT	\N	PRESENT	0
544917	542936	20142Y	PARTICIPANT	\N	PRESENT	0
544918	542936	20132W	PARTICIPANT	\N	PRESENT	0
544919	542936	20024T	PARTICIPANT	\N	PRESENT	0
544920	542936	19593H	PARTICIPANT	\N	PRESENT	0
544921	542936	19349W	PARTICIPANT	\N	PRESENT	0
544922	542936	20056C	PARTICIPANT	\N	PRESENT	0
544923	542936	11012A	PARTICIPANT	\N	PRESENT	0
545515	545514	11048N	PARTICIPANT	\N	PRESENT	0
545517	545516	11048N	PARTICIPANT	\N	PRESENT	0
545519	545518	04086Q	PARTICIPANT	\N	PRESENT	0
545521	545520	11048N	PARTICIPANT	\N	PRESENT	0
545522	545520	08011M	PARTICIPANT	\N	PRESENT	0
545524	545523	11048N	PARTICIPANT	\N	PRESENT	0
545525	545523	08011M	PARTICIPANT	\N	PRESENT	0
545556	545555	11048N	PARTICIPANT	\N	PRESENT	0
545557	545555	08011M	PARTICIPANT	\N	PRESENT	0
545559	545558	19711U	PARTICIPANT	\N	PRESENT	0
544904	542936	11045K	PARTICIPANT	\N	PRESENT	0
544905	542936	20112S	PARTICIPANT	\N	PRESENT	0
545561	545560	19711U	PARTICIPANT	\N	PRESENT	0
546022	534870	08012N	PARTICIPANT	\N	EXCUSE	0
547498	543173	20100N	PARTICIPANT	\N	PRESENT	0
549001	548814	19631V	PARTICIPANT	\N	EXCUSE	0
549002	548814	11010L	PARTICIPANT	\N	EXCUSE	0
549017	548967	19679N	PARTICIPANT	\N	PRESENT	0
549018	548967	18193Q	PARTICIPANT	\N	PRESENT	0
549147	547778	14069U	PARTICIPANT	\N	PRESENT	1
549148	547778	19581D	PARTICIPANT	\N	PRESENT	1
549215	547148	07029T	PARTICIPANT	\N	PRESENT	0
549216	547148	19762G	PARTICIPANT	\N	PRESENT	0
549217	547148	19741B	PARTICIPANT	\N	PRESENT	1
549218	547148	20116W	PARTICIPANT	\N	PRESENT	1
549219	547148	11040E	PARTICIPANT	\N	PRESENT	1
549220	547148	19647E	PARTICIPANT	\N	PRESENT	1
549221	547148	01057W	PARTICIPANT	\N	PRESENT	1
549222	547148	14121F	PARTICIPANT	\N	PRESENT	1
549223	547148	99004R	PARTICIPANT	\N	PRESENT	1
549224	547148	20126Y	PARTICIPANT	\N	PRESENT	1
549225	547148	19711U	PARTICIPANT	\N	PRESENT	1
549226	547148	12016W	PARTICIPANT	\N	PRESENT	1
549229	547148	19671E	PARTICIPANT	\N	PRESENT	1
549230	547148	19349W	PARTICIPANT	\N	PRESENT	1
549231	547148	19479G	PARTICIPANT	\N	PRESENT	1
549232	547148	14173T	PARTICIPANT	\N	PRESENT	1
549252	547148	11053K	PARTICIPANT	\N	PRESENT	0
549283	549282	19701S	PARTICIPANT	\N	PRESENT	0
549284	549282	19745F	PARTICIPANT	\N	PRESENT	0
549285	549282	19637C	PARTICIPANT	\N	PRESENT	0
549286	549282	19549D	PARTICIPANT	\N	PRESENT	0
549287	549282	19820Y	PARTICIPANT	\N	PRESENT	0
549288	549282	19251M	PARTICIPANT	\N	PRESENT	0
549289	549282	19826F	PARTICIPANT	\N	PRESENT	0
549290	549282	20136B	PARTICIPANT	\N	PRESENT	0
549292	549291	19701S	PARTICIPANT	\N	PRESENT	0
549293	549291	19826F	PARTICIPANT	\N	PRESENT	0
549294	549291	20136B	PARTICIPANT	\N	PRESENT	0
549295	549291	19637C	PARTICIPANT	\N	PRESENT	0
549296	549291	20120S	PARTICIPANT	\N	PRESENT	0
549297	549291	19251M	PARTICIPANT	\N	PRESENT	0
549298	549291	19745F	PARTICIPANT	\N	PRESENT	0
549299	549291	19387D	PARTICIPANT	\N	PRESENT	0
549301	549300	19701S	PARTICIPANT	\N	PRESENT	0
549302	549300	19826F	PARTICIPANT	\N	PRESENT	0
549303	549300	20136B	PARTICIPANT	\N	PRESENT	0
549304	549300	20120S	PARTICIPANT	\N	PRESENT	0
549305	549300	19637C	PARTICIPANT	\N	PRESENT	0
549306	549300	19387D	PARTICIPANT	\N	PRESENT	0
549307	549300	19251M	PARTICIPANT	\N	PRESENT	0
549314	545500	20106U	PARTICIPANT	\N	EXCUSE	0
550867	545942	01058X	PARTICIPANT	\N	PRESENT	0
550870	545942	19503N	PARTICIPANT	\N	PRESENT	0
550871	545942	14221J	PARTICIPANT	\N	PRESENT	0
550872	545942	20128B	PARTICIPANT	\N	PRESENT	0
550874	545942	19735D	PARTICIPANT	\N	PRESENT	0
562349	559720	19798U	PARTICIPANT	\N	PRESENT	1
562350	559721	19715Y	PARTICIPANT	\N	PRESENT	1
562351	559721	19703U	PARTICIPANT	\N	PRESENT	1
562352	559721	14217N	PARTICIPANT	\N	PRESENT	1
562353	559721	20130U	PARTICIPANT	\N	PRESENT	1
562659	562573	14026U	PARTICIPANT	\N	PRESENT	1
562660	562573	19717B	PARTICIPANT	\N	PRESENT	1
562670	562579	19717B	PARTICIPANT	\N	PRESENT	1
562671	562579	14026U	PARTICIPANT	\N	PRESENT	1
562672	562579	20130U	PARTICIPANT	\N	PRESENT	1
562694	561762	11053K	PARTICIPANT	\N	PRESENT	0
563896	561981	14147R	PARTICIPANT	\N	PRESENT	1
566451	566450	11027H	PARTICIPANT	\N	PRESENT	1
564180	561981	20074E	PARTICIPANT	\N	EXCUSE	0
566449	566448	99004R	PARTICIPANT	\N	PRESENT	0
566452	566450	19709B	PARTICIPANT	\N	PRESENT	1
566457	566456	20044X	PARTICIPANT	\N	PRESENT	0
566458	566456	08009T	PARTICIPANT	\N	PRESENT	0
566459	562046	14189C	PARTICIPANT	\N	PRESENT	0
566460	562046	20024T	PARTICIPANT	\N	PRESENT	0
566461	562046	20116W	PARTICIPANT	\N	PRESENT	0
566462	562046	20042V	PARTICIPANT	\N	PRESENT	0
566463	562046	14083S	PARTICIPANT	\N	PRESENT	0
566464	562046	11053K	PARTICIPANT	\N	PRESENT	0
566465	562046	17229F	PARTICIPANT	\N	PRESENT	0
566466	562046	14179A	PARTICIPANT	\N	PRESENT	0
566467	562046	11048N	PARTICIPANT	\N	PRESENT	0
566468	562046	20052X	PARTICIPANT	\N	PRESENT	0
566469	562046	01048V	PARTICIPANT	\N	PRESENT	0
566470	562046	20056C	PARTICIPANT	\N	PRESENT	0
566471	562046	19671E	PARTICIPANT	\N	PRESENT	0
566472	562046	11097X	PARTICIPANT	\N	PRESENT	0
566474	566473	20070A	PARTICIPANT	\N	PRESENT	0
566476	566475	20070A	PARTICIPANT	\N	PRESENT	0
566477	566475	11110B	PARTICIPANT	\N	PRESENT	0
566479	566478	11048N	PARTICIPANT	\N	PRESENT	0
566481	566480	19545Y	PARTICIPANT	\N	PRESENT	0
566482	566480	19689Q	PARTICIPANT	\N	PRESENT	0
566484	566483	14225N	PARTICIPANT	\N	PRESENT	0
566485	566483	01057W	PARTICIPANT	\N	PRESENT	0
566487	566486	01057W	PARTICIPANT	\N	PRESENT	0
566488	566486	14225N	PARTICIPANT	\N	PRESENT	0
566490	566489	19545Y	PARTICIPANT	\N	PRESENT	0
566491	566489	19689Q	PARTICIPANT	\N	PRESENT	0
566493	566492	19667J	PARTICIPANT	\N	PRESENT	0
566494	566492	11040E	PARTICIPANT	\N	PRESENT	0
566496	566495	20050V	PARTICIPANT	\N	PRESENT	0
566499	566497	19367Y	PARTICIPANT	\N	PRESENT	0
566500	566497	14213J	PARTICIPANT	\N	PRESENT	0
566501	566497	19691J	PARTICIPANT	\N	PRESENT	0
566502	566497	19553Y	PARTICIPANT	\N	PRESENT	0
566503	566497	11067R	PARTICIPANT	\N	PRESENT	0
566504	566497	20130U	PARTICIPANT	\N	PRESENT	0
566505	566497	19798U	PARTICIPANT	\N	PRESENT	0
566506	566498	19367Y	PARTICIPANT	\N	PRESENT	0
566507	566498	14213J	PARTICIPANT	\N	PRESENT	0
566508	566498	20130U	PARTICIPANT	\N	PRESENT	0
566509	566498	11067R	PARTICIPANT	\N	PRESENT	0
567666	566438	18193Q	PARTICIPANT	\N	PRESENT	0
567667	566438	19649G	PARTICIPANT	\N	PRESENT	0
567668	566438	19760E	PARTICIPANT	\N	PRESENT	0
567669	566438	11031D	PARTICIPANT	\N	PRESENT	0
567670	566438	20142Y	PARTICIPANT	\N	PRESENT	0
567671	566438	20130U	PARTICIPANT	\N	PRESENT	0
567672	566438	11012A	PARTICIPANT	\N	PRESENT	0
567673	566438	14071N	PARTICIPANT	\N	PRESENT	0
567674	566438	01024M	PARTICIPANT	\N	PRESENT	0
567675	566438	19697Q	PARTICIPANT	\N	PRESENT	0
567676	566438	19599P	PARTICIPANT	\N	PRESENT	0
567677	566438	19631V	PARTICIPANT	\N	PRESENT	0
567678	566438	19569H	PARTICIPANT	\N	PRESENT	0
567679	566438	19629C	PARTICIPANT	\N	PRESENT	0
567680	566438	19681G	PARTICIPANT	\N	PRESENT	0
567681	566438	11064N	PARTICIPANT	\N	PRESENT	0
567682	566438	11097X	PARTICIPANT	\N	PRESENT	0
567683	566438	19415P	PARTICIPANT	\N	PRESENT	0
567684	566438	20126Y	PARTICIPANT	\N	PRESENT	0
567685	566438	97011G	PARTICIPANT	\N	PRESENT	0
567686	566438	14147R	PARTICIPANT	\N	PRESENT	0
567687	566438	20108W	PARTICIPANT	\N	PRESENT	0
567689	566438	11067R	PARTICIPANT	\N	PRESENT	0
567690	566438	19413M	PARTICIPANT	\N	PRESENT	0
567691	566438	14217N	PARTICIPANT	\N	PRESENT	0
567692	566438	20082E	PARTICIPANT	\N	PRESENT	0
567664	566438	19719D	PARTICIPANT	\N	PRESENT	0
567665	566438	19669L	PARTICIPANT	\N	PRESENT	0
567693	566438	07029T	PARTICIPANT	\N	PRESENT	0
567694	566438	18083K	PARTICIPANT	\N	PRESENT	0
567695	566438	19683J	PARTICIPANT	\N	PRESENT	0
567696	566438	14229S	PARTICIPANT	\N	PRESENT	0
567697	566438	14021P	PARTICIPANT	\N	PRESENT	0
567698	566438	11115U	PARTICIPANT	\N	PRESENT	0
567699	566438	19399H	PARTICIPANT	\N	PRESENT	0
567700	566438	04043D	PARTICIPANT	\N	PRESENT	0
567701	566438	14059S	PARTICIPANT	\N	PRESENT	0
567713	566438	20124W	PARTICIPANT	\N	PRESENT	0
567707	566438	04092N	PARTICIPANT	\N	PRESENT	0
567708	566438	19503N	PARTICIPANT	\N	PRESENT	0
567714	566017	14053L	PARTICIPANT	\N	PRESENT	0
567715	566017	11026G	PARTICIPANT	\N	PRESENT	0
567716	566017	04047H	PRESIDENT	0	PRESENT	0
567717	566017	19673G	PARTICIPANT	\N	PRESENT	0
567718	566017	01028R	PARTICIPANT	\N	PRESENT	0
567719	566017	05008E	PARTICIPANT	\N	PRESENT	0
567720	566017	95063L	PARTICIPANT	\N	PRESENT	0
567721	566017	20108W	PARTICIPANT	\N	PRESENT	0
567722	566017	14041T	PARTICIPANT	\N	PRESENT	0
567723	566017	14147R	PARTICIPANT	\N	PRESENT	0
567724	566017	14215L	PARTICIPANT	\N	PRESENT	0
567725	566017	04008A	PARTICIPANT	\N	PRESENT	0
567726	566017	20128B	PARTICIPANT	\N	PRESENT	0
567727	566017	08018U	PARTICIPANT	\N	PRESENT	0
567728	566017	11072N	PARTICIPANT	\N	PRESENT	0
567729	566438	14031R	PARTICIPANT	\N	PRESENT	0
567730	566438	20114U	PARTICIPANT	\N	PRESENT	0
567733	566523	14026U	PARTICIPANT	\N	PRESENT	1
567734	566523	19717B	PARTICIPANT	\N	PRESENT	1
567735	566524	19717B	PARTICIPANT	\N	PRESENT	1
567736	566524	14026U	PARTICIPANT	\N	PRESENT	1
567738	567737	14053L	PARTICIPANT	\N	PRESENT	0
567739	567737	04008A	PARTICIPANT	\N	PRESENT	0
567740	567737	07004J	PARTICIPANT	\N	PRESENT	0
567741	567737	11026G	PARTICIPANT	\N	PRESENT	0
567743	567742	14053L	PARTICIPANT	\N	PRESENT	0
567744	567742	04008A	PARTICIPANT	\N	PRESENT	0
567745	567742	11026G	PARTICIPANT	\N	PRESENT	0
567746	567742	19581D	PARTICIPANT	\N	PRESENT	0
567747	567742	19593H	PARTICIPANT	\N	PRESENT	0
567749	567748	14053L	PARTICIPANT	\N	PRESENT	0
567750	567748	14041T	PARTICIPANT	\N	PRESENT	0
567751	567748	07004J	PARTICIPANT	\N	PRESENT	0
567752	567748	04085P	PARTICIPANT	\N	PRESENT	0
567753	567748	20128B	PARTICIPANT	\N	PRESENT	0
567754	567748	11026G	PARTICIPANT	\N	PRESENT	0
567755	567748	04008A	PARTICIPANT	\N	PRESENT	0
567756	567748	14267Y	PARTICIPANT	\N	PRESENT	0
567758	567757	14053L	PARTICIPANT	\N	PRESENT	0
567759	567757	04008A	PARTICIPANT	\N	PRESENT	0
567760	567757	20128B	PARTICIPANT	\N	PRESENT	0
567761	567757	07004J	PARTICIPANT	\N	PRESENT	0
567763	567762	14053L	PARTICIPANT	\N	PRESENT	0
567764	567762	07004J	PARTICIPANT	\N	PRESENT	0
567765	567762	11026G	PARTICIPANT	\N	PRESENT	0
567766	567762	14267Y	PARTICIPANT	\N	PRESENT	0
567768	567767	14053L	PARTICIPANT	\N	PRESENT	0
567769	567767	11026G	PARTICIPANT	\N	PRESENT	0
567953	567951	20124W	PARTICIPANT	\N	PRESENT	0
567954	567951	19667J	PARTICIPANT	\N	PRESENT	0
567955	567951	19467C	PARTICIPANT	\N	PRESENT	0
567956	567951	20062A	PARTICIPANT	\N	PRESENT	0
567984	566018	14089Y	PARTICIPANT	\N	PRESENT	1
568006	566181	18083K	PARTICIPANT	\N	PRESENT	1
568007	566181	20134Y	PARTICIPANT	\N	PRESENT	1
568008	566181	20124W	PARTICIPANT	\N	PRESENT	1
568009	566181	14123H	PARTICIPANT	\N	PRESENT	1
568010	566181	08017T	PRESIDENT	0	PRESENT	0
568011	566181	04057K	PARTICIPANT	\N	PRESENT	0
568012	566181	20098N	PARTICIPANT	\N	PRESENT	1
568013	566181	19527W	PARTICIPANT	\N	EXCUSE	0
568014	566181	20106U	PARTICIPANT	\N	PRESENT	1
568016	566181	14030Q	PARTICIPANT	\N	EXCUSE	0
542961	542960	19725B	PARTICIPANT	\N	PRESENT	0
542962	542960	14026U	PARTICIPANT	\N	PRESENT	0
542963	542956	19725B	PARTICIPANT	\N	PRESENT	0
542964	542956	14026U	PARTICIPANT	\N	PRESENT	0
542971	542808	10006L	PARTICIPANT	\N	EXCUSE	0
542974	542973	14147R	PARTICIPANT	\N	PRESENT	0
545716	545715	99004R	PARTICIPANT	\N	PRESENT	0
545736	545735	04086Q	PARTICIPANT	\N	PRESENT	0
548036	548035	20092G	PARTICIPANT	\N	PRESENT	0
548037	548035	14041T	PARTICIPANT	\N	PRESENT	0
548049	548047	19515S	PRESIDENT	0	PRESENT	0
548050	548047	19575F	PARTICIPANT	\N	PRESENT	0
548053	548047	14030Q	PARTICIPANT	\N	PRESENT	0
548056	548047	14105F	PARTICIPANT	\N	PRESENT	0
548059	548047	19467C	PARTICIPANT	\N	PRESENT	0
548062	548047	19251M	PARTICIPANT	\N	PRESENT	0
548063	548047	20092G	PARTICIPANT	\N	PRESENT	0
548064	548047	19760E	PARTICIPANT	\N	PRESENT	0
548067	548047	19717B	PARTICIPANT	\N	PRESENT	0
548069	548047	19697Q	PARTICIPANT	\N	PRESENT	0
548070	548047	20134Y	PARTICIPANT	\N	PRESENT	0
548074	548047	19695N	PARTICIPANT	\N	PRESENT	0
548076	548047	20082E	PARTICIPANT	\N	PRESENT	0
548078	548047	14083S	PARTICIPANT	\N	PRESENT	0
548086	548047	19651A	PARTICIPANT	\N	PRESENT	0
548091	548047	19954N	PARTICIPANT	\N	PRESENT	0
548094	548047	11056N	PARTICIPANT	\N	PRESENT	0
548096	548047	14259Y	PARTICIPANT	\N	PRESENT	0
548097	548047	99004R	PARTICIPANT	\N	PRESENT	0
548098	548047	20044X	PARTICIPANT	\N	PRESENT	0
548099	548047	19703U	PARTICIPANT	\N	PRESENT	0
548100	548047	19479G	PARTICIPANT	\N	PRESENT	0
548105	548047	19643A	PARTICIPANT	\N	PRESENT	0
548121	548047	08060W	PARTICIPANT	\N	EXCUSE	0
548122	548047	19545Y	PARTICIPANT	\N	EXCUSE	0
548124	548047	14026U	PARTICIPANT	\N	EXCUSE	0
548125	548047	08015R	PARTICIPANT	\N	EXCUSE	0
548240	548047	20132W	PARTICIPANT	\N	PRESENT	0
548710	545416	12041X	PARTICIPANT	\N	PRESENT	0
548711	545416	19673G	PARTICIPANT	\N	PRESENT	0
548712	545416	19749K	PARTICIPANT	\N	PRESENT	0
548713	545416	19758L	PARTICIPANT	\N	PRESENT	0
548714	545416	19329S	PARTICIPANT	\N	PRESENT	0
548715	545416	11012A	PARTICIPANT	\N	PRESENT	0
548716	545416	19717B	PARTICIPANT	\N	PRESENT	0
548717	545416	19543W	PARTICIPANT	\N	PRESENT	0
548718	545416	07004J	PARTICIPANT	\N	PRESENT	0
548719	545416	14231L	PARTICIPANT	\N	PRESENT	0
548720	545416	19695N	PARTICIPANT	\N	PRESENT	0
548721	545416	14215L	PARTICIPANT	\N	PRESENT	0
548722	545416	14021P	PARTICIPANT	\N	PRESENT	0
548723	545416	19647E	PARTICIPANT	\N	PRESENT	0
548724	545416	19649G	PARTICIPANT	\N	PRESENT	0
548725	545416	20124W	PARTICIPANT	\N	PRESENT	0
548726	545416	20074E	PARTICIPANT	\N	PRESENT	0
548727	545416	20112S	PARTICIPANT	\N	PRESENT	0
548728	545416	04047H	PARTICIPANT	\N	PRESENT	0
548729	545416	19565D	PARTICIPANT	\N	PRESENT	0
548730	545416	19711U	PARTICIPANT	\N	PRESENT	0
548731	545416	20108W	PARTICIPANT	\N	PRESENT	0
548732	545416	19447X	PARTICIPANT	\N	PRESENT	0
548733	545416	14109K	PARTICIPANT	\N	PRESENT	0
548734	545416	20130U	PARTICIPANT	\N	PRESENT	0
548735	545416	19367Y	PARTICIPANT	\N	PRESENT	0
548737	545416	19741B	PARTICIPANT	\N	PRESENT	0
548739	545416	14053L	PARTICIPANT	\N	PRESENT	0
548740	545416	19667J	PARTICIPANT	\N	PRESENT	0
548741	545416	19533U	PARTICIPANT	\N	PRESENT	0
548743	545416	20122U	PARTICIPANT	\N	PRESENT	0
548747	545416	14055N	PARTICIPANT	\N	PRESENT	0
548753	545416	19629C	PARTICIPANT	\N	PRESENT	0
548778	545416	05008E	PARTICIPANT	\N	PRESENT	0
548782	545416	11083R	PARTICIPANT	\N	PRESENT	0
548786	545416	01028R	PARTICIPANT	\N	PRESENT	0
548787	545416	04034C	PARTICIPANT	\N	PRESENT	0
548813	545416	04059M	PARTICIPANT	\N	PRESENT	0
548817	545416	11033F	PARTICIPANT	\N	PRESENT	0
548818	545416	99004R	PARTICIPANT	\N	PRESENT	0
548819	545416	19687N	PARTICIPANT	\N	PRESENT	0
548820	545416	11031D	PARTICIPANT	\N	PRESENT	0
548821	545416	11077T	PARTICIPANT	\N	PRESENT	0
548845	545416	19689Q	PARTICIPANT	\N	PRESENT	0
548857	545416	11045K	PARTICIPANT	\N	PRESENT	0
548858	545416	20034V	PARTICIPANT	\N	PRESENT	0
548859	545416	20114U	PARTICIPANT	\N	PRESENT	0
548860	545416	19643A	PARTICIPANT	\N	PRESENT	0
548863	545416	19651A	PARTICIPANT	\N	PRESENT	0
548924	545417	19673G	PARTICIPANT	\N	PRESENT	0
548925	545417	19749K	PARTICIPANT	\N	PRESENT	0
548926	545417	20074E	PARTICIPANT	\N	PRESENT	0
548927	545417	14041T	PARTICIPANT	\N	PRESENT	0
548928	545417	07004J	PARTICIPANT	\N	PRESENT	0
548929	545417	04059M	PARTICIPANT	\N	PRESENT	0
548930	545417	19643A	PARTICIPANT	\N	PRESENT	0
548931	545417	19629C	PARTICIPANT	\N	PRESENT	0
548932	545417	19543W	PARTICIPANT	\N	PRESENT	0
548933	545417	14231L	PARTICIPANT	\N	PRESENT	0
548934	545417	19593H	PARTICIPANT	\N	PRESENT	0
548935	545417	19695N	PARTICIPANT	\N	PRESENT	0
548936	545417	20112S	PARTICIPANT	\N	PRESENT	0
548937	545417	19649G	PARTICIPANT	\N	PRESENT	0
548938	545417	19651A	PARTICIPANT	\N	PRESENT	0
548939	545417	19697Q	PARTICIPANT	\N	PRESENT	0
548940	545417	14215L	PARTICIPANT	\N	PRESENT	0
548941	545417	19367Y	PARTICIPANT	\N	PRESENT	0
548942	545417	14109K	PARTICIPANT	\N	PRESENT	0
548943	545417	19447X	PARTICIPANT	\N	PRESENT	0
548944	545417	99004R	PARTICIPANT	\N	PRESENT	0
548945	545417	20034V	PARTICIPANT	\N	PRESENT	0
548946	545417	19667J	PARTICIPANT	\N	PRESENT	0
548947	545417	19711U	PARTICIPANT	\N	PRESENT	0
548948	545417	11033F	PARTICIPANT	\N	PRESENT	0
548949	545417	11012A	PARTICIPANT	\N	PRESENT	0
548950	545417	19717B	PARTICIPANT	\N	PRESENT	0
548951	545417	19741B	PARTICIPANT	\N	PRESENT	0
548952	545417	20108W	PARTICIPANT	\N	PRESENT	0
548953	545417	20122U	PARTICIPANT	\N	PRESENT	0
548954	545417	20124W	PARTICIPANT	\N	PRESENT	0
548955	545417	01028R	PARTICIPANT	\N	PRESENT	0
548956	545417	14055N	PARTICIPANT	\N	PRESENT	0
548957	545417	19687N	PARTICIPANT	\N	PRESENT	0
548961	545417	14021P	PARTICIPANT	\N	PRESENT	0
548959	545417	11031D	PARTICIPANT	\N	PRESENT	0
548960	545417	04085P	PARTICIPANT	\N	PRESENT	0
548922	545417	11045K	PARTICIPANT	\N	PRESENT	0
548923	545417	04047H	PARTICIPANT	\N	PRESENT	0
548962	545417	19689Q	PARTICIPANT	\N	PRESENT	0
548963	545417	05008E	PARTICIPANT	\N	PRESENT	0
548964	545417	19647E	PARTICIPANT	\N	PRESENT	0
548965	545417	07033P	PARTICIPANT	\N	PRESENT	0
548966	545417	20130U	PARTICIPANT	\N	PRESENT	0
548968	545417	19533U	PARTICIPANT	\N	PRESENT	0
548969	545417	14251Q	PARTICIPANT	\N	PRESENT	0
548976	545417	11085T	PARTICIPANT	\N	PRESENT	0
549330	545942	01048V	PARTICIPANT	\N	PRESENT	0
549331	545942	19693L	PARTICIPANT	\N	EXCUSE	0
552725	551735	19697Q	PARTICIPANT	\N	PRESENT	0
552726	551735	20174H	PARTICIPANT	\N	PRESENT	0
552727	551735	20116W	PARTICIPANT	\N	PRESENT	0
552728	551735	11012A	PARTICIPANT	\N	PRESENT	0
552729	551735	20146D	PARTICIPANT	\N	PRESENT	0
552730	551735	11083R	PARTICIPANT	\N	PRESENT	0
552731	551735	18193Q	PARTICIPANT	\N	PRESENT	0
552732	551735	17589D	PARTICIPANT	\N	PRESENT	0
552733	551735	11027H	PARTICIPANT	\N	PRESENT	0
552734	551735	14033T	PARTICIPANT	\N	PRESENT	0
552735	551735	08017T	PARTICIPANT	\N	PRESENT	0
552736	551735	14001X	PARTICIPANT	\N	PRESENT	0
552737	551735	17965H	PARTICIPANT	\N	PRESENT	0
552738	551735	19575F	PARTICIPANT	\N	PRESENT	0
552739	551735	11110B	PARTICIPANT	\N	PRESENT	0
552740	551735	20018V	PARTICIPANT	\N	PRESENT	0
552741	551735	20034V	PARTICIPANT	\N	PRESENT	0
552742	551735	19711U	PARTICIPANT	\N	PRESENT	0
552743	551735	14097Y	PARTICIPANT	\N	PRESENT	0
552744	551735	17637T	PARTICIPANT	\N	PRESENT	0
552745	551735	01058X	PARTICIPANT	\N	PRESENT	0
552746	551735	14229S	PARTICIPANT	\N	PRESENT	0
552747	551735	20050V	PARTICIPANT	\N	PRESENT	0
552748	551735	19687N	PARTICIPANT	\N	PRESENT	0
552749	551735	08069G	PARTICIPANT	\N	PRESENT	0
552750	551735	14071N	PARTICIPANT	\N	PRESENT	0
552751	551735	04092N	PARTICIPANT	\N	PRESENT	0
552752	551735	19467C	PARTICIPANT	\N	PRESENT	0
552753	551735	14169X	PARTICIPANT	\N	PRESENT	0
552754	551735	20070A	PARTICIPANT	\N	PRESENT	0
552755	551735	19739H	PARTICIPANT	\N	PRESENT	0
552756	551735	19954N	PARTICIPANT	\N	PRESENT	0
552757	551735	19611R	PARTICIPANT	\N	PRESENT	0
552758	551735	14179A	PARTICIPANT	\N	PRESENT	0
552759	551735	19591F	PARTICIPANT	\N	PRESENT	0
552760	551735	20096L	PARTICIPANT	\N	PRESENT	0
552761	551735	04033B	PARTICIPANT	\N	PRESENT	0
552762	551735	19415P	PARTICIPANT	\N	PRESENT	0
552763	551735	19735D	PARTICIPANT	\N	PRESENT	0
552764	551735	20028X	PARTICIPANT	\N	PRESENT	0
552765	551735	01024M	PARTICIPANT	\N	PRESENT	0
552766	551735	19619A	PARTICIPANT	\N	PRESENT	0
552767	551735	19745F	PARTICIPANT	\N	PRESENT	0
552768	551735	19713W	PARTICIPANT	\N	PRESENT	0
552770	551735	19515S	PARTICIPANT	\N	PRESENT	0
552772	551735	20038A	PARTICIPANT	\N	PRESENT	0
552833	551735	14030Q	PARTICIPANT	\N	PRESENT	0
552775	551735	14205J	PARTICIPANT	\N	PRESENT	0
552776	551735	19699S	PARTICIPANT	\N	PRESENT	0
552778	551735	19369B	PARTICIPANT	\N	PRESENT	0
552781	551735	11045K	PARTICIPANT	\N	PRESENT	0
552782	551735	20172F	PARTICIPANT	\N	PRESENT	0
552784	551735	14327T	PARTICIPANT	\N	PRESENT	0
552785	551735	19533U	PARTICIPANT	\N	PRESENT	0
552787	551735	05008E	PARTICIPANT	\N	PRESENT	0
552789	551735	14213J	PARTICIPANT	\N	PRESENT	0
552790	551735	19762G	PARTICIPANT	\N	PRESENT	0
552791	551735	14357A	PARTICIPANT	\N	PRESENT	0
552792	551735	19621T	PARTICIPANT	\N	PRESENT	0
552793	551735	19383Y	PARTICIPANT	\N	PRESENT	0
552794	551735	14059S	PARTICIPANT	\N	PRESENT	0
552795	551735	20138D	PARTICIPANT	\N	PRESENT	0
552796	551735	19768N	PARTICIPANT	\N	PRESENT	0
552797	551735	19399H	PARTICIPANT	\N	PRESENT	0
552798	551735	19447X	PARTICIPANT	\N	PRESENT	0
552799	551735	19966S	PARTICIPANT	\N	PRESENT	0
552867	551735	14069U	PARTICIPANT	\N	PRESENT	0
552801	551735	14219Q	PARTICIPANT	\N	PRESENT	0
552802	551735	19573D	PARTICIPANT	\N	PRESENT	0
552806	551735	20044X	PARTICIPANT	\N	PRESENT	0
552804	551735	20066E	PARTICIPANT	\N	PRESENT	0
552805	551735	08047A	PARTICIPANT	\N	PRESENT	0
552807	551735	19709B	PARTICIPANT	\N	PRESENT	0
552808	551735	20060X	PARTICIPANT	\N	PRESENT	0
552809	551735	14133K	PARTICIPANT	\N	PRESENT	0
552810	551735	20126Y	PARTICIPANT	\N	PRESENT	0
552811	551735	14329V	PARTICIPANT	\N	PRESENT	0
552812	551735	14187A	PARTICIPANT	\N	PRESENT	0
552813	551735	04043D	PARTICIPANT	\N	PRESENT	0
552814	551735	19685L	PARTICIPANT	\N	PRESENT	0
552815	551735	14189C	PARTICIPANT	\N	PRESENT	0
552832	551735	19441R	PARTICIPANT	\N	PRESENT	0
552823	551735	14083S	PARTICIPANT	\N	PRESENT	0
552820	551735	14089Y	PARTICIPANT	\N	PRESENT	0
552827	551735	19747H	PARTICIPANT	\N	PRESENT	0
552828	551735	20062A	PARTICIPANT	\N	PRESENT	0
552834	551735	19507S	PARTICIPANT	\N	PRESENT	0
552850	551735	19715Y	PARTICIPANT	\N	PRESENT	0
552858	551735	19349W	PARTICIPANT	\N	PRESENT	0
552866	551543	19399H	PARTICIPANT	\N	PRESENT	0
552868	551735	08009T	PARTICIPANT	\N	PRESENT	0
552869	551735	19673G	PARTICIPANT	\N	PRESENT	0
553090	551736	86034E	PARTICIPANT	\N	PRESENT	0
553092	553091	11026G	PARTICIPANT	\N	PRESENT	0
553093	553091	11027H	PARTICIPANT	\N	PRESENT	0
553094	553091	19709B	PARTICIPANT	\N	PRESENT	0
553095	553091	14041T	PARTICIPANT	\N	PRESENT	0
553096	553091	04034C	PARTICIPANT	\N	PRESENT	0
553097	553091	08017T	PARTICIPANT	\N	PRESENT	0
553098	553091	19647E	PARTICIPANT	\N	PRESENT	0
553099	553091	14255U	PARTICIPANT	\N	PRESENT	0
553100	553091	20174H	PARTICIPANT	\N	PRESENT	0
553101	553091	08018U	PARTICIPANT	\N	PRESENT	0
553102	553091	14147R	PARTICIPANT	\N	PRESENT	0
553103	553091	14215L	PARTICIPANT	\N	PRESENT	0
553105	553104	10006L	PARTICIPANT	\N	PRESENT	0
553106	553104	04043D	PARTICIPANT	\N	PRESENT	0
553107	553104	14215L	PARTICIPANT	\N	PRESENT	0
553108	553104	14255U	PARTICIPANT	\N	PRESENT	0
553109	553104	08017T	PARTICIPANT	\N	PRESENT	0
553110	553104	08018U	PARTICIPANT	\N	PRESENT	0
553111	553104	20174H	PARTICIPANT	\N	PRESENT	0
553112	553104	14211G	PARTICIPANT	\N	PRESENT	0
553113	553104	14331P	PARTICIPANT	\N	PRESENT	0
553114	553104	11026G	PARTICIPANT	\N	PRESENT	0
553115	553104	14041T	PARTICIPANT	\N	PRESENT	0
553116	553104	14147R	PARTICIPANT	\N	PRESENT	0
553117	551736	19643A	PARTICIPANT	\N	PRESENT	0
553118	551736	11056N	PARTICIPANT	\N	PRESENT	0
553119	551736	20070A	PARTICIPANT	\N	PRESENT	0
553120	551736	14097Y	PARTICIPANT	\N	PRESENT	0
553121	551736	19649G	PARTICIPANT	\N	PRESENT	0
553122	551736	19503N	PARTICIPANT	\N	PRESENT	0
553123	551736	20046A	PARTICIPANT	\N	PRESENT	0
553124	551736	11045K	PARTICIPANT	\N	PRESENT	0
553125	551736	20060X	PARTICIPANT	\N	PRESENT	0
553126	551736	14225N	PARTICIPANT	\N	PRESENT	0
553127	551736	95063L	PARTICIPANT	\N	PRESENT	0
553128	551736	19651A	PARTICIPANT	\N	PRESENT	0
553129	551736	20174H	PARTICIPANT	\N	PRESENT	0
553130	551736	19782L	PARTICIPANT	\N	PRESENT	0
553131	551736	19697Q	PARTICIPANT	\N	PRESENT	0
553132	551736	14001X	PARTICIPANT	\N	PRESENT	0
553133	551736	19489J	PARTICIPANT	\N	PRESENT	0
553134	551736	19349W	PARTICIPANT	\N	PRESENT	0
553135	551736	14195A	PARTICIPANT	\N	PRESENT	0
553136	551736	19583F	PARTICIPANT	\N	PRESENT	0
553137	551736	14189C	PARTICIPANT	\N	PRESENT	0
553138	551736	19739H	PARTICIPANT	\N	PRESENT	0
553139	551736	19569H	PARTICIPANT	\N	PRESENT	0
553140	551736	20144B	PARTICIPANT	\N	PRESENT	0
553141	551736	20050V	PARTICIPANT	\N	PRESENT	0
553142	551736	04057K	PARTICIPANT	\N	PRESENT	0
553143	551736	11012A	PARTICIPANT	\N	PRESENT	0
553144	551736	20100N	PARTICIPANT	\N	PRESENT	0
553145	551736	19820Y	PARTICIPANT	\N	PRESENT	0
553146	551736	20048C	PARTICIPANT	\N	PRESENT	0
553147	551736	08061X	PARTICIPANT	\N	PRESENT	0
553148	551736	08009T	PARTICIPANT	\N	PRESENT	0
553149	551736	11085T	PARTICIPANT	\N	PRESENT	0
553150	551736	04085P	PARTICIPANT	\N	PRESENT	0
553151	551736	19565D	PARTICIPANT	\N	PRESENT	0
553152	551736	19758L	PARTICIPANT	\N	PRESENT	0
553153	551736	14021P	PARTICIPANT	\N	PRESENT	0
553154	551736	19549D	PARTICIPANT	\N	PRESENT	0
553155	551736	11033F	PARTICIPANT	\N	PRESENT	0
553156	551736	20142Y	PARTICIPANT	\N	PRESENT	0
553157	551736	20018V	PARTICIPANT	\N	PRESENT	0
553158	551736	19413M	PARTICIPANT	\N	PRESENT	0
553159	551736	11067R	PARTICIPANT	\N	PRESENT	0
553160	551736	12028B	PARTICIPANT	\N	PRESENT	0
545575	545574	20118Y	PARTICIPANT	\N	PRESENT	0
545599	545393	19643A	PARTICIPANT	\N	PRESENT	1
545600	545393	20180F	PARTICIPANT	\N	PRESENT	1
545601	545393	19611R	PARTICIPANT	\N	PRESENT	0
545602	545393	19593H	PARTICIPANT	\N	PRESENT	0
545609	545395	19611R	PARTICIPANT	\N	PRESENT	0
545604	545394	20180F	PARTICIPANT	\N	PRESENT	1
545605	545394	20172F	PARTICIPANT	\N	PRESENT	1
545606	545394	19611R	PARTICIPANT	\N	PRESENT	0
545607	545394	19593H	PARTICIPANT	\N	PRESENT	0
545608	545395	19593H	PARTICIPANT	\N	PRESENT	0
545621	542796	19631V	PARTICIPANT	\N	EXCUSE	0
546416	545160	19729F	PARTICIPANT	\N	PRESENT	0
546417	545160	14111D	PARTICIPANT	\N	PRESENT	0
546418	545160	20074E	PARTICIPANT	\N	PRESENT	0
546419	545160	04047H	PRESIDENT	0	PRESENT	0
546420	545160	19749K	PARTICIPANT	\N	PRESENT	0
546421	545160	19673G	PARTICIPANT	\N	PRESENT	0
546443	545160	14053L	PARTICIPANT	\N	PRESENT	0
546444	545160	10015M	PARTICIPANT	\N	PRESENT	0
546445	545160	14147R	PARTICIPANT	\N	PRESENT	0
546446	545160	19447X	PARTICIPANT	\N	PRESENT	0
546459	545160	19954N	PARTICIPANT	\N	PRESENT	0
546460	545160	07004J	PARTICIPANT	\N	PRESENT	0
546461	545160	14215L	PARTICIPANT	\N	PRESENT	0
546462	545160	19649G	PARTICIPANT	\N	PRESENT	0
546463	545160	05008E	PARTICIPANT	\N	PRESENT	0
546464	545160	11085T	PARTICIPANT	\N	PRESENT	0
546465	545160	14001X	PARTICIPANT	\N	PRESENT	0
546466	545160	14179A	PARTICIPANT	\N	PRESENT	0
546467	545160	20114U	PARTICIPANT	\N	PRESENT	0
546468	545160	11072N	PARTICIPANT	\N	PRESENT	0
546469	545160	01028R	PARTICIPANT	\N	PRESENT	0
546470	545160	14231L	PARTICIPANT	\N	PRESENT	0
546471	545160	19489J	PARTICIPANT	\N	PRESENT	0
546472	545160	14021P	PARTICIPANT	\N	PRESENT	0
546475	545330	20130U	PARTICIPANT	\N	PRESENT	1
546476	545330	19697Q	PARTICIPANT	\N	PRESENT	1
546477	545330	04057K	PARTICIPANT	\N	PRESENT	1
546478	545330	04092N	PARTICIPANT	0	PRESENT	0
546479	545330	08045X	PARTICIPANT	\N	PRESENT	1
546480	545330	20040T	PARTICIPANT	\N	PRESENT	0
546481	545330	19301E	PARTICIPANT	\N	PRESENT	1
546482	545330	19715Y	PARTICIPANT	\N	PRESENT	1
546483	545330	19691J	PARTICIPANT	\N	PRESENT	1
546484	545330	19717B	PARTICIPANT	\N	PRESENT	0
546485	545330	20172F	PARTICIPANT	\N	PRESENT	1
546486	545330	19723Y	PARTICIPANT	\N	PRESENT	1
546487	545330	19553Y	PARTICIPANT	\N	PRESENT	1
546488	545330	11031D	PARTICIPANT	\N	PRESENT	1
546489	545330	11103C	PARTICIPANT	\N	PRESENT	1
546490	545330	14042U	PARTICIPANT	\N	PRESENT	1
546491	545330	19657G	PARTICIPANT	\N	PRESENT	1
546492	545330	04043D	PARTICIPANT	\N	PRESENT	1
546493	545330	10006L	PRESIDENT	0	PRESENT	0
546494	545330	19760E	PARTICIPANT	\N	PRESENT	1
546495	545330	19591F	PARTICIPANT	\N	PRESENT	1
546498	545160	11056N	PARTICIPANT	\N	PRESENT	0
546500	546497	19503N	PARTICIPANT	\N	PRESENT	0
546501	546497	19820Y	PARTICIPANT	\N	PRESENT	0
546502	546497	19619A	PARTICIPANT	\N	PRESENT	0
546503	546497	14357A	PARTICIPANT	\N	PRESENT	0
546504	546497	20092G	PARTICIPANT	\N	PRESENT	0
546505	546499	19503N	PARTICIPANT	\N	PRESENT	0
546506	546499	19820Y	PARTICIPANT	\N	PRESENT	0
546507	546499	19619A	PARTICIPANT	\N	PRESENT	0
546509	546499	14357A	PARTICIPANT	\N	PRESENT	0
546510	546499	20092G	PARTICIPANT	\N	PRESENT	0
546511	546499	20070A	PARTICIPANT	\N	PRESENT	0
546512	546499	19711U	PARTICIPANT	\N	PRESENT	0
546513	545160	14259Y	PARTICIPANT	\N	PRESENT	0
546515	545331	20130U	PARTICIPANT	\N	PRESENT	1
546516	545331	19697Q	PARTICIPANT	\N	PRESENT	1
546517	545331	04057K	PARTICIPANT	\N	PRESENT	1
546518	545331	04092N	PARTICIPANT	0	PRESENT	0
546519	545331	08045X	PARTICIPANT	\N	PRESENT	1
546520	545331	20040T	PARTICIPANT	\N	PRESENT	0
546521	545331	19301E	PARTICIPANT	\N	PRESENT	1
546522	545331	19715Y	PARTICIPANT	\N	PRESENT	1
546523	545331	19691J	PARTICIPANT	\N	PRESENT	1
546524	545331	19717B	PARTICIPANT	\N	PRESENT	0
546525	545331	20172F	PARTICIPANT	\N	PRESENT	1
546526	545331	19723Y	PARTICIPANT	\N	PRESENT	1
546527	545331	19553Y	PARTICIPANT	\N	PRESENT	1
546528	545331	11031D	PARTICIPANT	\N	PRESENT	1
546529	545331	11103C	PARTICIPANT	\N	PRESENT	1
546530	545331	14042U	PARTICIPANT	\N	EXCUSE	0
546531	545331	19657G	PARTICIPANT	\N	PRESENT	1
546532	545331	04043D	PARTICIPANT	\N	PRESENT	0
546533	545331	10006L	PRESIDENT	0	PRESENT	0
546534	545331	19760E	PARTICIPANT	\N	PRESENT	1
546535	545331	19591F	PARTICIPANT	\N	PRESENT	1
546541	544625	14331P	PARTICIPANT	\N	PRESENT	0
546542	544625	11048N	PARTICIPANT	\N	PRESENT	0
546543	544625	19711U	PARTICIPANT	\N	PRESENT	0
546544	544625	19687N	PARTICIPANT	\N	PRESENT	0
546545	544625	01057W	PARTICIPANT	\N	PRESENT	0
546546	544625	20080C	PARTICIPANT	\N	PRESENT	0
546547	544625	20050V	PARTICIPANT	\N	PRESENT	0
546548	544625	11074Q	PARTICIPANT	\N	PRESENT	0
546549	544625	20044X	PARTICIPANT	\N	PRESENT	0
546550	544625	19671E	PARTICIPANT	\N	PRESENT	0
546551	544625	04086Q	PARTICIPANT	\N	PRESENT	0
546552	544625	11040E	PARTICIPANT	\N	PRESENT	0
546553	544625	19349W	PARTICIPANT	\N	PRESENT	0
546554	544625	19741B	PARTICIPANT	\N	PRESENT	0
546555	544625	14253S	PARTICIPANT	\N	PRESENT	0
546556	544625	20116W	PARTICIPANT	\N	PRESENT	0
546561	544625	14189C	PARTICIPANT	\N	PRESENT	0
546562	544625	11053K	PARTICIPANT	\N	PRESENT	0
546564	544625	14225N	PRESIDENT	0	PRESENT	0
546565	544625	20022R	PARTICIPANT	\N	PRESENT	0
563721	561980	20128B	PARTICIPANT	\N	PRESENT	1
563722	561980	14179A	PARTICIPANT	\N	PRESENT	1
563725	561980	11072N	PARTICIPANT	\N	PRESENT	1
563728	561980	19749K	PARTICIPANT	\N	PRESENT	1
563796	563785	19760E	PARTICIPANT	\N	PRESENT	0
563794	563785	19695N	PARTICIPANT	\N	PRESENT	0
563795	563785	19697Q	PARTICIPANT	\N	PRESENT	0
563799	563785	20126Y	PARTICIPANT	\N	PRESENT	0
563800	563785	14105F	PARTICIPANT	\N	PRESENT	0
563802	563785	19467C	PARTICIPANT	\N	PRESENT	0
563803	563785	14083S	PARTICIPANT	\N	PRESENT	0
563804	563785	19515S	PRESIDENT	0	PRESENT	0
563805	563785	14357A	PARTICIPANT	\N	PRESENT	0
563822	548265	19735D	PARTICIPANT	\N	EXCUSE	0
563892	563891	14053L	PARTICIPANT	\N	PRESENT	0
563893	563891	14299H	PARTICIPANT	\N	PRESENT	0
563895	563891	11066Q	PARTICIPANT	\N	PRESENT	0
563911	548265	19533U	PARTICIPANT	\N	PRESENT	0
563912	548265	20128B	PARTICIPANT	\N	EXCUSE	0
564097	564096	14147R	PARTICIPANT	\N	PRESENT	0
564098	564096	19543W	PARTICIPANT	\N	PRESENT	0
564103	564102	14147R	PARTICIPANT	\N	PRESENT	0
564110	559959	14259Y	PRESIDENT	0	PRESENT	0
564111	559959	11097X	PARTICIPANT	\N	PRESENT	0
564347	564346	14193X	PARTICIPANT	\N	PRESENT	0
564348	564346	11027H	PARTICIPANT	\N	PRESENT	0
564349	564346	11066Q	PARTICIPANT	\N	PRESENT	0
564351	564350	14193X	PARTICIPANT	\N	PRESENT	0
564352	564350	11027H	PARTICIPANT	\N	PRESENT	0
564355	564354	14053L	PARTICIPANT	\N	PRESENT	0
564356	564354	04008A	PARTICIPANT	\N	PRESENT	0
564650	564649	14147R	PARTICIPANT	\N	PRESENT	0
565185	565123	19719D	PARTICIPANT	\N	PRESENT	0
565186	565123	17589D	PARTICIPANT	\N	PRESENT	0
565187	565174	19719D	PARTICIPANT	\N	PRESENT	0
565188	565174	14109K	PARTICIPANT	\N	PRESENT	0
565189	565123	19637C	PARTICIPANT	\N	PRESENT	0
565269	564887	19717B	PARTICIPANT	\N	PRESENT	1
565274	564887	14026U	PARTICIPANT	\N	PRESENT	1
565276	564887	14217N	PARTICIPANT	\N	PRESENT	1
565494	564255	19467C	PARTICIPANT	\N	PRESENT	1
565495	564255	20174H	PARTICIPANT	\N	PRESENT	1
566446	566445	05008E	PARTICIPANT	\N	PRESENT	0
566447	566445	11053K	PARTICIPANT	\N	PRESENT	0
567120	566454	19443T	PARTICIPANT	\N	PRESENT	1
567121	566454	12041X	PARTICIPANT	\N	PRESENT	1
567122	566454	19565D	PARTICIPANT	\N	PRESENT	0
567123	566454	20072C	PARTICIPANT	\N	PRESENT	1
567124	566454	04034C	PARTICIPANT	\N	PRESENT	0
567125	566454	01058X	PARTICIPANT	\N	PRESENT	1
567126	566454	11027H	PARTICIPANT	\N	PRESENT	1
567127	566454	04042C	PRESIDENT	0	PRESENT	0
567128	566454	11066Q	PARTICIPANT	\N	PRESENT	0
567129	566454	08056B	PARTICIPANT	\N	PRESENT	1
567130	566454	19421M	PARTICIPANT	\N	PRESENT	0
567131	566454	19347U	PARTICIPANT	\N	PRESENT	1
567132	566454	97011G	PARTICIPANT	\N	PRESENT	0
567133	566454	08061X	PARTICIPANT	\N	PRESENT	0
567134	566454	14249W	PARTICIPANT	\N	PRESENT	1
567135	566454	08047A	PARTICIPANT	\N	PRESENT	0
567136	566454	14059S	PARTICIPANT	\N	PRESENT	0
567137	566454	14097Y	PARTICIPANT	\N	PRESENT	1
567138	566454	04035D	PARTICIPANT	\N	PRESENT	1
567139	566454	14133K	PARTICIPANT	\N	PRESENT	0
567140	566454	01062T	PARTICIPANT	\N	PRESENT	0
567141	566454	08069G	PARTICIPANT	\N	PRESENT	0
567142	566454	20042V	PARTICIPANT	\N	PRESENT	0
567143	566454	01024M	PARTICIPANT	\N	PRESENT	0
567144	566454	19721W	PARTICIPANT	\N	PRESENT	1
567145	566454	14105F	PARTICIPANT	\N	PRESENT	0
567146	566454	14267Y	PARTICIPANT	\N	PRESENT	0
567147	566454	11064N	PARTICIPANT	\N	PRESENT	0
567148	566454	11083R	PARTICIPANT	\N	PRESENT	1
567149	566454	14211G	PARTICIPANT	\N	PRESENT	0
567150	566454	17023S	PARTICIPANT	\N	PRESENT	0
567166	566454	16685X	PARTICIPANT	\N	EXCUSE	0
567167	566454	11054L	PARTICIPANT	\N	EXCUSE	0
567201	566436	19585H	PARTICIPANT	\N	PRESENT	0
567202	566436	19479G	PARTICIPANT	\N	PRESENT	0
567203	566436	19745F	PARTICIPANT	\N	PRESENT	0
567204	566436	19569H	PARTICIPANT	\N	PRESENT	0
567205	566436	19695N	PARTICIPANT	\N	PRESENT	0
567206	566436	14231L	PARTICIPANT	\N	PRESENT	0
567207	566436	20144B	PARTICIPANT	\N	PRESENT	0
567208	566436	14109K	PARTICIPANT	\N	PRESENT	0
567209	566436	18193Q	PARTICIPANT	\N	PRESENT	0
567211	566436	19760E	PARTICIPANT	\N	PRESENT	0
567212	566436	19565D	PARTICIPANT	\N	PRESENT	0
567213	566436	19693L	PARTICIPANT	\N	PRESENT	0
567214	566436	01028R	PARTICIPANT	\N	PRESENT	0
567215	566436	14211G	PARTICIPANT	\N	PRESENT	0
567216	566436	19711U	PARTICIPANT	\N	PRESENT	0
567217	566436	14225N	PARTICIPANT	\N	PRESENT	0
567218	566436	04059M	PARTICIPANT	\N	PRESENT	0
567219	566436	19599P	PARTICIPANT	\N	PRESENT	0
567220	566436	99004R	PARTICIPANT	\N	PRESENT	0
567221	566436	14229S	PARTICIPANT	\N	PRESENT	0
567222	566436	08010L	PARTICIPANT	\N	PRESENT	0
567223	566436	14257W	PARTICIPANT	\N	PRESENT	0
567224	566436	11045K	PARTICIPANT	\N	PRESENT	0
567225	566436	20076G	PARTICIPANT	\N	PRESENT	0
567226	566436	14021P	PARTICIPANT	\N	PRESENT	0
567227	566436	01058X	PARTICIPANT	\N	PRESENT	0
567228	566436	19649G	PARTICIPANT	\N	PRESENT	0
567229	566436	01048V	PARTICIPANT	\N	PRESENT	0
567230	566436	19549D	PARTICIPANT	\N	PRESENT	0
567231	566436	14223L	PARTICIPANT	\N	PRESENT	0
567232	566436	20080C	PARTICIPANT	\N	PRESENT	0
567233	566436	19515S	PARTICIPANT	\N	PRESENT	0
567234	566436	11041F	PARTICIPANT	\N	PRESENT	0
567235	566436	19683J	PARTICIPANT	\N	PRESENT	0
567236	566436	19527W	PARTICIPANT	\N	PRESENT	0
567237	566436	20074E	PARTICIPANT	\N	PRESENT	0
567238	566436	19333N	PARTICIPANT	\N	PRESENT	0
567239	566436	01057W	PARTICIPANT	\N	PRESENT	0
567240	566436	19725B	PARTICIPANT	\N	PRESENT	0
567241	566436	19631V	PARTICIPANT	\N	PRESENT	0
567242	566436	12028B	PARTICIPANT	\N	PRESENT	0
567243	566436	17367Q	PARTICIPANT	\N	PRESENT	0
567244	566436	20082E	PARTICIPANT	\N	PRESENT	0
567245	566436	14123H	PARTICIPANT	\N	PRESENT	0
567246	566436	19503N	PARTICIPANT	\N	PRESENT	0
567247	566436	08017T	PARTICIPANT	\N	PRESENT	0
567248	566436	04043D	PARTICIPANT	\N	PRESENT	0
567249	566436	20070A	PARTICIPANT	\N	PRESENT	0
567250	566436	04092N	PARTICIPANT	\N	PRESENT	0
567251	566436	19413M	PARTICIPANT	\N	PRESENT	0
567252	566436	19747H	PARTICIPANT	\N	PRESENT	0
567253	566436	11097X	PARTICIPANT	\N	PRESENT	0
567254	566436	20018V	PARTICIPANT	\N	PRESENT	0
567255	566436	19415P	PARTICIPANT	\N	PRESENT	0
567256	566436	11031D	PARTICIPANT	\N	PRESENT	0
567257	566436	14187A	PARTICIPANT	\N	PRESENT	0
567258	566436	12041X	PARTICIPANT	\N	PRESENT	0
567259	566436	04085P	PARTICIPANT	\N	PRESENT	0
567260	566436	20112S	PARTICIPANT	\N	PRESENT	0
567261	566436	19593H	PARTICIPANT	\N	PRESENT	0
567262	566436	04033B	PARTICIPANT	\N	PRESENT	0
567263	566436	20102Q	PARTICIPANT	\N	PRESENT	0
567264	566436	14169X	PARTICIPANT	\N	PRESENT	0
567265	566436	11033F	PARTICIPANT	\N	PRESENT	0
567266	566436	11080N	PARTICIPANT	\N	PRESENT	0
567267	566436	11048N	PARTICIPANT	\N	PRESENT	0
567268	566436	11090Q	PARTICIPANT	\N	PRESENT	0
567269	566436	20092G	PARTICIPANT	\N	PRESENT	0
567270	566436	20142Y	PARTICIPANT	\N	PRESENT	0
567271	566436	20036X	PARTICIPANT	\N	PRESENT	0
567272	566436	19798U	PARTICIPANT	\N	PRESENT	0
567273	566436	20130U	PARTICIPANT	\N	PRESENT	0
567274	566436	19533U	PARTICIPANT	\N	PRESENT	0
567275	566436	19647E	PARTICIPANT	\N	PRESENT	0
567276	566436	14105F	PARTICIPANT	\N	PRESENT	0
567277	566436	20118Y	PARTICIPANT	\N	PRESENT	0
567278	566436	20100N	PARTICIPANT	\N	PRESENT	0
567279	566436	18083K	PARTICIPANT	\N	PRESENT	0
567280	566436	14259Y	PARTICIPANT	\N	PRESENT	0
567281	566436	20038A	PARTICIPANT	\N	PRESENT	0
567282	566436	08061X	PARTICIPANT	\N	PRESENT	0
567283	566436	04045F	PARTICIPANT	\N	PRESENT	0
545734	534870	04070G	PARTICIPANT	\N	EXCUSE	0
547993	543174	19521Q	PARTICIPANT	\N	PRESENT	1
547994	543174	12016W	PARTICIPANT	\N	PRESENT	1
547995	543174	19563B	PARTICIPANT	\N	PRESENT	1
547996	543174	19711U	PARTICIPANT	\N	PRESENT	1
547997	543174	19441R	PARTICIPANT	\N	PRESENT	1
547998	543174	11026G	PARTICIPANT	\N	PRESENT	1
547999	543174	14033T	PARTICIPANT	\N	PRESENT	1
548000	543174	20100N	PARTICIPANT	\N	PRESENT	0
548001	543174	20094J	PARTICIPANT	\N	PRESENT	0
548002	543174	19701S	PARTICIPANT	\N	PRESENT	0
548003	543174	14089Y	PARTICIPANT	\N	PRESENT	0
548004	543174	14357A	PARTICIPANT	\N	PRESENT	0
548005	543174	11083R	PARTICIPANT	\N	PRESENT	0
548006	543174	14097Y	PARTICIPANT	\N	PRESENT	0
548007	543174	04070G	PARTICIPANT	\N	PRESENT	0
548008	543174	14001X	PARTICIPANT	\N	PRESENT	0
548009	543174	04057K	PARTICIPANT	\N	PRESENT	0
548010	543174	14331P	PRESIDENT	0	PRESENT	0
548011	543174	10015M	PARTICIPANT	\N	PRESENT	0
548012	543174	14073Q	PARTICIPANT	\N	PRESENT	0
549414	545418	19611R	PARTICIPANT	\N	PRESENT	0
549415	545418	20106U	PARTICIPANT	\N	PRESENT	0
549416	545418	20128B	PARTICIPANT	\N	PRESENT	0
549417	545418	11012A	PARTICIPANT	\N	PRESENT	0
549418	545418	20132W	PARTICIPANT	\N	PRESENT	0
549419	545418	19719D	PARTICIPANT	\N	PRESENT	0
549420	545418	14179A	PARTICIPANT	\N	PRESENT	0
549421	545418	11097X	PARTICIPANT	\N	PRESENT	0
549422	545418	14231L	PARTICIPANT	\N	PRESENT	0
549423	545418	11043H	PARTICIPANT	\N	PRESENT	0
549424	545418	20052X	PARTICIPANT	\N	PRESENT	0
549425	545418	19621T	PARTICIPANT	\N	PRESENT	0
549426	545418	14073Q	PARTICIPANT	\N	PRESENT	0
549427	545418	11090Q	PARTICIPANT	\N	PRESENT	0
549428	545418	14030Q	PARTICIPANT	\N	PRESENT	0
549429	545418	19749K	PARTICIPANT	\N	PRESENT	0
549430	545418	19725B	PARTICIPANT	\N	PRESENT	0
549431	545418	19631V	PARTICIPANT	\N	PRESENT	0
549432	545418	20152B	PARTICIPANT	\N	PRESENT	0
549433	545418	19649G	PARTICIPANT	\N	PRESENT	0
549434	545418	17965H	PARTICIPANT	\N	PRESENT	0
549435	545418	19703U	PARTICIPANT	\N	PRESENT	0
549436	545418	14229S	PARTICIPANT	\N	PRESENT	0
549437	545418	14147R	PARTICIPANT	\N	PRESENT	0
549438	545418	18193Q	PARTICIPANT	\N	PRESENT	0
549439	545418	20130U	PARTICIPANT	\N	PRESENT	0
549440	545418	19954N	PARTICIPANT	\N	PRESENT	0
549441	545418	11033F	PARTICIPANT	\N	PRESENT	0
549442	545418	20092G	PARTICIPANT	\N	PRESENT	0
549443	545418	20038A	PARTICIPANT	\N	PRESENT	0
549444	545418	20026V	PARTICIPANT	\N	PRESENT	0
549445	545418	14033T	PARTICIPANT	\N	PRESENT	0
549446	545418	19399H	PARTICIPANT	\N	PRESENT	0
549447	545418	20054A	PARTICIPANT	\N	PRESENT	0
549448	545418	11048N	PARTICIPANT	\N	PRESENT	0
549412	545418	11045K	PARTICIPANT	\N	PRESENT	0
549413	545418	19533U	PARTICIPANT	\N	PRESENT	0
549449	545418	04033B	PARTICIPANT	\N	PRESENT	0
549450	545418	11104D	PARTICIPANT	\N	PRESENT	0
549451	545418	08012N	PARTICIPANT	\N	PRESENT	0
549452	545418	19421M	PARTICIPANT	\N	PRESENT	0
549453	545418	19503N	PARTICIPANT	\N	PRESENT	0
549454	545418	14257W	PARTICIPANT	\N	PRESENT	0
549455	545418	20080C	PARTICIPANT	\N	PRESENT	0
549456	545418	19643A	PARTICIPANT	\N	PRESENT	0
549457	545418	19575F	PARTICIPANT	\N	PRESENT	0
549458	545418	20032T	PARTICIPANT	\N	PRESENT	0
549459	545418	19593H	PARTICIPANT	\N	PRESENT	0
549460	545418	14026U	PARTICIPANT	\N	PRESENT	0
549461	545418	19651A	PARTICIPANT	\N	PRESENT	0
549462	545418	19563B	PARTICIPANT	\N	PRESENT	0
549463	545418	08034U	PARTICIPANT	\N	PRESENT	0
549464	545418	19553Y	PARTICIPANT	\N	PRESENT	0
549465	545418	20066E	PARTICIPANT	\N	PRESENT	0
549466	545418	20180F	PARTICIPANT	\N	PRESENT	0
549467	545418	14219Q	PARTICIPANT	\N	PRESENT	0
549468	545418	20056C	PARTICIPANT	\N	PRESENT	0
549469	545418	10015M	PARTICIPANT	\N	PRESENT	0
549470	545418	19673G	PARTICIPANT	\N	PRESENT	0
549471	545418	11056N	PARTICIPANT	\N	PRESENT	0
549472	545418	19747H	PARTICIPANT	\N	PRESENT	0
549473	545418	04085P	PARTICIPANT	\N	PRESENT	0
549474	545418	19760E	PARTICIPANT	\N	PRESENT	0
549475	545418	19695N	PARTICIPANT	\N	PRESENT	0
549476	545418	20090E	PARTICIPANT	\N	PRESENT	0
549477	545418	19758L	PARTICIPANT	\N	PRESENT	0
549478	545418	20064C	PARTICIPANT	\N	PRESENT	0
549479	545418	14217N	PARTICIPANT	\N	PRESENT	0
549480	545418	14069U	PARTICIPANT	\N	PRESENT	0
549481	545418	19489J	PARTICIPANT	\N	PRESENT	0
549482	545418	05008E	PARTICIPANT	\N	PRESENT	0
549483	545418	14215L	PARTICIPANT	\N	PRESENT	0
549484	545418	19447X	PARTICIPANT	\N	PRESENT	0
549485	545418	19735D	PARTICIPANT	\N	PRESENT	0
549486	545418	19369B	PARTICIPANT	\N	PRESENT	0
549487	545418	20070A	PARTICIPANT	\N	PRESENT	0
549488	545418	20044X	PARTICIPANT	\N	PRESENT	0
549489	545418	14109K	PARTICIPANT	\N	PRESENT	0
549490	545418	19527W	PARTICIPANT	\N	PRESENT	0
549491	545418	20028X	PARTICIPANT	\N	PRESENT	0
549492	545418	20098N	PARTICIPANT	\N	PRESENT	0
549493	545418	14123H	PARTICIPANT	\N	PRESENT	0
549494	545418	19693L	PARTICIPANT	\N	PRESENT	0
549495	545418	19573D	PARTICIPANT	\N	PRESENT	0
549496	545418	20124W	PARTICIPANT	\N	PRESENT	0
549497	545418	14357A	PARTICIPANT	\N	PRESENT	0
549498	545418	19531S	PARTICIPANT	\N	PRESENT	0
549499	545418	19691J	PARTICIPANT	\N	PRESENT	0
549500	545418	20114U	PARTICIPANT	\N	PRESENT	0
549501	545418	20086J	PARTICIPANT	\N	PRESENT	0
549502	545418	14055N	PARTICIPANT	\N	PRESENT	0
549503	545418	14187A	PARTICIPANT	\N	PRESENT	0
549504	545418	18083K	PARTICIPANT	\N	PRESENT	0
549505	545418	01028R	PARTICIPANT	\N	PRESENT	0
549506	545418	20022R	PARTICIPANT	\N	PRESENT	0
549507	545418	19383Y	PARTICIPANT	\N	PRESENT	0
549508	545418	19507S	PARTICIPANT	\N	PRESENT	0
549509	545418	20082E	PARTICIPANT	\N	PRESENT	0
550816	550815	20076G	PARTICIPANT	\N	PRESENT	0
550817	550815	19713W	PARTICIPANT	\N	PRESENT	1
550818	550815	14205J	PARTICIPANT	\N	PRESENT	0
550819	550815	14038Y	PARTICIPANT	\N	PRESENT	0
550820	550815	19563B	PARTICIPANT	\N	PRESENT	0
550821	550815	20032T	PARTICIPANT	\N	PRESENT	0
550822	550815	14033T	PARTICIPANT	\N	PRESENT	0
550823	550815	20044X	PARTICIPANT	\N	PRESENT	1
550824	550815	11097X	PARTICIPANT	\N	PRESENT	1
550825	550815	20082E	PARTICIPANT	\N	PRESENT	0
550826	550815	19723Y	PARTICIPANT	\N	PRESENT	0
550827	550815	20054A	PARTICIPANT	\N	PRESENT	1
550828	550815	04045F	PARTICIPANT	\N	PRESENT	1
550829	550815	20118Y	PARTICIPANT	\N	PRESENT	0
550830	550815	14169X	PARTICIPANT	\N	PRESENT	0
550831	550815	19575F	PARTICIPANT	\N	PRESENT	0
550832	550815	20058E	PARTICIPANT	\N	PRESENT	1
550833	550815	14179A	PARTICIPANT	\N	PRESENT	0
550834	550815	01048V	PARTICIPANT	\N	PRESENT	0
550836	550835	20094J	PARTICIPANT	\N	PRESENT	0
550837	550835	19575F	PARTICIPANT	\N	PRESENT	0
550838	550835	14257W	PARTICIPANT	\N	PRESENT	0
550839	550835	20018V	PARTICIPANT	\N	PRESENT	0
550840	550835	19637C	PARTICIPANT	\N	PRESENT	0
551199	551196	20022R	PARTICIPANT	\N	PRESENT	0
551224	551221	11074Q	PARTICIPANT	\N	PRESENT	0
551225	551221	19349W	PARTICIPANT	\N	PRESENT	0
551228	551227	11074Q	PARTICIPANT	\N	PRESENT	0
551229	551227	19349W	PARTICIPANT	\N	PRESENT	0
551241	551235	11074Q	PARTICIPANT	\N	PRESENT	0
551242	551235	19349W	PARTICIPANT	\N	PRESENT	0
551244	551243	11048N	PARTICIPANT	\N	PRESENT	0
551247	551246	11048N	PARTICIPANT	\N	PRESENT	0
551250	551249	11048N	PARTICIPANT	\N	PRESENT	0
551251	551249	14225N	PARTICIPANT	\N	PRESENT	0
551252	548814	19301E	PARTICIPANT	\N	EXCUSE	0
551255	551254	11048N	PARTICIPANT	\N	PRESENT	0
551259	551258	14253S	PARTICIPANT	\N	PRESENT	0
551272	551271	11048N	PARTICIPANT	\N	PRESENT	0
551276	551275	11048N	PARTICIPANT	\N	PRESENT	0
551277	551275	08011M	PARTICIPANT	\N	PRESENT	0
551360	551359	20086J	PARTICIPANT	\N	PRESENT	0
553163	551736	20102Q	PARTICIPANT	\N	PRESENT	0
553164	551736	19575F	PARTICIPANT	\N	PRESENT	0
553165	551736	20082E	PARTICIPANT	\N	PRESENT	0
553166	551736	01058X	PARTICIPANT	\N	PRESENT	0
553167	551736	04059M	PARTICIPANT	\N	PRESENT	0
553168	551736	99004R	PARTICIPANT	\N	PRESENT	0
553169	551736	08045X	PARTICIPANT	\N	PRESENT	0
553170	551736	20076G	PARTICIPANT	\N	PRESENT	0
553171	551736	20146D	PARTICIPANT	\N	PRESENT	0
553172	551736	14123H	PARTICIPANT	\N	PRESENT	0
553173	551736	14071N	PARTICIPANT	\N	PRESENT	0
553174	551736	19563B	PARTICIPANT	\N	PRESENT	0
553175	551736	01048V	PARTICIPANT	\N	PRESENT	0
553176	551736	19387D	PARTICIPANT	\N	PRESENT	0
553177	551736	04047H	PARTICIPANT	\N	PRESENT	0
553178	551736	19866P	PARTICIPANT	\N	PRESENT	0
553179	551736	18193Q	PARTICIPANT	\N	PRESENT	0
553180	551736	19745F	PARTICIPANT	\N	PRESENT	0
553181	551736	14169X	PARTICIPANT	\N	PRESENT	0
553182	551736	19691J	PARTICIPANT	\N	PRESENT	0
553183	551736	17229F	PARTICIPANT	\N	PRESENT	0
553184	551736	14031R	PARTICIPANT	\N	PRESENT	0
553185	551736	20072C	PARTICIPANT	\N	PRESENT	0
553186	551736	11053K	PARTICIPANT	\N	PRESENT	0
553187	551736	20116W	PARTICIPANT	\N	PRESENT	0
553188	551736	14030Q	PARTICIPANT	\N	PRESENT	0
553189	551736	14207L	PARTICIPANT	\N	PRESENT	0
553190	551736	08069G	PARTICIPANT	\N	PRESENT	0
553191	551736	20132W	PARTICIPANT	\N	PRESENT	0
553192	551736	19515S	PARTICIPANT	\N	PRESENT	0
553193	551736	19735D	PARTICIPANT	\N	PRESENT	0
553194	551736	16685X	PARTICIPANT	\N	PRESENT	0
553195	551736	19766L	PARTICIPANT	\N	PRESENT	0
553196	551736	19713W	PARTICIPANT	\N	PRESENT	0
553197	551736	20066E	PARTICIPANT	\N	PRESENT	0
553198	551736	11080N	PARTICIPANT	\N	PRESENT	0
553199	551736	19441R	PARTICIPANT	\N	PRESENT	0
553200	551736	14205J	PARTICIPANT	\N	PRESENT	0
553201	551736	20068G	PARTICIPANT	\N	PRESENT	0
553202	551736	17589D	PARTICIPANT	\N	PRESENT	0
553203	551736	14249W	PARTICIPANT	\N	PRESENT	0
553204	551736	20022R	PARTICIPANT	\N	PRESENT	0
553205	551736	19347U	PARTICIPANT	\N	PRESENT	0
553206	551736	14073Q	PARTICIPANT	\N	PRESENT	0
553207	551736	20040T	PARTICIPANT	\N	PRESENT	0
553208	551736	20038A	PARTICIPANT	\N	PRESENT	0
553209	551736	19685L	PARTICIPANT	\N	PRESENT	0
553210	551736	20052X	PARTICIPANT	\N	PRESENT	0
553211	551736	18083K	PARTICIPANT	\N	PRESENT	0
553212	551736	19335Q	PARTICIPANT	\N	PRESENT	0
553213	551736	19369B	PARTICIPANT	\N	PRESENT	0
553214	551736	19573D	PARTICIPANT	\N	PRESENT	0
553215	551736	19826F	PARTICIPANT	\N	PRESENT	0
553216	551736	19671E	PARTICIPANT	\N	PRESENT	0
553217	551736	19421M	PARTICIPANT	\N	PRESENT	0
553218	551736	19673G	PARTICIPANT	\N	PRESENT	0
553219	551736	14089Y	PARTICIPANT	\N	PRESENT	0
553220	551736	01024M	PARTICIPANT	\N	PRESENT	0
553221	551736	14215L	PARTICIPANT	\N	PRESENT	0
553223	551736	19447X	PARTICIPANT	\N	PRESENT	0
553224	551736	19415P	PARTICIPANT	\N	PRESENT	0
553225	551736	11097X	PARTICIPANT	\N	PRESENT	0
553226	551736	14038Y	PARTICIPANT	\N	PRESENT	0
553227	551736	01025N	PARTICIPANT	\N	PRESENT	0
553228	551736	19747H	PARTICIPANT	\N	PRESENT	0
553229	551736	14327T	PARTICIPANT	\N	PRESENT	0
553230	551736	19619A	PARTICIPANT	\N	PRESENT	0
553231	551736	20086J	PARTICIPANT	\N	PRESENT	0
553232	551736	01043Q	PARTICIPANT	\N	PRESENT	0
553233	551736	19333N	PARTICIPANT	\N	PRESENT	0
553234	551736	08017T	PARTICIPANT	\N	PRESENT	0
553235	551736	20044X	PARTICIPANT	\N	PRESENT	0
553236	550640	01028R	PARTICIPANT	\N	PRESENT	0
553237	551736	19467C	PARTICIPANT	\N	PRESENT	0
553239	551736	20034V	PARTICIPANT	\N	PRESENT	0
553240	553222	14041T	PARTICIPANT	\N	PRESENT	0
553241	553222	14255U	PARTICIPANT	\N	PRESENT	0
553242	553222	19741B	PARTICIPANT	\N	PRESENT	0
553243	551736	20056C	PARTICIPANT	\N	PRESENT	0
553244	553222	19954N	PARTICIPANT	\N	PRESENT	0
553245	551736	20054A	PARTICIPANT	\N	PRESENT	0
553246	551736	20090E	PARTICIPANT	\N	PRESENT	0
553247	553222	14217N	PARTICIPANT	\N	PRESENT	0
553248	551736	14253S	PARTICIPANT	\N	PRESENT	0
553249	551736	14059S	PARTICIPANT	\N	PRESENT	0
553251	551736	20136B	PARTICIPANT	\N	PRESENT	0
553252	551736	07029T	PARTICIPANT	\N	PRESENT	0
553253	551736	14329V	PARTICIPANT	\N	PRESENT	0
553254	553222	01058X	PARTICIPANT	\N	PRESENT	0
553255	551736	19383Y	PARTICIPANT	\N	PRESENT	0
553256	551736	14041T	PARTICIPANT	\N	PRESENT	0
553257	551736	14357A	PARTICIPANT	\N	PRESENT	0
553258	551736	19675J	PARTICIPANT	\N	PRESENT	0
553259	553222	18193Q	PARTICIPANT	\N	PRESENT	0
553260	551736	08047A	PARTICIPANT	\N	PRESENT	0
553261	551736	20020P	PARTICIPANT	\N	PRESENT	0
553262	551736	19762G	PARTICIPANT	\N	PRESENT	0
553263	551736	14026U	PARTICIPANT	\N	PRESENT	0
553264	551736	14147R	PARTICIPANT	\N	PRESENT	0
553265	551736	14053L	PARTICIPANT	\N	PRESENT	0
553266	551736	14187A	PARTICIPANT	\N	PRESENT	0
553267	551736	04092N	PARTICIPANT	\N	PRESENT	0
553268	551736	20172F	PARTICIPANT	\N	PRESENT	0
553269	551736	17737W	PARTICIPANT	\N	PRESENT	0
553270	551736	14229S	PARTICIPANT	\N	PRESENT	0
553271	551736	08015R	PARTICIPANT	\N	PRESENT	0
553272	551736	04033B	PARTICIPANT	\N	PRESENT	0
553273	551736	20108W	PARTICIPANT	\N	PRESENT	0
553274	551736	20062A	PARTICIPANT	\N	PRESENT	0
553275	551736	19768N	PARTICIPANT	\N	PRESENT	0
553276	551736	19657G	PARTICIPANT	\N	PRESENT	0
553277	551736	19399H	PARTICIPANT	\N	PRESENT	0
553278	551736	20024T	PARTICIPANT	\N	PRESENT	0
553279	551736	14033T	PARTICIPANT	\N	PRESENT	0
553280	551736	20098N	PARTICIPANT	\N	PRESENT	0
553281	551736	14213J	PARTICIPANT	\N	PRESENT	0
553282	551736	19443T	PARTICIPANT	\N	PRESENT	0
553283	551736	14219Q	PARTICIPANT	\N	PRESENT	0
553284	551736	05008E	PARTICIPANT	\N	PRESENT	0
553285	551736	19553Y	PARTICIPANT	\N	PRESENT	0
553287	551736	19711U	PARTICIPANT	\N	PRESENT	0
553290	551736	20026V	PARTICIPANT	\N	PRESENT	0
553291	551736	11031D	PARTICIPANT	\N	PRESENT	0
553292	551736	01060R	PARTICIPANT	\N	PRESENT	0
553293	551736	19760E	PARTICIPANT	\N	PRESENT	0
553295	551736	17637T	PARTICIPANT	\N	PRESENT	0
553297	551736	11070L	PARTICIPANT	\N	PRESENT	0
553298	551736	01057W	PARTICIPANT	\N	PRESENT	0
553306	551543	19643A	PARTICIPANT	\N	EXCUSE	0
553303	551736	20058E	PARTICIPANT	\N	PRESENT	0
553304	551736	19479G	PARTICIPANT	\N	PRESENT	0
553305	551736	20118Y	PARTICIPANT	\N	PRESENT	0
553307	551736	08034U	PARTICIPANT	\N	PRESENT	0
553308	551736	14259Y	PARTICIPANT	\N	PRESENT	0
553309	551736	20042V	PARTICIPANT	\N	PRESENT	0
553310	551736	20110Q	PARTICIPANT	\N	PRESENT	0
553315	551736	11048N	PARTICIPANT	\N	PRESENT	0
553316	551736	19507S	PARTICIPANT	\N	PRESENT	0
553317	551736	20138D	PARTICIPANT	\N	PRESENT	0
553318	551736	10006L	PARTICIPANT	\N	PRESENT	0
553319	551736	19715Y	PARTICIPANT	\N	PRESENT	0
553320	551736	14179A	PARTICIPANT	\N	PRESENT	0
553161	551736	20084G	PARTICIPANT	\N	PRESENT	0
553162	551736	20080C	PARTICIPANT	\N	PRESENT	0
553321	551736	01028R	PARTICIPANT	\N	PRESENT	0
553322	551736	14083S	PARTICIPANT	\N	PRESENT	0
553323	551736	19591F	PARTICIPANT	\N	PRESENT	0
553324	551736	14042U	PARTICIPANT	\N	PRESENT	0
553325	551736	19593H	PARTICIPANT	\N	PRESENT	0
553326	551736	19695N	PARTICIPANT	\N	PRESENT	0
553327	551736	08010L	PARTICIPANT	\N	PRESENT	0
553328	551736	19667J	PARTICIPANT	\N	PRESENT	0
553329	551736	20126Y	PARTICIPANT	\N	PRESENT	0
553330	551736	19701S	PARTICIPANT	\N	PRESENT	0
553331	551736	14231L	PARTICIPANT	\N	PRESENT	0
553332	551736	14217N	PARTICIPANT	\N	PRESENT	0
553333	551736	11066Q	PARTICIPANT	\N	PRESENT	0
553334	551736	11083R	PARTICIPANT	\N	PRESENT	0
553335	551736	20122U	PARTICIPANT	\N	PRESENT	0
553336	551736	19689Q	PARTICIPANT	\N	PRESENT	0
545420	545419	16685X	PARTICIPANT	\N	PRESENT	0
546725	546723	11109J	PARTICIPANT	\N	EXCUSE	0
546726	546723	19651A	PARTICIPANT	\N	PRESENT	1
546727	546723	14030Q	PARTICIPANT	\N	PRESENT	0
546728	546723	19643A	PARTICIPANT	\N	PRESENT	0
546729	546723	20134Y	PARTICIPANT	\N	PRESENT	0
546730	546723	07033P	PARTICIPANT	\N	PRESENT	0
546731	546723	20132W	PARTICIPANT	\N	PRESENT	0
546732	546723	20180F	PARTICIPANT	\N	PRESENT	0
546733	546723	14123H	PARTICIPANT	\N	PRESENT	0
546734	546723	20048C	PARTICIPANT	\N	PRESENT	0
546735	546723	19399H	PARTICIPANT	\N	PRESENT	0
546736	546723	20056C	PARTICIPANT	\N	PRESENT	0
546737	546723	14073Q	PARTICIPANT	\N	PRESENT	0
546738	546723	19611R	PARTICIPANT	\N	PRESENT	0
546739	546723	19699S	PARTICIPANT	\N	PRESENT	0
546740	546723	20052X	PARTICIPANT	\N	PRESENT	0
546741	546723	08012N	PARTICIPANT	\N	PRESENT	0
546742	546723	04070G	PARTICIPANT	\N	PRESENT	0
546743	546723	19593H	PARTICIPANT	\N	PRESENT	0
546744	546723	08061X	PARTICIPANT	\N	PRESENT	0
546745	546723	19533U	PARTICIPANT	\N	PRESENT	0
546746	546723	11043H	PARTICIPANT	\N	PRESENT	0
546747	546723	20026V	PARTICIPANT	\N	PRESENT	0
546748	546723	20058E	PARTICIPANT	\N	PRESENT	1
546749	546723	19527W	PARTICIPANT	\N	PRESENT	1
546750	546723	17589D	PARTICIPANT	\N	PRESENT	1
546751	546723	20124W	PARTICIPANT	\N	PRESENT	1
546752	546723	14109K	PARTICIPANT	\N	PRESENT	1
546753	546723	20098N	PARTICIPANT	\N	PRESENT	1
546754	546723	20084G	PARTICIPANT	\N	PRESENT	1
546755	546723	20152B	PARTICIPANT	\N	PRESENT	0
546805	546723	19735D	PARTICIPANT	\N	EXCUSE	0
546884	543173	14089Y	PARTICIPANT	\N	PRESENT	0
546885	543173	14207L	PARTICIPANT	\N	PRESENT	1
546886	543173	11083R	PARTICIPANT	\N	PRESENT	0
546887	543173	14026U	PARTICIPANT	\N	PRESENT	0
546888	543173	19553Y	PARTICIPANT	\N	PRESENT	1
546889	543173	19725B	PARTICIPANT	\N	PRESENT	0
546890	543173	14073Q	PARTICIPANT	\N	PRESENT	0
546891	543173	11026G	PARTICIPANT	\N	PRESENT	1
546892	543173	19441R	PARTICIPANT	\N	PRESENT	0
546893	543173	19711U	PARTICIPANT	\N	PRESENT	1
546894	543173	12016W	PARTICIPANT	\N	PRESENT	1
546895	543173	19563B	PARTICIPANT	\N	PRESENT	0
546896	543173	04070G	PARTICIPANT	\N	PRESENT	1
546897	543173	14331P	PRESIDENT	0	PRESENT	0
546898	543173	04034C	PARTICIPANT	\N	PRESENT	1
546899	543173	20094J	PARTICIPANT	\N	PRESENT	0
546900	543173	14097Y	PARTICIPANT	\N	PRESENT	0
546901	543173	20128B	PARTICIPANT	\N	PRESENT	1
546902	543173	04057K	PARTICIPANT	\N	PRESENT	1
546916	543173	14189C	PARTICIPANT	\N	PRESENT	0
546917	543173	19521Q	PARTICIPANT	\N	PRESENT	1
547128	546824	04092N	PARTICIPANT	\N	PRESENT	1
547129	546824	11097X	PARTICIPANT	\N	PRESENT	1
547130	546824	20130U	PARTICIPANT	\N	PRESENT	1
547131	546824	14071N	PARTICIPANT	\N	PRESENT	1
547132	546824	17779H	PARTICIPANT	\N	PRESENT	1
547133	546824	19760E	PARTICIPANT	\N	PRESENT	1
547357	545333	14133K	PARTICIPANT	\N	PRESENT	0
547358	545333	14105F	PARTICIPANT	\N	PRESENT	1
547359	545333	20042V	PARTICIPANT	\N	PRESENT	0
547361	545333	14267Y	PRESIDENT	0	PRESENT	0
547362	545333	98018T	PARTICIPANT	\N	PRESENT	1
547363	545333	01024M	PARTICIPANT	\N	PRESENT	0
547364	545333	14249W	PARTICIPANT	\N	PRESENT	0
547365	545333	97011G	PARTICIPANT	\N	PRESENT	0
547366	545333	04035D	PARTICIPANT	\N	PRESENT	1
547367	545333	11083R	PARTICIPANT	\N	PRESENT	1
547368	545333	19347U	PARTICIPANT	\N	PRESENT	0
547369	545333	08056B	PARTICIPANT	\N	PRESENT	1
547372	545333	19565D	PARTICIPANT	\N	PRESENT	1
547375	545333	20072C	PARTICIPANT	\N	PRESENT	0
547378	545333	20128B	PARTICIPANT	\N	PRESENT	0
547379	545333	08069G	PARTICIPANT	\N	PRESENT	0
547381	545333	14097Y	PARTICIPANT	\N	PRESENT	0
547387	545333	12041X	PARTICIPANT	\N	PRESENT	0
547388	545333	19709B	PARTICIPANT	\N	PRESENT	0
547390	545333	19443T	PARTICIPANT	\N	PRESENT	0
547391	545333	19421M	PARTICIPANT	\N	PRESENT	1
547392	545333	11054L	PARTICIPANT	\N	PRESENT	0
547393	545333	01058X	PARTICIPANT	\N	PRESENT	1
547395	545333	01062T	PARTICIPANT	\N	PRESENT	1
547396	545333	20064C	PARTICIPANT	\N	PRESENT	0
547397	545333	11041F	PARTICIPANT	\N	PRESENT	1
547398	545333	11066Q	PARTICIPANT	\N	PRESENT	1
547399	545333	04034C	PARTICIPANT	\N	PRESENT	1
547448	545333	14255U	PARTICIPANT	\N	PRESENT	0
548875	548873	14173T	PARTICIPANT	\N	PRESENT	0
548878	548873	08034U	PARTICIPANT	\N	PRESENT	0
548879	548873	01043Q	PARTICIPANT	\N	PRESENT	0
548880	548873	05012A	PARTICIPANT	\N	PRESENT	0
548881	548873	19735D	PARTICIPANT	\N	PRESENT	0
548882	548873	11097X	PARTICIPANT	\N	PRESENT	0
548977	545889	14030Q	PARTICIPANT	\N	PRESENT	0
548978	545889	19673G	PARTICIPANT	\N	PRESENT	0
548979	545889	20056C	PARTICIPANT	\N	PRESENT	0
548980	545889	20054A	PARTICIPANT	\N	PRESENT	0
550906	550905	20042V	PARTICIPANT	\N	PRESENT	0
550907	550905	11080N	PARTICIPANT	\N	PRESENT	0
550908	550905	01057W	PARTICIPANT	\N	PRESENT	0
550909	550905	14121F	PARTICIPANT	\N	PRESENT	0
550910	550905	19711U	PARTICIPANT	\N	PRESENT	0
550911	550905	11074Q	PARTICIPANT	\N	PRESENT	0
550942	550941	95063L	PARTICIPANT	\N	PRESENT	0
550943	550941	19671E	PARTICIPANT	\N	PRESENT	0
550944	550941	11026G	PARTICIPANT	\N	PRESENT	0
550945	550941	19693L	PARTICIPANT	\N	PRESENT	0
550946	550941	20064C	PARTICIPANT	\N	PRESENT	0
550947	550941	14255U	PARTICIPANT	\N	PRESENT	0
550954	550893	19735D	PARTICIPANT	\N	PRESENT	1
550955	550923	19735D	PARTICIPANT	\N	PRESENT	1
550956	550923	20142Y	PARTICIPANT	\N	PRESENT	1
550957	550924	19735D	PARTICIPANT	\N	PRESENT	1
550958	550924	14229S	PARTICIPANT	\N	PRESENT	1
550959	550926	19735D	PARTICIPANT	\N	PRESENT	1
550960	550926	19533U	PARTICIPANT	\N	PRESENT	1
564463	563793	19593H	PRESIDENT	0	PRESENT	0
564464	563793	19611R	PARTICIPANT	\N	PRESENT	0
564465	563793	19533U	PARTICIPANT	\N	PRESENT	0
564466	563793	14147R	PARTICIPANT	\N	PRESENT	0
564467	563793	19643A	PARTICIPANT	\N	PRESENT	0
564468	563821	19721W	PARTICIPANT	\N	PRESENT	1
564469	563821	19533U	PARTICIPANT	\N	PRESENT	1
564470	563821	19693L	PARTICIPANT	\N	PRESENT	0
564471	563821	19643A	PARTICIPANT	\N	PRESENT	1
564472	563821	14147R	PARTICIPANT	\N	PRESENT	1
564473	563821	20180F	PARTICIPANT	\N	PRESENT	1
564474	563821	20142Y	PARTICIPANT	\N	PRESENT	1
564475	563821	19715Y	PARTICIPANT	\N	PRESENT	1
564476	563821	19593H	PRESIDENT	0	PRESENT	0
564477	563821	19611R	PARTICIPANT	\N	PRESENT	0
564478	563821	20082E	PARTICIPANT	\N	EXCUSE	0
564479	564202	14053L	PARTICIPANT	\N	EXCUSE	0
564481	564480	14259Y	PARTICIPANT	\N	PRESENT	0
564482	564480	20110Q	PARTICIPANT	\N	PRESENT	0
564483	564480	20068G	PARTICIPANT	\N	PRESENT	0
564485	564484	14231L	PARTICIPANT	\N	PRESENT	0
564487	564486	14231L	PARTICIPANT	\N	PRESENT	0
564521	564520	14173T	PARTICIPANT	\N	PRESENT	0
564787	564202	19717B	PARTICIPANT	\N	PRESENT	1
564788	564202	19631V	PARTICIPANT	\N	PRESENT	0
564789	564202	18083K	PARTICIPANT	\N	PRESENT	0
564790	564202	19577H	PARTICIPANT	\N	PRESENT	1
564791	564202	11010L	PARTICIPANT	\N	EXCUSE	0
564792	564202	19347U	PARTICIPANT	\N	EXCUSE	0
564793	564202	19691J	PARTICIPANT	\N	PRESENT	1
564794	564202	20034V	PARTICIPANT	\N	PRESENT	1
564796	564202	14059S	PRESIDENT	0	PRESENT	0
564797	564202	12016W	PARTICIPANT	\N	EXCUSE	0
564798	564202	14147R	PARTICIPANT	\N	PRESENT	1
564799	564202	20028X	PARTICIPANT	\N	PRESENT	1
564801	564202	19319Q	PARTICIPANT	\N	EXCUSE	0
564803	564202	20150Y	PARTICIPANT	\N	PRESENT	1
564850	559959	04070G	PARTICIPANT	\N	EXCUSE	0
564862	564385	04086Q	PARTICIPANT	\N	PRESENT	1
564863	564385	11074Q	PARTICIPANT	\N	PRESENT	1
564864	564385	11110B	PARTICIPANT	\N	PRESENT	1
564865	564385	14121F	PARTICIPANT	\N	PRESENT	1
564866	564385	99004R	PARTICIPANT	\N	PRESENT	1
564867	564385	20126Y	PARTICIPANT	\N	PRESENT	1
564868	564385	19671E	PARTICIPANT	\N	PRESENT	1
564869	564385	14331P	PARTICIPANT	\N	PRESENT	1
564870	564385	14327T	PARTICIPANT	\N	PRESENT	0
565047	563024	19760E	PARTICIPANT	\N	PRESENT	1
565055	563024	19415P	PARTICIPANT	\N	PRESENT	1
565056	563024	11103C	PARTICIPANT	\N	PRESENT	1
565057	563024	11031D	PARTICIPANT	\N	PRESENT	1
565058	563024	14217N	PARTICIPANT	\N	PRESENT	1
565059	563024	19553Y	PARTICIPANT	\N	PRESENT	1
565060	563024	14026U	PARTICIPANT	\N	PRESENT	1
565061	563024	19569H	PARTICIPANT	\N	PRESENT	1
565062	563024	20066E	PARTICIPANT	\N	PRESENT	1
565063	563024	19715Y	PARTICIPANT	\N	PRESENT	1
565064	563024	19697Q	PARTICIPANT	\N	PRESENT	1
565065	563024	19657G	PARTICIPANT	\N	PRESENT	1
565066	563024	04057K	PARTICIPANT	\N	PRESENT	1
565067	563024	14223L	PARTICIPANT	\N	PRESENT	1
565068	563024	20130U	PARTICIPANT	\N	PRESENT	1
565069	563024	04043D	PARTICIPANT	\N	PRESENT	1
565070	563024	19367Y	PARTICIPANT	\N	PRESENT	0
565071	563024	14195A	PARTICIPANT	\N	PRESENT	0
565072	563024	10006L	PRESIDENT	0	PRESENT	0
565073	563024	14042U	PARTICIPANT	\N	PRESENT	0
565074	563024	20040T	PARTICIPANT	\N	PRESENT	0
565075	563024	19691J	PARTICIPANT	\N	PRESENT	0
565076	563024	14213J	PARTICIPANT	\N	PRESENT	0
565077	563024	18193Q	PARTICIPANT	\N	PRESENT	0
565093	563024	11067R	PARTICIPANT	\N	PRESENT	0
565094	563024	14071N	PARTICIPANT	\N	PRESENT	0
565095	563024	04092N	PARTICIPANT	\N	PRESENT	0
565096	563024	17965H	PARTICIPANT	\N	PRESENT	0
565097	563024	19798U	PARTICIPANT	\N	PRESENT	0
565098	563024	11097X	PARTICIPANT	\N	PRESENT	0
565101	563024	20172F	PARTICIPANT	\N	PRESENT	1
565108	563024	17779H	PARTICIPANT	\N	EXCUSE	0
565124	563024	01034P	PARTICIPANT	\N	PRESENT	0
566519	566518	14267Y	PARTICIPANT	\N	PRESENT	0
566521	566520	14267Y	PARTICIPANT	\N	PRESENT	0
566522	566520	11064N	PARTICIPANT	\N	PRESENT	0
566555	563821	19735D	PARTICIPANT	\N	EXCUSE	0
566557	566556	19719D	PARTICIPANT	\N	PRESENT	0
566558	565994	19593H	PARTICIPANT	\N	PRESENT	0
566559	565994	19611R	PARTICIPANT	\N	PRESENT	0
566560	565994	19533U	PARTICIPANT	\N	PRESENT	1
566561	565994	19715Y	PARTICIPANT	\N	PRESENT	1
566562	565993	14030Q	PARTICIPANT	\N	PRESENT	0
566563	565993	19643A	PARTICIPANT	\N	PRESENT	0
566564	565993	20132W	PARTICIPANT	\N	PRESENT	0
566565	565993	19715Y	PARTICIPANT	\N	PRESENT	0
566566	565993	20142Y	PARTICIPANT	\N	PRESENT	0
566567	565993	14147R	PARTICIPANT	\N	PRESENT	0
566568	565993	19593H	PARTICIPANT	\N	PRESENT	0
566569	565993	19533U	PARTICIPANT	\N	PRESENT	0
566570	565993	19611R	PARTICIPANT	\N	PRESENT	0
566807	566434	20082E	PARTICIPANT	\N	PRESENT	0
566808	566434	20100N	PARTICIPANT	\N	PRESENT	0
566809	566573	19593H	PARTICIPANT	\N	PRESENT	0
566810	566573	19643A	PARTICIPANT	\N	PRESENT	0
566811	566573	20132W	PARTICIPANT	\N	PRESENT	0
566812	566573	19699S	PARTICIPANT	\N	PRESENT	0
566813	566573	20134Y	PARTICIPANT	\N	PRESENT	0
566814	566573	19611R	PRESIDENT	0	PRESENT	0
566815	566573	19693L	PARTICIPANT	\N	PRESENT	0
566816	566573	19399H	PARTICIPANT	\N	PRESENT	0
566817	566573	20152B	PARTICIPANT	\N	PRESENT	0
566818	566573	20052X	PARTICIPANT	\N	PRESENT	0
566819	566573	14229S	PARTICIPANT	\N	PRESENT	0
566820	566573	20098N	PARTICIPANT	\N	PRESENT	0
566821	566573	20058E	PARTICIPANT	\N	PRESENT	0
566822	566573	14030Q	PARTICIPANT	\N	PRESENT	0
566823	566573	20056C	PARTICIPANT	\N	PRESENT	0
566824	566573	20180F	PARTICIPANT	\N	PRESENT	0
566825	566573	20112S	PARTICIPANT	\N	PRESENT	0
566826	566573	20124W	PARTICIPANT	\N	PRESENT	0
566827	566573	20084G	PARTICIPANT	\N	PRESENT	0
566828	566573	11109J	PARTICIPANT	\N	EXCUSE	0
566829	566434	14187A	PARTICIPANT	\N	PRESENT	0
566830	566434	19611R	PARTICIPANT	\N	PRESENT	0
566831	566453	12041X	PARTICIPANT	\N	PRESENT	1
566832	566453	19565D	PARTICIPANT	\N	PRESENT	0
566833	566453	04034C	PARTICIPANT	\N	PRESENT	0
566834	566453	01058X	PARTICIPANT	\N	PRESENT	0
566835	566453	11027H	PARTICIPANT	\N	PRESENT	0
566836	566453	16685X	PARTICIPANT	\N	PRESENT	0
566837	566453	04042C	PRESIDENT	0	PRESENT	0
566838	566453	11066Q	PARTICIPANT	\N	PRESENT	0
566839	566453	12028B	PARTICIPANT	\N	PRESENT	0
566840	566453	19421M	PARTICIPANT	\N	PRESENT	0
566841	566453	19347U	PARTICIPANT	\N	PRESENT	0
566842	566453	97011G	PARTICIPANT	\N	PRESENT	0
566843	566453	08061X	PARTICIPANT	\N	PRESENT	0
566844	566453	14249W	PARTICIPANT	\N	PRESENT	0
566845	566453	08047A	PARTICIPANT	\N	PRESENT	0
566846	566453	14059S	PARTICIPANT	\N	PRESENT	0
566847	566453	14097Y	PARTICIPANT	\N	PRESENT	0
566848	566453	14133K	PARTICIPANT	\N	PRESENT	0
566849	566453	01062T	PARTICIPANT	\N	PRESENT	0
566850	566453	20042V	PARTICIPANT	\N	PRESENT	0
566851	566453	01024M	PARTICIPANT	\N	PRESENT	0
566853	566453	11064N	PARTICIPANT	\N	PRESENT	0
566854	566453	14211G	PARTICIPANT	\N	PRESENT	0
566855	566453	14255U	PARTICIPANT	\N	PRESENT	0
566856	566453	17023S	PARTICIPANT	\N	PRESENT	0
566857	566453	11054L	PARTICIPANT	\N	EXCUSE	0
566867	566434	20108W	PARTICIPANT	\N	PRESENT	0
566868	566434	99004R	PARTICIPANT	\N	PRESENT	0
566869	566434	19507S	PARTICIPANT	\N	PRESENT	0
566870	566434	04033B	PARTICIPANT	\N	PRESENT	0
566871	566434	19691J	PARTICIPANT	\N	PRESENT	0
566872	566434	11012A	PARTICIPANT	\N	PRESENT	0
566873	566434	14147R	PARTICIPANT	\N	PRESENT	0
566874	566434	14121F	PARTICIPANT	\N	PRESENT	0
566875	566434	14211G	PARTICIPANT	\N	PRESENT	0
566876	566434	20172F	PARTICIPANT	\N	PRESENT	0
566877	566434	01048V	PARTICIPANT	\N	PRESENT	0
542887	540097	19643A	PARTICIPANT	\N	PRESENT	1
542888	540097	20082E	PARTICIPANT	\N	PRESENT	1
542889	540097	19721W	PARTICIPANT	\N	PRESENT	1
542890	540097	19533U	PARTICIPANT	\N	PRESENT	1
542891	540097	14147R	PARTICIPANT	\N	PRESENT	1
542892	540097	19735D	PARTICIPANT	\N	PRESENT	1
542893	540097	20142Y	PARTICIPANT	\N	PRESENT	1
542894	540097	19715Y	PARTICIPANT	\N	PRESENT	1
542895	540097	19954N	PARTICIPANT	\N	PRESENT	1
542896	540097	20050V	PARTICIPANT	\N	PRESENT	1
542897	540097	19611R	PARTICIPANT	\N	PRESENT	0
542898	540097	19593H	PRESIDENT	0	PRESENT	0
542899	540097	14059S	PARTICIPANT	\N	PRESENT	0
542900	540097	19693L	PARTICIPANT	\N	PRESENT	0
542901	537014	19643A	PARTICIPANT	\N	PRESENT	1
542902	537014	19533U	PARTICIPANT	\N	PRESENT	1
542903	537014	14147R	PARTICIPANT	\N	PRESENT	1
542904	537014	20142Y	PARTICIPANT	\N	PRESENT	1
542905	537014	19593H	PRESIDENT	0	PRESENT	0
542906	537014	19611R	PARTICIPANT	\N	PRESENT	0
542907	537014	19715Y	PARTICIPANT	\N	PRESENT	0
542908	537014	19693L	PARTICIPANT	\N	PRESENT	0
542909	537014	20114U	PARTICIPANT	\N	PRESENT	0
542910	537014	14059S	PARTICIPANT	\N	PRESENT	0
543846	543841	20076G	PARTICIPANT	\N	PRESENT	0
543847	543841	20024T	PARTICIPANT	\N	PRESENT	0
543849	543841	20116W	PARTICIPANT	\N	PRESENT	0
543850	543841	14069U	PARTICIPANT	\N	PRESENT	0
543851	543841	19383Y	PARTICIPANT	\N	PRESENT	0
543852	543841	20090E	PARTICIPANT	\N	PRESENT	0
543895	543841	11103C	PARTICIPANT	\N	PRESENT	0
543896	543841	14329V	PARTICIPANT	\N	PRESENT	0
543897	543841	19467C	PARTICIPANT	\N	PRESENT	0
543898	543841	18083K	PARTICIPANT	\N	PRESENT	0
543899	543841	14357A	PARTICIPANT	\N	PRESENT	0
543900	543841	17589D	PARTICIPANT	\N	PRESENT	0
543901	543841	19507S	PARTICIPANT	\N	PRESENT	0
543902	543841	14026U	PARTICIPANT	\N	PRESENT	0
543903	543841	14213J	PARTICIPANT	\N	PRESENT	0
543904	543841	14221J	PARTICIPANT	\N	PRESENT	0
543905	543841	19739H	PARTICIPANT	\N	PRESENT	0
543906	543841	19679N	PARTICIPANT	\N	PRESENT	0
543907	543841	14331P	PARTICIPANT	\N	PRESENT	0
543908	543841	19619A	PARTICIPANT	\N	PRESENT	0
543909	543841	20092G	PARTICIPANT	\N	PRESENT	0
544055	542362	20066E	PARTICIPANT	\N	PRESENT	1
545027	545026	19515S	PRESIDENT	0	PRESENT	0
545028	545026	14105F	PARTICIPANT	\N	PRESENT	0
545029	545026	14083S	PARTICIPANT	\N	PRESENT	0
545030	545026	20060X	PARTICIPANT	\N	PRESENT	0
545031	545026	19467C	PARTICIPANT	\N	PRESENT	0
545032	545026	19251M	PARTICIPANT	\N	PRESENT	0
545034	545026	20134Y	PARTICIPANT	\N	PRESENT	0
545037	545026	19697Q	PARTICIPANT	\N	PRESENT	0
545038	545026	19671E	PARTICIPANT	\N	PRESENT	0
545039	545026	19369B	PARTICIPANT	\N	PRESENT	0
545040	545026	20092G	PARTICIPANT	\N	PRESENT	0
545041	545026	19575F	PARTICIPANT	\N	EXCUSE	0
545042	545026	14030Q	PARTICIPANT	\N	EXCUSE	0
545043	545026	19545Y	PARTICIPANT	\N	EXCUSE	0
545044	545026	14195A	PARTICIPANT	\N	EXCUSE	0
545045	545026	14041T	PARTICIPANT	\N	EXCUSE	0
545046	545026	20040T	PARTICIPANT	\N	EXCUSE	0
545047	545026	14026U	PARTICIPANT	\N	EXCUSE	0
545049	545026	08015R	PARTICIPANT	\N	EXCUSE	0
545053	545026	19762G	PARTICIPANT	\N	EXCUSE	0
545636	545159	19749K	PARTICIPANT	\N	PRESENT	0
545637	545159	19673G	PARTICIPANT	\N	PRESENT	0
545638	545159	14215L	PARTICIPANT	\N	PRESENT	0
545639	545159	20074E	PARTICIPANT	\N	PRESENT	0
545640	545159	07004J	PARTICIPANT	\N	PRESENT	0
545641	545159	14001X	PARTICIPANT	\N	PRESENT	0
545642	545159	19729F	PARTICIPANT	\N	PRESENT	0
545643	545159	19649G	PARTICIPANT	\N	PRESENT	0
545644	545159	19447X	PARTICIPANT	\N	PRESENT	0
545645	545159	20110Q	PARTICIPANT	\N	PRESENT	0
545646	545159	05008E	PARTICIPANT	\N	PRESENT	0
545667	543152	20180F	PARTICIPANT	\N	PRESENT	0
545648	545159	04047H	PRESIDENT	0	PRESENT	0
545649	545159	01028R	PARTICIPANT	\N	PRESENT	0
545650	545159	14231L	PARTICIPANT	\N	PRESENT	0
545651	545159	17737W	PARTICIPANT	\N	PRESENT	0
545652	545159	20108W	PARTICIPANT	\N	PRESENT	0
545653	545159	14041T	PARTICIPANT	\N	PRESENT	0
545654	545159	14259Y	PARTICIPANT	\N	PRESENT	0
545655	545159	11072N	PARTICIPANT	\N	PRESENT	0
545705	543152	19699S	PARTICIPANT	\N	PRESENT	0
545756	545404	86034E	PARTICIPANT	\N	PRESENT	0
545706	543152	04033B	PARTICIPANT	\N	PRESENT	0
545659	545159	14111D	PARTICIPANT	\N	PRESENT	0
545660	545159	14089Y	PARTICIPANT	\N	PRESENT	0
545661	545159	19543W	PARTICIPANT	\N	PRESENT	0
545662	545159	11056N	PARTICIPANT	\N	PRESENT	0
545663	545159	14179A	PARTICIPANT	\N	PRESENT	0
545664	545159	19585H	PARTICIPANT	\N	PRESENT	0
545665	545159	11033F	PARTICIPANT	\N	PRESENT	0
545707	543152	20134Y	PARTICIPANT	\N	PRESENT	0
545671	543152	19399H	PARTICIPANT	\N	PRESENT	0
545672	543152	20152B	PARTICIPANT	\N	PRESENT	0
545673	543152	19621T	PARTICIPANT	\N	PRESENT	0
545674	543152	19593H	PARTICIPANT	\N	PRESENT	0
545675	543152	20132W	PARTICIPANT	\N	PRESENT	0
545708	543152	20098N	PARTICIPANT	\N	PRESENT	0
545677	543152	14073Q	PARTICIPANT	\N	PRESENT	0
545678	543152	19611R	PRESIDENT	0	PRESENT	0
545679	543152	20048C	PARTICIPANT	\N	PRESENT	0
545680	543152	14229S	PARTICIPANT	\N	PRESENT	0
545681	543152	14030Q	PARTICIPANT	\N	PRESENT	0
545682	543152	19735D	PARTICIPANT	\N	PRESENT	0
545709	543152	20026V	PARTICIPANT	\N	PRESENT	0
545710	543152	20056C	PARTICIPANT	\N	PRESENT	0
545757	545404	19569H	PARTICIPANT	\N	PRESENT	0
545758	545404	19798U	PARTICIPANT	\N	PRESENT	0
545712	543152	11043H	PARTICIPANT	\N	PRESENT	0
545759	545404	07004J	PARTICIPANT	\N	PRESENT	0
545760	545404	14041T	PARTICIPANT	\N	PRESENT	0
545714	543152	11109J	PARTICIPANT	\N	EXCUSE	0
545717	543152	20138D	PARTICIPANT	\N	PRESENT	0
545761	545404	19703U	PARTICIPANT	\N	PRESENT	0
545762	545404	19719D	PARTICIPANT	\N	PRESENT	0
545763	545404	20090E	PARTICIPANT	\N	PRESENT	0
545764	545404	14105F	PARTICIPANT	\N	PRESENT	0
545765	545404	20078J	PARTICIPANT	\N	PRESENT	0
545766	545404	19443T	PARTICIPANT	\N	PRESENT	0
545767	545404	20098N	PARTICIPANT	\N	PRESENT	0
545768	545404	19593H	PARTICIPANT	\N	PRESENT	0
545769	545404	11072N	PARTICIPANT	\N	PRESENT	0
545770	545404	19651A	PARTICIPANT	\N	PRESENT	0
545771	545404	14207L	PARTICIPANT	\N	PRESENT	0
545772	545404	20132W	PARTICIPANT	\N	PRESENT	0
545704	543152	19573D	PARTICIPANT	\N	PRESENT	0
545773	545404	19649G	PARTICIPANT	\N	PRESENT	0
545774	545404	04047H	PARTICIPANT	\N	PRESENT	0
545775	545404	11103C	PARTICIPANT	\N	PRESENT	0
545777	545404	18083K	PARTICIPANT	\N	PRESENT	0
545778	545404	14123H	PARTICIPANT	\N	PRESENT	0
545779	545404	14223L	PARTICIPANT	\N	PRESENT	0
545780	545404	12028B	PARTICIPANT	\N	PRESENT	0
545781	545404	14021P	PARTICIPANT	\N	PRESENT	0
545783	545404	20052X	PARTICIPANT	\N	PRESENT	0
545784	545404	20020P	PARTICIPANT	\N	PRESENT	0
545785	545404	04086Q	PARTICIPANT	\N	PRESENT	0
545786	545404	19467C	PARTICIPANT	\N	PRESENT	0
545787	545404	14031R	PARTICIPANT	\N	PRESENT	0
545788	545404	19673G	PARTICIPANT	\N	PRESENT	0
545789	545404	19749K	PARTICIPANT	\N	PRESENT	0
545790	545404	19551W	PARTICIPANT	\N	PRESENT	0
545791	545404	04085P	PARTICIPANT	\N	PRESENT	0
545792	545404	08011M	PARTICIPANT	\N	PRESENT	0
545793	545404	11056N	PARTICIPANT	\N	PRESENT	0
545794	545404	12041X	PARTICIPANT	\N	PRESENT	0
545795	545404	99004R	PARTICIPANT	\N	PRESENT	0
545796	545404	11040E	PARTICIPANT	\N	PRESENT	0
545797	545404	11033F	PARTICIPANT	\N	PRESENT	0
545798	545404	14231L	PARTICIPANT	\N	PRESENT	0
545799	545404	19621T	PARTICIPANT	\N	PRESENT	0
545800	545404	19671E	PARTICIPANT	\N	PRESENT	0
545801	545404	20076G	PARTICIPANT	\N	PRESENT	0
545802	545404	19762G	PARTICIPANT	\N	PRESENT	0
553342	553341	19760E	PARTICIPANT	\N	PRESENT	0
553343	553341	14189C	PARTICIPANT	\N	PRESENT	0
553344	553341	20022R	PARTICIPANT	\N	PRESENT	0
553345	553341	19954N	PARTICIPANT	\N	PRESENT	0
553346	553341	19575F	PARTICIPANT	\N	PRESENT	0
553347	553341	14069U	PARTICIPANT	\N	PRESENT	0
553348	553341	19747H	PARTICIPANT	\N	PRESENT	0
553349	553341	20090E	PARTICIPANT	\N	PRESENT	0
553350	553341	19782L	PARTICIPANT	\N	PRESENT	0
553351	553341	14207L	PARTICIPANT	\N	PRESENT	0
553352	553341	14083S	PARTICIPANT	\N	PRESENT	0
553353	553341	14038Y	PARTICIPANT	\N	PRESENT	0
553354	553341	20144B	PARTICIPANT	\N	PRESENT	0
553355	553341	19467C	PARTICIPANT	\N	PRESENT	0
553356	553341	14357A	PARTICIPANT	\N	PRESENT	0
553357	553341	20140W	PARTICIPANT	\N	PRESENT	0
553358	553341	01024M	PARTICIPANT	\N	PRESENT	0
553359	553341	14215L	PARTICIPANT	\N	PRESENT	0
553360	553341	20040T	PARTICIPANT	\N	PRESENT	0
553361	553341	19507S	PARTICIPANT	\N	PRESENT	0
553362	553341	20174H	PARTICIPANT	\N	PRESENT	0
553363	553341	01025N	PARTICIPANT	\N	PRESENT	0
553364	553341	20172F	PARTICIPANT	\N	PRESENT	0
553365	553341	20120S	PARTICIPANT	\N	PRESENT	0
553366	553341	14033T	PARTICIPANT	\N	PRESENT	0
553367	553341	19511N	PARTICIPANT	\N	PRESENT	0
553368	553341	19531S	PARTICIPANT	\N	PRESENT	0
553369	553341	20126Y	PARTICIPANT	\N	PRESENT	0
553370	553341	07029T	PARTICIPANT	\N	PRESENT	0
553371	553341	08015R	PARTICIPANT	\N	PRESENT	0
553372	553341	16685X	PARTICIPANT	\N	PRESENT	0
553373	553341	08034U	PARTICIPANT	\N	PRESENT	0
553374	553341	14059S	PARTICIPANT	\N	PRESENT	0
553375	553341	19441R	PARTICIPANT	\N	PRESENT	0
553376	553341	20018V	PARTICIPANT	\N	PRESENT	0
553377	553341	14109K	PARTICIPANT	\N	PRESENT	0
553378	553341	14257W	PARTICIPANT	\N	PRESENT	0
553379	553341	20096L	PARTICIPANT	\N	PRESENT	0
553380	553341	14169X	PARTICIPANT	\N	PRESENT	0
553381	553341	19745F	PARTICIPANT	\N	PRESENT	0
553382	553341	20118Y	PARTICIPANT	\N	PRESENT	0
553383	553341	20082E	PARTICIPANT	\N	PRESENT	0
553384	553341	20054A	PARTICIPANT	\N	PRESENT	0
553385	553341	04045F	PARTICIPANT	\N	PRESENT	0
553386	553341	19762G	PARTICIPANT	\N	PRESENT	0
553387	553341	20062A	PARTICIPANT	\N	PRESENT	0
553388	553341	20026V	PARTICIPANT	\N	PRESENT	0
553543	551451	01043Q	PARTICIPANT	\N	PRESENT	0
553544	551284	08073C	PARTICIPANT	\N	PRESENT	1
553545	551284	20126Y	PARTICIPANT	\N	PRESENT	1
553546	551284	14121F	PARTICIPANT	\N	PRESENT	1
553547	551284	11074Q	PARTICIPANT	\N	PRESENT	1
553548	551284	19647E	PARTICIPANT	\N	PRESENT	1
553549	551451	11072N	PARTICIPANT	\N	PRESENT	0
553550	551451	19591F	PARTICIPANT	\N	PRESENT	0
553551	551451	11083R	PARTICIPANT	\N	PRESENT	0
553552	551451	19866P	PARTICIPANT	\N	PRESENT	0
553553	551451	11012A	PARTICIPANT	\N	PRESENT	0
553567	551284	14207L	PARTICIPANT	\N	PRESENT	1
553569	551284	20174H	PARTICIPANT	\N	PRESENT	0
553571	551284	19521Q	PARTICIPANT	\N	PRESENT	0
553573	551284	11077T	PARTICIPANT	\N	PRESENT	1
553574	551284	14251Q	PARTICIPANT	\N	PRESENT	1
553575	551284	04045F	PARTICIPANT	\N	PRESENT	1
553578	551284	19507S	PARTICIPANT	\N	PRESENT	0
553582	551284	20062A	PARTICIPANT	\N	PRESENT	1
553611	551284	19705W	PARTICIPANT	\N	PRESENT	0
553612	551284	20104S	PARTICIPANT	\N	PRESENT	0
553614	551285	14327T	PARTICIPANT	\N	PRESENT	0
553615	551285	14331P	PARTICIPANT	\N	PRESENT	0
553616	551285	01048V	PARTICIPANT	\N	PRESENT	0
553617	551285	01057W	PARTICIPANT	\N	PRESENT	0
553618	551285	19441R	PARTICIPANT	\N	PRESENT	0
553619	551285	11053K	PARTICIPANT	\N	PRESENT	0
553620	551285	20080C	PARTICIPANT	\N	PRESENT	0
553621	551285	14225N	PRESIDENT	0	PRESENT	0
553622	551285	11070L	PARTICIPANT	\N	PRESENT	0
553623	551285	20100N	PARTICIPANT	\N	PRESENT	0
553624	551285	07029T	PARTICIPANT	\N	PRESENT	0
553625	551285	19349W	PARTICIPANT	\N	PRESENT	0
553626	551285	20018V	PARTICIPANT	\N	PRESENT	0
553627	551285	20022R	PARTICIPANT	\N	PRESENT	0
553628	551285	20126Y	PARTICIPANT	\N	PRESENT	0
553629	551285	11048N	PARTICIPANT	\N	PRESENT	0
553630	551285	19647E	PARTICIPANT	\N	PRESENT	0
553631	551285	19479G	PARTICIPANT	\N	PRESENT	0
553632	551285	19711U	PARTICIPANT	\N	PRESENT	0
553633	551285	19531S	PARTICIPANT	\N	PRESENT	0
553634	551285	08034U	PARTICIPANT	\N	PRESENT	0
553635	551285	11026G	PARTICIPANT	\N	PRESENT	0
553636	551285	19689Q	PARTICIPANT	\N	PRESENT	0
553637	551285	08011M	PARTICIPANT	\N	PRESENT	0
553638	551285	20044X	PARTICIPANT	\N	PRESENT	0
553639	551285	04086Q	PARTICIPANT	\N	PRESENT	0
553640	551285	14083S	PARTICIPANT	\N	PRESENT	0
553641	551285	19741B	PARTICIPANT	\N	PRESENT	0
553642	551285	99004R	PARTICIPANT	\N	PRESENT	0
553643	551285	19762G	PARTICIPANT	\N	PRESENT	0
553662	553660	14187A	PARTICIPANT	\N	PRESENT	0
553663	553661	14187A	PARTICIPANT	\N	PRESENT	0
553664	553661	01043Q	PARTICIPANT	\N	PRESENT	0
553666	553665	14187A	PARTICIPANT	\N	PRESENT	0
553667	553665	01043Q	PARTICIPANT	\N	PRESENT	0
553713	553647	11072N	PARTICIPANT	\N	PRESENT	0
553714	553647	19599P	PARTICIPANT	\N	PRESENT	0
553715	553647	19503N	PARTICIPANT	\N	PRESENT	0
553716	553647	19631V	PARTICIPANT	\N	PRESENT	0
553717	553647	11012A	PARTICIPANT	\N	PRESENT	0
553718	553647	20116W	PARTICIPANT	\N	PRESENT	0
553719	553647	14207L	PARTICIPANT	\N	PRESENT	0
553720	553647	14071N	PARTICIPANT	\N	PRESENT	0
553721	553647	20072C	PARTICIPANT	\N	PRESENT	0
553722	553647	20100N	PARTICIPANT	\N	PRESENT	0
553723	553647	19347U	PARTICIPANT	\N	PRESENT	0
553724	553647	20110Q	PARTICIPANT	\N	PRESENT	0
553725	553647	14215L	PARTICIPANT	\N	PRESENT	0
553726	553647	19713W	PARTICIPANT	\N	PRESENT	0
553727	553647	20034V	PARTICIPANT	\N	PRESENT	0
553728	553647	20026V	PARTICIPANT	\N	PRESENT	0
553729	553647	20090E	PARTICIPANT	\N	PRESENT	0
553730	553647	07029T	PARTICIPANT	\N	PRESENT	0
553731	553647	14147R	PARTICIPANT	\N	PRESENT	0
553732	553647	20044X	PARTICIPANT	\N	PRESENT	0
553733	553647	14038Y	PARTICIPANT	\N	PRESENT	0
553734	553647	19954N	PARTICIPANT	\N	PRESENT	0
553735	553647	19643A	PARTICIPANT	\N	PRESENT	0
553736	553647	14033T	PARTICIPANT	\N	PRESENT	0
553737	553647	20132W	PARTICIPANT	\N	PRESENT	0
553738	553647	19591F	PARTICIPANT	\N	PRESENT	0
553739	553647	14069U	PARTICIPANT	\N	PRESENT	0
553740	553647	14187A	PARTICIPANT	\N	PRESENT	0
553741	553647	19593H	PARTICIPANT	\N	PRESENT	0
553742	553647	20122U	PARTICIPANT	\N	PRESENT	0
553743	553647	19575F	PARTICIPANT	\N	PRESENT	0
553744	553647	08010L	PARTICIPANT	\N	PRESENT	0
553745	553647	11056N	PARTICIPANT	\N	PRESENT	0
553746	553647	14179A	PARTICIPANT	\N	PRESENT	0
553747	553647	14030Q	PARTICIPANT	\N	PRESENT	0
553748	553647	19369B	PARTICIPANT	\N	PRESENT	0
553749	553647	14083S	PARTICIPANT	\N	PRESENT	0
553711	553647	99004R	PARTICIPANT	\N	PRESENT	0
553712	553647	04047H	PARTICIPANT	\N	PRESENT	0
547913	547911	20094J	PARTICIPANT	\N	PRESENT	0
547914	547911	04070G	PARTICIPANT	\N	PRESENT	0
550961	550927	19735D	PARTICIPANT	\N	PRESENT	1
550962	550928	19735D	PARTICIPANT	\N	PRESENT	1
550963	550929	19735D	PARTICIPANT	\N	PRESENT	1
550964	550929	20052X	PARTICIPANT	\N	PRESENT	1
550965	550929	20048C	PARTICIPANT	\N	PRESENT	1
551048	551047	11097X	PARTICIPANT	\N	PRESENT	0
551049	551047	17779H	PARTICIPANT	\N	PRESENT	0
551050	551047	20130U	PARTICIPANT	\N	PRESENT	0
551051	551047	04092N	PARTICIPANT	\N	PRESENT	0
551136	551129	20050V	PARTICIPANT	\N	PRESENT	0
551190	551188	04047H	PARTICIPANT	\N	PRESENT	0
551191	551188	14053L	PARTICIPANT	\N	PRESENT	0
551192	551188	14299H	PARTICIPANT	\N	PRESENT	0
551195	551188	11066Q	PARTICIPANT	\N	PRESENT	0
551231	551223	20048C	PARTICIPANT	\N	PRESENT	0
551232	551223	20052X	PARTICIPANT	\N	PRESENT	0
551233	551223	17779H	PARTICIPANT	\N	PRESENT	0
551234	551223	11067R	PARTICIPANT	\N	PRESENT	0
551237	551222	19651A	PARTICIPANT	\N	PRESENT	0
551238	551222	20052X	PARTICIPANT	\N	PRESENT	0
551239	551222	20048C	PARTICIPANT	\N	PRESENT	0
551240	551222	17779H	PARTICIPANT	\N	PRESENT	0
551263	551262	04034C	PARTICIPANT	\N	PRESENT	1
551264	551262	19421M	PARTICIPANT	\N	PRESENT	1
551290	551289	14257W	PARTICIPANT	\N	PRESENT	0
551291	551289	19467C	PARTICIPANT	\N	PRESENT	0
551292	551289	14205J	PARTICIPANT	\N	PRESENT	0
551293	551289	14033T	PARTICIPANT	\N	PRESENT	0
551294	551289	14207L	PARTICIPANT	\N	PRESENT	0
551295	551289	11090Q	PARTICIPANT	\N	PRESENT	0
551297	551296	19413M	PARTICIPANT	\N	PRESENT	0
551298	551296	14257W	PARTICIPANT	\N	PRESENT	0
551299	551296	14207L	PARTICIPANT	\N	PRESENT	0
551300	551296	14205J	PARTICIPANT	\N	PRESENT	0
551301	551296	19467C	PARTICIPANT	\N	PRESENT	0
551302	551296	14033T	PARTICIPANT	\N	PRESENT	0
551303	551296	19563B	PARTICIPANT	\N	PRESENT	0
551304	551296	20054A	PARTICIPANT	\N	PRESENT	0
551306	551305	19413M	PARTICIPANT	\N	PRESENT	0
551307	551305	14257W	PARTICIPANT	\N	PRESENT	0
551308	551305	14207L	PARTICIPANT	\N	PRESENT	0
551309	551305	14205J	PARTICIPANT	\N	PRESENT	0
551310	551305	19467C	PARTICIPANT	\N	PRESENT	0
551311	551305	14033T	PARTICIPANT	\N	PRESENT	0
551312	551305	19563B	PARTICIPANT	\N	PRESENT	0
551313	551305	20054A	PARTICIPANT	\N	PRESENT	0
551315	551314	19413M	PARTICIPANT	\N	PRESENT	0
551316	551314	14257W	PARTICIPANT	\N	PRESENT	0
551317	551314	14207L	PARTICIPANT	\N	PRESENT	0
551318	551314	14205J	PARTICIPANT	\N	PRESENT	0
551319	551314	19467C	PARTICIPANT	\N	PRESENT	0
551320	551314	14033T	PARTICIPANT	\N	PRESENT	0
551321	551314	19563B	PARTICIPANT	\N	PRESENT	0
551322	551314	20054A	PARTICIPANT	\N	PRESENT	0
551324	551323	19413M	PARTICIPANT	\N	PRESENT	0
551325	551323	14257W	PARTICIPANT	\N	PRESENT	0
551326	551323	14207L	PARTICIPANT	\N	PRESENT	0
551327	551323	14205J	PARTICIPANT	\N	PRESENT	0
551328	551323	14033T	PARTICIPANT	\N	PRESENT	0
551329	551323	19563B	PARTICIPANT	\N	PRESENT	0
551330	551323	20054A	PARTICIPANT	\N	PRESENT	0
551331	551323	20082E	PARTICIPANT	\N	PRESENT	0
551334	551333	14257W	PARTICIPANT	\N	PRESENT	0
551335	551333	14207L	PARTICIPANT	\N	PRESENT	0
551336	551333	14205J	PARTICIPANT	\N	PRESENT	0
551337	551333	14033T	PARTICIPANT	\N	PRESENT	0
551338	551333	20054A	PARTICIPANT	\N	PRESENT	0
551339	551333	20082E	PARTICIPANT	\N	PRESENT	0
551340	551333	19782L	PARTICIPANT	\N	PRESENT	0
551341	551333	19413M	PARTICIPANT	\N	PRESENT	0
551343	551342	14257W	PARTICIPANT	\N	PRESENT	0
551344	551342	14207L	PARTICIPANT	\N	PRESENT	0
551345	551342	14205J	PARTICIPANT	\N	PRESENT	0
551346	551342	14033T	PARTICIPANT	\N	PRESENT	0
551347	551342	20054A	PARTICIPANT	\N	PRESENT	0
551348	551342	20082E	PARTICIPANT	\N	PRESENT	0
551349	551342	19782L	PARTICIPANT	\N	PRESENT	0
551350	551342	19413M	PARTICIPANT	\N	PRESENT	0
551352	551351	14257W	PARTICIPANT	\N	PRESENT	0
551353	551351	14207L	PARTICIPANT	\N	PRESENT	0
551354	551351	14205J	PARTICIPANT	\N	PRESENT	0
551355	551351	14033T	PARTICIPANT	\N	PRESENT	0
551356	551351	20054A	PARTICIPANT	\N	PRESENT	0
553608	553607	04047H	PARTICIPANT	\N	PRESENT	0
554098	554097	19760E	PARTICIPANT	\N	PRESENT	0
554099	554097	19515S	PRESIDENT	0	PRESENT	0
554100	554097	19575F	PARTICIPANT	\N	PRESENT	0
554101	554097	20094J	PARTICIPANT	\N	PRESENT	0
554102	554097	20060X	PARTICIPANT	\N	PRESENT	0
554103	554097	19467C	PARTICIPANT	\N	PRESENT	0
554104	554097	14041T	PARTICIPANT	\N	PRESENT	0
554105	554097	20126Y	PARTICIPANT	\N	PRESENT	0
554106	554097	08015R	PARTICIPANT	\N	PRESENT	0
554107	554097	19671E	PARTICIPANT	\N	PRESENT	0
554108	554097	19369B	PARTICIPANT	\N	PRESENT	0
554109	554097	14030Q	PARTICIPANT	\N	EXCUSE	0
554110	554097	19545Y	PARTICIPANT	\N	EXCUSE	0
554111	554097	14357A	PARTICIPANT	\N	EXCUSE	0
554112	554097	14026U	PARTICIPANT	\N	EXCUSE	0
554113	554097	20048C	PARTICIPANT	\N	EXCUSE	0
554114	554097	20082E	PARTICIPANT	\N	EXCUSE	0
554115	554097	20092G	PARTICIPANT	\N	EXCUSE	0
554920	554919	19333N	PARTICIPANT	\N	PRESENT	0
554921	554919	04043D	PARTICIPANT	\N	PRESENT	0
554922	554919	14001X	PARTICIPANT	\N	PRESENT	0
555053	554348	19593H	PARTICIPANT	\N	PRESENT	0
555054	554348	19611R	PARTICIPANT	\N	PRESENT	0
555056	555055	19693L	PARTICIPANT	\N	PRESENT	1
555057	555055	20082E	PARTICIPANT	\N	PRESENT	1
555058	555055	19593H	PARTICIPANT	\N	PRESENT	0
555059	555055	19611R	PARTICIPANT	\N	PRESENT	0
555060	555052	14147R	PARTICIPANT	\N	PRESENT	1
555061	555052	19611R	PARTICIPANT	\N	PRESENT	0
555062	555052	19593H	PARTICIPANT	\N	PRESENT	0
555063	555052	19319Q	PARTICIPANT	\N	PRESENT	0
555065	555064	14147R	PARTICIPANT	\N	PRESENT	1
555066	555064	19611R	PARTICIPANT	\N	PRESENT	0
555067	555064	19593H	PARTICIPANT	\N	PRESENT	0
555095	555094	01048V	PARTICIPANT	\N	PRESENT	0
555106	554521	19717B	PARTICIPANT	\N	PRESENT	1
555108	554521	14217N	PARTICIPANT	\N	PRESENT	1
555107	554521	14026U	PARTICIPANT	\N	PRESENT	1
555109	554539	14026U	PARTICIPANT	\N	PRESENT	1
555110	554539	19717B	PARTICIPANT	\N	PRESENT	1
555111	554539	17965H	PARTICIPANT	\N	PRESENT	1
555112	554538	19717B	PARTICIPANT	\N	PRESENT	1
555113	554538	14026U	PARTICIPANT	\N	PRESENT	1
555114	554538	17965H	PARTICIPANT	\N	PRESENT	1
555115	554537	19717B	PARTICIPANT	\N	PRESENT	1
555116	554537	14026U	PARTICIPANT	\N	PRESENT	1
555117	554537	20130U	PARTICIPANT	\N	PRESENT	1
555118	554537	17965H	PARTICIPANT	\N	PRESENT	1
555119	554536	19717B	PARTICIPANT	\N	PRESENT	1
555120	554536	14026U	PARTICIPANT	\N	PRESENT	1
555121	554536	20130U	PARTICIPANT	\N	PRESENT	1
555122	554536	17965H	PARTICIPANT	\N	PRESENT	1
555125	555124	17779H	PARTICIPANT	\N	PRESENT	0
555126	555124	14179A	PARTICIPANT	\N	PRESENT	0
555128	555127	19651A	PARTICIPANT	\N	PRESENT	0
555129	555127	17779H	PARTICIPANT	\N	PRESENT	0
555131	555130	19651A	PARTICIPANT	\N	PRESENT	0
555132	555130	14179A	PARTICIPANT	\N	PRESENT	0
555133	555130	17779H	PARTICIPANT	\N	PRESENT	0
555135	555134	17779H	PARTICIPANT	\N	PRESENT	0
555136	555134	11067R	PARTICIPANT	\N	PRESENT	0
555138	555137	14179A	PARTICIPANT	\N	PRESENT	0
555139	555137	17779H	PARTICIPANT	\N	PRESENT	0
555140	555137	11067R	PARTICIPANT	\N	PRESENT	0
555142	555141	17779H	PARTICIPANT	\N	PRESENT	0
555144	555143	17779H	PARTICIPANT	\N	PRESENT	0
555145	555143	11067R	PARTICIPANT	\N	PRESENT	0
555147	555146	17779H	PARTICIPANT	\N	PRESENT	0
555149	555148	14179A	PARTICIPANT	\N	PRESENT	0
555150	555148	17779H	PARTICIPANT	\N	PRESENT	0
555152	555151	17779H	PARTICIPANT	\N	PRESENT	0
555153	555151	11067R	PARTICIPANT	\N	PRESENT	0
563232	563230	14026U	PARTICIPANT	\N	PRESENT	1
563233	563230	19717B	PARTICIPANT	\N	PRESENT	1
563234	563230	20130U	PARTICIPANT	\N	PRESENT	1
565175	564386	19335Q	PARTICIPANT	\N	PRESENT	0
565176	564386	19667J	PARTICIPANT	\N	PRESENT	1
565177	564386	04071H	PARTICIPANT	\N	PRESENT	1
565178	564386	19647E	PARTICIPANT	\N	PRESENT	1
565179	564386	14121F	PARTICIPANT	\N	PRESENT	1
565180	564386	20126Y	PARTICIPANT	\N	PRESENT	1
565181	564386	08011M	PARTICIPANT	\N	PRESENT	1
565182	564386	20050V	PARTICIPANT	\N	PRESENT	1
565183	564386	14331P	PARTICIPANT	\N	PRESENT	1
565184	564386	19479G	PARTICIPANT	\N	PRESENT	1
565220	564386	14189C	PARTICIPANT	\N	PRESENT	0
565221	564386	11110B	PARTICIPANT	\N	PRESENT	0
565222	564386	11048N	PARTICIPANT	\N	PRESENT	0
565223	564386	08034U	PARTICIPANT	\N	PRESENT	0
565224	564386	01048V	PARTICIPANT	\N	PRESENT	0
566105	566104	05008E	PARTICIPANT	\N	PRESENT	0
566106	566104	11053K	PARTICIPANT	\N	PRESENT	0
566107	566104	01028R	PARTICIPANT	\N	PRESENT	0
566576	566575	04071H	PARTICIPANT	\N	PRESENT	0
566578	566577	14053L	PARTICIPANT	\N	PRESENT	0
566580	566579	14053L	PARTICIPANT	\N	PRESENT	0
566581	566579	07004J	PARTICIPANT	\N	PRESENT	0
566582	566579	11026G	PARTICIPANT	\N	PRESENT	0
566584	566583	14053L	PARTICIPANT	\N	PRESENT	0
566585	566583	07004J	PARTICIPANT	\N	PRESENT	0
566586	566583	04008A	PARTICIPANT	\N	PRESENT	0
566587	566583	11026G	PARTICIPANT	\N	PRESENT	0
566589	566588	14053L	PARTICIPANT	\N	PRESENT	0
566590	566588	14267Y	PARTICIPANT	\N	PRESENT	0
566593	566592	14053L	PARTICIPANT	\N	PRESENT	0
566594	566592	07004J	PARTICIPANT	\N	PRESENT	0
566595	566592	11026G	PARTICIPANT	\N	PRESENT	0
566596	566592	14267Y	PARTICIPANT	\N	PRESENT	0
566598	566597	14053L	PARTICIPANT	\N	PRESENT	0
566599	566597	11026G	PARTICIPANT	\N	PRESENT	0
566601	566600	14053L	PARTICIPANT	\N	PRESENT	0
566602	566600	04008A	PARTICIPANT	\N	PRESENT	0
566603	566600	07004J	PARTICIPANT	\N	PRESENT	0
567078	566014	14179A	PARTICIPANT	\N	PRESENT	1
567079	566014	19581D	PARTICIPANT	\N	PRESENT	1
567080	566014	19649G	PARTICIPANT	\N	PRESENT	1
567081	566014	20114U	PARTICIPANT	\N	PRESENT	1
567082	566014	10015M	PARTICIPANT	\N	PRESENT	1
567083	566014	11033F	PARTICIPANT	\N	PRESENT	1
567084	566014	20128B	PARTICIPANT	\N	PRESENT	1
567085	566014	19489J	PARTICIPANT	\N	PRESENT	1
567086	566016	19581D	PARTICIPANT	\N	PRESENT	1
567087	566016	14179A	PARTICIPANT	\N	PRESENT	1
567088	566016	20114U	PARTICIPANT	\N	PRESENT	1
567089	566016	10015M	PARTICIPANT	\N	PRESENT	1
567090	566016	11033F	PARTICIPANT	\N	PRESENT	1
567091	566016	19489J	PARTICIPANT	\N	PRESENT	1
567092	566016	14001X	PARTICIPANT	\N	PRESENT	1
567093	566016	19629C	PARTICIPANT	\N	PRESENT	1
567094	566016	20128B	PARTICIPANT	\N	PRESENT	1
567095	566016	17737W	PARTICIPANT	\N	PRESENT	1
567096	566016	04008A	PARTICIPANT	\N	PRESENT	1
567151	566153	19741B	PARTICIPANT	\N	PRESENT	1
567152	566153	11053K	PARTICIPANT	\N	PRESENT	1
567153	566153	04086Q	PARTICIPANT	\N	PRESENT	1
567154	566153	11110B	PARTICIPANT	\N	PRESENT	1
567155	566153	14121F	PARTICIPANT	\N	PRESENT	1
567156	566153	08010L	PARTICIPANT	\N	PRESENT	1
567157	566153	20050V	PARTICIPANT	\N	PRESENT	1
567158	566153	19349W	PARTICIPANT	\N	PRESENT	1
567159	566153	19687N	PARTICIPANT	\N	PRESENT	1
567160	566153	19479G	PARTICIPANT	\N	PRESENT	1
567161	566153	14173T	PARTICIPANT	\N	PRESENT	1
567731	566017	04085P	PARTICIPANT	\N	PRESENT	1
567732	566017	07004J	PARTICIPANT	\N	PRESENT	1
568017	568015	14133K	PARTICIPANT	\N	PRESENT	0
568018	568015	14097Y	PARTICIPANT	\N	PRESENT	0
568019	566181	14073Q	PARTICIPANT	\N	EXCUSE	0
568021	568020	14133K	PARTICIPANT	\N	PRESENT	0
568022	568020	11083R	PARTICIPANT	\N	PRESENT	0
568023	568020	14097Y	PARTICIPANT	\N	PRESENT	0
568025	568024	14133K	PARTICIPANT	\N	PRESENT	0
568026	568024	11083R	PARTICIPANT	\N	PRESENT	0
568027	568024	14097Y	PARTICIPANT	\N	PRESENT	0
568029	568028	14071N	PARTICIPANT	\N	PRESENT	0
568030	568028	14187A	PARTICIPANT	\N	PRESENT	0
568031	568028	14215L	PARTICIPANT	\N	PRESENT	0
568032	568028	08010L	PARTICIPANT	\N	PRESENT	0
568033	568028	14231L	PRESIDENT	0	PRESENT	0
568034	568028	19565D	PARTICIPANT	\N	PRESENT	0
568035	568028	19333N	PARTICIPANT	\N	PRESENT	0
568036	568028	01057W	PARTICIPANT	\N	PRESENT	0
568037	568028	14327T	PARTICIPANT	\N	PRESENT	0
568038	568028	17637T	PARTICIPANT	\N	PRESENT	0
568039	568028	04045F	PARTICIPANT	\N	PRESENT	0
568040	568028	19349W	PARTICIPANT	\N	PRESENT	1
568041	568028	19735D	PARTICIPANT	\N	PRESENT	1
568042	568028	04086Q	PARTICIPANT	\N	PRESENT	1
568043	568028	19681G	PARTICIPANT	\N	PRESENT	1
568044	568028	20058E	PARTICIPANT	\N	PRESENT	1
568045	568028	14257W	PARTICIPANT	\N	PRESENT	1
568046	568028	14229S	PARTICIPANT	\N	PRESENT	1
568048	568047	11026G	PARTICIPANT	\N	PRESENT	0
568049	568047	20114U	PARTICIPANT	\N	PRESENT	0
568050	568047	11067R	PARTICIPANT	\N	PRESENT	0
568052	568051	19591F	PARTICIPANT	\N	PRESENT	0
568053	568051	20130U	PARTICIPANT	\N	PRESENT	0
568054	568051	19713W	PARTICIPANT	\N	PRESENT	0
568055	568051	20114U	PARTICIPANT	\N	PRESENT	0
568056	568051	19729F	PARTICIPANT	\N	PRESENT	0
568058	568057	20114U	PARTICIPANT	\N	PRESENT	0
568059	568057	19729F	PARTICIPANT	\N	PRESENT	0
568060	568057	19713W	PARTICIPANT	\N	PRESENT	0
568063	568062	11053K	PARTICIPANT	\N	PRESENT	0
568064	568062	01028R	PARTICIPANT	\N	PRESENT	0
568068	568066	19515S	PRESIDENT	0	PRESENT	0
568069	568066	14030Q	PARTICIPANT	\N	PRESENT	0
568070	568066	14105F	PARTICIPANT	\N	PRESENT	0
568071	568066	20060X	PARTICIPANT	\N	PRESENT	0
568072	568066	14041T	PARTICIPANT	\N	PRESENT	0
568073	568066	19695N	PARTICIPANT	\N	PRESENT	0
568074	568066	20126Y	PARTICIPANT	\N	PRESENT	0
568075	568066	19697Q	PARTICIPANT	\N	PRESENT	0
568076	568066	14031R	PARTICIPANT	\N	PRESENT	0
568077	568066	19671E	PARTICIPANT	\N	PRESENT	0
568078	568066	19369B	PARTICIPANT	\N	PRESENT	0
568079	568066	08060W	PARTICIPANT	\N	EXCUSE	0
568080	568066	19545Y	PARTICIPANT	\N	EXCUSE	0
568081	568066	14026U	PARTICIPANT	\N	EXCUSE	0
568082	568066	20048C	PARTICIPANT	\N	EXCUSE	0
568083	568066	16685X	PARTICIPANT	\N	EXCUSE	0
568084	568066	08015R	PARTICIPANT	\N	EXCUSE	0
568141	568140	14231L	PARTICIPANT	\N	PRESENT	1
568142	568140	19565D	PARTICIPANT	\N	PRESENT	0
568143	568140	19333N	PARTICIPANT	\N	PRESENT	0
568144	568140	01057W	PARTICIPANT	\N	PRESENT	0
568145	568140	14327T	PARTICIPANT	\N	PRESENT	0
568146	568140	17637T	PARTICIPANT	\N	PRESENT	0
568147	568140	08010L	PARTICIPANT	\N	PRESENT	0
568148	568140	04045F	PARTICIPANT	\N	PRESENT	0
568149	568140	14215L	PARTICIPANT	\N	PRESENT	0
568150	568140	14187A	PARTICIPANT	\N	PRESENT	0
568151	568140	14071N	PARTICIPANT	\N	PRESENT	0
568152	568140	04086Q	PARTICIPANT	\N	PRESENT	1
568153	568140	19735D	PARTICIPANT	\N	PRESENT	1
568154	568140	19349W	PARTICIPANT	\N	PRESENT	1
568155	568140	19681G	PARTICIPANT	\N	PRESENT	1
568156	568140	20058E	PARTICIPANT	\N	PRESENT	1
568157	568140	14257W	PARTICIPANT	\N	PRESENT	1
568158	568140	14229S	PARTICIPANT	\N	PRESENT	1
568161	566018	14069U	PARTICIPANT	\N	PRESENT	1
568162	566018	14179A	PARTICIPANT	\N	PRESENT	1
568163	566018	11101A	PARTICIPANT	\N	PRESENT	0
568164	566018	14357A	PARTICIPANT	\N	PRESENT	0
568165	566018	20100N	PARTICIPANT	\N	PRESENT	0
568166	566018	04035D	PARTICIPANT	\N	PRESENT	0
568167	566018	19711U	PARTICIPANT	\N	PRESENT	0
568168	566018	04070G	PARTICIPANT	\N	PRESENT	1
568169	566018	14331P	PARTICIPANT	\N	PRESENT	0
568179	568177	08069G	PARTICIPANT	\N	PRESENT	0
568180	568177	20136B	PARTICIPANT	\N	PRESENT	0
568187	568186	19251M	PARTICIPANT	\N	PRESENT	0
543063	542808	11033F	PARTICIPANT	\N	EXCUSE	0
543066	543065	08017T	PARTICIPANT	\N	PRESENT	0
543068	543067	20116W	PARTICIPANT	\N	PRESENT	0
543069	543067	20042V	PARTICIPANT	\N	PRESENT	0
543070	543067	11080N	PARTICIPANT	\N	PRESENT	0
543071	543067	11074Q	PARTICIPANT	\N	PRESENT	0
543072	543067	01057W	PARTICIPANT	\N	PRESENT	0
543073	543067	14121F	PARTICIPANT	\N	PRESENT	0
543074	543067	19711U	PARTICIPANT	\N	PRESENT	0
543075	543067	19335Q	PARTICIPANT	\N	PRESENT	0
543078	543077	08060W	PARTICIPANT	\N	PRESENT	0
543079	543077	19701S	PARTICIPANT	\N	PRESENT	0
543080	543077	19681G	PARTICIPANT	\N	PRESENT	0
543081	543077	19525U	PARTICIPANT	\N	PRESENT	0
543082	543077	17229F	PARTICIPANT	\N	PRESENT	0
543083	543077	20038A	PARTICIPANT	\N	PRESENT	0
543084	543077	19599P	PARTICIPANT	\N	PRESENT	0
543085	543077	14031R	PARTICIPANT	\N	PRESENT	0
543086	543077	19826F	PARTICIPANT	\N	PRESENT	0
543087	543077	20122U	PARTICIPANT	\N	PRESENT	0
544059	544058	05008E	PARTICIPANT	\N	PRESENT	0
544060	544058	11053K	PARTICIPANT	\N	PRESENT	0
544061	544058	01028R	PARTICIPANT	\N	PRESENT	0
544996	533928	14189C	PARTICIPANT	\N	EXCUSE	0
544997	533928	20024T	PARTICIPANT	\N	PRESENT	0
544998	533928	14030Q	PRESIDENT	0	PRESENT	0
544999	533928	19693L	PARTICIPANT	\N	PRESENT	0
545000	533928	19599P	PARTICIPANT	\N	EXCUSE	0
545001	533928	20106U	PARTICIPANT	\N	PRESENT	0
545002	533928	20066E	PARTICIPANT	\N	PRESENT	0
545003	533928	19715Y	PARTICIPANT	\N	EXCUSE	0
545004	533928	20056C	PARTICIPANT	\N	PRESENT	0
545005	533928	07029T	PARTICIPANT	\N	EXCUSE	0
545006	533928	14109K	PARTICIPANT	\N	PRESENT	0
545007	533928	19866P	PARTICIPANT	\N	PRESENT	0
545008	533928	20118Y	PARTICIPANT	\N	EXCUSE	0
545009	533928	19798U	PARTICIPANT	\N	PRESENT	0
545010	533928	20098N	PARTICIPANT	\N	PRESENT	0
545011	533928	19527W	PARTICIPANT	\N	PRESENT	0
545012	533928	20046A	PARTICIPANT	\N	PRESENT	0
545013	533928	19749K	PARTICIPANT	\N	PRESENT	0
545014	533928	19575F	PARTICIPANT	\N	PRESENT	0
545286	542796	14059S	PARTICIPANT	\N	EXCUSE	0
545803	545404	20116W	PARTICIPANT	\N	PRESENT	0
545804	545404	04057K	PARTICIPANT	\N	PRESENT	0
545805	545404	14179A	PARTICIPANT	\N	PRESENT	0
545806	545404	14133K	PARTICIPANT	\N	PRESENT	0
545807	545404	04033B	PARTICIPANT	\N	PRESENT	0
545808	545404	05008E	PARTICIPANT	\N	PRESENT	0
545809	545404	14071N	PARTICIPANT	\N	PRESENT	0
545810	545404	10015M	PARTICIPANT	\N	PRESENT	0
545811	545404	14169X	PARTICIPANT	\N	PRESENT	0
545812	545404	20024T	PARTICIPANT	\N	PRESENT	0
545813	545404	19399H	PARTICIPANT	\N	PRESENT	0
545814	545404	19954N	PARTICIPANT	\N	PRESENT	0
545815	545404	08017T	PARTICIPANT	\N	PRESENT	0
545816	545404	19333N	PARTICIPANT	\N	PRESENT	0
545817	545404	19717B	PARTICIPANT	\N	PRESENT	0
545818	545404	20108W	PARTICIPANT	\N	PRESENT	0
545819	545404	19489J	PARTICIPANT	\N	PRESENT	0
545820	545404	11045K	PARTICIPANT	\N	PRESENT	0
545821	545404	11067R	PARTICIPANT	\N	PRESENT	0
545822	545404	14001X	PARTICIPANT	\N	PRESENT	0
545823	545404	19543W	PARTICIPANT	\N	PRESENT	0
545824	545404	20044X	PARTICIPANT	\N	PRESENT	0
545825	545404	20180F	PARTICIPANT	\N	PRESENT	0
545826	545404	19367Y	PARTICIPANT	\N	PRESENT	0
545827	545404	19581D	PARTICIPANT	\N	PRESENT	0
545828	545404	14237S	PARTICIPANT	\N	PRESENT	0
545829	545404	97011G	PARTICIPANT	\N	PRESENT	0
545830	545404	19689Q	PARTICIPANT	\N	PRESENT	0
545831	545404	20080C	PARTICIPANT	\N	PRESENT	0
545832	545404	19503N	PARTICIPANT	\N	PRESENT	0
545833	545404	20034V	PARTICIPANT	\N	PRESENT	0
545834	545404	19697Q	PARTICIPANT	\N	PRESENT	0
545835	545404	20110Q	PARTICIPANT	\N	PRESENT	0
545836	545404	01028R	PARTICIPANT	\N	PRESENT	0
545837	545404	19531S	PARTICIPANT	\N	PRESENT	0
545838	545404	14089Y	PARTICIPANT	\N	PRESENT	0
545839	545404	20126Y	PARTICIPANT	\N	PRESENT	0
545840	545404	14189C	PARTICIPANT	\N	PRESENT	0
545841	545404	20128B	PARTICIPANT	\N	PRESENT	0
545842	545404	20046A	PARTICIPANT	\N	PRESENT	0
545843	545404	11043H	PARTICIPANT	\N	PRESENT	0
545844	545404	08009T	PARTICIPANT	\N	PRESENT	0
545845	545404	14215L	PARTICIPANT	\N	PRESENT	0
545846	545404	19415P	PARTICIPANT	\N	PRESENT	0
545847	545404	19347U	PARTICIPANT	\N	PRESENT	0
545848	545404	08069G	PARTICIPANT	\N	PRESENT	0
545849	545404	14107H	PARTICIPANT	\N	PRESENT	0
545850	545404	14229S	PARTICIPANT	\N	PRESENT	0
545857	545404	08061X	PARTICIPANT	\N	PRESENT	0
545852	545404	19747H	PARTICIPANT	\N	PRESENT	0
545853	545404	19549D	PARTICIPANT	\N	PRESENT	0
545854	545404	14055N	PARTICIPANT	\N	PRESENT	0
545855	545404	20106U	PARTICIPANT	\N	PRESENT	0
545856	545404	19585H	PARTICIPANT	\N	PRESENT	0
545858	545404	19721W	PARTICIPANT	\N	PRESENT	0
545859	545404	20152B	PARTICIPANT	\N	PRESENT	0
545860	545404	20140W	PARTICIPANT	\N	PRESENT	0
545861	545404	14030Q	PARTICIPANT	\N	PRESENT	0
545862	545404	19643A	PARTICIPANT	\N	PRESENT	0
545863	545404	19507S	PARTICIPANT	\N	PRESENT	0
545864	545404	19826F	PARTICIPANT	\N	PRESENT	0
545865	545404	11031D	PARTICIPANT	\N	PRESENT	0
545866	545404	20134Y	PARTICIPANT	\N	PRESENT	0
545867	545404	11104D	PARTICIPANT	\N	PRESENT	0
545868	545404	19745F	PARTICIPANT	\N	PRESENT	0
545869	545404	19739H	PARTICIPANT	\N	PRESENT	0
545870	545404	19573D	PARTICIPANT	\N	PRESENT	0
545871	545404	92040Q	PARTICIPANT	\N	PRESENT	0
545872	545404	14259Y	PARTICIPANT	\N	PRESENT	0
545873	545746	04070G	PARTICIPANT	\N	PRESENT	0
545874	545746	19611R	PRESIDENT	0	PRESENT	0
545875	545746	19735D	PARTICIPANT	\N	PRESENT	0
545876	545746	14109K	PARTICIPANT	\N	PRESENT	1
545877	545746	20048C	PARTICIPANT	\N	PRESENT	0
545878	545746	20052X	PARTICIPANT	\N	PRESENT	0
545879	545746	14229S	PARTICIPANT	\N	PRESENT	0
545880	545746	19383Y	PARTICIPANT	\N	PRESENT	0
545881	545746	14331P	PARTICIPANT	\N	PRESENT	0
545882	545746	01043Q	PARTICIPANT	\N	PRESENT	0
545883	545746	14187A	PARTICIPANT	\N	PRESENT	0
545884	545746	19441R	PARTICIPANT	\N	PRESENT	0
545885	545746	11090Q	PARTICIPANT	\N	PRESENT	0
545886	545404	20026V	PARTICIPANT	\N	PRESENT	0
545887	545404	19729F	PARTICIPANT	\N	PRESENT	0
545888	545404	19447X	PARTICIPANT	\N	PRESENT	0
545890	545746	19768N	PARTICIPANT	\N	PRESENT	0
545891	545746	19701S	PARTICIPANT	\N	PRESENT	1
545892	545746	14026U	PARTICIPANT	\N	PRESENT	1
545893	545746	19631V	PARTICIPANT	\N	PRESENT	1
545894	545746	19553Y	PARTICIPANT	\N	PRESENT	1
545895	545746	19369B	PARTICIPANT	\N	PRESENT	1
545896	545746	08028W	PARTICIPANT	\N	PRESENT	1
545897	545746	20030R	PARTICIPANT	\N	PRESENT	1
545898	545746	04035D	PARTICIPANT	\N	PRESENT	1
545899	545746	19711U	PARTICIPANT	\N	PRESENT	1
545900	545746	14133K	PARTICIPANT	\N	PRESENT	0
545901	545746	11026G	PARTICIPANT	\N	PRESENT	1
545902	545746	20058E	PARTICIPANT	\N	PRESENT	0
545903	545404	20056C	PARTICIPANT	\N	PRESENT	0
545904	545746	19699S	PARTICIPANT	\N	PRESENT	0
545905	545746	04057K	PARTICIPANT	\N	PRESENT	0
545906	545746	14089Y	PARTICIPANT	\N	PRESENT	0
545907	545746	11083R	PARTICIPANT	\N	PRESENT	0
545908	545404	01024M	PARTICIPANT	\N	PRESENT	0
545909	545404	20172F	PARTICIPANT	\N	PRESENT	0
545910	545404	17779H	PARTICIPANT	\N	PRESENT	0
545911	545404	19599P	PARTICIPANT	\N	PRESENT	0
545912	545404	14251Q	PARTICIPANT	\N	PRESENT	0
545913	545404	14225N	PARTICIPANT	\N	PRESENT	0
545914	545404	08010L	PARTICIPANT	\N	PRESENT	0
545915	545404	20084G	PARTICIPANT	\N	PRESENT	0
545916	545404	20122U	PARTICIPANT	\N	PRESENT	0
545917	545746	19515S	PARTICIPANT	\N	PRESENT	0
545918	545746	14357A	PARTICIPANT	\N	PRESENT	0
545919	545746	20104S	PARTICIPANT	\N	PRESENT	0
545920	545746	14237S	PARTICIPANT	\N	PRESENT	0
545921	545746	20100N	PARTICIPANT	\N	PRESENT	0
545922	545746	20018V	PARTICIPANT	\N	PRESENT	0
553789	551453	99004R	PARTICIPANT	\N	PRESENT	0
553790	551453	11012A	PARTICIPANT	\N	PRESENT	0
553791	551453	20116W	PARTICIPANT	\N	PRESENT	0
553792	551453	20072C	PARTICIPANT	\N	PRESENT	0
553793	551453	14207L	PARTICIPANT	\N	PRESENT	0
553794	551453	20132W	PARTICIPANT	\N	PRESENT	0
553795	551453	20122U	PARTICIPANT	\N	PRESENT	0
553796	551453	20110Q	PARTICIPANT	\N	PRESENT	0
553797	551453	19347U	PARTICIPANT	\N	PRESENT	0
553798	551453	20100N	PARTICIPANT	\N	PRESENT	0
553799	551453	19713W	PARTICIPANT	\N	PRESENT	0
553800	551453	14083S	PARTICIPANT	\N	PRESENT	0
553801	551453	14179A	PARTICIPANT	\N	PRESENT	0
553802	551453	19369B	PARTICIPANT	\N	PRESENT	0
553803	551453	14030Q	PARTICIPANT	\N	PRESENT	0
553804	551453	14219Q	PARTICIPANT	\N	PRESENT	0
553805	551453	04047H	PARTICIPANT	\N	PRESENT	0
553806	551453	14069U	PARTICIPANT	\N	PRESENT	0
553807	551453	11056N	PARTICIPANT	\N	PRESENT	0
553808	551453	20114U	PARTICIPANT	\N	PRESENT	0
553809	551453	14215L	PARTICIPANT	\N	PRESENT	0
553810	551453	14213J	PARTICIPANT	\N	PRESENT	0
553811	551453	14187A	PARTICIPANT	\N	PRESENT	0
553812	551453	20090E	PARTICIPANT	\N	PRESENT	0
553813	551453	14147R	PARTICIPANT	\N	PRESENT	0
553814	551453	07029T	PARTICIPANT	\N	PRESENT	0
553815	551453	19954N	PARTICIPANT	\N	PRESENT	0
553816	551453	20026V	PARTICIPANT	\N	PRESENT	0
553817	551453	14033T	PARTICIPANT	\N	PRESENT	0
553818	551453	20044X	PARTICIPANT	\N	PRESENT	0
553819	551453	08010L	PARTICIPANT	\N	PRESENT	0
553820	551453	20128B	PARTICIPANT	\N	PRESENT	0
553821	551453	14038Y	PARTICIPANT	\N	PRESENT	0
553822	551453	19760E	PARTICIPANT	\N	PRESENT	0
553838	550138	14331P	PRESIDENT	0	PRESENT	0
553839	550138	14073Q	PARTICIPANT	\N	PRESENT	0
553840	550138	19711U	PARTICIPANT	\N	PRESENT	0
553841	550138	04034C	PARTICIPANT	\N	PRESENT	0
553842	550138	14026U	PARTICIPANT	\N	PRESENT	0
553843	550138	12041X	PARTICIPANT	\N	PRESENT	0
553844	550138	14237S	PARTICIPANT	\N	PRESENT	0
553845	550138	20104S	PARTICIPANT	\N	PRESENT	0
553846	550138	14169X	PARTICIPANT	\N	PRESENT	0
553847	550138	19725B	PARTICIPANT	\N	PRESENT	1
553849	550138	19521Q	PARTICIPANT	\N	PRESENT	1
553852	550138	20094J	PARTICIPANT	\N	PRESENT	1
553853	550138	20128B	PARTICIPANT	\N	PRESENT	1
553854	550138	12016W	PARTICIPANT	\N	PRESENT	1
553860	550138	20112S	PARTICIPANT	\N	EXCUSE	0
553861	550138	14189C	PARTICIPANT	\N	EXCUSE	0
553864	550139	14207L	PARTICIPANT	\N	PRESENT	1
553865	550139	14189C	PARTICIPANT	\N	EXCUSE	0
553869	550139	11083R	PARTICIPANT	\N	PRESENT	0
553867	550139	19701S	PARTICIPANT	\N	EXCUSE	0
553868	550139	19507S	PARTICIPANT	\N	PRESENT	0
553870	550139	20128B	PARTICIPANT	\N	PRESENT	1
553871	550139	14097Y	PARTICIPANT	\N	PRESENT	1
553872	550139	19441R	PARTICIPANT	\N	PRESENT	0
553873	550139	14237S	PARTICIPANT	\N	PRESENT	0
553874	550139	14331P	PRESIDENT	0	PRESENT	0
553875	550139	19563B	PARTICIPANT	\N	PRESENT	0
553876	550139	14001X	PARTICIPANT	\N	PRESENT	0
554117	549005	19657G	PARTICIPANT	\N	EXCUSE	0
554222	545943	20128B	PARTICIPANT	\N	PRESENT	0
554224	545943	19723Y	PARTICIPANT	\N	PRESENT	0
554225	545943	19709B	PARTICIPANT	\N	PRESENT	0
554227	545943	19533U	PARTICIPANT	\N	EXCUSE	0
554228	545943	19503N	PARTICIPANT	\N	PRESENT	0
554229	545943	01058X	PARTICIPANT	\N	PRESENT	0
554232	545943	04043D	PARTICIPANT	\N	PRESENT	0
554247	554246	05008E	PARTICIPANT	\N	PRESENT	0
554248	554246	11053K	PARTICIPANT	\N	PRESENT	0
554249	554246	01028R	PARTICIPANT	\N	PRESENT	0
554259	554258	20070A	PARTICIPANT	\N	PRESENT	0
554349	554345	14189C	PARTICIPANT	\N	PRESENT	0
554350	554345	19631V	PARTICIPANT	\N	PRESENT	1
554351	554345	19575F	PARTICIPANT	\N	PRESENT	0
554352	554345	20138D	PARTICIPANT	\N	PRESENT	1
554353	554345	19643A	PARTICIPANT	\N	PRESENT	1
554354	554345	19629C	PARTICIPANT	\N	PRESENT	1
554355	554345	19347U	PARTICIPANT	\N	PRESENT	0
554356	554345	14179A	PARTICIPANT	\N	PRESENT	0
554357	554345	20066E	PARTICIPANT	\N	PRESENT	1
554358	554345	20056C	PARTICIPANT	\N	PRESENT	0
554359	554345	20018V	PARTICIPANT	\N	PRESENT	0
554360	554345	19768N	PARTICIPANT	\N	PRESENT	0
554361	554345	14237S	PARTICIPANT	\N	PRESENT	0
554362	554345	19503N	PARTICIPANT	\N	PRESENT	0
554364	554345	14107H	PARTICIPANT	\N	PRESENT	1
554365	554345	20058E	PARTICIPANT	\N	PRESENT	0
554372	554371	19709B	PARTICIPANT	\N	PRESENT	0
554373	554371	11027H	PARTICIPANT	\N	PRESENT	0
554406	554405	14189C	PARTICIPANT	\N	PRESENT	0
554407	554405	19631V	PARTICIPANT	\N	PRESENT	0
554408	554405	19575F	PARTICIPANT	\N	PRESENT	0
554409	554405	20138D	PARTICIPANT	\N	PRESENT	1
554410	554405	19643A	PARTICIPANT	\N	PRESENT	1
554411	554405	19383Y	PARTICIPANT	\N	PRESENT	0
554412	554405	14327T	PARTICIPANT	\N	PRESENT	1
554413	554405	14187A	PARTICIPANT	\N	PRESENT	0
554414	554405	19347U	PARTICIPANT	\N	PRESENT	0
554415	554405	14179A	PARTICIPANT	\N	PRESENT	0
554416	554405	20056C	PARTICIPANT	\N	PRESENT	0
554420	554405	19768N	PARTICIPANT	\N	PRESENT	0
554418	554405	20018V	PARTICIPANT	\N	PRESENT	0
554419	554405	14109K	PARTICIPANT	\N	PRESENT	0
554421	554405	19503N	PARTICIPANT	\N	PRESENT	0
554422	554405	14107H	PARTICIPANT	\N	PRESENT	1
554423	554405	20044X	PARTICIPANT	\N	PRESENT	1
554424	554405	20058E	PARTICIPANT	\N	PRESENT	1
554522	549005	19717B	PARTICIPANT	\N	PRESENT	0
554523	549005	18083K	PARTICIPANT	\N	PRESENT	0
554524	549005	11010L	PARTICIPANT	\N	EXCUSE	0
554525	549005	19347U	PARTICIPANT	\N	PRESENT	0
554527	549005	20034V	PARTICIPANT	\N	PRESENT	0
554528	549005	19715Y	PARTICIPANT	\N	PRESENT	0
554529	549005	12016W	PARTICIPANT	\N	PRESENT	0
554530	549005	14147R	PARTICIPANT	\N	PRESENT	0
554531	549005	20148F	PARTICIPANT	\N	EXCUSE	0
554532	549005	19301E	PARTICIPANT	\N	PRESENT	0
554550	551278	14026U	PARTICIPANT	\N	PRESENT	1
554551	551278	20130U	PARTICIPANT	\N	PRESENT	1
554607	554606	19575F	PARTICIPANT	\N	PRESENT	1
554608	554606	19820Y	PARTICIPANT	\N	PRESENT	1
554609	554606	20100N	PARTICIPANT	\N	PRESENT	1
554610	554606	04045F	PARTICIPANT	\N	PRESENT	1
554611	554606	14205J	PARTICIPANT	\N	PRESENT	1
554612	554606	19701S	PARTICIPANT	\N	PRESENT	0
554613	554606	19826F	PARTICIPANT	\N	PRESENT	0
554614	554606	20136B	PARTICIPANT	\N	PRESENT	0
554616	554615	19701S	PARTICIPANT	\N	PRESENT	0
554617	554615	19826F	PARTICIPANT	\N	PRESENT	0
554618	554615	20136B	PARTICIPANT	\N	PRESENT	0
554619	554615	20100N	PARTICIPANT	\N	PRESENT	1
554620	554615	19387D	PARTICIPANT	\N	PRESENT	1
554622	554621	19701S	PARTICIPANT	\N	PRESENT	0
554623	554621	19826F	PARTICIPANT	\N	PRESENT	0
554624	554621	20136B	PARTICIPANT	\N	PRESENT	0
554625	554621	14205J	PARTICIPANT	\N	PRESENT	0
554627	554626	19701S	PARTICIPANT	\N	PRESENT	0
554628	554626	19826F	PARTICIPANT	\N	PRESENT	0
554629	554626	20136B	PARTICIPANT	\N	PRESENT	0
554630	554626	20100N	PARTICIPANT	\N	PRESENT	1
554632	554631	19701S	PARTICIPANT	\N	PRESENT	0
554633	554631	19826F	PARTICIPANT	\N	PRESENT	0
554634	554631	20136B	PARTICIPANT	\N	PRESENT	0
554636	554635	19701S	PARTICIPANT	\N	PRESENT	0
554637	554635	19826F	PARTICIPANT	\N	PRESENT	0
554638	554635	20136B	PARTICIPANT	\N	PRESENT	0
554641	554640	19663E	PARTICIPANT	\N	PRESENT	0
554642	554640	19798U	PARTICIPANT	\N	PRESENT	0
554643	554640	14213J	PARTICIPANT	\N	PRESENT	0
554644	554640	10006L	PARTICIPANT	\N	PRESENT	0
543854	543853	10015M	PARTICIPANT	\N	PRESENT	0
543855	543853	11027H	PARTICIPANT	\N	PRESENT	0
543856	543853	14213J	PARTICIPANT	\N	PRESENT	0
543857	543853	18083K	PARTICIPANT	\N	PRESENT	0
543858	543853	20024T	PARTICIPANT	\N	PRESENT	0
543859	543853	20042V	PARTICIPANT	\N	PRESENT	0
543894	543853	12016W	PARTICIPANT	\N	PRESENT	0
543915	543910	10015M	PARTICIPANT	\N	PRESENT	0
543916	543910	04035D	PARTICIPANT	\N	PRESENT	0
543917	543910	20090E	PARTICIPANT	\N	PRESENT	0
543918	543910	20042V	PARTICIPANT	\N	PRESENT	0
543919	543910	19611R	PARTICIPANT	\N	PRESENT	0
543920	543910	11065P	PARTICIPANT	\N	PRESENT	0
543921	543910	20064C	PARTICIPANT	\N	PRESENT	0
543922	543910	14255U	PARTICIPANT	\N	PRESENT	0
543923	543910	20114U	PARTICIPANT	\N	PRESENT	0
543924	543910	20084G	PARTICIPANT	\N	PRESENT	0
555154	555151	14179A	PARTICIPANT	\N	PRESENT	0
555156	555155	17779H	PARTICIPANT	\N	PRESENT	0
555157	555155	11067R	PARTICIPANT	\N	PRESENT	0
555158	555155	14179A	PARTICIPANT	\N	PRESENT	0
555160	555159	14179A	PARTICIPANT	\N	PRESENT	0
555161	555159	17779H	PARTICIPANT	\N	PRESENT	0
555172	555162	19701S	PARTICIPANT	\N	PRESENT	0
555173	555162	19503N	PARTICIPANT	\N	PRESENT	0
555174	555162	19637C	PARTICIPANT	\N	PRESENT	0
555175	555162	19387D	PARTICIPANT	\N	PRESENT	0
555176	555162	18083K	PARTICIPANT	\N	PRESENT	0
555177	555163	19701S	PARTICIPANT	\N	PRESENT	0
555178	555163	19503N	PARTICIPANT	\N	PRESENT	0
555179	555163	18083K	PARTICIPANT	\N	PRESENT	0
555180	555164	19701S	PARTICIPANT	\N	PRESENT	0
555181	555165	19701S	PARTICIPANT	\N	PRESENT	0
555182	555165	14205J	PARTICIPANT	\N	PRESENT	0
555183	555165	19575F	PARTICIPANT	\N	PRESENT	0
555184	555166	19701S	PARTICIPANT	\N	PRESENT	0
555185	555166	18083K	PARTICIPANT	\N	PRESENT	0
555186	555167	19701S	PARTICIPANT	\N	PRESENT	0
555187	555167	14205J	PARTICIPANT	\N	PRESENT	0
555188	555167	19820Y	PARTICIPANT	\N	PRESENT	0
555189	555168	19701S	PARTICIPANT	\N	PRESENT	0
555190	555169	19701S	PARTICIPANT	\N	PRESENT	0
555191	555170	19701S	PARTICIPANT	\N	PRESENT	0
555192	555171	19701S	PARTICIPANT	\N	PRESENT	0
555197	555193	19701S	PARTICIPANT	\N	PRESENT	0
555198	555194	19701S	PARTICIPANT	\N	PRESENT	0
555199	555194	14205J	PARTICIPANT	\N	PRESENT	0
555200	555195	19701S	PARTICIPANT	\N	PRESENT	0
555201	555196	19701S	PARTICIPANT	\N	PRESENT	0
555328	555327	10006L	PARTICIPANT	\N	PRESENT	0
555329	555327	14041T	PARTICIPANT	\N	PRESENT	0
555330	555327	19741B	PARTICIPANT	\N	PRESENT	0
555331	555327	14255U	PARTICIPANT	\N	PRESENT	0
555332	555327	14217N	PARTICIPANT	\N	PRESENT	0
555333	555327	18193Q	PARTICIPANT	\N	PRESENT	0
555334	555327	16685X	PARTICIPANT	\N	PRESENT	0
555335	555327	20096L	PARTICIPANT	\N	PRESENT	0
555336	555327	19745F	PARTICIPANT	\N	PRESENT	0
555337	555327	01058X	PARTICIPANT	\N	PRESENT	0
555340	555339	19826F	PARTICIPANT	\N	PRESENT	0
555377	555376	19701S	PARTICIPANT	\N	PRESENT	0
555379	555378	19701S	PARTICIPANT	\N	PRESENT	0
555380	555378	19826F	PARTICIPANT	\N	PRESENT	0
555381	555314	19701S	PARTICIPANT	\N	PRESENT	0
557308	557307	14267Y	PARTICIPANT	\N	PRESENT	0
557309	557307	19565D	PARTICIPANT	\N	PRESENT	0
557311	557310	14267Y	PARTICIPANT	\N	PRESENT	0
557312	557310	19565D	PARTICIPANT	\N	PRESENT	0
557900	557898	14205J	PARTICIPANT	\N	PRESENT	0
557901	557899	14205J	PARTICIPANT	\N	PRESENT	0
557903	557902	20042V	PARTICIPANT	\N	PRESENT	0
557905	557904	20042V	PARTICIPANT	\N	PRESENT	0
557907	557906	20042V	PARTICIPANT	\N	PRESENT	0
557908	557069	14030Q	PARTICIPANT	\N	PRESENT	0
557909	557069	19713W	PARTICIPANT	\N	PRESENT	0
557910	557069	19762G	PARTICIPANT	\N	PRESENT	0
557911	557070	14030Q	PARTICIPANT	\N	PRESENT	0
557912	557070	19713W	PARTICIPANT	\N	PRESENT	0
557913	557070	19762G	PARTICIPANT	\N	PRESENT	0
557914	557070	14109K	PARTICIPANT	\N	PRESENT	0
557917	557916	01048V	PARTICIPANT	\N	PRESENT	0
557919	557918	14225N	PARTICIPANT	\N	PRESENT	0
557920	557918	11048N	PARTICIPANT	\N	PRESENT	0
557921	557918	19741B	PARTICIPANT	\N	PRESENT	0
557922	557918	14083S	PARTICIPANT	\N	PRESENT	0
557923	557918	20070A	PARTICIPANT	\N	PRESENT	0
557924	557918	19647E	PARTICIPANT	\N	PRESENT	0
557925	557918	19479G	PARTICIPANT	\N	PRESENT	0
557927	557926	19741B	PARTICIPANT	\N	PRESENT	0
557929	557928	19741B	PARTICIPANT	\N	PRESENT	0
557931	557930	11053K	PARTICIPANT	\N	PRESENT	0
557934	557933	08009T	PARTICIPANT	\N	PRESENT	0
557940	557939	14331P	PARTICIPANT	\N	PRESENT	0
557941	557939	19725B	PARTICIPANT	\N	PRESENT	0
557942	557939	11083R	PARTICIPANT	\N	PRESENT	0
557943	557939	20100N	PARTICIPANT	\N	PRESENT	0
557944	557939	12041X	PARTICIPANT	\N	PRESENT	0
557945	557939	04057K	PARTICIPANT	\N	PRESENT	0
557947	557946	14331P	PARTICIPANT	\N	PRESENT	0
557948	557946	19725B	PARTICIPANT	\N	PRESENT	0
557949	557946	11083R	PARTICIPANT	\N	PRESENT	0
557950	557946	04057K	PARTICIPANT	\N	PRESENT	0
557952	557951	04070G	PARTICIPANT	\N	PRESENT	0
557970	557969	19667J	PARTICIPANT	\N	PRESENT	0
557971	557969	11040E	PARTICIPANT	\N	PRESENT	0
557973	557972	19667J	PARTICIPANT	\N	PRESENT	0
557974	557972	11040E	PARTICIPANT	\N	PRESENT	0
558044	558037	18193Q	PARTICIPANT	\N	PRESENT	1
558045	558037	19679N	PARTICIPANT	\N	PRESENT	1
558047	558038	18193Q	PARTICIPANT	\N	PRESENT	0
558048	558038	19679N	PARTICIPANT	\N	PRESENT	0
558055	558039	19760E	PARTICIPANT	\N	PRESENT	1
558059	558039	18193Q	PARTICIPANT	\N	PRESENT	1
558060	558039	19679N	PARTICIPANT	\N	PRESENT	1
558265	557975	11056N	PARTICIPANT	\N	PRESENT	0
558266	557975	19649G	PARTICIPANT	\N	PRESENT	0
558267	557975	19629C	PARTICIPANT	\N	PRESENT	0
558268	557975	20074E	PARTICIPANT	\N	PRESENT	0
558269	557975	14041T	PARTICIPANT	\N	PRESENT	0
558270	557975	20108W	PARTICIPANT	\N	PRESENT	0
558271	557975	14147R	PARTICIPANT	\N	PRESENT	0
558272	557975	14151M	PARTICIPANT	\N	PRESENT	0
558273	557975	14215L	PARTICIPANT	\N	PRESENT	0
558274	557975	04047H	PRESIDENT	0	PRESENT	0
558275	557975	19447X	PARTICIPANT	\N	PRESENT	0
558276	557975	05008E	PARTICIPANT	\N	PRESENT	0
558277	557975	14111D	PARTICIPANT	\N	PRESENT	0
558278	557975	11026G	PARTICIPANT	\N	PRESENT	0
558279	557975	14089Y	PARTICIPANT	\N	PRESENT	0
558280	557975	17737W	PARTICIPANT	\N	PRESENT	0
558322	557729	12041X	PARTICIPANT	\N	PRESENT	0
558326	557688	14026U	PARTICIPANT	\N	PRESENT	0
558327	557688	12028B	PARTICIPANT	\N	PRESENT	0
558328	557688	11041F	PARTICIPANT	\N	PRESENT	0
558329	557688	20116W	PARTICIPANT	\N	PRESENT	0
558330	557688	19421M	PARTICIPANT	\N	PRESENT	0
558331	557688	14105F	PARTICIPANT	\N	PRESENT	0
558332	557688	12041X	PARTICIPANT	\N	PRESENT	0
558333	557688	20072C	PARTICIPANT	\N	PRESENT	0
558334	557688	19583F	PARTICIPANT	\N	PRESENT	0
558335	557688	11103C	PARTICIPANT	\N	PRESENT	0
558336	557688	14133K	PARTICIPANT	\N	PRESENT	0
558337	557688	14267Y	PARTICIPANT	\N	PRESENT	0
558338	557688	19669L	PARTICIPANT	\N	PRESENT	0
558339	557688	11012A	PARTICIPANT	\N	PRESENT	0
558340	557688	04034C	PARTICIPANT	\N	PRESENT	0
558341	557688	97011G	PARTICIPANT	\N	PRESENT	0
558342	557688	14089Y	PARTICIPANT	\N	PRESENT	0
558343	557688	19629C	PARTICIPANT	\N	PRESENT	0
558344	557688	04042C	PARTICIPANT	\N	PRESENT	0
558345	557688	20090E	PARTICIPANT	\N	PRESENT	0
558346	557688	19565D	PARTICIPANT	\N	PRESENT	0
558347	557688	11040E	PARTICIPANT	\N	PRESENT	0
558348	557688	20130U	PARTICIPANT	\N	PRESENT	0
558349	557688	11027H	PARTICIPANT	\N	PRESENT	0
558350	557688	01062T	PARTICIPANT	\N	PRESENT	0
558351	557688	20070A	PARTICIPANT	\N	PRESENT	0
558352	557688	19347U	PARTICIPANT	\N	PRESENT	0
558353	557688	11054L	PARTICIPANT	\N	PRESENT	0
558354	557688	18083K	PARTICIPANT	\N	PRESENT	0
558355	557688	11083R	PARTICIPANT	\N	PRESENT	0
563026	561979	04085P	PARTICIPANT	\N	PRESENT	1
563027	561979	19543W	PARTICIPANT	\N	PRESENT	1
563028	561979	19954N	PARTICIPANT	\N	PRESENT	1
563029	561979	20110Q	PARTICIPANT	\N	PRESENT	1
563030	561979	11033F	PARTICIPANT	\N	PRESENT	1
563031	561979	17737W	PARTICIPANT	\N	PRESENT	1
563032	561979	19629C	PARTICIPANT	\N	PRESENT	1
563033	561979	04008A	PARTICIPANT	\N	PRESENT	1
563034	561979	14151M	PARTICIPANT	\N	PRESENT	1
563035	561979	19489J	PARTICIPANT	\N	PRESENT	1
563036	561979	19581D	PARTICIPANT	\N	PRESENT	1
563037	561979	19675J	PARTICIPANT	\N	PRESENT	1
563260	562866	19295A	PARTICIPANT	\N	EXCUSE	0
563545	563544	14331P	PARTICIPANT	\N	PRESENT	0
563546	563544	19725B	PARTICIPANT	\N	PRESENT	0
563547	563544	12041X	PARTICIPANT	\N	PRESENT	0
563548	563544	11083R	PARTICIPANT	\N	PRESENT	0
563689	563688	20070A	PARTICIPANT	\N	PRESENT	0
563690	563688	10015M	PARTICIPANT	\N	PRESENT	0
563693	563522	20062A	PARTICIPANT	\N	PRESENT	0
563694	563522	20056C	PARTICIPANT	\N	PRESENT	1
563695	563522	20048C	PRESIDENT	0	PRESENT	0
563696	563522	20084G	PARTICIPANT	\N	PRESENT	0
563697	563522	17779H	PARTICIPANT	\N	PRESENT	0
563698	563522	11067R	PARTICIPANT	\N	PRESENT	0
563740	563739	19503N	PARTICIPANT	\N	PRESENT	0
563787	548265	19723Y	PARTICIPANT	\N	EXCUSE	0
563791	548265	01058X	PARTICIPANT	\N	PRESENT	0
563792	548265	19503N	PARTICIPANT	\N	PRESENT	0
563797	548265	20066E	PARTICIPANT	\N	PRESENT	0
563798	548265	19709B	PARTICIPANT	\N	PRESENT	0
563801	548265	20072C	PARTICIPANT	\N	PRESENT	0
563806	548265	19693L	PARTICIPANT	\N	PRESENT	0
563807	548265	11067R	PARTICIPANT	\N	PRESENT	0
566369	566368	19673G	PARTICIPANT	\N	PRESENT	0
566370	566368	20134Y	PARTICIPANT	\N	PRESENT	1
566371	566368	19643A	PARTICIPANT	\N	PRESENT	1
566372	566368	20152B	PARTICIPANT	\N	PRESENT	0
566373	566368	19691J	PARTICIPANT	\N	PRESENT	0
566374	566368	04057K	PARTICIPANT	\N	PRESENT	0
566375	566368	19527W	PRESIDENT	0	PRESENT	0
566376	566368	08017T	PARTICIPANT	\N	PRESENT	1
566377	566368	18083K	PARTICIPANT	\N	PRESENT	1
566378	566368	20106U	PARTICIPANT	\N	PRESENT	1
566379	566368	14030Q	PARTICIPANT	\N	EXCUSE	0
566383	566382	14133K	PARTICIPANT	\N	PRESENT	0
566384	566382	04085P	PARTICIPANT	\N	PRESENT	0
566385	566382	04047H	PARTICIPANT	\N	PRESENT	0
566386	566382	11053K	PARTICIPANT	\N	PRESENT	0
566387	566382	19719D	PARTICIPANT	\N	PRESENT	0
566388	566382	10006L	PARTICIPANT	\N	PRESENT	0
566389	566382	19347U	PARTICIPANT	\N	PRESENT	0
566390	566382	14026U	PARTICIPANT	\N	PRESENT	0
566391	566382	11048N	PARTICIPANT	\N	PRESENT	0
566392	566382	99004R	PARTICIPANT	\N	PRESENT	0
566393	566382	12041X	PARTICIPANT	\N	PRESENT	0
566394	566382	01043Q	PARTICIPANT	\N	PRESENT	0
566395	566382	14219Q	PARTICIPANT	\N	PRESENT	0
566396	566382	14251Q	PARTICIPANT	\N	PRESENT	0
566397	566382	11085T	PARTICIPANT	\N	PRESENT	0
566398	566382	08061X	PARTICIPANT	\N	PRESENT	0
566399	566382	11090Q	PARTICIPANT	\N	PRESENT	0
566400	566382	14331P	PARTICIPANT	\N	PRESENT	0
566401	566382	14225N	PARTICIPANT	\N	PRESENT	0
566402	566382	04033B	PARTICIPANT	\N	PRESENT	0
566403	566382	14229S	PARTICIPANT	\N	PRESENT	0
566404	566382	11045K	PARTICIPANT	\N	PRESENT	0
566405	566382	01034P	PARTICIPANT	\N	PRESENT	0
566901	564488	20136B	PARTICIPANT	\N	PRESENT	0
566902	564488	20068G	PARTICIPANT	\N	PRESENT	0
566903	564488	14031R	PARTICIPANT	\N	PRESENT	0
566904	564488	11101A	PARTICIPANT	\N	PRESENT	0
566905	564488	20140W	PARTICIPANT	\N	PRESENT	0
566906	564488	19549D	PARTICIPANT	\N	PRESENT	0
566907	564488	20076G	PARTICIPANT	\N	PRESENT	0
566908	564488	20020P	PARTICIPANT	\N	PRESENT	0
566909	564488	14221J	PARTICIPANT	\N	PRESENT	0
566910	564488	20096L	PARTICIPANT	\N	PRESENT	0
566911	564488	17229F	PARTICIPANT	\N	PRESENT	0
566912	564488	17637T	PARTICIPANT	\N	PRESENT	0
566913	564488	14219Q	PRESIDENT	0	PRESENT	0
566914	564488	19251M	PARTICIPANT	\N	PRESENT	0
566915	564488	14231L	PARTICIPANT	\N	PRESENT	0
566916	564488	14259Y	PARTICIPANT	\N	PRESENT	0
566917	564488	19333N	PARTICIPANT	\N	PRESENT	0
566918	564488	20038A	PARTICIPANT	\N	PRESENT	0
566919	564488	18083K	PARTICIPANT	\N	PRESENT	0
566920	564488	19745F	PARTICIPANT	\N	PRESENT	0
566921	564488	14169X	PARTICIPANT	\N	PRESENT	0
566922	564488	19739H	PARTICIPANT	\N	PRESENT	0
566923	564488	05012A	PARTICIPANT	\N	PRESENT	1
566924	564488	19619A	PARTICIPANT	\N	PRESENT	1
566925	564488	19637C	PARTICIPANT	\N	PRESENT	1
566926	564488	20118Y	PARTICIPANT	\N	PRESENT	0
566927	564488	19685L	PARTICIPANT	\N	PRESENT	0
566928	564488	19503N	PARTICIPANT	\N	PRESENT	0
566929	564488	19551W	PARTICIPANT	\N	PRESENT	0
566930	564488	20106U	PARTICIPANT	\N	PRESENT	0
566931	564488	20102Q	PARTICIPANT	\N	PRESENT	0
566932	564488	19820Y	PARTICIPANT	\N	PRESENT	1
566933	564488	19387D	PARTICIPANT	\N	PRESENT	1
566934	564488	19599P	PARTICIPANT	\N	PRESENT	0
566935	564488	20100N	PARTICIPANT	\N	PRESENT	0
566941	566014	14053L	PARTICIPANT	\N	PRESENT	0
566942	566014	14111D	PARTICIPANT	\N	PRESENT	0
566943	566014	20074E	PARTICIPANT	\N	PRESENT	0
566944	566014	04047H	PRESIDENT	0	PRESENT	0
566945	566014	01028R	PARTICIPANT	\N	PRESENT	0
566946	566014	05008E	PARTICIPANT	\N	PRESENT	0
566947	566014	19447X	PARTICIPANT	\N	PRESENT	0
566948	566014	14089Y	PARTICIPANT	\N	PRESENT	0
566949	566014	11056N	PARTICIPANT	\N	PRESENT	0
566950	566014	19729F	PARTICIPANT	\N	PRESENT	0
566951	566014	95063L	PARTICIPANT	\N	PRESENT	0
566952	566014	14041T	PARTICIPANT	\N	PRESENT	0
566953	566014	14147R	PARTICIPANT	\N	PRESENT	0
566954	566014	14215L	PARTICIPANT	\N	PRESENT	0
566955	566014	14021P	PARTICIPANT	\N	PRESENT	0
566956	566014	20108W	PARTICIPANT	\N	PRESENT	0
566966	565471	20142Y	PARTICIPANT	\N	PRESENT	0
566967	565471	20048C	PARTICIPANT	\N	PRESENT	0
566968	565471	19399H	PARTICIPANT	\N	PRESENT	0
566971	565471	19527W	PARTICIPANT	\N	PRESENT	0
566972	565471	19693L	PARTICIPANT	\N	PRESENT	0
566973	565471	20052X	PARTICIPANT	\N	PRESENT	0
566974	565471	14030Q	PARTICIPANT	\N	PRESENT	0
566975	565471	20098N	PARTICIPANT	\N	PRESENT	0
566976	565471	19735D	PARTICIPANT	\N	PRESENT	0
566977	565471	20084G	PARTICIPANT	\N	PRESENT	0
566978	566016	14053L	PARTICIPANT	\N	PRESENT	0
566979	566016	14111D	PARTICIPANT	\N	PRESENT	0
566980	566016	20074E	PARTICIPANT	\N	PRESENT	0
566981	566016	04047H	PRESIDENT	0	PRESENT	0
566982	566016	01028R	PARTICIPANT	\N	PRESENT	0
566983	566016	05008E	PARTICIPANT	\N	PRESENT	0
566984	566016	19447X	PARTICIPANT	\N	PRESENT	0
566985	566016	14231L	PARTICIPANT	\N	PRESENT	0
566986	566016	14089Y	PARTICIPANT	\N	PRESENT	0
566987	566016	19725B	PARTICIPANT	\N	PRESENT	0
566988	566016	11056N	PARTICIPANT	\N	PRESENT	0
566989	566016	19729F	PARTICIPANT	\N	PRESENT	0
566990	566016	95063L	PARTICIPANT	\N	PRESENT	0
566991	566016	14041T	PARTICIPANT	\N	PRESENT	0
566992	566016	14147R	PARTICIPANT	\N	PRESENT	0
566993	566016	14215L	PARTICIPANT	\N	PRESENT	0
566994	566016	14259Y	PARTICIPANT	\N	PRESENT	0
566995	566016	11072N	PARTICIPANT	\N	PRESENT	0
566996	566016	14021P	PARTICIPANT	\N	PRESENT	0
566997	565268	20130U	PARTICIPANT	\N	PRESENT	1
566998	565268	19697Q	PARTICIPANT	\N	PRESENT	1
566999	565268	11067R	PARTICIPANT	\N	PRESENT	0
567000	565268	04092N	PARTICIPANT	0	PRESENT	0
567001	565268	19713W	PARTICIPANT	\N	PRESENT	0
567002	565268	11097X	PARTICIPANT	\N	PRESENT	0
567003	565268	20040T	PARTICIPANT	\N	PRESENT	0
567004	565268	19415P	PARTICIPANT	\N	PRESENT	0
567005	565268	19691J	PARTICIPANT	\N	PRESENT	0
567006	565268	14223L	PARTICIPANT	\N	PRESENT	0
542320	541389	19489J	PARTICIPANT	\N	PRESENT	1
542321	541389	11026G	PARTICIPANT	\N	PRESENT	1
542322	541389	14147R	PARTICIPANT	\N	PRESENT	1
545291	545287	20130U	PARTICIPANT	\N	PRESENT	0
545292	545287	19679N	PARTICIPANT	\N	PRESENT	0
545293	545288	19679N	PARTICIPANT	\N	PRESENT	0
545294	545290	20130U	PARTICIPANT	\N	PRESENT	0
545295	545290	19679N	PARTICIPANT	\N	PRESENT	0
545296	537066	14275Y	PARTICIPANT	\N	EXCUSE	0
545297	537069	14275Y	PARTICIPANT	\N	EXCUSE	0
545301	545300	11072N	PARTICIPANT	\N	PRESENT	0
545302	545300	14069U	PARTICIPANT	\N	PRESENT	0
545304	545303	14069U	PARTICIPANT	\N	PRESENT	0
545305	545303	11072N	PARTICIPANT	\N	PRESENT	0
545307	545306	14069U	PARTICIPANT	\N	PRESENT	0
545308	545306	11072N	PARTICIPANT	\N	PRESENT	0
545310	545309	14069U	PARTICIPANT	\N	PRESENT	0
545311	545309	11072N	PARTICIPANT	\N	PRESENT	0
545313	545312	14147R	PARTICIPANT	\N	PRESENT	0
545923	545746	20128B	PARTICIPANT	\N	PRESENT	0
545924	545746	14329V	PARTICIPANT	\N	PRESENT	0
545925	545746	20034V	PARTICIPANT	\N	PRESENT	0
545926	545746	14189C	PARTICIPANT	\N	PRESENT	0
545927	545746	20144B	PARTICIPANT	\N	PRESENT	0
545928	545746	19251M	PARTICIPANT	\N	PRESENT	0
545929	545746	19747H	PARTICIPANT	\N	PRESENT	0
545930	545746	14257W	PARTICIPANT	\N	PRESENT	0
545931	545746	19399H	PARTICIPANT	\N	PRESENT	0
545932	545746	19511N	PARTICIPANT	\N	PRESENT	0
545933	545404	17737W	PARTICIPANT	\N	PRESENT	0
545934	545746	14038Y	PARTICIPANT	\N	PRESENT	0
545935	545746	14207L	PARTICIPANT	\N	PRESENT	0
545936	545746	20088L	PARTICIPANT	\N	PRESENT	1
545937	545746	04045F	PARTICIPANT	\N	PRESENT	1
545938	545746	20174H	PARTICIPANT	\N	PRESENT	1
545939	545746	19725B	PARTICIPANT	\N	PRESENT	0
545940	545746	14169X	PARTICIPANT	\N	PRESENT	1
545941	545404	20066E	PARTICIPANT	\N	PRESENT	0
545947	545404	20092G	PARTICIPANT	\N	PRESENT	0
545948	545404	14217N	PARTICIPANT	\N	PRESENT	0
545949	545404	14221J	PARTICIPANT	\N	PRESENT	0
545950	545746	20062A	PARTICIPANT	\N	PRESENT	1
545951	545746	19705W	PARTICIPANT	\N	PRESENT	1
545952	545746	19575F	PARTICIPANT	\N	PRESENT	1
545953	545404	14147R	PARTICIPANT	\N	PRESENT	0
545954	545404	19527W	PARTICIPANT	\N	PRESENT	0
545955	545404	19515S	PARTICIPANT	\N	PRESENT	0
545965	545404	11048N	PARTICIPANT	\N	PRESENT	0
545966	545404	11012A	PARTICIPANT	\N	PRESENT	0
545967	545404	20138D	PARTICIPANT	\N	PRESENT	0
545968	545404	14083S	PARTICIPANT	\N	PRESENT	0
545969	545404	20136B	PARTICIPANT	\N	PRESENT	0
545970	543955	19383Y	PARTICIPANT	\N	PRESENT	0
545971	543955	14331P	PARTICIPANT	\N	PRESENT	0
545972	543955	04070G	PARTICIPANT	\N	PRESENT	0
545973	543955	19768N	PARTICIPANT	\N	PRESENT	0
545974	543955	19515S	PARTICIPANT	\N	PRESENT	0
545975	543955	19699S	PARTICIPANT	\N	PRESENT	0
545976	543955	01043Q	PARTICIPANT	\N	PRESENT	0
545977	543955	14357A	PARTICIPANT	\N	PRESENT	0
545978	543955	19441R	PARTICIPANT	\N	PRESENT	0
545979	543955	20104S	PARTICIPANT	\N	PRESENT	0
545980	543955	14229S	PARTICIPANT	\N	PRESENT	0
545981	543955	20100N	PARTICIPANT	\N	PRESENT	0
545982	543955	14237S	PARTICIPANT	\N	PRESENT	0
545983	543955	20018V	PARTICIPANT	\N	PRESENT	0
545984	543955	19511N	PARTICIPANT	\N	PRESENT	0
545985	543955	20128B	PARTICIPANT	\N	PRESENT	0
545986	543955	14329V	PARTICIPANT	\N	PRESENT	0
545987	543955	14038Y	PARTICIPANT	\N	PRESENT	0
545988	543955	20034V	PARTICIPANT	\N	PRESENT	0
545989	543955	04057K	PARTICIPANT	\N	PRESENT	0
545990	543955	14189C	PARTICIPANT	\N	PRESENT	0
545991	543955	14133K	PARTICIPANT	\N	PRESENT	0
545992	543955	14187A	PARTICIPANT	\N	PRESENT	0
545993	543955	19611R	PARTICIPANT	\N	PRESENT	0
545994	543955	20144B	PARTICIPANT	\N	PRESENT	0
545995	543955	20048C	PARTICIPANT	\N	PRESENT	0
545996	543955	19251M	PARTICIPANT	\N	PRESENT	0
545997	543955	11090Q	PRESIDENT	0	PRESENT	0
545998	543955	19399H	PARTICIPANT	\N	PRESENT	0
545999	543955	20052X	PARTICIPANT	\N	PRESENT	0
546000	543955	20058E	PARTICIPANT	\N	PRESENT	0
546001	543955	19725B	PARTICIPANT	\N	PRESENT	0
546002	543955	14089Y	PARTICIPANT	\N	PRESENT	0
546003	543955	19735D	PARTICIPANT	\N	PRESENT	0
546004	543955	11083R	PARTICIPANT	\N	PRESENT	0
546005	543955	14123H	PARTICIPANT	\N	PRESENT	0
546006	543955	19747H	PARTICIPANT	\N	PRESENT	0
546007	543955	14207L	PARTICIPANT	\N	PRESENT	0
546008	543955	14257W	PARTICIPANT	\N	PRESENT	0
546009	545404	19741B	PARTICIPANT	\N	PRESENT	0
546010	545404	11077T	PARTICIPANT	\N	PRESENT	0
546011	545404	19687N	PARTICIPANT	\N	PRESENT	0
546012	545404	14053L	PARTICIPANT	\N	PRESENT	0
546013	544751	14237S	PARTICIPANT	\N	PRESENT	0
546014	544751	11048N	PARTICIPANT	\N	PRESENT	0
546015	544751	20076G	PARTICIPANT	\N	PRESENT	0
546016	544751	19503N	PARTICIPANT	\N	PRESENT	0
546017	544751	20092G	PARTICIPANT	\N	PRESENT	0
546018	544751	14357A	PRESIDENT	0	PRESENT	0
546019	544751	19739H	PARTICIPANT	\N	PRESENT	0
546020	544751	19820Y	PARTICIPANT	\N	PRESENT	1
546021	544751	19619A	PARTICIPANT	\N	PRESENT	1
546023	545404	11097X	PARTICIPANT	\N	PRESENT	0
546024	545404	14329V	PARTICIPANT	\N	PRESENT	0
546025	544751	19507S	PARTICIPANT	\N	PRESENT	0
546026	544751	20070A	PARTICIPANT	\N	PRESENT	0
546027	545404	14267Y	PARTICIPANT	\N	PRESENT	0
546028	545404	19699S	PARTICIPANT	\N	PRESENT	0
546032	545404	14213J	PARTICIPANT	\N	PRESENT	0
546030	545404	19735D	PARTICIPANT	\N	PRESENT	0
546031	545404	20114U	PARTICIPANT	\N	PRESENT	0
546033	545404	19725B	PARTICIPANT	\N	PRESENT	0
546034	545404	19383Y	PARTICIPANT	\N	PRESENT	0
546035	545404	20100N	PARTICIPANT	\N	PRESENT	0
546036	545404	01060R	PARTICIPANT	\N	PRESENT	0
546037	545404	01025N	PARTICIPANT	\N	PRESENT	0
546038	545404	04070G	PARTICIPANT	\N	PRESENT	0
546039	545404	20118Y	PARTICIPANT	\N	PRESENT	0
546040	545404	11053K	PARTICIPANT	\N	PRESENT	0
546044	545404	14257W	PARTICIPANT	\N	PRESENT	0
546049	545404	19966S	PARTICIPANT	\N	PRESENT	0
546051	544751	14033T	PARTICIPANT	\N	PRESENT	0
546052	544751	20054A	PARTICIPANT	\N	PRESENT	0
546053	545404	16685X	PARTICIPANT	\N	PRESENT	0
546054	544751	20126Y	PARTICIPANT	\N	PRESENT	0
546055	545404	19479G	PARTICIPANT	\N	PRESENT	0
546056	545404	20058E	PARTICIPANT	\N	PRESENT	0
546057	545746	14123H	PARTICIPANT	\N	PRESENT	0
546058	544337	19333N	PARTICIPANT	\N	PRESENT	0
546059	544337	20032T	PARTICIPANT	\N	PRESENT	1
546060	544337	20136B	PARTICIPANT	\N	PRESENT	1
546061	544337	14031R	PARTICIPANT	\N	PRESENT	0
546062	544337	20140W	PARTICIPANT	\N	PRESENT	1
546063	544337	19549D	PARTICIPANT	\N	PRESENT	0
546064	544337	19387D	PARTICIPANT	\N	PRESENT	1
546065	544337	19820Y	PARTICIPANT	\N	PRESENT	1
546066	544337	14219Q	PRESIDENT	0	PRESENT	0
546067	544337	19251M	PARTICIPANT	\N	PRESENT	0
546068	544337	19599P	PARTICIPANT	\N	PRESENT	0
546069	544337	20096L	PARTICIPANT	\N	PRESENT	0
546070	544337	14169X	PARTICIPANT	\N	PRESENT	0
546071	544337	19637C	PARTICIPANT	\N	PRESENT	1
546072	544337	18083K	PARTICIPANT	\N	PRESENT	0
546073	544337	14237S	PARTICIPANT	\N	PRESENT	0
546074	544337	20100N	PARTICIPANT	\N	PRESENT	0
546075	544337	19503N	PARTICIPANT	\N	PRESENT	0
546076	544337	19739H	PARTICIPANT	\N	PRESENT	0
546077	544337	19745F	PARTICIPANT	\N	PRESENT	0
546078	544337	11065P	PARTICIPANT	\N	PRESENT	0
546079	544337	20120S	PARTICIPANT	\N	PRESENT	1
546090	545404	11085T	PARTICIPANT	\N	PRESENT	0
546096	545404	20018V	PARTICIPANT	\N	PRESENT	0
546102	545404	14097Y	PARTICIPANT	\N	PRESENT	0
546103	544337	20144B	PARTICIPANT	\N	PRESENT	0
546104	544337	11101A	PARTICIPANT	\N	PRESENT	0
546105	544337	19685L	PARTICIPANT	\N	EXCUSE	0
546114	545404	19611R	PARTICIPANT	\N	PRESENT	0
546115	545404	19691J	PARTICIPANT	\N	PRESENT	0
546116	545404	20104S	PARTICIPANT	\N	PRESENT	0
554645	554640	20066E	PARTICIPANT	\N	PRESENT	0
554646	554640	19553Y	PARTICIPANT	\N	PRESENT	0
554648	554639	20024T	PARTICIPANT	\N	PRESENT	0
554649	554639	20138D	PARTICIPANT	\N	PRESENT	0
554650	554639	19749K	PARTICIPANT	\N	PRESENT	0
554651	554639	19667J	PARTICIPANT	\N	PRESENT	0
554652	554639	10006L	PARTICIPANT	\N	PRESENT	0
554653	554639	19663E	PARTICIPANT	\N	PRESENT	0
554654	554639	19798U	PARTICIPANT	\N	PRESENT	0
554655	554639	14213J	PARTICIPANT	\N	PRESENT	0
554656	554639	19553Y	PARTICIPANT	\N	PRESENT	0
554686	554685	14331P	PARTICIPANT	\N	PRESENT	0
554687	554685	11083R	PARTICIPANT	\N	PRESENT	0
554688	554685	19725B	PARTICIPANT	\N	PRESENT	0
554704	554703	14331P	PARTICIPANT	\N	PRESENT	0
554705	554703	19725B	PARTICIPANT	\N	PRESENT	0
554706	554703	11083R	PARTICIPANT	\N	PRESENT	0
554707	554703	20100N	PARTICIPANT	\N	PRESENT	0
554711	554710	14133K	PARTICIPANT	\N	PRESENT	0
554712	554710	14097Y	PARTICIPANT	\N	PRESENT	0
554713	554710	11083R	PARTICIPANT	\N	PRESENT	0
554715	554714	14133K	PARTICIPANT	\N	PRESENT	0
554716	554714	14097Y	PARTICIPANT	\N	PRESENT	0
554717	554714	11083R	PARTICIPANT	\N	PRESENT	0
554718	554714	11115U	PARTICIPANT	\N	PRESENT	0
554720	554719	14133K	PARTICIPANT	\N	PRESENT	0
554721	554719	14097Y	PARTICIPANT	\N	PRESENT	0
554722	554719	11083R	PARTICIPANT	\N	PRESENT	0
554780	554779	19723Y	PARTICIPANT	\N	PRESENT	0
554782	554779	19735D	PARTICIPANT	\N	PRESENT	0
554788	554784	14033T	PARTICIPANT	\N	PRESENT	0
554790	554789	14033T	PARTICIPANT	\N	PRESENT	0
554791	554785	14033T	PARTICIPANT	\N	PRESENT	0
554792	554786	14033T	PARTICIPANT	\N	PRESENT	0
554793	554787	14033T	PARTICIPANT	\N	PRESENT	0
554794	547927	20114U	PARTICIPANT	\N	PRESENT	1
554795	547927	19693L	PARTICIPANT	\N	PRESENT	0
554796	547927	19643A	PARTICIPANT	\N	PRESENT	1
554797	547927	20172F	PARTICIPANT	\N	PRESENT	1
554798	547927	20180F	PARTICIPANT	\N	PRESENT	1
554799	547927	19611R	PARTICIPANT	\N	PRESENT	0
554800	547927	19735D	PARTICIPANT	\N	EXCUSE	0
554801	547927	14147R	PARTICIPANT	\N	PRESENT	1
554802	547927	19593H	PRESIDENT	0	PRESENT	0
554803	547927	19745F	PARTICIPANT	\N	PRESENT	1
554804	547927	19533U	PARTICIPANT	\N	PRESENT	0
554805	547927	20132W	PARTICIPANT	\N	PRESENT	1
554806	547927	19715Y	PARTICIPANT	\N	PRESENT	1
554807	552602	19611R	PARTICIPANT	\N	PRESENT	0
554808	552602	19593H	PRESIDENT	0	PRESENT	0
554809	552602	19643A	PARTICIPANT	\N	PRESENT	0
554810	552602	20142Y	PARTICIPANT	\N	PRESENT	0
554811	552602	14147R	PARTICIPANT	\N	PRESENT	0
554812	552602	20180F	PARTICIPANT	\N	PRESENT	0
554813	552602	20082E	PARTICIPANT	\N	PRESENT	0
554814	552602	19721W	PARTICIPANT	\N	PRESENT	0
554815	552602	19533U	PARTICIPANT	\N	PRESENT	0
554816	552602	20114U	PARTICIPANT	\N	PRESENT	0
554817	552602	19735D	PARTICIPANT	\N	PRESENT	0
554819	554818	14133K	PARTICIPANT	\N	PRESENT	0
554820	554818	14147R	PARTICIPANT	\N	PRESENT	0
554821	554818	14217N	PARTICIPANT	\N	PRESENT	0
554822	554818	11026G	PARTICIPANT	\N	PRESENT	0
554853	554848	14205J	PARTICIPANT	\N	PRESENT	0
554854	554848	04045F	PARTICIPANT	\N	PRESENT	0
554857	554856	14205J	PARTICIPANT	\N	PRESENT	1
554858	554849	14033T	PARTICIPANT	\N	PRESENT	0
554859	554850	14033T	PARTICIPANT	\N	PRESENT	0
554860	554851	14033T	PARTICIPANT	\N	PRESENT	0
554861	554852	14033T	PARTICIPANT	\N	PRESENT	0
554863	554855	14033T	PARTICIPANT	\N	PRESENT	0
554865	554862	14205J	PARTICIPANT	\N	PRESENT	0
554866	554862	20092G	PARTICIPANT	\N	PRESENT	0
554868	554867	14187A	PARTICIPANT	\N	PRESENT	0
554869	554867	01043Q	PARTICIPANT	\N	PRESENT	0
554871	554870	19575F	PARTICIPANT	\N	PRESENT	0
554872	554870	20094J	PARTICIPANT	\N	PRESENT	0
554873	554870	14069U	PARTICIPANT	\N	PRESENT	0
554874	554870	14083S	PARTICIPANT	\N	PRESENT	0
554875	554870	19721W	PARTICIPANT	\N	PRESENT	0
554876	554870	14038Y	PARTICIPANT	\N	PRESENT	0
554877	554870	14357A	PARTICIPANT	\N	PRESENT	0
554878	554870	01024M	PARTICIPANT	\N	PRESENT	0
554879	554870	20174H	PARTICIPANT	\N	PRESENT	0
554880	554870	20038A	PARTICIPANT	\N	PRESENT	0
554881	554870	14033T	PARTICIPANT	\N	PRESENT	0
554882	554870	19333N	PARTICIPANT	\N	PRESENT	0
554883	554870	20126Y	PARTICIPANT	\N	PRESENT	0
554884	554870	19711U	PARTICIPANT	\N	PRESENT	0
554885	554870	14257W	PARTICIPANT	\N	PRESENT	0
554886	554870	19533U	PARTICIPANT	\N	PRESENT	0
554887	554870	19619A	PARTICIPANT	\N	PRESENT	0
554888	554870	19413M	PARTICIPANT	\N	PRESENT	0
554890	554889	14255U	PARTICIPANT	\N	PRESENT	0
554891	554889	19701S	PARTICIPANT	\N	PRESENT	0
554892	554889	11027H	PARTICIPANT	\N	PRESENT	0
554893	554889	19762G	PARTICIPANT	\N	PRESENT	0
554894	554889	11026G	PARTICIPANT	\N	PRESENT	0
554925	554543	14026U	PARTICIPANT	\N	PRESENT	1
554926	554543	19717B	PARTICIPANT	\N	PRESENT	1
554927	554543	14217N	PARTICIPANT	\N	PRESENT	1
554928	554543	17965H	PARTICIPANT	\N	PRESENT	1
554929	554542	19717B	PARTICIPANT	\N	PRESENT	1
554930	554542	14026U	PARTICIPANT	\N	PRESENT	1
554931	554542	17965H	PARTICIPANT	\N	PRESENT	1
554932	554542	14217N	PARTICIPANT	\N	PRESENT	1
554948	554947	14205J	PARTICIPANT	\N	PRESENT	1
554950	554949	14205J	PARTICIPANT	\N	PRESENT	0
554951	554949	14207L	PARTICIPANT	\N	PRESENT	0
554953	554952	14205J	PARTICIPANT	\N	PRESENT	1
554966	554954	19701S	PARTICIPANT	\N	PRESENT	0
554990	554958	19826F	PARTICIPANT	\N	PRESENT	0
554968	554954	19503N	PARTICIPANT	\N	PRESENT	0
554969	554954	20100N	PARTICIPANT	\N	PRESENT	0
554970	554955	19701S	PARTICIPANT	\N	PRESENT	0
554989	554954	19826F	PARTICIPANT	\N	PRESENT	0
554973	554955	19503N	PARTICIPANT	\N	PRESENT	0
554975	554955	20100N	PARTICIPANT	\N	PRESENT	0
554976	554957	19701S	PARTICIPANT	\N	PRESENT	0
554980	554957	19503N	PARTICIPANT	\N	PRESENT	0
554978	554957	20100N	PARTICIPANT	\N	PRESENT	0
554982	554957	19826F	PARTICIPANT	\N	PRESENT	0
554984	554956	19826F	PARTICIPANT	\N	PRESENT	0
554983	554956	19701S	PARTICIPANT	\N	PRESENT	0
554985	554956	20100N	PARTICIPANT	\N	PRESENT	0
554986	554956	19503N	PARTICIPANT	\N	PRESENT	0
554987	554956	19637C	PARTICIPANT	\N	PRESENT	0
554988	554955	19826F	PARTICIPANT	\N	PRESENT	0
554991	554958	19701S	PARTICIPANT	\N	PRESENT	0
554992	554958	20136B	PARTICIPANT	\N	PRESENT	0
554993	554958	19503N	PARTICIPANT	\N	PRESENT	0
554994	554958	20100N	PARTICIPANT	\N	PRESENT	0
554995	554958	14169X	PARTICIPANT	\N	PRESENT	0
554996	552407	19826F	PARTICIPANT	\N	PRESENT	0
554997	552407	19701S	PARTICIPANT	\N	PRESENT	0
554998	552407	20136B	PARTICIPANT	\N	PRESENT	0
554999	552407	19503N	PARTICIPANT	\N	PRESENT	0
555000	554959	19826F	PARTICIPANT	\N	PRESENT	0
555001	554959	19701S	PARTICIPANT	\N	PRESENT	0
555002	554959	20136B	PARTICIPANT	\N	PRESENT	0
555003	554959	19503N	PARTICIPANT	\N	PRESENT	0
555004	554959	20100N	PARTICIPANT	\N	PRESENT	0
555005	554960	19826F	PARTICIPANT	\N	PRESENT	0
555006	554960	19701S	PARTICIPANT	\N	PRESENT	0
555007	554960	20136B	PARTICIPANT	\N	PRESENT	0
555008	554960	19503N	PARTICIPANT	\N	PRESENT	0
555009	554961	19826F	PARTICIPANT	\N	PRESENT	0
555010	554961	20136B	PARTICIPANT	\N	PRESENT	0
555011	554961	14205J	PARTICIPANT	\N	PRESENT	0
555012	554961	19503N	PARTICIPANT	\N	PRESENT	0
555013	554961	18083K	PARTICIPANT	\N	PRESENT	0
555026	553339	18193Q	PARTICIPANT	\N	PRESENT	0
555027	553339	19679N	PARTICIPANT	\N	PRESENT	0
555028	553339	17965H	PARTICIPANT	\N	PRESENT	0
555043	550930	19735D	PARTICIPANT	\N	PRESENT	1
555044	550931	19735D	PARTICIPANT	\N	PRESENT	1
555045	550931	19533U	PARTICIPANT	\N	PRESENT	1
555252	551812	04043D	PARTICIPANT	\N	PRESENT	0
555300	555299	19701S	PARTICIPANT	\N	PRESENT	0
542542	537399	19515S	PRESIDENT	0	PRESENT	0
542543	537399	14105F	PARTICIPANT	\N	PRESENT	0
542544	537399	14026U	PARTICIPANT	\N	PRESENT	0
542545	537399	20048C	PARTICIPANT	\N	PRESENT	0
542546	537399	16685X	PARTICIPANT	\N	PRESENT	0
542547	537399	20082E	PARTICIPANT	\N	PRESENT	0
542548	537399	19467C	PARTICIPANT	\N	PRESENT	0
542549	537399	19717B	PARTICIPANT	\N	PRESENT	0
542550	537399	14083S	PARTICIPANT	\N	PRESENT	0
542551	537399	19695N	PARTICIPANT	\N	PRESENT	0
542552	537399	19575F	PARTICIPANT	\N	PRESENT	0
542553	537399	19369B	PARTICIPANT	\N	PRESENT	0
542555	537399	20040T	PARTICIPANT	\N	PRESENT	0
542556	537399	19762G	PARTICIPANT	\N	PRESENT	0
542557	537399	20092G	PARTICIPANT	\N	PRESENT	0
542559	537399	20126Y	PARTICIPANT	\N	PRESENT	0
542560	537399	14357A	PARTICIPANT	\N	PRESENT	0
542562	537399	19760E	PARTICIPANT	\N	EXCUSE	0
542563	537399	08060W	PARTICIPANT	\N	EXCUSE	0
542564	537399	19545Y	PARTICIPANT	\N	EXCUSE	0
542565	537399	08028W	PARTICIPANT	\N	EXCUSE	0
542567	537399	08015R	PARTICIPANT	\N	EXCUSE	0
542568	537399	14031R	PARTICIPANT	\N	EXCUSE	0
542569	537399	20054A	PARTICIPANT	\N	EXCUSE	0
542575	534228	08012N	PARTICIPANT	\N	EXCUSE	0
542576	534228	20032T	PARTICIPANT	\N	PRESENT	0
542577	534228	19954N	PARTICIPANT	\N	PRESENT	0
542578	534228	11040E	PARTICIPANT	\N	PRESENT	0
542579	534228	19747H	PARTICIPANT	\N	PRESENT	0
542580	534228	19643A	PARTICIPANT	\N	PRESENT	0
542582	534228	14038Y	PARTICIPANT	\N	PRESENT	0
542583	534228	11056N	PARTICIPANT	\N	PRESENT	0
542584	534228	19553Y	PARTICIPANT	\N	PRESENT	0
542585	534228	99004R	PARTICIPANT	\N	PRESENT	0
542586	534228	19711U	PARTICIPANT	\N	PRESENT	0
542587	534228	11097X	PARTICIPANT	\N	PRESENT	0
542588	534228	19479G	PARTICIPANT	\N	PRESENT	0
543059	543058	14147R	PARTICIPANT	\N	PRESENT	0
543061	543060	14147R	PARTICIPANT	\N	PRESENT	0
543062	543060	19749K	PARTICIPANT	\N	PRESENT	0
545741	542796	97011G	PARTICIPANT	\N	EXCUSE	0
545743	542796	19717B	PRESIDENT	0	PRESENT	0
545747	543152	19651A	PARTICIPANT	\N	PRESENT	1
545748	543152	19758L	PARTICIPANT	\N	PRESENT	1
545749	543152	19693L	PARTICIPANT	\N	PRESENT	1
545750	543152	20124W	PARTICIPANT	\N	PRESENT	1
545751	543152	20142Y	PARTICIPANT	\N	PRESENT	1
545752	543152	14109K	PARTICIPANT	\N	PRESENT	1
545753	543152	20052X	PARTICIPANT	\N	PRESENT	1
545754	543152	20058E	PARTICIPANT	\N	PRESENT	1
545755	543152	19527W	PARTICIPANT	\N	PRESENT	1
546863	545160	11033F	PARTICIPANT	\N	PRESENT	1
546864	545160	14069U	PARTICIPANT	\N	PRESENT	1
546868	545160	19725B	PARTICIPANT	\N	PRESENT	1
546866	545160	19629C	PARTICIPANT	\N	PRESENT	1
546867	545160	14041T	PARTICIPANT	\N	PRESENT	1
546869	545160	95063L	PARTICIPANT	\N	PRESENT	1
546870	545160	14107H	PARTICIPANT	\N	PRESENT	1
546871	545160	19675J	PARTICIPANT	\N	PRESENT	1
547112	545161	11026G	PARTICIPANT	\N	PRESENT	1
547113	545161	19581D	PARTICIPANT	\N	PRESENT	1
547928	547818	19581D	PARTICIPANT	\N	PRESENT	0
556159	556158	20036X	PARTICIPANT	\N	PRESENT	0
556189	556188	20036X	PARTICIPANT	\N	PRESENT	0
557584	557583	04047H	PARTICIPANT	\N	PRESENT	0
557585	557583	14053L	PARTICIPANT	\N	PRESENT	0
557586	557583	14299H	PARTICIPANT	\N	PRESENT	0
557589	557583	11066Q	PARTICIPANT	\N	PRESENT	0
558356	557688	16685X	PARTICIPANT	\N	PRESENT	0
558357	557688	01048V	PARTICIPANT	\N	PRESENT	0
558358	557688	19349W	PARTICIPANT	\N	PRESENT	0
558359	557688	20112S	PARTICIPANT	\N	PRESENT	0
558360	557688	14030Q	PARTICIPANT	\N	PRESENT	0
558361	557688	19709B	PARTICIPANT	\N	PRESENT	0
558362	557688	11033F	PARTICIPANT	\N	PRESENT	0
558363	557688	19443T	PARTICIPANT	\N	PRESENT	0
558364	557688	08069G	PARTICIPANT	\N	PRESENT	0
558365	557688	08047A	PARTICIPANT	\N	PRESENT	0
558366	557688	14059S	PARTICIPANT	\N	PRESENT	0
558367	557688	19467C	PARTICIPANT	\N	PRESENT	0
558368	557688	20046A	PARTICIPANT	\N	PRESENT	0
558369	557688	19717B	PARTICIPANT	\N	PRESENT	0
558370	557688	08017T	PARTICIPANT	\N	PRESENT	0
558371	557688	08061X	PARTICIPANT	\N	PRESENT	0
558372	557688	11070L	PARTICIPANT	\N	PRESENT	0
558373	557688	19585H	PARTICIPANT	\N	PRESENT	0
558374	557688	19723Y	PARTICIPANT	\N	PRESENT	0
558375	557688	01028R	PARTICIPANT	\N	PRESENT	0
558376	557688	20052X	PARTICIPANT	\N	PRESENT	0
558415	557688	19521Q	PARTICIPANT	\N	PRESENT	0
558416	557688	14331P	PARTICIPANT	\N	PRESENT	0
558417	557688	14249W	PARTICIPANT	\N	PRESENT	0
558418	557688	14042U	PARTICIPANT	\N	PRESENT	0
558419	557688	14147R	PARTICIPANT	\N	PRESENT	0
558420	557688	19798U	PARTICIPANT	\N	PRESENT	0
558421	557688	11026G	PARTICIPANT	\N	PRESENT	0
558422	557688	20044X	PARTICIPANT	\N	PRESENT	0
558423	557688	04085P	PARTICIPANT	\N	PRESENT	0
558424	557697	20018V	PARTICIPANT	\N	PRESENT	1
558425	557697	19711U	PARTICIPANT	\N	PRESENT	0
558426	557697	20136B	PARTICIPANT	\N	PRESENT	0
558427	557688	20056C	PARTICIPANT	\N	PRESENT	0
558465	557915	19593H	PARTICIPANT	\N	PRESENT	0
558466	557915	19611R	PARTICIPANT	\N	PRESENT	0
558467	557915	19643A	PARTICIPANT	\N	PRESENT	1
558468	557915	20132W	PARTICIPANT	\N	PRESENT	1
558469	557915	19715Y	PARTICIPANT	\N	PRESENT	1
558470	557915	14147R	PARTICIPANT	\N	PRESENT	1
558472	557915	19693L	PARTICIPANT	\N	PRESENT	1
558653	557690	19669L	PARTICIPANT	\N	PRESENT	0
558654	557690	19565D	PARTICIPANT	\N	PRESENT	0
558655	557690	14267Y	PARTICIPANT	\N	PRESENT	0
558656	557690	14195A	PARTICIPANT	\N	PRESENT	0
558657	557690	20090E	PARTICIPANT	\N	PRESENT	0
558658	557690	11083R	PARTICIPANT	\N	PRESENT	0
558659	557690	12028B	PARTICIPANT	\N	PRESENT	0
558660	557690	20072C	PARTICIPANT	\N	PRESENT	0
558661	557690	14042U	PARTICIPANT	\N	PRESENT	0
558662	557690	16685X	PARTICIPANT	\N	PRESENT	0
558663	557690	04034C	PARTICIPANT	\N	PRESENT	0
558664	557690	11027H	PARTICIPANT	\N	PRESENT	0
558665	557690	14193X	PARTICIPANT	\N	PRESENT	0
558666	557690	19421M	PARTICIPANT	\N	PRESENT	0
558667	557690	08047A	PARTICIPANT	\N	PRESENT	0
558668	557690	01062T	PARTICIPANT	\N	PRESENT	0
558669	557690	11041F	PARTICIPANT	\N	PRESENT	0
558670	557690	19347U	PARTICIPANT	\N	PRESENT	0
558671	557690	20028X	PARTICIPANT	\N	PRESENT	0
558672	557690	12041X	PARTICIPANT	\N	PRESENT	0
558673	557690	11012A	PARTICIPANT	\N	PRESENT	0
558674	557690	19443T	PARTICIPANT	\N	PRESENT	0
558675	557690	19629C	PARTICIPANT	\N	PRESENT	0
558676	557690	14249W	PARTICIPANT	\N	PRESENT	0
558677	557690	11054L	PARTICIPANT	\N	PRESENT	0
558678	557690	08017T	PARTICIPANT	\N	PRESENT	0
558679	557690	20116W	PARTICIPANT	\N	PRESENT	0
558680	557690	14059S	PARTICIPANT	\N	PRESENT	0
558681	557690	01058X	PARTICIPANT	\N	PRESENT	0
558682	557690	14147R	PARTICIPANT	\N	PRESENT	0
558683	557690	19798U	PARTICIPANT	\N	PRESENT	0
558684	557690	20130U	PARTICIPANT	\N	PRESENT	0
558685	557690	20034V	PARTICIPANT	\N	PRESENT	0
558686	557690	20082E	PARTICIPANT	\N	PRESENT	0
558687	557690	11043H	PARTICIPANT	\N	PRESENT	0
558688	557690	17023S	PARTICIPANT	\N	PRESENT	0
558689	557690	20048C	PARTICIPANT	\N	PRESENT	0
558693	557690	17637T	PARTICIPANT	\N	PRESENT	0
558691	557690	19709B	PARTICIPANT	\N	PRESENT	0
558692	557690	08069G	PARTICIPANT	\N	PRESENT	0
558694	557690	01024M	PARTICIPANT	\N	PRESENT	0
558695	557690	19447X	PARTICIPANT	\N	PRESENT	0
558696	557690	20084G	PARTICIPANT	\N	PRESENT	0
558697	557690	14071N	PARTICIPANT	\N	PRESENT	0
558698	557690	14083S	PARTICIPANT	\N	PRESENT	0
558699	557690	19723Y	PARTICIPANT	\N	PRESENT	0
558651	557690	99004R	PARTICIPANT	\N	PRESENT	0
558652	557690	04042C	PARTICIPANT	\N	PRESENT	0
562983	560332	19319Q	PARTICIPANT	\N	EXCUSE	0
562984	560332	20150Y	PARTICIPANT	\N	EXCUSE	0
562985	560332	11010L	PARTICIPANT	\N	EXCUSE	0
562986	560332	14097Y	PARTICIPANT	\N	EXCUSE	0
562987	560332	19717B	PARTICIPANT	\N	PRESENT	1
562988	560332	14059S	PRESIDENT	0	PRESENT	0
562989	560332	19347U	PARTICIPANT	\N	EXCUSE	0
562990	560332	05008E	PARTICIPANT	\N	PRESENT	0
563554	563552	19719D	PARTICIPANT	\N	PRESENT	0
563555	563552	20038A	PARTICIPANT	\N	PRESENT	1
563556	563552	20028X	PARTICIPANT	\N	PRESENT	1
563557	563552	14109K	PARTICIPANT	\N	PRESENT	1
563558	563552	19713W	PARTICIPANT	\N	PRESENT	0
563559	563552	20026V	PARTICIPANT	\N	PRESENT	1
563748	561764	19741B	PARTICIPANT	\N	PRESENT	1
563749	561764	19545Y	PARTICIPANT	\N	PRESENT	1
563750	561764	04086Q	PARTICIPANT	\N	PRESENT	1
563751	561764	11110B	PARTICIPANT	\N	PRESENT	1
563752	561764	99004R	PARTICIPANT	\N	PRESENT	1
563753	561764	19671E	PARTICIPANT	\N	PRESENT	1
563754	561764	20150Y	PARTICIPANT	\N	PRESENT	1
563755	561764	19762G	PARTICIPANT	\N	PRESENT	1
563756	561764	19479G	PARTICIPANT	\N	PRESENT	1
564128	559959	14193X	PARTICIPANT	\N	EXCUSE	0
566879	566434	20098N	PARTICIPANT	\N	PRESENT	0
566880	566434	19533U	PARTICIPANT	\N	PRESENT	0
566881	566434	14215L	PARTICIPANT	\N	PRESENT	0
566882	566434	20114U	PARTICIPANT	\N	PRESENT	0
566889	566434	19479G	PARTICIPANT	\N	PRESENT	0
566893	566434	20126Y	PARTICIPANT	\N	PRESENT	0
566894	566434	20072C	PARTICIPANT	\N	PRESENT	0
566895	566434	20066E	PARTICIPANT	\N	PRESENT	0
566896	566434	19565D	PARTICIPANT	\N	PRESENT	0
566897	566434	01024M	PARTICIPANT	\N	PRESENT	0
566898	566434	14071N	PARTICIPANT	\N	PRESENT	0
566899	566434	11097X	PARTICIPANT	\N	PRESENT	0
566900	566434	14257W	PARTICIPANT	\N	PRESENT	0
567075	565471	14109K	PARTICIPANT	\N	PRESENT	0
567076	565471	08017T	PARTICIPANT	\N	PRESENT	0
567284	566436	95063L	PARTICIPANT	\N	PRESENT	0
567285	566436	14031R	PARTICIPANT	\N	PRESENT	0
567286	566436	11072N	PARTICIPANT	\N	PRESENT	0
567287	566436	19447X	PARTICIPANT	\N	PRESENT	0
567288	566436	14038Y	PARTICIPANT	\N	PRESENT	0
567289	566436	20044X	PARTICIPANT	\N	PRESENT	0
567290	566436	19467C	PARTICIPANT	\N	PRESENT	0
567291	566436	20106U	PARTICIPANT	\N	PRESENT	0
567292	566436	19697Q	PARTICIPANT	\N	PRESENT	0
567293	566436	11083R	PARTICIPANT	\N	PRESENT	0
567294	566436	19954N	PARTICIPANT	\N	PRESENT	0
567295	566436	19591F	PARTICIPANT	\N	PRESENT	0
567296	566436	20056C	PARTICIPANT	\N	PRESENT	0
567297	566436	14249W	PARTICIPANT	\N	PRESENT	0
567298	566436	20098N	PARTICIPANT	\N	PRESENT	0
567299	566436	19329S	PARTICIPANT	\N	PRESENT	0
567300	566436	92040Q	PARTICIPANT	\N	PRESENT	0
567301	566436	08034U	PARTICIPANT	\N	PRESENT	0
567302	566436	19729F	PARTICIPANT	\N	PRESENT	0
567303	566436	20128B	PARTICIPANT	\N	PRESENT	0
567304	566436	19705W	PARTICIPANT	\N	PRESENT	0
567305	566436	20140W	PARTICIPANT	\N	PRESENT	0
567306	566436	20172F	PARTICIPANT	\N	PRESENT	0
567307	566436	08015R	PARTICIPANT	\N	PRESENT	0
567308	566436	19709B	PARTICIPANT	\N	PRESENT	0
567309	566436	14213J	PARTICIPANT	\N	PRESENT	0
567310	566436	20116W	PARTICIPANT	\N	PRESENT	0
567311	566436	11012A	PARTICIPANT	\N	PRESENT	0
567312	566436	14357A	PARTICIPANT	\N	PRESENT	0
567313	566436	14207L	PARTICIPANT	\N	PRESENT	0
567314	566436	20020P	PARTICIPANT	\N	PRESENT	0
567315	566436	19629C	PARTICIPANT	\N	PRESENT	0
567316	566436	20124W	PARTICIPANT	\N	PRESENT	0
567374	566436	17637T	PARTICIPANT	\N	PRESENT	0
567318	566436	20132W	PARTICIPANT	\N	PRESENT	0
567319	566436	20126Y	PARTICIPANT	\N	PRESENT	0
567320	566436	14217N	PARTICIPANT	\N	PRESENT	0
567321	566436	20072C	PARTICIPANT	\N	PRESENT	0
567322	566436	97011G	PARTICIPANT	\N	PRESENT	0
567323	566436	14147R	PARTICIPANT	\N	PRESENT	0
567324	566436	14221J	PARTICIPANT	\N	PRESENT	0
567325	566436	19679N	PARTICIPANT	\N	PRESENT	0
567326	566436	14111D	PARTICIPANT	\N	PRESENT	0
567327	566436	04057K	PARTICIPANT	\N	PRESENT	0
567328	566436	14059S	PARTICIPANT	\N	PRESENT	0
567329	566436	20050V	PARTICIPANT	\N	PRESENT	0
567330	566436	20148F	PARTICIPANT	\N	PRESENT	0
567331	566436	11064N	PARTICIPANT	\N	PRESENT	0
567332	566436	14251Q	PARTICIPANT	\N	PRESENT	0
567333	566436	19581D	PARTICIPANT	\N	PRESENT	0
567334	566436	11099A	PARTICIPANT	\N	PRESENT	0
567335	566436	20048C	PARTICIPANT	\N	PRESENT	0
567336	566436	20052X	PARTICIPANT	\N	PRESENT	0
567337	566436	20042V	PARTICIPANT	\N	PRESENT	0
567338	566436	19713W	PARTICIPANT	\N	PRESENT	0
567339	566436	19441R	PARTICIPANT	\N	PRESENT	0
567340	566436	19735D	PARTICIPANT	\N	PRESENT	0
567341	566436	01024M	PARTICIPANT	\N	PRESENT	0
567342	566436	19739H	PARTICIPANT	\N	PRESENT	0
567343	566436	01034P	PARTICIPANT	\N	PRESENT	0
567344	566436	19611R	PARTICIPANT	\N	PRESENT	0
567345	566436	19691J	PARTICIPANT	\N	PRESENT	0
567346	566436	14030Q	PARTICIPANT	\N	PRESENT	0
567347	566436	14327T	PARTICIPANT	\N	PRESENT	0
567348	566436	14179A	PARTICIPANT	\N	PRESENT	0
567349	566436	20066E	PARTICIPANT	\N	PRESENT	0
567350	566436	11085T	PARTICIPANT	\N	PRESENT	0
567351	566436	14255U	PARTICIPANT	\N	PRESENT	0
567352	566436	19826F	PARTICIPANT	\N	PRESENT	0
567353	566436	14083S	PARTICIPANT	\N	PRESENT	0
567354	566436	17023S	PARTICIPANT	\N	PRESENT	0
567355	566436	19685L	PARTICIPANT	\N	PRESENT	0
567356	566436	20040T	PARTICIPANT	\N	PRESENT	0
567357	566436	14205J	PARTICIPANT	\N	PRESENT	0
567358	566436	14042U	PARTICIPANT	\N	PRESENT	0
567359	566436	19681G	PARTICIPANT	\N	PRESENT	0
567360	566436	01043Q	PARTICIPANT	\N	PRESENT	0
567361	566436	14219Q	PARTICIPANT	\N	PRESENT	0
567362	566436	11067R	PARTICIPANT	\N	PRESENT	0
567363	566436	17965H	PARTICIPANT	\N	PRESENT	0
567364	566436	08018U	PARTICIPANT	\N	PRESENT	0
567365	566436	19687N	PARTICIPANT	\N	PRESENT	0
567366	566436	20062A	PARTICIPANT	\N	PRESENT	0
567367	566436	08047A	PARTICIPANT	\N	PRESENT	0
567368	566436	11027H	PARTICIPANT	\N	PRESENT	0
567369	566436	86034E	PARTICIPANT	\N	PRESENT	0
567370	566436	04047H	PARTICIPANT	\N	PRESENT	0
567371	566436	19507S	PARTICIPANT	\N	PRESENT	0
567372	566436	11065P	PARTICIPANT	\N	PRESENT	0
567373	566436	19719D	PARTICIPANT	\N	PRESENT	0
567375	566436	11066Q	PARTICIPANT	\N	PRESENT	0
567381	566436	19251M	PARTICIPANT	\N	PRESENT	0
567382	566436	08069G	PARTICIPANT	\N	PRESENT	0
567383	566436	19335Q	PARTICIPANT	\N	PRESENT	0
567384	566436	08009T	PARTICIPANT	\N	PRESENT	0
567385	566436	14089Y	PARTICIPANT	\N	PRESENT	0
541979	537910	14026U	PARTICIPANT	\N	PRESENT	1
541980	537910	04057K	PARTICIPANT	\N	PRESENT	1
541981	537910	04043D	PARTICIPANT	\N	PRESENT	1
541984	537910	19383Y	PARTICIPANT	\N	PRESENT	0
541986	537910	20054A	PARTICIPANT	\N	PRESENT	0
544002	544001	14267Y	PARTICIPANT	\N	PRESENT	0
544003	544001	14105F	PARTICIPANT	\N	PRESENT	0
545479	545478	20086J	PARTICIPANT	\N	PRESENT	0
545480	545478	14205J	PARTICIPANT	\N	PRESENT	0
545481	545478	20082E	PARTICIPANT	\N	PRESENT	0
545482	545478	14033T	PARTICIPANT	\N	PRESENT	0
545483	545478	20174H	PARTICIPANT	\N	PRESENT	0
545484	545478	20144B	PARTICIPANT	\N	PRESENT	0
545487	545486	20082E	PARTICIPANT	\N	PRESENT	0
545488	545486	14205J	PARTICIPANT	\N	PRESENT	0
545490	545489	20082E	PARTICIPANT	\N	PRESENT	0
545491	545489	14205J	PARTICIPANT	\N	PRESENT	0
545493	545492	20086J	PARTICIPANT	\N	PRESENT	0
545494	545492	20082E	PARTICIPANT	\N	PRESENT	0
545495	545492	14205J	PARTICIPANT	\N	PRESENT	0
545496	545492	20092G	PARTICIPANT	\N	PRESENT	0
546117	545404	17637T	PARTICIPANT	\N	PRESENT	0
546118	545404	20042V	PARTICIPANT	\N	PRESENT	0
546119	545404	19695N	PARTICIPANT	\N	PRESENT	0
546120	545404	14073Q	PARTICIPANT	\N	PRESENT	0
546121	545404	20082E	PARTICIPANT	\N	PRESENT	0
546122	545404	01048V	PARTICIPANT	\N	PRESENT	0
546123	545404	19533U	PARTICIPANT	\N	PRESENT	0
546124	545404	14069U	PARTICIPANT	\N	PRESENT	0
546125	545404	19768N	PARTICIPANT	\N	PRESENT	0
546126	545404	14357A	PARTICIPANT	\N	PRESENT	0
546127	545404	19679N	PARTICIPANT	\N	PRESENT	0
546128	545404	20062A	PARTICIPANT	\N	PRESENT	0
546129	545404	19441R	PARTICIPANT	\N	PRESENT	0
546130	545404	01043Q	PARTICIPANT	\N	PRESENT	0
546131	545404	20124W	PARTICIPANT	\N	PRESENT	0
546132	545404	18193Q	PARTICIPANT	\N	PRESENT	0
546133	545404	19251M	PARTICIPANT	\N	PRESENT	0
546134	545404	14187A	PARTICIPANT	\N	PRESENT	0
546135	545404	01057W	PARTICIPANT	\N	PRESENT	0
546136	545404	20074E	PARTICIPANT	\N	PRESENT	0
546137	545404	19713W	PARTICIPANT	\N	PRESENT	0
546138	545404	20070A	PARTICIPANT	\N	PRESENT	0
546139	545404	20102Q	PARTICIPANT	\N	PRESENT	0
546140	545404	14219Q	PARTICIPANT	\N	PRESENT	0
546141	545404	05012A	PARTICIPANT	\N	PRESENT	0
546142	545404	14255U	PARTICIPANT	\N	PRESENT	0
546143	545404	20022R	PARTICIPANT	\N	PRESENT	0
546144	545738	19954N	PARTICIPANT	\N	PRESENT	0
546145	545738	20074E	PARTICIPANT	\N	PRESENT	0
546146	545738	14041T	PARTICIPANT	\N	PRESENT	0
546147	545738	14001X	PARTICIPANT	\N	PRESENT	0
546148	545738	19749K	PARTICIPANT	\N	PRESENT	0
546149	545738	19673G	PARTICIPANT	\N	PRESENT	0
546150	545738	01028R	PARTICIPANT	\N	PRESENT	0
546151	545738	04047H	PRESIDENT	0	PRESENT	0
546152	545738	19447X	PARTICIPANT	\N	PRESENT	0
546153	545738	19489J	PARTICIPANT	\N	PRESENT	0
546154	545738	10015M	PARTICIPANT	\N	PRESENT	0
546155	545738	14215L	PARTICIPANT	\N	PRESENT	0
546156	545738	14053L	PARTICIPANT	\N	PRESENT	0
546157	545738	07004J	PARTICIPANT	\N	PRESENT	0
546158	545738	19725B	PARTICIPANT	\N	PRESENT	0
546159	545738	14231L	PARTICIPANT	\N	PRESENT	0
546160	545738	19729F	PARTICIPANT	\N	PRESENT	0
546161	545738	19543W	PARTICIPANT	\N	PRESENT	0
546162	545738	17737W	PARTICIPANT	\N	PRESENT	0
546163	545738	14089Y	PARTICIPANT	\N	PRESENT	0
546291	545405	19719D	PARTICIPANT	\N	PRESENT	0
546292	545405	19673G	PARTICIPANT	\N	PRESENT	0
546293	545405	04047H	PARTICIPANT	\N	PRESENT	0
546294	545405	19749K	PARTICIPANT	\N	PRESENT	0
546295	545405	20090E	PARTICIPANT	\N	PRESENT	0
546299	545405	20082E	PARTICIPANT	\N	PRESENT	0
546300	545405	19503N	PARTICIPANT	\N	PRESENT	0
546301	545405	11033F	PARTICIPANT	\N	PRESENT	0
546302	545405	20100N	PARTICIPANT	\N	PRESENT	0
546303	545405	20110Q	PARTICIPANT	\N	PRESENT	0
546304	545405	17589D	PARTICIPANT	\N	PRESENT	0
546305	545405	11104D	PARTICIPANT	\N	PRESENT	0
546306	545405	14097Y	PARTICIPANT	\N	PRESENT	0
546307	545405	11056N	PARTICIPANT	\N	PRESENT	0
546308	545405	19333N	PARTICIPANT	\N	PRESENT	0
546309	545405	99004R	PARTICIPANT	\N	PRESENT	0
546310	545405	14001X	PARTICIPANT	\N	PRESENT	0
546311	545405	19689Q	PARTICIPANT	\N	PRESENT	0
546312	545405	20078J	PARTICIPANT	\N	PRESENT	0
546313	545405	11012A	PARTICIPANT	\N	PRESENT	0
546314	545405	14123H	PARTICIPANT	\N	PRESENT	0
546315	545405	14207L	PARTICIPANT	\N	PRESENT	0
546316	545405	11043H	PARTICIPANT	\N	PRESENT	0
546317	545405	19651A	PARTICIPANT	\N	PRESENT	0
546318	545405	11090Q	PARTICIPANT	\N	PRESENT	0
546319	545405	20106U	PARTICIPANT	\N	PRESENT	0
546320	545405	11072N	PARTICIPANT	\N	PRESENT	0
546321	545405	14215L	PARTICIPANT	\N	PRESENT	0
546322	545405	20022R	PARTICIPANT	\N	PRESENT	0
546323	545405	20046A	PARTICIPANT	\N	PRESENT	0
546324	545405	18083K	PARTICIPANT	\N	PRESENT	0
546325	545405	19593H	PARTICIPANT	\N	PRESENT	0
546326	545405	19649G	PARTICIPANT	\N	PRESENT	0
546327	545405	17737W	PARTICIPANT	\N	PRESENT	0
546328	545405	20116W	PARTICIPANT	\N	PRESENT	0
546329	545405	20180F	PARTICIPANT	\N	PRESENT	0
546330	545405	14231L	PARTICIPANT	\N	PRESENT	0
546331	545405	19611R	PARTICIPANT	\N	PRESENT	0
546332	545405	19954N	PARTICIPANT	\N	PRESENT	0
546333	545405	20066E	PARTICIPANT	\N	PRESENT	0
546334	545405	14030Q	PARTICIPANT	\N	PRESENT	0
546335	545405	20026V	PARTICIPANT	\N	PRESENT	0
546336	545405	20056C	PARTICIPANT	\N	PRESENT	0
546337	545405	14083S	PARTICIPANT	\N	PRESENT	0
546338	545405	14033T	PARTICIPANT	\N	PRESENT	0
546339	545405	14089Y	PARTICIPANT	\N	PRESENT	0
546340	545405	20058E	PARTICIPANT	\N	PRESENT	0
546341	545405	19747H	PARTICIPANT	\N	PRESENT	0
546342	545405	20070A	PARTICIPANT	\N	PRESENT	0
546343	545405	20080C	PARTICIPANT	\N	PRESENT	0
546344	545405	19447X	PARTICIPANT	\N	PRESENT	0
546345	545405	14038Y	PARTICIPANT	\N	PRESENT	0
546347	545405	20018V	PARTICIPANT	\N	PRESENT	0
546348	545405	20098N	PARTICIPANT	\N	PRESENT	0
546349	545405	20054A	PARTICIPANT	\N	PRESENT	0
546350	545405	14055N	PARTICIPANT	\N	PRESENT	0
546351	545405	19729F	PARTICIPANT	\N	PRESENT	0
546352	545405	19671E	PARTICIPANT	\N	PRESENT	0
546353	545405	14217N	PARTICIPANT	\N	PRESENT	0
546354	545405	19798U	PARTICIPANT	\N	PRESENT	0
546355	545405	20034V	PARTICIPANT	\N	PRESENT	0
546356	545405	14053L	PARTICIPANT	\N	PRESENT	0
546357	545405	20062A	PARTICIPANT	\N	PRESENT	0
546358	545405	20140W	PARTICIPANT	\N	PRESENT	0
546359	545405	14147R	PARTICIPANT	\N	PRESENT	0
546360	545405	19703U	PARTICIPANT	\N	PRESENT	0
546361	545405	20024T	PARTICIPANT	\N	PRESENT	0
546362	545405	19443T	PARTICIPANT	\N	PRESENT	0
546363	545405	04033B	PARTICIPANT	\N	PRESENT	0
546364	545405	19467C	PARTICIPANT	\N	PRESENT	0
546365	545405	05012A	PARTICIPANT	\N	PRESENT	0
546366	545405	19415P	PARTICIPANT	\N	PRESENT	0
546367	545405	19533U	PARTICIPANT	\N	PRESENT	0
546368	545405	19741B	PARTICIPANT	\N	PRESENT	0
546373	545405	18193Q	PARTICIPANT	\N	PRESENT	0
546370	545405	20048C	PARTICIPANT	\N	PRESENT	0
546371	545405	19347U	PARTICIPANT	\N	PRESENT	0
546372	545405	20126Y	PARTICIPANT	\N	PRESENT	0
546374	545405	20132W	PARTICIPANT	\N	PRESENT	0
546375	545405	11077T	PARTICIPANT	\N	PRESENT	0
546376	545405	19695N	PARTICIPANT	\N	PRESENT	0
546377	545405	11097X	PARTICIPANT	\N	PRESENT	0
546378	545405	19621T	PARTICIPANT	\N	PRESENT	0
546379	545405	10015M	PARTICIPANT	\N	PRESENT	0
546381	545405	11048N	PARTICIPANT	\N	PRESENT	0
546382	545405	20152B	PARTICIPANT	\N	PRESENT	0
546383	545405	14069U	PARTICIPANT	\N	PRESENT	0
546384	545405	14071N	PARTICIPANT	\N	PRESENT	0
546385	545405	19573D	PARTICIPANT	\N	PRESENT	0
546386	545405	19543W	PARTICIPANT	\N	PRESENT	0
546387	545405	20124W	PARTICIPANT	\N	PRESENT	0
546388	545405	19489J	PARTICIPANT	\N	PRESENT	0
555303	555302	19701S	PARTICIPANT	\N	PRESENT	0
555305	555302	19387D	PARTICIPANT	\N	PRESENT	0
555306	555302	19503N	PARTICIPANT	\N	PRESENT	0
555308	555302	19543W	PARTICIPANT	\N	PRESENT	0
555310	555309	19701S	PARTICIPANT	\N	PRESENT	0
555312	555311	19701S	PARTICIPANT	\N	PRESENT	0
555313	555311	14205J	PARTICIPANT	\N	PRESENT	0
555317	555316	19826F	PARTICIPANT	\N	PRESENT	0
555319	555318	19826F	PARTICIPANT	\N	PRESENT	0
555320	555318	14205J	PARTICIPANT	\N	PRESENT	0
555322	555321	19701S	PARTICIPANT	\N	PRESENT	0
555324	555323	19701S	PARTICIPANT	\N	PRESENT	0
555325	555323	19543W	PARTICIPANT	\N	PRESENT	0
555383	555382	20042V	PARTICIPANT	\N	PRESENT	1
555384	555382	01058X	PARTICIPANT	\N	PRESENT	1
555385	555382	14193X	PARTICIPANT	\N	PRESENT	1
555386	555382	11054L	PARTICIPANT	\N	PRESENT	1
555418	553250	19551W	PARTICIPANT	\N	EXCUSE	0
555419	553250	11097X	PARTICIPANT	\N	PRESENT	0
555432	554659	19577H	PARTICIPANT	\N	EXCUSE	0
555433	554659	19715Y	PARTICIPANT	\N	EXCUSE	0
555434	554659	19657G	PARTICIPANT	\N	EXCUSE	0
555437	555399	19447X	PARTICIPANT	\N	EXCUSE	0
555448	555444	20136B	PARTICIPANT	\N	PRESENT	0
555449	555444	20100N	PARTICIPANT	\N	PRESENT	0
555450	555445	20136B	PARTICIPANT	\N	PRESENT	0
555451	555445	20100N	PARTICIPANT	\N	PRESENT	0
555452	555445	19551W	PARTICIPANT	\N	PRESENT	0
555453	555446	20136B	PARTICIPANT	\N	PRESENT	0
555454	555446	20100N	PARTICIPANT	\N	PRESENT	0
555455	555446	19551W	PARTICIPANT	\N	PRESENT	0
555456	555447	20136B	PARTICIPANT	\N	PRESENT	0
555457	555447	20100N	PARTICIPANT	\N	PRESENT	0
555459	555458	20136B	PARTICIPANT	\N	PRESENT	0
555460	555458	20100N	PARTICIPANT	\N	PRESENT	0
555464	555461	20136B	PARTICIPANT	\N	PRESENT	0
555465	555461	20100N	PARTICIPANT	\N	PRESENT	0
555466	555462	20136B	PARTICIPANT	\N	PRESENT	0
555467	555463	20136B	PARTICIPANT	\N	PRESENT	0
555468	555463	20100N	PARTICIPANT	\N	PRESENT	0
555471	555469	20136B	PARTICIPANT	\N	PRESENT	0
555472	555469	20100N	PARTICIPANT	\N	PRESENT	0
555473	555470	20136B	PARTICIPANT	\N	PRESENT	0
555474	555470	20100N	PARTICIPANT	\N	PRESENT	0
555480	555479	14205J	PARTICIPANT	\N	PRESENT	0
555481	555479	20092G	PARTICIPANT	\N	PRESENT	0
555486	555484	14205J	PARTICIPANT	\N	PRESENT	0
555487	555485	14205J	PARTICIPANT	\N	PRESENT	0
555488	555483	14205J	PARTICIPANT	\N	PRESENT	0
555489	555483	20092G	PARTICIPANT	\N	PRESENT	0
555490	555482	14205J	PARTICIPANT	\N	PRESENT	0
555496	555492	14205J	PARTICIPANT	\N	PRESENT	0
555497	555492	20092G	PARTICIPANT	\N	PRESENT	0
555498	555494	14205J	PARTICIPANT	\N	PRESENT	0
555501	555500	11090Q	PARTICIPANT	\N	PRESENT	0
555502	555500	14331P	PARTICIPANT	\N	PRESENT	0
555503	555500	11083R	PARTICIPANT	\N	PRESENT	0
555504	555500	19711U	PARTICIPANT	\N	PRESENT	0
555505	555500	14097Y	PARTICIPANT	\N	PRESENT	0
555506	555500	04035D	PARTICIPANT	\N	PRESENT	0
555507	555500	14225N	PARTICIPANT	\N	PRESENT	0
555511	555031	20090E	PARTICIPANT	\N	PRESENT	0
555509	555031	12041X	PARTICIPANT	\N	PRESENT	0
555510	555031	19697Q	PARTICIPANT	\N	PRESENT	0
555512	555031	20028X	PARTICIPANT	\N	PRESENT	0
555513	555031	20130U	PARTICIPANT	\N	PRESENT	0
555514	555031	19515S	PARTICIPANT	\N	PRESENT	0
555515	555031	19643A	PARTICIPANT	\N	PRESENT	0
555516	555031	19695N	PARTICIPANT	\N	PRESENT	0
555517	555031	20052X	PARTICIPANT	\N	PRESENT	0
555518	555031	20048C	PARTICIPANT	\N	PRESENT	0
555519	555031	11103C	PARTICIPANT	\N	PRESENT	0
555520	555031	04057K	PARTICIPANT	\N	PRESENT	0
555521	555031	14026U	PARTICIPANT	\N	PRESENT	0
555522	555031	14083S	PARTICIPANT	\N	PRESENT	0
555523	555031	14071N	PARTICIPANT	\N	PRESENT	0
555524	555031	19798U	PARTICIPANT	\N	PRESENT	0
555525	555031	19301E	PARTICIPANT	\N	PRESENT	0
555526	555031	19575F	PARTICIPANT	\N	PRESENT	0
555527	555031	20038A	PARTICIPANT	\N	PRESENT	0
555528	555031	14187A	PARTICIPANT	\N	PRESENT	0
555529	555031	20020P	PARTICIPANT	\N	PRESENT	0
555530	555031	18083K	PARTICIPANT	\N	PRESENT	0
555531	555031	08028W	PARTICIPANT	\N	PRESENT	0
555532	555031	08069G	PARTICIPANT	\N	PRESENT	0
555533	555031	19369B	PARTICIPANT	\N	PRESENT	0
555534	555031	14219Q	PARTICIPANT	\N	PRESENT	0
555535	555031	20064C	PARTICIPANT	\N	PRESENT	0
555536	555031	97011G	PARTICIPANT	\N	PRESENT	0
555537	555031	11056N	PARTICIPANT	\N	PRESENT	0
555538	555031	20174H	PARTICIPANT	\N	PRESENT	0
555539	555031	20026V	PARTICIPANT	\N	PRESENT	0
555540	555031	19749K	PARTICIPANT	\N	PRESENT	0
555541	555031	20024T	PARTICIPANT	\N	PRESENT	0
555542	555031	20098N	PARTICIPANT	\N	PRESENT	0
555543	555341	11048N	PARTICIPANT	\N	PRESENT	0
555544	555341	19479G	PARTICIPANT	\N	PRESENT	0
555545	555341	19711U	PARTICIPANT	\N	PRESENT	0
555546	555341	19687N	PARTICIPANT	\N	PRESENT	0
555547	555341	20080C	PARTICIPANT	\N	PRESENT	0
555548	555341	19667J	PARTICIPANT	\N	PRESENT	0
555549	555341	20044X	PARTICIPANT	\N	PRESENT	0
555550	555341	14225N	PRESIDENT	0	PRESENT	0
555551	555341	04086Q	PARTICIPANT	\N	PRESENT	0
555552	555341	14083S	PARTICIPANT	\N	PRESENT	0
555553	555341	11012A	PARTICIPANT	\N	PRESENT	0
555554	555341	20070A	PARTICIPANT	\N	PRESENT	0
555555	555341	19349W	PARTICIPANT	\N	PRESENT	0
555556	555341	19741B	PARTICIPANT	\N	PRESENT	0
555557	555341	99004R	PARTICIPANT	\N	PRESENT	0
555558	555341	20116W	PARTICIPANT	\N	PRESENT	0
555559	555341	20022R	PARTICIPANT	\N	PRESENT	0
555560	555341	20126Y	PARTICIPANT	\N	PRESENT	0
555561	555341	19762G	PARTICIPANT	\N	PRESENT	0
555562	555031	19467C	PARTICIPANT	\N	PRESENT	0
555563	555031	14053L	PARTICIPANT	\N	PRESENT	0
555564	555031	14147R	PARTICIPANT	\N	PRESENT	0
555565	555031	14038Y	PARTICIPANT	\N	PRESENT	0
555566	555031	14021P	PARTICIPANT	\N	PRESENT	0
555567	555031	08056B	PARTICIPANT	\N	PRESENT	0
555568	555341	19647E	PARTICIPANT	\N	PRESENT	0
555569	555341	11040E	PARTICIPANT	\N	PRESENT	0
555570	555341	20036X	PARTICIPANT	\N	EXCUSE	0
555571	555341	14189C	PARTICIPANT	\N	EXCUSE	0
555572	555031	95063L	PARTICIPANT	\N	PRESENT	0
555573	555341	19689Q	PARTICIPANT	\N	PRESENT	0
555574	555341	08010L	PARTICIPANT	\N	PRESENT	0
555575	555031	14030Q	PARTICIPANT	\N	PRESENT	0
555579	555031	14105F	PARTICIPANT	\N	PRESENT	0
555580	555031	11010L	PARTICIPANT	\N	PRESENT	0
555581	555031	20062A	PARTICIPANT	\N	PRESENT	0
555582	555031	01024M	PARTICIPANT	\N	PRESENT	0
555583	555341	01057W	PARTICIPANT	\N	PRESENT	0
555584	555341	08009T	PARTICIPANT	\N	PRESENT	0
555585	555341	19545Y	PARTICIPANT	\N	EXCUSE	0
555586	555031	14223L	PARTICIPANT	\N	PRESENT	0
555587	555031	20056C	PARTICIPANT	\N	PRESENT	0
555588	555031	01062T	PARTICIPANT	\N	PRESENT	0
555589	555031	11012A	PARTICIPANT	\N	PRESENT	0
555590	555031	20140W	PARTICIPANT	\N	PRESENT	0
555591	555031	07029T	PARTICIPANT	\N	PRESENT	0
555592	555031	20124W	PARTICIPANT	\N	PRESENT	0
555593	555031	20172F	PARTICIPANT	\N	PRESENT	0
555594	555031	14031R	PARTICIPANT	\N	PRESENT	0
555596	555031	11077T	PARTICIPANT	\N	PRESENT	0
555597	555031	14221J	PARTICIPANT	\N	PRESENT	0
555598	555031	04085P	PARTICIPANT	\N	PRESENT	0
555599	555031	19760E	PARTICIPANT	\N	PRESENT	0
555600	555031	19747H	PARTICIPANT	\N	PRESENT	0
555601	555031	19713W	PARTICIPANT	\N	PRESENT	0
555603	555031	19599P	PARTICIPANT	\N	PRESENT	0
555604	555031	19383Y	PARTICIPANT	\N	PRESENT	0
555605	555031	19681G	PARTICIPANT	\N	PRESENT	0
555606	555031	19631V	PARTICIPANT	\N	PRESENT	0
555607	555031	19533U	PARTICIPANT	\N	PRESENT	0
555608	555031	08061X	PARTICIPANT	\N	PRESENT	0
555609	555031	19319Q	PARTICIPANT	\N	PRESENT	0
555610	555031	08015R	PARTICIPANT	\N	PRESENT	0
555611	555031	14069U	PARTICIPANT	\N	PRESENT	0
546997	543190	11053K	PARTICIPANT	\N	PRESENT	0
546998	543190	20024T	PARTICIPANT	\N	PRESENT	0
546999	543190	20056C	PARTICIPANT	\N	PRESENT	0
547000	543190	14221J	PARTICIPANT	\N	PRESENT	0
547001	543190	19671E	PARTICIPANT	\N	PRESENT	0
547002	543190	19349W	PARTICIPANT	\N	PRESENT	0
547046	547039	08009T	PARTICIPANT	\N	PRESENT	0
547050	547039	20044X	PARTICIPANT	\N	PRESENT	0
547137	547136	20036X	PARTICIPANT	\N	PRESENT	0
547144	547142	08011M	PARTICIPANT	\N	PRESENT	0
547145	547142	14253S	PARTICIPANT	\N	PRESENT	0
547146	547143	08011M	PARTICIPANT	\N	PRESENT	0
547147	547143	14253S	PARTICIPANT	\N	PRESENT	0
547374	547373	07033P	PARTICIPANT	\N	PRESENT	0
547376	547373	14123H	PARTICIPANT	\N	PRESENT	0
547377	547373	14059S	PARTICIPANT	\N	PRESENT	0
547380	547373	14147R	PARTICIPANT	\N	PRESENT	0
547382	547373	14255U	PARTICIPANT	\N	PRESENT	0
547383	547373	14179A	PARTICIPANT	\N	PRESENT	0
547384	547373	19551W	PARTICIPANT	\N	PRESENT	0
547386	547373	20084G	PARTICIPANT	\N	PRESENT	0
547828	547827	11065P	PARTICIPANT	\N	PRESENT	0
547829	547827	19387D	PARTICIPANT	\N	PRESENT	0
547830	547827	20102Q	PARTICIPANT	\N	PRESENT	0
547831	547827	19701S	PARTICIPANT	\N	PRESENT	0
547836	547827	20046A	PARTICIPANT	\N	PRESENT	0
547837	547827	19503N	PARTICIPANT	\N	PRESENT	0
547838	547827	19251M	PARTICIPANT	\N	PRESENT	0
547840	547839	19739H	PARTICIPANT	\N	PRESENT	0
547841	547839	19820Y	PARTICIPANT	\N	PRESENT	0
547842	547839	19701S	PARTICIPANT	\N	PRESENT	0
547843	547839	20106U	PARTICIPANT	\N	PRESENT	0
547844	547839	14213J	PARTICIPANT	\N	PRESENT	0
547845	547839	20038A	PARTICIPANT	\N	PRESENT	0
547846	547839	01024M	PARTICIPANT	\N	PRESENT	0
550126	550125	18083K	PARTICIPANT	\N	PRESENT	0
550127	550125	14097Y	PARTICIPANT	\N	PRESENT	0
550128	550125	08034U	PARTICIPANT	\N	PRESENT	0
550129	550125	11097X	PARTICIPANT	\N	PRESENT	0
550130	550125	20062A	PARTICIPANT	\N	PRESENT	0
550131	550125	14173T	PARTICIPANT	\N	PRESENT	0
556390	555342	07029T	PARTICIPANT	\N	EXCUSE	0
558700	557690	14255U	PARTICIPANT	\N	PRESENT	0
558701	557690	01028R	PARTICIPANT	\N	PRESENT	0
558702	557690	19741B	PARTICIPANT	\N	PRESENT	0
558703	557690	20070A	PARTICIPANT	\N	PRESENT	0
558704	557690	20054A	PARTICIPANT	\N	PRESENT	0
558705	557690	19621T	PARTICIPANT	\N	PRESENT	0
558706	557690	11048N	PARTICIPANT	\N	PRESENT	0
558707	557690	14213J	PARTICIPANT	\N	PRESENT	0
558708	557690	19551W	PARTICIPANT	\N	PRESENT	0
559522	557731	19747H	PARTICIPANT	\N	PRESENT	1
559585	559552	20120S	PARTICIPANT	\N	PRESENT	0
559586	559552	14033T	PARTICIPANT	\N	PRESENT	0
559587	559552	14179A	PARTICIPANT	\N	PRESENT	0
559592	559552	08015R	PARTICIPANT	\N	PRESENT	0
559589	559552	19333N	PARTICIPANT	\N	PRESENT	0
559590	557694	19669L	PARTICIPANT	\N	PRESENT	0
559591	559552	14213J	PARTICIPANT	\N	PRESENT	0
559593	559552	16685X	PARTICIPANT	\N	PRESENT	0
559594	559552	01048V	PARTICIPANT	\N	PRESENT	0
559595	559552	14059S	PARTICIPANT	\N	PRESENT	0
559596	559552	19441R	PARTICIPANT	\N	PRESENT	0
559597	559552	20028X	PARTICIPANT	\N	PRESENT	0
559598	559552	14257W	PARTICIPANT	\N	PRESENT	0
559599	559552	05012A	PARTICIPANT	\N	PRESENT	0
559600	559552	19739H	PARTICIPANT	\N	PRESENT	0
559601	559552	20082E	PARTICIPANT	\N	PRESENT	0
559602	559552	20054A	PARTICIPANT	\N	PRESENT	0
559603	559552	20092G	PARTICIPANT	\N	PRESENT	0
559604	559552	20044X	PARTICIPANT	\N	PRESENT	0
559605	559552	20062A	PARTICIPANT	\N	PRESENT	0
559606	557694	19387D	PARTICIPANT	\N	PRESENT	0
559607	557694	19599P	PARTICIPANT	\N	PRESENT	0
559608	557979	19719D	PARTICIPANT	\N	PRESENT	1
559609	557979	20038A	PARTICIPANT	\N	PRESENT	0
559610	557979	14109K	PRESIDENT	0	PRESENT	1
559611	557979	20026V	PARTICIPANT	\N	PRESENT	1
559612	558529	19611R	PRESIDENT	0	PRESENT	0
559613	558529	14229S	PARTICIPANT	\N	PRESENT	0
559614	558529	19593H	PARTICIPANT	\N	PRESENT	0
559615	558529	20056C	PARTICIPANT	\N	PRESENT	0
559616	558529	20098N	PARTICIPANT	\N	PRESENT	0
559617	558529	14030Q	PARTICIPANT	\N	PRESENT	0
559618	558529	19399H	PARTICIPANT	\N	PRESENT	0
559619	558529	04059M	PARTICIPANT	\N	PRESENT	0
559620	558529	19735D	PARTICIPANT	\N	PRESENT	0
559621	558529	20180F	PARTICIPANT	\N	PRESENT	0
559622	558529	20084G	PARTICIPANT	\N	PRESENT	0
559623	558529	19643A	PARTICIPANT	\N	EXCUSE	0
559624	558529	20124W	PARTICIPANT	\N	PRESENT	1
559625	558529	20048C	PARTICIPANT	\N	PRESENT	1
559626	558529	19693L	PARTICIPANT	\N	PRESENT	1
559627	558529	20026V	PARTICIPANT	\N	PRESENT	1
559628	558529	20142Y	PARTICIPANT	\N	PRESENT	1
559629	558529	20132W	PARTICIPANT	\N	PRESENT	1
559630	558529	19651A	PARTICIPANT	\N	PRESENT	1
559631	558529	20052X	PARTICIPANT	\N	PRESENT	1
559632	558529	11109J	PARTICIPANT	\N	EXCUSE	0
559633	558529	19699S	PARTICIPANT	\N	EXCUSE	0
559641	559458	20120S	PARTICIPANT	\N	PRESENT	1
559642	559458	20068G	PARTICIPANT	\N	PRESENT	0
559645	559458	19619A	PARTICIPANT	\N	PRESENT	0
559646	559458	19251M	PARTICIPANT	\N	PRESENT	1
559667	559666	14041T	PARTICIPANT	\N	PRESENT	0
559668	559666	19709B	PARTICIPANT	\N	PRESENT	0
559669	559666	08010L	PARTICIPANT	\N	PRESENT	0
559670	559666	08017T	PARTICIPANT	\N	PRESENT	0
559671	559666	19503N	PARTICIPANT	\N	PRESENT	0
559672	559666	04034C	PARTICIPANT	\N	PRESENT	0
559679	559666	19447X	PARTICIPANT	\N	PRESENT	0
559680	559666	99004R	PARTICIPANT	\N	PRESENT	0
559681	559666	11031D	PARTICIPANT	\N	PRESENT	0
559683	559682	14329V	PARTICIPANT	\N	PRESENT	0
559685	559684	14329V	PARTICIPANT	\N	PRESENT	0
559809	556324	14259Y	PRESIDENT	0	PRESENT	0
559810	556324	19399H	PARTICIPANT	\N	EXCUSE	0
559812	556324	11097X	PARTICIPANT	\N	PRESENT	0
559834	559649	14249W	PARTICIPANT	\N	PRESENT	0
559836	559649	01048V	PARTICIPANT	\N	PRESENT	0
559837	559649	19711U	PARTICIPANT	\N	PRESENT	0
559838	559649	08061X	PARTICIPANT	\N	PRESENT	0
559843	559649	08010L	PARTICIPANT	\N	PRESENT	0
559844	559649	08069G	PARTICIPANT	\N	PRESENT	0
559851	559649	19719D	PARTICIPANT	\N	PRESENT	0
559852	559649	20142Y	PARTICIPANT	\N	PRESENT	0
559853	559203	19649G	PARTICIPANT	\N	PRESENT	0
559854	559203	95063L	PARTICIPANT	\N	PRESENT	0
559855	559203	11026G	PARTICIPANT	\N	PRESENT	0
559856	559203	20108W	PARTICIPANT	\N	PRESENT	0
559857	559203	14179A	PARTICIPANT	\N	PRESENT	0
559858	559203	14215L	PARTICIPANT	\N	PRESENT	0
559859	559203	08018U	PARTICIPANT	\N	PRESENT	0
559860	559203	19749K	PARTICIPANT	\N	PRESENT	0
559861	559203	04047H	PRESIDENT	0	PRESENT	0
559862	559203	01028R	PARTICIPANT	\N	PRESENT	0
559863	559203	05008E	PARTICIPANT	\N	PRESENT	0
559864	559203	11072N	PARTICIPANT	\N	PRESENT	0
559865	559203	07004J	PARTICIPANT	\N	PRESENT	0
559866	559649	14215L	PARTICIPANT	\N	PRESENT	0
559867	559649	20048C	PARTICIPANT	\N	PRESENT	0
559868	559649	19443T	PARTICIPANT	\N	PRESENT	0
559869	559203	04085P	PARTICIPANT	\N	PRESENT	1
559870	559203	19543W	PARTICIPANT	\N	PRESENT	1
559871	559203	19954N	PARTICIPANT	\N	PRESENT	1
559872	559203	20110Q	PARTICIPANT	\N	PRESENT	1
559873	559203	19629C	PARTICIPANT	\N	PRESENT	1
559874	559203	14151M	PARTICIPANT	\N	PRESENT	1
559875	559203	19447X	PARTICIPANT	\N	PRESENT	0
559876	559203	14021P	PARTICIPANT	\N	PRESENT	1
559877	559203	19489J	PARTICIPANT	\N	PRESENT	1
559878	559203	14147R	PARTICIPANT	\N	PRESENT	1
562763	561979	19725B	PARTICIPANT	\N	PRESENT	0
562764	561979	07004J	PARTICIPANT	\N	PRESENT	0
562765	561979	14041T	PARTICIPANT	\N	PRESENT	0
562766	561979	20108W	PARTICIPANT	\N	PRESENT	0
562767	561979	14215L	PRESIDENT	0	PRESENT	0
562768	561979	19585H	PARTICIPANT	\N	PRESENT	0
562771	562770	19333N	PARTICIPANT	\N	PRESENT	0
562772	562770	20136B	PARTICIPANT	\N	PRESENT	0
562773	562770	14219Q	PARTICIPANT	\N	PRESENT	0
562774	562770	19503N	PARTICIPANT	\N	PRESENT	0
562775	562770	19826F	PARTICIPANT	\N	PRESENT	0
562776	562770	20046A	PARTICIPANT	\N	PRESENT	0
562777	562770	20102Q	PARTICIPANT	\N	PRESENT	0
562778	562770	19599P	PARTICIPANT	\N	PRESENT	0
562779	561979	14053L	PARTICIPANT	\N	PRESENT	0
562780	561979	10015M	PARTICIPANT	\N	PRESENT	0
562781	561979	11026G	PARTICIPANT	\N	PRESENT	0
562782	561979	04047H	PRESIDENT	1	PRESENT	0
562783	561979	01028R	PARTICIPANT	\N	PRESENT	0
562784	561979	05008E	PARTICIPANT	\N	PRESENT	0
562785	561979	19447X	PARTICIPANT	\N	PRESENT	0
562786	561979	19729F	PARTICIPANT	\N	PRESENT	0
562787	561979	95063L	PARTICIPANT	\N	PRESENT	0
562788	561979	14179A	PARTICIPANT	\N	PRESENT	0
562789	561979	14147R	PARTICIPANT	\N	PRESENT	0
562790	561979	20114U	PARTICIPANT	\N	PRESENT	0
562791	561979	19749K	PARTICIPANT	\N	PRESENT	0
562792	561979	20128B	PARTICIPANT	\N	PRESENT	0
562793	562554	20056C	PARTICIPANT	\N	PRESENT	0
562794	562554	19699S	PARTICIPANT	\N	PRESENT	0
562795	562554	20142Y	PARTICIPANT	\N	PRESENT	0
562796	562554	14030Q	PARTICIPANT	\N	PRESENT	0
562797	562554	20048C	PARTICIPANT	\N	PRESENT	1
562798	562554	20026V	PARTICIPANT	\N	PRESENT	1
562799	562554	20132W	PARTICIPANT	\N	PRESENT	0
562800	562554	11104D	PARTICIPANT	\N	PRESENT	0
562801	562770	19701S	PARTICIPANT	\N	PRESENT	0
562802	562770	14031R	PRESIDENT	0	PRESENT	0
562803	562770	19549D	PARTICIPANT	\N	PRESENT	0
562804	562770	20140W	PARTICIPANT	\N	PRESENT	0
562805	562770	19387D	PARTICIPANT	\N	PRESENT	1
562806	562770	19251M	PARTICIPANT	\N	PRESENT	0
562807	562770	19820Y	PARTICIPANT	\N	PRESENT	1
562808	562770	17229F	PARTICIPANT	\N	PRESENT	0
562809	562770	19637C	PARTICIPANT	\N	PRESENT	1
562810	562770	18083K	PARTICIPANT	\N	PRESENT	0
562811	562770	19551W	PARTICIPANT	\N	PRESENT	0
562812	562770	14237S	PARTICIPANT	\N	PRESENT	0
562813	562770	20100N	PARTICIPANT	\N	PRESENT	0
562814	562770	19739H	PARTICIPANT	\N	PRESENT	0
562815	562770	20024T	PARTICIPANT	\N	PRESENT	1
562816	562554	20134Y	PARTICIPANT	\N	PRESENT	0
562817	562554	14073Q	PARTICIPANT	\N	PRESENT	0
562818	562554	19533U	PARTICIPANT	\N	PRESENT	0
562819	562554	19611R	PRESIDENT	0	PRESENT	0
562820	562554	19693L	PARTICIPANT	\N	PRESENT	0
562821	562554	20052X	PARTICIPANT	\N	PRESENT	0
562822	562554	14229S	PARTICIPANT	\N	PRESENT	0
562823	562554	20098N	PARTICIPANT	\N	PRESENT	0
562824	562554	20180F	PARTICIPANT	\N	PRESENT	0
562825	562554	07033P	PARTICIPANT	\N	PRESENT	0
562826	562554	20124W	PARTICIPANT	\N	PRESENT	0
562827	562554	19758L	PARTICIPANT	\N	PRESENT	0
562828	562025	19383Y	PARTICIPANT	\N	PRESENT	0
562829	562025	14038Y	PARTICIPANT	\N	PRESENT	0
562830	562025	19515S	PARTICIPANT	\N	PRESENT	0
562831	562025	20092G	PARTICIPANT	\N	PRESENT	0
562832	562025	14187A	PARTICIPANT	\N	PRESENT	0
562833	562025	20144B	PARTICIPANT	\N	PRESENT	0
562834	562025	19695N	PARTICIPANT	\N	PRESENT	0
562835	562025	11090Q	PRESIDENT	0	PRESENT	0
562836	562025	20054A	PARTICIPANT	\N	PRESENT	0
562837	562025	11099A	PARTICIPANT	\N	PRESENT	0
562838	562025	19507S	PARTICIPANT	\N	PRESENT	0
562839	562025	19747H	PARTICIPANT	\N	PRESENT	0
562840	562025	14257W	PARTICIPANT	\N	PRESENT	0
562841	562025	14329V	PARTICIPANT	\N	PRESENT	0
562842	562554	19651A	PARTICIPANT	\N	PRESENT	1
562843	562554	19399H	PARTICIPANT	\N	PRESENT	1
562844	562554	20152B	PARTICIPANT	\N	PRESENT	1
562845	562554	20058E	PARTICIPANT	\N	PRESENT	1
562846	562554	14109K	PARTICIPANT	\N	PRESENT	1
562847	562554	11109J	PARTICIPANT	\N	EXCUSE	0
562848	562770	14221J	PARTICIPANT	\N	PRESENT	0
562849	562770	19685L	PARTICIPANT	\N	PRESENT	0
562850	562770	20038A	PARTICIPANT	\N	PRESENT	0
562851	562770	20118Y	PARTICIPANT	\N	PRESENT	0
562852	562554	04070G	PARTICIPANT	\N	PRESENT	0
562853	562554	08017T	PARTICIPANT	\N	PRESENT	1
562854	562554	19735D	PARTICIPANT	\N	PRESENT	1
562855	562554	19621T	PARTICIPANT	\N	PRESENT	0
562856	562770	20020P	PARTICIPANT	\N	PRESENT	1
562857	562770	20068G	PARTICIPANT	\N	PRESENT	1
562860	562025	19467C	PARTICIPANT	\N	PRESENT	0
562864	562770	11065P	PARTICIPANT	\N	PRESENT	0
562865	562770	19745F	PARTICIPANT	\N	PRESENT	0
562868	561763	04086Q	PARTICIPANT	\N	PRESENT	0
562869	561763	11040E	PARTICIPANT	\N	PRESENT	0
562870	561763	14327T	PARTICIPANT	\N	PRESENT	0
562871	561763	11048N	PARTICIPANT	\N	PRESENT	0
562872	561763	19711U	PARTICIPANT	\N	PRESENT	0
562873	561763	19349W	PARTICIPANT	\N	PRESENT	0
562874	561763	20080C	PARTICIPANT	\N	PRESENT	0
562875	561763	20116W	PARTICIPANT	\N	PRESENT	0
562876	561763	14225N	PRESIDENT	0	PRESENT	0
562877	561763	20044X	PARTICIPANT	\N	PRESENT	0
562878	562866	11067R	PARTICIPANT	\N	PRESENT	0
562879	562866	20090E	PARTICIPANT	\N	PRESENT	0
562880	562866	04092N	PARTICIPANT	0	PRESENT	1
562881	562866	11097X	PARTICIPANT	\N	PRESENT	0
562882	562866	19415P	PARTICIPANT	\N	PRESENT	0
562883	562866	19691J	PARTICIPANT	\N	PRESENT	0
562884	562866	18193Q	PARTICIPANT	\N	PRESENT	0
562885	562866	14026U	PARTICIPANT	\N	PRESENT	0
562886	562866	20172F	PARTICIPANT	\N	PRESENT	0
562887	562866	11031D	PARTICIPANT	\N	PRESENT	0
562888	562866	19703U	PARTICIPANT	\N	PRESENT	0
562889	562866	14042U	PARTICIPANT	\N	PRESENT	0
562890	562866	19367Y	PARTICIPANT	\N	PRESENT	0
562891	562866	14213J	PARTICIPANT	\N	PRESENT	0
562892	562866	14217N	PARTICIPANT	\N	PRESENT	0
562893	562866	04043D	PARTICIPANT	\N	PRESENT	1
562894	561763	14189C	PARTICIPANT	\N	PRESENT	0
562895	561763	11053K	PARTICIPANT	\N	PRESENT	0
562896	561763	14083S	PARTICIPANT	\N	PRESENT	0
562897	561763	19335Q	PARTICIPANT	\N	PRESENT	0
562898	561763	20126Y	PARTICIPANT	\N	PRESENT	0
562899	562866	19569H	PARTICIPANT	\N	PRESENT	1
562900	562866	14223L	PARTICIPANT	\N	PRESENT	1
562901	562866	17779H	PARTICIPANT	\N	PRESENT	0
562902	562866	19679N	PARTICIPANT	\N	PRESENT	1
562903	562866	10006L	PRESIDENT	0	PRESENT	0
562904	562866	20130U	PARTICIPANT	\N	PRESENT	1
562905	562866	01034P	PARTICIPANT	\N	PRESENT	1
562906	562866	04057K	PARTICIPANT	\N	PRESENT	0
562907	562866	08045X	PARTICIPANT	\N	PRESENT	1
562908	562866	19301E	PARTICIPANT	\N	PRESENT	1
562909	562866	17965H	PARTICIPANT	\N	PRESENT	1
562910	562866	19717B	PARTICIPANT	\N	PRESENT	1
562911	562866	20066E	PARTICIPANT	\N	PRESENT	1
562912	562866	11103C	PARTICIPANT	\N	PRESENT	1
562913	562866	19657G	PARTICIPANT	\N	PRESENT	1
562914	562866	19760E	PARTICIPANT	\N	PRESENT	1
562915	561763	01048V	PARTICIPANT	\N	PRESENT	0
562916	561763	19667J	PARTICIPANT	\N	PRESENT	0
562917	562025	19768N	PARTICIPANT	\N	PRESENT	1
562918	562025	19782L	PARTICIPANT	\N	PRESENT	1
562919	562025	11077T	PARTICIPANT	\N	PRESENT	1
562920	562025	04045F	PARTICIPANT	\N	PRESENT	1
562921	562025	19631V	PARTICIPANT	\N	PRESENT	1
562922	562025	19575F	PARTICIPANT	\N	PRESENT	1
562923	562025	19369B	PARTICIPANT	\N	PRESENT	1
562924	562025	20018V	PARTICIPANT	\N	PRESENT	1
562925	562025	19563B	PARTICIPANT	\N	PRESENT	1
562926	562025	01025N	PARTICIPANT	\N	PRESENT	1
562927	562025	14033T	PARTICIPANT	\N	PRESENT	1
562928	562025	20174H	PARTICIPANT	\N	PRESENT	1
562929	562025	14205J	PARTICIPANT	\N	PRESENT	1
562930	562025	14251Q	PARTICIPANT	\N	PRESENT	0
562931	562025	14207L	PARTICIPANT	\N	PRESENT	1
562932	561763	20022R	PARTICIPANT	\N	PRESENT	0
543107	543106	19709B	PARTICIPANT	\N	PRESENT	0
543109	543108	19709B	PARTICIPANT	\N	PRESENT	0
543155	543154	14231L	PARTICIPANT	\N	PRESENT	0
543156	543154	19489J	PARTICIPANT	\N	PRESENT	1
543158	543157	14231L	PARTICIPANT	\N	PRESENT	0
543159	543157	19489J	PARTICIPANT	\N	PRESENT	1
543161	543160	14231L	PARTICIPANT	\N	PRESENT	0
543162	543160	19489J	PARTICIPANT	\N	PRESENT	1
543164	543163	14231L	PARTICIPANT	\N	PRESENT	0
543165	542808	14189C	PARTICIPANT	\N	PRESENT	1
543166	542808	11031D	PARTICIPANT	\N	PRESENT	1
543167	542808	19683J	PRESIDENT	0	PRESENT	0
543168	542808	99004R	PARTICIPANT	\N	PRESENT	0
543169	542808	19699S	PARTICIPANT	\N	PRESENT	0
543170	542808	19563B	PARTICIPANT	\N	PRESENT	1
543171	542808	19705W	PARTICIPANT	\N	PRESENT	1
543172	542808	14229S	PARTICIPANT	\N	PRESENT	0
543176	542801	14133K	PARTICIPANT	\N	PRESENT	0
543177	542801	19383Y	PRESIDENT	0	PRESENT	0
543178	542801	19467C	PARTICIPANT	\N	PRESENT	0
543179	542801	19719D	PARTICIPANT	\N	PRESENT	0
543180	542801	20140W	PARTICIPANT	\N	PRESENT	0
543181	542801	20038A	PARTICIPANT	\N	PRESENT	0
543182	542801	14026U	PARTICIPANT	\N	PRESENT	0
543183	542801	19637C	PARTICIPANT	\N	PRESENT	0
543184	542801	20028X	PARTICIPANT	\N	PRESENT	0
543185	542801	19798U	PARTICIPANT	\N	PRESENT	0
543186	542801	19762G	PARTICIPANT	\N	PRESENT	0
543187	542801	19551W	PARTICIPANT	\N	PRESENT	1
543188	542801	14109K	PARTICIPANT	\N	PRESENT	1
543191	542801	20026V	PARTICIPANT	\N	PRESENT	1
543192	542801	14030Q	PARTICIPANT	\N	PRESENT	0
543193	542801	19758L	PARTICIPANT	\N	EXCUSE	0
545398	544762	19551W	PARTICIPANT	\N	PRESENT	1
545399	544762	19745F	PARTICIPANT	\N	PRESENT	1
545400	544762	19619A	PARTICIPANT	\N	PRESENT	1
545401	544762	19820Y	PARTICIPANT	\N	PRESENT	1
545402	544762	20106U	PARTICIPANT	\N	PRESENT	1
545403	544762	19637C	PARTICIPANT	\N	PRESENT	1
546391	545405	20172F	PARTICIPANT	\N	PRESENT	0
546392	545405	19768N	PARTICIPANT	\N	PRESENT	0
546393	545405	14111D	PARTICIPANT	\N	PRESENT	0
546394	545405	20114U	PARTICIPANT	\N	PRESENT	0
546395	545405	14026U	PARTICIPANT	\N	PRESENT	0
546396	545405	17367Q	PARTICIPANT	\N	PRESENT	0
546397	545405	20092G	PARTICIPANT	\N	PRESENT	0
546398	545405	14133K	PARTICIPANT	\N	PRESENT	0
546399	545405	19383Y	PARTICIPANT	\N	PRESENT	0
546400	545405	14169X	PARTICIPANT	\N	PRESENT	0
546401	545405	19507S	PARTICIPANT	\N	PRESENT	0
546402	545405	19762G	PARTICIPANT	\N	PRESENT	0
546403	545405	14329V	PARTICIPANT	\N	PRESENT	0
546404	545405	14357A	PARTICIPANT	\N	PRESENT	0
546405	545405	14219Q	PARTICIPANT	\N	PRESENT	0
546406	545405	19369B	PARTICIPANT	\N	PRESENT	0
546407	545405	19563B	PARTICIPANT	\N	PRESENT	0
546408	545405	14187A	PARTICIPANT	\N	PRESENT	0
546409	545405	04085P	PARTICIPANT	\N	PRESENT	0
546410	545405	19551W	PARTICIPANT	\N	PRESENT	0
546411	545405	01028R	PARTICIPANT	\N	PRESENT	0
546412	545405	19549D	PARTICIPANT	\N	PRESENT	0
546413	545405	19725B	PARTICIPANT	\N	PRESENT	0
546414	545405	19399H	PARTICIPANT	\N	PRESENT	0
546415	545405	14179A	PARTICIPANT	\N	PRESENT	0
547427	547417	11074Q	PARTICIPANT	\N	PRESENT	0
547428	547417	19349W	PARTICIPANT	\N	PRESENT	0
549265	547500	20040T	PARTICIPANT	\N	PRESENT	0
549280	545942	20066E	PARTICIPANT	\N	PRESENT	0
549541	549003	19383Y	PARTICIPANT	\N	PRESENT	0
549542	549003	14038Y	PARTICIPANT	\N	PRESENT	0
549543	549003	19768N	PARTICIPANT	\N	PRESENT	0
549544	549003	19515S	PARTICIPANT	\N	PRESENT	0
549545	549003	14357A	PARTICIPANT	\N	PRESENT	0
546389	545405	14021P	PARTICIPANT	\N	PRESENT	0
546390	545405	19782L	PARTICIPANT	\N	PRESENT	0
549546	549003	19441R	PARTICIPANT	\N	PRESENT	0
549547	549003	20082E	PARTICIPANT	\N	PRESENT	0
549548	549003	14033T	PARTICIPANT	\N	PRESENT	0
549549	549003	11090Q	PRESIDENT	0	PRESENT	0
549550	549003	19866P	PARTICIPANT	\N	PRESENT	0
549551	549003	20054A	PARTICIPANT	\N	PRESENT	0
549552	549003	20104S	PARTICIPANT	\N	PRESENT	0
549553	549003	19631V	PARTICIPANT	\N	PRESENT	0
549554	549003	14205J	PARTICIPANT	\N	PRESENT	0
549555	549003	20062A	PARTICIPANT	\N	PRESENT	0
549556	549003	19705W	PARTICIPANT	\N	PRESENT	0
549557	549003	19507S	PARTICIPANT	\N	PRESENT	0
549558	549003	08015R	PARTICIPANT	\N	PRESENT	0
549559	549003	19369B	PARTICIPANT	\N	PRESENT	0
549560	549003	19747H	PARTICIPANT	\N	PRESENT	0
549561	549003	14207L	PARTICIPANT	\N	PRESENT	0
549562	549003	19511N	PARTICIPANT	\N	PRESENT	0
549563	549003	08028W	PARTICIPANT	\N	PRESENT	0
549564	549003	19563B	PARTICIPANT	\N	PRESENT	0
549565	549253	20132W	PARTICIPANT	\N	PRESENT	0
549566	549253	14030Q	PARTICIPANT	\N	PRESENT	1
549567	549253	19527W	PARTICIPANT	\N	PRESENT	1
549568	549253	19533U	PARTICIPANT	\N	PRESENT	1
549569	549253	19651A	PARTICIPANT	\N	PRESENT	1
549570	549253	20058E	PARTICIPANT	\N	PRESENT	0
549571	549253	20124W	PARTICIPANT	\N	PRESENT	1
549572	549253	20026V	PARTICIPANT	\N	PRESENT	1
549573	549253	08061X	PARTICIPANT	\N	PRESENT	0
549574	549253	20084G	PARTICIPANT	\N	PRESENT	1
549575	547892	20130U	PARTICIPANT	\N	PRESENT	1
549576	547892	19697Q	PARTICIPANT	\N	PRESENT	1
549577	547892	14355X	PARTICIPANT	\N	PRESENT	1
549578	547892	19569H	PARTICIPANT	\N	PRESENT	1
549579	547892	19663E	PARTICIPANT	\N	PRESENT	1
549580	547892	20148F	PARTICIPANT	\N	PRESENT	1
549581	547892	20172F	PARTICIPANT	\N	PRESENT	1
549582	547892	19553Y	PARTICIPANT	\N	PRESENT	1
549583	547892	19679N	PARTICIPANT	\N	PRESENT	1
549584	547892	11103C	PARTICIPANT	\N	PRESENT	1
549585	547892	14042U	PARTICIPANT	\N	PRESENT	1
549586	547892	19367Y	PARTICIPANT	\N	PRESENT	1
549587	547892	14213J	PARTICIPANT	\N	PRESENT	1
549588	547892	19760E	PARTICIPANT	\N	PRESENT	1
549593	545501	19333N	PARTICIPANT	\N	PRESENT	0
549594	545501	20032T	PARTICIPANT	\N	PRESENT	0
549595	545501	19701S	PARTICIPANT	\N	PRESENT	1
549596	545501	14031R	PARTICIPANT	\N	PRESENT	0
549597	545501	20038A	PARTICIPANT	\N	PRESENT	0
549598	545501	20140W	PARTICIPANT	\N	PRESENT	0
549599	545501	19549D	PARTICIPANT	\N	PRESENT	0
549600	545501	19387D	PARTICIPANT	\N	PRESENT	1
549601	545501	19251M	PARTICIPANT	\N	PRESENT	1
549602	545501	14219Q	PRESIDENT	0	PRESENT	0
549603	545501	19820Y	PARTICIPANT	\N	PRESENT	0
549604	545501	19826F	PARTICIPANT	\N	PRESENT	0
549605	545501	20046A	PARTICIPANT	\N	PRESENT	1
549606	545501	19599P	PARTICIPANT	\N	PRESENT	0
549607	545501	20096L	PARTICIPANT	\N	PRESENT	0
549608	545501	17229F	PARTICIPANT	\N	PRESENT	0
549609	545501	18083K	PARTICIPANT	\N	PRESENT	0
549610	545501	14237S	PARTICIPANT	\N	PRESENT	0
549611	545501	20106U	PARTICIPANT	\N	PRESENT	1
549612	545501	20118Y	PARTICIPANT	\N	PRESENT	0
549613	545501	19503N	PARTICIPANT	\N	PRESENT	0
549614	545501	19739H	PARTICIPANT	\N	PRESENT	0
549615	545501	20020P	PARTICIPANT	\N	PRESENT	0
549616	545501	19745F	PARTICIPANT	\N	PRESENT	0
549617	547892	11067R	PARTICIPANT	\N	PRESENT	0
549618	547892	20090E	PARTICIPANT	\N	PRESENT	0
549619	547892	11097X	PARTICIPANT	\N	PRESENT	0
549620	547892	18193Q	PARTICIPANT	\N	PRESENT	0
549621	547892	19703U	PARTICIPANT	\N	PRESENT	0
549622	547892	14195A	PARTICIPANT	\N	PRESENT	0
549623	547892	14217N	PARTICIPANT	\N	PRESENT	0
549624	547892	19683J	PARTICIPANT	\N	PRESENT	0
549625	547892	10006L	PRESIDENT	0	PRESENT	0
549626	547892	19713W	PARTICIPANT	\N	PRESENT	0
549627	547892	20040T	PARTICIPANT	\N	PRESENT	0
549628	547892	17965H	PARTICIPANT	\N	PRESENT	0
549629	547892	19691J	PARTICIPANT	\N	PRESENT	0
549630	547892	19723Y	PARTICIPANT	\N	PRESENT	0
549631	547892	14071N	PARTICIPANT	\N	PRESENT	0
549632	549003	20088L	PARTICIPANT	\N	PRESENT	1
549633	549003	19782L	PARTICIPANT	\N	PRESENT	1
549634	549003	01043Q	PARTICIPANT	\N	PRESENT	0
555670	555032	19599P	PARTICIPANT	\N	PRESENT	0
555671	555032	19631V	PARTICIPANT	\N	PRESENT	0
555672	555032	19301E	PARTICIPANT	\N	PRESENT	0
555673	555032	95063L	PARTICIPANT	\N	PRESENT	0
555674	555032	20016T	PARTICIPANT	\N	PRESENT	0
555675	555032	04057K	PARTICIPANT	\N	PRESENT	0
555676	555032	19319Q	PARTICIPANT	\N	PRESENT	0
555677	554659	14331P	PARTICIPANT	\N	EXCUSE	0
555678	555032	19713W	PARTICIPANT	\N	PRESENT	0
555679	555032	19691J	PARTICIPANT	\N	PRESENT	0
555680	555032	14030Q	PARTICIPANT	\N	PRESENT	0
555681	555032	01024M	PARTICIPANT	\N	PRESENT	0
555682	555032	14215L	PARTICIPANT	\N	PRESENT	0
555683	555032	08061X	PARTICIPANT	\N	PRESENT	0
555684	555032	11056N	PARTICIPANT	\N	PRESENT	0
555685	555032	11077T	PARTICIPANT	\N	PRESENT	0
555686	555032	20064C	PARTICIPANT	\N	PRESENT	0
555687	555032	20062A	PARTICIPANT	\N	PRESENT	0
555688	555032	14053L	PARTICIPANT	\N	PRESENT	0
555689	555032	14071N	PARTICIPANT	\N	PRESENT	0
555690	555032	14069U	PARTICIPANT	\N	PRESENT	0
555691	555032	14042U	PARTICIPANT	\N	PRESENT	0
555692	555032	19369B	PARTICIPANT	\N	PRESENT	0
555693	555032	08028W	PARTICIPANT	\N	PRESENT	0
555694	555032	20024T	PARTICIPANT	\N	PRESENT	0
555695	555032	19747H	PARTICIPANT	\N	PRESENT	0
555696	555032	08015R	PARTICIPANT	\N	PRESENT	0
555697	555032	07029T	PARTICIPANT	\N	PRESENT	0
555698	555032	14021P	PARTICIPANT	\N	PRESENT	0
555699	555032	14221J	PARTICIPANT	\N	PRESENT	0
555700	555032	14147R	PARTICIPANT	\N	PRESENT	0
555701	555032	14187A	PARTICIPANT	\N	PRESENT	0
555702	555032	11103C	PARTICIPANT	\N	PRESENT	0
555703	555032	97011G	PARTICIPANT	\N	PRESENT	0
555704	555032	11010L	PARTICIPANT	\N	PRESENT	0
555705	555032	18083K	PARTICIPANT	\N	PRESENT	0
555706	555032	19533U	PARTICIPANT	\N	PRESENT	0
555707	555032	19467C	PARTICIPANT	\N	PRESENT	0
555708	555032	20066E	PARTICIPANT	\N	PRESENT	0
555709	555032	11090Q	PARTICIPANT	\N	PRESENT	0
555710	555032	01028R	PARTICIPANT	\N	PRESENT	0
555711	555032	14031R	PARTICIPANT	\N	PRESENT	0
555712	555032	19507S	PARTICIPANT	\N	PRESENT	0
555713	555032	14357A	PARTICIPANT	\N	PRESENT	0
555714	555032	14211G	PARTICIPANT	\N	PRESENT	0
555715	555032	14223L	PARTICIPANT	\N	PRESENT	0
555716	555032	04033B	PARTICIPANT	\N	PRESENT	0
555717	555032	20148F	PARTICIPANT	\N	PRESENT	0
555718	555032	19798U	PARTICIPANT	\N	PRESENT	0
555719	555032	20018V	PARTICIPANT	\N	PRESENT	0
555720	555032	19347U	PARTICIPANT	\N	PRESENT	0
555721	555032	04047H	PARTICIPANT	\N	PRESENT	0
555722	555032	20054A	PARTICIPANT	\N	PRESENT	0
555723	555032	14219Q	PARTICIPANT	\N	PRESENT	0
555724	555032	19367Y	PARTICIPANT	\N	PRESENT	0
555668	555032	86034E	PARTICIPANT	\N	PRESENT	0
555669	555032	20028X	PARTICIPANT	\N	PRESENT	0
555725	555032	19575F	PARTICIPANT	\N	PRESENT	0
555726	555032	19515S	PARTICIPANT	\N	PRESENT	0
555727	555032	01057W	PARTICIPANT	\N	PRESENT	0
555728	555032	20056C	PARTICIPANT	\N	PRESENT	0
555729	555032	20140W	PARTICIPANT	\N	PRESENT	0
555730	555032	19954N	PARTICIPANT	\N	PRESENT	0
555731	555032	14059S	PARTICIPANT	\N	PRESENT	0
555732	555032	20026V	PARTICIPANT	\N	PRESENT	0
555733	555032	19383Y	PARTICIPANT	\N	PRESENT	0
555734	555032	20020P	PARTICIPANT	\N	PRESENT	0
555735	555032	20124W	PARTICIPANT	\N	PRESENT	0
555736	555032	04085P	PARTICIPANT	\N	PRESENT	0
555737	555032	19695N	PARTICIPANT	\N	PRESENT	0
555738	555032	14038Y	PARTICIPANT	\N	PRESENT	0
555739	555032	19447X	PARTICIPANT	\N	PRESENT	0
555740	555032	11012A	PARTICIPANT	\N	PRESENT	0
555741	555032	19563B	PARTICIPANT	\N	PRESENT	0
555742	555032	14189C	PARTICIPANT	\N	PRESENT	0
555743	555353	20090E	PARTICIPANT	\N	PRESENT	0
555744	555353	20078J	PARTICIPANT	\N	PRESENT	0
555745	555353	20048C	PRESIDENT	0	PRESENT	0
555746	555353	20052X	PARTICIPANT	\N	PRESENT	1
555747	555353	17779H	PARTICIPANT	\N	PRESENT	0
555748	555353	20062A	PARTICIPANT	\N	EXCUSE	0
555749	555032	14205J	PARTICIPANT	\N	PRESENT	0
555750	555032	19415P	PARTICIPANT	\N	PRESENT	0
555751	555032	20108W	PARTICIPANT	\N	PRESENT	0
555752	555032	19681G	PARTICIPANT	\N	PRESENT	0
555753	555032	19553Y	PARTICIPANT	\N	PRESENT	0
555754	555032	14151M	PARTICIPANT	\N	PRESENT	0
555756	555032	19689Q	PARTICIPANT	\N	PRESENT	0
555757	555032	14105F	PARTICIPANT	\N	PRESENT	0
555829	555032	14121F	PARTICIPANT	\N	PRESENT	0
555764	555032	20090E	PARTICIPANT	\N	PRESENT	0
555766	555032	14083S	PARTICIPANT	\N	PRESENT	0
555769	555032	01025N	PARTICIPANT	\N	PRESENT	0
555770	555032	17023S	PARTICIPANT	\N	PRESENT	0
555771	555032	16685X	PARTICIPANT	\N	PRESENT	0
555778	555777	19447X	PARTICIPANT	\N	PRESENT	0
555779	555777	19581D	PARTICIPANT	\N	PRESENT	0
555780	555777	19954N	PARTICIPANT	\N	PRESENT	0
555781	555777	07004J	PARTICIPANT	\N	PRESENT	0
555782	555755	19333N	PARTICIPANT	\N	PRESENT	0
555831	555032	04043D	PARTICIPANT	\N	PRESENT	0
555784	555755	20136B	PARTICIPANT	\N	PRESENT	0
555785	555755	14031R	PARTICIPANT	\N	PRESENT	0
555786	555755	20038A	PARTICIPANT	\N	PRESENT	0
555787	555755	20076G	PARTICIPANT	\N	PRESENT	0
555788	555755	14219Q	PRESIDENT	0	PRESENT	0
555789	555755	19251M	PARTICIPANT	\N	PRESENT	0
555790	555755	19826F	PARTICIPANT	\N	PRESENT	0
555791	555755	19599P	PARTICIPANT	\N	PRESENT	0
555792	555755	17229F	PARTICIPANT	\N	PRESENT	0
555793	555755	18083K	PARTICIPANT	\N	PRESENT	0
555794	555755	20100N	PARTICIPANT	\N	PRESENT	0
555795	555755	20118Y	PARTICIPANT	\N	PRESENT	0
555796	555755	19745F	PARTICIPANT	\N	PRESENT	0
555797	555755	19685L	PARTICIPANT	\N	PRESENT	0
555798	555755	19681G	PARTICIPANT	\N	PRESENT	0
555799	555755	20120S	PARTICIPANT	\N	PRESENT	0
555801	555800	19447X	PARTICIPANT	\N	PRESENT	0
555802	555800	19581D	PARTICIPANT	\N	PRESENT	0
555803	555800	19954N	PARTICIPANT	\N	PRESENT	0
555804	555755	20140W	PARTICIPANT	\N	PRESENT	0
555805	555755	19549D	PARTICIPANT	\N	PRESENT	0
555806	555755	14237S	PARTICIPANT	\N	PRESENT	0
555807	555800	07004J	PARTICIPANT	\N	PRESENT	0
555808	555800	11026G	PARTICIPANT	\N	PRESENT	0
555809	555755	14169X	PARTICIPANT	\N	PRESENT	0
555810	555032	19349W	PARTICIPANT	\N	PRESENT	0
555811	555032	20102Q	PARTICIPANT	\N	PRESENT	0
555813	555812	19447X	PARTICIPANT	\N	PRESENT	0
555814	555812	07004J	PARTICIPANT	\N	PRESENT	0
555815	555032	19758L	PARTICIPANT	\N	PRESENT	0
555816	555032	19760E	PARTICIPANT	\N	PRESENT	0
555818	555817	19447X	PARTICIPANT	\N	PRESENT	0
555819	555817	19954N	PARTICIPANT	\N	PRESENT	0
555820	555817	11026G	PARTICIPANT	\N	PRESENT	0
555821	555817	07004J	PARTICIPANT	\N	PRESENT	0
555822	555032	14249W	PARTICIPANT	\N	PRESENT	0
555823	555032	19543W	PARTICIPANT	\N	PRESENT	0
555824	555755	19701S	PARTICIPANT	\N	PRESENT	0
555825	555755	20096L	PARTICIPANT	\N	PRESENT	0
555826	555755	20020P	PARTICIPANT	\N	PRESENT	0
555827	555755	20024T	PARTICIPANT	\N	PRESENT	0
555828	555755	08060W	PARTICIPANT	\N	PRESENT	1
555830	555032	19741B	PARTICIPANT	\N	PRESENT	0
555832	555032	19479G	PARTICIPANT	\N	PRESENT	0
555833	555755	19820Y	PARTICIPANT	\N	PRESENT	1
555834	555032	12041X	PARTICIPANT	\N	PRESENT	0
555835	555032	20044X	PARTICIPANT	\N	PRESENT	0
555836	555032	04035D	PARTICIPANT	\N	PRESENT	0
555837	555032	20022R	PARTICIPANT	\N	PRESENT	0
555838	555032	11067R	PARTICIPANT	\N	PRESENT	0
555839	555353	19689Q	PARTICIPANT	\N	PRESENT	0
555840	555032	14257W	PARTICIPANT	\N	PRESENT	0
555841	555032	11043H	PARTICIPANT	\N	PRESENT	0
556031	556030	04047H	PARTICIPANT	\N	PRESENT	0
556032	556030	11066Q	PARTICIPANT	\N	PRESENT	0
556361	554923	19717B	PARTICIPANT	\N	PRESENT	1
556362	554923	19679N	PARTICIPANT	\N	PRESENT	0
557000	555398	17023S	PARTICIPANT	\N	PRESENT	1
557001	555398	08047A	PARTICIPANT	\N	PRESENT	1
542812	539588	19319Q	PARTICIPANT	\N	PRESENT	0
542813	539588	20034V	PARTICIPANT	\N	PRESENT	0
542821	539588	19577H	PARTICIPANT	\N	PRESENT	0
542832	539588	19715Y	PARTICIPANT	\N	EXCUSE	0
544994	544993	14187A	PARTICIPANT	\N	PRESENT	0
545421	534870	20144B	PARTICIPANT	\N	EXCUSE	0
545718	545159	19954N	PARTICIPANT	\N	PRESENT	1
545719	545159	19629C	PARTICIPANT	\N	PRESENT	1
545720	545159	19581D	PARTICIPANT	\N	PRESENT	1
545721	545159	14147R	PARTICIPANT	\N	PRESENT	1
545722	545159	95063L	PARTICIPANT	\N	PRESENT	1
545723	545159	14107H	PARTICIPANT	\N	PRESENT	1
547968	547967	14205J	PARTICIPANT	\N	PRESENT	0
547969	547967	14033T	PARTICIPANT	\N	PRESENT	0
547970	547967	20054A	PARTICIPANT	\N	PRESENT	0
547975	547974	20054A	PARTICIPANT	\N	PRESENT	0
547976	547974	14207L	PARTICIPANT	\N	PRESENT	0
547977	547974	14033T	PARTICIPANT	\N	PRESENT	0
547978	547974	11090Q	PARTICIPANT	\N	PRESENT	0
547980	547974	14257W	PARTICIPANT	\N	PRESENT	0
547984	547982	14033T	PARTICIPANT	\N	PRESENT	0
547985	547982	14205J	PARTICIPANT	\N	PRESENT	0
547986	547982	11090Q	PARTICIPANT	\N	PRESENT	0
547987	547982	19782L	PARTICIPANT	\N	PRESENT	0
547988	547982	14207L	PARTICIPANT	\N	PRESENT	0
547989	547982	14257W	PARTICIPANT	\N	PRESENT	0
547990	547982	20054A	PARTICIPANT	\N	PRESENT	0
548013	543958	20104S	PARTICIPANT	\N	PRESENT	1
548014	543958	20096L	PARTICIPANT	\N	PRESENT	0
548015	543958	19711U	PARTICIPANT	\N	PRESENT	0
549791	549789	01043Q	PARTICIPANT	\N	PRESENT	0
549792	549790	01043Q	PARTICIPANT	\N	PRESENT	0
549793	549790	14187A	PARTICIPANT	\N	PRESENT	0
549965	547139	14189C	PARTICIPANT	\N	PRESENT	0
549967	547139	20024T	PARTICIPANT	\N	PRESENT	0
549968	547139	19575F	PARTICIPANT	\N	PRESENT	0
549969	547139	20116W	PARTICIPANT	\N	PRESENT	0
549971	547139	14069U	PARTICIPANT	\N	PRESENT	0
549972	547139	20042V	PARTICIPANT	\N	PRESENT	0
549974	547139	20090E	PARTICIPANT	\N	PRESENT	0
549975	547139	14083S	PARTICIPANT	\N	PRESENT	0
549976	547139	11053K	PARTICIPANT	\N	PRESENT	0
549977	547139	17229F	PARTICIPANT	\N	PRESENT	0
549978	547139	08045X	PARTICIPANT	\N	PRESENT	0
549981	547139	14211G	PARTICIPANT	\N	PRESENT	0
549982	547139	01048V	PARTICIPANT	\N	PRESENT	0
549983	547139	14179A	PARTICIPANT	\N	PRESENT	0
549985	547139	19333N	PARTICIPANT	\N	PRESENT	0
549987	547139	20056C	PARTICIPANT	\N	PRESENT	0
549989	547139	20052X	PARTICIPANT	\N	PRESENT	0
549991	547139	19671E	PARTICIPANT	\N	PRESENT	0
549992	547139	19745F	PARTICIPANT	\N	PRESENT	0
549993	547139	19739H	PARTICIPANT	\N	PRESENT	0
549995	547139	19349W	PARTICIPANT	\N	PRESENT	0
549997	547139	20150Y	PARTICIPANT	\N	PRESENT	0
550000	547139	20044X	PARTICIPANT	\N	PRESENT	0
550097	550096	08009T	PARTICIPANT	\N	PRESENT	0
550099	550096	20044X	PARTICIPANT	\N	PRESENT	0
550109	550108	19711U	PARTICIPANT	\N	PRESENT	0
550133	550132	19479G	PARTICIPANT	\N	PRESENT	0
550135	550134	19479G	PARTICIPANT	\N	PRESENT	0
552097	551505	17965H	PARTICIPANT	\N	PRESENT	1
551538	551537	19643A	PARTICIPANT	\N	PRESENT	1
551539	551537	19954N	PARTICIPANT	\N	PRESENT	1
551540	551537	20132W	PARTICIPANT	\N	PRESENT	1
551541	551537	19593H	PARTICIPANT	\N	PRESENT	0
551542	551537	19611R	PARTICIPANT	\N	PRESENT	0
552053	551505	11053K	PARTICIPANT	\N	PRESENT	0
552107	551505	20066E	PARTICIPANT	\N	PRESENT	0
552112	551505	20098N	PARTICIPANT	\N	PRESENT	1
552113	551505	20040T	PARTICIPANT	\N	EXCUSE	0
552183	552182	14001X	PARTICIPANT	\N	PRESENT	0
552184	552182	04035D	PARTICIPANT	\N	PRESENT	0
552185	552182	20042V	PARTICIPANT	\N	PRESENT	0
559910	559650	11012A	PARTICIPANT	\N	PRESENT	0
559911	559650	08017T	PARTICIPANT	\N	PRESENT	0
559912	559650	12028B	PARTICIPANT	\N	PRESENT	0
559913	559650	11054L	PARTICIPANT	\N	PRESENT	0
559914	559650	01062T	PARTICIPANT	\N	PRESENT	0
559915	559650	20142Y	PARTICIPANT	\N	PRESENT	0
559916	559650	11083R	PARTICIPANT	\N	PRESENT	0
559917	559650	11070L	PARTICIPANT	\N	PRESENT	0
559918	559650	14083S	PARTICIPANT	\N	PRESENT	0
559919	559650	08047A	PARTICIPANT	\N	PRESENT	0
559920	559650	19443T	PARTICIPANT	\N	PRESENT	0
559921	559650	19709B	PARTICIPANT	\N	PRESENT	0
559922	559650	20034V	PARTICIPANT	\N	PRESENT	0
559923	559650	19693L	PARTICIPANT	\N	PRESENT	0
559924	559650	20070A	PARTICIPANT	\N	PRESENT	0
559925	559650	04034C	PARTICIPANT	\N	PRESENT	0
559926	559650	19421M	PARTICIPANT	\N	PRESENT	0
559927	559650	19669L	PARTICIPANT	\N	PRESENT	0
559928	559650	04042C	PARTICIPANT	\N	PRESENT	0
559929	559650	04085P	PARTICIPANT	\N	PRESENT	0
559908	559650	19719D	PARTICIPANT	\N	PRESENT	0
559909	559650	12041X	PARTICIPANT	\N	PRESENT	0
559930	559650	11115U	PARTICIPANT	\N	PRESENT	0
559931	559650	14021P	PARTICIPANT	\N	PRESENT	0
559932	559650	16685X	PARTICIPANT	\N	PRESENT	0
559933	559650	14059S	PARTICIPANT	\N	PRESENT	0
559934	559650	01028R	PARTICIPANT	\N	PRESENT	0
559935	559650	11027H	PARTICIPANT	\N	PRESENT	0
559936	559650	17023S	PARTICIPANT	\N	PRESENT	0
559937	559650	20048C	PARTICIPANT	\N	PRESENT	0
559938	559650	19347U	PARTICIPANT	\N	PRESENT	0
559984	559648	19549D	PARTICIPANT	\N	EXCUSE	0
560003	559651	99004R	PARTICIPANT	\N	PRESENT	0
560004	559651	19319Q	PARTICIPANT	\N	PRESENT	0
560007	559651	19649G	PARTICIPANT	\N	PRESENT	0
560009	559651	11045K	PARTICIPANT	\N	PRESENT	0
560011	559651	11103C	PARTICIPANT	\N	PRESENT	0
560012	559651	20108W	PARTICIPANT	\N	PRESENT	0
560013	559651	19673G	PARTICIPANT	\N	PRESENT	0
560014	559651	19683J	PARTICIPANT	\N	PRESENT	0
560015	559651	19583F	PARTICIPANT	\N	PRESENT	0
560017	559651	19629C	PARTICIPANT	\N	PRESENT	0
560018	559651	20072C	PARTICIPANT	\N	PRESENT	0
560019	559651	17965H	PARTICIPANT	\N	PRESENT	0
560020	559651	95063L	PARTICIPANT	\N	PRESENT	0
560021	559651	04085P	PARTICIPANT	\N	PRESENT	0
560023	559651	20076G	PARTICIPANT	\N	PRESENT	0
560024	559651	19725B	PARTICIPANT	\N	PRESENT	0
560026	559651	11026G	PARTICIPANT	\N	PRESENT	0
560027	559651	20078J	PARTICIPANT	\N	PRESENT	0
560029	559651	14229S	PARTICIPANT	\N	PRESENT	0
560031	559651	20066E	PARTICIPANT	\N	PRESENT	0
560032	559651	14267Y	PARTICIPANT	\N	PRESENT	0
560033	559651	19749K	PARTICIPANT	\N	PRESENT	0
560034	559651	14215L	PARTICIPANT	\N	PRESENT	0
560035	559651	10015M	PARTICIPANT	\N	PRESENT	0
560036	559651	19766L	PARTICIPANT	\N	PRESENT	0
560037	559651	11031D	PARTICIPANT	\N	PRESENT	0
560038	559651	12028B	PARTICIPANT	\N	PRESENT	0
560039	559651	14207L	PARTICIPANT	\N	PRESENT	0
560044	559651	19697Q	PARTICIPANT	\N	PRESENT	0
560041	559651	05008E	PARTICIPANT	\N	PRESENT	0
560042	559651	04047H	PARTICIPANT	\N	PRESENT	0
560043	559651	01058X	PARTICIPANT	\N	PRESENT	0
560045	559651	14053L	PARTICIPANT	\N	PRESENT	0
560046	559651	14223L	PARTICIPANT	\N	PRESENT	0
560047	559651	19447X	PARTICIPANT	\N	PRESENT	0
560048	559651	19729F	PARTICIPANT	\N	PRESENT	0
560049	559651	11033F	PARTICIPANT	\N	PRESENT	0
560050	559651	04057K	PARTICIPANT	\N	PRESENT	0
560051	559651	19657G	PARTICIPANT	\N	PRESENT	0
560052	559651	10006L	PARTICIPANT	\N	PRESENT	0
560053	559651	19703U	PARTICIPANT	\N	PRESENT	0
560054	559651	19647E	PARTICIPANT	\N	PRESENT	0
560055	559651	14089Y	PARTICIPANT	\N	PRESENT	0
560056	559651	19467C	PARTICIPANT	\N	PRESENT	0
560057	559651	19689Q	PARTICIPANT	\N	PRESENT	0
560058	559651	19479G	PARTICIPANT	\N	PRESENT	0
560059	559651	04033B	PARTICIPANT	\N	PRESENT	0
560060	559651	19679N	PARTICIPANT	\N	PRESENT	0
560061	559651	14179A	PARTICIPANT	\N	PRESENT	0
560062	559651	19687N	PARTICIPANT	\N	PRESENT	0
560063	559651	20054A	PARTICIPANT	\N	PRESENT	0
560064	559651	08061X	PARTICIPANT	\N	PRESENT	0
560065	559651	07004J	PARTICIPANT	\N	PRESENT	0
560067	559651	18083K	PARTICIPANT	\N	PRESENT	0
563677	563676	04070G	PARTICIPANT	\N	PRESENT	0
563678	563676	14169X	PARTICIPANT	\N	PRESENT	0
564204	564202	05008E	PARTICIPANT	\N	EXCUSE	0
564291	564262	18193Q	PARTICIPANT	\N	PRESENT	1
564302	564263	18193Q	PARTICIPANT	\N	PRESENT	1
564307	564305	20090E	PARTICIPANT	\N	PRESENT	0
564308	564305	19591F	PARTICIPANT	\N	PRESENT	0
564309	564305	20114U	PARTICIPANT	\N	PRESENT	0
564310	564305	19729F	PARTICIPANT	\N	PRESENT	0
564311	564305	11067R	PARTICIPANT	\N	PRESENT	0
564312	564306	20090E	PARTICIPANT	\N	PRESENT	0
564313	564306	19591F	PARTICIPANT	\N	PRESENT	0
564314	564306	20114U	PARTICIPANT	\N	PRESENT	0
564315	564306	19729F	PARTICIPANT	\N	PRESENT	0
564316	564266	14213J	PARTICIPANT	\N	PRESENT	0
564317	564266	11067R	PARTICIPANT	\N	PRESENT	0
564318	564266	19798U	PARTICIPANT	\N	PRESENT	0
564319	564266	19367Y	PARTICIPANT	\N	PRESENT	0
564320	564266	14042U	PARTICIPANT	\N	PRESENT	0
564321	564266	19691J	PARTICIPANT	\N	PRESENT	0
564322	562275	14042U	PARTICIPANT	\N	PRESENT	0
564323	562275	14213J	PARTICIPANT	\N	PRESENT	0
564324	562275	19367Y	PARTICIPANT	\N	PRESENT	0
564325	562275	11067R	PARTICIPANT	\N	PRESENT	0
565458	565457	20042V	PARTICIPANT	\N	PRESENT	0
565459	565457	20024T	PARTICIPANT	\N	PRESENT	0
565460	565457	18083K	PARTICIPANT	\N	PRESENT	0
565464	565457	11026G	PARTICIPANT	\N	PRESENT	0
565462	565457	11065P	PARTICIPANT	\N	PRESENT	0
565463	565457	10015M	PARTICIPANT	\N	PRESENT	0
565818	564387	14225N	PARTICIPANT	\N	PRESENT	0
565880	564387	19545Y	PARTICIPANT	\N	PRESENT	1
565878	564387	20022R	PARTICIPANT	\N	PRESENT	1
565879	564387	11040E	PARTICIPANT	\N	PRESENT	1
565881	564387	19647E	PARTICIPANT	\N	PRESENT	1
565882	564387	14121F	PARTICIPANT	\N	PRESENT	1
565883	564387	99004R	PARTICIPANT	\N	PRESENT	1
565884	564387	19762G	PARTICIPANT	\N	PRESENT	1
565886	564387	11074Q	PARTICIPANT	\N	EXCUSE	0
565963	565931	14357A	PARTICIPANT	\N	PRESENT	0
565964	565931	14026U	PARTICIPANT	\N	PRESENT	0
565965	565931	14097Y	PARTICIPANT	\N	PRESENT	0
565966	565931	19725B	PARTICIPANT	\N	PRESENT	1
565967	565931	11083R	PARTICIPANT	\N	PRESENT	0
565968	565931	19441R	PARTICIPANT	\N	PRESENT	0
565969	565931	20100N	PARTICIPANT	\N	PRESENT	0
565970	565931	04034C	PARTICIPANT	\N	PRESENT	1
565971	565931	14237S	PARTICIPANT	\N	PRESENT	1
565972	565931	04070G	PARTICIPANT	\N	EXCUSE	0
565973	565931	14331P	PRESIDENT	0	PRESENT	0
565974	565931	14001X	PARTICIPANT	\N	PRESENT	0
565975	564342	12041X	PARTICIPANT	\N	PRESENT	0
565976	565931	14207L	PARTICIPANT	\N	PRESENT	1
565977	565931	20128B	PARTICIPANT	\N	PRESENT	1
565978	565931	11026G	PARTICIPANT	\N	PRESENT	0
565979	564342	19721W	PARTICIPANT	\N	PRESENT	0
565980	564342	14042U	PARTICIPANT	\N	PRESENT	0
565981	564342	20028X	PARTICIPANT	\N	PRESENT	0
565982	564342	20136B	PARTICIPANT	\N	PRESENT	0
565983	564342	14026U	PARTICIPANT	\N	PRESENT	0
565984	564342	20020P	PARTICIPANT	\N	PRESENT	0
565985	564342	14191V	PARTICIPANT	\N	PRESENT	0
565986	565931	04092N	PARTICIPANT	\N	PRESENT	0
565990	564342	20018V	PARTICIPANT	\N	PRESENT	0
565992	564342	19760E	PARTICIPANT	\N	PRESENT	0
565995	564342	14038Y	PARTICIPANT	\N	PRESENT	0
565997	564342	20180F	PARTICIPANT	\N	PRESENT	0
566000	565991	19593H	PRESIDENT	0	PRESENT	0
566001	565991	19611R	PARTICIPANT	\N	PRESENT	0
566002	565991	19693L	PARTICIPANT	\N	PRESENT	0
566003	564342	20086J	PARTICIPANT	\N	PRESENT	0
566004	564342	14187A	PARTICIPANT	\N	PRESENT	0
566008	564342	14041T	PARTICIPANT	\N	PRESENT	0
566009	564342	19826F	PARTICIPANT	\N	PRESENT	0
566010	564342	20038A	PARTICIPANT	\N	PRESENT	0
566011	564342	20070A	PARTICIPANT	\N	PRESENT	0
566012	564342	19421M	PARTICIPANT	\N	PRESENT	0
566013	564342	11027H	PARTICIPANT	\N	PRESENT	0
566021	564342	19441R	PARTICIPANT	\N	PRESENT	0
566022	564342	14249W	PARTICIPANT	\N	PRESENT	0
566024	566023	14030Q	PARTICIPANT	\N	PRESENT	0
566025	566023	19643A	PARTICIPANT	\N	PRESENT	1
566026	566023	20114U	PARTICIPANT	\N	PRESENT	0
566027	564342	08045X	PARTICIPANT	\N	PRESENT	0
566028	564388	14327T	PARTICIPANT	\N	PRESENT	0
566029	564388	99004R	PARTICIPANT	\N	PRESENT	0
566030	564388	19667J	PARTICIPANT	\N	PRESENT	0
566031	564342	08060W	PARTICIPANT	\N	PRESENT	0
566032	564342	14083S	PARTICIPANT	\N	PRESENT	0
566033	564388	11048N	PARTICIPANT	\N	PRESENT	0
566034	564342	19467C	PARTICIPANT	\N	PRESENT	0
566035	564388	19711U	PARTICIPANT	\N	PRESENT	0
566036	564388	11053K	PARTICIPANT	\N	PRESENT	0
566037	564388	14225N	PRESIDENT	0	PRESENT	0
566038	564388	07029T	PARTICIPANT	\N	PRESENT	0
566039	564388	08034U	PARTICIPANT	\N	PRESENT	0
566040	564388	08010L	PARTICIPANT	\N	PRESENT	0
566041	564342	14107H	PARTICIPANT	\N	PRESENT	0
566042	564388	20070A	PARTICIPANT	\N	PRESENT	0
566043	566023	20152B	PARTICIPANT	\N	PRESENT	0
566044	564342	20124W	PARTICIPANT	\N	PRESENT	0
566045	566023	18083K	PARTICIPANT	\N	PRESENT	1
566046	566023	20134Y	PARTICIPANT	\N	PRESENT	0
566047	566023	20124W	PARTICIPANT	\N	PRESENT	0
566048	566023	19673G	PARTICIPANT	\N	PRESENT	0
566049	566023	04035D	PARTICIPANT	\N	EXCUSE	0
566050	566023	19691J	PARTICIPANT	\N	PRESENT	0
566051	566023	19553Y	PARTICIPANT	\N	PRESENT	1
566052	566023	08017T	PARTICIPANT	\N	PRESENT	0
566053	566023	04057K	PARTICIPANT	\N	PRESENT	0
566054	566023	20098N	PARTICIPANT	\N	PRESENT	1
566055	566023	19527W	PARTICIPANT	\N	PRESENT	0
566056	564342	19695N	PARTICIPANT	\N	PRESENT	0
566057	564388	14083S	PARTICIPANT	\N	PRESENT	0
566058	564342	14001X	PARTICIPANT	\N	PRESENT	0
566059	564342	19349W	PARTICIPANT	\N	PRESENT	0
566060	564342	14031R	PARTICIPANT	\N	PRESENT	0
566061	564342	19611R	PARTICIPANT	\N	PRESENT	0
566062	564342	19335Q	PARTICIPANT	\N	PRESENT	0
566063	564342	19762G	PARTICIPANT	\N	PRESENT	0
566064	564342	20172F	PARTICIPANT	\N	PRESENT	0
566065	564342	20142Y	PARTICIPANT	\N	PRESENT	0
566066	564342	19585H	PARTICIPANT	\N	PRESENT	0
566077	564342	17589D	PARTICIPANT	\N	PRESENT	0
566163	564343	19667J	PARTICIPANT	\N	PRESENT	0
566165	564343	20070A	PARTICIPANT	\N	PRESENT	0
566166	564343	20108W	PARTICIPANT	\N	PRESENT	0
566167	564343	11072N	PARTICIPANT	\N	PRESENT	0
566168	564343	19585H	PARTICIPANT	\N	PRESENT	0
566169	564343	20110Q	PARTICIPANT	\N	PRESENT	0
566170	564343	04085P	PARTICIPANT	\N	PRESENT	0
566171	564343	20172F	PARTICIPANT	\N	PRESENT	0
566133	564343	11045K	PARTICIPANT	\N	PRESENT	0
566160	564343	11070L	PARTICIPANT	\N	PRESENT	0
566172	564343	19649G	PARTICIPANT	\N	PRESENT	0
566173	564343	20132W	PARTICIPANT	\N	PRESENT	0
566174	564343	14215L	PARTICIPANT	\N	PRESENT	0
566175	564343	18083K	PARTICIPANT	\N	PRESENT	0
566177	564343	19747H	PARTICIPANT	\N	PRESENT	0
566178	564343	19399H	PARTICIPANT	\N	PRESENT	0
566196	563019	11067R	PARTICIPANT	\N	PRESENT	0
566197	563019	20048C	PRESIDENT	0	PRESENT	0
566198	563019	17779H	PARTICIPANT	\N	PRESENT	0
566199	563019	14053L	PARTICIPANT	\N	EXCUSE	0
566200	564343	14083S	PARTICIPANT	\N	PRESENT	0
566203	563019	19651A	PARTICIPANT	\N	PRESENT	1
566204	564343	11040E	PARTICIPANT	\N	PRESENT	0
566206	564343	01048V	PARTICIPANT	\N	PRESENT	0
566207	563019	20084G	PARTICIPANT	\N	PRESENT	1
566208	564343	20134Y	PARTICIPANT	\N	PRESENT	0
566209	564343	14267Y	PARTICIPANT	\N	PRESENT	0
566210	564343	20026V	PARTICIPANT	\N	PRESENT	0
566211	564343	19479G	PARTICIPANT	\N	PRESENT	0
566212	564343	19467C	PARTICIPANT	\N	PRESENT	0
566213	564343	11083R	PARTICIPANT	\N	PRESENT	0
544094	543936	01057W	PARTICIPANT	\N	PRESENT	0
544095	543936	19762G	PARTICIPANT	\N	PRESENT	0
544096	543936	20080C	PARTICIPANT	\N	PRESENT	1
544097	543936	99004R	PARTICIPANT	\N	PRESENT	1
544098	543936	20126Y	PARTICIPANT	\N	PRESENT	1
544099	543936	19711U	PARTICIPANT	\N	PRESENT	1
544100	543936	12016W	PARTICIPANT	\N	PRESENT	1
544101	543936	08010L	PARTICIPANT	\N	PRESENT	1
544102	543936	14253S	PARTICIPANT	\N	PRESENT	1
544103	543936	20050V	PARTICIPANT	\N	PRESENT	1
544104	543936	20036X	PARTICIPANT	\N	PRESENT	1
544105	543936	08073C	PARTICIPANT	\N	PRESENT	1
544106	543936	11012A	PARTICIPANT	\N	PRESENT	1
544107	543936	14173T	PARTICIPANT	\N	PRESENT	1
544132	543936	19545Y	PARTICIPANT	\N	PRESENT	0
544133	543936	19671E	PARTICIPANT	\N	PRESENT	0
544146	544144	08011M	PARTICIPANT	\N	PRESENT	0
544158	544157	14083S	PARTICIPANT	\N	PRESENT	0
544159	544157	11012A	PARTICIPANT	\N	PRESENT	0
544605	544603	08060W	PARTICIPANT	\N	PRESENT	0
544606	544603	05012A	PARTICIPANT	\N	PRESENT	0
544607	544603	19525U	PARTICIPANT	\N	PRESENT	0
544608	544603	17229F	PARTICIPANT	\N	PRESENT	0
544609	544603	20038A	PARTICIPANT	\N	PRESENT	0
544610	544603	20100N	PARTICIPANT	\N	PRESENT	0
544611	544603	19387D	PARTICIPANT	\N	PRESENT	0
544612	544603	19551W	PARTICIPANT	\N	PRESENT	0
544613	544603	20136B	PARTICIPANT	\N	PRESENT	0
544617	544616	08060W	PARTICIPANT	\N	PRESENT	0
544618	544616	05012A	PARTICIPANT	\N	PRESENT	0
544619	544616	17229F	PARTICIPANT	\N	PRESENT	0
544621	544616	20038A	PARTICIPANT	\N	PRESENT	0
544622	544616	19387D	PARTICIPANT	\N	PRESENT	0
544623	544616	19551W	PARTICIPANT	\N	PRESENT	0
544624	544616	20136B	PARTICIPANT	\N	PRESENT	0
544627	544626	08060W	PARTICIPANT	\N	PRESENT	0
544628	544626	05012A	PARTICIPANT	\N	PRESENT	0
544629	544626	20038A	PARTICIPANT	\N	PRESENT	0
544630	544626	19387D	PARTICIPANT	\N	PRESENT	0
544631	544626	19551W	PARTICIPANT	\N	PRESENT	0
544632	544626	20136B	PARTICIPANT	\N	PRESENT	0
545153	545152	14147R	PARTICIPANT	\N	PRESENT	0
545444	545438	04070G	PARTICIPANT	\N	PRESENT	0
545445	545438	20094J	PARTICIPANT	\N	PRESENT	0
545446	545440	04070G	PARTICIPANT	\N	PRESENT	0
545447	545440	20094J	PARTICIPANT	\N	PRESENT	0
549635	549003	19413M	PARTICIPANT	\N	PRESENT	1
549636	549003	04045F	PARTICIPANT	\N	PRESENT	1
549637	549003	14329V	PARTICIPANT	\N	PRESENT	0
549638	549003	20030R	PARTICIPANT	\N	PRESENT	1
549639	549003	19467C	PARTICIPANT	\N	PRESENT	1
549640	549003	19695N	PARTICIPANT	\N	PRESENT	0
549641	549003	01025N	PARTICIPANT	\N	PRESENT	1
549642	549003	20174H	PARTICIPANT	\N	PRESENT	0
549643	549003	14251Q	PARTICIPANT	\N	PRESENT	0
549644	549003	14257W	PARTICIPANT	\N	PRESENT	0
549649	549003	19575F	PARTICIPANT	\N	PRESENT	0
549650	549003	20144B	PARTICIPANT	\N	PRESENT	0
549651	545501	20102Q	PARTICIPANT	\N	PRESENT	0
549652	545501	19637C	PARTICIPANT	\N	PRESENT	1
549653	545501	14169X	PARTICIPANT	\N	PRESENT	1
549654	549253	20098N	PARTICIPANT	\N	PRESENT	1
549655	549003	11077T	PARTICIPANT	\N	PRESENT	1
549659	549253	07033P	PARTICIPANT	\N	PRESENT	0
549660	545501	19551W	PARTICIPANT	\N	PRESENT	1
549661	549253	20152B	PARTICIPANT	\N	PRESENT	0
549662	545501	20068G	PARTICIPANT	\N	PRESENT	0
549663	549253	08017T	PARTICIPANT	\N	PRESENT	1
549664	549253	19735D	PARTICIPANT	\N	PRESENT	1
549667	547779	14053L	PARTICIPANT	\N	PRESENT	0
549668	547779	19585H	PARTICIPANT	\N	PRESENT	0
549669	547779	14001X	PARTICIPANT	\N	PRESENT	0
549670	547779	11072N	PARTICIPANT	\N	PRESENT	0
549671	549253	19593H	PARTICIPANT	\N	PRESENT	0
549672	547149	14327T	PARTICIPANT	\N	PRESENT	0
549673	547149	11048N	PARTICIPANT	\N	PRESENT	0
549674	547149	19647E	PARTICIPANT	\N	PRESENT	0
549675	547149	01048V	PARTICIPANT	\N	PRESENT	0
549676	547149	14189C	PARTICIPANT	\N	PRESENT	0
549677	547149	01057W	PARTICIPANT	\N	PRESENT	0
549678	547149	19689Q	PARTICIPANT	\N	PRESENT	0
549679	547149	11053K	PARTICIPANT	\N	PRESENT	0
549680	547149	19667J	PARTICIPANT	\N	PRESENT	0
549681	547149	20044X	PARTICIPANT	\N	PRESENT	0
549682	547149	14225N	PRESIDENT	0	PRESENT	0
549683	547149	04086Q	PARTICIPANT	\N	PRESENT	0
549684	547149	11040E	PARTICIPANT	\N	PRESENT	0
549685	547149	14083S	PARTICIPANT	\N	PRESENT	0
549686	547149	08009T	PARTICIPANT	\N	PRESENT	0
549687	547149	20070A	PARTICIPANT	\N	PRESENT	0
549688	547149	19349W	PARTICIPANT	\N	PRESENT	0
549689	547149	20116W	PARTICIPANT	\N	PRESENT	0
549690	547149	20022R	PARTICIPANT	\N	PRESENT	0
549691	547149	20126Y	PARTICIPANT	\N	PRESENT	0
549692	547149	07029T	PARTICIPANT	\N	EXCUSE	0
549817	549666	19443T	PARTICIPANT	\N	PRESENT	1
549818	549666	19565D	PARTICIPANT	\N	PRESENT	0
549819	549666	04034C	PARTICIPANT	\N	PRESENT	0
549820	549666	01058X	PARTICIPANT	\N	PRESENT	1
549821	549666	16685X	PARTICIPANT	\N	PRESENT	1
549822	549666	11027H	PARTICIPANT	\N	PRESENT	0
549823	549666	04042C	PRESIDENT	0	PRESENT	0
549824	549666	11066Q	PARTICIPANT	\N	PRESENT	0
549825	549666	08056B	PARTICIPANT	\N	PRESENT	0
549826	549666	19421M	PARTICIPANT	\N	PRESENT	0
549827	549666	19709B	PARTICIPANT	\N	PRESENT	0
549828	549666	14193X	PARTICIPANT	\N	PRESENT	1
549829	549666	19347U	PARTICIPANT	\N	PRESENT	1
549830	549666	97011G	PARTICIPANT	\N	PRESENT	0
549831	549666	14249W	PARTICIPANT	\N	PRESENT	0
549832	549666	08047A	PARTICIPANT	\N	PRESENT	0
549833	549666	20128B	PARTICIPANT	\N	PRESENT	0
549834	549666	14059S	PARTICIPANT	\N	PRESENT	1
549835	549666	14097Y	PARTICIPANT	\N	PRESENT	1
549836	549666	04035D	PARTICIPANT	\N	PRESENT	1
549837	549666	14133K	PARTICIPANT	\N	PRESENT	1
549838	549666	08069G	PARTICIPANT	\N	PRESENT	0
549839	549666	11041F	PARTICIPANT	\N	PRESENT	1
549840	549666	20042V	PARTICIPANT	\N	PRESENT	0
549841	549666	01024M	PARTICIPANT	\N	PRESENT	0
549842	549666	14105F	PARTICIPANT	\N	PRESENT	0
549843	549666	20064C	PARTICIPANT	\N	PRESENT	0
549844	549666	14267Y	PARTICIPANT	\N	PRESENT	0
549845	549666	11083R	PARTICIPANT	\N	PRESENT	1
549846	549666	14211G	PARTICIPANT	\N	PRESENT	0
549847	549666	19583F	PARTICIPANT	\N	PRESENT	0
549848	549666	14255U	PARTICIPANT	\N	PRESENT	0
549849	549666	17023S	PARTICIPANT	\N	PRESENT	1
549850	549666	11054L	PARTICIPANT	\N	PRESENT	1
549852	549694	19383Y	PRESIDENT	0	PRESENT	0
549853	549694	19551W	PARTICIPANT	\N	PRESENT	1
549854	549694	19467C	PARTICIPANT	\N	PRESENT	1
549855	549694	20038A	PARTICIPANT	\N	PRESENT	0
549856	549694	19798U	PARTICIPANT	\N	PRESENT	1
549857	549694	19441R	PARTICIPANT	\N	PRESENT	0
549858	549694	14026U	PARTICIPANT	\N	PRESENT	1
549859	549694	19719D	PARTICIPANT	\N	PRESENT	0
549860	549694	20026V	PARTICIPANT	\N	PRESENT	0
549861	549694	19637C	PARTICIPANT	\N	PRESENT	1
549862	549694	19762G	PARTICIPANT	\N	PRESENT	0
549863	549694	14030Q	PARTICIPANT	\N	PRESENT	0
549864	549694	14109K	PARTICIPANT	\N	EXCUSE	0
549865	549694	19758L	PARTICIPANT	\N	EXCUSE	0
549866	549694	20028X	PARTICIPANT	\N	EXCUSE	0
549869	548791	86034E	PARTICIPANT	\N	PRESENT	0
549870	548791	19673G	PARTICIPANT	\N	PRESENT	0
549871	548791	20056C	PARTICIPANT	\N	PRESENT	0
549872	548791	19507S	PARTICIPANT	\N	PRESENT	0
549873	548791	20108W	PARTICIPANT	\N	PRESENT	0
549874	548791	20046A	PARTICIPANT	\N	PRESENT	0
549875	548791	14231L	PARTICIPANT	\N	PRESENT	0
549876	548791	19533U	PARTICIPANT	\N	PRESENT	0
549877	548791	19709B	PARTICIPANT	\N	PRESENT	0
549878	548791	17229F	PARTICIPANT	\N	PRESENT	0
549879	548791	20098N	PARTICIPANT	\N	PRESENT	0
549880	548791	19866P	PARTICIPANT	\N	PRESENT	0
549881	548791	11103C	PARTICIPANT	\N	PRESENT	0
549882	548791	19695N	PARTICIPANT	\N	PRESENT	0
549883	548791	11033F	PARTICIPANT	\N	PRESENT	0
549884	548791	19583F	PARTICIPANT	\N	PRESENT	0
549885	548791	19565D	PARTICIPANT	\N	PRESENT	0
557071	557069	19383Y	PARTICIPANT	\N	PRESENT	0
557072	557069	19719D	PARTICIPANT	\N	PRESENT	0
557073	557069	14026U	PARTICIPANT	\N	PRESENT	1
557074	557069	11099A	PARTICIPANT	\N	PRESENT	1
557075	557069	14109K	PARTICIPANT	\N	PRESENT	0
557076	557070	19383Y	PARTICIPANT	\N	PRESENT	0
557077	557070	19719D	PARTICIPANT	\N	PRESENT	0
557103	557101	19826F	PARTICIPANT	\N	PRESENT	0
557104	557101	20136B	PARTICIPANT	\N	PRESENT	0
557105	557101	19701S	PARTICIPANT	\N	PRESENT	0
557208	556989	19826F	PARTICIPANT	\N	PRESENT	0
557210	556986	19701S	PARTICIPANT	\N	PRESENT	0
557221	557220	19251M	PARTICIPANT	\N	PRESENT	0
557222	557220	20076G	PARTICIPANT	\N	PRESENT	0
557223	557220	19681G	PARTICIPANT	\N	PRESENT	0
557224	557220	19503N	PARTICIPANT	\N	PRESENT	0
557225	557220	19387D	PARTICIPANT	\N	PRESENT	0
557226	557220	11065P	PARTICIPANT	\N	PRESENT	0
557237	537395	14189C	PARTICIPANT	\N	PRESENT	0
557238	537395	20024T	PARTICIPANT	\N	EXCUSE	0
557239	537395	14030Q	PRESIDENT	0	PRESENT	0
557240	537395	11031D	PARTICIPANT	\N	PRESENT	0
557241	537395	19693L	PARTICIPANT	\N	PRESENT	0
557242	537395	20106U	PARTICIPANT	\N	EXCUSE	0
557243	537395	14179A	PARTICIPANT	\N	PRESENT	0
557245	537395	14109K	PARTICIPANT	\N	PRESENT	0
557246	537395	20118Y	PARTICIPANT	\N	EXCUSE	0
557247	537395	20130U	PARTICIPANT	\N	EXCUSE	0
557248	537395	19798U	PARTICIPANT	\N	PRESENT	1
557249	537395	19749K	PARTICIPANT	\N	PRESENT	0
557250	537395	19715Y	PARTICIPANT	\N	PRESENT	1
557328	557326	19826F	PARTICIPANT	\N	PRESENT	0
557329	557326	14205J	PARTICIPANT	\N	PRESENT	0
557330	557326	20018V	PARTICIPANT	\N	PRESENT	0
557331	557326	11099A	PARTICIPANT	\N	PRESENT	0
557334	545944	01048V	PARTICIPANT	\N	PRESENT	0
557335	545944	11067R	PARTICIPANT	\N	PRESENT	0
557336	545944	19503N	PARTICIPANT	\N	PRESENT	0
557337	545944	19593H	PARTICIPANT	\N	PRESENT	0
557340	545944	20128B	PARTICIPANT	\N	PRESENT	0
557342	545944	19693L	PARTICIPANT	\N	PRESENT	0
557343	545944	19723Y	PARTICIPANT	\N	PRESENT	0
557346	545944	01058X	PARTICIPANT	\N	PRESENT	0
557348	545944	19533U	PARTICIPANT	\N	PRESENT	0
557368	557367	14255U	PARTICIPANT	\N	PRESENT	0
557369	557367	14041T	PARTICIPANT	\N	PRESENT	0
557370	557367	14357A	PARTICIPANT	\N	PRESENT	0
557371	557367	14215L	PARTICIPANT	\N	PRESENT	0
557372	557367	08018U	PARTICIPANT	\N	PRESENT	0
557374	557367	04043D	PARTICIPANT	\N	PRESENT	0
557376	557367	14147R	PARTICIPANT	\N	PRESENT	0
557377	557367	08017T	PARTICIPANT	\N	PRESENT	0
557386	557383	08034U	PARTICIPANT	\N	PRESENT	0
557380	557367	14211G	PARTICIPANT	\N	PRESENT	0
557381	557367	20174H	PARTICIPANT	\N	PRESENT	0
557384	557383	17737W	PARTICIPANT	\N	PRESENT	0
557385	557383	14255U	PARTICIPANT	\N	PRESENT	0
557387	557383	14041T	PARTICIPANT	\N	PRESENT	0
557388	557383	19647E	PARTICIPANT	\N	PRESENT	0
557389	557383	08018U	PARTICIPANT	\N	PRESENT	0
557390	557383	19709B	PARTICIPANT	\N	PRESENT	0
557391	557383	08017T	PARTICIPANT	\N	PRESENT	0
557392	557383	14147R	PARTICIPANT	\N	PRESENT	0
557393	557383	04043D	PARTICIPANT	\N	PRESENT	0
557394	545944	04043D	PARTICIPANT	\N	PRESENT	0
557402	557401	14133K	PARTICIPANT	\N	PRESENT	0
557403	557401	14255U	PARTICIPANT	\N	PRESENT	0
557404	557401	04042C	PARTICIPANT	\N	PRESENT	0
557405	557401	14267Y	PARTICIPANT	\N	PRESENT	0
557406	557401	04035D	PARTICIPANT	\N	PRESENT	0
557407	557401	11083R	PARTICIPANT	\N	PRESENT	0
557408	557401	19347U	PARTICIPANT	\N	PRESENT	0
557409	557401	11064N	PARTICIPANT	\N	PRESENT	0
557410	557401	12041X	PARTICIPANT	\N	PRESENT	0
557411	557401	08047A	PARTICIPANT	\N	PRESENT	0
557412	557401	14193X	PARTICIPANT	\N	PRESENT	0
557413	557401	19421M	PARTICIPANT	\N	PRESENT	0
557414	557401	01062T	PARTICIPANT	\N	PRESENT	0
557415	557401	20064C	PARTICIPANT	\N	PRESENT	0
557416	557401	11041F	PARTICIPANT	\N	PRESENT	0
557422	557421	20042V	PARTICIPANT	\N	PRESENT	0
557423	557421	11080N	PARTICIPANT	\N	PRESENT	0
557424	557421	19347U	PARTICIPANT	\N	PRESENT	0
557425	557421	01057W	PARTICIPANT	\N	PRESENT	0
557426	557421	14121F	PARTICIPANT	\N	PRESENT	0
557427	557421	19711U	PARTICIPANT	\N	PRESENT	0
557428	557421	19335Q	PARTICIPANT	\N	PRESENT	0
557430	555351	14071N	PARTICIPANT	\N	EXCUSE	0
557431	555351	05012A	PARTICIPANT	\N	EXCUSE	0
557432	555351	20110Q	PARTICIPANT	\N	PRESENT	0
557433	555351	01057W	PARTICIPANT	\N	PRESENT	0
557434	555351	20084G	PARTICIPANT	\N	PRESENT	0
557435	555351	20090E	PARTICIPANT	\N	PRESENT	0
557436	555351	19333N	PARTICIPANT	\N	PRESENT	0
557437	555351	14215L	PARTICIPANT	\N	PRESENT	0
557438	555351	14187A	PARTICIPANT	\N	PRESENT	0
557439	555351	08010L	PARTICIPANT	\N	PRESENT	1
557440	555351	20022R	PARTICIPANT	\N	PRESENT	1
557441	555351	20058E	PARTICIPANT	\N	PRESENT	1
557442	555351	04086Q	PARTICIPANT	\N	PRESENT	1
557443	555351	04045F	PARTICIPANT	\N	PRESENT	1
557444	555351	19565D	PARTICIPANT	\N	PRESENT	1
557445	555351	19735D	PARTICIPANT	\N	EXCUSE	1
557446	555351	14229S	PARTICIPANT	\N	PRESENT	1
557469	557462	14205J	PARTICIPANT	\N	PRESENT	0
557470	555344	19643A	PARTICIPANT	\N	PRESENT	1
557471	555344	19721W	PARTICIPANT	\N	PRESENT	1
557472	555344	19693L	PARTICIPANT	\N	PRESENT	0
557473	555344	20132W	PARTICIPANT	\N	PRESENT	0
557474	555344	20180F	PARTICIPANT	\N	PRESENT	1
557475	555344	19715Y	PARTICIPANT	\N	PRESENT	1
557476	555344	19611R	PARTICIPANT	\N	PRESENT	0
557477	555344	19735D	PARTICIPANT	\N	PRESENT	1
557478	555344	20096L	PARTICIPANT	\N	PRESENT	1
557479	555344	19593H	PRESIDENT	0	PRESENT	0
557480	555344	20050V	PARTICIPANT	\N	PRESENT	1
557481	555344	19533U	PARTICIPANT	\N	PRESENT	0
557482	555344	20082E	PARTICIPANT	\N	PRESENT	0
557506	554778	14189C	PARTICIPANT	\N	EXCUSE	0
557507	554778	20104S	PARTICIPANT	\N	PRESENT	0
557508	554778	14357A	PARTICIPANT	\N	PRESENT	0
557509	554778	11083R	PARTICIPANT	\N	PRESENT	0
557510	554778	14033T	PARTICIPANT	\N	PRESENT	1
557511	554778	14026U	PARTICIPANT	\N	PRESENT	0
557512	554778	19725B	PARTICIPANT	\N	PRESENT	0
557513	554778	20128B	PARTICIPANT	\N	PRESENT	1
557515	554778	14073Q	PARTICIPANT	\N	PRESENT	0
557516	554778	08034U	PARTICIPANT	\N	PRESENT	0
557517	554778	19441R	PARTICIPANT	\N	PRESENT	0
557518	554778	14331P	PARTICIPANT	\N	PRESENT	0
557519	554778	04034C	PARTICIPANT	\N	PRESENT	1
557520	554778	14237S	PARTICIPANT	\N	PRESENT	0
557521	554778	14097Y	PARTICIPANT	\N	PRESENT	1
557554	557553	08045X	PARTICIPANT	\N	PRESENT	0
557558	557556	11048N	PARTICIPANT	\N	PRESENT	0
557560	557556	08011M	PARTICIPANT	\N	PRESENT	0
557591	557590	08009T	PARTICIPANT	\N	PRESENT	0
557592	557590	20044X	PARTICIPANT	\N	PRESENT	0
557643	557640	11053K	PARTICIPANT	\N	PRESENT	0
557663	557662	19711U	PARTICIPANT	\N	PRESENT	0
557664	555499	14179A	PARTICIPANT	\N	PRESENT	0
557665	555499	20024T	PARTICIPANT	\N	PRESENT	0
557666	555499	20116W	PARTICIPANT	\N	PRESENT	0
557667	555499	20042V	PARTICIPANT	\N	PRESENT	0
557668	555499	20090E	PARTICIPANT	\N	PRESENT	0
557669	555499	14083S	PARTICIPANT	\N	PRESENT	0
557670	555499	11053K	PARTICIPANT	\N	PRESENT	0
557671	555499	19681G	PARTICIPANT	\N	PRESENT	0
557672	555499	17229F	PARTICIPANT	\N	PRESENT	0
557673	555499	08045X	PARTICIPANT	\N	PRESENT	0
557674	555499	19333N	PARTICIPANT	\N	PRESENT	0
557675	555499	20056C	PARTICIPANT	\N	PRESENT	0
557676	555499	20052X	PARTICIPANT	\N	PRESENT	0
557678	555499	14221J	PARTICIPANT	\N	PRESENT	0
557679	555499	19671E	PARTICIPANT	\N	PRESENT	0
557680	555499	19745F	PARTICIPANT	\N	PRESENT	0
543987	541673	11053K	PARTICIPANT	\N	PRESENT	1
543988	541673	99004R	PARTICIPANT	\N	PRESENT	1
543989	541673	19711U	PARTICIPANT	\N	PRESENT	1
543990	541673	08010L	PARTICIPANT	\N	PRESENT	1
543991	541673	12016W	PARTICIPANT	\N	PRESENT	1
543992	541673	14253S	PARTICIPANT	\N	PRESENT	1
543993	541673	20050V	PARTICIPANT	\N	PRESENT	1
543994	541673	20036X	PARTICIPANT	\N	PRESENT	1
545268	542796	05008E	PARTICIPANT	\N	EXCUSE	0
545270	542796	11010L	PARTICIPANT	\N	EXCUSE	0
552250	550473	11031D	PARTICIPANT	\N	PRESENT	1
552251	550473	20172F	PARTICIPANT	\N	PRESENT	1
552252	550473	14042U	PARTICIPANT	\N	PRESENT	1
552253	550473	19798U	PARTICIPANT	\N	PRESENT	1
552254	550473	19691J	PARTICIPANT	\N	PRESENT	1
552255	550473	14355X	PARTICIPANT	\N	PRESENT	1
552256	550473	04057K	PARTICIPANT	\N	PRESENT	0
552248	550473	14223L	PARTICIPANT	\N	PRESENT	1
552249	550473	20130U	PARTICIPANT	\N	PRESENT	1
552257	550473	14195A	PARTICIPANT	\N	PRESENT	0
552258	550473	19415P	PARTICIPANT	\N	PRESENT	0
552288	550473	19591F	PARTICIPANT	\N	PRESENT	1
552289	550473	11103C	PARTICIPANT	\N	PRESENT	1
553990	553989	05008E	PARTICIPANT	\N	PRESENT	0
553991	553989	11033F	PARTICIPANT	\N	PRESENT	0
553992	553989	11053K	PARTICIPANT	\N	PRESENT	0
553993	553989	14357A	PARTICIPANT	\N	PRESENT	0
553994	553989	11070L	PARTICIPANT	\N	PRESENT	0
553995	553989	19719D	PARTICIPANT	\N	PRESENT	0
553996	553989	19673G	PARTICIPANT	\N	PRESENT	0
553997	553989	01025N	PARTICIPANT	\N	PRESENT	0
553998	553989	19599P	PARTICIPANT	\N	PRESENT	0
553999	553989	14033T	PARTICIPANT	\N	PRESENT	0
554000	553989	14123H	PARTICIPANT	\N	PRESENT	0
554001	553989	14026U	PARTICIPANT	\N	PRESENT	0
554002	553989	11064N	PARTICIPANT	\N	PRESENT	0
554003	553989	14179A	PARTICIPANT	\N	PRESENT	0
554004	553989	14213J	PARTICIPANT	\N	PRESENT	0
554005	553989	19715Y	PARTICIPANT	\N	PRESENT	0
554006	553989	99004R	PARTICIPANT	\N	PRESENT	0
554007	553989	86034E	PARTICIPANT	\N	PRESENT	0
554008	553989	12041X	PARTICIPANT	\N	PRESENT	0
554009	553989	01043Q	PARTICIPANT	\N	PRESENT	0
554010	553989	14147R	PARTICIPANT	\N	PRESENT	0
554011	553989	08073C	PARTICIPANT	\N	PRESENT	0
554012	553989	11045K	PARTICIPANT	\N	PRESENT	0
554013	553989	01028R	PARTICIPANT	\N	PRESENT	0
554014	553989	19413M	PARTICIPANT	\N	PRESENT	0
554084	548970	14257W	PARTICIPANT	\N	PRESENT	1
554085	548970	05012A	PARTICIPANT	\N	PRESENT	1
554086	548970	19565D	PARTICIPANT	\N	PRESENT	1
554087	548970	20058E	PARTICIPANT	\N	PRESENT	1
554088	548970	14069U	PARTICIPANT	\N	PRESENT	1
554089	548970	04045F	PARTICIPANT	\N	PRESENT	1
554090	548970	14215L	PARTICIPANT	\N	PRESENT	0
554091	548970	17637T	PARTICIPANT	\N	PRESENT	0
554092	548970	20090E	PARTICIPANT	\N	PRESENT	0
554093	548970	14071N	PARTICIPANT	\N	PRESENT	0
554094	548970	19349W	PARTICIPANT	\N	PRESENT	0
554095	548970	19333N	PARTICIPANT	\N	PRESENT	0
554096	548970	20084G	PARTICIPANT	\N	PRESENT	0
555842	555032	14217N	PARTICIPANT	\N	PRESENT	0
555843	555032	14331P	PARTICIPANT	\N	PRESENT	0
555844	555032	14207L	PARTICIPANT	\N	PRESENT	0
555845	555032	14133K	PARTICIPANT	\N	PRESENT	0
555846	555032	04042C	PARTICIPANT	\N	PRESENT	0
555849	555032	20174H	PARTICIPANT	\N	PRESENT	0
555850	555032	19251M	PARTICIPANT	\N	PRESENT	0
555851	555032	19549D	PARTICIPANT	\N	PRESENT	0
555852	555032	20082E	PARTICIPANT	\N	PRESENT	0
555853	555032	14213J	PARTICIPANT	\N	PRESENT	0
555854	555032	20180F	PARTICIPANT	\N	PRESENT	0
555855	555032	11085T	PARTICIPANT	\N	PRESENT	0
555856	555032	14237S	PARTICIPANT	\N	PRESENT	0
555967	555033	20082E	PARTICIPANT	\N	PRESENT	0
555964	555033	12041X	PARTICIPANT	\N	PRESENT	0
555965	555033	19599P	PARTICIPANT	\N	PRESENT	0
555966	555033	14121F	PARTICIPANT	\N	PRESENT	0
555968	555033	20064C	PARTICIPANT	\N	PRESENT	0
555969	555033	14257W	PARTICIPANT	\N	PRESENT	0
555970	555033	18193Q	PARTICIPANT	\N	PRESENT	0
555971	555033	19549D	PARTICIPANT	\N	PRESENT	0
555972	555033	20018V	PARTICIPANT	\N	PRESENT	0
555973	555033	14021P	PARTICIPANT	\N	PRESENT	0
555974	555033	19631V	PARTICIPANT	\N	PRESENT	0
555975	555033	11012A	PARTICIPANT	\N	PRESENT	0
555976	555033	11077T	PARTICIPANT	\N	PRESENT	0
555977	555033	19681G	PARTICIPANT	\N	PRESENT	0
555978	555033	19563B	PARTICIPANT	\N	PRESENT	0
555979	555033	20174H	PARTICIPANT	\N	PRESENT	0
555980	555033	19347U	PARTICIPANT	\N	PRESENT	0
555981	555033	14207L	PARTICIPANT	\N	PRESENT	0
555982	555033	14189C	PARTICIPANT	\N	PRESENT	0
555983	555033	19367Y	PARTICIPANT	\N	PRESENT	0
555984	555033	19369B	PARTICIPANT	\N	PRESENT	0
555985	555033	20066E	PARTICIPANT	\N	PRESENT	0
555986	555033	14042U	PARTICIPANT	\N	PRESENT	0
555987	555033	01025N	PARTICIPANT	\N	PRESENT	0
555988	555033	19479G	PARTICIPANT	\N	PRESENT	0
555989	555033	14331P	PARTICIPANT	\N	PRESENT	0
555990	555033	14237S	PARTICIPANT	\N	PRESENT	0
555991	555033	19383Y	PARTICIPANT	\N	PRESENT	0
555992	555033	97011G	PARTICIPANT	\N	PRESENT	0
555993	555033	20090E	PARTICIPANT	\N	PRESENT	0
555994	555033	11090Q	PARTICIPANT	\N	PRESENT	0
555995	555033	14147R	PARTICIPANT	\N	PRESENT	0
555996	555033	20180F	PARTICIPANT	\N	PRESENT	0
555997	555033	14073Q	PARTICIPANT	\N	PRESENT	0
555998	555033	14223L	PARTICIPANT	\N	PRESENT	0
555999	555033	20046A	PARTICIPANT	\N	PRESENT	0
556000	555033	19760E	PARTICIPANT	\N	PRESENT	0
556001	555033	20094J	PARTICIPANT	\N	PRESENT	0
556002	555033	11097X	PARTICIPANT	\N	PRESENT	0
556003	555033	19515S	PARTICIPANT	\N	PRESENT	0
556005	555033	19758L	PARTICIPANT	\N	PRESENT	0
556006	555033	18083K	PARTICIPANT	\N	PRESENT	0
556007	555033	19747H	PARTICIPANT	\N	PRESENT	0
556018	555033	14205J	PARTICIPANT	\N	PRESENT	0
556019	555033	20102Q	PARTICIPANT	\N	PRESENT	0
556020	555033	20028X	PARTICIPANT	\N	PRESENT	0
556023	555033	14083S	PARTICIPANT	\N	PRESENT	0
556024	555033	20062A	PARTICIPANT	\N	PRESENT	0
556025	555033	20116W	PARTICIPANT	\N	PRESENT	0
556026	555033	14030Q	PARTICIPANT	\N	PRESENT	0
556027	555033	20144B	PARTICIPANT	\N	PRESENT	0
556028	555033	19533U	PARTICIPANT	\N	PRESENT	0
556029	555033	19643A	PARTICIPANT	\N	PRESENT	0
556034	555033	20070A	PARTICIPANT	\N	PRESENT	0
556035	555033	19413M	PARTICIPANT	\N	PRESENT	0
556036	555033	19503N	PARTICIPANT	\N	PRESENT	0
556037	555033	19467C	PARTICIPANT	\N	PRESENT	0
556038	555033	20140W	PARTICIPANT	\N	PRESENT	0
556039	555033	14179A	PARTICIPANT	\N	PRESENT	0
562384	561978	14041T	PARTICIPANT	\N	PRESENT	1
562385	561978	17737W	PARTICIPANT	\N	PRESENT	1
562401	562400	19741B	PARTICIPANT	\N	PRESENT	0
562402	562400	97011G	PARTICIPANT	\N	PRESENT	0
562403	562400	08034U	PARTICIPANT	\N	PRESENT	0
562404	562400	11041F	PARTICIPANT	\N	PRESENT	0
562405	562400	14147R	PARTICIPANT	\N	PRESENT	0
562528	562526	11090Q	PARTICIPANT	\N	PRESENT	0
562529	562526	14331P	PARTICIPANT	\N	PRESENT	0
562530	562526	11083R	PARTICIPANT	\N	PRESENT	0
562532	562526	14123H	PARTICIPANT	\N	PRESENT	0
562533	562526	19711U	PARTICIPANT	\N	PRESENT	0
562534	562526	14225N	PARTICIPANT	\N	PRESENT	0
562535	562526	19369B	PARTICIPANT	\N	PRESENT	0
562536	562526	01024M	PARTICIPANT	\N	PRESENT	0
562537	562526	19565D	PARTICIPANT	\N	PRESENT	0
562538	562526	04035D	PARTICIPANT	\N	PRESENT	0
562539	562526	14205J	PARTICIPANT	\N	PRESENT	0
562540	562526	19747H	PARTICIPANT	\N	PRESENT	0
562541	562526	19709B	PARTICIPANT	\N	PRESENT	1
562542	562526	14097Y	PARTICIPANT	\N	PRESENT	1
562543	562526	19443T	PARTICIPANT	\N	PRESENT	1
563619	562204	01043Q	PARTICIPANT	\N	PRESENT	0
563620	562204	19467C	PARTICIPANT	\N	PRESENT	0
563621	562204	14257W	PARTICIPANT	\N	PRESENT	0
563622	562204	19549D	PARTICIPANT	\N	PRESENT	0
563623	562204	19631V	PARTICIPANT	\N	PRESENT	0
563624	562204	20082E	PARTICIPANT	\N	PRESENT	0
563625	562204	19333N	PARTICIPANT	\N	PRESENT	0
563626	562204	20092G	PARTICIPANT	\N	PRESENT	0
563627	562204	19599P	PARTICIPANT	\N	PRESENT	0
563628	562204	11090Q	PARTICIPANT	\N	PRESENT	0
563629	562204	19629C	PARTICIPANT	\N	PRESENT	0
563630	562204	14207L	PARTICIPANT	\N	PRESENT	0
563631	562204	19563B	PARTICIPANT	\N	PRESENT	0
563632	562204	01025N	PARTICIPANT	\N	PRESENT	0
563633	562204	01024M	PARTICIPANT	\N	PRESENT	0
564378	564202	14331P	PARTICIPANT	\N	EXCUSE	0
564522	559959	19711U	PARTICIPANT	\N	PRESENT	0
564523	559959	19553Y	PARTICIPANT	\N	PRESENT	0
564524	559959	20050V	PARTICIPANT	\N	EXCUSE	0
564526	564250	19575F	PARTICIPANT	\N	PRESENT	1
564527	564250	14205J	PARTICIPANT	\N	PRESENT	0
564528	564250	20034V	PARTICIPANT	\N	PRESENT	1
564529	564250	20174H	PARTICIPANT	\N	PRESENT	1
564530	564250	08028W	PARTICIPANT	\N	EXCUSE	0
564531	564250	19768N	PARTICIPANT	\N	PRESENT	1
564532	564251	19695N	PARTICIPANT	\N	PRESENT	1
565126	565125	14089Y	PARTICIPANT	\N	PRESENT	0
565127	565125	20104S	PARTICIPANT	\N	PRESENT	0
565128	565125	14169X	PARTICIPANT	\N	PRESENT	0
565150	565125	11026G	PARTICIPANT	\N	PRESENT	0
565152	565151	11083R	PARTICIPANT	\N	PRESENT	0
565153	565151	19725B	PARTICIPANT	\N	PRESENT	0
565154	565151	14042U	PARTICIPANT	\N	PRESENT	0
565155	565151	20106U	PARTICIPANT	\N	PRESENT	1
565156	565151	04057K	PARTICIPANT	\N	PRESENT	0
565157	565151	19503N	PARTICIPANT	\N	PRESENT	0
565158	565151	95063L	PARTICIPANT	\N	PRESENT	0
565159	565151	20098N	PARTICIPANT	\N	PRESENT	1
565163	565161	14030Q	PARTICIPANT	\N	PRESENT	0
565162	565161	20022R	PARTICIPANT	\N	PRESENT	1
565164	565161	14231L	PARTICIPANT	\N	PRESENT	0
565165	565161	11083R	PARTICIPANT	\N	PRESENT	0
565166	565161	19503N	PARTICIPANT	\N	PRESENT	0
565167	565161	20150Y	PARTICIPANT	\N	PRESENT	1
565168	565161	14059S	PARTICIPANT	\N	PRESENT	0
565169	565161	20098N	PARTICIPANT	\N	PRESENT	0
566673	566670	19575F	PARTICIPANT	\N	PRESENT	1
566674	566670	20152B	PARTICIPANT	\N	PRESENT	0
566675	566670	20040T	PARTICIPANT	\N	PRESENT	0
566676	566670	20132W	PARTICIPANT	\N	PRESENT	0
566677	566670	17023S	PARTICIPANT	\N	PRESENT	0
566678	566670	19399H	PARTICIPANT	\N	PRESENT	0
566681	566670	19699S	PARTICIPANT	\N	PRESENT	0
566682	566670	20052X	PARTICIPANT	\N	PRESENT	0
566683	566670	14221J	PARTICIPANT	\N	PRESENT	0
566684	566670	14147R	PARTICIPANT	\N	PRESENT	0
566685	566670	20096L	PARTICIPANT	\N	PRESENT	0
566686	566670	20058E	PARTICIPANT	\N	PRESENT	0
566687	566670	20026V	PARTICIPANT	\N	PRESENT	1
566688	566670	11043H	PARTICIPANT	\N	PRESENT	0
566689	566670	20098N	PARTICIPANT	\N	PRESENT	0
566690	566670	17965H	PARTICIPANT	\N	PRESENT	0
566691	566670	20024T	PARTICIPANT	\N	PRESENT	0
566692	566670	19533U	PARTICIPANT	\N	PRESENT	0
566693	566670	19349W	PARTICIPANT	\N	PRESENT	1
566694	566670	14213J	PARTICIPANT	\N	PRESENT	1
566698	566670	20056C	PARTICIPANT	\N	PRESENT	1
567187	567186	14193X	PARTICIPANT	\N	PRESENT	0
567188	567186	19421M	PARTICIPANT	\N	PRESENT	0
567190	567189	20116W	PARTICIPANT	\N	PRESENT	0
567191	567189	11103C	PARTICIPANT	\N	PRESENT	0
567192	567189	19467C	PARTICIPANT	\N	PRESENT	0
567193	567189	18083K	PARTICIPANT	\N	PRESENT	0
567194	567189	14357A	PARTICIPANT	\N	PRESENT	0
567195	567189	14187A	PARTICIPANT	\N	PRESENT	0
567196	567189	20038A	PARTICIPANT	\N	PRESENT	0
567197	567189	20018V	PARTICIPANT	\N	PRESENT	0
567198	567189	08061X	PARTICIPANT	\N	PRESENT	0
567199	567189	19739H	PARTICIPANT	\N	PRESENT	0
567200	567189	19713W	PARTICIPANT	\N	PRESENT	0
567564	566437	19719D	PARTICIPANT	\N	PRESENT	0
567565	566437	19507S	PARTICIPANT	\N	PRESENT	0
567566	566437	20062A	PARTICIPANT	\N	PRESENT	0
567574	566437	19503N	PARTICIPANT	\N	PRESENT	0
567568	566437	01028R	PARTICIPANT	\N	PRESENT	0
567569	566437	14109K	PARTICIPANT	\N	PRESENT	0
567570	566437	04059M	PARTICIPANT	\N	PRESENT	0
567571	566437	20132W	PARTICIPANT	\N	PRESENT	0
567572	566437	20142Y	PARTICIPANT	\N	PRESENT	0
567573	566437	19413M	PARTICIPANT	\N	PRESENT	0
567575	566437	19683J	PARTICIPANT	\N	PRESENT	0
567576	566437	14257W	PARTICIPANT	\N	PRESENT	0
567577	566437	97011G	PARTICIPANT	\N	PRESENT	0
567578	566437	19611R	PARTICIPANT	\N	PRESENT	0
567579	566437	14229S	PARTICIPANT	\N	PRESENT	0
567580	566437	20082E	PARTICIPANT	\N	PRESENT	0
567581	566437	19333N	PARTICIPANT	\N	PRESENT	0
567582	566437	20098N	PARTICIPANT	\N	PRESENT	0
567583	566437	14259Y	PARTICIPANT	\N	PRESENT	0
567584	566437	14031R	PARTICIPANT	\N	PRESENT	0
567585	566437	20180F	PARTICIPANT	\N	PRESENT	0
567586	566437	19467C	PARTICIPANT	\N	PRESENT	0
567587	566437	01024M	PARTICIPANT	\N	PRESENT	0
567588	566437	19693L	PARTICIPANT	\N	PRESENT	0
567589	566437	19643A	PARTICIPANT	\N	PRESENT	0
567590	566437	19631V	PARTICIPANT	\N	PRESENT	0
567591	566437	14217N	PARTICIPANT	\N	PRESENT	0
567592	566437	20112S	PARTICIPANT	\N	PRESENT	0
567593	566437	18193Q	PARTICIPANT	\N	PRESENT	0
567594	566437	19735D	PARTICIPANT	\N	PRESENT	0
567595	566437	14089Y	PARTICIPANT	\N	PRESENT	0
567597	566437	17023S	PARTICIPANT	\N	PRESENT	0
567598	566437	11064N	PARTICIPANT	\N	PRESENT	0
567599	566260	20048C	PRESIDENT	0	PRESENT	0
567600	566260	17779H	PARTICIPANT	\N	PRESENT	1
567601	566260	20090E	PARTICIPANT	\N	EXCUSE	0
567602	566437	20052X	PARTICIPANT	\N	PRESENT	0
567603	566260	20056C	PARTICIPANT	\N	PRESENT	1
567604	566437	20108W	PARTICIPANT	\N	PRESENT	0
567605	566260	11067R	PARTICIPANT	\N	PRESENT	0
567606	566437	19697Q	PARTICIPANT	\N	PRESENT	0
567607	566437	19760E	PARTICIPANT	\N	PRESENT	0
567608	566437	11012A	PARTICIPANT	\N	PRESENT	0
567609	566437	07029T	PARTICIPANT	\N	PRESENT	0
567610	566437	19647E	PARTICIPANT	\N	PRESENT	0
567612	566437	19629C	PARTICIPANT	\N	PRESENT	0
567615	566437	20100N	PARTICIPANT	\N	PRESENT	0
567616	566437	19669L	PARTICIPANT	\N	PRESENT	0
567617	566437	20068G	PARTICIPANT	\N	PRESENT	0
567618	566437	19479G	PARTICIPANT	\N	PRESENT	0
567619	566260	14179A	PARTICIPANT	\N	PRESENT	1
567620	566437	19681G	PARTICIPANT	\N	PRESENT	0
567621	566437	20152B	PARTICIPANT	\N	PRESENT	0
567622	566437	18083K	PARTICIPANT	\N	PRESENT	0
567623	566437	14071N	PARTICIPANT	\N	PRESENT	0
567624	566437	20130U	PARTICIPANT	\N	PRESENT	0
567625	566437	20092G	PARTICIPANT	\N	PRESENT	0
545190	545188	04047H	PARTICIPANT	\N	PRESENT	0
545191	545188	14053L	PARTICIPANT	\N	PRESENT	0
545192	545188	14299H	PARTICIPANT	\N	PRESENT	0
545195	545188	11066Q	PARTICIPANT	\N	PRESENT	0
545324	542975	19447X	PARTICIPANT	\N	PRESENT	1
545325	542975	14215L	PARTICIPANT	\N	PRESENT	1
545374	537069	19717B	PRESIDENT	0	PRESENT	0
545375	537069	19347U	PARTICIPANT	\N	PRESENT	0
545376	537069	19715Y	PARTICIPANT	\N	PRESENT	0
545377	537069	20034V	PARTICIPANT	\N	PRESENT	0
545378	537069	20150Y	PARTICIPANT	\N	PRESENT	0
545379	537069	12016W	PARTICIPANT	\N	EXCUSE	0
546083	546081	12028B	PARTICIPANT	\N	PRESENT	0
549886	548791	20112S	PARTICIPANT	\N	PRESENT	0
549887	548791	19593H	PARTICIPANT	\N	PRESENT	0
549888	548791	14001X	PARTICIPANT	\N	PRESENT	0
549889	548791	20148F	PARTICIPANT	\N	PRESENT	0
549890	548791	20062A	PARTICIPANT	\N	PRESENT	0
549891	548791	19525U	PARTICIPANT	\N	PRESENT	0
549892	548791	20102Q	PARTICIPANT	\N	PRESENT	0
549893	549694	19713W	PARTICIPANT	\N	PRESENT	0
549894	548791	19527W	PARTICIPANT	\N	PRESENT	0
549895	548791	99004R	PARTICIPANT	\N	PRESENT	0
549897	548791	20116W	PARTICIPANT	\N	PRESENT	0
549898	548791	20114U	PARTICIPANT	\N	PRESENT	0
549899	548791	14189C	PARTICIPANT	\N	PRESENT	0
549900	548791	14030Q	PARTICIPANT	\N	PRESENT	0
549901	548791	20152B	PARTICIPANT	\N	PRESENT	0
549902	548791	19749K	PARTICIPANT	\N	PRESENT	0
549903	548791	19723Y	PARTICIPANT	\N	PRESENT	0
549904	548791	19447X	PARTICIPANT	\N	PRESENT	0
549905	548791	20086J	PARTICIPANT	\N	PRESENT	0
549906	548791	10015M	PARTICIPANT	\N	PRESENT	0
549907	548791	19954N	PARTICIPANT	\N	PRESENT	0
549908	548791	14105F	PARTICIPANT	\N	PRESENT	0
549909	548791	20044X	PARTICIPANT	\N	PRESENT	0
549910	548791	20074E	PARTICIPANT	\N	PRESENT	0
549911	548791	04043D	PARTICIPANT	\N	PRESENT	0
549912	548791	20054A	PARTICIPANT	\N	PRESENT	0
549913	548791	20126Y	PARTICIPANT	\N	PRESENT	0
549914	548791	19643A	PARTICIPANT	\N	PRESENT	0
549915	548791	20138D	PARTICIPANT	\N	PRESENT	0
549916	548791	14267Y	PARTICIPANT	\N	PRESENT	0
549917	548791	12028B	PARTICIPANT	\N	PRESENT	0
549918	548791	17965H	PARTICIPANT	\N	PRESENT	0
549919	548791	14021P	PARTICIPANT	\N	PRESENT	0
549920	548791	14121F	PARTICIPANT	\N	PRESENT	0
549921	548791	14195A	PARTICIPANT	\N	PRESENT	0
549922	548791	20048C	PARTICIPANT	\N	PRESENT	0
549923	548791	14275Y	PARTICIPANT	\N	PRESENT	0
549924	548791	14083S	PARTICIPANT	\N	PRESENT	0
549925	548791	14107H	PARTICIPANT	\N	PRESENT	0
549926	548791	11012A	PARTICIPANT	\N	PRESENT	0
549927	548791	19301E	PARTICIPANT	\N	PRESENT	0
549928	548791	11083R	PARTICIPANT	\N	PRESENT	0
549929	548791	19745F	PARTICIPANT	\N	PRESENT	0
549930	548791	05008E	PARTICIPANT	\N	PRESENT	0
549931	548791	20022R	PARTICIPANT	\N	PRESENT	0
549932	548791	11080N	PARTICIPANT	\N	PRESENT	0
549933	548791	19467C	PARTICIPANT	\N	PRESENT	0
549935	548791	14071N	PARTICIPANT	\N	PRESENT	0
549936	548791	19515S	PARTICIPANT	\N	PRESENT	0
549937	548791	08015R	PARTICIPANT	\N	PRESENT	0
549938	548791	14357A	PARTICIPANT	\N	PRESENT	0
549939	548791	04086Q	PARTICIPANT	\N	PRESENT	0
549940	548791	20088L	PARTICIPANT	\N	PRESENT	0
549941	548791	04085P	PARTICIPANT	\N	PRESENT	0
549942	548791	11056N	PARTICIPANT	\N	PRESENT	0
549943	548791	14211G	PARTICIPANT	\N	PRESENT	0
549944	548791	11040E	PARTICIPANT	\N	PRESENT	0
549945	548791	12041X	PARTICIPANT	\N	PRESENT	0
549946	548791	19693L	PARTICIPANT	\N	PRESENT	0
549947	548791	19703U	PARTICIPANT	\N	PRESENT	0
549948	548791	20076G	PARTICIPANT	\N	PRESENT	0
549949	548791	20092G	PARTICIPANT	\N	PRESENT	0
549950	548791	20100N	PARTICIPANT	\N	PRESENT	0
549951	548791	19689Q	PARTICIPANT	\N	PRESENT	0
549952	548791	08069G	PARTICIPANT	\N	PRESENT	0
549953	548791	20174H	PARTICIPANT	\N	PRESENT	0
549954	548791	19591F	PARTICIPANT	\N	PRESENT	0
549955	548791	01058X	PARTICIPANT	\N	PRESENT	0
549956	548791	20150Y	PARTICIPANT	\N	PRESENT	0
549958	548791	19651A	PARTICIPANT	\N	PRESENT	0
549959	548791	11072N	PARTICIPANT	\N	PRESENT	0
549960	548791	95063L	PARTICIPANT	\N	PRESENT	0
549961	548791	19329S	PARTICIPANT	\N	PRESENT	0
549962	548791	14249W	PARTICIPANT	\N	PRESENT	0
549963	548791	14038Y	PARTICIPANT	\N	PRESENT	0
549964	548791	14251Q	PARTICIPANT	\N	PRESENT	0
549966	548791	20050V	PARTICIPANT	\N	PRESENT	0
549970	548791	19573D	PARTICIPANT	\N	PRESENT	0
549973	548791	19479G	PARTICIPANT	\N	PRESENT	0
549979	548791	19719D	PARTICIPANT	\N	PRESENT	0
549980	548791	20132W	PARTICIPANT	\N	PRESENT	0
549984	548791	20140W	PARTICIPANT	\N	PRESENT	0
549986	548791	14041T	PARTICIPANT	\N	PRESENT	0
549988	548791	14026U	PARTICIPANT	\N	PRESENT	0
549990	548791	11048N	PARTICIPANT	\N	PRESENT	0
549994	548791	19585H	PARTICIPANT	\N	PRESENT	0
549996	548791	19575F	PARTICIPANT	\N	PRESENT	0
549998	548791	20032T	PARTICIPANT	\N	PRESENT	0
549999	548791	20042V	PARTICIPANT	\N	PRESENT	0
550001	548791	14259Y	PARTICIPANT	\N	PRESENT	0
550002	548791	20052X	PARTICIPANT	\N	PRESENT	0
550003	548791	19441R	PARTICIPANT	\N	PRESENT	0
550004	548791	14033T	PARTICIPANT	\N	PRESENT	0
550005	548791	20144B	PARTICIPANT	\N	PRESENT	0
550006	548791	19739H	PARTICIPANT	\N	PRESENT	0
550007	548791	14179A	PARTICIPANT	\N	PRESENT	0
550008	548791	19611R	PARTICIPANT	\N	PRESENT	0
550009	548791	18083K	PARTICIPANT	\N	PRESENT	0
550010	548791	19826F	PARTICIPANT	\N	PRESENT	0
550011	548791	14069U	PARTICIPANT	\N	PRESENT	0
550012	548791	19685L	PARTICIPANT	\N	PRESENT	0
550013	548791	14219Q	PARTICIPANT	\N	PRESENT	0
550014	548791	14205J	PARTICIPANT	\N	PRESENT	0
550015	548791	20090E	PARTICIPANT	\N	PRESENT	0
550016	548791	19335Q	PARTICIPANT	\N	PRESENT	0
550018	548791	08010L	PARTICIPANT	\N	PRESENT	0
550019	548791	19349W	PARTICIPANT	\N	PRESENT	0
550022	548791	08034U	PARTICIPANT	\N	PRESENT	0
550023	548791	14031R	PARTICIPANT	\N	PRESENT	0
550025	548791	14123H	PARTICIPANT	\N	PRESENT	0
550027	548791	97011G	PARTICIPANT	\N	PRESENT	0
550031	548791	20124W	PARTICIPANT	\N	PRESENT	0
550033	548791	20120S	PARTICIPANT	\N	PRESENT	0
550034	548791	19621T	PARTICIPANT	\N	PRESENT	0
550035	548791	04059M	PARTICIPANT	\N	PRESENT	0
550036	548791	19701S	PARTICIPANT	\N	PRESENT	0
550037	548791	19549D	PARTICIPANT	\N	PRESENT	0
550038	548791	14331P	PARTICIPANT	\N	PRESENT	0
550039	548791	20080C	PARTICIPANT	\N	PRESENT	0
550040	548791	10006L	PARTICIPANT	\N	PRESENT	0
550041	548791	20064C	PARTICIPANT	\N	PRESENT	0
550042	548791	20084G	PARTICIPANT	\N	PRESENT	0
550043	548791	19820Y	PARTICIPANT	\N	PRESENT	0
550044	548791	20118Y	PARTICIPANT	\N	PRESENT	0
550045	548791	08012N	PARTICIPANT	\N	PRESENT	0
550046	548791	11067R	PARTICIPANT	\N	PRESENT	0
550047	548791	14109K	PARTICIPANT	\N	PRESENT	0
550048	548791	04047H	PARTICIPANT	\N	PRESENT	0
550049	548791	20096L	PARTICIPANT	\N	PRESENT	0
550050	548791	19683J	PARTICIPANT	\N	PRESENT	0
550051	548791	07033P	PARTICIPANT	\N	PRESENT	0
550052	548791	20070A	PARTICIPANT	\N	PRESENT	0
550053	548791	11074Q	PARTICIPANT	\N	PRESENT	0
550054	548791	19647E	PARTICIPANT	\N	PRESENT	0
550055	548791	20172F	PARTICIPANT	\N	PRESENT	0
550056	548791	19599P	PARTICIPANT	\N	PRESENT	0
550057	548791	11027H	PARTICIPANT	\N	PRESENT	0
550058	548791	11043H	PARTICIPANT	\N	PRESENT	0
550059	548791	14225N	PARTICIPANT	\N	PRESENT	0
550062	548791	01028R	PARTICIPANT	\N	PRESENT	0
550063	548791	19741B	PARTICIPANT	\N	PRESENT	0
550065	548791	19383Y	PARTICIPANT	\N	PRESENT	0
557681	555499	19739H	PARTICIPANT	\N	PRESENT	0
557682	555499	19735D	PARTICIPANT	\N	PRESENT	0
557683	555499	19349W	PARTICIPANT	\N	PRESENT	0
557685	555499	14225N	PARTICIPANT	\N	PRESENT	0
557686	555499	20150Y	PARTICIPANT	\N	PRESENT	0
557696	557695	19711U	PARTICIPANT	\N	PRESENT	0
557715	557712	19711U	PARTICIPANT	\N	PRESENT	0
557728	557727	19711U	PARTICIPANT	\N	PRESENT	0
557736	557735	14225N	PARTICIPANT	\N	PRESENT	0
557737	557735	11048N	PARTICIPANT	\N	PRESENT	0
557956	557955	19507S	PARTICIPANT	\N	PRESENT	0
557957	557955	14357A	PRESIDENT	0	PRESENT	0
557958	557955	20092G	PARTICIPANT	\N	PRESENT	0
557959	557955	19503N	PARTICIPANT	\N	PRESENT	0
557960	557955	19739H	PARTICIPANT	\N	PRESENT	0
557961	557955	20054A	PARTICIPANT	\N	PRESENT	0
557962	557955	19413M	PARTICIPANT	\N	PRESENT	0
557963	557955	20070A	PARTICIPANT	\N	PRESENT	0
557964	557955	20144B	PARTICIPANT	\N	PRESENT	0
557965	557955	19820Y	PARTICIPANT	\N	PRESENT	0
557966	557955	14237S	PARTICIPANT	\N	PRESENT	0
557967	557955	20126Y	PARTICIPANT	\N	PRESENT	0
557968	557955	19782L	PARTICIPANT	\N	PRESENT	0
558024	558019	14231L	PRESIDENT	0	PRESENT	0
558555	558552	01028R	PARTICIPANT	\N	PRESENT	0
558553	558552	05008E	PARTICIPANT	\N	PRESENT	0
558554	558552	11053K	PARTICIPANT	\N	PRESENT	0
558709	557305	14225N	PRESIDENT	0	PRESENT	0
558710	557305	14327T	PARTICIPANT	\N	PRESENT	0
558711	557305	14331P	PARTICIPANT	\N	PRESENT	0
558712	557305	11048N	PARTICIPANT	\N	PRESENT	0
558713	557305	19711U	PARTICIPANT	\N	PRESENT	0
558714	557305	01048V	PARTICIPANT	\N	PRESENT	0
558716	557305	01057W	PARTICIPANT	\N	PRESENT	0
558717	557305	19689Q	PARTICIPANT	\N	PRESENT	0
558718	557305	20080C	PARTICIPANT	\N	PRESENT	0
558719	557305	20044X	PARTICIPANT	\N	PRESENT	0
558720	557305	11040E	PARTICIPANT	\N	PRESENT	0
558721	557305	04086Q	PARTICIPANT	\N	PRESENT	0
558722	557305	08009T	PARTICIPANT	\N	PRESENT	0
558723	557305	19741B	PARTICIPANT	\N	PRESENT	0
558724	557305	99004R	PARTICIPANT	\N	PRESENT	0
558725	557305	20116W	PARTICIPANT	\N	PRESENT	0
558726	557305	19335Q	PARTICIPANT	\N	PRESENT	0
558727	557305	20130U	PARTICIPANT	\N	PRESENT	0
558728	557305	14083S	PARTICIPANT	\N	PRESENT	0
558729	557305	20070A	PARTICIPANT	\N	PRESENT	0
558730	557977	19527W	PARTICIPANT	\N	PRESENT	0
558731	557977	20132W	PARTICIPANT	\N	PRESENT	1
558732	557977	20134Y	PARTICIPANT	\N	PRESENT	0
558733	557977	19533U	PARTICIPANT	\N	PRESENT	0
558734	557977	14073Q	PARTICIPANT	\N	PRESENT	0
558735	557977	19651A	PARTICIPANT	\N	PRESENT	1
558736	557977	19611R	PRESIDENT	0	PRESENT	0
558737	557977	20048C	PARTICIPANT	\N	PRESENT	1
558738	557977	19693L	PARTICIPANT	\N	PRESENT	0
558739	557977	19399H	PARTICIPANT	\N	PRESENT	0
558740	557977	20052X	PARTICIPANT	\N	PRESENT	0
558741	557977	20058E	PARTICIPANT	\N	PRESENT	1
558742	557977	14030Q	PARTICIPANT	\N	PRESENT	0
558743	557977	20056C	PARTICIPANT	\N	PRESENT	0
558744	557977	20180F	PARTICIPANT	\N	PRESENT	0
558745	557977	92040Q	PARTICIPANT	\N	PRESENT	0
558746	557977	20112S	PARTICIPANT	\N	PRESENT	0
558747	557977	11043H	PARTICIPANT	\N	PRESENT	0
558748	557977	11104D	PARTICIPANT	\N	PRESENT	1
558749	557977	19758L	PARTICIPANT	\N	PRESENT	1
558750	557977	19621T	PARTICIPANT	\N	PRESENT	0
558751	557977	20084G	PARTICIPANT	\N	PRESENT	0
558752	557977	11109J	PARTICIPANT	\N	EXCUSE	0
558753	558007	14031R	PARTICIPANT	\N	PRESENT	0
558754	558007	20038A	PARTICIPANT	\N	PRESENT	0
558755	558007	20076G	PARTICIPANT	\N	PRESENT	0
558756	558007	20140W	PARTICIPANT	\N	PRESENT	1
558757	558007	14219Q	PRESIDENT	0	PRESENT	0
558758	558007	19251M	PARTICIPANT	\N	PRESENT	0
558759	558007	19826F	PARTICIPANT	\N	PRESENT	0
558760	558007	20046A	PARTICIPANT	\N	PRESENT	0
558761	558007	19599P	PARTICIPANT	\N	PRESENT	0
558762	558007	20102Q	PARTICIPANT	\N	PRESENT	0
558763	558007	17229F	PARTICIPANT	\N	PRESENT	0
558764	558007	20096L	PARTICIPANT	\N	PRESENT	0
558765	558007	18083K	PARTICIPANT	\N	PRESENT	0
558766	558007	19503N	PARTICIPANT	\N	PRESENT	0
558767	558007	19739H	PARTICIPANT	\N	PRESENT	0
558768	558007	19745F	PARTICIPANT	\N	PRESENT	0
558769	558007	17367Q	PARTICIPANT	\N	PRESENT	0
558770	558007	17637T	PARTICIPANT	\N	PRESENT	0
558774	557977	14109K	PARTICIPANT	\N	PRESENT	1
558793	557305	07029T	PARTICIPANT	\N	PRESENT	0
558794	557305	19762G	PARTICIPANT	\N	PRESENT	0
558795	558007	19549D	PARTICIPANT	\N	PRESENT	0
558796	558007	19387D	PARTICIPANT	\N	PRESENT	0
558797	558007	14237S	PARTICIPANT	\N	PRESENT	0
558798	558007	08060W	PARTICIPANT	\N	PRESENT	0
558799	558007	20118Y	PARTICIPANT	\N	PRESENT	0
558800	557731	19383Y	PARTICIPANT	\N	PRESENT	0
558801	557731	19768N	PARTICIPANT	\N	PRESENT	1
558802	557731	19515S	PARTICIPANT	\N	PRESENT	0
558803	557731	19782L	PARTICIPANT	\N	PRESENT	1
558804	557731	20092G	PARTICIPANT	\N	PRESENT	0
558805	557731	19441R	PARTICIPANT	\N	PRESENT	0
558806	557731	19413M	PARTICIPANT	\N	PRESENT	1
558807	557731	04045F	PARTICIPANT	\N	PRESENT	1
558808	557731	19631V	PARTICIPANT	\N	PRESENT	1
558809	557731	11099A	PARTICIPANT	\N	PRESENT	0
558810	557731	08015R	PARTICIPANT	\N	PRESENT	0
558811	557731	20018V	PARTICIPANT	\N	PRESENT	1
558812	557731	14038Y	PARTICIPANT	\N	PRESENT	1
558813	557731	19467C	PARTICIPANT	\N	PRESENT	0
558814	557731	20034V	PARTICIPANT	\N	PRESENT	0
558815	557731	14187A	PARTICIPANT	\N	PRESENT	0
558816	557731	19695N	PARTICIPANT	\N	PRESENT	0
558817	557731	11090Q	PRESIDENT	0	PRESENT	0
558818	557731	14033T	PARTICIPANT	\N	PRESENT	1
558819	557731	20054A	PARTICIPANT	\N	PRESENT	0
558820	557731	20174H	PARTICIPANT	\N	PRESENT	0
558821	557731	20062A	PARTICIPANT	\N	PRESENT	0
558822	557731	14251Q	PARTICIPANT	\N	PRESENT	1
558823	557731	14207L	PARTICIPANT	\N	PRESENT	0
558824	557731	14257W	PARTICIPANT	\N	PRESENT	1
558825	557731	19575F	PARTICIPANT	\N	PRESENT	1
558827	557977	17589D	PARTICIPANT	\N	PRESENT	1
558833	558007	19333N	PARTICIPANT	\N	PRESENT	0
558834	558007	20024T	PARTICIPANT	\N	PRESENT	0
558835	558007	20136B	PARTICIPANT	\N	PRESENT	0
558836	558007	19619A	PARTICIPANT	\N	PRESENT	0
558839	558007	05012A	PARTICIPANT	\N	PRESENT	0
558840	558007	11065P	PARTICIPANT	\N	PRESENT	0
558842	558007	20100N	PARTICIPANT	\N	PRESENT	0
558843	557731	20086J	PARTICIPANT	\N	PRESENT	0
558844	557731	20082E	PARTICIPANT	\N	PRESENT	0
558845	557731	19563B	PARTICIPANT	\N	PRESENT	0
558846	557731	14205J	PARTICIPANT	\N	PRESENT	0
558853	555048	19697Q	PARTICIPANT	\N	PRESENT	1
558854	555367	19697Q	PARTICIPANT	\N	PRESENT	1
558855	555367	11067R	PARTICIPANT	\N	PRESENT	1
558856	558007	20106U	PARTICIPANT	\N	PRESENT	1
558857	558007	20068G	PARTICIPANT	\N	PRESENT	1
558858	557731	20028X	PARTICIPANT	\N	PRESENT	0
558859	557731	14329V	PARTICIPANT	\N	PRESENT	0
558860	557731	20144B	PARTICIPANT	\N	PRESENT	0
558862	557884	14053L	PARTICIPANT	\N	PRESENT	0
558863	557884	11026G	PARTICIPANT	\N	PRESENT	0
558864	557884	04047H	PRESIDENT	0	PRESENT	0
558865	557884	19673G	PARTICIPANT	\N	PRESENT	0
558866	557884	01028R	PARTICIPANT	\N	PRESENT	0
558867	557884	19447X	PARTICIPANT	\N	PRESENT	0
558868	557884	14231L	PARTICIPANT	\N	PRESENT	0
558869	557884	17737W	PARTICIPANT	\N	PRESENT	0
558870	557884	14041T	PARTICIPANT	\N	PRESENT	0
558871	557884	14147R	PARTICIPANT	\N	PRESENT	0
558872	557884	14151M	PARTICIPANT	\N	PRESENT	0
558873	557884	14215L	PARTICIPANT	\N	PRESENT	0
558874	557884	19749K	PARTICIPANT	\N	PRESENT	0
558875	557884	11056N	PARTICIPANT	\N	PRESENT	0
558876	557884	95063L	PARTICIPANT	\N	PRESENT	0
558894	557884	04085P	PARTICIPANT	\N	PRESENT	1
558895	557884	19543W	PARTICIPANT	\N	PRESENT	1
558896	557884	19954N	PARTICIPANT	\N	PRESENT	1
543721	542364	11067R	PARTICIPANT	\N	PRESENT	0
543722	542364	19569H	PARTICIPANT	\N	PRESENT	0
543723	542364	19798U	PARTICIPANT	\N	PRESENT	0
543724	542364	11097X	PARTICIPANT	\N	PRESENT	0
543725	542364	19415P	PARTICIPANT	\N	PRESENT	0
543726	542364	14223L	PARTICIPANT	\N	PRESENT	1
543727	542364	17779H	PARTICIPANT	\N	PRESENT	1
543728	542364	19553Y	PARTICIPANT	\N	PRESENT	0
543729	542364	14042U	PARTICIPANT	\N	PRESENT	0
543730	542364	14195A	PARTICIPANT	\N	PRESENT	0
543731	542364	19367Y	PARTICIPANT	\N	PRESENT	0
543732	542364	14213J	PARTICIPANT	\N	PRESENT	0
543733	542364	14217N	PARTICIPANT	\N	PRESENT	0
543734	542364	19683J	PARTICIPANT	\N	PRESENT	0
543735	542364	10006L	PRESIDENT	0	PRESENT	0
543736	542364	20130U	PARTICIPANT	\N	PRESENT	1
543737	542364	04057K	PARTICIPANT	\N	PRESENT	1
543738	542364	04092N	PARTICIPANT	0	PRESENT	0
543739	542364	19663E	PARTICIPANT	\N	PRESENT	1
543740	542364	19301E	PARTICIPANT	\N	PRESENT	1
543741	542364	17965H	PARTICIPANT	\N	PRESENT	1
543742	542364	19715Y	PARTICIPANT	\N	PRESENT	0
543743	542364	19691J	PARTICIPANT	\N	PRESENT	0
543744	542364	19717B	PARTICIPANT	\N	PRESENT	1
543745	542364	19723Y	PARTICIPANT	\N	PRESENT	0
543746	542364	20066E	PARTICIPANT	\N	PRESENT	0
543747	542364	19657G	PARTICIPANT	\N	PRESENT	1
543762	542570	19699S	PARTICIPANT	\N	PRESENT	0
543763	542570	19533U	PARTICIPANT	\N	PRESENT	0
543764	542570	14229S	PARTICIPANT	\N	PRESENT	1
543765	542570	19573D	PARTICIPANT	\N	PRESENT	0
543766	542570	08017T	PARTICIPANT	\N	PRESENT	1
543767	542570	20112S	PARTICIPANT	\N	PRESENT	0
543768	542570	20026V	PARTICIPANT	\N	PRESENT	1
543769	542570	19593H	PARTICIPANT	\N	PRESENT	0
543770	542570	19643A	PARTICIPANT	\N	PRESENT	1
543771	542570	14073Q	PARTICIPANT	\N	PRESENT	0
543772	542570	19651A	PARTICIPANT	\N	PRESENT	0
543773	542570	19611R	PRESIDENT	0	PRESENT	0
543774	542570	20142Y	PARTICIPANT	\N	PRESENT	0
543775	542570	20048C	PARTICIPANT	\N	PRESENT	1
543776	542570	19399H	PARTICIPANT	\N	PRESENT	0
543777	542570	20152B	PARTICIPANT	\N	PRESENT	1
543778	542570	20052X	PARTICIPANT	\N	PRESENT	0
543779	542570	20058E	PARTICIPANT	\N	PRESENT	1
543780	542570	14030Q	PARTICIPANT	\N	PRESENT	0
543781	542570	20056C	PARTICIPANT	\N	PRESENT	0
543782	542570	19735D	PARTICIPANT	\N	PRESENT	1
543783	542570	14123H	PARTICIPANT	\N	PRESENT	0
543784	542570	11104D	PARTICIPANT	\N	PRESENT	1
543785	542570	19758L	PARTICIPANT	\N	PRESENT	0
543786	542570	19621T	PARTICIPANT	\N	PRESENT	0
543787	542570	20084G	PARTICIPANT	\N	PRESENT	1
543788	542570	08061X	PARTICIPANT	\N	PRESENT	0
543789	542570	19693L	PARTICIPANT	\N	PRESENT	1
543790	542570	20180F	PARTICIPANT	\N	PRESENT	1
543791	542570	14109K	PARTICIPANT	\N	PRESENT	1
543792	542589	20086J	PARTICIPANT	\N	PRESENT	0
543793	542589	19383Y	PARTICIPANT	\N	PRESENT	0
543794	542589	20088L	PARTICIPANT	\N	PRESENT	1
543795	542589	19768N	PARTICIPANT	\N	PRESENT	1
543796	542589	19515S	PARTICIPANT	\N	PRESENT	0
543797	542589	19782L	PARTICIPANT	\N	PRESENT	1
543798	542589	14357A	PARTICIPANT	\N	PRESENT	0
543799	542589	19413M	PARTICIPANT	\N	PRESENT	0
543800	542589	20082E	PARTICIPANT	\N	PRESENT	0
543801	542589	20094J	PARTICIPANT	\N	PRESENT	0
543802	542589	04045F	PARTICIPANT	\N	PRESENT	1
543803	542589	19631V	PARTICIPANT	\N	PRESENT	1
543804	542589	20104S	PARTICIPANT	\N	PRESENT	1
543805	542589	19705W	PARTICIPANT	\N	PRESENT	0
543806	542589	08015R	PARTICIPANT	\N	PRESENT	1
543807	542589	19575F	PARTICIPANT	\N	PRESENT	0
543808	542589	20018V	PARTICIPANT	\N	PRESENT	1
543809	542589	19511N	PARTICIPANT	\N	PRESENT	0
543810	542589	08028W	PARTICIPANT	\N	PRESENT	0
543811	542589	20028X	PARTICIPANT	\N	PRESENT	0
543812	542589	14038Y	PARTICIPANT	\N	PRESENT	0
543813	542589	19467C	PARTICIPANT	\N	PRESENT	0
543814	542589	20034V	PARTICIPANT	\N	PRESENT	0
543815	542589	14187A	PARTICIPANT	\N	PRESENT	0
543816	542589	20144B	PARTICIPANT	\N	PRESENT	0
543817	542589	19695N	PARTICIPANT	\N	PRESENT	0
543818	542589	14033T	PARTICIPANT	\N	PRESENT	0
543819	542589	11090Q	PRESIDENT	0	PRESENT	0
543820	542589	01025N	PARTICIPANT	\N	PRESENT	1
543821	542589	20054A	PARTICIPANT	\N	PRESENT	1
543822	542589	20174H	PARTICIPANT	\N	PRESENT	1
543823	542589	20062A	PARTICIPANT	\N	PRESENT	0
543824	542589	19507S	PARTICIPANT	\N	PRESENT	0
543825	542589	14207L	PARTICIPANT	\N	PRESENT	0
543826	542589	14257W	PARTICIPANT	\N	PRESENT	0
543827	542589	20030R	PARTICIPANT	\N	PRESENT	1
543828	542589	19369B	PARTICIPANT	\N	PRESENT	0
543829	541673	04086Q	PARTICIPANT	\N	PRESENT	0
543830	541673	11040E	PARTICIPANT	\N	PRESENT	0
543831	541673	14331P	PARTICIPANT	\N	PRESENT	0
543832	541673	14083S	PARTICIPANT	\N	PRESENT	0
543833	541673	11048N	PARTICIPANT	\N	PRESENT	0
543834	541673	19687N	PARTICIPANT	\N	PRESENT	0
543835	541673	14225N	PRESIDENT	0	PRESENT	0
543836	541673	11070L	PARTICIPANT	\N	PRESENT	0
543837	541673	07029T	PARTICIPANT	\N	EXCUSE	0
543839	542589	19441R	PARTICIPANT	\N	PRESENT	1
543840	542589	19747H	PARTICIPANT	\N	PRESENT	1
543842	541673	01048V	PARTICIPANT	\N	PRESENT	0
543843	541673	19531S	PARTICIPANT	\N	PRESENT	0
543844	541673	20070A	PARTICIPANT	\N	PRESENT	0
543845	541673	19349W	PARTICIPANT	\N	PRESENT	0
543848	542570	04070G	PARTICIPANT	\N	PRESENT	1
543860	539764	19333N	PARTICIPANT	\N	PRESENT	0
543861	539764	19701S	PARTICIPANT	\N	PRESENT	1
543862	539764	19549D	PARTICIPANT	\N	PRESENT	0
543863	539764	20076G	PARTICIPANT	\N	PRESENT	0
543864	539764	19387D	PARTICIPANT	\N	PRESENT	1
543865	539764	14219Q	PRESIDENT	0	PRESENT	0
543866	539764	19820Y	PARTICIPANT	\N	PRESENT	0
543867	539764	19826F	PARTICIPANT	\N	PRESENT	0
543868	539764	14221J	PARTICIPANT	\N	PRESENT	0
543869	539764	19599P	PARTICIPANT	\N	PRESENT	0
543870	539764	19637C	PARTICIPANT	\N	PRESENT	1
543871	539764	14237S	PARTICIPANT	\N	PRESENT	0
543872	539764	18083K	PARTICIPANT	\N	PRESENT	0
543873	539764	05012A	PARTICIPANT	\N	PRESENT	0
543874	539764	08060W	PARTICIPANT	\N	PRESENT	1
543875	539764	20106U	PARTICIPANT	\N	PRESENT	1
543876	539764	20020P	PARTICIPANT	\N	PRESENT	0
543877	539764	19685L	PARTICIPANT	\N	PRESENT	0
543878	539764	20024T	PARTICIPANT	\N	PRESENT	0
543879	539764	19525U	PARTICIPANT	\N	PRESENT	0
543880	539764	20032T	PARTICIPANT	\N	PRESENT	0
543881	539764	20136B	PARTICIPANT	\N	PRESENT	0
543882	539764	14031R	PARTICIPANT	\N	PRESENT	0
543883	539764	20038A	PARTICIPANT	\N	PRESENT	0
543884	539764	20140W	PARTICIPANT	\N	PRESENT	0
543885	539764	19251M	PARTICIPANT	\N	PRESENT	0
543886	539764	20046A	PARTICIPANT	\N	PRESENT	0
543887	539764	14169X	PARTICIPANT	\N	PRESENT	0
543888	539764	17229F	PARTICIPANT	\N	PRESENT	0
543889	539764	20068G	PARTICIPANT	\N	PRESENT	0
543890	539764	19739H	PARTICIPANT	\N	PRESENT	0
543891	539764	19745F	PARTICIPANT	\N	PRESENT	1
543892	539764	19577H	PARTICIPANT	\N	PRESENT	1
543893	539764	19619A	PARTICIPANT	\N	PRESENT	0
543911	542589	20092G	PARTICIPANT	\N	PRESENT	0
543912	542589	19563B	PARTICIPANT	\N	PRESENT	0
543913	542589	14205J	PARTICIPANT	\N	PRESENT	0
543914	542589	14251Q	PARTICIPANT	\N	PRESENT	1
543925	542570	20098N	PARTICIPANT	\N	PRESENT	1
543926	542570	19527W	PARTICIPANT	\N	PRESENT	1
543927	542570	17589D	PARTICIPANT	\N	PRESENT	1
543928	541673	08034U	PARTICIPANT	\N	PRESENT	0
543929	541673	19667J	PARTICIPANT	\N	PRESENT	0
543930	541673	20044X	PARTICIPANT	\N	PRESENT	0
543931	541673	14121F	PARTICIPANT	\N	PRESENT	0
543932	541673	20116W	PARTICIPANT	\N	PRESENT	0
543933	541673	20022R	PARTICIPANT	\N	PRESENT	0
544004	542823	20114U	PARTICIPANT	\N	PRESENT	0
544005	542362	19697Q	PARTICIPANT	\N	PRESENT	0
544006	542362	11067R	PARTICIPANT	\N	PRESENT	0
544007	542362	20090E	PARTICIPANT	\N	PRESENT	0
562933	562770	20106U	PARTICIPANT	\N	PRESENT	1
562934	561763	19687N	PARTICIPANT	\N	PRESENT	0
562937	562554	04059M	PARTICIPANT	\N	PRESENT	0
562938	562554	20084G	PARTICIPANT	\N	PRESENT	0
562947	562770	17367Q	PARTICIPANT	\N	PRESENT	1
562948	561763	08034U	PARTICIPANT	\N	PRESENT	0
562950	561979	14231L	PARTICIPANT	\N	PRESENT	0
562952	561763	07029T	PARTICIPANT	\N	PRESENT	0
562953	562229	19565D	PARTICIPANT	\N	PRESENT	0
562954	562229	20072C	PARTICIPANT	\N	PRESENT	1
562955	562229	04034C	PARTICIPANT	\N	PRESENT	0
562956	562229	01058X	PARTICIPANT	\N	PRESENT	1
562957	562229	16685X	PARTICIPANT	\N	PRESENT	1
562958	562229	04042C	PRESIDENT	0	PRESENT	0
562959	562229	11066Q	PARTICIPANT	\N	PRESENT	0
562960	562229	19421M	PARTICIPANT	\N	PRESENT	1
562961	562229	19709B	PARTICIPANT	\N	PRESENT	1
562962	562229	19347U	PARTICIPANT	\N	PRESENT	0
562963	562229	97011G	PARTICIPANT	\N	PRESENT	0
562964	562229	08061X	PARTICIPANT	\N	PRESENT	0
562965	562229	14249W	PARTICIPANT	\N	PRESENT	1
562966	562229	08047A	PARTICIPANT	\N	PRESENT	0
562967	562229	14059S	PARTICIPANT	\N	PRESENT	0
562968	562229	14097Y	PARTICIPANT	\N	PRESENT	0
562969	562229	04035D	PARTICIPANT	\N	PRESENT	0
562970	562229	14133K	PARTICIPANT	\N	PRESENT	0
562971	562229	01062T	PARTICIPANT	\N	PRESENT	1
562972	562229	08069G	PARTICIPANT	\N	PRESENT	0
562973	562229	11041F	PARTICIPANT	\N	PRESENT	1
562974	562229	01024M	PARTICIPANT	\N	PRESENT	0
562975	562229	19721W	PARTICIPANT	\N	PRESENT	1
562976	562229	14105F	PARTICIPANT	\N	PRESENT	1
562977	562229	98022P	PARTICIPANT	\N	PRESENT	0
562978	562229	14267Y	PARTICIPANT	\N	PRESENT	0
562979	562229	11083R	PARTICIPANT	\N	PRESENT	0
562980	562229	14211G	PARTICIPANT	\N	PRESENT	0
562981	562229	14255U	PARTICIPANT	\N	PRESENT	0
562982	562229	17023S	PARTICIPANT	\N	PRESENT	0
563041	562202	14275Y	PARTICIPANT	\N	PRESENT	0
563042	562202	19719D	PARTICIPANT	\N	PRESENT	0
563043	562202	98022P	PARTICIPANT	\N	PRESENT	0
563044	562202	08045X	PARTICIPANT	\N	PRESENT	0
563045	562202	19629C	PARTICIPANT	\N	PRESENT	0
563046	562202	14221J	PARTICIPANT	\N	PRESENT	0
563047	562202	14267Y	PARTICIPANT	\N	PRESENT	0
563048	562202	20090E	PARTICIPANT	\N	PRESENT	0
563049	562202	20138D	PARTICIPANT	\N	PRESENT	0
563050	562202	20108W	PARTICIPANT	\N	PRESENT	0
563051	562202	19954N	PARTICIPANT	\N	PRESENT	0
563052	562202	11040E	PARTICIPANT	\N	PRESENT	0
563053	562202	19760E	PARTICIPANT	\N	PRESENT	0
563054	562202	19593H	PARTICIPANT	\N	PRESENT	0
563055	562202	19527W	PARTICIPANT	\N	PRESENT	0
563056	562202	11085T	PARTICIPANT	\N	PRESENT	0
563057	562202	04070G	PARTICIPANT	\N	PRESENT	0
563058	562202	19725B	PARTICIPANT	\N	PRESENT	0
563059	562202	20056C	PARTICIPANT	\N	PRESENT	0
563060	562202	19703U	PARTICIPANT	\N	PRESENT	0
563061	562202	19333N	PARTICIPANT	\N	PRESENT	0
563062	562202	19647E	PARTICIPANT	\N	PRESENT	0
563063	562202	04059M	PARTICIPANT	\N	PRESENT	0
563064	562202	14207L	PARTICIPANT	\N	PRESENT	0
563065	562202	19745F	PARTICIPANT	\N	PRESENT	0
563066	562202	19766L	PARTICIPANT	\N	PRESENT	0
563067	562202	19581D	PARTICIPANT	\N	PRESENT	0
563068	562202	14229S	PARTICIPANT	\N	PRESENT	0
563069	562202	19683J	PARTICIPANT	\N	PRESENT	0
563070	562202	20144B	PARTICIPANT	\N	PRESENT	0
563071	562202	14030Q	PARTICIPANT	\N	PRESENT	0
563072	562202	14327T	PARTICIPANT	\N	PRESENT	0
563073	562202	20116W	PARTICIPANT	\N	PRESENT	0
563074	562202	17229F	PARTICIPANT	\N	PRESENT	0
563075	562202	04057K	PARTICIPANT	\N	PRESENT	0
563076	562202	14121F	PARTICIPANT	\N	PRESENT	0
563077	562202	20142Y	PARTICIPANT	\N	PRESENT	0
563078	562202	20080C	PARTICIPANT	\N	PRESENT	0
563079	562202	19691J	PARTICIPANT	\N	PRESENT	0
563080	562202	20072C	PARTICIPANT	\N	PRESENT	0
563081	562202	11110B	PARTICIPANT	\N	PRESENT	0
563082	562202	19631V	PARTICIPANT	\N	PRESENT	0
563083	562202	19599P	PARTICIPANT	\N	PRESENT	0
563084	562202	20114U	PARTICIPANT	\N	PRESENT	0
563085	562202	17779H	PARTICIPANT	\N	PRESENT	0
563086	562202	19713W	PARTICIPANT	\N	PRESENT	0
563087	562202	20044X	PARTICIPANT	\N	PRESENT	0
563088	562202	14259Y	PARTICIPANT	\N	PRESENT	0
563089	562202	20140W	PARTICIPANT	\N	PRESENT	0
563090	562202	19729F	PARTICIPANT	\N	PRESENT	0
563091	562202	14231L	PARTICIPANT	\N	PRESENT	0
563092	562202	08009T	PARTICIPANT	\N	PRESENT	0
563093	562202	11045K	PARTICIPANT	\N	PRESENT	0
563094	562202	19563B	PARTICIPANT	\N	PRESENT	0
563095	562202	11067R	PARTICIPANT	\N	PRESENT	0
563096	562202	19649G	PARTICIPANT	\N	PRESENT	0
563097	562202	20060X	PARTICIPANT	\N	PRESENT	0
563098	562202	20092G	PARTICIPANT	\N	PRESENT	0
563099	562202	19549D	PARTICIPANT	\N	PRESENT	0
563100	562202	14225N	PARTICIPANT	\N	PRESENT	0
563101	562202	11041F	PARTICIPANT	\N	PRESENT	0
563102	562202	19699S	PARTICIPANT	\N	PRESENT	0
563103	562202	19479G	PARTICIPANT	\N	PRESENT	0
563104	562202	07004J	PARTICIPANT	\N	PRESENT	0
563105	562202	19503N	PARTICIPANT	\N	PRESENT	0
563106	562202	97011G	PARTICIPANT	\N	PRESENT	0
563107	562202	20020P	PARTICIPANT	\N	PRESENT	0
563108	562202	19447X	PARTICIPANT	\N	PRESENT	0
563109	562202	20026V	PARTICIPANT	\N	PRESENT	0
563110	562202	19667J	PARTICIPANT	\N	PRESENT	0
563111	562202	14073Q	PARTICIPANT	\N	PRESENT	0
563112	562202	19687N	PARTICIPANT	\N	PRESENT	0
563113	562202	04085P	PARTICIPANT	\N	PRESENT	0
563114	562202	19695N	PARTICIPANT	\N	PRESENT	0
563115	562202	20102Q	PARTICIPANT	\N	PRESENT	0
563116	562202	14211G	PARTICIPANT	\N	PRESENT	0
563117	562202	20046A	PARTICIPANT	\N	PRESENT	0
563118	562202	19693L	PARTICIPANT	\N	PRESENT	0
563120	562202	18083K	PARTICIPANT	\N	PRESENT	0
563121	562202	01028R	PARTICIPANT	\N	PRESENT	0
563122	562202	20096L	PARTICIPANT	\N	PRESENT	0
563123	562202	19515S	PARTICIPANT	\N	PRESENT	0
563124	562202	11090Q	PARTICIPANT	\N	PRESENT	0
563125	562202	14031R	PARTICIPANT	\N	PRESENT	0
563126	562202	19573D	PARTICIPANT	\N	PRESENT	0
563127	562202	04033B	PARTICIPANT	\N	PRESENT	0
563128	562202	18193Q	PARTICIPANT	\N	PRESENT	0
563129	562202	14187A	PARTICIPANT	\N	PRESENT	0
563130	562202	14257W	PARTICIPANT	\N	PRESENT	0
563131	562202	20022R	PARTICIPANT	\N	PRESENT	0
563132	562202	14021P	PARTICIPANT	\N	PRESENT	0
563133	562202	11066Q	PARTICIPANT	\N	PRESENT	0
563134	562202	04043D	PARTICIPANT	\N	PRESENT	0
563135	562202	14147R	PARTICIPANT	\N	PRESENT	0
563136	562202	20070A	PARTICIPANT	\N	PRESENT	0
563137	562202	08010L	PARTICIPANT	\N	PRESENT	0
563138	562202	11104D	PARTICIPANT	\N	PRESENT	0
563139	562202	04035D	PARTICIPANT	\N	PRESENT	0
563140	562202	20082E	PARTICIPANT	\N	PRESENT	0
563141	562202	17637T	PARTICIPANT	\N	PRESENT	0
563142	562202	19251M	PARTICIPANT	\N	PRESENT	0
563143	562202	14097Y	PARTICIPANT	\N	PRESENT	0
563144	562202	12041X	PARTICIPANT	\N	PRESENT	0
563145	562202	20064C	PARTICIPANT	\N	PRESENT	0
563146	562202	14038Y	PARTICIPANT	\N	PRESENT	0
563147	562202	19347U	PARTICIPANT	\N	PRESENT	0
563148	562202	20100N	PARTICIPANT	\N	PRESENT	0
563149	562202	11033F	PARTICIPANT	\N	PRESENT	0
563150	562202	19689Q	PARTICIPANT	\N	PRESENT	0
563151	562202	11099A	PARTICIPANT	\N	PRESENT	0
563152	562202	19467C	PARTICIPANT	\N	PRESENT	0
563153	562202	08061X	PARTICIPANT	\N	PRESENT	0
563154	562202	95063L	PARTICIPANT	\N	PRESENT	0
563155	562202	20128B	PARTICIPANT	\N	PRESENT	0
563156	562202	14133K	PARTICIPANT	\N	PRESENT	0
563157	562202	19651A	PARTICIPANT	\N	PRESENT	0
563158	562202	11083R	PARTICIPANT	\N	PRESENT	0
563159	562202	19591F	PARTICIPANT	\N	PRESENT	0
563160	562202	19301E	PARTICIPANT	\N	PRESENT	0
563161	562202	08034U	PARTICIPANT	\N	PRESENT	0
563162	562202	19349W	PARTICIPANT	\N	PRESENT	0
563163	562202	20174H	PARTICIPANT	\N	PRESENT	0
563164	562202	20098N	PARTICIPANT	\N	PRESENT	0
541656	537079	14133K	PARTICIPANT	\N	PRESENT	0
541657	537079	19701S	PARTICIPANT	\N	PRESENT	0
541658	537079	20100N	PARTICIPANT	\N	PRESENT	0
541659	537079	11083R	PARTICIPANT	\N	PRESENT	0
541660	537079	14097Y	PARTICIPANT	\N	PRESENT	0
541661	537079	14073Q	PARTICIPANT	\N	PRESENT	0
541662	537079	14331P	PRESIDENT	0	PRESENT	0
541663	537079	04057K	PARTICIPANT	\N	PRESENT	1
541664	537079	08034U	PARTICIPANT	\N	PRESENT	0
541665	537079	04070G	PARTICIPANT	\N	EXCUSE	0
541901	539652	01034P	PARTICIPANT	\N	PRESENT	1
541902	539652	20130U	PARTICIPANT	\N	PRESENT	1
541903	539652	19657G	PARTICIPANT	\N	PRESENT	1
541904	539652	11103C	PARTICIPANT	\N	PRESENT	1
541905	539652	19697Q	PARTICIPANT	\N	PRESENT	1
541906	539652	10006L	PARTICIPANT	\N	PRESENT	1
541907	539652	14042U	PARTICIPANT	\N	PRESENT	0
541908	539652	11097X	PRESIDENT	0	PRESENT	0
541909	539652	19683J	PARTICIPANT	\N	PRESENT	0
541910	539652	14213J	PARTICIPANT	\N	PRESENT	0
541911	539652	14071N	PARTICIPANT	\N	PRESENT	0
541912	539652	17779H	PARTICIPANT	\N	PRESENT	0
541913	539652	18193Q	PARTICIPANT	\N	PRESENT	0
541914	539652	14026U	PARTICIPANT	\N	PRESENT	0
541994	539689	20128B	PARTICIPANT	\N	PRESENT	1
541998	539689	19421M	PARTICIPANT	\N	PRESENT	1
542000	539689	98018T	PARTICIPANT	\N	PRESENT	1
542091	542090	20094J	PARTICIPANT	\N	PRESENT	0
542092	542090	14257W	PARTICIPANT	\N	PRESENT	0
542093	542090	14189C	PARTICIPANT	\N	PRESENT	0
542094	542090	20060X	PARTICIPANT	\N	PRESENT	0
542095	542090	14195A	PARTICIPANT	\N	PRESENT	0
542096	542090	19549D	PARTICIPANT	\N	PRESENT	0
542097	542090	20018V	PARTICIPANT	\N	PRESENT	0
542098	542090	14097Y	PARTICIPANT	\N	PRESENT	0
542099	542090	19689Q	PARTICIPANT	\N	PRESENT	0
542100	542090	19637C	PARTICIPANT	\N	PRESENT	0
542103	542102	20032T	PARTICIPANT	\N	PRESENT	0
542104	542102	19782L	PARTICIPANT	\N	PRESENT	0
542105	542102	20144B	PARTICIPANT	\N	PRESENT	0
542106	542102	19681G	PARTICIPANT	\N	PRESENT	0
542107	542102	20070A	PARTICIPANT	\N	PRESENT	0
542108	542102	14357A	PARTICIPANT	\N	PRESENT	0
542109	542102	14033T	PARTICIPANT	\N	PRESENT	1
542110	542102	20126Y	PARTICIPANT	\N	PRESENT	0
542111	542102	20050V	PARTICIPANT	\N	PRESENT	0
542112	542102	14237S	PARTICIPANT	\N	PRESENT	0
542113	542102	19503N	PARTICIPANT	\N	PRESENT	0
542114	542102	20054A	PARTICIPANT	\N	PRESENT	0
542115	542102	20092G	PARTICIPANT	\N	PRESENT	0
542116	542102	19413M	PARTICIPANT	\N	PRESENT	0
542117	542102	19619A	PARTICIPANT	\N	PRESENT	1
542121	542120	14069U	PARTICIPANT	\N	PRESENT	0
542122	542120	14083S	PARTICIPANT	\N	PRESENT	0
542123	542120	20144B	PARTICIPANT	\N	PRESENT	0
542124	542120	19681G	PARTICIPANT	\N	PRESENT	0
542125	542120	14357A	PARTICIPANT	\N	PRESENT	0
542126	542120	20038A	PARTICIPANT	\N	PRESENT	0
542127	542120	08018U	PARTICIPANT	\N	PRESENT	0
542128	542120	14033T	PARTICIPANT	\N	PRESENT	0
542129	542120	19551W	PARTICIPANT	\N	PRESENT	0
542130	542120	19711U	PARTICIPANT	\N	PRESENT	0
542131	542120	19503N	PARTICIPANT	\N	PRESENT	0
542132	542120	20092G	PARTICIPANT	\N	PRESENT	0
542133	542120	20062A	PARTICIPANT	\N	PRESENT	0
542134	542120	19413M	PARTICIPANT	\N	PRESENT	0
542135	542120	08028W	PARTICIPANT	\N	PRESENT	0
542138	541642	20032T	PARTICIPANT	\N	PRESENT	0
542142	541642	20090E	PARTICIPANT	\N	PRESENT	0
542140	541642	20088L	PARTICIPANT	\N	PRESENT	0
542141	541642	19383Y	PARTICIPANT	\N	PRESENT	0
542143	541642	20174H	PARTICIPANT	\N	PRESENT	0
542144	541642	20132W	PARTICIPANT	\N	PRESENT	0
542145	541642	20128B	PARTICIPANT	\N	PRESENT	0
542146	541642	20126Y	PARTICIPANT	\N	PRESENT	0
542147	541642	19723Y	PARTICIPANT	\N	PRESENT	0
542148	541642	08015R	PARTICIPANT	\N	PRESENT	0
542149	541642	20028X	PARTICIPANT	\N	PRESENT	0
542150	541642	14109K	PARTICIPANT	\N	PRESENT	0
542151	541642	14257W	PARTICIPANT	\N	PRESENT	0
542152	541642	05012A	PARTICIPANT	\N	PRESENT	0
542153	541642	19443T	PARTICIPANT	\N	PRESENT	0
542154	541642	19798U	PARTICIPANT	\N	PRESENT	0
542155	541642	11097X	PARTICIPANT	\N	PRESENT	1
542156	541642	04045F	PARTICIPANT	\N	PRESENT	1
542157	541642	19713W	PARTICIPANT	\N	PRESENT	1
542158	541642	20058E	PARTICIPANT	\N	PRESENT	1
542161	542160	14187A	PARTICIPANT	\N	PRESENT	0
542162	542160	01043Q	PARTICIPANT	\N	PRESENT	0
542239	542238	14205J	PARTICIPANT	\N	PRESENT	0
542240	542238	20082E	PARTICIPANT	\N	PRESENT	0
542241	542238	19768N	PARTICIPANT	\N	PRESENT	0
542243	542242	14205J	PARTICIPANT	\N	PRESENT	0
542244	542242	20086J	PARTICIPANT	\N	PRESENT	0
542245	542242	20082E	PARTICIPANT	\N	PRESENT	0
542426	538123	19683J	PRESIDENT	0	PRESENT	0
544109	544108	14173T	PARTICIPANT	\N	PRESENT	0
544118	542570	11109J	PARTICIPANT	\N	EXCUSE	0
544134	540094	14249W	PARTICIPANT	\N	PRESENT	0
544135	540094	14073Q	PARTICIPANT	\N	PRESENT	0
545623	545622	04086Q	PARTICIPANT	\N	PRESENT	0
545625	545624	04086Q	PARTICIPANT	\N	PRESENT	0
545626	545624	20050V	PARTICIPANT	\N	PRESENT	0
546806	544625	19667J	PARTICIPANT	\N	PRESENT	1
546807	544625	19545Y	PARTICIPANT	\N	PRESENT	1
546808	544625	11110B	PARTICIPANT	\N	PRESENT	1
546809	544625	14121F	PARTICIPANT	\N	PRESENT	1
546810	544625	99004R	PARTICIPANT	\N	PRESENT	1
546811	544625	20126Y	PARTICIPANT	\N	PRESENT	1
546812	544625	08010L	PARTICIPANT	\N	PRESENT	1
546813	544625	12016W	PARTICIPANT	\N	PRESENT	1
546814	544625	19335Q	PARTICIPANT	\N	PRESENT	1
546815	544625	20036X	PARTICIPANT	\N	PRESENT	1
546816	544625	11012A	PARTICIPANT	\N	PRESENT	1
546817	544625	19762G	PARTICIPANT	\N	PRESENT	1
546818	544625	19479G	PARTICIPANT	\N	PRESENT	1
546819	544625	14173T	PARTICIPANT	\N	PRESENT	1
548755	543175	14133K	PARTICIPANT	\N	PRESENT	0
548756	543175	14189C	PARTICIPANT	\N	PRESENT	0
548757	543175	14089Y	PARTICIPANT	\N	PRESENT	0
548758	543175	14207L	PARTICIPANT	\N	PRESENT	0
548759	543175	20104S	PARTICIPANT	\N	PRESENT	0
548760	543175	14357A	PARTICIPANT	\N	PRESENT	0
548761	543175	19701S	PARTICIPANT	\N	PRESENT	1
548762	543175	14169X	PARTICIPANT	\N	PRESENT	1
548763	543175	19251M	PARTICIPANT	\N	PRESENT	0
548764	543175	20100N	PARTICIPANT	\N	PRESENT	0
548765	543175	04035D	PARTICIPANT	\N	PRESENT	1
548766	543175	11083R	PARTICIPANT	\N	PRESENT	0
548767	543175	14026U	PARTICIPANT	\N	PRESENT	1
548768	543175	19553Y	PARTICIPANT	\N	PRESENT	1
548769	543175	19725B	PARTICIPANT	\N	PRESENT	0
548770	543175	20128B	PARTICIPANT	\N	PRESENT	0
548771	543175	19711U	PARTICIPANT	\N	PRESENT	1
548772	543175	11026G	PARTICIPANT	\N	PRESENT	1
548773	543175	19441R	PARTICIPANT	\N	PRESENT	0
548774	543175	04057K	PARTICIPANT	\N	PRESENT	0
548775	543175	04070G	PARTICIPANT	\N	PRESENT	0
548776	543175	14237S	PARTICIPANT	\N	PRESENT	0
548777	543175	14331P	PRESIDENT	0	PRESENT	0
550067	548791	14229S	PARTICIPANT	\N	PRESENT	0
550069	548791	20026V	PARTICIPANT	\N	PRESENT	0
550071	548791	08056B	PARTICIPANT	\N	PRESENT	0
550072	548791	08017T	PARTICIPANT	\N	PRESENT	0
550074	548791	17779H	PARTICIPANT	\N	PRESENT	0
550075	548791	20060X	PARTICIPANT	\N	PRESENT	0
550076	548791	04033B	PARTICIPANT	\N	PRESENT	0
550078	548791	18193Q	PARTICIPANT	\N	PRESENT	0
550079	548791	14215L	PARTICIPANT	\N	PRESENT	0
550080	548791	14187A	PARTICIPANT	\N	PRESENT	0
550081	548791	19725B	PARTICIPANT	\N	PRESENT	0
550082	548791	19747H	PARTICIPANT	\N	PRESENT	0
550083	548791	11097X	PARTICIPANT	\N	PRESENT	0
550084	548791	19503N	PARTICIPANT	\N	PRESENT	0
550086	548791	19333N	PARTICIPANT	\N	PRESENT	0
550087	548791	04042C	PARTICIPANT	\N	PRESENT	0
550089	548791	04008A	PARTICIPANT	\N	PRESENT	0
550090	548791	16685X	PARTICIPANT	\N	PRESENT	0
550091	548791	04035D	PARTICIPANT	\N	PRESENT	0
558897	557884	14069U	PARTICIPANT	\N	PRESENT	1
558898	557884	20114U	PARTICIPANT	\N	PRESENT	1
558899	557884	04008A	PARTICIPANT	\N	PRESENT	1
558900	557884	20074E	PARTICIPANT	\N	PRESENT	1
558901	557884	19725B	PARTICIPANT	\N	PRESENT	1
558902	557884	14179A	PARTICIPANT	\N	PRESENT	1
558903	557884	19581D	PARTICIPANT	\N	PRESENT	1
558904	557884	11072N	PARTICIPANT	\N	PRESENT	1
558905	557884	10015M	PARTICIPANT	\N	PRESENT	1
558906	557884	19675J	PARTICIPANT	\N	PRESENT	1
558907	557884	14259Y	PARTICIPANT	\N	PRESENT	1
558908	557731	01043Q	PARTICIPANT	\N	PRESENT	0
558909	557731	19507S	PARTICIPANT	\N	PRESENT	0
558910	557305	11053K	PARTICIPANT	\N	PRESENT	0
558911	558007	14169X	PARTICIPANT	\N	PRESENT	1
558913	558007	19551W	PARTICIPANT	\N	PRESENT	0
558916	557886	14041T	PARTICIPANT	\N	PRESENT	0
558917	557886	14147R	PARTICIPANT	\N	PRESENT	0
558918	557886	14231L	PARTICIPANT	\N	PRESENT	0
558919	557886	04047H	PRESIDENT	0	PRESENT	0
558920	557886	19673G	PARTICIPANT	\N	PRESENT	0
558922	558527	19527W	PARTICIPANT	\N	PRESENT	0
558923	558527	20132W	PARTICIPANT	\N	PRESENT	1
558924	558527	19699S	PARTICIPANT	\N	PRESENT	0
558925	558527	19533U	PARTICIPANT	\N	PRESENT	0
558926	558527	14073Q	PARTICIPANT	\N	PRESENT	0
558927	558527	19651A	PARTICIPANT	\N	PRESENT	1
558928	558527	19611R	PRESIDENT	0	PRESENT	0
558929	558527	20048C	PARTICIPANT	\N	PRESENT	1
558930	558527	19693L	PARTICIPANT	\N	PRESENT	0
558931	558527	19399H	PARTICIPANT	\N	PRESENT	0
558932	558527	20052X	PARTICIPANT	\N	PRESENT	0
558933	558527	14030Q	PARTICIPANT	\N	PRESENT	0
558934	558527	20180F	PARTICIPANT	\N	PRESENT	0
558935	558527	19735D	PARTICIPANT	\N	PRESENT	0
558936	558527	14123H	PARTICIPANT	\N	PRESENT	0
558937	558527	19758L	PARTICIPANT	\N	PRESENT	1
558938	558527	19621T	PARTICIPANT	\N	PRESENT	0
558939	558527	20084G	PARTICIPANT	\N	PRESENT	0
558940	557886	14053L	PARTICIPANT	\N	PRESENT	0
558941	557886	14215L	PARTICIPANT	\N	PRESENT	0
558942	557886	20110Q	PARTICIPANT	\N	PRESENT	0
558943	557886	14021P	PARTICIPANT	\N	PRESENT	0
558944	557886	17737W	PARTICIPANT	\N	PRESENT	0
558945	557886	20108W	PARTICIPANT	\N	PRESENT	0
558946	557886	19749K	PARTICIPANT	\N	PRESENT	0
558947	557886	14259Y	PARTICIPANT	\N	PRESENT	0
558948	557886	19447X	PARTICIPANT	\N	PRESENT	0
558949	558527	20134Y	PARTICIPANT	\N	PRESENT	1
558950	558527	20098N	PARTICIPANT	\N	PRESENT	1
558951	558527	14109K	PARTICIPANT	\N	PRESENT	1
558955	557886	19543W	PARTICIPANT	\N	PRESENT	1
558956	557886	19954N	PARTICIPANT	\N	PRESENT	1
558957	557886	20074E	PARTICIPANT	\N	PRESENT	1
558958	557886	14179A	PARTICIPANT	\N	PRESENT	1
558959	557886	11072N	PARTICIPANT	\N	PRESENT	1
558960	557886	10015M	PARTICIPANT	\N	PRESENT	1
558961	557886	19675J	PARTICIPANT	\N	PRESENT	1
558974	558527	20026V	PARTICIPANT	\N	PRESENT	1
558994	558964	17779H	PARTICIPANT	\N	PRESENT	0
558995	558964	11097X	PARTICIPANT	\N	PRESENT	0
558996	558969	08045X	PARTICIPANT	\N	PRESENT	0
558997	558970	08045X	PARTICIPANT	\N	PRESENT	0
558998	558978	19703U	PARTICIPANT	\N	PRESENT	0
558999	558980	19703U	PARTICIPANT	\N	PRESENT	0
559014	557693	19629C	PARTICIPANT	\N	PRESENT	0
559015	557693	11041F	PARTICIPANT	\N	PRESENT	0
559016	557693	20024T	PARTICIPANT	\N	PRESENT	0
559017	557693	20056C	PARTICIPANT	\N	PRESENT	0
559018	557693	19525U	PARTICIPANT	\N	PRESENT	0
559019	557693	19593H	PARTICIPANT	\N	PRESENT	0
559020	557693	19699S	PARTICIPANT	\N	PRESENT	0
559021	557693	20068G	PARTICIPANT	\N	PRESENT	0
559022	557693	19705W	PARTICIPANT	\N	PRESENT	0
559023	557693	14195A	PARTICIPANT	\N	PRESENT	0
559024	557693	20086J	PARTICIPANT	\N	PRESENT	0
559025	557693	14147R	PARTICIPANT	\N	PRESENT	0
559026	557693	14053L	PARTICIPANT	\N	PRESENT	0
559027	557693	19826F	PARTICIPANT	\N	PRESENT	0
559028	557693	19683J	PARTICIPANT	\N	PRESENT	0
559029	557693	20072C	PARTICIPANT	\N	PRESENT	0
559030	557693	19675J	PARTICIPANT	\N	PRESENT	0
559031	557693	11054L	PARTICIPANT	\N	PRESENT	0
559032	557693	11040E	PARTICIPANT	\N	PRESENT	0
559034	557693	05012A	PARTICIPANT	\N	PRESENT	0
559035	557693	14225N	PARTICIPANT	\N	PRESENT	0
559038	557693	20028X	PARTICIPANT	\N	PRESENT	0
559039	557693	12041X	PARTICIPANT	\N	PRESENT	0
559041	557693	19711U	PARTICIPANT	\N	PRESENT	0
559042	557693	11077T	PARTICIPANT	\N	PRESENT	0
559047	557693	11080N	PARTICIPANT	\N	PRESENT	0
559049	557693	19691J	PARTICIPANT	\N	PRESENT	0
559051	557693	14121F	PARTICIPANT	\N	PRESENT	0
559052	557693	04085P	PARTICIPANT	\N	PRESENT	0
559053	557693	19695N	PARTICIPANT	\N	PRESENT	0
559054	557693	20116W	PARTICIPANT	\N	PRESENT	0
559055	557693	19415P	PARTICIPANT	\N	PRESENT	0
559057	557693	19443T	PARTICIPANT	\N	PRESENT	0
559058	557693	19581D	PARTICIPANT	\N	PRESENT	0
559060	557693	97011G	PARTICIPANT	\N	PRESENT	0
559061	557693	19798U	PARTICIPANT	\N	PRESENT	0
559063	557693	19619A	PARTICIPANT	\N	PRESENT	0
559064	557693	19387D	PARTICIPANT	\N	PRESENT	0
559066	557693	08061X	PARTICIPANT	\N	PRESENT	0
559067	557693	19333N	PARTICIPANT	\N	PRESENT	0
559068	557693	14357A	PARTICIPANT	\N	PRESENT	0
559070	557693	07029T	PARTICIPANT	\N	PRESENT	0
559071	557693	20172F	PARTICIPANT	\N	PRESENT	0
559072	557693	86034E	PARTICIPANT	\N	PRESENT	0
559073	557693	19611R	PARTICIPANT	\N	PRESENT	0
559074	557693	20082E	PARTICIPANT	\N	PRESENT	0
559076	557693	20080C	PARTICIPANT	\N	PRESENT	0
559077	557693	92040Q	PARTICIPANT	\N	PRESENT	0
559078	557693	20136B	PARTICIPANT	\N	PRESENT	0
559079	557693	14329V	PARTICIPANT	\N	PRESENT	0
559080	557693	14083S	PARTICIPANT	\N	PRESENT	0
559081	557693	08069G	PARTICIPANT	\N	PRESENT	0
559082	557693	11012A	PARTICIPANT	\N	PRESENT	0
559083	557693	19723Y	PARTICIPANT	\N	PRESENT	0
559084	557693	20048C	PARTICIPANT	\N	PRESENT	0
559085	557693	19599P	PARTICIPANT	\N	PRESENT	0
559086	557693	14237S	PARTICIPANT	\N	PRESENT	0
559087	557693	19583F	PARTICIPANT	\N	PRESENT	0
559088	557693	16685X	PARTICIPANT	\N	PRESENT	0
559089	557693	14031R	PARTICIPANT	\N	PRESENT	0
559090	557693	01057W	PARTICIPANT	\N	PRESENT	0
559091	557693	14217N	PARTICIPANT	\N	PRESENT	0
559092	557693	11097X	PARTICIPANT	\N	PRESENT	0
559093	557693	19685L	PARTICIPANT	\N	PRESENT	0
559094	557693	19573D	PARTICIPANT	\N	PRESENT	0
559095	557693	19713W	PARTICIPANT	\N	PRESENT	0
559096	557693	11067R	PARTICIPANT	\N	PRESENT	0
559097	557693	01043Q	PARTICIPANT	\N	PRESENT	0
559098	557693	17229F	PARTICIPANT	\N	PRESENT	0
559099	557693	14073Q	PARTICIPANT	\N	PRESENT	0
559100	557693	20036X	PARTICIPANT	\N	PRESENT	0
559101	557693	20174H	PARTICIPANT	\N	PRESENT	0
559102	557693	14187A	PARTICIPANT	\N	PRESENT	0
559103	557693	11090Q	PARTICIPANT	\N	PRESENT	0
559104	557693	20098N	PARTICIPANT	\N	PRESENT	0
559105	557693	14151M	PARTICIPANT	\N	PRESENT	0
559106	557693	18083K	PARTICIPANT	\N	PRESENT	0
559107	557693	19717B	PARTICIPANT	\N	PRESENT	0
559108	557693	20042V	PARTICIPANT	\N	PRESENT	0
559109	557693	01028R	PARTICIPANT	\N	PRESENT	0
559110	557693	20112S	PARTICIPANT	\N	PRESENT	0
559111	557693	19549D	PARTICIPANT	\N	PRESENT	0
559112	557693	20044X	PARTICIPANT	\N	PRESENT	0
559113	557693	14255U	PARTICIPANT	\N	PRESENT	0
559114	557693	20034V	PARTICIPANT	\N	PRESENT	0
559115	557693	14030Q	PARTICIPANT	\N	PRESENT	0
559116	557693	11048N	PARTICIPANT	\N	PRESENT	0
559117	557693	20180F	PARTICIPANT	\N	PRESENT	0
559118	557693	11083R	PARTICIPANT	\N	PRESENT	0
559119	557693	17589D	PARTICIPANT	\N	PRESENT	0
559120	557693	14213J	PARTICIPANT	\N	PRESENT	0
559121	557693	19367Y	PARTICIPANT	\N	PRESENT	0
559122	557693	20052X	PARTICIPANT	\N	PRESENT	0
559123	557693	19687N	PARTICIPANT	\N	PRESENT	0
559124	557693	19503N	PARTICIPANT	\N	PRESENT	0
559125	557693	14021P	PARTICIPANT	\N	PRESENT	0
544008	542362	19798U	PARTICIPANT	\N	PRESENT	0
544009	542362	19569H	PARTICIPANT	\N	PRESENT	0
544010	542362	11097X	PARTICIPANT	\N	PRESENT	0
544011	542362	19415P	PARTICIPANT	\N	PRESENT	0
544012	542362	14223L	PARTICIPANT	\N	PRESENT	1
544013	542362	18193Q	PARTICIPANT	\N	PRESENT	0
544014	542362	17779H	PARTICIPANT	\N	PRESENT	1
544015	542362	11031D	PARTICIPANT	\N	PRESENT	0
544016	542362	19553Y	PARTICIPANT	\N	PRESENT	0
544017	542362	19679N	PARTICIPANT	\N	PRESENT	0
544018	542362	14042U	PARTICIPANT	\N	PRESENT	0
544019	542362	14195A	PARTICIPANT	\N	PRESENT	0
544020	542362	14213J	PARTICIPANT	\N	PRESENT	0
544021	542362	14217N	PARTICIPANT	\N	PRESENT	0
544022	542362	19683J	PARTICIPANT	\N	PRESENT	0
544023	542362	10006L	PRESIDENT	0	PRESENT	0
544024	542362	19591F	PARTICIPANT	\N	PRESENT	1
544025	542362	20130U	PARTICIPANT	\N	PRESENT	1
544026	542362	01034P	PARTICIPANT	\N	PRESENT	0
544027	542362	04092N	PARTICIPANT	\N	PRESENT	0
544028	542362	19663E	PARTICIPANT	\N	PRESENT	0
544029	542362	17965H	PARTICIPANT	\N	PRESENT	1
544030	542362	19301E	PARTICIPANT	\N	PRESENT	1
544031	542362	19715Y	PARTICIPANT	\N	PRESENT	0
544032	542362	19691J	PARTICIPANT	\N	PRESENT	0
544033	542362	19717B	PARTICIPANT	\N	PRESENT	1
544034	542362	20172F	PARTICIPANT	\N	PRESENT	0
544035	542362	19723Y	PARTICIPANT	\N	PRESENT	0
544036	542362	11103C	PARTICIPANT	\N	PRESENT	1
544037	542362	14071N	PARTICIPANT	\N	PRESENT	0
544038	542362	04043D	PARTICIPANT	\N	PRESENT	0
544039	542362	19760E	PARTICIPANT	\N	PRESENT	0
544040	542362	19367Y	PARTICIPANT	\N	EXCUSE	0
544041	542362	19295A	PARTICIPANT	\N	EXCUSE	0
544062	542816	95041E	PARTICIPANT	\N	PRESENT	0
544063	542816	19443T	PARTICIPANT	\N	PRESENT	1
544064	542816	19565D	PARTICIPANT	\N	PRESENT	0
544065	542816	20072C	PARTICIPANT	\N	PRESENT	0
544066	542816	04034C	PARTICIPANT	\N	PRESENT	0
544067	542816	01058X	PARTICIPANT	\N	PRESENT	0
544068	542816	16685X	PARTICIPANT	\N	PRESENT	0
544069	542816	04042C	PRESIDENT	0	PRESENT	0
544070	542816	11054L	PARTICIPANT	\N	PRESENT	0
544071	542816	19669L	PARTICIPANT	\N	PRESENT	0
544072	542816	11066Q	PARTICIPANT	\N	PRESENT	0
544073	542816	08056B	PARTICIPANT	\N	PRESENT	0
544074	542816	19421M	PARTICIPANT	\N	PRESENT	0
544075	542816	19347U	PARTICIPANT	\N	PRESENT	0
544076	542816	14249W	PARTICIPANT	\N	PRESENT	0
544077	542816	08047A	PARTICIPANT	\N	PRESENT	1
544078	542816	20128B	PARTICIPANT	\N	PRESENT	1
544079	542816	14059S	PARTICIPANT	\N	PRESENT	0
544080	542816	14097Y	PARTICIPANT	\N	PRESENT	1
544081	542816	04035D	PARTICIPANT	\N	PRESENT	1
544082	542816	01062T	PARTICIPANT	\N	PRESENT	1
544083	542816	08069G	PARTICIPANT	\N	PRESENT	0
544084	542816	20042V	PARTICIPANT	\N	PRESENT	0
544085	542816	01024M	PARTICIPANT	\N	PRESENT	1
544086	542816	14083S	PARTICIPANT	\N	PRESENT	1
544087	542816	14105F	PARTICIPANT	\N	PRESENT	0
544088	542816	20064C	PARTICIPANT	\N	PRESENT	0
544089	542816	11012A	PARTICIPANT	\N	PRESENT	1
544090	542816	98018T	PARTICIPANT	\N	PRESENT	1
544091	542816	14267Y	PARTICIPANT	\N	PRESENT	1
544092	542816	14255U	PARTICIPANT	\N	PRESENT	0
544093	542816	17023S	PARTICIPANT	\N	PRESENT	0
549798	547149	19741B	PARTICIPANT	\N	PRESENT	1
549799	547149	20080C	PARTICIPANT	\N	PRESENT	1
549800	547149	19545Y	PARTICIPANT	\N	PRESENT	1
549801	547149	11110B	PARTICIPANT	\N	PRESENT	1
549802	547149	14121F	PARTICIPANT	\N	PRESENT	1
549803	547149	19531S	PARTICIPANT	\N	PRESENT	1
549804	547149	99004R	PARTICIPANT	\N	PRESENT	1
549805	547149	19711U	PARTICIPANT	\N	PRESENT	1
549806	547149	08010L	PARTICIPANT	\N	PRESENT	1
549807	547149	12016W	PARTICIPANT	\N	PRESENT	1
549808	547149	19335Q	PARTICIPANT	\N	PRESENT	1
549809	547149	20050V	PARTICIPANT	\N	PRESENT	1
549810	547149	14331P	PARTICIPANT	\N	PRESENT	1
549811	547149	20150Y	PARTICIPANT	\N	PRESENT	1
549812	547149	19479G	PARTICIPANT	\N	PRESENT	1
549813	547149	14173T	PARTICIPANT	\N	PRESENT	1
549851	547149	11012A	PARTICIPANT	\N	PRESENT	1
553089	545943	19693L	PARTICIPANT	\N	EXCUSE	0
553288	553286	11085T	PARTICIPANT	\N	PRESENT	0
553289	553286	19954N	PARTICIPANT	\N	PRESENT	0
553294	553286	19647E	PARTICIPANT	\N	PRESENT	0
553296	553286	19741B	PARTICIPANT	\N	PRESENT	0
553299	553286	19637C	PARTICIPANT	\N	PRESENT	0
553300	553286	19798U	PARTICIPANT	\N	PRESENT	0
553301	553286	19515S	PARTICIPANT	\N	PRESENT	0
556081	555034	11070L	PARTICIPANT	\N	PRESENT	0
556082	555034	14097Y	PARTICIPANT	\N	PRESENT	0
556083	555034	14257W	PARTICIPANT	\N	PRESENT	0
556084	555034	19333N	PARTICIPANT	\N	PRESENT	0
556085	555034	20018V	PARTICIPANT	\N	PRESENT	0
556086	555034	20082E	PARTICIPANT	\N	PRESENT	0
556087	555034	20038A	PARTICIPANT	\N	PRESENT	0
556088	555034	11090Q	PARTICIPANT	\N	PRESENT	0
556089	555034	18193Q	PARTICIPANT	\N	PRESENT	0
556090	555034	11067R	PARTICIPANT	\N	PRESENT	0
556091	555034	19798U	PARTICIPANT	\N	PRESENT	0
556092	555034	20094J	PARTICIPANT	\N	PRESENT	0
556093	555034	14147R	PARTICIPANT	\N	PRESENT	0
556094	555034	19503N	PARTICIPANT	\N	PRESENT	0
556095	555034	20092G	PARTICIPANT	\N	PRESENT	0
556096	555034	11099A	PARTICIPANT	\N	PRESENT	0
556097	555034	20172F	PARTICIPANT	\N	PRESENT	0
556098	555034	20100N	PARTICIPANT	\N	PRESENT	0
556099	555034	19349W	PARTICIPANT	\N	PRESENT	0
556100	555034	20118Y	PARTICIPANT	\N	PRESENT	0
556101	555034	20026V	PARTICIPANT	\N	PRESENT	0
556102	555034	20180F	PARTICIPANT	\N	PRESENT	0
556103	555034	14207L	PARTICIPANT	\N	PRESENT	0
556104	555034	11012A	PARTICIPANT	\N	PRESENT	0
556105	555034	20140W	PARTICIPANT	\N	PRESENT	0
556106	555034	14111D	PARTICIPANT	\N	PRESENT	0
556107	555034	14331P	PARTICIPANT	\N	PRESENT	0
556108	555034	20056C	PARTICIPANT	\N	PRESENT	0
556109	555034	19447X	PARTICIPANT	\N	PRESENT	0
556110	555034	20174H	PARTICIPANT	\N	PRESENT	0
556111	555034	14259Y	PARTICIPANT	\N	PRESENT	0
556112	555034	01028R	PARTICIPANT	\N	PRESENT	0
556113	555034	20116W	PARTICIPANT	\N	PRESENT	0
556114	555034	19441R	PARTICIPANT	\N	PRESENT	0
556115	555034	20120S	PARTICIPANT	\N	PRESENT	0
556116	555034	19713W	PARTICIPANT	\N	PRESENT	0
556117	555034	20054A	PARTICIPANT	\N	PRESENT	0
556118	555034	20098N	PARTICIPANT	\N	PRESENT	0
556119	555034	19725B	PARTICIPANT	\N	PRESENT	0
556120	555034	14021P	PARTICIPANT	\N	PRESENT	0
556121	555034	14105F	PARTICIPANT	\N	PRESENT	0
556122	555034	19681G	PARTICIPANT	\N	PRESENT	0
556123	555034	05012A	PARTICIPANT	\N	PRESENT	0
556124	555034	19413M	PARTICIPANT	\N	PRESENT	0
556125	555034	20028X	PARTICIPANT	\N	PRESENT	0
556126	555034	19758L	PARTICIPANT	\N	PRESENT	0
556127	555034	04045F	PARTICIPANT	\N	PRESENT	0
556128	555034	19565D	PARTICIPANT	\N	PRESENT	0
556129	555034	20102Q	PARTICIPANT	\N	PRESENT	0
556130	555034	20080C	PARTICIPANT	\N	PRESENT	0
556131	555034	01025N	PARTICIPANT	\N	PRESENT	0
556132	555034	20126Y	PARTICIPANT	\N	PRESENT	0
556133	555034	14059S	PARTICIPANT	\N	PRESENT	0
556134	555034	20062A	PARTICIPANT	\N	PRESENT	0
556135	555034	19760E	PARTICIPANT	\N	PRESENT	0
556136	555034	20044X	PARTICIPANT	\N	PRESENT	0
556137	555034	11097X	PARTICIPANT	\N	PRESENT	0
556138	555034	17023S	PARTICIPANT	\N	PRESENT	0
556139	555034	14026U	PARTICIPANT	\N	PRESENT	0
556140	555034	20124W	PARTICIPANT	\N	PRESENT	0
556141	555034	20070A	PARTICIPANT	\N	PRESENT	0
556142	555034	14179A	PARTICIPANT	\N	PRESENT	0
556278	556277	14187A	PARTICIPANT	\N	PRESENT	0
556306	556277	01043Q	PARTICIPANT	\N	PRESENT	0
556320	556319	14205J	PARTICIPANT	\N	PRESENT	0
558011	558010	07004J	PARTICIPANT	\N	PRESENT	0
558013	558012	07004J	PARTICIPANT	\N	PRESENT	0
558015	558014	07004J	PARTICIPANT	\N	PRESENT	0
558017	558016	07004J	PARTICIPANT	\N	PRESENT	0
571967	571741	20052X	PARTICIPANT	\N	PRESENT	0
571968	571741	19399H	PARTICIPANT	\N	PRESENT	0
571969	571741	14213J	PARTICIPANT	\N	PRESENT	1
571970	571741	20056C	PARTICIPANT	\N	PRESENT	1
571971	571741	19699S	PARTICIPANT	\N	PRESENT	0
571972	571741	17965H	PARTICIPANT	\N	PRESENT	0
571973	571741	19533U	PARTICIPANT	\N	PRESENT	0
571974	571741	19611R	PARTICIPANT	\N	PRESENT	0
571975	571741	14030Q	PARTICIPANT	\N	PRESENT	0
571976	570964	19643A	PARTICIPANT	\N	PRESENT	0
571977	570964	20180F	PARTICIPANT	\N	PRESENT	0
571978	570964	19699S	PARTICIPANT	\N	PRESENT	0
571979	570964	20052X	PARTICIPANT	\N	PRESENT	0
571980	570964	20056C	PARTICIPANT	\N	PRESENT	0
571981	570964	14030Q	PARTICIPANT	\N	PRESENT	0
571982	570964	07033P	PARTICIPANT	\N	PRESENT	0
571983	570964	19399H	PARTICIPANT	\N	PRESENT	0
571984	570964	20112S	PARTICIPANT	\N	PRESENT	0
571985	570964	20132W	PARTICIPANT	\N	PRESENT	0
571986	570964	14229S	PARTICIPANT	\N	PRESENT	0
571987	570964	20134Y	PARTICIPANT	\N	PRESENT	0
571988	570964	11104D	PARTICIPANT	\N	PRESENT	0
571989	570964	11109J	PARTICIPANT	\N	EXCUSE	0
571990	570964	04059M	PARTICIPANT	\N	PRESENT	0
571991	570964	20048C	PARTICIPANT	\N	PRESENT	1
571992	570964	20142Y	PARTICIPANT	\N	PRESENT	1
571993	570964	04070G	PARTICIPANT	\N	PRESENT	1
571994	570964	19735D	PARTICIPANT	\N	PRESENT	0
571995	570964	19527W	PARTICIPANT	\N	PRESENT	0
571996	570964	19611R	PRESIDENT	0	PRESENT	0
571997	570964	19593H	PARTICIPANT	\N	PRESENT	1
586296	585744	14026U	PARTICIPANT	\N	PRESENT	0
586297	585744	11027H	PARTICIPANT	\N	PRESENT	0
586298	585744	11054L	PARTICIPANT	\N	PRESENT	0
586299	585744	14229S	PARTICIPANT	\N	PRESENT	0
586300	585744	20086J	PARTICIPANT	\N	PRESENT	0
586301	585744	14187A	PARTICIPANT	\N	PRESENT	0
586302	585744	20248J	PARTICIPANT	\N	PRESENT	0
586303	585744	19387D	PARTICIPANT	\N	PRESENT	0
586304	585744	07033P	PARTICIPANT	\N	PRESENT	0
586305	585744	20048C	PARTICIPANT	\N	PRESENT	0
586306	585744	14223L	PARTICIPANT	\N	PRESENT	0
586309	585744	19760E	PARTICIPANT	\N	PRESENT	0
586310	585744	11066Q	PARTICIPANT	\N	PRESENT	0
586315	585744	20056C	PARTICIPANT	\N	PRESENT	0
586317	585744	11043H	PARTICIPANT	\N	PRESENT	0
586322	585744	19503N	PARTICIPANT	\N	PRESENT	0
586323	585744	17737W	PARTICIPANT	\N	PRESENT	0
586324	585744	14071N	PARTICIPANT	\N	PRESENT	0
586325	585744	20174H	PARTICIPANT	\N	PRESENT	0
586326	585744	01024M	PARTICIPANT	\N	PRESENT	0
586327	585744	19335Q	PARTICIPANT	\N	PRESENT	0
586901	585578	11067R	PARTICIPANT	\N	PRESENT	0
586902	585578	20074E	PARTICIPANT	\N	PRESENT	0
586903	585578	11097X	PARTICIPANT	\N	PRESENT	0
586904	585578	14001X	PARTICIPANT	\N	PRESENT	0
586905	585578	18193Q	PARTICIPANT	\N	PRESENT	0
586906	585578	04047H	PRESIDENT	0	PRESENT	0
586907	585578	01028R	PARTICIPANT	\N	PRESENT	0
586908	585578	19447X	PARTICIPANT	\N	PRESENT	0
586909	585578	05008E	PARTICIPANT	\N	PRESENT	0
586910	585578	19553Y	PARTICIPANT	\N	PRESENT	0
586911	585578	11031D	PARTICIPANT	\N	PRESENT	0
586912	585578	14107H	PARTICIPANT	\N	PRESENT	0
586913	585578	19679N	PARTICIPANT	\N	PRESENT	0
586914	585578	20108W	PARTICIPANT	\N	PRESENT	0
586915	585578	14042U	PARTICIPANT	\N	PRESENT	0
586916	585578	20114U	PARTICIPANT	\N	PRESENT	0
586917	585578	14151M	PARTICIPANT	\N	PRESENT	0
586918	585578	14213J	PARTICIPANT	\N	PRESENT	0
586919	585578	11072N	PARTICIPANT	\N	PRESENT	0
586920	585578	19591F	PARTICIPANT	\N	PRESENT	0
586921	585578	14053L	PARTICIPANT	\N	PRESENT	0
586922	585578	14111D	PARTICIPANT	\N	PRESENT	0
586923	585578	19713W	PARTICIPANT	\N	PRESENT	0
586924	585578	10015M	PARTICIPANT	\N	PRESENT	0
586925	585578	11026G	PARTICIPANT	\N	PRESENT	0
586926	585578	19301E	PARTICIPANT	\N	PRESENT	0
586927	585578	19691J	PARTICIPANT	\N	PRESENT	0
586928	585578	20172F	PARTICIPANT	\N	PRESENT	0
586929	585578	19723Y	PARTICIPANT	\N	PRESENT	0
586930	585578	19729F	PARTICIPANT	\N	PRESENT	0
586931	585578	20248J	PARTICIPANT	\N	PRESENT	0
586932	585578	14071N	PARTICIPANT	\N	PRESENT	0
586933	585578	19749K	PARTICIPANT	\N	PRESENT	0
586934	585578	19760E	PARTICIPANT	\N	PRESENT	0
586942	584138	20032T	PARTICIPANT	\N	PRESENT	0
586943	584138	20068G	PARTICIPANT	\N	PRESENT	0
586944	584138	14031R	PARTICIPANT	\N	PRESENT	0
586945	584138	08009T	PARTICIPANT	\N	PRESENT	0
586946	584138	19549D	PARTICIPANT	\N	PRESENT	0
586947	584138	19503N	PARTICIPANT	\N	PRESENT	0
586948	584138	20046A	PARTICIPANT	\N	PRESENT	0
586949	584138	20102Q	PARTICIPANT	\N	PRESENT	0
586950	584138	20024T	PARTICIPANT	\N	PRESENT	0
586951	584138	17229F	PARTICIPANT	\N	PRESENT	0
586952	584138	17637T	PARTICIPANT	\N	PRESENT	0
586953	584138	19820Y	PARTICIPANT	\N	PRESENT	0
586954	584138	14221J	PARTICIPANT	\N	PRESENT	0
586955	584138	19826F	PARTICIPANT	\N	PRESENT	0
586956	584138	19599P	PARTICIPANT	\N	PRESENT	0
586957	584138	19637C	PARTICIPANT	\N	PRESENT	0
586958	584138	18083K	PARTICIPANT	\N	PRESENT	0
586959	584138	14237S	PARTICIPANT	\N	PRESENT	0
586960	584138	19745F	PARTICIPANT	\N	PRESENT	0
586961	584138	17367Q	PARTICIPANT	\N	PRESENT	0
586962	584138	19701S	PARTICIPANT	\N	PRESENT	0
586963	584138	20020P	PARTICIPANT	\N	PRESENT	0
586964	584138	11065P	PARTICIPANT	\N	PRESENT	0
586965	584138	20140W	PARTICIPANT	\N	PRESENT	0
586966	584138	19619A	PARTICIPANT	\N	PRESENT	0
586967	584138	19333N	PARTICIPANT	\N	PRESENT	0
586968	584138	14219Q	PRESIDENT	0	PRESENT	0
586969	584138	20136B	PARTICIPANT	\N	PRESENT	0
586970	584138	20106U	PARTICIPANT	\N	PRESENT	0
586971	584138	19251M	PARTICIPANT	\N	PRESENT	0
586972	584138	19387D	PARTICIPANT	\N	PRESENT	0
586973	584138	20038A	PARTICIPANT	\N	PRESENT	0
586974	584138	08060W	PARTICIPANT	\N	EXCUSE	0
586975	584138	20096L	PARTICIPANT	\N	PRESENT	0
586976	585411	14327T	PARTICIPANT	\N	PRESENT	0
586977	585411	14331P	PARTICIPANT	\N	PRESENT	0
586978	585411	19647E	PARTICIPANT	\N	PRESENT	0
586979	585411	19711U	PARTICIPANT	\N	PRESENT	0
586980	585411	01057W	PARTICIPANT	\N	PRESENT	0
586981	585411	12016W	PARTICIPANT	\N	PRESENT	0
586982	585411	20050V	PARTICIPANT	\N	PRESENT	0
586983	585411	20044X	PARTICIPANT	\N	PRESENT	0
586984	585411	14225N	PRESIDENT	0	PRESENT	0
586985	585411	14173T	PARTICIPANT	\N	PRESENT	0
586986	585411	11040E	PARTICIPANT	\N	PRESENT	0
586987	585411	19349W	PARTICIPANT	\N	PRESENT	0
586988	585411	14121F	PARTICIPANT	\N	PRESENT	0
586989	585411	99004R	PARTICIPANT	\N	PRESENT	0
586990	585411	20022R	PARTICIPANT	\N	PRESENT	0
586991	585411	19762G	PARTICIPANT	\N	PRESENT	0
586992	585411	11048N	PARTICIPANT	\N	PRESENT	0
586993	585411	19687N	PARTICIPANT	\N	PRESENT	0
586994	585411	20086J	PARTICIPANT	\N	PRESENT	0
586995	585691	19515S	PARTICIPANT	\N	PRESENT	0
586996	585691	20092G	PARTICIPANT	\N	PRESENT	0
586997	585691	19782L	PARTICIPANT	\N	PRESENT	1
586998	585691	01043Q	PARTICIPANT	\N	PRESENT	0
586999	585691	14357A	PARTICIPANT	\N	PRESENT	0
587000	585691	19441R	PARTICIPANT	\N	PRESENT	0
587001	585691	19413M	PARTICIPANT	\N	PRESENT	0
587002	585691	20082E	PARTICIPANT	\N	PRESENT	1
587003	585691	20094J	PARTICIPANT	\N	PRESENT	0
587004	585691	19705W	PARTICIPANT	\N	PRESENT	0
587005	585691	19575F	PARTICIPANT	\N	PRESENT	0
587006	585691	20018V	PARTICIPANT	\N	PRESENT	0
587007	585691	08028W	PARTICIPANT	\N	PRESENT	0
587008	585691	19563B	PARTICIPANT	\N	PRESENT	0
587009	585691	14329V	PARTICIPANT	\N	PRESENT	0
587010	585691	14038Y	PARTICIPANT	\N	PRESENT	0
587011	585691	20030R	PARTICIPANT	\N	PRESENT	1
587012	585691	19467C	PARTICIPANT	\N	PRESENT	0
587013	585691	14187A	PARTICIPANT	\N	PRESENT	0
587014	585691	11090Q	PRESIDENT	0	PRESENT	0
587015	585691	14033T	PARTICIPANT	\N	PRESENT	0
587016	585691	20054A	PARTICIPANT	\N	PRESENT	0
579092	578175	14179A	PARTICIPANT	\N	PRESENT	0
579093	578175	20124W	PARTICIPANT	\N	PRESENT	0
579094	578175	19533U	PARTICIPANT	\N	PRESENT	0
579099	578175	19399H	PARTICIPANT	\N	PRESENT	0
579100	578175	19599P	PARTICIPANT	\N	PRESENT	0
579101	578175	17023S	PARTICIPANT	\N	PRESENT	0
579102	578175	18083K	PARTICIPANT	\N	PRESENT	0
579103	578175	07029T	PARTICIPANT	\N	PRESENT	0
579104	578175	14038Y	PARTICIPANT	\N	PRESENT	0
579105	578175	20100N	PARTICIPANT	\N	PRESENT	0
579106	578175	19762G	PARTICIPANT	\N	PRESENT	0
579107	578175	20086J	PARTICIPANT	\N	PRESENT	0
579108	578175	19691J	PARTICIPANT	\N	PRESENT	0
579109	578175	08010L	PARTICIPANT	\N	PRESENT	0
579110	578175	20040T	PARTICIPANT	\N	PRESENT	0
579125	578175	11056N	PARTICIPANT	\N	PRESENT	0
579126	578175	11099A	PARTICIPANT	\N	PRESENT	0
579127	578175	19657G	PARTICIPANT	\N	PRESENT	0
579128	578175	14217N	PARTICIPANT	\N	PRESENT	0
579129	578175	14231L	PARTICIPANT	\N	PRESENT	0
579130	578175	19715Y	PARTICIPANT	\N	PRESENT	0
579131	578175	20134Y	PARTICIPANT	\N	PRESENT	0
579187	578176	19695N	PARTICIPANT	\N	PRESENT	0
579188	578176	19760E	PARTICIPANT	\N	PRESENT	0
579189	578176	19758L	PARTICIPANT	\N	PRESENT	0
579190	578176	20046A	PARTICIPANT	\N	PRESENT	0
579191	578176	14001X	PARTICIPANT	\N	PRESENT	0
579192	578176	19715Y	PARTICIPANT	\N	PRESENT	0
579193	578176	17779H	PARTICIPANT	\N	PRESENT	0
579194	578176	19599P	PARTICIPANT	\N	PRESENT	0
579195	578176	20130U	PARTICIPANT	\N	PRESENT	0
579196	578176	20110Q	PARTICIPANT	\N	PRESENT	0
579197	578176	20100N	PARTICIPANT	\N	PRESENT	0
579198	578176	19301E	PARTICIPANT	\N	PRESENT	0
579199	578176	19349W	PARTICIPANT	\N	PRESENT	0
579200	578176	11012A	PARTICIPANT	\N	PRESENT	0
579201	578176	19583F	PARTICIPANT	\N	PRESENT	0
579202	578176	14231L	PARTICIPANT	\N	PRESENT	0
579203	578176	14327T	PARTICIPANT	\N	PRESENT	0
579204	578176	14042U	PARTICIPANT	\N	PRESENT	0
579205	578176	19691J	PARTICIPANT	\N	PRESENT	0
579206	578176	14083S	PARTICIPANT	\N	PRESENT	0
579207	578176	14215L	PARTICIPANT	\N	PRESENT	0
579208	578176	11097X	PARTICIPANT	\N	PRESENT	0
579209	578176	14055N	PARTICIPANT	\N	PRESENT	0
579210	578176	19762G	PARTICIPANT	\N	PRESENT	0
579211	578176	19533U	PARTICIPANT	\N	PRESENT	0
579212	578176	19657G	PARTICIPANT	\N	PRESENT	0
579213	578176	07029T	PARTICIPANT	\N	PRESENT	0
579214	578176	04047H	PARTICIPANT	\N	PRESENT	0
579215	578176	04092N	PARTICIPANT	\N	PRESENT	0
579216	578176	10006L	PARTICIPANT	\N	PRESENT	0
579217	578176	14169X	PARTICIPANT	\N	PRESENT	0
579218	578176	18083K	PARTICIPANT	\N	PRESENT	0
579219	578176	14259Y	PARTICIPANT	\N	PRESENT	0
579234	578176	19399H	PARTICIPANT	\N	PRESENT	0
579221	578176	20098N	PARTICIPANT	\N	PRESENT	0
579222	578176	20034V	PARTICIPANT	\N	PRESENT	0
579223	578176	20044X	PARTICIPANT	\N	PRESENT	0
579224	578176	20058E	PARTICIPANT	\N	PRESENT	0
579225	578176	14038Y	PARTICIPANT	\N	PRESENT	0
579226	578176	14189C	PARTICIPANT	\N	PRESENT	0
579227	578176	20096L	PARTICIPANT	\N	PRESENT	0
579228	578176	20076G	PARTICIPANT	\N	PRESENT	0
579229	578176	19489J	PARTICIPANT	\N	PRESENT	0
579230	578176	20102Q	PARTICIPANT	\N	PRESENT	0
579231	578176	20086J	PARTICIPANT	\N	PRESENT	0
579185	578176	01043Q	PARTICIPANT	\N	PRESENT	0
579186	578176	11056N	PARTICIPANT	\N	PRESENT	0
579232	578176	08010L	PARTICIPANT	\N	PRESENT	0
579233	578176	14217N	PARTICIPANT	\N	PRESENT	0
579235	578176	12016W	PARTICIPANT	\N	PRESENT	0
579236	578176	20124W	PARTICIPANT	\N	PRESENT	0
579237	578176	14073Q	PARTICIPANT	\N	PRESENT	0
579238	578176	19251M	PARTICIPANT	\N	PRESENT	0
579239	578176	11065P	PARTICIPANT	\N	PRESENT	0
579240	578176	20120S	PARTICIPANT	\N	PRESENT	0
579241	578176	19749K	PARTICIPANT	\N	PRESENT	0
579242	578176	19593H	PARTICIPANT	\N	PRESENT	0
579246	578176	04085P	PARTICIPANT	\N	PRESENT	0
579247	578176	17367Q	PARTICIPANT	\N	PRESENT	0
579248	578176	14179A	PARTICIPANT	\N	PRESENT	0
579249	578176	17023S	PARTICIPANT	\N	PRESENT	0
579250	578176	20128B	PARTICIPANT	\N	PRESENT	0
579251	578176	11099A	PARTICIPANT	\N	PRESENT	0
579252	578176	14219Q	PARTICIPANT	\N	PRESENT	0
579253	578176	20094J	PARTICIPANT	\N	PRESENT	0
579254	578176	14357A	PARTICIPANT	\N	PRESENT	0
579255	578176	19447X	PARTICIPANT	\N	PRESENT	0
579256	578176	19713W	PARTICIPANT	\N	PRESENT	0
579257	578176	19717B	PARTICIPANT	\N	PRESENT	0
579258	578176	19711U	PARTICIPANT	\N	PRESENT	0
579259	578176	19347U	PARTICIPANT	\N	PRESENT	0
579260	578176	11070L	PARTICIPANT	\N	PRESENT	0
579261	578176	19575F	PARTICIPANT	\N	PRESENT	0
579262	578176	14225N	PARTICIPANT	\N	PRESENT	0
579315	578177	14259Y	PARTICIPANT	\N	PRESENT	0
579316	578177	11056N	PARTICIPANT	\N	PRESENT	0
579317	578177	19295A	PARTICIPANT	\N	PRESENT	0
579318	578177	12016W	PARTICIPANT	\N	PRESENT	0
579319	578177	14001X	PARTICIPANT	\N	PRESENT	0
579320	578177	19489J	PARTICIPANT	\N	PRESENT	0
579321	578177	14073Q	PARTICIPANT	\N	PRESENT	0
579322	578177	19347U	PARTICIPANT	\N	PRESENT	0
579323	578177	20100N	PARTICIPANT	\N	PRESENT	0
579324	578177	20110Q	PARTICIPANT	\N	PRESENT	0
579325	578177	20130U	PARTICIPANT	\N	PRESENT	0
579326	578177	19301E	PARTICIPANT	\N	PRESENT	0
579327	578177	08073C	PARTICIPANT	\N	PRESENT	0
579328	578177	14219Q	PARTICIPANT	\N	PRESENT	0
579329	578177	14042U	PARTICIPANT	\N	PRESENT	0
579330	578177	20128B	PARTICIPANT	\N	PRESENT	0
579331	578177	07029T	PARTICIPANT	\N	PRESENT	0
579332	578177	14083S	PARTICIPANT	\N	PRESENT	0
579333	578177	14231L	PARTICIPANT	\N	PRESENT	0
579334	578177	19691J	PARTICIPANT	\N	PRESENT	0
579335	578177	20120S	PARTICIPANT	\N	PRESENT	0
579336	578177	20124W	PARTICIPANT	\N	PRESENT	0
579337	578177	19695N	PARTICIPANT	\N	PRESENT	0
579338	578177	20046A	PARTICIPANT	\N	PRESENT	0
579339	578177	19593H	PARTICIPANT	\N	PRESENT	0
579340	578177	11097X	PARTICIPANT	\N	PRESENT	0
579341	578177	17367Q	PARTICIPANT	\N	PRESENT	0
579342	578177	20058E	PARTICIPANT	\N	PRESENT	0
579343	578177	18083K	PARTICIPANT	\N	PRESENT	0
579344	578177	19647E	PARTICIPANT	\N	PRESENT	0
579345	578177	20076G	PARTICIPANT	\N	PRESENT	0
579346	578177	14038Y	PARTICIPANT	\N	PRESENT	0
579347	578177	19575F	PARTICIPANT	\N	PRESENT	0
579348	578177	20034V	PARTICIPANT	\N	PRESENT	0
579349	578177	20108W	PARTICIPANT	\N	PRESENT	0
579350	578177	14217N	PARTICIPANT	\N	PRESENT	0
579351	578177	19349W	PARTICIPANT	\N	PRESENT	0
579352	578177	17023S	PARTICIPANT	\N	PRESENT	0
579353	578177	19251M	PARTICIPANT	\N	PRESENT	0
579354	578177	11043H	PARTICIPANT	\N	PRESENT	0
579355	578177	20086J	PARTICIPANT	\N	PRESENT	0
579356	578177	20098N	PARTICIPANT	\N	PRESENT	0
579357	578177	11099A	PARTICIPANT	\N	PRESENT	0
579358	578177	19399H	PARTICIPANT	\N	PRESENT	0
579359	578177	14327T	PARTICIPANT	\N	PRESENT	0
579360	578177	04047H	PARTICIPANT	\N	PRESENT	0
579361	578177	01028R	PARTICIPANT	\N	PRESENT	0
579362	578177	19713W	PARTICIPANT	\N	PRESENT	0
579363	578177	20126Y	PARTICIPANT	\N	PRESENT	0
579364	578177	20094J	PARTICIPANT	\N	PRESENT	0
579313	578177	11070L	PARTICIPANT	\N	PRESENT	0
579314	578177	14215L	PARTICIPANT	\N	PRESENT	0
579365	578177	20044X	PARTICIPANT	\N	PRESENT	0
579366	578177	19447X	PARTICIPANT	\N	PRESENT	0
579367	578177	19758L	PARTICIPANT	\N	PRESENT	0
579368	578177	19335Q	PARTICIPANT	\N	PRESENT	0
579369	578177	08010L	PARTICIPANT	\N	PRESENT	0
579370	578177	11012A	PARTICIPANT	\N	PRESENT	0
582852	582631	19649G	PARTICIPANT	\N	PRESENT	0
582853	582631	19543W	PARTICIPANT	\N	PRESENT	0
582854	582631	19673G	PARTICIPANT	\N	PRESENT	0
582855	582631	05008E	PARTICIPANT	\N	PRESENT	0
582856	582631	19447X	PARTICIPANT	\N	PRESENT	0
582857	582631	17737W	PARTICIPANT	\N	PRESENT	0
582858	582631	14275Y	PARTICIPANT	\N	PRESENT	0
570413	568173	14179A	PARTICIPANT	\N	PRESENT	1
570414	568173	19447X	PARTICIPANT	\N	PRESENT	1
570415	568173	11072N	PARTICIPANT	\N	PRESENT	1
570573	567854	14331P	PRESIDENT	0	PRESENT	0
570574	567854	14097Y	PARTICIPANT	\N	PRESENT	0
570575	567854	14237S	PARTICIPANT	\N	PRESENT	0
570411	568173	04085P	PARTICIPANT	\N	PRESENT	1
570412	568173	14041T	PARTICIPANT	\N	PRESENT	1
570576	567854	19441R	PARTICIPANT	\N	PRESENT	0
570577	567854	14357A	PARTICIPANT	\N	PRESENT	0
570578	567854	10015M	PARTICIPANT	\N	PRESENT	0
570579	567854	12041X	PARTICIPANT	\N	PRESENT	0
570580	567854	11083R	PARTICIPANT	\N	PRESENT	0
570581	567854	20104S	PARTICIPANT	\N	PRESENT	0
570582	567854	04034C	PARTICIPANT	\N	PRESENT	0
570583	567854	19725B	PARTICIPANT	\N	PRESENT	1
570584	567854	19711U	PARTICIPANT	\N	PRESENT	1
570586	567854	14169X	PARTICIPANT	\N	PRESENT	0
579113	578154	19735D	PARTICIPANT	\N	PRESENT	0
579114	578154	19723Y	PARTICIPANT	\N	PRESENT	0
579116	578154	01048V	PARTICIPANT	\N	EXCUSE	0
579117	578154	19533U	PARTICIPANT	\N	PRESENT	0
579118	578154	19503N	PARTICIPANT	\N	PRESENT	0
579119	578154	04043D	PARTICIPANT	\N	PRESENT	0
579120	578154	01058X	PARTICIPANT	\N	PRESENT	0
581911	579514	04092N	PARTICIPANT	\N	PRESENT	1
581912	579514	14042U	PARTICIPANT	\N	PRESENT	1
581913	579549	20172F	PARTICIPANT	\N	PRESENT	1
581951	579244	19697Q	PARTICIPANT	\N	PRESENT	0
581952	579244	19713W	PARTICIPANT	\N	PRESENT	0
581953	579244	11045K	PARTICIPANT	\N	PRESENT	0
581954	579244	19663E	PARTICIPANT	\N	PRESENT	0
581955	579244	17965H	PARTICIPANT	\N	PRESENT	0
581956	579244	19715Y	PARTICIPANT	\N	PRESENT	0
581957	579244	18193Q	PARTICIPANT	\N	PRESENT	0
581958	579244	20148F	PARTICIPANT	\N	PRESENT	0
581959	579244	17779H	PARTICIPANT	\N	PRESENT	0
581960	579244	11031D	PARTICIPANT	\N	PRESENT	0
581961	579244	19553Y	PARTICIPANT	\N	PRESENT	0
581962	579244	19657G	PARTICIPANT	\N	PRESENT	0
581963	579244	14071N	PARTICIPANT	\N	PRESENT	0
581964	579244	14217N	PARTICIPANT	\N	PRESENT	0
581965	579244	10006L	PRESIDENT	0	PRESENT	0
581984	581921	14053L	PARTICIPANT	\N	PRESENT	0
581985	581921	19649G	PARTICIPANT	\N	PRESENT	0
581986	581921	10015M	PARTICIPANT	\N	PRESENT	0
581987	581921	11026G	PARTICIPANT	\N	PRESENT	0
581988	581921	04047H	PRESIDENT	0	PRESENT	0
581989	581921	19673G	PARTICIPANT	\N	PRESENT	0
581990	581921	19675J	PARTICIPANT	\N	PRESENT	0
581991	581921	11033F	PARTICIPANT	\N	PRESENT	0
581992	581921	05008E	PARTICIPANT	\N	PRESENT	0
581993	581921	14231L	PARTICIPANT	\N	PRESENT	0
581994	581921	14089Y	PARTICIPANT	\N	PRESENT	0
581995	581921	95063L	PARTICIPANT	\N	PRESENT	0
581996	581921	07004J	PARTICIPANT	\N	PRESENT	0
581997	581921	20108W	PARTICIPANT	\N	PRESENT	0
581998	581921	14179A	PARTICIPANT	\N	PRESENT	0
581999	581921	14215L	PARTICIPANT	\N	PRESENT	0
582000	581921	11085T	PARTICIPANT	\N	PRESENT	0
582001	581921	14021P	PARTICIPANT	\N	PRESENT	0
582003	581921	14041T	PARTICIPANT	\N	PRESENT	0
582004	581921	14217N	PARTICIPANT	\N	PRESENT	0
582021	580054	14026U	PARTICIPANT	\N	PRESENT	0
582022	580054	20086J	PARTICIPANT	\N	PRESENT	0
582023	580054	19713W	PARTICIPANT	\N	PRESENT	0
582024	580054	20034V	PARTICIPANT	\N	PRESENT	0
582025	580054	17737W	PARTICIPANT	\N	PRESENT	0
582026	580054	20124W	PARTICIPANT	\N	PRESENT	0
582027	580054	14053L	PARTICIPANT	\N	PRESENT	0
582028	580054	20044X	PARTICIPANT	\N	PRESENT	0
582029	580054	14071N	PARTICIPANT	\N	PRESENT	0
582030	580054	07004J	PARTICIPANT	\N	PRESENT	0
582031	580054	19611R	PARTICIPANT	\N	PRESENT	0
582032	580054	20128B	PARTICIPANT	\N	PRESENT	0
582033	580054	01024M	PARTICIPANT	\N	PRESENT	0
582034	580054	12041X	PARTICIPANT	\N	PRESENT	0
582035	580054	11031D	PARTICIPANT	\N	PRESENT	0
582036	580054	04047H	PARTICIPANT	\N	PRESENT	0
582037	580054	05008E	PARTICIPANT	\N	PRESENT	0
582038	580054	14217N	PARTICIPANT	\N	PRESENT	0
582039	580054	10006L	PARTICIPANT	\N	PRESENT	0
582040	580054	19593H	PARTICIPANT	\N	PRESENT	0
582041	580054	19695N	PARTICIPANT	\N	PRESENT	0
582042	580054	04085P	PARTICIPANT	\N	PRESENT	0
582043	580054	18193Q	PARTICIPANT	\N	PRESENT	0
582044	580054	20084G	PARTICIPANT	\N	PRESENT	0
582045	580054	19715Y	PARTICIPANT	\N	PRESENT	0
582046	580054	19649G	PARTICIPANT	\N	PRESENT	0
582047	580054	12016W	PARTICIPANT	\N	PRESENT	0
582048	580054	14021P	PARTICIPANT	\N	PRESENT	0
582049	580054	20130U	PARTICIPANT	\N	PRESENT	0
582050	580054	19347U	PARTICIPANT	\N	PRESENT	0
582051	580054	19687N	PARTICIPANT	\N	PRESENT	0
582052	580054	20100N	PARTICIPANT	\N	PRESENT	0
582053	580054	19651A	PARTICIPANT	\N	PRESENT	0
582054	580054	95063L	PARTICIPANT	\N	PRESENT	0
582055	580054	19583F	PARTICIPANT	\N	PRESENT	0
582056	580054	14089Y	PARTICIPANT	\N	PRESENT	0
582057	580054	11099A	PARTICIPANT	\N	PRESENT	0
582058	580054	19577H	PARTICIPANT	\N	PRESENT	0
582059	580054	11085T	PARTICIPANT	\N	PRESENT	0
582060	580054	11053K	PARTICIPANT	\N	PRESENT	0
582061	580054	14251Q	PARTICIPANT	\N	PRESENT	0
582062	580054	20120S	PARTICIPANT	\N	PRESENT	0
582063	580054	20148F	PARTICIPANT	\N	PRESENT	0
582064	580054	19553Y	PARTICIPANT	\N	PRESENT	0
582065	580054	14215L	PARTICIPANT	\N	PRESENT	0
582066	580054	11097X	PARTICIPANT	\N	PRESENT	0
582067	580054	14055N	PARTICIPANT	\N	PRESENT	0
582068	580054	19762G	PARTICIPANT	\N	PRESENT	0
582069	580054	04033B	PARTICIPANT	\N	PRESENT	0
582070	580054	14179A	PARTICIPANT	\N	PRESENT	0
582071	580054	07029T	PARTICIPANT	\N	PRESENT	0
582072	580054	19766L	PARTICIPANT	\N	PRESENT	0
582073	580054	20038A	PARTICIPANT	\N	PRESENT	0
582074	580054	10015M	PARTICIPANT	\N	PRESENT	0
582075	580054	18083K	PARTICIPANT	\N	PRESENT	0
582076	580054	17779H	PARTICIPANT	\N	PRESENT	0
582077	580054	19723Y	PARTICIPANT	\N	PRESENT	0
582078	580054	19573D	PARTICIPANT	\N	PRESENT	0
582079	580054	19543W	PARTICIPANT	\N	PRESENT	0
582080	580054	20052X	PARTICIPANT	\N	PRESENT	0
582081	580054	08069G	PARTICIPANT	\N	PRESENT	0
582082	580054	01057W	PARTICIPANT	\N	PRESENT	0
582083	580054	20090E	PARTICIPANT	\N	PRESENT	0
582084	580054	19443T	PARTICIPANT	\N	PRESENT	0
582085	580054	11026G	PARTICIPANT	\N	PRESENT	0
582086	580054	04035D	PARTICIPANT	\N	PRESENT	0
582558	582557	05008E	PARTICIPANT	\N	PRESENT	0
583459	583226	19533U	PARTICIPANT	\N	PRESENT	1
572769	571152	19415P	PARTICIPANT	\N	PRESENT	0
572771	571152	20062A	PARTICIPANT	\N	PRESENT	0
572772	571152	20024T	PARTICIPANT	\N	PRESENT	0
572773	571152	04092N	PARTICIPANT	\N	PRESENT	0
572774	571152	19399H	PARTICIPANT	\N	PRESENT	0
572775	571152	19347U	PARTICIPANT	\N	PRESENT	0
572777	571152	99004R	PARTICIPANT	\N	PRESENT	0
572780	571152	11067R	PARTICIPANT	\N	PRESENT	0
572781	571152	11097X	PARTICIPANT	\N	PRESENT	0
572782	571152	14041T	PARTICIPANT	\N	PRESENT	0
572783	571152	11012A	PARTICIPANT	\N	PRESENT	0
572784	571152	19591F	PARTICIPANT	\N	PRESENT	0
572785	571152	19515S	PARTICIPANT	\N	PRESENT	0
572805	571152	14071N	PARTICIPANT	\N	PRESENT	0
572827	572729	19551W	PARTICIPANT	\N	PRESENT	1
572828	572729	14083S	PRESIDENT	0	PRESENT	0
572829	572729	14357A	PARTICIPANT	\N	PRESENT	0
572830	572729	19687N	PARTICIPANT	\N	PRESENT	0
572831	572729	19369B	PARTICIPANT	\N	PRESENT	0
572832	572729	19749K	PARTICIPANT	\N	PRESENT	0
572839	571152	20100N	PARTICIPANT	\N	PRESENT	0
572840	571152	10015M	PARTICIPANT	\N	PRESENT	0
572841	571152	11026G	PARTICIPANT	\N	PRESENT	0
572842	571152	01024M	PARTICIPANT	\N	PRESENT	0
572843	571152	19551W	PARTICIPANT	\N	PRESENT	0
572844	571152	08018U	PARTICIPANT	\N	PRESENT	0
572845	571152	19533U	PARTICIPANT	\N	PRESENT	0
572846	571152	14357A	PARTICIPANT	\N	PRESENT	0
572856	571152	19619A	PARTICIPANT	\N	PRESENT	0
572857	571152	19701S	PARTICIPANT	\N	PRESENT	0
572859	571152	14207L	PARTICIPANT	\N	PRESENT	0
572860	571152	14031R	PARTICIPANT	\N	PRESENT	0
572861	571152	19369B	PARTICIPANT	\N	PRESENT	0
572862	571152	14219Q	PARTICIPANT	\N	PRESENT	0
572863	571152	20052X	PARTICIPANT	\N	PRESENT	0
572864	571152	19333N	PARTICIPANT	\N	PRESENT	0
572865	571152	20136B	PARTICIPANT	\N	PRESENT	0
572866	572729	14026U	PARTICIPANT	\N	EXCUSE	0
572868	571152	20114U	PARTICIPANT	\N	PRESENT	0
572869	571152	20106U	PARTICIPANT	\N	PRESENT	0
572870	571152	19697Q	PARTICIPANT	\N	PRESENT	0
572871	571152	14231L	PARTICIPANT	\N	PRESENT	0
572872	571152	04043D	PARTICIPANT	\N	PRESENT	0
575192	575191	14053L	PARTICIPANT	\N	PRESENT	0
575193	575191	14299H	PARTICIPANT	\N	PRESENT	0
575198	575196	04047H	PARTICIPANT	\N	PRESENT	0
575199	575196	14053L	PARTICIPANT	\N	PRESENT	0
575200	575196	14299H	PARTICIPANT	\N	PRESENT	0
575203	575196	11066Q	PARTICIPANT	\N	PRESENT	0
575205	575204	14053L	PARTICIPANT	\N	PRESENT	0
575207	575204	11066Q	PARTICIPANT	\N	PRESENT	0
575213	575212	19683J	PRESIDENT	0	PRESENT	0
575214	575212	99004R	PARTICIPANT	\N	PRESENT	0
575215	575212	14189C	PARTICIPANT	\N	PRESENT	0
575216	575212	19447X	PARTICIPANT	\N	PRESENT	1
575217	575212	10006L	PARTICIPANT	\N	PRESENT	1
575218	575212	19699S	PARTICIPANT	\N	PRESENT	1
575219	575212	14207L	PARTICIPANT	\N	PRESENT	1
575220	575212	11031D	PARTICIPANT	\N	EXCUSE	0
575221	575212	11033F	PARTICIPANT	\N	EXCUSE	0
577190	575109	11056N	PARTICIPANT	\N	PRESENT	0
575318	575315	19479G	PARTICIPANT	\N	PRESENT	0
575319	575316	19479G	PARTICIPANT	\N	PRESENT	0
577191	575109	07004J	PARTICIPANT	\N	PRESENT	0
577192	575109	04047H	PRESIDENT	0	PRESENT	0
577193	575109	14259Y	PARTICIPANT	\N	PRESENT	0
577194	575109	19673G	PARTICIPANT	\N	PRESENT	0
577195	575109	19447X	PARTICIPANT	\N	PRESENT	0
577196	575109	14231L	PARTICIPANT	\N	PRESENT	0
577547	575271	08073C	PARTICIPANT	\N	PRESENT	0
577198	575109	10015M	PARTICIPANT	\N	PRESENT	0
577199	575109	14147R	PARTICIPANT	\N	PRESENT	0
577200	575253	19383Y	PARTICIPANT	\N	PRESENT	0
577201	575253	14038Y	PARTICIPANT	\N	PRESENT	0
577202	575253	20034V	PARTICIPANT	\N	PRESENT	0
577203	575253	19782L	PARTICIPANT	\N	PRESENT	1
577204	575253	14187A	PARTICIPANT	\N	PRESENT	0
577205	575253	20078J	PARTICIPANT	\N	PRESENT	1
577206	575253	20144B	PARTICIPANT	\N	PRESENT	0
577207	575253	20082E	PARTICIPANT	\N	PRESENT	1
577208	575253	11090Q	PRESIDENT	0	PRESENT	0
577209	575253	14033T	PARTICIPANT	\N	PRESENT	1
577210	575253	04045F	PARTICIPANT	\N	PRESENT	0
577211	575253	19631V	PARTICIPANT	\N	PRESENT	0
577212	575253	20174H	PARTICIPANT	\N	PRESENT	1
577213	575253	20062A	PARTICIPANT	\N	PRESENT	0
577214	575253	19705W	PARTICIPANT	\N	PRESENT	0
577215	575253	19507S	PARTICIPANT	\N	PRESENT	0
577216	575253	20018V	PARTICIPANT	\N	PRESENT	1
577217	575253	19747H	PARTICIPANT	\N	PRESENT	0
577218	575253	14207L	PARTICIPANT	\N	PRESENT	0
577219	575253	14257W	PARTICIPANT	\N	PRESENT	0
577220	575109	14215L	PARTICIPANT	\N	PRESENT	0
577221	575109	01028R	PARTICIPANT	\N	PRESENT	0
577222	575253	19768N	PARTICIPANT	\N	PRESENT	0
577223	575109	14089Y	PARTICIPANT	\N	PRESENT	0
577224	575109	20110Q	PARTICIPANT	\N	PRESENT	0
577225	575109	11085T	PARTICIPANT	\N	PRESENT	0
577231	575253	14205J	PARTICIPANT	\N	PRESENT	1
577548	575271	08061X	PARTICIPANT	\N	PRESENT	0
577549	575271	19489J	PARTICIPANT	\N	PRESENT	0
577550	575271	14073Q	PARTICIPANT	\N	PRESENT	0
577551	575271	14030Q	PARTICIPANT	\N	PRESENT	0
577552	575271	20036X	PARTICIPANT	\N	PRESENT	0
577553	575271	19691J	PARTICIPANT	\N	PRESENT	0
577554	575271	19387D	PARTICIPANT	\N	PRESENT	0
577555	575271	19631V	PARTICIPANT	\N	PRESENT	0
577556	575271	19741B	PARTICIPANT	\N	PRESENT	0
577557	575271	19543W	PARTICIPANT	\N	PRESENT	0
577561	575271	20110Q	PARTICIPANT	\N	PRESENT	0
577559	575271	20022R	PARTICIPANT	\N	PRESENT	0
577560	575271	11033F	PARTICIPANT	\N	PRESENT	0
577562	575271	20094J	PARTICIPANT	\N	PRESENT	0
577563	575271	19367Y	PARTICIPANT	\N	PRESENT	0
577564	575271	14089Y	PARTICIPANT	\N	PRESENT	0
577565	575271	19747H	PARTICIPANT	\N	PRESENT	0
577566	575271	19383Y	PARTICIPANT	\N	PRESENT	0
577567	575271	20080C	PARTICIPANT	\N	PRESENT	0
577568	575271	19621T	PARTICIPANT	\N	PRESENT	0
577569	575271	19758L	PARTICIPANT	\N	PRESENT	0
577570	575271	04047H	PARTICIPANT	\N	PRESENT	0
577571	575271	20090E	PARTICIPANT	\N	PRESENT	0
577572	575271	14207L	PARTICIPANT	\N	PRESENT	0
577573	575271	20060X	PARTICIPANT	\N	PRESENT	0
577574	575271	14329V	PARTICIPANT	\N	PRESENT	0
577575	575271	14038Y	PARTICIPANT	\N	PRESENT	0
577576	575271	19467C	PARTICIPANT	\N	PRESENT	0
577577	575271	18083K	PARTICIPANT	\N	PRESENT	0
577578	575271	11056N	PARTICIPANT	\N	PRESENT	0
577579	575271	14357A	PARTICIPANT	\N	PRESENT	0
577580	575271	11065P	PARTICIPANT	\N	PRESENT	0
577581	575271	19693L	PARTICIPANT	\N	PRESENT	0
577582	575271	19719D	PARTICIPANT	\N	PRESENT	0
577583	575271	14327T	PARTICIPANT	\N	PRESENT	0
577584	575271	20140W	PARTICIPANT	\N	PRESENT	0
577585	575271	14217N	PARTICIPANT	\N	PRESENT	0
577586	575271	01024M	PARTICIPANT	\N	PRESENT	0
577587	575271	19251M	PARTICIPANT	\N	PRESENT	0
577588	575271	14215L	PARTICIPANT	\N	PRESENT	0
577589	575271	19577H	PARTICIPANT	\N	PRESENT	0
577590	575271	14042U	PARTICIPANT	\N	PRESENT	0
577591	575271	20134Y	PARTICIPANT	\N	PRESENT	0
577592	575271	20124W	PARTICIPANT	\N	PRESENT	0
577593	575271	19507S	PARTICIPANT	\N	PRESENT	0
577594	575271	14187A	PARTICIPANT	\N	PRESENT	0
577595	575271	19673G	PARTICIPANT	\N	PRESENT	0
577596	575271	20174H	PARTICIPANT	\N	PRESENT	0
577597	575271	20038A	PARTICIPANT	\N	PRESENT	0
577598	575271	20100N	PARTICIPANT	\N	PRESENT	0
577599	575271	20132W	PARTICIPANT	\N	PRESENT	0
577600	575271	19599P	PARTICIPANT	\N	PRESENT	0
577601	575271	17023S	PARTICIPANT	\N	PRESENT	0
577602	575271	97011G	PARTICIPANT	\N	PRESENT	0
577603	575271	14231L	PARTICIPANT	\N	PRESENT	0
577604	575271	19399H	PARTICIPANT	\N	PRESENT	0
577605	575271	20048C	PARTICIPANT	\N	PRESENT	0
571283	566641	14097Y	PARTICIPANT	\N	PRESENT	0
571284	566641	14237S	PARTICIPANT	\N	PRESENT	0
574988	574987	11040E	PARTICIPANT	\N	PRESENT	0
574989	574987	19479G	PARTICIPANT	\N	PRESENT	0
574990	574986	11040E	PARTICIPANT	\N	PRESENT	0
574991	574986	19479G	PARTICIPANT	\N	PRESENT	0
574994	566272	19717B	PRESIDENT	0	PRESENT	0
575039	565801	20024T	PARTICIPANT	\N	EXCUSE	0
575040	565801	14030Q	PRESIDENT	0	PRESENT	0
575041	565801	17737W	PARTICIPANT	\N	EXCUSE	0
575042	565801	19621T	PARTICIPANT	\N	EXCUSE	0
575043	565801	11031D	PARTICIPANT	\N	EXCUSE	0
575044	565801	19599P	PARTICIPANT	\N	PRESENT	0
575045	565801	04035D	PARTICIPANT	\N	PRESENT	0
575046	565801	20106U	PARTICIPANT	\N	PRESENT	1
575047	565801	14179A	PARTICIPANT	\N	PRESENT	1
575048	565801	07029T	PARTICIPANT	\N	PRESENT	0
575049	565801	14109K	PARTICIPANT	\N	PRESENT	0
575050	565801	20118Y	PARTICIPANT	\N	EXCUSE	0
575051	565801	20130U	PARTICIPANT	\N	EXCUSE	0
575052	565801	20098N	PARTICIPANT	\N	EXCUSE	0
575053	565801	19527W	PARTICIPANT	\N	PRESENT	1
575054	565801	20046A	PARTICIPANT	\N	EXCUSE	0
575055	565801	19749K	PARTICIPANT	\N	PRESENT	0
575235	575160	19954N	PARTICIPANT	\N	PRESENT	1
575236	575160	19643A	PARTICIPANT	\N	PRESENT	0
575237	575160	14123H	PARTICIPANT	\N	PRESENT	0
575238	575160	08017T	PARTICIPANT	\N	PRESENT	0
575239	575160	04057K	PARTICIPANT	\N	PRESENT	0
575240	575160	19527W	PARTICIPANT	\N	PRESENT	0
575241	575160	20106U	PARTICIPANT	\N	PRESENT	1
575420	575412	14255U	PARTICIPANT	\N	PRESENT	0
575427	575412	14041T	PARTICIPANT	\N	PRESENT	0
575432	575412	08018U	PARTICIPANT	\N	PRESENT	0
575439	575412	19709B	PARTICIPANT	\N	PRESENT	0
575445	575412	11026G	PARTICIPANT	\N	PRESENT	0
575450	575412	14147R	PARTICIPANT	\N	PRESENT	0
575487	575375	14255U	PARTICIPANT	\N	PRESENT	0
575488	575375	14041T	PARTICIPANT	\N	PRESENT	0
575489	575375	08018U	PARTICIPANT	\N	PRESENT	0
575490	575375	19709B	PARTICIPANT	\N	PRESENT	0
575491	575375	11026G	PARTICIPANT	\N	PRESENT	0
575492	575375	14147R	PARTICIPANT	\N	PRESENT	0
575494	575493	14249W	PARTICIPANT	\N	PRESENT	0
575495	575493	14041T	PARTICIPANT	\N	PRESENT	0
575496	575493	19954N	PARTICIPANT	\N	PRESENT	0
575497	575493	20056C	PARTICIPANT	\N	PRESENT	0
575498	575493	19711U	PARTICIPANT	\N	PRESENT	0
575499	575493	17367Q	PARTICIPANT	\N	PRESENT	0
575500	575493	14357A	PARTICIPANT	\N	PRESENT	0
575501	575493	14179A	PARTICIPANT	\N	PRESENT	0
575502	575493	14097Y	PARTICIPANT	\N	PRESENT	0
575503	575493	14147R	PARTICIPANT	\N	PRESENT	0
575504	575493	19766L	PARTICIPANT	\N	PRESENT	0
575505	575493	04033B	PARTICIPANT	\N	PRESENT	0
576969	576968	14030Q	PARTICIPANT	\N	PRESENT	0
576970	576968	20114U	PARTICIPANT	\N	PRESENT	0
576971	576968	19643A	PARTICIPANT	\N	PRESENT	0
576972	576968	20152B	PARTICIPANT	\N	PRESENT	0
576973	576968	18083K	PARTICIPANT	\N	PRESENT	0
576974	576968	20134Y	PARTICIPANT	\N	PRESENT	0
576975	576968	20124W	PARTICIPANT	\N	PRESENT	0
576976	576968	19673G	PARTICIPANT	\N	PRESENT	0
576977	576968	14123H	PARTICIPANT	\N	PRESENT	0
576978	576968	19691J	PARTICIPANT	\N	PRESENT	0
576979	576968	14073Q	PARTICIPANT	\N	PRESENT	0
576980	576968	08017T	PARTICIPANT	\N	PRESENT	0
576981	576968	04057K	PARTICIPANT	\N	PRESENT	0
576982	576968	19527W	PRESIDENT	0	PRESENT	0
582700	582698	11083R	PARTICIPANT	\N	PRESENT	0
582701	582698	17367Q	PARTICIPANT	\N	PRESENT	0
582702	582698	20082E	PARTICIPANT	\N	PRESENT	0
582703	582698	07004J	PARTICIPANT	\N	PRESENT	0
582704	582699	17367Q	PARTICIPANT	\N	PRESENT	0
582705	582699	11083R	PARTICIPANT	\N	PRESENT	0
582706	582699	19593H	PARTICIPANT	\N	PRESENT	0
582879	582878	14329V	PARTICIPANT	\N	PRESENT	0
582880	582878	14207L	PARTICIPANT	\N	PRESENT	0
582882	582881	14329V	PARTICIPANT	\N	PRESENT	0
582884	582883	14329V	PARTICIPANT	\N	PRESENT	0
585771	585770	20144B	PARTICIPANT	\N	PRESENT	0
583438	583226	11043H	PARTICIPANT	\N	PRESENT	0
583439	583226	08012N	PARTICIPANT	\N	PRESENT	1
583440	583226	14030Q	PARTICIPANT	\N	PRESENT	1
583475	583227	08012N	PARTICIPANT	\N	PRESENT	1
583476	583227	19651A	PARTICIPANT	\N	PRESENT	1
583477	583227	11043H	PARTICIPANT	\N	PRESENT	1
583479	583478	19735D	PARTICIPANT	\N	PRESENT	1
583480	583478	14229S	PARTICIPANT	\N	PRESENT	1
583482	583481	14229S	PARTICIPANT	\N	PRESENT	1
583484	583483	14229S	PARTICIPANT	\N	PRESENT	1
583486	583485	20056C	PARTICIPANT	\N	PRESENT	1
583487	583485	19735D	PARTICIPANT	\N	PRESENT	1
583488	583485	14229S	PARTICIPANT	\N	PRESENT	1
583490	583489	14229S	PARTICIPANT	\N	PRESENT	1
583491	583489	19735D	PARTICIPANT	\N	PRESENT	1
585768	585767	20144B	PARTICIPANT	\N	PRESENT	0
585769	585767	20028X	PARTICIPANT	\N	PRESENT	0
585772	585770	20028X	PARTICIPANT	\N	PRESENT	0
585773	585770	14357A	PARTICIPANT	\N	PRESENT	0
585774	585770	20174H	PARTICIPANT	\N	PRESENT	0
585775	585770	20030R	PARTICIPANT	\N	PRESENT	0
585776	585770	19631V	PARTICIPANT	\N	PRESENT	0
585778	585777	20144B	PARTICIPANT	\N	PRESENT	0
585779	585777	14033T	PARTICIPANT	\N	PRESENT	0
585780	585777	20030R	PARTICIPANT	\N	PRESENT	0
585781	585777	19631V	PARTICIPANT	\N	PRESENT	0
585782	585777	20028X	PARTICIPANT	\N	PRESENT	0
585783	585777	20092G	PARTICIPANT	\N	PRESENT	0
585784	585777	20174H	PARTICIPANT	\N	PRESENT	0
585786	585785	20144B	PARTICIPANT	\N	PRESENT	0
585787	585785	14033T	PARTICIPANT	\N	PRESENT	0
585788	585785	20030R	PARTICIPANT	\N	PRESENT	0
585789	585785	19631V	PARTICIPANT	\N	PRESENT	0
585790	585785	20028X	PARTICIPANT	\N	PRESENT	0
585791	585785	20092G	PARTICIPANT	\N	PRESENT	0
585792	585785	20174H	PARTICIPANT	\N	PRESENT	0
585794	585793	20144B	PARTICIPANT	\N	PRESENT	0
585795	585793	14033T	PARTICIPANT	\N	PRESENT	0
585796	585793	20174H	PARTICIPANT	\N	PRESENT	0
585797	585793	20092G	PARTICIPANT	\N	PRESENT	0
585799	585798	20144B	PARTICIPANT	\N	PRESENT	0
585801	585800	20144B	PARTICIPANT	\N	PRESENT	0
585802	585800	20092G	PARTICIPANT	\N	PRESENT	0
585804	585803	20144B	PARTICIPANT	\N	PRESENT	0
585805	585803	20092G	PARTICIPANT	\N	PRESENT	0
585807	585806	19347U	PARTICIPANT	\N	PRESENT	0
585809	585808	19347U	PARTICIPANT	\N	PRESENT	0
585812	585811	05008E	PARTICIPANT	\N	PRESENT	0
585813	585811	11053K	PARTICIPANT	\N	PRESENT	0
585814	585811	01028R	PARTICIPANT	\N	PRESENT	0
585817	585816	19709B	PARTICIPANT	\N	PRESENT	0
585819	585818	19709B	PARTICIPANT	\N	PRESENT	0
585820	585818	11041F	PARTICIPANT	\N	PRESENT	0
585822	585821	04047H	PARTICIPANT	\N	PRESENT	0
585823	585821	20108W	PARTICIPANT	\N	PRESENT	0
585824	585821	11072N	PARTICIPANT	\N	PRESENT	0
585827	585571	20134Y	PARTICIPANT	\N	PRESENT	0
585828	585571	20036X	PARTICIPANT	\N	PRESENT	0
587017	585691	20252E	PARTICIPANT	\N	PRESENT	0
587018	585691	19507S	PARTICIPANT	\N	PRESENT	0
587019	585691	14207L	PARTICIPANT	\N	PRESENT	0
587020	585691	19747H	PARTICIPANT	\N	PRESENT	0
587021	585691	14257W	PARTICIPANT	\N	PRESENT	0
588441	588440	14193X	PARTICIPANT	\N	PRESENT	0
588442	588440	11027H	PARTICIPANT	\N	PRESENT	0
588444	588443	19447X	PARTICIPANT	\N	PRESENT	0
582859	582631	95063L	PARTICIPANT	\N	PRESENT	0
582860	582631	14041T	PARTICIPANT	\N	PRESENT	0
582861	582631	14147R	PARTICIPANT	\N	PRESENT	0
582862	582631	14151M	PARTICIPANT	\N	PRESENT	0
582863	582631	14215L	PRESIDENT	0	PRESENT	0
582864	582631	08018U	PARTICIPANT	\N	PRESENT	0
582865	582631	19749K	PARTICIPANT	\N	PRESENT	0
582866	582631	14111D	PARTICIPANT	\N	EXCUSE	0
582867	582631	20108W	PARTICIPANT	\N	EXCUSE	0
582868	582631	04047H	PARTICIPANT	\N	EXCUSE	0
582869	582631	11072N	PARTICIPANT	\N	EXCUSE	0
582925	582629	19611R	PARTICIPANT	\N	PRESENT	0
582926	582629	19369B	PARTICIPANT	\N	PRESENT	0
582927	582629	19749K	PARTICIPANT	\N	PRESENT	0
582928	582629	01024M	PARTICIPANT	\N	PRESENT	0
582929	582629	14275Y	PARTICIPANT	\N	PRESENT	0
582930	582629	19415P	PARTICIPANT	\N	PRESENT	0
582931	582629	20124W	PARTICIPANT	\N	PRESENT	0
582935	582629	97011G	PARTICIPANT	\N	PRESENT	0
582933	582629	20024T	PARTICIPANT	\N	PRESENT	0
582934	582629	20062A	PARTICIPANT	\N	PRESENT	0
582936	582629	20020P	PARTICIPANT	\N	PRESENT	0
582937	582629	10006L	PARTICIPANT	\N	PRESENT	0
582938	582629	14217N	PARTICIPANT	\N	PRESENT	0
582939	582629	01058X	PARTICIPANT	\N	PRESENT	0
582940	582629	19729F	PARTICIPANT	\N	PRESENT	0
582941	582629	20148F	PARTICIPANT	\N	PRESENT	0
582942	582629	14147R	PARTICIPANT	\N	PRESENT	0
582943	582629	19711U	PARTICIPANT	\N	PRESENT	0
582944	582629	86034E	PARTICIPANT	\N	PRESENT	0
582945	582629	99004R	PARTICIPANT	\N	PRESENT	0
582946	582629	19399H	PARTICIPANT	\N	PRESENT	0
582947	582629	19443T	PARTICIPANT	\N	PRESENT	0
582948	582629	14041T	PARTICIPANT	\N	PRESENT	0
582949	582629	08047A	PARTICIPANT	\N	PRESENT	0
582950	582629	14038Y	PARTICIPANT	\N	PRESENT	0
582951	582629	20032T	PARTICIPANT	\N	PRESENT	0
582952	582629	20180F	PARTICIPANT	\N	PRESENT	0
582953	582629	20056C	PARTICIPANT	\N	PRESENT	0
582954	582629	19673G	PARTICIPANT	\N	PRESENT	0
582955	582629	19515S	PARTICIPANT	\N	PRESENT	0
582956	582629	19679N	PARTICIPANT	\N	PRESENT	0
582957	582629	14215L	PARTICIPANT	\N	PRESENT	0
582958	582629	05008E	PARTICIPANT	\N	PRESENT	0
582959	582629	19593H	PARTICIPANT	\N	PRESENT	0
582960	582629	11090Q	PARTICIPANT	\N	PRESENT	0
582961	582629	16685X	PARTICIPANT	\N	PRESENT	0
582962	582629	14069U	PARTICIPANT	\N	PRESENT	0
582963	582629	19543W	PARTICIPANT	\N	PRESENT	0
582964	582629	01060R	PARTICIPANT	\N	PRESENT	0
582965	582629	20252E	PARTICIPANT	\N	PRESENT	0
582966	582629	11027H	PARTICIPANT	\N	PRESENT	0
582967	582629	19347U	PARTICIPANT	\N	PRESENT	0
582968	582629	08069G	PARTICIPANT	\N	PRESENT	0
582969	582629	20152B	PARTICIPANT	\N	PRESENT	0
582970	582629	04042C	PARTICIPANT	\N	PRESENT	0
582971	582629	11066Q	PARTICIPANT	\N	PRESENT	0
582972	582629	19573D	PARTICIPANT	\N	PRESENT	0
582973	582629	04033B	PARTICIPANT	\N	PRESENT	0
582974	582629	19591F	PARTICIPANT	\N	PRESENT	0
582975	582629	14205J	PARTICIPANT	\N	PRESENT	0
582976	582629	14026U	PARTICIPANT	\N	PRESENT	0
582977	582629	20086J	PARTICIPANT	\N	PRESENT	0
582978	582629	11097X	PARTICIPANT	\N	PRESENT	0
582979	582629	14089Y	PARTICIPANT	\N	PRESENT	0
582980	582629	19387D	PARTICIPANT	\N	PRESENT	0
582981	582629	20100N	PARTICIPANT	\N	PRESENT	0
582982	582629	14259Y	PARTICIPANT	\N	PRESENT	0
582983	582629	11048N	PARTICIPANT	\N	PRESENT	0
582984	582629	11045K	PARTICIPANT	\N	PRESENT	0
583053	582630	19295A	PARTICIPANT	\N	PRESENT	0
583049	582630	19443T	PARTICIPANT	\N	PRESENT	0
583050	582630	20252E	PARTICIPANT	\N	PRESENT	0
583051	582630	20102Q	PARTICIPANT	\N	PRESENT	0
583052	582630	19593H	PARTICIPANT	\N	PRESENT	0
583054	582630	20142Y	PARTICIPANT	\N	PRESENT	0
583055	582630	12016W	PARTICIPANT	\N	PRESENT	0
583056	582630	11066Q	PARTICIPANT	\N	PRESENT	0
583057	582630	20130U	PARTICIPANT	\N	PRESENT	0
583058	582630	04085P	PARTICIPANT	\N	PRESENT	0
583059	582630	19683J	PARTICIPANT	\N	PRESENT	0
583060	582630	20100N	PARTICIPANT	\N	PRESENT	0
583061	582630	20086J	PARTICIPANT	\N	PRESENT	0
583062	582630	19415P	PARTICIPANT	\N	PRESENT	0
583063	582630	19479G	PARTICIPANT	\N	PRESENT	0
583064	582630	11054L	PARTICIPANT	\N	PRESENT	0
583065	582630	08073C	PARTICIPANT	\N	PRESENT	0
583069	582630	14275Y	PARTICIPANT	\N	PRESENT	0
583067	582630	20092G	PARTICIPANT	\N	PRESENT	0
583068	582630	19301E	PARTICIPANT	\N	PRESENT	0
583070	582630	14219Q	PARTICIPANT	\N	PRESENT	0
583071	582630	14042U	PARTICIPANT	\N	PRESENT	0
583072	582630	19333N	PARTICIPANT	\N	PRESENT	0
583073	582630	11097X	PARTICIPANT	\N	PRESENT	0
583074	582630	20180F	PARTICIPANT	\N	PRESENT	0
583075	582630	11064N	PARTICIPANT	\N	PRESENT	0
583076	582630	11080N	PARTICIPANT	\N	PRESENT	0
583077	582630	14041T	PARTICIPANT	\N	PRESENT	0
583078	582630	20032T	PARTICIPANT	\N	PRESENT	0
583079	582630	19515S	PARTICIPANT	\N	PRESENT	0
583538	583525	19415P	PARTICIPANT	\N	PRESENT	0
583081	582630	16685X	PARTICIPANT	\N	PRESENT	0
583082	582630	19369B	PARTICIPANT	\N	PRESENT	0
583083	582630	19758L	PARTICIPANT	\N	PRESENT	0
583084	582630	19695N	PARTICIPANT	\N	PRESENT	0
583085	582630	11077T	PARTICIPANT	\N	PRESENT	0
583086	582630	19711U	PARTICIPANT	\N	PRESENT	0
583087	582630	11031D	PARTICIPANT	\N	PRESENT	0
583088	582630	01058X	PARTICIPANT	\N	PRESENT	0
583089	582630	11040E	PARTICIPANT	\N	PRESENT	0
583090	582630	19679N	PARTICIPANT	\N	PRESENT	0
583091	582630	14257W	PARTICIPANT	\N	PRESENT	0
583092	582630	14069U	PARTICIPANT	\N	PRESENT	0
583093	582630	11090Q	PARTICIPANT	\N	PRESENT	0
583094	582630	14026U	PARTICIPANT	\N	PRESENT	0
583095	582630	04033B	PARTICIPANT	\N	PRESENT	0
583096	582630	14151M	PARTICIPANT	\N	PRESENT	0
583097	582630	19649G	PARTICIPANT	\N	PRESENT	0
583098	582630	10006L	PARTICIPANT	\N	PRESENT	0
583540	583526	19415P	PARTICIPANT	\N	PRESENT	0
583100	582630	19527W	PARTICIPANT	\N	PRESENT	0
583539	583525	11067R	PARTICIPANT	\N	PRESENT	0
583541	583526	11067R	PARTICIPANT	\N	PRESENT	0
583542	583527	19415P	PARTICIPANT	\N	PRESENT	0
583543	583527	11067R	PARTICIPANT	\N	PRESENT	0
583544	583528	19415P	PARTICIPANT	\N	PRESENT	0
583545	583528	10006L	PARTICIPANT	\N	PRESENT	0
583546	583528	11067R	PARTICIPANT	\N	PRESENT	0
583548	583547	19415P	PARTICIPANT	\N	PRESENT	0
583549	583547	11067R	PARTICIPANT	\N	PRESENT	0
583550	583529	19415P	PARTICIPANT	\N	PRESENT	0
583551	583530	19415P	PARTICIPANT	\N	PRESENT	0
583552	583524	20248J	PARTICIPANT	\N	PRESENT	0
583553	583524	20090E	PARTICIPANT	\N	PRESENT	0
583557	583524	20114U	PARTICIPANT	\N	PRESENT	0
583555	583524	19591F	PARTICIPANT	\N	PRESENT	0
583556	583524	19729F	PARTICIPANT	\N	PRESENT	0
583558	583531	19415P	PARTICIPANT	\N	PRESENT	0
583559	583531	20130U	PARTICIPANT	\N	PRESENT	0
583560	583532	19415P	PARTICIPANT	\N	PRESENT	0
583561	583532	11067R	PARTICIPANT	\N	PRESENT	0
583562	583532	20130U	PARTICIPANT	\N	PRESENT	0
583563	583533	19415P	PARTICIPANT	\N	PRESENT	0
583564	583533	11067R	PARTICIPANT	\N	PRESENT	0
583565	583533	20130U	PARTICIPANT	\N	PRESENT	0
583566	583537	19415P	PARTICIPANT	\N	PRESENT	0
583567	583537	11067R	PARTICIPANT	\N	PRESENT	0
583568	583534	19415P	PARTICIPANT	\N	PRESENT	0
583569	583534	11067R	PARTICIPANT	\N	PRESENT	0
583570	583534	20130U	PARTICIPANT	\N	PRESENT	0
583571	583535	19415P	PARTICIPANT	\N	PRESENT	0
583572	583535	11067R	PARTICIPANT	\N	PRESENT	0
583573	583535	20130U	PARTICIPANT	\N	PRESENT	0
583574	583536	19415P	PARTICIPANT	\N	PRESENT	0
583690	583689	14215L	PARTICIPANT	\N	PRESENT	0
584324	583470	11103C	PARTICIPANT	\N	PRESENT	1
584325	583470	04043D	PARTICIPANT	\N	PRESENT	1
584326	583470	19301E	PARTICIPANT	\N	PRESENT	1
584327	583470	19697Q	PARTICIPANT	\N	PRESENT	1
584328	583470	20130U	PARTICIPANT	\N	PRESENT	1
584329	583470	10006L	PRESIDENT	0	PRESENT	0
583468	583467	14329V	PARTICIPANT	\N	PRESENT	0
583472	583471	14193X	PARTICIPANT	\N	PRESENT	0
583473	583471	14267Y	PARTICIPANT	\N	PRESENT	0
583474	583471	19421M	PARTICIPANT	\N	PRESENT	0
585587	585586	14213J	PARTICIPANT	\N	PRESENT	1
585588	585586	20130U	PARTICIPANT	\N	PRESENT	1
585611	585570	20134Y	PARTICIPANT	\N	PRESENT	1
585613	585570	19399H	PARTICIPANT	\N	PRESENT	1
585614	585570	08012N	PARTICIPANT	\N	PRESENT	1
585620	585570	20036X	PARTICIPANT	\N	PRESENT	0
585624	585570	19699S	PARTICIPANT	\N	PRESENT	1
585832	585831	19651A	PARTICIPANT	\N	PRESENT	1
585833	585831	19735D	PARTICIPANT	\N	PRESENT	1
585834	585831	14229S	PARTICIPANT	\N	PRESENT	1
585838	585837	19735D	PARTICIPANT	\N	PRESENT	1
585958	585408	19531S	PARTICIPANT	\N	PRESENT	1
585959	585408	20126Y	PARTICIPANT	\N	PRESENT	1
585960	585408	14331P	PARTICIPANT	\N	PRESENT	1
598972	598074	19333N	PARTICIPANT	\N	PRESENT	0
598973	598074	20056C	PARTICIPANT	\N	PRESENT	0
598974	598074	04033B	PARTICIPANT	\N	PRESENT	0
598975	598074	14038Y	PARTICIPANT	\N	PRESENT	0
598976	598074	20054A	PARTICIPANT	\N	PRESENT	0
598977	598074	20044X	PARTICIPANT	\N	PRESENT	0
598978	598074	20180F	PARTICIPANT	\N	PRESENT	0
598979	598074	20058E	PARTICIPANT	\N	PRESENT	0
598980	598074	20024T	PARTICIPANT	\N	PRESENT	0
598981	598074	20136B	PARTICIPANT	\N	PRESENT	0
599010	598074	11012A	PARTICIPANT	\N	PRESENT	0
598983	598074	19367Y	PARTICIPANT	\N	PRESENT	0
598988	598017	01048V	PARTICIPANT	\N	PRESENT	0
598985	598017	11070L	PARTICIPANT	\N	PRESENT	0
598986	598074	19507S	PARTICIPANT	\N	PRESENT	0
598987	598074	20030R	PARTICIPANT	\N	PRESENT	0
598989	598074	08009T	PARTICIPANT	\N	PRESENT	0
598990	598074	20076G	PARTICIPANT	\N	PRESENT	0
598991	598074	11033F	PARTICIPANT	\N	PRESENT	0
598992	598074	11065P	PARTICIPANT	\N	PRESENT	0
598993	598074	19515S	PARTICIPANT	\N	PRESENT	0
598995	598074	19565D	PARTICIPANT	\N	PRESENT	0
598996	598994	11027H	PARTICIPANT	\N	PRESENT	0
598997	598994	14193X	PARTICIPANT	\N	PRESENT	0
598999	598998	11027H	PARTICIPANT	\N	PRESENT	0
599000	598998	14193X	PARTICIPANT	\N	PRESENT	0
599001	598074	11026G	PARTICIPANT	\N	PRESENT	0
599003	599002	11027H	PARTICIPANT	\N	PRESENT	0
599004	599002	14193X	PARTICIPANT	\N	PRESENT	0
599005	598074	20078J	PARTICIPANT	\N	PRESENT	0
599006	598074	20062A	PARTICIPANT	\N	PRESENT	0
599007	598074	14189C	PARTICIPANT	\N	PRESENT	0
599008	598074	19745F	PARTICIPANT	\N	PRESENT	0
599009	598074	97011G	PARTICIPANT	\N	PRESENT	0
599011	598074	20026V	PARTICIPANT	\N	PRESENT	0
599012	598074	01024M	PARTICIPANT	\N	PRESENT	0
599013	598074	01025N	PARTICIPANT	\N	PRESENT	0
599014	598074	14231L	PARTICIPANT	\N	PRESENT	0
598970	598074	19447X	PARTICIPANT	\N	PRESENT	0
599015	598074	14026U	PARTICIPANT	\N	PRESENT	0
599016	598074	19443T	PARTICIPANT	\N	PRESENT	0
599017	598074	20032T	PARTICIPANT	\N	PRESENT	0
599018	598074	14267Y	PARTICIPANT	\N	PRESENT	0
599019	598074	14121F	PARTICIPANT	\N	PRESENT	0
599020	598074	08010L	PARTICIPANT	\N	PRESENT	0
599021	598017	11053K	PARTICIPANT	\N	PRESENT	0
599022	598017	19349W	PARTICIPANT	\N	PRESENT	0
599023	598074	19713W	PARTICIPANT	\N	PRESENT	0
599024	598074	19760E	PARTICIPANT	\N	PRESENT	0
599025	598074	20096L	PARTICIPANT	\N	PRESENT	0
599026	597710	14001X	PARTICIPANT	\N	PRESENT	0
599027	597710	19585H	PARTICIPANT	\N	PRESENT	0
599028	597710	04047H	PRESIDENT	0	PRESENT	0
599029	597710	19675J	PARTICIPANT	\N	PRESENT	0
599030	597710	01028R	PARTICIPANT	\N	PRESENT	0
599031	597710	19447X	PARTICIPANT	\N	PRESENT	0
599032	597710	14231L	PARTICIPANT	\N	PRESENT	0
599033	597710	19725B	PARTICIPANT	\N	PRESENT	0
599034	597710	11056N	PARTICIPANT	\N	PRESENT	0
599035	597710	19629C	PARTICIPANT	\N	PRESENT	0
599036	597710	20108W	PARTICIPANT	\N	PRESENT	0
599037	597710	20110Q	PARTICIPANT	\N	PRESENT	0
599038	597710	14147R	PARTICIPANT	\N	PRESENT	0
599039	597710	14151M	PARTICIPANT	\N	PRESENT	0
599040	597710	14215L	PARTICIPANT	\N	PRESENT	0
599041	597710	14021P	PARTICIPANT	\N	PRESENT	0
599042	598074	20118Y	PARTICIPANT	\N	PRESENT	0
599043	598074	19413M	PARTICIPANT	\N	PRESENT	0
599044	598074	20108W	PARTICIPANT	\N	PRESENT	0
599045	598074	19762G	PARTICIPANT	\N	PRESENT	0
599046	598074	20104S	PARTICIPANT	\N	PRESENT	0
599047	598074	19569H	PARTICIPANT	\N	PRESENT	0
599048	598074	14215L	PARTICIPANT	\N	PRESENT	0
599049	598074	14069U	PARTICIPANT	\N	PRESENT	0
599050	598074	19725B	PARTICIPANT	\N	PRESENT	0
599051	598074	11056N	PARTICIPANT	\N	PRESENT	0
599052	598074	19798U	PARTICIPANT	\N	PRESENT	0
599053	598074	20252E	PARTICIPANT	\N	PRESENT	0
599054	598074	19251M	PARTICIPANT	\N	PRESENT	0
599055	598074	19703U	PARTICIPANT	\N	PRESENT	0
599056	598074	19479G	PARTICIPANT	\N	PRESENT	0
599057	598074	14030Q	PARTICIPANT	\N	PRESENT	0
599058	598074	11099A	PARTICIPANT	\N	PRESENT	0
599059	598074	20052X	PARTICIPANT	\N	PRESENT	0
599060	598074	14073Q	PARTICIPANT	\N	PRESENT	0
599061	598074	19758L	PARTICIPANT	\N	PRESENT	0
599062	598074	19563B	PARTICIPANT	\N	PRESENT	0
599063	598074	19399H	PARTICIPANT	\N	PRESENT	0
599065	599064	20050V	PARTICIPANT	\N	PRESENT	0
599067	599066	20252E	PARTICIPANT	\N	PRESENT	0
599069	599068	14331P	PARTICIPANT	\N	PRESENT	0
599071	599070	14331P	PARTICIPANT	\N	PRESENT	0
599073	599072	14331P	PARTICIPANT	\N	PRESENT	0
599075	599074	08034U	PARTICIPANT	\N	PRESENT	0
599077	599076	08009T	PARTICIPANT	\N	PRESENT	0
599078	599076	20044X	PARTICIPANT	\N	PRESENT	0
599080	599079	19399H	PARTICIPANT	\N	PRESENT	0
599081	599079	20132W	PARTICIPANT	\N	PRESENT	0
599082	599079	20084G	PARTICIPANT	\N	PRESENT	0
599083	599079	04070G	PARTICIPANT	\N	PRESENT	0
599084	597710	08018U	PARTICIPANT	\N	EXCUSE	0
599085	597710	19729F	PARTICIPANT	\N	EXCUSE	0
599086	597324	19697Q	PARTICIPANT	\N	PRESENT	0
599087	597324	11067R	PARTICIPANT	\N	PRESENT	0
599088	597324	20090E	PARTICIPANT	\N	PRESENT	0
599089	597324	19569H	PARTICIPANT	\N	PRESENT	0
599090	597324	19798U	PARTICIPANT	\N	PRESENT	0
599091	597324	11097X	PARTICIPANT	\N	PRESENT	0
599092	597324	18193Q	PARTICIPANT	\N	PRESENT	0
599093	597324	11031D	PARTICIPANT	\N	PRESENT	0
599094	597324	19703U	PARTICIPANT	\N	PRESENT	0
599095	597324	19553Y	PARTICIPANT	\N	PRESENT	0
599096	597324	14042U	PARTICIPANT	\N	PRESENT	0
599097	597324	14195A	PARTICIPANT	\N	PRESENT	0
599098	597324	19367Y	PARTICIPANT	\N	PRESENT	0
599099	597324	14213J	PARTICIPANT	\N	PRESENT	0
599100	597324	19683J	PARTICIPANT	\N	PRESENT	0
599101	597324	10006L	PRESIDENT	0	PRESENT	0
599102	597324	20130U	PARTICIPANT	\N	PRESENT	0
599103	597324	04092N	PARTICIPANT	\N	PRESENT	0
599104	597324	19713W	PARTICIPANT	\N	PRESENT	0
599105	597324	08045X	PARTICIPANT	\N	PRESENT	0
599106	597324	20040T	PARTICIPANT	\N	PRESENT	0
599107	597324	17965H	PARTICIPANT	\N	PRESENT	0
599108	597324	19301E	PARTICIPANT	\N	PRESENT	0
599109	597324	19691J	PARTICIPANT	\N	PRESENT	0
599110	597324	20148F	PARTICIPANT	\N	PRESENT	0
599111	597324	20172F	PARTICIPANT	\N	PRESENT	0
599112	597324	19723Y	PARTICIPANT	\N	PRESENT	0
599113	597324	20248J	PARTICIPANT	\N	PRESENT	0
599114	597324	20066E	PARTICIPANT	\N	PRESENT	0
599115	597324	11103C	PARTICIPANT	\N	PRESENT	0
599116	597324	19657G	PARTICIPANT	\N	PRESENT	0
599117	597324	14071N	PARTICIPANT	\N	PRESENT	0
599118	597324	04043D	PARTICIPANT	\N	PRESENT	0
599119	597324	19760E	PARTICIPANT	\N	PRESENT	0
599121	599120	11053K	PARTICIPANT	\N	PRESENT	0
599123	599122	11053K	PARTICIPANT	\N	PRESENT	0
599124	597713	14111D	PARTICIPANT	\N	PRESENT	0
599125	597713	19629C	PARTICIPANT	\N	PRESENT	0
599126	597713	20108W	PARTICIPANT	\N	PRESENT	0
599127	597713	19581D	PARTICIPANT	\N	PRESENT	0
599128	597713	19585H	PARTICIPANT	\N	PRESENT	0
577606	575271	14179A	PARTICIPANT	\N	PRESENT	0
577607	575271	20128B	PARTICIPANT	\N	PRESENT	0
577608	575271	20068G	PARTICIPANT	\N	PRESENT	0
577609	575271	01057W	PARTICIPANT	\N	PRESENT	0
577610	575271	14123H	PARTICIPANT	\N	PRESENT	0
577611	575271	19347U	PARTICIPANT	\N	PRESENT	0
577612	575271	19820Y	PARTICIPANT	\N	PRESENT	0
577613	575271	19695N	PARTICIPANT	\N	PRESENT	0
577614	575271	20066E	PARTICIPANT	\N	PRESENT	0
577615	575271	19715Y	PARTICIPANT	\N	PRESENT	0
577616	575271	19531S	PARTICIPANT	\N	PRESENT	0
577617	575271	19447X	PARTICIPANT	\N	PRESENT	0
577618	575271	20102Q	PARTICIPANT	\N	PRESENT	0
577619	575271	07029T	PARTICIPANT	\N	PRESENT	0
577620	575271	19699S	PARTICIPANT	\N	PRESENT	0
577621	575271	16685X	PARTICIPANT	\N	PRESENT	0
577622	575271	19563B	PARTICIPANT	\N	PRESENT	0
577623	575271	11085T	PARTICIPANT	\N	PRESENT	0
577624	575271	20142Y	PARTICIPANT	\N	PRESENT	0
577625	575271	14031R	PARTICIPANT	\N	PRESENT	0
577626	575271	19657G	PARTICIPANT	\N	PRESENT	0
577627	575271	12016W	PARTICIPANT	\N	PRESENT	0
577628	575271	19441R	PARTICIPANT	\N	PRESENT	0
577629	575271	14219Q	PARTICIPANT	\N	PRESENT	0
577630	575271	20052X	PARTICIPANT	\N	PRESENT	0
577631	575271	08010L	PARTICIPANT	\N	PRESENT	0
577632	575271	11067R	PARTICIPANT	\N	PRESENT	0
577633	575271	20018V	PARTICIPANT	\N	PRESENT	0
577634	575271	19335Q	PARTICIPANT	\N	PRESENT	0
577635	575271	19369B	PARTICIPANT	\N	PRESENT	0
577636	575271	11072N	PARTICIPANT	\N	PRESENT	0
577637	575271	19768N	PARTICIPANT	\N	PRESENT	0
577638	575271	20044X	PARTICIPANT	\N	PRESENT	0
577639	575271	20092G	PARTICIPANT	\N	PRESENT	0
577640	575271	20020P	PARTICIPANT	\N	PRESENT	0
577641	575271	95063L	PARTICIPANT	\N	PRESENT	0
577642	575271	10015M	PARTICIPANT	\N	PRESENT	0
577643	575271	20082E	PARTICIPANT	\N	PRESENT	0
577644	575271	14225N	PARTICIPANT	\N	PRESENT	0
577645	575271	11090Q	PARTICIPANT	\N	PRESENT	0
577646	575271	11097X	PARTICIPANT	\N	PRESENT	0
577647	575271	19762G	PARTICIPANT	\N	PRESENT	0
577648	575271	20062A	PARTICIPANT	\N	PRESENT	0
577649	575271	20084G	PARTICIPANT	\N	PRESENT	0
577650	575271	19689Q	PARTICIPANT	\N	PRESENT	0
577651	575271	20064C	PARTICIPANT	\N	PRESENT	0
577652	575271	20046A	PARTICIPANT	\N	PRESENT	0
577653	575271	19749K	PARTICIPANT	\N	PRESENT	0
577654	575271	20058E	PARTICIPANT	\N	PRESENT	0
577763	575272	19719D	PARTICIPANT	\N	PRESENT	0
577764	575272	11056N	PARTICIPANT	\N	PRESENT	0
577765	575272	19715Y	PARTICIPANT	\N	PRESENT	0
577766	575272	19563B	PARTICIPANT	\N	PRESENT	0
577767	575272	10015M	PARTICIPANT	\N	PRESENT	0
577768	575272	14001X	PARTICIPANT	\N	PRESENT	0
577769	575272	19758L	PARTICIPANT	\N	PRESENT	0
577770	575272	20120S	PARTICIPANT	\N	PRESENT	0
577771	575272	20152B	PARTICIPANT	\N	PRESENT	0
577773	575272	19489J	PARTICIPANT	\N	PRESENT	0
577774	575272	19333N	PARTICIPANT	\N	PRESENT	0
577775	575272	20082E	PARTICIPANT	\N	PRESENT	0
577776	575272	19531S	PARTICIPANT	\N	PRESENT	0
577777	575272	19251M	PARTICIPANT	\N	PRESENT	0
577778	575272	19347U	PARTICIPANT	\N	PRESENT	0
577779	575272	20092G	PARTICIPANT	\N	PRESENT	0
577780	575272	20174H	PARTICIPANT	\N	PRESENT	0
577781	575272	20110Q	PARTICIPANT	\N	PRESENT	0
577782	575272	14327T	PARTICIPANT	\N	PRESENT	0
577783	575272	19533U	PARTICIPANT	\N	PRESENT	0
577784	575272	20124W	PARTICIPANT	\N	PRESENT	0
577785	575272	20062A	PARTICIPANT	\N	PRESENT	0
577786	575272	20020P	PARTICIPANT	\N	PRESENT	0
577787	575272	14357A	PARTICIPANT	\N	PRESENT	0
577788	575272	11097X	PARTICIPANT	\N	PRESENT	0
577789	575272	18083K	PARTICIPANT	\N	PRESENT	0
577790	575272	17367Q	PARTICIPANT	\N	PRESENT	0
577791	575272	19447X	PARTICIPANT	\N	PRESENT	0
577792	575272	14038Y	PARTICIPANT	\N	PRESENT	0
577793	575272	20058E	PARTICIPANT	\N	PRESENT	0
577794	575272	20100N	PARTICIPANT	\N	PRESENT	0
577795	575272	04085P	PARTICIPANT	\N	PRESENT	0
577796	575272	19820Y	PARTICIPANT	\N	PRESENT	0
577798	575272	19387D	PARTICIPANT	\N	PRESENT	0
577800	575272	14329V	PARTICIPANT	\N	PRESENT	0
577801	575272	20044X	PARTICIPANT	\N	PRESENT	0
577814	575272	19749K	PARTICIPANT	\N	PRESENT	0
577815	575272	19611R	PARTICIPANT	\N	PRESENT	0
577817	575272	19507S	PARTICIPANT	\N	PRESENT	0
577820	575272	20026V	PARTICIPANT	\N	PRESENT	0
577822	575272	14187A	PARTICIPANT	\N	PRESENT	0
577824	575272	19701S	PARTICIPANT	\N	PRESENT	0
577826	575272	19693L	PARTICIPANT	\N	PRESENT	0
577827	575272	19575F	PARTICIPANT	\N	PRESENT	0
577828	575272	19515S	PARTICIPANT	\N	PRESENT	0
577901	575272	11101A	PARTICIPANT	\N	PRESENT	0
577902	575272	20036X	PARTICIPANT	\N	PRESENT	0
577903	575272	19695N	PARTICIPANT	\N	PRESENT	0
577904	575272	14229S	PARTICIPANT	\N	PRESENT	0
577905	575272	19599P	PARTICIPANT	\N	PRESENT	0
577906	575272	05012A	PARTICIPANT	\N	PRESENT	0
577907	575272	01048V	PARTICIPANT	\N	PRESENT	0
577908	575224	19687N	PARTICIPANT	\N	PRESENT	0
577928	575272	20034V	PARTICIPANT	\N	PRESENT	0
577910	575224	19551W	PARTICIPANT	\N	PRESENT	0
577911	575272	11067R	PARTICIPANT	\N	PRESENT	0
577912	575272	11065P	PARTICIPANT	\N	PRESENT	0
577913	575272	08010L	PARTICIPANT	\N	PRESENT	0
577918	575272	19621T	PARTICIPANT	\N	PRESENT	0
577919	575272	19683J	PARTICIPANT	\N	PRESENT	0
577925	575224	19545Y	PARTICIPANT	\N	EXCUSE	0
577926	575272	19629C	PARTICIPANT	\N	PRESENT	0
577927	575272	07004J	PARTICIPANT	\N	PRESENT	0
577929	575272	17023S	PARTICIPANT	\N	PRESENT	0
577954	575272	19657G	PARTICIPANT	\N	PRESENT	0
577961	575272	14083S	PARTICIPANT	\N	PRESENT	0
577962	575272	19503N	PARTICIPANT	\N	PRESENT	0
577963	575272	11072N	PARTICIPANT	\N	PRESENT	0
577966	575272	19631V	PARTICIPANT	\N	PRESENT	0
577976	575272	19717B	PARTICIPANT	\N	PRESENT	0
577981	575272	11085T	PARTICIPANT	\N	PRESENT	0
577982	575272	19671E	PARTICIPANT	\N	PRESENT	0
577983	575272	17637T	PARTICIPANT	\N	PRESENT	0
577984	575272	95041E	PARTICIPANT	\N	PRESENT	0
577985	575272	99004R	PARTICIPANT	\N	PRESENT	0
577987	575272	19689Q	PARTICIPANT	\N	PRESENT	0
577988	575272	20066E	PARTICIPANT	\N	PRESENT	0
577990	575272	14169X	PARTICIPANT	\N	PRESENT	0
578011	575272	14021P	PARTICIPANT	\N	PRESENT	0
578012	575272	14089Y	PARTICIPANT	\N	PRESENT	0
578059	575273	11070L	PARTICIPANT	\N	PRESENT	0
578076	575273	19489J	PARTICIPANT	\N	PRESENT	0
578077	575273	14001X	PARTICIPANT	\N	PRESENT	0
578081	575273	14259Y	PARTICIPANT	\N	PRESENT	0
578079	575273	19629C	PARTICIPANT	\N	PRESENT	0
578080	575273	19399H	PARTICIPANT	\N	PRESENT	0
578082	575273	95041E	PARTICIPANT	\N	PRESENT	0
578083	575273	20034V	PARTICIPANT	\N	PRESENT	0
578084	575273	20110Q	PARTICIPANT	\N	PRESENT	0
578085	575273	19599P	PARTICIPANT	\N	PRESENT	0
578086	575273	19563B	PARTICIPANT	\N	PRESENT	0
578087	575273	19631V	PARTICIPANT	\N	PRESENT	0
578088	575273	14083S	PARTICIPANT	\N	PRESENT	0
578089	575273	20124W	PARTICIPANT	\N	PRESENT	0
578090	575273	11056N	PARTICIPANT	\N	PRESENT	0
578091	575273	17367Q	PARTICIPANT	\N	PRESENT	0
578092	575273	14169X	PARTICIPANT	\N	PRESENT	0
578093	575273	14215L	PARTICIPANT	\N	PRESENT	0
578094	575273	19671E	PARTICIPANT	\N	PRESENT	0
578095	575273	04047H	PARTICIPANT	\N	PRESENT	0
578096	575273	20046A	PARTICIPANT	\N	PRESENT	0
578097	575273	95063L	PARTICIPANT	\N	PRESENT	0
578098	575273	14329V	PARTICIPANT	\N	PRESENT	0
578099	575273	20026V	PARTICIPANT	\N	PRESENT	0
578100	575273	14187A	PARTICIPANT	\N	PRESENT	0
578101	575273	14231L	PARTICIPANT	\N	PRESENT	0
577761	575272	08073C	PARTICIPANT	\N	PRESENT	0
577762	575272	20090E	PARTICIPANT	\N	PRESENT	0
578102	575273	19335Q	PARTICIPANT	\N	PRESENT	0
578103	575273	20062A	PARTICIPANT	\N	PRESENT	0
578104	575273	01028R	PARTICIPANT	\N	PRESENT	0
578105	575273	01048V	PARTICIPANT	\N	PRESENT	0
578988	578987	05008E	PARTICIPANT	\N	PRESENT	0
578989	578987	11053K	PARTICIPANT	\N	PRESENT	0
578990	578987	14357A	PARTICIPANT	\N	PRESENT	0
578991	578987	11070L	PARTICIPANT	\N	PRESENT	0
578992	578987	19719D	PARTICIPANT	\N	PRESENT	0
578993	578987	19673G	PARTICIPANT	\N	PRESENT	0
578994	578987	01025N	PARTICIPANT	\N	PRESENT	0
578995	578987	19599P	PARTICIPANT	\N	PRESENT	0
578996	578987	14033T	PARTICIPANT	\N	PRESENT	0
578997	578987	14123H	PARTICIPANT	\N	PRESENT	0
578998	578987	14026U	PARTICIPANT	\N	PRESENT	0
578999	578987	14179A	PARTICIPANT	\N	PRESENT	0
579000	578987	14213J	PARTICIPANT	\N	PRESENT	0
579001	578987	99004R	PARTICIPANT	\N	PRESENT	0
579002	578987	86034E	PARTICIPANT	\N	PRESENT	0
579003	578987	12041X	PARTICIPANT	\N	PRESENT	0
579004	578987	01043Q	PARTICIPANT	\N	PRESENT	0
579005	578987	19413M	PARTICIPANT	\N	PRESENT	0
579007	578987	01028R	PARTICIPANT	\N	PRESENT	0
579008	578987	08073C	PARTICIPANT	\N	PRESENT	0
579009	578987	14147R	PARTICIPANT	\N	PRESENT	0
579050	578908	19545Y	PARTICIPANT	\N	EXCUSE	0
579051	578909	19545Y	PARTICIPANT	\N	EXCUSE	0
580578	579135	14053L	PARTICIPANT	\N	PRESENT	0
580579	579135	20074E	PARTICIPANT	\N	PRESENT	0
580580	579135	10015M	PARTICIPANT	\N	PRESENT	0
580581	579135	04047H	PRESIDENT	0	PRESENT	0
580582	579135	19673G	PARTICIPANT	\N	PRESENT	0
580583	579135	05008E	PARTICIPANT	\N	PRESENT	0
580584	579135	19725B	PARTICIPANT	\N	PRESENT	0
580585	579135	11056N	PARTICIPANT	\N	PRESENT	0
580586	579135	19489J	PARTICIPANT	\N	PRESENT	0
580587	579135	14107H	PARTICIPANT	\N	PRESENT	0
580588	579135	14041T	PARTICIPANT	\N	PRESENT	0
580589	579135	14147R	PARTICIPANT	\N	PRESENT	0
580590	579135	14215L	PRESIDENT	1	PRESENT	0
580591	579135	20128B	PARTICIPANT	\N	PRESENT	0
580592	579135	14021P	PARTICIPANT	\N	PRESENT	0
580593	579135	01028R	PARTICIPANT	\N	PRESENT	0
582114	579243	20066E	PARTICIPANT	\N	PRESENT	1
582115	579243	20090E	PARTICIPANT	\N	PRESENT	1
582116	579243	04057K	PARTICIPANT	\N	PRESENT	1
582117	579243	14213J	PARTICIPANT	\N	PRESENT	1
582118	579243	20248J	PARTICIPANT	\N	PRESENT	1
582119	579243	14355X	PARTICIPANT	\N	PRESENT	1
582120	579243	19569H	PARTICIPANT	\N	PRESENT	1
582121	579243	11031D	PARTICIPANT	\N	PRESENT	1
582122	579243	20172F	PARTICIPANT	\N	PRESENT	1
582123	579243	11067R	PARTICIPANT	\N	PRESENT	1
582124	579243	19798U	PARTICIPANT	\N	PRESENT	1
582125	579243	11097X	PARTICIPANT	\N	PRESENT	0
587022	585691	19383Y	PARTICIPANT	\N	PRESENT	0
587023	585691	14251Q	PARTICIPANT	\N	PRESENT	1
587024	585691	04045F	PARTICIPANT	\N	EXCUSE	0
587025	584138	05012A	PARTICIPANT	\N	PRESENT	0
587026	584138	19659J	PARTICIPANT	\N	PRESENT	0
587027	585691	11099A	PARTICIPANT	\N	PRESENT	1
587028	585411	01048V	PARTICIPANT	\N	PRESENT	0
587029	585411	20080C	PARTICIPANT	\N	PRESENT	0
587047	585411	04071H	PARTICIPANT	\N	PRESENT	0
587048	585411	20036X	PARTICIPANT	\N	PRESENT	0
587049	585411	19387D	PARTICIPANT	\N	PRESENT	0
587050	585411	20070A	PARTICIPANT	\N	PRESENT	0
587052	585411	19741B	PARTICIPANT	\N	PRESENT	0
587053	585411	11053K	PARTICIPANT	\N	PRESENT	0
587054	585715	19443T	PARTICIPANT	\N	PRESENT	0
587055	585715	19565D	PARTICIPANT	\N	PRESENT	0
587056	585715	20072C	PARTICIPANT	\N	PRESENT	0
587057	585715	04034C	PARTICIPANT	\N	PRESENT	0
587058	585715	01058X	PARTICIPANT	\N	PRESENT	0
587059	585715	16685X	PARTICIPANT	\N	PRESENT	0
587060	585715	04042C	PRESIDENT	0	PRESENT	0
587061	585715	11054L	PARTICIPANT	\N	PRESENT	0
587062	585715	11066Q	PARTICIPANT	\N	PRESENT	0
587063	585715	19669L	PARTICIPANT	\N	PRESENT	0
587064	585715	12028B	PARTICIPANT	\N	PRESENT	0
587065	585715	14055N	PARTICIPANT	\N	PRESENT	0
587066	585715	19421M	PARTICIPANT	\N	PRESENT	0
587067	585715	19709B	PARTICIPANT	\N	PRESENT	0
587068	585715	19347U	PARTICIPANT	\N	PRESENT	0
587069	585715	14193X	PARTICIPANT	\N	PRESENT	0
587070	585715	08061X	PARTICIPANT	\N	PRESENT	0
587071	585715	08047A	PARTICIPANT	\N	PRESENT	0
587072	585715	14097Y	PARTICIPANT	\N	PRESENT	0
587073	585715	14059S	PARTICIPANT	\N	PRESENT	0
587074	585715	04035D	PARTICIPANT	\N	PRESENT	0
587075	585715	01062T	PARTICIPANT	\N	PRESENT	0
587076	585715	14133K	PARTICIPANT	\N	PRESENT	0
587077	585715	08069G	PARTICIPANT	\N	PRESENT	0
587078	585715	20042V	PARTICIPANT	\N	PRESENT	0
587079	585715	01024M	PARTICIPANT	\N	PRESENT	0
587080	585715	14105F	PARTICIPANT	\N	PRESENT	0
587081	585715	20064C	PARTICIPANT	\N	PRESENT	0
587082	585715	98018T	PARTICIPANT	\N	PRESENT	0
587083	585715	14267Y	PARTICIPANT	\N	PRESENT	0
587084	585715	11064N	PARTICIPANT	\N	PRESENT	0
587085	585715	11083R	PARTICIPANT	\N	PRESENT	0
587086	585715	14211G	PARTICIPANT	\N	PRESENT	0
587087	585715	14255U	PARTICIPANT	\N	PRESENT	0
587088	585715	11027H	PARTICIPANT	\N	PRESENT	0
587094	585578	10006L	PARTICIPANT	\N	PRESENT	0
587095	585578	04092N	PARTICIPANT	\N	PRESENT	0
587096	585578	20040T	PARTICIPANT	\N	PRESENT	0
587097	585578	14021P	PARTICIPANT	\N	PRESENT	0
587098	585578	20090E	PARTICIPANT	\N	PRESENT	0
587099	585578	19415P	PARTICIPANT	\N	PRESENT	0
587100	585578	14223L	PARTICIPANT	\N	PRESENT	0
587101	585578	14231L	PARTICIPANT	\N	PRESENT	0
587102	585578	19703U	PARTICIPANT	\N	PRESENT	0
587103	585578	17737W	PARTICIPANT	\N	PRESENT	0
587104	585578	14195A	PARTICIPANT	\N	PRESENT	0
587105	585578	19367Y	PARTICIPANT	\N	PRESENT	0
587106	585578	14215L	PARTICIPANT	\N	PRESENT	0
587107	585578	17965H	PARTICIPANT	\N	PRESENT	0
587108	585578	11056N	PARTICIPANT	\N	PRESENT	0
587109	585578	95063L	PARTICIPANT	\N	PRESENT	0
587110	585578	11085T	PARTICIPANT	\N	PRESENT	0
587111	585411	19531S	PARTICIPANT	\N	PRESENT	0
587112	584138	11101A	PARTICIPANT	\N	PRESENT	0
587113	584138	20100N	PARTICIPANT	\N	EXCUSE	0
587116	584138	19739H	PARTICIPANT	\N	PRESENT	0
587133	585715	08056B	PARTICIPANT	\N	EXCUSE	0
587148	585579	14053L	PARTICIPANT	\N	PRESENT	0
587149	585579	14111D	PARTICIPANT	\N	PRESENT	0
587150	585579	20074E	PARTICIPANT	\N	PRESENT	0
587151	585579	10015M	PARTICIPANT	\N	PRESENT	0
587152	585579	11026G	PARTICIPANT	\N	PRESENT	0
587153	585579	04047H	PRESIDENT	0	PRESENT	0
587154	585579	01028R	PARTICIPANT	\N	PRESENT	0
587155	585579	05008E	PARTICIPANT	\N	PRESENT	0
587156	585579	19447X	PARTICIPANT	\N	PRESENT	0
587157	585579	14089Y	PARTICIPANT	\N	PRESENT	0
587158	585579	11056N	PARTICIPANT	\N	PRESENT	0
587159	585579	19729F	PARTICIPANT	\N	PRESENT	0
587160	585579	17737W	PARTICIPANT	\N	PRESENT	0
587161	585579	95063L	PARTICIPANT	\N	PRESENT	0
587162	585579	20108W	PARTICIPANT	\N	PRESENT	0
587163	585579	14107H	PARTICIPANT	\N	PRESENT	0
587164	585579	20114U	PARTICIPANT	\N	PRESENT	0
587165	585579	14215L	PARTICIPANT	\N	PRESENT	0
587166	585579	19749K	PARTICIPANT	\N	PRESENT	0
587167	585579	14021P	PARTICIPANT	\N	PRESENT	0
587168	585579	11072N	PARTICIPANT	\N	PRESENT	0
587169	585411	11070L	PARTICIPANT	\N	PRESENT	0
587175	585715	17023S	PARTICIPANT	\N	PRESENT	0
587176	585411	07029T	PARTICIPANT	\N	PRESENT	0
587177	585411	08010L	PARTICIPANT	\N	PRESENT	0
587178	585411	20116W	PARTICIPANT	\N	PRESENT	0
587179	585411	19335Q	PARTICIPANT	\N	PRESENT	0
587180	585411	14189C	PARTICIPANT	\N	EXCUSE	0
587185	585411	19671E	PARTICIPANT	\N	EXCUSE	0
587211	585411	08009T	PARTICIPANT	\N	PRESENT	0
587268	585411	11012A	PARTICIPANT	\N	PRESENT	0
587390	585752	86034E	PARTICIPANT	\N	PRESENT	0
587391	585752	11012A	PARTICIPANT	\N	PRESENT	0
587392	585752	14107H	PARTICIPANT	\N	PRESENT	0
587393	585752	19739H	PARTICIPANT	\N	PRESENT	0
587394	585752	19549D	PARTICIPANT	\N	PRESENT	0
587395	585752	14111D	PARTICIPANT	\N	PRESENT	0
587396	585752	14229S	PARTICIPANT	\N	PRESENT	0
587397	585752	19669L	PARTICIPANT	\N	PRESENT	0
584330	583470	19715Y	PARTICIPANT	\N	PRESENT	0
584331	583470	17779H	PARTICIPANT	\N	PRESENT	0
584332	583470	14281W	PARTICIPANT	\N	PRESENT	0
584333	583470	11067R	PARTICIPANT	\N	PRESENT	0
584334	583470	19760E	PARTICIPANT	\N	PRESENT	0
584335	583470	14042U	PARTICIPANT	\N	PRESENT	0
584336	583470	14071N	PARTICIPANT	\N	PRESENT	0
584337	583470	20090E	PARTICIPANT	\N	PRESENT	0
584338	583470	19367Y	PARTICIPANT	\N	PRESENT	0
584339	583470	20066E	PARTICIPANT	\N	PRESENT	0
584340	583470	19691J	PARTICIPANT	\N	PRESENT	0
584341	583470	14223L	PARTICIPANT	\N	PRESENT	0
584342	583470	19703U	PARTICIPANT	\N	PRESENT	0
584343	583470	19415P	PARTICIPANT	\N	PRESENT	0
584344	583470	14213J	PARTICIPANT	\N	PRESENT	0
584345	583470	14217N	PARTICIPANT	\N	PRESENT	0
584346	583470	11097X	PARTICIPANT	\N	PRESENT	0
584347	583470	20172F	PARTICIPANT	\N	PRESENT	0
584348	583470	20248J	PARTICIPANT	\N	PRESENT	0
584349	583470	14026U	PARTICIPANT	\N	PRESENT	1
584350	583470	19798U	PARTICIPANT	\N	PRESENT	1
584351	583470	19723Y	PARTICIPANT	\N	PRESENT	0
584352	583470	08045X	PARTICIPANT	\N	PRESENT	0
584353	583470	11031D	PARTICIPANT	\N	PRESENT	0
584354	583470	19569H	PARTICIPANT	\N	PRESENT	0
584355	583470	19553Y	PARTICIPANT	\N	PRESENT	0
584379	583470	18193Q	PARTICIPANT	\N	PRESENT	0
584417	583470	14195A	PARTICIPANT	\N	PRESENT	0
584419	583470	19713W	PARTICIPANT	\N	PRESENT	0
584424	583454	20028X	PARTICIPANT	\N	PRESENT	0
584425	583454	08015R	PARTICIPANT	\N	PRESENT	1
584426	583470	17965H	PARTICIPANT	\N	PRESENT	0
584452	583470	01034P	PARTICIPANT	\N	PRESENT	1
584465	583470	04057K	PARTICIPANT	\N	PRESENT	0
584476	583470	20040T	PARTICIPANT	\N	PRESENT	0
584485	583470	04092N	PARTICIPANT	\N	PRESENT	0
584486	583470	14355X	PARTICIPANT	\N	EXCUSE	0
584487	583462	07004J	PARTICIPANT	\N	EXCUSE	0
584488	583462	19673G	PARTICIPANT	\N	EXCUSE	0
584490	583462	20128B	PARTICIPANT	\N	PRESENT	1
584491	583462	19489J	PARTICIPANT	\N	PRESENT	1
584492	583462	19675J	PARTICIPANT	\N	PRESENT	1
584493	583462	17737W	PARTICIPANT	\N	PRESENT	1
584495	584494	19515S	PRESIDENT	0	PRESENT	0
584496	584494	19575F	PARTICIPANT	\N	PRESENT	0
584497	584494	20060X	PARTICIPANT	\N	PRESENT	0
584498	584494	19467C	PARTICIPANT	\N	PRESENT	0
584499	584494	14083S	PARTICIPANT	\N	PRESENT	0
584500	584494	14105F	PARTICIPANT	\N	PRESENT	0
584501	584494	20040T	PARTICIPANT	\N	PRESENT	0
584502	584494	19697Q	PARTICIPANT	\N	PRESENT	0
584503	584494	16685X	PARTICIPANT	\N	PRESENT	0
584504	584494	19369B	PARTICIPANT	\N	PRESENT	0
584505	584494	20126Y	PARTICIPANT	\N	PRESENT	0
584506	584494	19671E	PARTICIPANT	\N	PRESENT	0
584507	584494	19551W	PARTICIPANT	\N	PRESENT	0
584508	584494	19689Q	PARTICIPANT	\N	PRESENT	0
584509	584494	19687N	PARTICIPANT	\N	PRESENT	0
584510	584494	19749K	PARTICIPANT	\N	PRESENT	0
584511	584494	08060W	PARTICIPANT	\N	EXCUSE	0
584512	584494	08028W	PARTICIPANT	\N	EXCUSE	0
584513	584494	14357A	PARTICIPANT	\N	EXCUSE	0
584514	584494	19251M	PARTICIPANT	\N	EXCUSE	0
584515	584494	14031R	PARTICIPANT	\N	EXCUSE	0
584521	584520	14189C	PARTICIPANT	\N	PRESENT	0
584522	584520	14207L	PARTICIPANT	\N	EXCUSE	0
584523	584520	11031D	PARTICIPANT	\N	PRESENT	0
584524	584520	10006L	PARTICIPANT	\N	PRESENT	0
584525	584520	19683J	PARTICIPANT	\N	PRESENT	0
584526	584520	99004R	PARTICIPANT	\N	PRESENT	0
584527	584520	19447X	PARTICIPANT	\N	EXCUSE	0
584528	584520	19699S	PARTICIPANT	\N	PRESENT	0
584529	584520	19697Q	PARTICIPANT	\N	PRESENT	0
584530	584520	19563B	PARTICIPANT	\N	PRESENT	0
584531	584520	14229S	PARTICIPANT	\N	PRESENT	0
584532	584520	20030R	PARTICIPANT	\N	EXCUSE	0
584567	583463	20128B	PARTICIPANT	\N	PRESENT	1
584568	583463	19489J	PARTICIPANT	\N	PRESENT	1
584569	583463	19675J	PARTICIPANT	\N	PRESENT	1
584612	584611	05008E	PARTICIPANT	\N	PRESENT	0
584613	584611	11053K	PARTICIPANT	\N	PRESENT	0
584614	584611	01028R	PARTICIPANT	\N	PRESENT	0
584720	584715	19711U	PARTICIPANT	\N	PRESENT	1
584886	584880	19383Y	PARTICIPANT	\N	PRESENT	0
584887	584880	14109K	PARTICIPANT	\N	PRESENT	1
584888	584880	14030Q	PARTICIPANT	\N	PRESENT	0
584889	584880	19758L	PARTICIPANT	\N	PRESENT	0
584891	584880	11099A	PARTICIPANT	\N	PRESENT	0
585330	583492	20032T	PARTICIPANT	\N	PRESENT	0
585331	583492	19631V	PARTICIPANT	\N	PRESENT	0
585332	583492	04085P	PARTICIPANT	\N	PRESENT	0
585333	583492	19515S	PARTICIPANT	\N	PRESENT	0
585334	583492	20076G	PARTICIPANT	\N	PRESENT	0
585335	583492	19741B	PARTICIPANT	\N	PRESENT	0
585336	583492	19543W	PARTICIPANT	\N	PRESENT	0
585337	583492	20024T	PARTICIPANT	\N	PRESENT	0
585338	583492	20022R	PARTICIPANT	\N	PRESENT	0
585339	583492	19954N	PARTICIPANT	\N	PRESENT	0
585340	583492	20110Q	PARTICIPANT	\N	PRESENT	0
585341	583492	14030Q	PARTICIPANT	\N	PRESENT	0
585342	583492	14069U	PARTICIPANT	\N	PRESENT	0
585343	583492	14089Y	PARTICIPANT	\N	PRESENT	0
585344	583492	14105F	PARTICIPANT	\N	PRESENT	0
585345	583492	04047H	PARTICIPANT	\N	PRESENT	0
585346	583492	20090E	PARTICIPANT	\N	PRESENT	0
585347	583492	14207L	PARTICIPANT	\N	PRESENT	0
585348	583492	14053L	PARTICIPANT	\N	PRESENT	0
585349	583492	14083S	PARTICIPANT	\N	PRESENT	0
585350	583492	11103C	PARTICIPANT	\N	PRESENT	0
585351	583492	19629C	PARTICIPANT	\N	PRESENT	0
585352	583492	19467C	PARTICIPANT	\N	PRESENT	0
585354	583492	18083K	PARTICIPANT	\N	PRESENT	0
585356	583492	19681G	PARTICIPANT	\N	PRESENT	0
585358	583492	11056N	PARTICIPANT	\N	PRESENT	0
585360	583492	14357A	PARTICIPANT	\N	PRESENT	0
585363	583492	11070L	PARTICIPANT	\N	PRESENT	0
585364	583492	01024M	PARTICIPANT	\N	PRESENT	0
585365	583492	20248J	PARTICIPANT	\N	PRESENT	0
585366	583492	19507S	PARTICIPANT	\N	PRESENT	0
585367	583492	14151M	PARTICIPANT	\N	PRESENT	0
585368	583492	01025N	PARTICIPANT	\N	PRESENT	0
585369	583492	20132W	PARTICIPANT	\N	PRESENT	0
585370	583492	97011G	PARTICIPANT	\N	PRESENT	0
585371	583492	14231L	PARTICIPANT	\N	PRESENT	0
585372	583492	14355X	PARTICIPANT	\N	PRESENT	0
585373	583492	14033T	PARTICIPANT	\N	PRESENT	0
585374	583492	14123H	PARTICIPANT	\N	PRESENT	0
585375	583492	20072C	PARTICIPANT	\N	PRESENT	0
585377	583492	19399H	PARTICIPANT	\N	PRESENT	0
585378	583492	19715Y	PARTICIPANT	\N	PRESENT	0
585379	583492	20056C	PARTICIPANT	\N	PRESENT	0
585380	583492	20126Y	PARTICIPANT	\N	PRESENT	0
585381	583492	19735D	PARTICIPANT	\N	PRESENT	0
585382	583492	19611R	PARTICIPANT	\N	PRESENT	0
585383	583492	07029T	PARTICIPANT	\N	PRESENT	0
585384	583492	20108W	PARTICIPANT	\N	PRESENT	0
585385	583492	19729F	PARTICIPANT	\N	PRESENT	0
585386	583492	20052X	PARTICIPANT	\N	PRESENT	0
585387	583492	14219Q	PARTICIPANT	\N	PRESENT	0
585388	583492	01048V	PARTICIPANT	\N	PRESENT	0
585389	583492	20142Y	PARTICIPANT	\N	PRESENT	0
585390	583492	14147R	PARTICIPANT	\N	PRESENT	0
585391	583492	11072N	PARTICIPANT	\N	PRESENT	0
585392	583492	08061X	PARTICIPANT	\N	PRESENT	0
585394	583492	14237S	PARTICIPANT	\N	PRESENT	0
585395	583492	19443T	PARTICIPANT	\N	PRESENT	0
585396	583492	19349W	PARTICIPANT	\N	PRESENT	0
585397	583492	11012A	PARTICIPANT	\N	PRESENT	0
585398	583492	04033B	PARTICIPANT	\N	PRESENT	0
585399	583492	95063L	PARTICIPANT	\N	PRESENT	0
585400	583492	20054A	PARTICIPANT	\N	PRESENT	0
585401	583492	20044X	PARTICIPANT	\N	PRESENT	0
585402	583492	01058X	PARTICIPANT	\N	PRESENT	0
585403	583492	20062A	PARTICIPANT	\N	PRESENT	0
585404	583492	20046A	PARTICIPANT	\N	PRESENT	0
585492	585491	14053L	PARTICIPANT	\N	PRESENT	0
585494	585491	11066Q	PARTICIPANT	\N	PRESENT	0
585496	585495	20108W	PARTICIPANT	\N	PRESENT	0
585687	583340	20048C	PRESIDENT	0	PRESENT	0
585688	583340	17779H	PARTICIPANT	\N	PRESENT	0
574197	573011	04047H	PRESIDENT	0	PRESENT	0
574213	573011	19729F	PARTICIPANT	\N	PRESENT	0
574214	573011	14001X	PARTICIPANT	\N	PRESENT	0
574215	573011	19749K	PARTICIPANT	\N	PRESENT	0
574201	573011	14215L	PRESIDENT	1	PRESENT	0
574216	573011	20128B	PARTICIPANT	\N	PRESENT	0
574217	573011	14259Y	PARTICIPANT	\N	PRESENT	0
574204	573011	14053L	PARTICIPANT	\N	PRESENT	0
574205	573011	05008E	PARTICIPANT	\N	PRESENT	0
574206	573011	11056N	PARTICIPANT	\N	PRESENT	0
574207	573011	19489J	PARTICIPANT	\N	PRESENT	0
574208	573011	07004J	PARTICIPANT	\N	PRESENT	0
574209	573011	11026G	PARTICIPANT	\N	PRESENT	0
574210	573011	01028R	PARTICIPANT	\N	PRESENT	0
574211	573011	14231L	PARTICIPANT	\N	PRESENT	0
574212	573011	20108W	PARTICIPANT	\N	PRESENT	0
574300	573339	08069G	PARTICIPANT	\N	PRESENT	0
574301	573339	11054L	PARTICIPANT	\N	PRESENT	0
574309	573339	14097Y	PARTICIPANT	\N	PRESENT	0
574310	573339	11066Q	PARTICIPANT	\N	PRESENT	0
574315	573339	19421M	PARTICIPANT	\N	PRESENT	0
574317	573340	04035D	PARTICIPANT	\N	PRESENT	0
574318	573340	14133K	PARTICIPANT	\N	PRESENT	0
574319	573340	01062T	PARTICIPANT	\N	PRESENT	0
574320	573340	19565D	PARTICIPANT	\N	PRESENT	0
574321	573340	08069G	PARTICIPANT	\N	PRESENT	0
574322	573340	20042V	PARTICIPANT	\N	PRESENT	0
574323	573340	01058X	PARTICIPANT	\N	PRESENT	1
574324	573340	04042C	PRESIDENT	0	PRESENT	0
574325	573340	11054L	PARTICIPANT	\N	PRESENT	1
574326	573340	01024M	PARTICIPANT	\N	PRESENT	0
574327	573340	12028B	PARTICIPANT	\N	PRESENT	0
574328	573340	19421M	PARTICIPANT	\N	PRESENT	1
574329	573340	14267Y	PARTICIPANT	\N	PRESENT	0
574330	573340	19347U	PARTICIPANT	\N	PRESENT	1
574331	573340	11083R	PARTICIPANT	\N	PRESENT	0
574332	573340	97011G	PARTICIPANT	\N	PRESENT	0
574333	573340	17023S	PARTICIPANT	\N	PRESENT	0
574336	574298	14331P	PARTICIPANT	\N	PRESENT	0
574337	574298	04071H	PARTICIPANT	\N	PRESENT	0
574338	574298	11048N	PARTICIPANT	\N	PRESENT	0
574339	574298	19711U	PARTICIPANT	\N	PRESENT	0
574340	574298	01057W	PARTICIPANT	\N	PRESENT	0
574341	574298	11053K	PARTICIPANT	\N	PRESENT	0
574342	574298	20080C	PARTICIPANT	\N	PRESENT	0
574343	574298	11074Q	PARTICIPANT	\N	PRESENT	0
574344	574298	20044X	PARTICIPANT	\N	PRESENT	0
574345	574298	14225N	PRESIDENT	0	PRESENT	0
574346	574298	14083S	PARTICIPANT	\N	PRESENT	0
574347	574298	07029T	PARTICIPANT	\N	PRESENT	0
574348	574298	11012A	PARTICIPANT	\N	PRESENT	0
574349	574298	20070A	PARTICIPANT	\N	PRESENT	0
574350	574298	19741B	PARTICIPANT	\N	PRESENT	0
574351	574298	19335Q	PARTICIPANT	\N	PRESENT	0
574356	574298	01048V	PARTICIPANT	\N	PRESENT	0
577895	577894	14331P	PARTICIPANT	\N	PRESENT	0
577896	577894	11083R	PARTICIPANT	\N	PRESENT	0
577897	577894	14073Q	PARTICIPANT	\N	PRESENT	0
577898	577894	19563B	PARTICIPANT	\N	PRESENT	0
590660	588411	14133K	PARTICIPANT	\N	PRESENT	0
590661	588411	20042V	PARTICIPANT	\N	PRESENT	0
590662	588411	14105F	PARTICIPANT	\N	PRESENT	0
590663	588411	04042C	PRESIDENT	0	PRESENT	0
590675	588411	12028B	PARTICIPANT	\N	PRESENT	0
590676	588411	14267Y	PARTICIPANT	\N	PRESENT	0
590680	588411	17023S	PARTICIPANT	\N	PRESENT	0
590678	588411	01024M	PARTICIPANT	\N	PRESENT	0
590679	588411	14249W	PARTICIPANT	\N	PRESENT	0
590681	588411	11083R	PARTICIPANT	\N	PRESENT	0
590682	588411	19347U	PARTICIPANT	\N	EXCUSE	0
590684	588411	08056B	PARTICIPANT	\N	PRESENT	0
590692	588411	14211G	PARTICIPANT	\N	PRESENT	0
590693	588411	19565D	PARTICIPANT	\N	PRESENT	0
590695	588411	11064N	PARTICIPANT	\N	PRESENT	0
590696	588411	20072C	PARTICIPANT	\N	PRESENT	0
590697	588411	08069G	PARTICIPANT	\N	PRESENT	0
590698	588411	14097Y	PARTICIPANT	\N	PRESENT	0
590699	588411	95041E	PARTICIPANT	\N	PRESENT	0
590701	588411	12041X	PARTICIPANT	\N	PRESENT	0
590703	588411	19709B	PARTICIPANT	\N	PRESENT	0
590704	588411	16685X	PARTICIPANT	\N	PRESENT	0
590705	588411	14059S	PARTICIPANT	\N	PRESENT	0
590707	588411	14193X	PRESIDENT	1	PRESENT	0
590708	588411	19443T	PARTICIPANT	\N	PRESENT	0
590709	588411	14055N	PARTICIPANT	\N	PRESENT	0
590710	588411	11054L	PARTICIPANT	\N	PRESENT	0
590711	588411	19421M	PARTICIPANT	\N	PRESENT	0
590712	588411	01058X	PARTICIPANT	\N	PRESENT	0
590713	588411	19669L	PARTICIPANT	\N	PRESENT	0
590714	588411	01062T	PARTICIPANT	\N	PRESENT	0
590715	588411	20064C	PARTICIPANT	\N	PRESENT	0
590716	588411	11041F	PARTICIPANT	\N	PRESENT	0
590718	588411	11066Q	PARTICIPANT	\N	PRESENT	0
590725	588412	11041F	PARTICIPANT	\N	PRESENT	1
590966	590913	04045F	PARTICIPANT	\N	PRESENT	0
593758	593442	04047H	PARTICIPANT	\N	PRESENT	0
593759	593442	14038Y	PARTICIPANT	\N	PRESENT	0
593760	593442	14179A	PARTICIPANT	\N	PRESENT	0
593761	593442	20090E	PARTICIPANT	\N	PRESENT	0
593762	593442	14151M	PARTICIPANT	\N	PRESENT	0
593763	593442	14111D	PARTICIPANT	\N	PRESENT	0
593764	593442	19585H	PARTICIPANT	\N	PRESENT	0
593765	593442	95063L	PARTICIPANT	\N	PRESENT	0
593766	593442	20054A	PARTICIPANT	\N	PRESENT	0
593767	593442	19507S	PARTICIPANT	\N	PRESENT	0
593768	593442	01057W	PARTICIPANT	\N	PRESENT	0
593769	593442	19573D	PARTICIPANT	\N	PRESENT	0
593770	593442	11072N	PARTICIPANT	\N	PRESENT	0
593771	593442	19717B	PARTICIPANT	\N	PRESENT	0
593772	593442	01024M	PARTICIPANT	\N	PRESENT	0
593773	593442	19749K	PARTICIPANT	\N	PRESENT	0
593774	593442	97011G	PARTICIPANT	\N	PRESENT	0
593775	593442	19533U	PARTICIPANT	\N	PRESENT	0
593776	593442	14069U	PARTICIPANT	\N	PRESENT	0
593856	593442	20102Q	PARTICIPANT	\N	PRESENT	0
593857	593442	14207L	PARTICIPANT	\N	PRESENT	0
593858	593442	20058E	PARTICIPANT	\N	PRESENT	0
593859	593442	11067R	PARTICIPANT	\N	PRESENT	0
593861	593442	11026G	PARTICIPANT	\N	PRESENT	0
593862	593442	20020P	PARTICIPANT	\N	PRESENT	0
593863	593442	20032T	PARTICIPANT	\N	PRESENT	0
593864	593442	19866P	PARTICIPANT	\N	PRESENT	0
593865	593545	20086J	PARTICIPANT	\N	PRESENT	0
593866	593545	11048N	PARTICIPANT	\N	PRESENT	0
593867	593545	19531S	PARTICIPANT	\N	PRESENT	0
593868	593545	11053K	PARTICIPANT	\N	PRESENT	0
593869	593545	08010L	PARTICIPANT	\N	PRESENT	0
593870	593545	99004R	PARTICIPANT	\N	PRESENT	0
593871	593545	19762G	PARTICIPANT	\N	PRESENT	0
593872	593442	20028X	PARTICIPANT	\N	PRESENT	0
593873	593442	20180F	PARTICIPANT	\N	PRESENT	0
593874	593442	14059S	PARTICIPANT	\N	PRESENT	0
593875	593442	01048V	PARTICIPANT	\N	PRESENT	0
593876	593442	14001X	PARTICIPANT	\N	PRESENT	0
593877	593442	19399H	PARTICIPANT	\N	PRESENT	0
593878	593442	11012A	PARTICIPANT	\N	PRESENT	0
593881	590931	19333N	PARTICIPANT	\N	PRESENT	0
593882	590931	14031R	PRESIDENT	0	PRESENT	0
593883	590931	20038A	PARTICIPANT	\N	PRESENT	0
593884	590931	20076G	PARTICIPANT	\N	PRESENT	0
593885	590931	19549D	PARTICIPANT	\N	PRESENT	0
593886	590931	19251M	PARTICIPANT	\N	PRESENT	1
593887	590931	19820Y	PARTICIPANT	\N	PRESENT	0
593888	590931	19826F	PARTICIPANT	\N	PRESENT	0
593889	590931	20102Q	PARTICIPANT	\N	PRESENT	0
593890	590931	14169X	PARTICIPANT	\N	PRESENT	0
593891	590931	18083K	PARTICIPANT	\N	PRESENT	0
593892	590931	08060W	PARTICIPANT	\N	PRESENT	0
593893	590931	20068G	PARTICIPANT	\N	PRESENT	0
593894	590931	19739H	PARTICIPANT	\N	PRESENT	0
593895	590931	20020P	PARTICIPANT	\N	PRESENT	0
593896	590931	11065P	PARTICIPANT	\N	PRESENT	0
593897	590931	19745F	PARTICIPANT	\N	PRESENT	0
595586	595585	14133K	PARTICIPANT	\N	PRESENT	0
595587	595585	11066Q	PARTICIPANT	\N	PRESENT	0
595589	595588	11041F	PARTICIPANT	\N	PRESENT	1
595590	595588	19709B	PARTICIPANT	\N	PRESENT	1
578108	575273	20058E	PARTICIPANT	\N	PRESENT	0
578109	575273	17637T	PARTICIPANT	\N	PRESENT	0
578110	575273	19749K	PARTICIPANT	\N	PRESENT	0
578111	575273	14089Y	PARTICIPANT	\N	PRESENT	0
578112	575273	20066E	PARTICIPANT	\N	PRESENT	0
578113	575273	10015M	PARTICIPANT	\N	PRESENT	0
578114	575273	20068G	PARTICIPANT	\N	PRESENT	0
578115	575273	11090Q	PARTICIPANT	\N	PRESENT	0
578116	575273	05012A	PARTICIPANT	\N	PRESENT	0
578117	575273	20130U	PARTICIPANT	\N	PRESENT	0
578118	575273	19347U	PARTICIPANT	\N	PRESENT	0
578119	575273	11033F	PARTICIPANT	\N	PRESENT	0
578120	575273	20092G	PARTICIPANT	\N	PRESENT	0
578121	575273	20100N	PARTICIPANT	\N	PRESENT	0
578122	575273	20134Y	PARTICIPANT	\N	PRESENT	0
578123	575273	17023S	PARTICIPANT	\N	PRESENT	0
578106	575273	19695N	PARTICIPANT	\N	PRESENT	0
578107	575273	19621T	PARTICIPANT	\N	PRESENT	0
582727	582726	19701S	PARTICIPANT	\N	PRESENT	0
582728	582726	19693L	PARTICIPANT	\N	PRESENT	0
582729	582726	19671E	PARTICIPANT	\N	PRESENT	0
582730	582726	11027H	PARTICIPANT	\N	PRESENT	0
589095	588230	01028R	PARTICIPANT	\N	PRESENT	0
589103	588230	14038Y	PARTICIPANT	\N	PRESENT	0
589101	588531	14026U	PARTICIPANT	\N	PRESENT	0
589102	588531	14151M	PARTICIPANT	\N	PRESENT	0
589104	588531	20122U	PARTICIPANT	\N	PRESENT	0
589105	588531	14055N	PARTICIPANT	\N	PRESENT	0
589106	588531	01048V	PARTICIPANT	\N	PRESENT	0
589107	588531	14207L	PARTICIPANT	\N	PRESENT	0
589108	588531	20116W	PARTICIPANT	\N	PRESENT	0
589109	588531	11026G	PARTICIPANT	\N	PRESENT	0
589110	588531	14089Y	PARTICIPANT	\N	PRESENT	0
589112	588531	19725B	PARTICIPANT	\N	PRESENT	0
589113	588531	19441R	PARTICIPANT	\N	PRESENT	0
589114	588531	04045F	PARTICIPANT	\N	PRESENT	0
589115	588531	14001X	PARTICIPANT	\N	PRESENT	0
589159	588534	11026G	PARTICIPANT	\N	PRESENT	0
589160	588534	20064C	PARTICIPANT	\N	PRESENT	0
589161	588534	19725B	PARTICIPANT	\N	PRESENT	0
589162	588534	20102Q	PARTICIPANT	\N	PRESENT	0
589163	588534	11064N	PARTICIPANT	\N	PRESENT	0
589164	588534	20122U	PARTICIPANT	\N	PRESENT	0
589165	588534	11012A	PARTICIPANT	\N	PRESENT	0
589166	588534	19681G	PARTICIPANT	\N	PRESENT	0
589167	588534	20116W	PARTICIPANT	\N	PRESENT	0
589168	588534	14207L	PARTICIPANT	\N	PRESENT	0
589169	588534	19563B	PARTICIPANT	\N	PRESENT	0
589170	588534	19441R	PARTICIPANT	\N	PRESENT	0
589171	588534	19349W	PARTICIPANT	\N	PRESENT	0
589172	588534	04045F	PARTICIPANT	\N	PRESENT	0
589173	588534	14189C	PARTICIPANT	\N	PRESENT	0
589174	588534	14089Y	PARTICIPANT	\N	PRESENT	0
589175	588534	20130U	PARTICIPANT	\N	PRESENT	0
589176	588534	01024M	PARTICIPANT	\N	PRESENT	0
589177	588534	20090E	PARTICIPANT	\N	PRESENT	0
589179	588534	14331P	PARTICIPANT	\N	PRESENT	0
589181	588534	19711U	PARTICIPANT	\N	PRESENT	0
589270	588534	20082E	PARTICIPANT	\N	PRESENT	0
589184	588534	04085P	PARTICIPANT	\N	PRESENT	0
589185	588534	19565D	PARTICIPANT	\N	PRESENT	0
589189	588534	14055N	PARTICIPANT	\N	PRESENT	0
589200	588534	99004R	PARTICIPANT	\N	PRESENT	0
589201	588534	19747H	PARTICIPANT	\N	PRESENT	0
589202	588534	14237S	PARTICIPANT	\N	PRESENT	0
589203	588534	14033T	PARTICIPANT	\N	PRESENT	0
589205	588534	14069U	PARTICIPANT	\N	PRESENT	0
589206	588534	20048C	PARTICIPANT	\N	PRESENT	0
589207	588534	19760E	PARTICIPANT	\N	PRESENT	0
589257	588534	19782L	PARTICIPANT	\N	PRESENT	0
589262	588534	14026U	PARTICIPANT	\N	PRESENT	0
589265	588534	14221J	PARTICIPANT	\N	PRESENT	0
589266	588534	14133K	PARTICIPANT	\N	PRESENT	0
589267	588534	20054A	PARTICIPANT	\N	PRESENT	0
589268	588534	20104S	PARTICIPANT	\N	PRESENT	0
589269	588534	20068G	PARTICIPANT	\N	PRESENT	0
589271	588534	14217N	PARTICIPANT	\N	PRESENT	0
589272	588534	04092N	PARTICIPANT	\N	PRESENT	0
589157	588534	12041X	PARTICIPANT	\N	PRESENT	0
589158	588534	14001X	PARTICIPANT	\N	PRESENT	0
589273	588534	20028X	PARTICIPANT	\N	PRESENT	0
589274	588534	14173T	PARTICIPANT	\N	PRESENT	0
589275	588534	19683J	PARTICIPANT	\N	PRESENT	0
589276	588534	14179A	PARTICIPANT	\N	PRESENT	0
589284	588534	20140W	PARTICIPANT	\N	PRESENT	0
589285	588534	19741B	PARTICIPANT	\N	PRESENT	0
589286	588534	11072N	PARTICIPANT	\N	PRESENT	0
589287	588534	20024T	PARTICIPANT	\N	PRESENT	0
589313	588532	19715Y	PARTICIPANT	\N	PRESENT	0
589314	588532	19683J	PARTICIPANT	\N	PRESENT	0
589315	588532	20140W	PARTICIPANT	\N	PRESENT	0
589316	588532	19631V	PARTICIPANT	\N	PRESENT	0
589317	588532	14033T	PARTICIPANT	\N	PRESENT	0
589318	588532	20026V	PARTICIPANT	\N	PRESENT	0
589319	588532	20028X	PARTICIPANT	\N	PRESENT	0
589320	588532	04085P	PARTICIPANT	\N	PRESENT	0
589321	588532	20148F	PARTICIPANT	\N	PRESENT	0
589322	588532	04092N	PARTICIPANT	\N	PRESENT	0
589323	588532	19703U	PARTICIPANT	\N	PRESENT	0
589324	588532	11072N	PARTICIPANT	\N	PRESENT	0
589325	588532	20150Y	PARTICIPANT	\N	PRESENT	0
589326	588532	20034V	PARTICIPANT	\N	PRESENT	0
589327	588532	19301E	PARTICIPANT	\N	PRESENT	0
589328	588532	10006L	PARTICIPANT	\N	PRESENT	0
589329	588532	14221J	PARTICIPANT	\N	PRESENT	0
589330	588532	14219Q	PARTICIPANT	\N	PRESENT	0
589331	588532	19717B	PARTICIPANT	\N	PRESENT	0
589332	588532	19347U	PARTICIPANT	\N	PRESENT	0
589333	588532	14147R	PARTICIPANT	\N	PRESENT	0
589334	588532	18193Q	PARTICIPANT	\N	PRESENT	0
589335	588532	19760E	PARTICIPANT	\N	PRESENT	0
589311	588532	19719D	PARTICIPANT	\N	PRESENT	0
589312	588532	19295A	PARTICIPANT	\N	PRESENT	0
589336	588532	19691J	PARTICIPANT	\N	PRESENT	0
589337	588532	20046A	PARTICIPANT	\N	PRESENT	0
589338	588532	11077T	PARTICIPANT	\N	PRESENT	0
589339	588532	12016W	PARTICIPANT	\N	PRESENT	0
589340	588532	20252E	PARTICIPANT	\N	PRESENT	0
589341	588532	20146D	PARTICIPANT	\N	PRESENT	0
589342	588532	08073C	PARTICIPANT	\N	PRESENT	0
589343	588532	19383Y	PARTICIPANT	\N	PRESENT	0
589344	588532	18083K	PARTICIPANT	\N	PRESENT	0
589345	588532	07029T	PARTICIPANT	\N	PRESENT	0
589644	588234	14259Y	PARTICIPANT	\N	PRESENT	0
589681	588234	14089Y	PARTICIPANT	\N	PRESENT	0
589738	586713	19637C	PARTICIPANT	\N	EXCUSE	0
589773	588235	19333N	PARTICIPANT	\N	PRESENT	0
589774	588235	14147R	PARTICIPANT	\N	PRESENT	0
589775	588235	14215L	PRESIDENT	0	PRESENT	0
589776	588235	08018U	PARTICIPANT	\N	EXCUSE	0
589777	588235	04047H	PARTICIPANT	\N	EXCUSE	0
589785	589784	20054A	PARTICIPANT	\N	PRESENT	0
589786	589784	20082E	PARTICIPANT	\N	PRESENT	0
589787	589784	20030R	PARTICIPANT	\N	PRESENT	0
589789	587935	20054A	PARTICIPANT	\N	PRESENT	0
589794	589788	20054A	PARTICIPANT	\N	PRESENT	0
589796	589788	20082E	PARTICIPANT	\N	PRESENT	0
589802	589798	20054A	PARTICIPANT	\N	PRESENT	0
589804	588536	19629C	PARTICIPANT	\N	PRESENT	0
589805	588536	20130U	PARTICIPANT	\N	PRESENT	0
589806	588536	20050V	PARTICIPANT	\N	PRESENT	0
589807	588536	07004J	PARTICIPANT	\N	PRESENT	0
589808	588536	19479G	PARTICIPANT	\N	PRESENT	0
589809	589803	20054A	PARTICIPANT	\N	PRESENT	0
589810	589803	20082E	PARTICIPANT	\N	PRESENT	0
589811	588536	14111D	PARTICIPANT	\N	PRESENT	0
589812	588536	20144B	PARTICIPANT	\N	PRESENT	0
589814	589813	20054A	PARTICIPANT	\N	PRESENT	0
589815	589813	20082E	PARTICIPANT	\N	PRESENT	0
589816	588536	11040E	PARTICIPANT	\N	PRESENT	0
589817	588536	19659J	PARTICIPANT	\N	PRESENT	0
589818	588536	14327T	PARTICIPANT	\N	PRESENT	0
589819	588536	19581D	PARTICIPANT	\N	PRESENT	0
589820	588536	19798U	PARTICIPANT	\N	PRESENT	0
589821	588536	11067R	PARTICIPANT	\N	PRESENT	0
589822	588536	19707Y	PARTICIPANT	\N	PRESENT	0
589823	588536	19705W	PARTICIPANT	\N	PRESENT	0
589824	588536	19758L	PARTICIPANT	\N	PRESENT	0
589825	588536	20046A	PARTICIPANT	\N	PRESENT	0
589826	588536	19593H	PARTICIPANT	\N	PRESENT	0
587398	585752	18193Q	PARTICIPANT	\N	PRESENT	0
587399	585752	19525U	PARTICIPANT	\N	PRESENT	0
587400	585752	14121F	PARTICIPANT	\N	PRESENT	0
587401	585752	12016W	PARTICIPANT	\N	PRESENT	0
587402	585752	08061X	PARTICIPANT	\N	PRESENT	0
587403	585752	20072C	PARTICIPANT	\N	PRESENT	0
587404	585752	08017T	PARTICIPANT	\N	PRESENT	0
587405	585752	19347U	PARTICIPANT	\N	PRESENT	0
587406	585752	11033F	PARTICIPANT	\N	PRESENT	0
587407	585752	20114U	PARTICIPANT	\N	PRESENT	0
587408	585752	19593H	PARTICIPANT	\N	PRESENT	0
587409	585752	19251M	PARTICIPANT	\N	PRESENT	0
587410	585752	20030R	PARTICIPANT	\N	PRESENT	0
587411	585752	11066Q	PARTICIPANT	\N	PRESENT	0
587412	585752	19301E	PARTICIPANT	\N	PRESENT	0
587413	585752	19719D	PARTICIPANT	\N	PRESENT	0
587414	585752	19563B	PARTICIPANT	\N	PRESENT	0
587415	585752	19479G	PARTICIPANT	\N	PRESENT	0
587416	585752	19441R	PARTICIPANT	\N	PRESENT	0
587417	585752	20042V	PARTICIPANT	\N	PRESENT	0
587418	585752	19699S	PARTICIPANT	\N	PRESENT	0
587419	585752	14219Q	PARTICIPANT	\N	PRESENT	0
587420	585752	20036X	PARTICIPANT	\N	PRESENT	0
587421	585752	14021P	PARTICIPANT	\N	PRESENT	0
587422	585752	20092G	PARTICIPANT	\N	PRESENT	0
587423	585752	19569H	PARTICIPANT	\N	PRESENT	0
587424	585752	08009T	PARTICIPANT	\N	PRESENT	0
587425	585752	20132W	PARTICIPANT	\N	PRESENT	0
587426	585752	20060X	PARTICIPANT	\N	PRESENT	0
587427	585752	19575F	PARTICIPANT	\N	PRESENT	0
587428	585752	19693L	PARTICIPANT	\N	PRESENT	0
587429	585752	19679N	PARTICIPANT	\N	PRESENT	0
587430	585752	19766L	PARTICIPANT	\N	PRESENT	0
587431	585752	17367Q	PARTICIPANT	\N	PRESENT	0
587432	585752	99004R	PARTICIPANT	\N	PRESENT	0
587433	585752	11101A	PARTICIPANT	\N	PRESENT	0
587434	585752	14026U	PARTICIPANT	\N	PRESENT	0
587435	585752	04047H	PARTICIPANT	\N	PRESENT	0
587436	585752	04042C	PARTICIPANT	\N	PRESENT	0
587437	585752	20068G	PARTICIPANT	\N	PRESENT	0
587438	585752	01057W	PARTICIPANT	\N	PRESENT	0
587439	585752	05012A	PARTICIPANT	\N	PRESENT	0
587440	585752	20022R	PARTICIPANT	\N	PRESENT	0
587441	585752	19573D	PARTICIPANT	\N	PRESENT	0
587442	585752	20032T	PARTICIPANT	\N	PRESENT	0
587443	585752	14187A	PARTICIPANT	\N	PRESENT	0
587444	585752	04033B	PARTICIPANT	\N	PRESENT	0
587445	585752	08028W	PARTICIPANT	\N	PRESENT	0
587446	585752	14259Y	PARTICIPANT	\N	PRESENT	0
587447	585752	01048V	PARTICIPANT	\N	PRESENT	0
587448	585752	19701S	PARTICIPANT	\N	PRESENT	0
587449	585752	19760E	PARTICIPANT	\N	PRESENT	0
587450	585752	95041E	PARTICIPANT	\N	PRESENT	0
587451	585752	19581D	PARTICIPANT	\N	PRESENT	0
587452	585752	14193X	PARTICIPANT	\N	PRESENT	0
587453	585752	04085P	PARTICIPANT	\N	PRESENT	0
587454	585752	19758L	PARTICIPANT	\N	PRESENT	0
587455	585752	19565D	PARTICIPANT	\N	PRESENT	0
587456	585752	17637T	PARTICIPANT	\N	PRESENT	0
587457	585752	19711U	PARTICIPANT	\N	PRESENT	0
587458	585752	19599P	PARTICIPANT	\N	PRESENT	0
587459	585752	19715Y	PARTICIPANT	\N	PRESENT	0
587460	585752	01028R	PARTICIPANT	\N	PRESENT	0
587461	585752	08010L	PARTICIPANT	\N	PRESENT	0
587462	585752	04059M	PARTICIPANT	\N	PRESENT	0
587463	585752	19747H	PARTICIPANT	\N	PRESENT	0
587464	585752	04092N	PARTICIPANT	\N	PRESENT	0
587465	585752	11056N	PARTICIPANT	\N	PRESENT	0
587466	585752	20074E	PARTICIPANT	\N	PRESENT	0
587467	585752	14001X	PARTICIPANT	\N	PRESENT	0
587468	585752	19647E	PARTICIPANT	\N	PRESENT	0
587469	585752	19333N	PARTICIPANT	\N	PRESENT	0
587470	585752	19683J	PARTICIPANT	\N	PRESENT	0
587471	585752	19643A	PARTICIPANT	\N	PRESENT	0
587472	585752	10015M	PARTICIPANT	\N	PRESENT	0
587473	585752	19649G	PARTICIPANT	\N	PRESENT	0
587474	585752	05008E	PARTICIPANT	\N	PRESENT	0
587475	585752	20028X	PARTICIPANT	\N	PRESENT	0
587476	585752	11097X	PARTICIPANT	\N	PRESENT	0
587477	585752	11027H	PARTICIPANT	\N	PRESENT	0
587478	585752	11054L	PARTICIPANT	\N	PRESENT	0
587479	585752	14033T	PARTICIPANT	\N	PRESENT	0
587480	585752	14281W	PARTICIPANT	\N	PRESENT	0
587481	585752	19515S	PARTICIPANT	\N	PRESENT	0
587482	585752	20070A	PARTICIPANT	\N	PRESENT	0
587483	585752	20082E	PARTICIPANT	\N	PRESENT	0
587484	585752	14123H	PARTICIPANT	\N	PRESENT	0
587485	585752	11090Q	PARTICIPANT	\N	PRESENT	0
587486	585752	11067R	PARTICIPANT	\N	PRESENT	0
587487	585752	11110B	PARTICIPANT	\N	PRESENT	0
587488	585752	14331P	PARTICIPANT	\N	PRESENT	0
587489	585752	14105F	PARTICIPANT	\N	PRESENT	0
587490	585752	12028B	PARTICIPANT	\N	PRESENT	0
587491	585752	19503N	PARTICIPANT	\N	PRESENT	0
587492	585752	20118Y	PARTICIPANT	\N	PRESENT	0
587493	585752	20102Q	PARTICIPANT	\N	PRESENT	0
587494	585752	11043H	PARTICIPANT	\N	PRESENT	0
587495	585752	14031R	PARTICIPANT	\N	PRESENT	0
587496	585752	20038A	PARTICIPANT	\N	PRESENT	0
587497	585752	11026G	PARTICIPANT	\N	PRESENT	0
587498	585752	14173T	PARTICIPANT	\N	PRESENT	0
587499	585752	20094J	PARTICIPANT	\N	PRESENT	0
587500	585752	19723Y	PARTICIPANT	\N	PRESENT	0
587501	585752	19413M	PARTICIPANT	\N	PRESENT	0
587502	585752	14038Y	PARTICIPANT	\N	PRESENT	0
587503	585752	19531S	PARTICIPANT	\N	PRESENT	0
587504	585752	19467C	PARTICIPANT	\N	PRESENT	0
587505	585752	14225N	PARTICIPANT	\N	PRESENT	0
587506	585752	19507S	PARTICIPANT	\N	PRESENT	0
587507	585752	20056C	PARTICIPANT	\N	PRESENT	0
587508	585752	20136B	PARTICIPANT	\N	PRESENT	0
587509	585752	20026V	PARTICIPANT	\N	PRESENT	0
587510	585752	20180F	PARTICIPANT	\N	PRESENT	0
587511	585752	20098N	PARTICIPANT	\N	PRESENT	0
587512	585752	11065P	PARTICIPANT	\N	PRESENT	0
587513	585752	20134Y	PARTICIPANT	\N	PRESENT	0
587514	585752	20086J	PARTICIPANT	\N	PRESENT	0
587515	585752	20174H	PARTICIPANT	\N	PRESENT	0
587516	585752	19659J	PARTICIPANT	\N	PRESENT	0
587517	585752	20104S	PARTICIPANT	\N	PRESENT	0
587518	585752	20108W	PARTICIPANT	\N	PRESENT	0
587519	585752	19697Q	PARTICIPANT	\N	PRESENT	0
587520	585752	19651A	PARTICIPANT	\N	PRESENT	0
587521	585752	19399H	PARTICIPANT	\N	PRESENT	0
587522	585752	11083R	PARTICIPANT	\N	PRESENT	0
587523	585752	20128B	PARTICIPANT	\N	PRESENT	0
587524	585752	19741B	PARTICIPANT	\N	PRESENT	0
587525	585752	95063L	PARTICIPANT	\N	PRESENT	0
587526	585752	19729F	PARTICIPANT	\N	PRESENT	0
587527	585752	11072N	PARTICIPANT	\N	PRESENT	0
587528	585752	14053L	PARTICIPANT	\N	PRESENT	0
587529	585752	19637C	PARTICIPANT	\N	PRESENT	0
587530	585752	19705W	PARTICIPANT	\N	PRESENT	0
587531	585752	19703U	PARTICIPANT	\N	PRESENT	0
587532	585752	14221J	PARTICIPANT	\N	PRESENT	0
587533	585752	14195A	PARTICIPANT	\N	PRESENT	0
587534	585752	20138D	PARTICIPANT	\N	PRESENT	0
587535	585752	11064N	PARTICIPANT	\N	PRESENT	0
587536	585752	17737W	PARTICIPANT	\N	PRESENT	0
587537	585752	14207L	PARTICIPANT	\N	PRESENT	0
587538	585752	19629C	PARTICIPANT	\N	PRESENT	0
587539	585752	20024T	PARTICIPANT	\N	PRESENT	0
587540	585752	20044X	PARTICIPANT	\N	PRESENT	0
587541	585752	19689Q	PARTICIPANT	\N	PRESENT	0
587542	585752	14213J	PARTICIPANT	\N	PRESENT	0
587543	585752	19387D	PARTICIPANT	\N	PRESENT	0
587544	585752	19768N	PARTICIPANT	\N	PRESENT	0
587545	585752	20116W	PARTICIPANT	\N	PRESENT	0
587546	585752	04043D	PARTICIPANT	\N	PRESENT	0
587547	585752	17229F	PARTICIPANT	\N	PRESENT	0
587548	585752	07033P	PARTICIPANT	\N	PRESENT	0
587549	585752	19691J	PARTICIPANT	\N	PRESENT	0
587550	585752	14217N	PARTICIPANT	\N	PRESENT	0
587551	585752	20120S	PARTICIPANT	\N	PRESENT	0
587552	585752	19713W	PARTICIPANT	\N	PRESENT	0
587553	585752	20152B	PARTICIPANT	\N	PRESENT	0
587554	585752	20020P	PARTICIPANT	\N	PRESENT	0
587555	585752	16685X	PARTICIPANT	\N	PRESENT	0
587559	585752	20126Y	PARTICIPANT	\N	PRESENT	0
587557	585752	19383Y	PARTICIPANT	\N	PRESENT	0
587558	585752	20124W	PARTICIPANT	\N	PRESENT	0
585689	583340	20062A	PARTICIPANT	\N	PRESENT	0
585693	583340	14179A	PARTICIPANT	\N	PRESENT	0
585694	583340	20052X	PARTICIPANT	\N	PRESENT	1
585853	585839	19415P	PARTICIPANT	\N	PRESENT	0
585854	585839	14042U	PARTICIPANT	\N	PRESENT	0
585855	585839	18193Q	PARTICIPANT	\N	PRESENT	0
585856	585839	11067R	PARTICIPANT	\N	PRESENT	0
585857	585839	20130U	PARTICIPANT	\N	PRESENT	0
585858	585840	19415P	PARTICIPANT	\N	PRESENT	0
585859	585840	14042U	PARTICIPANT	\N	PRESENT	0
585860	585840	11031D	PARTICIPANT	\N	PRESENT	0
585861	585840	18193Q	PARTICIPANT	\N	PRESENT	0
585862	585840	19723Y	PARTICIPANT	\N	PRESENT	0
585863	585840	20130U	PARTICIPANT	\N	PRESENT	0
585864	585840	11097X	PARTICIPANT	\N	PRESENT	0
585865	585841	19415P	PARTICIPANT	\N	PRESENT	0
585866	585841	14042U	PARTICIPANT	\N	PRESENT	0
585867	585842	19415P	PARTICIPANT	\N	PRESENT	0
585868	585843	19415P	PARTICIPANT	\N	PRESENT	0
585869	585843	14042U	PARTICIPANT	\N	PRESENT	0
585870	585844	19415P	PARTICIPANT	\N	PRESENT	0
585871	585844	14042U	PARTICIPANT	\N	PRESENT	0
585872	585845	19415P	PARTICIPANT	\N	PRESENT	0
585873	585845	14042U	PARTICIPANT	\N	PRESENT	0
585874	585845	20130U	PARTICIPANT	\N	PRESENT	0
585875	585846	19415P	PARTICIPANT	\N	PRESENT	0
585876	585846	11067R	PARTICIPANT	\N	PRESENT	0
585877	585847	19415P	PARTICIPANT	\N	PRESENT	0
585878	585847	11067R	PARTICIPANT	\N	PRESENT	0
585879	585847	20130U	PARTICIPANT	\N	PRESENT	0
585880	585848	19683J	PARTICIPANT	\N	PRESENT	0
585881	585849	19683J	PARTICIPANT	\N	PRESENT	0
585882	585850	19683J	PARTICIPANT	\N	PRESENT	0
585883	585851	19683J	PARTICIPANT	\N	PRESENT	0
585884	585852	19683J	PARTICIPANT	\N	PRESENT	0
585971	585408	14189C	PARTICIPANT	\N	EXCUSE	0
586795	586794	11040E	PARTICIPANT	\N	PRESENT	0
586796	586794	19479G	PARTICIPANT	\N	PRESENT	0
586798	586797	11040E	PARTICIPANT	\N	PRESENT	0
586799	586797	19479G	PARTICIPANT	\N	PRESENT	0
587360	585625	19701S	PARTICIPANT	\N	PRESENT	0
587361	585625	11026G	PARTICIPANT	\N	PRESENT	0
587362	585625	14331P	PRESIDENT	0	PRESENT	0
587363	585625	14089Y	PARTICIPANT	\N	PRESENT	0
587364	585625	20098N	PARTICIPANT	\N	PRESENT	0
587365	585625	19563B	PARTICIPANT	\N	PRESENT	0
587366	585625	14026U	PARTICIPANT	\N	PRESENT	0
587367	585625	19441R	PARTICIPANT	\N	PRESENT	0
587368	585625	10015M	PARTICIPANT	\N	PRESENT	0
587369	585625	14001X	PARTICIPANT	\N	PRESENT	0
587370	585625	19531S	PARTICIPANT	\N	PRESENT	0
587372	585625	20104S	PARTICIPANT	\N	PRESENT	0
587373	585625	19333N	PARTICIPANT	\N	PRESENT	0
587374	585625	11083R	PARTICIPANT	\N	PRESENT	1
587375	585625	11101A	PARTICIPANT	\N	PRESENT	0
587378	585625	14097Y	PARTICIPANT	\N	PRESENT	1
587380	585625	04070G	PARTICIPANT	\N	EXCUSE	0
587381	585625	14189C	PARTICIPANT	\N	EXCUSE	0
587382	585625	20100N	PARTICIPANT	\N	EXCUSE	0
587560	585752	19735D	PARTICIPANT	\N	PRESENT	0
587561	585752	20054A	PARTICIPANT	\N	PRESENT	0
587562	585752	11031D	PARTICIPANT	\N	PRESENT	0
587563	585752	14059S	PARTICIPANT	\N	PRESENT	0
587564	585752	20052X	PARTICIPANT	\N	PRESENT	0
587565	585752	11053K	PARTICIPANT	\N	PRESENT	0
587566	585752	20252E	PARTICIPANT	\N	PRESENT	0
587567	585752	20144B	PARTICIPANT	\N	PRESENT	0
587568	585752	14251Q	PARTICIPANT	\N	PRESENT	0
587569	585752	19611R	PARTICIPANT	\N	PRESENT	0
587570	585752	14329V	PARTICIPANT	\N	PRESENT	0
587571	585752	19369B	PARTICIPANT	\N	PRESENT	0
587572	585752	19621T	PARTICIPANT	\N	PRESENT	0
587573	585752	14083S	PARTICIPANT	\N	PRESENT	0
587574	585752	14267Y	PARTICIPANT	\N	PRESENT	0
587575	585752	19367Y	PARTICIPANT	\N	PRESENT	0
587576	585752	19826F	PARTICIPANT	\N	PRESENT	0
587577	585752	14255U	PARTICIPANT	\N	PRESENT	0
587578	585752	04070G	PARTICIPANT	\N	PRESENT	0
587579	585752	01024M	PARTICIPANT	\N	PRESENT	0
587580	585752	14327T	PARTICIPANT	\N	PRESENT	0
587581	585752	14030Q	PARTICIPANT	\N	PRESENT	0
587582	585752	01043Q	PARTICIPANT	\N	PRESENT	0
587583	585752	19335Q	PARTICIPANT	\N	PRESENT	0
587584	585752	14055N	PARTICIPANT	\N	PRESENT	0
587585	585752	17965H	PARTICIPANT	\N	PRESENT	0
587586	585752	01062T	PARTICIPANT	\N	PRESENT	0
587587	585752	19685L	PARTICIPANT	\N	PRESENT	0
587588	585752	11103C	PARTICIPANT	\N	PRESENT	0
587589	585752	20048C	PARTICIPANT	\N	PRESENT	0
587590	585752	19749K	PARTICIPANT	\N	PRESENT	0
587591	585752	20090E	PARTICIPANT	\N	PRESENT	0
587592	585752	14357A	PARTICIPANT	\N	PRESENT	0
587593	585752	98018T	PARTICIPANT	\N	PRESENT	0
587594	585752	20172F	PARTICIPANT	\N	PRESENT	0
587595	585752	04035D	PARTICIPANT	\N	PRESENT	0
587596	585752	19533U	PARTICIPANT	\N	PRESENT	0
587597	585752	19415P	PARTICIPANT	\N	PRESENT	0
587598	585752	19762G	PARTICIPANT	\N	PRESENT	0
587599	585752	19687N	PARTICIPANT	\N	PRESENT	0
587600	585752	14071N	PARTICIPANT	\N	PRESENT	0
587601	585752	14223L	PARTICIPANT	\N	PRESENT	0
587605	585752	17023S	PARTICIPANT	\N	PRESENT	0
587603	585752	20080C	PARTICIPANT	\N	PRESENT	0
587604	585752	14205J	PARTICIPANT	\N	PRESENT	0
587606	585752	20040T	PARTICIPANT	\N	PRESENT	0
587607	585752	19745F	PARTICIPANT	\N	PRESENT	0
587608	585752	11045K	PARTICIPANT	\N	PRESENT	0
587609	585752	11048N	PARTICIPANT	\N	PRESENT	0
587610	585752	20018V	PARTICIPANT	\N	PRESENT	0
587611	585752	20064C	PARTICIPANT	\N	PRESENT	0
587612	585752	01058X	PARTICIPANT	\N	PRESENT	0
587613	585752	14042U	PARTICIPANT	\N	PRESENT	0
587614	585752	20066E	PARTICIPANT	\N	PRESENT	0
587616	585752	19447X	PARTICIPANT	\N	PRESENT	0
587617	585752	20130U	PARTICIPANT	\N	PRESENT	0
587620	585752	08047A	PARTICIPANT	\N	PRESENT	0
587621	585752	11085T	PARTICIPANT	\N	PRESENT	0
587622	585752	19551W	PARTICIPANT	\N	PRESENT	0
587626	585752	14089Y	PARTICIPANT	\N	PRESENT	0
587862	585753	11043H	PARTICIPANT	\N	PRESENT	0
587625	585752	04071H	PARTICIPANT	\N	PRESENT	0
587857	585753	99004R	PARTICIPANT	\N	PRESENT	0
587858	585753	20090E	PARTICIPANT	\N	PRESENT	0
587860	585753	17737W	PARTICIPANT	\N	PRESENT	0
587861	585753	20110Q	PARTICIPANT	\N	PRESENT	0
587863	585753	14053L	PARTICIPANT	\N	PRESENT	0
587864	585753	19729F	PARTICIPANT	\N	PRESENT	0
587865	585753	14215L	PARTICIPANT	\N	PRESENT	0
587866	585753	14123H	PARTICIPANT	\N	PRESENT	0
587867	585753	19749K	PARTICIPANT	\N	PRESENT	0
587868	585753	11056N	PARTICIPANT	\N	PRESENT	0
587869	585753	19367Y	PARTICIPANT	\N	PRESENT	0
587870	585753	19515S	PARTICIPANT	\N	PRESENT	0
587871	585753	14089Y	PARTICIPANT	\N	PRESENT	0
587872	585753	20048C	PARTICIPANT	\N	PRESENT	0
587873	585753	20114U	PARTICIPANT	\N	PRESENT	0
587874	585753	14207L	PARTICIPANT	\N	PRESENT	0
587875	585753	19629C	PARTICIPANT	\N	PRESENT	0
587876	585753	20024T	PARTICIPANT	\N	PRESENT	0
587877	585753	20138D	PARTICIPANT	\N	PRESENT	0
587878	585753	19563B	PARTICIPANT	\N	PRESENT	0
587879	585753	19447X	PARTICIPANT	\N	PRESENT	0
587880	585753	01048V	PARTICIPANT	\N	PRESENT	0
587881	585753	19697Q	PARTICIPANT	\N	PRESENT	0
587882	585753	01028R	PARTICIPANT	\N	PRESENT	0
587883	585753	20030R	PARTICIPANT	\N	PRESENT	0
587884	587618	20032T	PARTICIPANT	\N	PRESENT	0
587885	587618	11048N	PARTICIPANT	\N	PRESENT	0
587886	587618	20092G	PARTICIPANT	\N	PRESENT	0
587887	587618	19711U	PARTICIPANT	\N	PRESENT	0
587888	587618	14357A	PRESIDENT	0	PRESENT	0
587889	587618	19413M	PARTICIPANT	\N	PRESENT	0
587890	587618	14033T	PARTICIPANT	\N	PRESENT	0
587891	587618	20102Q	PARTICIPANT	\N	PRESENT	0
587892	587618	20054A	PARTICIPANT	\N	PRESENT	0
587893	587618	19507S	PARTICIPANT	\N	PRESENT	0
587894	587618	20070A	PARTICIPANT	\N	PRESENT	0
587895	587618	19503N	PARTICIPANT	\N	PRESENT	0
570928	570925	14071N	PARTICIPANT	\N	PRESENT	0
570932	570925	19575F	PARTICIPANT	\N	PRESENT	0
570933	570925	19798U	PARTICIPANT	\N	PRESENT	0
570937	570925	20038A	PARTICIPANT	\N	PRESENT	0
570938	570925	11083R	PARTICIPANT	\N	PRESENT	0
570940	570925	14097Y	PARTICIPANT	\N	PRESENT	0
585913	585650	20248J	PARTICIPANT	\N	PRESENT	0
585914	585650	11097X	PARTICIPANT	\N	PRESENT	0
585915	585650	14042U	PARTICIPANT	\N	PRESENT	0
585916	585650	19367Y	PARTICIPANT	\N	PRESENT	0
585917	585650	14213J	PARTICIPANT	\N	PRESENT	0
585918	585650	14071N	PARTICIPANT	\N	PRESENT	0
585919	585650	14217N	PARTICIPANT	\N	PRESENT	0
585920	585650	10006L	PRESIDENT	0	PRESENT	0
585921	585650	19683J	PARTICIPANT	\N	PRESENT	0
585922	585650	17779H	PARTICIPANT	\N	PRESENT	0
585931	585408	19647E	PARTICIPANT	\N	PRESENT	0
585932	585408	19711U	PARTICIPANT	\N	PRESENT	0
585933	585408	19545Y	PRESIDENT	0	PRESENT	0
585934	585408	19687N	PARTICIPANT	\N	PRESENT	0
585935	585408	11053K	PARTICIPANT	\N	PRESENT	0
585936	585408	12016W	PARTICIPANT	\N	PRESENT	0
585937	585408	19741B	PARTICIPANT	\N	PRESENT	0
585938	585408	99004R	PARTICIPANT	\N	PRESENT	0
585939	585408	19335Q	PARTICIPANT	\N	PRESENT	0
585940	585408	20022R	PARTICIPANT	\N	PRESENT	0
585941	585408	14225N	PARTICIPANT	\N	PRESENT	0
585942	585408	11070L	PARTICIPANT	\N	PRESENT	0
585943	585408	01057W	PARTICIPANT	\N	PRESENT	0
585944	585408	19349W	PARTICIPANT	\N	PRESENT	0
585945	585408	11074Q	PARTICIPANT	\N	PRESENT	0
585946	585408	08011M	PARTICIPANT	\N	PRESENT	0
585947	585408	19689Q	PARTICIPANT	\N	PRESENT	0
585948	585408	20080C	PARTICIPANT	\N	PRESENT	0
585949	585408	11048N	PARTICIPANT	\N	PRESENT	0
585951	585408	11040E	PARTICIPANT	\N	PRESENT	0
585952	585730	99004R	PARTICIPANT	\N	PRESENT	0
585953	585650	19569H	PARTICIPANT	\N	PRESENT	0
585954	585650	19663E	PARTICIPANT	\N	PRESENT	0
585955	585650	11031D	PARTICIPANT	\N	PRESENT	0
585956	585650	19553Y	PARTICIPANT	\N	PRESENT	0
585957	585408	19671E	PARTICIPANT	\N	EXCUSE	0
585961	585730	19689Q	PARTICIPANT	\N	PRESENT	0
585962	585730	19741B	PARTICIPANT	\N	PRESENT	0
585963	585730	19711U	PARTICIPANT	\N	PRESENT	0
585964	585730	19593H	PARTICIPANT	\N	PRESENT	0
585965	585730	11048N	PARTICIPANT	\N	PRESENT	0
585966	585730	20080C	PARTICIPANT	\N	PRESENT	0
585967	585730	11040E	PARTICIPANT	\N	PRESENT	0
585968	585730	19651A	PARTICIPANT	\N	PRESENT	0
585969	585730	20130U	PARTICIPANT	\N	PRESENT	0
585970	585730	10015M	PARTICIPANT	\N	PRESENT	0
585972	585730	19335Q	PARTICIPANT	\N	PRESENT	0
585973	585730	14225N	PARTICIPANT	\N	PRESENT	0
585974	585730	19687N	PARTICIPANT	\N	PRESENT	0
585975	585730	01057W	PARTICIPANT	\N	PRESENT	0
585976	585730	19545Y	PARTICIPANT	\N	PRESENT	0
585977	585730	11074Q	PARTICIPANT	\N	PRESENT	0
585978	585730	19349W	PARTICIPANT	\N	PRESENT	0
585979	585730	11053K	PARTICIPANT	\N	PRESENT	0
585982	585730	19647E	PARTICIPANT	\N	PRESENT	0
585983	585730	19954N	PARTICIPANT	\N	PRESENT	0
585984	585730	11070L	PARTICIPANT	\N	PRESENT	0
585985	585730	20022R	PARTICIPANT	\N	PRESENT	0
585986	585730	11012A	PARTICIPANT	\N	PRESENT	0
585987	585730	19531S	PARTICIPANT	\N	PRESENT	0
585988	585730	14213J	PARTICIPANT	\N	PRESENT	0
585989	585730	11097X	PARTICIPANT	\N	PRESENT	0
585990	585730	19569H	PARTICIPANT	\N	PRESENT	0
585994	585730	01034P	PARTICIPANT	\N	PRESENT	0
586004	585730	19695N	PARTICIPANT	\N	PRESENT	0
586011	585730	14217N	PARTICIPANT	\N	PRESENT	0
586012	585730	10006L	PARTICIPANT	\N	PRESENT	0
586013	585730	19629C	PARTICIPANT	\N	PRESENT	0
586014	585730	14071N	PARTICIPANT	\N	PRESENT	0
586015	585730	19713W	PARTICIPANT	\N	PRESENT	0
586016	585730	20108W	PARTICIPANT	\N	PRESENT	0
586017	585730	19663E	PARTICIPANT	\N	PRESENT	0
586022	585730	11026G	PARTICIPANT	\N	PRESENT	0
586023	585730	19760E	PARTICIPANT	\N	PRESENT	0
586024	585730	20090E	PARTICIPANT	\N	PRESENT	0
586058	585734	14071N	PARTICIPANT	\N	PRESENT	0
586059	585734	11012A	PARTICIPANT	\N	PRESENT	0
586060	585734	11053K	PARTICIPANT	\N	PRESENT	0
586061	585734	11040E	PARTICIPANT	\N	PRESENT	0
586062	585734	19687N	PARTICIPANT	\N	PRESENT	0
586063	585734	14195A	PARTICIPANT	\N	PRESENT	0
586064	585734	11074Q	PARTICIPANT	\N	PRESENT	0
586065	585734	19741B	PARTICIPANT	\N	PRESENT	0
586066	585734	19553Y	PARTICIPANT	\N	PRESENT	0
586067	585734	11048N	PARTICIPANT	\N	PRESENT	0
586068	585734	14225N	PARTICIPANT	\N	PRESENT	0
586069	585734	20130U	PARTICIPANT	\N	PRESENT	0
586070	585734	19689Q	PARTICIPANT	\N	PRESENT	0
586071	585734	19647E	PARTICIPANT	\N	PRESENT	0
586072	585734	19691J	PARTICIPANT	\N	PRESENT	0
586073	585734	20080C	PARTICIPANT	\N	PRESENT	0
586074	585734	20090E	PARTICIPANT	\N	PRESENT	0
586075	585734	11070L	PARTICIPANT	\N	PRESENT	0
586076	585734	20248J	PARTICIPANT	\N	PRESENT	0
586077	585734	11026G	PARTICIPANT	\N	PRESENT	0
586078	585734	19349W	PARTICIPANT	\N	PRESENT	0
586079	585734	19335Q	PARTICIPANT	\N	PRESENT	0
586080	585734	20252E	PARTICIPANT	\N	PRESENT	0
586081	585734	11097X	PARTICIPANT	\N	PRESENT	0
586082	585734	14213J	PARTICIPANT	\N	PRESENT	0
586083	585734	19531S	PARTICIPANT	\N	PRESENT	0
586084	585734	19367Y	PARTICIPANT	\N	PRESENT	0
586085	585734	01057W	PARTICIPANT	\N	PRESENT	0
586086	585734	19760E	PARTICIPANT	\N	PRESENT	0
586087	585734	19723Y	PARTICIPANT	\N	PRESENT	0
586088	585734	14217N	PARTICIPANT	\N	PRESENT	0
586056	585734	11045K	PARTICIPANT	\N	PRESENT	0
586057	585734	19629C	PARTICIPANT	\N	PRESENT	0
586089	585734	20140W	PARTICIPANT	\N	PRESENT	0
586093	585734	14089Y	PARTICIPANT	\N	PRESENT	0
586091	585734	07029T	PARTICIPANT	\N	PRESENT	0
586092	585734	14042U	PARTICIPANT	\N	PRESENT	0
586094	585734	19683J	PARTICIPANT	\N	PRESENT	0
586095	585734	10006L	PARTICIPANT	\N	PRESENT	0
586096	585734	19545Y	PARTICIPANT	\N	PRESENT	0
586097	585734	19301E	PARTICIPANT	\N	PRESENT	0
586098	585734	11031D	PARTICIPANT	\N	PRESENT	0
586099	585734	01034P	PARTICIPANT	\N	PRESENT	0
586139	585741	11045K	PARTICIPANT	\N	PRESENT	0
586140	585741	19760E	PARTICIPANT	\N	PRESENT	0
586141	585741	11031D	PARTICIPANT	\N	PRESENT	0
586142	585741	11074Q	PARTICIPANT	\N	PRESENT	0
586143	585741	19683J	PARTICIPANT	\N	PRESENT	0
586144	585741	20080C	PARTICIPANT	\N	PRESENT	0
586145	585741	19349W	PARTICIPANT	\N	PRESENT	0
586146	585741	20130U	PARTICIPANT	\N	PRESENT	0
586147	585741	19553Y	PARTICIPANT	\N	PRESENT	0
586148	585741	11012A	PARTICIPANT	\N	PRESENT	0
586149	585741	11048N	PARTICIPANT	\N	PRESENT	0
586150	585741	14195A	PARTICIPANT	\N	PRESENT	0
586151	585741	19301E	PARTICIPANT	\N	PRESENT	0
586152	585741	14042U	PARTICIPANT	\N	PRESENT	0
586153	585741	07029T	PARTICIPANT	\N	PRESENT	0
586154	585741	14213J	PARTICIPANT	\N	PRESENT	0
586155	585741	19723Y	PARTICIPANT	\N	PRESENT	0
586156	585741	20090E	PARTICIPANT	\N	PRESENT	0
586157	585741	11097X	PARTICIPANT	\N	PRESENT	0
586158	585741	14217N	PARTICIPANT	\N	PRESENT	0
586159	585741	14071N	PARTICIPANT	\N	PRESENT	0
586160	585741	20252E	PARTICIPANT	\N	PRESENT	0
586161	585741	19367Y	PARTICIPANT	\N	PRESENT	0
586162	585741	10006L	PARTICIPANT	\N	PRESENT	0
586163	585741	01034P	PARTICIPANT	\N	PRESENT	0
586164	585741	17023S	PARTICIPANT	\N	PRESENT	0
586165	585741	19545Y	PARTICIPANT	\N	PRESENT	0
586166	585741	19569H	PARTICIPANT	\N	PRESENT	0
587170	585658	10006L	PRESIDENT	0	PRESENT	0
587171	585658	19295A	PARTICIPANT	\N	EXCUSE	0
587172	585658	04057K	PARTICIPANT	\N	EXCUSE	0
587173	585658	04043D	PARTICIPANT	\N	PRESENT	0
587174	585658	20040T	PARTICIPANT	\N	PRESENT	0
599129	597713	19673G	PARTICIPANT	\N	PRESENT	0
599130	597713	10015M	PARTICIPANT	\N	PRESENT	0
599131	597713	14215L	PRESIDENT	0	PRESENT	0
599132	597713	19675J	PARTICIPANT	\N	PRESENT	0
589827	588536	20070A	PARTICIPANT	\N	PRESENT	0
589828	588536	19563B	PARTICIPANT	\N	PRESENT	0
589829	588536	14267Y	PARTICIPANT	\N	PRESENT	0
589830	588536	14053L	PARTICIPANT	\N	PRESENT	0
589834	588536	20264J	PARTICIPANT	\N	PRESENT	0
589832	588536	14179A	PARTICIPANT	\N	PRESENT	0
589833	588536	19057M	PARTICIPANT	\N	PRESENT	0
589835	588536	19725B	PARTICIPANT	\N	PRESENT	0
589836	588536	20052X	PARTICIPANT	\N	PRESENT	0
589837	588536	11085T	PARTICIPANT	\N	PRESENT	0
589838	588536	14089Y	PARTICIPANT	\N	PRESENT	0
589839	588536	19826F	PARTICIPANT	\N	PRESENT	0
589840	588536	19577H	PARTICIPANT	\N	PRESENT	0
589841	588536	14195A	PARTICIPANT	\N	PRESENT	0
589842	588536	14026U	PARTICIPANT	\N	PRESENT	0
589843	588536	99004R	PARTICIPANT	\N	PRESENT	0
589844	588536	19766L	PARTICIPANT	\N	PRESENT	0
589845	588536	20038A	PARTICIPANT	\N	PRESENT	0
589846	588536	19954N	PARTICIPANT	\N	PRESENT	0
589847	588536	17779H	PARTICIPANT	\N	PRESENT	0
589848	588536	19649G	PARTICIPANT	\N	PRESENT	0
589849	588536	20142Y	PARTICIPANT	\N	PRESENT	0
589850	588536	19782L	PARTICIPANT	\N	PRESENT	0
589851	588536	20110Q	PARTICIPANT	\N	PRESENT	0
589852	588536	08045X	PARTICIPANT	\N	PRESENT	0
589853	588536	19333N	PARTICIPANT	\N	PRESENT	0
589854	588536	19717B	PARTICIPANT	\N	PRESENT	0
589855	588536	14207L	PARTICIPANT	\N	PRESENT	0
589856	588536	20116W	PARTICIPANT	\N	PRESENT	0
589857	588536	19719D	PARTICIPANT	\N	PRESENT	0
589858	588536	14251Q	PARTICIPANT	\N	PRESENT	0
589859	588536	19301E	PARTICIPANT	\N	PRESENT	0
589861	588536	19549D	PARTICIPANT	\N	PRESENT	0
589862	589860	20094J	PARTICIPANT	\N	PRESENT	0
589863	588536	19599P	PARTICIPANT	\N	PRESENT	0
589864	589860	20018V	PARTICIPANT	\N	PRESENT	0
589865	588536	14121F	PARTICIPANT	\N	PRESENT	0
589866	589860	19575F	PARTICIPANT	\N	PRESENT	0
589867	589860	14189C	PARTICIPANT	\N	PRESENT	0
589868	588536	18193Q	PARTICIPANT	\N	PRESENT	0
589869	588536	11110B	PARTICIPANT	\N	PRESENT	0
589870	589860	19549D	PARTICIPANT	\N	PRESENT	0
589871	588536	19820Y	PARTICIPANT	\N	PRESENT	0
589872	588536	14225N	PARTICIPANT	\N	PRESENT	0
589873	588536	19729F	PARTICIPANT	\N	PRESENT	0
589874	588536	01058X	PARTICIPANT	\N	PRESENT	0
589875	588536	19667J	PARTICIPANT	\N	PRESENT	0
589876	588536	20048C	PARTICIPANT	\N	PRESENT	0
589877	588536	19739H	PARTICIPANT	\N	PRESENT	0
589878	588536	19619A	PARTICIPANT	\N	PRESENT	0
589879	588536	20018V	PARTICIPANT	\N	PRESENT	0
589880	588536	19503N	PARTICIPANT	\N	PRESENT	0
589881	588536	17965H	PARTICIPANT	\N	PRESENT	0
589882	588536	19489J	PARTICIPANT	\N	PRESENT	0
589883	588536	19631V	PARTICIPANT	\N	PRESENT	0
589884	588536	14257W	PARTICIPANT	\N	PRESENT	0
589885	588536	04059M	PARTICIPANT	\N	PRESENT	0
589886	588536	19715Y	PARTICIPANT	\N	PRESENT	0
589887	588536	04085P	PARTICIPANT	\N	PRESENT	0
589888	588536	19695N	PARTICIPANT	\N	PRESENT	0
589889	588536	19565D	PARTICIPANT	\N	PRESENT	0
589890	588536	04045F	PARTICIPANT	\N	PRESENT	0
589891	588536	20106U	PARTICIPANT	\N	PRESENT	0
589892	588536	19651A	PARTICIPANT	\N	PRESENT	0
589893	588536	20058E	PARTICIPANT	\N	PRESENT	0
589894	588536	19573D	PARTICIPANT	\N	PRESENT	0
589896	588536	19467C	PARTICIPANT	\N	PRESENT	0
589897	588536	19709B	PARTICIPANT	\N	PRESENT	0
589899	588536	14033T	PARTICIPANT	\N	PRESENT	0
589900	588536	19349W	PARTICIPANT	\N	PRESENT	0
589901	588536	20128B	PARTICIPANT	\N	PRESENT	0
589902	588536	19443T	PARTICIPANT	\N	PRESENT	0
589903	588536	20150Y	PARTICIPANT	\N	PRESENT	0
589904	588536	20026V	PARTICIPANT	\N	PRESENT	0
589905	588536	19697Q	PARTICIPANT	\N	PRESENT	0
589906	588536	11083R	PARTICIPANT	\N	PRESENT	0
589907	588536	19515S	PARTICIPANT	\N	PRESENT	0
589909	588536	14055N	PARTICIPANT	\N	PRESENT	0
589910	588536	14259Y	PARTICIPANT	\N	PRESENT	0
589911	588536	11012A	PARTICIPANT	\N	PRESENT	0
589912	588536	19399H	PARTICIPANT	\N	PRESENT	0
589913	588536	20132W	PARTICIPANT	\N	PRESENT	0
589914	588536	20140W	PARTICIPANT	\N	PRESENT	0
589915	588536	20104S	PARTICIPANT	\N	PRESENT	0
589916	588536	20072C	PARTICIPANT	\N	PRESENT	0
589917	588536	20108W	PARTICIPANT	\N	PRESENT	0
589918	588536	01057W	PARTICIPANT	\N	PRESENT	0
589919	588536	20138D	PARTICIPANT	\N	PRESENT	0
589920	588536	19760E	PARTICIPANT	\N	PRESENT	0
589921	588536	11056N	PARTICIPANT	\N	PRESENT	0
589922	588536	20172F	PARTICIPANT	\N	PRESENT	0
589923	588536	20032T	PARTICIPANT	\N	PRESENT	0
589924	588536	14147R	PARTICIPANT	\N	PRESENT	0
589925	588536	14213J	PARTICIPANT	\N	PRESENT	0
589926	588536	20114U	PARTICIPANT	\N	PRESENT	0
589927	588536	20068G	PARTICIPANT	\N	PRESENT	0
589928	588536	20022R	PARTICIPANT	\N	PRESENT	0
589929	588536	05012A	PARTICIPANT	\N	PRESENT	0
589930	588536	19251M	PARTICIPANT	\N	PRESENT	0
589931	588536	11090Q	PARTICIPANT	\N	PRESENT	0
589932	588536	14151M	PARTICIPANT	\N	PRESENT	0
589933	588536	97011G	PARTICIPANT	\N	PRESENT	0
589934	588536	14281W	PARTICIPANT	\N	PRESENT	0
589935	588536	14329V	PARTICIPANT	\N	PRESENT	0
589936	588536	14357A	PARTICIPANT	\N	PRESENT	0
589937	588536	14001X	PARTICIPANT	\N	PRESENT	0
589938	588536	14059S	PARTICIPANT	\N	PRESENT	0
589939	588536	08056B	PARTICIPANT	\N	PRESENT	0
589940	588536	20126Y	PARTICIPANT	\N	PRESENT	0
589941	588536	19533U	PARTICIPANT	\N	PRESENT	0
589942	588536	14193X	PARTICIPANT	\N	PRESENT	0
589943	588536	08060W	PARTICIPANT	\N	PRESENT	0
589944	588536	20084G	PARTICIPANT	\N	PRESENT	0
589945	588536	19383Y	PARTICIPANT	\N	PRESENT	0
589946	588536	20060X	PARTICIPANT	\N	PRESENT	0
589947	588536	20080C	PARTICIPANT	\N	PRESENT	0
589948	588536	14217N	PARTICIPANT	\N	PRESENT	0
589949	588536	20094J	PARTICIPANT	\N	PRESENT	0
589950	588536	14215L	PARTICIPANT	\N	PRESENT	0
589951	588536	10006L	PARTICIPANT	\N	PRESENT	0
589952	588536	14069U	PARTICIPANT	\N	PRESENT	0
589953	588536	19367Y	PARTICIPANT	\N	PRESENT	0
589954	588536	19687N	PARTICIPANT	\N	PRESENT	0
589955	588536	19415P	PARTICIPANT	\N	PRESENT	0
589956	588536	11097X	PARTICIPANT	\N	PRESENT	0
589957	588536	14071N	PARTICIPANT	\N	PRESENT	0
589982	588536	20120S	PARTICIPANT	\N	PRESENT	0
589959	588536	19701S	PARTICIPANT	\N	PRESENT	0
589960	588536	19762G	PARTICIPANT	\N	PRESENT	0
589961	588536	14189C	PARTICIPANT	\N	PRESENT	0
589962	588536	20020P	PARTICIPANT	\N	PRESENT	0
589963	588536	07033P	PARTICIPANT	\N	PRESENT	0
589964	588536	14249W	PARTICIPANT	\N	PRESENT	0
589965	588536	19545Y	PARTICIPANT	\N	PRESENT	0
589966	588536	04033B	PARTICIPANT	\N	PRESENT	0
589968	588536	14187A	PARTICIPANT	\N	PRESENT	0
589969	588536	19679N	PARTICIPANT	\N	PRESENT	0
589970	588536	20076G	PARTICIPANT	\N	PRESENT	0
589971	588536	04057K	PARTICIPANT	\N	PRESENT	0
589972	588536	18083K	PARTICIPANT	\N	PRESENT	0
589973	588536	08069G	PARTICIPANT	\N	PRESENT	0
589974	588536	04042C	PARTICIPANT	\N	PRESENT	0
589975	588536	04092N	PARTICIPANT	\N	PRESENT	0
589976	588536	11048N	PARTICIPANT	\N	PRESENT	0
589977	588536	19747H	PARTICIPANT	\N	PRESENT	0
589978	588536	20042V	PARTICIPANT	\N	PRESENT	0
589979	588536	08010L	PARTICIPANT	\N	PRESENT	0
589980	588536	14030Q	PARTICIPANT	\N	PRESENT	0
589981	588536	11053K	PARTICIPANT	\N	PRESENT	0
589983	588536	19703U	PARTICIPANT	\N	PRESENT	0
589984	588536	14221J	PARTICIPANT	\N	PRESENT	0
589985	588536	04047H	PARTICIPANT	\N	PRESENT	0
589986	588536	04008A	PARTICIPANT	\N	PRESENT	0
589987	588536	01024M	PARTICIPANT	\N	PRESENT	0
589988	588536	19711U	PARTICIPANT	\N	PRESENT	0
589989	588536	20248J	PARTICIPANT	\N	PRESENT	0
589990	588536	17637T	PARTICIPANT	\N	PRESENT	0
570598	570597	14195A	PARTICIPANT	\N	PRESENT	0
570599	570597	08010L	PARTICIPANT	\N	PRESENT	0
570600	570597	04057K	PARTICIPANT	\N	PRESENT	0
570601	570597	20062A	PARTICIPANT	\N	PRESENT	0
574218	573011	20110Q	PARTICIPANT	\N	PRESENT	0
574219	573011	11085T	PARTICIPANT	\N	PRESENT	0
574220	573011	14147R	PARTICIPANT	\N	PRESENT	0
574221	573011	14179A	PARTICIPANT	\N	PRESENT	0
574222	573011	19954N	PARTICIPANT	\N	PRESENT	0
574223	573011	14111D	PARTICIPANT	\N	PRESENT	0
574224	573011	20068G	PARTICIPANT	\N	PRESENT	0
574225	573011	14021P	PARTICIPANT	\N	PRESENT	0
574226	573011	04092N	PARTICIPANT	\N	PRESENT	0
574229	572778	20090E	PARTICIPANT	\N	PRESENT	0
574230	572778	11067R	PARTICIPANT	\N	PRESENT	0
574231	572778	04092N	PARTICIPANT	\N	PRESENT	0
574232	572778	19713W	PARTICIPANT	\N	PRESENT	0
574233	572778	19798U	PARTICIPANT	\N	PRESENT	0
574234	572778	11097X	PARTICIPANT	\N	PRESENT	0
574235	572778	20040T	PARTICIPANT	\N	PRESENT	0
574236	572778	19691J	PARTICIPANT	\N	PRESENT	0
574237	572778	19679N	PARTICIPANT	\N	PRESENT	0
574238	572778	14195A	PARTICIPANT	\N	PRESENT	0
574239	572778	19367Y	PARTICIPANT	\N	PRESENT	0
574240	572778	14217N	PARTICIPANT	\N	PRESENT	0
574241	572778	04043D	PARTICIPANT	\N	PRESENT	0
574242	572778	10006L	PRESIDENT	0	PRESENT	0
574252	573339	04035D	PARTICIPANT	\N	PRESENT	0
574253	573339	01062T	PARTICIPANT	\N	PRESENT	0
574254	573339	19565D	PARTICIPANT	\N	PRESENT	0
574255	573339	14133K	PARTICIPANT	\N	PRESENT	0
574256	573339	20042V	PARTICIPANT	\N	PRESENT	0
574257	573339	04042C	PRESIDENT	0	PRESENT	0
574258	573339	01024M	PARTICIPANT	\N	PRESENT	0
574259	573339	08056B	PARTICIPANT	\N	PRESENT	0
574260	573339	12028B	PARTICIPANT	\N	PRESENT	0
574261	573339	14105F	PARTICIPANT	\N	PRESENT	1
574262	573339	14267Y	PARTICIPANT	\N	PRESENT	0
574263	573339	19347U	PARTICIPANT	\N	PRESENT	0
574264	573339	11083R	PARTICIPANT	\N	PRESENT	0
574265	573339	97011G	PARTICIPANT	\N	PRESENT	0
574266	573339	14255U	PARTICIPANT	\N	PRESENT	0
574267	573339	17023S	PARTICIPANT	\N	PRESENT	0
574268	573339	08047A	PARTICIPANT	\N	PRESENT	0
574270	573339	98018T	PARTICIPANT	\N	PRESENT	1
574271	572787	14327T	PARTICIPANT	\N	PRESENT	0
574272	572787	14331P	PARTICIPANT	\N	PRESENT	0
574273	572787	11048N	PARTICIPANT	\N	PRESENT	0
574274	572787	19479G	PARTICIPANT	\N	PRESENT	0
574275	572787	19647E	PARTICIPANT	\N	PRESENT	0
574276	572787	19711U	PARTICIPANT	\N	PRESENT	0
574277	572787	01048V	PARTICIPANT	\N	PRESENT	0
574278	572787	01057W	PARTICIPANT	\N	PRESENT	0
574279	572787	19689Q	PARTICIPANT	\N	PRESENT	0
574280	572787	20080C	PARTICIPANT	\N	PRESENT	0
574281	572787	20050V	PARTICIPANT	\N	PRESENT	0
574282	572787	11074Q	PARTICIPANT	\N	PRESENT	0
574283	572787	08011M	PARTICIPANT	\N	PRESENT	0
574284	572787	20044X	PARTICIPANT	\N	PRESENT	0
574285	572787	14225N	PRESIDENT	0	PRESENT	0
574286	572787	11040E	PARTICIPANT	\N	PRESENT	0
574287	572787	14083S	PARTICIPANT	\N	PRESENT	0
574288	572787	20070A	PARTICIPANT	\N	PRESENT	0
574289	572787	19741B	PARTICIPANT	\N	PRESENT	0
574290	572787	08010L	PARTICIPANT	\N	PRESENT	0
574291	572787	99004R	PARTICIPANT	\N	PRESENT	0
574292	572787	19335Q	PARTICIPANT	\N	PRESENT	0
574293	572787	19762G	PARTICIPANT	\N	PRESENT	0
574403	573014	11056N	PARTICIPANT	\N	PRESENT	0
574404	573014	19489J	PARTICIPANT	\N	PRESENT	0
574405	573014	04047H	PRESIDENT	0	PRESENT	0
574406	573014	14259Y	PARTICIPANT	\N	PRESENT	0
574407	573014	14231L	PARTICIPANT	\N	PRESENT	0
574417	573014	20108W	PARTICIPANT	\N	PRESENT	0
574418	573014	14001X	PARTICIPANT	\N	PRESENT	0
574419	573014	20110Q	PARTICIPANT	\N	PRESENT	0
574425	573014	05008E	PARTICIPANT	\N	PRESENT	0
574426	573014	14111D	PARTICIPANT	\N	PRESENT	0
574427	573014	14147R	PARTICIPANT	\N	PRESENT	0
574428	573014	14215L	PARTICIPANT	\N	PRESENT	0
574432	573014	14053L	PARTICIPANT	\N	PRESENT	0
574435	573329	11041F	PARTICIPANT	\N	PRESENT	0
574436	573329	19729F	PARTICIPANT	\N	PRESENT	0
574437	573329	20090E	PARTICIPANT	\N	PRESENT	0
574438	573329	19399H	PARTICIPANT	\N	PRESENT	0
574439	573329	20056C	PARTICIPANT	\N	PRESENT	0
574440	573329	20034V	PARTICIPANT	\N	PRESENT	0
574441	573329	19735D	PARTICIPANT	\N	PRESENT	0
574442	573329	19525U	PARTICIPANT	\N	PRESENT	0
574443	573329	08045X	PARTICIPANT	\N	PRESENT	0
574444	573329	20046A	PARTICIPANT	\N	PRESENT	0
574445	573329	20102Q	PARTICIPANT	\N	PRESENT	0
574446	573329	20026V	PARTICIPANT	\N	PRESENT	0
574447	573329	19766L	PARTICIPANT	\N	PRESENT	0
574448	573329	08069G	PARTICIPANT	\N	PRESENT	0
574449	573329	19349W	PARTICIPANT	\N	PRESENT	0
574450	573329	14225N	PARTICIPANT	\N	PRESENT	0
574451	573329	14253S	PARTICIPANT	\N	PRESENT	0
574452	573329	19798U	PARTICIPANT	\N	PRESENT	0
574453	573329	04043D	PARTICIPANT	\N	PRESENT	0
574454	573329	14223L	PARTICIPANT	\N	PRESENT	0
574455	573329	20024T	PARTICIPANT	\N	PRESENT	0
574456	573329	20094J	PARTICIPANT	\N	PRESENT	0
574457	573329	19553Y	PARTICIPANT	\N	PRESENT	0
574458	573329	14111D	PARTICIPANT	\N	PRESENT	0
574459	573329	11043H	PARTICIPANT	\N	PRESENT	0
574460	573329	11101A	PARTICIPANT	\N	PRESENT	0
574461	573329	19683J	PARTICIPANT	\N	PRESENT	0
574462	573329	14205J	PARTICIPANT	\N	PRESENT	0
574463	573329	19507S	PARTICIPANT	\N	PRESENT	0
574464	573329	19563B	PARTICIPANT	\N	PRESENT	0
574465	573329	20052X	PARTICIPANT	\N	PRESENT	0
574466	573329	11066Q	PARTICIPANT	\N	PRESENT	0
574467	573329	19479G	PARTICIPANT	\N	PRESENT	0
574468	573329	20068G	PARTICIPANT	\N	PRESENT	0
574469	573329	20152B	PARTICIPANT	\N	PRESENT	0
574470	573329	20132W	PARTICIPANT	\N	PRESENT	0
574471	573329	17229F	PARTICIPANT	\N	PRESENT	0
574472	573329	11040E	PARTICIPANT	\N	PRESENT	0
574473	573329	07029T	PARTICIPANT	\N	PRESENT	0
574474	573329	86034E	PARTICIPANT	\N	PRESENT	0
574475	573329	20100N	PARTICIPANT	\N	PRESENT	0
574476	573329	14069U	PARTICIPANT	\N	PRESENT	0
574477	573329	20144B	PARTICIPANT	\N	PRESENT	0
574478	573329	19709B	PARTICIPANT	\N	PRESENT	0
574479	573329	11103C	PARTICIPANT	\N	PRESENT	0
574480	573329	19782L	PARTICIPANT	\N	PRESENT	0
574481	573329	19573D	PARTICIPANT	\N	PRESENT	0
574482	573329	19695N	PARTICIPANT	\N	PRESENT	0
574483	573329	11074Q	PARTICIPANT	\N	PRESENT	0
574484	573329	19621T	PARTICIPANT	\N	PRESENT	0
574485	573329	19741B	PARTICIPANT	\N	PRESENT	0
574486	573329	19619A	PARTICIPANT	\N	PRESENT	0
574487	573329	99004R	PARTICIPANT	\N	PRESENT	0
574488	573329	14031R	PARTICIPANT	\N	PRESENT	0
574489	573329	20042V	PARTICIPANT	\N	PRESENT	0
574490	573329	14329V	PARTICIPANT	\N	PRESENT	0
574491	573329	19585H	PARTICIPANT	\N	PRESENT	0
574492	573329	19467C	PARTICIPANT	\N	PRESENT	0
574493	573329	19768N	PARTICIPANT	\N	PRESENT	0
574494	573329	14109K	PARTICIPANT	\N	PRESENT	0
574495	573329	14251Q	PARTICIPANT	\N	PRESENT	0
574496	573329	20058E	PARTICIPANT	\N	PRESENT	0
574497	573329	14195A	PARTICIPANT	\N	PRESENT	0
574498	573329	11067R	PARTICIPANT	\N	PRESENT	0
574499	573329	20054A	PARTICIPANT	\N	PRESENT	0
574500	573329	19954N	PARTICIPANT	\N	PRESENT	0
574501	573329	19719D	PARTICIPANT	\N	PRESENT	0
574502	573329	19599P	PARTICIPANT	\N	PRESENT	0
574503	573329	01062T	PARTICIPANT	\N	PRESENT	0
574504	573329	20028X	PARTICIPANT	\N	PRESENT	0
574505	573329	14097Y	PARTICIPANT	\N	PRESENT	0
574506	573329	11065P	PARTICIPANT	\N	PRESENT	0
574507	573329	14071N	PARTICIPANT	\N	PRESENT	0
574508	573329	19711U	PARTICIPANT	\N	PRESENT	0
574509	573329	01057W	PARTICIPANT	\N	PRESENT	0
574510	573329	19611R	PARTICIPANT	\N	PRESENT	0
574511	573329	14073Q	PARTICIPANT	\N	PRESENT	0
574512	573329	20060X	PARTICIPANT	\N	PRESENT	0
574513	573329	20036X	PARTICIPANT	\N	PRESENT	0
574514	573329	20080C	PARTICIPANT	\N	PRESENT	0
587896	587618	19739H	PARTICIPANT	\N	PRESENT	0
587897	587618	19619A	PARTICIPANT	\N	PRESENT	0
587898	587618	20126Y	PARTICIPANT	\N	PRESENT	0
587899	586490	19383Y	PRESIDENT	0	PRESENT	0
587900	586490	14133K	PARTICIPANT	\N	PRESENT	0
587901	586490	20038A	PARTICIPANT	\N	PRESENT	0
587902	586490	19713W	PARTICIPANT	\N	PRESENT	0
587903	586490	19441R	PARTICIPANT	\N	PRESENT	0
587947	585753	14187A	PARTICIPANT	\N	PRESENT	0
587905	586490	19719D	PARTICIPANT	\N	PRESENT	0
587906	586490	19637C	PARTICIPANT	\N	PRESENT	0
587907	586490	14030Q	PARTICIPANT	\N	PRESENT	0
587908	586490	19551W	PARTICIPANT	\N	PRESENT	0
587909	586490	11099A	PARTICIPANT	\N	PRESENT	0
587910	586490	14109K	PARTICIPANT	\N	PRESENT	1
587911	586490	19758L	PARTICIPANT	\N	PRESENT	0
587933	585753	14021P	PARTICIPANT	\N	PRESENT	0
587913	586490	20028X	PARTICIPANT	\N	PRESENT	0
587914	586490	19762G	PARTICIPANT	\N	PRESENT	0
587915	585753	11012A	PARTICIPANT	\N	PRESENT	0
587916	585753	04085P	PARTICIPANT	\N	PRESENT	0
587917	586490	19798U	PARTICIPANT	\N	PRESENT	1
587918	585753	20124W	PARTICIPANT	\N	PRESENT	0
587919	585753	20136B	PARTICIPANT	\N	PRESENT	0
587920	585753	20086J	PARTICIPANT	\N	PRESENT	0
587921	587618	20144B	PARTICIPANT	\N	PRESENT	0
587922	585753	14083S	PARTICIPANT	\N	PRESENT	0
588011	585753	14030Q	PARTICIPANT	\N	PRESENT	0
587924	585753	11072N	PARTICIPANT	\N	PRESENT	0
587925	586490	19467C	PARTICIPANT	\N	PRESENT	0
587926	585753	14251Q	PARTICIPANT	\N	PRESENT	0
587927	585753	20020P	PARTICIPANT	\N	PRESENT	0
587928	585753	20108W	PARTICIPANT	\N	PRESENT	0
587929	585753	14205J	PARTICIPANT	\N	PRESENT	0
587930	585753	08061X	PARTICIPANT	\N	PRESENT	0
587931	585753	11097X	PARTICIPANT	\N	PRESENT	0
587932	585753	20022R	PARTICIPANT	\N	PRESENT	0
587940	585753	95063L	PARTICIPANT	\N	PRESENT	0
587942	585753	11067R	PARTICIPANT	\N	PRESENT	0
587943	585753	20180F	PARTICIPANT	\N	PRESENT	0
587944	585753	04047H	PARTICIPANT	\N	PRESENT	0
587945	585753	01024M	PARTICIPANT	\N	PRESENT	0
587946	586490	19621T	PARTICIPANT	\N	EXCUSE	0
587968	585753	20072C	PARTICIPANT	\N	PRESENT	0
587975	585753	07004J	PARTICIPANT	\N	PRESENT	0
587976	585753	19533U	PARTICIPANT	\N	PRESENT	0
587980	585753	14033T	PARTICIPANT	\N	PRESENT	0
587981	585753	20032T	PARTICIPANT	\N	PRESENT	0
587983	585753	19387D	PARTICIPANT	\N	PRESENT	0
587984	585753	20102Q	PARTICIPANT	\N	PRESENT	0
587985	585753	19467C	PARTICIPANT	\N	PRESENT	0
587986	585716	95041E	PARTICIPANT	\N	PRESENT	0
587987	585716	12041X	PARTICIPANT	\N	PRESENT	0
587988	585716	14133K	PARTICIPANT	\N	PRESENT	0
587989	585716	01062T	PARTICIPANT	\N	PRESENT	0
587990	585716	20072C	PARTICIPANT	\N	PRESENT	0
587991	585716	19565D	PARTICIPANT	\N	PRESENT	1
587992	585716	16685X	PARTICIPANT	\N	PRESENT	0
587993	585716	11027H	PARTICIPANT	\N	PRESENT	0
587994	585716	04042C	PRESIDENT	0	PRESENT	0
587995	585716	11054L	PARTICIPANT	\N	PRESENT	0
587996	585716	01024M	PARTICIPANT	\N	PRESENT	0
587997	585716	11066Q	PARTICIPANT	\N	PRESENT	0
587998	585716	19669L	PARTICIPANT	\N	PRESENT	0
587999	585716	12028B	PARTICIPANT	\N	PRESENT	0
588000	585716	20064C	PARTICIPANT	\N	PRESENT	0
588001	585716	98018T	PARTICIPANT	\N	PRESENT	0
588002	585716	19421M	PARTICIPANT	\N	PRESENT	0
588003	585716	14193X	PARTICIPANT	\N	PRESENT	0
588004	585716	14267Y	PARTICIPANT	\N	PRESENT	0
588005	585716	11083R	PARTICIPANT	\N	PRESENT	0
588006	585716	08061X	PARTICIPANT	\N	PRESENT	0
588007	585716	17023S	PARTICIPANT	\N	PRESENT	0
588008	585716	14255U	PARTICIPANT	\N	PRESENT	0
588009	585716	08047A	PARTICIPANT	\N	PRESENT	0
588010	585753	20104S	PARTICIPANT	\N	PRESENT	0
588012	585753	19649G	PARTICIPANT	\N	PRESENT	0
588013	585753	20036X	PARTICIPANT	\N	PRESENT	0
588014	585753	20044X	PARTICIPANT	\N	PRESENT	0
588015	585753	11026G	PARTICIPANT	\N	PRESENT	0
588016	585753	20082E	PARTICIPANT	\N	PRESENT	0
588018	585753	19747H	PARTICIPANT	\N	PRESENT	0
588020	585753	11048N	PARTICIPANT	\N	PRESENT	0
588021	585753	19441R	PARTICIPANT	\N	PRESENT	0
588022	585716	01058X	PARTICIPANT	\N	PRESENT	1
588023	585716	20042V	PARTICIPANT	\N	PRESENT	0
588024	585716	11064N	PARTICIPANT	\N	PRESENT	0
588025	585753	20052X	PARTICIPANT	\N	PRESENT	0
588026	585716	19443T	PARTICIPANT	\N	PRESENT	1
588027	585716	08056B	PARTICIPANT	\N	EXCUSE	0
588028	585753	19503N	PARTICIPANT	\N	PRESENT	0
588029	585716	19347U	PARTICIPANT	\N	PRESENT	0
588030	585753	20092G	PARTICIPANT	\N	PRESENT	0
588031	585753	14357A	PARTICIPANT	\N	PRESENT	0
588032	585753	20054A	PARTICIPANT	\N	PRESENT	0
588033	585753	20252E	PARTICIPANT	\N	PRESENT	0
588034	585753	20098N	PARTICIPANT	\N	PRESENT	0
588035	585753	05008E	PARTICIPANT	\N	PRESENT	0
588036	585753	19413M	PARTICIPANT	\N	PRESENT	0
588201	585815	14105F	PARTICIPANT	\N	PRESENT	0
588202	585815	19760E	PARTICIPANT	\N	PRESENT	0
588203	585815	20094J	PARTICIPANT	\N	PRESENT	0
588204	585815	19467C	PARTICIPANT	\N	PRESENT	0
588205	585815	14083S	PARTICIPANT	\N	PRESENT	0
588206	585815	14030Q	PARTICIPANT	\N	PRESENT	0
588207	585815	20048C	PARTICIPANT	\N	PRESENT	0
588208	585815	20030R	PARTICIPANT	\N	PRESENT	0
588209	585815	19762G	PARTICIPANT	\N	PRESENT	0
588210	585815	19671E	PARTICIPANT	\N	PRESENT	0
588211	585815	14357A	PARTICIPANT	\N	PRESENT	0
588212	585815	20040T	PARTICIPANT	\N	PRESENT	0
588213	585815	19301E	PARTICIPANT	\N	PRESENT	0
588214	585815	20054A	PARTICIPANT	\N	PRESENT	0
588215	585815	19717B	PARTICIPANT	\N	EXCUSE	0
588216	585815	08060W	PARTICIPANT	\N	EXCUSE	0
588217	585815	19545Y	PARTICIPANT	\N	EXCUSE	0
588218	585815	14195A	PARTICIPANT	\N	EXCUSE	0
588219	585815	08028W	PARTICIPANT	\N	EXCUSE	0
588220	585815	20134Y	PARTICIPANT	\N	EXCUSE	0
588221	585815	14026U	PARTICIPANT	\N	EXCUSE	0
588222	585815	20126Y	PARTICIPANT	\N	EXCUSE	0
588223	585815	08015R	PARTICIPANT	\N	EXCUSE	0
588224	585815	16685X	PARTICIPANT	\N	EXCUSE	0
588225	585815	19697Q	PARTICIPANT	\N	EXCUSE	0
588226	585815	14031R	PARTICIPANT	\N	EXCUSE	0
588227	585815	19369B	PARTICIPANT	\N	EXCUSE	0
588228	585815	20082E	PARTICIPANT	\N	PRESENT	0
588559	588558	19479G	PARTICIPANT	\N	PRESENT	0
588561	588560	14121F	PARTICIPANT	\N	PRESENT	0
588586	588585	08018U	PARTICIPANT	\N	PRESENT	0
588588	588587	08018U	PARTICIPANT	\N	PRESENT	0
588590	588589	08018U	PARTICIPANT	\N	PRESENT	0
588592	588591	08018U	PARTICIPANT	\N	PRESENT	0
588612	588529	86034E	PARTICIPANT	\N	PRESENT	0
588613	588529	20034V	PARTICIPANT	\N	PRESENT	0
588614	588529	12028B	PARTICIPANT	\N	PRESENT	0
588615	588529	14195A	PARTICIPANT	\N	PRESENT	0
588616	588529	19798U	PARTICIPANT	\N	PRESENT	0
588617	588529	20152B	PARTICIPANT	\N	PRESENT	0
588199	585815	19515S	PRESIDENT	0	PRESENT	0
588200	585815	19575F	PARTICIPANT	\N	PRESENT	0
588618	588529	19593H	PARTICIPANT	\N	PRESENT	0
588619	588529	20248J	PARTICIPANT	\N	PRESENT	0
588620	588529	19467C	PARTICIPANT	\N	PRESENT	0
588621	588529	14033T	PARTICIPANT	\N	PRESENT	0
588622	588529	14231L	PARTICIPANT	\N	PRESENT	0
588623	588529	20090E	PARTICIPANT	\N	PRESENT	0
588624	588529	20074E	PARTICIPANT	\N	PRESENT	0
588625	588529	20108W	PARTICIPANT	\N	PRESENT	0
588626	588529	20026V	PARTICIPANT	\N	PRESENT	0
588627	588529	20136B	PARTICIPANT	\N	PRESENT	0
588628	588529	20138D	PARTICIPANT	\N	PRESENT	0
588629	588529	19533U	PARTICIPANT	\N	PRESENT	0
588630	588529	14105F	PARTICIPANT	\N	PRESENT	0
588631	588529	17737W	PARTICIPANT	\N	PRESENT	0
588632	588529	11085T	PARTICIPANT	\N	PRESENT	0
588633	588529	19301E	PARTICIPANT	\N	PRESENT	0
588634	588529	14219Q	PARTICIPANT	\N	PRESENT	0
588635	588529	19739H	PARTICIPANT	\N	PRESENT	0
588636	588529	19699S	PARTICIPANT	\N	PRESENT	0
570731	568176	14179A	PARTICIPANT	\N	PRESENT	1
570732	568176	19489J	PARTICIPANT	\N	PRESENT	1
570733	568176	14147R	PARTICIPANT	\N	PRESENT	1
571441	571438	19719D	PARTICIPANT	\N	PRESENT	0
571442	571438	14030Q	PARTICIPANT	\N	PRESENT	0
571443	571438	19798U	PARTICIPANT	\N	PRESENT	0
573552	572988	11056N	PARTICIPANT	\N	PRESENT	1
573553	572988	14147R	PARTICIPANT	\N	PRESENT	1
573554	572988	19447X	PARTICIPANT	\N	PRESENT	1
573555	572988	19675J	PARTICIPANT	\N	PRESENT	1
573556	572988	14179A	PARTICIPANT	\N	PRESENT	1
573644	571526	19503N	PARTICIPANT	\N	PRESENT	0
573645	571526	19387D	PARTICIPANT	\N	PRESENT	1
573648	571526	20106U	PARTICIPANT	\N	PRESENT	1
573653	571526	19551W	PARTICIPANT	\N	EXCUSE	0
575757	575223	14038Y	PARTICIPANT	\N	PRESENT	1
575758	575223	14041T	PARTICIPANT	\N	PRESENT	0
575759	575223	19687N	PARTICIPANT	\N	PRESENT	0
575760	575223	19575F	PRESIDENT	0	PRESENT	0
575761	575223	20128B	PARTICIPANT	\N	PRESENT	1
575762	575223	19369B	PARTICIPANT	\N	EXCUSE	0
575771	575105	04047H	PRESIDENT	0	PRESENT	0
575772	575105	20108W	PARTICIPANT	\N	PRESENT	0
575773	575105	11056N	PARTICIPANT	\N	PRESENT	0
575774	575105	19447X	PARTICIPANT	\N	PRESENT	0
575797	575105	19489J	PARTICIPANT	\N	PRESENT	0
575798	575105	95063L	PARTICIPANT	\N	PRESENT	0
575799	575105	14107H	PARTICIPANT	\N	PRESENT	0
575858	575266	08028W	PARTICIPANT	\N	PRESENT	0
575795	575105	14069U	PARTICIPANT	\N	PRESENT	0
575796	575266	11070L	PARTICIPANT	\N	PRESENT	0
575800	575266	14026U	PARTICIPANT	\N	PRESENT	0
575801	575266	20090E	PARTICIPANT	\N	PRESENT	0
575802	575266	19717B	PARTICIPANT	\N	PRESENT	0
575803	575266	19673G	PARTICIPANT	\N	PRESENT	0
575804	575266	14217N	PARTICIPANT	\N	PRESENT	0
575805	575266	19697Q	PARTICIPANT	\N	PRESENT	0
575806	575266	19415P	PARTICIPANT	\N	PRESENT	0
575807	575266	19954N	PARTICIPANT	\N	PRESENT	0
575808	575266	19681G	PARTICIPANT	\N	PRESENT	0
575809	575266	14331P	PARTICIPANT	\N	PRESENT	0
575810	575266	18193Q	PARTICIPANT	\N	PRESENT	0
575811	575266	14038Y	PARTICIPANT	\N	PRESENT	0
575812	575266	19515S	PARTICIPANT	\N	PRESENT	0
575813	575266	10006L	PARTICIPANT	\N	PRESENT	0
575814	575266	20054A	PARTICIPANT	\N	PRESENT	0
575815	575266	20130U	PARTICIPANT	\N	PRESENT	0
575816	575266	19760E	PARTICIPANT	\N	PRESENT	0
575817	575266	19503N	PARTICIPANT	\N	PRESENT	0
575818	575266	11067R	PARTICIPANT	\N	PRESENT	0
575819	575266	14071N	PARTICIPANT	\N	PRESENT	0
575821	575266	14033T	PARTICIPANT	\N	PRESENT	0
575822	575266	20024T	PARTICIPANT	\N	PRESENT	0
575824	575266	14213J	PARTICIPANT	\N	PRESENT	0
575825	575266	14069U	PARTICIPANT	\N	PRESENT	0
575826	575266	04092N	PARTICIPANT	\N	PRESENT	0
575827	575266	19507S	PARTICIPANT	\N	PRESENT	0
575828	575266	11097X	PARTICIPANT	\N	PRESENT	0
575829	575266	14107H	PARTICIPANT	\N	PRESENT	0
575830	575266	11064N	PARTICIPANT	\N	PRESENT	0
575831	575266	19479G	PARTICIPANT	\N	PRESENT	0
575832	575266	19565D	PARTICIPANT	\N	PRESENT	0
575833	575266	14105F	PARTICIPANT	\N	PRESENT	0
575834	575266	14109K	PARTICIPANT	\N	PRESENT	0
575839	575266	14147R	PARTICIPANT	\N	PRESENT	0
575840	575266	19711U	PARTICIPANT	\N	PRESENT	0
575841	575266	08056B	PARTICIPANT	\N	PRESENT	0
575842	575266	11045K	PARTICIPANT	\N	PRESENT	0
575843	575266	19689Q	PARTICIPANT	\N	PRESENT	0
575844	575266	19399H	PARTICIPANT	\N	PRESENT	0
575845	575266	19657G	PARTICIPANT	\N	PRESENT	0
575846	575266	17965H	PARTICIPANT	\N	PRESENT	0
575847	575266	19387D	PARTICIPANT	\N	PRESENT	0
575848	575266	20116W	PARTICIPANT	\N	PRESENT	0
575849	575266	18083K	PARTICIPANT	\N	PRESENT	0
575850	575266	19683J	PARTICIPANT	\N	PRESENT	0
575851	575266	19367Y	PARTICIPANT	\N	PRESENT	0
575852	575266	11031D	PARTICIPANT	\N	PRESENT	0
575853	575266	14207L	PARTICIPANT	\N	PRESENT	0
575854	575266	17779H	PARTICIPANT	\N	PRESENT	0
575855	575266	20098N	PARTICIPANT	\N	PRESENT	0
575856	575266	19798U	PARTICIPANT	\N	PRESENT	0
575857	575266	19569H	PARTICIPANT	\N	PRESENT	0
575859	575266	19581D	PARTICIPANT	\N	PRESENT	0
575860	575105	14147R	PARTICIPANT	\N	PRESENT	0
575861	575105	05008E	PARTICIPANT	\N	PRESENT	0
575862	575266	20026V	PARTICIPANT	\N	PRESENT	0
575863	575266	19629C	PARTICIPANT	\N	PRESENT	0
575864	575266	04043D	PARTICIPANT	\N	PRESENT	0
575866	575266	19747H	PARTICIPANT	\N	PRESENT	0
575868	575266	19441R	PARTICIPANT	\N	PRESENT	0
575870	575266	20174H	PARTICIPANT	\N	PRESENT	0
575872	575266	20048C	PARTICIPANT	\N	PRESENT	0
575873	575105	20110Q	PARTICIPANT	\N	PRESENT	0
575874	575266	19782L	PARTICIPANT	\N	PRESENT	0
575875	575266	14259Y	PARTICIPANT	\N	PRESENT	0
575876	575266	20088L	PARTICIPANT	\N	PRESENT	0
575877	575266	20114U	PARTICIPANT	\N	PRESENT	0
575878	575266	20042V	PARTICIPANT	\N	PRESENT	0
575879	575266	14223L	PARTICIPANT	\N	PRESENT	0
575880	575266	20028X	PARTICIPANT	\N	PRESENT	0
575881	575266	14042U	PARTICIPANT	\N	PRESENT	0
575882	575266	19663E	PARTICIPANT	\N	PRESENT	0
575883	575266	01024M	PARTICIPANT	\N	PRESENT	0
575884	575266	19563B	PARTICIPANT	\N	PRESENT	0
575885	575266	04045F	PARTICIPANT	\N	PRESENT	0
575886	575266	14151M	PARTICIPANT	\N	PRESENT	0
575887	575266	20036X	PARTICIPANT	\N	PRESENT	0
575888	575266	20056C	PARTICIPANT	\N	PRESENT	0
575889	575266	14267Y	PARTICIPANT	\N	PRESENT	0
575890	575266	01058X	PARTICIPANT	\N	PRESENT	0
575891	575266	20172F	PARTICIPANT	\N	PRESENT	0
575892	575266	97011G	PARTICIPANT	\N	PRESENT	0
575893	575266	20082E	PARTICIPANT	\N	PRESENT	0
575900	575266	19691J	PARTICIPANT	\N	PRESENT	0
575902	575266	19573D	PARTICIPANT	\N	PRESENT	0
575903	575266	19735D	PARTICIPANT	\N	PRESENT	0
575905	575266	14189C	PARTICIPANT	\N	PRESENT	0
575906	575266	20062A	PARTICIPANT	\N	PRESENT	0
575907	575266	11103C	PARTICIPANT	\N	PRESENT	0
575938	575266	04057K	PARTICIPANT	\N	PRESENT	0
575939	575266	14215L	PARTICIPANT	\N	PRESENT	0
575941	575209	14083S	PARTICIPANT	\N	PRESENT	0
575942	575209	11048N	PARTICIPANT	\N	PRESENT	0
575943	575209	14189C	PARTICIPANT	\N	PRESENT	0
575944	575209	01057W	PARTICIPANT	\N	PRESENT	0
575945	575209	20070A	PARTICIPANT	\N	PRESENT	0
575946	575209	20080C	PARTICIPANT	\N	PRESENT	0
575947	575209	08010L	PARTICIPANT	\N	PRESENT	0
575948	575209	20116W	PARTICIPANT	\N	PRESENT	0
575949	575209	11074Q	PARTICIPANT	\N	PRESENT	0
575950	575209	20044X	PARTICIPANT	\N	PRESENT	0
575951	575209	14225N	PRESIDENT	0	PRESENT	0
575952	575209	19762G	PARTICIPANT	\N	PRESENT	0
575970	575266	14195A	PARTICIPANT	\N	PRESENT	0
575980	575266	14031R	PARTICIPANT	\N	PRESENT	0
575981	575266	19467C	PARTICIPANT	\N	PRESENT	0
575982	575266	14021P	PARTICIPANT	\N	PRESENT	0
575997	575106	20108W	PARTICIPANT	\N	PRESENT	0
575985	575266	14053L	PARTICIPANT	\N	PRESENT	0
575986	575266	14211G	PARTICIPANT	\N	PRESENT	0
575987	575266	17023S	PARTICIPANT	\N	PRESENT	0
575988	575266	20070A	PARTICIPANT	\N	PRESENT	0
575989	575106	14038Y	PARTICIPANT	\N	PRESENT	0
575990	575106	19333N	PARTICIPANT	\N	PRESENT	0
575991	575106	19798U	PARTICIPANT	\N	PRESENT	0
575992	575106	04047H	PRESIDENT	0	PRESENT	0
575993	575106	14173T	PARTICIPANT	\N	PRESENT	0
575994	575266	19533U	PARTICIPANT	\N	PRESENT	0
575995	575106	20074E	PARTICIPANT	\N	PRESENT	0
575996	575266	14083S	PARTICIPANT	\N	PRESENT	0
575998	575106	14147R	PARTICIPANT	\N	PRESENT	0
575999	575106	19749K	PARTICIPANT	\N	PRESENT	0
578328	575245	18083K	PARTICIPANT	\N	PRESENT	0
576001	575106	14205J	PARTICIPANT	\N	PRESENT	0
578327	575245	19367Y	PARTICIPANT	\N	PRESENT	0
578329	575245	14357A	PARTICIPANT	\N	PRESENT	0
578330	575245	19663E	PARTICIPANT	\N	PRESENT	0
578331	575245	14041T	PARTICIPANT	\N	PRESENT	0
578332	575245	14026U	PARTICIPANT	\N	PRESENT	0
578333	575245	14179A	PARTICIPANT	\N	PRESENT	0
589991	588536	14211G	PARTICIPANT	\N	PRESENT	0
589992	588536	11072N	PARTICIPANT	\N	PRESENT	0
589993	588536	19575F	PARTICIPANT	\N	PRESENT	0
589994	588536	08061X	PARTICIPANT	\N	PRESENT	0
589995	588536	19553Y	PARTICIPANT	\N	PRESENT	0
589996	588536	14109K	PARTICIPANT	\N	PRESENT	0
589997	588536	11064N	PARTICIPANT	\N	PRESENT	0
589998	588536	20066E	PARTICIPANT	\N	PRESENT	0
589999	588536	14231L	PARTICIPANT	\N	PRESENT	0
590000	588536	19569H	PARTICIPANT	\N	PRESENT	0
590001	588536	19735D	PARTICIPANT	\N	PRESENT	0
590002	588536	20034V	PARTICIPANT	\N	PRESENT	0
590003	588536	19611R	PARTICIPANT	\N	PRESENT	0
590004	588536	19699S	PARTICIPANT	\N	PRESENT	0
590005	588536	01043Q	PARTICIPANT	\N	PRESENT	0
590006	588536	20098N	PARTICIPANT	\N	PRESENT	0
590007	588536	14205J	PARTICIPANT	\N	PRESENT	0
590008	588536	19441R	PARTICIPANT	\N	PRESENT	0
590009	588536	19663E	PARTICIPANT	\N	PRESENT	0
590010	588536	19335Q	PARTICIPANT	\N	PRESENT	0
590011	588536	14219Q	PARTICIPANT	\N	PRESENT	0
590012	588536	19369B	PARTICIPANT	\N	PRESENT	0
590013	588536	04070G	PARTICIPANT	\N	PRESENT	0
590014	588536	11010L	PARTICIPANT	\N	PRESENT	0
590015	588536	19745F	PARTICIPANT	\N	PRESENT	0
590019	588536	01028R	PARTICIPANT	\N	PRESENT	0
590017	588536	20252E	PARTICIPANT	\N	PRESENT	0
590018	588536	19689Q	PARTICIPANT	\N	PRESENT	0
590020	588536	19647E	PARTICIPANT	\N	PRESENT	0
590023	588536	20054A	PARTICIPANT	\N	PRESENT	0
590024	588536	14133K	PARTICIPANT	\N	PRESENT	0
590025	588536	19531S	PARTICIPANT	\N	PRESENT	0
590026	588536	11031D	PARTICIPANT	\N	PRESENT	0
590027	588536	12041X	PARTICIPANT	\N	PRESENT	0
590028	588536	17367Q	PARTICIPANT	\N	PRESENT	0
590029	588536	16685X	PARTICIPANT	\N	PRESENT	0
590030	588536	19673G	PARTICIPANT	\N	PRESENT	0
590031	588536	20124W	PARTICIPANT	\N	PRESENT	0
590032	588536	19591F	PARTICIPANT	\N	PRESENT	0
590033	588536	20136B	PARTICIPANT	\N	PRESENT	0
590034	588536	14123H	PARTICIPANT	\N	PRESENT	0
590035	588536	17229F	PARTICIPANT	\N	PRESENT	0
590036	588536	14042U	PARTICIPANT	\N	PRESENT	0
590037	588536	19295A	PARTICIPANT	\N	PRESENT	0
590038	588536	19683J	PARTICIPANT	\N	PRESENT	0
590039	588536	14021P	PARTICIPANT	\N	PRESENT	0
590040	588536	01060R	PARTICIPANT	\N	PRESENT	0
590041	588536	14083S	PARTICIPANT	\N	PRESENT	0
590042	588536	12028B	PARTICIPANT	\N	PRESENT	0
590043	588536	19421M	PARTICIPANT	\N	PRESENT	0
590044	588536	14097Y	PARTICIPANT	\N	PRESENT	0
590045	588536	11066Q	PARTICIPANT	\N	PRESENT	0
590046	588536	11054L	PARTICIPANT	\N	PRESENT	0
590047	588536	20064C	PARTICIPANT	\N	PRESENT	0
590048	588536	01062T	PARTICIPANT	\N	PRESENT	0
590285	588539	01043Q	PARTICIPANT	\N	PRESENT	0
590286	588539	08061X	PARTICIPANT	\N	PRESENT	0
590287	588539	04033B	PARTICIPANT	\N	PRESENT	0
590288	588539	14215L	PARTICIPANT	\N	PRESENT	0
590289	588539	01060R	PARTICIPANT	\N	PRESENT	0
590290	588539	14221J	PARTICIPANT	\N	PRESENT	0
590291	588539	05008E	PARTICIPANT	\N	PRESENT	0
590292	588539	20130U	PARTICIPANT	\N	PRESENT	0
590293	588539	11056N	PARTICIPANT	\N	PRESENT	0
590294	588539	11085T	PARTICIPANT	\N	PRESENT	0
590295	588539	11012A	PARTICIPANT	\N	PRESENT	0
590296	588539	14021P	PARTICIPANT	\N	PRESENT	0
590297	588539	19711U	PARTICIPANT	\N	PRESENT	0
590302	588539	20108W	PARTICIPANT	\N	PRESENT	0
590303	588539	20090E	PARTICIPANT	\N	PRESENT	0
590304	588539	19467C	PARTICIPANT	\N	PRESENT	0
590305	588539	19651A	PARTICIPANT	\N	PRESENT	0
590306	588539	14123H	PARTICIPANT	\N	PRESENT	0
590307	588539	20034V	PARTICIPANT	\N	PRESENT	0
590308	588539	01028R	PARTICIPANT	\N	PRESENT	0
590309	588539	19599P	PARTICIPANT	\N	PRESENT	0
590310	588539	19333N	PARTICIPANT	\N	PRESENT	0
590311	588539	11072N	PARTICIPANT	\N	PRESENT	0
590312	588539	14187A	PARTICIPANT	\N	PRESENT	0
590313	588539	14109K	PARTICIPANT	\N	PRESENT	0
590314	588539	19758L	PARTICIPANT	\N	PRESENT	0
590315	588539	20084G	PARTICIPANT	\N	PRESENT	0
590316	588539	19563B	PARTICIPANT	\N	PRESENT	0
590322	588539	19533U	PARTICIPANT	\N	PRESENT	0
590324	588539	19747H	PARTICIPANT	\N	PRESENT	0
590325	588539	20026V	PARTICIPANT	\N	PRESENT	0
590326	588539	01025N	PARTICIPANT	\N	PRESENT	0
590327	588539	14231L	PARTICIPANT	\N	PRESENT	0
590328	588539	19479G	PARTICIPANT	\N	PRESENT	0
590331	588539	14069U	PARTICIPANT	\N	PRESENT	0
590332	588539	19399H	PARTICIPANT	\N	PRESENT	0
590333	588539	04047H	PARTICIPANT	\N	PRESENT	0
590340	588539	14001X	PARTICIPANT	\N	PRESENT	0
590342	588539	14251Q	PARTICIPANT	\N	PRESENT	0
590350	588539	18083K	PARTICIPANT	\N	PRESENT	0
590353	588539	20032T	PARTICIPANT	\N	PRESENT	0
590355	588539	19954N	PARTICIPANT	\N	PRESENT	0
590356	588539	14033T	PARTICIPANT	\N	PRESENT	0
590358	588539	19629C	PARTICIPANT	\N	PRESENT	0
590361	588539	19631V	PARTICIPANT	\N	PRESENT	0
590367	588539	20062A	PARTICIPANT	\N	PRESENT	0
590372	588539	20114U	PARTICIPANT	\N	PRESENT	0
590376	588539	19581D	PARTICIPANT	\N	PRESENT	0
590380	588539	19611R	PARTICIPANT	\N	PRESENT	0
590383	588539	20052X	PARTICIPANT	\N	PRESENT	0
590384	588539	20068G	PARTICIPANT	\N	PRESENT	0
590400	588412	19443T	PARTICIPANT	\N	PRESENT	0
590401	588412	12041X	PARTICIPANT	\N	PRESENT	0
590402	588412	19565D	PARTICIPANT	\N	PRESENT	0
590403	588412	20072C	PARTICIPANT	\N	PRESENT	0
590404	588412	01058X	PARTICIPANT	\N	PRESENT	0
590405	588412	11027H	PARTICIPANT	\N	PRESENT	0
590406	588412	16685X	PARTICIPANT	\N	PRESENT	0
590407	588412	04042C	PRESIDENT	0	PRESENT	0
590408	588412	11054L	PARTICIPANT	\N	PRESENT	0
590409	588412	11066Q	PARTICIPANT	\N	PRESENT	0
590410	588412	12028B	PARTICIPANT	\N	PRESENT	0
590411	588412	19421M	PARTICIPANT	\N	PRESENT	0
590412	588412	14193X	PARTICIPANT	\N	PRESENT	0
590413	588412	97011G	PARTICIPANT	\N	PRESENT	0
590414	588412	14249W	PARTICIPANT	\N	PRESENT	0
590415	588412	14059S	PARTICIPANT	\N	PRESENT	0
590416	588412	14097Y	PARTICIPANT	\N	PRESENT	0
590418	588412	14133K	PARTICIPANT	\N	PRESENT	0
590419	588412	01062T	PARTICIPANT	\N	PRESENT	0
590420	588412	20042V	PARTICIPANT	\N	PRESENT	0
590421	588412	01024M	PARTICIPANT	\N	PRESENT	0
590422	588412	14105F	PARTICIPANT	\N	PRESENT	1
590423	588412	20064C	PARTICIPANT	\N	PRESENT	0
590424	588412	14267Y	PARTICIPANT	\N	PRESENT	0
590425	588412	11083R	PARTICIPANT	\N	PRESENT	0
590426	588412	17023S	PARTICIPANT	\N	PRESENT	0
590428	588412	19347U	PARTICIPANT	\N	EXCUSE	0
590430	588539	14151M	PARTICIPANT	\N	PRESENT	0
590437	588539	14147R	PARTICIPANT	\N	PRESENT	0
590438	588539	14207L	PARTICIPANT	\N	PRESENT	0
590439	588539	19647E	PARTICIPANT	\N	PRESENT	0
590440	588539	19715Y	PARTICIPANT	\N	PRESENT	0
590441	588539	18193Q	PARTICIPANT	\N	PRESENT	0
590442	588539	19531S	PARTICIPANT	\N	PRESENT	0
590443	588539	11077T	PARTICIPANT	\N	PRESENT	0
590444	588539	11048N	PARTICIPANT	\N	PRESENT	0
590445	588539	11097X	PARTICIPANT	\N	PRESENT	0
590446	588539	14217N	PARTICIPANT	\N	PRESENT	0
590447	588539	19565D	PARTICIPANT	\N	PRESENT	0
590448	588539	97011G	PARTICIPANT	\N	PRESENT	0
590450	588539	20104S	PARTICIPANT	\N	PRESENT	0
590451	588539	20086J	PARTICIPANT	\N	PRESENT	0
590452	588539	14053L	PARTICIPANT	\N	PRESENT	0
590453	588539	20048C	PARTICIPANT	\N	PRESENT	0
590454	588539	01024M	PARTICIPANT	\N	PRESENT	0
590665	590657	19643A	PARTICIPANT	\N	PRESENT	0
590666	590657	11056N	PARTICIPANT	\N	PRESENT	0
590667	590657	20044X	PARTICIPANT	\N	PRESENT	0
590668	590659	19643A	PARTICIPANT	\N	PRESENT	0
590669	590659	20044X	PARTICIPANT	\N	PRESENT	0
590670	590659	11056N	PARTICIPANT	\N	PRESENT	0
590671	590664	19643A	PARTICIPANT	\N	PRESENT	0
590673	590664	20044X	PARTICIPANT	\N	PRESENT	0
570270	566530	01048V	PARTICIPANT	\N	PRESENT	0
570272	566530	19503N	PARTICIPANT	\N	PRESENT	0
570274	568173	05008E	PARTICIPANT	\N	PRESENT	0
570275	566530	14038Y	PARTICIPANT	\N	PRESENT	0
570277	566530	17229F	PARTICIPANT	\N	PRESENT	0
570278	566530	20106U	PARTICIPANT	\N	PRESENT	0
570279	566530	20140W	PARTICIPANT	\N	PRESENT	0
570280	566530	20056C	PARTICIPANT	\N	PRESENT	0
570281	566530	20092G	PARTICIPANT	\N	PRESENT	0
570282	566530	14253S	PARTICIPANT	\N	PRESENT	0
570284	568173	14231L	PARTICIPANT	\N	PRESENT	0
570287	566530	19599P	PARTICIPANT	\N	PRESENT	0
570300	566530	20026V	PARTICIPANT	\N	PRESENT	0
570301	566530	14237S	PARTICIPANT	\N	PRESENT	0
570302	566530	04034C	PARTICIPANT	\N	PRESENT	0
570303	566530	19747H	PARTICIPANT	\N	PRESENT	0
570304	566530	01058X	PARTICIPANT	\N	PRESENT	0
570305	566530	20062A	PARTICIPANT	\N	PRESENT	0
570306	566530	14187A	PARTICIPANT	\N	PRESENT	0
570307	566530	20136B	PARTICIPANT	\N	PRESENT	0
570308	566530	20086J	PARTICIPANT	\N	PRESENT	0
570309	566530	19507S	PARTICIPANT	\N	PRESENT	0
570310	566530	19399H	PARTICIPANT	\N	PRESENT	0
570311	566530	19369B	PARTICIPANT	\N	PRESENT	0
570312	566530	17637T	PARTICIPANT	\N	PRESENT	0
570313	566530	20172F	PARTICIPANT	\N	PRESENT	0
570314	566530	20080C	PARTICIPANT	\N	PRESENT	0
570315	566530	14357A	PARTICIPANT	\N	PRESENT	0
570316	566530	14033T	PARTICIPANT	\N	PRESENT	0
570317	566530	20072C	PARTICIPANT	\N	PRESENT	0
570318	566530	08010L	PARTICIPANT	\N	PRESENT	0
570319	566530	20130U	PARTICIPANT	\N	PRESENT	0
570320	566530	08015R	PARTICIPANT	\N	PRESENT	0
570321	566530	14071N	PARTICIPANT	\N	PRESENT	0
570322	566530	20098N	PARTICIPANT	\N	PRESENT	0
570323	566530	11064N	PARTICIPANT	\N	PRESENT	0
570324	566530	20108W	PARTICIPANT	\N	PRESENT	0
570325	566530	20144B	PARTICIPANT	\N	PRESENT	0
570326	566530	01024M	PARTICIPANT	\N	PRESENT	0
570327	566530	20120S	PARTICIPANT	\N	PRESENT	0
570328	566530	19619A	PARTICIPANT	\N	PRESENT	0
570330	566530	20110Q	PARTICIPANT	\N	PRESENT	0
570334	566530	04033B	PARTICIPANT	\N	PRESENT	0
570335	566530	14147R	PARTICIPANT	\N	PRESENT	0
570336	566530	19697Q	PARTICIPANT	\N	PRESENT	0
570337	566530	14327T	PARTICIPANT	\N	PRESENT	0
570338	566530	20116W	PARTICIPANT	\N	PRESENT	0
570339	566530	11067R	PARTICIPANT	\N	PRESENT	0
570340	566530	14195A	PARTICIPANT	\N	PRESENT	0
570343	566530	20152B	PARTICIPANT	\N	PRESENT	0
570344	566530	20082E	PARTICIPANT	\N	PRESENT	0
570345	566530	14217N	PARTICIPANT	\N	PRESENT	0
570346	566530	11097X	PARTICIPANT	\N	PRESENT	0
570347	566530	14059S	PARTICIPANT	\N	PRESENT	0
570348	566530	20142Y	PARTICIPANT	\N	PRESENT	0
570349	566530	20112S	PARTICIPANT	\N	PRESENT	0
570350	566530	20104S	PARTICIPANT	\N	PRESENT	0
570351	566530	14030Q	PARTICIPANT	\N	PRESENT	0
570354	566530	19533U	PARTICIPANT	\N	PRESENT	0
570365	566530	14215L	PARTICIPANT	\N	PRESENT	0
570366	566530	19441R	PARTICIPANT	\N	PRESENT	0
570367	566530	01057W	PARTICIPANT	\N	PRESENT	0
570368	566530	19749K	PARTICIPANT	\N	PRESENT	0
570369	566530	08061X	PARTICIPANT	\N	PRESENT	0
570375	566530	20118Y	PARTICIPANT	\N	PRESENT	0
570391	566530	20066E	PARTICIPANT	\N	PRESENT	0
570393	566530	14231L	PARTICIPANT	\N	PRESENT	0
570400	566530	11099A	PARTICIPANT	\N	PRESENT	0
570410	566530	17023S	PARTICIPANT	\N	PRESENT	0
570416	566530	20134Y	PARTICIPANT	\N	PRESENT	0
570492	566532	14219Q	PARTICIPANT	\N	PRESENT	0
570493	566532	19826F	PARTICIPANT	\N	PRESENT	0
570494	566532	20136B	PARTICIPANT	\N	PRESENT	0
570495	566532	19631V	PARTICIPANT	\N	PRESENT	0
570496	566532	19599P	PARTICIPANT	\N	PRESENT	0
570497	566532	20092G	PARTICIPANT	\N	PRESENT	0
570498	566532	20100N	PARTICIPANT	\N	PRESENT	0
570499	566532	11065P	PARTICIPANT	\N	PRESENT	0
570500	566532	20110Q	PARTICIPANT	\N	PRESENT	0
570501	566532	14195A	PARTICIPANT	\N	PRESENT	0
570502	566532	19503N	PARTICIPANT	\N	PRESENT	0
570503	566532	14038Y	PARTICIPANT	\N	PRESENT	0
570504	566532	19333N	PARTICIPANT	\N	PRESENT	0
570505	566532	11090Q	PARTICIPANT	\N	PRESENT	0
570506	566532	20112S	PARTICIPANT	\N	PRESENT	0
570507	566532	20130U	PARTICIPANT	\N	PRESENT	0
570508	566532	19691J	PARTICIPANT	\N	PRESENT	0
570509	566532	19619A	PARTICIPANT	\N	PRESENT	0
570510	566532	20066E	PARTICIPANT	\N	PRESENT	0
570511	566532	17229F	PARTICIPANT	\N	PRESENT	0
570512	566532	14207L	PARTICIPANT	\N	PRESENT	0
570513	566532	20080C	PARTICIPANT	\N	PRESENT	0
570514	566532	20046A	PARTICIPANT	\N	PRESENT	0
570515	566532	20142Y	PARTICIPANT	\N	PRESENT	0
570516	566532	19413M	PARTICIPANT	\N	PRESENT	0
570517	566532	19251M	PARTICIPANT	\N	PRESENT	0
570518	566532	14097Y	PARTICIPANT	\N	PRESENT	0
570519	566532	14257W	PARTICIPANT	\N	PRESENT	0
570520	566532	14205J	PARTICIPANT	\N	PRESENT	0
570521	566532	20076G	PARTICIPANT	\N	PRESENT	0
570522	566532	19515S	PARTICIPANT	\N	PRESENT	0
570523	566532	20038A	PARTICIPANT	\N	PRESENT	0
570524	566532	17367Q	PARTICIPANT	\N	PRESENT	0
570525	566532	14253S	PARTICIPANT	\N	PRESENT	0
570526	566532	20102Q	PARTICIPANT	\N	PRESENT	0
570527	566532	19695N	PARTICIPANT	\N	PRESENT	0
570528	566532	14031R	PARTICIPANT	\N	PRESENT	0
570529	566532	19747H	PARTICIPANT	\N	PRESENT	0
570530	566532	14033T	PARTICIPANT	\N	PRESENT	0
570531	566532	20118Y	PARTICIPANT	\N	PRESENT	0
570532	566532	14327T	PARTICIPANT	\N	PRESENT	0
570533	566532	11067R	PARTICIPANT	\N	PRESENT	0
570534	566532	17023S	PARTICIPANT	\N	PRESENT	0
570535	566532	19549D	PARTICIPANT	\N	PRESENT	0
570536	566532	04045F	PARTICIPANT	\N	PRESENT	0
570537	566532	14187A	PARTICIPANT	\N	PRESENT	0
570538	566532	20124W	PARTICIPANT	\N	PRESENT	0
570539	566532	14215L	PARTICIPANT	\N	PRESENT	0
570540	566532	20106U	PARTICIPANT	\N	PRESENT	0
570541	566532	20140W	PARTICIPANT	\N	PRESENT	0
570542	566532	20026V	PARTICIPANT	\N	PRESENT	0
570543	566532	19533U	PARTICIPANT	\N	PRESENT	0
570544	566532	20180F	PARTICIPANT	\N	PRESENT	0
570545	566532	08069G	PARTICIPANT	\N	PRESENT	0
570546	566532	14083S	PARTICIPANT	\N	PRESENT	0
570547	566532	11097X	PARTICIPANT	\N	PRESENT	0
570548	566532	19711U	PARTICIPANT	\N	PRESENT	0
570549	566532	11012A	PARTICIPANT	\N	PRESENT	0
570550	566532	04047H	PARTICIPANT	\N	PRESENT	0
570551	566532	20116W	PARTICIPANT	\N	PRESENT	0
570552	566532	20072C	PARTICIPANT	\N	PRESENT	0
570553	566532	14217N	PARTICIPANT	\N	PRESENT	0
570554	566532	19369B	PARTICIPANT	\N	PRESENT	0
570555	566532	01024M	PARTICIPANT	\N	PRESENT	0
570556	566532	17637T	PARTICIPANT	\N	PRESENT	0
570557	566532	20126Y	PARTICIPANT	\N	PRESENT	0
570558	566532	04033B	PARTICIPANT	\N	PRESENT	0
570559	566532	14357A	PARTICIPANT	\N	PRESENT	0
570560	566532	14231L	PARTICIPANT	\N	PRESENT	0
570561	566532	07029T	PARTICIPANT	\N	PRESENT	0
570562	566532	14169X	PARTICIPANT	\N	PRESENT	0
570563	566532	11099A	PARTICIPANT	\N	PRESENT	0
570564	566532	19441R	PARTICIPANT	\N	PRESENT	0
570490	566532	19719D	PARTICIPANT	\N	PRESENT	0
570491	566532	19701S	PARTICIPANT	\N	PRESENT	0
570565	566532	11064N	PARTICIPANT	\N	PRESENT	0
570566	566532	20082E	PARTICIPANT	\N	PRESENT	0
570567	566532	11033F	PARTICIPANT	\N	PRESENT	0
570568	566532	20120S	PARTICIPANT	\N	PRESENT	0
570569	566532	14071N	PARTICIPANT	\N	PRESENT	0
574515	573329	19565D	PARTICIPANT	\N	PRESENT	0
570571	566532	18083K	PARTICIPANT	\N	PRESENT	0
570572	566532	20052X	PARTICIPANT	\N	PRESENT	0
574516	573329	04085P	PARTICIPANT	\N	PRESENT	0
574517	573329	14357A	PARTICIPANT	\N	PRESENT	0
574518	573329	20022R	PARTICIPANT	\N	PRESENT	0
574519	573329	14249W	PARTICIPANT	\N	PRESENT	0
574520	573329	19739H	PARTICIPANT	\N	PRESENT	0
574521	573329	19697Q	PARTICIPANT	\N	PRESENT	0
574522	573329	20044X	PARTICIPANT	\N	PRESENT	0
574523	573329	08015R	PARTICIPANT	\N	PRESENT	0
588639	588529	14217N	PARTICIPANT	\N	PRESENT	0
588640	588529	11012A	PARTICIPANT	\N	PRESENT	0
588641	588529	14031R	PARTICIPANT	\N	PRESENT	0
588642	588529	14187A	PARTICIPANT	\N	PRESENT	0
588643	588529	19711U	PARTICIPANT	\N	PRESENT	0
588644	588529	05012A	PARTICIPANT	\N	PRESENT	0
588645	588529	04033B	PARTICIPANT	\N	PRESENT	0
588646	588529	14147R	PARTICIPANT	\N	PRESENT	0
588647	588529	11090Q	PARTICIPANT	\N	PRESENT	0
588648	588529	19760E	PARTICIPANT	\N	PRESENT	0
588649	588529	20264J	PARTICIPANT	\N	PRESENT	0
588650	588529	19683J	PARTICIPANT	\N	PRESENT	0
588651	588529	14021P	PARTICIPANT	\N	PRESENT	0
588652	588529	19669L	PARTICIPANT	\N	PRESENT	0
588653	588529	19369B	PARTICIPANT	\N	PRESENT	0
588654	588529	20072C	PARTICIPANT	\N	PRESENT	0
588655	588529	20144B	PARTICIPANT	\N	PRESENT	0
588656	588529	19545Y	PARTICIPANT	\N	PRESENT	0
588657	588529	20066E	PARTICIPANT	\N	PRESENT	0
588658	588529	19569H	PARTICIPANT	\N	PRESENT	0
588659	588529	05008E	PARTICIPANT	\N	PRESENT	0
588660	588529	19563B	PARTICIPANT	\N	PRESENT	0
588661	588529	19585H	PARTICIPANT	\N	PRESENT	0
588662	588529	14109K	PARTICIPANT	\N	PRESENT	0
588663	588529	19527W	PARTICIPANT	\N	PRESENT	0
588664	588529	20028X	PARTICIPANT	\N	PRESENT	0
588665	588529	19415P	PARTICIPANT	\N	PRESENT	0
588666	588529	19747H	PARTICIPANT	\N	PRESENT	0
588667	588529	14055N	PARTICIPANT	\N	PRESENT	0
588668	588529	14357A	PARTICIPANT	\N	PRESENT	0
588637	588529	20022R	PARTICIPANT	\N	PRESENT	0
588638	588529	20038A	PARTICIPANT	\N	PRESENT	0
588669	588529	07033P	PARTICIPANT	\N	PRESENT	0
588670	588529	14213J	PARTICIPANT	\N	PRESENT	0
588671	588529	99004R	PARTICIPANT	\N	PRESENT	0
588734	588530	19681G	PARTICIPANT	\N	PRESENT	0
588735	588530	14055N	PARTICIPANT	\N	PRESENT	0
588736	588530	07033P	PARTICIPANT	\N	PRESENT	0
588737	588530	05012A	PARTICIPANT	\N	PRESENT	0
588738	588530	14109K	PARTICIPANT	\N	PRESENT	0
588739	588530	04085P	PARTICIPANT	\N	PRESENT	0
588740	588526	19569H	PARTICIPANT	\N	PRESENT	0
588741	588526	19798U	PARTICIPANT	\N	PRESENT	0
588742	588526	11097X	PARTICIPANT	\N	PRESENT	0
588743	588526	20040T	PARTICIPANT	\N	PRESENT	0
588744	588526	19691J	PARTICIPANT	\N	PRESENT	1
588745	588526	19717B	PARTICIPANT	\N	PRESENT	0
588746	588526	19703U	PARTICIPANT	\N	PRESENT	0
588747	588526	20066E	PARTICIPANT	\N	PRESENT	0
588748	588526	19679N	PARTICIPANT	\N	PRESENT	0
588749	588526	14042U	PARTICIPANT	\N	PRESENT	0
588750	588526	14195A	PARTICIPANT	\N	PRESENT	0
588751	588526	19367Y	PARTICIPANT	\N	PRESENT	0
588752	588526	19760E	PARTICIPANT	\N	PRESENT	0
588753	588530	04045F	PARTICIPANT	\N	PRESENT	0
588754	588530	20052X	PARTICIPANT	\N	PRESENT	0
588757	588530	99004R	PARTICIPANT	\N	PRESENT	0
588760	588530	20044X	PARTICIPANT	\N	PRESENT	0
588761	588530	20098N	PARTICIPANT	\N	PRESENT	0
588763	588530	20026V	PARTICIPANT	\N	PRESENT	0
588765	588530	14021P	PARTICIPANT	\N	PRESENT	0
588768	588530	20114U	PARTICIPANT	\N	PRESENT	0
588769	588530	11085T	PARTICIPANT	\N	PRESENT	0
588771	588530	19826F	PARTICIPANT	\N	PRESENT	0
588772	588530	20042V	PARTICIPANT	\N	PRESENT	0
588773	588530	19683J	PARTICIPANT	\N	PRESENT	0
588774	588530	20130U	PARTICIPANT	\N	PRESENT	0
588775	588530	11110B	PARTICIPANT	\N	PRESENT	0
588776	588530	04059M	PARTICIPANT	\N	PRESENT	0
588777	588530	20110Q	PARTICIPANT	\N	PRESENT	0
588778	588530	14089Y	PARTICIPANT	\N	PRESENT	0
588779	588526	19697Q	PARTICIPANT	\N	PRESENT	0
588780	588526	14223L	PARTICIPANT	\N	PRESENT	0
588781	588526	14026U	PARTICIPANT	\N	PRESENT	0
588782	588526	19295A	PARTICIPANT	\N	PRESENT	0
588783	588526	17779H	PARTICIPANT	\N	PRESENT	1
588784	588526	11103C	PARTICIPANT	\N	PRESENT	1
588785	588530	19649G	PARTICIPANT	\N	PRESENT	0
588786	588530	04033B	PARTICIPANT	\N	PRESENT	0
588787	588530	18083K	PARTICIPANT	\N	PRESENT	0
588788	588530	01057W	PARTICIPANT	\N	PRESENT	0
588789	588530	19741B	PARTICIPANT	\N	PRESENT	0
588790	588530	20034V	PARTICIPANT	\N	PRESENT	0
588791	588530	19573D	PARTICIPANT	\N	PRESENT	0
588792	588530	20086J	PARTICIPANT	\N	PRESENT	0
588793	588530	20138D	PARTICIPANT	\N	PRESENT	0
588794	588530	20022R	PARTICIPANT	\N	PRESENT	0
588795	588530	20136B	PARTICIPANT	\N	PRESENT	0
588796	588530	08028W	PARTICIPANT	\N	PRESENT	0
588799	588530	14211G	PARTICIPANT	\N	PRESENT	0
588800	588530	17637T	PARTICIPANT	\N	PRESENT	0
588802	588530	14329V	PARTICIPANT	\N	PRESENT	0
588803	588530	20124W	PARTICIPANT	\N	PRESENT	0
588804	588530	08056B	PARTICIPANT	\N	PRESENT	0
588805	588530	20252E	PARTICIPANT	\N	PRESENT	0
588732	588530	12041X	PARTICIPANT	\N	PRESENT	0
588733	588530	19527W	PARTICIPANT	\N	PRESENT	0
588806	588530	19581D	PARTICIPANT	\N	PRESENT	0
588807	588530	01024M	PARTICIPANT	\N	PRESENT	0
588808	588530	07004J	PARTICIPANT	\N	PRESENT	0
588809	588530	17023S	PARTICIPANT	\N	PRESENT	0
588810	588530	19669L	PARTICIPANT	\N	PRESENT	0
588811	588530	11033F	PARTICIPANT	\N	PRESENT	0
588812	588530	08045X	PARTICIPANT	\N	PRESENT	0
588813	588530	14105F	PARTICIPANT	\N	PRESENT	0
588814	588530	19533U	PARTICIPANT	\N	PRESENT	0
588815	588530	19593H	PARTICIPANT	\N	PRESENT	0
588816	588530	20046A	PARTICIPANT	\N	PRESENT	0
588818	588530	11064N	PARTICIPANT	\N	PRESENT	0
588819	588530	19333N	PARTICIPANT	\N	PRESENT	0
588825	588530	14071N	PARTICIPANT	\N	PRESENT	0
588826	588530	19725B	PARTICIPANT	\N	PRESENT	0
588827	588530	19611R	PARTICIPANT	\N	PRESENT	0
588828	588530	19415P	PARTICIPANT	\N	PRESENT	0
588829	588530	11012A	PARTICIPANT	\N	PRESENT	0
588831	588530	19503N	PARTICIPANT	\N	PRESENT	0
588833	588530	11041F	PARTICIPANT	\N	PRESENT	0
588855	588530	08034U	PARTICIPANT	\N	PRESENT	0
588835	588530	01058X	PARTICIPANT	\N	PRESENT	0
588836	588530	01062T	PARTICIPANT	\N	PRESENT	0
588837	588530	14069U	PARTICIPANT	\N	PRESENT	0
588840	588530	20140W	PARTICIPANT	\N	PRESENT	0
588842	588530	19647E	PARTICIPANT	\N	PRESENT	0
588843	588530	14259Y	PARTICIPANT	\N	PRESENT	0
588845	588530	19651A	PARTICIPANT	\N	PRESENT	0
588846	588530	14147R	PARTICIPANT	\N	PRESENT	0
588847	588530	20264J	PARTICIPANT	\N	PRESENT	0
588848	588530	14189C	PARTICIPANT	\N	PRESENT	0
588849	588530	12016W	PARTICIPANT	\N	PRESENT	0
588850	588530	19531S	PARTICIPANT	\N	PRESENT	0
588852	588530	08010L	PARTICIPANT	\N	PRESENT	0
588853	588530	04008A	PARTICIPANT	\N	PRESENT	0
588854	588530	01048V	PARTICIPANT	\N	PRESENT	0
588856	588530	20090E	PARTICIPANT	\N	PRESENT	0
588857	588530	14059S	PARTICIPANT	\N	PRESENT	0
588858	588530	20102Q	PARTICIPANT	\N	PRESENT	0
588859	588530	20072C	PARTICIPANT	\N	PRESENT	0
588860	588530	20064C	PARTICIPANT	\N	PRESENT	0
588861	588530	14111D	PARTICIPANT	\N	PRESENT	0
588862	588530	19563B	PARTICIPANT	\N	PRESENT	0
588863	588530	20150Y	PARTICIPANT	\N	PRESENT	0
588864	588530	04043D	PARTICIPANT	\N	PRESENT	0
588865	588530	20142Y	PARTICIPANT	\N	PRESENT	0
588866	588530	19549D	PARTICIPANT	\N	PRESENT	0
588867	588530	11056N	PARTICIPANT	\N	PRESENT	0
588868	588530	14033T	PARTICIPANT	\N	PRESENT	0
588869	588526	20090E	PARTICIPANT	\N	PRESENT	0
588870	588526	04057K	PARTICIPANT	\N	PRESENT	0
588871	588526	18193Q	PARTICIPANT	\N	PRESENT	0
588872	588526	14213J	PARTICIPANT	\N	PRESENT	0
588874	588530	19695N	PARTICIPANT	\N	PRESENT	0
588875	588530	14151M	PARTICIPANT	\N	PRESENT	0
588876	588530	14121F	PARTICIPANT	\N	PRESENT	0
588877	588530	14267Y	PARTICIPANT	\N	PRESENT	0
588878	588530	20108W	PARTICIPANT	\N	PRESENT	0
588879	588530	19565D	PARTICIPANT	\N	PRESENT	0
588880	588530	14231L	PARTICIPANT	\N	PRESENT	0
588881	588530	19543W	PARTICIPANT	\N	PRESENT	0
588883	588530	19467C	PARTICIPANT	\N	PRESENT	0
588884	588530	20028X	PARTICIPANT	\N	PRESENT	0
588885	588530	20024T	PARTICIPANT	\N	PRESENT	0
572950	572939	20116W	PARTICIPANT	\N	PRESENT	0
572986	572985	14231L	PRESIDENT	0	PRESENT	0
572987	572985	14327T	PARTICIPANT	\N	PRESENT	0
572989	572985	14215L	PARTICIPANT	\N	PRESENT	0
572991	572985	19758L	PARTICIPANT	\N	PRESENT	0
572992	572985	08010L	PARTICIPANT	\N	PRESENT	0
572993	572985	19333N	PARTICIPANT	\N	PRESENT	0
572994	572985	14071N	PARTICIPANT	\N	PRESENT	0
572997	572985	14229S	PARTICIPANT	\N	PRESENT	0
572998	572985	14053L	PARTICIPANT	\N	PRESENT	1
573000	572985	20090E	PARTICIPANT	\N	PRESENT	1
573001	572985	19681G	PARTICIPANT	\N	PRESENT	1
573002	572985	04086Q	PARTICIPANT	\N	PRESENT	1
573003	572985	19735D	PARTICIPANT	\N	PRESENT	1
573004	572985	19489J	PARTICIPANT	\N	PRESENT	1
573005	572985	14257W	PARTICIPANT	\N	PRESENT	1
573006	572985	19349W	PARTICIPANT	\N	PRESENT	1
573007	572985	01057W	PARTICIPANT	\N	PRESENT	1
573008	572985	14205J	PARTICIPANT	\N	PRESENT	1
573009	572985	19565D	PARTICIPANT	\N	EXCUSE	0
573074	555421	11067R	PARTICIPANT	\N	PRESENT	0
573076	555421	01058X	PARTICIPANT	\N	PRESENT	1
573078	555421	20128B	PARTICIPANT	\N	PRESENT	1
573079	555421	04043D	PARTICIPANT	\N	PRESENT	0
573080	555421	19735D	PARTICIPANT	\N	PRESENT	1
573081	555421	01048V	PARTICIPANT	\N	EXCUSE	0
573150	573149	20128B	PARTICIPANT	\N	PRESENT	0
573187	566272	05008E	PARTICIPANT	\N	EXCUSE	0
574379	574378	14030Q	PARTICIPANT	\N	PRESENT	0
574380	574378	20132W	PARTICIPANT	\N	PRESENT	0
574381	574378	19758L	PARTICIPANT	\N	PRESENT	0
574382	574378	14073Q	PARTICIPANT	\N	PRESENT	0
574383	574378	08017T	PARTICIPANT	\N	PRESENT	0
574384	574378	20152B	PARTICIPANT	\N	PRESENT	1
574385	574378	19651A	PARTICIPANT	\N	PRESENT	1
574386	574378	19643A	PARTICIPANT	\N	PRESENT	1
574387	574378	20142Y	PARTICIPANT	\N	PRESENT	1
574388	574378	19611R	PARTICIPANT	\N	PRESENT	0
574389	574378	20052X	PARTICIPANT	\N	PRESENT	0
574390	574378	20124W	PARTICIPANT	\N	PRESENT	0
574391	574378	20026V	PARTICIPANT	\N	PRESENT	0
574392	574378	19573D	PARTICIPANT	\N	PRESENT	0
574393	574378	19533U	PARTICIPANT	\N	PRESENT	0
574394	574378	20098N	PARTICIPANT	\N	PRESENT	0
574395	574378	20056C	PARTICIPANT	\N	PRESENT	0
574396	574378	11104D	PARTICIPANT	\N	PRESENT	0
574397	574378	14109K	PARTICIPANT	\N	PRESENT	0
574398	574378	11043H	PARTICIPANT	\N	PRESENT	0
574399	574378	20048C	PARTICIPANT	\N	PRESENT	1
574400	574378	19699S	PARTICIPANT	\N	PRESENT	1
574401	574378	20058E	PARTICIPANT	\N	PRESENT	1
574402	574378	19527W	PARTICIPANT	\N	PRESENT	1
574884	574883	14255U	PARTICIPANT	\N	PRESENT	0
574885	574883	04035D	PARTICIPANT	\N	PRESENT	1
574886	574883	11067R	PARTICIPANT	\N	PRESENT	0
574887	574883	19479G	PARTICIPANT	\N	PRESENT	1
574889	574888	14255U	PARTICIPANT	\N	PRESENT	0
574890	574888	19701S	PARTICIPANT	\N	PRESENT	0
574891	574888	14179A	PARTICIPANT	\N	PRESENT	0
574892	574888	14030Q	PARTICIPANT	\N	PRESENT	0
574900	574899	19643A	PARTICIPANT	\N	PRESENT	1
574901	574899	20114U	PARTICIPANT	\N	PRESENT	0
574902	574899	20124W	PARTICIPANT	\N	PRESENT	0
574903	574899	19691J	PARTICIPANT	\N	PRESENT	0
574904	574899	14073Q	PARTICIPANT	\N	PRESENT	1
574905	574899	08017T	PARTICIPANT	\N	PRESENT	0
574906	574899	04057K	PARTICIPANT	\N	PRESENT	0
574907	574899	19527W	PARTICIPANT	\N	PRESENT	0
574960	571359	19673G	PARTICIPANT	\N	PRESENT	0
574961	571359	04035D	PARTICIPANT	\N	PRESENT	0
574962	571359	20066E	PARTICIPANT	\N	PRESENT	0
574963	571359	20056C	PARTICIPANT	\N	PRESENT	0
574964	571359	19503N	PARTICIPANT	\N	PRESENT	0
576281	575107	11033F	PARTICIPANT	\N	PRESENT	1
576282	575107	14069U	PARTICIPANT	\N	PRESENT	1
576283	575107	17737W	PARTICIPANT	\N	PRESENT	1
576284	575107	20114U	PARTICIPANT	\N	PRESENT	1
576285	575107	19629C	PARTICIPANT	\N	PRESENT	1
576286	575107	20128B	PARTICIPANT	\N	PRESENT	1
576287	575107	19581D	PARTICIPANT	\N	PRESENT	1
576288	575107	14107H	PARTICIPANT	\N	PRESENT	1
576289	575107	19675J	PARTICIPANT	\N	PRESENT	1
578334	575245	19333N	PARTICIPANT	\N	PRESENT	0
578335	575245	19399H	PARTICIPANT	\N	PRESENT	0
578336	575245	19711U	PARTICIPANT	\N	PRESENT	0
578337	575245	08034U	PARTICIPANT	\N	PRESENT	0
578338	575245	14147R	PARTICIPANT	\N	PRESENT	0
578339	575245	04033B	PARTICIPANT	\N	PRESENT	0
578340	575245	01034P	PARTICIPANT	\N	PRESENT	0
578520	575245	11041F	PARTICIPANT	\N	PRESENT	0
583504	583503	11090Q	PARTICIPANT	\N	PRESENT	0
583505	583503	14329V	PARTICIPANT	\N	PRESENT	0
583507	583506	19553Y	PARTICIPANT	\N	PRESENT	0
583512	583511	11053K	PARTICIPANT	\N	PRESENT	0
583514	583513	20070A	PARTICIPANT	\N	PRESENT	0
583515	583513	11110B	PARTICIPANT	\N	PRESENT	0
583516	583246	20070A	PARTICIPANT	\N	PRESENT	0
583517	583246	11110B	PARTICIPANT	\N	PRESENT	0
583519	583518	08009T	PARTICIPANT	\N	PRESENT	1
583521	583520	08010L	PARTICIPANT	\N	PRESENT	0
583523	583522	20050V	PARTICIPANT	\N	PRESENT	0
583586	583585	11070L	PARTICIPANT	\N	PRESENT	0
583587	583585	19647E	PARTICIPANT	\N	PRESENT	0
583590	583588	20092G	PARTICIPANT	\N	PRESENT	0
583591	583588	14357A	PARTICIPANT	\N	PRESENT	0
583592	583589	14357A	PARTICIPANT	\N	PRESENT	0
583593	583589	20092G	PARTICIPANT	\N	PRESENT	0
583595	583594	20092G	PARTICIPANT	\N	PRESENT	0
583596	583594	14357A	PARTICIPANT	\N	PRESENT	0
583598	583597	14357A	PARTICIPANT	\N	PRESENT	0
583599	583597	20092G	PARTICIPANT	\N	PRESENT	0
583602	583601	14357A	PARTICIPANT	\N	PRESENT	0
583605	583604	20092G	PARTICIPANT	\N	PRESENT	0
583606	583603	20092G	PARTICIPANT	\N	PRESENT	0
583611	583610	10006L	PARTICIPANT	\N	PRESENT	0
583938	583221	11031D	PARTICIPANT	\N	PRESENT	0
583936	583221	14030Q	PRESIDENT	0	PRESENT	0
583937	583221	14179A	PARTICIPANT	\N	PRESENT	0
583939	583221	19715Y	PARTICIPANT	\N	PRESENT	0
583940	583221	19866P	PARTICIPANT	\N	PRESENT	0
583941	583221	19599P	PARTICIPANT	\N	PRESENT	0
583943	583221	14109K	PARTICIPANT	\N	PRESENT	0
583945	583221	19749K	PARTICIPANT	\N	PRESENT	0
583948	583221	20130U	PARTICIPANT	\N	PRESENT	0
583951	583221	19693L	PARTICIPANT	\N	PRESENT	0
583955	583221	20106U	PARTICIPANT	\N	EXCUSE	0
583956	583221	20118Y	PARTICIPANT	\N	EXCUSE	0
583958	583221	20024T	PARTICIPANT	\N	EXCUSE	0
583959	583221	17737W	PARTICIPANT	\N	EXCUSE	0
583960	583221	20080C	PARTICIPANT	\N	EXCUSE	0
583964	583221	19798U	PARTICIPANT	\N	PRESENT	0
585724	585723	19673G	PARTICIPANT	\N	PRESENT	0
587117	585658	04092N	PARTICIPANT	\N	PRESENT	0
587118	585658	19415P	PARTICIPANT	\N	PRESENT	0
587114	585658	14281W	PARTICIPANT	\N	PRESENT	0
587115	585658	19683J	PARTICIPANT	\N	PRESENT	0
587119	585658	14042U	PARTICIPANT	\N	PRESENT	0
587120	585658	19553Y	PARTICIPANT	\N	PRESENT	0
587121	585658	19703U	PARTICIPANT	\N	PRESENT	0
587122	585658	14217N	PARTICIPANT	\N	PRESENT	0
587123	585658	19367Y	PARTICIPANT	\N	PRESENT	0
587124	585658	11097X	PARTICIPANT	\N	PRESENT	0
587125	585658	20090E	PARTICIPANT	\N	PRESENT	0
587126	585658	19569H	PARTICIPANT	\N	PRESENT	0
587127	585658	11103C	PARTICIPANT	\N	PRESENT	1
587128	585658	19798U	PARTICIPANT	\N	PRESENT	1
587129	585658	19697Q	PARTICIPANT	\N	PRESENT	1
587130	585658	14195A	PARTICIPANT	\N	PRESENT	0
587131	585658	11031D	PARTICIPANT	\N	PRESENT	0
587132	585658	19301E	PARTICIPANT	\N	PRESENT	0
587134	585658	01034P	PARTICIPANT	\N	PRESENT	1
587135	585658	19713W	PARTICIPANT	\N	PRESENT	0
587136	585658	14026U	PARTICIPANT	\N	PRESENT	0
587137	585658	11067R	PARTICIPANT	\N	PRESENT	0
587138	585658	20066E	PARTICIPANT	\N	PRESENT	0
587139	585658	14223L	PARTICIPANT	\N	PRESENT	0
591063	590541	19489J	PARTICIPANT	\N	PRESENT	1
591066	590541	19729F	PARTICIPANT	\N	EXCUSE	0
591560	590540	19585H	PARTICIPANT	\N	PRESENT	0
591561	590540	04047H	PRESIDENT	0	PRESENT	0
591562	590540	19673G	PARTICIPANT	\N	PRESENT	0
591563	590540	19447X	PARTICIPANT	\N	PRESENT	0
591564	590540	20110Q	PARTICIPANT	\N	PRESENT	0
591565	590540	14215L	PARTICIPANT	\N	PRESENT	0
591566	590540	19749K	PARTICIPANT	\N	PRESENT	0
591567	590540	01028R	PARTICIPANT	\N	PRESENT	0
591568	590540	10015M	PARTICIPANT	\N	PRESENT	0
591569	590540	19729F	PARTICIPANT	\N	EXCUSE	0
591570	590540	14053L	PARTICIPANT	\N	PRESENT	0
591571	590540	14111D	PARTICIPANT	\N	PRESENT	0
591572	590540	19649G	PARTICIPANT	\N	PRESENT	0
591573	590540	11026G	PARTICIPANT	\N	PRESENT	0
591574	590540	19725B	PARTICIPANT	\N	PRESENT	0
591575	590540	07004J	PARTICIPANT	\N	PRESENT	0
591576	590540	20114U	PARTICIPANT	\N	PRESENT	0
591577	590540	14151M	PARTICIPANT	\N	PRESENT	0
591578	590540	11033F	PARTICIPANT	\N	PRESENT	0
591579	590540	14275Y	PARTICIPANT	\N	PRESENT	0
591580	590540	19629C	PARTICIPANT	\N	PRESENT	0
591581	590540	14107H	PARTICIPANT	\N	PRESENT	0
591582	590540	14179A	PARTICIPANT	\N	PRESENT	0
591583	590540	11072N	PARTICIPANT	\N	PRESENT	0
591584	590394	19697Q	PARTICIPANT	\N	PRESENT	1
591585	590394	11067R	PARTICIPANT	\N	PRESENT	0
591586	590394	20090E	PARTICIPANT	\N	PRESENT	0
591587	590394	19798U	PARTICIPANT	\N	PRESENT	0
591588	590394	11097X	PARTICIPANT	\N	PRESENT	0
591589	590394	19415P	PARTICIPANT	\N	PRESENT	0
591590	590394	18193Q	PARTICIPANT	\N	PRESENT	0
591591	590394	14223L	PARTICIPANT	\N	PRESENT	0
591592	590394	17779H	PARTICIPANT	\N	PRESENT	0
591593	590394	19703U	PARTICIPANT	\N	PRESENT	0
591594	590394	14042U	PARTICIPANT	\N	PRESENT	0
591595	590394	14195A	PARTICIPANT	\N	PRESENT	0
591596	590394	14213J	PARTICIPANT	\N	PRESENT	0
591597	590394	14217N	PARTICIPANT	\N	PRESENT	0
591598	590394	10006L	PRESIDENT	0	PRESENT	0
591599	590394	19591F	PARTICIPANT	\N	PRESENT	0
591600	590394	20130U	PARTICIPANT	\N	PRESENT	1
591601	590394	19713W	PARTICIPANT	\N	PRESENT	0
591602	590394	08045X	PARTICIPANT	\N	PRESENT	1
591603	590394	11045K	PARTICIPANT	\N	PRESENT	0
591604	590394	19301E	PARTICIPANT	\N	PRESENT	0
591605	590394	19691J	PARTICIPANT	\N	PRESENT	0
591606	590394	19717B	PARTICIPANT	\N	PRESENT	1
591607	590394	20172F	PARTICIPANT	\N	PRESENT	0
591608	590394	19723Y	PARTICIPANT	\N	PRESENT	0
591609	590394	20248J	PARTICIPANT	\N	PRESENT	0
591610	590394	20066E	PARTICIPANT	\N	PRESENT	0
591611	590394	11103C	PARTICIPANT	\N	PRESENT	1
591612	590394	14071N	PARTICIPANT	\N	PRESENT	0
591613	590394	19760E	PARTICIPANT	\N	PRESENT	1
591618	590540	14147R	PARTICIPANT	\N	PRESENT	0
591619	590540	95063L	PARTICIPANT	\N	PRESENT	0
591620	590829	14327T	PARTICIPANT	\N	PRESENT	0
591621	590829	19711U	PARTICIPANT	\N	PRESENT	0
591622	590829	20080C	PARTICIPANT	\N	PRESENT	0
591623	590829	20050V	PARTICIPANT	\N	PRESENT	0
591624	590829	99004R	PARTICIPANT	\N	PRESENT	0
591625	590829	19335Q	PARTICIPANT	\N	PRESENT	0
591626	590829	14173T	PARTICIPANT	\N	PRESENT	0
591632	590829	11048N	PARTICIPANT	\N	PRESENT	0
591633	590829	14225N	PRESIDENT	0	PRESENT	0
591655	590829	19687N	PARTICIPANT	\N	PRESENT	0
591656	590829	19689Q	PARTICIPANT	\N	PRESENT	0
591657	590829	20044X	PARTICIPANT	\N	PRESENT	0
591658	590829	14121F	PARTICIPANT	\N	PRESENT	0
591659	590829	08010L	PARTICIPANT	\N	PRESENT	0
591661	590829	11074Q	PARTICIPANT	\N	PRESENT	0
591662	590829	07029T	PARTICIPANT	\N	PRESENT	0
591663	590829	20070A	PARTICIPANT	\N	PRESENT	0
591664	590829	19531S	PARTICIPANT	\N	PRESENT	0
591665	590829	20086J	PARTICIPANT	\N	PRESENT	0
591666	590829	08034U	PARTICIPANT	\N	PRESENT	0
591667	590829	11040E	PARTICIPANT	\N	PRESENT	0
591668	590829	11070L	PARTICIPANT	\N	PRESENT	0
591669	590829	19826F	PARTICIPANT	\N	PRESENT	0
591670	590829	08060W	PARTICIPANT	\N	PRESENT	0
591671	590829	19741B	PARTICIPANT	\N	PRESENT	0
591673	590829	14083S	PARTICIPANT	\N	PRESENT	0
591674	590829	19762G	PARTICIPANT	\N	PRESENT	0
591675	590829	08011M	PARTICIPANT	\N	PRESENT	0
591676	590829	20022R	PARTICIPANT	\N	PRESENT	0
591677	590829	19349W	PARTICIPANT	\N	PRESENT	0
591678	590829	14331P	PARTICIPANT	\N	PRESENT	0
591679	590829	19545Y	PARTICIPANT	\N	PRESENT	0
591680	590829	14189C	PARTICIPANT	\N	PRESENT	0
591681	590829	01057W	PARTICIPANT	\N	PRESENT	0
591682	590829	11053K	PARTICIPANT	\N	PRESENT	0
591683	590829	20116W	PARTICIPANT	\N	PRESENT	0
591684	590829	20126Y	PARTICIPANT	\N	PRESENT	0
591685	590829	08009T	PARTICIPANT	\N	PRESENT	0
591686	590829	20036X	PARTICIPANT	\N	PRESENT	0
591687	590540	14231L	PARTICIPANT	\N	PRESENT	0
591688	590540	08018U	PARTICIPANT	\N	PRESENT	0
591689	590540	14259Y	PARTICIPANT	\N	PRESENT	0
591690	590540	04008A	PARTICIPANT	\N	PRESENT	0
591694	590829	01048V	PARTICIPANT	\N	PRESENT	0
591725	590829	04071H	PARTICIPANT	\N	PRESENT	0
591726	590829	20150Y	PARTICIPANT	\N	PRESENT	0
591736	590540	19515S	PARTICIPANT	\N	PRESENT	0
591737	590540	19679N	PARTICIPANT	\N	PRESENT	0
591738	590540	20128B	PARTICIPANT	\N	PRESENT	0
591739	590540	14001X	PARTICIPANT	\N	PRESENT	0
591740	590540	19543W	PARTICIPANT	\N	PRESENT	0
591743	590797	19383Y	PARTICIPANT	\N	PRESENT	0
591744	590797	20088L	PARTICIPANT	\N	PRESENT	0
591745	590797	19768N	PARTICIPANT	\N	PRESENT	0
591746	590797	19515S	PARTICIPANT	\N	PRESENT	0
591747	590797	20092G	PARTICIPANT	\N	PRESENT	0
591748	590797	19782L	PARTICIPANT	\N	PRESENT	0
591749	590797	14357A	PARTICIPANT	\N	PRESENT	0
591750	590797	19441R	PARTICIPANT	\N	PRESENT	0
591751	590797	20078J	PARTICIPANT	\N	PRESENT	0
591752	590797	19413M	PARTICIPANT	\N	PRESENT	0
591753	590797	20082E	PARTICIPANT	\N	PRESENT	0
591754	590797	20094J	PARTICIPANT	\N	PRESENT	0
591755	590797	04045F	PARTICIPANT	\N	PRESENT	0
591756	590797	19631V	PARTICIPANT	\N	PRESENT	0
591757	590797	20104S	PARTICIPANT	\N	PRESENT	0
591758	590797	19705W	PARTICIPANT	\N	PRESENT	0
591759	590797	08015R	PARTICIPANT	\N	PRESENT	1
591760	590797	19575F	PARTICIPANT	\N	PRESENT	0
591761	590797	19369B	PARTICIPANT	\N	PRESENT	0
591762	590797	20018V	PARTICIPANT	\N	PRESENT	1
591763	590797	19563B	PARTICIPANT	\N	PRESENT	0
590674	590664	11056N	PARTICIPANT	\N	PRESENT	0
591062	590541	14107H	PARTICIPANT	\N	PRESENT	1
591764	590797	19521Q	PARTICIPANT	\N	PRESENT	0
591765	590797	20028X	PARTICIPANT	\N	PRESENT	0
591766	590797	14329V	PARTICIPANT	\N	PRESENT	0
591767	590797	14038Y	PARTICIPANT	\N	PRESENT	0
591768	590797	20030R	PARTICIPANT	\N	PRESENT	1
591769	590797	19467C	PARTICIPANT	\N	PRESENT	0
591770	590797	20034V	PARTICIPANT	\N	PRESENT	0
591771	590797	14187A	PRESIDENT	0	PRESENT	0
591772	590797	20144B	PARTICIPANT	\N	PRESENT	0
591773	590797	19695N	PARTICIPANT	\N	PRESENT	0
591774	590797	14033T	PARTICIPANT	\N	PRESENT	0
591775	590797	01025N	PARTICIPANT	\N	PRESENT	0
591776	590797	20174H	PARTICIPANT	\N	PRESENT	1
591777	590797	14205J	PARTICIPANT	\N	PRESENT	0
591778	590797	20060X	PARTICIPANT	\N	PRESENT	0
591779	590797	20062A	PARTICIPANT	\N	PRESENT	0
591780	590797	14251Q	PARTICIPANT	\N	PRESENT	1
591781	590797	19507S	PARTICIPANT	\N	PRESENT	0
591782	590797	14207L	PARTICIPANT	\N	PRESENT	0
591783	590797	14257W	PARTICIPANT	\N	PRESENT	0
591889	590850	20108W	PARTICIPANT	\N	PRESENT	0
591930	590850	20172F	PARTICIPANT	\N	PRESENT	0
591931	590850	14331P	PARTICIPANT	\N	PRESENT	0
591932	590850	20032T	PARTICIPANT	\N	PRESENT	0
591933	590850	19631V	PARTICIPANT	\N	PRESENT	0
591934	590850	11115U	PARTICIPANT	\N	PRESENT	0
591935	590850	19725B	PARTICIPANT	\N	PRESENT	0
591936	590850	19527W	PARTICIPANT	\N	PRESENT	0
591937	590850	14031R	PARTICIPANT	\N	PRESENT	0
572873	571152	20124W	PARTICIPANT	\N	PRESENT	0
572935	571153	19333N	PARTICIPANT	\N	PRESENT	0
572936	571153	19599P	PARTICIPANT	\N	PRESENT	0
572937	571153	19551W	PARTICIPANT	\N	PRESENT	0
572938	571153	11067R	PARTICIPANT	\N	PRESENT	0
572940	571153	20092G	PARTICIPANT	\N	PRESENT	0
572941	571153	20106U	PARTICIPANT	\N	PRESENT	0
572942	571153	19697Q	PARTICIPANT	\N	PRESENT	0
572943	571153	04045F	PARTICIPANT	\N	PRESENT	0
572944	571153	14207L	PARTICIPANT	\N	PRESENT	0
572945	571153	19826F	PARTICIPANT	\N	PRESENT	0
572946	571153	14231L	PARTICIPANT	\N	PRESENT	0
572947	571153	20052X	PARTICIPANT	\N	PRESENT	0
572948	571153	14041T	PARTICIPANT	\N	PRESENT	0
572949	571153	19507S	PARTICIPANT	\N	PRESENT	0
572951	571153	19533U	PARTICIPANT	\N	PRESENT	0
572952	571153	14357A	PARTICIPANT	\N	PRESENT	0
572953	571153	20062A	PARTICIPANT	\N	PRESENT	0
572954	571153	20124W	PARTICIPANT	\N	PRESENT	0
572955	571153	20020P	PARTICIPANT	\N	PRESENT	0
572956	571153	14217N	PARTICIPANT	\N	PRESENT	0
572957	571153	19711U	PARTICIPANT	\N	PRESENT	0
572958	571153	04043D	PARTICIPANT	\N	PRESENT	0
572959	571153	19747H	PARTICIPANT	\N	PRESENT	0
572960	571153	20100N	PARTICIPANT	\N	PRESENT	0
572962	571153	19369B	PARTICIPANT	\N	PRESENT	0
572963	571153	19619A	PARTICIPANT	\N	PRESENT	0
572964	571153	19701S	PARTICIPANT	\N	PRESENT	0
572965	571153	20136B	PARTICIPANT	\N	PRESENT	0
572966	571153	14219Q	PARTICIPANT	\N	PRESENT	0
572967	571153	14257W	PARTICIPANT	\N	PRESENT	0
572968	571153	19251M	PARTICIPANT	\N	PRESENT	0
572969	571153	20102Q	PARTICIPANT	\N	PRESENT	0
572970	571153	11040E	PARTICIPANT	\N	PRESENT	0
572971	571153	10015M	PARTICIPANT	\N	PRESENT	0
572972	571153	19503N	PARTICIPANT	\N	PRESENT	0
572973	571153	14169X	PARTICIPANT	\N	PRESENT	0
572974	571153	19515S	PARTICIPANT	\N	PRESENT	0
572975	571153	14205J	PARTICIPANT	\N	PRESENT	0
572976	571153	14083S	PARTICIPANT	\N	PRESENT	0
572977	571153	14031R	PARTICIPANT	\N	PRESENT	0
572978	571153	14038Y	PARTICIPANT	\N	PRESENT	0
572979	571153	19954N	PARTICIPANT	\N	PRESENT	0
572980	571153	20180F	PARTICIPANT	\N	PRESENT	0
572981	571153	19399H	PARTICIPANT	\N	PRESENT	0
572982	571153	14187A	PARTICIPANT	\N	PRESENT	0
572983	571153	11064N	PARTICIPANT	\N	PRESENT	0
572984	571153	20082E	PARTICIPANT	\N	PRESENT	0
572995	571153	19758L	PARTICIPANT	\N	PRESENT	0
572996	571153	11065P	PARTICIPANT	\N	PRESENT	0
572999	571153	14215L	PARTICIPANT	\N	PRESENT	0
573067	571154	11040E	PARTICIPANT	\N	PRESENT	0
573068	571154	19599P	PARTICIPANT	\N	PRESENT	0
573108	571154	19747H	PARTICIPANT	\N	PRESENT	0
573070	571154	19251M	PARTICIPANT	\N	PRESENT	0
573071	571154	19333N	PARTICIPANT	\N	PRESENT	0
573072	571154	19826F	PARTICIPANT	\N	PRESENT	0
573073	571154	20136B	PARTICIPANT	\N	PRESENT	0
573082	571154	10015M	PARTICIPANT	\N	PRESENT	0
572933	571153	12041X	PARTICIPANT	\N	PRESENT	0
572934	571153	20114U	PARTICIPANT	\N	PRESENT	0
573083	571154	19515S	PARTICIPANT	\N	PRESENT	0
573084	571154	11090Q	PARTICIPANT	\N	PRESENT	0
573085	571154	14031R	PARTICIPANT	\N	PRESENT	0
573086	571154	19954N	PARTICIPANT	\N	PRESENT	0
573087	571154	20102Q	PARTICIPANT	\N	PRESENT	0
573088	571154	19758L	PARTICIPANT	\N	PRESENT	0
573089	571154	20034V	PARTICIPANT	\N	PRESENT	0
573090	571154	14111D	PARTICIPANT	\N	PRESENT	0
573091	571154	11065P	PARTICIPANT	\N	PRESENT	0
573092	571154	20110Q	PARTICIPANT	\N	PRESENT	0
573093	571154	20100N	PARTICIPANT	\N	PRESENT	0
573094	571154	19503N	PARTICIPANT	\N	PRESENT	0
573095	571154	19369B	PARTICIPANT	\N	PRESENT	0
573096	571154	19551W	PARTICIPANT	\N	PRESENT	0
573097	571154	14257W	PARTICIPANT	\N	PRESENT	0
573098	571154	11033F	PARTICIPANT	\N	PRESENT	0
573099	571154	19619A	PARTICIPANT	\N	PRESENT	0
573100	571154	19637C	PARTICIPANT	\N	PRESENT	0
573101	571154	11012A	PARTICIPANT	\N	PRESENT	0
573102	571154	20124W	PARTICIPANT	\N	PRESENT	0
573103	571154	19721W	PARTICIPANT	\N	PRESENT	0
573104	571154	20082E	PARTICIPANT	\N	PRESENT	0
573105	571154	14215L	PARTICIPANT	\N	PRESENT	0
573106	571154	20046A	PARTICIPANT	\N	PRESENT	0
573107	571154	19399H	PARTICIPANT	\N	PRESENT	0
573109	571154	14187A	PARTICIPANT	\N	PRESENT	0
573110	571154	20180F	PARTICIPANT	\N	PRESENT	0
573111	571154	11067R	PARTICIPANT	\N	PRESENT	0
573112	571154	19683J	PARTICIPANT	\N	PRESENT	0
573117	571154	14207L	PARTICIPANT	\N	PRESENT	0
573114	571154	19697Q	PARTICIPANT	\N	PRESENT	0
573115	571154	20052X	PARTICIPANT	\N	PRESENT	0
573116	571154	19681G	PARTICIPANT	\N	PRESENT	0
573118	571154	20092G	PARTICIPANT	\N	PRESENT	0
573119	571154	19711U	PARTICIPANT	\N	PRESENT	0
573120	571154	20114U	PARTICIPANT	\N	PRESENT	0
573121	571154	19701S	PARTICIPANT	\N	PRESENT	0
573135	571154	11101A	PARTICIPANT	\N	PRESENT	0
573123	571154	04043D	PARTICIPANT	\N	PRESENT	0
573124	571154	20020P	PARTICIPANT	\N	PRESENT	0
573128	571154	14205J	PARTICIPANT	\N	PRESENT	0
573065	571154	99004R	PARTICIPANT	\N	PRESENT	0
573066	571154	14219Q	PARTICIPANT	\N	PRESENT	0
573129	571154	20120S	PARTICIPANT	\N	PRESENT	0
573130	571154	20018V	PARTICIPANT	\N	PRESENT	0
573131	571154	14038Y	PARTICIPANT	\N	PRESENT	0
573132	571154	19631V	PARTICIPANT	\N	PRESENT	0
573133	571154	11053K	PARTICIPANT	\N	PRESENT	0
573134	571154	19533U	PARTICIPANT	\N	PRESENT	0
573140	571154	14030Q	PARTICIPANT	\N	PRESENT	0
573141	571154	14231L	PARTICIPANT	\N	PRESENT	0
573142	571154	04085P	PARTICIPANT	\N	PRESENT	0
573143	571154	11045K	PARTICIPANT	\N	PRESENT	0
573144	571154	08010L	PARTICIPANT	\N	PRESENT	0
573145	571154	17023S	PARTICIPANT	\N	PRESENT	0
573146	571154	19691J	PARTICIPANT	\N	PRESENT	0
573147	571154	19413M	PARTICIPANT	\N	PRESENT	0
573148	571154	14357A	PARTICIPANT	\N	PRESENT	0
573183	571154	20070A	PARTICIPANT	\N	PRESENT	0
573184	571154	20106U	PARTICIPANT	\N	PRESENT	0
573185	571154	14169X	PARTICIPANT	\N	PRESENT	0
573186	571154	14251Q	PARTICIPANT	\N	PRESENT	0
573188	571154	11085T	PARTICIPANT	\N	PRESENT	0
573189	571154	19549D	PARTICIPANT	\N	PRESENT	0
573201	571154	20152B	PARTICIPANT	\N	PRESENT	0
573239	571155	11045K	PARTICIPANT	\N	PRESENT	0
573240	571155	11090Q	PARTICIPANT	\N	PRESENT	0
573241	571155	14187A	PARTICIPANT	\N	PRESENT	0
573242	571155	20092G	PARTICIPANT	\N	PRESENT	0
573243	571155	11040E	PARTICIPANT	\N	PRESENT	0
573244	571155	20100N	PARTICIPANT	\N	PRESENT	0
573245	571155	19631V	PARTICIPANT	\N	PRESENT	0
573246	571155	19619A	PARTICIPANT	\N	PRESENT	0
573247	571155	19369B	PARTICIPANT	\N	PRESENT	0
573248	571155	19701S	PARTICIPANT	\N	PRESENT	0
573249	571155	14031R	PARTICIPANT	\N	PRESENT	0
573250	571155	19599P	PARTICIPANT	\N	PRESENT	0
573251	571155	19503N	PARTICIPANT	\N	PRESENT	0
573252	571155	20152B	PARTICIPANT	\N	PRESENT	0
573253	571155	19711U	PARTICIPANT	\N	PRESENT	0
573254	571155	20034V	PARTICIPANT	\N	PRESENT	0
573255	571155	19826F	PARTICIPANT	\N	PRESENT	0
573256	571155	19413M	PARTICIPANT	\N	PRESENT	0
573257	571155	20106U	PARTICIPANT	\N	PRESENT	0
573258	571155	19697Q	PARTICIPANT	\N	PRESENT	0
573259	571155	14207L	PARTICIPANT	\N	PRESENT	0
573260	571155	19681G	PARTICIPANT	\N	PRESENT	0
573261	571155	17023S	PARTICIPANT	\N	PRESENT	0
573262	571155	19515S	PARTICIPANT	\N	PRESENT	0
573263	571155	12041X	PARTICIPANT	\N	PRESENT	0
573264	571155	20102Q	PARTICIPANT	\N	PRESENT	0
573265	571155	20046A	PARTICIPANT	\N	PRESENT	0
573266	571155	20018V	PARTICIPANT	\N	PRESENT	0
573267	571155	07029T	PARTICIPANT	\N	PRESENT	0
573268	571155	20082E	PARTICIPANT	\N	PRESENT	0
573269	571155	19549D	PARTICIPANT	\N	PRESENT	0
573270	571155	14030Q	PARTICIPANT	\N	PRESENT	0
573271	571155	14219Q	PARTICIPANT	\N	PRESENT	0
573272	571155	19333N	PARTICIPANT	\N	PRESENT	0
573273	571155	14257W	PARTICIPANT	\N	PRESENT	0
588886	588530	19479G	PARTICIPANT	\N	PRESENT	0
588887	588530	20132W	PARTICIPANT	\N	PRESENT	0
588888	588530	14173T	PARTICIPANT	\N	PRESENT	0
588889	588530	19399H	PARTICIPANT	\N	PRESENT	0
588890	588530	14133K	PARTICIPANT	\N	PRESENT	0
588891	588530	19711U	PARTICIPANT	\N	PRESENT	0
588892	588530	14223L	PARTICIPANT	\N	PRESENT	0
588893	588530	04035D	PARTICIPANT	\N	PRESENT	0
588894	588530	20066E	PARTICIPANT	\N	PRESENT	0
588895	588530	20068G	PARTICIPANT	\N	PRESENT	0
588896	588530	20070A	PARTICIPANT	\N	PRESENT	0
588897	588530	19599P	PARTICIPANT	\N	PRESENT	0
588899	588530	14225N	PARTICIPANT	\N	PRESENT	0
589058	588900	19679N	PARTICIPANT	\N	PRESENT	0
589097	588229	14069U	PARTICIPANT	\N	PRESENT	1
589682	588234	04085P	PARTICIPANT	\N	PRESENT	1
589099	588229	10015M	PARTICIPANT	\N	PRESENT	1
589100	588229	14107H	PARTICIPANT	\N	PRESENT	1
589683	588234	14179A	PARTICIPANT	\N	PRESENT	1
589684	588234	19649G	PARTICIPANT	\N	PRESENT	1
589685	588234	10015M	PARTICIPANT	\N	PRESENT	1
589686	588234	14107H	PARTICIPANT	\N	PRESENT	1
589778	588235	14038Y	PARTICIPANT	\N	PRESENT	1
589779	588235	17737W	PARTICIPANT	\N	PRESENT	1
589780	588235	20128B	PARTICIPANT	\N	PRESENT	1
590022	590021	19719D	PARTICIPANT	\N	PRESENT	0
590357	590351	19717B	PRESIDENT	0	PRESENT	0
590359	590351	97011G	PARTICIPANT	\N	EXCUSE	0
590360	590351	19329S	PARTICIPANT	\N	EXCUSE	0
590370	590351	11012A	PARTICIPANT	\N	PRESENT	0
590363	590351	14331P	PARTICIPANT	\N	EXCUSE	0
590364	590351	19691J	PARTICIPANT	\N	EXCUSE	0
590365	590351	14259Y	PARTICIPANT	\N	EXCUSE	0
590366	590351	05008E	PARTICIPANT	\N	EXCUSE	0
590368	590351	11090Q	PARTICIPANT	\N	EXCUSE	0
590369	590351	08073C	PARTICIPANT	\N	PRESENT	0
590371	590351	19503N	PARTICIPANT	\N	PRESENT	0
590373	590351	86034E	PARTICIPANT	\N	PRESENT	0
590374	590351	17023S	PARTICIPANT	\N	PRESENT	0
590375	590351	11072N	PARTICIPANT	\N	PRESENT	0
590432	590431	17367Q	PARTICIPANT	\N	PRESENT	0
590433	590431	11083R	PARTICIPANT	\N	PRESENT	0
590434	590431	08061X	PARTICIPANT	\N	PRESENT	0
590477	586370	20104S	PRESIDENT	0	PRESENT	0
590478	586370	20094J	PARTICIPANT	\N	PRESENT	0
590479	586370	14097Y	PARTICIPANT	\N	PRESENT	1
590480	586370	10015M	PARTICIPANT	\N	PRESENT	1
590481	586370	04070G	PARTICIPANT	\N	PRESENT	0
590482	586370	04057K	PARTICIPANT	\N	PRESENT	1
590483	586370	14331P	PARTICIPANT	\N	EXCUSE	0
590484	586370	19333N	PARTICIPANT	\N	PRESENT	0
590485	586370	20128B	PARTICIPANT	\N	PRESENT	1
590486	586370	19531S	PARTICIPANT	\N	PRESENT	0
590487	586370	14207L	PARTICIPANT	\N	PRESENT	1
590488	586370	14189C	PARTICIPANT	\N	PRESENT	0
590650	590649	19335Q	PARTICIPANT	\N	PRESENT	0
590652	590651	19667J	PARTICIPANT	\N	PRESENT	0
590653	590651	11040E	PARTICIPANT	\N	PRESENT	0
590654	588543	14105F	PARTICIPANT	\N	PRESENT	0
590655	588543	20084G	PARTICIPANT	\N	PRESENT	0
590656	588543	07029T	PARTICIPANT	\N	PRESENT	0
590658	588543	20132W	PARTICIPANT	\N	PRESENT	0
590568	590567	05008E	PARTICIPANT	\N	PRESENT	0
590720	588543	19577H	PARTICIPANT	\N	PRESENT	0
590683	588543	20090E	PARTICIPANT	\N	PRESENT	0
590573	590567	11033F	PARTICIPANT	\N	PRESENT	0
590574	590567	11053K	PARTICIPANT	\N	PRESENT	0
590575	590567	11070L	PARTICIPANT	\N	PRESENT	0
590576	590567	19719D	PARTICIPANT	\N	PRESENT	0
590577	590567	19673G	PARTICIPANT	\N	PRESENT	0
590578	590567	01025N	PARTICIPANT	\N	PRESENT	0
590579	590567	14033T	PARTICIPANT	\N	PRESENT	0
590580	590567	14123H	PARTICIPANT	\N	PRESENT	0
590581	590567	14026U	PARTICIPANT	\N	PRESENT	0
590582	590567	11064N	PARTICIPANT	\N	PRESENT	0
590583	590567	14179A	PARTICIPANT	\N	PRESENT	0
590584	590567	14213J	PARTICIPANT	\N	PRESENT	0
590585	590567	19715Y	PARTICIPANT	\N	PRESENT	0
590586	590567	99004R	PARTICIPANT	\N	PRESENT	0
590587	590567	86034E	PARTICIPANT	\N	PRESENT	0
590588	590567	12041X	PARTICIPANT	\N	PRESENT	0
590589	590567	14147R	PARTICIPANT	\N	PRESENT	0
590590	590567	01028R	PARTICIPANT	\N	PRESENT	0
590591	590567	19301E	PARTICIPANT	\N	PRESENT	0
590592	590567	01043Q	PARTICIPANT	\N	PRESENT	0
590685	588543	20248J	PARTICIPANT	\N	PRESENT	0
590686	588543	11031D	PARTICIPANT	\N	PRESENT	0
590687	588543	18083K	PARTICIPANT	\N	PRESENT	0
590688	588543	19758L	PARTICIPANT	\N	PRESENT	0
590689	588543	18193Q	PARTICIPANT	\N	PRESENT	0
590690	588543	19301E	PARTICIPANT	\N	PRESENT	0
590691	588543	20040T	PARTICIPANT	\N	PRESENT	0
590694	588543	11067R	PARTICIPANT	\N	PRESENT	0
590717	588543	11064N	PARTICIPANT	\N	PRESENT	0
590719	588543	04085P	PARTICIPANT	\N	PRESENT	0
590721	588543	14069U	PARTICIPANT	\N	PRESENT	0
590630	590629	11053K	PARTICIPANT	\N	PRESENT	0
590632	590631	11074Q	PARTICIPANT	\N	PRESENT	0
590633	590631	19349W	PARTICIPANT	\N	PRESENT	0
590635	590634	01057W	PARTICIPANT	\N	PRESENT	0
590636	590634	14225N	PARTICIPANT	\N	PRESENT	0
590726	588543	19699S	PARTICIPANT	\N	PRESENT	0
590723	588543	19687N	PARTICIPANT	\N	PRESENT	0
590724	588543	19479G	PARTICIPANT	\N	PRESENT	0
588992	588531	08015R	PARTICIPANT	\N	PRESENT	0
589053	588898	19679N	PARTICIPANT	\N	PRESENT	0
590727	588543	19543W	PARTICIPANT	\N	PRESENT	0
590642	590641	04057K	PARTICIPANT	\N	PRESENT	0
590643	590641	14249W	PARTICIPANT	\N	PRESENT	0
590644	590641	14069U	PARTICIPANT	\N	PRESENT	0
590728	588543	19593H	PARTICIPANT	\N	PRESENT	0
590729	588543	04057K	PARTICIPANT	\N	PRESENT	0
590730	588543	20124W	PARTICIPANT	\N	PRESENT	0
590648	588543	99004R	PARTICIPANT	\N	PRESENT	0
590731	588543	19683J	PARTICIPANT	\N	PRESENT	0
590732	588543	20032T	PARTICIPANT	\N	PRESENT	0
590733	588543	14030Q	PARTICIPANT	\N	PRESENT	0
590734	588543	19527W	PARTICIPANT	\N	PRESENT	0
590735	588543	20024T	PARTICIPANT	\N	PRESENT	0
590736	588543	20152B	PARTICIPANT	\N	PRESENT	0
590745	588543	14123H	PARTICIPANT	\N	PRESENT	0
590775	588544	20084G	PARTICIPANT	\N	PRESENT	0
590776	588544	11067R	PARTICIPANT	\N	PRESENT	0
590777	588544	20106U	PARTICIPANT	\N	PRESENT	0
590778	588544	11064N	PARTICIPANT	\N	PRESENT	0
590779	588544	19479G	PARTICIPANT	\N	PRESENT	0
590780	588544	20248J	PARTICIPANT	\N	PRESENT	0
590781	588544	14030Q	PARTICIPANT	\N	PRESENT	0
590782	588544	20132W	PARTICIPANT	\N	PRESENT	0
590783	588544	20152B	PARTICIPANT	\N	PRESENT	0
590784	588544	20124W	PARTICIPANT	\N	PRESENT	0
590785	588544	07029T	PARTICIPANT	\N	PRESENT	0
590786	588544	18083K	PARTICIPANT	\N	PRESENT	0
590787	588544	11031D	PARTICIPANT	\N	PRESENT	0
590788	588544	19758L	PARTICIPANT	\N	PRESENT	0
590789	588544	19687N	PARTICIPANT	\N	PRESENT	0
590790	588544	19593H	PARTICIPANT	\N	PRESENT	0
590791	588544	04057K	PARTICIPANT	\N	PRESENT	0
590792	588544	19553Y	PARTICIPANT	\N	PRESENT	0
590793	588544	14069U	PARTICIPANT	\N	PRESENT	0
590794	588544	14123H	PARTICIPANT	\N	PRESENT	0
590795	588544	19577H	PARTICIPANT	\N	PRESENT	0
590796	588544	19747H	PARTICIPANT	\N	PRESENT	0
590801	590351	18083K	PARTICIPANT	\N	PRESENT	0
590802	590351	20034V	PARTICIPANT	\N	PRESENT	0
590803	590351	12016W	PARTICIPANT	\N	PRESENT	0
590811	590810	14133K	PARTICIPANT	\N	PRESENT	0
590812	590810	14097Y	PARTICIPANT	\N	PRESENT	0
590773	588544	99004R	PARTICIPANT	\N	PRESENT	0
590774	588544	19527W	PARTICIPANT	\N	PRESENT	0
590814	590813	14133K	PARTICIPANT	\N	PRESENT	0
590815	590813	14097Y	PARTICIPANT	\N	PRESENT	0
590817	590816	14267Y	PARTICIPANT	\N	PRESENT	0
590818	590816	19565D	PARTICIPANT	\N	PRESENT	0
590822	590821	14189C	PARTICIPANT	\N	PRESENT	0
590823	590821	20120S	PARTICIPANT	\N	PRESENT	0
590824	590821	19683J	PRESIDENT	0	PRESENT	0
590825	590821	99004R	PARTICIPANT	\N	PRESENT	0
590826	590821	20034V	PARTICIPANT	\N	PRESENT	0
590830	590821	19717B	PARTICIPANT	\N	PRESENT	0
590831	590821	19319Q	PARTICIPANT	\N	PRESENT	0
583218	583217	19711U	PARTICIPANT	\N	PRESENT	0
583223	583222	20050V	PARTICIPANT	\N	PRESENT	0
583834	583833	19447X	PARTICIPANT	\N	PRESENT	0
583837	583836	19447X	PARTICIPANT	\N	PRESENT	0
583838	583836	19725B	PARTICIPANT	\N	PRESENT	0
585640	585637	14213J	PARTICIPANT	\N	PRESENT	0
585641	585637	18193Q	PARTICIPANT	\N	PRESENT	0
586447	583492	20104S	PARTICIPANT	\N	PRESENT	0
586449	583493	20104S	PARTICIPANT	\N	PRESENT	0
586452	583494	20104S	PARTICIPANT	\N	PRESENT	0
586454	583495	20104S	PARTICIPANT	\N	PRESENT	0
587140	585658	20248J	PARTICIPANT	\N	PRESENT	0
587141	585658	19723Y	PARTICIPANT	\N	PRESENT	0
587142	585658	18193Q	PARTICIPANT	\N	PRESENT	0
587143	585658	14071N	PARTICIPANT	\N	PRESENT	0
587144	585658	20130U	PARTICIPANT	\N	PRESENT	1
587145	585658	14213J	PARTICIPANT	\N	PRESENT	0
587146	585658	20172F	PARTICIPANT	\N	PRESENT	0
587147	585658	19679N	PARTICIPANT	\N	PRESENT	0
589349	589348	20092G	PARTICIPANT	\N	PRESENT	0
589350	589348	20130U	PARTICIPANT	\N	PRESENT	0
589352	589351	14083S	PARTICIPANT	\N	PRESENT	0
589353	589351	14267Y	PARTICIPANT	\N	PRESENT	0
589382	589351	14059S	PARTICIPANT	\N	PRESENT	0
589383	589351	14193X	PARTICIPANT	\N	PRESENT	0
589384	589351	19421M	PARTICIPANT	\N	PRESENT	0
589465	588526	19631V	PARTICIPANT	\N	PRESENT	0
589466	588526	19515S	PARTICIPANT	\N	PRESENT	0
589469	588526	19575F	PARTICIPANT	\N	PRESENT	0
589471	588526	20094J	PARTICIPANT	\N	PRESENT	0
589472	588526	19747H	PARTICIPANT	\N	PRESENT	0
589473	588526	19383Y	PARTICIPANT	\N	PRESENT	0
589474	588526	19782L	PARTICIPANT	\N	PRESENT	0
589475	588526	14207L	PARTICIPANT	\N	PRESENT	0
589476	588526	20104S	PARTICIPANT	\N	PRESENT	0
589477	588526	08028W	PARTICIPANT	\N	PRESENT	0
589478	588526	14357A	PARTICIPANT	\N	PRESENT	0
589479	588526	14187A	PARTICIPANT	\N	PRESENT	0
589480	588526	19511N	PARTICIPANT	\N	PRESENT	0
589481	588526	01043Q	PARTICIPANT	\N	PRESENT	0
589482	588526	14251Q	PARTICIPANT	\N	PRESENT	0
589483	588526	19563B	PARTICIPANT	\N	PRESENT	0
589485	588526	20028X	PARTICIPANT	\N	PRESENT	0
589486	588526	20018V	PARTICIPANT	\N	PRESENT	0
589487	588526	14257W	PARTICIPANT	\N	PRESENT	0
589488	588526	11090Q	PARTICIPANT	\N	PRESENT	0
589489	588526	19705W	PARTICIPANT	\N	PRESENT	0
589490	588526	20078J	PARTICIPANT	\N	PRESENT	1
589491	588526	20088L	PARTICIPANT	\N	PRESENT	1
589492	588526	19467C	PARTICIPANT	\N	PRESENT	1
589493	588526	08015R	PARTICIPANT	\N	PRESENT	1
589494	588526	14205J	PARTICIPANT	\N	PRESENT	1
589495	588526	19768N	PARTICIPANT	\N	PRESENT	1
589496	588526	19866P	PARTICIPANT	\N	PRESENT	1
589497	588526	20030R	PARTICIPANT	\N	PRESENT	1
589499	588526	20074E	PARTICIPANT	\N	PRESENT	0
589500	588526	14231L	PARTICIPANT	\N	PRESENT	0
589501	588526	11026G	PARTICIPANT	\N	PRESENT	0
589502	588526	14111D	PARTICIPANT	\N	PRESENT	0
589503	588526	14147R	PARTICIPANT	\N	PRESENT	0
589504	588526	01028R	PARTICIPANT	\N	PRESENT	0
589505	588526	19585H	PARTICIPANT	\N	PRESENT	0
589506	588526	14069U	PARTICIPANT	\N	PRESENT	1
589507	588526	10015M	PARTICIPANT	\N	PRESENT	1
589508	588526	14107H	PARTICIPANT	\N	PRESENT	1
589513	588526	14030Q	PARTICIPANT	\N	PRESENT	0
589514	588526	14105F	PARTICIPANT	\N	PRESENT	0
589515	588526	14083S	PARTICIPANT	\N	PRESENT	0
589516	588526	19251M	PARTICIPANT	\N	PRESENT	0
589517	588526	14031R	PARTICIPANT	\N	PRESENT	0
589518	588526	19762G	PARTICIPANT	\N	PRESENT	0
589519	588526	19671E	PARTICIPANT	\N	PRESENT	1
592899	592898	08012N	PARTICIPANT	\N	PRESENT	0
592903	592898	11043H	PARTICIPANT	\N	PRESENT	0
593325	593323	19709B	PARTICIPANT	\N	PRESENT	0
593452	593451	19651A	PARTICIPANT	\N	PRESENT	0
593453	593451	20094J	PARTICIPANT	\N	PRESENT	0
593455	593451	20042V	PARTICIPANT	\N	PRESENT	0
593456	593451	04070G	PARTICIPANT	\N	PRESENT	0
593457	593451	20028X	PARTICIPANT	\N	PRESENT	0
593458	593451	11012A	PARTICIPANT	\N	PRESENT	0
593459	593451	20064C	PARTICIPANT	\N	PRESENT	0
593461	593451	14001X	PARTICIPANT	\N	PRESENT	0
593465	593463	14001X	PARTICIPANT	\N	PRESENT	0
593466	593463	19725B	PARTICIPANT	\N	PRESENT	0
593467	593463	04070G	PARTICIPANT	\N	PRESENT	0
593607	593570	19679N	PARTICIPANT	\N	PRESENT	1
593610	593576	19679N	PARTICIPANT	\N	PRESENT	1
596584	594920	14329V	PARTICIPANT	\N	EXCUSE	0
596641	595603	20068G	PARTICIPANT	\N	PRESENT	0
596662	595603	19399H	PARTICIPANT	\N	PRESENT	0
596660	595603	86034E	PARTICIPANT	\N	PRESENT	0
596661	595603	14031R	PARTICIPANT	\N	PRESENT	0
596663	595603	20024T	PARTICIPANT	\N	PRESENT	0
596664	595603	08056B	PARTICIPANT	\N	PRESENT	0
596665	595603	14105F	PARTICIPANT	\N	PRESENT	0
596666	595603	19533U	PARTICIPANT	\N	PRESENT	0
596667	595603	19798U	PARTICIPANT	\N	PRESENT	0
596668	595603	11101A	PARTICIPANT	\N	PRESENT	0
596669	595603	19383Y	PARTICIPANT	\N	PRESENT	0
596670	595603	14053L	PARTICIPANT	\N	PRESENT	0
596671	595603	19695N	PARTICIPANT	\N	PRESENT	0
596672	595603	19705W	PARTICIPANT	\N	PRESENT	0
596673	595603	99004R	PARTICIPANT	\N	PRESENT	0
596674	595603	08069G	PARTICIPANT	\N	PRESENT	0
596676	595603	20096L	PARTICIPANT	\N	PRESENT	0
596678	595603	19643A	PARTICIPANT	\N	PRESENT	0
596679	595603	20022R	PARTICIPANT	\N	PRESENT	0
596680	595603	20026V	PARTICIPANT	\N	PRESENT	0
596681	595603	11066Q	PARTICIPANT	\N	PRESENT	0
596682	595603	19739H	PARTICIPANT	\N	PRESENT	0
596683	595603	14073Q	PARTICIPANT	\N	PRESENT	0
596684	595603	14107H	PARTICIPANT	\N	PRESENT	0
596685	595603	20036X	PARTICIPANT	\N	PRESENT	0
596686	595603	19349W	PARTICIPANT	\N	PRESENT	0
596687	595603	19649G	PARTICIPANT	\N	PRESENT	0
596688	595603	20084G	PARTICIPANT	\N	PRESENT	0
596689	595603	19583F	PARTICIPANT	\N	PRESENT	0
596690	595603	14221J	PARTICIPANT	\N	PRESENT	0
596691	595603	19503N	PARTICIPANT	\N	PRESENT	0
596692	595603	20088L	PARTICIPANT	\N	PRESENT	0
596693	595603	17229F	PARTICIPANT	\N	PRESENT	0
596694	595603	11012A	PARTICIPANT	\N	PRESENT	0
596695	595603	19820Y	PARTICIPANT	\N	PRESENT	0
596696	595603	19699S	PARTICIPANT	\N	PRESENT	0
596697	595603	08061X	PARTICIPANT	\N	PRESENT	0
596698	595603	11041F	PARTICIPANT	\N	PRESENT	0
596699	595603	19647E	PARTICIPANT	\N	PRESENT	0
596700	595603	14257W	PARTICIPANT	\N	PRESENT	0
596701	595603	14281W	PARTICIPANT	\N	PRESENT	0
596702	595603	14111D	PARTICIPANT	\N	PRESENT	0
596703	595603	19866P	PARTICIPANT	\N	PRESENT	0
596704	595603	20132W	PARTICIPANT	\N	PRESENT	0
596705	595603	20144B	PARTICIPANT	\N	PRESENT	0
596706	595603	11054L	PARTICIPANT	\N	PRESENT	0
596707	595603	14001X	PARTICIPANT	\N	PRESENT	0
596708	595603	19599P	PARTICIPANT	\N	PRESENT	0
596709	595603	19689Q	PARTICIPANT	\N	PRESENT	0
596710	595603	14207L	PARTICIPANT	\N	PRESENT	0
596711	595603	16685X	PARTICIPANT	\N	PRESENT	0
596712	595603	20052X	PARTICIPANT	\N	PRESENT	0
596713	595603	14195A	PARTICIPANT	\N	PRESENT	0
596714	595603	19563B	PARTICIPANT	\N	PRESENT	0
596715	595603	14229S	PARTICIPANT	\N	PRESENT	0
596716	595603	20064C	PARTICIPANT	\N	PRESENT	0
596717	595603	11040E	PARTICIPANT	\N	PRESENT	0
596718	595603	19760E	PARTICIPANT	\N	PRESENT	0
596719	595603	19758L	PARTICIPANT	\N	PRESENT	0
596720	595603	11056N	PARTICIPANT	\N	PRESENT	0
596721	595603	04085P	PARTICIPANT	\N	PRESENT	0
596722	595603	14211G	PARTICIPANT	\N	PRESENT	0
596723	595603	19565D	PARTICIPANT	\N	PRESENT	0
596724	595603	19593H	PARTICIPANT	\N	PRESENT	0
596725	595603	19693L	PARTICIPANT	\N	PRESENT	0
596726	595603	20112S	PARTICIPANT	\N	PRESENT	0
596727	595603	20046A	PARTICIPANT	\N	PRESENT	0
596728	595603	19575F	PARTICIPANT	\N	PRESENT	0
596729	595603	20092G	PARTICIPANT	\N	PRESENT	0
596730	595603	19347U	PARTICIPANT	\N	PRESENT	0
596731	595603	17637T	PARTICIPANT	\N	PRESENT	0
596732	595603	20100N	PARTICIPANT	\N	PRESENT	0
591938	590850	11010L	PARTICIPANT	\N	PRESENT	0
591939	590850	20264J	PARTICIPANT	\N	PRESENT	0
591940	590850	19673G	PARTICIPANT	\N	PRESENT	0
591941	590850	20038A	PARTICIPANT	\N	PRESENT	0
591942	590850	11110B	PARTICIPANT	\N	PRESENT	0
591943	590850	14281W	PARTICIPANT	\N	PRESENT	0
591944	590850	19515S	PARTICIPANT	\N	PRESENT	0
591945	590850	14191V	PARTICIPANT	\N	PRESENT	0
591946	590850	11066Q	PARTICIPANT	\N	PRESENT	0
591947	590850	14259Y	PARTICIPANT	\N	PRESENT	0
591948	590850	11054L	PARTICIPANT	\N	PRESENT	0
591949	590850	20068G	PARTICIPANT	\N	PRESENT	0
591950	590850	19531S	PARTICIPANT	\N	PRESENT	0
591951	590850	19413M	PARTICIPANT	\N	PRESENT	0
591952	590850	19503N	PARTICIPANT	\N	PRESENT	0
591953	590850	20022R	PARTICIPANT	\N	PRESENT	0
591954	590850	20060X	PARTICIPANT	\N	PRESENT	0
591955	590850	05012A	PARTICIPANT	\N	PRESENT	0
591956	590850	14097Y	PARTICIPANT	\N	PRESENT	0
591957	590850	20114U	PARTICIPANT	\N	PRESENT	0
591958	590850	18193Q	PARTICIPANT	\N	PRESENT	0
591959	590850	17965H	PARTICIPANT	\N	PRESENT	0
591960	590850	19443T	PARTICIPANT	\N	PRESENT	0
592062	590850	20086J	PARTICIPANT	\N	PRESENT	0
591962	590850	19643A	PARTICIPANT	\N	PRESENT	0
591963	590850	20028X	PARTICIPANT	\N	PRESENT	0
591964	590850	20064C	PARTICIPANT	\N	PRESENT	0
591965	590850	14169X	PARTICIPANT	\N	PRESENT	0
591966	590850	20088L	PARTICIPANT	\N	PRESENT	0
591967	590850	10015M	PARTICIPANT	\N	PRESENT	0
591968	590850	01058X	PARTICIPANT	\N	PRESENT	0
591969	590850	20030R	PARTICIPANT	\N	PRESENT	0
591970	590850	04033B	PARTICIPANT	\N	PRESENT	0
591971	590850	11045K	PARTICIPANT	\N	PRESENT	0
591972	590850	08069G	PARTICIPANT	\N	PRESENT	0
591973	590850	19599P	PARTICIPANT	\N	PRESENT	0
591974	590850	18083K	PARTICIPANT	\N	PRESENT	0
591975	590850	04059M	PARTICIPANT	\N	PRESENT	0
591976	590850	01028R	PARTICIPANT	\N	PRESENT	0
591977	590850	11048N	PARTICIPANT	\N	PRESENT	0
591978	590850	08010L	PARTICIPANT	\N	PRESENT	0
591979	590850	11101A	PARTICIPANT	\N	PRESENT	0
591980	590850	19703U	PARTICIPANT	\N	PRESENT	0
591981	590850	19679N	PARTICIPANT	\N	PRESENT	0
591982	590850	19649G	PARTICIPANT	\N	PRESENT	0
591983	590850	20076G	PARTICIPANT	\N	PRESENT	0
591984	590850	20078J	PARTICIPANT	\N	PRESENT	0
591985	590850	14021P	PARTICIPANT	\N	PRESENT	0
591986	590850	14229S	PARTICIPANT	\N	PRESENT	0
591987	590850	99004R	PARTICIPANT	\N	PRESENT	0
591988	590850	19549D	PARTICIPANT	\N	PRESENT	0
591989	590850	19669L	PARTICIPANT	\N	PRESENT	0
591990	590850	19575F	PARTICIPANT	\N	PRESENT	0
591991	590850	04008A	PARTICIPANT	\N	PRESENT	0
591992	590850	04047H	PARTICIPANT	\N	PRESENT	0
591993	590850	08060W	PARTICIPANT	\N	PRESENT	0
591994	590850	14026U	PARTICIPANT	\N	PRESENT	0
591995	590850	08034U	PARTICIPANT	\N	PRESENT	0
591996	590850	11097X	PARTICIPANT	\N	PRESENT	0
591997	590850	19699S	PARTICIPANT	\N	PRESENT	0
591998	590850	14275Y	PARTICIPANT	\N	PRESENT	0
591999	590850	14071N	PARTICIPANT	\N	PRESENT	0
592000	590850	20052X	PARTICIPANT	\N	PRESENT	0
592001	590850	20042V	PARTICIPANT	\N	PRESENT	0
592002	590850	19415P	PARTICIPANT	\N	PRESENT	0
592003	590850	14042U	PARTICIPANT	\N	PRESENT	0
592004	590850	14215L	PARTICIPANT	\N	PRESENT	0
592005	590850	14219Q	PARTICIPANT	\N	PRESENT	0
592006	590850	19441R	PARTICIPANT	\N	PRESENT	0
592007	590850	19421M	PARTICIPANT	\N	PRESENT	0
592008	590850	19619A	PARTICIPANT	\N	PRESENT	0
592009	590850	19569H	PARTICIPANT	\N	PRESENT	0
592010	590850	14187A	PARTICIPANT	\N	PRESENT	0
592011	590850	19739H	PARTICIPANT	\N	PRESENT	0
592012	590850	19533U	PARTICIPANT	\N	PRESENT	0
592013	590850	16685X	PARTICIPANT	\N	PRESENT	0
592014	590850	14105F	PARTICIPANT	\N	PRESENT	0
592015	590850	20144B	PARTICIPANT	\N	PRESENT	0
592016	590850	10006L	PARTICIPANT	\N	PRESENT	0
592017	590850	14205J	PARTICIPANT	\N	PRESENT	0
592018	590850	19798U	PARTICIPANT	\N	PRESENT	0
592019	590850	08009T	PARTICIPANT	\N	PRESENT	0
592020	590850	14193X	PARTICIPANT	\N	PRESENT	0
592021	590850	11053K	PARTICIPANT	\N	PRESENT	0
592022	590850	19611R	PARTICIPANT	\N	PRESENT	0
592023	590850	19369B	PARTICIPANT	\N	PRESENT	0
592024	590850	19621T	PARTICIPANT	\N	PRESENT	0
592025	590850	11031D	PARTICIPANT	\N	PRESENT	0
592026	590850	14257W	PARTICIPANT	\N	PRESENT	0
592027	590850	20252E	PARTICIPANT	\N	PRESENT	0
592028	590850	20128B	PARTICIPANT	\N	PRESENT	0
592029	590850	20120S	PARTICIPANT	\N	PRESENT	0
592030	590850	19691J	PARTICIPANT	\N	PRESENT	0
592031	590850	14217N	PARTICIPANT	\N	PRESENT	0
592032	590850	19745F	PARTICIPANT	\N	PRESENT	0
592033	590850	11103C	PARTICIPANT	\N	PRESENT	0
592034	590850	17229F	PARTICIPANT	\N	PRESENT	0
592035	590850	97011G	PARTICIPANT	\N	PRESENT	0
592036	590850	11070L	PARTICIPANT	\N	PRESENT	0
592037	590850	14179A	PARTICIPANT	\N	PRESENT	0
592038	590850	14329V	PARTICIPANT	\N	PRESENT	0
592039	590850	14327T	PARTICIPANT	\N	PRESENT	0
592040	590850	14147R	PARTICIPANT	\N	PRESENT	0
592041	590850	14030Q	PARTICIPANT	\N	PRESENT	0
592042	590850	01025N	PARTICIPANT	\N	PRESENT	0
592043	590850	14357A	PARTICIPANT	\N	PRESENT	0
592044	590850	04070G	PARTICIPANT	\N	PRESENT	0
592045	590850	19675J	PARTICIPANT	\N	PRESENT	0
592046	590850	20066E	PARTICIPANT	\N	PRESENT	0
592047	590850	19383Y	PARTICIPANT	\N	PRESENT	0
592048	590850	20094J	PARTICIPANT	\N	PRESENT	0
592049	590850	19762G	PARTICIPANT	\N	PRESENT	0
592050	590850	20036X	PARTICIPANT	\N	PRESENT	0
592051	590850	20054A	PARTICIPANT	\N	PRESENT	0
592052	590850	20126Y	PARTICIPANT	\N	PRESENT	0
592053	590850	20124W	PARTICIPANT	\N	PRESENT	0
592054	590850	01024M	PARTICIPANT	\N	PRESENT	0
592055	590850	14059S	PARTICIPANT	\N	PRESENT	0
592056	590850	14189C	PARTICIPANT	\N	PRESENT	0
592057	590850	14255U	PARTICIPANT	\N	PRESENT	0
592058	590850	20090E	PARTICIPANT	\N	PRESENT	0
592059	590850	19826F	PARTICIPANT	\N	PRESENT	0
592060	590850	20062A	PARTICIPANT	\N	PRESENT	0
592061	590850	14083S	PARTICIPANT	\N	PRESENT	0
592063	590850	14073Q	PARTICIPANT	\N	PRESENT	0
592064	590850	19685L	PARTICIPANT	\N	PRESENT	0
592065	590850	19335Q	PARTICIPANT	\N	PRESENT	0
592066	590850	20020P	PARTICIPANT	\N	PRESENT	0
592071	590850	20080C	PARTICIPANT	\N	PRESENT	0
592068	590850	19543W	PARTICIPANT	\N	PRESENT	0
592069	590850	20026V	PARTICIPANT	\N	PRESENT	0
592070	590850	19479G	PARTICIPANT	\N	PRESENT	0
592072	590850	04092N	PARTICIPANT	\N	PRESENT	0
592073	590850	20070A	PARTICIPANT	\N	PRESENT	0
592074	590850	20018V	PARTICIPANT	\N	PRESENT	0
592075	590850	20082E	PARTICIPANT	\N	PRESENT	0
592076	590850	01057W	PARTICIPANT	\N	PRESENT	0
592077	590850	19553Y	PARTICIPANT	\N	PRESENT	0
592078	590850	01048V	PARTICIPANT	\N	PRESENT	0
592079	590850	19766L	PARTICIPANT	\N	PRESENT	0
592080	590850	20098N	PARTICIPANT	\N	PRESENT	0
592081	590850	19663E	PARTICIPANT	\N	PRESENT	0
592093	590850	04042C	PARTICIPANT	\N	PRESENT	0
592112	590850	11077T	PARTICIPANT	\N	PRESENT	0
592116	590850	11085T	PARTICIPANT	\N	PRESENT	0
592118	590850	20248J	PARTICIPANT	\N	PRESENT	0
592117	590850	19749K	PARTICIPANT	\N	PRESENT	0
592119	590850	19713W	PARTICIPANT	\N	PRESENT	0
592120	590850	14109K	PARTICIPANT	\N	PRESENT	0
592121	590850	01034P	PARTICIPANT	\N	PRESENT	0
592122	590850	19697Q	PARTICIPANT	\N	PRESENT	0
592129	592128	19717B	PARTICIPANT	\N	PRESENT	0
592125	590850	20048C	PARTICIPANT	\N	PRESENT	0
592126	590850	14121F	PARTICIPANT	\N	PRESENT	0
592127	590850	14123H	PARTICIPANT	\N	PRESENT	0
592130	592128	20024T	PARTICIPANT	\N	PRESENT	0
592131	592128	20022R	PARTICIPANT	\N	PRESENT	0
592132	592128	19575F	PARTICIPANT	\N	PRESENT	0
592133	592128	20264J	PARTICIPANT	\N	PRESENT	0
592134	592128	20144B	PARTICIPANT	\N	PRESENT	0
592135	592128	97011G	PARTICIPANT	\N	PRESENT	0
573276	571155	11065P	PARTICIPANT	\N	PRESENT	0
573277	571155	14215L	PARTICIPANT	\N	PRESENT	0
573274	571155	20110Q	PARTICIPANT	\N	PRESENT	0
573275	571155	20180F	PARTICIPANT	\N	PRESENT	0
573281	571155	19251M	PARTICIPANT	\N	PRESENT	0
573279	571155	19591F	PARTICIPANT	\N	PRESENT	0
573280	571155	20136B	PARTICIPANT	\N	PRESENT	0
573282	571155	14038Y	PARTICIPANT	\N	PRESENT	0
573283	571155	14357A	PARTICIPANT	\N	PRESENT	0
573284	571155	19663E	PARTICIPANT	\N	PRESENT	0
573285	571155	18083K	PARTICIPANT	\N	PRESENT	0
574524	573329	05012A	PARTICIPANT	\N	PRESENT	0
574525	573329	04059M	PARTICIPANT	\N	PRESENT	0
574526	573329	14053L	PARTICIPANT	\N	PRESENT	0
574527	573329	04047H	PARTICIPANT	\N	PRESENT	0
574528	573329	08017T	PARTICIPANT	\N	PRESENT	0
574529	573329	04033B	PARTICIPANT	\N	PRESENT	0
574530	573329	20126Y	PARTICIPANT	\N	PRESENT	0
574531	573329	14219Q	PARTICIPANT	\N	PRESENT	0
574532	573329	11045K	PARTICIPANT	\N	PRESENT	0
574533	573329	19758L	PARTICIPANT	\N	PRESENT	0
574534	573329	12028B	PARTICIPANT	\N	PRESENT	0
574535	573329	19647E	PARTICIPANT	\N	PRESENT	0
574536	573329	20092G	PARTICIPANT	\N	PRESENT	0
574537	573329	11027H	PARTICIPANT	\N	PRESENT	0
574538	573329	14257W	PARTICIPANT	\N	PRESENT	0
574539	573329	01058X	PARTICIPANT	\N	PRESENT	0
574540	573329	19679N	PARTICIPANT	\N	PRESENT	0
574541	573329	04008A	PARTICIPANT	\N	PRESENT	0
574542	573329	08012N	PARTICIPANT	\N	PRESENT	0
574543	573329	19531S	PARTICIPANT	\N	PRESENT	0
574544	573329	19725B	PARTICIPANT	\N	PRESENT	0
574545	573329	14021P	PARTICIPANT	\N	PRESENT	0
574546	573329	01028R	PARTICIPANT	\N	PRESENT	0
574547	573329	08061X	PARTICIPANT	\N	PRESENT	0
574548	573329	19515S	PARTICIPANT	\N	PRESENT	0
574549	573329	19503N	PARTICIPANT	\N	PRESENT	0
574550	573329	11026G	PARTICIPANT	\N	PRESENT	0
574551	573329	19545Y	PARTICIPANT	\N	PRESENT	0
574552	573329	20050V	PARTICIPANT	\N	PRESENT	0
574553	573329	11097X	PARTICIPANT	\N	PRESENT	0
574554	573329	04057K	PARTICIPANT	\N	PRESENT	0
574614	573329	19335Q	PARTICIPANT	\N	PRESENT	0
574556	573329	14217N	PARTICIPANT	\N	PRESENT	0
574557	573329	20142Y	PARTICIPANT	\N	PRESENT	0
574558	573329	14259Y	PARTICIPANT	\N	PRESENT	0
574559	573329	19347U	PARTICIPANT	\N	PRESENT	0
574560	573329	14221J	PARTICIPANT	\N	PRESENT	0
574561	573329	19413M	PARTICIPANT	\N	PRESENT	0
574562	573329	19441R	PARTICIPANT	\N	PRESENT	0
574563	573329	19762G	PARTICIPANT	\N	PRESENT	0
574564	573329	20040T	PARTICIPANT	\N	PRESENT	0
574565	573329	04070G	PARTICIPANT	\N	PRESENT	0
574566	573329	19533U	PARTICIPANT	\N	PRESENT	0
574567	573329	14327T	PARTICIPANT	\N	PRESENT	0
574568	573329	14147R	PARTICIPANT	\N	PRESENT	0
574569	573329	01024M	PARTICIPANT	\N	PRESENT	0
574570	573329	14189C	PARTICIPANT	\N	PRESENT	0
574571	573329	14038Y	PARTICIPANT	\N	PRESENT	0
574572	573329	11056N	PARTICIPANT	\N	PRESENT	0
574573	573329	14207L	PARTICIPANT	\N	PRESENT	0
574574	573329	12041X	PARTICIPANT	\N	PRESENT	0
574575	573329	14033T	PARTICIPANT	\N	PRESENT	0
574576	573329	14213J	PARTICIPANT	\N	PRESENT	0
574577	573329	19367Y	PARTICIPANT	\N	PRESENT	0
574578	573329	19663E	PARTICIPANT	\N	PRESENT	0
574579	573329	08056B	PARTICIPANT	\N	PRESENT	0
574580	573329	19369B	PARTICIPANT	\N	PRESENT	0
574581	573329	20124W	PARTICIPANT	\N	PRESENT	0
574582	573329	97011G	PARTICIPANT	\N	PRESENT	0
574583	573329	19701S	PARTICIPANT	\N	PRESENT	0
574584	573329	20114U	PARTICIPANT	\N	PRESENT	0
574585	573329	18193Q	PARTICIPANT	\N	PRESENT	0
574586	573329	08047A	PARTICIPANT	\N	PRESENT	0
574587	573329	04042C	PARTICIPANT	\N	PRESENT	0
574588	573329	20104S	PARTICIPANT	\N	PRESENT	0
574589	573329	11033F	PARTICIPANT	\N	PRESENT	0
574590	573329	19760E	PARTICIPANT	\N	PRESENT	0
574591	573329	14237S	PARTICIPANT	\N	PRESENT	0
574592	573329	19747H	PARTICIPANT	\N	PRESENT	0
574593	573329	19671E	PARTICIPANT	\N	PRESENT	0
574594	573329	20066E	PARTICIPANT	\N	PRESENT	0
574598	573329	04092N	PARTICIPANT	\N	PRESENT	0
574596	573329	11053K	PARTICIPANT	\N	PRESENT	0
574597	573329	19631V	PARTICIPANT	\N	PRESENT	0
574599	573329	16685X	PARTICIPANT	\N	PRESENT	0
574600	573329	20038A	PARTICIPANT	\N	PRESENT	0
574601	573329	11031D	PARTICIPANT	\N	PRESENT	0
574602	573329	11048N	PARTICIPANT	\N	PRESENT	0
574603	573329	01048V	PARTICIPANT	\N	PRESENT	0
574604	573329	14041T	PARTICIPANT	\N	PRESENT	0
574605	573329	04034C	PARTICIPANT	\N	PRESENT	0
574606	573329	20070A	PARTICIPANT	\N	PRESENT	0
574607	573329	20174H	PARTICIPANT	\N	PRESENT	0
574608	573329	11083R	PARTICIPANT	\N	PRESENT	0
574609	573329	20128B	PARTICIPANT	\N	PRESENT	0
574610	573329	14229S	PARTICIPANT	\N	PRESENT	0
574625	573329	20048C	PARTICIPANT	\N	PRESENT	0
574612	573329	19649G	PARTICIPANT	\N	PRESENT	0
574613	573329	17965H	PARTICIPANT	\N	PRESENT	0
574624	573329	14083S	PARTICIPANT	\N	PRESENT	0
574637	573329	11085T	PARTICIPANT	\N	PRESENT	0
574641	573329	04071H	PARTICIPANT	\N	PRESENT	0
574646	573329	14179A	PARTICIPANT	\N	PRESENT	0
574829	573541	19719D	PARTICIPANT	\N	PRESENT	0
574842	574645	20056C	PARTICIPANT	\N	PRESENT	1
574843	574645	20048C	PRESIDENT	0	PRESENT	0
574844	574645	20058E	PARTICIPANT	\N	PRESENT	0
574845	574645	19701S	PARTICIPANT	\N	EXCUSE	0
574846	574645	20052X	PARTICIPANT	\N	PRESENT	0
574878	574645	14179A	PARTICIPANT	\N	PRESENT	1
574879	574645	19651A	PARTICIPANT	\N	PRESENT	1
574880	574378	19399H	PARTICIPANT	\N	EXCUSE	0
574893	573541	14225N	PARTICIPANT	\N	PRESENT	0
574894	573541	11048N	PARTICIPANT	\N	PRESENT	0
574895	573541	11012A	PARTICIPANT	\N	PRESENT	0
574896	573541	11040E	PARTICIPANT	\N	PRESENT	0
574897	573541	19479G	PARTICIPANT	\N	PRESENT	0
574898	573541	20050V	PARTICIPANT	\N	PRESENT	0
574908	573541	19503N	PARTICIPANT	\N	PRESENT	0
574909	573541	19689Q	PARTICIPANT	\N	PRESENT	0
574910	573541	14327T	PARTICIPANT	\N	PRESENT	0
574911	573541	14083S	PARTICIPANT	\N	PRESENT	0
574912	573541	19711U	PARTICIPANT	\N	PRESENT	0
574913	573541	20044X	PARTICIPANT	\N	PRESENT	0
574914	573541	07029T	PARTICIPANT	\N	PRESENT	0
574915	573541	14331P	PARTICIPANT	\N	PRESENT	0
574916	573541	14097Y	PARTICIPANT	\N	PRESENT	0
574917	573541	01057W	PARTICIPANT	\N	PRESENT	0
574918	573541	19758L	PARTICIPANT	\N	PRESENT	0
574919	573541	19335Q	PARTICIPANT	\N	PRESENT	0
574920	573541	19553Y	PARTICIPANT	\N	PRESENT	0
574921	573541	20130U	PARTICIPANT	\N	PRESENT	0
574922	573541	20070A	PARTICIPANT	\N	PRESENT	0
574923	573541	19647E	PARTICIPANT	\N	PRESENT	0
574924	573541	20080C	PARTICIPANT	\N	PRESENT	0
574925	573541	20132W	PARTICIPANT	\N	PRESENT	0
574926	573541	11067R	PARTICIPANT	\N	PRESENT	0
574927	573541	20142Y	PARTICIPANT	\N	PRESENT	0
574928	573541	19687N	PARTICIPANT	\N	PRESENT	0
574929	573541	11074Q	PARTICIPANT	\N	PRESENT	0
574930	573541	14253S	PARTICIPANT	\N	PRESENT	0
574931	573541	19713W	PARTICIPANT	\N	PRESENT	0
574932	573541	11043H	PARTICIPANT	\N	PRESENT	0
574933	573541	04033B	PARTICIPANT	\N	PRESENT	0
574934	573541	20092G	PARTICIPANT	\N	PRESENT	0
574935	573541	14169X	PARTICIPANT	\N	PRESENT	0
574936	573541	19349W	PARTICIPANT	\N	PRESENT	0
574937	573541	20048C	PARTICIPANT	\N	PRESENT	0
574938	573541	19762G	PARTICIPANT	\N	PRESENT	0
574939	573541	19531S	PARTICIPANT	\N	PRESENT	0
574940	573541	14030Q	PARTICIPANT	\N	PRESENT	0
574941	573541	11070L	PARTICIPANT	\N	PRESENT	0
574942	573541	11053K	PARTICIPANT	\N	PRESENT	0
574943	573541	14069U	PARTICIPANT	\N	PRESENT	0
574944	573541	20134Y	PARTICIPANT	\N	PRESENT	0
574945	573541	19347U	PARTICIPANT	\N	PRESENT	0
574946	573541	18083K	PARTICIPANT	\N	PRESENT	0
574947	573541	14179A	PARTICIPANT	\N	PRESENT	0
574948	573541	17367Q	PARTICIPANT	\N	PRESENT	0
574949	573541	14215L	PARTICIPANT	\N	PRESENT	0
590832	590821	19577H	PARTICIPANT	\N	PRESENT	0
590833	590821	11010L	PARTICIPANT	\N	PRESENT	0
590834	590821	19715Y	PARTICIPANT	\N	PRESENT	0
590835	590821	20146D	PARTICIPANT	\N	PRESENT	0
590836	590821	19657G	PARTICIPANT	\N	PRESENT	0
590837	590821	19301E	PARTICIPANT	\N	PRESENT	0
590868	590821	10006L	PARTICIPANT	\N	EXCUSE	0
590869	590821	19447X	PARTICIPANT	\N	EXCUSE	0
590870	590821	19563B	PARTICIPANT	\N	EXCUSE	0
590871	590821	12016W	PARTICIPANT	\N	PRESENT	0
590872	590821	14229S	PARTICIPANT	\N	PRESENT	0
590914	590913	19415P	PARTICIPANT	\N	PRESENT	0
590926	590925	19673G	PARTICIPANT	\N	PRESENT	0
590927	590925	14030Q	PARTICIPANT	\N	PRESENT	0
591070	590977	19643A	PARTICIPANT	\N	PRESENT	0
591071	590977	20044X	PARTICIPANT	\N	PRESENT	0
591257	591256	05008E	PARTICIPANT	\N	PRESENT	0
591258	591256	11053K	PARTICIPANT	\N	PRESENT	0
591259	591256	01028R	PARTICIPANT	\N	PRESENT	0
591785	590829	19647E	PARTICIPANT	\N	PRESENT	1
591786	590829	11012A	PARTICIPANT	\N	PRESENT	1
591787	590829	19479G	PARTICIPANT	\N	PRESENT	1
592828	591132	04059M	PARTICIPANT	\N	PRESENT	0
592829	591132	19651A	PARTICIPANT	\N	PRESENT	0
592830	591132	14030Q	PARTICIPANT	\N	PRESENT	0
592831	591132	19643A	PARTICIPANT	\N	PRESENT	0
592832	591132	20138D	PARTICIPANT	\N	PRESENT	1
592833	591132	19621T	PARTICIPANT	\N	PRESENT	0
592834	591132	19758L	PARTICIPANT	\N	PRESENT	0
592835	591132	19057M	PARTICIPANT	\N	PRESENT	0
592836	591132	20264J	PARTICIPANT	\N	PRESENT	0
592837	591132	17589D	PARTICIPANT	\N	PRESENT	1
592838	591132	20134Y	PARTICIPANT	\N	PRESENT	0
592839	591132	20132W	PARTICIPANT	\N	PRESENT	0
592840	591132	20180F	PARTICIPANT	\N	PRESENT	1
592841	591132	14123H	PARTICIPANT	\N	PRESENT	0
592842	591132	20048C	PARTICIPANT	\N	PRESENT	1
592843	591132	19399H	PARTICIPANT	\N	PRESENT	0
592844	591132	20056C	PARTICIPANT	\N	PRESENT	0
592845	591132	14073Q	PARTICIPANT	\N	PRESENT	0
592846	591132	19611R	PRESIDENT	0	PRESENT	0
592847	591132	19735D	PARTICIPANT	\N	PRESENT	0
592848	591132	19699S	PARTICIPANT	\N	PRESENT	0
592849	591132	20052X	PARTICIPANT	\N	PRESENT	0
592850	591132	08012N	PARTICIPANT	\N	PRESENT	0
592851	591132	11104D	PARTICIPANT	\N	PRESENT	1
592852	591132	20142Y	PARTICIPANT	\N	PRESENT	0
592853	591132	14109K	PARTICIPANT	\N	PRESENT	0
592854	591132	19593H	PARTICIPANT	\N	PRESENT	0
592855	591132	19573D	PARTICIPANT	\N	PRESENT	0
592856	591132	19533U	PARTICIPANT	\N	PRESENT	0
592857	591132	19766L	PARTICIPANT	\N	PRESENT	0
592858	591132	04033B	PARTICIPANT	\N	PRESENT	0
592859	591132	14229S	PARTICIPANT	\N	PRESENT	0
592860	591132	11043H	PARTICIPANT	\N	PRESENT	0
592861	591132	20098N	PARTICIPANT	\N	PRESENT	0
592862	591132	19693L	PARTICIPANT	\N	PRESENT	0
592863	591132	20026V	PARTICIPANT	\N	PRESENT	0
592864	591132	20058E	PARTICIPANT	\N	PRESENT	0
592865	584519	14189C	PARTICIPANT	\N	PRESENT	0
592866	584519	20024T	PARTICIPANT	\N	PRESENT	0
592867	584519	20130U	PARTICIPANT	\N	PRESENT	0
592868	584519	14109K	PARTICIPANT	\N	PRESENT	0
592869	584519	19866P	PARTICIPANT	\N	PRESENT	0
592870	584519	20106U	PARTICIPANT	\N	PRESENT	0
592871	584519	19749K	PARTICIPANT	\N	PRESENT	0
592872	584519	20046A	PARTICIPANT	\N	PRESENT	0
592873	584519	20114U	PARTICIPANT	\N	PRESENT	0
592874	584519	14030Q	PARTICIPANT	\N	PRESENT	0
592875	584519	20066E	PARTICIPANT	\N	PRESENT	1
592876	584519	11031D	PARTICIPANT	\N	PRESENT	1
592877	584519	19621T	PARTICIPANT	\N	EXCUSE	0
592878	584519	19599P	PARTICIPANT	\N	EXCUSE	0
592879	584519	14221J	PARTICIPANT	\N	EXCUSE	0
592880	584519	20056C	PARTICIPANT	\N	PRESENT	1
592882	584519	07029T	PARTICIPANT	\N	PRESENT	0
592883	584519	19693L	PARTICIPANT	\N	PRESENT	0
592884	590855	14089Y	PARTICIPANT	\N	PRESENT	0
592885	590855	20104S	PARTICIPANT	\N	PRESENT	0
592886	590855	19701S	PARTICIPANT	\N	PRESENT	0
592887	590855	12041X	PARTICIPANT	\N	PRESENT	0
592888	590855	04045F	PARTICIPANT	\N	PRESENT	0
592889	590855	14001X	PARTICIPANT	\N	PRESENT	0
592890	590855	04057K	PARTICIPANT	\N	PRESENT	0
592891	590855	19711U	PARTICIPANT	\N	PRESENT	0
592892	590855	11026G	PARTICIPANT	\N	PRESENT	1
592893	590855	14207L	PARTICIPANT	\N	PRESENT	1
592894	590855	14073Q	PARTICIPANT	\N	PRESENT	0
592895	590855	14331P	PRESIDENT	0	PRESENT	0
592896	590855	10015M	PARTICIPANT	\N	PRESENT	0
592897	590855	20094J	PARTICIPANT	\N	PRESENT	0
592900	584519	20118Y	PARTICIPANT	\N	PRESENT	1
593095	590809	05012A	PRESIDENT	0	PRESENT	0
593096	590809	14229S	PARTICIPANT	\N	PRESENT	0
593097	590809	20062A	PARTICIPANT	\N	PRESENT	0
593098	590809	08010L	PARTICIPANT	\N	PRESENT	0
593099	590809	17637T	PARTICIPANT	\N	PRESENT	0
593100	590809	19349W	PARTICIPANT	\N	PRESENT	0
593101	590809	04045F	PARTICIPANT	\N	PRESENT	0
593102	590809	14071N	PARTICIPANT	\N	PRESENT	0
593103	590809	14205J	PARTICIPANT	\N	PRESENT	0
593104	590809	14173T	PARTICIPANT	\N	PRESENT	0
593105	590809	19820Y	PARTICIPANT	\N	PRESENT	0
593108	590809	19565D	PARTICIPANT	\N	PRESENT	0
593109	590809	20090E	PARTICIPANT	\N	PRESENT	0
593110	590809	19333N	PARTICIPANT	\N	PRESENT	0
593111	590809	14053L	PARTICIPANT	\N	PRESENT	0
593112	590809	20022R	PARTICIPANT	\N	EXCUSE	0
593113	590809	14327T	PARTICIPANT	\N	EXCUSE	0
593114	590809	14215L	PARTICIPANT	\N	EXCUSE	0
593115	590809	20084G	PARTICIPANT	\N	EXCUSE	0
593116	590809	20122U	PARTICIPANT	\N	EXCUSE	0
593118	590808	05012A	PRESIDENT	0	PRESENT	0
593119	590808	14229S	PARTICIPANT	\N	PRESENT	0
593120	590808	20062A	PARTICIPANT	\N	PRESENT	0
593121	590808	19349W	PARTICIPANT	\N	PRESENT	0
593122	590808	08010L	PARTICIPANT	\N	PRESENT	0
593123	590808	14205J	PARTICIPANT	\N	PRESENT	0
593124	590808	04045F	PARTICIPANT	\N	PRESENT	0
593125	590808	14071N	PARTICIPANT	\N	PRESENT	0
593126	590808	17637T	PARTICIPANT	\N	PRESENT	0
593127	590808	14173T	PARTICIPANT	\N	PRESENT	0
593128	590808	19565D	PARTICIPANT	\N	PRESENT	0
593129	590808	19820Y	PARTICIPANT	\N	PRESENT	0
593130	590808	20090E	PARTICIPANT	\N	PRESENT	0
593131	590808	19333N	PARTICIPANT	\N	PRESENT	0
593132	590808	14053L	PARTICIPANT	\N	PRESENT	0
593133	590808	20022R	PARTICIPANT	\N	EXCUSE	0
593134	590808	14327T	PARTICIPANT	\N	EXCUSE	0
593135	590808	14215L	PARTICIPANT	\N	EXCUSE	0
593136	590808	20084G	PARTICIPANT	\N	EXCUSE	0
593137	590808	20122U	PARTICIPANT	\N	EXCUSE	0
593173	590860	20116W	PARTICIPANT	\N	PRESENT	0
593176	590860	19695N	PARTICIPANT	\N	PRESENT	0
593177	590860	20092G	PARTICIPANT	\N	PRESENT	0
593178	590860	19369B	PARTICIPANT	\N	PRESENT	0
593180	590860	20142Y	PARTICIPANT	\N	PRESENT	0
593181	590860	20030R	PARTICIPANT	\N	PRESENT	0
593182	590860	20100N	PARTICIPANT	\N	PRESENT	0
593183	590860	19689Q	PARTICIPANT	\N	PRESENT	0
593184	590860	19782L	PARTICIPANT	\N	PRESENT	0
593185	590860	11043H	PARTICIPANT	\N	PRESENT	0
593186	590860	18083K	PARTICIPANT	\N	PRESENT	0
593187	590860	20134Y	PARTICIPANT	\N	PRESENT	0
593188	590860	19347U	PARTICIPANT	\N	PRESENT	0
593189	590860	16685X	PARTICIPANT	\N	PRESENT	0
593190	590860	14257W	PARTICIPANT	\N	PRESENT	0
593191	590860	14038Y	PARTICIPANT	\N	PRESENT	0
593192	590860	11090Q	PARTICIPANT	\N	PRESENT	0
593193	590860	20144B	PARTICIPANT	\N	PRESENT	0
593194	590860	19629C	PARTICIPANT	\N	PRESENT	0
593205	590860	14205J	PARTICIPANT	\N	PRESENT	0
593207	590860	20090E	PARTICIPANT	\N	PRESENT	0
593220	590860	14089Y	PARTICIPANT	\N	PRESENT	0
593221	590860	11065P	PARTICIPANT	\N	PRESENT	0
593222	590860	19533U	PARTICIPANT	\N	PRESENT	0
593223	590860	19349W	PARTICIPANT	\N	PRESENT	0
593224	590860	19667J	PARTICIPANT	\N	PRESENT	0
593225	590860	19747H	PARTICIPANT	\N	PRESENT	0
593226	590860	20036X	PARTICIPANT	\N	PRESENT	0
593227	590860	20104S	PARTICIPANT	\N	PRESENT	0
573922	573921	17779H	PARTICIPANT	\N	PRESENT	0
573932	573931	17779H	PARTICIPANT	\N	PRESENT	0
574334	572778	19683J	PARTICIPANT	\N	PRESENT	1
574335	572778	19415P	PARTICIPANT	\N	PRESENT	0
575867	575865	11067R	PARTICIPANT	\N	EXCUSE	0
575871	575865	20066E	PARTICIPANT	\N	EXCUSE	0
576988	570634	14189C	PARTICIPANT	\N	PRESENT	0
576989	570634	20024T	PARTICIPANT	\N	PRESENT	0
576990	570634	14030Q	PRESIDENT	0	PRESENT	0
576991	570634	20080C	PARTICIPANT	\N	PRESENT	0
576992	570634	11031D	PARTICIPANT	\N	PRESENT	0
576993	570634	19693L	PARTICIPANT	\N	PRESENT	1
576994	570634	20140W	PARTICIPANT	\N	PRESENT	0
576995	570634	19599P	PARTICIPANT	\N	PRESENT	0
576996	570634	20106U	PARTICIPANT	\N	PRESENT	0
576997	570634	14179A	PARTICIPANT	\N	PRESENT	1
576998	570634	20066E	PARTICIPANT	\N	PRESENT	0
576999	570634	20034V	PARTICIPANT	\N	PRESENT	0
577000	570634	20056C	PARTICIPANT	\N	PRESENT	0
577001	570634	19715Y	PARTICIPANT	\N	PRESENT	0
577002	570634	07029T	PARTICIPANT	\N	PRESENT	0
577003	570634	08017T	PARTICIPANT	\N	PRESENT	0
577004	570634	19657G	PARTICIPANT	\N	PRESENT	0
577005	570634	14221J	PARTICIPANT	\N	PRESENT	0
577006	570634	14109K	PARTICIPANT	\N	PRESENT	0
577007	570634	19768N	PARTICIPANT	\N	PRESENT	0
577008	570634	19866P	PARTICIPANT	\N	PRESENT	0
577009	570634	20098N	PARTICIPANT	\N	PRESENT	0
577010	570634	19749K	PARTICIPANT	\N	PRESENT	0
577011	570634	20046A	PARTICIPANT	\N	PRESENT	0
577012	570634	11045K	PARTICIPANT	\N	PRESENT	0
577013	570634	20118Y	PARTICIPANT	\N	EXCUSE	0
577014	570634	20130U	PARTICIPANT	\N	EXCUSE	0
579558	579557	05008E	PARTICIPANT	\N	PRESENT	0
579559	579557	11053K	PARTICIPANT	\N	PRESENT	0
579560	579557	01028R	PARTICIPANT	\N	PRESENT	0
579626	579437	14026U	PARTICIPANT	\N	PRESENT	0
579627	579437	14053L	PARTICIPANT	\N	PRESENT	0
579628	579437	14231L	PARTICIPANT	\N	PRESENT	0
579629	579437	19719D	PARTICIPANT	\N	PRESENT	0
579630	579437	14111D	PARTICIPANT	\N	PRESENT	0
579631	579437	14041T	PARTICIPANT	\N	PRESENT	0
579632	579437	17367Q	PARTICIPANT	\N	PRESENT	0
579633	579437	14147R	PARTICIPANT	\N	PRESENT	0
579634	579437	11056N	PARTICIPANT	\N	PRESENT	0
579635	579437	19798U	PARTICIPANT	\N	PRESENT	0
579636	579437	04047H	PARTICIPANT	\N	PRESENT	0
579637	579437	14219Q	PARTICIPANT	\N	PRESENT	0
579638	579437	11072N	PARTICIPANT	\N	PRESENT	0
579639	579437	20026V	PARTICIPANT	\N	PRESENT	0
579640	579437	20038A	PARTICIPANT	\N	PRESENT	0
579641	579437	14173T	PARTICIPANT	\N	PRESENT	0
579642	579437	19673G	PARTICIPANT	\N	PRESENT	0
579643	579437	11099A	PARTICIPANT	\N	PRESENT	0
579644	579437	19758L	PARTICIPANT	\N	PRESENT	0
579645	579437	20110Q	PARTICIPANT	\N	PRESENT	0
579646	579437	19619A	PARTICIPANT	\N	PRESENT	0
579647	579437	19739H	PARTICIPANT	\N	PRESENT	0
579648	579437	19631V	PARTICIPANT	\N	PRESENT	0
579649	579437	19489J	PARTICIPANT	\N	PRESENT	0
579650	579437	07029T	PARTICIPANT	\N	PRESENT	0
579651	579437	20116W	PARTICIPANT	\N	PRESENT	0
579652	579437	20152B	PARTICIPANT	\N	PRESENT	0
579653	579437	19701S	PARTICIPANT	\N	PRESENT	0
579654	579437	20108W	PARTICIPANT	\N	PRESENT	0
579655	579437	19333N	PARTICIPANT	\N	PRESENT	0
579656	579437	19447X	PARTICIPANT	\N	PRESENT	0
579657	579437	20054A	PARTICIPANT	\N	PRESENT	0
579658	579437	14042U	PARTICIPANT	\N	PRESENT	0
579659	579437	14215L	PARTICIPANT	\N	PRESENT	0
579660	579437	14055N	PARTICIPANT	\N	PRESENT	0
579661	579437	19693L	PARTICIPANT	\N	PRESENT	0
579662	579437	19599P	PARTICIPANT	\N	PRESENT	0
579663	579437	20032T	PARTICIPANT	\N	PRESENT	0
579664	579437	08061X	PARTICIPANT	\N	PRESENT	0
579665	579437	20034V	PARTICIPANT	\N	PRESENT	0
579666	579437	04033B	PARTICIPANT	\N	PRESENT	0
579667	579437	20100N	PARTICIPANT	\N	PRESENT	0
579668	579437	20068G	PARTICIPANT	\N	PRESENT	0
579669	579437	11090Q	PARTICIPANT	\N	PRESENT	0
579670	579437	19347U	PARTICIPANT	\N	PRESENT	0
579671	579437	19621T	PARTICIPANT	\N	PRESENT	0
579672	579437	95063L	PARTICIPANT	\N	PRESENT	0
579673	579437	20044X	PARTICIPANT	\N	PRESENT	0
579674	579437	19565D	PARTICIPANT	\N	PRESENT	0
579675	579437	14038Y	PARTICIPANT	\N	PRESENT	0
579676	579437	20126Y	PARTICIPANT	\N	PRESENT	0
579677	579437	14071N	PARTICIPANT	\N	PRESENT	0
579678	579437	14187A	PARTICIPANT	\N	PRESENT	0
579679	579437	19725B	PARTICIPANT	\N	PRESENT	0
579680	579437	19713W	PARTICIPANT	\N	PRESENT	0
579681	579437	19747H	PARTICIPANT	\N	PRESENT	0
579682	579437	19251M	PARTICIPANT	\N	PRESENT	0
579683	579437	14073Q	PARTICIPANT	\N	PRESENT	0
579684	579437	14151M	PARTICIPANT	\N	PRESENT	0
579685	579437	04042C	PARTICIPANT	\N	PRESENT	0
579686	579437	19749K	PARTICIPANT	\N	PRESENT	0
579687	579437	11043H	PARTICIPANT	\N	PRESENT	0
579688	579437	10015M	PARTICIPANT	\N	PRESENT	0
579689	579437	18193Q	PARTICIPANT	\N	PRESENT	0
579690	579437	19691J	PARTICIPANT	\N	PRESENT	0
579691	579437	19611R	PARTICIPANT	\N	PRESENT	0
579692	579437	20022R	PARTICIPANT	\N	PRESENT	0
579693	579437	08010L	PARTICIPANT	\N	PRESENT	0
579694	579437	20140W	PARTICIPANT	\N	PRESENT	0
579695	579437	08015R	PARTICIPANT	\N	PRESENT	0
579696	579437	20018V	PARTICIPANT	\N	PRESENT	0
579697	579437	20180F	PARTICIPANT	\N	PRESENT	0
579698	579437	20142Y	PARTICIPANT	\N	PRESENT	0
579699	579437	17023S	PARTICIPANT	\N	PRESENT	0
579700	579437	14251Q	PARTICIPANT	\N	PRESENT	0
579701	579437	19479G	PARTICIPANT	\N	PRESENT	0
579702	579437	01057W	PARTICIPANT	\N	PRESENT	0
579703	579437	14193X	PARTICIPANT	\N	PRESENT	0
579704	579437	19782L	PARTICIPANT	\N	PRESENT	0
579705	579437	19563B	PARTICIPANT	\N	PRESENT	0
579706	579437	20098N	PARTICIPANT	\N	PRESENT	0
579707	579437	14259Y	PARTICIPANT	\N	PRESENT	0
579708	579437	11065P	PARTICIPANT	\N	PRESENT	0
579709	579437	20072C	PARTICIPANT	\N	PRESENT	0
579710	579437	04085P	PARTICIPANT	\N	PRESENT	0
579711	579437	14021P	PARTICIPANT	\N	PRESENT	0
579712	579437	07004J	PARTICIPANT	\N	PRESENT	0
579713	579437	01028R	PARTICIPANT	\N	PRESENT	0
583372	583371	17367Q	PARTICIPANT	\N	PRESENT	1
583373	583371	11083R	PARTICIPANT	\N	PRESENT	0
583374	583371	20180F	PARTICIPANT	\N	PRESENT	1
583375	583371	20082E	PARTICIPANT	\N	PRESENT	1
583509	583508	19553Y	PARTICIPANT	\N	PRESENT	0
583678	583461	20110Q	PARTICIPANT	\N	PRESENT	1
585718	585717	20066E	PARTICIPANT	\N	PRESENT	0
585721	585719	20066E	PARTICIPANT	\N	PRESENT	0
585722	585720	20066E	PARTICIPANT	\N	PRESENT	0
589459	589457	19447X	PARTICIPANT	\N	PRESENT	0
589460	589457	14275Y	PARTICIPANT	\N	PRESENT	0
596733	595603	11065P	PARTICIPANT	\N	PRESENT	0
596734	595603	01058X	PARTICIPANT	\N	PRESENT	0
596735	595603	20142Y	PARTICIPANT	\N	PRESENT	0
596736	595603	01028R	PARTICIPANT	\N	PRESENT	0
596737	595603	04059M	PARTICIPANT	\N	PRESENT	0
596738	595603	11027H	PARTICIPANT	\N	PRESENT	0
596739	595603	14021P	PARTICIPANT	\N	PRESENT	0
596740	595603	19333N	PARTICIPANT	\N	PRESENT	0
596741	595603	04042C	PARTICIPANT	\N	PRESENT	0
596742	595603	11067R	PARTICIPANT	\N	PRESENT	0
596743	595603	18083K	PARTICIPANT	\N	PRESENT	0
596744	595603	19549D	PARTICIPANT	\N	PRESENT	0
596745	595603	19669L	PARTICIPANT	\N	PRESENT	0
596746	595603	20078J	PARTICIPANT	\N	PRESENT	0
596747	595603	20074E	PARTICIPANT	\N	PRESENT	0
596748	595603	08012N	PARTICIPANT	\N	PRESENT	0
596749	595603	20070A	PARTICIPANT	\N	PRESENT	0
596750	595603	20060X	PARTICIPANT	\N	PRESENT	0
596751	595603	20076G	PARTICIPANT	\N	PRESENT	0
596752	595603	19413M	PARTICIPANT	\N	PRESENT	0
596753	595603	20264J	PARTICIPANT	\N	PRESENT	0
596754	595603	14121F	PARTICIPANT	\N	PRESENT	0
596755	595603	18193Q	PARTICIPANT	\N	PRESENT	0
592136	592128	14179A	PARTICIPANT	\N	PRESENT	0
592137	592128	19735D	PARTICIPANT	\N	PRESENT	0
592138	592128	19441R	PARTICIPANT	\N	PRESENT	0
592139	592128	20142Y	PARTICIPANT	\N	PRESENT	0
592140	592128	05012A	PARTICIPANT	\N	PRESENT	0
592141	592128	19766L	PARTICIPANT	\N	PRESENT	0
592142	592128	20150Y	PARTICIPANT	\N	PRESENT	0
592143	592128	20098N	PARTICIPANT	\N	PRESENT	0
592144	592128	20064C	PARTICIPANT	\N	PRESENT	0
592145	592128	20248J	PARTICIPANT	\N	PRESENT	0
592146	590850	11043H	PARTICIPANT	\N	PRESENT	0
592147	590850	14089Y	PARTICIPANT	\N	PRESENT	0
592406	590851	11045K	PARTICIPANT	\N	PRESENT	0
592149	590850	17737W	PARTICIPANT	\N	PRESENT	0
592151	592150	01048V	PARTICIPANT	\N	PRESENT	0
592407	590851	19683J	PARTICIPANT	\N	PRESENT	0
592408	590851	10006L	PARTICIPANT	\N	PRESENT	0
592409	590851	19593H	PARTICIPANT	\N	PRESENT	0
592410	590851	20046A	PARTICIPANT	\N	PRESENT	0
592411	590851	11077T	PARTICIPANT	\N	PRESENT	0
592412	590851	20070A	PARTICIPANT	\N	PRESENT	0
592413	590851	20018V	PARTICIPANT	\N	PRESENT	0
592414	590851	19599P	PARTICIPANT	\N	PRESENT	0
592415	590851	20114U	PARTICIPANT	\N	PRESENT	0
592416	590851	11067R	PARTICIPANT	\N	PRESENT	0
592417	590851	14121F	PARTICIPANT	\N	PRESENT	0
592418	590851	08060W	PARTICIPANT	\N	PRESENT	0
592419	590851	19649G	PARTICIPANT	\N	PRESENT	0
592420	590851	20146D	PARTICIPANT	\N	PRESENT	0
592421	590851	19697Q	PARTICIPANT	\N	PRESENT	0
592422	590851	11033F	PARTICIPANT	\N	PRESENT	0
592423	590851	20130U	PARTICIPANT	\N	PRESENT	0
592424	590851	14195A	PARTICIPANT	\N	PRESENT	0
592425	590851	04059M	PARTICIPANT	\N	PRESENT	0
592426	590851	19553Y	PARTICIPANT	\N	PRESENT	0
592427	590851	19866P	PARTICIPANT	\N	PRESENT	0
592428	590851	14097Y	PARTICIPANT	\N	PRESENT	0
592429	590851	19725B	PARTICIPANT	\N	PRESENT	0
592430	590851	14281W	PARTICIPANT	\N	PRESENT	0
592431	590851	19820Y	PARTICIPANT	\N	PRESENT	0
592432	590851	18193Q	PARTICIPANT	\N	PRESENT	0
592433	590851	19713W	PARTICIPANT	\N	PRESENT	0
592434	590851	14205J	PARTICIPANT	\N	PRESENT	0
592435	590851	19443T	PARTICIPANT	\N	PRESENT	0
592436	590851	20082E	PARTICIPANT	\N	PRESENT	0
592437	590851	12016W	PARTICIPANT	\N	PRESENT	0
592438	590851	19333N	PARTICIPANT	\N	PRESENT	0
592439	590851	17779H	PARTICIPANT	\N	PRESENT	0
592440	590851	20080C	PARTICIPANT	\N	PRESENT	0
592441	590851	19503N	PARTICIPANT	\N	PRESENT	0
592442	590851	12028B	PARTICIPANT	\N	PRESENT	0
592443	590851	19527W	PARTICIPANT	\N	PRESENT	0
592444	590851	14257W	PARTICIPANT	\N	PRESENT	0
592445	590851	01028R	PARTICIPANT	\N	PRESENT	0
592446	590851	19569H	PARTICIPANT	\N	PRESENT	0
592447	590851	20028X	PARTICIPANT	\N	PRESENT	0
592448	590851	19629C	PARTICIPANT	\N	PRESENT	0
592449	590851	14207L	PARTICIPANT	\N	PRESENT	0
592450	590851	11026G	PARTICIPANT	\N	PRESENT	0
592451	590851	14083S	PARTICIPANT	\N	PRESENT	0
592452	590851	95063L	PARTICIPANT	\N	PRESENT	0
592453	590851	14275Y	PARTICIPANT	\N	PRESENT	0
592454	590851	14189C	PARTICIPANT	\N	PRESENT	0
592455	590851	20030R	PARTICIPANT	\N	PRESENT	0
592456	590851	14229S	PARTICIPANT	\N	PRESENT	0
592457	590851	11097X	PARTICIPANT	\N	PRESENT	0
592458	590851	04092N	PARTICIPANT	\N	PRESENT	0
592459	590851	19533U	PARTICIPANT	\N	PRESENT	0
592460	590851	97011G	PARTICIPANT	\N	PRESENT	0
592461	590851	20062A	PARTICIPANT	\N	PRESENT	0
592462	590851	20090E	PARTICIPANT	\N	PRESENT	0
592463	590851	19768N	PARTICIPANT	\N	PRESENT	0
592464	590851	20068G	PARTICIPANT	\N	PRESENT	0
592465	590851	20026V	PARTICIPANT	\N	PRESENT	0
592466	590851	18083K	PARTICIPANT	\N	PRESENT	0
592467	590851	19467C	PARTICIPANT	\N	PRESENT	0
592468	590851	14191V	PARTICIPANT	\N	PRESENT	0
592469	590851	01058X	PARTICIPANT	\N	PRESENT	0
592470	590851	08069G	PARTICIPANT	\N	PRESENT	0
592471	590851	19723Y	PARTICIPANT	\N	PRESENT	0
592472	590851	20096L	PARTICIPANT	\N	PRESENT	0
592473	590851	19551W	PARTICIPANT	\N	PRESENT	0
592474	590851	19549D	PARTICIPANT	\N	PRESENT	0
592475	590851	04085P	PARTICIPANT	\N	PRESENT	0
592476	590851	11031D	PARTICIPANT	\N	PRESENT	0
592477	590851	14030Q	PARTICIPANT	\N	PRESENT	0
592478	590851	20248J	PARTICIPANT	\N	PRESENT	0
592479	590851	19663E	PARTICIPANT	\N	PRESENT	0
592480	590851	14217N	PARTICIPANT	\N	PRESENT	0
592481	590851	19798U	PARTICIPANT	\N	PRESENT	0
592482	590851	14021P	PARTICIPANT	\N	PRESENT	0
592483	590851	20120S	PARTICIPANT	\N	PRESENT	0
592484	590851	11066Q	PARTICIPANT	\N	PRESENT	0
592485	590851	20172F	PARTICIPANT	\N	PRESENT	0
592486	590851	14151M	PARTICIPANT	\N	PRESENT	0
592487	590851	19563B	PARTICIPANT	\N	PRESENT	0
592488	590851	19387D	PARTICIPANT	\N	PRESENT	0
592489	590851	14089Y	PARTICIPANT	\N	PRESENT	0
592490	590851	11012A	PARTICIPANT	\N	PRESENT	0
592491	590851	14213J	PARTICIPANT	\N	PRESENT	0
592492	590851	14055N	PARTICIPANT	\N	PRESENT	0
592493	590851	19591F	PARTICIPANT	\N	PRESENT	0
592494	590851	20038A	PARTICIPANT	\N	PRESENT	0
592495	590851	20118Y	PARTICIPANT	\N	PRESENT	0
592496	590851	20054A	PARTICIPANT	\N	PRESENT	0
592497	590851	20098N	PARTICIPANT	\N	PRESENT	0
592498	590851	19349W	PARTICIPANT	\N	PRESENT	0
592499	590851	17965H	PARTICIPANT	\N	PRESENT	0
592500	590851	19673G	PARTICIPANT	\N	PRESENT	0
592501	590851	14179A	PARTICIPANT	\N	PRESENT	0
592502	590851	14059S	PARTICIPANT	\N	PRESENT	0
592503	590851	14001X	PARTICIPANT	\N	PRESENT	0
592504	590851	19719D	PARTICIPANT	\N	PRESENT	0
592505	590851	20108W	PARTICIPANT	\N	PRESENT	0
592506	590851	20102Q	PARTICIPANT	\N	PRESENT	0
592507	590851	20116W	PARTICIPANT	\N	PRESENT	0
592508	590851	10015M	PARTICIPANT	\N	PRESENT	0
592509	590851	04045F	PARTICIPANT	\N	PRESENT	0
592510	590851	20100N	PARTICIPANT	\N	PRESENT	0
592511	590851	19691J	PARTICIPANT	\N	PRESENT	0
592512	590851	19703U	PARTICIPANT	\N	PRESENT	0
592513	590851	19383Y	PARTICIPANT	\N	PRESENT	0
592514	590851	19447X	PARTICIPANT	\N	PRESENT	0
592515	590851	20052X	PARTICIPANT	\N	PRESENT	0
592516	590851	20024T	PARTICIPANT	\N	PRESENT	0
592518	590851	20092G	PARTICIPANT	\N	PRESENT	0
592519	590851	19758L	PARTICIPANT	\N	PRESENT	0
592520	590851	19699S	PARTICIPANT	\N	PRESENT	0
592521	590851	19415P	PARTICIPANT	\N	PRESENT	0
592522	590851	14329V	PARTICIPANT	\N	PRESENT	0
592523	590490	19549D	PARTICIPANT	\N	PRESENT	0
592524	590490	19503N	PARTICIPANT	\N	PRESENT	0
592525	590490	20020P	PARTICIPANT	\N	PRESENT	0
592526	590490	20046A	PARTICIPANT	\N	PRESENT	0
592527	590490	20102Q	PARTICIPANT	\N	PRESENT	0
592528	590490	19599P	PARTICIPANT	\N	PRESENT	0
592529	590490	19637C	PARTICIPANT	\N	PRESENT	0
592530	590490	11065P	PARTICIPANT	\N	PRESENT	0
592531	590490	20106U	PARTICIPANT	\N	PRESENT	1
592532	590490	18083K	PARTICIPANT	\N	PRESENT	0
592533	590851	20042V	PARTICIPANT	\N	PRESENT	0
592534	590490	14219Q	PRESIDENT	0	PRESENT	0
592535	590490	19251M	PARTICIPANT	\N	PRESENT	1
592536	590490	14031R	PARTICIPANT	\N	PRESENT	0
592537	590851	07029T	PARTICIPANT	\N	PRESENT	0
592538	590490	19387D	PARTICIPANT	\N	PRESENT	1
592539	590851	14147R	PARTICIPANT	\N	PRESENT	0
592540	590851	20060X	PARTICIPANT	\N	PRESENT	0
592541	590851	14071N	PARTICIPANT	\N	PRESENT	0
592542	590851	20110Q	PARTICIPANT	\N	PRESENT	0
592543	590851	14033T	PARTICIPANT	\N	PRESENT	0
592544	590851	11072N	PARTICIPANT	\N	PRESENT	0
592545	590851	07004J	PARTICIPANT	\N	PRESENT	0
592546	590851	11056N	PARTICIPANT	\N	PRESENT	0
592547	590490	20100N	PARTICIPANT	\N	PRESENT	0
592548	590490	20024T	PARTICIPANT	\N	PRESENT	0
592549	590851	14073Q	PARTICIPANT	\N	PRESENT	0
592550	590851	14053L	PARTICIPANT	\N	PRESENT	0
592551	590851	20104S	PARTICIPANT	\N	PRESENT	0
592552	590851	19717B	PARTICIPANT	\N	PRESENT	0
592553	590490	19701S	PARTICIPANT	\N	PRESENT	1
574952	573541	20058E	PARTICIPANT	\N	PRESENT	0
574953	573541	20126Y	PARTICIPANT	\N	PRESENT	0
574954	573541	14021P	PARTICIPANT	\N	PRESENT	0
574955	573541	20034V	PARTICIPANT	\N	PRESENT	0
574956	573541	17023S	PARTICIPANT	\N	PRESENT	0
574957	573541	14237S	PARTICIPANT	\N	PRESENT	0
574958	573541	14073Q	PARTICIPANT	\N	PRESENT	0
574959	573541	14041T	PARTICIPANT	\N	PRESENT	0
575511	575103	04047H	PRESIDENT	0	PRESENT	0
575512	575103	11026G	PARTICIPANT	\N	PRESENT	0
575518	575103	05008E	PARTICIPANT	\N	PRESENT	0
575522	575103	11072N	PARTICIPANT	\N	PRESENT	0
575523	575103	14089Y	PARTICIPANT	\N	PRESENT	0
575524	575103	19489J	PARTICIPANT	\N	PRESENT	0
575525	575103	95063L	PARTICIPANT	\N	PRESENT	0
575526	575103	20108W	PARTICIPANT	\N	PRESENT	0
575530	575103	14179A	PARTICIPANT	\N	PRESENT	0
575547	575255	11070L	PARTICIPANT	\N	PRESENT	0
575548	575255	19681G	PARTICIPANT	\N	PRESENT	0
575549	575255	04085P	PARTICIPANT	\N	PRESENT	0
575550	575255	19826F	PARTICIPANT	\N	PRESENT	0
575551	575255	19760E	PARTICIPANT	\N	PRESENT	0
575552	575255	20044X	PARTICIPANT	\N	PRESENT	0
575554	575255	11072N	PARTICIPANT	\N	PRESENT	0
575555	575255	14089Y	PARTICIPANT	\N	PRESENT	0
575556	575255	99004R	PARTICIPANT	\N	PRESENT	0
575557	575255	19691J	PARTICIPANT	\N	PRESENT	0
575558	575255	14111D	PARTICIPANT	\N	PRESENT	0
575559	575255	19489J	PARTICIPANT	\N	PRESENT	0
575560	575255	19447X	PARTICIPANT	\N	PRESENT	0
575561	575255	20054A	PARTICIPANT	\N	PRESENT	0
575562	575255	20110Q	PARTICIPANT	\N	PRESENT	0
575563	575255	04047H	PARTICIPANT	\N	PRESENT	0
575564	575255	17965H	PARTICIPANT	\N	PRESENT	0
575565	575255	05008E	PARTICIPANT	\N	PRESENT	0
575566	575255	14219Q	PARTICIPANT	\N	PRESENT	0
575567	575255	14189C	PARTICIPANT	\N	PRESENT	0
575568	575255	11085T	PARTICIPANT	\N	PRESENT	0
575569	575255	14231L	PARTICIPANT	\N	PRESENT	0
575570	575255	14021P	PARTICIPANT	\N	PRESENT	0
575571	575255	19569H	PARTICIPANT	\N	PRESENT	0
575580	575255	11097X	PARTICIPANT	\N	PRESENT	0
575581	575255	20108W	PARTICIPANT	\N	PRESENT	0
575583	575255	14026U	PARTICIPANT	\N	PRESENT	0
575584	575255	19577H	PARTICIPANT	\N	PRESENT	0
575585	575255	19349W	PARTICIPANT	\N	PRESENT	0
575586	575255	11026G	PARTICIPANT	\N	PRESENT	0
575587	575255	19683J	PARTICIPANT	\N	PRESENT	0
575588	575255	20116W	PARTICIPANT	\N	PRESENT	0
575589	575255	17023S	PARTICIPANT	\N	PRESENT	0
575590	575255	11083R	PARTICIPANT	\N	PRESENT	0
575591	575255	19697Q	PARTICIPANT	\N	PRESENT	0
575592	575255	14179A	PARTICIPANT	\N	PRESENT	0
575593	575255	19717B	PARTICIPANT	\N	PRESENT	0
575596	575255	04043D	PARTICIPANT	\N	PRESENT	0
575597	575255	19599P	PARTICIPANT	\N	PRESENT	0
575598	575255	14215L	PARTICIPANT	\N	PRESENT	0
575599	575255	18193Q	PARTICIPANT	\N	PRESENT	0
575600	575255	14071N	PARTICIPANT	\N	PRESENT	0
575601	575255	20124W	PARTICIPANT	\N	PRESENT	0
575602	575255	17637T	PARTICIPANT	\N	PRESENT	0
575603	575104	20074E	PARTICIPANT	\N	PRESENT	0
575604	575104	19489J	PARTICIPANT	\N	PRESENT	0
575605	575104	14111D	PARTICIPANT	\N	PRESENT	0
575606	575104	14215L	PRESIDENT	0	PRESENT	0
575607	575104	04047H	PARTICIPANT	\N	PRESENT	0
575608	575104	05008E	PARTICIPANT	\N	PRESENT	0
575610	575255	20034V	PARTICIPANT	\N	PRESENT	0
575617	575255	11064N	PARTICIPANT	\N	PRESENT	0
575618	575255	20130U	PARTICIPANT	\N	PRESENT	0
575619	575255	20048C	PARTICIPANT	\N	PRESENT	0
575620	575255	17779H	PARTICIPANT	\N	PRESENT	0
575662	575263	19599P	PARTICIPANT	\N	PRESENT	0
575663	575263	20116W	PARTICIPANT	\N	PRESENT	0
575664	575263	11064N	PARTICIPANT	\N	PRESENT	0
575665	575263	14071N	PARTICIPANT	\N	PRESENT	0
575666	575263	19760E	PARTICIPANT	\N	PRESENT	0
575667	575263	19826F	PARTICIPANT	\N	PRESENT	0
575668	575263	20048C	PARTICIPANT	\N	PRESENT	0
575669	575263	17023S	PARTICIPANT	\N	PRESENT	0
575670	575263	14089Y	PARTICIPANT	\N	PRESENT	0
575671	575263	19691J	PARTICIPANT	\N	PRESENT	0
575672	575263	11067R	PARTICIPANT	\N	PRESENT	0
575673	575263	05008E	PARTICIPANT	\N	PRESENT	0
575674	575263	20124W	PARTICIPANT	\N	PRESENT	0
575675	575263	04043D	PARTICIPANT	\N	PRESENT	0
575676	575263	17779H	PARTICIPANT	\N	PRESENT	0
575677	575263	20108W	PARTICIPANT	\N	PRESENT	0
575678	575263	17965H	PARTICIPANT	\N	PRESENT	0
575679	575263	20130U	PARTICIPANT	\N	PRESENT	0
575680	575263	19697Q	PARTICIPANT	\N	PRESENT	0
575681	575263	14215L	PARTICIPANT	\N	PRESENT	0
575682	575263	11097X	PARTICIPANT	\N	PRESENT	0
575683	575263	19569H	PARTICIPANT	\N	PRESENT	0
575684	575263	04085P	PARTICIPANT	\N	PRESENT	0
575685	575263	20054A	PARTICIPANT	\N	PRESENT	0
575686	575263	20034V	PARTICIPANT	\N	PRESENT	0
575687	575263	14026U	PARTICIPANT	\N	PRESENT	0
575688	575263	19717B	PARTICIPANT	\N	PRESENT	0
575689	575263	19681G	PARTICIPANT	\N	PRESENT	0
575690	575263	11031D	PARTICIPANT	\N	PRESENT	0
575691	575263	19663E	PARTICIPANT	\N	PRESENT	0
575692	575263	19657G	PARTICIPANT	\N	PRESENT	0
575693	575263	19349W	PARTICIPANT	\N	PRESENT	0
575694	575263	14042U	PARTICIPANT	\N	PRESENT	0
575695	575263	10006L	PARTICIPANT	\N	PRESENT	0
575696	575263	19723Y	PARTICIPANT	\N	PRESENT	0
575724	575265	19717B	PARTICIPANT	\N	PRESENT	0
575725	575265	11031D	PARTICIPANT	\N	PRESENT	0
575726	575265	19760E	PARTICIPANT	\N	PRESENT	0
575727	575265	20130U	PARTICIPANT	\N	PRESENT	0
575660	575263	11070L	PARTICIPANT	\N	PRESENT	0
575661	575263	18193Q	PARTICIPANT	\N	PRESENT	0
575728	575265	17965H	PARTICIPANT	\N	PRESENT	0
575729	575265	14071N	PARTICIPANT	\N	PRESENT	0
575730	575265	20034V	PARTICIPANT	\N	PRESENT	0
575731	575265	14042U	PARTICIPANT	\N	PRESENT	0
575732	575265	11064N	PARTICIPANT	\N	PRESENT	0
575733	575265	11067R	PARTICIPANT	\N	PRESENT	0
575734	575265	19663E	PARTICIPANT	\N	PRESENT	0
575735	575265	10006L	PARTICIPANT	\N	PRESENT	0
575736	575265	19697Q	PARTICIPANT	\N	PRESENT	0
575737	575265	18193Q	PARTICIPANT	\N	PRESENT	0
575738	575265	14215L	PARTICIPANT	\N	PRESENT	0
575739	575265	19723Y	PARTICIPANT	\N	PRESENT	0
574950	573541	16685X	PARTICIPANT	\N	PRESENT	0
574951	573541	14109K	PARTICIPANT	\N	PRESENT	0
575740	575265	20124W	PARTICIPANT	\N	PRESENT	0
575741	575265	17779H	PARTICIPANT	\N	PRESENT	0
575742	575265	20116W	PARTICIPANT	\N	PRESENT	0
575743	575265	11097X	PARTICIPANT	\N	PRESENT	0
575744	575265	19657G	PARTICIPANT	\N	PRESENT	0
575745	575265	20114U	PARTICIPANT	\N	PRESENT	0
575746	575265	19681G	PARTICIPANT	\N	PRESENT	0
575747	575265	20110Q	PARTICIPANT	\N	PRESENT	0
575748	575265	20054A	PARTICIPANT	\N	PRESENT	0
575722	575265	01043Q	PARTICIPANT	\N	PRESENT	0
575723	575265	14026U	PARTICIPANT	\N	PRESENT	0
575749	575265	19569H	PARTICIPANT	\N	PRESENT	0
575750	575265	19693L	PARTICIPANT	\N	PRESENT	0
575764	575763	14229S	PARTICIPANT	\N	PRESENT	1
575775	574852	20130U	PARTICIPANT	\N	PRESENT	1
575776	574852	17779H	PARTICIPANT	\N	PRESENT	0
575777	574852	10006L	PRESIDENT	0	PRESENT	0
575778	574852	01034P	PARTICIPANT	\N	PRESENT	1
575779	574852	11097X	PARTICIPANT	\N	PRESENT	0
575780	574852	04092N	PARTICIPANT	\N	PRESENT	0
575781	574852	14071N	PARTICIPANT	\N	PRESENT	0
575782	574852	14213J	PARTICIPANT	\N	PRESENT	0
575783	574852	19798U	PARTICIPANT	\N	PRESENT	0
575786	574852	14195A	PARTICIPANT	\N	PRESENT	0
575787	574852	19415P	PARTICIPANT	\N	PRESENT	0
575788	574852	14217N	PARTICIPANT	\N	PRESENT	0
575789	574852	14223L	PARTICIPANT	\N	PRESENT	0
575790	574852	19569H	PARTICIPANT	\N	PRESENT	0
575791	574852	14042U	PARTICIPANT	\N	PRESENT	0
575793	574852	19697Q	PARTICIPANT	\N	PRESENT	1
576880	576879	20074E	PARTICIPANT	\N	PRESENT	0
576883	576879	14179A	PARTICIPANT	\N	PRESENT	0
576884	576879	14021P	PARTICIPANT	\N	PRESENT	0
576886	576885	20074E	PARTICIPANT	\N	PRESENT	0
593228	590860	20034V	PARTICIPANT	\N	PRESENT	0
593229	590860	14053L	PARTICIPANT	\N	PRESENT	0
593230	590860	19693L	PARTICIPANT	\N	PRESENT	0
593231	590860	01048V	PARTICIPANT	\N	PRESENT	0
593232	590860	19399H	PARTICIPANT	\N	PRESENT	0
593233	590860	07029T	PARTICIPANT	\N	PRESENT	0
593234	590860	19479G	PARTICIPANT	\N	PRESENT	0
593235	590860	11012A	PARTICIPANT	\N	PRESENT	0
593236	590860	20130U	PARTICIPANT	\N	PRESENT	0
593237	590860	11067R	PARTICIPANT	\N	PRESENT	0
593238	590860	19683J	PARTICIPANT	\N	PRESENT	0
593281	590861	19747H	PARTICIPANT	\N	PRESENT	0
593282	590861	19369B	PARTICIPANT	\N	PRESENT	0
593283	590861	19399H	PARTICIPANT	\N	PRESENT	0
593284	590861	08018U	PARTICIPANT	\N	PRESENT	0
593285	590861	19629C	PARTICIPANT	\N	PRESENT	0
593286	590861	11012A	PARTICIPANT	\N	PRESENT	0
593288	590861	14053L	PARTICIPANT	\N	PRESENT	0
593289	590861	20110Q	PARTICIPANT	\N	PRESENT	0
593290	590861	04085P	PARTICIPANT	\N	PRESENT	0
593292	590861	07004J	PARTICIPANT	\N	PRESENT	0
593294	590861	19717B	PARTICIPANT	\N	PRESENT	0
593295	590861	01028R	PARTICIPANT	\N	PRESENT	0
593296	590861	19782L	PARTICIPANT	\N	PRESENT	0
593298	590861	19387D	PARTICIPANT	\N	PRESENT	0
593299	590861	20034V	PARTICIPANT	\N	PRESENT	0
593300	590861	14038Y	PARTICIPANT	\N	PRESENT	0
593301	590861	19866P	PARTICIPANT	\N	PRESENT	0
593302	590861	19349W	PARTICIPANT	\N	PRESENT	0
593303	590861	20116W	PARTICIPANT	\N	PRESENT	0
593304	590861	20266L	PARTICIPANT	\N	PRESENT	0
593305	590861	20030R	PARTICIPANT	\N	PRESENT	0
593306	590861	19593H	PARTICIPANT	\N	PRESENT	0
593307	590861	19467C	PARTICIPANT	\N	PRESENT	0
593308	590861	11010L	PARTICIPANT	\N	PRESENT	0
593309	590861	19563B	PARTICIPANT	\N	PRESENT	0
593310	590861	19503N	PARTICIPANT	\N	PRESENT	0
593311	590861	19687N	PARTICIPANT	\N	PRESENT	0
593316	590861	07029T	PARTICIPANT	\N	PRESENT	0
593317	590861	11115U	PARTICIPANT	\N	PRESENT	0
593318	590861	11064N	PARTICIPANT	\N	PRESENT	0
593319	590861	11065P	PARTICIPANT	\N	PRESENT	0
593320	590861	19347U	PARTICIPANT	\N	PRESENT	0
593324	590861	14121F	PARTICIPANT	\N	PRESENT	0
593326	590861	14205J	PARTICIPANT	\N	PRESENT	0
593328	590861	19667J	PARTICIPANT	\N	PRESENT	0
593336	590861	20036X	PARTICIPANT	\N	PRESENT	0
593337	590861	14123H	PARTICIPANT	\N	PRESENT	0
593338	590861	11070L	PARTICIPANT	\N	PRESENT	0
593369	590862	19349W	PARTICIPANT	\N	PRESENT	0
593370	590862	14207L	PARTICIPANT	\N	PRESENT	0
593279	590861	08073C	PARTICIPANT	\N	PRESENT	0
593280	590861	14207L	PARTICIPANT	\N	PRESENT	0
593371	590862	20116W	PARTICIPANT	\N	PRESENT	0
593372	590862	19717B	PARTICIPANT	\N	PRESENT	0
593373	590862	19563B	PARTICIPANT	\N	PRESENT	0
593374	590862	11064N	PARTICIPANT	\N	PRESENT	0
593375	590862	19369B	PARTICIPANT	\N	PRESENT	0
593376	590862	14205J	PARTICIPANT	\N	PRESENT	0
593377	590862	14123H	PARTICIPANT	\N	PRESENT	0
593378	590862	01048V	PARTICIPANT	\N	PRESENT	0
593379	590862	19667J	PARTICIPANT	\N	PRESENT	0
593380	590862	07029T	PARTICIPANT	\N	PRESENT	0
593381	590862	19782L	PARTICIPANT	\N	PRESENT	0
593382	590862	19687N	PARTICIPANT	\N	PRESENT	0
593383	590862	14121F	PARTICIPANT	\N	PRESENT	0
593384	590862	01028R	PARTICIPANT	\N	PRESENT	0
593385	590862	20036X	PARTICIPANT	\N	PRESENT	0
593386	590862	11012A	PARTICIPANT	\N	PRESENT	0
593387	590862	19711U	PARTICIPANT	\N	PRESENT	0
593388	590862	20022R	PARTICIPANT	\N	PRESENT	0
593389	590862	19866P	PARTICIPANT	\N	PRESENT	0
593390	590862	20042V	PARTICIPANT	\N	PRESENT	0
593391	590862	20034V	PARTICIPANT	\N	PRESENT	0
593392	590862	04085P	PARTICIPANT	\N	PRESENT	0
593393	590862	19387D	PARTICIPANT	\N	PRESENT	0
593365	590862	08073C	PARTICIPANT	\N	PRESENT	0
593368	590862	11070L	PARTICIPANT	\N	PRESENT	0
593401	590975	11040E	PARTICIPANT	\N	PRESENT	0
593402	590975	19479G	PARTICIPANT	\N	PRESENT	0
593421	590863	01028R	PARTICIPANT	\N	PRESENT	0
593422	590863	11012A	PARTICIPANT	\N	PRESENT	0
593423	590863	19866P	PARTICIPANT	\N	PRESENT	0
593424	590863	04085P	PARTICIPANT	\N	PRESENT	0
593425	590863	19369B	PARTICIPANT	\N	PRESENT	0
593426	590863	14205J	PARTICIPANT	\N	PRESENT	0
593427	590863	14207L	PARTICIPANT	\N	PRESENT	0
593428	590863	14257W	PARTICIPANT	\N	PRESENT	0
593429	590863	07029T	PARTICIPANT	\N	PRESENT	0
593430	590863	19782L	PARTICIPANT	\N	PRESENT	0
593431	590863	19563B	PARTICIPANT	\N	PRESENT	0
593471	593470	19549D	PARTICIPANT	\N	PRESENT	0
593433	590863	11099A	PARTICIPANT	\N	PRESENT	0
593434	590863	19695N	PARTICIPANT	\N	PRESENT	0
593435	590863	20034V	PARTICIPANT	\N	PRESENT	0
593472	593470	19503N	PARTICIPANT	\N	PRESENT	0
593419	590863	08073C	PARTICIPANT	\N	PRESENT	0
593420	590863	14121F	PARTICIPANT	\N	PRESENT	0
593473	593470	19637C	PARTICIPANT	\N	PRESENT	0
593474	593470	14219Q	PARTICIPANT	\N	PRESENT	0
593475	593470	11065P	PARTICIPANT	\N	PRESENT	0
593476	593470	18083K	PARTICIPANT	\N	PRESENT	0
593477	593470	19251M	PARTICIPANT	\N	PRESENT	0
593478	593436	19347U	PARTICIPANT	\N	EXCUSE	0
593480	593479	11083R	PARTICIPANT	\N	PRESENT	0
593482	593481	11083R	PARTICIPANT	\N	PRESENT	0
593484	593483	86034E	PARTICIPANT	\N	PRESENT	0
593485	593483	04085P	PARTICIPANT	\N	PRESENT	0
593486	593483	04047H	PARTICIPANT	\N	PRESENT	0
593487	593483	04042C	PARTICIPANT	\N	PRESENT	0
593488	593483	11070L	PARTICIPANT	\N	PRESENT	0
593489	593483	19719D	PARTICIPANT	\N	PRESENT	0
593490	593483	14042U	PARTICIPANT	\N	PRESENT	0
593491	593483	14187A	PARTICIPANT	\N	PRESENT	0
593492	593483	19347U	PARTICIPANT	\N	PRESENT	0
593493	593483	14026U	PARTICIPANT	\N	PRESENT	0
593494	593483	11048N	PARTICIPANT	\N	PRESENT	0
593495	593483	14021P	PARTICIPANT	\N	PRESENT	0
593496	593483	99004R	PARTICIPANT	\N	PRESENT	0
593497	593483	19611R	PARTICIPANT	\N	PRESENT	0
593498	593483	12041X	PARTICIPANT	\N	PRESENT	0
593499	593483	14219Q	PARTICIPANT	\N	PRESENT	0
593500	593483	14251Q	PARTICIPANT	\N	PRESENT	0
593501	593483	14071N	PARTICIPANT	\N	PRESENT	0
593502	593483	08073C	PARTICIPANT	\N	PRESENT	0
593503	593483	08061X	PARTICIPANT	\N	PRESENT	0
593504	593483	14331P	PARTICIPANT	\N	PRESENT	0
593505	593483	11012A	PARTICIPANT	\N	PRESENT	0
593506	593483	11045K	PARTICIPANT	\N	PRESENT	0
593507	593483	01028R	PARTICIPANT	\N	PRESENT	0
593554	593553	04071H	PARTICIPANT	\N	PRESENT	0
593510	593509	14071N	PARTICIPANT	\N	PRESENT	0
593550	593549	07029T	PARTICIPANT	\N	PRESENT	0
593556	593555	04071H	PARTICIPANT	\N	PRESENT	0
593558	593557	19687N	PARTICIPANT	\N	PRESENT	0
593560	593559	19687N	PARTICIPANT	\N	PRESENT	0
593562	593561	19687N	PARTICIPANT	\N	PRESENT	0
593564	593563	20080C	PARTICIPANT	\N	PRESENT	0
593566	593565	20080C	PARTICIPANT	\N	PRESENT	0
593568	593567	08010L	PARTICIPANT	\N	PRESENT	0
593580	593579	19711U	PARTICIPANT	\N	PRESENT	1
593583	593582	20086J	PARTICIPANT	\N	PRESENT	0
593586	593584	19667J	PARTICIPANT	\N	PRESENT	0
593587	593584	11040E	PARTICIPANT	\N	PRESENT	0
593589	593588	19667J	PARTICIPANT	\N	PRESENT	0
593590	593588	11040E	PARTICIPANT	\N	PRESENT	0
593592	593591	19667J	PARTICIPANT	\N	PRESENT	0
593593	593591	11040E	PARTICIPANT	\N	PRESENT	0
593605	593604	11074Q	PARTICIPANT	\N	PRESENT	0
593606	593604	19349W	PARTICIPANT	\N	PRESENT	0
593609	593608	19479G	PARTICIPANT	\N	PRESENT	0
593612	593611	11074Q	PARTICIPANT	\N	PRESENT	0
593613	593611	19349W	PARTICIPANT	\N	PRESENT	0
593616	593615	19479G	PARTICIPANT	\N	PRESENT	0
593617	592948	20128B	PARTICIPANT	\N	PRESENT	1
593618	592948	14147R	PARTICIPANT	\N	PRESENT	1
593619	592948	10015M	PARTICIPANT	\N	PRESENT	1
593620	592948	14107H	PARTICIPANT	\N	PRESENT	1
593621	592948	08018U	PARTICIPANT	\N	EXCUSE	0
572007	572006	14193X	PARTICIPANT	\N	PRESENT	0
572008	572006	14083S	PARTICIPANT	\N	PRESENT	0
572009	572006	14059S	PARTICIPANT	\N	PRESENT	0
572010	572006	14267Y	PARTICIPANT	\N	PRESENT	0
572011	572006	19421M	PARTICIPANT	\N	PRESENT	0
572217	572216	14267Y	PARTICIPANT	\N	PRESENT	0
572218	572216	20070A	PARTICIPANT	\N	PRESENT	0
572219	572216	07004J	PARTICIPANT	\N	PRESENT	0
572220	572216	11027H	PARTICIPANT	\N	PRESENT	0
572221	572216	11026G	PARTICIPANT	\N	PRESENT	0
572222	572216	10015M	PARTICIPANT	\N	PRESENT	0
572226	572225	17737W	PARTICIPANT	\N	PRESENT	0
574304	572787	20022R	PARTICIPANT	\N	PRESENT	1
574305	572787	19545Y	PARTICIPANT	\N	PRESENT	1
574306	572787	20126Y	PARTICIPANT	\N	PRESENT	1
574307	572787	20036X	PARTICIPANT	\N	PRESENT	1
574308	572787	19349W	PARTICIPANT	\N	PRESENT	1
574311	572787	11012A	PARTICIPANT	\N	PRESENT	1
574313	572787	19687N	PARTICIPANT	\N	PRESENT	1
575184	566272	97011G	PARTICIPANT	\N	PRESENT	1
575185	566272	19347U	PARTICIPANT	\N	PRESENT	0
575187	566272	20034V	PARTICIPANT	\N	PRESENT	0
575188	566272	19715Y	PARTICIPANT	\N	PRESENT	1
575189	566272	12016W	PARTICIPANT	\N	PRESENT	1
575190	566272	14147R	PARTICIPANT	\N	PRESENT	1
575195	566272	17023S	PARTICIPANT	\N	PRESENT	0
581905	581902	19415P	PARTICIPANT	\N	PRESENT	0
581906	581903	19415P	PARTICIPANT	\N	PRESENT	0
581907	581904	19415P	PARTICIPANT	\N	PRESENT	0
581908	581904	11031D	PARTICIPANT	\N	PRESENT	0
581909	581904	20130U	PARTICIPANT	\N	PRESENT	0
581910	579467	20108W	PARTICIPANT	\N	PRESENT	0
581914	580621	19593H	PARTICIPANT	\N	PRESENT	0
581915	580621	11083R	PARTICIPANT	\N	PRESENT	0
581916	580621	20082E	PARTICIPANT	\N	PRESENT	1
581917	580621	17367Q	PARTICIPANT	\N	PRESENT	0
581918	580622	17367Q	PARTICIPANT	\N	PRESENT	0
581919	580622	11083R	PARTICIPANT	\N	PRESENT	0
581920	580622	19593H	PARTICIPANT	\N	PRESENT	0
587978	587977	11043H	PARTICIPANT	\N	PRESENT	1
587979	587977	08012N	PARTICIPANT	\N	PRESENT	1
596756	595603	19725B	PARTICIPANT	\N	PRESENT	0
596757	595603	10015M	PARTICIPANT	\N	PRESENT	0
596758	595603	14223L	PARTICIPANT	\N	PRESENT	0
596759	595603	19527W	PARTICIPANT	\N	PRESENT	0
596760	595603	04033B	PARTICIPANT	\N	PRESENT	0
596761	595603	14071N	PARTICIPANT	\N	PRESENT	0
596762	595603	17965H	PARTICIPANT	\N	PRESENT	0
596763	595603	14187A	PARTICIPANT	\N	PRESENT	0
596764	595603	19421M	PARTICIPANT	\N	PRESENT	0
596765	595603	11045K	PARTICIPANT	\N	PRESENT	0
596766	595603	20094J	PARTICIPANT	\N	PRESENT	0
596767	595603	20082E	PARTICIPANT	\N	PRESENT	0
596768	595603	14069U	PARTICIPANT	\N	PRESENT	0
596769	595603	19251M	PARTICIPANT	\N	PRESENT	0
596770	595603	11080N	PARTICIPANT	\N	PRESENT	0
596771	595603	20028X	PARTICIPANT	\N	PRESENT	0
596772	595603	20018V	PARTICIPANT	\N	PRESENT	0
596773	595603	01057W	PARTICIPANT	\N	PRESENT	0
596774	595603	05012A	PARTICIPANT	\N	PRESENT	0
596775	595603	11090Q	PARTICIPANT	\N	PRESENT	0
596776	595603	19782L	PARTICIPANT	\N	PRESENT	0
596777	595603	11033F	PARTICIPANT	\N	PRESENT	0
596778	595603	19651A	PARTICIPANT	\N	PRESENT	0
596779	595603	11083R	PARTICIPANT	\N	PRESENT	0
596780	595603	20128B	PARTICIPANT	\N	PRESENT	0
596781	595603	20032T	PARTICIPANT	\N	PRESENT	0
596782	595603	19591F	PARTICIPANT	\N	PRESENT	0
596783	595603	95063L	PARTICIPANT	\N	PRESENT	0
596784	595603	04045F	PARTICIPANT	\N	PRESENT	0
596785	595603	19515S	PARTICIPANT	\N	PRESENT	0
596786	595603	20174H	PARTICIPANT	\N	PRESENT	0
596787	595603	19697Q	PARTICIPANT	\N	PRESENT	0
596788	595603	20038A	PARTICIPANT	\N	PRESENT	0
596789	595603	19683J	PARTICIPANT	\N	PRESENT	0
596790	595603	08045X	PARTICIPANT	\N	PRESENT	0
596791	595603	19701S	PARTICIPANT	\N	PRESENT	0
596792	595603	19581D	PARTICIPANT	\N	PRESENT	0
596793	595603	20072C	PARTICIPANT	\N	PRESENT	0
596794	595603	19553Y	PARTICIPANT	\N	PRESENT	0
596795	595603	14038Y	PARTICIPANT	\N	PRESENT	0
596796	595603	20252E	PARTICIPANT	\N	PRESENT	0
596797	595603	19629C	PARTICIPANT	\N	PRESENT	0
596798	595603	19387D	PARTICIPANT	\N	PRESENT	0
596799	595603	17737W	PARTICIPANT	\N	PRESENT	0
596800	595603	19545Y	PARTICIPANT	\N	PRESENT	0
596801	595603	20050V	PARTICIPANT	\N	PRESENT	0
596802	595603	20136B	PARTICIPANT	\N	PRESENT	0
596803	595603	20042V	PARTICIPANT	\N	PRESENT	0
596804	595603	19447X	PARTICIPANT	\N	PRESENT	0
596805	595603	04057K	PARTICIPANT	\N	PRESENT	0
596806	595603	19573D	PARTICIPANT	\N	PRESENT	0
596807	595603	20048C	PARTICIPANT	\N	PRESENT	0
596808	595603	20172F	PARTICIPANT	\N	PRESENT	0
596809	595603	19713W	PARTICIPANT	\N	PRESENT	0
596810	595603	14219Q	PARTICIPANT	\N	PRESENT	0
596811	595603	19441R	PARTICIPANT	\N	PRESENT	0
596812	595603	19479G	PARTICIPANT	\N	PRESENT	0
596813	595603	14147R	PARTICIPANT	\N	PRESENT	0
596814	595603	20266L	PARTICIPANT	\N	PRESENT	0
596815	595603	19723Y	PARTICIPANT	\N	PRESENT	0
596816	595603	11053K	PARTICIPANT	\N	PRESENT	0
596817	595603	19467C	PARTICIPANT	\N	PRESENT	0
596818	595603	14231L	PARTICIPANT	\N	PRESENT	0
596819	595603	20056C	PARTICIPANT	\N	PRESENT	0
596820	595603	19691J	PARTICIPANT	\N	PRESENT	0
596821	595603	20098N	PARTICIPANT	\N	PRESENT	0
596822	595603	19611R	PARTICIPANT	\N	PRESENT	0
596823	595603	20116W	PARTICIPANT	\N	PRESENT	0
596824	595603	04070G	PARTICIPANT	\N	PRESENT	0
596825	595603	20108W	PARTICIPANT	\N	PRESENT	0
596826	595603	14089Y	PARTICIPANT	\N	PRESENT	0
596827	595603	05008E	PARTICIPANT	\N	PRESENT	0
596828	595603	14267Y	PARTICIPANT	\N	PRESENT	0
596829	595603	14213J	PARTICIPANT	\N	PRESENT	0
596830	595603	20040T	PARTICIPANT	\N	PRESENT	0
596831	595603	20138D	PARTICIPANT	\N	PRESENT	0
596832	595603	19335Q	PARTICIPANT	\N	PRESENT	0
596833	595603	19685L	PARTICIPANT	\N	PRESENT	0
596834	595603	19749K	PARTICIPANT	\N	PRESENT	0
596835	595603	19826F	PARTICIPANT	\N	PRESENT	0
596836	595603	14255U	PARTICIPANT	\N	PRESENT	0
596837	595603	14083S	PARTICIPANT	\N	PRESENT	0
596838	595603	19762G	PARTICIPANT	\N	PRESENT	0
596839	595603	20110Q	PARTICIPANT	\N	PRESENT	0
596840	595603	19621T	PARTICIPANT	\N	PRESENT	0
596841	595603	07004J	PARTICIPANT	\N	PRESENT	0
596842	595603	20066E	PARTICIPANT	\N	PRESENT	0
596843	595603	11085T	PARTICIPANT	\N	PRESENT	0
596844	595603	01025N	PARTICIPANT	\N	PRESENT	0
596845	595603	01024M	PARTICIPANT	\N	PRESENT	0
596846	595603	20054A	PARTICIPANT	\N	PRESENT	0
596847	595603	14030Q	PARTICIPANT	\N	PRESENT	0
596848	595603	20126Y	PARTICIPANT	\N	PRESENT	0
596849	595603	14327T	PARTICIPANT	\N	PRESENT	0
596850	595603	20152B	PARTICIPANT	\N	PRESENT	0
596851	595603	20080C	PARTICIPANT	\N	PRESENT	0
596852	595603	20090E	PARTICIPANT	\N	PRESENT	0
596853	595603	19707Y	PARTICIPANT	\N	PRESENT	0
596854	595603	08015R	PARTICIPANT	\N	PRESENT	0
596855	595603	19768N	PARTICIPANT	\N	PRESENT	0
596856	595603	07029T	PARTICIPANT	\N	PRESENT	0
596857	595603	08018U	PARTICIPANT	\N	PRESENT	0
596858	595603	19709B	PARTICIPANT	\N	PRESENT	0
596859	595603	20044X	PARTICIPANT	\N	PRESENT	0
596860	595603	20058E	PARTICIPANT	\N	PRESENT	0
596861	595603	19507S	PARTICIPANT	\N	PRESENT	0
596862	595603	14033T	PARTICIPANT	\N	PRESENT	0
596863	595603	20104S	PARTICIPANT	\N	PRESENT	0
596864	595603	04047H	PARTICIPANT	\N	PRESENT	0
596865	595603	08010L	PARTICIPANT	\N	PRESENT	0
596866	595603	14026U	PARTICIPANT	\N	PRESENT	0
596867	595603	19703U	PARTICIPANT	\N	PRESENT	0
596868	595603	11097X	PARTICIPANT	\N	PRESENT	0
596869	595603	19367Y	PARTICIPANT	\N	PRESENT	0
596870	595603	11048N	PARTICIPANT	\N	PRESENT	0
596871	595603	19711U	PARTICIPANT	\N	PRESENT	0
596872	595603	14193X	PARTICIPANT	\N	PRESENT	0
596873	595603	20062A	PARTICIPANT	\N	PRESENT	0
596874	595603	11043H	PARTICIPANT	\N	PRESENT	0
596875	595603	19745F	PARTICIPANT	\N	PRESENT	0
592556	590851	14123H	PARTICIPANT	\N	PRESENT	0
592557	590851	20142Y	PARTICIPANT	\N	PRESENT	0
592558	590851	19621T	PARTICIPANT	\N	PRESENT	0
592560	590490	19619A	PARTICIPANT	\N	PRESENT	0
592561	590851	19441R	PARTICIPANT	\N	PRESENT	0
592562	590851	20134Y	PARTICIPANT	\N	PRESENT	0
592563	590851	20034V	PARTICIPANT	\N	PRESENT	0
592664	590854	14151M	PARTICIPANT	\N	PRESENT	0
592665	590854	11031D	PARTICIPANT	\N	PRESENT	0
592666	590854	04085P	PARTICIPANT	\N	PRESENT	0
592667	590854	14097Y	PARTICIPANT	\N	PRESENT	0
592668	590854	18193Q	PARTICIPANT	\N	PRESENT	0
592708	590854	19599P	PARTICIPANT	\N	PRESENT	0
592670	590854	19551W	PARTICIPANT	\N	PRESENT	0
592671	590854	20070A	PARTICIPANT	\N	PRESENT	0
592672	590854	20060X	PARTICIPANT	\N	PRESENT	0
592701	590854	19333N	PARTICIPANT	\N	PRESENT	0
592674	590854	11026G	PARTICIPANT	\N	PRESENT	0
592675	590854	19629C	PARTICIPANT	\N	PRESENT	0
592676	590854	19719D	PARTICIPANT	\N	PRESENT	0
592677	590854	04047H	PARTICIPANT	\N	PRESENT	0
592678	590854	11056N	PARTICIPANT	\N	PRESENT	0
592679	590854	19758L	PARTICIPANT	\N	PRESENT	0
592683	590854	20030R	PARTICIPANT	\N	PRESENT	0
592681	590854	11033F	PARTICIPANT	\N	PRESENT	0
592682	590854	20110Q	PARTICIPANT	\N	PRESENT	0
592684	590854	20134Y	PARTICIPANT	\N	PRESENT	0
592685	590854	08060W	PARTICIPANT	\N	PRESENT	0
592686	590854	19563B	PARTICIPANT	\N	PRESENT	0
592687	590854	19441R	PARTICIPANT	\N	PRESENT	0
592688	590854	19691J	PARTICIPANT	\N	PRESENT	0
592689	590854	07004J	PARTICIPANT	\N	PRESENT	0
592690	590854	14053L	PARTICIPANT	\N	PRESENT	0
592691	590854	20120S	PARTICIPANT	\N	PRESENT	0
592692	590854	20080C	PARTICIPANT	\N	PRESENT	0
592693	590854	19820Y	PARTICIPANT	\N	PRESENT	0
592694	590854	20090E	PARTICIPANT	\N	PRESENT	0
592695	590854	20034V	PARTICIPANT	\N	PRESENT	0
592696	590854	07029T	PARTICIPANT	\N	PRESENT	0
592697	590854	14033T	PARTICIPANT	\N	PRESENT	0
592698	590854	14123H	PARTICIPANT	\N	PRESENT	0
592702	590854	14195A	PARTICIPANT	\N	PRESENT	0
592700	590854	11072N	PARTICIPANT	\N	PRESENT	0
592703	590854	17965H	PARTICIPANT	\N	PRESENT	0
592704	590854	20114U	PARTICIPANT	\N	PRESENT	0
592705	590854	20024T	PARTICIPANT	\N	PRESENT	0
592706	590854	14147R	PARTICIPANT	\N	PRESENT	0
592707	590854	11067R	PARTICIPANT	\N	PRESENT	0
592709	590854	18083K	PARTICIPANT	\N	PRESENT	0
592710	590854	20062A	PARTICIPANT	\N	PRESENT	0
592711	590854	20038A	PARTICIPANT	\N	PRESENT	0
592712	590854	19503N	PARTICIPANT	\N	PRESENT	0
592713	590854	20028X	PARTICIPANT	\N	PRESENT	0
592714	590854	01028R	PARTICIPANT	\N	PRESENT	0
592715	590854	14042U	PARTICIPANT	\N	PRESENT	0
592716	590854	20108W	PARTICIPANT	\N	PRESENT	0
592717	590854	20116W	PARTICIPANT	\N	PRESENT	0
592718	590854	20018V	PARTICIPANT	\N	PRESENT	0
592719	590854	20026V	PARTICIPANT	\N	PRESENT	0
592720	590854	14357A	PARTICIPANT	\N	PRESENT	0
592721	590854	19415P	PARTICIPANT	\N	PRESENT	0
592722	590854	14207L	PARTICIPANT	\N	PRESENT	0
592723	590854	19447X	PARTICIPANT	\N	PRESENT	0
592724	590854	14331P	PARTICIPANT	\N	PRESENT	0
592725	590854	19349W	PARTICIPANT	\N	PRESENT	0
592726	590854	19347U	PARTICIPANT	\N	PRESENT	0
592727	590854	19467C	PARTICIPANT	\N	PRESENT	0
592728	590854	20104S	PARTICIPANT	\N	PRESENT	0
592729	590854	19723Y	PARTICIPANT	\N	PRESENT	0
592730	590854	14191V	PARTICIPANT	\N	PRESENT	0
592731	590854	11065P	PARTICIPANT	\N	PRESENT	0
592732	590854	11097X	PARTICIPANT	\N	PRESENT	0
592733	590854	14217N	PARTICIPANT	\N	PRESENT	0
592734	590854	19621T	PARTICIPANT	\N	PRESENT	0
592735	590854	12041X	PARTICIPANT	\N	PRESENT	0
592798	590856	14193X	PARTICIPANT	\N	PRESENT	0
592799	590856	14331P	PARTICIPANT	\N	PRESENT	0
592800	590856	11048N	PARTICIPANT	\N	PRESENT	0
592801	590856	14001X	PARTICIPANT	\N	PRESENT	0
592802	590856	19333N	PARTICIPANT	\N	PRESENT	0
592803	590856	19531S	PARTICIPANT	\N	PRESENT	0
592804	590856	12016W	PARTICIPANT	\N	PRESENT	0
592805	590856	20100N	PARTICIPANT	\N	PRESENT	0
592806	590856	19347U	PARTICIPANT	\N	PRESENT	0
592807	590856	04057K	PARTICIPANT	\N	PRESENT	0
592808	590856	20046A	PARTICIPANT	\N	PRESENT	0
592809	590856	20102Q	PARTICIPANT	\N	PRESENT	0
592810	590856	11083R	PARTICIPANT	\N	PRESENT	0
592811	590856	14219Q	PARTICIPANT	\N	PRESENT	0
592812	590856	07004J	PARTICIPANT	\N	PRESENT	0
592813	590856	04070G	PARTICIPANT	\N	PRESENT	0
592814	590856	14026U	PARTICIPANT	\N	PRESENT	0
592815	590856	14033T	PARTICIPANT	\N	PRESENT	0
592816	590856	19399H	PARTICIPANT	\N	PRESENT	0
592817	590856	10015M	PARTICIPANT	\N	PRESENT	0
592818	590856	14207L	PARTICIPANT	\N	PRESENT	0
592819	590856	14237S	PARTICIPANT	\N	PRESENT	0
592820	590856	07029T	PARTICIPANT	\N	PRESENT	0
592821	590856	14147R	PARTICIPANT	\N	PRESENT	0
592822	590856	20048C	PARTICIPANT	\N	PRESENT	0
592823	590856	20030R	PARTICIPANT	\N	PRESENT	0
592824	590856	95063L	PARTICIPANT	\N	PRESENT	0
592825	590856	18083K	PARTICIPANT	\N	PRESENT	0
592826	590857	12041X	PARTICIPANT	\N	PRESENT	0
592905	590857	20134Y	PARTICIPANT	\N	PRESENT	0
592662	590854	11045K	PARTICIPANT	\N	PRESENT	0
592663	590854	19673G	PARTICIPANT	\N	PRESENT	0
592554	590851	20150Y	PARTICIPANT	\N	PRESENT	0
592555	590851	20058E	PARTICIPANT	\N	PRESENT	0
592906	590857	19593H	PARTICIPANT	\N	PRESENT	0
592907	590857	14073Q	PARTICIPANT	\N	PRESENT	0
592908	590857	20036X	PARTICIPANT	\N	PRESENT	0
592909	590857	19585H	PARTICIPANT	\N	PRESENT	0
592910	590857	14191V	PARTICIPANT	\N	PRESENT	0
592911	590857	19758L	PARTICIPANT	\N	PRESENT	0
592912	590857	11012A	PARTICIPANT	\N	PRESENT	0
592913	590857	08012N	PARTICIPANT	\N	PRESENT	0
592914	590857	11043H	PARTICIPANT	\N	PRESENT	0
592915	590857	19399H	PARTICIPANT	\N	PRESENT	0
592916	590857	20142Y	PARTICIPANT	\N	PRESENT	0
592920	590857	20024T	PARTICIPANT	\N	PRESENT	0
592921	590857	19621T	PARTICIPANT	\N	PRESENT	0
592922	590857	20110Q	PARTICIPANT	\N	PRESENT	0
592923	590857	19611R	PARTICIPANT	\N	PRESENT	0
592924	590857	19349W	PARTICIPANT	\N	PRESENT	0
592925	590857	14207L	PARTICIPANT	\N	PRESENT	0
592927	590857	14147R	PARTICIPANT	\N	PRESENT	0
592928	590857	20100N	PARTICIPANT	\N	PRESENT	0
592929	590857	20030R	PARTICIPANT	\N	PRESENT	0
592931	590857	20266L	PARTICIPANT	\N	PRESENT	0
592932	590857	14189C	PARTICIPANT	\N	PRESENT	0
592933	590857	19533U	PARTICIPANT	\N	PRESENT	0
592935	590857	14123H	PARTICIPANT	\N	PRESENT	0
592936	590857	20090E	PARTICIPANT	\N	PRESENT	0
592937	590857	11065P	PARTICIPANT	\N	PRESENT	0
592938	590857	19347U	PARTICIPANT	\N	PRESENT	0
592939	590857	20144B	PARTICIPANT	\N	PRESENT	0
592940	590857	14030Q	PARTICIPANT	\N	PRESENT	0
592941	590857	20116W	PARTICIPANT	\N	PRESENT	0
592796	590856	11070L	PARTICIPANT	\N	PRESENT	0
592797	590856	12041X	PARTICIPANT	\N	PRESENT	0
592943	590857	14031R	PARTICIPANT	\N	PRESENT	0
592945	590857	20104S	PARTICIPANT	\N	PRESENT	0
592946	590857	19699S	PARTICIPANT	\N	PRESENT	0
592947	590857	14089Y	PARTICIPANT	\N	PRESENT	0
592952	590857	20052X	PARTICIPANT	\N	PRESENT	0
592955	590857	19467C	PARTICIPANT	\N	PRESENT	0
592956	590857	14229S	PARTICIPANT	\N	PRESENT	0
592957	590857	19782L	PARTICIPANT	\N	PRESENT	0
592958	590857	20048C	PARTICIPANT	\N	PRESENT	0
592959	590857	20092G	PARTICIPANT	\N	PRESENT	0
592960	590857	19695N	PARTICIPANT	\N	PRESENT	0
592961	590397	20090E	PARTICIPANT	\N	PRESENT	1
592962	590397	11067R	PARTICIPANT	\N	PRESENT	0
592963	590397	14281W	PARTICIPANT	\N	PRESENT	0
592964	590397	19798U	PARTICIPANT	\N	PRESENT	1
592965	590397	11097X	PARTICIPANT	\N	PRESENT	0
592966	590397	14042U	PARTICIPANT	\N	PRESENT	0
592967	590397	14195A	PARTICIPANT	\N	PRESENT	0
592968	590397	14213J	PARTICIPANT	\N	PRESENT	0
592969	590397	14217N	PARTICIPANT	\N	PRESENT	0
571277	571276	14097Y	PARTICIPANT	\N	PRESENT	0
571278	571276	14133K	PARTICIPANT	\N	PRESENT	0
571279	571276	11083R	PARTICIPANT	\N	PRESENT	0
576044	574851	14217N	PRESIDENT	0	PRESENT	0
576045	574851	04057K	PARTICIPANT	\N	PRESENT	1
576046	574851	11103C	PARTICIPANT	\N	PRESENT	1
576047	574851	20130U	PARTICIPANT	\N	PRESENT	1
576048	574851	19697Q	PARTICIPANT	\N	PRESENT	1
576049	574851	19717B	PARTICIPANT	\N	PRESENT	0
576050	574851	19683J	PARTICIPANT	\N	PRESENT	0
576051	574851	19715Y	PARTICIPANT	\N	PRESENT	0
576052	574851	04092N	PARTICIPANT	\N	PRESENT	0
576053	574851	19367Y	PARTICIPANT	\N	PRESENT	0
576054	574851	14042U	PARTICIPANT	\N	PRESENT	0
576055	574851	20066E	PARTICIPANT	\N	PRESENT	0
576056	574851	20172F	PARTICIPANT	\N	PRESENT	0
576057	574851	19703U	PARTICIPANT	\N	PRESENT	0
576058	574851	19691J	PARTICIPANT	\N	PRESENT	0
576059	574851	19415P	PARTICIPANT	\N	PRESENT	0
576060	574851	20040T	PARTICIPANT	\N	PRESENT	0
576061	574851	19569H	PARTICIPANT	\N	PRESENT	0
576062	574851	20090E	PARTICIPANT	\N	PRESENT	0
576063	574851	04043D	PARTICIPANT	\N	PRESENT	1
576087	574851	11067R	PARTICIPANT	\N	PRESENT	0
576088	574851	18193Q	PARTICIPANT	\N	PRESENT	0
576089	574851	17779H	PARTICIPANT	\N	PRESENT	0
576090	574851	14195A	PARTICIPANT	\N	PRESENT	0
576091	574851	19301E	PARTICIPANT	\N	PRESENT	0
576092	574851	11097X	PARTICIPANT	\N	PRESENT	0
576093	574851	19723Y	PARTICIPANT	\N	PRESENT	0
576094	574851	19760E	PARTICIPANT	\N	PRESENT	1
576095	574851	19657G	PARTICIPANT	\N	PRESENT	0
576096	574851	14213J	PARTICIPANT	\N	PRESENT	0
576097	574851	14223L	PARTICIPANT	\N	PRESENT	0
576098	574851	17965H	PARTICIPANT	\N	PRESENT	0
576099	574851	19798U	PARTICIPANT	\N	PRESENT	0
576100	574851	19295A	PARTICIPANT	\N	EXCUSE	0
576101	574851	20148F	PARTICIPANT	\N	PRESENT	0
576160	574851	11031D	PARTICIPANT	\N	PRESENT	1
576161	574851	19591F	PARTICIPANT	\N	PRESENT	1
576162	574851	10006L	PRESIDENT	1	PRESENT	0
576163	574851	08045X	PARTICIPANT	\N	PRESENT	0
576164	574851	01034P	PARTICIPANT	\N	PRESENT	0
576887	576885	14179A	PARTICIPANT	\N	PRESENT	0
576888	576885	14021P	PARTICIPANT	\N	PRESENT	0
576892	576891	20074E	PARTICIPANT	\N	PRESENT	0
576893	576891	14179A	PARTICIPANT	\N	PRESENT	0
576894	576891	14021P	PARTICIPANT	\N	PRESENT	0
576895	576891	20114U	PARTICIPANT	\N	PRESENT	0
576897	576896	20074E	PARTICIPANT	\N	PRESENT	0
576898	576896	14179A	PARTICIPANT	\N	PRESENT	0
576899	576896	14021P	PARTICIPANT	\N	PRESENT	0
576949	555423	19735D	PARTICIPANT	\N	EXCUSE	0
576987	576986	14249W	PARTICIPANT	\N	PRESENT	0
577900	575224	19575F	PRESIDENT	0	PRESENT	0
578506	577322	14107H	PARTICIPANT	\N	PRESENT	1
578503	577322	14147R	PARTICIPANT	\N	PRESENT	1
578505	577322	14179A	PARTICIPANT	\N	PRESENT	1
578507	577322	19447X	PARTICIPANT	\N	PRESENT	1
578509	577322	08018U	PARTICIPANT	\N	EXCUSE	0
578527	577322	14231L	PARTICIPANT	\N	PRESENT	0
578711	578170	19719D	PARTICIPANT	\N	PRESENT	0
578712	578170	20070A	PARTICIPANT	\N	PRESENT	0
578717	578170	14147R	PARTICIPANT	\N	PRESENT	0
578718	578170	14031R	PARTICIPANT	\N	PRESENT	0
578720	578170	14033T	PARTICIPANT	\N	PRESENT	0
578726	578170	17023S	PARTICIPANT	\N	PRESENT	0
578727	578170	14123H	PARTICIPANT	\N	PRESENT	0
578736	577327	19489J	PARTICIPANT	\N	PRESENT	0
578737	578172	12041X	PARTICIPANT	\N	PRESENT	0
578738	578723	19687N	PARTICIPANT	\N	PRESENT	0
578731	577327	20108W	PARTICIPANT	\N	PRESENT	0
578732	577327	20110Q	PARTICIPANT	\N	PRESENT	0
578733	577327	04047H	PRESIDENT	0	PRESENT	0
578734	577327	11056N	PARTICIPANT	\N	PRESENT	0
578735	577327	07004J	PARTICIPANT	\N	PRESENT	0
578739	578723	19575F	PRESIDENT	0	PRESENT	1
578740	578723	17779H	PARTICIPANT	\N	PRESENT	1
578741	578172	20090E	PARTICIPANT	\N	PRESENT	0
578742	578172	20062A	PARTICIPANT	\N	PRESENT	0
578743	578172	19569H	PARTICIPANT	\N	PRESENT	0
578744	578172	18083K	PARTICIPANT	\N	PRESENT	0
578745	578172	20034V	PARTICIPANT	\N	PRESENT	0
578746	578172	20026V	PARTICIPANT	\N	PRESENT	0
580599	579135	19447X	PARTICIPANT	\N	PRESENT	0
580600	579135	14089Y	PARTICIPANT	\N	PRESENT	0
580601	579135	95063L	PARTICIPANT	\N	PRESENT	0
580602	579135	14179A	PARTICIPANT	\N	PRESENT	0
580603	579135	14151M	PARTICIPANT	\N	PRESENT	0
580604	579135	14231L	PARTICIPANT	\N	PRESENT	0
580605	579135	14111D	PARTICIPANT	\N	PRESENT	0
580606	579135	17737W	PARTICIPANT	\N	PRESENT	0
580624	579135	19585H	PARTICIPANT	\N	PRESENT	0
580631	579602	14331P	PARTICIPANT	\N	PRESENT	0
580632	579602	11048N	PARTICIPANT	\N	PRESENT	0
580633	579602	01057W	PARTICIPANT	\N	PRESENT	0
580634	579602	20080C	PARTICIPANT	\N	PRESENT	0
580635	579602	11053K	PARTICIPANT	\N	PRESENT	0
580636	579602	11074Q	PRESIDENT	0	PRESENT	0
580637	579602	19667J	PARTICIPANT	\N	PRESENT	0
580638	579602	20044X	PARTICIPANT	\N	PRESENT	0
580639	579602	11070L	PARTICIPANT	\N	PRESENT	0
580640	579602	07029T	PARTICIPANT	\N	PRESENT	0
580641	579602	14083S	PARTICIPANT	\N	PRESENT	0
580642	579602	11012A	PARTICIPANT	\N	PRESENT	0
580643	579602	20070A	PARTICIPANT	\N	PRESENT	0
580644	579602	08009T	PARTICIPANT	\N	PRESENT	0
580645	579602	19741B	PARTICIPANT	\N	PRESENT	0
580646	579602	99004R	PARTICIPANT	\N	PRESENT	0
580647	579602	20116W	PARTICIPANT	\N	PRESENT	0
580648	579602	19335Q	PARTICIPANT	\N	PRESENT	0
580649	579602	20022R	PARTICIPANT	\N	PRESENT	0
580650	579602	20126Y	PARTICIPANT	\N	PRESENT	0
580675	579602	19647E	PARTICIPANT	\N	PRESENT	0
580676	579602	19479G	PARTICIPANT	\N	PRESENT	0
580677	579602	19687N	PARTICIPANT	\N	PRESENT	0
580678	579602	08010L	PARTICIPANT	\N	PRESENT	0
580690	578921	19443T	PARTICIPANT	\N	PRESENT	0
580691	578921	12041X	PARTICIPANT	\N	PRESENT	0
580692	578921	19565D	PARTICIPANT	\N	PRESENT	0
580693	578921	01058X	PARTICIPANT	\N	PRESENT	0
580695	578921	04042C	PRESIDENT	0	PRESENT	0
580696	578921	19669L	PARTICIPANT	\N	PRESENT	0
580697	578921	11066Q	PARTICIPANT	\N	PRESENT	0
580698	578921	08056B	PARTICIPANT	\N	PRESENT	0
580699	578921	12028B	PARTICIPANT	\N	PRESENT	0
580700	578921	19421M	PARTICIPANT	\N	PRESENT	0
580701	578921	19709B	PARTICIPANT	\N	PRESENT	0
580702	578921	14193X	PARTICIPANT	\N	PRESENT	0
580703	578921	19347U	PARTICIPANT	\N	PRESENT	0
580704	578921	97011G	PARTICIPANT	\N	PRESENT	0
580705	578921	08061X	PARTICIPANT	\N	PRESENT	0
580706	578921	08047A	PARTICIPANT	\N	PRESENT	0
580707	578921	14059S	PARTICIPANT	\N	PRESENT	0
580708	578921	14097Y	PARTICIPANT	\N	PRESENT	0
580709	578921	04035D	PARTICIPANT	\N	PRESENT	0
580710	578921	01062T	PARTICIPANT	\N	PRESENT	0
580712	578921	01024M	PARTICIPANT	\N	PRESENT	0
580713	578921	20064C	PARTICIPANT	\N	PRESENT	0
580714	578921	14267Y	PARTICIPANT	\N	PRESENT	0
580715	578921	11083R	PARTICIPANT	\N	PRESENT	0
580716	578921	14255U	PARTICIPANT	\N	PRESENT	0
580717	578921	17023S	PARTICIPANT	\N	PRESENT	0
580750	579136	14053L	PARTICIPANT	\N	PRESENT	0
580751	579136	19649G	PARTICIPANT	\N	PRESENT	0
580752	579136	10015M	PARTICIPANT	\N	PRESENT	0
580753	579136	11026G	PARTICIPANT	\N	PRESENT	0
580754	579136	19581D	PARTICIPANT	\N	PRESENT	0
580755	579136	04047H	PRESIDENT	0	PRESENT	0
580756	579136	14089Y	PARTICIPANT	\N	PRESENT	0
580757	579136	19725B	PARTICIPANT	\N	PRESENT	0
580758	579136	14041T	PARTICIPANT	\N	PRESENT	0
580759	579136	14147R	PARTICIPANT	\N	PRESENT	0
580760	579136	20114U	PARTICIPANT	\N	PRESENT	0
580761	579136	14215L	PARTICIPANT	\N	PRESENT	0
580762	579136	19749K	PARTICIPANT	\N	PRESENT	0
580763	579136	14021P	PARTICIPANT	\N	PRESENT	0
593622	592948	14231L	PARTICIPANT	\N	EXCUSE	0
593623	592948	19729F	PARTICIPANT	\N	EXCUSE	0
593633	593632	99004R	PARTICIPANT	\N	PRESENT	0
593635	593634	20022R	PARTICIPANT	\N	PRESENT	0
593637	593636	20022R	PARTICIPANT	\N	PRESENT	0
593639	593638	14189C	PARTICIPANT	\N	PRESENT	0
593642	593641	11053K	PARTICIPANT	\N	PRESENT	0
595273	595272	14031R	PARTICIPANT	\N	PRESENT	0
593647	593436	19717B	PRESIDENT	0	PRESENT	0
593650	591278	14026U	PARTICIPANT	\N	PRESENT	1
593651	591278	20130U	PARTICIPANT	\N	PRESENT	1
593860	593436	14331P	PARTICIPANT	\N	EXCUSE	0
593921	593920	11064N	PARTICIPANT	\N	PRESENT	0
593922	593920	14219Q	PARTICIPANT	\N	PRESENT	0
594187	590928	19681G	PARTICIPANT	\N	EXCUSE	0
594188	590928	20020P	PARTICIPANT	\N	EXCUSE	0
594189	593436	14097Y	PARTICIPANT	\N	PRESENT	0
594190	593085	19725B	PARTICIPANT	\N	PRESENT	0
594191	593085	12041X	PARTICIPANT	\N	PRESENT	0
594192	593085	14026U	PARTICIPANT	\N	EXCUSE	0
594193	593085	20100N	PARTICIPANT	\N	PRESENT	0
594194	593085	20098N	PARTICIPANT	\N	PRESENT	0
594195	593085	14331P	PRESIDENT	0	PRESENT	0
594196	593085	10015M	PARTICIPANT	\N	PRESENT	0
594197	593085	19701S	PARTICIPANT	\N	PRESENT	0
594198	593085	14189C	PARTICIPANT	\N	EXCUSE	0
594199	593085	20128B	PARTICIPANT	\N	PRESENT	0
594200	593085	14237S	PARTICIPANT	\N	PRESENT	0
594201	593085	19531S	PARTICIPANT	\N	PRESENT	0
594202	593085	20104S	PARTICIPANT	\N	PRESENT	0
594203	593085	11101A	PARTICIPANT	\N	PRESENT	0
594204	593085	14097Y	PARTICIPANT	\N	PRESENT	0
594242	593085	14001X	PARTICIPANT	\N	PRESENT	0
594243	593085	19441R	PARTICIPANT	\N	PRESENT	0
594244	593085	04057K	PARTICIPANT	\N	EXCUSE	0
594245	593085	19553Y	PARTICIPANT	\N	EXCUSE	0
594246	593085	11083R	PARTICIPANT	\N	PRESENT	0
594248	593085	08018U	PARTICIPANT	\N	EXCUSE	0
594921	593436	19319Q	PARTICIPANT	\N	PRESENT	1
595248	595247	20066E	PARTICIPANT	\N	PRESENT	0
595258	593436	08034U	PARTICIPANT	\N	PRESENT	0
595280	595274	14083S	PARTICIPANT	\N	PRESENT	0
595281	595274	19599P	PARTICIPANT	\N	PRESENT	0
595282	595274	19820Y	PARTICIPANT	\N	PRESENT	0
595283	595274	20034V	PARTICIPANT	\N	PRESENT	0
595284	595274	08015R	PARTICIPANT	\N	PRESENT	0
595285	595274	14031R	PARTICIPANT	\N	PRESENT	0
595286	595274	19745F	PARTICIPANT	\N	PRESENT	0
595290	595276	14083S	PARTICIPANT	\N	PRESENT	0
595288	595274	14331P	PARTICIPANT	\N	PRESENT	0
595289	595274	19619A	PARTICIPANT	\N	PRESENT	0
595291	595276	19820Y	PARTICIPANT	\N	PRESENT	0
595292	595276	20034V	PARTICIPANT	\N	PRESENT	0
595293	595276	08015R	PARTICIPANT	\N	PRESENT	0
595294	595276	14031R	PARTICIPANT	\N	PRESENT	0
595295	595276	19745F	PARTICIPANT	\N	PRESENT	0
595296	595276	19619A	PARTICIPANT	\N	PRESENT	0
595298	595297	99004R	PARTICIPANT	\N	PRESENT	0
595299	595297	11085T	PARTICIPANT	\N	PRESENT	0
595301	595278	14083S	PARTICIPANT	\N	PRESENT	0
595302	595278	19820Y	PARTICIPANT	\N	PRESENT	0
595303	595278	20034V	PARTICIPANT	\N	PRESENT	0
595304	595278	08015R	PARTICIPANT	\N	PRESENT	0
595305	595278	14031R	PARTICIPANT	\N	PRESENT	0
595306	595278	19745F	PARTICIPANT	\N	PRESENT	0
595307	595278	19619A	PARTICIPANT	\N	PRESENT	0
595310	595309	20110Q	PARTICIPANT	\N	PRESENT	0
595311	595309	20116W	PARTICIPANT	\N	PRESENT	0
595312	595309	14083S	PARTICIPANT	\N	PRESENT	0
595313	595309	19599P	PARTICIPANT	\N	PRESENT	0
595314	595309	20172F	PARTICIPANT	\N	PRESENT	0
595315	595309	19820Y	PARTICIPANT	\N	PRESENT	0
595316	595309	20180F	PARTICIPANT	\N	PRESENT	0
595317	595309	20034V	PARTICIPANT	\N	PRESENT	0
595319	595309	14031R	PARTICIPANT	\N	PRESENT	0
595320	595309	19826F	PARTICIPANT	\N	PRESENT	0
595321	595309	19619A	PARTICIPANT	\N	PRESENT	0
595325	595324	01048V	PARTICIPANT	\N	PRESENT	0
595331	595327	01048V	PARTICIPANT	\N	PRESENT	0
595334	595333	14327T	PARTICIPANT	\N	PRESENT	0
595337	595336	14327T	PARTICIPANT	\N	PRESENT	0
595340	595338	20116W	PARTICIPANT	\N	PRESENT	0
595345	593322	12041X	PARTICIPANT	\N	PRESENT	0
595346	595341	14042U	PARTICIPANT	\N	PRESENT	0
595347	595341	20130U	PARTICIPANT	\N	PRESENT	0
595349	595344	11097X	PARTICIPANT	\N	PRESENT	0
595350	595344	20130U	PARTICIPANT	\N	PRESENT	0
595361	595359	11097X	PARTICIPANT	\N	PRESENT	0
595362	595359	20130U	PARTICIPANT	\N	PRESENT	0
595363	595328	14042U	PARTICIPANT	\N	PRESENT	0
595364	595328	20130U	PARTICIPANT	\N	PRESENT	0
595366	595365	08012N	PARTICIPANT	\N	PRESENT	0
595367	595365	11043H	PARTICIPANT	\N	PRESENT	1
595373	595372	08012N	PARTICIPANT	\N	PRESENT	0
595374	595372	11043H	PARTICIPANT	\N	PRESENT	0
595380	590806	14231L	PRESIDENT	0	PRESENT	0
595381	590806	05012A	PARTICIPANT	\N	PRESENT	0
595382	590806	19573D	PARTICIPANT	\N	PRESENT	0
595383	590806	08010L	PARTICIPANT	\N	PRESENT	0
595384	590806	19349W	PARTICIPANT	\N	PRESENT	0
595385	590806	14205J	PARTICIPANT	\N	PRESENT	0
595386	590806	14173T	PARTICIPANT	\N	PRESENT	0
595387	590806	14257W	PARTICIPANT	\N	PRESENT	0
595388	590806	20022R	PARTICIPANT	\N	PRESENT	0
595389	590806	14069U	PARTICIPANT	\N	PRESENT	0
595390	590806	20070A	PARTICIPANT	\N	PRESENT	0
595391	590806	19758L	PARTICIPANT	\N	PRESENT	0
595392	590806	14151M	PARTICIPANT	\N	PRESENT	0
595393	590806	01057W	PARTICIPANT	\N	PRESENT	0
595394	590806	20090E	PARTICIPANT	\N	PRESENT	0
595395	590806	20110Q	PARTICIPANT	\N	PRESENT	0
595396	590806	14053L	PARTICIPANT	\N	PRESENT	0
595397	590806	14217N	PARTICIPANT	\N	PRESENT	0
595398	590806	19447X	PARTICIPANT	\N	PRESENT	0
595399	590806	14327T	PARTICIPANT	\N	PRESENT	0
595400	590806	04045F	PARTICIPANT	\N	PRESENT	0
595401	590806	19333N	PARTICIPANT	\N	PRESENT	0
595402	590806	17637T	PARTICIPANT	\N	PRESENT	0
595403	590806	19711U	PARTICIPANT	\N	PRESENT	0
595404	590806	19826F	PARTICIPANT	\N	PRESENT	0
595405	590806	19735D	PARTICIPANT	\N	PRESENT	0
595406	590806	19681G	PARTICIPANT	\N	PRESENT	0
595407	590806	19820Y	PARTICIPANT	\N	PRESENT	0
595408	590806	20134Y	PARTICIPANT	\N	PRESENT	0
595409	590806	19489J	PARTICIPANT	\N	PRESENT	0
595410	590806	19782L	PARTICIPANT	\N	EXCUSE	0
595411	590806	14281W	PARTICIPANT	\N	EXCUSE	0
595412	590806	19565D	PARTICIPANT	\N	EXCUSE	0
595413	590806	19563B	PARTICIPANT	\N	EXCUSE	0
595414	590806	14071N	PARTICIPANT	\N	EXCUSE	0
595415	590806	20062A	PARTICIPANT	\N	EXCUSE	0
595416	590806	20084G	PARTICIPANT	\N	EXCUSE	0
595417	590807	14231L	PRESIDENT	0	PRESENT	0
595418	590807	05012A	PARTICIPANT	\N	PRESENT	0
595419	590807	04045F	PARTICIPANT	\N	PRESENT	0
595420	590807	14205J	PARTICIPANT	\N	PRESENT	0
595421	590807	08010L	PARTICIPANT	\N	PRESENT	0
595422	590807	20022R	PARTICIPANT	\N	PRESENT	0
595423	590807	14069U	PARTICIPANT	\N	PRESENT	0
595424	590807	19758L	PARTICIPANT	\N	PRESENT	0
595425	590807	20090E	PARTICIPANT	\N	PRESENT	0
595426	590807	20110Q	PARTICIPANT	\N	PRESENT	0
595427	590807	20070A	PARTICIPANT	\N	PRESENT	0
595428	590807	19681G	PARTICIPANT	\N	PRESENT	0
595429	590807	14327T	PARTICIPANT	\N	PRESENT	0
595430	590807	14053L	PARTICIPANT	\N	PRESENT	0
595431	590807	14217N	PARTICIPANT	\N	PRESENT	0
595432	590807	19447X	PARTICIPANT	\N	PRESENT	0
595433	590807	01057W	PARTICIPANT	\N	PRESENT	0
595434	590807	19711U	PARTICIPANT	\N	PRESENT	0
595435	590807	19573D	PARTICIPANT	\N	PRESENT	0
595436	590807	19826F	PARTICIPANT	\N	PRESENT	0
595437	590807	19333N	PARTICIPANT	\N	PRESENT	0
595438	590807	14151M	PARTICIPANT	\N	PRESENT	0
595439	590807	17637T	PARTICIPANT	\N	PRESENT	0
595440	590807	19349W	PARTICIPANT	\N	PRESENT	0
595441	590807	19820Y	PARTICIPANT	\N	PRESENT	0
595442	590807	20134Y	PARTICIPANT	\N	PRESENT	0
595443	590807	14173T	PARTICIPANT	\N	PRESENT	0
572717	570219	19711U	PARTICIPANT	\N	PRESENT	0
572718	570219	04034C	PARTICIPANT	\N	PRESENT	0
572719	570219	11083R	PARTICIPANT	\N	PRESENT	0
572720	570219	11026G	PARTICIPANT	\N	PRESENT	0
572721	570219	14357A	PARTICIPANT	\N	PRESENT	0
572722	570219	10015M	PARTICIPANT	\N	PRESENT	0
572723	570219	14331P	PRESIDENT	0	PRESENT	0
572724	570219	04057K	PARTICIPANT	\N	EXCUSE	0
572725	570219	19507S	PARTICIPANT	\N	PRESENT	0
572726	570219	20128B	PARTICIPANT	\N	PRESENT	1
572727	570219	14073Q	PARTICIPANT	\N	PRESENT	1
572728	570219	14089Y	PARTICIPANT	\N	PRESENT	0
572748	572736	14189C	PARTICIPANT	\N	PRESENT	0
572755	572736	14207L	PARTICIPANT	\N	PRESENT	1
572758	572736	11031D	PARTICIPANT	\N	PRESENT	0
572760	572736	10006L	PARTICIPANT	\N	PRESENT	1
572763	572736	19683J	PRESIDENT	0	PRESENT	0
572764	572736	99004R	PARTICIPANT	\N	PRESENT	0
572766	572736	14229S	PARTICIPANT	\N	PRESENT	0
572770	572736	19563B	PARTICIPANT	\N	EXCUSE	0
585726	585725	19447X	PARTICIPANT	\N	PRESENT	0
585727	585725	19749K	PARTICIPANT	\N	PRESENT	0
585729	585728	19447X	PARTICIPANT	\N	PRESENT	0
589520	589509	20054A	PARTICIPANT	\N	PRESENT	0
589521	589509	11099A	PARTICIPANT	\N	PRESENT	0
589522	589509	20018V	PARTICIPANT	\N	PRESENT	0
589523	589509	20082E	PARTICIPANT	\N	PRESENT	0
589524	589510	20054A	PARTICIPANT	\N	PRESENT	0
589525	589510	11099A	PARTICIPANT	\N	PRESENT	0
589526	589510	20082E	PARTICIPANT	\N	PRESENT	0
589527	589512	20054A	PARTICIPANT	\N	PRESENT	0
589530	589464	20054A	PARTICIPANT	\N	PRESENT	0
589531	589464	20082E	PARTICIPANT	\N	PRESENT	0
589532	589464	11099A	PARTICIPANT	\N	PRESENT	0
589534	589467	20054A	PARTICIPANT	\N	PRESENT	0
589535	589467	20082E	PARTICIPANT	\N	PRESENT	0
589536	589467	11099A	PARTICIPANT	\N	PRESENT	0
589537	589467	14033T	PARTICIPANT	\N	PRESENT	0
589538	589468	20054A	PARTICIPANT	\N	PRESENT	0
589557	589468	20082E	PARTICIPANT	\N	PRESENT	0
589558	589470	20054A	PARTICIPANT	\N	PRESENT	0
589559	589470	20082E	PARTICIPANT	\N	PRESENT	0
589560	589470	14033T	PARTICIPANT	\N	PRESENT	0
591788	590850	86034E	PARTICIPANT	\N	PRESENT	0
591796	590850	20266L	PARTICIPANT	\N	PRESENT	0
591797	590850	12028B	PARTICIPANT	\N	PRESENT	0
591798	590850	19593H	PARTICIPANT	\N	PRESENT	0
591799	590850	19333N	PARTICIPANT	\N	PRESENT	0
591801	590850	19349W	PARTICIPANT	\N	PRESENT	0
591810	590850	20110Q	PARTICIPANT	\N	PRESENT	0
591811	590850	19689Q	PARTICIPANT	\N	PRESENT	0
591812	590850	20142Y	PARTICIPANT	\N	PRESENT	0
591814	590850	20134Y	PARTICIPANT	\N	PRESENT	0
591815	590850	11033F	PARTICIPANT	\N	PRESENT	0
591816	590850	19820Y	PARTICIPANT	\N	PRESENT	0
591817	590850	11067R	PARTICIPANT	\N	PRESENT	0
591819	590850	08012N	PARTICIPANT	\N	PRESENT	0
591822	590850	14151M	PARTICIPANT	\N	PRESENT	0
591826	590850	11041F	PARTICIPANT	\N	PRESENT	0
591827	590850	17779H	PARTICIPANT	\N	PRESENT	0
591828	590850	11065P	PARTICIPANT	\N	PRESENT	0
591829	590850	19347U	PARTICIPANT	\N	PRESENT	0
591830	590850	20130U	PARTICIPANT	\N	PRESENT	0
591831	590850	20092G	PARTICIPANT	\N	PRESENT	0
591832	590850	04085P	PARTICIPANT	\N	PRESENT	0
591833	590850	19711U	PARTICIPANT	\N	PRESENT	0
591834	590850	19687N	PARTICIPANT	\N	PRESENT	0
591835	590850	19758L	PARTICIPANT	\N	PRESENT	0
591836	590850	20058E	PARTICIPANT	\N	PRESENT	0
591837	590850	12041X	PARTICIPANT	\N	PRESENT	0
591838	590850	11056N	PARTICIPANT	\N	PRESENT	0
591839	590850	19565D	PARTICIPANT	\N	PRESENT	0
591840	590850	20046A	PARTICIPANT	\N	PRESENT	0
591841	590850	20102Q	PARTICIPANT	\N	PRESENT	0
591842	590850	17367Q	PARTICIPANT	\N	PRESENT	0
591843	590850	14195A	PARTICIPANT	\N	PRESENT	0
591844	590850	20044X	PARTICIPANT	\N	PRESENT	0
591845	590850	14355X	PARTICIPANT	\N	PRESENT	0
591846	590850	20122U	PARTICIPANT	\N	PRESENT	0
591847	590850	14111D	PARTICIPANT	\N	PRESENT	0
591848	590850	07029T	PARTICIPANT	\N	PRESENT	0
591849	590850	14251Q	PARTICIPANT	\N	PRESENT	0
591850	590850	04057K	PARTICIPANT	\N	PRESENT	0
591851	590850	14038Y	PARTICIPANT	\N	PRESENT	0
591852	590850	20050V	PARTICIPANT	\N	PRESENT	0
591853	590850	19545Y	PARTICIPANT	\N	PRESENT	0
591854	590850	19723Y	PARTICIPANT	\N	PRESENT	0
591855	590850	19563B	PARTICIPANT	\N	PRESENT	0
591856	590850	19467C	PARTICIPANT	\N	PRESENT	0
591857	590850	17589D	PARTICIPANT	\N	PRESENT	0
591858	590850	20056C	PARTICIPANT	\N	PRESENT	0
591859	590850	14033T	PARTICIPANT	\N	PRESENT	0
591860	590850	19782L	PARTICIPANT	\N	PRESENT	0
591861	590850	14249W	PARTICIPANT	\N	PRESENT	0
591862	590850	19741B	PARTICIPANT	\N	PRESENT	0
591863	590850	20174H	PARTICIPANT	\N	PRESENT	0
591864	590850	19399H	PARTICIPANT	\N	PRESENT	0
591865	590850	20104S	PARTICIPANT	\N	PRESENT	0
591866	590850	19057M	PARTICIPANT	\N	PRESENT	0
591867	590839	19443T	PARTICIPANT	\N	PRESENT	0
591868	590839	19565D	PARTICIPANT	\N	PRESENT	0
591869	590839	01058X	PARTICIPANT	\N	PRESENT	1
591870	590839	16685X	PARTICIPANT	\N	PRESENT	0
591871	590839	04042C	PRESIDENT	0	PRESENT	0
591872	590839	11054L	PARTICIPANT	\N	PRESENT	0
591873	590839	11066Q	PARTICIPANT	\N	PRESENT	0
591874	590839	08056B	PARTICIPANT	\N	PRESENT	1
591875	590839	12028B	PARTICIPANT	\N	PRESENT	0
591876	590839	11115U	PARTICIPANT	\N	PRESENT	0
591877	590839	19421M	PARTICIPANT	\N	PRESENT	0
591878	590839	19709B	PARTICIPANT	\N	PRESENT	0
591879	590839	14193X	PRESIDENT	1	PRESENT	0
591880	590839	19347U	PARTICIPANT	\N	PRESENT	0
591881	590839	97011G	PARTICIPANT	\N	PRESENT	0
591882	590839	08061X	PARTICIPANT	\N	PRESENT	0
591883	590839	14249W	PARTICIPANT	\N	PRESENT	0
591884	590839	14059S	PARTICIPANT	\N	PRESENT	0
591885	590839	14097Y	PARTICIPANT	\N	PRESENT	0
591886	590839	08069G	PARTICIPANT	\N	PRESENT	0
591887	590839	20042V	PARTICIPANT	\N	PRESENT	0
591888	590839	01024M	PARTICIPANT	\N	PRESENT	0
591890	590839	19721W	PARTICIPANT	\N	PRESENT	1
591891	590839	14105F	PARTICIPANT	\N	PRESENT	0
591892	590839	20064C	PARTICIPANT	\N	PRESENT	0
591893	590839	14267Y	PARTICIPANT	\N	PRESENT	0
591894	590839	11064N	PARTICIPANT	\N	PRESENT	0
591895	590839	14211G	PARTICIPANT	\N	PRESENT	0
591896	590839	14255U	PRESIDENT	2	PRESENT	0
591897	590839	17023S	PARTICIPANT	\N	PRESENT	0
591898	590850	19591F	PARTICIPANT	\N	PRESENT	0
591899	590850	20150Y	PARTICIPANT	\N	PRESENT	0
591900	590850	20024T	PARTICIPANT	\N	PRESENT	0
591901	590850	11083R	PARTICIPANT	\N	PRESENT	0
591902	590850	14213J	PARTICIPANT	\N	PRESENT	0
591903	590850	20146D	PARTICIPANT	\N	PRESENT	0
591904	590850	19637C	PARTICIPANT	\N	PRESENT	0
591905	590850	19707Y	PARTICIPANT	\N	PRESENT	0
591906	590850	19705W	PARTICIPANT	\N	PRESENT	0
591907	590850	04045F	PARTICIPANT	\N	PRESENT	0
591908	590850	19301E	PARTICIPANT	\N	PRESENT	0
591909	590850	08061X	PARTICIPANT	\N	PRESENT	0
591910	590850	19768N	PARTICIPANT	\N	PRESENT	0
591911	590850	95063L	PARTICIPANT	\N	PRESENT	0
591912	590850	19507S	PARTICIPANT	\N	PRESENT	0
591913	590850	11072N	PARTICIPANT	\N	PRESENT	0
591914	590850	19573D	PARTICIPANT	\N	PRESENT	0
591915	590850	19447X	PARTICIPANT	\N	PRESENT	0
591916	590850	11012A	PARTICIPANT	\N	PRESENT	0
591917	590850	19866P	PARTICIPANT	\N	PRESENT	0
591918	590850	14173T	PARTICIPANT	\N	PRESENT	0
591919	590850	19681G	PARTICIPANT	\N	PRESENT	0
591920	590850	19719D	PARTICIPANT	\N	PRESENT	0
591921	590850	19387D	PARTICIPANT	\N	PRESENT	0
591922	590850	20096L	PARTICIPANT	\N	PRESENT	0
591923	590850	14207L	PARTICIPANT	\N	PRESENT	0
591924	590850	20140W	PARTICIPANT	\N	PRESENT	0
591925	590850	19629C	PARTICIPANT	\N	PRESENT	0
591926	590850	20132W	PARTICIPANT	\N	PRESENT	0
591927	590850	19717B	PARTICIPANT	\N	PRESENT	0
591928	590850	08047A	PARTICIPANT	\N	PRESENT	0
591929	590850	20116W	PARTICIPANT	\N	PRESENT	0
592970	590397	18193Q	PARTICIPANT	\N	PRESENT	0
592971	590397	10006L	PRESIDENT	0	PRESENT	0
592972	590397	19683J	PARTICIPANT	\N	PRESENT	0
592973	590397	20130U	PARTICIPANT	\N	EXCUSE	0
592974	590397	14223L	PARTICIPANT	\N	EXCUSE	0
592975	590397	01034P	PARTICIPANT	\N	PRESENT	1
592976	590397	11045K	PARTICIPANT	\N	PRESENT	0
592977	590397	19415P	PARTICIPANT	\N	PRESENT	0
592978	590397	17965H	PARTICIPANT	\N	PRESENT	0
592979	590397	19715Y	PARTICIPANT	\N	PRESENT	1
592980	590397	19703U	PARTICIPANT	\N	PRESENT	1
592981	590397	11031D	PARTICIPANT	\N	PRESENT	0
592982	590397	20066E	PARTICIPANT	\N	PRESENT	1
592983	590397	19679N	PARTICIPANT	\N	PRESENT	1
592984	590397	11103C	PARTICIPANT	\N	PRESENT	1
592985	590397	14071N	PARTICIPANT	\N	PRESENT	0
592986	590397	19591F	PARTICIPANT	\N	PRESENT	1
592987	590857	04071H	PARTICIPANT	\N	PRESENT	0
592997	590857	19693L	PARTICIPANT	\N	PRESENT	0
592998	590857	11053K	PARTICIPANT	\N	PRESENT	0
592999	590857	19531S	PARTICIPANT	\N	PRESENT	0
593000	590857	19369B	PARTICIPANT	\N	PRESENT	0
593001	590857	20018V	PARTICIPANT	\N	PRESENT	0
593002	590857	19747H	PARTICIPANT	\N	PRESENT	0
593003	590857	17023S	PARTICIPANT	\N	PRESENT	0
593007	590857	19333N	PARTICIPANT	\N	PRESENT	0
593008	590857	20028X	PARTICIPANT	\N	PRESENT	0
593009	590857	04045F	PARTICIPANT	\N	PRESENT	0
593010	590857	14205J	PARTICIPANT	\N	PRESENT	0
593011	590857	20062A	PARTICIPANT	\N	PRESENT	0
593012	590857	18083K	PARTICIPANT	\N	PRESENT	0
593013	590857	14331P	PARTICIPANT	\N	PRESENT	0
593014	590857	11090Q	PARTICIPANT	\N	PRESENT	0
593065	590858	20144B	PARTICIPANT	\N	PRESENT	0
593066	590858	20018V	PARTICIPANT	\N	PRESENT	0
593067	590858	20028X	PARTICIPANT	\N	PRESENT	0
593068	590858	14073Q	PARTICIPANT	\N	PRESENT	0
593069	590858	14205J	PARTICIPANT	\N	PRESENT	0
593070	590858	20062A	PARTICIPANT	\N	PRESENT	0
593071	590858	19533U	PARTICIPANT	\N	PRESENT	0
593072	590858	18083K	PARTICIPANT	\N	PRESENT	0
593073	590858	19467C	PARTICIPANT	\N	PRESENT	0
593074	590858	19747H	PARTICIPANT	\N	PRESENT	0
593075	590858	19693L	PARTICIPANT	\N	PRESENT	0
593091	590858	20134Y	PARTICIPANT	\N	PRESENT	0
593077	590858	19695N	PARTICIPANT	\N	PRESENT	0
593078	590858	19369B	PARTICIPANT	\N	PRESENT	0
593079	590858	20116W	PARTICIPANT	\N	PRESENT	0
593080	590858	19611R	PARTICIPANT	\N	PRESENT	0
593081	590858	20030R	PARTICIPANT	\N	PRESENT	0
593082	590858	11090Q	PARTICIPANT	\N	PRESENT	0
593083	590858	19782L	PARTICIPANT	\N	PRESENT	0
593084	590858	20092G	PARTICIPANT	\N	PRESENT	0
593086	590858	20100N	PARTICIPANT	\N	PRESENT	0
593087	590858	20110Q	PARTICIPANT	\N	PRESENT	0
593088	590858	14331P	PARTICIPANT	\N	PRESENT	0
593089	590858	20034V	PARTICIPANT	\N	PRESENT	0
593090	590858	11065P	PARTICIPANT	\N	PRESENT	0
593092	590858	20142Y	PARTICIPANT	\N	PRESENT	0
593117	590858	20036X	PARTICIPANT	\N	PRESENT	0
593138	590858	14257W	PARTICIPANT	\N	PRESENT	0
593139	590858	14071N	PARTICIPANT	\N	PRESENT	0
593168	590544	19629C	PARTICIPANT	\N	PRESENT	0
593169	590544	95063L	PARTICIPANT	\N	PRESENT	0
593170	590860	20028X	PARTICIPANT	\N	PRESENT	0
593171	590860	20018V	PARTICIPANT	\N	PRESENT	0
593172	590860	14195A	PARTICIPANT	\N	PRESENT	0
593330	593329	14249W	PARTICIPANT	\N	PRESENT	0
593332	593331	19709B	PARTICIPANT	\N	PRESENT	0
593333	593331	11041F	PARTICIPANT	\N	PRESENT	0
593335	593334	14249W	PARTICIPANT	\N	PRESENT	0
593681	593680	14121F	PARTICIPANT	\N	PRESENT	0
593685	593684	14225N	PARTICIPANT	\N	PRESENT	0
593688	593686	11048N	PARTICIPANT	\N	PRESENT	0
593691	593690	14121F	PARTICIPANT	\N	PRESENT	0
593694	593693	19711U	PARTICIPANT	\N	PRESENT	1
593698	593697	20036X	PARTICIPANT	\N	PRESENT	0
593734	593733	20116W	PARTICIPANT	\N	PRESENT	0
593736	593735	20116W	PARTICIPANT	\N	PRESENT	0
593838	593836	19581D	PARTICIPANT	\N	PRESENT	0
593063	590858	12041X	PARTICIPANT	\N	PRESENT	0
593064	590858	19347U	PARTICIPANT	\N	PRESENT	0
593916	593545	11074Q	PARTICIPANT	\N	EXCUSE	0
593917	593545	11110B	PARTICIPANT	\N	PRESENT	1
593918	593545	20050V	PARTICIPANT	\N	PRESENT	1
593919	593545	19691J	PARTICIPANT	\N	PRESENT	1
595212	592995	14089Y	PARTICIPANT	\N	PRESENT	0
593164	590860	12041X	PARTICIPANT	\N	PRESENT	0
593165	590544	10015M	PARTICIPANT	\N	PRESENT	0
593166	590544	08018U	PRESIDENT	0	PRESENT	0
593167	590544	01028R	PARTICIPANT	\N	PRESENT	0
595213	592995	20104S	PARTICIPANT	\N	PRESENT	0
595214	592995	19701S	PARTICIPANT	\N	PRESENT	0
595215	592995	14357A	PARTICIPANT	\N	PRESENT	0
595216	592995	20100N	PARTICIPANT	\N	PRESENT	0
595217	592995	11083R	PARTICIPANT	\N	PRESENT	0
595218	592995	14033T	PARTICIPANT	\N	PRESENT	1
595219	592995	20128B	PARTICIPANT	\N	PRESENT	1
595220	592995	14097Y	PARTICIPANT	\N	PRESENT	0
595221	592995	14073Q	PARTICIPANT	\N	PRESENT	0
595222	592995	12041X	PARTICIPANT	\N	PRESENT	0
595223	592995	19441R	PARTICIPANT	\N	PRESENT	0
595224	592995	14237S	PARTICIPANT	\N	PRESENT	0
595225	592995	14331P	PRESIDENT	0	PRESENT	0
595226	592995	04045F	PARTICIPANT	\N	PRESENT	0
595454	595453	05008E	PARTICIPANT	\N	PRESENT	0
595455	595453	01028R	PARTICIPANT	\N	PRESENT	0
595456	595371	14073Q	PARTICIPANT	\N	PRESENT	0
595457	595371	08012N	PARTICIPANT	\N	PRESENT	0
595458	595371	11043H	PARTICIPANT	\N	PRESENT	0
595459	595368	08012N	PARTICIPANT	\N	PRESENT	0
595460	595368	11043H	PARTICIPANT	\N	PRESENT	0
595559	595558	14255U	PARTICIPANT	\N	PRESENT	0
595611	595609	11056N	PARTICIPANT	\N	PRESENT	0
595728	595502	14111D	PARTICIPANT	\N	PRESENT	0
595729	595502	20074E	PARTICIPANT	\N	PRESENT	0
595730	595502	19585H	PARTICIPANT	\N	PRESENT	0
595731	595502	04047H	PRESIDENT	0	PRESENT	0
595732	595502	19673G	PARTICIPANT	\N	PRESENT	0
595733	595502	19447X	PARTICIPANT	\N	PRESENT	0
595734	595502	05008E	PARTICIPANT	\N	PRESENT	0
595735	595502	11056N	PARTICIPANT	\N	PRESENT	0
595736	595502	07004J	PARTICIPANT	\N	PRESENT	0
595737	595502	14215L	PARTICIPANT	\N	PRESENT	0
595738	595502	08018U	PARTICIPANT	\N	PRESENT	0
595739	595502	20022R	PARTICIPANT	\N	PRESENT	0
595740	595502	11072N	PARTICIPANT	\N	PRESENT	0
595746	595504	11056N	PARTICIPANT	\N	PRESENT	0
595747	595504	07004J	PARTICIPANT	\N	PRESENT	0
595748	595504	20074E	PARTICIPANT	\N	PRESENT	0
595749	595504	04047H	PRESIDENT	0	PRESENT	0
595750	595504	19673G	PARTICIPANT	\N	PRESENT	0
595751	595504	05008E	PARTICIPANT	\N	PRESENT	0
595752	595504	14053L	PARTICIPANT	\N	PRESENT	0
595753	595504	14231L	PARTICIPANT	\N	PRESENT	0
595754	595504	11072N	PARTICIPANT	\N	PRESENT	0
595755	595504	19649G	PARTICIPANT	\N	PRESENT	0
595756	595504	95063L	PARTICIPANT	\N	PRESENT	0
595805	595600	11045K	PARTICIPANT	\N	PRESENT	0
595806	595504	01028R	PARTICIPANT	\N	PRESENT	0
595807	595504	19447X	PARTICIPANT	\N	PRESENT	0
595808	595504	14179A	PARTICIPANT	\N	PRESENT	0
595809	595504	14215L	PARTICIPANT	\N	PRESENT	0
595810	595504	08018U	PARTICIPANT	\N	PRESENT	0
595811	595504	20022R	PARTICIPANT	\N	PRESENT	0
595855	595600	20074E	PARTICIPANT	\N	PRESENT	0
595856	595600	20128B	PARTICIPANT	\N	PRESENT	0
595857	595600	14195A	PARTICIPANT	\N	PRESENT	0
595858	595600	20108W	PARTICIPANT	\N	PRESENT	0
595859	595600	20110Q	PARTICIPANT	\N	PRESENT	0
595860	595600	04085P	PARTICIPANT	\N	PRESENT	0
595861	595600	14179A	PARTICIPANT	\N	PRESENT	0
595862	595600	14107H	PARTICIPANT	\N	PRESENT	0
595863	595600	19725B	PARTICIPANT	\N	PRESENT	0
595864	594908	19798U	PARTICIPANT	\N	PRESENT	0
595865	594908	17965H	PARTICIPANT	\N	PRESENT	0
595866	594908	18193Q	PARTICIPANT	\N	PRESENT	0
595867	594908	14223L	PARTICIPANT	\N	PRESENT	0
595868	594908	14026U	PARTICIPANT	\N	PRESENT	0
595869	594908	20172F	PARTICIPANT	\N	PRESENT	0
571561	571560	17779H	PARTICIPANT	\N	PRESENT	0
571562	571560	20056C	PARTICIPANT	\N	PRESENT	0
571563	570846	19729F	PARTICIPANT	\N	PRESENT	1
571565	570846	19649G	PARTICIPANT	\N	PRESENT	1
571580	570846	20074E	PARTICIPANT	\N	EXCUSE	0
575101	568683	05008E	PARTICIPANT	\N	EXCUSE	0
575102	568683	14219Q	PARTICIPANT	\N	EXCUSE	0
575141	573462	19533U	PARTICIPANT	\N	PRESENT	0
575144	573462	11067R	PARTICIPANT	\N	PRESENT	0
575145	573462	20072C	PARTICIPANT	\N	PRESENT	0
575147	573462	19723Y	PARTICIPANT	\N	PRESENT	0
575148	573462	19735D	PARTICIPANT	\N	PRESENT	0
575149	573462	20128B	PARTICIPANT	\N	PRESENT	0
575151	573462	19663E	PARTICIPANT	\N	PRESENT	0
575154	573462	19503N	PARTICIPANT	\N	PRESENT	0
575155	573462	01048V	PARTICIPANT	\N	EXCUSE	0
575167	575164	20068G	PARTICIPANT	\N	PRESENT	0
575168	575164	05012A	PARTICIPANT	\N	PRESENT	0
575170	575164	14169X	PARTICIPANT	\N	PRESENT	0
579096	579095	19421M	PARTICIPANT	\N	PRESENT	1
579098	579097	19421M	PARTICIPANT	\N	PRESENT	0
580764	579136	14151M	PARTICIPANT	\N	PRESENT	0
580765	579136	19447X	PARTICIPANT	\N	PRESENT	0
580766	579136	20108W	PARTICIPANT	\N	PRESENT	0
580768	579136	11056N	PARTICIPANT	\N	PRESENT	0
580769	579136	17737W	PARTICIPANT	\N	PRESENT	0
580770	579136	95063L	PARTICIPANT	\N	PRESENT	0
580771	579136	20128B	PARTICIPANT	\N	PRESENT	0
580785	579404	19511N	PARTICIPANT	\N	PRESENT	0
580786	579404	08069G	PARTICIPANT	\N	PRESENT	0
580787	579404	19507S	PARTICIPANT	\N	PRESENT	0
580788	579404	14267Y	PARTICIPANT	\N	PRESENT	0
580789	579404	19563B	PARTICIPANT	\N	PRESENT	0
580790	579404	19583F	PARTICIPANT	\N	PRESENT	0
580791	579404	19619A	PARTICIPANT	\N	PRESENT	0
580792	579404	08045X	PARTICIPANT	\N	PRESENT	0
580793	579404	14281W	PARTICIPANT	\N	PRESENT	0
580794	579404	19739H	PARTICIPANT	\N	PRESENT	0
580795	579404	14231L	PARTICIPANT	\N	PRESENT	0
580796	579404	11067R	PARTICIPANT	\N	PRESENT	0
580797	579404	19629C	PARTICIPANT	\N	PRESENT	0
580798	579404	17779H	PARTICIPANT	\N	PRESENT	0
580799	579404	18193Q	PARTICIPANT	\N	PRESENT	0
580800	579404	20084G	PARTICIPANT	\N	PRESENT	0
580801	579136	19585H	PARTICIPANT	\N	PRESENT	0
580802	579136	08018U	PARTICIPANT	\N	PRESENT	0
580806	579404	19715Y	PARTICIPANT	\N	PRESENT	0
580807	579404	20102Q	PARTICIPANT	\N	PRESENT	0
580808	579404	11056N	PARTICIPANT	\N	PRESENT	0
580810	579404	20046A	PARTICIPANT	\N	PRESENT	0
580811	579404	19593H	PARTICIPANT	\N	PRESENT	0
580816	579404	19611R	PARTICIPANT	\N	PRESENT	0
580817	579404	17229F	PARTICIPANT	\N	PRESENT	0
580819	579404	20144B	PARTICIPANT	\N	PRESENT	0
580820	579404	20072C	PARTICIPANT	\N	PRESENT	0
580821	579404	04045F	PARTICIPANT	\N	PRESENT	0
580822	579404	11041F	PARTICIPANT	\N	PRESENT	0
580823	579404	11045K	PARTICIPANT	\N	PRESENT	0
580824	579404	19525U	PARTICIPANT	\N	PRESENT	0
580825	579404	19503N	PARTICIPANT	\N	PRESENT	0
580826	579404	20060X	PARTICIPANT	\N	PRESENT	0
580827	579404	14042U	PARTICIPANT	\N	PRESENT	0
580828	579404	19301E	PARTICIPANT	\N	PRESENT	0
580829	579404	11072N	PARTICIPANT	\N	PRESENT	0
580830	579404	19637C	PARTICIPANT	\N	PRESENT	0
580831	579404	19697Q	PARTICIPANT	\N	PRESENT	0
580832	579404	08061X	PARTICIPANT	\N	PRESENT	0
580833	579404	19782L	PARTICIPANT	\N	PRESENT	0
580834	579404	14021P	PARTICIPANT	\N	PRESENT	0
580835	579404	19649G	PARTICIPANT	\N	PRESENT	0
580836	579404	19683J	PARTICIPANT	\N	PRESENT	0
580837	579404	20114U	PARTICIPANT	\N	PRESENT	0
580838	579404	04008A	PARTICIPANT	\N	PRESENT	0
580839	579404	01058X	PARTICIPANT	\N	PRESENT	0
580840	579404	19575F	PARTICIPANT	\N	PRESENT	0
580841	579404	99004R	PARTICIPANT	\N	PRESENT	0
580842	579404	20076G	PARTICIPANT	\N	PRESENT	0
580843	579404	20082E	PARTICIPANT	\N	PRESENT	0
580844	579404	20078J	PARTICIPANT	\N	PRESENT	0
580845	579404	19251M	PARTICIPANT	\N	PRESENT	0
580846	579404	12016W	PARTICIPANT	\N	PRESENT	0
580847	579404	20028X	PARTICIPANT	\N	PRESENT	0
580848	579404	10015M	PARTICIPANT	\N	PRESENT	0
580849	579404	20064C	PARTICIPANT	\N	PRESENT	0
580850	579404	11080N	PARTICIPANT	\N	PRESENT	0
580851	579404	19820Y	PARTICIPANT	\N	PRESENT	0
580852	579404	14151M	PARTICIPANT	\N	PRESENT	0
580853	579404	01057W	PARTICIPANT	\N	PRESENT	0
580854	579404	19599P	PARTICIPANT	\N	PRESENT	0
580855	579404	01028R	PARTICIPANT	\N	PRESENT	0
580856	579404	19725B	PARTICIPANT	\N	PRESENT	0
580857	579404	19758L	PARTICIPANT	\N	PRESENT	0
580858	579404	19760E	PARTICIPANT	\N	PRESENT	0
580859	579404	11031D	PARTICIPANT	\N	PRESENT	0
580860	579404	20112S	PARTICIPANT	\N	PRESENT	0
580861	579404	04085P	PARTICIPANT	\N	PRESENT	0
580862	579404	20068G	PARTICIPANT	\N	PRESENT	0
580863	579404	19766L	PARTICIPANT	\N	PRESENT	0
580864	579404	20058E	PARTICIPANT	\N	PRESENT	0
580865	579404	19687N	PARTICIPANT	\N	PRESENT	0
580866	579404	20044X	PARTICIPANT	\N	PRESENT	0
580867	579404	19565D	PARTICIPANT	\N	PRESENT	0
580868	579404	20086J	PARTICIPANT	\N	PRESENT	0
580869	579404	20092G	PARTICIPANT	\N	PRESENT	0
580870	579404	14038Y	PARTICIPANT	\N	PRESENT	0
580871	579404	11033F	PARTICIPANT	\N	PRESENT	0
580872	579404	19723Y	PARTICIPANT	\N	PRESENT	0
580873	579404	11065P	PARTICIPANT	\N	PRESENT	0
580874	579404	19467C	PARTICIPANT	\N	PRESENT	0
580875	579404	19347U	PARTICIPANT	\N	PRESENT	0
580876	579404	19447X	PARTICIPANT	\N	PRESENT	0
580877	579404	19573D	PARTICIPANT	\N	PRESENT	0
580878	579404	20070A	PARTICIPANT	\N	PRESENT	0
580879	579404	19673G	PARTICIPANT	\N	PRESENT	0
580880	579404	20098N	PARTICIPANT	\N	PRESENT	0
580881	579404	20056C	PARTICIPANT	\N	PRESENT	0
580882	579404	11099A	PARTICIPANT	\N	PRESENT	0
580883	579404	14041T	PARTICIPANT	\N	PRESENT	0
580884	579404	08018U	PARTICIPANT	\N	PRESENT	0
580885	579404	14033T	PARTICIPANT	\N	PRESENT	0
580886	579404	20174H	PARTICIPANT	\N	PRESENT	0
580887	579404	11083R	PARTICIPANT	\N	PRESENT	0
580888	579404	20128B	PARTICIPANT	\N	PRESENT	0
580889	579404	14195A	PARTICIPANT	\N	PRESENT	0
580890	579404	20050V	PARTICIPANT	\N	PRESENT	0
580891	579404	20180F	PARTICIPANT	\N	PRESENT	0
580892	579404	20096L	PARTICIPANT	\N	PRESENT	0
580893	579404	19719D	PARTICIPANT	\N	PRESENT	0
580894	579404	19866P	PARTICIPANT	\N	PRESENT	0
580895	579404	11012A	PARTICIPANT	\N	PRESENT	0
580896	579404	17367Q	PARTICIPANT	\N	PRESENT	0
580897	579404	19387D	PARTICIPANT	\N	PRESENT	0
580898	579404	19681G	PARTICIPANT	\N	PRESENT	0
580899	579404	20116W	PARTICIPANT	\N	PRESENT	0
580900	579404	19657G	PARTICIPANT	\N	PRESENT	0
580901	579404	19553Y	PARTICIPANT	\N	PRESENT	0
580902	579404	14107H	PARTICIPANT	\N	PRESENT	0
580903	579404	05012A	PARTICIPANT	\N	PRESENT	0
580904	579404	19717B	PARTICIPANT	\N	PRESENT	0
580905	579404	20132W	PARTICIPANT	\N	PRESENT	0
580906	579404	19768N	PARTICIPANT	\N	PRESENT	0
580907	579404	14147R	PARTICIPANT	\N	PRESENT	0
580908	579404	14251Q	PARTICIPANT	\N	PRESENT	0
580909	579404	20100N	PARTICIPANT	\N	PRESENT	0
580910	579404	20090E	PARTICIPANT	\N	PRESENT	0
580911	579404	14031R	PARTICIPANT	\N	PRESENT	0
580912	579404	08047A	PARTICIPANT	\N	PRESENT	0
580913	579404	14257W	PARTICIPANT	\N	PRESENT	0
580914	579404	17737W	PARTICIPANT	\N	PRESENT	0
580915	579404	19699S	PARTICIPANT	\N	PRESENT	0
580916	579404	04033B	PARTICIPANT	\N	PRESENT	0
580917	579404	14089Y	PARTICIPANT	\N	PRESENT	0
580918	579404	11090Q	PARTICIPANT	\N	PRESENT	0
580919	579404	19369B	PARTICIPANT	\N	PRESENT	0
580920	579404	19335Q	PARTICIPANT	\N	PRESENT	0
580921	579404	19685L	PARTICIPANT	\N	PRESENT	0
580922	579404	20148F	PARTICIPANT	\N	PRESENT	0
595444	590807	19489J	PARTICIPANT	\N	PRESENT	0
595445	590807	14257W	PARTICIPANT	\N	PRESENT	0
595446	590807	19782L	PARTICIPANT	\N	EXCUSE	0
595447	590807	14281W	PARTICIPANT	\N	EXCUSE	0
595448	590807	19565D	PARTICIPANT	\N	EXCUSE	0
595449	590807	19563B	PARTICIPANT	\N	EXCUSE	0
595450	590807	14071N	PARTICIPANT	\N	EXCUSE	0
595451	590807	20062A	PARTICIPANT	\N	EXCUSE	0
595452	590807	20084G	PARTICIPANT	\N	EXCUSE	0
595462	595461	19741B	PARTICIPANT	\N	PRESENT	0
595464	595463	19741B	PARTICIPANT	\N	PRESENT	0
595466	595465	08009T	PARTICIPANT	\N	PRESENT	0
595467	595465	20044X	PARTICIPANT	\N	PRESENT	0
595469	595468	11053K	PARTICIPANT	\N	PRESENT	0
595471	595470	08009T	PARTICIPANT	\N	PRESENT	0
595472	595470	20044X	PARTICIPANT	\N	PRESENT	0
595475	595473	11097X	PARTICIPANT	\N	PRESENT	0
595476	595474	19479G	PARTICIPANT	\N	PRESENT	0
595478	595477	11074Q	PARTICIPANT	\N	PRESENT	0
595479	595477	19349W	PARTICIPANT	\N	PRESENT	0
595482	595481	19479G	PARTICIPANT	\N	PRESENT	0
595484	595483	11074Q	PARTICIPANT	\N	PRESENT	0
595485	595483	19349W	PARTICIPANT	\N	PRESENT	0
595491	595490	20086J	PARTICIPANT	\N	PRESENT	0
595493	595492	19711U	PARTICIPANT	\N	PRESENT	0
595495	595494	19531S	PARTICIPANT	\N	PRESENT	0
595496	595494	19762G	PARTICIPANT	\N	PRESENT	0
595498	595497	19531S	PARTICIPANT	\N	PRESENT	0
595499	595497	19762G	PARTICIPANT	\N	PRESENT	0
595501	595500	14173T	PARTICIPANT	\N	PRESENT	0
595505	595503	14173T	PARTICIPANT	\N	PRESENT	0
595513	595512	14173T	PARTICIPANT	\N	PRESENT	0
595518	595516	11048N	PARTICIPANT	\N	PRESENT	0
595533	595531	19711U	PARTICIPANT	\N	PRESENT	0
595554	595553	19335Q	PARTICIPANT	\N	PRESENT	0
595557	595555	19335Q	PARTICIPANT	\N	PRESENT	0
595561	595560	11048N	PARTICIPANT	\N	PRESENT	0
595563	595562	20086J	PARTICIPANT	\N	PRESENT	0
595619	595617	08012N	PARTICIPANT	\N	PRESENT	1
595814	595504	19629C	PARTICIPANT	\N	PRESENT	1
595815	595504	19725B	PARTICIPANT	\N	PRESENT	1
595816	595504	19489J	PARTICIPANT	\N	PRESENT	1
595817	595504	14147R	PARTICIPANT	\N	PRESENT	1
595818	595504	14107H	PARTICIPANT	\N	PRESENT	1
595812	595504	19543W	PARTICIPANT	\N	PRESENT	1
595813	595504	20110Q	PARTICIPANT	\N	PRESENT	1
595819	595504	19367Y	PARTICIPANT	\N	PRESENT	0
595820	595504	19295A	PARTICIPANT	\N	PRESENT	0
595821	595504	10006L	PARTICIPANT	\N	PRESENT	0
595822	595504	14042U	PARTICIPANT	\N	PRESENT	0
595823	595504	20172F	PARTICIPANT	\N	PRESENT	0
595824	595504	14355X	PARTICIPANT	\N	PRESENT	0
595825	595504	14026U	PARTICIPANT	\N	PRESENT	0
595826	595504	19691J	PARTICIPANT	\N	PRESENT	0
595827	595504	19553Y	PARTICIPANT	\N	PRESENT	0
595828	595504	19569H	PARTICIPANT	\N	PRESENT	0
595829	595504	19683J	PARTICIPANT	\N	PRESENT	0
595830	595504	18193Q	PARTICIPANT	\N	PRESENT	0
595831	595504	11067R	PARTICIPANT	\N	PRESENT	0
595832	595504	14223L	PARTICIPANT	\N	PRESENT	0
595833	595504	17965H	PARTICIPANT	\N	PRESENT	0
595834	595504	19679N	PARTICIPANT	\N	PRESENT	0
595835	595504	19798U	PARTICIPANT	\N	PRESENT	0
595836	595504	19713W	PARTICIPANT	\N	PRESENT	1
595837	595504	19703U	PARTICIPANT	\N	PRESENT	0
595838	595504	19663E	PARTICIPANT	\N	PRESENT	1
595839	595504	14213J	PARTICIPANT	\N	PRESENT	1
595840	595504	20066E	PARTICIPANT	\N	PRESENT	1
595841	595504	19697Q	PARTICIPANT	\N	PRESENT	1
595842	595504	17779H	PARTICIPANT	\N	PRESENT	1
595843	595504	19657G	PARTICIPANT	\N	PRESENT	1
595844	595504	11097X	PARTICIPANT	\N	PRESENT	1
596238	596236	14030Q	PARTICIPANT	\N	PRESENT	0
596239	596236	19621T	PARTICIPANT	\N	PRESENT	0
596240	596236	14109K	PARTICIPANT	\N	PRESENT	0
596241	596236	19719D	PARTICIPANT	\N	PRESENT	1
596242	596237	14030Q	PARTICIPANT	\N	PRESENT	0
596243	596237	19621T	PARTICIPANT	\N	PRESENT	0
596244	596237	20132W	PARTICIPANT	\N	PRESENT	1
596245	596237	14109K	PARTICIPANT	\N	PRESENT	0
596250	596247	19399H	PARTICIPANT	\N	PRESENT	0
596251	596248	19399H	PARTICIPANT	\N	PRESENT	0
596252	596247	19611R	PARTICIPANT	\N	PRESENT	0
596267	596261	20086J	PARTICIPANT	\N	PRESENT	0
596268	596261	20042V	PARTICIPANT	\N	PRESENT	0
596269	596261	14105F	PARTICIPANT	\N	PRESENT	0
596270	596261	19782L	PARTICIPANT	\N	PRESENT	0
596271	596261	20090E	PARTICIPANT	\N	PRESENT	0
596272	596261	01024M	PARTICIPANT	\N	PRESENT	0
596273	596261	20174H	PARTICIPANT	\N	PRESENT	0
596274	596261	01025N	PARTICIPANT	\N	PRESENT	0
596275	596261	19820Y	PARTICIPANT	\N	PRESENT	0
596276	596261	20126Y	PARTICIPANT	\N	PRESENT	0
596277	596261	19723Y	PARTICIPANT	\N	PRESENT	0
596278	596261	08015R	PARTICIPANT	\N	PRESENT	0
596279	596261	19441R	PARTICIPANT	\N	PRESENT	0
596280	596261	11097X	PARTICIPANT	\N	PRESENT	0
596281	596261	04045F	PARTICIPANT	\N	PRESENT	0
596448	596446	95063L	PARTICIPANT	\N	PRESENT	0
596450	596446	19621T	PARTICIPANT	\N	PRESENT	0
596451	596446	20056C	PARTICIPANT	\N	PRESENT	0
596452	596446	14255U	PARTICIPANT	\N	PRESENT	0
596454	596453	95063L	PARTICIPANT	\N	PRESENT	0
596455	596453	19621T	PARTICIPANT	\N	PRESENT	0
596456	596453	14255U	PARTICIPANT	\N	PRESENT	0
596457	596453	20056C	PARTICIPANT	\N	PRESENT	0
596458	596453	11083R	PARTICIPANT	\N	PRESENT	0
596459	596453	14073Q	PARTICIPANT	\N	PRESENT	0
596460	596453	11064N	PARTICIPANT	\N	PRESENT	0
596461	596453	19543W	PARTICIPANT	\N	PRESENT	0
596630	596612	17965H	PARTICIPANT	\N	PRESENT	0
596631	596612	19349W	PARTICIPANT	\N	PRESENT	0
596632	596612	20044X	PARTICIPANT	\N	PRESENT	0
596633	596612	20098N	PARTICIPANT	\N	PRESENT	0
596634	596612	20026V	PARTICIPANT	\N	PRESENT	0
596635	596612	20058E	PARTICIPANT	\N	PRESENT	0
596639	596612	19611R	PARTICIPANT	\N	PRESENT	0
596640	596612	14030Q	PARTICIPANT	\N	PRESENT	0
596642	596612	19251M	PARTICIPANT	\N	PRESENT	0
596643	596612	20074E	PARTICIPANT	\N	PRESENT	0
596644	596612	19723Y	PARTICIPANT	\N	PRESENT	0
596645	596612	14213J	PARTICIPANT	\N	PRESENT	0
596646	596612	14249W	PARTICIPANT	\N	PRESENT	0
596649	596648	20086J	PARTICIPANT	\N	PRESENT	0
596650	596612	19585H	PARTICIPANT	\N	PRESENT	0
596651	596612	20056C	PARTICIPANT	\N	PRESENT	0
596657	596656	20086J	PARTICIPANT	\N	PRESENT	1
596883	595486	14189C	PARTICIPANT	\N	PRESENT	0
596884	595486	14089Y	PARTICIPANT	\N	PRESENT	0
596885	595486	20104S	PARTICIPANT	\N	PRESENT	0
596886	595486	14357A	PARTICIPANT	\N	EXCUSE	0
596887	595486	20100N	PARTICIPANT	\N	PRESENT	0
596889	595486	04035D	PARTICIPANT	\N	EXCUSE	0
596890	595486	11083R	PARTICIPANT	\N	PRESENT	0
596891	595486	14026U	PARTICIPANT	\N	EXCUSE	0
596893	595486	19725B	PARTICIPANT	\N	PRESENT	0
596894	595486	20128B	PARTICIPANT	\N	PRESENT	0
596895	595486	19333N	PARTICIPANT	\N	PRESENT	0
596896	595486	19531S	PARTICIPANT	\N	PRESENT	0
596897	595486	14073Q	PARTICIPANT	\N	PRESENT	0
596898	595486	11026G	PARTICIPANT	\N	PRESENT	0
596899	595486	08034U	PARTICIPANT	\N	PRESENT	0
596900	595486	12016W	PARTICIPANT	\N	PRESENT	1
596901	595486	14001X	PARTICIPANT	\N	PRESENT	0
596902	595486	04070G	PARTICIPANT	\N	PRESENT	0
596903	595486	14237S	PARTICIPANT	\N	PRESENT	1
596904	595486	14331P	PRESIDENT	0	PRESENT	0
596905	595486	10015M	PARTICIPANT	\N	PRESENT	0
596906	595486	04045F	PARTICIPANT	\N	PRESENT	0
597539	597538	19515S	PRESIDENT	0	PRESENT	0
597540	597538	19575F	PARTICIPANT	\N	PRESENT	0
597541	597538	14083S	PARTICIPANT	\N	PRESENT	0
597542	597538	20060X	PARTICIPANT	\N	PRESENT	0
597543	597538	19467C	PARTICIPANT	\N	PRESENT	0
597544	597538	14031R	PARTICIPANT	\N	PRESENT	0
597545	597538	20092G	PARTICIPANT	\N	PRESENT	0
597546	597538	19762G	PARTICIPANT	\N	PRESENT	0
597547	597538	14026U	PARTICIPANT	\N	PRESENT	1
597548	597538	19671E	PARTICIPANT	\N	PRESENT	1
597549	597538	20082E	PARTICIPANT	\N	PRESENT	1
597550	597538	14030Q	PARTICIPANT	\N	PRESENT	0
570675	568176	04047H	PRESIDENT	0	PRESENT	0
570676	566533	19631V	PARTICIPANT	\N	PRESENT	0
570677	566533	11097X	PARTICIPANT	\N	PRESENT	0
570678	566533	11099A	PARTICIPANT	\N	PRESENT	0
570679	566533	20118Y	PARTICIPANT	\N	PRESENT	0
570680	566533	14205J	PARTICIPANT	\N	PRESENT	0
570681	566533	11065P	PARTICIPANT	\N	PRESENT	0
570682	566533	11090Q	PARTICIPANT	\N	PRESENT	0
570684	566533	20180F	PARTICIPANT	\N	PRESENT	0
570685	566533	14169X	PARTICIPANT	\N	PRESENT	0
570686	566533	11064N	PARTICIPANT	\N	PRESENT	0
570687	566533	14097Y	PARTICIPANT	\N	PRESENT	0
570688	566533	20106U	PARTICIPANT	\N	PRESENT	0
570703	566533	19711U	PARTICIPANT	\N	PRESENT	0
570705	566533	19747H	PARTICIPANT	\N	PRESENT	0
570706	566533	19699S	PARTICIPANT	\N	PRESENT	0
570707	566533	14249W	PARTICIPANT	\N	PRESENT	0
570708	566533	97011G	PARTICIPANT	\N	PRESENT	0
570709	566533	20112S	PARTICIPANT	\N	PRESENT	0
570714	566533	20116W	PARTICIPANT	\N	PRESENT	0
570715	566533	14187A	PARTICIPANT	\N	PRESENT	0
570716	566533	20144B	PARTICIPANT	\N	PRESENT	0
570717	566533	19701S	PARTICIPANT	\N	PRESENT	0
570718	566533	10006L	PARTICIPANT	\N	PRESENT	0
570719	566533	19533U	PARTICIPANT	\N	PRESENT	0
570720	566533	20142Y	PARTICIPANT	\N	PRESENT	0
570721	566533	08069G	PARTICIPANT	\N	PRESENT	0
570722	566533	20136B	PARTICIPANT	\N	PRESENT	0
570723	566533	14357A	PARTICIPANT	\N	PRESENT	0
570724	566533	20048C	PARTICIPANT	\N	PRESENT	0
570725	566533	14327T	PARTICIPANT	\N	PRESENT	0
570726	566533	20082E	PARTICIPANT	\N	PRESENT	0
570727	566533	08010L	PARTICIPANT	\N	PRESENT	0
570728	566533	14038Y	PARTICIPANT	\N	PRESENT	0
570729	566533	08034U	PARTICIPANT	\N	PRESENT	0
570730	566533	11033F	PARTICIPANT	\N	PRESENT	0
570734	566533	01028R	PARTICIPANT	\N	PRESENT	0
570735	566533	14041T	PARTICIPANT	\N	PRESENT	0
570736	566533	14030Q	PARTICIPANT	\N	PRESENT	0
570737	566533	14231L	PARTICIPANT	\N	PRESENT	0
570743	566533	20052X	PARTICIPANT	\N	PRESENT	0
570750	566533	07004J	PARTICIPANT	\N	PRESENT	0
570765	566533	19695N	PARTICIPANT	\N	PRESENT	0
570785	566533	20130U	PARTICIPANT	\N	PRESENT	0
570855	566534	14031R	PARTICIPANT	\N	PRESENT	0
570856	566534	11097X	PARTICIPANT	\N	PRESENT	0
570857	566534	19826F	PARTICIPANT	\N	PRESENT	0
570858	566534	19515S	PARTICIPANT	\N	PRESENT	0
570859	566534	20102Q	PARTICIPANT	\N	PRESENT	0
570860	566534	14219Q	PARTICIPANT	\N	PRESENT	0
570861	566534	07029T	PARTICIPANT	\N	PRESENT	0
570862	566534	19399H	PARTICIPANT	\N	PRESENT	0
570863	566534	14038Y	PARTICIPANT	\N	PRESENT	0
570864	566534	20082E	PARTICIPANT	\N	PRESENT	0
570865	566534	20152B	PARTICIPANT	\N	PRESENT	0
570866	566534	14187A	PARTICIPANT	\N	PRESENT	0
570867	566534	19551W	PARTICIPANT	\N	PRESENT	0
570868	566534	17367Q	PARTICIPANT	\N	PRESENT	0
570869	566534	14033T	PARTICIPANT	\N	PRESENT	0
570870	566534	19533U	PARTICIPANT	\N	PRESENT	0
570871	566534	19631V	PARTICIPANT	\N	PRESENT	0
570872	566534	20080C	PARTICIPANT	\N	PRESENT	0
570873	566534	20076G	PARTICIPANT	\N	PRESENT	0
570874	566534	11099A	PARTICIPANT	\N	PRESENT	0
570875	566534	18083K	PARTICIPANT	\N	PRESENT	0
570876	566534	20092G	PARTICIPANT	\N	PRESENT	0
570877	566534	11033F	PARTICIPANT	\N	PRESENT	0
570878	566534	11065P	PARTICIPANT	\N	PRESENT	0
570879	566534	14215L	PARTICIPANT	\N	PRESENT	0
570880	566534	19599P	PARTICIPANT	\N	PRESENT	0
570881	566534	19549D	PARTICIPANT	\N	PRESENT	0
570882	566534	19333N	PARTICIPANT	\N	PRESENT	0
570883	566534	04043D	PARTICIPANT	\N	PRESENT	0
570884	566534	04085P	PARTICIPANT	\N	PRESENT	0
570885	566534	20072C	PARTICIPANT	\N	PRESENT	0
570886	566534	04045F	PARTICIPANT	\N	PRESENT	0
570887	566534	14207L	PARTICIPANT	\N	PRESENT	0
570888	566534	19681G	PARTICIPANT	\N	PRESENT	0
570889	566534	04034C	PARTICIPANT	\N	PRESENT	0
570890	566534	11090Q	PARTICIPANT	\N	PRESENT	0
570891	566534	14205J	PARTICIPANT	\N	PRESENT	0
570892	566534	19749K	PARTICIPANT	\N	PRESENT	0
570893	566534	19619A	PARTICIPANT	\N	PRESENT	0
570894	566534	20052X	PARTICIPANT	\N	PRESENT	0
570895	566534	11053K	PARTICIPANT	\N	PRESENT	0
570896	566534	17229F	PARTICIPANT	\N	PRESENT	0
570897	566534	19369B	PARTICIPANT	\N	PRESENT	0
570898	566534	14030Q	PARTICIPANT	\N	PRESENT	0
570899	566534	20112S	PARTICIPANT	\N	PRESENT	0
570900	566534	08034U	PARTICIPANT	\N	PRESENT	0
570901	566534	20116W	PARTICIPANT	\N	PRESENT	0
570850	566534	11070L	PARTICIPANT	\N	PRESENT	0
570854	566534	99004R	PARTICIPANT	\N	PRESENT	0
570902	566534	19747H	PARTICIPANT	\N	PRESENT	0
570903	566534	19503N	PARTICIPANT	\N	PRESENT	0
570904	566534	04057K	PARTICIPANT	\N	PRESENT	0
570905	566534	19347U	PARTICIPANT	\N	PRESENT	0
570906	566534	19695N	PARTICIPANT	\N	PRESENT	0
570907	566534	19611R	PARTICIPANT	\N	PRESENT	0
570908	566534	14169X	PARTICIPANT	\N	PRESENT	0
570909	566534	11031D	PARTICIPANT	\N	PRESENT	0
570910	566534	08010L	PARTICIPANT	\N	PRESENT	0
570911	566534	20120S	PARTICIPANT	\N	PRESENT	0
570912	566534	20130U	PARTICIPANT	\N	PRESENT	0
570913	566534	14097Y	PARTICIPANT	\N	PRESENT	0
570915	566534	20136B	PARTICIPANT	\N	PRESENT	0
570916	566534	19701S	PARTICIPANT	\N	PRESENT	0
570917	566534	14083S	PARTICIPANT	\N	PRESENT	0
570918	566534	20020P	PARTICIPANT	\N	PRESENT	0
570919	566534	14357A	PARTICIPANT	\N	PRESENT	0
570926	566534	20134Y	PARTICIPANT	\N	PRESENT	0
570939	566534	20100N	PARTICIPANT	\N	PRESENT	0
570941	566534	19760E	PARTICIPANT	\N	PRESENT	0
570942	566534	20142Y	PARTICIPANT	\N	PRESENT	0
570951	566534	17637T	PARTICIPANT	\N	PRESENT	0
570952	566534	19721W	PARTICIPANT	\N	PRESENT	0
570953	566534	19711U	PARTICIPANT	\N	PRESENT	0
570954	566534	11012A	PARTICIPANT	\N	PRESENT	0
570959	566534	19689Q	PARTICIPANT	\N	PRESENT	0
570960	566534	19413M	PARTICIPANT	\N	PRESENT	0
570962	566534	19687N	PARTICIPANT	\N	PRESENT	0
570963	566534	20144B	PARTICIPANT	\N	PRESENT	0
570965	566534	95063L	PARTICIPANT	\N	PRESENT	0
570969	566534	01028R	PARTICIPANT	\N	PRESENT	0
570972	566534	19647E	PARTICIPANT	\N	PRESENT	0
570973	566534	10015M	PARTICIPANT	\N	PRESENT	0
570974	566534	20110Q	PARTICIPANT	\N	PRESENT	0
570983	566534	20118Y	PARTICIPANT	\N	PRESENT	0
570984	566534	14251Q	PARTICIPANT	\N	PRESENT	0
570988	566534	19697Q	PARTICIPANT	\N	PRESENT	0
570989	566534	14231L	PARTICIPANT	\N	PRESENT	0
571039	566535	99004R	PARTICIPANT	\N	PRESENT	0
571040	566535	19695N	PARTICIPANT	\N	PRESENT	0
571041	566535	19333N	PARTICIPANT	\N	PRESENT	0
571042	566535	11033F	PARTICIPANT	\N	PRESENT	0
571043	566535	14187A	PARTICIPANT	\N	PRESENT	0
571044	566535	20120S	PARTICIPANT	\N	PRESENT	0
571045	566535	20134Y	PARTICIPANT	\N	PRESENT	0
571046	566535	20076G	PARTICIPANT	\N	PRESENT	0
571047	566535	19551W	PARTICIPANT	\N	PRESENT	0
571048	566535	19533U	PARTICIPANT	\N	PRESENT	0
571049	566535	18083K	PARTICIPANT	\N	PRESENT	0
571050	566535	19413M	PARTICIPANT	\N	PRESENT	0
571051	566535	17229F	PARTICIPANT	\N	PRESENT	0
571052	566535	14031R	PARTICIPANT	\N	PRESENT	0
571053	566535	11090Q	PARTICIPANT	\N	PRESENT	0
571054	566535	19721W	PARTICIPANT	\N	PRESENT	0
571055	566535	20118Y	PARTICIPANT	\N	PRESENT	0
571056	566535	19826F	PARTICIPANT	\N	PRESENT	0
571057	566535	14038Y	PARTICIPANT	\N	PRESENT	0
571058	566535	17367Q	PARTICIPANT	\N	PRESENT	0
571059	566535	20130U	PARTICIPANT	\N	PRESENT	0
571060	566535	19681G	PARTICIPANT	\N	PRESENT	0
571061	566535	19619A	PARTICIPANT	\N	PRESENT	0
571062	566535	19631V	PARTICIPANT	\N	PRESENT	0
571063	566535	19549D	PARTICIPANT	\N	PRESENT	0
571064	566535	04045F	PARTICIPANT	\N	PRESENT	0
571065	566535	14357A	PARTICIPANT	\N	PRESENT	0
571066	566535	14215L	PARTICIPANT	\N	PRESENT	0
571067	566535	20112S	PARTICIPANT	\N	PRESENT	0
571068	566535	20102Q	PARTICIPANT	\N	PRESENT	0
595870	594908	19723Y	PARTICIPANT	\N	PRESENT	0
595871	594908	19703U	PARTICIPANT	\N	PRESENT	0
595872	594908	20066E	PARTICIPANT	\N	PRESENT	0
595873	594908	14042U	PARTICIPANT	\N	PRESENT	0
595874	594908	19367Y	PARTICIPANT	\N	PRESENT	0
595875	594908	10006L	PRESIDENT	0	PRESENT	0
595876	594908	19760E	PARTICIPANT	\N	PRESENT	0
595877	595600	20024T	PARTICIPANT	\N	PRESENT	0
595878	595600	20090E	PARTICIPANT	\N	PRESENT	0
595879	595600	19826F	PARTICIPANT	\N	PRESENT	0
595880	595348	11048N	PARTICIPANT	\N	PRESENT	0
595881	595348	19711U	PRESIDENT	0	PRESENT	0
595882	595348	20036X	PARTICIPANT	\N	PRESENT	0
595883	595348	20252E	PARTICIPANT	\N	PRESENT	0
595884	595348	20116W	PARTICIPANT	\N	PRESENT	0
595885	595348	11040E	PARTICIPANT	\N	PRESENT	0
595886	595348	14327T	PARTICIPANT	\N	PRESENT	0
595887	595348	19349W	PARTICIPANT	\N	PRESENT	0
595888	595600	19581D	PARTICIPANT	\N	PRESENT	0
595889	595348	99004R	PARTICIPANT	\N	PRESENT	0
595890	594908	11067R	PARTICIPANT	\N	EXCUSE	0
595891	594908	04057K	PARTICIPANT	\N	EXCUSE	0
595892	594908	19295A	PARTICIPANT	\N	EXCUSE	0
595893	594908	17779H	PARTICIPANT	\N	EXCUSE	0
595894	595600	14021P	PARTICIPANT	\N	PRESENT	0
595895	595600	19739H	PARTICIPANT	\N	PRESENT	0
595896	595348	14189C	PARTICIPANT	\N	PRESENT	0
595897	595348	20080C	PARTICIPANT	\N	PRESENT	0
595898	595348	19667J	PARTICIPANT	\N	PRESENT	0
595899	595348	11070L	PARTICIPANT	\N	PRESENT	0
595900	595600	19866P	PARTICIPANT	\N	PRESENT	0
595901	595600	11012A	PARTICIPANT	\N	PRESENT	0
595902	595348	19479G	PARTICIPANT	\N	PRESENT	0
595903	595348	07029T	PARTICIPANT	\N	PRESENT	0
595904	595600	04047H	PARTICIPANT	\N	PRESENT	0
595905	595600	95063L	PARTICIPANT	\N	PRESENT	0
595906	595348	04071H	PARTICIPANT	\N	PRESENT	0
595907	595348	01057W	PARTICIPANT	\N	PRESENT	0
595908	595600	08056B	PARTICIPANT	\N	PRESENT	0
595909	595600	14267Y	PARTICIPANT	\N	PRESENT	0
595910	595600	11056N	PARTICIPANT	\N	PRESENT	0
595911	595600	14173T	PARTICIPANT	\N	PRESENT	0
595912	595600	19758L	PARTICIPANT	\N	PRESENT	0
595913	595600	16685X	PARTICIPANT	\N	PRESENT	0
595914	595348	14083S	PARTICIPANT	\N	PRESENT	0
595915	595600	14207L	PARTICIPANT	\N	PRESENT	0
595916	595600	19798U	PARTICIPANT	\N	PRESENT	0
595917	595600	19369B	PARTICIPANT	\N	PRESENT	0
595918	595348	08034U	PARTICIPANT	\N	PRESENT	0
595919	595600	14053L	PARTICIPANT	\N	PRESENT	0
595920	595600	18083K	PARTICIPANT	\N	PRESENT	0
595921	595348	19335Q	PARTICIPANT	\N	PRESENT	0
595922	595600	19679N	PARTICIPANT	\N	PRESENT	0
595923	595600	19333N	PARTICIPANT	\N	PRESENT	0
595924	595600	18193Q	PARTICIPANT	\N	PRESENT	0
595925	595600	17965H	PARTICIPANT	\N	PRESENT	0
595926	595600	14211G	PARTICIPANT	\N	PRESENT	0
595927	595600	19583F	PARTICIPANT	\N	PRESENT	0
595928	595600	20098N	PARTICIPANT	\N	PRESENT	0
595929	595600	20174H	PARTICIPANT	\N	PRESENT	0
595930	595600	19565D	PARTICIPANT	\N	PRESENT	0
595931	595348	20126Y	PARTICIPANT	\N	PRESENT	0
595932	595348	19531S	PARTICIPANT	\N	PRESENT	0
595933	595600	14111D	PARTICIPANT	\N	PRESENT	0
595934	595600	20142Y	PARTICIPANT	\N	PRESENT	0
596075	595348	11012A	PARTICIPANT	\N	EXCUSE	0
596118	595601	19421M	PARTICIPANT	\N	PRESENT	0
596119	595601	20136B	PARTICIPANT	\N	PRESENT	0
596120	595601	20022R	PARTICIPANT	\N	PRESENT	0
596121	595601	19581D	PARTICIPANT	\N	PRESENT	0
596122	595348	11026G	PARTICIPANT	\N	PRESENT	0
596123	595601	19533U	PARTICIPANT	\N	PRESENT	0
596124	595601	19367Y	PARTICIPANT	\N	PRESENT	0
596125	595601	19387D	PARTICIPANT	\N	PRESENT	0
596126	595601	19866P	PARTICIPANT	\N	PRESENT	0
596127	595601	07004J	PARTICIPANT	\N	PRESENT	0
596128	595601	19563B	PARTICIPANT	\N	PRESENT	0
596129	595601	19681G	PARTICIPANT	\N	PRESENT	0
596130	595601	19673G	PARTICIPANT	\N	PRESENT	0
596131	595601	19447X	PARTICIPANT	\N	PRESENT	0
596132	595601	20102Q	PARTICIPANT	\N	PRESENT	0
596133	595601	20092G	PARTICIPANT	\N	PRESENT	0
596134	595601	20266L	PARTICIPANT	\N	PRESENT	0
596135	595601	01058X	PARTICIPANT	\N	PRESENT	0
596136	595601	14195A	PARTICIPANT	\N	PRESENT	0
596137	595601	19507S	PARTICIPANT	\N	PRESENT	0
596138	595601	19565D	PARTICIPANT	\N	PRESENT	0
596139	595601	20056C	PARTICIPANT	\N	PRESENT	0
596140	595601	19527W	PARTICIPANT	\N	PRESENT	0
596141	595601	19383Y	PARTICIPANT	\N	PRESENT	0
596142	595601	11031D	PARTICIPANT	\N	PRESENT	0
596143	595601	20024T	PARTICIPANT	\N	PRESENT	0
596144	595601	14147R	PARTICIPANT	\N	PRESENT	0
596145	595601	14189C	PARTICIPANT	\N	PRESENT	0
596149	595601	19479G	PARTICIPANT	\N	PRESENT	0
596150	595601	08056B	PARTICIPANT	\N	PRESENT	0
596151	595601	19573D	PARTICIPANT	\N	PRESENT	0
596152	595601	20044X	PARTICIPANT	\N	PRESENT	0
596153	595601	20116W	PARTICIPANT	\N	PRESENT	0
596154	595601	19782L	PARTICIPANT	\N	PRESENT	0
596155	595601	19747H	PARTICIPANT	\N	PRESENT	0
596156	595601	17637T	PARTICIPANT	\N	PRESENT	0
596157	595601	11043H	PARTICIPANT	\N	PRESENT	0
596158	595601	19549D	PARTICIPANT	\N	PRESENT	0
596159	595601	10015M	PARTICIPANT	\N	PRESENT	0
596160	595601	11026G	PARTICIPANT	\N	PRESENT	0
596161	595601	19691J	PARTICIPANT	\N	PRESENT	0
596162	595601	20046A	PARTICIPANT	\N	PRESENT	0
596163	595601	14105F	PARTICIPANT	\N	PRESENT	0
596164	595601	14107H	PARTICIPANT	\N	PRESENT	0
596165	595601	20090E	PARTICIPANT	\N	PRESENT	0
596166	595601	19503N	PARTICIPANT	\N	PRESENT	0
596167	595601	19685L	PARTICIPANT	\N	PRESENT	0
596168	595601	19543W	PARTICIPANT	\N	PRESENT	0
596169	595601	14259Y	PARTICIPANT	\N	PRESENT	0
596170	595601	20112S	PARTICIPANT	\N	PRESENT	0
596171	595601	20104S	PARTICIPANT	\N	PRESENT	0
596172	595601	20048C	PARTICIPANT	\N	PRESENT	0
596173	595601	20042V	PARTICIPANT	\N	PRESENT	0
596174	595601	20174H	PARTICIPANT	\N	PRESENT	0
596175	595601	14069U	PARTICIPANT	\N	PRESENT	0
596176	595601	19723Y	PARTICIPANT	\N	PRESENT	0
596177	595601	11097X	PARTICIPANT	\N	PRESENT	0
596178	595601	14109K	PARTICIPANT	\N	PRESENT	0
596179	595601	19703U	PARTICIPANT	\N	PRESENT	0
596180	595601	14071N	PARTICIPANT	\N	PRESENT	0
596181	595601	20082E	PARTICIPANT	\N	PRESENT	0
596182	595601	19667J	PARTICIPANT	\N	PRESENT	0
596183	595601	04047H	PARTICIPANT	\N	PRESENT	0
596184	595601	01034P	PARTICIPANT	\N	PRESENT	0
596185	595601	20120S	PARTICIPANT	\N	PRESENT	0
596186	595601	11012A	PARTICIPANT	\N	PRESENT	0
596187	595601	14053L	PARTICIPANT	\N	PRESENT	0
596188	595601	08015R	PARTICIPANT	\N	PRESENT	0
596194	595601	08061X	PARTICIPANT	\N	PRESENT	0
596199	595601	11085T	PARTICIPANT	\N	PRESENT	0
596211	595601	14223L	PARTICIPANT	\N	PRESENT	0
596213	595601	14083S	PARTICIPANT	\N	PRESENT	0
596232	595601	19441R	PARTICIPANT	\N	PRESENT	0
596233	595601	20252E	PARTICIPANT	\N	PRESENT	0
596246	595601	14257W	PARTICIPANT	\N	PRESENT	0
596253	595601	20018V	PARTICIPANT	\N	PRESENT	0
596254	595601	20038A	PARTICIPANT	\N	PRESENT	0
596256	595601	01024M	PARTICIPANT	\N	PRESENT	0
596257	595601	11090Q	PARTICIPANT	\N	PRESENT	0
596259	588873	19798U	PARTICIPANT	\N	PRESENT	0
596260	595601	08010L	PARTICIPANT	\N	PRESENT	0
596262	595601	07029T	PARTICIPANT	\N	PRESENT	0
596263	595601	19741B	PARTICIPANT	\N	PRESENT	0
596264	595601	19713W	PARTICIPANT	\N	PRESENT	0
596265	595601	11053K	PARTICIPANT	\N	PRESENT	0
596266	595601	14038Y	PARTICIPANT	\N	PRESENT	0
596282	595601	20066E	PARTICIPANT	\N	PRESENT	0
596283	595601	19699S	PARTICIPANT	\N	PRESENT	0
596284	595601	20052X	PARTICIPANT	\N	PRESENT	0
596285	595601	14089Y	PARTICIPANT	\N	PRESENT	0
596305	595507	20074E	PARTICIPANT	\N	PRESENT	0
596306	595507	19581D	PARTICIPANT	\N	PRESENT	0
596307	595507	19585H	PARTICIPANT	\N	PRESENT	0
596308	595507	04047H	PRESIDENT	0	PRESENT	0
596309	595507	19673G	PARTICIPANT	\N	PRESENT	0
596310	595507	01028R	PARTICIPANT	\N	PRESENT	0
572791	572790	18083K	PARTICIPANT	\N	PRESENT	0
572807	572806	14041T	PARTICIPANT	\N	PRESENT	0
572793	572790	19693L	PARTICIPANT	\N	PRESENT	0
572794	572790	14041T	PARTICIPANT	\N	PRESENT	0
572795	572790	14215L	PARTICIPANT	\N	PRESENT	0
572808	572806	14357A	PARTICIPANT	\N	PRESENT	0
572809	572806	18083K	PARTICIPANT	\N	PRESENT	0
572810	572806	14147R	PARTICIPANT	\N	PRESENT	0
572800	572790	14211G	PARTICIPANT	\N	PRESENT	0
572801	572790	08017T	PARTICIPANT	\N	PRESENT	0
572802	572790	14147R	PARTICIPANT	\N	PRESENT	0
572803	572790	19671E	PARTICIPANT	\N	PRESENT	0
572811	572806	14071N	PARTICIPANT	\N	PRESENT	0
572812	572806	19671E	PARTICIPANT	\N	PRESENT	0
572813	572806	08017T	PARTICIPANT	\N	PRESENT	0
572814	572806	14211G	PARTICIPANT	\N	PRESENT	0
572815	572806	14215L	PARTICIPANT	\N	PRESENT	0
572817	572806	19693L	PARTICIPANT	\N	PRESENT	0
572822	572806	08018U	PARTICIPANT	\N	PRESENT	0
572826	572806	19647E	PARTICIPANT	\N	PRESENT	0
572836	572835	14041T	PARTICIPANT	\N	PRESENT	0
572837	572835	08009T	PARTICIPANT	\N	PRESENT	0
572838	572835	14255U	PARTICIPANT	\N	PRESENT	0
574408	571905	19507S	PARTICIPANT	\N	PRESENT	0
574409	571905	11083R	PARTICIPANT	\N	PRESENT	0
574410	571905	20100N	PARTICIPANT	\N	PRESENT	0
574411	571905	19725B	PARTICIPANT	\N	PRESENT	0
574412	571905	19333N	PARTICIPANT	\N	PRESENT	0
574413	571905	19441R	PARTICIPANT	\N	PRESENT	0
574414	571905	19711U	PARTICIPANT	\N	PRESENT	0
574415	571905	14073Q	PARTICIPANT	\N	PRESENT	0
574416	571905	19531S	PARTICIPANT	\N	PRESENT	0
574420	571905	11101A	PARTICIPANT	\N	PRESENT	0
574421	571905	14237S	PARTICIPANT	\N	PRESENT	0
574422	571905	14331P	PARTICIPANT	\N	PRESENT	0
574423	571905	20098N	PARTICIPANT	\N	PRESENT	0
574424	571905	04034C	PARTICIPANT	\N	PRESENT	0
574429	571905	20128B	PARTICIPANT	\N	PRESENT	1
574430	571905	14189C	PARTICIPANT	\N	PRESENT	0
574431	571905	04070G	PARTICIPANT	\N	PRESENT	0
574630	574628	19687N	PARTICIPANT	\N	PRESENT	0
574631	574628	19749K	PARTICIPANT	\N	PRESENT	0
574633	574632	19687N	PARTICIPANT	\N	PRESENT	0
574634	574632	14038Y	PARTICIPANT	\N	PRESENT	0
574635	574632	20128B	PARTICIPANT	\N	PRESENT	0
574636	574632	20020P	PARTICIPANT	\N	PRESENT	0
574642	574378	19621T	PARTICIPANT	\N	EXCUSE	0
574643	574378	11109J	PARTICIPANT	\N	EXCUSE	0
574644	574378	20084G	PARTICIPANT	\N	EXCUSE	0
574830	572779	18193Q	PARTICIPANT	\N	PRESENT	0
574831	572779	20130U	PARTICIPANT	\N	PRESENT	0
574832	572779	11031D	PARTICIPANT	\N	PRESENT	0
574833	572779	19697Q	PARTICIPANT	\N	PRESENT	0
574834	572779	19553Y	PARTICIPANT	\N	PRESENT	0
574835	572779	04092N	PARTICIPANT	\N	PRESENT	0
574836	572779	19679N	PARTICIPANT	\N	PRESENT	0
574837	572779	20066E	PARTICIPANT	\N	PRESENT	0
574838	572779	10006L	PRESIDENT	0	PRESENT	0
574839	572779	17779H	PARTICIPANT	\N	PRESENT	1
574840	572779	14071N	PARTICIPANT	\N	PRESENT	0
574841	572779	19798U	PARTICIPANT	\N	PRESENT	0
574847	572779	11097X	PARTICIPANT	\N	PRESENT	0
574848	572779	04057K	PARTICIPANT	\N	EXCUSE	0
574849	572779	11067R	PARTICIPANT	\N	EXCUSE	0
580923	579404	19701S	PARTICIPANT	\N	PRESENT	0
580924	579404	14083S	PARTICIPANT	\N	PRESENT	0
580925	579404	19798U	PARTICIPANT	\N	PRESENT	0
580926	579404	14073Q	PARTICIPANT	\N	PRESENT	0
580927	579404	11070L	PARTICIPANT	\N	PRESENT	0
580928	579404	14255U	PARTICIPANT	\N	PRESENT	0
580929	579404	07033P	PARTICIPANT	\N	PRESENT	0
580930	579404	20066E	PARTICIPANT	\N	PRESENT	0
580931	579404	11085T	PARTICIPANT	\N	PRESENT	0
580932	579404	01024M	PARTICIPANT	\N	PRESENT	0
580933	579404	01043Q	PARTICIPANT	\N	PRESENT	0
580934	579404	20126Y	PARTICIPANT	\N	PRESENT	0
580935	579404	19691J	PARTICIPANT	\N	PRESENT	0
580936	579404	20054A	PARTICIPANT	\N	PRESENT	0
580937	579404	14179A	PARTICIPANT	\N	PRESENT	0
580938	579404	19713W	PARTICIPANT	\N	PRESENT	0
580939	579404	11053K	PARTICIPANT	\N	PRESENT	0
580940	579404	19581D	PARTICIPANT	\N	PRESENT	0
580941	579404	20248J	PARTICIPANT	\N	PRESENT	0
580942	579404	19671E	PARTICIPANT	\N	PRESENT	0
580943	579404	14219Q	PARTICIPANT	\N	PRESENT	0
580944	579404	14193X	PARTICIPANT	\N	PRESENT	0
580945	579404	20040T	PARTICIPANT	\N	PRESENT	0
580946	579404	14237S	PARTICIPANT	\N	PRESENT	0
580947	579404	14187A	PARTICIPANT	\N	PRESENT	0
580948	579404	14217N	PARTICIPANT	\N	PRESENT	0
580949	579404	14215L	PARTICIPANT	\N	PRESENT	0
580950	579404	05008E	PARTICIPANT	\N	PRESENT	0
580951	579404	19415P	PARTICIPANT	\N	PRESENT	0
580952	579404	11097X	PARTICIPANT	\N	PRESENT	0
580953	579404	04086Q	PARTICIPANT	\N	PRESENT	0
580954	579404	11066Q	PARTICIPANT	\N	PRESENT	0
580955	579404	04092N	PARTICIPANT	\N	PRESENT	0
580956	579404	19413M	PARTICIPANT	\N	PRESENT	0
580957	579404	19747H	PARTICIPANT	\N	PRESENT	0
580958	579404	04047H	PARTICIPANT	\N	PRESENT	0
580959	579404	04070G	PARTICIPANT	\N	PRESENT	0
580960	579404	11048N	PARTICIPANT	\N	PRESENT	0
580961	579404	08010L	PARTICIPANT	\N	PRESENT	0
580962	579404	19703U	PARTICIPANT	\N	PRESENT	0
580963	579404	19333N	PARTICIPANT	\N	PRESENT	0
581027	579404	19709B	PARTICIPANT	\N	PRESENT	0
580965	579404	04035D	PARTICIPANT	\N	PRESENT	0
580966	579404	19693L	PARTICIPANT	\N	PRESENT	0
580967	579404	14211G	PARTICIPANT	\N	PRESENT	0
580968	579404	20094J	PARTICIPANT	\N	PRESENT	0
580969	579404	20036X	PARTICIPANT	\N	PRESENT	0
580970	579404	20142Y	PARTICIPANT	\N	PRESENT	0
580971	579404	95063L	PARTICIPANT	\N	PRESENT	0
580972	579404	20022R	PARTICIPANT	\N	PRESENT	0
580973	579404	14053L	PARTICIPANT	\N	PRESENT	0
580974	579404	19443T	PARTICIPANT	\N	PRESENT	0
580975	579404	97011G	PARTICIPANT	\N	PRESENT	0
580979	579404	20152B	PARTICIPANT	\N	PRESENT	0
580977	579404	19383Y	PARTICIPANT	\N	PRESENT	0
580978	579404	20020P	PARTICIPANT	\N	PRESENT	0
580980	579404	14357A	PARTICIPANT	\N	PRESENT	0
580981	579404	14059S	PARTICIPANT	\N	PRESENT	0
580982	579404	08056B	PARTICIPANT	\N	PRESENT	0
580983	579404	07029T	PARTICIPANT	\N	PRESENT	0
580984	579404	20032T	PARTICIPANT	\N	PRESENT	0
581007	579404	19441R	PARTICIPANT	\N	PRESENT	0
580986	579404	19667J	PARTICIPANT	\N	PRESENT	0
580987	579404	20038A	PARTICIPANT	\N	PRESENT	0
580988	579404	04071H	PARTICIPANT	\N	PRESENT	0
580989	579404	19711U	PARTICIPANT	\N	PRESENT	0
580990	579404	20026V	PARTICIPANT	\N	PRESENT	0
580991	579404	19591F	PARTICIPANT	\N	PRESENT	0
580993	580992	14041T	PARTICIPANT	\N	PRESENT	0
580994	580992	19575F	PARTICIPANT	\N	PRESENT	0
580995	580992	14357A	PARTICIPANT	\N	PRESENT	0
580996	580992	14215L	PARTICIPANT	\N	PRESENT	0
580997	580992	19333N	PARTICIPANT	\N	PRESENT	0
580998	580992	20126Y	PARTICIPANT	\N	PRESENT	0
580999	580992	14147R	PARTICIPANT	\N	PRESENT	0
581000	580992	19673G	PARTICIPANT	\N	PRESENT	0
581001	579404	20106U	PARTICIPANT	\N	PRESENT	0
581002	579404	20172F	PARTICIPANT	\N	PRESENT	0
581003	579404	20118Y	PARTICIPANT	\N	PRESENT	0
581004	579404	14331P	PARTICIPANT	\N	PRESENT	0
581005	579404	20138D	PARTICIPANT	\N	PRESENT	0
581006	579404	20108W	PARTICIPANT	\N	PRESENT	0
581015	579404	19489J	PARTICIPANT	\N	PRESENT	0
581009	579404	20024T	PARTICIPANT	\N	PRESENT	0
581010	579404	18083K	PARTICIPANT	\N	PRESENT	0
581011	579404	20088L	PARTICIPANT	\N	PRESENT	0
581016	579404	14205J	PARTICIPANT	\N	PRESENT	0
581017	579404	20034V	PARTICIPANT	\N	PRESENT	0
581018	579404	14213J	PARTICIPANT	\N	PRESENT	0
581020	581019	14267Y	PARTICIPANT	\N	PRESENT	0
581021	581019	14193X	PARTICIPANT	\N	PRESENT	0
581022	581019	19421M	PARTICIPANT	\N	PRESENT	0
581023	579404	17023S	PARTICIPANT	\N	PRESENT	0
581024	579404	08009T	PARTICIPANT	\N	PRESENT	0
581025	579404	14026U	PARTICIPANT	\N	PRESENT	0
581026	579404	86034E	PARTICIPANT	\N	PRESENT	0
597551	597538	19760E	PARTICIPANT	\N	EXCUSE	0
597552	597538	08060W	PARTICIPANT	\N	EXCUSE	0
597553	597538	14329V	PARTICIPANT	\N	EXCUSE	0
597554	597538	14195A	PARTICIPANT	\N	EXCUSE	0
597555	597538	08028W	PARTICIPANT	\N	EXCUSE	0
597557	597538	14357A	PARTICIPANT	\N	EXCUSE	0
597558	597538	19251M	PARTICIPANT	\N	EXCUSE	0
597559	597538	20048C	PARTICIPANT	\N	EXCUSE	0
597561	597538	20126Y	PARTICIPANT	\N	EXCUSE	0
597563	597538	08015R	PARTICIPANT	\N	EXCUSE	0
597565	597538	19369B	PARTICIPANT	\N	EXCUSE	0
597566	597538	20054A	PARTICIPANT	\N	EXCUSE	0
597568	597538	16685X	PARTICIPANT	\N	EXCUSE	0
597572	597571	14073Q	PARTICIPANT	\N	PRESENT	0
597573	597571	14033T	PARTICIPANT	\N	PRESENT	0
597575	597574	14073Q	PARTICIPANT	\N	PRESENT	0
597576	597574	14033T	PARTICIPANT	\N	PRESENT	0
597590	597588	11097X	PARTICIPANT	\N	PRESENT	1
597616	597599	14189C	PARTICIPANT	\N	PRESENT	0
597657	595488	14189C	PARTICIPANT	\N	PRESENT	0
597658	595488	20094J	PARTICIPANT	\N	PRESENT	0
597660	595488	20100N	PARTICIPANT	\N	PRESENT	0
597686	595488	14033T	PARTICIPANT	\N	PRESENT	0
597687	595488	20128B	PARTICIPANT	\N	PRESENT	0
597688	595488	19333N	PARTICIPANT	\N	PRESENT	0
597689	595488	19531S	PARTICIPANT	\N	PRESENT	0
597756	595488	14357A	PARTICIPANT	\N	EXCUSE	0
597692	595488	14073Q	PARTICIPANT	\N	PRESENT	0
597696	595488	12041X	PARTICIPANT	\N	PRESENT	0
597698	595488	19711U	PARTICIPANT	\N	PRESENT	0
597700	595488	12016W	PARTICIPANT	\N	PRESENT	1
597701	595488	04070G	PARTICIPANT	\N	PRESENT	1
597702	595488	08034U	PARTICIPANT	\N	PRESENT	0
597703	595488	11026G	PARTICIPANT	\N	PRESENT	0
597704	595488	14001X	PARTICIPANT	\N	PRESENT	0
597705	595488	04057K	PARTICIPANT	\N	PRESENT	1
597706	595488	10015M	PARTICIPANT	\N	PRESENT	0
597707	595488	14169X	PARTICIPANT	\N	PRESENT	1
597708	595488	14237S	PARTICIPANT	\N	PRESENT	1
597709	597695	04057K	PARTICIPANT	\N	PRESENT	0
597711	597695	14189C	PARTICIPANT	\N	PRESENT	0
597750	595488	14331P	PRESIDENT	0	PRESENT	0
597753	595608	19766L	PARTICIPANT	\N	PRESENT	0
597754	595488	14089Y	PARTICIPANT	\N	EXCUSE	0
597755	595488	20104S	PARTICIPANT	\N	EXCUSE	0
597757	595488	04035D	PARTICIPANT	\N	EXCUSE	0
597758	595608	20034V	PARTICIPANT	\N	PRESENT	0
597759	595608	20126Y	PARTICIPANT	\N	PRESENT	0
597761	597760	20032T	PARTICIPANT	\N	PRESENT	0
597763	597762	20032T	PARTICIPANT	\N	PRESENT	0
597764	597762	20108W	PARTICIPANT	\N	PRESENT	0
597765	597762	20102Q	PARTICIPANT	\N	PRESENT	0
597766	595608	14026U	PARTICIPANT	\N	PRESENT	0
597767	595608	14179A	PARTICIPANT	\N	PRESENT	0
597768	595608	19697Q	PARTICIPANT	\N	PRESENT	0
597769	595488	19515S	PARTICIPANT	\N	PRESENT	0
597770	595488	19575F	PARTICIPANT	\N	PRESENT	0
597771	595488	19747H	PARTICIPANT	\N	PRESENT	0
597772	595488	14038Y	PARTICIPANT	\N	PRESENT	0
597773	595488	19467C	PARTICIPANT	\N	PRESENT	0
597774	595488	14251Q	PARTICIPANT	\N	PRESENT	0
597775	595488	20018V	PARTICIPANT	\N	PRESENT	0
597776	595488	19369B	PARTICIPANT	\N	PRESENT	0
597777	595608	11056N	PARTICIPANT	\N	PRESENT	0
597778	595488	19768N	PARTICIPANT	\N	PRESENT	0
597779	595488	11090Q	PARTICIPANT	\N	PRESENT	0
597780	595488	20054A	PARTICIPANT	\N	PRESENT	0
597781	595488	20062A	PARTICIPANT	\N	PRESENT	1
597782	595488	19413M	PARTICIPANT	\N	PRESENT	0
597783	595488	14257W	PARTICIPANT	\N	PRESENT	1
597784	595510	20128B	PARTICIPANT	\N	PRESENT	1
597785	595510	14231L	PARTICIPANT	\N	PRESENT	0
597786	595510	10015M	PARTICIPANT	\N	PRESENT	0
597817	595613	04047H	PARTICIPANT	\N	PRESENT	0
597818	595613	19649G	PARTICIPANT	\N	PRESENT	0
597819	595613	19647E	PARTICIPANT	\N	PRESENT	0
597820	595613	14121F	PARTICIPANT	\N	PRESENT	0
597821	595613	19531S	PARTICIPANT	\N	PRESENT	0
597822	595613	04085P	PARTICIPANT	\N	PRESENT	0
597823	595613	11031D	PARTICIPANT	\N	PRESENT	0
597824	595613	11012A	PARTICIPANT	\N	PRESENT	0
597825	595613	19583F	PARTICIPANT	\N	PRESENT	0
597826	595613	19545Y	PARTICIPANT	\N	PRESENT	0
597827	595613	08069G	PARTICIPANT	\N	PRESENT	0
597828	595510	11067R	PARTICIPANT	\N	PRESENT	0
597829	595613	19741B	PARTICIPANT	\N	PRESENT	0
597830	595613	19766L	PARTICIPANT	\N	PRESENT	0
597831	595613	08018U	PARTICIPANT	\N	PRESENT	0
597832	595613	20034V	PARTICIPANT	\N	PRESENT	0
597833	595613	19693L	PARTICIPANT	\N	PRESENT	0
597834	595613	07004J	PARTICIPANT	\N	PRESENT	0
597835	595613	01024M	PARTICIPANT	\N	PRESENT	0
597836	595613	19629C	PARTICIPANT	\N	PRESENT	0
597837	595613	20142Y	PARTICIPANT	\N	PRESENT	0
597838	595613	19689Q	PARTICIPANT	\N	PRESENT	0
597839	595613	20106U	PARTICIPANT	\N	PRESENT	0
597840	595613	19697Q	PARTICIPANT	\N	PRESENT	0
597841	595613	19758L	PARTICIPANT	\N	PRESENT	0
597842	595613	14026U	PARTICIPANT	\N	PRESENT	0
597843	595613	20126Y	PARTICIPANT	\N	PRESENT	0
597844	595613	14147R	PARTICIPANT	\N	PRESENT	0
597815	595613	99004R	PARTICIPANT	\N	PRESENT	0
597816	595613	05008E	PARTICIPANT	\N	PRESENT	0
597845	595613	19399H	PARTICIPANT	\N	PRESENT	0
597846	595613	19711U	PARTICIPANT	\N	PRESENT	0
597847	595613	14215L	PARTICIPANT	\N	PRESENT	0
597848	595613	14179A	PARTICIPANT	\N	PRESENT	0
597849	595613	04033B	PARTICIPANT	\N	PRESENT	0
597850	595613	01028R	PARTICIPANT	\N	PRESENT	0
597851	595613	11053K	PARTICIPANT	\N	PRESENT	0
597852	595613	14251Q	PARTICIPANT	\N	PRESENT	0
597853	595613	20110Q	PARTICIPANT	\N	PRESENT	0
597854	595613	20096L	PARTICIPANT	\N	PRESENT	0
597855	595613	10015M	PARTICIPANT	\N	PRESENT	0
597856	595613	14069U	PARTICIPANT	\N	PRESENT	0
597857	595613	20172F	PARTICIPANT	\N	PRESENT	0
597858	595613	20098N	PARTICIPANT	\N	PRESENT	0
597860	597859	19651A	PARTICIPANT	\N	PRESENT	0
597861	597859	14069U	PARTICIPANT	\N	PRESENT	0
597862	597859	20074E	PARTICIPANT	\N	PRESENT	0
597863	597859	14001X	PARTICIPANT	\N	PRESENT	0
597864	597859	20038A	PARTICIPANT	\N	PRESENT	0
597865	595621	20130U	PARTICIPANT	\N	PRESENT	0
597866	595621	11097X	PARTICIPANT	\N	PRESENT	0
597867	597538	08010L	PARTICIPANT	\N	PRESENT	0
597868	597538	20022R	PARTICIPANT	\N	PRESENT	0
597869	597538	19565D	PARTICIPANT	\N	PRESENT	0
597870	597538	14229S	PARTICIPANT	\N	PRESENT	0
597871	597538	05012A	PARTICIPANT	\N	PRESENT	0
597872	597538	14231L	PARTICIPANT	\N	PRESENT	0
597873	597538	20058E	PARTICIPANT	\N	PRESENT	0
597874	597538	14187A	PARTICIPANT	\N	PRESENT	0
597875	597538	20070A	PARTICIPANT	\N	PRESENT	0
597877	597538	20090E	PARTICIPANT	\N	PRESENT	1
597878	597538	19349W	PARTICIPANT	\N	PRESENT	1
597879	597538	14107H	PARTICIPANT	\N	PRESENT	1
597880	597538	20062A	PARTICIPANT	\N	PRESENT	1
597881	597538	14257W	PARTICIPANT	\N	PRESENT	1
597882	597538	14205J	PARTICIPANT	\N	PRESENT	1
597883	597538	14151M	PARTICIPANT	\N	PRESENT	1
597884	590805	08010L	PARTICIPANT	\N	PRESENT	0
597885	590805	20022R	PARTICIPANT	\N	PRESENT	0
597886	590805	19565D	PARTICIPANT	\N	PRESENT	0
597887	590805	14229S	PARTICIPANT	\N	PRESENT	0
597888	590805	05012A	PARTICIPANT	\N	PRESENT	0
597889	590805	14231L	PRESIDENT	0	PRESENT	0
597890	590805	20058E	PARTICIPANT	\N	PRESENT	0
597891	590805	14187A	PARTICIPANT	\N	PRESENT	0
597892	590805	20070A	PARTICIPANT	\N	PRESENT	0
597893	590805	01057W	PARTICIPANT	\N	PRESENT	0
597894	590805	20090E	PARTICIPANT	\N	PRESENT	1
597895	590805	19349W	PARTICIPANT	\N	PRESENT	1
597896	590805	14107H	PARTICIPANT	\N	PRESENT	1
597897	590805	20062A	PARTICIPANT	\N	PRESENT	1
597898	590805	14257W	PARTICIPANT	\N	PRESENT	1
597899	590805	14205J	PARTICIPANT	\N	PRESENT	1
597900	590805	14151M	PARTICIPANT	\N	PRESENT	1
597901	590805	14030Q	PARTICIPANT	\N	PRESENT	0
597902	590805	19575F	PARTICIPANT	\N	PRESENT	0
597903	590805	19515S	PARTICIPANT	\N	PRESENT	0
571071	566535	19599P	PARTICIPANT	\N	PRESENT	0
571072	566535	04043D	PARTICIPANT	\N	PRESENT	0
571073	566535	20110Q	PARTICIPANT	\N	PRESENT	0
571074	566535	11065P	PARTICIPANT	\N	PRESENT	0
571075	566535	20152B	PARTICIPANT	\N	PRESENT	0
571076	566535	20092G	PARTICIPANT	\N	PRESENT	0
571077	566535	20100N	PARTICIPANT	\N	PRESENT	0
571078	566535	14251Q	PARTICIPANT	\N	PRESENT	0
571079	566535	07029T	PARTICIPANT	\N	PRESENT	0
571080	566535	14219Q	PARTICIPANT	\N	PRESENT	0
571081	566535	19369B	PARTICIPANT	\N	PRESENT	0
571082	566535	19503N	PARTICIPANT	\N	PRESENT	0
571083	566535	19760E	PARTICIPANT	\N	PRESENT	0
571084	566535	14033T	PARTICIPANT	\N	PRESENT	0
571085	566535	19711U	PARTICIPANT	\N	PRESENT	0
571086	566535	17637T	PARTICIPANT	\N	PRESENT	0
571087	566535	14083S	PARTICIPANT	\N	PRESENT	0
571088	566535	20136B	PARTICIPANT	\N	PRESENT	0
571089	566535	14231L	PARTICIPANT	\N	PRESENT	0
571069	566535	04085P	PARTICIPANT	\N	PRESENT	0
571070	566535	19697Q	PARTICIPANT	\N	PRESENT	0
571090	566535	19701S	PARTICIPANT	\N	PRESENT	0
571780	571767	11031D	PARTICIPANT	\N	PRESENT	0
571781	571767	11067R	PARTICIPANT	\N	PRESENT	0
571782	571767	19575F	PARTICIPANT	\N	PRESENT	1
571783	566571	20134Y	PARTICIPANT	\N	PRESENT	1
571784	566571	19593H	PARTICIPANT	\N	PRESENT	1
571786	571785	19593H	PARTICIPANT	\N	PRESENT	0
571788	571787	19593H	PARTICIPANT	\N	PRESENT	0
571791	571789	19593H	PARTICIPANT	\N	PRESENT	0
571793	571792	19593H	PARTICIPANT	\N	PRESENT	0
571795	571794	19593H	PARTICIPANT	\N	PRESENT	0
571797	571796	19593H	PARTICIPANT	\N	PRESENT	0
572847	571228	20114U	PARTICIPANT	\N	PRESENT	0
572848	571228	20152B	PARTICIPANT	\N	PRESENT	0
572849	571228	20124W	PARTICIPANT	\N	PRESENT	0
572850	571228	19673G	PARTICIPANT	\N	PRESENT	0
572851	571228	04035D	PARTICIPANT	\N	PRESENT	0
572852	571228	20034V	PARTICIPANT	\N	PRESENT	0
572853	571228	04057K	PARTICIPANT	\N	PRESENT	0
572854	571228	19527W	PARTICIPANT	\N	PRESENT	0
572855	571228	20106U	PARTICIPANT	\N	PRESENT	1
572858	571228	14030Q	PARTICIPANT	\N	EXCUSE	0
573139	573138	19507S	PARTICIPANT	\N	PRESENT	0
573152	573151	20068G	PARTICIPANT	\N	PRESENT	0
573154	573153	20068G	PARTICIPANT	\N	PRESENT	0
573156	573155	20068G	PARTICIPANT	\N	PRESENT	0
573158	573157	20068G	PARTICIPANT	\N	PRESENT	0
573160	573159	20068G	PARTICIPANT	\N	PRESENT	0
573162	573161	20068G	PARTICIPANT	\N	PRESENT	0
573164	573163	20068G	PARTICIPANT	\N	PRESENT	0
573166	573165	20068G	PARTICIPANT	\N	PRESENT	0
573168	573167	20068G	PARTICIPANT	\N	PRESENT	0
573170	573169	20068G	PARTICIPANT	\N	PRESENT	0
573172	573171	20068G	PARTICIPANT	\N	PRESENT	0
573174	573173	20068G	PARTICIPANT	\N	PRESENT	0
573176	573175	20068G	PARTICIPANT	\N	PRESENT	0
573178	573177	20068G	PARTICIPANT	\N	PRESENT	0
573180	573179	20068G	PARTICIPANT	\N	PRESENT	0
573182	573181	20068G	PARTICIPANT	\N	PRESENT	0
574615	573011	14069U	PARTICIPANT	\N	PRESENT	1
574616	573011	20114U	PARTICIPANT	\N	PRESENT	1
574617	573011	19629C	PARTICIPANT	\N	PRESENT	1
574618	573011	20074E	PARTICIPANT	\N	PRESENT	1
574619	573011	19649G	PARTICIPANT	\N	PRESENT	1
574620	573011	19447X	PARTICIPANT	\N	PRESENT	1
574621	573011	10015M	PARTICIPANT	\N	PRESENT	1
574622	573011	14107H	PARTICIPANT	\N	PRESENT	1
574623	573011	19675J	PARTICIPANT	\N	PRESENT	1
574626	573011	19725B	PARTICIPANT	\N	PRESENT	1
574638	573014	20074E	PARTICIPANT	\N	PRESENT	1
574639	573014	14179A	PARTICIPANT	\N	PRESENT	1
574640	573014	19675J	PARTICIPANT	\N	PRESENT	1
576105	576104	14189C	PARTICIPANT	\N	PRESENT	0
576106	576104	20076G	PARTICIPANT	\N	PRESENT	0
576107	576104	20024T	PARTICIPANT	\N	PRESENT	0
576108	576104	14038Y	PARTICIPANT	\N	PRESENT	0
576109	576104	14042U	PARTICIPANT	\N	PRESENT	0
576110	576104	19723Y	PARTICIPANT	\N	PRESENT	0
576111	576104	14205J	PARTICIPANT	\N	PRESENT	0
576112	576104	14059S	PARTICIPANT	\N	PRESENT	0
576113	576104	19563B	PARTICIPANT	\N	PRESENT	0
576116	576104	20028X	PARTICIPANT	\N	PRESENT	0
576117	576104	20054A	PARTICIPANT	\N	PRESENT	0
576118	576104	11097X	PARTICIPANT	\N	PRESENT	0
576119	576104	11043H	PARTICIPANT	\N	PRESENT	0
576120	576104	04045F	PARTICIPANT	\N	PRESENT	0
576121	576104	19575F	PARTICIPANT	\N	PRESENT	1
576122	576104	20128B	PARTICIPANT	\N	PRESENT	1
576123	576104	14179A	PARTICIPANT	\N	PRESENT	1
576124	576104	19551W	PARTICIPANT	\N	PRESENT	1
576125	576104	14097Y	PARTICIPANT	\N	PRESENT	1
576126	576104	20082E	PARTICIPANT	\N	PRESENT	1
576127	576104	20058E	PARTICIPANT	\N	PRESENT	1
576167	576166	14033T	PARTICIPANT	\N	PRESENT	0
576168	576166	19551W	PARTICIPANT	\N	PRESENT	0
576169	576166	19575F	PARTICIPANT	\N	PRESENT	0
576170	576166	19681G	PARTICIPANT	\N	PRESENT	0
576171	576166	20062A	PARTICIPANT	\N	PRESENT	0
576172	576166	19619A	PARTICIPANT	\N	PRESENT	0
576173	576166	20126Y	PARTICIPANT	\N	PRESENT	0
576175	576166	19413M	PARTICIPANT	\N	PRESENT	0
576176	576166	19533U	PARTICIPANT	\N	PRESENT	0
576177	576166	19333N	PARTICIPANT	\N	PRESENT	0
576178	576166	19820Y	PARTICIPANT	\N	PRESENT	0
576179	576166	19503N	PARTICIPANT	\N	PRESENT	0
576180	576166	14083S	PARTICIPANT	\N	PRESENT	0
576181	576166	20174H	PARTICIPANT	\N	PRESENT	0
576182	576166	14257W	PARTICIPANT	\N	PRESENT	0
576183	576166	20092G	PARTICIPANT	\N	PRESENT	0
577931	577396	19575F	PARTICIPANT	\N	PRESENT	0
577932	577396	19695N	PARTICIPANT	\N	PRESENT	0
577933	577396	14083S	PARTICIPANT	\N	PRESENT	0
577934	577396	14329V	PARTICIPANT	\N	PRESENT	0
577935	577396	19760E	PARTICIPANT	\N	PRESENT	0
577936	577396	14105F	PARTICIPANT	\N	PRESENT	0
577937	577396	19369B	PARTICIPANT	\N	PRESENT	0
577938	577396	19671E	PARTICIPANT	\N	PRESENT	0
577939	577396	19717B	PARTICIPANT	\N	PRESENT	0
577942	577396	20092G	PARTICIPANT	\N	PRESENT	0
577943	577396	19515S	PARTICIPANT	\N	PRESENT	0
577944	577396	14357A	PARTICIPANT	\N	PRESENT	0
577945	577396	16685X	PARTICIPANT	\N	PRESENT	0
577946	577396	14031R	PARTICIPANT	\N	PRESENT	0
577947	577396	14030Q	PARTICIPANT	\N	EXCUSE	0
577948	577396	19545Y	PARTICIPANT	\N	EXCUSE	0
577949	577396	08028W	PARTICIPANT	\N	EXCUSE	0
577950	577396	14026U	PARTICIPANT	\N	EXCUSE	0
577951	577396	20048C	PARTICIPANT	\N	EXCUSE	0
577952	577396	08015R	PARTICIPANT	\N	EXCUSE	0
577953	577396	20054A	PARTICIPANT	\N	EXCUSE	0
577956	577955	19515S	PARTICIPANT	\N	PRESENT	0
577957	577955	19695N	PARTICIPANT	\N	PRESENT	0
577958	577955	19575F	PARTICIPANT	\N	PRESENT	0
577959	577955	14083S	PARTICIPANT	\N	PRESENT	0
585298	583625	20172F	PARTICIPANT	\N	PRESENT	0
585301	583624	20172F	PARTICIPANT	\N	PRESENT	0
585357	583458	04071H	PARTICIPANT	\N	PRESENT	1
585353	583458	07029T	PARTICIPANT	\N	EXCUSE	0
585355	583458	19545Y	PARTICIPANT	\N	PRESENT	1
585359	583458	12016W	PARTICIPANT	\N	PRESENT	1
585361	583458	20150Y	PARTICIPANT	\N	PRESENT	1
585362	583458	14173T	PARTICIPANT	\N	PRESENT	1
588993	588229	20074E	PARTICIPANT	\N	PRESENT	0
588994	588229	04047H	PRESIDENT	0	PRESENT	0
588995	588229	14111D	PARTICIPANT	\N	PRESENT	0
588996	588229	11026G	PARTICIPANT	\N	PRESENT	0
588997	588229	14147R	PARTICIPANT	\N	PRESENT	0
588998	588229	19585H	PARTICIPANT	\N	PRESENT	0
588999	588229	01028R	PARTICIPANT	\N	PRESENT	0
589000	588229	14231L	PARTICIPANT	\N	PRESENT	0
589001	588229	08018U	PARTICIPANT	\N	EXCUSE	0
589002	588531	20028X	PARTICIPANT	\N	PRESENT	0
589003	588531	14121F	PARTICIPANT	\N	PRESENT	0
589004	588531	19599P	PARTICIPANT	\N	PRESENT	0
589005	588531	08010L	PARTICIPANT	\N	PRESENT	0
589006	588531	19415P	PARTICIPANT	\N	PRESENT	0
589007	588531	20130U	PARTICIPANT	\N	PRESENT	0
589008	588531	14069U	PARTICIPANT	\N	PRESENT	0
589009	588531	20102Q	PARTICIPANT	\N	PRESENT	0
589010	588531	04033B	PARTICIPANT	\N	PRESENT	0
596311	595507	05008E	PARTICIPANT	\N	PRESENT	0
596312	595507	19447X	PARTICIPANT	\N	PRESENT	0
596313	595507	14231L	PARTICIPANT	\N	PRESENT	0
596314	595507	07004J	PARTICIPANT	\N	PRESENT	0
596315	595507	20108W	PARTICIPANT	\N	PRESENT	0
596316	595507	20110Q	PARTICIPANT	\N	PRESENT	0
596317	595507	14179A	PARTICIPANT	\N	PRESENT	0
596318	595507	14215L	PARTICIPANT	\N	PRESENT	0
596319	595507	20022R	PARTICIPANT	\N	PRESENT	0
596320	595507	11072N	PARTICIPANT	\N	PRESENT	0
596321	595507	14053L	PARTICIPANT	\N	PRESENT	0
596322	595507	14111D	PARTICIPANT	\N	PRESENT	0
596323	595507	19649G	PARTICIPANT	\N	PRESENT	0
596324	595507	10015M	PARTICIPANT	\N	PRESENT	0
596325	595507	11026G	PARTICIPANT	\N	PRESENT	0
596326	595507	14089Y	PARTICIPANT	\N	PRESENT	0
596327	595507	11056N	PARTICIPANT	\N	PRESENT	0
596328	595507	14069U	PARTICIPANT	\N	PRESENT	0
596329	595507	11085T	PARTICIPANT	\N	PRESENT	0
596330	595507	19749K	PARTICIPANT	\N	PRESENT	0
596331	595507	04008A	PARTICIPANT	\N	PRESENT	0
596332	595507	14021P	PARTICIPANT	\N	PRESENT	0
596333	595507	14026U	PARTICIPANT	\N	PRESENT	0
596334	595507	14259Y	PARTICIPANT	\N	PRESENT	0
596335	595507	19543W	PARTICIPANT	\N	PRESENT	0
596336	595507	14147R	PARTICIPANT	\N	PRESENT	0
596337	595507	19725B	PARTICIPANT	\N	PRESENT	0
596338	595507	95063L	PARTICIPANT	\N	PRESENT	0
596341	595352	14327T	PARTICIPANT	\N	PRESENT	0
596342	595352	20086J	PARTICIPANT	\N	PRESENT	0
596343	595352	14331P	PARTICIPANT	\N	PRESENT	0
596344	595352	11048N	PARTICIPANT	\N	PRESENT	0
596345	595352	19647E	PARTICIPANT	\N	PRESENT	0
596346	595352	19711U	PRESIDENT	0	PRESENT	0
596347	595352	20036X	PARTICIPANT	\N	PRESENT	0
596348	595352	08034U	PARTICIPANT	\N	PRESENT	0
596349	595352	01057W	PARTICIPANT	\N	PRESENT	0
596350	595352	19689Q	PARTICIPANT	\N	PRESENT	0
596351	595352	20080C	PARTICIPANT	\N	PRESENT	0
596352	595352	11074Q	PARTICIPANT	\N	PRESENT	0
596353	595352	19667J	PARTICIPANT	\N	PRESENT	0
596354	595352	20044X	PARTICIPANT	\N	PRESENT	0
596355	595352	11040E	PARTICIPANT	\N	PRESENT	0
596356	595352	14083S	PARTICIPANT	\N	PRESENT	0
596357	595352	20252E	PARTICIPANT	\N	PRESENT	0
596358	595352	08009T	PARTICIPANT	\N	PRESENT	0
596359	595352	14121F	PARTICIPANT	\N	PRESENT	0
596360	595352	14253S	PARTICIPANT	\N	PRESENT	0
596361	595352	99004R	PARTICIPANT	\N	PRESENT	0
596362	595352	20116W	PARTICIPANT	\N	PRESENT	0
596363	595352	19762G	PARTICIPANT	\N	PRESENT	0
596364	595352	14189C	PARTICIPANT	\N	EXCUSE	0
596365	595352	14225N	PARTICIPANT	\N	EXCUSE	0
596366	594912	11067R	PARTICIPANT	\N	PRESENT	0
596367	594912	20090E	PARTICIPANT	\N	PRESENT	0
596368	594912	19569H	PARTICIPANT	\N	PRESENT	0
596369	594912	19798U	PARTICIPANT	\N	PRESENT	0
596370	594912	11097X	PARTICIPANT	\N	PRESENT	0
596371	594912	14223L	PARTICIPANT	\N	PRESENT	0
596372	594912	18193Q	PARTICIPANT	\N	PRESENT	0
596373	594912	19703U	PARTICIPANT	\N	PRESENT	0
596374	594912	14042U	PARTICIPANT	\N	PRESENT	0
596375	594912	14195A	PARTICIPANT	\N	PRESENT	0
596376	594912	19367Y	PARTICIPANT	\N	PRESENT	0
596377	594912	14213J	PARTICIPANT	\N	PRESENT	0
596378	594912	10006L	PRESIDENT	0	PRESENT	0
596381	594912	01034P	PARTICIPANT	\N	PRESENT	0
596383	594912	11045K	PARTICIPANT	\N	PRESENT	0
596384	594912	08045X	PARTICIPANT	\N	PRESENT	0
596385	594912	19691J	PARTICIPANT	\N	PRESENT	0
596387	594912	20172F	PARTICIPANT	\N	PRESENT	0
596388	594912	19723Y	PARTICIPANT	\N	PRESENT	0
596392	594912	14071N	PARTICIPANT	\N	PRESENT	0
596393	594912	19760E	PARTICIPANT	\N	PRESENT	0
596397	595352	08010L	PARTICIPANT	\N	PRESENT	0
596398	595352	19335Q	PARTICIPANT	\N	PRESENT	0
596399	595352	20070A	PARTICIPANT	\N	PRESENT	0
596400	595507	11033F	PARTICIPANT	\N	EXCUSE	0
596401	593811	19549D	PARTICIPANT	\N	PRESENT	0
596402	593811	20076G	PARTICIPANT	\N	PRESENT	0
596403	593811	19387D	PARTICIPANT	\N	PRESENT	0
596404	593811	14219Q	PRESIDENT	0	PRESENT	0
596405	593811	18083K	PARTICIPANT	\N	PRESENT	0
596406	593811	20024T	PARTICIPANT	\N	PRESENT	0
596407	593811	19637C	PARTICIPANT	\N	PRESENT	0
596408	593811	19251M	PARTICIPANT	\N	PRESENT	0
596422	595507	19729F	PARTICIPANT	\N	EXCUSE	0
596423	595352	11053K	PARTICIPANT	\N	PRESENT	0
596424	595352	19531S	PARTICIPANT	\N	PRESENT	0
596425	593811	19333N	PARTICIPANT	\N	PRESENT	0
596426	593811	20032T	PARTICIPANT	\N	PRESENT	0
596427	593811	20038A	PARTICIPANT	\N	PRESENT	0
596428	593811	19820Y	PARTICIPANT	\N	PRESENT	0
596429	593811	19826F	PARTICIPANT	\N	PRESENT	0
596430	593811	20046A	PARTICIPANT	\N	PRESENT	0
596431	593811	19599P	PARTICIPANT	\N	PRESENT	0
596432	593811	19503N	PARTICIPANT	\N	PRESENT	0
596433	593811	19745F	PARTICIPANT	\N	PRESENT	0
596434	593811	11065P	PARTICIPANT	\N	PRESENT	0
596435	593811	20106U	PARTICIPANT	\N	PRESENT	1
596436	593811	20136B	PARTICIPANT	\N	PRESENT	1
596437	593811	19619A	PARTICIPANT	\N	PRESENT	1
596438	593811	14031R	PARTICIPANT	\N	PRESENT	0
596439	593811	17229F	PARTICIPANT	\N	PRESENT	0
596440	593811	05012A	PARTICIPANT	\N	PRESENT	0
596441	593811	19739H	PARTICIPANT	\N	PRESENT	0
596443	595352	19349W	PARTICIPANT	\N	PRESENT	0
596444	595352	20126Y	PARTICIPANT	\N	PRESENT	0
596445	593811	14221J	PARTICIPANT	\N	PRESENT	0
596447	593811	20100N	PARTICIPANT	\N	PRESENT	0
596449	595507	04085P	PARTICIPANT	\N	PRESENT	0
596462	593811	19685L	PARTICIPANT	\N	PRESENT	0
596463	593811	19577H	PARTICIPANT	\N	PRESENT	1
596464	593811	19701S	PARTICIPANT	\N	PRESENT	0
596465	595352	07029T	PARTICIPANT	\N	PRESENT	0
596466	595480	19443T	PARTICIPANT	\N	PRESENT	0
596467	595480	12041X	PARTICIPANT	\N	PRESENT	0
596468	595480	19565D	PARTICIPANT	\N	PRESENT	0
596469	595480	20072C	PARTICIPANT	\N	PRESENT	0
596470	595480	19329S	PARTICIPANT	\N	PRESENT	0
596471	595480	01058X	PARTICIPANT	\N	PRESENT	0
596472	595480	11027H	PARTICIPANT	\N	PRESENT	0
596473	595480	16685X	PARTICIPANT	\N	PRESENT	0
596474	595480	04042C	PRESIDENT	0	PRESENT	0
596475	595480	11054L	PARTICIPANT	\N	PRESENT	0
596476	595480	19669L	PARTICIPANT	\N	PRESENT	0
596477	595480	11066Q	PARTICIPANT	\N	PRESENT	0
596478	595480	08056B	PARTICIPANT	\N	PRESENT	0
596479	595480	12028B	PARTICIPANT	\N	PRESENT	0
596480	595480	19421M	PARTICIPANT	\N	PRESENT	0
596481	595480	14193X	PARTICIPANT	\N	PRESENT	0
596482	595480	19347U	PARTICIPANT	\N	PRESENT	0
596483	595480	08061X	PARTICIPANT	\N	PRESENT	0
596484	595480	01062T	PARTICIPANT	\N	PRESENT	0
596485	595480	11041F	PARTICIPANT	\N	PRESENT	0
596486	595480	01024M	PARTICIPANT	\N	PRESENT	0
596487	595480	19721W	PARTICIPANT	\N	PRESENT	0
596488	595480	14105F	PARTICIPANT	\N	PRESENT	0
596489	595480	14267Y	PARTICIPANT	\N	PRESENT	0
596490	595480	14211G	PARTICIPANT	\N	PRESENT	0
596491	595480	19583F	PARTICIPANT	\N	PRESENT	0
596492	595480	14255U	PARTICIPANT	\N	PRESENT	0
596493	595480	04035D	PARTICIPANT	\N	EXCUSE	0
596494	595480	14249W	PARTICIPANT	\N	EXCUSE	0
596495	595480	17023S	PARTICIPANT	\N	EXCUSE	0
596496	595352	19545Y	PARTICIPANT	\N	PRESENT	0
596497	595480	20064C	PARTICIPANT	\N	PRESENT	0
596500	595480	11083R	PARTICIPANT	\N	PRESENT	0
596501	594920	19383Y	PARTICIPANT	\N	PRESENT	0
596502	594920	20088L	PARTICIPANT	\N	PRESENT	1
596503	594920	19768N	PARTICIPANT	\N	PRESENT	0
596504	594920	19515S	PARTICIPANT	\N	PRESENT	0
596505	594920	20092G	PARTICIPANT	\N	PRESENT	0
596506	594920	19782L	PARTICIPANT	\N	PRESENT	0
573349	573348	14089Y	PARTICIPANT	\N	PRESENT	0
573350	573348	14053L	PARTICIPANT	\N	PRESENT	0
573351	573348	19749K	PARTICIPANT	\N	PRESENT	0
573353	573352	14053L	PARTICIPANT	\N	PRESENT	0
573354	573352	14089Y	PARTICIPANT	\N	PRESENT	0
573355	573352	19649G	PARTICIPANT	\N	PRESENT	0
573356	573352	19749K	PARTICIPANT	\N	PRESENT	0
573358	573357	14089Y	PARTICIPANT	\N	PRESENT	0
573359	573357	19749K	PARTICIPANT	\N	PRESENT	0
573362	573360	11066Q	PARTICIPANT	\N	PRESENT	0
573364	573363	04047H	PARTICIPANT	\N	PRESENT	0
573367	573363	11066Q	PARTICIPANT	\N	PRESENT	0
574353	574352	20094J	PARTICIPANT	\N	PRESENT	0
574354	574352	14189C	PARTICIPANT	\N	PRESENT	0
574355	574352	19575F	PARTICIPANT	\N	PRESENT	0
577922	577921	14299H	PARTICIPANT	\N	PRESENT	0
577924	577921	11066Q	PARTICIPANT	\N	PRESENT	0
581240	579408	14026U	PARTICIPANT	\N	PRESENT	0
581241	579408	11056N	PARTICIPANT	\N	PRESENT	0
581242	579408	14231L	PARTICIPANT	\N	PRESENT	0
581244	579408	19489J	PARTICIPANT	\N	PRESENT	0
581247	579408	14055N	PARTICIPANT	\N	PRESENT	0
581256	579408	20108W	PARTICIPANT	\N	PRESENT	0
581259	579408	14251Q	PARTICIPANT	\N	PRESENT	0
581263	579408	20110Q	PARTICIPANT	\N	PRESENT	0
581267	579408	20128B	PARTICIPANT	\N	PRESENT	0
581271	579408	19719D	PARTICIPANT	\N	PRESENT	0
581273	579408	19251M	PARTICIPANT	\N	PRESENT	0
581275	579408	19681G	PARTICIPANT	\N	PRESENT	0
581276	579408	19717B	PARTICIPANT	\N	PRESENT	0
581277	579408	19553Y	PARTICIPANT	\N	PRESENT	0
581278	579408	19479G	PARTICIPANT	\N	PRESENT	0
581280	579408	14042U	PARTICIPANT	\N	PRESENT	0
581281	581279	04085P	PARTICIPANT	\N	PRESENT	0
581282	581279	05008E	PARTICIPANT	\N	PRESENT	0
581283	579408	19713W	PARTICIPANT	\N	PRESENT	0
581284	581279	04047H	PARTICIPANT	\N	PRESENT	0
581285	581279	19629C	PARTICIPANT	\N	PRESENT	0
581286	579408	19583F	PARTICIPANT	\N	PRESENT	0
581287	581279	11070L	PARTICIPANT	\N	PRESENT	0
581288	581279	14327T	PARTICIPANT	\N	PRESENT	0
581289	581279	10006L	PARTICIPANT	\N	PRESENT	0
581290	581279	14042U	PARTICIPANT	\N	PRESENT	0
581291	581279	14187A	PARTICIPANT	\N	PRESENT	0
581292	581279	19347U	PARTICIPANT	\N	PRESENT	0
581293	581279	14026U	PARTICIPANT	\N	PRESENT	0
581294	581279	11048N	PARTICIPANT	\N	PRESENT	0
581295	581279	14021P	PARTICIPANT	\N	PRESENT	0
581296	581279	99004R	PARTICIPANT	\N	PRESENT	0
581297	581279	19611R	PARTICIPANT	\N	PRESENT	0
581298	581279	01043Q	PARTICIPANT	\N	PRESENT	0
581299	581279	14251Q	PARTICIPANT	\N	PRESENT	0
581300	581279	14031R	PARTICIPANT	\N	PRESENT	0
581301	581279	11085T	PARTICIPANT	\N	PRESENT	0
581302	581279	14237S	PARTICIPANT	\N	PRESENT	0
581303	581279	14193X	PARTICIPANT	\N	PRESENT	0
581304	581279	11090Q	PARTICIPANT	\N	PRESENT	0
581305	581279	95063L	PARTICIPANT	\N	PRESENT	0
581306	581279	11045K	PARTICIPANT	\N	PRESENT	0
581307	579408	19768N	PARTICIPANT	\N	PRESENT	0
581308	579408	19443T	PARTICIPANT	\N	PRESENT	0
581309	579408	19673G	PARTICIPANT	\N	PRESENT	0
581310	579408	20076G	PARTICIPANT	\N	PRESENT	0
581311	579408	19693L	PARTICIPANT	\N	PRESENT	0
581312	579408	20068G	PARTICIPANT	\N	PRESENT	0
581313	579408	19715Y	PARTICIPANT	\N	PRESENT	0
581314	579408	20082E	PARTICIPANT	\N	PRESENT	0
581315	579408	20102Q	PARTICIPANT	\N	PRESENT	0
581316	579408	20028X	PARTICIPANT	\N	PRESENT	0
581317	579408	01028R	PARTICIPANT	\N	PRESENT	0
581318	579408	19820Y	PARTICIPANT	\N	PRESENT	0
581320	579408	11031D	PARTICIPANT	\N	PRESENT	0
581325	579408	14259Y	PARTICIPANT	\N	PRESENT	0
581329	579408	97011G	PARTICIPANT	\N	PRESENT	0
581333	579408	20174H	PARTICIPANT	\N	PRESENT	0
581336	579408	20132W	PARTICIPANT	\N	PRESENT	0
581337	579408	20032T	PARTICIPANT	\N	PRESENT	0
581338	579408	18083K	PARTICIPANT	\N	PRESENT	0
581339	579408	20044X	PARTICIPANT	\N	PRESENT	0
581340	579408	19758L	PARTICIPANT	\N	PRESENT	0
581341	579408	14257W	PARTICIPANT	\N	PRESENT	0
581342	579408	04045F	PARTICIPANT	\N	PRESENT	0
581343	579408	19619A	PARTICIPANT	\N	PRESENT	0
581344	579408	20020P	PARTICIPANT	\N	PRESENT	0
581345	579408	19695N	PARTICIPANT	\N	PRESENT	0
581346	579408	19593H	PARTICIPANT	\N	PRESENT	0
581347	579408	10015M	PARTICIPANT	\N	PRESENT	0
581348	579408	20090E	PARTICIPANT	\N	PRESENT	0
581349	579408	19703U	PARTICIPANT	\N	PRESENT	0
581350	579408	19335Q	PARTICIPANT	\N	PRESENT	0
581351	579408	20066E	PARTICIPANT	\N	PRESENT	0
581352	579408	19467C	PARTICIPANT	\N	PRESENT	0
581353	579408	20046A	PARTICIPANT	\N	PRESENT	0
581354	579408	11097X	PARTICIPANT	\N	PRESENT	0
581355	579408	08061X	PARTICIPANT	\N	PRESENT	0
581356	579408	20026V	PARTICIPANT	\N	PRESENT	0
581357	579408	20096L	PARTICIPANT	\N	PRESENT	0
581358	579408	20056C	PARTICIPANT	\N	PRESENT	0
581359	579408	07029T	PARTICIPANT	\N	PRESENT	0
581360	579408	20092G	PARTICIPANT	\N	PRESENT	0
581361	579408	04047H	PARTICIPANT	\N	PRESENT	0
581362	579408	20036X	PARTICIPANT	\N	PRESENT	0
581363	579408	19333N	PARTICIPANT	\N	PRESENT	0
581364	579408	14053L	PARTICIPANT	\N	PRESENT	0
581365	579408	12016W	PARTICIPANT	\N	PRESENT	0
581366	579408	14151M	PARTICIPANT	\N	PRESENT	0
581367	579408	20024T	PARTICIPANT	\N	PRESENT	0
581368	579408	20180F	PARTICIPANT	\N	PRESENT	0
581369	579408	14073Q	PARTICIPANT	\N	PRESENT	0
581370	579408	19699S	PARTICIPANT	\N	PRESENT	0
581371	579408	19441R	PARTICIPANT	\N	PRESENT	0
581372	579408	20098N	PARTICIPANT	\N	PRESENT	0
581373	579408	19413M	PARTICIPANT	\N	PRESENT	0
581374	579408	04085P	PARTICIPANT	\N	PRESENT	0
581375	579408	19760E	PARTICIPANT	\N	PRESENT	0
581376	579408	20022R	PARTICIPANT	\N	PRESENT	0
581377	579408	01024M	PARTICIPANT	\N	PRESENT	0
581378	579408	01043Q	PARTICIPANT	\N	PRESENT	0
581379	579408	04070G	PARTICIPANT	\N	PRESENT	0
581380	579408	14147R	PARTICIPANT	\N	PRESENT	0
581381	579408	14213J	PARTICIPANT	\N	PRESENT	0
581382	579408	20144B	PARTICIPANT	\N	PRESENT	0
581383	579408	19503N	PARTICIPANT	\N	PRESENT	0
581384	579408	19387D	PARTICIPANT	\N	PRESENT	0
581385	579408	01057W	PARTICIPANT	\N	PRESENT	0
581386	579408	19551W	PARTICIPANT	\N	PRESENT	0
581387	579408	20060X	PARTICIPANT	\N	PRESENT	0
581388	579408	17023S	PARTICIPANT	\N	PRESENT	0
581389	579408	11065P	PARTICIPANT	\N	PRESENT	0
581390	579408	05012A	PARTICIPANT	\N	PRESENT	0
581391	579408	14179A	PARTICIPANT	\N	PRESENT	0
581392	579408	19525U	PARTICIPANT	\N	PRESENT	0
581393	579408	19301E	PARTICIPANT	\N	PRESENT	0
581394	579408	19747H	PARTICIPANT	\N	PRESENT	0
581395	579408	14021P	PARTICIPANT	\N	PRESENT	0
597259	597258	19621T	PRESIDENT	1	PRESENT	0
597260	597258	19758L	PARTICIPANT	\N	PRESENT	0
597261	597258	20264J	PARTICIPANT	\N	PRESENT	0
597265	597258	20132W	PARTICIPANT	\N	PRESENT	0
597266	597258	14123H	PARTICIPANT	\N	PRESENT	0
597268	597258	20048C	PARTICIPANT	\N	PRESENT	0
597269	597258	19611R	PRESIDENT	0	PRESENT	0
597270	597258	19735D	PARTICIPANT	\N	PRESENT	1
597271	597258	20142Y	PARTICIPANT	\N	PRESENT	0
597272	597258	19593H	PARTICIPANT	\N	PRESENT	0
597273	597258	19573D	PARTICIPANT	\N	PRESENT	0
597274	597258	19533U	PARTICIPANT	\N	PRESENT	0
597275	597258	14229S	PARTICIPANT	\N	PRESENT	0
597276	597258	20084G	PARTICIPANT	\N	PRESENT	0
597277	597258	20026V	PARTICIPANT	\N	PRESENT	1
597278	597258	19693L	PARTICIPANT	\N	PRESENT	0
597346	595507	19629C	PARTICIPANT	\N	PRESENT	1
597347	595507	20128B	PARTICIPANT	\N	PRESENT	1
597348	595507	19489J	PARTICIPANT	\N	PRESENT	1
597349	595507	14107H	PARTICIPANT	\N	PRESENT	1
597350	595507	19675J	PARTICIPANT	\N	PRESENT	1
597904	590805	19762G	PARTICIPANT	\N	PRESENT	0
597905	590805	14083S	PARTICIPANT	\N	PRESENT	0
597906	590805	20060X	PARTICIPANT	\N	PRESENT	0
597907	590805	20092G	PARTICIPANT	\N	PRESENT	0
597908	590805	19467C	PARTICIPANT	\N	PRESENT	0
597909	590805	14031R	PARTICIPANT	\N	PRESENT	0
597910	590805	14026U	PARTICIPANT	\N	PRESENT	1
597911	590805	19671E	PARTICIPANT	\N	PRESENT	1
597912	590805	20082E	PARTICIPANT	\N	PRESENT	1
597913	595511	19649G	PARTICIPANT	\N	PRESENT	0
597914	595511	10015M	PARTICIPANT	\N	PRESENT	0
597915	595511	20108W	PARTICIPANT	\N	PRESENT	0
597916	595511	20110Q	PARTICIPANT	\N	PRESENT	0
597917	595511	14151M	PARTICIPANT	\N	PRESENT	0
597918	595511	14215L	PARTICIPANT	\N	PRESENT	0
597919	595511	11033F	PARTICIPANT	\N	PRESENT	0
597920	595511	05008E	PARTICIPANT	\N	PRESENT	0
597921	595511	14021P	PARTICIPANT	\N	PRESENT	0
597922	595511	14231L	PARTICIPANT	\N	PRESENT	0
597923	595511	11056N	PARTICIPANT	\N	PRESENT	0
597924	595511	04047H	PRESIDENT	0	PRESENT	0
597925	597538	01057W	PARTICIPANT	\N	PRESENT	0
598369	598278	19723Y	PARTICIPANT	\N	PRESENT	0
597927	595511	01028R	PARTICIPANT	\N	PRESENT	0
597928	595717	14189C	PARTICIPANT	\N	PRESENT	0
597929	595717	20100N	PARTICIPANT	\N	PRESENT	0
597930	595717	20128B	PARTICIPANT	\N	PRESENT	0
597931	595717	19333N	PARTICIPANT	\N	PRESENT	0
597932	595717	19531S	PARTICIPANT	\N	PRESENT	0
597933	595717	14073Q	PARTICIPANT	\N	PRESENT	0
597934	595717	12041X	PARTICIPANT	\N	PRESENT	0
597935	595717	19711U	PARTICIPANT	\N	PRESENT	0
597936	595717	11026G	PARTICIPANT	\N	PRESENT	0
597937	595717	08034U	PARTICIPANT	\N	PRESENT	0
597938	595717	14001X	PARTICIPANT	\N	PRESENT	0
597939	595717	14331P	PARTICIPANT	\N	PRESENT	0
597940	595717	10015M	PARTICIPANT	\N	PRESENT	0
597941	595717	12016W	PARTICIPANT	\N	PRESENT	1
597942	595717	04057K	PARTICIPANT	\N	PRESENT	1
597943	595717	04070G	PARTICIPANT	\N	PRESENT	1
597944	595717	14169X	PARTICIPANT	\N	PRESENT	1
597945	595717	14237S	PARTICIPANT	\N	PRESENT	1
598372	598278	19749K	PARTICIPANT	\N	PRESENT	0
598373	598278	20120S	PARTICIPANT	\N	PRESENT	0
598374	598278	14255U	PARTICIPANT	\N	PRESENT	0
598386	598385	14001X	PARTICIPANT	\N	PRESENT	0
598388	598387	19637C	PARTICIPANT	\N	PRESENT	0
598407	598406	19399H	PARTICIPANT	\N	PRESENT	1
598408	598406	14229S	PARTICIPANT	\N	PRESENT	1
598409	598406	19735D	PARTICIPANT	\N	PRESENT	1
598410	598406	20132W	PARTICIPANT	\N	PRESENT	1
598411	598406	14030Q	PARTICIPANT	\N	PRESENT	1
598413	598412	19399H	PARTICIPANT	\N	PRESENT	1
598414	598412	14229S	PARTICIPANT	\N	PRESENT	1
597959	595613	20108W	PARTICIPANT	\N	PRESENT	0
598415	598412	19735D	PARTICIPANT	\N	PRESENT	1
598416	598412	20132W	PARTICIPANT	\N	PRESENT	1
598425	598417	19699S	PARTICIPANT	\N	PRESENT	0
598426	598417	20132W	PARTICIPANT	\N	PRESENT	0
598427	598418	19699S	PARTICIPANT	\N	PRESENT	0
598428	598418	20132W	PARTICIPANT	\N	PRESENT	0
597967	597966	20032T	PARTICIPANT	\N	PRESENT	0
597968	597966	20102Q	PARTICIPANT	\N	PRESENT	0
598429	598419	19699S	PARTICIPANT	\N	PRESENT	0
598430	598420	19699S	PARTICIPANT	\N	PRESENT	0
598431	598421	19699S	PARTICIPANT	\N	PRESENT	0
597973	597972	20032T	PARTICIPANT	\N	PRESENT	0
597974	597972	20108W	PARTICIPANT	\N	PRESENT	0
597975	594915	14026U	PARTICIPANT	\N	PRESENT	0
597977	594915	14071N	PRESIDENT	0	PRESENT	0
597978	594915	19697Q	PARTICIPANT	\N	PRESENT	0
597979	594915	19663E	PARTICIPANT	\N	PRESENT	0
597981	597980	20032T	PARTICIPANT	\N	PRESENT	0
597982	594915	20130U	PARTICIPANT	\N	PRESENT	0
597983	597980	20108W	PARTICIPANT	\N	PRESENT	0
598432	598422	19699S	PARTICIPANT	\N	PRESENT	0
597985	594915	14213J	PARTICIPANT	\N	PRESENT	1
598433	598423	19699S	PARTICIPANT	\N	PRESENT	0
597988	597987	20032T	PARTICIPANT	\N	PRESENT	0
598439	598438	19693L	PARTICIPANT	\N	PRESENT	0
597990	597987	20108W	PARTICIPANT	\N	PRESENT	0
597991	597987	19954N	PARTICIPANT	\N	PRESENT	0
597992	597987	19551W	PARTICIPANT	\N	PRESENT	0
597993	597987	01062T	PARTICIPANT	\N	PRESENT	0
597994	597987	11048N	PARTICIPANT	\N	PRESENT	0
597995	597987	20096L	PARTICIPANT	\N	PRESENT	0
597996	597987	20124W	PARTICIPANT	\N	PRESENT	0
597997	597987	19685L	PARTICIPANT	\N	PRESENT	0
597998	595613	20264J	PARTICIPANT	\N	PRESENT	0
598000	597999	20032T	PARTICIPANT	\N	PRESENT	0
598002	598001	20032T	PARTICIPANT	\N	PRESENT	0
598003	598001	20096L	PARTICIPANT	\N	PRESENT	0
598441	598440	19693L	PARTICIPANT	\N	PRESENT	0
598443	598442	19693L	PARTICIPANT	\N	PRESENT	0
598008	595511	14147R	PARTICIPANT	\N	PRESENT	1
598448	598436	19533U	PARTICIPANT	\N	PRESENT	0
598446	598434	19533U	PARTICIPANT	\N	PRESENT	0
598012	590805	14327T	PARTICIPANT	\N	EXCUSE	0
598013	590805	19820Y	PARTICIPANT	\N	EXCUSE	0
598447	598435	19533U	PARTICIPANT	\N	PRESENT	0
598449	598437	19533U	PARTICIPANT	\N	PRESENT	0
598019	590805	20084G	PARTICIPANT	\N	EXCUSE	0
598020	590805	19489J	PARTICIPANT	\N	EXCUSE	0
598021	590805	14071N	PARTICIPANT	\N	EXCUSE	0
598022	590805	14053L	PARTICIPANT	\N	EXCUSE	0
598023	590805	14215L	PARTICIPANT	\N	EXCUSE	0
598025	590805	14217N	PARTICIPANT	\N	EXCUSE	0
598026	590805	19447X	PARTICIPANT	\N	EXCUSE	0
598027	590805	19563B	PARTICIPANT	\N	EXCUSE	0
598028	590805	19782L	PARTICIPANT	\N	EXCUSE	0
598029	590805	20122U	PARTICIPANT	\N	EXCUSE	0
598030	590805	04045F	PARTICIPANT	\N	EXCUSE	0
598031	590805	19735D	PARTICIPANT	\N	EXCUSE	0
598453	598450	20112S	PARTICIPANT	\N	PRESENT	0
598454	598451	20112S	PARTICIPANT	\N	PRESENT	0
598455	598452	20112S	PARTICIPANT	\N	PRESENT	1
598464	598456	19651A	PARTICIPANT	\N	PRESENT	0
598465	598456	19693L	PARTICIPANT	\N	PRESENT	0
598466	598457	19651A	PARTICIPANT	\N	PRESENT	0
598467	598458	19651A	PARTICIPANT	\N	PRESENT	0
598065	598064	20104S	PARTICIPANT	\N	PRESENT	0
598066	598064	14053L	PARTICIPANT	\N	PRESENT	0
598067	598064	14083S	PARTICIPANT	\N	PRESENT	0
598068	598064	19333N	PARTICIPANT	\N	PRESENT	0
598069	598064	14221J	PARTICIPANT	\N	PRESENT	0
598070	598064	14331P	PARTICIPANT	\N	PRESENT	0
598072	598071	20104S	PARTICIPANT	\N	PRESENT	0
598468	598458	19693L	PARTICIPANT	\N	PRESENT	0
598469	598459	19651A	PARTICIPANT	\N	PRESENT	0
598096	598095	19768N	PARTICIPANT	\N	PRESENT	0
598097	598095	19705W	PARTICIPANT	\N	PRESENT	0
598098	598095	20078J	PARTICIPANT	\N	PRESENT	0
598099	598095	19515S	PARTICIPANT	\N	PRESENT	0
598100	598095	19631V	PARTICIPANT	\N	PRESENT	0
598101	598095	19369B	PARTICIPANT	\N	PRESENT	0
598102	598095	19383Y	PARTICIPANT	\N	PRESENT	0
598104	598103	14187A	PARTICIPANT	\N	PRESENT	0
598105	598103	20092G	PARTICIPANT	\N	PRESENT	0
598107	598106	14187A	PARTICIPANT	\N	PRESENT	0
571302	571301	04057K	PARTICIPANT	\N	PRESENT	0
571303	571301	20106U	PARTICIPANT	\N	PRESENT	0
574358	574357	07033P	PARTICIPANT	\N	PRESENT	0
574359	574357	14059S	PARTICIPANT	\N	PRESENT	0
574360	574357	97011G	PARTICIPANT	\N	PRESENT	0
574361	574357	04043D	PARTICIPANT	\N	PRESENT	0
574362	574357	14255U	PARTICIPANT	\N	PRESENT	0
574363	574357	14147R	PARTICIPANT	\N	PRESENT	0
574364	574357	19413M	PARTICIPANT	\N	PRESENT	0
576217	575233	11012A	PARTICIPANT	\N	PRESENT	0
576259	575233	19545Y	PARTICIPANT	\N	PRESENT	1
576260	575233	14327T	PARTICIPANT	\N	PRESENT	1
576261	575233	11110B	PARTICIPANT	\N	PRESENT	1
576262	575233	19647E	PARTICIPANT	\N	PRESENT	1
576263	575233	20126Y	PARTICIPANT	\N	PRESENT	1
576264	575233	19335Q	PARTICIPANT	\N	PRESENT	1
576265	575233	20050V	PARTICIPANT	\N	PRESENT	1
577964	577914	20132W	PARTICIPANT	\N	PRESENT	1
577965	577914	20082E	PARTICIPANT	\N	PRESENT	1
577991	573762	19715Y	PARTICIPANT	\N	PRESENT	1
577992	573762	20130U	PARTICIPANT	\N	PRESENT	1
577993	573760	19715Y	PARTICIPANT	\N	PRESENT	1
577994	573760	19703U	PARTICIPANT	\N	PRESENT	1
577995	573760	20130U	PARTICIPANT	\N	PRESENT	1
577996	573760	11031D	PARTICIPANT	\N	PRESENT	1
578001	577997	14042U	PARTICIPANT	\N	PRESENT	1
578002	577997	04092N	PARTICIPANT	\N	PRESENT	1
578003	577998	14042U	PARTICIPANT	\N	PRESENT	1
578004	577998	20130U	PARTICIPANT	\N	PRESENT	1
578005	577999	14042U	PARTICIPANT	\N	PRESENT	1
578006	577999	04092N	PARTICIPANT	\N	PRESENT	1
578007	577999	20130U	PARTICIPANT	\N	PRESENT	1
578008	578000	14042U	PARTICIPANT	\N	PRESENT	1
578009	578000	04092N	PARTICIPANT	\N	PRESENT	1
578010	578000	20130U	PARTICIPANT	\N	PRESENT	1
578064	578061	20090E	PARTICIPANT	\N	PRESENT	0
578065	578061	19591F	PARTICIPANT	\N	PRESENT	0
578066	578061	20114U	PARTICIPANT	\N	PRESENT	0
578067	578060	20090E	PARTICIPANT	\N	PRESENT	0
578068	578060	19729F	PARTICIPANT	\N	PRESENT	0
578069	578060	20114U	PARTICIPANT	\N	PRESENT	0
578070	578062	20090E	PARTICIPANT	\N	PRESENT	0
578071	578062	11067R	PARTICIPANT	\N	PRESENT	0
578072	578062	20130U	PARTICIPANT	\N	PRESENT	0
578073	578063	19367Y	PARTICIPANT	\N	PRESENT	0
578074	578063	14213J	PARTICIPANT	\N	PRESENT	0
578075	578063	11067R	PARTICIPANT	\N	PRESENT	0
578125	578124	20074E	PARTICIPANT	\N	PRESENT	0
578126	578124	14179A	PARTICIPANT	\N	PRESENT	0
578127	578124	14021P	PARTICIPANT	\N	PRESENT	0
578659	577325	04047H	PRESIDENT	0	PRESENT	0
578660	577325	19447X	PARTICIPANT	\N	PRESENT	0
578661	577325	20108W	PARTICIPANT	\N	PRESENT	0
578666	577325	19489J	PARTICIPANT	\N	PRESENT	0
578667	578170	08073C	PARTICIPANT	\N	PRESENT	0
578668	577325	17737W	PARTICIPANT	\N	PRESENT	0
578669	577325	14111D	PARTICIPANT	\N	PRESENT	0
578670	577325	19585H	PARTICIPANT	\N	PRESENT	0
578671	577325	11056N	PARTICIPANT	\N	PRESENT	0
578672	577325	20110Q	PARTICIPANT	\N	PRESENT	0
578673	578662	14041T	PARTICIPANT	\N	EXCUSE	0
578674	578170	17589D	PARTICIPANT	\N	PRESENT	0
578675	578170	19569H	PARTICIPANT	\N	PRESENT	0
578676	578170	19503N	PARTICIPANT	\N	PRESENT	0
578677	578170	19619A	PARTICIPANT	\N	PRESENT	0
578678	578170	11066Q	PARTICIPANT	\N	PRESENT	0
578679	578170	01058X	PARTICIPANT	\N	PRESENT	0
578680	578170	14213J	PARTICIPANT	\N	PRESENT	0
578681	578170	19527W	PARTICIPANT	\N	PRESENT	0
578682	578170	20028X	PARTICIPANT	\N	PRESENT	0
578683	578170	11101A	PARTICIPANT	\N	PRESENT	0
578684	578170	14030Q	PARTICIPANT	\N	PRESENT	0
578685	578170	14001X	PARTICIPANT	\N	PRESENT	0
578686	578170	11099A	PARTICIPANT	\N	PRESENT	0
578687	578170	11043H	PARTICIPANT	\N	PRESENT	0
578688	578170	14111D	PARTICIPANT	\N	PRESENT	0
578689	578170	14327T	PARTICIPANT	\N	PRESENT	0
578690	578170	19758L	PARTICIPANT	\N	PRESENT	0
578691	578170	97011G	PARTICIPANT	\N	PRESENT	0
578692	578170	20118Y	PARTICIPANT	\N	PRESENT	0
578693	578170	19705W	PARTICIPANT	\N	PRESENT	0
578694	578170	19749K	PARTICIPANT	\N	PRESENT	0
578695	578170	19709B	PARTICIPANT	\N	PRESENT	0
578696	578170	20152B	PARTICIPANT	\N	PRESENT	0
578697	578170	17965H	PARTICIPANT	\N	PRESENT	0
578698	578170	20054A	PARTICIPANT	\N	PRESENT	0
578699	578170	14189C	PARTICIPANT	\N	PRESENT	0
578700	578170	11115U	PARTICIPANT	\N	PRESENT	0
578701	578170	04043D	PARTICIPANT	\N	PRESENT	0
578702	578170	19637C	PARTICIPANT	\N	PRESENT	0
578703	578170	20090E	PARTICIPANT	\N	PRESENT	0
578704	578170	14169X	PARTICIPANT	\N	PRESENT	0
578705	578170	20044X	PARTICIPANT	\N	PRESENT	0
578706	578170	05012A	PARTICIPANT	\N	PRESENT	0
578707	578170	19599P	PARTICIPANT	\N	PRESENT	0
578708	578170	19511N	PARTICIPANT	\N	PRESENT	0
578709	578170	20142Y	PARTICIPANT	\N	PRESENT	0
578750	578172	20028X	PARTICIPANT	\N	PRESENT	0
578748	578172	20082E	PARTICIPANT	\N	PRESENT	0
578749	578172	19631V	PARTICIPANT	\N	PRESENT	0
578751	578172	11083R	PARTICIPANT	\N	PRESENT	0
578752	578172	19782L	PARTICIPANT	\N	PRESENT	0
578753	578172	19301E	PARTICIPANT	\N	PRESENT	0
578754	578172	04085P	PARTICIPANT	\N	PRESENT	0
578755	578172	19760E	PARTICIPANT	\N	PRESENT	0
578756	578172	19758L	PARTICIPANT	\N	PRESENT	0
578757	578172	14231L	PARTICIPANT	\N	PRESENT	0
578758	578172	19826F	PARTICIPANT	\N	PRESENT	0
578759	578172	11012A	PARTICIPANT	\N	PRESENT	0
578760	578172	19866P	PARTICIPANT	\N	PRESENT	0
578761	578172	19717B	PARTICIPANT	\N	PRESENT	0
578762	578172	14001X	PARTICIPANT	\N	PRESENT	0
578763	578172	17023S	PARTICIPANT	\N	PRESENT	0
578764	578172	14187A	PARTICIPANT	\N	PRESENT	0
578765	578172	20054A	PARTICIPANT	\N	PRESENT	0
578766	578172	97011G	PARTICIPANT	\N	PRESENT	0
578767	578172	19741B	PARTICIPANT	\N	PRESENT	0
578768	578172	19503N	PARTICIPANT	\N	PRESENT	0
578769	578172	19447X	PARTICIPANT	\N	PRESENT	0
578770	578172	19747H	PARTICIPANT	\N	PRESENT	0
578771	578172	11101A	PARTICIPANT	\N	PRESENT	0
578772	578172	20136B	PARTICIPANT	\N	PRESENT	0
578773	578172	19515S	PARTICIPANT	\N	PRESENT	0
578774	578172	10015M	PARTICIPANT	\N	PRESENT	0
578775	578172	01058X	PARTICIPANT	\N	PRESENT	0
578776	578172	04092N	PARTICIPANT	\N	PRESENT	0
578777	578172	14327T	PARTICIPANT	\N	PRESENT	0
578778	578172	14038Y	PARTICIPANT	\N	PRESENT	0
578779	578172	20044X	PARTICIPANT	\N	PRESENT	0
578780	578172	19768N	PARTICIPANT	\N	PRESENT	0
578781	578172	08028W	PARTICIPANT	\N	PRESENT	0
578782	578172	04057K	PARTICIPANT	\N	PRESENT	0
578783	578172	19467C	PARTICIPANT	\N	PRESENT	0
578786	578172	20140W	PARTICIPANT	\N	PRESENT	0
578789	578172	12016W	PARTICIPANT	\N	PRESENT	0
578790	578172	19387D	PARTICIPANT	\N	PRESENT	0
578791	578172	19563B	PARTICIPANT	\N	PRESENT	0
578792	578172	20152B	PARTICIPANT	\N	PRESENT	0
578793	578172	14169X	PARTICIPANT	\N	PRESENT	0
578794	578172	14215L	PARTICIPANT	\N	PRESENT	0
578795	578172	18193Q	PARTICIPANT	\N	PRESENT	0
578796	578172	19647E	PARTICIPANT	\N	PRESENT	0
578797	578172	11097X	PARTICIPANT	\N	PRESENT	0
578798	578172	19657G	PARTICIPANT	\N	PRESENT	0
578799	578172	20110Q	PARTICIPANT	\N	PRESENT	0
578800	578172	19251M	PARTICIPANT	\N	PRESENT	0
578801	578172	14217N	PARTICIPANT	\N	PRESENT	0
578810	578172	19711U	PARTICIPANT	\N	PRESENT	0
578811	578172	08061X	PARTICIPANT	\N	PRESENT	0
578812	578172	19349W	PARTICIPANT	\N	PRESENT	0
578813	578172	20036X	PARTICIPANT	\N	PRESENT	0
578814	578172	19577H	PARTICIPANT	\N	PRESENT	0
578815	578172	10006L	PARTICIPANT	\N	PRESENT	0
578816	578172	14111D	PARTICIPANT	\N	PRESENT	0
578817	578172	11090Q	PARTICIPANT	\N	PRESENT	0
578818	578172	19621T	PARTICIPANT	\N	PRESENT	0
578819	578172	19489J	PARTICIPANT	\N	PRESENT	0
578820	578172	20108W	PARTICIPANT	\N	PRESENT	0
578821	578172	20130U	PARTICIPANT	\N	PRESENT	0
578822	578172	04047H	PARTICIPANT	\N	PRESENT	0
578823	578172	19335Q	PARTICIPANT	\N	PRESENT	0
596507	594920	01043Q	PARTICIPANT	\N	PRESENT	0
596508	594920	19441R	PARTICIPANT	\N	PRESENT	0
596509	594920	20078J	PARTICIPANT	\N	PRESENT	0
596510	594920	19413M	PARTICIPANT	\N	PRESENT	0
596511	594920	20082E	PARTICIPANT	\N	PRESENT	0
596512	594920	20094J	PARTICIPANT	\N	PRESENT	0
596513	594920	04045F	PARTICIPANT	\N	PRESENT	0
596514	594920	19631V	PARTICIPANT	\N	PRESENT	0
596515	594920	20104S	PARTICIPANT	\N	PRESENT	0
596516	594920	19705W	PARTICIPANT	\N	PRESENT	0
596517	594920	19707Y	PARTICIPANT	\N	PRESENT	0
596518	594920	08015R	PARTICIPANT	\N	PRESENT	0
596519	594920	19575F	PARTICIPANT	\N	PRESENT	0
596520	594920	19369B	PARTICIPANT	\N	PRESENT	0
596521	594920	20018V	PARTICIPANT	\N	PRESENT	0
596522	594920	19563B	PARTICIPANT	\N	PRESENT	0
596523	594920	20028X	PARTICIPANT	\N	PRESENT	0
596524	594920	20030R	PARTICIPANT	\N	PRESENT	1
596525	594920	14038Y	PARTICIPANT	\N	PRESENT	0
596526	594920	19467C	PARTICIPANT	\N	PRESENT	0
596527	594920	20034V	PARTICIPANT	\N	PRESENT	0
596528	594920	14187A	PARTICIPANT	\N	PRESENT	0
596529	594920	20144B	PARTICIPANT	\N	PRESENT	0
596530	594920	19695N	PARTICIPANT	\N	PRESENT	0
596531	594920	11090Q	PRESIDENT	0	PRESENT	0
596532	594920	14033T	PARTICIPANT	\N	PRESENT	0
596533	594920	01025N	PARTICIPANT	\N	PRESENT	0
596534	594920	20054A	PARTICIPANT	\N	PRESENT	0
596535	594920	20174H	PARTICIPANT	\N	PRESENT	0
596536	594920	14205J	PARTICIPANT	\N	PRESENT	1
596537	594920	20062A	PARTICIPANT	\N	PRESENT	0
596538	594920	14251Q	PARTICIPANT	\N	PRESENT	1
596539	594920	19507S	PARTICIPANT	\N	PRESENT	0
596540	594920	19747H	PARTICIPANT	\N	PRESENT	0
596541	594920	14207L	PARTICIPANT	\N	PRESENT	0
596542	594920	14257W	PARTICIPANT	\N	PRESENT	0
596543	594912	20040T	PARTICIPANT	\N	PRESENT	0
596544	594912	19683J	PARTICIPANT	\N	PRESENT	0
596595	594912	11031D	PARTICIPANT	\N	PRESENT	0
596636	596610	20094J	PARTICIPANT	\N	PRESENT	0
596637	596610	20110Q	PARTICIPANT	\N	PRESENT	0
596638	596610	20018V	PARTICIPANT	\N	PRESENT	0
596876	595603	01043Q	PARTICIPANT	\N	PRESENT	0
596877	595603	01062T	PARTICIPANT	\N	PRESENT	0
596878	595603	19543W	PARTICIPANT	\N	PRESENT	0
596879	595603	14042U	PARTICIPANT	\N	PRESENT	0
596880	595603	19369B	PARTICIPANT	\N	PRESENT	0
596881	595603	19663E	PARTICIPANT	\N	PRESENT	0
596888	595603	11031D	PARTICIPANT	\N	PRESENT	0
596892	595603	19531S	PARTICIPANT	\N	PRESENT	0
596907	595603	17779H	PARTICIPANT	\N	PRESENT	0
596908	596882	20088L	PARTICIPANT	\N	PRESENT	0
596909	596882	14105F	PARTICIPANT	\N	PRESENT	0
596910	596882	19782L	PARTICIPANT	\N	PRESENT	0
596911	596882	20090E	PARTICIPANT	\N	PRESENT	0
596912	596882	14207L	PARTICIPANT	\N	PRESENT	0
596913	596882	01024M	PARTICIPANT	\N	PRESENT	0
596914	596882	20074E	PARTICIPANT	\N	PRESENT	0
596915	596882	01025N	PARTICIPANT	\N	PRESENT	0
596916	596882	20132W	PARTICIPANT	\N	PRESENT	0
596917	596882	01057W	PARTICIPANT	\N	PRESENT	0
596918	596882	14213J	PARTICIPANT	\N	PRESENT	0
596919	596882	08015R	PARTICIPANT	\N	PRESENT	0
596920	595603	14251Q	PARTICIPANT	\N	PRESENT	0
596921	595603	08009T	PARTICIPANT	\N	PRESENT	0
596922	596882	20028X	PARTICIPANT	\N	PRESENT	0
596926	596882	19533U	PARTICIPANT	\N	PRESENT	0
596924	595603	08034U	PARTICIPANT	\N	PRESENT	0
596925	596882	14257W	PARTICIPANT	\N	PRESENT	0
596927	596882	19745F	PARTICIPANT	\N	PRESENT	0
596928	596882	05012A	PARTICIPANT	\N	PRESENT	0
596929	596882	19503N	PARTICIPANT	\N	PRESENT	0
596930	596882	19798U	PARTICIPANT	\N	PRESENT	0
596931	596882	11097X	PARTICIPANT	\N	PRESENT	0
596932	595603	11070L	PARTICIPANT	\N	PRESENT	0
596933	595603	14123H	PARTICIPANT	\N	PRESENT	0
596934	595603	20120S	PARTICIPANT	\N	PRESENT	0
596935	595603	19721W	PARTICIPANT	\N	PRESENT	0
596936	595603	14179A	PARTICIPANT	\N	PRESENT	0
596938	596937	20124W	PARTICIPANT	\N	PRESENT	0
596939	595603	19569H	PARTICIPANT	\N	PRESENT	0
596940	595603	20130U	PARTICIPANT	\N	PRESENT	0
596941	595603	20034V	PARTICIPANT	\N	PRESENT	0
597178	596942	19701S	PARTICIPANT	\N	PRESENT	0
597179	596942	20096L	PARTICIPANT	\N	PRESENT	0
597180	596942	19549D	PARTICIPANT	\N	PRESENT	0
597181	595604	20130U	PARTICIPANT	\N	PRESENT	0
597182	595604	19866P	PARTICIPANT	\N	PRESENT	0
597183	595604	19479G	PARTICIPANT	\N	PRESENT	0
597184	595604	99004R	PARTICIPANT	\N	PRESENT	0
597185	595604	19583F	PARTICIPANT	\N	PRESENT	0
597186	595604	19745F	PARTICIPANT	\N	PRESENT	0
597187	595604	20138D	PARTICIPANT	\N	PRESENT	0
597188	595604	14281W	PARTICIPANT	\N	PRESENT	0
597189	595604	19569H	PARTICIPANT	\N	PRESENT	0
597190	595604	20090E	PARTICIPANT	\N	PRESENT	0
597191	595604	19383Y	PARTICIPANT	\N	PRESENT	0
597192	595604	18083K	PARTICIPANT	\N	PRESENT	0
597193	595604	14030Q	PARTICIPANT	\N	PRESENT	0
597194	595604	20172F	PARTICIPANT	\N	PRESENT	0
597195	595604	11031D	PARTICIPANT	\N	PRESENT	0
597196	595604	19599P	PARTICIPANT	\N	PRESENT	0
597197	595604	20024T	PARTICIPANT	\N	PRESENT	0
597198	595604	19507S	PARTICIPANT	\N	PRESENT	0
597199	595356	11048N	PARTICIPANT	\N	PRESENT	0
597200	595356	19711U	PRESIDENT	0	PRESENT	0
597201	595356	19565D	PARTICIPANT	\N	PRESENT	0
597202	595356	08034U	PARTICIPANT	\N	PRESENT	0
597203	595356	01057W	PARTICIPANT	\N	PRESENT	0
597204	595356	20080C	PARTICIPANT	\N	PRESENT	0
597205	595356	19667J	PARTICIPANT	\N	PRESENT	0
597206	595356	07029T	PARTICIPANT	\N	PRESENT	0
597207	595356	19349W	PARTICIPANT	\N	PRESENT	0
597208	595356	14121F	PARTICIPANT	\N	PRESENT	0
597210	595604	14031R	PARTICIPANT	\N	PRESENT	0
597211	595604	19563B	PARTICIPANT	\N	PRESENT	0
597212	595356	20044X	PARTICIPANT	\N	PRESENT	0
597213	595604	11045K	PARTICIPANT	\N	PRESENT	0
597214	595356	20070A	PARTICIPANT	\N	PRESENT	0
597215	595356	19647E	PARTICIPANT	\N	PRESENT	0
597216	595604	20098N	PARTICIPANT	\N	PRESENT	0
597217	595604	14147R	PARTICIPANT	\N	PRESENT	0
597218	595604	10006L	PARTICIPANT	\N	PRESENT	0
597219	595356	19479G	PARTICIPANT	\N	PRESENT	0
597220	595356	14083S	PARTICIPANT	\N	PRESENT	0
597221	595604	11067R	PARTICIPANT	\N	PRESENT	0
597222	595604	19749K	PARTICIPANT	\N	PRESENT	0
597223	595356	14225N	PARTICIPANT	\N	EXCUSE	0
597224	595604	18193Q	PARTICIPANT	\N	PRESENT	0
597225	595356	08010L	PARTICIPANT	\N	PRESENT	0
597226	595604	01058X	PARTICIPANT	\N	PRESENT	0
597227	595604	20056C	PARTICIPANT	\N	PRESENT	0
597228	595604	19713W	PARTICIPANT	\N	PRESENT	0
597229	595604	14069U	PARTICIPANT	\N	PRESENT	0
597230	595604	04057K	PARTICIPANT	\N	PRESENT	0
597231	595604	17779H	PARTICIPANT	\N	PRESENT	0
597232	595604	01024M	PARTICIPANT	\N	PRESENT	0
597233	595356	04071H	PARTICIPANT	\N	PRESENT	0
597234	595356	19335Q	PARTICIPANT	\N	PRESENT	0
597235	595604	20064C	PARTICIPANT	\N	PRESENT	0
597236	595356	11012A	PARTICIPANT	\N	PRESENT	0
597237	593812	20032T	PARTICIPANT	\N	PRESENT	1
597238	593812	19387D	PARTICIPANT	\N	PRESENT	0
597239	593812	20046A	PARTICIPANT	\N	PRESENT	0
597240	593812	19745F	PARTICIPANT	\N	PRESENT	0
597241	593812	19826F	PARTICIPANT	\N	PRESENT	0
597242	595604	19760E	PARTICIPANT	\N	PRESENT	0
597243	593812	08009T	PARTICIPANT	\N	PRESENT	0
597244	593812	19333N	PARTICIPANT	\N	PRESENT	0
597245	593812	19549D	PARTICIPANT	\N	PRESENT	0
597246	593812	19251M	PARTICIPANT	\N	PRESENT	0
597248	593812	20136B	PARTICIPANT	\N	PRESENT	0
597249	593812	20038A	PARTICIPANT	\N	PRESENT	0
597250	593812	14031R	PARTICIPANT	\N	PRESENT	0
597251	593812	18083K	PARTICIPANT	\N	PRESENT	0
597252	593812	19503N	PARTICIPANT	\N	PRESENT	0
597253	593812	17637T	PARTICIPANT	\N	PRESENT	0
597254	593812	11065P	PARTICIPANT	\N	PRESENT	1
597255	593812	08060W	PARTICIPANT	\N	EXCUSE	0
597256	593812	20076G	PARTICIPANT	\N	EXCUSE	0
570967	570966	17779H	PARTICIPANT	\N	PRESENT	0
570968	570966	11067R	PARTICIPANT	\N	PRESENT	0
570971	570970	17779H	PARTICIPANT	\N	PRESENT	0
570976	570975	14255U	PARTICIPANT	\N	PRESENT	0
575166	575162	14189C	PARTICIPANT	\N	PRESENT	0
570978	570975	04043D	PARTICIPANT	\N	PRESENT	0
570979	570975	20132W	PARTICIPANT	\N	PRESENT	0
570980	570975	01034P	PARTICIPANT	\N	PRESENT	0
575169	575162	19667J	PARTICIPANT	\N	PRESENT	0
570982	570975	20082E	PARTICIPANT	\N	PRESENT	0
575171	575162	11040E	PARTICIPANT	\N	PRESENT	0
575172	575162	20080C	PARTICIPANT	\N	PRESENT	0
575173	575162	11053K	PARTICIPANT	\N	PRESENT	0
575174	575162	14327T	PARTICIPANT	\N	PRESENT	0
575175	575162	19647E	PARTICIPANT	\N	PRESENT	0
575176	575162	01057W	PARTICIPANT	\N	PRESENT	0
575177	575162	11048N	PARTICIPANT	\N	PRESENT	0
575178	575162	07029T	PARTICIPANT	\N	PRESENT	0
575179	575162	19711U	PARTICIPANT	\N	PRESENT	0
575180	575162	14253S	PARTICIPANT	\N	PRESENT	0
575181	575162	19349W	PARTICIPANT	\N	PRESENT	0
575182	575162	14225N	PRESIDENT	0	PRESENT	0
575183	575162	19479G	PARTICIPANT	\N	PRESENT	0
575210	575162	19689Q	PARTICIPANT	\N	PRESENT	0
575953	575940	19954N	PARTICIPANT	\N	PRESENT	0
575954	575940	19643A	PARTICIPANT	\N	PRESENT	0
575955	575940	20114U	PARTICIPANT	\N	PRESENT	0
575956	575940	19721W	PARTICIPANT	\N	PRESENT	0
575957	575940	19693L	PARTICIPANT	\N	PRESENT	0
575958	575940	20132W	PARTICIPANT	\N	PRESENT	0
575959	575940	20172F	PARTICIPANT	\N	PRESENT	0
575960	575940	19611R	PARTICIPANT	\N	PRESENT	0
575961	575940	19735D	PARTICIPANT	\N	PRESENT	0
575962	575940	14059S	PARTICIPANT	\N	PRESENT	0
575963	575940	20142Y	PARTICIPANT	\N	PRESENT	0
575964	575940	14147R	PARTICIPANT	\N	PRESENT	0
575965	575940	20096L	PARTICIPANT	\N	PRESENT	0
575966	575940	19593H	PRESIDENT	0	PRESENT	0
575967	575940	19533U	PARTICIPANT	\N	PRESENT	0
575968	575940	20082E	PARTICIPANT	\N	PRESENT	0
576219	568683	19717B	PRESIDENT	0	PRESENT	0
576220	568683	14259Y	PARTICIPANT	\N	EXCUSE	0
576221	568683	11010L	PARTICIPANT	\N	EXCUSE	0
576222	568683	20146D	PARTICIPANT	\N	EXCUSE	0
576223	568683	08073C	PARTICIPANT	\N	PRESENT	0
581398	579408	19573D	PARTICIPANT	\N	PRESENT	0
581399	579408	19347U	PARTICIPANT	\N	PRESENT	0
581400	579408	18193Q	PARTICIPANT	\N	PRESENT	0
581401	579408	20070A	PARTICIPANT	\N	PRESENT	0
581403	579408	20120S	PARTICIPANT	\N	PRESENT	0
581404	579408	14187A	PARTICIPANT	\N	PRESENT	0
581407	579408	19599P	PARTICIPANT	\N	PRESENT	0
581409	579408	20058E	PARTICIPANT	\N	PRESENT	0
581410	579408	17367Q	PARTICIPANT	\N	PRESENT	0
581412	579408	19711U	PARTICIPANT	\N	PRESENT	0
581415	579408	14033T	PARTICIPANT	\N	PRESENT	0
581420	579408	14038Y	PARTICIPANT	\N	PRESENT	0
581421	579408	20152B	PARTICIPANT	\N	PRESENT	0
581422	579408	20064C	PARTICIPANT	\N	PRESENT	0
581423	579408	20142Y	PARTICIPANT	\N	PRESENT	0
581424	579408	14217N	PARTICIPANT	\N	PRESENT	0
581425	579408	20112S	PARTICIPANT	\N	PRESENT	0
581426	579408	11012A	PARTICIPANT	\N	PRESENT	0
581427	579408	19739H	PARTICIPANT	\N	PRESENT	0
581428	579408	20038A	PARTICIPANT	\N	PRESENT	0
581429	579408	11053K	PARTICIPANT	\N	PRESENT	0
581430	579408	19383Y	PARTICIPANT	\N	PRESENT	0
581431	579408	01058X	PARTICIPANT	\N	PRESENT	0
581432	579408	19565D	PARTICIPANT	\N	PRESENT	0
581433	579408	20100N	PARTICIPANT	\N	PRESENT	0
581434	579408	20094J	PARTICIPANT	\N	PRESENT	0
581435	579408	19687N	PARTICIPANT	\N	PRESENT	0
581436	579408	19685L	PARTICIPANT	\N	PRESENT	0
581437	579408	95063L	PARTICIPANT	\N	PRESENT	0
581438	579408	19782L	PARTICIPANT	\N	PRESENT	0
581439	579408	14089Y	PARTICIPANT	\N	PRESENT	0
581440	579408	14281W	PARTICIPANT	\N	PRESENT	0
581441	579606	19593H	PARTICIPANT	\N	PRESENT	0
581442	579606	20180F	PARTICIPANT	\N	PRESENT	0
581443	579606	17367Q	PRESIDENT	0	PRESENT	0
581444	579408	11048N	PARTICIPANT	\N	PRESENT	0
581445	579408	10006L	PARTICIPANT	\N	PRESENT	0
581446	579606	11083R	PARTICIPANT	\N	PRESENT	0
581447	579606	19333N	PARTICIPANT	\N	PRESENT	0
581555	579412	14026U	PARTICIPANT	\N	PRESENT	0
581556	579412	11048N	PARTICIPANT	\N	PRESENT	0
581557	579412	11070L	PARTICIPANT	\N	PRESENT	0
581558	579412	19647E	PARTICIPANT	\N	PRESENT	0
581559	579412	19583F	PARTICIPANT	\N	PRESENT	0
581560	579412	20036X	PARTICIPANT	\N	PRESENT	0
581561	579412	20110Q	PARTICIPANT	\N	PRESENT	0
581562	579412	08073C	PARTICIPANT	\N	PRESENT	0
581563	579412	11012A	PARTICIPANT	\N	PRESENT	0
581564	579412	19687N	PARTICIPANT	\N	PRESENT	0
581565	579412	19711U	PARTICIPANT	\N	PRESENT	0
581566	579412	18083K	PARTICIPANT	\N	PRESENT	0
581567	579412	19673G	PARTICIPANT	\N	PRESENT	0
581568	579412	20038A	PARTICIPANT	\N	PRESENT	0
581569	579412	20070A	PARTICIPANT	\N	PRESENT	0
581570	579412	19565D	PARTICIPANT	\N	PRESENT	0
581571	579412	12016W	PARTICIPANT	\N	PRESENT	0
581572	579412	20094J	PARTICIPANT	\N	PRESENT	0
581573	579412	19251M	PARTICIPANT	\N	PRESENT	0
581574	579412	19413M	PARTICIPANT	\N	PRESENT	0
581575	579412	19551W	PARTICIPANT	\N	PRESENT	0
581576	579412	19820Y	PARTICIPANT	\N	PRESENT	0
581577	579412	19782L	PARTICIPANT	\N	PRESENT	0
581578	579412	04045F	PARTICIPANT	\N	PRESENT	0
581579	579412	19866P	PARTICIPANT	\N	PRESENT	0
581580	579412	14195A	PARTICIPANT	\N	PRESENT	0
581581	579412	20102Q	PARTICIPANT	\N	PRESENT	0
581582	579412	19758L	PARTICIPANT	\N	PRESENT	0
581583	579412	14251Q	PARTICIPANT	\N	PRESENT	0
581584	579412	19441R	PARTICIPANT	\N	PRESENT	0
581585	579412	19553Y	PARTICIPANT	\N	PRESENT	0
581586	579412	11053K	PARTICIPANT	\N	PRESENT	0
581396	579408	14195A	PARTICIPANT	\N	PRESENT	0
581397	579408	19657G	PARTICIPANT	\N	PRESENT	0
581587	579412	19699S	PARTICIPANT	\N	PRESENT	0
581588	579412	19335Q	PARTICIPANT	\N	PRESENT	0
581589	579412	20080C	PARTICIPANT	\N	PRESENT	0
581590	579412	20126Y	PARTICIPANT	\N	PRESENT	0
581591	579412	11097X	PARTICIPANT	\N	PRESENT	0
581592	579412	99004R	PARTICIPANT	\N	PRESENT	0
581593	579412	20022R	PARTICIPANT	\N	PRESENT	0
581594	579412	05012A	PARTICIPANT	\N	PRESENT	0
581595	579412	97011G	PARTICIPANT	\N	PRESENT	0
581596	579412	20090E	PARTICIPANT	\N	PRESENT	0
581597	579412	20092G	PARTICIPANT	\N	PRESENT	0
581598	579412	20112S	PARTICIPANT	\N	PRESENT	0
581599	579606	04035D	PARTICIPANT	\N	PRESENT	0
581600	579412	01058X	PARTICIPANT	\N	PRESENT	0
581601	579412	19657G	PARTICIPANT	\N	PRESENT	0
581602	579606	20132W	PARTICIPANT	\N	PRESENT	0
581603	579606	14255U	PARTICIPANT	\N	PRESENT	0
581604	579412	07029T	PARTICIPANT	\N	PRESENT	0
581605	579412	20056C	PARTICIPANT	\N	PRESENT	0
581606	579412	20026V	PARTICIPANT	\N	PRESENT	0
581607	579412	20096L	PARTICIPANT	\N	PRESENT	0
581608	579412	10015M	PARTICIPANT	\N	PRESENT	0
581609	579412	01057W	PARTICIPANT	\N	PRESENT	0
581610	579412	19629C	PARTICIPANT	\N	PRESENT	0
581611	579412	19563B	PARTICIPANT	\N	PRESENT	0
581612	579412	20044X	PARTICIPANT	\N	PRESENT	0
581613	579412	04071H	PARTICIPANT	\N	PRESENT	0
581614	579412	14109K	PARTICIPANT	\N	PRESENT	0
581615	579412	08061X	PARTICIPANT	\N	PRESENT	0
581616	579412	20046A	PARTICIPANT	\N	PRESENT	0
581617	579412	19695N	PARTICIPANT	\N	PRESENT	0
581618	579412	19533U	PARTICIPANT	\N	PRESENT	0
581619	579412	19467C	PARTICIPANT	\N	PRESENT	0
581620	579412	12041X	PARTICIPANT	\N	PRESENT	0
581621	579412	19715Y	PARTICIPANT	\N	PRESENT	0
598079	598059	19533U	PARTICIPANT	\N	PRESENT	0
598082	598059	20072C	PARTICIPANT	\N	PRESENT	0
598083	598059	18003S	PARTICIPANT	\N	PRESENT	0
598086	598059	01058X	PARTICIPANT	\N	PRESENT	0
598088	598059	01048V	PARTICIPANT	\N	EXCUSE	0
598091	598059	19735D	PARTICIPANT	\N	EXCUSE	0
598092	598059	11067R	PARTICIPANT	\N	EXCUSE	0
598108	598106	20092G	PARTICIPANT	\N	PRESENT	0
598109	598043	19399H	PARTICIPANT	\N	PRESENT	0
598110	598043	20132W	PARTICIPANT	\N	PRESENT	0
598112	598111	14187A	PARTICIPANT	\N	PRESENT	0
598470	598463	19651A	PARTICIPANT	\N	PRESENT	0
598115	598114	19631V	PARTICIPANT	\N	PRESENT	0
598475	598473	14033T	PARTICIPANT	\N	PRESENT	0
598472	598471	14033T	PARTICIPANT	\N	PRESENT	0
598124	598119	14111D	PARTICIPANT	\N	PRESENT	0
598125	598123	14111D	PARTICIPANT	\N	PRESENT	0
598368	598278	20054A	PARTICIPANT	\N	PRESENT	0
598127	595613	19713W	PARTICIPANT	\N	PRESENT	0
598184	595614	20092G	PARTICIPANT	\N	PRESENT	0
598185	595614	20142Y	PARTICIPANT	\N	PRESENT	0
598186	595614	20130U	PARTICIPANT	\N	PRESENT	0
598187	595614	19583F	PARTICIPANT	\N	PRESENT	0
598188	595614	14189C	PARTICIPANT	\N	PRESENT	0
598189	595614	19713W	PARTICIPANT	\N	PRESENT	0
598190	595614	19543W	PARTICIPANT	\N	PRESENT	0
598191	595614	14215L	PARTICIPANT	\N	PRESENT	0
598192	595614	20120S	PARTICIPANT	\N	PRESENT	0
598193	595614	14071N	PARTICIPANT	\N	PRESENT	0
598194	595614	19762G	PARTICIPANT	\N	PRESENT	0
598195	595614	20054A	PARTICIPANT	\N	PRESENT	0
598196	595614	08069G	PARTICIPANT	\N	PRESENT	0
598197	595614	19649G	PARTICIPANT	\N	PRESENT	0
598198	595614	11026G	PARTICIPANT	\N	PRESENT	0
598199	595614	14151M	PARTICIPANT	\N	PRESENT	0
598200	595614	01028R	PARTICIPANT	\N	PRESENT	0
598201	595614	11045K	PARTICIPANT	\N	PRESENT	0
598202	595614	20128B	PARTICIPANT	\N	PRESENT	0
598203	595614	19629C	PARTICIPANT	\N	PRESENT	0
598204	595614	07004J	PARTICIPANT	\N	PRESENT	0
598205	595614	19711U	PARTICIPANT	\N	PRESENT	0
598206	595614	11090Q	PARTICIPANT	\N	PRESENT	0
598208	595614	14179A	PARTICIPANT	\N	PRESENT	0
598209	595614	10015M	PARTICIPANT	\N	PRESENT	0
598210	595614	20096L	PARTICIPANT	\N	PRESENT	0
598211	595614	19766L	PARTICIPANT	\N	PRESENT	0
598212	595614	19667J	PARTICIPANT	\N	PRESENT	0
598213	595614	08018U	PARTICIPANT	\N	PRESENT	0
598214	595614	11033F	PARTICIPANT	\N	PRESENT	0
598215	595614	12041X	PARTICIPANT	\N	PRESENT	0
598216	595614	19768N	PARTICIPANT	\N	PRESENT	0
598217	595614	19741B	PARTICIPANT	\N	PRESENT	0
598218	595614	04033B	PARTICIPANT	\N	PRESENT	0
598219	595614	19723Y	PARTICIPANT	\N	PRESENT	0
598220	595614	20034V	PARTICIPANT	\N	PRESENT	0
598221	595614	19399H	PARTICIPANT	\N	PRESENT	0
598222	595614	20264J	PARTICIPANT	\N	PRESENT	0
598223	595614	11056N	PARTICIPANT	\N	PRESENT	0
598225	595614	19593H	PARTICIPANT	\N	PRESENT	0
598226	595614	01024M	PARTICIPANT	\N	PRESENT	0
598227	595614	19758L	PARTICIPANT	\N	PRESENT	0
598228	595614	19697Q	PARTICIPANT	\N	PRESENT	0
598229	595614	05008E	PARTICIPANT	\N	PRESENT	0
598230	595614	04047H	PARTICIPANT	\N	PRESENT	0
598232	598224	11056N	PARTICIPANT	\N	PRESENT	0
598233	598207	11056N	PARTICIPANT	\N	PRESENT	0
598234	595614	14055N	PARTICIPANT	\N	PRESENT	0
598235	595614	14026U	PARTICIPANT	\N	PRESENT	0
598236	595614	20110Q	PARTICIPANT	\N	PRESENT	0
598237	595614	14030Q	PARTICIPANT	\N	PRESENT	0
598238	595614	17367Q	PARTICIPANT	\N	PRESENT	0
598239	595614	14069U	PARTICIPANT	\N	PRESENT	0
598240	595614	19747H	PARTICIPANT	\N	PRESENT	0
598182	595614	11070L	PARTICIPANT	\N	PRESENT	0
598183	595614	04085P	PARTICIPANT	\N	PRESENT	0
598241	595614	19621T	PARTICIPANT	\N	PRESENT	0
598242	595614	20104S	PARTICIPANT	\N	PRESENT	0
598243	595614	14255U	PARTICIPANT	\N	PRESENT	0
598244	595614	04042C	PARTICIPANT	\N	PRESENT	0
598245	595614	11053K	PARTICIPANT	\N	PRESENT	0
598246	595614	19545Y	PARTICIPANT	\N	PRESENT	0
598247	595614	14038Y	PARTICIPANT	\N	PRESENT	0
598248	595614	19467C	PARTICIPANT	\N	PRESENT	0
598249	595614	19701S	PARTICIPANT	\N	PRESENT	0
598250	595614	11031D	PARTICIPANT	\N	PRESENT	0
598251	595614	19663E	PARTICIPANT	\N	PRESENT	0
598252	595614	19647E	PARTICIPANT	\N	PRESENT	0
598253	595614	20132W	PARTICIPANT	\N	PRESENT	0
598254	595614	20172F	PARTICIPANT	\N	PRESENT	0
598255	595614	14231L	PARTICIPANT	\N	PRESENT	0
598256	595614	19695N	PARTICIPANT	\N	PRESENT	0
598257	595614	19347U	PARTICIPANT	\N	PRESENT	0
598258	595614	20106U	PARTICIPANT	\N	PRESENT	0
598259	595614	19569H	PARTICIPANT	\N	PRESENT	0
598260	595614	20048C	PARTICIPANT	\N	PRESENT	0
598261	595614	14121F	PARTICIPANT	\N	PRESENT	0
598262	595614	14021P	PARTICIPANT	\N	PRESENT	0
598263	595614	99004R	PARTICIPANT	\N	PRESENT	0
598264	595614	08010L	PARTICIPANT	\N	PRESENT	0
598265	595614	18193Q	PARTICIPANT	\N	PRESENT	0
598266	595614	20108W	PARTICIPANT	\N	PRESENT	0
598267	595614	14251Q	PARTICIPANT	\N	PRESENT	0
598268	595614	14001X	PARTICIPANT	\N	PRESENT	0
598269	595614	11085T	PARTICIPANT	\N	PRESENT	0
598270	595614	14147R	PARTICIPANT	\N	PRESENT	0
598271	595614	19335Q	PARTICIPANT	\N	PRESENT	0
598272	595614	11012A	PARTICIPANT	\N	PRESENT	0
598273	595614	14229S	PARTICIPANT	\N	PRESENT	0
598274	595614	20098N	PARTICIPANT	\N	PRESENT	0
598275	595614	19689Q	PARTICIPANT	\N	PRESENT	0
598276	595614	20126Y	PARTICIPANT	\N	PRESENT	0
598277	595614	19693L	PARTICIPANT	\N	PRESENT	0
598326	598278	11045K	PARTICIPANT	\N	PRESENT	0
598327	598278	05008E	PARTICIPANT	\N	PRESENT	0
598328	598278	04047H	PARTICIPANT	\N	PRESENT	0
598329	598278	04085P	PARTICIPANT	\N	PRESENT	0
598330	598278	14179A	PARTICIPANT	\N	PRESENT	0
598331	598278	19649G	PARTICIPANT	\N	PRESENT	0
598367	598278	01024M	PARTICIPANT	\N	PRESENT	0
598333	598278	11033F	PARTICIPANT	\N	PRESENT	0
598334	598278	20096L	PARTICIPANT	\N	PRESENT	0
598477	598476	14033T	PARTICIPANT	\N	PRESENT	0
598336	598278	04033B	PARTICIPANT	\N	PRESENT	0
598337	598278	20130U	PARTICIPANT	\N	PRESENT	0
598338	598278	19629C	PARTICIPANT	\N	PRESENT	0
598339	598278	20092G	PARTICIPANT	\N	PRESENT	0
598340	598278	19768N	PARTICIPANT	\N	PRESENT	0
598341	598278	19583F	PARTICIPANT	\N	PRESENT	0
598342	598278	19711U	PARTICIPANT	\N	PRESENT	0
598343	598278	19766L	PARTICIPANT	\N	PRESENT	0
598344	598278	19705W	PARTICIPANT	\N	PRESENT	0
598345	598278	20034V	PARTICIPANT	\N	PRESENT	0
598346	598278	20264J	PARTICIPANT	\N	PRESENT	0
598347	598278	14251Q	PARTICIPANT	\N	PRESENT	0
598348	598278	14026U	PARTICIPANT	\N	PRESENT	0
598349	598278	20086J	PARTICIPANT	\N	PRESENT	0
598350	598278	14231L	PARTICIPANT	\N	PRESENT	0
598351	598278	11090Q	PARTICIPANT	\N	PRESENT	0
598352	598278	14151M	PARTICIPANT	\N	PRESENT	0
598353	598278	11026G	PARTICIPANT	\N	PRESENT	0
598354	598278	19741B	PARTICIPANT	\N	PRESENT	0
598355	598278	20128B	PARTICIPANT	\N	PRESENT	0
598356	598278	08069G	PARTICIPANT	\N	PRESENT	0
598357	598278	19758L	PARTICIPANT	\N	PRESENT	0
598358	598278	11056N	PARTICIPANT	\N	PRESENT	0
598359	598278	12041X	PARTICIPANT	\N	PRESENT	0
598360	598278	19593H	PARTICIPANT	\N	PRESENT	0
598361	598278	07004J	PARTICIPANT	\N	PRESENT	0
598362	598278	19663E	PARTICIPANT	\N	PRESENT	0
598363	598278	14055N	PARTICIPANT	\N	PRESENT	0
598364	598278	14215L	PARTICIPANT	\N	PRESENT	0
598365	598278	14071N	PARTICIPANT	\N	PRESENT	0
598366	598278	10015M	PARTICIPANT	\N	PRESENT	0
598484	598483	14187A	PARTICIPANT	\N	PRESENT	0
598488	598487	14187A	PARTICIPANT	\N	PRESENT	0
570352	567710	20094J	PARTICIPANT	\N	PRESENT	1
570353	567710	19441R	PARTICIPANT	\N	PRESENT	0
578824	578172	01057W	PARTICIPANT	\N	PRESENT	0
578827	578172	11056N	PARTICIPANT	\N	PRESENT	0
578828	578172	20142Y	PARTICIPANT	\N	PRESENT	0
578829	578172	17737W	PARTICIPANT	\N	PRESENT	0
578830	578172	20092G	PARTICIPANT	\N	PRESENT	0
578831	578172	01043Q	PARTICIPANT	\N	PRESENT	0
578832	578172	14259Y	PARTICIPANT	\N	PRESENT	0
578833	578723	14041T	PARTICIPANT	\N	EXCUSE	0
578834	578172	20172F	PARTICIPANT	\N	PRESENT	0
578835	578172	08010L	PARTICIPANT	\N	PRESENT	0
578836	578172	01034P	PARTICIPANT	\N	PRESENT	0
578837	578172	19683J	PARTICIPANT	\N	PRESENT	0
578838	578172	14151M	PARTICIPANT	\N	PRESENT	0
578839	578172	19663E	PARTICIPANT	\N	PRESENT	0
578840	578172	19671E	PARTICIPANT	\N	PRESENT	0
578841	578172	08069G	PARTICIPANT	\N	PRESENT	0
578842	578172	19533U	PARTICIPANT	\N	PRESENT	0
578843	578172	11043H	PARTICIPANT	\N	PRESENT	0
578844	578172	19543W	PARTICIPANT	\N	PRESENT	0
578845	578172	20132W	PARTICIPANT	\N	PRESENT	0
578846	578172	19715Y	PARTICIPANT	\N	PRESENT	0
578847	578172	19399H	PARTICIPANT	\N	PRESENT	0
578848	578172	20058E	PARTICIPANT	\N	PRESENT	0
578849	578172	14229S	PARTICIPANT	\N	PRESENT	0
578850	578172	17779H	PARTICIPANT	\N	PRESENT	0
578851	578172	14030Q	PARTICIPANT	\N	PRESENT	0
578852	578172	19695N	PARTICIPANT	\N	PRESENT	0
578853	578172	20174H	PARTICIPANT	\N	PRESENT	0
578854	578172	11067R	PARTICIPANT	\N	PRESENT	0
578855	578172	14123H	PARTICIPANT	\N	PRESENT	0
578856	578172	19441R	PARTICIPANT	\N	PRESENT	0
578857	578172	14033T	PARTICIPANT	\N	PRESENT	0
578858	578172	19687N	PARTICIPANT	\N	PRESENT	0
578859	578172	20064C	PARTICIPANT	\N	PRESENT	0
578860	578172	19673G	PARTICIPANT	\N	PRESENT	0
578861	578172	19749K	PARTICIPANT	\N	PRESENT	0
578862	578172	11072N	PARTICIPANT	\N	PRESENT	0
578863	578172	20134Y	PARTICIPANT	\N	PRESENT	0
578864	578172	19820Y	PARTICIPANT	\N	PRESENT	0
578865	578172	14147R	PARTICIPANT	\N	PRESENT	0
578866	578172	14357A	PARTICIPANT	\N	PRESENT	0
578868	578867	19711U	PARTICIPANT	\N	PRESENT	0
578869	578867	20024T	PARTICIPANT	\N	PRESENT	1
578870	578867	14255U	PARTICIPANT	\N	PRESENT	1
578871	578867	19798U	PARTICIPANT	\N	PRESENT	1
578872	578867	14187A	PARTICIPANT	\N	PRESENT	1
578873	578172	17367Q	PARTICIPANT	\N	PRESENT	0
578874	578172	01028R	PARTICIPANT	\N	PRESENT	0
578875	578172	19413M	PARTICIPANT	\N	PRESENT	0
578917	577328	14179A	PARTICIPANT	\N	PRESENT	1
578915	577328	19447X	PARTICIPANT	\N	PRESENT	1
578916	577328	14147R	PARTICIPANT	\N	PRESENT	1
578918	577328	20108W	PARTICIPANT	\N	PRESENT	1
578919	577328	14069U	PARTICIPANT	\N	PRESENT	1
582758	582696	19551W	PARTICIPANT	\N	PRESENT	0
582759	582696	14083S	PARTICIPANT	\N	PRESENT	0
582760	582696	19687N	PARTICIPANT	\N	PRESENT	0
582761	582696	14041T	PARTICIPANT	\N	PRESENT	0
582762	582696	19575F	PRESIDENT	0	PRESENT	0
582763	582696	19749K	PARTICIPANT	\N	PRESENT	0
582764	582696	19545Y	PARTICIPANT	\N	EXCUSE	0
585992	585650	11067R	PARTICIPANT	\N	EXCUSE	0
585993	585650	19798U	PARTICIPANT	\N	EXCUSE	0
585995	585650	19713W	PARTICIPANT	\N	PRESENT	1
585996	585650	01034P	PARTICIPANT	\N	PRESENT	0
585997	585650	04043D	PARTICIPANT	\N	PRESENT	1
585998	585650	20130U	PARTICIPANT	\N	PRESENT	1
585999	585650	11103C	PARTICIPANT	\N	PRESENT	1
586000	585650	20066E	PARTICIPANT	\N	PRESENT	1
586001	585650	19723Y	PARTICIPANT	\N	PRESENT	1
585991	585650	19760E	PARTICIPANT	\N	PRESENT	1
586002	585650	18193Q	PARTICIPANT	\N	PRESENT	1
586003	585650	19697Q	PARTICIPANT	\N	PRESENT	1
586007	586005	20022R	PARTICIPANT	\N	PRESENT	0
586008	586006	20022R	PARTICIPANT	\N	PRESENT	0
586010	586009	20022R	PARTICIPANT	\N	PRESENT	0
586020	586019	11104D	PARTICIPANT	\N	PRESENT	1
586021	586018	11104D	PARTICIPANT	\N	PRESENT	1
589011	588531	19565D	PARTICIPANT	\N	PRESENT	0
589012	588531	14223L	PARTICIPANT	\N	PRESENT	0
589013	588531	11041F	PARTICIPANT	\N	PRESENT	0
589014	588531	20252E	PARTICIPANT	\N	PRESENT	0
589015	588531	20150Y	PARTICIPANT	\N	PRESENT	0
589016	588531	14059S	PARTICIPANT	\N	PRESENT	0
589017	588531	19669L	PARTICIPANT	\N	PRESENT	0
589018	588531	01058X	PARTICIPANT	\N	PRESENT	0
589019	588531	01062T	PARTICIPANT	\N	PRESENT	0
589020	588531	20068G	PARTICIPANT	\N	PRESENT	0
589021	588531	14187A	PARTICIPANT	\N	PRESENT	0
589022	588531	14133K	PARTICIPANT	\N	PRESENT	0
589023	588531	19711U	PARTICIPANT	\N	PRESENT	0
589024	588531	20090E	PARTICIPANT	\N	PRESENT	0
589025	588531	19681G	PARTICIPANT	\N	PRESENT	0
589026	588531	11012A	PARTICIPANT	\N	PRESENT	0
589027	588531	14173T	PARTICIPANT	\N	PRESENT	0
589028	588531	20072C	PARTICIPANT	\N	PRESENT	0
589029	588531	19467C	PARTICIPANT	\N	PRESENT	0
589030	588531	19747H	PARTICIPANT	\N	PRESENT	0
589031	588531	14031R	PARTICIPANT	\N	PRESENT	0
589032	588531	01024M	PARTICIPANT	\N	PRESENT	0
589033	588531	20114U	PARTICIPANT	\N	PRESENT	0
589035	588531	19782L	PARTICIPANT	\N	PRESENT	0
589036	588531	11064N	PARTICIPANT	\N	PRESENT	0
589037	588531	19479G	PARTICIPANT	\N	PRESENT	0
589038	588531	14231L	PARTICIPANT	\N	PRESENT	0
589039	588531	20066E	PARTICIPANT	\N	PRESENT	0
589040	588531	14267Y	PARTICIPANT	\N	PRESENT	0
589041	588531	17637T	PARTICIPANT	\N	PRESENT	0
589042	588531	14189C	PARTICIPANT	\N	PRESENT	0
589043	588531	04035D	PARTICIPANT	\N	PRESENT	0
589044	588531	11103C	PARTICIPANT	\N	PRESENT	0
589045	588531	19703U	PARTICIPANT	\N	PRESENT	0
589046	588531	19347U	PARTICIPANT	\N	PRESENT	0
589047	588531	11054L	PARTICIPANT	\N	PRESENT	0
589048	588531	14249W	PARTICIPANT	\N	PRESENT	0
589049	588531	08047A	PARTICIPANT	\N	PRESENT	0
589050	588531	20108W	PARTICIPANT	\N	PRESENT	0
589051	588531	20064C	PARTICIPANT	\N	PRESENT	0
589052	588531	19399H	PARTICIPANT	\N	PRESENT	0
589054	588230	19798U	PARTICIPANT	\N	PRESENT	0
589055	588230	20266L	PARTICIPANT	\N	PRESENT	0
589056	588230	04047H	PRESIDENT	0	PRESENT	0
589057	588531	14147R	PARTICIPANT	\N	PRESENT	0
589059	588531	19741B	PARTICIPANT	\N	PRESENT	0
589060	588230	20074E	PARTICIPANT	\N	PRESENT	0
589062	587936	19383Y	PARTICIPANT	\N	PRESENT	0
589063	587936	20088L	PARTICIPANT	\N	PRESENT	1
589064	587936	19768N	PARTICIPANT	\N	PRESENT	1
589065	587936	19782L	PARTICIPANT	\N	PRESENT	0
589066	587936	01043Q	PARTICIPANT	\N	PRESENT	0
589067	587936	14357A	PARTICIPANT	\N	PRESENT	0
589068	587936	20078J	PARTICIPANT	\N	PRESENT	1
589069	587936	20094J	PARTICIPANT	\N	PRESENT	0
589070	587936	19866P	PARTICIPANT	\N	PRESENT	1
589071	587936	20104S	PARTICIPANT	\N	PRESENT	0
589072	587936	19631V	PARTICIPANT	\N	PRESENT	0
589073	587936	19705W	PARTICIPANT	\N	PRESENT	0
589074	587936	08015R	PARTICIPANT	\N	PRESENT	1
589075	587936	19575F	PARTICIPANT	\N	PRESENT	0
589076	587936	20018V	PARTICIPANT	\N	PRESENT	0
589077	587936	19511N	PARTICIPANT	\N	PRESENT	0
589078	587936	19563B	PARTICIPANT	\N	PRESENT	0
589079	587936	08028W	PARTICIPANT	\N	PRESENT	0
589080	587936	20028X	PARTICIPANT	\N	PRESENT	0
589081	587936	20030R	PARTICIPANT	\N	PRESENT	1
589082	587936	19467C	PARTICIPANT	\N	PRESENT	1
589083	587936	14187A	PARTICIPANT	\N	PRESENT	0
589084	587936	11090Q	PRESIDENT	0	PRESENT	0
589085	587936	14205J	PARTICIPANT	\N	PRESENT	1
589086	587936	14251Q	PARTICIPANT	\N	PRESENT	0
589087	587936	19747H	PARTICIPANT	\N	PRESENT	0
589088	587936	14207L	PARTICIPANT	\N	PRESENT	0
589089	587936	14257W	PARTICIPANT	\N	PRESENT	0
589090	587936	19515S	PARTICIPANT	\N	PRESENT	0
589091	588230	19333N	PARTICIPANT	\N	PRESENT	0
589092	588230	14179A	PARTICIPANT	\N	PRESENT	0
589093	588531	19651A	PARTICIPANT	\N	PRESENT	0
589094	588531	14331P	PARTICIPANT	\N	PRESENT	0
597267	595604	19591F	PARTICIPANT	\N	PRESENT	0
597279	595604	20252E	PARTICIPANT	\N	PRESENT	0
597280	595604	14073Q	PARTICIPANT	\N	PRESENT	0
597281	595604	19565D	PARTICIPANT	\N	PRESENT	0
597282	595604	11097X	PARTICIPANT	\N	PRESENT	0
597283	593812	20140W	PARTICIPANT	\N	PRESENT	1
597284	595604	20120S	PARTICIPANT	\N	PRESENT	0
597285	595604	14215L	PARTICIPANT	\N	PRESENT	0
597286	595604	19413M	PARTICIPANT	\N	PRESENT	0
597288	593812	19701S	PARTICIPANT	\N	PRESENT	0
597289	597287	19703U	PARTICIPANT	\N	PRESENT	0
597290	597287	20130U	PARTICIPANT	\N	PRESENT	1
597291	595356	11053K	PARTICIPANT	\N	PRESENT	0
597292	595604	20108W	PARTICIPANT	\N	PRESENT	0
597293	595604	20104S	PARTICIPANT	\N	PRESENT	0
597294	595604	19691J	PARTICIPANT	\N	PRESENT	0
597295	595604	14231L	PARTICIPANT	\N	PRESENT	0
597296	595604	19629C	PARTICIPANT	\N	PRESENT	0
597297	595604	19695N	PARTICIPANT	\N	PRESENT	0
597298	595604	19649G	PARTICIPANT	\N	PRESENT	0
597299	595604	14053L	PARTICIPANT	\N	PRESENT	0
597300	595604	14179A	PARTICIPANT	\N	PRESENT	0
597301	595604	20046A	PARTICIPANT	\N	PRESENT	0
597302	595604	19467C	PARTICIPANT	\N	PRESENT	0
597303	595604	14121F	PARTICIPANT	\N	PRESENT	0
597305	595356	14189C	PARTICIPANT	\N	EXCUSE	0
597307	597306	14215L	PARTICIPANT	\N	PRESENT	0
597308	595356	19545Y	PARTICIPANT	\N	PRESENT	1
597309	595604	08015R	PARTICIPANT	\N	PRESENT	0
597310	595356	12016W	PARTICIPANT	\N	PRESENT	1
597311	595356	19671E	PARTICIPANT	\N	PRESENT	1
597312	595356	20050V	PARTICIPANT	\N	PRESENT	1
597314	597313	14215L	PARTICIPANT	\N	PRESENT	0
597315	594533	14223L	PARTICIPANT	\N	PRESENT	0
597316	594534	14223L	PARTICIPANT	\N	PRESENT	0
597317	595200	14213J	PARTICIPANT	\N	PRESENT	1
597318	595200	14042U	PARTICIPANT	\N	PRESENT	1
597319	595200	14223L	PARTICIPANT	\N	PRESENT	1
597320	595604	20070A	PARTICIPANT	\N	PRESENT	0
597321	595604	20080C	PARTICIPANT	\N	PRESENT	0
597322	595604	19693L	PARTICIPANT	\N	PRESENT	0
597323	595604	19711U	PARTICIPANT	\N	PRESENT	0
597325	595604	20266L	PARTICIPANT	\N	PRESENT	0
597326	595604	14033T	PARTICIPANT	\N	PRESENT	0
597327	595604	20022R	PARTICIPANT	\N	PRESENT	0
597328	595604	20082E	PARTICIPANT	\N	PRESENT	0
597329	595604	11056N	PARTICIPANT	\N	PRESENT	0
597330	595604	19820Y	PARTICIPANT	\N	PRESENT	0
597331	595604	19447X	PARTICIPANT	\N	PRESENT	0
597332	595604	19663E	PARTICIPANT	\N	PRESENT	0
597333	595604	14123H	PARTICIPANT	\N	PRESENT	0
597334	595604	20058E	PARTICIPANT	\N	PRESENT	0
597335	595604	14189C	PARTICIPANT	\N	PRESENT	0
597336	595604	20044X	PARTICIPANT	\N	PRESENT	0
597337	587186	20066E	PARTICIPANT	\N	PRESENT	0
597338	595604	20142Y	PARTICIPANT	\N	PRESENT	0
597339	595604	20110Q	PARTICIPANT	\N	PRESENT	0
597340	595604	19575F	PARTICIPANT	\N	PRESENT	0
597341	595604	14026U	PARTICIPANT	\N	PRESENT	0
597342	595604	19533U	PARTICIPANT	\N	PRESENT	0
597343	595604	19399H	PARTICIPANT	\N	PRESENT	0
597344	595604	14038Y	PARTICIPANT	\N	PRESENT	0
597345	595604	08010L	PARTICIPANT	\N	PRESENT	0
597351	595604	20054A	PARTICIPANT	\N	PRESENT	0
597352	595604	19758L	PARTICIPANT	\N	PRESENT	0
597353	595604	19747H	PARTICIPANT	\N	PRESENT	0
597354	595604	11012A	PARTICIPANT	\N	PRESENT	0
597355	595604	19701S	PARTICIPANT	\N	PRESENT	0
597356	595604	19573D	PARTICIPANT	\N	PRESENT	0
597357	595604	20052X	PARTICIPANT	\N	PRESENT	0
597358	595604	14021P	PARTICIPANT	\N	PRESENT	0
597359	595604	19347U	PARTICIPANT	\N	PRESENT	0
597360	595604	11085T	PARTICIPANT	\N	PRESENT	0
597361	595604	14042U	PARTICIPANT	\N	PRESENT	0
597362	595604	20126Y	PARTICIPANT	\N	PRESENT	0
597413	595605	11031D	PARTICIPANT	\N	PRESENT	0
597414	595605	19565D	PARTICIPANT	\N	PRESENT	0
597415	595605	14071N	PARTICIPANT	\N	PRESENT	0
597416	595605	14069U	PARTICIPANT	\N	PRESENT	0
597417	595605	20046A	PARTICIPANT	\N	PRESENT	0
597418	595605	19621T	PARTICIPANT	\N	PRESENT	0
597419	595605	19447X	PARTICIPANT	\N	PRESENT	0
597420	595605	11045K	PARTICIPANT	\N	PRESENT	0
597421	595605	14033T	PARTICIPANT	\N	PRESENT	0
597422	595605	19599P	PARTICIPANT	\N	PRESENT	0
597423	595605	20172F	PARTICIPANT	\N	PRESENT	0
597424	595605	20130U	PARTICIPANT	\N	PRESENT	0
597425	595605	10006L	PARTICIPANT	\N	PRESENT	0
597426	595605	20126Y	PARTICIPANT	\N	PRESENT	0
597427	595605	19866P	PARTICIPANT	\N	PRESENT	0
597428	595605	19663E	PARTICIPANT	\N	PRESENT	0
597429	595605	19573D	PARTICIPANT	\N	PRESENT	0
597430	595605	14030Q	PARTICIPANT	\N	PRESENT	0
597431	595605	20034V	PARTICIPANT	\N	PRESENT	0
597432	595605	04057K	PARTICIPANT	\N	PRESENT	0
597433	595605	19747H	PARTICIPANT	\N	PRESENT	0
597434	595605	19467C	PARTICIPANT	\N	PRESENT	0
597435	595605	14053L	PARTICIPANT	\N	PRESENT	0
597439	595605	20100N	PARTICIPANT	\N	PRESENT	0
597437	595605	14147R	PARTICIPANT	\N	PRESENT	0
597438	595605	20142Y	PARTICIPANT	\N	PRESENT	0
597440	595605	19591F	PARTICIPANT	\N	PRESENT	0
597441	595605	18193Q	PARTICIPANT	\N	PRESENT	0
597442	595605	20054A	PARTICIPANT	\N	PRESENT	0
597446	595605	19693L	PARTICIPANT	\N	PRESENT	0
597444	595605	01024M	PARTICIPANT	\N	PRESENT	0
597445	595605	19569H	PARTICIPANT	\N	PRESENT	0
597447	595605	20252E	PARTICIPANT	\N	PRESENT	0
597448	595605	19749K	PARTICIPANT	\N	PRESENT	0
597449	595605	19575F	PARTICIPANT	\N	PRESENT	0
597450	595605	14083S	PARTICIPANT	\N	PRESENT	0
597451	595605	20110Q	PARTICIPANT	\N	PRESENT	0
597452	595605	19545Y	PARTICIPANT	\N	PRESENT	0
597453	595605	14215L	PARTICIPANT	\N	PRESENT	0
597454	595605	11048N	PARTICIPANT	\N	PRESENT	0
597455	595605	20098N	PARTICIPANT	\N	PRESENT	0
597456	595605	20070A	PARTICIPANT	\N	PRESENT	0
597458	597457	04033B	PARTICIPANT	\N	PRESENT	0
597459	597457	14255U	PARTICIPANT	\N	PRESENT	0
597460	597457	20264J	PARTICIPANT	\N	PRESENT	0
597461	597457	19709B	PARTICIPANT	\N	PRESENT	0
597462	597457	08018U	PARTICIPANT	\N	PRESENT	0
597463	597457	19507S	PARTICIPANT	\N	PRESENT	0
597411	595605	14026U	PARTICIPANT	\N	PRESENT	0
597412	595605	17779H	PARTICIPANT	\N	PRESENT	0
597464	597457	20108W	PARTICIPANT	\N	PRESENT	0
597465	597457	19515S	PARTICIPANT	\N	PRESENT	0
597466	597457	04047H	PARTICIPANT	\N	PRESENT	0
597467	597457	19621T	PARTICIPANT	\N	PRESENT	0
597468	597457	20138D	PARTICIPANT	\N	PRESENT	0
597469	597457	14069U	PARTICIPANT	\N	PRESENT	0
597470	597457	18083K	PARTICIPANT	\N	PRESENT	0
597471	597457	14259Y	PARTICIPANT	\N	PRESENT	0
597472	597457	19693L	PARTICIPANT	\N	PRESENT	0
597473	597457	14026U	PARTICIPANT	\N	PRESENT	0
597474	597457	20120S	PARTICIPANT	\N	PRESENT	0
597475	597457	08034U	PARTICIPANT	\N	PRESENT	0
597476	597457	14031R	PARTICIPANT	\N	PRESENT	0
597477	597457	14071N	PARTICIPANT	\N	PRESENT	0
597478	597457	14147R	PARTICIPANT	\N	PRESENT	0
597479	597457	19533U	PARTICIPANT	\N	PRESENT	0
597480	597457	14193X	PARTICIPANT	\N	PRESENT	0
597481	597457	20098N	PARTICIPANT	\N	PRESENT	0
597482	597457	19705W	PARTICIPANT	\N	PRESENT	0
597483	597457	20058E	PARTICIPANT	\N	PRESENT	0
597485	595510	19729F	PARTICIPANT	\N	EXCUSE	0
597491	595607	99004R	PARTICIPANT	\N	PRESENT	0
597496	595510	14053L	PARTICIPANT	\N	PRESENT	0
597497	595510	19697Q	PARTICIPANT	\N	PRESENT	0
597498	595510	19649G	PARTICIPANT	\N	PRESENT	0
597499	595510	19533U	PARTICIPANT	\N	PRESENT	0
597500	595510	11045K	PARTICIPANT	\N	PRESENT	0
597501	595510	11026G	PARTICIPANT	\N	PRESENT	0
597502	595510	19581D	PARTICIPANT	\N	PRESENT	0
597503	595510	18193Q	PARTICIPANT	\N	PRESENT	0
597504	595510	04047H	PRESIDENT	0	PRESENT	0
597505	595510	14026U	PARTICIPANT	\N	PRESENT	0
597257	595356	14327T	PARTICIPANT	\N	PRESENT	0
597262	593812	19820Y	PARTICIPANT	\N	PRESENT	0
597263	593812	14219Q	PRESIDENT	0	PRESENT	0
597264	593812	20106U	PARTICIPANT	\N	PRESENT	1
573714	572776	17779H	PARTICIPANT	\N	EXCUSE	0
575246	574965	14133K	PARTICIPANT	\N	EXCUSE	0
575247	574965	14026U	PARTICIPANT	\N	EXCUSE	0
575248	574965	19637C	PARTICIPANT	\N	EXCUSE	0
575249	574965	19467C	PARTICIPANT	\N	EXCUSE	0
575321	575320	20022R	PARTICIPANT	\N	PRESENT	0
575322	575320	14331P	PARTICIPANT	\N	PRESENT	0
575324	575323	20022R	PARTICIPANT	\N	PRESENT	0
575325	575323	14331P	PARTICIPANT	\N	PRESENT	0
575327	575326	20050V	PARTICIPANT	\N	PRESENT	0
575329	575328	19717B	PARTICIPANT	\N	PRESENT	0
575330	575328	19347U	PARTICIPANT	\N	PRESENT	0
575331	575328	20034V	PARTICIPANT	\N	PRESENT	0
575332	575328	12016W	PARTICIPANT	\N	PRESENT	0
580108	580107	14357A	PARTICIPANT	\N	PRESENT	0
580109	580107	19711U	PARTICIPANT	\N	PRESENT	0
580110	580107	19647E	PARTICIPANT	\N	PRESENT	0
580134	580133	19711U	PARTICIPANT	\N	PRESENT	0
580402	580401	14089Y	PARTICIPANT	\N	PRESENT	0
580403	580401	14053L	PARTICIPANT	\N	PRESENT	0
580405	580404	14089Y	PARTICIPANT	\N	PRESENT	0
580406	580404	14053L	PARTICIPANT	\N	PRESENT	0
580407	580404	19581D	PARTICIPANT	\N	PRESENT	0
581673	579423	12041X	PARTICIPANT	\N	PRESENT	0
581674	579423	20028X	PARTICIPANT	\N	PRESENT	0
581675	579423	04085P	PARTICIPANT	\N	PRESENT	0
581676	579423	14053L	PARTICIPANT	\N	PRESENT	0
581677	579423	04008A	PARTICIPANT	\N	PRESENT	0
581678	579423	95063L	PARTICIPANT	\N	PRESENT	0
581679	579423	11012A	PARTICIPANT	\N	PRESENT	0
581680	579423	14215L	PARTICIPANT	\N	PRESENT	0
581681	579423	19673G	PARTICIPANT	\N	PRESENT	0
581682	579423	07029T	PARTICIPANT	\N	PRESENT	0
581683	579423	14071N	PARTICIPANT	\N	PRESENT	0
581684	579423	19629C	PARTICIPANT	\N	PRESENT	0
581685	579423	19866P	PARTICIPANT	\N	PRESENT	0
581686	579423	11026G	PARTICIPANT	\N	PRESENT	0
581687	579423	19467C	PARTICIPANT	\N	PRESENT	0
581688	579423	20090E	PARTICIPANT	\N	PRESENT	0
581689	579423	20110Q	PARTICIPANT	\N	PRESENT	0
581690	579423	20038A	PARTICIPANT	\N	PRESENT	0
581691	579423	04047H	PARTICIPANT	\N	PRESENT	0
581692	579423	01028R	PARTICIPANT	\N	PRESENT	0
581693	579423	20082E	PARTICIPANT	\N	PRESENT	0
581694	579423	19820Y	PARTICIPANT	\N	PRESENT	0
581695	579423	19563B	PARTICIPANT	\N	PRESENT	0
581696	579423	20096L	PARTICIPANT	\N	PRESENT	0
581697	579423	20056C	PARTICIPANT	\N	PRESENT	0
581698	579423	20180F	PARTICIPANT	\N	PRESENT	0
581699	579423	20034V	PARTICIPANT	\N	PRESENT	0
581700	579423	20026V	PARTICIPANT	\N	PRESENT	0
581701	579423	11066Q	PARTICIPANT	\N	PRESENT	0
581702	579423	19565D	PARTICIPANT	\N	PRESENT	0
581703	579423	19747H	PARTICIPANT	\N	PRESENT	0
581704	579423	14021P	PARTICIPANT	\N	PRESENT	0
581705	579423	19443T	PARTICIPANT	\N	PRESENT	0
581706	579423	19701S	PARTICIPANT	\N	PRESENT	0
581707	579423	14089Y	PARTICIPANT	\N	PRESENT	0
581708	579423	19533U	PARTICIPANT	\N	PRESENT	0
581709	579423	19447X	PARTICIPANT	\N	PRESENT	0
581710	579423	20092G	PARTICIPANT	\N	PRESENT	0
581711	579423	20100N	PARTICIPANT	\N	PRESENT	0
581712	579423	19347U	PARTICIPANT	\N	PRESENT	0
581713	579423	18083K	PARTICIPANT	\N	PRESENT	0
581714	579423	14231L	PARTICIPANT	\N	PRESENT	0
581715	579423	17023S	PARTICIPANT	\N	PRESENT	0
581716	579137	14053L	PARTICIPANT	\N	PRESENT	0
581717	579137	14089Y	PARTICIPANT	\N	PRESENT	0
581718	579137	95063L	PARTICIPANT	\N	PRESENT	0
581719	579137	11026G	PARTICIPANT	\N	PRESENT	0
581720	579137	20110Q	PARTICIPANT	\N	PRESENT	0
581721	579137	14215L	PARTICIPANT	\N	PRESENT	0
581722	579137	04047H	PRESIDENT	0	PRESENT	0
581723	579137	04008A	PARTICIPANT	\N	PRESENT	0
581724	579137	19673G	PARTICIPANT	\N	PRESENT	0
581725	579137	01028R	PARTICIPANT	\N	PRESENT	0
581726	579137	14231L	PARTICIPANT	\N	PRESENT	0
581727	579137	19447X	PARTICIPANT	\N	PRESENT	0
581728	579423	20070A	PARTICIPANT	\N	PRESENT	0
581730	579423	14357A	PARTICIPANT	\N	PRESENT	0
581731	579423	14069U	PARTICIPANT	\N	PRESENT	0
581740	581739	19421M	PARTICIPANT	\N	PRESENT	1
581741	581739	19669L	PARTICIPANT	\N	PRESENT	1
581931	581930	14329V	PARTICIPANT	\N	PRESENT	0
581933	581932	14329V	PARTICIPANT	\N	PRESENT	0
581944	581943	14205J	PARTICIPANT	\N	PRESENT	0
581946	581945	14205J	PARTICIPANT	\N	PRESENT	1
581947	581945	19782L	PARTICIPANT	\N	PRESENT	1
581949	581948	14205J	PARTICIPANT	\N	PRESENT	0
581950	581948	11099A	PARTICIPANT	\N	PRESENT	0
582586	582585	14041T	PARTICIPANT	\N	PRESENT	0
582587	582585	19593H	PARTICIPANT	\N	PRESENT	0
582688	582686	11083R	PARTICIPANT	\N	PRESENT	0
582689	582686	17367Q	PARTICIPANT	\N	PRESENT	0
582690	582686	19593H	PARTICIPANT	\N	PRESENT	0
582691	582686	20134Y	PARTICIPANT	\N	PRESENT	0
582692	582687	17367Q	PARTICIPANT	\N	PRESENT	0
582693	582687	11083R	PARTICIPANT	\N	PRESENT	0
582694	582687	19593H	PARTICIPANT	\N	PRESENT	0
582770	582765	04047H	PARTICIPANT	\N	PRESENT	0
582771	582765	20108W	PARTICIPANT	\N	PRESENT	0
582773	582766	20074E	PARTICIPANT	\N	PRESENT	0
582774	582766	14179A	PARTICIPANT	\N	PRESENT	0
582776	582775	19447X	PARTICIPANT	\N	PRESENT	0
582830	582745	14231L	PARTICIPANT	\N	PRESENT	0
582831	582745	08034U	PARTICIPANT	\N	PRESENT	0
582832	582745	14229S	PARTICIPANT	\N	PRESENT	0
582833	582765	11072N	PARTICIPANT	\N	PRESENT	0
582834	582766	14237S	PARTICIPANT	\N	PRESENT	0
582835	582766	19768N	PARTICIPANT	\N	PRESENT	0
582891	582629	12016W	PARTICIPANT	\N	PRESENT	0
582838	582837	17367Q	PARTICIPANT	\N	PRESENT	0
582839	582837	11083R	PARTICIPANT	\N	PRESENT	0
582840	582837	19593H	PARTICIPANT	\N	PRESENT	0
582842	582841	17367Q	PARTICIPANT	\N	PRESENT	0
582843	582841	11083R	PARTICIPANT	\N	PRESENT	0
582844	582841	19593H	PARTICIPANT	\N	PRESENT	0
582846	582845	17367Q	PARTICIPANT	\N	PRESENT	0
582847	582845	11083R	PARTICIPANT	\N	PRESENT	0
582848	582845	19593H	PARTICIPANT	\N	PRESENT	0
582850	582849	20092G	PARTICIPANT	\N	PRESENT	1
582851	582849	14357A	PARTICIPANT	\N	PRESENT	1
582889	582629	08073C	PARTICIPANT	\N	PRESENT	0
582890	582629	19295A	PARTICIPANT	\N	PRESENT	0
582892	582629	11026G	PARTICIPANT	\N	PRESENT	0
582893	582629	19649G	PARTICIPANT	\N	PRESENT	0
582894	582629	14151M	PARTICIPANT	\N	PRESENT	0
582895	582629	19715Y	PARTICIPANT	\N	PRESENT	0
582896	582629	19683J	PARTICIPANT	\N	PRESENT	0
582897	582629	11054L	PARTICIPANT	\N	PRESENT	0
582898	582629	20130U	PARTICIPANT	\N	PRESENT	0
582899	582629	20142Y	PARTICIPANT	\N	PRESENT	0
582900	582629	20110Q	PARTICIPANT	\N	PRESENT	0
582901	582629	19697Q	PARTICIPANT	\N	PRESENT	0
582902	582629	19301E	PARTICIPANT	\N	PRESENT	0
582903	582629	20150Y	PARTICIPANT	\N	PRESENT	0
582904	582629	19329S	PARTICIPANT	\N	PRESENT	0
582905	582629	95063L	PARTICIPANT	\N	PRESENT	0
582906	582629	01028R	PARTICIPANT	\N	PRESENT	0
582907	582629	04085P	PARTICIPANT	\N	PRESENT	0
582908	582629	11031D	PARTICIPANT	\N	PRESENT	0
582909	582629	19687N	PARTICIPANT	\N	PRESENT	0
582910	582629	12041X	PARTICIPANT	\N	PRESENT	0
582911	582629	19695N	PARTICIPANT	\N	PRESENT	0
582912	582629	14219Q	PARTICIPANT	\N	PRESENT	0
582913	582629	19479G	PARTICIPANT	\N	PRESENT	0
582914	582629	19441R	PARTICIPANT	\N	PRESENT	0
582915	582629	11064N	PARTICIPANT	\N	PRESENT	0
582916	582629	20122U	PARTICIPANT	\N	PRESENT	0
582917	582629	14251Q	PARTICIPANT	\N	PRESENT	0
582918	582629	20132W	PARTICIPANT	\N	PRESENT	0
582919	582629	11012A	PARTICIPANT	\N	PRESENT	0
582920	582629	14107H	PARTICIPANT	\N	PRESENT	0
582827	582777	19447X	PARTICIPANT	\N	PRESENT	0
582829	582745	19749K	PARTICIPANT	\N	PRESENT	0
582921	582629	19758L	PARTICIPANT	\N	PRESENT	0
582922	582629	19691J	PARTICIPANT	\N	PRESENT	0
582923	582629	14042U	PARTICIPANT	\N	PRESENT	0
582924	582629	11053K	PARTICIPANT	\N	PRESENT	0
598493	598492	14187A	PARTICIPANT	\N	PRESENT	0
598494	598492	19631V	PARTICIPANT	\N	PRESENT	0
598489	598487	19631V	PARTICIPANT	\N	PRESENT	0
598490	598487	20174H	PARTICIPANT	\N	PRESENT	0
598496	598495	14187A	PARTICIPANT	\N	PRESENT	0
598497	598371	19735D	PARTICIPANT	\N	PRESENT	1
598498	598371	20142Y	PARTICIPANT	\N	PRESENT	1
598499	598478	19735D	PARTICIPANT	\N	PRESENT	0
598500	598478	14229S	PARTICIPANT	\N	PRESENT	0
598501	598478	19693L	PARTICIPANT	\N	PRESENT	1
598502	598478	20132W	PARTICIPANT	\N	PRESENT	1
598503	598478	20264J	PARTICIPANT	\N	PRESENT	0
598527	598509	14123H	PARTICIPANT	\N	PRESENT	1
598528	598509	20124W	PARTICIPANT	\N	PRESENT	1
598529	598509	14030Q	PARTICIPANT	\N	PRESENT	1
598530	598509	19693L	PARTICIPANT	\N	PRESENT	1
598531	598521	14123H	PARTICIPANT	\N	PRESENT	1
598532	598521	14109K	PARTICIPANT	\N	PRESENT	1
598533	598521	14030Q	PARTICIPANT	\N	PRESENT	1
598534	598521	20124W	PARTICIPANT	\N	PRESENT	1
598536	598535	14123H	PARTICIPANT	\N	PRESENT	1
598537	598535	11043H	PARTICIPANT	\N	PRESENT	1
598538	598504	14123H	PARTICIPANT	\N	PRESENT	1
598539	598524	14123H	PARTICIPANT	\N	PRESENT	1
598540	598525	14123H	PARTICIPANT	\N	PRESENT	1
598541	598525	14109K	PARTICIPANT	\N	PRESENT	1
598542	598525	14030Q	PARTICIPANT	\N	PRESENT	1
598543	598525	20180F	PARTICIPANT	\N	PRESENT	1
598544	598526	14123H	PARTICIPANT	\N	PRESENT	1
598551	598545	20124W	PARTICIPANT	\N	PRESENT	0
598552	598545	20142Y	PARTICIPANT	\N	PRESENT	1
598553	598545	19735D	PARTICIPANT	\N	PRESENT	1
598554	598546	20124W	PARTICIPANT	\N	PRESENT	1
598555	598546	19735D	PARTICIPANT	\N	PRESENT	1
598556	598547	20124W	PARTICIPANT	\N	PRESENT	0
598557	598548	20124W	PARTICIPANT	\N	PRESENT	1
598558	598550	20124W	PARTICIPANT	\N	PRESENT	1
598559	598549	20124W	PARTICIPANT	\N	PRESENT	0
598562	598560	20124W	PARTICIPANT	\N	PRESENT	0
598563	598561	20124W	PARTICIPANT	\N	PRESENT	0
598569	598565	14030Q	PARTICIPANT	\N	PRESENT	0
598570	598565	19621T	PARTICIPANT	\N	PRESENT	0
598571	598565	14109K	PARTICIPANT	\N	PRESENT	1
598572	598565	20124W	PARTICIPANT	\N	PRESENT	1
598573	598566	14030Q	PARTICIPANT	\N	PRESENT	0
598574	598566	19621T	PARTICIPANT	\N	PRESENT	0
598575	598566	14109K	PARTICIPANT	\N	PRESENT	0
598576	598547	19593H	PARTICIPANT	\N	PRESENT	0
598577	598550	19735D	PARTICIPANT	\N	PRESENT	1
598588	598585	14071N	PARTICIPANT	\N	PRESENT	0
598589	598585	20130U	PARTICIPANT	\N	PRESENT	0
598590	598586	11067R	PARTICIPANT	\N	PRESENT	0
598591	598586	14071N	PARTICIPANT	\N	PRESENT	0
598592	598587	11067R	PARTICIPANT	\N	PRESENT	0
598593	598587	14071N	PARTICIPANT	\N	PRESENT	0
598594	598584	14042U	PARTICIPANT	\N	PRESENT	0
598595	598584	14213J	PARTICIPANT	\N	PRESENT	0
598596	598584	11067R	PARTICIPANT	\N	PRESENT	0
598597	598584	14071N	PARTICIPANT	\N	PRESENT	0
598598	598582	14042U	PARTICIPANT	\N	PRESENT	0
598599	598582	14026U	PARTICIPANT	\N	PRESENT	0
598600	598582	14213J	PARTICIPANT	\N	PRESENT	0
598601	598581	14042U	PARTICIPANT	\N	PRESENT	0
598602	598581	14213J	PARTICIPANT	\N	PRESENT	0
598603	598580	14042U	PARTICIPANT	\N	PRESENT	0
598604	598580	14213J	PARTICIPANT	\N	PRESENT	0
598605	598580	14223L	PARTICIPANT	\N	PRESENT	0
598606	598583	14213J	PARTICIPANT	\N	PRESENT	0
598607	598583	11067R	PARTICIPANT	\N	PRESENT	0
598608	598583	18193Q	PARTICIPANT	\N	PRESENT	0
598609	598583	20130U	PARTICIPANT	\N	PRESENT	0
598610	598583	17965H	PARTICIPANT	\N	PRESENT	0
598611	598579	14213J	PARTICIPANT	\N	PRESENT	0
598612	598579	20130U	PARTICIPANT	\N	PRESENT	0
598613	598578	14213J	PARTICIPANT	\N	PRESENT	0
598614	598578	11067R	PARTICIPANT	\N	PRESENT	0
598615	598578	20130U	PARTICIPANT	\N	PRESENT	0
598616	598578	17965H	PARTICIPANT	\N	PRESENT	0
598617	598578	18193Q	PARTICIPANT	\N	PRESENT	0
598627	595687	18083K	PARTICIPANT	\N	PRESENT	0
598628	595687	19333N	PARTICIPANT	\N	PRESENT	0
598629	595687	19701S	PARTICIPANT	\N	PRESENT	0
598630	595687	19745F	PARTICIPANT	\N	PRESENT	0
598631	595687	20024T	PARTICIPANT	\N	PRESENT	0
598632	595687	20032T	PARTICIPANT	\N	PRESENT	0
598633	595687	14031R	PARTICIPANT	\N	PRESENT	0
598634	595687	19549D	PARTICIPANT	\N	PRESENT	0
598635	595687	14219Q	PRESIDENT	0	PRESENT	0
598636	595687	19820Y	PARTICIPANT	\N	PRESENT	0
598637	595687	20102Q	PARTICIPANT	\N	PRESENT	0
598638	595687	19739H	PARTICIPANT	\N	PRESENT	0
598639	595687	11065P	PARTICIPANT	\N	PRESENT	0
598640	598014	14083S	PARTICIPANT	\N	PRESENT	0
598641	598014	11048N	PARTICIPANT	\N	PRESENT	0
598642	598014	04071H	PARTICIPANT	\N	PRESENT	0
598643	598014	19711U	PRESIDENT	0	PRESENT	0
598644	598014	20070A	PARTICIPANT	\N	PRESENT	0
598645	598014	19687N	PARTICIPANT	\N	PRESENT	0
598646	598014	19741B	PARTICIPANT	\N	PRESENT	0
598647	598014	08010L	PARTICIPANT	\N	PRESENT	0
598648	598014	99004R	PARTICIPANT	\N	PRESENT	0
598649	598014	20044X	PARTICIPANT	\N	PRESENT	0
598650	598014	14173T	PARTICIPANT	\N	PRESENT	0
598651	595687	20136B	PARTICIPANT	\N	PRESENT	0
598652	595687	20096L	PARTICIPANT	\N	PRESENT	0
598653	598014	14189C	PARTICIPANT	\N	PRESENT	0
598654	598014	20126Y	PARTICIPANT	\N	PRESENT	0
598655	598014	19647E	PARTICIPANT	\N	PRESENT	0
598657	598014	01048V	PARTICIPANT	\N	PRESENT	0
598658	598014	11110B	PARTICIPANT	\N	PRESENT	0
598659	598014	19671E	PARTICIPANT	\N	PRESENT	0
598660	598656	11053K	PARTICIPANT	\N	PRESENT	0
598662	598661	19711U	PARTICIPANT	\N	PRESENT	1
598664	598663	08073C	PARTICIPANT	\N	PRESENT	0
598665	598663	20150Y	PARTICIPANT	\N	PRESENT	0
598666	598014	19762G	PARTICIPANT	\N	PRESENT	0
598668	598667	08073C	PARTICIPANT	\N	PRESENT	0
598669	598667	20150Y	PARTICIPANT	\N	PRESENT	0
598670	598014	19667J	PARTICIPANT	\N	PRESENT	0
598672	598671	14327T	PARTICIPANT	\N	PRESENT	0
598674	598673	14327T	PARTICIPANT	\N	PRESENT	0
598676	598675	08010L	PARTICIPANT	\N	PRESENT	0
598677	598014	14225N	PARTICIPANT	\N	EXCUSE	0
598679	598678	08010L	PARTICIPANT	\N	PRESENT	0
598682	598680	08010L	PARTICIPANT	\N	PRESENT	0
598683	598681	08010L	PARTICIPANT	\N	PRESENT	0
598685	598684	11048N	PARTICIPANT	\N	PRESENT	0
598687	598686	11048N	PARTICIPANT	\N	PRESENT	0
598689	598688	11048N	PARTICIPANT	\N	PRESENT	0
598691	598690	11048N	PARTICIPANT	\N	PRESENT	0
598693	598692	11048N	PARTICIPANT	\N	PRESENT	0
598695	598694	20080C	PARTICIPANT	\N	PRESENT	0
598697	598696	20070A	PARTICIPANT	\N	PRESENT	0
598698	598696	11110B	PARTICIPANT	\N	PRESENT	0
598700	595687	20038A	PARTICIPANT	\N	EXCUSE	0
598701	595687	19551W	PARTICIPANT	\N	EXCUSE	0
598702	598073	19719D	PARTICIPANT	\N	PRESENT	0
598704	598703	19762G	PARTICIPANT	\N	PRESENT	0
598705	598703	19531S	PARTICIPANT	\N	PRESENT	0
598707	598706	19531S	PARTICIPANT	\N	PRESENT	0
598708	598706	19762G	PARTICIPANT	\N	PRESENT	0
598709	598073	19387D	PARTICIPANT	\N	PRESENT	0
598710	598073	18083K	PARTICIPANT	\N	PRESENT	0
598712	598711	19531S	PARTICIPANT	\N	PRESENT	0
598713	598711	19762G	PARTICIPANT	\N	PRESENT	0
598714	598073	17229F	PARTICIPANT	\N	PRESENT	0
598715	598073	20062A	PARTICIPANT	\N	PRESENT	0
598716	598073	14031R	PARTICIPANT	\N	PRESENT	0
598717	598073	19820Y	PARTICIPANT	\N	PRESENT	0
598718	598073	19637C	PARTICIPANT	\N	PRESENT	0
598719	598073	14073Q	PARTICIPANT	\N	PRESENT	0
598720	598073	20024T	PARTICIPANT	\N	PRESENT	0
598721	598073	14038Y	PARTICIPANT	\N	PRESENT	0
598727	598073	19515S	PARTICIPANT	\N	PRESENT	0
598722	598017	11040E	PARTICIPANT	\N	PRESENT	0
598723	598017	14331P	PARTICIPANT	\N	PRESENT	0
598724	598017	19479G	PARTICIPANT	\N	PRESENT	0
598725	598017	19711U	PARTICIPANT	\N	PRESENT	0
598726	598017	08034U	PRESIDENT	0	PRESENT	0
598728	598017	19687N	PARTICIPANT	\N	PRESENT	0
571150	571149	11053K	PARTICIPANT	\N	PRESENT	0
571160	571159	08009T	PARTICIPANT	\N	PRESENT	0
571161	571159	20044X	PARTICIPANT	\N	PRESENT	0
571163	571162	01057W	PARTICIPANT	\N	PRESENT	0
571164	571162	14225N	PARTICIPANT	\N	PRESENT	0
571167	571166	20080C	PARTICIPANT	\N	PRESENT	0
571169	571168	20080C	PARTICIPANT	\N	PRESENT	0
571318	571304	19333N	PARTICIPANT	\N	PRESENT	0
571319	571304	14031R	PARTICIPANT	\N	PRESENT	0
571320	571304	14219Q	PRESIDENT	0	PRESENT	0
571321	571304	20020P	PARTICIPANT	\N	PRESENT	0
571322	571304	20102Q	PARTICIPANT	\N	PRESENT	0
571323	571304	19701S	PARTICIPANT	\N	PRESENT	0
571324	571304	19577H	PARTICIPANT	\N	PRESENT	1
571325	571304	11065P	PARTICIPANT	\N	PRESENT	0
571326	571304	19619A	PARTICIPANT	\N	PRESENT	0
571327	571304	14169X	PARTICIPANT	\N	PRESENT	0
571328	571304	19387D	PARTICIPANT	\N	PRESENT	1
571329	571304	20136B	PARTICIPANT	\N	PRESENT	0
571330	571304	19826F	PARTICIPANT	\N	PRESENT	0
571331	571304	19681G	PARTICIPANT	\N	PRESENT	1
571361	571144	14026U	PARTICIPANT	\N	PRESENT	0
571362	571144	20100N	PARTICIPANT	\N	PRESENT	0
571363	571144	20102Q	PARTICIPANT	\N	PRESENT	0
571382	571144	20174H	PARTICIPANT	\N	PRESENT	0
571383	571144	04045F	PARTICIPANT	\N	PRESENT	0
571384	571144	11090Q	PARTICIPANT	\N	PRESENT	0
571385	571144	19333N	PARTICIPANT	\N	PRESENT	0
571386	571144	14207L	PARTICIPANT	\N	PRESENT	0
571387	571144	20020P	PARTICIPANT	\N	PRESENT	0
571388	571144	17229F	PARTICIPANT	\N	PRESENT	0
571389	571144	19826F	PARTICIPANT	\N	PRESENT	0
571390	571144	20116W	PARTICIPANT	\N	PRESENT	0
571391	571144	99004R	PARTICIPANT	\N	PRESENT	0
571392	571144	19619A	PARTICIPANT	\N	PRESENT	0
571393	571144	19507S	PARTICIPANT	\N	PRESENT	0
571394	571144	18083K	PARTICIPANT	\N	PRESENT	0
571395	571144	19515S	PARTICIPANT	\N	PRESENT	0
571396	571144	14031R	PARTICIPANT	\N	PRESENT	0
571397	571144	10015M	PARTICIPANT	\N	PRESENT	0
571398	571144	11065P	PARTICIPANT	\N	PRESENT	0
571399	571144	19701S	PARTICIPANT	\N	PRESENT	0
571403	571144	19369B	PARTICIPANT	\N	PRESENT	0
571404	571144	14219Q	PARTICIPANT	\N	PRESENT	0
571405	571144	20136B	PARTICIPANT	\N	PRESENT	0
571406	571144	14179A	PARTICIPANT	\N	PRESENT	0
571407	571144	20076G	PARTICIPANT	\N	PRESENT	0
571408	571144	20062A	PARTICIPANT	\N	PRESENT	0
571411	571144	19711U	PARTICIPANT	\N	PRESENT	0
571415	571144	14215L	PARTICIPANT	\N	PRESENT	0
571416	571144	20140W	PARTICIPANT	\N	PRESENT	0
571417	571144	19954N	PARTICIPANT	\N	PRESENT	0
571418	571144	11103C	PARTICIPANT	\N	PRESENT	0
571419	571144	14231L	PARTICIPANT	\N	PRESENT	0
571420	571144	14257W	PARTICIPANT	\N	PRESENT	0
571421	571144	04057K	PARTICIPANT	\N	PRESENT	0
571422	571144	19739H	PARTICIPANT	\N	PRESENT	0
571423	571144	20098N	PARTICIPANT	\N	PRESENT	0
571424	571144	19549D	PARTICIPANT	\N	PRESENT	0
571425	571144	19599P	PARTICIPANT	\N	PRESENT	0
571426	571144	19503N	PARTICIPANT	\N	PRESENT	0
571427	571144	19581D	PARTICIPANT	\N	PRESENT	0
571428	571144	08034U	PARTICIPANT	\N	PRESENT	0
571429	571144	19585H	PARTICIPANT	\N	PRESENT	0
571430	571144	14147R	PARTICIPANT	\N	PRESENT	0
571431	571144	20108W	PARTICIPANT	\N	PRESENT	0
571432	571144	11040E	PARTICIPANT	\N	PRESENT	0
571433	571144	19681G	PARTICIPANT	\N	PRESENT	0
571434	571144	08010L	PARTICIPANT	\N	PRESENT	0
571435	571144	20152B	PARTICIPANT	\N	PRESENT	0
571436	571144	01058X	PARTICIPANT	\N	PRESENT	0
571437	571144	20044X	PARTICIPANT	\N	PRESENT	0
571439	571144	19479G	PARTICIPANT	\N	PRESENT	0
571440	571144	08061X	PARTICIPANT	\N	PRESENT	0
571444	571144	04085P	PARTICIPANT	\N	PRESENT	0
571445	571144	20180F	PARTICIPANT	\N	PRESENT	0
571450	571144	19747H	PARTICIPANT	\N	PRESENT	0
571454	571144	01048V	PARTICIPANT	\N	PRESENT	0
571461	571144	11097X	PARTICIPANT	\N	PRESENT	0
571462	571144	14083S	PARTICIPANT	\N	PRESENT	0
571463	571144	20056C	PARTICIPANT	\N	PRESENT	0
571464	571144	14038Y	PARTICIPANT	\N	PRESENT	0
571465	571144	19631V	PARTICIPANT	\N	PRESENT	0
571466	571144	20096L	PARTICIPANT	\N	PRESENT	0
571467	571144	19721W	PARTICIPANT	\N	PRESENT	0
571468	571144	14042U	PARTICIPANT	\N	PRESENT	0
571469	571144	20092G	PARTICIPANT	\N	PRESENT	0
571470	571144	19820Y	PARTICIPANT	\N	PRESENT	0
571471	571144	19347U	PARTICIPANT	\N	PRESENT	0
571472	571144	20066E	PARTICIPANT	\N	PRESENT	0
571473	571144	20018V	PARTICIPANT	\N	PRESENT	0
571474	571144	11067R	PARTICIPANT	\N	PRESENT	0
571475	571144	14357A	PARTICIPANT	\N	PRESENT	0
571476	571144	20126Y	PARTICIPANT	\N	PRESENT	0
571477	571144	19551W	PARTICIPANT	\N	PRESENT	0
571478	571144	20142Y	PARTICIPANT	\N	PRESENT	0
571479	571144	14327T	PARTICIPANT	\N	PRESENT	0
571480	571144	20120S	PARTICIPANT	\N	PRESENT	0
571488	571144	19533U	PARTICIPANT	\N	PRESENT	0
571507	571144	20124W	PARTICIPANT	\N	PRESENT	0
571508	571144	19713W	PARTICIPANT	\N	PRESENT	0
571509	571144	19685L	PARTICIPANT	\N	PRESENT	0
571510	571144	19741B	PARTICIPANT	\N	PRESENT	0
571511	571144	14111D	PARTICIPANT	\N	PRESENT	0
571512	571144	19413M	PARTICIPANT	\N	PRESENT	0
571513	571144	08028W	PARTICIPANT	\N	PRESENT	0
571514	571144	14267Y	PARTICIPANT	\N	PRESENT	0
571515	571144	19798U	PARTICIPANT	\N	PRESENT	0
571516	571144	19467C	PARTICIPANT	\N	PRESENT	0
571517	571144	20118Y	PARTICIPANT	\N	PRESENT	0
571518	571144	20050V	PARTICIPANT	\N	PRESENT	0
571519	571144	14217N	PARTICIPANT	\N	PRESENT	0
571520	571144	19725B	PARTICIPANT	\N	PRESENT	0
571521	571144	20052X	PARTICIPANT	\N	PRESENT	0
571522	571144	20048C	PARTICIPANT	\N	PRESENT	0
571523	571144	14187A	PARTICIPANT	\N	PRESENT	0
571524	571144	19441R	PARTICIPANT	\N	PRESENT	0
571525	571144	07029T	PARTICIPANT	\N	PRESENT	0
571576	571144	14071N	PARTICIPANT	\N	PRESENT	0
571577	571144	18193Q	PARTICIPANT	\N	PRESENT	0
571578	571144	20070A	PARTICIPANT	\N	PRESENT	0
571579	571144	14021P	PARTICIPANT	\N	PRESENT	0
571581	571144	11033F	PARTICIPANT	\N	PRESENT	0
571582	571144	14205J	PARTICIPANT	\N	PRESENT	0
572527	572526	19709B	PARTICIPANT	\N	PRESENT	0
572566	570333	19703U	PARTICIPANT	\N	PRESENT	1
572568	570333	19301E	PARTICIPANT	\N	PRESENT	1
572569	570333	17965H	PARTICIPANT	\N	PRESENT	1
572570	570333	20066E	PARTICIPANT	\N	PRESENT	1
572571	570333	14223L	PARTICIPANT	\N	PRESENT	1
572572	570333	11103C	PARTICIPANT	\N	PRESENT	1
572573	570333	20090E	PARTICIPANT	\N	PRESENT	1
572574	570333	19657G	PARTICIPANT	\N	PRESENT	1
572733	571152	12041X	PARTICIPANT	\N	PRESENT	0
572734	571152	14213J	PARTICIPANT	\N	PRESENT	0
572735	571152	19683J	PARTICIPANT	\N	PRESENT	0
572737	571152	04045F	PARTICIPANT	\N	PRESENT	0
572738	571152	19711U	PARTICIPANT	\N	PRESENT	0
572739	571152	20132W	PARTICIPANT	\N	PRESENT	0
572740	571152	20092G	PARTICIPANT	\N	PRESENT	0
572741	571152	11031D	PARTICIPANT	\N	PRESENT	0
572742	571152	14195A	PARTICIPANT	\N	PRESENT	0
572743	571152	14042U	PARTICIPANT	\N	PRESENT	0
572744	571152	19649G	PARTICIPANT	\N	PRESENT	0
572745	571152	10006L	PARTICIPANT	\N	PRESENT	0
572746	571152	14111D	PARTICIPANT	\N	PRESENT	0
572747	571152	11083R	PARTICIPANT	\N	PRESENT	0
572749	571152	20020P	PARTICIPANT	\N	PRESENT	0
572750	571152	14215L	PARTICIPANT	\N	PRESENT	0
572751	571152	14221J	PARTICIPANT	\N	PRESENT	0
572752	571152	20102Q	PARTICIPANT	\N	PRESENT	0
572753	571152	19251M	PARTICIPANT	\N	PRESENT	0
572754	571152	19954N	PARTICIPANT	\N	PRESENT	0
572756	571152	19507S	PARTICIPANT	\N	PRESENT	0
572757	571152	19713W	PARTICIPANT	\N	PRESENT	0
572759	571152	19447X	PARTICIPANT	\N	PRESENT	0
572761	571152	19599P	PARTICIPANT	\N	PRESENT	0
572762	571152	11040E	PARTICIPANT	\N	PRESENT	0
572765	571152	04047H	PARTICIPANT	\N	PRESENT	0
572767	571152	14217N	PARTICIPANT	\N	PRESENT	0
572768	571152	20072C	PARTICIPANT	\N	PRESENT	0
597487	597486	14042U	PARTICIPANT	\N	PRESENT	1
597488	597486	19723Y	PARTICIPANT	\N	PRESENT	1
597489	597486	20130U	PARTICIPANT	\N	PRESENT	1
597492	594914	14281W	PARTICIPANT	\N	PRESENT	0
597493	594914	18193Q	PARTICIPANT	\N	PRESENT	0
597741	594914	11097X	PARTICIPANT	\N	PRESENT	1
597495	594914	11067R	PARTICIPANT	\N	PRESENT	0
597506	595510	01028R	PARTICIPANT	\N	PRESENT	0
597507	595510	11033F	PARTICIPANT	\N	PRESENT	0
597508	595510	19447X	PARTICIPANT	\N	PRESENT	0
597509	595510	05008E	PARTICIPANT	\N	PRESENT	0
597510	595510	14281W	PARTICIPANT	\N	PRESENT	0
597511	595510	14147R	PARTICIPANT	\N	PRESENT	0
597512	595510	14179A	PARTICIPANT	\N	PRESENT	0
597513	595510	14215L	PARTICIPANT	\N	PRESENT	0
597514	595510	14071N	PARTICIPANT	\N	PRESENT	0
597515	595510	19749K	PARTICIPANT	\N	PRESENT	0
597516	595510	20022R	PARTICIPANT	\N	PRESENT	0
597517	595510	10006L	PARTICIPANT	\N	PRESENT	0
597518	595510	14021P	PARTICIPANT	\N	PRESENT	0
597519	595510	11056N	PARTICIPANT	\N	PRESENT	0
597520	595607	19583F	PARTICIPANT	\N	PRESENT	0
597521	595607	19347U	PARTICIPANT	\N	PRESENT	0
597522	595607	11031D	PARTICIPANT	\N	PRESENT	0
597523	595607	14030Q	PARTICIPANT	\N	PRESENT	0
597524	595607	11012A	PARTICIPANT	\N	PRESENT	0
597525	595607	12028B	PARTICIPANT	\N	PRESENT	0
597526	595607	20106U	PARTICIPANT	\N	PRESENT	0
597527	595607	20172F	PARTICIPANT	\N	PRESENT	0
597528	595607	08061X	PARTICIPANT	\N	PRESENT	0
597529	595510	11097X	PARTICIPANT	\N	PRESENT	1
597530	595510	19543W	PARTICIPANT	\N	PRESENT	0
597531	595510	14213J	PARTICIPANT	\N	PRESENT	1
597532	595510	19713W	PARTICIPANT	\N	PRESENT	1
597533	595510	08045X	PARTICIPANT	\N	PRESENT	1
597534	595510	19723Y	PARTICIPANT	\N	PRESENT	1
597535	595510	20066E	PARTICIPANT	\N	PRESENT	1
597536	595510	11103C	PARTICIPANT	\N	PRESENT	1
597537	595607	14267Y	PARTICIPANT	\N	PRESENT	0
597556	595607	19545Y	PARTICIPANT	\N	PRESENT	0
597560	595607	12041X	PARTICIPANT	\N	PRESENT	0
597562	595607	11040E	PARTICIPANT	\N	PRESENT	0
597564	595607	01058X	PARTICIPANT	\N	PRESENT	0
597567	595607	19689Q	PARTICIPANT	\N	PRESENT	0
597569	595607	20252E	PARTICIPANT	\N	PRESENT	0
597570	595607	01024M	PARTICIPANT	\N	PRESENT	0
597577	595607	11053K	PARTICIPANT	\N	PRESENT	0
597578	594912	19657G	PARTICIPANT	\N	PRESENT	1
597579	594912	20130U	PARTICIPANT	\N	PRESENT	1
597580	594912	19715Y	PARTICIPANT	\N	PRESENT	1
597581	594912	20066E	PARTICIPANT	\N	PRESENT	1
597582	594912	19713W	PARTICIPANT	\N	PRESENT	1
597583	594912	17779H	PARTICIPANT	\N	PRESENT	1
597584	594912	19553Y	PARTICIPANT	\N	PRESENT	1
597585	594912	04092N	PARTICIPANT	\N	PRESENT	1
597586	594912	11103C	PARTICIPANT	\N	PRESENT	1
597587	594912	19591F	PARTICIPANT	\N	PRESENT	1
597589	594912	19295A	PARTICIPANT	\N	EXCUSE	0
597591	595607	20142Y	PARTICIPANT	\N	PRESENT	0
597592	595607	19693L	PARTICIPANT	\N	PRESENT	0
597593	595607	19467C	PARTICIPANT	\N	PRESENT	0
597594	595607	19747H	PARTICIPANT	\N	PRESENT	0
597595	595607	14073Q	PARTICIPANT	\N	PRESENT	0
597596	595607	14189C	PARTICIPANT	\N	PRESENT	0
597597	595607	14033T	PARTICIPANT	\N	PRESENT	0
597598	595607	19741B	PARTICIPANT	\N	PRESENT	0
597600	595717	14038Y	PARTICIPANT	\N	PRESENT	0
597601	595717	19467C	PARTICIPANT	\N	PRESENT	0
597602	595717	19768N	PARTICIPANT	\N	PRESENT	0
597603	595717	19515S	PARTICIPANT	\N	PRESENT	0
597604	595717	19413M	PARTICIPANT	\N	PRESENT	0
597605	595717	11090Q	PRESIDENT	0	PRESENT	0
597606	595717	14033T	PARTICIPANT	\N	PRESENT	0
597607	595717	20094J	PARTICIPANT	\N	PRESENT	0
597608	595717	20054A	PARTICIPANT	\N	PRESENT	0
597609	595717	20062A	PARTICIPANT	\N	PRESENT	1
597610	595717	14251Q	PARTICIPANT	\N	PRESENT	0
597611	595717	19575F	PARTICIPANT	\N	PRESENT	0
597612	595717	19369B	PARTICIPANT	\N	PRESENT	0
597613	595717	19747H	PARTICIPANT	\N	PRESENT	0
597614	595717	20018V	PARTICIPANT	\N	PRESENT	0
597615	595717	14257W	PARTICIPANT	\N	PRESENT	1
597617	595607	19711U	PARTICIPANT	\N	PRESENT	0
597618	595607	19335Q	PARTICIPANT	\N	PRESENT	0
597619	595717	14357A	PARTICIPANT	\N	EXCUSE	0
597620	595717	20104S	PARTICIPANT	\N	EXCUSE	0
597621	595607	19629C	PARTICIPANT	\N	PRESENT	0
597622	595607	19369B	PARTICIPANT	\N	PRESENT	0
597623	595607	19533U	PARTICIPANT	\N	PRESENT	0
597624	595607	14121F	PARTICIPANT	\N	PRESENT	0
597656	595608	11031D	PARTICIPANT	\N	PRESENT	0
597659	595608	11040E	PARTICIPANT	\N	PRESENT	0
597661	595608	19335Q	PARTICIPANT	\N	PRESENT	0
597662	595608	14073Q	PARTICIPANT	\N	PRESENT	0
597663	595608	19369B	PARTICIPANT	\N	PRESENT	0
597664	595608	14030Q	PARTICIPANT	\N	PRESENT	0
597665	595608	01024M	PARTICIPANT	\N	PRESENT	0
597666	595608	19583F	PARTICIPANT	\N	PRESENT	0
597667	595608	20106U	PARTICIPANT	\N	PRESENT	0
597668	595608	20142Y	PARTICIPANT	\N	PRESENT	0
597669	595608	19689Q	PARTICIPANT	\N	PRESENT	0
597670	595608	19347U	PARTICIPANT	\N	PRESENT	0
597671	595608	19545Y	PARTICIPANT	\N	PRESENT	0
597672	595608	14189C	PARTICIPANT	\N	PRESENT	0
597673	595608	11053K	PARTICIPANT	\N	PRESENT	0
597674	595608	12028B	PARTICIPANT	\N	PRESENT	0
597675	595608	19711U	PARTICIPANT	\N	PRESENT	0
597676	595608	19533U	PARTICIPANT	\N	PRESENT	0
597677	595608	19741B	PARTICIPANT	\N	PRESENT	0
597678	595608	20172F	PARTICIPANT	\N	PRESENT	0
597679	595608	19531S	PARTICIPANT	\N	PRESENT	0
597680	595608	08069G	PARTICIPANT	\N	PRESENT	0
597681	595608	19667J	PARTICIPANT	\N	PRESENT	0
597682	595608	19467C	PARTICIPANT	\N	PRESENT	0
597683	595608	19747H	PARTICIPANT	\N	PRESENT	0
597684	595608	08018U	PARTICIPANT	\N	PRESENT	0
597685	595608	19693L	PARTICIPANT	\N	PRESENT	0
597691	595608	11012A	PARTICIPANT	\N	PRESENT	0
597693	595608	19629C	PARTICIPANT	\N	PRESENT	0
597654	595608	99004R	PARTICIPANT	\N	PRESENT	0
597655	595608	12041X	PARTICIPANT	\N	PRESENT	0
597694	595608	08061X	PARTICIPANT	\N	PRESENT	0
597697	595608	14267Y	PARTICIPANT	\N	PRESENT	0
597699	595608	14121F	PARTICIPANT	\N	PRESENT	0
597714	595608	14038Y	PARTICIPANT	\N	PRESENT	0
597715	595608	14219Q	PARTICIPANT	\N	PRESENT	0
597716	595608	07004J	PARTICIPANT	\N	PRESENT	0
597717	594914	19697Q	PARTICIPANT	\N	PRESENT	0
597718	594914	19533U	PARTICIPANT	\N	PRESENT	0
597719	594914	19543W	PARTICIPANT	\N	PRESENT	0
597720	594914	19581D	PARTICIPANT	\N	PRESENT	0
597721	594914	04047H	PARTICIPANT	\N	PRESENT	0
597722	594914	14026U	PARTICIPANT	\N	PRESENT	0
597723	594914	01028R	PARTICIPANT	\N	PRESENT	0
597724	594914	05008E	PARTICIPANT	\N	PRESENT	0
597725	594914	19447X	PARTICIPANT	\N	PRESENT	0
597726	594914	14231L	PARTICIPANT	\N	PRESENT	0
597727	594914	14147R	PARTICIPANT	\N	PRESENT	0
597728	594914	14179A	PARTICIPANT	\N	PRESENT	0
597729	594914	14215L	PARTICIPANT	\N	PRESENT	0
597730	594914	20022R	PARTICIPANT	\N	PRESENT	0
597731	594914	14053L	PARTICIPANT	\N	PRESENT	0
597732	594914	19649G	PARTICIPANT	\N	PRESENT	0
597733	594914	11026G	PARTICIPANT	\N	PRESENT	0
597734	594914	10015M	PARTICIPANT	\N	PRESENT	0
597735	594914	11033F	PARTICIPANT	\N	PRESENT	0
597736	594914	11056N	PARTICIPANT	\N	PRESENT	0
597737	594914	14071N	PARTICIPANT	\N	PRESENT	0
597738	594914	19749K	PARTICIPANT	\N	PRESENT	0
597739	594914	14021P	PARTICIPANT	\N	PRESENT	0
597740	594914	11103C	PARTICIPANT	\N	PRESENT	1
597742	594914	20066E	PARTICIPANT	\N	PRESENT	1
597743	594914	08045X	PARTICIPANT	\N	PRESENT	1
597744	594914	14213J	PARTICIPANT	\N	PRESENT	1
597745	594914	20128B	PARTICIPANT	\N	PRESENT	1
597746	594914	19713W	PARTICIPANT	\N	PRESENT	1
597747	594914	19723Y	PARTICIPANT	\N	PRESENT	1
597748	594914	10006L	PRESIDENT	0	PRESENT	0
597749	595608	14147R	PARTICIPANT	\N	PRESENT	0
597751	595608	19647E	PARTICIPANT	\N	PRESENT	0
597752	595608	20108W	PARTICIPANT	\N	PRESENT	0
570208	566530	01043Q	PARTICIPANT	\N	PRESENT	0
570209	566530	14205J	PARTICIPANT	\N	PRESENT	0
570210	566530	19413M	PARTICIPANT	\N	PRESENT	0
570211	568173	07004J	PARTICIPANT	\N	PRESENT	0
570212	568173	20108W	PARTICIPANT	\N	PRESENT	0
570242	568173	14089Y	PARTICIPANT	\N	PRESENT	0
570214	566530	14207L	PARTICIPANT	\N	PRESENT	0
570215	566530	01028R	PARTICIPANT	\N	PRESENT	0
570216	566530	20076G	PARTICIPANT	\N	PRESENT	0
570217	568173	19749K	PARTICIPANT	\N	PRESENT	0
570218	566530	20046A	PARTICIPANT	\N	PRESENT	0
570221	566530	19701S	PARTICIPANT	\N	PRESENT	0
570222	566530	20094J	PARTICIPANT	\N	PRESENT	0
570223	566530	20102Q	PARTICIPANT	\N	PRESENT	0
570224	566530	19711U	PARTICIPANT	\N	PRESENT	0
570225	566530	14111D	PARTICIPANT	\N	PRESENT	0
570226	566530	11090Q	PARTICIPANT	\N	PRESENT	0
570227	566530	19467C	PARTICIPANT	\N	PRESENT	0
570228	566530	19826F	PARTICIPANT	\N	PRESENT	0
570230	566530	14083S	PARTICIPANT	\N	PRESENT	0
570231	568173	14147R	PARTICIPANT	\N	PRESENT	0
570232	568173	14215L	PARTICIPANT	\N	PRESENT	0
570233	568173	04047H	PRESIDENT	0	PRESENT	0
570235	566530	14219Q	PARTICIPANT	\N	PRESENT	0
570237	566530	19760E	PARTICIPANT	\N	PRESENT	0
570238	566530	11031D	PARTICIPANT	\N	PRESENT	0
570240	566530	20020P	PARTICIPANT	\N	PRESENT	0
570241	566530	14097Y	PARTICIPANT	\N	PRESENT	0
570243	568173	95063L	PARTICIPANT	\N	PRESENT	0
570244	566530	19637C	PARTICIPANT	\N	PRESENT	0
570261	566530	14257W	PARTICIPANT	\N	PRESENT	0
570246	568173	10015M	PARTICIPANT	\N	PRESENT	0
570247	566530	19333N	PARTICIPANT	\N	PRESENT	0
570249	566530	20100N	PARTICIPANT	\N	PRESENT	0
570251	566530	11065P	PARTICIPANT	\N	PRESENT	0
570254	566530	19515S	PARTICIPANT	\N	PRESENT	0
570256	566530	19549D	PARTICIPANT	\N	PRESENT	0
570257	566530	20070A	PARTICIPANT	\N	PRESENT	0
570258	566530	04045F	PARTICIPANT	\N	PRESENT	0
570259	566530	19820Y	PARTICIPANT	\N	PRESENT	0
570260	566530	19251M	PARTICIPANT	\N	PRESENT	0
570262	566530	97011G	PARTICIPANT	\N	PRESENT	0
570263	566530	11012A	PARTICIPANT	\N	PRESENT	0
570264	566530	20180F	PARTICIPANT	\N	PRESENT	0
570265	566530	17367Q	PARTICIPANT	\N	PRESENT	0
570266	566530	20038A	PARTICIPANT	\N	PRESENT	0
570267	566530	14031R	PARTICIPANT	\N	PRESENT	0
570268	566530	07029T	PARTICIPANT	\N	PRESENT	0
578722	578721	11083R	PARTICIPANT	\N	PRESENT	0
578725	578724	17737W	PARTICIPANT	\N	PRESENT	0
578784	578747	19749K	PARTICIPANT	\N	PRESENT	0
578785	578747	20130U	PARTICIPANT	\N	PRESENT	1
578787	578747	14109K	PARTICIPANT	\N	PRESENT	1
578788	578747	14030Q	PARTICIPANT	\N	PRESENT	0
578899	577328	01028R	PARTICIPANT	\N	PRESENT	0
578900	577328	14231L	PARTICIPANT	\N	PRESENT	0
578901	577328	11056N	PARTICIPANT	\N	PRESENT	0
578922	578173	20034V	PARTICIPANT	\N	PRESENT	0
578923	578173	14038Y	PARTICIPANT	\N	PRESENT	0
578924	578173	20076G	PARTICIPANT	\N	PRESENT	0
578925	578173	18083K	PARTICIPANT	\N	PRESENT	0
578926	578173	19657G	PARTICIPANT	\N	PRESENT	0
578927	578173	20044X	PARTICIPANT	\N	PRESENT	0
578928	578173	20032T	PARTICIPANT	\N	PRESENT	0
578929	578173	19489J	PARTICIPANT	\N	PRESENT	0
578930	578173	14001X	PARTICIPANT	\N	PRESENT	0
578931	578173	19599P	PARTICIPANT	\N	PRESENT	0
578932	578173	20130U	PARTICIPANT	\N	PRESENT	0
578933	578173	19301E	PARTICIPANT	\N	PRESENT	0
578934	578173	20050V	PARTICIPANT	\N	PRESENT	0
578935	578173	14259Y	PARTICIPANT	\N	PRESENT	0
578936	578173	14217N	PARTICIPANT	\N	PRESENT	0
578937	578173	04047H	PARTICIPANT	\N	PRESENT	0
578938	578173	14215L	PARTICIPANT	\N	PRESENT	0
578939	578173	11097X	PARTICIPANT	\N	PRESENT	0
578940	578173	19503N	PARTICIPANT	\N	PRESENT	0
578941	578173	19683J	PARTICIPANT	\N	PRESENT	0
578942	578173	14083S	PARTICIPANT	\N	PRESENT	0
578943	578173	20026V	PARTICIPANT	\N	PRESENT	0
578944	578173	20058E	PARTICIPANT	\N	PRESENT	0
578945	578173	19758L	PARTICIPANT	\N	PRESENT	0
578946	578173	19760E	PARTICIPANT	\N	PRESENT	0
578947	578173	14042U	PARTICIPANT	\N	PRESENT	0
578948	578173	11012A	PARTICIPANT	\N	PRESENT	0
578949	578173	14231L	PARTICIPANT	\N	PRESENT	0
578950	578173	14327T	PARTICIPANT	\N	PRESENT	0
578951	578173	14169X	PARTICIPANT	\N	PRESENT	0
578952	578173	19711U	PARTICIPANT	\N	PRESENT	0
578953	578173	11056N	PARTICIPANT	\N	PRESENT	0
578954	578173	17367Q	PARTICIPANT	\N	PRESENT	0
578955	578173	19717B	PARTICIPANT	\N	PRESENT	0
578956	578173	11070L	PARTICIPANT	\N	PRESENT	0
578957	578173	19349W	PARTICIPANT	\N	PRESENT	0
578958	578173	19647E	PARTICIPANT	\N	PRESENT	0
578959	578173	20110Q	PARTICIPANT	\N	PRESENT	0
578960	578173	01028R	PARTICIPANT	\N	PRESENT	0
578961	578173	20134Y	PARTICIPANT	\N	PRESENT	0
578962	578173	04092N	PARTICIPANT	\N	PRESENT	0
578963	578173	10006L	PARTICIPANT	\N	PRESENT	0
578964	578173	11099A	PARTICIPANT	\N	PRESENT	0
578965	578173	07029T	PARTICIPANT	\N	PRESENT	0
578966	578173	14073Q	PARTICIPANT	\N	PRESENT	0
578967	578173	19713W	PARTICIPANT	\N	PRESENT	0
578968	578173	19715Y	PARTICIPANT	\N	PRESENT	0
578969	578173	14219Q	PARTICIPANT	\N	PRESENT	0
578970	578173	08010L	PARTICIPANT	\N	PRESENT	0
578971	578173	20120S	PARTICIPANT	\N	PRESENT	0
578976	578173	04085P	PARTICIPANT	\N	PRESENT	0
578977	578173	20128B	PARTICIPANT	\N	PRESENT	0
578978	578173	14331P	PARTICIPANT	\N	PRESENT	0
578979	578173	17779H	PARTICIPANT	\N	PRESENT	0
578980	578173	20098N	PARTICIPANT	\N	PRESENT	0
578981	578173	19533U	PARTICIPANT	\N	PRESENT	0
578982	578173	20096L	PARTICIPANT	\N	PRESENT	0
578983	578173	19447X	PARTICIPANT	\N	PRESENT	0
578984	578173	17023S	PARTICIPANT	\N	PRESENT	0
578985	578173	20102Q	PARTICIPANT	\N	PRESENT	0
578986	578173	20100N	PARTICIPANT	\N	PRESENT	0
579006	578173	04043D	PARTICIPANT	\N	PRESENT	0
579010	578173	20126Y	PARTICIPANT	\N	PRESENT	0
579053	578175	19689Q	PARTICIPANT	\N	PRESENT	0
579054	578175	19349W	PARTICIPANT	\N	PRESENT	0
579055	578175	11012A	PARTICIPANT	\N	PRESENT	0
579056	578175	19687N	PARTICIPANT	\N	PRESENT	0
579057	578175	20070A	PARTICIPANT	\N	PRESENT	0
579058	578175	14055N	PARTICIPANT	\N	PRESENT	0
579059	578175	19711U	PARTICIPANT	\N	PRESENT	0
579060	578175	11070L	PARTICIPANT	\N	PRESENT	0
579062	578175	14189C	PARTICIPANT	\N	PRESENT	0
579063	578175	19647E	PARTICIPANT	\N	PRESENT	0
579064	578175	20044X	PARTICIPANT	\N	PRESENT	0
579065	578175	14225N	PARTICIPANT	\N	PRESENT	0
579066	578175	10006L	PARTICIPANT	\N	PRESENT	0
579067	578175	11048N	PARTICIPANT	\N	PRESENT	0
579068	578175	14042U	PARTICIPANT	\N	PRESENT	0
579069	578175	19667J	PARTICIPANT	\N	PRESENT	0
579070	578175	20026V	PARTICIPANT	\N	PRESENT	0
579071	578175	14083S	PARTICIPANT	\N	PRESENT	0
579072	578175	20034V	PARTICIPANT	\N	PRESENT	0
579073	578175	20080C	PARTICIPANT	\N	PRESENT	0
579074	578175	04034C	PARTICIPANT	\N	PRESENT	0
579075	578175	14259Y	PARTICIPANT	\N	PRESENT	0
579076	578175	19593H	PARTICIPANT	\N	PRESENT	0
579077	578175	04092N	PARTICIPANT	\N	PRESENT	0
579078	578175	20032T	PARTICIPANT	\N	PRESENT	0
579079	578175	11053K	PARTICIPANT	\N	PRESENT	0
579080	578175	11040E	PARTICIPANT	\N	PRESENT	0
579081	578175	11097X	PARTICIPANT	\N	PRESENT	0
579082	578175	14327T	PARTICIPANT	\N	PRESENT	0
579083	578175	20076G	PARTICIPANT	\N	PRESENT	0
579084	578175	20102Q	PARTICIPANT	\N	PRESENT	0
579085	578175	20126Y	PARTICIPANT	\N	PRESENT	0
579086	578175	20130U	PARTICIPANT	\N	PRESENT	0
579087	578175	19760E	PARTICIPANT	\N	PRESENT	0
579088	578175	08011M	PARTICIPANT	\N	PRESENT	0
579089	578175	11085T	PARTICIPANT	\N	PRESENT	0
579090	578175	19583F	PARTICIPANT	\N	PRESENT	0
579049	578175	01043Q	PARTICIPANT	\N	PRESENT	0
579052	578175	20050V	PARTICIPANT	\N	PRESENT	0
579091	578175	20046A	PARTICIPANT	\N	PRESENT	0
596654	596653	19725B	PARTICIPANT	\N	PRESENT	0
596655	596653	14026U	PARTICIPANT	\N	PRESENT	0
596658	596652	14026U	PARTICIPANT	\N	PRESENT	0
596659	596652	19725B	PARTICIPANT	\N	PRESENT	0
598729	598017	99004R	PARTICIPANT	\N	PRESENT	0
598730	598017	19667J	PARTICIPANT	\N	PRESENT	0
598731	598017	20126Y	PARTICIPANT	\N	PRESENT	0
598732	598017	19762G	PARTICIPANT	\N	PRESENT	0
598733	598017	14225N	PARTICIPANT	\N	EXCUSE	0
598734	598073	20076G	PARTICIPANT	\N	PRESENT	0
598735	598073	14221J	PARTICIPANT	\N	PRESENT	0
598736	598017	11048N	PARTICIPANT	\N	PRESENT	0
598737	598073	11065P	PARTICIPANT	\N	PRESENT	0
598738	598073	19347U	PARTICIPANT	\N	PRESENT	0
598739	598073	19333N	PARTICIPANT	\N	PRESENT	0
598740	598073	19503N	PARTICIPANT	\N	PRESENT	0
598741	598017	20080C	PARTICIPANT	\N	PRESENT	0
598742	598017	08010L	PARTICIPANT	\N	PRESENT	0
598743	598017	20044X	PARTICIPANT	\N	PRESENT	0
598744	598017	19335Q	PARTICIPANT	\N	PRESENT	0
598745	598073	19251M	PARTICIPANT	\N	PRESENT	0
598746	598073	08009T	PARTICIPANT	\N	PRESENT	0
598747	598073	14219Q	PARTICIPANT	\N	PRESENT	0
598748	598073	20102Q	PARTICIPANT	\N	PRESENT	0
598749	598073	19593H	PARTICIPANT	\N	PRESENT	0
598750	598073	20112S	PARTICIPANT	\N	PRESENT	0
598751	598073	20046A	PARTICIPANT	\N	PRESENT	0
598752	598017	19671E	PARTICIPANT	\N	PRESENT	0
598753	598073	19565D	PARTICIPANT	\N	PRESENT	0
598754	598073	19507S	PARTICIPANT	\N	PRESENT	0
598755	598017	19689Q	PARTICIPANT	\N	PRESENT	0
598756	598073	20026V	PARTICIPANT	\N	PRESENT	0
598757	598073	20134Y	PARTICIPANT	\N	PRESENT	0
598758	598017	11074Q	PARTICIPANT	\N	PRESENT	0
598759	598073	20180F	PARTICIPANT	\N	PRESENT	0
598760	598073	14147R	PARTICIPANT	\N	PRESENT	0
598761	598073	19399H	PARTICIPANT	\N	PRESENT	0
598762	598017	07029T	PARTICIPANT	\N	PRESENT	0
598763	598073	20052X	PARTICIPANT	\N	PRESENT	0
598764	598073	19549D	PARTICIPANT	\N	PRESENT	0
598765	598073	11103C	PARTICIPANT	\N	PRESENT	0
598766	598073	14105F	PARTICIPANT	\N	PRESENT	0
598767	598073	11067R	PARTICIPANT	\N	PRESENT	0
598768	598017	14083S	PARTICIPANT	\N	PRESENT	0
598769	598073	14069U	PARTICIPANT	\N	PRESENT	0
598770	598073	20136B	PARTICIPANT	\N	PRESENT	0
598771	598017	20116W	PARTICIPANT	\N	PRESENT	0
598772	598017	01057W	PARTICIPANT	\N	PRESENT	0
598773	598073	20038A	PARTICIPANT	\N	PRESENT	0
598774	598073	20090E	PARTICIPANT	\N	PRESENT	0
598775	598017	19545Y	PARTICIPANT	\N	PRESENT	0
598776	598073	97011G	PARTICIPANT	\N	PRESENT	0
598777	598017	20070A	PARTICIPANT	\N	PRESENT	0
598778	598073	19701S	PARTICIPANT	\N	PRESENT	0
598779	598073	19583F	PARTICIPANT	\N	PRESENT	0
598780	598017	19741B	PARTICIPANT	\N	PRESENT	0
598781	598073	11033F	PARTICIPANT	\N	PRESENT	0
598782	598073	14179A	PARTICIPANT	\N	PRESENT	0
598783	598073	17023S	PARTICIPANT	\N	PRESENT	0
598784	598073	20092G	PARTICIPANT	\N	PRESENT	0
598785	598073	19699S	PARTICIPANT	\N	PRESENT	0
598787	598786	14255U	PARTICIPANT	\N	PRESENT	1
598788	598786	20064C	PARTICIPANT	\N	PRESENT	1
598789	598073	19782L	PARTICIPANT	\N	PRESENT	0
598790	598073	14033T	PARTICIPANT	\N	PRESENT	0
598791	598073	20056C	PARTICIPANT	\N	PRESENT	0
598792	598073	19533U	PARTICIPANT	\N	PRESENT	0
598793	598073	20174H	PARTICIPANT	\N	PRESENT	0
598794	598073	14189C	PARTICIPANT	\N	PRESENT	0
598795	598073	14042U	PARTICIPANT	\N	PRESENT	0
598796	598073	19569H	PARTICIPANT	\N	PRESENT	0
598797	598073	14231L	PARTICIPANT	\N	PRESENT	0
598798	598073	20152B	PARTICIPANT	\N	PRESENT	0
598799	598073	19581D	PARTICIPANT	\N	PRESENT	0
598800	598073	19367Y	PARTICIPANT	\N	PRESENT	0
598801	598073	20030R	PARTICIPANT	\N	PRESENT	0
598802	598073	20018V	PARTICIPANT	\N	PRESENT	0
598803	598073	01025N	PARTICIPANT	\N	PRESENT	0
598805	598804	19711U	PARTICIPANT	\N	PRESENT	0
598807	598806	19711U	PARTICIPANT	\N	PRESENT	0
598808	598073	19443T	PARTICIPANT	\N	PRESENT	0
598809	598073	19826F	PARTICIPANT	\N	PRESENT	0
598810	598073	20048C	PARTICIPANT	\N	PRESENT	0
598811	598073	20032T	PARTICIPANT	\N	PRESENT	0
598812	598073	19573D	PARTICIPANT	\N	PRESENT	0
598813	598073	19689Q	PARTICIPANT	\N	PRESENT	0
598814	598073	19739H	PARTICIPANT	\N	PRESENT	0
598815	598073	19551W	PARTICIPANT	\N	PRESENT	0
598816	598073	20028X	PARTICIPANT	\N	PRESENT	0
598817	598073	20100N	PARTICIPANT	\N	PRESENT	0
598818	598073	19631V	PARTICIPANT	\N	PRESENT	0
598819	598073	14021P	PARTICIPANT	\N	PRESENT	0
598820	598017	20252E	PARTICIPANT	\N	PRESENT	0
598821	598017	14189C	PARTICIPANT	\N	PRESENT	0
598822	598073	20120S	PARTICIPANT	\N	PRESENT	0
598823	598073	19543W	PARTICIPANT	\N	PRESENT	0
598824	598017	14173T	PARTICIPANT	\N	PRESENT	0
598825	598073	20054A	PARTICIPANT	\N	PRESENT	0
598826	598073	19383Y	PARTICIPANT	\N	PRESENT	0
598827	598073	04071H	PARTICIPANT	\N	PRESENT	0
598828	598073	01048V	PARTICIPANT	\N	PRESENT	0
598829	598017	11097X	PARTICIPANT	\N	PRESENT	0
598830	598073	20058E	PARTICIPANT	\N	PRESENT	0
598831	598073	20082E	PARTICIPANT	\N	PRESENT	0
598832	598073	19629C	PARTICIPANT	\N	PRESENT	0
598833	598073	19575F	PARTICIPANT	\N	PRESENT	0
598834	598073	19467C	PARTICIPANT	\N	PRESENT	0
598835	598017	11012A	PARTICIPANT	\N	EXCUSE	0
598836	598073	14257W	PARTICIPANT	\N	PRESENT	0
598837	598073	19745F	PARTICIPANT	\N	PRESENT	0
598838	598073	14207L	PARTICIPANT	\N	PRESENT	0
598839	598073	20068G	PARTICIPANT	\N	PRESENT	0
598840	598073	20044X	PARTICIPANT	\N	PRESENT	0
598841	598073	20122U	PARTICIPANT	\N	PRESENT	0
598842	598073	19447X	PARTICIPANT	\N	PRESENT	0
598843	598073	20116W	PARTICIPANT	\N	PRESENT	0
598844	598073	20078J	PARTICIPANT	\N	PRESENT	0
598845	598073	20042V	PARTICIPANT	\N	PRESENT	0
598927	598074	19719D	PARTICIPANT	\N	PRESENT	0
598928	598074	19549D	PARTICIPANT	\N	PRESENT	0
598929	598074	19820Y	PARTICIPANT	\N	PRESENT	0
598930	598074	14257W	PARTICIPANT	\N	PRESENT	0
598931	598074	20082E	PARTICIPANT	\N	PRESENT	0
598932	598074	19503N	PARTICIPANT	\N	PRESENT	0
598933	598074	20100N	PARTICIPANT	\N	PRESENT	0
598934	598074	19347U	PARTICIPANT	\N	PRESENT	0
598935	598074	20092G	PARTICIPANT	\N	PRESENT	0
598936	598074	20134Y	PARTICIPANT	\N	PRESENT	0
598937	598074	20112S	PARTICIPANT	\N	PRESENT	0
598938	598074	20122U	PARTICIPANT	\N	PRESENT	0
598939	598074	14221J	PARTICIPANT	\N	PRESENT	0
598940	598074	19629C	PARTICIPANT	\N	PRESENT	0
598941	598074	20116W	PARTICIPANT	\N	PRESENT	0
598942	598074	19387D	PARTICIPANT	\N	PRESENT	0
598943	598074	19637C	PARTICIPANT	\N	PRESENT	0
598944	598074	14207L	PARTICIPANT	\N	PRESENT	0
598945	598074	19631V	PARTICIPANT	\N	PRESENT	0
598946	598074	20102Q	PARTICIPANT	\N	PRESENT	0
598947	598074	20046A	PARTICIPANT	\N	PRESENT	0
598948	598074	19575F	PARTICIPANT	\N	PRESENT	0
598949	598074	19593H	PARTICIPANT	\N	PRESENT	0
598950	598074	11043H	PARTICIPANT	\N	PRESENT	0
598951	598074	19782L	PARTICIPANT	\N	PRESENT	0
598952	598074	20172F	PARTICIPANT	\N	PRESENT	0
598953	598074	14031R	PARTICIPANT	\N	PRESENT	0
598954	598074	19701S	PARTICIPANT	\N	PRESENT	0
598955	598074	19467C	PARTICIPANT	\N	PRESENT	0
598956	598074	14147R	PARTICIPANT	\N	PRESENT	0
598957	598074	19383Y	PARTICIPANT	\N	PRESENT	0
598958	598074	14105F	PARTICIPANT	\N	PRESENT	0
598959	598074	08056B	PARTICIPANT	\N	PRESENT	0
598960	598074	20068G	PARTICIPANT	\N	PRESENT	0
598961	598074	19747H	PARTICIPANT	\N	PRESENT	0
598962	598074	20090E	PARTICIPANT	\N	PRESENT	0
598963	598074	11103C	PARTICIPANT	\N	PRESENT	0
598964	598074	20042V	PARTICIPANT	\N	PRESENT	0
598965	598074	18083K	PARTICIPANT	\N	PRESENT	0
598966	598074	14179A	PARTICIPANT	\N	PRESENT	0
598967	598074	19543W	PARTICIPANT	\N	PRESENT	0
598968	598074	14219Q	PARTICIPANT	\N	PRESENT	0
598969	598074	19739H	PARTICIPANT	\N	PRESENT	0
579586	579585	05008E	PARTICIPANT	\N	PRESENT	0
579587	579585	11053K	PARTICIPANT	\N	PRESENT	0
579588	579585	01028R	PARTICIPANT	\N	PRESENT	0
579608	579607	14089Y	PARTICIPANT	\N	PRESENT	0
579609	579607	14053L	PARTICIPANT	\N	PRESENT	0
579611	579610	14089Y	PARTICIPANT	\N	PRESENT	0
579612	579610	14053L	PARTICIPANT	\N	PRESENT	0
579614	579613	14089Y	PARTICIPANT	\N	PRESENT	0
579618	579613	19649G	PARTICIPANT	\N	PRESENT	0
579616	579613	14053L	PARTICIPANT	\N	PRESENT	0
579617	579613	20114U	PARTICIPANT	\N	PRESENT	0
579620	579619	14089Y	PARTICIPANT	\N	PRESENT	0
579621	579619	14053L	PARTICIPANT	\N	PRESENT	0
579622	579619	20114U	PARTICIPANT	\N	PRESENT	0
579624	579623	14089Y	PARTICIPANT	\N	PRESENT	0
579625	579623	14053L	PARTICIPANT	\N	PRESENT	0
579727	579132	14053L	PARTICIPANT	\N	PRESENT	0
579728	579132	14111D	PARTICIPANT	\N	PRESENT	0
579729	579132	10015M	PARTICIPANT	\N	PRESENT	0
579730	579132	11026G	PARTICIPANT	\N	PRESENT	0
579731	579132	19585H	PARTICIPANT	\N	PRESENT	0
579732	579132	04047H	PRESIDENT	0	PRESENT	0
579733	579132	14231L	PARTICIPANT	\N	PRESENT	0
579734	579132	95063L	PARTICIPANT	\N	PRESENT	0
579735	579132	14041T	PARTICIPANT	\N	PRESENT	0
579736	579132	20110Q	PARTICIPANT	\N	PRESENT	0
579737	579132	14147R	PARTICIPANT	\N	PRESENT	0
579738	579132	14215L	PARTICIPANT	\N	PRESENT	0
579739	579132	04008A	PARTICIPANT	\N	PRESENT	0
579740	579132	11072N	PARTICIPANT	\N	PRESENT	0
579741	579132	14089Y	PARTICIPANT	\N	PRESENT	0
579742	579132	11056N	PARTICIPANT	\N	PRESENT	0
579743	579132	14259Y	PARTICIPANT	\N	PRESENT	0
579744	579132	05008E	PARTICIPANT	\N	PRESENT	0
579745	579132	20074E	PARTICIPANT	\N	EXCUSE	0
579746	579388	07029T	PARTICIPANT	\N	PRESENT	0
579747	579388	14147R	PARTICIPANT	\N	PRESENT	0
579748	579132	11033F	PARTICIPANT	\N	PRESENT	1
579749	579388	14089Y	PARTICIPANT	\N	PRESENT	0
579750	579132	14179A	PARTICIPANT	\N	PRESENT	1
579751	579132	19629C	PARTICIPANT	\N	PRESENT	1
579752	579132	14107H	PARTICIPANT	\N	PRESENT	1
579753	579388	14213J	PARTICIPANT	\N	PRESENT	0
579754	579388	20098N	PARTICIPANT	\N	PRESENT	0
579755	579388	19565D	PARTICIPANT	\N	PRESENT	0
579756	579388	19383Y	PARTICIPANT	\N	PRESENT	0
579757	579388	20072C	PARTICIPANT	\N	PRESENT	0
579758	579388	20020P	PARTICIPANT	\N	PRESENT	0
579759	579388	19667J	PARTICIPANT	\N	PRESENT	0
579760	579388	14205J	PARTICIPANT	\N	PRESENT	0
579761	579388	19719D	PARTICIPANT	\N	PRESENT	0
579762	579388	20096L	PARTICIPANT	\N	PRESENT	0
579764	579763	10006L	PARTICIPANT	\N	PRESENT	0
579765	579388	19798U	PARTICIPANT	\N	PRESENT	0
579766	579388	20032T	PARTICIPANT	\N	PRESENT	0
579767	579388	19735D	PARTICIPANT	\N	PRESENT	0
579768	579388	19685L	PARTICIPANT	\N	PRESENT	0
579769	579388	19741B	PARTICIPANT	\N	PRESENT	0
579770	579388	14237S	PARTICIPANT	\N	PRESENT	0
579771	579388	20102Q	PARTICIPANT	\N	PRESENT	0
579772	579388	01028R	PARTICIPANT	\N	PRESENT	0
579773	579388	14207L	PARTICIPANT	\N	PRESENT	0
579774	579388	14123H	PARTICIPANT	\N	PRESENT	0
579775	579388	19479G	PARTICIPANT	\N	PRESENT	0
579776	579388	11045K	PARTICIPANT	\N	PRESENT	0
579777	579388	14105F	PARTICIPANT	\N	PRESENT	0
579778	579388	14195A	PARTICIPANT	\N	PRESENT	0
579779	579388	10006L	PARTICIPANT	\N	PRESENT	0
579780	579388	11026G	PARTICIPANT	\N	PRESENT	0
579781	579388	20046A	PARTICIPANT	\N	PRESENT	0
579782	579388	20024T	PARTICIPANT	\N	PRESENT	0
579784	579388	19782L	PARTICIPANT	\N	PRESENT	0
579785	579783	14205J	PARTICIPANT	\N	PRESENT	0
579786	579783	20174H	PARTICIPANT	\N	PRESENT	0
579787	579388	18083K	PARTICIPANT	\N	PRESENT	0
579789	579788	14205J	PARTICIPANT	\N	PRESENT	0
579790	579788	20174H	PARTICIPANT	\N	PRESENT	0
579792	579791	14205J	PARTICIPANT	\N	PRESENT	0
579793	579791	20174H	PARTICIPANT	\N	PRESENT	0
579794	579791	14207L	PARTICIPANT	\N	PRESENT	0
579796	579795	14205J	PARTICIPANT	\N	PRESENT	0
579797	579795	20174H	PARTICIPANT	\N	PRESENT	0
579798	579388	08010L	PARTICIPANT	\N	PRESENT	0
579825	579389	11070L	PARTICIPANT	\N	PRESENT	0
579826	579806	19333N	PARTICIPANT	\N	PRESENT	0
579827	579806	20140W	PARTICIPANT	\N	PRESENT	0
579828	579806	19387D	PARTICIPANT	\N	PRESENT	0
579829	579806	20046A	PARTICIPANT	\N	PRESENT	0
579830	579806	19685L	PARTICIPANT	\N	PRESENT	0
579807	579806	19701S	PARTICIPANT	\N	PRESENT	0
579808	579806	20136B	PARTICIPANT	\N	PRESENT	0
579809	579806	20038A	PARTICIPANT	\N	PRESENT	0
579810	579806	20076G	PARTICIPANT	\N	PRESENT	0
579811	579806	14219Q	PRESIDENT	0	PRESENT	0
579812	579806	17229F	PARTICIPANT	\N	PRESENT	0
579813	579806	20096L	PARTICIPANT	\N	PRESENT	0
579814	579806	18083K	PARTICIPANT	\N	PRESENT	0
579815	579806	20100N	PARTICIPANT	\N	PRESENT	0
579816	579806	05012A	PARTICIPANT	\N	PRESENT	0
579817	579806	20118Y	PARTICIPANT	\N	PRESENT	0
579818	579806	19739H	PARTICIPANT	\N	PRESENT	0
579819	579806	11065P	PARTICIPANT	\N	PRESENT	0
579820	579806	20032T	PARTICIPANT	\N	PRESENT	0
579821	579806	19820Y	PARTICIPANT	\N	PRESENT	0
579822	579806	20068G	PARTICIPANT	\N	PRESENT	0
579823	579806	20020P	PARTICIPANT	\N	PRESENT	0
579824	579806	20120S	PARTICIPANT	\N	PRESENT	0
579831	579806	19525U	PARTICIPANT	\N	PRESENT	0
579832	579806	19826F	PARTICIPANT	\N	PRESENT	0
579833	579806	19599P	PARTICIPANT	\N	PRESENT	0
579834	579806	19503N	PARTICIPANT	\N	PRESENT	0
579835	579806	17367Q	PARTICIPANT	\N	PRESENT	0
579836	579806	20102Q	PARTICIPANT	\N	PRESENT	0
579837	579806	19637C	PARTICIPANT	\N	PRESENT	0
579838	579806	20024T	PARTICIPANT	\N	PRESENT	0
579839	579806	19619A	PARTICIPANT	\N	PRESENT	0
579840	579389	19701S	PARTICIPANT	\N	PRESENT	0
579841	579389	19826F	PARTICIPANT	\N	PRESENT	0
579842	579389	20136B	PARTICIPANT	\N	PRESENT	0
579843	579806	19549D	PARTICIPANT	\N	PRESENT	0
579844	579389	19637C	PARTICIPANT	\N	PRESENT	0
579845	579389	14207L	PARTICIPANT	\N	PRESENT	0
579846	579389	20046A	PARTICIPANT	\N	PRESENT	0
579847	579389	20102Q	PARTICIPANT	\N	PRESENT	0
579848	579389	19549D	PARTICIPANT	\N	PRESENT	0
579849	579389	14219Q	PARTICIPANT	\N	PRESENT	0
579850	579389	11090Q	PARTICIPANT	\N	PRESENT	0
579851	579389	14031R	PARTICIPANT	\N	PRESENT	0
579852	579389	19525U	PARTICIPANT	\N	PRESENT	0
579853	579389	14033T	PARTICIPANT	\N	PRESENT	0
579854	579389	18083K	PARTICIPANT	\N	PRESENT	0
579855	579806	19251M	PARTICIPANT	\N	PRESENT	0
579856	579806	08060W	PARTICIPANT	\N	EXCUSE	0
579857	579389	19387D	PARTICIPANT	\N	PRESENT	0
579858	579389	19583F	PARTICIPANT	\N	PRESENT	0
579859	579389	19619A	PARTICIPANT	\N	PRESENT	0
579860	579389	19533U	PARTICIPANT	\N	PRESENT	0
579861	579389	20090E	PARTICIPANT	\N	PRESENT	0
579862	579389	14231L	PARTICIPANT	\N	PRESENT	0
579863	579389	01025N	PARTICIPANT	\N	PRESENT	0
579864	579389	20088L	PARTICIPANT	\N	PRESENT	0
579865	579389	20112S	PARTICIPANT	\N	PRESENT	0
579866	579389	19503N	PARTICIPANT	\N	PRESENT	0
579867	579389	20076G	PARTICIPANT	\N	PRESENT	0
579868	579389	19333N	PARTICIPANT	\N	PRESENT	0
579870	579389	20100N	PARTICIPANT	\N	PRESENT	0
579871	579389	11065P	PARTICIPANT	\N	PRESENT	0
579872	579389	19739H	PARTICIPANT	\N	PRESENT	0
579873	579389	14073Q	PARTICIPANT	\N	PRESENT	0
579874	579389	19349W	PARTICIPANT	\N	PRESENT	0
579875	579389	17229F	PARTICIPANT	\N	PRESENT	0
579876	579389	20072C	PARTICIPANT	\N	PRESENT	0
579877	579389	20116W	PARTICIPANT	\N	PRESENT	0
579878	579389	19747H	PARTICIPANT	\N	PRESENT	0
579879	579389	20020P	PARTICIPANT	\N	PRESENT	0
579880	579389	20120S	PARTICIPANT	\N	PRESENT	0
579881	579389	19798U	PARTICIPANT	\N	PRESENT	0
579882	579389	20134Y	PARTICIPANT	\N	PRESENT	0
579883	579389	97011G	PARTICIPANT	\N	PRESENT	0
579884	579389	20050V	PARTICIPANT	\N	PRESENT	0
571281	571280	14259Y	PARTICIPANT	\N	PRESENT	0
571282	571280	14231L	PARTICIPANT	\N	PRESENT	0
571286	571285	14231L	PARTICIPANT	\N	PRESENT	0
571289	571287	14231L	PARTICIPANT	\N	PRESENT	0
571292	571291	14231L	PARTICIPANT	\N	PRESENT	0
575908	575105	07004J	PARTICIPANT	\N	PRESENT	0
571297	571291	20110Q	PARTICIPANT	\N	PRESENT	0
573521	571741	14147R	PARTICIPANT	\N	PRESENT	0
575909	575266	08061X	PARTICIPANT	\N	PRESENT	0
575910	575266	20124W	PARTICIPANT	\N	PRESENT	0
575911	575266	20128B	PARTICIPANT	\N	PRESENT	0
575912	575266	14179A	PARTICIPANT	\N	PRESENT	0
575913	575266	20126Y	PARTICIPANT	\N	PRESENT	0
575914	575266	14219Q	PARTICIPANT	\N	PRESENT	0
575915	575266	20034V	PARTICIPANT	\N	PRESENT	0
575916	575266	19723Y	PARTICIPANT	\N	PRESENT	0
575917	575266	20046A	PARTICIPANT	\N	PRESENT	0
575925	575266	08045X	PARTICIPANT	\N	PRESENT	0
575926	575266	20058E	PARTICIPANT	\N	PRESENT	0
575927	575266	19383Y	PARTICIPANT	\N	PRESENT	0
575928	575266	19443T	PARTICIPANT	\N	PRESENT	0
575929	575105	14179A	PARTICIPANT	\N	PRESENT	0
575930	575266	14073Q	PARTICIPANT	\N	PRESENT	0
575931	575266	19369B	PARTICIPANT	\N	PRESENT	0
575932	575266	19333N	PARTICIPANT	\N	PRESENT	0
575933	575266	14237S	PARTICIPANT	\N	PRESENT	0
575934	575266	19599P	PARTICIPANT	\N	PRESENT	0
575935	575266	11043H	PARTICIPANT	\N	PRESENT	0
575936	575266	14030Q	PARTICIPANT	\N	PRESENT	0
575937	575266	14169X	PARTICIPANT	\N	PRESENT	0
578910	578908	19575F	PRESIDENT	0	PRESENT	1
578911	578908	20128B	PARTICIPANT	\N	PRESENT	1
578912	578908	19551W	PARTICIPANT	\N	PRESENT	1
578913	578908	19687N	PARTICIPANT	\N	PRESENT	0
578914	578908	19749K	PARTICIPANT	\N	PRESENT	1
584421	583456	19711U	PARTICIPANT	\N	PRESENT	0
584422	583456	19531S	PARTICIPANT	\N	PRESENT	0
584423	583456	19687N	PARTICIPANT	\N	PRESENT	0
584427	583463	14053L	PARTICIPANT	\N	PRESENT	0
584428	583463	14111D	PARTICIPANT	\N	PRESENT	0
584429	583463	20074E	PARTICIPANT	\N	PRESENT	0
584430	583463	19543W	PARTICIPANT	\N	PRESENT	0
584431	583463	04047H	PRESIDENT	0	PRESENT	0
584432	583463	19447X	PARTICIPANT	\N	PRESENT	0
584433	583463	14231L	PARTICIPANT	\N	PRESENT	0
584434	583463	14089Y	PARTICIPANT	\N	PRESENT	0
584435	583463	19725B	PARTICIPANT	\N	PRESENT	0
584436	583463	19954N	PARTICIPANT	\N	PRESENT	0
584437	583463	11056N	PARTICIPANT	\N	PRESENT	0
584438	583463	14107H	PARTICIPANT	\N	PRESENT	0
584439	583463	20110Q	PARTICIPANT	\N	PRESENT	0
584440	583463	14147R	PARTICIPANT	\N	PRESENT	0
584441	583463	14179A	PARTICIPANT	\N	PRESENT	0
584442	583463	14069U	PARTICIPANT	\N	PRESENT	0
584443	583463	20114U	PARTICIPANT	\N	PRESENT	0
584444	583463	14151M	PARTICIPANT	\N	PRESENT	0
584445	583463	14215L	PARTICIPANT	\N	PRESENT	0
584446	583463	19749K	PARTICIPANT	\N	PRESENT	0
584447	583463	14021P	PARTICIPANT	\N	PRESENT	0
584448	583463	07004J	PARTICIPANT	\N	EXCUSE	0
584449	583463	19673G	PARTICIPANT	\N	EXCUSE	0
584453	583456	14225N	PRESIDENT	0	PRESENT	0
584454	583456	14083S	PARTICIPANT	\N	PRESENT	0
584457	583456	18083K	PARTICIPANT	\N	PRESENT	0
584475	583456	07029T	PARTICIPANT	\N	EXCUSE	0
584477	583463	14001X	PARTICIPANT	\N	PRESENT	0
584478	583463	19581D	PARTICIPANT	\N	PRESENT	0
584479	583463	01028R	PARTICIPANT	\N	PRESENT	0
584480	583463	05008E	PARTICIPANT	\N	PRESENT	0
584481	583463	11072N	PARTICIPANT	\N	PRESENT	0
584482	583463	19729F	PARTICIPANT	\N	PRESENT	0
584489	583456	19533U	PARTICIPANT	\N	PRESENT	0
584615	583497	12016W	PARTICIPANT	\N	PRESENT	0
584616	583497	19583F	PARTICIPANT	\N	PRESENT	0
584617	583497	14195A	PARTICIPANT	\N	PRESENT	0
584618	583497	19729F	PARTICIPANT	\N	PRESENT	0
584619	583497	19507S	PARTICIPANT	\N	PRESENT	0
584620	583497	14105F	PARTICIPANT	\N	PRESENT	0
584621	583497	11080N	PARTICIPANT	\N	PRESENT	0
584622	583497	20046A	PARTICIPANT	\N	PRESENT	0
584623	583497	20102Q	PARTICIPANT	\N	PRESENT	0
584624	583497	14253S	PARTICIPANT	\N	PRESENT	0
584625	583497	20086J	PARTICIPANT	\N	PRESENT	0
584626	583497	14223L	PARTICIPANT	\N	PRESENT	0
584627	583497	08017T	PARTICIPANT	\N	PRESENT	0
584630	583497	20024T	PARTICIPANT	\N	PRESENT	0
584633	583497	20052X	PARTICIPANT	\N	PRESENT	0
584636	583497	14259Y	PARTICIPANT	\N	PRESENT	0
584638	583497	20068G	PARTICIPANT	\N	PRESENT	0
584641	583497	08056B	PARTICIPANT	\N	PRESENT	0
584646	583497	14173T	PARTICIPANT	\N	PRESENT	0
584650	583497	11085T	PARTICIPANT	\N	PRESENT	0
584652	583497	14041T	PARTICIPANT	\N	PRESENT	0
584654	583497	20076G	PARTICIPANT	\N	PRESENT	0
584667	583497	19766L	PARTICIPANT	\N	PRESENT	0
584662	583497	14097Y	PARTICIPANT	\N	PRESENT	0
584664	583497	20056C	PARTICIPANT	\N	PRESENT	0
584668	583497	20092G	PARTICIPANT	\N	PRESENT	0
584669	583497	20144B	PARTICIPANT	\N	PRESENT	0
584670	583497	14267Y	PARTICIPANT	\N	PRESENT	0
584671	583497	19333N	PARTICIPANT	\N	PRESENT	0
584672	583497	14069U	PARTICIPANT	\N	PRESENT	0
584673	583497	04057K	PARTICIPANT	\N	PRESENT	0
584674	583497	19511N	PARTICIPANT	\N	PRESENT	0
584675	583497	19563B	PARTICIPANT	\N	PRESENT	0
584676	583497	19443T	PARTICIPANT	\N	PRESENT	0
584677	583497	14059S	PARTICIPANT	\N	PRESENT	0
584679	583497	20084G	PARTICIPANT	\N	PRESENT	0
584685	583497	19866P	PARTICIPANT	\N	PRESENT	0
584687	583497	19387D	PARTICIPANT	\N	PRESENT	0
584688	583497	19629C	PARTICIPANT	\N	PRESENT	0
584690	583497	20028X	PARTICIPANT	\N	PRESENT	0
584698	583497	20072C	PARTICIPANT	\N	PRESENT	0
584699	583497	20082E	PARTICIPANT	\N	PRESENT	0
584700	583497	14229S	PARTICIPANT	\N	PRESENT	0
584701	583497	14107H	PARTICIPANT	\N	PRESENT	0
584702	583497	20116W	PARTICIPANT	\N	PRESENT	0
584703	583497	19669L	PARTICIPANT	\N	PRESENT	0
584704	583497	04034C	PARTICIPANT	\N	PRESENT	0
584705	583497	19349W	PARTICIPANT	\N	PRESENT	0
584706	583497	99004R	PARTICIPANT	\N	PRESENT	0
584707	583497	14231L	PARTICIPANT	\N	PRESENT	0
584708	583497	19820Y	PARTICIPANT	\N	PRESENT	0
584709	583497	20126Y	PARTICIPANT	\N	PRESENT	0
584710	583497	19954N	PARTICIPANT	\N	PRESENT	0
584711	583497	11041F	PARTICIPANT	\N	PRESENT	0
584712	583497	19599P	PARTICIPANT	\N	PRESENT	0
584713	583497	14257W	PARTICIPANT	\N	PRESENT	0
584714	583497	19367Y	PARTICIPANT	\N	PRESENT	0
584716	583497	01025N	PARTICIPANT	\N	PRESENT	0
584717	583497	04070G	PARTICIPANT	\N	PRESENT	0
584718	583497	11064N	PARTICIPANT	\N	PRESENT	0
584719	583497	20252E	PARTICIPANT	\N	PRESENT	0
584721	583497	20048C	PARTICIPANT	\N	PRESENT	0
584722	583497	19593H	PARTICIPANT	\N	PRESENT	0
584723	583497	19549D	PARTICIPANT	\N	PRESENT	0
584724	583497	12028B	PARTICIPANT	\N	PRESENT	0
584725	583497	11097X	PARTICIPANT	\N	PRESENT	0
584726	583497	19581D	PARTICIPANT	\N	PRESENT	0
584727	583497	04045F	PARTICIPANT	\N	PRESENT	0
584728	583497	14055N	PARTICIPANT	\N	PRESENT	0
584729	583497	20020P	PARTICIPANT	\N	PRESENT	0
584730	583497	08018U	PARTICIPANT	\N	PRESENT	0
584732	583497	20152B	PARTICIPANT	\N	PRESENT	0
584733	583497	20128B	PARTICIPANT	\N	PRESENT	0
584735	583497	19347U	PARTICIPANT	\N	PRESENT	0
584736	583497	20142Y	PARTICIPANT	\N	PRESENT	0
584737	583497	20088L	PARTICIPANT	\N	PRESENT	0
584738	583497	20030R	PARTICIPANT	\N	PRESENT	0
584739	583497	20018V	PARTICIPANT	\N	PRESENT	0
584740	583497	19631V	PARTICIPANT	\N	PRESENT	0
584741	583497	17589D	PARTICIPANT	\N	PRESENT	0
584742	583497	08061X	PARTICIPANT	\N	PRESENT	0
584743	583497	14083S	PARTICIPANT	\N	PRESENT	0
584744	583497	19369B	PARTICIPANT	\N	PRESENT	0
584745	583497	19251M	PARTICIPANT	\N	PRESENT	0
584746	583497	16685X	PARTICIPANT	\N	PRESENT	0
584747	583497	14073Q	PARTICIPANT	\N	PRESENT	0
584748	583497	12041X	PARTICIPANT	\N	PRESENT	0
584749	583497	11083R	PARTICIPANT	\N	PRESENT	0
584750	583497	20042V	PARTICIPANT	\N	PRESENT	0
584790	583497	19413M	PARTICIPANT	\N	PRESENT	0
584791	583497	19711U	PARTICIPANT	\N	PRESENT	0
584792	583497	19489J	PARTICIPANT	\N	PRESENT	0
584793	583497	19725B	PARTICIPANT	\N	PRESENT	0
584794	583497	19693L	PARTICIPANT	\N	PRESENT	0
584795	583497	11110B	PARTICIPANT	\N	PRESENT	0
584796	583497	14001X	PARTICIPANT	\N	PRESENT	0
584797	583497	11045K	PARTICIPANT	\N	PRESENT	0
584798	583497	08010L	PARTICIPANT	\N	PRESENT	0
584799	583497	19760E	PARTICIPANT	\N	PRESENT	0
584800	583497	04047H	PARTICIPANT	\N	PRESENT	0
584801	583497	11040E	PARTICIPANT	\N	PRESENT	0
584802	583497	14026U	PARTICIPANT	\N	PRESENT	0
584803	583497	08034U	PARTICIPANT	\N	PRESENT	0
584804	583497	01028R	PARTICIPANT	\N	PRESENT	0
584805	583497	11048N	PARTICIPANT	\N	PRESENT	0
584806	583497	14123H	PARTICIPANT	\N	PRESENT	0
584807	583497	19713W	PARTICIPANT	\N	PRESENT	0
584808	583497	20074E	PARTICIPANT	\N	PRESENT	0
584809	583497	19699S	PARTICIPANT	\N	PRESENT	0
584810	583497	19619A	PARTICIPANT	\N	PRESENT	0
584811	583497	19479G	PARTICIPANT	\N	PRESENT	0
584812	583497	14219Q	PARTICIPANT	\N	PRESENT	0
584813	583497	14042U	PARTICIPANT	\N	PRESENT	0
584814	583497	01048V	PARTICIPANT	\N	PRESENT	0
584815	583497	19739H	PARTICIPANT	\N	PRESENT	0
584816	583497	04033B	PARTICIPANT	\N	PRESENT	0
584817	583497	14179A	PARTICIPANT	\N	PRESENT	0
584818	583497	14187A	PARTICIPANT	\N	PRESENT	0
584819	583497	14071N	PARTICIPANT	\N	PRESENT	0
584820	583497	20040T	PARTICIPANT	\N	PRESENT	0
584821	583497	14255U	PARTICIPANT	\N	PRESENT	0
584822	583497	19415P	PARTICIPANT	\N	PRESENT	0
584823	583497	11033F	PARTICIPANT	\N	PRESENT	0
584824	583497	14215L	PARTICIPANT	\N	PRESENT	0
584825	583497	20110Q	PARTICIPANT	\N	PRESENT	0
584826	583497	19525U	PARTICIPANT	\N	PRESENT	0
584827	583497	19701S	PARTICIPANT	\N	PRESENT	0
584828	583497	01043Q	PARTICIPANT	\N	PRESENT	0
584829	583497	04043D	PARTICIPANT	\N	PRESENT	0
584830	583497	14030Q	PARTICIPANT	\N	PRESENT	0
584831	583497	14327T	PARTICIPANT	\N	PRESENT	0
584832	583497	05012A	PARTICIPANT	\N	PRESENT	0
584833	583497	20066E	PARTICIPANT	\N	PRESENT	0
584834	583497	14205J	PARTICIPANT	\N	PRESENT	0
584835	583497	20022R	PARTICIPANT	\N	PRESENT	0
584836	583497	19691J	PARTICIPANT	\N	PRESENT	0
584837	583497	95063L	PARTICIPANT	\N	PRESENT	0
584838	583497	11072N	PARTICIPANT	\N	PRESENT	0
584839	583497	19695N	PARTICIPANT	\N	PRESENT	0
584840	583497	19515S	PARTICIPANT	\N	PRESENT	0
584841	583497	19399H	PARTICIPANT	\N	PRESENT	0
584842	583497	18083K	PARTICIPANT	\N	PRESENT	0
584843	583497	14189C	PARTICIPANT	\N	PRESENT	0
584844	583497	20094J	PARTICIPANT	\N	PRESENT	0
584845	583497	19533U	PARTICIPANT	\N	PRESENT	0
584846	583497	14193X	PARTICIPANT	\N	PRESENT	0
584847	583497	14281W	PARTICIPANT	\N	PRESENT	0
584848	583497	19383Y	PARTICIPANT	\N	PRESENT	0
584849	583497	97011G	PARTICIPANT	\N	PRESENT	0
584850	583497	14147R	PARTICIPANT	\N	PRESENT	0
584851	583497	20138D	PARTICIPANT	\N	PRESENT	0
584852	583497	20098N	PARTICIPANT	\N	PRESENT	0
584853	583497	08047A	PARTICIPANT	\N	PRESENT	0
584854	583497	92040Q	PARTICIPANT	\N	PRESENT	0
584855	583497	20026V	PARTICIPANT	\N	PRESENT	0
584856	583497	20062A	PARTICIPANT	\N	PRESENT	0
584857	583497	19447X	PARTICIPANT	\N	PRESENT	0
584858	583497	14038Y	PARTICIPANT	\N	PRESENT	0
584859	583497	11053K	PARTICIPANT	\N	PRESENT	0
584860	583497	19723Y	PARTICIPANT	\N	PRESENT	0
584861	583497	20180F	PARTICIPANT	\N	PRESENT	0
584862	583497	19467C	PARTICIPANT	\N	PRESENT	0
584863	583497	14033T	PARTICIPANT	\N	PRESENT	0
584864	583497	20104S	PARTICIPANT	\N	PRESENT	0
584865	583497	20108W	PARTICIPANT	\N	PRESENT	0
584866	583497	20148F	PARTICIPANT	\N	PRESENT	0
584867	583497	14213J	PARTICIPANT	\N	PRESENT	0
584868	583497	14357A	PARTICIPANT	\N	PRESENT	0
584869	583497	19621T	PARTICIPANT	\N	PRESENT	0
584870	583497	17737W	PARTICIPANT	\N	PRESENT	0
584871	583497	20120S	PARTICIPANT	\N	PRESENT	0
584872	583497	14331P	PARTICIPANT	\N	PRESENT	0
584873	583497	20090E	PARTICIPANT	\N	PRESENT	0
584874	583497	19768N	PARTICIPANT	\N	PRESENT	0
584875	583497	19643A	PARTICIPANT	\N	PRESENT	0
584876	583497	20096L	PARTICIPANT	\N	PRESENT	0
584877	583497	19741B	PARTICIPANT	\N	PRESENT	0
584878	583497	08069G	PARTICIPANT	\N	PRESENT	0
584879	583497	20044X	PARTICIPANT	\N	PRESENT	0
584881	583497	20058E	PARTICIPANT	\N	PRESENT	0
584882	583497	11090Q	PARTICIPANT	\N	PRESENT	0
584883	583497	20124W	PARTICIPANT	\N	PRESENT	0
584884	583497	20032T	PARTICIPANT	\N	PRESENT	0
584885	583497	86034E	PARTICIPANT	\N	PRESENT	0
584890	583497	19687N	PARTICIPANT	\N	PRESENT	0
584892	583497	01057W	PARTICIPANT	\N	PRESENT	0
584893	583497	11099A	PARTICIPANT	\N	PRESENT	0
584894	583497	19735D	PARTICIPANT	\N	PRESENT	0
584895	583497	14221J	PARTICIPANT	\N	PRESENT	0
584896	583497	20050V	PARTICIPANT	\N	PRESENT	0
584897	583497	14251Q	PARTICIPANT	\N	PRESENT	0
584898	583497	19671E	PARTICIPANT	\N	PRESENT	0
584899	583497	19531S	PARTICIPANT	\N	PRESENT	0
584900	583497	19573D	PARTICIPANT	\N	PRESENT	0
584901	583497	19663E	PARTICIPANT	\N	PRESENT	0
584902	583497	01024M	PARTICIPANT	\N	PRESENT	0
584903	583497	20080C	PARTICIPANT	\N	PRESENT	0
584904	583497	20248J	PARTICIPANT	\N	PRESENT	0
584905	583497	19611R	PARTICIPANT	\N	PRESENT	0
584906	583497	17229F	PARTICIPANT	\N	PRESENT	0
584907	583497	98018T	PARTICIPANT	\N	PRESENT	0
584908	583497	11043H	PARTICIPANT	\N	PRESENT	0
584909	583497	19553Y	PARTICIPANT	\N	PRESENT	0
584910	583497	19681G	PARTICIPANT	\N	PRESENT	0
584911	583497	20136B	PARTICIPANT	\N	PRESENT	0
584912	583497	11026G	PARTICIPANT	\N	PRESENT	0
584913	583497	14249W	PARTICIPANT	\N	PRESENT	0
584914	583497	19575F	PARTICIPANT	\N	PRESENT	0
584915	583497	20174H	PARTICIPANT	\N	PRESENT	0
585163	583498	19719D	PARTICIPANT	\N	PRESENT	0
585164	583498	19479G	PARTICIPANT	\N	PRESENT	0
585165	583498	19629C	PARTICIPANT	\N	PRESENT	0
585166	583498	14207L	PARTICIPANT	\N	PRESENT	0
585167	583498	14257W	PARTICIPANT	\N	PRESENT	0
585168	583498	20094J	PARTICIPANT	\N	PRESENT	0
585169	583498	19599P	PARTICIPANT	\N	PRESENT	0
585170	583498	11099A	PARTICIPANT	\N	PRESENT	0
585171	583498	20174H	PARTICIPANT	\N	PRESENT	0
585172	583498	14195A	PARTICIPANT	\N	PRESENT	0
585173	583498	14111D	PARTICIPANT	\N	PRESENT	0
585174	583498	19441R	PARTICIPANT	\N	PRESENT	0
585175	583498	19549D	PARTICIPANT	\N	PRESENT	0
585176	583498	19820Y	PARTICIPANT	\N	PRESENT	0
585177	583498	19713W	PARTICIPANT	\N	PRESENT	0
585178	583498	11090Q	PARTICIPANT	\N	PRESENT	0
585179	583498	14205J	PARTICIPANT	\N	PRESENT	0
585180	583498	19367Y	PARTICIPANT	\N	PRESENT	0
585181	583498	04045F	PARTICIPANT	\N	PRESENT	0
585182	583498	08061X	PARTICIPANT	\N	PRESENT	0
585183	583498	95063L	PARTICIPANT	\N	PRESENT	0
585184	583498	19695N	PARTICIPANT	\N	PRESENT	0
585186	583498	20102Q	PARTICIPANT	\N	PRESENT	0
585187	583498	20068G	PARTICIPANT	\N	PRESENT	0
585188	583498	19758L	PARTICIPANT	\N	PRESENT	0
585189	583498	20082E	PARTICIPANT	\N	PRESENT	0
585190	583498	19413M	PARTICIPANT	\N	PRESENT	0
585191	583498	20018V	PARTICIPANT	\N	PRESENT	0
585192	583498	20028X	PARTICIPANT	\N	PRESENT	0
585193	583498	20026V	PARTICIPANT	\N	PRESENT	0
585194	583498	19507S	PARTICIPANT	\N	PRESENT	0
585195	583498	20032T	PARTICIPANT	\N	PRESENT	0
585196	583498	14033T	PARTICIPANT	\N	PRESENT	0
585197	583498	20056C	PARTICIPANT	\N	PRESENT	0
585199	583498	14069U	PARTICIPANT	\N	PRESENT	0
585200	583498	19467C	PARTICIPANT	\N	PRESENT	0
585201	583498	20180F	PARTICIPANT	\N	PRESENT	0
585202	583498	19533U	PARTICIPANT	\N	PRESENT	0
585203	583498	14073Q	PARTICIPANT	\N	PRESENT	0
570616	566533	12041X	PARTICIPANT	\N	PRESENT	0
570635	566533	14219Q	PARTICIPANT	\N	PRESENT	0
570636	568176	10015M	PARTICIPANT	\N	PRESENT	0
570637	568176	14259Y	PARTICIPANT	\N	PRESENT	0
570638	568176	14231L	PARTICIPANT	\N	PRESENT	0
570639	566533	19826F	PARTICIPANT	\N	PRESENT	0
570640	566533	19251M	PARTICIPANT	\N	PRESENT	0
570641	566533	19413M	PARTICIPANT	\N	PRESENT	0
570642	566533	19599P	PARTICIPANT	\N	PRESENT	0
570643	566533	19333N	PARTICIPANT	\N	PRESENT	0
570644	566533	19503N	PARTICIPANT	\N	PRESENT	0
570645	566533	11031D	PARTICIPANT	\N	PRESENT	0
570646	568176	14215L	PARTICIPANT	\N	PRESENT	0
570647	566533	04085P	PARTICIPANT	\N	PRESENT	0
570648	566533	20102Q	PARTICIPANT	\N	PRESENT	0
570649	566533	04045F	PARTICIPANT	\N	PRESENT	0
570650	566533	11012A	PARTICIPANT	\N	PRESENT	0
570651	566533	20076G	PARTICIPANT	\N	PRESENT	0
570652	566533	19681G	PARTICIPANT	\N	PRESENT	0
570653	566533	14207L	PARTICIPANT	\N	PRESENT	0
570654	566533	19515S	PARTICIPANT	\N	PRESENT	0
570655	566533	14031R	PARTICIPANT	\N	PRESENT	0
570656	566533	20092G	PARTICIPANT	\N	PRESENT	0
570657	566533	14257W	PARTICIPANT	\N	PRESENT	0
570658	566533	20068G	PARTICIPANT	\N	PRESENT	0
570659	566533	19683J	PARTICIPANT	\N	PRESENT	0
570660	566533	18083K	PARTICIPANT	\N	PRESENT	0
570661	566533	14083S	PARTICIPANT	\N	PRESENT	0
570662	566533	19399H	PARTICIPANT	\N	PRESENT	0
570663	566533	19549D	PARTICIPANT	\N	PRESENT	0
570664	566533	07029T	PARTICIPANT	\N	PRESENT	0
570665	566533	20038A	PARTICIPANT	\N	PRESENT	0
570666	566533	17229F	PARTICIPANT	\N	PRESENT	0
570667	566533	17367Q	PARTICIPANT	\N	PRESENT	0
570668	566533	14033T	PARTICIPANT	\N	PRESENT	0
570669	566533	19619A	PARTICIPANT	\N	PRESENT	0
570670	568176	14041T	PARTICIPANT	\N	PRESENT	0
570671	568176	19749K	PARTICIPANT	\N	PRESENT	0
570672	566533	19369B	PARTICIPANT	\N	PRESENT	0
570673	566533	14217N	PARTICIPANT	\N	PRESENT	0
570674	566533	20020P	PARTICIPANT	\N	PRESENT	0
571128	567855	14133K	PARTICIPANT	\N	PRESENT	1
571129	567855	19333N	PARTICIPANT	\N	PRESENT	0
571130	567855	10015M	PARTICIPANT	\N	PRESENT	0
571131	567855	14331P	PRESIDENT	0	PRESENT	0
571132	567855	20128B	PARTICIPANT	\N	PRESENT	1
571133	567855	14189C	PARTICIPANT	\N	EXCUSE	0
571134	567855	04057K	PARTICIPANT	\N	EXCUSE	0
571135	567855	19563B	PARTICIPANT	\N	EXCUSE	0
571138	567855	14089Y	PARTICIPANT	\N	EXCUSE	0
571172	571171	20050V	PARTICIPANT	\N	PRESENT	0
576018	575107	20074E	PARTICIPANT	\N	PRESENT	0
576019	575107	04047H	PRESIDENT	0	PRESENT	0
576020	575107	19673G	PARTICIPANT	\N	PRESENT	0
576021	575107	01028R	PARTICIPANT	\N	PRESENT	0
576022	575107	14231L	PARTICIPANT	\N	PRESENT	0
576023	575107	19447X	PARTICIPANT	\N	PRESENT	0
576024	575107	05008E	PARTICIPANT	\N	PRESENT	0
576025	575107	19954N	PARTICIPANT	\N	PRESENT	0
576026	575107	19489J	PARTICIPANT	\N	PRESENT	0
576027	575107	07004J	PARTICIPANT	\N	PRESENT	0
576028	575107	14041T	PARTICIPANT	\N	PRESENT	0
576029	575107	20110Q	PARTICIPANT	\N	PRESENT	0
576030	575107	14147R	PARTICIPANT	\N	PRESENT	0
576031	575107	14179A	PARTICIPANT	\N	PRESENT	0
576032	575107	14151M	PARTICIPANT	\N	PRESENT	0
576033	575107	14215L	PARTICIPANT	\N	PRESENT	0
576034	575107	14259Y	PARTICIPANT	\N	PRESENT	0
576035	575107	11072N	PARTICIPANT	\N	PRESENT	0
576036	575107	14053L	PARTICIPANT	\N	PRESENT	0
576037	575107	14111D	PARTICIPANT	\N	PRESENT	0
576038	575107	10015M	PARTICIPANT	\N	PRESENT	0
576039	575107	14089Y	PARTICIPANT	\N	PRESENT	0
576040	575107	11056N	PARTICIPANT	\N	PRESENT	0
576041	575107	19729F	PARTICIPANT	\N	PRESENT	0
576042	575107	95063L	PARTICIPANT	\N	PRESENT	0
576043	575107	19749K	PARTICIPANT	\N	PRESENT	0
576064	575233	14331P	PARTICIPANT	\N	PRESENT	0
576065	575233	11048N	PARTICIPANT	\N	PRESENT	0
576066	575233	20036X	PARTICIPANT	\N	PRESENT	0
576067	575233	19711U	PARTICIPANT	\N	PRESENT	0
576068	575233	14189C	PARTICIPANT	\N	PRESENT	0
576069	575233	19531S	PARTICIPANT	\N	PRESENT	0
576070	575233	01057W	PARTICIPANT	\N	PRESENT	0
576071	575233	19689Q	PARTICIPANT	\N	PRESENT	0
576072	575233	11053K	PARTICIPANT	\N	PRESENT	0
576073	575233	20080C	PARTICIPANT	\N	PRESENT	0
576074	575233	08011M	PARTICIPANT	\N	PRESENT	0
576075	575233	20044X	PARTICIPANT	\N	PRESENT	0
576076	575233	14225N	PARTICIPANT	\N	PRESENT	0
576077	575233	14173T	PARTICIPANT	\N	PRESENT	0
576078	575233	11040E	PARTICIPANT	\N	PRESENT	0
576079	575233	14083S	PARTICIPANT	\N	PRESENT	0
576080	575233	19741B	PARTICIPANT	\N	PRESENT	0
576081	575233	08010L	PARTICIPANT	\N	PRESENT	0
576082	575233	20116W	PARTICIPANT	\N	PRESENT	0
576083	575233	14253S	PARTICIPANT	\N	PRESENT	0
576084	575233	99004R	PARTICIPANT	\N	PRESENT	0
576085	575233	20022R	PARTICIPANT	\N	PRESENT	0
576086	575233	19762G	PARTICIPANT	\N	PRESENT	0
576102	575233	04086Q	PARTICIPANT	\N	PRESENT	0
576103	575233	20070A	PARTICIPANT	\N	PRESENT	0
576114	575107	14001X	PARTICIPANT	\N	PRESENT	0
576115	575107	19649G	PARTICIPANT	\N	PRESENT	0
576128	575244	19443T	PARTICIPANT	\N	PRESENT	0
576129	575244	19565D	PARTICIPANT	\N	PRESENT	0
576130	575244	20072C	PARTICIPANT	\N	PRESENT	0
576131	575244	04034C	PARTICIPANT	\N	PRESENT	1
576132	575244	01058X	PARTICIPANT	\N	PRESENT	0
576133	575244	11027H	PARTICIPANT	\N	PRESENT	0
576134	575244	11066Q	PARTICIPANT	\N	PRESENT	0
576135	575244	08056B	PARTICIPANT	\N	PRESENT	0
576136	575244	12028B	PARTICIPANT	\N	PRESENT	0
576137	575244	19421M	PARTICIPANT	\N	PRESENT	0
576138	575244	19709B	PARTICIPANT	\N	PRESENT	0
576139	575244	14193X	PRESIDENT	0	PRESENT	0
576140	575244	19347U	PARTICIPANT	\N	PRESENT	0
576141	575244	97011G	PARTICIPANT	\N	PRESENT	0
576142	575244	08061X	PARTICIPANT	\N	PRESENT	0
576143	575244	14249W	PARTICIPANT	\N	PRESENT	0
576144	575244	08047A	PARTICIPANT	\N	PRESENT	1
576145	575244	14059S	PARTICIPANT	\N	PRESENT	0
576146	575244	14097Y	PARTICIPANT	\N	PRESENT	0
576147	575244	04035D	PARTICIPANT	\N	PRESENT	0
576148	575244	01062T	PARTICIPANT	\N	PRESENT	0
576149	575244	20042V	PARTICIPANT	\N	PRESENT	0
576150	575244	01024M	PARTICIPANT	\N	PRESENT	0
576151	575244	14105F	PARTICIPANT	\N	PRESENT	1
576152	575244	20064C	PARTICIPANT	\N	PRESENT	0
576153	575244	98018T	PARTICIPANT	\N	PRESENT	1
576154	575244	14267Y	PARTICIPANT	\N	PRESENT	0
576155	575244	11083R	PARTICIPANT	\N	PRESENT	1
576156	575244	14211G	PARTICIPANT	\N	PRESENT	0
576157	575233	19667J	PARTICIPANT	\N	PRESENT	0
576158	575107	11026G	PARTICIPANT	\N	PRESENT	0
576159	575233	19687N	PARTICIPANT	\N	PRESENT	0
576165	575244	11064N	PARTICIPANT	\N	PRESENT	0
576174	575244	04042C	PRESIDENT	1	PRESENT	0
576184	575067	18083K	PARTICIPANT	\N	PRESENT	0
576185	575067	20096L	PARTICIPANT	\N	PRESENT	0
576186	575067	17229F	PARTICIPANT	\N	PRESENT	0
576187	575067	19701S	PARTICIPANT	\N	PRESENT	0
576188	575067	14031R	PARTICIPANT	\N	PRESENT	0
576189	575067	20102Q	PARTICIPANT	\N	PRESENT	0
576190	575067	19333N	PARTICIPANT	\N	PRESENT	0
576191	575067	20076G	PARTICIPANT	\N	PRESENT	0
576192	575067	19387D	PARTICIPANT	\N	PRESENT	0
576193	575067	19251M	PARTICIPANT	\N	PRESENT	0
576194	575067	14219Q	PRESIDENT	0	PRESENT	0
576195	575067	20046A	PARTICIPANT	\N	PRESENT	0
576196	575067	20068G	PARTICIPANT	\N	PRESENT	0
576197	575067	19577H	PARTICIPANT	\N	PRESENT	0
576198	575067	19685L	PARTICIPANT	\N	EXCUSE	0
576199	575233	07029T	PARTICIPANT	\N	PRESENT	0
576200	575067	19820Y	PARTICIPANT	\N	PRESENT	0
576201	575067	14169X	PARTICIPANT	\N	PRESENT	0
576202	575067	19503N	PARTICIPANT	\N	PRESENT	0
576203	575067	20140W	PARTICIPANT	\N	PRESENT	0
576204	575067	14221J	PARTICIPANT	\N	PRESENT	0
576205	575067	17367Q	PARTICIPANT	\N	PRESENT	0
576206	575067	20100N	PARTICIPANT	\N	PRESENT	0
579885	579389	01058X	PARTICIPANT	\N	PRESENT	0
580400	579584	11067R	PARTICIPANT	\N	EXCUSE	0
580608	580598	17367Q	PARTICIPANT	\N	PRESENT	0
580609	580598	20132W	PARTICIPANT	\N	PRESENT	1
580610	580598	04035D	PARTICIPANT	\N	PRESENT	0
580611	580598	11083R	PARTICIPANT	\N	PRESENT	0
580612	580598	19593H	PARTICIPANT	\N	PRESENT	0
580613	580607	17367Q	PARTICIPANT	\N	PRESENT	0
580614	580607	20132W	PARTICIPANT	\N	PRESENT	1
580615	580607	04035D	PARTICIPANT	\N	PRESENT	0
580616	580607	11083R	PARTICIPANT	\N	PRESENT	0
580617	580607	19593H	PARTICIPANT	\N	PRESENT	0
580725	579584	20072C	PARTICIPANT	\N	EXCUSE	0
581737	579467	10006L	PRESIDENT	0	PRESENT	0
581738	579467	14217N	PARTICIPANT	\N	PRESENT	0
581742	579467	04043D	PARTICIPANT	\N	PRESENT	1
581743	579467	19569H	PARTICIPANT	\N	PRESENT	1
581744	579467	04092N	PARTICIPANT	\N	PRESENT	1
581745	579467	19798U	PARTICIPANT	\N	PRESENT	1
581746	579467	14223L	PARTICIPANT	\N	PRESENT	1
581747	579467	11103C	PARTICIPANT	\N	PRESENT	1
581748	579467	20130U	PARTICIPANT	\N	PRESENT	1
581749	579467	11097X	PARTICIPANT	\N	PRESENT	0
581750	579467	19697Q	PARTICIPANT	\N	PRESENT	0
581751	579467	17779H	PARTICIPANT	\N	PRESENT	0
581752	579467	19717B	PARTICIPANT	\N	PRESENT	0
581753	579467	20066E	PARTICIPANT	\N	PRESENT	0
581754	579467	18193Q	PARTICIPANT	\N	PRESENT	0
581755	579467	20040T	PARTICIPANT	\N	PRESENT	0
581756	579467	19715Y	PARTICIPANT	\N	PRESENT	0
581757	579467	11045K	PARTICIPANT	\N	PRESENT	0
581758	579467	20148F	PARTICIPANT	\N	PRESENT	0
581759	579467	19657G	PARTICIPANT	\N	PRESENT	0
581760	579467	19415P	PARTICIPANT	\N	PRESENT	0
581761	579467	11031D	PARTICIPANT	\N	PRESENT	0
581762	579467	19553Y	PARTICIPANT	\N	PRESENT	0
581763	579467	20090E	PARTICIPANT	\N	PRESENT	0
581764	579467	01034P	PARTICIPANT	\N	PRESENT	1
581765	579467	19367Y	PARTICIPANT	\N	PRESENT	0
581766	579467	19760E	PARTICIPANT	\N	PRESENT	0
581767	579467	14042U	PARTICIPANT	\N	PRESENT	0
581768	579467	19295A	PARTICIPANT	\N	EXCUSE	0
581769	579467	04057K	PARTICIPANT	\N	EXCUSE	0
581770	579467	19691J	PARTICIPANT	\N	EXCUSE	0
581771	579467	14071N	PARTICIPANT	\N	PRESENT	0
581772	579467	14355X	PARTICIPANT	\N	PRESENT	1
581773	579467	14231L	PARTICIPANT	\N	PRESENT	0
581774	579467	14053L	PARTICIPANT	\N	PRESENT	0
581775	579467	05008E	PARTICIPANT	\N	PRESENT	0
581776	579467	04047H	PARTICIPANT	\N	PRESENT	0
581777	579467	14021P	PARTICIPANT	\N	PRESENT	0
581778	579467	19649G	PARTICIPANT	\N	PRESENT	0
581779	579467	14151M	PARTICIPANT	\N	PRESENT	0
581780	579467	14213J	PARTICIPANT	\N	PRESENT	1
581781	579467	19301E	PARTICIPANT	\N	PRESENT	1
581782	579467	04085P	PARTICIPANT	\N	PRESENT	1
581783	579467	20128B	PARTICIPANT	\N	PRESENT	1
581784	579467	14179A	PARTICIPANT	\N	PRESENT	1
581785	579467	14147R	PARTICIPANT	\N	PRESENT	1
581786	579467	11033F	PARTICIPANT	\N	PRESENT	1
581787	579467	19749K	PARTICIPANT	\N	PRESENT	1
581788	579467	07004J	PARTICIPANT	\N	PRESENT	0
581789	579467	19447X	PARTICIPANT	\N	PRESENT	0
581790	579467	95063L	PARTICIPANT	\N	PRESENT	0
581791	579467	08045X	PARTICIPANT	\N	PRESENT	1
581792	579467	10015M	PARTICIPANT	\N	PRESENT	0
581793	579467	11026G	PARTICIPANT	\N	PRESENT	0
581794	579467	14215L	PARTICIPANT	\N	PRESENT	0
581795	579467	19673G	PARTICIPANT	\N	PRESENT	0
581796	579467	14041T	PARTICIPANT	\N	PRESENT	0
581797	579467	17737W	PARTICIPANT	\N	PRESENT	0
581798	579467	20110Q	PARTICIPANT	\N	PRESENT	0
581799	579467	14089Y	PARTICIPANT	\N	PRESENT	0
581800	579467	19713W	PARTICIPANT	\N	PRESENT	0
581892	581891	14255U	PARTICIPANT	\N	PRESENT	0
582087	581922	14053L	PARTICIPANT	\N	PRESENT	0
582088	581922	14179A	PARTICIPANT	\N	PRESENT	0
582089	581922	14041T	PARTICIPANT	\N	PRESENT	0
582090	581922	14215L	PARTICIPANT	\N	PRESENT	0
582091	581922	05008E	PARTICIPANT	\N	PRESENT	0
582092	581922	04047H	PRESIDENT	0	PRESENT	0
582093	581922	11026G	PARTICIPANT	\N	PRESENT	0
582094	581922	14089Y	PARTICIPANT	\N	PRESENT	0
582095	581922	17737W	PARTICIPANT	\N	PRESENT	0
582096	581922	07004J	PARTICIPANT	\N	PRESENT	0
582097	579243	19697Q	PARTICIPANT	\N	PRESENT	0
582098	579243	19553Y	PARTICIPANT	\N	PRESENT	0
582099	579243	19713W	PARTICIPANT	\N	PRESENT	0
582100	579243	11045K	PARTICIPANT	\N	PRESENT	0
582101	579243	14071N	PARTICIPANT	\N	PRESENT	0
582102	579243	18193Q	PARTICIPANT	\N	PRESENT	0
582103	579243	14217N	PARTICIPANT	\N	PRESENT	0
582104	579243	20148F	PARTICIPANT	\N	PRESENT	0
582105	579243	14026U	PARTICIPANT	\N	PRESENT	0
582106	579243	10006L	PRESIDENT	0	PRESENT	0
582107	579243	19723Y	PARTICIPANT	\N	PRESENT	0
582108	581922	14021P	PARTICIPANT	\N	PRESENT	0
582109	581893	08073C	PARTICIPANT	\N	PRESENT	0
582126	581893	19649G	PARTICIPANT	\N	PRESENT	0
582127	581893	20084G	PARTICIPANT	\N	PRESENT	0
582128	581893	14041T	PARTICIPANT	\N	PRESENT	0
582129	581893	14215L	PARTICIPANT	\N	PRESENT	0
582130	581893	20044X	PARTICIPANT	\N	PRESENT	0
582131	581893	19715Y	PARTICIPANT	\N	PRESENT	0
582132	581893	20148F	PARTICIPANT	\N	PRESENT	0
582133	581893	14357A	PARTICIPANT	\N	PRESENT	0
582134	581893	19347U	PARTICIPANT	\N	PRESENT	0
582135	581893	20130U	PARTICIPANT	\N	PRESENT	0
582136	581893	11099A	PARTICIPANT	\N	PRESENT	0
582137	581893	07004J	PARTICIPANT	\N	PRESENT	0
582138	581893	17737W	PARTICIPANT	\N	PRESENT	0
582141	581893	20034V	PARTICIPANT	\N	PRESENT	0
582142	581893	14179A	PARTICIPANT	\N	PRESENT	0
582143	581893	04085P	PARTICIPANT	\N	PRESENT	0
582144	581893	19611R	PARTICIPANT	\N	PRESENT	0
582145	581893	19667J	PARTICIPANT	\N	PRESENT	0
582146	581893	19697Q	PARTICIPANT	\N	PRESENT	0
582147	581893	11031D	PARTICIPANT	\N	PRESENT	0
582148	581893	20056C	PARTICIPANT	\N	PRESENT	0
582149	581893	11026G	PARTICIPANT	\N	PRESENT	0
582150	581893	07029T	PARTICIPANT	\N	PRESENT	0
582151	581893	20086J	PARTICIPANT	\N	PRESENT	0
582152	581893	17779H	PARTICIPANT	\N	PRESENT	0
582153	581893	19723Y	PARTICIPANT	\N	PRESENT	0
582154	581893	08010L	PARTICIPANT	\N	PRESENT	0
582155	581893	14021P	PARTICIPANT	\N	PRESENT	0
582156	581893	19703U	PARTICIPANT	\N	PRESENT	0
582157	581893	11045K	PARTICIPANT	\N	PRESENT	0
582158	581893	18083K	PARTICIPANT	\N	PRESENT	0
582159	581893	14225N	PARTICIPANT	\N	PRESENT	0
582160	581893	19766L	PARTICIPANT	\N	PRESENT	0
582161	581893	20070A	PARTICIPANT	\N	PRESENT	0
582162	581893	18193Q	PARTICIPANT	\N	PRESENT	0
582163	581893	19671E	PARTICIPANT	\N	PRESENT	0
582164	581893	14055N	PARTICIPANT	\N	PRESENT	0
582165	581893	14053L	PARTICIPANT	\N	PRESENT	0
582166	581893	19577H	PARTICIPANT	\N	PRESENT	0
582167	581893	14071N	PARTICIPANT	\N	PRESENT	0
582168	581893	20124W	PARTICIPANT	\N	PRESENT	0
582169	581893	04033B	PARTICIPANT	\N	PRESENT	0
582170	581893	11097X	PARTICIPANT	\N	PRESENT	0
582171	581893	19593H	PARTICIPANT	\N	PRESENT	0
582172	581893	19695N	PARTICIPANT	\N	PRESENT	0
582173	581893	19443T	PARTICIPANT	\N	PRESENT	0
582174	581893	11053K	PARTICIPANT	\N	PRESENT	0
582175	581893	19675J	PARTICIPANT	\N	PRESENT	0
582176	581893	14026U	PARTICIPANT	\N	PRESENT	0
582177	581893	99004R	PARTICIPANT	\N	PRESENT	0
582179	581893	20038A	PARTICIPANT	\N	PRESENT	0
582180	581893	19657G	PARTICIPANT	\N	PRESENT	0
582181	581893	14255U	PARTICIPANT	\N	PRESENT	0
582182	581893	19768N	PARTICIPANT	\N	PRESENT	0
582183	581893	01057W	PARTICIPANT	\N	PRESENT	0
582184	581893	19687N	PARTICIPANT	\N	PRESENT	0
582185	581893	19599P	PARTICIPANT	\N	PRESENT	0
582186	581893	19543W	PARTICIPANT	\N	PRESENT	0
582187	581893	19749K	PARTICIPANT	\N	PRESENT	0
582188	581893	05008E	PARTICIPANT	\N	PRESENT	0
571247	566536	19551W	PARTICIPANT	\N	PRESENT	0
571250	566536	11045K	PARTICIPANT	\N	PRESENT	0
571251	566536	20136B	PARTICIPANT	\N	PRESENT	0
571252	566536	19533U	PARTICIPANT	\N	PRESENT	0
571253	566536	07029T	PARTICIPANT	\N	PRESENT	0
571254	566536	18083K	PARTICIPANT	\N	PRESENT	0
571255	566536	10015M	PARTICIPANT	\N	PRESENT	0
571256	566536	19515S	PARTICIPANT	\N	PRESENT	0
571257	566536	20112S	PARTICIPANT	\N	PRESENT	0
571258	566536	19619A	PARTICIPANT	\N	PRESENT	0
571259	566536	19826F	PARTICIPANT	\N	PRESENT	0
571260	566536	14251Q	PARTICIPANT	\N	PRESENT	0
571261	566536	19347U	PARTICIPANT	\N	PRESENT	0
571262	566536	11099A	PARTICIPANT	\N	PRESENT	0
571263	566536	19549D	PARTICIPANT	\N	PRESENT	0
571264	566536	11031D	PARTICIPANT	\N	PRESENT	0
571265	566536	20110Q	PARTICIPANT	\N	PRESENT	0
571266	566536	19697Q	PARTICIPANT	\N	PRESENT	0
571267	566536	14231L	PARTICIPANT	\N	PRESENT	0
571268	566536	20118Y	PARTICIPANT	\N	PRESENT	0
574966	574965	11099A	PARTICIPANT	\N	PRESENT	0
574967	574965	19441R	PARTICIPANT	\N	PRESENT	0
574968	574965	19719D	PARTICIPANT	\N	PRESENT	0
574969	574965	14109K	PRESIDENT	0	PRESENT	0
574970	574965	19758L	PARTICIPANT	\N	PRESENT	0
574971	574965	19713W	PARTICIPANT	\N	PRESENT	0
574972	574965	20038A	PARTICIPANT	\N	PRESENT	0
574973	574965	20026V	PARTICIPANT	\N	PRESENT	1
574974	574965	19798U	PARTICIPANT	\N	PRESENT	1
574975	574433	14331P	PRESIDENT	0	PRESENT	0
579886	579389	11043H	PARTICIPANT	\N	PRESENT	0
579887	579389	19415P	PARTICIPANT	\N	PRESENT	0
574978	574433	04034C	PARTICIPANT	\N	PRESENT	1
574979	574433	11026G	PARTICIPANT	\N	PRESENT	0
574980	574433	14097Y	PARTICIPANT	\N	PRESENT	0
579888	579389	14147R	PARTICIPANT	\N	PRESENT	0
574982	574433	14133K	PARTICIPANT	\N	PRESENT	1
579889	579389	19565D	PARTICIPANT	\N	PRESENT	0
574985	574433	14073Q	PARTICIPANT	\N	PRESENT	0
579890	579389	20026V	PARTICIPANT	\N	PRESENT	0
574995	574433	04057K	PARTICIPANT	\N	PRESENT	0
574996	574433	14189C	PARTICIPANT	\N	EXCUSE	0
575343	575316	19543W	PARTICIPANT	\N	PRESENT	0
575341	575316	20032T	PARTICIPANT	\N	PRESENT	0
575342	575316	19651A	PARTICIPANT	\N	PRESENT	0
575344	575316	19954N	PARTICIPANT	\N	PRESENT	0
575345	575316	20042V	PARTICIPANT	\N	PRESENT	0
575346	575316	19643A	PARTICIPANT	\N	PRESENT	0
575347	575316	19747H	PARTICIPANT	\N	PRESENT	0
575348	575316	14038Y	PARTICIPANT	\N	PRESENT	0
575349	575316	20144B	PARTICIPANT	\N	PRESENT	0
575350	575316	19295A	PARTICIPANT	\N	PRESENT	0
575351	575316	11056N	PARTICIPANT	\N	PRESENT	0
575352	575316	11065P	PARTICIPANT	\N	PRESENT	0
575353	575316	14259Y	PARTICIPANT	\N	PRESENT	0
575354	575316	04071H	PARTICIPANT	\N	PRESENT	0
575355	575316	20132W	PARTICIPANT	\N	PRESENT	0
575356	575316	19553Y	PARTICIPANT	\N	PRESENT	0
575357	575316	19725B	PARTICIPANT	\N	PRESENT	0
575358	575316	19569H	PARTICIPANT	\N	PRESENT	0
575359	575316	19399H	PARTICIPANT	\N	PRESENT	0
575360	575316	19551W	PARTICIPANT	\N	PRESENT	0
575361	575316	99004R	PARTICIPANT	\N	PRESENT	0
575362	575316	19711U	PARTICIPANT	\N	PRESENT	0
575363	575316	08012N	PARTICIPANT	\N	PRESENT	0
575364	575316	20018V	PARTICIPANT	\N	PRESENT	0
575365	575316	04070G	PARTICIPANT	\N	PRESENT	0
575366	575316	20050V	PARTICIPANT	\N	PRESENT	0
575367	575316	14237S	PARTICIPANT	\N	PRESENT	0
575368	575316	14193X	PARTICIPANT	\N	PRESENT	0
575369	575316	95063L	PARTICIPANT	\N	PRESENT	0
575370	575316	20044X	PARTICIPANT	\N	PRESENT	0
575371	575316	11097X	PARTICIPANT	\N	PRESENT	0
575372	575316	19703U	PARTICIPANT	\N	PRESENT	0
575373	575316	01028R	PARTICIPANT	\N	PRESENT	0
575374	575316	19669L	PARTICIPANT	\N	PRESENT	0
575534	575533	14189C	PARTICIPANT	\N	PRESENT	0
575535	575533	14207L	PARTICIPANT	\N	PRESENT	1
575536	575533	11031D	PARTICIPANT	\N	PRESENT	0
575537	575533	19683J	PRESIDENT	0	PRESENT	0
575538	575533	99004R	PARTICIPANT	\N	PRESENT	0
575539	575533	19699S	PARTICIPANT	\N	PRESENT	1
575540	575533	11033F	PARTICIPANT	\N	EXCUSE	0
575541	575533	10006L	PARTICIPANT	\N	EXCUSE	0
575542	575533	19563B	PARTICIPANT	\N	EXCUSE	0
575543	575533	20030R	PARTICIPANT	\N	EXCUSE	0
579891	579389	20056C	PARTICIPANT	\N	PRESENT	0
579892	579389	07029T	PARTICIPANT	\N	PRESENT	0
579893	579389	20180F	PARTICIPANT	\N	PRESENT	0
579894	579389	01057W	PARTICIPANT	\N	PRESENT	0
579895	579389	20070A	PARTICIPANT	\N	PRESENT	0
579896	579389	19599P	PARTICIPANT	\N	PRESENT	0
579897	579389	14257W	PARTICIPANT	\N	PRESENT	0
579898	579389	19760E	PARTICIPANT	\N	PRESENT	0
579899	579389	14123H	PARTICIPANT	\N	PRESENT	0
579900	579389	19693L	PARTICIPANT	\N	PRESENT	0
579901	579389	19673G	PARTICIPANT	\N	PRESENT	0
579902	579389	20038A	PARTICIPANT	\N	PRESENT	0
579903	579389	20034V	PARTICIPANT	\N	PRESENT	0
579904	579389	19507S	PARTICIPANT	\N	PRESENT	0
579905	579389	08056B	PARTICIPANT	\N	PRESENT	0
579906	579389	20044X	PARTICIPANT	\N	PRESENT	0
579907	579389	20032T	PARTICIPANT	\N	PRESENT	0
579908	579389	19543W	PARTICIPANT	\N	PRESENT	0
579909	579389	20126Y	PARTICIPANT	\N	PRESENT	0
579910	579389	20066E	PARTICIPANT	\N	PRESENT	0
579911	579389	20022R	PARTICIPANT	\N	PRESENT	0
579912	579389	20098N	PARTICIPANT	\N	PRESENT	0
579913	579389	14111D	PARTICIPANT	\N	PRESENT	0
579914	579389	19335Q	PARTICIPANT	\N	PRESENT	0
579915	579389	01043Q	PARTICIPANT	\N	PRESENT	0
579916	579389	19782L	PARTICIPANT	\N	PRESENT	0
579917	579389	19441R	PARTICIPANT	\N	PRESENT	0
579918	579389	14042U	PARTICIPANT	\N	PRESENT	0
579919	579389	14179A	PARTICIPANT	\N	PRESENT	0
579920	579389	14259Y	PARTICIPANT	\N	PRESENT	0
579921	579389	11045K	PARTICIPANT	\N	PRESENT	0
579922	579389	12028B	PARTICIPANT	\N	PRESENT	0
579923	579389	19347U	PARTICIPANT	\N	PRESENT	0
579924	579389	19575F	PARTICIPANT	\N	PRESENT	0
579925	579389	01024M	PARTICIPANT	\N	PRESENT	0
579926	579389	08061X	PARTICIPANT	\N	PRESENT	0
579927	579389	04043D	PARTICIPANT	\N	PRESENT	0
579928	579389	20248J	PARTICIPANT	\N	PRESENT	0
579929	579389	20092G	PARTICIPANT	\N	PRESENT	0
579930	579389	20096L	PARTICIPANT	\N	PRESENT	0
579931	579389	14105F	PARTICIPANT	\N	PRESENT	0
579932	579389	11048N	PARTICIPANT	\N	PRESENT	0
579933	579389	19563B	PARTICIPANT	\N	PRESENT	0
579934	579389	20140W	PARTICIPANT	\N	PRESENT	0
579935	579389	14026U	PARTICIPANT	\N	PRESENT	0
579936	579389	19467C	PARTICIPANT	\N	PRESENT	0
579937	579389	05012A	PARTICIPANT	\N	PRESENT	0
579938	579389	20138D	PARTICIPANT	\N	PRESENT	0
579939	579389	14021P	PARTICIPANT	\N	PRESENT	0
579940	579389	19631V	PARTICIPANT	\N	PRESENT	0
579941	579389	20018V	PARTICIPANT	\N	PRESENT	0
579942	579389	19251M	PARTICIPANT	\N	PRESENT	0
579943	579389	19820Y	PARTICIPANT	\N	PRESENT	0
579944	579389	20118Y	PARTICIPANT	\N	PRESENT	0
579945	579389	19703U	PARTICIPANT	\N	PRESENT	0
579946	579389	12041X	PARTICIPANT	\N	PRESENT	0
579947	579389	19741B	PARTICIPANT	\N	PRESENT	0
579948	579389	19447X	PARTICIPANT	\N	PRESENT	0
579949	579389	20172F	PARTICIPANT	\N	PRESENT	0
579950	579389	17023S	PARTICIPANT	\N	PRESENT	0
579951	579389	20086J	PARTICIPANT	\N	PRESENT	0
585204	583498	14083S	PARTICIPANT	\N	PRESENT	0
590941	590913	20126Y	PARTICIPANT	\N	PRESENT	0
590942	590913	19768N	PARTICIPANT	\N	PRESENT	0
590943	590913	19467C	PARTICIPANT	\N	PRESENT	0
590944	590913	20094J	PARTICIPANT	\N	PRESENT	0
590945	590913	19575F	PARTICIPANT	\N	PRESENT	0
590946	590913	14179A	PARTICIPANT	\N	PRESENT	0
590948	590947	14053L	PARTICIPANT	\N	EXCUSE	0
590968	590967	04070G	PARTICIPANT	\N	PRESENT	0
590969	590967	14169X	PARTICIPANT	\N	PRESENT	0
590973	590972	04070G	PARTICIPANT	\N	PRESENT	0
590974	590972	14169X	PARTICIPANT	\N	PRESENT	0
590978	590392	20130U	PARTICIPANT	\N	PRESENT	1
590979	590392	19697Q	PARTICIPANT	\N	PRESENT	0
590980	590392	11067R	PARTICIPANT	\N	PRESENT	0
590981	590392	20090E	PARTICIPANT	\N	PRESENT	0
590982	590392	04057K	PARTICIPANT	\N	PRESENT	0
590983	590392	19798U	PARTICIPANT	\N	PRESENT	0
590984	590392	17965H	PARTICIPANT	\N	PRESENT	0
590985	590392	19301E	PARTICIPANT	\N	PRESENT	0
590986	590392	19691J	PARTICIPANT	\N	PRESENT	1
590987	590392	18193Q	PARTICIPANT	\N	PRESENT	0
590988	590392	19717B	PARTICIPANT	\N	PRESENT	0
590989	590392	14026U	PARTICIPANT	\N	PRESENT	0
590990	590392	19723Y	PARTICIPANT	\N	PRESENT	0
590991	590392	11031D	PARTICIPANT	\N	PRESENT	0
590992	590392	19553Y	PARTICIPANT	\N	PRESENT	0
590993	590392	20248J	PARTICIPANT	\N	PRESENT	0
590994	590392	11103C	PARTICIPANT	\N	PRESENT	1
590995	590392	14042U	PARTICIPANT	\N	PRESENT	0
590996	590392	14213J	PARTICIPANT	\N	PRESENT	0
590997	590392	14071N	PARTICIPANT	\N	PRESENT	0
590998	590392	14217N	PRESIDENT	0	PRESENT	0
590999	590392	19683J	PARTICIPANT	\N	PRESENT	0
591000	590392	10006L	PARTICIPANT	\N	PRESENT	0
591001	590392	19760E	PARTICIPANT	\N	PRESENT	0
591002	590392	19715Y	PARTICIPANT	\N	EXCUSE	0
591003	590844	19719D	PARTICIPANT	\N	PRESENT	0
591004	590844	19711U	PARTICIPANT	\N	PRESENT	0
591005	590844	20068G	PARTICIPANT	\N	PRESENT	0
591006	590844	19569H	PARTICIPANT	\N	PRESENT	0
591081	590844	14191V	PARTICIPANT	\N	PRESENT	0
591008	590844	20090E	PARTICIPANT	\N	PRESENT	0
591009	590844	20062A	PARTICIPANT	\N	PRESENT	0
591010	590844	20140W	PARTICIPANT	\N	PRESENT	0
591011	590844	20076G	PARTICIPANT	\N	PRESENT	0
591012	590844	20174H	PARTICIPANT	\N	PRESENT	0
591013	590844	10006L	PARTICIPANT	\N	PRESENT	0
591014	590844	14071N	PARTICIPANT	\N	PRESENT	0
591015	590844	04057K	PARTICIPANT	\N	PRESENT	0
591016	590844	20032T	PARTICIPANT	\N	PRESENT	0
591018	590844	12028B	PARTICIPANT	\N	PRESENT	0
591019	590844	19629C	PARTICIPANT	\N	PRESENT	0
591020	590844	20130U	PARTICIPANT	\N	PRESENT	0
591021	590844	95063L	PARTICIPANT	\N	PRESENT	0
591022	590844	14042U	PARTICIPANT	\N	PRESENT	0
591023	590844	19515S	PARTICIPANT	\N	PRESENT	0
591024	590844	19717B	PARTICIPANT	\N	PRESENT	0
591025	590844	18083K	PARTICIPANT	\N	PRESENT	0
591026	590844	19741B	PARTICIPANT	\N	PRESENT	0
591027	590844	19703U	PARTICIPANT	\N	PRESENT	0
591028	590844	14033T	PARTICIPANT	\N	PRESENT	0
591029	590844	20152B	PARTICIPANT	\N	PRESENT	0
591030	590844	14213J	PARTICIPANT	\N	PRESENT	0
591031	590844	11103C	PARTICIPANT	\N	PRESENT	0
591032	590844	20026V	PARTICIPANT	\N	PRESENT	0
591033	590844	19679N	PARTICIPANT	\N	PRESENT	0
591034	590844	14217N	PARTICIPANT	\N	PRESENT	0
591035	590844	19760E	PARTICIPANT	\N	PRESENT	0
591036	590844	19697Q	PARTICIPANT	\N	PRESENT	0
591037	590844	11067R	PARTICIPANT	\N	PRESENT	0
591038	590844	19479G	PARTICIPANT	\N	PRESENT	0
591039	590844	14195A	PARTICIPANT	\N	PRESENT	0
591040	590844	20132W	PARTICIPANT	\N	PRESENT	0
591041	590844	19399H	PARTICIPANT	\N	PRESENT	0
591042	590844	20054A	PARTICIPANT	\N	PRESENT	0
591043	590844	11031D	PARTICIPANT	\N	PRESENT	0
591044	590844	19301E	PARTICIPANT	\N	PRESENT	0
591045	590844	20066E	PARTICIPANT	\N	PRESENT	0
591046	590541	20108W	PARTICIPANT	\N	PRESENT	0
591047	590541	10015M	PARTICIPANT	\N	PRESENT	0
591048	590541	14147R	PARTICIPANT	\N	PRESENT	0
591049	590541	14179A	PARTICIPANT	\N	PRESENT	0
591050	590541	19543W	PARTICIPANT	\N	PRESENT	0
591051	590541	11085T	PARTICIPANT	\N	PRESENT	0
591052	590541	04047H	PRESIDENT	0	PRESENT	0
591053	590541	19673G	PARTICIPANT	\N	PRESENT	0
591054	590541	14231L	PARTICIPANT	\N	PRESENT	0
591055	590541	11072N	PARTICIPANT	\N	PRESENT	0
591056	590844	19507S	PARTICIPANT	\N	PRESENT	0
591057	590844	19798U	PARTICIPANT	\N	PRESENT	0
591058	590844	14107H	PARTICIPANT	\N	PRESENT	0
591064	590844	01043Q	PARTICIPANT	\N	PRESENT	0
591060	590844	18193Q	PARTICIPANT	\N	PRESENT	0
591061	590844	19533U	PARTICIPANT	\N	PRESENT	0
591065	590844	20180F	PARTICIPANT	\N	PRESENT	0
591067	590844	17965H	PARTICIPANT	\N	PRESENT	0
591068	590844	14147R	PARTICIPANT	\N	PRESENT	0
591069	590844	19683J	PARTICIPANT	\N	PRESENT	0
591072	590844	20056C	PARTICIPANT	\N	PRESENT	0
591073	590844	17779H	PARTICIPANT	\N	PRESENT	0
591074	590844	11048N	PARTICIPANT	\N	PRESENT	0
591075	590844	11115U	PARTICIPANT	\N	PRESENT	0
591076	590844	20038A	PARTICIPANT	\N	PRESENT	0
591077	590844	19713W	PARTICIPANT	\N	PRESENT	0
591078	590844	14223L	PARTICIPANT	\N	PRESENT	0
591079	590844	20104S	PARTICIPANT	\N	PRESENT	0
591082	590844	19651A	PARTICIPANT	\N	PRESENT	0
591083	590844	08061X	PARTICIPANT	\N	PRESENT	0
591084	590844	19687N	PARTICIPANT	\N	PRESENT	0
591085	590844	19553Y	PARTICIPANT	\N	PRESENT	0
591086	590844	11097X	PARTICIPANT	\N	PRESENT	0
591087	590844	14275Y	PARTICIPANT	\N	PRESENT	0
591088	590844	19467C	PARTICIPANT	\N	PRESENT	0
591089	590844	14121F	PARTICIPANT	\N	PRESENT	0
591090	590844	14073Q	PARTICIPANT	\N	PRESENT	0
591091	590844	01025N	PARTICIPANT	\N	PRESENT	0
591092	590844	14151M	PARTICIPANT	\N	PRESENT	0
591093	590844	20102Q	PARTICIPANT	\N	PRESENT	0
591094	590844	20134Y	PARTICIPANT	\N	PRESENT	0
591095	590844	20088L	PARTICIPANT	\N	PRESENT	0
591096	590800	19515S	PARTICIPANT	\N	PRESENT	0
591097	590800	20092G	PARTICIPANT	\N	PRESENT	0
591098	590800	20078J	PARTICIPANT	\N	PRESENT	0
591099	590800	19441R	PARTICIPANT	\N	PRESENT	0
591100	590800	19413M	PARTICIPANT	\N	PRESENT	0
591101	590800	04045F	PARTICIPANT	\N	PRESENT	0
591102	590800	20104S	PARTICIPANT	\N	PRESENT	0
591103	590800	11099A	PARTICIPANT	\N	PRESENT	0
591104	590800	19705W	PARTICIPANT	\N	PRESENT	0
591105	590800	19575F	PARTICIPANT	\N	PRESENT	0
591106	590800	19369B	PARTICIPANT	\N	PRESENT	0
591107	590800	19563B	PARTICIPANT	\N	PRESENT	0
591108	590800	14038Y	PARTICIPANT	\N	PRESENT	1
591109	590800	20030R	PARTICIPANT	\N	PRESENT	1
591110	590800	19467C	PARTICIPANT	\N	PRESENT	0
591111	590800	14187A	PARTICIPANT	\N	PRESENT	0
591112	590800	20144B	PARTICIPANT	\N	PRESENT	0
591113	590800	19695N	PARTICIPANT	\N	PRESENT	0
591114	590800	11090Q	PRESIDENT	0	PRESENT	0
591115	590800	14033T	PARTICIPANT	\N	PRESENT	0
591116	590800	01025N	PARTICIPANT	\N	PRESENT	0
591117	590800	20174H	PARTICIPANT	\N	PRESENT	0
591118	590800	20062A	PARTICIPANT	\N	PRESENT	0
591119	590800	19507S	PARTICIPANT	\N	PRESENT	0
591120	590800	14207L	PARTICIPANT	\N	PRESENT	1
591121	590800	14257W	PARTICIPANT	\N	PRESENT	0
591122	590800	19383Y	PARTICIPANT	\N	PRESENT	0
591123	590800	20082E	PARTICIPANT	\N	PRESENT	0
591124	590844	20070A	PARTICIPANT	\N	PRESENT	0
591125	590844	19681G	PARTICIPANT	\N	PRESENT	0
591126	590844	08045X	PARTICIPANT	\N	PRESENT	0
591127	590844	19747H	PARTICIPANT	\N	PRESENT	0
591128	590844	14231L	PARTICIPANT	\N	PRESENT	0
591129	590844	19762G	PARTICIPANT	\N	PRESENT	0
591134	590844	99004R	PARTICIPANT	\N	PRESENT	0
591135	590800	20094J	PARTICIPANT	\N	PRESENT	1
591136	590844	20116W	PARTICIPANT	\N	PRESENT	0
591137	590844	11012A	PARTICIPANT	\N	PRESENT	0
591138	590844	19387D	PARTICIPANT	\N	PRESENT	0
591139	590844	20028X	PARTICIPANT	\N	PRESENT	0
570602	570596	20082E	PARTICIPANT	\N	PRESENT	0
570603	570596	19533U	PARTICIPANT	\N	PRESENT	0
570604	570596	19593H	PRESIDENT	0	PRESENT	0
570605	570596	20142Y	PARTICIPANT	\N	PRESENT	0
570606	570596	19735D	PARTICIPANT	\N	PRESENT	0
570607	570596	19611R	PARTICIPANT	\N	PRESENT	0
570608	570596	19715Y	PARTICIPANT	\N	PRESENT	1
570609	570596	20132W	PARTICIPANT	\N	PRESENT	0
570610	570596	19693L	PARTICIPANT	\N	PRESENT	0
570611	570596	19721W	PARTICIPANT	\N	EXCUSE	0
570612	570596	20114U	PARTICIPANT	\N	PRESENT	0
570739	570738	20048C	PARTICIPANT	\N	PRESENT	1
570740	570738	19527W	PARTICIPANT	\N	PRESENT	1
570741	570738	20052X	PARTICIPANT	\N	PRESENT	1
570742	570738	20142Y	PARTICIPANT	\N	PRESENT	1
570745	570744	20048C	PARTICIPANT	\N	PRESENT	1
570746	570744	20052X	PARTICIPANT	\N	PRESENT	1
570747	570744	19527W	PARTICIPANT	\N	PRESENT	1
570748	570744	19533U	PARTICIPANT	\N	PRESENT	1
570749	570744	20142Y	PARTICIPANT	\N	PRESENT	1
570752	570751	20048C	PARTICIPANT	\N	PRESENT	1
570753	570751	20052X	PARTICIPANT	\N	PRESENT	1
570754	570751	19533U	PARTICIPANT	\N	PRESENT	1
570755	570751	20142Y	PARTICIPANT	\N	PRESENT	1
570757	570756	20048C	PARTICIPANT	\N	PRESENT	1
570758	570756	20052X	PARTICIPANT	\N	PRESENT	1
570760	570759	20052X	PARTICIPANT	\N	PRESENT	1
570761	570759	20048C	PARTICIPANT	\N	PRESENT	1
570767	570766	19527W	PARTICIPANT	\N	PRESENT	1
570768	570766	20052X	PARTICIPANT	\N	PRESENT	1
570770	570769	20048C	PARTICIPANT	\N	PRESENT	1
570771	570769	20052X	PARTICIPANT	\N	PRESENT	1
570772	570769	20142Y	PARTICIPANT	\N	PRESENT	1
570773	570769	19533U	PARTICIPANT	\N	PRESENT	1
570774	570769	19527W	PARTICIPANT	\N	PRESENT	1
570776	570775	20052X	PARTICIPANT	\N	PRESENT	1
570777	570775	20048C	PARTICIPANT	\N	PRESENT	1
570778	570775	19527W	PARTICIPANT	\N	PRESENT	1
570787	570786	19527W	PARTICIPANT	\N	PRESENT	1
570788	570786	20048C	PARTICIPANT	\N	PRESENT	1
570789	570786	20052X	PARTICIPANT	\N	PRESENT	1
570791	570790	20052X	PARTICIPANT	\N	PRESENT	1
570792	570790	20048C	PARTICIPANT	\N	PRESENT	1
570920	570914	20132W	PARTICIPANT	\N	PRESENT	1
570921	570914	19643A	PARTICIPANT	\N	PRESENT	1
570923	570922	20132W	PARTICIPANT	\N	PRESENT	1
570924	570922	19643A	PARTICIPANT	\N	PRESENT	1
570929	570927	20048C	PARTICIPANT	\N	PRESENT	1
570930	570927	20132W	PARTICIPANT	\N	PRESENT	1
570931	570927	19643A	PARTICIPANT	\N	PRESENT	1
570935	570934	19643A	PARTICIPANT	\N	PRESENT	1
570936	570934	20132W	PARTICIPANT	\N	PRESENT	1
570944	570943	20132W	PARTICIPANT	\N	PRESENT	1
570945	570943	19643A	PARTICIPANT	\N	PRESENT	1
570947	570946	20132W	PARTICIPANT	\N	PRESENT	1
570948	570946	19643A	PARTICIPANT	\N	PRESENT	1
570949	570946	14030Q	PARTICIPANT	\N	PRESENT	1
570950	570946	20048C	PARTICIPANT	\N	PRESENT	1
570956	570955	20132W	PARTICIPANT	\N	PRESENT	1
570957	570955	19643A	PARTICIPANT	\N	PRESENT	1
570986	570985	19663E	PARTICIPANT	\N	PRESENT	0
570987	570985	10006L	PARTICIPANT	\N	PRESENT	0
573542	572988	14053L	PARTICIPANT	\N	PRESENT	0
573561	571526	18083K	PARTICIPANT	\N	PRESENT	0
573544	572988	04047H	PRESIDENT	0	PRESENT	0
573545	572988	14215L	PARTICIPANT	\N	PRESENT	0
573546	572988	11026G	PARTICIPANT	\N	PRESENT	0
573547	572988	01028R	PARTICIPANT	\N	PRESENT	0
573548	572988	95063L	PARTICIPANT	\N	PRESENT	0
573549	572988	11033F	PARTICIPANT	\N	PRESENT	0
573550	572988	20108W	PARTICIPANT	\N	PRESENT	0
573551	572988	04008A	PARTICIPANT	\N	PRESENT	0
573557	571526	20068G	PARTICIPANT	\N	PRESENT	0
573558	571526	14219Q	PRESIDENT	0	PRESENT	0
573559	571526	20024T	PARTICIPANT	\N	PRESENT	0
573560	571526	11065P	PARTICIPANT	\N	PRESENT	0
573562	571526	20136B	PARTICIPANT	\N	PRESENT	0
573563	571526	19549D	PARTICIPANT	\N	PRESENT	0
573564	571526	20076G	PARTICIPANT	\N	PRESENT	0
573565	571526	19826F	PARTICIPANT	\N	PRESENT	0
573566	571526	19599P	PARTICIPANT	\N	PRESENT	0
573567	571526	19637C	PARTICIPANT	\N	PRESENT	0
573568	571526	14031R	PARTICIPANT	\N	PRESENT	0
573569	571526	17229F	PARTICIPANT	\N	PRESENT	0
573570	571526	20140W	PARTICIPANT	\N	PRESENT	0
573571	571526	19820Y	PARTICIPANT	\N	PRESENT	0
573572	571526	17367Q	PARTICIPANT	\N	PRESENT	0
573573	571526	20120S	PARTICIPANT	\N	PRESENT	0
573574	571526	20096L	PARTICIPANT	\N	PRESENT	0
573575	571526	19251M	PARTICIPANT	\N	PRESENT	0
573576	573326	86034E	PARTICIPANT	\N	PRESENT	0
573577	573326	14173T	PARTICIPANT	\N	PRESENT	0
573578	573326	14169X	PARTICIPANT	\N	PRESENT	0
573579	573326	20024T	PARTICIPANT	\N	PRESENT	0
573580	573326	14031R	PARTICIPANT	\N	PRESENT	0
573581	573326	17229F	PARTICIPANT	\N	PRESENT	0
573582	573326	20076G	PARTICIPANT	\N	PRESENT	0
573583	573326	99004R	PARTICIPANT	\N	PRESENT	0
573584	573326	14105F	PARTICIPANT	\N	PRESENT	0
573585	573326	14217N	PARTICIPANT	\N	PRESENT	0
573586	573326	14207L	PARTICIPANT	\N	PRESENT	0
573587	573326	19369B	PARTICIPANT	\N	PRESENT	0
573588	573326	20086J	PARTICIPANT	\N	PRESENT	0
573589	573326	19681G	PARTICIPANT	\N	PRESENT	0
573590	573326	14219Q	PARTICIPANT	\N	PRESENT	0
573591	573326	20020P	PARTICIPANT	\N	PRESENT	0
573592	573326	20032T	PARTICIPANT	\N	PRESENT	0
573593	573326	92040Q	PARTICIPANT	\N	PRESENT	0
573594	573326	20174H	PARTICIPANT	\N	PRESENT	0
573595	573326	19637C	PARTICIPANT	\N	PRESENT	0
573596	573326	14026U	PARTICIPANT	\N	PRESENT	0
573597	573326	18083K	PARTICIPANT	\N	PRESENT	0
573598	573326	20132W	PARTICIPANT	\N	PRESENT	0
573599	573326	20054A	PARTICIPANT	\N	PRESENT	0
573600	573326	19515S	PARTICIPANT	\N	PRESENT	0
573601	573326	19683J	PARTICIPANT	\N	PRESENT	0
573602	573326	19503N	PARTICIPANT	\N	PRESENT	0
573603	573326	20018V	PARTICIPANT	\N	PRESENT	0
573604	573326	19826F	PARTICIPANT	\N	PRESENT	0
573605	573326	14038Y	PARTICIPANT	\N	PRESENT	0
573606	573326	14215L	PARTICIPANT	\N	PRESENT	0
573607	573326	19735D	PARTICIPANT	\N	PRESENT	0
573608	573326	14257W	PARTICIPANT	\N	PRESENT	0
573609	573326	18193Q	PARTICIPANT	\N	PRESENT	0
573610	573326	01028R	PARTICIPANT	\N	PRESENT	0
573611	573326	20110Q	PARTICIPANT	\N	PRESENT	0
573612	573326	19591F	PARTICIPANT	\N	PRESENT	0
573613	573326	19820Y	PARTICIPANT	\N	PRESENT	0
573614	573326	20088L	PARTICIPANT	\N	PRESENT	0
573615	573326	17965H	PARTICIPANT	\N	PRESENT	0
573616	573326	08011M	PARTICIPANT	\N	PRESENT	0
573617	573326	11065P	PARTICIPANT	\N	PRESENT	0
573618	573326	20142Y	PARTICIPANT	\N	PRESENT	0
573619	573326	01048V	PARTICIPANT	\N	PRESENT	0
573620	573326	19782L	PARTICIPANT	\N	PRESENT	0
573621	573326	19599P	PARTICIPANT	\N	PRESENT	0
573622	573326	01058X	PARTICIPANT	\N	PRESENT	0
573623	573326	20060X	PARTICIPANT	\N	PRESENT	0
573624	573326	08012N	PARTICIPANT	\N	PRESENT	0
573625	573326	19413M	PARTICIPANT	\N	PRESENT	0
573626	573326	19631V	PARTICIPANT	\N	PRESENT	0
573627	573326	20090E	PARTICIPANT	\N	PRESENT	0
573628	573326	19725B	PARTICIPANT	\N	PRESENT	0
573629	573326	14147R	PARTICIPANT	\N	PRESENT	0
573630	573326	19251M	PARTICIPANT	\N	PRESENT	0
573631	573326	04085P	PARTICIPANT	\N	PRESENT	0
573632	573326	20046A	PARTICIPANT	\N	PRESENT	0
573633	573326	19695N	PARTICIPANT	\N	PRESENT	0
573634	573326	14073Q	PARTICIPANT	\N	PRESENT	0
573635	573326	20102Q	PARTICIPANT	\N	PRESENT	0
573636	573326	19333N	PARTICIPANT	\N	PRESENT	0
573637	573326	19619A	PARTICIPANT	\N	PRESENT	0
573638	573326	14267Y	PARTICIPANT	\N	PRESENT	0
573639	573326	20134Y	PARTICIPANT	\N	PRESENT	0
573640	573326	20100N	PARTICIPANT	\N	PRESENT	0
573641	573326	11103C	PARTICIPANT	\N	PRESENT	0
573642	573326	20062A	PARTICIPANT	\N	PRESENT	0
573643	573326	08061X	PARTICIPANT	\N	PRESENT	0
573646	573326	19721W	PARTICIPANT	\N	PRESENT	0
573647	573326	14223L	PARTICIPANT	\N	PRESENT	0
582189	581893	14217N	PARTICIPANT	\N	PRESENT	0
582190	581893	08045X	PARTICIPANT	\N	PRESENT	0
582191	581893	10006L	PARTICIPANT	\N	PRESENT	0
582192	581893	14042U	PARTICIPANT	\N	PRESENT	0
582193	581893	20052X	PARTICIPANT	\N	PRESENT	0
582194	581893	20126Y	PARTICIPANT	\N	PRESENT	0
582195	581893	19553Y	PARTICIPANT	\N	PRESENT	0
582196	581893	19651A	PARTICIPANT	\N	PRESENT	0
582197	581893	20058E	PARTICIPANT	\N	PRESENT	0
582198	581893	19533U	PARTICIPANT	\N	PRESENT	0
582199	581893	19713W	PARTICIPANT	\N	PRESENT	0
582200	581893	04047H	PARTICIPANT	\N	PRESENT	0
582201	581893	11085T	PARTICIPANT	\N	PRESENT	0
582202	581893	14229S	PARTICIPANT	\N	PRESENT	0
582203	581893	14089Y	PARTICIPANT	\N	PRESENT	0
582204	581893	19643A	PARTICIPANT	\N	PRESENT	0
582205	581893	19762G	PARTICIPANT	\N	PRESENT	0
582206	581893	10015M	PARTICIPANT	\N	PRESENT	0
582207	581893	20120S	PARTICIPANT	\N	PRESENT	0
582208	581893	19583F	PARTICIPANT	\N	PRESENT	0
582209	581893	12016W	PARTICIPANT	\N	PRESENT	0
582210	581893	20022R	PARTICIPANT	\N	PRESENT	0
582211	581893	20068G	PARTICIPANT	\N	PRESENT	0
582212	581893	14151M	PARTICIPANT	\N	PRESENT	0
582213	581893	19669L	PARTICIPANT	\N	PRESENT	0
582214	581893	20128B	PARTICIPANT	\N	PRESENT	0
582215	581893	14211G	PARTICIPANT	\N	PRESENT	0
582216	581893	14329V	PARTICIPANT	\N	PRESENT	0
582217	581893	14069U	PARTICIPANT	\N	PRESENT	0
582218	581893	16685X	PARTICIPANT	\N	PRESENT	0
582219	581893	20114U	PARTICIPANT	\N	PRESENT	0
582220	581893	04092N	PARTICIPANT	\N	PRESENT	0
582295	580071	14151M	PARTICIPANT	\N	PRESENT	0
582296	580071	19715Y	PARTICIPANT	\N	PRESENT	0
582297	580071	11045K	PARTICIPANT	\N	PRESENT	0
582298	580071	20130U	PARTICIPANT	\N	PRESENT	0
582299	580071	19583F	PARTICIPANT	\N	PRESENT	0
582300	580071	20114U	PARTICIPANT	\N	PRESENT	0
582396	580071	19573D	PARTICIPANT	\N	PRESENT	0
582302	580071	19553Y	PARTICIPANT	\N	PRESENT	0
582303	580071	19713W	PARTICIPANT	\N	PRESENT	0
582304	580071	20058E	PARTICIPANT	\N	PRESENT	0
582305	580071	19766L	PARTICIPANT	\N	PRESENT	0
582306	580071	20084G	PARTICIPANT	\N	PRESENT	0
582307	580071	11031D	PARTICIPANT	\N	PRESENT	0
582308	580071	04085P	PARTICIPANT	\N	PRESENT	0
582309	580071	12016W	PARTICIPANT	\N	PRESENT	0
582310	580071	19695N	PARTICIPANT	\N	PRESENT	0
582311	580071	19593H	PARTICIPANT	\N	PRESENT	0
582312	580071	19687N	PARTICIPANT	\N	PRESENT	0
582313	580071	19611R	PARTICIPANT	\N	PRESENT	0
582314	580071	20052X	PARTICIPANT	\N	PRESENT	0
582315	580071	20124W	PARTICIPANT	\N	PRESENT	0
582316	580071	14105F	PARTICIPANT	\N	PRESENT	0
582317	580071	19675J	PARTICIPANT	\N	PRESENT	0
582318	580071	07029T	PARTICIPANT	\N	PRESENT	0
582319	580071	14041T	PARTICIPANT	\N	PRESENT	0
582320	580071	17779H	PARTICIPANT	\N	PRESENT	0
582321	580071	14229S	PARTICIPANT	\N	PRESENT	0
582322	580071	20126Y	PARTICIPANT	\N	PRESENT	0
582323	580071	19671E	PARTICIPANT	\N	PRESENT	0
582324	580071	19643A	PARTICIPANT	\N	PRESENT	0
582325	580071	19762G	PARTICIPANT	\N	PRESENT	0
582326	580071	04092N	PARTICIPANT	\N	PRESENT	0
582327	580071	19347U	PARTICIPANT	\N	PRESENT	0
582328	580071	08069G	PARTICIPANT	\N	PRESENT	0
582329	580071	14089Y	PARTICIPANT	\N	PRESENT	0
582330	580071	19543W	PARTICIPANT	\N	PRESENT	0
582331	580071	01057W	PARTICIPANT	\N	PRESENT	0
582332	580071	14055N	PARTICIPANT	\N	PRESENT	0
582333	580071	20038A	PARTICIPANT	\N	PRESENT	0
582334	580071	08045X	PARTICIPANT	\N	PRESENT	0
582335	580071	11099A	PARTICIPANT	\N	PRESENT	0
582336	580071	20034V	PARTICIPANT	\N	PRESENT	0
582337	580071	20056C	PARTICIPANT	\N	PRESENT	0
582338	580071	14357A	PARTICIPANT	\N	PRESENT	0
582339	580071	04047H	PARTICIPANT	\N	PRESENT	0
582340	580071	14217N	PARTICIPANT	\N	PRESENT	0
582341	580071	20118Y	PARTICIPANT	\N	PRESENT	0
582342	580071	05008E	PARTICIPANT	\N	PRESENT	0
582343	580071	19657G	PARTICIPANT	\N	PRESENT	0
582344	580071	14211G	PARTICIPANT	\N	PRESENT	0
582345	580071	14042U	PARTICIPANT	\N	PRESENT	0
582346	580071	20044X	PARTICIPANT	\N	PRESENT	0
582347	580071	14053L	PARTICIPANT	\N	PRESENT	0
582348	580071	20022R	PARTICIPANT	\N	PRESENT	0
582349	580071	14026U	PARTICIPANT	\N	PRESENT	0
582350	580071	20120S	PARTICIPANT	\N	PRESENT	0
582351	580071	08010L	PARTICIPANT	\N	PRESENT	0
582352	580071	18193Q	PARTICIPANT	\N	PRESENT	0
582353	580071	19667J	PARTICIPANT	\N	PRESENT	0
582354	580071	14215L	PARTICIPANT	\N	PRESENT	0
582355	580071	18083K	PARTICIPANT	\N	PRESENT	0
582356	580071	04033B	PARTICIPANT	\N	PRESENT	0
582357	580071	10015M	PARTICIPANT	\N	PRESENT	0
582358	580071	19443T	PARTICIPANT	\N	PRESENT	0
582359	580071	01058X	PARTICIPANT	\N	PRESENT	0
582360	580071	20070A	PARTICIPANT	\N	PRESENT	0
582361	580071	20096L	PARTICIPANT	\N	PRESENT	0
582362	580071	19749K	PARTICIPANT	\N	PRESENT	0
582363	580071	20148F	PARTICIPANT	\N	PRESENT	0
582364	580071	14179A	PARTICIPANT	\N	PRESENT	0
582365	580071	14021P	PARTICIPANT	\N	PRESENT	0
582366	580071	07004J	PARTICIPANT	\N	PRESENT	0
582293	580071	99004R	PARTICIPANT	\N	PRESENT	0
582294	580071	19533U	PARTICIPANT	\N	PRESENT	0
582367	580071	19577H	PARTICIPANT	\N	PRESENT	0
582368	580071	20086J	PARTICIPANT	\N	PRESENT	0
582369	580071	04035D	PARTICIPANT	\N	PRESENT	0
582370	580071	19768N	PARTICIPANT	\N	PRESENT	0
582371	580071	11026G	PARTICIPANT	\N	PRESENT	0
582372	580071	10006L	PARTICIPANT	\N	PRESENT	0
582373	580071	19723Y	PARTICIPANT	\N	PRESENT	0
582374	580071	14255U	PARTICIPANT	\N	PRESENT	0
582375	580071	19649G	PARTICIPANT	\N	PRESENT	0
582376	580071	19669L	PARTICIPANT	\N	PRESENT	0
582377	580071	16685X	PARTICIPANT	\N	PRESENT	0
582378	580071	08073C	PARTICIPANT	\N	PRESENT	0
582379	580071	17737W	PARTICIPANT	\N	PRESENT	0
582380	580071	19599P	PARTICIPANT	\N	PRESENT	0
582381	580071	12041X	PARTICIPANT	\N	PRESENT	0
582382	580071	20122U	PARTICIPANT	\N	PRESENT	0
582383	580071	14071N	PARTICIPANT	\N	PRESENT	0
582384	580071	14069U	PARTICIPANT	\N	PRESENT	0
582385	580071	14225N	PARTICIPANT	\N	PRESENT	0
582386	580071	19703U	PARTICIPANT	\N	PRESENT	0
582387	580071	19701S	PARTICIPANT	\N	PRESENT	0
582388	580071	11085T	PARTICIPANT	\N	PRESENT	0
582389	580071	19651A	PARTICIPANT	\N	PRESENT	0
582390	580071	11053K	PARTICIPANT	\N	PRESENT	0
582391	580071	20172F	PARTICIPANT	\N	PRESENT	0
582392	580071	20068G	PARTICIPANT	\N	PRESENT	0
582393	580071	20128B	PARTICIPANT	\N	PRESENT	0
582394	580071	17023S	PARTICIPANT	\N	PRESENT	0
582395	580071	19697Q	PARTICIPANT	\N	PRESENT	0
571790	571741	11043H	PARTICIPANT	\N	PRESENT	0
580043	579390	11070L	PARTICIPANT	\N	PRESENT	0
575921	575918	14059S	PARTICIPANT	\N	PRESENT	0
575572	575103	04085P	PARTICIPANT	\N	PRESENT	1
575573	575103	14069U	PARTICIPANT	\N	PRESENT	1
575574	575103	11056N	PARTICIPANT	\N	PRESENT	1
575575	575103	07004J	PARTICIPANT	\N	PRESENT	1
575576	575103	14107H	PARTICIPANT	\N	PRESENT	1
575577	575103	14147R	PARTICIPANT	\N	PRESENT	1
575578	575103	19447X	PARTICIPANT	\N	PRESENT	1
575579	575103	20074E	PARTICIPANT	\N	EXCUSE	0
575919	575918	20104S	PARTICIPANT	\N	PRESENT	0
575920	575918	08045X	PARTICIPANT	\N	PRESENT	0
575922	575918	14331P	PARTICIPANT	\N	PRESENT	0
575923	575918	20180F	PARTICIPANT	\N	PRESENT	0
575924	575918	11090Q	PARTICIPANT	\N	PRESENT	0
580045	579390	19669L	PARTICIPANT	\N	PRESENT	0
580046	579390	19347U	PARTICIPANT	\N	PRESENT	0
580047	579390	04034C	PARTICIPANT	\N	PRESENT	0
580048	579390	08061X	PARTICIPANT	\N	PRESENT	0
580049	579390	14207L	PARTICIPANT	\N	PRESENT	0
575507	575506	20180F	PARTICIPANT	\N	PRESENT	1
575508	575506	19735D	PARTICIPANT	\N	PRESENT	1
575509	575506	14229S	PARTICIPANT	\N	PRESENT	1
575510	575506	20142Y	PARTICIPANT	\N	PRESENT	1
580050	579390	20116W	PARTICIPANT	\N	PRESENT	0
580051	579390	20072C	PARTICIPANT	\N	PRESENT	0
580052	579390	19387D	PARTICIPANT	\N	PRESENT	0
580053	579390	20050V	PARTICIPANT	\N	PRESENT	0
580055	579390	19583F	PARTICIPANT	\N	PRESENT	0
580056	579390	19333N	PARTICIPANT	\N	PRESENT	0
580057	579390	14257W	PARTICIPANT	\N	PRESENT	0
580058	579390	12041X	PARTICIPANT	\N	PRESENT	0
580059	579390	19565D	PARTICIPANT	\N	PRESENT	0
580060	579390	20088L	PARTICIPANT	\N	PRESENT	0
580061	579390	19251M	PARTICIPANT	\N	PRESENT	0
580062	579390	12028B	PARTICIPANT	\N	PRESENT	0
580063	579390	20070A	PARTICIPANT	\N	PRESENT	0
580064	579390	19820Y	PARTICIPANT	\N	PRESENT	0
580065	579390	14151M	PARTICIPANT	\N	PRESENT	0
580066	579390	20134Y	PARTICIPANT	\N	PRESENT	0
580067	579390	20018V	PARTICIPANT	\N	PRESENT	0
580068	579390	19631V	PARTICIPANT	\N	PRESENT	0
580070	579390	20100N	PARTICIPANT	\N	PRESENT	0
580072	579390	14107H	PARTICIPANT	\N	PRESENT	0
580073	579390	19563B	PARTICIPANT	\N	PRESENT	0
580074	579390	14073Q	PARTICIPANT	\N	PRESENT	0
580075	579390	01024M	PARTICIPANT	\N	PRESENT	0
580076	579390	14255U	PARTICIPANT	\N	PRESENT	0
580077	579390	19747H	PARTICIPANT	\N	PRESENT	0
580078	579390	19693L	PARTICIPANT	\N	PRESENT	0
580079	579390	20090E	PARTICIPANT	\N	PRESENT	0
580080	579390	19703U	PARTICIPANT	\N	PRESENT	0
580081	579390	20076G	PARTICIPANT	\N	PRESENT	0
580082	579390	97011G	PARTICIPANT	\N	PRESENT	0
580083	579390	20172F	PARTICIPANT	\N	PRESENT	0
580084	579390	19575F	PARTICIPANT	\N	PRESENT	0
580085	579390	14147R	PARTICIPANT	\N	PRESENT	0
580086	579390	08047A	PARTICIPANT	\N	PRESENT	0
580091	579390	19673G	PARTICIPANT	\N	PRESENT	0
580088	579390	20022R	PARTICIPANT	\N	PRESENT	0
580089	579390	20038A	PARTICIPANT	\N	PRESENT	0
580090	579390	05012A	PARTICIPANT	\N	PRESENT	0
580092	579390	20034V	PARTICIPANT	\N	PRESENT	0
580093	579390	01025N	PARTICIPANT	\N	PRESENT	0
580094	579390	19467C	PARTICIPANT	\N	PRESENT	0
580095	579390	14033T	PARTICIPANT	\N	PRESENT	0
580096	579390	20108W	PARTICIPANT	\N	PRESENT	0
580097	579390	19782L	PARTICIPANT	\N	PRESENT	0
580098	579390	04042C	PARTICIPANT	\N	PRESENT	0
580099	579390	19507S	PARTICIPANT	\N	PRESENT	0
580100	579390	19349W	PARTICIPANT	\N	PRESENT	0
580101	579390	14195A	PARTICIPANT	\N	PRESENT	0
580102	579390	01058X	PARTICIPANT	\N	PRESENT	0
580103	579390	20056C	PARTICIPANT	\N	PRESENT	0
580104	579390	19798U	PARTICIPANT	\N	PRESENT	0
580105	579390	14071N	PARTICIPANT	\N	PRESENT	0
580113	579390	14026U	PARTICIPANT	\N	PRESENT	0
580111	579390	14083S	PARTICIPANT	\N	PRESENT	0
580112	579390	19335Q	PARTICIPANT	\N	PRESENT	0
580114	579390	07029T	PARTICIPANT	\N	PRESENT	0
580115	579390	19725B	PARTICIPANT	\N	PRESENT	0
580116	579390	20180F	PARTICIPANT	\N	PRESENT	0
580117	579390	19599P	PARTICIPANT	\N	PRESENT	0
580118	579390	19383Y	PARTICIPANT	\N	PRESENT	0
580119	579562	20090E	PRESIDENT	0	PRESENT	0
580120	579562	17779H	PARTICIPANT	\N	PRESENT	0
580121	579390	20026V	PARTICIPANT	\N	PRESENT	0
580122	579390	19649G	PARTICIPANT	\N	PRESENT	0
580123	579390	19760E	PARTICIPANT	\N	PRESENT	0
580132	579390	07004J	PARTICIPANT	\N	PRESENT	0
580135	579390	19629C	PARTICIPANT	\N	PRESENT	0
580136	579390	19713W	PARTICIPANT	\N	PRESENT	0
580137	579390	14179A	PARTICIPANT	\N	PRESENT	0
580138	579390	01028R	PARTICIPANT	\N	PRESENT	0
580139	579390	19699S	PARTICIPANT	\N	PRESENT	0
580140	579390	19717B	PARTICIPANT	\N	PRESENT	0
580044	579390	19421M	PARTICIPANT	\N	PRESENT	0
580141	579390	19479G	PARTICIPANT	\N	PRESENT	0
580142	579390	19691J	PARTICIPANT	\N	PRESENT	0
580143	579562	20060X	PARTICIPANT	\N	PRESENT	0
580144	579562	20062A	PARTICIPANT	\N	EXCUSE	0
580145	579390	19697Q	PARTICIPANT	\N	PRESENT	0
580146	579390	20128B	PARTICIPANT	\N	PRESENT	0
580147	579390	14231L	PARTICIPANT	\N	PRESENT	0
580197	579391	19717B	PARTICIPANT	\N	PRESENT	0
580198	579391	19697Q	PARTICIPANT	\N	PRESENT	0
580199	579391	19760E	PARTICIPANT	\N	PRESENT	0
580200	579391	19713W	PARTICIPANT	\N	PRESENT	0
580201	579391	18193Q	PARTICIPANT	\N	PRESENT	0
580202	579391	20130U	PARTICIPANT	\N	PRESENT	0
580203	579391	20116W	PARTICIPANT	\N	PRESENT	0
580204	579391	14195A	PARTICIPANT	\N	PRESENT	0
580205	579391	19563B	PARTICIPANT	\N	PRESENT	0
580206	579391	19479G	PARTICIPANT	\N	PRESENT	0
580207	579391	07004J	PARTICIPANT	\N	PRESENT	0
580208	579391	11031D	PARTICIPANT	\N	PRESENT	0
580209	579391	19565D	PARTICIPANT	\N	PRESENT	0
580210	579391	14042U	PARTICIPANT	\N	PRESENT	0
580211	579391	19691J	PARTICIPANT	\N	PRESENT	0
580212	579391	19725B	PARTICIPANT	\N	PRESENT	0
580213	579391	20128B	PARTICIPANT	\N	PRESENT	0
580214	579391	01024M	PARTICIPANT	\N	PRESENT	0
580215	579391	19798U	PARTICIPANT	\N	PRESENT	0
580216	579391	19575F	PARTICIPANT	\N	PRESENT	0
580217	579391	19383Y	PARTICIPANT	\N	PRESENT	0
580218	579391	19703U	PARTICIPANT	\N	PRESENT	0
580219	579391	97011G	PARTICIPANT	\N	PRESENT	0
580220	579391	14147R	PARTICIPANT	\N	PRESENT	0
580221	579391	20026V	PARTICIPANT	\N	PRESENT	0
580222	579391	20056C	PARTICIPANT	\N	PRESENT	0
580223	579391	19467C	PARTICIPANT	\N	PRESENT	0
580224	579391	07029T	PARTICIPANT	\N	PRESENT	0
580225	579391	19693L	PARTICIPANT	\N	PRESENT	0
580226	579391	19335Q	PARTICIPANT	\N	PRESENT	0
580227	579391	19699S	PARTICIPANT	\N	PRESENT	0
580228	579391	01025N	PARTICIPANT	\N	PRESENT	0
580229	579391	14055N	PARTICIPANT	\N	PRESENT	0
580230	579391	14231L	PARTICIPANT	\N	PRESENT	0
580231	579391	19533U	PARTICIPANT	\N	PRESENT	0
580232	579391	11043H	PARTICIPANT	\N	PRESENT	0
580233	579391	11045K	PARTICIPANT	\N	PRESENT	0
580234	579391	10006L	PARTICIPANT	\N	PRESENT	0
580235	579391	14179A	PARTICIPANT	\N	PRESENT	0
580236	579391	19447X	PARTICIPANT	\N	PRESENT	0
580237	579391	14083S	PARTICIPANT	\N	PRESENT	0
580238	579391	20024T	PARTICIPANT	\N	PRESENT	0
580239	579391	20034V	PARTICIPANT	\N	PRESENT	0
580240	579391	04092N	PARTICIPANT	\N	PRESENT	0
580241	579391	14031R	PARTICIPANT	\N	PRESENT	0
580242	579391	19673G	PARTICIPANT	\N	PRESENT	0
580243	579391	20038A	PARTICIPANT	\N	PRESENT	0
580195	579391	11070L	PARTICIPANT	\N	PRESENT	0
580196	579391	14026U	PARTICIPANT	\N	PRESENT	0
580244	579391	14107H	PARTICIPANT	\N	PRESENT	0
580245	579391	20046A	PARTICIPANT	\N	PRESENT	0
580246	579391	20086J	PARTICIPANT	\N	PRESENT	0
580247	579391	19387D	PARTICIPANT	\N	PRESENT	0
580248	579391	08061X	PARTICIPANT	\N	PRESENT	0
580249	579391	14215L	PARTICIPANT	\N	PRESENT	0
580250	579391	20142Y	PARTICIPANT	\N	PRESENT	0
591207	590845	19387D	PARTICIPANT	\N	PRESENT	0
591208	590845	19553Y	PARTICIPANT	\N	PRESENT	0
591209	590845	14195A	PARTICIPANT	\N	PRESENT	0
591210	590845	11012A	PARTICIPANT	\N	PRESENT	0
591211	590845	14231L	PARTICIPANT	\N	PRESENT	0
591212	590845	14073Q	PARTICIPANT	\N	PRESENT	0
591213	590845	14275Y	PARTICIPANT	\N	PRESENT	0
591214	590845	08045X	PARTICIPANT	\N	PRESENT	0
591215	590845	18193Q	PARTICIPANT	\N	PRESENT	0
591216	590845	11031D	PARTICIPANT	\N	PRESENT	0
591217	590845	20102Q	PARTICIPANT	\N	PRESENT	0
591218	590845	20088L	PARTICIPANT	\N	PRESENT	0
591219	590845	14121F	PARTICIPANT	\N	PRESENT	0
591220	590845	20070A	PARTICIPANT	\N	PRESENT	0
591221	590845	19681G	PARTICIPANT	\N	PRESENT	0
591222	590845	20048C	PARTICIPANT	\N	PRESENT	0
591223	590845	19713W	PARTICIPANT	\N	PRESENT	0
591224	590845	17779H	PARTICIPANT	\N	PRESENT	0
591225	590845	19798U	PARTICIPANT	\N	PRESENT	0
591226	590845	20090E	PARTICIPANT	\N	PRESENT	0
591227	590845	20130U	PARTICIPANT	\N	PRESENT	0
591228	590845	20134Y	PARTICIPANT	\N	PRESENT	0
591229	590845	14217N	PARTICIPANT	\N	PRESENT	0
591230	590845	11097X	PARTICIPANT	\N	PRESENT	0
591231	590845	11103C	PARTICIPANT	\N	PRESENT	0
591232	590845	19679N	PARTICIPANT	\N	PRESENT	0
591233	590845	20076G	PARTICIPANT	\N	PRESENT	0
591234	590845	99004R	PARTICIPANT	\N	PRESENT	0
591235	590845	19703U	PARTICIPANT	\N	PRESENT	0
591236	590845	14223L	PARTICIPANT	\N	PRESENT	0
591237	590845	20068G	PARTICIPANT	\N	PRESENT	0
591238	590845	20026V	PARTICIPANT	\N	PRESENT	0
591239	590845	19747H	PARTICIPANT	\N	PRESENT	0
591240	590845	04033B	PARTICIPANT	\N	PRESENT	0
591241	590845	18083K	PARTICIPANT	\N	PRESENT	0
591242	590845	20140W	PARTICIPANT	\N	PRESENT	0
591243	590845	14071N	PARTICIPANT	\N	PRESENT	0
591244	590845	19549D	PARTICIPANT	\N	PRESENT	0
591245	590845	20038A	PARTICIPANT	\N	PRESENT	0
591289	590845	14042U	PARTICIPANT	\N	PRESENT	0
591247	590845	14173T	PARTICIPANT	\N	PRESENT	0
591248	590845	19691J	PARTICIPANT	\N	PRESENT	0
591249	590800	14205J	PARTICIPANT	\N	PRESENT	1
591250	590845	19760E	PARTICIPANT	\N	PRESENT	0
591251	590845	20132W	PARTICIPANT	\N	PRESENT	0
591252	590845	20116W	PARTICIPANT	\N	PRESENT	0
591253	590845	19651A	PARTICIPANT	\N	PRESENT	0
591254	590845	20248J	PARTICIPANT	\N	PRESENT	0
591255	590492	19251M	PARTICIPANT	\N	EXCUSE	0
591260	590845	19723Y	PARTICIPANT	\N	PRESENT	0
591261	590845	19543W	PARTICIPANT	\N	PRESENT	0
591262	590845	01025N	PARTICIPANT	\N	PRESENT	0
591263	590845	20082E	PARTICIPANT	\N	PRESENT	0
591264	590845	14257W	PARTICIPANT	\N	PRESENT	0
591265	590845	04045F	PARTICIPANT	\N	PRESENT	0
591266	590845	20054A	PARTICIPANT	\N	PRESENT	0
591267	590845	14213J	PARTICIPANT	\N	PRESENT	0
591268	590845	10006L	PARTICIPANT	\N	PRESENT	0
591269	590845	20174H	PARTICIPANT	\N	PRESENT	0
591270	590845	19563B	PARTICIPANT	\N	PRESENT	0
591271	590845	19762G	PARTICIPANT	\N	PRESENT	0
591272	590845	20078J	PARTICIPANT	\N	PRESENT	0
591273	590845	11027H	PARTICIPANT	\N	PRESENT	0
591205	590845	19719D	PARTICIPANT	\N	PRESENT	0
591206	590845	19301E	PARTICIPANT	\N	PRESENT	0
591274	590845	14033T	PARTICIPANT	\N	PRESENT	0
591275	590845	19441R	PARTICIPANT	\N	PRESENT	0
591276	590845	19515S	PARTICIPANT	\N	PRESENT	0
591277	590845	19695N	PARTICIPANT	\N	PRESENT	0
591279	590845	19467C	PARTICIPANT	\N	PRESENT	0
591283	590845	20044X	PARTICIPANT	\N	PRESENT	0
591284	590845	19507S	PARTICIPANT	\N	PRESENT	0
591285	590845	01057W	PARTICIPANT	\N	PRESENT	0
591286	590845	20062A	PARTICIPANT	\N	PRESENT	0
591287	590845	19673G	PARTICIPANT	\N	PRESENT	0
591288	590845	20172F	PARTICIPANT	\N	PRESENT	0
591290	590845	14107H	PARTICIPANT	\N	PRESENT	0
591291	590845	14147R	PARTICIPANT	\N	PRESENT	0
591292	590845	20018V	PARTICIPANT	\N	PRESENT	0
591293	590492	18083K	PARTICIPANT	\N	PRESENT	0
591294	590492	08060W	PARTICIPANT	\N	PRESENT	0
591295	590492	20068G	PARTICIPANT	\N	PRESENT	0
591296	590492	20076G	PARTICIPANT	\N	PRESENT	0
591297	590492	19387D	PARTICIPANT	\N	PRESENT	0
591298	590492	19739H	PARTICIPANT	\N	PRESENT	0
591299	590492	19820Y	PARTICIPANT	\N	PRESENT	0
591300	590492	14219Q	PRESIDENT	0	PRESENT	0
591301	590492	20020P	PARTICIPANT	\N	PRESENT	0
591302	590492	19745F	PARTICIPANT	\N	PRESENT	0
591303	590492	19826F	PARTICIPANT	\N	PRESENT	0
591304	590492	20046A	PARTICIPANT	\N	PRESENT	0
591305	590845	19383Y	PARTICIPANT	\N	PRESENT	0
591306	590492	20136B	PARTICIPANT	\N	PRESENT	0
591307	590492	14031R	PARTICIPANT	\N	PRESENT	0
591308	590492	20140W	PARTICIPANT	\N	PRESENT	0
591309	590492	14169X	PARTICIPANT	\N	PRESENT	0
591310	590492	19637C	PARTICIPANT	\N	PRESENT	0
591311	590492	20100N	PARTICIPANT	\N	PRESENT	0
591312	590492	19503N	PARTICIPANT	\N	PRESENT	0
591313	590492	17367Q	PARTICIPANT	\N	PRESENT	0
591314	590492	11065P	PARTICIPANT	\N	PRESENT	0
591315	590845	20066E	PARTICIPANT	\N	PRESENT	0
591316	590492	14237S	PARTICIPANT	\N	PRESENT	0
591317	590492	20106U	PARTICIPANT	\N	PRESENT	1
591318	590492	19681G	PARTICIPANT	\N	PRESENT	0
591319	590492	20032T	PARTICIPANT	\N	PRESENT	0
591320	590492	11101A	PARTICIPANT	\N	PRESENT	0
591321	590492	20120S	PARTICIPANT	\N	PRESENT	1
591322	590845	19413M	PARTICIPANT	\N	PRESENT	0
591323	590845	14189C	PARTICIPANT	\N	PRESENT	0
591324	590845	17637T	PARTICIPANT	\N	PRESENT	0
591325	590845	04092N	PARTICIPANT	\N	PRESENT	0
591326	590845	19631V	PARTICIPANT	\N	PRESENT	0
591327	590845	14083S	PARTICIPANT	\N	PRESENT	0
591329	591328	04047H	PARTICIPANT	\N	PRESENT	0
591330	591328	20108W	PARTICIPANT	\N	PRESENT	0
591331	591328	11072N	PARTICIPANT	\N	PRESENT	0
591332	591328	14111D	PARTICIPANT	\N	PRESENT	0
591346	590845	14111D	PARTICIPANT	\N	PRESENT	0
591334	590845	19369B	PARTICIPANT	\N	PRESENT	0
591335	590845	11048N	PARTICIPANT	\N	PRESENT	0
591336	590845	11085T	PARTICIPANT	\N	PRESENT	0
591337	590492	19549D	PARTICIPANT	\N	PRESENT	0
591338	590492	19551W	PARTICIPANT	\N	PRESENT	0
591339	590492	20118Y	PARTICIPANT	\N	PRESENT	0
591340	590492	19711U	PARTICIPANT	\N	PRESENT	0
591341	590492	19619A	PARTICIPANT	\N	PRESENT	0
591342	590845	19709B	PARTICIPANT	\N	PRESENT	0
591343	590845	20056C	PARTICIPANT	\N	PRESENT	0
591344	590845	20126Y	PARTICIPANT	\N	PRESENT	0
591345	590845	20052X	PARTICIPANT	\N	PRESENT	0
591347	590845	20034V	PARTICIPANT	\N	PRESENT	0
591348	590845	11110B	PARTICIPANT	\N	PRESENT	0
591349	590845	19687N	PARTICIPANT	\N	PRESENT	0
571807	571806	10006L	PARTICIPANT	\N	PRESENT	0
571808	571806	14357A	PARTICIPANT	\N	PRESENT	0
571809	571806	11026G	PARTICIPANT	\N	PRESENT	0
571904	571903	20094J	PARTICIPANT	\N	PRESENT	0
573649	573326	19739H	PARTICIPANT	\N	PRESENT	0
573650	573326	20144B	PARTICIPANT	\N	PRESENT	0
573651	573326	19549D	PARTICIPANT	\N	PRESENT	0
573652	573326	14033T	PARTICIPANT	\N	PRESENT	0
573654	573326	14225N	PARTICIPANT	\N	PRESENT	0
573655	573326	20140W	PARTICIPANT	\N	PRESENT	0
573656	573326	14221J	PARTICIPANT	\N	PRESENT	0
573657	573326	14195A	PARTICIPANT	\N	PRESENT	0
573658	573326	04059M	PARTICIPANT	\N	PRESENT	0
573659	573326	20096L	PARTICIPANT	\N	PRESENT	0
573660	573326	20036X	PARTICIPANT	\N	PRESENT	0
573661	573326	19747H	PARTICIPANT	\N	PRESENT	0
573662	573326	20116W	PARTICIPANT	\N	PRESENT	0
573663	573326	11056N	PARTICIPANT	\N	PRESENT	0
573664	573326	20028X	PARTICIPANT	\N	PRESENT	0
573665	573326	20120S	PARTICIPANT	\N	PRESENT	0
573666	573326	14187A	PARTICIPANT	\N	PRESENT	0
573667	573326	19717B	PARTICIPANT	\N	PRESENT	0
573668	573326	11090Q	PARTICIPANT	\N	PRESENT	0
573669	573326	19719D	PARTICIPANT	\N	PRESENT	0
573670	573326	08047A	PARTICIPANT	\N	PRESENT	0
573671	573326	20124W	PARTICIPANT	\N	PRESENT	0
573672	573326	12041X	PARTICIPANT	\N	PRESENT	0
573673	573326	19527W	PARTICIPANT	\N	PRESENT	0
573674	573326	14205J	PARTICIPANT	\N	PRESENT	0
573675	573326	11031D	PARTICIPANT	\N	PRESENT	0
573676	573326	19741B	PARTICIPANT	\N	PRESENT	0
573677	573326	20082E	PARTICIPANT	\N	PRESENT	0
573678	573326	19679N	PARTICIPANT	\N	PRESENT	0
573679	573326	19441R	PARTICIPANT	\N	PRESENT	0
573680	573326	20108W	PARTICIPANT	\N	PRESENT	0
573681	573326	01024M	PARTICIPANT	\N	PRESENT	0
573682	573326	11012A	PARTICIPANT	\N	PRESENT	0
573683	573326	20052X	PARTICIPANT	\N	PRESENT	0
573684	573326	04008A	PARTICIPANT	\N	PRESENT	0
573685	573326	11097X	PARTICIPANT	\N	PRESENT	0
573686	573326	20026V	PARTICIPANT	\N	PRESENT	0
573687	573326	05012A	PARTICIPANT	\N	PRESENT	0
573688	573326	14097Y	PARTICIPANT	\N	PRESENT	0
573689	573326	11083R	PARTICIPANT	\N	PRESENT	0
573690	573326	20092G	PARTICIPANT	\N	PRESENT	0
573702	573326	14055N	PARTICIPANT	\N	PRESENT	0
573692	573326	14069U	PARTICIPANT	\N	PRESENT	0
573693	573326	19415P	PARTICIPANT	\N	PRESENT	0
573694	573326	07029T	PARTICIPANT	\N	PRESENT	0
573695	573326	20042V	PARTICIPANT	\N	PRESENT	0
573696	573326	20126Y	PARTICIPANT	\N	PRESENT	0
573697	573326	19667J	PARTICIPANT	\N	PRESENT	0
573698	573326	19663E	PARTICIPANT	\N	PRESENT	0
573699	573326	20136B	PARTICIPANT	\N	PRESENT	0
573700	573326	08045X	PARTICIPANT	\N	PRESENT	0
573701	573326	19563B	PARTICIPANT	\N	PRESENT	0
573703	573326	08010L	PARTICIPANT	\N	PRESENT	0
573704	573326	14030Q	PARTICIPANT	\N	PRESENT	0
573705	573326	08073C	PARTICIPANT	\N	PRESENT	0
573706	573326	19507S	PARTICIPANT	\N	PRESENT	0
573707	573326	20044X	PARTICIPANT	\N	PRESENT	0
573708	573326	20034V	PARTICIPANT	\N	PRESENT	0
573709	573326	11045K	PARTICIPANT	\N	PRESENT	0
573710	573326	19643A	PARTICIPANT	\N	PRESENT	0
573712	573326	19701S	PARTICIPANT	\N	PRESENT	0
573713	573326	20152B	PARTICIPANT	\N	PRESENT	0
573715	573326	04070G	PARTICIPANT	\N	PRESENT	0
573716	573326	11085T	PARTICIPANT	\N	PRESENT	0
573717	573326	19762G	PARTICIPANT	\N	PRESENT	0
573718	573326	19671E	PARTICIPANT	\N	PRESENT	0
573719	573326	19335Q	PARTICIPANT	\N	PRESENT	0
573720	573326	08060W	PARTICIPANT	\N	PRESENT	0
573725	573326	19760E	PARTICIPANT	\N	PRESENT	0
573726	573326	19489J	PARTICIPANT	\N	PRESENT	0
573727	573326	11033F	PARTICIPANT	\N	PRESENT	0
573728	573326	04057K	PARTICIPANT	\N	PRESENT	0
573729	573326	14042U	PARTICIPANT	\N	PRESENT	0
573732	573326	11070L	PARTICIPANT	\N	PRESENT	0
573733	573326	19768N	PARTICIPANT	\N	PRESENT	0
573734	573326	08056B	PARTICIPANT	\N	PRESENT	0
573735	573326	14211G	PARTICIPANT	\N	PRESENT	0
573736	573326	19693L	PARTICIPANT	\N	PRESENT	0
573737	573326	14021P	PARTICIPANT	\N	PRESENT	0
573739	573326	19347U	PARTICIPANT	\N	PRESENT	0
573740	573326	01060R	PARTICIPANT	\N	PRESENT	0
573741	573326	20068G	PARTICIPANT	\N	PRESENT	0
573745	573326	20080C	PARTICIPANT	\N	PRESENT	0
573746	573326	19551W	PARTICIPANT	\N	PRESENT	0
573747	573326	14053L	PARTICIPANT	\N	PRESENT	0
573749	573326	01057W	PARTICIPANT	\N	PRESENT	0
573751	573326	20066E	PARTICIPANT	\N	PRESENT	0
573752	573326	20070A	PARTICIPANT	\N	PRESENT	0
573753	573326	20050V	PARTICIPANT	\N	PRESENT	0
573754	573326	14327T	PARTICIPANT	\N	PRESENT	0
573755	573326	11066Q	PARTICIPANT	\N	PRESENT	0
573756	573326	19713W	PARTICIPANT	\N	PRESENT	0
573757	573326	20098N	PARTICIPANT	\N	PRESENT	0
573758	573326	19545Y	PARTICIPANT	\N	PRESENT	0
573759	573326	08015R	PARTICIPANT	\N	PRESENT	0
573761	573326	19553Y	PARTICIPANT	\N	PRESENT	0
573763	573326	20128B	PARTICIPANT	\N	PRESENT	0
573923	572961	19768N	PARTICIPANT	\N	PRESENT	0
573924	572961	20034V	PARTICIPANT	\N	PRESENT	0
573925	572961	14187A	PARTICIPANT	\N	PRESENT	0
573926	572961	08015R	PARTICIPANT	\N	PRESENT	0
573927	572961	11090Q	PRESIDENT	0	PRESENT	0
573928	572961	14033T	PARTICIPANT	\N	PRESENT	0
573929	572961	20054A	PARTICIPANT	\N	PRESENT	0
573930	572961	19631V	PARTICIPANT	\N	PRESENT	0
573933	573327	86034E	PARTICIPANT	\N	PRESENT	0
573934	573327	11026G	PARTICIPANT	\N	PRESENT	0
573935	573327	11045K	PARTICIPANT	\N	PRESENT	0
573936	573327	11066Q	PARTICIPANT	\N	PRESENT	0
573937	573327	11033F	PARTICIPANT	\N	PRESENT	0
573938	572961	19515S	PARTICIPANT	\N	PRESENT	0
573939	572961	19747H	PARTICIPANT	\N	PRESENT	0
573940	573327	19553Y	PARTICIPANT	\N	PRESENT	0
573941	573327	14207L	PARTICIPANT	\N	PRESENT	0
573942	573327	14215L	PARTICIPANT	\N	PRESENT	0
573943	573327	04008A	PARTICIPANT	\N	PRESENT	0
573944	573327	19637C	PARTICIPANT	\N	PRESENT	0
574007	573327	20026V	PARTICIPANT	\N	PRESENT	0
573946	573327	07004J	PARTICIPANT	\N	PRESENT	0
573947	573327	20124W	PARTICIPANT	\N	PRESENT	0
573948	573327	14105F	PARTICIPANT	\N	PRESENT	0
573949	573327	20128B	PARTICIPANT	\N	PRESENT	0
573950	572961	19467C	PARTICIPANT	\N	PRESENT	0
573951	572961	20144B	PARTICIPANT	\N	PRESENT	0
573967	573327	04085P	PARTICIPANT	\N	PRESENT	0
573970	573327	11056N	PARTICIPANT	\N	PRESENT	0
573972	573327	01028R	PARTICIPANT	\N	PRESENT	0
573973	573327	14053L	PARTICIPANT	\N	PRESENT	0
573974	573327	04047H	PARTICIPANT	\N	PRESENT	0
573975	572961	19782L	PARTICIPANT	\N	PRESENT	0
573976	572961	01043Q	PARTICIPANT	\N	PRESENT	1
573977	572961	19441R	PARTICIPANT	\N	PRESENT	0
573978	572961	19695N	PARTICIPANT	\N	PRESENT	0
573979	572961	20174H	PARTICIPANT	\N	PRESENT	1
573980	572961	14205J	PARTICIPANT	\N	PRESENT	0
573981	573327	20042V	PARTICIPANT	\N	PRESENT	0
573982	573327	19713W	PARTICIPANT	\N	PRESENT	0
573983	573327	19725B	PARTICIPANT	\N	PRESENT	0
573984	573327	01024M	PARTICIPANT	\N	PRESENT	0
573985	573327	19826F	PARTICIPANT	\N	PRESENT	0
573986	573327	19347U	PARTICIPANT	\N	PRESENT	0
573987	573327	20116W	PARTICIPANT	\N	PRESENT	0
573988	572961	14038Y	PARTICIPANT	\N	PRESENT	1
573990	572961	20092G	PARTICIPANT	\N	PRESENT	0
573991	572961	20094J	PARTICIPANT	\N	PRESENT	0
574005	573327	19593H	PARTICIPANT	\N	PRESENT	0
574011	573327	20140W	PARTICIPANT	\N	PRESENT	0
574013	573327	20108W	PARTICIPANT	\N	PRESENT	0
574014	573327	14123H	PARTICIPANT	\N	PRESENT	0
574015	573327	08061X	PARTICIPANT	\N	PRESENT	0
574016	572961	20082E	PARTICIPANT	\N	PRESENT	0
574017	572961	20018V	PARTICIPANT	\N	PRESENT	1
574018	572961	08028W	PARTICIPANT	\N	EXCUSE	0
574020	572961	14257W	PARTICIPANT	\N	PRESENT	0
574021	572961	19413M	PARTICIPANT	\N	PRESENT	0
574022	573327	08056B	PARTICIPANT	\N	PRESENT	0
574029	573327	19611R	PARTICIPANT	\N	PRESENT	0
582461	581894	12016W	PARTICIPANT	\N	PRESENT	0
582462	581894	08045X	PARTICIPANT	\N	PRESENT	0
582463	581894	20084G	PARTICIPANT	\N	PRESENT	0
582464	581894	19649G	PARTICIPANT	\N	PRESENT	0
582465	581894	17779H	PARTICIPANT	\N	PRESENT	0
582466	581894	19347U	PARTICIPANT	\N	PRESENT	0
582467	581894	99004R	PARTICIPANT	\N	PRESENT	0
582468	581894	19766L	PARTICIPANT	\N	PRESENT	0
582469	581894	20130U	PARTICIPANT	\N	PRESENT	0
582470	581894	20038A	PARTICIPANT	\N	PRESENT	0
582471	581894	19697Q	PARTICIPANT	\N	PRESENT	0
582472	581894	20034V	PARTICIPANT	\N	PRESENT	0
582473	581894	19651A	PARTICIPANT	\N	PRESENT	0
582474	581894	20058E	PARTICIPANT	\N	PRESENT	0
582475	581894	19715Y	PARTICIPANT	\N	PRESENT	0
582476	581894	20086J	PARTICIPANT	\N	PRESENT	0
582477	581894	14073Q	PARTICIPANT	\N	PRESENT	0
582478	581894	14041T	PARTICIPANT	\N	PRESENT	0
582479	581894	07029T	PARTICIPANT	\N	PRESENT	0
582480	581894	19553Y	PARTICIPANT	\N	PRESENT	0
582481	581894	04057K	PARTICIPANT	\N	PRESENT	0
582482	581894	20056C	PARTICIPANT	\N	PRESENT	0
582483	581894	14089Y	PARTICIPANT	\N	PRESENT	0
582484	581894	20022R	PARTICIPANT	\N	PRESENT	0
582485	581894	14055N	PARTICIPANT	\N	PRESENT	0
582486	581894	14215L	PARTICIPANT	\N	PRESENT	0
582487	581894	19701S	PARTICIPANT	\N	PRESENT	0
582488	581894	20120S	PARTICIPANT	\N	PRESENT	0
582489	581894	04092N	PARTICIPANT	\N	PRESENT	0
582490	581894	19671E	PARTICIPANT	\N	PRESENT	0
582491	581894	12041X	PARTICIPANT	\N	PRESENT	0
582492	581894	14217N	PARTICIPANT	\N	PRESENT	0
582493	581894	05008E	PARTICIPANT	\N	PRESENT	0
582494	581894	19695N	PARTICIPANT	\N	PRESENT	0
582495	581894	19593H	PARTICIPANT	\N	PRESENT	0
582496	581894	20172F	PARTICIPANT	\N	PRESENT	0
582459	581894	11045K	PARTICIPANT	\N	PRESENT	0
582460	581894	20114U	PARTICIPANT	\N	PRESENT	0
582497	581894	19768N	PARTICIPANT	\N	PRESENT	0
582498	581894	17737W	PARTICIPANT	\N	PRESENT	0
582499	581894	20126Y	PARTICIPANT	\N	PRESENT	0
582500	581894	11099A	PARTICIPANT	\N	PRESENT	0
582501	581894	14357A	PARTICIPANT	\N	PRESENT	0
582502	581894	19723Y	PARTICIPANT	\N	PRESENT	0
582503	581894	14071N	PARTICIPANT	\N	PRESENT	0
582504	581894	20124W	PARTICIPANT	\N	PRESENT	0
582505	581894	11031D	PARTICIPANT	\N	PRESENT	0
582506	581894	20118Y	PARTICIPANT	\N	PRESENT	0
582507	581894	14053L	PARTICIPANT	\N	PRESENT	0
582508	581894	19443T	PARTICIPANT	\N	PRESENT	0
582509	581894	19657G	PARTICIPANT	\N	PRESENT	0
582510	581894	14026U	PARTICIPANT	\N	PRESENT	0
582511	581894	14151M	PARTICIPANT	\N	PRESENT	0
582512	581894	19749K	PARTICIPANT	\N	PRESENT	0
582513	581894	14255U	PARTICIPANT	\N	PRESENT	0
582514	581894	19577H	PARTICIPANT	\N	PRESENT	0
582515	581894	17023S	PARTICIPANT	\N	PRESENT	0
582516	581894	20044X	PARTICIPANT	\N	PRESENT	0
582517	581894	19573D	PARTICIPANT	\N	PRESENT	0
582518	581894	04033B	PARTICIPANT	\N	PRESENT	0
582519	581894	14042U	PARTICIPANT	\N	PRESENT	0
582520	581894	19687N	PARTICIPANT	\N	PRESENT	0
582521	581894	04035D	PARTICIPANT	\N	PRESENT	0
582522	581894	14211G	PARTICIPANT	\N	PRESENT	0
582523	581894	08069G	PARTICIPANT	\N	PRESENT	0
582524	581894	19713W	PARTICIPANT	\N	PRESENT	0
582525	581894	10006L	PARTICIPANT	\N	PRESENT	0
582526	581894	11026G	PARTICIPANT	\N	PRESENT	0
582527	581894	04047H	PARTICIPANT	\N	PRESENT	0
582528	581894	14179A	PARTICIPANT	\N	PRESENT	0
582529	581894	08010L	PARTICIPANT	\N	PRESENT	0
582530	581894	14069U	PARTICIPANT	\N	PRESENT	0
582567	582566	05008E	PARTICIPANT	\N	PRESENT	0
582568	582566	11053K	PARTICIPANT	\N	PRESENT	0
582569	582566	01028R	PARTICIPANT	\N	PRESENT	0
582870	582631	19954N	PARTICIPANT	\N	PRESENT	1
582871	582631	11033F	PARTICIPANT	\N	PRESENT	1
582872	582631	20110Q	PARTICIPANT	\N	PRESENT	1
582873	582631	14107H	PARTICIPANT	\N	PRESENT	1
582874	582631	14179A	PARTICIPANT	\N	PRESENT	1
582875	582631	11026G	PARTICIPANT	\N	PRESENT	1
582876	582631	19489J	PARTICIPANT	\N	PRESENT	1
582877	582631	14231L	PARTICIPANT	\N	EXCUSE	0
583254	583152	14327T	PARTICIPANT	\N	PRESENT	0
583255	583152	20086J	PARTICIPANT	\N	PRESENT	0
583256	583152	14331P	PARTICIPANT	\N	PRESENT	0
583257	583152	20036X	PARTICIPANT	\N	PRESENT	0
583258	583152	01048V	PARTICIPANT	\N	PRESENT	0
583259	583152	11053K	PARTICIPANT	\N	PRESENT	0
583260	583152	12016W	PARTICIPANT	\N	PRESENT	0
583261	583152	20080C	PARTICIPANT	\N	PRESENT	0
583262	583152	20050V	PARTICIPANT	\N	PRESENT	0
583263	583152	14225N	PRESIDENT	1	PRESENT	0
583264	583152	11070L	PARTICIPANT	\N	PRESENT	0
583265	583152	07029T	PARTICIPANT	\N	PRESENT	0
583266	583152	19349W	PARTICIPANT	\N	PRESENT	0
583267	583152	08010L	PARTICIPANT	\N	PRESENT	0
583268	583152	14121F	PARTICIPANT	\N	PRESENT	0
583269	583152	99004R	PARTICIPANT	\N	PRESENT	0
583270	583152	20022R	PARTICIPANT	\N	PRESENT	0
583271	583152	14189C	PARTICIPANT	\N	PRESENT	0
583272	583152	19335Q	PARTICIPANT	\N	PRESENT	0
583273	582885	19768N	PARTICIPANT	\N	PRESENT	0
583274	582885	19782L	PARTICIPANT	\N	PRESENT	1
583275	582885	20092G	PARTICIPANT	\N	PRESENT	0
583276	582885	01043Q	PARTICIPANT	\N	PRESENT	0
583277	582885	14357A	PARTICIPANT	\N	PRESENT	0
583278	582885	20078J	PARTICIPANT	\N	PRESENT	1
583279	582885	19441R	PARTICIPANT	\N	PRESENT	0
583280	582885	19413M	PARTICIPANT	\N	PRESENT	0
583281	582885	20082E	PARTICIPANT	\N	PRESENT	1
583282	582885	20094J	PARTICIPANT	\N	PRESENT	1
583283	582885	04045F	PARTICIPANT	\N	PRESENT	0
583284	582885	11099A	PARTICIPANT	\N	PRESENT	0
583285	582885	19575F	PARTICIPANT	\N	PRESENT	1
583286	582885	19369B	PARTICIPANT	\N	PRESENT	0
583287	582885	20018V	PARTICIPANT	\N	PRESENT	1
583288	582885	19563B	PARTICIPANT	\N	PRESENT	0
583289	582885	14329V	PARTICIPANT	\N	PRESENT	0
583290	582885	14038Y	PARTICIPANT	\N	PRESENT	0
583291	582885	19467C	PARTICIPANT	\N	PRESENT	1
583292	582885	20034V	PARTICIPANT	\N	PRESENT	0
583293	582885	14187A	PARTICIPANT	\N	PRESENT	0
583294	582885	20144B	PARTICIPANT	\N	PRESENT	0
583295	582885	19695N	PARTICIPANT	\N	PRESENT	0
583296	582885	01025N	PARTICIPANT	\N	PRESENT	1
583297	582885	11090Q	PRESIDENT	0	PRESENT	0
583298	582885	14033T	PARTICIPANT	\N	PRESENT	0
583299	582885	20054A	PARTICIPANT	\N	PRESENT	0
583300	582885	20174H	PARTICIPANT	\N	PRESENT	1
583301	582885	14205J	PARTICIPANT	\N	PRESENT	0
583302	582885	20060X	PARTICIPANT	\N	PRESENT	0
583303	582885	20062A	PARTICIPANT	\N	PRESENT	1
583304	582885	14251Q	PARTICIPANT	\N	PRESENT	1
583305	582885	19507S	PARTICIPANT	\N	PRESENT	0
583306	582885	14257W	PARTICIPANT	\N	PRESENT	0
583307	582885	14207L	PARTICIPANT	\N	EXCUSE	0
583308	582885	19521Q	PARTICIPANT	\N	EXCUSE	0
583309	583152	11048N	PARTICIPANT	\N	PRESENT	0
583310	582885	19705W	PARTICIPANT	\N	PRESENT	0
583311	582885	19747H	PARTICIPANT	\N	PRESENT	0
583312	583152	19479G	PRESIDENT	0	PRESENT	0
583313	583152	01057W	PARTICIPANT	\N	PRESENT	0
583314	583152	19671E	PARTICIPANT	\N	EXCUSE	0
583315	582768	19697Q	PARTICIPANT	\N	PRESENT	0
583316	582768	11067R	PARTICIPANT	\N	PRESENT	0
583317	582768	01034P	PARTICIPANT	\N	PRESENT	0
583318	582768	18193Q	PARTICIPANT	\N	PRESENT	0
583319	582768	20148F	PARTICIPANT	\N	PRESENT	0
583320	582768	19553Y	PARTICIPANT	\N	PRESENT	0
583321	582768	19703U	PARTICIPANT	\N	PRESENT	0
583322	582768	20248J	PARTICIPANT	\N	PRESENT	0
583323	582768	19679N	PARTICIPANT	\N	PRESENT	0
583324	582768	14042U	PARTICIPANT	\N	PRESENT	0
583325	582768	14195A	PARTICIPANT	\N	PRESENT	0
583326	582768	14213J	PARTICIPANT	\N	PRESENT	0
583327	582768	19367Y	PARTICIPANT	\N	PRESENT	0
583328	582768	14217N	PARTICIPANT	\N	PRESENT	0
583329	582768	19683J	PARTICIPANT	\N	PRESENT	0
583330	582768	10006L	PRESIDENT	0	PRESENT	0
570229	568254	11067R	PARTICIPANT	\N	PRESENT	0
570234	568254	18193Q	PARTICIPANT	\N	PRESENT	0
570236	568254	10006L	PRESIDENT	0	PRESENT	0
570239	568254	14213J	PARTICIPANT	0	PRESENT	0
570248	568254	14195A	PARTICIPANT	\N	PRESENT	0
570250	568254	11097X	PARTICIPANT	\N	PRESENT	0
570252	568254	14071N	PARTICIPANT	\N	PRESENT	0
570253	568254	04092N	PARTICIPANT	\N	PRESENT	0
570255	568254	14223L	PARTICIPANT	\N	PRESENT	1
570269	568254	20066E	PARTICIPANT	\N	PRESENT	0
570271	568254	19798U	PARTICIPANT	\N	PRESENT	0
570273	568254	19679N	PARTICIPANT	\N	PRESENT	1
570276	568254	14042U	PARTICIPANT	\N	PRESENT	1
570298	568254	19663E	PARTICIPANT	\N	PRESENT	0
570299	568254	14217N	PARTICIPANT	\N	PRESENT	0
573466	573324	99004R	PARTICIPANT	\N	PRESENT	0
573467	573324	20034V	PARTICIPANT	\N	PRESENT	0
573468	573324	14038Y	PARTICIPANT	\N	PRESENT	0
573469	573324	19681G	PARTICIPANT	\N	PRESENT	0
573470	573324	17229F	PARTICIPANT	\N	PRESENT	0
573471	573324	11090Q	PARTICIPANT	\N	PRESENT	0
573472	573324	20086J	PARTICIPANT	\N	PRESENT	0
573473	573324	19695N	PARTICIPANT	\N	PRESENT	0
573474	573324	19619A	PARTICIPANT	\N	PRESENT	0
573475	573324	20116W	PARTICIPANT	\N	PRESENT	0
573476	573324	14357A	PARTICIPANT	\N	PRESENT	0
573477	573324	14031R	PARTICIPANT	\N	PRESENT	0
573478	573324	20050V	PARTICIPANT	\N	PRESENT	0
573479	573324	19369B	PARTICIPANT	\N	PRESENT	0
573480	573324	20112S	PARTICIPANT	\N	PRESENT	0
573481	573324	20092G	PARTICIPANT	\N	PRESENT	0
573482	573324	20082E	PARTICIPANT	\N	PRESENT	0
573483	573324	11031D	PARTICIPANT	\N	PRESENT	0
573484	573324	11065P	PARTICIPANT	\N	PRESENT	0
573485	573324	14257W	PARTICIPANT	\N	PRESENT	0
573486	573324	19503N	PARTICIPANT	\N	PRESENT	0
573487	573324	08061X	PARTICIPANT	\N	PRESENT	0
573488	573324	19637C	PARTICIPANT	\N	PRESENT	0
573489	573324	19663E	PARTICIPANT	\N	PRESENT	0
573490	573324	14083S	PARTICIPANT	\N	PRESENT	0
573491	573324	19573D	PARTICIPANT	\N	PRESENT	0
573492	573324	14169X	PARTICIPANT	\N	PRESENT	0
573493	573324	14097Y	PARTICIPANT	\N	PRESENT	0
573494	573324	19549D	PARTICIPANT	\N	PRESENT	0
573495	573324	14219Q	PARTICIPANT	\N	PRESENT	0
573496	573324	19599P	PARTICIPANT	\N	PRESENT	0
573497	573324	20136B	PARTICIPANT	\N	PRESENT	0
573498	573324	19631V	PARTICIPANT	\N	PRESENT	0
573499	573324	19333N	PARTICIPANT	\N	PRESENT	0
573500	573324	01048V	PARTICIPANT	\N	PRESENT	0
573501	573324	17589D	PARTICIPANT	\N	PRESENT	0
573502	573324	19711U	PARTICIPANT	\N	PRESENT	0
573503	573324	19701S	PARTICIPANT	\N	PRESENT	0
573504	573324	04047H	PARTICIPANT	\N	PRESENT	0
573505	573324	11085T	PARTICIPANT	\N	PRESENT	0
573506	573324	12041X	PARTICIPANT	\N	PRESENT	0
573507	573324	20142Y	PARTICIPANT	\N	PRESENT	0
573508	573324	20120S	PARTICIPANT	\N	PRESENT	0
573509	573324	14331P	PARTICIPANT	\N	PRESENT	0
573510	573324	19347U	PARTICIPANT	\N	PRESENT	0
573511	573324	19697Q	PARTICIPANT	\N	PRESENT	0
573512	573324	14187A	PARTICIPANT	\N	PRESENT	0
573513	573324	20046A	PARTICIPANT	\N	PRESENT	0
573514	573324	20102Q	PARTICIPANT	\N	PRESENT	0
573515	573324	19413M	PARTICIPANT	\N	PRESENT	0
573516	573324	19741B	PARTICIPANT	\N	PRESENT	0
573517	573324	19747H	PARTICIPANT	\N	PRESENT	0
573518	573324	20076G	PARTICIPANT	\N	PRESENT	0
573519	573324	14205J	PARTICIPANT	\N	PRESENT	0
573520	573324	20018V	PARTICIPANT	\N	PRESENT	0
573523	573522	19333N	PARTICIPANT	\N	PRESENT	0
573524	573522	19701S	PARTICIPANT	\N	PRESENT	0
573525	573522	20136B	PARTICIPANT	\N	PRESENT	0
573526	573522	14031R	PARTICIPANT	\N	PRESENT	0
573527	573522	20076G	PARTICIPANT	\N	PRESENT	0
573528	573522	19549D	PARTICIPANT	\N	PRESENT	0
573529	573522	14219Q	PRESIDENT	0	PRESENT	0
573530	573522	14169X	PARTICIPANT	\N	PRESENT	0
573531	573522	17229F	PARTICIPANT	\N	PRESENT	0
573532	573522	19637C	PARTICIPANT	\N	PRESENT	0
573533	573522	19503N	PARTICIPANT	\N	PRESENT	0
573534	573522	19619A	PARTICIPANT	\N	PRESENT	0
573535	573522	11065P	PARTICIPANT	\N	PRESENT	0
573536	573522	20120S	PARTICIPANT	\N	PRESENT	0
573537	573522	19681G	PARTICIPANT	\N	PRESENT	0
573538	573324	20026V	PARTICIPANT	\N	PRESENT	0
573539	573324	11067R	PARTICIPANT	\N	PRESENT	0
573540	573324	04033B	PARTICIPANT	\N	PRESENT	0
575582	575533	14229S	PARTICIPANT	\N	EXCUSE	0
575609	575104	14147R	PARTICIPANT	\N	PRESENT	1
575611	575104	19447X	PARTICIPANT	\N	PRESENT	0
575612	575104	14089Y	PARTICIPANT	\N	PRESENT	0
575613	575104	14179A	PARTICIPANT	\N	PRESENT	0
575614	575104	20110Q	PARTICIPANT	\N	PRESENT	0
575615	575104	11072N	PARTICIPANT	\N	PRESENT	0
575616	575104	20108W	PARTICIPANT	\N	PRESENT	0
575754	575753	16685X	PARTICIPANT	\N	PRESENT	0
575756	575755	14249W	PARTICIPANT	\N	PRESENT	0
575768	575767	05008E	PARTICIPANT	\N	PRESENT	0
575769	575767	11053K	PARTICIPANT	\N	PRESENT	0
575770	575767	01028R	PARTICIPANT	\N	PRESENT	0
577437	555423	18003S	PARTICIPANT	\N	PRESENT	0
577439	555423	19533U	PARTICIPANT	\N	PRESENT	0
577441	555423	01058X	PARTICIPANT	\N	PRESENT	0
577443	555423	04043D	PARTICIPANT	\N	PRESENT	0
577444	555423	11067R	PARTICIPANT	\N	PRESENT	0
577445	555423	01048V	PARTICIPANT	\N	PRESENT	0
577446	555423	19503N	PARTICIPANT	\N	PRESENT	0
577453	555423	19723Y	PARTICIPANT	\N	PRESENT	0
577456	555423	20128B	PARTICIPANT	\N	PRESENT	0
578192	578191	14089Y	PARTICIPANT	\N	PRESENT	0
578193	578191	14053L	PARTICIPANT	\N	PRESENT	0
578195	578194	14089Y	PARTICIPANT	\N	PRESENT	0
578276	575271	14147R	PARTICIPANT	\N	PRESENT	0
578278	575253	08028W	PARTICIPANT	\N	EXCUSE	0
578279	575253	11099A	PARTICIPANT	\N	PRESENT	0
578280	575253	19467C	PARTICIPANT	\N	PRESENT	1
578283	578282	14089Y	PARTICIPANT	\N	PRESENT	0
578284	578282	14053L	PARTICIPANT	\N	PRESENT	0
578286	578285	14089Y	PARTICIPANT	\N	PRESENT	0
578287	578285	14053L	PARTICIPANT	\N	PRESENT	0
579599	579598	19711U	PARTICIPANT	\N	PRESENT	0
579601	579600	19711U	PARTICIPANT	\N	PRESENT	0
579605	579604	99004R	PARTICIPANT	\N	PRESENT	0
580254	579391	20180F	PARTICIPANT	\N	PRESENT	0
580252	579391	19631V	PARTICIPANT	\N	PRESENT	0
580253	579391	14038Y	PARTICIPANT	\N	PRESENT	0
580255	579391	20102Q	PARTICIPANT	\N	PRESENT	0
580256	579391	19629C	PARTICIPANT	\N	PRESENT	0
580257	579391	19749K	PARTICIPANT	\N	PRESENT	0
580258	579391	19649G	PARTICIPANT	\N	PRESENT	0
580259	579391	19719D	PARTICIPANT	\N	PRESENT	0
580260	579391	19741B	PARTICIPANT	\N	PRESENT	0
580261	579391	20044X	PARTICIPANT	\N	PRESENT	0
580262	579391	11053K	PARTICIPANT	\N	PRESENT	0
580263	579391	20090E	PARTICIPANT	\N	PRESENT	0
580264	579391	04047H	PARTICIPANT	\N	PRESENT	0
580265	579391	20108W	PARTICIPANT	\N	PRESENT	0
580266	579391	18083K	PARTICIPANT	\N	PRESENT	0
591421	590846	20108W	PARTICIPANT	\N	PRESENT	0
591422	590846	20110Q	PARTICIPANT	\N	PRESENT	0
591423	590846	19347U	PARTICIPANT	\N	PRESENT	0
591424	590846	20130U	PARTICIPANT	\N	PRESENT	0
591425	590846	17779H	PARTICIPANT	\N	PRESENT	0
591426	590846	11067R	PARTICIPANT	\N	PRESENT	0
591427	590846	19489J	PARTICIPANT	\N	PRESENT	0
591428	590846	19725B	PARTICIPANT	\N	PRESENT	0
591429	590846	01057W	PARTICIPANT	\N	PRESENT	0
591430	590846	19413M	PARTICIPANT	\N	PRESENT	0
591431	590846	20070A	PARTICIPANT	\N	PRESENT	0
591432	590846	19673G	PARTICIPANT	\N	PRESENT	0
591433	590846	11110B	PARTICIPANT	\N	PRESENT	0
591434	590846	14173T	PARTICIPANT	\N	PRESENT	0
591435	590846	20082E	PARTICIPANT	\N	PRESENT	0
591436	590846	10006L	PARTICIPANT	\N	PRESENT	0
591437	590846	14151M	PARTICIPANT	\N	PRESENT	0
591438	590846	20056C	PARTICIPANT	\N	PRESENT	0
591439	590846	18193Q	PARTICIPANT	\N	PRESENT	0
591440	590492	19685L	PARTICIPANT	\N	PRESENT	0
591441	590846	14121F	PARTICIPANT	\N	PRESENT	0
591442	590846	20034V	PARTICIPANT	\N	PRESENT	0
591443	590846	20088L	PARTICIPANT	\N	PRESENT	0
591444	590846	20044X	PARTICIPANT	\N	PRESENT	0
591445	590492	20038A	PARTICIPANT	\N	PRESENT	0
591446	590846	14195A	PARTICIPANT	\N	PRESENT	0
591447	590846	19399H	PARTICIPANT	\N	PRESENT	0
591448	590846	14111D	PARTICIPANT	\N	PRESENT	0
591449	590846	04033B	PARTICIPANT	\N	PRESENT	0
591450	590846	20052X	PARTICIPANT	\N	PRESENT	0
591451	590846	19369B	PARTICIPANT	\N	PRESENT	0
591452	590846	17229F	PARTICIPANT	\N	PRESENT	0
591453	590846	14213J	PARTICIPANT	\N	PRESENT	0
591454	590846	14147R	PARTICIPANT	\N	PRESENT	0
591455	590846	14189C	PARTICIPANT	\N	PRESENT	0
591456	590846	04092N	PARTICIPANT	\N	PRESENT	0
591457	590846	19441R	PARTICIPANT	\N	PRESENT	0
591458	590846	19691J	PARTICIPANT	\N	PRESENT	0
591459	590846	14217N	PARTICIPANT	\N	PRESENT	0
591460	590846	14231L	PARTICIPANT	\N	PRESENT	0
591461	590846	08009T	PARTICIPANT	\N	PRESENT	0
591462	590846	19573D	PARTICIPANT	\N	PRESENT	0
591419	590846	19719D	PARTICIPANT	\N	PRESENT	0
591420	590846	04047H	PARTICIPANT	\N	PRESENT	0
591463	590846	14107H	PARTICIPANT	\N	PRESENT	0
591464	590846	20132W	PARTICIPANT	\N	PRESENT	0
591465	590846	19798U	PARTICIPANT	\N	PRESENT	0
591466	590846	14267Y	PARTICIPANT	\N	PRESENT	0
591467	590846	14083S	PARTICIPANT	\N	PRESENT	0
591468	590846	14105F	PARTICIPANT	\N	PRESENT	0
591469	590846	14275Y	PARTICIPANT	\N	PRESENT	0
591470	590846	01025N	PARTICIPANT	\N	PRESENT	0
591471	590846	14187A	PARTICIPANT	\N	PRESENT	0
591472	590846	01024M	PARTICIPANT	\N	PRESENT	0
591473	590846	19747H	PARTICIPANT	\N	PRESENT	0
591474	590846	20248J	PARTICIPANT	\N	PRESENT	0
591475	590846	19543W	PARTICIPANT	\N	PRESENT	0
591476	590846	01060R	PARTICIPANT	\N	PRESENT	0
591477	590846	20054A	PARTICIPANT	\N	PRESENT	0
591478	590846	95063L	PARTICIPANT	\N	PRESENT	0
591479	590846	11053K	PARTICIPANT	\N	PRESENT	0
591480	590846	19383Y	PARTICIPANT	\N	PRESENT	0
591481	590846	19762G	PARTICIPANT	\N	PRESENT	0
591482	590846	11097X	PARTICIPANT	\N	PRESENT	0
591483	590846	20062A	PARTICIPANT	\N	PRESENT	0
591484	590846	20090E	PARTICIPANT	\N	PRESENT	0
591485	590846	97011G	PARTICIPANT	\N	PRESENT	0
591486	590846	16685X	PARTICIPANT	\N	PRESENT	0
591487	590846	19739H	PARTICIPANT	\N	PRESENT	0
591488	590846	19745F	PARTICIPANT	\N	PRESENT	0
591489	590846	04085P	PARTICIPANT	\N	PRESENT	0
591490	590846	20102Q	PARTICIPANT	\N	PRESENT	0
591491	590846	19507S	PARTICIPANT	\N	PRESENT	0
591492	590846	20038A	PARTICIPANT	\N	PRESENT	0
591493	590846	20076G	PARTICIPANT	\N	PRESENT	0
591494	590846	20126Y	PARTICIPANT	\N	PRESENT	0
591495	590846	14223L	PARTICIPANT	\N	PRESENT	0
591496	590846	20018V	PARTICIPANT	\N	PRESENT	0
591497	590846	05012A	PARTICIPANT	\N	PRESENT	0
591498	590846	18083K	PARTICIPANT	\N	PRESENT	0
591499	590846	11085T	PARTICIPANT	\N	PRESENT	0
591500	590846	20026V	PARTICIPANT	\N	PRESENT	0
591501	590846	14259Y	PARTICIPANT	\N	PRESENT	0
591502	590846	19711U	PARTICIPANT	\N	PRESENT	0
591503	590846	20098N	PARTICIPANT	\N	PRESENT	0
591504	590846	19467C	PARTICIPANT	\N	PRESENT	0
591505	590846	19349W	PARTICIPANT	\N	PRESENT	0
591506	590846	20252E	PARTICIPANT	\N	PRESENT	0
591507	590846	19820Y	PARTICIPANT	\N	PRESENT	0
591508	590846	20092G	PARTICIPANT	\N	PRESENT	0
591509	590846	19503N	PARTICIPANT	\N	PRESENT	0
591510	590976	11040E	PARTICIPANT	\N	PRESENT	0
591511	590976	19479G	PARTICIPANT	\N	PRESENT	0
591512	590846	14237S	PARTICIPANT	\N	PRESENT	0
591513	590846	19826F	PARTICIPANT	\N	PRESENT	0
591514	590846	20046A	PARTICIPANT	\N	PRESENT	0
591515	590846	14033T	PARTICIPANT	\N	PRESENT	0
591516	590846	20136B	PARTICIPANT	\N	PRESENT	0
591517	590846	19549D	PARTICIPANT	\N	PRESENT	0
591518	590846	11012A	PARTICIPANT	\N	PRESENT	0
591534	590846	14215L	PARTICIPANT	\N	PRESENT	0
591520	590846	14219Q	PARTICIPANT	\N	PRESENT	0
591521	590846	20140W	PARTICIPANT	\N	PRESENT	0
591522	590846	19723Y	PARTICIPANT	\N	PRESENT	0
591523	590846	17637T	PARTICIPANT	\N	PRESENT	0
591524	590846	20032T	PARTICIPANT	\N	PRESENT	0
591525	590846	19533U	PARTICIPANT	\N	PRESENT	0
591526	590846	19703U	PARTICIPANT	\N	PRESENT	0
591527	590846	14021P	PARTICIPANT	\N	PRESENT	0
591528	590846	19681G	PARTICIPANT	\N	PRESENT	0
591529	590846	19387D	PARTICIPANT	\N	PRESENT	0
591530	590846	19611R	PARTICIPANT	\N	PRESENT	0
591531	590846	08010L	PARTICIPANT	\N	PRESENT	0
591532	590846	14031R	PARTICIPANT	\N	PRESENT	0
591533	590846	14030Q	PARTICIPANT	\N	PRESENT	0
591535	590846	20174H	PARTICIPANT	\N	PRESENT	0
591536	590846	19479G	PARTICIPANT	\N	PRESENT	0
591537	590846	19685L	PARTICIPANT	\N	PRESENT	0
591538	590846	99004R	PARTICIPANT	\N	PRESENT	0
591539	590846	14169X	PARTICIPANT	\N	PRESENT	0
591540	590846	19758L	PARTICIPANT	\N	PRESENT	0
591541	590846	19553Y	PARTICIPANT	\N	PRESENT	0
591542	590846	19335Q	PARTICIPANT	\N	PRESENT	0
591543	590846	19687N	PARTICIPANT	\N	PRESENT	0
591544	590846	19447X	PARTICIPANT	\N	PRESENT	0
591545	590846	14026U	PARTICIPANT	\N	PRESENT	0
591546	590846	14249W	PARTICIPANT	\N	PRESENT	0
591547	590846	19629C	PARTICIPANT	\N	PRESENT	0
591548	590846	14042U	PARTICIPANT	\N	PRESENT	0
591549	590846	14073Q	PARTICIPANT	\N	PRESENT	0
591550	590846	20100N	PARTICIPANT	\N	PRESENT	0
591551	590846	19599P	PARTICIPANT	\N	PRESENT	0
591552	590846	11048N	PARTICIPANT	\N	PRESENT	0
591553	590846	20058E	PARTICIPANT	\N	PRESENT	0
591554	590846	20180F	PARTICIPANT	\N	PRESENT	0
591555	590846	20086J	PARTICIPANT	\N	PRESENT	0
591556	590846	19565D	PARTICIPANT	\N	PRESENT	0
591557	590846	20104S	PARTICIPANT	\N	PRESENT	0
591558	590846	19551W	PARTICIPANT	\N	PRESENT	0
591559	590846	14001X	PARTICIPANT	\N	PRESENT	0
591614	590394	14355X	PARTICIPANT	\N	PRESENT	0
591615	590394	04092N	PARTICIPANT	\N	PRESENT	0
591616	590394	14026U	PARTICIPANT	\N	PRESENT	0
591627	591617	20032T	PARTICIPANT	\N	PRESENT	0
591628	591617	14189C	PARTICIPANT	\N	PRESENT	0
591629	591617	19631V	PARTICIPANT	\N	PRESENT	0
591630	591617	19575F	PARTICIPANT	\N	PRESENT	0
591631	591617	11101A	PARTICIPANT	\N	PRESENT	0
591634	591617	19629C	PARTICIPANT	\N	PRESENT	0
591635	591617	20066E	PARTICIPANT	\N	PRESENT	0
591636	591617	14221J	PARTICIPANT	\N	PRESENT	0
591637	591617	20018V	PARTICIPANT	\N	PRESENT	0
591638	591617	20036X	PARTICIPANT	\N	PRESENT	0
591639	591617	14237S	PARTICIPANT	\N	PRESENT	0
591641	591617	19503N	PARTICIPANT	\N	PRESENT	0
591642	591617	14107H	PARTICIPANT	\N	PRESENT	0
591643	591617	20044X	PARTICIPANT	\N	PRESENT	0
591644	591617	20058E	PARTICIPANT	\N	PRESENT	0
591645	591640	14073Q	PARTICIPANT	\N	PRESENT	1
591646	591640	08012N	PARTICIPANT	\N	PRESENT	1
591647	591640	11043H	PARTICIPANT	\N	PRESENT	1
571810	571305	19333N	PARTICIPANT	\N	PRESENT	0
571811	571305	19701S	PARTICIPANT	\N	PRESENT	0
571812	571305	19549D	PARTICIPANT	\N	PRESENT	0
571813	571305	20140W	PARTICIPANT	\N	PRESENT	0
571814	571305	20076G	PARTICIPANT	\N	PRESENT	0
571815	571305	19503N	PARTICIPANT	\N	PRESENT	0
571816	571305	14219Q	PRESIDENT	0	PRESENT	0
571817	571305	20020P	PARTICIPANT	\N	PRESENT	0
571818	571305	19826F	PARTICIPANT	\N	PRESENT	0
571819	571305	14221J	PARTICIPANT	\N	PRESENT	0
571820	571305	20102Q	PARTICIPANT	\N	PRESENT	0
571821	571305	19619A	PARTICIPANT	\N	PRESENT	0
571822	571305	20038A	PARTICIPANT	\N	PRESENT	0
571823	571305	20096L	PARTICIPANT	\N	PRESENT	0
571824	571305	20068G	PARTICIPANT	\N	PRESENT	0
571825	571305	19251M	PARTICIPANT	\N	PRESENT	1
571826	571305	19637C	PARTICIPANT	\N	PRESENT	1
571827	571305	14031R	PARTICIPANT	\N	PRESENT	0
571828	571305	14237S	PARTICIPANT	\N	PRESENT	0
571829	570618	14327T	PARTICIPANT	\N	PRESENT	0
571830	570618	01048V	PARTICIPANT	\N	PRESENT	0
571831	570618	01057W	PARTICIPANT	\N	PRESENT	0
571832	570618	11053K	PARTICIPANT	\N	PRESENT	0
571833	570618	20080C	PARTICIPANT	\N	PRESENT	0
571834	570618	14225N	PRESIDENT	0	PRESENT	0
571835	570618	19671E	PARTICIPANT	\N	PRESENT	0
571836	570618	07029T	PARTICIPANT	\N	PRESENT	0
571837	570618	19349W	PARTICIPANT	\N	PRESENT	0
571838	570618	14253S	PARTICIPANT	\N	PRESENT	0
571839	570618	20116W	PARTICIPANT	\N	PRESENT	0
571840	570618	19335Q	PARTICIPANT	\N	PRESENT	0
571841	570618	20126Y	PARTICIPANT	\N	PRESENT	0
571842	570618	11048N	PARTICIPANT	\N	PRESENT	0
571843	570618	19479G	PARTICIPANT	\N	PRESENT	0
571844	570618	19647E	PARTICIPANT	\N	PRESENT	0
571845	570618	19711U	PARTICIPANT	\N	PRESENT	0
571846	570618	14189C	PARTICIPANT	\N	PRESENT	0
571847	570618	19687N	PARTICIPANT	\N	PRESENT	0
571848	570618	08011M	PARTICIPANT	\N	PRESENT	0
571849	570618	20044X	PARTICIPANT	\N	PRESENT	0
571850	570618	11040E	PARTICIPANT	\N	PRESENT	0
571851	570618	14083S	PARTICIPANT	\N	PRESENT	0
571852	570618	20070A	PARTICIPANT	\N	PRESENT	0
571853	570618	08009T	PARTICIPANT	\N	PRESENT	0
571854	570618	19741B	PARTICIPANT	\N	PRESENT	0
571855	570618	99004R	PARTICIPANT	\N	PRESENT	0
571856	570618	19762G	PARTICIPANT	\N	PRESENT	0
571857	571305	20032T	PARTICIPANT	\N	PRESENT	0
571858	571305	19820Y	PARTICIPANT	\N	PRESENT	0
571859	571305	20118Y	PARTICIPANT	\N	PRESENT	0
571860	571305	20106U	PARTICIPANT	\N	PRESENT	1
571861	571305	11065P	PARTICIPANT	\N	PRESENT	0
571862	571305	19387D	PARTICIPANT	\N	PRESENT	1
571866	571298	14059S	PARTICIPANT	\N	PRESENT	0
571867	571298	19443T	PARTICIPANT	\N	PRESENT	1
571868	571298	12041X	PARTICIPANT	\N	PRESENT	0
571869	571298	20072C	PARTICIPANT	\N	PRESENT	1
571870	571298	20042V	PARTICIPANT	\N	PRESENT	0
571871	571298	01058X	PARTICIPANT	\N	PRESENT	0
571872	571298	11027H	PARTICIPANT	\N	PRESENT	1
571873	571298	11054L	PARTICIPANT	\N	PRESENT	0
571874	571298	01024M	PARTICIPANT	\N	PRESENT	0
571875	571298	11066Q	PARTICIPANT	\N	PRESENT	0
571876	571298	08056B	PARTICIPANT	\N	PRESENT	1
571877	571298	14105F	PARTICIPANT	\N	PRESENT	1
571878	571298	98018T	PARTICIPANT	\N	PRESENT	1
571879	571298	14193X	PARTICIPANT	\N	PRESENT	0
571880	571298	14267Y	PRESIDENT	0	PRESENT	0
571881	571298	11064N	PARTICIPANT	\N	PRESENT	1
571882	571298	11083R	PARTICIPANT	\N	PRESENT	1
571883	571298	08061X	PARTICIPANT	\N	PRESENT	0
571884	571298	08047A	PARTICIPANT	\N	PRESENT	0
571885	571298	14255U	PARTICIPANT	\N	PRESENT	1
571901	571298	04035D	PARTICIPANT	\N	PRESENT	1
571902	571298	04042C	PARTICIPANT	\N	EXCUSE	0
571908	570618	11070L	PARTICIPANT	\N	PRESENT	0
571909	570618	19545Y	PARTICIPANT	\N	EXCUSE	0
571911	570332	20130U	PARTICIPANT	\N	PRESENT	0
571912	570332	11067R	PARTICIPANT	\N	PRESENT	0
571913	570332	19713W	PARTICIPANT	\N	PRESENT	0
571914	570332	19798U	PARTICIPANT	\N	PRESENT	0
571915	570332	11045K	PARTICIPANT	\N	PRESENT	0
571916	570332	11097X	PARTICIPANT	\N	PRESENT	0
571917	570332	20040T	PARTICIPANT	\N	PRESENT	0
571918	570332	19663E	PARTICIPANT	\N	PRESENT	0
571919	570332	19415P	PARTICIPANT	\N	PRESENT	0
571920	570332	19691J	PARTICIPANT	\N	PRESENT	0
571921	570332	18193Q	PARTICIPANT	\N	PRESENT	0
571922	570332	19717B	PARTICIPANT	\N	PRESENT	0
571923	570332	14026U	PARTICIPANT	\N	PRESENT	0
571924	570332	11031D	PARTICIPANT	\N	PRESENT	0
571925	570332	14042U	PARTICIPANT	\N	PRESENT	0
571926	570332	14195A	PARTICIPANT	\N	PRESENT	0
571927	570332	19367Y	PARTICIPANT	\N	PRESENT	1
571928	570332	14213J	PARTICIPANT	\N	PRESENT	0
571929	570332	14071N	PARTICIPANT	\N	PRESENT	0
571930	570332	14217N	PARTICIPANT	\N	PRESENT	0
571931	570332	19683J	PARTICIPANT	\N	PRESENT	0
571949	570848	14053L	PARTICIPANT	\N	PRESENT	0
571950	570848	14089Y	PARTICIPANT	\N	PRESENT	0
571951	570848	19725B	PARTICIPANT	\N	PRESENT	0
571952	570848	14275Y	PARTICIPANT	\N	PRESENT	0
571953	570848	14147R	PARTICIPANT	\N	PRESENT	0
571954	570848	20114U	PARTICIPANT	\N	PRESENT	0
571955	570848	19581D	PARTICIPANT	\N	PRESENT	0
571956	570848	14215L	PARTICIPANT	\N	PRESENT	0
571957	570848	04047H	PRESIDENT	0	PRESENT	0
571958	570848	19749K	PARTICIPANT	\N	PRESENT	0
571959	570848	20108W	PARTICIPANT	\N	PRESENT	0
571960	570848	10015M	PARTICIPANT	\N	PRESENT	0
571961	570848	01028R	PARTICIPANT	\N	PRESENT	0
572012	571146	86034E	PARTICIPANT	\N	PRESENT	0
572034	571146	08015R	PARTICIPANT	\N	PRESENT	0
572035	571146	20108W	PARTICIPANT	\N	PRESENT	0
572036	571146	14187A	PARTICIPANT	\N	PRESENT	0
572039	571146	19651A	PARTICIPANT	\N	PRESENT	0
572040	571146	19413M	PARTICIPANT	\N	PRESENT	0
572041	571146	20070A	PARTICIPANT	\N	PRESENT	0
572042	571146	19349W	PARTICIPANT	\N	PRESENT	0
572043	571146	19503N	PARTICIPANT	\N	PRESENT	0
572044	571146	19415P	PARTICIPANT	\N	PRESENT	0
572045	571146	19421M	PARTICIPANT	\N	PRESENT	0
572046	571146	20096L	PARTICIPANT	\N	PRESENT	0
572047	571146	20056C	PARTICIPANT	\N	PRESENT	0
572048	571146	19515S	PARTICIPANT	\N	PRESENT	0
572049	571146	08028W	PARTICIPANT	\N	PRESENT	0
572050	571146	20140W	PARTICIPANT	\N	PRESENT	0
572051	571146	11097X	PARTICIPANT	\N	PRESENT	0
572052	571146	19719D	PARTICIPANT	\N	PRESENT	0
572053	571146	19717B	PARTICIPANT	\N	PRESENT	0
572054	571146	20052X	PARTICIPANT	\N	PRESENT	0
572055	571146	20144B	PARTICIPANT	\N	PRESENT	0
572056	571146	19713W	PARTICIPANT	\N	PRESENT	0
572057	571146	19619A	PARTICIPANT	\N	PRESENT	0
572058	571146	19585H	PARTICIPANT	\N	PRESENT	0
572059	571146	17589D	PARTICIPANT	\N	PRESENT	0
572060	571146	14267Y	PARTICIPANT	\N	PRESENT	0
572061	571146	20044X	PARTICIPANT	\N	PRESENT	0
572062	571146	12028B	PARTICIPANT	\N	PRESENT	0
572063	571146	19333N	PARTICIPANT	\N	PRESENT	0
572064	571146	19649G	PARTICIPANT	\N	PRESENT	0
572065	571146	11104D	PARTICIPANT	\N	PRESENT	0
572066	571146	11056N	PARTICIPANT	\N	PRESENT	0
572067	571146	19695N	PARTICIPANT	\N	PRESENT	0
572068	571146	19758L	PARTICIPANT	\N	PRESENT	0
572069	571146	11012A	PARTICIPANT	\N	PRESENT	0
572070	571146	20132W	PARTICIPANT	\N	PRESENT	0
572071	571146	19782L	PARTICIPANT	\N	PRESENT	0
572072	571146	20180F	PARTICIPANT	\N	PRESENT	0
572073	571146	92040Q	PARTICIPANT	\N	PRESENT	0
572074	571146	11080N	PARTICIPANT	\N	PRESENT	0
572075	571146	19611R	PARTICIPANT	\N	PRESENT	0
572076	571146	19725B	PARTICIPANT	\N	PRESENT	0
572077	571146	19599P	PARTICIPANT	\N	PRESENT	0
572078	571146	11066Q	PARTICIPANT	\N	PRESENT	0
572079	571146	14221J	PARTICIPANT	\N	PRESENT	0
572080	571146	20072C	PARTICIPANT	\N	PRESENT	0
572081	571146	19683J	PARTICIPANT	\N	PRESENT	0
572082	571146	20066E	PARTICIPANT	\N	PRESENT	0
572083	571146	14215L	PARTICIPANT	\N	PRESENT	0
572084	571146	14031R	PARTICIPANT	\N	PRESENT	0
583331	582768	19760E	PARTICIPANT	\N	PRESENT	0
583332	582768	14355X	PARTICIPANT	\N	PRESENT	1
583333	582768	19798U	PARTICIPANT	\N	EXCUSE	0
583334	582768	20040T	PARTICIPANT	\N	EXCUSE	0
583335	582768	14071N	PARTICIPANT	\N	EXCUSE	0
583336	582768	19691J	PARTICIPANT	\N	EXCUSE	0
583337	582768	19295A	PARTICIPANT	\N	EXCUSE	0
583338	582768	17779H	PARTICIPANT	\N	EXCUSE	0
583339	583152	19531S	PARTICIPANT	\N	PRESENT	0
583353	583152	19689Q	PARTICIPANT	\N	PRESENT	0
583358	583152	19647E	PARTICIPANT	\N	PRESENT	0
583360	582885	19383Y	PARTICIPANT	\N	PRESENT	0
583361	582885	08015R	PARTICIPANT	\N	PRESENT	0
583362	582885	08028W	PARTICIPANT	\N	PRESENT	1
583363	582885	20252E	PARTICIPANT	\N	PRESENT	0
583387	583160	14053L	PARTICIPANT	\N	PRESENT	0
583388	583160	19725B	PARTICIPANT	\N	PRESENT	0
583389	583160	14089Y	PARTICIPANT	\N	PRESENT	0
583390	583160	19954N	PARTICIPANT	\N	PRESENT	0
583391	583160	95063L	PARTICIPANT	\N	PRESENT	0
583392	583160	20114U	PARTICIPANT	\N	PRESENT	0
583393	583160	04047H	PRESIDENT	0	PRESENT	0
583394	583160	19749K	PARTICIPANT	\N	PRESENT	0
583395	583160	14111D	PARTICIPANT	\N	PRESENT	0
583396	583160	19649G	PARTICIPANT	\N	PRESENT	0
583397	583160	11026G	PARTICIPANT	\N	PRESENT	0
583398	583160	10015M	PARTICIPANT	\N	PRESENT	0
583399	583160	19543W	PARTICIPANT	\N	PRESENT	0
583400	583160	01028R	PARTICIPANT	\N	PRESENT	0
583401	583160	04085P	PARTICIPANT	\N	PRESENT	0
583402	583160	14231L	PARTICIPANT	\N	PRESENT	0
583403	583160	07004J	PARTICIPANT	\N	PRESENT	0
583404	583160	14041T	PARTICIPANT	\N	PRESENT	0
583405	583160	14179A	PARTICIPANT	\N	PRESENT	0
583406	583160	14151M	PARTICIPANT	\N	PRESENT	0
583407	583160	14069U	PARTICIPANT	\N	PRESENT	0
583408	583160	11085T	PARTICIPANT	\N	PRESENT	0
583409	583160	08018U	PARTICIPANT	\N	PRESENT	0
583410	583160	14021P	PARTICIPANT	\N	PRESENT	0
583411	583160	11072N	PARTICIPANT	\N	PRESENT	0
583412	583160	05008E	PARTICIPANT	\N	PRESENT	1
583413	583160	14215L	PARTICIPANT	\N	PRESENT	0
583428	583427	20056C	PARTICIPANT	\N	PRESENT	1
583429	583427	19643A	PARTICIPANT	\N	PRESENT	1
583430	583427	19399H	PARTICIPANT	\N	PRESENT	1
583431	583427	20048C	PARTICIPANT	\N	PRESENT	1
583432	583427	19651A	PARTICIPANT	\N	PRESENT	1
583433	583427	19699S	PARTICIPANT	\N	PRESENT	1
583434	583427	20052X	PARTICIPANT	\N	PRESENT	1
583435	583427	19621T	PARTICIPANT	\N	PRESENT	1
583436	583427	08012N	PARTICIPANT	\N	PRESENT	1
583437	583427	14073Q	PARTICIPANT	\N	PRESENT	0
583441	583427	19693L	PARTICIPANT	\N	PRESENT	0
583442	583427	20134Y	PARTICIPANT	\N	PRESENT	0
583443	583427	19611R	PRESIDENT	0	PRESENT	0
583444	583427	14030Q	PARTICIPANT	\N	PRESENT	0
583445	583427	20152B	PARTICIPANT	\N	PRESENT	1
583446	583427	20132W	PARTICIPANT	\N	PRESENT	0
583447	583427	20180F	PARTICIPANT	\N	PRESENT	1
583448	583427	19533U	PARTICIPANT	\N	PRESENT	1
583449	583427	20026V	PARTICIPANT	\N	PRESENT	1
583450	583427	19527W	PARTICIPANT	\N	PRESENT	1
583451	583427	20058E	PARTICIPANT	\N	PRESENT	1
583452	583427	11043H	PARTICIPANT	\N	PRESENT	0
583453	583427	11104D	PARTICIPANT	\N	PRESENT	1
583676	583455	20018V	PARTICIPANT	\N	PRESENT	0
583677	583455	14357A	PARTICIPANT	\N	PRESENT	0
583679	583455	19507S	PARTICIPANT	\N	PRESENT	0
583680	583455	01043Q	PARTICIPANT	\N	PRESENT	0
583681	583455	20144B	PARTICIPANT	\N	PRESENT	0
583723	583455	19413M	PARTICIPANT	\N	PRESENT	0
583724	583455	14251Q	PARTICIPANT	\N	PRESENT	0
583726	583455	19369B	PARTICIPANT	\N	PRESENT	0
583727	583455	19563B	PARTICIPANT	\N	PRESENT	1
583961	583494	14033T	PARTICIPANT	\N	PRESENT	0
583962	583494	20120S	PARTICIPANT	\N	PRESENT	0
583954	583494	19820Y	PARTICIPANT	\N	PRESENT	0
583957	583494	20026V	PARTICIPANT	\N	PRESENT	0
583963	583494	20064C	PARTICIPANT	\N	PRESENT	0
583965	583494	20086J	PARTICIPANT	\N	PRESENT	0
583966	583494	20248J	PARTICIPANT	\N	PRESENT	0
583967	583494	19629C	PARTICIPANT	\N	PRESENT	0
583968	583494	19703U	PARTICIPANT	\N	PRESENT	0
583969	583494	14257W	PARTICIPANT	\N	PRESENT	0
583970	583494	14121F	PARTICIPANT	\N	PRESENT	0
583971	583494	19725B	PARTICIPANT	\N	PRESENT	0
583972	583494	20174H	PARTICIPANT	\N	PRESENT	0
583973	583494	19563B	PARTICIPANT	\N	PRESENT	0
583974	583494	14169X	PARTICIPANT	\N	PRESENT	0
583975	583494	19441R	PARTICIPANT	\N	PRESENT	0
583977	583494	11090Q	PARTICIPANT	\N	PRESENT	0
583978	583494	14205J	PARTICIPANT	\N	PRESENT	0
583979	583494	14147R	PARTICIPANT	\N	PRESENT	0
584036	583495	19507S	PARTICIPANT	\N	PRESENT	0
584037	583495	14033T	PARTICIPANT	\N	PRESENT	0
584038	583495	17589D	PARTICIPANT	\N	PRESENT	0
584039	583495	19347U	PARTICIPANT	\N	PRESENT	0
584040	583495	19725B	PARTICIPANT	\N	PRESENT	0
584041	583495	19631V	PARTICIPANT	\N	PRESENT	0
584042	583495	19760E	PARTICIPANT	\N	PRESENT	0
584043	583495	19695N	PARTICIPANT	\N	PRESENT	0
584044	583495	19820Y	PARTICIPANT	\N	PRESENT	0
584045	583495	19251M	PARTICIPANT	\N	PRESENT	0
584046	583495	14121F	PARTICIPANT	\N	PRESENT	0
584047	583495	19549D	PARTICIPANT	\N	PRESENT	0
584048	583495	19681G	PARTICIPANT	\N	PRESENT	0
584049	583495	20174H	PARTICIPANT	\N	PRESENT	0
584050	583495	14189C	PARTICIPANT	\N	PRESENT	0
584051	583495	20030R	PARTICIPANT	\N	PRESENT	0
584052	583495	19479G	PARTICIPANT	\N	PRESENT	0
584053	583495	04045F	PARTICIPANT	\N	PRESENT	0
584054	583495	19691J	PARTICIPANT	\N	PRESENT	0
584055	583495	01024M	PARTICIPANT	\N	PRESENT	0
584056	583495	01025N	PARTICIPANT	\N	PRESENT	0
584057	583495	20028X	PARTICIPANT	\N	PRESENT	0
584058	583495	14207L	PARTICIPANT	\N	PRESENT	0
584059	583495	20072C	PARTICIPANT	\N	PRESENT	0
584060	583495	19387D	PARTICIPANT	\N	PRESENT	0
584061	583495	19629C	PARTICIPANT	\N	PRESENT	0
584062	583495	08061X	PARTICIPANT	\N	PRESENT	0
584063	583495	20022R	PARTICIPANT	\N	PRESENT	0
584064	583495	14147R	PARTICIPANT	\N	PRESENT	0
584065	583495	19703U	PARTICIPANT	\N	PRESENT	0
584066	583495	19383Y	PARTICIPANT	\N	PRESENT	0
584067	583495	20120S	PARTICIPANT	\N	PRESENT	0
584068	583495	20032T	PARTICIPANT	\N	PRESENT	0
584069	583495	14173T	PARTICIPANT	\N	PRESENT	0
584070	583495	20056C	PARTICIPANT	\N	PRESENT	0
584071	583495	14169X	PARTICIPANT	\N	PRESENT	0
584072	583495	20076G	PARTICIPANT	\N	PRESENT	0
584073	583495	19693L	PARTICIPANT	\N	PRESENT	0
584074	583495	14205J	PARTICIPANT	\N	PRESENT	0
584075	583495	20046A	PARTICIPANT	\N	PRESENT	0
584076	583495	19563B	PARTICIPANT	\N	PRESENT	0
584077	583495	20090E	PARTICIPANT	\N	PRESENT	0
584078	583495	14327T	PARTICIPANT	\N	PRESENT	0
584079	583495	19739H	PARTICIPANT	\N	PRESENT	0
584080	583495	19441R	PARTICIPANT	\N	PRESENT	0
584081	583495	20130U	PARTICIPANT	\N	PRESENT	0
584082	583495	14257W	PARTICIPANT	\N	PRESENT	0
584083	583495	14055N	PARTICIPANT	\N	PRESENT	0
584084	583495	20180F	PARTICIPANT	\N	PRESENT	0
584085	583495	19715Y	PARTICIPANT	\N	PRESENT	0
584086	583495	19569H	PARTICIPANT	\N	PRESENT	0
584087	583495	20018V	PARTICIPANT	\N	PRESENT	0
584088	583495	11099A	PARTICIPANT	\N	PRESENT	0
584089	583495	11012A	PARTICIPANT	\N	PRESENT	0
584034	583495	11070L	PARTICIPANT	\N	PRESENT	0
584035	583495	11090Q	PARTICIPANT	\N	PRESENT	0
584090	583495	20054A	PARTICIPANT	\N	PRESENT	0
584091	583495	20088L	PARTICIPANT	\N	PRESENT	0
584092	583495	14223L	PARTICIPANT	\N	PRESENT	0
584093	583495	19413M	PARTICIPANT	\N	PRESENT	0
584097	583495	18083K	PARTICIPANT	\N	PRESENT	0
584095	583495	97011G	PARTICIPANT	\N	PRESENT	0
584096	583495	20116W	PARTICIPANT	\N	PRESENT	0
584098	583495	14030Q	PARTICIPANT	\N	PRESENT	0
584099	583495	19333N	PARTICIPANT	\N	PRESENT	0
584100	583976	19697Q	PARTICIPANT	\N	PRESENT	0
584101	583976	19467C	PARTICIPANT	\N	PRESENT	0
584102	583976	19515S	PARTICIPANT	\N	PRESENT	0
570371	570370	14030Q	PARTICIPANT	\N	PRESENT	0
570372	570370	11031D	PARTICIPANT	\N	PRESENT	0
570373	570370	14109K	PARTICIPANT	\N	PRESENT	1
570374	570370	11045K	PARTICIPANT	\N	PRESENT	0
570377	569828	19643A	PRESIDENT	0	PRESENT	0
570378	569828	20152B	PARTICIPANT	\N	PRESENT	0
570379	569828	20134Y	PARTICIPANT	\N	PRESENT	1
570380	569828	20124W	PARTICIPANT	\N	PRESENT	0
570381	569828	19673G	PARTICIPANT	\N	PRESENT	0
570382	569828	20034V	PARTICIPANT	\N	PRESENT	1
570383	569828	04057K	PARTICIPANT	\N	PRESENT	0
570384	569828	20098N	PARTICIPANT	\N	PRESENT	0
570385	569828	19527W	PARTICIPANT	\N	EXCUSE	0
570386	569828	14073Q	PARTICIPANT	\N	EXCUSE	0
570387	569828	19553Y	PARTICIPANT	\N	EXCUSE	0
570392	570376	20090E	PARTICIPANT	\N	PRESENT	0
570394	570376	19729F	PARTICIPANT	\N	PRESENT	0
570395	570388	20090E	PARTICIPANT	\N	PRESENT	0
570396	570388	20130U	PARTICIPANT	\N	PRESENT	0
570397	570388	19729F	PARTICIPANT	\N	PRESENT	0
570405	570390	19565D	PARTICIPANT	\N	PRESENT	0
570399	570389	20090E	PARTICIPANT	\N	PRESENT	0
570401	570389	20130U	PARTICIPANT	\N	PRESENT	0
570402	570389	20114U	PARTICIPANT	\N	PRESENT	0
570403	570389	19729F	PARTICIPANT	\N	PRESENT	0
570404	570390	01024M	PARTICIPANT	\N	PRESENT	0
570406	570390	14097Y	PARTICIPANT	\N	PRESENT	0
570407	570390	08047A	PARTICIPANT	\N	PRESENT	0
570408	570390	19798U	PARTICIPANT	\N	PRESENT	0
570409	570390	19691J	PARTICIPANT	\N	PRESENT	0
573191	573190	19643A	PARTICIPANT	\N	PRESENT	1
573192	573190	20152B	PARTICIPANT	\N	PRESENT	0
573193	573190	20124W	PARTICIPANT	\N	PRESENT	0
573194	573190	19673G	PARTICIPANT	\N	PRESENT	0
573195	573190	04035D	PARTICIPANT	\N	PRESENT	1
573196	573190	19691J	PARTICIPANT	\N	PRESENT	1
573197	573190	20106U	PARTICIPANT	\N	PRESENT	1
573198	573190	14073Q	PARTICIPANT	\N	PRESENT	1
573199	573190	04057K	PARTICIPANT	\N	PRESENT	0
573200	573190	19527W	PARTICIPANT	\N	PRESENT	0
573443	571300	20050V	PARTICIPANT	\N	PRESENT	0
576003	576002	20038A	PARTICIPANT	\N	PRESENT	0
576004	576002	19565D	PARTICIPANT	\N	PRESENT	0
576005	576002	14219Q	PARTICIPANT	\N	PRESENT	0
576006	576002	08012N	PARTICIPANT	\N	PRESENT	0
576007	576002	04043D	PARTICIPANT	\N	PRESENT	0
576008	576002	20044X	PARTICIPANT	\N	PRESENT	0
576009	576002	01058X	PARTICIPANT	\N	PRESENT	0
576010	576002	20084G	PARTICIPANT	\N	PRESENT	0
579564	579563	17737W	PARTICIPANT	\N	PRESENT	0
579565	579563	11026G	PARTICIPANT	\N	PRESENT	0
579566	579563	19709B	PARTICIPANT	\N	PRESENT	0
579568	579567	17737W	PARTICIPANT	\N	PRESENT	0
579569	579567	04042C	PARTICIPANT	\N	PRESENT	0
579571	579570	17737W	PARTICIPANT	\N	PRESENT	0
579573	579572	17737W	PARTICIPANT	\N	PRESENT	0
579575	579574	17737W	PARTICIPANT	\N	PRESENT	0
579577	579576	17737W	PARTICIPANT	\N	PRESENT	0
579579	579578	17737W	PARTICIPANT	\N	PRESENT	0
579582	579580	20090E	PARTICIPANT	\N	PRESENT	0
579583	579580	20130U	PARTICIPANT	\N	PRESENT	0
580327	579392	19749K	PARTICIPANT	\N	PRESENT	0
580328	579392	19649G	PARTICIPANT	\N	PRESENT	0
580329	579392	11045K	PARTICIPANT	\N	PRESENT	0
580330	579392	18193Q	PARTICIPANT	\N	PRESENT	0
580331	579392	19631V	PARTICIPANT	\N	PRESENT	0
580332	579392	04085P	PARTICIPANT	\N	PRESENT	0
580333	579392	19565D	PARTICIPANT	\N	PRESENT	0
580334	579392	14195A	PARTICIPANT	\N	PRESENT	0
580335	579392	19563B	PARTICIPANT	\N	PRESENT	0
580336	579392	14107H	PARTICIPANT	\N	PRESENT	0
580337	579392	19629C	PARTICIPANT	\N	PRESENT	0
580338	579392	19713W	PARTICIPANT	\N	PRESENT	0
580339	579392	07004J	PARTICIPANT	\N	PRESENT	0
580340	579392	19479G	PARTICIPANT	\N	PRESENT	0
580341	579392	14083S	PARTICIPANT	\N	PRESENT	0
580342	579392	20072C	PARTICIPANT	\N	PRESENT	0
580343	579392	01025N	PARTICIPANT	\N	PRESENT	0
580344	579392	01024M	PARTICIPANT	\N	PRESENT	0
580345	579392	19699S	PARTICIPANT	\N	PRESENT	0
580346	579392	14055N	PARTICIPANT	\N	PRESENT	0
580347	579392	11043H	PARTICIPANT	\N	PRESENT	0
580348	579392	20090E	PARTICIPANT	\N	PRESENT	0
580349	579392	14147R	PARTICIPANT	\N	PRESENT	0
580350	579392	19703U	PARTICIPANT	\N	PRESENT	0
580351	579392	18083K	PARTICIPANT	\N	PRESENT	0
580352	579392	19533U	PARTICIPANT	\N	PRESENT	0
580353	579392	97011G	PARTICIPANT	\N	PRESENT	0
580354	579392	11072N	PARTICIPANT	\N	PRESENT	0
580355	579392	20180F	PARTICIPANT	\N	PRESENT	0
580356	579392	20026V	PARTICIPANT	\N	PRESENT	0
580357	579392	20056C	PARTICIPANT	\N	PRESENT	0
580358	579392	20038A	PARTICIPANT	\N	PRESENT	0
580359	579392	19447X	PARTICIPANT	\N	PRESENT	0
580360	579392	07029T	PARTICIPANT	\N	PRESENT	0
580361	579392	19573D	PARTICIPANT	\N	PRESENT	0
580362	579392	20044X	PARTICIPANT	\N	PRESENT	0
580363	579392	10006L	PARTICIPANT	\N	PRESENT	0
580364	579392	20034V	PARTICIPANT	\N	PRESENT	0
580365	579392	20024T	PARTICIPANT	\N	PRESENT	0
580366	579392	20108W	PARTICIPANT	\N	PRESENT	0
580367	579392	14231L	PARTICIPANT	\N	PRESENT	0
580325	579392	11070L	PARTICIPANT	\N	PRESENT	0
580326	579392	19673G	PARTICIPANT	\N	PRESENT	0
580368	579392	19695N	PARTICIPANT	\N	PRESENT	0
580369	579392	11056N	PARTICIPANT	\N	PRESENT	0
580370	579392	20046A	PARTICIPANT	\N	PRESENT	0
580371	579392	20102Q	PARTICIPANT	\N	PRESENT	0
580372	579392	19820Y	PARTICIPANT	\N	PRESENT	0
580373	579392	20248J	PARTICIPANT	\N	PRESENT	0
580374	579392	20116W	PARTICIPANT	\N	PRESENT	0
580375	579392	19725B	PARTICIPANT	\N	PRESENT	0
580376	579392	14151M	PARTICIPANT	\N	PRESENT	0
580377	579392	20028X	PARTICIPANT	\N	PRESENT	0
580378	579392	14097Y	PARTICIPANT	\N	PRESENT	0
580379	579392	19798U	PARTICIPANT	\N	PRESENT	0
580380	579392	19383Y	PARTICIPANT	\N	PRESENT	0
580381	579392	14042U	PARTICIPANT	\N	PRESENT	0
580382	579392	20054A	PARTICIPANT	\N	PRESENT	0
580383	579392	20110Q	PARTICIPANT	\N	PRESENT	0
580384	579392	01057W	PARTICIPANT	\N	PRESENT	0
580385	579392	19467C	PARTICIPANT	\N	PRESENT	0
580386	579392	14021P	PARTICIPANT	\N	PRESENT	0
580387	579392	01028R	PARTICIPANT	\N	PRESENT	0
580388	579392	10015M	PARTICIPANT	\N	PRESENT	0
580389	579392	11026G	PARTICIPANT	\N	PRESENT	0
580390	579392	14215L	PARTICIPANT	\N	PRESENT	0
580391	579392	19691J	PARTICIPANT	\N	PRESENT	0
580392	579392	19443T	PARTICIPANT	\N	PRESENT	0
580393	579392	19782L	PARTICIPANT	\N	PRESENT	0
580394	579392	20132W	PARTICIPANT	\N	PRESENT	0
580395	579392	14033T	PARTICIPANT	\N	PRESENT	0
580396	579392	04047H	PARTICIPANT	\N	PRESENT	0
580397	579392	19441R	PARTICIPANT	\N	PRESENT	0
580398	579392	20022R	PARTICIPANT	\N	PRESENT	0
580399	579392	14089Y	PARTICIPANT	\N	PRESENT	0
591648	591640	20134Y	PARTICIPANT	\N	PRESENT	1
591789	590540	04085P	PARTICIPANT	\N	PRESENT	1
591790	590540	17737W	PARTICIPANT	\N	PRESENT	1
591791	590540	11056N	PARTICIPANT	\N	PRESENT	1
591792	590540	20074E	PARTICIPANT	\N	PRESENT	1
591793	590540	19489J	PARTICIPANT	\N	PRESENT	1
591794	590540	19675J	PARTICIPANT	\N	PRESENT	1
591806	590949	19782L	PARTICIPANT	\N	PRESENT	0
591807	590949	20090E	PARTICIPANT	\N	PRESENT	0
591808	590949	20174H	PARTICIPANT	\N	PRESENT	0
591809	590949	14213J	PARTICIPANT	\N	PRESENT	0
591813	590949	20028X	PARTICIPANT	\N	PRESENT	0
591818	590949	19369B	PARTICIPANT	\N	PRESENT	0
591820	590949	14109K	PARTICIPANT	\N	PRESENT	0
591821	590949	19745F	PARTICIPANT	\N	PRESENT	0
591823	590949	19503N	PARTICIPANT	\N	PRESENT	0
591824	590949	20062A	PARTICIPANT	\N	PRESENT	0
591825	590949	14059S	PARTICIPANT	\N	PRESENT	0
592901	588549	20066E	PARTICIPANT	\N	PRESENT	0
592919	592902	19679N	PARTICIPANT	\N	PRESENT	0
592926	592904	19679N	PARTICIPANT	\N	PRESENT	0
592934	592917	19679N	PARTICIPANT	\N	PRESENT	1
592953	592942	14042U	PARTICIPANT	\N	PRESENT	0
592954	592944	14042U	PARTICIPANT	\N	PRESENT	0
592988	590397	19569H	PARTICIPANT	\N	PRESENT	0
592989	590397	19723Y	PARTICIPANT	\N	PRESENT	0
592990	590397	20126Y	PARTICIPANT	\N	PRESENT	1
592993	590397	19553Y	PARTICIPANT	\N	PRESENT	1
592994	590397	19697Q	PARTICIPANT	\N	PRESENT	0
593004	590397	19301E	PARTICIPANT	\N	PRESENT	1
593005	590397	19760E	PARTICIPANT	\N	PRESENT	1
593006	590397	04057K	PARTICIPANT	\N	PRESENT	1
594169	592517	14038Y	PARTICIPANT	\N	PRESENT	0
594170	592517	19467C	PARTICIPANT	\N	PRESENT	0
594171	592517	20034V	PARTICIPANT	\N	PRESENT	0
594172	592517	14187A	PARTICIPANT	\N	PRESENT	0
594173	592517	20144B	PARTICIPANT	\N	PRESENT	0
594174	592517	01025N	PARTICIPANT	\N	PRESENT	0
594175	592517	14033T	PARTICIPANT	\N	PRESENT	0
594176	592517	11090Q	PARTICIPANT	\N	PRESENT	0
594177	592517	20054A	PARTICIPANT	\N	PRESENT	0
594178	592517	20174H	PARTICIPANT	\N	PRESENT	1
594179	592517	14205J	PARTICIPANT	\N	PRESENT	0
594180	592517	20062A	PARTICIPANT	\N	PRESENT	0
594181	592517	14251Q	PARTICIPANT	\N	PRESENT	1
594182	592517	19507S	PARTICIPANT	\N	PRESENT	0
594183	592517	14207L	PARTICIPANT	\N	PRESENT	0
594184	592517	19747H	PARTICIPANT	\N	PRESENT	0
594185	592517	14257W	PARTICIPANT	\N	PRESENT	0
595203	593436	97011G	PARTICIPANT	\N	PRESENT	0
595204	593436	19673G	PARTICIPANT	\N	PRESENT	0
595205	593436	20034V	PARTICIPANT	\N	PRESENT	0
595206	593436	20146D	PARTICIPANT	\N	PRESENT	0
595207	593436	14059S	PARTICIPANT	\N	PRESENT	0
595208	593436	19659J	PARTICIPANT	\N	PRESENT	0
595209	593436	14147R	PARTICIPANT	\N	PRESENT	0
595210	593436	20148F	PARTICIPANT	\N	PRESENT	1
595211	593436	17023S	PARTICIPANT	\N	PRESENT	1
595239	588556	20066E	PARTICIPANT	\N	PRESENT	0
595244	588557	20066E	PARTICIPANT	\N	PRESENT	0
595354	595351	19569H	PARTICIPANT	\N	PRESENT	0
595355	595351	20130U	PARTICIPANT	\N	PRESENT	0
595358	595357	19569H	PARTICIPANT	\N	PRESENT	0
595517	595514	19723Y	PARTICIPANT	\N	PRESENT	0
595519	595514	20072C	PARTICIPANT	\N	PRESENT	0
595520	595514	04043D	PARTICIPANT	\N	PRESENT	0
595521	595514	19533U	PARTICIPANT	\N	PRESENT	0
595522	595514	01058X	PARTICIPANT	\N	PRESENT	0
595523	595514	19663E	PARTICIPANT	\N	PRESENT	0
595524	595514	20128B	PARTICIPANT	\N	PRESENT	0
595526	595514	19735D	PARTICIPANT	\N	EXCUSE	0
595527	595514	20066E	PARTICIPANT	\N	EXCUSE	0
595528	595514	01048V	PARTICIPANT	\N	EXCUSE	0
595529	595514	11067R	PARTICIPANT	\N	EXCUSE	0
595556	593436	19301E	PARTICIPANT	\N	PRESENT	1
595757	594909	10006L	PRESIDENT	0	PRESENT	0
595758	594909	14042U	PARTICIPANT	\N	PRESENT	0
595759	594909	19703U	PARTICIPANT	\N	PRESENT	0
595760	594909	20172F	PARTICIPANT	\N	PRESENT	0
595761	594909	19683J	PARTICIPANT	\N	PRESENT	0
595762	594909	19691J	PARTICIPANT	\N	PRESENT	0
595763	594909	19679N	PARTICIPANT	\N	PRESENT	0
595764	594909	19798U	PARTICIPANT	\N	PRESENT	0
595765	594909	14355X	PARTICIPANT	\N	PRESENT	0
595766	594909	19367Y	PARTICIPANT	\N	PRESENT	0
595767	594909	14223L	PARTICIPANT	\N	PRESENT	0
595768	594909	14026U	PARTICIPANT	\N	PRESENT	0
595769	594909	14213J	PARTICIPANT	\N	PRESENT	1
595770	594909	19697Q	PARTICIPANT	\N	PRESENT	1
595771	594909	17779H	PARTICIPANT	\N	PRESENT	1
595772	594909	14053L	PARTICIPANT	\N	PRESENT	0
595773	594909	05008E	PARTICIPANT	\N	PRESENT	0
595774	594909	04047H	PARTICIPANT	\N	PRESENT	0
595775	594909	14231L	PARTICIPANT	\N	PRESENT	0
595776	594909	11072N	PARTICIPANT	\N	PRESENT	0
595777	594909	19447X	PARTICIPANT	\N	PRESENT	0
595778	594909	11067R	PARTICIPANT	\N	PRESENT	0
595779	594909	19543W	PARTICIPANT	\N	PRESENT	1
595780	594909	19629C	PARTICIPANT	\N	PRESENT	1
595781	594909	19725B	PARTICIPANT	\N	PRESENT	1
595782	594909	14107H	PARTICIPANT	\N	PRESENT	1
595783	594909	19489J	PARTICIPANT	\N	PRESENT	1
595784	594909	14147R	PARTICIPANT	\N	PRESENT	1
595785	594909	19649G	PARTICIPANT	\N	PRESENT	1
595786	594909	19295A	PARTICIPANT	\N	PRESENT	0
595787	594909	19663E	PARTICIPANT	\N	PRESENT	1
595788	594909	04057K	PARTICIPANT	\N	EXCUSE	0
595789	594909	19713W	PARTICIPANT	\N	PRESENT	1
595790	594909	19553Y	PARTICIPANT	\N	PRESENT	0
595791	594909	20066E	PARTICIPANT	\N	PRESENT	1
595792	594909	18193Q	PARTICIPANT	\N	PRESENT	0
595793	594909	17965H	PARTICIPANT	\N	PRESENT	0
595794	594909	20110Q	PARTICIPANT	\N	PRESENT	1
595795	594909	19569H	PARTICIPANT	\N	PRESENT	0
595796	594909	19657G	PARTICIPANT	\N	PRESENT	1
595797	594909	11097X	PARTICIPANT	\N	PRESENT	1
596189	593569	11109J	PARTICIPANT	\N	EXCUSE	0
596190	593569	04059M	PARTICIPANT	\N	PRESENT	0
596191	593569	19643A	PARTICIPANT	\N	PRESENT	1
596192	593569	19758L	PARTICIPANT	\N	PRESENT	0
596193	593569	20112S	PARTICIPANT	\N	PRESENT	0
596195	593569	20132W	PARTICIPANT	\N	PRESENT	0
596196	593569	20048C	PARTICIPANT	\N	PRESENT	0
596197	593569	19399H	PARTICIPANT	\N	PRESENT	0
596198	593569	20056C	PARTICIPANT	\N	PRESENT	0
596200	593569	14073Q	PARTICIPANT	\N	PRESENT	0
596201	593569	19611R	PRESIDENT	0	PRESENT	0
596202	593569	19699S	PARTICIPANT	\N	PRESENT	0
596203	593569	20052X	PARTICIPANT	\N	PRESENT	0
596204	593569	08012N	PARTICIPANT	\N	PRESENT	0
596205	593569	19573D	PARTICIPANT	\N	PRESENT	0
596206	593569	19533U	PARTICIPANT	\N	PRESENT	0
596207	593569	14229S	PARTICIPANT	\N	PRESENT	0
596208	593569	11043H	PARTICIPANT	\N	PRESENT	0
596209	593569	19527W	PARTICIPANT	\N	PRESENT	0
596210	593569	20026V	PARTICIPANT	\N	PRESENT	0
596212	593569	19766L	PARTICIPANT	\N	PRESENT	1
596214	588873	14030Q	PRESIDENT	0	PRESENT	0
596215	588873	11031D	PARTICIPANT	\N	PRESENT	0
596216	588873	19693L	PARTICIPANT	0	PRESENT	0
596217	588873	19599P	PARTICIPANT	\N	PRESENT	0
596218	588873	07029T	PARTICIPANT	\N	PRESENT	0
596219	588873	14109K	PARTICIPANT	\N	PRESENT	0
596220	588873	19866P	PARTICIPANT	\N	PRESENT	0
596221	588873	20046A	PARTICIPANT	\N	PRESENT	0
596222	588873	19749K	PARTICIPANT	\N	PRESENT	0
596223	588873	11045K	PARTICIPANT	\N	PRESENT	0
596224	588873	20024T	PARTICIPANT	\N	PRESENT	0
596225	588873	20114U	PARTICIPANT	\N	EXCUSE	0
596226	588873	20080C	PARTICIPANT	\N	EXCUSE	0
596227	588873	19621T	PARTICIPANT	\N	EXCUSE	0
596228	588873	04035D	PARTICIPANT	\N	EXCUSE	0
596229	588873	20118Y	PARTICIPANT	\N	EXCUSE	0
596230	588873	20130U	PARTICIPANT	\N	EXCUSE	0
596231	593569	19735D	PARTICIPANT	\N	PRESENT	1
596234	588873	14189C	PARTICIPANT	\N	PRESENT	0
596235	593569	20124W	PARTICIPANT	\N	PRESENT	0
596255	588873	20098N	PARTICIPANT	\N	PRESENT	0
572085	571146	08069G	PARTICIPANT	\N	PRESENT	0
572086	571146	14357A	PARTICIPANT	\N	PRESENT	0
572087	571146	14042U	PARTICIPANT	\N	PRESENT	0
572088	571146	19826F	PARTICIPANT	\N	PRESENT	0
572089	571146	19699S	PARTICIPANT	\N	PRESENT	0
572090	571146	19441R	PARTICIPANT	\N	PRESENT	0
572091	571146	20106U	PARTICIPANT	\N	PRESENT	0
572092	571146	20128B	PARTICIPANT	\N	PRESENT	0
572093	571146	04045F	PARTICIPANT	\N	PRESENT	0
572094	571146	08061X	PARTICIPANT	\N	PRESENT	0
572095	571146	14151M	PARTICIPANT	\N	PRESENT	0
572096	571146	20116W	PARTICIPANT	\N	PRESENT	0
572097	571146	14251Q	PARTICIPANT	\N	PRESENT	0
572098	571146	14111D	PARTICIPANT	\N	PRESENT	0
572099	571146	14195A	PARTICIPANT	\N	PRESENT	0
572100	571146	99004R	PARTICIPANT	\N	PRESENT	0
572101	571146	14026U	PARTICIPANT	\N	PRESENT	0
572102	571146	20076G	PARTICIPANT	\N	PRESENT	0
572103	571146	01048V	PARTICIPANT	\N	PRESENT	0
572104	571146	04033B	PARTICIPANT	\N	PRESENT	0
572105	571146	04047H	PARTICIPANT	\N	PRESENT	0
572106	571146	12041X	PARTICIPANT	\N	PRESENT	0
572107	571146	11040E	PARTICIPANT	\N	PRESENT	0
572108	571146	11031D	PARTICIPANT	\N	PRESENT	0
572109	571146	20038A	PARTICIPANT	\N	PRESENT	0
572110	571146	19593H	PARTICIPANT	\N	PRESENT	0
572111	571146	20102Q	PARTICIPANT	\N	PRESENT	0
572112	571146	20134Y	PARTICIPANT	\N	PRESENT	0
572113	571146	20092G	PARTICIPANT	\N	PRESENT	0
572114	571146	19347U	PARTICIPANT	\N	PRESENT	0
572115	571146	20142Y	PARTICIPANT	\N	PRESENT	0
572116	571146	19689Q	PARTICIPANT	\N	PRESENT	0
572117	571146	20136B	PARTICIPANT	\N	PRESENT	0
572118	571146	11033F	PARTICIPANT	\N	PRESENT	0
572119	571146	20098N	PARTICIPANT	\N	PRESENT	0
572120	571146	18193Q	PARTICIPANT	\N	PRESENT	0
572121	571146	01058X	PARTICIPANT	\N	PRESENT	0
572122	571146	11045K	PARTICIPANT	\N	PRESENT	0
572123	571146	20114U	PARTICIPANT	\N	PRESENT	0
572124	571146	11067R	PARTICIPANT	\N	PRESENT	0
572125	571146	14021P	PARTICIPANT	\N	PRESENT	0
572126	571146	04059M	PARTICIPANT	\N	PRESENT	0
572127	571146	01057W	PARTICIPANT	\N	PRESENT	0
572128	571146	14229S	PARTICIPANT	\N	PRESENT	0
572129	571146	19705W	PARTICIPANT	\N	PRESENT	0
572130	571146	14225N	PARTICIPANT	\N	PRESENT	0
572131	571146	19399H	PARTICIPANT	\N	PRESENT	0
572132	571146	19507S	PARTICIPANT	\N	PRESENT	0
572133	571146	19637C	PARTICIPANT	\N	PRESENT	0
572134	571146	04034C	PARTICIPANT	\N	PRESENT	0
572135	571146	19591F	PARTICIPANT	\N	PRESENT	0
572136	571146	11048N	PARTICIPANT	\N	PRESENT	0
572137	571146	11064N	PARTICIPANT	\N	PRESENT	0
572138	571146	14253S	PARTICIPANT	\N	PRESENT	0
572139	571146	04057K	PARTICIPANT	\N	PRESENT	0
572140	571146	14275Y	PARTICIPANT	\N	PRESENT	0
572141	571146	20042V	PARTICIPANT	\N	PRESENT	0
572142	571146	19479G	PARTICIPANT	\N	PRESENT	0
572143	571146	19739H	PARTICIPANT	\N	PRESENT	0
572199	571146	19563B	PARTICIPANT	\N	PRESENT	0
572145	571146	14219Q	PARTICIPANT	\N	PRESENT	0
572146	571146	19691J	PARTICIPANT	\N	PRESENT	0
572147	571146	14231L	PARTICIPANT	\N	PRESENT	0
572148	571146	14071N	PARTICIPANT	\N	PRESENT	0
572149	571146	20124W	PARTICIPANT	\N	PRESENT	0
572150	571146	19369B	PARTICIPANT	\N	PRESENT	0
572151	571146	19335Q	PARTICIPANT	\N	PRESENT	0
572152	571146	14059S	PARTICIPANT	\N	PRESENT	0
572153	571146	20062A	PARTICIPANT	\N	PRESENT	0
572154	571146	17023S	PARTICIPANT	\N	PRESENT	0
572155	571146	14089Y	PARTICIPANT	\N	PRESENT	0
572156	571146	11090Q	PARTICIPANT	\N	PRESENT	0
572157	571146	14205J	PARTICIPANT	\N	PRESENT	0
572158	571146	14189C	PARTICIPANT	\N	PRESENT	0
572159	571146	11085T	PARTICIPANT	\N	PRESENT	0
572160	571146	01024M	PARTICIPANT	\N	PRESENT	0
572161	571146	14030Q	PARTICIPANT	\N	PRESENT	0
572162	571146	08047A	PARTICIPANT	\N	PRESENT	0
572163	571146	20018V	PARTICIPANT	\N	PRESENT	0
572164	571146	20080C	PARTICIPANT	\N	PRESENT	0
572165	571146	05008E	PARTICIPANT	\N	PRESENT	0
572166	571146	14207L	PARTICIPANT	\N	PRESENT	0
572167	571146	14217N	PARTICIPANT	\N	PRESENT	0
572168	571146	14083S	PARTICIPANT	\N	PRESENT	0
572169	571146	10006L	PARTICIPANT	\N	PRESENT	0
572170	571146	19798U	PARTICIPANT	\N	PRESENT	0
572171	571146	14331P	PARTICIPANT	\N	PRESENT	0
572172	571146	04043D	PARTICIPANT	\N	PRESENT	0
572173	571146	10015M	PARTICIPANT	\N	PRESENT	0
572174	571146	14213J	PARTICIPANT	\N	PRESENT	0
572175	571146	19671E	PARTICIPANT	\N	PRESENT	0
572176	571146	19581D	PARTICIPANT	\N	PRESENT	0
572177	571146	17637T	PARTICIPANT	\N	PRESENT	0
572178	571146	20068G	PARTICIPANT	\N	PRESENT	0
572179	571146	19747H	PARTICIPANT	\N	PRESENT	0
572180	571146	08011M	PARTICIPANT	\N	PRESENT	0
572181	571146	08010L	PARTICIPANT	\N	PRESENT	0
572182	571146	08034U	PARTICIPANT	\N	PRESENT	0
572183	571146	04035D	PARTICIPANT	\N	PRESENT	0
572184	571146	19533U	PARTICIPANT	\N	PRESENT	0
572185	571146	14147R	PARTICIPANT	\N	PRESENT	0
572186	571146	20024T	PARTICIPANT	\N	PRESENT	0
572187	571146	20120S	PARTICIPANT	\N	PRESENT	0
572188	571146	19673G	PARTICIPANT	\N	PRESENT	0
572189	571146	19447X	PARTICIPANT	\N	PRESENT	0
572190	571146	14038Y	PARTICIPANT	\N	PRESENT	0
572191	571146	20034V	PARTICIPANT	\N	PRESENT	0
572192	571146	19954N	PARTICIPANT	\N	PRESENT	0
572193	571146	20172F	PARTICIPANT	\N	PRESENT	0
572194	571146	20082E	PARTICIPANT	\N	PRESENT	0
572195	571146	20032T	PARTICIPANT	\N	PRESENT	0
572196	571146	20050V	PARTICIPANT	\N	PRESENT	0
572197	571146	14257W	PARTICIPANT	\N	PRESENT	0
572198	571146	19701S	PARTICIPANT	\N	PRESENT	0
572200	571146	19549D	PARTICIPANT	\N	PRESENT	0
572201	571146	20126Y	PARTICIPANT	\N	PRESENT	0
572202	571146	19467C	PARTICIPANT	\N	PRESENT	0
572203	571146	14327T	PARTICIPANT	\N	PRESENT	0
572204	571146	14179A	PARTICIPANT	\N	PRESENT	0
572205	571146	19697Q	PARTICIPANT	\N	PRESENT	0
572206	571146	20100N	PARTICIPANT	\N	PRESENT	0
572207	571146	20152B	PARTICIPANT	\N	PRESENT	0
572208	571146	08018U	PARTICIPANT	\N	PRESENT	0
572209	571146	11043H	PARTICIPANT	\N	PRESENT	0
572210	571146	19766L	PARTICIPANT	\N	PRESENT	0
572211	571146	11065P	PARTICIPANT	\N	PRESENT	0
572212	571146	04085P	PARTICIPANT	\N	PRESENT	0
572213	571146	20048C	PARTICIPANT	\N	PRESENT	0
572214	571146	14169X	PARTICIPANT	\N	PRESENT	0
572215	571146	11053K	PARTICIPANT	\N	PRESENT	0
572223	571146	19820Y	PARTICIPANT	\N	PRESENT	0
572224	571146	20040T	PARTICIPANT	\N	PRESENT	0
572227	571146	20130U	PARTICIPANT	\N	PRESENT	0
572228	571146	14193X	PARTICIPANT	\N	PRESENT	0
580682	579602	14189C	PARTICIPANT	\N	EXCUSE	0
580683	579602	11040E	PARTICIPANT	\N	PRESENT	1
580684	579602	20050V	PARTICIPANT	\N	PRESENT	1
580685	579602	19349W	PARTICIPANT	\N	PRESENT	1
580686	579602	14173T	PARTICIPANT	\N	PRESENT	1
580689	579602	14225N	PARTICIPANT	\N	EXCUSE	0
584103	583976	19687N	PARTICIPANT	\N	PRESENT	0
584104	583976	19689Q	PARTICIPANT	\N	PRESENT	0
584105	583976	20040T	PARTICIPANT	\N	PRESENT	0
584106	583976	16685X	PARTICIPANT	\N	PRESENT	0
584107	583976	19671E	PARTICIPANT	\N	PRESENT	0
584108	583976	19551W	PARTICIPANT	\N	PRESENT	0
584109	583976	14083S	PARTICIPANT	\N	PRESENT	0
584110	583976	20060X	PARTICIPANT	\N	PRESENT	0
584111	583976	14105F	PARTICIPANT	\N	PRESENT	0
584112	583976	19575F	PRESIDENT	0	PRESENT	0
584113	583976	19369B	PARTICIPANT	\N	PRESENT	0
584114	583976	19749K	PARTICIPANT	\N	PRESENT	0
584115	583976	20126Y	PARTICIPANT	\N	PRESENT	0
584116	583495	19758L	PARTICIPANT	\N	PRESENT	0
584117	583495	20094J	PARTICIPANT	\N	PRESENT	0
584118	583495	14195A	PARTICIPANT	\N	PRESENT	0
584119	583495	20096L	PARTICIPANT	\N	PRESENT	0
584120	583495	19782L	PARTICIPANT	\N	PRESENT	0
584121	583495	20082E	PARTICIPANT	\N	PRESENT	0
584122	583495	05012A	PARTICIPANT	\N	PRESENT	0
584123	583495	20122U	PARTICIPANT	\N	PRESENT	0
584124	583495	19866P	PARTICIPANT	\N	PRESENT	0
584125	583495	20142Y	PARTICIPANT	\N	PRESENT	0
584126	583221	07029T	PARTICIPANT	\N	EXCUSE	0
584127	583495	19729F	PARTICIPANT	\N	PRESENT	0
584128	583495	20124W	PARTICIPANT	\N	PRESENT	0
584129	583495	11097X	PARTICIPANT	\N	PRESENT	0
584130	583495	11056N	PARTICIPANT	\N	PRESENT	0
584131	583495	20086J	PARTICIPANT	\N	PRESENT	0
584132	583495	20044X	PARTICIPANT	\N	PRESENT	0
584133	583495	14069U	PARTICIPANT	\N	PRESENT	0
584134	583495	14187A	PARTICIPANT	\N	PRESENT	0
584135	583495	20062A	PARTICIPANT	\N	PRESENT	0
584136	583495	14083S	PARTICIPANT	\N	PRESENT	0
584137	583495	14231L	PARTICIPANT	\N	PRESENT	0
584139	583495	14105F	PARTICIPANT	\N	PRESENT	0
584140	583495	19713W	PARTICIPANT	\N	PRESENT	0
584141	583495	20066E	PARTICIPANT	\N	PRESENT	0
584142	583495	14217N	PARTICIPANT	\N	PRESENT	0
584143	583495	14213J	PARTICIPANT	\N	PRESENT	0
584144	583495	20024T	PARTICIPANT	\N	PRESENT	0
584145	583495	19954N	PARTICIPANT	\N	PRESENT	0
584146	583495	14331P	PARTICIPANT	\N	PRESENT	0
584147	583495	01043Q	PARTICIPANT	\N	PRESENT	0
584148	583495	08010L	PARTICIPANT	\N	PRESENT	0
584149	583495	14357A	PARTICIPANT	\N	PRESENT	0
584216	583496	20082E	PARTICIPANT	\N	PRESENT	0
584217	583496	19441R	PARTICIPANT	\N	PRESENT	0
584218	583496	19820Y	PARTICIPANT	\N	PRESENT	0
584219	583496	20028X	PARTICIPANT	\N	PRESENT	0
584220	583496	14205J	PARTICIPANT	\N	PRESENT	0
584221	583496	14105F	PARTICIPANT	\N	PRESENT	0
584222	583496	20062A	PARTICIPANT	\N	PRESENT	0
584223	583496	11090Q	PARTICIPANT	\N	PRESENT	0
584224	583496	20026V	PARTICIPANT	\N	PRESENT	0
584225	583496	04045F	PARTICIPANT	\N	PRESENT	0
584226	583496	20180F	PARTICIPANT	\N	PRESENT	0
584227	583496	19954N	PARTICIPANT	\N	PRESENT	0
584228	583496	14207L	PARTICIPANT	\N	PRESENT	0
584229	583496	14038Y	PARTICIPANT	\N	PRESENT	0
584230	583496	20044X	PARTICIPANT	\N	PRESENT	0
584231	583496	19413M	PARTICIPANT	\N	PRESENT	0
584246	583496	11099A	PARTICIPANT	\N	PRESENT	0
584233	583496	20094J	PARTICIPANT	\N	PRESENT	0
584234	583496	19695N	PARTICIPANT	\N	PRESENT	0
584239	583496	18193Q	PARTICIPANT	\N	PRESENT	0
584236	583496	01025N	PARTICIPANT	\N	PRESENT	0
584237	583496	01024M	PARTICIPANT	\N	PRESENT	0
584238	583496	14357A	PARTICIPANT	\N	PRESENT	0
584240	583496	14267Y	PARTICIPANT	\N	PRESENT	0
584241	583496	18083K	PARTICIPANT	\N	PRESENT	0
584242	583496	19507S	PARTICIPANT	\N	PRESENT	0
584243	583496	19421M	PARTICIPANT	\N	PRESENT	0
584244	583496	19467C	PARTICIPANT	\N	PRESENT	0
584245	583496	20096L	PARTICIPANT	\N	PRESENT	0
584247	583496	19563B	PARTICIPANT	\N	PRESENT	0
584248	583496	20076G	PARTICIPANT	\N	PRESENT	0
584249	583496	20032T	PARTICIPANT	\N	PRESENT	0
584250	583496	14187A	PARTICIPANT	\N	PRESENT	0
584251	583496	19383Y	PARTICIPANT	\N	PRESENT	0
584252	583496	19551W	PARTICIPANT	\N	PRESENT	0
584253	583496	14331P	PARTICIPANT	\N	PRESENT	0
584254	583496	19739H	PARTICIPANT	\N	PRESENT	0
584255	583496	20030R	PARTICIPANT	\N	PRESENT	0
584256	583496	20248J	PARTICIPANT	\N	PRESENT	0
584257	583496	14195A	PARTICIPANT	\N	PRESENT	0
584258	583496	19703U	PARTICIPANT	\N	PRESENT	0
584259	583496	19723Y	PARTICIPANT	\N	PRESENT	0
584260	583496	14033T	PARTICIPANT	\N	PRESENT	0
584261	583496	20172F	PARTICIPANT	\N	PRESENT	0
584262	583496	11056N	PARTICIPANT	\N	PRESENT	0
584263	583496	19760E	PARTICIPANT	\N	PRESENT	0
584264	583496	19758L	PARTICIPANT	\N	PRESENT	0
584265	583496	20046A	PARTICIPANT	\N	PRESENT	0
584266	583496	19768N	PARTICIPANT	\N	PRESENT	0
584267	583496	20054A	PARTICIPANT	\N	PRESENT	0
584268	583496	11048N	PARTICIPANT	\N	PRESENT	0
584269	583496	14107H	PARTICIPANT	\N	PRESENT	0
584270	583496	20066E	PARTICIPANT	\N	PRESENT	0
584275	583496	20110Q	PARTICIPANT	\N	PRESENT	0
584272	583496	14213J	PARTICIPANT	\N	PRESENT	0
584273	583496	11097X	PARTICIPANT	\N	PRESENT	0
584274	583496	19387D	PARTICIPANT	\N	PRESENT	0
584276	583496	19347U	PARTICIPANT	\N	PRESENT	0
584277	583496	14327T	PARTICIPANT	\N	PRESENT	0
584278	583496	20018V	PARTICIPANT	\N	PRESENT	0
584279	583496	20090E	PARTICIPANT	\N	PRESENT	0
584280	583496	20124W	PARTICIPANT	\N	PRESENT	0
584281	583496	19415P	PARTICIPANT	\N	PRESENT	0
584282	583496	14147R	PARTICIPANT	\N	PRESENT	0
584214	583496	14026U	PARTICIPANT	\N	PRESENT	0
584215	583496	14257W	PARTICIPANT	\N	PRESENT	0
584283	583496	20092G	PARTICIPANT	\N	PRESENT	0
584284	583496	14021P	PARTICIPANT	\N	PRESENT	0
584285	583496	14215L	PARTICIPANT	\N	PRESENT	0
584286	583496	19713W	PARTICIPANT	\N	PRESENT	0
584287	583496	19782L	PARTICIPANT	\N	PRESENT	0
584288	583496	11012A	PARTICIPANT	\N	PRESENT	0
584289	583496	20072C	PARTICIPANT	\N	PRESENT	0
584290	583496	14249W	PARTICIPANT	\N	PRESENT	0
584291	583496	19349W	PARTICIPANT	\N	PRESENT	0
584292	583496	14071N	PARTICIPANT	\N	PRESENT	0
584293	583496	20126Y	PARTICIPANT	\N	PRESENT	0
584294	583496	19369B	PARTICIPANT	\N	PRESENT	0
584295	583496	14083S	PARTICIPANT	\N	PRESENT	0
584296	583496	19631V	PARTICIPANT	\N	PRESENT	0
584297	583496	14069U	PARTICIPANT	\N	PRESENT	0
584516	583463	08018U	PARTICIPANT	\N	PRESENT	0
584517	583463	14259Y	PARTICIPANT	\N	PRESENT	0
584539	583457	14327T	PARTICIPANT	\N	PRESENT	0
584540	583457	20086J	PARTICIPANT	\N	PRESENT	0
584541	583457	14331P	PARTICIPANT	\N	PRESENT	0
584542	583457	01057W	PARTICIPANT	\N	PRESENT	0
584543	583457	20080C	PARTICIPANT	\N	PRESENT	0
584544	583457	19667J	PARTICIPANT	\N	PRESENT	0
584545	583457	14225N	PRESIDENT	0	PRESENT	0
584546	583457	19671E	PARTICIPANT	\N	PRESENT	0
584547	583457	19349W	PARTICIPANT	\N	PRESENT	0
584548	583457	08010L	PARTICIPANT	\N	PRESENT	0
584549	583457	20116W	PARTICIPANT	\N	PRESENT	0
584550	583457	20022R	PARTICIPANT	\N	PRESENT	0
584551	583457	19479G	PARTICIPANT	\N	PRESENT	0
584552	583457	19647E	PARTICIPANT	\N	PRESENT	0
584553	583457	11048N	PARTICIPANT	\N	PRESENT	0
584554	583457	19711U	PARTICIPANT	\N	PRESENT	0
584555	583457	19531S	PARTICIPANT	\N	PRESENT	0
584556	583457	14189C	PARTICIPANT	\N	PRESENT	0
584557	583457	19687N	PARTICIPANT	\N	PRESENT	0
584558	583457	19689Q	PARTICIPANT	\N	PRESENT	0
584559	583457	14173T	PARTICIPANT	\N	PRESENT	0
584560	583457	11040E	PARTICIPANT	\N	PRESENT	0
584561	583457	14083S	PARTICIPANT	\N	PRESENT	0
584562	583457	11012A	PARTICIPANT	\N	PRESENT	0
584563	583457	19741B	PARTICIPANT	\N	PRESENT	0
584564	583457	14121F	PARTICIPANT	\N	PRESENT	0
580464	579400	20112S	PARTICIPANT	\N	PRESENT	0
580465	579400	19820Y	PARTICIPANT	\N	PRESENT	0
580466	579400	19489J	PARTICIPANT	\N	PRESENT	0
580467	579400	04045F	PARTICIPANT	\N	PRESENT	0
580468	579400	19782L	PARTICIPANT	\N	PRESENT	0
580469	579400	14195A	PARTICIPANT	\N	PRESENT	0
580470	579400	14219Q	PARTICIPANT	\N	PRESENT	0
580471	579400	20248J	PARTICIPANT	\N	PRESENT	0
580472	579400	14055N	PARTICIPANT	\N	PRESENT	0
580473	579400	20090E	PARTICIPANT	\N	PRESENT	0
580474	579400	20022R	PARTICIPANT	\N	PRESENT	0
580475	579400	05012A	PARTICIPANT	\N	PRESENT	0
580476	579400	14231L	PARTICIPANT	\N	PRESENT	0
580477	579400	04047H	PARTICIPANT	\N	PRESENT	0
580478	579400	20116W	PARTICIPANT	\N	PRESENT	0
580479	579400	19629C	PARTICIPANT	\N	PRESENT	0
580480	579400	14107H	PARTICIPANT	\N	PRESENT	0
580481	579400	20110Q	PARTICIPANT	\N	PRESENT	0
580482	579400	20100N	PARTICIPANT	\N	PRESENT	0
580483	579400	19798U	PARTICIPANT	\N	PRESENT	0
580484	579400	14053L	PARTICIPANT	\N	PRESENT	0
580485	579400	14026U	PARTICIPANT	\N	PRESENT	0
580486	579400	20108W	PARTICIPANT	\N	PRESENT	0
580487	579400	20034V	PARTICIPANT	\N	PRESENT	0
580488	579400	07029T	PARTICIPANT	\N	PRESENT	0
580489	579400	20076G	PARTICIPANT	\N	PRESENT	0
580490	579400	20038A	PARTICIPANT	\N	PRESENT	0
580491	579400	17367Q	PARTICIPANT	\N	PRESENT	0
580492	579400	11043H	PARTICIPANT	\N	PRESENT	0
580493	579400	14033T	PARTICIPANT	\N	PRESENT	0
580462	579400	19719D	PARTICIPANT	\N	PRESENT	0
580463	579400	20084G	PARTICIPANT	\N	PRESENT	0
580494	579400	14215L	PARTICIPANT	\N	PRESENT	0
580495	579400	11056N	PARTICIPANT	\N	PRESENT	0
580496	579400	14259Y	PARTICIPANT	\N	PRESENT	0
580497	579400	20046A	PARTICIPANT	\N	PRESENT	0
580498	579400	20102Q	PARTICIPANT	\N	PRESENT	0
580499	579400	14089Y	PARTICIPANT	\N	PRESENT	0
580500	579400	20096L	PARTICIPANT	\N	PRESENT	0
580501	579400	19631V	PARTICIPANT	\N	PRESENT	0
580502	579400	20088L	PARTICIPANT	\N	PRESENT	0
580503	579400	14205J	PARTICIPANT	\N	PRESENT	0
580504	579400	19573D	PARTICIPANT	\N	PRESENT	0
580505	579400	11072N	PARTICIPANT	\N	PRESENT	0
580506	579400	19735D	PARTICIPANT	\N	PRESENT	0
580507	579400	19447X	PARTICIPANT	\N	PRESENT	0
580508	579400	20126Y	PARTICIPANT	\N	PRESENT	0
580509	579400	01043Q	PARTICIPANT	\N	PRESENT	0
580510	579400	19691J	PARTICIPANT	\N	PRESENT	0
580511	579400	20066E	PARTICIPANT	\N	PRESENT	0
580512	579400	20128B	PARTICIPANT	\N	PRESENT	0
580513	579400	20094J	PARTICIPANT	\N	PRESENT	0
580514	579400	19415P	PARTICIPANT	\N	PRESENT	0
580515	579400	19747H	PARTICIPANT	\N	PRESENT	0
580516	579400	19467C	PARTICIPANT	\N	PRESENT	0
580517	579400	14042U	PARTICIPANT	\N	PRESENT	0
580518	579400	19441R	PARTICIPANT	\N	PRESENT	0
580519	579400	19739H	PARTICIPANT	\N	PRESENT	0
580520	579400	20072C	PARTICIPANT	\N	PRESENT	0
580521	579400	19387D	PARTICIPANT	\N	PRESENT	0
580522	579400	19565D	PARTICIPANT	\N	PRESENT	0
580523	579400	10015M	PARTICIPANT	\N	PRESENT	0
580524	579400	19301E	PARTICIPANT	\N	PRESENT	0
580525	579400	12016W	PARTICIPANT	\N	PRESENT	0
580526	579400	20172F	PARTICIPANT	\N	PRESENT	0
580527	579400	20028X	PARTICIPANT	\N	PRESENT	0
580528	579400	18193Q	PARTICIPANT	\N	PRESENT	0
580529	579400	14151M	PARTICIPANT	\N	PRESENT	0
580530	579400	19619A	PARTICIPANT	\N	PRESENT	0
580531	579400	19725B	PARTICIPANT	\N	PRESENT	0
580532	579400	14021P	PARTICIPANT	\N	PRESENT	0
580533	579400	20032T	PARTICIPANT	\N	PRESENT	0
580534	579400	19621T	PARTICIPANT	\N	PRESENT	0
580535	579400	95063L	PARTICIPANT	\N	PRESENT	0
580536	579400	19713W	PARTICIPANT	\N	PRESENT	0
580537	579400	20180F	PARTICIPANT	\N	PRESENT	0
580538	579400	14059S	PARTICIPANT	\N	PRESENT	0
580539	579400	17737W	PARTICIPANT	\N	PRESENT	0
580540	579400	20056C	PARTICIPANT	\N	PRESENT	0
580541	579400	19443T	PARTICIPANT	\N	PRESENT	0
580542	579400	20026V	PARTICIPANT	\N	PRESENT	0
580543	579400	19768N	PARTICIPANT	\N	PRESENT	0
580544	579400	19703U	PARTICIPANT	\N	PRESENT	0
580545	579400	14147R	PARTICIPANT	\N	PRESENT	0
580546	579400	20044X	PARTICIPANT	\N	PRESENT	0
580547	579400	01028R	PARTICIPANT	\N	PRESENT	0
580548	579400	14213J	PARTICIPANT	\N	PRESENT	0
580549	579400	14031R	PARTICIPANT	\N	PRESENT	0
580550	579400	20086J	PARTICIPANT	\N	PRESENT	0
580551	579400	04033B	PARTICIPANT	\N	PRESENT	0
580552	579400	01024M	PARTICIPANT	\N	PRESENT	0
580553	579400	14357A	PARTICIPANT	\N	PRESENT	0
580554	579400	20120S	PARTICIPANT	\N	PRESENT	0
580555	579400	20098N	PARTICIPANT	\N	PRESENT	0
580556	579400	20058E	PARTICIPANT	\N	PRESENT	0
580557	579400	20138D	PARTICIPANT	\N	PRESENT	0
580558	579400	20118Y	PARTICIPANT	\N	PRESENT	0
580559	579400	19333N	PARTICIPANT	\N	PRESENT	0
580560	579400	19563B	PARTICIPANT	\N	PRESENT	0
581321	581319	14031R	PARTICIPANT	\N	PRESENT	0
581322	581319	05008E	PARTICIPANT	\N	PRESENT	0
581323	581319	20136B	PARTICIPANT	\N	PRESENT	0
581324	581319	19826F	PARTICIPANT	\N	PRESENT	0
581326	581319	14083S	PARTICIPANT	\N	PRESENT	0
581327	581319	20036X	PARTICIPANT	\N	PRESENT	0
581328	581319	19820Y	PARTICIPANT	\N	PRESENT	0
581330	581319	14097Y	PARTICIPANT	\N	PRESENT	0
581331	581319	19599P	PARTICIPANT	\N	PRESENT	0
581332	581319	19723Y	PARTICIPANT	\N	PRESENT	0
581334	581319	20180F	PARTICIPANT	\N	PRESENT	0
581335	581319	20034V	PARTICIPANT	\N	PRESENT	0
581411	571360	20116W	PARTICIPANT	\N	PRESENT	0
581413	571360	20090E	PARTICIPANT	\N	PRESENT	0
581414	571360	14083S	PARTICIPANT	\N	PRESENT	0
581416	571360	11053K	PARTICIPANT	\N	PRESENT	0
581417	571360	19681G	PARTICIPANT	\N	PRESENT	0
581418	571360	19671E	PARTICIPANT	\N	PRESENT	0
581419	571360	19739H	PARTICIPANT	\N	PRESENT	0
581732	579464	19673G	PARTICIPANT	\N	PRESENT	0
581733	579464	07004J	PARTICIPANT	\N	PRESENT	0
581734	579464	14215L	PARTICIPANT	\N	PRESENT	0
581735	579464	19649G	PARTICIPANT	\N	PRESENT	0
581736	579464	04047H	PRESIDENT	0	PRESENT	0
581802	581801	19441R	PARTICIPANT	\N	PRESENT	0
581803	581801	19467C	PARTICIPANT	\N	PRESENT	0
581804	581801	14205J	PARTICIPANT	\N	PRESENT	0
581805	581801	20144B	PARTICIPANT	\N	PRESENT	0
581807	581806	19441R	PARTICIPANT	\N	PRESENT	0
581808	581806	14205J	PARTICIPANT	\N	PRESENT	0
581810	581809	11083R	PARTICIPANT	\N	PRESENT	0
581811	581809	19593H	PARTICIPANT	\N	PRESENT	0
581812	581809	17367Q	PARTICIPANT	\N	PRESENT	0
581813	581809	20180F	PARTICIPANT	\N	PRESENT	1
581814	579464	14053L	PARTICIPANT	\N	PRESENT	0
581815	579464	11026G	PARTICIPANT	\N	PRESENT	0
581816	579464	10015M	PARTICIPANT	\N	PRESENT	0
581817	579464	05008E	PARTICIPANT	\N	PRESENT	0
581818	579464	19447X	PARTICIPANT	\N	PRESENT	0
581819	579464	14089Y	PARTICIPANT	\N	PRESENT	0
581820	579464	17737W	PARTICIPANT	\N	PRESENT	0
581821	579464	95063L	PARTICIPANT	\N	PRESENT	0
581822	579464	20108W	PARTICIPANT	\N	PRESENT	0
581823	579464	14041T	PARTICIPANT	\N	PRESENT	0
581824	579464	20110Q	PARTICIPANT	\N	PRESENT	0
581825	579464	14151M	PARTICIPANT	\N	PRESENT	0
581826	579464	14021P	PARTICIPANT	\N	PRESENT	0
581846	579464	19798U	PARTICIPANT	\N	PRESENT	1
581847	579464	11097X	PARTICIPANT	\N	PRESENT	0
581848	579464	19553Y	PARTICIPANT	\N	PRESENT	0
581849	579464	14042U	PARTICIPANT	\N	PRESENT	0
581850	579464	10006L	PARTICIPANT	\N	PRESENT	0
581851	579464	04092N	PARTICIPANT	\N	PRESENT	1
581852	579464	20040T	PARTICIPANT	\N	PRESENT	0
581853	579464	20066E	PARTICIPANT	\N	PRESENT	0
581854	579464	14071N	PARTICIPANT	\N	PRESENT	0
581855	579464	19697Q	PARTICIPANT	\N	PRESENT	0
581856	579464	20090E	PARTICIPANT	\N	PRESENT	0
581857	579464	14355X	PARTICIPANT	\N	PRESENT	1
581858	579464	19569H	PARTICIPANT	\N	PRESENT	1
581859	579464	19415P	PARTICIPANT	\N	PRESENT	0
581860	579464	18193Q	PARTICIPANT	\N	PRESENT	0
581861	579464	14223L	PARTICIPANT	\N	PRESENT	1
581862	579464	17779H	PARTICIPANT	\N	PRESENT	0
593437	593436	05008E	PARTICIPANT	\N	EXCUSE	0
593438	593436	19715Y	PARTICIPANT	\N	EXCUSE	0
594136	593684	14121F	PARTICIPANT	\N	PRESENT	0
594186	593547	20126Y	PARTICIPANT	\N	PRESENT	1
594489	593444	20054A	PARTICIPANT	\N	PRESENT	0
594490	593444	14083S	PARTICIPANT	\N	PRESENT	0
594491	593444	14030Q	PARTICIPANT	\N	PRESENT	0
594492	593444	16685X	PARTICIPANT	\N	PRESENT	0
594493	593444	04042C	PARTICIPANT	\N	PRESENT	0
594494	593444	19685L	PARTICIPANT	\N	PRESENT	0
594495	593444	20078J	PARTICIPANT	\N	PRESENT	0
594496	593444	19703U	PARTICIPANT	\N	PRESENT	0
594497	593444	19369B	PARTICIPANT	\N	PRESENT	0
594498	593444	20152B	PARTICIPANT	\N	PRESENT	0
594500	594499	05008E	PARTICIPANT	\N	PRESENT	0
594501	594499	01028R	PARTICIPANT	\N	PRESENT	0
594502	593444	19621T	PARTICIPANT	\N	PRESENT	0
594503	593444	19507S	PARTICIPANT	\N	PRESENT	0
594504	594499	04085P	PARTICIPANT	\N	PRESENT	0
594505	594499	11026G	PARTICIPANT	\N	PRESENT	0
594506	593444	19671E	PARTICIPANT	\N	PRESENT	0
594507	593444	19711U	PARTICIPANT	\N	PRESENT	0
594508	593444	08010L	PARTICIPANT	\N	PRESENT	0
594509	593444	11012A	PARTICIPANT	\N	PRESENT	0
594510	593444	19443T	PARTICIPANT	\N	PRESENT	0
594511	593444	19762G	PARTICIPANT	\N	PRESENT	0
594512	593444	05012A	PARTICIPANT	\N	PRESENT	0
594513	593444	14187A	PARTICIPANT	\N	PRESENT	0
594514	593444	19675J	PARTICIPANT	\N	PRESENT	0
594515	593444	19663E	PARTICIPANT	\N	PRESENT	0
594517	593444	14179A	PARTICIPANT	\N	PRESENT	0
594518	593444	19543W	PARTICIPANT	\N	PRESENT	0
594519	593444	14255U	PARTICIPANT	\N	PRESENT	0
594520	593444	20110Q	PARTICIPANT	\N	PRESENT	0
594521	593444	14205J	PARTICIPANT	\N	PRESENT	0
594522	593444	19295A	PARTICIPANT	\N	PRESENT	0
594523	593444	19649G	PARTICIPANT	\N	PRESENT	0
594524	593444	19551W	PARTICIPANT	\N	PRESENT	0
594526	593444	11110B	PARTICIPANT	\N	PRESENT	0
594532	593444	19421M	PARTICIPANT	\N	PRESENT	0
594528	593444	04043D	PARTICIPANT	\N	PRESENT	0
594531	593444	19581D	PARTICIPANT	\N	PRESENT	0
594535	593444	20048C	PARTICIPANT	\N	PRESENT	0
594543	593444	14109K	PARTICIPANT	\N	PRESENT	0
594537	593444	20080C	PARTICIPANT	\N	PRESENT	0
594540	593444	14123H	PARTICIPANT	\N	PRESENT	0
594806	593446	01043Q	PARTICIPANT	\N	PRESENT	0
594807	593446	19651A	PARTICIPANT	\N	PRESENT	0
594808	593446	20132W	PARTICIPANT	\N	PRESENT	0
594809	593446	14109K	PARTICIPANT	\N	PRESENT	0
594810	593446	19721W	PARTICIPANT	\N	PRESENT	0
594811	593446	17589D	PARTICIPANT	\N	PRESENT	0
594812	593446	19621T	PARTICIPANT	\N	PRESENT	0
594813	593446	14229S	PARTICIPANT	\N	PRESENT	0
594814	593446	14121F	PARTICIPANT	\N	PRESENT	0
594815	593446	11012A	PARTICIPANT	\N	PRESENT	0
594816	593446	20142Y	PARTICIPANT	\N	PRESENT	0
594817	593446	19758L	PARTICIPANT	\N	PRESENT	0
594818	593446	20058E	PARTICIPANT	\N	PRESENT	0
594819	593446	19735D	PARTICIPANT	\N	PRESENT	0
594820	593446	14215L	PARTICIPANT	\N	PRESENT	0
594821	593446	19798U	PARTICIPANT	\N	PRESENT	0
594822	593446	14059S	PARTICIPANT	\N	PRESENT	0
594823	593446	19691J	PARTICIPANT	\N	PRESENT	0
594824	593446	20114U	PARTICIPANT	\N	PRESENT	0
594839	593446	20026V	PARTICIPANT	\N	PRESENT	0
594827	593446	19479G	PARTICIPANT	\N	PRESENT	0
594828	593446	19611R	PARTICIPANT	\N	PRESENT	0
594829	593446	11104D	PARTICIPANT	\N	PRESENT	0
594830	593446	19593H	PARTICIPANT	\N	PRESENT	0
594841	593446	20092G	PARTICIPANT	\N	PRESENT	0
594842	593446	19057M	PARTICIPANT	\N	PRESENT	0
594833	593446	19697Q	PARTICIPANT	\N	PRESENT	0
594834	593446	20024T	PARTICIPANT	\N	PRESENT	0
594835	593446	19527W	PARTICIPANT	\N	PRESENT	0
594836	593446	19693L	PARTICIPANT	\N	PRESENT	0
594837	593446	14123H	PARTICIPANT	\N	PRESENT	0
594838	593446	01057W	PARTICIPANT	\N	PRESENT	0
594840	593446	20264J	PARTICIPANT	\N	PRESENT	0
594843	593446	19507S	PARTICIPANT	\N	PRESENT	0
594844	593446	19747H	PARTICIPANT	\N	PRESENT	0
594845	593446	11056N	PARTICIPANT	\N	PRESENT	0
594846	593446	20134Y	PARTICIPANT	\N	PRESENT	0
594847	593446	20090E	PARTICIPANT	\N	PRESENT	0
594848	593446	14030Q	PARTICIPANT	\N	PRESENT	0
594849	593446	95063L	PARTICIPANT	\N	PRESENT	0
594850	593446	14031R	PARTICIPANT	\N	PRESENT	0
594851	593446	20052X	PARTICIPANT	\N	PRESENT	0
594852	593446	20102Q	PARTICIPANT	\N	PRESENT	0
594853	593446	19681G	PARTICIPANT	\N	PRESENT	0
594854	593446	11097X	PARTICIPANT	\N	PRESENT	0
594855	593446	19673G	PARTICIPANT	\N	PRESENT	0
594856	593446	19723Y	PARTICIPANT	\N	PRESENT	0
594857	593446	19563B	PARTICIPANT	\N	PRESENT	0
594858	593446	20034V	PARTICIPANT	\N	PRESENT	0
594859	593446	20084G	PARTICIPANT	\N	PRESENT	0
594860	593446	20054A	PARTICIPANT	\N	PRESENT	0
594861	593446	19782L	PARTICIPANT	\N	PRESENT	0
594869	593446	20056C	PARTICIPANT	\N	PRESENT	0
594870	593548	11048N	PARTICIPANT	\N	PRESENT	0
594871	593548	01057W	PARTICIPANT	\N	PRESENT	0
594872	593548	14121F	PARTICIPANT	\N	PRESENT	0
594873	593548	99004R	PARTICIPANT	\N	PRESENT	0
594874	593548	14225N	PRESIDENT	0	PRESENT	0
594875	593548	07029T	PARTICIPANT	\N	PRESENT	0
594876	593446	19515S	PARTICIPANT	\N	PRESENT	0
594877	593548	14327T	PARTICIPANT	\N	PRESENT	0
594878	593548	19711U	PARTICIPANT	\N	PRESENT	0
594882	593548	20080C	PARTICIPANT	\N	PRESENT	0
594880	593548	19647E	PARTICIPANT	\N	PRESENT	0
594881	593548	19689Q	PARTICIPANT	\N	PRESENT	0
594883	593446	19760E	PARTICIPANT	\N	PRESENT	0
594884	593548	19479G	PARTICIPANT	\N	PRESENT	0
594889	593446	20108W	PARTICIPANT	\N	PRESENT	0
594886	593548	20044X	PARTICIPANT	\N	PRESENT	0
594887	593548	11110B	PARTICIPANT	\N	PRESENT	0
594888	593446	20138D	PARTICIPANT	\N	PRESENT	0
594890	593446	20098N	PARTICIPANT	\N	PRESENT	0
594891	593548	14083S	PARTICIPANT	\N	PRESENT	0
594892	593446	19699S	PARTICIPANT	\N	PRESENT	0
594893	593446	19399H	PARTICIPANT	\N	PRESENT	0
594894	593446	20252E	PARTICIPANT	\N	PRESENT	0
594895	593446	19349W	PARTICIPANT	\N	PRESENT	0
594896	593548	20086J	PARTICIPANT	\N	PRESENT	0
594897	593548	11074Q	PARTICIPANT	\N	PRESENT	0
594898	593548	19741B	PARTICIPANT	\N	PRESENT	0
594899	593446	19573D	PARTICIPANT	\N	PRESENT	0
594900	593446	14205J	PARTICIPANT	\N	PRESENT	0
594901	593446	20172F	PARTICIPANT	\N	PRESENT	0
594923	593446	19447X	PARTICIPANT	\N	PRESENT	0
594903	593446	20266L	PARTICIPANT	\N	PRESENT	0
594904	593446	20136B	PARTICIPANT	\N	PRESENT	0
594905	593446	20248J	PARTICIPANT	\N	PRESENT	0
594906	593446	14231L	PARTICIPANT	\N	PRESENT	0
594907	593446	14147R	PARTICIPANT	\N	PRESENT	0
594916	593446	19549D	PARTICIPANT	\N	PRESENT	0
594917	593446	14069U	PARTICIPANT	\N	PRESENT	0
594922	593446	08012N	PARTICIPANT	\N	PRESENT	0
594924	593446	19467C	PARTICIPANT	\N	PRESENT	0
594925	593446	14033T	PARTICIPANT	\N	PRESENT	0
594926	593446	20048C	PARTICIPANT	\N	PRESENT	0
594927	593446	19581D	PARTICIPANT	\N	PRESENT	0
594928	593446	14259Y	PARTICIPANT	\N	PRESENT	0
594929	593548	20070A	PARTICIPANT	\N	PRESENT	0
594930	593322	19565D	PARTICIPANT	\N	PRESENT	0
594931	593322	20072C	PARTICIPANT	\N	PRESENT	0
594932	593322	01058X	PARTICIPANT	\N	PRESENT	0
594933	593322	16685X	PARTICIPANT	\N	PRESENT	0
594934	593322	04042C	PRESIDENT	0	PRESENT	0
594935	593322	19669L	PARTICIPANT	\N	PRESENT	0
594936	593322	11066Q	PARTICIPANT	\N	PRESENT	0
594937	593322	19421M	PARTICIPANT	\N	PRESENT	0
594938	593322	19709B	PARTICIPANT	\N	PRESENT	0
594939	593322	14193X	PARTICIPANT	\N	PRESENT	0
594940	593322	19347U	PARTICIPANT	\N	PRESENT	0
594941	593322	07033P	PARTICIPANT	\N	PRESENT	0
594942	593322	97011G	PARTICIPANT	\N	PRESENT	0
594943	593322	08061X	PARTICIPANT	\N	PRESENT	0
594944	593322	14249W	PARTICIPANT	\N	PRESENT	0
594945	593322	08047A	PARTICIPANT	\N	PRESENT	0
594946	593322	14059S	PARTICIPANT	\N	PRESENT	0
571365	571364	19699S	PARTICIPANT	\N	PRESENT	1
571366	571364	20180F	PARTICIPANT	\N	PRESENT	1
571367	571364	20124W	PARTICIPANT	\N	PRESENT	1
571368	571364	19651A	PARTICIPANT	\N	PRESENT	1
571369	571364	20134Y	PARTICIPANT	\N	PRESENT	1
571370	571364	14109K	PARTICIPANT	\N	PRESENT	1
571371	571364	20048C	PARTICIPANT	\N	PRESENT	1
571372	571364	20142Y	PARTICIPANT	\N	PRESENT	1
571373	571364	20132W	PARTICIPANT	\N	PRESENT	1
571374	571364	20098N	PARTICIPANT	\N	PRESENT	1
571376	571375	19699S	PARTICIPANT	\N	PRESENT	1
571377	571375	19651A	PARTICIPANT	\N	PRESENT	1
571378	571375	20142Y	PARTICIPANT	\N	PRESENT	1
571379	571375	14109K	PARTICIPANT	\N	PRESENT	1
571380	571375	20124W	PARTICIPANT	\N	PRESENT	1
571381	571375	20132W	PARTICIPANT	\N	PRESENT	1
571401	571400	19699S	PARTICIPANT	\N	PRESENT	1
571402	571400	19399H	PARTICIPANT	\N	PRESENT	1
571410	571409	19699S	PARTICIPANT	\N	PRESENT	1
571412	571409	19399H	PARTICIPANT	\N	PRESENT	1
571413	571409	20124W	PARTICIPANT	\N	PRESENT	1
571414	571409	19693L	PARTICIPANT	\N	PRESENT	1
571448	571446	19643A	PARTICIPANT	\N	PRESENT	1
571449	571446	19693L	PARTICIPANT	\N	PRESENT	1
571452	571451	19643A	PARTICIPANT	\N	PRESENT	1
571453	571451	19693L	PARTICIPANT	\N	PRESENT	1
571456	571455	20134Y	PARTICIPANT	\N	PRESENT	1
571457	571455	19693L	PARTICIPANT	\N	PRESENT	1
571458	571455	19575F	PARTICIPANT	\N	PRESENT	1
571459	571455	14229S	PARTICIPANT	\N	PRESENT	1
571460	571455	19643A	PARTICIPANT	\N	PRESENT	1
571482	571481	19643A	PARTICIPANT	\N	PRESENT	1
571483	571481	19651A	PARTICIPANT	\N	PRESENT	1
571484	571481	19693L	PARTICIPANT	\N	PRESENT	1
571485	571481	14229S	PARTICIPANT	\N	PRESENT	1
571486	571481	19719D	PARTICIPANT	\N	PRESENT	1
571487	571481	20134Y	PARTICIPANT	\N	PRESENT	1
571489	571481	19575F	PARTICIPANT	\N	PRESENT	1
571491	571490	19651A	PARTICIPANT	\N	PRESENT	1
571492	571490	19693L	PARTICIPANT	\N	PRESENT	1
571493	571490	19643A	PARTICIPANT	\N	PRESENT	1
571494	571490	14229S	PARTICIPANT	\N	PRESENT	1
571495	571490	19575F	PARTICIPANT	\N	PRESENT	1
571497	571496	19693L	PARTICIPANT	\N	PRESENT	1
571498	571496	14229S	PARTICIPANT	\N	PRESENT	1
571499	571496	19651A	PARTICIPANT	\N	PRESENT	1
571500	571496	19643A	PARTICIPANT	\N	PRESENT	1
571501	571496	19575F	PARTICIPANT	\N	PRESENT	1
571503	571502	19693L	PARTICIPANT	\N	PRESENT	1
571504	571502	19643A	PARTICIPANT	\N	PRESENT	1
571505	571502	20134Y	PARTICIPANT	\N	PRESENT	1
571506	571502	19575F	PARTICIPANT	\N	PRESENT	1
572413	572013	86034E	PARTICIPANT	\N	PRESENT	0
572414	570847	20068G	PARTICIPANT	\N	PRESENT	0
572415	572013	20100N	PARTICIPANT	\N	PRESENT	0
572416	572013	20042V	PARTICIPANT	\N	PRESENT	0
572417	572013	14267Y	PARTICIPANT	\N	PRESENT	0
572418	572013	19820Y	PARTICIPANT	\N	PRESENT	0
572419	572013	19599P	PARTICIPANT	\N	PRESENT	0
572420	572013	04034C	PARTICIPANT	\N	PRESENT	0
572421	572013	20128B	PARTICIPANT	\N	PRESENT	0
572422	572013	19479G	PARTICIPANT	\N	PRESENT	0
572423	572013	14193X	PARTICIPANT	\N	PRESENT	0
572424	572013	14331P	PARTICIPANT	\N	PRESENT	0
572425	572013	08047A	PARTICIPANT	\N	PRESENT	0
572426	572013	19467C	PARTICIPANT	\N	PRESENT	0
572427	572013	20076G	PARTICIPANT	\N	PRESENT	0
572428	570847	14111D	PARTICIPANT	\N	PRESENT	0
572429	570847	14147R	PARTICIPANT	\N	PRESENT	0
572430	570847	04047H	PRESIDENT	0	PRESENT	0
572431	570847	19749K	PARTICIPANT	\N	PRESENT	0
572432	572013	20038A	PARTICIPANT	\N	PRESENT	0
572433	572013	19766L	PARTICIPANT	\N	PRESENT	0
572434	572013	20072C	PARTICIPANT	\N	PRESENT	0
572435	572013	19333N	PARTICIPANT	\N	PRESENT	0
572436	572013	14097Y	PARTICIPANT	\N	PRESENT	0
572437	572013	11054L	PARTICIPANT	\N	PRESENT	0
572438	572013	14083S	PARTICIPANT	\N	PRESENT	0
572439	570333	19697Q	PARTICIPANT	\N	PRESENT	0
572440	570333	01034P	PARTICIPANT	\N	PRESENT	0
572441	570333	11067R	PARTICIPANT	\N	PRESENT	0
572442	570333	19798U	PARTICIPANT	\N	PRESENT	0
572443	570333	11097X	PARTICIPANT	\N	PRESENT	0
572444	570333	19691J	PARTICIPANT	\N	PRESENT	0
572445	570333	19717B	PARTICIPANT	\N	PRESENT	0
572446	570333	11031D	PARTICIPANT	\N	PRESENT	0
572447	570333	14042U	PARTICIPANT	\N	PRESENT	0
572448	570333	14195A	PARTICIPANT	\N	PRESENT	0
572449	570333	04043D	PARTICIPANT	\N	PRESENT	0
572450	570333	10006L	PRESIDENT	0	PRESENT	0
572451	570333	19591F	PARTICIPANT	\N	PRESENT	0
572452	572013	20144B	PARTICIPANT	\N	PRESENT	0
572453	572013	08061X	PARTICIPANT	\N	PRESENT	0
572454	572013	14255U	PARTICIPANT	\N	PRESENT	0
572455	572013	19421M	PARTICIPANT	\N	PRESENT	0
572456	570847	14259Y	PARTICIPANT	\N	PRESENT	0
572457	570847	14231L	PARTICIPANT	\N	PRESENT	0
572458	572013	04042C	PARTICIPANT	\N	PRESENT	0
572459	572013	04033B	PARTICIPANT	\N	PRESENT	0
572460	572013	19701S	PARTICIPANT	\N	PRESENT	0
572461	572013	14059S	PARTICIPANT	\N	PRESENT	0
572462	572013	19507S	PARTICIPANT	\N	PRESENT	0
572463	572013	19399H	PARTICIPANT	\N	PRESENT	0
572495	572013	14089Y	PARTICIPANT	\N	PRESENT	0
572498	572013	20024T	PARTICIPANT	\N	PRESENT	0
572499	572013	20048C	PARTICIPANT	\N	PRESENT	0
572500	572013	14038Y	PARTICIPANT	\N	PRESENT	0
572501	572013	14225N	PARTICIPANT	\N	PRESENT	0
572534	572013	19415P	PARTICIPANT	\N	PRESENT	0
572507	572013	17023S	PARTICIPANT	\N	PRESENT	0
572508	570333	19713W	PARTICIPANT	\N	PRESENT	0
572509	570333	11045K	PARTICIPANT	\N	PRESENT	0
572510	570333	20040T	PARTICIPANT	\N	PRESENT	0
572511	570333	19663E	PARTICIPANT	\N	PRESENT	0
572512	570333	14026U	PARTICIPANT	\N	PRESENT	0
572513	570333	14213J	PARTICIPANT	\N	PRESENT	0
572514	570333	14217N	PARTICIPANT	\N	PRESENT	0
572515	570333	04057K	PARTICIPANT	\N	EXCUSE	0
572516	570333	19295A	PARTICIPANT	\N	EXCUSE	0
572517	572013	19533U	PARTICIPANT	\N	PRESENT	0
572518	572013	19689Q	PARTICIPANT	\N	PRESENT	0
572519	572013	19749K	PARTICIPANT	\N	PRESENT	0
572520	572013	04035D	PARTICIPANT	\N	PRESENT	0
572521	572013	04085P	PARTICIPANT	\N	PRESENT	0
572522	572013	14030Q	PARTICIPANT	\N	PRESENT	0
572523	572013	20068G	PARTICIPANT	\N	PRESENT	0
572524	572013	12028B	PARTICIPANT	\N	PRESENT	0
572525	572013	19673G	PARTICIPANT	\N	PRESENT	0
572528	572013	19709B	PARTICIPANT	\N	PRESENT	0
572529	572013	14327T	PARTICIPANT	\N	PRESENT	0
572530	572013	19503N	PARTICIPANT	\N	PRESENT	0
572531	572013	20082E	PARTICIPANT	\N	PRESENT	0
572532	572013	20020P	PARTICIPANT	\N	PRESENT	0
572533	572013	19619A	PARTICIPANT	\N	PRESENT	0
572535	572013	19713W	PARTICIPANT	\N	PRESENT	0
572536	572013	20040T	PARTICIPANT	\N	PRESENT	0
572537	572013	14195A	PARTICIPANT	\N	PRESENT	0
572538	572013	11097X	PARTICIPANT	\N	PRESENT	0
572539	572013	11067R	PARTICIPANT	\N	PRESENT	0
572540	572013	19691J	PARTICIPANT	\N	PRESENT	0
572541	572013	14071N	PARTICIPANT	\N	PRESENT	0
572542	572013	20126Y	PARTICIPANT	\N	PRESENT	0
572543	572013	19585H	PARTICIPANT	\N	PRESENT	0
572544	572013	19441R	PARTICIPANT	\N	PRESENT	0
572545	572013	11053K	PARTICIPANT	\N	PRESENT	0
572546	572013	20034V	PARTICIPANT	\N	PRESENT	0
572547	572013	14031R	PARTICIPANT	\N	PRESENT	0
572548	572013	20052X	PARTICIPANT	\N	PRESENT	0
572549	572013	19758L	PARTICIPANT	\N	PRESENT	0
572558	572013	11090Q	PARTICIPANT	\N	PRESENT	0
572551	572013	14217N	PARTICIPANT	\N	PRESENT	0
572555	572013	14257W	PARTICIPANT	\N	PRESENT	0
572553	572013	14169X	PARTICIPANT	\N	PRESENT	0
572554	572013	14053L	PARTICIPANT	\N	PRESENT	0
572556	572013	19413M	PARTICIPANT	\N	PRESENT	0
572557	572013	19549D	PARTICIPANT	\N	PRESENT	0
572559	570849	19954N	PARTICIPANT	\N	PRESENT	0
572560	570849	11026G	PARTICIPANT	\N	PRESENT	0
572561	570849	14147R	PARTICIPANT	\N	PRESENT	0
572562	570849	04047H	PRESIDENT	0	PRESENT	0
584565	583457	99004R	PARTICIPANT	\N	PRESENT	0
584566	583457	07029T	PARTICIPANT	\N	EXCUSE	0
584570	583469	19443T	PARTICIPANT	\N	PRESENT	0
584571	583469	12041X	PARTICIPANT	\N	PRESENT	0
584572	583469	20072C	PARTICIPANT	\N	PRESENT	0
584573	583469	04034C	PARTICIPANT	\N	PRESENT	0
584574	583469	01058X	PARTICIPANT	\N	PRESENT	1
584575	583469	16685X	PARTICIPANT	\N	PRESENT	0
584576	583469	11066Q	PARTICIPANT	\N	PRESENT	0
584577	583469	08056B	PARTICIPANT	\N	PRESENT	0
584578	583469	12028B	PARTICIPANT	\N	PRESENT	0
584579	583469	14055N	PARTICIPANT	\N	PRESENT	0
584580	583469	19421M	PARTICIPANT	\N	PRESENT	0
584581	583469	19709B	PARTICIPANT	\N	PRESENT	0
584582	583469	14193X	PARTICIPANT	\N	PRESENT	0
584583	583469	19347U	PARTICIPANT	\N	PRESENT	0
584584	583469	97011G	PARTICIPANT	\N	PRESENT	0
584585	583469	08061X	PARTICIPANT	\N	PRESENT	0
584586	583469	08047A	PARTICIPANT	\N	PRESENT	0
584587	583469	14059S	PARTICIPANT	\N	PRESENT	0
584588	583469	14097Y	PARTICIPANT	\N	PRESENT	0
584589	583469	04035D	PARTICIPANT	\N	PRESENT	0
584590	583469	14133K	PARTICIPANT	\N	PRESENT	0
584591	583469	08069G	PARTICIPANT	\N	PRESENT	0
584592	583469	11041F	PARTICIPANT	\N	PRESENT	1
584593	583469	20042V	PARTICIPANT	\N	PRESENT	0
584594	583469	01024M	PARTICIPANT	\N	PRESENT	0
584595	583469	19319Q	PARTICIPANT	\N	PRESENT	1
584596	583469	14105F	PARTICIPANT	\N	PRESENT	0
584597	583469	98018T	PRESIDENT	0	PRESENT	0
584598	583469	14267Y	PARTICIPANT	\N	PRESENT	0
584599	583469	11064N	PARTICIPANT	\N	PRESENT	0
584600	583469	11083R	PARTICIPANT	\N	PRESENT	0
584601	583469	14211G	PARTICIPANT	\N	PRESENT	0
584602	583469	14255U	PARTICIPANT	\N	PRESENT	0
584603	583469	17023S	PARTICIPANT	\N	PRESENT	0
584604	583469	01062T	PARTICIPANT	\N	EXCUSE	0
584605	583469	19565D	PARTICIPANT	\N	EXCUSE	0
584606	583469	04042C	PARTICIPANT	\N	EXCUSE	0
585207	583498	01024M	PARTICIPANT	\N	PRESENT	0
585208	583498	20062A	PARTICIPANT	\N	PRESENT	0
585209	583498	19581D	PARTICIPANT	\N	PRESENT	0
585210	583498	20090E	PARTICIPANT	\N	PRESENT	0
585211	583498	19671E	PARTICIPANT	\N	PRESENT	0
585212	583498	14059S	PARTICIPANT	\N	PRESENT	0
585213	583498	20054A	PARTICIPANT	\N	PRESENT	0
585214	583498	20124W	PARTICIPANT	\N	PRESENT	0
585215	583498	20020P	PARTICIPANT	\N	PRESENT	0
585216	583498	01058X	PARTICIPANT	\N	PRESENT	0
585217	583498	20076G	PARTICIPANT	\N	PRESENT	0
585218	583498	19251M	PARTICIPANT	\N	PRESENT	0
585219	583498	18083K	PARTICIPANT	\N	PRESENT	0
585220	583498	14147R	PARTICIPANT	\N	PRESENT	0
585221	583498	20038A	PARTICIPANT	\N	PRESENT	0
585222	583498	19739H	PARTICIPANT	\N	PRESENT	0
585223	583498	20040T	PARTICIPANT	\N	PRESENT	0
585224	583498	04092N	PARTICIPANT	\N	PRESENT	0
585225	583498	05012A	PARTICIPANT	\N	PRESENT	0
585226	583498	19637C	PARTICIPANT	\N	PRESENT	0
585227	583498	14107H	PARTICIPANT	\N	PRESENT	0
585228	583498	19295A	PARTICIPANT	\N	PRESENT	0
585229	583498	20046A	PARTICIPANT	\N	PRESENT	0
585230	583498	20144B	PARTICIPANT	\N	PRESENT	0
585231	583498	19693L	PARTICIPANT	\N	PRESENT	0
585232	583498	19515S	PARTICIPANT	\N	PRESENT	0
585233	583498	20030R	PARTICIPANT	\N	PRESENT	0
585234	583498	19563B	PARTICIPANT	\N	PRESENT	0
585235	583498	20104S	PARTICIPANT	\N	PRESENT	0
585236	583498	97011G	PARTICIPANT	\N	PRESENT	0
585237	583498	11097X	PARTICIPANT	\N	PRESENT	0
585238	583498	20052X	PARTICIPANT	\N	PRESENT	0
585239	583498	14042U	PARTICIPANT	\N	PRESENT	0
585240	583498	20132W	PARTICIPANT	\N	PRESENT	0
585241	583498	14026U	PARTICIPANT	\N	PRESENT	0
585242	583498	19383Y	PARTICIPANT	\N	PRESENT	0
585243	583498	19399H	PARTICIPANT	\N	PRESENT	0
585244	583498	19387D	PARTICIPANT	\N	PRESENT	0
585245	583498	14173T	PARTICIPANT	\N	PRESENT	0
585246	583498	19866P	PARTICIPANT	\N	PRESENT	0
585247	583498	11056N	PARTICIPANT	\N	PRESENT	0
585248	583498	19760E	PARTICIPANT	\N	PRESENT	0
585249	583498	19954N	PARTICIPANT	\N	PRESENT	0
585250	583498	20128B	PARTICIPANT	\N	PRESENT	0
585251	583498	20142Y	PARTICIPANT	\N	PRESENT	0
585205	583498	17737W	PARTICIPANT	\N	PRESENT	0
585206	583498	19749K	PARTICIPANT	\N	PRESENT	0
585252	583498	19333N	PARTICIPANT	\N	PRESENT	0
585254	583498	19443T	PARTICIPANT	\N	PRESENT	0
585255	585253	19611R	PRESIDENT	0	PRESENT	0
585256	585253	19593H	PARTICIPANT	\N	PRESENT	0
585257	585253	08017T	PARTICIPANT	\N	PRESENT	0
585258	585253	20084G	PARTICIPANT	\N	PRESENT	0
585259	585253	11104D	PARTICIPANT	\N	PRESENT	0
585260	585253	20132W	PARTICIPANT	\N	PRESENT	0
585261	585253	20142Y	PARTICIPANT	\N	PRESENT	0
585262	585253	20180F	PARTICIPANT	\N	PRESENT	0
585263	585253	20026V	PARTICIPANT	\N	PRESENT	0
585264	585253	19699S	PARTICIPANT	\N	PRESENT	0
585265	585253	20052X	PARTICIPANT	\N	PRESENT	0
585266	585253	20056C	PARTICIPANT	\N	PRESENT	0
585267	585253	92040Q	PARTICIPANT	\N	PRESENT	0
585268	585253	14123H	PARTICIPANT	\N	PRESENT	0
585269	585253	20152B	PARTICIPANT	\N	PRESENT	0
585270	585253	19758L	PARTICIPANT	\N	PRESENT	0
585271	585253	19573D	PARTICIPANT	\N	PRESENT	0
585272	583498	16685X	PARTICIPANT	\N	PRESENT	0
585273	585253	19399H	PARTICIPANT	\N	PRESENT	0
585274	585253	14030Q	PARTICIPANT	\N	PRESENT	0
585275	583498	20074E	PARTICIPANT	\N	PRESENT	0
585276	585253	07033P	PARTICIPANT	\N	PRESENT	0
585277	585253	19621T	PARTICIPANT	\N	PRESENT	0
585278	585253	19693L	PARTICIPANT	\N	PRESENT	0
585279	585253	14229S	PARTICIPANT	\N	PRESENT	0
585280	585253	19533U	PARTICIPANT	\N	PRESENT	0
585281	585253	04070G	PARTICIPANT	\N	PRESENT	0
585282	585253	04059M	PARTICIPANT	\N	PRESENT	0
585283	585253	20048C	PARTICIPANT	\N	PRESENT	0
585284	585253	14073Q	PARTICIPANT	\N	PRESENT	0
585285	585253	17589D	PARTICIPANT	\N	PRESENT	0
585286	585253	19643A	PARTICIPANT	\N	PRESENT	0
585287	585253	20138D	PARTICIPANT	\N	PRESENT	1
585288	585253	20124W	PARTICIPANT	\N	PRESENT	1
585289	585253	20112S	PARTICIPANT	\N	PRESENT	1
585290	585253	19651A	PARTICIPANT	\N	PRESENT	1
585291	585253	14109K	PARTICIPANT	\N	PRESENT	1
585292	585253	19735D	PARTICIPANT	\N	PRESENT	0
585293	585253	20134Y	PARTICIPANT	\N	PRESENT	1
585294	585253	20098N	PARTICIPANT	\N	PRESENT	1
585295	583498	20024T	PARTICIPANT	\N	PRESENT	0
585296	583498	14030Q	PARTICIPANT	\N	PRESENT	0
585297	583498	20120S	PARTICIPANT	\N	PRESENT	0
585299	583498	19691J	PARTICIPANT	\N	PRESENT	0
585300	583498	20108W	PARTICIPANT	\N	PRESENT	0
585302	583458	14327T	PARTICIPANT	\N	PRESENT	0
585303	583458	20086J	PARTICIPANT	\N	PRESENT	0
585304	583458	11048N	PARTICIPANT	\N	PRESENT	0
585305	583458	19479G	PARTICIPANT	\N	PRESENT	0
585306	583458	19647E	PARTICIPANT	\N	PRESENT	0
585307	583458	19711U	PARTICIPANT	\N	PRESENT	0
585308	583458	08034U	PARTICIPANT	\N	PRESENT	0
585309	583458	19687N	PARTICIPANT	\N	PRESENT	0
585310	583458	01057W	PARTICIPANT	\N	PRESENT	0
585311	583458	19689Q	PARTICIPANT	\N	PRESENT	0
585312	583458	20080C	PARTICIPANT	\N	PRESENT	0
585313	583458	20050V	PARTICIPANT	\N	PRESENT	0
585314	583458	11074Q	PARTICIPANT	\N	PRESENT	0
585315	583458	20044X	PARTICIPANT	\N	PRESENT	0
585316	583458	14225N	PRESIDENT	0	PRESENT	0
585317	583458	11110B	PARTICIPANT	\N	PRESENT	0
585318	583458	11040E	PARTICIPANT	\N	PRESENT	0
585319	583458	14083S	PARTICIPANT	\N	PRESENT	0
585320	583458	08009T	PARTICIPANT	\N	PRESENT	0
585321	583458	19349W	PARTICIPANT	\N	PRESENT	0
585322	583458	14121F	PARTICIPANT	\N	PRESENT	0
585323	583458	08010L	PARTICIPANT	\N	PRESENT	0
585324	583458	20022R	PARTICIPANT	\N	PRESENT	0
585325	583458	20126Y	PARTICIPANT	\N	PRESENT	0
585326	583498	20048C	PARTICIPANT	\N	PRESENT	0
585327	583498	20058E	PARTICIPANT	\N	PRESENT	0
585329	583498	19543W	PARTICIPANT	\N	PRESENT	0
585376	583498	20022R	PARTICIPANT	\N	PRESENT	0
570711	570710	19553Y	PARTICIPANT	\N	PRESENT	0
570712	570710	20132W	PARTICIPANT	\N	PRESENT	0
570713	570710	19681G	PARTICIPANT	\N	PRESENT	0
571863	571290	14133K	PARTICIPANT	\N	PRESENT	1
571864	571290	20042V	PARTICIPANT	\N	PRESENT	1
571865	571290	14105F	PARTICIPANT	\N	PRESENT	1
571886	571290	14255U	PARTICIPANT	\N	PRESENT	0
571887	571290	04042C	PRESIDENT	0	PRESENT	0
571888	571290	14267Y	PARTICIPANT	\N	PRESENT	0
571889	571290	19565D	PARTICIPANT	\N	EXCUSE	0
571890	571290	11064N	PARTICIPANT	\N	PRESENT	1
571891	571290	08069G	PARTICIPANT	\N	PRESENT	0
571892	571290	12041X	PARTICIPANT	\N	PRESENT	0
571893	571290	16685X	PARTICIPANT	\N	PRESENT	0
571894	571290	08047A	PARTICIPANT	\N	PRESENT	0
571895	571290	14193X	PARTICIPANT	\N	PRESENT	0
571896	571290	11054L	PARTICIPANT	\N	PRESENT	0
571897	571290	19421M	PARTICIPANT	\N	PRESENT	0
571898	571290	01058X	PARTICIPANT	\N	PRESENT	0
571899	571290	01062T	PARTICIPANT	\N	EXCUSE	0
571900	571290	04034C	PARTICIPANT	\N	PRESENT	1
571910	570332	10006L	PRESIDENT	0	PRESENT	0
571932	570332	04057K	PARTICIPANT	\N	EXCUSE	0
571933	570332	19760E	PARTICIPANT	\N	PRESENT	1
571934	570332	19723Y	PARTICIPANT	\N	PRESENT	1
571935	570332	17965H	PARTICIPANT	\N	PRESENT	0
571936	570332	08045X	PARTICIPANT	\N	PRESENT	1
571937	570332	20090E	PARTICIPANT	\N	PRESENT	1
571938	570332	19697Q	PARTICIPANT	\N	PRESENT	0
571939	570332	14223L	PARTICIPANT	\N	PRESENT	1
571940	570332	20066E	PARTICIPANT	\N	PRESENT	1
571941	570332	11103C	PARTICIPANT	\N	PRESENT	1
571942	570332	04043D	PARTICIPANT	\N	PRESENT	1
571943	570332	19591F	PARTICIPANT	\N	PRESENT	1
571944	570332	19553Y	PARTICIPANT	\N	PRESENT	1
571945	570332	19657G	PARTICIPANT	\N	PRESENT	1
571948	570332	19295A	PARTICIPANT	\N	EXCUSE	0
574228	574227	20072C	PARTICIPANT	\N	PRESENT	0
578902	577328	19489J	PARTICIPANT	\N	PRESENT	0
578903	577328	20110Q	PARTICIPANT	\N	PRESENT	0
578904	577328	04047H	PRESIDENT	0	PRESENT	0
578905	577328	14259Y	PARTICIPANT	\N	PRESENT	0
578906	577328	19749K	PARTICIPANT	\N	PRESENT	0
578907	578173	99004R	PARTICIPANT	\N	PRESENT	0
581863	579464	11031D	PARTICIPANT	\N	PRESENT	0
581864	579464	19367Y	PARTICIPANT	\N	PRESENT	0
581865	579464	14213J	PARTICIPANT	\N	PRESENT	1
581866	579464	14217N	PARTICIPANT	\N	PRESENT	0
581867	579464	20130U	PARTICIPANT	\N	PRESENT	1
581868	579464	01034P	PARTICIPANT	\N	PRESENT	0
581869	579464	19713W	PARTICIPANT	\N	PRESENT	0
581870	579464	11045K	PARTICIPANT	\N	PRESENT	0
581871	579464	08045X	PARTICIPANT	\N	PRESENT	1
581872	579464	19301E	PARTICIPANT	\N	PRESENT	1
581873	579464	19715Y	PARTICIPANT	\N	PRESENT	0
581874	579464	19717B	PARTICIPANT	\N	PRESENT	0
581875	579464	20148F	PARTICIPANT	\N	PRESENT	0
581876	579464	11103C	PARTICIPANT	\N	PRESENT	1
581877	579464	19657G	PARTICIPANT	\N	PRESENT	0
581878	579464	04043D	PARTICIPANT	\N	PRESENT	1
581879	579464	19760E	PARTICIPANT	\N	PRESENT	0
581880	579464	20074E	PARTICIPANT	\N	EXCUSE	0
581881	579464	14147R	PARTICIPANT	\N	PRESENT	1
581882	579464	11033F	PARTICIPANT	\N	PRESENT	1
581883	579464	14179A	PARTICIPANT	\N	PRESENT	1
581884	579464	20128B	PARTICIPANT	\N	PRESENT	1
581885	579464	04085P	PARTICIPANT	\N	PRESENT	1
581886	579464	19749K	PARTICIPANT	\N	PRESENT	1
581890	579464	14231L	PARTICIPANT	\N	PRESENT	0
581898	579584	01048V	PARTICIPANT	\N	PRESENT	0
581900	579584	01058X	PARTICIPANT	\N	PRESENT	0
581926	581925	14097Y	PARTICIPANT	\N	PRESENT	0
581928	581927	14097Y	PARTICIPANT	\N	PRESENT	0
581929	581927	11083R	PARTICIPANT	\N	PRESENT	0
581966	579244	19717B	PARTICIPANT	\N	PRESENT	1
581967	579244	20066E	PARTICIPANT	\N	PRESENT	1
581968	579244	11103C	PARTICIPANT	\N	PRESENT	1
581969	579244	04043D	PARTICIPANT	\N	PRESENT	1
581970	579244	19760E	PARTICIPANT	\N	PRESENT	1
581971	579244	20248J	PARTICIPANT	\N	PRESENT	1
581972	579244	14042U	PARTICIPANT	\N	PRESENT	1
581973	579244	19723Y	PARTICIPANT	\N	PRESENT	1
581974	579244	14355X	PARTICIPANT	\N	PRESENT	1
581975	579244	19569H	PARTICIPANT	\N	PRESENT	1
581976	579244	11067R	PARTICIPANT	\N	PRESENT	1
581977	579244	20130U	PARTICIPANT	\N	PRESENT	1
581978	579244	11097X	PARTICIPANT	\N	PRESENT	1
581979	579244	01034P	PARTICIPANT	\N	PRESENT	1
581980	579244	14213J	PARTICIPANT	\N	PRESENT	1
581981	579244	19798U	PARTICIPANT	\N	PRESENT	1
581982	579244	20172F	PARTICIPANT	\N	PRESENT	1
581983	579244	08045X	PARTICIPANT	\N	PRESENT	1
583162	583161	11083R	PARTICIPANT	\N	PRESENT	0
583164	583163	14133K	PARTICIPANT	\N	PRESENT	0
583165	583163	14097Y	PARTICIPANT	\N	PRESENT	1
583167	583166	14097Y	PARTICIPANT	\N	PRESENT	0
583168	583166	14133K	PARTICIPANT	\N	PRESENT	0
583170	583169	14097Y	PARTICIPANT	\N	PRESENT	0
583171	583169	14133K	PARTICIPANT	\N	PRESENT	0
583173	583172	19647E	PARTICIPANT	\N	PRESENT	1
583174	583172	14225N	PRESIDENT	0	PRESENT	1
583175	583172	11048N	PARTICIPANT	\N	PRESENT	1
583176	583172	19689Q	PARTICIPANT	\N	PRESENT	1
583177	583172	19741B	PARTICIPANT	\N	PRESENT	1
583178	583172	19479G	PARTICIPANT	\N	PRESENT	1
583179	583172	19349W	PARTICIPANT	\N	PRESENT	1
583180	583172	11074Q	PARTICIPANT	\N	PRESENT	1
583181	583172	01057W	PARTICIPANT	\N	PRESENT	1
583182	583172	14327T	PARTICIPANT	\N	PRESENT	1
583183	583172	20044X	PARTICIPANT	\N	PRESENT	1
583186	583185	11053K	PARTICIPANT	\N	PRESENT	0
583187	583184	11053K	PARTICIPANT	\N	PRESENT	0
583189	583188	11083R	PARTICIPANT	\N	PRESENT	0
583190	583188	17367Q	PARTICIPANT	\N	PRESENT	0
583191	583188	19593H	PARTICIPANT	\N	PRESENT	0
583192	583188	19333N	PARTICIPANT	\N	PRESENT	0
583193	583188	19533U	PARTICIPANT	\N	PRESENT	1
583194	583188	07004J	PARTICIPANT	\N	PRESENT	1
583195	583188	20082E	PARTICIPANT	\N	PRESENT	1
583241	583157	11074Q	PARTICIPANT	\N	PRESENT	0
583242	583158	11074Q	PARTICIPANT	\N	PRESENT	0
583243	583158	18193Q	PARTICIPANT	\N	PRESENT	0
583244	583158	14255U	PARTICIPANT	\N	PRESENT	0
583341	582768	11097X	PARTICIPANT	\N	PRESENT	1
583342	582768	04057K	PARTICIPANT	\N	PRESENT	1
583343	582768	20130U	PARTICIPANT	\N	PRESENT	1
583344	582768	14223L	PARTICIPANT	\N	PRESENT	1
583345	582768	19723Y	PARTICIPANT	\N	PRESENT	1
583346	582768	17965H	PARTICIPANT	\N	PRESENT	1
583347	582768	19301E	PARTICIPANT	\N	PRESENT	1
583348	582768	19657G	PARTICIPANT	\N	PRESENT	1
583349	582768	20172F	PARTICIPANT	\N	PRESENT	1
583350	582768	14026U	PARTICIPANT	\N	PRESENT	1
583351	582768	19713W	PARTICIPANT	\N	PRESENT	1
583352	582768	20066E	PARTICIPANT	\N	PRESENT	1
583354	582768	04092N	PARTICIPANT	\N	PRESENT	0
583355	582768	20090E	PARTICIPANT	\N	PRESENT	0
583356	582768	11031D	PARTICIPANT	\N	PRESENT	0
583357	582768	04043D	PARTICIPANT	\N	PRESENT	0
583378	583152	14083S	PARTICIPANT	\N	PRESENT	1
583376	583152	11040E	PARTICIPANT	\N	EXCUSE	0
583377	583152	20116W	PARTICIPANT	\N	PRESENT	1
583379	583152	19545Y	PARTICIPANT	\N	PRESENT	1
583380	583152	20070A	PARTICIPANT	\N	PRESENT	1
583381	583152	11074Q	PARTICIPANT	\N	PRESENT	1
583382	583152	11110B	PARTICIPANT	\N	PRESENT	1
583383	583152	20126Y	PARTICIPANT	\N	PRESENT	1
583384	583152	19711U	PARTICIPANT	\N	PRESENT	1
583385	583152	11012A	PARTICIPANT	\N	PRESENT	1
583386	583152	19687N	PARTICIPANT	\N	PRESENT	1
583752	583455	14033T	PARTICIPANT	\N	PRESENT	1
583754	583455	20082E	PARTICIPANT	\N	PRESENT	1
584459	584458	19954N	PARTICIPANT	\N	PRESENT	0
584460	584458	19643A	PARTICIPANT	\N	PRESENT	0
584461	584458	18083K	PARTICIPANT	\N	PRESENT	0
584462	584458	20124W	PARTICIPANT	\N	PRESENT	0
594516	593436	11010L	PARTICIPANT	\N	EXCUSE	0
594529	594525	19679N	PARTICIPANT	\N	PRESENT	0
594530	594525	20248J	PARTICIPANT	\N	PRESENT	0
595716	595715	14215L	PARTICIPANT	\N	PRESENT	0
595723	590971	20066E	PARTICIPANT	\N	PRESENT	0
595724	590970	20066E	PARTICIPANT	\N	PRESENT	0
595845	594909	20022R	PARTICIPANT	\N	PRESENT	0
595846	594909	11056N	PARTICIPANT	\N	PRESENT	0
595847	594909	14215L	PARTICIPANT	\N	PRESENT	0
595848	594909	20074E	PARTICIPANT	\N	PRESENT	0
595849	594909	19673G	PARTICIPANT	\N	PRESENT	0
595850	594909	08018U	PARTICIPANT	\N	PRESENT	0
595851	594909	07004J	PARTICIPANT	\N	PRESENT	0
595852	594909	14179A	PARTICIPANT	\N	PRESENT	0
595853	594909	95063L	PARTICIPANT	\N	PRESENT	0
595854	594909	01028R	PARTICIPANT	\N	PRESENT	0
595991	595600	19760E	PARTICIPANT	\N	PRESENT	0
595992	595600	19675J	PARTICIPANT	\N	PRESENT	0
595993	595600	19527W	PARTICIPANT	\N	PRESENT	0
595994	595348	14225N	PARTICIPANT	\N	EXCUSE	0
595995	595600	14259Y	PARTICIPANT	\N	PRESENT	0
595996	595600	20136B	PARTICIPANT	\N	PRESENT	0
595997	595600	20026V	PARTICIPANT	\N	PRESENT	0
595998	595600	20102Q	PARTICIPANT	\N	PRESENT	0
595999	595600	19631V	PARTICIPANT	\N	PRESENT	0
596000	595600	19782L	PARTICIPANT	\N	PRESENT	0
596001	595348	08010L	PARTICIPANT	\N	PRESENT	0
596002	595600	19441R	PARTICIPANT	\N	PRESENT	0
596003	595600	01025N	PARTICIPANT	\N	PRESENT	0
596004	595600	20048C	PARTICIPANT	\N	PRESENT	0
596005	595600	19673G	PARTICIPANT	\N	PRESENT	0
596006	595600	20094J	PARTICIPANT	\N	PRESENT	0
596007	595600	14147R	PARTICIPANT	\N	PRESENT	0
596008	595600	20054A	PARTICIPANT	\N	PRESENT	0
596083	595601	08018U	PARTICIPANT	\N	PRESENT	0
596084	595601	19515S	PARTICIPANT	\N	PRESENT	0
596085	595601	19679N	PARTICIPANT	\N	PRESENT	0
596086	595601	14251Q	PARTICIPANT	\N	PRESENT	0
596087	595601	14215L	PARTICIPANT	\N	PRESENT	0
596088	595601	14173T	PARTICIPANT	\N	PRESENT	0
596089	595601	04085P	PARTICIPANT	\N	PRESENT	0
596090	595601	19569H	PARTICIPANT	\N	PRESENT	0
596091	595601	14207L	PARTICIPANT	\N	PRESENT	0
596092	595601	20094J	PARTICIPANT	\N	PRESENT	0
596093	595601	20128B	PARTICIPANT	\N	PRESENT	0
596094	595601	10006L	PARTICIPANT	\N	PRESENT	0
596095	595601	17779H	PARTICIPANT	\N	PRESENT	0
596096	595601	20034V	PARTICIPANT	\N	PRESENT	0
596097	595601	19251M	PARTICIPANT	\N	PRESENT	0
596098	595601	20028X	PARTICIPANT	\N	PRESENT	0
596099	595601	14211G	PARTICIPANT	\N	PRESENT	0
596100	595601	14033T	PARTICIPANT	\N	PRESENT	0
596101	595601	19760E	PARTICIPANT	\N	PRESENT	0
596102	595601	19758L	PARTICIPANT	\N	PRESENT	0
596103	595601	20142Y	PARTICIPANT	\N	PRESENT	0
596104	595601	11067R	PARTICIPANT	\N	PRESENT	0
596105	595601	19575F	PARTICIPANT	\N	PRESENT	0
596106	595601	20062A	PARTICIPANT	\N	PRESENT	0
596107	595601	19675J	PARTICIPANT	\N	PRESENT	0
596108	595601	20032T	PARTICIPANT	\N	PRESENT	0
596109	595601	18083K	PARTICIPANT	\N	PRESENT	0
596110	595601	20026V	PARTICIPANT	\N	PRESENT	0
596111	595601	19467C	PARTICIPANT	\N	PRESENT	0
596112	595601	19798U	PARTICIPANT	\N	PRESENT	0
596113	595601	20054A	PARTICIPANT	\N	PRESENT	0
596114	595601	20072C	PARTICIPANT	\N	PRESENT	0
596115	595601	19583F	PARTICIPANT	\N	PRESENT	0
596116	595601	08045X	PARTICIPANT	\N	PRESENT	0
596117	595601	19631V	PARTICIPANT	\N	PRESENT	0
596146	595348	11110B	PARTICIPANT	\N	PRESENT	1
596147	595348	19671E	PARTICIPANT	\N	PRESENT	1
596148	595348	20050V	PARTICIPANT	\N	PRESENT	1
596258	593569	20084G	PARTICIPANT	\N	PRESENT	0
596547	596545	20064C	PARTICIPANT	\N	PRESENT	0
596549	596548	19667J	PARTICIPANT	\N	PRESENT	0
596550	596548	20064C	PARTICIPANT	\N	PRESENT	0
596410	596409	14073Q	PARTICIPANT	\N	PRESENT	0
596411	596409	18083K	PARTICIPANT	\N	PRESENT	0
596412	596409	19515S	PARTICIPANT	\N	PRESENT	0
596413	596409	14147R	PARTICIPANT	\N	PRESENT	0
596414	596409	04045F	PARTICIPANT	\N	PRESENT	0
596415	596409	20126Y	PARTICIPANT	\N	PRESENT	0
596416	596409	20056C	PARTICIPANT	\N	PRESENT	0
596417	595622	20040T	PARTICIPANT	\N	PRESENT	0
596418	596409	19369B	PARTICIPANT	\N	PRESENT	0
596419	596409	19723Y	PARTICIPANT	\N	PRESENT	0
596420	596409	14083S	PARTICIPANT	\N	PRESENT	0
596421	594912	17965H	PARTICIPANT	\N	PRESENT	0
596442	594912	14281W	PARTICIPANT	\N	PRESENT	0
596498	594912	19663E	PARTICIPANT	\N	PRESENT	0
596499	594912	04057K	PARTICIPANT	\N	PRESENT	0
596546	596545	19701S	PARTICIPANT	\N	PRESENT	0
596551	596548	19701S	PARTICIPANT	\N	PRESENT	0
596552	596548	19762G	PARTICIPANT	\N	PRESENT	0
596557	596553	19758L	PARTICIPANT	\N	PRESENT	0
596555	596553	20152B	PARTICIPANT	\N	PRESENT	0
596556	596553	19621T	PARTICIPANT	\N	PRESENT	0
596558	596553	19057M	PARTICIPANT	\N	PRESENT	1
596559	596553	20264J	PARTICIPANT	\N	PRESENT	0
596560	596553	19693L	PARTICIPANT	\N	PRESENT	0
596561	596553	20132W	PARTICIPANT	\N	PRESENT	0
596562	596553	14123H	PARTICIPANT	\N	PRESENT	1
596563	596553	19399H	PARTICIPANT	\N	PRESENT	0
596564	596553	19611R	PRESIDENT	0	PRESENT	0
596565	596553	20052X	PARTICIPANT	\N	PRESENT	0
596081	595601	11045K	PARTICIPANT	\N	PRESENT	0
596082	595348	19647E	PARTICIPANT	\N	PRESENT	0
596566	596553	20142Y	PARTICIPANT	\N	PRESENT	0
596567	596553	04070G	PARTICIPANT	\N	PRESENT	0
596568	596553	19593H	PARTICIPANT	\N	PRESENT	0
596569	596553	19533U	PARTICIPANT	\N	PRESENT	0
596570	596553	14229S	PARTICIPANT	\N	PRESENT	0
596571	596553	20026V	PARTICIPANT	\N	PRESENT	0
596572	596553	20058E	PARTICIPANT	\N	PRESENT	0
596573	596553	19651A	PARTICIPANT	\N	PRESENT	1
596574	596553	20048C	PARTICIPANT	\N	PRESENT	0
596575	596553	20112S	PARTICIPANT	\N	PRESENT	1
596576	596553	11104D	PARTICIPANT	\N	PRESENT	1
596577	596553	19573D	PARTICIPANT	\N	PRESENT	0
596578	596553	11043H	PARTICIPANT	\N	PRESENT	0
596579	596553	20084G	PARTICIPANT	\N	PRESENT	0
596580	596553	19527W	PARTICIPANT	\N	PRESENT	0
596581	596553	14073Q	PARTICIPANT	\N	PRESENT	0
596582	596553	08012N	PARTICIPANT	\N	PRESENT	0
596583	596553	11083R	PARTICIPANT	\N	PRESENT	0
596585	595352	11110B	PARTICIPANT	\N	PRESENT	1
596586	595352	12016W	PARTICIPANT	\N	PRESENT	1
596587	595352	19671E	PARTICIPANT	\N	PRESENT	1
596588	595352	08011M	PARTICIPANT	\N	PRESENT	1
596589	595352	20050V	PARTICIPANT	\N	PRESENT	1
596590	595352	11012A	PARTICIPANT	\N	PRESENT	1
596591	595352	20150Y	PARTICIPANT	\N	PRESENT	1
596592	595352	19479G	PARTICIPANT	\N	PRESENT	1
596593	595352	14173T	PARTICIPANT	\N	PRESENT	1
596594	595352	14329V	PARTICIPANT	\N	PRESENT	1
596597	596596	14189C	PARTICIPANT	\N	PRESENT	0
596599	596598	14189C	PARTICIPANT	\N	PRESENT	0
596601	596600	14189C	PARTICIPANT	\N	PRESENT	0
596603	596602	19711U	PARTICIPANT	\N	PRESENT	0
596605	596604	11053K	PARTICIPANT	\N	PRESENT	0
596607	596606	11053K	PARTICIPANT	\N	PRESENT	0
596609	596608	19711U	PARTICIPANT	\N	PRESENT	1
596613	596612	11043H	PARTICIPANT	\N	PRESENT	0
596614	596612	14189C	PARTICIPANT	\N	PRESENT	0
596615	596612	19631V	PARTICIPANT	\N	PRESENT	0
596616	596612	20112S	PARTICIPANT	\N	PRESENT	0
596617	596612	20024T	PARTICIPANT	\N	PRESENT	0
596618	596612	20138D	PARTICIPANT	\N	PRESENT	0
596619	596612	20152B	PARTICIPANT	\N	PRESENT	0
596620	596612	20132W	PARTICIPANT	\N	PRESENT	0
596621	596612	19725B	PARTICIPANT	\N	PRESENT	0
596622	596612	19399H	PARTICIPANT	\N	PRESENT	0
596623	596612	14073Q	PARTICIPANT	\N	PRESENT	0
596624	596612	19699S	PARTICIPANT	\N	PRESENT	0
596625	596612	20052X	PARTICIPANT	\N	PRESENT	0
596626	596612	08012N	PARTICIPANT	\N	PRESENT	0
596627	596612	14147R	PARTICIPANT	\N	PRESENT	0
596628	596612	20096L	PARTICIPANT	\N	PRESENT	0
596629	596612	19533U	PARTICIPANT	\N	PRESENT	0
571573	571572	05008E	PARTICIPANT	\N	PRESENT	0
571574	571572	11053K	PARTICIPANT	\N	PRESENT	0
571575	571572	01028R	PARTICIPANT	\N	PRESENT	0
572731	571447	14030Q	PARTICIPANT	\N	PRESENT	0
572732	571447	19719D	PARTICIPANT	\N	PRESENT	0
573459	573458	17779H	PARTICIPANT	\N	PRESENT	0
573461	573460	17779H	PARTICIPANT	\N	PRESENT	0
573463	573462	01058X	PARTICIPANT	\N	PRESENT	0
573464	573462	20066E	PARTICIPANT	\N	EXCUSE	0
573721	573711	14189C	PARTICIPANT	\N	PRESENT	0
573722	573711	10006L	PARTICIPANT	\N	PRESENT	0
573723	573711	19683J	PRESIDENT	0	PRESENT	0
573724	573711	99004R	PARTICIPANT	\N	PRESENT	0
573730	573711	19699S	PARTICIPANT	\N	PRESENT	0
573731	573711	19705W	PARTICIPANT	\N	PRESENT	0
573738	573711	14229S	PARTICIPANT	\N	PRESENT	0
573742	573711	11031D	PARTICIPANT	\N	EXCUSE	0
573743	573711	19447X	PARTICIPANT	\N	EXCUSE	0
573744	573711	19563B	PARTICIPANT	\N	EXCUSE	0
573748	573711	04092N	PARTICIPANT	\N	EXCUSE	0
573750	573711	11033F	PARTICIPANT	\N	EXCUSE	0
574036	573327	20024T	PARTICIPANT	\N	PRESENT	0
574038	573327	17367Q	PARTICIPANT	\N	PRESENT	0
574039	573327	20080C	PARTICIPANT	\N	PRESENT	0
574040	573327	19719D	PARTICIPANT	\N	PRESENT	0
574041	573327	20056C	PARTICIPANT	\N	PRESENT	0
574042	573327	14109K	PARTICIPANT	\N	PRESENT	0
574043	573327	20142Y	PARTICIPANT	\N	PRESENT	0
574044	572961	20062A	PARTICIPANT	\N	PRESENT	1
574045	572961	19507S	PARTICIPANT	\N	PRESENT	0
574046	573327	19729F	PARTICIPANT	\N	PRESENT	0
574047	573327	14111D	PARTICIPANT	\N	PRESENT	0
574048	573327	14147R	PARTICIPANT	\N	PRESENT	0
574049	573327	19399H	PARTICIPANT	\N	PRESENT	0
574050	573327	99004R	PARTICIPANT	\N	PRESENT	0
574051	573327	20134Y	PARTICIPANT	\N	PRESENT	0
574052	573327	11053K	PARTICIPANT	\N	PRESENT	0
574053	573327	14189C	PARTICIPANT	\N	PRESENT	0
574054	573327	14151M	PARTICIPANT	\N	PRESENT	0
574055	572961	19563B	PARTICIPANT	\N	PRESENT	1
574057	573327	97011G	PARTICIPANT	\N	PRESENT	0
574058	573327	19573D	PARTICIPANT	\N	PRESENT	0
574059	573327	08073C	PARTICIPANT	\N	PRESENT	0
574061	573327	14055N	PARTICIPANT	\N	PRESENT	0
574062	573327	14021P	PARTICIPANT	\N	PRESENT	0
574063	573327	20028X	PARTICIPANT	\N	PRESENT	0
574064	573327	20048C	PARTICIPANT	\N	PRESENT	0
574066	573327	14001X	PARTICIPANT	\N	PRESENT	0
574067	573327	19467C	PARTICIPANT	\N	PRESENT	0
574068	573327	11027H	PARTICIPANT	\N	PRESENT	0
574069	573327	19749K	PARTICIPANT	\N	PRESENT	0
574070	573327	19479G	PARTICIPANT	\N	PRESENT	0
572563	570849	19749K	PARTICIPANT	\N	PRESENT	0
572564	570849	14231L	PARTICIPANT	\N	PRESENT	0
572565	570849	14021P	PARTICIPANT	\N	PRESENT	0
572730	571447	19758L	PARTICIPANT	\N	PRESENT	0
574071	573327	19758L	PARTICIPANT	\N	PRESENT	0
574072	573327	19565D	PARTICIPANT	\N	PRESENT	0
574088	573327	14179A	PARTICIPANT	\N	PRESENT	0
574086	573327	14083S	PARTICIPANT	\N	PRESENT	0
574087	573327	20132W	PARTICIPANT	\N	PRESENT	0
574089	573327	11012A	PARTICIPANT	\N	PRESENT	0
574090	573327	14223L	PARTICIPANT	\N	PRESENT	0
574091	573327	19367Y	PARTICIPANT	\N	PRESENT	0
574092	573327	19760E	PARTICIPANT	\N	PRESENT	0
574093	573327	14097Y	PARTICIPANT	\N	PRESENT	0
574094	573327	20034V	PARTICIPANT	\N	PRESENT	0
574095	573327	19441R	PARTICIPANT	\N	PRESENT	0
574096	573327	14169X	PARTICIPANT	\N	PRESENT	0
574097	573327	14225N	PARTICIPANT	\N	PRESENT	0
574098	573327	20052X	PARTICIPANT	\N	PRESENT	0
574099	573327	19782L	PARTICIPANT	\N	PRESENT	0
574100	573327	11090Q	PARTICIPANT	\N	PRESENT	0
574101	573327	20070A	PARTICIPANT	\N	PRESENT	0
574102	573327	14033T	PARTICIPANT	\N	PRESENT	0
574103	573327	19747H	PARTICIPANT	\N	PRESENT	0
574104	573327	20090E	PARTICIPANT	\N	PRESENT	0
574148	574105	14053L	PARTICIPANT	\N	PRESENT	0
574149	574105	04047H	PARTICIPANT	\N	PRESENT	0
574150	574105	14267Y	PARTICIPANT	\N	PRESENT	0
574151	574105	14026U	PARTICIPANT	\N	PRESENT	0
574152	574105	11033F	PARTICIPANT	\N	PRESENT	0
574153	574105	20038A	PARTICIPANT	\N	PRESENT	0
574154	574105	11026G	PARTICIPANT	\N	PRESENT	0
574155	574105	19467C	PARTICIPANT	\N	PRESENT	0
574156	574105	20034V	PARTICIPANT	\N	PRESENT	0
574157	574105	01024M	PARTICIPANT	\N	PRESENT	0
574158	574105	14215L	PARTICIPANT	\N	PRESENT	0
574159	574105	11066Q	PARTICIPANT	\N	PRESENT	0
574160	574105	07004J	PARTICIPANT	\N	PRESENT	0
574161	574105	20132W	PARTICIPANT	\N	PRESENT	0
574162	574105	19565D	PARTICIPANT	\N	PRESENT	0
574163	574105	01028R	PARTICIPANT	\N	PRESENT	0
574164	574105	19749K	PARTICIPANT	\N	PRESENT	0
574165	574105	19533U	PARTICIPANT	\N	PRESENT	0
574166	574105	19593H	PARTICIPANT	\N	PRESENT	0
574167	574105	20048C	PARTICIPANT	\N	PRESENT	0
574168	574105	20090E	PARTICIPANT	\N	PRESENT	0
574169	574105	20128B	PARTICIPANT	\N	PRESENT	0
574170	574105	19553Y	PARTICIPANT	\N	PRESENT	0
574171	574105	14033T	PARTICIPANT	\N	PRESENT	0
574172	574105	20094J	PARTICIPANT	\N	PRESENT	0
574173	574105	04008A	PARTICIPANT	\N	PRESENT	0
574174	574105	14147R	PARTICIPANT	\N	PRESENT	0
574175	574105	19673G	PARTICIPANT	\N	PRESENT	0
574176	574105	14021P	PARTICIPANT	\N	PRESENT	0
574177	574105	19573D	PARTICIPANT	\N	PRESENT	0
574178	574105	20052X	PARTICIPANT	\N	PRESENT	0
574179	574105	12041X	PARTICIPANT	\N	PRESENT	0
574180	574105	11056N	PARTICIPANT	\N	PRESENT	0
574181	574105	19760E	PARTICIPANT	\N	PRESENT	0
574182	574105	14083S	PARTICIPANT	\N	PRESENT	0
574183	574105	11097X	PARTICIPANT	\N	PRESENT	0
574184	574105	04070G	PARTICIPANT	\N	PRESENT	0
574185	574105	20142Y	PARTICIPANT	\N	PRESENT	0
574186	574105	14111D	PARTICIPANT	\N	PRESENT	0
574187	574105	14069U	PARTICIPANT	\N	PRESENT	0
574146	574105	11070L	PARTICIPANT	\N	PRESENT	0
574147	574105	04085P	PARTICIPANT	\N	PRESENT	0
574188	574105	18083K	PARTICIPANT	\N	PRESENT	0
574189	574105	20114U	PARTICIPANT	\N	PRESENT	0
574190	574105	19719D	PARTICIPANT	\N	PRESENT	0
574033	572961	20086J	PARTICIPANT	\N	PRESENT	0
574034	573327	08015R	PARTICIPANT	\N	PRESENT	0
574191	574105	19611R	PARTICIPANT	\N	PRESENT	0
574192	574105	14213J	PARTICIPANT	\N	PRESENT	0
574193	574105	20110Q	PARTICIPANT	\N	PRESENT	0
574194	574105	20134Y	PARTICIPANT	\N	PRESENT	0
574195	574105	19782L	PARTICIPANT	\N	PRESENT	0
574196	574105	19347U	PARTICIPANT	\N	PRESENT	0
574369	574298	19545Y	PARTICIPANT	\N	PRESENT	1
574370	574298	08010L	PARTICIPANT	\N	PRESENT	1
574367	574298	20126Y	PARTICIPANT	\N	PRESENT	1
574368	574298	20022R	PARTICIPANT	\N	PRESENT	1
574371	574298	20050V	PARTICIPANT	\N	PRESENT	1
574372	574298	20036X	PARTICIPANT	\N	PRESENT	1
574373	574298	19349W	PARTICIPANT	\N	PRESENT	1
574374	574298	19479G	PARTICIPANT	\N	PRESENT	1
574375	574298	14097Y	PARTICIPANT	\N	PRESENT	0
574376	574298	19729F	PARTICIPANT	\N	PRESENT	0
574377	574298	08047A	PARTICIPANT	\N	PRESENT	0
574629	574627	11065P	PARTICIPANT	\N	PRESENT	0
574855	574854	11097X	PARTICIPANT	\N	PRESENT	0
574856	574854	20088L	PARTICIPANT	\N	PRESENT	0
574857	574854	19515S	PARTICIPANT	\N	PRESENT	0
574858	574854	14329V	PARTICIPANT	\N	PRESENT	0
574859	574854	19782L	PARTICIPANT	\N	PRESENT	0
574860	574854	14357A	PARTICIPANT	\N	PRESENT	0
574861	574854	08056B	PARTICIPANT	\N	PRESENT	0
574862	574854	20090E	PARTICIPANT	\N	PRESENT	0
574863	574854	20028X	PARTICIPANT	\N	PRESENT	0
574864	574854	20040T	PARTICIPANT	\N	PRESENT	0
574865	574854	14207L	PARTICIPANT	\N	PRESENT	0
574866	574854	20114U	PARTICIPANT	\N	PRESENT	0
574867	574854	19467C	PARTICIPANT	\N	PRESENT	0
574868	574854	19798U	PARTICIPANT	\N	PRESENT	0
574869	574854	01024M	PARTICIPANT	\N	PRESENT	0
574870	574854	20058E	PARTICIPANT	\N	PRESENT	0
574871	574854	14213J	PARTICIPANT	\N	PRESENT	0
574872	574854	14109K	PARTICIPANT	\N	PRESENT	0
574873	574854	20084G	PARTICIPANT	\N	PRESENT	0
585393	583498	19723Y	PARTICIPANT	\N	PRESENT	0
585405	583498	14055N	PARTICIPANT	\N	PRESENT	0
585406	583498	20116W	PARTICIPANT	\N	PRESENT	0
585407	583498	14219Q	PARTICIPANT	\N	PRESENT	0
585412	583498	14357A	PARTICIPANT	\N	PRESENT	0
585413	583498	19369B	PARTICIPANT	\N	PRESENT	0
585414	583498	14217N	PARTICIPANT	\N	PRESENT	0
585415	583498	20060X	PARTICIPANT	\N	PRESENT	0
585416	583498	19725B	PARTICIPANT	\N	PRESENT	0
585417	583498	17965H	PARTICIPANT	\N	PRESENT	0
585418	583498	14021P	PARTICIPANT	\N	PRESENT	0
585419	583498	14151M	PARTICIPANT	\N	PRESENT	0
585420	583498	20084G	PARTICIPANT	\N	PRESENT	0
585421	583498	20110Q	PARTICIPANT	\N	PRESENT	0
585422	583498	20126Y	PARTICIPANT	\N	PRESENT	0
585423	583498	20152B	PARTICIPANT	\N	PRESENT	0
585499	583499	14021P	PARTICIPANT	\N	PRESENT	0
585500	583499	14179A	PARTICIPANT	\N	PRESENT	0
585514	583499	20084G	PARTICIPANT	\N	PRESENT	0
585502	583499	14195A	PARTICIPANT	\N	PRESENT	0
585503	583499	20110Q	PARTICIPANT	\N	PRESENT	0
585504	583499	20128B	PARTICIPANT	\N	PRESENT	0
585505	583499	14107H	PARTICIPANT	\N	PRESENT	0
585506	583499	04085P	PARTICIPANT	\N	PRESENT	0
585507	583499	19749K	PARTICIPANT	\N	PRESENT	0
585508	583499	14151M	PARTICIPANT	\N	PRESENT	0
585509	583499	20022R	PARTICIPANT	\N	PRESENT	0
585510	583499	19725B	PARTICIPANT	\N	PRESENT	0
585511	583499	14059S	PARTICIPANT	\N	PRESENT	0
585529	583499	20032T	PARTICIPANT	\N	PRESENT	0
585513	583499	20114U	PARTICIPANT	\N	PRESENT	0
585515	583499	20028X	PARTICIPANT	\N	PRESENT	0
585516	583499	19599P	PARTICIPANT	\N	PRESENT	0
585517	583499	04047H	PARTICIPANT	\N	PRESENT	0
585518	583499	14267Y	PARTICIPANT	\N	PRESENT	0
585519	583499	20248J	PARTICIPANT	\N	PRESENT	0
585520	583499	19367Y	PARTICIPANT	\N	PRESENT	0
585521	583499	19415P	PARTICIPANT	\N	PRESENT	0
585522	583499	19629C	PARTICIPANT	\N	PRESENT	0
585523	583499	19866P	PARTICIPANT	\N	PRESENT	0
585524	583499	20116W	PARTICIPANT	\N	PRESENT	0
585525	583499	19553Y	PARTICIPANT	\N	PRESENT	0
585526	583499	17965H	PARTICIPANT	\N	PRESENT	0
585527	583499	20152B	PARTICIPANT	\N	PRESENT	0
585528	583499	19443T	PARTICIPANT	\N	PRESENT	0
585530	583499	20038A	PARTICIPANT	\N	PRESENT	0
585531	583499	04045F	PARTICIPANT	\N	PRESENT	0
585532	583499	19954N	PARTICIPANT	\N	PRESENT	0
585533	583499	20180F	PARTICIPANT	\N	PRESENT	0
585534	583499	20026V	PARTICIPANT	\N	PRESENT	0
585535	583499	19413M	PARTICIPANT	\N	PRESENT	0
585536	583499	19631V	PARTICIPANT	\N	PRESENT	0
585537	583499	11077T	PARTICIPANT	\N	PRESENT	0
585538	583499	19758L	PARTICIPANT	\N	PRESENT	0
585539	583499	14215L	PARTICIPANT	\N	PRESENT	0
585540	583499	14053L	PARTICIPANT	\N	PRESENT	0
585541	583499	20124W	PARTICIPANT	\N	PRESENT	0
585542	583499	11048N	PARTICIPANT	\N	PRESENT	0
585543	583499	14231L	PARTICIPANT	\N	PRESENT	0
585544	583499	20024T	PARTICIPANT	\N	PRESENT	0
585545	583499	08010L	PARTICIPANT	\N	PRESENT	0
585546	583499	19691J	PARTICIPANT	\N	PRESENT	0
585547	583499	11056N	PARTICIPANT	\N	PRESENT	0
585548	583499	20086J	PARTICIPANT	\N	PRESENT	0
585549	583499	20030R	PARTICIPANT	\N	PRESENT	0
585550	583499	19347U	PARTICIPANT	\N	PRESENT	0
585551	583499	14030Q	PARTICIPANT	\N	PRESENT	0
585552	583499	20120S	PARTICIPANT	\N	PRESENT	0
585553	583499	20082E	PARTICIPANT	\N	PRESENT	0
585554	583499	20090E	PARTICIPANT	\N	PRESENT	0
585555	583499	20052X	PARTICIPANT	\N	PRESENT	0
585556	583499	14069U	PARTICIPANT	\N	PRESENT	0
585557	583499	14033T	PARTICIPANT	\N	PRESENT	0
585558	583499	19739H	PARTICIPANT	\N	PRESENT	0
585559	583499	18083K	PARTICIPANT	\N	PRESENT	0
585560	583499	19709B	PARTICIPANT	\N	PRESENT	0
585561	583499	14083S	PARTICIPANT	\N	PRESENT	0
585562	583499	19703U	PARTICIPANT	\N	PRESENT	0
585563	583499	07029T	PARTICIPANT	\N	PRESENT	0
585564	583499	20092G	PARTICIPANT	\N	PRESENT	0
585565	583499	20048C	PARTICIPANT	\N	PRESENT	0
585566	583499	14219Q	PARTICIPANT	\N	PRESENT	0
585567	583499	20126Y	PARTICIPANT	\N	PRESENT	0
585497	583499	99004R	PARTICIPANT	\N	PRESENT	0
585498	583499	20074E	PARTICIPANT	\N	PRESENT	0
585568	583499	14213J	PARTICIPANT	\N	PRESENT	0
585572	585569	20134Y	PARTICIPANT	\N	PRESENT	1
585573	585569	08012N	PARTICIPANT	\N	PRESENT	1
585574	585569	20036X	PARTICIPANT	\N	PRESENT	1
585575	585569	14030Q	PARTICIPANT	\N	PRESENT	1
585576	585569	20132W	PARTICIPANT	\N	PRESENT	1
585584	583500	14151M	PARTICIPANT	\N	PRESENT	0
585582	583500	01043Q	PARTICIPANT	\N	PRESENT	0
585583	583500	14195A	PARTICIPANT	\N	PRESENT	0
585585	583500	14173T	PARTICIPANT	\N	PRESENT	0
585589	583500	19667J	PARTICIPANT	\N	PRESENT	0
585590	583500	20038A	PARTICIPANT	\N	PRESENT	0
585591	583500	19713W	PARTICIPANT	\N	PRESENT	0
585592	583500	04085P	PARTICIPANT	\N	PRESENT	0
585593	583500	14215L	PARTICIPANT	\N	PRESENT	0
585600	583500	20090E	PARTICIPANT	\N	PRESENT	0
585595	583500	19758L	PARTICIPANT	\N	PRESENT	0
585596	583500	20110Q	PARTICIPANT	\N	PRESENT	0
585597	583500	19725B	PARTICIPANT	\N	PRESENT	0
585598	583500	20032T	PARTICIPANT	\N	PRESENT	0
585599	583500	14267Y	PARTICIPANT	\N	PRESENT	0
585601	583500	20128B	PARTICIPANT	\N	PRESENT	0
585602	583500	20116W	PARTICIPANT	\N	PRESENT	0
585603	583500	19866P	PARTICIPANT	\N	PRESENT	0
585604	583500	20248J	PARTICIPANT	\N	PRESENT	0
585605	583500	17965H	PARTICIPANT	\N	PRESENT	0
585606	583500	14179A	PARTICIPANT	\N	PRESENT	0
585607	583500	20132W	PARTICIPANT	\N	PRESENT	0
585608	583500	04045F	PARTICIPANT	\N	PRESENT	0
585609	583500	20024T	PARTICIPANT	\N	PRESENT	0
585610	583500	20086J	PARTICIPANT	\N	PRESENT	0
585612	583500	14021P	PARTICIPANT	\N	PRESENT	0
585615	583500	04047H	PARTICIPANT	\N	PRESENT	0
585616	583500	20074E	PARTICIPANT	\N	PRESENT	0
585617	583500	19749K	PARTICIPANT	\N	PRESENT	0
585618	583500	19691J	PARTICIPANT	\N	PRESENT	0
585619	583500	19739H	PARTICIPANT	\N	PRESENT	0
585621	583500	20124W	PARTICIPANT	\N	PRESENT	0
585622	583500	20152B	PARTICIPANT	\N	PRESENT	0
585623	583500	05012A	PARTICIPANT	\N	PRESENT	0
585628	583500	20030R	PARTICIPANT	\N	PRESENT	0
585630	583500	08061X	PARTICIPANT	\N	PRESENT	0
585631	583500	19543W	PARTICIPANT	\N	PRESENT	0
585632	583500	95063L	PARTICIPANT	\N	PRESENT	0
585633	583500	14069U	PARTICIPANT	\N	PRESENT	0
585634	583500	19629C	PARTICIPANT	\N	PRESENT	0
585635	583500	19631V	PARTICIPANT	\N	PRESENT	0
585636	583500	14133K	PARTICIPANT	\N	PRESENT	0
585638	583500	19467C	PARTICIPANT	\N	PRESENT	0
585639	583500	11056N	PARTICIPANT	\N	PRESENT	0
585642	583500	19533U	PARTICIPANT	\N	PRESENT	0
585643	583500	20082E	PARTICIPANT	\N	PRESENT	0
585644	583500	14073Q	PARTICIPANT	\N	PRESENT	0
585645	583500	19687N	PARTICIPANT	\N	PRESENT	0
585646	583500	20084G	PARTICIPANT	\N	PRESENT	0
585647	583500	08018U	PARTICIPANT	\N	PRESENT	0
585648	583500	20098N	PARTICIPANT	\N	PRESENT	0
585649	583500	20104S	PARTICIPANT	\N	PRESENT	0
585651	583500	14030Q	PARTICIPANT	\N	PRESENT	0
585656	583500	14033T	PARTICIPANT	\N	PRESENT	0
585654	583500	19349W	PARTICIPANT	\N	PRESENT	0
585655	583500	14213J	PARTICIPANT	\N	PRESENT	0
585657	583500	20114U	PARTICIPANT	\N	PRESENT	0
585660	583500	19699S	PARTICIPANT	\N	PRESENT	0
585661	583510	19333N	PARTICIPANT	\N	PRESENT	0
585662	583510	14331P	PRESIDENT	0	PRESENT	0
585663	583510	14097Y	PARTICIPANT	\N	PRESENT	0
585664	583510	04070G	PARTICIPANT	\N	PRESENT	0
585665	583510	19553Y	PARTICIPANT	\N	PRESENT	1
585666	583510	04035D	PARTICIPANT	\N	PRESENT	1
585667	583510	14073Q	PARTICIPANT	\N	PRESENT	0
585668	583510	19441R	PARTICIPANT	\N	PRESENT	0
585669	583510	12016W	PARTICIPANT	\N	PRESENT	1
585670	583510	11083R	PARTICIPANT	\N	PRESENT	0
585671	583510	14001X	PARTICIPANT	\N	PRESENT	0
585672	583510	14169X	PARTICIPANT	\N	PRESENT	1
585673	583500	20020P	PARTICIPANT	\N	PRESENT	0
580124	579805	04047H	PARTICIPANT	\N	PRESENT	0
580125	579805	20108W	PARTICIPANT	\N	PRESENT	0
580126	579805	07004J	PARTICIPANT	\N	PRESENT	0
580127	579805	20110Q	PARTICIPANT	\N	PRESENT	0
580128	579805	19489J	PARTICIPANT	\N	PRESENT	0
580129	579805	95063L	PARTICIPANT	\N	PRESENT	0
580130	579805	11056N	PARTICIPANT	\N	PRESENT	0
580131	579805	14107H	PARTICIPANT	\N	PRESENT	0
580804	580803	19643A	PARTICIPANT	\N	PRESENT	1
580805	580803	20152B	PARTICIPANT	\N	PRESENT	1
580809	580803	20134Y	PARTICIPANT	\N	PRESENT	1
580812	580803	19691J	PARTICIPANT	\N	PRESENT	1
580813	580803	20106U	PARTICIPANT	\N	PRESENT	1
580814	580803	14073Q	PARTICIPANT	\N	PRESENT	1
580815	580803	04057K	PARTICIPANT	\N	PRESENT	1
580818	580803	19527W	PARTICIPANT	\N	PRESENT	1
583364	583224	11043H	PARTICIPANT	\N	PRESENT	0
583365	583224	08012N	PARTICIPANT	\N	PRESENT	1
583366	583224	14030Q	PARTICIPANT	\N	PRESENT	1
583367	583224	19533U	PARTICIPANT	\N	PRESENT	1
583368	583224	20152B	PARTICIPANT	\N	PRESENT	0
583369	583225	11043H	PARTICIPANT	\N	PRESENT	0
583370	583225	20152B	PARTICIPANT	\N	PRESENT	0
584463	584458	14123H	PARTICIPANT	\N	PRESENT	0
584464	584458	19691J	PARTICIPANT	\N	PRESENT	1
584466	584458	20034V	PARTICIPANT	\N	EXCUSE	0
584467	584458	20134Y	PARTICIPANT	\N	EXCUSE	0
584468	584458	04070G	PARTICIPANT	\N	EXCUSE	0
584469	584458	14073Q	PARTICIPANT	\N	PRESENT	0
584470	584458	08017T	PARTICIPANT	\N	PRESENT	0
584471	584458	04057K	PARTICIPANT	\N	PRESENT	0
584472	584458	20098N	PARTICIPANT	\N	PRESENT	0
584473	584458	19527W	PARTICIPANT	\N	PRESENT	0
584474	584458	20114U	PARTICIPANT	\N	PRESENT	0
584751	583497	20054A	PARTICIPANT	\N	PRESENT	0
585887	585886	04085P	PARTICIPANT	\N	PRESENT	0
585888	585886	05008E	PARTICIPANT	\N	PRESENT	0
585889	585886	04047H	PARTICIPANT	\N	PRESENT	0
585890	585886	20104S	PARTICIPANT	\N	PRESENT	0
585891	585886	14217N	PARTICIPANT	\N	PRESENT	0
585892	585886	14042U	PARTICIPANT	\N	PRESENT	0
585893	585886	19347U	PARTICIPANT	\N	PRESENT	0
585894	585886	14026U	PARTICIPANT	\N	PRESENT	0
585895	585886	11048N	PARTICIPANT	\N	PRESENT	0
585896	585886	14021P	PARTICIPANT	\N	PRESENT	0
585897	585886	99004R	PARTICIPANT	\N	PRESENT	0
585898	585886	19611R	PARTICIPANT	\N	PRESENT	0
585899	585886	12041X	PARTICIPANT	\N	PRESENT	0
585900	585886	01043Q	PARTICIPANT	\N	PRESENT	0
585901	585886	14219Q	PARTICIPANT	\N	PRESENT	0
585902	585886	14251Q	PARTICIPANT	\N	PRESENT	0
585903	585886	11085T	PARTICIPANT	\N	PRESENT	0
585904	585886	01060R	PARTICIPANT	\N	PRESENT	0
585905	585886	08073C	PARTICIPANT	\N	PRESENT	0
585906	585886	08061X	PARTICIPANT	\N	PRESENT	0
585907	585886	14193X	PARTICIPANT	\N	PRESENT	0
585908	585886	14225N	PARTICIPANT	\N	PRESENT	0
585909	585886	11012A	PARTICIPANT	\N	PRESENT	0
585910	585886	04033B	PARTICIPANT	\N	PRESENT	0
585911	585886	11045K	PARTICIPANT	\N	PRESENT	0
586308	586307	08010L	PARTICIPANT	\N	PRESENT	0
586312	586311	20080C	PARTICIPANT	\N	PRESENT	0
586314	586313	20080C	PARTICIPANT	\N	PRESENT	0
586318	586316	99004R	PARTICIPANT	\N	PRESENT	0
586320	586319	08009T	PARTICIPANT	\N	PRESENT	0
586321	586319	20044X	PARTICIPANT	\N	PRESENT	0
586529	586527	11041F	PARTICIPANT	\N	PRESENT	0
586411	586384	19629C	PARTICIPANT	\N	PRESENT	0
586404	586402	20108W	PARTICIPANT	\N	PRESENT	0
586408	586386	19629C	PARTICIPANT	\N	PRESENT	0
586504	586503	11027H	PARTICIPANT	\N	PRESENT	0
586506	586503	07004J	PARTICIPANT	\N	PRESENT	0
586507	586503	10015M	PARTICIPANT	\N	PRESENT	0
586508	586503	20070A	PARTICIPANT	\N	PRESENT	0
586528	586527	95063L	PARTICIPANT	\N	PRESENT	0
586531	586530	95063L	PARTICIPANT	\N	PRESENT	0
586532	586530	14255U	PARTICIPANT	\N	PRESENT	0
586533	586530	19621T	PARTICIPANT	\N	PRESENT	0
586534	586530	20056C	PARTICIPANT	\N	PRESENT	0
586536	586535	95063L	PARTICIPANT	\N	PRESENT	0
586537	586535	14255U	PARTICIPANT	\N	PRESENT	0
586538	586535	19621T	PARTICIPANT	\N	PRESENT	0
586865	585653	19569H	PARTICIPANT	\N	PRESENT	1
586866	585653	19697Q	PARTICIPANT	\N	PRESENT	1
586867	585653	20130U	PARTICIPANT	\N	PRESENT	1
586868	585653	19760E	PARTICIPANT	\N	PRESENT	0
586869	585653	19553Y	PARTICIPANT	\N	PRESENT	0
586870	585653	17965H	PARTICIPANT	\N	PRESENT	0
586871	585653	19703U	PARTICIPANT	\N	PRESENT	0
586872	585653	19679N	PARTICIPANT	\N	PRESENT	0
586873	585653	19723Y	PARTICIPANT	\N	PRESENT	0
586874	585653	10006L	PRESIDENT	0	PRESENT	0
586875	585653	20090E	PARTICIPANT	\N	PRESENT	0
586876	585653	19415P	PARTICIPANT	\N	PRESENT	0
586877	585653	01028R	PARTICIPANT	\N	PRESENT	0
586878	585653	14053L	PARTICIPANT	\N	PRESENT	0
586879	585653	14071N	PARTICIPANT	\N	PRESENT	0
586880	585653	19691J	PARTICIPANT	\N	PRESENT	0
586881	585653	19713W	PARTICIPANT	\N	PRESENT	0
586882	585653	14042U	PARTICIPANT	\N	PRESENT	0
586883	585653	11026G	PARTICIPANT	\N	PRESENT	0
586884	585653	11033F	PARTICIPANT	\N	PRESENT	1
586885	585653	11097X	PARTICIPANT	\N	PRESENT	0
586886	585653	11072N	PARTICIPANT	\N	PRESENT	0
586887	585653	11067R	PARTICIPANT	\N	PRESENT	0
586888	585653	18193Q	PARTICIPANT	\N	PRESENT	0
586889	585653	14217N	PARTICIPANT	\N	PRESENT	0
586890	585653	04057K	PARTICIPANT	\N	EXCUSE	0
586891	585653	19591F	PARTICIPANT	\N	PRESENT	0
586892	585653	19729F	PARTICIPANT	\N	PRESENT	0
586893	585653	14026U	PARTICIPANT	\N	PRESENT	0
586894	585653	20110Q	PARTICIPANT	\N	PRESENT	1
586895	585653	19489J	PARTICIPANT	\N	PRESENT	1
586896	585653	14213J	PARTICIPANT	\N	PRESENT	0
586897	585653	19581D	PARTICIPANT	\N	PRESENT	1
586898	585653	19675J	PARTICIPANT	\N	PRESENT	1
586899	585653	19543W	PARTICIPANT	\N	PRESENT	1
586900	585653	20172F	PARTICIPANT	\N	PRESENT	0
586935	585653	20040T	PARTICIPANT	\N	PRESENT	0
586936	585653	19798U	PARTICIPANT	\N	PRESENT	1
586937	585653	19657G	PARTICIPANT	\N	PRESENT	1
586938	585653	14147R	PARTICIPANT	\N	PRESENT	1
586939	585653	19367Y	PARTICIPANT	\N	PRESENT	0
586940	585653	14223L	PARTICIPANT	\N	PRESENT	0
586941	585653	14195A	PARTICIPANT	\N	PRESENT	0
587030	585653	05008E	PARTICIPANT	\N	PRESENT	0
587031	585653	20128B	PARTICIPANT	\N	PRESENT	1
587032	585653	04047H	PARTICIPANT	\N	PRESENT	0
587033	585653	11056N	PARTICIPANT	\N	PRESENT	0
587034	585653	14215L	PARTICIPANT	\N	PRESENT	0
587035	585653	20074E	PARTICIPANT	\N	PRESENT	0
587036	585653	19447X	PARTICIPANT	\N	PRESENT	0
587037	585653	20108W	PARTICIPANT	\N	PRESENT	0
587038	585653	10015M	PARTICIPANT	\N	PRESENT	0
587039	585653	14151M	PARTICIPANT	\N	PRESENT	0
587040	585653	14001X	PARTICIPANT	\N	PRESENT	0
587041	585653	14231L	PARTICIPANT	\N	PRESENT	0
587042	585653	11085T	PARTICIPANT	\N	PRESENT	0
587043	585653	19749K	PARTICIPANT	\N	PRESENT	0
587044	585653	95063L	PARTICIPANT	\N	PRESENT	0
587045	585653	14107H	PARTICIPANT	\N	PRESENT	0
587046	585653	14111D	PARTICIPANT	\N	PRESENT	0
587051	585653	14021P	PARTICIPANT	\N	PRESENT	0
587089	585653	19301E	PARTICIPANT	\N	PRESENT	0
587091	585653	20066E	PARTICIPANT	\N	PRESENT	1
587092	585653	19295A	PARTICIPANT	\N	EXCUSE	0
587093	585653	11031D	PARTICIPANT	\N	PRESENT	0
587195	585578	19543W	PARTICIPANT	\N	PRESENT	1
587196	585578	20110Q	PARTICIPANT	\N	PRESENT	1
587197	585578	11033F	PARTICIPANT	\N	PRESENT	1
587198	585578	20128B	PARTICIPANT	\N	PRESENT	1
587199	585578	19489J	PARTICIPANT	\N	PRESENT	1
587200	585578	19581D	PARTICIPANT	\N	PRESENT	1
587201	585578	14147R	PARTICIPANT	\N	PRESENT	1
587202	585578	19675J	PARTICIPANT	\N	PRESENT	1
587203	585578	14026U	PARTICIPANT	\N	PRESENT	1
587204	585578	19569H	PARTICIPANT	\N	PRESENT	1
587205	585578	20066E	PARTICIPANT	\N	PRESENT	1
587206	585578	19697Q	PARTICIPANT	\N	PRESENT	1
593571	592948	14179A	PARTICIPANT	\N	PRESENT	0
593572	592948	19447X	PARTICIPANT	\N	PRESENT	0
593573	592948	14215L	PRESIDENT	0	PRESENT	0
593574	592948	14111D	PARTICIPANT	\N	PRESENT	0
593575	592948	20108W	PARTICIPANT	\N	PRESENT	0
593577	592948	20110Q	PARTICIPANT	\N	PRESENT	0
593578	592948	01028R	PARTICIPANT	\N	PRESENT	0
593581	592948	17737W	PARTICIPANT	\N	PRESENT	0
593585	593439	11045K	PARTICIPANT	\N	PRESENT	0
593594	593439	19447X	PARTICIPANT	\N	PRESENT	0
593595	593439	14179A	PARTICIPANT	\N	PRESENT	0
593596	593439	20110Q	PARTICIPANT	\N	PRESENT	0
593597	593439	07004J	PARTICIPANT	\N	PRESENT	0
593598	593439	11012A	PARTICIPANT	\N	PRESENT	0
593599	593439	01028R	PARTICIPANT	\N	PRESENT	0
593600	593439	95063L	PARTICIPANT	\N	PRESENT	0
593601	593439	14111D	PARTICIPANT	\N	PRESENT	0
593602	593439	04008A	PARTICIPANT	\N	PRESENT	0
593603	593439	20034V	PARTICIPANT	\N	PRESENT	0
593614	593439	14215L	PARTICIPANT	\N	PRESENT	0
593624	593439	19649G	PARTICIPANT	\N	PRESENT	0
593625	593439	04085P	PARTICIPANT	\N	PRESENT	0
593626	593439	14021P	PARTICIPANT	\N	PRESENT	0
593627	593439	11031D	PARTICIPANT	\N	PRESENT	0
593628	593439	20038A	PARTICIPANT	\N	PRESENT	0
593629	593439	14211G	PARTICIPANT	\N	PRESENT	0
593630	593439	20108W	PARTICIPANT	\N	PRESENT	0
593631	593439	19675J	PARTICIPANT	\N	PRESENT	0
593640	593439	19687N	PARTICIPANT	\N	PRESENT	0
593643	593439	19551W	PARTICIPANT	\N	PRESENT	0
593644	593439	19585H	PARTICIPANT	\N	PRESENT	0
593645	593439	01048V	PARTICIPANT	\N	PRESENT	0
593648	593439	19699S	PARTICIPANT	\N	PRESENT	0
593649	593439	20098N	PARTICIPANT	\N	PRESENT	0
593652	593439	20116W	PARTICIPANT	\N	PRESENT	0
593653	593439	14053L	PARTICIPANT	\N	PRESENT	0
593654	593439	14026U	PARTICIPANT	\N	PRESENT	0
593655	593439	14217N	PARTICIPANT	\N	PRESENT	0
593656	593439	19747H	PARTICIPANT	\N	PRESENT	0
593657	593439	11056N	PARTICIPANT	\N	PRESENT	0
593658	593439	19599P	PARTICIPANT	\N	PRESENT	0
593702	593701	14255U	PARTICIPANT	\N	PRESENT	0
593703	593701	20064C	PARTICIPANT	\N	PRESENT	0
593742	593741	14073Q	PARTICIPANT	\N	PRESENT	1
593743	593741	08012N	PARTICIPANT	\N	PRESENT	1
593744	593741	11043H	PARTICIPANT	\N	PRESENT	1
593796	593795	11040E	PARTICIPANT	\N	PRESENT	0
593797	591281	14026U	PARTICIPANT	\N	PRESENT	0
593798	591281	20130U	PARTICIPANT	\N	PRESENT	0
593804	593795	11026G	PARTICIPANT	\N	PRESENT	0
593806	593795	19503N	PARTICIPANT	\N	PRESENT	0
593807	593795	14059S	PARTICIPANT	\N	PRESENT	0
593808	593795	19713W	PARTICIPANT	\N	PRESENT	0
593816	593795	01048V	PARTICIPANT	\N	PRESENT	0
593817	593795	14133K	PARTICIPANT	\N	PRESENT	0
593818	593795	19563B	PARTICIPANT	\N	PRESENT	0
593823	593795	08056B	PARTICIPANT	\N	PRESENT	0
593908	593795	20054A	PARTICIPANT	\N	PRESENT	0
593909	593795	19349W	PARTICIPANT	\N	PRESENT	0
593915	590931	19659J	PARTICIPANT	\N	PRESENT	0
593980	591805	20142Y	PARTICIPANT	\N	PRESENT	0
593981	591805	14109K	PARTICIPANT	\N	PRESENT	0
593982	591805	14123H	PARTICIPANT	\N	PRESENT	0
593983	591805	19399H	PARTICIPANT	\N	PRESENT	0
593984	591805	14229S	PARTICIPANT	\N	PRESENT	0
593985	591805	20056C	PARTICIPANT	\N	PRESENT	0
593986	591805	19611R	PRESIDENT	0	PRESENT	0
593987	591805	19693L	PARTICIPANT	\N	PRESENT	0
593988	591805	20052X	PARTICIPANT	\N	PRESENT	0
593989	591805	19766L	PARTICIPANT	\N	PRESENT	1
593990	591805	11104D	PARTICIPANT	\N	PRESENT	0
593991	591805	20026V	PARTICIPANT	\N	PRESENT	0
593992	593547	14327T	PARTICIPANT	\N	PRESENT	0
593993	593547	14331P	PARTICIPANT	\N	PRESENT	0
593994	593547	11048N	PARTICIPANT	\N	PRESENT	0
593995	593547	19711U	PARTICIPANT	\N	PRESENT	0
593996	593547	20080C	PARTICIPANT	\N	PRESENT	0
593997	593547	20050V	PARTICIPANT	\N	PRESENT	0
593998	593547	14225N	PRESIDENT	0	PRESENT	0
593999	593547	11040E	PARTICIPANT	\N	PRESENT	0
594000	593547	07029T	PARTICIPANT	\N	PRESENT	0
594001	593547	20070A	PARTICIPANT	\N	PRESENT	0
594002	593547	08010L	PARTICIPANT	\N	PRESENT	0
594003	593547	20116W	PARTICIPANT	\N	PRESENT	0
594004	593547	19335Q	PARTICIPANT	\N	PRESENT	0
594005	593547	19762G	PARTICIPANT	\N	PRESENT	0
594006	593547	19531S	PARTICIPANT	\N	PRESENT	0
594007	593547	01057W	PARTICIPANT	\N	PRESENT	0
594008	593547	20044X	PARTICIPANT	\N	PRESENT	0
594009	593547	19741B	PARTICIPANT	\N	PRESENT	0
594010	591805	19593H	PARTICIPANT	\N	PRESENT	0
594011	591805	20132W	PARTICIPANT	\N	PRESENT	0
594012	591805	20134Y	PARTICIPANT	\N	PRESENT	0
594013	591805	19699S	PARTICIPANT	\N	PRESENT	0
594014	591805	20152B	PARTICIPANT	\N	PRESENT	0
594015	591805	14030Q	PARTICIPANT	\N	PRESENT	0
594016	591805	20180F	PARTICIPANT	\N	PRESENT	0
594017	591805	19573D	PARTICIPANT	\N	PRESENT	0
594018	591805	19758L	PARTICIPANT	\N	PRESENT	0
594019	591805	19621T	PARTICIPANT	\N	PRESENT	0
594021	593547	19479G	PARTICIPANT	\N	PRESENT	0
594022	593547	19689Q	PARTICIPANT	\N	PRESENT	0
594023	593547	19667J	PARTICIPANT	\N	PRESENT	0
594024	593547	11012A	PARTICIPANT	\N	PRESENT	0
594027	591805	19533U	PARTICIPANT	\N	PRESENT	0
594028	591805	19527W	PARTICIPANT	\N	PRESENT	0
594029	591805	19643A	PARTICIPANT	\N	PRESENT	0
594030	591805	14073Q	PARTICIPANT	\N	PRESENT	0
594031	591805	20048C	PARTICIPANT	\N	PRESENT	1
594033	591805	20084G	PARTICIPANT	\N	PRESENT	0
594034	593547	11110B	PARTICIPANT	\N	PRESENT	0
594035	593547	19647E	PARTICIPANT	\N	PRESENT	0
594038	591805	19651A	PARTICIPANT	\N	PRESENT	0
594039	591805	19057M	PARTICIPANT	\N	PRESENT	0
594040	591805	08012N	PARTICIPANT	\N	PRESENT	0
594041	591805	20058E	PARTICIPANT	\N	PRESENT	0
594042	591805	04059M	PARTICIPANT	\N	PRESENT	0
594043	590928	19685L	PARTICIPANT	\N	PRESENT	0
594044	590928	20038A	PARTICIPANT	\N	PRESENT	0
594045	590928	19619A	PARTICIPANT	\N	PRESENT	0
594247	593444	86034E	PARTICIPANT	\N	PRESENT	0
594249	593444	14105F	PARTICIPANT	\N	PRESENT	0
594250	593444	19565D	PARTICIPANT	\N	PRESENT	0
594251	593444	20266L	PARTICIPANT	\N	PRESENT	0
594252	593444	14097Y	PARTICIPANT	\N	PRESENT	0
594253	593444	19695N	PARTICIPANT	\N	PRESENT	0
594254	593444	14223L	PARTICIPANT	\N	PRESENT	0
594255	593444	20174H	PARTICIPANT	\N	PRESENT	0
594256	593444	20132W	PARTICIPANT	\N	PRESENT	0
594257	593444	20026V	PARTICIPANT	\N	PRESENT	0
594258	593444	19585H	PARTICIPANT	\N	PRESENT	0
594259	593444	04047H	PARTICIPANT	\N	PRESENT	0
594260	593444	11101A	PARTICIPANT	\N	PRESENT	0
594261	593444	19629C	PARTICIPANT	\N	PRESENT	0
594262	593444	08056B	PARTICIPANT	\N	PRESENT	0
594263	593444	14259Y	PARTICIPANT	\N	PRESENT	0
594264	593444	19739H	PARTICIPANT	\N	PRESENT	0
594265	593444	19479G	PARTICIPANT	\N	PRESENT	0
594266	593444	20024T	PARTICIPANT	\N	PRESENT	0
594267	593444	10015M	PARTICIPANT	\N	PRESENT	0
594268	593444	20252E	PARTICIPANT	\N	PRESENT	0
594269	593444	20074E	PARTICIPANT	\N	PRESENT	0
594270	593444	08047A	PARTICIPANT	\N	PRESENT	0
594271	593444	19515S	PARTICIPANT	\N	PRESENT	0
594272	593444	14267Y	PARTICIPANT	\N	PRESENT	0
594273	593444	11040E	PARTICIPANT	\N	PRESENT	0
594274	593444	19349W	PARTICIPANT	\N	PRESENT	0
594275	593444	19681G	PARTICIPANT	\N	PRESENT	0
594276	593444	14225N	PARTICIPANT	\N	PRESENT	0
594277	593444	20138D	PARTICIPANT	\N	PRESENT	0
594278	593444	19693L	PARTICIPANT	\N	PRESENT	0
594279	593444	19798U	PARTICIPANT	\N	PRESENT	0
594280	593444	14059S	PARTICIPANT	\N	PRESENT	0
594281	593444	12028B	PARTICIPANT	\N	PRESENT	0
594282	593444	19699S	PARTICIPANT	\N	PRESENT	0
594283	593444	14215L	PARTICIPANT	\N	PRESENT	0
594284	593444	19701S	PARTICIPANT	\N	PRESENT	0
594285	593444	14357A	PARTICIPANT	\N	PRESENT	0
594286	593444	20052X	PARTICIPANT	\N	PRESENT	0
594287	593444	19549D	PARTICIPANT	\N	PRESENT	0
594288	593444	19527W	PARTICIPANT	\N	PRESENT	0
571536	571534	19749K	PARTICIPANT	\N	PRESENT	0
571537	571534	19689Q	PARTICIPANT	\N	PRESENT	0
571538	571534	19687N	PARTICIPANT	\N	PRESENT	0
571566	571535	19575F	PRESIDENT	0	PRESENT	1
571541	571534	19551W	PARTICIPANT	\N	PRESENT	0
571543	571534	19685L	PARTICIPANT	\N	PRESENT	0
571544	571534	14026U	PARTICIPANT	\N	EXCUSE	0
571545	571534	20128B	PARTICIPANT	\N	EXCUSE	0
571546	571534	08045X	PARTICIPANT	\N	PRESENT	0
571547	571534	14217N	PARTICIPANT	\N	PRESENT	0
571548	571534	14041T	PARTICIPANT	\N	PRESENT	0
571549	571534	14357A	PRESIDENT	0	PRESENT	0
571550	571534	14038Y	PARTICIPANT	\N	PRESENT	0
571551	571534	19575F	PRESIDENT	1	PRESENT	1
571567	571535	19679N	PARTICIPANT	\N	PRESENT	1
571568	571535	14026U	PARTICIPANT	\N	EXCUSE	0
571569	571535	20128B	PARTICIPANT	\N	EXCUSE	0
571570	571535	14083S	PARTICIPANT	\N	PRESENT	0
571571	571535	19687N	PARTICIPANT	\N	PRESENT	0
571798	571299	04085P	PARTICIPANT	\N	PRESENT	1
571799	571299	17737W	PARTICIPANT	\N	PRESENT	1
571800	571299	14179A	PARTICIPANT	\N	PRESENT	1
571801	571299	07004J	PARTICIPANT	\N	PRESENT	1
571802	571299	19447X	PARTICIPANT	\N	PRESENT	1
571803	571299	19489J	PARTICIPANT	\N	PRESENT	1
571804	571299	10015M	PARTICIPANT	\N	PRESENT	1
571805	571299	20074E	PARTICIPANT	\N	EXCUSE	0
571962	570848	04085P	PARTICIPANT	\N	PRESENT	1
571963	570848	14179A	PARTICIPANT	\N	PRESENT	1
571964	570848	19447X	PARTICIPANT	\N	PRESENT	1
571965	570848	19729F	PARTICIPANT	\N	PRESENT	1
571966	570848	20074E	PARTICIPANT	\N	EXCUSE	0
572567	570849	19649G	PARTICIPANT	\N	PRESENT	1
574874	574854	20022R	PARTICIPANT	\N	PRESENT	0
574875	574854	08015R	PARTICIPANT	\N	PRESENT	0
574876	574854	20174H	PARTICIPANT	\N	PRESENT	0
574877	574854	20026V	PARTICIPANT	\N	PRESENT	0
574882	574881	19709B	PARTICIPANT	\N	PRESENT	1
575836	575835	05008E	PARTICIPANT	\N	PRESENT	0
575837	575835	11053K	PARTICIPANT	\N	PRESENT	0
575838	575835	01028R	PARTICIPANT	\N	PRESENT	0
575894	575865	01058X	PARTICIPANT	\N	PRESENT	0
575895	575865	19693L	PARTICIPANT	\N	PRESENT	0
575896	575865	19723Y	PARTICIPANT	\N	PRESENT	0
575898	575865	19709B	PARTICIPANT	\N	PRESENT	0
575901	575865	19735D	PARTICIPANT	\N	PRESENT	0
575904	575865	01048V	PARTICIPANT	\N	EXCUSE	0
576207	575244	14255U	PARTICIPANT	\N	PRESENT	1
576208	575233	19479G	PARTICIPANT	\N	PRESENT	0
576209	575067	14237S	PARTICIPANT	\N	PRESENT	0
576210	575067	20106U	PARTICIPANT	\N	PRESENT	0
576211	575067	19681G	PARTICIPANT	\N	PRESENT	0
576212	575067	20024T	PARTICIPANT	\N	PRESENT	0
576213	575067	20038A	PARTICIPANT	\N	PRESENT	0
576214	575067	19599P	PARTICIPANT	\N	PRESENT	0
576215	575067	05012A	PARTICIPANT	\N	PRESENT	0
576216	575244	16685X	PARTICIPANT	\N	PRESENT	0
576218	575244	17023S	PARTICIPANT	\N	PRESENT	0
576224	574984	19699S	PARTICIPANT	\N	PRESENT	0
576225	574984	19533U	PARTICIPANT	\N	PRESENT	0
576226	574984	20098N	PARTICIPANT	\N	PRESENT	0
576227	574984	19573D	PARTICIPANT	\N	PRESENT	0
576228	574984	20124W	PARTICIPANT	\N	PRESENT	0
576229	574984	20026V	PARTICIPANT	\N	PRESENT	0
576230	574984	19593H	PARTICIPANT	\N	PRESENT	0
576231	574984	19527W	PARTICIPANT	\N	PRESENT	0
576232	574984	20132W	PARTICIPANT	\N	PRESENT	0
576233	574984	19643A	PARTICIPANT	\N	PRESENT	0
576234	574984	20134Y	PARTICIPANT	\N	PRESENT	1
576235	574984	14073Q	PARTICIPANT	\N	PRESENT	0
576236	574984	19611R	PRESIDENT	0	PRESENT	0
576237	574984	20142Y	PARTICIPANT	\N	PRESENT	0
576238	574984	20048C	PARTICIPANT	\N	PRESENT	0
576239	574984	19693L	PARTICIPANT	\N	PRESENT	0
576240	574984	19399H	PARTICIPANT	\N	PRESENT	0
576298	575268	86034E	PARTICIPANT	\N	PRESENT	0
576242	574984	14030Q	PARTICIPANT	\N	PRESENT	0
576243	574984	20058E	PARTICIPANT	\N	PRESENT	0
576244	574984	20056C	PARTICIPANT	\N	PRESENT	0
576245	574984	19735D	PARTICIPANT	\N	PRESENT	1
576246	574984	14109K	PARTICIPANT	\N	PRESENT	1
576247	574984	11043H	PARTICIPANT	\N	PRESENT	0
576248	574984	19758L	PARTICIPANT	\N	PRESENT	0
576249	574984	20084G	PARTICIPANT	\N	PRESENT	0
576250	574984	19621T	PARTICIPANT	\N	PRESENT	0
576251	574984	11109J	PARTICIPANT	\N	EXCUSE	0
576252	574984	19651A	PARTICIPANT	\N	PRESENT	1
576299	575268	20028X	PARTICIPANT	\N	PRESENT	0
576300	575268	20106U	PARTICIPANT	\N	PRESENT	0
576301	575268	20088L	PARTICIPANT	\N	PRESENT	0
576302	575268	19725B	PARTICIPANT	\N	PRESENT	0
576303	575268	20174H	PARTICIPANT	\N	PRESENT	0
576304	575268	14207L	PARTICIPANT	\N	PRESENT	0
576305	575268	19629C	PARTICIPANT	\N	PRESENT	0
576306	575268	14107H	PARTICIPANT	\N	PRESENT	0
576307	575268	19681G	PARTICIPANT	\N	PRESENT	0
576308	575268	08017T	PARTICIPANT	\N	PRESENT	0
576309	575268	20024T	PARTICIPANT	\N	PRESENT	0
576310	575268	20054A	PARTICIPANT	\N	PRESENT	0
576311	575268	19673G	PARTICIPANT	\N	PRESENT	0
576312	575268	20098N	PARTICIPANT	\N	PRESENT	0
576313	575268	14237S	PARTICIPANT	\N	PRESENT	0
576314	575268	14030Q	PARTICIPANT	\N	PRESENT	0
576315	575268	20144B	PARTICIPANT	\N	PRESENT	0
576316	575268	19569H	PARTICIPANT	\N	PRESENT	0
576317	575268	19563B	PARTICIPANT	\N	PRESENT	0
576318	575268	07004J	PARTICIPANT	\N	PRESENT	0
576319	575268	20132W	PARTICIPANT	\N	PRESENT	0
576320	575268	20180F	PARTICIPANT	\N	PRESENT	0
576321	575268	14195A	PARTICIPANT	\N	PRESENT	0
576322	575268	14111D	PARTICIPANT	\N	PRESENT	0
576323	575268	17229F	PARTICIPANT	\N	PRESENT	0
576324	575268	14073Q	PARTICIPANT	\N	PRESENT	0
576325	575268	12028B	PARTICIPANT	\N	PRESENT	0
576326	575268	20082E	PARTICIPANT	\N	PRESENT	0
576327	575268	19766L	PARTICIPANT	\N	PRESENT	0
576328	575268	14169X	PARTICIPANT	\N	PRESENT	0
576329	575268	20076G	PARTICIPANT	\N	PRESENT	0
576330	575268	19333N	PARTICIPANT	\N	PRESENT	0
576331	575268	17779H	PARTICIPANT	\N	PRESENT	0
576332	575268	19683J	PARTICIPANT	\N	PRESENT	0
576333	575268	11041F	PARTICIPANT	\N	PRESENT	0
576334	575268	14151M	PARTICIPANT	\N	PRESENT	0
576335	575268	11056N	PARTICIPANT	\N	PRESENT	0
576336	575268	19760E	PARTICIPANT	\N	PRESENT	0
576337	575268	12041X	PARTICIPANT	\N	PRESENT	0
576338	575268	20084G	PARTICIPANT	\N	PRESENT	0
576339	575268	20116W	PARTICIPANT	\N	PRESENT	0
576340	575268	19387D	PARTICIPANT	\N	PRESENT	0
576341	575268	20142Y	PARTICIPANT	\N	PRESENT	0
576342	575268	14257W	PARTICIPANT	\N	PRESENT	0
576343	575268	20120S	PARTICIPANT	\N	PRESENT	0
576344	575268	19798U	PARTICIPANT	\N	PRESENT	0
576345	575268	99004R	PARTICIPANT	\N	PRESENT	0
576346	575268	92040Q	PARTICIPANT	\N	PRESENT	0
576347	575268	14033T	PARTICIPANT	\N	PRESENT	0
576348	575268	20056C	PARTICIPANT	\N	PRESENT	0
576349	575268	11080N	PARTICIPANT	\N	PRESENT	0
576350	575268	20138D	PARTICIPANT	\N	PRESENT	0
576351	575268	97011G	PARTICIPANT	\N	PRESENT	0
576352	575268	11066Q	PARTICIPANT	\N	PRESENT	0
576353	575268	20046A	PARTICIPANT	\N	PRESENT	0
576354	575268	19565D	PARTICIPANT	\N	PRESENT	0
576355	575268	20152B	PARTICIPANT	\N	PRESENT	0
576356	575268	19369B	PARTICIPANT	\N	PRESENT	0
576357	575268	19739H	PARTICIPANT	\N	PRESENT	0
576358	575268	19619A	PARTICIPANT	\N	PRESENT	0
576359	575268	19441R	PARTICIPANT	\N	PRESENT	0
576360	575268	04059M	PARTICIPANT	\N	PRESENT	0
576361	575268	19383Y	PARTICIPANT	\N	PRESENT	0
576362	575268	14187A	PARTICIPANT	\N	PRESENT	0
576363	575268	19866P	PARTICIPANT	\N	PRESENT	0
576364	575268	19719D	PARTICIPANT	\N	PRESENT	0
576365	575268	19758L	PARTICIPANT	\N	PRESENT	0
576366	575268	11065P	PARTICIPANT	\N	PRESENT	0
576367	575268	19820Y	PARTICIPANT	\N	PRESENT	0
576368	575268	20018V	PARTICIPANT	\N	PRESENT	0
576369	575268	20150Y	PARTICIPANT	\N	PRESENT	0
576370	575268	19651A	PARTICIPANT	\N	PRESENT	0
585674	583510	19701S	PARTICIPANT	\N	EXCUSE	0
585675	583510	14189C	PARTICIPANT	\N	EXCUSE	0
585676	583500	20094J	PARTICIPANT	\N	PRESENT	0
585677	583500	20048C	PARTICIPANT	\N	PRESENT	0
585678	583500	18083K	PARTICIPANT	\N	PRESENT	0
585679	583500	14042U	PARTICIPANT	\N	PRESENT	0
585680	583500	19954N	PARTICIPANT	\N	PRESENT	0
585681	583500	20026V	PARTICIPANT	\N	PRESENT	0
585682	583500	20056C	PARTICIPANT	\N	PRESENT	0
585699	583340	20090E	PARTICIPANT	\N	EXCUSE	0
585701	585700	20066E	PARTICIPANT	\N	PRESENT	0
585703	585702	19709B	PARTICIPANT	\N	EXCUSE	0
585705	585702	19735D	PARTICIPANT	\N	PRESENT	0
585706	585702	19723Y	PARTICIPANT	\N	PRESENT	0
585707	585702	01048V	PARTICIPANT	\N	PRESENT	0
585709	585702	01058X	PARTICIPANT	\N	PRESENT	0
585711	585702	11067R	PARTICIPANT	\N	PRESENT	0
585712	585702	19593H	PARTICIPANT	\N	PRESENT	0
585713	585702	19503N	PARTICIPANT	\N	EXCUSE	0
585714	585702	20066E	PARTICIPANT	\N	EXCUSE	0
586328	585577	14053L	PARTICIPANT	\N	PRESENT	0
586329	585577	14111D	PARTICIPANT	\N	PRESENT	0
586330	585577	20074E	PARTICIPANT	\N	PRESENT	0
586331	585577	10015M	PARTICIPANT	\N	PRESENT	0
586332	585577	19543W	PARTICIPANT	\N	PRESENT	0
586333	585577	04047H	PRESIDENT	0	PRESENT	0
586334	585577	19447X	PARTICIPANT	\N	PRESENT	0
586335	585577	05008E	PARTICIPANT	\N	PRESENT	0
586336	585577	14231L	PARTICIPANT	\N	PRESENT	0
586337	585577	14089Y	PARTICIPANT	\N	PRESENT	0
586338	585577	11056N	PARTICIPANT	\N	PRESENT	0
586339	585577	19954N	PARTICIPANT	\N	PRESENT	0
586340	585577	17737W	PARTICIPANT	\N	PRESENT	0
586341	585577	07004J	PARTICIPANT	\N	PRESENT	0
586342	585577	20110Q	PARTICIPANT	\N	PRESENT	0
586343	585577	11085T	PARTICIPANT	\N	PRESENT	0
586344	585577	14215L	PARTICIPANT	\N	PRESENT	0
586345	585577	11072N	PARTICIPANT	\N	PRESENT	0
586346	585744	19581D	PARTICIPANT	\N	PRESENT	0
586347	585744	08009T	PARTICIPANT	\N	PRESENT	0
586355	585744	20136B	PARTICIPANT	\N	PRESENT	0
586360	585744	19768N	PARTICIPANT	\N	PRESENT	0
586357	585744	19443T	PARTICIPANT	\N	PRESENT	0
586359	585744	14038Y	PARTICIPANT	\N	PRESENT	0
586361	585744	14033T	PARTICIPANT	\N	PRESENT	0
586362	585744	19679N	PARTICIPANT	\N	PRESENT	0
586363	585744	14217N	PARTICIPANT	\N	PRESENT	0
586364	585744	17965H	PARTICIPANT	\N	PRESENT	0
586365	585744	14083S	PARTICIPANT	\N	PRESENT	0
586366	585744	19593H	PARTICIPANT	\N	PRESENT	0
586367	585744	19782L	PARTICIPANT	\N	PRESENT	0
586368	585744	17229F	PARTICIPANT	\N	PRESENT	0
586369	585744	20030R	PARTICIPANT	\N	PRESENT	0
586372	585744	14053L	PARTICIPANT	\N	PRESENT	0
586373	585744	14107H	PARTICIPANT	\N	PRESENT	0
586383	585747	11045K	PARTICIPANT	\N	PRESENT	0
586388	585747	11031D	PARTICIPANT	\N	PRESENT	0
586389	585747	19683J	PARTICIPANT	\N	PRESENT	0
586390	585747	19760E	PARTICIPANT	\N	PRESENT	0
586391	585747	19515S	PARTICIPANT	\N	PRESENT	0
586381	586380	19673G	PARTICIPANT	\N	PRESENT	0
586382	586380	11026G	PARTICIPANT	\N	PRESENT	0
586392	585747	19301E	PARTICIPANT	\N	PRESENT	0
586393	585747	01048V	PARTICIPANT	\N	PRESENT	0
586394	585747	20130U	PARTICIPANT	\N	PRESENT	0
586486	585747	19715Y	PARTICIPANT	\N	PRESENT	0
586396	585747	14195A	PARTICIPANT	\N	PRESENT	0
586397	585747	19543W	PARTICIPANT	\N	PRESENT	0
586398	585747	19581D	PARTICIPANT	\N	PRESENT	0
586399	586374	14189C	PARTICIPANT	\N	PRESENT	0
586400	586374	11031D	PARTICIPANT	\N	PRESENT	0
586401	585747	14042U	PARTICIPANT	\N	PRESENT	0
586403	585747	19507S	PARTICIPANT	\N	PRESENT	0
586405	585747	10006L	PARTICIPANT	\N	PRESENT	0
586406	585747	20052X	PARTICIPANT	\N	PRESENT	0
586407	585747	01034P	PARTICIPANT	\N	PRESENT	0
586409	585747	19565D	PARTICIPANT	\N	PRESENT	0
586410	585747	20090E	PARTICIPANT	\N	PRESENT	0
586412	585747	14033T	PARTICIPANT	\N	PRESENT	0
586413	585747	11103C	PARTICIPANT	\N	PRESENT	0
586414	585747	11067R	PARTICIPANT	\N	PRESENT	0
586415	585747	20086J	PARTICIPANT	\N	PRESENT	0
586416	585747	11097X	PARTICIPANT	\N	PRESENT	0
586417	585747	19723Y	PARTICIPANT	\N	PRESENT	0
586418	585747	14038Y	PARTICIPANT	\N	PRESENT	0
586419	585747	14207L	PARTICIPANT	\N	PRESENT	0
586420	585747	19663E	PARTICIPANT	\N	PRESENT	0
586421	585747	19553Y	PARTICIPANT	\N	PRESENT	0
586422	585747	19563B	PARTICIPANT	\N	PRESENT	0
586423	585747	14217N	PARTICIPANT	\N	PRESENT	0
586424	585747	20140W	PARTICIPANT	\N	PRESENT	0
586425	585747	19569H	PARTICIPANT	\N	PRESENT	0
586426	585747	20024T	PARTICIPANT	\N	PRESENT	0
586427	585747	19647E	PARTICIPANT	\N	PRESENT	0
586428	585747	20248J	PARTICIPANT	\N	PRESENT	0
586429	585747	20048C	PARTICIPANT	\N	PRESENT	0
586430	585747	14211G	PARTICIPANT	\N	PRESENT	0
586431	585747	19399H	PARTICIPANT	\N	PRESENT	0
586432	585747	14121F	PARTICIPANT	\N	PRESENT	0
586433	585747	17779H	PARTICIPANT	\N	PRESENT	0
586434	585747	19415P	PARTICIPANT	\N	PRESENT	0
586435	585747	19467C	PARTICIPANT	\N	PRESENT	0
586436	585747	01025N	PARTICIPANT	\N	PRESENT	0
586437	585747	08028W	PARTICIPANT	\N	PRESENT	0
586438	585747	20098N	PARTICIPANT	\N	PRESENT	0
586439	585747	19758L	PARTICIPANT	\N	PRESENT	0
586440	585747	19691J	PARTICIPANT	\N	PRESENT	0
586441	585747	20122U	PARTICIPANT	\N	PRESENT	0
586442	585747	20046A	PARTICIPANT	\N	PRESENT	0
586443	585747	20064C	PARTICIPANT	\N	PRESENT	0
586444	585747	19367Y	PARTICIPANT	\N	PRESENT	0
586445	585747	20180F	PARTICIPANT	\N	PRESENT	0
586446	585747	95063L	PARTICIPANT	\N	PRESENT	0
586448	585747	95041E	PARTICIPANT	\N	PRESENT	0
586450	585747	14237S	PARTICIPANT	\N	PRESENT	0
586451	585747	19741B	PARTICIPANT	\N	PRESENT	0
586453	585747	14213J	PARTICIPANT	\N	PRESENT	0
586455	585747	20026V	PARTICIPANT	\N	PRESENT	0
586456	585747	20132W	PARTICIPANT	\N	PRESENT	0
586457	585747	19762G	PARTICIPANT	\N	PRESENT	0
586458	585747	19703U	PARTICIPANT	\N	PRESENT	0
586459	585747	20080C	PARTICIPANT	\N	PRESENT	0
586460	585747	14111D	PARTICIPANT	\N	PRESENT	0
586461	585747	04043D	PARTICIPANT	\N	PRESENT	0
586462	585747	14105F	PARTICIPANT	\N	PRESENT	0
586463	586374	19683J	PARTICIPANT	\N	PRESENT	0
586464	585747	20104S	PARTICIPANT	\N	PRESENT	0
586465	586374	19699S	PARTICIPANT	\N	PRESENT	0
586466	586374	20030R	PARTICIPANT	\N	PRESENT	0
586467	586374	19717B	PARTICIPANT	\N	PRESENT	0
586468	586374	14059S	PARTICIPANT	\N	PRESENT	0
586469	586374	17023S	PARTICIPANT	\N	PRESENT	0
586470	586374	19319Q	PARTICIPANT	\N	PRESENT	0
586471	586374	19691J	PARTICIPANT	\N	PRESENT	0
586472	586374	20028X	PARTICIPANT	\N	PRESENT	0
586473	586374	12016W	PARTICIPANT	\N	PRESENT	0
586474	586374	19659J	PARTICIPANT	\N	PRESENT	0
586475	586374	19295A	PARTICIPANT	\N	PRESENT	0
586476	586374	14207L	PARTICIPANT	\N	EXCUSE	0
586477	586374	10006L	PARTICIPANT	\N	EXCUSE	0
586478	586374	19447X	PARTICIPANT	\N	EXCUSE	0
586479	586374	99004R	PARTICIPANT	\N	EXCUSE	0
586480	586374	19697Q	PARTICIPANT	\N	EXCUSE	0
586481	585747	20054A	PARTICIPANT	\N	PRESENT	0
586482	585747	19629C	PARTICIPANT	\N	PRESENT	0
586483	585747	20108W	PARTICIPANT	\N	PRESENT	0
586484	585747	14215L	PARTICIPANT	\N	PRESENT	0
586485	585747	19768N	PARTICIPANT	\N	PRESENT	0
586487	585747	99004R	PARTICIPANT	\N	PRESENT	0
586488	585747	19711U	PARTICIPANT	\N	PRESENT	0
586489	585747	14031R	PARTICIPANT	\N	PRESENT	0
586491	585747	14229S	PARTICIPANT	\N	PRESENT	0
586492	585747	19591F	PARTICIPANT	\N	PRESENT	0
586493	585747	18083K	PARTICIPANT	\N	PRESENT	0
586494	585747	14259Y	PARTICIPANT	\N	PRESENT	0
586495	585747	14107H	PARTICIPANT	\N	PRESENT	0
586496	585747	19585H	PARTICIPANT	\N	PRESENT	0
586497	585747	19503N	PARTICIPANT	\N	PRESENT	0
575823	575820	20092G	PARTICIPANT	\N	PRESENT	0
575971	575209	19545Y	PARTICIPANT	\N	PRESENT	1
575972	575209	14327T	PARTICIPANT	\N	PRESENT	1
575973	575209	11110B	PARTICIPANT	\N	PRESENT	1
575974	575209	99004R	PARTICIPANT	\N	PRESENT	1
575975	575209	20126Y	PARTICIPANT	\N	PRESENT	1
575976	575209	19335Q	PARTICIPANT	\N	PRESENT	1
575977	575209	20050V	PARTICIPANT	\N	PRESENT	1
575978	575209	19479G	PARTICIPANT	\N	PRESENT	1
576254	576253	19631V	PARTICIPANT	\N	PRESENT	0
576255	576253	19782L	PARTICIPANT	\N	PRESENT	0
576256	576253	08028W	PARTICIPANT	\N	PRESENT	0
576257	576253	11101A	PARTICIPANT	\N	PRESENT	0
576258	576253	20018V	PARTICIPANT	\N	PRESENT	0
576291	576290	14089Y	PARTICIPANT	\N	PRESENT	0
576292	576290	19629C	PARTICIPANT	\N	PRESENT	0
576294	576293	14089Y	PARTICIPANT	\N	PRESENT	0
576295	576293	14053L	PARTICIPANT	\N	PRESENT	0
576296	576293	19749K	PARTICIPANT	\N	PRESENT	0
576297	575107	19725B	PARTICIPANT	\N	PRESENT	1
577915	577914	17367Q	PARTICIPANT	\N	PRESENT	0
577916	577914	11083R	PARTICIPANT	\N	PRESENT	0
577917	577914	19333N	PARTICIPANT	\N	PRESENT	0
577920	577914	04035D	PARTICIPANT	\N	PRESENT	0
577960	577914	11026G	PARTICIPANT	\N	PRESENT	0
583414	583160	20110Q	PARTICIPANT	\N	PRESENT	1
583415	583160	11033F	PARTICIPANT	\N	PRESENT	1
583416	583160	17737W	PARTICIPANT	\N	PRESENT	1
583417	583160	20128B	PARTICIPANT	\N	PRESENT	1
583418	583160	19489J	PARTICIPANT	\N	PRESENT	1
583419	583160	19729F	PARTICIPANT	\N	PRESENT	1
583420	583160	14147R	PARTICIPANT	\N	PRESENT	1
583426	582885	19631V	PARTICIPANT	\N	PRESENT	1
587207	585578	19657G	PARTICIPANT	\N	PRESENT	1
587208	585578	20130U	PARTICIPANT	\N	PRESENT	1
587209	585578	19798U	PARTICIPANT	\N	PRESENT	1
587210	585578	01034P	PARTICIPANT	\N	PRESENT	1
587274	585579	19543W	PARTICIPANT	\N	PRESENT	1
587275	585579	20110Q	PARTICIPANT	\N	PRESENT	1
587276	585579	20128B	PARTICIPANT	\N	PRESENT	1
587277	585579	19675J	PARTICIPANT	\N	PRESENT	1
587335	585653	20248J	PARTICIPANT	\N	PRESENT	0
587336	585653	04092N	PARTICIPANT	\N	PRESENT	0
587337	585653	01034P	PARTICIPANT	\N	PRESENT	0
587338	585653	20114U	PARTICIPANT	\N	PRESENT	0
587339	585653	17737W	PARTICIPANT	\N	PRESENT	0
587340	585659	11045K	PARTICIPANT	\N	PRESENT	0
587341	585659	11097X	PARTICIPANT	\N	PRESENT	0
587342	585659	19415P	PARTICIPANT	\N	PRESENT	0
587347	585659	11067R	PARTICIPANT	\N	PRESENT	0
587344	585659	19703U	PARTICIPANT	\N	PRESENT	0
587345	585659	10006L	PRESIDENT	0	PRESENT	0
587346	585659	20248J	PARTICIPANT	\N	PRESENT	0
587348	585659	20090E	PARTICIPANT	\N	PRESENT	0
587349	585659	14217N	PARTICIPANT	\N	PRESENT	0
587350	585659	14071N	PARTICIPANT	\N	PRESENT	0
587351	585659	14213J	PARTICIPANT	\N	PRESENT	0
587352	585659	14195A	PARTICIPANT	\N	PRESENT	0
587353	585659	11103C	PARTICIPANT	\N	PRESENT	1
587354	585659	11031D	PARTICIPANT	\N	PRESENT	0
587355	585659	19569H	PARTICIPANT	\N	PRESENT	0
587356	585659	20066E	PARTICIPANT	\N	PRESENT	0
587357	585659	19553Y	PARTICIPANT	\N	PRESENT	1
587358	585659	19798U	PARTICIPANT	\N	PRESENT	1
587359	585659	19691J	PARTICIPANT	\N	PRESENT	0
587371	585659	14042U	PARTICIPANT	\N	PRESENT	0
587376	585659	19657G	PARTICIPANT	\N	PRESENT	1
587377	585659	19295A	PARTICIPANT	\N	EXCUSE	0
587379	585659	19697Q	PARTICIPANT	\N	PRESENT	0
587619	587615	14213J	PARTICIPANT	\N	PRESENT	0
587949	587948	20032T	PARTICIPANT	\N	PRESENT	0
587950	587948	19760E	PARTICIPANT	\N	PRESENT	0
587951	587948	17367Q	PARTICIPANT	\N	PRESENT	0
587952	587948	19782L	PARTICIPANT	\N	PRESENT	0
587953	587948	20090E	PARTICIPANT	\N	PRESENT	0
587954	587948	11103C	PARTICIPANT	\N	PRESENT	0
587955	587948	19467C	PARTICIPANT	\N	PRESENT	0
587956	587948	14357A	PARTICIPANT	\N	PRESENT	0
587957	587948	08056B	PARTICIPANT	\N	PRESENT	0
587958	587948	19723Y	PARTICIPANT	\N	PRESENT	0
587959	587948	20018V	PARTICIPANT	\N	PRESENT	0
587960	587948	08061X	PARTICIPANT	\N	PRESENT	0
587961	587948	20030R	PARTICIPANT	\N	PRESENT	0
587962	587948	05012A	PARTICIPANT	\N	PRESENT	0
587963	587948	19739H	PARTICIPANT	\N	PRESENT	0
587964	587948	19679N	PARTICIPANT	\N	PRESENT	0
587965	587948	14331P	PARTICIPANT	\N	PRESENT	0
587966	587948	19619A	PARTICIPANT	\N	PRESENT	0
587967	587948	20092G	PARTICIPANT	\N	PRESENT	0
588292	588291	05008E	PARTICIPANT	\N	PRESENT	0
588293	588291	11053K	PARTICIPANT	\N	PRESENT	0
588294	588291	01028R	PARTICIPANT	\N	PRESENT	0
588546	588545	14169X	PARTICIPANT	\N	PRESENT	0
588605	588604	08012N	PARTICIPANT	\N	PRESENT	1
588606	588604	11043H	PARTICIPANT	\N	PRESENT	1
588608	588607	08012N	PARTICIPANT	\N	PRESENT	1
588609	588607	11043H	PARTICIPANT	\N	PRESENT	1
588755	584518	19515S	PRESIDENT	0	PRESENT	0
588756	584518	14083S	PARTICIPANT	\N	PRESENT	0
588758	584518	14026U	PARTICIPANT	\N	PRESENT	0
588851	584518	08028W	PARTICIPANT	\N	PRESENT	0
588762	584518	19575F	PARTICIPANT	\N	PRESENT	0
588764	584518	19697Q	PARTICIPANT	\N	PRESENT	0
588766	584518	14031R	PARTICIPANT	\N	PRESENT	0
588767	584518	14030Q	PARTICIPANT	\N	PRESENT	0
588770	584518	14105F	PARTICIPANT	\N	PRESENT	0
588797	584518	20030R	PARTICIPANT	\N	PRESENT	0
588798	584518	19467C	PARTICIPANT	\N	PRESENT	0
588801	584518	19301E	PARTICIPANT	\N	PRESENT	0
588817	584518	19762G	PARTICIPANT	\N	PRESENT	0
588820	584518	08060W	PARTICIPANT	\N	EXCUSE	0
588821	584518	08015R	PARTICIPANT	\N	EXCUSE	0
588822	584518	16685X	PARTICIPANT	\N	EXCUSE	0
588823	584518	20054A	PARTICIPANT	\N	EXCUSE	0
588824	584518	14357A	PARTICIPANT	\N	EXCUSE	0
588830	584518	19760E	PARTICIPANT	\N	PRESENT	0
588832	584518	20094J	PARTICIPANT	\N	PRESENT	0
588841	584518	19251M	PARTICIPANT	\N	PRESENT	0
588844	584518	19717B	PARTICIPANT	\N	PRESENT	0
589346	588838	20172F	PARTICIPANT	\N	PRESENT	1
589347	588839	20172F	PARTICIPANT	\N	PRESENT	0
589386	589385	20172F	PARTICIPANT	\N	PRESENT	1
589388	589387	20172F	PARTICIPANT	\N	PRESENT	1
589403	589400	20172F	PARTICIPANT	\N	PRESENT	1
589406	589405	20172F	PARTICIPANT	\N	PRESENT	1
589453	589450	19679N	PARTICIPANT	\N	PRESENT	0
589581	588547	20066E	PARTICIPANT	\N	PRESENT	0
589647	589646	04059M	PARTICIPANT	\N	PRESENT	0
589584	589583	20066E	PARTICIPANT	\N	PRESENT	0
589633	587935	14251Q	PARTICIPANT	\N	PRESENT	1
589634	587935	19747H	PARTICIPANT	\N	PRESENT	0
589635	587935	14207L	PARTICIPANT	\N	PRESENT	0
589636	587935	14257W	PARTICIPANT	\N	PRESENT	0
589648	589646	20112S	PARTICIPANT	\N	PRESENT	1
589649	589646	19651A	PARTICIPANT	\N	PRESENT	0
589650	589646	14030Q	PARTICIPANT	\N	PRESENT	1
589651	589646	19643A	PARTICIPANT	\N	PRESENT	1
589652	589646	19621T	PARTICIPANT	\N	EXCUSE	0
589653	589646	19758L	PARTICIPANT	\N	PRESENT	0
589654	589646	20264J	PARTICIPANT	\N	PRESENT	0
589655	589646	19693L	PARTICIPANT	\N	PRESENT	0
589657	589646	20134Y	PARTICIPANT	\N	PRESENT	0
589658	589646	20132W	PARTICIPANT	\N	PRESENT	0
589659	589646	20180F	PARTICIPANT	\N	PRESENT	1
589660	589646	14123H	PARTICIPANT	\N	PRESENT	0
589661	589646	20048C	PARTICIPANT	\N	PRESENT	0
589662	589646	19399H	PARTICIPANT	\N	PRESENT	0
589663	589646	20124W	PARTICIPANT	\N	PRESENT	0
589664	589646	20056C	PARTICIPANT	\N	EXCUSE	0
589665	589646	19611R	PRESIDENT	0	PRESENT	0
589666	589646	19735D	PARTICIPANT	\N	PRESENT	0
589667	589646	19699S	PARTICIPANT	\N	PRESENT	0
589668	589646	20052X	PARTICIPANT	\N	PRESENT	0
589669	589646	08012N	PARTICIPANT	\N	PRESENT	1
589670	589646	20142Y	PARTICIPANT	\N	PRESENT	0
589671	589646	14109K	PARTICIPANT	\N	PRESENT	1
589672	589646	19593H	PARTICIPANT	\N	PRESENT	0
592559	590947	05008E	PARTICIPANT	\N	EXCUSE	0
594959	593548	19545Y	PARTICIPANT	\N	PRESENT	1
594960	593548	20126Y	PARTICIPANT	\N	PRESENT	1
594961	593548	19671E	PARTICIPANT	\N	PRESENT	1
594962	593548	08011M	PARTICIPANT	\N	PRESENT	1
594963	593548	20050V	PARTICIPANT	\N	PRESENT	1
594964	593446	17637T	PARTICIPANT	\N	PRESENT	0
594965	593446	19701S	PARTICIPANT	\N	PRESENT	0
594966	593446	20104S	PARTICIPANT	\N	PRESENT	0
594967	593446	19441R	PARTICIPANT	\N	PRESENT	0
594968	593446	14217N	PARTICIPANT	\N	PRESENT	0
594969	593446	20082E	PARTICIPANT	\N	PRESENT	0
594970	593446	19413M	PARTICIPANT	\N	PRESENT	0
594971	593446	19591F	PARTICIPANT	\N	PRESENT	0
594972	593446	20094J	PARTICIPANT	\N	PRESENT	0
594973	593446	11048N	PARTICIPANT	\N	PRESENT	0
594974	593446	20066E	PARTICIPANT	\N	PRESENT	0
594975	593446	11033F	PARTICIPANT	\N	PRESENT	0
594976	593446	19725B	PARTICIPANT	\N	PRESENT	0
594977	593446	11067R	PARTICIPANT	\N	PRESENT	0
594997	593446	20080C	PARTICIPANT	\N	PRESENT	0
594998	593446	11110B	PARTICIPANT	\N	PRESENT	0
594999	593446	14105F	PARTICIPANT	\N	PRESENT	0
595000	593446	14097Y	PARTICIPANT	\N	PRESENT	0
595001	593446	19565D	PARTICIPANT	\N	PRESENT	0
595002	593446	07029T	PARTICIPANT	\N	PRESENT	0
595003	593446	97011G	PARTICIPANT	\N	PRESENT	0
595004	593446	20100N	PARTICIPANT	\N	PRESENT	0
595005	593446	19749K	PARTICIPANT	\N	PRESENT	0
595066	593447	19591F	PARTICIPANT	\N	PRESENT	0
595067	593447	04092N	PARTICIPANT	\N	PRESENT	0
595068	593447	11033F	PARTICIPANT	\N	PRESENT	0
595069	593447	19725B	PARTICIPANT	\N	PRESENT	0
595070	593447	17589D	PARTICIPANT	\N	PRESENT	0
595071	593447	14053L	PARTICIPANT	\N	PRESENT	0
595072	593447	20266L	PARTICIPANT	\N	PRESENT	0
595073	593447	04085P	PARTICIPANT	\N	PRESENT	0
595074	593447	19749K	PARTICIPANT	\N	PRESENT	0
595075	593447	20066E	PARTICIPANT	\N	PRESENT	0
595076	593447	20248J	PARTICIPANT	\N	PRESENT	0
595077	593447	20132W	PARTICIPANT	\N	PRESENT	0
595078	593447	19581D	PARTICIPANT	\N	PRESENT	0
595079	593447	20252E	PARTICIPANT	\N	PRESENT	0
595080	593447	14213J	PARTICIPANT	\N	PRESENT	0
595081	593447	17637T	PARTICIPANT	\N	PRESENT	0
595082	593447	20056C	PARTICIPANT	\N	PRESENT	0
595083	593447	20026V	PARTICIPANT	\N	PRESENT	0
595084	593447	19599P	PARTICIPANT	\N	PRESENT	0
595085	593447	20080C	PARTICIPANT	\N	PRESENT	0
595086	593447	14109K	PARTICIPANT	\N	PRESENT	0
595087	593447	19549D	PARTICIPANT	\N	PRESENT	0
595088	593447	11067R	PARTICIPANT	\N	PRESENT	0
595095	593447	14215L	PARTICIPANT	\N	PRESENT	0
595090	593447	14030Q	PARTICIPANT	\N	PRESENT	0
595091	593447	20264J	PARTICIPANT	\N	PRESENT	0
595092	593447	19673G	PARTICIPANT	\N	PRESENT	0
595093	593447	14097Y	PARTICIPANT	\N	PRESENT	0
595094	593447	20100N	PARTICIPANT	\N	PRESENT	0
595096	593447	19693L	PARTICIPANT	\N	PRESENT	0
595097	593447	20092G	PARTICIPANT	\N	PRESENT	0
595098	593447	04047H	PARTICIPANT	\N	PRESENT	0
595099	593447	11085T	PARTICIPANT	\N	PRESENT	0
595100	593447	19565D	PARTICIPANT	\N	PRESENT	0
595101	593447	19719D	PARTICIPANT	\N	PRESENT	0
595102	593447	11072N	PARTICIPANT	\N	PRESENT	0
595103	593447	11026G	PARTICIPANT	\N	PRESENT	0
595104	593447	19553Y	PARTICIPANT	\N	PRESENT	0
595105	593447	14083S	PARTICIPANT	\N	PRESENT	0
595106	593447	14105F	PARTICIPANT	\N	PRESENT	0
595107	593447	20104S	PARTICIPANT	\N	PRESENT	0
595108	593447	20098N	PARTICIPANT	\N	PRESENT	0
595109	593447	14033T	PARTICIPANT	\N	PRESENT	0
595110	593447	19762G	PARTICIPANT	\N	PRESENT	0
595111	593447	11097X	PARTICIPANT	\N	PRESENT	0
595112	593447	14217N	PARTICIPANT	\N	PRESENT	0
595149	593449	14053L	PARTICIPANT	\N	PRESENT	0
595150	593449	20266L	PARTICIPANT	\N	PRESENT	0
595151	593449	04085P	PARTICIPANT	\N	PRESENT	0
595152	593449	19749K	PARTICIPANT	\N	PRESENT	0
595153	593449	20132W	PARTICIPANT	\N	PRESENT	0
595184	593449	14215L	PARTICIPANT	\N	PRESENT	0
595155	593449	19581D	PARTICIPANT	\N	PRESENT	0
595156	593449	19621T	PARTICIPANT	\N	PRESENT	0
595157	593449	19553Y	PARTICIPANT	\N	PRESENT	0
595158	593449	11067R	PARTICIPANT	\N	PRESENT	0
595159	593449	04047H	PARTICIPANT	\N	PRESENT	0
595160	593449	19447X	PARTICIPANT	\N	PRESENT	0
595064	593447	19447X	PARTICIPANT	\N	PRESENT	0
595065	593447	01043Q	PARTICIPANT	\N	PRESENT	0
595161	593449	19725B	PARTICIPANT	\N	PRESENT	0
595162	593449	11033F	PARTICIPANT	\N	PRESENT	0
595163	593449	20100N	PARTICIPANT	\N	PRESENT	0
595164	593449	14231L	PARTICIPANT	\N	PRESENT	0
595165	593449	20056C	PARTICIPANT	\N	PRESENT	0
595166	593449	20264J	PARTICIPANT	\N	PRESENT	0
595167	593449	20110Q	PARTICIPANT	\N	PRESENT	0
595168	593449	20092G	PARTICIPANT	\N	PRESENT	0
595169	593449	19565D	PARTICIPANT	\N	PRESENT	0
595170	593449	14042U	PARTICIPANT	\N	PRESENT	0
595171	593449	20026V	PARTICIPANT	\N	PRESENT	0
595172	593449	20248J	PARTICIPANT	\N	PRESENT	0
595173	593449	11026G	PARTICIPANT	\N	PRESENT	0
595174	593449	14083S	PARTICIPANT	\N	PRESENT	0
595175	593449	14033T	PARTICIPANT	\N	PRESENT	0
595176	593449	95041E	PARTICIPANT	\N	PRESENT	0
595177	593449	14147R	PARTICIPANT	\N	PRESENT	0
595178	593449	20034V	PARTICIPANT	\N	PRESENT	0
595179	593449	20090E	PARTICIPANT	\N	PRESENT	0
595180	593449	20108W	PARTICIPANT	\N	PRESENT	0
595181	593449	20252E	PARTICIPANT	\N	PRESENT	0
595182	593449	14069U	PARTICIPANT	\N	PRESENT	0
595147	593449	19719D	PARTICIPANT	\N	PRESENT	0
595148	593449	17589D	PARTICIPANT	\N	PRESENT	0
595183	593449	14030Q	PARTICIPANT	\N	PRESENT	0
595185	593449	11048N	PARTICIPANT	\N	PRESENT	0
595186	593449	19573D	PARTICIPANT	\N	PRESENT	0
595187	593449	20048C	PARTICIPANT	\N	PRESENT	0
595188	593449	14073Q	PARTICIPANT	\N	PRESENT	0
595189	593449	20070A	PARTICIPANT	\N	PRESENT	0
595190	593449	20086J	PARTICIPANT	\N	PRESENT	0
595191	593449	19591F	PARTICIPANT	\N	PRESENT	0
595192	593449	20126Y	PARTICIPANT	\N	PRESENT	0
595193	593449	19533U	PARTICIPANT	\N	PRESENT	0
595195	595194	19679N	PARTICIPANT	\N	PRESENT	1
595196	595194	17779H	PARTICIPANT	\N	PRESENT	1
595198	595197	14033T	PARTICIPANT	\N	PRESENT	0
595199	595197	19575F	PARTICIPANT	\N	PRESENT	0
595201	591282	14026U	PARTICIPANT	\N	PRESENT	0
595202	593460	99004R	PARTICIPANT	\N	PRESENT	0
595227	593460	20030R	PARTICIPANT	\N	PRESENT	0
595228	593460	20056C	PARTICIPANT	\N	PRESENT	0
595229	593460	20026V	PARTICIPANT	\N	PRESENT	0
595230	593460	19954N	PARTICIPANT	\N	PRESENT	0
595231	593460	19599P	PARTICIPANT	\N	PRESENT	0
595232	593460	19399H	PARTICIPANT	\N	PRESENT	0
595233	593460	20102Q	PARTICIPANT	\N	PRESENT	0
595234	593460	20080C	PARTICIPANT	\N	PRESENT	0
595235	593460	20090E	PARTICIPANT	\N	PRESENT	0
595236	593460	11065P	PARTICIPANT	\N	PRESENT	0
595237	593460	20252E	PARTICIPANT	\N	PRESENT	0
595238	593460	19681G	PARTICIPANT	\N	PRESENT	0
595240	593460	20106U	PARTICIPANT	\N	PRESENT	0
595241	593460	14031R	PARTICIPANT	\N	PRESENT	0
595242	593460	95063L	PARTICIPANT	\N	PRESENT	0
595243	593460	19711U	PARTICIPANT	\N	PRESENT	0
595245	593460	19826F	PARTICIPANT	\N	PRESENT	0
595246	593460	08060W	PARTICIPANT	\N	PRESENT	0
594947	593322	14097Y	PARTICIPANT	\N	PRESENT	0
594949	593322	01062T	PARTICIPANT	\N	PRESENT	0
594950	593322	11041F	PARTICIPANT	\N	PRESENT	1
594951	593322	20042V	PARTICIPANT	\N	PRESENT	0
594952	593322	01024M	PARTICIPANT	\N	PRESENT	0
594953	593322	14105F	PARTICIPANT	\N	PRESENT	0
594954	593322	11083R	PARTICIPANT	\N	PRESENT	0
594955	593322	14211G	PARTICIPANT	\N	PRESENT	0
594956	593322	14255U	PARTICIPANT	\N	PRESENT	0
594957	593322	11054L	PARTICIPANT	\N	EXCUSE	0
594958	593446	19599P	PARTICIPANT	\N	PRESENT	0
595250	593460	19549D	PARTICIPANT	\N	PRESENT	0
595251	593460	19713W	PARTICIPANT	\N	PRESENT	0
571527	571144	19399H	PARTICIPANT	\N	PRESENT	0
571528	571144	19349W	PARTICIPANT	\N	PRESENT	0
571529	571144	11043H	PARTICIPANT	\N	PRESENT	0
571530	571144	20080C	PARTICIPANT	\N	PRESENT	0
571531	571144	11085T	PARTICIPANT	\N	PRESENT	0
571532	571144	20058E	PARTICIPANT	\N	PRESENT	0
571533	571144	19415P	PARTICIPANT	\N	PRESENT	0
571539	571144	14030Q	PARTICIPANT	\N	PRESENT	0
571542	571144	01057W	PARTICIPANT	\N	PRESENT	0
571552	571144	14221J	PARTICIPANT	\N	PRESENT	0
571553	571144	19687N	PARTICIPANT	\N	PRESENT	0
571554	571144	19637C	PARTICIPANT	\N	PRESENT	0
571555	570846	19725B	PARTICIPANT	\N	PRESENT	0
571556	570846	14147R	PARTICIPANT	\N	PRESENT	0
571557	570846	14215L	PARTICIPANT	\N	PRESENT	0
571558	570846	04047H	PRESIDENT	0	PRESENT	0
571559	570846	01028R	PARTICIPANT	\N	PRESENT	0
571564	571144	19691J	PARTICIPANT	\N	PRESENT	0
571583	571144	11053K	PARTICIPANT	\N	PRESENT	0
571584	571144	08015R	PARTICIPANT	\N	PRESENT	0
571585	571144	14169X	PARTICIPANT	\N	PRESENT	0
571586	571144	11104D	PARTICIPANT	\N	PRESENT	0
571587	571144	12041X	PARTICIPANT	\N	PRESENT	0
571588	571144	14195A	PARTICIPANT	\N	PRESENT	0
571589	571144	19709B	PARTICIPANT	\N	PRESENT	0
571650	571145	14083S	PARTICIPANT	\N	PRESENT	0
571651	571145	19551W	PARTICIPANT	\N	PRESENT	0
571652	571145	19503N	PARTICIPANT	\N	PRESENT	0
571653	571145	11090Q	PARTICIPANT	\N	PRESENT	0
571654	571145	14219Q	PARTICIPANT	\N	PRESENT	0
571655	571145	20136B	PARTICIPANT	\N	PRESENT	0
571656	571145	19673G	PARTICIPANT	\N	PRESENT	0
571657	571145	19585H	PARTICIPANT	\N	PRESENT	0
571658	571145	14195A	PARTICIPANT	\N	PRESENT	0
571659	571145	14030Q	PARTICIPANT	\N	PRESENT	0
571660	571145	14089Y	PARTICIPANT	\N	PRESENT	0
571661	571145	14207L	PARTICIPANT	\N	PRESENT	0
571662	571145	19820Y	PARTICIPANT	\N	PRESENT	0
571663	571145	08015R	PARTICIPANT	\N	PRESENT	0
571664	571145	11043H	PARTICIPANT	\N	PRESENT	0
571665	571145	19349W	PARTICIPANT	\N	PRESENT	0
571666	571145	11099A	PARTICIPANT	\N	PRESENT	0
571667	571145	19798U	PARTICIPANT	\N	PRESENT	0
571668	571145	17229F	PARTICIPANT	\N	PRESENT	0
571669	571145	20130U	PARTICIPANT	\N	PRESENT	0
571670	571145	19413M	PARTICIPANT	\N	PRESENT	0
571671	571145	20018V	PARTICIPANT	\N	PRESENT	0
571672	571145	14257W	PARTICIPANT	\N	PRESENT	0
571673	571145	19631V	PARTICIPANT	\N	PRESENT	0
571674	571145	19687N	PARTICIPANT	\N	PRESENT	0
571675	571145	20102Q	PARTICIPANT	\N	PRESENT	0
571676	571145	19695N	PARTICIPANT	\N	PRESENT	0
571677	571145	19647E	PARTICIPANT	\N	PRESENT	0
571678	571145	20072C	PARTICIPANT	\N	PRESENT	0
571679	571145	19719D	PARTICIPANT	\N	PRESENT	0
571680	571145	20116W	PARTICIPANT	\N	PRESENT	0
571681	571145	19826F	PARTICIPANT	\N	PRESENT	0
571682	571145	19369B	PARTICIPANT	\N	PRESENT	0
571683	571145	11065P	PARTICIPANT	\N	PRESENT	0
571684	571145	19701S	PARTICIPANT	\N	PRESENT	0
571685	571145	08034U	PARTICIPANT	\N	PRESENT	0
571686	571145	20076G	PARTICIPANT	\N	PRESENT	0
571687	571145	14031R	PARTICIPANT	\N	PRESENT	0
571688	571145	20040T	PARTICIPANT	\N	PRESENT	0
571689	571145	20100N	PARTICIPANT	\N	PRESENT	0
571690	571145	20110Q	PARTICIPANT	\N	PRESENT	0
571691	571145	20092G	PARTICIPANT	\N	PRESENT	0
571692	571145	20134Y	PARTICIPANT	\N	PRESENT	0
571693	571145	04045F	PARTICIPANT	\N	PRESENT	0
571694	571145	19637C	PARTICIPANT	\N	PRESENT	0
571695	571145	14205J	PARTICIPANT	\N	PRESENT	0
571696	571145	20140W	PARTICIPANT	\N	PRESENT	0
571697	571145	07029T	PARTICIPANT	\N	PRESENT	0
571698	571145	19333N	PARTICIPANT	\N	PRESENT	0
571699	571145	14215L	PARTICIPANT	\N	PRESENT	0
571700	571145	20124W	PARTICIPANT	\N	PRESENT	0
571701	571145	19533U	PARTICIPANT	\N	PRESENT	0
571702	571145	20180F	PARTICIPANT	\N	PRESENT	0
571703	571145	18083K	PARTICIPANT	\N	PRESENT	0
571704	571145	19954N	PARTICIPANT	\N	PRESENT	0
571705	571145	20096L	PARTICIPANT	\N	PRESENT	0
571706	571145	19441R	PARTICIPANT	\N	PRESENT	0
571707	571145	20052X	PARTICIPANT	\N	PRESENT	0
571648	571145	11070L	PARTICIPANT	\N	PRESENT	0
571649	571145	19549D	PARTICIPANT	\N	PRESENT	0
571708	571145	19762G	PARTICIPANT	\N	PRESENT	0
571709	571145	19415P	PARTICIPANT	\N	PRESENT	0
571710	571145	11097X	PARTICIPANT	\N	PRESENT	0
571711	571145	19782L	PARTICIPANT	\N	PRESENT	0
571712	571145	20126Y	PARTICIPANT	\N	PRESENT	0
571713	571145	14217N	PARTICIPANT	\N	PRESENT	0
571714	571145	14327T	PARTICIPANT	\N	PRESENT	0
571715	571145	14187A	PARTICIPANT	\N	PRESENT	0
571716	571145	19467C	PARTICIPANT	\N	PRESENT	0
571717	571145	19739H	PARTICIPANT	\N	PRESENT	0
571718	571145	20142Y	PARTICIPANT	\N	PRESENT	0
571719	571145	08061X	PARTICIPANT	\N	PRESENT	0
571720	571145	14221J	PARTICIPANT	\N	PRESENT	0
571721	571145	19347U	PARTICIPANT	\N	PRESENT	0
571722	571145	20044X	PARTICIPANT	\N	PRESENT	0
571723	571145	14038Y	PARTICIPANT	\N	PRESENT	0
571724	571145	19643A	PARTICIPANT	\N	PRESENT	0
571725	571145	20038A	PARTICIPANT	\N	PRESENT	0
571726	571145	14231L	PARTICIPANT	\N	PRESENT	0
571727	571145	14169X	PARTICIPANT	\N	PRESENT	0
571728	571145	14357A	PARTICIPANT	\N	PRESENT	0
571729	571145	19507S	PARTICIPANT	\N	PRESENT	0
571730	571145	04033B	PARTICIPANT	\N	PRESENT	0
571731	571145	20062A	PARTICIPANT	\N	PRESENT	0
571732	571145	14147R	PARTICIPANT	\N	PRESENT	0
571733	571145	20120S	PARTICIPANT	\N	PRESENT	0
571734	571145	20118Y	PARTICIPANT	\N	PRESENT	0
571735	571145	20058E	PARTICIPANT	\N	PRESENT	0
571736	571145	20070A	PARTICIPANT	\N	PRESENT	0
571737	571145	14213J	PARTICIPANT	\N	PRESENT	0
571738	571145	12041X	PARTICIPANT	\N	PRESENT	0
575969	575105	19725B	PARTICIPANT	\N	PRESENT	1
575979	575105	20074E	PARTICIPANT	\N	EXCUSE	0
576011	575106	19447X	PARTICIPANT	\N	PRESENT	1
576012	575106	20128B	PARTICIPANT	\N	PRESENT	1
576013	575106	07004J	PARTICIPANT	\N	PRESENT	1
576014	575106	14179A	PARTICIPANT	\N	PRESENT	1
576371	575268	10015M	PARTICIPANT	\N	PRESENT	0
576372	575268	05012A	PARTICIPANT	\N	PRESENT	0
576373	575268	14357A	PARTICIPANT	\N	PRESENT	0
576374	575268	19515S	PARTICIPANT	\N	PRESENT	0
576375	575268	19747H	PARTICIPANT	\N	PRESENT	0
576376	575268	14211G	PARTICIPANT	\N	PRESENT	0
576377	575268	17637T	PARTICIPANT	\N	PRESENT	0
576378	575268	19711U	PARTICIPANT	\N	PRESENT	0
576379	575268	04035D	PARTICIPANT	\N	PRESENT	0
576380	575268	08034U	PARTICIPANT	\N	PRESENT	0
576381	575268	01057W	PARTICIPANT	\N	PRESENT	0
576382	575268	11101A	PARTICIPANT	\N	PRESENT	0
576383	575268	19703U	PARTICIPANT	\N	PRESENT	0
576384	575268	01058X	PARTICIPANT	\N	PRESENT	0
576385	575268	04085P	PARTICIPANT	\N	PRESENT	0
576386	575268	19593H	PARTICIPANT	\N	PRESENT	0
576387	575268	08010L	PARTICIPANT	\N	PRESENT	0
576388	575268	04047H	PARTICIPANT	\N	PRESENT	0
576389	575268	20074E	PARTICIPANT	\N	PRESENT	0
576390	575268	20078J	PARTICIPANT	\N	PRESENT	0
576391	575268	18083K	PARTICIPANT	\N	PRESENT	0
576392	575268	20100N	PARTICIPANT	\N	PRESENT	0
576393	575268	20102Q	PARTICIPANT	\N	PRESENT	0
576394	575268	14123H	PARTICIPANT	\N	PRESENT	0
576395	575268	14133K	PARTICIPANT	\N	PRESENT	0
576396	575268	20134Y	PARTICIPANT	\N	PRESENT	0
576397	575268	04092N	PARTICIPANT	\N	PRESENT	0
576398	575268	11072N	PARTICIPANT	\N	PRESENT	0
576399	575268	08061X	PARTICIPANT	\N	PRESENT	0
576400	575268	14071N	PARTICIPANT	\N	PRESENT	0
576401	575268	19301E	PARTICIPANT	\N	PRESENT	0
576402	575268	95063L	PARTICIPANT	\N	PRESENT	0
576403	575268	04045F	PARTICIPANT	\N	PRESENT	0
576404	575268	04033B	PARTICIPANT	\N	PRESENT	0
576405	575268	11083R	PARTICIPANT	\N	PRESENT	0
576406	575268	11097X	PARTICIPANT	\N	PRESENT	0
576407	575268	19637C	PARTICIPANT	\N	PRESENT	0
576408	575268	08028W	PARTICIPANT	\N	PRESENT	0
576409	575268	19591F	PARTICIPANT	\N	PRESENT	0
586498	585747	20126Y	PARTICIPANT	\N	PRESENT	0
586499	585747	19713W	PARTICIPANT	\N	PRESENT	0
586500	585747	19745F	PARTICIPANT	\N	PRESENT	0
586501	585747	20252E	PARTICIPANT	\N	PRESENT	0
586502	585747	14223L	PARTICIPANT	\N	PRESENT	0
586509	585747	20042V	PARTICIPANT	\N	PRESENT	0
586510	585747	14173T	PARTICIPANT	\N	PRESENT	0
586511	585747	20056C	PARTICIPANT	\N	PRESENT	0
586512	585747	20144B	PARTICIPANT	\N	PRESENT	0
586513	585747	19954N	PARTICIPANT	\N	PRESENT	0
586514	585747	19699S	PARTICIPANT	\N	PRESENT	0
586515	585747	20040T	PARTICIPANT	\N	PRESENT	0
586516	585747	14071N	PARTICIPANT	\N	PRESENT	0
586517	585747	20116W	PARTICIPANT	\N	PRESENT	0
586518	585747	19387D	PARTICIPANT	\N	PRESENT	0
586519	585747	20174H	PARTICIPANT	\N	PRESENT	0
586520	585747	14219Q	PARTICIPANT	\N	PRESENT	0
586521	585747	14073Q	PARTICIPANT	\N	PRESENT	0
586522	585747	19333N	PARTICIPANT	\N	PRESENT	0
586523	585747	14221J	PARTICIPANT	\N	PRESENT	0
586539	585747	19679N	PARTICIPANT	\N	PRESENT	0
586540	585747	11072N	PARTICIPANT	\N	PRESENT	0
586526	585747	20044X	PARTICIPANT	\N	PRESENT	0
586541	585747	20074E	PARTICIPANT	\N	PRESENT	0
586542	585747	19479G	PARTICIPANT	\N	PRESENT	0
586543	585747	01058X	PARTICIPANT	\N	PRESENT	0
586544	585747	14231L	PARTICIPANT	\N	PRESENT	0
586545	585747	14133K	PARTICIPANT	\N	PRESENT	0
586546	585747	19533U	PARTICIPANT	\N	PRESENT	0
586547	585747	19697Q	PARTICIPANT	\N	PRESENT	0
586548	585747	14021P	PARTICIPANT	\N	PRESENT	0
586549	585747	11056N	PARTICIPANT	\N	PRESENT	0
586607	585749	08028W	PARTICIPANT	\N	PRESENT	0
586637	585749	20130U	PARTICIPANT	\N	PRESENT	0
586609	585749	10006L	PARTICIPANT	\N	PRESENT	0
586610	585749	19533U	PARTICIPANT	\N	PRESENT	0
586611	585749	14215L	PARTICIPANT	\N	PRESENT	0
586612	585749	19768N	PARTICIPANT	\N	PRESENT	0
586613	585749	19467C	PARTICIPANT	\N	PRESENT	0
586614	585749	14105F	PARTICIPANT	\N	PRESENT	0
586615	585749	11056N	PARTICIPANT	\N	PRESENT	0
586616	585749	05008E	PARTICIPANT	\N	PRESENT	0
586617	585749	19629C	PARTICIPANT	\N	PRESENT	0
586618	585749	19387D	PARTICIPANT	\N	PRESENT	0
586619	585749	19441R	PARTICIPANT	\N	PRESENT	0
586620	585749	19479G	PARTICIPANT	\N	PRESENT	0
586621	585749	19697Q	PARTICIPANT	\N	PRESENT	0
586622	585749	11033F	PARTICIPANT	\N	PRESENT	0
586623	585749	04085P	PARTICIPANT	\N	PRESENT	0
586624	585749	20110Q	PARTICIPANT	\N	PRESENT	0
586628	585749	19585H	PARTICIPANT	\N	PRESENT	0
586626	585749	20174H	PARTICIPANT	\N	PRESENT	0
586627	585749	14107H	PARTICIPANT	\N	PRESENT	0
586629	585749	19749K	PARTICIPANT	\N	PRESENT	0
586630	585749	08061X	PARTICIPANT	\N	PRESENT	0
586631	585749	14021P	PARTICIPANT	\N	PRESENT	0
586632	585749	20042V	PARTICIPANT	\N	PRESENT	0
586633	585749	19367Y	PARTICIPANT	\N	PRESENT	0
586634	585749	20252E	PARTICIPANT	\N	PRESENT	0
586635	585749	19399H	PARTICIPANT	\N	PRESENT	0
586636	585749	11072N	PARTICIPANT	\N	PRESENT	0
586638	585749	19649G	PARTICIPANT	\N	PRESENT	0
586639	585749	95063L	PARTICIPANT	\N	PRESENT	0
586640	585749	01048V	PARTICIPANT	\N	PRESENT	0
586641	585749	20108W	PARTICIPANT	\N	PRESENT	0
586642	585749	20090E	PARTICIPANT	\N	PRESENT	0
586643	585749	18083K	PARTICIPANT	\N	PRESENT	0
586644	585409	14327T	PRESIDENT	0	PRESENT	0
586645	585409	20086J	PARTICIPANT	\N	PRESENT	0
586646	585409	19333N	PARTICIPANT	\N	PRESENT	0
586647	585409	11048N	PARTICIPANT	\N	PRESENT	0
586648	585409	19515S	PARTICIPANT	\N	PRESENT	0
586649	585409	20044X	PARTICIPANT	\N	PRESENT	0
586650	585409	11110B	PARTICIPANT	\N	PRESENT	0
586651	585409	14173T	PARTICIPANT	\N	PRESENT	0
586652	585409	20070A	PARTICIPANT	\N	PRESENT	0
586653	585409	99004R	PARTICIPANT	\N	PRESENT	0
586654	585409	20116W	PARTICIPANT	\N	PRESENT	0
586655	585409	19335Q	PARTICIPANT	\N	PRESENT	0
586656	585409	19762G	PARTICIPANT	\N	PRESENT	0
586657	585409	14189C	PARTICIPANT	\N	EXCUSE	0
586658	585409	14225N	PARTICIPANT	\N	EXCUSE	0
586659	585409	19671E	PARTICIPANT	\N	EXCUSE	0
586660	585749	11043H	PARTICIPANT	\N	PRESENT	0
586661	585749	20036X	PARTICIPANT	\N	PRESENT	0
586662	585749	20114U	PARTICIPANT	\N	PRESENT	0
586663	585749	04047H	PARTICIPANT	\N	PRESENT	0
586605	585749	11045K	PARTICIPANT	\N	PRESENT	0
586606	585749	20074E	PARTICIPANT	\N	PRESENT	0
586664	585749	01028R	PARTICIPANT	\N	PRESENT	0
586665	585749	19651A	PARTICIPANT	\N	PRESENT	0
586666	585749	19507S	PARTICIPANT	\N	PRESENT	0
586667	585749	19747H	PARTICIPANT	\N	PRESENT	0
586668	585749	19415P	PARTICIPANT	\N	PRESENT	0
586669	585749	14053L	PARTICIPANT	\N	PRESENT	0
586670	585409	19479G	PARTICIPANT	\N	PRESENT	0
586671	585409	19647E	PARTICIPANT	\N	PRESENT	0
586672	585409	20080C	PARTICIPANT	\N	PRESENT	0
586673	585409	07029T	PARTICIPANT	\N	PRESENT	0
586674	585409	08009T	PARTICIPANT	\N	PRESENT	0
586675	585409	19741B	PARTICIPANT	\N	PRESENT	0
586676	585409	20126Y	PARTICIPANT	\N	PRESENT	0
586677	585409	11012A	PARTICIPANT	\N	PRESENT	0
586678	585749	14187A	PARTICIPANT	\N	PRESENT	0
586679	585749	19383Y	PARTICIPANT	\N	PRESENT	0
586680	585749	14223L	PARTICIPANT	\N	PRESENT	0
586681	585749	01034P	PARTICIPANT	\N	PRESENT	0
586682	585749	14231L	PARTICIPANT	\N	PRESENT	0
586683	585749	19782L	PARTICIPANT	\N	PRESENT	0
586684	585749	19447X	PARTICIPANT	\N	PRESENT	0
586685	585749	19685L	PARTICIPANT	\N	PRESENT	0
586686	585749	19549D	PARTICIPANT	\N	PRESENT	0
586687	585749	20172F	PARTICIPANT	\N	PRESENT	0
586688	585749	01062T	PARTICIPANT	\N	PRESENT	0
586689	585749	19599P	PARTICIPANT	\N	PRESENT	0
586690	585749	08010L	PARTICIPANT	\N	PRESENT	0
586691	585749	20082E	PARTICIPANT	\N	PRESENT	0
586692	585409	19711U	PARTICIPANT	\N	PRESENT	0
586693	585409	01057W	PARTICIPANT	\N	PRESENT	0
586694	585409	19687N	PARTICIPANT	\N	PRESENT	0
586695	585749	19669L	PARTICIPANT	\N	PRESENT	0
586696	585749	14033T	PARTICIPANT	\N	PRESENT	0
586697	585409	11053K	PARTICIPANT	\N	PRESENT	0
586698	585749	20120S	PARTICIPANT	\N	PRESENT	0
586699	585749	20138D	PARTICIPANT	\N	PRESENT	0
586700	585409	01048V	PARTICIPANT	\N	PRESENT	0
586701	585749	20180F	PARTICIPANT	\N	PRESENT	0
586702	585749	20054A	PARTICIPANT	\N	PRESENT	0
586703	585749	19565D	PARTICIPANT	\N	PRESENT	0
586704	585749	20028X	PARTICIPANT	\N	PRESENT	0
586705	585409	19349W	PARTICIPANT	\N	PRESENT	0
586706	585749	01024M	PARTICIPANT	\N	PRESENT	0
586707	585749	20086J	PARTICIPANT	\N	PRESENT	0
586708	585749	11097X	PARTICIPANT	\N	PRESENT	0
586709	585749	01043Q	PARTICIPANT	\N	PRESENT	0
586710	585749	19820Y	PARTICIPANT	\N	PRESENT	0
586711	585749	19691J	PARTICIPANT	\N	PRESENT	0
586712	585749	20046A	PARTICIPANT	\N	PRESENT	0
586714	585749	20024T	PARTICIPANT	\N	PRESENT	0
586715	585749	14089Y	PARTICIPANT	\N	PRESENT	0
586716	585409	12016W	PARTICIPANT	\N	PRESENT	0
586717	585749	20026V	PARTICIPANT	\N	PRESENT	0
586718	585749	14030Q	PARTICIPANT	\N	PRESENT	0
586719	585749	14217N	PARTICIPANT	\N	PRESENT	0
586720	585749	20056C	PARTICIPANT	\N	PRESENT	0
586721	585749	17637T	PARTICIPANT	\N	PRESENT	0
586722	585749	19503N	PARTICIPANT	\N	PRESENT	0
586723	585749	11012A	PARTICIPANT	\N	PRESENT	0
586724	585749	19515S	PARTICIPANT	\N	PRESENT	0
586725	585749	20098N	PARTICIPANT	\N	PRESENT	0
586726	585749	14259Y	PARTICIPANT	\N	PRESENT	0
586727	585749	14211G	PARTICIPANT	\N	PRESENT	0
586728	585749	19349W	PARTICIPANT	\N	PRESENT	0
586729	585749	07029T	PARTICIPANT	\N	PRESENT	0
586730	585749	19741B	PARTICIPANT	\N	PRESENT	0
586731	585749	11048N	PARTICIPANT	\N	PRESENT	0
586732	585749	19703U	PARTICIPANT	\N	PRESENT	0
586733	585749	20052X	PARTICIPANT	\N	PRESENT	0
586734	585749	19729F	PARTICIPANT	\N	PRESENT	0
574077	574076	14189C	PARTICIPANT	\N	PRESENT	0
574078	574076	20024T	PARTICIPANT	\N	PRESENT	0
574079	574076	14030Q	PARTICIPANT	\N	PRESENT	0
574080	574076	19693L	PARTICIPANT	\N	PRESENT	0
574081	574076	14109K	PARTICIPANT	\N	PRESENT	0
574082	574076	20046A	PARTICIPANT	\N	PRESENT	1
574083	574076	19749K	PARTICIPANT	\N	PRESENT	1
574084	574076	20056C	PARTICIPANT	\N	PRESENT	1
574085	574076	14179A	PARTICIPANT	\N	PRESENT	1
589415	588527	20066E	PARTICIPANT	\N	PRESENT	0
589416	588527	10006L	PRESIDENT	0	PRESENT	0
589417	588527	11067R	PARTICIPANT	\N	PRESENT	0
589418	588527	17779H	PARTICIPANT	\N	PRESENT	0
589419	588527	18193Q	PARTICIPANT	\N	PRESENT	0
589424	588527	19760E	PARTICIPANT	\N	PRESENT	0
589425	588527	19591F	PARTICIPANT	\N	PRESENT	0
589426	588527	19717B	PARTICIPANT	\N	PRESENT	0
589427	588527	19367Y	PARTICIPANT	\N	PRESENT	0
589428	588527	14042U	PARTICIPANT	\N	PRESENT	0
589429	588527	19415P	PARTICIPANT	\N	PRESENT	0
589430	588527	19663E	PARTICIPANT	\N	PRESENT	0
589431	588527	14217N	PARTICIPANT	\N	PRESENT	0
589432	588527	20248J	PARTICIPANT	\N	PRESENT	0
589433	588527	08045X	PARTICIPANT	\N	PRESENT	0
589434	588527	14223L	PARTICIPANT	\N	PRESENT	0
589435	588527	14071N	PARTICIPANT	\N	PRESENT	0
589436	588527	04092N	PARTICIPANT	\N	PRESENT	0
589437	588527	19679N	PARTICIPANT	\N	PRESENT	0
589438	588527	11097X	PARTICIPANT	\N	PRESENT	0
589439	588527	19703U	PARTICIPANT	\N	PRESENT	0
589443	588527	14026U	PARTICIPANT	\N	PRESENT	0
589444	588527	14195A	PARTICIPANT	\N	PRESENT	0
589446	588527	19798U	PARTICIPANT	\N	PRESENT	0
589448	588527	14213J	PARTICIPANT	\N	PRESENT	0
589449	588527	20090E	PARTICIPANT	\N	PRESENT	0
589454	588527	19569H	PARTICIPANT	\N	PRESENT	0
589455	588527	11031D	PARTICIPANT	\N	PRESENT	0
589461	588527	19697Q	PARTICIPANT	\N	PRESENT	0
589462	588527	11103C	PARTICIPANT	\N	PRESENT	1
589498	588527	19657G	PARTICIPANT	\N	PRESENT	1
589528	588527	20172F	PARTICIPANT	\N	PRESENT	0
589529	588527	04057K	PARTICIPANT	\N	PRESENT	0
589578	588527	19683J	PARTICIPANT	\N	PRESENT	0
589579	588527	14281W	PARTICIPANT	\N	PRESENT	0
589594	588527	19295A	PARTICIPANT	\N	PRESENT	0
589595	588527	17965H	PARTICIPANT	\N	PRESENT	0
589596	588527	01034P	PARTICIPANT	\N	PRESENT	0
589639	588527	19301E	PARTICIPANT	\N	PRESENT	1
589641	588527	20040T	PARTICIPANT	\N	PRESENT	0
589656	588527	19553Y	PARTICIPANT	\N	PRESENT	0
589673	589646	19573D	PARTICIPANT	\N	PRESENT	0
589680	589646	14229S	PARTICIPANT	\N	PRESENT	0
589675	589646	19533U	PARTICIPANT	\N	PRESENT	0
589676	589646	04033B	PARTICIPANT	\N	PRESENT	0
589677	589646	20084G	PARTICIPANT	\N	PRESENT	0
589678	589646	20026V	PARTICIPANT	\N	PRESENT	0
589679	589646	11104D	PARTICIPANT	\N	PRESENT	0
589781	588536	86034E	PARTICIPANT	\N	PRESENT	0
589782	588536	19511N	PARTICIPANT	\N	PRESENT	0
589783	588536	20266L	PARTICIPANT	\N	PRESENT	0
589791	588536	20028X	PARTICIPANT	\N	PRESENT	0
589792	588536	01025N	PARTICIPANT	\N	PRESENT	0
589793	588536	14223L	PARTICIPANT	\N	PRESENT	0
589795	588536	20090E	PARTICIPANT	\N	PRESENT	0
589797	588536	19741B	PARTICIPANT	\N	PRESENT	0
589799	588536	20062A	PARTICIPANT	\N	PRESENT	0
589800	588536	14173T	PARTICIPANT	\N	PRESENT	0
589801	588536	20102Q	PARTICIPANT	\N	PRESENT	0
590300	590298	19679N	PARTICIPANT	\N	PRESENT	0
590301	590299	19679N	PARTICIPANT	\N	PRESENT	0
590317	588528	19713W	PARTICIPANT	\N	PRESENT	1
590318	588528	10006L	PRESIDENT	0	PRESENT	0
590319	588528	20126Y	PARTICIPANT	\N	PRESENT	0
590320	588528	18193Q	PARTICIPANT	\N	PRESENT	0
590321	588528	04057K	PARTICIPANT	\N	PRESENT	0
590323	588528	17779H	PARTICIPANT	\N	PRESENT	0
590329	588528	19301E	PARTICIPANT	\N	PRESENT	0
590330	588528	14195A	PARTICIPANT	\N	PRESENT	0
590334	588528	19679N	PARTICIPANT	\N	PRESENT	1
590335	588528	04092N	PARTICIPANT	\N	PRESENT	0
590336	588528	01034P	PARTICIPANT	\N	PRESENT	0
590337	588528	19553Y	PARTICIPANT	\N	PRESENT	0
590338	588528	19415P	PARTICIPANT	\N	PRESENT	0
590339	588528	14213J	PARTICIPANT	\N	PRESENT	0
590341	588528	20066E	PARTICIPANT	\N	PRESENT	0
590343	588528	19703U	PARTICIPANT	\N	PRESENT	0
590344	588528	19798U	PARTICIPANT	\N	PRESENT	0
590345	588528	11097X	PARTICIPANT	\N	PRESENT	0
590346	588528	14071N	PARTICIPANT	\N	PRESENT	0
590347	588528	14217N	PARTICIPANT	\N	PRESENT	0
590348	588528	11103C	PARTICIPANT	\N	PRESENT	1
590349	588528	14042U	PARTICIPANT	\N	PRESENT	0
590352	590351	14219Q	PARTICIPANT	\N	EXCUSE	0
590354	588528	19663E	PARTICIPANT	\N	PRESENT	0
590399	588528	19715Y	PARTICIPANT	\N	PRESENT	0
590489	586370	12016W	PARTICIPANT	\N	PRESENT	1
590491	586370	11083R	PARTICIPANT	\N	PRESENT	0
590493	586370	14169X	PARTICIPANT	\N	PRESENT	0
590494	586370	20100N	PARTICIPANT	\N	EXCUSE	0
590496	590495	19549D	PARTICIPANT	\N	PRESENT	0
590497	590495	20124W	PARTICIPANT	\N	PRESENT	0
590498	590495	20038A	PARTICIPANT	\N	PRESENT	0
590499	590495	19701S	PARTICIPANT	\N	PRESENT	0
590500	590495	19820Y	PARTICIPANT	\N	PRESENT	0
590501	590495	19575F	PARTICIPANT	\N	PRESENT	0
590502	590495	20032T	PARTICIPANT	\N	PRESENT	0
590503	583608	14231L	PRESIDENT	0	PRESENT	0
590504	583608	05012A	PARTICIPANT	\N	PRESENT	0
590505	583608	04045F	PARTICIPANT	\N	PRESENT	0
590506	583608	14107H	PARTICIPANT	\N	PRESENT	0
590507	583608	20058E	PARTICIPANT	\N	PRESENT	0
590508	583608	20084G	PARTICIPANT	\N	EXCUSE	0
590509	583608	20022R	PARTICIPANT	\N	EXCUSE	0
590510	583608	20110Q	PARTICIPANT	\N	EXCUSE	0
590511	583608	14069U	PARTICIPANT	\N	PRESENT	0
590512	583608	20090E	PARTICIPANT	\N	PRESENT	0
590513	583608	14327T	PARTICIPANT	\N	PRESENT	0
590514	583608	14215L	PARTICIPANT	\N	EXCUSE	0
590515	583608	19758L	PARTICIPANT	\N	PRESENT	0
590516	583608	01057W	PARTICIPANT	\N	PRESENT	0
590517	583608	19826F	PARTICIPANT	\N	PRESENT	0
590518	583608	19349W	PARTICIPANT	\N	PRESENT	0
590519	583608	14053L	PARTICIPANT	\N	PRESENT	0
590520	583608	19489J	PARTICIPANT	\N	PRESENT	0
590521	583608	14205J	PARTICIPANT	\N	PRESENT	0
590522	583608	19565D	PARTICIPANT	\N	EXCUSE	0
590523	583608	19333N	PARTICIPANT	\N	EXCUSE	0
590524	583608	19735D	PARTICIPANT	\N	EXCUSE	0
590525	583608	20062A	PARTICIPANT	\N	PRESENT	0
590526	583608	20122U	PARTICIPANT	\N	EXCUSE	0
590527	583608	14229S	PARTICIPANT	\N	EXCUSE	0
590606	590603	19711U	PARTICIPANT	\N	PRESENT	0
590598	585691	20104S	PARTICIPANT	\N	PRESENT	0
590605	590603	14259Y	PRESIDENT	0	PRESENT	0
590607	590603	19479G	PARTICIPANT	\N	PRESENT	0
590608	590603	11056N	PARTICIPANT	\N	PRESENT	0
590609	590603	11040E	PARTICIPANT	\N	PRESENT	0
590610	590603	19703U	PARTICIPANT	\N	PRESENT	0
590611	590603	19399H	PARTICIPANT	\N	PRESENT	0
590612	590603	19643A	PARTICIPANT	\N	PRESENT	0
590613	590603	20032T	PARTICIPANT	\N	PRESENT	0
590614	590603	20018V	PARTICIPANT	\N	PRESENT	0
590615	590603	19954N	PARTICIPANT	\N	PRESENT	0
590616	590603	20042V	PARTICIPANT	\N	PRESENT	0
590617	590603	19747H	PARTICIPANT	\N	PRESENT	0
590618	590603	14193X	PARTICIPANT	\N	EXCUSE	0
590619	590603	95063L	PARTICIPANT	\N	EXCUSE	0
593662	593441	08012N	PARTICIPANT	\N	PRESENT	0
593660	593441	14026U	PARTICIPANT	\N	PRESENT	0
593661	593441	14207L	PARTICIPANT	\N	PRESENT	0
593663	593441	19709B	PARTICIPANT	\N	PRESENT	0
593664	593441	05012A	PARTICIPANT	\N	PRESENT	0
593665	593441	14147R	PARTICIPANT	\N	PRESENT	0
593666	593441	20062A	PARTICIPANT	\N	PRESENT	0
593670	593441	20044X	PARTICIPANT	\N	PRESENT	0
593668	593441	11101A	PARTICIPANT	\N	PRESENT	0
593669	593441	19954N	PARTICIPANT	\N	PRESENT	0
593671	593441	19369B	PARTICIPANT	\N	PRESENT	0
593672	593441	20116W	PARTICIPANT	\N	PRESENT	0
593673	593441	14001X	PARTICIPANT	\N	PRESENT	0
593674	593441	11054L	PARTICIPANT	\N	PRESENT	0
593675	593441	19866P	PARTICIPANT	\N	PRESENT	0
593676	593441	20108W	PARTICIPANT	\N	PRESENT	0
593677	593441	19643A	PARTICIPANT	\N	PRESENT	0
593678	593441	20034V	PARTICIPANT	\N	PRESENT	0
593679	593441	19335Q	PARTICIPANT	\N	PRESENT	0
593682	593441	20032T	PARTICIPANT	\N	PRESENT	0
593683	593441	14281W	PARTICIPANT	\N	PRESENT	0
593687	593441	12041X	PARTICIPANT	\N	PRESENT	0
593689	593441	14083S	PARTICIPANT	\N	PRESENT	0
593692	593441	07004J	PARTICIPANT	\N	PRESENT	0
593695	593441	14031R	PARTICIPANT	\N	PRESENT	0
593696	593441	08009T	PARTICIPANT	\N	PRESENT	0
593699	593441	19725B	PARTICIPANT	\N	PRESENT	0
593700	593441	14237S	PARTICIPANT	\N	PRESENT	0
593704	593441	14169X	PARTICIPANT	\N	PRESENT	0
593705	593441	19820Y	PARTICIPANT	\N	PRESENT	0
593706	593441	19758L	PARTICIPANT	\N	PRESENT	0
593707	593441	19621T	PARTICIPANT	\N	PRESENT	0
593708	593441	19573D	PARTICIPANT	\N	PRESENT	0
593709	593441	08073C	PARTICIPANT	\N	PRESENT	0
593720	593441	20140W	PARTICIPANT	\N	PRESENT	0
593711	593441	20172F	PARTICIPANT	\N	PRESENT	0
593712	593441	19531S	PARTICIPANT	\N	PRESENT	0
593713	593441	20082E	PARTICIPANT	\N	PRESENT	0
593714	593441	14249W	PARTICIPANT	\N	PRESENT	0
593715	593441	19637C	PARTICIPANT	\N	PRESENT	0
593716	593441	20134Y	PARTICIPANT	\N	PRESENT	0
593717	593441	11115U	PARTICIPANT	\N	PRESENT	0
593718	593441	20124W	PARTICIPANT	\N	PRESENT	0
593719	593441	01024M	PARTICIPANT	\N	PRESENT	0
593721	593441	08015R	PARTICIPANT	\N	PRESENT	0
593722	593441	19713W	PARTICIPANT	\N	PRESENT	0
593723	593441	04043D	PARTICIPANT	\N	PRESENT	0
593724	593441	19503N	PARTICIPANT	\N	PRESENT	0
593725	593441	19685L	PARTICIPANT	\N	PRESENT	0
593726	593441	19399H	PARTICIPANT	\N	PRESENT	0
593727	593441	20122U	PARTICIPANT	\N	PRESENT	0
593739	593442	14073Q	PARTICIPANT	\N	PRESENT	0
593740	593442	19447X	PARTICIPANT	\N	PRESENT	0
593745	593442	17737W	PARTICIPANT	\N	PRESENT	0
593746	593442	04085P	PARTICIPANT	\N	PRESENT	0
593747	593442	01028R	PARTICIPANT	\N	PRESENT	0
593779	593442	19651A	PARTICIPANT	\N	PRESENT	0
593738	593442	11070L	PARTICIPANT	\N	PRESENT	0
593748	593442	19649G	PARTICIPANT	\N	PRESENT	0
593749	593442	20072C	PARTICIPANT	\N	PRESENT	0
593750	593442	19629C	PARTICIPANT	\N	PRESENT	0
593751	593442	07004J	PARTICIPANT	\N	PRESENT	0
593752	593442	14215L	PARTICIPANT	\N	PRESENT	0
593753	593442	20152B	PARTICIPANT	\N	PRESENT	0
593754	593442	08056B	PARTICIPANT	\N	PRESENT	0
593755	593442	19798U	PARTICIPANT	\N	PRESENT	0
593756	593442	11103C	PARTICIPANT	\N	PRESENT	0
593757	593442	20110Q	PARTICIPANT	\N	PRESENT	0
593777	593442	19671E	PARTICIPANT	\N	PRESENT	0
593778	593442	20024T	PARTICIPANT	\N	PRESENT	0
593780	593442	19699S	PARTICIPANT	\N	PRESENT	0
593781	593442	14267Y	PARTICIPANT	\N	PRESENT	0
593782	593442	20048C	PARTICIPANT	\N	PRESENT	0
593783	593442	19367Y	PARTICIPANT	\N	PRESENT	0
593784	593442	20078J	PARTICIPANT	\N	PRESENT	0
593785	593442	20076G	PARTICIPANT	\N	PRESENT	0
593786	593442	20062A	PARTICIPANT	\N	PRESENT	0
593787	593442	14107H	PARTICIPANT	\N	PRESENT	0
593788	593442	01025N	PARTICIPANT	\N	PRESENT	0
593789	593442	19467C	PARTICIPANT	\N	PRESENT	0
593790	593442	20044X	PARTICIPANT	\N	PRESENT	0
593791	593442	19760E	PARTICIPANT	\N	PRESENT	0
593792	593442	14223L	PARTICIPANT	\N	PRESENT	0
593793	593442	04008A	PARTICIPANT	\N	PRESENT	0
593794	593442	11099A	PARTICIPANT	\N	PRESENT	0
593801	593442	19762G	PARTICIPANT	\N	PRESENT	0
593802	593442	19673G	PARTICIPANT	\N	PRESENT	0
593803	593442	20092G	PARTICIPANT	\N	PRESENT	0
593805	593442	14231L	PARTICIPANT	\N	PRESENT	0
593809	593442	19747H	PARTICIPANT	\N	PRESENT	0
593810	593442	19543W	PARTICIPANT	\N	PRESENT	0
593813	593442	20140W	PARTICIPANT	\N	PRESENT	0
593814	593442	19725B	PARTICIPANT	\N	PRESENT	0
593815	593442	20252E	PARTICIPANT	\N	PRESENT	0
593819	593442	19333N	PARTICIPANT	\N	PRESENT	0
593820	593442	14147R	PARTICIPANT	\N	PRESENT	0
593821	593442	19954N	PARTICIPANT	\N	PRESENT	0
593822	593442	19826F	PARTICIPANT	\N	PRESENT	0
593824	593442	11066Q	PARTICIPANT	\N	PRESENT	0
593825	593442	19415P	PARTICIPANT	\N	PRESENT	0
593826	593442	20128B	PARTICIPANT	\N	PRESENT	0
593827	593442	20022R	PARTICIPANT	\N	PRESENT	0
593828	593442	04043D	PARTICIPANT	\N	PRESENT	0
593829	593442	19515S	PARTICIPANT	\N	PRESENT	0
593830	593442	18083K	PARTICIPANT	\N	PRESENT	0
593831	593442	20098N	PARTICIPANT	\N	PRESENT	0
593832	593442	19631V	PARTICIPANT	\N	PRESENT	0
593833	593442	01043Q	PARTICIPANT	\N	PRESENT	0
593834	593442	19441R	PARTICIPANT	\N	PRESENT	0
593835	593442	10015M	PARTICIPANT	\N	PRESENT	0
593837	593442	20082E	PARTICIPANT	\N	PRESENT	0
593839	593545	14327T	PARTICIPANT	\N	PRESENT	0
593840	593545	14331P	PARTICIPANT	\N	PRESENT	0
593841	593545	19647E	PARTICIPANT	\N	PRESENT	0
593842	593545	19711U	PARTICIPANT	\N	PRESENT	0
593843	593545	01057W	PARTICIPANT	\N	PRESENT	0
593844	593545	20080C	PARTICIPANT	\N	PRESENT	0
593845	593545	20044X	PARTICIPANT	\N	PRESENT	0
593846	593545	19671E	PARTICIPANT	\N	PRESENT	0
593847	593545	14225N	PRESIDENT	0	PRESENT	0
593848	593545	14173T	PARTICIPANT	\N	PRESENT	0
593849	593545	07029T	PARTICIPANT	\N	PRESENT	0
593850	593545	20252E	PARTICIPANT	\N	PRESENT	0
593851	593545	20070A	PARTICIPANT	\N	PRESENT	0
593852	593545	19741B	PARTICIPANT	\N	PRESENT	0
593853	593545	20116W	PARTICIPANT	\N	PRESENT	0
593854	593545	19335Q	PARTICIPANT	\N	PRESENT	0
593855	593545	20126Y	PARTICIPANT	\N	PRESENT	0
593879	593545	19479G	PARTICIPANT	\N	PRESENT	0
593880	593545	08011M	PARTICIPANT	\N	PRESENT	0
593898	593545	11012A	PARTICIPANT	\N	PRESENT	0
593899	590931	19681G	PARTICIPANT	\N	PRESENT	1
593900	590931	20140W	PARTICIPANT	\N	PRESENT	0
593901	590931	14219Q	PARTICIPANT	\N	EXCUSE	0
593902	590931	20136B	PARTICIPANT	\N	PRESENT	0
593903	590931	14237S	PARTICIPANT	\N	PRESENT	0
593904	590931	20118Y	PARTICIPANT	\N	PRESENT	0
593905	590931	11101A	PARTICIPANT	\N	PRESENT	0
593906	590931	19637C	PARTICIPANT	\N	PRESENT	0
593907	590931	19685L	PARTICIPANT	\N	PRESENT	0
593910	590931	05012A	PARTICIPANT	\N	PRESENT	0
593911	590931	19619A	PARTICIPANT	\N	PRESENT	0
593912	590931	19503N	PARTICIPANT	\N	PRESENT	0
593913	593545	14083S	PARTICIPANT	\N	PRESENT	0
593914	593545	19687N	PARTICIPANT	\N	PRESENT	0
593923	590928	20068G	PARTICIPANT	\N	PRESENT	0
593924	590928	19251M	PARTICIPANT	\N	PRESENT	0
593925	590928	17229F	PARTICIPANT	\N	PRESENT	0
593926	590928	18083K	PARTICIPANT	\N	PRESENT	0
593927	590928	19333N	PARTICIPANT	\N	PRESENT	0
593928	590928	20140W	PARTICIPANT	\N	PRESENT	0
593929	590928	19826F	PARTICIPANT	\N	PRESENT	0
593930	590928	17367Q	PARTICIPANT	\N	PRESENT	0
593931	590928	19701S	PARTICIPANT	\N	PRESENT	1
593932	590928	20136B	PARTICIPANT	\N	PRESENT	1
593933	590928	19387D	PARTICIPANT	\N	PRESENT	1
593934	590928	14031R	PARTICIPANT	\N	PRESENT	0
593935	590928	20076G	PARTICIPANT	\N	PRESENT	0
593936	590928	14219Q	PRESIDENT	0	PRESENT	0
593937	590928	20102Q	PARTICIPANT	\N	PRESENT	0
593938	590928	19637C	PARTICIPANT	\N	PRESENT	0
576410	575268	01048V	PARTICIPANT	\N	PRESENT	0
576411	575268	19329S	PARTICIPANT	\N	PRESENT	0
576412	575268	19575F	PARTICIPANT	\N	PRESENT	0
576413	575268	19717B	PARTICIPANT	\N	PRESENT	0
576414	575268	19347U	PARTICIPANT	\N	PRESENT	0
576415	575268	14259Y	PARTICIPANT	\N	PRESENT	0
576416	575268	14223L	PARTICIPANT	\N	PRESENT	0
576417	575268	20072C	PARTICIPANT	\N	PRESENT	0
576418	575268	20022R	PARTICIPANT	\N	PRESENT	0
576419	575268	14215L	PARTICIPANT	\N	PRESENT	0
576420	575268	14217N	PARTICIPANT	\N	PRESENT	0
576421	575268	05008E	PARTICIPANT	\N	PRESENT	0
576422	575268	14221J	PARTICIPANT	\N	PRESENT	0
576423	575268	04057K	PARTICIPANT	\N	PRESENT	0
576424	575268	19671E	PARTICIPANT	\N	PRESENT	0
576425	575268	19581D	PARTICIPANT	\N	PRESENT	0
576426	575268	19599P	PARTICIPANT	\N	PRESENT	0
576427	575268	19621T	PARTICIPANT	\N	PRESENT	0
576428	575268	01028R	PARTICIPANT	\N	PRESENT	0
576429	575268	11031D	PARTICIPANT	\N	PRESENT	0
576430	575268	11040E	PARTICIPANT	\N	PRESENT	0
576431	575268	19367Y	PARTICIPANT	\N	PRESENT	0
576432	575268	20020P	PARTICIPANT	\N	PRESENT	0
576433	575268	19762G	PARTICIPANT	\N	PRESENT	0
576434	575268	14021P	PARTICIPANT	\N	PRESENT	0
576435	575268	20148F	PARTICIPANT	\N	PRESENT	0
576436	575268	14229S	PARTICIPANT	\N	PRESENT	0
576437	575268	20126Y	PARTICIPANT	\N	PRESENT	0
576438	575268	11045K	PARTICIPANT	\N	PRESENT	0
576439	575268	19649G	PARTICIPANT	\N	PRESENT	0
576440	575268	17965H	PARTICIPANT	\N	PRESENT	0
576441	575268	01062T	PARTICIPANT	\N	PRESENT	0
576442	575268	19675J	PARTICIPANT	\N	PRESENT	0
576443	575268	20128B	PARTICIPANT	\N	PRESENT	0
576444	575268	20092G	PARTICIPANT	\N	PRESENT	0
576445	575268	20062A	PARTICIPANT	\N	PRESENT	0
576446	575268	11067R	PARTICIPANT	\N	PRESENT	0
576447	575268	20090E	PARTICIPANT	\N	PRESENT	0
576448	575268	20114U	PARTICIPANT	\N	PRESENT	0
576449	575268	14059S	PARTICIPANT	\N	PRESENT	0
576450	575268	08045X	PARTICIPANT	\N	PRESENT	0
576451	575268	08056B	PARTICIPANT	\N	PRESENT	0
576452	575268	20124W	PARTICIPANT	\N	PRESENT	0
576453	575268	14281W	PARTICIPANT	\N	PRESENT	0
576454	575268	19549D	PARTICIPANT	\N	PRESENT	0
576455	575268	20038A	PARTICIPANT	\N	PRESENT	0
576456	575268	11026G	PARTICIPANT	\N	PRESENT	0
576457	575268	19413M	PARTICIPANT	\N	PRESENT	0
576458	575268	19667J	PARTICIPANT	\N	PRESENT	0
576459	575268	18193Q	PARTICIPANT	\N	PRESENT	0
576460	575268	14253S	PARTICIPANT	\N	PRESENT	0
576461	575268	20080C	PARTICIPANT	\N	PRESENT	0
576462	575268	11048N	PARTICIPANT	\N	PRESENT	0
576463	575268	14173T	PARTICIPANT	\N	PRESENT	0
576464	575268	19715Y	PARTICIPANT	\N	PRESENT	0
576465	575268	19447X	PARTICIPANT	\N	PRESENT	0
576466	575268	19503N	PARTICIPANT	\N	PRESENT	0
576467	575268	20026V	PARTICIPANT	\N	PRESENT	0
576468	575268	20070A	PARTICIPANT	\N	PRESENT	0
576469	575268	08012N	PARTICIPANT	\N	PRESENT	0
576470	575268	19954N	PARTICIPANT	\N	PRESENT	0
576471	575268	14147R	PARTICIPANT	\N	PRESENT	0
576472	575268	20094J	PARTICIPANT	\N	PRESENT	0
576473	575268	19631V	PARTICIPANT	\N	PRESENT	0
576474	575268	19527W	PARTICIPANT	\N	PRESENT	0
576475	575268	19705W	PARTICIPANT	\N	PRESENT	0
576476	575268	19768N	PARTICIPANT	\N	PRESENT	0
576477	575268	19643A	PARTICIPANT	\N	PRESENT	0
576478	575268	19251M	PARTICIPANT	\N	PRESENT	0
576479	575268	19729F	PARTICIPANT	\N	PRESENT	0
576480	575268	20064C	PARTICIPANT	\N	PRESENT	0
576481	575268	07029T	PARTICIPANT	\N	PRESENT	0
576482	575268	19657G	PARTICIPANT	\N	PRESENT	0
576483	575268	14249W	PARTICIPANT	\N	PRESENT	0
576484	575268	11064N	PARTICIPANT	\N	PRESENT	0
576485	575268	14251Q	PARTICIPANT	\N	PRESENT	0
576486	575268	14026U	PARTICIPANT	\N	PRESENT	0
576487	575268	14038Y	PARTICIPANT	\N	PRESENT	0
576488	575268	19741B	PARTICIPANT	\N	PRESENT	0
576489	575268	14231L	PARTICIPANT	\N	PRESENT	0
576490	575268	19399H	PARTICIPANT	\N	PRESENT	0
576491	575268	19691J	PARTICIPANT	\N	PRESENT	0
576492	575268	20104S	PARTICIPANT	\N	PRESENT	0
576493	575268	19611R	PARTICIPANT	\N	PRESENT	0
576494	575268	19443T	PARTICIPANT	\N	PRESENT	0
576495	575268	14109K	PARTICIPANT	\N	PRESENT	0
576496	575268	19507S	PARTICIPANT	\N	PRESENT	0
576497	575268	11053K	PARTICIPANT	\N	PRESENT	0
576498	575268	14205J	PARTICIPANT	\N	PRESENT	0
576499	575268	14267Y	PARTICIPANT	\N	PRESENT	0
576500	575268	20044X	PARTICIPANT	\N	PRESENT	0
576501	575268	01024M	PARTICIPANT	\N	PRESENT	0
576502	575268	19723Y	PARTICIPANT	\N	PRESENT	0
576503	575268	14089Y	PARTICIPANT	\N	PRESENT	0
576504	575268	14083S	PARTICIPANT	\N	PRESENT	0
576505	575268	19749K	PARTICIPANT	\N	PRESENT	0
576518	575268	19533U	PARTICIPANT	\N	PRESENT	0
576507	575268	11085T	PARTICIPANT	\N	PRESENT	0
576508	575268	19699S	PARTICIPANT	\N	PRESENT	0
576509	575268	20048C	PARTICIPANT	\N	PRESENT	0
576510	575268	20052X	PARTICIPANT	\N	PRESENT	0
576511	575268	14097Y	PARTICIPANT	\N	PRESENT	0
576512	575268	19479G	PARTICIPANT	\N	PRESENT	0
576513	575268	14193X	PARTICIPANT	\N	PRESENT	0
576514	575268	14219Q	PARTICIPANT	\N	PRESENT	0
576515	575268	14042U	PARTICIPANT	\N	PRESENT	0
576516	575268	16685X	PARTICIPANT	\N	PRESENT	0
576517	575268	20036X	PARTICIPANT	\N	PRESENT	0
576519	575268	14327T	PARTICIPANT	\N	PRESENT	0
576520	575268	20066E	PARTICIPANT	\N	PRESENT	0
576521	575268	19577H	PARTICIPANT	\N	PRESENT	0
576522	575268	11043H	PARTICIPANT	\N	PRESENT	0
576523	575268	20034V	PARTICIPANT	\N	PRESENT	0
576524	575268	20058E	PARTICIPANT	\N	PRESENT	0
576525	575268	04043D	PARTICIPANT	\N	PRESENT	0
576526	575268	20096L	PARTICIPANT	\N	PRESENT	0
576527	575268	14213J	PARTICIPANT	\N	PRESENT	0
576528	575268	17023S	PARTICIPANT	\N	PRESENT	0
576529	575268	14189C	PARTICIPANT	\N	PRESENT	0
576530	575268	14179A	PARTICIPANT	\N	PRESENT	0
576531	575268	11090Q	PARTICIPANT	\N	PRESENT	0
576532	575268	11033F	PARTICIPANT	\N	PRESENT	0
576533	575268	01060R	PARTICIPANT	\N	PRESENT	0
576534	575268	11012A	PARTICIPANT	\N	PRESENT	0
576535	575268	19551W	PARTICIPANT	\N	PRESENT	0
576536	575268	14069U	PARTICIPANT	\N	PRESENT	0
576537	575268	20042V	PARTICIPANT	\N	PRESENT	0
576538	575268	19467C	PARTICIPANT	\N	PRESENT	0
576539	575268	19735D	PARTICIPANT	\N	PRESENT	0
576781	575269	86034E	PARTICIPANT	\N	PRESENT	0
576782	575269	14195A	PARTICIPANT	\N	PRESENT	0
576783	575269	01060R	PARTICIPANT	\N	PRESENT	0
576784	575269	14001X	PARTICIPANT	\N	PRESENT	0
576785	575269	11056N	PARTICIPANT	\N	PRESENT	0
576786	575269	19758L	PARTICIPANT	\N	PRESENT	0
576787	575269	14259Y	PARTICIPANT	\N	PRESENT	0
576788	575269	19629C	PARTICIPANT	\N	PRESENT	0
576789	575269	95063L	PARTICIPANT	\N	PRESENT	0
576790	575269	19820Y	PARTICIPANT	\N	PRESENT	0
576791	575269	19695N	PARTICIPANT	\N	PRESENT	0
576792	575269	14169X	PARTICIPANT	\N	PRESENT	0
576793	575269	10015M	PARTICIPANT	\N	PRESENT	0
576794	575269	20098N	PARTICIPANT	\N	PRESENT	0
576795	575269	20026V	PARTICIPANT	\N	PRESENT	0
576796	575269	20180F	PARTICIPANT	\N	PRESENT	0
576797	575269	20076G	PARTICIPANT	\N	PRESENT	0
576798	575269	20020P	PARTICIPANT	\N	PRESENT	0
576804	575269	20082E	PARTICIPANT	\N	PRESENT	0
576805	575269	19489J	PARTICIPANT	\N	PRESENT	0
576806	575269	14225N	PARTICIPANT	\N	PRESENT	0
576807	575269	14231L	PARTICIPANT	\N	PRESENT	0
576808	575269	20100N	PARTICIPANT	\N	PRESENT	0
576809	575269	20092G	PARTICIPANT	\N	PRESENT	0
576810	575269	20110Q	PARTICIPANT	\N	PRESENT	0
576811	575269	19387D	PARTICIPANT	\N	PRESENT	0
576812	575269	14107H	PARTICIPANT	\N	PRESENT	0
576813	575269	20174H	PARTICIPANT	\N	PRESENT	0
576814	575269	14327T	PARTICIPANT	\N	PRESENT	0
576815	575269	19479G	PARTICIPANT	\N	PRESENT	0
576816	575269	19441R	PARTICIPANT	\N	PRESENT	0
586801	585751	14053L	PARTICIPANT	\N	PRESENT	0
586802	585751	20098N	PARTICIPANT	\N	PRESENT	0
586803	585751	14259Y	PARTICIPANT	\N	PRESENT	0
586804	585751	19749K	PARTICIPANT	\N	PRESENT	0
586805	585751	20110Q	PARTICIPANT	\N	PRESENT	0
586806	585751	11056N	PARTICIPANT	\N	PRESENT	0
586807	585751	20086J	PARTICIPANT	\N	PRESENT	0
586808	585751	20114U	PARTICIPANT	\N	PRESENT	0
586809	585751	20074E	PARTICIPANT	\N	PRESENT	0
586822	585751	11072N	PARTICIPANT	\N	PRESENT	0
586811	585751	19629C	PARTICIPANT	\N	PRESENT	0
586812	585751	20028X	PARTICIPANT	\N	PRESENT	0
586813	585751	19649G	PARTICIPANT	\N	PRESENT	0
586814	585751	14105F	PARTICIPANT	\N	PRESENT	0
586815	585751	01048V	PARTICIPANT	\N	PRESENT	0
586816	585751	14089Y	PARTICIPANT	\N	PRESENT	0
586817	585751	19367Y	PARTICIPANT	\N	PRESENT	0
586818	585751	14215L	PARTICIPANT	\N	PRESENT	0
586819	585751	20138D	PARTICIPANT	\N	PRESENT	0
586820	585751	20108W	PARTICIPANT	\N	PRESENT	0
586821	585751	01028R	PARTICIPANT	\N	PRESENT	0
586823	585751	19349W	PARTICIPANT	\N	PRESENT	0
586824	585751	14033T	PARTICIPANT	\N	PRESENT	0
586825	585751	20248J	PARTICIPANT	\N	PRESENT	0
586826	585751	14107H	PARTICIPANT	\N	PRESENT	0
586827	585751	19413M	PARTICIPANT	\N	PRESENT	0
586828	585751	05008E	PARTICIPANT	\N	PRESENT	0
586829	585751	20090E	PARTICIPANT	\N	PRESENT	0
586830	585751	19585H	PARTICIPANT	\N	PRESENT	0
586831	585751	04085P	PARTICIPANT	\N	PRESENT	0
586832	585751	19565D	PARTICIPANT	\N	PRESENT	0
586833	585751	20046A	PARTICIPANT	\N	PRESENT	0
586834	585751	95063L	PARTICIPANT	\N	PRESENT	0
586835	585751	19782L	PARTICIPANT	\N	PRESENT	0
586836	585751	04033B	PARTICIPANT	\N	PRESENT	0
586837	585751	20174H	PARTICIPANT	\N	PRESENT	0
586838	585751	14026U	PARTICIPANT	\N	PRESENT	0
586839	585751	19447X	PARTICIPANT	\N	PRESENT	0
586840	585751	20128B	PARTICIPANT	\N	PRESENT	0
586841	585751	19531S	PARTICIPANT	\N	PRESENT	0
586842	585751	20082E	PARTICIPANT	\N	PRESENT	0
586843	585751	19383Y	PARTICIPANT	\N	PRESENT	0
586844	585751	19507S	PARTICIPANT	\N	PRESENT	0
586845	585751	19768N	PARTICIPANT	\N	PRESENT	0
586846	585751	18083K	PARTICIPANT	\N	PRESENT	0
586847	585751	20048C	PARTICIPANT	\N	PRESENT	0
586848	585751	14187A	PARTICIPANT	\N	PRESENT	0
586849	585751	20180F	PARTICIPANT	\N	PRESENT	0
586850	585751	20026V	PARTICIPANT	\N	PRESENT	0
586851	585751	19954N	PARTICIPANT	\N	PRESENT	0
586852	585751	17637T	PARTICIPANT	\N	PRESENT	0
586853	585751	20032T	PARTICIPANT	\N	PRESENT	0
586854	585751	20140W	PARTICIPANT	\N	PRESENT	0
586855	585751	20056C	PARTICIPANT	\N	PRESENT	0
586856	585751	19563B	PARTICIPANT	\N	PRESENT	0
586857	585751	20022R	PARTICIPANT	\N	PRESENT	0
586793	585751	11070L	PARTICIPANT	\N	PRESENT	0
586800	585751	04047H	PARTICIPANT	\N	PRESENT	0
586858	585751	14213J	PARTICIPANT	\N	PRESENT	0
586859	585751	08061X	PARTICIPANT	\N	PRESENT	0
586860	585751	19729F	PARTICIPANT	\N	PRESENT	0
586861	585751	20172F	PARTICIPANT	\N	PRESENT	0
586862	585751	07029T	PARTICIPANT	\N	PRESENT	0
586863	585751	20058E	PARTICIPANT	\N	PRESENT	0
586864	585751	20120S	PARTICIPANT	\N	PRESENT	0
587183	587181	19679N	PARTICIPANT	\N	PRESENT	0
587184	587182	19679N	PARTICIPANT	\N	PRESENT	0
587187	585691	20060X	PARTICIPANT	\N	PRESENT	0
587188	585691	20144B	PARTICIPANT	\N	PRESENT	0
587189	585691	20174H	PARTICIPANT	\N	PRESENT	1
587191	585691	20028X	PARTICIPANT	\N	PRESENT	0
587192	587190	20066E	PARTICIPANT	\N	PRESENT	0
587193	585691	19369B	PARTICIPANT	\N	PRESENT	0
587194	585691	19768N	PARTICIPANT	\N	PRESENT	0
587213	587212	20066E	PARTICIPANT	\N	PRESENT	0
587216	587215	19515S	PARTICIPANT	\N	PRESENT	0
587217	587215	19651A	PARTICIPANT	\N	PRESENT	0
587218	587215	20086J	PARTICIPANT	\N	PRESENT	0
587219	587215	14105F	PARTICIPANT	\N	PRESENT	0
587220	587215	17737W	PARTICIPANT	\N	PRESENT	0
587221	587215	14259Y	PARTICIPANT	\N	PRESENT	0
587222	587215	20038A	PARTICIPANT	\N	PRESENT	0
587223	587215	19647E	PARTICIPANT	\N	PRESENT	0
587224	587215	20132W	PARTICIPANT	\N	PRESENT	0
587225	587215	19565D	PARTICIPANT	\N	PRESENT	0
587226	587215	20128B	PARTICIPANT	\N	PRESENT	0
587227	587215	20126Y	PARTICIPANT	\N	PRESENT	0
587228	587215	19735D	PARTICIPANT	\N	PRESENT	0
587229	587215	19709B	PARTICIPANT	\N	PRESENT	0
587230	587215	08010L	PARTICIPANT	\N	PRESENT	0
587231	587215	04070G	PARTICIPANT	\N	PRESENT	0
587232	587215	20096L	PARTICIPANT	\N	PRESENT	0
587233	587215	19533U	PARTICIPANT	\N	PRESENT	0
587234	587215	14331P	PARTICIPANT	\N	PRESENT	0
587235	587215	95063L	PARTICIPANT	\N	PRESENT	0
587236	587215	20098N	PARTICIPANT	\N	PRESENT	0
587237	587215	20064C	PARTICIPANT	\N	PRESENT	0
587238	587215	04034C	PARTICIPANT	\N	PRESENT	0
587239	587214	20066E	PARTICIPANT	\N	PRESENT	0
587240	587215	20252E	PARTICIPANT	\N	PRESENT	0
587242	587241	20032T	PARTICIPANT	\N	PRESENT	0
587243	587241	19575F	PARTICIPANT	\N	PRESENT	0
587244	587241	20140W	PARTICIPANT	\N	PRESENT	0
587245	587241	14033T	PARTICIPANT	\N	PRESENT	0
587246	587241	14205J	PARTICIPANT	\N	PRESENT	0
587247	587241	14059S	PARTICIPANT	\N	PRESENT	0
587248	587241	20028X	PARTICIPANT	\N	PRESENT	0
587249	587241	19745F	PARTICIPANT	\N	PRESENT	0
587250	587241	20082E	PARTICIPANT	\N	PRESENT	0
587251	587241	20118Y	PARTICIPANT	\N	PRESENT	0
587252	587241	20054A	PARTICIPANT	\N	PRESENT	0
587253	587241	11097X	PARTICIPANT	\N	PRESENT	0
587254	587241	19762G	PARTICIPANT	\N	PRESENT	0
587255	587241	19713W	PARTICIPANT	\N	PRESENT	0
587256	585810	17779H	PARTICIPANT	\N	PRESENT	0
587257	585810	19687N	PARTICIPANT	\N	PRESENT	0
587259	585810	14217N	PARTICIPANT	\N	PRESENT	0
587260	585810	14357A	PARTICIPANT	\N	PRESENT	0
587261	585810	20020P	PARTICIPANT	\N	PRESENT	0
587262	585810	19749K	PARTICIPANT	\N	PRESENT	0
587263	585810	19685L	PARTICIPANT	\N	PRESENT	0
587264	585810	19679N	PARTICIPANT	\N	PRESENT	0
587265	585810	20128B	PARTICIPANT	\N	PRESENT	0
587266	585810	19551W	PARTICIPANT	\N	PRESENT	0
587267	585810	19575F	PRESIDENT	0	PRESENT	0
587269	587258	14213J	PARTICIPANT	\N	PRESENT	0
587270	585810	14083S	PARTICIPANT	\N	PRESENT	1
587271	587258	18193Q	PARTICIPANT	\N	PRESENT	0
587280	587278	18193Q	PARTICIPANT	\N	PRESENT	0
587273	585810	14329V	PARTICIPANT	\N	PRESENT	0
587279	587278	14213J	PARTICIPANT	\N	PRESENT	0
587281	587278	11067R	PARTICIPANT	\N	PRESENT	0
587282	585810	14071N	PARTICIPANT	\N	EXCUSE	0
587283	585810	19545Y	PARTICIPANT	\N	EXCUSE	0
587284	585810	19369B	PARTICIPANT	\N	EXCUSE	0
587286	587285	14213J	PARTICIPANT	\N	PRESENT	0
587287	585912	04059M	PARTICIPANT	\N	PRESENT	0
587288	585912	20112S	PARTICIPANT	\N	PRESENT	1
587289	585912	19651A	PARTICIPANT	\N	PRESENT	0
587290	585912	14030Q	PARTICIPANT	\N	PRESENT	0
587291	585912	20138D	PARTICIPANT	\N	PRESENT	0
587292	585912	19643A	PARTICIPANT	\N	PRESENT	0
587293	585912	20152B	PARTICIPANT	\N	PRESENT	0
587294	585912	19621T	PARTICIPANT	\N	EXCUSE	0
587295	585912	19758L	PARTICIPANT	\N	PRESENT	0
587296	585912	19693L	PARTICIPANT	\N	PRESENT	0
587297	585912	20134Y	PARTICIPANT	\N	PRESENT	1
587298	585912	20124W	PARTICIPANT	\N	PRESENT	1
587299	585912	20132W	PARTICIPANT	\N	PRESENT	0
587300	585912	20180F	PARTICIPANT	\N	PRESENT	1
587301	585912	14123H	PARTICIPANT	\N	PRESENT	1
587302	585912	20048C	PARTICIPANT	\N	PRESENT	1
587303	585912	19399H	PARTICIPANT	\N	PRESENT	0
587304	585912	20056C	PARTICIPANT	\N	PRESENT	0
587305	585912	19611R	PRESIDENT	0	PRESENT	0
587306	585912	19735D	PARTICIPANT	\N	PRESENT	0
587307	585912	19699S	PARTICIPANT	\N	PRESENT	0
587308	585912	20052X	PARTICIPANT	\N	PRESENT	0
587309	585912	11104D	PARTICIPANT	\N	PRESENT	1
587310	585912	20142Y	PARTICIPANT	\N	PRESENT	0
587311	585912	04070G	PARTICIPANT	\N	PRESENT	0
570285	570283	20082E	PARTICIPANT	\N	PRESENT	1
570286	570283	19782L	PARTICIPANT	\N	PRESENT	1
570288	570283	19631V	PARTICIPANT	\N	PRESENT	1
570289	570283	14109K	PARTICIPANT	\N	PRESENT	1
570290	570283	19575F	PARTICIPANT	\N	PRESENT	1
570291	570283	11097X	PARTICIPANT	\N	PRESENT	0
570292	570283	11099A	PARTICIPANT	\N	PRESENT	0
570293	570283	08015R	PARTICIPANT	\N	PRESENT	0
570294	570283	19369B	PARTICIPANT	\N	PRESENT	0
570295	570283	19503N	PARTICIPANT	\N	PRESENT	0
570296	570283	20018V	PARTICIPANT	\N	PRESENT	0
570297	570283	14169X	PARTICIPANT	\N	PRESENT	0
572464	572013	20056C	PARTICIPANT	\N	PRESENT	0
572465	572013	19954N	PARTICIPANT	\N	PRESENT	0
572466	572013	20062A	PARTICIPANT	\N	PRESENT	0
572467	572013	20098N	PARTICIPANT	\N	PRESENT	0
572468	572013	20180F	PARTICIPANT	\N	PRESENT	0
572469	572013	20096L	PARTICIPANT	\N	PRESENT	0
572470	572013	01057W	PARTICIPANT	\N	PRESENT	0
572471	572013	14357A	PARTICIPANT	\N	PRESENT	0
572472	572013	19515S	PARTICIPANT	\N	PRESENT	0
572473	572013	99004R	PARTICIPANT	\N	PRESENT	0
572474	572013	01048V	PARTICIPANT	\N	PRESENT	0
572475	572013	08034U	PARTICIPANT	\N	PRESENT	0
572476	572013	11027H	PARTICIPANT	\N	PRESENT	0
572477	572013	11083R	PARTICIPANT	\N	PRESENT	0
572478	572013	19349W	PARTICIPANT	\N	PRESENT	0
572479	572013	11064N	PARTICIPANT	\N	PRESENT	0
572480	572013	14221J	PARTICIPANT	\N	PRESENT	0
572644	571148	19719D	PARTICIPANT	\N	PRESENT	0
572482	572013	19347U	PARTICIPANT	\N	PRESENT	0
572483	572013	01058X	PARTICIPANT	\N	PRESENT	0
572484	572013	19747H	PARTICIPANT	\N	PRESENT	0
572485	572013	01024M	PARTICIPANT	\N	PRESENT	0
572486	572013	04045F	PARTICIPANT	\N	PRESENT	0
572487	570847	10015M	PARTICIPANT	\N	PRESENT	0
572488	572013	19369B	PARTICIPANT	\N	PRESENT	0
572489	572013	08069G	PARTICIPANT	\N	PRESENT	0
572490	572013	12041X	PARTICIPANT	\N	PRESENT	0
572491	572013	20102Q	PARTICIPANT	\N	PRESENT	0
572492	572013	14215L	PARTICIPANT	\N	PRESENT	0
572503	570847	19954N	PARTICIPANT	\N	PRESENT	0
572504	572013	14147R	PARTICIPANT	\N	PRESENT	0
572505	572013	19447X	PARTICIPANT	\N	PRESENT	0
572506	572013	11012A	PARTICIPANT	\N	PRESENT	0
572575	572013	19826F	PARTICIPANT	\N	PRESENT	0
572646	571148	19503N	PARTICIPANT	\N	PRESENT	0
572647	571148	20018V	PARTICIPANT	\N	PRESENT	0
572648	571148	19631V	PARTICIPANT	\N	PRESENT	0
572649	571148	19413M	PARTICIPANT	\N	PRESENT	0
572650	571148	14071N	PARTICIPANT	\N	PRESENT	0
572651	571148	19758L	PARTICIPANT	\N	PRESENT	0
572652	571148	14215L	PARTICIPANT	\N	PRESENT	0
572653	571148	20102Q	PARTICIPANT	\N	PRESENT	0
572654	571148	14031R	PARTICIPANT	\N	PRESENT	0
572655	571148	14097Y	PARTICIPANT	\N	PRESENT	0
572656	571148	14038Y	PARTICIPANT	\N	PRESENT	0
572657	571148	20076G	PARTICIPANT	\N	PRESENT	0
572658	571148	17023S	PARTICIPANT	\N	PRESENT	0
572659	571148	19747H	PARTICIPANT	\N	PRESENT	0
572660	571148	14169X	PARTICIPANT	\N	PRESENT	0
572661	571148	19369B	PARTICIPANT	\N	PRESENT	0
572662	571148	20040T	PARTICIPANT	\N	PRESENT	0
572663	571148	19619A	PARTICIPANT	\N	PRESENT	0
572664	571148	11090Q	PARTICIPANT	\N	PRESENT	0
572665	571148	11099A	PARTICIPANT	\N	PRESENT	0
572666	571148	14205J	PARTICIPANT	\N	PRESENT	0
572667	571148	14207L	PARTICIPANT	\N	PRESENT	0
572668	571148	04045F	PARTICIPANT	\N	PRESENT	0
572669	571148	19585H	PARTICIPANT	\N	PRESENT	0
572670	571148	20132W	PARTICIPANT	\N	PRESENT	0
572671	571148	20072C	PARTICIPANT	\N	PRESENT	0
572672	571148	20130U	PARTICIPANT	\N	PRESENT	0
572673	571148	14257W	PARTICIPANT	\N	PRESENT	0
572674	571148	19599P	PARTICIPANT	\N	PRESENT	0
572675	571148	20106U	PARTICIPANT	\N	PRESENT	0
572676	571148	14219Q	PARTICIPANT	\N	PRESENT	0
572677	571148	04085P	PARTICIPANT	\N	PRESENT	0
572678	571148	20140W	PARTICIPANT	\N	PRESENT	0
572679	571148	20124W	PARTICIPANT	\N	PRESENT	0
572680	571148	14195A	PARTICIPANT	\N	PRESENT	0
572681	571148	11067R	PARTICIPANT	\N	PRESENT	0
572682	571148	19826F	PARTICIPANT	\N	PRESENT	0
572683	571148	20180F	PARTICIPANT	\N	PRESENT	0
572684	571148	20096L	PARTICIPANT	\N	PRESENT	0
572685	571148	20034V	PARTICIPANT	\N	PRESENT	0
572686	571148	19954N	PARTICIPANT	\N	PRESENT	0
572687	571148	20038A	PARTICIPANT	\N	PRESENT	0
572688	571148	11065P	PARTICIPANT	\N	PRESENT	0
572689	571148	14327T	PARTICIPANT	\N	PRESENT	0
572690	571148	14231L	PARTICIPANT	\N	PRESENT	0
572691	571148	20100N	PARTICIPANT	\N	PRESENT	0
572692	571148	19713W	PARTICIPANT	\N	PRESENT	0
572693	571148	19347U	PARTICIPANT	\N	PRESENT	0
572694	571148	19637C	PARTICIPANT	\N	PRESENT	0
572695	571148	20136B	PARTICIPANT	\N	PRESENT	0
572696	571148	11097X	PARTICIPANT	\N	PRESENT	0
572713	571148	20052X	PARTICIPANT	\N	PRESENT	0
572698	571148	20082E	PARTICIPANT	\N	PRESENT	0
572699	571148	14217N	PARTICIPANT	\N	PRESENT	0
572700	571148	14187A	PARTICIPANT	\N	PRESENT	0
572701	571148	19507S	PARTICIPANT	\N	PRESENT	0
572702	571148	14059S	PARTICIPANT	\N	PRESENT	0
572703	571148	14331P	PARTICIPANT	\N	PRESENT	0
572704	571148	14357A	PARTICIPANT	\N	PRESENT	0
572705	571148	20126Y	PARTICIPANT	\N	PRESENT	0
572706	571148	19251M	PARTICIPANT	\N	PRESENT	0
572707	571148	19551W	PARTICIPANT	\N	PRESENT	0
572708	571148	14053L	PARTICIPANT	\N	PRESENT	0
572709	571148	19701S	PARTICIPANT	\N	PRESENT	0
572710	571148	19333N	PARTICIPANT	\N	PRESENT	0
572711	571148	20062A	PARTICIPANT	\N	PRESENT	0
572712	571148	20110Q	PARTICIPANT	\N	PRESENT	0
572714	571148	14083S	PARTICIPANT	\N	PRESENT	0
572645	571148	19549D	PARTICIPANT	\N	PRESENT	0
572715	571148	19721W	PARTICIPANT	\N	PRESENT	0
572716	571148	14213J	PARTICIPANT	\N	PRESENT	0
572816	565800	20024T	PARTICIPANT	\N	PRESENT	0
572818	565800	14030Q	PRESIDENT	0	PRESENT	0
572819	565800	19693L	PARTICIPANT	\N	PRESENT	1
572820	565800	04035D	PARTICIPANT	\N	PRESENT	1
572821	565800	20106U	PARTICIPANT	\N	PRESENT	1
572823	565800	14179A	PARTICIPANT	\N	PRESENT	1
572824	565800	20056C	PARTICIPANT	\N	PRESENT	1
572825	565800	14109K	PARTICIPANT	\N	PRESENT	1
572833	565800	19527W	PARTICIPANT	\N	PRESENT	1
572834	565800	19749K	PARTICIPANT	\N	PRESENT	0
585981	585980	11048N	PARTICIPANT	\N	PRESENT	0
587937	584533	14030Q	PRESIDENT	0	PRESENT	0
587938	584533	19715Y	PARTICIPANT	\N	PRESENT	0
587939	584533	19599P	PARTICIPANT	\N	PRESENT	0
593367	593366	11064N	PARTICIPANT	\N	PRESENT	0
594036	593800	19723Y	PARTICIPANT	\N	PRESENT	1
594037	593800	20130U	PARTICIPANT	\N	PRESENT	1
594060	594059	19760E	PARTICIPANT	\N	PRESENT	0
594061	594059	20024T	PARTICIPANT	\N	PRESENT	0
594062	594059	20116W	PARTICIPANT	\N	PRESENT	0
594063	594059	17367Q	PARTICIPANT	\N	PRESENT	0
594064	594059	19383Y	PARTICIPANT	\N	PRESENT	0
594065	594059	20090E	PARTICIPANT	\N	PRESENT	0
594066	594059	11103C	PARTICIPANT	\N	PRESENT	0
594067	594059	14329V	PARTICIPANT	\N	PRESENT	0
594068	594059	18083K	PARTICIPANT	\N	PRESENT	0
594069	594059	14357A	PARTICIPANT	\N	PRESENT	0
594070	594059	17589D	PARTICIPANT	\N	PRESENT	0
594071	594059	20038A	PARTICIPANT	\N	PRESENT	0
594072	594059	16685X	PARTICIPANT	\N	PRESENT	0
594073	594059	14221J	PARTICIPANT	\N	PRESENT	0
594074	594059	04092N	PARTICIPANT	\N	PRESENT	0
594075	594059	20030R	PARTICIPANT	\N	PRESENT	0
594076	594059	20118Y	PARTICIPANT	\N	PRESENT	0
594077	594059	05012A	PARTICIPANT	\N	PRESENT	0
594078	594059	19739H	PARTICIPANT	\N	PRESENT	0
594079	594059	20062A	PARTICIPANT	\N	PRESENT	0
594080	594059	20064C	PARTICIPANT	\N	PRESENT	0
594081	594059	14173T	PARTICIPANT	\N	PRESENT	0
594085	594084	20130U	PARTICIPANT	\N	PRESENT	1
594086	594084	14026U	PARTICIPANT	\N	PRESENT	1
594291	593444	20180F	PARTICIPANT	\N	PRESENT	0
594292	593444	19367Y	PARTICIPANT	\N	PRESENT	0
594293	593444	20102Q	PARTICIPANT	\N	PRESENT	0
594289	593444	19826F	PARTICIPANT	\N	PRESENT	0
594290	593444	08069G	PARTICIPANT	\N	PRESENT	0
594294	593444	20116W	PARTICIPANT	\N	PRESENT	0
594295	593444	17229F	PARTICIPANT	\N	PRESENT	0
594296	593444	20108W	PARTICIPANT	\N	PRESENT	0
594297	593444	19667J	PARTICIPANT	\N	PRESENT	0
594298	593444	11010L	PARTICIPANT	\N	PRESENT	0
594299	593444	20098N	PARTICIPANT	\N	PRESENT	0
594300	593444	07033P	PARTICIPANT	\N	PRESENT	0
594301	593444	19573D	PARTICIPANT	\N	PRESENT	0
594302	593444	19593H	PARTICIPANT	\N	PRESENT	0
594303	593444	20084G	PARTICIPANT	\N	PRESENT	0
594304	593444	19659J	PARTICIPANT	\N	PRESENT	0
594305	593444	19717B	PARTICIPANT	\N	PRESENT	0
594306	593444	20050V	PARTICIPANT	\N	PRESENT	0
594307	593444	20122U	PARTICIPANT	\N	PRESENT	0
594308	593444	19721W	PARTICIPANT	\N	PRESENT	0
594309	593444	11066Q	PARTICIPANT	\N	PRESENT	0
594310	593444	17779H	PARTICIPANT	\N	PRESENT	0
594311	593444	11074Q	PARTICIPANT	\N	PRESENT	0
594312	593444	11072N	PARTICIPANT	\N	PRESENT	0
594314	593444	19637C	PARTICIPANT	\N	PRESENT	0
594315	593444	19611R	PARTICIPANT	\N	PRESENT	0
594316	593444	19745F	PARTICIPANT	\N	PRESENT	0
594317	593444	11085T	PARTICIPANT	\N	PRESENT	0
594322	593444	19749K	PARTICIPANT	\N	PRESENT	0
594325	593444	19569H	PARTICIPANT	\N	PRESENT	0
594327	593444	11031D	PARTICIPANT	\N	PRESENT	0
594330	593444	19489J	PARTICIPANT	\N	PRESENT	0
594331	593444	14257W	PARTICIPANT	\N	PRESENT	0
594333	593444	14281W	PARTICIPANT	\N	PRESENT	0
594334	593444	01062T	PARTICIPANT	\N	PRESENT	0
594337	593444	19503N	PARTICIPANT	\N	PRESENT	0
594338	593444	08060W	PARTICIPANT	\N	PRESENT	0
594339	593444	20082E	PARTICIPANT	\N	PRESENT	0
594340	593444	14229S	PARTICIPANT	\N	PRESENT	0
594342	593444	20070A	PARTICIPANT	\N	PRESENT	0
594343	593444	20094J	PARTICIPANT	\N	PRESENT	0
594344	593444	12041X	PARTICIPANT	\N	PRESENT	0
594345	593444	19760E	PARTICIPANT	\N	PRESENT	0
594346	593444	19758L	PARTICIPANT	\N	PRESENT	0
594347	593444	04085P	PARTICIPANT	\N	PRESENT	0
594348	593444	14211G	PARTICIPANT	\N	PRESENT	0
594349	593444	17637T	PARTICIPANT	\N	PRESENT	0
594350	593444	01058X	PARTICIPANT	\N	PRESENT	0
594351	593444	11099A	PARTICIPANT	\N	PRESENT	0
594352	593444	19689Q	PARTICIPANT	\N	PRESENT	0
594353	593444	20130U	PARTICIPANT	\N	PRESENT	0
594354	593444	20100N	PARTICIPANT	\N	PRESENT	0
594355	593444	99004R	PARTICIPANT	\N	PRESENT	0
594356	593444	11033F	PARTICIPANT	\N	PRESENT	0
594357	593444	20076G	PARTICIPANT	\N	PRESENT	0
594358	593444	19719D	PARTICIPANT	\N	PRESENT	0
594359	593444	17589D	PARTICIPANT	\N	PRESENT	0
594360	593444	04057K	PARTICIPANT	\N	PRESENT	0
594361	593444	14251Q	PARTICIPANT	\N	PRESENT	0
594362	593444	14221J	PARTICIPANT	\N	PRESENT	0
594363	593444	19575F	PARTICIPANT	\N	PRESENT	0
594364	593444	20146D	PARTICIPANT	\N	PRESENT	0
594365	593444	19651A	PARTICIPANT	\N	PRESENT	0
594366	593444	19697Q	PARTICIPANT	\N	PRESENT	0
594367	593444	11083R	PARTICIPANT	\N	PRESENT	0
594368	593444	20128B	PARTICIPANT	\N	PRESENT	0
594369	593444	95063L	PARTICIPANT	\N	PRESENT	0
594370	593444	19782L	PARTICIPANT	\N	PRESENT	0
594371	593444	19057M	PARTICIPANT	\N	PRESENT	0
594372	593444	14249W	PARTICIPANT	\N	PRESENT	0
594373	593444	14207L	PARTICIPANT	\N	PRESENT	0
594374	593444	19447X	PARTICIPANT	\N	PRESENT	0
594375	593444	19347U	PARTICIPANT	\N	PRESENT	0
594376	593444	20092G	PARTICIPANT	\N	PRESENT	0
594377	593444	19631V	PARTICIPANT	\N	PRESENT	0
594378	593444	20034V	PARTICIPANT	\N	PRESENT	0
594379	593444	19723Y	PARTICIPANT	\N	PRESENT	0
594380	593444	20044X	PARTICIPANT	\N	PRESENT	0
594381	593444	20086J	PARTICIPANT	\N	PRESENT	0
594382	593444	14038Y	PARTICIPANT	\N	PRESENT	0
594383	593444	19591F	PARTICIPANT	\N	PRESENT	0
594384	593444	20038A	PARTICIPANT	\N	PRESENT	0
594385	593444	19467C	PARTICIPANT	\N	PRESENT	0
594386	593444	11104D	PARTICIPANT	\N	PRESENT	0
594387	593444	20264J	PARTICIPANT	\N	PRESENT	0
594388	593444	19251M	PARTICIPANT	\N	PRESENT	0
594389	593444	14151M	PARTICIPANT	\N	PRESENT	0
594390	593444	11048N	PARTICIPANT	\N	PRESENT	0
594391	593444	19647E	PARTICIPANT	\N	PRESENT	0
594392	593444	08034U	PARTICIPANT	\N	PRESENT	0
594393	593444	19747H	PARTICIPANT	\N	PRESENT	0
594394	593444	11097X	PARTICIPANT	\N	PRESENT	0
594395	593444	19599P	PARTICIPANT	\N	PRESENT	0
594396	593444	19820Y	PARTICIPANT	\N	PRESENT	0
594397	593444	19415P	PARTICIPANT	\N	PRESENT	0
594398	593444	19725B	PARTICIPANT	\N	PRESENT	0
594399	593444	04033B	PARTICIPANT	\N	PRESENT	0
594404	593444	19643A	PARTICIPANT	\N	PRESENT	0
594401	593444	11043H	PARTICIPANT	\N	PRESENT	0
594402	593444	20114U	PARTICIPANT	\N	PRESENT	0
594403	593444	14169X	PARTICIPANT	\N	PRESENT	0
594405	593444	04071H	PARTICIPANT	\N	PRESENT	0
594406	593444	19333N	PARTICIPANT	\N	PRESENT	0
594407	593444	17367Q	PARTICIPANT	\N	PRESENT	0
594408	593444	11080N	PARTICIPANT	\N	PRESENT	0
594409	593444	20030R	PARTICIPANT	\N	PRESENT	0
594410	593444	20064C	PARTICIPANT	\N	PRESENT	0
594411	593444	20068G	PARTICIPANT	\N	PRESENT	0
594412	593444	19413M	PARTICIPANT	\N	PRESENT	0
594413	593444	14021P	PARTICIPANT	\N	PRESENT	0
594414	593444	19329S	PARTICIPANT	\N	PRESENT	0
594415	593444	19563B	PARTICIPANT	\N	PRESENT	0
594416	593444	01028R	PARTICIPANT	\N	PRESENT	0
594417	593444	14053L	PARTICIPANT	\N	PRESENT	0
594418	593444	05008E	PARTICIPANT	\N	PRESENT	0
594419	593444	20022R	PARTICIPANT	\N	PRESENT	0
594420	593444	20028X	PARTICIPANT	\N	PRESENT	0
594421	593444	14001X	PARTICIPANT	\N	PRESENT	0
594422	593444	14193X	PARTICIPANT	\N	PRESENT	0
594423	593444	14237S	PARTICIPANT	\N	PRESENT	0
594424	593444	11067R	PARTICIPANT	\N	PRESENT	0
594425	593444	10006L	PARTICIPANT	\N	PRESENT	0
594426	593444	14121F	PARTICIPANT	\N	PRESENT	0
594427	593444	19531S	PARTICIPANT	\N	PRESENT	0
594428	593444	20088L	PARTICIPANT	\N	PRESENT	0
594429	593444	18193Q	PARTICIPANT	\N	PRESENT	0
594430	593444	08012N	PARTICIPANT	\N	PRESENT	0
594431	593444	11065P	PARTICIPANT	\N	PRESENT	0
594432	593444	14331P	PARTICIPANT	\N	PRESENT	0
594433	593444	01024M	PARTICIPANT	\N	PRESENT	0
594434	593444	19691J	PARTICIPANT	\N	PRESENT	0
594435	593444	20118Y	PARTICIPANT	\N	PRESENT	0
570341	568285	14042U	PARTICIPANT	\N	PRESENT	0
570342	568285	04092N	PARTICIPANT	\N	PRESENT	0
570589	570587	19735D	PARTICIPANT	\N	PRESENT	0
570590	570587	19723Y	PARTICIPANT	\N	PRESENT	0
570593	570587	01058X	PARTICIPANT	\N	PRESENT	0
570594	570587	19709B	PARTICIPANT	\N	PRESENT	0
570595	570587	11067R	PARTICIPANT	\N	PRESENT	0
570621	555420	19735D	PARTICIPANT	\N	PRESENT	0
570622	555420	19723Y	PARTICIPANT	\N	PRESENT	0
570623	555420	19709B	PARTICIPANT	\N	PRESENT	0
570625	555420	01048V	PARTICIPANT	\N	EXCUSE	0
570626	555420	11067R	PARTICIPANT	\N	PRESENT	0
570628	555420	01058X	PARTICIPANT	\N	PRESENT	0
570629	555420	20128B	PARTICIPANT	\N	EXCUSE	0
570630	555420	19503N	PARTICIPANT	\N	EXCUSE	0
570683	555420	20072C	PARTICIPANT	\N	PRESENT	0
572867	572736	20030R	PARTICIPANT	\N	EXCUSE	0
574243	572778	11103C	PARTICIPANT	\N	PRESENT	1
574244	572778	04057K	PARTICIPANT	\N	PRESENT	1
574245	572778	14213J	PARTICIPANT	\N	PRESENT	1
574246	572778	19591F	PARTICIPANT	\N	PRESENT	1
574247	572778	19697Q	PARTICIPANT	\N	PRESENT	1
574248	572778	14071N	PARTICIPANT	\N	PRESENT	1
574249	572778	20130U	PARTICIPANT	\N	PRESENT	1
574250	572778	19717B	PARTICIPANT	\N	PRESENT	1
574251	572778	19553Y	PARTICIPANT	\N	PRESENT	1
574269	572778	19663E	PARTICIPANT	\N	PRESENT	1
574294	572778	20066E	PARTICIPANT	\N	PRESENT	0
574295	572778	18193Q	PARTICIPANT	\N	PRESENT	0
574296	572778	17965H	PARTICIPANT	\N	PRESENT	0
574297	572778	19760E	PARTICIPANT	\N	PRESENT	0
574299	572778	17779H	PARTICIPANT	\N	EXCUSE	0
574302	572778	08045X	PARTICIPANT	\N	PRESENT	1
574303	572778	19723Y	PARTICIPANT	\N	PRESENT	1
574312	572778	14223L	PARTICIPANT	\N	PRESENT	0
574314	572778	11031D	PARTICIPANT	\N	PRESENT	0
574316	572778	19569H	PARTICIPANT	\N	PRESENT	0
576818	575269	01048V	PARTICIPANT	\N	PRESENT	0
576819	575269	14187A	PARTICIPANT	\N	PRESENT	0
576820	575269	19467C	PARTICIPANT	\N	PRESENT	0
576821	575269	20044X	PARTICIPANT	\N	PRESENT	0
576822	575269	19447X	PARTICIPANT	\N	PRESENT	0
576823	575269	19515S	PARTICIPANT	\N	PRESENT	0
576824	575269	20068G	PARTICIPANT	\N	PRESENT	0
576825	575269	19383Y	PARTICIPANT	\N	PRESENT	0
576826	575269	19762G	PARTICIPANT	\N	PRESENT	0
576827	575269	19533U	PARTICIPANT	\N	PRESENT	0
576828	575269	19577H	PARTICIPANT	\N	PRESENT	0
576829	575269	20144B	PARTICIPANT	\N	PRESENT	0
576830	575269	14179A	PARTICIPANT	\N	PRESENT	0
576831	575269	11053K	PARTICIPANT	\N	PRESENT	0
576832	575269	14229S	PARTICIPANT	\N	PRESENT	0
576833	575269	18193Q	PARTICIPANT	\N	PRESENT	0
576834	575269	19503N	PARTICIPANT	\N	PRESENT	0
576835	575269	08061X	PARTICIPANT	\N	PRESENT	0
576836	575269	17367Q	PARTICIPANT	\N	PRESENT	0
576837	575269	11101A	PARTICIPANT	\N	PRESENT	0
576838	575269	19507S	PARTICIPANT	\N	PRESENT	0
576839	575269	04092N	PARTICIPANT	\N	PRESENT	0
576840	575269	20054A	PARTICIPANT	\N	PRESENT	0
576841	575269	19798U	PARTICIPANT	\N	PRESENT	0
576842	575269	14215L	PARTICIPANT	\N	PRESENT	0
576843	575269	20132W	PARTICIPANT	\N	PRESENT	0
576844	575269	04045F	PARTICIPANT	\N	PRESENT	0
576845	575269	19551W	PARTICIPANT	\N	PRESENT	0
576846	575269	01028R	PARTICIPANT	\N	PRESENT	0
576847	575269	19563B	PARTICIPANT	\N	PRESENT	0
576848	575269	14111D	PARTICIPANT	\N	PRESENT	0
576849	575269	11072N	PARTICIPANT	\N	PRESENT	0
576850	575269	11097X	PARTICIPANT	\N	PRESENT	0
576851	575269	08012N	PARTICIPANT	\N	PRESENT	0
576852	575269	14151M	PARTICIPANT	\N	PRESENT	0
576853	575269	20128B	PARTICIPANT	\N	PRESENT	0
576854	575269	14033T	PARTICIPANT	\N	PRESENT	0
576855	575269	04047H	PARTICIPANT	\N	PRESENT	0
576856	575269	14191V	PARTICIPANT	\N	PRESENT	0
576857	575269	19621T	PARTICIPANT	\N	PRESENT	0
576858	575269	20022R	PARTICIPANT	\N	PRESENT	0
576859	575269	14038Y	PARTICIPANT	\N	PRESENT	0
576860	575269	20062A	PARTICIPANT	\N	PRESENT	0
576861	575269	14071N	PARTICIPANT	\N	PRESENT	0
576862	575269	14329V	PARTICIPANT	\N	PRESENT	0
576863	575269	20036X	PARTICIPANT	\N	PRESENT	0
576864	575269	19637C	PARTICIPANT	\N	PRESENT	0
576865	575269	19760E	PARTICIPANT	\N	PRESENT	0
576866	575269	19301E	PARTICIPANT	\N	PRESENT	0
576867	575269	20058E	PARTICIPANT	\N	PRESENT	0
576868	575269	19735D	PARTICIPANT	\N	PRESENT	0
576869	575269	20126Y	PARTICIPANT	\N	PRESENT	0
576870	575269	20018V	PARTICIPANT	\N	PRESENT	0
576871	575269	01057W	PARTICIPANT	\N	PRESENT	0
576872	575269	11065P	PARTICIPANT	\N	PRESENT	0
576873	575269	14205J	PARTICIPANT	\N	PRESENT	0
576874	575269	14073Q	PARTICIPANT	\N	PRESENT	0
576875	575269	14219Q	PARTICIPANT	\N	PRESENT	0
576876	575269	14021P	PARTICIPANT	\N	PRESENT	0
576877	575269	20090E	PARTICIPANT	\N	PRESENT	0
576878	575269	19619A	PARTICIPANT	\N	PRESENT	0
576881	575269	05012A	PARTICIPANT	\N	PRESENT	0
577232	570632	14189C	PARTICIPANT	\N	PRESENT	0
577233	570632	14030Q	PRESIDENT	0	PRESENT	0
577234	570632	20024T	PARTICIPANT	\N	EXCUSE	0
577235	570632	20080C	PARTICIPANT	\N	PRESENT	1
577236	570632	11031D	PARTICIPANT	\N	EXCUSE	0
577237	570632	19693L	PARTICIPANT	\N	PRESENT	0
577238	570632	20140W	PARTICIPANT	\N	PRESENT	0
577239	570632	19599P	PARTICIPANT	\N	PRESENT	0
577240	570632	14179A	PARTICIPANT	\N	PRESENT	1
577241	570632	20066E	PARTICIPANT	\N	PRESENT	1
577242	570632	20118Y	PARTICIPANT	\N	EXCUSE	0
577243	570632	20130U	PARTICIPANT	\N	EXCUSE	0
577244	570632	20098N	PARTICIPANT	\N	PRESENT	1
577245	570632	19749K	PARTICIPANT	\N	PRESENT	0
577248	577247	19667J	PARTICIPANT	\N	PRESENT	0
577249	577247	20022R	PARTICIPANT	\N	PRESENT	0
577250	577247	20090E	PARTICIPANT	\N	PRESENT	0
577251	577247	14329V	PARTICIPANT	\N	PRESENT	0
577252	577247	20124W	PARTICIPANT	\N	PRESENT	0
577253	577247	20038A	PARTICIPANT	\N	PRESENT	0
577254	577247	20066E	PARTICIPANT	\N	PRESENT	0
577255	577247	16685X	PARTICIPANT	\N	PRESENT	0
577256	577247	14059S	PARTICIPANT	\N	PRESENT	0
577257	577247	20054A	PARTICIPANT	\N	PRESENT	0
577258	577247	20062A	PARTICIPANT	\N	PRESENT	0
577260	570632	20056C	PARTICIPANT	\N	PRESENT	1
577261	570632	07029T	PARTICIPANT	\N	PRESENT	0
577283	570632	20138D	PARTICIPANT	\N	EXCUSE	0
577285	570632	19798U	PARTICIPANT	\N	EXCUSE	0
577290	570632	17737W	PARTICIPANT	\N	EXCUSE	0
577335	574433	19701S	PARTICIPANT	\N	PRESENT	0
577336	574433	11083R	PARTICIPANT	\N	PRESENT	0
577337	574433	14033T	PARTICIPANT	\N	PRESENT	1
577338	574433	20100N	PARTICIPANT	\N	PRESENT	0
577339	574433	19563B	PARTICIPANT	\N	PRESENT	0
577342	574433	14001X	PARTICIPANT	\N	PRESENT	0
577343	574433	19333N	PARTICIPANT	\N	PRESENT	0
577344	574433	19531S	PARTICIPANT	\N	PRESENT	1
577346	574433	10015M	PARTICIPANT	\N	PRESENT	0
577347	574433	14237S	PARTICIPANT	\N	PRESENT	0
577349	574433	14357A	PARTICIPANT	\N	EXCUSE	0
577450	577448	19711U	PARTICIPANT	\N	PRESENT	0
577451	577448	14187A	PARTICIPANT	\N	PRESENT	1
577452	577448	20132W	PARTICIPANT	\N	PRESENT	0
577454	577448	20024T	PARTICIPANT	\N	PRESENT	0
577455	577448	14255U	PARTICIPANT	\N	PRESENT	1
577458	577457	19711U	PARTICIPANT	\N	PRESENT	0
577459	577457	14026U	PARTICIPANT	\N	PRESENT	0
577460	577457	20132W	PARTICIPANT	\N	PRESENT	0
577461	577457	14255U	PARTICIPANT	\N	PRESENT	1
577462	577457	11026G	PARTICIPANT	\N	PRESENT	1
577772	555423	19693L	PARTICIPANT	\N	EXCUSE	0
582733	582731	11066Q	PARTICIPANT	\N	PRESENT	0
582735	582734	04047H	PARTICIPANT	\N	PRESENT	0
582736	582734	11066Q	PARTICIPANT	\N	PRESENT	0
582737	582734	14053L	PARTICIPANT	\N	PRESENT	0
582741	582740	14089Y	PARTICIPANT	\N	PRESENT	0
582742	582740	14053L	PARTICIPANT	\N	PRESENT	0
582744	582743	14053L	PARTICIPANT	\N	PRESENT	0
582746	582745	14053L	PARTICIPANT	\N	PRESENT	0
582748	582747	04035D	PARTICIPANT	\N	PRESENT	0
582750	582749	11083R	PARTICIPANT	\N	PRESENT	0
582751	582749	17367Q	PARTICIPANT	\N	PRESENT	0
582752	582749	19593H	PARTICIPANT	\N	PRESENT	0
582753	582749	04035D	PARTICIPANT	\N	PRESENT	0
582755	582754	11083R	PARTICIPANT	\N	PRESENT	0
582756	582754	17367Q	PARTICIPANT	\N	PRESENT	0
582757	582754	19593H	PARTICIPANT	\N	PRESENT	0
587312	585912	19593H	PARTICIPANT	\N	PRESENT	0
587313	585912	19573D	PARTICIPANT	\N	PRESENT	0
587314	585912	19533U	PARTICIPANT	\N	PRESENT	0
587315	585912	19766L	PARTICIPANT	\N	PRESENT	0
587316	585912	04033B	PARTICIPANT	\N	PRESENT	0
587317	585912	11043H	PARTICIPANT	\N	PRESENT	0
587318	585912	14229S	PARTICIPANT	\N	PRESENT	0
587319	585912	20098N	PARTICIPANT	\N	PRESENT	0
587320	585912	20026V	PARTICIPANT	\N	PRESENT	0
587322	585411	14033T	PARTICIPANT	\N	PRESENT	1
587323	585411	19545Y	PARTICIPANT	\N	PRESENT	1
587324	585411	11110B	PARTICIPANT	\N	PRESENT	1
587325	585411	20126Y	PARTICIPANT	\N	PRESENT	1
587326	585411	19479G	PARTICIPANT	\N	PRESENT	1
587328	587327	14229S	PARTICIPANT	\N	PRESENT	0
587329	587327	19735D	PARTICIPANT	\N	PRESENT	0
587330	587327	20142Y	PARTICIPANT	\N	PRESENT	0
587331	587327	20026V	PARTICIPANT	\N	PRESENT	0
587332	587327	20056C	PARTICIPANT	\N	PRESENT	0
587333	587327	19693L	PARTICIPANT	\N	PRESENT	0
587334	587327	20180F	PARTICIPANT	\N	PRESENT	0
588078	585755	01043Q	PARTICIPANT	\N	PRESENT	0
588082	585755	19503N	PARTICIPANT	\N	PRESENT	0
588080	585755	20114U	PARTICIPANT	\N	PRESENT	0
588081	585755	20082E	PARTICIPANT	\N	PRESENT	0
588083	585755	19413M	PARTICIPANT	\N	PRESENT	0
588084	585755	20180F	PARTICIPANT	\N	PRESENT	0
588085	585755	19649G	PARTICIPANT	\N	PRESENT	0
588086	585755	11056N	PARTICIPANT	\N	PRESENT	0
588087	585755	19515S	PARTICIPANT	\N	PRESENT	0
588088	585755	20110Q	PARTICIPANT	\N	PRESENT	0
588089	585755	14033T	PARTICIPANT	\N	PRESENT	0
588090	585755	20092G	PARTICIPANT	\N	PRESENT	0
588091	585755	11072N	PARTICIPANT	\N	PRESENT	0
588092	585755	19729F	PARTICIPANT	\N	PRESENT	0
588093	585755	20036X	PARTICIPANT	\N	PRESENT	0
588094	585755	14215L	PARTICIPANT	\N	PRESENT	0
588095	585755	14187A	PARTICIPANT	\N	PRESENT	0
588096	585755	19629C	PARTICIPANT	\N	PRESENT	0
588100	585755	19333N	PARTICIPANT	\N	PRESENT	0
588098	585755	01028R	PARTICIPANT	\N	PRESENT	0
588099	585755	20072C	PARTICIPANT	\N	PRESENT	0
588101	585755	20102Q	PARTICIPANT	\N	PRESENT	0
588102	585755	04047H	PARTICIPANT	\N	PRESENT	0
588103	585755	19447X	PARTICIPANT	\N	PRESENT	0
588104	585755	14053L	PARTICIPANT	\N	PRESENT	0
588105	585755	19467C	PARTICIPANT	\N	PRESENT	0
588106	585755	20090E	PARTICIPANT	\N	PRESENT	0
588107	585755	19533U	PARTICIPANT	\N	PRESENT	0
588108	585755	14030Q	PARTICIPANT	\N	PRESENT	0
588109	585755	14357A	PARTICIPANT	\N	PRESENT	0
588110	585755	05008E	PARTICIPANT	\N	PRESENT	0
588111	585755	20086J	PARTICIPANT	\N	PRESENT	0
588112	585755	20044X	PARTICIPANT	\N	PRESENT	0
588113	585755	20120S	PARTICIPANT	\N	PRESENT	0
588114	585755	19415P	PARTICIPANT	\N	PRESENT	0
588115	585755	04085P	PARTICIPANT	\N	PRESENT	0
588116	585755	20052X	PARTICIPANT	\N	PRESENT	0
588117	585755	20054A	PARTICIPANT	\N	PRESENT	0
588118	585755	19563B	PARTICIPANT	\N	PRESENT	0
588119	585755	14071N	PARTICIPANT	\N	PRESENT	0
588120	585755	19758L	PARTICIPANT	\N	PRESENT	0
588121	585755	20124W	PARTICIPANT	\N	PRESENT	0
588122	585755	19347U	PARTICIPANT	\N	PRESENT	0
588123	585755	20252E	PARTICIPANT	\N	PRESENT	0
588124	585755	19749K	PARTICIPANT	\N	PRESENT	0
588125	585755	95063L	PARTICIPANT	\N	PRESENT	0
588126	585755	14089Y	PARTICIPANT	\N	PRESENT	0
588127	585755	17637T	PARTICIPANT	\N	PRESENT	0
588128	585755	19782L	PARTICIPANT	\N	PRESENT	0
588129	585755	19387D	PARTICIPANT	\N	PRESENT	0
588130	585755	14083S	PARTICIPANT	\N	PRESENT	0
588168	585756	14187A	PARTICIPANT	\N	PRESENT	0
588169	585756	11056N	PARTICIPANT	\N	PRESENT	0
588170	585756	14071N	PARTICIPANT	\N	PRESENT	0
588171	585756	04085P	PARTICIPANT	\N	PRESENT	0
588172	585756	05008E	PARTICIPANT	\N	PRESENT	0
588173	585756	20082E	PARTICIPANT	\N	PRESENT	0
588174	585756	14215L	PARTICIPANT	\N	PRESENT	0
588175	585756	19333N	PARTICIPANT	\N	PRESENT	0
588176	585756	20114U	PARTICIPANT	\N	PRESENT	0
588177	585756	20054A	PARTICIPANT	\N	PRESENT	0
588178	585756	01028R	PARTICIPANT	\N	PRESENT	0
588179	585756	20124W	PARTICIPANT	\N	PRESENT	0
588180	585756	19347U	PARTICIPANT	\N	PRESENT	0
588181	585756	14357A	PARTICIPANT	\N	PRESENT	0
588182	585756	19782L	PARTICIPANT	\N	PRESENT	0
588183	585756	19533U	PARTICIPANT	\N	PRESENT	0
588184	585756	20110Q	PARTICIPANT	\N	PRESENT	0
588185	585756	19729F	PARTICIPANT	\N	PRESENT	0
588186	585756	20180F	PARTICIPANT	\N	PRESENT	0
588187	585756	19447X	PARTICIPANT	\N	PRESENT	0
588188	585756	20090E	PARTICIPANT	\N	PRESENT	0
588189	585756	20072C	PARTICIPANT	\N	PRESENT	0
588190	585756	19387D	PARTICIPANT	\N	PRESENT	0
588191	585756	19563B	PARTICIPANT	\N	PRESENT	0
588192	585756	17637T	PARTICIPANT	\N	PRESENT	0
588193	585756	19749K	PARTICIPANT	\N	PRESENT	0
588194	585756	14083S	PARTICIPANT	\N	PRESENT	0
588195	585756	04047H	PARTICIPANT	\N	PRESENT	0
588196	585756	14053L	PARTICIPANT	\N	PRESENT	0
588197	585756	14089Y	PARTICIPANT	\N	PRESENT	0
588198	585756	11072N	PARTICIPANT	\N	PRESENT	0
588236	585759	11070L	PARTICIPANT	\N	PRESENT	0
588237	585759	20130U	PARTICIPANT	\N	PRESENT	0
588238	585759	20092G	PARTICIPANT	\N	PRESENT	0
588239	585759	11099A	PARTICIPANT	\N	PRESENT	0
588166	585756	19515S	PARTICIPANT	\N	PRESENT	0
588167	585756	01043Q	PARTICIPANT	\N	PRESENT	0
588240	585759	19251M	PARTICIPANT	\N	PRESENT	0
588241	585759	19387D	PARTICIPANT	\N	PRESENT	0
588242	585759	19739H	PARTICIPANT	\N	PRESENT	0
588243	585759	19441R	PARTICIPANT	\N	PRESENT	0
588244	585759	20072C	PARTICIPANT	\N	PRESENT	0
588245	585759	01025N	PARTICIPANT	\N	PRESENT	0
588246	585759	20048C	PARTICIPANT	\N	PRESENT	0
588247	585759	01058X	PARTICIPANT	\N	PRESENT	0
588248	585759	19729F	PARTICIPANT	\N	PRESENT	0
588249	585759	14033T	PARTICIPANT	\N	PRESENT	0
588250	585759	19467C	PARTICIPANT	\N	PRESENT	0
588251	585759	20022R	PARTICIPANT	\N	PRESENT	0
588252	585759	20054A	PARTICIPANT	\N	PRESENT	0
588253	585759	19563B	PARTICIPANT	\N	PRESENT	0
588254	585759	19667J	PARTICIPANT	\N	PRESENT	0
588255	585759	99004R	PARTICIPANT	\N	PRESENT	0
588256	585759	14329V	PARTICIPANT	\N	PRESENT	0
588257	585759	95063L	PARTICIPANT	\N	PRESENT	0
588258	585759	19413M	PARTICIPANT	\N	PRESENT	0
588259	585759	19695N	PARTICIPANT	\N	PRESENT	0
588260	585759	11090Q	PARTICIPANT	\N	PRESENT	0
588261	585759	11056N	PARTICIPANT	\N	PRESENT	0
588262	585759	14055N	PARTICIPANT	\N	PRESENT	0
588263	585759	19782L	PARTICIPANT	\N	PRESENT	0
588264	585759	20248J	PARTICIPANT	\N	PRESENT	0
588265	585759	11033F	PARTICIPANT	\N	PRESENT	0
588266	585759	20038A	PARTICIPANT	\N	PRESENT	0
588267	585759	20082E	PARTICIPANT	\N	PRESENT	0
588268	585759	20052X	PARTICIPANT	\N	PRESENT	0
588269	585759	19671E	PARTICIPANT	\N	PRESENT	0
588270	585759	19643A	PARTICIPANT	\N	PRESENT	0
588271	585759	20030R	PARTICIPANT	\N	PRESENT	0
588272	585759	19515S	PARTICIPANT	\N	PRESENT	0
571271	567854	11026G	PARTICIPANT	\N	PRESENT	1
571273	567854	14189C	PARTICIPANT	\N	EXCUSE	0
571274	567854	04057K	PARTICIPANT	\N	EXCUSE	0
571275	567854	19563B	PARTICIPANT	\N	EXCUSE	0
571293	555421	19709B	PARTICIPANT	\N	EXCUSE	0
571294	555421	19503N	PARTICIPANT	\N	EXCUSE	0
571295	555421	19693L	PARTICIPANT	\N	PRESENT	1
576882	575269	19413M	PARTICIPANT	\N	PRESENT	0
576889	575269	20084G	PARTICIPANT	\N	PRESENT	0
576890	575269	18083K	PARTICIPANT	\N	PRESENT	0
576900	575269	20102Q	PARTICIPANT	\N	PRESENT	0
576901	575269	19335Q	PARTICIPANT	\N	PRESENT	0
576902	575269	14257W	PARTICIPANT	\N	PRESENT	0
576903	575269	19723Y	PARTICIPANT	\N	PRESENT	0
576904	575269	14147R	PARTICIPANT	\N	PRESENT	0
576905	575269	19575F	PARTICIPANT	\N	PRESENT	0
576906	575269	14055N	PARTICIPANT	\N	PRESENT	0
576907	575269	19251M	PARTICIPANT	\N	PRESENT	0
576908	575269	19367Y	PARTICIPANT	\N	PRESENT	0
576909	575269	20142Y	PARTICIPANT	\N	PRESENT	0
576910	575269	12041X	PARTICIPANT	\N	PRESENT	0
576911	575269	20096L	PARTICIPANT	\N	PRESENT	0
576912	575269	19954N	PARTICIPANT	\N	PRESENT	0
576913	575269	20114U	PARTICIPANT	\N	PRESENT	0
576914	575245	14059S	PARTICIPANT	\N	PRESENT	0
576915	575245	14097Y	PARTICIPANT	\N	PRESENT	0
576916	575245	04035D	PARTICIPANT	\N	PRESENT	0
576917	575245	19443T	PARTICIPANT	\N	PRESENT	0
576918	575245	19565D	PARTICIPANT	\N	PRESENT	0
576919	575245	20072C	PARTICIPANT	\N	PRESENT	0
576920	575245	04034C	PARTICIPANT	\N	PRESENT	0
576921	575245	20042V	PARTICIPANT	\N	PRESENT	0
576922	575245	01058X	PARTICIPANT	\N	PRESENT	1
576923	575245	16685X	PARTICIPANT	\N	PRESENT	0
576924	575245	04042C	PRESIDENT	0	PRESENT	0
576925	575245	01024M	PARTICIPANT	\N	PRESENT	0
576926	575245	14105F	PARTICIPANT	\N	PRESENT	1
576927	575245	98018T	PARTICIPANT	\N	PRESENT	1
576928	575245	19421M	PARTICIPANT	\N	PRESENT	0
576929	575245	14267Y	PARTICIPANT	\N	PRESENT	0
576930	575245	11064N	PARTICIPANT	\N	PRESENT	0
576931	575245	19347U	PARTICIPANT	\N	PRESENT	0
576932	575245	11083R	PARTICIPANT	\N	PRESENT	0
576933	575245	97011G	PARTICIPANT	\N	PRESENT	0
576934	575245	14249W	PARTICIPANT	\N	PRESENT	0
576935	575245	17023S	PARTICIPANT	\N	PRESENT	0
576936	575245	14255U	PARTICIPANT	\N	PRESENT	1
576956	575269	14207L	PARTICIPANT	\N	PRESENT	0
576938	575269	20048C	PARTICIPANT	\N	PRESENT	0
576939	575269	05008E	PARTICIPANT	\N	PRESENT	0
576940	575269	19369B	PARTICIPANT	\N	PRESENT	0
576941	575269	20038A	PARTICIPANT	\N	PRESENT	0
576942	575269	17637T	PARTICIPANT	\N	PRESENT	0
576943	575269	14031R	PARTICIPANT	\N	PRESENT	0
576944	575269	19741B	PARTICIPANT	\N	PRESENT	0
576945	575269	20124W	PARTICIPANT	\N	PRESENT	0
576946	575269	20152B	PARTICIPANT	\N	PRESENT	0
576947	575269	17023S	PARTICIPANT	\N	PRESENT	0
576957	575269	11067R	PARTICIPANT	\N	PRESENT	0
576951	575269	19747H	PARTICIPANT	\N	PRESENT	0
576952	575269	19399H	PARTICIPANT	\N	PRESENT	0
576953	575269	11033F	PARTICIPANT	\N	PRESENT	0
576954	575269	19691J	PARTICIPANT	\N	PRESENT	0
576955	575269	97011G	PARTICIPANT	\N	PRESENT	0
576958	575269	19527W	PARTICIPANT	\N	PRESENT	0
576959	575269	20072C	PARTICIPANT	\N	PRESENT	0
576960	575269	20070A	PARTICIPANT	\N	PRESENT	0
576961	575269	01024M	PARTICIPANT	\N	PRESENT	0
576962	575269	20052X	PARTICIPANT	\N	PRESENT	0
576963	575269	20172F	PARTICIPANT	\N	PRESENT	0
576964	575269	08073C	PARTICIPANT	\N	PRESENT	0
576965	575269	04085P	PARTICIPANT	\N	PRESENT	0
576966	575269	14123H	PARTICIPANT	\N	PRESENT	0
576967	575269	19673G	PARTICIPANT	\N	PRESENT	0
576983	575269	20088L	PARTICIPANT	\N	PRESENT	0
576984	575269	20140W	PARTICIPANT	\N	PRESENT	0
576985	575269	19715Y	PARTICIPANT	\N	PRESENT	0
577015	575269	20034V	PARTICIPANT	\N	PRESENT	0
577016	575269	14217N	PARTICIPANT	\N	PRESENT	0
577017	575269	19749K	PARTICIPANT	\N	PRESENT	0
577018	575269	14237S	PARTICIPANT	\N	PRESENT	0
577019	575269	20066E	PARTICIPANT	\N	PRESENT	0
577020	575269	14189C	PARTICIPANT	\N	PRESENT	0
577021	575269	19866P	PARTICIPANT	\N	PRESENT	0
577022	575269	19599P	PARTICIPANT	\N	PRESENT	0
577023	575269	07029T	PARTICIPANT	\N	PRESENT	0
577024	575269	14213J	PARTICIPANT	\N	PRESENT	0
577025	575269	14030Q	PARTICIPANT	\N	PRESENT	0
577026	575269	08034U	PARTICIPANT	\N	PRESENT	0
577027	575269	19531S	PARTICIPANT	\N	PRESENT	0
577028	575269	20134Y	PARTICIPANT	\N	PRESENT	0
577029	575269	14097Y	PARTICIPANT	\N	PRESENT	0
577030	575269	14083S	PARTICIPANT	\N	PRESENT	0
577031	575269	14069U	PARTICIPANT	\N	PRESENT	0
577093	575270	04047H	PARTICIPANT	\N	PRESENT	0
577094	575270	14231L	PARTICIPANT	\N	PRESENT	0
577095	575270	14259Y	PARTICIPANT	\N	PRESENT	0
577096	575270	14001X	PARTICIPANT	\N	PRESENT	0
577097	575270	19715Y	PARTICIPANT	\N	PRESENT	0
577098	575270	20036X	PARTICIPANT	\N	PRESENT	0
577099	575270	19387D	PARTICIPANT	\N	PRESENT	0
577100	575270	20072C	PARTICIPANT	\N	PRESENT	0
577101	575270	19489J	PARTICIPANT	\N	PRESENT	0
577102	575270	14195A	PARTICIPANT	\N	PRESENT	0
577103	575270	19629C	PARTICIPANT	\N	PRESENT	0
577104	575270	10015M	PARTICIPANT	\N	PRESENT	0
577105	575270	19866P	PARTICIPANT	\N	PRESENT	0
577106	575270	14215L	PARTICIPANT	\N	PRESENT	0
577107	575270	19621T	PARTICIPANT	\N	PRESENT	0
577108	575270	14071N	PARTICIPANT	\N	PRESENT	0
577109	575270	14053L	PARTICIPANT	\N	PRESENT	0
577110	575270	14217N	PARTICIPANT	\N	PRESENT	0
577111	575270	20152B	PARTICIPANT	\N	PRESENT	0
577112	575270	19443T	PARTICIPANT	\N	PRESENT	0
577113	575270	20110Q	PARTICIPANT	\N	PRESENT	0
577114	575270	14191V	PARTICIPANT	\N	PRESENT	0
577115	575270	20090E	PARTICIPANT	\N	PRESENT	0
577116	575270	14357A	PARTICIPANT	\N	PRESENT	0
577117	575270	20026V	PARTICIPANT	\N	PRESENT	0
577118	575270	07029T	PARTICIPANT	\N	PRESENT	0
577119	575270	19447X	PARTICIPANT	\N	PRESENT	0
577120	575270	19575F	PARTICIPANT	\N	PRESENT	0
577121	575270	19467C	PARTICIPANT	\N	PRESENT	0
577122	575270	20180F	PARTICIPANT	\N	PRESENT	0
577123	575270	17367Q	PARTICIPANT	\N	PRESENT	0
577124	575270	19691J	PARTICIPANT	\N	PRESENT	0
577125	575270	14089Y	PARTICIPANT	\N	PRESENT	0
577126	575270	20092G	PARTICIPANT	\N	PRESENT	0
577127	575270	20100N	PARTICIPANT	\N	PRESENT	0
577128	575270	20174H	PARTICIPANT	\N	PRESENT	0
577129	575270	20140W	PARTICIPANT	\N	PRESENT	0
577130	575270	20034V	PARTICIPANT	\N	PRESENT	0
577131	575270	19723Y	PARTICIPANT	\N	PRESENT	0
577132	575270	05008E	PARTICIPANT	\N	PRESENT	0
577133	575270	14179A	PARTICIPANT	\N	PRESENT	0
577134	575270	19335Q	PARTICIPANT	\N	PRESENT	0
577135	575270	20134Y	PARTICIPANT	\N	PRESENT	0
577136	575270	14151M	PARTICIPANT	\N	PRESENT	0
577137	575270	20096L	PARTICIPANT	\N	PRESENT	0
577138	575270	14327T	PARTICIPANT	\N	PRESENT	0
577139	575270	01024M	PARTICIPANT	\N	PRESENT	0
577140	575270	20124W	PARTICIPANT	\N	PRESENT	0
577141	575270	19577H	PARTICIPANT	\N	PRESENT	0
577142	575270	11097X	PARTICIPANT	\N	PRESENT	0
577143	575270	11031D	PARTICIPANT	\N	PRESENT	0
577144	575270	20120S	PARTICIPANT	\N	PRESENT	0
577145	575270	14030Q	PARTICIPANT	\N	PRESENT	0
577146	575270	17023S	PARTICIPANT	\N	PRESENT	0
577147	575270	14187A	PARTICIPANT	\N	PRESENT	0
577148	575270	19551W	PARTICIPANT	\N	PRESENT	0
577149	575270	20142Y	PARTICIPANT	\N	PRESENT	0
577150	575270	19719D	PARTICIPANT	\N	PRESENT	0
577151	575270	19347U	PARTICIPANT	\N	PRESENT	0
577091	575270	14026U	PARTICIPANT	\N	PRESENT	0
577092	575270	11056N	PARTICIPANT	\N	PRESENT	0
577152	575270	14237S	PARTICIPANT	\N	PRESENT	0
577153	575270	14069U	PARTICIPANT	\N	PRESENT	0
577154	575270	19768N	PARTICIPANT	\N	PRESENT	0
577155	575270	19441R	PARTICIPANT	\N	PRESENT	0
577156	575270	19383Y	PARTICIPANT	\N	PRESENT	0
580773	580772	19643A	PARTICIPANT	\N	PRESENT	0
580774	580772	11043H	PARTICIPANT	\N	PRESENT	0
580775	580772	14073Q	PARTICIPANT	\N	PRESENT	0
580776	580772	19251M	PARTICIPANT	\N	PRESENT	0
580777	580772	20024T	PARTICIPANT	\N	PRESENT	0
580778	580772	19575F	PARTICIPANT	\N	PRESENT	0
580779	580772	20138D	PARTICIPANT	\N	PRESENT	0
580780	580772	20152B	PARTICIPANT	\N	PRESENT	0
580781	580772	19699S	PARTICIPANT	\N	PRESENT	0
580782	580772	20132W	PARTICIPANT	\N	PRESENT	0
580783	580772	19711U	PARTICIPANT	\N	PRESENT	0
581012	578921	14133K	PARTICIPANT	\N	PRESENT	1
581013	578921	14105F	PARTICIPANT	\N	PRESENT	1
581014	578921	19319Q	PARTICIPANT	\N	PRESENT	1
583208	583205	19575F	PRESIDENT	0	PRESENT	0
583209	583205	14041T	PARTICIPANT	\N	PRESENT	0
583210	583205	14083S	PARTICIPANT	\N	PRESENT	0
583211	583205	19687N	PARTICIPANT	\N	PRESENT	0
583212	583205	14357A	PARTICIPANT	\N	EXCUSE	0
583213	583205	14329V	PARTICIPANT	\N	EXCUSE	0
583214	583205	19551W	PARTICIPANT	\N	PRESENT	0
583215	583205	19545Y	PARTICIPANT	\N	PRESENT	0
583216	583205	14026U	PARTICIPANT	\N	PRESENT	0
583228	582769	19515S	PARTICIPANT	\N	PRESENT	1
583229	582769	11053K	PARTICIPANT	\N	PRESENT	0
583230	582769	14187A	PARTICIPANT	\N	PRESENT	0
583231	582769	17965H	PARTICIPANT	\N	PRESENT	1
583232	582769	19679N	PARTICIPANT	\N	PRESENT	0
583233	582769	18193Q	PRESIDENT	0	PRESENT	0
583234	582769	20066E	PARTICIPANT	\N	PRESENT	1
583235	582769	19367Y	PARTICIPANT	\N	PRESENT	0
583236	582769	19631V	PARTICIPANT	\N	PRESENT	1
583237	582769	20130U	PARTICIPANT	\N	EXCUSE	0
583238	582769	20018V	PARTICIPANT	\N	PRESENT	1
583239	582769	20044X	PARTICIPANT	\N	PRESENT	1
583240	582769	19703U	PARTICIPANT	\N	PRESENT	1
583245	582769	14205J	PARTICIPANT	\N	PRESENT	0
583248	583247	11083R	PARTICIPANT	\N	PRESENT	0
583249	583247	19533U	PARTICIPANT	\N	PRESENT	1
583250	583247	19369B	PARTICIPANT	\N	PRESENT	1
583252	583251	11083R	PARTICIPANT	\N	PRESENT	0
583253	583251	19533U	PARTICIPANT	\N	PRESENT	1
584534	583456	19647E	PARTICIPANT	\N	PRESENT	1
584535	583456	19335Q	PARTICIPANT	\N	PRESENT	1
584536	583456	20036X	PARTICIPANT	\N	PRESENT	1
584537	583456	11012A	PARTICIPANT	\N	PRESENT	1
584538	583456	19479G	PARTICIPANT	\N	PRESENT	1
584607	583457	11053K	PARTICIPANT	\N	PRESENT	1
584608	583457	11110B	PARTICIPANT	\N	PRESENT	1
584609	583457	20126Y	PARTICIPANT	\N	PRESENT	1
584610	583457	20050V	PARTICIPANT	\N	PRESENT	1
584734	582887	14329V	PARTICIPANT	\N	PRESENT	0
593516	593513	04057K	PARTICIPANT	\N	PRESENT	0
593517	593512	11067R	PARTICIPANT	\N	PRESENT	0
593518	593512	14071N	PARTICIPANT	\N	PRESENT	0
593519	593512	20130U	PARTICIPANT	\N	PRESENT	0
593520	593514	04057K	PARTICIPANT	\N	PRESENT	0
593521	593514	20130U	PARTICIPANT	\N	PRESENT	0
593522	593515	04057K	PARTICIPANT	\N	PRESENT	0
593523	593515	20130U	PARTICIPANT	\N	PRESENT	0
593524	593511	19691J	PARTICIPANT	\N	PRESENT	0
593525	593511	14071N	PARTICIPANT	\N	PRESENT	0
593527	593526	08009T	PARTICIPANT	\N	PRESENT	0
593528	593526	19669L	PARTICIPANT	\N	PRESENT	0
593529	593526	19739H	PARTICIPANT	\N	PRESENT	0
593530	593526	10015M	PARTICIPANT	\N	PRESENT	0
593531	593526	19713W	PARTICIPANT	\N	PRESENT	0
593532	593526	14026U	PARTICIPANT	\N	PRESENT	0
593534	593533	20118Y	PARTICIPANT	\N	PRESENT	0
593535	593533	14147R	PARTICIPANT	\N	PRESENT	0
593536	593533	04035D	PARTICIPANT	\N	PRESENT	0
593537	593533	19739H	PARTICIPANT	\N	PRESENT	0
593538	593533	17737W	PARTICIPANT	\N	PRESENT	0
593539	593533	16685X	PARTICIPANT	\N	PRESENT	0
593540	593533	18083K	PARTICIPANT	\N	PRESENT	0
595252	593460	14021P	PARTICIPANT	\N	PRESENT	0
595253	593460	11048N	PARTICIPANT	\N	PRESENT	0
595254	593460	14217N	PARTICIPANT	\N	PRESENT	0
595255	593460	19479G	PARTICIPANT	\N	PRESENT	0
595256	593460	19441R	PARTICIPANT	\N	PRESENT	0
595257	593460	14219Q	PARTICIPANT	\N	PRESENT	0
595259	593460	20092G	PARTICIPANT	\N	PRESENT	0
595260	593460	14147R	PARTICIPANT	\N	PRESENT	0
595261	593460	14251Q	PARTICIPANT	\N	PRESENT	0
595262	593460	14073Q	PARTICIPANT	\N	PRESENT	0
595263	593460	20048C	PARTICIPANT	\N	PRESENT	0
595264	593460	14089Y	PARTICIPANT	\N	PRESENT	0
595265	593460	20122U	PARTICIPANT	\N	PRESENT	0
595266	593460	20104S	PARTICIPANT	\N	PRESENT	0
595267	593460	04043D	PARTICIPANT	\N	PRESENT	0
595271	593460	20044X	PARTICIPANT	\N	PRESENT	0
595269	593460	14105F	PARTICIPANT	\N	PRESENT	0
595270	593460	14121F	PARTICIPANT	\N	PRESENT	0
595275	593460	19611R	PARTICIPANT	\N	PRESENT	0
595277	593460	19739H	PARTICIPANT	\N	PRESENT	0
595279	593460	20136B	PARTICIPANT	\N	PRESENT	0
595300	593460	19747H	PARTICIPANT	\N	PRESENT	0
595308	593460	19782L	PARTICIPANT	\N	PRESENT	0
595318	593460	14069U	PARTICIPANT	\N	PRESENT	0
595322	593460	19543W	PARTICIPANT	\N	PRESENT	0
595323	593460	14215L	PARTICIPANT	\N	PRESENT	0
595326	593460	11067R	PARTICIPANT	\N	PRESENT	0
595329	593460	14053L	PARTICIPANT	\N	PRESENT	0
595330	593460	19467C	PARTICIPANT	\N	PRESENT	0
595332	593460	20126Y	PARTICIPANT	\N	PRESENT	0
595335	593460	19647E	PARTICIPANT	\N	PRESENT	0
595339	593460	19762G	PARTICIPANT	\N	PRESENT	0
595342	593460	19447X	PARTICIPANT	\N	PRESENT	0
595360	593460	11097X	PARTICIPANT	\N	PRESENT	0
595369	593460	20100N	PARTICIPANT	\N	PRESENT	0
595377	593460	19295A	PARTICIPANT	\N	PRESENT	0
595532	595530	14259Y	PARTICIPANT	\N	PRESENT	0
595534	595530	11097X	PARTICIPANT	\N	PRESENT	0
595535	595530	95063L	PARTICIPANT	\N	PRESENT	0
595536	595530	11056N	PARTICIPANT	\N	PRESENT	0
595537	595530	20044X	PARTICIPANT	\N	PRESENT	0
595538	595530	19643A	PARTICIPANT	\N	PRESENT	0
595539	595530	19399H	PARTICIPANT	\N	PRESENT	0
595540	595530	01028R	PARTICIPANT	\N	PRESENT	0
595541	595530	19651A	PARTICIPANT	\N	PRESENT	0
595542	595530	19553Y	PARTICIPANT	\N	PRESENT	0
595543	595530	19954N	PARTICIPANT	\N	PRESENT	0
595544	595530	04071H	PARTICIPANT	\N	PRESENT	0
595545	595530	19479G	PARTICIPANT	\N	PRESENT	0
595546	595530	20144B	PARTICIPANT	\N	EXCUSE	0
595547	595530	04070G	PARTICIPANT	\N	EXCUSE	0
595548	595530	19551W	PARTICIPANT	\N	EXCUSE	0
595549	595530	20018V	PARTICIPANT	\N	EXCUSE	0
595550	595530	20050V	PARTICIPANT	\N	EXCUSE	0
595551	595530	14193X	PARTICIPANT	\N	EXCUSE	0
595552	595530	19703U	PARTICIPANT	\N	EXCUSE	0
595597	595596	11053K	PARTICIPANT	\N	PRESENT	0
595620	595618	14267Y	PARTICIPANT	\N	PRESENT	0
595628	595627	19667J	PARTICIPANT	\N	PRESENT	0
595629	595627	11040E	PARTICIPANT	\N	PRESENT	0
595635	595624	11067R	PARTICIPANT	\N	PRESENT	0
595636	595624	14071N	PARTICIPANT	\N	PRESENT	0
595637	595624	20130U	PARTICIPANT	\N	PRESENT	0
595639	595625	11067R	PARTICIPANT	\N	PRESENT	0
595640	595625	14071N	PARTICIPANT	\N	PRESENT	0
595641	595625	20130U	PARTICIPANT	\N	PRESENT	0
595642	595638	19667J	PARTICIPANT	\N	PRESENT	0
595643	595638	11040E	PARTICIPANT	\N	PRESENT	0
595644	595626	11067R	PARTICIPANT	\N	PRESENT	0
595645	595626	14071N	PARTICIPANT	\N	PRESENT	0
595646	595631	14042U	PARTICIPANT	\N	PRESENT	0
595647	595631	14213J	PARTICIPANT	\N	PRESENT	0
595648	595630	20248J	PARTICIPANT	\N	PRESENT	0
595649	595630	14042U	PARTICIPANT	\N	PRESENT	0
595650	595630	14213J	PARTICIPANT	\N	PRESENT	0
595651	595630	01034P	PARTICIPANT	\N	PRESENT	0
595652	595630	19703U	PARTICIPANT	\N	PRESENT	0
595653	595630	19713W	PARTICIPANT	\N	PRESENT	0
595654	595632	14042U	PARTICIPANT	\N	PRESENT	0
595655	595632	14213J	PARTICIPANT	\N	PRESENT	0
595656	595633	14213J	PARTICIPANT	\N	PRESENT	0
595657	595634	14213J	PARTICIPANT	\N	PRESENT	0
595658	595634	20130U	PARTICIPANT	\N	PRESENT	0
595660	595659	19689Q	PARTICIPANT	\N	PRESENT	0
570356	570355	04070G	PARTICIPANT	\N	PRESENT	0
570357	570355	04034C	PARTICIPANT	\N	PRESENT	0
570358	570355	01028R	PARTICIPANT	\N	PRESENT	0
570689	570329	19515S	PARTICIPANT	\N	PRESENT	0
570690	570329	14357A	PARTICIPANT	\N	PRESENT	0
570691	570329	14038Y	PARTICIPANT	\N	PRESENT	0
570692	570329	14033T	PARTICIPANT	\N	PRESENT	0
570693	570329	11099A	PARTICIPANT	\N	PRESENT	0
570694	570329	11090Q	PRESIDENT	0	PRESENT	0
570695	570329	20082E	PARTICIPANT	\N	PRESENT	0
570696	570329	19413M	PARTICIPANT	\N	PRESENT	0
570697	570329	14257W	PARTICIPANT	\N	PRESENT	0
570698	570329	19747H	PARTICIPANT	\N	PRESENT	0
570699	570329	14187A	PARTICIPANT	\N	PRESENT	0
570700	570329	14205J	PARTICIPANT	\N	PRESENT	0
570701	570329	19441R	PARTICIPANT	\N	PRESENT	0
570702	570329	04045F	PARTICIPANT	\N	PRESENT	0
570704	570329	08028W	PARTICIPANT	\N	EXCUSE	0
570762	570619	14331P	PARTICIPANT	\N	PRESENT	0
570763	570619	12041X	PARTICIPANT	\N	PRESENT	0
570764	570619	11083R	PARTICIPANT	\N	PRESENT	0
570781	570779	04047H	PARTICIPANT	\N	PRESENT	0
570782	570779	04042C	PARTICIPANT	\N	PRESENT	0
570784	570779	11066Q	PARTICIPANT	\N	PRESENT	0
570794	570793	19643A	PARTICIPANT	\N	PRESENT	0
570795	570793	20152B	PARTICIPANT	\N	PRESENT	0
570796	570793	20134Y	PARTICIPANT	\N	PRESENT	1
570797	570793	19691J	PRESIDENT	0	PRESENT	0
570798	570793	04057K	PARTICIPANT	\N	PRESENT	0
577400	577397	19515S	PRESIDENT	0	PRESENT	0
570852	570847	20074E	PARTICIPANT	\N	EXCUSE	0
577398	577397	19717B	PARTICIPANT	\N	PRESENT	0
577401	577397	19575F	PARTICIPANT	\N	PRESENT	0
571947	571305	19745F	PARTICIPANT	\N	EXCUSE	0
577402	577397	14030Q	PARTICIPANT	\N	PRESENT	0
577404	577397	14083S	PARTICIPANT	\N	PRESENT	0
577405	577397	20060X	PARTICIPANT	\N	PRESENT	0
577406	577397	14329V	PARTICIPANT	\N	PRESENT	0
577407	577397	19467C	PARTICIPANT	\N	PRESENT	0
577408	577397	14357A	PARTICIPANT	\N	PRESENT	0
577409	577397	14041T	PARTICIPANT	\N	PRESENT	0
577410	577397	19251M	PARTICIPANT	\N	PRESENT	0
577411	577397	20134Y	PARTICIPANT	\N	PRESENT	0
577412	577397	19695N	PARTICIPANT	\N	PRESENT	0
577413	577397	14031R	PARTICIPANT	\N	PRESENT	0
577414	577397	19671E	PARTICIPANT	\N	PRESENT	0
577415	577397	20092G	PARTICIPANT	\N	PRESENT	0
577417	577397	08060W	PARTICIPANT	\N	EXCUSE	0
577418	577397	14195A	PARTICIPANT	\N	EXCUSE	0
577419	577397	08028W	PARTICIPANT	\N	EXCUSE	0
577420	577397	08011M	PARTICIPANT	\N	EXCUSE	0
577421	577397	20040T	PARTICIPANT	\N	EXCUSE	0
577422	577397	14026U	PARTICIPANT	\N	EXCUSE	0
577424	577397	20126Y	PARTICIPANT	\N	EXCUSE	0
577425	577397	08015R	PARTICIPANT	\N	EXCUSE	0
577427	577397	19697Q	PARTICIPANT	\N	EXCUSE	0
577428	577397	14253S	PARTICIPANT	\N	EXCUSE	0
577429	577397	19679N	PARTICIPANT	\N	EXCUSE	0
577430	577397	20054A	PARTICIPANT	\N	EXCUSE	0
577834	575272	19711U	PARTICIPANT	\N	PRESENT	0
577836	575272	19762G	PARTICIPANT	\N	PRESENT	0
577837	575272	20068G	PARTICIPANT	\N	PRESENT	0
577839	575272	19335Q	PARTICIPANT	\N	PRESENT	0
577842	575272	05008E	PARTICIPANT	\N	PRESENT	0
577860	575272	14030Q	PARTICIPANT	\N	PRESENT	0
577845	575272	04047H	PARTICIPANT	\N	PRESENT	0
577846	575272	19768N	PARTICIPANT	\N	PRESENT	0
577847	575272	20022R	PARTICIPANT	\N	PRESENT	0
577848	575272	19467C	PARTICIPANT	\N	PRESENT	0
577849	575272	20128B	PARTICIPANT	\N	PRESENT	0
577850	575272	12016W	PARTICIPANT	\N	PRESENT	0
577851	575272	19691J	PARTICIPANT	\N	PRESENT	0
577852	575272	20052X	PARTICIPANT	\N	PRESENT	0
577853	575272	19399H	PARTICIPANT	\N	PRESENT	0
577854	575272	14215L	PARTICIPANT	\N	PRESENT	0
577855	575272	14231L	PARTICIPANT	\N	PRESENT	0
577856	575272	14259Y	PARTICIPANT	\N	PRESENT	0
577857	575272	19673G	PARTICIPANT	\N	PRESENT	0
577858	575272	20134Y	PARTICIPANT	\N	PRESENT	0
577859	575272	11090Q	PARTICIPANT	\N	PRESENT	0
577861	575272	20142Y	PARTICIPANT	\N	PRESENT	0
577862	575272	16685X	PARTICIPANT	\N	PRESENT	0
577863	575272	08061X	PARTICIPANT	\N	PRESENT	0
577864	575272	19441R	PARTICIPANT	\N	PRESENT	0
577865	575272	19697Q	PARTICIPANT	\N	PRESENT	0
577866	575272	14249W	PARTICIPANT	\N	PRESENT	0
577867	575272	20094J	PARTICIPANT	\N	PRESENT	0
577868	575272	95063L	PARTICIPANT	\N	PRESENT	0
577869	575272	20046A	PARTICIPANT	\N	PRESENT	0
577871	575272	08034U	PARTICIPANT	\N	PRESENT	0
577875	577870	20084G	PARTICIPANT	\N	PRESENT	0
577873	577870	20022R	PARTICIPANT	\N	PRESENT	0
577874	577870	08010L	PARTICIPANT	\N	PRESENT	0
577876	577870	19758L	PARTICIPANT	\N	PRESENT	0
577877	577870	04045F	PARTICIPANT	\N	PRESENT	0
577878	577870	20090E	PARTICIPANT	\N	PRESENT	0
577879	577870	19489J	PARTICIPANT	\N	PRESENT	0
577880	577870	01057W	PARTICIPANT	\N	PRESENT	0
577881	577870	05012A	PRESIDENT	1	PRESENT	0
577882	577870	08009T	PARTICIPANT	\N	PRESENT	0
577883	577870	14257W	PARTICIPANT	\N	PRESENT	0
577884	575272	19723Y	PARTICIPANT	\N	PRESENT	0
577885	577870	19735D	PARTICIPANT	\N	PRESENT	1
577886	577870	20058E	PARTICIPANT	\N	PRESENT	1
577887	577870	19349W	PARTICIPANT	\N	PRESENT	1
577888	577870	14107H	PARTICIPANT	\N	PRESENT	1
577889	577870	14229S	PARTICIPANT	\N	PRESENT	1
577890	577870	14205J	PARTICIPANT	\N	PRESENT	1
577891	575272	20084G	PARTICIPANT	\N	PRESENT	0
577893	575272	04043D	PARTICIPANT	\N	PRESENT	0
577899	575272	14179A	PARTICIPANT	\N	PRESENT	0
577940	577870	19565D	PARTICIPANT	\N	EXCUSE	0
577941	577870	14231L	PRESIDENT	0	PRESENT	0
577967	568683	19631V	PARTICIPANT	\N	PRESENT	0
577968	568683	18083K	PARTICIPANT	\N	PRESENT	0
577969	568683	19577H	PARTICIPANT	\N	PRESENT	0
577970	568683	17023S	PARTICIPANT	\N	PRESENT	0
577971	568683	20034V	PARTICIPANT	\N	PRESENT	0
577972	568683	19715Y	PARTICIPANT	\N	PRESENT	0
577973	568683	14059S	PARTICIPANT	\N	PRESENT	0
577974	568683	19657G	PARTICIPANT	\N	PRESENT	0
577975	568683	14147R	PARTICIPANT	\N	PRESENT	1
577977	568683	20028X	PARTICIPANT	\N	PRESENT	1
577978	568683	20148F	PARTICIPANT	\N	PRESENT	0
577399	577397	19369B	PARTICIPANT	\N	PRESENT	0
577979	568683	19319Q	PARTICIPANT	\N	PRESENT	1
577980	568683	20150Y	PARTICIPANT	\N	PRESENT	0
578319	577322	04047H	PRESIDENT	0	PRESENT	0
578320	577322	20108W	PARTICIPANT	\N	PRESENT	0
578321	577322	19581D	PARTICIPANT	\N	PRESENT	0
578322	577322	07004J	PARTICIPANT	\N	PRESENT	0
578323	577322	05008E	PARTICIPANT	\N	PRESENT	0
578324	577322	95063L	PARTICIPANT	\N	PRESENT	0
578325	577322	19489J	PARTICIPANT	\N	PRESENT	0
578326	577322	11056N	PARTICIPANT	\N	PRESENT	0
578341	577989	14327T	PARTICIPANT	\N	PRESENT	0
578342	577989	11048N	PARTICIPANT	\N	PRESENT	0
578343	577989	04071H	PARTICIPANT	\N	PRESENT	0
578344	577989	19711U	PARTICIPANT	\N	PRESENT	0
578345	577989	19687N	PARTICIPANT	\N	PRESENT	0
578346	577989	20080C	PARTICIPANT	\N	PRESENT	0
578347	577989	19667J	PARTICIPANT	\N	PRESENT	0
578348	577989	14225N	PRESIDENT	0	PRESENT	0
578349	577989	11012A	PARTICIPANT	\N	PRESENT	0
578350	577989	19349W	PARTICIPANT	\N	PRESENT	0
578351	577989	19741B	PARTICIPANT	\N	PRESENT	0
578352	577989	99004R	PARTICIPANT	\N	PRESENT	0
578353	577989	20116W	PARTICIPANT	\N	PRESENT	0
578354	577989	20022R	PARTICIPANT	\N	PRESENT	0
578355	577989	14331P	PARTICIPANT	\N	PRESENT	0
578356	577989	07029T	PARTICIPANT	\N	PRESENT	0
578357	577989	11040E	PARTICIPANT	\N	PRESENT	0
578358	578169	14026U	PARTICIPANT	\N	PRESENT	0
578359	578169	11048N	PARTICIPANT	\N	PRESENT	0
578360	578169	19563B	PARTICIPANT	\N	PRESENT	0
578361	577989	19762G	PARTICIPANT	\N	PRESENT	0
578362	577989	01057W	PARTICIPANT	\N	PRESENT	0
578363	578169	19611R	PARTICIPANT	\N	PRESENT	0
581935	581934	20060X	PARTICIPANT	\N	PRESENT	0
581936	581934	19701S	PARTICIPANT	\N	PRESENT	0
581937	581934	19333N	PARTICIPANT	\N	PRESENT	0
581938	581934	20056C	PARTICIPANT	\N	PRESENT	0
581939	581934	19723Y	PARTICIPANT	\N	PRESENT	0
581940	581934	19533U	PARTICIPANT	\N	PRESENT	0
588273	585759	19543W	PARTICIPANT	\N	PRESENT	0
588274	585759	19713W	PARTICIPANT	\N	PRESENT	0
588275	585759	20252E	PARTICIPANT	\N	PRESENT	0
588276	585759	14030Q	PARTICIPANT	\N	PRESENT	0
588277	585759	19711U	PARTICIPANT	\N	PRESENT	0
588278	585759	20090E	PARTICIPANT	\N	PRESENT	0
588279	585759	14187A	PARTICIPANT	\N	PRESENT	0
588280	585759	20104S	PARTICIPANT	\N	PRESENT	0
588281	585759	20066E	PARTICIPANT	\N	PRESENT	0
588282	585759	19629C	PARTICIPANT	\N	PRESENT	0
588283	585759	14257W	PARTICIPANT	\N	PRESENT	0
588284	585759	20108W	PARTICIPANT	\N	PRESENT	0
588285	585759	19747H	PARTICIPANT	\N	PRESENT	0
588287	588286	01043Q	PARTICIPANT	\N	PRESENT	0
588288	585759	19749K	PARTICIPANT	\N	PRESENT	0
588289	585759	14123H	PARTICIPANT	\N	PRESENT	0
588290	585759	20032T	PARTICIPANT	\N	PRESENT	0
588295	585759	20110Q	PARTICIPANT	\N	PRESENT	0
588296	585759	11045K	PARTICIPANT	\N	PRESENT	0
588297	585759	14215L	PARTICIPANT	\N	PRESENT	0
588298	585759	04085P	PARTICIPANT	\N	PRESENT	0
588299	585759	20136B	PARTICIPANT	\N	PRESENT	0
588300	585759	19758L	PARTICIPANT	\N	PRESENT	0
588343	588341	14053L	PARTICIPANT	\N	PRESENT	0
588344	588341	14299H	PARTICIPANT	\N	PRESENT	0
588346	588341	11066Q	PARTICIPANT	\N	PRESENT	0
588347	585762	19667J	PARTICIPANT	\N	PRESENT	0
588348	585762	20092G	PARTICIPANT	\N	PRESENT	0
588349	585762	11033F	PARTICIPANT	\N	PRESENT	0
588350	585762	19713W	PARTICIPANT	\N	PRESENT	0
588389	585762	19503N	PARTICIPANT	\N	PRESENT	0
588352	585762	11090Q	PARTICIPANT	\N	PRESENT	0
588353	585762	14329V	PARTICIPANT	\N	PRESENT	0
588354	585762	20022R	PARTICIPANT	\N	PRESENT	0
588387	585762	20054A	PARTICIPANT	\N	PRESENT	0
588356	585762	19711U	PARTICIPANT	\N	PRESENT	0
588357	585762	19695N	PARTICIPANT	\N	PRESENT	0
588388	585762	19441R	PARTICIPANT	\N	PRESENT	0
588391	588390	19447X	PARTICIPANT	\N	PRESENT	0
588360	585762	14257W	PARTICIPANT	\N	PRESENT	0
588361	585762	19413M	PARTICIPANT	\N	PRESENT	0
588392	588390	19749K	PARTICIPANT	\N	PRESENT	0
588393	588390	19725B	PARTICIPANT	\N	PRESENT	0
588394	585762	11012A	PARTICIPANT	\N	PRESENT	0
588365	585762	19782L	PARTICIPANT	\N	PRESENT	0
588395	585762	20032T	PARTICIPANT	\N	PRESENT	0
588367	585762	01025N	PARTICIPANT	\N	PRESENT	0
588396	585762	19515S	PARTICIPANT	\N	PRESENT	0
588369	585762	20090E	PARTICIPANT	\N	PRESENT	0
588370	585762	19387D	PARTICIPANT	\N	PRESENT	0
588371	585762	20136B	PARTICIPANT	\N	PRESENT	0
588372	585762	19629C	PARTICIPANT	\N	PRESENT	0
588373	585762	20066E	PARTICIPANT	\N	PRESENT	0
588374	585762	19671E	PARTICIPANT	\N	PRESENT	0
588375	585762	14038Y	PARTICIPANT	\N	PRESENT	0
588376	585762	19467C	PARTICIPANT	\N	PRESENT	0
588377	585762	19563B	PARTICIPANT	\N	PRESENT	0
588378	585762	19739H	PARTICIPANT	\N	PRESENT	0
588380	588379	20108W	PARTICIPANT	\N	PRESENT	0
588382	588381	20108W	PARTICIPANT	\N	PRESENT	0
588383	585762	08010L	PARTICIPANT	\N	PRESENT	0
588340	585762	11045K	PARTICIPANT	\N	PRESENT	0
588342	588341	04047H	PARTICIPANT	\N	PRESENT	0
588384	585762	14215L	PARTICIPANT	\N	PRESENT	0
588385	585762	19747H	PARTICIPANT	\N	PRESENT	0
588397	585762	19533U	PARTICIPANT	\N	PRESENT	0
588398	585762	11056N	PARTICIPANT	\N	PRESENT	0
588399	585762	20038A	PARTICIPANT	\N	PRESENT	0
588400	585762	04043D	PARTICIPANT	\N	PRESENT	0
588401	585762	19758L	PARTICIPANT	\N	PRESENT	0
588402	585762	19643A	PARTICIPANT	\N	PRESENT	0
588403	585762	20104S	PARTICIPANT	\N	PRESENT	0
588404	585762	19687N	PARTICIPANT	\N	PRESENT	0
588405	585762	20248J	PARTICIPANT	\N	PRESENT	0
588406	585762	04085P	PARTICIPANT	\N	PRESENT	0
588407	585762	19649G	PARTICIPANT	\N	PRESENT	0
588408	585762	14357A	PARTICIPANT	\N	PRESENT	0
588409	585762	20086J	PARTICIPANT	\N	PRESENT	0
588415	585762	14083S	PARTICIPANT	\N	PRESENT	0
588413	585762	11067R	PARTICIPANT	\N	PRESENT	0
588414	585762	19697Q	PARTICIPANT	\N	PRESENT	0
588417	588416	17367Q	PRESIDENT	0	PRESENT	0
588418	588416	14255U	PARTICIPANT	\N	PRESENT	0
588419	588416	20132W	PARTICIPANT	\N	PRESENT	0
588420	588416	11083R	PARTICIPANT	\N	PRESENT	0
588421	588416	07004J	PARTICIPANT	\N	PRESENT	0
588422	588416	19333N	PARTICIPANT	\N	PRESENT	0
588423	588416	11026G	PARTICIPANT	\N	PRESENT	0
588424	588416	19593H	PARTICIPANT	\N	PRESENT	0
588425	588416	19533U	PARTICIPANT	\N	PRESENT	0
588426	588416	20082E	PARTICIPANT	\N	PRESENT	0
588428	588427	11043H	PARTICIPANT	\N	PRESENT	0
588429	588427	08012N	PARTICIPANT	\N	PRESENT	1
588430	588427	19611R	PARTICIPANT	\N	PRESENT	0
588431	585762	11027H	PARTICIPANT	\N	PRESENT	0
588433	588432	20130U	PARTICIPANT	\N	PRESENT	1
588434	588432	20172F	PARTICIPANT	\N	PRESENT	1
588435	585762	20110Q	PARTICIPANT	\N	PRESENT	0
588436	585686	20172F	PARTICIPANT	\N	PRESENT	1
588437	585686	20130U	PARTICIPANT	\N	PRESENT	1
588438	585762	99004R	PARTICIPANT	\N	PRESENT	0
588439	585762	11099A	PARTICIPANT	\N	PRESENT	0
588445	585762	20094J	PARTICIPANT	\N	PRESENT	0
588447	585762	11065P	PARTICIPANT	\N	PRESENT	0
588499	588498	19667J	PARTICIPANT	\N	PRESENT	0
588500	588498	20022R	PARTICIPANT	\N	PRESENT	0
588501	588498	11033F	PARTICIPANT	\N	PRESENT	0
588502	588498	20094J	PARTICIPANT	\N	PRESENT	0
588503	588498	20152B	PARTICIPANT	\N	PRESENT	0
588504	588498	19782L	PARTICIPANT	\N	PRESENT	0
588505	588498	14329V	PARTICIPANT	\N	PRESENT	0
588506	588498	14357A	PARTICIPANT	\N	PRESENT	0
588507	588498	11065P	PARTICIPANT	\N	PRESENT	0
588508	588498	19693L	PARTICIPANT	\N	PRESENT	0
588509	588498	20248J	PARTICIPANT	\N	PRESENT	0
588510	588498	01025N	PARTICIPANT	\N	PRESENT	0
588511	588498	19695N	PARTICIPANT	\N	PRESENT	0
588512	588498	19387D	PARTICIPANT	\N	PRESENT	0
588513	588498	14026U	PARTICIPANT	\N	PRESENT	0
588514	588498	20066E	PARTICIPANT	\N	PRESENT	0
588515	588498	19711U	PARTICIPANT	\N	PRESENT	0
588516	588498	20252E	PARTICIPANT	\N	PRESENT	0
588517	588498	19563B	PARTICIPANT	\N	PRESENT	0
588518	588498	14257W	PARTICIPANT	\N	PRESENT	0
588519	588498	11090Q	PARTICIPANT	\N	PRESENT	0
588520	588498	20092G	PARTICIPANT	\N	PRESENT	0
588521	588498	19687N	PARTICIPANT	\N	PRESENT	0
588522	588498	19713W	PARTICIPANT	\N	PRESENT	0
588523	588498	20136B	PARTICIPANT	\N	PRESENT	0
574065	566272	11010L	PARTICIPANT	\N	EXCUSE	0
574073	566272	19657G	PARTICIPANT	\N	EXCUSE	0
574074	566272	20148F	PARTICIPANT	\N	EXCUSE	0
575211	573462	04043D	PARTICIPANT	\N	EXCUSE	0
575258	575257	14097Y	PARTICIPANT	\N	PRESENT	0
575259	575257	11083R	PARTICIPANT	\N	PRESENT	0
575261	575260	14097Y	PARTICIPANT	\N	PRESENT	1
575262	575260	14133K	PARTICIPANT	\N	PRESENT	1
577157	575270	20068G	PARTICIPANT	\N	PRESENT	0
577158	575270	14147R	PARTICIPANT	\N	PRESENT	0
577159	575270	19573D	PARTICIPANT	\N	PRESENT	0
577160	575270	18083K	PARTICIPANT	\N	PRESENT	0
577161	575270	19503N	PARTICIPANT	\N	PRESENT	0
577162	575270	19565D	PARTICIPANT	\N	PRESENT	0
577163	575270	14219Q	PARTICIPANT	\N	PRESENT	0
577164	575270	20098N	PARTICIPANT	\N	PRESENT	0
577165	575270	20066E	PARTICIPANT	\N	PRESENT	0
577166	575270	20052X	PARTICIPANT	\N	PRESENT	0
577167	575270	19599P	PARTICIPANT	\N	PRESENT	0
577168	575270	19631V	PARTICIPANT	\N	PRESENT	0
577169	575270	20018V	PARTICIPANT	\N	PRESENT	0
577170	575270	20128B	PARTICIPANT	\N	PRESENT	0
577171	575270	11072N	PARTICIPANT	\N	PRESENT	0
577172	575270	19820Y	PARTICIPANT	\N	PRESENT	0
577173	575270	14083S	PARTICIPANT	\N	PRESENT	0
577174	575270	19693L	PARTICIPANT	\N	PRESENT	0
577175	575270	19251M	PARTICIPANT	\N	PRESENT	0
577176	575270	95063L	PARTICIPANT	\N	PRESENT	0
577177	575270	05012A	PARTICIPANT	\N	PRESENT	0
577178	575270	20062A	PARTICIPANT	\N	PRESENT	0
577179	575270	20094J	PARTICIPANT	\N	PRESENT	0
577180	575270	11065P	PARTICIPANT	\N	PRESENT	0
577181	575270	19507S	PARTICIPANT	\N	PRESENT	0
577182	575270	20044X	PARTICIPANT	\N	PRESENT	0
577183	575270	19531S	PARTICIPANT	\N	PRESENT	0
577184	575270	19749K	PARTICIPANT	\N	PRESENT	0
577185	575270	19695N	PARTICIPANT	\N	PRESENT	0
577186	575270	20132W	PARTICIPANT	\N	PRESENT	0
577187	575270	19741B	PARTICIPANT	\N	PRESENT	0
577188	575270	19563B	PARTICIPANT	\N	PRESENT	0
577189	575270	20126Y	PARTICIPANT	\N	PRESENT	0
578713	577325	14215L	PARTICIPANT	\N	PRESENT	1
578714	577325	20128B	PARTICIPANT	\N	PRESENT	1
578715	577325	14179A	PARTICIPANT	\N	PRESENT	1
578716	577325	14147R	PARTICIPANT	\N	PRESENT	1
578719	577325	08018U	PARTICIPANT	\N	EXCUSE	0
578803	578802	04047H	PARTICIPANT	\N	PRESENT	0
578804	578802	11056N	PARTICIPANT	\N	PRESENT	0
578805	578802	20110Q	PARTICIPANT	\N	PRESENT	0
578806	578802	07004J	PARTICIPANT	\N	PRESENT	0
578807	578802	95063L	PARTICIPANT	\N	PRESENT	0
578808	578802	19489J	PARTICIPANT	\N	PRESENT	0
578809	578802	20108W	PARTICIPANT	\N	PRESENT	0
578825	577327	14215L	PARTICIPANT	\N	PRESENT	1
578826	577327	19447X	PARTICIPANT	\N	PRESENT	1
578877	578876	19593H	PARTICIPANT	\N	PRESENT	0
578879	578878	19593H	PARTICIPANT	\N	PRESENT	1
578880	578878	04070G	PARTICIPANT	\N	PRESENT	1
578882	578881	19593H	PARTICIPANT	\N	PRESENT	1
578883	578881	14053L	PARTICIPANT	\N	PRESENT	1
578885	578884	19593H	PARTICIPANT	\N	PRESENT	1
578886	578884	14053L	PARTICIPANT	\N	PRESENT	1
578888	578887	19593H	PARTICIPANT	\N	PRESENT	0
578889	578887	19611R	PARTICIPANT	\N	PRESENT	0
578890	578887	14267Y	PARTICIPANT	\N	PRESENT	0
578891	578887	14053L	PARTICIPANT	\N	PRESENT	0
578972	578909	19687N	PARTICIPANT	\N	PRESENT	0
578973	578909	19551W	PARTICIPANT	\N	PRESENT	1
578974	578909	19689Q	PRESIDENT	0	PRESENT	0
578975	578909	19749K	PARTICIPANT	\N	PRESENT	0
587384	587383	11026G	PARTICIPANT	\N	PRESENT	0
587385	587383	10015M	PARTICIPANT	\N	PRESENT	0
587387	587386	11026G	PARTICIPANT	\N	PRESENT	0
587388	587386	10015M	PARTICIPANT	\N	PRESENT	0
587389	587386	14331P	PARTICIPANT	\N	PRESENT	0
587941	584533	20098N	PARTICIPANT	\N	PRESENT	1
587969	584533	20106U	PARTICIPANT	\N	PRESENT	1
587970	584533	14109K	PARTICIPANT	\N	EXCUSE	0
587971	584533	20118Y	PARTICIPANT	\N	EXCUSE	0
587972	584533	19693L	PARTICIPANT	\N	EXCUSE	0
587973	584533	20046A	PARTICIPANT	\N	EXCUSE	0
587974	584533	20080C	PARTICIPANT	\N	EXCUSE	0
587982	584533	14179A	PARTICIPANT	\N	PRESENT	1
588017	585683	20172F	PARTICIPANT	\N	PRESENT	0
588019	585684	20172F	PARTICIPANT	\N	PRESENT	0
588565	588564	14281W	PARTICIPANT	\N	PRESENT	0
588566	588564	19683J	PARTICIPANT	\N	PRESENT	0
588567	588564	19553Y	PARTICIPANT	\N	PRESENT	0
588568	588564	20130U	PARTICIPANT	\N	PRESENT	0
588569	588563	11031D	PARTICIPANT	\N	PRESENT	0
588570	588563	14042U	PARTICIPANT	\N	PRESENT	0
588571	588563	14281W	PARTICIPANT	\N	PRESENT	0
588572	588563	20130U	PARTICIPANT	\N	PRESENT	0
588573	588563	19683J	PARTICIPANT	\N	PRESENT	0
588576	588574	19415P	PARTICIPANT	\N	PRESENT	0
588577	588575	19415P	PARTICIPANT	\N	PRESENT	0
588578	588575	11067R	PARTICIPANT	\N	PRESENT	0
588579	585842	11067R	PARTICIPANT	\N	PRESENT	0
588594	588593	04047H	PARTICIPANT	\N	PRESENT	0
588595	588593	20108W	PARTICIPANT	\N	PRESENT	0
588596	588593	11072N	PARTICIPANT	\N	PRESENT	0
588598	588597	11072N	PARTICIPANT	\N	PRESENT	0
588599	588597	20108W	PARTICIPANT	\N	PRESENT	0
588601	588600	04047H	PARTICIPANT	\N	PRESENT	0
588602	588600	20108W	PARTICIPANT	\N	PRESENT	0
588603	588600	11072N	PARTICIPANT	\N	PRESENT	0
589587	589586	19251M	PARTICIPANT	\N	PRESENT	0
589588	589586	19711U	PARTICIPANT	\N	PRESENT	0
589589	589586	19593H	PARTICIPANT	\N	PRESENT	0
589590	589586	19782L	PARTICIPANT	\N	PRESENT	0
589591	589586	11064N	PARTICIPANT	\N	PRESENT	0
589592	589586	20084G	PARTICIPANT	\N	PRESENT	0
589637	587935	20144B	PARTICIPANT	\N	PRESENT	0
589638	587935	20174H	PARTICIPANT	\N	PRESENT	1
589640	587935	19347U	PARTICIPANT	\N	PRESENT	0
589643	589642	20080C	PARTICIPANT	\N	PRESENT	0
589687	587936	19760E	PARTICIPANT	\N	PRESENT	0
589688	587936	19717B	PARTICIPANT	\N	PRESENT	0
589689	587936	19367Y	PARTICIPANT	\N	PRESENT	0
589690	587936	20090E	PARTICIPANT	\N	PRESENT	0
589691	587936	14195A	PARTICIPANT	\N	PRESENT	0
589692	587936	19295A	PARTICIPANT	\N	PRESENT	0
589693	587936	14042U	PARTICIPANT	\N	PRESENT	0
589694	587936	20040T	PARTICIPANT	\N	PRESENT	0
589695	587936	14026U	PARTICIPANT	\N	PRESENT	0
589696	587936	19569H	PARTICIPANT	\N	PRESENT	0
589697	587936	14213J	PARTICIPANT	\N	PRESENT	0
589698	587936	20066E	PARTICIPANT	\N	PRESENT	0
589699	587936	19697Q	PARTICIPANT	\N	PRESENT	0
589700	587936	18193Q	PARTICIPANT	\N	PRESENT	0
589701	587936	04057K	PARTICIPANT	\N	PRESENT	0
589702	587936	14223L	PARTICIPANT	\N	PRESENT	0
589703	587936	19679N	PARTICIPANT	\N	PRESENT	0
589704	587936	19798U	PARTICIPANT	\N	PRESENT	0
589705	587936	11097X	PARTICIPANT	\N	PRESENT	0
589706	587936	19703U	PARTICIPANT	\N	PRESENT	0
589707	587936	11103C	PARTICIPANT	\N	PRESENT	1
589708	587936	19691J	PARTICIPANT	\N	PRESENT	1
589709	587936	17779H	PARTICIPANT	\N	PRESENT	1
589710	587936	19301E	PARTICIPANT	\N	PRESENT	1
589711	587936	04047H	PARTICIPANT	\N	PRESENT	0
589712	587936	20074E	PARTICIPANT	\N	PRESENT	0
589713	587936	14231L	PARTICIPANT	\N	PRESENT	0
589714	587936	11026G	PARTICIPANT	\N	PRESENT	0
589715	587936	14111D	PARTICIPANT	\N	PRESENT	0
589716	587936	14147R	PARTICIPANT	\N	PRESENT	0
589717	587936	01028R	PARTICIPANT	\N	PRESENT	0
589718	587936	19585H	PARTICIPANT	\N	PRESENT	0
589719	587936	14069U	PARTICIPANT	\N	PRESENT	1
589720	587936	10015M	PARTICIPANT	\N	PRESENT	1
589721	587936	14107H	PARTICIPANT	\N	PRESENT	1
589722	587936	14030Q	PARTICIPANT	\N	PRESENT	0
589723	587936	14105F	PARTICIPANT	\N	PRESENT	0
589724	587936	14083S	PARTICIPANT	\N	PRESENT	0
589725	587936	19251M	PARTICIPANT	\N	PRESENT	0
589726	587936	14031R	PARTICIPANT	\N	PRESENT	0
589727	587936	19762G	PARTICIPANT	\N	PRESENT	0
589728	587936	19671E	PARTICIPANT	\N	PRESENT	1
589729	588525	19741B	PARTICIPANT	\N	PRESENT	1
589730	588525	19667J	PARTICIPANT	\N	PRESENT	1
589731	588525	11040E	PARTICIPANT	\N	PRESENT	1
580727	580726	19415P	PARTICIPANT	\N	PRESENT	0
580728	580726	19591F	PARTICIPANT	\N	PRESENT	0
580729	580726	20130U	PARTICIPANT	\N	PRESENT	0
580730	580724	19415P	PARTICIPANT	\N	PRESENT	0
580731	580723	19415P	PARTICIPANT	\N	PRESENT	0
580732	580718	14217N	PARTICIPANT	\N	PRESENT	0
580733	580718	14213J	PARTICIPANT	\N	PRESENT	0
580734	580718	19723Y	PARTICIPANT	\N	PRESENT	0
580735	580718	19657G	PARTICIPANT	\N	PRESENT	0
580736	580719	14217N	PARTICIPANT	\N	PRESENT	0
580737	580719	20066E	PARTICIPANT	\N	PRESENT	0
580738	580719	19553Y	PARTICIPANT	\N	PRESENT	0
580739	580719	14213J	PARTICIPANT	\N	PRESENT	0
580740	580719	19723Y	PARTICIPANT	\N	PRESENT	0
580741	580719	19697Q	PARTICIPANT	\N	PRESENT	0
580742	580719	19657G	PARTICIPANT	\N	PRESENT	0
580743	580720	14217N	PARTICIPANT	\N	PRESENT	0
580744	580720	19697Q	PARTICIPANT	\N	PRESENT	0
591653	590394	19663E	PARTICIPANT	\N	PRESENT	0
591654	590394	19679N	PARTICIPANT	\N	PRESENT	0
591660	590394	19715Y	PARTICIPANT	\N	PRESENT	0
591672	590394	20126Y	PARTICIPANT	\N	PRESENT	1
591703	591699	20138D	PARTICIPANT	\N	PRESENT	0
591704	591699	20114U	PARTICIPANT	\N	PRESENT	0
591705	591699	14083S	PARTICIPANT	\N	PRESENT	0
591706	591699	11065P	PARTICIPANT	\N	PRESENT	0
591707	591699	20172F	PARTICIPANT	\N	PRESENT	0
591708	591699	19820Y	PARTICIPANT	\N	PRESENT	0
591710	591699	20180F	PARTICIPANT	\N	PRESENT	0
591711	591699	20106U	PARTICIPANT	\N	PRESENT	0
591712	591699	19723Y	PARTICIPANT	\N	PRESENT	0
591713	591699	14031R	PARTICIPANT	\N	PRESENT	0
591714	591699	19826F	PARTICIPANT	\N	PRESENT	0
591715	591699	20036X	PARTICIPANT	\N	PRESENT	0
591716	591699	14331P	PARTICIPANT	\N	PRESENT	0
591717	591701	20114U	PARTICIPANT	\N	PRESENT	0
591718	591701	14083S	PARTICIPANT	\N	PRESENT	0
591719	591701	11065P	PARTICIPANT	\N	PRESENT	0
591720	591701	19820Y	PARTICIPANT	\N	PRESENT	0
591721	591701	20180F	PARTICIPANT	\N	PRESENT	0
591722	591701	20106U	PARTICIPANT	\N	PRESENT	0
591723	591701	14031R	PARTICIPANT	\N	PRESENT	0
591724	591701	19619A	PARTICIPANT	\N	PRESENT	0
591784	590797	11090Q	PARTICIPANT	\N	EXCUSE	0
593394	590916	14189C	PARTICIPANT	\N	PRESENT	0
593395	590916	99004R	PARTICIPANT	\N	PRESENT	0
593396	590916	11031D	PARTICIPANT	\N	PRESENT	0
593397	590916	20120S	PARTICIPANT	\N	PRESENT	0
593398	590916	19717B	PARTICIPANT	\N	PRESENT	0
593939	590928	19659J	PARTICIPANT	\N	PRESENT	0
593940	590928	20024T	PARTICIPANT	\N	PRESENT	0
593941	590928	20100N	PARTICIPANT	\N	PRESENT	0
593942	590928	14237S	PARTICIPANT	\N	PRESENT	0
593943	590928	20106U	PARTICIPANT	\N	PRESENT	1
593944	591742	20130U	PARTICIPANT	\N	PRESENT	0
593945	591742	11067R	PARTICIPANT	\N	PRESENT	0
593946	591742	20090E	PARTICIPANT	\N	PRESENT	0
593947	591742	01034P	PARTICIPANT	\N	PRESENT	0
593948	591742	04092N	PARTICIPANT	\N	PRESENT	0
593949	591742	19713W	PARTICIPANT	\N	PRESENT	0
593950	591742	11097X	PARTICIPANT	\N	PRESENT	0
594142	592517	19383Y	PARTICIPANT	\N	PRESENT	0
593952	591742	19415P	PARTICIPANT	\N	PRESENT	0
593953	591742	19691J	PARTICIPANT	\N	PRESENT	0
594114	593547	14083S	PARTICIPANT	\N	PRESENT	0
593955	591742	14223L	PARTICIPANT	\N	PRESENT	0
593956	591742	18193Q	PARTICIPANT	\N	PRESENT	0
594116	593547	19349W	PARTICIPANT	\N	PRESENT	0
593958	591742	19723Y	PARTICIPANT	\N	PRESENT	0
593959	591742	19703U	PARTICIPANT	\N	PRESENT	0
593960	591742	20248J	PARTICIPANT	\N	PRESENT	0
593961	591742	20066E	PARTICIPANT	\N	PRESENT	0
593962	591742	14042U	PARTICIPANT	\N	PRESENT	0
594120	591742	19367Y	PARTICIPANT	\N	PRESENT	0
593964	591742	14213J	PARTICIPANT	\N	PRESENT	0
593965	591742	14071N	PARTICIPANT	\N	PRESENT	0
593966	591742	14217N	PARTICIPANT	\N	PRESENT	0
593967	591742	10006L	PRESIDENT	0	PRESENT	0
593969	590928	19549D	PARTICIPANT	\N	PRESENT	0
593970	590928	19820Y	PARTICIPANT	\N	PRESENT	0
593971	590928	20096L	PARTICIPANT	\N	PRESENT	0
593972	590928	19503N	PARTICIPANT	\N	PRESENT	0
593973	590928	11065P	PARTICIPANT	\N	PRESENT	0
593974	590928	05012A	PARTICIPANT	\N	PRESENT	0
593975	590928	20032T	PARTICIPANT	\N	PRESENT	1
593976	590928	14221J	PARTICIPANT	\N	PRESENT	0
593977	590928	14169X	PARTICIPANT	\N	PRESENT	0
593978	590928	19739H	PARTICIPANT	\N	PRESENT	0
593979	590928	19745F	PARTICIPANT	\N	PRESENT	1
594050	590928	20118Y	PARTICIPANT	\N	PRESENT	0
594051	591805	19735D	PARTICIPANT	\N	PRESENT	0
594052	591805	17589D	PARTICIPANT	\N	PRESENT	1
594053	591805	20098N	PARTICIPANT	\N	PRESENT	0
594054	593547	11053K	PARTICIPANT	\N	PRESENT	0
594055	593547	11074Q	PARTICIPANT	\N	PRESENT	0
594056	593547	14173T	PARTICIPANT	\N	PRESENT	0
594057	593547	14121F	PARTICIPANT	\N	PRESENT	0
594058	593547	08034U	PARTICIPANT	\N	PRESENT	0
594082	593547	08012N	PARTICIPANT	\N	PRESENT	0
594083	593547	11104D	PARTICIPANT	\N	PRESENT	0
594087	592950	14053L	PARTICIPANT	\N	PRESENT	0
594088	592950	10015M	PARTICIPANT	\N	PRESENT	0
594089	592950	19543W	PARTICIPANT	\N	PRESENT	0
594090	592950	19581D	PARTICIPANT	\N	PRESENT	0
594091	592950	19673G	PARTICIPANT	\N	PRESENT	0
594092	592950	19675J	PARTICIPANT	\N	PRESENT	0
594093	592950	01028R	PARTICIPANT	\N	PRESENT	0
594094	592950	14231L	PARTICIPANT	\N	PRESENT	0
594095	592950	19447X	PARTICIPANT	\N	PRESENT	0
594096	592950	19725B	PARTICIPANT	\N	PRESENT	0
594097	592950	11056N	PARTICIPANT	\N	PRESENT	0
594098	592950	95063L	PARTICIPANT	\N	PRESENT	0
594099	592950	19629C	PARTICIPANT	\N	PRESENT	0
594100	592950	14147R	PARTICIPANT	\N	PRESENT	0
594101	592950	14151M	PARTICIPANT	\N	PRESENT	0
594102	592950	14069U	PARTICIPANT	\N	PRESENT	0
594103	592950	14215L	PARTICIPANT	\N	PRESENT	0
594104	592950	14259Y	PARTICIPANT	\N	PRESENT	0
594105	592950	20022R	PARTICIPANT	\N	PRESENT	0
594106	592950	19749K	PARTICIPANT	\N	PRESENT	0
594107	592950	20128B	PARTICIPANT	\N	PRESENT	0
594108	592950	19729F	PARTICIPANT	\N	EXCUSE	0
594109	592950	08018U	PARTICIPANT	\N	EXCUSE	0
594110	593547	11070L	PARTICIPANT	\N	PRESENT	0
594111	593547	99004R	PARTICIPANT	\N	PRESENT	0
594112	591742	19591F	PARTICIPANT	\N	PRESENT	0
594113	591742	20126Y	PARTICIPANT	\N	PRESENT	1
594121	593547	19687N	PARTICIPANT	\N	PRESENT	0
594122	593547	08011M	PARTICIPANT	\N	PRESENT	0
594123	593547	14179A	PARTICIPANT	\N	PRESENT	0
594124	591805	20138D	PARTICIPANT	\N	PRESENT	0
594125	591805	11043H	PARTICIPANT	\N	PRESENT	0
594126	591805	11109J	PARTICIPANT	\N	EXCUSE	0
594127	591742	19553Y	PARTICIPANT	\N	PRESENT	0
594143	592517	20088L	PARTICIPANT	\N	PRESENT	1
594144	592517	19768N	PARTICIPANT	\N	PRESENT	0
594145	592517	19515S	PARTICIPANT	\N	PRESENT	0
594146	592517	20092G	PARTICIPANT	\N	PRESENT	0
594147	592517	19782L	PARTICIPANT	\N	PRESENT	0
594148	592517	01043Q	PARTICIPANT	\N	PRESENT	0
594149	592517	14357A	PARTICIPANT	\N	PRESENT	0
594150	592517	19441R	PARTICIPANT	\N	PRESENT	0
594151	592517	20078J	PARTICIPANT	\N	PRESENT	0
594152	592517	19413M	PARTICIPANT	\N	PRESENT	0
594153	592517	20082E	PARTICIPANT	\N	PRESENT	0
594154	592517	20094J	PARTICIPANT	\N	PRESENT	0
594155	592517	19866P	PARTICIPANT	\N	PRESENT	0
594156	592517	04045F	PARTICIPANT	\N	PRESENT	0
594157	592517	19631V	PARTICIPANT	\N	PRESENT	0
594158	592517	20104S	PARTICIPANT	\N	PRESENT	0
594159	592517	11099A	PARTICIPANT	\N	PRESENT	0
594160	592517	19705W	PARTICIPANT	\N	PRESENT	0
594161	592517	19707Y	PARTICIPANT	\N	PRESENT	0
594162	592517	08015R	PARTICIPANT	\N	PRESENT	0
594163	592517	19575F	PARTICIPANT	\N	PRESENT	0
594164	592517	19369B	PARTICIPANT	\N	PRESENT	0
594165	592517	20018V	PARTICIPANT	\N	PRESENT	1
594166	592517	19563B	PARTICIPANT	\N	PRESENT	0
594167	592517	20028X	PARTICIPANT	\N	PRESENT	0
594168	592517	20030R	PARTICIPANT	\N	PRESENT	1
571239	566537	19619A	PARTICIPANT	\N	PRESENT	0
571092	566536	11090Q	PARTICIPANT	\N	PRESENT	0
571093	566536	14215L	PARTICIPANT	\N	PRESENT	0
571094	566536	14219Q	PARTICIPANT	\N	PRESENT	0
571095	566536	20102Q	PARTICIPANT	\N	PRESENT	0
571240	566537	07029T	PARTICIPANT	\N	PRESENT	0
571241	566537	19549D	PARTICIPANT	\N	PRESENT	0
571242	566537	19515S	PARTICIPANT	\N	PRESENT	0
571099	566536	14033T	PARTICIPANT	\N	PRESENT	0
571100	566536	14038Y	PARTICIPANT	\N	PRESENT	0
571101	566536	19631V	PARTICIPANT	\N	PRESENT	0
571243	566537	20136B	PARTICIPANT	\N	PRESENT	0
571103	566536	19701S	PARTICIPANT	\N	PRESENT	0
571244	566537	19551W	PARTICIPANT	\N	PRESENT	0
571105	566536	20076G	PARTICIPANT	\N	PRESENT	0
571106	566536	11065P	PARTICIPANT	\N	PRESENT	0
571107	566536	17229F	PARTICIPANT	\N	PRESENT	0
571108	566536	14031R	PARTICIPANT	\N	PRESENT	0
571245	566537	18083K	PARTICIPANT	\N	PRESENT	0
571246	566537	11085T	PARTICIPANT	\N	PRESENT	0
571111	566536	19369B	PARTICIPANT	\N	PRESENT	0
571248	566537	20152B	PARTICIPANT	\N	PRESENT	0
571249	566537	20110Q	PARTICIPANT	\N	PRESENT	0
571114	566536	19711U	PARTICIPANT	\N	PRESENT	0
571115	566536	19503N	PARTICIPANT	\N	PRESENT	0
571116	566536	19333N	PARTICIPANT	\N	PRESENT	0
571117	566536	14071N	PARTICIPANT	\N	PRESENT	0
571269	566537	19611R	PARTICIPANT	\N	PRESENT	0
571270	566537	11099A	PARTICIPANT	\N	PRESENT	0
571120	566536	19681G	PARTICIPANT	\N	PRESENT	0
571272	566537	14251Q	PARTICIPANT	\N	PRESENT	0
571122	566536	14357A	PARTICIPANT	\N	PRESENT	0
571123	566536	14083S	PARTICIPANT	\N	PRESENT	0
571334	571304	20106U	PARTICIPANT	\N	EXCUSE	0
573286	571156	99004R	PARTICIPANT	\N	PRESENT	0
571126	566536	19599P	PARTICIPANT	\N	PRESENT	0
573287	571156	19333N	PARTICIPANT	\N	PRESENT	0
573288	571156	14031R	PARTICIPANT	\N	PRESENT	0
571137	566536	19637C	PARTICIPANT	\N	PRESENT	0
571139	566536	20092G	PARTICIPANT	\N	PRESENT	0
573289	571156	14038Y	PARTICIPANT	\N	PRESENT	0
571141	566536	17367Q	PARTICIPANT	\N	PRESENT	0
571142	566536	20100N	PARTICIPANT	\N	PRESENT	0
573290	571156	14219Q	PARTICIPANT	\N	PRESENT	0
571165	566536	99004R	PARTICIPANT	\N	PRESENT	0
571170	566536	04043D	PARTICIPANT	\N	PRESENT	0
571173	566536	19251M	PARTICIPANT	\N	PRESENT	0
573291	571156	11090Q	PARTICIPANT	\N	PRESENT	0
571175	566537	11090Q	PARTICIPANT	\N	PRESENT	0
571218	566537	20130U	PARTICIPANT	\N	PRESENT	0
571215	566537	14215L	PARTICIPANT	\N	PRESENT	0
571178	566537	14033T	PARTICIPANT	\N	PRESENT	0
571179	566537	14038Y	PARTICIPANT	\N	PRESENT	0
571180	566537	19631V	PARTICIPANT	\N	PRESENT	0
571217	566537	20102Q	PARTICIPANT	\N	PRESENT	0
571219	566537	19251M	PARTICIPANT	\N	PRESENT	0
571183	566537	20076G	PARTICIPANT	\N	PRESENT	0
571220	566537	14083S	PARTICIPANT	\N	PRESENT	0
573292	571156	19826F	PARTICIPANT	\N	PRESENT	0
571186	566537	14031R	PARTICIPANT	\N	PRESENT	0
571222	566537	14357A	PARTICIPANT	\N	PRESENT	0
571223	566537	14071N	PARTICIPANT	\N	PRESENT	0
571226	566537	19687N	PARTICIPANT	\N	PRESENT	0
571190	566537	19503N	PARTICIPANT	\N	PRESENT	0
571191	566537	19333N	PARTICIPANT	\N	PRESENT	0
571224	566537	99004R	PARTICIPANT	\N	PRESENT	0
571225	566537	11065P	PARTICIPANT	\N	PRESENT	0
571227	566537	19681G	PARTICIPANT	\N	PRESENT	0
571229	566537	19701S	PARTICIPANT	\N	PRESENT	0
571230	566537	19711U	PARTICIPANT	\N	PRESENT	0
571232	566537	17229F	PARTICIPANT	\N	PRESENT	0
571233	566537	19369B	PARTICIPANT	\N	PRESENT	0
571199	566537	19637C	PARTICIPANT	\N	PRESENT	0
571200	566537	20092G	PARTICIPANT	\N	PRESENT	0
571234	566537	14219Q	PARTICIPANT	\N	PRESENT	0
571202	566537	17367Q	PARTICIPANT	\N	PRESENT	0
571235	566537	04043D	PARTICIPANT	\N	PRESENT	0
571236	566536	12041X	PARTICIPANT	\N	PRESENT	0
571237	566536	20130U	PARTICIPANT	\N	PRESENT	0
571206	566537	20100N	PARTICIPANT	\N	PRESENT	0
571238	566536	19687N	PARTICIPANT	\N	PRESENT	0
573293	571156	11040E	PARTICIPANT	\N	PRESENT	0
571209	566537	19599P	PARTICIPANT	\N	PRESENT	0
573294	571156	19711U	PARTICIPANT	\N	PRESENT	0
573295	571156	14215L	PARTICIPANT	\N	PRESENT	0
573296	571156	20102Q	PARTICIPANT	\N	PRESENT	0
571213	566537	12041X	PARTICIPANT	\N	PRESENT	0
573297	571156	11053K	PARTICIPANT	\N	PRESENT	0
573298	571156	20046A	PARTICIPANT	\N	PRESENT	0
573299	571156	19503N	PARTICIPANT	\N	PRESENT	0
573300	571156	11012A	PARTICIPANT	\N	PRESENT	0
573301	571156	19549D	PARTICIPANT	\N	PRESENT	0
573302	571156	11099A	PARTICIPANT	\N	PRESENT	0
573303	571156	20092G	PARTICIPANT	\N	PRESENT	0
573304	571156	11065P	PARTICIPANT	\N	PRESENT	0
573305	571156	19681G	PARTICIPANT	\N	PRESENT	0
573306	571156	14207L	PARTICIPANT	\N	PRESENT	0
573307	571156	20106U	PARTICIPANT	\N	PRESENT	0
573308	571156	19369B	PARTICIPANT	\N	PRESENT	0
573309	571156	20018V	PARTICIPANT	\N	PRESENT	0
573310	571156	19619A	PARTICIPANT	\N	PRESENT	0
573311	571156	19515S	PARTICIPANT	\N	PRESENT	0
573312	571156	20180F	PARTICIPANT	\N	PRESENT	0
573313	571156	19701S	PARTICIPANT	\N	PRESENT	0
573314	571156	07029T	PARTICIPANT	\N	PRESENT	0
573315	571156	19749K	PARTICIPANT	\N	PRESENT	0
573316	571156	20100N	PARTICIPANT	\N	PRESENT	0
573317	571156	14257W	PARTICIPANT	\N	PRESENT	0
573318	571156	20110Q	PARTICIPANT	\N	PRESENT	0
573319	571156	20034V	PARTICIPANT	\N	PRESENT	0
573320	571156	14073Q	PARTICIPANT	\N	PRESENT	0
573321	571156	19413M	PARTICIPANT	\N	PRESENT	0
573322	571156	01048V	PARTICIPANT	\N	PRESENT	0
573323	571156	14030Q	PARTICIPANT	\N	PRESENT	0
573337	571156	20082E	PARTICIPANT	\N	PRESENT	0
573338	571156	19599P	PARTICIPANT	\N	PRESENT	0
573341	571156	11033F	PARTICIPANT	\N	PRESENT	0
573342	571156	19347U	PARTICIPANT	\N	PRESENT	0
573343	571156	19697Q	PARTICIPANT	\N	PRESENT	0
573344	571156	20134Y	PARTICIPANT	\N	PRESENT	0
573346	571156	20114U	PARTICIPANT	\N	PRESENT	0
573347	571156	19631V	PARTICIPANT	\N	PRESENT	0
573404	571157	19503N	PARTICIPANT	\N	PRESENT	0
573405	571157	11033F	PARTICIPANT	\N	PRESENT	0
573406	571157	20100N	PARTICIPANT	\N	PRESENT	0
573407	571157	20106U	PARTICIPANT	\N	PRESENT	0
573408	571157	14207L	PARTICIPANT	\N	PRESENT	0
573409	571157	19515S	PARTICIPANT	\N	PRESENT	0
573410	571157	19369B	PARTICIPANT	\N	PRESENT	0
573411	571157	14038Y	PARTICIPANT	\N	PRESENT	0
573412	571157	14073Q	PARTICIPANT	\N	PRESENT	0
573413	571157	07029T	PARTICIPANT	\N	PRESENT	0
573414	571157	19701S	PARTICIPANT	\N	PRESENT	0
573415	571157	20034V	PARTICIPANT	\N	PRESENT	0
573416	571157	20110Q	PARTICIPANT	\N	PRESENT	0
573417	571157	18083K	PARTICIPANT	\N	PRESENT	0
573418	571157	19711U	PARTICIPANT	\N	PRESENT	0
573419	571157	20180F	PARTICIPANT	\N	PRESENT	0
573420	571157	14031R	PARTICIPANT	\N	PRESENT	0
573421	571157	19826F	PARTICIPANT	\N	PRESENT	0
573422	571157	14215L	PARTICIPANT	\N	PRESENT	0
573423	571157	20046A	PARTICIPANT	\N	PRESENT	0
573424	571157	20114U	PARTICIPANT	\N	PRESENT	0
573425	571157	14219Q	PARTICIPANT	\N	PRESENT	0
573426	571157	01048V	PARTICIPANT	\N	PRESENT	0
573427	571157	11090Q	PARTICIPANT	\N	PRESENT	0
573428	571157	19697Q	PARTICIPANT	\N	PRESENT	0
573429	571157	20136B	PARTICIPANT	\N	PRESENT	0
573430	571157	11065P	PARTICIPANT	\N	PRESENT	0
573431	571157	19619A	PARTICIPANT	\N	PRESENT	0
573432	571157	19631V	PARTICIPANT	\N	PRESENT	0
573433	571157	11099A	PARTICIPANT	\N	PRESENT	0
573434	571157	19549D	PARTICIPANT	\N	PRESENT	0
573435	571157	11012A	PARTICIPANT	\N	PRESENT	0
573436	571157	19333N	PARTICIPANT	\N	PRESENT	0
573437	571157	20082E	PARTICIPANT	\N	PRESENT	0
573402	571157	11070L	PARTICIPANT	\N	PRESENT	0
573403	571157	11040E	PARTICIPANT	\N	PRESENT	0
573438	571157	14257W	PARTICIPANT	\N	PRESENT	0
573439	571157	20102Q	PARTICIPANT	\N	PRESENT	0
573440	571157	19599P	PARTICIPANT	\N	PRESENT	0
581827	578409	14030Q	PRESIDENT	0	PRESENT	0
581828	578409	19693L	PARTICIPANT	\N	EXCUSE	0
581829	578409	19599P	PARTICIPANT	\N	PRESENT	0
581830	578409	04035D	PARTICIPANT	\N	PRESENT	0
581831	578409	14109K	PARTICIPANT	\N	PRESENT	0
581832	578409	11045K	PARTICIPANT	\N	PRESENT	0
581833	578409	19749K	PARTICIPANT	\N	PRESENT	0
581834	578409	19866P	PARTICIPANT	\N	PRESENT	0
581835	578409	11031D	PARTICIPANT	\N	EXCUSE	0
581836	578409	20118Y	PARTICIPANT	\N	EXCUSE	0
581837	578409	20130U	PARTICIPANT	\N	EXCUSE	0
581838	578409	19681G	PARTICIPANT	\N	EXCUSE	0
581839	578409	20024T	PARTICIPANT	\N	EXCUSE	0
581840	578409	08017T	PARTICIPANT	\N	EXCUSE	0
581841	578409	17737W	PARTICIPANT	\N	PRESENT	0
581842	578409	19768N	PARTICIPANT	\N	PRESENT	0
581843	578409	14179A	PARTICIPANT	\N	PRESENT	0
581844	578409	19798U	PARTICIPANT	\N	PRESENT	1
581845	578409	19715Y	PARTICIPANT	\N	PRESENT	0
581887	578409	19621T	PARTICIPANT	\N	EXCUSE	0
581888	578409	07029T	PARTICIPANT	\N	EXCUSE	0
581889	578409	20066E	PARTICIPANT	\N	PRESENT	0
582708	582707	16685X	PARTICIPANT	\N	PRESENT	0
582709	582707	07004J	PARTICIPANT	\N	PRESENT	0
583615	583614	11026G	PARTICIPANT	\N	PRESENT	0
583616	583614	10015M	PARTICIPANT	\N	PRESENT	0
583618	583617	11026G	PARTICIPANT	\N	PRESENT	0
583619	583617	10015M	PARTICIPANT	\N	PRESENT	0
583621	583620	11026G	PARTICIPANT	\N	PRESENT	0
583622	583620	10015M	PARTICIPANT	\N	PRESENT	0
583627	583626	11026G	PARTICIPANT	\N	PRESENT	0
583628	583626	10015M	PARTICIPANT	\N	PRESENT	0
583630	583629	11026G	PARTICIPANT	\N	PRESENT	0
583631	583629	10015M	PARTICIPANT	\N	PRESENT	0
583633	583632	11026G	PARTICIPANT	\N	PRESENT	0
583634	583632	10015M	PARTICIPANT	\N	PRESENT	0
583636	583635	11026G	PARTICIPANT	\N	PRESENT	0
583637	583635	10015M	PARTICIPANT	\N	PRESENT	0
588524	586490	17589D	PARTICIPANT	\N	EXCUSE	0
588882	588526	11067R	PARTICIPANT	\N	EXCUSE	0
589061	588526	04047H	PARTICIPANT	\N	PRESENT	0
589111	588526	19301E	PARTICIPANT	\N	PRESENT	1
589178	583207	14189C	PARTICIPANT	\N	EXCUSE	0
589180	583207	20024T	PARTICIPANT	\N	PRESENT	0
589182	583207	14030Q	PRESIDENT	0	PRESENT	0
589186	583207	20080C	PARTICIPANT	\N	EXCUSE	0
589187	583207	11031D	PARTICIPANT	\N	PRESENT	0
589188	583207	19693L	PARTICIPANT	\N	PRESENT	0
589190	583207	19599P	PARTICIPANT	\N	PRESENT	0
589191	583207	20066E	PARTICIPANT	\N	EXCUSE	0
589192	583207	19715Y	PARTICIPANT	\N	PRESENT	1
589193	583207	14221J	PARTICIPANT	\N	PRESENT	0
589194	583207	14109K	PARTICIPANT	\N	PRESENT	0
589195	583207	19866P	PARTICIPANT	\N	PRESENT	1
589196	583207	20118Y	PARTICIPANT	\N	EXCUSE	0
589197	583207	20098N	PARTICIPANT	\N	PRESENT	1
589198	583207	20046A	PARTICIPANT	\N	PRESENT	0
589199	583207	19749K	PARTICIPANT	\N	PRESENT	0
589204	583207	14179A	PARTICIPANT	\N	PRESENT	1
589208	588229	19631V	PARTICIPANT	\N	PRESENT	0
589209	588229	19515S	PARTICIPANT	\N	PRESENT	0
589210	588229	19575F	PARTICIPANT	\N	PRESENT	0
589211	588229	20094J	PARTICIPANT	\N	PRESENT	0
589212	588229	19747H	PARTICIPANT	\N	PRESENT	0
589213	588229	19383Y	PARTICIPANT	\N	PRESENT	0
589214	588229	19782L	PARTICIPANT	\N	PRESENT	0
589215	588229	14207L	PARTICIPANT	\N	PRESENT	0
589216	588229	20104S	PARTICIPANT	\N	PRESENT	0
589217	588229	08028W	PARTICIPANT	\N	PRESENT	0
589218	588229	14357A	PARTICIPANT	\N	PRESENT	0
589219	588229	14187A	PARTICIPANT	\N	PRESENT	0
589220	588229	19511N	PARTICIPANT	\N	PRESENT	0
589221	588229	01043Q	PARTICIPANT	\N	PRESENT	0
589222	588229	14251Q	PARTICIPANT	\N	PRESENT	0
589223	588229	19563B	PARTICIPANT	\N	PRESENT	0
589224	588229	20028X	PARTICIPANT	\N	PRESENT	0
589225	588229	20018V	PARTICIPANT	\N	PRESENT	0
589226	588229	14257W	PARTICIPANT	\N	PRESENT	0
589227	588229	11090Q	PARTICIPANT	\N	PRESENT	0
589228	588229	19705W	PARTICIPANT	\N	PRESENT	0
589229	588229	20078J	PARTICIPANT	\N	PRESENT	1
589230	588229	20088L	PARTICIPANT	\N	PRESENT	1
589231	588229	19467C	PARTICIPANT	\N	PRESENT	1
589232	588229	08015R	PARTICIPANT	\N	PRESENT	1
589233	588229	14205J	PARTICIPANT	\N	PRESENT	1
589234	588229	19768N	PARTICIPANT	\N	PRESENT	1
589235	588229	19866P	PARTICIPANT	\N	PRESENT	1
589236	588229	20030R	PARTICIPANT	\N	PRESENT	1
589237	588229	19760E	PARTICIPANT	\N	PRESENT	0
589238	588229	19717B	PARTICIPANT	\N	PRESENT	0
589239	588229	19367Y	PARTICIPANT	\N	PRESENT	0
589240	588229	20090E	PARTICIPANT	\N	PRESENT	0
589241	588229	14195A	PARTICIPANT	\N	PRESENT	0
589242	588229	19295A	PARTICIPANT	\N	PRESENT	0
589243	588229	14042U	PARTICIPANT	\N	PRESENT	0
589244	588229	20040T	PARTICIPANT	\N	PRESENT	0
589245	588229	14026U	PARTICIPANT	\N	PRESENT	0
589246	588229	19569H	PARTICIPANT	\N	PRESENT	0
589247	588229	14213J	PARTICIPANT	\N	PRESENT	0
589248	588229	20066E	PARTICIPANT	\N	PRESENT	0
589249	588229	19697Q	PARTICIPANT	\N	PRESENT	0
589250	588229	18193Q	PARTICIPANT	\N	PRESENT	0
589251	588229	04057K	PARTICIPANT	\N	PRESENT	0
589252	588229	14223L	PARTICIPANT	\N	PRESENT	0
589253	588229	19679N	PARTICIPANT	\N	PRESENT	0
589254	588229	19798U	PARTICIPANT	\N	PRESENT	0
589255	588229	11097X	PARTICIPANT	\N	PRESENT	0
589256	588229	19703U	PARTICIPANT	\N	PRESENT	0
589258	588229	11103C	PARTICIPANT	\N	PRESENT	1
589259	588229	19691J	PARTICIPANT	\N	PRESENT	1
589260	588229	17779H	PARTICIPANT	\N	PRESENT	1
589261	588229	19301E	PARTICIPANT	\N	PRESENT	1
589263	588229	19762G	PARTICIPANT	\N	PRESENT	1
589264	588229	19671E	PARTICIPANT	\N	PRESENT	1
589277	588229	14030Q	PARTICIPANT	\N	PRESENT	0
589278	588229	14105F	PARTICIPANT	\N	PRESENT	0
589279	588229	14083S	PARTICIPANT	\N	PRESENT	0
589280	588229	19251M	PARTICIPANT	\N	PRESENT	0
589281	588229	14031R	PARTICIPANT	\N	PRESENT	0
589282	588230	14107H	PARTICIPANT	\N	PRESENT	1
589283	588230	08018U	PARTICIPANT	\N	EXCUSE	0
589354	588234	20074E	PARTICIPANT	\N	PRESENT	0
589355	588234	19581D	PARTICIPANT	\N	PRESENT	0
589356	588234	04047H	PRESIDENT	0	PRESENT	0
589357	588234	19673G	PARTICIPANT	\N	PRESENT	0
589358	588234	19675J	PARTICIPANT	\N	PRESENT	0
589359	588234	01028R	PARTICIPANT	\N	PRESENT	0
589360	588234	05008E	PARTICIPANT	\N	PRESENT	0
589361	588234	14231L	PARTICIPANT	\N	PRESENT	0
589362	588234	19489J	PARTICIPANT	\N	PRESENT	0
589363	588234	17737W	PARTICIPANT	\N	PRESENT	0
589364	588234	07004J	PARTICIPANT	\N	PRESENT	0
589365	588234	20108W	PARTICIPANT	\N	PRESENT	0
589366	588234	20110Q	PARTICIPANT	\N	PRESENT	0
589367	588234	14147R	PARTICIPANT	\N	PRESENT	0
589368	588234	14151M	PARTICIPANT	\N	PRESENT	0
589369	588234	14215L	PARTICIPANT	\N	PRESENT	0
589370	588234	11072N	PARTICIPANT	\N	PRESENT	0
589371	588234	14053L	PARTICIPANT	\N	PRESENT	0
589372	588234	14111D	PARTICIPANT	\N	PRESENT	0
589373	588234	11026G	PARTICIPANT	\N	PRESENT	0
589374	588234	19725B	PARTICIPANT	\N	PRESENT	0
589375	588234	19729F	PARTICIPANT	\N	PRESENT	0
589376	588234	19629C	PARTICIPANT	\N	PRESENT	0
589377	588234	11085T	PARTICIPANT	\N	PRESENT	0
589378	588234	04008A	PARTICIPANT	\N	PRESENT	0
589379	588234	19749K	PARTICIPANT	\N	PRESENT	0
589380	588234	14021P	PARTICIPANT	\N	PRESENT	0
589381	588234	08018U	PARTICIPANT	\N	EXCUSE	0
589389	588525	14327T	PARTICIPANT	\N	PRESENT	0
589390	588525	20086J	PARTICIPANT	\N	PRESENT	0
589391	588525	11048N	PARTICIPANT	\N	PRESENT	0
589392	588525	19711U	PARTICIPANT	\N	PRESENT	0
589393	588525	20080C	PARTICIPANT	\N	PRESENT	0
589394	588525	14121F	PARTICIPANT	\N	PRESENT	0
589395	588525	08011M	PARTICIPANT	\N	PRESENT	0
589396	588525	20116W	PARTICIPANT	\N	PRESENT	0
589397	588525	14225N	PRESIDENT	0	PRESENT	0
589398	588525	20126Y	PARTICIPANT	\N	PRESENT	0
589399	588525	14173T	PARTICIPANT	\N	PRESENT	0
589401	588525	11070L	PARTICIPANT	\N	PRESENT	0
574993	573334	08073C	PARTICIPANT	\N	PRESENT	0
574997	573334	14041T	PARTICIPANT	\N	PRESENT	0
574998	573334	14097Y	PARTICIPANT	\N	PRESENT	0
574999	573334	07029T	PARTICIPANT	\N	PRESENT	0
575000	573334	19399H	PARTICIPANT	\N	PRESENT	0
575001	573334	11040E	PARTICIPANT	\N	PRESENT	0
575002	573334	18083K	PARTICIPANT	\N	PRESENT	0
575003	573334	19479G	PARTICIPANT	\N	PRESENT	0
575004	573334	11053K	PARTICIPANT	\N	PRESENT	0
575005	573334	19711U	PARTICIPANT	\N	PRESENT	0
575006	573334	14073Q	PARTICIPANT	\N	PRESENT	0
575007	573334	19758L	PARTICIPANT	\N	PRESENT	0
575008	573334	14327T	PARTICIPANT	\N	PRESENT	0
575020	573334	20142Y	PARTICIPANT	\N	PRESENT	0
575010	573334	11048N	PARTICIPANT	\N	PRESENT	0
575011	573334	14225N	PARTICIPANT	\N	PRESENT	0
575012	573334	04070G	PARTICIPANT	\N	PRESENT	0
575013	573334	11012A	PARTICIPANT	\N	PRESENT	0
575014	573334	14215L	PARTICIPANT	\N	PRESENT	0
575015	573334	20044X	PARTICIPANT	\N	PRESENT	0
575016	573334	08069G	PARTICIPANT	\N	PRESENT	0
575017	573334	17367Q	PARTICIPANT	\N	PRESENT	0
575018	573334	20080C	PARTICIPANT	\N	PRESENT	0
575019	573334	19335Q	PARTICIPANT	\N	PRESENT	0
575021	573334	19689Q	PARTICIPANT	\N	PRESENT	0
575022	573334	19647E	PARTICIPANT	\N	PRESENT	0
575023	573334	14221J	PARTICIPANT	\N	PRESENT	0
575024	573334	20144B	PARTICIPANT	\N	PRESENT	0
575025	573334	19349W	PARTICIPANT	\N	PRESENT	0
575026	573334	04092N	PARTICIPANT	\N	PRESENT	0
575027	573334	14219Q	PARTICIPANT	\N	PRESENT	0
575028	573334	19649G	PARTICIPANT	\N	PRESENT	0
575029	573334	01057W	PARTICIPANT	\N	PRESENT	0
575030	573334	08011M	PARTICIPANT	\N	PRESENT	0
575031	573334	19725B	PARTICIPANT	\N	PRESENT	0
575032	573334	14259Y	PARTICIPANT	\N	PRESENT	0
575033	573334	16685X	PARTICIPANT	\N	PRESENT	0
575034	573334	08010L	PARTICIPANT	\N	PRESENT	0
575035	573334	11067R	PARTICIPANT	\N	PRESENT	0
575036	573334	14253S	PARTICIPANT	\N	PRESENT	0
575037	573334	20092G	PARTICIPANT	\N	PRESENT	0
575038	573334	19709B	PARTICIPANT	\N	PRESENT	0
575056	573334	19747H	PARTICIPANT	\N	PRESENT	0
575057	573334	14189C	PARTICIPANT	\N	PRESENT	0
575058	573334	19713W	PARTICIPANT	\N	PRESENT	0
575059	573334	14357A	PARTICIPANT	\N	PRESENT	0
575060	573334	99004R	PARTICIPANT	\N	PRESENT	0
575061	573334	19347U	PARTICIPANT	\N	PRESENT	0
575062	573334	14021P	PARTICIPANT	\N	PRESENT	0
575063	573334	11099A	PARTICIPANT	\N	PRESENT	0
575064	573334	14109K	PARTICIPANT	\N	PRESENT	0
575065	573334	14069U	PARTICIPANT	\N	PRESENT	0
575066	573334	14231L	PARTICIPANT	\N	PRESENT	0
575068	573334	20130U	PARTICIPANT	\N	PRESENT	0
575069	573334	14123H	PARTICIPANT	\N	PRESENT	0
575112	573335	14041T	PARTICIPANT	\N	PRESENT	0
575113	573335	11048N	PARTICIPANT	\N	PRESENT	0
575114	573335	11040E	PARTICIPANT	\N	PRESENT	0
575115	573335	14097Y	PARTICIPANT	\N	PRESENT	0
575116	573335	19711U	PARTICIPANT	\N	PRESENT	0
575117	573335	14225N	PARTICIPANT	\N	PRESENT	0
575118	573335	07029T	PARTICIPANT	\N	PRESENT	0
575119	573335	14030Q	PARTICIPANT	\N	PRESENT	0
575120	573335	19758L	PARTICIPANT	\N	PRESENT	0
575121	573335	14069U	PARTICIPANT	\N	PRESENT	0
575122	573335	14253S	PARTICIPANT	\N	PRESENT	0
575123	573335	20080C	PARTICIPANT	\N	PRESENT	0
575124	573335	19667J	PARTICIPANT	\N	PRESENT	0
575125	573335	19349W	PARTICIPANT	\N	PRESENT	0
575126	573335	19689Q	PARTICIPANT	\N	PRESENT	0
575127	573335	19647E	PARTICIPANT	\N	PRESENT	0
575128	573335	14327T	PARTICIPANT	\N	PRESENT	0
575129	573335	19479G	PARTICIPANT	\N	PRESENT	0
575130	573335	20142Y	PARTICIPANT	\N	PRESENT	0
575131	573335	20130U	PARTICIPANT	\N	PRESENT	0
575132	573335	11099A	PARTICIPANT	\N	PRESENT	0
575133	573335	19747H	PARTICIPANT	\N	PRESENT	0
575134	573335	14179A	PARTICIPANT	\N	PRESENT	0
575135	573335	14109K	PARTICIPANT	\N	PRESENT	0
575136	573335	19335Q	PARTICIPANT	\N	PRESENT	0
575137	573335	99004R	PARTICIPANT	\N	PRESENT	0
575138	573335	04043D	PARTICIPANT	\N	PRESENT	0
575139	573335	01057W	PARTICIPANT	\N	PRESENT	0
575140	573335	11012A	PARTICIPANT	\N	PRESENT	0
575142	573335	08011M	PARTICIPANT	\N	PRESENT	0
575143	573335	11053K	PARTICIPANT	\N	PRESENT	0
575110	573335	11070L	PARTICIPANT	\N	PRESENT	0
575111	573335	19709B	PARTICIPANT	\N	PRESENT	0
575150	573335	14189C	PARTICIPANT	\N	PRESENT	0
575156	573335	19503N	PARTICIPANT	\N	PRESENT	0
575157	573335	18083K	PARTICIPANT	\N	PRESENT	0
575158	573335	20134Y	PARTICIPANT	\N	PRESENT	0
575159	573335	20048C	PARTICIPANT	\N	PRESENT	0
575163	573335	14219Q	PARTICIPANT	\N	PRESENT	0
575165	573335	19762G	PARTICIPANT	\N	PRESENT	0
575186	573335	08010L	PARTICIPANT	\N	PRESENT	0
575208	573335	14123H	PARTICIPANT	\N	PRESENT	0
575222	573335	20092G	PARTICIPANT	\N	PRESENT	0
575225	573335	17023S	PARTICIPANT	\N	PRESENT	0
575226	573335	14259Y	PARTICIPANT	\N	PRESENT	0
575227	573335	04085P	PARTICIPANT	\N	PRESENT	0
575229	573335	19593H	PARTICIPANT	\N	PRESENT	0
575230	573335	01048V	PARTICIPANT	\N	PRESENT	0
575231	573335	17367Q	PARTICIPANT	\N	PRESENT	0
575234	573335	11033F	PARTICIPANT	\N	PRESENT	0
575242	573335	01028R	PARTICIPANT	\N	PRESENT	0
575243	573335	19713W	PARTICIPANT	\N	PRESENT	0
575254	573335	20034V	PARTICIPANT	\N	PRESENT	0
575251	573335	19687N	PARTICIPANT	\N	PRESENT	0
575252	573335	20070A	PARTICIPANT	\N	PRESENT	0
575286	575285	19367Y	PARTICIPANT	\N	PRESENT	0
575287	575285	14213J	PARTICIPANT	\N	PRESENT	0
575288	575285	11067R	PARTICIPANT	\N	PRESENT	0
575289	575283	14213J	PARTICIPANT	\N	PRESENT	0
575290	575283	11067R	PARTICIPANT	\N	PRESENT	0
575291	575284	14213J	PARTICIPANT	\N	PRESENT	0
575292	575284	11067R	PARTICIPANT	\N	PRESENT	0
575296	575295	08018U	PARTICIPANT	\N	PRESENT	0
575297	575295	14231L	PARTICIPANT	\N	PRESENT	0
575298	575295	11083R	PARTICIPANT	\N	PRESENT	0
575299	575295	19503N	PARTICIPANT	\N	PRESENT	0
575300	575295	14357A	PARTICIPANT	\N	PRESENT	0
575301	575295	17023S	PARTICIPANT	\N	PRESENT	0
575303	575302	19735D	PRESIDENT	0	PRESENT	0
575304	575302	04070G	PARTICIPANT	\N	PRESENT	1
575305	575302	20058E	PARTICIPANT	\N	PRESENT	0
575306	575302	14147R	PARTICIPANT	\N	PRESENT	0
575307	575302	20056C	PARTICIPANT	\N	PRESENT	0
575308	575302	20114U	PARTICIPANT	\N	PRESENT	0
575513	574853	14071N	PRESIDENT	0	PRESENT	0
575514	574853	19697Q	PARTICIPANT	\N	PRESENT	0
575515	574853	19717B	PARTICIPANT	\N	PRESENT	0
575516	574853	20130U	PARTICIPANT	\N	PRESENT	1
575517	574853	19301E	PARTICIPANT	\N	PRESENT	1
575519	574853	10006L	PARTICIPANT	\N	EXCUSE	0
575520	574853	19569H	PARTICIPANT	\N	PRESENT	0
575521	574853	17965H	PARTICIPANT	\N	PRESENT	0
575527	574853	14026U	PARTICIPANT	\N	PRESENT	0
575528	574853	19760E	PARTICIPANT	\N	PRESENT	1
575529	574853	19723Y	PARTICIPANT	\N	PRESENT	1
575531	574853	18193Q	PARTICIPANT	\N	PRESENT	1
575532	574853	11097X	PARTICIPANT	\N	PRESENT	0
575545	574853	11067R	PARTICIPANT	\N	EXCUSE	0
575546	574853	11031D	PARTICIPANT	\N	PRESENT	0
577226	575109	19629C	PARTICIPANT	\N	PRESENT	1
577227	575109	20128B	PARTICIPANT	\N	PRESENT	1
577228	575109	14179A	PARTICIPANT	\N	PRESENT	1
577229	575109	14069U	PARTICIPANT	\N	PRESENT	1
577230	575109	14107H	PARTICIPANT	\N	PRESENT	1
577259	575109	20074E	PARTICIPANT	\N	EXCUSE	0
579449	579448	19701S	PARTICIPANT	\N	PRESENT	0
579450	579448	11027H	PARTICIPANT	\N	PRESENT	0
579452	579448	14231L	PARTICIPANT	\N	PRESENT	0
579453	579448	20086J	PARTICIPANT	\N	PRESENT	0
579714	579132	20108W	PARTICIPANT	\N	PRESENT	0
579715	579132	19447X	PARTICIPANT	\N	PRESENT	0
579719	579388	19693L	PARTICIPANT	\N	PRESENT	0
579717	579388	08073C	PARTICIPANT	\N	PRESENT	0
579718	579388	19691J	PARTICIPANT	\N	PRESENT	0
579720	579388	08045X	PARTICIPANT	\N	PRESENT	0
582627	582625	20128B	PARTICIPANT	\N	PRESENT	0
582628	582626	20128B	PARTICIPANT	\N	PRESENT	0
591729	591727	19735D	PARTICIPANT	\N	PRESENT	0
591731	591727	01048V	PARTICIPANT	\N	PRESENT	0
591732	591727	19503N	PARTICIPANT	\N	PRESENT	0
591734	591727	20128B	PARTICIPANT	\N	PRESENT	0
591735	591727	19693L	PARTICIPANT	\N	PRESENT	0
593106	593093	17737W	PARTICIPANT	\N	PRESENT	0
593107	593094	17737W	PARTICIPANT	\N	PRESENT	0
593174	590544	14147R	PARTICIPANT	\N	PRESENT	1
593179	593175	19709B	PARTICIPANT	\N	PRESENT	0
593195	590947	19717B	PRESIDENT	0	PRESENT	0
593196	590947	19631V	PARTICIPANT	\N	PRESENT	1
593197	590947	18083K	PARTICIPANT	\N	PRESENT	0
593198	590947	14259Y	PARTICIPANT	\N	EXCUSE	0
593199	590947	17023S	PARTICIPANT	\N	PRESENT	0
593200	590947	97011G	PARTICIPANT	\N	PRESENT	0
593201	590947	11010L	PARTICIPANT	\N	PRESENT	0
593202	590947	19691J	PARTICIPANT	\N	EXCUSE	0
593203	590947	20034V	PARTICIPANT	\N	PRESENT	0
593204	590947	19715Y	PARTICIPANT	\N	EXCUSE	0
593206	590947	14097Y	PARTICIPANT	\N	PRESENT	1
593208	590947	08034U	PARTICIPANT	\N	PRESENT	0
593209	590947	14059S	PARTICIPANT	\N	PRESENT	0
593210	590947	12016W	PARTICIPANT	\N	PRESENT	1
593211	590947	14147R	PARTICIPANT	\N	PRESENT	0
593212	590947	20028X	PARTICIPANT	\N	PRESENT	0
593213	590947	08073C	PARTICIPANT	\N	EXCUSE	0
593214	590947	20146D	PARTICIPANT	\N	EXCUSE	0
593215	590947	20148F	PARTICIPANT	\N	PRESENT	1
593216	590947	14331P	PARTICIPANT	\N	EXCUSE	0
593217	590947	14275Y	PARTICIPANT	\N	PRESENT	0
593218	590947	19301E	PARTICIPANT	\N	PRESENT	1
593219	590947	14031R	PARTICIPANT	\N	PRESENT	0
593291	593287	14097Y	PARTICIPANT	\N	PRESENT	0
593293	593287	11054L	PARTICIPANT	\N	PRESENT	0
593297	593287	12041X	PARTICIPANT	\N	PRESENT	0
593313	593312	05008E	PARTICIPANT	\N	PRESENT	0
593314	593312	11053K	PARTICIPANT	\N	PRESENT	0
593315	593312	01028R	PARTICIPANT	\N	PRESENT	0
593968	591742	19798U	PARTICIPANT	\N	PRESENT	0
594020	591742	19569H	PARTICIPANT	\N	PRESENT	0
594025	591742	20172F	PARTICIPANT	\N	PRESENT	0
594134	594128	19575F	PARTICIPANT	\N	PRESENT	0
594032	591742	19663E	PARTICIPANT	\N	PRESENT	0
594046	591742	19760E	PARTICIPANT	\N	PRESENT	0
594047	591742	11031D	PARTICIPANT	\N	PRESENT	0
594048	591742	04057K	PARTICIPANT	\N	PRESENT	0
594049	591742	19679N	PARTICIPANT	\N	PRESENT	0
594115	593436	14053L	PARTICIPANT	\N	EXCUSE	0
594133	594128	14033T	PARTICIPANT	\N	PRESENT	0
594135	594129	14033T	PARTICIPANT	\N	PRESENT	0
594137	594130	14033T	PARTICIPANT	\N	PRESENT	0
594138	594130	14207L	PARTICIPANT	\N	PRESENT	0
594139	594131	14033T	PARTICIPANT	\N	PRESENT	0
594140	594131	19575F	PARTICIPANT	\N	PRESENT	0
594141	594132	14033T	PARTICIPANT	\N	PRESENT	0
594205	593321	14133K	PARTICIPANT	\N	PRESENT	0
594206	593321	20042V	PARTICIPANT	\N	PRESENT	0
594207	593321	14105F	PARTICIPANT	\N	PRESENT	0
594208	593321	14255U	PARTICIPANT	\N	PRESENT	0
594209	593321	04042C	PRESIDENT	0	PRESENT	0
594210	593321	12028B	PARTICIPANT	\N	PRESENT	0
594211	593321	14267Y	PARTICIPANT	\N	PRESENT	0
594212	593321	11115U	PARTICIPANT	\N	PRESENT	0
594213	593321	07033P	PARTICIPANT	\N	PRESENT	0
594214	593321	01024M	PARTICIPANT	\N	PRESENT	0
594215	593321	14249W	PARTICIPANT	\N	PRESENT	0
594216	593321	97011G	PARTICIPANT	\N	PRESENT	0
594217	593321	11083R	PARTICIPANT	\N	PRESENT	0
594218	593321	19347U	PARTICIPANT	\N	PRESENT	0
594219	593321	08056B	PARTICIPANT	\N	PRESENT	0
594220	593321	14211G	PARTICIPANT	\N	PRESENT	0
594221	593321	11064N	PARTICIPANT	\N	PRESENT	0
594222	593321	20072C	PARTICIPANT	\N	PRESENT	0
594223	593321	19329S	PARTICIPANT	\N	PRESENT	0
594224	593321	08069G	PARTICIPANT	\N	PRESENT	0
594225	593321	14097Y	PARTICIPANT	\N	PRESENT	0
594226	593321	12041X	PARTICIPANT	\N	PRESENT	0
594227	593321	19709B	PARTICIPANT	\N	PRESENT	0
594228	593321	16685X	PARTICIPANT	\N	PRESENT	0
594229	593321	14059S	PARTICIPANT	\N	PRESENT	0
594230	593321	08061X	PARTICIPANT	\N	PRESENT	0
594231	593321	08047A	PARTICIPANT	\N	PRESENT	0
594232	593321	14193X	PARTICIPANT	\N	PRESENT	0
594233	593321	19319Q	PARTICIPANT	\N	PRESENT	1
594234	593321	19443T	PARTICIPANT	\N	PRESENT	0
594235	593321	11054L	PARTICIPANT	\N	PRESENT	0
594236	593321	19421M	PARTICIPANT	\N	PRESENT	0
594237	593321	01058X	PARTICIPANT	\N	PRESENT	0
594238	593321	01062T	PARTICIPANT	\N	PRESENT	0
594239	593321	20064C	PARTICIPANT	\N	PRESENT	0
594240	593321	11041F	PARTICIPANT	\N	PRESENT	1
594241	593321	11066Q	PARTICIPANT	\N	PRESENT	0
594320	594313	19741B	PARTICIPANT	\N	PRESENT	0
594321	594313	05008E	PARTICIPANT	\N	PRESENT	0
594323	594313	20024T	PARTICIPANT	\N	PRESENT	0
594324	594313	14357A	PARTICIPANT	\N	PRESENT	0
594326	594313	14123H	PARTICIPANT	\N	PRESENT	0
594328	594313	08015R	PARTICIPANT	\N	PRESENT	0
594329	594313	08034U	PARTICIPANT	\N	PRESENT	0
594332	594313	20062A	PARTICIPANT	\N	PRESENT	0
594335	594313	14223L	PARTICIPANT	\N	PRESENT	0
594336	594313	14147R	PARTICIPANT	\N	PRESENT	0
594341	594313	97011G	PARTICIPANT	\N	PRESENT	0
594436	593444	20072C	PARTICIPANT	\N	PRESENT	0
594437	593444	01057W	PARTICIPANT	\N	PRESENT	0
594438	593444	11053K	PARTICIPANT	\N	PRESENT	0
594439	593444	20144B	PARTICIPANT	\N	PRESENT	0
594440	593444	14327T	PARTICIPANT	\N	PRESENT	0
594441	593444	14042U	PARTICIPANT	\N	PRESENT	0
594442	593444	11115U	PARTICIPANT	\N	PRESENT	0
594443	593444	14031R	PARTICIPANT	\N	PRESENT	0
594444	593444	20248J	PARTICIPANT	\N	PRESENT	0
594445	593444	01025N	PARTICIPANT	\N	PRESENT	0
594446	593444	19679N	PARTICIPANT	\N	PRESENT	0
594447	593444	14173T	PARTICIPANT	\N	PRESENT	0
594449	593444	14219Q	PARTICIPANT	\N	PRESENT	0
594450	593444	19441R	PARTICIPANT	\N	PRESENT	0
594451	593444	19735D	PARTICIPANT	\N	PRESENT	0
594452	593444	20096L	PARTICIPANT	\N	PRESENT	0
594453	593444	01043Q	PARTICIPANT	\N	PRESENT	0
594454	593444	19713W	PARTICIPANT	\N	PRESENT	0
594455	593444	19619A	PARTICIPANT	\N	PRESENT	0
594456	593444	20140W	PARTICIPANT	\N	PRESENT	0
594457	593444	19335Q	PARTICIPANT	\N	PRESENT	0
594458	593444	04045F	PARTICIPANT	\N	PRESENT	0
594460	593444	20172F	PARTICIPANT	\N	PRESENT	0
594461	593444	20066E	PARTICIPANT	\N	PRESENT	0
594462	593444	14147R	PARTICIPANT	\N	PRESENT	0
594463	593444	97011G	PARTICIPANT	\N	PRESENT	0
594464	593444	14069U	PARTICIPANT	\N	PRESENT	0
594465	593444	14217N	PARTICIPANT	\N	PRESENT	0
594466	593444	11056N	PARTICIPANT	\N	PRESENT	0
594467	593444	08061X	PARTICIPANT	\N	PRESENT	0
594468	593444	19553Y	PARTICIPANT	\N	PRESENT	0
594469	593444	19383Y	PARTICIPANT	\N	PRESENT	0
594470	593444	20042V	PARTICIPANT	\N	PRESENT	0
594471	593444	14329V	PARTICIPANT	\N	PRESENT	0
594472	593444	14213J	PARTICIPANT	\N	PRESENT	0
594473	593444	20104S	PARTICIPANT	\N	PRESENT	0
594474	593444	19399H	PARTICIPANT	\N	PRESENT	0
594475	593444	14033T	PARTICIPANT	\N	PRESENT	0
594476	593444	20056C	PARTICIPANT	\N	PRESENT	0
594477	593444	14231L	PARTICIPANT	\N	PRESENT	0
594478	593444	07029T	PARTICIPANT	\N	PRESENT	0
594479	593444	19741B	PARTICIPANT	\N	PRESENT	0
594480	593444	08015R	PARTICIPANT	\N	PRESENT	0
594481	593444	04059M	PARTICIPANT	\N	PRESENT	0
594482	593444	19768N	PARTICIPANT	\N	PRESENT	0
594483	593444	19705W	PARTICIPANT	\N	PRESENT	0
594484	593444	19707Y	PARTICIPANT	\N	PRESENT	0
594485	593444	20062A	PARTICIPANT	\N	PRESENT	0
594486	593444	20060X	PARTICIPANT	\N	PRESENT	0
594487	593444	20090E	PARTICIPANT	\N	PRESENT	0
594488	593444	20126Y	PARTICIPANT	\N	PRESENT	0
571332	571304	19637C	PARTICIPANT	\N	PRESENT	1
571333	571304	18083K	PARTICIPANT	\N	PRESENT	0
573441	571157	19413M	PARTICIPANT	\N	PRESENT	0
573442	571157	20134Y	PARTICIPANT	\N	PRESENT	0
573444	571157	20092G	PARTICIPANT	\N	PRESENT	0
573445	571157	19681G	PARTICIPANT	\N	PRESENT	0
573446	571157	19347U	PARTICIPANT	\N	PRESENT	0
573447	571157	99004R	PARTICIPANT	\N	PRESENT	0
573448	571157	19749K	PARTICIPANT	\N	PRESENT	0
573449	571157	20086J	PARTICIPANT	\N	PRESENT	0
573450	571157	19766L	PARTICIPANT	\N	PRESENT	0
573451	571157	14030Q	PARTICIPANT	\N	PRESENT	0
573452	571157	17637T	PARTICIPANT	\N	PRESENT	0
573989	573327	14217N	PARTICIPANT	\N	PRESENT	0
573992	573327	19533U	PARTICIPANT	\N	PRESENT	0
573993	573327	01058X	PARTICIPANT	\N	PRESENT	0
573994	573327	20044X	PARTICIPANT	\N	PRESENT	0
573997	573327	20102Q	PARTICIPANT	\N	PRESENT	0
573998	573327	14267Y	PARTICIPANT	\N	PRESENT	0
573999	572961	20088L	PARTICIPANT	\N	PRESENT	1
574000	572961	20104S	PARTICIPANT	\N	PRESENT	0
574001	572961	19705W	PARTICIPANT	\N	PRESENT	1
574003	573327	01057W	PARTICIPANT	\N	PRESENT	0
576800	576799	19711U	PARTICIPANT	\N	PRESENT	0
576802	576801	20022R	PARTICIPANT	\N	PRESENT	0
576803	576801	14331P	PARTICIPANT	\N	PRESENT	0
578130	578129	11048N	PARTICIPANT	\N	PRESENT	0
578365	578169	19667J	PARTICIPANT	\N	PRESENT	0
578366	577989	11053K	PARTICIPANT	\N	PRESENT	1
578367	577989	19647E	PARTICIPANT	\N	PRESENT	1
578368	577989	20126Y	PARTICIPANT	\N	PRESENT	1
578369	577989	19671E	PARTICIPANT	\N	PRESENT	1
578370	577989	20050V	PARTICIPANT	\N	PRESENT	1
578371	577989	20044X	PARTICIPANT	\N	PRESENT	1
578372	577989	19479G	PARTICIPANT	\N	PRESENT	1
578373	577989	14173T	PARTICIPANT	\N	PRESENT	1
578374	578169	11103C	PARTICIPANT	\N	PRESENT	0
578375	578169	20054A	PARTICIPANT	\N	PRESENT	0
578376	578169	20034V	PARTICIPANT	\N	PRESENT	0
578377	578169	19349W	PARTICIPANT	\N	PRESENT	0
578378	578169	20080C	PARTICIPANT	\N	PRESENT	0
578379	578169	19711U	PARTICIPANT	\N	PRESENT	0
578380	577989	14189C	PARTICIPANT	\N	EXCUSE	0
578381	578169	17589D	PARTICIPANT	\N	PRESENT	0
578382	578169	19687N	PARTICIPANT	\N	PRESENT	0
578383	578169	14111D	PARTICIPANT	\N	PRESENT	0
578384	578169	01057W	PARTICIPANT	\N	PRESENT	0
578385	578169	14225N	PARTICIPANT	\N	PRESENT	0
578386	578169	11040E	PARTICIPANT	\N	PRESENT	0
578387	578169	14327T	PARTICIPANT	\N	PRESENT	0
578406	578169	14231L	PARTICIPANT	\N	PRESENT	0
578389	578169	01048V	PARTICIPANT	\N	PRESENT	0
578390	578169	99004R	PARTICIPANT	\N	PRESENT	0
578391	578169	20038A	PARTICIPANT	\N	PRESENT	0
578392	578169	20022R	PARTICIPANT	\N	PRESENT	0
578393	578169	19762G	PARTICIPANT	\N	PRESENT	0
578394	578169	20172F	PARTICIPANT	\N	PRESENT	0
578395	578169	19689Q	PARTICIPANT	\N	PRESENT	0
578396	578169	20130U	PARTICIPANT	\N	PRESENT	0
578397	578169	14187A	PARTICIPANT	\N	PRESENT	0
578398	578169	14001X	PARTICIPANT	\N	PRESENT	0
578399	578169	20102Q	PARTICIPANT	\N	PRESENT	0
578400	578169	11012A	PARTICIPANT	\N	PRESENT	0
578401	578169	11097X	PARTICIPANT	\N	PRESENT	0
578402	578169	11065P	PARTICIPANT	\N	PRESENT	0
578403	578169	19503N	PARTICIPANT	\N	PRESENT	0
578404	578169	19741B	PARTICIPANT	\N	PRESENT	0
578405	578169	19691J	PARTICIPANT	\N	PRESENT	0
578407	578169	19631V	PARTICIPANT	\N	PRESENT	0
578408	578169	19577H	PARTICIPANT	\N	PRESENT	0
578410	577322	17737W	PARTICIPANT	\N	PRESENT	0
578411	577322	10015M	PARTICIPANT	\N	PRESENT	0
578412	577322	14259Y	PARTICIPANT	\N	PRESENT	0
578413	578169	19657G	PARTICIPANT	\N	PRESENT	0
578414	578169	08028W	PARTICIPANT	\N	PRESENT	0
578415	578169	19369B	PARTICIPANT	\N	PRESENT	0
578416	578169	20174H	PARTICIPANT	\N	PRESENT	0
578417	578169	07029T	PARTICIPANT	\N	PRESENT	0
578418	578169	19301E	PARTICIPANT	\N	PRESENT	0
578460	578168	20142Y	PARTICIPANT	\N	PRESENT	0
578461	578168	20110Q	PARTICIPANT	\N	PRESENT	0
578462	578168	20130U	PARTICIPANT	\N	PRESENT	0
578463	578168	19689Q	PARTICIPANT	\N	PRESENT	0
578464	578168	19301E	PARTICIPANT	\N	PRESENT	0
578465	578168	17589D	PARTICIPANT	\N	PRESENT	0
578466	578168	19369B	PARTICIPANT	\N	PRESENT	0
578467	578168	19563B	PARTICIPANT	\N	PRESENT	0
578468	578168	19691J	PARTICIPANT	\N	PRESENT	0
578469	578168	19577H	PARTICIPANT	\N	PRESENT	0
578470	578168	19631V	PARTICIPANT	\N	PRESENT	0
578471	578168	14001X	PARTICIPANT	\N	PRESENT	0
578472	578168	20080C	PARTICIPANT	\N	PRESENT	0
578473	578168	19349W	PARTICIPANT	\N	PRESENT	0
578474	578168	11012A	PARTICIPANT	\N	PRESENT	0
578475	578168	14111D	PARTICIPANT	\N	PRESENT	0
578476	578168	11072N	PARTICIPANT	\N	PRESENT	0
578477	578168	11097X	PARTICIPANT	\N	PRESENT	0
578478	578168	19711U	PARTICIPANT	\N	PRESENT	0
578479	578168	11048N	PARTICIPANT	\N	PRESENT	0
578480	578168	20022R	PARTICIPANT	\N	PRESENT	0
578481	578168	01048V	PARTICIPANT	\N	PRESENT	0
578482	578168	20174H	PARTICIPANT	\N	PRESENT	0
578483	578168	19515S	PARTICIPANT	\N	PRESENT	0
578484	578168	07029T	PARTICIPANT	\N	PRESENT	0
578485	578168	19762G	PARTICIPANT	\N	PRESENT	0
578486	578168	20054A	PARTICIPANT	\N	PRESENT	0
578487	578168	14187A	PARTICIPANT	\N	PRESENT	0
578488	578168	14259Y	PARTICIPANT	\N	PRESENT	0
578489	578168	99004R	PARTICIPANT	\N	PRESENT	0
578490	578168	19611R	PARTICIPANT	\N	PRESENT	0
578491	578168	14215L	PARTICIPANT	\N	PRESENT	0
578492	578168	12041X	PARTICIPANT	\N	PRESENT	0
578493	578168	20102Q	PARTICIPANT	\N	PRESENT	0
578494	578168	01043Q	PARTICIPANT	\N	PRESENT	0
578495	578168	19735D	PARTICIPANT	\N	PRESENT	0
578496	578168	05008E	PARTICIPANT	\N	PRESENT	0
578497	578168	19441R	PARTICIPANT	\N	PRESENT	0
578498	578168	19489J	PARTICIPANT	\N	PRESENT	0
578458	578168	14026U	PARTICIPANT	\N	PRESENT	0
578459	578168	19503N	PARTICIPANT	\N	PRESENT	0
578499	578168	95063L	PARTICIPANT	\N	PRESENT	0
578500	578168	10015M	PARTICIPANT	\N	PRESENT	0
578501	578168	11103C	PARTICIPANT	\N	PRESENT	0
578502	578168	19782L	PARTICIPANT	\N	PRESENT	0
578504	578168	19749K	PARTICIPANT	\N	PRESENT	0
578542	578168	19335Q	PARTICIPANT	\N	PRESENT	0
578510	578168	19719D	PARTICIPANT	\N	PRESENT	0
578511	578168	19657G	PARTICIPANT	\N	PRESENT	0
578512	578168	20034V	PARTICIPANT	\N	PRESENT	0
578513	578168	20036X	PARTICIPANT	\N	PRESENT	0
578514	578168	11056N	PARTICIPANT	\N	PRESENT	0
578515	578168	14151M	PARTICIPANT	\N	PRESENT	0
578516	578168	20038A	PARTICIPANT	\N	PRESENT	0
578517	578168	19621T	PARTICIPANT	\N	PRESENT	0
578518	578168	14231L	PARTICIPANT	\N	PRESENT	0
578519	578168	19747H	PARTICIPANT	\N	PRESENT	0
578521	578168	20132W	PARTICIPANT	\N	PRESENT	0
578522	578168	20108W	PARTICIPANT	\N	PRESENT	0
578523	578168	19447X	PARTICIPANT	\N	PRESENT	0
578524	578168	20090E	PARTICIPANT	\N	PRESENT	0
578525	578168	11085T	PARTICIPANT	\N	PRESENT	0
578526	578168	20092G	PARTICIPANT	\N	PRESENT	0
578528	578168	04092N	PARTICIPANT	\N	PRESENT	0
578529	578168	14071N	PARTICIPANT	\N	PRESENT	0
578530	578168	04047H	PARTICIPANT	\N	PRESENT	0
578531	578168	20128B	PARTICIPANT	\N	PRESENT	0
578532	578168	19387D	PARTICIPANT	\N	PRESENT	0
578533	578168	11067R	PARTICIPANT	\N	PRESENT	0
578534	578168	20098N	PARTICIPANT	\N	PRESENT	0
578535	578168	11065P	PARTICIPANT	\N	PRESENT	0
578536	578168	19533U	PARTICIPANT	\N	PRESENT	0
578537	578168	04035D	PARTICIPANT	\N	PRESENT	0
578538	578168	14189C	PARTICIPANT	\N	PRESENT	0
578539	578168	14327T	PARTICIPANT	\N	PRESENT	0
578540	578168	19715Y	PARTICIPANT	\N	PRESENT	0
578541	578168	17637T	PARTICIPANT	\N	PRESENT	0
580595	580594	19575F	PARTICIPANT	\N	PRESENT	0
580596	580594	18083K	PARTICIPANT	\N	PRESENT	0
580597	580594	20150Y	PARTICIPANT	\N	PRESENT	1
580619	579540	20172F	PARTICIPANT	\N	PRESENT	1
580625	579245	14223L	PARTICIPANT	\N	PRESENT	1
580626	579245	20130U	PARTICIPANT	\N	PRESENT	1
580627	579245	19569H	PARTICIPANT	\N	PRESENT	1
580628	579245	19301E	PARTICIPANT	\N	PRESENT	1
580629	579245	11097X	PARTICIPANT	\N	PRESENT	1
580630	579245	19715Y	PARTICIPANT	\N	PRESENT	1
580651	579245	19657G	PARTICIPANT	\N	PRESENT	1
580652	579245	11031D	PARTICIPANT	\N	PRESENT	0
580653	579245	19760E	PARTICIPANT	\N	PRESENT	0
580654	579245	19683J	PARTICIPANT	\N	PRESENT	0
580655	579245	19717B	PARTICIPANT	\N	PRESENT	0
580656	579245	17779H	PARTICIPANT	\N	PRESENT	0
580657	579245	11067R	PARTICIPANT	\N	PRESENT	0
580658	579245	18193Q	PARTICIPANT	\N	PRESENT	0
580659	579245	14042U	PARTICIPANT	\N	PRESENT	0
580660	579245	19691J	PARTICIPANT	\N	PRESENT	0
580661	579245	19703U	PARTICIPANT	\N	PRESENT	0
580662	579245	04092N	PARTICIPANT	\N	PRESENT	0
580663	579245	19713W	PARTICIPANT	\N	PRESENT	0
580664	579245	20248J	PARTICIPANT	\N	PRESENT	0
580674	579245	20148F	PARTICIPANT	\N	PRESENT	0
580666	579245	14071N	PARTICIPANT	\N	PRESENT	0
580667	579245	10006L	PRESIDENT	0	PRESENT	0
580668	579245	14217N	PARTICIPANT	\N	PRESENT	0
580669	579245	14213J	PARTICIPANT	\N	PRESENT	0
580670	579245	20090E	PARTICIPANT	\N	PRESENT	0
580671	579245	19798U	PARTICIPANT	\N	PRESENT	0
580672	579245	19415P	PARTICIPANT	\N	PRESENT	0
580673	579245	20040T	PARTICIPANT	\N	PRESENT	0
580679	579245	19723Y	PARTICIPANT	\N	PRESENT	0
580680	579245	04043D	PARTICIPANT	\N	PRESENT	0
580681	579245	20066E	PARTICIPANT	\N	PRESENT	0
580687	579245	19295A	PARTICIPANT	\N	EXCUSE	0
580688	579245	04057K	PARTICIPANT	\N	EXCUSE	0
582647	582645	14205J	PARTICIPANT	\N	PRESENT	0
582648	582645	04045F	PARTICIPANT	\N	PRESENT	0
582649	582645	19563B	PARTICIPANT	\N	PRESENT	0
582650	582645	14033T	PARTICIPANT	\N	PRESENT	0
582651	582645	20062A	PARTICIPANT	\N	PRESENT	0
582652	582645	19441R	PARTICIPANT	\N	PRESENT	0
582653	582645	19413M	PARTICIPANT	\N	PRESENT	0
582654	582645	19768N	PARTICIPANT	\N	PRESENT	0
582655	582645	14207L	PARTICIPANT	\N	PRESENT	0
582656	582645	19467C	PARTICIPANT	\N	PRESENT	0
582657	582645	20060X	PARTICIPANT	\N	PRESENT	0
582658	582646	14205J	PARTICIPANT	\N	PRESENT	0
582659	582646	19467C	PARTICIPANT	\N	PRESENT	0
582660	582646	19413M	PARTICIPANT	\N	PRESENT	0
582661	582646	14033T	PARTICIPANT	\N	PRESENT	0
582662	582646	19441R	PARTICIPANT	\N	PRESENT	0
582663	582646	20062A	PARTICIPANT	\N	PRESENT	0
582664	582646	14207L	PARTICIPANT	\N	PRESENT	0
582665	582646	20060X	PARTICIPANT	\N	PRESENT	0
582666	582646	20034V	PARTICIPANT	\N	PRESENT	0
584450	583454	20094J	PARTICIPANT	\N	PRESENT	0
584451	583454	11099A	PARTICIPANT	\N	PRESENT	0
584455	583454	20088L	PARTICIPANT	\N	PRESENT	0
584456	583454	14205J	PARTICIPANT	\N	PRESENT	1
584484	584483	14215L	PARTICIPANT	\N	PRESENT	0
589402	588525	20022R	PARTICIPANT	\N	PRESENT	0
589404	588525	01057W	PARTICIPANT	\N	PRESENT	0
589407	588525	99004R	PARTICIPANT	\N	PRESENT	0
589408	588234	19954N	PARTICIPANT	\N	PRESENT	0
589409	588234	14069U	PARTICIPANT	\N	PRESENT	0
589410	588525	20050V	PARTICIPANT	\N	PRESENT	0
589411	588525	11074Q	PARTICIPANT	\N	PRESENT	0
589412	588527	20130U	PARTICIPANT	\N	PRESENT	1
589413	588527	19713W	PARTICIPANT	\N	PRESENT	1
589414	588527	04043D	PARTICIPANT	\N	PRESENT	1
589420	588525	14331P	PARTICIPANT	\N	PRESENT	0
589421	588525	19531S	PARTICIPANT	\N	PRESENT	0
589422	588525	08010L	PARTICIPANT	\N	PRESENT	0
589423	588525	19335Q	PARTICIPANT	\N	PRESENT	0
589441	588525	14189C	PARTICIPANT	\N	PRESENT	0
589442	588525	19689Q	PARTICIPANT	\N	PRESENT	0
589445	588525	14083S	PARTICIPANT	\N	PRESENT	0
589447	588525	19349W	PARTICIPANT	\N	PRESENT	0
589451	588525	19687N	PARTICIPANT	\N	PRESENT	0
589452	588525	19762G	PARTICIPANT	\N	PRESENT	0
589456	588525	07029T	PARTICIPANT	\N	PRESENT	0
589463	588525	20070A	PARTICIPANT	\N	PRESENT	0
589484	588525	19671E	PARTICIPANT	\N	EXCUSE	0
589511	588525	19545Y	PARTICIPANT	\N	PRESENT	0
589533	588525	11053K	PARTICIPANT	\N	PRESENT	0
589539	586713	20032T	PARTICIPANT	\N	PRESENT	0
589540	586713	20136B	PARTICIPANT	\N	PRESENT	0
589541	586713	19549D	PARTICIPANT	\N	PRESENT	0
589542	586713	19251M	PARTICIPANT	\N	PRESENT	0
589543	586713	19820Y	PARTICIPANT	\N	PRESENT	0
589544	586713	14219Q	PRESIDENT	0	PRESENT	0
589545	586713	19826F	PARTICIPANT	\N	PRESENT	0
589546	586713	14221J	PARTICIPANT	\N	PRESENT	0
589547	586713	20046A	PARTICIPANT	\N	PRESENT	0
589548	586713	19599P	PARTICIPANT	\N	PRESENT	0
589549	586713	20102Q	PARTICIPANT	\N	PRESENT	0
589550	586713	17229F	PARTICIPANT	\N	PRESENT	0
589551	586713	18083K	PARTICIPANT	\N	PRESENT	0
589552	586713	08060W	PARTICIPANT	\N	PRESENT	0
589553	586713	19503N	PARTICIPANT	\N	PRESENT	0
589554	586713	20020P	PARTICIPANT	\N	PRESENT	0
589555	586713	19745F	PARTICIPANT	\N	PRESENT	0
589556	586713	11065P	PARTICIPANT	\N	PRESENT	0
589561	586713	17367Q	PARTICIPANT	\N	PRESENT	0
589562	586713	19619A	PARTICIPANT	\N	PRESENT	0
589563	586713	19387D	PARTICIPANT	\N	PRESENT	0
589564	586713	20076G	PARTICIPANT	\N	PRESENT	0
589565	586713	20140W	PARTICIPANT	\N	PRESENT	0
589566	586713	19681G	PARTICIPANT	\N	PRESENT	0
589567	586713	20024T	PARTICIPANT	\N	PRESENT	0
589568	586713	20106U	PARTICIPANT	\N	PRESENT	0
589569	586713	19525U	PARTICIPANT	\N	PRESENT	0
589570	586713	05012A	PARTICIPANT	\N	PRESENT	0
589571	586713	20118Y	PARTICIPANT	\N	PRESENT	0
589572	586713	20038A	PARTICIPANT	\N	PRESENT	0
589573	586713	20068G	PARTICIPANT	\N	PRESENT	0
589574	586713	19333N	PARTICIPANT	\N	PRESENT	0
589575	586713	19701S	PARTICIPANT	\N	PRESENT	0
589576	586713	14001X	PARTICIPANT	\N	PRESENT	0
589577	586713	19739H	PARTICIPANT	\N	PRESENT	0
589580	588234	11056N	PARTICIPANT	\N	PRESENT	0
589585	588525	19679N	PARTICIPANT	\N	PRESENT	0
589597	586713	20042V	PARTICIPANT	\N	PRESENT	0
589598	587935	19383Y	PARTICIPANT	\N	PRESENT	0
589599	587935	20088L	PARTICIPANT	\N	PRESENT	1
589600	587935	19768N	PARTICIPANT	\N	PRESENT	1
589601	587935	19515S	PARTICIPANT	\N	PRESENT	0
589602	587935	20092G	PARTICIPANT	\N	PRESENT	0
589603	587935	19782L	PARTICIPANT	\N	PRESENT	0
589604	587935	01043Q	PARTICIPANT	\N	PRESENT	0
589605	587935	14357A	PARTICIPANT	\N	PRESENT	0
589606	587935	19441R	PARTICIPANT	\N	PRESENT	0
589607	587935	20078J	PARTICIPANT	\N	PRESENT	1
589608	587935	20094J	PARTICIPANT	\N	PRESENT	0
589609	587935	04045F	PARTICIPANT	\N	PRESENT	0
589610	587935	20104S	PARTICIPANT	\N	PRESENT	0
589611	587935	19631V	PARTICIPANT	\N	PRESENT	0
589612	587935	19705W	PARTICIPANT	\N	PRESENT	0
589613	587935	08015R	PARTICIPANT	\N	PRESENT	1
589614	587935	19575F	PARTICIPANT	\N	PRESENT	0
589615	587935	19369B	PARTICIPANT	\N	PRESENT	0
589616	587935	20018V	PARTICIPANT	\N	PRESENT	0
589617	587935	19511N	PARTICIPANT	\N	PRESENT	0
589618	587935	08028W	PARTICIPANT	\N	PRESENT	0
589619	587935	19563B	PARTICIPANT	\N	PRESENT	0
589620	587935	14329V	PARTICIPANT	\N	PRESENT	0
589621	587935	20028X	PARTICIPANT	\N	PRESENT	0
589622	587935	20030R	PARTICIPANT	\N	PRESENT	1
589623	587935	19467C	PARTICIPANT	\N	PRESENT	0
589624	587935	20034V	PARTICIPANT	\N	PRESENT	0
589625	587935	14187A	PARTICIPANT	\N	PRESENT	0
589626	587935	19695N	PARTICIPANT	\N	PRESENT	0
589627	587935	14033T	PARTICIPANT	\N	PRESENT	0
589628	587935	11090Q	PRESIDENT	0	PRESENT	0
589629	587935	01025N	PARTICIPANT	\N	PRESENT	0
589630	587935	14205J	PARTICIPANT	\N	PRESENT	0
589631	587935	20060X	PARTICIPANT	\N	PRESENT	1
589632	587935	20062A	PARTICIPANT	\N	PRESENT	0
579721	579388	19573D	PARTICIPANT	\N	PRESENT	0
579722	579388	19713W	PARTICIPANT	\N	PRESENT	0
579723	579388	19725B	PARTICIPANT	\N	PRESENT	0
579724	579388	19301E	PARTICIPANT	\N	PRESENT	0
579725	579388	14033T	PARTICIPANT	\N	PRESENT	0
579726	579388	19621T	PARTICIPANT	\N	PRESENT	0
582006	582005	14225N	PARTICIPANT	\N	PRESENT	0
582007	582005	11048N	PARTICIPANT	\N	PRESENT	0
581666	581665	05008E	PARTICIPANT	\N	PRESENT	0
581667	581665	11033F	PARTICIPANT	\N	PRESENT	0
581668	581665	20114U	PARTICIPANT	\N	PRESENT	0
581669	581665	14179A	PARTICIPANT	\N	PRESENT	0
581670	581665	19649G	PARTICIPANT	\N	PRESENT	0
581671	581665	11026G	PARTICIPANT	\N	PRESENT	0
581672	581665	14217N	PARTICIPANT	\N	PRESENT	0
581729	579137	20074E	PARTICIPANT	\N	EXCUSE	0
582009	582008	14225N	PARTICIPANT	\N	PRESENT	1
582010	582008	11048N	PARTICIPANT	\N	PRESENT	1
582012	582011	20050V	PARTICIPANT	\N	PRESENT	0
582014	582013	11053K	PARTICIPANT	\N	PRESENT	0
585697	585696	14215L	PARTICIPANT	\N	PRESENT	0
585829	585826	11040E	PARTICIPANT	\N	PRESENT	0
585830	585826	19479G	PARTICIPANT	\N	PRESENT	0
585835	585825	11040E	PARTICIPANT	\N	PRESENT	0
585836	585825	19479G	PARTICIPANT	\N	PRESENT	0
586348	585577	11033F	PARTICIPANT	\N	PRESENT	1
586349	585577	20128B	PARTICIPANT	\N	PRESENT	1
586350	585577	14179A	PARTICIPANT	\N	PRESENT	1
586351	585577	14147R	PARTICIPANT	\N	PRESENT	1
586352	585577	14107H	PARTICIPANT	\N	PRESENT	1
586353	585577	19675J	PARTICIPANT	\N	PRESENT	1
586354	585577	19729F	PARTICIPANT	\N	EXCUSE	0
586358	582765	14111D	PARTICIPANT	\N	PRESENT	0
588611	588610	14179A	PARTICIPANT	\N	PRESENT	0
589732	588525	11110B	PARTICIPANT	\N	PRESENT	1
589733	588525	19647E	PARTICIPANT	\N	PRESENT	1
589734	588525	12016W	PARTICIPANT	\N	PRESENT	1
589735	588525	11012A	PARTICIPANT	\N	PRESENT	1
589736	588525	19479G	PARTICIPANT	\N	PRESENT	1
589737	588525	20036X	PARTICIPANT	\N	EXCUSE	0
589739	588562	14189C	PARTICIPANT	\N	PRESENT	0
589740	588562	20024T	PARTICIPANT	\N	PRESENT	0
589741	588562	19575F	PARTICIPANT	\N	PRESENT	0
589742	588562	14069U	PARTICIPANT	\N	PRESENT	0
589743	588562	20042V	PARTICIPANT	\N	PRESENT	0
589744	588562	20090E	PARTICIPANT	\N	PRESENT	0
589745	588562	14083S	PARTICIPANT	\N	PRESENT	0
589746	588562	11053K	PARTICIPANT	\N	PRESENT	0
589747	588562	19681G	PARTICIPANT	\N	PRESENT	0
589748	588562	17229F	PARTICIPANT	\N	PRESENT	0
589749	588562	11048N	PARTICIPANT	\N	PRESENT	0
589750	588562	19611R	PARTICIPANT	\N	PRESENT	0
589751	588562	20052X	PARTICIPANT	\N	PRESENT	0
589752	588562	19745F	PARTICIPANT	\N	PRESENT	0
589753	588562	19739H	PARTICIPANT	\N	PRESENT	0
589754	588562	19735D	PARTICIPANT	\N	PRESENT	0
589755	588562	19349W	PARTICIPANT	\N	PRESENT	0
589757	589756	99004R	PARTICIPANT	\N	PRESENT	0
589759	589758	99004R	PARTICIPANT	\N	PRESENT	0
589761	589760	99004R	PARTICIPANT	\N	PRESENT	0
589763	589762	19349W	PARTICIPANT	\N	PRESENT	0
589765	589764	11074Q	PARTICIPANT	\N	PRESENT	0
589766	589764	19349W	PARTICIPANT	\N	PRESENT	0
589768	589767	19711U	PARTICIPANT	\N	PRESENT	0
589770	589769	19711U	PARTICIPANT	\N	PRESENT	1
589772	589771	19711U	PARTICIPANT	\N	PRESENT	1
590378	590377	19447X	PARTICIPANT	\N	PRESENT	0
590379	590377	14179A	PARTICIPANT	\N	PRESENT	0
590382	590381	19447X	PARTICIPANT	\N	PRESENT	0
590385	583206	20098N	PARTICIPANT	\N	PRESENT	1
590386	583206	20106U	PARTICIPANT	\N	PRESENT	1
590387	583206	14030Q	PRESIDENT	0	PRESENT	0
590388	583206	11031D	PARTICIPANT	\N	PRESENT	0
590389	583206	19599P	PARTICIPANT	\N	PRESENT	0
590390	583206	19749K	PARTICIPANT	\N	PRESENT	0
590391	583206	14189C	PARTICIPANT	\N	PRESENT	0
590398	583206	14109K	PARTICIPANT	\N	PRESENT	0
590429	583206	20046A	PARTICIPANT	\N	PRESENT	1
590435	583206	20140W	PARTICIPANT	\N	PRESENT	0
590436	583206	20114U	PARTICIPANT	\N	PRESENT	0
590449	583206	14179A	PARTICIPANT	\N	PRESENT	1
590455	583607	14030Q	PRESIDENT	0	PRESENT	0
590456	583607	19599P	PARTICIPANT	\N	PRESENT	0
590457	583607	19749K	PARTICIPANT	\N	PRESENT	0
590458	583607	14221J	PARTICIPANT	\N	PRESENT	0
590459	583607	20080C	PARTICIPANT	\N	EXCUSE	0
590460	583607	19621T	PARTICIPANT	\N	EXCUSE	0
590461	583607	19715Y	PARTICIPANT	\N	EXCUSE	0
590462	583607	14109K	PARTICIPANT	\N	EXCUSE	0
590463	583607	19866P	PARTICIPANT	\N	EXCUSE	0
590464	583607	20130U	PARTICIPANT	\N	EXCUSE	0
590465	583607	20046A	PARTICIPANT	\N	EXCUSE	0
590466	583206	20080C	PARTICIPANT	\N	EXCUSE	0
590467	583206	19866P	PARTICIPANT	\N	EXCUSE	0
590468	583607	17737W	PARTICIPANT	\N	PRESENT	1
590469	583607	20106U	PARTICIPANT	\N	PRESENT	1
590470	583607	20114U	PARTICIPANT	\N	PRESENT	1
590471	583607	20066E	PARTICIPANT	\N	PRESENT	0
590472	583607	07029T	PARTICIPANT	\N	PRESENT	0
590473	583607	19693L	PARTICIPANT	\N	PRESENT	0
590475	583607	11031D	PARTICIPANT	\N	PRESENT	0
590476	583607	20024T	PARTICIPANT	\N	PRESENT	0
590620	590603	20050V	PARTICIPANT	\N	EXCUSE	0
590621	590603	11065P	PARTICIPANT	\N	EXCUSE	0
590622	590603	01028R	PARTICIPANT	\N	EXCUSE	0
590623	590603	20144B	PARTICIPANT	\N	EXCUSE	0
590624	590603	99004R	PARTICIPANT	\N	EXCUSE	0
590625	590603	11097X	PARTICIPANT	\N	EXCUSE	0
590627	590603	04070G	PARTICIPANT	\N	EXCUSE	0
590628	590603	20132W	PARTICIPANT	\N	PRESENT	0
590700	590351	11010L	PARTICIPANT	\N	PRESENT	0
590702	590351	19715Y	PARTICIPANT	\N	PRESENT	0
590706	590351	19631V	PARTICIPANT	\N	PRESENT	0
590738	590737	20090E	PARTICIPANT	\N	PRESENT	0
590739	590737	20106U	PARTICIPANT	\N	PRESENT	0
590740	590737	14097Y	PARTICIPANT	\N	PRESENT	0
590741	590737	11067R	PARTICIPANT	\N	PRESENT	0
590742	590737	20018V	PARTICIPANT	\N	PRESENT	0
590743	590737	14030Q	PARTICIPANT	\N	PRESENT	0
590744	590737	19749K	PARTICIPANT	\N	PRESENT	0
590820	590819	16685X	PARTICIPANT	\N	PRESENT	0
590841	590840	04035D	PARTICIPANT	\N	PRESENT	0
590843	590842	04035D	PARTICIPANT	\N	PRESENT	0
590865	590864	08034U	PARTICIPANT	\N	PRESENT	0
590867	590866	08034U	PARTICIPANT	\N	PRESENT	0
590877	590873	08060W	PARTICIPANT	\N	PRESENT	0
590878	590873	19826F	PARTICIPANT	\N	PRESENT	0
590879	590874	08060W	PARTICIPANT	\N	PRESENT	0
590884	590875	08060W	PARTICIPANT	\N	PRESENT	0
590881	590874	19826F	PARTICIPANT	\N	PRESENT	0
590883	590882	19711U	PARTICIPANT	\N	PRESENT	1
590885	590875	19826F	PARTICIPANT	\N	PRESENT	0
590886	590876	19826F	PARTICIPANT	\N	PRESENT	0
590888	590887	20054A	PARTICIPANT	\N	PRESENT	0
590889	590887	14207L	PARTICIPANT	\N	PRESENT	0
590891	590890	14121F	PARTICIPANT	\N	PRESENT	0
590893	590892	14121F	PARTICIPANT	\N	PRESENT	0
590895	590894	19515S	PARTICIPANT	\N	PRESENT	0
590897	590896	20094J	PARTICIPANT	\N	PRESENT	0
590898	590896	19515S	PARTICIPANT	\N	PRESENT	0
590899	590896	14207L	PARTICIPANT	\N	PRESENT	0
590901	590900	19515S	PARTICIPANT	\N	PRESENT	0
590903	590902	19782L	PARTICIPANT	\N	PRESENT	0
590904	590902	19515S	PARTICIPANT	\N	PRESENT	0
590906	590905	19515S	PARTICIPANT	\N	PRESENT	0
590908	590907	19515S	PARTICIPANT	\N	PRESENT	0
590910	590909	08028W	PARTICIPANT	\N	PRESENT	0
590911	590909	20018V	PARTICIPANT	\N	PRESENT	0
590912	588548	20066E	PARTICIPANT	\N	PRESENT	0
590915	589593	20172F	PARTICIPANT	\N	PRESENT	1
590933	590932	19711U	PARTICIPANT	\N	PRESENT	1
590935	590934	19711U	PARTICIPANT	\N	PRESENT	1
590936	590913	11012A	PARTICIPANT	\N	PRESENT	0
590937	590913	14237S	PARTICIPANT	\N	PRESENT	0
590939	590913	14193X	PARTICIPANT	\N	PRESENT	0
590940	590913	20054A	PARTICIPANT	\N	PRESENT	0
591692	591691	19569H	PARTICIPANT	\N	PRESENT	0
591693	591691	11067R	PARTICIPANT	\N	PRESENT	0
591695	590394	19683J	PARTICIPANT	\N	PRESENT	0
591696	590394	11031D	PARTICIPANT	\N	PRESENT	0
591697	590394	14281W	PARTICIPANT	\N	PRESENT	0
591698	590394	04057K	PARTICIPANT	\N	PRESENT	0
591700	590394	01034P	PARTICIPANT	\N	PRESENT	0
591702	590394	19569H	PARTICIPANT	\N	PRESENT	0
591709	590394	17965H	PARTICIPANT	\N	PRESENT	0
592082	590838	20042V	PARTICIPANT	\N	PRESENT	0
592083	590838	14105F	PARTICIPANT	\N	PRESENT	0
592084	590838	14255U	PARTICIPANT	\N	PRESENT	0
592085	590838	04042C	PRESIDENT	0	PRESENT	0
592086	590838	14267Y	PARTICIPANT	\N	PRESENT	0
592087	590838	11027H	PARTICIPANT	\N	PRESENT	0
592088	590838	01024M	PARTICIPANT	\N	PRESENT	0
592089	590838	14249W	PARTICIPANT	\N	PRESENT	0
592090	590838	97011G	PARTICIPANT	\N	PRESENT	0
592091	590838	04035D	PARTICIPANT	\N	PRESENT	1
592092	590838	11083R	PARTICIPANT	\N	PRESENT	0
592094	590838	19347U	PARTICIPANT	\N	PRESENT	0
592095	590838	14211G	PARTICIPANT	\N	PRESENT	0
592096	590838	19565D	PARTICIPANT	\N	PRESENT	0
592097	590838	11064N	PARTICIPANT	\N	PRESENT	0
592098	590838	14097Y	PARTICIPANT	\N	PRESENT	0
592099	590838	12041X	PARTICIPANT	\N	PRESENT	0
592100	590838	16685X	PARTICIPANT	\N	PRESENT	0
592101	590838	08061X	PARTICIPANT	\N	PRESENT	0
592102	590838	08047A	PARTICIPANT	\N	PRESENT	0
592103	590838	14193X	PARTICIPANT	\N	PRESENT	0
592104	590838	19443T	PARTICIPANT	\N	PRESENT	0
592105	590838	11054L	PARTICIPANT	\N	PRESENT	0
592106	590838	19421M	PARTICIPANT	\N	PRESENT	0
592107	590838	01058X	PARTICIPANT	\N	PRESENT	0
592108	590838	19669L	PARTICIPANT	\N	PRESENT	0
592109	590838	01062T	PARTICIPANT	\N	PRESENT	0
592110	590838	11041F	PARTICIPANT	\N	PRESENT	1
592111	590838	11066Q	PARTICIPANT	\N	PRESENT	0
592113	590838	19329S	PARTICIPANT	\N	PRESENT	1
592123	590839	08047A	PARTICIPANT	\N	PRESENT	0
594538	591742	11103C	PARTICIPANT	\N	PRESENT	1
594539	591742	17779H	PARTICIPANT	\N	PRESENT	1
594541	591742	19717B	PARTICIPANT	\N	PRESENT	1
594542	591742	17965H	PARTICIPANT	\N	PRESENT	1
594825	594313	14215L	PARTICIPANT	\N	PRESENT	0
594862	592950	19954N	PARTICIPANT	\N	PRESENT	0
594863	592950	11033F	PARTICIPANT	\N	PRESENT	0
594864	592950	04047H	PRESIDENT	0	PRESENT	0
594865	592950	14001X	PARTICIPANT	\N	PRESENT	0
594866	592950	11072N	PARTICIPANT	\N	PRESENT	0
594867	592950	19489J	PARTICIPANT	\N	PRESENT	1
594868	592950	14107H	PARTICIPANT	\N	PRESENT	1
594918	593436	19691J	PARTICIPANT	\N	EXCUSE	0
594979	594978	14033T	PARTICIPANT	\N	PRESENT	0
594980	594978	19721W	PARTICIPANT	\N	PRESENT	0
594981	594978	19413M	PARTICIPANT	\N	PRESENT	0
594982	594978	14257W	PARTICIPANT	\N	PRESENT	0
594983	594978	11065P	PARTICIPANT	\N	PRESENT	0
594984	594978	20092G	PARTICIPANT	\N	PRESENT	0
594985	594978	20144B	PARTICIPANT	\N	PRESENT	0
594986	594978	19333N	PARTICIPANT	\N	PRESENT	0
594987	594978	19551W	PARTICIPANT	\N	PRESENT	0
594988	594978	19711U	PARTICIPANT	\N	PRESENT	0
594989	594978	20126Y	PARTICIPANT	\N	PRESENT	0
594990	594978	19619A	PARTICIPANT	\N	PRESENT	0
594991	594978	19575F	PARTICIPANT	\N	PRESENT	0
594992	594978	20174H	PARTICIPANT	\N	PRESENT	0
594993	594978	20094J	PARTICIPANT	\N	PRESENT	0
594994	594978	20038A	PARTICIPANT	\N	PRESENT	0
594995	594978	19533U	PARTICIPANT	\N	PRESENT	0
594996	594978	19820Y	PARTICIPANT	\N	PRESENT	0
595661	595659	19545Y	PARTICIPANT	\N	PRESENT	0
595663	595662	19667J	PARTICIPANT	\N	PRESENT	0
595664	595662	11040E	PARTICIPANT	\N	PRESENT	0
595666	595665	19545Y	PARTICIPANT	\N	PRESENT	0
595667	595665	19689Q	PARTICIPANT	\N	PRESENT	0
595669	595668	04071H	PARTICIPANT	\N	PRESENT	0
595671	595670	04071H	PARTICIPANT	\N	PRESENT	0
595673	595672	08034U	PARTICIPANT	\N	PRESENT	0
595675	595674	11048N	PARTICIPANT	\N	PRESENT	0
595677	595676	14083S	PARTICIPANT	\N	PRESENT	0
595678	595676	11012A	PARTICIPANT	\N	PRESENT	0
595680	595679	11070L	PARTICIPANT	\N	PRESENT	0
595681	595679	19647E	PARTICIPANT	\N	PRESENT	0
595683	595682	11048N	PARTICIPANT	\N	PRESENT	0
595685	595684	11070L	PARTICIPANT	\N	PRESENT	0
595686	595684	19647E	PARTICIPANT	\N	PRESENT	0
595706	595705	01025N	PARTICIPANT	\N	PRESENT	0
595707	595705	14207L	PARTICIPANT	\N	PRESENT	0
595708	595705	20028X	PARTICIPANT	\N	PRESENT	0
595709	595705	19507S	PARTICIPANT	\N	PRESENT	0
595710	595705	19563B	PARTICIPANT	\N	PRESENT	0
595712	595711	05008E	PARTICIPANT	\N	PRESENT	0
595713	595711	11053K	PARTICIPANT	\N	PRESENT	0
595714	595711	01028R	PARTICIPANT	\N	PRESENT	0
595719	595718	99004R	PARTICIPANT	\N	PRESENT	0
595720	595718	11031D	PARTICIPANT	\N	PRESENT	0
595726	595725	19593H	PARTICIPANT	\N	PRESENT	0
595727	595725	19693L	PARTICIPANT	\N	PRESENT	0
595799	595798	19399H	PARTICIPANT	\N	PRESENT	1
595800	595798	19611R	PARTICIPANT	\N	PRESENT	1
595801	595798	20084G	PARTICIPANT	\N	PRESENT	1
595802	595798	04070G	PARTICIPANT	\N	PRESENT	1
595803	595798	20142Y	PARTICIPANT	\N	PRESENT	1
595804	595798	20056C	PARTICIPANT	\N	PRESENT	1
595935	594908	20130U	PARTICIPANT	\N	PRESENT	0
595936	594908	19713W	PARTICIPANT	\N	PRESENT	1
595937	594908	08045X	PARTICIPANT	\N	PRESENT	1
595938	594908	19691J	PARTICIPANT	\N	PRESENT	1
595939	594908	19553Y	PARTICIPANT	\N	PRESENT	1
595940	594908	11103C	PARTICIPANT	\N	PRESENT	0
595941	594908	19657G	PARTICIPANT	\N	PRESENT	0
595942	595600	01024M	PARTICIPANT	\N	PRESENT	0
595943	595348	19545Y	PARTICIPANT	\N	PRESENT	0
595944	595600	20122U	PARTICIPANT	\N	PRESENT	0
595945	595600	08045X	PARTICIPANT	\N	PRESENT	0
595946	595600	11067R	PARTICIPANT	\N	PRESENT	0
595947	595600	01058X	PARTICIPANT	\N	PRESENT	0
595948	595600	11103C	PARTICIPANT	\N	PRESENT	0
595949	595600	20072C	PARTICIPANT	\N	PRESENT	0
595950	595600	20062A	PARTICIPANT	\N	PRESENT	0
595951	595600	19747H	PARTICIPANT	\N	PRESENT	0
595952	595600	19515S	PARTICIPANT	\N	PRESENT	0
595953	594919	19768N	PARTICIPANT	\N	PRESENT	0
595954	594919	19515S	PARTICIPANT	\N	PRESENT	0
595955	594919	19782L	PARTICIPANT	\N	PRESENT	0
595956	594919	20092G	PARTICIPANT	\N	PRESENT	0
595957	594919	20078J	PARTICIPANT	\N	PRESENT	0
595958	594919	19441R	PARTICIPANT	\N	PRESENT	0
595959	594919	20094J	PARTICIPANT	\N	PRESENT	0
595960	594919	04045F	PARTICIPANT	\N	PRESENT	0
595961	594919	20104S	PARTICIPANT	\N	PRESENT	0
595962	594919	19631V	PARTICIPANT	\N	PRESENT	1
595963	594919	19705W	PARTICIPANT	\N	PRESENT	0
595964	594919	19707Y	PARTICIPANT	\N	PRESENT	0
595965	594919	08015R	PARTICIPANT	\N	PRESENT	0
595966	594919	19511N	PARTICIPANT	\N	PRESENT	0
595967	594919	20030R	PARTICIPANT	\N	PRESENT	1
595968	594919	19467C	PARTICIPANT	\N	PRESENT	0
595969	594919	20034V	PARTICIPANT	\N	PRESENT	0
595970	594919	14187A	PRESIDENT	0	PRESENT	0
595971	594919	01025N	PARTICIPANT	\N	PRESENT	0
595972	594919	14033T	PARTICIPANT	\N	PRESENT	0
595973	594919	20054A	PARTICIPANT	\N	PRESENT	0
595974	594919	20174H	PARTICIPANT	\N	PRESENT	1
595975	594919	20062A	PARTICIPANT	\N	PRESENT	0
595976	594919	14251Q	PARTICIPANT	\N	PRESENT	0
595977	594919	19747H	PARTICIPANT	\N	PRESENT	0
595978	595600	14033T	PARTICIPANT	\N	PRESENT	0
595979	595600	14105F	PARTICIPANT	\N	PRESENT	0
595980	595600	14071N	PARTICIPANT	\N	PRESENT	0
595981	595600	19367Y	PARTICIPANT	\N	PRESENT	0
595982	595600	19467C	PARTICIPANT	\N	PRESENT	0
595983	595600	20034V	PARTICIPANT	\N	PRESENT	0
595984	595348	19762G	PARTICIPANT	\N	PRESENT	0
595985	595600	19251M	PARTICIPANT	\N	PRESENT	0
595986	595600	17779H	PARTICIPANT	\N	PRESENT	0
595987	595348	14331P	PARTICIPANT	\N	PRESENT	0
595988	595600	20078J	PARTICIPANT	\N	PRESENT	0
595989	595600	14069U	PARTICIPANT	\N	PRESENT	0
595990	595348	20044X	PARTICIPANT	\N	PRESENT	0
571336	571335	14133K	PARTICIPANT	\N	PRESENT	0
571337	571335	04085P	PARTICIPANT	\N	PRESENT	0
571338	571335	04059M	PARTICIPANT	\N	PRESENT	0
571339	571335	11033F	PARTICIPANT	\N	PRESENT	0
571340	571335	11053K	PARTICIPANT	\N	PRESENT	0
571341	571335	14038Y	PARTICIPANT	\N	PRESENT	0
571342	571335	19719D	PARTICIPANT	\N	PRESENT	0
571343	571335	10006L	PARTICIPANT	\N	PRESENT	0
571344	571335	08018U	PARTICIPANT	\N	PRESENT	0
571345	571335	14026U	PARTICIPANT	\N	PRESENT	0
571346	571335	99004R	PARTICIPANT	\N	PRESENT	0
571347	571335	19611R	PARTICIPANT	\N	PRESENT	0
571348	571335	12041X	PARTICIPANT	\N	PRESENT	0
571349	571335	01043Q	PARTICIPANT	\N	PRESENT	0
571350	571335	14219Q	PARTICIPANT	\N	PRESENT	0
571351	571335	04057K	PARTICIPANT	\N	PRESENT	0
571352	571335	08061X	PARTICIPANT	\N	PRESENT	0
571353	571335	14331P	PARTICIPANT	\N	PRESENT	0
571354	571335	14225N	PARTICIPANT	\N	PRESENT	0
571355	571335	04033B	PARTICIPANT	\N	PRESENT	0
571356	571335	11045K	PARTICIPANT	\N	PRESENT	0
571357	571335	01034P	PARTICIPANT	\N	PRESENT	0
571747	571299	11056N	PARTICIPANT	\N	PRESENT	0
571742	571299	20108W	PARTICIPANT	\N	PRESENT	0
571743	571299	04047H	PRESIDENT	0	PRESENT	0
571744	571299	14259Y	PARTICIPANT	\N	PRESENT	0
571745	571299	19673G	PARTICIPANT	\N	PRESENT	0
571746	571299	19581D	PARTICIPANT	\N	PRESENT	0
571748	571299	19954N	PARTICIPANT	\N	PRESENT	0
571749	571299	19649G	PARTICIPANT	\N	PRESENT	0
571750	571299	05008E	PARTICIPANT	\N	PRESENT	0
571751	571299	19725B	PARTICIPANT	\N	PRESENT	0
571752	571299	14111D	PARTICIPANT	\N	PRESENT	0
571753	571299	14215L	PARTICIPANT	\N	PRESENT	0
571754	571299	14151M	PARTICIPANT	\N	PRESENT	0
571755	571299	14021P	PARTICIPANT	\N	PRESENT	0
571756	571299	19585H	PARTICIPANT	\N	PRESENT	0
571757	571299	14053L	PARTICIPANT	\N	PRESENT	0
571758	571299	01028R	PARTICIPANT	\N	PRESENT	0
571759	571299	14231L	PARTICIPANT	\N	PRESENT	0
571760	571299	95063L	PARTICIPANT	\N	PRESENT	0
571761	571299	20110Q	PARTICIPANT	\N	PRESENT	0
571762	571299	14147R	PARTICIPANT	\N	PRESENT	0
571763	571299	11085T	PARTICIPANT	\N	PRESENT	0
571764	571299	19749K	PARTICIPANT	\N	PRESENT	0
571765	571299	20128B	PARTICIPANT	\N	PRESENT	0
571766	571299	20114U	PARTICIPANT	\N	PRESENT	0
571768	571767	20092G	PARTICIPANT	\N	PRESENT	0
571769	571767	14041T	PARTICIPANT	\N	PRESENT	0
571770	571767	14213J	PARTICIPANT	\N	PRESENT	0
571771	571767	99004R	PARTICIPANT	\N	PRESENT	0
571772	571767	04045F	PARTICIPANT	\N	PRESENT	0
571773	571767	19683J	PARTICIPANT	\N	PRESENT	0
571774	571767	19447X	PARTICIPANT	\N	PRESENT	0
571775	571767	14195A	PARTICIPANT	\N	PRESENT	0
571776	571767	19415P	PRESIDENT	0	PRESENT	0
571777	571767	14217N	PARTICIPANT	\N	PRESENT	0
571778	571767	11045K	PARTICIPANT	\N	PRESENT	0
571779	571767	04092N	PARTICIPANT	\N	EXCUSE	0
572015	572014	14089Y	PARTICIPANT	\N	PRESENT	0
572016	572014	14053L	PARTICIPANT	\N	PRESENT	0
572017	572014	19749K	PARTICIPANT	\N	PRESENT	0
572019	572018	14089Y	PARTICIPANT	\N	PRESENT	0
572020	572018	14053L	PARTICIPANT	\N	PRESENT	0
572021	572018	17737W	PARTICIPANT	\N	PRESENT	0
572022	572018	19649G	PARTICIPANT	\N	PRESENT	0
572023	572018	19749K	PARTICIPANT	\N	PRESENT	0
572025	572024	14089Y	PARTICIPANT	\N	PRESENT	0
572026	572024	14053L	PARTICIPANT	\N	PRESENT	0
572027	572024	19749K	PARTICIPANT	\N	PRESENT	0
572029	572028	14089Y	PARTICIPANT	\N	PRESENT	0
572030	572028	14053L	PARTICIPANT	\N	PRESENT	0
572031	572028	20128B	PARTICIPANT	\N	PRESENT	0
572032	572028	19749K	PARTICIPANT	\N	PRESENT	0
572033	572028	01028R	PARTICIPANT	\N	PRESENT	0
578587	578543	14001X	PARTICIPANT	\N	PRESENT	0
578588	578543	19629C	PARTICIPANT	\N	PRESENT	0
578589	578543	19631V	PARTICIPANT	\N	PRESENT	0
578590	578543	11056N	PARTICIPANT	\N	PRESENT	0
578591	578543	20102Q	PARTICIPANT	\N	PRESENT	0
578592	578543	20042V	PARTICIPANT	\N	PRESENT	0
578593	578543	19711U	PARTICIPANT	\N	PRESENT	0
578594	578543	01048V	PARTICIPANT	\N	PRESENT	0
578595	578543	11072N	PARTICIPANT	\N	PRESENT	0
578596	578543	19447X	PARTICIPANT	\N	PRESENT	0
578597	578543	19715Y	PARTICIPANT	\N	PRESENT	0
578598	578543	11067R	PARTICIPANT	\N	PRESENT	0
578599	578543	19441R	PARTICIPANT	\N	PRESENT	0
578600	578543	14327T	PARTICIPANT	\N	PRESENT	0
578601	578543	19335Q	PARTICIPANT	\N	PRESENT	0
578602	578543	19691J	PARTICIPANT	\N	PRESENT	0
578603	578543	19515S	PARTICIPANT	\N	PRESENT	0
578604	578543	20038A	PARTICIPANT	\N	PRESENT	0
578605	578543	20034V	PARTICIPANT	\N	PRESENT	0
578606	578543	19657G	PARTICIPANT	\N	PRESENT	0
578607	578543	19689Q	PARTICIPANT	\N	PRESENT	0
578608	578543	17589D	PARTICIPANT	\N	PRESENT	0
578609	578543	14071N	PARTICIPANT	\N	PRESENT	0
578610	578543	19577H	PARTICIPANT	\N	PRESENT	0
578611	578543	19533U	PARTICIPANT	\N	PRESENT	0
578612	578543	17637T	PARTICIPANT	\N	PRESENT	0
578613	578543	19489J	PARTICIPANT	\N	PRESENT	0
578614	578543	95063L	PARTICIPANT	\N	PRESENT	0
578615	578543	04092N	PARTICIPANT	\N	PRESENT	0
578616	578543	20044X	PARTICIPANT	\N	PRESENT	0
578617	578543	04047H	PARTICIPANT	\N	PRESENT	0
578618	578543	19735D	PARTICIPANT	\N	PRESENT	0
578619	578543	20132W	PARTICIPANT	\N	PRESENT	0
578620	578543	19347U	PARTICIPANT	\N	PRESENT	0
578621	578543	14030Q	PARTICIPANT	\N	PRESENT	0
578622	578543	20142Y	PARTICIPANT	\N	PRESENT	0
578623	578543	19747H	PARTICIPANT	\N	PRESENT	0
578585	578543	19719D	PARTICIPANT	\N	PRESENT	0
578586	578543	14187A	PARTICIPANT	\N	PRESENT	0
578624	578543	14215L	PARTICIPANT	\N	PRESENT	0
578625	578543	05008E	PARTICIPANT	\N	PRESENT	0
578626	578543	01057W	PARTICIPANT	\N	PRESENT	0
578627	578543	20092G	PARTICIPANT	\N	PRESENT	0
578628	578543	20022R	PARTICIPANT	\N	PRESENT	0
578629	578543	01043Q	PARTICIPANT	\N	PRESENT	0
578630	578543	20090E	PARTICIPANT	\N	PRESENT	0
578631	578543	07029T	PARTICIPANT	\N	PRESENT	0
578632	578543	19768N	PARTICIPANT	\N	PRESENT	0
578633	578543	19301E	PARTICIPANT	\N	PRESENT	0
578634	578543	20110Q	PARTICIPANT	\N	PRESENT	0
578635	578543	14231L	PARTICIPANT	\N	PRESENT	0
578636	578543	08010L	PARTICIPANT	\N	PRESENT	0
578637	578543	12041X	PARTICIPANT	\N	PRESENT	0
578638	578543	19621T	PARTICIPANT	\N	PRESENT	0
578639	578543	20174H	PARTICIPANT	\N	PRESENT	0
578640	578543	19591F	PARTICIPANT	\N	PRESENT	0
578641	578543	20128B	PARTICIPANT	\N	PRESENT	0
578642	578543	10015M	PARTICIPANT	\N	PRESENT	0
578643	578543	11097X	PARTICIPANT	\N	PRESENT	0
578644	578543	19503N	PARTICIPANT	\N	PRESENT	0
578645	578543	14179A	PARTICIPANT	\N	PRESENT	0
578646	578543	17023S	PARTICIPANT	\N	PRESENT	0
578647	578543	20106U	PARTICIPANT	\N	PRESENT	0
578648	578543	20036X	PARTICIPANT	\N	PRESENT	0
578649	578543	14151M	PARTICIPANT	\N	PRESENT	0
578650	578543	14229S	PARTICIPANT	\N	PRESENT	0
578651	578543	19782L	PARTICIPANT	\N	PRESENT	0
578652	578543	01028R	PARTICIPANT	\N	PRESENT	0
578653	578543	14026U	PARTICIPANT	\N	PRESENT	0
578654	578543	14205J	PARTICIPANT	\N	PRESENT	0
578655	578543	11048N	PARTICIPANT	\N	PRESENT	0
578656	578543	14111D	PARTICIPANT	\N	PRESENT	0
578657	578543	11090Q	PARTICIPANT	\N	PRESENT	0
578658	578543	14033T	PARTICIPANT	\N	PRESENT	0
578920	577328	08018U	PARTICIPANT	\N	EXCUSE	0
579385	578179	99004R	PARTICIPANT	\N	PRESENT	0
579394	578179	14001X	PARTICIPANT	\N	PRESENT	0
579395	578179	11056N	PARTICIPANT	\N	PRESENT	0
579396	578179	20110Q	PARTICIPANT	\N	PRESENT	0
579397	578179	19489J	PARTICIPANT	\N	PRESENT	0
579398	578179	11099A	PARTICIPANT	\N	PRESENT	0
579399	578179	19717B	PARTICIPANT	\N	PRESENT	0
579401	578179	14073Q	PARTICIPANT	\N	PRESENT	0
579402	578179	20108W	PARTICIPANT	\N	PRESENT	0
579403	578179	17367Q	PARTICIPANT	\N	PRESENT	0
579405	578179	20124W	PARTICIPANT	\N	PRESENT	0
582015	581921	11056N	PARTICIPANT	\N	PRESENT	1
582016	581921	19629C	PARTICIPANT	\N	PRESENT	1
582017	581921	19543W	PARTICIPANT	\N	PRESENT	1
582018	581921	14147R	PARTICIPANT	\N	PRESENT	1
582019	581921	19749K	PARTICIPANT	\N	PRESENT	1
582020	581921	20074E	PARTICIPANT	\N	EXCUSE	0
582561	582557	19649G	PARTICIPANT	\N	PRESENT	0
582562	582557	04085P	PARTICIPANT	\N	PRESENT	0
582563	582557	11085T	PARTICIPANT	\N	PRESENT	0
582564	582557	19543W	PARTICIPANT	\N	PRESENT	0
582559	582557	04047H	PRESIDENT	0	PRESENT	0
582560	582557	14215L	PARTICIPANT	\N	PRESENT	0
582575	582572	20174H	PARTICIPANT	\N	PRESENT	0
582573	582572	14205J	PARTICIPANT	\N	PRESENT	0
582574	582572	20054A	PARTICIPANT	\N	PRESENT	0
582577	582576	14205J	PARTICIPANT	\N	PRESENT	0
582578	582576	20054A	PARTICIPANT	\N	PRESENT	0
582579	582576	20174H	PARTICIPANT	\N	PRESENT	0
582581	582580	14205J	PARTICIPANT	\N	PRESENT	0
582582	582580	20054A	PARTICIPANT	\N	PRESENT	0
583101	582630	19525U	PARTICIPANT	\N	PRESENT	0
583102	582630	04059M	PARTICIPANT	\N	PRESENT	0
583103	582630	01028R	PARTICIPANT	\N	PRESENT	0
583104	582630	19715Y	PARTICIPANT	\N	PRESENT	0
583105	582630	19689Q	PARTICIPANT	\N	PRESENT	0
583106	582630	20020P	PARTICIPANT	\N	PRESENT	0
583107	582630	20152B	PARTICIPANT	\N	PRESENT	0
583108	582630	20124W	PARTICIPANT	\N	PRESENT	0
583109	582630	20062A	PARTICIPANT	\N	PRESENT	0
583110	582630	97011G	PARTICIPANT	\N	PRESENT	0
583111	582630	14147R	PARTICIPANT	\N	PRESENT	0
583112	582630	19697Q	PARTICIPANT	\N	PRESENT	0
583113	582630	14249W	PARTICIPANT	\N	PRESENT	0
583114	582630	20024T	PARTICIPANT	\N	PRESENT	0
583115	582630	04042C	PARTICIPANT	\N	PRESENT	0
583116	582630	11012A	PARTICIPANT	\N	PRESENT	0
583117	582630	14107H	PARTICIPANT	\N	PRESENT	0
583118	582630	08047A	PARTICIPANT	\N	PRESENT	0
583119	582630	19387D	PARTICIPANT	\N	PRESENT	0
583120	582630	20148F	PARTICIPANT	\N	PRESENT	0
583121	582630	20132W	PARTICIPANT	\N	PRESENT	0
583122	582630	19705W	PARTICIPANT	\N	PRESENT	0
583123	582630	20150Y	PARTICIPANT	\N	PRESENT	0
583124	582630	11048N	PARTICIPANT	\N	PRESENT	0
583125	582630	14038Y	PARTICIPANT	\N	PRESENT	0
583126	582630	11053K	PARTICIPANT	\N	PRESENT	0
583127	582630	19573D	PARTICIPANT	\N	PRESENT	0
583128	582630	19611R	PARTICIPANT	\N	PRESENT	0
583129	582630	20056C	PARTICIPANT	\N	PRESENT	0
583130	582630	19441R	PARTICIPANT	\N	PRESENT	0
583131	582630	19673G	PARTICIPANT	\N	PRESENT	0
583132	582630	20048C	PARTICIPANT	\N	PRESENT	0
583133	582630	20110Q	PARTICIPANT	\N	PRESENT	0
583134	582630	12041X	PARTICIPANT	\N	PRESENT	0
583135	582630	95063L	PARTICIPANT	\N	PRESENT	0
583136	582630	19347U	PARTICIPANT	\N	PRESENT	0
583137	582630	20136B	PARTICIPANT	\N	PRESENT	0
583138	582630	11027H	PARTICIPANT	\N	PRESENT	0
583139	582630	08017T	PARTICIPANT	\N	PRESENT	0
583140	582630	19591F	PARTICIPANT	\N	PRESENT	0
583141	582630	20122U	PARTICIPANT	\N	PRESENT	0
583142	582630	11033F	PARTICIPANT	\N	PRESENT	0
583143	582630	08018U	PARTICIPANT	\N	PRESENT	0
583144	582630	19647E	PARTICIPANT	\N	PRESENT	0
583145	582630	01024M	PARTICIPANT	\N	PRESENT	0
583146	582630	14251Q	PARTICIPANT	\N	PRESENT	0
583147	582630	11083R	PARTICIPANT	\N	PRESENT	0
583148	582630	19866P	PARTICIPANT	\N	PRESENT	0
583149	582630	14217N	PARTICIPANT	\N	PRESENT	0
583150	582630	19581D	PARTICIPANT	\N	PRESENT	0
583154	582630	14089Y	PARTICIPANT	\N	PRESENT	0
583155	582630	01060R	PARTICIPANT	\N	PRESENT	0
583156	582630	11045K	PARTICIPANT	\N	PRESENT	0
584298	583462	20074E	PARTICIPANT	\N	PRESENT	0
584299	583462	04047H	PRESIDENT	0	PRESENT	0
584300	583462	01028R	PARTICIPANT	\N	PRESENT	0
584301	583462	14231L	PARTICIPANT	\N	PRESENT	0
584302	583462	19447X	PARTICIPANT	\N	PRESENT	0
584303	583462	05008E	PARTICIPANT	\N	PRESENT	0
584304	583462	19954N	PARTICIPANT	\N	PRESENT	0
584305	583462	14107H	PARTICIPANT	\N	PRESENT	0
584306	583462	14147R	PARTICIPANT	\N	PRESENT	0
584307	583462	14179A	PARTICIPANT	\N	PRESENT	0
584308	583462	14151M	PARTICIPANT	\N	PRESENT	0
584309	583462	14215L	PARTICIPANT	\N	PRESENT	0
584310	583462	11072N	PARTICIPANT	\N	PRESENT	0
584311	583462	14053L	PARTICIPANT	\N	PRESENT	0
584312	583462	14111D	PARTICIPANT	\N	PRESENT	0
584313	583462	11026G	PARTICIPANT	\N	PRESENT	0
584314	583462	04085P	PARTICIPANT	\N	PRESENT	0
584315	583462	19725B	PARTICIPANT	\N	PRESENT	0
584316	583462	14089Y	PARTICIPANT	\N	PRESENT	0
584317	583462	11056N	PARTICIPANT	\N	PRESENT	0
584318	583462	19729F	PARTICIPANT	\N	PRESENT	0
584319	583462	95063L	PARTICIPANT	\N	PRESENT	0
584320	583462	14069U	PARTICIPANT	\N	PRESENT	0
584321	583462	19749K	PARTICIPANT	\N	PRESENT	0
584322	583462	14021P	PARTICIPANT	\N	PRESENT	0
584323	583462	20114U	PARTICIPANT	\N	PRESENT	0
584356	583456	20086J	PARTICIPANT	\N	PRESENT	0
584357	583456	14327T	PARTICIPANT	\N	PRESENT	0
584358	583456	14331P	PARTICIPANT	\N	PRESENT	0
584359	583456	11048N	PARTICIPANT	\N	PRESENT	0
584360	583456	01048V	PARTICIPANT	\N	PRESENT	0
584361	583456	14189C	PARTICIPANT	\N	PRESENT	0
584362	583456	01057W	PARTICIPANT	\N	PRESENT	0
584363	583456	11053K	PARTICIPANT	\N	PRESENT	0
584364	583456	12016W	PARTICIPANT	\N	PRESENT	0
584365	583456	20050V	PARTICIPANT	\N	PRESENT	0
584366	583456	20044X	PARTICIPANT	\N	PRESENT	0
584367	583456	19671E	PARTICIPANT	\N	PRESENT	0
584368	583456	11110B	PARTICIPANT	\N	PRESENT	0
584369	583456	14173T	PARTICIPANT	\N	PRESENT	0
584370	583456	11040E	PARTICIPANT	\N	PRESENT	0
584371	583456	19349W	PARTICIPANT	\N	PRESENT	0
584372	583456	19741B	PARTICIPANT	\N	PRESENT	0
584373	583456	08010L	PARTICIPANT	\N	PRESENT	0
584374	583456	14121F	PARTICIPANT	\N	PRESENT	0
584375	583456	99004R	PARTICIPANT	\N	PRESENT	0
584376	583456	20116W	PARTICIPANT	\N	PRESENT	0
584377	583456	20022R	PARTICIPANT	\N	PRESENT	0
584378	583456	20126Y	PARTICIPANT	\N	PRESENT	0
584380	583454	19383Y	PARTICIPANT	\N	PRESENT	0
584381	583454	19768N	PARTICIPANT	\N	PRESENT	0
584382	583454	19515S	PARTICIPANT	\N	PRESENT	0
584383	583454	20092G	PARTICIPANT	\N	PRESENT	0
584384	583454	19782L	PARTICIPANT	\N	PRESENT	1
584385	583454	01043Q	PARTICIPANT	\N	PRESENT	0
584386	583454	14357A	PARTICIPANT	\N	PRESENT	0
584387	583454	20078J	PARTICIPANT	\N	PRESENT	0
584388	583454	19441R	PARTICIPANT	\N	PRESENT	0
584389	583454	19413M	PARTICIPANT	\N	PRESENT	0
584390	583454	20082E	PARTICIPANT	\N	PRESENT	1
584391	583454	04045F	PARTICIPANT	\N	PRESENT	0
584392	583454	19631V	PARTICIPANT	\N	PRESENT	0
584393	583454	20104S	PARTICIPANT	\N	PRESENT	0
584394	583454	19705W	PARTICIPANT	\N	PRESENT	0
584395	583454	19575F	PARTICIPANT	\N	PRESENT	0
584396	583454	19369B	PARTICIPANT	\N	PRESENT	0
584397	583454	20018V	PARTICIPANT	\N	PRESENT	0
584398	583454	19511N	PARTICIPANT	\N	PRESENT	0
584399	583454	19563B	PARTICIPANT	\N	PRESENT	0
584400	583454	14329V	PARTICIPANT	\N	PRESENT	0
584401	583454	14038Y	PARTICIPANT	\N	PRESENT	0
584402	583454	20030R	PARTICIPANT	\N	PRESENT	1
584403	583454	19467C	PARTICIPANT	\N	PRESENT	0
584404	583454	14187A	PARTICIPANT	\N	PRESENT	0
584405	583454	20144B	PARTICIPANT	\N	PRESENT	0
584406	583454	19695N	PARTICIPANT	\N	PRESENT	0
584407	583454	01025N	PARTICIPANT	\N	PRESENT	0
584408	583454	11090Q	PRESIDENT	0	PRESENT	0
584409	583454	14033T	PARTICIPANT	\N	PRESENT	0
584410	583454	20054A	PARTICIPANT	\N	PRESENT	0
584411	583454	20174H	PARTICIPANT	\N	PRESENT	1
584412	583454	20062A	PARTICIPANT	\N	PRESENT	0
584413	583454	20252E	PARTICIPANT	\N	PRESENT	0
584414	583454	19507S	PARTICIPANT	\N	PRESENT	0
584415	583454	14207L	PARTICIPANT	\N	PRESENT	0
584416	583454	14257W	PARTICIPANT	\N	PRESENT	0
584418	583454	14251Q	PARTICIPANT	\N	PRESENT	0
584420	583456	11074Q	PARTICIPANT	\N	PRESENT	0
578132	575274	14259Y	PARTICIPANT	\N	PRESENT	0
578133	575274	19599P	PARTICIPANT	\N	PRESENT	0
578134	575274	14001X	PARTICIPANT	\N	PRESENT	0
578135	575274	19631V	PARTICIPANT	\N	PRESENT	0
578136	575274	14169X	PARTICIPANT	\N	PRESENT	0
578137	575274	11056N	PARTICIPANT	\N	PRESENT	0
578138	575274	95063L	PARTICIPANT	\N	PRESENT	0
578139	575274	20100N	PARTICIPANT	\N	PRESENT	0
578128	575274	01043Q	PARTICIPANT	\N	PRESENT	0
578131	575274	14215L	PARTICIPANT	\N	PRESENT	0
578140	575274	20034V	PARTICIPANT	\N	PRESENT	0
578141	575274	19782L	PARTICIPANT	\N	PRESENT	0
578142	575274	07029T	PARTICIPANT	\N	PRESENT	0
578143	575274	17367Q	PARTICIPANT	\N	PRESENT	0
578144	575274	14329V	PARTICIPANT	\N	PRESENT	0
578145	575274	19717B	PARTICIPANT	\N	PRESENT	0
578146	575274	20062A	PARTICIPANT	\N	PRESENT	0
578147	575274	19629C	PARTICIPANT	\N	PRESENT	0
578148	575274	19693L	PARTICIPANT	\N	PRESENT	0
578149	575274	99004R	PARTICIPANT	\N	PRESENT	0
578150	575274	19749K	PARTICIPANT	\N	PRESENT	0
578151	575274	20068G	PARTICIPANT	\N	PRESENT	0
578156	575274	20110Q	PARTICIPANT	\N	PRESENT	0
578153	575274	19515S	PARTICIPANT	\N	PRESENT	0
578155	575274	19489J	PARTICIPANT	\N	PRESENT	0
578157	575274	19301E	PARTICIPANT	\N	PRESENT	0
578161	575274	20134Y	PARTICIPANT	\N	PRESENT	0
578159	575274	10015M	PARTICIPANT	\N	PRESENT	0
578160	575274	05012A	PARTICIPANT	\N	PRESENT	0
578162	575274	01048V	PARTICIPANT	\N	PRESENT	0
578163	575274	19335Q	PARTICIPANT	\N	PRESENT	0
578164	575274	04085P	PARTICIPANT	\N	PRESENT	0
578171	575274	19563B	PARTICIPANT	\N	PRESENT	0
578166	575274	19657G	PARTICIPANT	\N	PRESENT	0
578167	575274	01028R	PARTICIPANT	\N	PRESENT	0
578174	575274	14083S	PARTICIPANT	\N	PRESENT	0
578178	575274	19695N	PARTICIPANT	\N	PRESENT	0
578182	575274	05008E	PARTICIPANT	\N	PRESENT	0
578183	575274	14089Y	PARTICIPANT	\N	PRESENT	0
578184	575274	14231L	PARTICIPANT	\N	PRESENT	0
578185	575274	17023S	PARTICIPANT	\N	PRESENT	0
578186	575274	14187A	PARTICIPANT	\N	PRESENT	0
578187	575274	20122U	PARTICIPANT	\N	PRESENT	0
578188	575274	20152B	PARTICIPANT	\N	PRESENT	0
578189	575274	04047H	PARTICIPANT	\N	PRESENT	0
578190	575274	19711U	PARTICIPANT	\N	PRESENT	0
578196	575274	19715Y	PARTICIPANT	\N	PRESENT	0
578197	575274	20056C	PARTICIPANT	\N	PRESENT	0
578198	575274	11090Q	PARTICIPANT	\N	PRESENT	0
578233	575275	20110Q	PARTICIPANT	\N	PRESENT	0
578234	575275	14259Y	PARTICIPANT	\N	PRESENT	0
578235	575275	14215L	PARTICIPANT	\N	PRESENT	0
578258	575275	19693L	PARTICIPANT	\N	PRESENT	0
578237	575275	04047H	PARTICIPANT	\N	PRESENT	0
578238	575275	19629C	PARTICIPANT	\N	PRESENT	0
578239	575275	19657G	PARTICIPANT	\N	PRESENT	0
578240	575275	20100N	PARTICIPANT	\N	PRESENT	0
578241	575275	19631V	PARTICIPANT	\N	PRESENT	0
578242	575275	14001X	PARTICIPANT	\N	PRESENT	0
578243	575275	19489J	PARTICIPANT	\N	PRESENT	0
578244	575275	04085P	PARTICIPANT	\N	PRESENT	0
578245	575275	19717B	PARTICIPANT	\N	PRESENT	0
578246	575275	19749K	PARTICIPANT	\N	PRESENT	0
578247	575275	01043Q	PARTICIPANT	\N	PRESENT	0
578248	575275	17367Q	PARTICIPANT	\N	PRESENT	0
578249	575275	11090Q	PARTICIPANT	\N	PRESENT	0
578250	575275	14187A	PARTICIPANT	\N	PRESENT	0
578251	575275	20152B	PARTICIPANT	\N	PRESENT	0
578252	575275	20122U	PARTICIPANT	\N	PRESENT	0
578253	575275	95063L	PARTICIPANT	\N	PRESENT	0
578254	575275	11072N	PARTICIPANT	\N	PRESENT	0
578255	575275	19515S	PARTICIPANT	\N	PRESENT	0
578256	575275	99004R	PARTICIPANT	\N	PRESENT	0
578257	575275	20124W	PARTICIPANT	\N	PRESENT	0
578259	575275	05008E	PARTICIPANT	\N	PRESENT	0
578260	575275	19301E	PARTICIPANT	\N	PRESENT	0
578261	575275	11056N	PARTICIPANT	\N	PRESENT	0
578262	575275	19695N	PARTICIPANT	\N	PRESENT	0
578266	575275	19335Q	PARTICIPANT	\N	PRESENT	0
578264	575275	01048V	PARTICIPANT	\N	PRESENT	0
578265	575275	20068G	PARTICIPANT	\N	PRESENT	0
578231	575275	14026U	PARTICIPANT	\N	PRESENT	0
578232	575275	19711U	PARTICIPANT	\N	PRESENT	0
578267	575275	20134Y	PARTICIPANT	\N	PRESENT	0
578268	575275	04043D	PARTICIPANT	\N	PRESENT	0
578269	575275	19715Y	PARTICIPANT	\N	PRESENT	0
578270	575275	19782L	PARTICIPANT	\N	PRESENT	0
578271	575275	19687N	PARTICIPANT	\N	PRESENT	0
578272	575275	17023S	PARTICIPANT	\N	PRESENT	0
578273	575275	20034V	PARTICIPANT	\N	PRESENT	0
578274	575275	14231L	PARTICIPANT	\N	PRESENT	0
578275	575275	20130U	PARTICIPANT	\N	PRESENT	0
578277	575275	11085T	PARTICIPANT	\N	PRESENT	0
578281	575275	04042C	PARTICIPANT	\N	PRESENT	0
578289	578288	19367Y	PARTICIPANT	\N	PRESENT	0
578290	578288	20042V	PARTICIPANT	\N	PRESENT	0
578291	578288	14255U	PARTICIPANT	\N	PRESENT	0
578292	578288	04042C	PARTICIPANT	\N	PRESENT	0
578293	578288	18083K	PARTICIPANT	\N	PRESENT	0
578294	578288	14357A	PARTICIPANT	\N	PRESENT	0
578295	578288	19663E	PARTICIPANT	\N	PRESENT	0
578296	578288	98018T	PARTICIPANT	\N	PRESENT	0
578297	578288	14041T	PARTICIPANT	\N	PRESENT	0
578298	578288	14097Y	PARTICIPANT	\N	PRESENT	0
578299	578288	19399H	PARTICIPANT	\N	PRESENT	0
578300	578288	19333N	PARTICIPANT	\N	PRESENT	0
578301	578288	14179A	PARTICIPANT	\N	PRESENT	0
578302	578288	14026U	PARTICIPANT	\N	PRESENT	0
578303	578288	04035D	PARTICIPANT	\N	PRESENT	0
578304	578288	97011G	PARTICIPANT	\N	PRESENT	0
578305	578288	14249W	PARTICIPANT	\N	PRESENT	0
578306	578288	14147R	PARTICIPANT	\N	PRESENT	0
578307	578288	14059S	PARTICIPANT	\N	PRESENT	0
578308	578288	08034U	PARTICIPANT	\N	PRESENT	0
578309	578288	04034C	PARTICIPANT	\N	PRESENT	0
578310	578288	01034P	PARTICIPANT	\N	PRESENT	0
578311	578288	11041F	PARTICIPANT	\N	PRESENT	0
578312	578288	01058X	PARTICIPANT	\N	PRESENT	0
578313	578288	04033B	PARTICIPANT	\N	PRESENT	0
578314	578288	19711U	PARTICIPANT	\N	PRESENT	0
578315	578288	16685X	PARTICIPANT	\N	PRESENT	0
578317	578316	14071N	PARTICIPANT	\N	PRESENT	0
579471	579470	14329V	PARTICIPANT	\N	PRESENT	0
579473	579472	14329V	PARTICIPANT	\N	PRESENT	0
584752	583497	20132W	PARTICIPANT	\N	PRESENT	0
584753	583497	14121F	PARTICIPANT	\N	PRESENT	0
584754	583497	19421M	PARTICIPANT	\N	PRESENT	0
584755	583497	19637C	PARTICIPANT	\N	PRESENT	0
584756	583497	04059M	PARTICIPANT	\N	PRESENT	0
584757	583497	20172F	PARTICIPANT	\N	PRESENT	0
584758	583497	19758L	PARTICIPANT	\N	PRESENT	0
584759	583497	04085P	PARTICIPANT	\N	PRESENT	0
584760	583497	11056N	PARTICIPANT	\N	PRESENT	0
584761	583497	20130U	PARTICIPANT	\N	PRESENT	0
584762	583497	19651A	PARTICIPANT	\N	PRESENT	0
584763	583497	14211G	PARTICIPANT	\N	PRESENT	0
584777	583497	19715Y	PARTICIPANT	\N	PRESENT	0
584765	583497	19703U	PARTICIPANT	\N	PRESENT	0
584766	583497	19697Q	PARTICIPANT	\N	PRESENT	0
584767	583497	11077T	PARTICIPANT	\N	PRESENT	0
584768	583497	04035D	PARTICIPANT	\N	PRESENT	0
584769	583497	11031D	PARTICIPANT	\N	PRESENT	0
584770	583497	14207L	PARTICIPANT	\N	PRESENT	0
584771	583497	05008E	PARTICIPANT	\N	PRESENT	0
584772	583497	19719D	PARTICIPANT	\N	PRESENT	0
584773	583497	11012A	PARTICIPANT	\N	PRESENT	0
584774	583497	19679N	PARTICIPANT	\N	PRESENT	0
584775	583497	20078J	PARTICIPANT	\N	PRESENT	0
584776	583497	19329S	PARTICIPANT	\N	PRESENT	0
584778	583497	17779H	PARTICIPANT	\N	PRESENT	0
584779	583497	14021P	PARTICIPANT	\N	PRESENT	0
584780	583497	19647E	PARTICIPANT	\N	PRESENT	0
584781	583497	19683J	PARTICIPANT	\N	PRESENT	0
584782	583497	14151M	PARTICIPANT	\N	PRESENT	0
584783	583497	04092N	PARTICIPANT	\N	PRESENT	0
584784	583497	08045X	PARTICIPANT	\N	PRESENT	0
584785	583497	11067R	PARTICIPANT	\N	PRESENT	0
584786	583497	14169X	PARTICIPANT	\N	PRESENT	0
584787	583497	17965H	PARTICIPANT	\N	PRESENT	0
584788	583497	18193Q	PARTICIPANT	\N	PRESENT	0
584789	583497	01058X	PARTICIPANT	\N	PRESENT	0
580745	579135	11033F	PARTICIPANT	\N	PRESENT	1
580746	579135	19629C	PARTICIPANT	\N	PRESENT	1
580747	579135	19581D	PARTICIPANT	\N	PRESENT	1
580748	579135	19675J	PARTICIPANT	\N	PRESENT	1
580749	579135	19749K	PARTICIPANT	\N	PRESENT	1
583640	583461	14053L	PARTICIPANT	\N	PRESENT	0
583641	583461	20074E	PARTICIPANT	\N	PRESENT	0
583642	583461	14147R	PARTICIPANT	\N	PRESENT	0
583643	583461	19543W	PARTICIPANT	\N	PRESENT	0
583644	583461	14069U	PARTICIPANT	\N	PRESENT	0
583645	583461	04047H	PRESIDENT	0	PRESENT	0
583646	583461	14259Y	PARTICIPANT	\N	PRESENT	0
583647	583461	19447X	PARTICIPANT	\N	PRESENT	0
583648	583461	11072N	PARTICIPANT	\N	PRESENT	0
583649	583461	05008E	PARTICIPANT	\N	PRESENT	0
583650	583461	07004J	PARTICIPANT	\N	EXCUSE	0
583651	583461	19673G	PARTICIPANT	\N	EXCUSE	0
583770	583493	20142Y	PARTICIPANT	\N	PRESENT	0
583653	583455	20030R	PARTICIPANT	\N	PRESENT	0
583654	583455	19467C	PARTICIPANT	\N	PRESENT	0
583655	583455	19768N	PARTICIPANT	\N	PRESENT	0
583656	583455	20088L	PARTICIPANT	\N	PRESENT	0
583657	583455	19515S	PARTICIPANT	\N	PRESENT	0
583658	583455	20078J	PARTICIPANT	\N	PRESENT	0
583659	583455	19441R	PARTICIPANT	\N	PRESENT	0
583660	583455	11090Q	PRESIDENT	0	PRESENT	0
583661	583455	01025N	PARTICIPANT	\N	PRESENT	0
583662	583455	04045F	PARTICIPANT	\N	PRESENT	0
583663	583455	20054A	PARTICIPANT	\N	PRESENT	0
583664	583455	20174H	PARTICIPANT	\N	PRESENT	1
583665	583455	14205J	PARTICIPANT	\N	PRESENT	0
583666	583455	11099A	PARTICIPANT	\N	PRESENT	0
583667	583455	20062A	PARTICIPANT	\N	PRESENT	0
583668	583455	20252E	PARTICIPANT	\N	PRESENT	0
583669	583455	19575F	PARTICIPANT	\N	PRESENT	0
583670	583455	14257W	PARTICIPANT	\N	PRESENT	0
583671	583455	20028X	PARTICIPANT	\N	PRESENT	0
583672	583455	19705W	PARTICIPANT	\N	PRESENT	1
583673	583455	08015R	PARTICIPANT	\N	PRESENT	1
583674	583455	19383Y	PARTICIPANT	\N	PRESENT	0
583675	583455	14187A	PARTICIPANT	\N	PRESENT	0
583771	583493	20110Q	PARTICIPANT	\N	PRESENT	0
583772	583493	04059M	PARTICIPANT	\N	PRESENT	0
583773	583493	19399H	PARTICIPANT	\N	PRESENT	0
583774	583493	19593H	PARTICIPANT	\N	PRESENT	0
583775	583493	19681G	PARTICIPANT	\N	PRESENT	0
583776	583493	14189C	PARTICIPANT	\N	PRESENT	0
583777	583493	20248J	PARTICIPANT	\N	PRESENT	0
583778	583493	19387D	PARTICIPANT	\N	PRESENT	0
583779	583493	20132W	PARTICIPANT	\N	PRESENT	0
583780	583493	20072C	PARTICIPANT	\N	PRESENT	0
583781	583493	14207L	PARTICIPANT	\N	PRESENT	0
583782	583493	19349W	PARTICIPANT	\N	PRESENT	0
583783	583493	01024M	PARTICIPANT	\N	PRESENT	0
583784	583493	14030Q	PARTICIPANT	\N	PRESENT	0
583785	583493	08061X	PARTICIPANT	\N	PRESENT	0
583786	583493	11103C	PARTICIPANT	\N	PRESENT	0
583787	583493	97011G	PARTICIPANT	\N	PRESENT	0
583788	583493	14105F	PARTICIPANT	\N	PRESENT	0
583789	583493	14147R	PARTICIPANT	\N	PRESENT	0
583790	583493	20024T	PARTICIPANT	\N	PRESENT	0
583791	583493	01058X	PARTICIPANT	\N	PRESENT	0
583792	583493	20090E	PARTICIPANT	\N	PRESENT	0
583793	583493	19703U	PARTICIPANT	\N	PRESENT	0
583794	583493	19954N	PARTICIPANT	\N	PRESENT	0
583795	583493	20032T	PARTICIPANT	\N	PRESENT	0
583796	583493	20026V	PARTICIPANT	\N	PRESENT	0
583797	583493	20180F	PARTICIPANT	\N	PRESENT	0
583798	583493	20044X	PARTICIPANT	\N	PRESENT	0
583799	583493	19515S	PARTICIPANT	\N	PRESENT	0
583800	583493	20076G	PARTICIPANT	\N	PRESENT	0
583801	583493	20078J	PARTICIPANT	\N	PRESENT	0
583802	583493	07029T	PARTICIPANT	\N	PRESENT	0
583803	583493	04070G	PARTICIPANT	\N	PRESENT	0
583804	583493	19611R	PARTICIPANT	\N	PRESENT	0
583805	583493	19758L	PARTICIPANT	\N	PRESENT	0
583806	583493	20046A	PARTICIPANT	\N	PRESENT	0
583807	583493	19760E	PARTICIPANT	\N	PRESENT	0
583808	583493	14038Y	PARTICIPANT	\N	PRESENT	0
583809	583493	19629C	PARTICIPANT	\N	PRESENT	0
583810	583493	20098N	PARTICIPANT	\N	PRESENT	0
583811	583493	19651A	PARTICIPANT	\N	PRESENT	0
583812	583493	20056C	PARTICIPANT	\N	PRESENT	0
583813	583493	20152B	PARTICIPANT	\N	PRESENT	0
583814	583493	17589D	PARTICIPANT	\N	PRESENT	0
583815	583493	20108W	PARTICIPANT	\N	PRESENT	0
583816	583493	14357A	PARTICIPANT	\N	PRESENT	0
583817	583763	19551W	PARTICIPANT	\N	PRESENT	0
583818	583763	14083S	PARTICIPANT	\N	PRESENT	0
583819	583763	19687N	PARTICIPANT	\N	PRESENT	0
583820	583763	19689Q	PARTICIPANT	\N	PRESENT	0
583821	583763	19575F	PRESIDENT	0	PRESENT	0
583822	583763	14026U	PARTICIPANT	\N	PRESENT	0
583823	583763	17779H	PARTICIPANT	\N	PRESENT	0
583824	583763	19369B	PARTICIPANT	\N	EXCUSE	0
583825	583493	14259Y	PARTICIPANT	\N	PRESENT	0
583826	583493	14069U	PARTICIPANT	\N	PRESENT	0
583827	583493	01025N	PARTICIPANT	\N	PRESENT	0
583828	583493	14221J	PARTICIPANT	\N	PRESENT	0
583829	583493	19549D	PARTICIPANT	\N	PRESENT	0
583830	583493	20058E	PARTICIPANT	\N	PRESENT	0
583831	583493	19573D	PARTICIPANT	\N	PRESENT	0
583832	583493	14071N	PARTICIPANT	\N	PRESENT	0
583835	583493	01060R	PARTICIPANT	\N	PRESENT	0
583839	583493	20106U	PARTICIPANT	\N	PRESENT	0
583840	583493	19251M	PARTICIPANT	\N	PRESENT	0
583841	583493	14219Q	PARTICIPANT	\N	PRESENT	0
583842	583493	14229S	PARTICIPANT	\N	PRESENT	0
583843	583493	14237S	PARTICIPANT	\N	PRESENT	0
583844	583493	19467C	PARTICIPANT	\N	PRESENT	0
583845	583493	08009T	PARTICIPANT	\N	PRESENT	0
583896	583494	11070L	PARTICIPANT	\N	PRESENT	0
583897	583494	19549D	PARTICIPANT	\N	PRESENT	0
583898	583494	19251M	PARTICIPANT	\N	PRESENT	0
583899	583494	19631V	PARTICIPANT	\N	PRESENT	0
583900	583494	17589D	PARTICIPANT	\N	PRESENT	0
583901	583494	19515S	PARTICIPANT	\N	PRESENT	0
583902	583494	14237S	PARTICIPANT	\N	PRESENT	0
583768	583493	11070L	PARTICIPANT	\N	PRESENT	0
583769	583493	14151M	PARTICIPANT	\N	PRESENT	0
583903	583494	19349W	PARTICIPANT	\N	PRESENT	0
583904	583494	14105F	PARTICIPANT	\N	PRESENT	0
583905	583494	20106U	PARTICIPANT	\N	PRESENT	0
583906	583494	97011G	PARTICIPANT	\N	PRESENT	0
583907	583494	19681G	PARTICIPANT	\N	PRESENT	0
583908	583494	19507S	PARTICIPANT	\N	PRESENT	0
583909	583494	11056N	PARTICIPANT	\N	PRESENT	0
583910	583494	19383Y	PARTICIPANT	\N	PRESENT	0
583911	583494	19758L	PARTICIPANT	\N	PRESENT	0
583912	583494	20030R	PARTICIPANT	\N	PRESENT	0
583913	583494	14219Q	PARTICIPANT	\N	PRESENT	0
583914	583494	19651A	PARTICIPANT	\N	PRESENT	0
583915	583494	20180F	PARTICIPANT	\N	PRESENT	0
583916	583494	20132W	PARTICIPANT	\N	PRESENT	0
583917	583494	20072C	PARTICIPANT	\N	PRESENT	0
583918	583494	19573D	PARTICIPANT	\N	PRESENT	0
583919	583494	14207L	PARTICIPANT	\N	PRESENT	0
583920	583494	14189C	PARTICIPANT	\N	PRESENT	0
583921	583494	14038Y	PARTICIPANT	\N	PRESENT	0
583922	583494	08009T	PARTICIPANT	\N	PRESENT	0
583923	583494	01024M	PARTICIPANT	\N	PRESENT	0
583924	583494	01025N	PARTICIPANT	\N	PRESENT	0
583925	583494	14357A	PARTICIPANT	\N	PRESENT	0
583926	583494	20090E	PARTICIPANT	\N	PRESENT	0
583927	583494	20076G	PARTICIPANT	\N	PRESENT	0
583928	583494	20028X	PARTICIPANT	\N	PRESENT	0
583929	583494	20044X	PARTICIPANT	\N	PRESENT	0
583930	583494	20046A	PARTICIPANT	\N	PRESENT	0
583931	583494	19760E	PARTICIPANT	\N	PRESENT	0
583932	583494	19467C	PARTICIPANT	\N	PRESENT	0
583933	583494	19387D	PARTICIPANT	\N	PRESENT	0
583934	583494	08061X	PARTICIPANT	\N	PRESENT	0
583935	583494	14173T	PARTICIPANT	\N	PRESENT	0
583942	583494	19347U	PARTICIPANT	\N	PRESENT	0
583944	583494	14221J	PARTICIPANT	\N	PRESENT	0
583946	583494	20080C	PARTICIPANT	\N	PRESENT	0
583947	583494	20032T	PARTICIPANT	\N	PRESENT	0
583949	583494	19533U	PARTICIPANT	\N	PRESENT	0
583950	583494	19479G	PARTICIPANT	\N	PRESENT	0
583952	583494	11053K	PARTICIPANT	\N	PRESENT	0
583953	583494	14223L	PARTICIPANT	\N	PRESENT	0
572494	572493	20056C	PARTICIPANT	\N	PRESENT	0
572497	572496	14249W	PARTICIPANT	\N	PRESENT	0
573952	572776	10006L	PRESIDENT	0	PRESENT	0
573953	572776	19760E	PARTICIPANT	\N	PRESENT	0
573954	572776	11031D	PARTICIPANT	\N	PRESENT	0
573955	572776	11067R	PARTICIPANT	\N	PRESENT	0
573956	572776	19683J	PARTICIPANT	\N	PRESENT	0
573957	572776	04057K	PARTICIPANT	\N	PRESENT	0
573958	572776	14195A	PARTICIPANT	\N	PRESENT	0
573959	572776	19697Q	PARTICIPANT	\N	PRESENT	0
573960	572776	19553Y	PARTICIPANT	\N	PRESENT	0
573961	572776	19679N	PARTICIPANT	\N	PRESENT	0
573962	572776	14213J	PARTICIPANT	\N	PRESENT	0
573963	572776	19367Y	PARTICIPANT	\N	PRESENT	0
573964	572776	19663E	PARTICIPANT	\N	PRESENT	0
573965	572776	19569H	PARTICIPANT	\N	PRESENT	0
573966	572776	01034P	PARTICIPANT	\N	PRESENT	0
573968	572776	14042U	PARTICIPANT	\N	PRESENT	0
573969	572776	19415P	PARTICIPANT	\N	PRESENT	0
573971	572776	11097X	PARTICIPANT	\N	PRESENT	0
573995	572776	14223L	PARTICIPANT	\N	PRESENT	0
573996	572776	19798U	PARTICIPANT	\N	PRESENT	0
574002	572776	20066E	PARTICIPANT	\N	PRESENT	0
574004	572776	19301E	PARTICIPANT	\N	PRESENT	1
574006	572776	20130U	PARTICIPANT	\N	PRESENT	0
574008	572776	14071N	PARTICIPANT	\N	PRESENT	0
574009	572776	04092N	PARTICIPANT	\N	PRESENT	0
574010	572776	20090E	PARTICIPANT	\N	PRESENT	0
574024	572776	17965H	PARTICIPANT	\N	PRESENT	0
574019	572776	20068G	PARTICIPANT	\N	PRESENT	0
574023	572776	18193Q	PARTICIPANT	\N	PRESENT	0
574025	572776	04043D	PARTICIPANT	\N	PRESENT	0
574026	572776	11103C	PARTICIPANT	\N	PRESENT	1
574027	572776	19295A	PARTICIPANT	\N	EXCUSE	0
574028	572776	19715Y	PARTICIPANT	\N	PRESENT	1
574035	572776	08045X	PARTICIPANT	\N	PRESENT	1
574037	572776	19723Y	PARTICIPANT	\N	PRESENT	1
576266	575544	17367Q	PRESIDENT	0	PRESENT	0
576267	575544	20050V	PARTICIPANT	\N	PRESENT	0
576268	575544	20132W	PARTICIPANT	\N	PRESENT	0
576269	575544	19621T	PARTICIPANT	\N	PRESENT	0
576270	575544	19593H	PARTICIPANT	\N	PRESENT	0
576271	575544	07004J	PARTICIPANT	\N	PRESENT	0
576272	575544	20082E	PARTICIPANT	\N	PRESENT	0
576273	575544	11026G	PARTICIPANT	\N	PRESENT	0
576274	575544	20058E	PARTICIPANT	\N	PRESENT	0
576275	575544	19333N	PARTICIPANT	\N	PRESENT	0
576276	575544	19533U	PARTICIPANT	\N	PRESENT	0
576277	575544	11083R	PARTICIPANT	\N	PRESENT	0
576278	575544	19369B	PARTICIPANT	\N	PRESENT	0
576279	575544	97011G	PARTICIPANT	\N	PRESENT	0
576280	575544	04035D	PARTICIPANT	\N	EXCUSE	0
578663	578662	19575F	PRESIDENT	0	PRESENT	1
578664	578662	19749K	PARTICIPANT	\N	PRESENT	1
578665	578662	19687N	PARTICIPANT	\N	PRESENT	0
579373	579371	11083R	PARTICIPANT	\N	PRESENT	0
579374	579371	20050V	PARTICIPANT	\N	PRESENT	0
579375	579371	20132W	PARTICIPANT	\N	PRESENT	0
579376	577930	11083R	PARTICIPANT	\N	PRESENT	1
579377	577930	17367Q	PRESIDENT	0	PRESENT	0
579378	577930	19333N	PARTICIPANT	\N	PRESENT	0
579379	577930	20082E	PARTICIPANT	\N	PRESENT	0
579380	577930	19533U	PARTICIPANT	\N	PRESENT	0
579381	577930	97011G	PARTICIPANT	\N	PRESENT	0
579382	577930	20134Y	PARTICIPANT	\N	PRESENT	1
579383	577930	20132W	PARTICIPANT	\N	PRESENT	1
579384	577930	20180F	PARTICIPANT	\N	PRESENT	0
579406	578179	18083K	PARTICIPANT	\N	PRESENT	0
579407	578179	20076G	PARTICIPANT	\N	PRESENT	0
579409	578179	19629C	PARTICIPANT	\N	PRESENT	0
579410	578179	19758L	PARTICIPANT	\N	PRESENT	0
579411	578179	20102Q	PARTICIPANT	\N	PRESENT	0
579413	578179	20100N	PARTICIPANT	\N	PRESENT	0
579414	578179	14215L	PARTICIPANT	\N	PRESENT	0
579415	578179	14259Y	PARTICIPANT	\N	PRESENT	0
579416	578179	07029T	PARTICIPANT	\N	PRESENT	0
579418	578179	19711U	PARTICIPANT	\N	PRESENT	0
579419	578179	11097X	PARTICIPANT	\N	PRESENT	0
579420	578179	19301E	PARTICIPANT	\N	PRESENT	0
579421	578179	11065P	PARTICIPANT	\N	PRESENT	0
579422	578179	14219Q	PARTICIPANT	\N	PRESENT	0
579425	578179	19545Y	PARTICIPANT	\N	PRESENT	0
579426	578179	19251M	PARTICIPANT	\N	PRESENT	0
579427	578179	14189C	PARTICIPANT	\N	PRESENT	0
579428	578179	20128B	PARTICIPANT	\N	PRESENT	0
579429	578179	14327T	PARTICIPANT	\N	PRESENT	0
579431	578179	19687N	PARTICIPANT	\N	PRESENT	0
579433	578179	19335Q	PARTICIPANT	\N	PRESENT	0
579435	578179	20046A	PARTICIPANT	\N	PRESENT	0
579436	578179	17023S	PARTICIPANT	\N	PRESENT	0
579438	578179	19347U	PARTICIPANT	\N	PRESENT	0
579439	578179	11090Q	PARTICIPANT	\N	PRESENT	0
579440	578179	14038Y	PARTICIPANT	\N	PRESENT	0
579441	578179	11012A	PARTICIPANT	\N	PRESENT	0
579442	578179	20094J	PARTICIPANT	\N	PRESENT	0
579443	578179	14083S	PARTICIPANT	\N	PRESENT	0
579444	578179	20086J	PARTICIPANT	\N	PRESENT	0
579445	578179	14231L	PARTICIPANT	\N	PRESENT	0
579446	578179	07004J	PARTICIPANT	\N	PRESENT	0
579447	578179	04047H	PARTICIPANT	\N	PRESENT	0
579451	578179	12016W	PARTICIPANT	\N	PRESENT	0
579454	578179	20152B	PARTICIPANT	\N	PRESENT	0
579455	578179	20058E	PARTICIPANT	\N	PRESENT	0
579456	578179	20098N	PARTICIPANT	\N	PRESENT	0
579457	578179	14042U	PARTICIPANT	\N	PRESENT	0
579458	578179	19691J	PARTICIPANT	\N	PRESENT	0
579459	578179	19575F	PARTICIPANT	\N	PRESENT	0
579460	578179	11043H	PARTICIPANT	\N	PRESENT	0
579461	578179	14357A	PARTICIPANT	\N	PRESENT	0
579462	578179	20034V	PARTICIPANT	\N	PRESENT	0
579463	578179	08010L	PARTICIPANT	\N	PRESENT	0
579466	578179	20096L	PARTICIPANT	\N	PRESENT	0
579468	578179	19695N	PARTICIPANT	\N	PRESENT	0
579469	578179	19647E	PARTICIPANT	\N	PRESENT	0
579510	578180	04047H	PARTICIPANT	\N	PRESENT	0
579511	578180	07004J	PARTICIPANT	\N	PRESENT	0
579512	578180	19629C	PARTICIPANT	\N	PRESENT	0
579513	578180	14259Y	PARTICIPANT	\N	PRESENT	0
579515	578180	19583F	PARTICIPANT	\N	PRESENT	0
579516	578180	20102Q	PARTICIPANT	\N	PRESENT	0
579517	578180	19489J	PARTICIPANT	\N	PRESENT	0
579518	578180	20110Q	PARTICIPANT	\N	PRESENT	0
579519	578180	14219Q	PARTICIPANT	\N	PRESENT	0
579520	578180	11099A	PARTICIPANT	\N	PRESENT	0
579521	578180	20108W	PARTICIPANT	\N	PRESENT	0
579522	578180	18083K	PARTICIPANT	\N	PRESENT	0
579523	578180	20076G	PARTICIPANT	\N	PRESENT	0
579524	578180	04085P	PARTICIPANT	\N	PRESENT	0
579525	578180	19758L	PARTICIPANT	\N	PRESENT	0
579526	578180	19301E	PARTICIPANT	\N	PRESENT	0
579527	578180	17367Q	PARTICIPANT	\N	PRESENT	0
579528	578180	20094J	PARTICIPANT	\N	PRESENT	0
579529	578180	19691J	PARTICIPANT	\N	PRESENT	0
579530	578180	20152B	PARTICIPANT	\N	PRESENT	0
579531	578180	20130U	PARTICIPANT	\N	PRESENT	0
579532	578180	14055N	PARTICIPANT	\N	PRESENT	0
579533	578180	20034V	PARTICIPANT	\N	PRESENT	0
579534	578180	14038Y	PARTICIPANT	\N	PRESENT	0
579535	578180	14217N	PARTICIPANT	\N	PRESENT	0
579536	578180	14001X	PARTICIPANT	\N	PRESENT	0
579537	578180	11097X	PARTICIPANT	\N	PRESENT	0
579538	578180	14215L	PARTICIPANT	\N	PRESENT	0
579539	578180	19545Y	PARTICIPANT	\N	PRESENT	0
579541	578180	20100N	PARTICIPANT	\N	PRESENT	0
579542	578180	11043H	PARTICIPANT	\N	PRESENT	0
579543	578180	11090Q	PARTICIPANT	\N	PRESENT	0
579544	578180	19335Q	PARTICIPANT	\N	PRESENT	0
579545	578180	11056N	PARTICIPANT	\N	PRESENT	0
579508	578180	19719D	PARTICIPANT	\N	PRESENT	0
579509	578180	14231L	PARTICIPANT	\N	PRESENT	0
579546	578180	17023S	PARTICIPANT	\N	PRESENT	0
579547	578180	07029T	PARTICIPANT	\N	PRESENT	0
579548	578180	14357A	PARTICIPANT	\N	PRESENT	0
579550	578180	19711U	PARTICIPANT	\N	PRESENT	0
579551	578180	20068G	PARTICIPANT	\N	PRESENT	0
579552	578180	08010L	PARTICIPANT	\N	PRESENT	0
579553	578180	20046A	PARTICIPANT	\N	PRESENT	0
579554	578180	20098N	PARTICIPANT	\N	PRESENT	0
579555	578180	20124W	PARTICIPANT	\N	PRESENT	0
579556	578180	20086J	PARTICIPANT	\N	PRESENT	0
579561	578180	19717B	PARTICIPANT	\N	PRESENT	0
616084	616083	14225N	PARTICIPANT	\N	PRESENT	0
616086	616083	14151M	PARTICIPANT	\N	PRESENT	0
616087	616083	14257W	PARTICIPANT	\N	PRESENT	0
616088	616083	12041X	PARTICIPANT	\N	PRESENT	0
616089	616083	07033P	PARTICIPANT	\N	PRESENT	0
616090	616083	11026G	PARTICIPANT	\N	PRESENT	0
616091	616083	95063L	PARTICIPANT	\N	PRESENT	0
616411	616386	14026U	PARTICIPANT	\N	PRESENT	0
616412	616386	14187A	PARTICIPANT	\N	PRESENT	0
616413	616386	19387D	PARTICIPANT	\N	PRESENT	0
616414	616386	19631V	PARTICIPANT	\N	PRESENT	0
616415	616386	19637C	PARTICIPANT	\N	PRESENT	0
616416	616386	19585H	PARTICIPANT	\N	PRESENT	0
616417	616386	14038Y	PARTICIPANT	\N	PRESENT	0
616418	616386	19701S	PARTICIPANT	\N	PRESENT	0
616419	616386	19689Q	PARTICIPANT	\N	PRESENT	0
616420	616386	11077T	PARTICIPANT	\N	PRESENT	0
616421	616386	14205J	PARTICIPANT	\N	PRESENT	0
616422	616386	20088L	PARTICIPANT	\N	PRESENT	0
616423	616386	19671E	PARTICIPANT	\N	PRESENT	0
616424	616386	14189C	PARTICIPANT	\N	PRESENT	0
616425	616386	20028X	PARTICIPANT	\N	PRESENT	0
616426	616386	11115U	PARTICIPANT	\N	PRESENT	0
616427	616386	20090E	PARTICIPANT	\N	PRESENT	0
616428	616386	20172F	PARTICIPANT	\N	PRESENT	0
616429	616386	14237S	PARTICIPANT	\N	PRESENT	0
616430	616386	20086J	PARTICIPANT	\N	PRESENT	0
616432	616386	19565D	PARTICIPANT	\N	PRESENT	0
616433	616386	18193Q	PARTICIPANT	\N	PRESENT	0
616434	616386	20022R	PARTICIPANT	\N	PRESENT	0
616435	616386	11053K	PARTICIPANT	\N	PRESENT	0
616436	616386	19611R	PARTICIPANT	\N	PRESENT	0
616437	616386	12028B	PARTICIPANT	\N	PRESENT	0
616438	616386	20024T	PARTICIPANT	\N	PRESENT	0
616439	616386	20072C	PARTICIPANT	\N	PRESENT	0
616440	616386	08028W	PARTICIPANT	\N	PRESENT	0
616441	616386	19729F	PARTICIPANT	\N	PRESENT	0
616442	616386	20286Q	PARTICIPANT	\N	PRESENT	0
616443	616386	20052X	PARTICIPANT	\N	PRESENT	0
616444	616386	19760E	PARTICIPANT	\N	PRESENT	0
616445	616386	19569H	PARTICIPANT	\N	PRESENT	0
616446	616386	20032T	PARTICIPANT	\N	PRESENT	0
616450	616386	11090Q	PARTICIPANT	\N	PRESENT	0
616451	616386	19515S	PARTICIPANT	\N	PRESENT	0
616452	616386	20054A	PARTICIPANT	\N	PRESENT	0
616457	616386	19687N	PARTICIPANT	\N	PRESENT	0
616458	616386	08061X	PARTICIPANT	\N	PRESENT	0
616461	616386	14031R	PARTICIPANT	\N	PRESENT	0
616464	616386	14107H	PARTICIPANT	\N	PRESENT	0
616467	616386	19782L	PARTICIPANT	\N	PRESENT	0
616469	616386	99004R	PARTICIPANT	\N	PRESENT	0
616470	616305	19467C	PARTICIPANT	\N	PRESENT	0
616471	616305	01062T	PARTICIPANT	\N	PRESENT	0
616472	616305	19301E	PARTICIPANT	\N	PRESENT	0
616473	616305	14221J	PARTICIPANT	\N	PRESENT	0
616474	616305	19723Y	PARTICIPANT	\N	PRESENT	0
616475	616305	11031D	PARTICIPANT	\N	PRESENT	0
616476	616305	19703U	PARTICIPANT	\N	PRESENT	0
616477	616305	19553Y	PARTICIPANT	\N	PRESENT	0
616478	616305	20062A	PARTICIPANT	\N	PRESENT	0
616479	616305	19735D	PARTICIPANT	\N	PRESENT	0
616480	616305	14147R	PARTICIPANT	\N	PRESENT	0
616481	616305	19683J	PRESIDENT	0	PRESENT	0
616482	616305	10006L	PARTICIPANT	\N	PRESENT	0
616483	616305	20130U	PARTICIPANT	\N	PRESENT	0
616484	616305	04092N	PARTICIPANT	\N	EXCUSE	0
616485	616305	19295A	PARTICIPANT	\N	EXCUSE	0
616493	616386	19563B	PARTICIPANT	\N	PRESENT	0
616499	616386	19679N	PARTICIPANT	\N	PRESENT	0
616501	616386	19441R	PARTICIPANT	\N	PRESENT	0
616502	616386	20056C	PARTICIPANT	\N	PRESENT	0
616503	616386	11101A	PARTICIPANT	\N	PRESENT	0
616505	616386	20026V	PARTICIPANT	\N	PRESENT	0
616506	616386	19954N	PARTICIPANT	\N	PRESENT	0
616507	616386	19507S	PARTICIPANT	\N	PRESENT	0
616508	616386	14105F	PARTICIPANT	\N	PRESENT	0
616509	616386	20180F	PARTICIPANT	\N	PRESENT	0
616511	616386	14331P	PARTICIPANT	\N	PRESENT	0
616512	616386	14069U	PARTICIPANT	\N	PRESENT	0
616513	616386	18083K	PARTICIPANT	\N	PRESENT	0
616516	616386	08015R	PARTICIPANT	\N	PRESENT	0
616517	616386	19443T	PARTICIPANT	\N	PRESENT	0
616518	616386	14357A	PARTICIPANT	\N	PRESENT	0
616519	616386	20108W	PARTICIPANT	\N	PRESENT	0
616525	616386	20174H	PARTICIPANT	\N	PRESENT	0
616526	616386	19479G	PARTICIPANT	\N	PRESENT	0
616529	616386	19593H	PARTICIPANT	\N	PRESENT	0
616530	616386	14083S	PARTICIPANT	\N	PRESENT	0
616531	616386	20066E	PARTICIPANT	\N	PRESENT	0
616532	616386	19745F	PARTICIPANT	\N	PRESENT	0
616533	616386	14042U	PARTICIPANT	\N	PRESENT	0
616534	616386	19333N	PARTICIPANT	\N	PRESENT	0
616535	616386	20248J	PARTICIPANT	\N	PRESENT	0
616536	616386	14055N	PARTICIPANT	\N	PRESENT	0
616537	616386	11026G	PARTICIPANT	\N	PRESENT	0
616538	616386	14147R	PARTICIPANT	\N	PRESENT	0
616539	616386	20132W	PARTICIPANT	\N	PRESENT	0
616595	616387	20108W	PARTICIPANT	\N	PRESENT	0
616596	616387	19729F	PARTICIPANT	\N	PRESENT	0
616597	616387	17737W	PARTICIPANT	\N	PRESENT	0
616598	616387	20024T	PARTICIPANT	\N	PRESENT	0
616599	616387	19954N	PARTICIPANT	\N	PRESENT	0
616600	616387	20110Q	PARTICIPANT	\N	PRESENT	0
616601	616387	19543W	PARTICIPANT	\N	PRESENT	0
616602	616387	11026G	PARTICIPANT	\N	PRESENT	0
616603	616387	04085P	PARTICIPANT	\N	PRESENT	0
616604	616387	20132W	PARTICIPANT	\N	PRESENT	0
616605	616387	01028R	PARTICIPANT	\N	PRESENT	0
616606	616387	19671E	PARTICIPANT	\N	PRESENT	0
616607	616387	14151M	PARTICIPANT	\N	PRESENT	0
616608	616387	11115U	PARTICIPANT	\N	PRESENT	0
616609	616387	11077T	PARTICIPANT	\N	PRESENT	0
616610	616387	19333N	PARTICIPANT	\N	PRESENT	0
616611	616387	19782L	PARTICIPANT	\N	PRESENT	0
616612	616387	19745F	PARTICIPANT	\N	PRESENT	0
616613	616387	14083S	PARTICIPANT	\N	PRESENT	0
616614	616387	14205J	PARTICIPANT	\N	PRESENT	0
616615	616387	14189C	PARTICIPANT	\N	PRESENT	0
616616	616387	20286Q	PARTICIPANT	\N	PRESENT	0
616617	616387	14042U	PARTICIPANT	\N	PRESENT	0
616618	616387	11053K	PARTICIPANT	\N	PRESENT	0
616619	616387	20066E	PARTICIPANT	\N	PRESENT	0
616620	616387	19563B	PARTICIPANT	\N	PRESENT	0
616621	616387	19387D	PARTICIPANT	\N	PRESENT	0
616622	616387	20174H	PARTICIPANT	\N	PRESENT	0
616623	616387	19441R	PARTICIPANT	\N	PRESENT	0
616624	616387	19479G	PARTICIPANT	\N	PRESENT	0
616625	616387	11033F	PARTICIPANT	\N	PRESENT	0
616626	616387	20248J	PARTICIPANT	\N	PRESENT	0
616627	616387	20054A	PARTICIPANT	\N	PRESENT	0
616628	616387	20090E	PARTICIPANT	\N	PRESENT	0
616629	616387	11090Q	PARTICIPANT	\N	PRESENT	0
616630	616387	14357A	PARTICIPANT	\N	PRESENT	0
616631	616387	19515S	PARTICIPANT	\N	PRESENT	0
616632	616387	19383Y	PARTICIPANT	\N	PRESENT	0
616633	616387	18083K	PARTICIPANT	\N	PRESENT	0
616634	616387	14257W	PARTICIPANT	\N	PRESENT	0
616635	616387	14038Y	PARTICIPANT	\N	PRESENT	0
616636	616387	99004R	PARTICIPANT	\N	PRESENT	0
616637	616387	19679N	PARTICIPANT	\N	PRESENT	0
616638	616387	20128B	PARTICIPANT	\N	PRESENT	0
616639	616387	19593H	PARTICIPANT	\N	PRESENT	0
616640	616387	20180F	PARTICIPANT	\N	PRESENT	0
616641	616387	14133K	PARTICIPANT	\N	PRESENT	0
616642	616387	20028X	PARTICIPANT	\N	PRESENT	0
616643	616387	14073Q	PARTICIPANT	\N	PRESENT	0
616644	616387	19549D	PARTICIPANT	\N	PRESENT	0
616645	616387	14221J	PARTICIPANT	\N	PRESENT	0
616646	616387	08028W	PARTICIPANT	\N	PRESENT	0
616647	616387	17637T	PARTICIPANT	\N	PRESENT	0
616593	616387	14026U	PARTICIPANT	\N	PRESENT	0
616594	616387	14055N	PARTICIPANT	\N	PRESENT	0
616648	616387	19503N	PARTICIPANT	\N	PRESENT	0
616649	616387	11067R	PARTICIPANT	\N	PRESENT	0
616650	616387	01024M	PARTICIPANT	\N	PRESENT	0
616651	616387	14217N	PARTICIPANT	\N	PRESENT	0
616652	616387	14033T	PARTICIPANT	\N	PRESENT	0
616653	616387	20152B	PARTICIPANT	\N	PRESENT	0
616654	616387	08061X	PARTICIPANT	\N	PRESENT	0
616655	616387	01058X	PARTICIPANT	\N	PRESENT	0
616656	616387	14219Q	PARTICIPANT	\N	PRESENT	0
605994	603150	14083S	PARTICIPANT	\N	PRESENT	0
605995	603150	20100N	PARTICIPANT	\N	PRESENT	0
605996	603150	14105F	PARTICIPANT	\N	PRESENT	0
605997	603150	20070A	PARTICIPANT	\N	PRESENT	0
605998	603150	20062A	PARTICIPANT	\N	PRESENT	0
605999	603150	14225N	PARTICIPANT	\N	PRESENT	0
606000	603150	20116W	PARTICIPANT	\N	PRESENT	0
606001	603150	08010L	PARTICIPANT	\N	PRESENT	0
606002	603150	20114U	PARTICIPANT	\N	PRESENT	0
606003	603150	08034U	PARTICIPANT	\N	PRESENT	0
606004	602969	14133K	PARTICIPANT	\N	PRESENT	0
606005	602969	14357A	PARTICIPANT	\N	PRESENT	0
606006	602969	14331P	PRESIDENT	0	PRESENT	0
606007	602969	10015M	PARTICIPANT	\N	PRESENT	0
606008	602969	04045F	PARTICIPANT	\N	PRESENT	0
606009	602969	11026G	PARTICIPANT	\N	PRESENT	0
606010	602969	14097Y	PARTICIPANT	\N	PRESENT	0
606011	602969	14189C	PARTICIPANT	\N	EXCUSE	0
606012	602969	08018U	PARTICIPANT	\N	EXCUSE	0
606013	602969	04057K	PARTICIPANT	\N	EXCUSE	0
606014	602969	19701S	PARTICIPANT	\N	EXCUSE	0
606015	602969	17737W	PARTICIPANT	\N	PRESENT	0
606016	602969	19441R	PARTICIPANT	\N	PRESENT	0
606017	602969	19711U	PARTICIPANT	\N	PRESENT	0
606018	602969	14033T	PARTICIPANT	\N	PRESENT	0
606019	602969	19563B	PARTICIPANT	\N	PRESENT	0
606038	602969	14073Q	PARTICIPANT	\N	PRESENT	0
606066	601484	14189C	PARTICIPANT	\N	EXCUSE	0
606068	601484	20024T	PARTICIPANT	\N	PRESENT	0
606070	601484	14030Q	PRESIDENT	0	PRESENT	0
606073	601484	20114U	PARTICIPANT	\N	PRESENT	0
606074	601484	20080C	PARTICIPANT	\N	EXCUSE	0
606076	601484	11031D	PARTICIPANT	\N	PRESENT	0
606078	601484	20106U	PARTICIPANT	\N	EXCUSE	0
606079	601484	20066E	PARTICIPANT	\N	PRESENT	0
606082	601484	14109K	PARTICIPANT	\N	EXCUSE	0
606083	601484	20118Y	PARTICIPANT	\N	EXCUSE	0
606085	601484	20130U	PARTICIPANT	\N	PRESENT	0
606087	601484	19798U	PARTICIPANT	\N	PRESENT	0
606088	601484	11045K	PARTICIPANT	\N	PRESENT	0
606091	601484	20046A	PARTICIPANT	\N	PRESENT	0
606224	606223	19629C	PARTICIPANT	\N	PRESENT	0
606413	606411	11083R	PARTICIPANT	\N	PRESENT	0
606414	606411	14001X	PARTICIPANT	\N	PRESENT	0
606415	606411	14331P	PRESIDENT	0	PRESENT	0
606416	606411	14073Q	PARTICIPANT	\N	PRESENT	0
606417	606411	19441R	PARTICIPANT	\N	PRESENT	0
606418	606411	20100N	PARTICIPANT	\N	PRESENT	0
606419	606411	12041X	PARTICIPANT	\N	PRESENT	0
606434	606433	14073Q	PARTICIPANT	\N	PRESENT	0
606435	606432	14073Q	PARTICIPANT	\N	PRESENT	0
606438	603144	14327T	PARTICIPANT	\N	PRESENT	0
606439	603144	11048N	PARTICIPANT	\N	PRESENT	0
606440	603144	19711U	PARTICIPANT	\N	PRESENT	0
606441	603144	01057W	PARTICIPANT	\N	PRESENT	0
606442	603144	11053K	PARTICIPANT	\N	PRESENT	0
606443	603144	20080C	PARTICIPANT	\N	PRESENT	0
606444	603144	19667J	PARTICIPANT	\N	PRESENT	0
606445	603144	20044X	PARTICIPANT	\N	PRESENT	0
606446	603144	14225N	PRESIDENT	0	PRESENT	0
606447	603144	11040E	PARTICIPANT	\N	PRESENT	0
606448	603144	07029T	PARTICIPANT	\N	PRESENT	0
606449	603144	20252E	PARTICIPANT	\N	PRESENT	0
606450	603144	19349W	PARTICIPANT	\N	PRESENT	0
606451	603144	08009T	PARTICIPANT	\N	EXCUSE	0
606452	603144	20050V	PARTICIPANT	\N	EXCUSE	0
606453	603144	11074Q	PARTICIPANT	\N	EXCUSE	0
606454	603144	12016W	PARTICIPANT	\N	PRESENT	0
606455	603144	20070A	PARTICIPANT	\N	PRESENT	0
606456	603144	08010L	PARTICIPANT	\N	PRESENT	0
606457	603144	19479G	PARTICIPANT	\N	PRESENT	0
606458	603144	19689Q	PARTICIPANT	\N	PRESENT	0
606459	603144	14083S	PARTICIPANT	\N	PRESENT	0
606460	603144	99004R	PARTICIPANT	\N	PRESENT	0
606461	603144	19545Y	PARTICIPANT	\N	PRESENT	0
607125	606808	20044X	PARTICIPANT	\N	EXCUSE	0
607178	606896	20104S	PARTICIPANT	\N	PRESENT	0
607179	606896	20180F	PARTICIPANT	\N	PRESENT	0
607232	606426	11109J	PARTICIPANT	\N	EXCUSE	0
607233	606426	20042V	PARTICIPANT	\N	PRESENT	0
607488	606407	11026G	PARTICIPANT	\N	PRESENT	0
607514	606428	04070G	PARTICIPANT	\N	PRESENT	0
607515	606428	20098N	PARTICIPANT	\N	PRESENT	0
607516	606428	20134Y	PARTICIPANT	\N	PRESENT	0
607517	606428	14073Q	PARTICIPANT	\N	PRESENT	0
607518	606428	20052X	PARTICIPANT	\N	PRESENT	0
607519	606428	19057M	PARTICIPANT	\N	PRESENT	0
607531	606855	19768N	PARTICIPANT	\N	PRESENT	0
607532	606855	19515S	PARTICIPANT	\N	PRESENT	0
607533	606855	11077T	PARTICIPANT	\N	PRESENT	0
607534	606855	19782L	PARTICIPANT	\N	PRESENT	0
607535	606855	20092G	PARTICIPANT	\N	PRESENT	0
607536	606855	01043Q	PARTICIPANT	\N	PRESENT	0
607537	606855	14357A	PARTICIPANT	\N	PRESENT	0
607538	606855	19441R	PARTICIPANT	\N	PRESENT	0
607539	606855	20078J	PARTICIPANT	\N	PRESENT	0
607540	606855	19413M	PARTICIPANT	\N	PRESENT	0
607541	606855	20082E	PARTICIPANT	\N	PRESENT	0
607542	606855	20094J	PARTICIPANT	\N	PRESENT	0
607543	606855	04045F	PARTICIPANT	\N	PRESENT	0
607544	606855	19866P	PARTICIPANT	\N	PRESENT	0
607545	606855	19631V	PARTICIPANT	\N	PRESENT	0
607546	606855	20104S	PARTICIPANT	\N	PRESENT	0
607547	606855	11099A	PARTICIPANT	\N	PRESENT	0
607548	606855	19707Y	PARTICIPANT	\N	PRESENT	0
607549	606855	08015R	PARTICIPANT	\N	PRESENT	0
607550	606855	19575F	PARTICIPANT	\N	PRESENT	0
607551	606855	19369B	PARTICIPANT	\N	PRESENT	0
607552	606855	20018V	PARTICIPANT	\N	PRESENT	0
607553	606855	19511N	PARTICIPANT	\N	PRESENT	0
607554	606855	08028W	PARTICIPANT	\N	PRESENT	0
607555	606855	19563B	PARTICIPANT	\N	PRESENT	0
607556	606855	20028X	PARTICIPANT	\N	PRESENT	0
607557	606855	14329V	PARTICIPANT	\N	PRESENT	0
607558	606855	14038Y	PARTICIPANT	\N	PRESENT	0
607559	606855	19467C	PARTICIPANT	\N	PRESENT	0
607560	606855	14187A	PARTICIPANT	\N	PRESENT	0
607561	606855	20144B	PARTICIPANT	\N	PRESENT	0
607562	606855	01025N	PARTICIPANT	\N	PRESENT	0
607563	606855	11090Q	PRESIDENT	0	PRESENT	0
607564	606855	14033T	PARTICIPANT	\N	PRESENT	0
607565	606855	20054A	PARTICIPANT	\N	PRESENT	0
607566	606855	20174H	PARTICIPANT	\N	PRESENT	0
607567	606855	14205J	PARTICIPANT	\N	PRESENT	0
607568	606855	20060X	PARTICIPANT	\N	PRESENT	0
607569	606855	20062A	PARTICIPANT	\N	PRESENT	0
607570	606855	14251Q	PARTICIPANT	\N	PRESENT	0
607571	606855	19507S	PARTICIPANT	\N	PRESENT	0
607572	606855	19747H	PARTICIPANT	\N	PRESENT	0
607573	606855	14207L	PARTICIPANT	\N	PRESENT	0
607574	606855	14257W	PARTICIPANT	\N	PRESENT	0
607595	607213	20024T	PARTICIPANT	\N	PRESENT	0
607596	607213	20068G	PARTICIPANT	\N	PRESENT	0
607599	607213	20062A	PARTICIPANT	\N	PRESENT	0
607600	607213	14105F	PARTICIPANT	\N	PRESENT	0
607602	607213	12016W	PARTICIPANT	\N	PRESENT	0
607603	607213	11104D	PARTICIPANT	\N	PRESENT	0
607604	607213	20266L	PARTICIPANT	\N	PRESENT	0
607605	607213	19057M	PARTICIPANT	\N	PRESENT	0
607606	607213	19681G	PARTICIPANT	\N	PRESENT	0
607607	607213	19511N	PARTICIPANT	\N	PRESENT	0
607608	607213	86034E	PARTICIPANT	\N	PRESENT	0
607609	607213	19669L	PARTICIPANT	\N	PRESENT	0
607610	607213	11066Q	PARTICIPANT	\N	PRESENT	0
607611	607213	20028X	PARTICIPANT	\N	PRESENT	0
607612	607213	19687N	PARTICIPANT	\N	PRESENT	0
607613	607213	12041X	PARTICIPANT	\N	PRESENT	0
607614	607213	14109K	PARTICIPANT	\N	PRESENT	0
607615	607213	19251M	PARTICIPANT	\N	PRESENT	0
607616	607213	19866P	PARTICIPANT	\N	PRESENT	0
607617	607213	14207L	PARTICIPANT	\N	PRESENT	0
607618	607213	14107H	PARTICIPANT	\N	PRESENT	0
607619	607213	11012A	PARTICIPANT	\N	PRESENT	0
607620	607213	20072C	PARTICIPANT	\N	PRESENT	0
607621	607213	19611R	PARTICIPANT	\N	PRESENT	0
607622	607213	19479G	PARTICIPANT	\N	PRESENT	0
607623	607213	14221J	PARTICIPANT	\N	PRESENT	0
607624	607213	14111D	PARTICIPANT	\N	PRESENT	0
609167	608514	19549D	PARTICIPANT	\N	PRESENT	0
609168	608514	11077T	PARTICIPANT	\N	PRESENT	0
609170	608514	01024M	PARTICIPANT	\N	PRESENT	0
609171	608514	14205J	PARTICIPANT	\N	PRESENT	0
609182	608514	11012A	PARTICIPANT	\N	PRESENT	0
609183	608514	19760E	PARTICIPANT	\N	PRESENT	0
609184	608514	19629C	PARTICIPANT	\N	PRESENT	0
609185	608514	20100N	PARTICIPANT	\N	PRESENT	0
609186	608514	10006L	PARTICIPANT	\N	PRESENT	0
609187	608514	19703U	PARTICIPANT	\N	PRESENT	0
609188	608514	20026V	PARTICIPANT	\N	PRESENT	0
609189	608514	20024T	PARTICIPANT	\N	PRESENT	0
609190	608514	14069U	PARTICIPANT	\N	PRESENT	0
609191	608514	11085T	PARTICIPANT	\N	PRESENT	0
609192	608514	20052X	PARTICIPANT	\N	PRESENT	0
609193	608514	19569H	PARTICIPANT	\N	PRESENT	0
609194	608514	19413M	PARTICIPANT	\N	PRESENT	0
609195	608514	20094J	PARTICIPANT	\N	PRESENT	0
609196	608514	19533U	PARTICIPANT	\N	PRESENT	0
609197	608514	11115U	PARTICIPANT	\N	PRESENT	0
609198	608514	19701S	PARTICIPANT	\N	PRESENT	0
609199	608514	19565D	PARTICIPANT	\N	PRESENT	0
609200	608514	14030Q	PARTICIPANT	\N	PRESENT	0
609201	608514	20102Q	PARTICIPANT	\N	PRESENT	0
609202	608514	19749K	PARTICIPANT	\N	PRESENT	0
609203	608514	19563B	PARTICIPANT	\N	PRESENT	0
609235	608515	19629C	PARTICIPANT	\N	PRESENT	0
609236	608515	19749K	PARTICIPANT	\N	PRESENT	0
609237	608515	04008A	PARTICIPANT	\N	PRESENT	0
609238	608515	14053L	PARTICIPANT	\N	PRESENT	0
609239	608515	20266L	PARTICIPANT	\N	PRESENT	0
609240	608515	19760E	PARTICIPANT	\N	PRESENT	0
609241	608515	04085P	PARTICIPANT	\N	PRESENT	0
609242	608515	20102Q	PARTICIPANT	\N	PRESENT	0
609243	608515	19447X	PARTICIPANT	\N	PRESENT	0
609244	608515	19565D	PARTICIPANT	\N	PRESENT	0
609245	608515	19563B	PARTICIPANT	\N	PRESENT	0
609246	608515	19585H	PARTICIPANT	\N	PRESENT	0
609247	608515	14021P	PARTICIPANT	\N	PRESENT	0
609248	608515	01028R	PARTICIPANT	\N	PRESENT	0
609249	608515	20134Y	PARTICIPANT	\N	PRESENT	0
609250	608515	08010L	PARTICIPANT	\N	PRESENT	0
609251	608515	19719D	PARTICIPANT	\N	PRESENT	0
609252	608515	19599P	PARTICIPANT	\N	PRESENT	0
609253	608515	20032T	PARTICIPANT	\N	PRESENT	0
609254	608515	20052X	PARTICIPANT	\N	PRESENT	0
609255	608515	14147R	PARTICIPANT	\N	PRESENT	0
609256	608515	17637T	PARTICIPANT	\N	PRESENT	0
609257	608515	11056N	PARTICIPANT	\N	PRESENT	0
609258	608515	20082E	PARTICIPANT	\N	PRESENT	0
609259	608515	14033T	PARTICIPANT	\N	PRESENT	0
609233	608515	99004R	PARTICIPANT	\N	PRESENT	0
609234	608515	14151M	PARTICIPANT	\N	PRESENT	0
609260	608515	04047H	PARTICIPANT	\N	PRESENT	0
609261	608515	07029T	PARTICIPANT	\N	PRESENT	0
609262	608515	18083K	PARTICIPANT	\N	PRESENT	0
609263	608515	14071N	PARTICIPANT	\N	PRESENT	0
610742	610740	05008E	PARTICIPANT	\N	EXCUSE	0
610743	610740	19715Y	PARTICIPANT	\N	EXCUSE	0
610744	610741	05008E	PARTICIPANT	\N	EXCUSE	0
610745	610741	19715Y	PARTICIPANT	\N	EXCUSE	0
610889	610669	14053L	PARTICIPANT	\N	PRESENT	0
610890	610669	19729F	PARTICIPANT	\N	EXCUSE	0
610891	610669	11026G	PARTICIPANT	\N	PRESENT	0
610892	610669	14001X	PARTICIPANT	\N	PRESENT	0
610893	610669	14147R	PARTICIPANT	\N	PRESENT	0
610894	610669	20022R	PARTICIPANT	\N	PRESENT	0
610895	610669	11072N	PARTICIPANT	\N	PRESENT	0
610896	610669	20074E	PARTICIPANT	\N	PRESENT	0
610897	610669	10015M	PARTICIPANT	\N	PRESENT	0
610898	610669	19725B	PARTICIPANT	\N	PRESENT	0
610899	610669	14089Y	PARTICIPANT	\N	PRESENT	0
610906	610669	04047H	PRESIDENT	0	PRESENT	0
610924	610669	01028R	PARTICIPANT	\N	PRESENT	0
610926	610669	14151M	PARTICIPANT	\N	PRESENT	0
610944	610669	14111D	PARTICIPANT	\N	PRESENT	0
612880	612877	08073C	PARTICIPANT	\N	PRESENT	0
612881	612877	20150Y	PARTICIPANT	\N	PRESENT	0
613859	613858	20022R	PARTICIPANT	\N	PRESENT	0
613860	613858	19575F	PARTICIPANT	\N	PRESENT	0
613861	613858	14105F	PARTICIPANT	\N	PRESENT	0
613862	613858	19782L	PARTICIPANT	\N	PRESENT	0
613863	613858	20090E	PARTICIPANT	\N	PRESENT	0
613864	613858	01024M	PARTICIPANT	\N	PRESENT	0
613865	613858	01025N	PARTICIPANT	\N	PRESENT	0
613866	613858	20132W	PARTICIPANT	\N	PRESENT	0
613867	613858	08056B	PARTICIPANT	\N	PRESENT	0
613868	613858	20126Y	PARTICIPANT	\N	PRESENT	0
613869	613858	19723Y	PARTICIPANT	\N	PRESENT	0
613870	613858	08015R	PARTICIPANT	\N	PRESENT	0
613871	613858	20028X	PARTICIPANT	\N	PRESENT	0
613872	613858	19745F	PARTICIPANT	\N	PRESENT	0
613873	613858	11097X	PARTICIPANT	\N	PRESENT	0
613874	613858	04045F	PARTICIPANT	\N	PRESENT	0
616379	616378	19629C	PARTICIPANT	\N	PRESENT	0
616380	616378	14038Y	PARTICIPANT	\N	PRESENT	0
616381	616378	04047H	PARTICIPANT	\N	PRESENT	0
616382	616378	20092G	PARTICIPANT	\N	PRESENT	0
616383	616378	14147R	PARTICIPANT	\N	PRESENT	0
618375	618374	08009T	PARTICIPANT	\N	PRESENT	0
618376	618374	20044X	PARTICIPANT	\N	PRESENT	0
620745	618091	20128B	PARTICIPANT	\N	PRESENT	0
620746	618091	14042U	PARTICIPANT	\N	PRESENT	0
620747	618091	20142Y	PARTICIPANT	\N	PRESENT	0
620748	618091	04042C	PARTICIPANT	\N	PRESENT	0
620749	618091	04059M	PARTICIPANT	\N	PRESENT	0
620750	618091	11110B	PARTICIPANT	\N	PRESENT	0
620751	618091	14089Y	PARTICIPANT	\N	PRESENT	0
620752	618091	04045F	PARTICIPANT	\N	PRESENT	0
620753	618091	04085P	PARTICIPANT	\N	PRESENT	0
620754	618091	20114U	PARTICIPANT	\N	PRESENT	0
620755	618091	14055N	PARTICIPANT	\N	PRESENT	0
620756	618091	20064C	PARTICIPANT	\N	PRESENT	0
620757	618091	14021P	PARTICIPANT	\N	PRESENT	0
620758	618091	20106U	PARTICIPANT	\N	PRESENT	0
620759	618091	04035D	PARTICIPANT	\N	PRESENT	0
620760	618091	19531S	PARTICIPANT	\N	PRESENT	0
620761	618091	11048N	PARTICIPANT	\N	PRESENT	0
620762	618091	19866P	PARTICIPANT	\N	PRESENT	0
620763	618091	19515S	PARTICIPANT	\N	PRESENT	0
620764	618091	19619A	PARTICIPANT	\N	PRESENT	0
620765	618091	14225N	PARTICIPANT	\N	PRESENT	0
620766	618091	20144B	PARTICIPANT	\N	PRESENT	0
620887	618092	86034E	PARTICIPANT	\N	PRESENT	0
620890	618092	05008E	PARTICIPANT	\N	PRESENT	0
620891	618092	04047H	PARTICIPANT	\N	PRESENT	0
620892	618092	14217N	PARTICIPANT	\N	PRESENT	0
620893	618092	10006L	PARTICIPANT	\N	PRESENT	0
620894	618092	14030Q	PARTICIPANT	\N	PRESENT	0
620895	618092	14275Y	PARTICIPANT	\N	PRESENT	0
620896	618092	11033F	PARTICIPANT	\N	PRESENT	0
620897	618092	19301E	PARTICIPANT	\N	PRESENT	0
620898	618092	20130U	PARTICIPANT	\N	PRESENT	0
620899	618092	20110Q	PARTICIPANT	\N	PRESENT	0
620900	618092	20134Y	PARTICIPANT	\N	PRESENT	0
620901	618092	20036X	PARTICIPANT	\N	PRESENT	0
620902	618092	14001X	PARTICIPANT	\N	PRESENT	0
620903	618092	19525U	PARTICIPANT	\N	PRESENT	0
620904	618092	19651A	PARTICIPANT	\N	PRESENT	0
620905	618092	19683J	PARTICIPANT	\N	PRESENT	0
620906	618092	19527W	PARTICIPANT	\N	PRESENT	0
620907	618092	14021P	PARTICIPANT	\N	PRESENT	0
620908	618092	14151M	PARTICIPANT	\N	PRESENT	0
620909	618092	19649G	PARTICIPANT	\N	PRESENT	0
620910	618092	20286Q	PARTICIPANT	\N	PRESENT	0
620911	618092	20028X	PARTICIPANT	\N	PRESENT	0
620912	618092	14055N	PARTICIPANT	\N	PRESENT	0
620913	618092	14329V	PARTICIPANT	\N	PRESENT	0
620914	618092	19657G	PARTICIPANT	\N	PRESENT	0
620915	618092	07029T	PARTICIPANT	\N	PRESENT	0
620916	618092	14097Y	PARTICIPANT	\N	PRESENT	0
620917	618092	19715Y	PARTICIPANT	\N	PRESENT	0
620918	618092	11027H	PARTICIPANT	\N	PRESENT	0
620919	618092	19647E	PARTICIPANT	\N	PRESENT	0
620920	618092	19489J	PARTICIPANT	\N	PRESENT	0
620921	618092	20084G	PARTICIPANT	\N	PRESENT	0
620922	618092	19413M	PARTICIPANT	\N	PRESENT	0
620923	618092	19531S	PARTICIPANT	\N	PRESENT	0
620924	618092	20064C	PARTICIPANT	\N	PRESENT	0
620925	618092	20080C	PARTICIPANT	\N	PRESENT	0
620926	618092	18193Q	PARTICIPANT	\N	PRESENT	0
601843	601099	14195A	PARTICIPANT	\N	PRESENT	0
601844	601099	11031D	PARTICIPANT	\N	PRESENT	0
601845	601099	20130U	PARTICIPANT	\N	PRESENT	0
601846	601099	18193Q	PARTICIPANT	\N	PRESENT	0
601847	601099	11067R	PARTICIPANT	\N	PRESENT	0
601848	601099	17965H	PARTICIPANT	\N	PRESENT	0
601849	601099	19782L	PARTICIPANT	\N	PRESENT	0
601850	601099	14327T	PARTICIPANT	\N	PRESENT	0
601851	601099	14042U	PARTICIPANT	\N	PRESENT	0
601852	601099	19479G	PARTICIPANT	\N	PRESENT	0
601853	601099	04045F	PARTICIPANT	\N	PRESENT	0
601854	601099	19697Q	PARTICIPANT	\N	PRESENT	0
601855	601099	19569H	PARTICIPANT	\N	PRESENT	0
601856	601099	19415P	PARTICIPANT	\N	PRESENT	0
601857	601099	11097X	PARTICIPANT	\N	PRESENT	0
601858	601099	04092N	PARTICIPANT	\N	PRESENT	0
601859	601099	14071N	PARTICIPANT	\N	PRESENT	0
601860	601099	19301E	PARTICIPANT	\N	PRESENT	0
601861	601099	14207L	PARTICIPANT	\N	PRESENT	0
601862	601099	20072C	PARTICIPANT	\N	PRESENT	0
601863	601099	20090E	PARTICIPANT	\N	PRESENT	0
601864	601099	19447X	PARTICIPANT	\N	PRESENT	0
601865	601099	19663E	PARTICIPANT	\N	PRESENT	0
601866	601099	14223L	PARTICIPANT	\N	PRESENT	0
601867	601099	19683J	PARTICIPANT	\N	PRESENT	0
601868	601099	20248J	PARTICIPANT	\N	PRESENT	0
601869	601099	20062A	PARTICIPANT	\N	PRESENT	0
601870	601099	19367Y	PARTICIPANT	\N	PRESENT	0
601871	601099	20066E	PARTICIPANT	\N	PRESENT	0
601872	601099	20032T	PARTICIPANT	\N	PRESENT	0
601873	601099	14021P	PARTICIPANT	\N	PRESENT	0
601874	601099	19591F	PARTICIPANT	\N	PRESENT	0
601875	601099	10006L	PARTICIPANT	\N	PRESENT	0
601876	601099	12041X	PARTICIPANT	\N	PRESENT	0
601877	601099	19657G	PARTICIPANT	\N	PRESENT	0
601878	601099	20172F	PARTICIPANT	\N	PRESENT	0
601879	601099	19503N	PARTICIPANT	\N	PRESENT	0
601880	601099	19703U	PARTICIPANT	\N	PRESENT	0
601841	601099	99004R	PARTICIPANT	\N	PRESENT	0
601842	601099	14213J	PARTICIPANT	\N	PRESENT	0
601881	601099	19723Y	PARTICIPANT	\N	PRESENT	0
601882	601099	08045X	PARTICIPANT	\N	PRESENT	0
601883	601099	19575F	PARTICIPANT	\N	PRESENT	0
601884	601099	20120S	PARTICIPANT	\N	PRESENT	0
601885	601099	20054A	PARTICIPANT	\N	PRESENT	0
601886	601099	19798U	PARTICIPANT	\N	PRESENT	0
601887	601099	20096L	PARTICIPANT	\N	PRESENT	0
601888	601099	20056C	PARTICIPANT	\N	PRESENT	0
601889	601099	20140W	PARTICIPANT	\N	PRESENT	0
601890	601099	19467C	PARTICIPANT	\N	PRESENT	0
601891	601099	14219Q	PARTICIPANT	\N	PRESENT	0
601892	601099	20026V	PARTICIPANT	\N	PRESENT	0
601893	601099	19679N	PARTICIPANT	\N	PRESENT	0
601894	601099	17779H	PARTICIPANT	\N	PRESENT	0
601895	601099	14083S	PARTICIPANT	\N	PRESENT	0
601896	601099	19747H	PARTICIPANT	\N	PRESENT	0
601897	601099	19741B	PARTICIPANT	\N	PRESENT	0
601898	601099	14217N	PARTICIPANT	\N	PRESENT	0
601899	601099	19735D	PARTICIPANT	\N	PRESENT	0
601900	601099	11012A	PARTICIPANT	\N	PRESENT	0
601901	601099	14033T	PARTICIPANT	\N	PRESENT	0
601902	601099	20180F	PARTICIPANT	\N	PRESENT	0
601903	601099	19760E	PARTICIPANT	\N	PRESENT	0
601904	601099	14187A	PARTICIPANT	\N	PRESENT	0
601905	601099	19758L	PARTICIPANT	\N	PRESENT	0
601906	601099	14026U	PARTICIPANT	\N	PRESENT	0
601907	601099	19553Y	PARTICIPANT	\N	PRESENT	0
601908	601099	19565D	PARTICIPANT	\N	PRESENT	0
601909	601099	20108W	PARTICIPANT	\N	PRESENT	0
601910	601099	19739H	PARTICIPANT	\N	PRESENT	0
601911	601099	20132W	PARTICIPANT	\N	PRESENT	0
601912	601099	07029T	PARTICIPANT	\N	PRESENT	0
601913	601099	19573D	PARTICIPANT	\N	PRESENT	0
601914	601099	19347U	PARTICIPANT	\N	PRESENT	0
601915	601099	19533U	PARTICIPANT	\N	PRESENT	0
601916	601099	19413M	PARTICIPANT	\N	PRESENT	0
601917	601099	18083K	PARTICIPANT	\N	PRESENT	0
601918	601099	20070A	PARTICIPANT	\N	PRESENT	0
601919	601099	14089Y	PARTICIPANT	\N	PRESENT	0
601920	601099	20092G	PARTICIPANT	\N	PRESENT	0
601921	601099	20110Q	PARTICIPANT	\N	PRESENT	0
601922	601099	11048N	PARTICIPANT	\N	PRESENT	0
601923	601099	11077T	PARTICIPANT	\N	PRESENT	0
601924	601099	20082E	PARTICIPANT	\N	PRESENT	0
601925	601099	20048C	PARTICIPANT	\N	PRESENT	0
601926	601099	14069U	PARTICIPANT	\N	PRESENT	0
601927	601099	19715Y	PARTICIPANT	\N	PRESENT	0
601928	601099	01028R	PARTICIPANT	\N	PRESENT	0
601929	601099	14073Q	PARTICIPANT	\N	PRESENT	0
601930	601099	14215L	PARTICIPANT	\N	PRESENT	0
601931	601099	19507S	PARTICIPANT	\N	PRESENT	0
601932	601099	11043H	PARTICIPANT	\N	PRESENT	0
602095	600212	01043Q	PARTICIPANT	\N	PRESENT	0
602096	600212	19441R	PARTICIPANT	\N	PRESENT	0
602097	600212	19413M	PARTICIPANT	\N	PRESENT	0
602098	600212	20082E	PARTICIPANT	\N	PRESENT	0
602099	600212	20094J	PARTICIPANT	\N	PRESENT	0
602100	600212	11099A	PARTICIPANT	\N	PRESENT	0
602101	600212	19705W	PARTICIPANT	\N	PRESENT	0
602102	600212	19707Y	PARTICIPANT	\N	PRESENT	0
602103	600212	08015R	PARTICIPANT	\N	PRESENT	0
602104	600212	19575F	PARTICIPANT	\N	PRESENT	0
602105	600212	19369B	PARTICIPANT	\N	PRESENT	0
602106	600212	20018V	PARTICIPANT	\N	PRESENT	0
602107	600212	19511N	PARTICIPANT	\N	PRESENT	0
602108	600212	19563B	PARTICIPANT	\N	PRESENT	0
602109	600212	14329V	PARTICIPANT	\N	PRESENT	0
602110	600212	20030R	PARTICIPANT	\N	PRESENT	0
602111	600212	14038Y	PARTICIPANT	\N	PRESENT	0
602112	600212	19467C	PARTICIPANT	\N	PRESENT	0
602113	600212	14187A	PARTICIPANT	\N	PRESENT	0
602114	600212	20144B	PARTICIPANT	\N	PRESENT	0
602115	600212	19695N	PARTICIPANT	\N	PRESENT	0
602116	600212	14033T	PARTICIPANT	\N	PRESENT	0
602117	600212	11090Q	PRESIDENT	0	PRESENT	0
602118	600212	01025N	PARTICIPANT	\N	PRESENT	0
602119	600212	20054A	PARTICIPANT	\N	PRESENT	0
602120	600212	20174H	PARTICIPANT	\N	PRESENT	0
602121	600212	14205J	PARTICIPANT	\N	PRESENT	0
602122	600212	20060X	PARTICIPANT	\N	PRESENT	0
602123	600212	20062A	PARTICIPANT	\N	PRESENT	0
602124	600212	14251Q	PARTICIPANT	\N	PRESENT	0
602125	600212	19507S	PARTICIPANT	\N	PRESENT	0
602126	600212	14207L	PARTICIPANT	\N	PRESENT	0
602127	600212	19747H	PARTICIPANT	\N	PRESENT	0
602128	600212	14257W	PARTICIPANT	\N	PRESENT	0
602130	598625	19251M	PARTICIPANT	\N	PRESENT	0
602188	601186	11109J	PARTICIPANT	\N	EXCUSE	0
602189	600825	19697Q	PARTICIPANT	\N	PRESENT	0
602190	600825	19569H	PARTICIPANT	\N	PRESENT	0
602191	600825	18193Q	PARTICIPANT	\N	PRESENT	0
602192	600825	19553Y	PARTICIPANT	\N	PRESENT	0
602193	600825	19663E	PARTICIPANT	\N	PRESENT	0
602194	600825	17965H	PARTICIPANT	\N	PRESENT	0
602195	600825	19301E	PARTICIPANT	\N	PRESENT	0
602196	600825	19723Y	PARTICIPANT	\N	PRESENT	0
602197	600825	19760E	PARTICIPANT	\N	PRESENT	0
602198	600213	20088L	PARTICIPANT	\N	PRESENT	0
602199	600213	19768N	PARTICIPANT	\N	PRESENT	0
602200	600213	19515S	PARTICIPANT	\N	PRESENT	0
602201	600213	20092G	PARTICIPANT	\N	PRESENT	0
602202	600213	19782L	PARTICIPANT	\N	PRESENT	0
602203	600213	11077T	PARTICIPANT	\N	PRESENT	0
602204	600213	01043Q	PARTICIPANT	\N	PRESENT	0
602205	600213	19441R	PARTICIPANT	\N	PRESENT	0
602206	600213	19413M	PARTICIPANT	\N	PRESENT	0
602207	600213	20082E	PARTICIPANT	\N	PRESENT	0
602208	600213	20094J	PARTICIPANT	\N	PRESENT	0
602209	600213	11099A	PARTICIPANT	\N	PRESENT	0
602210	600213	19705W	PARTICIPANT	\N	PRESENT	0
602211	600213	19707Y	PARTICIPANT	\N	PRESENT	0
602212	600213	08015R	PARTICIPANT	\N	PRESENT	0
602213	600213	19575F	PARTICIPANT	\N	PRESENT	0
602214	600213	19369B	PARTICIPANT	\N	PRESENT	0
602215	600213	20018V	PARTICIPANT	\N	PRESENT	0
602216	600213	19511N	PARTICIPANT	\N	PRESENT	0
602217	600213	19563B	PARTICIPANT	\N	PRESENT	0
602218	600213	14329V	PARTICIPANT	\N	PRESENT	0
602219	600213	20030R	PARTICIPANT	\N	PRESENT	0
602220	600213	14038Y	PARTICIPANT	\N	PRESENT	0
599362	597324	14355X	PARTICIPANT	\N	PRESENT	0
599363	597324	20126Y	PARTICIPANT	\N	PRESENT	0
599367	595688	19619A	PARTICIPANT	\N	EXCUSE	0
599386	598117	19383Y	PARTICIPANT	\N	PRESENT	0
599387	598117	19515S	PARTICIPANT	\N	PRESENT	0
599388	598117	19782L	PARTICIPANT	\N	PRESENT	0
599389	598117	11077T	PARTICIPANT	\N	PRESENT	0
599390	598117	20092G	PARTICIPANT	\N	PRESENT	0
599391	598117	14357A	PARTICIPANT	\N	PRESENT	0
599392	598117	20078J	PARTICIPANT	\N	PRESENT	0
599393	598117	19441R	PARTICIPANT	\N	PRESENT	0
599394	598117	19413M	PARTICIPANT	\N	PRESENT	0
599395	598117	20082E	PARTICIPANT	\N	PRESENT	0
599396	598117	20094J	PARTICIPANT	\N	PRESENT	0
599397	598117	19631V	PARTICIPANT	\N	PRESENT	0
599398	598117	11099A	PARTICIPANT	\N	PRESENT	0
599399	598117	08015R	PARTICIPANT	\N	PRESENT	0
599400	598117	19575F	PARTICIPANT	\N	PRESENT	0
599401	598117	19369B	PARTICIPANT	\N	PRESENT	0
599402	598117	20018V	PARTICIPANT	\N	PRESENT	0
599403	598117	19563B	PARTICIPANT	\N	PRESENT	0
599404	598117	20028X	PARTICIPANT	\N	PRESENT	0
599405	598117	14038Y	PARTICIPANT	\N	PRESENT	0
599406	598117	20030R	PARTICIPANT	\N	PRESENT	0
599407	598117	19467C	PARTICIPANT	\N	PRESENT	0
599408	598117	14187A	PARTICIPANT	\N	PRESENT	0
599409	598117	20144B	PARTICIPANT	\N	PRESENT	0
599410	598117	19695N	PARTICIPANT	\N	PRESENT	0
599411	598117	14033T	PARTICIPANT	\N	PRESENT	0
599412	598117	01025N	PARTICIPANT	\N	PRESENT	0
599413	598117	11090Q	PRESIDENT	0	PRESENT	0
599414	598117	20054A	PARTICIPANT	\N	PRESENT	0
599415	598117	20174H	PARTICIPANT	\N	PRESENT	0
599416	598117	14205J	PARTICIPANT	\N	PRESENT	0
599417	598117	20062A	PARTICIPANT	\N	PRESENT	0
599418	598117	14251Q	PARTICIPANT	\N	PRESENT	0
599419	598117	19507S	PARTICIPANT	\N	PRESENT	0
599420	598117	19747H	PARTICIPANT	\N	PRESENT	0
599421	598117	14207L	PARTICIPANT	\N	PRESENT	0
599422	598117	14257W	PARTICIPANT	\N	PRESENT	0
599435	598075	86034E	PARTICIPANT	\N	PRESENT	0
599436	598075	14331P	PARTICIPANT	\N	PRESENT	0
599437	598075	20068G	PARTICIPANT	\N	PRESENT	0
599438	598075	14105F	PARTICIPANT	\N	PRESENT	0
599439	598075	19629C	PARTICIPANT	\N	PRESENT	0
599440	598075	19383Y	PARTICIPANT	\N	PRESENT	0
599441	598075	11077T	PARTICIPANT	\N	PRESENT	0
599442	598075	19565D	PARTICIPANT	\N	PRESENT	0
599443	598075	14173T	PARTICIPANT	\N	PRESENT	0
599444	598075	97011G	PARTICIPANT	\N	PRESENT	0
599445	598075	11027H	PARTICIPANT	\N	PRESENT	0
599446	598075	08060W	PARTICIPANT	\N	PRESENT	0
599447	598075	11080N	PARTICIPANT	\N	PRESENT	0
599448	598075	19866P	PARTICIPANT	\N	PRESENT	0
599449	598075	11101A	PARTICIPANT	\N	PRESENT	0
599450	598075	20024T	PARTICIPANT	\N	PRESENT	0
599451	598075	12028B	PARTICIPANT	\N	PRESENT	0
599452	598075	19399H	PARTICIPANT	\N	PRESENT	0
599453	598075	99004R	PARTICIPANT	\N	PRESENT	0
599455	598075	14207L	PARTICIPANT	\N	PRESENT	0
599456	598075	19699S	PARTICIPANT	\N	PRESENT	0
599457	598075	14221J	PARTICIPANT	\N	PRESENT	0
599458	598075	16685X	PARTICIPANT	\N	PRESENT	0
599459	598075	14267Y	PARTICIPANT	\N	PRESENT	0
599460	598075	20090E	PARTICIPANT	\N	PRESENT	0
599461	598075	20062A	PARTICIPANT	\N	PRESENT	0
599462	598075	19745F	PARTICIPANT	\N	PRESENT	0
599463	598075	20116W	PARTICIPANT	\N	PRESENT	0
599464	598075	19367Y	PARTICIPANT	\N	PRESENT	0
599465	598075	19585H	PARTICIPANT	\N	PRESENT	0
599466	598075	20032T	PARTICIPANT	\N	PRESENT	0
599467	598075	19782L	PARTICIPANT	\N	PRESENT	0
599468	598075	14253S	PARTICIPANT	\N	PRESENT	0
599469	598075	11041F	PARTICIPANT	\N	PRESENT	0
599470	598075	19637C	PARTICIPANT	\N	PRESENT	0
599471	598075	11103C	PARTICIPANT	\N	PRESENT	0
599472	598075	11104D	PARTICIPANT	\N	PRESENT	0
599473	598075	20144B	PARTICIPANT	\N	PRESENT	0
599474	598075	20056C	PARTICIPANT	\N	PRESENT	0
599475	598075	19826F	PARTICIPANT	\N	PRESENT	0
599476	598075	14053L	PARTICIPANT	\N	PRESENT	0
599477	598075	20026V	PARTICIPANT	\N	PRESENT	0
599478	598075	04092N	PARTICIPANT	\N	PRESENT	0
599479	598075	20152B	PARTICIPANT	\N	PRESENT	0
599480	598075	20054A	PARTICIPANT	\N	PRESENT	0
599481	598075	14211G	PARTICIPANT	\N	PRESENT	0
599482	598075	10006L	PARTICIPANT	\N	PRESENT	0
599483	598075	92040Q	PARTICIPANT	\N	PRESENT	0
599484	598075	19349W	PARTICIPANT	\N	PRESENT	0
599485	598075	11033F	PARTICIPANT	\N	PRESENT	0
599486	598075	14038Y	PARTICIPANT	\N	PRESENT	0
599487	598075	14355X	PARTICIPANT	\N	PRESENT	0
599488	598075	14187A	PARTICIPANT	\N	PRESENT	0
599489	598075	17737W	PARTICIPANT	\N	PRESENT	0
599490	598075	07033P	PARTICIPANT	\N	PRESENT	0
599491	598075	14217N	PARTICIPANT	\N	PRESENT	0
599492	598075	19583F	PARTICIPANT	\N	PRESENT	0
599493	598075	07004J	PARTICIPANT	\N	PRESENT	0
599494	598075	19301E	PARTICIPANT	\N	PRESENT	0
599495	598075	20146D	PARTICIPANT	\N	PRESENT	0
599496	598075	14033T	PARTICIPANT	\N	PRESENT	0
599497	598075	11083R	PARTICIPANT	\N	PRESENT	0
599498	598075	14059S	PARTICIPANT	\N	PRESENT	0
599499	598075	19443T	PARTICIPANT	\N	PRESENT	0
599500	598075	19467C	PARTICIPANT	\N	PRESENT	0
599501	598075	18083K	PARTICIPANT	\N	PRESENT	0
599502	598075	11066Q	PARTICIPANT	\N	PRESENT	0
599503	598075	19798U	PARTICIPANT	\N	PRESENT	0
599504	598075	19719D	PARTICIPANT	\N	PRESENT	0
599505	598075	11012A	PARTICIPANT	\N	PRESENT	0
599506	598075	19333N	PARTICIPANT	\N	PRESENT	0
599507	598075	08012N	PARTICIPANT	\N	PRESENT	0
599508	598075	20120S	PARTICIPANT	\N	PRESENT	0
599509	598075	05012A	PARTICIPANT	\N	PRESENT	0
599510	598075	19739H	PARTICIPANT	\N	PRESENT	0
599511	598075	20048C	PARTICIPANT	\N	PRESENT	0
599512	598075	14219Q	PARTICIPANT	\N	PRESENT	0
599513	598075	19563B	PARTICIPANT	\N	PRESENT	0
599514	598075	19758L	PARTICIPANT	\N	PRESENT	0
599515	598075	11065P	PARTICIPANT	\N	PRESENT	0
599516	598075	20030R	PARTICIPANT	\N	PRESENT	0
599517	598075	19335Q	PARTICIPANT	\N	PRESENT	0
599518	598075	20148F	PARTICIPANT	\N	PRESENT	0
599519	598075	04043D	PARTICIPANT	\N	PRESENT	0
599520	598075	11064N	PARTICIPANT	\N	PRESENT	0
599521	598075	17589D	PARTICIPANT	\N	PRESENT	0
599522	598075	04057K	PARTICIPANT	\N	PRESENT	0
599523	598075	20052X	PARTICIPANT	\N	PRESENT	0
599524	598075	14097Y	PARTICIPANT	\N	PRESENT	0
599525	598075	08015R	PARTICIPANT	\N	PRESENT	0
599526	598075	19703U	PARTICIPANT	\N	PRESENT	0
599527	598075	14111D	PARTICIPANT	\N	PRESENT	0
599528	598075	19569H	PARTICIPANT	\N	PRESENT	0
599529	598075	11054L	PARTICIPANT	\N	PRESENT	0
599530	598075	17965H	PARTICIPANT	\N	PRESENT	0
599531	598075	19413M	PARTICIPANT	\N	PRESENT	0
599532	598075	19669L	PARTICIPANT	\N	PRESENT	0
599533	598075	95063L	PARTICIPANT	\N	PRESENT	0
599534	598075	11099A	PARTICIPANT	\N	PRESENT	0
599535	598075	19599P	PARTICIPANT	\N	PRESENT	0
599536	598075	01034P	PARTICIPANT	\N	PRESENT	0
599537	598075	20132W	PARTICIPANT	\N	PRESENT	0
599538	598075	20022R	PARTICIPANT	\N	PRESENT	0
599539	598075	19369B	PARTICIPANT	\N	PRESENT	0
599540	598075	04070G	PARTICIPANT	\N	PRESENT	0
599541	598075	17229F	PARTICIPANT	\N	PRESENT	0
599542	598075	19695N	PARTICIPANT	\N	PRESENT	0
599543	598075	04085P	PARTICIPANT	\N	PRESENT	0
599544	598075	11056N	PARTICIPANT	\N	PRESENT	0
599545	598075	11040E	PARTICIPANT	\N	PRESENT	0
599546	598075	11045K	PARTICIPANT	\N	PRESENT	0
599547	598075	19687N	PARTICIPANT	\N	PRESENT	0
599548	598075	11031D	PARTICIPANT	\N	PRESENT	0
599549	598075	12041X	PARTICIPANT	\N	PRESENT	0
599550	598075	20046A	PARTICIPANT	\N	PRESENT	0
599551	598075	20102Q	PARTICIPANT	\N	PRESENT	0
599552	598075	20100N	PARTICIPANT	\N	PRESENT	0
599553	598075	20110Q	PARTICIPANT	\N	PRESENT	0
599554	598075	20130U	PARTICIPANT	\N	PRESENT	0
599555	598075	20092G	PARTICIPANT	\N	PRESENT	0
599556	598075	04035D	PARTICIPANT	\N	PRESENT	0
607625	607213	04057K	PARTICIPANT	\N	PRESENT	0
607626	607213	19619A	PARTICIPANT	\N	PRESENT	0
607627	607213	04045F	PARTICIPANT	\N	PRESENT	0
607628	607213	20100N	PARTICIPANT	\N	PRESENT	0
607629	607213	19758L	PARTICIPANT	\N	PRESENT	0
607630	607213	20080C	PARTICIPANT	\N	PRESENT	0
607631	607213	11064N	PARTICIPANT	\N	PRESENT	0
607632	607213	18193Q	PARTICIPANT	\N	PRESENT	0
607633	607213	11067R	PARTICIPANT	\N	PRESENT	0
607634	607213	14281W	PARTICIPANT	\N	PRESENT	0
607635	607213	14229S	PARTICIPANT	\N	PRESENT	0
607636	607213	14225N	PARTICIPANT	\N	PRESENT	0
607637	607213	11031D	PARTICIPANT	\N	PRESENT	0
607638	607213	04085P	PARTICIPANT	\N	PRESENT	0
607639	607213	11040E	PARTICIPANT	\N	PRESENT	0
607640	607213	19593H	PARTICIPANT	\N	PRESENT	0
607641	607213	20046A	PARTICIPANT	\N	PRESENT	0
607642	607213	20102Q	PARTICIPANT	\N	PRESENT	0
607643	607213	11077T	PARTICIPANT	\N	PRESENT	0
607644	607213	01028R	PARTICIPANT	\N	PRESENT	0
607645	607213	14211G	PARTICIPANT	\N	PRESENT	0
607646	607213	04059M	PARTICIPANT	\N	PRESENT	0
607647	607213	19711U	PARTICIPANT	\N	PRESENT	0
607648	607213	17779H	PARTICIPANT	\N	PRESENT	0
607649	607213	04008A	PARTICIPANT	\N	PRESENT	0
607650	607213	14021P	PARTICIPANT	\N	PRESENT	0
607651	607213	19683J	PARTICIPANT	\N	PRESENT	0
607652	607213	19747H	PARTICIPANT	\N	PRESENT	0
607653	607213	19333N	PARTICIPANT	\N	PRESENT	0
607654	607213	11080N	PARTICIPANT	\N	PRESENT	0
607655	607213	19649G	PARTICIPANT	\N	PRESENT	0
607656	607213	19693L	PARTICIPANT	\N	PRESENT	0
607657	607213	19489J	PARTICIPANT	\N	PRESENT	0
607658	607213	20114U	PARTICIPANT	\N	PRESENT	0
607659	607213	19549D	PARTICIPANT	\N	PRESENT	0
607660	607213	11103C	PARTICIPANT	\N	PRESENT	0
607661	607213	11041F	PARTICIPANT	\N	PRESENT	0
607662	607213	19703U	PARTICIPANT	\N	PRESENT	0
607663	607213	17637T	PARTICIPANT	\N	PRESENT	0
607664	607213	11054L	PARTICIPANT	\N	PRESENT	0
607665	607213	04035D	PARTICIPANT	\N	PRESENT	0
607666	607213	99004R	PARTICIPANT	\N	PRESENT	0
607667	607213	19820Y	PARTICIPANT	\N	PRESENT	0
607668	607213	19575F	PARTICIPANT	\N	PRESENT	0
607669	607213	08010L	PARTICIPANT	\N	PRESENT	0
607670	607213	20060X	PARTICIPANT	\N	PRESENT	0
607671	607213	19599P	PARTICIPANT	\N	PRESENT	0
607672	607213	14121F	PARTICIPANT	\N	PRESENT	0
607673	607213	14026U	PARTICIPANT	\N	PRESENT	0
607674	607213	11110B	PARTICIPANT	\N	PRESENT	0
607675	607213	11045K	PARTICIPANT	\N	PRESENT	0
607676	607213	04047H	PARTICIPANT	\N	PRESENT	0
607677	607213	19531S	PARTICIPANT	\N	PRESENT	0
607678	607213	20082E	PARTICIPANT	\N	PRESENT	0
607679	607213	12028B	PARTICIPANT	\N	PRESENT	0
607680	607213	08034U	PARTICIPANT	\N	PRESENT	0
607681	607213	20112S	PARTICIPANT	\N	PRESENT	0
607682	607213	11048N	PARTICIPANT	\N	PRESENT	0
607683	607213	17965H	PARTICIPANT	\N	PRESENT	0
607684	607213	20064C	PARTICIPANT	\N	PRESENT	0
607685	607213	08069G	PARTICIPANT	\N	PRESENT	0
607687	607213	14133K	PARTICIPANT	\N	PRESENT	0
607688	607213	20094J	PARTICIPANT	\N	PRESENT	0
607689	607213	20078J	PARTICIPANT	\N	PRESENT	0
607690	607213	20084G	PARTICIPANT	\N	PRESENT	0
607691	607213	20074E	PARTICIPANT	\N	PRESENT	0
607692	607213	20018V	PARTICIPANT	\N	PRESENT	0
607693	607213	20076G	PARTICIPANT	\N	PRESENT	0
607694	607213	19527W	PARTICIPANT	\N	PRESENT	0
607695	607213	19631V	PARTICIPANT	\N	PRESENT	0
607696	607213	04042C	PARTICIPANT	\N	PRESENT	0
607697	607213	19725B	PARTICIPANT	\N	PRESENT	0
607698	607213	19643A	PARTICIPANT	\N	PRESENT	0
607699	607213	19715Y	PARTICIPANT	\N	PRESENT	0
607700	607213	14223L	PARTICIPANT	\N	PRESENT	0
607701	607213	11043H	PARTICIPANT	\N	PRESENT	0
607702	607213	08028W	PARTICIPANT	\N	PRESENT	0
607703	607213	19760E	PARTICIPANT	\N	PRESENT	0
607704	607213	14123H	PARTICIPANT	\N	PRESENT	0
607705	607213	14187A	PARTICIPANT	\N	PRESENT	0
607706	607213	19689Q	PARTICIPANT	\N	PRESENT	0
607707	607213	14071N	PARTICIPANT	\N	PRESENT	0
607708	607213	20092G	PARTICIPANT	\N	PRESENT	0
607709	607213	19415P	PARTICIPANT	\N	PRESENT	0
607710	607213	20130U	PARTICIPANT	\N	PRESENT	0
607711	607213	05008E	PARTICIPANT	\N	PRESENT	0
607712	607213	19347U	PARTICIPANT	\N	PRESENT	0
607713	607213	20142Y	PARTICIPANT	\N	PRESENT	0
607714	607213	14053L	PARTICIPANT	\N	PRESENT	0
607715	607213	20134Y	PARTICIPANT	\N	PRESENT	0
607716	607213	19701S	PARTICIPANT	\N	PRESENT	0
607717	607213	19782L	PARTICIPANT	\N	PRESENT	0
607718	607213	95063L	PARTICIPANT	\N	PRESENT	0
607719	607213	04043D	PARTICIPANT	\N	PRESENT	0
607720	607213	11072N	PARTICIPANT	\N	PRESENT	0
607721	607213	11083R	PARTICIPANT	\N	PRESENT	0
607722	607213	20106U	PARTICIPANT	\N	PRESENT	0
607723	607213	20022R	PARTICIPANT	\N	PRESENT	0
607724	607213	19697Q	PARTICIPANT	\N	PRESENT	0
607725	607213	01057W	PARTICIPANT	\N	PRESENT	0
607726	607213	11033F	PARTICIPANT	\N	PRESENT	0
607727	607213	05012A	PARTICIPANT	\N	PRESENT	0
607728	607213	04071H	PARTICIPANT	\N	PRESENT	0
607729	607213	14249W	PARTICIPANT	\N	PRESENT	0
607730	607213	19515S	PARTICIPANT	\N	PRESENT	0
607731	607213	20174H	PARTICIPANT	\N	PRESENT	0
607732	607213	20038A	PARTICIPANT	\N	PRESENT	0
607733	607213	19673G	PARTICIPANT	\N	PRESENT	0
607734	607213	19545Y	PARTICIPANT	\N	PRESENT	0
607735	607213	19585H	PARTICIPANT	\N	PRESENT	0
607736	607213	14031R	PARTICIPANT	\N	PRESENT	0
607737	607213	20050V	PARTICIPANT	\N	PRESENT	0
607738	607213	19667J	PARTICIPANT	\N	PRESENT	0
607739	607213	14257W	PARTICIPANT	\N	PRESENT	0
607740	607213	20136B	PARTICIPANT	\N	PRESENT	0
607741	607213	14331P	PARTICIPANT	\N	PRESENT	0
607742	607213	19563B	PARTICIPANT	\N	PRESENT	0
607743	607213	20118Y	PARTICIPANT	\N	PRESENT	0
607744	607213	19629C	PARTICIPANT	\N	PRESENT	0
607745	607213	19533U	PARTICIPANT	\N	PRESENT	0
607746	607213	10006L	PARTICIPANT	\N	PRESENT	0
607747	607213	19798U	PARTICIPANT	\N	PRESENT	0
607748	607213	19719D	PARTICIPANT	\N	PRESENT	0
607749	607213	19387D	PARTICIPANT	\N	PRESENT	0
607750	607213	95041E	PARTICIPANT	\N	PRESENT	0
607751	607213	19671E	PARTICIPANT	\N	PRESENT	0
607752	607213	20132W	PARTICIPANT	\N	PRESENT	0
607753	607213	20252E	PARTICIPANT	\N	PRESENT	0
607754	607213	14217N	PARTICIPANT	\N	PRESENT	0
607755	607213	20152B	PARTICIPANT	\N	PRESENT	0
607756	607213	11090Q	PARTICIPANT	\N	PRESENT	0
607757	607213	07033P	PARTICIPANT	\N	PRESENT	0
607758	607213	14231L	PARTICIPANT	\N	PRESENT	0
607759	607213	17229F	PARTICIPANT	\N	PRESENT	0
607760	607213	97011G	PARTICIPANT	\N	PRESENT	0
607761	607213	11101A	PARTICIPANT	\N	PRESENT	0
607762	607213	11065P	PARTICIPANT	\N	PRESENT	0
607763	607213	14329V	PARTICIPANT	\N	PRESENT	0
607764	607213	14357A	PARTICIPANT	\N	PRESENT	0
607765	607213	19713W	PARTICIPANT	\N	PRESENT	0
607766	607213	04033B	PARTICIPANT	\N	PRESENT	0
607767	607213	19745F	PARTICIPANT	\N	PRESENT	0
607768	607213	14179A	PARTICIPANT	\N	PRESENT	0
607769	607213	08056B	PARTICIPANT	\N	PRESENT	0
607770	607213	19691J	PARTICIPANT	\N	PRESENT	0
607771	607213	20020P	PARTICIPANT	\N	PRESENT	0
607772	607213	20110Q	PARTICIPANT	\N	PRESENT	0
607773	607213	20054A	PARTICIPANT	\N	PRESENT	0
607774	607213	01034P	PARTICIPANT	\N	PRESENT	0
607775	607213	19369B	PARTICIPANT	\N	PRESENT	0
607776	607213	20126Y	PARTICIPANT	\N	PRESENT	0
607777	607213	20124W	PARTICIPANT	\N	PRESENT	0
607778	607213	11053K	PARTICIPANT	\N	PRESENT	0
607779	607213	20144B	PARTICIPANT	\N	PRESENT	0
607780	607213	20090E	PARTICIPANT	\N	PRESENT	0
607781	607213	14205J	PARTICIPANT	\N	PRESENT	0
607782	607213	19569H	PARTICIPANT	\N	PRESENT	0
607783	607213	14147R	PARTICIPANT	\N	PRESENT	0
607784	607213	19739H	PARTICIPANT	\N	PRESENT	0
607785	607213	19735D	PARTICIPANT	\N	PRESENT	0
607786	607213	20172F	PARTICIPANT	\N	PRESENT	0
601166	601165	19631V	PARTICIPANT	\N	PRESENT	0
601168	601167	11110B	PARTICIPANT	\N	PRESENT	0
601169	601167	20070A	PARTICIPANT	\N	PRESENT	0
601171	601170	11110B	PARTICIPANT	\N	PRESENT	0
601172	601170	20070A	PARTICIPANT	\N	PRESENT	0
601174	601173	11048N	PARTICIPANT	\N	PRESENT	0
601176	601175	11048N	PARTICIPANT	\N	PRESENT	0
601178	601177	14331P	PARTICIPANT	\N	PRESENT	0
601180	601179	20050V	PARTICIPANT	\N	PRESENT	0
601182	601181	14331P	PARTICIPANT	\N	PRESENT	1
601184	601183	20050V	PARTICIPANT	\N	PRESENT	0
601192	601191	08010L	PARTICIPANT	\N	PRESENT	0
601219	601218	11070L	PARTICIPANT	\N	PRESENT	0
601220	601218	19647E	PARTICIPANT	\N	PRESENT	0
601222	601221	19647E	PARTICIPANT	\N	PRESENT	1
601609	600495	20116W	PARTICIPANT	\N	PRESENT	0
601610	600495	11048N	PARTICIPANT	\N	PRESENT	0
601611	600495	08034U	PARTICIPANT	\N	PRESENT	0
601612	600495	99004R	PARTICIPANT	\N	PRESENT	0
601613	601098	14069U	PARTICIPANT	\N	PRESENT	0
601614	601098	14231L	PARTICIPANT	\N	PRESENT	0
601615	601098	19543W	PARTICIPANT	\N	PRESENT	0
601616	601098	19697Q	PARTICIPANT	\N	PRESENT	0
601617	601098	14173T	PARTICIPANT	\N	PRESENT	0
601618	601098	19333N	PARTICIPANT	\N	PRESENT	0
601619	601098	19599P	PARTICIPANT	\N	PRESENT	0
601620	601098	19768N	PARTICIPANT	\N	PRESENT	0
601621	601098	14215L	PARTICIPANT	\N	PRESENT	0
601622	601098	12016W	PARTICIPANT	\N	PRESENT	0
601623	601098	20096L	PARTICIPANT	\N	PRESENT	0
601624	600495	11053K	PARTICIPANT	\N	PRESENT	0
601625	600495	08073C	PARTICIPANT	\N	PRESENT	0
601626	601098	14107H	PARTICIPANT	\N	PRESENT	0
601627	601098	19689Q	PARTICIPANT	\N	PRESENT	0
601628	601098	19573D	PARTICIPANT	\N	PRESENT	0
601629	601098	11077T	PARTICIPANT	\N	PRESENT	0
601630	601098	19679N	PARTICIPANT	\N	PRESENT	0
601631	601098	19549D	PARTICIPANT	\N	PRESENT	0
601632	601098	05008E	PARTICIPANT	\N	PRESENT	0
601633	601098	20086J	PARTICIPANT	\N	PRESENT	0
601634	601098	19563B	PARTICIPANT	\N	PRESENT	0
601635	601098	14111D	PARTICIPANT	\N	PRESENT	0
601636	601098	19443T	PARTICIPANT	\N	PRESENT	0
601637	601098	20082E	PARTICIPANT	\N	PRESENT	0
601638	601098	20102Q	PARTICIPANT	\N	PRESENT	0
601639	600636	19649G	PARTICIPANT	\N	PRESENT	0
601640	601098	20092G	PARTICIPANT	\N	PRESENT	0
601641	600636	11072N	PARTICIPANT	\N	PRESENT	0
601642	600636	04047H	PRESIDENT	0	PRESENT	0
601643	600636	19673G	PARTICIPANT	\N	PRESENT	0
601644	600636	14111D	PARTICIPANT	\N	PRESENT	0
601645	600636	05008E	PARTICIPANT	\N	PRESENT	0
601646	600636	14053L	PARTICIPANT	\N	PRESENT	0
601647	600636	19447X	PARTICIPANT	\N	PRESENT	0
601648	600636	04085P	PARTICIPANT	\N	PRESENT	0
601649	600636	14089Y	PARTICIPANT	\N	PRESENT	0
601650	600636	19725B	PARTICIPANT	\N	PRESENT	0
601651	600636	14107H	PARTICIPANT	\N	PRESENT	0
601652	600636	20110Q	PARTICIPANT	\N	PRESENT	0
601653	600636	08010L	PARTICIPANT	\N	PRESENT	0
601654	600636	14215L	PARTICIPANT	\N	PRESENT	0
601655	600636	20022R	PARTICIPANT	\N	PRESENT	0
601656	600636	19749K	PARTICIPANT	\N	PRESENT	0
601657	600636	19729F	PARTICIPANT	\N	EXCUSE	0
601658	600636	19629C	PARTICIPANT	\N	EXCUSE	0
601659	601098	11012A	PARTICIPANT	\N	PRESENT	0
601661	600495	20080C	PARTICIPANT	\N	PRESENT	0
601662	600495	19647E	PARTICIPANT	\N	PRESENT	0
601664	601098	14021P	PARTICIPANT	\N	PRESENT	0
601665	601098	11045K	PARTICIPANT	\N	PRESENT	0
601666	601098	14151M	PARTICIPANT	\N	PRESENT	0
601667	601098	14267Y	PARTICIPANT	\N	PRESENT	0
601668	601098	20126Y	PARTICIPANT	\N	PRESENT	0
601677	601098	20064C	PARTICIPANT	\N	PRESENT	0
601670	600636	11026G	PARTICIPANT	\N	PRESENT	0
601671	600636	19543W	PARTICIPANT	\N	PRESENT	0
601672	600636	01028R	PARTICIPANT	\N	PRESENT	0
601673	600636	14231L	PARTICIPANT	\N	PRESENT	0
601674	600636	20108W	PARTICIPANT	\N	PRESENT	0
601675	600636	14147R	PARTICIPANT	\N	PRESENT	0
601676	601098	19349W	PARTICIPANT	\N	PRESENT	0
601678	601098	08061X	PARTICIPANT	\N	PRESENT	0
601679	600636	17737W	PARTICIPANT	\N	EXCUSE	0
601680	601098	99004R	PARTICIPANT	\N	PRESENT	0
601681	601098	95041E	PARTICIPANT	\N	PRESENT	0
601682	600636	11056N	PARTICIPANT	\N	PRESENT	0
601683	601098	08069G	PARTICIPANT	\N	PRESENT	0
601684	601098	14030Q	PARTICIPANT	\N	PRESENT	0
601695	601098	14327T	PARTICIPANT	\N	PRESENT	0
601706	601098	19673G	PARTICIPANT	\N	PRESENT	0
601708	601098	20110Q	PARTICIPANT	\N	PRESENT	0
601717	601098	14033T	PARTICIPANT	\N	PRESENT	0
601718	601098	14083S	PARTICIPANT	\N	PRESENT	0
601719	601098	08034U	PARTICIPANT	\N	PRESENT	0
601720	601098	19441R	PARTICIPANT	\N	PRESENT	0
601721	601098	14205J	PARTICIPANT	\N	PRESENT	0
601722	600211	19383Y	PARTICIPANT	\N	PRESENT	0
601723	600211	19768N	PARTICIPANT	\N	PRESENT	0
601724	600211	20088L	PARTICIPANT	\N	PRESENT	0
601725	600211	19515S	PARTICIPANT	\N	PRESENT	0
601726	600211	19782L	PARTICIPANT	\N	PRESENT	0
601727	600211	20092G	PARTICIPANT	\N	PRESENT	0
601728	600211	11077T	PARTICIPANT	\N	PRESENT	0
601729	600211	14357A	PARTICIPANT	\N	PRESENT	0
601730	600211	19441R	PARTICIPANT	\N	PRESENT	0
601731	600211	20082E	PARTICIPANT	\N	PRESENT	0
601732	600211	20094J	PARTICIPANT	\N	PRESENT	0
601733	600211	04045F	PARTICIPANT	\N	PRESENT	0
601734	600211	19631V	PARTICIPANT	\N	PRESENT	0
601735	600211	11099A	PARTICIPANT	\N	PRESENT	0
601736	600211	08015R	PARTICIPANT	\N	PRESENT	0
601737	600211	19575F	PARTICIPANT	\N	PRESENT	0
601738	600211	19369B	PARTICIPANT	\N	PRESENT	0
601739	600211	20018V	PARTICIPANT	\N	PRESENT	0
601740	600211	19511N	PARTICIPANT	\N	PRESENT	0
601741	600211	08028W	PARTICIPANT	\N	PRESENT	0
601742	600211	14038Y	PARTICIPANT	\N	PRESENT	0
601743	600211	19467C	PARTICIPANT	\N	PRESENT	0
601744	600211	14187A	PARTICIPANT	\N	PRESENT	0
601745	600211	14033T	PARTICIPANT	\N	PRESENT	0
601746	600211	11090Q	PRESIDENT	0	PRESENT	0
601747	600211	20054A	PARTICIPANT	\N	PRESENT	0
601748	600211	14205J	PARTICIPANT	\N	PRESENT	0
601749	600211	20062A	PARTICIPANT	\N	PRESENT	0
601750	600211	14251Q	PARTICIPANT	\N	PRESENT	0
601751	600211	19507S	PARTICIPANT	\N	PRESENT	0
601752	600211	19747H	PARTICIPANT	\N	PRESENT	0
601753	600211	14207L	PARTICIPANT	\N	PRESENT	0
601754	600211	14257W	PARTICIPANT	\N	PRESENT	0
601757	601098	19631V	PARTICIPANT	\N	PRESENT	0
601758	601098	14187A	PARTICIPANT	\N	PRESENT	0
603010	598626	11065P	PARTICIPANT	\N	EXCUSE	0
603011	598626	20038A	PARTICIPANT	\N	EXCUSE	0
603013	598626	05012A	PARTICIPANT	\N	EXCUSE	0
603014	598626	20046A	PARTICIPANT	\N	EXCUSE	0
608727	608508	08073C	PARTICIPANT	\N	PRESENT	0
608728	608508	20018V	PARTICIPANT	\N	PRESENT	0
608729	608508	20070A	PARTICIPANT	\N	PRESENT	0
608730	608508	19782L	PARTICIPANT	\N	PRESENT	0
608731	608508	19569H	PARTICIPANT	\N	PRESENT	0
608732	608508	20110Q	PARTICIPANT	\N	PRESENT	0
608733	608508	01062T	PARTICIPANT	\N	PRESENT	0
608734	608508	17229F	PARTICIPANT	\N	PRESENT	0
608735	608508	19826F	PARTICIPANT	\N	PRESENT	0
608736	608508	14053L	PARTICIPANT	\N	PRESENT	0
608737	608508	14038Y	PARTICIPANT	\N	PRESENT	0
608738	608508	20056C	PARTICIPANT	\N	PRESENT	0
608739	608508	19507S	PARTICIPANT	\N	PRESENT	0
608740	608508	19611R	PARTICIPANT	\N	PRESENT	0
608741	608508	12028B	PARTICIPANT	\N	PRESENT	0
608742	608508	14205J	PARTICIPANT	\N	PRESENT	0
608743	608508	20136B	PARTICIPANT	\N	PRESENT	0
608744	608508	14187A	PARTICIPANT	\N	PRESENT	0
608745	608508	20046A	PARTICIPANT	\N	PRESENT	0
608746	608508	14069U	PARTICIPANT	\N	PRESENT	0
608747	608508	11043H	PARTICIPANT	\N	PRESENT	0
608748	608508	20048C	PARTICIPANT	\N	PRESENT	0
608749	608508	20054A	PARTICIPANT	\N	PRESENT	0
608750	608508	19593H	PARTICIPANT	\N	PRESENT	0
608751	608508	14111D	PARTICIPANT	\N	PRESENT	0
608752	608508	19637C	PARTICIPANT	\N	PRESENT	0
602221	600213	19467C	PARTICIPANT	\N	PRESENT	0
602222	600213	14187A	PARTICIPANT	\N	PRESENT	0
602223	600213	20144B	PARTICIPANT	\N	PRESENT	0
602224	600213	19695N	PARTICIPANT	\N	PRESENT	0
602225	600213	14033T	PARTICIPANT	\N	PRESENT	0
602226	600213	11090Q	PRESIDENT	0	PRESENT	0
602227	600213	01025N	PARTICIPANT	\N	PRESENT	0
602228	600213	20054A	PARTICIPANT	\N	PRESENT	0
602229	600213	20174H	PARTICIPANT	\N	PRESENT	0
602230	600213	14205J	PARTICIPANT	\N	PRESENT	0
602231	600213	20060X	PARTICIPANT	\N	PRESENT	0
602232	600213	20062A	PARTICIPANT	\N	PRESENT	0
602233	600213	14251Q	PARTICIPANT	\N	PRESENT	0
602234	600213	19507S	PARTICIPANT	\N	PRESENT	0
602235	600213	14207L	PARTICIPANT	\N	PRESENT	0
602236	600213	19747H	PARTICIPANT	\N	PRESENT	0
602237	600213	14257W	PARTICIPANT	\N	PRESENT	0
602269	601100	20090E	PARTICIPANT	\N	PRESENT	0
602266	601100	19295A	PARTICIPANT	\N	PRESENT	0
602267	601100	19479G	PARTICIPANT	\N	PRESENT	0
602268	601100	19511N	PARTICIPANT	\N	PRESENT	0
602270	601100	14217N	PARTICIPANT	\N	PRESENT	0
602271	601100	19798U	PARTICIPANT	\N	PRESENT	0
602272	601100	20068G	PARTICIPANT	\N	PRESENT	0
602273	601100	19766L	PARTICIPANT	\N	PRESENT	0
602274	601100	11103C	PARTICIPANT	\N	PRESENT	0
602275	601100	19701S	PARTICIPANT	\N	PRESENT	0
602276	601100	11041F	PARTICIPANT	\N	PRESENT	0
602277	601100	11101A	PARTICIPANT	\N	PRESENT	0
602278	601100	99004R	PARTICIPANT	\N	PRESENT	0
602279	601100	20044X	PARTICIPANT	\N	PRESENT	0
602280	601100	19415P	PARTICIPANT	\N	PRESENT	0
602281	601100	14059S	PARTICIPANT	\N	PRESENT	0
602282	601100	04057K	PARTICIPANT	\N	PRESENT	0
602283	601100	14223L	PARTICIPANT	\N	PRESENT	0
602284	601100	14237S	PARTICIPANT	\N	PRESENT	0
602285	601100	14259Y	PARTICIPANT	\N	PRESENT	0
602286	601100	19693L	PARTICIPANT	\N	PRESENT	0
602287	601100	14211G	PARTICIPANT	\N	PRESENT	0
602288	601100	20180F	PARTICIPANT	\N	PRESENT	0
602289	601100	19723Y	PARTICIPANT	\N	PRESENT	0
602290	601100	14173T	PARTICIPANT	\N	PRESENT	0
602291	601100	19533U	PARTICIPANT	\N	PRESENT	0
602292	601100	19711U	PARTICIPANT	\N	PRESENT	0
602293	601100	20106U	PARTICIPANT	\N	PRESENT	0
602294	601100	11066Q	PARTICIPANT	\N	PRESENT	0
602295	601100	20072C	PARTICIPANT	\N	PRESENT	0
602296	601100	20144B	PARTICIPANT	\N	PRESENT	0
602297	601100	17965H	PARTICIPANT	\N	PRESENT	0
602298	601100	20172F	PARTICIPANT	\N	PRESENT	0
602299	601100	19673G	PARTICIPANT	\N	PRESENT	0
602300	601100	20108W	PARTICIPANT	\N	PRESENT	0
602301	601100	08015R	PARTICIPANT	\N	PRESENT	0
602302	601100	20024T	PARTICIPANT	\N	PRESENT	0
602303	601100	19679N	PARTICIPANT	\N	PRESENT	0
602304	601100	19683J	PARTICIPANT	\N	PRESENT	0
602305	601100	20142Y	PARTICIPANT	\N	PRESENT	0
602306	601100	20048C	PARTICIPANT	\N	PRESENT	0
602307	601100	19651A	PARTICIPANT	\N	PRESENT	0
602308	601100	19349W	PARTICIPANT	\N	PRESENT	0
602309	601100	19637C	PARTICIPANT	\N	PRESENT	0
602311	601100	19527W	PARTICIPANT	\N	PRESENT	0
602313	601100	19725B	PARTICIPANT	\N	PRESENT	0
602314	601100	14331P	PARTICIPANT	\N	PRESENT	0
602315	601100	20032T	PARTICIPANT	\N	PRESENT	0
602334	601100	19760E	PARTICIPANT	\N	PRESENT	0
602335	601100	04035D	PARTICIPANT	\N	PRESENT	0
602336	601100	11056N	PARTICIPANT	\N	PRESENT	0
602337	601100	19687N	PARTICIPANT	\N	PRESENT	0
602338	601100	04085P	PARTICIPANT	\N	PRESENT	0
602339	601100	18083K	PARTICIPANT	\N	PRESENT	0
602340	601100	19565D	PARTICIPANT	\N	PRESENT	0
602341	601100	12041X	PARTICIPANT	\N	PRESENT	0
602342	601100	11031D	PARTICIPANT	\N	PRESENT	0
602343	601100	11040E	PARTICIPANT	\N	PRESENT	0
602345	601100	19758L	PARTICIPANT	\N	PRESENT	0
602347	601100	11077T	PARTICIPANT	\N	PRESENT	0
602348	601100	19593H	PARTICIPANT	\N	PRESENT	0
602349	601100	19695N	PARTICIPANT	\N	PRESENT	0
602350	601100	20102Q	PARTICIPANT	\N	PRESENT	0
602351	601100	20112S	PARTICIPANT	\N	PRESENT	0
602352	601100	01058X	PARTICIPANT	\N	PRESENT	0
602353	601100	20058E	PARTICIPANT	\N	PRESENT	0
602354	601100	20100N	PARTICIPANT	\N	PRESENT	0
602355	601100	20086J	PARTICIPANT	\N	PRESENT	0
602356	601100	20092G	PARTICIPANT	\N	PRESENT	0
602357	601100	20130U	PARTICIPANT	\N	PRESENT	0
602358	601100	05008E	PARTICIPANT	\N	PRESENT	0
602359	601100	20134Y	PARTICIPANT	\N	PRESENT	0
602360	601100	14038Y	PARTICIPANT	\N	PRESENT	0
602361	601100	11033F	PARTICIPANT	\N	PRESENT	0
602362	601100	20038A	PARTICIPANT	\N	PRESENT	0
602363	601100	19663E	PARTICIPANT	\N	PRESENT	0
602364	601100	19467C	PARTICIPANT	\N	PRESENT	0
602365	601100	19782L	PARTICIPANT	\N	PRESENT	0
602366	601100	08061X	PARTICIPANT	\N	PRESENT	0
602367	601100	11072N	PARTICIPANT	\N	PRESENT	0
602368	601100	19573D	PARTICIPANT	\N	PRESENT	0
602369	601100	11083R	PARTICIPANT	\N	PRESENT	0
602370	601100	19697Q	PARTICIPANT	\N	PRESENT	0
602372	601100	20174H	PARTICIPANT	\N	PRESENT	0
602374	601100	19719D	PARTICIPANT	\N	PRESENT	0
602375	601100	20056C	PARTICIPANT	\N	PRESENT	0
602376	601100	20140W	PARTICIPANT	\N	PRESENT	0
602377	601100	20116W	PARTICIPANT	\N	PRESENT	0
602379	601100	08018U	PARTICIPANT	\N	PRESENT	0
602380	601100	20132W	PARTICIPANT	\N	PRESENT	0
602381	601100	14033T	PARTICIPANT	\N	PRESENT	0
602382	601100	20026V	PARTICIPANT	\N	PRESENT	0
602383	601100	19553Y	PARTICIPANT	\N	PRESENT	0
602384	601100	14031R	PARTICIPANT	\N	PRESENT	0
602385	601100	19591F	PARTICIPANT	\N	PRESENT	0
602386	601100	92040Q	PARTICIPANT	\N	PRESENT	0
602387	601100	19667J	PARTICIPANT	\N	PRESENT	0
602388	601100	19563B	PARTICIPANT	\N	PRESENT	0
602389	601100	14107H	PARTICIPANT	\N	PRESENT	0
602390	601100	14195A	PARTICIPANT	\N	PRESENT	0
602391	601100	19545Y	PARTICIPANT	\N	PRESENT	0
602392	601100	11080N	PARTICIPANT	\N	PRESENT	0
602393	601100	14111D	PARTICIPANT	\N	PRESENT	0
602394	601100	19515S	PARTICIPANT	\N	PRESENT	0
602395	601100	01057W	PARTICIPANT	\N	PRESENT	0
602396	601100	19631V	PARTICIPANT	\N	PRESENT	0
602397	601100	14225N	PARTICIPANT	\N	PRESENT	0
602398	601100	17367Q	PARTICIPANT	\N	PRESENT	0
602399	601100	19715Y	PARTICIPANT	\N	PRESENT	0
602400	601100	14169X	PARTICIPANT	\N	PRESENT	0
602401	601100	19335Q	PARTICIPANT	\N	PRESENT	0
602402	601100	19599P	PARTICIPANT	\N	PRESENT	0
602403	601100	19741B	PARTICIPANT	\N	PRESENT	0
602404	601100	17779H	PARTICIPANT	\N	PRESENT	0
602405	601100	14257W	PARTICIPANT	\N	PRESENT	0
602406	601100	12016W	PARTICIPANT	\N	PRESENT	0
602407	601100	19333N	PARTICIPANT	\N	PRESENT	0
602408	601100	14001X	PARTICIPANT	\N	PRESENT	0
602409	601100	19649G	PARTICIPANT	\N	PRESENT	0
602410	601100	19747H	PARTICIPANT	\N	PRESENT	0
602411	601100	11045K	PARTICIPANT	\N	PRESENT	0
602412	601100	19657G	PARTICIPANT	\N	PRESENT	0
602413	601100	14021P	PARTICIPANT	\N	PRESENT	0
602414	601100	19399H	PARTICIPANT	\N	PRESENT	0
602415	601100	11054L	PARTICIPANT	\N	PRESENT	0
602416	601100	19669L	PARTICIPANT	\N	PRESENT	0
602417	601100	14213J	PARTICIPANT	\N	PRESENT	0
602418	601100	14097Y	PARTICIPANT	\N	PRESENT	0
602419	601100	19707Y	PARTICIPANT	\N	PRESENT	0
602420	601100	11090Q	PARTICIPANT	\N	PRESENT	0
602421	601100	19768N	PARTICIPANT	\N	PRESENT	0
602422	601100	11067R	PARTICIPANT	\N	PRESENT	0
602423	601100	19705W	PARTICIPANT	\N	PRESENT	0
602424	601100	08045X	PARTICIPANT	\N	PRESENT	0
602425	601100	19689Q	PARTICIPANT	\N	PRESENT	0
602426	601100	04059M	PARTICIPANT	\N	PRESENT	0
602427	601100	11097X	PARTICIPANT	\N	PRESENT	0
602428	601100	20070A	PARTICIPANT	\N	PRESENT	0
602429	601100	19820Y	PARTICIPANT	\N	PRESENT	0
602430	601100	08012N	PARTICIPANT	\N	PRESENT	0
602431	601100	20022R	PARTICIPANT	\N	PRESENT	0
602432	601100	04071H	PARTICIPANT	\N	PRESENT	0
602433	601100	14109K	PARTICIPANT	\N	PRESENT	0
602434	601100	11104D	PARTICIPANT	\N	PRESENT	0
602435	601100	14281W	PARTICIPANT	\N	PRESENT	0
602436	601100	04033B	PARTICIPANT	\N	PRESENT	0
599557	598075	19693L	PARTICIPANT	\N	PRESENT	0
599558	598075	20128B	PARTICIPANT	\N	PRESENT	0
599559	598075	08010L	PARTICIPANT	\N	PRESENT	0
599560	598075	20122U	PARTICIPANT	\N	PRESENT	0
599561	598075	19387D	PARTICIPANT	\N	PRESENT	0
599562	598075	20044X	PARTICIPANT	\N	PRESENT	0
599563	598075	19723Y	PARTICIPANT	\N	PRESENT	0
599564	598075	11110B	PARTICIPANT	\N	PRESENT	0
599565	598075	20094J	PARTICIPANT	\N	PRESENT	0
599566	598075	19251M	PARTICIPANT	\N	PRESENT	0
599567	598075	20018V	PARTICIPANT	\N	PRESENT	0
599568	598075	20082E	PARTICIPANT	\N	PRESENT	0
599569	598075	19503N	PARTICIPANT	\N	PRESENT	0
599570	598075	08045X	PARTICIPANT	\N	PRESENT	0
599571	598075	19551W	PARTICIPANT	\N	PRESENT	0
599572	598075	19673G	PARTICIPANT	\N	PRESENT	0
599573	598075	20084G	PARTICIPANT	\N	PRESENT	0
599574	598075	14257W	PARTICIPANT	\N	PRESENT	0
599575	598075	19515S	PARTICIPANT	\N	PRESENT	0
599576	598075	19820Y	PARTICIPANT	\N	PRESENT	0
599577	598075	20180F	PARTICIPANT	\N	PRESENT	0
599578	598075	01062T	PARTICIPANT	\N	PRESENT	0
599579	598075	14031R	PARTICIPANT	\N	PRESENT	0
599580	598075	19549D	PARTICIPANT	\N	PRESENT	0
599581	598075	11067R	PARTICIPANT	\N	PRESENT	0
599582	598075	20114U	PARTICIPANT	\N	PRESENT	0
599583	598075	07029T	PARTICIPANT	\N	PRESENT	0
599584	598075	20028X	PARTICIPANT	\N	PRESENT	0
599585	598075	19667J	PARTICIPANT	\N	PRESENT	0
599586	598075	14121F	PARTICIPANT	\N	PRESENT	0
599587	598075	19954N	PARTICIPANT	\N	PRESENT	0
599588	598075	14151M	PARTICIPANT	\N	PRESENT	0
599589	598075	01057W	PARTICIPANT	\N	PRESENT	0
599590	598075	19649G	PARTICIPANT	\N	PRESENT	0
599591	598075	19647E	PARTICIPANT	\N	PRESENT	0
599592	598075	18193Q	PARTICIPANT	\N	PRESENT	0
599593	598075	19683J	PARTICIPANT	\N	PRESENT	0
599594	598075	20096L	PARTICIPANT	\N	PRESENT	0
599595	598075	20108W	PARTICIPANT	\N	PRESENT	0
599596	598075	14229S	PARTICIPANT	\N	PRESENT	0
599597	598075	20134Y	PARTICIPANT	\N	PRESENT	0
599598	598075	20140W	PARTICIPANT	\N	PRESENT	0
599599	598075	19657G	PARTICIPANT	\N	PRESENT	0
599600	598075	14249W	PARTICIPANT	\N	PRESENT	0
599601	598075	14213J	PARTICIPANT	\N	PRESENT	0
599602	598075	01060R	PARTICIPANT	\N	PRESENT	0
599603	598075	14251Q	PARTICIPANT	\N	PRESENT	0
599604	598075	14147R	PARTICIPANT	\N	PRESENT	0
599605	598075	19543W	PARTICIPANT	\N	PRESENT	0
599606	598075	20042V	PARTICIPANT	\N	PRESENT	0
599607	598075	20118Y	PARTICIPANT	\N	PRESENT	0
599608	598075	19441R	PARTICIPANT	\N	PRESENT	0
599609	598075	19347U	PARTICIPANT	\N	PRESENT	0
599610	598075	19479G	PARTICIPANT	\N	PRESENT	0
599611	598075	19721W	PARTICIPANT	\N	PRESENT	0
599612	598075	14357A	PARTICIPANT	\N	PRESENT	0
599613	598075	19611R	PARTICIPANT	\N	PRESENT	0
599614	598075	11053K	PARTICIPANT	\N	PRESENT	0
599615	598075	19691J	PARTICIPANT	\N	PRESENT	0
599616	598075	14231L	PARTICIPANT	\N	PRESENT	0
599617	598075	01025N	PARTICIPANT	\N	PRESENT	0
599618	598075	14030Q	PARTICIPANT	\N	PRESENT	0
599619	598075	14255U	PARTICIPANT	\N	PRESENT	0
599620	598075	20066E	PARTICIPANT	\N	PRESENT	0
599621	598075	11085T	PARTICIPANT	\N	PRESENT	0
599622	598075	11070L	PARTICIPANT	\N	PRESENT	0
599623	598075	20252E	PARTICIPANT	\N	PRESENT	0
599624	598075	19749K	PARTICIPANT	\N	PRESENT	0
599625	598075	20040T	PARTICIPANT	\N	PRESENT	0
599626	598075	20080C	PARTICIPANT	\N	PRESENT	0
599627	598075	20070A	PARTICIPANT	\N	PRESENT	0
599628	598075	19581D	PARTICIPANT	\N	PRESENT	0
599629	598075	14327T	PARTICIPANT	\N	PRESENT	0
599630	598075	19621T	PARTICIPANT	\N	PRESENT	0
599631	598075	14083S	PARTICIPANT	\N	PRESENT	0
599632	598075	19671E	PARTICIPANT	\N	PRESENT	0
599633	598075	20136B	PARTICIPANT	\N	PRESENT	0
599634	598075	14069U	PARTICIPANT	\N	PRESENT	0
599635	598075	19701S	PARTICIPANT	\N	PRESENT	0
599636	598075	14215L	PARTICIPANT	\N	PRESENT	0
599637	598075	14071N	PARTICIPANT	\N	PRESENT	0
599638	598075	04033B	PARTICIPANT	\N	PRESENT	0
599639	598075	14195A	PARTICIPANT	\N	PRESENT	0
599640	598075	05008E	PARTICIPANT	\N	PRESENT	0
599641	598075	11097X	PARTICIPANT	\N	PRESENT	0
599642	598075	08034U	PARTICIPANT	\N	PRESENT	0
599643	598075	19747H	PARTICIPANT	\N	PRESENT	0
599644	598075	14026U	PARTICIPANT	\N	PRESENT	0
599645	598075	19711U	PARTICIPANT	\N	PRESENT	0
599646	598075	19591F	PARTICIPANT	\N	PRESENT	0
599648	598075	19679N	PARTICIPANT	\N	PRESENT	0
599649	598075	20076G	PARTICIPANT	\N	PRESENT	0
599650	598075	20078J	PARTICIPANT	\N	PRESENT	0
599651	598075	11090Q	PARTICIPANT	\N	PRESENT	0
599652	598075	01048V	PARTICIPANT	\N	PRESENT	0
599653	598075	11043H	PARTICIPANT	\N	PRESENT	0
599654	598075	10015M	PARTICIPANT	\N	PRESENT	0
599655	598075	20124W	PARTICIPANT	\N	PRESENT	0
599656	598075	19447X	PARTICIPANT	\N	PRESENT	0
599657	598075	19507S	PARTICIPANT	\N	PRESENT	0
599658	598075	01058X	PARTICIPANT	\N	PRESENT	0
599659	598075	08056B	PARTICIPANT	\N	PRESENT	0
599660	598075	08047A	PARTICIPANT	\N	PRESENT	0
599661	598075	20172F	PARTICIPANT	\N	PRESENT	0
599662	598075	11048N	PARTICIPANT	\N	PRESENT	0
599663	598075	14055N	PARTICIPANT	\N	PRESENT	0
599664	598075	04047H	PARTICIPANT	\N	PRESENT	0
599665	598075	19643A	PARTICIPANT	\N	PRESENT	0
599666	598075	17367Q	PARTICIPANT	\N	PRESENT	0
599667	598075	20142Y	PARTICIPANT	\N	PRESENT	0
599668	598075	19697Q	PARTICIPANT	\N	PRESENT	0
599669	598075	19762G	PARTICIPANT	\N	PRESENT	0
599670	598075	19593H	PARTICIPANT	\N	PRESENT	0
599671	598075	19760E	PARTICIPANT	\N	PRESENT	0
599673	598075	14021P	PARTICIPANT	\N	PRESENT	0
599674	598075	19725B	PARTICIPANT	\N	PRESENT	0
599675	598075	20126Y	PARTICIPANT	\N	PRESENT	0
599676	598075	19553Y	PARTICIPANT	\N	PRESENT	0
599677	598075	08009T	PARTICIPANT	\N	PRESENT	0
599680	598075	01028R	PARTICIPANT	\N	PRESENT	0
599682	598075	20106U	PARTICIPANT	\N	PRESENT	0
599684	598075	14042U	PARTICIPANT	\N	PRESENT	0
599685	598075	08069G	PARTICIPANT	\N	PRESENT	0
599686	598075	20112S	PARTICIPANT	\N	PRESENT	0
599687	598075	01024M	PARTICIPANT	\N	PRESENT	0
599688	598075	14179A	PARTICIPANT	\N	PRESENT	0
599689	598075	19421M	PARTICIPANT	\N	PRESENT	0
599694	598075	04045F	PARTICIPANT	\N	PRESENT	0
599697	598075	19713W	PARTICIPANT	\N	PRESENT	0
599699	598075	19741B	PARTICIPANT	\N	PRESENT	0
599703	598075	19057M	PARTICIPANT	\N	PRESENT	0
607787	607213	14213J	PARTICIPANT	\N	PRESENT	0
607788	607213	19721W	PARTICIPANT	\N	PRESENT	0
607789	607213	08047A	PARTICIPANT	\N	PRESENT	0
607790	607213	19441R	PARTICIPANT	\N	PRESENT	0
607791	607213	19707Y	PARTICIPANT	\N	PRESENT	0
607792	607213	14042U	PARTICIPANT	\N	PRESENT	0
607793	607213	20148F	PARTICIPANT	\N	PRESENT	0
607794	607213	14219Q	PARTICIPANT	\N	PRESENT	0
607795	607213	20052X	PARTICIPANT	\N	PRESENT	0
607796	607213	20140W	PARTICIPANT	\N	PRESENT	0
607797	607213	20042V	PARTICIPANT	\N	PRESENT	0
607798	607213	19699S	PARTICIPANT	\N	PRESENT	0
607799	607213	19467C	PARTICIPANT	\N	PRESENT	0
607800	607213	14267Y	PARTICIPANT	\N	PRESENT	0
607801	607213	19543W	PARTICIPANT	\N	PRESENT	0
607802	607213	14083S	PARTICIPANT	\N	PRESENT	0
607803	607213	19768N	PARTICIPANT	\N	PRESENT	0
607804	607213	08015R	PARTICIPANT	\N	PRESENT	0
607805	607213	07004J	PARTICIPANT	\N	PRESENT	0
607806	607213	20096L	PARTICIPANT	\N	PRESENT	0
607807	607213	19577H	PARTICIPANT	\N	PRESENT	0
607808	607213	01024M	PARTICIPANT	\N	PRESENT	0
607839	607213	11027H	PARTICIPANT	\N	PRESENT	0
607810	607213	01043Q	PARTICIPANT	\N	PRESENT	0
607811	607213	14327T	PARTICIPANT	\N	PRESENT	0
607812	607213	20026V	PARTICIPANT	\N	PRESENT	0
607813	607213	14055N	PARTICIPANT	\N	PRESENT	0
607814	607213	14059S	PARTICIPANT	\N	PRESENT	0
607815	607213	10015M	PARTICIPANT	\N	PRESENT	0
607816	607213	19447X	PARTICIPANT	\N	PRESENT	0
607817	607213	19573D	PARTICIPANT	\N	PRESENT	0
607818	607213	20034V	PARTICIPANT	\N	PRESENT	0
607819	607213	14215L	PARTICIPANT	\N	PRESENT	0
607820	607213	20086J	PARTICIPANT	\N	PRESENT	0
607821	607213	20058E	PARTICIPANT	\N	PRESENT	0
607822	607213	14038Y	PARTICIPANT	\N	PRESENT	0
607823	607213	19663E	PARTICIPANT	\N	PRESENT	0
607846	607213	08018U	PARTICIPANT	\N	PRESENT	0
607848	607213	19591F	PARTICIPANT	\N	PRESENT	0
607826	607213	19741B	PARTICIPANT	\N	PRESENT	0
607827	607213	19399H	PARTICIPANT	\N	PRESENT	0
607828	607213	07029T	PARTICIPANT	\N	PRESENT	0
607847	607213	14033T	PARTICIPANT	\N	PRESENT	0
607830	607213	20104S	PARTICIPANT	\N	PRESENT	0
607831	607213	14193X	PARTICIPANT	\N	PRESENT	0
607832	607213	20056C	PARTICIPANT	\N	PRESENT	0
607833	607213	14253S	PARTICIPANT	\N	PRESENT	0
607834	607213	18083K	PARTICIPANT	\N	PRESENT	0
607835	607213	14097Y	PARTICIPANT	\N	PRESENT	0
607836	607213	20120S	PARTICIPANT	\N	PRESENT	0
607837	607213	20180F	PARTICIPANT	\N	PRESENT	0
607838	607213	20122U	PARTICIPANT	\N	PRESENT	0
607840	607213	20070A	PARTICIPANT	\N	PRESENT	0
607841	607213	11097X	PARTICIPANT	\N	PRESENT	0
607842	607213	19443T	PARTICIPANT	\N	PRESENT	0
607843	607213	19826F	PARTICIPANT	\N	PRESENT	0
607844	607213	19762G	PARTICIPANT	\N	PRESENT	0
607845	607213	19723Y	PARTICIPANT	\N	PRESENT	0
607849	607213	14255U	PARTICIPANT	\N	PRESENT	0
607850	607213	04070G	PARTICIPANT	\N	PRESENT	0
607851	607213	14251Q	PARTICIPANT	\N	PRESENT	0
607852	607213	19413M	PARTICIPANT	\N	PRESENT	0
607853	607213	19329S	PARTICIPANT	\N	PRESENT	0
607854	607213	20128B	PARTICIPANT	\N	PRESENT	0
607855	607213	19657G	PARTICIPANT	\N	PRESENT	0
607856	607213	11056N	PARTICIPANT	\N	PRESENT	0
607857	607213	20098N	PARTICIPANT	\N	PRESENT	0
607858	607213	14259Y	PARTICIPANT	\N	PRESENT	0
607859	607213	14030Q	PARTICIPANT	\N	PRESENT	0
607860	607213	11085T	PARTICIPANT	\N	PRESENT	0
607861	607213	19675J	PARTICIPANT	\N	PRESENT	0
607862	607213	14069U	PARTICIPANT	\N	PRESENT	0
607866	607213	19503N	PARTICIPANT	\N	PRESENT	0
607867	607213	14237S	PARTICIPANT	\N	PRESENT	0
607868	607213	04092N	PARTICIPANT	\N	PRESENT	0
607869	607213	11070L	PARTICIPANT	\N	PRESENT	0
607870	607213	19565D	PARTICIPANT	\N	PRESENT	0
607871	607213	17589D	PARTICIPANT	\N	PRESENT	0
607876	607213	11026G	PARTICIPANT	\N	PRESENT	0
607887	607213	14189C	PARTICIPANT	\N	PRESENT	0
607888	607213	20048C	PARTICIPANT	\N	PRESENT	0
608158	607209	11045K	PARTICIPANT	\N	PRESENT	0
608169	607209	19479G	PARTICIPANT	\N	PRESENT	0
608167	607209	11053K	PARTICIPANT	\N	PRESENT	0
608161	607209	07029T	PARTICIPANT	\N	PRESENT	0
608162	607209	20180F	PARTICIPANT	\N	PRESENT	0
608163	607209	20070A	PARTICIPANT	\N	PRESENT	0
608200	606857	19515S	PARTICIPANT	\N	PRESENT	0
608224	607209	19467C	PARTICIPANT	\N	PRESENT	0
608166	607209	20080C	PARTICIPANT	\N	PRESENT	0
608168	607209	14327T	PARTICIPANT	\N	PRESENT	0
608170	607209	14069U	PARTICIPANT	\N	PRESENT	0
608171	607209	19533U	PARTICIPANT	\N	PRESENT	0
608172	607209	19681G	PARTICIPANT	\N	PRESENT	0
608173	607209	11048N	PARTICIPANT	\N	PRESENT	0
608174	607209	14225N	PARTICIPANT	\N	PRESENT	0
608175	607209	04045F	PARTICIPANT	\N	PRESENT	0
608176	607209	14031R	PARTICIPANT	\N	PRESENT	0
608177	607209	19657G	PARTICIPANT	\N	PRESENT	0
608178	607209	19671E	PARTICIPANT	\N	PRESENT	0
608179	607209	19545Y	PARTICIPANT	\N	PRESENT	0
608180	607209	14107H	PARTICIPANT	\N	PRESENT	0
608181	607209	01057W	PARTICIPANT	\N	PRESENT	0
608182	607209	19741B	PARTICIPANT	\N	PRESENT	0
608183	607209	20252E	PARTICIPANT	\N	PRESENT	0
608184	607209	19689Q	PARTICIPANT	\N	PRESENT	0
608185	607209	19531S	PARTICIPANT	\N	PRESENT	0
608186	607209	20024T	PARTICIPANT	\N	PRESENT	0
608187	607209	14147R	PARTICIPANT	\N	PRESENT	0
608188	607209	01024M	PARTICIPANT	\N	PRESENT	0
608189	607209	20090E	PARTICIPANT	\N	PRESENT	0
608190	607209	18083K	PARTICIPANT	\N	PRESENT	0
608191	607209	14179A	PARTICIPANT	\N	PRESENT	0
608192	607209	19703U	PARTICIPANT	\N	PRESENT	0
608193	607209	19687N	PARTICIPANT	\N	PRESENT	0
608194	607209	12016W	PARTICIPANT	\N	PRESENT	0
608195	607209	20126Y	PARTICIPANT	\N	PRESENT	0
608196	607209	20052X	PARTICIPANT	\N	PRESENT	0
608197	607209	14105F	PARTICIPANT	\N	PRESENT	0
608198	607209	97011G	PARTICIPANT	\N	PRESENT	0
608199	607209	04043D	PARTICIPANT	\N	PRESENT	0
608201	606857	20092G	PARTICIPANT	\N	PRESENT	0
608202	606857	19441R	PARTICIPANT	\N	PRESENT	0
608203	606857	20078J	PARTICIPANT	\N	PRESENT	0
608204	606857	19413M	PARTICIPANT	\N	PRESENT	0
608205	606857	14033T	PARTICIPANT	\N	PRESENT	0
608206	606857	11090Q	PRESIDENT	0	PRESENT	0
608207	606857	20104S	PARTICIPANT	\N	PRESENT	0
608208	606857	20060X	PARTICIPANT	\N	PRESENT	0
608209	606857	20062A	PARTICIPANT	\N	PRESENT	0
608210	606857	08015R	PARTICIPANT	\N	PRESENT	0
608211	606857	19575F	PARTICIPANT	\N	PRESENT	0
608212	606857	14207L	PARTICIPANT	\N	PRESENT	0
608213	606857	19747H	PARTICIPANT	\N	PRESENT	0
608214	606857	19563B	PARTICIPANT	\N	PRESENT	0
608215	606857	14257W	PARTICIPANT	\N	PRESENT	0
608216	607209	99004R	PARTICIPANT	\N	PRESENT	0
608217	607209	19503N	PARTICIPANT	\N	PRESENT	0
608218	607209	14083S	PARTICIPANT	\N	PRESENT	0
608219	607209	11097X	PARTICIPANT	\N	PRESENT	0
608220	607209	14213J	PARTICIPANT	\N	PRESENT	0
608221	607209	20172F	PARTICIPANT	\N	PRESENT	0
608222	607209	14331P	PARTICIPANT	\N	PRESENT	0
608223	607209	19647E	PARTICIPANT	\N	PRESENT	0
608225	607209	20086J	PARTICIPANT	\N	PRESENT	0
608231	606436	14053L	PARTICIPANT	\N	EXCUSE	0
608235	606436	05008E	PARTICIPANT	\N	EXCUSE	0
608239	607209	20092G	PARTICIPANT	\N	PRESENT	0
603510	603140	11070L	PARTICIPANT	\N	PRESENT	0
603511	603140	14217N	PARTICIPANT	\N	PRESENT	0
603512	603140	19798U	PARTICIPANT	\N	PRESENT	0
603513	603140	19695N	PARTICIPANT	\N	PRESENT	0
603514	603140	19679N	PARTICIPANT	\N	PRESENT	0
603515	603140	19687N	PARTICIPANT	\N	PRESENT	0
603516	603140	19760E	PARTICIPANT	\N	PRESENT	0
603517	603140	20130U	PARTICIPANT	\N	PRESENT	0
603518	603140	19719D	PARTICIPANT	\N	PRESENT	0
603519	603140	20122U	PARTICIPANT	\N	PRESENT	0
603520	603140	17779H	PARTICIPANT	\N	PRESENT	0
603521	603140	17965H	PARTICIPANT	\N	PRESENT	0
603522	603140	20248J	PARTICIPANT	\N	PRESENT	0
603523	603140	20022R	PARTICIPANT	\N	PRESENT	0
603530	603140	11031D	PARTICIPANT	\N	PRESENT	0
603531	603140	19301E	PARTICIPANT	\N	PRESENT	0
603532	603140	19697Q	PARTICIPANT	\N	PRESENT	0
603533	603140	19651A	PARTICIPANT	\N	PRESENT	0
603538	603140	19551W	PARTICIPANT	\N	PRESENT	0
603540	603140	19723Y	PARTICIPANT	\N	PRESENT	0
603541	603140	11012A	PARTICIPANT	\N	PRESENT	0
603542	603140	20032T	PARTICIPANT	\N	PRESENT	0
603543	603140	04043D	PARTICIPANT	\N	PRESENT	0
603545	603140	14191V	PARTICIPANT	\N	PRESENT	0
603546	603140	20104S	PARTICIPANT	\N	PRESENT	0
603547	603140	20108W	PARTICIPANT	\N	PRESENT	0
603548	603140	20100N	PARTICIPANT	\N	PRESENT	0
603549	603140	19479G	PARTICIPANT	\N	PRESENT	0
603550	603140	19741B	PARTICIPANT	\N	PRESENT	0
603552	603140	20142Y	PARTICIPANT	\N	PRESENT	0
603553	603140	04047H	PARTICIPANT	\N	PRESENT	0
603554	603140	14053L	PARTICIPANT	\N	PRESENT	0
603555	603140	19725B	PARTICIPANT	\N	PRESENT	0
603556	603140	19369B	PARTICIPANT	\N	PRESENT	0
603557	603140	20026V	PARTICIPANT	\N	PRESENT	0
603558	603140	14259Y	PARTICIPANT	\N	PRESENT	0
608753	608508	14331P	PARTICIPANT	\N	PRESENT	0
608754	608508	14026U	PARTICIPANT	\N	PRESENT	0
608755	608508	19251M	PARTICIPANT	\N	PRESENT	0
608756	608508	14147R	PARTICIPANT	\N	PRESENT	0
608757	608508	11056N	PARTICIPANT	\N	PRESENT	0
608758	608508	20032T	PARTICIPANT	\N	PRESENT	0
608759	608508	20068G	PARTICIPANT	\N	PRESENT	0
608760	608508	11066Q	PARTICIPANT	\N	PRESENT	0
608761	608508	20028X	PARTICIPANT	\N	PRESENT	0
608762	608508	07033P	PARTICIPANT	\N	PRESENT	0
608763	608508	97011G	PARTICIPANT	\N	PRESENT	0
608764	608508	19703U	PARTICIPANT	\N	PRESENT	0
608765	608508	14213J	PARTICIPANT	\N	PRESENT	0
608766	608508	19671E	PARTICIPANT	\N	PRESENT	0
608767	608508	20026V	PARTICIPANT	\N	PRESENT	0
608768	608508	19719D	PARTICIPANT	\N	PRESENT	0
608769	608508	20086J	PARTICIPANT	\N	PRESENT	0
608770	608508	19749K	PARTICIPANT	\N	PRESENT	0
608771	608508	10006L	PARTICIPANT	\N	PRESENT	0
608772	608508	20024T	PARTICIPANT	\N	PRESENT	0
608773	608508	19599P	PARTICIPANT	\N	PRESENT	0
608774	608508	18083K	PARTICIPANT	\N	PRESENT	0
608775	608508	14021P	PARTICIPANT	\N	PRESENT	0
608819	608510	14259Y	PARTICIPANT	\N	PRESENT	0
608820	608510	11064N	PARTICIPANT	\N	PRESENT	0
608821	608510	20110Q	PARTICIPANT	\N	PRESENT	0
608822	608510	20046A	PARTICIPANT	\N	PRESENT	0
608823	608510	14189C	PARTICIPANT	\N	PRESENT	0
608824	608510	19866P	PARTICIPANT	\N	PRESENT	0
608825	608510	14225N	PARTICIPANT	\N	PRESENT	0
608826	608510	14169X	PARTICIPANT	\N	PRESENT	0
608827	608510	19335Q	PARTICIPANT	\N	PRESENT	0
608828	608510	19599P	PARTICIPANT	\N	PRESENT	0
608829	608510	20024T	PARTICIPANT	\N	PRESENT	0
608853	608510	11056N	PARTICIPANT	\N	PRESENT	0
608854	608510	19760E	PARTICIPANT	\N	PRESENT	0
608789	608510	14026U	PARTICIPANT	\N	PRESENT	0
608818	608510	19681G	PARTICIPANT	\N	PRESENT	0
608855	608510	19758L	PARTICIPANT	\N	PRESENT	0
608856	608510	20102Q	PARTICIPANT	\N	PRESENT	0
608857	608510	20122U	PARTICIPANT	\N	PRESENT	0
608858	608510	19387D	PARTICIPANT	\N	PRESENT	0
608859	608510	19745F	PARTICIPANT	\N	PRESENT	0
608860	608510	19826F	PARTICIPANT	\N	PRESENT	0
608861	608510	19798U	PARTICIPANT	\N	PRESENT	0
608862	608510	20048C	PARTICIPANT	\N	PRESENT	0
608863	608510	20090E	PARTICIPANT	\N	PRESENT	0
608864	608510	97011G	PARTICIPANT	\N	PRESENT	0
608865	608510	11103C	PARTICIPANT	\N	PRESENT	0
608866	608510	14069U	PARTICIPANT	\N	PRESENT	0
608867	608510	20108W	PARTICIPANT	\N	PRESENT	0
608868	608510	20032T	PARTICIPANT	\N	PRESENT	0
608869	608510	01058X	PARTICIPANT	\N	PRESENT	0
608870	608510	14033T	PARTICIPANT	\N	PRESENT	0
608871	608510	20026V	PARTICIPANT	\N	PRESENT	0
608872	608510	18083K	PARTICIPANT	\N	PRESENT	0
608873	608510	19507S	PARTICIPANT	\N	PRESENT	0
608874	608510	19399H	PARTICIPANT	\N	PRESENT	0
608875	608510	14147R	PARTICIPANT	\N	PRESENT	0
608876	608510	20020P	PARTICIPANT	\N	PRESENT	0
608877	608510	14038Y	PARTICIPANT	\N	PRESENT	0
608878	608510	17229F	PARTICIPANT	\N	PRESENT	0
608879	608510	19739H	PARTICIPANT	\N	PRESENT	0
608880	608510	19347U	PARTICIPANT	\N	PRESENT	0
608881	608510	20056C	PARTICIPANT	\N	PRESENT	0
608887	608510	11040E	PARTICIPANT	\N	PRESENT	0
608888	608510	19565D	PARTICIPANT	\N	PRESENT	0
608889	608510	08028W	PARTICIPANT	\N	PRESENT	0
608890	608510	20062A	PARTICIPANT	\N	PRESENT	0
608891	608510	20152B	PARTICIPANT	\N	PRESENT	0
608892	608510	08056B	PARTICIPANT	\N	PRESENT	0
608893	608510	19687N	PARTICIPANT	\N	PRESENT	0
608894	608510	01057W	PARTICIPANT	\N	PRESENT	0
608895	608510	19583F	PARTICIPANT	\N	PRESENT	0
608896	608510	19820Y	PARTICIPANT	\N	PRESENT	0
608897	608510	20120S	PARTICIPANT	\N	PRESENT	0
608898	608510	19479G	PARTICIPANT	\N	PRESENT	0
608899	608510	19467C	PARTICIPANT	\N	PRESENT	0
608900	608510	19489J	PARTICIPANT	\N	PRESENT	0
608901	608510	14195A	PARTICIPANT	\N	PRESENT	0
608906	608510	14121F	PARTICIPANT	\N	PRESENT	0
608907	608510	01043Q	PARTICIPANT	\N	PRESENT	0
608908	608510	20148F	PARTICIPANT	\N	PRESENT	0
608909	608510	19549D	PARTICIPANT	\N	PRESENT	0
608910	608510	20112S	PARTICIPANT	\N	PRESENT	0
608911	608510	19747H	PARTICIPANT	\N	PRESENT	0
608916	608510	19333N	PARTICIPANT	\N	PRESENT	0
608919	608510	20092G	PARTICIPANT	\N	PRESENT	0
608920	608510	11101A	PARTICIPANT	\N	PRESENT	0
608921	608510	20022R	PARTICIPANT	\N	PRESENT	0
608922	608510	19543W	PARTICIPANT	\N	PRESENT	0
608923	608510	20052X	PARTICIPANT	\N	PRESENT	0
608924	608510	14073Q	PARTICIPANT	\N	PRESENT	0
608926	608510	20136B	PARTICIPANT	\N	PRESENT	0
608927	608510	19671E	PARTICIPANT	\N	PRESENT	0
608928	608510	14111D	PARTICIPANT	\N	PRESENT	0
608929	608510	20030R	PARTICIPANT	\N	PRESENT	0
608930	608510	19413M	PARTICIPANT	\N	PRESENT	0
608931	608510	14187A	PARTICIPANT	\N	PRESENT	0
608932	608510	20180F	PARTICIPANT	\N	PRESENT	0
608934	608510	12028B	PARTICIPANT	\N	PRESENT	0
608935	608510	19563B	PARTICIPANT	\N	PRESENT	0
608936	608510	14105F	PARTICIPANT	\N	PRESENT	0
608937	608510	11012A	PARTICIPANT	\N	PRESENT	0
608938	608510	14223L	PARTICIPANT	\N	PRESENT	0
608939	608510	14083S	PARTICIPANT	\N	PRESENT	0
608940	608510	01024M	PARTICIPANT	\N	PRESENT	0
608941	608510	20140W	PARTICIPANT	\N	PRESENT	0
608942	608510	19251M	PARTICIPANT	\N	PRESENT	0
608945	608510	19713W	PARTICIPANT	\N	PRESENT	0
608946	608510	19691J	PARTICIPANT	\N	PRESENT	0
608948	608510	14257W	PARTICIPANT	\N	PRESENT	0
608949	608510	19503N	PARTICIPANT	\N	PRESENT	0
608950	608510	14207L	PARTICIPANT	\N	PRESENT	0
608951	608510	11077T	PARTICIPANT	\N	PRESENT	0
608952	608510	20082E	PARTICIPANT	\N	PRESENT	0
608953	608510	04033B	PARTICIPANT	\N	PRESENT	0
602437	601100	14151M	PARTICIPANT	\N	PRESENT	0
602438	601100	14053L	PARTICIPANT	\N	PRESENT	0
602439	601100	20264J	PARTICIPANT	\N	PRESENT	0
602440	601100	19413M	PARTICIPANT	\N	PRESENT	0
602496	601100	17229F	PARTICIPANT	\N	PRESENT	0
602442	601100	18193Q	PARTICIPANT	\N	PRESENT	0
602443	601100	14071N	PARTICIPANT	\N	PRESENT	0
602444	601100	20150Y	PARTICIPANT	\N	PRESENT	0
602445	601100	11048N	PARTICIPANT	\N	PRESENT	0
602446	601100	20082E	PARTICIPANT	\N	PRESENT	0
602447	601100	04092N	PARTICIPANT	\N	PRESENT	0
602448	601100	12028B	PARTICIPANT	\N	PRESENT	0
602449	601100	08034U	PARTICIPANT	\N	PRESENT	0
602450	601100	19503N	PARTICIPANT	\N	PRESENT	0
602451	601100	20080C	PARTICIPANT	\N	PRESENT	0
602452	601100	20018V	PARTICIPANT	\N	PRESENT	0
602453	601100	17637T	PARTICIPANT	\N	PRESENT	0
602454	601100	20094J	PARTICIPANT	\N	PRESENT	0
602455	601100	20030R	PARTICIPANT	\N	PRESENT	0
602456	601100	19703U	PARTICIPANT	\N	PRESENT	0
602458	601100	19647E	PARTICIPANT	\N	PRESENT	0
602460	601100	20084G	PARTICIPANT	\N	PRESENT	0
602462	601100	19251M	PARTICIPANT	\N	PRESENT	0
602464	601100	20074E	PARTICIPANT	\N	PRESENT	0
602467	601100	20136B	PARTICIPANT	\N	PRESENT	0
602468	601100	19709B	PARTICIPANT	\N	PRESENT	0
602469	601100	20060X	PARTICIPANT	\N	PRESENT	0
602470	601100	14251Q	PARTICIPANT	\N	PRESENT	0
602471	601100	14123H	PARTICIPANT	\N	PRESENT	0
602472	601100	17589D	PARTICIPANT	\N	PRESENT	0
602473	601100	20124W	PARTICIPANT	\N	PRESENT	0
602474	601100	14329V	PARTICIPANT	\N	PRESENT	0
602475	601100	97011G	PARTICIPANT	\N	PRESENT	0
602476	601100	20120S	PARTICIPANT	\N	PRESENT	0
602478	601100	19762G	PARTICIPANT	\N	PRESENT	0
602479	601100	19367Y	PARTICIPANT	\N	PRESENT	0
602480	601100	95041E	PARTICIPANT	\N	PRESENT	0
602481	601100	20042V	PARTICIPANT	\N	PRESENT	0
602482	601100	04042C	PARTICIPANT	\N	PRESENT	0
602483	601100	19699S	PARTICIPANT	\N	PRESENT	0
602484	601100	19713W	PARTICIPANT	\N	PRESENT	0
602485	601100	19739H	PARTICIPANT	\N	PRESENT	0
602486	601100	20020P	PARTICIPANT	\N	PRESENT	0
602487	601100	08069G	PARTICIPANT	\N	PRESENT	0
602488	601100	19735D	PARTICIPANT	\N	PRESENT	0
602489	601100	20126Y	PARTICIPANT	\N	PRESENT	0
602490	601100	19569H	PARTICIPANT	\N	PRESENT	0
602491	601100	20054A	PARTICIPANT	\N	PRESENT	0
602492	601100	14042U	PARTICIPANT	\N	PRESENT	0
602493	601100	11099A	PARTICIPANT	\N	PRESENT	0
602494	601100	19347U	PARTICIPANT	\N	PRESENT	0
602495	601100	14069U	PARTICIPANT	\N	PRESENT	0
602497	601100	14231L	PARTICIPANT	\N	PRESENT	0
602498	601100	10006L	PARTICIPANT	\N	PRESENT	0
602499	601100	19611R	PARTICIPANT	\N	PRESENT	0
602500	601100	19745F	PARTICIPANT	\N	PRESENT	0
602501	601100	04043D	PARTICIPANT	\N	PRESENT	0
602502	601100	19369B	PARTICIPANT	\N	PRESENT	0
602503	601100	08009T	PARTICIPANT	\N	PRESENT	0
602504	601100	11053K	PARTICIPANT	\N	PRESENT	0
602505	601100	14205J	PARTICIPANT	\N	PRESENT	0
602506	601100	19441R	PARTICIPANT	\N	PRESENT	0
602507	601100	19721W	PARTICIPANT	\N	PRESENT	0
602508	601100	19619A	PARTICIPANT	\N	PRESENT	0
602509	601100	14219Q	PARTICIPANT	\N	PRESENT	0
602510	601100	14089Y	PARTICIPANT	\N	PRESENT	0
602511	601100	14073Q	PARTICIPANT	\N	PRESENT	0
602512	601100	14083S	PARTICIPANT	\N	PRESENT	0
602513	601100	20040T	PARTICIPANT	\N	PRESENT	0
602514	601100	19575F	PARTICIPANT	\N	PRESENT	0
602515	601100	11070L	PARTICIPANT	\N	PRESENT	0
602516	601100	19826F	PARTICIPANT	\N	PRESENT	0
602517	601100	11085T	PARTICIPANT	\N	PRESENT	0
602518	601100	01024M	PARTICIPANT	\N	PRESENT	0
602519	601100	20066E	PARTICIPANT	\N	PRESENT	0
602520	601100	04070G	PARTICIPANT	\N	PRESENT	0
602521	601100	01025N	PARTICIPANT	\N	PRESENT	0
602522	601100	14030Q	PARTICIPANT	\N	PRESENT	0
602523	601100	14327T	PARTICIPANT	\N	PRESENT	0
602524	601100	20252E	PARTICIPANT	\N	PRESENT	0
602525	601100	01043Q	PARTICIPANT	\N	PRESENT	0
602526	601100	20052X	PARTICIPANT	\N	PRESENT	0
602527	601100	04045F	PARTICIPANT	\N	PRESENT	0
602528	601100	86034E	PARTICIPANT	\N	PRESENT	0
602529	601100	19549D	PARTICIPANT	\N	PRESENT	0
602530	601100	01062T	PARTICIPANT	\N	PRESENT	0
602531	601100	19551W	PARTICIPANT	\N	PRESENT	0
602532	601100	19387D	PARTICIPANT	\N	PRESENT	0
602533	601100	11012A	PARTICIPANT	\N	PRESENT	0
602534	601100	14026U	PARTICIPANT	\N	PRESENT	0
602535	601100	08010L	PARTICIPANT	\N	PRESENT	0
602536	601100	04008A	PARTICIPANT	\N	PRESENT	0
602537	601100	14267Y	PARTICIPANT	\N	PRESENT	0
602538	601100	19443T	PARTICIPANT	\N	PRESENT	0
602539	601100	16685X	PARTICIPANT	\N	PRESENT	0
602540	601100	08056B	PARTICIPANT	\N	PRESENT	0
602541	601100	19621T	PARTICIPANT	\N	PRESENT	0
602542	601100	19301E	PARTICIPANT	\N	PRESENT	0
602543	601100	01060R	PARTICIPANT	\N	PRESENT	0
602544	601100	19447X	PARTICIPANT	\N	PRESENT	0
602545	601100	11115U	PARTICIPANT	\N	PRESENT	0
602546	601100	08047A	PARTICIPANT	\N	PRESENT	0
602549	601100	14105F	PARTICIPANT	\N	PRESENT	0
602550	601100	19507S	PARTICIPANT	\N	PRESENT	0
602551	601100	17023S	PARTICIPANT	\N	PRESENT	0
602552	601100	19543W	PARTICIPANT	\N	PRESENT	0
602554	601100	19585H	PARTICIPANT	\N	PRESENT	0
602555	601100	20050V	PARTICIPANT	\N	PRESENT	0
602556	601100	11064N	PARTICIPANT	\N	PRESENT	0
602557	601100	19531S	PARTICIPANT	\N	PRESENT	0
602558	601100	01028R	PARTICIPANT	\N	PRESENT	0
602559	601100	19681G	PARTICIPANT	\N	PRESENT	0
602560	601100	14187A	PARTICIPANT	\N	PRESENT	0
602561	601100	01048V	PARTICIPANT	\N	PRESENT	0
602564	601100	20064C	PARTICIPANT	\N	PRESENT	0
602565	601100	19671E	PARTICIPANT	\N	PRESENT	0
602830	601102	19719D	PARTICIPANT	\N	PRESENT	0
602831	598626	14031R	PARTICIPANT	\N	PRESENT	0
602832	598626	19503N	PARTICIPANT	\N	PRESENT	0
602833	598626	14219Q	PRESIDENT	0	PRESENT	0
602834	598626	19826F	PARTICIPANT	\N	PRESENT	0
602835	598626	20102Q	PARTICIPANT	\N	PRESENT	0
602836	601102	19295A	PARTICIPANT	\N	PRESENT	0
602837	601102	17589D	PARTICIPANT	\N	PRESENT	0
602838	601102	14195A	PARTICIPANT	\N	PRESENT	0
602839	601102	19569H	PARTICIPANT	\N	PRESENT	0
602840	601102	19691J	PARTICIPANT	\N	PRESENT	0
602841	601102	20066E	PARTICIPANT	\N	PRESENT	0
602842	601102	14033T	PARTICIPANT	\N	PRESENT	0
602843	601102	19467C	PARTICIPANT	\N	PRESENT	0
602844	598626	18083K	PARTICIPANT	\N	PRESENT	0
602845	598626	20106U	PARTICIPANT	\N	PRESENT	0
602846	598626	20136B	PARTICIPANT	\N	PRESENT	0
602847	601102	04092N	PARTICIPANT	\N	PRESENT	0
602848	601102	19663E	PARTICIPANT	\N	PRESENT	0
602849	601102	04043D	PARTICIPANT	\N	PRESENT	0
602850	601102	19553Y	PARTICIPANT	\N	PRESENT	0
602851	601102	19683J	PARTICIPANT	\N	PRESENT	0
602852	601102	17965H	PARTICIPANT	\N	PRESENT	0
602853	601102	19697Q	PARTICIPANT	\N	PRESENT	0
602854	601102	11031D	PARTICIPANT	\N	PRESENT	0
602855	601102	19565D	PARTICIPANT	\N	PRESENT	0
602856	601102	20090E	PARTICIPANT	\N	PRESENT	0
602857	601102	20130U	PARTICIPANT	\N	PRESENT	0
602858	601102	11097X	PARTICIPANT	\N	PRESENT	0
602859	601102	14213J	PARTICIPANT	\N	PRESENT	0
602860	601102	10006L	PARTICIPANT	\N	PRESENT	0
602861	601102	19415P	PARTICIPANT	\N	PRESENT	0
602862	601102	11067R	PARTICIPANT	\N	PRESENT	0
602863	601102	19798U	PARTICIPANT	\N	PRESENT	0
602864	601102	14217N	PARTICIPANT	\N	PRESENT	0
602865	601102	20054A	PARTICIPANT	\N	PRESENT	0
602866	601102	19679N	PARTICIPANT	\N	PRESENT	0
602867	601102	04057K	PARTICIPANT	\N	PRESENT	0
602868	601102	19723Y	PARTICIPANT	\N	PRESENT	0
602869	601102	14042U	PARTICIPANT	\N	PRESENT	0
602870	601102	19713W	PARTICIPANT	\N	PRESENT	0
602871	601102	18193Q	PARTICIPANT	\N	PRESENT	0
602872	601102	19715Y	PARTICIPANT	\N	PRESENT	0
602873	601102	14071N	PARTICIPANT	\N	PRESENT	0
602874	601102	17779H	PARTICIPANT	\N	PRESENT	0
602875	601102	14281W	PARTICIPANT	\N	PRESENT	0
602876	601102	20040T	PARTICIPANT	\N	PRESENT	0
602877	601102	14038Y	PARTICIPANT	\N	PRESENT	0
599741	598075	14123H	PARTICIPANT	\N	PRESENT	0
599745	598075	20038A	PARTICIPANT	\N	PRESENT	0
599746	598075	20248J	PARTICIPANT	\N	PRESENT	0
599752	598075	19533U	PARTICIPANT	\N	PRESENT	0
600051	598076	11045K	PARTICIPANT	\N	PRESENT	0
600052	595689	14031R	PARTICIPANT	\N	PRESENT	0
600053	595689	19503N	PARTICIPANT	\N	PRESENT	0
600054	595689	14221J	PARTICIPANT	\N	PRESENT	0
600055	598076	20054A	PARTICIPANT	\N	PRESENT	0
600056	598076	14121F	PARTICIPANT	\N	PRESENT	0
600057	598076	07004J	PARTICIPANT	\N	PRESENT	0
600058	598076	17589D	PARTICIPANT	\N	PRESENT	0
600059	598076	19583F	PARTICIPANT	\N	PRESENT	0
600060	598076	19553Y	PARTICIPANT	\N	PRESENT	0
600061	598076	19629C	PARTICIPANT	\N	PRESENT	0
600062	598076	14215L	PARTICIPANT	\N	PRESENT	0
600063	598076	14257W	PARTICIPANT	\N	PRESENT	0
600064	598076	19383Y	PARTICIPANT	\N	PRESENT	0
600066	598076	20120S	PARTICIPANT	\N	PRESENT	0
600067	598076	14059S	PARTICIPANT	\N	PRESENT	0
600073	598076	19637C	PARTICIPANT	\N	PRESENT	0
600078	598076	19782L	PARTICIPANT	\N	PRESENT	0
600079	598076	14207L	PARTICIPANT	\N	PRESENT	0
600080	598076	14069U	PARTICIPANT	\N	PRESENT	0
600081	598076	20062A	PARTICIPANT	\N	PRESENT	0
600082	598076	20090E	PARTICIPANT	\N	PRESENT	0
600083	598076	20032T	PARTICIPANT	\N	PRESENT	0
600084	598076	14033T	PARTICIPANT	\N	PRESENT	0
600085	598076	97011G	PARTICIPANT	\N	PRESENT	0
600086	598076	20082E	PARTICIPANT	\N	PRESENT	0
600087	598076	11090Q	PARTICIPANT	\N	PRESENT	0
600088	598076	20068G	PARTICIPANT	\N	PRESENT	0
600089	595689	19333N	PARTICIPANT	\N	PRESENT	0
600090	595689	19701S	PARTICIPANT	\N	PRESENT	0
600091	595689	20136B	PARTICIPANT	\N	PRESENT	0
600092	595689	19251M	PARTICIPANT	\N	PRESENT	0
600093	595689	19826F	PARTICIPANT	\N	PRESENT	0
600094	595689	19599P	PARTICIPANT	\N	PRESENT	0
600095	595689	20102Q	PARTICIPANT	\N	PRESENT	0
600096	595689	18083K	PARTICIPANT	\N	PRESENT	0
600097	595689	19739H	PARTICIPANT	\N	PRESENT	0
600098	595689	19745F	PARTICIPANT	\N	PRESENT	0
600099	598076	10015M	PARTICIPANT	\N	PRESENT	0
600100	598076	19507S	PARTICIPANT	\N	PRESENT	0
600101	598076	19515S	PARTICIPANT	\N	PRESENT	0
600102	598076	19695N	PARTICIPANT	\N	PRESENT	0
600103	598076	19749K	PARTICIPANT	\N	PRESENT	0
600104	598076	19479G	PARTICIPANT	\N	PRESENT	0
600105	598076	19441R	PARTICIPANT	\N	PRESENT	0
600106	595689	11065P	PARTICIPANT	\N	PRESENT	0
600107	595689	20038A	PARTICIPANT	\N	PRESENT	0
600108	595689	19387D	PARTICIPANT	\N	PRESENT	0
600109	595689	19549D	PARTICIPANT	\N	PRESENT	0
600110	595689	20100N	PARTICIPANT	\N	PRESENT	0
600111	598076	11097X	PARTICIPANT	\N	PRESENT	0
600112	598076	19747H	PARTICIPANT	\N	PRESENT	0
600113	598076	01025N	PARTICIPANT	\N	PRESENT	0
600114	595689	20046A	PARTICIPANT	\N	PRESENT	0
600115	598076	19413M	PARTICIPANT	\N	PRESENT	0
600116	598076	11099A	PARTICIPANT	\N	PRESENT	0
600117	598076	08015R	PARTICIPANT	\N	PRESENT	0
600118	598076	19467C	PARTICIPANT	\N	PRESENT	0
600119	598076	20022R	PARTICIPANT	\N	PRESENT	0
600120	598076	05012A	PARTICIPANT	\N	PRESENT	0
600121	598076	01048V	PARTICIPANT	\N	PRESENT	0
600122	598076	20144B	PARTICIPANT	\N	PRESENT	0
600123	598076	20042V	PARTICIPANT	\N	PRESENT	0
600124	598076	20030R	PARTICIPANT	\N	PRESENT	0
600125	598076	20118Y	PARTICIPANT	\N	PRESENT	0
600153	598076	20112S	PARTICIPANT	\N	PRESENT	0
600214	598024	20116W	PARTICIPANT	\N	PRESENT	0
600215	598024	08011M	PARTICIPANT	\N	PRESENT	0
600216	598076	20044X	PARTICIPANT	\N	PRESENT	0
600217	598076	19447X	PARTICIPANT	\N	PRESENT	0
600218	598076	08034U	PARTICIPANT	\N	PRESENT	0
600219	598076	01024M	PARTICIPANT	\N	PRESENT	0
600220	598076	19713W	PARTICIPANT	\N	PRESENT	0
600221	598076	20046A	PARTICIPANT	\N	PRESENT	0
600222	598076	19565D	PARTICIPANT	\N	PRESENT	0
600223	598076	14357A	PARTICIPANT	\N	PRESENT	0
600224	598076	14097Y	PARTICIPANT	\N	PRESENT	0
600225	598076	19691J	PARTICIPANT	\N	PRESENT	0
600226	598076	20048C	PARTICIPANT	\N	PRESENT	0
600227	598076	07029T	PARTICIPANT	\N	PRESENT	0
600228	598076	11077T	PARTICIPANT	\N	PRESENT	0
600229	598076	19301E	PARTICIPANT	\N	PRESENT	0
600230	598076	20092G	PARTICIPANT	\N	PRESENT	0
600231	598076	20106U	PARTICIPANT	\N	PRESENT	0
600237	598076	20116W	PARTICIPANT	\N	PRESENT	0
600238	598076	08069G	PARTICIPANT	\N	PRESENT	0
600239	598076	14231L	PARTICIPANT	\N	PRESENT	0
600240	598076	20180F	PARTICIPANT	\N	PRESENT	0
600241	598076	20056C	PARTICIPANT	\N	PRESENT	0
600242	598076	19533U	PARTICIPANT	\N	PRESENT	0
600243	598076	14123H	PARTICIPANT	\N	PRESENT	0
600244	598076	20066E	PARTICIPANT	\N	PRESENT	0
600245	598076	19758L	PARTICIPANT	\N	PRESENT	0
600246	598076	19723Y	PARTICIPANT	\N	PRESENT	0
600247	598076	20026V	PARTICIPANT	\N	PRESENT	0
600248	598076	19551W	PARTICIPANT	\N	PRESENT	0
600305	599366	11070L	PARTICIPANT	\N	PRESENT	0
600306	599366	14033T	PARTICIPANT	\N	PRESENT	0
600307	599366	20082E	PARTICIPANT	\N	PRESENT	0
600308	599366	19782L	PARTICIPANT	\N	PRESENT	0
600309	599366	19563B	PARTICIPANT	\N	PRESENT	0
600310	599366	19413M	PARTICIPANT	\N	PRESENT	0
600311	599366	14026U	PARTICIPANT	\N	PRESENT	0
600312	599366	18083K	PARTICIPANT	\N	PRESENT	0
600313	599366	20090E	PARTICIPANT	\N	PRESENT	0
600314	599366	20032T	PARTICIPANT	\N	PRESENT	0
600315	599366	20030R	PARTICIPANT	\N	PRESENT	0
600316	599366	14257W	PARTICIPANT	\N	PRESENT	0
600317	599366	19631V	PARTICIPANT	\N	PRESENT	0
600318	599366	19629C	PARTICIPANT	\N	PRESENT	0
600319	599366	14207L	PARTICIPANT	\N	PRESENT	0
600320	599366	19747H	PARTICIPANT	\N	PRESENT	0
600321	599366	14217N	PARTICIPANT	\N	PRESENT	0
600322	599366	19301E	PARTICIPANT	\N	PRESENT	0
600323	599366	20126Y	PARTICIPANT	\N	PRESENT	0
600324	599366	20044X	PARTICIPANT	\N	PRESENT	0
600325	599366	19467C	PARTICIPANT	\N	PRESENT	0
600326	599366	20038A	PARTICIPANT	\N	PRESENT	0
600327	599366	20180F	PARTICIPANT	\N	PRESENT	0
600328	599366	20026V	PARTICIPANT	\N	PRESENT	0
600329	599366	20118Y	PARTICIPANT	\N	PRESENT	0
600330	599366	08015R	PARTICIPANT	\N	PRESENT	0
600331	599366	11099A	PARTICIPANT	\N	PRESENT	0
600332	599366	20062A	PARTICIPANT	\N	PRESENT	0
600333	599366	14357A	PARTICIPANT	\N	PRESENT	0
600334	599366	19447X	PARTICIPANT	\N	PRESENT	0
600335	599366	19551W	PARTICIPANT	\N	PRESENT	0
600336	599366	01025N	PARTICIPANT	\N	PRESENT	0
600337	599366	19387D	PARTICIPANT	\N	PRESENT	0
600338	599366	19713W	PARTICIPANT	\N	PRESENT	0
600339	599366	19479G	PARTICIPANT	\N	PRESENT	0
600340	599366	19441R	PARTICIPANT	\N	PRESENT	0
600341	599366	07004J	PARTICIPANT	\N	PRESENT	0
600342	599366	14249W	PARTICIPANT	\N	PRESENT	0
600343	599366	20018V	PARTICIPANT	\N	PRESENT	0
600344	599366	19695N	PARTICIPANT	\N	PRESENT	0
600345	599366	19565D	PARTICIPANT	\N	PRESENT	0
600346	599366	20116W	PARTICIPANT	\N	PRESENT	0
600347	599366	01024M	PARTICIPANT	\N	PRESENT	0
600348	599366	05012A	PARTICIPANT	\N	PRESENT	0
600349	599366	10015M	PARTICIPANT	\N	PRESENT	0
600350	599366	20092G	PARTICIPANT	\N	PRESENT	0
600351	599366	20054A	PARTICIPANT	\N	PRESENT	0
600352	599366	11090Q	PARTICIPANT	\N	PRESENT	0
600353	599366	11048N	PARTICIPANT	\N	PRESENT	0
600354	599366	19369B	PARTICIPANT	\N	PRESENT	0
600355	599366	11077T	PARTICIPANT	\N	PRESENT	0
600356	599366	19758L	PARTICIPANT	\N	PRESENT	0
600357	599366	19347U	PARTICIPANT	\N	PRESENT	0
600358	599366	14083S	PARTICIPANT	\N	PRESENT	0
608284	607210	20070A	PARTICIPANT	\N	PRESENT	0
608285	607210	19647E	PARTICIPANT	\N	PRESENT	0
608286	607210	20080C	PARTICIPANT	\N	PRESENT	0
608287	607210	12016W	PARTICIPANT	\N	PRESENT	0
608288	607210	14121F	PARTICIPANT	\N	PRESENT	0
608289	607210	20092G	PARTICIPANT	\N	PRESENT	0
608290	607210	20106U	PARTICIPANT	\N	PRESENT	0
608291	607210	19681G	PARTICIPANT	\N	PRESENT	0
608292	607210	19545Y	PARTICIPANT	\N	PRESENT	0
608293	607210	14083S	PARTICIPANT	\N	PRESENT	0
608294	607210	01024M	PARTICIPANT	\N	PRESENT	0
608295	607210	20126Y	PARTICIPANT	\N	PRESENT	0
608296	607210	19703U	PARTICIPANT	\N	PRESENT	0
608297	607210	20090E	PARTICIPANT	\N	PRESENT	0
608298	607210	19762G	PARTICIPANT	\N	PRESENT	0
608299	607210	14213J	PARTICIPANT	\N	PRESENT	0
608300	607210	11097X	PARTICIPANT	\N	PRESENT	0
608301	607210	20024T	PARTICIPANT	\N	PRESENT	0
608302	607210	14105F	PARTICIPANT	\N	PRESENT	0
608303	607210	04043D	PARTICIPANT	\N	PRESENT	0
608304	607210	14331P	PARTICIPANT	\N	PRESENT	0
608305	607210	19711U	PARTICIPANT	\N	PRESENT	0
608306	607210	19741B	PARTICIPANT	\N	PRESENT	0
608307	607210	19467C	PARTICIPANT	\N	PRESENT	0
608308	607210	20086J	PARTICIPANT	\N	PRESENT	0
608309	607210	01057W	PARTICIPANT	\N	PRESENT	0
608310	607210	19657G	PARTICIPANT	\N	PRESENT	0
608311	607210	14225N	PARTICIPANT	\N	PRESENT	0
608312	607210	11048N	PARTICIPANT	\N	PRESENT	0
608282	607210	11045K	PARTICIPANT	\N	PRESENT	0
608283	607210	19687N	PARTICIPANT	\N	PRESENT	0
608314	607210	07029T	PARTICIPANT	\N	PRESENT	0
608318	607210	19399H	PARTICIPANT	\N	PRESENT	0
608323	607210	19866P	PARTICIPANT	\N	PRESENT	0
608325	607210	20122U	PARTICIPANT	\N	PRESENT	0
608326	607210	19333N	PARTICIPANT	\N	PRESENT	0
608327	607210	19531S	PARTICIPANT	\N	PRESENT	0
608328	607210	19671E	PARTICIPANT	\N	PRESENT	0
608329	607210	11056N	PARTICIPANT	\N	PRESENT	0
608330	607210	19479G	PARTICIPANT	\N	PRESENT	0
608331	607210	19565D	PARTICIPANT	\N	PRESENT	0
608332	607210	19747H	PARTICIPANT	\N	PRESENT	0
608390	608389	11054L	PARTICIPANT	\N	PRESENT	0
608391	608389	20130U	PARTICIPANT	\N	PRESENT	0
608392	608389	14097Y	PARTICIPANT	\N	PRESENT	0
608393	608389	14179A	PARTICIPANT	\N	PRESENT	0
608394	608389	11031D	PARTICIPANT	\N	PRESENT	0
608395	608389	11033F	PARTICIPANT	\N	PRESENT	0
608397	606436	19631V	PARTICIPANT	\N	PRESENT	1
608398	606436	17023S	PARTICIPANT	\N	PRESENT	1
608399	606436	11010L	PARTICIPANT	\N	EXCUSE	0
608400	606436	20034V	PARTICIPANT	\N	EXCUSE	0
608401	606436	19329S	PARTICIPANT	\N	PRESENT	1
608402	606436	14097Y	PARTICIPANT	\N	PRESENT	0
608403	606436	08034U	PARTICIPANT	\N	PRESENT	0
608404	606436	20028X	PARTICIPANT	\N	PRESENT	1
608406	606436	11072N	PARTICIPANT	\N	PRESENT	0
608407	606436	20148F	PARTICIPANT	\N	PRESENT	0
608422	606436	20146D	PARTICIPANT	\N	PRESENT	1
608423	606436	08073C	PARTICIPANT	\N	EXCUSE	0
608425	606225	14259Y	PRESIDENT	0	PRESENT	0
608426	606225	19399H	PARTICIPANT	\N	PRESENT	0
608427	606225	11097X	PARTICIPANT	\N	PRESENT	0
608502	607211	20090E	PARTICIPANT	\N	PRESENT	0
608429	606225	11056N	PARTICIPANT	\N	PRESENT	0
608430	606225	19711U	PARTICIPANT	\N	PRESENT	0
608431	606225	20132W	PARTICIPANT	\N	PRESENT	0
608432	606225	19479G	PARTICIPANT	\N	PRESENT	0
608433	606225	20044X	PARTICIPANT	\N	EXCUSE	0
608434	606225	20050V	PARTICIPANT	\N	EXCUSE	0
608435	606225	19551W	PARTICIPANT	\N	EXCUSE	0
608436	606225	14193X	PARTICIPANT	\N	EXCUSE	0
608437	606225	20144B	PARTICIPANT	\N	EXCUSE	0
608438	606225	01028R	PARTICIPANT	\N	EXCUSE	0
608439	606225	19651A	PARTICIPANT	\N	EXCUSE	0
608452	606225	19747H	PARTICIPANT	\N	PRESENT	0
608493	606278	20130U	PARTICIPANT	\N	PRESENT	0
608494	606278	04057K	PARTICIPANT	\N	PRESENT	0
608495	606278	19713W	PARTICIPANT	\N	PRESENT	0
608496	606278	19663E	PARTICIPANT	\N	PRESENT	0
608497	606278	19723Y	PARTICIPANT	\N	PRESENT	0
608498	606278	14195A	PARTICIPANT	\N	PRESENT	0
608499	606278	14217N	PARTICIPANT	\N	PRESENT	0
608500	606278	04043D	PARTICIPANT	\N	PRESENT	0
608501	607211	14267Y	PARTICIPANT	\N	PRESENT	0
608503	607211	19533U	PARTICIPANT	\N	PRESENT	0
608504	607211	20180F	PARTICIPANT	\N	PRESENT	0
608505	607211	14213J	PARTICIPANT	\N	PRESENT	0
608506	607211	18083K	PARTICIPANT	\N	PRESENT	0
608507	607211	14217N	PARTICIPANT	\N	PRESENT	0
608509	607211	20022R	PARTICIPANT	\N	PRESENT	0
608511	607211	19723Y	PARTICIPANT	\N	PRESENT	0
608512	607211	14089Y	PARTICIPANT	\N	PRESENT	0
608517	607211	04043D	PARTICIPANT	\N	PRESENT	0
608523	607211	14069U	PARTICIPANT	\N	PRESENT	0
608524	607211	19573D	PARTICIPANT	\N	PRESENT	0
608525	607211	19711U	PARTICIPANT	\N	PRESENT	0
608574	607212	19591F	PARTICIPANT	\N	PRESENT	0
608575	607212	14195A	PARTICIPANT	\N	PRESENT	0
608576	607212	20266L	PARTICIPANT	\N	PRESENT	0
608577	607212	11031D	PARTICIPANT	\N	PRESENT	0
608578	607212	19569H	PARTICIPANT	\N	PRESENT	0
608580	607212	11012A	PARTICIPANT	\N	PRESENT	0
608581	607212	19683J	PARTICIPANT	\N	PRESENT	0
608582	608579	11027H	PARTICIPANT	\N	PRESENT	0
608583	608579	10006L	PARTICIPANT	\N	PRESENT	0
608584	607212	20090E	PARTICIPANT	\N	PRESENT	0
608585	608579	08012N	PARTICIPANT	\N	PRESENT	0
608586	608579	20084G	PARTICIPANT	\N	PRESENT	0
608587	608579	04043D	PARTICIPANT	\N	PRESENT	0
608588	608579	19709B	PARTICIPANT	\N	PRESENT	0
608589	607212	11097X	PARTICIPANT	\N	PRESENT	0
608592	607212	11067R	PARTICIPANT	\N	PRESENT	0
608593	607212	14105F	PARTICIPANT	\N	PRESENT	0
608594	607212	20248J	PARTICIPANT	\N	PRESENT	0
608599	607212	19657G	PARTICIPANT	\N	PRESENT	0
608600	607212	10006L	PARTICIPANT	\N	PRESENT	0
608601	607212	19693L	PARTICIPANT	\N	PRESENT	0
608602	607212	18193Q	PARTICIPANT	\N	PRESENT	0
608603	607212	14069U	PARTICIPANT	\N	PRESENT	0
608604	607212	14147R	PARTICIPANT	\N	PRESENT	0
608605	607212	19713W	PARTICIPANT	\N	PRESENT	0
608606	607212	14217N	PARTICIPANT	\N	PRESENT	0
608607	607212	19543W	PARTICIPANT	\N	PRESENT	0
608608	607212	07033P	PARTICIPANT	\N	PRESENT	0
608609	607212	19467C	PARTICIPANT	\N	PRESENT	0
608610	607212	08010L	PARTICIPANT	\N	PRESENT	0
608611	607212	04085P	PARTICIPANT	\N	PRESENT	0
608612	607212	19747H	PARTICIPANT	\N	PRESENT	0
608613	602477	20054A	PARTICIPANT	\N	EXCUSE	0
608572	607212	99004R	PARTICIPANT	\N	PRESENT	0
608573	607212	14042U	PARTICIPANT	\N	PRESENT	0
608614	602477	20092G	PARTICIPANT	\N	EXCUSE	0
608615	602477	14026U	PARTICIPANT	\N	EXCUSE	0
608616	602477	08060W	PARTICIPANT	\N	EXCUSE	0
608617	602477	20060X	PARTICIPANT	\N	EXCUSE	0
608618	602477	08015R	PARTICIPANT	\N	EXCUSE	0
608619	602477	19575F	PARTICIPANT	\N	EXCUSE	0
608620	602477	19760E	PARTICIPANT	\N	EXCUSE	0
608621	602477	19251M	PARTICIPANT	\N	EXCUSE	0
608622	602477	16685X	PARTICIPANT	\N	EXCUSE	0
608623	602477	19369B	PARTICIPANT	\N	EXCUSE	0
608624	602477	14030Q	PARTICIPANT	\N	EXCUSE	0
608625	602477	20126Y	PARTICIPANT	\N	EXCUSE	0
608626	602477	19717B	PARTICIPANT	\N	EXCUSE	0
608627	602477	14195A	PARTICIPANT	\N	EXCUSE	0
608628	602477	20082E	PARTICIPANT	\N	EXCUSE	0
608629	602477	19697Q	PARTICIPANT	\N	EXCUSE	0
608630	602477	20040T	PARTICIPANT	\N	EXCUSE	0
608631	607212	08018U	PARTICIPANT	\N	PRESENT	0
608635	607212	14251Q	PARTICIPANT	\N	PRESENT	0
608637	608636	14255U	PARTICIPANT	\N	PRESENT	0
608638	608636	05012A	PARTICIPANT	\N	PRESENT	0
608640	608639	14255U	PARTICIPANT	\N	PRESENT	0
608641	608639	19533U	PARTICIPANT	\N	PRESENT	0
608642	607212	19663E	PARTICIPANT	\N	PRESENT	0
608643	607212	19669L	PARTICIPANT	\N	PRESENT	0
608644	607212	20092G	PARTICIPANT	\N	PRESENT	0
608645	607212	11048N	PARTICIPANT	\N	PRESENT	0
608654	608653	19760E	PARTICIPANT	\N	PRESENT	0
599318	599317	05008E	PARTICIPANT	\N	PRESENT	0
599319	599317	11053K	PARTICIPANT	\N	PRESENT	0
599320	599317	01028R	PARTICIPANT	\N	PRESENT	0
603026	601108	19399H	PARTICIPANT	\N	PRESENT	0
603027	601108	19621T	PARTICIPANT	\N	PRESENT	0
603028	601108	19611R	PRESIDENT	0	PRESENT	0
603029	601108	19699S	PARTICIPANT	\N	PRESENT	0
603030	601108	20264J	PARTICIPANT	\N	PRESENT	0
603031	601108	20180F	PARTICIPANT	\N	PRESENT	0
603032	601108	04070G	PARTICIPANT	\N	PRESENT	0
603033	601108	20134Y	PARTICIPANT	\N	PRESENT	0
603034	601108	19593H	PARTICIPANT	\N	PRESENT	0
603035	601108	20132W	PARTICIPANT	\N	PRESENT	0
603036	601108	19643A	PARTICIPANT	\N	PRESENT	0
603037	601108	20124W	PARTICIPANT	\N	PRESENT	0
603038	601108	20052X	PARTICIPANT	\N	PRESENT	0
603039	601108	19735D	PARTICIPANT	\N	PRESENT	0
603040	601108	20058E	PARTICIPANT	\N	PRESENT	0
603041	601108	14229S	PARTICIPANT	\N	PRESENT	0
603042	601108	20142Y	PARTICIPANT	\N	PRESENT	0
603043	601108	19651A	PARTICIPANT	\N	PRESENT	0
603044	601108	19725B	PARTICIPANT	\N	PRESENT	0
603045	601108	20094J	PARTICIPANT	\N	PRESENT	0
603046	601108	14001X	PARTICIPANT	\N	PRESENT	0
603047	601108	14331P	PARTICIPANT	\N	PRESENT	0
603048	601108	08034U	PARTICIPANT	\N	PRESENT	0
603049	601108	14251Q	PARTICIPANT	\N	PRESENT	0
603050	601108	12041X	PARTICIPANT	\N	PRESENT	0
603051	601108	11109J	PARTICIPANT	\N	EXCUSE	0
608791	608790	86034E	PARTICIPANT	\N	PRESENT	0
608792	608790	04085P	PARTICIPANT	\N	PRESENT	0
608793	608790	05008E	PARTICIPANT	\N	PRESENT	0
608794	608790	04047H	PARTICIPANT	\N	PRESENT	0
608795	608790	04042C	PARTICIPANT	\N	PRESENT	0
608796	608790	11070L	PARTICIPANT	\N	PRESENT	0
608797	608790	19719D	PARTICIPANT	\N	PRESENT	0
608798	608790	10006L	PARTICIPANT	\N	PRESENT	0
608799	608790	14042U	PARTICIPANT	\N	PRESENT	0
608800	608790	19347U	PARTICIPANT	\N	PRESENT	0
608801	608790	14026U	PARTICIPANT	\N	PRESENT	0
608802	608790	11048N	PARTICIPANT	\N	PRESENT	0
608803	608790	14021P	PARTICIPANT	\N	PRESENT	0
608804	608790	99004R	PARTICIPANT	\N	PRESENT	0
608805	608790	19611R	PARTICIPANT	\N	PRESENT	0
608806	608790	12041X	PARTICIPANT	\N	PRESENT	0
608807	608790	01043Q	PARTICIPANT	\N	PRESENT	0
608808	608790	14219Q	PARTICIPANT	\N	PRESENT	0
608809	608790	14251Q	PARTICIPANT	\N	PRESENT	0
608810	608790	11085T	PARTICIPANT	\N	PRESENT	0
608811	608790	11072N	PARTICIPANT	\N	PRESENT	0
608812	608790	08073C	PARTICIPANT	\N	PRESENT	0
608813	608790	11090Q	PARTICIPANT	\N	PRESENT	0
608814	608790	14331P	PARTICIPANT	\N	PRESENT	0
608815	608790	14225N	PARTICIPANT	\N	PRESENT	0
608816	608790	11012A	PARTICIPANT	\N	PRESENT	0
608817	608790	04033B	PARTICIPANT	\N	PRESENT	0
608831	608830	86034E	PARTICIPANT	\N	PRESENT	0
608832	608830	04085P	PARTICIPANT	\N	PRESENT	0
608833	608830	04047H	PARTICIPANT	\N	PRESENT	0
608834	608830	14267Y	PARTICIPANT	\N	PRESENT	0
608835	608830	19719D	PARTICIPANT	\N	PRESENT	0
608836	608830	14042U	PARTICIPANT	\N	PRESENT	0
608837	608830	19347U	PARTICIPANT	\N	PRESENT	0
608838	608830	14026U	PARTICIPANT	\N	PRESENT	0
608839	608830	11048N	PARTICIPANT	\N	PRESENT	0
608840	608830	14021P	PARTICIPANT	\N	PRESENT	0
608841	608830	19611R	PARTICIPANT	\N	PRESENT	0
608842	608830	12041X	PARTICIPANT	\N	PRESENT	0
608843	608830	14219Q	PARTICIPANT	\N	PRESENT	0
608844	608830	04057K	PARTICIPANT	\N	PRESENT	0
608845	608830	01060R	PARTICIPANT	\N	PRESENT	0
608846	608830	14071N	PARTICIPANT	\N	PRESENT	0
608847	608830	08061X	PARTICIPANT	\N	PRESENT	0
608848	608830	11090Q	PARTICIPANT	\N	PRESENT	0
608849	608830	14331P	PARTICIPANT	\N	PRESENT	0
608850	608830	11012A	PARTICIPANT	\N	PRESENT	0
608851	608830	04033B	PARTICIPANT	\N	PRESENT	0
608852	608830	01028R	PARTICIPANT	\N	PRESENT	0
608883	608882	95063L	PARTICIPANT	\N	PRESENT	0
608884	608882	20056C	PARTICIPANT	\N	PRESENT	0
608886	608885	95063L	PARTICIPANT	\N	PRESENT	0
608999	608513	20032T	PARTICIPANT	\N	PRESENT	0
609000	608513	20062A	PARTICIPANT	\N	PRESENT	0
609001	608513	14259Y	PARTICIPANT	\N	PRESENT	0
609002	608513	01057W	PARTICIPANT	\N	PRESENT	0
609003	608513	19691J	PARTICIPANT	\N	PRESENT	0
609004	608513	01024M	PARTICIPANT	\N	PRESENT	0
609005	608513	04033B	PARTICIPANT	\N	PRESENT	0
609006	608513	11065P	PARTICIPANT	\N	PRESENT	0
609007	608513	19251M	PARTICIPANT	\N	PRESENT	0
609008	608513	19671E	PARTICIPANT	\N	PRESENT	0
609009	608513	19507S	PARTICIPANT	\N	PRESENT	0
609010	608513	19820Y	PARTICIPANT	\N	PRESENT	0
609011	608513	14083S	PARTICIPANT	\N	PRESENT	0
609012	608513	19866P	PARTICIPANT	\N	PRESENT	0
609013	608513	11101A	PARTICIPANT	\N	PRESENT	0
609014	608513	19583F	PARTICIPANT	\N	PRESENT	0
609015	608513	19387D	PARTICIPANT	\N	PRESENT	0
609016	608513	14207L	PARTICIPANT	\N	PRESENT	0
609018	608513	11056N	PARTICIPANT	\N	PRESENT	0
609019	608513	19745F	PARTICIPANT	\N	PRESENT	0
609020	608513	19695N	PARTICIPANT	\N	PRESENT	0
609021	608513	14109K	PARTICIPANT	\N	PRESENT	0
609022	608513	20092G	PARTICIPANT	\N	PRESENT	0
609023	608513	20102Q	PARTICIPANT	\N	PRESENT	0
608997	608513	14026U	PARTICIPANT	\N	PRESENT	0
608998	608513	19711U	PARTICIPANT	\N	PRESENT	0
609024	608513	19758L	PARTICIPANT	\N	PRESENT	0
609025	608513	19565D	PARTICIPANT	\N	PRESENT	0
609026	608513	11077T	PARTICIPANT	\N	PRESENT	0
609027	608513	20142Y	PARTICIPANT	\N	PRESENT	0
609028	608513	20100N	PARTICIPANT	\N	PRESENT	0
609029	608513	18193Q	PARTICIPANT	\N	PRESENT	0
609030	608513	20066E	PARTICIPANT	\N	PRESENT	0
609031	608513	14219Q	PARTICIPANT	\N	PRESENT	0
609032	608513	14105F	PARTICIPANT	\N	PRESENT	0
609033	608513	14205J	PARTICIPANT	\N	PRESENT	0
609037	608513	14031R	PARTICIPANT	\N	PRESENT	0
609041	608513	20024T	PARTICIPANT	\N	PRESENT	0
609048	608513	20030R	PARTICIPANT	\N	PRESENT	0
609058	608513	14221J	PARTICIPANT	\N	PRESENT	0
609059	608513	19503N	PARTICIPANT	\N	PRESENT	0
609060	608513	19399H	PARTICIPANT	\N	PRESENT	0
609061	608513	18083K	PARTICIPANT	\N	PRESENT	0
609062	608513	19760E	PARTICIPANT	\N	PRESENT	0
609077	608513	19413M	PARTICIPANT	\N	PRESENT	0
609078	608513	14257W	PARTICIPANT	\N	PRESENT	0
609079	608513	20082E	PARTICIPANT	\N	PRESENT	0
609082	608513	19762G	PARTICIPANT	\N	PRESENT	0
609085	608513	19631V	PARTICIPANT	\N	PRESENT	0
609086	608513	14189C	PARTICIPANT	\N	PRESENT	0
609089	608513	19585H	PARTICIPANT	\N	PRESENT	0
609090	608513	11012A	PARTICIPANT	\N	PRESENT	0
609091	608513	19369B	PARTICIPANT	\N	PRESENT	0
609092	608513	20096L	PARTICIPANT	\N	PRESENT	0
609093	608513	14038Y	PARTICIPANT	\N	PRESENT	0
609094	608513	19629C	PARTICIPANT	\N	PRESENT	0
609095	608513	19441R	PARTICIPANT	\N	PRESENT	0
609096	608513	20052X	PARTICIPANT	\N	PRESENT	0
609097	608513	20018V	PARTICIPANT	\N	PRESENT	0
609098	608513	19549D	PARTICIPANT	\N	PRESENT	0
609099	608513	14069U	PARTICIPANT	\N	PRESENT	0
609100	608513	20088L	PARTICIPANT	\N	PRESENT	0
609101	608513	20070A	PARTICIPANT	\N	PRESENT	0
609102	608513	20122U	PARTICIPANT	\N	PRESENT	0
609103	608513	14217N	PARTICIPANT	\N	PRESENT	0
609104	608513	20140W	PARTICIPANT	\N	PRESENT	0
609105	608513	19479G	PARTICIPANT	\N	PRESENT	0
602878	601102	19507S	PARTICIPANT	\N	PRESENT	0
602879	598626	19387D	PARTICIPANT	\N	PRESENT	0
602880	598626	19599P	PARTICIPANT	\N	PRESENT	0
602881	598626	20024T	PARTICIPANT	\N	PRESENT	0
602882	598626	14169X	PARTICIPANT	\N	PRESENT	0
602883	598626	19820Y	PARTICIPANT	\N	PRESENT	0
602884	601102	11012A	PARTICIPANT	\N	PRESENT	0
602885	598626	19549D	PARTICIPANT	\N	PRESENT	0
602886	601102	14026U	PARTICIPANT	\N	PRESENT	0
602916	601102	20172F	PARTICIPANT	\N	PRESENT	0
602888	600586	14327T	PARTICIPANT	\N	PRESENT	0
602889	600586	11048N	PARTICIPANT	\N	PRESENT	0
602890	600586	19647E	PARTICIPANT	\N	PRESENT	0
602891	600586	19711U	PARTICIPANT	\N	PRESENT	0
602892	600586	19531S	PARTICIPANT	\N	PRESENT	0
602893	600586	12016W	PARTICIPANT	\N	PRESENT	0
602894	600586	19413M	PARTICIPANT	\N	PRESENT	0
602895	600586	19671E	PARTICIPANT	\N	PRESENT	0
602896	600586	14225N	PRESIDENT	0	PRESENT	0
602897	600586	20150Y	PARTICIPANT	\N	PRESENT	0
602898	600586	20252E	PARTICIPANT	\N	PRESENT	0
602899	600586	20070A	PARTICIPANT	\N	PRESENT	0
602900	600586	99004R	PARTICIPANT	\N	PRESENT	0
602901	600586	19335Q	PARTICIPANT	\N	PRESENT	0
602902	600586	20126Y	PARTICIPANT	\N	PRESENT	0
602903	600586	19762G	PARTICIPANT	\N	PRESENT	0
602904	600586	07029T	PARTICIPANT	\N	EXCUSE	0
603614	603613	19711U	PARTICIPANT	\N	PRESENT	0
602906	600586	14189C	PARTICIPANT	\N	EXCUSE	0
602907	600586	20080C	PARTICIPANT	\N	EXCUSE	0
602909	601102	11045K	PARTICIPANT	\N	PRESENT	0
602910	601102	19301E	PARTICIPANT	\N	PRESENT	0
602911	601102	19479G	PARTICIPANT	\N	PRESENT	0
602912	601102	19591F	PARTICIPANT	\N	PRESENT	0
602913	601102	04085P	PARTICIPANT	\N	PRESENT	0
602914	601102	11104D	PARTICIPANT	\N	PRESENT	0
602915	601102	20024T	PARTICIPANT	\N	PRESENT	0
602917	601102	19673G	PARTICIPANT	\N	PRESENT	0
602918	601102	14215L	PARTICIPANT	\N	PRESENT	0
602919	601102	20120S	PARTICIPANT	\N	PRESENT	0
602920	601102	19689Q	PARTICIPANT	\N	PRESENT	0
602921	600586	08010L	PARTICIPANT	\N	PRESENT	0
602926	601102	08045X	PARTICIPANT	\N	PRESENT	0
602928	598626	14237S	PARTICIPANT	\N	PRESENT	0
602941	600586	19741B	PARTICIPANT	\N	PRESENT	0
602947	601102	14083S	PARTICIPANT	\N	PRESENT	0
603612	603611	11053K	PARTICIPANT	\N	PRESENT	0
603615	603613	14001X	PARTICIPANT	\N	PRESENT	0
603620	603619	14237S	PARTICIPANT	\N	PRESENT	0
603621	603619	20094J	PARTICIPANT	\N	PRESENT	0
603623	603622	14237S	PARTICIPANT	\N	PRESENT	0
603624	603622	20094J	PARTICIPANT	\N	PRESENT	0
603626	603625	20094J	PARTICIPANT	\N	PRESENT	0
603627	603625	14237S	PARTICIPANT	\N	PRESENT	0
606659	606658	20022R	PARTICIPANT	\N	PRESENT	0
606660	606658	20114U	PARTICIPANT	\N	PRESENT	0
606662	606661	20022R	PARTICIPANT	\N	PRESENT	0
606830	606261	20130U	PARTICIPANT	\N	PRESENT	0
606812	606404	19629C	PARTICIPANT	\N	PRESENT	0
606813	606404	04047H	PRESIDENT	0	PRESENT	0
606814	606404	14089Y	PARTICIPANT	\N	EXCUSE	0
606815	606404	19581D	PARTICIPANT	\N	EXCUSE	0
606816	606404	20074E	PARTICIPANT	\N	PRESENT	0
606817	606404	19725B	PARTICIPANT	\N	PRESENT	0
606818	606404	14111D	PARTICIPANT	\N	PRESENT	0
606819	606404	11026G	PARTICIPANT	\N	PRESENT	0
606820	606404	14179A	PARTICIPANT	\N	PRESENT	0
606821	606404	19673G	PARTICIPANT	\N	PRESENT	0
606822	606404	20128B	PARTICIPANT	\N	PRESENT	0
606823	606404	19447X	PARTICIPANT	\N	PRESENT	0
606824	606404	05008E	PARTICIPANT	\N	PRESENT	0
606825	606404	01028R	PARTICIPANT	\N	PRESENT	0
606826	606404	20114U	PARTICIPANT	\N	PRESENT	0
606827	606404	14069U	PARTICIPANT	\N	PRESENT	0
606829	606404	95063L	PARTICIPANT	\N	PRESENT	0
606831	606261	11067R	PARTICIPANT	\N	PRESENT	0
606832	606261	11097X	PARTICIPANT	\N	PRESENT	0
606833	606261	17965H	PARTICIPANT	\N	PRESENT	0
606834	606261	19691J	PARTICIPANT	\N	PRESENT	0
606835	606261	18193Q	PARTICIPANT	\N	PRESENT	0
606836	606261	14223L	PARTICIPANT	\N	PRESENT	0
606837	606261	20148F	PARTICIPANT	\N	PRESENT	0
606838	606261	17779H	PARTICIPANT	\N	PRESENT	0
606839	606261	19703U	PARTICIPANT	\N	PRESENT	0
606840	606261	19679N	PARTICIPANT	\N	PRESENT	0
606841	606261	14213J	PARTICIPANT	\N	PRESENT	0
606842	606261	10006L	PRESIDENT	0	PRESENT	0
606843	606261	19760E	PARTICIPANT	\N	PRESENT	0
606844	606404	14231L	PARTICIPANT	\N	PRESENT	0
606845	606261	19798U	PARTICIPANT	\N	PRESENT	0
606846	606261	19713W	PARTICIPANT	\N	PRESENT	0
606847	606261	20040T	PARTICIPANT	\N	PRESENT	0
606848	606261	19415P	PARTICIPANT	\N	PRESENT	0
606849	606261	20172F	PARTICIPANT	\N	PRESENT	0
606850	606261	19553Y	PARTICIPANT	\N	PRESENT	0
606851	606261	14042U	PARTICIPANT	\N	PRESENT	0
606852	606261	14217N	PARTICIPANT	\N	PRESENT	0
606864	606828	19383Y	PARTICIPANT	\N	PRESENT	0
606865	606828	19768N	PARTICIPANT	\N	PRESENT	0
606866	606828	19515S	PARTICIPANT	\N	PRESENT	0
606867	606828	19782L	PARTICIPANT	\N	PRESENT	0
606868	606828	20092G	PARTICIPANT	\N	PRESENT	0
606869	606828	01043Q	PARTICIPANT	\N	PRESENT	0
606870	606828	19441R	PARTICIPANT	\N	PRESENT	0
606871	606828	20078J	PARTICIPANT	\N	PRESENT	0
606872	606828	20082E	PARTICIPANT	\N	PRESENT	0
606873	606828	20094J	PARTICIPANT	\N	PRESENT	0
606874	606828	19631V	PARTICIPANT	\N	PRESENT	0
606875	606828	11099A	PARTICIPANT	\N	PRESENT	0
606876	606828	08015R	PARTICIPANT	\N	PRESENT	0
606877	606828	19575F	PARTICIPANT	\N	PRESENT	0
606878	606828	19369B	PARTICIPANT	\N	PRESENT	0
606879	606828	20018V	PARTICIPANT	\N	PRESENT	0
606880	606828	08028W	PARTICIPANT	\N	PRESENT	0
606881	606828	14329V	PARTICIPANT	\N	PRESENT	0
606882	606828	20028X	PARTICIPANT	\N	PRESENT	0
606883	606828	14038Y	PARTICIPANT	\N	PRESENT	0
606884	606828	14187A	PRESIDENT	0	PRESENT	0
606885	606828	14033T	PARTICIPANT	\N	PRESENT	0
606886	606828	14205J	PARTICIPANT	\N	PRESENT	0
606887	606828	20060X	PARTICIPANT	\N	PRESENT	0
606888	606828	20062A	PARTICIPANT	\N	PRESENT	0
606889	606828	14251Q	PARTICIPANT	\N	PRESENT	0
606890	606828	19507S	PARTICIPANT	\N	PRESENT	0
606891	606828	14257W	PARTICIPANT	\N	PRESENT	0
606899	606306	86034E	PARTICIPANT	\N	PRESENT	0
606900	606306	11048N	PARTICIPANT	\N	PRESENT	0
606901	606306	14225N	PARTICIPANT	\N	PRESENT	0
606902	606808	20086J	PARTICIPANT	\N	PRESENT	0
606903	606808	19479G	PARTICIPANT	\N	PRESENT	0
606904	606808	14173T	PARTICIPANT	\N	PRESENT	0
606905	606808	11040E	PARTICIPANT	\N	PRESENT	0
606906	606808	11053K	PARTICIPANT	\N	PRESENT	0
606907	606808	19349W	PARTICIPANT	\N	PRESENT	0
606908	606808	99004R	PARTICIPANT	\N	PRESENT	0
606909	606808	14225N	PRESIDENT	0	PRESENT	0
606910	606808	20126Y	PARTICIPANT	\N	PRESENT	0
606911	606808	07029T	PARTICIPANT	\N	PRESENT	0
606912	606808	14327T	PARTICIPANT	\N	PRESENT	0
606913	606808	11048N	PARTICIPANT	\N	PRESENT	0
606914	606808	19711U	PARTICIPANT	\N	PRESENT	0
606915	606808	11070L	PARTICIPANT	\N	PRESENT	0
606916	606808	14083S	PARTICIPANT	\N	PRESENT	0
606917	606808	19741B	PARTICIPANT	\N	PRESENT	0
606918	606808	14121F	PARTICIPANT	\N	PRESENT	0
606919	606808	04071H	PARTICIPANT	\N	PRESENT	0
606920	606808	01057W	PARTICIPANT	\N	PRESENT	0
606921	606808	20070A	PARTICIPANT	\N	PRESENT	0
606922	606808	08010L	PARTICIPANT	\N	PRESENT	0
606923	606808	14253S	PARTICIPANT	\N	PRESENT	0
606924	606808	19335Q	PARTICIPANT	\N	PRESENT	0
606925	606808	20080C	PARTICIPANT	\N	PRESENT	0
606926	606808	19667J	PARTICIPANT	\N	PRESENT	0
606927	606808	14189C	PARTICIPANT	\N	PRESENT	0
606928	606808	19762G	PARTICIPANT	\N	PRESENT	0
606929	606306	11033F	PARTICIPANT	\N	PRESENT	0
606930	606306	19647E	PARTICIPANT	\N	PRESENT	0
606931	606306	19349W	PARTICIPANT	\N	PRESENT	0
606932	606306	20050V	PARTICIPANT	\N	PRESENT	0
606933	606306	04033B	PARTICIPANT	\N	PRESENT	0
606934	606306	19687N	PARTICIPANT	\N	PRESENT	0
600165	598004	11083R	PARTICIPANT	\N	PRESENT	0
600166	598004	19583F	PARTICIPANT	\N	PRESENT	0
600167	598004	08061X	PARTICIPANT	\N	PRESENT	0
600168	598004	11054L	PARTICIPANT	\N	PRESENT	0
600169	598004	19669L	PARTICIPANT	\N	PRESENT	0
600170	598004	01062T	PARTICIPANT	\N	PRESENT	0
600179	595689	19820Y	PARTICIPANT	\N	PRESENT	0
600180	595689	19619A	PARTICIPANT	\N	EXCUSE	0
600196	600195	14111D	PARTICIPANT	\N	PRESENT	0
600204	600203	11027H	PARTICIPANT	\N	PRESENT	0
600205	600203	14193X	PARTICIPANT	\N	PRESENT	0
603503	602908	20130U	PARTICIPANT	\N	PRESENT	0
603501	602908	11067R	PARTICIPANT	\N	EXCUSE	0
603498	602908	19798U	PARTICIPANT	\N	PRESENT	0
603499	602908	19679N	PARTICIPANT	\N	PRESENT	0
603502	602908	14217N	PRESIDENT	0	PRESENT	0
603504	602908	04043D	PARTICIPANT	\N	PRESENT	0
603505	602908	19697Q	PARTICIPANT	\N	PRESENT	0
603506	602908	17779H	PARTICIPANT	\N	PRESENT	0
603507	602908	19723Y	PARTICIPANT	\N	PRESENT	0
603508	602908	20248J	PARTICIPANT	\N	PRESENT	0
603509	602908	11031D	PARTICIPANT	\N	PRESENT	0
603525	603524	19369B	PARTICIPANT	\N	PRESENT	0
603527	603526	19369B	PARTICIPANT	\N	PRESENT	0
603534	603528	19369B	PARTICIPANT	\N	PRESENT	0
603536	603535	14205J	PARTICIPANT	\N	PRESENT	0
603560	603122	11040E	PARTICIPANT	\N	PRESENT	0
603561	603122	19479G	PARTICIPANT	\N	PRESENT	0
603562	603122	99004R	PARTICIPANT	\N	PRESENT	0
603563	603122	20086J	PARTICIPANT	\N	PRESENT	0
603564	603122	20044X	PARTICIPANT	\N	PRESENT	0
603565	603122	19711U	PARTICIPANT	\N	PRESENT	0
603566	603122	20080C	PARTICIPANT	\N	PRESENT	0
603567	603122	19349W	PARTICIPANT	\N	PRESENT	0
603568	603122	11048N	PARTICIPANT	\N	PRESENT	0
603569	603122	14327T	PARTICIPANT	\N	PRESENT	0
603570	603122	14189C	PARTICIPANT	\N	PRESENT	0
603571	603122	14225N	PRESIDENT	0	PRESENT	0
603572	603122	08010L	PARTICIPANT	\N	PRESENT	0
603573	603122	20070A	PARTICIPANT	\N	PRESENT	0
603574	603122	19687N	PARTICIPANT	\N	PRESENT	0
603575	603122	19671E	PARTICIPANT	\N	PRESENT	0
603576	603122	19689Q	PARTICIPANT	\N	PRESENT	0
603577	603122	19741B	PARTICIPANT	\N	PRESENT	0
603578	603122	01048V	PARTICIPANT	\N	PRESENT	0
603579	603122	19667J	PARTICIPANT	\N	PRESENT	0
603580	603122	08011M	PARTICIPANT	\N	PRESENT	0
603581	603122	12016W	PARTICIPANT	\N	PRESENT	0
603582	603122	14083S	PARTICIPANT	\N	PRESENT	0
603583	603122	20126Y	PARTICIPANT	\N	PRESENT	0
603584	603122	14173T	PARTICIPANT	\N	PRESENT	0
603585	603122	11110B	PARTICIPANT	\N	PRESENT	0
603586	601162	14219Q	PRESIDENT	0	PRESENT	0
603587	601162	19826F	PARTICIPANT	\N	PRESENT	0
603588	601162	18083K	PARTICIPANT	\N	PRESENT	0
603589	601162	20024T	PARTICIPANT	\N	PRESENT	0
603590	603122	08034U	PARTICIPANT	\N	PRESENT	0
603591	601162	19333N	PARTICIPANT	\N	PRESENT	0
603592	601162	20032T	PARTICIPANT	\N	PRESENT	0
603593	601162	14169X	PARTICIPANT	\N	PRESENT	0
603594	601162	20100N	PARTICIPANT	\N	PRESENT	0
603595	601162	19251M	PARTICIPANT	\N	PRESENT	0
603596	601162	19685L	PARTICIPANT	\N	PRESENT	0
603597	601162	19599P	PARTICIPANT	\N	PRESENT	0
603598	601162	19549D	PARTICIPANT	\N	PRESENT	0
603599	601162	19503N	PARTICIPANT	\N	PRESENT	0
603600	601162	17367Q	PARTICIPANT	\N	PRESENT	0
603601	601162	20096L	PARTICIPANT	\N	PRESENT	0
603602	601162	20136B	PARTICIPANT	\N	PRESENT	0
603603	601162	19637C	PARTICIPANT	\N	PRESENT	0
603604	601162	20020P	PARTICIPANT	\N	PRESENT	0
603605	603122	20252E	PARTICIPANT	\N	PRESENT	0
603606	601162	14031R	PARTICIPANT	\N	PRESENT	0
603607	601162	14237S	PARTICIPANT	\N	PRESENT	0
603608	601162	19525U	PARTICIPANT	\N	PRESENT	0
603609	601162	19739H	PARTICIPANT	\N	PRESENT	0
603638	601163	14327T	PARTICIPANT	\N	PRESENT	0
603639	601163	20118Y	PARTICIPANT	\N	PRESENT	0
603640	601163	14219Q	PRESIDENT	0	PRESENT	0
603641	601163	19826F	PARTICIPANT	\N	PRESENT	0
603642	601163	20024T	PARTICIPANT	\N	PRESENT	0
603643	601163	19637C	PARTICIPANT	\N	PRESENT	0
603644	601163	19333N	PARTICIPANT	\N	PRESENT	0
603645	601163	18083K	PARTICIPANT	\N	PRESENT	0
603646	601163	19503N	PARTICIPANT	\N	PRESENT	0
603647	601163	19599P	PARTICIPANT	\N	PRESENT	0
603648	601163	20102Q	PARTICIPANT	\N	PRESENT	0
603649	601163	14169X	PARTICIPANT	\N	PRESENT	0
603650	601163	19820Y	PARTICIPANT	\N	PRESENT	0
603651	601163	19549D	PARTICIPANT	\N	PRESENT	0
603652	601163	20076G	PARTICIPANT	\N	PRESENT	0
603653	601163	08060W	PARTICIPANT	\N	PRESENT	0
603654	601163	14031R	PARTICIPANT	\N	PRESENT	0
603655	601163	19387D	PARTICIPANT	\N	PRESENT	0
603656	601163	19551W	PARTICIPANT	\N	PRESENT	0
603657	601163	19619A	PARTICIPANT	\N	PRESENT	0
603658	601163	19685L	PARTICIPANT	\N	PRESENT	0
603659	603142	86034E	PARTICIPANT	\N	PRESENT	0
603660	601163	19745F	PARTICIPANT	\N	PRESENT	0
603661	601163	14237S	PARTICIPANT	\N	PRESENT	0
603662	603142	19507S	PARTICIPANT	\N	PRESENT	0
603663	603142	20034V	PARTICIPANT	\N	PRESENT	0
603664	603142	20152B	PARTICIPANT	\N	PRESENT	0
603665	603142	19798U	PARTICIPANT	\N	PRESENT	0
603666	603142	19511N	PARTICIPANT	\N	PRESENT	0
603667	603142	20120S	PARTICIPANT	\N	PRESENT	0
600163	598004	12028B	PARTICIPANT	\N	PRESENT	0
600164	598004	14267Y	PARTICIPANT	\N	PRESENT	0
603668	603142	08028W	PARTICIPANT	\N	PRESENT	0
603669	603142	20068G	PARTICIPANT	\N	PRESENT	0
603670	603142	19766L	PARTICIPANT	\N	PRESENT	0
603671	603142	20024T	PARTICIPANT	\N	PRESENT	0
603672	603142	19673G	PARTICIPANT	\N	PRESENT	0
603673	603142	19443T	PARTICIPANT	\N	PRESENT	0
603674	603142	19745F	PARTICIPANT	\N	PRESENT	0
603675	603142	20076G	PARTICIPANT	\N	PRESENT	0
603676	603142	11103C	PARTICIPANT	\N	PRESENT	0
603679	603142	14169X	PARTICIPANT	\N	PRESENT	0
603680	603142	14031R	PARTICIPANT	\N	PRESENT	0
603681	603142	19709B	PARTICIPANT	\N	PRESENT	0
603682	603142	01060R	PARTICIPANT	\N	PRESENT	0
603683	603142	19703U	PARTICIPANT	\N	PRESENT	0
603684	603142	19387D	PARTICIPANT	\N	PRESENT	0
603685	603142	14217N	PARTICIPANT	\N	PRESENT	0
603686	603142	19715Y	PARTICIPANT	\N	PRESENT	0
603687	603142	08060W	PARTICIPANT	\N	PRESENT	0
603688	603142	17965H	PARTICIPANT	\N	PRESENT	0
603689	603142	19599P	PARTICIPANT	\N	PRESENT	0
603690	603142	04045F	PARTICIPANT	\N	PRESENT	0
603691	603142	19697Q	PARTICIPANT	\N	PRESENT	0
603692	603142	19866P	PARTICIPANT	\N	PRESENT	0
603693	603142	20072C	PARTICIPANT	\N	PRESENT	0
603694	603142	19563B	PARTICIPANT	\N	PRESENT	0
603695	603142	14195A	PARTICIPANT	\N	PRESENT	0
603696	603142	19585H	PARTICIPANT	\N	PRESENT	0
603697	603142	14221J	PARTICIPANT	\N	PRESENT	0
603698	603142	14211G	PARTICIPANT	\N	PRESENT	0
603699	603142	20134Y	PARTICIPANT	\N	PRESENT	0
603700	603142	19711U	PARTICIPANT	\N	PRESENT	0
603701	603142	20130U	PARTICIPANT	\N	PRESENT	0
603702	603142	20074E	PARTICIPANT	\N	PRESENT	0
603703	603142	19679N	PARTICIPANT	\N	PRESENT	0
603704	603142	04008A	PARTICIPANT	\N	PRESENT	0
603705	603142	11101A	PARTICIPANT	\N	PRESENT	0
603706	603142	99004R	PARTICIPANT	\N	PRESENT	0
603707	603142	01058X	PARTICIPANT	\N	PRESENT	0
603708	603142	18083K	PARTICIPANT	\N	PRESENT	0
603709	603142	04047H	PARTICIPANT	\N	PRESENT	0
603710	603142	19415P	PARTICIPANT	\N	PRESENT	0
603711	603142	19689Q	PARTICIPANT	\N	PRESENT	0
603715	603142	11097X	PARTICIPANT	\N	PRESENT	0
603713	603142	08034U	PARTICIPANT	\N	PRESENT	0
603714	603142	20266L	PARTICIPANT	\N	PRESENT	0
603716	603142	19347U	PARTICIPANT	\N	PRESENT	0
603717	603142	19747H	PARTICIPANT	\N	PRESENT	0
603718	603142	19725B	PARTICIPANT	\N	PRESENT	0
603719	603142	14053L	PARTICIPANT	\N	PRESENT	0
603720	603142	20084G	PARTICIPANT	\N	PRESENT	0
603721	603142	14193X	PARTICIPANT	\N	PRESENT	0
603722	603142	19413M	PARTICIPANT	\N	PRESENT	0
603723	603142	14071N	PARTICIPANT	\N	PRESENT	0
608657	608653	20130U	PARTICIPANT	\N	PRESENT	0
608658	608653	11097X	PARTICIPANT	\N	PRESENT	0
608659	608653	14042U	PARTICIPANT	\N	PRESENT	0
608944	608943	14073Q	PARTICIPANT	\N	PRESENT	0
609568	609567	20024T	PARTICIPANT	\N	PRESENT	0
609569	609567	14105F	PARTICIPANT	\N	PRESENT	0
609570	609567	19782L	PARTICIPANT	\N	PRESENT	0
609571	609567	20090E	PARTICIPANT	\N	PRESENT	0
609572	609567	11103C	PARTICIPANT	\N	PRESENT	0
609573	609567	19467C	PARTICIPANT	\N	PRESENT	0
609574	609567	18083K	PARTICIPANT	\N	PRESENT	0
609575	609567	14357A	PARTICIPANT	\N	PRESENT	0
609576	609567	17589D	PARTICIPANT	\N	PRESENT	0
609577	609567	01057W	PARTICIPANT	\N	PRESENT	0
609578	609567	14213J	PARTICIPANT	\N	PRESENT	0
609579	609567	14097Y	PARTICIPANT	\N	PRESENT	0
609580	609567	20126Y	PARTICIPANT	\N	PRESENT	0
609581	609567	19723Y	PARTICIPANT	\N	PRESENT	0
609582	609567	20018V	PARTICIPANT	\N	PRESENT	0
609583	609567	20030R	PARTICIPANT	\N	PRESENT	0
609584	609567	19679N	PARTICIPANT	\N	PRESENT	0
609585	609567	14331P	PARTICIPANT	\N	PRESENT	0
609586	609567	01058X	PARTICIPANT	\N	PRESENT	0
609587	609567	19713W	PARTICIPANT	\N	PRESENT	0
609588	608672	14189C	PARTICIPANT	\N	PRESENT	0
610687	610686	19749K	PARTICIPANT	\N	PRESENT	0
610847	610668	19629C	PARTICIPANT	\N	PRESENT	0
610848	610747	14026U	PARTICIPANT	\N	PRESENT	0
608655	608653	18193Q	PARTICIPANT	\N	PRESENT	0
608656	608653	19713W	PARTICIPANT	\N	PRESENT	0
610849	610668	20074E	PARTICIPANT	\N	PRESENT	0
610850	610668	20022R	PARTICIPANT	\N	PRESENT	0
610851	610668	04047H	PRESIDENT	0	PRESENT	0
610852	610668	19673G	PARTICIPANT	\N	PRESENT	0
610853	610668	01028R	PARTICIPANT	\N	PRESENT	0
610854	610668	19447X	PARTICIPANT	\N	PRESENT	0
610855	610668	11072N	PARTICIPANT	\N	PRESENT	0
610856	610668	14231L	PARTICIPANT	\N	PRESENT	0
610857	610668	14053L	PARTICIPANT	\N	PRESENT	0
610858	610668	20114U	PARTICIPANT	\N	PRESENT	0
610933	610747	20180F	PARTICIPANT	\N	PRESENT	0
610934	610747	19399H	PARTICIPANT	\N	PRESENT	0
610936	610747	20054A	PARTICIPANT	\N	PRESENT	0
610940	610747	20018V	PARTICIPANT	\N	PRESENT	0
610941	610747	14207L	PARTICIPANT	\N	PRESENT	0
610942	610747	20118Y	PARTICIPANT	\N	PRESENT	0
610943	610747	20090E	PARTICIPANT	\N	PRESENT	0
610946	610747	20082E	PARTICIPANT	\N	PRESENT	0
610947	610747	20092G	PARTICIPANT	\N	PRESENT	0
610948	610747	20024T	PARTICIPANT	\N	PRESENT	0
610949	610747	20086J	PARTICIPANT	\N	PRESENT	0
610950	610747	20072C	PARTICIPANT	\N	PRESENT	0
610951	610747	14221J	PARTICIPANT	\N	PRESENT	0
610952	610747	20032T	PARTICIPANT	\N	PRESENT	0
610953	610747	19954N	PARTICIPANT	\N	PRESENT	0
610954	610747	19782L	PARTICIPANT	\N	PRESENT	0
610955	610747	08061X	PARTICIPANT	\N	PRESENT	0
610956	610747	14038Y	PARTICIPANT	\N	PRESENT	0
610957	610747	11090Q	PARTICIPANT	\N	PRESENT	0
610958	610747	01025N	PARTICIPANT	\N	PRESENT	0
610959	610747	20078J	PARTICIPANT	\N	PRESENT	0
610960	610747	20076G	PARTICIPANT	\N	PRESENT	0
610961	610747	11103C	PARTICIPANT	\N	PRESENT	0
610962	610747	14189C	PARTICIPANT	\N	PRESENT	0
610963	610747	19575F	PARTICIPANT	\N	PRESENT	0
610965	610964	19701S	PARTICIPANT	\N	PRESENT	0
610966	610964	19693L	PARTICIPANT	\N	PRESENT	0
610967	610964	95063L	PARTICIPANT	\N	PRESENT	0
610968	610964	11026G	PARTICIPANT	\N	PRESENT	0
610969	610747	19507S	PARTICIPANT	\N	PRESENT	0
610971	610747	19349W	PARTICIPANT	\N	PRESENT	0
610973	610747	19443T	PARTICIPANT	\N	PRESENT	0
610974	610747	20064C	PARTICIPANT	\N	PRESENT	0
610975	610747	18083K	PARTICIPANT	\N	PRESENT	0
610976	610747	18193Q	PARTICIPANT	\N	PRESENT	0
610977	610747	19565D	PARTICIPANT	\N	PRESENT	0
610978	610747	14147R	PARTICIPANT	\N	PRESENT	0
610979	610747	14229S	PARTICIPANT	\N	PRESENT	0
610980	610747	19762G	PARTICIPANT	\N	PRESENT	0
610981	610747	08056B	PARTICIPANT	\N	PRESENT	0
610982	610747	19563B	PARTICIPANT	\N	PRESENT	0
610983	610747	14033T	PARTICIPANT	\N	PRESENT	0
610984	610747	20068G	PARTICIPANT	\N	PRESENT	0
610985	610747	19251M	PARTICIPANT	\N	PRESENT	0
610986	610747	19551W	PARTICIPANT	\N	PRESENT	0
610987	610747	14107H	PARTICIPANT	\N	PRESENT	0
610988	610747	08028W	PARTICIPANT	\N	PRESENT	0
610989	610747	19525U	PARTICIPANT	\N	PRESENT	0
610990	610747	11056N	PARTICIPANT	\N	PRESENT	0
610991	610747	11040E	PARTICIPANT	\N	PRESENT	0
610992	610747	20112S	PARTICIPANT	\N	PRESENT	0
610993	610747	16685X	PARTICIPANT	\N	PRESENT	0
610994	610747	20144B	PARTICIPANT	\N	PRESENT	0
610995	610747	19671E	PARTICIPANT	\N	PRESENT	0
610996	610747	20116W	PARTICIPANT	\N	PRESENT	0
610997	610747	19749K	PARTICIPANT	\N	PRESENT	0
610998	610747	19569H	PARTICIPANT	\N	PRESENT	0
610999	610747	19543W	PARTICIPANT	\N	PRESENT	0
611000	610747	20028X	PARTICIPANT	\N	PRESENT	0
611001	610747	05012A	PARTICIPANT	\N	PRESENT	0
611002	610747	20052X	PARTICIPANT	\N	PRESENT	0
611003	610747	14031R	PARTICIPANT	\N	PRESENT	0
611004	610747	19591F	PARTICIPANT	\N	PRESENT	0
611005	610747	14257W	PARTICIPANT	\N	PRESENT	0
611006	610747	19741B	PARTICIPANT	\N	PRESENT	0
611007	610747	19467C	PARTICIPANT	\N	PRESENT	0
611008	610747	97011G	PARTICIPANT	\N	PRESENT	0
611009	610747	14083S	PARTICIPANT	\N	PRESENT	0
611010	610747	19747H	PARTICIPANT	\N	PRESENT	0
611011	610747	19441R	PARTICIPANT	\N	PRESENT	0
611012	610747	19713W	PARTICIPANT	\N	PRESENT	0
611013	610747	19673G	PARTICIPANT	\N	PRESENT	0
611014	610747	08015R	PARTICIPANT	\N	PRESENT	0
611015	610747	19866P	PARTICIPANT	\N	PRESENT	0
611076	610748	14026U	PARTICIPANT	\N	PRESENT	0
611077	610748	11033F	PARTICIPANT	\N	PRESENT	0
611078	610748	20092G	PARTICIPANT	\N	PRESENT	0
611079	610748	19551W	PARTICIPANT	\N	PRESENT	0
611119	610748	18083K	PARTICIPANT	\N	PRESENT	0
611081	610748	19649G	PARTICIPANT	\N	PRESENT	0
611122	610748	14205J	PARTICIPANT	\N	PRESENT	0
611083	610748	20018V	PARTICIPANT	\N	PRESENT	0
611084	610748	14221J	PARTICIPANT	\N	PRESENT	0
611085	610748	19629C	PARTICIPANT	\N	PRESENT	0
611086	610748	19866P	PARTICIPANT	\N	PRESENT	0
611087	610748	19591F	PARTICIPANT	\N	PRESENT	0
611089	610748	19673G	PARTICIPANT	\N	PRESENT	0
611090	610748	20266L	PARTICIPANT	\N	PRESENT	0
611091	610748	04085P	PARTICIPANT	\N	PRESENT	0
611092	610748	11040E	PARTICIPANT	\N	PRESENT	0
611093	610748	14089Y	PARTICIPANT	\N	PRESENT	0
611094	610748	14107H	PARTICIPANT	\N	PRESENT	0
611095	610748	14207L	PARTICIPANT	\N	PRESENT	0
611096	610748	20072C	PARTICIPANT	\N	PRESENT	0
611097	610748	20116W	PARTICIPANT	\N	PRESENT	0
611098	610748	19643A	PARTICIPANT	\N	PRESENT	0
611099	610748	20078J	PARTICIPANT	\N	PRESENT	0
611100	610748	20090E	PARTICIPANT	\N	PRESENT	0
611101	610748	08056B	PARTICIPANT	\N	PRESENT	0
611102	610748	11090Q	PARTICIPANT	\N	PRESENT	0
611103	610748	11103C	PARTICIPANT	\N	PRESENT	0
611104	610748	14147R	PARTICIPANT	\N	PRESENT	0
611105	610748	20068G	PARTICIPANT	\N	PRESENT	0
611106	610748	20180F	PARTICIPANT	\N	PRESENT	0
611107	610748	19741B	PARTICIPANT	\N	PRESENT	0
611108	610748	19507S	PARTICIPANT	\N	PRESENT	0
611109	610748	20034V	PARTICIPANT	\N	PRESENT	0
611110	610748	19954N	PARTICIPANT	\N	PRESENT	0
611111	610748	19467C	PARTICIPANT	\N	PRESENT	0
611112	610748	19747H	PARTICIPANT	\N	PRESENT	0
611113	610748	19762G	PARTICIPANT	\N	PRESENT	0
611114	610748	05012A	PARTICIPANT	\N	PRESENT	0
611115	610748	19782L	PARTICIPANT	\N	PRESENT	0
611116	610748	20080C	PARTICIPANT	\N	PRESENT	0
611118	610748	19349W	PARTICIPANT	\N	PRESENT	0
611120	610748	97011G	PARTICIPANT	\N	PRESENT	0
611121	610748	20052X	PARTICIPANT	\N	PRESENT	0
611123	610748	19569H	PARTICIPANT	\N	PRESENT	0
611124	610748	19543W	PARTICIPANT	\N	PRESENT	0
611125	610748	19441R	PARTICIPANT	\N	PRESENT	0
609145	608514	19399H	PARTICIPANT	\N	PRESENT	0
609146	608514	20092G	PARTICIPANT	\N	PRESENT	0
609147	608514	14207L	PARTICIPANT	\N	PRESENT	0
609148	608514	14257W	PARTICIPANT	\N	PRESENT	0
609149	608514	19369B	PARTICIPANT	\N	PRESENT	0
609150	608514	18193Q	PARTICIPANT	\N	PRESENT	0
609151	608514	19507S	PARTICIPANT	\N	PRESENT	0
609152	608514	20062A	PARTICIPANT	\N	PRESENT	0
609153	608514	20140W	PARTICIPANT	\N	PRESENT	0
609154	608514	14083S	PARTICIPANT	\N	PRESENT	0
609155	608514	19866P	PARTICIPANT	\N	PRESENT	0
609156	608514	19479G	PARTICIPANT	\N	PRESENT	0
609157	608514	19441R	PARTICIPANT	\N	PRESENT	0
609159	608514	19585H	PARTICIPANT	\N	PRESENT	0
609160	608514	20142Y	PARTICIPANT	\N	PRESENT	0
609161	608514	20018V	PARTICIPANT	\N	PRESENT	0
609162	608514	19503N	PARTICIPANT	\N	PRESENT	0
609163	608514	19631V	PARTICIPANT	\N	PRESENT	0
609164	608514	20088L	PARTICIPANT	\N	PRESENT	0
609165	608514	20032T	PARTICIPANT	\N	PRESENT	0
609166	608514	14031R	PARTICIPANT	\N	PRESENT	0
609317	608647	14259Y	PARTICIPANT	\N	PRESENT	0
609318	608647	11056N	PARTICIPANT	\N	PRESENT	0
609319	608234	11067R	PARTICIPANT	\N	PRESENT	0
609143	608514	14026U	PARTICIPANT	\N	PRESENT	0
609144	608514	19583F	PARTICIPANT	\N	PRESENT	0
609320	608234	19569H	PARTICIPANT	\N	PRESENT	0
609321	608234	19798U	PARTICIPANT	\N	PRESENT	0
609322	608234	11097X	PARTICIPANT	\N	PRESENT	0
609323	608234	19415P	PARTICIPANT	\N	PRESENT	0
609324	608234	18193Q	PARTICIPANT	\N	PRESENT	0
609325	608234	14223L	PARTICIPANT	\N	PRESENT	0
609326	608234	14026U	PARTICIPANT	\N	PRESENT	0
609327	608234	11031D	PARTICIPANT	\N	PRESENT	0
609328	608234	19703U	PARTICIPANT	\N	PRESENT	0
609329	608234	19679N	PARTICIPANT	\N	PRESENT	0
609330	608234	14042U	PARTICIPANT	\N	PRESENT	0
609331	608234	14195A	PARTICIPANT	\N	PRESENT	0
609332	608234	19367Y	PARTICIPANT	\N	PRESENT	0
609333	608234	14213J	PARTICIPANT	\N	PRESENT	0
609334	608234	14217N	PARTICIPANT	\N	PRESENT	0
609335	608234	10006L	PRESIDENT	0	PRESENT	0
609336	608234	20130U	PARTICIPANT	\N	PRESENT	0
609337	608234	11045K	PARTICIPANT	\N	PRESENT	0
609338	608234	08045X	PARTICIPANT	\N	PRESENT	0
609339	608234	17965H	PARTICIPANT	\N	PRESENT	0
609340	608234	19691J	PARTICIPANT	\N	PRESENT	0
609341	608234	20172F	PARTICIPANT	\N	PRESENT	0
609342	608234	19723Y	PARTICIPANT	\N	PRESENT	0
609343	608234	11103C	PARTICIPANT	\N	PRESENT	0
609344	608234	14071N	PARTICIPANT	\N	PRESENT	0
609345	608234	19760E	PARTICIPANT	\N	PRESENT	0
609346	608647	11026G	PARTICIPANT	\N	PRESENT	0
609347	608647	08018U	PARTICIPANT	\N	PRESENT	0
609348	608661	19699S	PARTICIPANT	\N	PRESENT	0
609349	608661	19533U	PARTICIPANT	\N	PRESENT	0
609350	608661	04033B	PARTICIPANT	\N	PRESENT	0
609351	608661	14229S	PARTICIPANT	\N	PRESENT	0
609352	608661	19573D	PARTICIPANT	\N	PRESENT	0
609353	608661	20112S	PARTICIPANT	\N	PRESENT	0
609354	608661	20026V	PARTICIPANT	\N	PRESENT	0
609355	608661	20132W	PARTICIPANT	\N	PRESENT	0
609356	608661	19643A	PARTICIPANT	\N	PRESENT	0
609357	608661	19651A	PARTICIPANT	\N	PRESENT	0
609358	608661	14073Q	PARTICIPANT	\N	PRESENT	0
609359	608661	19611R	PRESIDENT	0	PRESENT	0
609360	608661	20142Y	PARTICIPANT	\N	PRESENT	0
609361	608661	20048C	PARTICIPANT	\N	PRESENT	0
609362	608661	19693L	PARTICIPANT	\N	PRESENT	0
609363	608661	19399H	PARTICIPANT	\N	PRESENT	0
609364	608661	20052X	PARTICIPANT	\N	PRESENT	0
609365	608661	14030Q	PARTICIPANT	\N	PRESENT	0
609366	608661	20056C	PARTICIPANT	\N	PRESENT	0
609367	608661	20180F	PARTICIPANT	\N	PRESENT	0
609368	608661	04059M	PARTICIPANT	\N	PRESENT	0
609369	608661	20264J	PARTICIPANT	\N	PRESENT	0
609370	608661	14109K	PARTICIPANT	\N	PRESENT	0
609371	608661	19758L	PARTICIPANT	\N	PRESENT	0
609372	608661	20084G	PARTICIPANT	\N	PRESENT	0
609373	608661	19735D	PARTICIPANT	\N	EXCUSE	0
609374	608661	11109J	PARTICIPANT	\N	EXCUSE	0
609446	608672	14331P	PARTICIPANT	\N	PRESENT	0
609447	608672	07029T	PARTICIPANT	\N	PRESENT	0
609448	608672	08010L	PARTICIPANT	\N	PRESENT	0
609449	608672	20050V	PARTICIPANT	\N	PRESENT	0
609451	608672	14083S	PARTICIPANT	\N	PRESENT	0
609452	608672	20080C	PARTICIPANT	\N	EXCUSE	0
609458	606464	18083K	PARTICIPANT	\N	PRESENT	0
609459	608649	14053L	PARTICIPANT	\N	PRESENT	0
609460	608649	19649G	PARTICIPANT	\N	PRESENT	0
609461	608649	19543W	PARTICIPANT	\N	PRESENT	0
609462	608649	19585H	PARTICIPANT	\N	PRESENT	0
609463	608649	04047H	PRESIDENT	0	PRESENT	0
609464	608649	01028R	PARTICIPANT	\N	PRESENT	0
609465	608649	19447X	PARTICIPANT	\N	PRESENT	0
609466	608649	19725B	PARTICIPANT	\N	PRESENT	0
609467	608649	11056N	PARTICIPANT	\N	PRESENT	0
609468	608649	17737W	PARTICIPANT	\N	PRESENT	0
609469	608649	95063L	PARTICIPANT	\N	PRESENT	0
609470	608649	14147R	PARTICIPANT	\N	PRESENT	0
609471	608649	14179A	PARTICIPANT	\N	PRESENT	0
609472	608649	14215L	PARTICIPANT	\N	PRESENT	0
609473	608649	19749K	PARTICIPANT	\N	PRESENT	0
609474	608649	20022R	PARTICIPANT	\N	PRESENT	0
609475	608649	14111D	PARTICIPANT	\N	PRESENT	0
609476	608649	08018U	PARTICIPANT	\N	PRESENT	0
609477	608649	19729F	PARTICIPANT	\N	EXCUSE	0
609478	608649	20074E	PARTICIPANT	\N	PRESENT	0
609479	608711	19768N	PARTICIPANT	\N	PRESENT	0
609480	608711	20088L	PARTICIPANT	\N	PRESENT	0
609481	608711	19515S	PARTICIPANT	\N	PRESENT	0
609482	608711	19782L	PARTICIPANT	\N	PRESENT	0
609483	608711	20092G	PARTICIPANT	\N	PRESENT	0
609484	608711	11077T	PARTICIPANT	\N	PRESENT	0
609485	608711	01043Q	PARTICIPANT	\N	PRESENT	0
609486	608711	14357A	PARTICIPANT	\N	PRESENT	0
609487	608711	19441R	PARTICIPANT	\N	PRESENT	0
609488	608711	19413M	PARTICIPANT	\N	PRESENT	0
609489	608711	20082E	PARTICIPANT	\N	PRESENT	0
609490	608711	20094J	PARTICIPANT	\N	PRESENT	0
609491	608711	04045F	PARTICIPANT	\N	PRESENT	0
609492	608711	20104S	PARTICIPANT	\N	PRESENT	0
609493	608711	19705W	PARTICIPANT	\N	PRESENT	0
609494	608711	19707Y	PARTICIPANT	\N	PRESENT	0
609495	608711	08015R	PARTICIPANT	\N	PRESENT	0
609496	608711	19575F	PARTICIPANT	\N	PRESENT	0
609497	608711	19369B	PARTICIPANT	\N	PRESENT	0
609498	608711	20018V	PARTICIPANT	\N	PRESENT	0
609499	608711	19511N	PARTICIPANT	\N	PRESENT	0
609500	608711	08028W	PARTICIPANT	\N	PRESENT	0
609501	608711	19563B	PARTICIPANT	\N	PRESENT	0
609502	608711	20028X	PARTICIPANT	\N	PRESENT	0
609503	608711	20030R	PARTICIPANT	\N	PRESENT	0
609504	608711	14038Y	PARTICIPANT	\N	PRESENT	0
609505	608711	19467C	PARTICIPANT	\N	PRESENT	0
609506	608711	14187A	PARTICIPANT	\N	PRESENT	0
609507	608711	20144B	PARTICIPANT	\N	PRESENT	0
609508	608711	19695N	PARTICIPANT	\N	PRESENT	0
609509	608711	11090Q	PRESIDENT	0	PRESENT	0
609510	608711	14033T	PARTICIPANT	\N	PRESENT	0
609511	608711	01025N	PARTICIPANT	\N	PRESENT	0
609512	608711	20054A	PARTICIPANT	\N	PRESENT	0
609513	608711	20174H	PARTICIPANT	\N	PRESENT	0
609514	608711	14205J	PARTICIPANT	\N	PRESENT	0
609515	608711	20062A	PARTICIPANT	\N	PRESENT	0
609516	608711	14251Q	PARTICIPANT	\N	PRESENT	0
609517	608711	19507S	PARTICIPANT	\N	PRESENT	0
609518	608711	19747H	PARTICIPANT	\N	PRESENT	0
609519	608711	14207L	PARTICIPANT	\N	PRESENT	0
609520	608711	14257W	PARTICIPANT	\N	PRESENT	0
609521	608711	20078J	PARTICIPANT	\N	PRESENT	0
609522	608649	05008E	PARTICIPANT	\N	PRESENT	0
609523	608709	19768N	PARTICIPANT	\N	PRESENT	0
609524	608709	20088L	PARTICIPANT	\N	PRESENT	0
609525	608709	19515S	PARTICIPANT	\N	PRESENT	0
609526	608709	19782L	PARTICIPANT	\N	PRESENT	0
609527	608709	20092G	PARTICIPANT	\N	PRESENT	0
609528	608709	11077T	PARTICIPANT	\N	PRESENT	0
609529	608709	01043Q	PARTICIPANT	\N	PRESENT	0
609530	608709	14357A	PARTICIPANT	\N	PRESENT	0
606937	606306	20090E	PARTICIPANT	\N	PRESENT	0
606938	606306	19593H	PARTICIPANT	\N	PRESENT	0
606939	606306	19798U	PARTICIPANT	\N	PRESENT	0
606940	606306	14033T	PARTICIPANT	\N	PRESENT	0
606941	606306	20068G	PARTICIPANT	\N	PRESENT	0
606942	606306	20074E	PARTICIPANT	\N	PRESENT	0
606943	606306	20082E	PARTICIPANT	\N	PRESENT	0
606944	606306	12028B	PARTICIPANT	\N	PRESENT	0
606945	606306	19689Q	PARTICIPANT	\N	PRESENT	0
606946	606306	14223L	PARTICIPANT	\N	PRESENT	0
606947	606306	19766L	PARTICIPANT	\N	PRESENT	0
606948	606306	10015M	PARTICIPANT	\N	PRESENT	0
606949	606306	19826F	PARTICIPANT	\N	PRESENT	0
606950	606306	19447X	PARTICIPANT	\N	PRESENT	0
606951	606306	11040E	PARTICIPANT	\N	PRESENT	0
606952	606306	14173T	PARTICIPANT	\N	PRESENT	0
606953	606306	20028X	PARTICIPANT	\N	PRESENT	0
606954	606306	11053K	PARTICIPANT	\N	PRESENT	0
606955	606306	19577H	PARTICIPANT	\N	PRESENT	0
606956	606306	20126Y	PARTICIPANT	\N	PRESENT	0
606957	606306	20076G	PARTICIPANT	\N	PRESENT	0
606958	606306	14083S	PARTICIPANT	\N	PRESENT	0
606959	606306	14189C	PARTICIPANT	\N	PRESENT	0
606960	606306	04045F	PARTICIPANT	\N	PRESENT	0
606961	606306	19591F	PARTICIPANT	\N	PRESENT	0
606962	606306	18083K	PARTICIPANT	\N	PRESENT	0
606963	606306	19741B	PARTICIPANT	\N	PRESENT	0
606964	606306	19667J	PARTICIPANT	\N	PRESENT	0
606965	606306	11103C	PARTICIPANT	\N	PRESENT	0
606966	606306	19335Q	PARTICIPANT	\N	PRESENT	0
606967	606306	19683J	PARTICIPANT	\N	PRESENT	0
606968	606306	19669L	PARTICIPANT	\N	PRESENT	0
606969	606306	14229S	PARTICIPANT	\N	PRESENT	0
606970	606306	20070A	PARTICIPANT	\N	PRESENT	0
606971	606306	14121F	PARTICIPANT	\N	PRESENT	0
606972	606306	19619A	PARTICIPANT	\N	PRESENT	0
606973	606306	20084G	PARTICIPANT	\N	PRESENT	0
606974	606306	14257W	PARTICIPANT	\N	PRESENT	0
606975	606306	11070L	PARTICIPANT	\N	PRESENT	0
606976	606306	08010L	PARTICIPANT	\N	PRESENT	0
606977	606306	08028W	PARTICIPANT	\N	PRESENT	0
606978	606306	19681G	PARTICIPANT	\N	PRESENT	0
606979	606306	19719D	PARTICIPANT	\N	PRESENT	0
606980	606306	20072C	PARTICIPANT	\N	PRESENT	0
606981	606306	08073C	PARTICIPANT	\N	PRESENT	0
606982	606306	11104D	PARTICIPANT	\N	PRESENT	0
606983	606306	14001X	PARTICIPANT	\N	PRESENT	0
606984	606306	11077T	PARTICIPANT	\N	PRESENT	0
606985	606306	20080C	PARTICIPANT	\N	PRESENT	0
606986	606306	07029T	PARTICIPANT	\N	PRESENT	0
606987	606306	99004R	PARTICIPANT	\N	PRESENT	0
606988	606306	01058X	PARTICIPANT	\N	PRESENT	0
606989	606306	14107H	PARTICIPANT	\N	PRESENT	0
606935	606306	19479G	PARTICIPANT	\N	PRESENT	0
606936	606306	11012A	PARTICIPANT	\N	PRESENT	0
606990	606306	19629C	PARTICIPANT	\N	PRESENT	0
606991	606306	04059M	PARTICIPANT	\N	PRESENT	0
606992	606306	11066Q	PARTICIPANT	\N	PRESENT	0
606993	606306	19553Y	PARTICIPANT	\N	PRESENT	0
606994	606306	19866P	PARTICIPANT	\N	PRESENT	0
606995	606306	01028R	PARTICIPANT	\N	PRESENT	0
606996	606306	20252E	PARTICIPANT	\N	PRESENT	0
606997	606306	14021P	PARTICIPANT	\N	PRESENT	0
606998	606306	20042V	PARTICIPANT	\N	PRESENT	0
607080	606306	20092G	PARTICIPANT	\N	PRESENT	0
607000	606306	17779H	PARTICIPANT	\N	PRESENT	0
607071	606306	20134Y	PARTICIPANT	\N	PRESENT	0
607002	606306	20100N	PARTICIPANT	\N	PRESENT	0
607003	606306	20018V	PARTICIPANT	\N	PRESENT	0
607004	606306	19531S	PARTICIPANT	\N	PRESENT	0
607005	606306	05008E	PARTICIPANT	\N	PRESENT	0
607007	606306	14147R	PARTICIPANT	\N	PRESENT	0
607008	606306	14211G	PARTICIPANT	\N	PRESENT	0
607009	606306	08015R	PARTICIPANT	\N	PRESENT	0
607010	606306	19693L	PARTICIPANT	\N	PRESENT	0
607011	606306	04092N	PARTICIPANT	\N	PRESENT	0
607012	606306	08011M	PARTICIPANT	\N	PRESENT	0
607013	606306	20078J	PARTICIPANT	\N	PRESENT	0
607014	606306	19643A	PARTICIPANT	\N	PRESENT	0
607015	606306	19515S	PARTICIPANT	\N	PRESENT	0
607016	606306	11097X	PARTICIPANT	\N	PRESENT	0
607017	606306	14187A	PARTICIPANT	\N	PRESENT	0
607018	606306	01057W	PARTICIPANT	\N	PRESENT	0
607082	606306	19673G	PARTICIPANT	\N	PRESENT	0
607020	606306	20046A	PARTICIPANT	\N	PRESENT	0
607021	606306	20102Q	PARTICIPANT	\N	PRESENT	0
607022	606306	19758L	PARTICIPANT	\N	PRESENT	0
607023	606306	04085P	PARTICIPANT	\N	PRESENT	0
607069	606306	20060X	PARTICIPANT	\N	PRESENT	0
607025	606306	20116W	PARTICIPANT	\N	PRESENT	0
607067	606306	19387D	PARTICIPANT	\N	PRESENT	0
607068	606306	19782L	PARTICIPANT	\N	PRESENT	0
607072	606306	19251M	PARTICIPANT	\N	PRESENT	0
607079	606306	04057K	PARTICIPANT	\N	PRESENT	0
607070	606306	11072N	PARTICIPANT	\N	PRESENT	0
607031	606306	20062A	PARTICIPANT	\N	PRESENT	0
607032	606306	08056B	PARTICIPANT	\N	PRESENT	0
607046	606306	19333N	PARTICIPANT	\N	PRESENT	0
607048	606306	14219Q	PARTICIPANT	\N	PRESENT	0
607081	606306	20266L	PARTICIPANT	\N	PRESENT	0
607036	606306	17965H	PARTICIPANT	\N	PRESENT	0
607037	606306	11045K	PARTICIPANT	\N	PRESENT	0
607038	606306	11056N	PARTICIPANT	\N	PRESENT	0
607039	606306	95063L	PARTICIPANT	\N	PRESENT	0
607040	606306	19503N	PARTICIPANT	\N	PRESENT	0
607041	606306	20032T	PARTICIPANT	\N	PRESENT	0
607042	606306	14111D	PARTICIPANT	\N	PRESENT	0
607043	606306	11090Q	PARTICIPANT	\N	PRESENT	0
607044	606306	19551W	PARTICIPANT	\N	PRESENT	0
607045	606306	19725B	PARTICIPANT	\N	PRESENT	0
607047	606306	19703U	PARTICIPANT	\N	PRESENT	0
607049	606306	19691J	PARTICIPANT	\N	PRESENT	0
607050	606306	19820Y	PARTICIPANT	\N	PRESENT	0
607051	606306	14133K	PARTICIPANT	\N	PRESENT	0
607052	606306	17229F	PARTICIPANT	\N	PRESENT	0
607053	606306	20048C	PARTICIPANT	\N	PRESENT	0
607054	606306	14327T	PARTICIPANT	\N	PRESENT	0
607055	606306	19527W	PARTICIPANT	\N	PRESENT	0
607056	606306	11099A	PARTICIPANT	\N	PRESENT	0
607057	606306	20140W	PARTICIPANT	\N	PRESENT	0
607058	606306	14215L	PARTICIPANT	\N	PRESENT	0
607059	606306	19507S	PARTICIPANT	\N	PRESENT	0
607060	606306	19768N	PARTICIPANT	\N	PRESENT	0
607061	606306	20148F	PARTICIPANT	\N	PRESENT	0
607062	606306	19679N	PARTICIPANT	\N	PRESENT	0
607063	606306	20020P	PARTICIPANT	\N	PRESENT	0
607064	606306	20086J	PARTICIPANT	\N	PRESENT	0
607065	606306	14030Q	PARTICIPANT	\N	PRESENT	0
607066	606306	20132W	PARTICIPANT	\N	PRESENT	0
607073	606306	20022R	PARTICIPANT	\N	PRESENT	0
607074	606306	11054L	PARTICIPANT	\N	PRESENT	0
607075	606306	20124W	PARTICIPANT	\N	PRESENT	0
607076	606306	11110B	PARTICIPANT	\N	PRESENT	0
607077	606306	14109K	PARTICIPANT	\N	PRESENT	0
607078	606306	14221J	PARTICIPANT	\N	PRESENT	0
607083	606306	20038A	PARTICIPANT	\N	PRESENT	0
607084	606306	20026V	PARTICIPANT	\N	PRESENT	0
607085	606306	19467C	PARTICIPANT	\N	PRESENT	0
607086	606306	08060W	PARTICIPANT	\N	PRESENT	0
607087	606306	20056C	PARTICIPANT	\N	PRESENT	0
607088	606306	20136B	PARTICIPANT	\N	PRESENT	0
607089	606306	20098N	PARTICIPANT	\N	PRESENT	0
607090	606306	19383Y	PARTICIPANT	\N	PRESENT	0
607091	606306	20096L	PARTICIPANT	\N	PRESENT	0
607092	606306	20104S	PARTICIPANT	\N	PRESENT	0
607093	606306	19699S	PARTICIPANT	\N	PRESENT	0
607094	606306	19747H	PARTICIPANT	\N	PRESENT	0
607095	606306	20144B	PARTICIPANT	\N	PRESENT	0
607096	606306	14213J	PARTICIPANT	\N	PRESENT	0
607097	606306	97011G	PARTICIPANT	\N	PRESENT	0
607098	606306	14357A	PARTICIPANT	\N	PRESENT	0
607099	606306	20094J	PARTICIPANT	\N	PRESENT	0
607100	606306	14329V	PARTICIPANT	\N	PRESENT	0
607101	606306	19369B	PARTICIPANT	\N	PRESENT	0
607102	606306	19549D	PARTICIPANT	\N	PRESENT	0
607103	606306	19762G	PARTICIPANT	\N	PRESENT	0
607104	606306	19415P	PARTICIPANT	\N	PRESENT	0
607106	606306	19621T	PARTICIPANT	\N	PRESENT	0
607107	606306	12016W	PARTICIPANT	\N	PRESENT	0
607108	606306	04047H	PARTICIPANT	\N	PRESENT	0
599690	599647	19691J	PARTICIPANT	\N	PRESENT	0
599691	599647	19760E	PARTICIPANT	\N	PRESENT	0
599692	599647	19798U	PARTICIPANT	\N	PRESENT	0
599693	599672	19760E	PARTICIPANT	\N	PRESENT	0
599695	599672	19691J	PARTICIPANT	\N	PRESENT	0
599696	599672	19798U	PARTICIPANT	\N	PRESENT	0
599754	598117	04045F	PARTICIPANT	\N	EXCUSE	0
599755	598117	20034V	PARTICIPANT	\N	EXCUSE	0
599756	599751	19631V	PARTICIPANT	\N	PRESENT	0
599757	599751	19515S	PARTICIPANT	\N	PRESENT	0
599758	599751	19575F	PARTICIPANT	\N	PRESENT	0
599759	599751	20094J	PARTICIPANT	\N	PRESENT	0
599760	599751	20078J	PARTICIPANT	\N	PRESENT	0
599761	599751	19747H	PARTICIPANT	\N	PRESENT	0
599762	599751	19383Y	PARTICIPANT	\N	PRESENT	0
599763	599751	19782L	PARTICIPANT	\N	PRESENT	0
599764	599751	14207L	PARTICIPANT	\N	PRESENT	0
599765	599751	14038Y	PARTICIPANT	\N	PRESENT	0
599766	599751	20144B	PARTICIPANT	\N	PRESENT	0
599767	599751	14357A	PARTICIPANT	\N	PRESENT	0
599768	599751	19507S	PARTICIPANT	\N	PRESENT	0
599769	599751	14187A	PARTICIPANT	\N	PRESENT	0
599770	599751	20174H	PARTICIPANT	\N	PRESENT	0
599771	599751	01025N	PARTICIPANT	\N	PRESENT	0
599772	599751	19695N	PARTICIPANT	\N	PRESENT	0
599773	599751	14033T	PARTICIPANT	\N	PRESENT	0
599774	599751	20034V	PARTICIPANT	\N	EXCUSE	0
599775	599751	11099A	PARTICIPANT	\N	PRESENT	0
599776	599751	08015R	PARTICIPANT	\N	PRESENT	0
599777	599751	19467C	PARTICIPANT	\N	PRESENT	0
599778	599751	11077T	PARTICIPANT	\N	PRESENT	0
599779	599751	14205J	PARTICIPANT	\N	PRESENT	0
599780	599751	19441R	PARTICIPANT	\N	PRESENT	0
599781	599751	14251Q	PARTICIPANT	\N	PRESENT	0
599782	599751	19563B	PARTICIPANT	\N	PRESENT	0
599783	599751	20028X	PARTICIPANT	\N	PRESENT	0
599784	599751	20018V	PARTICIPANT	\N	PRESENT	0
599785	599751	19369B	PARTICIPANT	\N	PRESENT	0
599786	599751	14257W	PARTICIPANT	\N	PRESENT	0
599787	599751	20030R	PARTICIPANT	\N	PRESENT	0
599788	599751	11090Q	PRESIDENT	0	PRESENT	0
599789	599751	20082E	PARTICIPANT	\N	PRESENT	0
599790	599751	20054A	PARTICIPANT	\N	PRESENT	0
599791	599751	20092G	PARTICIPANT	\N	PRESENT	0
599792	599751	04045F	PARTICIPANT	\N	EXCUSE	0
599793	599751	20062A	PARTICIPANT	\N	PRESENT	0
599794	599751	19413M	PARTICIPANT	\N	PRESENT	0
603724	603142	04033B	PARTICIPANT	\N	PRESENT	0
603725	603142	01048V	PARTICIPANT	\N	PRESENT	0
603726	603142	14225N	PARTICIPANT	\N	PRESENT	0
603727	603142	10015M	PARTICIPANT	\N	PRESENT	0
603728	603142	14223L	PARTICIPANT	\N	PRESENT	0
603729	603142	19515S	PARTICIPANT	\N	PRESENT	0
603730	603142	14191V	PARTICIPANT	\N	PRESENT	0
603731	603142	11080N	PARTICIPANT	\N	PRESENT	0
603732	603142	19549D	PARTICIPANT	\N	PRESENT	0
603733	603142	05012A	PARTICIPANT	\N	PRESENT	0
603734	603142	19421M	PARTICIPANT	\N	PRESENT	0
603735	603142	14215L	PARTICIPANT	\N	PRESENT	0
603736	603142	04043D	PARTICIPANT	\N	PRESENT	0
603737	603142	20038A	PARTICIPANT	\N	PRESENT	0
603738	603142	19667J	PARTICIPANT	\N	PRESENT	0
603739	603142	14253S	PARTICIPANT	\N	PRESENT	0
603740	603142	17737W	PARTICIPANT	\N	PRESENT	0
603741	603142	14331P	PARTICIPANT	\N	PRESENT	0
603742	603142	20032T	PARTICIPANT	\N	PRESENT	0
603743	603142	08045X	PARTICIPANT	\N	PRESENT	0
603744	603142	20022R	PARTICIPANT	\N	PRESENT	0
603745	603142	11066Q	PARTICIPANT	\N	PRESENT	0
603746	603142	11104D	PARTICIPANT	\N	PRESENT	0
603747	603142	20118Y	PARTICIPANT	\N	PRESENT	0
603748	603142	14105F	PARTICIPANT	\N	PRESENT	0
603749	603142	11067R	PARTICIPANT	\N	PRESENT	0
603750	603142	19820Y	PARTICIPANT	\N	PRESENT	0
603751	603142	14257W	PARTICIPANT	\N	PRESENT	0
603752	603142	19671E	PARTICIPANT	\N	PRESENT	0
603753	603142	19758L	PARTICIPANT	\N	PRESENT	0
603754	603142	19760E	PARTICIPANT	\N	PRESENT	0
603755	603142	11040E	PARTICIPANT	\N	PRESENT	0
603756	603142	19581D	PARTICIPANT	\N	PRESENT	0
603757	603142	11056N	PARTICIPANT	\N	PRESENT	0
603758	603142	19367Y	PARTICIPANT	\N	PRESENT	0
603759	603142	95041E	PARTICIPANT	\N	PRESENT	0
603760	603142	04085P	PARTICIPANT	\N	PRESENT	0
603761	603142	12041X	PARTICIPANT	\N	PRESENT	0
603762	603142	20252E	PARTICIPANT	\N	PRESENT	0
603763	603142	19695N	PARTICIPANT	\N	PRESENT	0
603764	603142	11077T	PARTICIPANT	\N	PRESENT	0
603765	603142	19593H	PARTICIPANT	\N	PRESENT	0
603766	603142	20046A	PARTICIPANT	\N	PRESENT	0
603767	603142	20102Q	PARTICIPANT	\N	PRESENT	0
603768	603142	19621T	PARTICIPANT	\N	PRESENT	0
603769	603142	20036X	PARTICIPANT	\N	PRESENT	0
603770	603142	20020P	PARTICIPANT	\N	PRESENT	0
603771	603142	19651A	PARTICIPANT	\N	PRESENT	0
603772	603142	20174H	PARTICIPANT	\N	PRESENT	0
603773	603142	20106U	PARTICIPANT	\N	PRESENT	0
603774	603142	20054A	PARTICIPANT	\N	PRESENT	0
603775	603142	19301E	PARTICIPANT	\N	PRESENT	0
603776	603142	20126Y	PARTICIPANT	\N	PRESENT	0
603777	603142	11072N	PARTICIPANT	\N	PRESENT	0
603778	603142	19675J	PARTICIPANT	\N	PRESENT	0
603779	603142	19717B	PARTICIPANT	\N	PRESENT	0
603780	603142	19681G	PARTICIPANT	\N	PRESENT	0
603781	603142	11012A	PARTICIPANT	\N	PRESENT	0
603782	603142	14357A	PARTICIPANT	\N	PRESENT	0
603783	603142	14207L	PARTICIPANT	\N	PRESENT	0
603784	603142	07033P	PARTICIPANT	\N	PRESENT	0
603785	603142	14107H	PARTICIPANT	\N	PRESENT	0
603786	603142	20132W	PARTICIPANT	\N	PRESENT	0
603787	603142	19553Y	PARTICIPANT	\N	PRESENT	0
603788	603142	14329V	PARTICIPANT	\N	PRESENT	0
603789	603142	19719D	PARTICIPANT	\N	PRESENT	0
603790	603142	19629C	PARTICIPANT	\N	PRESENT	0
603791	603142	20062A	PARTICIPANT	\N	PRESENT	0
603792	603142	01057W	PARTICIPANT	\N	PRESENT	0
603793	603142	04057K	PARTICIPANT	\N	PRESENT	0
603794	603142	19768N	PARTICIPANT	\N	PRESENT	0
603795	603142	08015R	PARTICIPANT	\N	PRESENT	0
603796	603142	11065P	PARTICIPANT	\N	PRESENT	0
603797	603142	20100N	PARTICIPANT	\N	PRESENT	0
603798	603142	19657G	PARTICIPANT	\N	PRESENT	0
603799	603142	07029T	PARTICIPANT	\N	PRESENT	0
603800	603142	14251Q	PARTICIPANT	\N	PRESENT	0
603801	603142	19643A	PARTICIPANT	\N	PRESENT	0
603802	603142	14026U	PARTICIPANT	\N	PRESENT	0
603803	603142	19573D	PARTICIPANT	\N	PRESENT	0
603804	603142	20026V	PARTICIPANT	\N	PRESENT	0
603805	603142	19503N	PARTICIPANT	\N	PRESENT	0
603806	603142	20098N	PARTICIPANT	\N	PRESENT	0
603807	603142	14097Y	PARTICIPANT	\N	PRESENT	0
603808	603142	20096L	PARTICIPANT	\N	PRESENT	0
603809	603142	20180F	PARTICIPANT	\N	PRESENT	0
603810	603142	92040Q	PARTICIPANT	\N	PRESENT	0
603811	603142	20136B	PARTICIPANT	\N	PRESENT	0
603812	603142	14038Y	PARTICIPANT	\N	PRESENT	0
603813	603142	19723Y	PARTICIPANT	\N	PRESENT	0
603814	603142	19467C	PARTICIPANT	\N	PRESENT	0
603815	603142	20056C	PARTICIPANT	\N	PRESENT	0
603816	603142	20172F	PARTICIPANT	\N	PRESENT	0
603817	603142	20138D	PARTICIPANT	\N	PRESENT	0
603818	603142	20108W	PARTICIPANT	\N	PRESENT	0
603819	603142	19383Y	PARTICIPANT	\N	PRESENT	0
603820	603142	08010L	PARTICIPANT	\N	PRESENT	0
603821	603142	04035D	PARTICIPANT	\N	PRESENT	0
603822	603142	19399H	PARTICIPANT	\N	PRESENT	0
603823	603142	14033T	PARTICIPANT	\N	PRESENT	0
603824	603142	14213J	PARTICIPANT	\N	PRESENT	0
603825	603142	20110Q	PARTICIPANT	\N	PRESENT	0
603826	603142	20082E	PARTICIPANT	\N	PRESENT	0
603827	603142	20112S	PARTICIPANT	\N	PRESENT	0
603828	603142	11031D	PARTICIPANT	\N	PRESENT	0
603829	603142	19565D	PARTICIPANT	\N	PRESENT	0
603830	603142	19669L	PARTICIPANT	\N	PRESENT	0
603831	603142	01028R	PARTICIPANT	\N	PRESENT	0
603832	603142	19782L	PARTICIPANT	\N	PRESENT	0
603833	603142	19659J	PARTICIPANT	\N	PRESENT	0
603834	603142	14055N	PARTICIPANT	\N	PRESENT	0
603835	603142	04042C	PARTICIPANT	\N	PRESENT	0
603837	603142	19545Y	PARTICIPANT	\N	PRESENT	0
603838	603142	19762G	PARTICIPANT	\N	PRESENT	0
611128	610748	19671E	PARTICIPANT	\N	PRESENT	0
611129	610748	19387D	PARTICIPANT	\N	PRESENT	0
611130	610748	11031D	PARTICIPANT	\N	PRESENT	0
611201	610748	19347U	PARTICIPANT	\N	PRESENT	0
611132	610748	04047H	PARTICIPANT	\N	PRESENT	0
611133	610748	19749K	PARTICIPANT	\N	PRESENT	0
611134	610748	20138D	PARTICIPANT	\N	PRESENT	0
611135	610748	20032T	PARTICIPANT	\N	PRESENT	0
611136	610748	14021P	PARTICIPANT	\N	PRESENT	0
611137	610748	20066E	PARTICIPANT	\N	PRESENT	0
611138	610748	20096L	PARTICIPANT	\N	PRESENT	0
611139	610748	14069U	PARTICIPANT	\N	PRESENT	0
611140	610748	14223L	PARTICIPANT	\N	PRESENT	0
611126	610748	19713W	PARTICIPANT	\N	PRESENT	0
611127	610748	14189C	PARTICIPANT	\N	PRESENT	0
611162	610748	20174H	PARTICIPANT	\N	PRESENT	0
611142	610748	08061X	PARTICIPANT	\N	PRESENT	0
611143	610748	14031R	PARTICIPANT	\N	PRESENT	0
611144	610748	20108W	PARTICIPANT	\N	PRESENT	0
611145	610748	14038Y	PARTICIPANT	\N	PRESENT	0
611149	610748	18193Q	PARTICIPANT	\N	PRESENT	0
611147	610748	20264J	PARTICIPANT	\N	PRESENT	0
611148	610748	20110Q	PARTICIPANT	\N	PRESENT	0
611150	610748	20130U	PARTICIPANT	\N	PRESENT	0
611151	610748	11067R	PARTICIPANT	\N	PRESENT	0
611152	610748	20134Y	PARTICIPANT	\N	PRESENT	0
611153	610748	20054A	PARTICIPANT	\N	PRESENT	0
611154	610748	19383Y	PARTICIPANT	\N	PRESENT	0
611155	610748	08018U	PARTICIPANT	\N	PRESENT	0
611156	610748	11026G	PARTICIPANT	\N	PRESENT	0
611178	610748	14217N	PARTICIPANT	\N	PRESENT	0
611158	610748	19631V	PARTICIPANT	\N	PRESENT	0
611159	610748	19745F	PARTICIPANT	\N	PRESENT	0
611160	610748	20122U	PARTICIPANT	\N	PRESENT	0
611161	610748	20050V	PARTICIPANT	\N	PRESENT	0
611163	610748	14357A	PARTICIPANT	\N	PRESENT	0
611164	609970	19533U	PRESIDENT	0	PRESENT	0
611165	609970	19798U	PARTICIPANT	\N	PRESENT	0
611166	609970	20042V	PARTICIPANT	\N	PRESENT	0
611167	609970	20112S	PARTICIPANT	\N	PRESENT	0
611168	609970	19820Y	PARTICIPANT	\N	PRESENT	0
611169	609970	04045F	PARTICIPANT	\N	PRESENT	0
611170	609970	14207L	PARTICIPANT	\N	PRESENT	0
611171	609970	19599P	PARTICIPANT	\N	PRESENT	0
611172	609970	17023S	PARTICIPANT	\N	PRESENT	0
611173	609970	20096L	PARTICIPANT	\N	PRESENT	0
611174	609970	17589D	PARTICIPANT	\N	EXCUSE	0
611175	610748	08034U	PARTICIPANT	\N	PRESENT	0
611176	610748	17229F	PARTICIPANT	\N	PRESENT	0
611177	610748	11027H	PARTICIPANT	\N	PRESENT	0
611179	610748	20024T	PARTICIPANT	\N	PRESENT	0
611180	610748	01034P	PARTICIPANT	\N	PRESENT	0
611181	610748	20248J	PARTICIPANT	\N	PRESENT	0
611182	609970	20124W	PARTICIPANT	\N	PRESENT	0
611183	610748	01028R	PARTICIPANT	\N	PRESENT	0
611184	610748	14225N	PARTICIPANT	\N	PRESENT	0
611185	610748	14033T	PARTICIPANT	\N	PRESENT	0
611186	610748	14042U	PARTICIPANT	\N	PRESENT	0
611187	610748	14133K	PARTICIPANT	\N	PRESENT	0
611188	610748	19647E	PARTICIPANT	\N	PRESENT	0
611189	610748	19565D	PARTICIPANT	\N	PRESENT	0
611190	610748	20022R	PARTICIPANT	\N	PRESENT	0
611191	610748	19479G	PARTICIPANT	\N	PRESENT	0
611192	610748	19691J	PARTICIPANT	\N	PRESENT	0
611193	610748	14001X	PARTICIPANT	\N	PRESENT	0
611194	610748	14109K	PARTICIPANT	\N	PRESENT	0
611195	610748	11012A	PARTICIPANT	\N	PRESENT	0
611196	610748	11097X	PARTICIPANT	\N	PRESENT	0
611197	610748	19489J	PARTICIPANT	\N	PRESENT	0
611198	610748	01024M	PARTICIPANT	\N	PRESENT	0
611199	610748	20114U	PARTICIPANT	\N	PRESENT	0
611200	610748	20062A	PARTICIPANT	\N	PRESENT	0
611202	610748	04045F	PARTICIPANT	\N	PRESENT	0
611203	610748	14053L	PARTICIPANT	\N	PRESENT	0
611204	610748	14105F	PARTICIPANT	\N	PRESENT	0
611205	610748	20064C	PARTICIPANT	\N	PRESENT	0
611206	610748	11045K	PARTICIPANT	\N	PRESENT	0
611207	610593	14327T	PARTICIPANT	\N	PRESENT	0
611208	610593	11048N	PARTICIPANT	\N	PRESENT	0
611209	610593	19479G	PARTICIPANT	\N	PRESENT	0
611210	610593	19711U	PARTICIPANT	\N	PRESENT	0
611211	610593	19531S	PARTICIPANT	\N	PRESENT	0
611212	610593	01057W	PARTICIPANT	\N	PRESENT	0
611213	610593	20080C	PARTICIPANT	\N	PRESENT	0
611214	610593	20044X	PARTICIPANT	\N	PRESENT	0
611215	610593	19671E	PARTICIPANT	\N	PRESENT	0
611216	610593	14225N	PRESIDENT	0	PRESENT	0
611217	610593	20252E	PARTICIPANT	\N	PRESENT	0
611218	610593	08009T	PARTICIPANT	\N	PRESENT	0
611219	610593	20070A	PARTICIPANT	\N	PRESENT	0
611220	610593	19349W	PARTICIPANT	\N	PRESENT	0
611221	610593	19741B	PARTICIPANT	\N	PRESENT	0
611222	610593	08010L	PARTICIPANT	\N	PRESENT	0
611223	610593	99004R	PARTICIPANT	\N	PRESENT	0
611224	610593	19335Q	PARTICIPANT	\N	PRESENT	0
611225	610593	20126Y	PARTICIPANT	\N	PRESENT	0
611226	610593	19762G	PARTICIPANT	\N	PRESENT	0
611229	610748	08028W	PARTICIPANT	\N	PRESENT	0
611230	611228	08012N	PARTICIPANT	\N	PRESENT	1
611231	611228	11043H	PARTICIPANT	\N	PRESENT	1
611234	610748	20124W	PARTICIPANT	\N	PRESENT	0
611235	610748	20046A	PARTICIPANT	\N	PRESENT	0
611236	610748	11085T	PARTICIPANT	\N	PRESENT	0
611237	610748	19798U	PARTICIPANT	\N	PRESENT	0
611238	610748	20058E	PARTICIPANT	\N	PRESENT	0
611241	610795	14097Y	PARTICIPANT	\N	PRESENT	0
611242	610795	95041E	PARTICIPANT	\N	PRESENT	0
611243	610795	12041X	PARTICIPANT	\N	PRESENT	0
611244	610795	20072C	PARTICIPANT	\N	PRESENT	0
611245	610795	01058X	PARTICIPANT	\N	PRESENT	0
611246	610795	16685X	PARTICIPANT	\N	PRESENT	0
611247	610795	11027H	PARTICIPANT	\N	PRESENT	0
611248	610795	04042C	PRESIDENT	0	PRESENT	0
611249	610795	01024M	PARTICIPANT	\N	PRESENT	0
611250	610795	11054L	PARTICIPANT	\N	PRESENT	0
611251	610795	14105F	PARTICIPANT	\N	PRESENT	0
611252	610795	20064C	PARTICIPANT	\N	PRESENT	0
611253	610795	14193X	PARTICIPANT	\N	PRESENT	0
611254	610795	11064N	PARTICIPANT	\N	PRESENT	0
611255	610795	19347U	PARTICIPANT	\N	PRESENT	0
611256	610795	11083R	PARTICIPANT	\N	PRESENT	0
611257	610795	97011G	PARTICIPANT	\N	PRESENT	0
611258	610795	08061X	PARTICIPANT	\N	PRESENT	0
611259	610795	14211G	PARTICIPANT	\N	PRESENT	0
611260	610795	14249W	PARTICIPANT	\N	PRESENT	0
611261	610795	08047A	PARTICIPANT	\N	PRESENT	0
611266	610795	19565D	PARTICIPANT	\N	PRESENT	0
611267	610795	08056B	PARTICIPANT	\N	PRESENT	0
611268	610795	07033P	PARTICIPANT	\N	PRESENT	0
611269	610795	11066Q	PARTICIPANT	\N	EXCUSE	0
611270	610795	19669L	PARTICIPANT	\N	EXCUSE	0
611271	610795	14059S	PARTICIPANT	\N	PRESENT	0
611272	610795	17023S	PARTICIPANT	\N	PRESENT	0
611273	610593	11053K	PARTICIPANT	\N	PRESENT	0
611274	610593	07029T	PARTICIPANT	\N	PRESENT	0
611275	610593	14121F	PARTICIPANT	\N	EXCUSE	0
611276	610784	04059M	PARTICIPANT	\N	PRESENT	0
611277	610784	19651A	PARTICIPANT	\N	PRESENT	0
611278	610784	20086J	PARTICIPANT	\N	PRESENT	0
611279	610784	20152B	PARTICIPANT	\N	PRESENT	0
611280	610784	11053K	PARTICIPANT	\N	PRESENT	0
611281	610784	20132W	PARTICIPANT	\N	PRESENT	0
611282	610784	19725B	PARTICIPANT	\N	PRESENT	0
611283	610784	19399H	PARTICIPANT	\N	PRESENT	0
611284	610784	20056C	PARTICIPANT	\N	PRESENT	0
611285	610784	19611R	PRESIDENT	0	PRESENT	0
611286	610784	19699S	PARTICIPANT	\N	PRESENT	0
611287	610784	12041X	PARTICIPANT	\N	PRESENT	0
611288	610784	20142Y	PARTICIPANT	\N	PRESENT	0
611289	610784	19705W	PARTICIPANT	\N	PRESENT	0
611290	610784	14229S	PARTICIPANT	\N	PRESENT	0
611291	610784	20026V	PARTICIPANT	\N	PRESENT	0
611509	610282	20040T	PARTICIPANT	\N	PRESENT	0
611510	610282	14042U	PARTICIPANT	\N	PRESENT	0
611327	610671	17737W	PARTICIPANT	\N	EXCUSE	0
611328	610671	19729F	PARTICIPANT	\N	EXCUSE	0
611508	610282	17779H	PARTICIPANT	\N	PRESENT	0
611511	610282	20172F	PARTICIPANT	\N	PRESENT	0
611512	610282	14026U	PARTICIPANT	\N	PRESENT	0
603178	603177	12028B	PARTICIPANT	\N	PRESENT	0
603181	603180	11064N	PARTICIPANT	\N	PRESENT	0
605826	605820	14329V	PARTICIPANT	\N	PRESENT	0
605827	605821	14329V	PARTICIPANT	\N	PRESENT	0
608913	608660	14059S	PRESIDENT	0	PRESENT	0
609531	608709	19441R	PARTICIPANT	\N	PRESENT	0
609532	608709	19413M	PARTICIPANT	\N	PRESENT	0
609533	608709	20082E	PARTICIPANT	\N	PRESENT	0
609534	608709	20094J	PARTICIPANT	\N	PRESENT	0
609535	608709	04045F	PARTICIPANT	\N	PRESENT	0
609536	608709	20104S	PARTICIPANT	\N	PRESENT	0
609537	608709	19705W	PARTICIPANT	\N	PRESENT	0
609538	608709	19707Y	PARTICIPANT	\N	PRESENT	0
609539	608709	08015R	PARTICIPANT	\N	PRESENT	0
609540	608709	19575F	PARTICIPANT	\N	PRESENT	0
609541	608709	19369B	PARTICIPANT	\N	PRESENT	0
609542	608709	20018V	PARTICIPANT	\N	PRESENT	0
609543	608709	19511N	PARTICIPANT	\N	PRESENT	0
609544	608709	08028W	PARTICIPANT	\N	PRESENT	0
609545	608709	19563B	PARTICIPANT	\N	PRESENT	0
609546	608709	20028X	PARTICIPANT	\N	PRESENT	0
609547	608709	20030R	PARTICIPANT	\N	PRESENT	0
609548	608709	14038Y	PARTICIPANT	\N	PRESENT	0
609549	608709	19467C	PARTICIPANT	\N	PRESENT	0
609550	608709	14187A	PARTICIPANT	\N	PRESENT	0
609551	608709	20144B	PARTICIPANT	\N	PRESENT	0
609552	608709	19695N	PARTICIPANT	\N	PRESENT	0
609553	608709	11090Q	PRESIDENT	0	PRESENT	0
609554	608709	14033T	PARTICIPANT	\N	PRESENT	0
609555	608709	01025N	PARTICIPANT	\N	PRESENT	0
609556	608709	20054A	PARTICIPANT	\N	PRESENT	0
609557	608709	20174H	PARTICIPANT	\N	PRESENT	0
609558	608709	14205J	PARTICIPANT	\N	PRESENT	0
609559	608709	20062A	PARTICIPANT	\N	PRESENT	0
609560	608709	14251Q	PARTICIPANT	\N	PRESENT	0
609561	608709	19507S	PARTICIPANT	\N	PRESENT	0
609562	608709	19747H	PARTICIPANT	\N	PRESENT	0
609563	608709	14207L	PARTICIPANT	\N	PRESENT	0
609564	608709	14257W	PARTICIPANT	\N	PRESENT	0
609565	608709	20078J	PARTICIPANT	\N	PRESENT	0
609589	608234	19697Q	PARTICIPANT	\N	PRESENT	0
609590	608234	19553Y	PARTICIPANT	\N	PRESENT	0
609591	608234	19663E	PARTICIPANT	\N	PRESENT	0
609592	608234	04092N	PARTICIPANT	\N	EXCUSE	0
609593	608234	20040T	PARTICIPANT	\N	EXCUSE	0
609594	608234	19295A	PARTICIPANT	\N	EXCUSE	0
609595	609285	19533U	PRESIDENT	1	PRESENT	0
609596	609285	19798U	PARTICIPANT	\N	PRESENT	0
609597	609285	19820Y	PARTICIPANT	\N	PRESENT	0
609598	609285	14215L	PARTICIPANT	\N	PRESENT	0
609599	609285	14207L	PARTICIPANT	\N	PRESENT	0
609600	609285	04045F	PARTICIPANT	\N	PRESENT	0
609601	609285	19693L	PARTICIPANT	\N	PRESENT	0
609602	609285	17589D	PRESIDENT	0	PRESENT	0
609603	609285	20134Y	PARTICIPANT	\N	PRESENT	0
609604	609285	20096L	PARTICIPANT	\N	PRESENT	0
609605	609285	17023S	PARTICIPANT	\N	PRESENT	0
609611	608516	14097Y	PARTICIPANT	\N	PRESENT	0
609612	608516	20064C	PARTICIPANT	\N	PRESENT	0
609613	608516	20068G	PARTICIPANT	\N	PRESENT	0
609614	608516	19671E	PARTICIPANT	\N	PRESENT	0
609615	608516	20090E	PARTICIPANT	\N	PRESENT	0
609616	608516	14105F	PARTICIPANT	\N	PRESENT	0
609617	608516	19399H	PARTICIPANT	\N	PRESENT	0
609618	608516	11103C	PARTICIPANT	\N	PRESENT	0
609619	608516	20132W	PARTICIPANT	\N	PRESENT	0
609620	608516	12028B	PARTICIPANT	\N	PRESENT	0
609621	608516	19798U	PARTICIPANT	\N	PRESENT	0
609622	608516	19569H	PARTICIPANT	\N	PRESENT	0
609623	608516	20036X	PARTICIPANT	\N	PRESENT	0
609624	608516	20134Y	PARTICIPANT	\N	PRESENT	0
609625	608516	14111D	PARTICIPANT	\N	PRESENT	0
609626	608516	18083K	PARTICIPANT	\N	PRESENT	0
609627	608516	19511N	PARTICIPANT	\N	PRESENT	0
609628	608516	14205J	PARTICIPANT	\N	PRESENT	0
609629	608516	19719D	PARTICIPANT	\N	PRESENT	0
609630	608516	19583F	PARTICIPANT	\N	PRESENT	0
609631	608516	19543W	PARTICIPANT	\N	PRESENT	0
609632	608516	01025N	PARTICIPANT	\N	PRESENT	0
609633	608516	19479G	PARTICIPANT	\N	PRESENT	0
609634	608516	20266L	PARTICIPANT	\N	PRESENT	0
609635	608516	11056N	PARTICIPANT	\N	PRESENT	0
609636	608516	19760E	PARTICIPANT	\N	PRESENT	0
609637	608516	20032T	PARTICIPANT	\N	PRESENT	0
609638	608516	08047A	PARTICIPANT	\N	PRESENT	0
609639	608516	19563B	PARTICIPANT	\N	PRESENT	0
609640	608516	20142Y	PARTICIPANT	\N	PRESENT	0
609641	608516	14038Y	PARTICIPANT	\N	PRESENT	0
609642	608516	14217N	PARTICIPANT	\N	PRESENT	0
609643	608516	19447X	PARTICIPANT	\N	PRESENT	0
609644	608516	20104S	PARTICIPANT	\N	PRESENT	0
609645	608516	19711U	PARTICIPANT	\N	PRESENT	0
609646	608516	20172F	PARTICIPANT	\N	PRESENT	0
609647	608516	14357A	PARTICIPANT	\N	PRESENT	0
609648	608516	20100N	PARTICIPANT	\N	PRESENT	0
609649	608516	20030R	PARTICIPANT	\N	PRESENT	0
609650	608516	19549D	PARTICIPANT	\N	PRESENT	0
609651	608516	19333N	PARTICIPANT	\N	PRESENT	0
609652	608516	19687N	PARTICIPANT	\N	PRESENT	0
609653	608516	19503N	PARTICIPANT	\N	PRESENT	0
609654	608516	04045F	PARTICIPANT	\N	PRESENT	0
609655	608516	19637C	PARTICIPANT	\N	PRESENT	0
609656	608516	08061X	PARTICIPANT	\N	PRESENT	0
609657	608516	95041E	PARTICIPANT	\N	PRESENT	0
609658	608516	11067R	PARTICIPANT	\N	PRESENT	0
609659	608516	19619A	PARTICIPANT	\N	PRESENT	0
609660	608516	19251M	PARTICIPANT	\N	PRESENT	0
609661	608516	20138D	PARTICIPANT	\N	PRESENT	0
609662	608516	20022R	PARTICIPANT	\N	PRESENT	0
609663	608516	11066Q	PARTICIPANT	\N	PRESENT	0
609664	608516	14073Q	PARTICIPANT	\N	PRESENT	0
609665	608516	17779H	PARTICIPANT	\N	PRESENT	0
609666	608516	19349W	PARTICIPANT	\N	PRESENT	0
609667	608516	19599P	PARTICIPANT	\N	PRESENT	0
609668	608516	01043Q	PARTICIPANT	\N	PRESENT	0
609669	608516	19525U	PARTICIPANT	\N	PRESENT	0
609670	608516	19591F	PARTICIPANT	\N	PRESENT	0
609671	608516	14151M	PARTICIPANT	\N	PRESENT	0
609672	608516	19553Y	PARTICIPANT	\N	PRESENT	0
609673	608516	11012A	PARTICIPANT	\N	PRESENT	0
609674	608516	14221J	PARTICIPANT	\N	PRESENT	0
609675	608516	19749K	PARTICIPANT	\N	PRESENT	0
609676	608516	11085T	PARTICIPANT	\N	PRESENT	0
609677	608516	20070A	PARTICIPANT	\N	PRESENT	0
609678	608516	20080C	PARTICIPANT	\N	PRESENT	0
609679	608516	17965H	PARTICIPANT	\N	PRESENT	0
609680	608516	14207L	PARTICIPANT	\N	PRESENT	0
609681	608516	19651A	PARTICIPANT	\N	PRESENT	0
609682	608516	14109K	PARTICIPANT	\N	PRESENT	0
609683	608516	20018V	PARTICIPANT	\N	PRESENT	0
609684	608516	20130U	PARTICIPANT	\N	PRESENT	0
609685	608516	14225N	PARTICIPANT	\N	PRESENT	0
609686	608516	19782L	PARTICIPANT	\N	PRESENT	0
609687	608516	20082E	PARTICIPANT	\N	PRESENT	0
609688	608516	11040E	PARTICIPANT	\N	PRESENT	0
609689	608516	11031D	PARTICIPANT	\N	PRESENT	0
609690	608516	19695N	PARTICIPANT	\N	PRESENT	0
609691	608516	11077T	PARTICIPANT	\N	PRESENT	0
609692	608516	20046A	PARTICIPANT	\N	PRESENT	0
609693	608516	20102Q	PARTICIPANT	\N	PRESENT	0
609694	608516	01028R	PARTICIPANT	\N	PRESENT	0
609695	608516	19820Y	PARTICIPANT	\N	PRESENT	0
609696	608516	19725B	PARTICIPANT	\N	PRESENT	0
609697	608516	20174H	PARTICIPANT	\N	PRESENT	0
609698	608516	19527W	PARTICIPANT	\N	PRESENT	0
609699	608516	11065P	PARTICIPANT	\N	PRESENT	0
609700	608516	19693L	PARTICIPANT	\N	PRESENT	0
609701	608516	20092G	PARTICIPANT	\N	PRESENT	0
609702	608516	19689Q	PARTICIPANT	\N	PRESENT	0
609703	608516	01058X	PARTICIPANT	\N	PRESENT	0
609704	608516	19575F	PARTICIPANT	\N	PRESENT	0
609705	608516	19703U	PARTICIPANT	\N	PRESENT	0
609706	608516	20106U	PARTICIPANT	\N	PRESENT	0
609707	608516	20128B	PARTICIPANT	\N	PRESENT	0
609708	608516	11101A	PARTICIPANT	\N	PRESENT	0
609709	608516	20146D	PARTICIPANT	\N	PRESENT	0
609710	608516	08010L	PARTICIPANT	\N	PRESENT	0
609711	608516	14026U	PARTICIPANT	\N	PRESENT	0
609712	608516	11033F	PARTICIPANT	\N	PRESENT	0
609713	608516	04047H	PARTICIPANT	\N	PRESENT	0
609714	608516	11048N	PARTICIPANT	\N	PRESENT	0
607109	606306	14031R	PARTICIPANT	\N	PRESENT	0
607110	606306	11101A	PARTICIPANT	\N	PRESENT	0
607111	606306	20180F	PARTICIPANT	\N	PRESENT	0
607112	606306	19399H	PARTICIPANT	\N	PRESENT	0
607113	606306	04008A	PARTICIPANT	\N	PRESENT	0
607121	606306	11026G	PARTICIPANT	\N	PRESENT	0
607115	606306	04071H	PARTICIPANT	\N	PRESENT	0
607116	606306	19657G	PARTICIPANT	\N	PRESENT	0
607117	606306	01043Q	PARTICIPANT	\N	PRESENT	0
607118	606306	92040Q	PARTICIPANT	\N	PRESENT	0
607119	606306	14059S	PARTICIPANT	\N	PRESENT	0
607120	606306	10006L	PARTICIPANT	\N	PRESENT	0
607122	606306	19745F	PARTICIPANT	\N	PRESENT	0
607123	606306	14038Y	PARTICIPANT	\N	PRESENT	0
607124	606306	19739H	PARTICIPANT	\N	PRESENT	0
607126	606306	14255U	PARTICIPANT	\N	PRESENT	0
607127	606306	19569H	PARTICIPANT	\N	PRESENT	0
607142	606306	19713W	PARTICIPANT	\N	PRESENT	0
607129	606306	19599P	PARTICIPANT	\N	PRESENT	0
607130	606306	14217N	PARTICIPANT	\N	PRESENT	0
607132	606306	14026U	PARTICIPANT	\N	PRESENT	0
607133	606306	20058E	PARTICIPANT	\N	PRESENT	0
607134	606306	20118Y	PARTICIPANT	\N	PRESENT	0
607135	606306	19711U	PARTICIPANT	\N	PRESENT	0
607136	606306	19631V	PARTICIPANT	\N	PRESENT	0
607137	606306	14207L	PARTICIPANT	\N	PRESENT	0
607140	606306	19575F	PARTICIPANT	\N	PRESENT	0
607139	606306	01024M	PARTICIPANT	\N	PRESENT	0
607141	606306	20024T	PARTICIPANT	\N	PRESENT	0
607143	606306	19663E	PARTICIPANT	\N	PRESENT	0
607144	606306	20142Y	PARTICIPANT	\N	PRESENT	0
607145	606306	14069U	PARTICIPANT	\N	PRESENT	0
607146	606306	19735D	PARTICIPANT	\N	PRESENT	0
607147	606306	14331P	PARTICIPANT	\N	PRESENT	0
607148	606306	20034V	PARTICIPANT	\N	PRESENT	0
607149	606306	19413M	PARTICIPANT	\N	PRESENT	0
607150	606306	19347U	PARTICIPANT	\N	PRESENT	0
607151	606306	08034U	PARTICIPANT	\N	PRESENT	0
607152	606306	11065P	PARTICIPANT	\N	PRESENT	0
607153	606306	14193X	PARTICIPANT	\N	PRESENT	0
607154	606306	20052X	PARTICIPANT	\N	PRESENT	0
607155	606306	19563B	PARTICIPANT	\N	PRESENT	0
607156	606306	11067R	PARTICIPANT	\N	PRESENT	0
607157	606306	11027H	PARTICIPANT	\N	PRESENT	0
607158	606306	14259Y	PARTICIPANT	\N	PRESENT	0
607159	606306	20114U	PARTICIPANT	\N	PRESENT	0
607160	606306	19685L	PARTICIPANT	\N	PRESENT	0
607161	606306	14073Q	PARTICIPANT	\N	PRESENT	0
607163	606306	19637C	PARTICIPANT	\N	PRESENT	0
607164	606306	20128B	PARTICIPANT	\N	PRESENT	0
607165	606306	19543W	PARTICIPANT	\N	PRESENT	0
607166	606306	14231L	PARTICIPANT	\N	PRESENT	0
607167	606306	01025N	PARTICIPANT	\N	PRESENT	0
607168	606306	14205J	PARTICIPANT	\N	PRESENT	0
607169	606306	19441R	PARTICIPANT	\N	PRESENT	0
607172	606306	01048V	PARTICIPANT	\N	PRESENT	0
607173	606306	14249W	PARTICIPANT	\N	PRESENT	0
607174	606306	11085T	PARTICIPANT	\N	PRESENT	0
607184	606426	19593H	PARTICIPANT	\N	PRESENT	0
607185	606426	19766L	PARTICIPANT	\N	PRESENT	0
607186	606426	19643A	PARTICIPANT	\N	PRESENT	0
607187	606426	20132W	PARTICIPANT	\N	PRESENT	0
607188	606426	19699S	PARTICIPANT	\N	PRESENT	0
607189	606426	20134Y	PARTICIPANT	\N	PRESENT	0
607190	606426	19611R	PRESIDENT	0	PRESENT	0
607191	606426	20142Y	PARTICIPANT	\N	PRESENT	0
607192	606426	20048C	PARTICIPANT	\N	PRESENT	0
607193	606426	19693L	PARTICIPANT	\N	PRESENT	0
607194	606426	19399H	PARTICIPANT	\N	PRESENT	0
607195	606426	20052X	PARTICIPANT	\N	PRESENT	0
607196	606426	14229S	PARTICIPANT	\N	PRESENT	0
607197	606426	14030Q	PARTICIPANT	\N	PRESENT	0
607198	606426	20056C	PARTICIPANT	\N	PRESENT	0
607199	606426	20180F	PARTICIPANT	\N	PRESENT	0
607200	606426	04059M	PARTICIPANT	\N	PRESENT	0
607201	606426	11104D	PARTICIPANT	\N	PRESENT	0
607202	606426	20124W	PARTICIPANT	\N	PRESENT	0
607203	606426	19758L	PARTICIPANT	\N	PRESENT	0
607204	606426	20084G	PARTICIPANT	\N	PRESENT	0
607214	606426	20026V	PARTICIPANT	\N	PRESENT	0
607215	606426	19527W	PARTICIPANT	\N	PRESENT	0
607216	606426	14073Q	PARTICIPANT	\N	PRESENT	0
607217	606426	20058E	PARTICIPANT	\N	PRESENT	0
607220	606426	14109K	PARTICIPANT	\N	PRESENT	0
607235	606262	20130U	PARTICIPANT	\N	PRESENT	0
607237	606262	20090E	PARTICIPANT	\N	PRESENT	0
607239	606262	19569H	PARTICIPANT	\N	PRESENT	0
607241	606262	19798U	PARTICIPANT	\N	PRESENT	0
607243	606262	11097X	PARTICIPANT	\N	PRESENT	0
607245	606262	19663E	PARTICIPANT	\N	PRESENT	0
607247	606262	17965H	PARTICIPANT	\N	PRESENT	0
607248	606262	19691J	PARTICIPANT	\N	PRESENT	0
607251	606262	18193Q	PARTICIPANT	\N	PRESENT	0
607252	606262	20148F	PARTICIPANT	\N	PRESENT	0
607254	606262	14223L	PARTICIPANT	\N	PRESENT	0
607257	606262	14026U	PARTICIPANT	\N	PRESENT	0
607259	606262	20172F	PARTICIPANT	\N	PRESENT	0
607260	606262	17779H	PARTICIPANT	\N	PRESENT	0
607263	606262	19703U	PARTICIPANT	\N	PRESENT	0
607265	606262	11103C	PARTICIPANT	\N	PRESENT	0
607267	606262	19679N	PARTICIPANT	\N	PRESENT	0
607269	606262	14042U	PARTICIPANT	\N	PRESENT	0
607271	606262	14213J	PARTICIPANT	\N	PRESENT	0
607273	606262	14217N	PRESIDENT	0	PRESENT	0
607275	606262	04043D	PARTICIPANT	\N	PRESENT	0
607277	606262	10006L	PRESIDENT	1	PRESENT	0
607279	606262	19591F	PARTICIPANT	\N	PRESENT	0
607280	606262	04057K	PARTICIPANT	\N	EXCUSE	0
607283	606262	20040T	PARTICIPANT	\N	EXCUSE	0
607284	606262	14071N	PARTICIPANT	\N	EXCUSE	0
607287	606262	19657G	PARTICIPANT	\N	EXCUSE	0
607289	606854	19383Y	PARTICIPANT	\N	PRESENT	0
607290	606854	19768N	PARTICIPANT	\N	PRESENT	0
607291	606854	19515S	PARTICIPANT	\N	PRESENT	0
607292	606854	19782L	PARTICIPANT	\N	PRESENT	0
607293	606854	20092G	PARTICIPANT	\N	PRESENT	0
607294	606854	01043Q	PARTICIPANT	\N	PRESENT	0
607295	606854	20078J	PARTICIPANT	\N	PRESENT	0
607296	606854	19441R	PARTICIPANT	\N	PRESENT	0
607297	606854	19413M	PARTICIPANT	\N	PRESENT	0
607298	606854	20082E	PARTICIPANT	\N	PRESENT	0
607299	606854	20094J	PARTICIPANT	\N	PRESENT	0
607300	606854	04045F	PARTICIPANT	\N	PRESENT	0
607301	606854	20104S	PARTICIPANT	\N	PRESENT	0
607302	606854	19631V	PARTICIPANT	\N	PRESENT	0
607303	606854	11099A	PARTICIPANT	\N	PRESENT	0
607304	606854	08015R	PARTICIPANT	\N	PRESENT	0
607305	606854	19575F	PARTICIPANT	\N	PRESENT	0
607306	606854	19369B	PARTICIPANT	\N	PRESENT	0
607307	606854	20018V	PARTICIPANT	\N	PRESENT	0
607308	606854	19511N	PARTICIPANT	\N	PRESENT	0
607309	606854	19563B	PARTICIPANT	\N	PRESENT	0
607310	606854	20028X	PARTICIPANT	\N	PRESENT	0
607311	606854	14038Y	PARTICIPANT	\N	PRESENT	0
607312	606854	19467C	PARTICIPANT	\N	PRESENT	0
607313	606854	20034V	PARTICIPANT	\N	PRESENT	0
607314	606854	14187A	PRESIDENT	0	PRESENT	0
607315	606854	20144B	PARTICIPANT	\N	PRESENT	0
607316	606854	01025N	PARTICIPANT	\N	PRESENT	0
607317	606854	11090Q	PRESIDENT	1	PRESENT	0
607318	606854	14033T	PARTICIPANT	\N	PRESENT	0
607319	606854	20054A	PARTICIPANT	\N	PRESENT	0
607320	606854	14205J	PARTICIPANT	\N	PRESENT	0
607321	606854	20062A	PARTICIPANT	\N	PRESENT	0
607322	606854	19507S	PARTICIPANT	\N	PRESENT	0
607323	606854	19747H	PARTICIPANT	\N	PRESENT	0
607324	606854	14257W	PARTICIPANT	\N	PRESENT	0
607325	606854	20060X	PARTICIPANT	\N	PRESENT	0
607328	606407	20074E	PARTICIPANT	\N	PRESENT	0
607332	607183	14327T	PARTICIPANT	\N	PRESENT	0
607333	607183	19479G	PARTICIPANT	\N	PRESENT	0
607334	607183	11048N	PARTICIPANT	\N	PRESENT	0
607335	607183	19687N	PARTICIPANT	\N	PRESENT	0
607336	607183	20080C	PARTICIPANT	\N	PRESENT	0
607337	607183	12016W	PARTICIPANT	\N	PRESENT	0
607338	607183	11053K	PARTICIPANT	\N	PRESENT	0
607339	607183	14121F	PARTICIPANT	\N	PRESENT	0
607340	607183	14253S	PARTICIPANT	\N	PRESENT	0
607341	607183	19667J	PARTICIPANT	\N	PRESENT	0
607342	607183	11070L	PARTICIPANT	\N	PRESENT	0
607343	607183	19671E	PARTICIPANT	\N	PRESENT	0
600398	599368	19717B	PARTICIPANT	\N	EXCUSE	0
600399	599368	17023S	PARTICIPANT	\N	PRESENT	1
600400	599368	97011G	PARTICIPANT	\N	PRESENT	0
600401	599368	19691J	PARTICIPANT	\N	PRESENT	0
600403	599368	19715Y	PARTICIPANT	\N	PRESENT	1
600404	599368	19657G	PARTICIPANT	\N	PRESENT	1
600406	599368	14147R	PARTICIPANT	\N	PRESENT	1
600408	599368	19301E	PARTICIPANT	\N	PRESENT	1
600409	599368	19319Q	PARTICIPANT	\N	PRESENT	1
600411	599368	20148F	PARTICIPANT	\N	PRESENT	0
600412	599368	20146D	PARTICIPANT	\N	PRESENT	0
601188	601187	14179A	PARTICIPANT	\N	PRESENT	0
601190	601189	14179A	PARTICIPANT	\N	PRESENT	0
601194	601193	10006L	PARTICIPANT	\N	PRESENT	0
601195	601193	20056C	PARTICIPANT	\N	PRESENT	0
601196	601193	12041X	PARTICIPANT	\N	PRESENT	0
601199	601198	10006L	PARTICIPANT	\N	PRESENT	0
601201	601200	10006L	PARTICIPANT	\N	PRESENT	0
601203	601202	10006L	PARTICIPANT	\N	PRESENT	0
601205	601204	10006L	PARTICIPANT	\N	PRESENT	0
601206	601204	14217N	PARTICIPANT	\N	PRESENT	0
601208	601207	10006L	PARTICIPANT	\N	PRESENT	0
601209	601207	14217N	PARTICIPANT	\N	PRESENT	0
601210	601207	20126Y	PARTICIPANT	\N	PRESENT	0
601211	601207	18193Q	PARTICIPANT	\N	PRESENT	0
601212	601207	04092N	PARTICIPANT	\N	PRESENT	0
601213	601207	19687N	PARTICIPANT	\N	PRESENT	0
601214	601207	01058X	PARTICIPANT	\N	PRESENT	0
601216	601215	10006L	PARTICIPANT	\N	PRESENT	0
601217	601215	14041T	PARTICIPANT	\N	PRESENT	0
601266	600815	14223L	PARTICIPANT	\N	PRESENT	0
601267	600815	19657G	PARTICIPANT	\N	PRESENT	0
601271	600815	19591F	PARTICIPANT	\N	PRESENT	0
601281	600815	19679N	PARTICIPANT	\N	PRESENT	0
601282	600815	19569H	PARTICIPANT	\N	PRESENT	0
601292	601286	14257W	PARTICIPANT	\N	PRESENT	0
603839	603142	11090Q	PARTICIPANT	\N	PRESENT	0
601318	601311	14257W	PARTICIPANT	\N	PRESENT	0
601319	601311	19515S	PARTICIPANT	\N	PRESENT	0
603840	603142	04059M	PARTICIPANT	\N	PRESENT	0
603841	603142	19631V	PARTICIPANT	\N	PRESENT	0
603842	603142	20088L	PARTICIPANT	\N	PRESENT	0
603843	603142	20080C	PARTICIPANT	\N	PRESENT	0
603844	603142	05008E	PARTICIPANT	\N	PRESENT	0
603845	603142	20060X	PARTICIPANT	\N	PRESENT	0
603846	603142	20264J	PARTICIPANT	\N	PRESENT	0
603847	603142	19954N	PARTICIPANT	\N	PRESENT	0
603848	603142	19525U	PARTICIPANT	\N	PRESENT	0
603849	603142	19329S	PARTICIPANT	\N	PRESENT	0
603850	603142	14069U	PARTICIPANT	\N	PRESENT	0
603851	603142	14355X	PARTICIPANT	\N	PRESENT	0
603852	603142	19333N	PARTICIPANT	\N	PRESENT	0
603853	603142	20128B	PARTICIPANT	\N	PRESENT	0
603854	603142	08047A	PARTICIPANT	\N	PRESENT	0
603855	603142	14259Y	PARTICIPANT	\N	PRESENT	0
603856	603142	19663E	PARTICIPANT	\N	PRESENT	0
603857	603142	20140W	PARTICIPANT	\N	PRESENT	0
603858	603142	20124W	PARTICIPANT	\N	PRESENT	0
603859	603142	14187A	PARTICIPANT	\N	PRESENT	0
603860	603142	11043H	PARTICIPANT	\N	PRESENT	0
603861	603142	11115U	PARTICIPANT	\N	PRESENT	0
603862	603142	10006L	PARTICIPANT	\N	PRESENT	0
603863	603142	14059S	PARTICIPANT	\N	PRESENT	0
603864	603142	11045K	PARTICIPANT	\N	PRESENT	0
603865	603142	04092N	PARTICIPANT	\N	PRESENT	0
603866	603142	11027H	PARTICIPANT	\N	PRESENT	0
603867	603142	14281W	PARTICIPANT	\N	PRESENT	0
603868	603142	20044X	PARTICIPANT	\N	PRESENT	0
603869	603142	14173T	PARTICIPANT	\N	PRESENT	0
603870	603142	19687N	PARTICIPANT	\N	PRESENT	0
603871	603142	19683J	PARTICIPANT	\N	PRESENT	0
603872	603142	20028X	PARTICIPANT	\N	PRESENT	0
603873	603142	08061X	PARTICIPANT	\N	PRESENT	0
603874	603142	14021P	PARTICIPANT	\N	PRESENT	0
603875	603142	19707Y	PARTICIPANT	\N	PRESENT	0
603876	603142	19705W	PARTICIPANT	\N	PRESENT	0
603877	603142	20078J	PARTICIPANT	\N	PRESENT	0
603878	603142	14229S	PARTICIPANT	\N	PRESENT	0
603879	603142	01062T	PARTICIPANT	\N	PRESENT	0
603880	603142	14121F	PARTICIPANT	\N	PRESENT	0
603881	603142	19649G	PARTICIPANT	\N	PRESENT	0
603882	603142	14109K	PARTICIPANT	\N	PRESENT	0
603883	603142	11099A	PARTICIPANT	\N	PRESENT	0
603884	603142	20142Y	PARTICIPANT	\N	PRESENT	0
603885	603142	19489J	PARTICIPANT	\N	PRESENT	0
603886	603142	11110B	PARTICIPANT	\N	PRESENT	0
603887	603142	01024M	PARTICIPANT	\N	PRESENT	0
603888	603142	19479G	PARTICIPANT	\N	PRESENT	0
603889	603142	14219Q	PARTICIPANT	\N	PRESENT	0
603890	603142	19441R	PARTICIPANT	\N	PRESENT	0
603891	603142	19721W	PARTICIPANT	\N	PRESENT	0
603892	603142	01025N	PARTICIPANT	\N	PRESENT	0
603893	603142	19619A	PARTICIPANT	\N	PRESENT	0
603894	603142	20052X	PARTICIPANT	\N	PRESENT	0
603895	603142	19569H	PARTICIPANT	\N	PRESENT	0
603896	603142	19739H	PARTICIPANT	\N	PRESENT	0
603897	603142	20066E	PARTICIPANT	\N	PRESENT	0
603898	603142	20144B	PARTICIPANT	\N	PRESENT	0
603899	603142	14205J	PARTICIPANT	\N	PRESENT	0
603919	603142	11085T	PARTICIPANT	\N	PRESENT	0
603901	603142	14179A	PARTICIPANT	\N	PRESENT	0
603902	603142	19611R	PARTICIPANT	\N	PRESENT	0
603903	603142	19369B	PARTICIPANT	\N	PRESENT	0
603931	603142	19533U	PARTICIPANT	\N	PRESENT	0
603905	603142	14030Q	PARTICIPANT	\N	PRESENT	0
603906	603142	17229F	PARTICIPANT	\N	PRESENT	0
603907	603142	14231L	PARTICIPANT	\N	PRESENT	0
603922	603142	20064C	PARTICIPANT	\N	PRESENT	0
603909	603142	14089Y	PARTICIPANT	\N	PRESENT	0
603920	603142	14267Y	PARTICIPANT	\N	PRESENT	0
603911	603142	14073Q	PARTICIPANT	\N	PRESENT	0
603912	603142	11070L	PARTICIPANT	\N	PRESENT	0
603913	603142	14042U	PARTICIPANT	\N	PRESENT	0
603914	603142	19577H	PARTICIPANT	\N	PRESENT	0
603915	603142	14147R	PARTICIPANT	\N	PRESENT	0
603916	603142	11048N	PARTICIPANT	\N	PRESENT	0
603917	603142	19335Q	PARTICIPANT	\N	PRESENT	0
603921	603142	17367Q	PARTICIPANT	\N	PRESENT	0
603923	603142	04071H	PARTICIPANT	\N	PRESENT	0
603924	603142	20018V	PARTICIPANT	\N	PRESENT	0
603925	603142	14001X	PARTICIPANT	\N	PRESENT	0
603926	603142	14151M	PARTICIPANT	\N	PRESENT	0
603927	603142	19575F	PARTICIPANT	\N	PRESENT	0
603928	603142	20070A	PARTICIPANT	\N	PRESENT	0
603929	603142	07004J	PARTICIPANT	\N	PRESENT	0
603930	603142	19693L	PARTICIPANT	\N	PRESENT	0
603932	603142	20090E	PARTICIPANT	\N	PRESENT	0
603933	603142	20148F	PARTICIPANT	\N	PRESENT	0
603934	603142	19447X	PARTICIPANT	\N	PRESENT	0
603935	603142	19349W	PARTICIPANT	\N	PRESENT	0
603936	603142	19713W	PARTICIPANT	\N	PRESENT	0
603937	603142	19735D	PARTICIPANT	\N	PRESENT	0
603938	603142	17779H	PARTICIPANT	\N	PRESENT	0
603939	603142	20094J	PARTICIPANT	\N	PRESENT	0
603940	603142	20030R	PARTICIPANT	\N	PRESENT	0
603941	603142	20116W	PARTICIPANT	\N	PRESENT	0
603942	603142	19749K	PARTICIPANT	\N	PRESENT	0
603943	603142	12016W	PARTICIPANT	\N	PRESENT	0
603944	603142	18193Q	PARTICIPANT	\N	PRESENT	0
603945	603142	11064N	PARTICIPANT	\N	PRESENT	0
603946	603142	19637C	PARTICIPANT	\N	PRESENT	0
603947	603142	19551W	PARTICIPANT	\N	PRESENT	0
603948	603142	19531S	PARTICIPANT	\N	PRESENT	0
603949	603142	20248J	PARTICIPANT	\N	PRESENT	0
603950	603142	19251M	PARTICIPANT	\N	PRESENT	0
603951	603142	19701S	PARTICIPANT	\N	PRESENT	0
603953	603142	19691J	PARTICIPANT	\N	PRESENT	0
603954	603142	19685L	PARTICIPANT	\N	PRESENT	0
603958	603142	14083S	PARTICIPANT	\N	PRESENT	0
603960	603142	16685X	PARTICIPANT	\N	PRESENT	0
603963	603142	97011G	PARTICIPANT	\N	PRESENT	0
603964	603142	01034P	PARTICIPANT	\N	PRESENT	0
603965	603142	01043Q	PARTICIPANT	\N	PRESENT	0
603966	603142	11083R	PARTICIPANT	\N	PRESENT	0
603970	603142	11054L	PARTICIPANT	\N	PRESENT	0
603972	603142	20092G	PARTICIPANT	\N	PRESENT	0
603974	603142	11026G	PARTICIPANT	\N	PRESENT	0
603976	603142	19591F	PARTICIPANT	\N	PRESENT	0
603978	603142	19543W	PARTICIPANT	\N	PRESENT	0
611513	610282	19569H	PARTICIPANT	\N	PRESENT	0
611514	610282	20066E	PARTICIPANT	\N	PRESENT	0
611515	610282	04043D	PARTICIPANT	\N	PRESENT	0
611516	610282	11097X	PARTICIPANT	\N	PRESENT	0
611517	610282	19713W	PARTICIPANT	\N	PRESENT	0
611518	610282	20248J	PARTICIPANT	\N	PRESENT	0
611519	610282	11031D	PARTICIPANT	\N	PRESENT	0
611520	610282	19415P	PARTICIPANT	\N	PRESENT	0
611530	610282	11045K	PARTICIPANT	\N	PRESENT	0
611574	610282	14223L	PARTICIPANT	\N	PRESENT	0
611604	610282	04057K	PARTICIPANT	\N	PRESENT	0
611605	610282	19697Q	PARTICIPANT	\N	PRESENT	0
611606	610282	19663E	PARTICIPANT	\N	PRESENT	0
611612	610727	11109J	PARTICIPANT	\N	EXCUSE	0
612812	610701	14133K	PARTICIPANT	\N	PRESENT	0
612813	610701	14189C	PARTICIPANT	\N	PRESENT	0
612814	610701	14207L	PARTICIPANT	\N	PRESENT	0
612815	610701	20104S	PRESIDENT	0	PRESENT	0
612816	610701	14357A	PARTICIPANT	\N	PRESENT	0
612817	610701	20100N	PARTICIPANT	\N	PRESENT	0
612818	610701	04035D	PARTICIPANT	\N	PRESENT	0
612819	610701	11083R	PARTICIPANT	\N	PRESENT	0
612820	610701	14033T	PARTICIPANT	\N	PRESENT	0
612821	610701	14097Y	PARTICIPANT	\N	PRESENT	0
612822	610701	19711U	PARTICIPANT	\N	PRESENT	0
612823	610701	14001X	PARTICIPANT	\N	EXCUSE	0
612824	610701	14237S	PARTICIPANT	\N	EXCUSE	0
612825	610701	10015M	PARTICIPANT	\N	PRESENT	0
612826	610701	04045F	PARTICIPANT	\N	PRESENT	0
613043	610789	10006L	PARTICIPANT	\N	PRESENT	0
613044	610789	14147R	PRESIDENT	0	PRESENT	0
613045	610789	19691J	PARTICIPANT	\N	PRESENT	0
613046	610789	19301E	PARTICIPANT	\N	PRESENT	0
613047	610789	19703U	PRESIDENT	1	PRESENT	0
613048	610789	04092N	PARTICIPANT	\N	PRESENT	0
613049	610789	01062T	PARTICIPANT	\N	PRESENT	0
613050	610789	19735D	PARTICIPANT	\N	PRESENT	0
613051	610789	19467C	PARTICIPANT	\N	PRESENT	0
613058	610789	20148F	PARTICIPANT	\N	PRESENT	0
613053	610789	19683J	PARTICIPANT	\N	EXCUSE	0
613054	610789	19723Y	PARTICIPANT	\N	PRESENT	0
613055	610789	20062A	PARTICIPANT	\N	PRESENT	0
613056	610789	19713W	PARTICIPANT	\N	PRESENT	0
613064	610789	20130U	PARTICIPANT	\N	PRESENT	0
613059	610789	19295A	PARTICIPANT	\N	PRESENT	0
613060	610789	11031D	PARTICIPANT	\N	PRESENT	0
613071	610741	19717B	PARTICIPANT	\N	PRESENT	0
613072	610741	18083K	PARTICIPANT	\N	PRESENT	1
613073	610741	17023S	PARTICIPANT	\N	PRESENT	0
613074	610741	20034V	PARTICIPANT	\N	EXCUSE	0
613075	610741	14059S	PARTICIPANT	\N	EXCUSE	0
613076	610741	19673G	PARTICIPANT	\N	EXCUSE	0
613077	610741	20150Y	PARTICIPANT	\N	PRESENT	0
613078	610741	20146D	PARTICIPANT	\N	PRESENT	0
613079	610741	20148F	PARTICIPANT	\N	EXCUSE	0
613081	610741	11072N	PARTICIPANT	\N	EXCUSE	0
613138	612318	19693L	PARTICIPANT	\N	PRESENT	0
613139	612318	20072C	PARTICIPANT	\N	PRESENT	0
613140	612318	20128B	PARTICIPANT	\N	PRESENT	0
613141	612318	19735D	PARTICIPANT	\N	PRESENT	0
613142	612318	19723Y	PARTICIPANT	\N	PRESENT	0
613143	612318	01048V	PARTICIPANT	\N	PRESENT	0
613144	612318	11067R	PARTICIPANT	\N	PRESENT	0
613145	612318	19593H	PARTICIPANT	\N	PRESENT	0
613146	612318	19503N	PARTICIPANT	\N	PRESENT	0
613147	612318	04043D	PARTICIPANT	\N	PRESENT	0
613148	612318	01058X	PARTICIPANT	\N	PRESENT	0
613154	613153	19709B	PARTICIPANT	\N	PRESENT	0
613155	613153	11041F	PARTICIPANT	\N	PRESENT	0
613159	613157	19709B	PARTICIPANT	\N	PRESENT	1
613174	613173	01058X	PARTICIPANT	\N	PRESENT	0
613176	613175	01058X	PARTICIPANT	\N	PRESENT	1
613178	613177	14133K	PARTICIPANT	\N	PRESENT	0
613192	613190	19551W	PARTICIPANT	\N	EXCUSE	0
613193	613190	20042V	PARTICIPANT	\N	EXCUSE	0
613194	613190	95063L	PARTICIPANT	\N	EXCUSE	0
613195	613190	14193X	PARTICIPANT	\N	EXCUSE	0
613291	613190	19479G	PARTICIPANT	\N	EXCUSE	0
613292	613190	20018V	PARTICIPANT	\N	EXCUSE	0
613293	613190	11097X	PARTICIPANT	\N	PRESENT	0
613294	613190	20144B	PARTICIPANT	\N	EXCUSE	0
613296	613190	11040E	PARTICIPANT	\N	EXCUSE	0
613297	613190	01028R	PARTICIPANT	\N	EXCUSE	0
613298	613190	20032T	PARTICIPANT	\N	EXCUSE	0
613299	613190	99004R	PARTICIPANT	\N	EXCUSE	0
613300	613190	14259Y	PARTICIPANT	\N	PRESENT	0
613309	613308	14225N	PARTICIPANT	\N	PRESENT	0
613521	613520	19515S	PARTICIPANT	\N	PRESENT	0
613522	613520	14083S	PARTICIPANT	\N	PRESENT	0
613523	613520	16685X	PARTICIPANT	\N	PRESENT	0
613524	613520	19671E	PARTICIPANT	\N	PRESENT	0
613525	613520	19762G	PARTICIPANT	\N	PRESENT	0
613540	613536	19515S	PARTICIPANT	\N	PRESENT	0
613541	613536	14083S	PARTICIPANT	\N	PRESENT	0
613543	613536	16685X	PARTICIPANT	\N	PRESENT	0
613544	613536	19671E	PARTICIPANT	\N	PRESENT	0
613545	613536	19762G	PARTICIPANT	\N	PRESENT	0
613619	613618	19515S	PARTICIPANT	\N	PRESENT	0
613621	613618	14083S	PARTICIPANT	\N	PRESENT	0
613622	613618	16685X	PARTICIPANT	\N	PRESENT	0
613623	613618	19671E	PARTICIPANT	\N	PRESENT	0
613625	613618	19762G	PARTICIPANT	\N	PRESENT	0
614028	613070	11048N	PARTICIPANT	\N	PRESENT	0
614029	613070	08009T	PARTICIPANT	\N	PRESENT	0
614030	613070	19349W	PARTICIPANT	\N	PRESENT	0
614031	613070	19667J	PARTICIPANT	\N	PRESENT	0
614032	613070	20116W	PARTICIPANT	\N	PRESENT	0
614033	613070	20044X	PARTICIPANT	\N	PRESENT	0
614034	613070	14173T	PARTICIPANT	\N	PRESENT	0
614038	613070	14327T	PARTICIPANT	\N	PRESENT	0
614039	613070	14121F	PARTICIPANT	\N	PRESENT	0
614040	613070	14225N	PRESIDENT	0	PRESENT	0
614041	613070	01057W	PARTICIPANT	\N	PRESENT	0
614048	613385	20030R	PARTICIPANT	\N	PRESENT	0
614049	613385	19383Y	PARTICIPANT	\N	PRESENT	0
614050	613385	14038Y	PARTICIPANT	\N	PRESENT	0
614051	613385	20088L	PARTICIPANT	\N	PRESENT	0
614052	613385	19768N	PARTICIPANT	\N	PRESENT	0
614053	613385	20034V	PARTICIPANT	\N	PRESENT	0
614054	613385	19782L	PARTICIPANT	\N	PRESENT	0
614055	613385	14187A	PARTICIPANT	\N	PRESENT	0
614056	613385	20078J	PARTICIPANT	\N	PRESENT	0
614057	613385	19441R	PARTICIPANT	\N	PRESENT	0
614058	613385	20082E	PARTICIPANT	\N	PRESENT	0
614059	613385	04045F	PARTICIPANT	\N	PRESENT	0
614060	613385	19631V	PARTICIPANT	\N	PRESENT	0
614061	613385	20174H	PARTICIPANT	\N	PRESENT	0
614062	613385	20062A	PARTICIPANT	\N	PRESENT	0
614063	613385	19507S	PARTICIPANT	\N	PRESENT	0
614064	613385	19747H	PARTICIPANT	\N	PRESENT	0
614065	613385	14207L	PARTICIPANT	\N	PRESENT	0
614066	613385	08028W	PARTICIPANT	\N	PRESENT	0
614067	613385	14257W	PARTICIPANT	\N	PRESENT	0
614068	613385	11090Q	PRESIDENT	0	PRESENT	0
614069	613385	14205J	PARTICIPANT	\N	PRESENT	0
614070	613385	19369B	PARTICIPANT	\N	PRESENT	0
614071	613385	20028X	PARTICIPANT	\N	PRESENT	0
614072	613385	20054A	PARTICIPANT	\N	PRESENT	0
614073	611540	19766L	PARTICIPANT	\N	PRESENT	0
614074	611540	19699S	PARTICIPANT	\N	PRESENT	0
614075	611540	01060R	PARTICIPANT	\N	PRESENT	0
614076	611540	14229S	PARTICIPANT	\N	PRESENT	0
614077	611540	20098N	PARTICIPANT	\N	PRESENT	0
614078	611540	92040Q	PARTICIPANT	\N	PRESENT	0
614079	611540	20112S	PARTICIPANT	\N	PRESENT	0
614080	611540	20026V	PARTICIPANT	\N	PRESENT	0
614081	611540	19593H	PARTICIPANT	\N	PRESENT	0
614082	611540	19643A	PARTICIPANT	\N	PRESENT	0
614083	611540	20132W	PARTICIPANT	\N	PRESENT	0
614084	611540	20134Y	PARTICIPANT	\N	PRESENT	0
614085	611540	14073Q	PARTICIPANT	\N	PRESENT	0
614086	611540	19651A	PARTICIPANT	\N	PRESENT	0
614087	611540	19611R	PRESIDENT	0	PRESENT	0
614088	611540	19693L	PARTICIPANT	\N	PRESENT	0
614089	611540	19399H	PARTICIPANT	\N	PRESENT	0
614090	611540	20152B	PARTICIPANT	\N	PRESENT	0
600417	600407	20034V	PARTICIPANT	\N	PRESENT	0
600418	600402	20034V	PARTICIPANT	\N	PRESENT	0
600419	600405	20034V	PARTICIPANT	\N	PRESENT	0
600420	600413	20034V	PARTICIPANT	\N	PRESENT	0
600423	600410	20034V	PARTICIPANT	\N	PRESENT	0
600424	600414	20034V	PARTICIPANT	\N	PRESENT	0
600426	600425	20034V	PARTICIPANT	\N	PRESENT	0
600751	600750	19768N	PARTICIPANT	\N	PRESENT	0
600759	600750	19515S	PARTICIPANT	\N	PRESENT	0
600760	600750	19383Y	PARTICIPANT	\N	PRESENT	0
600761	600750	14033T	PARTICIPANT	\N	PRESENT	0
600762	600750	20078J	PARTICIPANT	\N	PRESENT	0
600912	600911	19369B	PARTICIPANT	\N	PRESENT	0
606284	603133	07029T	PARTICIPANT	\N	EXCUSE	0
607006	606808	19671E	PARTICIPANT	\N	EXCUSE	0
607386	606854	19762G	PARTICIPANT	\N	PRESENT	0
609715	608516	08034U	PARTICIPANT	\N	PRESENT	0
609716	608516	19387D	PARTICIPANT	\N	PRESENT	0
609717	608516	19747H	PARTICIPANT	\N	PRESENT	0
609718	608516	19415P	PARTICIPANT	\N	PRESENT	0
609719	608516	11097X	PARTICIPANT	\N	PRESENT	0
609720	608516	17589D	PARTICIPANT	\N	PRESENT	0
609721	608516	04033B	PARTICIPANT	\N	PRESENT	0
609722	608516	14223L	PARTICIPANT	\N	PRESENT	0
609723	608516	14251Q	PARTICIPANT	\N	PRESENT	0
609724	608516	20050V	PARTICIPANT	\N	PRESENT	0
609725	608516	11043H	PARTICIPANT	\N	PRESENT	0
609726	608516	19347U	PARTICIPANT	\N	PRESENT	0
609727	608516	14169X	PARTICIPANT	\N	PRESENT	0
609728	608516	20122U	PARTICIPANT	\N	PRESENT	0
609729	608516	19643A	PARTICIPANT	\N	PRESENT	0
609730	608516	14195A	PARTICIPANT	\N	PRESENT	0
609731	608516	17367Q	PARTICIPANT	\N	PRESENT	0
609732	608516	11080N	PARTICIPANT	\N	PRESENT	0
609733	608516	01057W	PARTICIPANT	\N	PRESENT	0
609734	608516	19565D	PARTICIPANT	\N	PRESENT	0
609735	608516	19679N	PARTICIPANT	\N	PRESENT	0
609736	608516	19593H	PARTICIPANT	\N	PRESENT	0
609737	608516	05012A	PARTICIPANT	\N	PRESENT	0
609738	608516	11090Q	PARTICIPANT	\N	PRESENT	0
609739	608516	04043D	PARTICIPANT	\N	PRESENT	0
609740	608516	14069U	PARTICIPANT	\N	PRESENT	0
609741	608516	14053L	PARTICIPANT	\N	PRESENT	0
609742	608516	19421M	PARTICIPANT	\N	PRESENT	0
609743	608516	14237S	PARTICIPANT	\N	PRESENT	0
609744	608516	14030Q	PARTICIPANT	\N	PRESENT	0
609761	608516	20042V	PARTICIPANT	\N	PRESENT	0
609746	608516	10006L	PARTICIPANT	\N	PRESENT	0
609747	608516	19533U	PARTICIPANT	\N	PRESENT	0
609748	608516	14189C	PARTICIPANT	\N	PRESENT	0
609749	608516	14083S	PARTICIPANT	\N	PRESENT	0
609750	608516	11053K	PARTICIPANT	\N	PRESENT	0
609751	608516	19721W	PARTICIPANT	\N	PRESENT	0
609752	608516	14259Y	PARTICIPANT	\N	PRESENT	0
609753	608516	20136B	PARTICIPANT	\N	PRESENT	0
609754	608516	11115U	PARTICIPANT	\N	PRESENT	0
609755	608516	14267Y	PARTICIPANT	\N	PRESENT	0
609756	608516	14031R	PARTICIPANT	\N	PRESENT	0
609757	608516	14173T	PARTICIPANT	\N	PRESENT	0
609758	608516	92040Q	PARTICIPANT	\N	PRESENT	0
609760	608516	20096L	PARTICIPANT	\N	PRESENT	0
609762	608516	17229F	PARTICIPANT	\N	PRESENT	0
609763	608516	20140W	PARTICIPANT	\N	PRESENT	0
609764	608516	20026V	PARTICIPANT	\N	PRESENT	0
609765	608516	14042U	PARTICIPANT	\N	PRESENT	0
609766	608709	04059M	PARTICIPANT	\N	PRESENT	0
609767	608709	20112S	PARTICIPANT	\N	PRESENT	0
609768	608516	20180F	PARTICIPANT	\N	PRESENT	0
609769	608516	20056C	PARTICIPANT	\N	PRESENT	0
609770	608709	19651A	PARTICIPANT	\N	PRESENT	0
609771	608709	14030Q	PARTICIPANT	\N	PRESENT	0
609772	608709	19643A	PARTICIPANT	\N	PRESENT	0
609773	608709	19621T	PARTICIPANT	\N	PRESENT	0
609774	608709	19758L	PARTICIPANT	\N	PRESENT	0
609775	608516	97011G	PARTICIPANT	\N	PRESENT	0
609776	608709	20264J	PARTICIPANT	\N	PRESENT	0
609777	608516	14147R	PARTICIPANT	\N	PRESENT	0
609778	608709	19693L	PARTICIPANT	\N	PRESENT	0
609779	608709	20132W	PARTICIPANT	\N	PRESENT	0
609780	608709	14123H	PARTICIPANT	\N	PRESENT	0
609781	608516	17737W	PARTICIPANT	\N	PRESENT	0
609782	608709	20180F	PARTICIPANT	\N	PRESENT	0
609783	608709	20048C	PARTICIPANT	\N	PRESENT	0
609784	608709	19399H	PARTICIPANT	\N	PRESENT	0
609785	608516	07033P	PARTICIPANT	\N	PRESENT	0
609786	608516	19691J	PARTICIPANT	\N	PRESENT	0
609787	608709	20056C	PARTICIPANT	\N	PRESENT	0
609788	608516	14179A	PARTICIPANT	\N	PRESENT	0
609789	608516	20252E	PARTICIPANT	\N	PRESENT	0
609790	608709	14073Q	PARTICIPANT	\N	PRESENT	0
609791	608709	19611R	PARTICIPANT	\N	PRESENT	0
609792	608516	19611R	PARTICIPANT	\N	PRESENT	0
609793	608516	19699S	PARTICIPANT	\N	PRESENT	0
609794	608709	19699S	PARTICIPANT	\N	PRESENT	0
609795	608709	20052X	PARTICIPANT	\N	PRESENT	0
609796	608709	20142Y	PARTICIPANT	\N	PRESENT	0
609797	608516	19762G	PARTICIPANT	\N	PRESENT	0
609798	608709	14109K	PARTICIPANT	\N	PRESENT	0
609799	608516	20062A	PARTICIPANT	\N	PRESENT	0
609800	608709	19573D	PARTICIPANT	\N	PRESENT	0
609801	608709	19533U	PARTICIPANT	\N	PRESENT	0
609802	608516	20152B	PARTICIPANT	\N	PRESENT	0
609803	608709	04033B	PARTICIPANT	\N	PRESENT	0
609804	608516	20020P	PARTICIPANT	\N	PRESENT	0
609805	608516	19629C	PARTICIPANT	\N	PRESENT	0
609806	608709	14229S	PARTICIPANT	\N	PRESENT	0
609807	608709	20084G	PARTICIPANT	\N	PRESENT	0
609808	608516	20048C	PARTICIPANT	\N	PRESENT	0
609809	608709	19527W	PARTICIPANT	\N	PRESENT	0
609810	608516	14213J	PARTICIPANT	\N	PRESENT	0
609811	608516	20052X	PARTICIPANT	\N	PRESENT	0
609812	608709	20026V	PARTICIPANT	\N	PRESENT	0
609813	608516	20024T	PARTICIPANT	\N	PRESENT	0
609814	608516	14219Q	PARTICIPANT	\N	PRESENT	0
609815	608516	20108W	PARTICIPANT	\N	PRESENT	0
609816	608516	19573D	PARTICIPANT	\N	PRESENT	0
609817	608516	11070L	PARTICIPANT	\N	PRESENT	0
609818	608516	19441R	PARTICIPANT	\N	PRESENT	0
609819	608516	14033T	PARTICIPANT	\N	PRESENT	0
609820	608516	20066E	PARTICIPANT	\N	PRESENT	0
609821	608516	19467C	PARTICIPANT	\N	PRESENT	0
609822	608516	20112S	PARTICIPANT	\N	PRESENT	0
609823	608516	19723Y	PARTICIPANT	\N	PRESENT	0
609824	608516	04085P	PARTICIPANT	\N	PRESENT	0
609825	608516	19369B	PARTICIPANT	\N	PRESENT	0
609826	608516	20058E	PARTICIPANT	\N	PRESENT	0
609827	608516	19663E	PARTICIPANT	\N	PRESENT	0
609828	608516	04070G	PARTICIPANT	\N	PRESENT	0
609829	608516	19709B	PARTICIPANT	\N	PRESENT	0
609830	608516	08018U	PARTICIPANT	\N	PRESENT	0
609831	608516	07029T	PARTICIPANT	\N	PRESENT	0
609832	608516	08015R	PARTICIPANT	\N	PRESENT	0
609833	608516	19826F	PARTICIPANT	\N	PRESENT	0
609834	608516	19713W	PARTICIPANT	\N	PRESENT	0
609835	608516	20086J	PARTICIPANT	\N	PRESENT	0
609836	608516	01034P	PARTICIPANT	\N	PRESENT	0
609837	608516	19507S	PARTICIPANT	\N	PRESENT	0
609838	608516	19705W	PARTICIPANT	\N	PRESENT	0
609839	608516	19768N	PARTICIPANT	\N	PRESENT	0
609840	608516	19707Y	PARTICIPANT	\N	PRESENT	0
609841	608516	08056B	PARTICIPANT	\N	PRESENT	0
609842	608516	20054A	PARTICIPANT	\N	PRESENT	0
609843	608516	20126Y	PARTICIPANT	\N	PRESENT	0
609847	608516	20088L	PARTICIPANT	\N	PRESENT	0
609845	608516	86034E	PARTICIPANT	\N	PRESENT	0
609846	608516	04059M	PARTICIPANT	\N	PRESENT	0
609848	608516	08069G	PARTICIPANT	\N	PRESENT	0
609849	608516	19681G	PARTICIPANT	\N	PRESENT	0
609850	608516	14187A	PARTICIPANT	\N	PRESENT	0
609851	608516	20060X	PARTICIPANT	\N	PRESENT	0
609852	608516	05008E	PARTICIPANT	\N	PRESENT	0
609853	608516	11110B	PARTICIPANT	\N	PRESENT	0
609854	608516	19489J	PARTICIPANT	\N	PRESENT	0
609855	608516	08045X	PARTICIPANT	\N	PRESENT	0
609856	608516	19621T	PARTICIPANT	\N	PRESENT	0
609857	608516	14121F	PARTICIPANT	\N	PRESENT	0
609858	608516	19367Y	PARTICIPANT	\N	PRESENT	0
609859	608516	19551W	PARTICIPANT	\N	PRESENT	0
609860	608516	19531S	PARTICIPANT	\N	PRESENT	0
609861	608516	20264J	PARTICIPANT	\N	PRESENT	0
607344	607183	99004R	PARTICIPANT	\N	PRESENT	0
607345	606428	19766L	PARTICIPANT	\N	PRESENT	0
607346	606428	19699S	PARTICIPANT	\N	PRESENT	0
607347	606428	19533U	PARTICIPANT	\N	PRESENT	0
607348	606428	04033B	PARTICIPANT	\N	PRESENT	0
607349	606428	14229S	PARTICIPANT	\N	PRESENT	0
607350	606428	19573D	PARTICIPANT	\N	PRESENT	0
607351	606428	20112S	PARTICIPANT	\N	PRESENT	0
607352	606428	92040Q	PARTICIPANT	\N	PRESENT	0
607353	606428	20124W	PARTICIPANT	\N	PRESENT	0
607354	606428	20026V	PARTICIPANT	\N	PRESENT	0
607355	606428	19593H	PARTICIPANT	\N	PRESENT	0
607356	606428	19527W	PARTICIPANT	\N	PRESENT	0
607357	606428	19643A	PARTICIPANT	\N	PRESENT	0
607358	606428	20132W	PARTICIPANT	\N	PRESENT	0
607359	606428	19611R	PRESIDENT	0	PRESENT	0
607360	606428	20142Y	PARTICIPANT	\N	PRESENT	0
607361	606428	20048C	PARTICIPANT	\N	PRESENT	0
607362	606428	19693L	PARTICIPANT	\N	PRESENT	0
607363	606428	19399H	PARTICIPANT	\N	PRESENT	0
607364	606428	19719D	PARTICIPANT	\N	PRESENT	0
607365	606428	20056C	PARTICIPANT	\N	PRESENT	0
607366	606428	20180F	PARTICIPANT	\N	PRESENT	0
607367	606428	19735D	PARTICIPANT	\N	PRESENT	0
607368	606428	20266L	PARTICIPANT	\N	PRESENT	0
607369	606428	14109K	PARTICIPANT	\N	PRESENT	0
607370	606428	11104D	PARTICIPANT	\N	PRESENT	0
607371	606428	11043H	PARTICIPANT	\N	PRESENT	0
607372	606428	20084G	PARTICIPANT	\N	PRESENT	0
607373	606428	19621T	PARTICIPANT	\N	PRESENT	0
607374	607183	14083S	PARTICIPANT	\N	PRESENT	0
607375	607183	19741B	PARTICIPANT	\N	PRESENT	0
607376	607183	20126Y	PARTICIPANT	\N	PRESENT	0
607377	607183	01057W	PARTICIPANT	\N	PRESENT	0
607378	607183	20070A	PARTICIPANT	\N	PRESENT	0
607379	607183	14331P	PARTICIPANT	\N	PRESENT	0
607380	607183	07029T	PARTICIPANT	\N	PRESENT	0
607381	607183	20050V	PARTICIPANT	\N	PRESENT	0
607382	607183	11012A	PARTICIPANT	\N	PRESENT	0
607384	607183	20086J	PARTICIPANT	\N	PRESENT	0
607387	607183	19711U	PARTICIPANT	\N	PRESENT	0
607388	607183	19531S	PARTICIPANT	\N	PRESENT	0
607391	606428	20152B	PARTICIPANT	\N	PRESENT	0
607392	606428	14030Q	PARTICIPANT	\N	PRESENT	0
607393	606428	14123H	PARTICIPANT	\N	PRESENT	0
607394	606428	11109J	PARTICIPANT	\N	EXCUSE	0
607395	607183	14225N	PRESIDENT	0	PRESENT	0
607396	607183	04071H	PARTICIPANT	\N	PRESENT	0
607397	607183	11040E	PARTICIPANT	\N	PRESENT	0
607400	607183	14189C	PARTICIPANT	\N	PRESENT	0
607404	607183	19762G	PARTICIPANT	\N	PRESENT	0
607407	607183	11110B	PARTICIPANT	\N	PRESENT	0
607408	607183	19689Q	PARTICIPANT	\N	PRESENT	0
607409	607183	19647E	PARTICIPANT	\N	PRESENT	0
607410	607183	20252E	PARTICIPANT	\N	PRESENT	0
607411	606407	14053L	PARTICIPANT	\N	PRESENT	0
607412	606407	14001X	PARTICIPANT	\N	PRESENT	0
607413	606407	04047H	PRESIDENT	0	PRESENT	0
607414	606407	01028R	PARTICIPANT	\N	PRESENT	0
607415	606407	19447X	PARTICIPANT	\N	PRESENT	0
607416	606407	05008E	PARTICIPANT	\N	PRESENT	0
607417	606407	04085P	PARTICIPANT	\N	PRESENT	0
607418	606407	19725B	PARTICIPANT	\N	PRESENT	0
607419	606407	11056N	PARTICIPANT	\N	PRESENT	0
607420	606407	19489J	PARTICIPANT	\N	PRESENT	0
607421	606407	95063L	PARTICIPANT	\N	PRESENT	0
607422	606407	14147R	PARTICIPANT	\N	PRESENT	0
607423	606407	14151M	PARTICIPANT	\N	PRESENT	0
607424	606407	20114U	PARTICIPANT	\N	PRESENT	0
607425	606407	14215L	PARTICIPANT	\N	PRESENT	0
607426	606407	08018U	PARTICIPANT	\N	PRESENT	0
607427	606407	20022R	PARTICIPANT	\N	PRESENT	0
607428	606407	04008A	PARTICIPANT	\N	PRESENT	0
607429	606407	20128B	PARTICIPANT	\N	PRESENT	0
607430	606407	14021P	PARTICIPANT	\N	PRESENT	0
607431	606407	19629C	PARTICIPANT	\N	PRESENT	0
607432	606407	07004J	PARTICIPANT	\N	PRESENT	0
607433	606407	10015M	PARTICIPANT	\N	PRESENT	0
607434	606407	14107H	PARTICIPANT	\N	PRESENT	0
607435	606407	20110Q	PARTICIPANT	\N	PRESENT	0
607436	606407	14069U	PARTICIPANT	\N	PRESENT	0
607437	606407	19543W	PARTICIPANT	\N	PRESENT	0
607438	606407	14231L	PARTICIPANT	\N	PRESENT	0
607439	606407	11072N	PARTICIPANT	\N	PRESENT	0
607440	606407	14089Y	PARTICIPANT	\N	EXCUSE	0
607441	606407	19729F	PARTICIPANT	\N	EXCUSE	0
607442	606407	17737W	PARTICIPANT	\N	EXCUSE	0
607443	606407	19581D	PARTICIPANT	\N	EXCUSE	0
607444	606407	11033F	PARTICIPANT	\N	EXCUSE	0
607450	607183	20044X	PARTICIPANT	\N	EXCUSE	0
607451	606407	14259Y	PARTICIPANT	\N	PRESENT	0
607453	606402	95041E	PARTICIPANT	\N	PRESENT	0
607454	606402	19443T	PARTICIPANT	\N	PRESENT	0
607455	606402	12041X	PARTICIPANT	\N	PRESENT	0
607456	606402	11080N	PARTICIPANT	\N	PRESENT	0
607457	606402	19565D	PARTICIPANT	\N	PRESENT	0
607458	606402	20072C	PARTICIPANT	\N	PRESENT	0
607459	606402	11027H	PARTICIPANT	\N	PRESENT	0
607460	606402	04042C	PRESIDENT	0	PRESENT	0
607461	606402	11054L	PARTICIPANT	\N	PRESENT	0
607462	606402	19669L	PARTICIPANT	\N	PRESENT	0
607463	606402	11066Q	PARTICIPANT	\N	PRESENT	0
607464	606402	08056B	PARTICIPANT	\N	PRESENT	0
607465	606402	12028B	PARTICIPANT	\N	PRESENT	0
607466	606402	14055N	PARTICIPANT	\N	PRESENT	0
607467	606402	19709B	PARTICIPANT	\N	PRESENT	0
607468	606402	14193X	PARTICIPANT	\N	PRESENT	0
607469	606402	07033P	PARTICIPANT	\N	PRESENT	0
607470	606402	97011G	PARTICIPANT	\N	PRESENT	0
607471	606402	08047A	PRESIDENT	1	PRESENT	0
607472	606402	14059S	PARTICIPANT	\N	PRESENT	0
607473	606402	14097Y	PARTICIPANT	\N	PRESENT	0
607474	606402	04035D	PARTICIPANT	\N	PRESENT	0
607475	606402	14133K	PARTICIPANT	\N	PRESENT	0
607476	606402	01062T	PARTICIPANT	\N	PRESENT	0
607477	606402	08069G	PARTICIPANT	\N	PRESENT	0
607478	606402	11041F	PARTICIPANT	\N	PRESENT	0
607479	606402	20042V	PARTICIPANT	\N	PRESENT	0
607480	606402	01024M	PARTICIPANT	\N	PRESENT	0
607481	606402	19721W	PARTICIPANT	\N	PRESENT	0
607482	606402	14105F	PARTICIPANT	\N	PRESENT	0
607483	606402	20064C	PARTICIPANT	\N	PRESENT	0
607484	606402	14267Y	PARTICIPANT	\N	PRESENT	0
607485	606402	14255U	PARTICIPANT	\N	PRESENT	0
608566	606777	20040T	PARTICIPANT	\N	PRESENT	0
608567	606780	19691J	PARTICIPANT	\N	PRESENT	0
608568	606798	19691J	PARTICIPANT	\N	PRESENT	0
608569	606798	17965H	PARTICIPANT	\N	PRESENT	0
608954	608660	19717B	PARTICIPANT	\N	PRESENT	1
608955	608660	19631V	PARTICIPANT	\N	PRESENT	0
608956	608660	05008E	PARTICIPANT	\N	EXCUSE	0
608957	608660	19577H	PARTICIPANT	\N	PRESENT	1
608958	608660	17023S	PARTICIPANT	\N	PRESENT	0
608959	608660	97011G	PARTICIPANT	\N	PRESENT	0
608960	608660	20034V	PARTICIPANT	\N	PRESENT	1
608961	608660	14097Y	PARTICIPANT	\N	PRESENT	0
608962	608660	14331P	PARTICIPANT	\N	PRESENT	0
608963	608660	20148F	PARTICIPANT	\N	PRESENT	0
608996	608660	20146D	PARTICIPANT	\N	PRESENT	0
609017	608660	19715Y	PARTICIPANT	\N	EXCUSE	0
609230	609229	14053L	PARTICIPANT	\N	PRESENT	0
609232	609229	11066Q	PARTICIPANT	\N	PRESENT	0
609265	609264	04033B	PARTICIPANT	\N	PRESENT	0
609266	609264	14223L	PARTICIPANT	\N	PRESENT	0
609267	609264	19723Y	PARTICIPANT	\N	PRESENT	0
609268	609264	07033P	PARTICIPANT	\N	PRESENT	0
609269	609264	19447X	PARTICIPANT	\N	PRESENT	0
609270	609264	19367Y	PARTICIPANT	\N	PRESENT	0
609271	609264	20042V	PARTICIPANT	\N	PRESENT	0
609272	609264	08056B	PARTICIPANT	\N	PRESENT	0
604274	603124	14327T	PARTICIPANT	\N	PRESENT	0
604275	603124	99004R	PARTICIPANT	\N	PRESENT	0
604276	603124	14225N	PRESIDENT	0	PRESENT	0
604277	603124	14173T	PARTICIPANT	\N	PRESENT	0
604278	603143	01043Q	PARTICIPANT	\N	PRESENT	0
604279	603124	20086J	PARTICIPANT	\N	PRESENT	0
604280	603124	11048N	PARTICIPANT	\N	PRESENT	0
604281	603124	08010L	PARTICIPANT	\N	PRESENT	0
604282	603124	19711U	PARTICIPANT	\N	PRESENT	0
604283	603124	19545Y	PARTICIPANT	\N	PRESENT	0
604284	603124	12016W	PARTICIPANT	\N	PRESENT	0
604285	603124	20044X	PARTICIPANT	\N	PRESENT	0
604286	603124	19671E	PARTICIPANT	\N	PRESENT	0
604287	603124	20252E	PARTICIPANT	\N	PRESENT	0
604288	603124	19349W	PARTICIPANT	\N	PRESENT	0
604289	603124	19762G	PARTICIPANT	\N	PRESENT	0
604290	603124	14331P	PARTICIPANT	\N	PRESENT	0
604291	603124	14187A	PARTICIPANT	\N	PRESENT	0
604292	603124	20080C	PARTICIPANT	\N	PRESENT	0
604293	603124	19667J	PARTICIPANT	\N	PRESENT	0
604294	603143	14033T	PARTICIPANT	\N	PRESENT	0
604295	603143	20092G	PARTICIPANT	\N	PRESENT	0
604296	603143	20036X	PARTICIPANT	\N	PRESENT	0
604297	603143	20174H	PARTICIPANT	\N	PRESENT	0
604298	603143	19347U	PARTICIPANT	\N	PRESENT	0
604318	603143	19563B	PARTICIPANT	\N	PRESENT	0
604300	603143	20100N	PARTICIPANT	\N	PRESENT	0
604301	603143	20142Y	PARTICIPANT	\N	PRESENT	0
604302	603124	19333N	PARTICIPANT	\N	PRESENT	0
604304	603143	19631V	PARTICIPANT	\N	PRESENT	0
604305	603143	11056N	PARTICIPANT	\N	PRESENT	0
604306	603143	19820Y	PARTICIPANT	\N	PRESENT	0
604307	603143	14109K	PARTICIPANT	\N	PRESENT	0
604308	603143	19413M	PARTICIPANT	\N	PRESENT	0
604309	603143	20082E	PARTICIPANT	\N	PRESENT	0
604310	603143	14107H	PARTICIPANT	\N	PRESENT	0
604311	603124	20116W	PARTICIPANT	\N	PRESENT	0
604312	603143	11077T	PARTICIPANT	\N	PRESENT	0
604313	603143	19695N	PARTICIPANT	\N	PRESENT	0
604314	603143	20088L	PARTICIPANT	\N	PRESENT	0
604315	603124	11040E	PARTICIPANT	\N	PRESENT	0
604316	603143	14257W	PARTICIPANT	\N	PRESENT	0
604317	603143	19619A	PARTICIPANT	\N	PRESENT	0
604319	603143	19543W	PARTICIPANT	\N	PRESENT	0
604320	603143	04057K	PARTICIPANT	\N	PRESENT	0
604321	603143	14055N	PARTICIPANT	\N	PRESENT	0
604322	603143	20090E	PARTICIPANT	\N	PRESENT	0
604324	603143	20062A	PARTICIPANT	\N	PRESENT	0
604326	603143	20120S	PARTICIPANT	\N	PRESENT	0
604329	603143	19798U	PARTICIPANT	\N	PRESENT	0
604330	603143	19533U	PARTICIPANT	\N	PRESENT	0
604331	603143	14069U	PARTICIPANT	\N	PRESENT	0
604332	603143	97011G	PARTICIPANT	\N	PRESENT	0
604333	603143	20034V	PARTICIPANT	\N	PRESENT	0
604334	603143	14147R	PARTICIPANT	\N	PRESENT	0
604335	603143	11090Q	PARTICIPANT	\N	PRESENT	0
604345	603143	20032T	PARTICIPANT	\N	PRESENT	0
604337	603143	01048V	PARTICIPANT	\N	PRESENT	0
604338	603143	18083K	PARTICIPANT	\N	PRESENT	0
604339	603143	19507S	PARTICIPANT	\N	PRESENT	0
604340	603143	19447X	PARTICIPANT	\N	PRESENT	0
604341	603143	19515S	PARTICIPANT	\N	PRESENT	0
604342	603143	19575F	PARTICIPANT	\N	PRESENT	0
604343	603143	19703U	PARTICIPANT	\N	PRESENT	0
604344	603143	19251M	PARTICIPANT	\N	PRESENT	0
604346	603143	20028X	PARTICIPANT	\N	PRESENT	0
604347	603143	19715Y	PARTICIPANT	\N	PRESENT	0
604348	603124	01057W	PARTICIPANT	\N	PRESENT	0
604349	603143	14038Y	PARTICIPANT	\N	PRESENT	0
604350	603143	08015R	PARTICIPANT	\N	PRESENT	0
604351	603143	14191V	PARTICIPANT	\N	PRESENT	0
604352	603143	14097Y	PARTICIPANT	\N	PRESENT	0
604353	603143	20030R	PARTICIPANT	\N	PRESENT	0
604354	603143	19782L	PARTICIPANT	\N	PRESENT	0
604355	603143	19369B	PARTICIPANT	\N	PRESENT	0
604356	603143	08028W	PARTICIPANT	\N	PRESENT	0
604357	603143	20068G	PARTICIPANT	\N	PRESENT	0
604358	603124	07029T	PARTICIPANT	\N	PRESENT	0
604359	603124	20126Y	PARTICIPANT	\N	PRESENT	0
604360	603124	08034U	PARTICIPANT	\N	PRESENT	0
604361	603143	20136B	PARTICIPANT	\N	PRESENT	0
604362	603143	19954N	PARTICIPANT	\N	PRESENT	0
604363	603143	20104S	PARTICIPANT	\N	PRESENT	0
604364	603143	20026V	PARTICIPANT	\N	PRESENT	0
604365	603143	20180F	PARTICIPANT	\N	PRESENT	0
604366	603143	19581D	PARTICIPANT	\N	PRESENT	0
604367	603143	01024M	PARTICIPANT	\N	PRESENT	0
604368	603124	19335Q	PARTICIPANT	\N	PRESENT	0
604369	603124	19647E	PARTICIPANT	\N	PRESENT	0
604370	603124	19479G	PARTICIPANT	\N	PRESENT	0
604371	603124	19687N	PARTICIPANT	\N	PRESENT	0
604372	603124	20150Y	PARTICIPANT	\N	PRESENT	0
604373	603143	14189C	PARTICIPANT	\N	PRESENT	0
604374	603143	19758L	PARTICIPANT	\N	PRESENT	0
604375	603143	14026U	PARTICIPANT	\N	PRESENT	0
604376	603143	20152B	PARTICIPANT	\N	PRESENT	0
604380	603143	20144B	PARTICIPANT	\N	PRESENT	0
604378	603143	20038A	PARTICIPANT	\N	PRESENT	0
604379	603143	20056C	PARTICIPANT	\N	PRESENT	0
604381	603143	20140W	PARTICIPANT	\N	PRESENT	0
604382	603143	20020P	PARTICIPANT	\N	PRESENT	0
604383	603143	14331P	PARTICIPANT	\N	PRESENT	0
604384	603143	11097X	PARTICIPANT	\N	PRESENT	0
604385	603143	14193X	PARTICIPANT	\N	PRESENT	0
604386	603124	19399H	PARTICIPANT	\N	PRESENT	0
604387	603124	14083S	PARTICIPANT	\N	PRESENT	0
604388	603143	19467C	PARTICIPANT	\N	PRESENT	0
604389	603143	14231L	PARTICIPANT	\N	PRESENT	0
604390	603143	14105F	PARTICIPANT	\N	PRESENT	0
604391	603143	20102Q	PARTICIPANT	\N	PRESENT	0
604392	603143	10015M	PARTICIPANT	\N	PRESENT	0
604393	603143	11103C	PARTICIPANT	\N	PRESENT	0
604394	603143	19673G	PARTICIPANT	\N	PRESENT	0
604395	603143	14217N	PARTICIPANT	\N	PRESENT	0
604396	603124	20070A	PARTICIPANT	\N	PRESENT	0
604397	603143	19599P	PARTICIPANT	\N	PRESENT	0
604398	603143	14111D	PARTICIPANT	\N	PRESENT	0
604399	603143	04033B	PARTICIPANT	\N	PRESENT	0
604400	603143	20024T	PARTICIPANT	\N	PRESENT	0
604402	603143	11083R	PARTICIPANT	\N	PRESENT	0
604403	603143	19553Y	PARTICIPANT	\N	PRESENT	0
604404	603124	11012A	PARTICIPANT	\N	PRESENT	0
604464	604401	01043Q	PARTICIPANT	\N	PRESENT	0
604465	604401	11083R	PARTICIPANT	\N	PRESENT	0
604466	604401	04045F	PARTICIPANT	\N	PRESENT	0
604467	604401	11070L	PARTICIPANT	\N	PRESENT	0
604469	604401	11064N	PARTICIPANT	\N	PRESENT	0
604470	604401	19563B	PARTICIPANT	\N	PRESENT	0
604471	604401	19553Y	PARTICIPANT	\N	PRESENT	0
604472	604401	20174H	PARTICIPANT	\N	PRESENT	0
604473	604401	20100N	PARTICIPANT	\N	PRESENT	0
604474	604401	08060W	PARTICIPANT	\N	PRESENT	0
604475	604401	11026G	PARTICIPANT	\N	PRESENT	0
604476	604401	14001X	PARTICIPANT	\N	PRESENT	0
604477	604401	14097Y	PARTICIPANT	\N	PRESENT	0
604478	604401	19599P	PARTICIPANT	\N	PRESENT	0
604479	604401	19758L	PARTICIPANT	\N	PRESENT	0
604480	604401	14231L	PARTICIPANT	\N	PRESENT	0
604481	604401	01024M	PARTICIPANT	\N	PRESENT	0
604482	604401	20090E	PARTICIPANT	\N	PRESENT	0
604483	604401	14026U	PARTICIPANT	\N	PRESENT	0
604484	604401	20024T	PARTICIPANT	\N	PRESENT	0
604485	604401	20104S	PARTICIPANT	\N	PRESENT	0
604487	604401	10015M	PARTICIPANT	\N	PRESENT	0
604488	604401	14331P	PARTICIPANT	\N	PRESENT	0
604489	604401	20068G	PARTICIPANT	\N	PRESENT	0
604492	604401	12016W	PARTICIPANT	\N	PRESENT	0
604493	604401	20056C	PARTICIPANT	\N	PRESENT	0
604495	604401	19954N	PARTICIPANT	\N	PRESENT	0
604496	604401	20108W	PARTICIPANT	\N	PRESENT	0
604497	604401	19798U	PARTICIPANT	\N	PRESENT	0
604498	603124	11074Q	PARTICIPANT	\N	EXCUSE	0
604499	604401	19701S	PARTICIPANT	\N	PRESENT	0
604500	604401	04033B	PARTICIPANT	\N	PRESENT	0
604501	604401	01060R	PARTICIPANT	\N	PRESENT	0
604502	604401	19421M	PARTICIPANT	\N	PRESENT	0
604503	604401	20020P	PARTICIPANT	\N	PRESENT	0
604504	604401	14030Q	PARTICIPANT	\N	PRESENT	0
604505	604401	19441R	PARTICIPANT	\N	PRESENT	0
604506	604401	19673G	PARTICIPANT	\N	PRESENT	0
604507	604401	12041X	PARTICIPANT	\N	PRESENT	0
614091	611540	20052X	PARTICIPANT	\N	PRESENT	0
614092	611540	14030Q	PARTICIPANT	\N	PRESENT	0
614093	611540	20056C	PARTICIPANT	\N	PRESENT	0
614094	611540	20180F	PARTICIPANT	\N	PRESENT	0
614095	611540	20264J	PARTICIPANT	\N	PRESENT	0
614096	611540	11104D	PARTICIPANT	\N	PRESENT	0
614097	611540	19758L	PARTICIPANT	\N	PRESENT	0
614098	611540	17589D	PARTICIPANT	\N	PRESENT	0
614099	611540	19621T	PARTICIPANT	\N	PRESENT	0
614100	611540	20084G	PARTICIPANT	\N	PRESENT	0
614102	613070	20086J	PARTICIPANT	\N	PRESENT	0
614103	613070	19711U	PARTICIPANT	\N	PRESENT	0
614104	613070	08010L	PARTICIPANT	\N	PRESENT	0
614105	613070	19479G	PARTICIPANT	\N	PRESENT	0
614106	613070	20070A	PARTICIPANT	\N	PRESENT	0
614107	613070	20126Y	PARTICIPANT	\N	PRESENT	0
614108	611540	19533U	PARTICIPANT	\N	PRESENT	0
614109	611540	20142Y	PARTICIPANT	\N	PRESENT	0
614110	611540	20058E	PARTICIPANT	\N	PRESENT	0
614111	611540	11109J	PARTICIPANT	\N	EXCUSE	0
614114	612793	19543W	PARTICIPANT	\N	PRESENT	0
614115	612793	19585H	PARTICIPANT	\N	PRESENT	0
614116	612793	04047H	PRESIDENT	0	PRESENT	0
614117	612793	19447X	PARTICIPANT	\N	PRESENT	0
614118	612793	19489J	PARTICIPANT	\N	PRESENT	0
614119	612793	07004J	PARTICIPANT	\N	PRESENT	0
614120	612793	20108W	PARTICIPANT	\N	PRESENT	0
614121	612793	20110Q	PARTICIPANT	\N	PRESENT	0
614122	612793	14147R	PARTICIPANT	\N	PRESENT	0
614123	612793	20114U	PARTICIPANT	\N	PRESENT	0
614124	612793	14151M	PARTICIPANT	\N	PRESENT	0
614125	612793	14215L	PARTICIPANT	\N	PRESENT	0
614126	612793	08018U	PARTICIPANT	\N	PRESENT	0
614127	612793	20022R	PARTICIPANT	\N	PRESENT	0
614128	612793	20128B	PARTICIPANT	\N	PRESENT	0
614129	612793	11072N	PARTICIPANT	\N	PRESENT	0
614130	612793	14053L	PARTICIPANT	\N	PRESENT	0
614131	612793	14111D	PARTICIPANT	\N	PRESENT	0
614132	612793	10015M	PARTICIPANT	\N	PRESENT	0
614133	612793	04085P	PARTICIPANT	\N	PRESENT	0
614134	612793	11056N	PARTICIPANT	\N	PRESENT	0
614135	612793	95063L	PARTICIPANT	\N	PRESENT	0
614136	612793	19629C	PARTICIPANT	\N	PRESENT	0
614137	612793	14069U	PARTICIPANT	\N	PRESENT	0
614138	612793	19749K	PARTICIPANT	\N	PRESENT	0
614139	612793	14021P	PARTICIPANT	\N	PRESENT	0
614140	612793	14089Y	PARTICIPANT	\N	PRESENT	0
614158	613320	19333N	PARTICIPANT	\N	PRESENT	0
614159	613320	19701S	PARTICIPANT	\N	PRESENT	0
614160	613320	19549D	PARTICIPANT	\N	PRESENT	0
614161	613320	19387D	PARTICIPANT	\N	PRESENT	0
614162	613320	19820Y	PARTICIPANT	\N	PRESENT	0
614163	613320	14219Q	PRESIDENT	0	PRESENT	0
614164	613320	19826F	PARTICIPANT	\N	PRESENT	0
614165	613320	20102Q	PARTICIPANT	\N	PRESENT	0
614166	613320	18083K	PARTICIPANT	\N	PRESENT	0
614167	613320	05012A	PARTICIPANT	\N	PRESENT	0
614168	613320	20118Y	PARTICIPANT	\N	PRESENT	0
614169	613320	19503N	PARTICIPANT	\N	PRESENT	0
614170	613320	17367Q	PARTICIPANT	\N	PRESENT	0
614171	613320	20024T	PARTICIPANT	\N	PRESENT	0
614172	613320	11065P	PARTICIPANT	\N	PRESENT	0
614173	613320	19525U	PARTICIPANT	\N	PRESENT	0
614174	613320	20032T	PARTICIPANT	\N	PRESENT	0
614175	613320	14031R	PARTICIPANT	\N	PRESENT	0
614176	613320	20038A	PARTICIPANT	\N	PRESENT	0
614177	613320	20046A	PARTICIPANT	\N	PRESENT	0
614178	613320	14169X	PARTICIPANT	\N	PRESENT	0
614179	613320	17229F	PARTICIPANT	\N	PRESENT	0
614180	613320	20068G	PARTICIPANT	\N	PRESENT	0
614181	613320	11101A	PARTICIPANT	\N	PRESENT	0
614182	613320	19745F	PARTICIPANT	\N	PRESENT	0
614187	613320	20086J	PARTICIPANT	\N	PRESENT	0
614188	613320	14327T	PARTICIPANT	\N	PRESENT	0
614189	613320	01057W	PARTICIPANT	\N	PRESENT	0
614190	613320	19667J	PARTICIPANT	\N	PRESENT	0
614191	613320	14225N	PARTICIPANT	\N	PRESENT	0
614192	613320	19349W	PARTICIPANT	\N	PRESENT	0
614193	613320	08010L	PARTICIPANT	\N	PRESENT	0
614194	613320	20116W	PARTICIPANT	\N	PRESENT	0
614195	613320	20126Y	PARTICIPANT	\N	PRESENT	0
614196	613320	11048N	PARTICIPANT	\N	PRESENT	0
614197	613320	19479G	PARTICIPANT	\N	PRESENT	0
614198	613320	19711U	PARTICIPANT	\N	PRESENT	0
614199	613320	20044X	PARTICIPANT	\N	PRESENT	0
614200	613320	14173T	PARTICIPANT	\N	PRESENT	0
614201	613320	20070A	PARTICIPANT	\N	PRESENT	0
614202	613320	08009T	PARTICIPANT	\N	PRESENT	0
614203	613320	14121F	PARTICIPANT	\N	PRESENT	0
614204	611540	19527W	PARTICIPANT	\N	PRESENT	0
614205	611540	20138D	PARTICIPANT	\N	PRESENT	0
614206	611540	20048C	PARTICIPANT	\N	PRESENT	0
614207	611540	04059M	PARTICIPANT	\N	PRESENT	0
614213	611540	04033B	PARTICIPANT	\N	PRESENT	0
614238	611540	04070G	PARTICIPANT	\N	PRESENT	0
614257	613320	19367Y	PARTICIPANT	\N	PRESENT	0
614258	613320	20090E	PARTICIPANT	\N	PRESENT	0
614259	613320	10006L	PARTICIPANT	\N	PRESENT	0
614260	613320	14217N	PARTICIPANT	\N	PRESENT	0
614261	613320	20040T	PARTICIPANT	\N	PRESENT	0
614262	613320	20172F	PARTICIPANT	\N	PRESENT	0
614263	613320	19691J	PARTICIPANT	\N	PRESENT	0
614264	613320	19723Y	PARTICIPANT	\N	PRESENT	0
614265	613320	19679N	PARTICIPANT	\N	PRESENT	0
614266	613320	19798U	PARTICIPANT	\N	PRESENT	0
614267	613320	11097X	PARTICIPANT	\N	PRESENT	0
614268	613320	19703U	PARTICIPANT	\N	PRESENT	0
614289	611540	14123H	PARTICIPANT	\N	PRESENT	0
614313	611227	18083K	PARTICIPANT	\N	PRESENT	0
614314	611227	20068G	PARTICIPANT	\N	PRESENT	0
614315	611227	19387D	PARTICIPANT	\N	PRESENT	0
614316	611227	20046A	PARTICIPANT	\N	PRESENT	0
614317	611227	20102Q	PARTICIPANT	\N	PRESENT	0
614326	613320	19631V	PARTICIPANT	\N	PRESENT	0
614327	613320	20078J	PARTICIPANT	\N	PRESENT	0
614330	613320	20088L	PARTICIPANT	\N	PRESENT	0
614332	613320	19747H	PARTICIPANT	\N	PRESENT	0
614335	613320	19383Y	PARTICIPANT	\N	PRESENT	0
614337	613320	19782L	PARTICIPANT	\N	PRESENT	0
614339	613320	14207L	PARTICIPANT	\N	PRESENT	0
614342	613320	14038Y	PARTICIPANT	\N	PRESENT	0
614344	613320	08028W	PARTICIPANT	\N	PRESENT	0
614347	613320	19507S	PARTICIPANT	\N	PRESENT	0
614349	611227	20032T	PARTICIPANT	\N	PRESENT	0
614350	611227	20136B	PARTICIPANT	\N	PRESENT	0
614351	611227	14031R	PARTICIPANT	\N	PRESENT	0
614352	611227	20076G	PARTICIPANT	\N	PRESENT	0
614353	611227	19826F	PARTICIPANT	\N	PRESENT	0
614354	611227	17229F	PARTICIPANT	\N	PRESENT	0
614355	611227	14169X	PARTICIPANT	\N	PRESENT	0
614356	611227	05012A	PARTICIPANT	\N	PRESENT	0
614357	611227	14219Q	PRESIDENT	0	PRESENT	0
614358	611227	19739H	PARTICIPANT	\N	PRESENT	0
614359	611227	20038A	PARTICIPANT	\N	PRESENT	0
614360	611227	19251M	PARTICIPANT	\N	PRESENT	0
614361	611227	08060W	PARTICIPANT	\N	PRESENT	0
614362	611540	19573D	PARTICIPANT	\N	PRESENT	0
614375	611227	19333N	PARTICIPANT	\N	PRESENT	0
614376	611227	19551W	PARTICIPANT	\N	PRESENT	0
614377	611227	20100N	PARTICIPANT	\N	PRESENT	0
614378	611227	19503N	PARTICIPANT	\N	PRESENT	0
614379	611227	20020P	PARTICIPANT	\N	PRESENT	0
614380	611227	19745F	PARTICIPANT	\N	PRESENT	0
614392	611227	19820Y	PARTICIPANT	\N	PRESENT	0
614401	611540	20124W	PARTICIPANT	\N	PRESENT	0
614405	611227	11101A	PARTICIPANT	\N	PRESENT	0
614408	613320	14187A	PARTICIPANT	\N	PRESENT	0
614409	613320	20174H	PARTICIPANT	\N	PRESENT	0
614412	611227	19599P	PARTICIPANT	\N	PRESENT	0
614421	614112	20090E	PARTICIPANT	\N	PRESENT	0
614422	614112	11067R	PARTICIPANT	\N	PRESENT	0
614423	614112	19798U	PARTICIPANT	\N	PRESENT	0
614424	614112	11097X	PARTICIPANT	\N	PRESENT	0
614425	614112	20040T	PARTICIPANT	\N	PRESENT	0
614426	614112	19415P	PARTICIPANT	\N	PRESENT	0
614427	614112	19691J	PARTICIPANT	\N	PRESENT	0
614428	614112	19715Y	PARTICIPANT	\N	PRESENT	0
614429	614112	20148F	PARTICIPANT	\N	PRESENT	0
614430	614112	20172F	PARTICIPANT	\N	PRESENT	0
614431	614112	17779H	PARTICIPANT	\N	PRESENT	0
614432	614112	19703U	PARTICIPANT	\N	PRESENT	0
600068	600065	19507S	PARTICIPANT	\N	PRESENT	0
600069	600065	01025N	PARTICIPANT	\N	PRESENT	0
600070	600065	19413M	PARTICIPANT	\N	PRESENT	0
600071	600065	19762G	PARTICIPANT	\N	PRESENT	0
600072	600065	20144B	PARTICIPANT	\N	PRESENT	0
600075	600074	01025N	PARTICIPANT	\N	PRESENT	0
602923	600700	20084G	PARTICIPANT	\N	PRESENT	0
600077	600074	19507S	PARTICIPANT	\N	PRESENT	0
602922	600700	19399H	PARTICIPANT	\N	PRESENT	0
602924	600700	20142Y	PARTICIPANT	\N	PRESENT	0
602927	602925	19399H	PARTICIPANT	\N	PRESENT	0
602952	600209	20094J	PARTICIPANT	\N	PRESENT	0
602953	600209	04035D	PARTICIPANT	\N	PRESENT	0
602954	600209	19725B	PARTICIPANT	\N	PRESENT	0
602956	600209	12041X	PARTICIPANT	\N	PRESENT	0
602957	600209	11026G	PARTICIPANT	\N	PRESENT	0
602959	600209	08034U	PARTICIPANT	\N	PRESENT	0
602960	600209	04070G	PARTICIPANT	\N	PRESENT	0
602961	600209	14331P	PRESIDENT	0	PRESENT	0
602962	600209	14251Q	PARTICIPANT	\N	PRESENT	0
602966	600209	14189C	PARTICIPANT	\N	EXCUSE	0
602967	600209	14357A	PARTICIPANT	\N	EXCUSE	0
602968	600209	20104S	PARTICIPANT	\N	EXCUSE	0
603328	603327	04035D	PARTICIPANT	\N	PRESENT	0
603329	603327	14151M	PARTICIPANT	\N	PRESENT	0
603330	603327	14259Y	PARTICIPANT	\N	PRESENT	0
603331	603327	20032T	PARTICIPANT	\N	PRESENT	0
603332	603327	19709B	PARTICIPANT	\N	PRESENT	0
603333	603327	14026U	PARTICIPANT	\N	PRESENT	0
603334	603327	14215L	PARTICIPANT	\N	PRESENT	0
603335	603327	20120S	PARTICIPANT	\N	PRESENT	0
603336	603327	19741B	PARTICIPANT	\N	PRESENT	0
603337	603327	19673G	PARTICIPANT	\N	PRESENT	0
603338	603327	14071N	PARTICIPANT	\N	PRESENT	0
603340	603339	04070G	PARTICIPANT	\N	PRESENT	0
603343	603342	08010L	PARTICIPANT	\N	PRESENT	0
603344	603342	11026G	PARTICIPANT	\N	PRESENT	0
603346	603342	19467C	PARTICIPANT	\N	PRESENT	0
603347	603342	20248J	PARTICIPANT	\N	PRESENT	0
603348	603342	20054A	PARTICIPANT	\N	PRESENT	0
603349	603342	19573D	PARTICIPANT	\N	PRESENT	0
603367	603201	20130U	PARTICIPANT	\N	PRESENT	0
603368	603201	19679N	PARTICIPANT	\N	PRESENT	0
603371	603365	20130U	PARTICIPANT	\N	PRESENT	0
603372	603365	19679N	PARTICIPANT	\N	PRESENT	0
607521	607520	04033B	PARTICIPANT	\N	PRESENT	0
607522	607520	08011M	PARTICIPANT	\N	PRESENT	0
607523	607520	14179A	PARTICIPANT	\N	PRESENT	0
607525	607524	11043H	PARTICIPANT	\N	PRESENT	0
607526	607524	08012N	PARTICIPANT	\N	PRESENT	0
607527	607524	14073Q	PARTICIPANT	\N	PRESENT	0
607529	607528	08012N	PARTICIPANT	\N	PRESENT	0
607530	607528	11043H	PARTICIPANT	\N	PRESENT	0
607575	606855	19705W	PARTICIPANT	\N	EXCUSE	0
607576	606855	19711U	PARTICIPANT	\N	PRESENT	0
607601	606428	17589D	PARTICIPANT	\N	EXCUSE	0
607686	606402	11064N	PARTICIPANT	\N	PRESENT	0
609862	608516	14021P	PARTICIPANT	\N	PRESENT	0
609863	608516	18193Q	PARTICIPANT	\N	PRESENT	0
609864	608516	08012N	PARTICIPANT	\N	PRESENT	0
609865	608516	20074E	PARTICIPANT	\N	PRESENT	0
609866	608516	20028X	PARTICIPANT	\N	PRESENT	0
609867	608516	14257W	PARTICIPANT	\N	PRESENT	0
609868	608516	14229S	PARTICIPANT	\N	PRESENT	0
609869	608516	19581D	PARTICIPANT	\N	PRESENT	0
609870	608516	20084G	PARTICIPANT	\N	PRESENT	0
609871	608516	14055N	PARTICIPANT	\N	PRESENT	0
609872	608516	20094J	PARTICIPANT	\N	PRESENT	0
609873	608516	14001X	PARTICIPANT	\N	PRESENT	0
609874	608516	04008A	PARTICIPANT	\N	PRESENT	0
609940	608650	20042V	PARTICIPANT	\N	PRESENT	0
609877	608516	19745F	PARTICIPANT	\N	PRESENT	0
609899	608516	20120S	PARTICIPANT	\N	PRESENT	0
609941	608650	14105F	PARTICIPANT	\N	PRESENT	0
609942	608650	04042C	PARTICIPANT	\N	EXCUSE	0
609943	608650	12028B	PARTICIPANT	\N	PRESENT	0
609944	608650	19721W	PARTICIPANT	\N	PRESENT	0
609945	608650	14267Y	PRESIDENT	0	PRESENT	0
609946	608650	07033P	PARTICIPANT	\N	PRESENT	0
609947	608650	14249W	PARTICIPANT	\N	EXCUSE	0
609948	608650	17023S	PARTICIPANT	\N	PRESENT	0
609949	608650	04035D	PARTICIPANT	\N	EXCUSE	0
609950	608650	11083R	PARTICIPANT	\N	PRESENT	0
609951	608650	19347U	PARTICIPANT	\N	PRESENT	0
609952	608650	08056B	PARTICIPANT	\N	PRESENT	0
609953	608650	19565D	PARTICIPANT	\N	PRESENT	0
609954	608650	11064N	PARTICIPANT	\N	PRESENT	0
609955	608650	08069G	PARTICIPANT	\N	PRESENT	0
609956	608650	14097Y	PARTICIPANT	\N	PRESENT	0
609957	608650	12041X	PARTICIPANT	\N	PRESENT	0
609958	608650	19709B	PARTICIPANT	\N	PRESENT	0
609959	608650	16685X	PARTICIPANT	\N	PRESENT	0
609960	608650	14059S	PARTICIPANT	\N	PRESENT	0
609962	608650	08061X	PARTICIPANT	\N	PRESENT	0
609963	608650	08047A	PARTICIPANT	\N	PRESENT	0
610808	610806	11012A	PARTICIPANT	\N	PRESENT	0
609965	608650	11054L	PARTICIPANT	\N	EXCUSE	0
609966	608650	19421M	PARTICIPANT	\N	PRESENT	0
609967	608650	01058X	PARTICIPANT	\N	PRESENT	0
609968	608650	01062T	PARTICIPANT	\N	PRESENT	0
609969	608650	11066Q	PARTICIPANT	\N	PRESENT	0
609971	608650	97011G	PARTICIPANT	\N	PRESENT	0
609972	608650	14193X	PARTICIPANT	\N	EXCUSE	0
610807	610806	19415P	PARTICIPANT	\N	PRESENT	0
610809	610806	04045F	PARTICIPANT	\N	PRESENT	0
610810	610806	14193X	PARTICIPANT	\N	PRESENT	0
610824	610822	14257W	PARTICIPANT	\N	PRESENT	0
610826	610825	14257W	PARTICIPANT	\N	PRESENT	0
610828	610827	14257W	PARTICIPANT	\N	PRESENT	0
610833	610615	11083R	PARTICIPANT	\N	PRESENT	0
611293	611292	11090Q	PARTICIPANT	\N	PRESENT	0
611294	611292	19575F	PARTICIPANT	\N	PRESENT	0
611295	611292	19782L	PARTICIPANT	\N	PRESENT	0
611296	611292	14038Y	PARTICIPANT	\N	PRESENT	0
611297	611292	14187A	PARTICIPANT	\N	PRESENT	0
611298	611292	14205J	PARTICIPANT	\N	PRESENT	0
611299	611292	19441R	PARTICIPANT	\N	PRESENT	0
611300	611292	19563B	PARTICIPANT	\N	PRESENT	0
611301	611292	20028X	PARTICIPANT	\N	PRESENT	0
611302	611292	20030R	PARTICIPANT	\N	PRESENT	0
611303	611292	20092G	PARTICIPANT	\N	PRESENT	0
611304	611292	19629C	PARTICIPANT	\N	PRESENT	0
611305	611292	19725B	PARTICIPANT	\N	PRESENT	0
611306	611292	14147R	PARTICIPANT	\N	PRESENT	0
611456	610675	19443T	PARTICIPANT	\N	PRESENT	0
611457	610675	95041E	PARTICIPANT	\N	PRESENT	0
611458	610675	12041X	PARTICIPANT	\N	PRESENT	0
611459	610675	20072C	PARTICIPANT	\N	PRESENT	0
611460	610675	19565D	PARTICIPANT	\N	PRESENT	0
611461	610675	19329S	PARTICIPANT	\N	PRESENT	0
611462	610675	01058X	PARTICIPANT	\N	PRESENT	0
611463	610675	16685X	PARTICIPANT	\N	PRESENT	0
611464	610675	11027H	PARTICIPANT	\N	PRESENT	0
611465	610675	04042C	PRESIDENT	1	PRESENT	0
611466	610675	11054L	PARTICIPANT	\N	PRESENT	0
611467	610675	11066Q	PARTICIPANT	\N	PRESENT	0
611468	610675	12028B	PARTICIPANT	\N	PRESENT	0
611469	610675	11115U	PARTICIPANT	\N	PRESENT	0
611470	610675	14055N	PARTICIPANT	\N	PRESENT	0
611471	610675	19421M	PARTICIPANT	\N	PRESENT	0
611472	610675	19347U	PARTICIPANT	\N	PRESENT	0
611473	610675	14193X	PARTICIPANT	\N	PRESENT	0
611474	610675	07033P	PARTICIPANT	\N	PRESENT	0
611475	610675	08061X	PARTICIPANT	\N	PRESENT	0
611476	610675	97011G	PARTICIPANT	\N	PRESENT	0
611477	610675	14249W	PARTICIPANT	\N	PRESENT	0
611478	610675	08047A	PRESIDENT	0	PRESENT	0
611479	610675	14059S	PARTICIPANT	\N	PRESENT	0
611480	610675	04035D	PARTICIPANT	\N	PRESENT	0
611481	610675	01062T	PARTICIPANT	\N	PRESENT	0
611482	610675	11041F	PARTICIPANT	\N	PRESENT	0
611483	610675	08069G	PARTICIPANT	\N	PRESENT	0
611484	610675	20042V	PARTICIPANT	\N	PRESENT	0
611485	610675	14105F	PARTICIPANT	\N	PRESENT	0
611486	610675	20064C	PARTICIPANT	\N	PRESENT	0
611487	610675	14267Y	PARTICIPANT	\N	PRESENT	0
611488	610675	11064N	PARTICIPANT	\N	PRESENT	0
611489	610675	11083R	PARTICIPANT	\N	PRESENT	0
611490	610675	14211G	PARTICIPANT	\N	PRESENT	0
611492	610670	20128B	PARTICIPANT	\N	PRESENT	0
609273	609264	08034U	PARTICIPANT	\N	PRESENT	0
609274	609264	14147R	PARTICIPANT	\N	PRESENT	0
609279	609264	97011G	PARTICIPANT	\N	PRESENT	0
609276	609264	19711U	PARTICIPANT	\N	PRESENT	0
609277	609264	14030Q	PARTICIPANT	\N	PRESENT	0
609278	609264	19713W	PARTICIPANT	\N	PRESENT	0
609280	609264	17367Q	PARTICIPANT	\N	PRESENT	0
609282	609281	04043D	PARTICIPANT	\N	PRESENT	0
609283	609281	08010L	PARTICIPANT	\N	PRESENT	0
609284	609281	20120S	PARTICIPANT	\N	PRESENT	0
610730	610729	04059M	PARTICIPANT	\N	PRESENT	0
610731	610729	20152B	PARTICIPANT	\N	PRESENT	0
610732	610729	11053K	PARTICIPANT	\N	PRESENT	0
610733	610729	20132W	PARTICIPANT	\N	PRESENT	0
610734	610729	19399H	PARTICIPANT	\N	PRESENT	0
610735	610729	20056C	PARTICIPANT	\N	PRESENT	0
610736	610729	19611R	PRESIDENT	0	PRESENT	0
610737	610729	19699S	PARTICIPANT	\N	PRESENT	0
610738	610729	19705W	PARTICIPANT	\N	PRESENT	0
610739	610729	14229S	PARTICIPANT	\N	PRESENT	0
610794	603089	95063L	PARTICIPANT	\N	PRESENT	0
611331	610670	14111D	PARTICIPANT	\N	PRESENT	0
611332	608705	20032T	PARTICIPANT	\N	PRESENT	0
611333	608705	20068G	PARTICIPANT	\N	PRESENT	0
611334	608705	20076G	PARTICIPANT	\N	PRESENT	0
611335	610670	07004J	PARTICIPANT	\N	PRESENT	0
611336	610670	11033F	PARTICIPANT	\N	PRESENT	0
611337	608705	14219Q	PRESIDENT	0	PRESENT	0
611338	608705	14221J	PARTICIPANT	\N	PRESENT	0
611339	610670	14215L	PARTICIPANT	\N	PRESENT	0
611340	610670	19447X	PARTICIPANT	\N	PRESENT	0
611341	610670	19675J	PARTICIPANT	\N	PRESENT	0
611342	610670	14053L	PARTICIPANT	\N	PRESENT	0
611343	610670	19749K	PARTICIPANT	\N	PRESENT	0
611344	610670	14231L	PARTICIPANT	\N	PRESENT	0
611345	610670	19725B	PARTICIPANT	\N	PRESENT	0
611346	610670	20022R	PARTICIPANT	\N	PRESENT	0
611347	610670	04047H	PRESIDENT	0	PRESENT	0
611348	610670	19649G	PARTICIPANT	\N	PRESENT	0
611349	610670	14151M	PARTICIPANT	\N	PRESENT	0
611350	608705	19549D	PARTICIPANT	\N	PRESENT	0
611351	608705	19387D	PARTICIPANT	\N	PRESENT	0
611352	608705	19599P	PARTICIPANT	\N	PRESENT	0
611353	608705	20102Q	PARTICIPANT	\N	PRESENT	0
611354	608705	19637C	PARTICIPANT	\N	PRESENT	0
611355	608705	20100N	PARTICIPANT	\N	PRESENT	0
611356	608705	18083K	PARTICIPANT	\N	PRESENT	0
611357	608705	08060W	PARTICIPANT	\N	PRESENT	0
611358	608705	20118Y	PARTICIPANT	\N	PRESENT	0
611359	608705	19503N	PARTICIPANT	\N	PRESENT	0
611360	608705	17367Q	PARTICIPANT	\N	PRESENT	0
611361	608705	20024T	PARTICIPANT	\N	PRESENT	0
611362	608705	19525U	PARTICIPANT	\N	PRESENT	0
611363	608705	14031R	PARTICIPANT	\N	PRESENT	0
611364	608705	19251M	PARTICIPANT	\N	PRESENT	0
611365	608705	17229F	PARTICIPANT	\N	PRESENT	0
611366	608705	14169X	PARTICIPANT	\N	PRESENT	0
611367	608705	19739H	PARTICIPANT	\N	PRESENT	0
611368	608705	19745F	PARTICIPANT	\N	PRESENT	0
611369	608705	19619A	PARTICIPANT	\N	PRESENT	0
611370	608705	11065P	PARTICIPANT	\N	PRESENT	0
611371	610670	11026G	PARTICIPANT	\N	PRESENT	0
611372	610670	19581D	PARTICIPANT	\N	PRESENT	0
611373	610670	19673G	PARTICIPANT	\N	PRESENT	0
611374	610670	14107H	PARTICIPANT	\N	PRESENT	0
611375	610670	14147R	PARTICIPANT	\N	PRESENT	0
611376	610670	14069U	PARTICIPANT	\N	PRESENT	0
611377	610670	14021P	PARTICIPANT	\N	PRESENT	0
611378	610670	11072N	PARTICIPANT	\N	PRESENT	0
611379	610670	10015M	PARTICIPANT	\N	PRESENT	0
611380	610670	14089Y	PARTICIPANT	\N	PRESENT	0
611381	610670	20074E	PARTICIPANT	\N	PRESENT	0
611382	610282	20130U	PARTICIPANT	\N	PRESENT	0
611383	610282	11067R	PARTICIPANT	\N	PRESENT	0
611384	610282	20090E	PARTICIPANT	\N	PRESENT	0
611385	610282	04092N	PARTICIPANT	\N	PRESENT	0
611386	610282	19798U	PARTICIPANT	\N	PRESENT	0
611387	610282	08045X	PARTICIPANT	\N	PRESENT	0
611388	610282	17965H	PARTICIPANT	\N	PRESENT	0
611389	610282	19301E	PARTICIPANT	\N	PRESENT	0
611390	610282	19691J	PARTICIPANT	\N	PRESENT	0
611391	610282	19717B	PARTICIPANT	\N	PRESENT	0
611392	610282	18193Q	PARTICIPANT	\N	PRESENT	0
611393	610282	20148F	PARTICIPANT	\N	PRESENT	0
611394	610282	19723Y	PARTICIPANT	\N	PRESENT	0
611395	610282	19553Y	PARTICIPANT	\N	PRESENT	0
611396	610282	19679N	PARTICIPANT	\N	PRESENT	0
611397	610282	11103C	PARTICIPANT	\N	PRESENT	0
611398	610282	14195A	PARTICIPANT	\N	PRESENT	0
611399	610282	14213J	PARTICIPANT	\N	PRESENT	0
611400	610282	19367Y	PARTICIPANT	\N	PRESENT	0
611401	610282	14071N	PARTICIPANT	\N	PRESENT	0
611402	610282	14217N	PARTICIPANT	\N	PRESENT	0
611403	610282	10006L	PRESIDENT	0	PRESENT	0
611404	610282	19760E	PARTICIPANT	\N	PRESENT	0
611405	610670	95063L	PARTICIPANT	\N	PRESENT	0
611406	610670	20110Q	PARTICIPANT	\N	PRESENT	0
611407	610670	19954N	PARTICIPANT	\N	PRESENT	0
611408	608705	20096L	PARTICIPANT	\N	PRESENT	0
611409	608705	05012A	PARTICIPANT	\N	PRESENT	0
611410	608705	20122U	PARTICIPANT	\N	PRESENT	0
611411	608705	20140W	PARTICIPANT	\N	PRESENT	0
611412	610670	14259Y	PARTICIPANT	\N	PRESENT	0
611413	610670	08018U	PARTICIPANT	\N	PRESENT	0
611414	610670	19629C	PARTICIPANT	\N	PRESENT	0
611415	610670	05008E	PARTICIPANT	\N	PRESENT	0
611416	610670	19729F	PARTICIPANT	\N	EXCUSE	0
611417	610670	19489J	PARTICIPANT	\N	PRESENT	0
611418	610674	19443T	PARTICIPANT	\N	PRESENT	0
611419	610674	95041E	PARTICIPANT	\N	PRESENT	0
611420	610674	12041X	PARTICIPANT	\N	PRESENT	0
611421	610674	20072C	PARTICIPANT	\N	PRESENT	0
611422	610674	19565D	PARTICIPANT	\N	PRESENT	0
611423	610674	19329S	PARTICIPANT	\N	PRESENT	0
611424	610674	01058X	PARTICIPANT	\N	PRESENT	0
611425	610674	16685X	PARTICIPANT	\N	PRESENT	0
611426	610674	11027H	PARTICIPANT	\N	PRESENT	0
611427	610674	04042C	PRESIDENT	1	PRESENT	0
611428	610674	11054L	PARTICIPANT	\N	PRESENT	0
611429	610674	11066Q	PARTICIPANT	\N	PRESENT	0
611430	610674	12028B	PARTICIPANT	\N	PRESENT	0
611431	610674	11115U	PARTICIPANT	\N	PRESENT	0
611432	610674	14055N	PARTICIPANT	\N	PRESENT	0
611433	610674	19421M	PARTICIPANT	\N	PRESENT	0
611434	610674	19347U	PARTICIPANT	\N	PRESENT	0
611435	610674	14193X	PARTICIPANT	\N	PRESENT	0
611436	610674	07033P	PARTICIPANT	\N	PRESENT	0
611437	610674	08061X	PARTICIPANT	\N	PRESENT	0
611438	610674	97011G	PARTICIPANT	\N	PRESENT	0
611439	610674	14249W	PARTICIPANT	\N	PRESENT	0
611440	610674	08047A	PRESIDENT	0	PRESENT	0
611441	610674	14059S	PARTICIPANT	\N	PRESENT	0
611442	610674	04035D	PARTICIPANT	\N	PRESENT	0
611443	610674	01062T	PARTICIPANT	\N	PRESENT	0
611444	610674	11041F	PARTICIPANT	\N	PRESENT	0
611445	610674	20042V	PARTICIPANT	\N	PRESENT	0
611446	610674	14105F	PARTICIPANT	\N	PRESENT	0
611447	610674	20064C	PARTICIPANT	\N	PRESENT	0
611448	610674	14267Y	PARTICIPANT	\N	PRESENT	0
611449	610674	11064N	PARTICIPANT	\N	PRESENT	0
611450	610674	11083R	PARTICIPANT	\N	PRESENT	0
611451	610674	14211G	PARTICIPANT	\N	PRESENT	0
611454	610674	08069G	PARTICIPANT	\N	PRESENT	0
611541	610671	20074E	PARTICIPANT	\N	PRESENT	0
611542	610671	19581D	PARTICIPANT	\N	PRESENT	0
611543	610671	04047H	PRESIDENT	0	PRESENT	0
611544	610671	19675J	PARTICIPANT	\N	PRESENT	0
611545	610671	01028R	PARTICIPANT	\N	PRESENT	0
611546	610671	19447X	PARTICIPANT	\N	PRESENT	0
611547	610671	05008E	PARTICIPANT	\N	PRESENT	0
611548	610671	19954N	PARTICIPANT	\N	PRESENT	0
611549	610671	19489J	PARTICIPANT	\N	PRESENT	0
611550	610671	07004J	PARTICIPANT	\N	PRESENT	0
611551	610671	14107H	PARTICIPANT	\N	PRESENT	0
611552	610671	20110Q	PARTICIPANT	\N	PRESENT	0
611553	610671	14147R	PARTICIPANT	\N	PRESENT	0
611554	610671	20114U	PARTICIPANT	\N	PRESENT	0
611555	610671	14151M	PARTICIPANT	\N	PRESENT	0
611556	610671	14215L	PARTICIPANT	\N	PRESENT	0
611557	610671	08018U	PARTICIPANT	\N	PRESENT	0
599744	599742	20040T	PARTICIPANT	\N	PRESENT	0
599748	599747	20040T	PARTICIPANT	\N	PRESENT	0
601225	601223	18083K	PARTICIPANT	\N	PRESENT	0
601268	601265	18083K	PARTICIPANT	\N	PRESENT	0
601270	601269	18083K	PARTICIPANT	\N	PRESENT	0
601277	601276	18083K	PARTICIPANT	\N	PRESENT	0
601274	601272	19467C	PARTICIPANT	\N	PRESENT	0
601275	601272	18083K	PARTICIPANT	\N	PRESENT	0
601279	601278	18083K	PARTICIPANT	\N	PRESENT	0
601280	601278	14169X	PARTICIPANT	\N	PRESENT	0
601338	601335	19679N	PARTICIPANT	\N	PRESENT	0
601339	601337	19679N	PARTICIPANT	\N	PRESENT	0
604510	602256	04071H	PARTICIPANT	\N	PRESENT	0
604511	602256	20074E	PARTICIPANT	\N	PRESENT	0
604508	604401	11077T	PARTICIPANT	\N	PRESENT	0
604509	604401	20046A	PARTICIPANT	\N	PRESENT	0
604512	602256	19543W	PARTICIPANT	\N	PRESENT	0
604513	602256	19581D	PARTICIPANT	\N	PRESENT	0
604514	602256	04047H	PRESIDENT	0	PRESENT	0
604515	602256	19447X	PARTICIPANT	\N	PRESENT	0
604516	602256	04085P	PARTICIPANT	\N	PRESENT	0
604517	602256	14089Y	PARTICIPANT	\N	PRESENT	0
604518	602256	11056N	PARTICIPANT	\N	PRESENT	0
604519	602256	95063L	PARTICIPANT	\N	PRESENT	0
604520	602256	14147R	PARTICIPANT	\N	PRESENT	0
604521	602256	14151M	PARTICIPANT	\N	PRESENT	0
604522	602256	14069U	PARTICIPANT	\N	PRESENT	0
604523	602256	14215L	PARTICIPANT	\N	PRESENT	0
604524	602256	20022R	PARTICIPANT	\N	PRESENT	0
604525	602256	11072N	PARTICIPANT	\N	PRESENT	0
604526	602256	19729F	PARTICIPANT	\N	EXCUSE	0
604527	604401	01062T	PARTICIPANT	\N	PRESENT	0
604528	602256	05008E	PARTICIPANT	\N	PRESENT	0
604556	604401	19479G	PARTICIPANT	\N	PRESENT	0
604530	602256	14053L	PARTICIPANT	\N	PRESENT	0
604531	604401	19685L	PARTICIPANT	\N	PRESENT	0
604532	604401	18083K	PARTICIPANT	\N	PRESENT	0
604533	602256	14179A	PARTICIPANT	\N	PRESENT	0
604534	604401	20136B	PARTICIPANT	\N	PRESENT	0
604535	604401	20032T	PARTICIPANT	\N	PRESENT	0
604536	604401	14083S	PARTICIPANT	\N	PRESENT	0
604537	604401	19399H	PARTICIPANT	\N	PRESENT	0
604538	604401	20102Q	PARTICIPANT	\N	PRESENT	0
604539	603124	20050V	PARTICIPANT	\N	PRESENT	0
604540	604401	19333N	PARTICIPANT	\N	PRESENT	0
604541	604401	14219Q	PARTICIPANT	\N	PRESENT	0
604542	604401	04042C	PARTICIPANT	\N	PRESENT	0
604543	604401	14059S	PARTICIPANT	\N	PRESENT	0
604544	604401	14031R	PARTICIPANT	\N	PRESENT	0
604545	604401	19565D	PARTICIPANT	\N	PRESENT	0
604546	604401	14169X	PARTICIPANT	\N	PRESENT	0
604547	604401	14073Q	PARTICIPANT	\N	PRESENT	0
604548	604401	20120S	PARTICIPANT	\N	PRESENT	0
604549	604401	14237S	PARTICIPANT	\N	PRESENT	0
604550	604401	19747H	PARTICIPANT	\N	PRESENT	0
604551	604401	14038Y	PARTICIPANT	\N	PRESENT	0
604552	604401	08028W	PARTICIPANT	\N	PRESENT	0
604553	602256	19671E	PARTICIPANT	\N	PRESENT	0
604554	604401	14221J	PARTICIPANT	\N	PRESENT	0
604555	604401	14189C	PARTICIPANT	\N	PRESENT	0
604557	604401	01025N	PARTICIPANT	\N	PRESENT	0
604558	604401	19443T	PARTICIPANT	\N	PRESENT	0
604559	604401	19515S	PARTICIPANT	\N	PRESENT	0
604560	604401	20128B	PARTICIPANT	\N	PRESENT	0
604561	604401	11101A	PARTICIPANT	\N	PRESENT	0
604562	604405	20088L	PARTICIPANT	\N	PRESENT	0
604563	604405	19768N	PARTICIPANT	\N	PRESENT	0
604564	604405	19515S	PARTICIPANT	\N	PRESENT	0
604565	604405	20092G	PARTICIPANT	\N	PRESENT	0
604566	604405	19782L	PARTICIPANT	\N	PRESENT	0
604567	604405	19413M	PARTICIPANT	\N	PRESENT	0
604568	604405	20094J	PARTICIPANT	\N	PRESENT	0
604569	604405	19631V	PARTICIPANT	\N	PRESENT	0
604570	604405	11099A	PARTICIPANT	\N	PRESENT	0
604571	604405	20018V	PARTICIPANT	\N	PRESENT	0
604572	604405	19511N	PARTICIPANT	\N	PRESENT	0
604573	604405	08028W	PARTICIPANT	\N	PRESENT	0
604574	604405	14038Y	PARTICIPANT	\N	PRESENT	0
604575	604405	19467C	PARTICIPANT	\N	PRESENT	0
604576	604405	20034V	PARTICIPANT	\N	PRESENT	0
604577	604405	14187A	PARTICIPANT	\N	PRESENT	0
604578	604405	20144B	PARTICIPANT	\N	PRESENT	0
604579	604405	11090Q	PRESIDENT	0	PRESENT	0
604580	604405	14033T	PARTICIPANT	\N	PRESENT	0
604581	604405	01025N	PARTICIPANT	\N	PRESENT	0
604582	604405	20054A	PARTICIPANT	\N	PRESENT	0
604583	604405	20174H	PARTICIPANT	\N	PRESENT	0
604584	604405	20062A	PARTICIPANT	\N	PRESENT	0
604585	604405	19507S	PARTICIPANT	\N	PRESENT	0
604586	604405	19747H	PARTICIPANT	\N	PRESENT	0
604587	604405	14257W	PARTICIPANT	\N	PRESENT	0
604589	604401	14042U	PARTICIPANT	\N	PRESENT	0
604590	604401	20126Y	PARTICIPANT	\N	PRESENT	0
604591	604401	14147R	PARTICIPANT	\N	PRESENT	0
604592	604401	11097X	PARTICIPANT	\N	PRESENT	0
604644	603145	20108W	PARTICIPANT	\N	PRESENT	0
604645	603145	14097Y	PARTICIPANT	\N	PRESENT	0
604646	603145	19599P	PARTICIPANT	\N	PRESENT	0
604647	603145	01062T	PARTICIPANT	\N	PRESENT	0
604648	603145	20128B	PARTICIPANT	\N	PRESENT	0
604649	603145	04045F	PARTICIPANT	\N	PRESENT	0
604650	603145	14221J	PARTICIPANT	\N	PRESENT	0
604651	603145	20100N	PARTICIPANT	\N	PRESENT	0
604652	603145	20102Q	PARTICIPANT	\N	PRESENT	0
604653	603145	19565D	PARTICIPANT	\N	PRESENT	0
604654	603145	14219Q	PARTICIPANT	\N	PRESENT	0
604655	603145	14042U	PARTICIPANT	\N	PRESENT	0
604656	603145	14073Q	PARTICIPANT	\N	PRESENT	0
604657	603145	01025N	PARTICIPANT	\N	PRESENT	0
604658	603145	19479G	PARTICIPANT	\N	PRESENT	0
604659	603145	19441R	PARTICIPANT	\N	PRESENT	0
604660	603145	19685L	PARTICIPANT	\N	PRESENT	0
604661	603145	19747H	PARTICIPANT	\N	PRESENT	0
604662	603145	20126Y	PARTICIPANT	\N	PRESENT	0
604663	603145	20124W	PARTICIPANT	\N	PRESENT	0
604664	603145	14059S	PARTICIPANT	\N	PRESENT	0
604665	603145	20090E	PARTICIPANT	\N	PRESENT	0
604666	603145	20062A	PARTICIPANT	\N	PRESENT	0
604667	603145	20024T	PARTICIPANT	\N	PRESENT	0
604668	603145	10015M	PARTICIPANT	\N	PRESENT	0
604669	603145	11097X	PARTICIPANT	\N	PRESENT	0
604670	603145	20068G	PARTICIPANT	\N	PRESENT	0
604671	603145	14147R	PARTICIPANT	\N	PRESENT	0
604672	603145	19443T	PARTICIPANT	\N	PRESENT	0
604673	603145	20136B	PARTICIPANT	\N	PRESENT	0
604674	603145	20026V	PARTICIPANT	\N	PRESENT	0
604675	603145	20096L	PARTICIPANT	\N	PRESENT	0
604676	603145	08034U	PARTICIPANT	\N	PRESENT	0
604677	603145	20104S	PARTICIPANT	\N	PRESENT	0
604678	603145	19673G	PARTICIPANT	\N	PRESENT	0
604679	603145	14215L	PARTICIPANT	\N	PRESENT	0
604680	603145	08028W	PARTICIPANT	\N	PRESENT	0
604681	603145	19515S	PARTICIPANT	\N	PRESENT	0
604682	603145	19820Y	PARTICIPANT	\N	PRESENT	0
604683	603145	20138D	PARTICIPANT	\N	PRESENT	0
604684	603145	14217N	PARTICIPANT	\N	PRESENT	0
604685	603145	20098N	PARTICIPANT	\N	PRESENT	0
604686	603145	19549D	PARTICIPANT	\N	PRESENT	0
604687	603145	01060R	PARTICIPANT	\N	PRESENT	0
604688	603145	19467C	PARTICIPANT	\N	PRESENT	0
604689	603145	20054A	PARTICIPANT	\N	PRESENT	0
604690	603145	19551W	PARTICIPANT	\N	PRESENT	0
604691	603145	14179A	PARTICIPANT	\N	PRESENT	0
604692	603145	14033T	PARTICIPANT	\N	PRESENT	0
604642	603145	11070L	PARTICIPANT	\N	PRESENT	0
604643	603145	20032T	PARTICIPANT	\N	PRESENT	0
604693	603145	20022R	PARTICIPANT	\N	PRESENT	0
604694	603145	17367Q	PARTICIPANT	\N	PRESENT	0
604695	603145	19335Q	PARTICIPANT	\N	PRESENT	0
604696	603145	12041X	PARTICIPANT	\N	PRESENT	0
604697	603145	20056C	PARTICIPANT	\N	PRESENT	0
604698	603145	14357A	PARTICIPANT	\N	PRESENT	0
614433	614112	19553Y	PARTICIPANT	\N	PRESENT	0
614434	614112	11031D	PARTICIPANT	\N	PRESENT	0
614435	614112	20248J	PARTICIPANT	\N	PRESENT	0
614436	614112	19679N	PARTICIPANT	\N	PRESENT	0
614437	614112	14042U	PARTICIPANT	\N	PRESENT	0
614438	614112	14195A	PARTICIPANT	\N	PRESENT	0
614439	614112	14213J	PARTICIPANT	\N	PRESENT	0
614440	614112	19367Y	PARTICIPANT	\N	PRESENT	0
614441	614112	14217N	PARTICIPANT	\N	PRESENT	0
614442	614112	10006L	PRESIDENT	0	PRESENT	0
614443	614112	19683J	PARTICIPANT	\N	PRESENT	0
614444	614112	19760E	PARTICIPANT	\N	PRESENT	0
614445	613320	20034V	PARTICIPANT	\N	PRESENT	0
614446	613320	14205J	PARTICIPANT	\N	PRESENT	0
614447	613320	19441R	PARTICIPANT	\N	PRESENT	0
614448	613320	20028X	PARTICIPANT	\N	PRESENT	0
614449	613320	19369B	PARTICIPANT	\N	PRESENT	0
614450	613320	14257W	PARTICIPANT	\N	PRESENT	0
614451	613320	19768N	PARTICIPANT	\N	PRESENT	0
614454	613320	20030R	PARTICIPANT	\N	PRESENT	0
614456	613320	11090Q	PARTICIPANT	\N	PRESENT	0
614460	613320	20082E	PARTICIPANT	\N	PRESENT	0
614461	613320	20054A	PARTICIPANT	\N	PRESENT	0
614462	613320	04045F	PARTICIPANT	\N	PRESENT	0
614464	613320	20062A	PARTICIPANT	\N	PRESENT	0
614468	613320	19543W	PARTICIPANT	\N	PRESENT	0
614470	613320	20022R	PARTICIPANT	\N	PRESENT	0
614472	613320	19954N	PARTICIPANT	\N	PRESENT	0
614475	613320	20110Q	PARTICIPANT	\N	PRESENT	0
614477	613320	14089Y	PARTICIPANT	\N	PRESENT	0
614479	613320	04047H	PARTICIPANT	\N	PRESENT	0
614482	613320	14053L	PARTICIPANT	\N	PRESENT	0
614484	613320	19629C	PARTICIPANT	\N	PRESENT	0
614487	611227	19549D	PARTICIPANT	\N	PRESENT	0
614488	611227	20024T	PARTICIPANT	\N	PRESENT	0
614489	611227	11065P	PARTICIPANT	\N	PRESENT	0
614496	613320	14215L	PARTICIPANT	\N	PRESENT	0
614499	613320	14151M	PARTICIPANT	\N	PRESENT	0
614501	613320	07004J	PARTICIPANT	\N	PRESENT	0
614503	613320	20128B	PARTICIPANT	\N	PRESENT	0
614504	613320	19447X	PARTICIPANT	\N	PRESENT	0
614505	613320	14021P	PARTICIPANT	\N	PRESENT	0
614506	613320	19489J	PARTICIPANT	\N	PRESENT	0
614507	613320	14111D	PARTICIPANT	\N	PRESENT	0
614508	613320	14001X	PARTICIPANT	\N	PRESENT	0
614509	613320	10015M	PARTICIPANT	\N	PRESENT	0
614510	613320	95063L	PARTICIPANT	\N	PRESENT	0
614511	613320	19585H	PARTICIPANT	\N	PRESENT	0
614512	612793	14259Y	PARTICIPANT	\N	PRESENT	0
614513	612793	04008A	PARTICIPANT	\N	PRESENT	0
614514	612793	14001X	PARTICIPANT	\N	PRESENT	0
614515	612793	14231L	PARTICIPANT	\N	PRESENT	0
614516	612793	19954N	PARTICIPANT	\N	PRESENT	0
614517	612793	17737W	PARTICIPANT	\N	PRESENT	0
614519	611540	14109K	PARTICIPANT	\N	PRESENT	0
614520	611540	19735D	PARTICIPANT	\N	PRESENT	0
614546	611227	20096L	PARTICIPANT	\N	PRESENT	0
614547	611227	14237S	PARTICIPANT	\N	PRESENT	0
614521	613070	19768N	PARTICIPANT	\N	PRESENT	0
614522	613070	19782L	PARTICIPANT	\N	PRESENT	0
614523	613070	19798U	PARTICIPANT	\N	PRESENT	0
614524	613070	11097X	PARTICIPANT	\N	PRESENT	0
614525	613070	19441R	PARTICIPANT	\N	PRESENT	0
614526	613070	19543W	PARTICIPANT	\N	PRESENT	0
614527	613070	19447X	PARTICIPANT	\N	PRESENT	0
614528	613070	19954N	PARTICIPANT	\N	PRESENT	0
614529	613070	19679N	PARTICIPANT	\N	PRESENT	0
614530	613070	14151M	PARTICIPANT	\N	PRESENT	0
614531	613070	20022R	PARTICIPANT	\N	PRESENT	0
614532	613070	10006L	PARTICIPANT	\N	PRESENT	0
614533	613070	20028X	PARTICIPANT	\N	PRESENT	0
614534	613070	14038Y	PARTICIPANT	\N	PRESENT	0
614535	613070	20030R	PARTICIPANT	\N	PRESENT	0
614536	613070	20034V	PARTICIPANT	\N	PRESENT	0
614537	613070	14187A	PARTICIPANT	\N	PRESENT	0
614538	613070	10015M	PARTICIPANT	\N	PRESENT	0
614539	613070	20040T	PARTICIPANT	\N	PRESENT	0
614540	613070	19691J	PARTICIPANT	\N	PRESENT	0
614541	613070	11090Q	PARTICIPANT	\N	PRESENT	0
614542	613070	14089Y	PARTICIPANT	\N	PRESENT	0
614543	613070	20062A	PARTICIPANT	\N	PRESENT	0
614544	613070	14207L	PARTICIPANT	\N	PRESENT	0
614545	613070	14021P	PARTICIPANT	\N	PRESENT	0
614548	613070	14257W	PARTICIPANT	\N	PRESENT	0
614549	613070	19383Y	PARTICIPANT	\N	PRESENT	0
614550	613070	20088L	PARTICIPANT	\N	PRESENT	0
614551	613070	20090E	PARTICIPANT	\N	PRESENT	0
614552	613070	20078J	PARTICIPANT	\N	PRESENT	0
614553	613070	14001X	PARTICIPANT	\N	PRESENT	0
614554	613070	20082E	PARTICIPANT	\N	PRESENT	0
614555	613070	04045F	PARTICIPANT	\N	PRESENT	0
614556	613070	19585H	PARTICIPANT	\N	PRESENT	0
614557	613070	04047H	PARTICIPANT	\N	PRESENT	0
614558	613070	19631V	PARTICIPANT	\N	PRESENT	0
614559	613070	19703U	PARTICIPANT	\N	PRESENT	0
614561	613070	19489J	PARTICIPANT	\N	PRESENT	0
614563	613070	07004J	PARTICIPANT	\N	PRESENT	0
614566	613070	20110Q	PARTICIPANT	\N	PRESENT	0
614567	613070	19367Y	PARTICIPANT	\N	PRESENT	0
614568	613070	19369B	PARTICIPANT	\N	PRESENT	0
614570	613070	14215L	PARTICIPANT	\N	PRESENT	0
614572	613070	14217N	PARTICIPANT	\N	PRESENT	0
614575	613070	08028W	PARTICIPANT	\N	PRESENT	0
614577	613070	20128B	PARTICIPANT	\N	PRESENT	0
614579	613070	14053L	PARTICIPANT	\N	PRESENT	0
614582	613070	14111D	PARTICIPANT	\N	PRESENT	0
614583	613070	20172F	PARTICIPANT	\N	PRESENT	0
614585	613070	19723Y	PARTICIPANT	\N	PRESENT	0
614587	613070	20174H	PARTICIPANT	\N	PRESENT	0
614588	613070	14205J	PARTICIPANT	\N	PRESENT	0
614592	613070	95063L	PARTICIPANT	\N	PRESENT	0
614593	613070	19629C	PARTICIPANT	\N	PRESENT	0
614595	613070	19507S	PARTICIPANT	\N	PRESENT	0
614598	613070	19747H	PARTICIPANT	\N	PRESENT	0
614635	611227	19681G	PARTICIPANT	\N	EXCUSE	0
614803	613386	19383Y	PARTICIPANT	\N	PRESENT	0
614804	613386	20088L	PARTICIPANT	\N	PRESENT	0
614805	613386	19768N	PARTICIPANT	\N	PRESENT	0
614806	613386	19515S	PARTICIPANT	\N	PRESENT	0
614807	613386	19782L	PARTICIPANT	\N	PRESENT	0
614808	613386	20092G	PARTICIPANT	\N	PRESENT	0
614809	613386	19441R	PARTICIPANT	\N	PRESENT	0
614810	613386	20078J	PARTICIPANT	\N	PRESENT	0
614811	613386	20082E	PARTICIPANT	\N	PRESENT	0
614812	613386	20094J	PARTICIPANT	\N	PRESENT	0
614813	613386	04045F	PARTICIPANT	\N	PRESENT	0
614814	613386	19631V	PARTICIPANT	\N	PRESENT	0
614815	613386	20104S	PARTICIPANT	\N	PRESENT	0
614816	613386	08015R	PARTICIPANT	\N	PRESENT	0
614817	613386	19369B	PARTICIPANT	\N	PRESENT	0
614818	613386	19563B	PARTICIPANT	\N	PRESENT	0
614819	613386	08028W	PARTICIPANT	\N	PRESENT	0
614820	613386	20028X	PARTICIPANT	\N	PRESENT	0
614821	613386	20030R	PARTICIPANT	\N	PRESENT	0
614822	613386	14038Y	PARTICIPANT	\N	PRESENT	0
614823	613386	19467C	PARTICIPANT	\N	PRESENT	0
614824	613386	20034V	PARTICIPANT	\N	PRESENT	0
614825	613386	14187A	PARTICIPANT	\N	PRESENT	0
614826	613386	11090Q	PRESIDENT	0	PRESENT	0
614827	613386	20054A	PARTICIPANT	\N	PRESENT	0
614828	613386	20174H	PARTICIPANT	\N	PRESENT	0
614829	613386	14205J	PARTICIPANT	\N	PRESENT	0
614830	613386	19507S	PARTICIPANT	\N	PRESENT	0
614831	613386	14207L	PARTICIPANT	\N	PRESENT	0
614832	613386	19747H	PARTICIPANT	\N	PRESENT	0
614833	613386	14257W	PARTICIPANT	\N	PRESENT	0
614847	614112	18193Q	PARTICIPANT	\N	PRESENT	0
614848	611227	19701S	PARTICIPANT	\N	PRESENT	0
614849	611227	17367Q	PARTICIPANT	\N	EXCUSE	0
614850	614101	20090E	PARTICIPANT	\N	PRESENT	0
614851	614101	11067R	PARTICIPANT	\N	PRESENT	0
614852	614101	19798U	PARTICIPANT	\N	PRESENT	0
614853	614101	11097X	PARTICIPANT	\N	PRESENT	0
614854	614101	19415P	PARTICIPANT	\N	PRESENT	0
614855	614101	18193Q	PARTICIPANT	\N	PRESENT	0
614856	614101	17779H	PARTICIPANT	\N	PRESENT	0
614857	614101	19703U	PARTICIPANT	\N	PRESENT	0
614858	614101	19553Y	PARTICIPANT	\N	PRESENT	0
614859	614101	11031D	PARTICIPANT	\N	PRESENT	0
614860	614101	19679N	PARTICIPANT	\N	PRESENT	0
614861	614101	14042U	PARTICIPANT	\N	PRESENT	0
606772	606771	17737W	PARTICIPANT	\N	PRESENT	0
606774	606773	17737W	PARTICIPANT	\N	PRESENT	0
608228	606761	14169X	PARTICIPANT	\N	PRESENT	0
608229	606768	20094J	PARTICIPANT	\N	PRESENT	0
608230	606768	04070G	PARTICIPANT	\N	PRESENT	0
608237	608236	20094J	PARTICIPANT	\N	PRESENT	0
608238	608236	04070G	PARTICIPANT	\N	PRESENT	0
608315	608313	20094J	PARTICIPANT	\N	PRESENT	0
608316	608313	04070G	PARTICIPANT	\N	PRESENT	0
609566	608711	14073Q	PARTICIPANT	\N	PRESENT	0
609607	609606	14255U	PARTICIPANT	\N	PRESENT	0
609608	609606	04035D	PARTICIPANT	\N	PRESENT	0
609609	609606	19585H	PARTICIPANT	\N	PRESENT	0
609610	609606	07004J	PARTICIPANT	\N	PRESENT	0
609890	609888	20120S	PARTICIPANT	\N	PRESENT	0
609892	609888	19629C	PARTICIPANT	\N	PRESENT	0
609903	608714	08015R	PARTICIPANT	\N	PRESENT	0
609909	608516	20110Q	PARTICIPANT	\N	PRESENT	0
611496	610675	19349W	PARTICIPANT	\N	PRESENT	0
611497	608705	19701S	PARTICIPANT	\N	PRESENT	0
611498	608705	19820Y	PARTICIPANT	\N	PRESENT	0
611499	608705	19826F	PARTICIPANT	\N	PRESENT	0
611500	608705	20106U	PARTICIPANT	\N	PRESENT	0
611501	608705	19685L	PARTICIPANT	\N	PRESENT	0
611502	608705	20046A	PARTICIPANT	\N	PRESENT	0
611503	608705	19551W	PARTICIPANT	\N	PRESENT	0
611504	608705	19333N	PARTICIPANT	\N	PRESENT	0
611505	610670	20114U	PARTICIPANT	\N	PRESENT	0
611506	610670	04085P	PARTICIPANT	\N	PRESENT	0
611507	610670	01028R	PARTICIPANT	\N	PRESENT	0
611528	608705	20136B	PARTICIPANT	\N	PRESENT	0
611529	608705	20038A	PARTICIPANT	\N	PRESENT	0
611539	608705	19659J	PARTICIPANT	\N	PRESENT	0
611608	611607	07033P	PARTICIPANT	\N	PRESENT	0
611609	611607	19551W	PARTICIPANT	\N	PRESENT	0
611610	611607	14059S	PARTICIPANT	\N	PRESENT	0
611611	611607	04043D	PARTICIPANT	\N	PRESENT	0
612157	610672	14111D	PARTICIPANT	\N	PRESENT	0
612330	610672	11072N	PARTICIPANT	\N	PRESENT	0
612333	610751	19820Y	PARTICIPANT	\N	PRESENT	0
612335	610751	20082E	PARTICIPANT	\N	PRESENT	0
612337	610672	19729F	PARTICIPANT	\N	EXCUSE	0
612338	610751	11067R	PARTICIPANT	\N	PRESENT	0
612339	610751	19713W	PARTICIPANT	\N	PRESENT	0
612340	610751	20066E	PARTICIPANT	\N	PRESENT	0
612341	610751	20040T	PARTICIPANT	\N	PRESENT	0
612342	610751	19507S	PARTICIPANT	\N	PRESENT	0
612343	610672	95063L	PARTICIPANT	\N	PRESENT	0
612344	610672	20074E	PARTICIPANT	\N	PRESENT	0
612345	610672	14147R	PARTICIPANT	\N	PRESENT	0
612346	610672	14215L	PARTICIPANT	\N	PRESENT	0
612347	610672	19585H	PARTICIPANT	\N	EXCUSE	0
612348	610751	14213J	PARTICIPANT	\N	PRESENT	0
612349	610751	20032T	PARTICIPANT	\N	PRESENT	0
612350	610751	01043Q	PARTICIPANT	\N	PRESENT	0
612351	610751	17779H	PARTICIPANT	\N	PRESENT	0
612352	610751	19565D	PARTICIPANT	\N	PRESENT	0
612353	610751	20104S	PARTICIPANT	\N	PRESENT	0
612354	610751	20024T	PARTICIPANT	\N	PRESENT	0
612376	610751	19383Y	PARTICIPANT	\N	PRESENT	0
612356	610751	19691J	PARTICIPANT	\N	PRESENT	0
612357	610751	20046A	PARTICIPANT	\N	PRESENT	0
612358	610751	11097X	PARTICIPANT	\N	PRESENT	0
612359	610751	04092N	PARTICIPANT	\N	PRESENT	0
612360	610751	20180F	PARTICIPANT	\N	PRESENT	0
612361	610751	20026V	PARTICIPANT	\N	PRESENT	0
612362	610751	19657G	PARTICIPANT	\N	PRESENT	0
612363	610751	20056C	PARTICIPANT	\N	PRESENT	0
612364	610751	10006L	PARTICIPANT	\N	PRESENT	0
612365	610751	19782L	PARTICIPANT	\N	PRESENT	0
612366	610751	20038A	PARTICIPANT	\N	PRESENT	0
612367	610751	19760E	PARTICIPANT	\N	PRESENT	0
612368	610751	17965H	PARTICIPANT	\N	PRESENT	0
612369	610751	19717B	PARTICIPANT	\N	PRESENT	0
612370	610751	20062A	PARTICIPANT	\N	PRESENT	0
612371	610751	19701S	PARTICIPANT	\N	PRESENT	0
612372	610751	14259Y	PARTICIPANT	\N	PRESENT	0
612374	610751	14031R	PARTICIPANT	\N	PRESENT	0
612375	610751	20138D	PARTICIPANT	\N	PRESENT	0
612377	610672	14053L	PARTICIPANT	\N	PRESENT	0
612378	610672	19543W	PARTICIPANT	\N	PRESENT	0
612379	610672	14069U	PARTICIPANT	\N	PRESENT	0
612380	610751	19629C	PARTICIPANT	\N	PRESENT	0
612381	610751	19866P	PARTICIPANT	\N	PRESENT	0
612382	610751	20136B	PARTICIPANT	\N	PRESENT	0
612383	610751	14071N	PARTICIPANT	\N	PRESENT	0
612384	610751	14042U	PARTICIPANT	\N	PRESENT	0
612385	610751	20248J	PARTICIPANT	\N	PRESENT	0
612386	610725	19593H	PARTICIPANT	\N	PRESENT	0
612387	610725	19643A	PARTICIPANT	\N	PRESENT	0
612388	610725	20132W	PARTICIPANT	\N	PRESENT	0
612389	610725	19611R	PARTICIPANT	\N	PRESENT	0
612390	610725	20048C	PARTICIPANT	\N	PRESENT	0
612391	610725	19399H	PARTICIPANT	\N	PRESENT	0
612392	610725	14229S	PARTICIPANT	\N	PRESENT	0
612393	610725	14030Q	PARTICIPANT	\N	PRESENT	0
612394	610725	19735D	PARTICIPANT	\N	PRESENT	0
612395	610725	14109K	PARTICIPANT	\N	PRESENT	0
612396	610725	11043H	PARTICIPANT	\N	PRESENT	0
612397	610725	19758L	PARTICIPANT	\N	PRESENT	0
612398	610725	20084G	PARTICIPANT	\N	PRESENT	0
612399	610725	19621T	PARTICIPANT	\N	PRESENT	0
612400	610725	11109J	PARTICIPANT	\N	EXCUSE	0
612401	610672	20114U	PARTICIPANT	\N	PRESENT	0
612402	610751	19747H	PARTICIPANT	\N	PRESENT	0
612403	610751	08056B	PARTICIPANT	\N	PRESENT	0
612405	610751	20108W	PARTICIPANT	\N	PRESENT	0
612407	610751	08015R	PARTICIPANT	\N	PRESENT	0
612408	610751	01058X	PARTICIPANT	\N	PRESENT	0
612409	610751	14033T	PARTICIPANT	\N	PRESENT	0
612410	610751	20078J	PARTICIPANT	\N	PRESENT	0
612411	610751	20172F	PARTICIPANT	\N	PRESENT	0
612415	610751	19413M	PARTICIPANT	\N	PRESENT	0
612466	610751	19301E	PARTICIPANT	\N	PRESENT	0
612467	610751	11012A	PARTICIPANT	\N	PRESENT	0
612474	610751	19798U	PARTICIPANT	\N	PRESENT	0
612483	610751	19631V	PARTICIPANT	\N	PRESENT	0
612484	610751	08045X	PARTICIPANT	\N	PRESENT	0
612497	610751	19723Y	PARTICIPANT	\N	PRESENT	0
612501	610751	20030R	PARTICIPANT	\N	PRESENT	0
612514	610751	19369B	PARTICIPANT	\N	PRESENT	0
612534	610751	20088L	PARTICIPANT	\N	PRESENT	0
612535	610751	20068G	PARTICIPANT	\N	PRESENT	0
612536	610751	20090E	PARTICIPANT	\N	PRESENT	0
613331	610785	04059M	PARTICIPANT	\N	PRESENT	0
613332	610785	19651A	PARTICIPANT	\N	PRESENT	0
613333	610785	19399H	PARTICIPANT	\N	PRESENT	0
613334	610785	19611R	PRESIDENT	0	PRESENT	0
613335	610785	19699S	PARTICIPANT	\N	PRESENT	0
613336	610785	14229S	PARTICIPANT	\N	PRESENT	0
613337	610785	19669L	PARTICIPANT	\N	PRESENT	0
613338	610786	04059M	PARTICIPANT	\N	PRESENT	0
613339	610786	19651A	PARTICIPANT	\N	PRESENT	0
613340	610786	11053K	PARTICIPANT	\N	PRESENT	0
613341	610786	20122U	PARTICIPANT	\N	PRESENT	0
613342	610786	14229S	PARTICIPANT	\N	PRESENT	0
613343	610786	19699S	PARTICIPANT	\N	PRESENT	0
613344	610786	19611R	PRESIDENT	0	PRESENT	0
613345	610786	19399H	PARTICIPANT	\N	PRESENT	0
613373	608712	17023S	PARTICIPANT	\N	PRESENT	0
613374	608712	19329S	PARTICIPANT	\N	PRESENT	1
613375	608712	20034V	PARTICIPANT	\N	PRESENT	0
613376	608712	19715Y	PARTICIPANT	\N	PRESENT	1
613377	608712	14059S	PARTICIPANT	\N	EXCUSE	0
613378	608712	19657G	PARTICIPANT	\N	PRESENT	1
613380	608712	08073C	PARTICIPANT	\N	PRESENT	0
613381	608712	20150Y	PARTICIPANT	\N	PRESENT	0
613388	613387	04059M	PARTICIPANT	\N	PRESENT	0
613389	613387	19651A	PARTICIPANT	\N	PRESENT	0
613390	613387	20086J	PARTICIPANT	\N	EXCUSE	0
613391	613387	19399H	PARTICIPANT	\N	PRESENT	0
613392	613387	19611R	PRESIDENT	0	PRESENT	0
613393	613387	19699S	PARTICIPANT	\N	PRESENT	0
613394	613387	12041X	PARTICIPANT	\N	PRESENT	0
613395	613387	20142Y	PARTICIPANT	\N	PRESENT	0
613397	613365	19713W	PARTICIPANT	\N	PRESENT	0
613398	613396	19713W	PARTICIPANT	\N	PRESENT	0
613399	613396	19723Y	PARTICIPANT	\N	PRESENT	0
614015	612404	19703U	PARTICIPANT	\N	PRESENT	0
614017	612404	19679N	PARTICIPANT	\N	PRESENT	0
614018	612404	14217N	PARTICIPANT	\N	PRESENT	0
611558	610671	20022R	PARTICIPANT	\N	PRESENT	0
611559	610671	20128B	PARTICIPANT	\N	PRESENT	0
611560	610671	14111D	PARTICIPANT	\N	PRESENT	0
611561	610671	10015M	PARTICIPANT	\N	PRESENT	0
611562	610671	11026G	PARTICIPANT	\N	PRESENT	0
611563	610671	11033F	PARTICIPANT	\N	PRESENT	0
611564	610671	04085P	PARTICIPANT	\N	PRESENT	0
611565	610671	14089Y	PARTICIPANT	\N	PRESENT	0
611566	610671	19725B	PARTICIPANT	\N	PRESENT	0
611567	610671	95063L	PARTICIPANT	\N	PRESENT	0
611568	610671	19629C	PARTICIPANT	\N	PRESENT	0
611569	610671	14069U	PARTICIPANT	\N	PRESENT	0
611570	610671	19749K	PARTICIPANT	\N	PRESENT	0
611571	610671	04008A	PARTICIPANT	\N	PRESENT	0
611572	610671	14021P	PARTICIPANT	\N	PRESENT	0
611573	610671	14259Y	PARTICIPANT	\N	PRESENT	0
611575	610727	19766L	PARTICIPANT	\N	PRESENT	0
611576	610727	19699S	PARTICIPANT	\N	PRESENT	0
611577	610727	19533U	PARTICIPANT	\N	PRESENT	0
611578	610727	04033B	PARTICIPANT	\N	PRESENT	0
611579	610727	14229S	PARTICIPANT	\N	PRESENT	0
611580	610727	19573D	PARTICIPANT	\N	PRESENT	0
611581	610727	20112S	PARTICIPANT	\N	PRESENT	0
611582	610727	08012N	PARTICIPANT	\N	PRESENT	0
611583	610727	20026V	PARTICIPANT	\N	PRESENT	0
611584	610727	19643A	PARTICIPANT	\N	PRESENT	0
611585	610727	20132W	PARTICIPANT	\N	PRESENT	0
611586	610727	20134Y	PARTICIPANT	\N	PRESENT	0
611587	610727	19611R	PARTICIPANT	\N	PRESENT	0
611588	610727	20142Y	PARTICIPANT	\N	PRESENT	0
611589	610727	20048C	PARTICIPANT	\N	PRESENT	0
611590	610727	19399H	PARTICIPANT	\N	PRESENT	0
611591	610727	20052X	PARTICIPANT	\N	PRESENT	0
611592	610727	14030Q	PARTICIPANT	\N	PRESENT	0
611593	610727	20056C	PARTICIPANT	\N	PRESENT	0
611594	610727	20180F	PARTICIPANT	\N	PRESENT	0
611595	610727	04059M	PARTICIPANT	\N	PRESENT	0
611596	610727	20264J	PARTICIPANT	\N	PRESENT	0
611597	610727	19735D	PARTICIPANT	\N	PRESENT	0
611598	610727	19057M	PARTICIPANT	\N	PRESENT	0
611599	610727	14123H	PARTICIPANT	\N	PRESENT	0
611600	610727	11104D	PARTICIPANT	\N	PRESENT	0
611601	610727	11043H	PARTICIPANT	\N	PRESENT	0
611602	610727	19621T	PARTICIPANT	\N	PRESENT	0
611603	610727	20084G	PARTICIPANT	\N	PRESENT	0
611623	610534	19383Y	PARTICIPANT	\N	PRESENT	0
611624	610534	19768N	PARTICIPANT	\N	PRESENT	0
611625	610534	20088L	PARTICIPANT	\N	PRESENT	0
611626	610534	19515S	PARTICIPANT	\N	PRESENT	0
611627	610534	11077T	PARTICIPANT	\N	PRESENT	0
611628	610534	20092G	PARTICIPANT	\N	PRESENT	0
611629	610534	19782L	PARTICIPANT	\N	PRESENT	0
611630	610534	01043Q	PARTICIPANT	\N	PRESENT	0
611631	610534	14357A	PARTICIPANT	\N	PRESENT	0
611632	610534	19441R	PARTICIPANT	\N	PRESENT	0
611633	610534	20078J	PARTICIPANT	\N	PRESENT	0
611634	610534	19413M	PARTICIPANT	\N	PRESENT	0
611635	610534	20082E	PARTICIPANT	\N	PRESENT	0
611636	610534	20094J	PARTICIPANT	\N	PRESENT	0
611638	610534	19631V	PARTICIPANT	\N	PRESENT	0
611639	610534	20104S	PARTICIPANT	\N	PRESENT	0
611640	610534	19705W	PARTICIPANT	\N	PRESENT	0
611641	610534	19707Y	PARTICIPANT	\N	PRESENT	0
611642	610534	08015R	PARTICIPANT	\N	PRESENT	0
611643	610534	19575F	PARTICIPANT	\N	PRESENT	0
611644	610534	19369B	PARTICIPANT	\N	PRESENT	0
611645	610534	20018V	PARTICIPANT	\N	PRESENT	0
611646	610534	19511N	PARTICIPANT	\N	PRESENT	0
611647	610534	08028W	PARTICIPANT	\N	PRESENT	0
611648	610534	19563B	PARTICIPANT	\N	PRESENT	0
611649	610534	14329V	PARTICIPANT	\N	PRESENT	0
611650	610534	20028X	PARTICIPANT	\N	PRESENT	0
611651	610534	20030R	PARTICIPANT	\N	PRESENT	0
611652	610534	14038Y	PARTICIPANT	\N	PRESENT	0
611653	610534	19467C	PARTICIPANT	\N	PRESENT	0
611654	610534	14187A	PARTICIPANT	\N	PRESENT	0
611655	610534	20144B	PARTICIPANT	\N	PRESENT	0
611656	610534	19695N	PARTICIPANT	\N	PRESENT	0
611657	610534	14033T	PARTICIPANT	\N	PRESENT	0
611658	610534	11090Q	PRESIDENT	0	PRESENT	0
611659	610534	01025N	PARTICIPANT	\N	PRESENT	0
611660	610534	20054A	PARTICIPANT	\N	PRESENT	0
611661	610534	20174H	PARTICIPANT	\N	PRESENT	0
611662	610534	14205J	PARTICIPANT	\N	PRESENT	0
611663	610534	20062A	PARTICIPANT	\N	PRESENT	0
611664	610534	14251Q	PARTICIPANT	\N	PRESENT	0
611665	610534	19507S	PARTICIPANT	\N	PRESENT	0
611666	610534	19747H	PARTICIPANT	\N	PRESENT	0
611667	610534	14207L	PARTICIPANT	\N	PRESENT	0
611668	610534	14257W	PARTICIPANT	\N	PRESENT	0
611670	610750	19675J	PARTICIPANT	\N	PRESENT	0
611671	610750	08069G	PARTICIPANT	\N	PRESENT	0
611677	610750	20100N	PARTICIPANT	\N	PRESENT	0
611673	610750	14105F	PARTICIPANT	\N	PRESENT	0
611674	610750	14223L	PARTICIPANT	\N	PRESENT	0
611675	610750	20138D	PARTICIPANT	\N	PRESENT	0
611676	610750	20068G	PARTICIPANT	\N	PRESENT	0
611678	610750	08060W	PARTICIPANT	\N	PRESENT	0
611679	610750	17779H	PARTICIPANT	\N	PRESENT	0
611680	610750	19443T	PARTICIPANT	\N	PRESENT	0
611681	610750	14053L	PARTICIPANT	\N	PRESENT	0
611682	610750	19347U	PARTICIPANT	\N	PRESENT	0
611683	610750	19681G	PARTICIPANT	\N	PRESENT	0
611684	610750	19619A	PARTICIPANT	\N	PRESENT	0
611685	610750	19569H	PARTICIPANT	\N	PRESENT	0
611686	610750	11041F	PARTICIPANT	\N	PRESENT	0
611687	610750	19599P	PARTICIPANT	\N	PRESENT	0
611688	610750	14001X	PARTICIPANT	\N	PRESENT	0
611689	610750	14331P	PARTICIPANT	\N	PRESENT	0
611690	610750	20102Q	PARTICIPANT	\N	PRESENT	0
611691	610750	19369B	PARTICIPANT	\N	PRESENT	0
611692	610750	19629C	PARTICIPANT	\N	PRESENT	0
611693	610750	19689Q	PARTICIPANT	\N	PRESENT	0
611694	610750	19826F	PARTICIPANT	\N	PRESENT	0
611695	610750	19511N	PARTICIPANT	\N	PRESENT	0
611696	610750	11054L	PARTICIPANT	\N	PRESENT	0
611697	610750	18193Q	PARTICIPANT	\N	PRESENT	0
611698	610750	14221J	PARTICIPANT	\N	PRESENT	0
611699	610750	14097Y	PARTICIPANT	\N	PRESENT	0
611700	610750	20094J	PARTICIPANT	\N	PRESENT	0
611701	610750	19575F	PARTICIPANT	\N	PRESENT	0
611702	610750	04070G	PARTICIPANT	\N	PRESENT	0
611703	610750	95041E	PARTICIPANT	\N	PRESENT	0
611704	610750	20146D	PARTICIPANT	\N	PRESENT	0
611705	610750	19659J	PARTICIPANT	\N	PRESENT	0
611706	610750	14231L	PARTICIPANT	\N	PRESENT	0
611707	610750	19711U	PARTICIPANT	\N	PRESENT	0
611708	610750	19679N	PARTICIPANT	\N	PRESENT	0
611709	610750	11067R	PARTICIPANT	\N	PRESENT	0
611710	610750	19593H	PARTICIPANT	\N	PRESENT	0
611711	610750	19583F	PARTICIPANT	\N	PRESENT	0
611712	610750	14111D	PARTICIPANT	\N	PRESENT	0
611713	610750	14267Y	PARTICIPANT	\N	PRESENT	0
611714	610750	20136B	PARTICIPANT	\N	PRESENT	0
611715	610750	20022R	PARTICIPANT	\N	PRESENT	0
611716	610750	14259Y	PARTICIPANT	\N	PRESENT	0
611717	610750	20090E	PARTICIPANT	\N	PRESENT	0
611718	610750	20062A	PARTICIPANT	\N	PRESENT	0
611719	610750	19383Y	PARTICIPANT	\N	PRESENT	0
611720	610750	20098N	PARTICIPANT	\N	PRESENT	0
611721	610750	20078J	PARTICIPANT	\N	PRESENT	0
611722	610750	20032T	PARTICIPANT	\N	PRESENT	0
611723	610750	19349W	PARTICIPANT	\N	PRESENT	0
611724	610750	11104D	PARTICIPANT	\N	PRESENT	0
611725	610750	14107H	PARTICIPANT	\N	PRESENT	0
611726	610750	19691J	PARTICIPANT	\N	PRESENT	0
611727	610750	19747H	PARTICIPANT	\N	PRESENT	0
611728	610750	20088L	PARTICIPANT	\N	PRESENT	0
611729	610750	19637C	PARTICIPANT	\N	PRESENT	0
611730	610750	19758L	PARTICIPANT	\N	PRESENT	0
611731	610750	19527W	PARTICIPANT	\N	PRESENT	0
611732	610750	11045K	PARTICIPANT	\N	PRESENT	0
611733	610750	11110B	PARTICIPANT	\N	PRESENT	0
611734	610750	01025N	PARTICIPANT	\N	PRESENT	0
611735	610750	19421M	PARTICIPANT	\N	PRESENT	0
611736	610750	19415P	PARTICIPANT	\N	PRESENT	0
611737	610750	14217N	PARTICIPANT	\N	PRESENT	0
611738	610750	20080C	PARTICIPANT	\N	PRESENT	0
611739	610750	19413M	PARTICIPANT	\N	PRESENT	0
611740	610750	19549D	PARTICIPANT	\N	PRESENT	0
602137	600819	04057K	PARTICIPANT	\N	EXCUSE	0
602138	600819	19760E	PARTICIPANT	\N	PRESENT	0
602139	600819	19367Y	PARTICIPANT	\N	PRESENT	0
602140	600819	19415P	PARTICIPANT	\N	PRESENT	0
602141	600819	20090E	PARTICIPANT	\N	PRESENT	0
602142	600819	14195A	PARTICIPANT	\N	PRESENT	0
602143	600819	11031D	PARTICIPANT	\N	PRESENT	0
602144	600819	10006L	PRESIDENT	0	PRESENT	0
602145	600819	14217N	PARTICIPANT	\N	PRESENT	0
602146	600819	20248J	PARTICIPANT	\N	PRESENT	0
602147	600819	14042U	PARTICIPANT	\N	PRESENT	0
602148	600819	08045X	PARTICIPANT	\N	PRESENT	0
602149	600819	20172F	PARTICIPANT	\N	PRESENT	0
602150	600819	19691J	PARTICIPANT	\N	PRESENT	0
602151	600819	19553Y	PARTICIPANT	\N	PRESENT	0
602152	600819	19569H	PARTICIPANT	\N	PRESENT	0
602153	600819	14213J	PARTICIPANT	\N	PRESENT	0
602154	600819	20066E	PARTICIPANT	\N	PRESENT	0
602155	600819	19715Y	PARTICIPANT	\N	PRESENT	0
602156	600819	19683J	PARTICIPANT	\N	PRESENT	0
602157	600819	19723Y	PARTICIPANT	\N	PRESENT	0
602158	600819	18193Q	PARTICIPANT	\N	PRESENT	0
602159	600819	19657G	PARTICIPANT	\N	PRESENT	0
602160	600819	11067R	PARTICIPANT	\N	PRESENT	0
602161	600819	14223L	PARTICIPANT	\N	PRESENT	0
602162	600819	14071N	PARTICIPANT	\N	PRESENT	0
602163	600819	17965H	PARTICIPANT	\N	PRESENT	0
602164	600819	19679N	PARTICIPANT	\N	PRESENT	0
602165	600819	19798U	PARTICIPANT	\N	PRESENT	0
602166	600819	11097X	PARTICIPANT	\N	PRESENT	0
602167	600819	19703U	PARTICIPANT	\N	PRESENT	0
602168	600819	19713W	PARTICIPANT	\N	PRESENT	0
602169	600819	01034P	PARTICIPANT	\N	PRESENT	0
602170	600821	04057K	PARTICIPANT	\N	PRESENT	0
602171	600821	19760E	PARTICIPANT	\N	PRESENT	0
602172	600821	20090E	PARTICIPANT	\N	PRESENT	0
602173	600821	10006L	PRESIDENT	0	PRESENT	0
602174	600821	14042U	PARTICIPANT	\N	PRESENT	0
602175	600821	08045X	PARTICIPANT	\N	PRESENT	0
602176	600821	20172F	PARTICIPANT	\N	PRESENT	0
602177	600821	14026U	PARTICIPANT	\N	PRESENT	0
602178	600821	14213J	PARTICIPANT	\N	PRESENT	0
602179	600821	19723Y	PARTICIPANT	\N	PRESENT	0
602180	600821	19657G	PARTICIPANT	\N	PRESENT	0
602181	600821	11067R	PARTICIPANT	\N	PRESENT	0
602182	600821	04092N	PARTICIPANT	\N	PRESENT	0
602183	600821	14071N	PARTICIPANT	\N	PRESENT	0
602184	600821	20130U	PARTICIPANT	\N	PRESENT	0
602185	600821	19798U	PARTICIPANT	\N	PRESENT	0
602186	600821	11097X	PARTICIPANT	\N	PRESENT	0
602187	600821	01034P	PARTICIPANT	\N	PRESENT	0
602255	602254	19703U	PARTICIPANT	\N	PRESENT	0
602260	602259	20074E	PARTICIPANT	\N	PRESENT	0
602262	602261	20114U	PARTICIPANT	\N	PRESENT	0
602263	602261	20074E	PARTICIPANT	\N	PRESENT	0
602265	602264	20074E	PARTICIPANT	\N	PRESENT	0
602312	602310	11072N	PARTICIPANT	\N	PRESENT	0
602459	602457	20024T	PARTICIPANT	\N	PRESENT	0
602461	602457	97011G	PARTICIPANT	\N	PRESENT	0
602463	602457	11041F	PARTICIPANT	\N	PRESENT	0
602465	602457	08015R	PARTICIPANT	\N	PRESENT	0
602466	602457	08034U	PARTICIPANT	\N	PRESENT	0
602548	602547	20074E	PARTICIPANT	\N	PRESENT	0
602987	602985	19701S	PARTICIPANT	\N	PRESENT	0
602988	602985	95063L	PARTICIPANT	\N	PRESENT	0
602989	602985	20106U	PARTICIPANT	\N	PRESENT	0
602990	602985	19693L	PARTICIPANT	\N	PRESENT	0
602992	602991	04059M	PARTICIPANT	\N	PRESENT	0
602993	602991	17367Q	PARTICIPANT	\N	PRESENT	0
602994	602991	20114U	PARTICIPANT	\N	PRESENT	0
602995	602991	04042C	PARTICIPANT	\N	PRESENT	0
602996	602991	14053L	PARTICIPANT	\N	PRESENT	0
602998	602991	19693L	PARTICIPANT	\N	PRESENT	0
602999	602991	14281W	PARTICIPANT	\N	PRESENT	0
603000	602991	14187A	PARTICIPANT	\N	PRESENT	0
603001	602991	07033P	PARTICIPANT	\N	PRESENT	0
603002	602991	19565D	PARTICIPANT	\N	PRESENT	0
603003	602991	99004R	PARTICIPANT	\N	PRESENT	0
603004	602991	11026G	PARTICIPANT	\N	PRESENT	0
603007	602991	19443T	PARTICIPANT	\N	PRESENT	0
603008	602991	19503N	PARTICIPANT	\N	PRESENT	0
603009	602991	20018V	PARTICIPANT	\N	PRESENT	0
603012	602991	19663E	PARTICIPANT	\N	PRESENT	0
604741	603164	01062T	PARTICIPANT	\N	PRESENT	0
604742	603164	01060R	PARTICIPANT	\N	PRESENT	0
604746	603164	20096L	PARTICIPANT	\N	PRESENT	0
604744	603164	20124W	PARTICIPANT	\N	PRESENT	0
604745	603164	19685L	PARTICIPANT	\N	PRESENT	0
604747	603164	10015M	PARTICIPANT	\N	PRESENT	0
604748	603164	19551W	PARTICIPANT	\N	PRESENT	0
604749	603164	19954N	PARTICIPANT	\N	PRESENT	0
604750	603164	20032T	PARTICIPANT	\N	PRESENT	0
604755	603164	14221J	PARTICIPANT	\N	PRESENT	0
604752	603164	20102Q	PARTICIPANT	\N	PRESENT	0
604753	603164	20034V	PARTICIPANT	\N	PRESENT	0
604754	603164	14073Q	PARTICIPANT	\N	PRESENT	0
604756	603164	14219Q	PARTICIPANT	\N	PRESENT	0
604757	603164	04045F	PARTICIPANT	\N	PRESENT	0
604758	603164	14147R	PARTICIPANT	\N	PRESENT	0
604759	603164	20098N	PARTICIPANT	\N	PRESENT	0
604760	603164	19565D	PARTICIPANT	\N	PRESENT	0
604761	603164	20128B	PARTICIPANT	\N	PRESENT	0
604762	603164	20108W	PARTICIPANT	\N	PRESENT	0
604763	603164	14026U	PARTICIPANT	\N	PRESENT	0
604764	603164	19349W	PARTICIPANT	\N	PRESENT	0
604765	603164	20126Y	PARTICIPANT	\N	PRESENT	0
604766	603164	19335Q	PARTICIPANT	\N	PRESENT	0
604767	603164	18083K	PARTICIPANT	\N	PRESENT	0
604768	603164	14021P	PARTICIPANT	\N	PRESENT	0
604769	603164	19599P	PARTICIPANT	\N	PRESENT	0
604770	603164	14030Q	PARTICIPANT	\N	PRESENT	0
604771	603164	19553Y	PARTICIPANT	\N	PRESENT	0
604772	603164	14033T	PARTICIPANT	\N	PRESENT	0
604773	603164	20026V	PARTICIPANT	\N	PRESENT	0
604739	603164	12041X	PARTICIPANT	\N	PRESENT	0
604740	603164	20100N	PARTICIPANT	\N	PRESENT	0
604774	603164	19629C	PARTICIPANT	\N	PRESENT	0
604775	603164	14031R	PARTICIPANT	\N	PRESENT	0
604776	603164	20136B	PARTICIPANT	\N	PRESENT	0
604777	602258	19954N	PARTICIPANT	\N	PRESENT	0
604778	602258	07004J	PARTICIPANT	\N	PRESENT	0
604779	602258	14179A	PARTICIPANT	\N	PRESENT	0
604780	602258	04047H	PRESIDENT	0	PRESENT	0
604781	602258	19673G	PARTICIPANT	\N	PRESENT	0
604782	602258	19675J	PARTICIPANT	\N	PRESENT	0
604783	602258	14231L	PARTICIPANT	\N	PRESENT	0
604784	602258	19447X	PARTICIPANT	\N	PRESENT	0
604785	602258	19729F	PARTICIPANT	\N	EXCUSE	0
604786	602258	08018U	PARTICIPANT	\N	EXCUSE	0
604787	602258	20074E	PARTICIPANT	\N	PRESENT	0
604788	602258	14001X	PARTICIPANT	\N	PRESENT	0
604789	602258	11033F	PARTICIPANT	\N	PRESENT	0
604790	602258	14147R	PARTICIPANT	\N	PRESENT	0
604791	602258	19749K	PARTICIPANT	\N	PRESENT	0
604792	602258	20022R	PARTICIPANT	\N	PRESENT	0
604793	602258	11072N	PARTICIPANT	\N	PRESENT	0
604794	602258	20110Q	PARTICIPANT	\N	PRESENT	0
604795	602258	14151M	PARTICIPANT	\N	PRESENT	0
604796	602258	04008A	PARTICIPANT	\N	PRESENT	0
604797	602258	19585H	PARTICIPANT	\N	PRESENT	0
604798	602258	14275Y	PARTICIPANT	\N	PRESENT	0
604799	602258	20114U	PARTICIPANT	\N	PRESENT	0
604800	602258	10015M	PARTICIPANT	\N	PRESENT	0
604801	602258	11026G	PARTICIPANT	\N	PRESENT	0
604802	602258	14089Y	PARTICIPANT	\N	PRESENT	0
604803	602258	19725B	PARTICIPANT	\N	PRESENT	0
604804	602258	95063L	PARTICIPANT	\N	PRESENT	0
604805	602258	14069U	PARTICIPANT	\N	PRESENT	0
604806	603129	20252E	PARTICIPANT	\N	PRESENT	0
604807	603129	20116W	PARTICIPANT	\N	PRESENT	0
604808	603129	14173T	PARTICIPANT	\N	PRESENT	0
604809	603129	14327T	PRESIDENT	1	PRESENT	0
604810	603129	11053K	PARTICIPANT	\N	PRESENT	0
604811	603129	08010L	PARTICIPANT	\N	PRESENT	0
604812	602939	19703U	PARTICIPANT	\N	PRESENT	0
604813	602939	20090E	PARTICIPANT	\N	PRESENT	0
604814	602939	11067R	PARTICIPANT	\N	PRESENT	0
604815	602939	14355X	PARTICIPANT	\N	PRESENT	0
604816	602939	11103C	PARTICIPANT	\N	PRESENT	0
604817	602939	14195A	PARTICIPANT	\N	PRESENT	0
604818	602939	14213J	PARTICIPANT	\N	PRESENT	0
614862	614101	14195A	PARTICIPANT	\N	PRESENT	0
614863	614101	14213J	PARTICIPANT	\N	PRESENT	0
614864	614101	19367Y	PARTICIPANT	\N	PRESENT	0
614865	614101	14217N	PARTICIPANT	\N	PRESENT	0
614866	614101	10006L	PRESIDENT	0	PRESENT	0
614867	614101	19683J	PARTICIPANT	\N	PRESENT	0
614868	614101	20040T	PARTICIPANT	\N	PRESENT	0
614869	614101	19691J	PARTICIPANT	\N	PRESENT	0
614870	614101	19715Y	PARTICIPANT	\N	PRESENT	0
614871	614101	20148F	PARTICIPANT	\N	PRESENT	0
614872	614101	20172F	PARTICIPANT	\N	PRESENT	0
614873	614101	20248J	PARTICIPANT	\N	PRESENT	0
614874	614101	19760E	PARTICIPANT	\N	PRESENT	0
614884	612997	20024T	PARTICIPANT	\N	PRESENT	0
614885	612997	14053L	PARTICIPANT	\N	PRESENT	0
614901	613311	86034E	PARTICIPANT	\N	PRESENT	0
614902	613311	08060W	PARTICIPANT	\N	PRESENT	0
614903	613311	19511N	PARTICIPANT	\N	PRESENT	0
614904	613311	20068G	PARTICIPANT	\N	PRESENT	0
614905	613311	14173T	PARTICIPANT	\N	PRESENT	0
614906	613311	19593H	PARTICIPANT	\N	PRESENT	0
614907	613311	11056N	PARTICIPANT	\N	PRESENT	0
614908	613311	19629C	PARTICIPANT	\N	PRESENT	0
614909	613311	20090E	PARTICIPANT	\N	PRESENT	0
614910	613311	14105F	PARTICIPANT	\N	PRESENT	0
614911	613311	08028W	PARTICIPANT	\N	PRESENT	0
614912	613311	20102Q	PARTICIPANT	\N	PRESENT	0
614913	613311	14133K	PARTICIPANT	\N	PRESENT	0
614914	613311	20108W	PARTICIPANT	\N	PRESENT	0
614915	613311	05012A	PARTICIPANT	\N	PRESENT	0
614916	613311	14038Y	PARTICIPANT	\N	PRESENT	0
614917	613311	19739H	PARTICIPANT	\N	PRESENT	0
614918	613311	04045F	PARTICIPANT	\N	PRESENT	0
614919	613311	11054L	PARTICIPANT	\N	PRESENT	0
614920	613311	14237S	PARTICIPANT	\N	PRESENT	0
614921	613311	07033P	PARTICIPANT	\N	PRESENT	0
614922	613311	19415P	PARTICIPANT	\N	PRESENT	0
614923	613311	19581D	PARTICIPANT	\N	PRESENT	0
614924	613311	14071N	PARTICIPANT	\N	PRESENT	0
614925	613311	19683J	PARTICIPANT	\N	PRESENT	0
614926	613311	20152B	PARTICIPANT	\N	PRESENT	0
614927	613311	19479G	PARTICIPANT	\N	PRESENT	0
614928	613311	14267Y	PARTICIPANT	\N	PRESENT	0
614929	613311	20264J	PARTICIPANT	\N	PRESENT	0
614930	613311	19387D	PARTICIPANT	\N	PRESENT	0
614931	613311	07004J	PARTICIPANT	\N	PRESENT	0
614932	613311	14053L	PARTICIPANT	\N	PRESENT	0
614933	613311	19699S	PARTICIPANT	\N	PRESENT	0
614934	613311	08047A	PARTICIPANT	\N	PRESENT	0
614935	613311	19507S	PARTICIPANT	\N	PRESENT	0
614936	613311	19399H	PARTICIPANT	\N	PRESENT	0
614937	613311	12028B	PARTICIPANT	\N	PRESENT	0
614938	613311	14251Q	PARTICIPANT	\N	PRESENT	0
614939	613311	19766L	PARTICIPANT	\N	PRESENT	0
614940	613311	19673G	PARTICIPANT	\N	PRESENT	0
614941	613311	04047H	PARTICIPANT	\N	PRESENT	0
614942	613311	19798U	PARTICIPANT	\N	PRESENT	0
614943	613311	01024M	PARTICIPANT	\N	PRESENT	0
614944	613311	20100N	PARTICIPANT	\N	PRESENT	0
614945	613311	14195A	PARTICIPANT	\N	PRESENT	0
614946	613311	20072C	PARTICIPANT	\N	PRESENT	0
614947	613311	19383Y	PARTICIPANT	\N	PRESENT	0
614948	613311	20172F	PARTICIPANT	\N	PRESENT	0
614949	613311	20078J	PARTICIPANT	\N	PRESENT	0
614950	613311	11104D	PARTICIPANT	\N	PRESENT	0
614951	613311	20028X	PARTICIPANT	\N	PRESENT	0
614952	613311	11066Q	PARTICIPANT	\N	PRESENT	0
614953	613311	04008A	PARTICIPANT	\N	PRESENT	0
614954	613311	19693L	PARTICIPANT	\N	PRESENT	0
614955	613311	14211G	PARTICIPANT	\N	PRESENT	0
614956	613311	19515S	PARTICIPANT	\N	PRESENT	0
614957	613311	14031R	PARTICIPANT	\N	PRESENT	0
614958	613311	92040Q	PARTICIPANT	\N	PRESENT	0
614959	613311	20116W	PARTICIPANT	\N	PRESENT	0
614960	613311	20030R	PARTICIPANT	\N	PRESENT	0
614961	613311	08015R	PARTICIPANT	\N	PRESENT	0
614962	613311	11080N	PARTICIPANT	\N	PRESENT	0
614963	613311	11077T	PARTICIPANT	\N	PRESENT	0
614964	613311	19565D	PARTICIPANT	\N	PRESENT	0
614965	613311	20046A	PARTICIPANT	\N	PRESENT	0
614966	613311	18083K	PARTICIPANT	\N	PRESENT	0
614967	613311	14329V	PARTICIPANT	\N	PRESENT	0
614968	613311	11072N	PARTICIPANT	\N	PRESENT	0
614969	613311	19251M	PARTICIPANT	\N	PRESENT	0
614970	613311	19681G	PARTICIPANT	\N	PRESENT	0
614971	613311	20036X	PARTICIPANT	\N	PRESENT	0
614972	613311	19573D	PARTICIPANT	\N	PRESENT	0
614973	613311	19703U	PARTICIPANT	\N	PRESENT	0
614974	613311	20132W	PARTICIPANT	\N	PRESENT	0
614975	613311	11085T	PARTICIPANT	\N	PRESENT	0
614976	613311	04092N	PARTICIPANT	\N	PRESENT	0
614977	613311	20142Y	PARTICIPANT	\N	PRESENT	0
614978	613311	17589D	PARTICIPANT	\N	PRESENT	0
614979	613311	20252E	PARTICIPANT	\N	PRESENT	0
614980	613311	20110Q	PARTICIPANT	\N	PRESENT	0
614981	613311	19713W	PARTICIPANT	\N	PRESENT	0
614982	613311	14219Q	PARTICIPANT	\N	PRESENT	0
614983	613311	14151M	PARTICIPANT	\N	PRESENT	0
614984	613311	19525U	PARTICIPANT	\N	PRESENT	0
614985	613311	19647E	PARTICIPANT	\N	PRESENT	0
614986	613311	11027H	PARTICIPANT	\N	PRESENT	0
614987	613311	12041X	PARTICIPANT	\N	PRESENT	0
614988	613311	19782L	PARTICIPANT	\N	PRESENT	0
614989	613311	11067R	PARTICIPANT	\N	PRESENT	0
614990	613311	20148F	PARTICIPANT	\N	PRESENT	0
614991	613311	05008E	PARTICIPANT	\N	PRESENT	0
614992	613311	08061X	PARTICIPANT	\N	PRESENT	0
614993	613311	19643A	PARTICIPANT	\N	PRESENT	0
614994	613311	19679N	PARTICIPANT	\N	PRESENT	0
614995	613311	14253S	PARTICIPANT	\N	PRESENT	0
614996	613311	20076G	PARTICIPANT	\N	PRESENT	0
614997	613311	11045K	PARTICIPANT	\N	PRESENT	0
614998	613311	04070G	PARTICIPANT	\N	PRESENT	0
614999	613311	19701S	PARTICIPANT	\N	PRESENT	0
615000	613311	20022R	PARTICIPANT	\N	PRESENT	0
615001	613311	14042U	PARTICIPANT	\N	PRESENT	0
615002	613311	19747H	PARTICIPANT	\N	PRESENT	0
615003	613311	19621T	PARTICIPANT	\N	PRESENT	0
615004	613311	20118Y	PARTICIPANT	\N	PRESENT	0
615005	613311	19527W	PARTICIPANT	\N	PRESENT	0
615006	613311	14179A	PARTICIPANT	\N	PRESENT	0
615007	613311	14089Y	PARTICIPANT	\N	PRESENT	0
615008	613311	20138D	PARTICIPANT	\N	PRESENT	0
615009	613311	20112S	PARTICIPANT	\N	PRESENT	0
615010	613311	19687N	PARTICIPANT	\N	PRESENT	0
615011	613311	08011M	PARTICIPANT	\N	PRESENT	0
615012	613311	20130U	PARTICIPANT	\N	PRESENT	0
615013	613311	01058X	PARTICIPANT	\N	PRESENT	0
615014	613311	19695N	PARTICIPANT	\N	PRESENT	0
615015	613311	99004R	PARTICIPANT	\N	PRESENT	0
615016	613311	20134Y	PARTICIPANT	\N	PRESENT	0
615017	613311	14026U	PARTICIPANT	\N	PRESENT	0
615018	613311	11033F	PARTICIPANT	\N	PRESENT	0
615019	613311	11101A	PARTICIPANT	\N	PRESENT	0
615020	613311	95063L	PARTICIPANT	\N	PRESENT	0
615021	613311	20106U	PARTICIPANT	\N	PRESENT	0
615022	613311	19651A	PARTICIPANT	\N	PRESENT	0
615023	613311	10015M	PARTICIPANT	\N	PRESENT	0
615024	613311	20128B	PARTICIPANT	\N	PRESENT	0
615025	613311	19349W	PARTICIPANT	\N	PRESENT	0
615026	613311	19301E	PARTICIPANT	\N	PRESENT	0
615027	613311	20146D	PARTICIPANT	\N	PRESENT	0
615028	613311	19697Q	PARTICIPANT	\N	PRESENT	0
615029	613311	20086J	PARTICIPANT	\N	PRESENT	0
615030	613311	19545Y	PARTICIPANT	\N	PRESENT	0
615031	613311	20050V	PARTICIPANT	\N	PRESENT	0
615032	613311	14111D	PARTICIPANT	\N	PRESENT	0
615033	613311	19723Y	PARTICIPANT	\N	PRESENT	0
615034	613311	19563B	PARTICIPANT	\N	PRESENT	0
615035	613311	04057K	PARTICIPANT	\N	PRESENT	0
615036	613311	19467C	PARTICIPANT	\N	PRESENT	0
615037	613311	19443T	PARTICIPANT	\N	PRESENT	0
615038	613311	14207L	PARTICIPANT	\N	PRESENT	0
615039	613311	19553Y	PARTICIPANT	\N	PRESENT	0
615040	613311	20056C	PARTICIPANT	\N	PRESENT	0
615041	613311	20180F	PARTICIPANT	\N	PRESENT	0
615042	613311	20026V	PARTICIPANT	\N	PRESENT	0
615043	613311	19717B	PARTICIPANT	\N	PRESENT	0
615044	613311	07029T	PARTICIPANT	\N	PRESENT	0
615045	613311	01028R	PARTICIPANT	\N	PRESENT	0
615046	613311	04059M	PARTICIPANT	\N	PRESENT	0
606199	606197	05008E	PARTICIPANT	\N	PRESENT	0
606200	606197	11053K	PARTICIPANT	\N	PRESENT	0
606201	606197	01028R	PARTICIPANT	\N	PRESENT	0
606268	601486	19717B	PRESIDENT	0	PRESENT	0
606269	601486	97011G	PARTICIPANT	\N	PRESENT	0
606270	601486	19691J	PARTICIPANT	\N	PRESENT	0
606271	601486	20034V	PARTICIPANT	\N	PRESENT	0
606272	601486	14097Y	PARTICIPANT	\N	PRESENT	0
606273	601486	20148F	PARTICIPANT	\N	PRESENT	0
606274	601486	20146D	PARTICIPANT	\N	PRESENT	0
606276	601486	14059S	PARTICIPANT	\N	PRESENT	0
606277	601486	14147R	PARTICIPANT	\N	PRESENT	0
606283	601484	07029T	PARTICIPANT	\N	EXCUSE	0
607207	607206	14193X	PARTICIPANT	\N	PRESENT	0
611669	608712	14259Y	PARTICIPANT	\N	EXCUSE	0
611986	610675	14133K	PARTICIPANT	\N	PRESENT	0
611988	610675	01024M	PARTICIPANT	\N	PRESENT	0
611989	610675	08056B	PARTICIPANT	\N	PRESENT	0
611990	610675	14097Y	PARTICIPANT	\N	PRESENT	0
611992	610675	14331P	PARTICIPANT	\N	PRESENT	0
614020	612404	19691J	PARTICIPANT	\N	PRESENT	0
614021	612404	19798U	PARTICIPANT	\N	PRESENT	0
614022	612404	10006L	PRESIDENT	0	PRESENT	0
614025	612404	19723Y	PARTICIPANT	\N	PRESENT	0
614026	612404	20090E	PARTICIPANT	\N	PRESENT	0
614045	612404	19367Y	PARTICIPANT	\N	PRESENT	0
614215	612404	20116W	PARTICIPANT	\N	PRESENT	0
614209	612404	20172F	PARTICIPANT	\N	PRESENT	0
614210	612404	11097X	PARTICIPANT	\N	PRESENT	0
614211	612404	20040T	PARTICIPANT	\N	PRESENT	0
614212	612404	19295A	PARTICIPANT	\N	EXCUSE	0
614214	612404	19667J	PARTICIPANT	\N	PRESENT	0
614216	612404	20086J	PARTICIPANT	\N	PRESENT	0
614217	612404	20070A	PARTICIPANT	\N	PRESENT	0
614218	612404	14327T	PARTICIPANT	\N	PRESENT	0
614219	612404	01057W	PARTICIPANT	\N	PRESENT	0
614220	612404	11048N	PARTICIPANT	\N	PRESENT	0
614221	612404	14121F	PARTICIPANT	\N	PRESENT	0
614222	612404	20126Y	PARTICIPANT	\N	PRESENT	0
614223	612404	19711U	PARTICIPANT	\N	PRESENT	0
614224	612404	08010L	PARTICIPANT	\N	PRESENT	0
614225	612404	08009T	PARTICIPANT	\N	PRESENT	0
614226	612404	19349W	PARTICIPANT	\N	PRESENT	0
614227	612404	14225N	PARTICIPANT	\N	PRESENT	0
614228	612404	20044X	PARTICIPANT	\N	PRESENT	0
614229	612404	19479G	PARTICIPANT	\N	PRESENT	0
614230	612404	14173T	PARTICIPANT	\N	PRESENT	0
614231	612404	14219Q	PARTICIPANT	\N	PRESENT	0
614232	612404	20118Y	PARTICIPANT	\N	PRESENT	0
614233	612404	20038A	PARTICIPANT	\N	PRESENT	0
614234	612404	14031R	PARTICIPANT	\N	PRESENT	0
614235	612404	17229F	PARTICIPANT	\N	PRESENT	0
614236	612404	20032T	PARTICIPANT	\N	PRESENT	0
614237	612404	19820Y	PARTICIPANT	\N	PRESENT	0
614239	612404	18083K	PARTICIPANT	\N	PRESENT	0
614240	612404	20102Q	PARTICIPANT	\N	PRESENT	0
614241	612404	05012A	PARTICIPANT	\N	PRESENT	0
614242	612404	19701S	PARTICIPANT	\N	PRESENT	0
614243	612404	19387D	PARTICIPANT	\N	PRESENT	0
614244	612404	19503N	PARTICIPANT	\N	PRESENT	0
614245	612404	19549D	PARTICIPANT	\N	PRESENT	0
614246	612404	19333N	PARTICIPANT	\N	PRESENT	0
614247	612404	20046A	PARTICIPANT	\N	PRESENT	0
614248	612404	14169X	PARTICIPANT	\N	PRESENT	0
614249	612404	17367Q	PARTICIPANT	\N	PRESENT	0
614250	612404	19745F	PARTICIPANT	\N	PRESENT	0
614251	612404	11101A	PARTICIPANT	\N	PRESENT	0
614252	612404	11065P	PARTICIPANT	\N	PRESENT	0
614253	612404	19826F	PARTICIPANT	\N	PRESENT	0
614254	612404	19525U	PARTICIPANT	\N	PRESENT	0
614255	612404	20068G	PARTICIPANT	\N	PRESENT	0
614256	612404	20024T	PARTICIPANT	\N	PRESENT	0
614309	612404	19631V	PARTICIPANT	\N	PRESENT	0
614310	612404	20078J	PARTICIPANT	\N	PRESENT	0
614311	612404	20088L	PARTICIPANT	\N	PRESENT	0
614312	612404	19747H	PARTICIPANT	\N	PRESENT	0
614318	612404	19383Y	PARTICIPANT	\N	PRESENT	0
614319	612404	19782L	PARTICIPANT	\N	PRESENT	0
614320	612404	14207L	PARTICIPANT	\N	PRESENT	0
614321	612404	14038Y	PARTICIPANT	\N	PRESENT	0
614322	612404	08028W	PARTICIPANT	\N	PRESENT	0
614323	612404	19507S	PARTICIPANT	\N	PRESENT	0
614324	612404	14187A	PARTICIPANT	\N	PRESENT	0
614325	612404	20174H	PARTICIPANT	\N	PRESENT	0
614328	612404	20034V	PARTICIPANT	\N	PRESENT	0
614329	612404	14205J	PARTICIPANT	\N	PRESENT	0
614331	612404	19441R	PARTICIPANT	\N	PRESENT	0
614333	612404	20028X	PARTICIPANT	\N	PRESENT	0
614334	612404	19369B	PARTICIPANT	\N	PRESENT	0
614336	612404	14257W	PARTICIPANT	\N	PRESENT	0
614338	612404	19768N	PARTICIPANT	\N	PRESENT	0
614340	612404	20030R	PARTICIPANT	\N	PRESENT	0
614341	612404	11090Q	PARTICIPANT	\N	PRESENT	0
614343	612404	20082E	PARTICIPANT	\N	PRESENT	0
614345	612404	20054A	PARTICIPANT	\N	PRESENT	0
614346	612404	04045F	PARTICIPANT	\N	PRESENT	0
614348	612404	20062A	PARTICIPANT	\N	PRESENT	0
614668	614666	04047H	PARTICIPANT	\N	PRESENT	0
614669	614666	11066Q	PARTICIPANT	\N	PRESENT	0
614672	614666	14299H	PARTICIPANT	\N	PRESENT	0
614673	614666	14053L	PARTICIPANT	\N	PRESENT	0
614674	614666	04042C	PARTICIPANT	\N	PRESENT	0
614676	614675	14299H	PARTICIPANT	\N	PRESENT	0
614678	614675	11066Q	PARTICIPANT	\N	PRESENT	0
614783	612404	19543W	PARTICIPANT	\N	PRESENT	0
614784	612404	20022R	PARTICIPANT	\N	PRESENT	0
614785	612404	19954N	PARTICIPANT	\N	PRESENT	0
614786	612404	20110Q	PARTICIPANT	\N	PRESENT	0
614787	612404	14089Y	PARTICIPANT	\N	PRESENT	0
614788	612404	04047H	PARTICIPANT	\N	PRESENT	0
614789	612404	14053L	PARTICIPANT	\N	PRESENT	0
614790	612404	19629C	PARTICIPANT	\N	PRESENT	0
614791	612404	14215L	PARTICIPANT	\N	PRESENT	0
614792	612404	14151M	PARTICIPANT	\N	PRESENT	0
614793	612404	07004J	PARTICIPANT	\N	PRESENT	0
614794	612404	20128B	PARTICIPANT	\N	PRESENT	0
614795	612404	19447X	PARTICIPANT	\N	PRESENT	0
614796	612404	14021P	PARTICIPANT	\N	PRESENT	0
614797	612404	19489J	PARTICIPANT	\N	PRESENT	0
614798	612404	14111D	PARTICIPANT	\N	PRESENT	0
614799	612404	14001X	PARTICIPANT	\N	PRESENT	0
614800	612404	10015M	PARTICIPANT	\N	PRESENT	0
614801	612404	95063L	PARTICIPANT	\N	PRESENT	0
614802	612404	19585H	PARTICIPANT	\N	PRESENT	0
615870	610746	14259Y	PARTICIPANT	\N	PRESENT	0
615871	610746	19673G	PARTICIPANT	\N	PRESENT	0
615872	610746	17023S	PARTICIPANT	\N	PRESENT	0
615873	610746	97011G	PARTICIPANT	\N	PRESENT	0
615874	610746	19691J	PARTICIPANT	\N	EXCUSE	0
615875	610746	20034V	PARTICIPANT	\N	PRESENT	0
615876	610746	19715Y	PARTICIPANT	\N	PRESENT	0
615877	610746	14097Y	PARTICIPANT	\N	PRESENT	1
615878	610746	14059S	PARTICIPANT	\N	EXCUSE	0
615879	610746	14147R	PARTICIPANT	\N	PRESENT	0
615880	610746	11072N	PARTICIPANT	\N	PRESENT	0
615881	610746	20148F	PARTICIPANT	\N	PRESENT	0
615882	610746	20146D	PARTICIPANT	\N	PRESENT	0
615883	610746	19319Q	PARTICIPANT	\N	PRESENT	1
615884	610746	20150Y	PARTICIPANT	\N	PRESENT	0
615887	610746	19747H	PARTICIPANT	\N	PRESENT	0
615888	610746	11056N	PARTICIPANT	\N	PRESENT	0
615889	610746	19399H	PARTICIPANT	\N	PRESENT	0
615890	610746	20044X	PARTICIPANT	\N	PRESENT	0
615891	610746	11097X	PARTICIPANT	\N	PRESENT	0
615946	614875	14195A	PARTICIPANT	\N	EXCUSE	0
615947	614875	08028W	PARTICIPANT	\N	EXCUSE	0
615948	614875	20040T	PARTICIPANT	\N	EXCUSE	0
615949	614875	20126Y	PARTICIPANT	\N	EXCUSE	0
615950	614875	19866P	PARTICIPANT	\N	EXCUSE	0
615954	615953	19251M	PARTICIPANT	\N	PRESENT	0
615955	615953	19467C	PARTICIPANT	\N	PRESENT	0
615956	615953	14083S	PARTICIPANT	\N	PRESENT	0
615957	615953	14030Q	PARTICIPANT	\N	PRESENT	0
615958	615953	19671E	PARTICIPANT	\N	PRESENT	0
615959	615953	14329V	PARTICIPANT	\N	PRESENT	0
615960	615953	19515S	PRESIDENT	0	PRESENT	0
615961	615953	19762G	PARTICIPANT	\N	PRESENT	0
611741	610750	20082E	PARTICIPANT	\N	PRESENT	0
611742	610750	19489J	PARTICIPANT	\N	PRESENT	0
611743	610750	20030R	PARTICIPANT	\N	PRESENT	0
611744	610750	20142Y	PARTICIPANT	\N	PRESENT	0
611745	610750	19687N	PARTICIPANT	\N	PRESENT	0
611746	610750	11056N	PARTICIPANT	\N	PRESENT	0
611747	610750	19760E	PARTICIPANT	\N	PRESENT	0
611748	610750	12041X	PARTICIPANT	\N	PRESENT	0
611749	610750	14257W	PARTICIPANT	\N	PRESENT	0
611750	610750	20028X	PARTICIPANT	\N	PRESENT	0
611751	610750	01062T	PARTICIPANT	\N	PRESENT	0
611752	610750	11072N	PARTICIPANT	\N	PRESENT	0
611753	610750	20114U	PARTICIPANT	\N	PRESENT	0
611754	610750	20116W	PARTICIPANT	\N	PRESENT	0
611755	610750	19820Y	PARTICIPANT	\N	PRESENT	0
611756	610750	19503N	PARTICIPANT	\N	PRESENT	0
611757	610750	20106U	PARTICIPANT	\N	PRESENT	0
611758	610750	19866P	PARTICIPANT	\N	PRESENT	0
611759	610750	11070L	PARTICIPANT	\N	PRESENT	0
611760	610750	14189C	PARTICIPANT	\N	PRESENT	0
611761	610750	01043Q	PARTICIPANT	\N	PRESENT	0
611762	610750	20040T	PARTICIPANT	\N	PRESENT	0
611763	610750	17965H	PARTICIPANT	\N	PRESENT	0
611764	610750	19301E	PARTICIPANT	\N	PRESENT	0
611765	610750	19782L	PARTICIPANT	\N	PRESENT	0
611766	610750	19525U	PARTICIPANT	\N	PRESENT	0
611767	610750	20174H	PARTICIPANT	\N	PRESENT	0
611768	610750	19695N	PARTICIPANT	\N	PRESENT	0
611769	610750	95063L	PARTICIPANT	\N	PRESENT	0
611770	610750	14211G	PARTICIPANT	\N	PRESENT	0
611771	610750	19565D	PARTICIPANT	\N	PRESENT	0
611772	610750	17637T	PARTICIPANT	\N	PRESENT	0
611773	610750	11077T	PARTICIPANT	\N	PRESENT	0
611774	610750	04035D	PARTICIPANT	\N	PRESENT	0
611775	610750	18083K	PARTICIPANT	\N	PRESENT	0
611776	610750	20046A	PARTICIPANT	\N	PRESENT	0
611777	610750	01058X	PARTICIPANT	\N	PRESENT	0
611778	610750	20266L	PARTICIPANT	\N	PRESENT	0
611779	610750	99004R	PARTICIPANT	\N	PRESENT	0
611780	610750	14026U	PARTICIPANT	\N	PRESENT	0
611781	610750	20130U	PARTICIPANT	\N	PRESENT	0
611782	610750	08010L	PARTICIPANT	\N	PRESENT	0
611783	610750	04047H	PARTICIPANT	\N	PRESENT	0
611784	610750	01028R	PARTICIPANT	\N	PRESENT	0
611785	610750	08034U	PARTICIPANT	\N	PRESENT	0
611786	610750	11027H	PARTICIPANT	\N	PRESENT	0
611788	610750	14225N	PARTICIPANT	\N	PRESENT	0
611789	610750	04092N	PARTICIPANT	\N	PRESENT	0
611790	610750	04059M	PARTICIPANT	\N	PRESENT	0
611792	610750	11048N	PARTICIPANT	\N	PRESENT	0
611793	610750	19649G	PARTICIPANT	\N	PRESENT	0
611795	610750	14021P	PARTICIPANT	\N	PRESENT	0
611796	610750	04042C	PARTICIPANT	\N	PRESENT	0
611799	610750	14229S	PARTICIPANT	\N	PRESENT	0
611800	610750	19647E	PARTICIPANT	\N	PRESENT	0
611802	610750	19333N	PARTICIPANT	\N	PRESENT	0
611803	610750	20074E	PARTICIPANT	\N	PRESENT	0
611805	610750	20076G	PARTICIPANT	\N	PRESENT	0
611808	610750	19669L	PARTICIPANT	\N	PRESENT	0
611810	610750	14133K	PARTICIPANT	\N	PRESENT	0
611812	610750	08045X	PARTICIPANT	\N	PRESENT	0
611814	610750	17367Q	PARTICIPANT	\N	PRESENT	0
611815	610750	19643A	PARTICIPANT	\N	PRESENT	0
611817	610750	20070A	PARTICIPANT	\N	PRESENT	0
611819	610750	14169X	PARTICIPANT	\N	PRESENT	0
611821	610750	14109K	PARTICIPANT	\N	PRESENT	0
611822	610750	14281W	PARTICIPANT	\N	PRESENT	0
611824	610750	10015M	PARTICIPANT	\N	PRESENT	0
611825	610750	11043H	PARTICIPANT	\N	PRESENT	0
611827	610750	08028W	PARTICIPANT	\N	PRESENT	0
611829	610750	11066Q	PARTICIPANT	\N	PRESENT	0
611830	610750	04033B	PARTICIPANT	\N	PRESENT	0
611831	610750	20084G	PARTICIPANT	\N	PRESENT	0
611833	610750	19725B	PARTICIPANT	\N	PRESENT	0
611834	610750	14187A	PARTICIPANT	\N	PRESENT	0
611836	610750	11031D	PARTICIPANT	\N	PRESENT	0
611837	610750	19531S	PARTICIPANT	\N	PRESENT	0
611839	610750	14071N	PARTICIPANT	\N	PRESENT	0
611840	610750	20060X	PARTICIPANT	\N	PRESENT	0
611842	610750	14215L	PARTICIPANT	\N	PRESENT	0
611843	610750	20018V	PARTICIPANT	\N	PRESENT	0
611844	610750	12028B	PARTICIPANT	\N	PRESENT	0
611845	610750	19701S	PARTICIPANT	\N	PRESENT	0
611846	610750	14069U	PARTICIPANT	\N	PRESENT	0
611847	610750	19295A	PARTICIPANT	\N	PRESENT	0
611849	610750	19631V	PARTICIPANT	\N	PRESENT	0
611850	610750	20264J	PARTICIPANT	\N	PRESENT	0
611851	610750	11090Q	PARTICIPANT	\N	PRESENT	0
611852	610750	19251M	PARTICIPANT	\N	PRESENT	0
611853	610750	19551W	PARTICIPANT	\N	PRESENT	0
611854	610750	20064C	PARTICIPANT	\N	PRESENT	0
611855	610750	01057W	PARTICIPANT	\N	PRESENT	0
611856	610750	19766L	PARTICIPANT	\N	PRESENT	0
611857	610750	19515S	PARTICIPANT	\N	PRESENT	0
611858	610750	20038A	PARTICIPANT	\N	PRESENT	0
611859	610750	19673G	PARTICIPANT	\N	PRESENT	0
611860	610750	14031R	PARTICIPANT	\N	PRESENT	0
611861	610750	19667J	PARTICIPANT	\N	PRESENT	0
611862	610750	14253S	PARTICIPANT	\N	PRESENT	0
611863	610750	20134Y	PARTICIPANT	\N	PRESENT	0
611864	610750	19954N	PARTICIPANT	\N	PRESENT	0
611865	610750	20092G	PARTICIPANT	\N	PRESENT	0
611866	610750	19651A	PARTICIPANT	\N	PRESENT	0
611867	610750	20118Y	PARTICIPANT	\N	PRESENT	0
611868	610750	08061X	PARTICIPANT	\N	PRESENT	0
611869	610750	19533U	PARTICIPANT	\N	PRESENT	0
611870	610750	10006L	PARTICIPANT	\N	PRESENT	0
611871	610750	04045F	PARTICIPANT	\N	PRESENT	0
611872	610750	19591F	PARTICIPANT	\N	PRESENT	0
611873	610750	20252E	PARTICIPANT	\N	PRESENT	0
611874	610750	20120S	PARTICIPANT	\N	PRESENT	0
611875	610750	19329S	PARTICIPANT	\N	PRESENT	0
611876	610750	14193X	PARTICIPANT	\N	PRESENT	0
611877	610750	14249W	PARTICIPANT	\N	PRESENT	0
611878	610750	19581D	PARTICIPANT	\N	PRESENT	0
611879	610750	19671E	PARTICIPANT	\N	PRESENT	0
611880	610750	11033F	PARTICIPANT	\N	PRESENT	0
611881	610750	14055N	PARTICIPANT	\N	PRESENT	0
611882	610750	19367Y	PARTICIPANT	\N	PRESENT	0
611883	610750	11065P	PARTICIPANT	\N	PRESENT	0
611884	610750	19621T	PARTICIPANT	\N	PRESENT	0
611885	610750	07033P	PARTICIPANT	\N	PRESENT	0
611886	610750	11103C	PARTICIPANT	\N	PRESENT	0
611887	610750	97011G	PARTICIPANT	\N	PRESENT	0
611888	610750	14357A	PARTICIPANT	\N	PRESENT	0
611889	610750	19762G	PARTICIPANT	\N	PRESENT	0
611890	610750	20054A	PARTICIPANT	\N	PRESENT	0
611891	610750	20126Y	PARTICIPANT	\N	PRESENT	0
611892	610750	11083R	PARTICIPANT	\N	PRESENT	0
611893	610750	20124W	PARTICIPANT	\N	PRESENT	0
611894	610750	19553Y	PARTICIPANT	\N	PRESENT	0
611895	610750	20072C	PARTICIPANT	\N	PRESENT	0
611896	610750	08056B	PARTICIPANT	\N	PRESENT	0
611897	610750	19717B	PARTICIPANT	\N	PRESENT	0
611898	610750	04071H	PARTICIPANT	\N	PRESENT	0
611899	610750	19387D	PARTICIPANT	\N	PRESENT	0
611904	610750	20122U	PARTICIPANT	\N	PRESENT	0
611901	610750	14059S	PARTICIPANT	\N	PRESENT	0
611902	610750	20132W	PARTICIPANT	\N	PRESENT	0
611903	610750	19545Y	PARTICIPANT	\N	PRESENT	0
611905	610750	17589D	PARTICIPANT	\N	PRESENT	0
611906	610750	14195A	PARTICIPANT	\N	PRESENT	0
611907	610750	04057K	PARTICIPANT	\N	PRESENT	0
611908	610750	19707Y	PARTICIPANT	\N	PRESENT	0
611909	610750	19705W	PARTICIPANT	\N	PRESENT	0
611910	610750	20024T	PARTICIPANT	\N	PRESENT	0
611911	610750	20050V	PARTICIPANT	\N	PRESENT	0
611912	610750	08047A	PARTICIPANT	\N	PRESENT	0
611913	610750	20172F	PARTICIPANT	\N	PRESENT	0
611914	610750	01060R	PARTICIPANT	\N	PRESENT	0
611915	610750	20140W	PARTICIPANT	\N	PRESENT	0
611916	610750	19399H	PARTICIPANT	\N	PRESENT	0
611917	610750	20052X	PARTICIPANT	\N	PRESENT	0
611918	610750	14147R	PARTICIPANT	\N	PRESENT	0
611919	610750	19441R	PARTICIPANT	\N	PRESENT	0
611920	610750	16685X	PARTICIPANT	\N	PRESENT	0
611921	610750	11053K	PARTICIPANT	\N	PRESENT	0
611922	610750	14042U	PARTICIPANT	\N	PRESENT	0
611923	610750	20042V	PARTICIPANT	\N	PRESENT	0
611924	610750	19447X	PARTICIPANT	\N	PRESENT	0
611925	610750	19573D	PARTICIPANT	\N	PRESENT	0
604819	602939	19691J	PARTICIPANT	\N	PRESENT	0
604820	602939	14223L	PARTICIPANT	\N	PRESENT	0
604821	602939	10006L	PRESIDENT	0	PRESENT	0
604822	602258	01028R	PARTICIPANT	\N	PRESENT	0
604823	602258	17737W	PARTICIPANT	\N	PRESENT	0
604824	602258	14107H	PARTICIPANT	\N	PRESENT	0
604825	602258	14215L	PARTICIPANT	\N	PRESENT	0
604826	602258	04085P	PARTICIPANT	\N	PRESENT	0
604827	603129	20086J	PARTICIPANT	\N	PRESENT	0
604828	603129	14331P	PARTICIPANT	\N	PRESENT	0
604829	603129	20036X	PARTICIPANT	\N	PRESENT	0
604830	603129	19711U	PARTICIPANT	\N	PRESENT	0
604831	603129	01057W	PARTICIPANT	\N	PRESENT	0
604832	603129	20080C	PARTICIPANT	\N	PRESENT	0
604833	603129	20050V	PARTICIPANT	\N	PRESENT	0
604834	603129	19667J	PARTICIPANT	\N	PRESENT	0
604835	603129	20044X	PARTICIPANT	\N	PRESENT	0
604836	603129	11070L	PARTICIPANT	\N	PRESENT	0
604837	603129	19671E	PARTICIPANT	\N	PRESENT	0
604838	603129	18083K	PARTICIPANT	\N	PRESENT	0
604839	603129	14083S	PARTICIPANT	\N	PRESENT	0
604840	603129	11012A	PARTICIPANT	\N	PRESENT	0
604841	603129	20070A	PARTICIPANT	\N	PRESENT	0
604842	603129	14253S	PARTICIPANT	\N	PRESENT	0
604843	603129	99004R	PARTICIPANT	\N	PRESENT	0
604844	603129	20126Y	PARTICIPANT	\N	PRESENT	0
604845	602939	20130U	PARTICIPANT	\N	PRESENT	0
604846	602939	19697Q	PARTICIPANT	\N	PRESENT	0
604847	602939	04092N	PARTICIPANT	\N	PRESENT	0
604848	602939	19713W	PARTICIPANT	\N	PRESENT	0
604849	602939	19798U	PARTICIPANT	\N	PRESENT	0
604850	602939	11097X	PARTICIPANT	\N	PRESENT	0
604851	602939	08045X	PARTICIPANT	\N	PRESENT	0
604852	602939	19415P	PARTICIPANT	\N	PRESENT	0
604853	602939	18193Q	PARTICIPANT	\N	PRESENT	0
604854	602939	19679N	PARTICIPANT	\N	PRESENT	0
604855	602939	14071N	PARTICIPANT	\N	PRESENT	0
604856	602939	20040T	PARTICIPANT	\N	PRESENT	0
604857	602939	14042U	PARTICIPANT	\N	PRESENT	0
604858	602939	14026U	PARTICIPANT	\N	PRESENT	0
604859	603129	07029T	PARTICIPANT	\N	PRESENT	0
604860	603129	19531S	PARTICIPANT	\N	PRESENT	0
604861	603129	11040E	PARTICIPANT	\N	PRESENT	0
604862	603129	14225N	PRESIDENT	0	PRESENT	0
604863	603054	19766L	PARTICIPANT	\N	PRESENT	0
604864	603054	19533U	PARTICIPANT	\N	PRESENT	0
604865	603054	01060R	PARTICIPANT	\N	PRESENT	0
604866	603054	14229S	PARTICIPANT	\N	PRESENT	0
604867	603054	20098N	PARTICIPANT	\N	PRESENT	0
604868	603054	20112S	PARTICIPANT	\N	PRESENT	0
604869	603054	20124W	PARTICIPANT	\N	PRESENT	0
604870	603054	20026V	PARTICIPANT	\N	PRESENT	0
604871	603054	19593H	PARTICIPANT	\N	PRESENT	0
604872	603054	20132W	PARTICIPANT	\N	PRESENT	0
604873	603054	19643A	PARTICIPANT	\N	PRESENT	0
604874	603054	14073Q	PARTICIPANT	\N	PRESENT	0
604875	603054	19651A	PARTICIPANT	\N	PRESENT	0
604876	603054	19611R	PRESIDENT	0	PRESENT	0
604877	603054	20142Y	PARTICIPANT	\N	PRESENT	0
604878	603054	19399H	PARTICIPANT	\N	PRESENT	0
604879	603054	20052X	PARTICIPANT	\N	PRESENT	0
604880	603054	19719D	PARTICIPANT	\N	PRESENT	0
604881	603054	14030Q	PARTICIPANT	\N	PRESENT	0
604882	603054	20056C	PARTICIPANT	\N	PRESENT	0
604883	603054	20180F	PARTICIPANT	\N	PRESENT	0
604884	603054	04059M	PARTICIPANT	\N	PRESENT	0
604885	603054	20264J	PARTICIPANT	\N	PRESENT	0
604886	603054	14123H	PARTICIPANT	\N	PRESENT	0
604887	603054	11104D	PARTICIPANT	\N	PRESENT	0
604888	603054	19758L	PARTICIPANT	\N	PRESENT	0
604889	603054	20152B	PARTICIPANT	\N	PRESENT	0
604890	603054	11109J	PARTICIPANT	\N	EXCUSE	0
604891	603129	04071H	PARTICIPANT	\N	PRESENT	0
604892	603129	08034U	PARTICIPANT	\N	PRESENT	0
604893	603129	19741B	PARTICIPANT	\N	PRESENT	0
604894	603129	19762G	PARTICIPANT	\N	PRESENT	0
604895	603129	11074Q	PARTICIPANT	\N	EXCUSE	0
604896	602258	19543W	PARTICIPANT	\N	PRESENT	0
604897	602258	19581D	PARTICIPANT	\N	PRESENT	0
604898	602258	11056N	PARTICIPANT	\N	PRESENT	0
604899	603054	14109K	PARTICIPANT	\N	PRESENT	0
604900	603054	92040Q	PARTICIPANT	\N	PRESENT	0
604901	603054	11043H	PARTICIPANT	\N	PRESENT	0
604902	603054	20134Y	PARTICIPANT	\N	PRESENT	0
604903	603054	08012N	PARTICIPANT	\N	PRESENT	0
604904	603054	20048C	PARTICIPANT	\N	PRESENT	0
604906	603129	19647E	PARTICIPANT	\N	PRESENT	0
604907	604905	19333N	PARTICIPANT	\N	PRESENT	0
604908	604905	19549D	PARTICIPANT	\N	PRESENT	0
604909	604905	20076G	PARTICIPANT	\N	PRESENT	0
604910	604905	19387D	PARTICIPANT	\N	PRESENT	0
604911	604905	14219Q	PRESIDENT	0	PRESENT	0
604912	604905	19826F	PARTICIPANT	\N	PRESENT	0
604913	604905	19599P	PARTICIPANT	\N	PRESENT	0
604914	604905	14237S	PARTICIPANT	\N	PRESENT	0
604915	604905	20100N	PARTICIPANT	\N	PRESENT	0
604916	604905	18083K	PARTICIPANT	\N	PRESENT	0
604917	604905	20106U	PARTICIPANT	\N	PRESENT	0
604918	604905	08060W	PARTICIPANT	\N	PRESENT	0
604919	604905	20118Y	PARTICIPANT	\N	PRESENT	0
604920	604905	19503N	PARTICIPANT	\N	PRESENT	0
604921	604905	20020P	PARTICIPANT	\N	PRESENT	0
604922	604905	17367Q	PARTICIPANT	\N	PRESENT	0
604923	604905	20024T	PARTICIPANT	\N	PRESENT	0
604924	604905	19525U	PARTICIPANT	\N	PRESENT	0
604925	604905	14031R	PARTICIPANT	\N	PRESENT	0
604926	604905	20038A	PARTICIPANT	\N	PRESENT	0
604927	604905	19251M	PARTICIPANT	\N	PRESENT	0
604928	604905	20046A	PARTICIPANT	\N	PRESENT	0
604929	604905	17229F	PARTICIPANT	\N	PRESENT	0
604930	604905	20068G	PARTICIPANT	\N	PRESENT	0
604931	604905	11101A	PARTICIPANT	\N	PRESENT	0
604932	604905	19745F	PARTICIPANT	\N	PRESENT	0
604933	604905	19659J	PARTICIPANT	\N	PRESENT	0
604934	602258	05008E	PARTICIPANT	\N	PRESENT	0
604935	602258	11085T	PARTICIPANT	\N	PRESENT	0
604936	604905	20120S	PARTICIPANT	\N	PRESENT	0
604937	604905	20140W	PARTICIPANT	\N	PRESENT	0
604938	604905	20096L	PARTICIPANT	\N	PRESENT	0
604939	603054	04070G	PARTICIPANT	\N	PRESENT	0
604940	604905	19701S	PARTICIPANT	\N	EXCUSE	0
604941	602258	20108W	PARTICIPANT	\N	PRESENT	0
604942	602258	14053L	PARTICIPANT	\N	PRESENT	0
604943	602258	19649G	PARTICIPANT	\N	PRESENT	0
604944	604905	20102Q	PARTICIPANT	\N	PRESENT	0
604945	604905	14221J	PARTICIPANT	\N	PRESENT	0
604951	604905	11065P	PARTICIPANT	\N	PRESENT	0
604957	603054	20266L	PARTICIPANT	\N	PRESENT	0
604960	603054	19573D	PARTICIPANT	\N	PRESENT	0
604962	604905	19685L	PARTICIPANT	\N	PRESENT	0
604963	604905	19820Y	PARTICIPANT	\N	PRESENT	0
604964	602939	19553Y	PARTICIPANT	\N	PRESENT	0
604965	602939	19717B	PARTICIPANT	\N	PRESENT	0
604966	603129	19349W	PARTICIPANT	\N	PRESENT	0
604967	603129	19479G	PARTICIPANT	\N	PRESENT	0
604968	603129	19689Q	PARTICIPANT	\N	PRESENT	0
604969	603129	12016W	PARTICIPANT	\N	PRESENT	0
604970	604905	19681G	PARTICIPANT	\N	PRESENT	0
604971	602258	14111D	PARTICIPANT	\N	PRESENT	0
604972	603129	01048V	PARTICIPANT	\N	PRESENT	0
604973	604905	20136B	PARTICIPANT	\N	PRESENT	0
604974	602258	14021P	PARTICIPANT	\N	PRESENT	0
604975	603129	11048N	PARTICIPANT	\N	PRESENT	0
604976	604490	19383Y	PARTICIPANT	\N	PRESENT	0
604977	604490	20088L	PARTICIPANT	\N	PRESENT	0
604978	604490	19768N	PARTICIPANT	\N	PRESENT	0
604979	604490	19515S	PARTICIPANT	\N	PRESENT	0
604980	604490	19782L	PARTICIPANT	\N	PRESENT	0
604981	604490	20092G	PARTICIPANT	\N	PRESENT	0
604982	604490	11077T	PARTICIPANT	\N	PRESENT	0
604983	604490	14357A	PARTICIPANT	\N	PRESENT	0
604984	604490	20078J	PARTICIPANT	\N	PRESENT	0
604985	604490	19441R	PARTICIPANT	\N	PRESENT	0
604986	604490	19413M	PARTICIPANT	\N	PRESENT	0
604987	604490	20094J	PARTICIPANT	\N	PRESENT	0
604988	604490	04045F	PARTICIPANT	\N	PRESENT	0
604989	604490	19631V	PARTICIPANT	\N	PRESENT	0
604990	604490	20104S	PARTICIPANT	\N	PRESENT	0
604991	604490	11099A	PARTICIPANT	\N	PRESENT	0
604992	604490	19705W	PARTICIPANT	\N	PRESENT	0
604993	604490	19707Y	PARTICIPANT	\N	PRESENT	0
615047	613311	04071H	PARTICIPANT	\N	PRESENT	0
615048	613311	14257W	PARTICIPANT	\N	PRESENT	0
615049	613311	19667J	PARTICIPANT	\N	PRESENT	0
615050	613311	19715Y	PARTICIPANT	\N	PRESENT	0
615051	613311	19599P	PARTICIPANT	\N	PRESENT	0
615052	613311	14021P	PARTICIPANT	\N	PRESENT	0
615053	613311	14229S	PARTICIPANT	\N	PRESENT	0
615054	613311	14001X	PARTICIPANT	\N	PRESENT	0
615055	613311	11031D	PARTICIPANT	\N	PRESENT	0
615056	613311	19760E	PARTICIPANT	\N	PRESENT	0
615057	613311	20096L	PARTICIPANT	\N	PRESENT	0
615058	613311	19741B	PARTICIPANT	\N	PRESENT	0
615059	613311	19551W	PARTICIPANT	\N	PRESENT	0
615060	613311	19549D	PARTICIPANT	\N	PRESENT	0
615061	613311	11041F	PARTICIPANT	\N	PRESENT	0
615062	613311	19954N	PARTICIPANT	\N	PRESENT	0
615063	613311	19820Y	PARTICIPANT	\N	PRESENT	0
615064	613311	20084G	PARTICIPANT	\N	PRESENT	0
615065	613311	20104S	PARTICIPANT	\N	PRESENT	0
615066	613311	14109K	PARTICIPANT	\N	PRESENT	0
615067	613311	20114U	PARTICIPANT	\N	PRESENT	0
615068	613311	20094J	PARTICIPANT	\N	PRESENT	0
615069	613311	19719D	PARTICIPANT	\N	PRESENT	0
615070	613311	20140W	PARTICIPANT	\N	PRESENT	0
615071	613311	19413M	PARTICIPANT	\N	PRESENT	0
615072	613311	19705W	PARTICIPANT	\N	PRESENT	0
615073	613311	19503N	PARTICIPANT	\N	PRESENT	0
615074	613311	19531S	PARTICIPANT	\N	PRESENT	0
615075	613311	19707Y	PARTICIPANT	\N	PRESENT	0
615076	613311	18193Q	PARTICIPANT	\N	PRESENT	0
615077	613311	19768N	PARTICIPANT	\N	PRESENT	0
615078	613311	20082E	PARTICIPANT	\N	PRESENT	0
615079	613311	19347U	PARTICIPANT	\N	PRESENT	0
615080	613311	19631V	PARTICIPANT	\N	PRESENT	0
615081	613311	19489J	PARTICIPANT	\N	PRESENT	0
615082	613311	20024T	PARTICIPANT	\N	PRESENT	0
615083	613311	19649G	PARTICIPANT	\N	PRESENT	0
615084	613311	19333N	PARTICIPANT	\N	PRESENT	0
615085	613311	08012N	PARTICIPANT	\N	PRESENT	0
615086	613311	11026G	PARTICIPANT	\N	PRESENT	0
615087	613311	01057W	PARTICIPANT	\N	PRESENT	0
615088	613311	20032T	PARTICIPANT	\N	PRESENT	0
615089	613311	19758L	PARTICIPANT	\N	PRESENT	0
615090	613311	11043H	PARTICIPANT	\N	PRESENT	0
615091	613311	14189C	PARTICIPANT	\N	PRESENT	0
615092	613311	19441R	PARTICIPANT	\N	PRESENT	0
615093	613311	20052X	PARTICIPANT	\N	PRESENT	0
615094	613311	04042C	PARTICIPANT	\N	PRESENT	0
615095	613311	19721W	PARTICIPANT	\N	PRESENT	0
615096	613311	19735D	PARTICIPANT	\N	PRESENT	0
615097	613311	14205J	PARTICIPANT	\N	PRESENT	0
615098	613311	11053K	PARTICIPANT	\N	PRESENT	0
615099	613311	17637T	PARTICIPANT	\N	PRESENT	0
615100	613311	08009T	PARTICIPANT	\N	PRESENT	0
615101	613311	14231L	PARTICIPANT	\N	PRESENT	0
615102	613311	19691J	PARTICIPANT	\N	PRESENT	0
615103	613311	17229F	PARTICIPANT	\N	PRESENT	0
615104	613311	19611R	PARTICIPANT	\N	PRESENT	0
615105	613311	08010L	PARTICIPANT	\N	PRESENT	0
615106	613311	20040T	PARTICIPANT	\N	PRESENT	0
615107	613311	14073Q	PARTICIPANT	\N	PRESENT	0
615108	613311	14255U	PARTICIPANT	\N	PRESENT	0
615109	613311	08034U	PARTICIPANT	\N	PRESENT	0
615110	613311	01043Q	PARTICIPANT	\N	PRESENT	0
615111	613311	11048N	PARTICIPANT	\N	PRESENT	0
615112	613311	20248J	PARTICIPANT	\N	PRESENT	0
615113	613311	14327T	PARTICIPANT	\N	PRESENT	0
615114	613311	14187A	PARTICIPANT	\N	PRESENT	0
615115	613311	04033B	PARTICIPANT	\N	PRESENT	0
615116	613311	14030Q	PARTICIPANT	\N	PRESENT	0
615117	613311	11097X	PARTICIPANT	\N	PRESENT	0
615118	613311	19826F	PARTICIPANT	\N	PRESENT	0
615119	613311	20174H	PARTICIPANT	\N	PRESENT	0
615120	613311	14215L	PARTICIPANT	\N	PRESENT	0
615121	613311	17023S	PARTICIPANT	\N	PRESENT	0
615122	613311	01025N	PARTICIPANT	\N	PRESENT	0
615123	613311	20070A	PARTICIPANT	\N	PRESENT	0
615187	613311	19585H	PARTICIPANT	\N	PRESENT	0
615125	613311	19745F	PARTICIPANT	\N	PRESENT	0
615126	613311	14217N	PARTICIPANT	\N	PRESENT	0
615127	613311	20120S	PARTICIPANT	\N	PRESENT	0
615128	613311	20088L	PARTICIPANT	\N	PRESENT	0
615185	613311	19367Y	PARTICIPANT	\N	PRESENT	0
615179	613311	20044X	PARTICIPANT	\N	PRESENT	0
615131	613311	20020P	PARTICIPANT	\N	PRESENT	0
615132	613311	20126Y	PARTICIPANT	\N	PRESENT	0
615133	613311	20124W	PARTICIPANT	\N	PRESENT	0
615134	613311	19762G	PARTICIPANT	\N	PRESENT	0
615135	613311	17779H	PARTICIPANT	\N	PRESENT	0
615136	613311	14357A	PARTICIPANT	\N	PRESENT	0
615137	613311	08056B	PARTICIPANT	\N	PRESENT	0
615138	613311	14147R	PARTICIPANT	\N	PRESENT	0
615139	613311	17737W	PARTICIPANT	\N	PRESENT	0
615140	613311	19447X	PARTICIPANT	\N	PRESENT	0
615141	613311	20058E	PARTICIPANT	\N	PRESENT	0
615142	613311	97011G	PARTICIPANT	\N	PRESENT	0
615143	613311	19575F	PARTICIPANT	\N	PRESENT	0
615144	613311	20062A	PARTICIPANT	\N	PRESENT	0
615145	613311	20038A	PARTICIPANT	\N	PRESENT	0
615182	613311	19711U	PARTICIPANT	\N	PRESENT	0
615147	613311	19533U	PARTICIPANT	\N	PRESENT	0
615148	613311	19709B	PARTICIPANT	\N	PRESENT	0
615150	613311	08018U	PARTICIPANT	\N	PRESENT	0
615184	613311	14069U	PARTICIPANT	\N	PRESENT	0
615159	613311	14033T	PARTICIPANT	\N	PRESENT	0
615157	613311	14059S	PARTICIPANT	\N	PRESENT	0
615158	613311	20064C	PARTICIPANT	\N	PRESENT	0
615160	613311	19671E	PARTICIPANT	\N	PRESENT	0
615161	613311	20266L	PARTICIPANT	\N	PRESENT	0
615162	613311	14213J	PARTICIPANT	\N	PRESENT	0
615163	613311	04085P	PARTICIPANT	\N	PRESENT	0
615164	613311	20054A	PARTICIPANT	\N	PRESENT	0
615165	613311	14225N	PARTICIPANT	\N	PRESENT	0
615166	613311	14055N	PARTICIPANT	\N	PRESENT	0
615167	613311	01060R	PARTICIPANT	\N	PRESENT	0
615181	613311	20098N	PARTICIPANT	\N	PRESENT	0
615169	613311	20048C	PARTICIPANT	\N	PRESENT	0
615170	613311	16685X	PARTICIPANT	\N	PRESENT	0
615171	613311	19369B	PARTICIPANT	\N	PRESENT	0
615172	613311	20092G	PARTICIPANT	\N	PRESENT	0
615173	613311	14249W	PARTICIPANT	\N	PRESENT	0
615174	613311	01062T	PARTICIPANT	\N	PRESENT	0
615175	613311	14121F	PARTICIPANT	\N	PRESENT	0
615176	613311	14083S	PARTICIPANT	\N	PRESENT	0
615177	613311	11012A	PARTICIPANT	\N	PRESENT	0
615178	613311	10006L	PARTICIPANT	\N	PRESENT	0
615186	613311	14331P	PARTICIPANT	\N	PRESENT	0
615188	613311	19749K	PARTICIPANT	\N	PRESENT	0
615189	613070	20118Y	PARTICIPANT	\N	PRESENT	0
615190	613070	20038A	PARTICIPANT	\N	PRESENT	0
615191	613070	14031R	PARTICIPANT	\N	PRESENT	0
615192	613070	17229F	PARTICIPANT	\N	PRESENT	0
615193	613311	11115U	PARTICIPANT	\N	PRESENT	0
615194	613070	20032T	PARTICIPANT	\N	PRESENT	0
615195	613070	19820Y	PARTICIPANT	\N	PRESENT	0
615196	613070	18083K	PARTICIPANT	\N	PRESENT	0
615197	613070	20102Q	PARTICIPANT	\N	PRESENT	0
615198	613311	20080C	PARTICIPANT	\N	PRESENT	0
615199	613070	05012A	PARTICIPANT	\N	PRESENT	0
615200	613311	08069G	PARTICIPANT	\N	PRESENT	0
615201	613070	19701S	PARTICIPANT	\N	PRESENT	0
615202	613070	19387D	PARTICIPANT	\N	PRESENT	0
615203	613070	19503N	PARTICIPANT	\N	PRESENT	0
615204	613070	19549D	PARTICIPANT	\N	PRESENT	0
615205	613070	19333N	PARTICIPANT	\N	PRESENT	0
615206	613070	20046A	PARTICIPANT	\N	PRESENT	0
615207	613070	14169X	PARTICIPANT	\N	PRESENT	0
615208	613070	17367Q	PARTICIPANT	\N	PRESENT	0
615209	613070	19745F	PARTICIPANT	\N	PRESENT	0
615210	613070	11101A	PARTICIPANT	\N	PRESENT	0
615211	613070	11065P	PARTICIPANT	\N	PRESENT	0
615212	613070	19826F	PARTICIPANT	\N	PRESENT	0
615213	613070	19525U	PARTICIPANT	\N	PRESENT	0
615214	613070	20068G	PARTICIPANT	\N	PRESENT	0
615215	613070	20024T	PARTICIPANT	\N	PRESENT	0
615219	613311	19543W	PARTICIPANT	\N	PRESENT	0
615217	613311	14169X	PARTICIPANT	\N	PRESENT	0
615218	613311	14123H	PARTICIPANT	\N	PRESENT	0
615220	613311	08073C	PARTICIPANT	\N	PRESENT	0
615221	613311	08045X	PARTICIPANT	\N	PRESENT	0
615222	613311	20136B	PARTICIPANT	\N	PRESENT	0
601686	601685	19711U	PARTICIPANT	\N	PRESENT	0
601687	601685	11040E	PARTICIPANT	\N	PRESENT	0
601688	601685	19479G	PARTICIPANT	\N	PRESENT	0
601689	601685	11056N	PARTICIPANT	\N	PRESENT	0
601690	601685	20050V	PARTICIPANT	\N	PRESENT	0
601691	601685	14193X	PARTICIPANT	\N	PRESENT	0
601692	601685	20144B	PARTICIPANT	\N	PRESENT	0
601693	601685	19551W	PARTICIPANT	\N	PRESENT	0
601694	601685	20032T	PARTICIPANT	\N	PRESENT	0
601696	601685	04071H	PARTICIPANT	\N	PRESENT	0
601697	601685	14259Y	PRESIDENT	0	PRESENT	0
601698	601685	19643A	PARTICIPANT	\N	EXCUSE	0
601699	601685	99004R	PARTICIPANT	\N	EXCUSE	0
601700	601685	19747H	PARTICIPANT	\N	EXCUSE	0
601701	601685	19399H	PARTICIPANT	\N	EXCUSE	0
601702	601685	19954N	PARTICIPANT	\N	EXCUSE	0
601703	601685	11065P	PARTICIPANT	\N	EXCUSE	0
601704	601685	01028R	PARTICIPANT	\N	EXCUSE	0
601705	601685	20018V	PARTICIPANT	\N	EXCUSE	0
606494	606493	14033T	PARTICIPANT	\N	PRESENT	0
606495	606493	12041X	PARTICIPANT	\N	PRESENT	0
606509	606230	20066E	PARTICIPANT	\N	EXCUSE	0
607864	607863	20064C	PARTICIPANT	\N	PRESENT	0
607872	607865	19503N	PARTICIPANT	\N	PRESENT	0
607874	607873	19701S	PARTICIPANT	\N	PRESENT	0
607875	607873	20064C	PARTICIPANT	\N	PRESENT	0
607878	607877	14255U	PARTICIPANT	\N	PRESENT	0
607879	607877	19585H	PARTICIPANT	\N	PRESENT	0
607880	607877	10015M	PARTICIPANT	\N	PRESENT	0
607881	607877	20120S	PARTICIPANT	\N	PRESENT	0
607882	607877	19329S	PARTICIPANT	\N	PRESENT	0
607883	607877	19826F	PARTICIPANT	\N	PRESENT	0
607884	607877	20106U	PARTICIPANT	\N	PRESENT	0
607885	607877	11027H	PARTICIPANT	\N	PRESENT	0
607886	607877	18083K	PARTICIPANT	\N	PRESENT	0
608350	606857	11099A	PARTICIPANT	\N	PRESENT	0
608351	606857	11077T	PARTICIPANT	\N	PRESENT	0
608596	608595	05008E	PARTICIPANT	\N	PRESENT	0
608597	608595	11053K	PARTICIPANT	\N	PRESENT	0
608598	608595	01028R	PARTICIPANT	\N	PRESENT	0
610530	610523	20104S	PARTICIPANT	\N	PRESENT	0
610531	610523	20180F	PARTICIPANT	\N	PRESENT	0
610537	610533	20104S	PARTICIPANT	\N	PRESENT	0
610538	610533	14053L	PARTICIPANT	\N	PRESENT	0
610539	610533	20180F	PARTICIPANT	\N	PRESENT	0
610540	610533	14030Q	PARTICIPANT	\N	PRESENT	0
610543	610542	20104S	PARTICIPANT	\N	PRESENT	0
610596	610594	11083R	PARTICIPANT	\N	PRESENT	0
610609	610595	11083R	PARTICIPANT	\N	PRESENT	0
613777	613773	08034U	PARTICIPANT	\N	PRESENT	0
613803	613802	14151M	PARTICIPANT	\N	PRESENT	0
613824	613823	19673G	PARTICIPANT	\N	PRESENT	0
613825	613823	20114U	PARTICIPANT	\N	PRESENT	0
613841	613840	19673G	PARTICIPANT	\N	PRESENT	0
613842	613840	19573D	PARTICIPANT	\N	PRESENT	0
615962	615953	19575F	PARTICIPANT	\N	PRESENT	0
615963	615953	14105F	PARTICIPANT	\N	PRESENT	0
615964	615953	08015R	PARTICIPANT	\N	PRESENT	0
615965	615953	20092G	PARTICIPANT	\N	PRESENT	0
615966	615953	20048C	PARTICIPANT	\N	PRESENT	0
615967	615953	20094J	PARTICIPANT	\N	PRESENT	0
615968	615953	16685X	PARTICIPANT	\N	PRESENT	0
615970	615953	19545Y	PARTICIPANT	\N	PRESENT	0
615971	615953	20060X	PARTICIPANT	\N	EXCUSE	0
615972	615953	14195A	PARTICIPANT	\N	EXCUSE	0
615973	615953	08028W	PARTICIPANT	\N	EXCUSE	0
615974	615953	14357A	PARTICIPANT	\N	PRESENT	0
615975	615953	20040T	PARTICIPANT	\N	PRESENT	0
615976	615953	20126Y	PARTICIPANT	\N	PRESENT	0
615977	615953	20108W	PARTICIPANT	\N	PRESENT	0
615978	615953	19866P	PARTICIPANT	\N	PRESENT	0
615979	615953	20082E	PARTICIPANT	\N	EXCUSE	0
616405	610805	18083K	PARTICIPANT	\N	PRESENT	0
616431	616275	11056N	PRESIDENT	0	PRESENT	0
616448	616447	11048N	PARTICIPANT	\N	PRESENT	0
616449	616447	08011M	PARTICIPANT	\N	PRESENT	0
616453	616275	95063L	PARTICIPANT	\N	PRESENT	0
616454	616275	05008E	PARTICIPANT	\N	EXCUSE	0
616456	616275	20108W	PARTICIPANT	\N	PRESENT	0
616459	616275	19749K	PARTICIPANT	\N	PRESENT	0
616462	616275	14089Y	PARTICIPANT	\N	PRESENT	0
616465	616275	20098N	PARTICIPANT	\N	PRESENT	0
616466	616275	20024T	PARTICIPANT	\N	PRESENT	0
616468	616275	20040T	PARTICIPANT	\N	PRESENT	0
616490	616275	19826F	PARTICIPANT	\N	PRESENT	0
616496	616275	14225N	PARTICIPANT	\N	PRESENT	0
616500	616275	11026G	PARTICIPANT	\N	PRESENT	0
616504	616275	17367Q	PARTICIPANT	\N	PRESENT	0
616510	616275	08045X	PARTICIPANT	\N	PRESENT	1
616527	616275	14107H	PARTICIPANT	\N	PRESENT	1
617187	616238	11056N	PARTICIPANT	\N	PRESENT	1
616796	616795	20094J	PARTICIPANT	\N	PRESENT	0
617186	616238	19489J	PARTICIPANT	\N	PRESENT	1
617196	617194	19798U	PARTICIPANT	\N	PRESENT	0
617197	617194	17965H	PARTICIPANT	\N	PRESENT	0
617198	617194	19367Y	PARTICIPANT	\N	PRESENT	0
617199	617195	19798U	PARTICIPANT	\N	PRESENT	0
617200	617195	17965H	PARTICIPANT	\N	PRESENT	0
617201	617195	19367Y	PARTICIPANT	\N	PRESENT	0
617202	617195	20090E	PARTICIPANT	\N	PRESENT	0
617796	616280	19713W	PARTICIPANT	\N	PRESENT	0
617797	616280	20248J	PARTICIPANT	\N	PRESENT	0
617807	616280	10006L	PRESIDENT	0	PRESENT	0
617805	616280	20040T	PARTICIPANT	\N	PRESENT	0
617806	616280	14213J	PARTICIPANT	\N	PRESENT	0
617808	616280	04092N	PARTICIPANT	\N	EXCUSE	0
617811	616280	19798U	PARTICIPANT	\N	PRESENT	0
617812	616280	19367Y	PARTICIPANT	\N	PRESENT	0
617813	616280	17965H	PARTICIPANT	\N	PRESENT	0
617815	616280	20130U	PARTICIPANT	\N	PRESENT	0
617816	616280	19301E	PARTICIPANT	\N	PRESENT	0
617817	616280	11067R	PARTICIPANT	\N	PRESENT	0
617819	616280	11097X	PARTICIPANT	\N	PRESENT	0
617825	616280	19679N	PARTICIPANT	\N	PRESENT	0
617845	616280	19415P	PARTICIPANT	\N	PRESENT	0
617846	616280	19760E	PARTICIPANT	\N	PRESENT	1
617849	616280	14217N	PARTICIPANT	\N	PRESENT	0
617877	616280	19723Y	PARTICIPANT	\N	PRESENT	0
618320	618319	04047H	PARTICIPANT	\N	PRESENT	0
618321	618319	04042C	PARTICIPANT	\N	PRESENT	0
618322	618319	14053L	PARTICIPANT	\N	PRESENT	0
618323	618319	11066Q	PARTICIPANT	\N	PRESENT	0
618511	618408	10006L	PARTICIPANT	\N	PRESENT	0
618512	618408	11031D	PARTICIPANT	\N	PRESENT	0
618513	618408	19713W	PARTICIPANT	\N	PRESENT	1
618514	618408	20130U	PARTICIPANT	\N	PRESENT	1
618515	618408	14147R	PARTICIPANT	\N	PRESENT	1
618516	618510	10006L	PARTICIPANT	\N	PRESENT	0
618517	618510	19713W	PARTICIPANT	\N	PRESENT	1
618518	618510	11031D	PARTICIPANT	\N	PRESENT	0
618519	618510	14147R	PARTICIPANT	\N	PRESENT	1
618520	618510	20130U	PARTICIPANT	\N	PRESENT	1
618521	618510	19553Y	PARTICIPANT	\N	PRESENT	1
619840	619638	20112S	PARTICIPANT	\N	PRESENT	1
619830	618370	08045X	PARTICIPANT	\N	EXCUSE	0
619839	619638	11109J	PARTICIPANT	\N	EXCUSE	0
619841	619638	19651A	PARTICIPANT	\N	PRESENT	1
619842	619638	14030Q	PARTICIPANT	\N	PRESENT	0
619843	619638	19643A	PARTICIPANT	\N	PRESENT	0
619844	619638	19758L	PARTICIPANT	\N	PRESENT	0
619845	619638	19693L	PARTICIPANT	\N	PRESENT	0
619846	619638	20134Y	PARTICIPANT	\N	PRESENT	1
619847	619638	20124W	PARTICIPANT	\N	PRESENT	0
619848	619638	20132W	PARTICIPANT	\N	PRESENT	0
619849	619638	20172F	PARTICIPANT	\N	PRESENT	0
619850	619638	14123H	PARTICIPANT	\N	PRESENT	0
619851	619638	19399H	PARTICIPANT	\N	PRESENT	0
619853	619638	20056C	PARTICIPANT	\N	PRESENT	1
619854	619638	14073Q	PARTICIPANT	\N	PRESENT	0
619856	619638	19611R	PRESIDENT	0	PRESENT	0
619858	619638	19735D	PARTICIPANT	\N	PRESENT	1
619860	619638	19699S	PARTICIPANT	\N	PRESENT	0
619862	619638	20052X	PARTICIPANT	\N	PRESENT	0
611926	610750	19699S	PARTICIPANT	\N	PRESENT	0
611927	610750	19713W	PARTICIPANT	\N	PRESENT	0
611928	610750	20026V	PARTICIPANT	\N	PRESENT	0
611929	610750	19479G	PARTICIPANT	\N	PRESENT	0
611930	610750	19741B	PARTICIPANT	\N	PRESENT	0
611931	610750	08015R	PARTICIPANT	\N	PRESENT	0
611932	610750	19739H	PARTICIPANT	\N	PRESENT	0
611933	610750	92040Q	PARTICIPANT	\N	PRESENT	0
611934	610750	20096L	PARTICIPANT	\N	PRESENT	0
611935	610750	14219Q	PARTICIPANT	\N	PRESENT	0
611936	610750	19657G	PARTICIPANT	\N	PRESENT	0
611937	610750	19735D	PARTICIPANT	\N	PRESENT	0
611938	610750	20144B	PARTICIPANT	\N	PRESENT	0
611939	610750	14123H	PARTICIPANT	\N	PRESENT	0
611940	610750	08009T	PARTICIPANT	\N	PRESENT	0
611941	610750	19467C	PARTICIPANT	\N	PRESENT	0
611942	610750	20066E	PARTICIPANT	\N	PRESENT	0
611943	610750	19611R	PARTICIPANT	\N	PRESENT	0
611944	610750	20056C	PARTICIPANT	\N	PRESENT	0
611945	610750	14038Y	PARTICIPANT	\N	PRESENT	0
611946	610750	17229F	PARTICIPANT	\N	PRESENT	0
611947	610750	14327T	PARTICIPANT	\N	PRESENT	0
611948	610750	20044X	PARTICIPANT	\N	PRESENT	0
611949	610750	19663E	PARTICIPANT	\N	PRESENT	0
611950	610750	19745F	PARTICIPANT	\N	PRESENT	0
611951	610750	19709B	PARTICIPANT	\N	PRESENT	0
611952	610750	14033T	PARTICIPANT	\N	PRESENT	0
611953	610750	17023S	PARTICIPANT	\N	PRESENT	0
611954	610750	14083S	PARTICIPANT	\N	PRESENT	0
611955	610750	14089Y	PARTICIPANT	\N	PRESENT	0
611956	610750	14205J	PARTICIPANT	\N	PRESENT	0
611957	610750	14255U	PARTICIPANT	\N	PRESENT	0
611958	610750	19723Y	PARTICIPANT	\N	PRESENT	0
611959	610750	11085T	PARTICIPANT	\N	PRESENT	0
611960	610750	86034E	PARTICIPANT	\N	PRESENT	0
611961	610750	19577H	PARTICIPANT	\N	PRESENT	0
611962	610750	20180F	PARTICIPANT	\N	PRESENT	0
611963	610750	20148F	PARTICIPANT	\N	PRESENT	0
611964	610750	01024M	PARTICIPANT	\N	PRESENT	0
611965	610750	14329V	PARTICIPANT	\N	PRESENT	0
611966	610750	05012A	PARTICIPANT	\N	PRESENT	0
611967	610750	12016W	PARTICIPANT	\N	PRESENT	0
611968	610750	19768N	PARTICIPANT	\N	PRESENT	0
611969	610750	19697Q	PARTICIPANT	\N	PRESENT	0
611970	610750	20104S	PARTICIPANT	\N	PRESENT	0
611971	610750	14030Q	PARTICIPANT	\N	PRESENT	0
611972	610750	19543W	PARTICIPANT	\N	PRESENT	0
611973	610750	14213J	PARTICIPANT	\N	PRESENT	0
611974	610750	05008E	PARTICIPANT	\N	PRESENT	0
611975	610750	20108W	PARTICIPANT	\N	PRESENT	0
611976	610750	08018U	PARTICIPANT	\N	PRESENT	0
611977	610750	20112S	PARTICIPANT	\N	PRESENT	0
611978	610750	11097X	PARTICIPANT	\N	PRESENT	0
611979	610750	04085P	PARTICIPANT	\N	PRESENT	0
611980	610750	11012A	PARTICIPANT	\N	PRESENT	0
611981	610750	20048C	PARTICIPANT	\N	PRESENT	0
611982	610750	19685L	PARTICIPANT	\N	PRESENT	0
611983	610750	20110Q	PARTICIPANT	\N	PRESENT	0
611984	610750	20248J	PARTICIPANT	\N	PRESENT	0
611985	610750	19057M	PARTICIPANT	\N	PRESENT	0
611987	610750	08012N	PARTICIPANT	\N	PRESENT	0
611991	610750	20150Y	PARTICIPANT	\N	PRESENT	0
611993	610750	20036X	PARTICIPANT	\N	PRESENT	0
611994	610750	19507S	PARTICIPANT	\N	PRESENT	0
612313	610751	11070L	PARTICIPANT	\N	PRESENT	0
612314	610672	11056N	PARTICIPANT	\N	PRESENT	0
612315	610672	20022R	PARTICIPANT	\N	PRESENT	0
612316	610672	04047H	PRESIDENT	0	PRESENT	0
612317	610672	08018U	PARTICIPANT	\N	PRESENT	0
612319	610751	11031D	PARTICIPANT	\N	PRESENT	0
612320	610751	20130U	PARTICIPANT	\N	PRESENT	0
612322	610672	10015M	PARTICIPANT	\N	PRESENT	0
612323	610751	17589D	PARTICIPANT	\N	PRESENT	0
612324	610751	19479G	PARTICIPANT	\N	PRESENT	0
612538	610751	20092G	PARTICIPANT	\N	PRESENT	0
612328	610751	18193Q	PARTICIPANT	\N	PRESENT	0
612539	610751	14069U	PARTICIPANT	\N	PRESENT	0
612537	610751	19441R	PARTICIPANT	\N	PRESENT	0
612541	612540	19782L	PARTICIPANT	\N	PRESENT	0
612542	612540	05008E	PARTICIPANT	\N	PRESENT	0
612543	612540	14030Q	PARTICIPANT	\N	PRESENT	0
612544	612540	14083S	PARTICIPANT	\N	PRESENT	0
612545	612540	08045X	PARTICIPANT	\N	PRESENT	0
612546	612540	20180F	PARTICIPANT	\N	PRESENT	0
612547	612540	20104S	PARTICIPANT	\N	PRESENT	0
612548	612540	14213J	PARTICIPANT	\N	PRESENT	0
612549	612540	14221J	PARTICIPANT	\N	PRESENT	0
612550	610751	14187A	PARTICIPANT	\N	PRESENT	0
612551	610751	20052X	PARTICIPANT	\N	PRESENT	0
612552	608646	14053L	PARTICIPANT	\N	PRESENT	0
612553	608646	11056N	PARTICIPANT	\N	PRESENT	0
612554	608646	20074E	PARTICIPANT	\N	PRESENT	0
612555	608646	14215L	PARTICIPANT	\N	PRESENT	0
612556	608646	04047H	PRESIDENT	0	PRESENT	0
612606	610752	01043Q	PARTICIPANT	\N	PRESENT	0
612607	610752	19747H	PARTICIPANT	\N	PRESENT	0
612608	610752	19441R	PARTICIPANT	\N	PRESENT	0
612609	610752	20052X	PARTICIPANT	\N	PRESENT	0
612610	610752	19369B	PARTICIPANT	\N	PRESENT	0
612611	610752	19713W	PARTICIPANT	\N	PRESENT	0
612612	610752	17589D	PARTICIPANT	\N	PRESENT	0
612613	610752	19782L	PARTICIPANT	\N	PRESENT	0
612614	610752	20092G	PARTICIPANT	\N	PRESENT	0
612615	610752	20130U	PARTICIPANT	\N	PRESENT	0
612616	610752	08045X	PARTICIPANT	\N	PRESENT	0
612617	610752	19631V	PARTICIPANT	\N	PRESENT	0
612618	610752	20030R	PARTICIPANT	\N	PRESENT	0
612619	610752	18193Q	PARTICIPANT	\N	PRESENT	0
612620	610752	19820Y	PARTICIPANT	\N	PRESENT	0
612621	610752	20078J	PARTICIPANT	\N	PRESENT	0
612622	610752	11031D	PARTICIPANT	\N	PRESENT	0
612623	610752	19798U	PARTICIPANT	\N	PRESENT	0
612624	610752	11097X	PARTICIPANT	\N	PRESENT	0
612625	610752	19565D	PARTICIPANT	\N	PRESENT	0
612626	610752	20046A	PARTICIPANT	\N	PRESENT	0
612627	610752	14069U	PARTICIPANT	\N	PRESENT	0
612628	610752	20118Y	PARTICIPANT	\N	PRESENT	0
612629	610752	19723Y	PARTICIPANT	\N	PRESENT	0
612630	610752	14033T	PARTICIPANT	\N	PRESENT	0
612631	610752	20088L	PARTICIPANT	\N	PRESENT	0
612632	610752	20068G	PARTICIPANT	\N	PRESENT	0
612633	610752	11067R	PARTICIPANT	\N	PRESENT	0
612634	610752	19507S	PARTICIPANT	\N	PRESENT	0
612635	610752	20062A	PARTICIPANT	\N	PRESENT	0
612636	610752	20144B	PARTICIPANT	\N	PRESENT	0
612637	610752	11012A	PARTICIPANT	\N	PRESENT	0
612638	610752	19866P	PARTICIPANT	\N	PRESENT	0
612640	610752	20048C	PARTICIPANT	\N	PRESENT	0
612641	610752	14217N	PARTICIPANT	\N	PRESENT	0
612642	610752	20086J	PARTICIPANT	\N	PRESENT	0
612643	610752	20090E	PARTICIPANT	\N	PRESENT	0
612644	610752	17965H	PARTICIPANT	\N	PRESENT	0
612645	610752	20174H	PARTICIPANT	\N	PRESENT	0
612646	610752	14257W	PARTICIPANT	\N	PRESENT	0
612647	610752	18083K	PARTICIPANT	\N	PRESENT	0
612648	610752	19691J	PARTICIPANT	\N	PRESENT	0
612649	610752	20180F	PARTICIPANT	\N	PRESENT	0
612650	610752	19383Y	PARTICIPANT	\N	PRESENT	0
612651	610752	20018V	PARTICIPANT	\N	PRESENT	0
612652	610752	14169X	PARTICIPANT	\N	PRESENT	0
612653	610752	20024T	PARTICIPANT	\N	PRESENT	0
612604	610752	11070L	PARTICIPANT	\N	PRESENT	0
612605	610752	14187A	PARTICIPANT	\N	PRESENT	0
612655	612654	20104S	PARTICIPANT	\N	PRESENT	0
612656	612654	19782L	PARTICIPANT	\N	PRESENT	0
612657	610752	17023S	PARTICIPANT	\N	PRESENT	0
612658	612654	20144B	PARTICIPANT	\N	PRESENT	0
612659	612654	19507S	PARTICIPANT	\N	PRESENT	0
612660	610752	08056B	PARTICIPANT	\N	PRESENT	0
612661	610752	20038A	PARTICIPANT	\N	PRESENT	0
612662	610752	20054A	PARTICIPANT	\N	PRESENT	0
612663	610752	20058E	PARTICIPANT	\N	PRESENT	0
612672	610752	14111D	PARTICIPANT	\N	PRESENT	0
612673	610752	20060X	PARTICIPANT	\N	PRESENT	0
612674	608646	19673G	PARTICIPANT	\N	PRESENT	0
612675	608646	01028R	PARTICIPANT	\N	PRESENT	0
612676	608646	14231L	PARTICIPANT	\N	PRESENT	0
612677	608646	19489J	PARTICIPANT	\N	PRESENT	0
612678	608646	95063L	PARTICIPANT	\N	PRESENT	0
612679	608646	14147R	PARTICIPANT	\N	PRESENT	0
612680	608646	20022R	PARTICIPANT	\N	PRESENT	0
600201	600200	14111D	PARTICIPANT	\N	PRESENT	0
604994	604490	08015R	PARTICIPANT	\N	PRESENT	0
604995	604490	19575F	PARTICIPANT	\N	PRESENT	0
604996	604490	19369B	PARTICIPANT	\N	PRESENT	0
604997	604490	20018V	PARTICIPANT	\N	PRESENT	0
604998	604490	19511N	PARTICIPANT	\N	PRESENT	0
604999	604490	19563B	PARTICIPANT	\N	PRESENT	0
605000	604490	08028W	PARTICIPANT	\N	PRESENT	0
605001	604490	14329V	PARTICIPANT	\N	PRESENT	0
605002	604490	20028X	PARTICIPANT	\N	PRESENT	0
605003	604490	20030R	PARTICIPANT	\N	PRESENT	0
605004	604490	14038Y	PARTICIPANT	\N	PRESENT	0
605005	604490	19467C	PARTICIPANT	\N	PRESENT	0
605006	604490	20034V	PARTICIPANT	\N	PRESENT	0
605007	604490	14187A	PARTICIPANT	\N	PRESENT	0
605008	604490	20144B	PARTICIPANT	\N	PRESENT	0
605009	604490	19695N	PARTICIPANT	\N	PRESENT	0
605010	604490	14033T	PARTICIPANT	\N	PRESENT	0
605011	604490	11090Q	PRESIDENT	0	PRESENT	0
605012	604490	01025N	PARTICIPANT	\N	PRESENT	0
605013	604490	20054A	PARTICIPANT	\N	PRESENT	0
605014	604490	20174H	PARTICIPANT	\N	PRESENT	0
605015	604490	14205J	PARTICIPANT	\N	PRESENT	0
605016	604490	20062A	PARTICIPANT	\N	PRESENT	0
605017	604490	14251Q	PARTICIPANT	\N	PRESENT	0
605018	604490	19507S	PARTICIPANT	\N	PRESENT	0
605019	604490	19747H	PARTICIPANT	\N	PRESENT	0
605020	604490	14207L	PARTICIPANT	\N	PRESENT	0
605021	603054	04033B	PARTICIPANT	\N	PRESENT	0
605022	603054	20138D	PARTICIPANT	\N	PRESENT	0
605023	604905	19577H	PARTICIPANT	\N	PRESENT	0
605024	604905	05012A	PARTICIPANT	\N	PRESENT	0
605025	604905	20032T	PARTICIPANT	\N	PRESENT	0
605026	603054	19735D	PARTICIPANT	\N	PRESENT	0
605027	602939	11031D	PARTICIPANT	\N	PRESENT	0
605028	602939	04057K	PARTICIPANT	\N	PRESENT	0
605029	602939	17965H	PARTICIPANT	\N	PRESENT	0
605030	604905	19551W	PARTICIPANT	\N	PRESENT	0
605031	603129	19335Q	PARTICIPANT	\N	PRESENT	0
605032	602566	19443T	PARTICIPANT	\N	PRESENT	0
605033	602566	95041E	PARTICIPANT	\N	PRESENT	0
605034	602566	11080N	PARTICIPANT	\N	PRESENT	0
605035	602566	19565D	PARTICIPANT	\N	PRESENT	0
605036	602566	20072C	PARTICIPANT	\N	PRESENT	0
605037	602566	19329S	PARTICIPANT	\N	PRESENT	0
605038	602566	01058X	PARTICIPANT	\N	PRESENT	0
605039	602566	11027H	PARTICIPANT	\N	PRESENT	0
605040	602566	16685X	PARTICIPANT	\N	PRESENT	0
605041	602566	04042C	PRESIDENT	0	PRESENT	0
605073	602566	11054L	PARTICIPANT	\N	PRESENT	0
605043	602566	19669L	PARTICIPANT	\N	PRESENT	0
605044	602566	11066Q	PARTICIPANT	\N	PRESENT	0
605045	602566	08056B	PARTICIPANT	\N	PRESENT	0
605046	602566	12028B	PARTICIPANT	\N	PRESENT	0
605047	602566	11115U	PARTICIPANT	\N	PRESENT	0
605074	602566	14055N	PARTICIPANT	\N	PRESENT	0
605049	602566	19421M	PARTICIPANT	\N	PRESENT	0
605050	602566	19709B	PARTICIPANT	\N	PRESENT	0
605051	602566	14193X	PARTICIPANT	\N	PRESENT	0
605052	602566	19347U	PARTICIPANT	\N	PRESENT	0
605053	602566	07033P	PARTICIPANT	\N	PRESENT	0
605054	602566	97011G	PARTICIPANT	\N	PRESENT	0
605055	602566	08061X	PARTICIPANT	\N	PRESENT	0
605056	602566	14249W	PARTICIPANT	\N	PRESENT	0
605057	602566	08047A	PARTICIPANT	\N	PRESENT	0
605058	602566	14059S	PARTICIPANT	\N	PRESENT	0
605059	602566	14097Y	PARTICIPANT	\N	PRESENT	0
605060	602566	01062T	PARTICIPANT	\N	PRESENT	0
605061	602566	08069G	PARTICIPANT	\N	PRESENT	0
605062	602566	11041F	PARTICIPANT	\N	PRESENT	0
605063	602566	20042V	PARTICIPANT	\N	PRESENT	0
605064	602566	01024M	PARTICIPANT	\N	PRESENT	0
605065	602566	14191V	PARTICIPANT	\N	PRESENT	0
605066	602566	19721W	PARTICIPANT	\N	PRESENT	0
605067	602566	14105F	PARTICIPANT	\N	PRESENT	0
605117	603129	19545Y	PARTICIPANT	\N	PRESENT	0
605069	602566	14267Y	PARTICIPANT	\N	PRESENT	0
605070	602566	11064N	PARTICIPANT	\N	PRESENT	0
605071	602566	11083R	PARTICIPANT	\N	PRESENT	0
605072	602566	14211G	PARTICIPANT	\N	PRESENT	0
605075	602566	20064C	PARTICIPANT	\N	PRESENT	0
605076	602567	19443T	PARTICIPANT	\N	PRESENT	0
605077	602567	95041E	PARTICIPANT	\N	PRESENT	0
605078	602567	11080N	PARTICIPANT	\N	PRESENT	0
605079	602567	19565D	PARTICIPANT	\N	PRESENT	0
605080	602567	20072C	PARTICIPANT	\N	PRESENT	0
605081	602567	19329S	PARTICIPANT	\N	PRESENT	0
605082	602567	01058X	PARTICIPANT	\N	PRESENT	0
605083	602567	11027H	PARTICIPANT	\N	PRESENT	0
605084	602567	16685X	PARTICIPANT	\N	PRESENT	0
605085	602567	04042C	PRESIDENT	0	PRESENT	0
605118	603129	08009T	PARTICIPANT	\N	EXCUSE	0
605087	602567	19669L	PARTICIPANT	\N	PRESENT	0
605088	602567	11066Q	PARTICIPANT	\N	PRESENT	0
605089	602567	08056B	PARTICIPANT	\N	PRESENT	0
605090	602567	12028B	PARTICIPANT	\N	PRESENT	0
605091	602567	11115U	PARTICIPANT	\N	PRESENT	0
605119	603147	86034E	PARTICIPANT	\N	PRESENT	0
605093	602567	19421M	PARTICIPANT	\N	PRESENT	0
605094	602567	19709B	PARTICIPANT	\N	PRESENT	0
605095	602567	14193X	PARTICIPANT	\N	PRESENT	0
605096	602567	19347U	PARTICIPANT	\N	PRESENT	0
605097	602567	07033P	PARTICIPANT	\N	PRESENT	0
605098	602567	97011G	PARTICIPANT	\N	PRESENT	0
605099	602567	08061X	PARTICIPANT	\N	PRESENT	0
605100	602567	14249W	PARTICIPANT	\N	PRESENT	0
605101	602567	08047A	PARTICIPANT	\N	PRESENT	0
605102	602567	14059S	PARTICIPANT	\N	PRESENT	0
605103	602567	14097Y	PARTICIPANT	\N	PRESENT	0
605104	602567	01062T	PARTICIPANT	\N	PRESENT	0
605105	602567	08069G	PARTICIPANT	\N	PRESENT	0
605106	602567	11041F	PARTICIPANT	\N	PRESENT	0
605107	602567	20042V	PARTICIPANT	\N	PRESENT	0
605108	602567	01024M	PARTICIPANT	\N	PRESENT	0
605109	602567	14191V	PARTICIPANT	\N	PRESENT	0
605110	602567	19721W	PARTICIPANT	\N	PRESENT	0
605111	602567	14105F	PARTICIPANT	\N	PRESENT	0
605120	603147	19569H	PARTICIPANT	\N	PRESENT	0
605113	602567	14267Y	PARTICIPANT	\N	PRESENT	0
605114	602567	11064N	PARTICIPANT	\N	PRESENT	0
605115	602567	11083R	PARTICIPANT	\N	PRESENT	0
605116	602567	14211G	PARTICIPANT	\N	PRESENT	0
605121	603147	19681G	PARTICIPANT	\N	PRESENT	0
605122	603147	14259Y	PARTICIPANT	\N	PRESENT	0
605123	603147	11080N	PARTICIPANT	\N	PRESENT	0
605124	603147	19593H	PARTICIPANT	\N	PRESENT	0
605125	603147	20102Q	PARTICIPANT	\N	PRESENT	0
605126	603147	14225N	PARTICIPANT	\N	PRESENT	0
605127	603147	20068G	PARTICIPANT	\N	PRESENT	0
605128	603147	19525U	PARTICIPANT	\N	PRESENT	0
605129	603147	19387D	PARTICIPANT	\N	PRESENT	0
605130	603147	20114U	PARTICIPANT	\N	PRESENT	0
605131	603147	12028B	PARTICIPANT	\N	PRESENT	0
605132	603147	20072C	PARTICIPANT	\N	PRESENT	0
605133	603147	19479G	PARTICIPANT	\N	PRESENT	0
605134	603147	14331P	PARTICIPANT	\N	PRESENT	0
605135	603147	19399H	PARTICIPANT	\N	PRESENT	0
605136	603147	19741B	PARTICIPANT	\N	PRESENT	0
605137	603147	14191V	PARTICIPANT	\N	PRESENT	0
605139	603147	14267Y	PARTICIPANT	\N	PRESENT	0
605140	603147	20112S	PARTICIPANT	\N	PRESENT	0
605141	603147	20084G	PARTICIPANT	\N	PRESENT	0
605142	603147	11033F	PARTICIPANT	\N	PRESENT	0
605143	603147	19798U	PARTICIPANT	\N	PRESENT	0
605144	603147	20074E	PARTICIPANT	\N	PRESENT	0
605145	603147	20144B	PARTICIPANT	\N	PRESENT	0
605146	603147	20174H	PARTICIPANT	\N	PRESENT	0
605147	603147	14053L	PARTICIPANT	\N	PRESENT	0
605149	603147	19673G	PARTICIPANT	\N	PRESENT	0
605151	603147	14059S	PARTICIPANT	\N	PRESENT	0
605152	603147	20062A	PARTICIPANT	\N	PRESENT	0
605153	603147	20090E	PARTICIPANT	\N	PRESENT	0
605154	603147	14105F	PARTICIPANT	\N	PRESENT	0
605155	603147	11103C	PARTICIPANT	\N	PRESENT	0
605156	603147	14030Q	PARTICIPANT	\N	PRESENT	0
605157	603147	92040Q	PARTICIPANT	\N	PRESENT	0
605158	603147	20056C	PARTICIPANT	\N	PRESENT	0
605159	603147	14217N	PARTICIPANT	\N	PRESENT	0
615223	613311	19591F	PARTICIPANT	\N	PRESENT	0
615509	613312	12041X	PARTICIPANT	\N	PRESENT	0
615510	613312	14195A	PARTICIPANT	\N	PRESENT	0
615511	613312	17589D	PARTICIPANT	\N	PRESENT	0
615512	613312	19479G	PARTICIPANT	\N	PRESENT	0
615513	613312	14042U	PARTICIPANT	\N	PRESENT	0
615514	613312	19467C	PARTICIPANT	\N	PRESENT	0
615515	613312	19749K	PARTICIPANT	\N	PRESENT	0
615516	613312	19679N	PARTICIPANT	\N	PRESENT	0
615664	613312	11048N	PARTICIPANT	\N	PRESENT	0
615691	613312	11056N	PARTICIPANT	\N	PRESENT	0
615669	613312	08010L	PARTICIPANT	\N	PRESENT	0
615692	613312	19581D	PARTICIPANT	\N	PRESENT	0
615693	613312	19413M	PARTICIPANT	\N	PRESENT	0
615694	613312	19762G	PARTICIPANT	\N	PRESENT	0
615695	613312	19673G	PARTICIPANT	\N	PRESENT	0
615696	613312	19503N	PARTICIPANT	\N	PRESENT	0
615697	613312	20104S	PARTICIPANT	\N	PRESENT	0
615698	613312	97011G	PARTICIPANT	\N	PRESENT	0
615699	613312	99004R	PARTICIPANT	\N	PRESENT	0
615700	613312	19782L	PARTICIPANT	\N	PRESENT	0
615701	613312	14215L	PARTICIPANT	\N	PRESENT	0
615702	613312	19691J	PARTICIPANT	\N	PRESENT	0
615703	613312	20080C	PARTICIPANT	\N	PRESENT	0
615714	613312	19741B	PARTICIPANT	\N	PRESENT	0
615715	613312	14026U	PARTICIPANT	\N	PRESENT	0
615716	613312	19681G	PARTICIPANT	\N	PRESENT	0
615717	613312	19057M	PARTICIPANT	\N	PRESENT	0
615718	613312	19399H	PARTICIPANT	\N	PRESENT	0
615719	613312	19533U	PARTICIPANT	\N	PRESENT	0
615720	613312	19553Y	PARTICIPANT	\N	PRESENT	0
615721	613312	01043Q	PARTICIPANT	\N	PRESENT	0
615764	613313	19415P	PARTICIPANT	\N	PRESENT	0
615765	613313	20090E	PARTICIPANT	\N	PRESENT	0
615766	613313	20130U	PARTICIPANT	\N	PRESENT	0
615767	613313	19782L	PARTICIPANT	\N	PRESENT	0
615768	613313	11067R	PARTICIPANT	\N	PRESENT	0
615769	613313	14195A	PARTICIPANT	\N	PRESENT	0
615770	613313	19553Y	PARTICIPANT	\N	PRESENT	0
615771	613313	19713W	PARTICIPANT	\N	PRESENT	0
615772	613313	20048C	PARTICIPANT	\N	PRESENT	0
615773	613313	14030Q	PARTICIPANT	\N	PRESENT	0
615774	613313	19760E	PARTICIPANT	\N	PRESENT	0
615775	613313	11031D	PARTICIPANT	\N	PRESENT	0
615776	613313	11097X	PARTICIPANT	\N	PRESENT	0
615777	613313	20038A	PARTICIPANT	\N	PRESENT	0
615778	613313	18083K	PARTICIPANT	\N	PRESENT	0
615779	613313	07029T	PARTICIPANT	\N	PRESENT	0
615780	613313	19717B	PARTICIPANT	\N	PRESENT	0
615781	613313	14217N	PARTICIPANT	\N	PRESENT	0
615782	613313	19447X	PARTICIPANT	\N	PRESENT	0
615783	613313	20062A	PARTICIPANT	\N	PRESENT	0
615784	613313	14026U	PARTICIPANT	\N	PRESENT	0
615785	613313	20248J	PARTICIPANT	\N	PRESENT	0
615786	613313	99004R	PARTICIPANT	\N	PRESENT	0
615787	613313	14147R	PARTICIPANT	\N	PRESENT	0
615788	613313	19591F	PARTICIPANT	\N	PRESENT	0
615789	613313	11065P	PARTICIPANT	\N	PRESENT	0
615790	613313	19691J	PARTICIPANT	\N	PRESENT	0
615791	613313	20110Q	PARTICIPANT	\N	PRESENT	0
615792	613313	18193Q	PARTICIPANT	\N	PRESENT	0
615793	613313	20180F	PARTICIPANT	\N	PRESENT	0
615794	613313	14042U	PARTICIPANT	\N	PRESENT	0
615795	613313	19503N	PARTICIPANT	\N	PRESENT	0
615796	613313	14179A	PARTICIPANT	\N	PRESENT	0
615797	613313	20024T	PARTICIPANT	\N	PRESENT	0
615798	613313	17779H	PARTICIPANT	\N	PRESENT	0
615799	613313	95041E	PARTICIPANT	\N	PRESENT	0
615800	613313	14215L	PARTICIPANT	\N	PRESENT	0
615801	613313	19741B	PARTICIPANT	\N	PRESENT	0
615821	613119	10006L	PARTICIPANT	0	PRESENT	0
615835	613119	19683J	PRESIDENT	0	PRESENT	0
615762	613313	19719D	PARTICIPANT	\N	PRESENT	0
615763	613313	10006L	PARTICIPANT	\N	PRESENT	0
615836	613119	19713W	PARTICIPANT	\N	PRESENT	0
615841	613119	19467C	PARTICIPANT	\N	PRESENT	0
615843	613119	14147R	PARTICIPANT	\N	PRESENT	0
615844	613119	11031D	PARTICIPANT	\N	PRESENT	0
615850	613119	19703U	PARTICIPANT	\N	EXCUSE	0
615851	613119	19553Y	PARTICIPANT	\N	PRESENT	0
615852	613119	19301E	PARTICIPANT	\N	PRESENT	0
615856	613119	19691J	PARTICIPANT	\N	PRESENT	0
615861	615860	05008E	PARTICIPANT	\N	PRESENT	0
615862	615860	11053K	PARTICIPANT	\N	PRESENT	0
615863	615860	01028R	PARTICIPANT	\N	PRESENT	0
616041	613119	20130U	PARTICIPANT	\N	EXCUSE	0
616042	613119	04092N	PARTICIPANT	\N	EXCUSE	0
616200	616199	20116W	PARTICIPANT	\N	PRESENT	0
616201	616199	11080N	PARTICIPANT	\N	PRESENT	0
616202	616199	19347U	PARTICIPANT	\N	PRESENT	0
616203	616199	01057W	PARTICIPANT	\N	PRESENT	0
616204	616199	14121F	PARTICIPANT	\N	PRESENT	0
616207	616199	05012A	PARTICIPANT	\N	PRESENT	0
616241	616240	19768N	PARTICIPANT	\N	PRESENT	0
616242	616240	19631V	PARTICIPANT	\N	PRESENT	0
616243	616240	19705W	PARTICIPANT	\N	PRESENT	0
616244	616240	19515S	PARTICIPANT	\N	PRESENT	0
616247	616246	14219Q	PARTICIPANT	\N	PRESENT	0
616248	616246	20140W	PARTICIPANT	\N	PRESENT	0
616249	616246	20024T	PARTICIPANT	\N	PRESENT	0
616250	616246	14221J	PARTICIPANT	\N	PRESENT	0
616251	616246	20020P	PARTICIPANT	\N	PRESENT	0
616252	616246	19599P	PARTICIPANT	\N	PRESENT	0
616253	616246	20120S	PARTICIPANT	\N	PRESENT	0
616254	616246	19637C	PARTICIPANT	\N	PRESENT	0
616255	616246	19251M	PARTICIPANT	\N	PRESENT	0
616256	616246	20068G	PARTICIPANT	\N	PRESENT	0
616257	616246	20032T	PARTICIPANT	\N	PRESENT	0
616258	616246	19685L	PARTICIPANT	\N	PRESENT	0
616259	616246	05012A	PARTICIPANT	\N	PRESENT	0
616263	616262	20020P	PARTICIPANT	\N	PRESENT	0
616264	616262	20032T	PARTICIPANT	\N	PRESENT	0
616265	616262	20100N	PARTICIPANT	\N	PRESENT	0
616282	616281	20024T	PARTICIPANT	\N	PRESENT	0
616283	616281	14026U	PARTICIPANT	\N	PRESENT	0
616284	616281	01057W	PARTICIPANT	\N	PRESENT	0
616285	616281	20064C	PARTICIPANT	\N	PRESENT	0
616286	616281	14147R	PARTICIPANT	\N	PRESENT	0
616291	616290	11026G	PARTICIPANT	\N	PRESENT	0
616292	616290	08069G	PARTICIPANT	\N	PRESENT	0
616293	616290	20122U	PARTICIPANT	\N	PRESENT	0
616294	616290	10015M	PARTICIPANT	\N	PRESENT	0
616295	616290	20136B	PARTICIPANT	\N	PRESENT	0
616296	616287	11043H	PARTICIPANT	\N	PRESENT	0
616297	616289	11043H	PARTICIPANT	\N	PRESENT	1
616487	616273	11097X	PRESIDENT	0	PRESENT	0
616488	616273	19760E	PARTICIPANT	\N	PRESENT	0
616489	616273	14042U	PARTICIPANT	\N	PRESENT	0
616491	616273	14213J	PARTICIPANT	\N	PRESENT	0
616492	616273	18193Q	PARTICIPANT	\N	PRESENT	0
616494	616273	11103C	PARTICIPANT	\N	PRESENT	1
616497	616273	14281W	PARTICIPANT	\N	PRESENT	1
616498	616273	17779H	PARTICIPANT	\N	PRESENT	1
616520	616273	04092N	PARTICIPANT	\N	EXCUSE	0
616521	616273	14071N	PARTICIPANT	\N	EXCUSE	0
616522	616273	20130U	PARTICIPANT	\N	EXCUSE	0
616523	616273	19683J	PARTICIPANT	\N	EXCUSE	0
616524	616273	01034P	PARTICIPANT	\N	EXCUSE	0
616657	616387	20088L	PARTICIPANT	\N	PRESENT	0
616658	616387	19565D	PARTICIPANT	\N	PRESENT	0
616659	616387	14267Y	PARTICIPANT	\N	PRESENT	0
616660	616387	20092G	PARTICIPANT	\N	PRESENT	0
616661	616387	20098N	PARTICIPANT	\N	PRESENT	0
616663	616387	19741B	PARTICIPANT	\N	PRESENT	0
616664	616387	11097X	PARTICIPANT	\N	PRESENT	0
616665	616387	20142Y	PARTICIPANT	\N	PRESENT	0
616666	616387	20032T	PARTICIPANT	\N	PRESENT	0
617521	617520	14089Y	PARTICIPANT	\N	PRESENT	0
617522	617520	11056N	PARTICIPANT	\N	PRESENT	0
617523	617520	19749K	PARTICIPANT	\N	PRESENT	0
617524	617520	20024T	PARTICIPANT	\N	PRESENT	0
618211	616376	14031R	PARTICIPANT	\N	PRESENT	0
618414	617126	05008E	PARTICIPANT	\N	EXCUSE	0
618415	617126	14053L	PARTICIPANT	\N	EXCUSE	0
618431	618365	19697Q	PARTICIPANT	\N	PRESENT	1
618432	618365	11067R	PARTICIPANT	\N	PRESENT	1
618433	618365	20074E	PARTICIPANT	\N	PRESENT	0
618434	618365	19798U	PARTICIPANT	\N	PRESENT	0
618435	618365	19569H	PARTICIPANT	\N	PRESENT	0
618436	618365	11097X	PARTICIPANT	\N	PRESENT	0
618437	618365	04047H	PARTICIPANT	\N	PRESENT	0
602930	602929	19593H	PARTICIPANT	\N	PRESENT	0
602931	602929	12028B	PARTICIPANT	\N	PRESENT	0
602932	602929	04035D	PARTICIPANT	\N	PRESENT	0
602933	602929	14109K	PARTICIPANT	\N	PRESENT	0
602934	602929	20114U	PARTICIPANT	\N	PRESENT	0
602935	602929	20026V	PARTICIPANT	\N	PRESENT	0
602936	602929	19782L	PARTICIPANT	\N	PRESENT	0
602937	602929	11064N	PARTICIPANT	\N	PRESENT	0
602942	602929	19251M	PARTICIPANT	\N	PRESENT	0
603052	600209	14001X	PARTICIPANT	\N	PRESENT	0
604946	602939	19760E	PARTICIPANT	\N	PRESENT	0
604947	602939	19683J	PARTICIPANT	\N	PRESENT	0
604948	602939	19715Y	PARTICIPANT	\N	PRESENT	0
604949	602939	17779H	PARTICIPANT	\N	PRESENT	0
604950	602939	14281W	PARTICIPANT	\N	PRESENT	0
604952	602939	19591F	PARTICIPANT	\N	PRESENT	0
604953	602939	14217N	PARTICIPANT	\N	PRESENT	0
604954	602939	20172F	PARTICIPANT	\N	PRESENT	0
604955	602939	19663E	PARTICIPANT	\N	PRESENT	0
604956	602939	04043D	PARTICIPANT	\N	PRESENT	0
604958	602939	20148F	PARTICIPANT	\N	PRESENT	0
604959	602939	20066E	PARTICIPANT	\N	PRESENT	0
604961	602939	19569H	PARTICIPANT	\N	PRESENT	0
610618	610617	14215L	PARTICIPANT	\N	PRESENT	0
610624	610607	01048V	PRESIDENT	0	PRESENT	0
610626	610607	01058X	PARTICIPANT	\N	PRESENT	0
610627	610607	19503N	PARTICIPANT	\N	PRESENT	0
610628	610607	04043D	PARTICIPANT	\N	PRESENT	0
610630	610607	11067R	PARTICIPANT	\N	PRESENT	0
610631	610607	19709B	PARTICIPANT	\N	PRESENT	0
610632	610607	19533U	PARTICIPANT	\N	PRESENT	0
610634	610607	19723Y	PARTICIPANT	\N	PRESENT	0
610636	610607	19693L	PARTICIPANT	\N	EXCUSE	0
610637	610607	19735D	PARTICIPANT	\N	EXCUSE	0
610638	610604	01048V	PARTICIPANT	\N	PRESENT	0
610640	610604	01058X	PARTICIPANT	\N	PRESENT	0
610641	610604	19503N	PARTICIPANT	\N	PRESENT	0
610642	610604	04043D	PARTICIPANT	\N	PRESENT	0
610644	610604	11067R	PARTICIPANT	\N	PRESENT	0
610645	610604	19709B	PARTICIPANT	\N	PRESENT	0
610646	610604	19533U	PARTICIPANT	\N	PRESENT	0
610648	610604	19723Y	PARTICIPANT	\N	PRESENT	0
610650	610604	19693L	PARTICIPANT	\N	EXCUSE	0
610652	610604	19735D	PARTICIPANT	\N	EXCUSE	0
610653	610605	01048V	PARTICIPANT	\N	PRESENT	0
610655	610605	01058X	PARTICIPANT	\N	PRESENT	0
610656	610605	19503N	PARTICIPANT	\N	PRESENT	0
610657	610605	04043D	PARTICIPANT	\N	PRESENT	0
610659	610605	11067R	PARTICIPANT	\N	PRESENT	0
610660	610605	19709B	PARTICIPANT	\N	PRESENT	0
610661	610605	19533U	PARTICIPANT	\N	PRESENT	0
610663	610605	19723Y	PARTICIPANT	\N	PRESENT	0
610665	610605	19693L	PARTICIPANT	\N	EXCUSE	0
610667	610605	19735D	PARTICIPANT	\N	EXCUSE	0
610677	610506	19295A	PARTICIPANT	\N	EXCUSE	0
610690	610689	04070G	PARTICIPANT	\N	PRESENT	0
610691	610689	19593H	PARTICIPANT	\N	PRESENT	0
610692	610689	20084G	PARTICIPANT	\N	PRESENT	0
610693	610603	04070G	PARTICIPANT	\N	PRESENT	0
610694	610603	20084G	PARTICIPANT	\N	PRESENT	0
610695	610603	19593H	PARTICIPANT	\N	PRESENT	0
610696	610603	19621T	PARTICIPANT	\N	PRESENT	0
612312	612311	14215L	PARTICIPANT	\N	PRESENT	0
612321	612318	20066E	PARTICIPANT	\N	PRESENT	0
612468	608324	20024T	PARTICIPANT	\N	PRESENT	0
612469	608324	17737W	PARTICIPANT	\N	EXCUSE	0
612470	608324	20080C	PARTICIPANT	\N	EXCUSE	0
612471	608324	11031D	PARTICIPANT	\N	EXCUSE	0
612472	608324	19693L	PARTICIPANT	\N	EXCUSE	0
612473	608324	19599P	PARTICIPANT	\N	PRESENT	0
612475	608324	20106U	PARTICIPANT	\N	PRESENT	0
612476	608324	19715Y	PARTICIPANT	\N	EXCUSE	0
612477	608324	20066E	PARTICIPANT	\N	EXCUSE	0
612478	608324	20130U	PARTICIPANT	\N	EXCUSE	0
612479	608324	11045K	PARTICIPANT	\N	PRESENT	0
612480	608324	20098N	PARTICIPANT	\N	PRESENT	0
612481	608324	14030Q	PRESIDENT	0	PRESENT	0
612639	608324	20114U	PARTICIPANT	\N	PRESENT	0
613156	613152	14133K	PARTICIPANT	\N	PRESENT	0
613163	613152	20042V	PARTICIPANT	\N	PRESENT	0
613164	613152	04042C	PARTICIPANT	\N	PRESENT	0
613165	613152	08056B	PARTICIPANT	\N	PRESENT	0
613166	613152	01048V	PARTICIPANT	\N	PRESENT	0
613167	613152	11026G	PARTICIPANT	\N	PRESENT	0
613168	613152	14059S	PARTICIPANT	\N	PRESENT	0
613169	613152	19713W	PARTICIPANT	\N	PRESENT	0
613170	613152	05012A	PARTICIPANT	\N	PRESENT	0
613171	613152	19503N	PARTICIPANT	\N	PRESENT	0
613180	613179	14299H	PARTICIPANT	\N	PRESENT	0
613182	613179	11066Q	PARTICIPANT	\N	PRESENT	0
613184	613183	04047H	PARTICIPANT	\N	PRESENT	0
613185	613183	14299H	PARTICIPANT	\N	PRESENT	0
613186	613183	11066Q	PARTICIPANT	\N	PRESENT	0
619864	619638	11104D	PARTICIPANT	\N	PRESENT	1
619865	619638	20142Y	PARTICIPANT	\N	PRESENT	1
619866	619638	14109K	PARTICIPANT	\N	PRESENT	1
619867	619638	04070G	PARTICIPANT	\N	PRESENT	0
619868	619638	19593H	PARTICIPANT	\N	PRESENT	0
619869	619638	19573D	PARTICIPANT	\N	PRESENT	0
619872	619638	14229S	PARTICIPANT	\N	PRESENT	0
619873	619638	20098N	PARTICIPANT	\N	PRESENT	0
619874	619638	20084G	PARTICIPANT	\N	PRESENT	0
619875	619638	19527W	PARTICIPANT	\N	PRESENT	0
619876	619638	20026V	PARTICIPANT	\N	PRESENT	1
619877	619638	20058E	PARTICIPANT	\N	PRESENT	1
619879	619638	20094J	PARTICIPANT	\N	PRESENT	0
619880	619638	17589D	PARTICIPANT	\N	PRESENT	0
620927	618092	12028B	PARTICIPANT	\N	PRESENT	0
621130	618093	14026U	PARTICIPANT	\N	PRESENT	0
621131	618093	20042V	PARTICIPANT	\N	PRESENT	0
621132	618093	14151M	PARTICIPANT	\N	PRESENT	0
621133	618093	14111D	PARTICIPANT	\N	PRESENT	0
621134	618093	14069U	PARTICIPANT	\N	PRESENT	0
621135	618093	20100N	PARTICIPANT	\N	PRESENT	0
621136	618093	20102Q	PARTICIPANT	\N	PRESENT	0
621137	618093	14179A	PARTICIPANT	\N	PRESENT	0
621138	618093	11012A	PARTICIPANT	\N	PRESENT	0
621139	618093	19551W	PARTICIPANT	\N	PRESENT	0
621140	618093	20106U	PARTICIPANT	\N	PRESENT	0
621141	618093	20180F	PARTICIPANT	\N	PRESENT	0
621161	618093	19413M	PARTICIPANT	\N	PRESENT	0
621143	621065	18083K	PRESIDENT	0	PRESENT	0
621144	621065	20266L	PARTICIPANT	\N	PRESENT	0
621145	621065	19866P	PARTICIPANT	\N	PRESENT	0
621146	618093	20090E	PARTICIPANT	\N	PRESENT	0
621147	618093	17229F	PARTICIPANT	\N	PRESENT	0
621148	618093	19739H	PARTICIPANT	\N	PRESENT	0
621149	618093	19399H	PARTICIPANT	\N	PRESENT	0
621150	618093	20098N	PARTICIPANT	\N	PRESENT	0
621152	618093	20068G	PARTICIPANT	\N	PRESENT	0
621154	618093	18083K	PARTICIPANT	\N	PRESENT	0
621156	618093	14215L	PARTICIPANT	\N	PRESENT	0
621157	618093	20052X	PARTICIPANT	\N	PRESENT	0
621158	618093	19691J	PARTICIPANT	\N	PRESENT	0
621163	618093	97011G	PARTICIPANT	\N	PRESENT	0
621164	618093	20046A	PARTICIPANT	\N	PRESENT	0
621165	618093	19629C	PARTICIPANT	\N	PRESENT	0
621166	618093	14073Q	PARTICIPANT	\N	PRESENT	0
621167	618093	19749K	PARTICIPANT	\N	PRESENT	0
621168	618093	11066Q	PARTICIPANT	\N	PRESENT	0
621170	618093	04092N	PARTICIPANT	\N	PRESENT	0
621171	618093	20092G	PARTICIPANT	\N	PRESENT	0
621172	618093	19441R	PARTICIPANT	\N	PRESENT	0
621173	618093	11067R	PARTICIPANT	\N	PRESENT	0
621174	618093	19619A	PARTICIPANT	\N	PRESENT	0
612681	608646	11072N	PARTICIPANT	\N	PRESENT	0
612682	608646	19447X	PARTICIPANT	\N	PRESENT	0
612683	610752	19467C	PARTICIPANT	\N	PRESENT	0
612684	610752	14357A	PARTICIPANT	\N	PRESENT	0
612685	610752	20110Q	PARTICIPANT	\N	PRESENT	0
612686	608646	19729F	PARTICIPANT	\N	EXCUSE	0
612687	610752	19741B	PARTICIPANT	\N	PRESENT	0
612688	610752	14207L	PARTICIPANT	\N	PRESENT	0
612689	610752	19681G	PARTICIPANT	\N	PRESENT	0
612690	610752	19347U	PARTICIPANT	\N	PRESENT	0
612691	610752	14030Q	PARTICIPANT	\N	PRESENT	0
612692	610752	19503N	PARTICIPANT	\N	PRESENT	0
612693	610752	14026U	PARTICIPANT	\N	PRESENT	0
612694	610752	01057W	PARTICIPANT	\N	PRESENT	0
612695	610752	20032T	PARTICIPANT	\N	PRESENT	0
612696	610752	97011G	PARTICIPANT	\N	PRESENT	0
612700	610752	14259Y	PARTICIPANT	\N	PRESENT	0
612698	610752	14147R	PARTICIPANT	\N	PRESENT	0
612699	610752	19447X	PARTICIPANT	\N	PRESENT	0
612701	610752	19399H	PARTICIPANT	\N	PRESENT	0
612702	610752	20126Y	PARTICIPANT	\N	PRESENT	0
612703	610752	14215L	PARTICIPANT	\N	PRESENT	0
612704	610752	14071N	PARTICIPANT	\N	PRESENT	0
612742	610753	14097Y	PARTICIPANT	\N	PRESENT	0
612743	610753	20044X	PARTICIPANT	\N	PRESENT	0
612744	610753	20094J	PARTICIPANT	\N	PRESENT	0
612745	610753	19507S	PARTICIPANT	\N	PRESENT	0
612746	610753	14133K	PARTICIPANT	\N	PRESENT	0
612747	610753	20030R	PARTICIPANT	\N	PRESENT	0
612748	610753	20082E	PARTICIPANT	\N	PRESENT	0
612749	610753	20104S	PARTICIPANT	\N	PRESENT	0
612750	610753	19441R	PARTICIPANT	\N	PRESENT	0
612751	610753	12041X	PARTICIPANT	\N	PRESENT	0
612752	610753	14357A	PARTICIPANT	\N	PRESENT	0
612753	610753	18083K	PARTICIPANT	\N	PRESENT	0
612754	610753	20038A	PARTICIPANT	\N	PRESENT	0
612755	610753	08034U	PARTICIPANT	\N	PRESENT	0
612756	610753	04070G	PARTICIPANT	\N	PRESENT	0
612757	610753	20126Y	PARTICIPANT	\N	PRESENT	0
612758	610753	20100N	PARTICIPANT	\N	PRESENT	0
612759	610753	04057K	PARTICIPANT	\N	PRESENT	0
612760	610753	19553Y	PARTICIPANT	\N	PRESENT	0
612761	610753	11083R	PARTICIPANT	\N	PRESENT	0
612762	610753	14033T	PARTICIPANT	\N	PRESENT	0
612763	610753	14147R	PARTICIPANT	\N	PRESENT	0
612764	610753	10015M	PARTICIPANT	\N	PRESENT	0
612765	610753	20032T	PARTICIPANT	\N	PRESENT	0
612766	610753	14021P	PARTICIPANT	\N	PRESENT	0
612767	610753	11056N	PARTICIPANT	\N	PRESENT	0
612768	610753	20116W	PARTICIPANT	\N	PRESENT	0
615665	615662	01057W	PARTICIPANT	\N	PRESENT	0
615666	615662	20024T	PARTICIPANT	\N	PRESENT	0
615667	615662	14026U	PARTICIPANT	\N	PRESENT	0
615668	615662	14147R	PARTICIPANT	\N	PRESENT	0
615670	615662	20064C	PARTICIPANT	\N	PRESENT	0
615672	615671	20022R	PARTICIPANT	\N	PRESENT	0
615673	615671	19954N	PARTICIPANT	\N	PRESENT	0
615674	615671	17737W	PARTICIPANT	\N	PRESENT	0
612740	610753	14026U	PARTICIPANT	\N	PRESENT	0
612741	610753	19333N	PARTICIPANT	\N	PRESENT	0
615675	615671	19565D	PARTICIPANT	\N	PRESENT	0
615676	615671	14026U	PARTICIPANT	\N	PRESENT	0
615677	615671	19709B	PARTICIPANT	\N	PRESENT	0
615678	615671	20096L	PARTICIPANT	\N	PRESENT	0
615679	615671	19503N	PARTICIPANT	\N	PRESENT	0
615680	615671	20064C	PARTICIPANT	\N	PRESENT	0
615682	615681	20032T	PARTICIPANT	\N	PRESENT	0
615683	615681	20024T	PARTICIPANT	\N	PRESENT	0
615684	615681	17737W	PARTICIPANT	\N	PRESENT	0
615685	615681	19709B	PARTICIPANT	\N	PRESENT	0
615686	615681	11026G	PARTICIPANT	\N	PRESENT	0
615688	615687	01025N	PARTICIPANT	\N	PRESENT	0
615689	615687	11026G	PARTICIPANT	\N	PRESENT	0
615690	615687	20058E	PARTICIPANT	\N	PRESENT	0
618110	616376	19515S	PRESIDENT	0	PRESENT	0
618111	616376	14083S	PARTICIPANT	\N	PRESENT	0
618112	616376	19762G	PARTICIPANT	\N	PRESENT	0
618113	616376	20092G	PARTICIPANT	\N	PRESENT	0
618114	616376	19251M	PARTICIPANT	\N	PRESENT	0
618115	616376	20094J	PARTICIPANT	\N	PRESENT	0
618116	616376	14357A	PARTICIPANT	\N	PRESENT	0
618117	616376	19467C	PARTICIPANT	\N	PRESENT	0
618118	616376	19575F	PARTICIPANT	\N	PRESENT	0
618119	616376	19369B	PARTICIPANT	\N	PRESENT	0
618120	616376	16685X	PARTICIPANT	\N	PRESENT	0
618121	616376	20060X	PARTICIPANT	\N	PRESENT	0
618122	616376	14030Q	PARTICIPANT	\N	PRESENT	0
618128	616376	20082E	PARTICIPANT	\N	PRESENT	0
618130	616376	19679N	PARTICIPANT	\N	PRESENT	0
618132	616376	20054A	PARTICIPANT	\N	PRESENT	0
618136	616376	19697Q	PARTICIPANT	\N	PRESENT	0
618143	616376	20126Y	PARTICIPANT	\N	PRESENT	0
618150	616376	14038Y	PARTICIPANT	\N	PRESENT	0
618153	616376	19441R	PARTICIPANT	\N	PRESENT	0
618154	616376	04045F	PARTICIPANT	\N	PRESENT	0
618156	616376	14207L	PARTICIPANT	\N	PRESENT	0
618157	616376	20034V	PARTICIPANT	\N	PRESENT	0
621175	618093	19479G	PARTICIPANT	\N	PRESENT	0
621214	621213	19569H	PARTICIPANT	\N	PRESENT	0
621217	618857	19651A	PARTICIPANT	\N	PRESENT	0
621218	618857	19954N	PARTICIPANT	\N	PRESENT	0
621219	618857	11040E	PARTICIPANT	\N	PRESENT	0
621220	618857	20042V	PARTICIPANT	\N	PRESENT	0
621221	618857	19643A	PARTICIPANT	\N	PRESENT	0
621222	618857	19747H	PARTICIPANT	\N	PRESENT	0
621223	618857	20144B	PARTICIPANT	\N	EXCUSE	0
621224	618857	11056N	PARTICIPANT	\N	PRESENT	0
621225	618857	14259Y	PRESIDENT	0	PRESENT	0
621226	618857	20132W	PARTICIPANT	\N	PRESENT	0
621227	618857	20068G	PARTICIPANT	\N	PRESENT	0
621228	618857	19725B	PARTICIPANT	\N	PRESENT	0
621229	618857	19399H	PARTICIPANT	\N	PRESENT	0
621230	618857	19551W	PARTICIPANT	\N	EXCUSE	0
621231	618857	20018V	PARTICIPANT	\N	PRESENT	0
621232	618857	04070G	PARTICIPANT	\N	PRESENT	0
621233	618857	20050V	PARTICIPANT	\N	EXCUSE	0
621234	618857	20044X	PARTICIPANT	\N	PRESENT	0
621235	618857	11097X	PARTICIPANT	\N	PRESENT	0
621236	618857	01028R	PARTICIPANT	\N	EXCUSE	0
621237	618857	19479G	PARTICIPANT	\N	PRESENT	0
621250	618857	20032T	PARTICIPANT	\N	EXCUSE	0
621347	621344	20144B	PARTICIPANT	\N	PRESENT	0
621349	621345	20144B	PARTICIPANT	\N	PRESENT	0
621350	621345	20094J	PARTICIPANT	\N	PRESENT	0
621352	621351	20144B	PARTICIPANT	\N	PRESENT	0
621517	621348	04059M	PARTICIPANT	\N	PRESENT	0
622004	621292	95063L	PRESIDENT	0	PRESENT	0
622005	621292	14089Y	PARTICIPANT	\N	PRESENT	0
622006	621292	14053L	PARTICIPANT	\N	PRESENT	0
622011	621292	08045X	PARTICIPANT	\N	PRESENT	0
621522	621348	11053K	PARTICIPANT	\N	PRESENT	1
622013	621292	11056N	PARTICIPANT	\N	EXCUSE	0
622015	621389	17023S	PARTICIPANT	\N	PRESENT	0
622016	621292	19749K	PARTICIPANT	\N	PRESENT	0
621526	621348	19725B	PARTICIPANT	\N	PRESENT	1
621527	621348	19399H	PARTICIPANT	\N	PRESENT	1
621528	621348	20056C	PARTICIPANT	\N	PRESENT	1
621529	621348	19611R	PRESIDENT	0	PRESENT	0
621530	621348	19699S	PARTICIPANT	\N	PRESENT	0
621531	621348	12041X	PARTICIPANT	\N	PRESENT	1
621532	621348	20142Y	PARTICIPANT	\N	PRESENT	1
622017	621292	19826F	PARTICIPANT	\N	PRESENT	0
621534	621348	14229S	PARTICIPANT	\N	PRESENT	0
622018	621389	20024T	PARTICIPANT	\N	PRESENT	0
622019	621389	14121F	PARTICIPANT	\N	PRESENT	0
622020	621389	14107H	PARTICIPANT	\N	PRESENT	0
622021	621292	20098N	PARTICIPANT	\N	PRESENT	0
622022	621389	20124W	PARTICIPANT	\N	PRESENT	0
622023	621389	08056B	PARTICIPANT	\N	PRESENT	0
622024	621389	20072C	PARTICIPANT	\N	PRESENT	0
622025	621389	20116W	PARTICIPANT	\N	PRESENT	0
622026	621389	19543W	PARTICIPANT	\N	PRESENT	0
622027	621389	14069U	PARTICIPANT	\N	PRESENT	0
622028	621389	01028R	PARTICIPANT	\N	PRESENT	0
622029	621389	20066E	PARTICIPANT	\N	PRESENT	0
622030	621389	14195A	PARTICIPANT	\N	PRESENT	0
622032	621389	20080C	PARTICIPANT	\N	PRESENT	0
622033	621389	14211G	PARTICIPANT	\N	PRESENT	0
622034	621389	14223L	PARTICIPANT	\N	PRESENT	0
622035	621389	19549D	PARTICIPANT	\N	PRESENT	0
622036	621389	19723Y	PARTICIPANT	\N	PRESENT	0
603056	601103	19760E	PARTICIPANT	\N	PRESENT	0
603053	601103	14026U	PARTICIPANT	\N	PRESENT	0
603055	601103	11067R	PARTICIPANT	\N	PRESENT	0
603057	601103	19683J	PARTICIPANT	\N	PRESENT	0
603058	601103	20130U	PARTICIPANT	\N	PRESENT	0
603059	601103	19569H	PARTICIPANT	\N	PRESENT	0
603060	601103	14042U	PARTICIPANT	\N	PRESENT	0
603061	601103	20248J	PARTICIPANT	\N	PRESENT	0
603062	601103	19301E	PARTICIPANT	\N	PRESENT	0
603063	601103	20024T	PARTICIPANT	\N	PRESENT	0
603064	601103	07029T	PARTICIPANT	\N	PRESENT	0
603065	601103	14207L	PARTICIPANT	\N	PRESENT	0
603066	601103	11097X	PARTICIPANT	\N	PRESENT	0
603067	601103	14215L	PARTICIPANT	\N	PRESENT	0
603068	601103	17965H	PARTICIPANT	\N	PRESENT	0
603069	601103	01034P	PARTICIPANT	\N	PRESENT	0
603070	601103	10006L	PARTICIPANT	\N	PRESENT	0
603071	601103	14213J	PARTICIPANT	\N	PRESENT	0
603072	601103	19679N	PARTICIPANT	\N	PRESENT	0
603073	601103	08045X	PARTICIPANT	\N	PRESENT	0
603074	601103	20132W	PARTICIPANT	\N	PRESENT	0
603075	601103	14217N	PARTICIPANT	\N	PRESENT	0
603076	601103	04057K	PARTICIPANT	\N	PRESENT	0
603077	601103	19711U	PARTICIPANT	\N	PRESENT	0
603078	601103	19663E	PARTICIPANT	\N	PRESENT	0
603079	601103	19691J	PARTICIPANT	\N	PRESENT	0
603080	601103	19713W	PARTICIPANT	\N	PRESENT	0
603081	601103	19657G	PARTICIPANT	\N	PRESENT	0
603082	601103	19667J	PARTICIPANT	\N	PRESENT	0
603083	601103	04085P	PARTICIPANT	\N	PRESENT	0
603084	601103	11031D	PARTICIPANT	\N	PRESENT	0
603085	601103	18193Q	PARTICIPANT	\N	PRESENT	0
603086	601103	19415P	PARTICIPANT	\N	PRESENT	0
603087	601103	14071N	PARTICIPANT	\N	PRESENT	0
603088	601103	14281W	PARTICIPANT	\N	PRESENT	0
603091	601103	19703U	PARTICIPANT	\N	PRESENT	0
603092	601103	20146D	PARTICIPANT	\N	PRESENT	0
603119	601103	19705W	PARTICIPANT	\N	PRESENT	0
603121	601103	19715Y	PARTICIPANT	\N	PRESENT	0
603123	601103	20070A	PARTICIPANT	\N	PRESENT	0
603125	601103	19697Q	PARTICIPANT	\N	PRESENT	0
603138	601103	19295A	PARTICIPANT	\N	PRESENT	0
603146	601103	14021P	PARTICIPANT	\N	PRESENT	0
603148	601103	14069U	PARTICIPANT	\N	PRESENT	0
603175	601103	19553Y	PARTICIPANT	\N	PRESENT	0
603176	601103	20066E	PARTICIPANT	\N	PRESENT	0
603179	601103	99004R	PARTICIPANT	\N	PRESENT	0
603182	601103	11045K	PARTICIPANT	\N	PRESENT	0
603183	601103	19723Y	PARTICIPANT	\N	PRESENT	0
603184	601103	04033B	PARTICIPANT	\N	PRESENT	0
603187	601103	19347U	PARTICIPANT	\N	PRESENT	0
603188	601103	04043D	PARTICIPANT	\N	PRESENT	0
603200	601103	12041X	PARTICIPANT	\N	PRESENT	0
603202	601103	20098N	PARTICIPANT	\N	PRESENT	0
603262	601104	14213J	PARTICIPANT	\N	PRESENT	0
603263	601104	10006L	PARTICIPANT	\N	PRESENT	0
603272	601104	20132W	PARTICIPANT	\N	PRESENT	0
603273	601104	19553Y	PARTICIPANT	\N	PRESENT	0
603274	601104	14207L	PARTICIPANT	\N	PRESENT	0
603275	601104	11031D	PARTICIPANT	\N	PRESENT	0
603276	601104	07029T	PARTICIPANT	\N	PRESENT	0
603278	601104	19301E	PARTICIPANT	\N	PRESENT	0
603352	601104	20098N	PARTICIPANT	\N	PRESENT	0
603293	601104	17779H	PARTICIPANT	\N	PRESENT	0
603294	601104	19657G	PARTICIPANT	\N	PRESENT	0
603295	601104	14071N	PARTICIPANT	\N	PRESENT	0
603296	601104	19760E	PARTICIPANT	\N	PRESENT	0
603297	601104	11067R	PARTICIPANT	\N	PRESENT	0
603298	601104	19683J	PARTICIPANT	\N	PRESENT	0
603299	601104	19713W	PARTICIPANT	\N	PRESENT	0
603300	601104	19569H	PARTICIPANT	\N	PRESENT	0
603301	601104	01034P	PARTICIPANT	\N	PRESENT	0
603302	601104	04057K	PARTICIPANT	\N	PRESENT	0
603303	601104	19679N	PARTICIPANT	\N	PRESENT	0
603304	601104	19591F	PARTICIPANT	\N	PRESENT	0
603305	601104	19689Q	PARTICIPANT	\N	PRESENT	0
603306	601104	20130U	PARTICIPANT	\N	PRESENT	0
603307	601104	19663E	PARTICIPANT	\N	PRESENT	0
603308	601104	11097X	PARTICIPANT	\N	PRESENT	0
603309	601104	19415P	PARTICIPANT	\N	PRESENT	0
603310	601104	19687N	PARTICIPANT	\N	PRESENT	0
603311	601104	08045X	PARTICIPANT	\N	PRESENT	0
603312	601104	18193Q	PARTICIPANT	\N	PRESENT	0
603313	601104	14215L	PARTICIPANT	\N	PRESENT	0
603314	601104	20248J	PARTICIPANT	\N	PRESENT	0
603315	601104	19295A	PARTICIPANT	\N	PRESENT	0
603316	601104	19723Y	PARTICIPANT	\N	PRESENT	0
603317	601104	19715Y	PARTICIPANT	\N	PRESENT	0
603318	601104	17965H	PARTICIPANT	\N	PRESENT	0
603319	601104	20066E	PARTICIPANT	\N	PRESENT	0
603320	601104	14042U	PARTICIPANT	\N	PRESENT	0
603321	601104	14026U	PARTICIPANT	\N	PRESENT	0
603322	601104	99004R	PARTICIPANT	\N	PRESENT	0
603323	601104	04043D	PARTICIPANT	\N	PRESENT	0
603324	601104	19577H	PARTICIPANT	\N	PRESENT	0
603325	601104	14217N	PARTICIPANT	\N	PRESENT	0
603326	601104	14069U	PARTICIPANT	\N	PRESENT	0
603341	601104	19703U	PARTICIPANT	\N	PRESENT	0
603345	601104	04033B	PARTICIPANT	\N	PRESENT	0
603248	601104	11045K	PARTICIPANT	\N	PRESENT	0
603261	601104	19691J	PARTICIPANT	\N	PRESENT	0
603350	601104	14021P	PARTICIPANT	\N	PRESENT	0
603351	601104	19527W	PARTICIPANT	\N	PRESENT	0
603353	601104	19697Q	PARTICIPANT	\N	PRESENT	0
603354	601104	14281W	PARTICIPANT	\N	PRESENT	0
603363	601104	20152B	PARTICIPANT	\N	PRESENT	0
603366	601104	11085T	PARTICIPANT	\N	PRESENT	0
603380	601104	19667J	PARTICIPANT	\N	PRESENT	0
603381	601104	11026G	PARTICIPANT	\N	PRESENT	0
603382	601104	19705W	PARTICIPANT	\N	PRESENT	0
603434	603379	14026U	PARTICIPANT	\N	PRESENT	0
603435	603379	17779H	PARTICIPANT	\N	PRESENT	0
603436	603379	20248J	PARTICIPANT	\N	PRESENT	0
603437	603379	20066E	PARTICIPANT	\N	PRESENT	0
603438	603379	14042U	PARTICIPANT	\N	PRESENT	0
603439	603379	14213J	PARTICIPANT	\N	PRESENT	0
603440	603379	19657G	PARTICIPANT	\N	PRESENT	0
603441	603379	14217N	PARTICIPANT	\N	PRESENT	0
603442	603379	10006L	PRESIDENT	0	PRESENT	0
603443	601105	11070L	PARTICIPANT	\N	PRESENT	0
603444	601105	19715Y	PARTICIPANT	\N	PRESENT	0
603445	601105	19683J	PARTICIPANT	\N	PRESENT	0
603446	601105	17779H	PARTICIPANT	\N	PRESENT	0
603447	601105	18193Q	PARTICIPANT	\N	PRESENT	0
603448	601105	11031D	PARTICIPANT	\N	PRESENT	0
603449	601105	14071N	PARTICIPANT	\N	PRESENT	0
603450	601105	19569H	PARTICIPANT	\N	PRESENT	0
603451	601105	04057K	PARTICIPANT	\N	PRESENT	0
603452	601105	14026U	PARTICIPANT	\N	PRESENT	0
603453	601105	14207L	PARTICIPANT	\N	PRESENT	0
603454	601105	19760E	PARTICIPANT	\N	PRESENT	0
603455	601105	17965H	PARTICIPANT	\N	PRESENT	0
603456	601105	19687N	PARTICIPANT	\N	PRESENT	0
603457	601105	20132W	PARTICIPANT	\N	PRESENT	0
603458	601105	11097X	PARTICIPANT	\N	PRESENT	0
603459	601105	19705W	PARTICIPANT	\N	PRESENT	0
603460	601105	20130U	PARTICIPANT	\N	PRESENT	0
603461	601105	11067R	PARTICIPANT	\N	PRESENT	0
603462	601105	14213J	PARTICIPANT	\N	PRESENT	0
603463	601105	19713W	PARTICIPANT	\N	PRESENT	0
603464	601105	04033B	PARTICIPANT	\N	PRESENT	0
603465	601105	19723Y	PARTICIPANT	\N	PRESENT	0
603466	601105	19663E	PARTICIPANT	\N	PRESENT	0
603467	601105	20248J	PARTICIPANT	\N	PRESENT	0
603468	601105	19691J	PARTICIPANT	\N	PRESENT	0
603469	601105	19347U	PARTICIPANT	\N	PRESENT	0
603470	601105	19301E	PARTICIPANT	\N	PRESENT	0
603471	601105	10006L	PARTICIPANT	\N	PRESENT	0
603472	601105	20152B	PARTICIPANT	\N	PRESENT	0
603473	601105	14042U	PARTICIPANT	\N	PRESENT	0
603474	601105	14217N	PARTICIPANT	\N	PRESENT	0
603424	603379	19697Q	PARTICIPANT	\N	PRESENT	0
603425	603379	11067R	PARTICIPANT	\N	PRESENT	0
603426	603379	04057K	PARTICIPANT	\N	PRESENT	0
603427	603379	19713W	PARTICIPANT	\N	PRESENT	0
603428	603379	19569H	PARTICIPANT	\N	PRESENT	0
603429	603379	11097X	PARTICIPANT	\N	PRESENT	0
603430	603379	19663E	PARTICIPANT	\N	PRESENT	0
603431	603379	17965H	PARTICIPANT	\N	PRESENT	0
603432	603379	19301E	PARTICIPANT	\N	PRESENT	0
603433	603379	18193Q	PARTICIPANT	\N	PRESENT	0
618475	618365	14021P	PARTICIPANT	\N	PRESENT	0
618476	618357	19798U	PARTICIPANT	\N	PRESENT	0
618477	618357	20074E	PARTICIPANT	\N	PRESENT	0
618478	618357	19569H	PARTICIPANT	\N	PRESENT	0
618479	618357	11097X	PARTICIPANT	\N	PRESENT	0
618480	618357	04047H	PRESIDENT	0	PRESENT	0
618481	618357	19673G	PARTICIPANT	\N	PRESENT	0
618482	618357	05008E	PARTICIPANT	\N	PRESENT	0
618483	618357	19447X	PARTICIPANT	\N	PRESENT	0
618484	618357	14231L	PARTICIPANT	\N	PRESENT	0
618485	618357	19954N	PARTICIPANT	\N	PRESENT	0
618486	618357	19703U	PARTICIPANT	\N	PRESENT	0
618487	618357	17737W	PARTICIPANT	\N	PRESENT	0
618488	618357	20108W	PARTICIPANT	\N	PRESENT	0
618489	618357	14042U	PARTICIPANT	\N	PRESENT	0
618490	618357	14179A	PARTICIPANT	\N	PRESENT	0
618491	618357	19367Y	PARTICIPANT	\N	PRESENT	0
618492	618357	14151M	PARTICIPANT	\N	PRESENT	0
618493	618357	14215L	PARTICIPANT	\N	PRESENT	0
618494	618357	14217N	RAPPORTEUR_AVIS	\N	PRESENT	0
618495	618357	08018U	PARTICIPANT	\N	PRESENT	0
618496	618357	20022R	PARTICIPANT	\N	PRESENT	0
618497	618357	14053L	PARTICIPANT	\N	PRESENT	0
618498	618357	19649G	PARTICIPANT	\N	PRESENT	0
618499	618357	17965H	PARTICIPANT	\N	PRESENT	0
618500	618357	19691J	PARTICIPANT	\N	PRESENT	0
618501	618357	11033F	PARTICIPANT	\N	PRESENT	0
618502	618357	04085P	PARTICIPANT	\N	PRESENT	0
618503	618357	19723Y	PARTICIPANT	\N	PRESENT	0
618504	618357	95063L	PARTICIPANT	\N	PRESENT	0
618505	618357	19657G	PARTICIPANT	\N	PRESENT	0
618506	618357	11085T	PARTICIPANT	\N	PRESENT	0
618507	618357	19749K	PARTICIPANT	\N	PRESENT	0
618508	618357	19760E	PARTICIPANT	\N	PRESENT	0
618509	618357	14021P	PARTICIPANT	\N	PRESENT	0
618608	618607	20140W	PARTICIPANT	\N	PRESENT	0
618612	618611	19599P	PARTICIPANT	\N	PRESENT	0
618613	618611	19685L	PARTICIPANT	\N	PRESENT	0
618614	618611	20100N	PARTICIPANT	\N	PRESENT	0
618618	618617	19599P	PARTICIPANT	\N	PRESENT	0
618619	618617	19685L	PARTICIPANT	\N	PRESENT	0
618622	618621	20024T	PARTICIPANT	\N	PRESENT	0
618623	618621	19685L	PARTICIPANT	\N	PRESENT	0
618624	618621	20100N	PARTICIPANT	\N	PRESENT	0
618633	618630	20024T	PARTICIPANT	\N	PRESENT	0
618634	618630	19685L	PARTICIPANT	\N	PRESENT	0
618693	618692	20086J	PARTICIPANT	\N	PRESENT	0
618695	618694	20086J	PARTICIPANT	\N	PRESENT	0
618697	618696	20086J	PARTICIPANT	\N	PRESENT	0
618699	618698	11048N	PARTICIPANT	\N	PRESENT	0
618700	618083	20062A	PARTICIPANT	\N	PRESENT	0
618701	618372	20030R	PARTICIPANT	\N	PRESENT	0
618702	618372	19515S	PARTICIPANT	\N	PRESENT	0
618703	618372	19782L	PARTICIPANT	\N	PRESENT	0
618704	618372	20092G	PARTICIPANT	\N	PRESENT	0
618705	618372	01043Q	PARTICIPANT	\N	PRESENT	1
618706	618372	14357A	PARTICIPANT	\N	PRESENT	1
618707	618372	14187A	PARTICIPANT	\N	PRESENT	0
618708	618372	20082E	PARTICIPANT	\N	PRESENT	0
618709	618372	19695N	PARTICIPANT	\N	PRESENT	0
618710	618372	14033T	PARTICIPANT	\N	PRESENT	1
618711	618372	11090Q	PRESIDENT	0	PRESENT	0
618712	618372	20094J	PARTICIPANT	\N	PRESENT	1
618713	618372	20054A	PARTICIPANT	\N	PRESENT	0
618714	618372	20174H	PARTICIPANT	\N	PRESENT	1
618715	618372	20062A	PARTICIPANT	\N	PRESENT	0
618716	618372	19705W	PARTICIPANT	\N	PRESENT	1
618717	618372	19707Y	PARTICIPANT	\N	PRESENT	1
618718	618372	20018V	PARTICIPANT	\N	PRESENT	1
618719	618372	14257W	PARTICIPANT	\N	PRESENT	0
618720	618083	20142Y	PARTICIPANT	\N	PRESENT	0
618721	618083	14229S	PARTICIPANT	\N	PRESENT	0
618722	618083	14329V	PARTICIPANT	\N	PRESENT	0
618723	618083	20054A	PARTICIPANT	\N	PRESENT	0
618724	618083	19515S	PARTICIPANT	\N	PRESENT	0
618725	618083	11090Q	PARTICIPANT	\N	PRESENT	0
618726	618083	14042U	PARTICIPANT	\N	PRESENT	0
618727	618083	20092G	PARTICIPANT	\N	PRESENT	0
618728	618083	14257W	PARTICIPANT	\N	PRESENT	0
618729	618083	11097X	PARTICIPANT	\N	PRESENT	0
618730	618083	19739H	PARTICIPANT	\N	PRESENT	0
618731	618083	11103C	PARTICIPANT	\N	PRESENT	0
618732	618083	16685X	PARTICIPANT	\N	PRESENT	0
618772	618084	20062A	PARTICIPANT	\N	PRESENT	0
618773	618084	20090E	PARTICIPANT	\N	PRESENT	0
618774	618084	14329V	PARTICIPANT	\N	PRESENT	0
618775	618084	20026V	PARTICIPANT	\N	PRESENT	0
618776	618084	20180F	PARTICIPANT	\N	PRESENT	0
618777	618084	19515S	PARTICIPANT	\N	PRESENT	0
618778	618084	19693L	PARTICIPANT	\N	PRESENT	0
618779	618084	19621T	PARTICIPANT	\N	PRESENT	0
618780	618084	20054A	PARTICIPANT	\N	PRESENT	0
618781	618084	19739H	PARTICIPANT	\N	PRESENT	0
618782	618084	16685X	PARTICIPANT	\N	PRESENT	0
618783	618084	20116W	PARTICIPANT	\N	PRESENT	0
618784	618084	11012A	PARTICIPANT	\N	PRESENT	0
618785	618084	17589D	PARTICIPANT	\N	PRESENT	0
618786	618084	19563B	PARTICIPANT	\N	PRESENT	0
618787	618084	20092G	PARTICIPANT	\N	PRESENT	0
618788	618084	20030R	PARTICIPANT	\N	PRESENT	0
618789	618084	20082E	PARTICIPANT	\N	PRESENT	0
618790	618084	14257W	PARTICIPANT	\N	PRESENT	0
618791	618084	11090Q	PARTICIPANT	\N	PRESENT	0
618875	618088	86034E	PARTICIPANT	\N	PRESENT	0
618793	618084	11097X	PARTICIPANT	\N	PRESENT	0
618794	618084	14169X	PARTICIPANT	\N	PRESENT	0
618795	618084	19695N	PARTICIPANT	\N	PRESENT	0
618796	618084	14187A	PARTICIPANT	\N	PRESENT	0
618797	618084	19711U	PARTICIPANT	\N	PRESENT	0
618798	618084	19573D	PARTICIPANT	\N	PRESENT	0
618799	618084	08061X	PARTICIPANT	\N	PRESENT	0
618800	618084	19782L	PARTICIPANT	\N	PRESENT	0
618876	618088	05008E	PARTICIPANT	\N	PRESENT	0
618877	618088	14217N	PARTICIPANT	\N	PRESENT	0
618878	618088	95063L	PARTICIPANT	\N	PRESENT	0
618879	618088	14251Q	PARTICIPANT	\N	PRESENT	0
618880	618088	20108W	PARTICIPANT	\N	PRESENT	0
618881	618088	20110Q	PARTICIPANT	\N	PRESENT	0
618882	618088	04085P	PARTICIPANT	\N	PRESENT	0
618883	618088	14089Y	PARTICIPANT	\N	PRESENT	0
618770	618084	14026U	PARTICIPANT	\N	PRESENT	0
618771	618084	11103C	PARTICIPANT	\N	PRESENT	0
618884	618088	19629C	PARTICIPANT	\N	PRESENT	0
618885	618088	14055N	PARTICIPANT	\N	PRESENT	0
618438	618365	05008E	PARTICIPANT	\N	PRESENT	0
618439	618365	14231L	PARTICIPANT	\N	PRESENT	0
618440	618365	19954N	PARTICIPANT	\N	PRESENT	0
618441	618365	19703U	PARTICIPANT	\N	PRESENT	0
618442	618365	11031D	PARTICIPANT	\N	PRESENT	0
618443	618365	19553Y	PARTICIPANT	\N	PRESENT	1
618444	618365	17737W	PARTICIPANT	\N	PRESENT	0
618445	618365	14107H	PARTICIPANT	\N	PRESENT	1
618446	618365	20108W	PARTICIPANT	\N	PRESENT	0
618447	618365	14042U	PARTICIPANT	\N	PRESENT	0
618448	618365	14179A	PARTICIPANT	\N	PRESENT	0
618449	618365	14195A	PARTICIPANT	\N	PRESENT	1
618450	618365	19367Y	PARTICIPANT	\N	PRESENT	0
618451	618365	14151M	PARTICIPANT	\N	PRESENT	0
618452	618365	14217N	PARTICIPANT	\N	PRESENT	0
618453	618365	08018U	PARTICIPANT	\N	PRESENT	0
618454	618365	20022R	PARTICIPANT	\N	PRESENT	0
618455	618365	19683J	PARTICIPANT	\N	PRESENT	0
618456	618365	10006L	PRESIDENT	0	PRESENT	0
618457	618365	14053L	PARTICIPANT	\N	PRESENT	0
618458	618365	20130U	PARTICIPANT	\N	PRESENT	0
618459	618365	19649G	PARTICIPANT	\N	PRESENT	0
618460	618365	19713W	PARTICIPANT	\N	PRESENT	1
618461	618365	17965H	PARTICIPANT	\N	PRESENT	0
618462	618365	19301E	PARTICIPANT	\N	PRESENT	1
618463	618365	19715Y	PARTICIPANT	\N	PRESENT	0
618464	618365	19691J	PARTICIPANT	\N	PRESENT	0
618465	618365	19717B	PARTICIPANT	\N	PRESENT	1
618466	618365	11033F	PARTICIPANT	\N	PRESENT	0
618467	618365	04085P	PARTICIPANT	\N	PRESENT	0
618468	618365	95063L	PARTICIPANT	\N	PRESENT	0
618469	618365	20066E	PARTICIPANT	\N	PRESENT	1
618470	618365	20266L	PARTICIPANT	\N	PRESENT	1
618471	618365	19657G	PARTICIPANT	\N	PRESENT	0
618472	618365	11085T	PARTICIPANT	\N	PRESENT	0
618473	618365	19749K	PARTICIPANT	\N	PRESENT	0
618474	618365	19760E	PARTICIPANT	\N	PRESENT	0
609088	609087	17023S	PARTICIPANT	\N	PRESENT	0
610459	603495	20024T	PARTICIPANT	\N	PRESENT	0
610460	603495	14030Q	PRESIDENT	0	PRESENT	0
610461	603495	20046A	PARTICIPANT	\N	PRESENT	0
610462	603495	11045K	PARTICIPANT	\N	PRESENT	0
610463	603495	19599P	PARTICIPANT	\N	PRESENT	0
610464	603495	20066E	PARTICIPANT	\N	PRESENT	0
610465	603495	14109K	PARTICIPANT	\N	PRESENT	0
610466	603495	19749K	PARTICIPANT	\N	PRESENT	0
610467	603495	11031D	PARTICIPANT	\N	PRESENT	0
610468	603495	19621T	PARTICIPANT	\N	EXCUSE	0
610469	603495	19693L	PARTICIPANT	\N	EXCUSE	0
610470	603495	14179A	PARTICIPANT	\N	PRESENT	0
610471	603495	20106U	PARTICIPANT	\N	EXCUSE	0
610472	603495	20118Y	PARTICIPANT	\N	EXCUSE	0
610473	603495	14189C	PARTICIPANT	\N	EXCUSE	0
610474	603495	20080C	PARTICIPANT	\N	PRESENT	0
615151	615149	20090E	PARTICIPANT	\N	PRESENT	0
615153	615149	19747H	PARTICIPANT	\N	PRESENT	0
615154	615149	19703U	PARTICIPANT	\N	PRESENT	0
615156	615149	10015M	PARTICIPANT	\N	PRESENT	0
619060	618351	95063L	PARTICIPANT	\N	EXCUSE	0
619062	618351	19749K	PARTICIPANT	\N	PRESENT	0
619077	618351	14107H	PARTICIPANT	\N	PRESENT	1
619078	618351	14053L	PRESIDENT	1	PRESENT	0
619080	618351	11056N	PRESIDENT	0	PRESENT	0
619081	618351	14089Y	PARTICIPANT	\N	PRESENT	0
619123	618351	20086J	PARTICIPANT	\N	PRESENT	0
619134	618351	17367Q	PARTICIPANT	\N	PRESENT	0
619219	618351	20024T	PARTICIPANT	\N	PRESENT	0
620678	618226	14207L	PARTICIPANT	\N	PRESENT	0
620679	618226	19533U	PARTICIPANT	\N	PRESENT	0
620682	618226	19820Y	PARTICIPANT	\N	PRESENT	0
620688	620687	08009T	PARTICIPANT	\N	PRESENT	0
620689	620687	20084G	PARTICIPANT	\N	PRESENT	0
620690	620687	10015M	PARTICIPANT	\N	PRESENT	0
620692	620687	19713W	PARTICIPANT	\N	PRESENT	0
620693	620687	04035D	PARTICIPANT	\N	PRESENT	0
620694	620687	19739H	PARTICIPANT	\N	PRESENT	0
620695	620687	11026G	PARTICIPANT	\N	PRESENT	0
621110	621109	08009T	PARTICIPANT	\N	PRESENT	0
621111	621109	20044X	PARTICIPANT	\N	PRESENT	0
621112	617126	19717B	PRESIDENT	0	PRESENT	0
621113	617126	18083K	PARTICIPANT	\N	PRESENT	0
621114	617126	19577H	PARTICIPANT	\N	PRESENT	1
621115	617126	17023S	PARTICIPANT	\N	PRESENT	1
621116	617126	97011G	PARTICIPANT	\N	PRESENT	0
621117	617126	11010L	PARTICIPANT	\N	EXCUSE	0
621118	617126	20034V	PARTICIPANT	\N	EXCUSE	0
621119	617126	14097Y	PARTICIPANT	\N	PRESENT	0
621120	617126	14059S	PARTICIPANT	\N	PRESENT	0
621121	617126	14147R	PARTICIPANT	\N	PRESENT	0
621122	617126	11072N	PARTICIPANT	\N	PRESENT	1
621123	617126	20148F	PARTICIPANT	\N	PRESENT	0
621124	617126	20146D	PARTICIPANT	\N	PRESENT	1
621125	617126	20150Y	PARTICIPANT	\N	PRESENT	1
621127	617126	19715Y	PARTICIPANT	\N	EXCUSE	0
621176	618093	14231L	PARTICIPANT	\N	PRESENT	0
621177	618093	19683J	PARTICIPANT	\N	PRESENT	0
621179	618093	07029T	PARTICIPANT	\N	PRESENT	0
621180	618093	19713W	PARTICIPANT	\N	PRESENT	0
621270	618095	19467C	PARTICIPANT	\N	PRESENT	0
621255	618095	99004R	PARTICIPANT	\N	PRESENT	0
621256	618095	19713W	PARTICIPANT	\N	PRESENT	0
621257	618095	04092N	PARTICIPANT	\N	PRESENT	0
621258	618095	20130U	PARTICIPANT	\N	PRESENT	0
621259	618095	11031D	PARTICIPANT	\N	PRESENT	0
621260	618095	19691J	PARTICIPANT	\N	PRESENT	0
621261	618095	11012A	PARTICIPANT	\N	PRESENT	0
621262	618095	19683J	PARTICIPANT	\N	PRESENT	0
621263	618095	19697Q	PARTICIPANT	\N	PRESENT	0
621264	618095	04057K	PARTICIPANT	\N	PRESENT	0
621265	618095	11048N	PARTICIPANT	\N	PRESENT	0
621266	618095	17779H	PARTICIPANT	\N	PRESENT	0
621267	618095	10006L	PARTICIPANT	\N	PRESENT	0
621268	618095	14038Y	PARTICIPANT	\N	PRESENT	0
621269	618095	19760E	PARTICIPANT	\N	PRESENT	0
621271	618095	19749K	PARTICIPANT	\N	PRESENT	0
621272	618095	04085P	PARTICIPANT	\N	PRESENT	0
621273	618095	19479G	PARTICIPANT	\N	PRESENT	0
621274	618095	11053K	PARTICIPANT	\N	PRESENT	0
621275	618095	97011G	PARTICIPANT	\N	PRESENT	0
621276	618095	07029T	PARTICIPANT	\N	PRESENT	0
621277	618095	11085T	PARTICIPANT	\N	PRESENT	0
621278	618095	14357A	PARTICIPANT	\N	PRESENT	0
621279	618095	20042V	PARTICIPANT	\N	PRESENT	0
622037	621389	20142Y	PARTICIPANT	\N	PRESENT	0
622038	621389	20286Q	PARTICIPANT	\N	PRESENT	0
622040	621285	14257W	PARTICIPANT	\N	PRESENT	0
622043	621389	20104S	PARTICIPANT	\N	PRESENT	0
622046	621389	20078J	PARTICIPANT	\N	PRESENT	0
622050	621389	19631V	PARTICIPANT	\N	PRESENT	0
622063	621389	19441R	PARTICIPANT	\N	PRESENT	0
622064	621389	20172F	PARTICIPANT	\N	PRESENT	0
622065	621389	14083S	PARTICIPANT	\N	PRESENT	0
622066	621389	20032T	PARTICIPANT	\N	PRESENT	0
622068	621389	19768N	PARTICIPANT	\N	PRESENT	0
622072	621389	14031R	PARTICIPANT	\N	PRESENT	0
622079	621389	14097Y	PARTICIPANT	\N	PRESENT	0
622080	621389	97011G	PARTICIPANT	\N	PRESENT	0
622081	621389	19565D	PARTICIPANT	\N	PRESENT	0
622082	621389	18083K	PARTICIPANT	\N	PRESENT	0
622083	621389	14215L	PARTICIPANT	\N	PRESENT	0
622084	621389	14179A	PARTICIPANT	\N	PRESENT	0
622085	621292	17367Q	PARTICIPANT	\N	PRESENT	0
622086	621389	20044X	PARTICIPANT	\N	PRESENT	0
622087	621389	20090E	PARTICIPANT	\N	PRESENT	0
622088	621389	19563B	PARTICIPANT	\N	PRESENT	0
622089	621389	14059S	PARTICIPANT	\N	PRESENT	0
622090	621389	20102Q	PARTICIPANT	\N	PRESENT	0
622091	621389	14105F	PARTICIPANT	\N	PRESENT	0
622092	621389	20100N	PARTICIPANT	\N	PRESENT	0
622093	621178	20130U	PARTICIPANT	\N	PRESENT	1
622094	621178	11031D	PARTICIPANT	\N	PRESENT	0
622095	621178	19703U	PARTICIPANT	\N	PRESENT	0
622096	621178	19467C	PARTICIPANT	\N	PRESENT	0
622097	621178	20062A	PARTICIPANT	\N	PRESENT	0
622098	621178	04092N	PARTICIPANT	\N	PRESENT	0
622099	621178	19713W	PARTICIPANT	\N	PRESENT	0
622100	621178	19735D	PARTICIPANT	\N	PRESENT	0
622101	621178	19301E	PARTICIPANT	\N	PRESENT	1
622102	621178	19683J	PRESIDENT	0	PRESENT	0
622103	621178	10006L	PARTICIPANT	\N	PRESENT	0
622104	621389	19383Y	PARTICIPANT	\N	PRESENT	0
622105	621389	20054A	PARTICIPANT	\N	PRESENT	0
622107	621389	16685X	PARTICIPANT	\N	PRESENT	0
622108	621389	19798U	PARTICIPANT	\N	PRESENT	0
622109	621389	19599P	PARTICIPANT	\N	PRESENT	0
622110	621389	20136B	PARTICIPANT	\N	PRESENT	0
622122	620888	20086J	PARTICIPANT	\N	PRESENT	0
622123	620888	19479G	PARTICIPANT	\N	PRESENT	0
622124	620888	11048N	PARTICIPANT	\N	PRESENT	0
622125	620888	19711U	PARTICIPANT	\N	PRESENT	0
622126	620888	20036X	PARTICIPANT	\N	PRESENT	0
622127	620888	08034U	PARTICIPANT	\N	PRESENT	0
622128	620888	19545Y	PARTICIPANT	\N	PRESENT	0
622129	620888	01057W	PARTICIPANT	\N	PRESENT	0
622130	620888	19687N	PARTICIPANT	\N	PRESENT	0
622131	620888	11053K	PARTICIPANT	\N	PRESENT	0
622132	620888	20080C	PARTICIPANT	\N	PRESENT	0
622133	620888	11074Q	PARTICIPANT	\N	PRESENT	0
622134	620888	14033T	PARTICIPANT	\N	PRESENT	0
622135	620888	20044X	PARTICIPANT	\N	PRESENT	0
622136	620888	14225N	PRESIDENT	0	PRESENT	0
622137	620888	14083S	PARTICIPANT	\N	PRESENT	0
622138	620888	20252E	PARTICIPANT	\N	PRESENT	0
622139	620888	08009T	PARTICIPANT	\N	PRESENT	0
622140	620888	20070A	PARTICIPANT	\N	PRESENT	0
622141	620888	99004R	PARTICIPANT	\N	PRESENT	0
622142	620888	20126Y	PARTICIPANT	\N	PRESENT	0
622143	620888	07029T	PARTICIPANT	\N	EXCUSE	0
622144	620888	14173T	PARTICIPANT	\N	EXCUSE	0
622145	621285	20038A	PARTICIPANT	\N	PRESENT	0
622146	621389	01025N	PARTICIPANT	\N	PRESENT	0
622156	621389	19673G	PARTICIPANT	\N	PRESENT	0
622164	621389	14147R	PARTICIPANT	\N	PRESENT	0
622171	621389	20180F	PARTICIPANT	\N	PRESENT	0
622172	621389	11097X	PARTICIPANT	\N	PRESENT	0
622173	621389	20022R	PARTICIPANT	\N	PRESENT	0
622174	621389	08015R	PARTICIPANT	\N	PRESENT	0
622182	621389	20042V	PARTICIPANT	\N	PRESENT	0
622184	621389	95063L	PARTICIPANT	\N	PRESENT	0
622185	621389	14053L	PARTICIPANT	\N	PRESENT	0
622186	620888	11040E	PARTICIPANT	\N	PRESENT	1
622187	620888	19647E	PARTICIPANT	\N	PRESENT	1
622188	620888	19335Q	PARTICIPANT	\N	PRESENT	1
622189	620888	19671E	PARTICIPANT	\N	PRESENT	1
622190	621389	19713W	PARTICIPANT	\N	PRESENT	0
622191	621389	14213J	PARTICIPANT	\N	PRESENT	0
622192	621389	20122U	PARTICIPANT	\N	PRESENT	0
622193	621389	19711U	PARTICIPANT	\N	PRESENT	0
622194	621389	19479G	PARTICIPANT	\N	PRESENT	0
622195	621389	11048N	PARTICIPANT	\N	PRESENT	0
622196	621389	14123H	PARTICIPANT	\N	PRESENT	0
622197	621389	01057W	PARTICIPANT	\N	PRESENT	0
622200	621389	20126Y	PARTICIPANT	\N	PRESENT	0
622201	621389	19762G	PARTICIPANT	\N	PRESENT	0
622208	621389	19685L	PARTICIPANT	\N	PRESENT	0
622209	621389	20174H	PARTICIPANT	\N	PRESENT	0
622210	621389	11012A	PARTICIPANT	\N	PRESENT	0
622211	621389	20108W	PARTICIPANT	\N	PRESENT	0
622212	621389	19569H	PARTICIPANT	\N	PRESENT	0
621353	621346	04059M	PARTICIPANT	\N	PRESENT	0
622213	621389	14026U	PARTICIPANT	\N	PRESENT	0
622214	621389	19782L	PARTICIPANT	\N	PRESENT	0
622215	621389	14217N	PARTICIPANT	\N	PRESENT	0
622216	621389	19467C	PARTICIPANT	\N	PRESENT	0
621358	621346	11053K	PARTICIPANT	\N	PRESENT	0
622217	621389	14038Y	PARTICIPANT	\N	PRESENT	0
622218	621389	19747H	PARTICIPANT	\N	PRESENT	0
621361	621346	20132W	PARTICIPANT	\N	PRESENT	0
621362	621346	19725B	PARTICIPANT	\N	PRESENT	1
621363	621346	19399H	PARTICIPANT	\N	PRESENT	0
622219	621389	19693L	PARTICIPANT	\N	PRESENT	0
621365	621346	19611R	PRESIDENT	0	PRESENT	0
621366	621346	19699S	PRESIDENT	1	PRESENT	0
622227	621389	20092G	PARTICIPANT	\N	PRESENT	0
621368	621346	20142Y	PARTICIPANT	\N	PRESENT	0
621369	621346	19705W	PARTICIPANT	\N	PRESENT	1
621370	621346	14229S	PARTICIPANT	\N	PRESENT	0
622228	621389	19507S	PARTICIPANT	\N	PRESENT	0
622229	621389	14187A	PARTICIPANT	\N	PRESENT	0
622230	621389	14133K	PARTICIPANT	\N	PRESENT	0
622231	621389	19415P	PARTICIPANT	\N	PRESENT	0
622277	621390	19611R	PARTICIPANT	\N	PRESENT	0
622278	621390	20134Y	PARTICIPANT	\N	PRESENT	0
622279	621390	08012N	PARTICIPANT	\N	PRESENT	0
622280	621390	19711U	PARTICIPANT	\N	PRESENT	0
622281	621390	19533U	PARTICIPANT	\N	PRESENT	0
622282	621390	19387D	PARTICIPANT	\N	PRESENT	0
622283	621390	14229S	PARTICIPANT	\N	PRESENT	0
622284	621390	19349W	PARTICIPANT	\N	PRESENT	0
622285	621390	19585H	PARTICIPANT	\N	PRESENT	0
622286	621390	20052X	PARTICIPANT	\N	PRESENT	0
622287	621390	20048C	PARTICIPANT	\N	PRESENT	0
622288	621390	14073Q	PARTICIPANT	\N	PRESENT	0
622289	621390	14030Q	PARTICIPANT	\N	PRESENT	0
622290	621390	20112S	PARTICIPANT	\N	PRESENT	0
622291	621390	19758L	PARTICIPANT	\N	PRESENT	0
622292	621390	19565D	PARTICIPANT	\N	PRESENT	0
622293	621390	20124W	PARTICIPANT	\N	PRESENT	0
622294	621390	20090E	PARTICIPANT	\N	PRESENT	0
622295	621390	14213J	PARTICIPANT	\N	PRESENT	0
622296	621390	14069U	PARTICIPANT	\N	PRESENT	0
622297	621390	19399H	PARTICIPANT	\N	PRESENT	0
622298	621390	14097Y	PARTICIPANT	\N	PRESENT	0
622299	621390	19503N	PARTICIPANT	\N	PRESENT	0
622300	621390	14275Y	PARTICIPANT	\N	PRESENT	0
622301	621390	14123H	PARTICIPANT	\N	PRESENT	0
622302	621390	19693L	PARTICIPANT	\N	PRESENT	0
622303	621390	14089Y	PARTICIPANT	\N	PRESENT	0
622304	621390	17023S	PARTICIPANT	\N	PRESENT	0
622305	621390	19631V	PARTICIPANT	\N	PRESENT	0
622306	621390	20128B	PARTICIPANT	\N	PRESENT	0
622307	621390	14031R	PARTICIPANT	\N	PRESENT	0
622308	621390	19798U	PARTICIPANT	\N	PRESENT	0
622309	621390	14147R	PARTICIPANT	\N	PRESENT	0
622310	621390	20032T	PARTICIPANT	\N	PRESENT	0
622311	621390	14033T	PARTICIPANT	\N	PRESENT	0
622312	621390	14021P	PARTICIPANT	\N	PRESENT	0
622313	621390	11097X	PARTICIPANT	\N	PRESENT	0
622314	621390	19621T	PARTICIPANT	\N	PRESENT	0
622315	621390	20058E	PARTICIPANT	\N	PRESENT	0
622316	621390	14026U	PARTICIPANT	\N	PRESENT	0
622317	621390	19549D	PARTICIPANT	\N	PRESENT	0
622318	621390	19747H	PARTICIPANT	\N	PRESENT	0
622319	621390	20054A	PARTICIPANT	\N	PRESENT	0
622275	621390	11070L	PARTICIPANT	\N	PRESENT	0
622276	621390	11043H	PARTICIPANT	\N	PRESENT	0
622320	621390	19719D	PARTICIPANT	\N	PRESENT	0
622321	621390	14207L	PARTICIPANT	\N	PRESENT	0
622322	621390	19573D	PARTICIPANT	\N	PRESENT	0
622323	621390	11012A	PARTICIPANT	\N	PRESENT	0
622324	621390	20082E	PARTICIPANT	\N	PRESENT	0
622325	621390	20180F	PARTICIPANT	\N	PRESENT	0
622326	621390	19782L	PARTICIPANT	\N	PRESENT	0
622327	621390	20116W	PARTICIPANT	\N	PRESENT	0
622328	621390	07029T	PARTICIPANT	\N	PRESENT	0
622381	622378	20024T	PARTICIPANT	\N	PRESENT	0
622383	622378	20090E	PARTICIPANT	\N	PRESENT	0
622382	622378	20114U	PARTICIPANT	\N	PRESENT	0
622384	622378	14255U	PARTICIPANT	\N	PRESENT	0
622385	622378	14053L	PARTICIPANT	\N	PRESENT	0
622386	622378	12028B	PARTICIPANT	\N	PRESENT	0
622387	622378	18083K	PARTICIPANT	\N	PRESENT	0
622388	622378	11027H	PARTICIPANT	\N	PRESENT	0
622389	622378	20070A	PARTICIPANT	\N	PRESENT	0
622390	622378	17229F	PARTICIPANT	\N	PRESENT	0
622391	622378	14213J	PARTICIPANT	\N	PRESENT	0
622392	622378	20084G	PARTICIPANT	\N	PRESENT	0
622393	622378	19749K	PARTICIPANT	\N	PRESENT	0
622416	621510	04085P	PARTICIPANT	\N	PRESENT	1
622417	621510	19543W	PARTICIPANT	\N	PRESENT	1
622418	621510	11033F	PARTICIPANT	\N	PRESENT	1
622419	621510	19629C	PARTICIPANT	\N	PRESENT	1
622420	621510	11056N	PARTICIPANT	\N	PRESENT	1
622421	621510	20074E	PARTICIPANT	\N	PRESENT	1
622422	621510	14151M	PARTICIPANT	\N	PRESENT	1
622423	621510	07004J	PARTICIPANT	\N	PRESENT	1
622424	621510	19725B	PARTICIPANT	\N	PRESENT	1
622426	621510	20128B	PARTICIPANT	\N	PRESENT	1
622427	621510	14179A	PARTICIPANT	\N	PRESENT	1
622428	621510	19489J	PARTICIPANT	\N	PRESENT	1
622429	621510	11026G	PARTICIPANT	\N	PRESENT	1
622430	621510	10015M	PARTICIPANT	\N	PRESENT	1
622431	621510	14107H	PARTICIPANT	\N	PRESENT	1
622483	622482	19507S	PARTICIPANT	\N	PRESENT	0
622484	622482	20088L	PARTICIPANT	\N	PRESENT	0
622485	622482	19782L	PARTICIPANT	\N	PRESENT	0
622486	622482	14033T	PARTICIPANT	\N	PRESENT	0
622487	622482	19413M	PARTICIPANT	\N	PRESENT	0
622489	622488	19507S	PARTICIPANT	\N	PRESENT	0
622490	622488	20088L	PARTICIPANT	\N	PRESENT	0
622491	622488	19782L	PARTICIPANT	\N	PRESENT	0
622493	622488	14033T	PARTICIPANT	\N	PRESENT	0
622494	622488	19413M	PARTICIPANT	\N	PRESENT	0
622496	622495	20092G	PARTICIPANT	\N	PRESENT	0
622497	622495	19507S	PARTICIPANT	\N	PRESENT	0
622498	622495	14033T	PARTICIPANT	\N	PRESENT	0
622499	622495	19782L	PARTICIPANT	\N	PRESENT	0
622500	622495	20174H	PARTICIPANT	\N	PRESENT	0
622502	622501	20092G	PARTICIPANT	\N	PRESENT	0
622503	622501	19507S	PARTICIPANT	\N	PRESENT	0
622504	622501	14033T	PARTICIPANT	\N	PRESENT	0
622505	622501	19782L	PARTICIPANT	\N	PRESENT	0
622506	622501	20174H	PARTICIPANT	\N	PRESENT	0
603475	601105	20066E	PARTICIPANT	\N	PRESENT	0
603476	601105	19697Q	PARTICIPANT	\N	PRESENT	0
603477	601105	19657G	PARTICIPANT	\N	PRESENT	0
603478	601105	04035D	PARTICIPANT	\N	PRESENT	0
605160	603147	14223L	PARTICIPANT	\N	PRESENT	0
605161	603147	08028W	PARTICIPANT	\N	PRESENT	0
605162	603147	11045K	PARTICIPANT	\N	PRESENT	0
605163	603147	11067R	PARTICIPANT	\N	PRESENT	0
605164	603147	19629C	PARTICIPANT	\N	PRESENT	0
605165	603147	19349W	PARTICIPANT	\N	PRESENT	0
605166	603147	19725B	PARTICIPANT	\N	PRESENT	0
605167	603147	20018V	PARTICIPANT	\N	PRESENT	0
605168	603147	11054L	PARTICIPANT	\N	PRESENT	0
605169	603147	11077T	PARTICIPANT	\N	PRESENT	0
605170	603147	20036X	PARTICIPANT	\N	PRESENT	0
605171	603147	11041F	PARTICIPANT	\N	PRESENT	0
605172	603147	19826F	PARTICIPANT	\N	PRESENT	0
605173	603147	14073Q	PARTICIPANT	\N	PRESENT	0
605174	603147	04042C	PARTICIPANT	\N	PRESENT	0
605175	603147	11097X	PARTICIPANT	\N	PRESENT	0
605176	603147	14133K	PARTICIPANT	\N	PRESENT	0
605177	603147	10006L	PARTICIPANT	\N	PRESENT	0
605178	603147	11031D	PARTICIPANT	\N	PRESENT	0
605179	603147	11056N	PARTICIPANT	\N	PRESENT	0
605180	603147	19719D	PARTICIPANT	\N	PRESENT	0
605181	603147	14221J	PARTICIPANT	\N	PRESENT	0
605182	603147	20142Y	PARTICIPANT	\N	PRESENT	0
605183	603147	19717B	PARTICIPANT	\N	PRESENT	0
605184	603147	20116W	PARTICIPANT	\N	PRESENT	0
605185	603147	11083R	PARTICIPANT	\N	PRESENT	0
605186	603147	08012N	PARTICIPANT	\N	PRESENT	0
605187	603147	17965H	PARTICIPANT	\N	PRESENT	0
605188	603147	19637C	PARTICIPANT	\N	PRESENT	0
605189	603147	19301E	PARTICIPANT	\N	PRESENT	0
605190	603147	08061X	PARTICIPANT	\N	PRESENT	0
605191	603147	19659J	PARTICIPANT	\N	PRESENT	0
605192	603147	20110Q	PARTICIPANT	\N	PRESENT	0
605193	603147	04057K	PARTICIPANT	\N	PRESENT	0
605194	603147	19760E	PARTICIPANT	\N	PRESENT	0
605195	603147	20130U	PARTICIPANT	\N	PRESENT	0
605196	603147	19251M	PARTICIPANT	\N	PRESENT	0
605197	603147	14121F	PARTICIPANT	\N	PRESENT	0
605198	603147	20132W	PARTICIPANT	\N	PRESENT	0
605199	603147	11012A	PARTICIPANT	\N	PRESENT	0
605200	603147	19651A	PARTICIPANT	\N	PRESENT	0
605201	603147	19685L	PARTICIPANT	\N	PRESENT	0
605202	603147	19545Y	PARTICIPANT	\N	PRESENT	0
605203	603147	19683J	PARTICIPANT	\N	PRESENT	0
605204	603147	20088L	PARTICIPANT	\N	PRESENT	0
605205	603147	20150Y	PARTICIPANT	\N	PRESENT	0
605206	603147	08060W	PARTICIPANT	\N	PRESENT	0
605207	603147	04059M	PARTICIPANT	\N	PRESENT	0
605208	603147	11040E	PARTICIPANT	\N	PRESENT	0
605209	603147	19553Y	PARTICIPANT	\N	PRESENT	0
605210	603147	14249W	PARTICIPANT	\N	PRESENT	0
605211	603147	19333N	PARTICIPANT	\N	PRESENT	0
605212	603147	19503N	PARTICIPANT	\N	PRESENT	0
605213	603147	19758L	PARTICIPANT	\N	PRESENT	0
605214	603147	14151M	PARTICIPANT	\N	PRESENT	0
605215	603147	20030R	PARTICIPANT	\N	PRESENT	0
605216	603147	04085P	PARTICIPANT	\N	PRESENT	0
605217	603147	01043Q	PARTICIPANT	\N	PRESENT	0
605218	603147	14211G	PARTICIPANT	\N	PRESENT	0
605219	603147	19711U	PARTICIPANT	\N	PRESENT	0
605220	603147	19695N	PARTICIPANT	\N	PRESENT	0
605221	603147	20046A	PARTICIPANT	\N	PRESENT	0
605222	603147	08010L	PARTICIPANT	\N	PRESENT	0
605223	603147	11065P	PARTICIPANT	\N	PRESENT	0
605224	603147	20092G	PARTICIPANT	\N	PRESENT	0
605225	603147	04008A	PARTICIPANT	\N	PRESENT	0
605226	603147	11099A	PARTICIPANT	\N	PRESENT	0
605227	603147	14026U	PARTICIPANT	\N	PRESENT	0
605228	603147	19703U	PARTICIPANT	\N	PRESENT	0
605229	603147	04047H	PARTICIPANT	\N	PRESENT	0
605230	603147	95063L	PARTICIPANT	\N	PRESENT	0
605231	603147	08034U	PARTICIPANT	\N	PRESENT	0
605232	603147	11072N	PARTICIPANT	\N	PRESENT	0
605233	603147	17367Q	PARTICIPANT	\N	PRESENT	0
605234	603147	04071H	PARTICIPANT	\N	PRESENT	0
605235	603147	10015M	PARTICIPANT	\N	PRESENT	0
605236	603147	19866P	PARTICIPANT	\N	PRESENT	0
605237	603147	14107H	PARTICIPANT	\N	PRESENT	0
605238	603147	19515S	PARTICIPANT	\N	PRESENT	0
605239	603147	14195A	PARTICIPANT	\N	PRESENT	0
605240	603147	19585H	PARTICIPANT	\N	PRESENT	0
605241	603147	19689Q	PARTICIPANT	\N	PRESENT	0
605242	603147	04045F	PARTICIPANT	\N	PRESENT	0
605243	603147	20128B	PARTICIPANT	\N	PRESENT	0
605244	603130	20086J	PARTICIPANT	\N	PRESENT	0
605245	603130	14327T	PARTICIPANT	\N	PRESENT	0
605246	603130	11048N	PARTICIPANT	\N	PRESENT	0
605247	603130	19479G	PARTICIPANT	\N	PRESENT	0
605248	603130	19647E	PARTICIPANT	\N	PRESENT	0
605249	603130	19711U	PARTICIPANT	\N	PRESENT	0
605250	603130	08034U	PARTICIPANT	\N	PRESENT	0
605251	603130	19545Y	PARTICIPANT	\N	PRESENT	0
605252	603130	19687N	PARTICIPANT	\N	PRESENT	0
605253	603130	19689Q	PARTICIPANT	\N	PRESENT	0
605254	603130	11053K	PARTICIPANT	\N	PRESENT	0
605255	603130	20080C	PARTICIPANT	\N	PRESENT	0
605256	603130	11070L	PARTICIPANT	\N	PRESENT	0
605257	603130	14225N	PARTICIPANT	\N	PRESENT	0
605258	603130	20252E	PARTICIPANT	\N	PRESENT	0
605259	603130	20070A	PARTICIPANT	\N	PRESENT	0
605260	603130	19349W	PRESIDENT	0	PRESENT	0
605261	603130	19741B	PARTICIPANT	\N	PRESENT	0
605262	603130	99004R	PARTICIPANT	\N	PRESENT	0
605263	603130	19667J	PARTICIPANT	\N	PRESENT	0
605264	603147	19563B	PARTICIPANT	\N	PRESENT	0
605265	603147	14207L	PARTICIPANT	\N	PRESENT	0
605266	603147	19631V	PARTICIPANT	\N	PRESENT	0
605267	603147	14281W	PARTICIPANT	\N	PRESENT	0
605268	603147	19549D	PARTICIPANT	\N	PRESENT	0
605269	603147	12016W	PARTICIPANT	\N	PRESENT	0
605270	603147	19413M	PARTICIPANT	\N	PRESENT	0
605271	603147	19591F	PARTICIPANT	\N	PRESENT	0
605272	603147	14109K	PARTICIPANT	\N	PRESENT	0
605273	603147	20060X	PARTICIPANT	\N	PRESENT	0
605274	603147	14251Q	PARTICIPANT	\N	PRESENT	0
605275	603147	16685X	PARTICIPANT	\N	PRESENT	0
605276	603147	20052X	PARTICIPANT	\N	PRESENT	0
605277	603147	11090Q	PARTICIPANT	\N	PRESENT	0
605278	603147	20070A	PARTICIPANT	\N	PRESENT	0
605279	603147	20264J	PARTICIPANT	\N	PRESENT	0
605280	603147	11110B	PARTICIPANT	\N	PRESENT	0
605281	603147	19347U	PARTICIPANT	\N	PRESENT	0
605282	603147	19782L	PARTICIPANT	\N	PRESENT	0
605283	603147	20050V	PARTICIPANT	\N	PRESENT	0
605284	603147	19599P	PARTICIPANT	\N	PRESENT	0
605285	603147	19820Y	PARTICIPANT	\N	PRESENT	0
605286	603147	14097Y	PARTICIPANT	\N	PRESENT	0
605287	603147	20266L	PARTICIPANT	\N	PRESENT	0
605288	603147	19329S	PARTICIPANT	\N	PRESENT	0
605289	603147	08073C	PARTICIPANT	\N	PRESENT	0
605290	603147	19715Y	PARTICIPANT	\N	PRESENT	0
605291	603147	19531S	PARTICIPANT	\N	PRESENT	0
605292	603147	19687N	PARTICIPANT	\N	PRESENT	0
605293	603147	14021P	PARTICIPANT	\N	PRESENT	0
605294	603147	19649G	PARTICIPANT	\N	PRESENT	0
605295	603147	18193Q	PARTICIPANT	\N	PRESENT	0
605296	603147	11104D	PARTICIPANT	\N	PRESENT	0
605297	603147	14001X	PARTICIPANT	\N	PRESENT	0
605298	603147	20028X	PARTICIPANT	\N	PRESENT	0
605299	603147	20082E	PARTICIPANT	\N	PRESENT	0
605300	603147	19551W	PARTICIPANT	\N	PRESENT	0
605301	603147	01028R	PARTICIPANT	\N	PRESENT	0
605302	603147	14229S	PARTICIPANT	\N	PRESENT	0
605303	603147	11066Q	PARTICIPANT	\N	PRESENT	0
605304	603147	11048N	PARTICIPANT	\N	PRESENT	0
605305	603147	19621T	PARTICIPANT	\N	PRESENT	0
605306	603147	14042U	PARTICIPANT	\N	PRESENT	0
605307	603147	20152B	PARTICIPANT	\N	PRESENT	0
605308	603147	20020P	PARTICIPANT	\N	PRESENT	0
605309	603147	19543W	PARTICIPANT	\N	PRESENT	0
605310	603147	20042V	PARTICIPANT	\N	PRESENT	0
605311	603147	19762G	PARTICIPANT	\N	PRESENT	0
605312	603147	19383Y	PARTICIPANT	\N	PRESENT	0
605313	603147	14089Y	PARTICIPANT	\N	PRESENT	0
605314	603147	14083S	PARTICIPANT	\N	PRESENT	0
605315	603147	19675J	PARTICIPANT	\N	PRESENT	0
605316	603147	11053K	PARTICIPANT	\N	PRESENT	0
618886	618088	01028R	PARTICIPANT	\N	PRESENT	0
618887	618088	19723Y	PARTICIPANT	\N	PRESENT	0
618888	618088	19683J	PARTICIPANT	\N	PRESENT	0
618889	618088	19447X	PARTICIPANT	\N	PRESENT	0
618890	618088	14042U	PARTICIPANT	\N	PRESENT	0
618891	618088	20090E	PARTICIPANT	\N	PRESENT	0
618892	618088	14267Y	PARTICIPANT	\N	PRESENT	0
618893	618088	14179A	PARTICIPANT	\N	PRESENT	0
618894	618088	20286Q	PARTICIPANT	\N	PRESENT	0
618895	618088	11040E	PARTICIPANT	\N	PRESENT	0
618896	618088	11031D	PARTICIPANT	\N	PRESENT	0
618897	618088	11056N	PARTICIPANT	\N	PRESENT	0
618898	618088	19695N	PARTICIPANT	\N	PRESENT	0
618899	618088	19565D	PARTICIPANT	\N	PRESENT	0
618900	618088	19593H	PARTICIPANT	\N	PRESENT	0
618901	618088	20064C	PARTICIPANT	\N	PRESENT	0
618902	618088	12028B	PARTICIPANT	\N	PRESENT	0
618903	618088	11067R	PARTICIPANT	\N	PRESENT	0
618904	618088	14097Y	PARTICIPANT	\N	PRESENT	0
618905	618088	19649G	PARTICIPANT	\N	PRESENT	0
618906	618088	20084G	PARTICIPANT	\N	PRESENT	0
618907	618088	19515S	PARTICIPANT	\N	PRESENT	0
618908	618088	14021P	PARTICIPANT	\N	PRESENT	0
618909	618088	18083K	PARTICIPANT	\N	PRESENT	0
618910	618088	20130U	PARTICIPANT	\N	PRESENT	0
618911	618088	19782L	PARTICIPANT	\N	PRESENT	0
618912	618088	14031R	PARTICIPANT	\N	PRESENT	0
618913	618088	19673G	PARTICIPANT	\N	PRESENT	0
618914	618088	20076G	PARTICIPANT	\N	PRESENT	0
618915	618088	20074E	PARTICIPANT	\N	PRESENT	0
618916	618088	01058X	PARTICIPANT	\N	PRESENT	0
618917	618088	19525U	PARTICIPANT	\N	PRESENT	0
618918	618088	11065P	PARTICIPANT	\N	PRESENT	0
618919	618088	19693L	PARTICIPANT	\N	PRESENT	0
618920	618088	11033F	PARTICIPANT	\N	PRESENT	0
618921	618088	20174H	PARTICIPANT	\N	PRESENT	0
618922	618088	14211G	PARTICIPANT	\N	PRESENT	0
618923	618088	19651A	PARTICIPANT	\N	PRESENT	0
618924	618088	04008A	PARTICIPANT	\N	PRESENT	0
618925	618088	19637C	PARTICIPANT	\N	PRESENT	0
618926	618088	17637T	PARTICIPANT	\N	PRESENT	0
618927	618088	19387D	PARTICIPANT	\N	PRESENT	0
618928	618088	19575F	PARTICIPANT	\N	PRESENT	0
618929	618088	20106U	PARTICIPANT	\N	PRESENT	0
618930	618088	04045F	PARTICIPANT	\N	PRESENT	0
618931	618088	99004R	PARTICIPANT	\N	PRESENT	0
618932	618088	08010L	PARTICIPANT	\N	PRESENT	0
618933	618088	19489J	PARTICIPANT	\N	PRESENT	0
618934	618088	11101A	PARTICIPANT	\N	PRESENT	0
618935	618088	19745F	PARTICIPANT	\N	PRESENT	0
618936	618088	19703U	PARTICIPANT	\N	PRESENT	0
618937	618088	04092N	PARTICIPANT	\N	PRESENT	0
618938	618088	17229F	PARTICIPANT	\N	PRESENT	0
618939	618088	14133K	PARTICIPANT	\N	PRESENT	0
618940	618088	20072C	PARTICIPANT	\N	PRESENT	0
618941	618088	04033B	PARTICIPANT	\N	PRESENT	0
618942	618088	14207L	PARTICIPANT	\N	PRESENT	0
618943	618088	14187A	PARTICIPANT	\N	PRESENT	0
618944	618088	01048V	PARTICIPANT	\N	PRESENT	0
618945	618088	14223L	PARTICIPANT	\N	PRESENT	0
618946	618088	11026G	PARTICIPANT	\N	PRESENT	0
618947	618088	14001X	PARTICIPANT	\N	PRESENT	0
618948	618088	20026V	PARTICIPANT	\N	PRESENT	0
618949	618088	19725B	PARTICIPANT	\N	PRESENT	0
618950	618088	17965H	PARTICIPANT	\N	PRESENT	0
618951	618088	20180F	PARTICIPANT	\N	PRESENT	0
618952	618088	11045K	PARTICIPANT	\N	PRESENT	0
618953	618088	19573D	PARTICIPANT	\N	PRESENT	0
618954	618088	20132W	PARTICIPANT	\N	PRESENT	0
618955	618088	14038Y	PARTICIPANT	\N	PRESENT	0
618956	618088	19553Y	PARTICIPANT	\N	PRESENT	0
618957	618088	19441R	PARTICIPANT	\N	PRESENT	0
618958	618088	14327T	PARTICIPANT	\N	PRESENT	0
618959	618088	10015M	PARTICIPANT	\N	PRESENT	0
618960	618088	19569H	PARTICIPANT	\N	PRESENT	0
618961	618088	20144B	PARTICIPANT	\N	PRESENT	0
618962	618088	20022R	PARTICIPANT	\N	PRESENT	0
618963	618088	05012A	PARTICIPANT	\N	PRESENT	0
618964	618088	08009T	PARTICIPANT	\N	PRESENT	0
618965	618088	14221J	PARTICIPANT	\N	PRESENT	0
618966	618088	20136B	PARTICIPANT	\N	PRESENT	0
618967	618088	14111D	PARTICIPANT	\N	PRESENT	0
618968	618088	14329V	PARTICIPANT	\N	PRESENT	0
618969	618088	14357A	PARTICIPANT	\N	PRESENT	0
618970	618088	14195A	PARTICIPANT	\N	PRESENT	0
618971	618088	19675J	PARTICIPANT	\N	PRESENT	0
618972	618088	20124W	PARTICIPANT	\N	PRESENT	0
618973	618088	04047H	PARTICIPANT	\N	PRESENT	0
618974	618088	20062A	PARTICIPANT	\N	PRESENT	0
618975	618088	10006L	PARTICIPANT	\N	PRESENT	0
618976	618088	14213J	PARTICIPANT	\N	PRESENT	0
618977	618088	20036X	PARTICIPANT	\N	PRESENT	0
618978	618088	19715Y	PARTICIPANT	\N	PRESENT	0
618979	618088	18193Q	PARTICIPANT	\N	PRESENT	0
618980	618088	11054L	PARTICIPANT	\N	PRESENT	0
618981	618088	19301E	PARTICIPANT	\N	PRESENT	0
618982	618088	19399H	PARTICIPANT	\N	PRESENT	0
618983	618088	19741B	PARTICIPANT	\N	PRESENT	0
618984	618088	20042V	PARTICIPANT	\N	PRESENT	0
618985	618088	19657G	PARTICIPANT	\N	PRESENT	0
618986	618088	04057K	PARTICIPANT	\N	PRESENT	0
618987	618088	20098N	PARTICIPANT	\N	PRESENT	0
618988	618088	20116W	PARTICIPANT	\N	PRESENT	0
618989	618088	04070G	PARTICIPANT	\N	PRESENT	0
618990	618088	20066E	PARTICIPANT	\N	PRESENT	0
618991	618088	20056C	PARTICIPANT	\N	PRESENT	0
618992	618088	14189C	PARTICIPANT	\N	PRESENT	0
618993	618088	14205J	PARTICIPANT	\N	PRESENT	0
618994	618088	19467C	PARTICIPANT	\N	PRESENT	0
618995	618088	20058E	PARTICIPANT	\N	PRESENT	0
618996	618088	20044X	PARTICIPANT	\N	PRESENT	0
618997	618088	11066Q	PARTICIPANT	\N	PRESENT	0
618998	618088	20054A	PARTICIPANT	\N	PRESENT	0
618999	618088	19866P	PARTICIPANT	\N	PRESENT	0
619000	618088	20126Y	PARTICIPANT	\N	PRESENT	0
619001	618088	19749K	PARTICIPANT	\N	PRESENT	0
619002	618088	08015R	PARTICIPANT	\N	PRESENT	0
619003	618088	19415P	PARTICIPANT	\N	PRESENT	0
619004	618088	11097X	PARTICIPANT	\N	PRESENT	0
619005	618088	19421M	PARTICIPANT	\N	PRESENT	0
619006	618088	19479G	PARTICIPANT	\N	PRESENT	0
619007	618088	14253S	PARTICIPANT	\N	PRESENT	0
619008	618088	14229S	PARTICIPANT	\N	PRESENT	0
619009	618088	14147R	PARTICIPANT	\N	PRESENT	0
619010	618088	14105F	PARTICIPANT	\N	PRESENT	0
619011	618088	01024M	PARTICIPANT	\N	PRESENT	0
619012	618088	14215L	PARTICIPANT	\N	PRESENT	0
619013	618088	01043Q	PARTICIPANT	\N	PRESENT	0
619014	618088	08060W	PARTICIPANT	\N	PRESENT	0
619015	618088	19701S	PARTICIPANT	\N	PRESENT	0
619016	618088	19549D	PARTICIPANT	\N	PRESENT	0
619017	618088	19798U	PARTICIPANT	\N	PRESENT	0
619018	618088	11053K	PARTICIPANT	\N	PRESENT	0
619019	618088	19545Y	PARTICIPANT	\N	PRESENT	0
619020	618088	19057M	PARTICIPANT	\N	PRESENT	0
619021	618088	20172F	PARTICIPANT	\N	PRESENT	0
619022	618088	19583F	PARTICIPANT	\N	PRESENT	0
619023	618088	14053L	PARTICIPANT	\N	PRESENT	0
619024	618088	19758L	PARTICIPANT	\N	PRESENT	0
619025	618088	20118Y	PARTICIPANT	\N	PRESENT	0
619026	618835	19717B	PARTICIPANT	\N	EXCUSE	0
619027	618088	20112S	PARTICIPANT	\N	PRESENT	0
619028	618835	20114U	PARTICIPANT	\N	PRESENT	0
619029	618835	20104S	PARTICIPANT	\N	PRESENT	0
619030	618835	20100N	PARTICIPANT	\N	PRESENT	0
619031	618835	17023S	PARTICIPANT	\N	PRESENT	0
619032	618088	19687N	PARTICIPANT	\N	PRESENT	0
619033	618835	11064N	PARTICIPANT	\N	PRESENT	0
619034	618835	19333N	PARTICIPANT	\N	PRESENT	0
619035	618088	20046A	PARTICIPANT	\N	PRESENT	0
619036	618835	19447X	PARTICIPANT	\N	EXCUSE	0
619037	618088	12041X	PARTICIPANT	\N	PRESENT	0
619038	618835	14059S	PARTICIPANT	\N	PRESENT	0
619039	618835	20150Y	PARTICIPANT	\N	PRESENT	0
619040	618835	04043D	PARTICIPANT	\N	EXCUSE	0
619041	618835	19503N	PARTICIPANT	\N	PRESENT	0
619042	618835	20096L	PARTICIPANT	\N	PRESENT	0
619043	618835	19826F	PARTICIPANT	\N	PRESENT	0
619044	618088	19295A	PARTICIPANT	\N	PRESENT	0
619045	618088	20070A	PARTICIPANT	\N	PRESENT	0
619046	618088	97011G	PARTICIPANT	\N	PRESENT	0
601933	598625	18083K	PARTICIPANT	\N	PRESENT	0
601934	598625	19333N	PARTICIPANT	\N	PRESENT	0
601935	598625	14031R	PARTICIPANT	\N	PRESENT	0
601936	598625	19387D	PARTICIPANT	\N	PRESENT	0
601937	598625	14219Q	PRESIDENT	0	PRESENT	0
601938	598625	19826F	PARTICIPANT	\N	PRESENT	0
601939	598625	19745F	PARTICIPANT	\N	PRESENT	0
601940	598625	19599P	PARTICIPANT	\N	PRESENT	0
601941	598625	20102Q	PARTICIPANT	\N	PRESENT	0
601942	598625	20024T	PARTICIPANT	\N	PRESENT	0
601943	598625	14169X	PARTICIPANT	\N	PRESENT	0
601944	598625	17229F	PARTICIPANT	\N	PRESENT	0
601945	598625	20046A	PARTICIPANT	\N	PRESENT	0
601946	598625	20068G	PARTICIPANT	\N	PRESENT	0
601947	598625	11101A	PARTICIPANT	\N	PRESENT	0
601948	598625	19739H	PARTICIPANT	\N	PRESENT	0
601949	598625	20020P	PARTICIPANT	\N	PRESENT	0
601950	598625	20032T	PARTICIPANT	\N	PRESENT	0
601951	598625	19637C	PARTICIPANT	\N	PRESENT	0
601952	598625	17637T	PARTICIPANT	\N	PRESENT	0
601953	598625	20100N	PARTICIPANT	\N	PRESENT	0
601954	598625	19503N	PARTICIPANT	\N	PRESENT	0
601955	598625	17367Q	PARTICIPANT	\N	PRESENT	0
601956	598625	19619A	PARTICIPANT	\N	PRESENT	0
601957	598625	20076G	PARTICIPANT	\N	PRESENT	0
601958	598625	19681G	PARTICIPANT	\N	PRESENT	0
601959	598625	19549D	PARTICIPANT	\N	PRESENT	0
601960	598625	19551W	PARTICIPANT	\N	PRESENT	0
601961	598625	19820Y	PARTICIPANT	\N	PRESENT	0
601962	598625	14237S	PARTICIPANT	\N	PRESENT	0
601963	598625	20136B	PARTICIPANT	\N	PRESENT	0
601964	598625	20106U	PARTICIPANT	\N	PRESENT	0
601965	598625	19701S	PARTICIPANT	\N	PRESENT	0
601966	601186	19527W	PARTICIPANT	\N	PRESENT	0
601967	601186	19643A	PARTICIPANT	\N	PRESENT	0
601968	601186	20132W	PARTICIPANT	\N	PRESENT	0
601969	601186	19533U	PARTICIPANT	\N	PRESENT	0
601970	601186	14073Q	PARTICIPANT	\N	PRESENT	0
601971	601186	19611R	PRESIDENT	0	PRESENT	0
601972	601186	20142Y	PARTICIPANT	\N	PRESENT	0
601973	601186	01060R	PARTICIPANT	\N	PRESENT	0
601974	601186	20048C	PARTICIPANT	\N	PRESENT	0
601975	601186	19693L	PARTICIPANT	\N	PRESENT	0
601976	601186	19399H	PARTICIPANT	\N	PRESENT	0
601977	601186	20052X	PARTICIPANT	\N	PRESENT	0
601978	601186	14030Q	PARTICIPANT	\N	PRESENT	0
601979	601186	20056C	PARTICIPANT	\N	PRESENT	0
601980	601186	20180F	PARTICIPANT	\N	PRESENT	0
601981	601186	20112S	PARTICIPANT	\N	PRESENT	0
601982	601186	92040Q	PARTICIPANT	\N	PRESENT	0
601983	601186	14123H	PARTICIPANT	\N	PRESENT	0
601984	601186	11104D	PARTICIPANT	\N	PRESENT	0
601985	601186	20124W	PARTICIPANT	\N	PRESENT	0
601986	601186	19758L	PARTICIPANT	\N	PRESENT	0
601987	601186	17589D	PARTICIPANT	\N	PRESENT	0
602011	598625	11065P	PARTICIPANT	\N	EXCUSE	0
601989	601186	19621T	PARTICIPANT	\N	PRESENT	0
601990	601186	19699S	PARTICIPANT	\N	PRESENT	0
601991	600552	14331P	PARTICIPANT	\N	PRESENT	0
601992	600552	19479G	PARTICIPANT	\N	PRESENT	0
601993	600552	08034U	PARTICIPANT	\N	PRESENT	0
601994	600552	99004R	PARTICIPANT	\N	PRESENT	0
601995	600552	19671E	PARTICIPANT	\N	PRESENT	0
601996	600552	11048N	PARTICIPANT	\N	PRESENT	0
601997	600552	14225N	PRESIDENT	0	PRESENT	0
601998	600552	14173T	PARTICIPANT	\N	PRESENT	0
601999	600552	14327T	PARTICIPANT	\N	PRESENT	0
602000	600552	20252E	PARTICIPANT	\N	PRESENT	0
602001	600552	14121F	PARTICIPANT	\N	PRESENT	0
602002	600552	11070L	PARTICIPANT	\N	PRESENT	0
602003	600552	19711U	PARTICIPANT	\N	PRESENT	0
602004	600552	08073C	PARTICIPANT	\N	PRESENT	0
602005	601186	20026V	PARTICIPANT	\N	PRESENT	0
602006	601186	20134Y	PARTICIPANT	\N	PRESENT	0
602007	601186	04059M	PARTICIPANT	\N	PRESENT	0
602008	601186	14109K	PARTICIPANT	\N	PRESENT	0
602009	600552	11053K	PARTICIPANT	\N	PRESENT	0
602010	600552	01057W	PARTICIPANT	\N	PRESENT	0
602012	600552	19689Q	PARTICIPANT	\N	PRESENT	0
602013	600552	20080C	PARTICIPANT	\N	PRESENT	0
602014	600552	07029T	PARTICIPANT	\N	PRESENT	0
602015	600552	20044X	PARTICIPANT	\N	PRESENT	0
602016	600552	20070A	PARTICIPANT	\N	PRESENT	0
602017	600552	19687N	PARTICIPANT	\N	PRESENT	0
602018	600552	11040E	PARTICIPANT	\N	PRESENT	0
602019	600552	20086J	PARTICIPANT	\N	PRESENT	0
602020	600552	20116W	PARTICIPANT	\N	PRESENT	0
602021	600552	20050V	PARTICIPANT	\N	PRESENT	0
602022	600552	14083S	PARTICIPANT	\N	PRESENT	0
602023	600552	19335Q	PARTICIPANT	\N	PRESENT	0
602024	600552	14189C	PARTICIPANT	\N	EXCUSE	0
602025	600552	19762G	PARTICIPANT	\N	PRESENT	0
602026	600552	19667J	PARTICIPANT	\N	PRESENT	0
602027	598625	20096L	PARTICIPANT	\N	PRESENT	0
602028	600552	19349W	PARTICIPANT	\N	PRESENT	0
602029	600552	11012A	PARTICIPANT	\N	PRESENT	0
602030	600552	11110B	PARTICIPANT	\N	PRESENT	0
602031	600552	19545Y	PARTICIPANT	\N	PRESENT	0
602032	600552	04071H	PARTICIPANT	\N	PRESENT	0
602033	600552	12016W	PARTICIPANT	\N	PRESENT	0
602034	600552	08010L	PARTICIPANT	\N	PRESENT	0
602035	600552	01048V	PARTICIPANT	\N	PRESENT	0
602036	601186	04033B	PARTICIPANT	\N	PRESENT	0
602037	601186	14229S	PARTICIPANT	\N	PRESENT	0
602038	601186	20098N	PARTICIPANT	\N	PRESENT	0
602039	601186	19573D	PARTICIPANT	\N	PRESENT	0
602040	601186	08012N	PARTICIPANT	\N	PRESENT	0
602041	601186	19593H	PARTICIPANT	\N	PRESENT	0
602042	601186	20058E	PARTICIPANT	\N	PRESENT	0
602043	601186	20266L	PARTICIPANT	\N	PRESENT	0
602044	601186	19735D	PARTICIPANT	\N	PRESENT	0
602045	601186	20084G	PARTICIPANT	\N	PRESENT	0
602046	601186	04070G	PARTICIPANT	\N	PRESENT	0
602047	601186	20264J	PARTICIPANT	\N	PRESENT	0
602048	600552	19647E	PARTICIPANT	\N	PRESENT	0
602049	600552	19741B	PARTICIPANT	\N	PRESENT	0
602050	600552	14073Q	PARTICIPANT	\N	PRESENT	0
602051	600552	11083R	PARTICIPANT	\N	PRESENT	0
602052	600552	14253S	PARTICIPANT	\N	PRESENT	0
602053	601186	11043H	PARTICIPANT	\N	PRESENT	0
602054	598625	20140W	PARTICIPANT	\N	PRESENT	0
602055	598625	19515S	PARTICIPANT	\N	PRESENT	0
602056	598625	05012A	PARTICIPANT	\N	EXCUSE	0
602057	598625	20038A	PARTICIPANT	\N	PRESENT	0
602058	600825	11067R	PARTICIPANT	\N	PRESENT	0
602059	600825	20090E	PARTICIPANT	\N	PRESENT	0
602060	600825	19798U	PARTICIPANT	\N	PRESENT	0
602061	600825	11097X	PARTICIPANT	\N	PRESENT	0
602062	600825	19415P	PARTICIPANT	\N	PRESENT	0
602063	600825	14223L	PARTICIPANT	\N	PRESENT	0
602064	600825	14026U	PARTICIPANT	\N	PRESENT	0
602065	600825	17779H	PARTICIPANT	\N	PRESENT	0
602066	600825	19703U	PARTICIPANT	\N	PRESENT	0
602067	600825	14281W	PARTICIPANT	\N	PRESENT	0
602068	600825	19679N	PARTICIPANT	\N	PRESENT	0
602069	600825	14042U	PARTICIPANT	\N	PRESENT	0
602070	600825	14213J	PARTICIPANT	\N	PRESENT	0
602071	600825	19367Y	PARTICIPANT	\N	PRESENT	0
602072	600825	14217N	PARTICIPANT	\N	PRESENT	0
602073	600825	10006L	PRESIDENT	0	PRESENT	0
602074	600825	20130U	PARTICIPANT	\N	PRESENT	0
602075	600825	04092N	PARTICIPANT	\N	PRESENT	0
602076	600825	08045X	PARTICIPANT	\N	PRESENT	0
602077	600825	20040T	PARTICIPANT	\N	PRESENT	0
602078	600825	20172F	PARTICIPANT	\N	PRESENT	0
602079	600825	20248J	PARTICIPANT	\N	PRESENT	0
602080	600825	20066E	PARTICIPANT	\N	PRESENT	0
602081	600825	11103C	PARTICIPANT	\N	PRESENT	0
602082	600825	19657G	PARTICIPANT	\N	PRESENT	0
602083	600825	14071N	PARTICIPANT	\N	PRESENT	0
602084	600825	04043D	PARTICIPANT	\N	PRESENT	0
602085	600825	04057K	PARTICIPANT	\N	PRESENT	0
602086	600552	08009T	PARTICIPANT	\N	PRESENT	0
602087	600552	20126Y	PARTICIPANT	\N	PRESENT	0
602088	601186	19719D	PARTICIPANT	\N	PRESENT	0
602089	600212	20088L	PARTICIPANT	\N	PRESENT	0
602090	600212	19768N	PARTICIPANT	\N	PRESENT	0
602091	600212	19515S	PARTICIPANT	\N	PRESENT	0
602092	600212	20092G	PARTICIPANT	\N	PRESENT	0
602093	600212	19782L	PARTICIPANT	\N	PRESENT	0
602094	600212	11077T	PARTICIPANT	\N	PRESENT	0
620930	618092	17965H	PARTICIPANT	\N	PRESENT	0
620931	618092	20142Y	PARTICIPANT	\N	PRESENT	0
620932	618092	19619A	PARTICIPANT	\N	PRESENT	0
620933	618092	17023S	PARTICIPANT	\N	PRESENT	0
620934	618092	01028R	PARTICIPANT	\N	PRESENT	0
620935	618092	95063L	PARTICIPANT	\N	PRESENT	0
620936	618092	19866P	PARTICIPANT	\N	PRESENT	0
620937	618092	19629C	PARTICIPANT	\N	PRESENT	0
620938	618092	14207L	PARTICIPANT	\N	PRESENT	0
620939	618092	14179A	PARTICIPANT	\N	PRESENT	0
620940	618092	11097X	PARTICIPANT	\N	PRESENT	0
620941	618092	19415P	PARTICIPANT	\N	PRESENT	0
620942	618092	14215L	PARTICIPANT	\N	PRESENT	0
620943	618092	19671E	PARTICIPANT	\N	PRESENT	0
620944	618092	19621T	PARTICIPANT	\N	PRESENT	0
620945	618092	19691J	PARTICIPANT	\N	PRESENT	0
620946	618092	19717B	PARTICIPANT	\N	PRESENT	0
620947	618092	14251Q	PARTICIPANT	\N	PRESENT	0
620948	618092	20086J	PARTICIPANT	\N	PRESENT	0
620949	618092	20090E	PARTICIPANT	\N	PRESENT	0
620950	618092	19675J	PARTICIPANT	\N	PRESENT	0
620951	618092	19768N	PARTICIPANT	\N	PRESENT	0
620952	618092	14026U	PARTICIPANT	\N	PRESENT	0
620953	618092	20024T	PARTICIPANT	\N	PRESENT	0
620954	618092	19399H	PARTICIPANT	\N	PRESENT	0
620955	618092	08018U	PARTICIPANT	\N	PRESENT	0
620956	618092	14033T	PARTICIPANT	\N	PRESENT	0
620957	618092	20096L	PARTICIPANT	\N	PRESENT	0
620958	618092	19663E	PARTICIPANT	\N	PRESENT	0
620959	618092	20044X	PARTICIPANT	\N	PRESENT	0
620960	618092	19467C	PARTICIPANT	\N	PRESENT	0
620961	618092	19447X	PARTICIPANT	\N	PRESENT	0
620962	618092	20038A	PARTICIPANT	\N	PRESENT	0
620963	618092	01057W	PARTICIPANT	\N	PRESENT	0
620964	618092	20076G	PARTICIPANT	\N	PRESENT	0
620965	618092	20074E	PARTICIPANT	\N	PRESENT	0
620966	618092	18083K	PARTICIPANT	\N	PRESENT	0
620967	618092	20022R	PARTICIPANT	\N	PRESENT	0
620968	618092	19711U	PARTICIPANT	\N	PRESENT	0
620969	618092	20032T	PARTICIPANT	\N	PRESENT	0
620970	618092	14147R	PARTICIPANT	\N	PRESENT	0
620971	618092	20094J	PARTICIPANT	\N	PRESENT	0
620972	618092	11048N	PARTICIPANT	\N	PRESENT	0
620973	618092	19713W	PARTICIPANT	\N	PRESENT	0
620974	618092	08069G	PARTICIPANT	\N	PRESENT	0
620975	618092	04033B	PARTICIPANT	\N	PRESENT	0
620976	618092	11090Q	PARTICIPANT	\N	PRESENT	0
620977	618092	14187A	PARTICIPANT	\N	PRESENT	0
620978	618092	04092N	PARTICIPANT	\N	PRESENT	0
620979	618092	20180F	PARTICIPANT	\N	PRESENT	0
620980	618092	20026V	PARTICIPANT	\N	PRESENT	0
620981	618092	11026G	PARTICIPANT	\N	PRESENT	0
620982	618092	20264J	PARTICIPANT	\N	PRESENT	0
620928	618092	19503N	PARTICIPANT	\N	PRESENT	0
620929	618092	19333N	PARTICIPANT	\N	PRESENT	0
620983	618092	10015M	PARTICIPANT	\N	PRESENT	0
620984	618092	04085P	PARTICIPANT	\N	PRESENT	0
620985	618092	11056N	PARTICIPANT	\N	PRESENT	0
620986	618092	11031D	PARTICIPANT	\N	PRESENT	0
620987	618092	12041X	PARTICIPANT	\N	PRESENT	0
620988	618092	19723Y	PARTICIPANT	\N	PRESENT	0
620989	618092	14357A	PARTICIPANT	\N	PRESENT	0
620990	618092	19747H	PARTICIPANT	\N	PRESENT	0
620991	618092	19563B	PARTICIPANT	\N	PRESENT	0
620992	618092	20070A	PARTICIPANT	\N	PRESENT	0
620993	618092	19826F	PARTICIPANT	\N	PRESENT	0
620994	618092	19719D	PARTICIPANT	\N	PRESENT	0
620995	618092	19549D	PARTICIPANT	\N	PRESENT	0
620996	618092	20118Y	PARTICIPANT	\N	PRESENT	0
620997	618092	14189C	PARTICIPANT	\N	PRESENT	0
620998	618092	14255U	PARTICIPANT	\N	PRESENT	0
620999	618092	08010L	PARTICIPANT	\N	PRESENT	0
621000	618092	20128B	PARTICIPANT	\N	PRESENT	0
621001	618092	19507S	PARTICIPANT	\N	PRESENT	0
621002	618092	14231L	PARTICIPANT	\N	PRESENT	0
621003	618092	17637T	PARTICIPANT	\N	PRESENT	0
621004	618092	19703U	PARTICIPANT	\N	PRESENT	0
621005	618092	20252E	PARTICIPANT	\N	PRESENT	0
621006	618092	19533U	PARTICIPANT	\N	PRESENT	0
621007	618092	14053L	PARTICIPANT	\N	PRESENT	0
621008	618092	19701S	PARTICIPANT	\N	PRESENT	0
621009	618092	14089Y	PARTICIPANT	\N	PRESENT	0
621010	618092	20062A	PARTICIPANT	\N	PRESENT	0
621011	618092	19553Y	PARTICIPANT	\N	PRESENT	0
621012	618092	19687N	PARTICIPANT	\N	PRESENT	0
621013	618092	05012A	PARTICIPANT	\N	PRESENT	0
621014	618092	17779H	PARTICIPANT	\N	PRESENT	0
621015	618092	20042V	PARTICIPANT	\N	PRESENT	0
621016	618092	19749K	PARTICIPANT	\N	PRESENT	0
621017	618092	19515S	PARTICIPANT	\N	PRESENT	0
621018	618092	19695N	PARTICIPANT	\N	PRESENT	0
621019	618092	20114U	PARTICIPANT	\N	PRESENT	0
621020	618092	14038Y	PARTICIPANT	\N	PRESENT	0
621021	618092	19347U	PARTICIPANT	\N	PRESENT	0
621022	618092	19551W	PARTICIPANT	\N	PRESENT	0
621023	618092	20052X	PARTICIPANT	\N	PRESENT	0
621024	618092	20124W	PARTICIPANT	\N	PRESENT	0
621025	618092	20266L	PARTICIPANT	\N	PRESENT	0
621026	618092	20106U	PARTICIPANT	\N	PRESENT	0
621027	618092	20100N	PARTICIPANT	\N	PRESENT	0
621028	618092	20058E	PARTICIPANT	\N	PRESENT	0
621029	618092	14083S	PARTICIPANT	\N	PRESENT	0
621030	618092	19295A	PARTICIPANT	\N	PRESENT	0
621031	618092	14111D	PARTICIPANT	\N	PRESENT	0
621032	618092	14259Y	PARTICIPANT	\N	PRESENT	0
621033	618092	14073Q	PARTICIPANT	\N	PRESENT	0
621034	618092	04035D	PARTICIPANT	\N	PRESENT	0
621035	618092	20098N	PARTICIPANT	\N	PRESENT	0
621036	618092	20126Y	PARTICIPANT	\N	PRESENT	0
621037	618092	20048C	PARTICIPANT	\N	PRESENT	0
621038	618092	19441R	PARTICIPANT	\N	PRESENT	0
621039	618092	19479G	PARTICIPANT	\N	PRESENT	0
621040	618092	19721W	PARTICIPANT	\N	PRESENT	0
621041	618092	04042C	PARTICIPANT	\N	PRESENT	0
621042	618092	19739H	PARTICIPANT	\N	PRESENT	0
621043	618092	20066E	PARTICIPANT	\N	PRESENT	0
621044	618092	19057M	PARTICIPANT	\N	PRESENT	0
621045	618092	20054A	PARTICIPANT	\N	PRESENT	0
621155	621151	19533U	PARTICIPANT	\N	PRESENT	0
621129	621128	14327T	PARTICIPANT	\N	PRESENT	0
621153	621151	14207L	PARTICIPANT	\N	PRESENT	0
621159	621151	20132W	PARTICIPANT	\N	PRESENT	0
621160	621151	19954N	PARTICIPANT	\N	PRESENT	1
621162	621151	19798U	PARTICIPANT	\N	PRESENT	1
621169	621151	19820Y	PARTICIPANT	\N	PRESENT	1
621726	621725	14030Q	PARTICIPANT	\N	PRESENT	0
621727	621725	14083S	PARTICIPANT	\N	PRESENT	0
621728	621725	20054A	PARTICIPANT	\N	PRESENT	0
621729	621725	19515S	PARTICIPANT	\N	PRESENT	0
621730	621725	20094J	PARTICIPANT	\N	PRESENT	0
621731	621725	19671E	PARTICIPANT	\N	PRESENT	0
621732	621725	20048C	PARTICIPANT	\N	PRESENT	0
621733	621725	19762G	PARTICIPANT	\N	PRESENT	0
621735	621734	20126Y	PARTICIPANT	\N	PRESENT	0
621736	621734	19671E	PARTICIPANT	\N	PRESENT	0
621737	621734	14030Q	PARTICIPANT	\N	PRESENT	0
621738	621734	19762G	PARTICIPANT	\N	PRESENT	0
621739	621734	20048C	PARTICIPANT	\N	PRESENT	0
621741	621740	19467C	PARTICIPANT	\N	PRESENT	0
621742	621740	14030Q	PARTICIPANT	\N	PRESENT	0
621743	621740	14083S	PARTICIPANT	\N	PRESENT	0
621744	621740	19762G	PARTICIPANT	\N	PRESENT	0
621745	621740	20048C	PARTICIPANT	\N	PRESENT	0
621747	621746	19515S	PARTICIPANT	\N	PRESENT	0
621748	621746	14030Q	PARTICIPANT	\N	PRESENT	0
621749	621746	14083S	PARTICIPANT	\N	PRESENT	0
621750	621746	19467C	PARTICIPANT	\N	PRESENT	0
621751	621746	20048C	PARTICIPANT	\N	PRESENT	0
621752	621746	16685X	PARTICIPANT	\N	PRESENT	0
621753	621746	19697Q	PARTICIPANT	\N	PRESENT	0
621754	621746	19762G	PARTICIPANT	\N	PRESENT	0
621760	621757	14033T	PARTICIPANT	\N	PRESENT	0
621761	621758	14033T	PARTICIPANT	\N	PRESENT	0
621762	621759	14033T	PARTICIPANT	\N	PRESENT	0
621771	621769	14033T	PARTICIPANT	\N	PRESENT	0
621776	621772	14033T	PARTICIPANT	\N	PRESENT	0
621777	621773	14033T	PARTICIPANT	\N	PRESENT	0
621778	621774	14033T	PARTICIPANT	\N	PRESENT	0
621783	621782	11053K	PARTICIPANT	\N	PRESENT	0
621780	621775	14033T	PARTICIPANT	\N	PRESENT	0
621781	621770	14033T	PARTICIPANT	\N	PRESENT	0
601093	601092	11033F	PARTICIPANT	\N	PRESENT	0
601094	601092	19447X	PARTICIPANT	\N	PRESENT	0
601095	601092	11026G	PARTICIPANT	\N	PRESENT	0
605317	603147	14357A	PARTICIPANT	\N	PRESENT	0
605318	603147	19721W	PARTICIPANT	\N	PRESENT	0
605319	603147	11070L	PARTICIPANT	\N	PRESENT	0
605320	603147	14329V	PARTICIPANT	\N	PRESENT	0
605321	603147	14327T	PARTICIPANT	\N	PRESENT	0
605322	603147	14213J	PARTICIPANT	\N	PRESENT	0
605323	603147	17229F	PARTICIPANT	\N	PRESENT	0
605324	603147	01024M	PARTICIPANT	\N	PRESENT	0
605325	603147	19577H	PARTICIPANT	\N	PRESENT	0
605326	603147	20024T	PARTICIPANT	\N	PRESENT	0
605327	603147	99004R	PARTICIPANT	\N	PRESENT	0
605328	603147	20040T	PARTICIPANT	\N	PRESENT	0
605329	603147	19581D	PARTICIPANT	\N	PRESENT	0
605330	603147	01025N	PARTICIPANT	\N	PRESENT	0
605331	603147	20148F	PARTICIPANT	\N	PRESENT	0
605332	603147	20108W	PARTICIPANT	\N	PRESENT	0
605333	603147	20104S	PARTICIPANT	\N	PRESENT	0
605334	603147	20180F	PARTICIPANT	\N	PRESENT	0
605335	603147	19691J	PARTICIPANT	\N	PRESENT	0
605336	603147	08069G	PARTICIPANT	\N	PRESENT	0
605337	603147	20066E	PARTICIPANT	\N	PRESENT	0
605338	603147	14031R	PARTICIPANT	\N	PRESENT	0
605339	603147	19511N	PARTICIPANT	\N	PRESENT	0
605340	603147	20252E	PARTICIPANT	\N	PRESENT	0
605341	603147	19611R	PARTICIPANT	\N	PRESENT	0
605342	603147	14205J	PARTICIPANT	\N	PRESENT	0
605343	603147	19707Y	PARTICIPANT	\N	PRESENT	0
605344	603147	14219Q	PARTICIPANT	\N	PRESENT	0
605345	603147	19443T	PARTICIPANT	\N	PRESENT	0
605346	603147	07004J	PARTICIPANT	\N	PRESENT	0
605347	603147	20098N	PARTICIPANT	\N	PRESENT	0
605348	603147	20026V	PARTICIPANT	\N	PRESENT	0
605349	603147	11085T	PARTICIPANT	\N	PRESENT	0
605350	603147	19335Q	PARTICIPANT	\N	PRESENT	0
605351	603147	19467C	PARTICIPANT	\N	PRESENT	0
605352	603147	18083K	PARTICIPANT	\N	PRESENT	0
605353	603147	19369B	PARTICIPANT	\N	PRESENT	0
605354	603147	20140W	PARTICIPANT	\N	PRESENT	0
605355	603147	19723Y	PARTICIPANT	\N	PRESENT	0
605356	603147	19739H	PARTICIPANT	\N	PRESENT	0
605357	603147	19619A	PARTICIPANT	\N	PRESENT	0
605358	603147	14038Y	PARTICIPANT	\N	PRESENT	0
605359	603147	20086J	PARTICIPANT	\N	PRESENT	0
605360	603147	19954N	PARTICIPANT	\N	PRESENT	0
605361	603147	20022R	PARTICIPANT	\N	PRESENT	0
605362	603147	20044X	PARTICIPANT	\N	PRESENT	0
605363	603147	19663E	PARTICIPANT	\N	PRESENT	0
605364	603147	19709B	PARTICIPANT	\N	PRESENT	0
605365	603147	20096L	PARTICIPANT	\N	PRESENT	0
605366	603147	07029T	PARTICIPANT	\N	PRESENT	0
605367	603147	14069U	PARTICIPANT	\N	PRESENT	0
605368	603147	20078J	PARTICIPANT	\N	PRESENT	0
605369	603147	19705W	PARTICIPANT	\N	PRESENT	0
605370	603147	19766L	PARTICIPANT	\N	PRESENT	0
605371	603147	19768N	PARTICIPANT	\N	PRESENT	0
605372	603147	11101A	PARTICIPANT	\N	PRESENT	0
605373	603147	08056B	PARTICIPANT	\N	PRESENT	0
605374	603147	20124W	PARTICIPANT	\N	PRESENT	0
605375	603147	20032T	PARTICIPANT	\N	PRESENT	0
605376	603147	20076G	PARTICIPANT	\N	PRESENT	0
605377	603147	05008E	PARTICIPANT	\N	PRESENT	0
605378	603147	19667J	PARTICIPANT	\N	PRESENT	0
605379	603147	19643A	PARTICIPANT	\N	PRESENT	0
605380	603147	19747H	PARTICIPANT	\N	PRESENT	0
605381	603147	14179A	PARTICIPANT	\N	PRESENT	0
605382	603147	14187A	PARTICIPANT	\N	PRESENT	0
605383	603147	20038A	PARTICIPANT	\N	PRESENT	0
605406	603147	01058X	PARTICIPANT	\N	PRESENT	0
605385	603147	19507S	PARTICIPANT	\N	PRESENT	0
605386	603147	14123H	PARTICIPANT	\N	PRESENT	0
605387	603147	20048C	PARTICIPANT	\N	PRESENT	0
605388	603147	01057W	PARTICIPANT	\N	PRESENT	0
605389	603147	08015R	PARTICIPANT	\N	PRESENT	0
605390	603147	19489J	PARTICIPANT	\N	PRESENT	0
605391	603147	14147R	PARTICIPANT	\N	PRESENT	0
605408	603147	19421M	PARTICIPANT	\N	PRESENT	0
605393	603147	19671E	PARTICIPANT	\N	PRESENT	0
605394	603147	97011G	PARTICIPANT	\N	PRESENT	0
605395	603147	20120S	PARTICIPANT	\N	PRESENT	0
605396	603147	19679N	PARTICIPANT	\N	PRESENT	0
605397	603147	14071N	PARTICIPANT	\N	PRESENT	0
605398	603147	14253S	PARTICIPANT	\N	PRESENT	0
605399	603147	19573D	PARTICIPANT	\N	PRESENT	0
605400	603147	08047A	PARTICIPANT	\N	PRESENT	0
605401	603147	19533U	PARTICIPANT	\N	PRESENT	0
605402	603147	20134Y	PARTICIPANT	\N	PRESENT	0
605403	603147	20034V	PARTICIPANT	\N	PRESENT	0
605404	603147	14275Y	PARTICIPANT	\N	PRESENT	0
605405	603147	14237S	PARTICIPANT	\N	PRESENT	0
605407	603147	11043H	PARTICIPANT	\N	PRESENT	0
605409	603147	20094J	PARTICIPANT	\N	PRESENT	0
605410	603147	01060R	PARTICIPANT	\N	PRESENT	0
605411	603147	14055N	PARTICIPANT	\N	PRESENT	0
605412	603147	14033T	PARTICIPANT	\N	PRESENT	0
605413	603147	20126Y	PARTICIPANT	\N	PRESENT	0
605417	603147	04043D	PARTICIPANT	\N	PRESENT	0
605415	603147	20100N	PARTICIPANT	\N	PRESENT	0
605416	603147	20136B	PARTICIPANT	\N	PRESENT	0
605418	603147	14355X	PARTICIPANT	\N	PRESENT	0
605419	603147	04033B	PARTICIPANT	\N	PRESENT	0
605420	603147	19647E	PARTICIPANT	\N	PRESENT	0
605421	603147	19745F	PARTICIPANT	\N	PRESENT	0
605422	603147	20080C	PARTICIPANT	\N	PRESENT	0
605423	603147	11026G	PARTICIPANT	\N	PRESENT	0
605424	603147	04070G	PARTICIPANT	\N	PRESENT	0
605428	603147	20138D	PARTICIPANT	\N	PRESENT	0
605429	603147	20106U	PARTICIPANT	\N	PRESENT	0
605430	603147	19441R	PARTICIPANT	\N	PRESENT	0
605431	603147	05012A	PARTICIPANT	\N	PRESENT	0
605432	603147	17737W	PARTICIPANT	\N	PRESENT	0
605433	603147	19447X	PARTICIPANT	\N	PRESENT	0
605434	603147	01034P	PARTICIPANT	\N	PRESENT	0
605722	603149	99004R	PARTICIPANT	\N	PRESENT	0
605723	603149	11048N	PARTICIPANT	\N	PRESENT	0
605724	603149	14225N	PARTICIPANT	\N	PRESENT	0
605725	603149	19711U	PARTICIPANT	\N	PRESENT	0
605726	603149	19689Q	PARTICIPANT	\N	PRESENT	0
605727	603149	19687N	PARTICIPANT	\N	PRESENT	0
605728	603149	11053K	PARTICIPANT	\N	PRESENT	0
605729	603149	20116W	PARTICIPANT	\N	PRESENT	0
605730	603149	19647E	PARTICIPANT	\N	PRESENT	0
605731	603149	08073C	PARTICIPANT	\N	PRESENT	0
605732	603149	19545Y	PARTICIPANT	\N	PRESENT	0
605733	603149	11070L	PARTICIPANT	\N	PRESENT	0
605734	603149	20080C	PARTICIPANT	\N	PRESENT	0
605735	603149	20124W	PARTICIPANT	\N	PRESENT	0
605736	603149	11040E	PARTICIPANT	\N	PRESENT	0
605738	603149	20252E	PARTICIPANT	\N	PRESENT	0
605739	603149	14223L	PARTICIPANT	\N	PRESENT	0
605740	603149	19657G	PARTICIPANT	\N	PRESENT	0
605741	603149	14105F	PARTICIPANT	\N	PRESENT	0
605742	603149	11056N	PARTICIPANT	\N	PRESENT	0
605743	601164	19333N	PARTICIPANT	\N	PRESENT	0
605744	601164	14031R	PARTICIPANT	\N	PRESENT	0
605745	601164	19826F	PARTICIPANT	\N	PRESENT	0
605746	601164	19599P	PARTICIPANT	\N	PRESENT	0
605747	601164	17229F	PARTICIPANT	\N	PRESENT	0
605748	601164	19637C	PARTICIPANT	\N	PRESENT	0
605749	601164	20100N	PARTICIPANT	\N	PRESENT	0
605750	601164	18083K	PARTICIPANT	\N	PRESENT	0
605751	601164	19551W	PARTICIPANT	\N	PRESENT	0
605752	601164	08060W	PARTICIPANT	\N	PRESENT	0
605753	601164	19503N	PARTICIPANT	\N	PRESENT	0
605754	601164	20020P	PARTICIPANT	\N	PRESENT	0
605755	601164	19745F	PARTICIPANT	\N	PRESENT	0
605756	601164	20024T	PARTICIPANT	\N	PRESENT	0
605757	601164	19525U	PARTICIPANT	\N	PRESENT	0
605758	601164	20120S	PARTICIPANT	\N	PRESENT	0
605759	603149	19479G	PARTICIPANT	\N	PRESENT	0
605760	603149	19741B	PARTICIPANT	\N	PRESENT	0
605762	603149	20032T	PARTICIPANT	\N	PRESENT	0
605764	603149	19507S	PARTICIPANT	\N	PRESENT	0
605768	603149	19760E	PARTICIPANT	\N	PRESENT	0
605769	603149	14069U	PARTICIPANT	\N	PRESENT	0
605770	603149	20062A	PARTICIPANT	\N	PRESENT	0
619047	618088	19563B	PARTICIPANT	\N	PRESENT	0
619048	618088	19954N	PARTICIPANT	\N	PRESENT	0
619049	618088	19367Y	PARTICIPANT	\N	PRESENT	0
619050	618088	19762G	PARTICIPANT	\N	PRESENT	0
619051	618088	20252E	PARTICIPANT	\N	PRESENT	0
619052	618088	11110B	PARTICIPANT	\N	PRESENT	0
619053	618088	20020P	PARTICIPANT	\N	PRESENT	0
619054	618088	19709B	PARTICIPANT	\N	PRESENT	0
619055	618088	19671E	PARTICIPANT	\N	PRESENT	0
619056	618088	19383Y	PARTICIPANT	\N	PRESENT	0
619057	618088	20128B	PARTICIPANT	\N	PRESENT	0
619058	618088	14026U	PARTICIPANT	\N	PRESENT	0
619059	618088	19599P	PARTICIPANT	\N	PRESENT	0
619061	618088	08056B	PARTICIPANT	\N	PRESENT	0
619063	618088	11027H	PARTICIPANT	\N	PRESENT	0
619064	618088	19335Q	PARTICIPANT	\N	PRESENT	0
619065	618088	08034U	PARTICIPANT	\N	PRESENT	0
619066	618088	19713W	PARTICIPANT	\N	PRESENT	0
619067	618088	17737W	PARTICIPANT	\N	PRESENT	0
619068	618088	14249W	PARTICIPANT	\N	PRESENT	0
619069	618088	04059M	PARTICIPANT	\N	PRESENT	0
619070	618088	11048N	PARTICIPANT	\N	PRESENT	0
619071	618088	17589D	PARTICIPANT	\N	PRESENT	0
619072	618088	19585H	PARTICIPANT	\N	PRESENT	0
619073	618088	14033T	PARTICIPANT	\N	PRESENT	0
619074	618088	20030R	PARTICIPANT	\N	PRESENT	0
619075	618088	20018V	PARTICIPANT	\N	PRESENT	0
619076	618088	14073Q	PARTICIPANT	\N	PRESENT	0
619079	618088	20028X	PARTICIPANT	\N	PRESENT	0
619082	618088	11064N	PARTICIPANT	\N	PRESENT	0
619083	618088	19347U	PARTICIPANT	\N	PRESENT	0
619084	618088	17023S	PARTICIPANT	\N	PRESENT	0
619085	618088	20122U	PARTICIPANT	\N	PRESENT	0
619086	618088	19413M	PARTICIPANT	\N	PRESENT	0
619087	618088	95041E	PARTICIPANT	\N	PRESENT	0
619088	618088	19826F	PARTICIPANT	\N	PRESENT	0
619089	618088	20114U	PARTICIPANT	\N	PRESENT	0
619090	618088	14151M	PARTICIPANT	\N	PRESENT	0
619091	618088	19333N	PARTICIPANT	\N	PRESENT	0
619092	618088	20100N	PARTICIPANT	\N	PRESENT	0
619093	618088	20266L	PARTICIPANT	\N	PRESENT	0
619094	618088	19503N	PARTICIPANT	\N	PRESENT	0
619095	618088	20050V	PARTICIPANT	\N	PRESENT	0
619096	618088	19739H	PARTICIPANT	\N	PRESENT	0
619097	618088	20142Y	PARTICIPANT	\N	PRESENT	0
619098	618088	14059S	PARTICIPANT	\N	PRESENT	0
619099	618088	20032T	PARTICIPANT	\N	PRESENT	0
619100	618357	11031D	PARTICIPANT	\N	PRESENT	0
619101	618357	19295A	PARTICIPANT	\N	PRESENT	0
619102	618357	10006L	PARTICIPANT	\N	PRESENT	0
619103	618357	14026U	PARTICIPANT	\N	PRESENT	0
619104	618088	08069G	PARTICIPANT	\N	PRESENT	0
619105	618357	19715Y	PARTICIPANT	\N	PRESENT	0
619106	618088	19747H	PARTICIPANT	\N	PRESENT	0
619107	618088	14231L	PARTICIPANT	\N	PRESENT	0
619108	618088	19760E	PARTICIPANT	\N	PRESENT	0
619109	618357	19683J	PARTICIPANT	\N	PRESENT	0
619110	618357	20130U	PARTICIPANT	\N	PRESENT	0
619111	618357	11045K	PARTICIPANT	\N	PRESENT	0
619112	618088	17779H	PARTICIPANT	\N	PRESENT	0
619114	618088	14331P	PARTICIPANT	\N	PRESENT	0
619115	618088	16685X	PARTICIPANT	\N	PRESENT	0
619116	618088	20092G	PARTICIPANT	\N	PRESENT	0
619117	618088	14259Y	PARTICIPANT	\N	PRESENT	0
619118	618088	19533U	PARTICIPANT	\N	PRESENT	0
619119	618088	14083S	PARTICIPANT	\N	PRESENT	0
619120	618088	20134Y	PARTICIPANT	\N	PRESENT	0
619121	618088	19543W	PARTICIPANT	\N	PRESENT	0
619122	618088	20078J	PARTICIPANT	\N	PRESENT	0
619124	618410	19667J	PRESIDENT	0	PRESENT	0
619125	618410	04085P	PARTICIPANT	\N	PRESENT	0
619126	618410	14257W	PARTICIPANT	\N	PRESENT	0
619127	618088	19443T	PARTICIPANT	\N	PRESENT	0
619128	618088	20068G	PARTICIPANT	\N	PRESENT	0
619129	618088	19768N	PARTICIPANT	\N	PRESENT	0
619130	618088	11085T	PARTICIPANT	\N	PRESENT	0
619131	618088	19591F	PARTICIPANT	\N	PRESENT	0
619135	618088	20024T	PARTICIPANT	\N	PRESENT	0
619136	618088	19685L	PARTICIPANT	\N	PRESENT	0
619137	618088	20102Q	PARTICIPANT	\N	PRESENT	0
619138	618088	19251M	PARTICIPANT	\N	PRESENT	0
619139	618088	19611R	PARTICIPANT	\N	PRESENT	0
619140	618088	20264J	PARTICIPANT	\N	PRESENT	0
619141	618088	08061X	PARTICIPANT	\N	PRESENT	0
619142	618088	19717B	PARTICIPANT	\N	PRESENT	0
619143	618088	20080C	PARTICIPANT	\N	PRESENT	0
619144	618088	19669L	PARTICIPANT	\N	PRESENT	0
619145	618088	19699S	PARTICIPANT	\N	PRESENT	0
619146	618088	19647E	PARTICIPANT	\N	PRESENT	0
619147	618088	14069U	PARTICIPANT	\N	PRESENT	0
619148	618088	19551W	PARTICIPANT	\N	PRESENT	0
619149	618088	19697Q	PARTICIPANT	\N	PRESENT	0
619150	618410	19531S	PARTICIPANT	\N	PRESENT	1
619151	618410	19711U	PARTICIPANT	\N	PRESENT	1
619153	618088	19735D	PARTICIPANT	\N	PRESENT	0
619154	618088	14225N	PARTICIPANT	\N	PRESENT	0
619155	618088	08018U	PARTICIPANT	\N	PRESENT	0
619156	618088	20096L	PARTICIPANT	\N	PRESENT	0
619157	618088	20104S	PARTICIPANT	\N	PRESENT	0
619158	618088	11072N	PARTICIPANT	\N	PRESENT	0
619160	618088	20052X	PARTICIPANT	\N	PRESENT	0
619161	618088	14123H	PARTICIPANT	\N	PRESENT	0
619162	618410	20044X	PARTICIPANT	\N	PRESENT	1
619163	618367	11067R	PARTICIPANT	\N	PRESENT	0
619164	618367	20090E	PARTICIPANT	\N	PRESENT	0
619165	618367	14355X	PARTICIPANT	\N	PRESENT	1
619166	618367	19569H	PARTICIPANT	\N	PRESENT	0
619167	618367	11097X	PARTICIPANT	\N	PRESENT	0
619168	618367	14223L	PARTICIPANT	\N	PRESENT	0
619169	618367	18193Q	PARTICIPANT	\N	PRESENT	0
619170	618367	14026U	PARTICIPANT	\N	PRESENT	0
619171	618367	17779H	PARTICIPANT	\N	PRESENT	1
619172	618367	19553Y	PARTICIPANT	\N	PRESENT	0
619173	618367	14042U	PARTICIPANT	\N	PRESENT	0
619174	618367	14195A	PARTICIPANT	\N	PRESENT	0
619175	618367	19367Y	PARTICIPANT	\N	PRESENT	0
619176	618367	14217N	PARTICIPANT	\N	PRESENT	0
619177	618367	10006L	PARTICIPANT	\N	PRESENT	0
619178	618367	19683J	PARTICIPANT	\N	PRESENT	0
619179	618367	20130U	PARTICIPANT	\N	PRESENT	0
619180	618367	04092N	PRESIDENT	0	PRESENT	0
619181	618367	19713W	PARTICIPANT	\N	PRESENT	0
619182	618367	20040T	PARTICIPANT	\N	PRESENT	0
619183	618367	19663E	PARTICIPANT	\N	PRESENT	0
619184	618367	19691J	PARTICIPANT	\N	PRESENT	0
619185	618367	20066E	PARTICIPANT	\N	PRESENT	0
619186	618367	20266L	PARTICIPANT	\N	PRESENT	0
619187	618367	19657G	PARTICIPANT	\N	PRESENT	0
619188	618367	04043D	PARTICIPANT	\N	PRESENT	1
619191	618359	04047H	PRESIDENT	0	PRESENT	0
619192	618359	04008A	PARTICIPANT	\N	PRESENT	0
619193	618359	05008E	PARTICIPANT	\N	PRESENT	0
619194	618359	14001X	PARTICIPANT	\N	PRESENT	0
619195	618359	19543W	PARTICIPANT	\N	PRESENT	0
619196	618359	19673G	PARTICIPANT	\N	PRESENT	0
619197	618359	01028R	PARTICIPANT	\N	PRESENT	0
619198	618359	19447X	PARTICIPANT	\N	PRESENT	0
619199	618359	19954N	PARTICIPANT	\N	PRESENT	0
619200	618359	19489J	PARTICIPANT	\N	PRESENT	0
619201	618359	17737W	PARTICIPANT	\N	PRESENT	0
619202	618359	20108W	PARTICIPANT	\N	PRESENT	0
619203	618359	20110Q	PARTICIPANT	\N	PRESENT	0
619204	618359	14179A	PARTICIPANT	\N	PRESENT	0
619205	618359	14147R	PARTICIPANT	\N	PRESENT	0
619206	618359	14151M	PARTICIPANT	\N	PRESENT	0
619207	618359	20114U	PARTICIPANT	\N	PRESENT	0
619208	618359	14215L	PARTICIPANT	\N	PRESENT	0
619209	618359	08018U	PARTICIPANT	\N	PRESENT	0
619210	618359	14259Y	PARTICIPANT	\N	PRESENT	0
619211	618359	20022R	PARTICIPANT	\N	PRESENT	0
619212	618359	19649G	PARTICIPANT	\N	PRESENT	0
619213	618359	14111D	PARTICIPANT	\N	PRESENT	0
619214	618359	11026G	PARTICIPANT	\N	PRESENT	0
619215	618359	10015M	PARTICIPANT	\N	PRESENT	0
619216	618359	11033F	PARTICIPANT	\N	PRESENT	0
619217	618359	14069U	PARTICIPANT	\N	PRESENT	0
619224	618359	19629C	PARTICIPANT	\N	PRESENT	1
619225	618359	19725B	PARTICIPANT	\N	PRESENT	1
619226	618359	20128B	PARTICIPANT	\N	PRESENT	1
619870	618360	17737W	PARTICIPANT	\N	PRESENT	0
619871	618360	14089Y	PARTICIPANT	\N	PRESENT	0
601485	601098	11070L	PARTICIPANT	\N	PRESENT	0
601490	601098	19569H	PARTICIPANT	\N	PRESENT	0
601491	601098	20062A	PARTICIPANT	\N	PRESENT	0
601492	601098	18193Q	PARTICIPANT	\N	PRESENT	0
601493	601098	19415P	PARTICIPANT	\N	PRESENT	0
601494	601098	14217N	PARTICIPANT	\N	PRESENT	0
601495	601098	19515S	PARTICIPANT	\N	PRESENT	0
601496	601098	14195A	PARTICIPANT	\N	PRESENT	0
601497	601098	19715Y	PARTICIPANT	\N	PRESENT	0
601498	601098	14042U	PARTICIPANT	\N	PRESENT	0
601499	601098	20090E	PARTICIPANT	\N	PRESENT	0
601500	601098	14059S	PARTICIPANT	\N	PRESENT	0
601501	601098	19798U	PARTICIPANT	\N	PRESENT	0
601502	601098	01034P	PARTICIPANT	\N	PRESENT	0
601503	601098	04057K	PARTICIPANT	\N	PRESENT	0
601504	601098	19683J	PARTICIPANT	\N	PRESENT	0
601505	601098	20130U	PARTICIPANT	\N	PRESENT	0
601506	601098	08045X	PARTICIPANT	\N	PRESENT	0
601507	601098	19301E	PARTICIPANT	\N	PRESENT	0
601508	601098	11026G	PARTICIPANT	\N	PRESENT	0
601509	601098	19657G	PARTICIPANT	\N	PRESENT	0
601510	601098	14213J	PARTICIPANT	\N	PRESENT	0
601511	601098	19723Y	PARTICIPANT	\N	PRESENT	0
601512	601098	14038Y	PARTICIPANT	\N	PRESENT	0
601513	601098	17779H	PARTICIPANT	\N	PRESENT	0
601514	601098	04092N	PARTICIPANT	\N	PRESENT	0
601515	601098	14026U	PARTICIPANT	\N	PRESENT	0
601516	601098	97011G	PARTICIPANT	\N	PRESENT	0
601517	601098	20098N	PARTICIPANT	\N	PRESENT	0
601518	601098	08028W	PARTICIPANT	\N	PRESENT	0
601519	601098	11103C	PARTICIPANT	\N	PRESENT	0
601520	601098	14071N	PARTICIPANT	\N	PRESENT	0
601521	601098	11097X	PARTICIPANT	\N	PRESENT	0
601522	601098	20076G	PARTICIPANT	\N	PRESENT	0
601523	601098	19760E	PARTICIPANT	\N	PRESENT	0
601524	601098	11031D	PARTICIPANT	\N	PRESENT	0
601525	601098	19447X	PARTICIPANT	\N	PRESENT	0
601526	601098	19681G	PARTICIPANT	\N	PRESENT	0
601527	601098	19507S	PARTICIPANT	\N	PRESENT	0
601528	601098	20108W	PARTICIPANT	\N	PRESENT	0
601529	601098	10006L	PARTICIPANT	\N	PRESENT	0
601530	601098	20026V	PARTICIPANT	\N	PRESENT	0
601531	601098	17965H	PARTICIPANT	\N	PRESENT	0
601532	601098	20248J	PARTICIPANT	\N	PRESENT	0
601533	601098	20180F	PARTICIPANT	\N	PRESENT	0
601759	600637	14053L	PARTICIPANT	\N	PRESENT	0
601535	601098	19758L	PARTICIPANT	\N	PRESENT	0
601536	601098	20132W	PARTICIPANT	\N	PRESENT	0
601537	601098	19527W	PARTICIPANT	\N	PRESENT	0
601538	601098	19553Y	PARTICIPANT	\N	PRESENT	0
601539	601098	20044X	PARTICIPANT	\N	PRESENT	0
601540	601098	19745F	PARTICIPANT	\N	PRESENT	0
601541	601098	20066E	PARTICIPANT	\N	PRESENT	0
601542	601098	19533U	PARTICIPANT	\N	PRESENT	0
601543	601098	20172F	PARTICIPANT	\N	PRESENT	0
601544	601098	19703U	PARTICIPANT	\N	PRESENT	0
601545	600495	14327T	PARTICIPANT	\N	PRESENT	0
601546	600495	01048V	PARTICIPANT	\N	PRESENT	0
601547	600495	19545Y	PARTICIPANT	\N	PRESENT	0
601548	600495	14225N	PRESIDENT	0	PRESENT	0
601549	600495	19671E	PARTICIPANT	\N	PRESENT	0
601550	600495	11110B	PARTICIPANT	\N	PRESENT	0
601551	600495	07029T	PARTICIPANT	\N	PRESENT	0
601553	600495	19679N	PARTICIPANT	\N	PRESENT	0
601554	600495	19349W	PARTICIPANT	\N	PRESENT	0
601555	600495	20126Y	PARTICIPANT	\N	PRESENT	0
601556	600495	19479G	PARTICIPANT	\N	PRESENT	0
601557	600495	19711U	PARTICIPANT	\N	PRESENT	0
601558	600495	19687N	PARTICIPANT	\N	PRESENT	0
601559	600495	19689Q	PARTICIPANT	\N	PRESENT	0
601560	600495	12016W	PARTICIPANT	\N	PRESENT	0
601561	600495	20150Y	PARTICIPANT	\N	PRESENT	0
601562	600495	11040E	PARTICIPANT	\N	PRESENT	0
601563	600495	11012A	PARTICIPANT	\N	PRESENT	0
601564	600495	20070A	PARTICIPANT	\N	PRESENT	0
601565	600495	14121F	PARTICIPANT	\N	PRESENT	0
601567	600495	19762G	PARTICIPANT	\N	PRESENT	0
601568	600495	14189C	PARTICIPANT	\N	EXCUSE	0
601569	601098	19651A	PARTICIPANT	\N	PRESENT	0
601570	601098	20032T	PARTICIPANT	\N	PRESENT	0
601571	601098	19383Y	PARTICIPANT	\N	PRESENT	0
601572	601098	19503N	PARTICIPANT	\N	PRESENT	0
601573	601098	20140W	PARTICIPANT	\N	PRESENT	0
601574	601098	11043H	PARTICIPANT	\N	PRESENT	0
601575	601098	01025N	PARTICIPANT	\N	PRESENT	0
601576	601098	19591F	PARTICIPANT	\N	PRESENT	0
601577	601098	19713W	PARTICIPANT	\N	PRESENT	0
601578	601098	19826F	PARTICIPANT	\N	PRESENT	0
601579	601098	14147R	PARTICIPANT	\N	PRESENT	0
601580	601098	20030R	PARTICIPANT	\N	PRESENT	0
601581	601098	20056C	PARTICIPANT	\N	PRESENT	0
601582	601098	19782L	PARTICIPANT	\N	PRESENT	0
601583	601098	04043D	PARTICIPANT	\N	PRESENT	0
601584	601098	14207L	PARTICIPANT	\N	PRESENT	0
601585	601098	19739H	PARTICIPANT	\N	PRESENT	0
601586	601098	14357A	PARTICIPANT	\N	PRESENT	0
601587	601098	14105F	PARTICIPANT	\N	PRESENT	0
601588	601098	08056B	PARTICIPANT	\N	PRESENT	0
601589	601098	01024M	PARTICIPANT	\N	PRESENT	0
601590	601098	14223L	PARTICIPANT	\N	PRESENT	0
601591	601098	19467C	PARTICIPANT	\N	PRESENT	0
601592	601098	19699S	PARTICIPANT	\N	PRESENT	0
601593	601098	14281W	PARTICIPANT	\N	PRESENT	0
601594	601098	11067R	PARTICIPANT	\N	PRESENT	0
601595	601098	19663E	PARTICIPANT	\N	PRESENT	0
601596	601098	19387D	PARTICIPANT	\N	PRESENT	0
601597	601098	19575F	PARTICIPANT	\N	PRESENT	0
601598	601098	19367Y	PARTICIPANT	\N	PRESENT	0
601599	601098	19295A	PARTICIPANT	\N	PRESENT	0
601600	601098	20020P	PARTICIPANT	\N	PRESENT	0
601601	601098	14257W	PARTICIPANT	\N	PRESENT	0
601602	601098	04045F	PARTICIPANT	\N	PRESENT	0
601603	601098	14031R	PARTICIPANT	\N	PRESENT	0
601604	601098	20054A	PARTICIPANT	\N	PRESENT	0
601605	601098	19747H	PARTICIPANT	\N	PRESENT	0
601606	601098	19691J	PARTICIPANT	\N	PRESENT	0
601607	601098	20088L	PARTICIPANT	\N	PRESENT	0
601608	601098	20144B	PARTICIPANT	\N	PRESENT	0
601760	600637	14111D	PARTICIPANT	\N	PRESENT	0
601761	600637	19543W	PARTICIPANT	\N	PRESENT	0
601762	600637	04047H	PRESIDENT	0	PRESENT	0
601763	600637	14225N	PARTICIPANT	\N	PRESENT	0
601764	600637	01028R	PARTICIPANT	\N	PRESENT	0
601765	600637	14231L	PARTICIPANT	\N	PRESENT	0
601766	600637	19447X	PARTICIPANT	\N	PRESENT	0
601767	600637	05008E	PARTICIPANT	\N	PRESENT	0
601768	600637	11056N	PARTICIPANT	\N	PRESENT	0
601769	600637	19489J	PARTICIPANT	\N	PRESENT	0
601770	600637	20108W	PARTICIPANT	\N	PRESENT	0
601771	600637	20110Q	PARTICIPANT	\N	PRESENT	0
601772	600637	14215L	PARTICIPANT	\N	PRESENT	0
601773	600637	20022R	PARTICIPANT	\N	PRESENT	0
601774	600637	14259Y	PARTICIPANT	\N	PRESENT	0
601775	600637	11072N	PARTICIPANT	\N	PRESENT	0
601776	600637	19725B	PARTICIPANT	\N	PRESENT	0
601777	600637	19649G	PARTICIPANT	\N	PRESENT	0
601778	600637	14107H	PARTICIPANT	\N	PRESENT	0
601779	600637	14147R	PARTICIPANT	\N	PRESENT	0
601780	600637	14021P	PARTICIPANT	\N	PRESENT	0
601781	600637	19729F	PARTICIPANT	\N	EXCUSE	0
601782	600637	17737W	PARTICIPANT	\N	EXCUSE	0
601783	600637	19629C	PARTICIPANT	\N	EXCUSE	0
601784	601098	14225N	PARTICIPANT	\N	PRESENT	0
621281	621280	14089Y	PARTICIPANT	\N	PRESENT	0
621282	621280	19749K	PARTICIPANT	\N	PRESENT	0
621594	621410	14001X	PARTICIPANT	\N	PRESENT	1
621595	621410	19729F	PARTICIPANT	\N	PRESENT	1
621596	621410	07004J	PARTICIPANT	\N	PRESENT	1
621597	621410	20110Q	PARTICIPANT	\N	PRESENT	1
621598	621410	19725B	PARTICIPANT	\N	PRESENT	1
621599	621410	10015M	PARTICIPANT	\N	PRESENT	1
621600	621410	19954N	PARTICIPANT	\N	PRESENT	1
621601	621410	14021P	PARTICIPANT	\N	PRESENT	1
621602	621410	14147R	PARTICIPANT	\N	PRESENT	1
621603	621410	04085P	PARTICIPANT	\N	PRESENT	1
621604	621410	11056N	PARTICIPANT	\N	PRESENT	1
621605	621410	19489J	PARTICIPANT	\N	PRESENT	1
621606	621410	11026G	PARTICIPANT	\N	PRESENT	1
621607	621410	14179A	PARTICIPANT	\N	PRESENT	1
621608	621410	14151M	PARTICIPANT	\N	PRESENT	1
621609	621410	19649G	PARTICIPANT	\N	PRESENT	1
621610	621410	14231L	PARTICIPANT	\N	PRESENT	1
621611	621410	20128B	PARTICIPANT	\N	PRESENT	1
621612	621410	20074E	PARTICIPANT	\N	EXCUSE	0
621712	621411	19725B	PARTICIPANT	\N	PRESENT	1
621713	621411	14147R	PARTICIPANT	\N	PRESENT	1
621714	621411	11026G	PARTICIPANT	\N	PRESENT	1
621716	621411	20074E	PARTICIPANT	\N	EXCUSE	0
621767	621755	20066E	PARTICIPANT	\N	PRESENT	1
621768	621755	19713W	PARTICIPANT	\N	PRESENT	1
621784	621782	01028R	PARTICIPANT	\N	PRESENT	0
621791	621790	14026U	PARTICIPANT	\N	PRESENT	0
621792	621790	19725B	PARTICIPANT	\N	PRESENT	0
621793	621512	04059M	PARTICIPANT	\N	PRESENT	0
621794	621512	19651A	PARTICIPANT	\N	PRESENT	1
621814	621388	14026U	PARTICIPANT	\N	PRESENT	0
621815	621458	20180F	PARTICIPANT	\N	PRESENT	0
621816	621458	08012N	PARTICIPANT	\N	PRESENT	0
621798	621512	11053K	PARTICIPANT	\N	PRESENT	1
621817	621458	11043H	PARTICIPANT	\N	PRESENT	0
621818	621458	20152B	PARTICIPANT	\N	PRESENT	0
621819	621458	20026V	PARTICIPANT	\N	PRESENT	0
621820	621458	20172F	PARTICIPANT	\N	PRESENT	0
621803	621512	19399H	PARTICIPANT	\N	PRESENT	1
621804	621512	20056C	PARTICIPANT	\N	PRESENT	1
621805	621512	19611R	PRESIDENT	0	PRESENT	0
621806	621512	19699S	PARTICIPANT	\N	PRESENT	0
621821	621458	14229S	PARTICIPANT	\N	PRESENT	0
621808	621512	20142Y	PARTICIPANT	\N	PRESENT	0
621809	621512	19705W	PARTICIPANT	\N	PRESENT	1
621810	621512	14229S	PARTICIPANT	\N	PRESENT	0
621811	621512	19669L	PARTICIPANT	\N	PRESENT	1
621812	621512	20026V	PARTICIPANT	\N	PRESENT	1
621813	621512	20122U	PARTICIPANT	\N	PRESENT	0
621822	621458	20084G	PARTICIPANT	\N	PRESENT	0
621823	621458	19699S	PARTICIPANT	\N	PRESENT	0
621824	621458	20134Y	PARTICIPANT	\N	PRESENT	1
621825	621458	14073Q	PARTICIPANT	\N	PRESENT	0
621826	621458	19611R	PRESIDENT	0	PRESENT	0
621827	621458	14030Q	PARTICIPANT	\N	PRESENT	0
621828	621458	19573D	PARTICIPANT	\N	PRESENT	0
621829	621458	11104D	PARTICIPANT	\N	PRESENT	1
621830	621458	19621T	PARTICIPANT	\N	PRESENT	0
621831	621458	20132W	PARTICIPANT	\N	PRESENT	0
621832	621458	14109K	PARTICIPANT	\N	PRESENT	1
621833	621388	14001X	PARTICIPANT	\N	PRESENT	0
621834	621388	20116W	PARTICIPANT	\N	PRESENT	0
621835	621388	19741B	PARTICIPANT	\N	PRESENT	0
621836	621388	14179A	PARTICIPANT	\N	PRESENT	0
621837	621388	14267Y	PARTICIPANT	\N	PRESENT	0
621838	621388	20126Y	PARTICIPANT	\N	PRESENT	0
621839	621458	19533U	PARTICIPANT	\N	PRESENT	0
621840	621458	20056C	PARTICIPANT	\N	PRESENT	0
621841	621458	20124W	PARTICIPANT	\N	PRESENT	0
621842	621388	19531S	PARTICIPANT	\N	PRESENT	0
621845	621388	19347U	PARTICIPANT	\N	PRESENT	0
621846	621388	19685L	PARTICIPANT	\N	PRESENT	0
621850	621388	20122U	PARTICIPANT	\N	PRESENT	0
621854	621388	14331P	PARTICIPANT	\N	PRESENT	0
621855	621388	08009T	PARTICIPANT	\N	PRESENT	0
621856	621388	11027H	PARTICIPANT	\N	PRESENT	0
621857	621388	14223L	PARTICIPANT	\N	PRESENT	0
621858	621388	20094J	PARTICIPANT	\N	PRESENT	0
621859	621388	19782L	PARTICIPANT	\N	PRESENT	0
621860	621388	20058E	PARTICIPANT	\N	PRESENT	0
621861	621388	20036X	PARTICIPANT	\N	PRESENT	0
621862	621388	19954N	PARTICIPANT	\N	PRESENT	0
621863	621388	18083K	PARTICIPANT	\N	PRESENT	0
621864	621388	11031D	PARTICIPANT	\N	PRESENT	0
621865	621388	04092N	PARTICIPANT	\N	PRESENT	0
621866	621388	08015R	PARTICIPANT	\N	PRESENT	0
621867	621388	19709B	PARTICIPANT	\N	PRESENT	0
621868	621388	19369B	PARTICIPANT	\N	PRESENT	0
621869	621388	19758L	PARTICIPANT	\N	PRESENT	0
621870	621388	20062A	PARTICIPANT	\N	PRESENT	0
621871	621388	14147R	PARTICIPANT	\N	PRESENT	0
621874	621388	01028R	PARTICIPANT	\N	PRESENT	0
621876	621388	20266L	PARTICIPANT	\N	PRESENT	0
621882	621388	20118Y	PARTICIPANT	\N	PRESENT	0
621883	621388	11110B	PARTICIPANT	\N	PRESENT	0
621884	621388	20044X	PARTICIPANT	\N	PRESENT	0
621885	621388	14195A	PARTICIPANT	\N	PRESENT	0
621886	621388	20098N	PARTICIPANT	\N	PRESENT	0
621887	621388	19335Q	PARTICIPANT	\N	PRESENT	0
621888	621388	14217N	PARTICIPANT	\N	PRESENT	0
621889	621388	20018V	PARTICIPANT	\N	PRESENT	0
621890	621388	19721W	PARTICIPANT	\N	PRESENT	0
621891	621388	11101A	PARTICIPANT	\N	PRESENT	0
621892	621388	14107H	PARTICIPANT	\N	PRESENT	0
621893	621388	14193X	PARTICIPANT	\N	PRESENT	0
621894	621388	14053L	PARTICIPANT	\N	PRESENT	0
621895	621388	14073Q	PARTICIPANT	\N	PRESENT	0
621896	621388	20024T	PARTICIPANT	\N	PRESENT	0
621946	621389	20112S	PARTICIPANT	\N	PRESENT	0
621947	621389	19954N	PARTICIPANT	\N	PRESENT	0
621948	621389	14073Q	PARTICIPANT	\N	PRESENT	0
621949	621389	19387D	PARTICIPANT	\N	PRESENT	0
621950	621389	08012N	PARTICIPANT	\N	PRESENT	0
621951	621389	19349W	PARTICIPANT	\N	PRESENT	0
621952	621389	19585H	PARTICIPANT	\N	PRESENT	0
621953	621389	19533U	PARTICIPANT	\N	PRESENT	0
621954	621389	20134Y	PARTICIPANT	\N	PRESENT	0
621955	621389	19527W	PARTICIPANT	\N	PRESENT	0
621956	621389	14237S	PARTICIPANT	\N	PRESENT	0
621957	621389	20056C	PARTICIPANT	\N	PRESENT	0
621973	621389	20098N	PARTICIPANT	\N	PRESENT	0
621974	621285	20090E	PARTICIPANT	\N	PRESENT	0
621975	621285	07004J	PARTICIPANT	\N	PRESENT	0
621912	621389	19719D	PARTICIPANT	\N	PRESENT	0
621945	621389	11043H	PARTICIPANT	\N	PRESENT	0
621976	621285	19667J	PRESIDENT	0	PRESENT	0
621977	621285	20044X	PARTICIPANT	\N	PRESENT	0
621978	621285	04085P	PARTICIPANT	\N	PRESENT	0
621979	621389	19593H	PARTICIPANT	\N	PRESENT	0
621980	621389	19758L	PARTICIPANT	\N	PRESENT	0
621981	621389	19399H	PARTICIPANT	\N	PRESENT	0
621982	621389	14021P	PARTICIPANT	\N	PRESENT	0
621983	621389	17965H	PARTICIPANT	\N	PRESENT	0
621984	621389	19725B	PARTICIPANT	\N	PRESENT	0
621985	621389	14030Q	PARTICIPANT	\N	PRESENT	0
621986	621285	19711U	PARTICIPANT	\N	PRESENT	0
621987	621389	20152B	PARTICIPANT	\N	PRESENT	0
621988	621389	19621T	PARTICIPANT	\N	PRESENT	0
621989	621389	19643A	PARTICIPANT	\N	PRESENT	0
621990	621389	19717B	PARTICIPANT	\N	PRESENT	0
621991	621389	20052X	PARTICIPANT	\N	PRESENT	0
621992	621389	14189C	PARTICIPANT	\N	PRESENT	0
621993	621389	19611R	PARTICIPANT	\N	PRESENT	0
621994	621389	19573D	PARTICIPANT	\N	PRESENT	0
621995	621389	20132W	PARTICIPANT	\N	PRESENT	0
621996	621285	20064C	PARTICIPANT	\N	PRESENT	1
621997	621285	19531S	PARTICIPANT	\N	PRESENT	0
621998	621285	14249W	PARTICIPANT	\N	PRESENT	0
621999	621389	20058E	PARTICIPANT	\N	PRESENT	0
622000	621285	19741B	PARTICIPANT	\N	PRESENT	0
622002	621285	17737W	PARTICIPANT	\N	PRESENT	0
622003	621389	14033T	PARTICIPANT	\N	PRESENT	0
622007	621389	14207L	PARTICIPANT	\N	PRESENT	0
622008	621389	19729F	PARTICIPANT	\N	PRESENT	0
622009	621389	19699S	PARTICIPANT	\N	PRESENT	0
622010	621389	19443T	PARTICIPANT	\N	PRESENT	0
622012	621389	14229S	PARTICIPANT	\N	PRESENT	0
622014	621389	19679N	PARTICIPANT	\N	PRESENT	0
605771	603149	11104D	PARTICIPANT	\N	PRESENT	0
605772	603149	19747H	PARTICIPANT	\N	PRESENT	0
605773	603149	14021P	PARTICIPANT	\N	PRESENT	0
605774	603149	01057W	PARTICIPANT	\N	PRESENT	0
605775	603149	20044X	PARTICIPANT	\N	PRESENT	0
605778	603149	11041F	PARTICIPANT	\N	PRESENT	0
605779	603149	20070A	PARTICIPANT	\N	PRESENT	0
605780	603149	19399H	PARTICIPANT	\N	PRESENT	0
605781	603149	19349W	PARTICIPANT	\N	PRESENT	0
605782	603149	14089Y	PARTICIPANT	\N	PRESENT	0
605783	603149	01024M	PARTICIPANT	\N	PRESENT	0
605784	603149	19347U	PARTICIPANT	\N	PRESENT	0
605785	601164	19549D	PARTICIPANT	\N	PRESENT	0
605786	601164	14219Q	PRESIDENT	0	PRESENT	0
605787	601164	19820Y	PARTICIPANT	\N	PRESENT	0
605788	601164	05012A	PARTICIPANT	\N	PRESENT	0
605789	601164	20106U	PARTICIPANT	\N	PRESENT	0
605790	601164	19685L	PARTICIPANT	\N	PRESENT	0
605791	601164	20136B	PARTICIPANT	\N	PRESENT	0
605792	601164	20038A	PARTICIPANT	\N	PRESENT	0
605793	601164	19619A	PARTICIPANT	\N	PRESENT	0
605795	601164	19701S	PARTICIPANT	\N	EXCUSE	0
605796	601164	11065P	PARTICIPANT	\N	PRESENT	0
605797	603149	20086J	PARTICIPANT	\N	PRESENT	0
605798	603149	04033B	PARTICIPANT	\N	PRESENT	0
605799	603149	19671E	PARTICIPANT	\N	PRESENT	0
605800	603149	20036X	PARTICIPANT	\N	PRESENT	0
605801	603149	12016W	PARTICIPANT	\N	PRESENT	0
605802	603149	11067R	PARTICIPANT	\N	PRESENT	0
605803	603149	14109K	PARTICIPANT	\N	PRESENT	0
605804	603149	11012A	PARTICIPANT	\N	PRESENT	0
605805	603149	14073Q	PARTICIPANT	\N	PRESENT	0
605806	603149	19577H	PARTICIPANT	\N	PRESENT	0
605807	603149	11043H	PARTICIPANT	\N	PRESENT	0
605808	603149	14189C	PARTICIPANT	\N	PRESENT	0
605809	601164	20102Q	PARTICIPANT	\N	PRESENT	0
605810	603149	18193Q	PARTICIPANT	\N	PRESENT	0
605811	603149	20098N	PARTICIPANT	\N	PRESENT	0
605812	603149	20090E	PARTICIPANT	\N	PRESENT	0
605813	603149	20126Y	PARTICIPANT	\N	PRESENT	0
605814	603149	14083S	PARTICIPANT	\N	PRESENT	0
605815	603149	11097X	PARTICIPANT	\N	PRESENT	0
605816	603149	08034U	PARTICIPANT	\N	PRESENT	0
605817	603149	19335Q	PARTICIPANT	\N	PRESENT	0
605818	603149	19533U	PARTICIPANT	\N	PRESENT	0
605819	603149	19569H	PARTICIPANT	\N	PRESENT	0
605825	603149	19954N	PARTICIPANT	\N	PRESENT	0
605828	601164	20032T	PARTICIPANT	\N	PRESENT	0
605829	603149	19629C	PARTICIPANT	\N	PRESENT	0
605830	603149	19413M	PARTICIPANT	\N	PRESENT	0
605831	603149	19421M	PARTICIPANT	\N	PRESENT	0
605832	603149	17965H	PARTICIPANT	\N	PRESENT	0
605833	603149	97011G	PARTICIPANT	\N	PRESENT	0
605834	603149	19762G	PARTICIPANT	\N	PRESENT	0
605835	603149	19691J	PARTICIPANT	\N	PRESENT	0
605837	603149	20104S	PARTICIPANT	\N	PRESENT	0
605838	603149	20052X	PARTICIPANT	\N	PRESENT	0
605839	603149	19667J	PARTICIPANT	\N	PRESENT	0
605840	604494	19383Y	PARTICIPANT	\N	PRESENT	0
605841	604494	19768N	PARTICIPANT	\N	PRESENT	0
605842	604494	20088L	PARTICIPANT	\N	PRESENT	0
605843	604494	19515S	PARTICIPANT	\N	PRESENT	0
605844	604494	19782L	PARTICIPANT	\N	PRESENT	0
605845	604494	14357A	PARTICIPANT	\N	PRESENT	0
605846	604494	20078J	PARTICIPANT	\N	PRESENT	0
605847	604494	19441R	PARTICIPANT	\N	PRESENT	0
605848	604494	19413M	PARTICIPANT	\N	PRESENT	0
605849	604494	20082E	PARTICIPANT	\N	PRESENT	0
605850	604494	04045F	PARTICIPANT	\N	PRESENT	0
605851	604494	19866P	PARTICIPANT	\N	PRESENT	0
605852	604494	11099A	PARTICIPANT	\N	PRESENT	0
605853	604494	19705W	PARTICIPANT	\N	PRESENT	0
605854	604494	08015R	PARTICIPANT	\N	PRESENT	0
605855	604494	19575F	PARTICIPANT	\N	PRESENT	0
605856	604494	19369B	PARTICIPANT	\N	PRESENT	0
605857	604494	20018V	PARTICIPANT	\N	PRESENT	0
605858	604494	19511N	PARTICIPANT	\N	PRESENT	0
605859	604494	08028W	PARTICIPANT	\N	PRESENT	0
605860	604494	14038Y	PARTICIPANT	\N	PRESENT	0
605861	604494	19467C	PARTICIPANT	\N	PRESENT	0
605862	604494	20034V	PARTICIPANT	\N	PRESENT	0
605863	604494	14187A	PARTICIPANT	\N	PRESENT	0
605864	604494	20144B	PARTICIPANT	\N	PRESENT	0
605865	604494	19695N	PARTICIPANT	\N	PRESENT	0
605866	604494	11090Q	PRESIDENT	0	PRESENT	0
605867	604494	14033T	PARTICIPANT	\N	PRESENT	0
605868	604494	20060X	PARTICIPANT	\N	PRESENT	0
605869	604494	20062A	PARTICIPANT	\N	PRESENT	0
605870	604494	14207L	PARTICIPANT	\N	PRESENT	0
605871	604494	19747H	PARTICIPANT	\N	PRESENT	0
605872	603149	20088L	PARTICIPANT	\N	PRESENT	0
605873	603149	14357A	PARTICIPANT	\N	PRESENT	0
605874	603149	14033T	PARTICIPANT	\N	PRESENT	0
605875	603149	19782L	PARTICIPANT	\N	PRESENT	0
605876	603149	19443T	PARTICIPANT	\N	PRESENT	0
605877	603149	19515S	PARTICIPANT	\N	PRESENT	0
605878	603149	20018V	PARTICIPANT	\N	PRESENT	0
605879	603149	20142Y	PARTICIPANT	\N	PRESENT	0
605880	603149	14147R	PARTICIPANT	\N	PRESENT	0
605881	603149	20024T	PARTICIPANT	\N	PRESENT	0
605882	603149	17023S	PARTICIPANT	\N	PRESENT	0
605883	603149	20100N	PARTICIPANT	\N	PRESENT	0
605884	603149	19387D	PARTICIPANT	\N	PRESENT	0
605885	603149	19693L	PARTICIPANT	\N	PRESENT	0
605886	603149	20092G	PARTICIPANT	\N	PRESENT	0
605887	603149	14331P	PARTICIPANT	\N	PRESENT	0
605888	603149	14026U	PARTICIPANT	\N	PRESENT	0
605889	603149	20112S	PARTICIPANT	\N	PRESENT	0
605890	603149	07029T	PARTICIPANT	\N	PRESENT	0
605891	603149	19758L	PARTICIPANT	\N	PRESENT	0
605892	603149	19549D	PARTICIPANT	\N	PRESENT	0
605893	603149	14001X	PARTICIPANT	\N	PRESENT	0
605894	603149	19467C	PARTICIPANT	\N	PRESENT	0
605895	603149	08028W	PARTICIPANT	\N	PRESENT	0
605896	603149	18083K	PARTICIPANT	\N	PRESENT	0
605897	603149	01025N	PARTICIPANT	\N	PRESENT	0
605898	603149	08010L	PARTICIPANT	\N	PRESENT	0
605899	603149	14053L	PARTICIPANT	\N	PRESENT	0
605900	603149	11099A	PARTICIPANT	\N	PRESENT	0
605901	603149	08061X	PARTICIPANT	\N	PRESENT	0
605902	603149	11065P	PARTICIPANT	\N	PRESENT	0
605903	603149	20110Q	PARTICIPANT	\N	PRESENT	0
605904	603149	14215L	PARTICIPANT	\N	PRESENT	0
605905	603149	20130U	PARTICIPANT	\N	PRESENT	0
605906	603149	20266L	PARTICIPANT	\N	PRESENT	0
605907	603149	19441R	PARTICIPANT	\N	PRESENT	0
605908	603149	19563B	PARTICIPANT	\N	PRESENT	0
605909	603149	20048C	PARTICIPANT	\N	PRESENT	0
605910	603149	19679N	PARTICIPANT	\N	PRESENT	0
605962	603150	01043Q	PARTICIPANT	\N	PRESENT	0
605963	603150	20080C	PARTICIPANT	\N	PRESENT	0
605964	603150	19689Q	PARTICIPANT	\N	PRESENT	0
605965	603150	20036X	PARTICIPANT	\N	PRESENT	0
605966	603150	19441R	PARTICIPANT	\N	PRESENT	0
605967	603150	11070L	PARTICIPANT	\N	PRESENT	0
605968	603150	19563B	PARTICIPANT	\N	PRESENT	0
605969	603150	19671E	PARTICIPANT	\N	PRESENT	0
605970	603150	20252E	PARTICIPANT	\N	PRESENT	0
605971	603150	11048N	PARTICIPANT	\N	PRESENT	0
605972	603150	19687N	PARTICIPANT	\N	PRESENT	0
605973	603150	19711U	PARTICIPANT	\N	PRESENT	0
605974	603150	11043H	PARTICIPANT	\N	PRESENT	0
605975	603150	19349W	PARTICIPANT	\N	PRESENT	0
605976	603150	19647E	PARTICIPANT	\N	PRESENT	0
605977	603150	11053K	PARTICIPANT	\N	PRESENT	0
605978	603150	19657G	PARTICIPANT	\N	PRESENT	0
605979	603150	14033T	PARTICIPANT	\N	PRESENT	0
605980	603150	19577H	PARTICIPANT	\N	PRESENT	0
605981	603150	14215L	PARTICIPANT	\N	PRESENT	0
605982	603150	19335Q	PARTICIPANT	\N	PRESENT	0
605983	603150	19747H	PARTICIPANT	\N	PRESENT	0
605984	603150	11040E	PARTICIPANT	\N	PRESENT	0
605985	603150	19421M	PARTICIPANT	\N	PRESENT	0
605986	603150	20048C	PARTICIPANT	\N	PRESENT	0
605987	603150	14026U	PARTICIPANT	\N	PRESENT	0
605988	603150	07029T	PARTICIPANT	\N	PRESENT	0
605989	603150	19545Y	PARTICIPANT	\N	PRESENT	0
605990	603150	14357A	PARTICIPANT	\N	PRESENT	0
605991	603150	19741B	PARTICIPANT	\N	PRESENT	0
605992	603150	19762G	PARTICIPANT	\N	PRESENT	0
605993	603150	11097X	PARTICIPANT	\N	PRESENT	0
619892	618360	14259Y	PARTICIPANT	\N	PRESENT	0
620538	618091	20056C	PARTICIPANT	\N	PRESENT	0
620539	618091	20026V	PARTICIPANT	\N	PRESENT	0
620540	618091	20180F	PARTICIPANT	\N	PRESENT	0
620541	618091	20058E	PARTICIPANT	\N	PRESENT	0
620542	618091	14059S	PARTICIPANT	\N	PRESENT	0
620543	618091	20024T	PARTICIPANT	\N	PRESENT	0
620544	618091	14026U	PARTICIPANT	\N	PRESENT	0
620545	618091	14069U	PARTICIPANT	\N	PRESENT	0
620546	618091	20096L	PARTICIPANT	\N	PRESENT	0
620547	618091	19545Y	PARTICIPANT	\N	PRESENT	0
620548	618091	19629C	PARTICIPANT	\N	PRESENT	0
620549	618091	19295A	PARTICIPANT	\N	PRESENT	0
620550	618091	19758L	PARTICIPANT	\N	PRESENT	0
620551	618091	19695N	PARTICIPANT	\N	PRESENT	0
620552	618091	19565D	PARTICIPANT	\N	PRESENT	0
620553	618091	20046A	PARTICIPANT	\N	PRESENT	0
620554	618091	19593H	PARTICIPANT	\N	PRESENT	0
620555	618091	11056N	PARTICIPANT	\N	PRESENT	0
620556	618091	04070G	PARTICIPANT	\N	PRESENT	0
620557	618091	19826F	PARTICIPANT	\N	PRESENT	0
620558	618091	14205J	PARTICIPANT	\N	PRESENT	0
620559	618091	19721W	PARTICIPANT	\N	PRESENT	0
620560	618091	01058X	PARTICIPANT	\N	PRESENT	0
620561	618091	19693L	PARTICIPANT	\N	PRESENT	0
620562	618091	20172F	PARTICIPANT	\N	PRESENT	0
620563	618091	19525U	PARTICIPANT	\N	PRESENT	0
620564	618091	04047H	PARTICIPANT	\N	PRESENT	0
620565	618091	97011G	PARTICIPANT	\N	PRESENT	0
620566	618091	19399H	PARTICIPANT	\N	PRESENT	0
620567	618091	20108W	PARTICIPANT	\N	PRESENT	0
620568	618091	19723Y	PARTICIPANT	\N	PRESENT	0
620569	618091	20078J	PARTICIPANT	\N	PRESENT	0
620570	618091	19413M	PARTICIPANT	\N	PRESENT	0
620571	618091	19527W	PARTICIPANT	\N	PRESENT	0
620572	618091	19673G	PARTICIPANT	\N	PRESENT	0
620573	618091	19583F	PARTICIPANT	\N	PRESENT	0
620574	618091	11026G	PARTICIPANT	\N	PRESENT	0
620575	618091	19553Y	PARTICIPANT	\N	PRESENT	0
620576	618091	19543W	PARTICIPANT	\N	PRESENT	0
620577	618091	20094J	PARTICIPANT	\N	PRESENT	0
620578	618091	14073Q	PARTICIPANT	\N	PRESENT	0
620579	618363	20086J	PARTICIPANT	\N	PRESENT	0
620580	618363	14225N	PRESIDENT	0	PRESENT	0
620581	618091	11067R	PARTICIPANT	\N	PRESENT	0
620582	618091	14151M	PARTICIPANT	\N	PRESENT	0
620583	618091	19715Y	PARTICIPANT	\N	PRESENT	0
620584	618091	20042V	PARTICIPANT	\N	PRESENT	0
620585	618091	05008E	PARTICIPANT	\N	PRESENT	0
620586	618091	14217N	PARTICIPANT	\N	PRESENT	0
620587	618363	04057K	PARTICIPANT	\N	PRESENT	0
620588	618363	14073Q	PARTICIPANT	\N	PRESENT	0
620589	618363	19441R	PARTICIPANT	\N	PRESENT	0
620590	618363	20080C	PARTICIPANT	\N	PRESENT	0
620591	618363	20104S	PARTICIPANT	\N	PRESENT	0
620592	618091	95063L	PARTICIPANT	\N	PRESENT	0
620593	618412	17737W	PARTICIPANT	\N	PRESENT	0
620594	618091	19251M	PARTICIPANT	\N	PRESENT	0
620595	618091	20032T	PARTICIPANT	\N	PRESENT	0
620596	618091	19333N	PARTICIPANT	\N	PRESENT	0
620597	618091	20132W	PARTICIPANT	\N	PRESENT	0
620598	618091	20052X	PARTICIPANT	\N	PRESENT	0
620599	618091	20022R	PARTICIPANT	\N	PRESENT	0
620600	618091	20036X	PARTICIPANT	\N	PRESENT	0
620601	618091	19447X	PARTICIPANT	\N	PRESENT	0
620602	618091	19691J	PARTICIPANT	\N	PRESENT	0
620603	618091	14229S	PARTICIPANT	\N	PRESENT	0
620604	618091	11066Q	PARTICIPANT	\N	PRESENT	0
620605	618091	20062A	PARTICIPANT	\N	PRESENT	0
620606	618091	19671E	PARTICIPANT	\N	PRESENT	0
620607	618091	20054A	PARTICIPANT	\N	PRESENT	0
620608	618091	14133K	PARTICIPANT	\N	PRESENT	0
620609	618091	14083S	PARTICIPANT	\N	PRESENT	0
620610	618091	17965H	PARTICIPANT	\N	PRESENT	0
620611	618091	19503N	PARTICIPANT	\N	PRESENT	0
620612	618091	14001X	PARTICIPANT	\N	PRESENT	0
620613	618091	20138D	PARTICIPANT	\N	PRESENT	0
620614	618091	19301E	PARTICIPANT	\N	PRESENT	0
620615	618091	20136B	PARTICIPANT	\N	PRESENT	0
620616	618091	14053L	PARTICIPANT	\N	PRESENT	0
620617	618091	19421M	PARTICIPANT	\N	PRESENT	0
620618	618091	19697Q	PARTICIPANT	\N	PRESENT	0
620638	616409	20104S	PARTICIPANT	\N	PRESENT	0
620639	616409	14357A	PARTICIPANT	\N	PRESENT	0
620640	616409	20128B	PARTICIPANT	\N	PRESENT	0
620641	616409	14097Y	PARTICIPANT	\N	PRESENT	0
620642	616409	19711U	PARTICIPANT	\N	PRESENT	0
620643	616409	14073Q	PARTICIPANT	\N	PRESENT	0
620644	616409	19441R	PARTICIPANT	\N	PRESENT	0
620645	616409	04057K	PARTICIPANT	\N	PRESENT	0
620647	616409	14331P	PRESIDENT	0	PRESENT	0
620650	616409	11048N	PARTICIPANT	\N	PRESENT	0
620651	616409	99004R	PARTICIPANT	\N	PRESENT	0
620652	616409	07029T	PARTICIPANT	\N	PRESENT	0
620653	616409	01057W	PARTICIPANT	\N	PRESENT	0
620654	616409	20070A	PARTICIPANT	\N	PRESENT	0
620655	616409	11053K	PARTICIPANT	\N	PRESENT	0
620656	616409	14327T	PARTICIPANT	\N	PRESENT	0
620657	616409	19479G	PARTICIPANT	\N	PRESENT	0
620658	616409	14225N	PARTICIPANT	\N	PRESENT	0
620659	616409	20080C	PARTICIPANT	\N	PRESENT	0
620660	616409	19335Q	PARTICIPANT	\N	PRESENT	1
620661	616409	19647E	PARTICIPANT	\N	PRESENT	1
620662	616409	14121F	PARTICIPANT	\N	PRESENT	1
620663	616409	19349W	PARTICIPANT	\N	PRESENT	1
620664	616409	20086J	PARTICIPANT	\N	PRESENT	0
620673	616409	14207L	PARTICIPANT	\N	EXCUSE	0
620676	618091	19569H	PARTICIPANT	\N	PRESENT	0
620683	618091	19533U	PARTICIPANT	\N	PRESENT	0
620680	618091	11027H	PARTICIPANT	\N	PRESENT	0
620681	618091	14207L	PARTICIPANT	\N	PRESENT	0
620684	618091	20060X	PARTICIPANT	\N	PRESENT	0
620686	618091	04033B	PARTICIPANT	\N	PRESENT	0
620691	618091	14221J	PARTICIPANT	\N	PRESENT	0
620696	618091	07029T	PARTICIPANT	\N	PRESENT	0
620697	618091	14357A	PARTICIPANT	\N	PRESENT	0
620698	618091	11097X	PARTICIPANT	\N	PRESENT	0
620699	618091	14213J	PARTICIPANT	\N	PRESENT	0
620700	618091	19711U	PARTICIPANT	\N	PRESENT	0
620701	618091	20070A	PARTICIPANT	\N	PRESENT	0
620702	618091	11012A	PARTICIPANT	\N	PRESENT	0
620703	618091	19741B	PARTICIPANT	\N	PRESENT	0
620704	618091	20038A	PARTICIPANT	\N	PRESENT	0
620705	618091	19657G	PARTICIPANT	\N	PRESENT	0
620706	618091	01048V	PARTICIPANT	\N	PRESENT	0
620707	618091	20266L	PARTICIPANT	\N	PRESENT	0
620708	618091	14257W	PARTICIPANT	\N	PRESENT	0
620709	618091	20080C	PARTICIPANT	\N	PRESENT	0
620710	618091	17779H	PARTICIPANT	\N	PRESENT	0
620711	618091	19739H	PARTICIPANT	\N	PRESENT	0
620712	618091	18193Q	PARTICIPANT	\N	PRESENT	0
620713	618091	19611R	PARTICIPANT	\N	PRESENT	0
620714	618091	01057W	PARTICIPANT	\N	PRESENT	0
620715	618091	20118Y	PARTICIPANT	\N	PRESENT	0
620716	618091	14215L	PARTICIPANT	\N	PRESENT	0
620717	618091	08010L	PARTICIPANT	\N	PRESENT	0
620718	618091	99004R	PARTICIPANT	\N	PRESENT	0
620719	618091	08073C	PARTICIPANT	\N	PRESENT	0
620720	618091	05012A	PARTICIPANT	\N	PRESENT	0
620721	618091	12028B	PARTICIPANT	\N	PRESENT	0
620722	618091	19701S	PARTICIPANT	\N	PRESENT	0
620723	618091	19479G	PARTICIPANT	\N	PRESENT	0
620724	618091	14331P	PARTICIPANT	\N	PRESENT	0
620725	618091	16685X	PARTICIPANT	\N	PRESENT	0
620726	618091	08061X	PARTICIPANT	\N	PRESENT	0
620727	618091	14033T	PARTICIPANT	\N	PRESENT	0
620728	618091	19685L	PARTICIPANT	\N	PRESENT	0
620729	618091	20102Q	PARTICIPANT	\N	PRESENT	0
620730	618091	19621T	PARTICIPANT	\N	PRESENT	0
620731	618091	14259Y	PARTICIPANT	\N	PRESENT	0
620732	618091	20098N	PARTICIPANT	\N	PRESENT	0
620733	618091	10006L	PARTICIPANT	\N	PRESENT	0
620734	618091	14097Y	PARTICIPANT	\N	PRESENT	0
620735	618091	14187A	PARTICIPANT	\N	PRESENT	0
620736	618091	19760E	PARTICIPANT	\N	PRESENT	0
620737	618091	19687N	PARTICIPANT	\N	PRESENT	0
620738	618091	11053K	PARTICIPANT	\N	PRESENT	0
620739	618091	19551W	PARTICIPANT	\N	PRESENT	0
620740	618091	19717B	PARTICIPANT	\N	PRESENT	0
620741	618091	01024M	PARTICIPANT	\N	PRESENT	0
620744	618091	19441R	PARTICIPANT	\N	PRESENT	0
600451	600416	11056N	PARTICIPANT	\N	PRESENT	0
600452	600416	20030R	PARTICIPANT	\N	PRESENT	0
600453	600416	14331P	PARTICIPANT	\N	PRESENT	0
600454	600416	14257W	PARTICIPANT	\N	PRESENT	0
600455	600416	20080C	PARTICIPANT	\N	PRESENT	0
600458	600416	14207L	PARTICIPANT	\N	PRESENT	0
600459	600416	20048C	PARTICIPANT	\N	PRESENT	0
600460	600416	20052X	PARTICIPANT	\N	PRESENT	0
600461	600416	11099A	PARTICIPANT	\N	PRESENT	0
600462	600416	11053K	PARTICIPANT	\N	PRESENT	0
600463	600416	14121F	PARTICIPANT	\N	PRESENT	0
600464	600416	11067R	PARTICIPANT	\N	PRESENT	0
600469	600416	14069U	PARTICIPANT	\N	PRESENT	0
600470	600416	19549D	PARTICIPANT	\N	PRESENT	0
600471	600416	11065P	PARTICIPANT	\N	PRESENT	0
600472	600416	07004J	PARTICIPANT	\N	PRESENT	0
600473	600416	19599P	PARTICIPANT	\N	PRESENT	0
600474	600416	20134Y	PARTICIPANT	\N	PRESENT	0
600476	600416	19747H	PARTICIPANT	\N	PRESENT	0
600477	600416	19693L	PARTICIPANT	\N	PRESENT	0
600478	600416	19782L	PARTICIPANT	\N	PRESENT	0
600479	600416	14033T	PARTICIPANT	\N	PRESENT	0
600480	600416	20092G	PARTICIPANT	\N	PRESENT	0
600481	600416	19413M	PARTICIPANT	\N	PRESENT	0
600482	600416	19551W	PARTICIPANT	\N	PRESENT	0
600483	600416	19387D	PARTICIPANT	\N	PRESENT	0
600484	600416	19687N	PARTICIPANT	\N	PRESENT	0
600485	600416	20090E	PARTICIPANT	\N	PRESENT	0
600486	600416	19701S	PARTICIPANT	\N	PRESENT	0
600492	600416	11045K	PARTICIPANT	\N	PRESENT	0
600493	600416	19649G	PARTICIPANT	\N	PRESENT	0
600494	600416	14151M	PARTICIPANT	\N	PRESENT	0
600541	598078	20046A	PARTICIPANT	\N	PRESENT	0
600542	598078	04085P	PARTICIPANT	\N	PRESENT	0
600543	598078	19687N	PARTICIPANT	\N	PRESENT	0
600544	598078	01028R	PARTICIPANT	\N	PRESENT	0
600545	598078	19725B	PARTICIPANT	\N	PRESENT	0
600546	598078	20082E	PARTICIPANT	\N	PRESENT	0
600547	598078	20080C	PARTICIPANT	\N	PRESENT	0
600548	598078	20030R	PARTICIPANT	\N	PRESENT	0
600549	598078	11045K	PARTICIPANT	\N	PRESENT	0
600550	598078	11067R	PARTICIPANT	\N	PRESENT	0
600551	598078	19413M	PARTICIPANT	\N	PRESENT	0
600553	598078	19551W	PARTICIPANT	\N	PRESENT	0
600554	598078	11065P	PARTICIPANT	\N	PRESENT	0
600555	598078	20134Y	PARTICIPANT	\N	PRESENT	0
600557	598078	20100N	PARTICIPANT	\N	PRESENT	0
600562	598078	19649G	PARTICIPANT	\N	PRESENT	0
600564	598078	19701S	PARTICIPANT	\N	PRESENT	0
600566	598078	19782L	PARTICIPANT	\N	PRESENT	0
600568	598078	19693L	PARTICIPANT	\N	PRESENT	0
600570	598078	20090E	PARTICIPANT	\N	PRESENT	0
600571	598078	14195A	PARTICIPANT	\N	PRESENT	0
600574	598078	07004J	PARTICIPANT	\N	PRESENT	0
600576	598078	11033F	PARTICIPANT	\N	PRESENT	0
600579	598078	19585H	PARTICIPANT	\N	PRESENT	0
600582	598078	14207L	PARTICIPANT	\N	PRESENT	0
600583	598078	20108W	PARTICIPANT	\N	PRESENT	0
600584	598078	05008E	PARTICIPANT	\N	PRESENT	0
600585	598078	19599P	PARTICIPANT	\N	PRESENT	0
600587	598078	19747H	PARTICIPANT	\N	PRESENT	0
600588	598078	95063L	PARTICIPANT	\N	PRESENT	0
600589	598078	19629C	PARTICIPANT	\N	PRESENT	0
600590	598078	19387D	PARTICIPANT	\N	PRESENT	0
600591	598078	14121F	PARTICIPANT	\N	PRESENT	0
600592	598078	14257W	PARTICIPANT	\N	PRESENT	0
600600	598078	04047H	PARTICIPANT	\N	PRESENT	0
600594	598078	20110Q	PARTICIPANT	\N	PRESENT	0
600595	598078	14151M	PARTICIPANT	\N	PRESENT	0
600596	598078	20092G	PARTICIPANT	\N	PRESENT	0
600597	598078	20032T	PARTICIPANT	\N	PRESENT	0
600598	598078	11101A	PARTICIPANT	\N	PRESENT	0
600599	598078	20044X	PARTICIPANT	\N	PRESENT	0
600601	598078	14215L	PARTICIPANT	\N	PRESENT	0
600602	598078	18083K	PARTICIPANT	\N	PRESENT	0
600539	598078	08073C	PARTICIPANT	\N	PRESENT	0
600540	598078	11056N	PARTICIPANT	\N	PRESENT	0
600603	598078	14026U	PARTICIPANT	\N	PRESENT	0
600604	598078	97011G	PARTICIPANT	\N	PRESENT	0
600785	598084	07029T	PARTICIPANT	\N	PRESENT	0
600786	598084	19697Q	PARTICIPANT	\N	PRESENT	0
600816	598089	11056N	PARTICIPANT	\N	PRESENT	0
600818	598089	07004J	PARTICIPANT	\N	PRESENT	0
600820	598089	19543W	PARTICIPANT	\N	PRESENT	0
600822	598089	19697Q	PARTICIPANT	\N	PRESENT	0
600826	598089	19713W	PARTICIPANT	\N	PRESENT	0
600827	598089	19585H	PARTICIPANT	\N	PRESENT	0
600828	598089	19581D	PARTICIPANT	\N	PRESENT	0
600829	598089	11012A	PARTICIPANT	\N	PRESENT	0
600830	598089	04047H	PARTICIPANT	\N	PRESENT	0
600831	598089	19583F	PARTICIPANT	\N	PRESENT	0
600832	598089	19593H	PARTICIPANT	\N	PRESENT	0
600833	598089	14207L	PARTICIPANT	\N	PRESENT	0
600834	598089	14249W	PARTICIPANT	\N	PRESENT	0
600835	598089	20110Q	PARTICIPANT	\N	PRESENT	0
600836	598089	20122U	PARTICIPANT	\N	PRESENT	0
600837	598089	20108W	PARTICIPANT	\N	PRESENT	0
600838	598089	14217N	PARTICIPANT	\N	PRESENT	0
600839	598089	20048C	PARTICIPANT	\N	PRESENT	0
600840	598089	01028R	PARTICIPANT	\N	PRESENT	0
600841	598089	04057K	PARTICIPANT	\N	PRESENT	0
600842	598089	14251Q	PARTICIPANT	\N	PRESENT	0
600844	598089	14026U	PARTICIPANT	\N	PRESENT	0
600875	598089	14030Q	PARTICIPANT	\N	PRESENT	0
600877	598089	20140W	PARTICIPANT	\N	PRESENT	0
600896	598089	14215L	PARTICIPANT	\N	PRESENT	0
600812	598089	19719D	PARTICIPANT	\N	PRESENT	0
600814	598089	07029T	PARTICIPANT	\N	PRESENT	0
600913	598089	14083S	PARTICIPANT	\N	PRESENT	0
600919	598089	17589D	PARTICIPANT	\N	PRESENT	0
600930	598089	04085P	PARTICIPANT	\N	PRESENT	0
600931	598089	05008E	PARTICIPANT	\N	PRESENT	0
600932	598089	19399H	PARTICIPANT	\N	PRESENT	0
600936	598089	11026G	PARTICIPANT	\N	PRESENT	0
600934	598089	11033F	PARTICIPANT	\N	PRESENT	0
600935	598089	11085T	PARTICIPANT	\N	PRESENT	0
600969	598090	11033F	PARTICIPANT	\N	PRESENT	0
600970	598090	20110Q	PARTICIPANT	\N	PRESENT	0
600971	598090	04047H	PARTICIPANT	\N	PRESENT	0
600972	598090	14215L	PARTICIPANT	\N	PRESENT	0
600973	598090	05008E	PARTICIPANT	\N	PRESENT	0
600974	598090	14217N	PARTICIPANT	\N	PRESENT	0
600975	598090	19649G	PARTICIPANT	\N	PRESENT	0
600976	598090	19593H	PARTICIPANT	\N	PRESENT	0
600977	598090	07004J	PARTICIPANT	\N	PRESENT	0
600978	598090	19697Q	PARTICIPANT	\N	PRESENT	0
600979	598090	19399H	PARTICIPANT	\N	PRESENT	0
600980	598090	14207L	PARTICIPANT	\N	PRESENT	0
600981	598090	07029T	PARTICIPANT	\N	PRESENT	0
600982	598090	20108W	PARTICIPANT	\N	PRESENT	0
600986	598090	04085P	PARTICIPANT	\N	PRESENT	0
600987	598090	20050V	PARTICIPANT	\N	PRESENT	0
600988	598090	14251Q	PARTICIPANT	\N	PRESENT	0
600989	598090	08069G	PARTICIPANT	\N	PRESENT	0
606021	606020	19717B	PARTICIPANT	\N	PRESENT	0
606022	606020	19631V	PARTICIPANT	\N	PRESENT	0
606023	606020	04085P	PARTICIPANT	\N	PRESENT	0
606024	606020	19577H	PARTICIPANT	\N	PRESENT	0
606025	606020	19329S	PARTICIPANT	\N	PRESENT	0
606026	606020	20034V	PARTICIPANT	\N	PRESENT	0
606027	606020	19715Y	PARTICIPANT	\N	PRESENT	0
606028	606020	12016W	PARTICIPANT	\N	PRESENT	0
606029	606020	11072N	PARTICIPANT	\N	PRESENT	0
606030	606020	08073C	PARTICIPANT	\N	PRESENT	0
606031	606020	20146D	PARTICIPANT	\N	PRESENT	0
606032	606020	17023S	PARTICIPANT	\N	PRESENT	0
600967	598090	14026U	PARTICIPANT	\N	PRESENT	0
600968	598090	11026G	PARTICIPANT	\N	PRESENT	0
606033	606020	20150Y	PARTICIPANT	\N	PRESENT	0
606034	606020	14275Y	PARTICIPANT	\N	PRESENT	0
606035	606020	19301E	PARTICIPANT	\N	PRESENT	0
606036	606020	86034E	PARTICIPANT	\N	PRESENT	0
606037	606020	20148F	PARTICIPANT	\N	PRESENT	0
609897	609895	14001X	PARTICIPANT	\N	PRESENT	0
609901	609895	20074E	PARTICIPANT	\N	PRESENT	0
609904	609895	20042V	PARTICIPANT	\N	PRESENT	0
609907	609895	20094J	PARTICIPANT	\N	PRESENT	0
609924	609922	19782L	PARTICIPANT	\N	PRESENT	0
609925	609922	14109K	PARTICIPANT	\N	PRESENT	0
609926	609922	20174H	PARTICIPANT	\N	PRESENT	0
609927	609922	20028X	PARTICIPANT	\N	PRESENT	0
599323	597324	14026U	PARTICIPANT	\N	PRESENT	0
599324	597324	19679N	PARTICIPANT	\N	PRESENT	0
599325	597324	14217N	PARTICIPANT	\N	PRESENT	0
599326	597324	19591F	PARTICIPANT	\N	PRESENT	0
599327	597324	01034P	PARTICIPANT	\N	PRESENT	0
599328	597324	04057K	PARTICIPANT	\N	PRESENT	0
599329	597324	14223L	PARTICIPANT	\N	EXCUSE	0
599330	597484	19719D	PARTICIPANT	\N	PRESENT	0
599331	597484	14229S	PARTICIPANT	\N	PRESENT	0
599332	598018	19335Q	PARTICIPANT	\N	PRESENT	0
599333	598004	08047A	PRESIDENT	0	PRESENT	0
599334	598004	04042C	PARTICIPANT	\N	EXCUSE	0
599335	598004	14097Y	PARTICIPANT	\N	PRESENT	0
599336	598004	14059S	PARTICIPANT	\N	PRESENT	0
599337	598004	04035D	PARTICIPANT	\N	PRESENT	0
599338	598004	19443T	PARTICIPANT	\N	PRESENT	0
599339	598004	19565D	PARTICIPANT	\N	PRESENT	0
599340	598004	11041F	PARTICIPANT	\N	PRESENT	0
599341	598004	20042V	PARTICIPANT	\N	PRESENT	0
599342	598004	01058X	PARTICIPANT	\N	PRESENT	0
599343	598004	16685X	PARTICIPANT	\N	PRESENT	0
599344	598004	11027H	PARTICIPANT	\N	PRESENT	0
599345	598004	01024M	PARTICIPANT	\N	PRESENT	0
599346	598004	11066Q	PARTICIPANT	\N	PRESENT	0
599347	598004	19721W	PARTICIPANT	\N	PRESENT	0
599348	598004	08056B	PARTICIPANT	\N	PRESENT	0
599349	598004	14105F	PARTICIPANT	\N	PRESENT	0
599350	598004	14055N	PARTICIPANT	\N	PRESENT	0
599351	598004	19421M	PARTICIPANT	\N	PRESENT	0
599352	598004	11064N	PARTICIPANT	\N	PRESENT	0
599353	598004	19347U	PARTICIPANT	\N	PRESENT	0
599354	598004	07033P	PARTICIPANT	\N	PRESENT	0
599355	598004	97011G	PARTICIPANT	\N	PRESENT	0
599356	598004	14249W	PARTICIPANT	\N	PRESENT	0
599357	598004	14255U	PARTICIPANT	\N	PRESENT	0
599358	598018	14053L	PARTICIPANT	\N	PRESENT	0
599359	598018	19749K	PARTICIPANT	\N	PRESENT	0
599360	598004	08069G	PARTICIPANT	\N	PRESENT	0
599361	598004	14211G	PARTICIPANT	\N	PRESENT	0
600126	598024	14327T	PARTICIPANT	\N	PRESENT	0
600127	598024	19479G	PARTICIPANT	\N	PRESENT	0
600128	598024	19711U	PARTICIPANT	\N	PRESENT	0
600129	598024	08034U	PRESIDENT	0	PRESENT	0
600130	598024	19531S	PARTICIPANT	\N	PRESENT	0
600131	598024	19687N	PARTICIPANT	\N	PRESENT	0
600132	598024	01057W	PARTICIPANT	\N	PRESENT	0
600133	598024	19689Q	PARTICIPANT	\N	PRESENT	0
600134	598024	11053K	PARTICIPANT	\N	PRESENT	0
600135	598024	20080C	PARTICIPANT	\N	PRESENT	0
600136	598024	19667J	PARTICIPANT	\N	PRESENT	0
600137	598024	20044X	PARTICIPANT	\N	PRESENT	0
600138	598024	19671E	PARTICIPANT	\N	PRESENT	0
600139	598024	11040E	PARTICIPANT	\N	PRESENT	0
600140	598024	14083S	PARTICIPANT	\N	PRESENT	0
600141	598024	19349W	PARTICIPANT	\N	PRESENT	0
600142	598024	19741B	PARTICIPANT	\N	PRESENT	0
600143	598024	14121F	PARTICIPANT	\N	PRESENT	0
600144	598024	99004R	PARTICIPANT	\N	PRESENT	0
600145	598024	20126Y	PARTICIPANT	\N	PRESENT	0
600146	598024	14225N	PARTICIPANT	\N	EXCUSE	0
600147	598076	14133K	PARTICIPANT	\N	PRESENT	0
600148	598076	20018V	PARTICIPANT	\N	PRESENT	0
600149	598076	01058X	PARTICIPANT	\N	PRESENT	0
600150	598076	19563B	PARTICIPANT	\N	PRESENT	0
600151	595689	20106U	PARTICIPANT	\N	PRESENT	0
600152	598076	19585H	PARTICIPANT	\N	PRESENT	0
600154	598024	19647E	PARTICIPANT	\N	PRESENT	0
600155	598024	11070L	PARTICIPANT	\N	PRESENT	0
600156	598024	07029T	PARTICIPANT	\N	PRESENT	0
600157	598024	08010L	PARTICIPANT	\N	PRESENT	0
600158	598024	11012A	PARTICIPANT	\N	EXCUSE	0
600159	598076	19673G	PARTICIPANT	\N	PRESENT	0
600160	598076	19703U	PARTICIPANT	\N	PRESENT	0
600161	598076	14217N	PARTICIPANT	\N	PRESENT	0
600199	598076	14147R	PARTICIPANT	\N	PRESENT	0
600171	598076	20140W	PARTICIPANT	\N	PRESENT	0
600172	598076	19369B	PARTICIPANT	\N	PRESENT	0
600173	598076	19443T	PARTICIPANT	\N	PRESENT	0
600174	598076	20108W	PARTICIPANT	\N	PRESENT	0
600175	598076	11012A	PARTICIPANT	\N	PRESENT	0
600176	598076	18083K	PARTICIPANT	\N	PRESENT	0
600177	595689	14219Q	PRESIDENT	0	PRESENT	0
600181	598076	19387D	PARTICIPANT	\N	PRESENT	0
600183	598076	20100N	PARTICIPANT	\N	PRESENT	0
600184	598076	14021P	PARTICIPANT	\N	PRESENT	0
600185	598076	11056N	PARTICIPANT	\N	PRESENT	0
600186	598076	20038A	PARTICIPANT	\N	PRESENT	0
600187	598076	14031R	PARTICIPANT	\N	PRESENT	0
600189	598076	19503N	PARTICIPANT	\N	PRESENT	0
600190	598076	19631V	PARTICIPANT	\N	PRESENT	0
600192	598076	20126Y	PARTICIPANT	\N	PRESENT	0
600193	598076	19820Y	PARTICIPANT	\N	PRESENT	0
600194	598076	19549D	PARTICIPANT	\N	PRESENT	0
600197	598076	20024T	PARTICIPANT	\N	PRESENT	0
600198	598076	20136B	PARTICIPANT	\N	PRESENT	0
600202	598076	19719D	PARTICIPANT	\N	PRESENT	0
600208	598076	19599P	PARTICIPANT	\N	PRESENT	0
600210	598076	19333N	PARTICIPANT	\N	PRESENT	0
606039	603133	08009T	PARTICIPANT	\N	EXCUSE	0
606040	603133	20050V	PARTICIPANT	\N	EXCUSE	0
606041	603133	11074Q	PARTICIPANT	\N	EXCUSE	0
606042	603151	08073C	PARTICIPANT	\N	PRESENT	0
606043	603133	11040E	PARTICIPANT	\N	PRESENT	0
606044	603133	14083S	PARTICIPANT	\N	PRESENT	0
606045	603133	19479G	PARTICIPANT	\N	PRESENT	0
606046	603133	11012A	PARTICIPANT	\N	PRESENT	0
606047	603133	20252E	PARTICIPANT	\N	PRESENT	0
606048	603133	20070A	PARTICIPANT	\N	PRESENT	0
606049	603133	01057W	PARTICIPANT	\N	PRESENT	0
606050	603133	99004R	PARTICIPANT	\N	PRESENT	0
606051	603133	19762G	PARTICIPANT	\N	PRESENT	0
606052	603133	11048N	PARTICIPANT	\N	PRESENT	0
606053	603133	19711U	PARTICIPANT	\N	PRESENT	0
606054	603133	19667J	PARTICIPANT	\N	PRESENT	0
606055	603133	14225N	PRESIDENT	0	PRESENT	0
606056	603133	19421M	PARTICIPANT	\N	PRESENT	0
606061	603133	20086J	PARTICIPANT	\N	PRESENT	0
606062	603133	08010L	PARTICIPANT	\N	PRESENT	0
606063	603133	19349W	PARTICIPANT	\N	PRESENT	0
606064	603133	20150Y	PARTICIPANT	\N	PRESENT	0
606065	603133	19647E	PARTICIPANT	\N	PRESENT	0
606067	603151	19413M	PARTICIPANT	\N	PRESENT	0
606069	603151	14219Q	PARTICIPANT	\N	PRESENT	0
606071	603151	19739H	PARTICIPANT	\N	PRESENT	0
606072	603151	14107H	PARTICIPANT	\N	PRESENT	0
606075	603151	19545Y	PARTICIPANT	\N	PRESENT	0
606077	603151	11090Q	PARTICIPANT	\N	PRESENT	0
606080	603151	19695N	PARTICIPANT	\N	PRESENT	0
606081	603151	20088L	PARTICIPANT	\N	PRESENT	0
606084	603151	11033F	PARTICIPANT	\N	PRESENT	0
606086	603151	20248J	PARTICIPANT	\N	PRESENT	0
606089	603151	14147R	PARTICIPANT	\N	PRESENT	0
606090	603151	14033T	PARTICIPANT	\N	PRESENT	0
606092	603151	19467C	PARTICIPANT	\N	PRESENT	0
606093	603151	20090E	PARTICIPANT	\N	PRESENT	0
606094	603151	19387D	PARTICIPANT	\N	PRESENT	0
606096	603151	14329V	PARTICIPANT	\N	PRESENT	0
606097	603151	14059S	PARTICIPANT	\N	PRESENT	0
606099	603151	20048C	PARTICIPANT	\N	PRESENT	0
606100	603151	19782L	PARTICIPANT	\N	PRESENT	0
606104	603151	20092G	PARTICIPANT	\N	PRESENT	0
606105	603151	20030R	PARTICIPANT	\N	PRESENT	0
606106	603151	19629C	PARTICIPANT	\N	PRESENT	0
606107	603133	11053K	PARTICIPANT	\N	PRESENT	0
606108	603151	20038A	PARTICIPANT	\N	PRESENT	0
606109	603151	14259Y	PARTICIPANT	\N	PRESENT	0
606110	603133	19335Q	PARTICIPANT	\N	PRESENT	0
606111	603151	19533U	PARTICIPANT	\N	PRESENT	0
606112	603133	08034U	PARTICIPANT	\N	PRESENT	0
606113	603151	11067R	PARTICIPANT	\N	PRESENT	0
606115	603151	19563B	PARTICIPANT	\N	PRESENT	0
606116	603151	10015M	PARTICIPANT	\N	PRESENT	0
606117	603151	19749K	PARTICIPANT	\N	PRESENT	0
606118	603151	14105F	PARTICIPANT	\N	PRESENT	0
606119	603151	14071N	PARTICIPANT	\N	PRESENT	0
606120	603151	11097X	PARTICIPANT	\N	PRESENT	0
606121	603151	19399H	PARTICIPANT	\N	PRESENT	0
606122	603151	14053L	PARTICIPANT	\N	PRESENT	0
606123	603133	01048V	PARTICIPANT	\N	PRESENT	0
606124	603151	14069U	PARTICIPANT	\N	PRESENT	0
606125	603151	14109K	PARTICIPANT	\N	PRESENT	0
613082	610758	17737W	PARTICIPANT	\N	PRESENT	0
613083	610758	14215L	PARTICIPANT	\N	PRESENT	0
613000	610755	14147R	PARTICIPANT	\N	PRESENT	0
613001	610755	19593H	PARTICIPANT	\N	PRESENT	0
613084	610758	19593H	PARTICIPANT	\N	PRESENT	0
613085	610758	19563B	PARTICIPANT	\N	PRESENT	0
613086	610758	19565D	PARTICIPANT	\N	PRESENT	0
613087	610758	19669L	PARTICIPANT	\N	PRESENT	0
613088	610758	19543W	PARTICIPANT	\N	PRESENT	0
613089	610758	11012A	PARTICIPANT	\N	PRESENT	0
613090	610758	14055N	PARTICIPANT	\N	PRESENT	0
613091	610758	11033F	PARTICIPANT	\N	PRESENT	0
613092	610758	20150Y	PARTICIPANT	\N	PRESENT	0
613093	610758	01062T	PARTICIPANT	\N	PRESENT	0
613094	610758	14249W	PARTICIPANT	\N	PRESENT	0
613095	610758	14069U	PARTICIPANT	\N	PRESENT	0
613096	610758	20110Q	PARTICIPANT	\N	PRESENT	0
613097	610758	12041X	PARTICIPANT	\N	PRESENT	0
613098	610758	04059M	PARTICIPANT	\N	PRESENT	0
613099	610758	20136B	PARTICIPANT	\N	PRESENT	0
613100	610758	04047H	PARTICIPANT	\N	PRESENT	0
613101	610758	19681G	PARTICIPANT	\N	PRESENT	0
613103	610758	14021P	PARTICIPANT	\N	PRESENT	0
613104	610758	01028R	PARTICIPANT	\N	PRESENT	0
613105	610758	19599P	PARTICIPANT	\N	PRESENT	0
613107	610758	20112S	PARTICIPANT	\N	PRESENT	0
613108	613106	14193X	PARTICIPANT	\N	PRESENT	0
613109	613106	20042V	PARTICIPANT	\N	PRESENT	0
613028	610758	11045K	PARTICIPANT	\N	PRESENT	0
613080	610758	19507S	PARTICIPANT	\N	PRESENT	0
613110	610758	19687N	PARTICIPANT	\N	PRESENT	0
613111	610758	14229S	PARTICIPANT	\N	PRESENT	0
613117	610758	19649G	PARTICIPANT	\N	PRESENT	0
613113	613106	11083R	PARTICIPANT	\N	PRESENT	0
613114	610758	19820Y	PARTICIPANT	\N	PRESENT	0
613115	610758	20264J	PARTICIPANT	\N	PRESENT	0
613116	610758	19489J	PARTICIPANT	\N	PRESENT	0
613118	610758	19503N	PARTICIPANT	\N	PRESENT	0
613121	610758	20082E	PARTICIPANT	\N	PRESENT	0
613122	610758	20070A	PARTICIPANT	\N	PRESENT	0
613123	610758	19719D	PARTICIPANT	\N	PRESENT	0
613124	610758	19667J	PARTICIPANT	\N	PRESENT	0
613129	613127	20152B	PARTICIPANT	\N	PRESENT	0
613126	610758	17023S	PARTICIPANT	\N	PRESENT	0
613128	613127	19573D	PARTICIPANT	\N	PRESENT	0
613130	613127	20132W	PARTICIPANT	\N	PRESENT	0
613131	610758	14147R	PARTICIPANT	\N	PRESENT	0
613132	610758	20022R	PARTICIPANT	\N	PRESENT	0
613134	613133	19621T	PARTICIPANT	\N	PRESENT	0
613135	613133	04070G	PARTICIPANT	\N	PRESENT	0
613136	613133	19593H	PARTICIPANT	\N	PRESENT	0
613137	613133	20084G	PARTICIPANT	\N	PRESENT	0
613150	610758	19631V	PARTICIPANT	\N	PRESENT	0
613151	610758	19251M	PARTICIPANT	\N	PRESENT	0
613172	610758	17779H	PARTICIPANT	\N	PRESENT	0
613187	610758	19573D	PARTICIPANT	\N	PRESENT	0
613188	610758	20060X	PARTICIPANT	\N	PRESENT	0
613199	610758	20266L	PARTICIPANT	\N	PRESENT	0
613200	610758	04085P	PARTICIPANT	\N	PRESENT	0
613201	610758	20024T	PARTICIPANT	\N	PRESENT	0
613202	610758	19551W	PARTICIPANT	\N	PRESENT	0
613249	610759	20022R	PARTICIPANT	\N	PRESENT	0
613250	610759	04047H	PARTICIPANT	\N	PRESENT	0
613251	610759	14021P	PARTICIPANT	\N	PRESENT	0
613252	610759	19681G	PARTICIPANT	\N	PRESENT	0
613253	610759	20266L	PARTICIPANT	\N	PRESENT	0
613254	610759	20060X	PARTICIPANT	\N	PRESENT	0
613255	610759	20082E	PARTICIPANT	\N	PRESENT	0
613256	610759	01028R	PARTICIPANT	\N	PRESENT	0
613264	610759	19489J	PARTICIPANT	\N	PRESENT	0
613258	610759	14215L	PARTICIPANT	\N	PRESENT	0
613259	610759	11033F	PARTICIPANT	\N	PRESENT	0
613260	610759	20112S	PARTICIPANT	\N	PRESENT	0
613261	610759	19593H	PARTICIPANT	\N	PRESENT	0
613262	610759	19251M	PARTICIPANT	\N	PRESENT	0
613263	610759	20264J	PARTICIPANT	\N	PRESENT	0
613265	610759	14249W	PARTICIPANT	\N	PRESENT	0
613266	610759	19563B	PARTICIPANT	\N	PRESENT	0
613267	610759	19573D	PARTICIPANT	\N	PRESENT	0
613268	610759	19543W	PARTICIPANT	\N	PRESENT	0
613269	610759	20024T	PARTICIPANT	\N	PRESENT	0
613270	610759	14195A	PARTICIPANT	\N	PRESENT	0
613271	610759	14069U	PARTICIPANT	\N	PRESENT	0
613272	610759	20110Q	PARTICIPANT	\N	PRESENT	0
613273	610759	19551W	PARTICIPANT	\N	PRESENT	0
613280	610759	20070A	PARTICIPANT	\N	PRESENT	0
613301	610759	20136B	PARTICIPANT	\N	PRESENT	0
613302	610759	20094J	PARTICIPANT	\N	PRESENT	0
613303	610759	20130U	PARTICIPANT	\N	PRESENT	0
613456	612406	19713W	PARTICIPANT	\N	PRESENT	0
613459	612406	19691J	PARTICIPANT	\N	PRESENT	0
613473	612406	11031D	PARTICIPANT	\N	PRESENT	0
613494	613190	14038Y	PARTICIPANT	\N	EXCUSE	0
613822	613821	14073Q	PARTICIPANT	\N	PRESENT	1
613843	613821	08012N	PARTICIPANT	\N	PRESENT	1
613844	613821	11043H	PARTICIPANT	\N	PRESENT	1
613882	613190	04070G	PARTICIPANT	\N	EXCUSE	0
614636	613120	19443T	PARTICIPANT	\N	PRESENT	0
614637	613120	19565D	PARTICIPANT	\N	PRESENT	0
614638	613120	20072C	PARTICIPANT	\N	PRESENT	0
614639	613120	19329S	PARTICIPANT	\N	PRESENT	0
614640	613120	01058X	PARTICIPANT	\N	PRESENT	0
614641	613120	11027H	PARTICIPANT	\N	PRESENT	0
613247	610759	11045K	PARTICIPANT	\N	PRESENT	0
613248	610759	19599P	PARTICIPANT	\N	PRESENT	0
614642	613120	04042C	PRESIDENT	0	PRESENT	0
614643	613120	11054L	PARTICIPANT	\N	PRESENT	0
614644	613120	11066Q	PARTICIPANT	\N	PRESENT	0
614645	613120	14225N	PARTICIPANT	\N	PRESENT	0
614646	613120	08056B	PARTICIPANT	\N	PRESENT	0
614647	613120	12028B	PARTICIPANT	\N	PRESENT	0
614648	613120	19709B	PARTICIPANT	\N	PRESENT	0
614649	613120	19347U	PARTICIPANT	\N	PRESENT	0
614650	613120	97011G	PARTICIPANT	\N	PRESENT	0
614651	613120	08061X	PARTICIPANT	\N	PRESENT	0
614652	613120	08047A	PARTICIPANT	\N	PRESENT	0
614653	613120	19711U	PARTICIPANT	\N	PRESENT	0
614654	613120	14133K	PARTICIPANT	\N	PRESENT	0
614655	613120	01062T	PARTICIPANT	\N	PRESENT	0
614656	613120	08069G	PARTICIPANT	\N	PRESENT	0
614657	613120	11041F	PARTICIPANT	\N	PRESENT	0
614658	613120	01024M	PARTICIPANT	\N	PRESENT	0
614659	613120	19721W	PARTICIPANT	\N	PRESENT	0
614660	613120	14105F	PARTICIPANT	\N	PRESENT	0
614661	613120	20064C	PARTICIPANT	\N	PRESENT	0
614662	613120	14267Y	PARTICIPANT	\N	PRESENT	0
614663	613120	14211G	PARTICIPANT	\N	PRESENT	0
614664	613120	14255U	PARTICIPANT	\N	PRESENT	0
614665	613120	17023S	PARTICIPANT	\N	PRESENT	0
615530	613312	11031D	PARTICIPANT	\N	PRESENT	0
615531	613312	14073Q	PARTICIPANT	\N	PRESENT	0
615532	613312	14069U	PARTICIPANT	\N	PRESENT	0
615533	613312	07029T	PARTICIPANT	\N	PRESENT	0
615534	613312	11067R	PARTICIPANT	\N	PRESENT	0
615535	613312	20130U	PARTICIPANT	\N	PRESENT	0
615537	613312	20038A	PARTICIPANT	\N	PRESENT	0
615538	613312	20248J	PARTICIPANT	\N	PRESENT	0
615541	613312	19415P	PARTICIPANT	\N	PRESENT	0
615544	613312	11045K	PARTICIPANT	\N	PRESENT	0
615545	613312	19545Y	PARTICIPANT	\N	PRESENT	0
615546	613312	19717B	PARTICIPANT	\N	PRESENT	0
615547	613191	17737W	PARTICIPANT	\N	PRESENT	0
615548	613191	20090E	PARTICIPANT	\N	PRESENT	0
615549	613191	07004J	PARTICIPANT	\N	PRESENT	0
615550	613191	19741B	PARTICIPANT	\N	PRESENT	0
615551	613191	19667J	PRESIDENT	0	PRESENT	0
615552	613191	20044X	PARTICIPANT	\N	PRESENT	0
615553	613191	04085P	PARTICIPANT	\N	PRESENT	0
615554	613191	14257W	PARTICIPANT	\N	PRESENT	0
615555	613312	17779H	PARTICIPANT	\N	PRESENT	0
615556	613312	19693L	PARTICIPANT	\N	PRESENT	0
615557	613312	19713W	PARTICIPANT	\N	PRESENT	0
615558	613312	19591F	PARTICIPANT	\N	PRESENT	0
615559	613312	14217N	PARTICIPANT	\N	PRESENT	0
615560	613312	14213J	PARTICIPANT	\N	PRESENT	0
615561	613191	20064C	PARTICIPANT	\N	PRESENT	0
615562	613191	19671E	PARTICIPANT	\N	PRESENT	0
615563	613312	20024T	PARTICIPANT	\N	PRESENT	0
615564	613312	11097X	PARTICIPANT	\N	PRESENT	0
615565	613312	19723Y	PARTICIPANT	\N	PRESENT	0
615566	613312	14030Q	PARTICIPANT	\N	PRESENT	0
603559	602925	20132W	PARTICIPANT	\N	PRESENT	0
606605	606436	14147R	PARTICIPANT	\N	PRESENT	0
606607	606606	19629C	PARTICIPANT	\N	PRESENT	0
606630	606608	18083K	PARTICIPANT	\N	PRESENT	0
606643	606640	18083K	PARTICIPANT	\N	PRESENT	0
606655	606651	18083K	PARTICIPANT	\N	PRESENT	0
609929	609922	19507S	PARTICIPANT	\N	PRESENT	0
610819	610815	20060X	PARTICIPANT	\N	PRESENT	0
610817	610815	19569H	PARTICIPANT	\N	PRESENT	0
610818	610815	10015M	PARTICIPANT	\N	PRESENT	0
610820	606138	19673G	PARTICIPANT	\N	PRESENT	0
610821	606181	19673G	PARTICIPANT	\N	PRESENT	0
618123	616395	14026U	PARTICIPANT	\N	PRESENT	0
618161	616395	19760E	PARTICIPANT	\N	PRESENT	0
618162	616395	19713W	PARTICIPANT	\N	PRESENT	0
618163	616395	19629C	PARTICIPANT	\N	PRESENT	0
618164	616395	14195A	PARTICIPANT	\N	PRESENT	0
618165	616395	18193Q	PARTICIPANT	\N	PRESENT	0
618166	616395	19697Q	PARTICIPANT	\N	PRESENT	0
618170	616395	11031D	PARTICIPANT	\N	PRESENT	0
618168	616395	19679N	PARTICIPANT	\N	PRESENT	0
618169	616395	19689Q	PARTICIPANT	\N	PRESENT	0
618171	616395	20248J	PARTICIPANT	\N	PRESENT	0
618172	616395	11067R	PARTICIPANT	\N	PRESENT	0
618173	616395	07029T	PARTICIPANT	\N	PRESENT	0
618174	616395	19758L	PARTICIPANT	\N	PRESENT	0
618175	616395	20102Q	PARTICIPANT	\N	PRESENT	0
618176	616395	20046A	PARTICIPANT	\N	PRESENT	0
618177	616395	20174H	PARTICIPANT	\N	PRESENT	0
618178	616395	19651A	PARTICIPANT	\N	PRESENT	0
618179	616395	20092G	PARTICIPANT	\N	PRESENT	0
618180	616395	14357A	PARTICIPANT	\N	PRESENT	0
618182	616395	19467C	PARTICIPANT	\N	PRESENT	0
618183	616395	19251M	PARTICIPANT	\N	PRESENT	0
618184	616395	18083K	PARTICIPANT	\N	PRESENT	0
618185	616395	14083S	PARTICIPANT	\N	PRESENT	0
618186	616395	19687N	PARTICIPANT	\N	PRESENT	0
618187	616395	14073Q	PARTICIPANT	\N	PRESENT	0
618188	616395	19503N	PARTICIPANT	\N	PRESENT	0
618189	616395	20032T	PARTICIPANT	\N	PRESENT	0
618190	616395	19695N	PARTICIPANT	\N	PRESENT	0
618191	616395	14147R	PARTICIPANT	\N	PRESENT	0
618192	616395	01024M	PARTICIPANT	\N	PRESENT	0
618194	616395	08061X	PARTICIPANT	\N	PRESENT	0
618195	616395	97011G	PARTICIPANT	\N	PRESENT	0
618197	616395	14038Y	PARTICIPANT	\N	PRESENT	0
618198	616395	20098N	PARTICIPANT	\N	PRESENT	0
618199	616395	19711U	PARTICIPANT	\N	PRESENT	0
618200	616395	19762G	PARTICIPANT	\N	PRESENT	0
618202	616395	20144B	PARTICIPANT	\N	PRESENT	0
618206	616395	20134Y	PARTICIPANT	\N	PRESENT	0
618207	616395	04045F	PARTICIPANT	\N	PRESENT	0
618208	616395	19533U	PARTICIPANT	\N	PRESENT	0
618210	616395	14107H	PARTICIPANT	\N	PRESENT	0
618212	616395	20090E	PARTICIPANT	\N	PRESENT	0
618213	616395	19619A	PARTICIPANT	\N	PRESENT	0
618214	616395	19741B	PARTICIPANT	\N	PRESENT	0
618215	616395	14257W	PARTICIPANT	\N	PRESENT	0
618216	616395	11053K	PARTICIPANT	\N	PRESENT	0
618218	616395	20030R	PARTICIPANT	\N	PRESENT	0
618220	616395	14053L	PARTICIPANT	\N	PRESENT	0
618221	616395	14021P	PARTICIPANT	\N	PRESENT	0
618222	616395	20056C	PARTICIPANT	\N	PRESENT	0
618223	616395	19701S	PARTICIPANT	\N	PRESENT	0
618224	616395	19347U	PARTICIPANT	\N	PRESENT	0
618225	616395	19543W	PARTICIPANT	\N	PRESENT	0
618227	616395	19553Y	PARTICIPANT	\N	PRESENT	0
618272	616396	19758L	PARTICIPANT	\N	PRESENT	0
618273	616396	14021P	PARTICIPANT	\N	PRESENT	0
618274	616396	14257W	PARTICIPANT	\N	PRESENT	0
618275	616396	11067R	PARTICIPANT	\N	PRESENT	0
618276	616396	18193Q	PARTICIPANT	\N	PRESENT	0
618277	616396	19333N	PARTICIPANT	\N	PRESENT	0
618278	616396	19503N	PARTICIPANT	\N	PRESENT	0
618279	616396	19251M	PARTICIPANT	\N	PRESENT	0
618280	616396	20174H	PARTICIPANT	\N	PRESENT	0
618281	616396	19553Y	PARTICIPANT	\N	PRESENT	0
618282	616396	14107H	PARTICIPANT	\N	PRESENT	0
618283	616396	14195A	PARTICIPANT	\N	PRESENT	0
618284	616396	20134Y	PARTICIPANT	\N	PRESENT	0
618285	616396	19689Q	PARTICIPANT	\N	PRESENT	0
618286	616396	19347U	PARTICIPANT	\N	PRESENT	0
618287	616396	20092G	PARTICIPANT	\N	PRESENT	0
618288	616396	14221J	PARTICIPANT	\N	PRESENT	0
618289	616396	20144B	PARTICIPANT	\N	PRESENT	0
618290	616396	19543W	PARTICIPANT	\N	PRESENT	0
618291	616396	20248J	PARTICIPANT	\N	PRESENT	0
618292	616396	19651A	PARTICIPANT	\N	PRESENT	0
618293	616396	14053L	PARTICIPANT	\N	PRESENT	0
618294	616396	19701S	PARTICIPANT	\N	PRESENT	0
618295	616396	97011G	PARTICIPANT	\N	PRESENT	0
618296	616396	18083K	PARTICIPANT	\N	PRESENT	0
618297	616396	20090E	PARTICIPANT	\N	PRESENT	0
618298	616396	19762G	PARTICIPANT	\N	PRESENT	0
618299	616396	19533U	PARTICIPANT	\N	PRESENT	0
618300	616396	20032T	PARTICIPANT	\N	PRESENT	0
618301	616396	19575F	PARTICIPANT	\N	PRESENT	0
618302	616396	07029T	PARTICIPANT	\N	PRESENT	0
618303	616396	20056C	PARTICIPANT	\N	PRESENT	0
618304	616396	19467C	PARTICIPANT	\N	PRESENT	0
618305	616396	14038Y	PARTICIPANT	\N	PRESENT	0
618306	616396	20060X	PARTICIPANT	\N	PRESENT	0
618307	616396	20018V	PARTICIPANT	\N	PRESENT	0
618308	616396	01024M	PARTICIPANT	\N	PRESENT	0
618309	616396	19711U	PARTICIPANT	\N	PRESENT	0
618310	616396	19619A	PARTICIPANT	\N	PRESENT	0
618311	616396	20110Q	PARTICIPANT	\N	PRESENT	0
618312	616396	19695N	PARTICIPANT	\N	PRESENT	0
618313	616396	20102Q	PARTICIPANT	\N	PRESENT	0
618270	616396	14026U	PARTICIPANT	\N	PRESENT	0
618271	616396	11031D	PARTICIPANT	\N	PRESENT	0
618314	616396	17965H	PARTICIPANT	\N	PRESENT	0
618315	616396	20030R	PARTICIPANT	\N	PRESENT	0
618316	616396	20100N	PARTICIPANT	\N	PRESENT	0
618318	616396	19629C	PARTICIPANT	\N	PRESENT	0
619820	618360	20114U	PARTICIPANT	\N	PRESENT	0
619821	618360	11085T	PARTICIPANT	\N	PRESENT	0
619822	618360	19749K	PARTICIPANT	\N	PRESENT	0
619823	618360	04008A	PARTICIPANT	\N	PRESENT	0
619824	616408	20068G	PARTICIPANT	\N	PRESENT	1
619825	618360	14215L	PARTICIPANT	\N	PRESENT	0
619826	618360	11026G	PARTICIPANT	\N	PRESENT	0
619827	618360	11056N	PARTICIPANT	\N	PRESENT	0
619828	618360	14069U	PARTICIPANT	\N	PRESENT	0
619829	616408	19525U	PARTICIPANT	\N	PRESENT	0
619907	618090	19866P	PARTICIPANT	\N	PRESENT	0
619908	618090	19511N	PARTICIPANT	\N	PRESENT	0
619909	618090	14105F	PARTICIPANT	\N	PRESENT	0
619910	618090	19629C	PARTICIPANT	\N	PRESENT	0
619911	618090	20102Q	PARTICIPANT	\N	PRESENT	0
619912	618090	20068G	PARTICIPANT	\N	PRESENT	0
619913	618090	11080N	PARTICIPANT	\N	PRESENT	0
619914	618090	92040Q	PARTICIPANT	\N	PRESENT	0
619915	618090	14089Y	PARTICIPANT	\N	PRESENT	0
619916	618090	19301E	PARTICIPANT	\N	PRESENT	0
619917	618090	20092G	PARTICIPANT	\N	PRESENT	0
619918	618090	14229S	PARTICIPANT	\N	PRESENT	0
619919	618090	11066Q	PARTICIPANT	\N	PRESENT	0
619920	618090	14173T	PARTICIPANT	\N	PRESENT	0
619921	618090	20050V	PARTICIPANT	\N	PRESENT	0
619922	618090	19621T	PARTICIPANT	\N	PRESENT	0
619923	618090	11048N	PARTICIPANT	\N	PRESENT	0
619924	618090	11101A	PARTICIPANT	\N	PRESENT	0
619925	618090	19443T	PARTICIPANT	\N	PRESENT	0
619926	618090	19675J	PARTICIPANT	\N	PRESENT	0
619927	618090	17965H	PARTICIPANT	\N	PRESENT	0
619928	618090	19489J	PARTICIPANT	\N	PRESENT	0
619929	618090	97011G	PARTICIPANT	\N	PRESENT	0
619930	618090	19715Y	PARTICIPANT	\N	PRESENT	0
619931	618090	11027H	PARTICIPANT	\N	PRESENT	0
619932	618090	11054L	PARTICIPANT	\N	PRESENT	0
619933	618090	19747H	PARTICIPANT	\N	PRESENT	0
619935	618090	19741B	PARTICIPANT	\N	PRESENT	0
619937	618090	19531S	PARTICIPANT	\N	PRESENT	0
619938	618090	08009T	PARTICIPANT	\N	PRESENT	0
619939	618090	19333N	PARTICIPANT	\N	PRESENT	0
619940	618090	19703U	PARTICIPANT	\N	PRESENT	0
619941	618090	11041F	PARTICIPANT	\N	PRESENT	0
619943	618090	19057M	PARTICIPANT	\N	PRESENT	0
619944	618090	19593H	PARTICIPANT	\N	PRESENT	0
619945	618090	19295A	PARTICIPANT	\N	PRESENT	0
609928	609922	19369B	PARTICIPANT	\N	PRESENT	0
613197	613196	20136B	PARTICIPANT	\N	PRESENT	0
613848	613307	19954N	PARTICIPANT	\N	PRESENT	0
613849	613307	11085T	PARTICIPANT	\N	PRESENT	0
613850	613307	20024T	PARTICIPANT	\N	PRESENT	0
613851	613307	19741B	PARTICIPANT	\N	PRESENT	0
613852	613307	19507S	PARTICIPANT	\N	PRESENT	0
613853	613307	20022R	PARTICIPANT	\N	PRESENT	0
613854	613307	11056N	PARTICIPANT	\N	PRESENT	0
613855	613307	20064C	PARTICIPANT	\N	PRESENT	0
613856	613307	20140W	PARTICIPANT	\N	PRESENT	0
613857	613307	19533U	PARTICIPANT	\N	PRESENT	0
613875	613307	17737W	PARTICIPANT	\N	PRESENT	0
613876	613307	14021P	PARTICIPANT	\N	PRESENT	0
613877	613307	11053K	PARTICIPANT	\N	PRESENT	0
613878	613307	20096L	PARTICIPANT	\N	PRESENT	0
613879	613307	01058X	PARTICIPANT	\N	PRESENT	0
613880	613307	08034U	PARTICIPANT	\N	PRESENT	0
613881	613307	14205J	PARTICIPANT	\N	PRESENT	0
613883	613307	14331P	PARTICIPANT	\N	PRESENT	0
613884	613307	19782L	PARTICIPANT	\N	PRESENT	0
613885	613307	14195A	PARTICIPANT	\N	PRESENT	0
613886	613307	08015R	PARTICIPANT	\N	PRESENT	0
613887	613307	20032T	PARTICIPANT	\N	PRESENT	0
613888	613307	20092G	PARTICIPANT	\N	PRESENT	0
613889	613307	19739H	PARTICIPANT	\N	PRESENT	0
613890	613307	19399H	PARTICIPANT	\N	PRESENT	0
613891	613307	19717B	PARTICIPANT	\N	PRESENT	0
613892	613307	19515S	PARTICIPANT	\N	PRESENT	0
613893	613307	14059S	PARTICIPANT	\N	PRESENT	0
613894	613307	19563B	PARTICIPANT	\N	PRESENT	0
613895	613307	20120S	PARTICIPANT	\N	PRESENT	0
613896	613307	14033T	PARTICIPANT	\N	PRESENT	0
613952	613310	18193Q	PARTICIPANT	\N	PRESENT	0
613953	613310	19713W	PARTICIPANT	\N	PRESENT	0
613954	613310	14042U	PARTICIPANT	\N	PRESENT	0
613955	613310	19749K	PARTICIPANT	\N	PRESENT	0
613956	613310	14030Q	PARTICIPANT	\N	PRESENT	0
613957	613310	19591F	PARTICIPANT	\N	PRESENT	0
613958	613310	19415P	PARTICIPANT	\N	PRESENT	0
613959	613310	19798U	PARTICIPANT	\N	PRESENT	0
613960	613310	19717B	PARTICIPANT	\N	PRESENT	0
613961	613310	14195A	PARTICIPANT	\N	PRESENT	0
613962	613310	14215L	PARTICIPANT	\N	PRESENT	0
613963	613310	19367Y	PARTICIPANT	\N	PRESENT	0
613964	613310	11031D	PARTICIPANT	\N	PRESENT	0
613965	613310	19565D	PARTICIPANT	\N	PRESENT	0
613966	613310	20124W	PARTICIPANT	\N	PRESENT	0
613967	613310	20130U	PARTICIPANT	\N	PRESENT	0
613968	613310	20090E	PARTICIPANT	\N	PRESENT	0
613969	613310	19782L	PARTICIPANT	\N	PRESENT	0
613970	613310	19715Y	PARTICIPANT	\N	PRESENT	0
613971	613310	10006L	PARTICIPANT	\N	PRESENT	0
613972	613310	19760E	PARTICIPANT	\N	PRESENT	0
613973	613310	20248J	PARTICIPANT	\N	PRESENT	0
613977	613310	19701S	PARTICIPANT	\N	PRESENT	0
613975	613310	11043H	PARTICIPANT	\N	PRESENT	0
613976	613310	19723Y	PARTICIPANT	\N	PRESENT	0
613978	613310	14147R	PARTICIPANT	\N	PRESENT	0
613979	613310	14213J	PARTICIPANT	\N	PRESENT	0
613980	613310	11097X	PARTICIPANT	\N	PRESENT	0
613981	613310	19679N	PARTICIPANT	\N	PRESENT	0
613982	613310	04092N	PARTICIPANT	\N	PRESENT	0
613983	613310	19447X	PARTICIPANT	\N	PRESENT	0
613984	613310	14217N	PARTICIPANT	\N	PRESENT	0
613985	613310	14059S	PARTICIPANT	\N	PRESENT	0
613986	613310	07029T	PARTICIPANT	\N	PRESENT	0
613987	613310	20030R	PARTICIPANT	\N	PRESENT	0
613988	613310	20134Y	PARTICIPANT	\N	PRESENT	0
613989	613310	20110Q	PARTICIPANT	\N	PRESENT	0
613990	613310	20038A	PARTICIPANT	\N	PRESENT	0
613991	613310	20062A	PARTICIPANT	\N	PRESENT	0
613992	613310	19703U	PARTICIPANT	\N	PRESENT	0
613993	613310	20086J	PARTICIPANT	\N	PRESENT	0
613994	613310	20180F	PARTICIPANT	\N	PRESENT	0
613995	613310	19954N	PARTICIPANT	\N	PRESENT	0
613996	613310	18083K	PARTICIPANT	\N	PRESENT	0
613997	613310	20114U	PARTICIPANT	\N	PRESENT	0
613998	613310	20048C	PARTICIPANT	\N	PRESENT	0
613999	613310	20034V	PARTICIPANT	\N	PRESENT	0
614000	613310	19503N	PARTICIPANT	\N	PRESENT	0
614001	613310	19347U	PARTICIPANT	\N	PRESENT	0
614002	613310	19507S	PARTICIPANT	\N	PRESENT	0
614003	613310	19383Y	PARTICIPANT	\N	PRESENT	0
614004	613310	19719D	PARTICIPANT	\N	PRESENT	0
614005	613310	14033T	PARTICIPANT	\N	PRESENT	0
613950	613310	99004R	PARTICIPANT	\N	PRESENT	0
613951	613310	11067R	PARTICIPANT	\N	PRESENT	0
615568	613312	20172F	PARTICIPANT	\N	PRESENT	0
615569	613312	14147R	PARTICIPANT	\N	PRESENT	0
615570	613191	19531S	PARTICIPANT	\N	PRESENT	0
615571	612796	19649G	PARTICIPANT	\N	PRESENT	0
615572	612796	11026G	PARTICIPANT	\N	PRESENT	0
615573	612796	19581D	PARTICIPANT	\N	PRESENT	0
615574	612796	19585H	PARTICIPANT	\N	PRESENT	0
615575	612796	04047H	PRESIDENT	0	PRESENT	0
615576	612796	01028R	PARTICIPANT	\N	PRESENT	0
615577	612796	19447X	PARTICIPANT	\N	PRESENT	0
615578	612796	14089Y	PARTICIPANT	\N	PRESENT	0
615579	612796	11056N	PARTICIPANT	\N	PRESENT	0
615580	612796	95063L	PARTICIPANT	\N	PRESENT	0
615581	612796	14151M	PARTICIPANT	\N	PRESENT	0
615582	612796	20114U	PARTICIPANT	\N	PRESENT	0
615583	612796	14215L	PARTICIPANT	\N	PRESENT	0
615584	612796	20022R	PARTICIPANT	\N	PRESENT	0
615585	612796	11072N	PARTICIPANT	\N	PRESENT	0
615586	613312	18083K	PARTICIPANT	\N	PRESENT	0
615588	612796	14147R	PARTICIPANT	\N	PRESENT	0
615589	612796	19749K	PARTICIPANT	\N	PRESENT	0
615590	613312	20026V	PARTICIPANT	\N	PRESENT	0
615591	612796	14231L	PARTICIPANT	\N	PRESENT	0
615595	613312	04057K	PARTICIPANT	\N	PRESENT	0
615606	613312	19760E	PARTICIPANT	\N	PRESENT	0
615607	613312	20054A	PARTICIPANT	\N	PRESENT	0
615608	613312	19349W	PARTICIPANT	\N	PRESENT	0
615609	613312	20082E	PARTICIPANT	\N	PRESENT	0
615610	613312	19798U	PARTICIPANT	\N	PRESENT	0
615611	612796	14179A	PARTICIPANT	\N	PRESENT	0
615613	613312	20048C	PARTICIPANT	\N	PRESENT	0
615614	613312	20180F	PARTICIPANT	\N	PRESENT	0
615615	613312	20032T	PARTICIPANT	\N	PRESENT	0
615616	613312	14038Y	PARTICIPANT	\N	PRESENT	0
615618	613312	19747H	PARTICIPANT	\N	PRESENT	0
615621	613312	18193Q	PARTICIPANT	\N	PRESENT	0
615633	613191	14249W	PARTICIPANT	\N	PRESENT	0
615635	613312	19703U	PARTICIPANT	\N	PRESENT	0
615636	613312	20030R	PARTICIPANT	\N	PRESENT	0
615655	613312	11012A	PARTICIPANT	\N	PRESENT	0
615656	613312	20090E	PARTICIPANT	\N	PRESENT	0
615657	613312	19715Y	PARTICIPANT	\N	PRESENT	0
618649	618358	14179A	PARTICIPANT	\N	PRESENT	0
618650	618358	14151M	PARTICIPANT	\N	PRESENT	0
618651	618358	14215L	PARTICIPANT	\N	PRESENT	0
618652	618358	08018U	PARTICIPANT	\N	PRESENT	0
618653	618358	14217N	PARTICIPANT	\N	PRESENT	0
618654	618358	20022R	PARTICIPANT	\N	PRESENT	0
618655	618358	14053L	PARTICIPANT	\N	PRESENT	0
618656	618358	19649G	PARTICIPANT	\N	PRESENT	0
618657	618358	14111D	PARTICIPANT	\N	PRESENT	0
618658	618358	11026G	PARTICIPANT	\N	PRESENT	0
618659	618358	11033F	PARTICIPANT	\N	PRESENT	0
618660	618358	04085P	PARTICIPANT	\N	PRESENT	0
618661	618358	14089Y	PARTICIPANT	\N	PRESENT	0
618662	618358	95063L	PARTICIPANT	\N	PRESENT	0
618663	618358	11085T	PARTICIPANT	\N	PRESENT	0
618664	618358	19749K	PARTICIPANT	\N	PRESENT	0
618665	618358	14021P	PARTICIPANT	\N	PRESENT	0
618666	618083	20030R	PARTICIPANT	\N	PRESENT	0
618667	618083	20180F	PARTICIPANT	\N	PRESENT	0
618668	618083	20152B	PARTICIPANT	\N	PRESENT	0
618669	618083	19569H	PARTICIPANT	\N	PRESENT	0
618670	618083	19563B	PARTICIPANT	\N	PRESENT	0
618671	618083	20116W	PARTICIPANT	\N	PRESENT	0
618672	618083	19693L	PARTICIPANT	\N	PRESENT	0
618673	618083	99004R	PARTICIPANT	\N	PRESENT	0
618674	618083	20026V	PARTICIPANT	\N	PRESENT	0
618675	618083	19611R	PARTICIPANT	\N	PRESENT	0
618687	618083	19711U	PARTICIPANT	\N	PRESENT	0
618688	618083	20090E	PARTICIPANT	\N	PRESENT	0
618689	618083	19760E	PARTICIPANT	\N	PRESENT	0
618690	618083	20082E	PARTICIPANT	\N	PRESENT	0
601481	601480	20110Q	PARTICIPANT	\N	PRESENT	0
606126	603151	19573D	PARTICIPANT	\N	PRESENT	0
606127	603151	14215L	PARTICIPANT	\N	PRESENT	0
606128	603151	20028X	PARTICIPANT	\N	PRESENT	0
606129	603151	14179A	PARTICIPANT	\N	PRESENT	0
606130	603151	14089Y	PARTICIPANT	\N	PRESENT	0
606131	603151	20022R	PARTICIPANT	\N	PRESENT	0
606132	603151	19649G	PARTICIPANT	\N	PRESENT	0
606133	603151	11072N	PARTICIPANT	\N	PRESENT	0
606134	603151	14038Y	PARTICIPANT	\N	PRESENT	0
606135	603151	19441R	PARTICIPANT	\N	PRESENT	0
606184	603152	20028X	PARTICIPANT	\N	PRESENT	0
606185	603152	04085P	PARTICIPANT	\N	PRESENT	0
606186	603152	19695N	PARTICIPANT	\N	PRESENT	0
606187	603152	14053L	PARTICIPANT	\N	PRESENT	0
606188	603152	19649G	PARTICIPANT	\N	PRESENT	0
606189	603152	14089Y	PARTICIPANT	\N	PRESENT	0
606190	603152	11026G	PARTICIPANT	\N	PRESENT	0
606191	603152	19629C	PARTICIPANT	\N	PRESENT	0
606192	603152	14107H	PARTICIPANT	\N	PRESENT	0
606193	603152	10015M	PARTICIPANT	\N	PRESENT	0
606194	603152	14069U	PARTICIPANT	\N	PRESENT	0
606195	603152	19749K	PARTICIPANT	\N	PRESENT	0
606196	603152	19739H	PARTICIPANT	\N	PRESENT	0
606198	603152	19441R	PARTICIPANT	\N	PRESENT	0
606202	603152	19543W	PARTICIPANT	\N	PRESENT	0
606203	603152	14073Q	PARTICIPANT	\N	PRESENT	0
606204	603152	20248J	PARTICIPANT	\N	PRESENT	0
606205	603152	20022R	PARTICIPANT	\N	PRESENT	0
606206	603152	11090Q	PARTICIPANT	\N	PRESENT	0
606207	603152	14329V	PARTICIPANT	\N	PRESENT	0
606208	603152	14215L	PARTICIPANT	\N	PRESENT	0
606209	603152	11097X	PARTICIPANT	\N	PRESENT	0
606210	603152	19545Y	PARTICIPANT	\N	PRESENT	0
606211	603152	14105F	PARTICIPANT	\N	PRESENT	0
606212	603152	11033F	PARTICIPANT	\N	PRESENT	0
606213	603152	11067R	PARTICIPANT	\N	PRESENT	0
606214	603152	19413M	PARTICIPANT	\N	PRESENT	0
606215	603152	11072N	PARTICIPANT	\N	PRESENT	0
606216	603152	19447X	PARTICIPANT	\N	PRESENT	0
606217	603152	19467C	PARTICIPANT	\N	PRESENT	0
606218	603152	14147R	PARTICIPANT	\N	PRESENT	0
606219	603152	04047H	PARTICIPANT	\N	PRESENT	0
606220	603152	14259Y	PARTICIPANT	\N	PRESENT	0
606221	603152	20030R	PARTICIPANT	\N	PRESENT	0
606222	603152	20110Q	PARTICIPANT	\N	PRESENT	0
606226	603152	14191V	PARTICIPANT	\N	PRESENT	0
606227	603152	20092G	PARTICIPANT	\N	PRESENT	0
606228	603152	01048V	PARTICIPANT	\N	PRESENT	0
606229	603152	19349W	PARTICIPANT	\N	PRESENT	0
606237	605794	14053L	PARTICIPANT	\N	PRESENT	0
606238	605794	19649G	PARTICIPANT	\N	PRESENT	0
606239	605794	11026G	PARTICIPANT	\N	PRESENT	0
606182	603152	08073C	PARTICIPANT	\N	PRESENT	0
606183	603152	19399H	PARTICIPANT	\N	PRESENT	0
606240	605794	10015M	PARTICIPANT	\N	PRESENT	0
606241	605794	19543W	PARTICIPANT	\N	PRESENT	0
606242	605794	04047H	PRESIDENT	0	PRESENT	0
606243	605794	11033F	PARTICIPANT	\N	PRESENT	0
606244	605794	19447X	PARTICIPANT	\N	PRESENT	0
606245	605794	05008E	PARTICIPANT	\N	PRESENT	0
606246	605794	14231L	PARTICIPANT	\N	PRESENT	0
606247	605794	04085P	PARTICIPANT	\N	PRESENT	0
606248	605794	14089Y	PARTICIPANT	\N	PRESENT	0
606249	605794	19629C	PARTICIPANT	\N	PRESENT	0
606250	605794	20110Q	PARTICIPANT	\N	PRESENT	0
606251	605794	14147R	PARTICIPANT	\N	PRESENT	0
606252	605794	14069U	PARTICIPANT	\N	PRESENT	0
606253	605794	14215L	PARTICIPANT	\N	PRESENT	0
606254	605794	14259Y	PARTICIPANT	\N	PRESENT	0
606255	605794	20022R	PARTICIPANT	\N	PRESENT	0
606256	605794	11072N	PARTICIPANT	\N	PRESENT	0
606257	605794	19729F	PARTICIPANT	\N	EXCUSE	0
606258	603152	05008E	PARTICIPANT	\N	PRESENT	0
606259	603152	20038A	PARTICIPANT	\N	PRESENT	0
606260	603152	14189C	PARTICIPANT	\N	PRESENT	0
606267	603152	19621T	PARTICIPANT	\N	PRESENT	0
606264	603152	19573D	PARTICIPANT	\N	PRESENT	0
606265	603152	19533U	PARTICIPANT	\N	PRESENT	0
606279	603152	20180F	PARTICIPANT	\N	PRESENT	0
606275	603152	20086J	PARTICIPANT	\N	PRESENT	0
606280	603152	17737W	PARTICIPANT	\N	PRESENT	0
606282	603152	01028R	PARTICIPANT	\N	PRESENT	0
606309	603153	14105F	PARTICIPANT	\N	PRESENT	0
606310	603153	19689Q	PARTICIPANT	\N	PRESENT	0
606311	603153	11048N	PARTICIPANT	\N	PRESENT	0
606312	603153	14225N	PARTICIPANT	\N	PRESENT	0
606313	603153	19683J	PARTICIPANT	\N	PRESENT	0
606314	603153	19711U	PARTICIPANT	\N	PRESENT	0
606315	603153	18083K	PARTICIPANT	\N	PRESENT	0
606316	603153	20090E	PARTICIPANT	\N	PRESENT	0
606317	603153	19798U	PARTICIPANT	\N	PRESENT	0
606318	603153	12041X	PARTICIPANT	\N	PRESENT	0
606319	603153	20030R	PARTICIPANT	\N	PRESENT	0
606320	603153	12016W	PARTICIPANT	\N	PRESENT	0
606321	603153	20028X	PARTICIPANT	\N	PRESENT	0
606322	603153	11040E	PARTICIPANT	\N	PRESENT	0
606323	603153	19758L	PARTICIPANT	\N	PRESENT	0
606324	603153	19687N	PARTICIPANT	\N	PRESENT	0
606325	603153	11012A	PARTICIPANT	\N	PRESENT	0
606302	603153	11045K	PARTICIPANT	\N	PRESENT	0
606308	603153	14031R	PARTICIPANT	\N	PRESENT	0
606326	603153	19349W	PARTICIPANT	\N	PRESENT	0
606327	603153	19545Y	PARTICIPANT	\N	PRESENT	0
606328	603153	04033B	PARTICIPANT	\N	PRESENT	0
606329	603153	11067R	PARTICIPANT	\N	PRESENT	0
606330	603153	20252E	PARTICIPANT	\N	PRESENT	0
606331	603153	19647E	PARTICIPANT	\N	PRESENT	0
606332	603153	04071H	PARTICIPANT	\N	PRESENT	0
606333	603153	19479G	PARTICIPANT	\N	PRESENT	0
606334	603153	14327T	PARTICIPANT	\N	PRESENT	0
606335	603153	19515S	PARTICIPANT	\N	PRESENT	0
606336	603153	19667J	PARTICIPANT	\N	PRESENT	0
606337	603153	11097X	PARTICIPANT	\N	PRESENT	0
606338	603153	08011M	PARTICIPANT	\N	PRESENT	0
606339	603153	19782L	PARTICIPANT	\N	PRESENT	0
606340	603153	19387D	PARTICIPANT	\N	PRESENT	0
606341	603153	20070A	PARTICIPANT	\N	PRESENT	0
606342	603153	20092G	PARTICIPANT	\N	PRESENT	0
606343	603153	14257W	PARTICIPANT	\N	PRESENT	0
606344	603153	20080C	PARTICIPANT	\N	PRESENT	0
606345	603153	04085P	PARTICIPANT	\N	PRESENT	0
606346	603153	20112S	PARTICIPANT	\N	PRESENT	0
606347	603153	20088L	PARTICIPANT	\N	PRESENT	0
606348	603153	19295A	PARTICIPANT	\N	PRESENT	0
606349	603153	14083S	PARTICIPANT	\N	PRESENT	0
606350	603153	19399H	PARTICIPANT	\N	PRESENT	0
606351	603153	20034V	PARTICIPANT	\N	PRESENT	0
606352	603153	20022R	PARTICIPANT	\N	PRESENT	0
606353	603153	14038Y	PARTICIPANT	\N	PRESENT	0
606354	603153	14191V	PARTICIPANT	\N	PRESENT	0
606355	603153	08034U	PARTICIPANT	\N	PRESENT	0
606356	603153	19715Y	PARTICIPANT	\N	PRESENT	0
606357	603153	19762G	PARTICIPANT	\N	PRESENT	0
606358	603153	14030Q	PARTICIPANT	\N	PRESENT	0
606359	603153	14189C	PARTICIPANT	\N	PRESENT	0
606360	603153	11053K	PARTICIPANT	\N	PRESENT	0
606361	603153	11031D	PARTICIPANT	\N	PRESENT	0
606362	603153	14026U	PARTICIPANT	\N	PRESENT	0
606370	603153	14215L	PARTICIPANT	\N	PRESENT	0
606371	603153	19531S	PARTICIPANT	\N	PRESENT	0
606372	603153	99004R	PARTICIPANT	\N	PRESENT	0
606374	603153	19441R	PARTICIPANT	\N	PRESENT	0
606375	603153	08010L	PARTICIPANT	\N	PRESENT	0
606376	603153	20024T	PARTICIPANT	\N	PRESENT	0
606377	603153	20036X	PARTICIPANT	\N	PRESENT	0
606378	603153	08056B	PARTICIPANT	\N	PRESENT	0
606379	603153	19335Q	PARTICIPANT	\N	PRESENT	0
606380	603153	19503N	PARTICIPANT	\N	PRESENT	0
606381	603153	04047H	PARTICIPANT	\N	PRESENT	0
606383	606382	14097Y	PARTICIPANT	\N	PRESENT	0
606384	606382	08047A	PARTICIPANT	\N	PRESENT	0
606385	603153	19533U	PARTICIPANT	\N	PRESENT	0
606386	603153	19543W	PARTICIPANT	\N	PRESENT	0
606388	603153	19467C	PARTICIPANT	\N	PRESENT	0
606389	606387	19669L	PARTICIPANT	\N	PRESENT	0
606390	606387	19421M	PARTICIPANT	\N	PRESENT	0
606391	603153	14357A	PARTICIPANT	\N	PRESENT	0
606394	606392	11066Q	PARTICIPANT	\N	PRESENT	0
606395	603153	19691J	PARTICIPANT	\N	PRESENT	0
615567	613312	10006L	PARTICIPANT	\N	PRESENT	0
618064	616394	04045F	PARTICIPANT	\N	PRESENT	0
618065	616394	19651A	PARTICIPANT	\N	PRESENT	0
618066	616394	18193Q	PARTICIPANT	\N	PRESENT	0
618067	616394	19301E	PARTICIPANT	\N	PRESENT	0
618068	616394	08045X	PARTICIPANT	\N	PRESENT	0
618069	616394	20130U	PARTICIPANT	\N	PRESENT	0
618070	616394	20030R	PARTICIPANT	\N	PRESENT	0
618071	616394	11031D	PARTICIPANT	\N	PRESENT	0
618072	616394	17965H	PARTICIPANT	\N	PRESENT	0
618073	616394	20018V	PARTICIPANT	\N	PRESENT	0
618074	616394	11067R	PARTICIPANT	\N	PRESENT	0
618075	616394	20066E	PARTICIPANT	\N	PRESENT	0
618076	616394	14042U	PARTICIPANT	\N	PRESENT	0
618077	616394	20024T	PARTICIPANT	\N	PRESENT	0
618078	616394	19663E	PARTICIPANT	\N	PRESENT	0
618079	616394	20062A	PARTICIPANT	\N	PRESENT	0
618080	616394	19760E	PARTICIPANT	\N	PRESENT	0
618081	616394	19553Y	PARTICIPANT	\N	PRESENT	0
618082	616394	19715Y	PARTICIPANT	\N	PRESENT	0
618085	616394	19057M	PARTICIPANT	\N	PRESENT	0
618086	616394	14069U	PARTICIPANT	\N	PRESENT	0
618087	616394	20092G	PARTICIPANT	\N	PRESENT	0
618097	616394	19563B	PARTICIPANT	\N	PRESENT	0
618098	616394	11097X	PARTICIPANT	\N	PRESENT	0
618099	616394	14026U	PARTICIPANT	\N	PRESENT	0
618100	616394	20180F	PARTICIPANT	\N	PRESENT	0
618101	616394	19575F	PARTICIPANT	\N	PRESENT	0
618102	616394	20098N	PARTICIPANT	\N	PRESENT	0
618103	616394	20058E	PARTICIPANT	\N	PRESENT	0
618104	616394	20138D	PARTICIPANT	\N	PRESENT	0
618105	616394	20108W	PARTICIPANT	\N	PRESENT	0
618106	616394	14237S	PARTICIPANT	\N	PRESENT	0
618107	616394	14147R	PARTICIPANT	\N	PRESENT	0
618108	616394	18083K	PARTICIPANT	\N	PRESENT	0
618109	616394	07029T	PARTICIPANT	\N	PRESENT	0
618352	616376	08060W	PARTICIPANT	\N	EXCUSE	0
618353	616376	14329V	PARTICIPANT	\N	EXCUSE	0
618354	616376	14195A	PARTICIPANT	\N	EXCUSE	0
618355	616376	20040T	PARTICIPANT	\N	EXCUSE	0
618356	616376	08015R	PARTICIPANT	\N	EXCUSE	0
618378	618377	19798U	PARTICIPANT	\N	PRESENT	0
618379	618377	19367Y	PARTICIPANT	\N	PRESENT	0
618380	618377	20090E	PARTICIPANT	\N	PRESENT	0
618381	618377	17965H	PARTICIPANT	\N	PRESENT	0
618383	618382	19798U	PARTICIPANT	\N	PRESENT	0
618384	618382	19367Y	PARTICIPANT	\N	PRESENT	0
618385	618382	19715Y	PARTICIPANT	\N	PRESENT	0
618386	618382	17965H	PARTICIPANT	\N	PRESENT	0
618387	618382	20090E	PARTICIPANT	\N	PRESENT	0
618389	618388	19798U	PARTICIPANT	\N	PRESENT	0
618390	618388	19367Y	PARTICIPANT	\N	PRESENT	0
618391	618388	20090E	PARTICIPANT	\N	PRESENT	0
618392	618388	17965H	PARTICIPANT	\N	PRESENT	0
618393	618388	19715Y	PARTICIPANT	\N	PRESENT	0
618395	618394	19798U	PARTICIPANT	\N	PRESENT	0
618396	618394	17965H	PARTICIPANT	\N	PRESENT	0
618397	618394	19715Y	PARTICIPANT	\N	PRESENT	0
618399	618398	17965H	PARTICIPANT	\N	PRESENT	0
618400	618398	19798U	PARTICIPANT	\N	PRESENT	0
618402	618401	19798U	PARTICIPANT	\N	PRESENT	0
618403	618401	19367Y	PARTICIPANT	\N	PRESENT	0
618404	618401	17965H	PARTICIPANT	\N	PRESENT	0
618405	618401	20248J	PARTICIPANT	\N	PRESENT	0
618406	618401	20040T	PARTICIPANT	\N	PRESENT	0
618428	618425	14033T	PARTICIPANT	\N	PRESENT	0
618429	618426	14033T	PARTICIPANT	\N	PRESENT	0
618430	618427	14033T	PARTICIPANT	\N	PRESENT	0
618828	618827	10006L	PARTICIPANT	\N	PRESENT	0
618829	618827	14147R	PARTICIPANT	\N	PRESENT	0
618830	618827	01062T	PARTICIPANT	\N	PRESENT	0
618831	618827	19703U	PARTICIPANT	\N	PRESENT	0
618832	618827	19691J	PARTICIPANT	\N	PRESENT	0
618833	618827	19723Y	PARTICIPANT	\N	PRESENT	0
619220	618359	11072N	PARTICIPANT	\N	PRESENT	0
619221	618359	95063L	PARTICIPANT	\N	PRESENT	0
619222	618359	11085T	PARTICIPANT	\N	PRESENT	0
619227	618367	08045X	PARTICIPANT	\N	EXCUSE	0
619228	618088	19663E	PARTICIPANT	\N	PRESENT	0
619229	618088	19691J	PARTICIPANT	\N	PRESENT	0
619230	618088	07029T	PARTICIPANT	\N	PRESENT	0
619231	618088	20060X	PARTICIPANT	\N	PRESENT	0
619232	618088	17367Q	PARTICIPANT	\N	PRESENT	0
619233	618088	20034V	PARTICIPANT	\N	PRESENT	0
619234	618088	11043H	PARTICIPANT	\N	PRESENT	0
619235	618088	19679N	PARTICIPANT	\N	PRESENT	0
619236	618088	20040T	PARTICIPANT	\N	PRESENT	0
619237	618088	19631V	PARTICIPANT	\N	PRESENT	0
619238	618088	04035D	PARTICIPANT	\N	PRESENT	0
619239	618088	08045X	PARTICIPANT	\N	PRESENT	0
619240	618088	11012A	PARTICIPANT	\N	PRESENT	0
619241	618088	11070L	PARTICIPANT	\N	PRESENT	0
619242	618088	92040Q	PARTICIPANT	\N	PRESENT	0
619243	618088	14257W	PARTICIPANT	\N	PRESENT	0
619244	618088	20086J	PARTICIPANT	\N	PRESENT	0
619245	618088	20140W	PARTICIPANT	\N	PRESENT	0
619246	618088	14121F	PARTICIPANT	\N	PRESENT	0
619247	618088	19531S	PARTICIPANT	\N	PRESENT	0
619248	618088	20082E	PARTICIPANT	\N	PRESENT	0
619249	618088	01057W	PARTICIPANT	\N	PRESENT	0
619251	618088	14030Q	PARTICIPANT	\N	PRESENT	0
619255	619152	14097Y	PARTICIPANT	\N	PRESENT	0
619256	619152	19515S	PARTICIPANT	\N	PRESENT	0
619257	619152	20066E	PARTICIPANT	\N	PRESENT	0
619258	619152	14193X	PARTICIPANT	\N	PRESENT	0
619259	619152	20082E	PRESIDENT	0	PRESENT	0
619260	619152	20050V	PARTICIPANT	\N	PRESENT	0
619261	619152	19747H	PARTICIPANT	\N	PRESENT	0
619262	619152	19693L	PARTICIPANT	\N	PRESENT	0
619263	619152	20126Y	PARTICIPANT	\N	PRESENT	0
619264	619152	11072N	PARTICIPANT	\N	PRESENT	0
619265	619152	20074E	PARTICIPANT	\N	EXCUSE	0
619266	619152	11077T	PARTICIPANT	\N	EXCUSE	0
619267	619152	19369B	PARTICIPANT	\N	EXCUSE	0
619268	618088	11115U	PARTICIPANT	\N	PRESENT	0
619269	618088	08073C	PARTICIPANT	\N	PRESENT	0
619270	618088	20048C	PARTICIPANT	\N	PRESENT	0
619271	618088	19621T	PARTICIPANT	\N	PRESENT	0
619272	618088	20094J	PARTICIPANT	\N	PRESENT	0
619451	618089	11045K	PARTICIPANT	\N	PRESENT	0
619454	618089	19525U	PARTICIPANT	\N	PRESENT	0
619456	618089	19599P	PARTICIPANT	\N	PRESENT	0
619455	618089	11031D	PARTICIPANT	\N	PRESENT	0
619457	618089	19683J	PARTICIPANT	\N	PRESENT	0
619458	618089	19489J	PARTICIPANT	\N	PRESENT	0
619459	618089	19699S	PARTICIPANT	\N	PRESENT	0
619460	618089	19647E	PARTICIPANT	\N	PRESENT	0
619461	618089	20082E	PARTICIPANT	\N	PRESENT	0
619462	618089	20084G	PARTICIPANT	\N	PRESENT	0
619463	618089	14229S	PARTICIPANT	\N	PRESENT	0
619464	618089	20028X	PARTICIPANT	\N	PRESENT	0
619465	618089	20018V	PARTICIPANT	\N	PRESENT	0
619466	618089	19703U	PARTICIPANT	\N	PRESENT	0
619467	618089	01028R	PARTICIPANT	\N	PRESENT	0
619468	618089	20074E	PARTICIPANT	\N	PRESENT	0
619469	618089	04045F	PARTICIPANT	\N	PRESENT	0
619470	618089	19575F	PARTICIPANT	\N	PRESENT	0
619471	618089	20100N	PARTICIPANT	\N	PRESENT	0
619472	618089	08069G	PARTICIPANT	\N	PRESENT	0
619473	618089	14223L	PARTICIPANT	\N	PRESENT	0
619474	618089	19701S	PARTICIPANT	\N	PRESENT	0
619475	618089	19747H	PARTICIPANT	\N	PRESENT	0
619476	618089	19768N	PARTICIPANT	\N	PRESENT	0
619477	618089	20030R	PARTICIPANT	\N	PRESENT	0
619478	618089	19503N	PARTICIPANT	\N	PRESENT	0
619479	618089	14195A	PARTICIPANT	\N	PRESENT	0
619480	618089	14071N	PARTICIPANT	\N	PRESENT	0
619481	618089	17589D	PARTICIPANT	\N	PRESENT	0
619482	618089	14147R	PARTICIPANT	\N	PRESENT	0
619483	618089	19619A	PARTICIPANT	\N	PRESENT	0
619484	618089	08010L	PARTICIPANT	\N	PRESENT	0
619485	618089	11101A	PARTICIPANT	\N	PRESENT	0
619486	618089	14021P	PARTICIPANT	\N	PRESENT	0
619487	618089	19367Y	PARTICIPANT	\N	PRESENT	0
619488	618089	20078J	PARTICIPANT	\N	PRESENT	0
619489	618089	20044X	PARTICIPANT	\N	PRESENT	0
619490	618089	19954N	PARTICIPANT	\N	PRESENT	0
619491	618089	20096L	PARTICIPANT	\N	PRESENT	0
619492	618089	04047H	PARTICIPANT	\N	PRESENT	0
619493	618089	20180F	PARTICIPANT	\N	PRESENT	0
619494	618089	05008E	PARTICIPANT	\N	PRESENT	0
602134	602132	11026G	PARTICIPANT	\N	PRESENT	0
602135	602133	11026G	PARTICIPANT	\N	PRESENT	0
602136	602131	11026G	PARTICIPANT	\N	PRESENT	0
602243	602242	14053L	PARTICIPANT	\N	PRESENT	0
602244	602242	19749K	PARTICIPANT	\N	PRESENT	0
602246	602245	19729F	PARTICIPANT	\N	PRESENT	0
602247	602245	95063L	PARTICIPANT	\N	PRESENT	0
602249	602248	19729F	PARTICIPANT	\N	PRESENT	0
602251	602250	19729F	PARTICIPANT	\N	PRESENT	0
602253	602252	19729F	PARTICIPANT	\N	PRESENT	0
608666	608665	20042V	PARTICIPANT	\N	PRESENT	0
608667	608665	11080N	PRESIDENT	0	PRESENT	0
608668	608665	01057W	PARTICIPANT	\N	PRESENT	0
608669	608665	14121F	PARTICIPANT	\N	PRESENT	0
608670	608665	19711U	PARTICIPANT	\N	PRESENT	0
608671	608665	05012A	PARTICIPANT	\N	PRESENT	0
615802	613314	14026U	PARTICIPANT	\N	PRESENT	0
615830	613314	20028X	PARTICIPANT	\N	PRESENT	0
615831	613314	20134Y	PARTICIPANT	\N	PRESENT	0
615832	613314	20132W	PARTICIPANT	\N	PRESENT	0
615833	613314	19593H	PARTICIPANT	\N	PRESENT	0
615834	613314	17589D	PARTICIPANT	\N	PRESENT	0
615837	613314	19643A	PARTICIPANT	\N	PRESENT	0
615838	613314	97011G	PARTICIPANT	\N	PRESENT	0
615839	613314	20024T	PARTICIPANT	\N	PRESENT	0
615840	613314	19693L	PARTICIPANT	\N	PRESENT	0
615842	613314	19057M	PARTICIPANT	\N	PRESENT	0
615845	613314	19599P	PARTICIPANT	\N	PRESENT	0
615846	613314	14031R	PARTICIPANT	\N	PRESENT	0
615847	613314	19611R	PARTICIPANT	\N	PRESENT	0
615848	613314	14267Y	PARTICIPANT	\N	PRESENT	0
615849	613314	20026V	PARTICIPANT	\N	PRESENT	0
615853	613314	04059M	PARTICIPANT	\N	PRESENT	0
615854	613314	19681G	PARTICIPANT	\N	PRESENT	0
615855	613314	14229S	PARTICIPANT	\N	PRESENT	0
615857	613314	20052X	PARTICIPANT	\N	PRESENT	0
615858	613314	19711U	PARTICIPANT	\N	PRESENT	0
615859	613314	20032T	PARTICIPANT	\N	PRESENT	0
615864	613314	20142Y	PARTICIPANT	\N	PRESENT	0
615865	613314	11083R	PARTICIPANT	\N	PRESENT	0
615866	613314	20048C	PARTICIPANT	\N	PRESENT	0
615867	613314	14257W	PARTICIPANT	\N	PRESENT	0
615868	613314	20102Q	PARTICIPANT	\N	PRESENT	0
615869	613314	20172F	PARTICIPANT	\N	PRESENT	0
615885	613314	14179A	PARTICIPANT	\N	PRESENT	0
615886	613314	20180F	PARTICIPANT	\N	PRESENT	0
615922	613315	20142Y	PARTICIPANT	\N	PRESENT	0
615923	613315	20134Y	PARTICIPANT	\N	PRESENT	0
615924	613315	19599P	PARTICIPANT	\N	PRESENT	0
615925	613315	14257W	PARTICIPANT	\N	PRESENT	0
615926	613315	19593H	PARTICIPANT	\N	PRESENT	0
615927	613315	20102Q	PARTICIPANT	\N	PRESENT	0
615928	613315	17589D	PARTICIPANT	\N	PRESENT	0
615929	613315	19681G	PARTICIPANT	\N	PRESENT	0
615930	613315	20052X	PARTICIPANT	\N	PRESENT	0
615931	613315	01024M	PARTICIPANT	\N	PRESENT	0
615932	613315	19057M	PARTICIPANT	\N	PRESENT	0
615933	613315	19711U	PARTICIPANT	\N	PRESENT	0
615934	613315	20032T	PARTICIPANT	\N	PRESENT	0
615935	613315	20172F	PARTICIPANT	\N	PRESENT	0
615936	613315	20180F	PARTICIPANT	\N	PRESENT	0
615937	613315	20026V	PARTICIPANT	\N	PRESENT	0
615938	613315	20132W	PARTICIPANT	\N	PRESENT	0
615939	613315	19693L	PARTICIPANT	\N	PRESENT	0
615940	613315	14021P	PARTICIPANT	\N	PRESENT	0
615951	613315	19611R	PARTICIPANT	\N	PRESENT	0
615952	613315	14229S	PARTICIPANT	\N	PRESENT	0
615969	613315	20090E	PARTICIPANT	\N	PRESENT	0
615980	613315	20098N	PARTICIPANT	\N	PRESENT	0
615982	613315	20130U	PARTICIPANT	\N	PRESENT	0
615987	613315	19349W	PARTICIPANT	\N	PRESENT	0
615988	613315	11083R	PARTICIPANT	\N	PRESENT	0
615989	613315	04057K	PARTICIPANT	\N	PRESENT	0
615990	613315	07029T	PARTICIPANT	\N	PRESENT	0
615920	613315	14026U	PARTICIPANT	\N	PRESENT	0
615921	613315	04059M	PARTICIPANT	\N	PRESENT	0
615991	613315	11045K	PARTICIPANT	\N	PRESENT	0
615992	613315	17023S	PARTICIPANT	\N	PRESENT	0
616021	613316	19599P	PARTICIPANT	\N	PRESENT	0
616022	613316	11045K	PARTICIPANT	\N	PRESENT	0
616023	613316	20130U	PARTICIPANT	\N	PRESENT	0
616024	613316	18193Q	PARTICIPANT	\N	PRESENT	0
616025	613316	17589D	PARTICIPANT	\N	PRESENT	0
616026	613316	04057K	PARTICIPANT	\N	PRESENT	0
616027	613316	01024M	PARTICIPANT	\N	PRESENT	0
616028	613316	19591F	PARTICIPANT	\N	PRESENT	0
616029	613316	19563B	PARTICIPANT	\N	PRESENT	0
616030	613316	14217N	PARTICIPANT	\N	PRESENT	0
616031	613316	20098N	PARTICIPANT	\N	PRESENT	0
616032	613316	19693L	PARTICIPANT	\N	PRESENT	0
616033	613316	20026V	PARTICIPANT	\N	PRESENT	0
616034	613316	19349W	PARTICIPANT	\N	PRESENT	0
616036	613316	11031D	PARTICIPANT	\N	PRESENT	0
616037	613316	14147R	PARTICIPANT	\N	PRESENT	0
616038	613316	20248J	PARTICIPANT	\N	PRESENT	0
616039	613316	11012A	PARTICIPANT	\N	PRESENT	0
616043	613316	20044X	PARTICIPANT	\N	PRESENT	0
616044	613316	20126Y	PARTICIPANT	\N	PRESENT	0
616066	613318	19826F	PARTICIPANT	\N	PRESENT	0
616067	613318	19681G	PARTICIPANT	\N	PRESENT	0
616068	613318	20080C	PARTICIPANT	\N	PRESENT	0
616069	613318	19349W	PARTICIPANT	\N	PRESENT	0
616070	613318	14251Q	PARTICIPANT	\N	PRESENT	0
616071	613318	14031R	PARTICIPANT	\N	PRESENT	0
616019	613316	14026U	PARTICIPANT	\N	PRESENT	0
616020	613316	20172F	PARTICIPANT	\N	PRESENT	0
616072	613318	11065P	PARTICIPANT	\N	PRESENT	0
616073	613318	19719D	PARTICIPANT	\N	PRESENT	0
616074	613318	19333N	PARTICIPANT	\N	PRESENT	0
616075	613318	14219Q	PARTICIPANT	\N	PRESENT	0
616076	613318	07029T	PARTICIPANT	\N	PRESENT	0
616077	613318	20044X	PARTICIPANT	\N	PRESENT	0
616078	613318	20026V	PARTICIPANT	\N	PRESENT	0
616079	613318	18083K	PARTICIPANT	\N	PRESENT	0
616080	613318	11048N	PARTICIPANT	\N	PRESENT	0
616081	613318	20034V	PARTICIPANT	\N	PRESENT	0
616064	613318	19711U	PARTICIPANT	\N	PRESENT	0
616065	613318	20102Q	PARTICIPANT	\N	PRESENT	0
616082	613318	01048V	PARTICIPANT	\N	PRESENT	0
616085	613318	19467C	PARTICIPANT	\N	PRESENT	0
616110	613318	20092G	PARTICIPANT	\N	PRESENT	0
616111	613318	07004J	PARTICIPANT	\N	PRESENT	0
616112	613318	20180F	PARTICIPANT	\N	PRESENT	0
616127	613318	19585H	PARTICIPANT	\N	PRESENT	0
616155	613319	19585H	PARTICIPANT	\N	PRESENT	0
616156	613319	14251Q	PARTICIPANT	\N	PRESENT	0
616157	613319	19333N	PARTICIPANT	\N	PRESENT	0
616158	613319	07004J	PARTICIPANT	\N	PRESENT	0
616159	613319	14179A	PARTICIPANT	\N	PRESENT	0
616160	613319	04047H	PARTICIPANT	\N	PRESENT	0
616161	613319	07029T	PARTICIPANT	\N	PRESENT	0
616162	613319	19467C	PARTICIPANT	\N	PRESENT	0
616163	613319	04085P	PARTICIPANT	\N	PRESENT	0
616164	613319	20034V	PARTICIPANT	\N	PRESENT	0
616165	613319	19693L	PARTICIPANT	\N	PRESENT	0
616166	613319	01028R	PARTICIPANT	\N	PRESENT	0
616167	613319	11012A	PARTICIPANT	\N	PRESENT	0
616168	613319	14215L	PARTICIPANT	\N	PRESENT	0
616169	613319	19711U	PARTICIPANT	\N	PRESENT	0
616170	613319	20110Q	PARTICIPANT	\N	PRESENT	0
616171	613319	95063L	PARTICIPANT	\N	PRESENT	0
616172	613319	20180F	PARTICIPANT	\N	PRESENT	0
616175	613319	11072N	PARTICIPANT	\N	PRESENT	0
618870	618824	20066E	PARTICIPANT	\N	PRESENT	1
618871	618824	20130U	PARTICIPANT	\N	PRESENT	1
618872	618824	19713W	PARTICIPANT	\N	PRESENT	1
619946	618090	18193Q	PARTICIPANT	\N	PRESENT	0
621844	621843	20086J	PARTICIPANT	\N	PRESENT	0
616153	613319	19719D	PARTICIPANT	\N	PRESENT	0
616154	613319	20102Q	PARTICIPANT	\N	PRESENT	0
621848	621847	11048N	PARTICIPANT	\N	PRESENT	0
621849	621847	08011M	PARTICIPANT	\N	PRESENT	0
621852	621851	11048N	PARTICIPANT	\N	PRESENT	0
621853	621851	08011M	PARTICIPANT	\N	PRESENT	0
622031	621292	14107H	PARTICIPANT	\N	PRESENT	1
623568	621513	04059M	PARTICIPANT	\N	PRESENT	0
623569	621513	19651A	PARTICIPANT	\N	PRESENT	1
623570	621513	20086J	PARTICIPANT	\N	PRESENT	0
623571	621513	20152B	PARTICIPANT	\N	PRESENT	0
623573	621513	11053K	PARTICIPANT	\N	PRESENT	0
618691	618083	19782L	PARTICIPANT	\N	PRESENT	0
618801	618084	19760E	PARTICIPANT	\N	PRESENT	0
618802	618084	14179A	PARTICIPANT	\N	PRESENT	0
618803	618084	20174H	PARTICIPANT	\N	PRESENT	0
618804	618084	20018V	PARTICIPANT	\N	PRESENT	0
618805	618084	14217N	PARTICIPANT	\N	PRESENT	0
618806	618084	19798U	PARTICIPANT	\N	PRESENT	0
618820	618084	17367Q	PARTICIPANT	\N	PRESENT	0
618822	618084	20032T	PARTICIPANT	\N	PRESENT	0
618823	618084	19747H	PARTICIPANT	\N	PRESENT	0
619133	619132	19507S	PARTICIPANT	\N	PRESENT	0
619189	618367	19715Y	PARTICIPANT	\N	PRESENT	0
619190	618367	19798U	PARTICIPANT	\N	PRESENT	0
619218	618367	20248J	PARTICIPANT	\N	EXCUSE	0
619223	618367	19703U	PARTICIPANT	\N	PRESENT	0
619254	619253	20140W	PARTICIPANT	\N	PRESENT	0
620646	618193	19701S	PARTICIPANT	\N	PRESENT	0
620648	618193	14001X	PARTICIPANT	\N	PRESENT	0
621070	621066	14231L	PRESIDENT	0	PRESENT	0
621071	621066	08010L	PARTICIPANT	\N	PRESENT	0
621072	621066	05012A	PARTICIPANT	\N	PRESENT	0
621073	621066	14053L	PARTICIPANT	\N	PRESENT	0
621074	621066	20062A	PARTICIPANT	\N	PRESENT	0
621075	621066	19826F	PARTICIPANT	\N	PRESENT	0
621076	621066	20090E	PARTICIPANT	\N	PRESENT	0
621077	621066	01057W	PARTICIPANT	\N	PRESENT	0
621078	621066	14187A	PARTICIPANT	\N	PRESENT	0
621080	621066	19565D	PARTICIPANT	\N	PRESENT	0
621081	621066	19820Y	PARTICIPANT	\N	PRESENT	0
621082	621066	14107H	PARTICIPANT	\N	PRESENT	0
621083	621066	20084G	PARTICIPANT	\N	PRESENT	0
621084	621066	04045F	PARTICIPANT	\N	PRESENT	0
621085	621066	19349W	PARTICIPANT	\N	PRESENT	0
621086	621066	14069U	PARTICIPANT	\N	PRESENT	0
621087	621066	19335Q	PARTICIPANT	\N	PRESENT	0
621088	621079	20144B	PARTICIPANT	\N	PRESENT	0
621089	621079	20088L	PARTICIPANT	\N	PRESENT	0
621090	621079	20094J	PARTICIPANT	\N	PRESENT	0
621091	621079	20174H	PARTICIPANT	\N	PRESENT	0
621092	621066	20022R	PARTICIPANT	\N	EXCUSE	0
621093	621066	19782L	PARTICIPANT	\N	EXCUSE	0
621094	621066	14327T	PARTICIPANT	\N	EXCUSE	0
621095	621066	14215L	PARTICIPANT	\N	EXCUSE	0
621096	621066	20120S	PARTICIPANT	\N	EXCUSE	0
621097	621066	19711U	PARTICIPANT	\N	EXCUSE	0
621098	621066	14071N	PARTICIPANT	\N	EXCUSE	0
621099	621066	14281W	PARTICIPANT	\N	PRESENT	0
621101	621100	20094J	PARTICIPANT	\N	PRESENT	0
621103	621066	19758L	PARTICIPANT	\N	PRESENT	0
621104	621066	14229S	PARTICIPANT	\N	PRESENT	0
621105	621066	19735D	PARTICIPANT	\N	PRESENT	0
621286	621284	10006L	PARTICIPANT	\N	PRESENT	0
621287	621284	19713W	PARTICIPANT	\N	PRESENT	0
621288	621284	19735D	PARTICIPANT	\N	PRESENT	0
621289	621284	19723Y	PARTICIPANT	\N	PRESENT	0
621290	621284	14147R	PARTICIPANT	\N	PRESENT	0
621293	618012	20130U	PARTICIPANT	\N	PRESENT	0
621294	618012	19467C	PARTICIPANT	\N	PRESENT	0
621295	618012	19713W	PARTICIPANT	\N	PRESENT	0
621296	618012	19691J	PARTICIPANT	\N	PRESENT	0
621309	621308	20110Q	PARTICIPANT	\N	PRESENT	0
621298	618012	19723Y	PARTICIPANT	\N	PRESENT	0
621299	618012	11031D	PARTICIPANT	\N	PRESENT	0
621300	618012	19703U	PARTICIPANT	\N	PRESENT	1
621301	618012	19553Y	PARTICIPANT	\N	PRESENT	1
621302	618012	19735D	PARTICIPANT	\N	PRESENT	1
621303	618012	14147R	PARTICIPANT	\N	PRESENT	1
621304	618012	19683J	PRESIDENT	0	PRESENT	0
621305	618012	10006L	PARTICIPANT	\N	PRESENT	0
621307	618012	20148F	PARTICIPANT	\N	EXCUSE	0
621310	621308	11085T	PARTICIPANT	\N	PRESENT	0
621311	621308	04057K	PARTICIPANT	\N	PRESENT	0
621313	621312	08028W	PARTICIPANT	\N	PRESENT	0
621314	621312	20052X	PARTICIPANT	\N	PRESENT	0
621315	621312	20018V	PARTICIPANT	\N	PRESENT	0
621400	618196	19701S	PARTICIPANT	\N	PRESENT	0
621401	618196	14001X	PARTICIPANT	\N	PRESENT	0
621412	621409	19575F	PARTICIPANT	\N	PRESENT	0
621413	621409	14357A	PARTICIPANT	\N	PRESENT	0
621414	621409	11065P	PARTICIPANT	\N	PRESENT	0
621415	621409	11070L	PARTICIPANT	\N	PRESENT	0
621416	621409	01024M	PARTICIPANT	\N	PRESENT	0
621417	621409	20174H	PARTICIPANT	\N	PRESENT	0
621418	621409	20038A	PARTICIPANT	\N	PRESENT	0
621419	621409	14033T	PARTICIPANT	\N	PRESENT	0
621420	621409	20126Y	PARTICIPANT	\N	PRESENT	0
621421	621409	19503N	PARTICIPANT	\N	PRESENT	0
621422	621409	19619A	PARTICIPANT	\N	PRESENT	0
621423	621409	20092G	PARTICIPANT	\N	PRESENT	0
621424	621409	20062A	PARTICIPANT	\N	PRESENT	0
621425	621409	19413M	PARTICIPANT	\N	PRESENT	0
621565	621507	14217N	PARTICIPANT	\N	EXCUSE	0
621614	621613	86034E	PARTICIPANT	\N	PRESENT	0
621615	621613	04085P	PARTICIPANT	\N	PRESENT	0
621616	621613	04042C	PARTICIPANT	\N	PRESENT	0
621617	621613	11053K	PARTICIPANT	\N	PRESENT	0
621618	621613	14215L	PARTICIPANT	\N	PRESENT	0
621619	621613	19629C	PARTICIPANT	\N	PRESENT	0
621620	621613	10006L	PARTICIPANT	\N	PRESENT	0
621621	621613	14042U	PARTICIPANT	\N	PRESENT	0
621386	617182	05008E	PARTICIPANT	\N	EXCUSE	0
621387	617182	11010L	PARTICIPANT	\N	EXCUSE	0
621622	621613	19347U	PARTICIPANT	\N	PRESENT	0
621623	621613	14026U	PARTICIPANT	\N	PRESENT	0
621624	621613	11048N	PARTICIPANT	\N	PRESENT	0
621625	621613	14021P	PARTICIPANT	\N	PRESENT	0
621626	621613	19611R	PARTICIPANT	\N	PRESENT	0
621627	621613	14251Q	PARTICIPANT	\N	PRESENT	0
621628	621613	11085T	PARTICIPANT	\N	PRESENT	0
621629	621613	08061X	PARTICIPANT	\N	PRESENT	0
621630	621613	11090Q	PARTICIPANT	\N	PRESENT	0
621631	621613	14331P	PARTICIPANT	\N	PRESENT	0
621632	621613	04033B	PARTICIPANT	\N	PRESENT	0
621633	621613	11045K	PARTICIPANT	\N	PRESENT	0
621914	621913	86034E	PARTICIPANT	\N	PRESENT	0
621915	621913	19717B	PARTICIPANT	\N	PRESENT	0
621916	621913	19515S	PARTICIPANT	\N	PRESENT	0
621917	621913	14030Q	PARTICIPANT	\N	PRESENT	0
621919	621913	20104S	PARTICIPANT	\N	PRESENT	0
621920	621913	04042C	PARTICIPANT	\N	PRESENT	0
621921	621913	11053K	PARTICIPANT	\N	PRESENT	0
621922	621913	19701S	PARTICIPANT	\N	PRESENT	0
621923	621913	14215L	PARTICIPANT	\N	PRESENT	0
621924	621913	14259Y	PARTICIPANT	\N	PRESENT	0
621925	621913	19719D	PARTICIPANT	\N	PRESENT	0
621926	621913	14231L	PARTICIPANT	\N	PRESENT	0
621927	621913	19347U	PARTICIPANT	\N	PRESENT	0
621928	621913	14026U	PARTICIPANT	\N	PRESENT	0
621929	621913	14021P	PARTICIPANT	\N	PRESENT	0
621930	621913	99004R	PARTICIPANT	\N	PRESENT	0
621931	621913	19611R	PARTICIPANT	\N	PRESENT	0
621932	621913	12041X	PARTICIPANT	\N	PRESENT	0
621933	621913	01048V	PARTICIPANT	\N	PRESENT	0
621934	621913	11085T	PARTICIPANT	\N	PRESENT	0
621935	621913	04057K	PARTICIPANT	\N	PRESENT	0
621936	621913	04092N	PARTICIPANT	\N	PRESENT	0
621937	621913	08061X	PARTICIPANT	\N	PRESENT	0
621938	621913	11090Q	PARTICIPANT	\N	PRESENT	0
621939	621913	14225N	PARTICIPANT	\N	PRESENT	0
621940	621913	11012A	PARTICIPANT	\N	PRESENT	0
621941	621913	04033B	PARTICIPANT	\N	PRESENT	0
621960	621959	19367Y	PARTICIPANT	\N	PRESENT	0
621962	621961	19367Y	PARTICIPANT	\N	PRESENT	0
621963	621961	20130U	PARTICIPANT	\N	PRESENT	0
621965	621964	19367Y	PARTICIPANT	\N	PRESENT	0
621966	621964	14213J	PARTICIPANT	\N	PRESENT	0
621967	621964	19713W	PARTICIPANT	\N	PRESENT	0
621969	621968	19367Y	PARTICIPANT	\N	PRESENT	0
621970	621968	14213J	PARTICIPANT	\N	PRESENT	0
621971	621968	20130U	PARTICIPANT	\N	PRESENT	0
621972	621968	19713W	PARTICIPANT	\N	PRESENT	0
622069	622067	18083K	PARTICIPANT	\N	PRESENT	0
622070	622067	19619A	PARTICIPANT	\N	PRESENT	0
622071	622067	19333N	PARTICIPANT	\N	PRESENT	0
622074	622073	14259Y	PARTICIPANT	\N	PRESENT	0
622075	622073	14275Y	PARTICIPANT	\N	PRESENT	0
622078	622077	14259Y	PARTICIPANT	\N	PRESENT	0
622106	622076	19367Y	PARTICIPANT	\N	PRESENT	0
622112	622111	14213J	PARTICIPANT	\N	PRESENT	0
602972	602971	11026G	PARTICIPANT	\N	PRESENT	0
602975	602974	19629C	PARTICIPANT	\N	PRESENT	0
602982	602978	01043Q	PARTICIPANT	\N	PRESENT	0
602986	602979	01043Q	PARTICIPANT	\N	PRESENT	0
603015	602980	01043Q	PARTICIPANT	\N	PRESENT	0
603016	602980	19631V	PARTICIPANT	\N	PRESENT	0
606401	603153	19577H	PARTICIPANT	\N	PRESENT	0
606403	603153	20248J	PARTICIPANT	\N	PRESENT	0
606409	603153	19569H	PARTICIPANT	\N	PRESENT	0
606410	603153	20086J	PARTICIPANT	\N	PRESENT	0
606412	603153	86034E	PARTICIPANT	\N	PRESENT	0
606421	606420	17737W	PARTICIPANT	\N	PRESENT	0
606422	603153	20100N	PARTICIPANT	\N	PRESENT	0
606423	603153	19747H	PARTICIPANT	\N	PRESENT	0
606424	603153	14069U	PARTICIPANT	\N	PRESENT	0
606863	606862	17737W	PARTICIPANT	\N	PRESENT	0
606892	606828	20104S	PARTICIPANT	\N	EXCUSE	0
606893	606828	19705W	PARTICIPANT	\N	EXCUSE	0
606894	606828	11090Q	PARTICIPANT	\N	EXCUSE	0
606895	606828	20054A	PARTICIPANT	\N	PRESENT	0
607330	607329	20022R	PARTICIPANT	\N	PRESENT	0
607331	607329	19599P	PARTICIPANT	\N	PRESENT	0
607385	607383	17737W	PARTICIPANT	\N	PRESENT	0
607399	607398	19749K	PARTICIPANT	\N	PRESENT	0
607402	607401	19749K	PARTICIPANT	\N	PRESENT	0
607403	607401	14021P	PARTICIPANT	\N	PRESENT	0
607406	607405	19749K	PARTICIPANT	\N	PRESENT	0
608382	607211	08073C	PARTICIPANT	\N	PRESENT	0
608408	607180	20090E	PARTICIPANT	\N	PRESENT	0
608409	607180	19711U	PARTICIPANT	\N	PRESENT	0
608410	607180	20064C	PARTICIPANT	\N	PRESENT	0
608411	607180	19531S	PARTICIPANT	\N	PRESENT	0
608412	607180	19689Q	PARTICIPANT	\N	PRESENT	0
608413	607180	19667J	PRESIDENT	0	PRESENT	0
608414	607180	19511N	PARTICIPANT	\N	PRESENT	0
608415	607180	19681G	PARTICIPANT	\N	PRESENT	0
608416	607180	19671E	PARTICIPANT	\N	PRESENT	0
608417	607180	14249W	PARTICIPANT	\N	PRESENT	0
608418	607180	04085P	PARTICIPANT	\N	PRESENT	0
608419	607180	19741B	PARTICIPANT	\N	EXCUSE	0
608420	607180	19335Q	PARTICIPANT	\N	EXCUSE	0
608421	607180	20044X	PARTICIPANT	\N	EXCUSE	0
608441	606278	20090E	PARTICIPANT	\N	PRESENT	0
608442	606278	11067R	PARTICIPANT	\N	PRESENT	0
608443	606278	20248J	PARTICIPANT	\N	PRESENT	0
608444	606278	14042U	PARTICIPANT	\N	PRESENT	0
608445	606278	14213J	PARTICIPANT	\N	PRESENT	0
608446	606278	10006L	PRESIDENT	0	PRESENT	0
608447	606278	19683J	PARTICIPANT	\N	PRESENT	0
608448	606278	20066E	PARTICIPANT	\N	EXCUSE	0
608449	606278	20040T	PARTICIPANT	\N	EXCUSE	0
608450	606278	14071N	PARTICIPANT	\N	EXCUSE	0
608451	606278	19760E	PARTICIPANT	\N	EXCUSE	0
608458	607211	20142Y	PARTICIPANT	\N	PRESENT	0
608460	607211	14109K	PARTICIPANT	\N	PRESENT	0
608461	607211	19057M	PARTICIPANT	\N	PRESENT	0
608462	607211	19611R	PARTICIPANT	\N	PRESENT	0
608463	607211	19699S	PARTICIPANT	\N	PRESENT	0
608464	607211	19399H	PARTICIPANT	\N	PRESENT	0
608467	607211	20132W	PARTICIPANT	\N	PRESENT	0
608469	607211	19758L	PARTICIPANT	\N	PRESENT	0
608471	607211	19593H	PARTICIPANT	\N	PRESENT	0
608474	607211	19621T	PARTICIPANT	\N	PRESENT	0
608480	607211	20152B	PARTICIPANT	\N	PRESENT	0
608481	607211	19735D	PARTICIPANT	\N	PRESENT	0
608482	607211	11056N	PARTICIPANT	\N	PRESENT	0
608483	607211	20134Y	PARTICIPANT	\N	PRESENT	0
608484	607211	20106U	PARTICIPANT	\N	PRESENT	0
608485	607211	08010L	PARTICIPANT	\N	PRESENT	0
608486	607211	19333N	PARTICIPANT	\N	PRESENT	0
608487	607211	19747H	PARTICIPANT	\N	PRESENT	0
608488	607211	19543W	PARTICIPANT	\N	PRESENT	0
608489	607211	20052X	PARTICIPANT	\N	PRESENT	0
608490	607211	20266L	PARTICIPANT	\N	PRESENT	0
608491	607211	04057K	PARTICIPANT	\N	PRESENT	0
608492	607211	14147R	PARTICIPANT	\N	PRESENT	0
608675	608674	20114U	PARTICIPANT	\N	PRESENT	0
608676	608674	19599P	PARTICIPANT	\N	PRESENT	0
608677	608674	14097Y	PARTICIPANT	\N	PRESENT	0
608678	608674	12041X	PARTICIPANT	\N	PRESENT	0
608679	608674	11054L	PARTICIPANT	\N	PRESENT	0
608681	608680	11083R	PARTICIPANT	\N	PRESENT	0
608683	608682	14030Q	PARTICIPANT	\N	PRESENT	0
608684	608682	14042U	PARTICIPANT	\N	PRESENT	0
608685	608682	19723Y	PARTICIPANT	\N	PRESENT	0
608686	608682	19503N	PARTICIPANT	\N	PRESENT	0
608687	608682	11083R	PARTICIPANT	\N	PRESENT	0
608689	608688	19749K	PARTICIPANT	\N	PRESENT	0
608691	608690	19749K	PARTICIPANT	\N	PRESENT	0
609286	608647	14111D	PARTICIPANT	\N	PRESENT	0
609287	608647	19649G	PARTICIPANT	\N	PRESENT	0
609288	608647	10015M	PARTICIPANT	\N	PRESENT	0
609289	608647	04047H	PRESIDENT	0	PRESENT	0
609290	608647	19673G	PARTICIPANT	\N	PRESENT	0
609291	608647	19447X	PARTICIPANT	\N	PRESENT	0
609292	608647	17737W	PARTICIPANT	\N	PRESENT	0
609293	608647	19629C	PARTICIPANT	\N	PRESENT	0
609294	608647	07004J	PARTICIPANT	\N	PRESENT	0
609295	608647	20110Q	PARTICIPANT	\N	PRESENT	0
609296	608647	14147R	PARTICIPANT	\N	PRESENT	0
609297	608647	14215L	PARTICIPANT	\N	PRESENT	0
609298	608647	19749K	PARTICIPANT	\N	PRESENT	0
609299	608647	20022R	PARTICIPANT	\N	PRESENT	0
609300	608647	19729F	PARTICIPANT	\N	EXCUSE	0
609301	608647	20074E	PARTICIPANT	\N	PRESENT	0
609302	608647	19543W	PARTICIPANT	\N	PRESENT	0
609303	608647	19585H	PARTICIPANT	\N	PRESENT	0
609304	608647	19489J	PARTICIPANT	\N	PRESENT	0
609305	608647	14151M	PARTICIPANT	\N	PRESENT	0
609306	608647	20128B	PARTICIPANT	\N	PRESENT	0
609307	608647	11033F	PARTICIPANT	\N	PRESENT	0
609308	608647	04085P	PARTICIPANT	\N	PRESENT	0
609309	608647	19725B	PARTICIPANT	\N	PRESENT	0
609310	608647	14069U	PARTICIPANT	\N	PRESENT	0
609311	608647	14021P	PARTICIPANT	\N	PRESENT	0
609312	608647	04008A	PARTICIPANT	\N	PRESENT	0
609313	608647	14001X	PARTICIPANT	\N	PRESENT	0
609314	608647	01028R	PARTICIPANT	\N	PRESENT	0
609315	608647	05008E	PARTICIPANT	\N	PRESENT	0
609316	608647	14179A	PARTICIPANT	\N	PRESENT	0
609375	608234	20090E	PARTICIPANT	\N	PRESENT	0
609376	608234	17779H	PARTICIPANT	\N	PRESENT	0
609377	608234	19591F	PARTICIPANT	\N	PRESENT	0
609378	608234	01034P	PARTICIPANT	\N	PRESENT	0
609379	608234	19713W	PARTICIPANT	\N	PRESENT	0
609380	608234	20066E	PARTICIPANT	\N	PRESENT	0
609381	608234	04043D	PARTICIPANT	\N	PRESENT	0
609382	608672	11040E	PARTICIPANT	\N	PRESENT	0
609383	608672	11048N	PARTICIPANT	\N	PRESENT	0
609384	608672	19479G	PARTICIPANT	\N	PRESENT	0
609385	608672	01057W	PARTICIPANT	\N	PRESENT	0
609386	608672	19349W	PARTICIPANT	\N	PRESENT	0
609387	608672	99004R	PARTICIPANT	\N	PRESENT	0
609388	608672	14225N	PRESIDENT	0	PRESENT	0
609389	608672	14173T	PARTICIPANT	\N	PRESENT	0
609390	608672	19531S	PARTICIPANT	\N	PRESENT	0
609391	608672	19689Q	PARTICIPANT	\N	PRESENT	0
609392	608672	11053K	PARTICIPANT	\N	PRESENT	0
609393	608672	19671E	PARTICIPANT	\N	PRESENT	0
609394	608672	11012A	PARTICIPANT	\N	PRESENT	0
609395	608672	20252E	PARTICIPANT	\N	PRESENT	0
609396	608672	20070A	PARTICIPANT	\N	PRESENT	0
609397	608672	14121F	PARTICIPANT	\N	PRESENT	0
609398	608672	14253S	PARTICIPANT	\N	PRESENT	0
609399	608672	20126Y	PARTICIPANT	\N	PRESENT	0
609400	608672	19762G	PARTICIPANT	\N	PRESENT	0
609401	608672	19711U	PARTICIPANT	\N	PRESENT	0
609402	606464	20032T	PARTICIPANT	\N	PRESENT	0
609403	606464	20136B	PARTICIPANT	\N	PRESENT	0
609404	606464	20102Q	PARTICIPANT	\N	PRESENT	0
609406	606464	11101A	PARTICIPANT	\N	PRESENT	0
609407	606464	19387D	PARTICIPANT	\N	PRESENT	0
609408	606464	19251M	PARTICIPANT	\N	PRESENT	0
609409	606464	19826F	PARTICIPANT	\N	PRESENT	0
609413	606464	20140W	PARTICIPANT	\N	PRESENT	0
609414	606464	19503N	PARTICIPANT	\N	PRESENT	0
609415	606464	20020P	PARTICIPANT	\N	PRESENT	0
609416	606464	14219Q	PRESIDENT	0	PRESENT	0
609417	606464	17367Q	PARTICIPANT	\N	PRESENT	0
609418	606464	14031R	PARTICIPANT	\N	PRESENT	0
619497	618089	14189C	PARTICIPANT	\N	PRESENT	0
619498	618089	11067R	PARTICIPANT	\N	PRESENT	0
619499	618089	14329V	PARTICIPANT	\N	PRESENT	0
619500	618089	14257W	PARTICIPANT	\N	PRESENT	0
619501	618089	14038Y	PARTICIPANT	\N	PRESENT	0
619502	618089	20118Y	PARTICIPANT	\N	PRESENT	0
619503	618089	14069U	PARTICIPANT	\N	PRESENT	0
619504	618089	19671E	PARTICIPANT	\N	PRESENT	0
619505	618089	19533U	PARTICIPANT	\N	PRESENT	0
619510	618089	20124W	PARTICIPANT	\N	PRESENT	0
619507	618089	20092G	PARTICIPANT	\N	PRESENT	0
619508	618089	20142Y	PARTICIPANT	\N	PRESENT	0
619509	618089	20090E	PARTICIPANT	\N	PRESENT	0
619511	618089	14089Y	PARTICIPANT	\N	PRESENT	0
619512	618089	20126Y	PARTICIPANT	\N	PRESENT	0
619513	618089	14187A	PARTICIPANT	\N	PRESENT	0
619514	618089	14030Q	PARTICIPANT	\N	PRESENT	0
619515	618089	19673G	PARTICIPANT	\N	PRESENT	0
619516	618089	20022R	PARTICIPANT	\N	PRESENT	0
619517	618089	19383Y	PARTICIPANT	\N	PRESENT	0
619518	618089	20076G	PARTICIPANT	\N	PRESENT	0
619519	618089	19643A	PARTICIPANT	\N	PRESENT	0
619520	618089	20086J	PARTICIPANT	\N	PRESENT	0
619521	618089	19798U	PARTICIPANT	\N	PRESENT	0
619522	618089	19399H	PARTICIPANT	\N	PRESENT	0
619523	618089	12028B	PARTICIPANT	\N	PRESENT	0
619524	618089	20058E	PARTICIPANT	\N	PRESENT	0
619525	618089	19467C	PARTICIPANT	\N	PRESENT	0
619526	618089	19549D	PARTICIPANT	\N	PRESENT	0
619527	618089	14215L	PARTICIPANT	\N	PRESENT	0
619528	618089	19826F	PARTICIPANT	\N	PRESENT	0
619529	618089	20110Q	PARTICIPANT	\N	PRESENT	0
619530	618089	20264J	PARTICIPANT	\N	PRESENT	0
619531	618089	19629C	PARTICIPANT	\N	PRESENT	0
619532	618089	14217N	PARTICIPANT	\N	PRESENT	0
619533	618089	14123H	PARTICIPANT	\N	PRESENT	0
619534	618089	14231L	PARTICIPANT	\N	PRESENT	0
619535	618089	20032T	PARTICIPANT	\N	PRESENT	0
619536	618089	20052X	PARTICIPANT	\N	PRESENT	0
619537	618089	17637T	PARTICIPANT	\N	PRESENT	0
619538	618089	11033F	PARTICIPANT	\N	PRESENT	0
619539	618089	19866P	PARTICIPANT	\N	PRESENT	0
619540	618089	14331P	PARTICIPANT	\N	PRESENT	0
619541	618089	20132W	PARTICIPANT	\N	PRESENT	0
619542	618089	04033B	PARTICIPANT	\N	PRESENT	0
619543	618089	19719D	PARTICIPANT	\N	PRESENT	0
619544	618089	14133K	PARTICIPANT	\N	PRESENT	0
619545	618089	14042U	PARTICIPANT	\N	PRESENT	0
619546	618089	19621T	PARTICIPANT	\N	PRESENT	0
619547	618089	20102Q	PARTICIPANT	\N	PRESENT	0
619548	618089	95063L	PARTICIPANT	\N	PRESENT	0
619549	618089	19758L	PARTICIPANT	\N	PRESENT	0
619550	618089	04085P	PARTICIPANT	\N	PRESENT	0
619551	618089	19695N	PARTICIPANT	\N	PRESENT	0
619552	618089	19443T	PARTICIPANT	\N	PRESENT	0
619553	618089	19565D	PARTICIPANT	\N	PRESENT	0
619554	618089	19347U	PARTICIPANT	\N	PRESENT	0
619555	618089	20266L	PARTICIPANT	\N	PRESENT	0
619556	618089	20116W	PARTICIPANT	\N	PRESENT	0
619557	618089	19689Q	PARTICIPANT	\N	PRESENT	0
619558	618089	19413M	PARTICIPANT	\N	PRESENT	0
619559	618089	19760E	PARTICIPANT	\N	PRESENT	0
619560	618089	19723Y	PARTICIPANT	\N	PRESENT	0
619561	618089	20252E	PARTICIPANT	\N	PRESENT	0
619562	618089	14151M	PARTICIPANT	\N	PRESENT	0
619563	618089	08015R	PARTICIPANT	\N	PRESENT	0
619564	618089	19447X	PARTICIPANT	\N	PRESENT	0
619565	618089	19569H	PARTICIPANT	\N	PRESENT	0
619566	618089	20134Y	PARTICIPANT	\N	PRESENT	0
619567	618089	14357A	PARTICIPANT	\N	PRESENT	0
619568	618089	11090Q	PARTICIPANT	\N	PRESENT	0
619569	618089	14055N	PARTICIPANT	\N	PRESENT	0
619570	618089	19687N	PARTICIPANT	\N	PRESENT	0
619571	618089	14193X	PARTICIPANT	\N	PRESENT	0
619572	618089	19551W	PARTICIPANT	\N	PRESENT	0
619573	618089	17737W	PARTICIPANT	\N	PRESENT	0
619574	618089	19649G	PARTICIPANT	\N	PRESENT	0
619575	618089	18193Q	PARTICIPANT	\N	PRESENT	0
619576	618089	20128B	PARTICIPANT	\N	PRESENT	0
619577	618089	19697Q	PARTICIPANT	\N	PRESENT	0
619581	618089	19693L	PARTICIPANT	\N	PRESENT	0
619579	618089	19741B	PARTICIPANT	\N	PRESENT	0
619580	618089	14083S	PARTICIPANT	\N	PRESENT	0
619582	618089	14179A	PARTICIPANT	\N	PRESENT	0
619583	618089	19782L	PARTICIPANT	\N	PRESENT	0
619584	618089	14213J	PARTICIPANT	\N	PRESENT	0
619585	618089	20172F	PARTICIPANT	\N	PRESENT	0
619586	618089	11097X	PARTICIPANT	\N	PRESENT	0
619587	618089	18083K	PARTICIPANT	\N	PRESENT	0
619588	618089	14053L	PARTICIPANT	\N	PRESENT	0
619589	618089	95041E	PARTICIPANT	\N	PRESENT	0
619590	618089	20104S	PARTICIPANT	\N	PRESENT	0
619591	618089	19715Y	PARTICIPANT	\N	PRESENT	0
619592	618089	10006L	PARTICIPANT	\N	PRESENT	0
619593	618089	19301E	PARTICIPANT	\N	PRESENT	0
619594	618089	20080C	PARTICIPANT	\N	PRESENT	0
619595	618089	19631V	PARTICIPANT	\N	PRESENT	0
619596	618089	20056C	PARTICIPANT	\N	PRESENT	0
619597	618089	17779H	PARTICIPANT	\N	PRESENT	0
619598	618089	20140W	PARTICIPANT	\N	PRESENT	0
619599	618089	20066E	PARTICIPANT	\N	PRESENT	0
619600	618089	20098N	PARTICIPANT	\N	PRESENT	0
619601	618089	20026V	PARTICIPANT	\N	PRESENT	0
619602	618089	17965H	PARTICIPANT	\N	PRESENT	0
619603	618089	19820Y	PARTICIPANT	\N	PRESENT	0
619604	618089	14259Y	PARTICIPANT	\N	PRESENT	0
619605	618089	20106U	PARTICIPANT	\N	PRESENT	0
619606	618089	08061X	PARTICIPANT	\N	PRESENT	0
619607	618089	19591F	PARTICIPANT	\N	PRESENT	0
619608	618089	07029T	PARTICIPANT	\N	PRESENT	0
619609	618089	14205J	PARTICIPANT	\N	PRESENT	0
619610	618089	20094J	PARTICIPANT	\N	PRESENT	0
619611	618089	20070A	PARTICIPANT	\N	PRESENT	0
619612	618089	19553Y	PARTICIPANT	\N	PRESENT	0
619613	618089	10015M	PARTICIPANT	\N	PRESENT	0
619614	618089	19762G	PARTICIPANT	\N	PRESENT	0
619615	618089	19415P	PARTICIPANT	\N	PRESENT	0
619616	618089	20062A	PARTICIPANT	\N	PRESENT	0
619617	618089	04092N	PARTICIPANT	\N	PRESENT	0
619618	618089	20054A	PARTICIPANT	\N	PRESENT	0
619619	618089	19657G	PARTICIPANT	\N	PRESENT	0
619620	618089	14026U	PARTICIPANT	\N	PRESENT	0
619621	618089	11048N	PARTICIPANT	\N	PRESENT	0
619622	618089	19573D	PARTICIPANT	\N	PRESENT	0
619623	618089	19713W	PARTICIPANT	\N	PRESENT	0
619624	618089	08018U	PARTICIPANT	\N	PRESENT	0
619625	618089	19251M	PARTICIPANT	\N	PRESENT	0
619626	618089	20064C	PARTICIPANT	\N	PRESENT	0
619627	618089	20048C	PARTICIPANT	\N	PRESENT	0
619628	618089	11026G	PARTICIPANT	\N	PRESENT	0
619629	618089	11065P	PARTICIPANT	\N	PRESENT	0
619630	618089	19387D	PARTICIPANT	\N	PRESENT	0
619631	618089	19507S	PARTICIPANT	\N	PRESENT	0
619632	618089	14105F	PARTICIPANT	\N	PRESENT	0
619633	618089	20136B	PARTICIPANT	\N	PRESENT	0
619634	618089	19531S	PARTICIPANT	\N	PRESENT	0
619495	618089	14033T	PARTICIPANT	\N	PRESENT	0
619496	618089	20038A	PARTICIPANT	\N	PRESENT	0
619635	618089	19057M	PARTICIPANT	\N	PRESENT	0
619636	618089	11043H	PARTICIPANT	\N	PRESENT	0
619637	618089	19545Y	PARTICIPANT	\N	PRESENT	0
619711	619707	14033T	PARTICIPANT	\N	PRESENT	0
619712	619707	12041X	PARTICIPANT	\N	PRESENT	0
619713	619707	14073Q	PARTICIPANT	\N	PRESENT	0
619714	619707	19333N	PARTICIPANT	\N	PRESENT	0
619716	619707	14026U	PARTICIPANT	\N	PRESENT	0
619726	618370	04057K	PARTICIPANT	\N	PRESENT	0
619727	618370	20130U	PARTICIPANT	\N	PRESENT	1
619728	618370	17779H	PARTICIPANT	\N	PRESENT	1
619729	618370	20266L	PARTICIPANT	\N	PRESENT	1
619730	618370	11103C	PARTICIPANT	\N	PRESENT	1
619731	618370	04043D	PARTICIPANT	\N	PRESENT	1
619732	618370	19301E	PARTICIPANT	\N	PRESENT	0
619733	618370	14026U	PARTICIPANT	\N	PRESENT	1
619734	618370	20066E	PARTICIPANT	\N	PRESENT	1
619735	618370	19591F	PARTICIPANT	\N	PRESENT	1
619736	618370	19553Y	PARTICIPANT	\N	PRESENT	1
619737	618370	19663E	PARTICIPANT	\N	PRESENT	1
619738	618370	19717B	PARTICIPANT	\N	PRESENT	1
619739	618370	14281W	PARTICIPANT	\N	PRESENT	1
619740	618370	19697Q	PARTICIPANT	\N	PRESENT	1
610835	610834	14071N	PARTICIPANT	\N	PRESENT	0
610836	610834	19826F	PARTICIPANT	\N	PRESENT	0
618616	618366	11103C	PARTICIPANT	\N	PRESENT	1
610839	610837	20118Y	PARTICIPANT	\N	PRESENT	0
619890	618364	19671E	PARTICIPANT	\N	EXCUSE	0
619891	618364	08010L	PARTICIPANT	\N	EXCUSE	0
622971	622970	20118Y	PARTICIPANT	\N	PRESENT	0
622973	622972	20118Y	PARTICIPANT	\N	PRESENT	0
623344	621403	19693L	PARTICIPANT	\N	PRESENT	0
623574	621513	11080N	PARTICIPANT	\N	PRESENT	0
623575	621513	19673G	PARTICIPANT	\N	PRESENT	1
623576	621513	20132W	PARTICIPANT	\N	PRESENT	0
623750	621785	10006L	PARTICIPANT	\N	PRESENT	0
623578	621513	19399H	PARTICIPANT	\N	PRESENT	0
623579	621513	20056C	PARTICIPANT	\N	PRESENT	0
623580	621513	19611R	PRESIDENT	0	PRESENT	0
623581	621513	19699S	PARTICIPANT	\N	PRESENT	0
623582	621513	12041X	PARTICIPANT	\N	PRESENT	0
623583	621513	20142Y	PARTICIPANT	\N	PRESENT	0
623584	621513	19705W	PARTICIPANT	\N	PRESENT	0
623585	621513	14229S	PARTICIPANT	\N	PRESENT	0
623586	621513	19669L	PARTICIPANT	\N	PRESENT	1
623587	621513	20026V	PARTICIPANT	\N	PRESENT	1
623588	621513	20122U	PARTICIPANT	\N	PRESENT	0
623751	621785	14147R	PARTICIPANT	\N	PRESENT	1
624726	624079	19701S	PARTICIPANT	\N	PRESENT	0
624727	624079	14357A	PARTICIPANT	\N	PRESENT	0
624728	624079	19507S	PARTICIPANT	\N	PRESENT	0
624729	624079	11026G	PARTICIPANT	\N	PRESENT	0
624730	624079	19441R	PARTICIPANT	\N	PRESENT	0
624731	624079	08034U	PARTICIPANT	\N	PRESENT	0
626745	626743	19701S	PARTICIPANT	\N	PRESENT	0
626746	626743	20124W	PARTICIPANT	\N	PRESENT	0
626747	626743	14213J	PARTICIPANT	\N	PRESENT	0
626748	626743	14083S	PARTICIPANT	\N	PRESENT	0
626749	626743	01024M	PARTICIPANT	\N	PRESENT	0
626764	624273	14030Q	PARTICIPANT	\N	EXCUSE	0
626765	624273	20094J	PARTICIPANT	\N	EXCUSE	0
626766	624273	19545Y	PARTICIPANT	\N	EXCUSE	0
626767	624273	08028W	PARTICIPANT	\N	EXCUSE	0
626768	624273	19369B	PARTICIPANT	\N	EXCUSE	0
626769	624273	20092G	PARTICIPANT	\N	EXCUSE	0
626867	625792	08034U	PARTICIPANT	\N	PRESENT	0
626868	625792	19333N	PARTICIPANT	\N	PRESENT	0
626869	625792	14026U	PARTICIPANT	\N	PRESENT	0
626871	626870	08034U	PARTICIPANT	\N	PRESENT	0
626872	626870	19333N	PARTICIPANT	\N	PRESENT	0
626965	626959	14147R	PARTICIPANT	\N	PRESENT	0
626966	626959	20062A	PARTICIPANT	\N	PRESENT	0
626967	626959	19301E	PARTICIPANT	\N	PRESENT	0
626968	626959	19713W	PARTICIPANT	\N	PRESENT	0
626969	626959	19723Y	PARTICIPANT	\N	PRESENT	0
626970	626960	10006L	PARTICIPANT	\N	PRESENT	0
626971	626960	11031D	PARTICIPANT	\N	PRESENT	0
626972	626960	14147R	PARTICIPANT	\N	PRESENT	0
626973	626960	20130U	PARTICIPANT	\N	PRESENT	0
626976	626960	19723Y	PARTICIPANT	\N	PRESENT	0
626978	626961	10006L	PARTICIPANT	\N	PRESENT	0
626977	626961	11031D	PARTICIPANT	\N	PRESENT	0
626979	626961	14147R	PARTICIPANT	\N	PRESENT	0
626980	626961	19723Y	PARTICIPANT	\N	PRESENT	0
626981	626961	20130U	PARTICIPANT	\N	PRESENT	0
626982	626962	19663E	PARTICIPANT	\N	PRESENT	0
626983	626962	10006L	PARTICIPANT	\N	PRESENT	0
626984	626962	19723Y	PARTICIPANT	\N	PRESENT	0
626985	626962	17965H	PARTICIPANT	\N	PRESENT	0
626986	626963	19663E	PARTICIPANT	\N	PRESENT	0
626987	626963	17965H	PARTICIPANT	\N	PRESENT	0
627006	627005	08009T	PARTICIPANT	\N	PRESENT	0
627007	627005	20044X	PARTICIPANT	\N	PRESENT	0
627009	627008	08009T	PARTICIPANT	\N	PRESENT	0
627010	627008	20044X	PARTICIPANT	\N	PRESENT	0
627022	627021	19782L	PARTICIPANT	\N	PRESENT	1
627023	627021	14038Y	PARTICIPANT	\N	PRESENT	0
627024	627021	14187A	PARTICIPANT	\N	PRESENT	1
627025	627021	20062A	PARTICIPANT	\N	PRESENT	0
627026	627021	19629C	PARTICIPANT	\N	PRESENT	0
627027	627021	11056N	PARTICIPANT	\N	PRESENT	0
627028	627021	14179A	PARTICIPANT	\N	PRESENT	1
627029	627021	14147R	PARTICIPANT	\N	PRESENT	0
627031	627030	20144B	PARTICIPANT	\N	PRESENT	0
627032	627030	19693L	PRESIDENT	0	PRESENT	0
627033	627030	14097Y	PARTICIPANT	\N	PRESENT	1
627034	627030	20050V	PARTICIPANT	\N	PRESENT	0
627035	627030	20082E	PARTICIPANT	\N	PRESENT	1
627036	627030	20126Y	PARTICIPANT	\N	PRESENT	1
627037	627030	19369B	PARTICIPANT	\N	EXCUSE	0
627039	627038	19747H	PARTICIPANT	\N	PRESENT	0
627040	627038	20264J	PARTICIPANT	\N	PRESENT	0
627041	627038	19693L	PARTICIPANT	\N	PRESENT	0
627042	627038	20074E	PARTICIPANT	\N	PRESENT	0
627043	627038	19369B	PARTICIPANT	\N	PRESENT	0
627044	627038	20050V	PARTICIPANT	\N	PRESENT	0
627045	627038	20082E	PARTICIPANT	\N	PRESENT	1
627046	627038	14097Y	PARTICIPANT	\N	PRESENT	1
627047	627038	20126Y	PARTICIPANT	\N	PRESENT	1
627049	626958	04059M	PARTICIPANT	\N	PRESENT	0
627050	626958	19651A	PARTICIPANT	\N	PRESENT	1
627051	626958	20086J	PARTICIPANT	\N	PRESENT	1
627072	627070	11026G	PARTICIPANT	\N	PRESENT	0
627073	624187	19531S	PARTICIPANT	\N	PRESENT	0
627054	626958	11053K	PARTICIPANT	\N	PRESENT	0
627074	624187	14331P	PARTICIPANT	\N	PRESENT	0
627078	627077	20022R	PARTICIPANT	\N	PRESENT	0
627080	627079	86034E	PARTICIPANT	\N	PRESENT	0
627058	626958	19725B	PARTICIPANT	\N	PRESENT	1
627059	626958	19399H	PARTICIPANT	\N	PRESENT	0
627060	626958	20056C	PARTICIPANT	\N	PRESENT	1
627061	626958	19611R	PRESIDENT	0	PRESENT	0
627062	626958	19699S	PARTICIPANT	\N	PRESENT	1
627081	627079	14133K	PARTICIPANT	\N	PRESENT	0
627064	626958	20142Y	PARTICIPANT	\N	PRESENT	1
627082	627079	20104S	PARTICIPANT	\N	PRESENT	0
627066	626958	14229S	PARTICIPANT	\N	PRESENT	0
627083	627079	11053K	PARTICIPANT	\N	PRESENT	0
627084	627079	11056N	PARTICIPANT	\N	PRESENT	0
627069	626958	20122U	PARTICIPANT	\N	PRESENT	0
627085	627079	14215L	PARTICIPANT	\N	PRESENT	0
627086	627079	19719D	PARTICIPANT	\N	PRESENT	0
627087	627079	10006L	PARTICIPANT	\N	PRESENT	0
627088	627079	19347U	PARTICIPANT	\N	PRESENT	0
627089	627079	14026U	PARTICIPANT	\N	PRESENT	0
627090	627079	11048N	PARTICIPANT	\N	PRESENT	0
627091	627079	14021P	PARTICIPANT	\N	PRESENT	0
627092	627079	99004R	PARTICIPANT	\N	PRESENT	0
627093	627079	14219Q	PARTICIPANT	\N	PRESENT	0
627094	627079	11085T	PARTICIPANT	\N	PRESENT	0
627095	627079	08061X	PARTICIPANT	\N	PRESENT	0
627096	627079	11090Q	PARTICIPANT	\N	PRESENT	0
627097	627079	11012A	PARTICIPANT	\N	PRESENT	0
627098	627079	04033B	PARTICIPANT	\N	PRESENT	0
627101	627100	18083K	PARTICIPANT	\N	PRESENT	0
627102	627100	19619A	PARTICIPANT	\N	PRESENT	0
627103	626862	11045K	PARTICIPANT	\N	PRESENT	0
627104	626862	14038Y	PARTICIPANT	\N	PRESENT	0
627105	626862	19593H	PARTICIPANT	\N	PRESENT	0
627106	626862	20102Q	PARTICIPANT	\N	PRESENT	0
627107	626862	19387D	PARTICIPANT	\N	PRESENT	0
627108	626862	20132W	PARTICIPANT	\N	PRESENT	0
627109	626862	19621T	PARTICIPANT	\N	PRESENT	0
627110	626862	20128B	PARTICIPANT	\N	PRESENT	0
627111	626862	19611R	PARTICIPANT	\N	PRESENT	0
627112	626862	19826F	PARTICIPANT	\N	PRESENT	0
627113	626862	20264J	PARTICIPANT	\N	PRESENT	0
627114	626862	19533U	PARTICIPANT	\N	PRESENT	0
627115	626862	20068G	PARTICIPANT	\N	PRESENT	0
627116	626862	14105F	PARTICIPANT	\N	PRESENT	0
627117	626862	20134Y	PARTICIPANT	\N	PRESENT	0
627118	626862	19758L	PARTICIPANT	\N	PRESENT	0
627119	626862	14229S	PARTICIPANT	\N	PRESENT	0
627120	626862	19563B	PARTICIPANT	\N	PRESENT	0
627121	626862	17589D	PARTICIPANT	\N	PRESENT	0
627122	626862	11033F	PARTICIPANT	\N	PRESENT	0
627123	626862	11083R	PARTICIPANT	\N	PRESENT	0
627124	626862	19782L	PARTICIPANT	\N	PRESENT	0
627125	626862	20052X	PARTICIPANT	\N	PRESENT	0
627126	626862	19741B	PARTICIPANT	\N	PRESENT	0
627127	626862	14193X	PARTICIPANT	\N	PRESENT	0
627128	626862	20032T	PARTICIPANT	\N	PRESENT	0
627129	626862	18083K	PARTICIPANT	\N	PRESENT	0
627130	626862	19507S	PARTICIPANT	\N	PRESENT	0
622113	622111	20174H	PARTICIPANT	\N	PRESENT	0
622114	622111	01057W	PARTICIPANT	\N	PRESENT	0
622115	622111	04045F	PARTICIPANT	\N	PRESENT	0
622116	622111	19798U	PARTICIPANT	\N	PRESENT	0
622117	622111	01024M	PARTICIPANT	\N	PRESENT	0
622118	622111	19820Y	PARTICIPANT	\N	PRESENT	0
622119	622111	20132W	PARTICIPANT	\N	PRESENT	0
622120	622111	19575F	PARTICIPANT	\N	PRESENT	0
622121	622111	20128B	PARTICIPANT	\N	PRESENT	0
622147	622111	19515S	PARTICIPANT	\N	PRESENT	0
622148	622111	19549D	PARTICIPANT	\N	PRESENT	0
622149	622111	14105F	PARTICIPANT	\N	PRESENT	0
622150	622111	11101A	PARTICIPANT	\N	PRESENT	0
622151	622111	01025N	PARTICIPANT	\N	PRESENT	0
622152	622111	20126Y	PARTICIPANT	\N	PRESENT	0
622153	622111	19723Y	PARTICIPANT	\N	PRESENT	0
622154	622111	08015R	PARTICIPANT	\N	PRESENT	0
622155	622111	11097X	PARTICIPANT	\N	PRESENT	0
622432	621178	14147R	PARTICIPANT	\N	PRESENT	0
622433	621178	19691J	PARTICIPANT	\N	PRESENT	0
622434	621178	19723Y	PARTICIPANT	\N	PRESENT	0
622526	620742	19383Y	PARTICIPANT	\N	PRESENT	0
622527	620742	19768N	PARTICIPANT	\N	PRESENT	0
622528	620742	20088L	PARTICIPANT	\N	PRESENT	1
622529	620742	19515S	PARTICIPANT	\N	PRESENT	0
622530	620742	19782L	PARTICIPANT	\N	PRESENT	1
622531	620742	20092G	PARTICIPANT	\N	PRESENT	0
622532	620742	11077T	PARTICIPANT	\N	PRESENT	1
622533	620742	01043Q	PARTICIPANT	\N	PRESENT	0
622534	620742	14357A	PARTICIPANT	\N	PRESENT	1
622535	620742	20078J	PARTICIPANT	\N	PRESENT	0
622536	620742	19441R	PARTICIPANT	\N	PRESENT	0
622537	620742	20082E	PARTICIPANT	\N	PRESENT	0
622538	620742	20094J	PARTICIPANT	\N	PRESENT	0
622539	620742	04045F	PARTICIPANT	\N	PRESENT	0
622540	620742	19866P	PARTICIPANT	\N	PRESENT	0
622541	620742	19631V	PARTICIPANT	\N	PRESENT	0
622542	620742	20104S	PARTICIPANT	\N	PRESENT	0
622543	620742	19705W	PARTICIPANT	\N	PRESENT	1
622544	620742	19707Y	PARTICIPANT	\N	PRESENT	1
622545	620742	08015R	PARTICIPANT	\N	PRESENT	0
622546	620742	19575F	PARTICIPANT	\N	PRESENT	0
622547	620742	19369B	PARTICIPANT	\N	PRESENT	1
622548	620742	19511N	PARTICIPANT	\N	PRESENT	0
622549	620742	08028W	PARTICIPANT	\N	PRESENT	1
622550	620742	19563B	PARTICIPANT	\N	PRESENT	1
622551	620742	14329V	PARTICIPANT	\N	PRESENT	1
622552	620742	14038Y	PARTICIPANT	\N	PRESENT	0
622553	620742	19467C	PARTICIPANT	\N	PRESENT	0
622554	620742	14187A	PARTICIPANT	\N	PRESENT	0
622555	620742	20144B	PARTICIPANT	\N	PRESENT	0
622556	620742	19695N	PARTICIPANT	\N	PRESENT	0
622557	620742	11090Q	PRESIDENT	0	PRESENT	0
622558	620742	14033T	PARTICIPANT	\N	PRESENT	0
622559	620742	01025N	PARTICIPANT	\N	PRESENT	0
622560	620742	20054A	PARTICIPANT	\N	PRESENT	0
622561	620742	20174H	PARTICIPANT	\N	PRESENT	0
622562	620742	14205J	PARTICIPANT	\N	PRESENT	0
622563	620742	20062A	PARTICIPANT	\N	PRESENT	0
622564	620742	14251Q	PARTICIPANT	\N	PRESENT	1
622565	620742	19507S	PARTICIPANT	\N	PRESENT	0
622566	620742	20286Q	PARTICIPANT	\N	PRESENT	0
622567	620742	19747H	PARTICIPANT	\N	PRESENT	0
622568	620742	14207L	PARTICIPANT	\N	PRESENT	0
622569	620742	14257W	PARTICIPANT	\N	PRESENT	0
622611	618873	19333N	PARTICIPANT	\N	PRESENT	0
622612	618873	20032T	PARTICIPANT	\N	PRESENT	0
622613	618873	19701S	PARTICIPANT	\N	PRESENT	0
622614	618873	20136B	PARTICIPANT	\N	PRESENT	0
622615	618873	14031R	PARTICIPANT	\N	PRESENT	0
622616	618873	20038A	PARTICIPANT	\N	PRESENT	0
622617	618873	19549D	PARTICIPANT	\N	PRESENT	0
622618	618873	19387D	PARTICIPANT	\N	PRESENT	0
622619	618873	14219Q	PARTICIPANT	\N	PRESENT	0
622620	618873	19826F	PARTICIPANT	\N	PRESENT	0
622621	618873	20102Q	PARTICIPANT	\N	PRESENT	0
622622	618873	19599P	PARTICIPANT	\N	PRESENT	0
622623	618873	17229F	PARTICIPANT	\N	PRESENT	0
622624	618873	18083K	PARTICIPANT	\N	PRESENT	0
622625	618873	19551W	PARTICIPANT	\N	PRESENT	0
622626	618873	05012A	PARTICIPANT	\N	PRESENT	0
622627	618873	20068G	PARTICIPANT	\N	PRESENT	0
622628	618873	20118Y	PARTICIPANT	\N	PRESENT	0
622629	618873	19503N	PARTICIPANT	\N	PRESENT	0
622630	618873	19745F	PARTICIPANT	\N	PRESENT	0
622631	618873	19685L	PARTICIPANT	\N	PRESENT	0
622632	618873	20024T	PARTICIPANT	\N	PRESENT	0
622633	618873	17637T	PARTICIPANT	\N	PRESENT	0
622639	620743	19383Y	PARTICIPANT	\N	PRESENT	0
622640	620743	19768N	PARTICIPANT	\N	PRESENT	0
622641	620743	20088L	PARTICIPANT	\N	PRESENT	1
622642	620743	19515S	PARTICIPANT	\N	PRESENT	0
622643	620743	19782L	PARTICIPANT	\N	PRESENT	1
622644	620743	20092G	PARTICIPANT	\N	PRESENT	0
622645	620743	11077T	PARTICIPANT	\N	PRESENT	1
622646	620743	01043Q	PARTICIPANT	\N	PRESENT	0
622647	620743	14357A	PARTICIPANT	\N	PRESENT	1
622648	620743	20078J	PARTICIPANT	\N	PRESENT	0
622649	620743	19441R	PARTICIPANT	\N	PRESENT	0
622650	620743	20082E	PARTICIPANT	\N	PRESENT	0
622651	620743	20094J	PARTICIPANT	\N	PRESENT	0
622652	620743	04045F	PARTICIPANT	\N	PRESENT	0
622653	620743	19866P	PARTICIPANT	\N	PRESENT	0
622654	620743	19631V	PARTICIPANT	\N	PRESENT	0
622655	620743	20104S	PARTICIPANT	\N	PRESENT	0
622656	620743	19705W	PARTICIPANT	\N	PRESENT	1
622657	620743	19707Y	PARTICIPANT	\N	PRESENT	1
622658	620743	08015R	PARTICIPANT	\N	PRESENT	0
622659	620743	19575F	PARTICIPANT	\N	PRESENT	0
622660	620743	19369B	PARTICIPANT	\N	PRESENT	1
622661	620743	19511N	PARTICIPANT	\N	PRESENT	0
622662	620743	08028W	PARTICIPANT	\N	PRESENT	1
622663	620743	19563B	PARTICIPANT	\N	PRESENT	1
622664	620743	14329V	PARTICIPANT	\N	PRESENT	1
622665	620743	14038Y	PARTICIPANT	\N	PRESENT	0
622666	620743	19467C	PARTICIPANT	\N	PRESENT	0
622667	620743	14187A	PARTICIPANT	\N	PRESENT	0
622668	620743	20144B	PARTICIPANT	\N	PRESENT	0
622669	620743	19695N	PARTICIPANT	\N	PRESENT	0
622670	620743	11090Q	PRESIDENT	0	PRESENT	0
622671	620743	14033T	PARTICIPANT	\N	PRESENT	0
622672	620743	01025N	PARTICIPANT	\N	PRESENT	0
622673	620743	20054A	PARTICIPANT	\N	PRESENT	0
622674	620743	20174H	PARTICIPANT	\N	PRESENT	0
622675	620743	14205J	PARTICIPANT	\N	PRESENT	0
622676	620743	20062A	PARTICIPANT	\N	PRESENT	0
622677	620743	14251Q	PARTICIPANT	\N	PRESENT	1
622678	620743	19507S	PARTICIPANT	\N	PRESENT	0
622679	620743	20286Q	PARTICIPANT	\N	PRESENT	0
622680	620743	19747H	PARTICIPANT	\N	PRESENT	0
622681	620743	14207L	PARTICIPANT	\N	PRESENT	0
622682	620743	14257W	PARTICIPANT	\N	PRESENT	0
622683	621391	19629C	PARTICIPANT	\N	PRESENT	0
622684	621391	04070G	PARTICIPANT	\N	PRESENT	0
622685	621391	20068G	PARTICIPANT	\N	PRESENT	0
622686	621391	14105F	PARTICIPANT	\N	PRESENT	0
622687	621391	20152B	PARTICIPANT	\N	PRESENT	0
622688	621391	14231L	PARTICIPANT	\N	PRESENT	0
622689	621391	20180F	PARTICIPANT	\N	PRESENT	0
622690	621391	14215L	PARTICIPANT	\N	PRESENT	0
622691	621391	20062A	PARTICIPANT	\N	PRESENT	0
622692	621391	20090E	PARTICIPANT	\N	PRESENT	0
622693	621391	14223L	PARTICIPANT	\N	PRESENT	0
622694	621391	17229F	PARTICIPANT	\N	PRESENT	0
622695	621391	14267Y	PARTICIPANT	\N	PRESENT	0
622696	621391	20072C	PARTICIPANT	\N	PRESENT	0
622697	621391	14221J	PARTICIPANT	\N	PRESENT	0
622698	621391	14111D	PARTICIPANT	\N	PRESENT	0
622699	621391	01025N	PARTICIPANT	\N	PRESENT	0
622700	621391	20138D	PARTICIPANT	\N	PRESENT	0
622701	621391	19711U	PARTICIPANT	\N	PRESENT	0
622702	621391	14059S	PARTICIPANT	\N	PRESENT	0
622703	621391	19782L	PARTICIPANT	\N	PRESENT	0
622704	621391	14107H	PARTICIPANT	\N	PRESENT	0
622705	621391	19866P	PARTICIPANT	\N	PRESENT	0
622706	621391	19715Y	PARTICIPANT	\N	PRESENT	0
622707	621391	20082E	PARTICIPANT	\N	PRESENT	0
622708	621391	19725B	PARTICIPANT	\N	PRESENT	0
622709	621391	12028B	PARTICIPANT	\N	PRESENT	0
622710	621391	19333N	PARTICIPANT	\N	PRESENT	0
599254	599208	19703U	PARTICIPANT	\N	PRESENT	0
599256	599210	19703U	PARTICIPANT	\N	PRESENT	0
599258	599210	18193Q	PARTICIPANT	\N	PRESENT	0
599259	599210	11067R	PARTICIPANT	\N	PRESENT	0
599260	599246	19703U	PARTICIPANT	\N	PRESENT	0
599261	599246	18193Q	PARTICIPANT	\N	PRESENT	0
599277	599246	11067R	PARTICIPANT	\N	PRESENT	0
599743	599252	19703U	PARTICIPANT	\N	PRESENT	0
599753	599749	20066E	PARTICIPANT	\N	PRESENT	0
600377	600376	12028B	PARTICIPANT	\N	PRESENT	0
600378	600376	11064N	PARTICIPANT	\N	PRESENT	0
601226	600815	19697Q	PARTICIPANT	\N	PRESENT	0
601227	600815	11067R	PARTICIPANT	\N	PRESENT	0
601283	601096	99004R	PARTICIPANT	\N	PRESENT	0
601229	600815	19798U	PARTICIPANT	\N	PRESENT	0
601230	600815	11097X	PARTICIPANT	\N	PRESENT	0
601231	600815	18193Q	PARTICIPANT	\N	PRESENT	0
601284	601096	20132W	PARTICIPANT	\N	PRESENT	0
601233	600815	11031D	PARTICIPANT	\N	PRESENT	0
601285	601096	19798U	PARTICIPANT	\N	PRESENT	0
601287	601096	14217N	PARTICIPANT	\N	PRESENT	0
601288	601096	19741B	PARTICIPANT	\N	PRESENT	0
601237	600815	14042U	PARTICIPANT	\N	PRESENT	0
601289	601096	14042U	PARTICIPANT	\N	PRESENT	0
601239	600815	14213J	PARTICIPANT	\N	PRESENT	0
601240	600815	10006L	PARTICIPANT	\N	PRESENT	0
601241	600815	20130U	PARTICIPANT	\N	PRESENT	0
601242	600815	01034P	PARTICIPANT	\N	PRESENT	0
601243	600815	04057K	PARTICIPANT	\N	EXCUSE	0
601290	601096	14213J	PARTICIPANT	\N	PRESENT	0
601291	601096	10006L	PARTICIPANT	\N	PRESENT	0
601246	600815	19663E	PARTICIPANT	\N	PRESENT	0
601247	600815	19691J	PARTICIPANT	\N	PRESENT	0
601294	601096	20044X	PARTICIPANT	\N	PRESENT	0
601295	601096	14026U	PARTICIPANT	\N	PRESENT	0
601296	601096	11097X	PARTICIPANT	\N	PRESENT	0
601297	601096	11067R	PARTICIPANT	\N	PRESENT	0
601252	600815	14071N	PARTICIPANT	\N	PRESENT	0
601298	601096	11031D	PARTICIPANT	\N	PRESENT	0
601254	600815	19760E	PARTICIPANT	\N	PRESENT	0
601255	600815	04092N	PARTICIPANT	0	PRESENT	0
601256	600815	17965H	PARTICIPANT	\N	PRESENT	0
601257	600815	20148F	PARTICIPANT	\N	PRESENT	0
601258	600815	14026U	PARTICIPANT	\N	PRESENT	0
601259	600815	19723Y	PARTICIPANT	\N	PRESENT	0
601260	600815	14195A	PARTICIPANT	\N	PRESENT	0
601261	600815	14217N	PARTICIPANT	\N	PRESENT	0
601262	600815	19683J	PARTICIPANT	\N	PRESENT	0
601263	600815	04043D	PARTICIPANT	\N	PRESENT	0
601264	600815	19301E	PARTICIPANT	\N	PRESENT	0
601299	601096	17965H	PARTICIPANT	\N	PRESENT	0
601300	601096	19683J	PARTICIPANT	\N	PRESENT	0
601301	601096	18193Q	PARTICIPANT	\N	PRESENT	0
601302	601096	20018V	PARTICIPANT	\N	PRESENT	0
601303	601096	19651A	PARTICIPANT	\N	PRESENT	0
601304	601096	95063L	PARTICIPANT	\N	PRESENT	0
601305	601096	14195A	PARTICIPANT	\N	PRESENT	0
601306	601096	20130U	PARTICIPANT	\N	PRESENT	0
601321	601096	19679N	PARTICIPANT	\N	PRESENT	0
601308	601096	19569H	PARTICIPANT	\N	PRESENT	0
601309	601096	19415P	PARTICIPANT	\N	PRESENT	0
601310	601096	14071N	PARTICIPANT	\N	PRESENT	0
601312	601096	04092N	PARTICIPANT	\N	PRESENT	0
601313	601096	20126Y	PARTICIPANT	\N	PRESENT	0
601314	601096	14281W	PARTICIPANT	\N	PRESENT	0
601315	601096	19591F	PARTICIPANT	\N	PRESENT	0
601316	601096	19697Q	PARTICIPANT	\N	PRESENT	0
601317	601096	01034P	PARTICIPANT	\N	PRESENT	0
601323	601096	19687N	PARTICIPANT	\N	PRESENT	0
601322	601096	19760E	PARTICIPANT	\N	PRESENT	0
601324	601096	17779H	PARTICIPANT	\N	PRESENT	0
601325	601096	07033P	PARTICIPANT	\N	PRESENT	0
601326	601096	04033B	PARTICIPANT	\N	PRESENT	0
601327	601096	04043D	PARTICIPANT	\N	PRESENT	0
601328	601096	14229S	PARTICIPANT	\N	PRESENT	0
601329	601096	14021P	PARTICIPANT	\N	PRESENT	0
601330	601096	19295A	PARTICIPANT	\N	PRESENT	0
601331	601096	04085P	PARTICIPANT	\N	PRESENT	0
601332	601096	19715Y	PARTICIPANT	\N	PRESENT	0
601333	601096	19369B	PARTICIPANT	\N	PRESENT	0
601334	601096	19723Y	PARTICIPANT	\N	PRESENT	0
601336	601096	19553Y	PARTICIPANT	\N	PRESENT	0
601340	601096	19301E	PARTICIPANT	\N	PRESENT	0
601341	601096	08045X	PARTICIPANT	\N	PRESENT	0
601342	601096	19691J	PARTICIPANT	\N	PRESENT	0
601343	601096	19367Y	PARTICIPANT	\N	PRESENT	0
602553	601197	14223L	PARTICIPANT	\N	PRESENT	0
602562	601486	05008E	PARTICIPANT	\N	EXCUSE	0
602563	601489	05008E	PARTICIPANT	\N	EXCUSE	0
603090	603089	19651A	PARTICIPANT	\N	PRESENT	0
603093	600692	14109K	PARTICIPANT	\N	PRESENT	0
603094	600692	19573D	PARTICIPANT	\N	PRESENT	0
603095	600692	19527W	PARTICIPANT	\N	PRESENT	0
603096	600692	11104D	PARTICIPANT	\N	PRESENT	0
603097	600692	20112S	PARTICIPANT	\N	PRESENT	0
603098	600692	19593H	PARTICIPANT	\N	PRESENT	0
603099	600692	20142Y	PARTICIPANT	\N	PRESENT	0
603100	600692	20134Y	PARTICIPANT	\N	PRESENT	0
603101	600692	20132W	PARTICIPANT	\N	PRESENT	0
603102	600692	04059M	PARTICIPANT	\N	PRESENT	0
603103	600692	14229S	PARTICIPANT	\N	PRESENT	0
603104	600692	19693L	PARTICIPANT	\N	PRESENT	0
603105	600692	19611R	PRESIDENT	0	PRESENT	0
603106	600692	92040Q	PARTICIPANT	\N	PRESENT	0
603107	600692	20180F	PARTICIPANT	\N	PRESENT	0
603108	600692	20056C	PARTICIPANT	\N	PRESENT	0
603109	600692	20026V	PARTICIPANT	\N	PRESENT	0
603110	600692	19399H	PARTICIPANT	\N	PRESENT	0
603111	600692	19735D	PARTICIPANT	\N	PRESENT	0
603112	600692	19699S	PARTICIPANT	\N	PRESENT	0
603113	600692	19643A	PARTICIPANT	\N	PRESENT	0
603114	600692	19651A	PARTICIPANT	\N	PRESENT	0
603115	600692	19533U	PARTICIPANT	\N	PRESENT	0
603116	600692	20048C	PARTICIPANT	\N	PRESENT	0
603117	600692	14030Q	PARTICIPANT	\N	PRESENT	0
603118	600692	20084G	PARTICIPANT	\N	PRESENT	0
603120	600692	11109J	PARTICIPANT	\N	EXCUSE	0
605763	605761	19575F	PARTICIPANT	\N	PRESENT	0
605765	605761	20038A	PARTICIPANT	\N	PRESENT	0
605766	605761	08012N	PARTICIPANT	\N	PRESENT	0
605767	605761	04043D	PARTICIPANT	\N	PRESENT	0
605836	602939	19367Y	PARTICIPANT	\N	EXCUSE	0
607326	606854	14251Q	PARTICIPANT	\N	EXCUSE	0
607327	606854	19705W	PARTICIPANT	\N	EXCUSE	0
608707	608706	19647E	PARTICIPANT	\N	PRESENT	0
608708	608706	14249W	PARTICIPANT	\N	PRESENT	0
608721	608720	19749K	PARTICIPANT	\N	PRESENT	0
608723	608722	19649G	PARTICIPANT	\N	PRESENT	0
608724	608722	19749K	PARTICIPANT	\N	PRESENT	0
608726	608725	19749K	PARTICIPANT	\N	PRESENT	0
609419	606464	19820Y	PARTICIPANT	\N	PRESENT	0
609420	606464	19637C	PARTICIPANT	\N	PRESENT	0
609421	606464	19745F	PARTICIPANT	\N	PRESENT	0
609422	606464	20024T	PARTICIPANT	\N	PRESENT	0
609423	606464	11065P	PARTICIPANT	\N	PRESENT	0
609424	606464	20038A	PARTICIPANT	\N	EXCUSE	0
609425	606464	19599P	PARTICIPANT	\N	EXCUSE	0
609426	606464	19549D	PARTICIPANT	\N	PRESENT	0
609427	606464	20046A	PARTICIPANT	\N	PRESENT	0
609428	606464	20100N	PARTICIPANT	\N	PRESENT	0
609429	606464	19551W	PARTICIPANT	\N	PRESENT	0
609430	608661	19527W	PARTICIPANT	\N	PRESENT	0
609431	608661	14123H	PARTICIPANT	\N	PRESENT	0
609432	608661	19621T	PARTICIPANT	\N	PRESENT	0
609433	606464	19333N	PARTICIPANT	\N	PRESENT	0
609434	606464	19701S	PARTICIPANT	\N	PRESENT	0
609435	606464	20120S	PARTICIPANT	\N	PRESENT	0
609436	606464	20068G	PARTICIPANT	\N	PRESENT	0
609437	606464	20106U	PARTICIPANT	\N	PRESENT	0
609438	606464	17229F	PARTICIPANT	\N	PRESENT	0
609439	606464	20096L	PARTICIPANT	\N	PRESENT	0
609440	606464	19619A	PARTICIPANT	\N	PRESENT	0
609441	606464	14237S	PARTICIPANT	\N	PRESENT	0
609443	608647	14053L	PARTICIPANT	\N	PRESENT	0
609444	608647	19581D	PARTICIPANT	\N	PRESENT	0
609445	608647	95063L	PARTICIPANT	\N	PRESENT	0
610475	608662	19717B	PARTICIPANT	\N	PRESENT	1
610476	608662	19631V	PARTICIPANT	\N	PRESENT	1
610477	608662	19577H	PARTICIPANT	\N	PRESENT	1
619831	618373	19631V	PARTICIPANT	\N	PRESENT	1
619832	618373	20094J	PARTICIPANT	\N	EXCUSE	0
619833	618373	19782L	PARTICIPANT	\N	EXCUSE	0
619834	618373	01043Q	PARTICIPANT	\N	EXCUSE	0
619835	618373	11077T	PARTICIPANT	\N	EXCUSE	0
619836	618373	19369B	PARTICIPANT	\N	EXCUSE	0
619837	618373	04045F	PARTICIPANT	\N	PRESENT	1
619838	618373	19515S	PARTICIPANT	\N	PRESENT	0
619852	618361	11033F	PARTICIPANT	\N	PRESENT	1
619855	618361	19629C	PARTICIPANT	\N	PRESENT	1
619857	618361	19725B	PARTICIPANT	\N	PRESENT	1
619859	618361	19729F	PARTICIPANT	\N	PRESENT	1
619861	618361	14001X	PARTICIPANT	\N	PRESENT	1
619863	618361	14107H	PARTICIPANT	\N	PRESENT	1
619878	618361	20022R	PARTICIPANT	\N	EXCUSE	0
619903	610254	04045F	PARTICIPANT	\N	PRESENT	1
619904	610254	19798U	PARTICIPANT	\N	PRESENT	0
619906	619905	14071N	PARTICIPANT	\N	PRESENT	0
619934	610254	19533U	PARTICIPANT	\N	PRESENT	0
619885	618364	19545Y	PARTICIPANT	\N	PRESENT	0
619936	610254	14207L	PARTICIPANT	\N	PRESENT	0
619942	618360	20022R	PARTICIPANT	\N	EXCUSE	0
619947	618090	19719D	PARTICIPANT	\N	PRESENT	0
619948	618090	05008E	PARTICIPANT	\N	PRESENT	0
619902	610254	20124W	PARTICIPANT	\N	PRESENT	1
619949	618090	14217N	PARTICIPANT	\N	PRESENT	0
619950	618090	14073Q	PARTICIPANT	\N	PRESENT	0
619951	618090	20138D	PARTICIPANT	\N	PRESENT	0
619952	618090	19399H	PARTICIPANT	\N	PRESENT	0
619953	618090	19798U	PARTICIPANT	\N	PRESENT	0
619954	618090	19565D	PARTICIPANT	\N	PRESENT	0
619955	618090	19563B	PARTICIPANT	\N	PRESENT	0
619956	618090	11033F	PARTICIPANT	\N	PRESENT	0
619957	618090	20088L	PARTICIPANT	\N	PRESENT	0
619958	618090	14111D	PARTICIPANT	\N	PRESENT	0
619959	618090	14275Y	PARTICIPANT	\N	PRESENT	0
619960	618090	14267Y	PARTICIPANT	\N	PRESENT	0
619961	618090	19387D	PARTICIPANT	\N	PRESENT	0
619962	618090	11012A	PARTICIPANT	\N	PRESENT	0
619963	618090	20030R	PARTICIPANT	\N	PRESENT	0
619964	618090	20084G	PARTICIPANT	\N	PRESENT	0
619965	618090	11067R	PARTICIPANT	\N	PRESENT	0
619966	618090	08045X	PARTICIPANT	\N	PRESENT	0
619967	618090	19725B	PARTICIPANT	\N	PRESENT	0
619968	618090	20072C	PARTICIPANT	\N	PRESENT	0
619969	618090	20060X	PARTICIPANT	\N	PRESENT	0
619970	618090	14151M	PARTICIPANT	\N	PRESENT	0
619971	618090	19820Y	PARTICIPANT	\N	PRESENT	0
619972	618090	19503N	PARTICIPANT	\N	PRESENT	0
619973	618090	11053K	PARTICIPANT	\N	PRESENT	0
619974	618090	19479G	PARTICIPANT	\N	PRESENT	0
619975	618090	19543W	PARTICIPANT	\N	PRESENT	0
619976	618090	20106U	PARTICIPANT	\N	PRESENT	0
619977	618090	20128B	PARTICIPANT	\N	PRESENT	0
619978	618090	20130U	PARTICIPANT	\N	PRESENT	0
619979	618090	17229F	PARTICIPANT	\N	PRESENT	0
619980	618090	11040E	PARTICIPANT	\N	PRESENT	0
619981	618090	19758L	PARTICIPANT	\N	PRESENT	0
619982	618090	11056N	PARTICIPANT	\N	PRESENT	0
619983	618090	19687N	PARTICIPANT	\N	PRESENT	0
619984	618090	04045F	PARTICIPANT	\N	PRESENT	0
619985	618090	19739H	PARTICIPANT	\N	PRESENT	0
619986	618090	20018V	PARTICIPANT	\N	PRESENT	0
619987	618090	20286Q	PARTICIPANT	\N	PRESENT	0
619988	618090	19583F	PARTICIPANT	\N	PRESENT	0
619989	618090	04057K	PARTICIPANT	\N	PRESENT	0
619990	618090	19782L	PARTICIPANT	\N	PRESENT	0
619991	618090	08061X	PARTICIPANT	\N	PRESENT	0
619992	618090	19697Q	PARTICIPANT	\N	PRESENT	0
619993	618360	14001X	PARTICIPANT	\N	PRESENT	1
619994	618090	14211G	PARTICIPANT	\N	PRESENT	0
619995	618090	17637T	PARTICIPANT	\N	PRESENT	0
619996	618090	19711U	PARTICIPANT	\N	PRESENT	0
619997	618090	04008A	PARTICIPANT	\N	PRESENT	0
619998	618090	19631V	PARTICIPANT	\N	PRESENT	0
619999	618090	20114U	PARTICIPANT	\N	PRESENT	0
620000	618090	20080C	PARTICIPANT	\N	PRESENT	0
620001	618090	19693L	PARTICIPANT	\N	PRESENT	0
620002	618090	14097Y	PARTICIPANT	\N	PRESENT	0
620003	618090	14021P	PARTICIPANT	\N	PRESENT	0
620004	618090	12028B	PARTICIPANT	\N	PRESENT	0
620005	618090	14026U	PARTICIPANT	\N	PRESENT	0
620006	618090	20028X	PARTICIPANT	\N	PRESENT	0
620007	618090	08010L	PARTICIPANT	\N	PRESENT	0
620008	618090	04047H	PARTICIPANT	\N	PRESENT	0
620009	618090	99004R	PARTICIPANT	\N	PRESENT	0
620010	618090	20264J	PARTICIPANT	\N	PRESENT	0
620011	618090	01058X	PARTICIPANT	\N	PRESENT	0
620012	618090	19679N	PARTICIPANT	\N	PRESENT	0
620013	618090	19683J	PARTICIPANT	\N	PRESENT	0
620014	618090	20076G	PARTICIPANT	\N	PRESENT	0
620015	618090	19649G	PARTICIPANT	\N	PRESENT	0
620016	618090	20074E	PARTICIPANT	\N	PRESENT	0
620017	618090	20078J	PARTICIPANT	\N	PRESENT	0
620018	618090	14001X	PARTICIPANT	\N	PRESENT	0
620019	618090	18083K	PARTICIPANT	\N	PRESENT	0
620020	618090	14257W	PARTICIPANT	\N	PRESENT	0
620021	618090	14123H	PARTICIPANT	\N	PRESENT	0
620022	618090	20082E	PARTICIPANT	\N	PRESENT	0
620023	618090	01028R	PARTICIPANT	\N	PRESENT	0
620024	618090	04092N	PARTICIPANT	\N	PRESENT	0
620025	618090	19413M	PARTICIPANT	\N	PRESENT	0
620026	618090	11097X	PARTICIPANT	\N	PRESENT	0
620027	618090	19527W	PARTICIPANT	\N	PRESENT	0
620028	618090	19647E	PARTICIPANT	\N	PRESENT	0
620029	618090	04085P	PARTICIPANT	\N	PRESENT	0
620030	618090	20112S	PARTICIPANT	\N	PRESENT	0
620031	618090	11031D	PARTICIPANT	\N	PRESENT	0
620032	618090	19695N	PARTICIPANT	\N	PRESENT	0
620033	618090	14187A	PARTICIPANT	\N	PRESENT	0
620034	618090	12041X	PARTICIPANT	\N	PRESENT	0
620035	618090	14133K	PARTICIPANT	\N	PRESENT	0
620036	618090	20022R	PARTICIPANT	\N	PRESENT	0
620037	618090	04033B	PARTICIPANT	\N	PRESENT	0
620038	618090	14223L	PARTICIPANT	\N	PRESENT	0
620039	618090	20064C	PARTICIPANT	\N	PRESENT	0
620040	618090	01048V	PARTICIPANT	\N	PRESENT	0
620041	618090	20046A	PARTICIPANT	\N	PRESENT	0
620042	618090	10015M	PARTICIPANT	\N	PRESENT	0
620043	618090	19760E	PARTICIPANT	\N	PRESENT	0
620044	618090	19515S	PARTICIPANT	\N	PRESENT	0
620045	618090	01057W	PARTICIPANT	\N	PRESENT	0
620046	618090	20134Y	PARTICIPANT	\N	PRESENT	0
620047	618090	20100N	PARTICIPANT	\N	PRESENT	0
620048	618090	05012A	PARTICIPANT	\N	PRESENT	0
620049	618090	11090Q	PARTICIPANT	\N	PRESENT	0
620050	618090	19347U	PARTICIPANT	\N	PRESENT	0
620051	618090	19701S	PARTICIPANT	\N	PRESENT	0
620052	618090	19421M	PARTICIPANT	\N	PRESENT	0
620053	618090	20036X	PARTICIPANT	\N	PRESENT	0
620054	618090	19651A	PARTICIPANT	\N	PRESENT	0
620055	618090	10006L	PARTICIPANT	\N	PRESENT	0
620056	618090	19533U	PARTICIPANT	\N	PRESENT	0
620057	618090	20118Y	PARTICIPANT	\N	PRESENT	0
620058	618090	14331P	PARTICIPANT	\N	PRESENT	0
620059	618090	11083R	PARTICIPANT	\N	PRESENT	0
620060	618090	20032T	PARTICIPANT	\N	PRESENT	0
620061	618090	11072N	PARTICIPANT	\N	PRESENT	0
620062	618090	20136B	PARTICIPANT	\N	PRESENT	0
620063	618090	08073C	PARTICIPANT	\N	PRESENT	0
620064	618090	14253S	PARTICIPANT	\N	PRESENT	0
620065	618090	95063L	PARTICIPANT	\N	PRESENT	0
620066	618090	11115U	PARTICIPANT	\N	PRESENT	0
620067	618090	19667J	PARTICIPANT	\N	PRESENT	0
620068	618090	14031R	PARTICIPANT	\N	PRESENT	0
620069	618090	19673G	PARTICIPANT	\N	PRESENT	0
620070	618090	20038A	PARTICIPANT	\N	PRESENT	0
620071	618090	14207L	PARTICIPANT	\N	PRESENT	0
620072	618090	20116W	PARTICIPANT	\N	PRESENT	0
620073	618090	19447X	PARTICIPANT	\N	PRESENT	0
620074	618090	20132W	PARTICIPANT	\N	PRESENT	0
620075	618090	20026V	PARTICIPANT	\N	PRESENT	0
620076	618090	20180F	PARTICIPANT	\N	PRESENT	0
620077	618090	19545Y	PARTICIPANT	\N	PRESENT	0
620078	618090	14195A	PARTICIPANT	\N	PRESENT	0
620080	618090	11065P	PARTICIPANT	\N	PRESENT	0
620081	618090	20140W	PARTICIPANT	\N	PRESENT	0
620082	618090	14251Q	PARTICIPANT	\N	PRESENT	0
620083	618090	20172F	PARTICIPANT	\N	PRESENT	0
620084	618090	14147R	PARTICIPANT	\N	PRESENT	0
606057	603133	11110B	PARTICIPANT	\N	PRESENT	0
606058	603133	04071H	PARTICIPANT	\N	PRESENT	0
606059	603133	08011M	PARTICIPANT	\N	PRESENT	0
606060	603133	19545Y	PARTICIPANT	\N	PRESENT	0
606231	603152	18083K	PARTICIPANT	\N	PRESENT	0
606232	603152	12016W	PARTICIPANT	\N	PRESENT	0
607446	607445	14133K	PARTICIPANT	\N	PRESENT	0
607447	607445	10006L	PARTICIPANT	\N	PRESENT	0
607448	607445	14097Y	PARTICIPANT	\N	PRESENT	0
607449	607445	14147R	PARTICIPANT	\N	PRESENT	0
618522	618357	19543W	PARTICIPANT	\N	PRESENT	0
618523	618357	20110Q	PARTICIPANT	\N	PRESENT	1
618524	618357	14069U	PARTICIPANT	\N	PRESENT	1
618525	618357	20114U	PARTICIPANT	\N	PRESENT	1
618526	618357	11056N	PARTICIPANT	\N	PRESENT	1
618527	618357	19725B	PARTICIPANT	\N	PRESENT	1
618528	618357	20128B	PARTICIPANT	\N	PRESENT	1
618529	618357	14147R	PARTICIPANT	\N	PRESENT	1
618530	618357	10015M	PARTICIPANT	\N	PRESENT	1
618531	618357	14107H	PARTICIPANT	\N	PRESENT	1
618532	618357	19717B	PARTICIPANT	\N	PRESENT	1
618533	618357	11103C	PARTICIPANT	\N	PRESENT	1
618534	618357	14195A	PARTICIPANT	\N	PRESENT	1
618535	618357	14281W	PARTICIPANT	\N	PRESENT	1
618536	618357	19553Y	PARTICIPANT	\N	PRESENT	1
618537	618357	19591F	PARTICIPANT	\N	PRESENT	1
618538	618357	14213J	PARTICIPANT	\N	PRESENT	1
618539	618357	20066E	PARTICIPANT	\N	PRESENT	1
618540	618357	18193Q	PARTICIPANT	\N	PRESENT	1
618541	618357	19697Q	PARTICIPANT	\N	PRESENT	1
618542	618357	17779H	PARTICIPANT	\N	PRESENT	0
618543	618357	11067R	PARTICIPANT	\N	PRESENT	1
618544	618357	14223L	PARTICIPANT	\N	PRESENT	1
618545	618357	19713W	PARTICIPANT	\N	PRESENT	1
618546	618357	19301E	PARTICIPANT	\N	PRESENT	1
618547	618357	20266L	PARTICIPANT	\N	PRESENT	1
618678	618677	20024T	PARTICIPANT	\N	PRESENT	0
618679	618677	19685L	PARTICIPANT	\N	PRESENT	0
618682	618681	20024T	PARTICIPANT	\N	PRESENT	0
618683	618681	19685L	PARTICIPANT	\N	PRESENT	0
618686	618685	20140W	PARTICIPANT	\N	PRESENT	0
618807	618358	19543W	PARTICIPANT	\N	PRESENT	1
618808	618358	20110Q	PARTICIPANT	\N	PRESENT	1
618809	618358	14069U	PARTICIPANT	\N	PRESENT	1
618810	618358	19629C	PARTICIPANT	\N	PRESENT	1
618811	618358	11056N	PARTICIPANT	\N	PRESENT	1
618812	618358	19489J	PARTICIPANT	\N	PRESENT	1
618813	618358	19729F	PARTICIPANT	\N	PRESENT	1
618814	618358	14001X	PARTICIPANT	\N	PRESENT	1
618815	618358	14147R	PARTICIPANT	\N	PRESENT	1
618816	618358	10015M	PARTICIPANT	\N	PRESENT	1
618817	618358	14107H	PARTICIPANT	\N	PRESENT	1
618818	618358	19675J	PARTICIPANT	\N	PRESENT	1
623861	621788	19569H	PARTICIPANT	\N	PRESENT	1
623860	621786	19569H	PARTICIPANT	\N	PRESENT	1
627131	626862	20076G	PARTICIPANT	\N	PRESENT	0
627132	626862	20142Y	PARTICIPANT	\N	PRESENT	0
627133	626862	14147R	PARTICIPANT	\N	PRESENT	0
627134	626862	14123H	PARTICIPANT	\N	PRESENT	0
627135	626862	11056N	PARTICIPANT	\N	PRESENT	0
627136	626862	19695N	PARTICIPANT	\N	PRESENT	0
627137	626862	01048V	PARTICIPANT	\N	PRESENT	0
627138	626862	14331P	PARTICIPANT	\N	PRESENT	0
627139	626862	19673G	PARTICIPANT	\N	PRESENT	0
627140	626862	19651A	PARTICIPANT	\N	PRESENT	0
627141	626862	08061X	PARTICIPANT	\N	PRESENT	0
627142	626862	14207L	PARTICIPANT	\N	PRESENT	0
627143	626862	14259Y	PARTICIPANT	\N	PRESENT	0
627144	626862	14033T	PARTICIPANT	\N	PRESENT	0
627145	626862	14042U	PARTICIPANT	\N	PRESENT	0
627146	626862	11040E	PARTICIPANT	\N	PRESENT	0
627147	626862	20098N	PARTICIPANT	\N	PRESENT	0
627148	626862	14133K	PARTICIPANT	\N	PRESENT	0
627149	626862	19760E	PARTICIPANT	\N	PRESENT	0
627150	626862	14021P	PARTICIPANT	\N	PRESENT	0
627151	626862	19503N	PARTICIPANT	\N	PRESENT	0
627152	626862	19629C	PARTICIPANT	\N	PRESENT	0
627153	626862	19671E	PARTICIPANT	\N	PRESENT	0
627154	626862	20048C	PARTICIPANT	\N	PRESENT	0
627155	626862	19349W	PARTICIPANT	\N	PRESENT	0
627156	626862	14237S	PARTICIPANT	\N	PRESENT	0
627158	627157	11056N	PRESIDENT	0	PRESENT	0
627159	627157	14089Y	PARTICIPANT	\N	PRESENT	0
627160	627157	19749K	PARTICIPANT	\N	PRESENT	0
627161	627157	95063L	PARTICIPANT	\N	PRESENT	0
627162	627157	20098N	PARTICIPANT	\N	PRESENT	0
627163	627157	11026G	PARTICIPANT	\N	PRESENT	1
627164	627157	14107H	PARTICIPANT	\N	PRESENT	1
627168	626862	20180F	PARTICIPANT	\N	PRESENT	0
627170	626795	11031D	PARTICIPANT	\N	PRESENT	0
627167	627157	20086J	PARTICIPANT	\N	PRESENT	1
627169	626795	19760E	PARTICIPANT	\N	PRESENT	0
627172	626795	11067R	PARTICIPANT	\N	PRESENT	0
627173	626795	14195A	PARTICIPANT	\N	PRESENT	0
627174	626795	10006L	PARTICIPANT	\N	PRESENT	0
627175	626795	01034P	PARTICIPANT	\N	PRESENT	0
627176	626795	19679N	PARTICIPANT	\N	PRESENT	0
627177	626795	14026U	PARTICIPANT	\N	PRESENT	0
627178	626795	14355X	PARTICIPANT	\N	PRESENT	0
627179	626795	14042U	PARTICIPANT	\N	PRESENT	0
627180	626795	19691J	PARTICIPANT	\N	PRESENT	0
627181	626795	20090E	PARTICIPANT	\N	PRESENT	0
627182	626795	19569H	PARTICIPANT	\N	PRESENT	0
627183	626795	20040T	PARTICIPANT	\N	PRESENT	0
627184	626795	04043D	PARTICIPANT	\N	PRESENT	0
627185	626795	14217N	PARTICIPANT	\N	PRESENT	0
627186	626862	20108W	PARTICIPANT	\N	PRESENT	0
627187	626862	20026V	PARTICIPANT	\N	PRESENT	0
627188	627157	14053L	PARTICIPANT	\N	PRESENT	0
627189	626862	20172F	PARTICIPANT	\N	PRESENT	0
627190	626795	20148F	PARTICIPANT	\N	PRESENT	0
627191	626795	19703U	PARTICIPANT	\N	PRESENT	0
627192	626862	19549D	PARTICIPANT	\N	PRESENT	0
627193	626862	14069U	PARTICIPANT	\N	PRESENT	0
627194	626795	18193Q	PARTICIPANT	\N	PRESENT	1
627195	626795	19657G	PARTICIPANT	\N	PRESENT	1
627196	626795	14213J	PARTICIPANT	\N	PRESENT	1
627197	626795	04057K	PARTICIPANT	\N	PRESENT	1
627198	626795	19723Y	PARTICIPANT	\N	PRESENT	1
627199	626795	19697Q	PARTICIPANT	\N	PRESENT	1
627200	626795	20130U	PARTICIPANT	\N	PRESENT	1
627201	626795	20066E	PARTICIPANT	\N	PRESENT	0
627202	626795	19683J	PARTICIPANT	\N	PRESENT	1
627203	626795	11103C	PARTICIPANT	\N	PRESENT	1
627204	626862	19443T	PARTICIPANT	\N	PRESENT	0
627205	626862	19479G	PARTICIPANT	\N	PRESENT	0
627206	626862	20122U	PARTICIPANT	\N	PRESENT	0
627207	626862	12016W	PARTICIPANT	\N	PRESENT	0
627208	626795	19798U	PARTICIPANT	\N	PRESENT	0
627209	626795	11097X	PARTICIPANT	\N	PRESENT	0
627210	626795	19415P	PARTICIPANT	\N	PRESENT	0
627211	626862	19399H	PARTICIPANT	\N	PRESENT	0
627212	626862	20136B	PARTICIPANT	\N	PRESENT	0
627213	626862	20054A	PARTICIPANT	\N	PRESENT	0
627214	626862	14083S	PARTICIPANT	\N	PRESENT	0
627215	626862	19383Y	PARTICIPANT	\N	PRESENT	0
627216	626795	19713W	PARTICIPANT	\N	PRESENT	0
627219	626887	19599P	PRESIDENT	0	PRESENT	0
627218	626795	19295A	PARTICIPANT	\N	EXCUSE	0
627220	626887	14207L	PARTICIPANT	\N	PRESENT	0
627221	626862	20024T	PARTICIPANT	\N	PRESENT	0
627222	626862	20104S	PARTICIPANT	\N	PRESENT	0
627223	626862	01024M	PARTICIPANT	\N	PRESENT	0
627224	626862	11101A	PARTICIPANT	\N	PRESENT	0
627225	626862	97011G	PARTICIPANT	\N	PRESENT	0
627226	626887	19693L	PARTICIPANT	\N	PRESENT	0
627227	626887	20112S	PARTICIPANT	\N	PRESENT	1
627228	626887	20042V	PARTICIPANT	\N	PRESENT	1
627229	626885	19667J	PRESIDENT	0	PRESENT	0
627230	626885	04085P	PARTICIPANT	\N	PRESENT	0
627231	626862	20070A	PARTICIPANT	\N	PRESENT	0
627232	626862	20110Q	PARTICIPANT	\N	PRESENT	0
627233	626862	19515S	PARTICIPANT	\N	PRESENT	0
627234	626862	20038A	PARTICIPANT	\N	PRESENT	0
627235	626862	20152B	PARTICIPANT	\N	PRESENT	0
627236	626862	19866P	PARTICIPANT	\N	PRESENT	0
627237	626862	19447X	PARTICIPANT	\N	PRESENT	0
627238	626862	11043H	PARTICIPANT	\N	PRESENT	0
627239	626862	01025N	PARTICIPANT	\N	PRESENT	0
622711	621391	19565D	PARTICIPANT	\N	PRESENT	0
622712	621391	20036X	PARTICIPANT	\N	PRESENT	0
622713	621391	20092G	PARTICIPANT	\N	PRESENT	0
622714	621391	20110Q	PARTICIPANT	\N	PRESENT	0
622715	621391	20130U	PARTICIPANT	\N	PRESENT	0
622716	621391	20108W	PARTICIPANT	\N	PRESENT	0
622717	621391	14253S	PARTICIPANT	\N	PRESENT	0
622718	621391	20056C	PARTICIPANT	\N	PRESENT	0
622719	621391	19383Y	PARTICIPANT	\N	PRESENT	0
622720	621391	19367Y	PARTICIPANT	\N	PRESENT	0
622721	621391	19826F	PARTICIPANT	\N	PRESENT	0
622722	621391	11097X	PARTICIPANT	\N	PRESENT	0
622723	621391	19531S	PARTICIPANT	\N	PRESENT	0
622724	621391	19683J	PARTICIPANT	\N	PRESENT	0
622725	621391	11054L	PARTICIPANT	\N	PRESENT	0
622726	621391	19599P	PARTICIPANT	\N	PRESENT	0
622727	621391	08034U	PARTICIPANT	\N	PRESENT	0
622728	621391	19569H	PARTICIPANT	\N	PRESENT	0
622729	621391	19563B	PARTICIPANT	\N	PRESENT	0
622730	621391	19585H	PARTICIPANT	\N	PRESENT	0
622731	621391	20112S	PARTICIPANT	\N	PRESENT	0
622732	621391	12041X	PARTICIPANT	\N	PRESENT	0
622733	621391	11056N	PARTICIPANT	\N	PRESENT	0
622734	621391	19695N	PARTICIPANT	\N	PRESENT	0
622735	621391	19593H	PARTICIPANT	\N	PRESENT	0
622736	621391	19659J	PARTICIPANT	\N	PRESENT	0
622737	621391	19349W	PARTICIPANT	\N	PRESENT	0
622738	621391	14229S	PARTICIPANT	\N	PRESENT	0
622739	621391	14257W	PARTICIPANT	\N	PRESENT	0
622740	621391	20084G	PARTICIPANT	\N	PRESENT	0
622741	621391	17737W	PARTICIPANT	\N	PRESENT	0
622742	621391	08056B	PARTICIPANT	\N	PRESENT	0
622743	621391	20078J	PARTICIPANT	\N	PRESENT	0
622744	621391	20022R	PARTICIPANT	\N	PRESENT	0
622809	621391	20050V	PARTICIPANT	\N	PRESENT	0
622810	621391	14195A	PARTICIPANT	\N	PRESENT	0
622811	621391	19399H	PARTICIPANT	\N	PRESENT	0
622812	621391	14251Q	PARTICIPANT	\N	PRESENT	0
622813	621391	20024T	PARTICIPANT	\N	PRESENT	0
622814	621391	19707Y	PARTICIPANT	\N	PRESENT	0
622815	621391	19705W	PARTICIPANT	\N	PRESENT	0
622816	621391	20142Y	PARTICIPANT	\N	PRESENT	0
622817	621391	08047A	PARTICIPANT	\N	PRESENT	0
622818	621391	20134Y	PARTICIPANT	\N	PRESENT	0
622819	621391	19631V	PARTICIPANT	\N	PRESENT	0
622820	621391	20136B	PARTICIPANT	\N	PRESENT	0
622909	621391	97011G	PARTICIPANT	\N	PRESENT	0
622822	621391	20132W	PARTICIPANT	\N	PRESENT	0
622823	621391	05012A	PARTICIPANT	\N	PRESENT	0
622824	621391	19643A	PARTICIPANT	\N	PRESENT	0
622825	621391	01057W	PARTICIPANT	\N	PRESENT	0
622826	621391	19543W	PARTICIPANT	\N	PRESENT	0
622827	621391	19679N	PARTICIPANT	\N	PRESENT	0
622828	621391	20052X	PARTICIPANT	\N	PRESENT	0
622829	621391	19699S	PARTICIPANT	\N	PRESENT	0
622830	621391	11115U	PARTICIPANT	\N	PRESENT	0
622831	621391	11053K	PARTICIPANT	\N	PRESENT	0
622832	621391	08009T	PARTICIPANT	\N	PRESENT	0
622833	621391	19723Y	PARTICIPANT	\N	PRESENT	0
622834	621391	19611R	PARTICIPANT	\N	PRESENT	0
622835	621391	20058E	PARTICIPANT	\N	PRESENT	0
622836	621391	19691J	PARTICIPANT	\N	PRESENT	0
622837	621391	20086J	PARTICIPANT	\N	PRESENT	0
622838	621391	19745F	PARTICIPANT	\N	PRESENT	0
622839	621391	11043H	PARTICIPANT	\N	PRESENT	0
622840	621391	19369B	PARTICIPANT	\N	PRESENT	0
622841	621391	04043D	PARTICIPANT	\N	PRESENT	0
622842	621391	20128B	PARTICIPANT	\N	PRESENT	0
622843	621391	08069G	PARTICIPANT	\N	PRESENT	0
622844	621391	14123H	PARTICIPANT	\N	PRESENT	0
622845	621391	20144B	PARTICIPANT	\N	PRESENT	0
622846	621391	16685X	PARTICIPANT	\N	PRESENT	0
622847	621391	14042U	PARTICIPANT	\N	PRESENT	0
622848	621391	17637T	PARTICIPANT	\N	PRESENT	0
622849	621391	19347U	PARTICIPANT	\N	PRESENT	0
622850	621391	19057M	PARTICIPANT	\N	PRESENT	0
622851	621391	04033B	PARTICIPANT	\N	PRESENT	0
622852	621391	19479G	PARTICIPANT	\N	PRESENT	0
622853	621391	86034E	PARTICIPANT	\N	PRESENT	0
622854	621391	19441R	PARTICIPANT	\N	PRESENT	0
622855	621391	08010L	PARTICIPANT	\N	PRESENT	0
622856	621391	04047H	PARTICIPANT	\N	PRESENT	0
622857	621391	19747H	PARTICIPANT	\N	PRESENT	0
622858	621391	20066E	PARTICIPANT	\N	PRESENT	0
622859	621391	19619A	PARTICIPANT	\N	PRESENT	0
622860	621391	04057K	PARTICIPANT	\N	PRESENT	0
622861	621391	20060X	PARTICIPANT	\N	PRESENT	0
622862	621391	14133K	PARTICIPANT	\N	PRESENT	0
622863	621391	14055N	PARTICIPANT	\N	PRESENT	0
622864	621391	04092N	PARTICIPANT	\N	PRESENT	0
622865	621391	14275Y	PARTICIPANT	\N	PRESENT	0
622866	621391	14187A	PARTICIPANT	\N	PRESENT	0
622867	621391	19713W	PARTICIPANT	\N	PRESENT	0
622868	621391	14071N	PARTICIPANT	\N	PRESENT	0
622869	621391	05008E	PARTICIPANT	\N	PRESENT	0
622870	621391	14083S	PARTICIPANT	\N	PRESENT	0
622871	621391	14053L	PARTICIPANT	\N	PRESENT	0
622872	621391	19335Q	PARTICIPANT	\N	PRESENT	0
622873	621391	14193X	PARTICIPANT	\N	PRESENT	0
622874	621391	19685L	PARTICIPANT	\N	PRESENT	0
622875	621391	19421M	PARTICIPANT	\N	PRESENT	0
622876	621391	11085T	PARTICIPANT	\N	PRESENT	0
622877	621391	19415P	PARTICIPANT	\N	PRESENT	0
622878	621391	04035D	PARTICIPANT	\N	PRESENT	0
622879	621391	20248J	PARTICIPANT	\N	PRESENT	0
622880	621391	14255U	PARTICIPANT	\N	PRESENT	0
622881	621391	19798U	PARTICIPANT	\N	PRESENT	0
622882	621391	20252E	PARTICIPANT	\N	PRESENT	0
622883	621391	17965H	PARTICIPANT	\N	PRESENT	0
622884	621391	11041F	PARTICIPANT	\N	PRESENT	0
622885	621391	14219Q	PARTICIPANT	\N	PRESENT	0
622886	621391	19687N	PARTICIPANT	\N	PRESENT	0
622887	621391	19533U	PARTICIPANT	\N	PRESENT	0
622888	621391	20118Y	PARTICIPANT	\N	PRESENT	0
622889	621391	19525U	PARTICIPANT	\N	PRESENT	0
622890	621391	95063L	PARTICIPANT	\N	PRESENT	0
622891	621391	14217N	PARTICIPANT	\N	PRESENT	0
622892	621391	01043Q	PARTICIPANT	\N	PRESENT	0
622893	621391	14030Q	PARTICIPANT	\N	PRESENT	0
622894	621391	20054A	PARTICIPANT	\N	PRESENT	0
622895	621391	14179A	PARTICIPANT	\N	PRESENT	0
622896	621391	20126Y	PARTICIPANT	\N	PRESENT	0
622897	621391	20124W	PARTICIPANT	\N	PRESENT	0
622898	621391	14033T	PARTICIPANT	\N	PRESENT	0
622899	621391	19954N	PARTICIPANT	\N	PRESENT	0
622900	621391	19762G	PARTICIPANT	\N	PRESENT	0
622901	621391	11080N	PARTICIPANT	\N	PRESENT	0
622902	621391	19515S	PARTICIPANT	\N	PRESENT	0
622903	621391	19663E	PARTICIPANT	\N	PRESENT	0
622904	621391	19507S	PARTICIPANT	\N	PRESENT	0
622905	621391	19447X	PARTICIPANT	\N	PRESENT	0
622906	621391	01048V	PARTICIPANT	\N	PRESENT	0
622907	621391	99004R	PARTICIPANT	\N	PRESENT	0
622908	621391	20032T	PARTICIPANT	\N	PRESENT	0
622910	621391	20174H	PARTICIPANT	\N	PRESENT	0
622914	621391	18083K	PARTICIPANT	\N	PRESENT	0
622916	621391	19701S	PARTICIPANT	\N	PRESENT	0
622918	621391	14001X	PARTICIPANT	\N	PRESENT	0
622920	621391	10006L	PARTICIPANT	\N	PRESENT	0
622921	621391	19760E	PARTICIPANT	\N	PRESENT	0
622922	621391	14213J	PARTICIPANT	\N	PRESENT	0
622923	621391	20094J	PARTICIPANT	\N	PRESENT	0
622928	621391	19768N	PARTICIPANT	\N	PRESENT	0
622925	621391	14205J	PARTICIPANT	\N	PRESENT	0
622926	621391	19749K	PARTICIPANT	\N	PRESENT	0
622927	621391	14189C	PARTICIPANT	\N	PRESENT	0
622929	621391	14069U	PARTICIPANT	\N	PRESENT	0
622931	621391	14026U	PARTICIPANT	\N	PRESENT	0
622936	621391	14147R	PARTICIPANT	\N	PRESENT	0
622965	621391	19709B	PARTICIPANT	\N	PRESENT	0
622941	621391	20266L	PARTICIPANT	\N	PRESENT	0
622942	621391	19689Q	PARTICIPANT	\N	PRESENT	0
622949	621391	11066Q	PARTICIPANT	\N	PRESENT	0
622964	621391	20042V	PARTICIPANT	\N	PRESENT	0
622966	621391	20040T	PARTICIPANT	\N	PRESENT	0
622967	621391	20172F	PARTICIPANT	\N	PRESENT	0
622968	621391	14073Q	PARTICIPANT	\N	PRESENT	0
622969	621391	01028R	PARTICIPANT	\N	PRESENT	0
622974	621391	19553Y	PARTICIPANT	\N	PRESENT	0
622975	621391	20048C	PARTICIPANT	\N	PRESENT	0
622976	621391	19621T	PARTICIPANT	\N	PRESENT	0
599201	597484	17589D	PARTICIPANT	\N	PRESENT	0
599202	597484	19399H	PARTICIPANT	\N	PRESENT	0
599203	598018	11070L	PARTICIPANT	\N	PRESENT	0
599204	598018	11110B	PARTICIPANT	\N	PRESENT	0
599205	598018	20116W	PARTICIPANT	\N	PRESENT	0
599206	598018	11012A	PARTICIPANT	\N	PRESENT	0
599207	598018	19545Y	PARTICIPANT	\N	PRESENT	0
599209	598018	19667J	PARTICIPANT	\N	PRESENT	0
599211	598005	19443T	PARTICIPANT	\N	PRESENT	0
599212	598005	19565D	PARTICIPANT	\N	PRESENT	0
599213	598005	01058X	PARTICIPANT	\N	PRESENT	0
599214	598005	16685X	PARTICIPANT	\N	PRESENT	0
599215	598005	11027H	PARTICIPANT	\N	PRESENT	0
599216	598005	11066Q	PARTICIPANT	\N	PRESENT	0
599217	598005	08056B	PARTICIPANT	\N	PRESENT	0
599218	598005	12028B	PARTICIPANT	\N	PRESENT	0
599219	598005	19421M	PARTICIPANT	\N	PRESENT	0
599220	598005	19347U	PARTICIPANT	\N	PRESENT	0
599221	598005	07033P	PARTICIPANT	\N	PRESENT	0
599222	598005	97011G	PARTICIPANT	\N	PRESENT	0
599223	598005	08061X	PARTICIPANT	\N	PRESENT	0
599224	598005	14249W	PARTICIPANT	\N	PRESENT	0
599225	598005	08047A	PRESIDENT	0	PRESENT	0
599226	598005	14097Y	PARTICIPANT	\N	PRESENT	0
599227	598005	14059S	PARTICIPANT	\N	PRESENT	0
599228	598005	04035D	PARTICIPANT	\N	PRESENT	0
599229	598005	01062T	PARTICIPANT	\N	PRESENT	0
599230	598005	11041F	PARTICIPANT	\N	PRESENT	0
599231	598005	08069G	PARTICIPANT	\N	PRESENT	0
599232	598005	20042V	PARTICIPANT	\N	PRESENT	0
599233	598005	01024M	PARTICIPANT	\N	PRESENT	0
599234	598005	14105F	PARTICIPANT	\N	PRESENT	0
599235	598005	11064N	PARTICIPANT	\N	PRESENT	0
599236	598005	14267Y	PARTICIPANT	\N	PRESENT	0
599237	598005	11083R	PARTICIPANT	\N	PRESENT	0
599238	598005	14211G	PARTICIPANT	\N	PRESENT	0
599239	598005	19583F	PARTICIPANT	\N	PRESENT	0
599240	598005	04042C	PARTICIPANT	\N	EXCUSE	0
599242	598005	14255U	PARTICIPANT	\N	PRESENT	0
599243	598005	14055N	PARTICIPANT	\N	PRESENT	0
599244	598005	11054L	PARTICIPANT	\N	PRESENT	0
599245	598018	20126Y	PARTICIPANT	\N	PRESENT	0
599247	598018	11074Q	PARTICIPANT	\N	PRESENT	0
600755	600747	19735D	PARTICIPANT	\N	PRESENT	0
599249	597484	19735D	PARTICIPANT	\N	PRESENT	0
599250	597484	14109K	PARTICIPANT	\N	PRESENT	0
599251	597484	14123H	PARTICIPANT	\N	PRESENT	0
599253	598005	19721W	PARTICIPANT	\N	PRESENT	0
599255	597484	04033B	PARTICIPANT	\N	PRESENT	0
599257	598005	19669L	PARTICIPANT	\N	PRESENT	0
600756	600747	11067R	PARTICIPANT	\N	PRESENT	0
600757	600747	01058X	PARTICIPANT	\N	PRESENT	0
600758	600747	19533U	PARTICIPANT	\N	PRESENT	0
600764	600747	19503N	PARTICIPANT	\N	PRESENT	0
600767	600747	01048V	PARTICIPANT	\N	PRESENT	0
600770	600747	04043D	PARTICIPANT	\N	PRESENT	0
601111	601110	11066Q	PARTICIPANT	\N	PRESENT	0
601113	601112	01058X	PARTICIPANT	\N	PRESENT	0
601114	601112	19347U	PARTICIPANT	\N	PRESENT	0
601120	601119	19593H	PARTICIPANT	\N	PRESENT	0
601121	601119	11065P	PARTICIPANT	\N	PRESENT	0
601122	601119	97011G	PARTICIPANT	\N	PRESENT	0
601123	601119	20180F	PARTICIPANT	\N	PRESENT	0
601124	601119	19551W	PARTICIPANT	\N	PRESENT	0
601125	601119	14059S	PARTICIPANT	\N	PRESENT	0
601126	601119	08012N	PARTICIPANT	\N	PRESENT	0
601127	601119	20084G	PARTICIPANT	\N	PRESENT	0
601128	601119	11041F	PARTICIPANT	\N	PRESENT	0
601131	601130	05008E	PARTICIPANT	\N	PRESENT	0
601132	601130	11053K	PARTICIPANT	\N	PRESENT	0
601133	601130	01028R	PARTICIPANT	\N	PRESENT	0
601136	601134	04057K	PARTICIPANT	\N	PRESENT	0
601137	601135	20114U	PARTICIPANT	\N	PRESENT	0
601141	601135	19565D	PARTICIPANT	\N	PRESENT	0
601139	601135	11056N	PARTICIPANT	\N	PRESENT	0
601140	601135	01024M	PARTICIPANT	\N	PRESENT	0
601142	601135	14026U	PARTICIPANT	\N	PRESENT	0
601143	601135	14179A	PARTICIPANT	\N	PRESENT	0
601144	601135	14097Y	PARTICIPANT	\N	PRESENT	0
601145	601135	08047A	PARTICIPANT	\N	PRESENT	0
601146	601135	19798U	PARTICIPANT	\N	PRESENT	0
601147	601135	04045F	PARTICIPANT	\N	PRESENT	0
601148	601135	19713W	PARTICIPANT	\N	PRESENT	0
601149	601135	19691J	PARTICIPANT	\N	PRESENT	0
601150	601134	19691J	PARTICIPANT	\N	PRESENT	0
601153	598436	19593H	PARTICIPANT	\N	PRESENT	0
601154	598436	14229S	PARTICIPANT	\N	PRESENT	0
601155	598437	14229S	PARTICIPANT	\N	PRESENT	0
601158	601156	14229S	PARTICIPANT	\N	PRESENT	1
601159	601156	19735D	PARTICIPANT	\N	PRESENT	1
601160	601157	14229S	PARTICIPANT	\N	PRESENT	1
601161	601157	19735D	PARTICIPANT	\N	PRESENT	1
601487	598434	20142Y	PARTICIPANT	\N	PRESENT	0
601488	598434	20132W	PARTICIPANT	\N	PRESENT	0
606095	602241	14189C	PARTICIPANT	\N	PRESENT	0
606098	602241	19573D	PARTICIPANT	\N	PRESENT	0
606101	602241	19683J	PRESIDENT	0	PRESENT	0
606102	602241	99004R	PARTICIPANT	\N	PRESENT	0
606103	602241	10006L	PARTICIPANT	\N	PRESENT	0
606234	606233	14189C	PARTICIPANT	\N	PRESENT	0
606235	606233	19683J	PRESIDENT	0	PRESENT	0
606236	606233	99004R	PARTICIPANT	\N	PRESENT	0
608334	608333	04059M	PARTICIPANT	\N	PRESENT	0
608335	608333	20086J	PARTICIPANT	\N	PRESENT	0
608336	608333	20152B	PARTICIPANT	\N	PRESENT	0
608337	608333	11053K	PARTICIPANT	\N	EXCUSE	0
608338	608333	19673G	PARTICIPANT	\N	PRESENT	0
608339	608333	20132W	PARTICIPANT	\N	PRESENT	0
608340	608333	19399H	PARTICIPANT	\N	PRESENT	0
608341	608333	20056C	PARTICIPANT	\N	PRESENT	0
608342	608333	19611R	PRESIDENT	1	PRESENT	0
608343	608333	19699S	PARTICIPANT	\N	PRESENT	0
608344	608333	12041X	PARTICIPANT	\N	PRESENT	0
608345	608333	20142Y	PRESIDENT	0	PRESENT	0
608346	608333	14229S	PARTICIPANT	\N	PRESENT	0
608347	608333	20026V	PARTICIPANT	\N	PRESENT	0
608348	608333	20122U	PARTICIPANT	\N	PRESENT	0
608349	608333	19669L	PARTICIPANT	\N	PRESENT	0
608353	608352	08015R	PARTICIPANT	\N	PRESENT	0
608354	608352	14225N	PARTICIPANT	\N	PRESENT	0
608355	608352	08056B	PARTICIPANT	\N	PRESENT	0
608356	608352	20052X	PARTICIPANT	\N	PRESENT	0
608903	608902	14213J	PARTICIPANT	\N	PRESENT	0
608904	608902	14042U	PARTICIPANT	\N	PRESENT	0
608905	608902	99004R	PARTICIPANT	\N	PRESENT	0
608912	608902	14189C	PARTICIPANT	\N	PRESENT	0
608914	608902	08045X	PARTICIPANT	\N	PRESENT	0
608915	608902	17965H	PARTICIPANT	\N	PRESENT	0
608917	608902	11097X	PARTICIPANT	\N	PRESENT	0
608918	608902	11031D	PARTICIPANT	\N	PRESENT	0
608925	608902	19760E	PARTICIPANT	\N	PRESENT	0
608933	608902	19683J	PARTICIPANT	\N	PRESENT	0
609034	608663	04059M	PARTICIPANT	\N	PRESENT	0
609035	608663	20086J	PARTICIPANT	\N	PRESENT	0
609036	608663	20152B	PARTICIPANT	\N	PRESENT	0
609038	608663	19621T	PARTICIPANT	\N	PRESENT	0
609040	608663	19673G	PARTICIPANT	\N	PRESENT	0
609043	608663	20132W	PARTICIPANT	\N	PRESENT	0
609044	608663	19725B	PARTICIPANT	\N	PRESENT	0
609046	608663	19399H	PARTICIPANT	\N	PRESENT	0
609049	608663	20056C	PARTICIPANT	\N	PRESENT	0
609050	608663	19611R	PRESIDENT	0	PRESENT	0
609051	608663	19699S	PARTICIPANT	\N	PRESENT	0
609052	608663	12041X	PARTICIPANT	\N	PRESENT	0
609053	608663	20142Y	PARTICIPANT	\N	PRESENT	0
609054	608663	19705W	PARTICIPANT	\N	PRESENT	0
609055	608663	14229S	PARTICIPANT	\N	PRESENT	0
609056	608663	20026V	PARTICIPANT	\N	PRESENT	0
609057	608663	20122U	PARTICIPANT	\N	PRESENT	0
610478	608662	17023S	PARTICIPANT	\N	PRESENT	0
610479	608662	97011G	PARTICIPANT	\N	PRESENT	0
610480	608662	20034V	PARTICIPANT	\N	EXCUSE	0
610481	608662	19715Y	PRESIDENT	0	PRESENT	0
610482	608662	08034U	PARTICIPANT	\N	PRESENT	0
610483	608662	14059S	PARTICIPANT	\N	EXCUSE	0
610484	608662	14147R	PARTICIPANT	\N	PRESENT	0
610485	608662	20148F	PARTICIPANT	\N	PRESENT	1
620085	618090	11064N	PARTICIPANT	\N	PRESENT	0
620086	618090	20252E	PARTICIPANT	\N	PRESENT	0
620087	618090	19671E	PARTICIPANT	\N	PRESENT	0
620088	618090	19251M	PARTICIPANT	\N	PRESENT	0
620089	618090	20070A	PARTICIPANT	\N	PRESENT	0
620090	618825	11067R	PARTICIPANT	\N	PRESENT	0
620091	618090	19367Y	PARTICIPANT	\N	PRESENT	0
620092	618090	19721W	PARTICIPANT	\N	PRESENT	0
620093	618090	14193X	PARTICIPANT	\N	PRESENT	0
620094	618825	19569H	PARTICIPANT	\N	PRESENT	0
620095	618090	20150Y	PARTICIPANT	\N	PRESENT	0
620096	618090	14069U	PARTICIPANT	\N	PRESENT	0
620097	618825	20130U	PARTICIPANT	\N	PRESENT	0
620098	618090	20020P	PARTICIPANT	\N	PRESENT	0
620099	618090	19762G	PARTICIPANT	\N	PRESENT	0
620100	618090	14357A	PARTICIPANT	\N	PRESENT	0
620101	618090	04042C	PARTICIPANT	\N	PRESENT	0
620102	618090	14221J	PARTICIPANT	\N	PRESENT	0
620103	618090	14329V	PARTICIPANT	\N	PRESENT	0
620104	618090	14213J	PARTICIPANT	\N	PRESENT	0
620105	618090	20024T	PARTICIPANT	\N	PRESENT	0
620106	618090	20042V	PARTICIPANT	\N	PRESENT	0
620107	618090	20108W	PARTICIPANT	\N	PRESENT	0
620108	618090	14030Q	PARTICIPANT	\N	PRESENT	0
620109	618090	14189C	PARTICIPANT	\N	PRESENT	0
620110	618090	20104S	PARTICIPANT	\N	PRESENT	0
620111	618090	14255U	PARTICIPANT	\N	PRESENT	0
620112	618090	14083S	PARTICIPANT	\N	PRESENT	0
620113	618090	20144B	PARTICIPANT	\N	PRESENT	0
620114	618090	19573D	PARTICIPANT	\N	PRESENT	0
620115	618090	20062A	PARTICIPANT	\N	PRESENT	0
620116	618090	14327T	PARTICIPANT	\N	PRESENT	0
620117	618090	14033T	PARTICIPANT	\N	PRESENT	0
620118	618090	20056C	PARTICIPANT	\N	PRESENT	0
620119	618090	19467C	PARTICIPANT	\N	PRESENT	0
620120	618090	19699S	PARTICIPANT	\N	PRESENT	0
620121	618090	01024M	PARTICIPANT	\N	PRESENT	0
620122	618090	20044X	PARTICIPANT	\N	PRESENT	0
620123	618090	14042U	PARTICIPANT	\N	PRESENT	0
620124	618090	19643A	PARTICIPANT	\N	PRESENT	0
620125	618090	20058E	PARTICIPANT	\N	PRESENT	0
620126	618090	14038Y	PARTICIPANT	\N	PRESENT	0
620127	618090	08018U	PARTICIPANT	\N	PRESENT	0
620128	618090	19691J	PARTICIPANT	\N	PRESENT	0
620129	618090	19569H	PARTICIPANT	\N	PRESENT	0
620130	618090	07029T	PARTICIPANT	\N	PRESENT	0
620131	618090	14179A	PARTICIPANT	\N	PRESENT	0
620132	618090	08056B	PARTICIPANT	\N	PRESENT	0
620133	618090	19685L	PARTICIPANT	\N	PRESENT	0
620134	618090	20086J	PARTICIPANT	\N	PRESENT	0
620135	618090	20048C	PARTICIPANT	\N	PRESENT	0
620136	618090	08015R	PARTICIPANT	\N	PRESENT	0
620137	618090	19768N	PARTICIPANT	\N	PRESENT	0
620138	618090	19705W	PARTICIPANT	\N	PRESENT	0
620139	618090	19707Y	PARTICIPANT	\N	PRESENT	0
620140	618090	01043Q	PARTICIPANT	\N	PRESENT	0
620141	618090	20054A	PARTICIPANT	\N	PRESENT	0
620142	618090	20052X	PARTICIPANT	\N	PRESENT	0
620143	618090	16685X	PARTICIPANT	\N	PRESENT	0
620144	618090	14059S	PARTICIPANT	\N	PRESENT	0
620145	618090	20124W	PARTICIPANT	\N	PRESENT	0
620146	618090	19441R	PARTICIPANT	\N	PRESENT	0
620147	618090	20126Y	PARTICIPANT	\N	PRESENT	0
620148	618090	11085T	PARTICIPANT	\N	PRESENT	0
620149	618090	20040T	PARTICIPANT	\N	PRESENT	0
620150	618090	14231L	PARTICIPANT	\N	PRESENT	0
620151	618090	19415P	PARTICIPANT	\N	PRESENT	0
620152	618090	19826F	PARTICIPANT	\N	PRESENT	0
620153	618090	19335Q	PARTICIPANT	\N	PRESENT	0
620154	618090	19745F	PARTICIPANT	\N	PRESENT	0
620155	618090	19575F	PARTICIPANT	\N	PRESENT	0
620156	618090	19749K	PARTICIPANT	\N	PRESENT	0
620157	618090	01034P	PARTICIPANT	\N	PRESENT	0
620158	618090	19619A	PARTICIPANT	\N	PRESENT	0
620159	618090	20090E	PARTICIPANT	\N	PRESENT	0
620160	618090	04070G	PARTICIPANT	\N	PRESENT	0
620161	618090	19525U	PARTICIPANT	\N	PRESENT	0
620162	618090	20174H	PARTICIPANT	\N	PRESENT	0
620163	618090	14249W	PARTICIPANT	\N	PRESENT	0
620164	618090	19717B	PARTICIPANT	\N	PRESENT	0
620165	618090	04059M	PARTICIPANT	\N	PRESENT	0
620166	618090	19549D	PARTICIPANT	\N	PRESENT	0
620167	618090	20094J	PARTICIPANT	\N	PRESENT	0
620168	618090	04035D	PARTICIPANT	\N	PRESENT	0
620169	618090	20098N	PARTICIPANT	\N	PRESENT	0
620170	618090	19599P	PARTICIPANT	\N	PRESENT	0
620171	618090	19669L	PARTICIPANT	\N	PRESENT	0
620172	618090	14053L	PARTICIPANT	\N	PRESENT	0
620173	618090	19663E	PARTICIPANT	\N	PRESENT	0
620174	618090	19723Y	PARTICIPANT	\N	PRESENT	0
620175	618090	20066E	PARTICIPANT	\N	PRESENT	0
620176	618090	20122U	PARTICIPANT	\N	PRESENT	0
620181	618090	20142Y	PARTICIPANT	\N	PRESENT	0
620178	618090	14205J	PARTICIPANT	\N	PRESENT	0
620179	618090	14259Y	PARTICIPANT	\N	PRESENT	0
620180	618090	20096L	PARTICIPANT	\N	PRESENT	0
620182	618090	20266L	PARTICIPANT	\N	PRESENT	0
620183	618090	19611R	PARTICIPANT	\N	PRESENT	0
620184	618090	19591F	PARTICIPANT	\N	PRESENT	0
620185	618090	17023S	PARTICIPANT	\N	PRESENT	0
620186	618090	17589D	PARTICIPANT	\N	PRESENT	0
620187	618090	19713W	PARTICIPANT	\N	PRESENT	0
620190	618090	11043H	PARTICIPANT	\N	PRESENT	0
620191	618090	08069G	PARTICIPANT	\N	PRESENT	0
620470	618091	01043Q	PARTICIPANT	\N	PRESENT	0
620471	618091	08069G	PARTICIPANT	\N	PRESENT	0
620472	618412	20064C	PARTICIPANT	\N	PRESENT	0
620473	618412	07004J	PARTICIPANT	\N	PRESENT	1
620474	618412	20038A	PARTICIPANT	\N	PRESENT	0
620475	618412	19667J	PRESIDENT	0	PRESENT	0
620476	618412	19511N	PARTICIPANT	\N	PRESENT	0
620477	618412	04085P	PARTICIPANT	\N	PRESENT	0
620478	618091	20068G	PARTICIPANT	\N	PRESENT	0
620479	618091	20076G	PARTICIPANT	\N	PRESENT	0
620480	618091	20074E	PARTICIPANT	\N	PRESENT	0
620481	618091	19663E	PARTICIPANT	\N	PRESENT	0
620482	618091	19467C	PARTICIPANT	\N	PRESENT	0
620483	618091	19443T	PARTICIPANT	\N	PRESENT	0
620484	618091	20090E	PARTICIPANT	\N	PRESENT	0
620485	618091	08056B	PARTICIPANT	\N	PRESENT	0
620486	618091	20124W	PARTICIPANT	\N	PRESENT	0
620487	618091	20126Y	PARTICIPANT	\N	PRESENT	0
620488	618091	20020P	PARTICIPANT	\N	PRESENT	0
620489	618091	11043H	PARTICIPANT	\N	PRESENT	0
620490	618091	19768N	PARTICIPANT	\N	PRESENT	0
620491	618091	10015M	PARTICIPANT	\N	PRESENT	0
620492	618091	19563B	PARTICIPANT	\N	PRESENT	0
620493	618091	14147R	PARTICIPANT	\N	PRESENT	0
620494	618091	14111D	PARTICIPANT	\N	PRESENT	0
620495	618091	14195A	PARTICIPANT	\N	PRESENT	0
620496	618091	19699S	PARTICIPANT	\N	PRESENT	0
620497	618091	11033F	PARTICIPANT	\N	PRESENT	0
620498	618091	20110Q	PARTICIPANT	\N	PRESENT	0
620499	618091	14038Y	PARTICIPANT	\N	PRESENT	0
620500	618091	11031D	PARTICIPANT	\N	PRESENT	0
620501	618091	04092N	PARTICIPANT	\N	PRESENT	0
620502	618091	14329V	PARTICIPANT	\N	PRESENT	0
620503	618091	18083K	PARTICIPANT	\N	PRESENT	0
620504	618091	20252E	PARTICIPANT	\N	PRESENT	0
620505	618091	19675J	PARTICIPANT	\N	PRESENT	0
620506	618091	19683J	PARTICIPANT	\N	PRESENT	0
620507	618091	19649G	PARTICIPANT	\N	PRESENT	0
620508	618091	20082E	PARTICIPANT	\N	PRESENT	0
620509	618091	01028R	PARTICIPANT	\N	PRESENT	0
620510	618091	20264J	PARTICIPANT	\N	PRESENT	0
620511	618091	19725B	PARTICIPANT	\N	PRESENT	0
620512	618091	20028X	PARTICIPANT	\N	PRESENT	0
620513	618091	19651A	PARTICIPANT	\N	PRESENT	0
620514	618091	14275Y	PARTICIPANT	\N	PRESENT	0
620515	618091	20286Q	PARTICIPANT	\N	PRESENT	0
620516	618091	19631V	PARTICIPANT	\N	PRESENT	0
620517	618091	14030Q	PARTICIPANT	\N	PRESENT	0
620518	618091	14255U	PARTICIPANT	\N	PRESENT	0
620519	618091	14189C	PARTICIPANT	\N	PRESENT	0
620520	618091	19703U	PARTICIPANT	\N	PRESENT	0
620521	618091	19415P	PARTICIPANT	\N	PRESENT	0
620522	618091	19747H	PARTICIPANT	\N	PRESENT	0
620523	618363	14327T	PRESIDENT	1	PRESENT	0
620524	618363	14331P	PARTICIPANT	\N	PRESENT	0
620525	618363	07029T	PARTICIPANT	\N	PRESENT	0
620526	618363	11048N	PARTICIPANT	\N	PRESENT	0
600845	590804	14231L	PRESIDENT	0	PRESENT	0
600846	590804	14215L	PARTICIPANT	\N	PRESENT	0
600847	590804	20122U	PARTICIPANT	\N	PRESENT	0
600848	590804	19735D	PARTICIPANT	\N	PRESENT	0
600849	590804	14229S	PARTICIPANT	\N	PRESENT	0
600850	590804	19565D	PARTICIPANT	\N	PRESENT	0
600851	590804	14217N	PARTICIPANT	\N	PRESENT	0
600852	590804	20090E	PARTICIPANT	\N	PRESENT	0
600853	590804	14071N	PARTICIPANT	\N	PRESENT	0
600854	590804	05012A	PARTICIPANT	\N	PRESENT	0
600855	590804	19333N	PARTICIPANT	\N	PRESENT	0
600856	590804	20084G	PARTICIPANT	\N	PRESENT	0
600857	590804	19782L	PARTICIPANT	\N	PRESENT	0
600858	590804	01057W	PARTICIPANT	\N	PRESENT	0
600859	590804	19447X	PARTICIPANT	\N	PRESENT	0
600860	590804	20062A	PARTICIPANT	\N	PRESENT	0
600861	590804	14151M	PARTICIPANT	\N	PRESENT	0
600862	590804	19563B	PARTICIPANT	\N	PRESENT	0
600863	590804	20022R	PARTICIPANT	\N	EXCUSE	0
600864	590804	14173T	PARTICIPANT	\N	EXCUSE	0
600865	590804	14205J	PARTICIPANT	\N	EXCUSE	0
600866	590804	19681G	PARTICIPANT	\N	EXCUSE	0
600867	590804	19826F	PARTICIPANT	\N	EXCUSE	0
600868	590804	04045F	PARTICIPANT	\N	EXCUSE	0
600869	590804	08010L	PARTICIPANT	\N	EXCUSE	0
600870	590804	20110Q	PARTICIPANT	\N	EXCUSE	0
600871	590804	14053L	PARTICIPANT	\N	EXCUSE	0
600872	590804	19711U	PARTICIPANT	\N	EXCUSE	0
600873	590804	19820Y	PARTICIPANT	\N	EXCUSE	0
600874	590804	20120S	PARTICIPANT	\N	EXCUSE	0
600876	590804	19758L	PARTICIPANT	\N	PRESENT	0
600880	600843	14215L	PARTICIPANT	\N	PRESENT	0
600879	600843	14231L	PRESIDENT	0	PRESENT	0
600881	600843	20122U	PARTICIPANT	\N	PRESENT	0
600882	600843	19735D	PARTICIPANT	\N	PRESENT	0
600883	600843	19758L	PARTICIPANT	\N	PRESENT	0
600884	600843	14229S	PARTICIPANT	\N	PRESENT	0
600885	600843	19565D	PARTICIPANT	\N	PRESENT	0
600886	600843	14217N	PARTICIPANT	\N	PRESENT	0
600887	600843	20090E	PARTICIPANT	\N	PRESENT	0
600888	600843	05012A	PARTICIPANT	\N	PRESENT	0
600889	600843	14071N	PARTICIPANT	\N	PRESENT	0
600890	600843	19333N	PARTICIPANT	\N	PRESENT	0
600891	600843	20084G	PARTICIPANT	\N	PRESENT	0
600892	600843	19782L	PARTICIPANT	\N	PRESENT	0
600893	600843	01057W	PARTICIPANT	\N	PRESENT	0
600894	600843	19447X	PARTICIPANT	\N	PRESENT	0
600895	600843	20062A	PARTICIPANT	\N	PRESENT	0
600897	600843	14151M	PARTICIPANT	\N	PRESENT	0
600898	600843	19563B	PARTICIPANT	\N	PRESENT	0
600899	600843	20022R	PARTICIPANT	\N	EXCUSE	0
600900	600843	20110Q	PARTICIPANT	\N	EXCUSE	0
600901	600843	14053L	PARTICIPANT	\N	EXCUSE	0
600902	600843	19681G	PARTICIPANT	\N	EXCUSE	0
600903	600843	20120S	PARTICIPANT	\N	EXCUSE	0
600904	600843	19820Y	PARTICIPANT	\N	EXCUSE	0
600905	600843	19711U	PARTICIPANT	\N	EXCUSE	0
600906	600843	08010L	PARTICIPANT	\N	EXCUSE	0
600907	600843	14205J	PARTICIPANT	\N	EXCUSE	0
600908	600843	19826F	PARTICIPANT	\N	EXCUSE	0
600909	600843	04045F	PARTICIPANT	\N	EXCUSE	0
600910	600843	14173T	PARTICIPANT	\N	EXCUSE	0
600915	600914	14053L	PARTICIPANT	\N	PRESENT	0
600916	600914	19749K	PARTICIPANT	\N	PRESENT	0
600918	600917	14053L	PARTICIPANT	\N	PRESENT	0
600920	600917	19749K	PARTICIPANT	\N	PRESENT	0
602316	600206	20104S	PARTICIPANT	\N	EXCUSE	0
602317	600206	20100N	PARTICIPANT	\N	PRESENT	0
602318	600206	04035D	PARTICIPANT	\N	PRESENT	0
602319	600206	11083R	PARTICIPANT	\N	PRESENT	0
602320	600206	14033T	PARTICIPANT	\N	PRESENT	0
602321	600206	14026U	PARTICIPANT	\N	PRESENT	0
602322	600206	19725B	PARTICIPANT	\N	PRESENT	0
602323	600206	14073Q	PARTICIPANT	\N	PRESENT	0
602324	600206	12041X	PARTICIPANT	\N	PRESENT	0
602325	600206	19711U	PARTICIPANT	\N	PRESENT	0
602326	600206	11026G	PARTICIPANT	\N	PRESENT	0
602327	600206	19441R	PARTICIPANT	\N	PRESENT	0
602328	600206	14001X	PARTICIPANT	\N	PRESENT	0
602329	600206	04057K	PARTICIPANT	\N	PRESENT	0
602330	600206	04070G	PARTICIPANT	\N	PRESENT	0
602331	600206	14169X	PARTICIPANT	\N	PRESENT	0
602332	600206	14237S	PARTICIPANT	\N	PRESENT	0
602333	600206	14331P	PRESIDENT	0	PRESENT	0
602344	600206	11101A	PARTICIPANT	\N	PRESENT	0
602346	600206	14357A	PARTICIPANT	\N	EXCUSE	0
602371	600206	04092N	PARTICIPANT	\N	PRESENT	0
602373	600206	20126Y	PARTICIPANT	\N	PRESENT	0
602976	602973	19711U	PARTICIPANT	\N	PRESENT	0
602983	602981	19531S	PARTICIPANT	\N	PRESENT	0
602984	602981	19762G	PARTICIPANT	\N	PRESENT	0
603005	602997	08009T	PARTICIPANT	\N	PRESENT	0
603006	602997	20044X	PARTICIPANT	\N	PRESENT	0
603018	603017	08009T	PARTICIPANT	\N	PRESENT	0
603019	603017	20044X	PARTICIPANT	\N	PRESENT	0
603021	603020	11053K	PARTICIPANT	\N	PRESENT	0
603127	603126	19709B	PARTICIPANT	\N	PRESENT	0
603128	603126	11041F	PARTICIPANT	\N	PRESENT	0
603134	603132	14169X	PARTICIPANT	\N	PRESENT	0
603135	603131	14169X	PARTICIPANT	\N	PRESENT	0
603137	603136	14169X	PARTICIPANT	\N	PRESENT	0
603165	603163	20032T	PARTICIPANT	\N	PRESENT	0
603166	603163	14038Y	PARTICIPANT	\N	PRESENT	0
603167	603163	14033T	PARTICIPANT	\N	PRESENT	0
603168	603163	14097Y	PARTICIPANT	\N	PRESENT	0
603169	603163	14205J	PARTICIPANT	\N	PRESENT	0
603170	603163	14059S	PARTICIPANT	\N	PRESENT	0
603171	603163	19563B	PARTICIPANT	\N	PRESENT	0
603172	603163	20082E	PARTICIPANT	\N	PRESENT	0
603173	603163	11097X	PARTICIPANT	\N	PRESENT	0
603174	603163	20062A	PARTICIPANT	\N	PRESENT	0
603616	601162	19551W	PARTICIPANT	\N	PRESENT	0
603617	601162	20038A	PARTICIPANT	\N	PRESENT	0
603618	601162	19701S	PARTICIPANT	\N	EXCUSE	0
603628	601486	14053L	PARTICIPANT	\N	EXCUSE	0
603629	601489	14053L	PARTICIPANT	\N	EXCUSE	0
606114	603150	14147R	PARTICIPANT	\N	PRESENT	0
609442	608660	19691J	PARTICIPANT	\N	EXCUSE	0
607487	607452	20066E	PARTICIPANT	\N	PRESENT	0
607489	607183	20116W	PARTICIPANT	\N	EXCUSE	0
627298	626863	11045K	PARTICIPANT	\N	PRESENT	0
627299	626863	01025N	PARTICIPANT	\N	PRESENT	0
627300	626863	01024M	PARTICIPANT	\N	PRESENT	0
627301	626863	19619A	PARTICIPANT	\N	PRESENT	0
627302	626863	14219Q	PARTICIPANT	\N	PRESENT	0
627303	626863	19387D	PARTICIPANT	\N	PRESENT	0
627304	626863	20122U	PARTICIPANT	\N	PRESENT	0
627305	626863	17589D	PARTICIPANT	\N	PRESENT	0
627306	626863	20054A	PARTICIPANT	\N	PRESENT	0
627307	626863	20152B	PARTICIPANT	\N	PRESENT	0
627308	626887	19533U	PRESIDENT	1	PRESENT	0
627309	626863	20142Y	PARTICIPANT	\N	PRESENT	0
627310	626863	20110Q	PARTICIPANT	\N	PRESENT	0
627311	626863	19551W	PARTICIPANT	\N	PRESENT	0
627312	626863	12016W	PARTICIPANT	\N	PRESENT	0
627313	626863	97011G	PARTICIPANT	\N	PRESENT	0
627314	626863	14105F	PARTICIPANT	\N	PRESENT	0
627315	626863	14069U	PARTICIPANT	\N	PRESENT	0
627316	626863	20032T	PARTICIPANT	\N	PRESENT	0
627317	626863	20024T	PARTICIPANT	\N	PRESENT	0
627318	626863	11101A	PARTICIPANT	\N	PRESENT	0
627319	626863	20104S	PARTICIPANT	\N	PRESENT	0
627320	626863	19399H	PARTICIPANT	\N	PRESENT	0
627321	626863	20026V	PARTICIPANT	\N	PRESENT	0
627322	626863	19549D	PARTICIPANT	\N	PRESENT	0
627323	626863	19820Y	PARTICIPANT	\N	PRESENT	0
627324	626863	19503N	PARTICIPANT	\N	PRESENT	0
627325	626863	19637C	PARTICIPANT	\N	PRESENT	0
627329	626863	19651A	PARTICIPANT	\N	PRESENT	0
627327	626863	14107H	PARTICIPANT	\N	PRESENT	0
627328	626863	08061X	PARTICIPANT	\N	PRESENT	0
627330	626863	20068G	PARTICIPANT	\N	PRESENT	0
627331	626885	17737W	PARTICIPANT	\N	PRESENT	0
627333	626885	20064C	PARTICIPANT	\N	PRESENT	0
627334	626885	07004J	PARTICIPANT	\N	PRESENT	0
627335	626885	14249W	PARTICIPANT	\N	PRESENT	0
627336	626863	11043H	PARTICIPANT	\N	PRESENT	0
627337	626863	20136B	PARTICIPANT	\N	PRESENT	0
627338	626863	19593H	PARTICIPANT	\N	PRESENT	0
627339	626863	20102Q	PARTICIPANT	\N	PRESENT	0
627340	626863	18083K	PARTICIPANT	\N	PRESENT	0
622977	621391	17023S	PARTICIPANT	\N	PRESENT	0
622979	621391	08018U	PARTICIPANT	\N	PRESENT	0
622998	621391	14089Y	PARTICIPANT	\N	PRESENT	0
623266	621392	01043Q	PARTICIPANT	\N	PRESENT	0
623267	621392	20130U	PARTICIPANT	\N	PRESENT	0
623268	621291	20090E	PARTICIPANT	\N	PRESENT	0
623269	621291	19711U	PARTICIPANT	\N	PRESENT	1
623270	621291	20064C	PARTICIPANT	\N	PRESENT	1
623271	621291	07004J	PARTICIPANT	\N	PRESENT	0
623272	621291	19667J	PRESIDENT	0	PRESENT	0
623273	621291	19671E	PARTICIPANT	\N	PRESENT	1
623274	621291	14249W	PARTICIPANT	\N	PRESENT	0
623275	621291	04085P	PARTICIPANT	\N	PRESENT	0
623276	621392	19689Q	PARTICIPANT	\N	PRESENT	0
623277	621392	14121F	PARTICIPANT	\N	PRESENT	0
623278	621392	19545Y	PARTICIPANT	\N	PRESENT	0
623279	621392	14195A	PARTICIPANT	\N	PRESENT	0
623280	621392	19553Y	PARTICIPANT	\N	PRESENT	0
623281	621392	14275Y	PARTICIPANT	\N	PRESENT	0
623282	621392	14030Q	PARTICIPANT	\N	PRESENT	0
623283	621392	14205J	PARTICIPANT	\N	PRESENT	0
623284	621392	19387D	PARTICIPANT	\N	PRESENT	0
623285	621392	14107H	PARTICIPANT	\N	PRESENT	0
623286	621392	20080C	PARTICIPANT	\N	PRESENT	0
623287	621392	11031D	PARTICIPANT	\N	PRESENT	0
623288	621392	19717B	PARTICIPANT	\N	PRESENT	0
623289	621392	14217N	PARTICIPANT	\N	PRESENT	0
623290	621392	20266L	PARTICIPANT	\N	PRESENT	0
623291	621392	20066E	PARTICIPANT	\N	PRESENT	0
623292	621291	20038A	PARTICIPANT	\N	PRESENT	0
623293	621392	19569H	PARTICIPANT	\N	PRESENT	0
623294	621392	14089Y	PARTICIPANT	\N	PRESENT	0
623295	621392	97011G	PARTICIPANT	\N	PRESENT	0
623296	621392	14055N	PARTICIPANT	\N	PRESENT	0
623297	621392	19383Y	PARTICIPANT	\N	PRESENT	0
623298	621392	14213J	PARTICIPANT	\N	PRESENT	0
623299	621392	20070A	PARTICIPANT	\N	PRESENT	0
623300	621392	19798U	PARTICIPANT	\N	PRESENT	0
623301	621392	20180F	PARTICIPANT	\N	PRESENT	0
623302	621392	04057K	PARTICIPANT	\N	PRESENT	0
623303	621392	11045K	PARTICIPANT	\N	PRESENT	0
623304	621392	19760E	PARTICIPANT	\N	PRESENT	0
623305	621392	11033F	PARTICIPANT	\N	PRESENT	0
623306	621392	19649G	PARTICIPANT	\N	PRESENT	0
623307	621392	20106U	PARTICIPANT	\N	PRESENT	0
623308	621392	20072C	PARTICIPANT	\N	PRESENT	0
623309	621392	19629C	PARTICIPANT	\N	PRESENT	0
623310	621392	20024T	PARTICIPANT	\N	PRESENT	0
623311	621392	14147R	PARTICIPANT	\N	PRESENT	0
623312	621403	19515S	PARTICIPANT	\N	PRESENT	0
623313	621403	20264J	PARTICIPANT	\N	PRESENT	0
623314	621403	14097Y	PARTICIPANT	\N	PRESENT	0
623315	621403	20050V	PARTICIPANT	\N	PRESENT	0
623316	621403	20082E	PRESIDENT	0	PRESENT	0
623317	621403	20074E	PARTICIPANT	\N	PRESENT	1
623318	621392	19467C	PARTICIPANT	\N	PRESENT	0
623319	621392	17965H	PARTICIPANT	\N	PRESENT	0
623320	621291	19531S	PARTICIPANT	\N	PRESENT	0
623321	621392	19349W	PARTICIPANT	\N	PRESENT	0
623322	621392	19758L	PARTICIPANT	\N	PRESENT	0
623323	621392	01028R	PARTICIPANT	\N	PRESENT	0
623324	621392	19697Q	PARTICIPANT	\N	PRESENT	0
623325	621392	17779H	PARTICIPANT	\N	PRESENT	0
623326	621403	19747H	PARTICIPANT	\N	PRESENT	0
623327	621392	11097X	PARTICIPANT	\N	PRESENT	0
623328	621392	19415P	PARTICIPANT	\N	PRESENT	0
623329	621392	19543W	PARTICIPANT	\N	PRESENT	0
623330	621392	19725B	PARTICIPANT	\N	PRESENT	0
623331	621392	14069U	PARTICIPANT	\N	PRESENT	0
623332	621392	04092N	PARTICIPANT	\N	PRESENT	0
623333	621392	01058X	PARTICIPANT	\N	PRESENT	0
623334	621392	17023S	PARTICIPANT	\N	PRESENT	0
623335	621392	19591F	PARTICIPANT	\N	PRESENT	0
623336	621392	19585H	PARTICIPANT	\N	PRESENT	0
623337	621392	20134Y	PARTICIPANT	\N	PRESENT	0
623338	621392	19479G	PARTICIPANT	\N	PRESENT	0
623339	621392	19527W	PARTICIPANT	\N	PRESENT	0
623340	621403	11077T	PARTICIPANT	\N	PRESENT	1
623341	621291	14257W	PARTICIPANT	\N	PRESENT	1
623342	621392	08056B	PARTICIPANT	\N	PRESENT	0
623343	621392	11067R	PARTICIPANT	\N	PRESENT	0
623345	621291	17737W	PARTICIPANT	\N	PRESENT	0
623346	621392	20032T	PARTICIPANT	\N	PRESENT	0
623347	621392	19826F	PARTICIPANT	\N	PRESENT	0
623348	621377	20150Y	PARTICIPANT	\N	PRESENT	0
623349	621377	20034V	PARTICIPANT	\N	EXCUSE	0
623350	621377	20102Q	PARTICIPANT	\N	PRESENT	0
623351	621392	19525U	PARTICIPANT	\N	PRESENT	0
623352	621377	14059S	PARTICIPANT	\N	PRESENT	0
623353	621377	14083S	PRESIDENT	0	PRESENT	0
623354	621392	19715Y	PARTICIPANT	\N	PRESENT	0
623355	621392	19443T	PARTICIPANT	\N	PRESENT	0
623356	621511	19725B	PARTICIPANT	\N	PRESENT	0
623357	621511	04047H	PRESIDENT	0	PRESENT	0
623358	621392	14357A	PARTICIPANT	\N	PRESENT	0
623359	621377	17023S	PARTICIPANT	\N	PRESENT	0
623360	621377	19503N	PARTICIPANT	\N	PRESENT	0
623361	621392	20248J	PARTICIPANT	\N	PRESENT	0
623362	621511	14089Y	PARTICIPANT	\N	PRESENT	0
623363	621511	14147R	PARTICIPANT	\N	PRESENT	0
623364	621511	14069U	PARTICIPANT	\N	PRESENT	0
623365	621511	14215L	PARTICIPANT	\N	PRESENT	0
623366	621392	14033T	PARTICIPANT	\N	PRESENT	0
623367	621392	19723Y	PARTICIPANT	\N	PRESENT	0
623368	621377	04043D	PARTICIPANT	\N	PRESENT	0
623369	621511	14053L	PARTICIPANT	\N	PRESENT	0
623370	621511	11056N	PARTICIPANT	\N	PRESENT	0
623371	621511	19749K	PARTICIPANT	\N	PRESENT	0
623372	621392	20172F	PARTICIPANT	\N	PRESENT	0
623373	621392	19057M	PARTICIPANT	\N	PRESENT	0
623374	621511	20110Q	PARTICIPANT	\N	PRESENT	0
623375	621392	08061X	PARTICIPANT	\N	PRESENT	0
623376	621392	20042V	PARTICIPANT	\N	PRESENT	0
623377	621392	20114U	PARTICIPANT	\N	PRESENT	0
623378	621511	19447X	PARTICIPANT	\N	PRESENT	0
623379	621392	14021P	PARTICIPANT	\N	PRESENT	0
623380	621392	20036X	PARTICIPANT	\N	PRESENT	0
623381	621392	11012A	PARTICIPANT	\N	PRESENT	0
623382	621291	19681G	PARTICIPANT	\N	PRESENT	1
623387	621392	14031R	PARTICIPANT	\N	PRESENT	0
623388	621392	19691J	PARTICIPANT	\N	PRESENT	0
623389	621392	20110Q	PARTICIPANT	\N	PRESENT	0
623390	621392	19347U	PARTICIPANT	\N	PRESENT	0
623391	621392	19749K	PARTICIPANT	\N	PRESENT	0
623392	621392	14207L	PARTICIPANT	\N	PRESENT	0
623394	621377	19447X	PARTICIPANT	\N	EXCUSE	0
623395	623393	14255U	PARTICIPANT	\N	PRESENT	0
623396	623393	14267Y	PARTICIPANT	\N	PRESENT	0
623397	623393	14059S	PARTICIPANT	\N	PRESENT	0
623398	623393	14193X	PARTICIPANT	\N	PRESENT	0
623399	621392	14026U	PARTICIPANT	\N	PRESENT	0
623400	623393	19421M	PARTICIPANT	\N	PRESENT	0
623401	621392	14038Y	PARTICIPANT	\N	PRESENT	0
623402	623393	14083S	PARTICIPANT	\N	PRESENT	0
623403	621377	19717B	PARTICIPANT	\N	EXCUSE	0
623404	621392	10006L	PARTICIPANT	\N	PRESENT	0
623405	621392	19333N	PARTICIPANT	\N	PRESENT	0
623406	621392	20058E	PARTICIPANT	\N	PRESENT	0
623407	621392	11027H	PARTICIPANT	\N	PRESENT	0
623408	621392	01048V	PARTICIPANT	\N	PRESENT	0
623409	621392	14097Y	PARTICIPANT	\N	PRESENT	0
623410	621377	20096L	PARTICIPANT	\N	PRESENT	0
623411	621406	19515S	PARTICIPANT	\N	PRESENT	0
623412	621406	20264J	PARTICIPANT	\N	PRESENT	0
623413	621406	11077T	PARTICIPANT	\N	PRESENT	1
623414	621406	20082E	PRESIDENT	0	PRESENT	0
623415	621406	20050V	PARTICIPANT	\N	PRESENT	0
623416	621406	19747H	PARTICIPANT	\N	PRESENT	0
623417	621406	19693L	PARTICIPANT	\N	PRESENT	0
623418	621392	07029T	PARTICIPANT	\N	PRESENT	0
623419	621392	20128B	PARTICIPANT	\N	PRESENT	0
623420	621392	19745F	PARTICIPANT	\N	PRESENT	0
599679	599678	19333N	PARTICIPANT	\N	PRESENT	0
599683	599681	19333N	PARTICIPANT	\N	PRESENT	0
603185	601486	14331P	PARTICIPANT	\N	EXCUSE	0
603186	601489	14331P	PARTICIPANT	\N	EXCUSE	0
603189	601489	19673G	PARTICIPANT	\N	EXCUSE	0
603190	601486	19673G	PARTICIPANT	\N	EXCUSE	0
610486	608662	20146D	PARTICIPANT	\N	PRESENT	0
610507	608673	19335Q	PARTICIPANT	\N	EXCUSE	0
610508	608673	19671E	PARTICIPANT	\N	EXCUSE	0
610509	608673	04085P	PARTICIPANT	\N	PRESENT	0
610510	608673	20064C	PARTICIPANT	\N	PRESENT	0
610511	608673	20090E	PARTICIPANT	\N	PRESENT	0
610512	608673	19711U	PARTICIPANT	\N	PRESENT	0
610545	610544	05012A	PRESIDENT	0	PRESENT	0
610514	608673	19667J	PRESIDENT	0	PRESENT	0
610546	610544	14257W	PARTICIPANT	\N	PRESENT	0
610547	610544	19333N	PARTICIPANT	\N	PRESENT	0
610548	610544	08010L	PARTICIPANT	\N	PRESENT	0
610549	610544	14229S	PARTICIPANT	\N	PRESENT	0
610550	610544	20062A	PARTICIPANT	\N	PRESENT	0
610520	608673	17737W	PARTICIPANT	\N	EXCUSE	0
610551	610544	19711U	PARTICIPANT	\N	PRESENT	0
610522	608673	14257W	PARTICIPANT	\N	PRESENT	0
610552	610544	20090E	PARTICIPANT	\N	PRESENT	0
610553	610544	14187A	PARTICIPANT	\N	PRESENT	0
610554	610544	19349W	PARTICIPANT	\N	PRESENT	0
610555	610544	20070A	PARTICIPANT	\N	PRESENT	0
610556	610544	20084G	PARTICIPANT	\N	PRESENT	0
610557	610544	19735D	PARTICIPANT	\N	EXCUSE	0
610558	610544	19820Y	PARTICIPANT	\N	EXCUSE	0
610559	610544	14327T	PARTICIPANT	\N	EXCUSE	0
610560	610544	20022R	PARTICIPANT	\N	EXCUSE	0
610561	610544	19335Q	PARTICIPANT	\N	EXCUSE	0
610562	610544	01057W	PARTICIPANT	\N	EXCUSE	0
610563	610544	14217N	PARTICIPANT	\N	EXCUSE	0
610862	610860	19575F	PARTICIPANT	\N	PRESENT	0
610863	610860	14105F	PARTICIPANT	\N	PRESENT	0
610566	610544	19565D	PARTICIPANT	\N	EXCUSE	0
610567	610544	14053L	PARTICIPANT	\N	EXCUSE	0
610568	610544	19782L	PARTICIPANT	\N	EXCUSE	0
610569	610544	19447X	PARTICIPANT	\N	EXCUSE	0
610570	610544	20110Q	PARTICIPANT	\N	EXCUSE	0
610571	610544	04045F	PARTICIPANT	\N	EXCUSE	0
610572	610544	14231L	PARTICIPANT	\N	EXCUSE	0
610861	610860	19631V	PARTICIPANT	\N	PRESENT	0
610864	610860	20152B	PARTICIPANT	\N	PRESENT	0
610865	610860	20024T	PARTICIPANT	\N	PRESENT	0
610866	610860	19629C	PARTICIPANT	\N	PRESENT	0
610867	610860	08028W	PARTICIPANT	\N	PRESENT	0
610868	610860	20134Y	PARTICIPANT	\N	PRESENT	0
610869	610860	19725B	PARTICIPANT	\N	PRESENT	0
610870	610860	20056C	PARTICIPANT	\N	PRESENT	0
610871	610860	14073Q	PARTICIPANT	\N	PRESENT	0
610872	610860	20052X	PARTICIPANT	\N	PRESENT	0
610873	610860	08012N	PARTICIPANT	\N	PRESENT	0
610874	610860	14221J	PARTICIPANT	\N	PRESENT	0
610875	610860	14147R	PARTICIPANT	\N	PRESENT	0
610876	610860	20096L	PARTICIPANT	\N	PRESENT	0
610877	610860	19533U	PARTICIPANT	\N	PRESENT	0
610878	610860	19349W	PARTICIPANT	\N	PRESENT	0
610879	610860	11043H	PARTICIPANT	\N	PRESENT	0
610880	610860	20026V	PARTICIPANT	\N	PRESENT	0
610881	610860	20058E	PARTICIPANT	\N	PRESENT	0
610882	610860	19585H	PARTICIPANT	\N	PRESENT	0
610883	610860	19611R	PARTICIPANT	\N	PRESENT	0
610885	610884	04070G	PARTICIPANT	\N	PRESENT	1
610886	610884	19621T	PARTICIPANT	\N	PRESENT	1
610887	610884	19593H	PARTICIPANT	\N	PRESENT	1
610888	610884	20084G	PARTICIPANT	\N	PRESENT	1
610900	610541	14089Y	PARTICIPANT	\N	PRESENT	0
610901	610541	11083R	PARTICIPANT	\N	PRESENT	0
610902	610541	19725B	PARTICIPANT	\N	PRESENT	0
610903	610541	11026G	PARTICIPANT	\N	PRESENT	0
610904	610541	14331P	PRESIDENT	0	PRESENT	0
610905	610541	10015M	PARTICIPANT	\N	PRESENT	0
610907	610541	04057K	PARTICIPANT	\N	PRESENT	0
610908	610541	14097Y	PARTICIPANT	\N	PRESENT	0
610909	610541	14001X	PARTICIPANT	\N	PRESENT	0
610910	610541	20022R	PARTICIPANT	\N	PRESENT	0
610911	610541	04047H	PARTICIPANT	\N	PRESENT	0
610912	610541	14053L	PARTICIPANT	\N	PRESENT	0
610913	610541	20074E	PARTICIPANT	\N	PRESENT	0
610914	610541	14147R	PARTICIPANT	\N	PRESENT	0
610915	610541	11072N	PARTICIPANT	\N	PRESENT	0
610921	610541	14237S	PARTICIPANT	\N	PRESENT	0
610923	610541	19701S	PARTICIPANT	\N	PRESENT	0
610925	610541	01028R	PARTICIPANT	\N	PRESENT	0
610927	610541	14151M	PARTICIPANT	\N	PRESENT	0
610929	610541	19563B	PARTICIPANT	\N	PRESENT	0
610930	610541	14231L	PARTICIPANT	\N	PRESENT	0
610937	610541	19441R	PARTICIPANT	\N	PRESENT	0
610939	610541	19711U	PARTICIPANT	\N	PRESENT	0
610945	610541	14111D	PARTICIPANT	\N	PRESENT	0
610970	610541	08034U	PARTICIPANT	\N	PRESENT	0
611263	611262	14331P	PARTICIPANT	\N	PRESENT	0
611264	611262	14001X	PARTICIPANT	\N	PRESENT	0
611265	611262	11083R	PARTICIPANT	\N	PRESENT	0
612008	612007	14255U	PARTICIPANT	\N	PRESENT	0
612009	612007	19545Y	PARTICIPANT	\N	PRESENT	0
612010	612007	18083K	PARTICIPANT	\N	PRESENT	0
612011	612007	20120S	PARTICIPANT	\N	PRESENT	0
612012	612007	08009T	PARTICIPANT	\N	PRESENT	0
612013	612007	14221J	PARTICIPANT	\N	PRESENT	0
612014	612007	05012A	PARTICIPANT	\N	PRESENT	0
613400	613068	14327T	PRESIDENT	0	PRESENT	0
613401	613068	11048N	PARTICIPANT	\N	PRESENT	0
613402	613068	01048V	PARTICIPANT	\N	PRESENT	0
613403	613068	19687N	PARTICIPANT	\N	PRESENT	0
613404	613068	20080C	PARTICIPANT	\N	PRESENT	0
613405	613068	11053K	PARTICIPANT	\N	PRESENT	0
613406	613068	14121F	PARTICIPANT	\N	PRESENT	0
613407	613068	99004R	PARTICIPANT	\N	PRESENT	0
613408	613068	14253S	PARTICIPANT	\N	PRESENT	0
613409	613068	20044X	PARTICIPANT	\N	PRESENT	0
613410	613068	19762G	PARTICIPANT	\N	PRESENT	0
613411	613068	19689Q	PARTICIPANT	\N	PRESENT	0
613412	613305	12041X	PARTICIPANT	\N	PRESENT	0
613413	613068	19711U	PARTICIPANT	\N	PRESENT	0
613414	613068	14173T	PARTICIPANT	\N	PRESENT	0
613415	613068	08010L	PARTICIPANT	\N	PRESENT	0
613416	613068	19741B	PARTICIPANT	\N	PRESENT	0
613417	613068	20116W	PARTICIPANT	\N	PRESENT	0
613418	613068	20086J	PARTICIPANT	\N	PRESENT	0
613419	613068	14189C	PARTICIPANT	\N	PRESENT	0
613420	613068	08034U	PARTICIPANT	\N	PRESENT	0
613421	613305	20030R	PARTICIPANT	\N	PRESENT	0
613422	613305	14030Q	PARTICIPANT	\N	PRESENT	0
613423	613305	20052X	PARTICIPANT	\N	PRESENT	0
613424	612406	20130U	PARTICIPANT	\N	PRESENT	0
613425	612406	11067R	PARTICIPANT	\N	PRESENT	0
613426	612406	20090E	PARTICIPANT	\N	PRESENT	0
613427	612406	19798U	PARTICIPANT	\N	PRESENT	0
613428	612406	11097X	PARTICIPANT	\N	PRESENT	0
613429	612406	19415P	PARTICIPANT	\N	PRESENT	0
613430	612406	20148F	PARTICIPANT	\N	PRESENT	0
613431	612406	19553Y	PARTICIPANT	\N	PRESENT	0
613432	612406	19703U	PARTICIPANT	\N	PRESENT	0
613433	612406	20248J	PARTICIPANT	\N	PRESENT	0
613434	612406	14042U	PARTICIPANT	\N	PRESENT	0
613435	612406	14213J	PARTICIPANT	\N	PRESENT	0
613436	612406	19657G	PARTICIPANT	\N	PRESENT	0
613437	612406	14217N	PARTICIPANT	\N	PRESENT	0
613438	612406	10006L	PRESIDENT	0	PRESENT	0
613439	612406	19683J	PARTICIPANT	\N	PRESENT	0
613440	613305	19768N	PARTICIPANT	\N	PRESENT	0
613441	613305	14031R	PARTICIPANT	\N	PRESENT	0
613442	613305	19565D	PARTICIPANT	\N	PRESENT	0
613443	613068	14083S	PARTICIPANT	\N	PRESENT	0
613444	613305	19573D	PARTICIPANT	\N	PRESENT	0
613445	613305	19531S	PARTICIPANT	\N	PRESENT	0
613446	613305	01025N	PARTICIPANT	\N	PRESENT	0
613447	612406	04057K	PARTICIPANT	\N	PRESENT	0
613448	612406	20040T	PARTICIPANT	\N	PRESENT	0
613449	612406	18193Q	PARTICIPANT	\N	PRESENT	0
613450	612406	19295A	PARTICIPANT	\N	EXCUSE	0
613451	613305	04057K	PARTICIPANT	\N	PRESENT	0
613452	613305	19637C	PARTICIPANT	\N	PRESENT	0
613453	613305	11066Q	PARTICIPANT	\N	PRESENT	0
613454	613068	14225N	PARTICIPANT	\N	EXCUSE	0
613457	613305	14189C	PARTICIPANT	\N	PRESENT	0
613458	613305	14259Y	PARTICIPANT	\N	PRESENT	0
616355	616349	19713W	PARTICIPANT	\N	PRESENT	0
616356	616350	19713W	PARTICIPANT	\N	PRESENT	0
616357	616351	19713W	PARTICIPANT	\N	PRESENT	0
616358	616353	19713W	PARTICIPANT	\N	PRESENT	0
616359	616352	19713W	PARTICIPANT	\N	PRESENT	0
616360	616354	19713W	PARTICIPANT	\N	PRESENT	0
620527	618363	19479G	PARTICIPANT	\N	PRESENT	0
620528	618363	19711U	PARTICIPANT	\N	PRESENT	0
620529	618363	14357A	PARTICIPANT	\N	PRESENT	0
620530	618363	01057W	PARTICIPANT	\N	PRESENT	0
620531	618363	20070A	PARTICIPANT	\N	PRESENT	0
620532	618363	11053K	PARTICIPANT	\N	PRESENT	0
620533	618363	99004R	PARTICIPANT	\N	PRESENT	0
620534	618363	20128B	PARTICIPANT	\N	PRESENT	0
620535	618412	19741B	PARTICIPANT	\N	PRESENT	0
620536	618412	14249W	PARTICIPANT	\N	PRESENT	0
620537	618412	14257W	PARTICIPANT	\N	PRESENT	0
620620	620619	14089Y	PARTICIPANT	\N	PRESENT	0
620621	620619	19749K	PARTICIPANT	\N	PRESENT	0
620622	620619	20024T	PARTICIPANT	\N	PRESENT	0
620623	618091	19489J	PARTICIPANT	\N	PRESENT	0
620624	618091	17637T	PARTICIPANT	\N	PRESENT	0
620625	618091	08018U	PARTICIPANT	\N	PRESENT	0
620626	618363	14097Y	PARTICIPANT	\N	PRESENT	0
620627	618363	19647E	PARTICIPANT	\N	PRESENT	1
620628	618363	19349W	PARTICIPANT	\N	PRESENT	1
620629	618363	14121F	PARTICIPANT	\N	PRESENT	1
620630	618363	19335Q	PARTICIPANT	\N	PRESENT	1
620631	618091	19798U	PARTICIPANT	\N	PRESENT	0
620632	618091	14237S	PARTICIPANT	\N	PRESENT	0
620674	618091	20044X	PARTICIPANT	\N	PRESENT	0
620634	618091	19713W	PARTICIPANT	\N	PRESENT	0
620635	618091	20066E	PARTICIPANT	\N	PRESENT	0
620636	618363	08010L	PARTICIPANT	\N	EXCUSE	0
620637	618091	14193X	PARTICIPANT	\N	PRESENT	0
620649	618091	20084G	PARTICIPANT	\N	PRESENT	0
620665	618091	14179A	PARTICIPANT	\N	PRESENT	0
620666	618317	19533U	PRESIDENT	0	PRESENT	0
620667	618317	19798U	PARTICIPANT	\N	PRESENT	0
620668	618317	19820Y	PARTICIPANT	\N	PRESENT	0
620669	618317	20114U	PARTICIPANT	\N	PRESENT	0
620670	618317	14207L	PARTICIPANT	\N	PRESENT	0
620671	618317	17023S	PARTICIPANT	\N	PRESENT	0
620672	618317	04045F	PARTICIPANT	\N	EXCUSE	0
620675	618091	20150Y	PARTICIPANT	\N	PRESENT	0
621306	621215	20066E	PARTICIPANT	\N	PRESENT	1
621427	621426	20032T	PARTICIPANT	\N	PRESENT	0
621428	621426	20024T	PARTICIPANT	\N	PRESENT	0
621429	621426	19954N	PARTICIPANT	\N	PRESENT	0
621430	621426	19575F	PARTICIPANT	\N	PRESENT	0
621431	621426	14069U	PARTICIPANT	\N	PRESENT	0
621432	621426	20088L	PARTICIPANT	\N	PRESENT	0
621433	621426	19383Y	PARTICIPANT	\N	PRESENT	0
621434	621426	20090E	PARTICIPANT	\N	PRESENT	0
621435	621426	14207L	PARTICIPANT	\N	PRESENT	0
621436	621426	14083S	PARTICIPANT	\N	PRESENT	0
621437	621426	19467C	PARTICIPANT	\N	PRESENT	0
621438	621426	18083K	PARTICIPANT	\N	PRESENT	0
621439	621426	19507S	PARTICIPANT	\N	PRESENT	0
621440	621426	20174H	PARTICIPANT	\N	PRESENT	0
621441	621426	14033T	PARTICIPANT	\N	PRESENT	0
621442	621426	14213J	PARTICIPANT	\N	PRESENT	0
621443	621426	19511N	PARTICIPANT	\N	PRESENT	0
621444	621426	20126Y	PARTICIPANT	\N	PRESENT	0
621445	621426	19637C	PARTICIPANT	\N	PRESENT	0
621446	621426	20018V	PARTICIPANT	\N	PRESENT	0
621447	621426	14257W	PARTICIPANT	\N	PRESENT	0
621448	621426	20118Y	PARTICIPANT	\N	PRESENT	0
621449	621426	20082E	PARTICIPANT	\N	PRESENT	0
621450	621426	20054A	PARTICIPANT	\N	PRESENT	0
621451	621426	11097X	PARTICIPANT	\N	PRESENT	0
621452	621426	04045F	PARTICIPANT	\N	PRESENT	0
621453	621426	20062A	PARTICIPANT	\N	PRESENT	0
621454	621426	20084G	PARTICIPANT	\N	PRESENT	0
621455	621426	14030Q	PARTICIPANT	\N	PRESENT	0
621456	621426	20180F	PARTICIPANT	\N	PRESENT	0
621459	621457	19507S	PARTICIPANT	\N	PRESENT	0
621460	621457	19413M	PARTICIPANT	\N	PRESENT	0
621461	621457	20088L	PARTICIPANT	\N	PRESENT	0
621463	621462	19507S	PARTICIPANT	\N	PRESENT	0
621464	621462	19413M	PARTICIPANT	\N	PRESENT	0
621465	621462	20088L	PARTICIPANT	\N	PRESENT	0
621467	621466	19507S	PARTICIPANT	\N	PRESENT	0
621468	621466	19782L	PARTICIPANT	\N	PRESENT	0
621469	621466	20088L	PARTICIPANT	\N	PRESENT	0
621470	621466	14033T	PARTICIPANT	\N	PRESENT	0
621472	621471	14033T	PARTICIPANT	\N	PRESENT	0
621473	621471	20088L	PARTICIPANT	\N	PRESENT	0
621474	621471	19507S	PARTICIPANT	\N	PRESENT	0
621475	621471	19782L	PARTICIPANT	\N	PRESENT	0
621476	621471	20030R	PARTICIPANT	\N	PRESENT	0
621477	621471	19531S	PARTICIPANT	\N	PRESENT	0
621479	621478	19507S	PARTICIPANT	\N	PRESENT	0
621480	621478	20088L	PARTICIPANT	\N	PRESENT	0
621481	621478	14033T	PARTICIPANT	\N	PRESENT	0
621482	621478	20018V	PARTICIPANT	\N	PRESENT	0
621483	621478	19782L	PARTICIPANT	\N	PRESENT	0
621484	621478	20030R	PARTICIPANT	\N	PRESENT	0
621485	621478	19531S	PARTICIPANT	\N	PRESENT	0
621487	621486	19507S	PARTICIPANT	\N	PRESENT	0
621488	621486	19782L	PARTICIPANT	\N	PRESENT	0
621489	621486	20088L	PARTICIPANT	\N	PRESENT	0
621490	621486	20030R	PARTICIPANT	\N	PRESENT	0
621492	621491	19507S	PARTICIPANT	\N	PRESENT	0
621493	621491	19782L	PARTICIPANT	\N	PRESENT	0
621494	621491	20088L	PARTICIPANT	\N	PRESENT	0
621495	621491	20030R	PARTICIPANT	\N	PRESENT	0
621497	621496	14033T	PARTICIPANT	\N	PRESENT	0
621498	621496	19507S	PARTICIPANT	\N	PRESENT	0
621499	621496	19782L	PARTICIPANT	\N	PRESENT	0
621500	621496	20030R	PARTICIPANT	\N	PRESENT	0
621504	621503	20140W	PARTICIPANT	\N	PRESENT	0
621505	621312	11101A	PARTICIPANT	\N	PRESENT	0
621506	621312	19703U	PARTICIPANT	\N	PRESENT	0
621545	621507	04092N	PARTICIPANT	\N	PRESENT	0
621546	621507	11097X	PARTICIPANT	\N	PRESENT	0
621547	621507	19663E	PARTICIPANT	\N	PRESENT	0
621548	621507	19657G	PARTICIPANT	\N	PRESENT	0
621549	621507	10006L	PRESIDENT	0	PRESENT	0
621550	621507	20090E	PARTICIPANT	\N	PRESENT	1
621551	621507	01034P	PARTICIPANT	\N	PRESENT	1
621552	621507	14355X	PARTICIPANT	\N	PRESENT	1
621553	621507	19798U	PARTICIPANT	\N	PRESENT	1
621554	621507	19713W	PARTICIPANT	\N	PRESENT	1
621555	621507	19569H	PARTICIPANT	\N	PRESENT	1
621556	621507	11045K	PARTICIPANT	\N	PRESENT	1
621557	621507	19415P	PARTICIPANT	\N	PRESENT	1
621558	621507	19691J	PARTICIPANT	\N	PRESENT	1
621559	621507	19723Y	PARTICIPANT	\N	PRESENT	1
621560	621507	20248J	PARTICIPANT	\N	PRESENT	1
621561	621507	20066E	PARTICIPANT	\N	PRESENT	1
621562	621507	11103C	PARTICIPANT	\N	PRESENT	1
621563	621507	04043D	PARTICIPANT	\N	PRESENT	1
621564	621507	19683J	PARTICIPANT	\N	PRESENT	1
621584	621410	95063L	PARTICIPANT	\N	PRESENT	0
621585	621410	20108W	PARTICIPANT	\N	PRESENT	0
621586	621410	19543W	PARTICIPANT	\N	PRESENT	0
621587	621410	14215L	PARTICIPANT	\N	PRESENT	0
621588	621410	08018U	PARTICIPANT	\N	PRESENT	0
621589	621410	04047H	PRESIDENT	0	PRESENT	0
621590	621410	19749K	PARTICIPANT	\N	PRESENT	0
621591	621410	10006L	PARTICIPANT	\N	PRESENT	0
610612	610610	11083R	PARTICIPANT	\N	PRESENT	0
610613	610611	11083R	PARTICIPANT	\N	PRESENT	0
610616	610614	11083R	PARTICIPANT	\N	PRESENT	0
612412	610740	14053L	PARTICIPANT	\N	EXCUSE	0
612413	610741	14053L	PARTICIPANT	\N	EXCUSE	0
612485	612482	19760E	PARTICIPANT	\N	PRESENT	0
612486	612482	19367Y	PARTICIPANT	\N	PRESENT	0
612487	612482	19415P	PARTICIPANT	\N	PRESENT	0
612488	612482	20090E	PARTICIPANT	\N	PRESENT	0
612489	612482	11103C	PARTICIPANT	\N	PRESENT	0
612490	612482	14195A	PARTICIPANT	\N	PRESENT	0
612491	612482	11031D	PARTICIPANT	\N	PRESENT	0
612492	612482	19663E	PARTICIPANT	0	PRESENT	0
612493	612482	10006L	PRESIDENT	0	PRESENT	0
612494	612482	14217N	PARTICIPANT	\N	PRESENT	0
612495	612482	20248J	PARTICIPANT	\N	PRESENT	0
612500	612482	20172F	PARTICIPANT	\N	PRESENT	0
612498	612482	14042U	PARTICIPANT	\N	PRESENT	0
612499	612482	08045X	PARTICIPANT	\N	PRESENT	0
612502	612482	19691J	PARTICIPANT	\N	PRESENT	0
612503	612482	19553Y	PARTICIPANT	\N	PRESENT	0
612504	612482	19569H	PARTICIPANT	\N	PRESENT	0
612505	612482	19591F	PARTICIPANT	\N	PRESENT	0
612507	612482	20066E	PARTICIPANT	\N	PRESENT	0
612508	612482	14213J	PARTICIPANT	\N	PRESENT	0
612509	612482	14026U	PARTICIPANT	\N	PRESENT	0
612512	612482	19723Y	PARTICIPANT	\N	PRESENT	0
612513	612482	18193Q	PARTICIPANT	\N	PRESENT	0
612515	612482	17779H	PARTICIPANT	\N	PRESENT	0
612517	612482	19697Q	PARTICIPANT	\N	PRESENT	0
612519	612482	11067R	PARTICIPANT	\N	PRESENT	0
612521	612482	14223L	PARTICIPANT	\N	PRESENT	0
612522	612482	14071N	PARTICIPANT	\N	PRESENT	0
612523	612482	01034P	PARTICIPANT	\N	PRESENT	0
612524	612482	19713W	PARTICIPANT	\N	PRESENT	0
612526	612482	19703U	PARTICIPANT	\N	PRESENT	0
612527	612482	11097X	PARTICIPANT	\N	PRESENT	0
612528	612482	11045K	PARTICIPANT	\N	PRESENT	0
612529	612482	19679N	PARTICIPANT	\N	PRESENT	0
612530	612482	19798U	PARTICIPANT	\N	PRESENT	0
612531	612482	04043D	PARTICIPANT	\N	PRESENT	0
612532	612482	17965H	PARTICIPANT	\N	PRESENT	0
612533	612482	20130U	PARTICIPANT	\N	PRESENT	0
614006	612794	07004J	PARTICIPANT	\N	PRESENT	0
614007	612794	19629C	PARTICIPANT	\N	PRESENT	0
614008	612794	04047H	PRESIDENT	0	PRESENT	0
614009	612794	14215L	PARTICIPANT	\N	PRESENT	0
614010	612794	19954N	PARTICIPANT	\N	PRESENT	0
614011	612794	19543W	PARTICIPANT	\N	PRESENT	0
614012	612794	14111D	PARTICIPANT	\N	PRESENT	0
614013	612794	10015M	PARTICIPANT	\N	PRESENT	0
614014	612794	14021P	PARTICIPANT	\N	PRESENT	0
614016	612794	14151M	PARTICIPANT	\N	PRESENT	0
614019	612794	19447X	PARTICIPANT	\N	PRESENT	0
614023	612794	20022R	PARTICIPANT	\N	PRESENT	0
614024	612794	19585H	PARTICIPANT	\N	PRESENT	0
614035	612794	20128B	PARTICIPANT	\N	PRESENT	0
614036	612794	14053L	PARTICIPANT	\N	PRESENT	0
614037	612794	14089Y	PARTICIPANT	\N	PRESENT	0
614046	612794	95063L	PARTICIPANT	\N	PRESENT	0
614043	612794	14001X	PARTICIPANT	\N	PRESENT	0
614044	612794	19489J	PARTICIPANT	\N	PRESENT	0
614047	612794	20110Q	PARTICIPANT	\N	PRESENT	0
616035	610746	19577H	PARTICIPANT	\N	PRESENT	1
618327	618181	10006L	PARTICIPANT	\N	PRESENT	0
618328	618181	19713W	PARTICIPANT	\N	PRESENT	0
618329	618181	14147R	PARTICIPANT	\N	PRESENT	0
618330	618181	19723Y	PARTICIPANT	\N	PRESENT	0
618331	618181	20130U	PARTICIPANT	\N	PRESENT	1
618332	618181	19301E	PARTICIPANT	\N	PRESENT	1
618333	618181	19703U	PARTICIPANT	\N	PRESENT	1
618334	618181	19735D	PARTICIPANT	\N	PRESENT	1
618335	618204	19723Y	PARTICIPANT	\N	PRESENT	0
618336	618204	10006L	PARTICIPANT	\N	PRESENT	0
618337	618204	19703U	PARTICIPANT	\N	PRESENT	1
618338	618204	19735D	PARTICIPANT	\N	PRESENT	1
618339	618204	14147R	PARTICIPANT	\N	PRESENT	1
618340	618204	20130U	PARTICIPANT	\N	PRESENT	1
618341	618203	19735D	PARTICIPANT	\N	PRESENT	1
618342	618203	19723Y	PARTICIPANT	\N	PRESENT	0
618343	618203	20130U	PARTICIPANT	\N	PRESENT	1
618344	618203	10006L	PARTICIPANT	\N	PRESENT	0
618345	618203	14147R	PARTICIPANT	\N	PRESENT	1
618346	618201	10006L	PARTICIPANT	\N	PRESENT	0
618347	618201	20130U	PARTICIPANT	\N	PRESENT	0
618348	618201	19735D	PARTICIPANT	\N	PRESENT	0
618349	618201	14147R	PARTICIPANT	\N	PRESENT	1
618350	618201	19723Y	PARTICIPANT	\N	PRESENT	0
618836	618834	04070G	PARTICIPANT	\N	PRESENT	0
618838	618834	14169X	PARTICIPANT	\N	PRESENT	0
618839	618217	19701S	PARTICIPANT	\N	PRESENT	0
618840	618217	11026G	PARTICIPANT	\N	PRESENT	0
618841	618219	19701S	PARTICIPANT	\N	PRESENT	0
618842	618219	11026G	PARTICIPANT	\N	PRESENT	0
618858	618856	04059M	PARTICIPANT	\N	PRESENT	0
618859	618856	19651A	PARTICIPANT	\N	PRESENT	1
618860	618856	11053K	PARTICIPANT	\N	PRESENT	1
618861	618856	19725B	PARTICIPANT	\N	PRESENT	0
618862	618856	19611R	PRESIDENT	0	PRESENT	0
618863	618856	20122U	PARTICIPANT	\N	EXCUSE	0
618864	618856	20026V	PARTICIPANT	\N	PRESENT	1
618865	618856	14229S	PARTICIPANT	\N	PRESENT	0
618866	618856	19705W	PARTICIPANT	\N	PRESENT	1
618867	618856	20142Y	PARTICIPANT	\N	PRESENT	0
618868	618856	12041X	PARTICIPANT	\N	PRESENT	0
618869	618856	19699S	PRESIDENT	1	PRESENT	0
621106	621066	19447X	PARTICIPANT	\N	PRESENT	0
621107	621066	14257W	PARTICIPANT	\N	PRESENT	0
621108	621066	20058E	PARTICIPANT	\N	PRESENT	0
623866	617182	19717B	PRESIDENT	0	PRESENT	0
623867	617182	18083K	PARTICIPANT	\N	PRESENT	1
623868	617182	19659J	PARTICIPANT	\N	PRESENT	0
623869	617182	17023S	PARTICIPANT	\N	PRESENT	0
623870	617182	20034V	PARTICIPANT	\N	PRESENT	1
623871	617182	14219Q	PARTICIPANT	\N	PRESENT	0
623872	617182	14059S	PARTICIPANT	\N	PRESENT	0
623873	617182	14147R	PARTICIPANT	\N	PRESENT	1
623930	617182	20148F	PARTICIPANT	\N	PRESENT	1
623931	617182	20146D	PARTICIPANT	\N	PRESENT	1
623932	617182	20150Y	PARTICIPANT	\N	EXCUSE	0
627356	626863	01058X	PARTICIPANT	\N	PRESENT	0
627357	626651	20070A	PARTICIPANT	\N	PRESENT	0
627358	626863	19383Y	PARTICIPANT	\N	PRESENT	0
627359	626651	19349W	PARTICIPANT	\N	PRESENT	0
627360	626885	20038A	PARTICIPANT	\N	PRESENT	0
627361	626885	19511N	PARTICIPANT	\N	PRESENT	0
627362	626887	20124W	PARTICIPANT	\N	PRESENT	1
627363	626863	19563B	PARTICIPANT	\N	PRESENT	0
627364	626863	05012A	PARTICIPANT	\N	PRESENT	0
627365	626863	14053L	PARTICIPANT	\N	PRESENT	0
627366	626795	04092N	PARTICIPANT	\N	PRESENT	1
627367	626651	04071H	PARTICIPANT	\N	PRESENT	0
627296	627295	20022R	PARTICIPANT	\N	PRESENT	0
627297	627295	20110Q	PARTICIPANT	\N	PRESENT	0
627341	626651	14327T	PARTICIPANT	\N	PRESENT	0
627342	626651	19479G	PARTICIPANT	\N	PRESENT	0
627343	626651	11048N	PARTICIPANT	\N	PRESENT	0
627344	626651	19711U	PARTICIPANT	\N	PRESENT	0
627345	626651	01048V	PARTICIPANT	\N	PRESENT	0
627346	626651	20080C	PARTICIPANT	\N	PRESENT	0
627347	626651	20044X	PARTICIPANT	\N	PRESENT	0
627348	626651	14225N	PRESIDENT	0	PRESENT	0
627349	626651	11070L	PARTICIPANT	\N	PRESENT	0
627350	626651	19671E	PARTICIPANT	\N	PRESENT	0
627351	626651	14083S	PARTICIPANT	\N	PRESENT	0
627352	626651	08009T	PARTICIPANT	\N	PRESENT	0
627353	626651	19741B	PARTICIPANT	\N	PRESENT	0
627354	626651	14253S	PARTICIPANT	\N	PRESENT	0
627355	626651	07029T	PARTICIPANT	\N	EXCUSE	0
627368	626651	19647E	PARTICIPANT	\N	PRESENT	0
627369	626651	01057W	PARTICIPANT	\N	PRESENT	0
627370	626651	08010L	PARTICIPANT	\N	PRESENT	0
627371	626651	19335Q	PARTICIPANT	\N	PRESENT	0
627372	626863	19251M	PARTICIPANT	\N	PRESENT	0
627373	626863	14237S	PARTICIPANT	\N	PRESENT	0
627374	626651	19687N	PARTICIPANT	\N	PRESENT	0
627375	626863	14121F	PARTICIPANT	\N	PRESENT	0
627376	626863	20076G	PARTICIPANT	\N	PRESENT	0
627377	626795	19301E	PARTICIPANT	\N	PRESENT	1
627378	626795	14223L	PARTICIPANT	\N	PRESENT	1
627380	627379	14083S	PRESIDENT	0	PRESENT	0
623500	621393	19697Q	PARTICIPANT	\N	PRESENT	0
623501	621393	08012N	PARTICIPANT	\N	PRESENT	0
623503	621393	20134Y	PARTICIPANT	\N	PRESENT	0
623504	621393	19347U	PARTICIPANT	\N	PRESENT	0
623498	621393	01043Q	PARTICIPANT	\N	PRESENT	0
623499	621393	11043H	PARTICIPANT	\N	PRESENT	0
623505	621393	20114U	PARTICIPANT	\N	PRESENT	0
623506	621393	20070A	PARTICIPANT	\N	PRESENT	0
623507	621393	20080C	PARTICIPANT	\N	PRESENT	0
623508	621393	07029T	PARTICIPANT	\N	PRESENT	0
623509	621393	20180F	PARTICIPANT	\N	PRESENT	0
623510	621393	19467C	PARTICIPANT	\N	PRESENT	0
623511	621393	19447X	PARTICIPANT	\N	PRESENT	0
623512	621393	14030Q	PARTICIPANT	\N	PRESENT	0
623513	621393	20066E	PARTICIPANT	\N	PRESENT	0
623514	621393	20106U	PARTICIPANT	\N	PRESENT	0
623515	621393	20128B	PARTICIPANT	\N	PRESENT	0
623516	621393	19387D	PARTICIPANT	\N	PRESENT	0
623517	621393	19585H	PARTICIPANT	\N	PRESENT	0
623518	621393	20052X	PARTICIPANT	\N	PRESENT	0
623519	621393	19745F	PARTICIPANT	\N	PRESENT	0
623520	621393	19715Y	PARTICIPANT	\N	PRESENT	0
623521	621393	14097Y	PARTICIPANT	\N	PRESENT	0
623522	621393	14257W	PARTICIPANT	\N	PRESENT	0
623523	621393	19725B	PARTICIPANT	\N	PRESENT	0
623524	621393	11031D	PARTICIPANT	\N	PRESENT	0
623525	621393	19760E	PARTICIPANT	\N	PRESENT	0
623526	621393	19349W	PARTICIPANT	\N	PRESENT	0
623527	621393	19758L	PARTICIPANT	\N	PRESENT	0
623528	621393	20112S	PARTICIPANT	\N	PRESENT	0
623529	621393	14357A	PARTICIPANT	\N	PRESENT	0
623530	621393	19533U	PARTICIPANT	\N	PRESENT	0
623531	621393	14215L	PARTICIPANT	\N	PRESENT	0
623532	621393	14031R	PARTICIPANT	\N	PRESENT	0
623533	621393	11097X	PARTICIPANT	\N	PRESENT	0
623534	621393	20058E	PARTICIPANT	\N	PRESENT	0
623535	621393	14053L	PARTICIPANT	\N	PRESENT	0
623536	621393	14038Y	PARTICIPANT	\N	PRESENT	0
623537	621393	97011G	PARTICIPANT	\N	PRESENT	0
623538	621393	04047H	PARTICIPANT	\N	PRESENT	0
623539	621393	14059S	PARTICIPANT	\N	PRESENT	0
623540	621393	19399H	PARTICIPANT	\N	PRESENT	0
623541	621393	19527W	PARTICIPANT	\N	PRESENT	0
623542	621393	11090Q	PARTICIPANT	\N	PRESENT	0
623543	621393	20056C	PARTICIPANT	\N	PRESENT	0
623544	621393	20152B	PARTICIPANT	\N	PRESENT	0
623545	621393	14217N	PARTICIPANT	\N	PRESENT	0
623546	621393	20090E	PARTICIPANT	\N	PRESENT	0
623547	621393	11048N	PARTICIPANT	\N	PRESENT	0
623548	621393	14107H	PARTICIPANT	\N	PRESENT	0
623549	621393	19701S	PARTICIPANT	\N	PRESENT	0
623550	621393	20102Q	PARTICIPANT	\N	PRESENT	0
623551	621393	14083S	PARTICIPANT	\N	PRESENT	0
623552	621393	20024T	PARTICIPANT	\N	PRESENT	0
623553	621393	08010L	PARTICIPANT	\N	PRESENT	0
623554	621393	11056N	PARTICIPANT	\N	PRESENT	0
623555	621393	08034U	PARTICIPANT	\N	PRESENT	0
623556	621393	20124W	PARTICIPANT	\N	PRESENT	0
623557	621393	17965H	PARTICIPANT	\N	PRESENT	0
623558	621393	19441R	PARTICIPANT	\N	PRESENT	0
623559	621393	11040E	PARTICIPANT	\N	PRESENT	0
623560	621393	14026U	PARTICIPANT	\N	PRESENT	0
623561	621393	19443T	PARTICIPANT	\N	PRESENT	0
623562	621393	20142Y	PARTICIPANT	\N	PRESENT	0
623563	621393	14229S	PARTICIPANT	\N	PRESENT	0
623564	621393	20082E	PARTICIPANT	\N	PRESENT	0
623565	621393	08018U	PARTICIPANT	\N	PRESENT	0
623566	621393	19611R	PARTICIPANT	\N	PRESENT	0
623567	621393	20072C	PARTICIPANT	\N	PRESENT	0
623589	621393	14147R	PARTICIPANT	\N	PRESENT	0
623590	621393	19747H	PARTICIPANT	\N	PRESENT	0
623591	621393	14231L	PARTICIPANT	\N	PRESENT	0
623592	621393	19723Y	PARTICIPANT	\N	PRESENT	0
623593	621393	07004J	PARTICIPANT	\N	PRESENT	0
623595	621393	19629C	PARTICIPANT	\N	PRESENT	0
623596	621393	19621T	PARTICIPANT	\N	PRESENT	0
623597	621393	14207L	PARTICIPANT	\N	PRESENT	0
623656	621395	11043H	PARTICIPANT	\N	PRESENT	0
623657	621395	19747H	PARTICIPANT	\N	PRESENT	0
623658	621395	14031R	PARTICIPANT	\N	PRESENT	0
623659	621395	19399H	PARTICIPANT	\N	PRESENT	0
623660	621395	19349W	PARTICIPANT	\N	PRESENT	0
623661	621395	19760E	PARTICIPANT	\N	PRESENT	0
623662	621395	20134Y	PARTICIPANT	\N	PRESENT	0
623663	621395	19527W	PARTICIPANT	\N	PRESENT	0
623664	621395	08012N	PARTICIPANT	\N	PRESENT	0
623665	621395	19629C	PARTICIPANT	\N	PRESENT	0
623666	621395	19585H	PARTICIPANT	\N	PRESENT	0
623667	621395	19387D	PARTICIPANT	\N	PRESENT	0
623668	621395	14107H	PARTICIPANT	\N	PRESENT	0
623669	621395	14207L	PARTICIPANT	\N	PRESENT	0
623670	621395	19611R	PARTICIPANT	\N	PRESENT	0
623671	621395	19758L	PARTICIPANT	\N	PRESENT	0
623672	621395	20102Q	PARTICIPANT	\N	PRESENT	0
623673	621395	20152B	PARTICIPANT	\N	PRESENT	0
623674	621395	14147R	PARTICIPANT	\N	PRESENT	0
623675	621395	19533U	PARTICIPANT	\N	PRESENT	0
623676	621395	14073Q	PARTICIPANT	\N	PRESENT	0
623677	621395	20052X	PARTICIPANT	\N	PRESENT	0
623678	621395	19467C	PARTICIPANT	\N	PRESENT	0
623679	621395	11065P	PARTICIPANT	\N	PRESENT	0
623680	621395	20180F	PARTICIPANT	\N	PRESENT	0
623681	621395	20024T	PARTICIPANT	\N	PRESENT	0
623682	621395	14083S	PARTICIPANT	\N	PRESENT	0
623683	621395	20106U	PARTICIPANT	\N	PRESENT	0
623684	621395	19719D	PARTICIPANT	\N	PRESENT	0
623685	621395	14215L	PARTICIPANT	\N	PRESENT	0
623686	621395	14357A	PARTICIPANT	\N	PRESENT	0
623687	621395	20128B	PARTICIPANT	\N	PRESENT	0
623688	621395	19503N	PARTICIPANT	\N	PRESENT	0
623689	621395	20048C	PARTICIPANT	\N	PRESENT	0
623697	621395	20058E	PARTICIPANT	\N	PRESENT	0
624111	624110	19599P	PARTICIPANT	\N	PRESENT	0
624112	624110	19685L	PARTICIPANT	\N	PRESENT	0
624113	622041	19599P	PARTICIPANT	\N	PRESENT	0
624114	622041	19685L	PARTICIPANT	\N	PRESENT	0
624115	622048	19599P	PARTICIPANT	\N	PRESENT	0
624116	622048	19685L	PARTICIPANT	\N	PRESENT	0
624120	624119	19599P	PARTICIPANT	\N	PRESENT	0
624121	624119	19685L	PARTICIPANT	\N	PRESENT	0
624124	624123	20024T	PARTICIPANT	\N	PRESENT	0
624125	624123	19685L	PARTICIPANT	\N	PRESENT	0
624179	624178	04047H	PARTICIPANT	\N	PRESENT	0
624180	624178	14053L	PARTICIPANT	\N	PRESENT	0
624181	624178	14299H	PARTICIPANT	\N	PRESENT	0
624191	624138	20066E	PARTICIPANT	\N	PRESENT	1
624190	624188	20066E	PARTICIPANT	\N	PRESENT	1
624192	624138	19691J	PARTICIPANT	\N	PRESENT	1
624193	621787	19569H	PARTICIPANT	\N	PRESENT	1
624198	624197	08009T	PARTICIPANT	\N	PRESENT	0
624199	624197	20044X	PARTICIPANT	\N	PRESENT	0
624201	624200	11048N	PARTICIPANT	\N	PRESENT	0
623654	621395	19621T	PARTICIPANT	\N	PRESENT	0
623655	621395	14026U	PARTICIPANT	\N	PRESENT	0
624202	624200	08011M	PARTICIPANT	\N	PRESENT	0
624204	624203	11048N	PARTICIPANT	\N	PRESENT	0
624205	624203	08011M	PARTICIPANT	\N	PRESENT	0
624207	624206	14253S	PARTICIPANT	\N	PRESENT	0
624208	624206	19531S	PARTICIPANT	\N	PRESENT	0
624302	624283	19669L	PARTICIPANT	\N	PRESENT	1
624280	624278	11053K	PARTICIPANT	\N	PRESENT	0
624281	624278	01028R	PARTICIPANT	\N	PRESENT	0
624284	624283	04059M	PARTICIPANT	\N	PRESENT	0
624286	624283	20086J	PARTICIPANT	\N	PRESENT	0
624293	624283	19725B	PARTICIPANT	\N	PRESENT	1
624294	624283	19399H	PARTICIPANT	\N	PRESENT	0
624295	624283	20056C	PARTICIPANT	\N	PRESENT	1
624296	624283	19611R	PRESIDENT	0	PRESENT	0
624297	624283	19699S	PARTICIPANT	\N	PRESENT	0
624299	624283	20142Y	PARTICIPANT	\N	PRESENT	0
624301	624283	14229S	PARTICIPANT	\N	PRESENT	0
601663	601660	19631V	PARTICIPANT	\N	PRESENT	0
605776	603130	11074Q	PARTICIPANT	\N	EXCUSE	0
608713	608712	19717B	PRESIDENT	0	PRESENT	0
601712	601707	20090E	PARTICIPANT	\N	PRESENT	0
601714	601707	20120S	PARTICIPANT	\N	PRESENT	0
601715	601707	04035D	PARTICIPANT	\N	PRESENT	0
601716	601707	12041X	PARTICIPANT	\N	PRESENT	0
605777	603130	08009T	PARTICIPANT	\N	EXCUSE	0
609875	608661	19515S	PARTICIPANT	\N	PRESENT	0
609878	608661	19707Y	PARTICIPANT	\N	PRESENT	0
609879	608661	19575F	PARTICIPANT	\N	PRESENT	0
609880	608661	20094J	PARTICIPANT	\N	PRESENT	0
609881	608661	20078J	PARTICIPANT	\N	PRESENT	0
609882	608661	20088L	PARTICIPANT	\N	PRESENT	0
609883	608661	19747H	PARTICIPANT	\N	PRESENT	0
609884	608661	19782L	PARTICIPANT	\N	PRESENT	0
609885	608661	14207L	PARTICIPANT	\N	PRESENT	0
609886	608661	20104S	PARTICIPANT	\N	PRESENT	0
609887	608661	14038Y	PARTICIPANT	\N	PRESENT	0
609889	608661	08028W	PARTICIPANT	\N	PRESENT	0
609891	608661	20144B	PARTICIPANT	\N	PRESENT	0
609893	608661	19467C	PARTICIPANT	\N	PRESENT	0
609894	608661	14357A	PARTICIPANT	\N	PRESENT	0
609896	608661	19507S	PARTICIPANT	\N	PRESENT	0
609898	608661	14187A	PARTICIPANT	\N	PRESENT	0
609900	608661	20174H	PARTICIPANT	\N	PRESENT	0
609902	608661	01025N	PARTICIPANT	\N	PRESENT	0
609905	608661	19695N	PARTICIPANT	\N	PRESENT	0
609906	608661	14033T	PARTICIPANT	\N	PRESENT	0
609908	608661	19511N	PARTICIPANT	\N	PRESENT	0
613460	613305	17023S	PARTICIPANT	\N	PRESENT	0
613461	613305	14001X	PARTICIPANT	\N	PRESENT	0
613463	613305	19515S	PARTICIPANT	\N	PRESENT	0
613465	613305	19695N	PARTICIPANT	\N	PRESENT	0
613466	613305	08010L	PARTICIPANT	\N	PRESENT	0
613467	613305	20092G	PARTICIPANT	\N	PRESENT	0
613468	613305	20090E	PARTICIPANT	\N	PRESENT	0
613469	613305	19760E	PARTICIPANT	\N	PRESENT	0
613470	613305	11115U	PARTICIPANT	\N	PRESENT	0
613471	613305	20116W	PARTICIPANT	\N	PRESENT	0
613472	613305	16685X	PARTICIPANT	\N	PRESENT	0
613474	613305	19503N	PARTICIPANT	\N	PRESENT	0
613475	613305	11110B	PARTICIPANT	\N	PRESENT	0
613476	613305	19679N	PARTICIPANT	\N	PRESENT	0
613477	613305	19621T	PARTICIPANT	\N	PRESENT	0
613478	613305	19575F	PARTICIPANT	\N	PRESENT	0
613479	613305	19581D	PARTICIPANT	\N	PRESENT	0
613480	613305	08073C	PARTICIPANT	\N	PRESENT	0
613481	613305	14089Y	PARTICIPANT	\N	PRESENT	0
613482	613305	19383Y	PARTICIPANT	\N	PRESENT	0
613483	613305	20108W	PARTICIPANT	\N	PRESENT	0
613484	613305	08045X	PARTICIPANT	\N	PRESENT	0
613485	613305	19691J	PARTICIPANT	\N	PRESENT	0
613486	613305	20024T	PARTICIPANT	\N	PRESENT	0
613487	613305	20054A	PARTICIPANT	\N	PRESENT	0
613488	613305	19693L	PARTICIPANT	\N	PRESENT	0
613489	613305	14071N	PARTICIPANT	\N	PRESENT	0
613490	613305	14147R	PARTICIPANT	\N	PRESENT	0
613491	613305	10015M	PARTICIPANT	\N	PRESENT	0
613492	613305	14083S	PARTICIPANT	\N	PRESENT	0
613493	613305	20068G	PARTICIPANT	\N	PRESENT	0
614270	611995	20094J	PARTICIPANT	\N	PRESENT	0
614271	611995	14207L	PARTICIPANT	\N	PRESENT	0
614272	611995	20104S	PARTICIPANT	\N	PRESENT	0
614273	611995	11101A	PARTICIPANT	\N	PRESENT	0
613499	613306	14026U	PARTICIPANT	\N	PRESENT	0
614269	611995	14189C	PARTICIPANT	\N	PRESENT	0
614274	611995	19507S	PARTICIPANT	\N	PRESENT	0
614275	611995	14073Q	PARTICIPANT	\N	PRESENT	0
614276	611995	19441R	PARTICIPANT	\N	PRESENT	0
614277	611995	14001X	PARTICIPANT	\N	PRESENT	0
614278	611995	19563B	PARTICIPANT	\N	PRESENT	0
614279	611995	14237S	PARTICIPANT	\N	PRESENT	0
614280	611995	14331P	PRESIDENT	0	PRESENT	0
614281	611995	04045F	PARTICIPANT	\N	PRESENT	0
614282	611995	19701S	PARTICIPANT	\N	PRESENT	0
614283	611995	08034U	PARTICIPANT	\N	PRESENT	0
614284	611995	11090Q	PARTICIPANT	\N	PRESENT	0
614285	611995	19631V	PARTICIPANT	\N	PRESENT	0
614286	611995	19515S	PARTICIPANT	\N	PRESENT	0
614287	611995	20078J	PARTICIPANT	\N	PRESENT	0
614288	611995	20088L	PARTICIPANT	\N	PRESENT	0
614290	611995	19747H	PARTICIPANT	\N	PRESENT	0
614291	611995	19383Y	PARTICIPANT	\N	PRESENT	0
614292	611995	19782L	PARTICIPANT	\N	PRESENT	0
614293	611995	14038Y	PARTICIPANT	\N	PRESENT	0
614294	611995	08028W	PARTICIPANT	\N	PRESENT	0
614295	611995	19467C	PARTICIPANT	\N	PRESENT	0
614296	611995	14187A	PARTICIPANT	\N	PRESENT	0
614297	611995	20174H	PARTICIPANT	\N	PRESENT	0
614298	611995	20034V	PARTICIPANT	\N	PRESENT	0
614299	611995	08015R	PARTICIPANT	\N	PRESENT	0
614300	611995	14205J	PARTICIPANT	\N	PRESENT	0
614301	611995	20028X	PARTICIPANT	\N	PRESENT	0
614302	611995	19369B	PARTICIPANT	\N	PRESENT	0
614303	611995	14257W	PARTICIPANT	\N	PRESENT	0
614304	611995	19768N	PARTICIPANT	\N	PRESENT	0
614305	611995	20030R	PARTICIPANT	\N	PRESENT	0
614306	611995	20082E	PARTICIPANT	\N	PRESENT	0
614307	611995	20054A	PARTICIPANT	\N	PRESENT	0
614308	611995	20092G	PARTICIPANT	\N	PRESENT	0
614679	613385	20144B	PARTICIPANT	\N	EXCUSE	0
614680	613385	20018V	PARTICIPANT	\N	EXCUSE	0
614681	613385	19866P	PARTICIPANT	\N	EXCUSE	0
614682	613385	14329V	PARTICIPANT	\N	EXCUSE	0
614683	613385	01025N	PARTICIPANT	\N	EXCUSE	0
614684	613385	19667J	PARTICIPANT	\N	PRESENT	0
614685	613385	20116W	PARTICIPANT	\N	PRESENT	0
614686	613385	20086J	PARTICIPANT	\N	PRESENT	0
614687	613385	20070A	PARTICIPANT	\N	PRESENT	0
614688	613385	14327T	PARTICIPANT	\N	PRESENT	0
614689	613385	01057W	PARTICIPANT	\N	PRESENT	0
614690	613385	11048N	PARTICIPANT	\N	PRESENT	0
614691	613385	14121F	PARTICIPANT	\N	PRESENT	0
614692	613385	20126Y	PARTICIPANT	\N	PRESENT	0
614693	613385	19711U	PARTICIPANT	\N	PRESENT	0
614694	613385	08010L	PARTICIPANT	\N	PRESENT	0
614695	613385	08009T	PARTICIPANT	\N	PRESENT	0
614696	613385	19349W	PARTICIPANT	\N	PRESENT	0
614697	613385	14225N	PARTICIPANT	\N	PRESENT	0
614698	613385	20044X	PARTICIPANT	\N	PRESENT	0
614699	613385	19479G	PARTICIPANT	\N	PRESENT	0
614700	613385	14173T	PARTICIPANT	\N	PRESENT	0
614701	613385	14219Q	PARTICIPANT	\N	PRESENT	0
614702	613385	20118Y	PARTICIPANT	\N	PRESENT	0
614703	613385	20038A	PARTICIPANT	\N	PRESENT	0
614704	613385	14031R	PARTICIPANT	\N	PRESENT	0
614705	613385	17229F	PARTICIPANT	\N	PRESENT	0
614706	613385	20032T	PARTICIPANT	\N	PRESENT	0
614707	613385	19820Y	PARTICIPANT	\N	PRESENT	0
614708	613385	18083K	PARTICIPANT	\N	PRESENT	0
614709	613385	20102Q	PARTICIPANT	\N	PRESENT	0
614710	613385	05012A	PARTICIPANT	\N	PRESENT	0
614711	613385	19701S	PARTICIPANT	\N	PRESENT	0
614712	613385	19387D	PARTICIPANT	\N	PRESENT	0
614713	613385	19503N	PARTICIPANT	\N	PRESENT	0
614714	613385	19549D	PARTICIPANT	\N	PRESENT	0
614715	613385	19333N	PARTICIPANT	\N	PRESENT	0
614716	613385	20046A	PARTICIPANT	\N	PRESENT	0
614717	613385	14169X	PARTICIPANT	\N	PRESENT	0
614719	613385	17367Q	PARTICIPANT	\N	PRESENT	0
614720	613385	19745F	PARTICIPANT	\N	PRESENT	0
614722	613385	11101A	PARTICIPANT	\N	PRESENT	0
614725	613385	11065P	PARTICIPANT	\N	PRESENT	0
614732	613385	19826F	PARTICIPANT	\N	PRESENT	0
614733	613385	19525U	PARTICIPANT	\N	PRESENT	0
614736	613385	20068G	PARTICIPANT	\N	PRESENT	0
614739	613385	20024T	PARTICIPANT	\N	PRESENT	0
614746	613385	19367Y	PARTICIPANT	\N	PRESENT	0
614750	613385	20090E	PARTICIPANT	\N	PRESENT	0
614753	613385	10006L	PARTICIPANT	\N	PRESENT	0
614754	613385	14217N	PARTICIPANT	\N	PRESENT	0
614755	613385	20040T	PARTICIPANT	\N	PRESENT	0
614756	613385	20172F	PARTICIPANT	\N	PRESENT	0
614757	613385	19691J	PARTICIPANT	\N	PRESENT	0
614758	613385	19723Y	PARTICIPANT	\N	PRESENT	0
614759	613385	19679N	PARTICIPANT	\N	PRESENT	0
614760	613385	19798U	PARTICIPANT	\N	PRESENT	0
614761	613385	11097X	PARTICIPANT	\N	PRESENT	0
621635	621374	20134Y	PARTICIPANT	\N	PRESENT	0
621636	621374	04047H	PARTICIPANT	\N	PRESENT	0
621637	621374	08018U	PARTICIPANT	\N	PRESENT	0
621638	621374	10006L	PARTICIPANT	\N	PRESENT	0
621639	621374	12041X	PARTICIPANT	\N	PRESENT	0
621640	621374	19593H	PARTICIPANT	\N	PRESENT	0
621641	621374	04085P	PARTICIPANT	\N	PRESENT	0
621642	621374	08069G	PARTICIPANT	\N	PRESENT	0
621643	621374	04092N	PARTICIPANT	\N	PRESENT	0
621644	621374	05008E	PARTICIPANT	\N	PRESENT	0
621645	621374	04033B	PARTICIPANT	\N	PRESENT	0
621646	621374	19711U	PARTICIPANT	\N	PRESENT	0
621647	621374	95063L	PARTICIPANT	\N	PRESENT	0
621648	621374	20050V	PARTICIPANT	\N	PRESENT	0
621649	621374	07029T	PARTICIPANT	\N	PRESENT	0
621650	621374	19707Y	PARTICIPANT	\N	PRESENT	0
621651	621374	19705W	PARTICIPANT	\N	PRESENT	0
621652	621374	19683J	PARTICIPANT	\N	PRESENT	0
621653	621374	20108W	PARTICIPANT	\N	PRESENT	0
621654	621374	19649G	PARTICIPANT	\N	PRESENT	0
621655	621374	20130U	PARTICIPANT	\N	PRESENT	0
621656	621374	01048V	PARTICIPANT	\N	PRESENT	0
621657	621374	14215L	PARTICIPANT	\N	PRESENT	0
621658	621374	19687N	PARTICIPANT	\N	PRESENT	0
621659	621374	11097X	PARTICIPANT	\N	PRESENT	0
621660	621374	19691J	PARTICIPANT	\N	PRESENT	0
621661	621374	14055N	PARTICIPANT	\N	PRESENT	0
621662	621374	19543W	PARTICIPANT	\N	PRESENT	0
621663	621374	11085T	PARTICIPANT	\N	PRESENT	0
621664	621374	19663E	PARTICIPANT	\N	PRESENT	0
621665	621374	01028R	PARTICIPANT	\N	PRESENT	0
621666	621374	11080N	PARTICIPANT	\N	PRESENT	0
621667	621374	04042C	PARTICIPANT	\N	PRESENT	0
621668	621374	11033F	PARTICIPANT	\N	PRESENT	0
621669	621374	20264J	PARTICIPANT	\N	PRESENT	0
621670	621374	19573D	PARTICIPANT	\N	PRESENT	0
621671	621374	19717B	PARTICIPANT	\N	PRESENT	0
621672	621374	14089Y	PARTICIPANT	\N	PRESENT	0
621673	621374	19643A	PARTICIPANT	\N	PRESENT	0
621674	621374	14179A	PARTICIPANT	\N	PRESENT	0
621675	621374	11090Q	PARTICIPANT	\N	PRESENT	0
621676	621374	19657G	PARTICIPANT	\N	PRESENT	0
621677	621374	11053K	PARTICIPANT	\N	PRESENT	0
621678	621374	17637T	PARTICIPANT	\N	PRESENT	0
621679	621374	19669L	PARTICIPANT	\N	PRESENT	0
621680	621374	20252E	PARTICIPANT	\N	PRESENT	0
621681	621374	14026U	PARTICIPANT	\N	PRESENT	0
621682	621374	19715Y	PARTICIPANT	\N	PRESENT	0
621683	621374	14357A	PARTICIPANT	\N	PRESENT	0
621684	621374	20022R	PARTICIPANT	\N	PRESENT	0
621685	621374	19675J	PARTICIPANT	\N	PRESENT	0
621686	621411	19543W	PARTICIPANT	\N	PRESENT	0
621687	621411	04047H	PRESIDENT	0	PRESENT	0
621688	621411	19675J	PARTICIPANT	\N	PRESENT	0
621689	621411	01028R	PARTICIPANT	\N	PRESENT	0
621690	621411	11033F	PARTICIPANT	\N	PRESENT	0
621691	621411	05008E	PARTICIPANT	\N	PRESENT	0
621692	621411	14089Y	PARTICIPANT	\N	PRESENT	0
621693	621411	95063L	PARTICIPANT	\N	PRESENT	0
621694	621411	20108W	PARTICIPANT	\N	PRESENT	0
621695	621411	14179A	PARTICIPANT	\N	PRESENT	0
621696	621411	14215L	PARTICIPANT	\N	PRESENT	0
621697	621411	11085T	PARTICIPANT	\N	PRESENT	0
621592	621410	01028R	PARTICIPANT	\N	PRESENT	0
621593	621410	05008E	PARTICIPANT	\N	PRESENT	0
621634	621374	99004R	PARTICIPANT	\N	PRESENT	0
621698	621411	08018U	PARTICIPANT	\N	PRESENT	0
621699	621411	20022R	PARTICIPANT	\N	PRESENT	0
621700	621508	20130U	PARTICIPANT	\N	PRESENT	0
621701	621508	04092N	PARTICIPANT	\N	PRESENT	0
621702	621508	11097X	PARTICIPANT	\N	PRESENT	0
621703	621508	19663E	PARTICIPANT	\N	PRESENT	0
621704	621508	19691J	PARTICIPANT	\N	PRESENT	0
621705	621508	19657G	PARTICIPANT	\N	PRESENT	0
621706	621508	19717B	PARTICIPANT	\N	PRESENT	0
621707	621508	14026U	PARTICIPANT	\N	PRESENT	0
621708	621508	04043D	PARTICIPANT	\N	PRESENT	1
621709	621508	10006L	PRESIDENT	0	PRESENT	0
621710	621508	14217N	PARTICIPANT	\N	EXCUSE	0
621711	621411	19749K	PARTICIPANT	\N	PRESENT	0
621715	621374	19749K	PARTICIPANT	\N	PRESENT	0
621717	621374	20152B	PARTICIPANT	\N	PRESENT	0
621756	580594	14255U	PARTICIPANT	\N	PRESENT	1
621723	621722	20024T	PARTICIPANT	\N	PRESENT	0
621724	621722	19515S	PARTICIPANT	\N	PRESENT	0
621764	621763	19575F	PARTICIPANT	\N	PRESENT	0
621765	621763	18083K	PARTICIPANT	\N	PRESENT	0
621766	621763	14151M	PARTICIPANT	\N	PRESENT	0
621873	621872	11040E	PARTICIPANT	\N	PRESENT	0
621875	621872	19643A	PARTICIPANT	\N	PRESENT	0
621877	621872	14331P	PARTICIPANT	\N	PRESENT	0
621878	621872	01057W	PARTICIPANT	\N	PRESENT	0
621879	621872	19349W	PARTICIPANT	\N	PRESENT	0
621880	621872	14147R	PARTICIPANT	\N	PRESENT	0
621881	621872	20026V	PARTICIPANT	\N	PRESENT	0
622051	621404	19747H	PARTICIPANT	\N	PRESENT	0
622052	621404	20264J	PARTICIPANT	\N	PRESENT	0
622053	621404	19693L	PARTICIPANT	\N	PRESENT	0
622054	621404	20074E	PARTICIPANT	\N	PRESENT	1
622055	621404	14213J	PARTICIPANT	\N	PRESENT	1
622056	621404	20066E	PARTICIPANT	\N	PRESENT	0
622057	621404	20126Y	PARTICIPANT	\N	PRESENT	1
622058	621404	19369B	PARTICIPANT	\N	PRESENT	0
622059	621404	20050V	PARTICIPANT	\N	PRESENT	0
622060	621404	20082E	PRESIDENT	0	PRESENT	0
622061	621404	14193X	PARTICIPANT	\N	PRESENT	0
622062	621404	11072N	PARTICIPANT	\N	PRESENT	1
622175	621405	20082E	PRESIDENT	0	PRESENT	0
622176	621405	14193X	PARTICIPANT	\N	PRESENT	0
622177	621405	20050V	PARTICIPANT	\N	PRESENT	0
622178	621405	20126Y	PARTICIPANT	\N	PRESENT	1
622179	621405	14213J	PARTICIPANT	\N	PRESENT	1
622180	621405	19747H	PARTICIPANT	\N	PRESENT	0
622181	621405	19693L	PARTICIPANT	\N	PRESENT	0
622183	621405	19369B	PARTICIPANT	\N	PRESENT	0
622202	622198	19768N	PARTICIPANT	\N	PRESENT	0
622203	622199	19768N	PARTICIPANT	\N	PRESENT	0
622205	622204	19768N	PARTICIPANT	\N	PRESENT	0
622207	622206	19768N	PARTICIPANT	\N	PRESENT	0
622221	622220	20094J	PARTICIPANT	\N	PRESENT	0
622222	622220	19762G	PARTICIPANT	\N	PRESENT	0
622223	622220	20048C	PARTICIPANT	\N	PRESENT	0
622224	622220	14105F	PARTICIPANT	\N	PRESENT	0
622225	622220	19515S	PARTICIPANT	\N	PRESENT	0
622226	622220	14030Q	PARTICIPANT	\N	PRESENT	0
622330	622329	20094J	PARTICIPANT	\N	PRESENT	0
622331	622329	20042V	PARTICIPANT	\N	PRESENT	0
622332	622329	07033P	PARTICIPANT	\N	PRESENT	0
622333	622329	04035D	PARTICIPANT	\N	PRESENT	0
622334	622329	14097Y	PARTICIPANT	\N	PRESENT	0
622335	622329	11026G	PARTICIPANT	\N	PRESENT	0
622336	622329	01048V	PARTICIPANT	\N	PRESENT	0
622337	622329	14059S	PARTICIPANT	\N	PRESENT	0
622338	622329	19503N	PARTICIPANT	\N	PRESENT	0
622339	622329	20054A	PARTICIPANT	\N	PRESENT	0
622340	622329	19713W	PARTICIPANT	\N	PRESENT	0
622341	622329	17023S	PARTICIPANT	\N	PRESENT	0
622375	620193	01034P	PARTICIPANT	\N	PRESENT	0
622377	622376	14071N	PARTICIPANT	\N	PRESENT	0
622415	620193	19683J	PARTICIPANT	\N	PRESENT	0
622425	620193	19715Y	PARTICIPANT	\N	PRESENT	0
622454	620193	04043D	PARTICIPANT	\N	PRESENT	0
622460	622455	14033T	PARTICIPANT	\N	PRESENT	0
622461	622455	12041X	PARTICIPANT	\N	PRESENT	0
622464	622455	14026U	PARTICIPANT	\N	PRESENT	0
622466	622465	14033T	PARTICIPANT	\N	PRESENT	0
622467	622465	12041X	PARTICIPANT	\N	PRESENT	0
622472	622471	14259Y	PARTICIPANT	\N	PRESENT	0
622473	620193	19663E	PARTICIPANT	\N	PRESENT	0
622474	620193	19697Q	PARTICIPANT	\N	PRESENT	1
622477	622476	14259Y	PARTICIPANT	\N	PRESENT	0
622478	622476	14275Y	PARTICIPANT	\N	PRESENT	0
622480	620193	20266L	PARTICIPANT	\N	PRESENT	1
622481	620193	14281W	PARTICIPANT	\N	PRESENT	1
622492	620193	19591F	PARTICIPANT	\N	PRESENT	0
622602	620889	19545Y	PARTICIPANT	\N	PRESENT	1
622603	620889	04071H	PARTICIPANT	\N	PRESENT	1
622604	620889	11074Q	PARTICIPANT	\N	PRESENT	1
622605	620889	11110B	PARTICIPANT	\N	PRESENT	1
622606	620889	19647E	PARTICIPANT	\N	PRESENT	1
622607	620889	14121F	PARTICIPANT	\N	PRESENT	1
609917	608516	19657G	PARTICIPANT	\N	PRESENT	0
609911	608516	19647E	PARTICIPANT	\N	PRESENT	0
609912	608516	19631V	PARTICIPANT	\N	PRESENT	0
609913	608516	20144B	PARTICIPANT	\N	PRESENT	0
609914	608516	17637T	PARTICIPANT	\N	PRESENT	0
609915	608516	19701S	PARTICIPANT	\N	PRESENT	0
609919	608516	14331P	PARTICIPANT	\N	PRESENT	0
621943	621918	19691J	PARTICIPANT	\N	PRESENT	1
609920	608516	95063L	PARTICIPANT	\N	PRESENT	0
609921	608516	14255U	PARTICIPANT	\N	PRESENT	0
609923	608516	07004J	PARTICIPANT	\N	PRESENT	0
621942	621918	20066E	PARTICIPANT	\N	PRESENT	1
621944	621918	20130U	PARTICIPANT	\N	PRESENT	1
622001	617182	14331P	PARTICIPANT	\N	EXCUSE	0
622342	620193	11067R	PARTICIPANT	\N	PRESENT	0
622343	620193	20090E	PARTICIPANT	\N	PRESENT	0
622344	620193	19569H	PARTICIPANT	\N	PRESENT	0
622345	620193	11097X	PARTICIPANT	\N	PRESENT	0
622346	620193	19415P	PARTICIPANT	\N	PRESENT	0
622347	620193	14223L	PARTICIPANT	\N	PRESENT	0
622348	620193	14026U	PARTICIPANT	\N	PRESENT	1
622349	620193	19553Y	PARTICIPANT	\N	PRESENT	1
622350	620193	11031D	PARTICIPANT	\N	PRESENT	1
622351	620193	19703U	PARTICIPANT	\N	PRESENT	0
622352	620193	19679N	PARTICIPANT	\N	PRESENT	0
622353	620193	14042U	PARTICIPANT	\N	PRESENT	0
622354	620193	14195A	PARTICIPANT	\N	PRESENT	0
622355	620193	19367Y	PARTICIPANT	\N	PRESENT	0
622356	620193	14213J	PARTICIPANT	\N	PRESENT	0
622357	620193	14217N	PARTICIPANT	\N	PRESENT	0
622358	620193	10006L	PRESIDENT	0	PRESENT	0
622359	620193	20130U	PARTICIPANT	\N	PRESENT	1
622360	620193	04057K	PARTICIPANT	\N	PRESENT	0
622361	620193	04092N	PARTICIPANT	\N	PRESENT	0
622362	620193	19713W	PARTICIPANT	\N	PRESENT	0
622363	620193	11045K	PARTICIPANT	\N	PRESENT	0
622364	620193	08045X	PARTICIPANT	\N	PRESENT	0
622365	620193	20040T	PARTICIPANT	\N	PRESENT	0
622366	620193	17965H	PARTICIPANT	\N	PRESENT	0
622367	620193	19691J	PARTICIPANT	\N	PRESENT	0
622368	620193	19717B	PARTICIPANT	\N	PRESENT	1
622369	620193	19723Y	PARTICIPANT	\N	PRESENT	0
622370	620193	20248J	PARTICIPANT	\N	PRESENT	0
622371	620193	20066E	PARTICIPANT	\N	PRESENT	0
622372	620193	11103C	PARTICIPANT	\N	PRESENT	1
622373	620193	14071N	PARTICIPANT	\N	PRESENT	0
622374	620193	17779H	PARTICIPANT	\N	EXCUSE	0
622394	621510	14053L	PARTICIPANT	\N	PRESENT	0
622395	621510	14001X	PARTICIPANT	\N	PRESENT	0
622396	621510	19585H	PARTICIPANT	\N	PRESENT	0
622397	621510	04047H	PRESIDENT	0	PRESENT	0
622398	621510	19675J	PARTICIPANT	\N	PRESENT	0
622399	621510	01028R	PARTICIPANT	\N	PRESENT	0
622400	621510	19447X	PARTICIPANT	\N	PRESENT	0
622401	621510	05008E	PARTICIPANT	\N	PRESENT	0
622402	621510	14231L	PARTICIPANT	\N	PRESENT	0
622403	621510	19729F	PARTICIPANT	\N	PRESENT	0
622404	621510	95063L	PARTICIPANT	\N	PRESENT	0
622405	621510	20108W	PARTICIPANT	\N	PRESENT	0
622406	621510	20110Q	PARTICIPANT	\N	PRESENT	0
622407	621510	14147R	PARTICIPANT	\N	PRESENT	0
622408	621510	20114U	PARTICIPANT	\N	PRESENT	0
622409	621510	14215L	PARTICIPANT	\N	PRESENT	0
622410	621510	20022R	PARTICIPANT	\N	PRESENT	0
622411	621510	19749K	PARTICIPANT	\N	PRESENT	0
622412	621510	04008A	PARTICIPANT	\N	PRESENT	0
622413	621510	14069U	PARTICIPANT	\N	PRESENT	0
622414	621510	11085T	PARTICIPANT	\N	PRESENT	0
622435	620889	11048N	PARTICIPANT	\N	PRESENT	0
622436	620889	19479G	PARTICIPANT	\N	PRESENT	0
622437	620889	20036X	PARTICIPANT	\N	PRESENT	0
622438	620889	14189C	PARTICIPANT	\N	PRESENT	0
622439	620889	01057W	PARTICIPANT	\N	PRESENT	0
622440	620889	19689Q	PARTICIPANT	\N	PRESENT	0
622441	620889	20080C	PARTICIPANT	\N	PRESENT	0
622442	620889	19667J	PARTICIPANT	\N	PRESENT	0
622443	620889	11070L	PARTICIPANT	\N	PRESENT	0
622444	620889	14225N	PRESIDENT	0	PRESENT	0
622445	620889	11040E	PARTICIPANT	\N	PRESENT	0
622446	620889	14083S	PARTICIPANT	\N	PRESENT	0
622447	620889	20252E	PARTICIPANT	\N	PRESENT	0
622448	620889	20070A	PARTICIPANT	\N	PRESENT	0
622449	620889	19349W	PARTICIPANT	\N	PRESENT	0
622450	620889	19741B	PARTICIPANT	\N	PRESENT	0
622451	620889	99004R	PARTICIPANT	\N	PRESENT	0
622452	620889	19335Q	PARTICIPANT	\N	PRESENT	0
622453	620889	20126Y	PARTICIPANT	\N	PRESENT	0
622456	620889	19762G	PARTICIPANT	\N	PRESENT	0
622457	620889	14327T	PARTICIPANT	\N	EXCUSE	0
622458	620889	14173T	PARTICIPANT	\N	EXCUSE	0
622459	620889	08010L	PARTICIPANT	\N	PRESENT	0
622462	620889	08034U	PARTICIPANT	\N	PRESENT	0
622463	620889	08009T	PARTICIPANT	\N	PRESENT	0
622468	620889	07029T	PARTICIPANT	\N	PRESENT	0
622469	620889	11053K	PARTICIPANT	\N	PRESENT	0
622470	620889	20116W	PARTICIPANT	\N	PRESENT	0
622479	620889	20044X	PARTICIPANT	\N	PRESENT	0
622745	621391	19443T	PARTICIPANT	\N	PRESENT	0
622746	621391	19467C	PARTICIPANT	\N	PRESENT	0
622747	621391	20044X	PARTICIPANT	\N	PRESENT	0
622748	621391	19703U	PARTICIPANT	\N	PRESENT	0
622749	621391	14357A	PARTICIPANT	\N	PRESENT	0
622750	621391	14329V	PARTICIPANT	\N	PRESENT	0
622751	621391	19549D	PARTICIPANT	\N	PRESENT	0
622752	621391	19649G	PARTICIPANT	\N	PRESENT	0
622753	621391	14121F	PARTICIPANT	\N	PRESENT	0
622754	621391	19387D	PARTICIPANT	\N	PRESENT	0
622755	621391	14207L	PARTICIPANT	\N	PRESENT	0
622756	621391	19329S	PARTICIPANT	\N	PRESENT	0
622757	621391	20106U	PARTICIPANT	\N	PRESENT	0
622758	621391	04045F	PARTICIPANT	\N	PRESENT	0
622759	621391	20116W	PARTICIPANT	\N	PRESENT	0
622760	621391	14249W	PARTICIPANT	\N	PRESENT	0
622761	621391	20114U	PARTICIPANT	\N	PRESENT	0
622762	621391	19545Y	PARTICIPANT	\N	PRESENT	0
622763	621391	11012A	PARTICIPANT	\N	PRESENT	0
622764	621391	19719D	PARTICIPANT	\N	PRESENT	0
622765	621391	19717B	PARTICIPANT	\N	PRESENT	0
622766	621391	19697Q	PARTICIPANT	\N	PRESENT	0
622767	621391	14211G	PARTICIPANT	\N	PRESENT	0
622768	621391	19741B	PARTICIPANT	\N	PRESENT	0
622769	621391	19758L	PARTICIPANT	\N	PRESENT	0
622770	621391	04085P	PARTICIPANT	\N	PRESENT	0
622771	621391	11048N	PARTICIPANT	\N	PRESENT	0
622772	621391	11040E	PARTICIPANT	\N	PRESENT	0
622773	621391	01058X	PARTICIPANT	\N	PRESENT	0
622774	621391	19693L	PARTICIPANT	\N	PRESENT	0
622775	621391	20102Q	PARTICIPANT	\N	PRESENT	0
622776	621391	19575F	PARTICIPANT	\N	PRESENT	0
622777	621391	20080C	PARTICIPANT	\N	PRESENT	0
622778	621391	17779H	PARTICIPANT	\N	PRESENT	0
622779	621391	04008A	PARTICIPANT	\N	PRESENT	0
622780	621391	04059M	PARTICIPANT	\N	PRESENT	0
622781	621391	14021P	PARTICIPANT	\N	PRESENT	0
622782	621391	11090Q	PARTICIPANT	\N	PRESENT	0
622783	621391	14097Y	PARTICIPANT	\N	PRESENT	0
622784	621391	11067R	PARTICIPANT	\N	PRESENT	0
622785	621391	11045K	PARTICIPANT	\N	PRESENT	0
622786	621391	19669L	PARTICIPANT	\N	PRESENT	0
622787	621391	19820Y	PARTICIPANT	\N	PRESENT	0
622788	621391	20070A	PARTICIPANT	\N	PRESENT	0
622789	621391	11027H	PARTICIPANT	\N	PRESENT	0
622790	621391	01034P	PARTICIPANT	\N	PRESENT	0
622791	621391	19503N	PARTICIPANT	\N	PRESENT	0
622792	621391	14038Y	PARTICIPANT	\N	PRESENT	0
622793	621391	20038A	PARTICIPANT	\N	PRESENT	0
622794	621391	19527W	PARTICIPANT	\N	PRESENT	0
622795	621391	20264J	PARTICIPANT	\N	PRESENT	0
622796	621391	19681G	PARTICIPANT	\N	PRESENT	0
622797	621391	19573D	PARTICIPANT	\N	PRESENT	0
622798	621391	08061X	PARTICIPANT	\N	PRESENT	0
622799	621391	07029T	PARTICIPANT	\N	PRESENT	0
622800	621391	11083R	PARTICIPANT	\N	PRESENT	0
622801	621391	19651A	PARTICIPANT	\N	PRESENT	0
622802	621391	14031R	PARTICIPANT	\N	PRESENT	0
622803	621391	20150Y	PARTICIPANT	\N	PRESENT	0
622804	621391	20096L	PARTICIPANT	\N	PRESENT	0
622805	621391	19729F	PARTICIPANT	\N	PRESENT	0
622806	621391	08015R	PARTICIPANT	\N	PRESENT	0
622807	621391	20122U	PARTICIPANT	\N	PRESENT	0
622808	621391	20104S	PARTICIPANT	\N	PRESENT	0
624219	621516	04059M	PARTICIPANT	\N	PRESENT	0
624220	621516	19651A	PARTICIPANT	\N	PRESENT	1
624713	624172	19717B	PARTICIPANT	\N	EXCUSE	0
624714	624172	14083S	PRESIDENT	0	PRESENT	0
624305	624283	11053K	PARTICIPANT	\N	PRESENT	1
624224	621516	11053K	PARTICIPANT	\N	PRESENT	0
624715	624172	20034V	PARTICIPANT	\N	PRESENT	0
624716	624172	19447X	PARTICIPANT	\N	PRESENT	0
624227	621516	20132W	PARTICIPANT	\N	PRESENT	1
624228	621516	19725B	PARTICIPANT	\N	PRESENT	1
624229	621516	19399H	PARTICIPANT	\N	PRESENT	0
624230	621516	20056C	PARTICIPANT	\N	PRESENT	1
624231	621516	19611R	PRESIDENT	0	PRESENT	0
624232	621516	19699S	PARTICIPANT	\N	PRESENT	0
624233	621516	12041X	PARTICIPANT	\N	PRESENT	0
624234	621516	20142Y	PARTICIPANT	\N	PRESENT	1
624717	624172	14059S	PARTICIPANT	\N	PRESENT	0
624236	621516	14229S	PARTICIPANT	\N	PRESENT	0
624718	624172	20102Q	PARTICIPANT	\N	PRESENT	0
624238	621516	20026V	PARTICIPANT	\N	PRESENT	0
624719	624172	19503N	PARTICIPANT	\N	PRESENT	0
624720	624172	20150Y	PARTICIPANT	\N	PRESENT	0
624721	624172	17023S	PARTICIPANT	\N	PRESENT	0
624722	624172	19333N	PARTICIPANT	\N	PRESENT	0
624723	624172	19826F	PARTICIPANT	\N	PRESENT	0
625019	624152	20068G	PARTICIPANT	\N	PRESENT	0
625020	624152	19251M	PARTICIPANT	\N	PRESENT	0
625021	624152	19745F	PARTICIPANT	\N	PRESENT	0
625022	624152	19599P	PARTICIPANT	\N	PRESENT	0
625023	624152	20102Q	PARTICIPANT	\N	PRESENT	0
625024	624152	19619A	PARTICIPANT	\N	PRESENT	0
625305	625300	18083K	PARTICIPANT	\N	PRESENT	0
625026	624141	11067R	PARTICIPANT	\N	PRESENT	0
625027	624141	19569H	PARTICIPANT	\N	PRESENT	0
625028	624141	11097X	PARTICIPANT	\N	PRESENT	0
625029	624141	19415P	PARTICIPANT	\N	PRESENT	0
625307	625301	19619A	PARTICIPANT	\N	PRESENT	0
625308	625301	18083K	PARTICIPANT	\N	PRESENT	0
625032	624141	17779H	PARTICIPANT	\N	PRESENT	0
625309	625301	19333N	PARTICIPANT	\N	PRESENT	0
625310	625301	14026U	PARTICIPANT	\N	PRESENT	0
625035	624141	19703U	PARTICIPANT	\N	PRESENT	0
625036	624141	19679N	PARTICIPANT	\N	PRESENT	0
625037	624141	14042U	PARTICIPANT	\N	PRESENT	0
625038	624141	19367Y	PARTICIPANT	\N	PRESENT	0
625039	624141	14213J	PARTICIPANT	\N	PRESENT	0
625311	625302	19619A	PARTICIPANT	\N	PRESENT	0
625041	624141	10006L	PRESIDENT	0	PRESENT	0
625312	625302	18083K	PARTICIPANT	\N	PRESENT	0
625313	625302	19333N	PARTICIPANT	\N	PRESENT	0
625044	624141	20040T	PARTICIPANT	\N	PRESENT	0
625314	625302	14026U	PARTICIPANT	\N	PRESENT	0
625046	624141	17965H	PARTICIPANT	\N	PRESENT	0
625315	625303	19619A	PARTICIPANT	\N	PRESENT	0
625316	625303	18083K	PARTICIPANT	\N	PRESENT	0
625318	624153	19383Y	PARTICIPANT	\N	PRESENT	0
625050	624141	20066E	PARTICIPANT	\N	PRESENT	0
625319	624153	20088L	PARTICIPANT	\N	PRESENT	0
625125	624152	19333N	PARTICIPANT	\N	PRESENT	0
625126	624152	19503N	PARTICIPANT	\N	PRESENT	0
625127	623502	01057W	PARTICIPANT	\N	PRESENT	0
625128	623502	08010L	PARTICIPANT	\N	PRESENT	0
625129	624152	20118Y	PARTICIPANT	\N	PRESENT	0
625130	624152	19525U	PARTICIPANT	\N	PRESENT	0
625138	625134	11033F	PARTICIPANT	\N	PRESENT	1
625139	625134	14147R	PARTICIPANT	\N	PRESENT	0
625140	625134	19673G	PARTICIPANT	\N	PRESENT	0
625141	625134	14053L	PARTICIPANT	\N	PRESENT	0
625142	625134	04047H	PRESIDENT	0	PRESENT	0
625143	624152	20140W	PARTICIPANT	\N	PRESENT	0
625144	625134	19729F	PARTICIPANT	\N	PRESENT	1
625145	625134	10015M	PARTICIPANT	\N	PRESENT	1
625146	625134	14107H	PARTICIPANT	\N	PRESENT	1
625148	624047	04085P	PARTICIPANT	\N	PRESENT	1
625149	624047	20110Q	PARTICIPANT	\N	PRESENT	1
625150	624047	11033F	PARTICIPANT	\N	PRESENT	1
625151	624047	14069U	PARTICIPANT	\N	PRESENT	1
625152	624047	11056N	PARTICIPANT	\N	PRESENT	1
625153	624047	19489J	PARTICIPANT	\N	PRESENT	1
625154	624047	19729F	PARTICIPANT	\N	PRESENT	1
625155	624047	10015M	PARTICIPANT	\N	PRESENT	1
625156	624047	14107H	PARTICIPANT	\N	PRESENT	1
625157	625147	14173T	PARTICIPANT	\N	PRESENT	0
625158	625147	19447X	PARTICIPANT	\N	PRESENT	0
625159	625147	18083K	PARTICIPANT	\N	PRESENT	0
625160	625147	14205J	PARTICIPANT	\N	PRESENT	1
625161	625134	05008E	PARTICIPANT	\N	PRESENT	0
625162	625134	01028R	PARTICIPANT	\N	PRESENT	0
625164	625163	20076G	PARTICIPANT	\N	PRESENT	0
625165	625163	20128B	PARTICIPANT	\N	PRESENT	0
625166	625163	14205J	PARTICIPANT	\N	PRESENT	0
625167	625163	19745F	PARTICIPANT	\N	PRESENT	0
625168	625163	20118Y	PARTICIPANT	\N	PRESENT	0
625169	625163	20054A	PARTICIPANT	\N	PRESENT	0
625170	625163	11097X	PARTICIPANT	\N	PRESENT	0
625171	625163	04045F	PARTICIPANT	\N	PRESENT	0
625172	625163	19762G	PARTICIPANT	\N	PRESENT	0
625173	624152	20106U	PARTICIPANT	\N	PRESENT	1
625174	624152	19387D	PARTICIPANT	\N	PRESENT	1
625175	624047	20074E	PARTICIPANT	\N	EXCUSE	0
625176	623502	19667J	PARTICIPANT	\N	PRESENT	0
625177	624047	08018U	PARTICIPANT	\N	EXCUSE	0
625178	623502	14053L	PARTICIPANT	\N	PRESENT	0
625179	623502	19749K	PARTICIPANT	\N	PRESENT	0
625205	625134	14179A	PARTICIPANT	\N	PRESENT	0
625206	625134	19749K	PARTICIPANT	\N	PRESENT	0
625207	625134	14259Y	PARTICIPANT	\N	PRESENT	0
625208	625134	19447X	PARTICIPANT	\N	PRESENT	0
625209	625134	19954N	PARTICIPANT	\N	PRESENT	0
625210	625134	20022R	PARTICIPANT	\N	PRESENT	0
625211	624152	14331P	PARTICIPANT	\N	PRESENT	1
625212	624152	14133K	PARTICIPANT	\N	PRESENT	0
625213	624152	11026G	PARTICIPANT	\N	PRESENT	0
625214	624152	14033T	PARTICIPANT	\N	PRESENT	0
625215	624152	19507S	PARTICIPANT	\N	PRESENT	0
625216	624152	19739H	PARTICIPANT	\N	PRESENT	0
625217	625134	11085T	PARTICIPANT	\N	PRESENT	0
625218	625134	95063L	PARTICIPANT	\N	PRESENT	0
625219	625134	19675J	PARTICIPANT	\N	PRESENT	0
625220	625134	19725B	PARTICIPANT	\N	PRESENT	0
625221	625134	14215L	PARTICIPANT	\N	PRESENT	0
625222	625134	19629C	PARTICIPANT	\N	PRESENT	0
625223	625134	14089Y	PARTICIPANT	\N	PRESENT	0
625224	625134	17737W	PARTICIPANT	\N	PRESENT	0
625227	624171	95041E	PARTICIPANT	\N	PRESENT	0
625228	624171	19443T	PARTICIPANT	\N	PRESENT	1
625229	624171	12041X	PARTICIPANT	\N	PRESENT	0
625230	624171	19565D	PARTICIPANT	\N	PRESENT	1
625231	624171	20072C	PARTICIPANT	\N	PRESENT	0
625232	624171	01058X	PARTICIPANT	\N	PRESENT	0
625233	624171	11027H	PARTICIPANT	\N	PRESENT	0
625234	624171	16685X	PARTICIPANT	\N	PRESENT	0
625235	624171	04042C	PRESIDENT	0	PRESENT	0
625236	624171	11054L	PARTICIPANT	\N	PRESENT	0
625237	624171	19669L	PARTICIPANT	\N	PRESENT	0
625238	624171	11066Q	PARTICIPANT	\N	PRESENT	0
625239	624171	12028B	PARTICIPANT	\N	PRESENT	0
625240	624171	11115U	PARTICIPANT	\N	PRESENT	0
625241	624171	19421M	PARTICIPANT	\N	PRESENT	0
625242	624171	19709B	PARTICIPANT	\N	PRESENT	0
625243	624171	14193X	PARTICIPANT	\N	PRESENT	0
625244	624171	19347U	PARTICIPANT	\N	PRESENT	0
625245	624171	08061X	PARTICIPANT	\N	PRESENT	0
625246	624171	14249W	PARTICIPANT	\N	PRESENT	0
625247	624171	08047A	PARTICIPANT	\N	PRESENT	0
625248	624171	14059S	PARTICIPANT	\N	PRESENT	0
625249	624171	14097Y	PARTICIPANT	\N	PRESENT	1
625250	624171	04035D	PARTICIPANT	\N	PRESENT	1
625251	624171	14133K	PARTICIPANT	\N	PRESENT	0
625252	624171	01062T	PARTICIPANT	\N	PRESENT	0
625253	624171	20042V	PARTICIPANT	\N	PRESENT	0
625254	624171	19319Q	PARTICIPANT	\N	PRESENT	0
625255	624171	14105F	PARTICIPANT	\N	PRESENT	0
625256	624171	20064C	PARTICIPANT	\N	PRESENT	1
625257	624171	14267Y	PARTICIPANT	\N	PRESENT	0
625258	624171	11064N	PARTICIPANT	\N	PRESENT	0
625259	624171	11083R	PARTICIPANT	\N	PRESENT	0
625260	624171	14255U	PARTICIPANT	\N	PRESENT	0
625261	624171	17023S	PARTICIPANT	\N	PRESENT	0
625262	624171	14211G	PARTICIPANT	\N	EXCUSE	0
625304	625300	19619A	PARTICIPANT	\N	PRESENT	0
600558	595598	20024T	PARTICIPANT	\N	EXCUSE	0
599371	599368	14059S	PRESIDENT	0	PRESENT	0
599372	599368	14331P	PARTICIPANT	\N	EXCUSE	0
599373	599368	19673G	PARTICIPANT	\N	PRESENT	0
599374	599368	14219Q	PARTICIPANT	\N	EXCUSE	0
599375	599368	05008E	PARTICIPANT	\N	EXCUSE	0
599376	599368	11010L	PARTICIPANT	\N	EXCUSE	0
600379	596677	14189C	PARTICIPANT	\N	EXCUSE	0
600380	596675	20100N	PARTICIPANT	\N	PRESENT	0
600381	596675	11083R	PARTICIPANT	\N	PRESENT	0
600382	596675	14033T	PARTICIPANT	\N	PRESENT	0
600383	596675	19725B	PARTICIPANT	\N	PRESENT	0
600384	596675	14097Y	PARTICIPANT	\N	PRESENT	0
600385	596675	12041X	PARTICIPANT	\N	PRESENT	0
600386	596675	11026G	PARTICIPANT	\N	PRESENT	0
600387	596675	12016W	PARTICIPANT	\N	PRESENT	0
600388	596675	14331P	PARTICIPANT	\N	PRESENT	0
600389	596675	10015M	PARTICIPANT	\N	PRESENT	0
600390	596675	04045F	PARTICIPANT	\N	PRESENT	0
600391	596675	19563B	PARTICIPANT	\N	PRESENT	0
600392	596675	08034U	PARTICIPANT	\N	PRESENT	0
600393	596675	14026U	PARTICIPANT	\N	EXCUSE	0
600394	596675	19441R	PARTICIPANT	\N	EXCUSE	0
600395	596675	04057K	PARTICIPANT	\N	EXCUSE	0
600396	596675	20128B	PARTICIPANT	\N	PRESENT	0
600397	596675	14189C	PARTICIPANT	\N	EXCUSE	0
600556	595598	14189C	PARTICIPANT	\N	EXCUSE	0
600559	595598	14030Q	PRESIDENT	0	PRESENT	0
600560	595598	20138D	PARTICIPANT	\N	EXCUSE	0
600561	595598	20114U	PARTICIPANT	\N	PRESENT	0
600563	595598	17737W	PARTICIPANT	\N	PRESENT	0
600565	595598	20080C	PARTICIPANT	\N	PRESENT	0
600567	595598	11031D	PARTICIPANT	\N	PRESENT	0
600569	595598	19599P	PARTICIPANT	\N	EXCUSE	0
600572	595598	20106U	PARTICIPANT	\N	EXCUSE	0
600573	595598	20066E	PARTICIPANT	\N	PRESENT	0
600575	595598	14109K	PARTICIPANT	\N	EXCUSE	0
600577	595598	20130U	PARTICIPANT	\N	PRESENT	0
600578	595598	11045K	PARTICIPANT	\N	PRESENT	0
600580	595598	20046A	PARTICIPANT	\N	PRESENT	0
600581	595598	19749K	PARTICIPANT	\N	PRESENT	0
600648	600647	14001X	PARTICIPANT	\N	PRESENT	0
600984	600983	04070G	PARTICIPANT	\N	PRESENT	0
600985	600983	14169X	PARTICIPANT	\N	PRESENT	0
612326	610832	04085P	PARTICIPANT	\N	PRESENT	0
612327	610832	19667J	PRESIDENT	0	PRESENT	0
612329	610832	19741B	PARTICIPANT	\N	PRESENT	0
612332	610832	19671E	PARTICIPANT	\N	PRESENT	0
612334	610832	20090E	PARTICIPANT	\N	PRESENT	0
612336	610832	14249W	PARTICIPANT	\N	PRESENT	0
612373	610832	14257W	PARTICIPANT	\N	PRESENT	0
612664	611233	11043H	PARTICIPANT	\N	PRESENT	0
612665	611233	19533U	PARTICIPANT	\N	PRESENT	0
612666	611233	08012N	PARTICIPANT	\N	PRESENT	0
612667	611232	08012N	PARTICIPANT	\N	PRESENT	0
612668	611232	11043H	PARTICIPANT	\N	PRESENT	0
612670	612669	08012N	PARTICIPANT	\N	PRESENT	0
612671	612669	11043H	PARTICIPANT	\N	PRESENT	0
614762	613385	19703U	PARTICIPANT	\N	PRESENT	0
614763	613385	19543W	PARTICIPANT	\N	PRESENT	0
614764	613385	20022R	PARTICIPANT	\N	PRESENT	0
614765	613385	19954N	PARTICIPANT	\N	PRESENT	0
614766	613385	20110Q	PARTICIPANT	\N	PRESENT	0
614767	613385	14089Y	PARTICIPANT	\N	PRESENT	0
614768	613385	04047H	PARTICIPANT	\N	PRESENT	0
614769	613385	14053L	PARTICIPANT	\N	PRESENT	0
614770	613385	19629C	PARTICIPANT	\N	PRESENT	0
614771	613385	14215L	PARTICIPANT	\N	PRESENT	0
614772	613385	14151M	PARTICIPANT	\N	PRESENT	0
614773	613385	07004J	PARTICIPANT	\N	PRESENT	0
614774	613385	20128B	PARTICIPANT	\N	PRESENT	0
614775	613385	19447X	PARTICIPANT	\N	PRESENT	0
614776	613385	14021P	PARTICIPANT	\N	PRESENT	0
614777	613385	19489J	PARTICIPANT	\N	PRESENT	0
614778	613385	14111D	PARTICIPANT	\N	PRESENT	0
614779	613385	14001X	PARTICIPANT	\N	PRESENT	0
614780	613385	10015M	PARTICIPANT	\N	PRESENT	0
614781	613385	95063L	PARTICIPANT	\N	PRESENT	0
614782	613385	19585H	PARTICIPANT	\N	PRESENT	0
614834	613386	20144B	PARTICIPANT	\N	EXCUSE	0
614835	613386	20018V	PARTICIPANT	\N	EXCUSE	0
614836	613386	19866P	PARTICIPANT	\N	EXCUSE	0
614837	613386	14329V	PARTICIPANT	\N	EXCUSE	0
614838	613386	01025N	PARTICIPANT	\N	EXCUSE	0
614839	613386	14001X	PARTICIPANT	\N	PRESENT	0
614840	613386	11101A	PARTICIPANT	\N	PRESENT	0
614841	613386	14331P	PARTICIPANT	\N	PRESENT	0
614842	613386	08034U	PARTICIPANT	\N	PRESENT	0
614843	613386	14189C	PARTICIPANT	\N	PRESENT	0
614844	613386	14237S	PARTICIPANT	\N	PRESENT	0
614845	613386	14073Q	PARTICIPANT	\N	PRESENT	0
614846	613386	19701S	PARTICIPANT	\N	PRESENT	0
614876	614875	19762G	PARTICIPANT	\N	PRESENT	0
614877	614875	14083S	PARTICIPANT	\N	PRESENT	0
614878	614875	19575F	PARTICIPANT	\N	PRESENT	0
614879	614875	19515S	PRESIDENT	0	PRESENT	0
614880	614875	19301E	PARTICIPANT	\N	PRESENT	0
614881	614875	20082E	PARTICIPANT	\N	PRESENT	0
614882	614875	20092G	PARTICIPANT	\N	PRESENT	0
614883	614875	20054A	PARTICIPANT	\N	PRESENT	0
615803	613304	14231L	PRESIDENT	0	PRESENT	0
615804	613304	14229S	PARTICIPANT	\N	PRESENT	0
615805	613304	19349W	PARTICIPANT	\N	PRESENT	0
615806	613304	14215L	PARTICIPANT	\N	PRESENT	0
615807	613304	19447X	PARTICIPANT	\N	PRESENT	0
615808	613304	20062A	PARTICIPANT	\N	PRESENT	0
615809	613304	01057W	PARTICIPANT	\N	PRESENT	0
615810	613304	14053L	PARTICIPANT	\N	PRESENT	0
615811	613304	20090E	PARTICIPANT	\N	PRESENT	0
615812	613304	19333N	PARTICIPANT	\N	PRESENT	0
615813	613304	20110Q	PARTICIPANT	\N	PRESENT	0
615814	613304	19826F	PARTICIPANT	\N	PRESENT	0
615815	613304	19563B	PARTICIPANT	\N	PRESENT	0
615816	613304	08010L	PARTICIPANT	\N	PRESENT	0
615817	613304	20022R	PARTICIPANT	\N	PRESENT	0
615818	613304	19782L	PARTICIPANT	\N	PRESENT	0
615819	613304	04045F	PARTICIPANT	\N	PRESENT	0
615820	613304	20084G	PARTICIPANT	\N	PRESENT	0
615822	613304	19681G	PARTICIPANT	\N	EXCUSE	0
615823	613304	19820Y	PARTICIPANT	\N	EXCUSE	0
615824	613304	19335Q	PARTICIPANT	\N	EXCUSE	0
615825	613304	14069U	PARTICIPANT	\N	EXCUSE	0
615826	613304	19711U	PARTICIPANT	\N	EXCUSE	0
615827	613304	14071N	PARTICIPANT	\N	EXCUSE	0
615828	613304	19735D	PARTICIPANT	\N	EXCUSE	0
615829	613304	19565D	PARTICIPANT	\N	EXCUSE	0
616312	616311	20024T	PARTICIPANT	\N	PRESENT	0
616313	616311	14219Q	PARTICIPANT	\N	PRESENT	0
616314	616311	19515S	PARTICIPANT	\N	PRESENT	0
616315	616311	19637C	PARTICIPANT	\N	PRESENT	0
616316	616311	19739H	PARTICIPANT	\N	PRESENT	0
616317	616311	20032T	PARTICIPANT	\N	PRESENT	0
616319	616318	20024T	PARTICIPANT	\N	PRESENT	0
616320	616318	19515S	PARTICIPANT	\N	PRESENT	0
616321	616318	19637C	PARTICIPANT	\N	PRESENT	0
616322	616318	19739H	PARTICIPANT	\N	PRESENT	0
616324	616323	20024T	PARTICIPANT	\N	PRESENT	0
616325	616323	19515S	PARTICIPANT	\N	PRESENT	0
616326	616323	19637C	PARTICIPANT	\N	PRESENT	0
616327	616323	19739H	PARTICIPANT	\N	PRESENT	0
616330	616329	20024T	PARTICIPANT	\N	PRESENT	0
616331	616329	19515S	PARTICIPANT	\N	PRESENT	0
616333	616332	19599P	PARTICIPANT	\N	PRESENT	0
616334	616332	11054L	PARTICIPANT	\N	PRESENT	0
616662	616305	19713W	PARTICIPANT	\N	PRESENT	0
622608	620889	19711U	PARTICIPANT	\N	PRESENT	1
622609	620889	20050V	PARTICIPANT	\N	PRESENT	1
622610	620889	11012A	PARTICIPANT	\N	PRESENT	1
622634	618873	11065P	PARTICIPANT	\N	PRESENT	1
622635	618873	19681G	PARTICIPANT	\N	PRESENT	1
622636	618873	19251M	PARTICIPANT	\N	PRESENT	1
622637	618873	20106U	PARTICIPANT	\N	PRESENT	1
622638	618873	19637C	PARTICIPANT	\N	PRESENT	1
622911	621343	14133K	PARTICIPANT	\N	PRESENT	0
622912	621343	20042V	PARTICIPANT	\N	PRESENT	0
622913	621343	14105F	PARTICIPANT	\N	PRESENT	0
622915	621343	14255U	PARTICIPANT	\N	PRESENT	0
622917	621343	04042C	PRESIDENT	0	PRESENT	0
622919	621343	12028B	PARTICIPANT	\N	PRESENT	0
622930	621343	14267Y	PARTICIPANT	\N	PRESENT	0
622932	621343	11027H	PARTICIPANT	\N	PRESENT	0
622933	621343	07033P	PARTICIPANT	\N	PRESENT	0
622934	621343	14249W	PARTICIPANT	\N	PRESENT	0
622935	621343	17023S	PARTICIPANT	\N	PRESENT	0
622937	621343	97011G	PARTICIPANT	\N	PRESENT	0
622938	621343	04035D	PARTICIPANT	\N	PRESENT	0
622940	621343	11083R	PARTICIPANT	\N	PRESENT	0
622943	621343	19347U	PARTICIPANT	\N	PRESENT	0
622944	621343	08056B	PARTICIPANT	\N	PRESENT	0
622945	621343	19565D	PARTICIPANT	\N	PRESENT	0
622946	621343	20072C	PARTICIPANT	\N	PRESENT	0
622947	621343	19329S	PARTICIPANT	\N	PRESENT	0
622948	621343	14097Y	PARTICIPANT	\N	PRESENT	0
622950	621343	12041X	PARTICIPANT	\N	PRESENT	0
622951	621343	16685X	PARTICIPANT	\N	PRESENT	0
622952	621343	14059S	PARTICIPANT	\N	PRESENT	0
622953	621343	08061X	PARTICIPANT	\N	PRESENT	0
622954	621343	08047A	PARTICIPANT	\N	PRESENT	0
622955	621343	14193X	PARTICIPANT	\N	PRESENT	0
622956	621343	19443T	PARTICIPANT	\N	PRESENT	0
622957	621343	11054L	PARTICIPANT	\N	PRESENT	0
622958	621343	19421M	PARTICIPANT	\N	PRESENT	0
622959	621343	01058X	PARTICIPANT	\N	PRESENT	0
622960	621343	19669L	PARTICIPANT	\N	PRESENT	1
622961	621343	01062T	PARTICIPANT	\N	PRESENT	1
622962	621343	11041F	PARTICIPANT	\N	PRESENT	0
622963	621343	11066Q	PARTICIPANT	\N	PRESENT	0
622980	622978	16685X	PARTICIPANT	\N	PRESENT	0
622981	620743	20086J	PARTICIPANT	\N	PRESENT	0
622982	622978	20118Y	PARTICIPANT	\N	PRESENT	0
622983	622978	17737W	PARTICIPANT	\N	PRESENT	0
622985	622978	14083S	PARTICIPANT	\N	PRESENT	0
622986	622984	19575F	PARTICIPANT	\N	PRESENT	0
622987	622984	19782L	PARTICIPANT	\N	PRESENT	1
622988	622984	14038Y	PARTICIPANT	\N	PRESENT	0
622989	622984	14187A	PARTICIPANT	\N	PRESENT	0
622990	622984	14205J	PARTICIPANT	\N	PRESENT	1
622991	622984	19563B	PARTICIPANT	\N	PRESENT	1
622992	622984	20028X	PARTICIPANT	\N	PRESENT	0
622993	622984	20092G	PARTICIPANT	\N	PRESENT	0
622994	622984	19629C	PARTICIPANT	\N	PRESENT	0
622995	622984	19725B	PARTICIPANT	\N	PRESENT	1
622996	622984	14179A	PARTICIPANT	\N	PRESENT	1
622997	622984	14147R	PARTICIPANT	\N	PRESENT	0
623000	622999	16685X	PARTICIPANT	\N	PRESENT	0
623001	622999	14083S	PARTICIPANT	\N	PRESENT	0
623002	622999	14249W	PARTICIPANT	\N	PRESENT	0
623003	622999	14073Q	PARTICIPANT	\N	PRESENT	0
623005	623004	19569H	PARTICIPANT	\N	PRESENT	0
623006	623004	11026G	PARTICIPANT	\N	PRESENT	0
623007	623004	20060X	PARTICIPANT	\N	PRESENT	0
623008	623004	14255U	PARTICIPANT	\N	PRESENT	0
623009	623004	20082E	PARTICIPANT	\N	PRESENT	0
623705	621102	20100N	PARTICIPANT	\N	PRESENT	1
623706	621102	11083R	PARTICIPANT	\N	PRESENT	1
623707	621102	14073Q	PARTICIPANT	\N	PRESENT	0
623708	621102	11026G	PARTICIPANT	\N	PRESENT	0
623710	621102	12041X	PARTICIPANT	\N	PRESENT	0
623713	621102	14331P	PRESIDENT	0	PRESENT	0
623714	621102	04045F	PARTICIPANT	\N	PRESENT	1
623716	621102	14001X	PARTICIPANT	\N	PRESENT	0
623726	621102	14207L	PARTICIPANT	\N	PRESENT	0
623728	621102	19701S	PARTICIPANT	\N	PRESENT	0
623736	621102	19333N	PARTICIPANT	\N	PRESENT	0
623738	621102	08034U	PARTICIPANT	\N	PRESENT	0
623740	621102	19711U	PARTICIPANT	\N	PRESENT	0
623742	621102	19441R	PARTICIPANT	\N	PRESENT	0
623745	621102	20104S	PARTICIPANT	\N	PRESENT	0
623747	621102	14033T	PARTICIPANT	\N	PRESENT	1
623748	621102	04057K	PARTICIPANT	\N	EXCUSE	0
623749	621102	14097Y	PARTICIPANT	\N	PRESENT	0
623752	619250	19749K	PARTICIPANT	\N	PRESENT	0
623753	619250	19527W	PARTICIPANT	\N	PRESENT	1
623754	619250	14179A	PARTICIPANT	\N	PRESENT	1
623755	619250	11045K	PARTICIPANT	\N	PRESENT	0
623757	619250	19681G	PARTICIPANT	\N	PRESENT	1
623765	619250	19599P	PARTICIPANT	\N	EXCUSE	0
623766	619250	20066E	PARTICIPANT	\N	EXCUSE	0
623767	619250	07029T	PARTICIPANT	\N	EXCUSE	0
623768	619250	20130U	PARTICIPANT	\N	EXCUSE	0
623803	623594	17779H	PARTICIPANT	\N	PRESENT	1
623804	621407	19591F	PARTICIPANT	\N	PRESENT	0
623805	621407	11067R	PARTICIPANT	\N	PRESENT	0
623806	621407	19713W	PARTICIPANT	\N	PRESENT	0
623807	621407	20090E	PARTICIPANT	\N	PRESENT	0
623808	621407	14217N	PARTICIPANT	\N	PRESENT	0
623809	621407	11097X	PARTICIPANT	\N	PRESENT	0
623810	621407	10006L	PARTICIPANT	\N	PRESENT	0
623811	621407	20130U	PARTICIPANT	\N	PRESENT	0
623812	621407	19415P	PARTICIPANT	\N	PRESENT	0
623813	621407	14073Q	PARTICIPANT	\N	PRESENT	0
623814	621407	14147R	PARTICIPANT	\N	PRESENT	0
623815	621407	04057K	PARTICIPANT	\N	PRESENT	0
623817	621407	19629C	PARTICIPANT	\N	PRESENT	0
623818	621407	11031D	PARTICIPANT	\N	PRESENT	0
623819	621407	19760E	PARTICIPANT	\N	PRESENT	0
623821	623816	19663E	PARTICIPANT	\N	PRESENT	0
623822	623816	20128B	PARTICIPANT	\N	PRESENT	0
623823	623816	19735D	PARTICIPANT	\N	EXCUSE	0
623824	623816	01048V	PARTICIPANT	\N	PRESENT	0
623831	621407	19719D	PARTICIPANT	\N	PRESENT	0
623826	623816	19533U	PARTICIPANT	\N	PRESENT	0
623827	623816	19503N	PARTICIPANT	\N	PRESENT	0
623829	623816	01058X	PARTICIPANT	\N	PRESENT	0
623830	621407	04043D	PARTICIPANT	\N	PRESENT	0
623832	621407	20248J	PARTICIPANT	\N	PRESENT	0
623837	621407	14207L	PARTICIPANT	\N	PRESENT	0
623839	623836	20064C	PARTICIPANT	\N	PRESENT	1
623840	623836	07004J	PARTICIPANT	\N	PRESENT	1
623841	623836	19667J	PRESIDENT	0	PRESENT	0
623842	623836	19671E	PARTICIPANT	\N	PRESENT	1
623843	623836	04085P	PARTICIPANT	\N	PRESENT	0
623844	621407	14267Y	PARTICIPANT	\N	PRESENT	0
623845	621407	01048V	PARTICIPANT	\N	PRESENT	0
623846	621407	19691J	PARTICIPANT	\N	PRESENT	0
623847	621407	17023S	PARTICIPANT	\N	PRESENT	0
623848	621407	14031R	PARTICIPANT	\N	PRESENT	0
623849	621407	14059S	PARTICIPANT	\N	PRESENT	0
623850	621407	19711U	PARTICIPANT	\N	PRESENT	0
623851	621407	14083S	PARTICIPANT	\N	PRESENT	0
623852	621407	20052X	PARTICIPANT	\N	PRESENT	0
623853	621407	19467C	PARTICIPANT	\N	PRESENT	0
623854	623836	20044X	PARTICIPANT	\N	PRESENT	1
623855	623836	14257W	PARTICIPANT	\N	PRESENT	1
623856	621407	19749K	PARTICIPANT	\N	PRESENT	0
623857	621407	20024T	PARTICIPANT	\N	PRESENT	0
623859	621407	14189C	PARTICIPANT	\N	PRESENT	0
623862	621407	20266L	PARTICIPANT	\N	PRESENT	0
623863	621407	14215L	PARTICIPANT	\N	PRESENT	0
623864	621407	19543W	PARTICIPANT	\N	PRESENT	0
623865	621407	20106U	PARTICIPANT	\N	PRESENT	0
623874	621407	19649G	PARTICIPANT	\N	PRESENT	0
599701	599700	14255U	PARTICIPANT	\N	PRESENT	0
599702	599700	04035D	PARTICIPANT	\N	PRESENT	0
600701	600699	04070G	PARTICIPANT	\N	PRESENT	0
600702	600699	20180F	PARTICIPANT	\N	PRESENT	0
600703	600699	20026V	PARTICIPANT	\N	PRESENT	0
600704	600699	20132W	PARTICIPANT	\N	PRESENT	0
600707	600699	19699S	PARTICIPANT	\N	PRESENT	0
600708	600699	20052X	PARTICIPANT	\N	PRESENT	0
600709	600699	19399H	PARTICIPANT	\N	PRESENT	0
600710	600699	19611R	PRESIDENT	0	PRESENT	0
600711	600699	20084G	PARTICIPANT	\N	PRESENT	0
600712	600699	20048C	PARTICIPANT	\N	PRESENT	0
600713	600699	19651A	PARTICIPANT	\N	PRESENT	0
600714	600699	20056C	PARTICIPANT	\N	PRESENT	0
600715	600699	20142Y	PARTICIPANT	\N	PRESENT	0
600716	600699	14073Q	PARTICIPANT	\N	PRESENT	0
600717	600699	19693L	PARTICIPANT	\N	EXCUSE	0
600718	600699	19643A	PARTICIPANT	\N	EXCUSE	0
600719	600699	11109J	PARTICIPANT	\N	EXCUSE	0
600781	600779	12016W	PARTICIPANT	\N	PRESENT	0
601755	600211	20040T	PARTICIPANT	\N	PRESENT	0
601756	600211	20086J	PARTICIPANT	\N	PRESENT	0
603633	603632	20110Q	PARTICIPANT	\N	PRESENT	0
603635	603634	20110Q	PARTICIPANT	\N	PRESENT	0
603637	603636	20110Q	PARTICIPANT	\N	PRESENT	0
603677	601163	19701S	PARTICIPANT	\N	EXCUSE	0
603678	601163	19251M	PARTICIPANT	\N	EXCUSE	0
604303	598561	14109K	PARTICIPANT	\N	PRESENT	0
604325	604323	14123H	PARTICIPANT	\N	PRESENT	1
604327	604323	14030Q	PARTICIPANT	\N	PRESENT	1
604328	604323	20180F	PARTICIPANT	\N	PRESENT	1
606764	606763	14169X	PARTICIPANT	\N	PRESENT	0
609456	609453	19531S	PARTICIPANT	\N	PRESENT	0
606853	606261	20090E	PARTICIPANT	\N	PRESENT	0
606858	606261	04057K	PARTICIPANT	\N	EXCUSE	0
606859	606261	14071N	PARTICIPANT	\N	EXCUSE	0
606860	606261	20066E	PARTICIPANT	\N	EXCUSE	0
606861	606261	19569H	PARTICIPANT	\N	PRESENT	0
607208	607205	01043Q	PARTICIPANT	\N	PRESENT	0
607491	607490	14147R	PARTICIPANT	\N	PRESENT	0
607492	607490	20086J	PARTICIPANT	\N	PRESENT	0
607493	607490	17737W	PARTICIPANT	\N	PRESENT	0
607494	607490	04042C	PARTICIPANT	\N	PRESENT	0
607495	607490	14179A	PARTICIPANT	\N	PRESENT	0
607496	607490	14231L	PARTICIPANT	\N	PRESENT	0
607497	607490	97011G	PARTICIPANT	\N	PRESENT	0
607498	607490	99004R	PARTICIPANT	\N	PRESENT	0
607499	607490	19447X	PARTICIPANT	\N	PRESENT	0
607500	607490	11085T	PARTICIPANT	\N	PRESENT	0
607501	607490	19711U	PARTICIPANT	\N	PRESENT	0
607502	607490	04033B	PARTICIPANT	\N	PRESENT	0
607503	607490	11064N	PARTICIPANT	\N	PRESENT	0
607504	607490	14105F	PARTICIPANT	\N	PRESENT	0
607505	607490	19251M	PARTICIPANT	\N	PRESENT	0
607506	607490	19735D	PARTICIPANT	\N	PRESENT	0
607508	607507	04070G	PARTICIPANT	\N	PRESENT	0
607509	607507	14255U	PARTICIPANT	\N	PRESENT	0
607510	607507	14211G	PARTICIPANT	\N	PRESENT	0
607511	607507	19699S	PARTICIPANT	\N	PRESENT	0
607512	607507	11026G	PARTICIPANT	\N	PRESENT	0
607513	607507	14357A	PARTICIPANT	\N	PRESENT	0
609454	609453	19631V	PARTICIPANT	\N	PRESENT	0
609455	609453	18083K	PARTICIPANT	\N	PRESENT	0
609457	609453	19669L	PARTICIPANT	\N	PRESENT	0
609939	608516	19413M	PARTICIPANT	\N	PRESENT	0
609961	608516	17023S	PARTICIPANT	\N	PRESENT	0
610222	608518	01043Q	PARTICIPANT	\N	PRESENT	0
610223	608518	19691J	PARTICIPANT	\N	PRESENT	0
610224	608518	11012A	PARTICIPANT	\N	PRESENT	0
610225	608518	19715Y	PARTICIPANT	\N	PRESENT	0
610226	608518	19583F	PARTICIPANT	\N	PRESENT	0
610227	608518	19657G	PARTICIPANT	\N	PRESENT	0
610228	608518	19347U	PARTICIPANT	\N	PRESENT	0
610229	608518	19695N	PARTICIPANT	\N	PRESENT	0
610230	608518	17023S	PARTICIPANT	\N	PRESENT	0
610231	608518	19683J	PARTICIPANT	\N	PRESENT	0
610232	608518	14053L	PARTICIPANT	\N	PRESENT	0
610233	608518	14237S	PARTICIPANT	\N	PRESENT	0
610234	608518	14267Y	PARTICIPANT	\N	PRESENT	0
610235	608518	14121F	PARTICIPANT	\N	PRESENT	0
610236	608518	20266L	PARTICIPANT	\N	PRESENT	0
610237	608518	20092G	PARTICIPANT	\N	PRESENT	0
610238	608518	20108W	PARTICIPANT	\N	PRESENT	0
610239	608518	20138D	PARTICIPANT	\N	PRESENT	0
610240	608518	19593H	PARTICIPANT	\N	PRESENT	0
610242	608518	11077T	PARTICIPANT	\N	PRESENT	0
610244	608518	19631V	PARTICIPANT	\N	PRESENT	0
610245	608518	17589D	PARTICIPANT	\N	PRESENT	0
610246	608518	19621T	PARTICIPANT	\N	PRESENT	0
610247	608518	14069U	PARTICIPANT	\N	PRESENT	0
610248	608518	20130U	PARTICIPANT	\N	PRESENT	0
610249	608518	19747H	PARTICIPANT	\N	PRESENT	0
610250	608518	14147R	PARTICIPANT	\N	PRESENT	0
610251	608518	19681G	PARTICIPANT	\N	PRESENT	0
610252	608518	19565D	PARTICIPANT	\N	PRESENT	0
610253	608518	20030R	PARTICIPANT	\N	PRESENT	0
610255	608518	19563B	PARTICIPANT	\N	PRESENT	0
610256	608518	04085P	PARTICIPANT	\N	PRESENT	0
610257	608518	14030Q	PARTICIPANT	\N	PRESENT	0
610258	608518	20180F	PARTICIPANT	\N	PRESENT	0
610259	608518	04043D	PARTICIPANT	\N	PRESENT	0
610260	608518	18083K	PARTICIPANT	\N	PRESENT	0
610261	608518	14221J	PARTICIPANT	\N	PRESENT	0
610262	608518	20026V	PARTICIPANT	\N	PRESENT	0
610263	608518	20056C	PARTICIPANT	\N	PRESENT	0
610264	608518	20152B	PARTICIPANT	\N	PRESENT	0
610265	608518	14033T	PARTICIPANT	\N	PRESENT	0
610266	608518	97011G	PARTICIPANT	\N	PRESENT	0
610267	608518	14109K	PARTICIPANT	\N	PRESENT	0
610268	608518	20142Y	PARTICIPANT	\N	PRESENT	0
610269	608518	14083S	PARTICIPANT	\N	PRESENT	0
610270	608518	14219Q	PARTICIPANT	\N	PRESENT	0
610271	608518	20042V	PARTICIPANT	\N	PRESENT	0
610272	608518	20112S	PARTICIPANT	\N	PRESENT	0
610273	608518	20024T	PARTICIPANT	\N	PRESENT	0
610274	608518	20132W	PARTICIPANT	\N	PRESENT	0
610275	608518	19467C	PARTICIPANT	\N	PRESENT	0
610277	608518	17779H	PARTICIPANT	\N	PRESENT	0
610283	608518	20134Y	PARTICIPANT	\N	PRESENT	0
610315	608521	20134Y	PARTICIPANT	\N	PRESENT	0
610316	608521	14030Q	PARTICIPANT	\N	PRESENT	0
610317	608521	17589D	PARTICIPANT	\N	PRESENT	0
610318	608521	19563B	PARTICIPANT	\N	PRESENT	0
610319	608521	20026V	PARTICIPANT	\N	PRESENT	0
610320	608521	19467C	PARTICIPANT	\N	PRESENT	0
610321	608521	20180F	PARTICIPANT	\N	PRESENT	0
610322	608521	20024T	PARTICIPANT	\N	PRESENT	0
610323	608521	14109K	PARTICIPANT	\N	PRESENT	0
610324	608521	19565D	PARTICIPANT	\N	PRESENT	0
610325	608521	20112S	PARTICIPANT	\N	PRESENT	0
610326	608521	17779H	PARTICIPANT	\N	PRESENT	0
610327	608521	20100N	PARTICIPANT	\N	PRESENT	0
610328	608521	19681G	PARTICIPANT	\N	PRESENT	0
610329	608521	19621T	PARTICIPANT	\N	PRESENT	0
610330	608521	04043D	PARTICIPANT	\N	PRESENT	0
610331	608521	14069U	PARTICIPANT	\N	PRESENT	0
610332	608521	20058E	PARTICIPANT	\N	PRESENT	0
610333	608521	19599P	PARTICIPANT	\N	PRESENT	0
610334	608521	20056C	PARTICIPANT	\N	PRESENT	0
610335	608521	20064C	PARTICIPANT	\N	PRESENT	0
610336	608521	19533U	PARTICIPANT	\N	PRESENT	0
610358	608521	20142Y	PARTICIPANT	\N	PRESENT	0
610359	608521	19687N	PARTICIPANT	\N	PRESENT	0
610360	608521	19527W	PARTICIPANT	\N	PRESENT	0
610368	608521	19711U	PARTICIPANT	\N	PRESENT	0
610373	608521	20062A	PARTICIPANT	\N	PRESENT	0
610374	608521	19715Y	PARTICIPANT	\N	PRESENT	0
610395	608521	20052X	PARTICIPANT	\N	PRESENT	0
610313	608521	01043Q	PARTICIPANT	\N	PRESENT	0
610314	608521	20132W	PARTICIPANT	\N	PRESENT	0
610396	608521	20048C	PARTICIPANT	\N	PRESENT	0
610397	608521	14021P	PARTICIPANT	\N	PRESENT	0
610398	608521	20152B	PARTICIPANT	\N	PRESENT	0
610399	608521	19629C	PARTICIPANT	\N	PRESENT	0
610400	608521	20032T	PARTICIPANT	\N	PRESENT	0
610401	608521	20080C	PARTICIPANT	\N	PRESENT	0
610402	608521	11043H	PARTICIPANT	\N	PRESENT	0
610403	608521	19347U	PARTICIPANT	\N	PRESENT	0
622508	622507	20092G	PARTICIPANT	\N	PRESENT	0
622509	622507	19507S	PARTICIPANT	\N	PRESENT	0
622510	622507	14033T	PARTICIPANT	\N	PRESENT	0
622512	622511	20092G	PARTICIPANT	\N	PRESENT	0
622513	622511	19507S	PARTICIPANT	\N	PRESENT	0
622514	622511	14033T	PARTICIPANT	\N	PRESENT	0
622516	622515	19507S	PARTICIPANT	\N	PRESENT	0
622517	622515	20092G	PARTICIPANT	\N	PRESENT	0
622518	622515	14033T	PARTICIPANT	\N	PRESENT	0
622520	622519	19507S	PARTICIPANT	\N	PRESENT	0
622522	622521	19507S	PARTICIPANT	\N	PRESENT	0
622523	622521	20088L	PARTICIPANT	\N	PRESENT	0
622524	622521	19782L	PARTICIPANT	\N	PRESENT	0
622570	622525	19507S	PARTICIPANT	\N	PRESENT	0
622571	622525	19782L	PARTICIPANT	\N	PRESENT	0
622572	622525	20088L	PARTICIPANT	\N	PRESENT	0
622573	622525	19413M	PARTICIPANT	\N	PRESENT	0
622575	622574	19507S	PARTICIPANT	\N	PRESENT	0
622576	622574	19782L	PARTICIPANT	\N	PRESENT	0
622577	622574	20088L	PARTICIPANT	\N	PRESENT	0
622578	622574	19413M	PARTICIPANT	\N	PRESENT	0
622580	622579	19507S	PARTICIPANT	\N	PRESENT	0
622581	622579	19782L	PARTICIPANT	\N	PRESENT	0
622582	622579	20088L	PARTICIPANT	\N	PRESENT	0
622583	622579	19413M	PARTICIPANT	\N	PRESENT	0
622585	622584	19507S	PARTICIPANT	\N	PRESENT	0
622586	622584	19782L	PARTICIPANT	\N	PRESENT	0
622587	622584	20088L	PARTICIPANT	\N	PRESENT	0
622588	622584	19413M	PARTICIPANT	\N	PRESENT	0
622589	622584	14257W	PARTICIPANT	\N	PRESENT	0
622591	622590	19507S	PARTICIPANT	\N	PRESENT	0
622592	622590	19782L	PARTICIPANT	\N	PRESENT	0
622593	622590	20088L	PARTICIPANT	\N	PRESENT	0
622594	622590	19413M	PARTICIPANT	\N	PRESENT	0
622595	622590	14257W	PARTICIPANT	\N	PRESENT	0
622597	622596	19507S	PARTICIPANT	\N	PRESENT	0
622598	622596	19782L	PARTICIPANT	\N	PRESENT	0
622599	622596	20088L	PARTICIPANT	\N	PRESENT	0
622600	622596	19413M	PARTICIPANT	\N	PRESENT	0
622601	622596	14257W	PARTICIPANT	\N	PRESENT	0
624160	623820	14026U	PARTICIPANT	\N	PRESENT	0
624161	623820	19725B	PARTICIPANT	\N	PRESENT	0
624162	620685	04070G	PARTICIPANT	\N	PRESENT	0
624163	620685	14169X	PARTICIPANT	\N	PRESENT	0
624164	623833	14026U	PARTICIPANT	\N	PRESENT	0
624165	623833	19725B	PARTICIPANT	\N	PRESENT	0
624166	621399	19701S	PARTICIPANT	\N	PRESENT	0
624167	621399	14001X	PARTICIPANT	\N	PRESENT	0
624185	624184	19768N	PARTICIPANT	\N	PRESENT	0
624186	624183	19768N	PARTICIPANT	\N	PRESENT	0
625053	624141	19691J	PARTICIPANT	\N	PRESENT	0
625054	624141	04057K	PARTICIPANT	\N	PRESENT	0
625481	625480	14147R	PARTICIPANT	\N	PRESENT	0
625071	624141	19798U	PARTICIPANT	\N	PRESENT	0
625131	624141	19715Y	PARTICIPANT	\N	PRESENT	0
625484	625483	14147R	PARTICIPANT	\N	PRESENT	0
625133	624141	04043D	PARTICIPANT	\N	PRESENT	0
625135	624141	14071N	PARTICIPANT	\N	PRESENT	0
625136	624141	14195A	PARTICIPANT	\N	PRESENT	0
625486	625485	14147R	PARTICIPANT	\N	PRESENT	0
625489	625488	14105F	PARTICIPANT	\N	PRESENT	0
625490	625488	08028W	PARTICIPANT	\N	PRESENT	0
625226	624141	01034P	PARTICIPANT	\N	PRESENT	0
625320	624153	19768N	PARTICIPANT	\N	PRESENT	0
625321	624153	19515S	PARTICIPANT	\N	PRESENT	0
625322	624153	20092G	PARTICIPANT	\N	PRESENT	0
625323	624153	19782L	PARTICIPANT	\N	PRESENT	0
625324	624153	11077T	PARTICIPANT	\N	PRESENT	1
625325	624153	01043Q	PARTICIPANT	\N	PRESENT	0
625326	624153	20078J	PARTICIPANT	\N	PRESENT	1
625327	624153	19441R	PARTICIPANT	\N	PRESENT	0
625328	624153	19413M	PARTICIPANT	\N	PRESENT	0
625329	624153	20082E	PARTICIPANT	\N	PRESENT	1
625330	624153	20094J	PARTICIPANT	\N	PRESENT	0
625331	624153	04045F	PARTICIPANT	\N	PRESENT	0
625332	624153	19866P	PARTICIPANT	\N	PRESENT	0
625333	624153	20104S	PARTICIPANT	\N	PRESENT	0
625334	624153	19705W	PARTICIPANT	\N	PRESENT	1
625335	624153	19707Y	PARTICIPANT	\N	PRESENT	1
625336	624153	08015R	PARTICIPANT	\N	PRESENT	0
625337	624153	19575F	PARTICIPANT	\N	PRESENT	0
625338	624153	19369B	PARTICIPANT	\N	PRESENT	1
625339	624153	20018V	PARTICIPANT	\N	PRESENT	0
625340	624153	19511N	PARTICIPANT	\N	PRESENT	0
625341	624153	19563B	PARTICIPANT	\N	PRESENT	0
625342	624153	08028W	PARTICIPANT	\N	PRESENT	0
625343	624153	14329V	PARTICIPANT	\N	PRESENT	0
625344	624153	20028X	PARTICIPANT	\N	PRESENT	0
625345	624153	14038Y	PARTICIPANT	\N	PRESENT	0
625346	624153	20030R	PARTICIPANT	\N	PRESENT	1
625347	624153	19467C	PARTICIPANT	\N	PRESENT	0
625348	624153	20034V	PARTICIPANT	\N	PRESENT	0
625349	624153	14187A	PARTICIPANT	\N	PRESENT	0
625350	624153	20144B	PARTICIPANT	\N	PRESENT	0
625351	624153	14033T	PARTICIPANT	\N	PRESENT	0
625352	624153	11090Q	PRESIDENT	0	PRESENT	0
625353	624153	01025N	PARTICIPANT	\N	PRESENT	1
625354	624153	20054A	PARTICIPANT	\N	PRESENT	0
625355	624153	20174H	PARTICIPANT	\N	PRESENT	0
625356	624153	14205J	PARTICIPANT	\N	PRESENT	0
625357	624153	20062A	PARTICIPANT	\N	PRESENT	0
625358	624153	14251Q	PARTICIPANT	\N	PRESENT	1
625359	624153	19507S	PARTICIPANT	\N	PRESENT	0
625360	624153	20286Q	PARTICIPANT	\N	PRESENT	0
625361	624153	19747H	PARTICIPANT	\N	PRESENT	0
625362	624153	14207L	PARTICIPANT	\N	PRESENT	0
625363	624153	14257W	PARTICIPANT	\N	PRESENT	0
625491	625488	20106U	PARTICIPANT	\N	PRESENT	0
625492	625488	19525U	PARTICIPANT	\N	PRESENT	0
625493	625488	14107H	PARTICIPANT	\N	PRESENT	0
625494	625488	19643A	PARTICIPANT	\N	PRESENT	0
625495	625488	20068G	PARTICIPANT	\N	PRESENT	0
625496	625488	19629C	PARTICIPANT	\N	PRESENT	0
625497	625488	14223L	PARTICIPANT	\N	PRESENT	0
625498	625488	11104D	PARTICIPANT	\N	PRESENT	0
625499	625488	11012A	PARTICIPANT	\N	PRESENT	0
625500	625488	20130U	PARTICIPANT	\N	PRESENT	0
625501	625488	19545Y	PARTICIPANT	\N	PRESENT	0
625502	625488	14026U	PARTICIPANT	\N	PRESENT	0
625503	625488	14083S	PARTICIPANT	\N	PRESENT	0
625504	625488	19687N	PARTICIPANT	\N	PRESENT	0
625505	625488	20172F	PARTICIPANT	\N	PRESENT	0
625506	625488	20060X	PARTICIPANT	\N	PRESENT	0
625507	625488	20052X	PARTICIPANT	\N	PRESENT	0
625508	625488	08010L	PARTICIPANT	\N	PRESENT	0
625509	625488	19679N	PARTICIPANT	\N	PRESENT	0
625510	625488	19533U	PARTICIPANT	\N	PRESENT	0
625511	625488	14281W	PARTICIPANT	\N	PRESENT	0
625512	625488	20074E	PARTICIPANT	\N	PRESENT	0
625513	625488	19866P	PARTICIPANT	\N	PRESENT	0
625514	625488	20180F	PARTICIPANT	\N	PRESENT	0
625515	625488	92040Q	PARTICIPANT	\N	PRESENT	0
625516	625488	20252E	PARTICIPANT	\N	PRESENT	0
625517	625488	11041F	PARTICIPANT	\N	PRESENT	0
625518	625488	19593H	PARTICIPANT	\N	PRESENT	0
625519	625488	20108W	PARTICIPANT	\N	PRESENT	0
625520	625488	19057M	PARTICIPANT	\N	PRESENT	0
625521	625488	86034E	PARTICIPANT	\N	PRESENT	0
625522	625488	20090E	PARTICIPANT	\N	PRESENT	0
625523	625488	19798U	PARTICIPANT	\N	PRESENT	0
625527	625488	20046A	PARTICIPANT	\N	PRESENT	0
625525	625488	11054L	PARTICIPANT	\N	PRESENT	0
625526	625488	20112S	PARTICIPANT	\N	PRESENT	0
625528	625488	19758L	PARTICIPANT	\N	PRESENT	0
625529	625488	19683J	PARTICIPANT	\N	PRESENT	0
625530	625488	19741B	PARTICIPANT	\N	PRESENT	0
625531	625488	19515S	PARTICIPANT	\N	PRESENT	0
625532	625488	14229S	PARTICIPANT	\N	PRESENT	0
625533	625488	11090Q	PARTICIPANT	\N	PRESENT	0
625534	625488	19675J	PARTICIPANT	\N	PRESENT	0
625535	625488	14033T	PARTICIPANT	\N	PRESENT	0
625536	625488	19319Q	PARTICIPANT	\N	PRESENT	0
625537	625488	20096L	PARTICIPANT	\N	PRESENT	0
625538	625488	20124W	PARTICIPANT	\N	PRESENT	0
625539	625488	20174H	PARTICIPANT	\N	PRESENT	0
625540	625488	19479G	PARTICIPANT	\N	PRESENT	0
625541	625488	19699S	PARTICIPANT	\N	PRESENT	0
625542	625488	14042U	PARTICIPANT	\N	PRESENT	0
625543	625488	12028B	PARTICIPANT	\N	PRESENT	0
625544	625488	20264J	PARTICIPANT	\N	PRESENT	0
625545	625488	19782L	PARTICIPANT	\N	PRESENT	0
600634	598526	14030Q	PARTICIPANT	\N	PRESENT	1
600635	598451	20142Y	PARTICIPANT	\N	PRESENT	0
600638	598567	14030Q	PARTICIPANT	\N	PRESENT	0
600639	598567	19621T	PARTICIPANT	\N	PRESENT	0
600640	598567	19758L	PARTICIPANT	\N	PRESENT	0
600641	598567	14109K	PARTICIPANT	\N	PRESENT	1
600642	598567	20058E	PARTICIPANT	\N	PRESENT	1
600685	600684	14030Q	PARTICIPANT	\N	PRESENT	0
600686	600684	19621T	PARTICIPANT	\N	PRESENT	0
600687	600684	19758L	PARTICIPANT	\N	PRESENT	0
600688	600684	14109K	PARTICIPANT	\N	PRESENT	1
606364	606363	04047H	PARTICIPANT	\N	PRESENT	0
606365	606363	14053L	PARTICIPANT	\N	PRESENT	0
606367	606366	14299H	PARTICIPANT	\N	PRESENT	0
606369	606366	11066Q	PARTICIPANT	\N	PRESENT	0
608571	608570	14215L	PARTICIPANT	\N	PRESENT	0
608590	606436	19673G	PARTICIPANT	\N	EXCUSE	0
608591	606436	12016W	PARTICIPANT	\N	PRESENT	1
610600	610599	11043H	PARTICIPANT	\N	PRESENT	1
608716	608714	19629C	PARTICIPANT	\N	PRESENT	0
608717	608714	20120S	PARTICIPANT	\N	PRESENT	0
610601	610599	08012N	PARTICIPANT	\N	PRESENT	1
608719	608714	11026G	PARTICIPANT	\N	PRESENT	0
610598	608673	19681G	PARTICIPANT	\N	EXCUSE	0
610602	610599	19533U	PARTICIPANT	\N	PRESENT	1
611453	608712	05008E	PARTICIPANT	\N	EXCUSE	0
611455	608712	14331P	PARTICIPANT	\N	EXCUSE	0
611493	610746	19717B	PRESIDENT	0	PRESENT	0
611494	610746	05008E	PARTICIPANT	\N	EXCUSE	0
611495	610746	14331P	PARTICIPANT	\N	EXCUSE	0
615637	611996	19701S	PARTICIPANT	\N	PRESENT	0
615638	611996	19507S	PARTICIPANT	\N	PRESENT	0
615639	611996	19531S	PARTICIPANT	\N	PRESENT	0
615640	611996	14237S	PARTICIPANT	\N	PRESENT	0
615641	611996	14331P	PRESIDENT	0	PRESENT	0
615642	611996	04045F	PARTICIPANT	\N	PRESENT	0
615643	611996	04070G	PARTICIPANT	\N	PRESENT	0
616680	616274	20134Y	PARTICIPANT	\N	PRESENT	1
615645	611996	14189C	PARTICIPANT	\N	EXCUSE	0
616514	616274	14207L	PARTICIPANT	\N	PRESENT	0
616677	616274	20132W	PARTICIPANT	\N	PRESENT	1
616679	616274	19693L	PARTICIPANT	\N	PRESENT	1
617010	616277	20130U	PARTICIPANT	\N	PRESENT	0
617011	616277	11067R	PARTICIPANT	\N	PRESENT	0
617012	616277	20090E	PARTICIPANT	\N	PRESENT	0
617013	616277	19713W	PARTICIPANT	\N	PRESENT	0
617014	616277	19569H	PARTICIPANT	\N	PRESENT	0
617015	616277	11097X	PARTICIPANT	\N	PRESENT	0
617016	616277	17965H	PARTICIPANT	\N	PRESENT	0
617017	616277	14026U	PARTICIPANT	\N	PRESENT	0
617018	616277	14281W	PARTICIPANT	\N	PRESENT	0
617019	616277	20066E	PARTICIPANT	\N	PRESENT	0
617020	616277	19679N	PARTICIPANT	\N	PRESENT	0
617021	616277	20266L	PARTICIPANT	\N	PRESENT	1
617022	616277	14195A	PARTICIPANT	\N	PRESENT	0
617023	616277	19367Y	PARTICIPANT	\N	PRESENT	0
617024	616277	14213J	PARTICIPANT	\N	PRESENT	0
617025	616277	04043D	PARTICIPANT	\N	PRESENT	1
617026	616277	10006L	PRESIDENT	0	PRESENT	0
617027	616406	19383Y	PARTICIPANT	\N	PRESENT	0
617028	616406	20088L	PARTICIPANT	\N	PRESENT	0
617029	616406	19515S	PARTICIPANT	\N	PRESENT	0
617030	616406	14357A	PARTICIPANT	\N	PRESENT	0
617031	616406	20078J	PARTICIPANT	\N	PRESENT	1
617032	616406	20082E	PARTICIPANT	\N	PRESENT	0
617033	616406	04045F	PARTICIPANT	\N	PRESENT	0
617034	616406	20104S	PARTICIPANT	\N	PRESENT	0
617035	616406	19631V	PARTICIPANT	\N	PRESENT	0
617036	616406	19705W	PARTICIPANT	\N	PRESENT	1
617037	616406	19707Y	PARTICIPANT	\N	PRESENT	1
617038	616406	08015R	PARTICIPANT	\N	PRESENT	0
617039	616406	19369B	PARTICIPANT	\N	PRESENT	0
617040	616406	20018V	PARTICIPANT	\N	PRESENT	0
617041	616406	19511N	PARTICIPANT	\N	PRESENT	0
617042	616406	08028W	PARTICIPANT	\N	PRESENT	0
617043	616406	19563B	PARTICIPANT	\N	PRESENT	0
617044	616406	20028X	PARTICIPANT	\N	PRESENT	0
617045	616406	20030R	PARTICIPANT	\N	PRESENT	0
617046	616406	19467C	PARTICIPANT	\N	PRESENT	0
617047	616406	20034V	PARTICIPANT	\N	PRESENT	0
617048	616406	14187A	PARTICIPANT	\N	PRESENT	0
617049	616406	20144B	PARTICIPANT	\N	PRESENT	0
617050	616406	14033T	PARTICIPANT	\N	PRESENT	0
617051	616406	11090Q	PRESIDENT	0	PRESENT	0
617052	616406	20054A	PARTICIPANT	\N	PRESENT	0
617053	616406	20174H	PARTICIPANT	\N	PRESENT	1
617054	616406	14205J	PARTICIPANT	\N	PRESENT	0
617055	616406	20060X	PARTICIPANT	\N	PRESENT	0
617056	616406	20062A	PARTICIPANT	\N	PRESENT	0
617057	616406	14251Q	PARTICIPANT	\N	PRESENT	1
617058	616406	19747H	PARTICIPANT	\N	PRESENT	0
617059	616406	14207L	PARTICIPANT	\N	PRESENT	0
617060	616406	14257W	PARTICIPANT	\N	PRESENT	0
617061	616406	19575F	PARTICIPANT	\N	PRESENT	0
617062	616406	14038Y	PARTICIPANT	\N	PRESENT	0
617063	616406	19782L	PARTICIPANT	\N	PRESENT	0
617064	616406	19413M	PARTICIPANT	\N	PRESENT	0
617065	616406	19866P	PARTICIPANT	\N	PRESENT	0
617066	616406	20286Q	PARTICIPANT	\N	PRESENT	0
617067	616277	04092N	PARTICIPANT	\N	PRESENT	1
617068	616277	19798U	PARTICIPANT	\N	PRESENT	0
617069	616277	19703U	PARTICIPANT	\N	PRESENT	0
617070	616406	19768N	PARTICIPANT	\N	PRESENT	0
617071	616277	14071N	PARTICIPANT	\N	PRESENT	0
617072	616277	14217N	PARTICIPANT	\N	PRESENT	0
617073	616277	19657G	PARTICIPANT	\N	PRESENT	1
617074	616277	01034P	PARTICIPANT	\N	PRESENT	0
617075	616277	19415P	PARTICIPANT	\N	PRESENT	0
617076	616277	19301E	PARTICIPANT	\N	PRESENT	1
617077	616277	19760E	PARTICIPANT	\N	PRESENT	1
617078	616277	18193Q	PARTICIPANT	\N	PRESENT	0
617079	616277	14042U	PARTICIPANT	\N	PRESENT	0
617080	616277	19723Y	PARTICIPANT	\N	PRESENT	0
617081	616277	20248J	PARTICIPANT	\N	PRESENT	0
617082	616406	11103C	PARTICIPANT	\N	PRESENT	0
617083	616406	01025N	PARTICIPANT	\N	EXCUSE	0
617084	616406	19441R	PARTICIPANT	\N	PRESENT	0
617085	616406	20092G	PARTICIPANT	\N	PRESENT	0
617086	616238	95063L	PARTICIPANT	\N	PRESENT	0
617087	616238	14069U	PARTICIPANT	\N	PRESENT	0
617127	616277	19553Y	PARTICIPANT	\N	PRESENT	1
617134	616277	11031D	PARTICIPANT	\N	PRESENT	0
617135	616277	19683J	PARTICIPANT	\N	PRESENT	0
617189	616277	19663E	PARTICIPANT	\N	PRESENT	0
617190	616277	14223L	PARTICIPANT	\N	PRESENT	0
617191	616277	11103C	PARTICIPANT	\N	PRESENT	1
617192	616277	20040T	PARTICIPANT	\N	PRESENT	0
617193	616277	19591F	PARTICIPANT	\N	PRESENT	0
617424	616391	19383Y	PARTICIPANT	\N	PRESENT	0
617425	616391	14327T	PARTICIPANT	\N	PRESENT	0
617426	616391	14030Q	PARTICIPANT	\N	PRESENT	0
617427	616391	14357A	PARTICIPANT	\N	PRESENT	0
617428	616391	01024M	PARTICIPANT	\N	PRESENT	0
617429	616391	04070G	PARTICIPANT	\N	PRESENT	0
617430	616391	20066E	PARTICIPANT	\N	PRESENT	0
617431	616391	14217N	PARTICIPANT	\N	PRESENT	0
617432	616391	10006L	PARTICIPANT	\N	PRESENT	0
617433	616391	19798U	PARTICIPANT	\N	PRESENT	0
617434	616391	14255U	PARTICIPANT	\N	PRESENT	0
617435	616391	19826F	PARTICIPANT	\N	PRESENT	0
617436	616391	14237S	PARTICIPANT	\N	PRESENT	0
617437	616391	14083S	PARTICIPANT	\N	PRESENT	0
617438	616391	19335Q	PARTICIPANT	\N	PRESENT	0
617439	616391	19581D	PARTICIPANT	\N	PRESENT	0
617440	616391	14089Y	PARTICIPANT	\N	PRESENT	0
617441	616391	19421M	PARTICIPANT	\N	PRESENT	0
617442	616391	14267Y	PARTICIPANT	\N	PRESENT	0
617443	616391	14215L	PARTICIPANT	\N	PRESENT	0
617444	616391	14069U	PARTICIPANT	\N	PRESENT	0
617445	616391	19685L	PARTICIPANT	\N	PRESENT	0
617446	616391	14187A	PARTICIPANT	\N	PRESENT	0
617447	616391	14071N	PARTICIPANT	\N	PRESENT	0
617448	616391	19415P	PARTICIPANT	\N	PRESENT	0
617449	616391	04042C	PARTICIPANT	\N	PRESENT	0
617450	616391	11048N	PARTICIPANT	\N	PRESENT	0
617451	616391	08010L	PARTICIPANT	\N	PRESENT	0
617452	616391	19703U	PARTICIPANT	\N	PRESENT	0
617453	616391	14123H	PARTICIPANT	\N	PRESENT	0
617454	616391	14169X	PARTICIPANT	\N	PRESENT	0
617455	616391	11043H	PARTICIPANT	\N	PRESENT	0
623761	621407	99004R	PARTICIPANT	\N	PRESENT	0
623769	623594	11067R	PARTICIPANT	\N	PRESENT	0
623770	623594	20090E	PARTICIPANT	\N	PRESENT	0
623771	623594	19713W	PARTICIPANT	\N	PRESENT	0
623772	623594	11097X	PARTICIPANT	\N	PRESENT	0
623773	623594	17965H	PARTICIPANT	\N	PRESENT	0
623774	623594	19415P	PARTICIPANT	\N	PRESENT	0
623775	623594	19691J	PARTICIPANT	\N	PRESENT	1
623776	623594	14223L	PARTICIPANT	\N	PRESENT	1
623777	623594	19723Y	PARTICIPANT	\N	PRESENT	0
623778	623594	20248J	PARTICIPANT	\N	PRESENT	0
623779	623594	11103C	PARTICIPANT	\N	PRESENT	1
623780	623594	14042U	PARTICIPANT	\N	PRESENT	1
623781	623594	14213J	PARTICIPANT	\N	PRESENT	1
623782	623594	14217N	PARTICIPANT	\N	PRESENT	0
623783	623594	10006L	PRESIDENT	0	PRESENT	0
623784	623594	19760E	PARTICIPANT	\N	PRESENT	0
623785	623594	19295A	PARTICIPANT	\N	EXCUSE	0
623909	621408	19551W	PARTICIPANT	\N	PRESENT	0
623910	621408	20106U	PARTICIPANT	\N	PRESENT	0
623911	621408	20266L	PARTICIPANT	\N	PRESENT	0
623912	621408	11031D	PARTICIPANT	\N	PRESENT	0
623913	621408	19713W	PARTICIPANT	\N	PRESENT	0
623914	621408	19629C	PARTICIPANT	\N	PRESENT	0
623915	621408	20090E	PARTICIPANT	\N	PRESENT	0
623916	621408	19711U	PARTICIPANT	\N	PRESENT	0
623917	621408	14217N	PARTICIPANT	\N	PRESENT	0
623918	621408	20024T	PARTICIPANT	\N	PRESENT	0
623919	621408	19467C	PARTICIPANT	\N	PRESENT	0
623920	621408	20248J	PARTICIPANT	\N	PRESENT	0
623921	621408	19691J	PARTICIPANT	\N	PRESENT	0
623922	621408	19543W	PARTICIPANT	\N	PRESENT	0
623923	621408	19749K	PARTICIPANT	\N	PRESENT	0
623924	621408	08018U	PARTICIPANT	\N	PRESENT	0
623925	621408	11067R	PARTICIPANT	\N	PRESENT	0
623926	621408	20052X	PARTICIPANT	\N	PRESENT	0
623907	621408	99004R	PARTICIPANT	\N	PRESENT	0
623908	621408	19649G	PARTICIPANT	\N	PRESENT	0
623927	621408	04043D	PARTICIPANT	\N	PRESENT	0
623928	621408	14215L	PARTICIPANT	\N	PRESENT	0
623929	621408	14221J	PARTICIPANT	\N	PRESENT	0
623933	621408	20122U	PARTICIPANT	\N	PRESENT	0
623934	621408	04057K	PARTICIPANT	\N	PRESENT	0
623935	621408	11033F	PARTICIPANT	\N	PRESENT	0
623936	621408	17637T	PARTICIPANT	\N	PRESENT	0
623937	621408	14069U	PARTICIPANT	\N	PRESENT	0
623938	621408	11040E	PARTICIPANT	\N	PRESENT	0
623941	621408	19349W	PARTICIPANT	\N	PRESENT	0
623943	621408	07004J	PARTICIPANT	\N	PRESENT	0
623944	621408	11026G	PARTICIPANT	\N	PRESENT	0
623970	621402	08018U	PARTICIPANT	\N	PRESENT	0
623971	621402	11026G	PARTICIPANT	\N	PRESENT	0
623972	621402	11031D	PARTICIPANT	\N	PRESENT	0
623973	621402	11040E	PARTICIPANT	\N	PRESENT	0
623974	621402	20122U	PARTICIPANT	\N	PRESENT	0
623975	621402	11033F	PARTICIPANT	\N	PRESENT	0
623976	621402	20266L	PARTICIPANT	\N	PRESENT	0
623977	621402	19543W	PARTICIPANT	\N	PRESENT	0
623978	621402	19713W	PARTICIPANT	\N	PRESENT	0
623979	621402	19749K	PARTICIPANT	\N	PRESENT	0
623980	621402	07004J	PARTICIPANT	\N	PRESENT	0
623981	621402	20090E	PARTICIPANT	\N	PRESENT	0
623982	621402	19711U	PARTICIPANT	\N	PRESENT	0
623983	621402	04043D	PARTICIPANT	\N	PRESENT	0
623984	621402	19649G	PARTICIPANT	\N	PRESENT	0
623985	621402	19629C	PARTICIPANT	\N	PRESENT	0
623986	621402	20106U	PARTICIPANT	\N	PRESENT	0
623987	621402	14107H	PARTICIPANT	\N	PRESENT	0
623988	621402	20128B	PARTICIPANT	\N	PRESENT	0
623968	621402	99004R	PARTICIPANT	\N	PRESENT	0
623969	621402	14215L	PARTICIPANT	\N	PRESENT	0
623993	621402	19347U	PARTICIPANT	\N	PRESENT	0
623995	623858	19533U	PRESIDENT	0	PRESENT	0
623996	623858	19798U	PARTICIPANT	\N	PRESENT	1
623997	623858	19820Y	PARTICIPANT	\N	PRESENT	1
623998	623858	20114U	PARTICIPANT	\N	PRESENT	1
623999	623858	14207L	PARTICIPANT	\N	PRESENT	0
624000	623858	20096L	PARTICIPANT	\N	PRESENT	0
624001	621402	14205J	PARTICIPANT	\N	PRESENT	0
624002	621402	14207L	PARTICIPANT	\N	PRESENT	0
624003	623816	20066E	PARTICIPANT	\N	EXCUSE	0
624004	621402	14069U	PARTICIPANT	\N	PRESENT	0
624005	621402	20092G	PARTICIPANT	\N	PRESENT	0
624026	621397	08018U	PARTICIPANT	\N	PRESENT	0
624039	621397	11026G	PARTICIPANT	\N	PRESENT	0
624028	621397	19629C	PARTICIPANT	\N	PRESENT	0
624029	621397	07004J	PARTICIPANT	\N	PRESENT	0
624030	621397	20090E	PARTICIPANT	\N	PRESENT	0
624031	621397	11040E	PARTICIPANT	\N	PRESENT	0
624032	621397	14215L	PARTICIPANT	\N	PRESENT	0
624033	621397	19503N	PARTICIPANT	\N	PRESENT	0
624034	621397	11033F	PARTICIPANT	\N	PRESENT	0
624035	621397	04070G	PARTICIPANT	\N	PRESENT	0
624036	621397	20134Y	PARTICIPANT	\N	PRESENT	0
624037	621397	20128B	PARTICIPANT	\N	PRESENT	0
624038	621397	19711U	PARTICIPANT	\N	PRESENT	0
624040	621397	19749K	PARTICIPANT	\N	PRESENT	0
624041	621397	20122U	PARTICIPANT	\N	PRESENT	0
624042	621397	19543W	PARTICIPANT	\N	PRESENT	0
624043	621397	19443T	PARTICIPANT	\N	PRESENT	0
624023	621397	12041X	PARTICIPANT	\N	PRESENT	0
624025	621397	20266L	PARTICIPANT	\N	PRESENT	0
624044	621397	19347U	PARTICIPANT	\N	PRESENT	0
624045	621397	08010L	PARTICIPANT	\N	PRESENT	0
624048	621397	19741B	PARTICIPANT	\N	PRESENT	0
624049	621397	19657G	PARTICIPANT	\N	PRESENT	0
624050	621397	19399H	PARTICIPANT	\N	PRESENT	0
624051	621397	19467C	PARTICIPANT	\N	PRESENT	0
624052	621397	14205J	PARTICIPANT	\N	PRESENT	0
624053	621397	19663E	PARTICIPANT	\N	PRESENT	0
624054	621397	19533U	PARTICIPANT	\N	PRESENT	0
624055	621397	14030Q	PARTICIPANT	\N	PRESENT	0
624057	624056	04059M	PARTICIPANT	\N	PRESENT	0
624058	624056	19651A	PARTICIPANT	\N	PRESENT	1
624082	621397	14255U	PARTICIPANT	\N	PRESENT	0
624084	624083	14255U	PARTICIPANT	\N	PRESENT	0
624085	624083	19611R	PARTICIPANT	\N	PRESENT	0
624062	624056	11053K	PARTICIPANT	\N	PRESENT	0
624087	624086	14089Y	PARTICIPANT	\N	PRESENT	0
624089	624088	14255U	PARTICIPANT	\N	PRESENT	0
624065	624056	20132W	PARTICIPANT	\N	PRESENT	0
624090	624088	19611R	PARTICIPANT	\N	PRESENT	0
624067	624056	19399H	PARTICIPANT	\N	PRESENT	0
624068	624056	20056C	PARTICIPANT	\N	PRESENT	0
624069	624056	19611R	PARTICIPANT	\N	PRESENT	0
624070	624056	19699S	PARTICIPANT	\N	PRESENT	0
624071	624056	12041X	PARTICIPANT	\N	PRESENT	0
624072	624056	20142Y	PARTICIPANT	\N	PRESENT	0
624073	624056	19705W	PARTICIPANT	\N	PRESENT	0
624074	624056	14229S	PARTICIPANT	\N	PRESENT	0
624075	624056	19669L	PARTICIPANT	\N	PRESENT	1
624076	624056	20026V	PARTICIPANT	\N	PRESENT	1
624077	624056	20122U	PARTICIPANT	\N	PRESENT	0
624078	621397	20104S	PARTICIPANT	\N	PRESENT	0
624091	624086	19749K	PARTICIPANT	\N	PRESENT	0
624092	621397	19687N	PARTICIPANT	\N	PRESENT	0
624093	621397	19713W	PARTICIPANT	\N	PRESENT	0
624097	621397	11045K	PARTICIPANT	\N	PRESENT	0
624095	621397	19649G	PARTICIPANT	\N	PRESENT	0
624096	621397	19667J	PARTICIPANT	\N	PRESENT	0
624098	621397	14231L	PARTICIPANT	\N	PRESENT	0
624099	621397	20142Y	PARTICIPANT	\N	PRESENT	0
624100	621397	20114U	PARTICIPANT	\N	PRESENT	0
624101	621789	20066E	PARTICIPANT	\N	PRESENT	1
624102	621789	20130U	PARTICIPANT	\N	PRESENT	1
624103	621397	20092G	PARTICIPANT	\N	PRESENT	0
624104	621789	19713W	PARTICIPANT	\N	PRESENT	1
624105	621789	19691J	PARTICIPANT	\N	PRESENT	1
624106	621958	20066E	PARTICIPANT	\N	PRESENT	1
624107	621958	19691J	PARTICIPANT	\N	PRESENT	1
624108	621958	20130U	PARTICIPANT	\N	PRESENT	1
624118	621397	14083S	PARTICIPANT	\N	PRESENT	0
624128	624127	20140W	PARTICIPANT	\N	PRESENT	0
624130	624129	20140W	PARTICIPANT	\N	PRESENT	0
624134	624133	20140W	PARTICIPANT	\N	PRESENT	0
624136	624135	05008E	PARTICIPANT	\N	EXCUSE	0
600448	600443	14187A	PARTICIPANT	\N	PRESENT	0
600449	600443	19631V	PARTICIPANT	\N	PRESENT	0
600450	600443	20174H	PARTICIPANT	\N	PRESENT	0
600456	600444	14187A	PARTICIPANT	\N	PRESENT	0
600457	600444	19631V	PARTICIPANT	\N	PRESENT	0
600467	600466	19631V	PARTICIPANT	\N	PRESENT	0
600468	600465	19631V	PARTICIPANT	\N	PRESENT	0
601344	601096	19689Q	PARTICIPANT	\N	PRESENT	0
601345	601096	14223L	PARTICIPANT	\N	PRESENT	0
601346	601096	19663E	PARTICIPANT	\N	PRESENT	0
601347	601096	20152B	PARTICIPANT	\N	PRESENT	0
601348	601096	19387D	PARTICIPANT	\N	PRESENT	0
601349	601096	04047H	PARTICIPANT	\N	PRESENT	0
601350	601096	19713W	PARTICIPANT	\N	PRESENT	0
601422	601097	11031D	PARTICIPANT	\N	PRESENT	0
601423	601097	19760E	PARTICIPANT	\N	PRESENT	0
601424	601097	11067R	PARTICIPANT	\N	PRESENT	0
601425	601097	19683J	PARTICIPANT	\N	PRESENT	0
601426	601097	19663E	PARTICIPANT	\N	PRESENT	0
601427	601097	19715Y	PARTICIPANT	\N	PRESENT	0
601428	601097	19657G	PARTICIPANT	\N	PRESENT	0
601429	601097	17965H	PARTICIPANT	\N	PRESENT	0
601461	601097	20066E	PARTICIPANT	\N	PRESENT	0
601431	601097	19798U	PARTICIPANT	\N	PRESENT	0
601432	601097	04092N	PARTICIPANT	\N	PRESENT	0
601433	601097	19367Y	PARTICIPANT	\N	PRESENT	0
601434	601097	04043D	PARTICIPANT	\N	PRESENT	0
601435	601097	14213J	PARTICIPANT	\N	PRESENT	0
601436	601097	11097X	PARTICIPANT	\N	PRESENT	0
601437	601097	14195A	PARTICIPANT	\N	PRESENT	0
601438	601097	19347U	PARTICIPANT	\N	PRESENT	0
601439	601097	20130U	PARTICIPANT	\N	PRESENT	0
601440	601097	19713W	PARTICIPANT	\N	PRESENT	0
601441	601097	19387D	PARTICIPANT	\N	PRESENT	0
601442	601097	19723Y	PARTICIPANT	\N	PRESENT	0
601443	601097	20132W	PARTICIPANT	\N	PRESENT	0
601444	601097	14042U	PARTICIPANT	\N	PRESENT	0
601445	601097	17779H	PARTICIPANT	\N	PRESENT	0
601446	601097	10006L	PARTICIPANT	\N	PRESENT	0
601447	601097	14071N	PARTICIPANT	\N	PRESENT	0
601448	601097	14217N	PARTICIPANT	\N	PRESENT	0
601449	601097	19569H	PARTICIPANT	\N	PRESENT	0
601450	601097	19415P	PARTICIPANT	\N	PRESENT	0
601451	601097	08045X	PARTICIPANT	\N	PRESENT	0
601452	601097	19301E	PARTICIPANT	\N	PRESENT	0
601453	601097	19687N	PARTICIPANT	\N	PRESENT	0
601454	601097	19679N	PARTICIPANT	\N	PRESENT	0
601455	601097	19697Q	PARTICIPANT	\N	PRESENT	0
601456	601097	20126Y	PARTICIPANT	\N	PRESENT	0
601457	601097	18193Q	PARTICIPANT	\N	PRESENT	0
601458	601097	11012A	PARTICIPANT	\N	PRESENT	0
601462	601097	20252E	PARTICIPANT	\N	PRESENT	0
601460	601097	01034P	PARTICIPANT	\N	PRESENT	0
601463	601097	14083S	PARTICIPANT	\N	PRESENT	0
601464	601097	19709B	PARTICIPANT	\N	PRESENT	0
601392	600817	19697Q	PARTICIPANT	\N	PRESENT	0
601393	600817	11067R	PARTICIPANT	\N	PRESENT	0
601394	600817	19569H	PARTICIPANT	\N	PRESENT	0
601395	600817	19798U	PARTICIPANT	\N	PRESENT	0
601396	600817	11097X	PARTICIPANT	\N	PRESENT	0
601397	600817	19415P	PARTICIPANT	\N	PRESENT	0
601398	600817	18193Q	PARTICIPANT	\N	PRESENT	0
601399	600817	14223L	PARTICIPANT	\N	PRESENT	0
601400	600817	17779H	PARTICIPANT	\N	PRESENT	0
601401	600817	11031D	PARTICIPANT	\N	PRESENT	0
601402	600817	19553Y	PARTICIPANT	\N	PRESENT	0
601403	600817	19679N	PARTICIPANT	\N	PRESENT	0
601404	600817	14042U	PARTICIPANT	\N	PRESENT	0
601405	600817	14195A	PARTICIPANT	\N	PRESENT	0
601406	600817	14213J	PARTICIPANT	\N	PRESENT	0
601407	600817	14217N	PARTICIPANT	\N	PRESENT	0
601408	600817	10006L	PARTICIPANT	\N	PRESENT	0
601409	600817	20130U	PARTICIPANT	\N	PRESENT	0
601410	600817	01034P	PARTICIPANT	\N	PRESENT	0
601411	600817	04092N	PARTICIPANT	\N	PRESENT	0
601412	600817	19713W	PARTICIPANT	\N	PRESENT	0
601413	600817	19663E	PARTICIPANT	\N	PRESENT	0
601414	600817	17965H	PARTICIPANT	\N	PRESENT	0
601415	600817	19715Y	PARTICIPANT	\N	PRESENT	0
601416	600817	20148F	PARTICIPANT	\N	PRESENT	0
601417	600817	19723Y	PARTICIPANT	\N	PRESENT	0
601418	600817	14071N	PARTICIPANT	\N	PRESENT	0
601419	600817	19760E	PARTICIPANT	\N	PRESENT	0
601420	600817	04057K	PARTICIPANT	\N	EXCUSE	0
601421	601097	11045K	PARTICIPANT	\N	PRESENT	0
601465	601097	11077T	PARTICIPANT	\N	PRESENT	0
601469	601097	19553Y	PARTICIPANT	\N	PRESENT	0
601471	601097	19705W	PARTICIPANT	\N	PRESENT	0
601473	601097	20030R	PARTICIPANT	\N	PRESENT	0
601474	601097	19691J	PARTICIPANT	\N	PRESENT	0
601476	601097	11026G	PARTICIPANT	\N	PRESENT	0
601477	601097	01028R	PARTICIPANT	\N	PRESENT	0
601479	601097	14026U	PARTICIPANT	\N	PRESENT	0
602239	600212	04045F	PARTICIPANT	\N	EXCUSE	0
602240	600212	14357A	PARTICIPANT	\N	EXCUSE	0
608519	606225	14038Y	PARTICIPANT	\N	EXCUSE	0
608520	606225	04070G	PARTICIPANT	\N	EXCUSE	0
610362	610361	19575F	PARTICIPANT	\N	PRESENT	0
610363	610361	19693L	PARTICIPANT	\N	PRESENT	0
610364	610361	19663E	PARTICIPANT	\N	PRESENT	0
610365	610361	10006L	PARTICIPANT	\N	PRESENT	0
610366	610361	19723Y	PARTICIPANT	\N	PRESENT	0
610367	610361	14223L	PARTICIPANT	\N	PRESENT	0
610369	610361	19798U	PARTICIPANT	\N	PRESENT	0
610370	610361	11097X	PARTICIPANT	\N	PRESENT	0
610371	610361	19703U	PARTICIPANT	\N	PRESENT	0
610372	610361	19749K	PARTICIPANT	\N	PRESENT	0
610388	610375	10006L	PARTICIPANT	\N	PRESENT	0
610386	610375	20024T	PARTICIPANT	\N	PRESENT	0
610387	610375	19663E	PARTICIPANT	\N	PRESENT	0
610389	610375	14213J	PARTICIPANT	\N	PRESENT	0
610390	610375	19723Y	PARTICIPANT	\N	PRESENT	0
610391	610375	19798U	PARTICIPANT	\N	PRESENT	0
610392	610375	11097X	PARTICIPANT	\N	PRESENT	0
610393	610375	19703U	PARTICIPANT	\N	PRESENT	0
610394	610375	19749K	PARTICIPANT	\N	PRESENT	0
610404	608521	20046A	PARTICIPANT	\N	PRESENT	0
610436	608522	20050V	PARTICIPANT	\N	PRESENT	0
610437	608522	11048N	PARTICIPANT	\N	PRESENT	0
610438	608522	19689Q	PARTICIPANT	\N	PRESENT	0
610439	608522	19687N	PARTICIPANT	\N	PRESENT	0
610440	608522	14083S	PARTICIPANT	\N	PRESENT	0
610441	608522	19553Y	PARTICIPANT	\N	PRESENT	0
610442	608522	19711U	PARTICIPANT	\N	PRESENT	0
610443	608522	20080C	PARTICIPANT	\N	PRESENT	0
610444	608522	20122U	PARTICIPANT	\N	PRESENT	0
610445	608522	19762G	PARTICIPANT	\N	PRESENT	0
610446	608522	20036X	PARTICIPANT	\N	PRESENT	0
610447	608522	20046A	PARTICIPANT	\N	PRESENT	0
610448	608522	11053K	PARTICIPANT	\N	PRESENT	0
610449	608522	20132W	PARTICIPANT	\N	PRESENT	0
610450	608522	19647E	PARTICIPANT	\N	PRESENT	0
610451	608522	20024T	PARTICIPANT	\N	PRESENT	0
610452	608522	14021P	PARTICIPANT	\N	PRESENT	0
610453	608522	14147R	PARTICIPANT	\N	PRESENT	0
610454	608522	20048C	PARTICIPANT	\N	PRESENT	0
610455	608522	20032T	PARTICIPANT	\N	PRESENT	0
610456	608522	14097Y	PARTICIPANT	\N	PRESENT	0
610457	608522	20062A	PARTICIPANT	\N	PRESENT	0
610458	608522	20126Y	PARTICIPANT	\N	PRESENT	0
610488	610487	14097Y	PARTICIPANT	\N	PRESENT	0
610489	610487	14205J	PARTICIPANT	\N	PRESENT	0
610490	610487	08012N	PARTICIPANT	\N	PRESENT	0
610491	610487	19762G	PARTICIPANT	\N	PRESENT	0
610492	610487	20062A	PARTICIPANT	\N	PRESENT	0
610493	610487	14173T	PARTICIPANT	\N	PRESENT	0
610434	608522	11070L	PARTICIPANT	\N	PRESENT	0
610435	608522	20070A	PARTICIPANT	\N	PRESENT	0
610496	610494	14237S	PARTICIPANT	\N	PRESENT	0
610497	610494	19629C	PARTICIPANT	\N	PRESENT	0
610498	610494	19768N	PARTICIPANT	\N	PRESENT	0
610499	610494	20032T	PARTICIPANT	\N	PRESENT	0
625546	625488	19563B	PARTICIPANT	\N	PRESENT	0
625547	625488	19511N	PARTICIPANT	\N	PRESENT	0
625548	625488	14267Y	PARTICIPANT	\N	PRESENT	0
625549	625488	19747H	PARTICIPANT	\N	PRESENT	0
625550	625488	14133K	PARTICIPANT	\N	PRESENT	0
625551	625488	19415P	PARTICIPANT	\N	PRESENT	0
625552	625488	20020P	PARTICIPANT	\N	PRESENT	0
625553	625488	14257W	PARTICIPANT	\N	PRESENT	0
625554	625488	14031R	PARTICIPANT	\N	PRESENT	0
625555	625488	19693L	PARTICIPANT	\N	PRESENT	0
625556	625488	14147R	PARTICIPANT	\N	PRESENT	0
625557	625488	19954N	PARTICIPANT	\N	PRESENT	0
625558	625488	14215L	PARTICIPANT	\N	PRESENT	0
625559	625488	14357A	PARTICIPANT	\N	PRESENT	0
625560	625488	19399H	PARTICIPANT	\N	PRESENT	0
625561	625488	18083K	PARTICIPANT	\N	PRESENT	0
625562	625488	19549D	PARTICIPANT	\N	PRESENT	0
625563	625488	08060W	PARTICIPANT	\N	PRESENT	0
625564	625488	08012N	PARTICIPANT	\N	PRESENT	0
625565	625488	19820Y	PARTICIPANT	\N	PRESENT	0
625566	625488	19413M	PARTICIPANT	\N	PRESENT	0
625567	625488	11066Q	PARTICIPANT	\N	PRESENT	0
625568	625488	19715Y	PARTICIPANT	\N	PRESENT	0
625569	625488	19745F	PARTICIPANT	\N	PRESENT	0
625570	625488	14213J	PARTICIPANT	\N	PRESENT	0
625571	625488	20076G	PARTICIPANT	\N	PRESENT	0
625572	625488	19711U	PARTICIPANT	\N	PRESENT	0
625573	625488	01058X	PARTICIPANT	\N	PRESENT	0
625574	625488	14207L	PARTICIPANT	\N	PRESENT	0
625575	625488	11027H	PARTICIPANT	\N	PRESENT	0
625576	625488	19333N	PARTICIPANT	\N	PRESENT	0
625577	625488	20084G	PARTICIPANT	\N	PRESENT	0
625578	625488	19651A	PARTICIPANT	\N	PRESENT	0
625579	625488	17589D	PARTICIPANT	\N	PRESENT	0
625580	625488	04057K	PARTICIPANT	\N	PRESENT	0
625581	625488	01028R	PARTICIPANT	\N	PRESENT	0
625582	625488	19685L	PARTICIPANT	\N	PRESENT	0
625585	625488	20116W	PARTICIPANT	\N	PRESENT	0
625586	625488	17229F	PARTICIPANT	\N	PRESENT	0
625587	625488	19301E	PARTICIPANT	\N	PRESENT	0
625588	625488	19349W	PARTICIPANT	\N	PRESENT	0
625589	625488	08061X	PARTICIPANT	\N	PRESENT	0
625590	625488	19611R	PARTICIPANT	\N	PRESENT	0
625591	625488	14231L	PARTICIPANT	\N	PRESENT	0
625592	625488	11053K	PARTICIPANT	\N	PRESENT	0
625593	625488	11085T	PARTICIPANT	\N	PRESENT	0
625594	625488	11026G	PARTICIPANT	\N	PRESENT	0
625595	625488	14021P	PARTICIPANT	\N	PRESENT	0
625596	625488	19347U	PARTICIPANT	\N	PRESENT	0
625597	625488	19697Q	PARTICIPANT	\N	PRESENT	0
625598	625488	14195A	PARTICIPANT	\N	PRESENT	0
625599	625488	20050V	PARTICIPANT	\N	PRESENT	0
625607	625488	14038Y	PARTICIPANT	\N	PRESENT	0
625608	625488	20086J	PARTICIPANT	\N	PRESENT	0
625609	625488	20044X	PARTICIPANT	\N	PRESENT	0
625610	625488	19467C	PARTICIPANT	\N	PRESENT	0
625611	625488	11056N	PARTICIPANT	\N	PRESENT	0
625613	625488	19573D	PARTICIPANT	\N	PRESENT	0
625616	625488	20026V	PARTICIPANT	\N	PRESENT	0
625618	625488	20056C	PARTICIPANT	\N	PRESENT	0
625619	625488	19673G	PARTICIPANT	\N	PRESENT	0
625620	625488	19691J	PARTICIPANT	\N	PRESENT	0
625621	625488	11010L	PARTICIPANT	\N	PRESENT	0
625622	625488	11045K	PARTICIPANT	\N	PRESENT	0
625623	625488	20134Y	PARTICIPANT	\N	PRESENT	0
625624	625488	20098N	PARTICIPANT	\N	PRESENT	0
625626	625488	20100N	PARTICIPANT	\N	PRESENT	0
625628	625488	19667J	PARTICIPANT	\N	PRESENT	0
625629	625488	11048N	PARTICIPANT	\N	PRESENT	0
625630	625488	08009T	PARTICIPANT	\N	PRESENT	0
625632	625488	20140W	PARTICIPANT	\N	PRESENT	0
625633	625488	11080N	PARTICIPANT	\N	PRESENT	0
625634	625488	11043H	PARTICIPANT	\N	PRESENT	0
625635	625488	14253S	PARTICIPANT	\N	PRESENT	0
625636	625488	08047A	PARTICIPANT	\N	PRESENT	0
625637	625488	20104S	PARTICIPANT	\N	PRESENT	0
625638	625488	08015R	PARTICIPANT	\N	PRESENT	0
625639	625488	20024T	PARTICIPANT	\N	PRESENT	0
625640	625488	14259Y	PARTICIPANT	\N	PRESENT	0
625641	625488	01057W	PARTICIPANT	\N	PRESENT	0
625642	625488	20022R	PARTICIPANT	\N	PRESENT	0
625643	625488	14059S	PARTICIPANT	\N	PRESENT	0
625644	625488	20136B	PARTICIPANT	\N	PRESENT	0
625645	625488	20138D	PARTICIPANT	\N	PRESENT	0
625646	625488	05012A	PARTICIPANT	\N	PRESENT	0
625647	625488	04043D	PARTICIPANT	\N	PRESENT	0
625649	625488	19383Y	PARTICIPANT	\N	PRESENT	0
625651	625488	19762G	PARTICIPANT	\N	PRESENT	0
625652	625488	20054A	PARTICIPANT	\N	PRESENT	0
625653	625488	14205J	PARTICIPANT	\N	PRESENT	0
625654	625488	20152B	PARTICIPANT	\N	PRESENT	0
625655	625488	11115U	PARTICIPANT	\N	PRESENT	0
625658	625488	20120S	PARTICIPANT	\N	PRESENT	0
625660	625488	19701S	PARTICIPANT	\N	PRESENT	0
625661	625488	20058E	PARTICIPANT	\N	PRESENT	0
625662	625488	14071N	PARTICIPANT	\N	PRESENT	0
625663	625488	14187A	PARTICIPANT	\N	PRESENT	0
625664	625488	14053L	PARTICIPANT	\N	PRESENT	0
625665	625488	14193X	PARTICIPANT	\N	PRESENT	0
625666	625488	04033B	PARTICIPANT	\N	PRESENT	0
625667	625488	08034U	PARTICIPANT	\N	PRESENT	0
625668	625488	11097X	PARTICIPANT	\N	PRESENT	0
625669	625488	05008E	PARTICIPANT	\N	PRESENT	0
625670	625488	04042C	PARTICIPANT	\N	PRESENT	0
625671	625488	04035D	PARTICIPANT	\N	PRESENT	0
625672	625488	08011M	PARTICIPANT	\N	PRESENT	0
625673	625488	14237S	PARTICIPANT	\N	PRESENT	0
625674	625488	10006L	PARTICIPANT	\N	PRESENT	0
625675	625488	04047H	PARTICIPANT	\N	PRESENT	0
625676	625488	19703U	PARTICIPANT	\N	PRESENT	0
625677	625488	17637T	PARTICIPANT	\N	PRESENT	0
625678	625488	99004R	PARTICIPANT	\N	PRESENT	0
625679	625488	14217N	PARTICIPANT	\N	PRESENT	0
625680	625488	19621T	PARTICIPANT	\N	PRESENT	0
625681	625488	20034V	PARTICIPANT	\N	PRESENT	0
625682	625488	14169X	PARTICIPANT	\N	PRESENT	0
625683	625488	19719D	PARTICIPANT	\N	PRESENT	0
625684	625488	20132W	PARTICIPANT	\N	PRESENT	0
625685	625488	20072C	PARTICIPANT	\N	PRESENT	0
625687	625488	04059M	PARTICIPANT	\N	PRESENT	0
625691	625488	17965H	PARTICIPANT	\N	PRESENT	0
625693	625488	20114U	PARTICIPANT	\N	PRESENT	0
625694	625488	14179A	PARTICIPANT	\N	PRESENT	0
625695	625488	04070G	PARTICIPANT	\N	PRESENT	0
625701	625488	20070A	PARTICIPANT	\N	PRESENT	0
625702	625488	20088L	PARTICIPANT	\N	PRESENT	0
625703	625488	11074Q	PARTICIPANT	\N	PRESENT	0
625704	625488	11033F	PARTICIPANT	\N	PRESENT	0
625705	625488	19647E	PARTICIPANT	\N	PRESENT	0
625707	625488	19599P	PARTICIPANT	\N	PRESENT	0
625708	625488	19689Q	PARTICIPANT	\N	PRESENT	0
625709	625488	01048V	PARTICIPANT	\N	PRESENT	0
625710	625488	20038A	PARTICIPANT	\N	PRESENT	0
625711	625488	19447X	PARTICIPANT	\N	PRESENT	0
625712	625488	14069U	PARTICIPANT	\N	PRESENT	0
625713	625488	19251M	PARTICIPANT	\N	PRESENT	0
625714	625488	14121F	PARTICIPANT	\N	PRESENT	0
625715	625488	19649G	PARTICIPANT	\N	PRESENT	0
625716	625488	14001X	PARTICIPANT	\N	PRESENT	0
625717	625488	11067R	PARTICIPANT	\N	PRESENT	0
625718	625488	19503N	PARTICIPANT	\N	PRESENT	0
625719	625488	20082E	PARTICIPANT	\N	PRESENT	0
625720	625488	19527W	PARTICIPANT	\N	PRESENT	0
600921	600765	19719D	PARTICIPANT	\N	PRESENT	1
600922	600765	14030Q	PARTICIPANT	\N	PRESENT	1
600923	600765	20180F	PARTICIPANT	\N	PRESENT	1
600924	600765	20026V	PARTICIPANT	\N	PRESENT	1
600925	600766	19719D	PARTICIPANT	\N	PRESENT	1
600926	600766	20180F	PARTICIPANT	\N	PRESENT	1
600927	600698	19399H	PARTICIPANT	\N	PRESENT	1
600928	600698	20132W	PARTICIPANT	\N	PRESENT	1
600929	600698	20142Y	PARTICIPANT	\N	PRESENT	1
607221	607218	19760E	PARTICIPANT	\N	PRESENT	0
607222	607219	19760E	PARTICIPANT	\N	PRESENT	0
607223	607219	20130U	PARTICIPANT	\N	PRESENT	0
607224	607219	19713W	PARTICIPANT	\N	PRESENT	0
607225	607219	18193Q	PARTICIPANT	\N	PRESENT	0
607226	607219	14042U	PARTICIPANT	\N	PRESENT	0
607228	607227	19760E	PARTICIPANT	\N	PRESENT	0
607229	607227	14042U	PARTICIPANT	\N	PRESENT	0
607230	607227	20130U	PARTICIPANT	\N	PRESENT	0
607231	607227	18193Q	PARTICIPANT	\N	PRESENT	0
608633	608632	08012N	PARTICIPANT	\N	PRESENT	1
608634	608632	11043H	PARTICIPANT	\N	PRESENT	1
608693	608692	19693L	PARTICIPANT	\N	PRESENT	0
608694	608692	19593H	PARTICIPANT	\N	PRESENT	0
610573	610506	20130U	PRESIDENT	0	PRESENT	0
610574	610506	19703U	PARTICIPANT	\N	PRESENT	0
610575	610506	19467C	PARTICIPANT	\N	PRESENT	0
610576	610506	11031D	PARTICIPANT	\N	PRESENT	0
610577	610506	20062A	PARTICIPANT	\N	PRESENT	0
610578	610506	19713W	PARTICIPANT	\N	PRESENT	0
610579	610506	14147R	PRESIDENT	1	PRESENT	0
610580	610506	10006L	PARTICIPANT	\N	PRESENT	0
610581	610506	19723Y	PARTICIPANT	\N	PRESENT	0
610582	610506	04092N	PARTICIPANT	\N	EXCUSE	0
610583	610506	01062T	PARTICIPANT	\N	EXCUSE	0
610584	610506	19735D	PARTICIPANT	\N	EXCUSE	0
610585	610506	19691J	PARTICIPANT	\N	EXCUSE	0
610586	610506	19683J	PARTICIPANT	\N	EXCUSE	0
610597	610544	14069U	PARTICIPANT	\N	EXCUSE	0
611614	611613	20114U	PARTICIPANT	\N	PRESENT	0
611615	611613	20056C	PARTICIPANT	\N	PRESENT	0
611616	611613	19735D	PARTICIPANT	\N	PRESENT	0
611617	611613	20052X	PARTICIPANT	\N	PRESENT	0
611618	611613	20142Y	PARTICIPANT	\N	PRESENT	0
611619	611613	14147R	PARTICIPANT	\N	PRESENT	0
611620	611613	14229S	PARTICIPANT	\N	PRESENT	0
611621	611613	20084G	PARTICIPANT	\N	PRESENT	0
611622	611613	20026V	PARTICIPANT	\N	PRESENT	0
613382	613379	05008E	PARTICIPANT	\N	PRESENT	0
613383	613379	11053K	PARTICIPANT	\N	PRESENT	0
613384	613379	01028R	PARTICIPANT	\N	PRESENT	0
613816	613815	14133K	PARTICIPANT	\N	PRESENT	0
616040	613304	14173T	PARTICIPANT	\N	EXCUSE	0
616062	616061	11048N	PARTICIPANT	\N	PRESENT	0
616063	616061	08011M	PARTICIPANT	\N	PRESENT	0
616667	616274	19954N	PARTICIPANT	\N	PRESENT	0
616668	616274	19643A	PARTICIPANT	\N	PRESENT	0
616669	616274	19533U	PRESIDENT	0	PRESENT	0
616670	616274	19798U	PARTICIPANT	\N	PRESENT	0
616671	616274	20042V	PARTICIPANT	\N	PRESENT	0
616672	616274	19820Y	PARTICIPANT	\N	PRESENT	0
616673	616274	14215L	PARTICIPANT	\N	PRESENT	0
616674	616274	19599P	PARTICIPANT	\N	PRESENT	0
616675	616274	20124W	PARTICIPANT	\N	PRESENT	0
616676	616274	20096L	PARTICIPANT	\N	PRESENT	0
616678	616387	20042V	PARTICIPANT	\N	PRESENT	0
616681	616387	19643A	PARTICIPANT	\N	PRESENT	0
616682	616387	19760E	PARTICIPANT	\N	PRESENT	0
616683	616387	19719D	PARTICIPANT	\N	PRESENT	0
616684	616387	19443T	PARTICIPANT	\N	PRESENT	0
616685	616387	14207L	PARTICIPANT	\N	PRESENT	0
616686	616387	19826F	PARTICIPANT	\N	PRESENT	0
616687	616387	20064C	PARTICIPANT	\N	PRESENT	0
616688	616387	20068G	PARTICIPANT	\N	PRESENT	0
616689	616387	20058E	PARTICIPANT	\N	PRESENT	0
616690	616387	20056C	PARTICIPANT	\N	PRESENT	0
616691	616387	19611R	PARTICIPANT	\N	PRESENT	0
616692	616387	14123H	PARTICIPANT	\N	PRESENT	0
616693	616387	19693L	PARTICIPANT	\N	PRESENT	0
616694	616387	19591F	PARTICIPANT	\N	PRESENT	0
616755	616388	20264J	PARTICIPANT	\N	PRESENT	0
616756	616388	19591F	PARTICIPANT	\N	PRESENT	0
616757	616388	20050V	PARTICIPANT	\N	PRESENT	0
616758	616388	19693L	PARTICIPANT	\N	PRESENT	0
616759	616388	20142Y	PARTICIPANT	\N	PRESENT	0
616760	616388	11033F	PARTICIPANT	\N	PRESENT	0
616761	616388	20110Q	PARTICIPANT	\N	PRESENT	0
616762	616388	20052X	PARTICIPANT	\N	PRESENT	0
616763	616388	20132W	PARTICIPANT	\N	PRESENT	0
616764	616388	11012A	PARTICIPANT	\N	PRESENT	0
616765	616388	19719D	PARTICIPANT	\N	PRESENT	0
616766	616388	14207L	PARTICIPANT	\N	PRESENT	0
616767	616388	20114U	PARTICIPANT	\N	PRESENT	0
616768	616388	20152B	PARTICIPANT	\N	PRESENT	0
616769	616388	19643A	PARTICIPANT	\N	PRESENT	0
616770	616388	20180F	PARTICIPANT	\N	PRESENT	0
616771	616388	20064C	PARTICIPANT	\N	PRESENT	0
616772	616388	11026G	PARTICIPANT	\N	PRESENT	0
616773	616388	19549D	PARTICIPANT	\N	PRESENT	0
616774	616388	20092G	PARTICIPANT	\N	PRESENT	0
616775	616388	20174H	PARTICIPANT	\N	PRESENT	0
616776	616388	14219Q	PARTICIPANT	\N	PRESENT	0
616777	616388	14042U	PARTICIPANT	\N	PRESENT	0
616778	616388	01024M	PARTICIPANT	\N	PRESENT	0
616779	616388	19826F	PARTICIPANT	\N	PRESENT	0
616780	616388	20248J	PARTICIPANT	\N	PRESENT	0
616781	616388	14089Y	PARTICIPANT	\N	PRESENT	0
616782	616388	20046A	PARTICIPANT	\N	PRESENT	0
616783	616388	20102Q	PARTICIPANT	\N	PRESENT	0
616784	616388	19565D	PARTICIPANT	\N	PRESENT	0
616785	616388	14069U	PARTICIPANT	\N	PRESENT	0
616786	616388	08028W	PARTICIPANT	\N	PRESENT	0
616787	616388	20068G	PARTICIPANT	\N	PRESENT	0
616794	616388	14073Q	PARTICIPANT	\N	PRESENT	0
616789	616388	19533U	PARTICIPANT	\N	PRESENT	0
616790	616388	14221J	PARTICIPANT	\N	PRESENT	0
616791	616388	20056C	PARTICIPANT	\N	PRESENT	0
616792	616388	19593H	PARTICIPANT	\N	PRESENT	0
616793	616388	14033T	PARTICIPANT	\N	PRESENT	0
616797	616388	20026V	PARTICIPANT	\N	PRESENT	0
616798	616388	20042V	PARTICIPANT	\N	PRESENT	0
616799	616388	20090E	PARTICIPANT	\N	PRESENT	0
616800	616388	97011G	PARTICIPANT	\N	PRESENT	0
616801	616388	14217N	PARTICIPANT	\N	PRESENT	0
616802	616388	14147R	PARTICIPANT	\N	PRESENT	0
616803	616388	11097X	PARTICIPANT	\N	PRESENT	0
616805	616388	20032T	PARTICIPANT	\N	PRESENT	0
616806	616388	19503N	PARTICIPANT	\N	PRESENT	0
616807	616388	20082E	PARTICIPANT	\N	PRESENT	0
616808	616388	19479G	PARTICIPANT	\N	PRESENT	0
616809	616388	19739H	PARTICIPANT	\N	PRESENT	0
616810	616388	19347U	PARTICIPANT	\N	PRESENT	0
616811	616388	19703U	PARTICIPANT	\N	PRESENT	0
616812	616388	19713W	PARTICIPANT	\N	PRESENT	0
616813	616388	19782L	PARTICIPANT	\N	PRESENT	0
616814	616388	19467C	PARTICIPANT	\N	PRESENT	0
616815	616388	19369B	PARTICIPANT	\N	PRESENT	0
616816	616388	19415P	PARTICIPANT	\N	PRESENT	0
616753	616388	14026U	PARTICIPANT	\N	PRESENT	0
616754	616388	19611R	PARTICIPANT	\N	PRESENT	0
616817	616388	20062A	PARTICIPANT	\N	PRESENT	0
616818	616388	19695N	PARTICIPANT	\N	PRESENT	0
616819	616388	19441R	PARTICIPANT	\N	PRESENT	0
616820	616388	20140W	PARTICIPANT	\N	PRESENT	0
624137	624135	14259Y	PARTICIPANT	\N	EXCUSE	0
624139	621397	11065P	PARTICIPANT	\N	PRESENT	0
624147	624024	20024T	PARTICIPANT	\N	EXCUSE	0
624196	624195	14327T	PARTICIPANT	\N	PRESENT	0
624218	621405	20074E	PARTICIPANT	\N	PRESENT	1
624245	624242	14217N	PARTICIPANT	\N	PRESENT	0
624246	624242	20248J	PARTICIPANT	\N	PRESENT	0
624247	624242	11067R	PARTICIPANT	\N	PRESENT	0
624248	624241	14217N	PARTICIPANT	\N	PRESENT	0
624249	624241	20248J	PARTICIPANT	\N	PRESENT	0
624250	624241	11067R	PARTICIPANT	\N	PRESENT	0
624251	624240	14217N	PARTICIPANT	\N	PRESENT	0
624252	624240	20248J	PARTICIPANT	\N	PRESENT	0
624253	624240	11067R	PARTICIPANT	\N	PRESENT	0
624254	624243	10006L	PARTICIPANT	\N	PRESENT	0
624255	624243	14147R	PARTICIPANT	\N	PRESENT	0
624256	624243	20062A	PARTICIPANT	\N	PRESENT	0
624257	624243	19301E	PARTICIPANT	\N	PRESENT	0
624258	624243	19553Y	PARTICIPANT	\N	PRESENT	0
624259	624243	11031D	PARTICIPANT	\N	PRESENT	0
624260	624243	19703U	PARTICIPANT	\N	PRESENT	0
624261	624244	11031D	PARTICIPANT	\N	PRESENT	0
624262	624244	10006L	PARTICIPANT	\N	PRESENT	0
624263	624244	19691J	PARTICIPANT	\N	PRESENT	0
624264	624244	19553Y	PARTICIPANT	\N	PRESENT	0
624265	624244	14147R	PARTICIPANT	\N	PRESENT	0
624266	624244	20062A	PARTICIPANT	\N	PRESENT	0
624267	624244	19301E	PARTICIPANT	\N	PRESENT	0
624268	624244	19703U	PARTICIPANT	\N	PRESENT	0
624271	624135	14331P	PARTICIPANT	\N	EXCUSE	0
624275	624274	10015M	PARTICIPANT	\N	PRESENT	0
624276	624274	11026G	PARTICIPANT	\N	PRESENT	0
624277	624274	14189C	PARTICIPANT	\N	PRESENT	0
624408	624145	19713W	PARTICIPANT	\N	PRESENT	0
624409	624145	11097X	PARTICIPANT	\N	PRESENT	0
624410	624145	20040T	PARTICIPANT	\N	PRESENT	0
624411	624145	19415P	PARTICIPANT	\N	PRESENT	0
624412	624145	19691J	PARTICIPANT	\N	PRESENT	0
624413	624145	14026U	PARTICIPANT	\N	PRESENT	0
624414	624145	19703U	PARTICIPANT	\N	PRESENT	0
624415	624145	11031D	PARTICIPANT	\N	PRESENT	0
624416	624145	14195A	PARTICIPANT	\N	PRESENT	0
624417	624145	14071N	PARTICIPANT	\N	PRESENT	0
624418	624145	11067R	PARTICIPANT	\N	EXCUSE	0
624419	624145	19295A	PARTICIPANT	\N	EXCUSE	0
624420	624145	19591F	PARTICIPANT	\N	PRESENT	1
624421	624149	19503N	PARTICIPANT	\N	PRESENT	0
624422	624149	19651A	PARTICIPANT	\N	PRESENT	0
624423	624149	19387D	PARTICIPANT	\N	PRESENT	0
624424	624149	14207L	PARTICIPANT	\N	PRESENT	0
624425	624149	95063L	PARTICIPANT	\N	PRESENT	0
624426	624149	01057W	PARTICIPANT	\N	PRESENT	0
624427	624149	14267Y	PARTICIPANT	\N	PRESENT	0
624428	624149	20062A	PARTICIPANT	\N	PRESENT	0
624429	624149	19637C	PARTICIPANT	\N	PRESENT	0
624430	624149	19954N	PARTICIPANT	\N	PRESENT	0
624431	624149	20070A	PARTICIPANT	\N	PRESENT	0
624432	624149	20122U	PARTICIPANT	\N	PRESENT	0
624433	624149	14259Y	PARTICIPANT	\N	PRESENT	0
624434	624149	14219Q	PARTICIPANT	\N	PRESENT	0
624435	624149	19441R	PARTICIPANT	\N	PRESENT	0
624436	624149	08028W	PARTICIPANT	\N	PRESENT	0
624437	624149	20044X	PARTICIPANT	\N	PRESENT	0
624438	624149	19671E	PARTICIPANT	\N	PRESENT	0
624439	624149	19421M	PARTICIPANT	\N	PRESENT	0
624440	624149	11065P	PARTICIPANT	\N	PRESENT	0
624441	624149	19758L	PARTICIPANT	\N	PRESENT	0
624442	624149	20046A	PARTICIPANT	\N	PRESENT	0
624443	624149	20100N	PARTICIPANT	\N	PRESENT	0
624444	624149	20102Q	PARTICIPANT	\N	PRESENT	0
624445	624149	14030Q	PARTICIPANT	\N	PRESENT	0
624446	624149	19768N	PARTICIPANT	\N	PRESENT	0
624447	624149	11097X	PARTICIPANT	\N	PRESENT	0
624448	624149	20090E	PARTICIPANT	\N	PRESENT	0
624449	624149	20038A	PARTICIPANT	\N	PRESENT	0
624450	624149	20112S	PARTICIPANT	\N	PRESENT	0
624451	624149	20124W	PARTICIPANT	\N	PRESENT	0
624452	624149	19575F	PARTICIPANT	\N	PRESENT	0
624453	624149	19367Y	PARTICIPANT	\N	PRESENT	0
624454	624149	19820Y	PARTICIPANT	\N	PRESENT	0
624455	624149	11056N	PARTICIPANT	\N	PRESENT	0
624456	624149	20116W	PARTICIPANT	\N	PRESENT	0
624457	624149	20026V	PARTICIPANT	\N	PRESENT	0
624458	624149	19747H	PARTICIPANT	\N	PRESENT	0
624459	624149	20140W	PARTICIPANT	\N	PRESENT	0
624460	624149	14107H	PARTICIPANT	\N	PRESENT	0
624461	624024	11056N	PRESIDENT	0	PRESENT	0
624462	624024	14089Y	PARTICIPANT	\N	PRESENT	0
624463	624149	20286Q	PARTICIPANT	\N	PRESENT	0
624464	624149	14033T	PARTICIPANT	\N	PRESENT	0
624465	624024	14225N	PARTICIPANT	\N	EXCUSE	0
624466	624149	20058E	PARTICIPANT	\N	PRESENT	0
624467	624149	20032T	PARTICIPANT	\N	PRESENT	0
624468	624149	19349W	PARTICIPANT	\N	PRESENT	0
624469	624149	19319Q	PARTICIPANT	\N	PRESENT	0
624470	624024	17367Q	PARTICIPANT	\N	PRESENT	0
624471	624024	19749K	PARTICIPANT	\N	PRESENT	0
624472	624024	20098N	PARTICIPANT	\N	PRESENT	1
624474	624024	14107H	PARTICIPANT	\N	PRESENT	0
624482	624024	11026G	PARTICIPANT	\N	PRESENT	0
624486	624024	19826F	PARTICIPANT	\N	PRESENT	0
624499	624024	19563B	PARTICIPANT	\N	PRESENT	1
624778	623421	19647E	PARTICIPANT	\N	PRESENT	0
624779	623421	11048N	PARTICIPANT	\N	PRESENT	0
624780	623421	01057W	PARTICIPANT	\N	PRESENT	0
624781	623421	11074Q	PARTICIPANT	\N	PRESENT	0
624782	623421	14225N	PRESIDENT	0	PRESENT	0
624783	623421	20070A	PARTICIPANT	\N	PRESENT	0
624784	623421	19479G	PARTICIPANT	\N	PRESENT	0
624826	623421	14189C	PARTICIPANT	\N	PRESENT	1
624827	623421	14121F	PARTICIPANT	\N	PRESENT	1
624828	623421	99004R	PARTICIPANT	\N	PRESENT	1
624829	623421	20126Y	PARTICIPANT	\N	PRESENT	1
624830	623421	19671E	PARTICIPANT	\N	PRESENT	1
624874	624150	08061X	PARTICIPANT	\N	PRESENT	0
624875	624150	19954N	PARTICIPANT	\N	PRESENT	0
624876	624150	04045F	PARTICIPANT	\N	PRESENT	0
624877	624150	14207L	PARTICIPANT	\N	PRESENT	0
624878	624150	20092G	PARTICIPANT	\N	PRESENT	0
624879	624150	08010L	PARTICIPANT	\N	PRESENT	0
624880	624150	16685X	PARTICIPANT	\N	PRESENT	0
624881	624150	20048C	PARTICIPANT	\N	PRESENT	0
624882	624150	19347U	PARTICIPANT	\N	PRESENT	0
624883	624150	14033T	PARTICIPANT	\N	PRESENT	0
624884	624150	14030Q	PARTICIPANT	\N	PRESENT	0
624885	624150	12041X	PARTICIPANT	\N	PRESENT	0
624886	624150	20046A	PARTICIPANT	\N	PRESENT	0
624887	624150	20102Q	PARTICIPANT	\N	PRESENT	0
624950	624151	12041X	PARTICIPANT	\N	PRESENT	0
624951	624151	20090E	PARTICIPANT	\N	PRESENT	0
624952	624151	19798U	PARTICIPANT	\N	PRESENT	0
624953	624151	19367Y	PARTICIPANT	\N	PRESENT	0
624954	624151	20110Q	PARTICIPANT	\N	PRESENT	0
624955	624151	20100N	PARTICIPANT	\N	PRESENT	0
624956	624151	14195A	PARTICIPANT	\N	PRESENT	0
624957	624151	20114U	PARTICIPANT	\N	PRESENT	0
624958	624151	17737W	PARTICIPANT	\N	PRESENT	0
624959	624151	20136B	PARTICIPANT	\N	PRESENT	0
624960	624151	19760E	PARTICIPANT	\N	PRESENT	0
624961	624151	19679N	PARTICIPANT	\N	PRESENT	0
624962	624151	19565D	PARTICIPANT	\N	PRESENT	0
624963	624151	20034V	PARTICIPANT	\N	PRESENT	0
624964	624151	19573D	PARTICIPANT	\N	PRESENT	0
624965	624151	07029T	PARTICIPANT	\N	PRESENT	0
624966	624151	11033F	PARTICIPANT	\N	PRESENT	0
624967	624151	95041E	PARTICIPANT	\N	PRESENT	0
624968	624151	19447X	PARTICIPANT	\N	PRESENT	0
624969	624151	19663E	PARTICIPANT	\N	PRESENT	0
624970	624151	11012A	PARTICIPANT	\N	PRESENT	0
624971	624151	20072C	PARTICIPANT	\N	PRESENT	0
624972	624151	19782L	PARTICIPANT	\N	PRESENT	0
624973	624151	17965H	PARTICIPANT	\N	PRESENT	0
624974	624151	20052X	PARTICIPANT	\N	PRESENT	0
624975	624151	20084G	PARTICIPANT	\N	PRESENT	0
624976	624151	14042U	PARTICIPANT	\N	PRESENT	0
624977	624151	20248J	PARTICIPANT	\N	PRESENT	0
624978	624151	17779H	PARTICIPANT	\N	PRESENT	0
624979	624151	20070A	PARTICIPANT	\N	PRESENT	0
624980	624151	20038A	PARTICIPANT	\N	PRESENT	0
624981	624151	19703U	PARTICIPANT	\N	PRESENT	0
624982	624151	14215L	PARTICIPANT	\N	PRESENT	0
602944	602943	14089Y	PARTICIPANT	\N	PRESENT	0
602945	602943	19447X	PARTICIPANT	\N	PRESENT	0
602948	602946	14089Y	PARTICIPANT	\N	PRESENT	0
602949	602946	19447X	PARTICIPANT	\N	PRESENT	0
602950	602946	11026G	PARTICIPANT	\N	PRESENT	0
602955	602951	14089Y	PARTICIPANT	\N	PRESENT	0
602958	602951	19447X	PARTICIPANT	\N	PRESENT	0
602964	602963	14089Y	PARTICIPANT	\N	PRESENT	0
602965	602963	19447X	PARTICIPANT	\N	PRESENT	0
606137	606136	20092G	PARTICIPANT	\N	PRESENT	0
606462	603155	99004R	PARTICIPANT	\N	PRESENT	0
606463	603155	11048N	PARTICIPANT	\N	PRESENT	0
606465	603155	14225N	PARTICIPANT	\N	PRESENT	0
606466	603155	19689Q	PARTICIPANT	\N	PRESENT	0
606467	603155	20100N	PARTICIPANT	\N	PRESENT	0
606468	603155	19593H	PARTICIPANT	\N	PRESENT	0
606469	603155	20062A	PARTICIPANT	\N	PRESENT	0
606470	603155	20044X	PARTICIPANT	\N	PRESENT	0
606471	603155	14327T	PARTICIPANT	\N	PRESENT	0
606472	603155	11040E	PARTICIPANT	\N	PRESENT	0
606473	603155	20080C	PARTICIPANT	\N	PRESENT	0
606474	603155	19647E	PARTICIPANT	\N	PRESENT	0
606475	603155	19711U	PARTICIPANT	\N	PRESENT	0
606476	603155	20116W	PARTICIPANT	\N	PRESENT	0
606477	603155	11053K	PARTICIPANT	\N	PRESENT	0
606478	603155	19349W	PARTICIPANT	\N	PRESENT	0
606479	603155	19669L	PARTICIPANT	\N	PRESENT	0
606480	603155	07029T	PARTICIPANT	\N	PRESENT	0
606481	603155	19687N	PARTICIPANT	\N	PRESENT	0
606482	603155	19545Y	PARTICIPANT	\N	PRESENT	0
606483	603155	11070L	PARTICIPANT	\N	PRESENT	0
606484	603155	14083S	PARTICIPANT	\N	PRESENT	0
606485	603155	19715Y	PARTICIPANT	\N	PRESENT	0
606486	603155	19503N	PARTICIPANT	\N	PRESENT	0
606487	603155	20070A	PARTICIPANT	\N	PRESENT	0
606488	603155	20112S	PARTICIPANT	\N	PRESENT	0
606489	603155	01057W	PARTICIPANT	\N	PRESENT	0
606490	603155	20252E	PARTICIPANT	\N	PRESENT	0
606491	603155	20022R	PARTICIPANT	\N	PRESENT	0
606492	603155	08010L	PARTICIPANT	\N	PRESENT	0
606496	603155	19705W	PARTICIPANT	\N	PRESENT	0
606497	603155	19657G	PARTICIPANT	\N	PRESENT	0
606498	603155	19301E	PARTICIPANT	\N	PRESENT	0
606499	603155	20036X	PARTICIPANT	\N	PRESENT	0
606500	603155	11031D	PARTICIPANT	\N	PRESENT	0
606501	603155	20034V	PARTICIPANT	\N	PRESENT	0
606505	603155	14331P	PARTICIPANT	\N	PRESENT	0
606503	603155	19693L	PARTICIPANT	\N	PRESENT	0
606504	603155	12016W	PARTICIPANT	\N	PRESENT	0
606506	603155	20086J	PARTICIPANT	\N	PRESENT	0
606507	603155	04071H	PARTICIPANT	\N	PRESENT	0
606508	603155	19479G	PARTICIPANT	\N	PRESENT	0
606510	603155	19295A	PARTICIPANT	\N	PRESENT	0
606511	603155	11085T	PARTICIPANT	\N	PRESENT	0
606513	603155	19667J	PARTICIPANT	\N	PRESENT	0
606516	603155	20054A	PARTICIPANT	\N	PRESENT	0
606556	603156	19689Q	PARTICIPANT	\N	PRESENT	0
606557	603156	20100N	PARTICIPANT	\N	PRESENT	0
606558	603156	19301E	PARTICIPANT	\N	PRESENT	0
606559	603156	19349W	PARTICIPANT	\N	PRESENT	0
606560	603156	20116W	PARTICIPANT	\N	PRESENT	0
606561	603156	20112S	PARTICIPANT	\N	PRESENT	0
606562	603156	11040E	PARTICIPANT	\N	PRESENT	0
606563	603156	14327T	PARTICIPANT	\N	PRESENT	0
606564	603156	11053K	PARTICIPANT	\N	PRESENT	0
606565	603156	19711U	PARTICIPANT	\N	PRESENT	0
606566	603156	20062A	PARTICIPANT	\N	PRESENT	0
606567	603156	19657G	PARTICIPANT	\N	PRESENT	0
606568	603156	07029T	PARTICIPANT	\N	PRESENT	0
606569	603156	20044X	PARTICIPANT	\N	PRESENT	0
606570	603156	19667J	PARTICIPANT	\N	PRESENT	0
606571	603156	19693L	PARTICIPANT	\N	PRESENT	0
606572	603156	14225N	PARTICIPANT	\N	PRESENT	0
606573	603156	11048N	PARTICIPANT	\N	PRESENT	0
606574	603156	12016W	PARTICIPANT	\N	PRESENT	0
606575	603156	20022R	PARTICIPANT	\N	PRESENT	0
606576	603156	20034V	PARTICIPANT	\N	PRESENT	0
606577	603156	19647E	PARTICIPANT	\N	PRESENT	0
606578	603156	20080C	PARTICIPANT	\N	PRESENT	0
606579	603156	20070A	PARTICIPANT	\N	PRESENT	0
606580	603156	19479G	PARTICIPANT	\N	PRESENT	0
606581	603156	95063L	PARTICIPANT	\N	PRESENT	0
606582	603156	19715Y	PARTICIPANT	\N	PRESENT	0
606583	603156	19295A	PARTICIPANT	\N	PRESENT	0
606584	603156	04071H	PARTICIPANT	\N	PRESENT	0
606585	603156	14083S	PARTICIPANT	\N	PRESENT	0
606586	603156	20086J	PARTICIPANT	\N	PRESENT	0
606587	603156	19545Y	PARTICIPANT	\N	PRESENT	0
606588	603156	20054A	PARTICIPANT	\N	PRESENT	0
606589	603156	08011M	PARTICIPANT	\N	PRESENT	0
606590	603156	20124W	PARTICIPANT	\N	PRESENT	0
606591	603156	01057W	PARTICIPANT	\N	PRESENT	0
606592	603156	08010L	PARTICIPANT	\N	PRESENT	0
606554	603156	11070L	PARTICIPANT	\N	PRESENT	0
606555	603156	20036X	PARTICIPANT	\N	PRESENT	0
606593	603156	20252E	PARTICIPANT	\N	PRESENT	0
606594	603156	20094J	PARTICIPANT	\N	PRESENT	0
606595	603156	19533U	PARTICIPANT	\N	PRESENT	0
606596	603156	14331P	PARTICIPANT	\N	PRESENT	0
606597	603156	14026U	PARTICIPANT	\N	PRESENT	0
606598	603156	19503N	PARTICIPANT	\N	PRESENT	0
608697	608696	19693L	PARTICIPANT	\N	PRESENT	0
608698	608696	19593H	PARTICIPANT	\N	PRESENT	0
610243	610241	14215L	PARTICIPANT	\N	PRESENT	0
610500	610494	19503N	PARTICIPANT	\N	PRESENT	0
610501	610494	97011G	PARTICIPANT	\N	PRESENT	0
610502	610494	20024T	PARTICIPANT	\N	PRESENT	0
610503	610494	14189C	PARTICIPANT	\N	PRESENT	0
610504	610494	19575F	PARTICIPANT	\N	PRESENT	0
610505	610494	19643A	PARTICIPANT	\N	PRESENT	0
610524	610495	19760E	PARTICIPANT	\N	PRESENT	0
610525	610495	18083K	PRESIDENT	0	PRESENT	0
610526	610495	14031R	PARTICIPANT	\N	PRESENT	0
610527	610495	20266L	PARTICIPANT	\N	PRESENT	0
610528	610495	17965H	PARTICIPANT	\N	PRESENT	0
610529	610495	18193Q	PARTICIPANT	\N	PRESENT	0
610532	610495	20034V	PARTICIPANT	\N	EXCUSE	0
610788	610787	17023S	PARTICIPANT	\N	PRESENT	0
610791	610790	18083K	PARTICIPANT	\N	PRESENT	0
610792	610790	19673G	PARTICIPANT	\N	PRESENT	0
610793	610790	14033T	PARTICIPANT	\N	PRESENT	0
611524	611522	20132W	PARTICIPANT	\N	PRESENT	1
611525	611522	04070G	PARTICIPANT	\N	PRESENT	1
611526	611522	19593H	PARTICIPANT	\N	PRESENT	1
611527	611522	20084G	PARTICIPANT	\N	PRESENT	1
611531	611521	04070G	PARTICIPANT	\N	PRESENT	1
611532	611521	20084G	PARTICIPANT	\N	PRESENT	1
611533	611521	19593H	PARTICIPANT	\N	PRESENT	1
611534	611521	20132W	PARTICIPANT	\N	PRESENT	1
611535	611523	04070G	PARTICIPANT	\N	PRESENT	1
611536	611523	19593H	PARTICIPANT	\N	PRESENT	1
611537	611523	20084G	PARTICIPANT	\N	PRESENT	1
611538	611523	20132W	PARTICIPANT	\N	PRESENT	1
613322	613321	19701S	PARTICIPANT	\N	PRESENT	0
613323	613321	11026G	PARTICIPANT	\N	PRESENT	0
613329	613325	19701S	PARTICIPANT	\N	PRESENT	0
613330	613325	11026G	PARTICIPANT	\N	PRESENT	0
614141	614113	20110Q	PARTICIPANT	\N	PRESENT	0
614142	614113	01057W	PARTICIPANT	\N	PRESENT	0
614143	614113	05012A	PARTICIPANT	\N	PRESENT	0
614144	614113	04045F	PARTICIPANT	\N	PRESENT	0
614145	614113	08010L	PARTICIPANT	\N	PRESENT	0
614146	614113	19489J	PARTICIPANT	\N	PRESENT	0
614147	614113	14053L	PARTICIPANT	\N	PRESENT	0
614148	614113	14069U	PARTICIPANT	\N	PRESENT	0
614149	614113	19565D	PARTICIPANT	\N	PRESENT	0
614150	614113	14231L	PRESIDENT	0	PRESENT	0
614151	614113	14257W	PARTICIPANT	\N	PRESENT	0
614152	614113	20122U	PARTICIPANT	\N	EXCUSE	0
614153	614113	19681G	PARTICIPANT	\N	EXCUSE	0
614154	614113	14327T	PARTICIPANT	\N	EXCUSE	0
614155	614113	20058E	PARTICIPANT	\N	EXCUSE	0
614156	614113	14281W	PARTICIPANT	\N	EXCUSE	0
614157	614113	14173T	PARTICIPANT	\N	EXCUSE	0
614184	614183	14151M	PARTICIPANT	\N	PRESENT	0
614186	614185	14151M	PARTICIPANT	\N	PRESENT	0
614363	612794	19667J	PARTICIPANT	\N	PRESENT	0
614364	612794	20116W	PARTICIPANT	\N	PRESENT	0
614365	612794	20086J	PARTICIPANT	\N	PRESENT	0
614366	612794	20070A	PARTICIPANT	\N	PRESENT	0
624343	624148	08073C	PARTICIPANT	\N	PRESENT	0
624344	624148	19637C	PARTICIPANT	\N	PRESENT	0
624345	624148	14001X	PARTICIPANT	\N	PRESENT	0
624346	624148	14231L	PARTICIPANT	\N	PRESENT	0
624347	624148	11043H	PARTICIPANT	\N	PRESENT	0
624351	624148	14169X	PARTICIPANT	\N	PRESENT	0
624349	624148	10006L	PARTICIPANT	\N	PRESENT	0
624350	624148	04043D	PARTICIPANT	\N	PRESENT	0
624352	624148	01028R	PARTICIPANT	\N	PRESENT	0
624353	624148	20018V	PARTICIPANT	\N	PRESENT	0
624354	624148	20096L	PARTICIPANT	\N	PRESENT	0
624355	624148	19735D	PARTICIPANT	\N	PRESENT	0
624356	624148	14187A	PARTICIPANT	\N	PRESENT	0
624357	624148	01024M	PARTICIPANT	\N	PRESENT	0
624358	624148	19553Y	PARTICIPANT	\N	PRESENT	0
624359	624148	20172F	PARTICIPANT	\N	PRESENT	0
624360	624148	19531S	PARTICIPANT	\N	PRESENT	0
624361	624148	11045K	PARTICIPANT	\N	PRESENT	0
624362	624148	20116W	PARTICIPANT	\N	PRESENT	0
624363	624148	19387D	PARTICIPANT	\N	PRESENT	0
624364	624148	14147R	PARTICIPANT	\N	PRESENT	0
624365	624148	19479G	PARTICIPANT	\N	PRESENT	0
624366	624148	20136B	PARTICIPANT	\N	PRESENT	0
624367	624148	14059S	PARTICIPANT	\N	PRESENT	0
624368	624148	14083S	PARTICIPANT	\N	PRESENT	0
624369	624148	19741B	PARTICIPANT	\N	PRESENT	0
624370	624148	19713W	PARTICIPANT	\N	PRESENT	0
624371	624148	19703U	PARTICIPANT	\N	PRESENT	0
624372	624148	20134Y	PARTICIPANT	\N	PRESENT	0
624373	624148	19611R	PARTICIPANT	\N	PRESENT	0
624374	624148	14237S	PARTICIPANT	\N	PRESENT	0
624375	624148	19667J	PARTICIPANT	\N	PRESENT	0
624376	624148	14038Y	PARTICIPANT	\N	PRESENT	0
624397	624145	20090E	PARTICIPANT	\N	PRESENT	0
624378	624148	14205J	PARTICIPANT	\N	PRESENT	0
624379	624148	20086J	PARTICIPANT	\N	PRESENT	0
624380	624148	19399H	PARTICIPANT	\N	PRESENT	0
624381	624148	07033P	PARTICIPANT	\N	PRESENT	0
624382	624148	19689Q	PARTICIPANT	\N	PRESENT	0
624383	624148	20060X	PARTICIPANT	\N	PRESENT	0
624384	624148	20032T	PARTICIPANT	\N	PRESENT	0
624385	624148	19758L	PARTICIPANT	\N	PRESENT	0
624386	624148	19593H	PARTICIPANT	\N	PRESENT	0
624387	624148	01062T	PARTICIPANT	\N	PRESENT	0
624388	624148	19599P	PARTICIPANT	\N	PRESENT	0
624389	624148	11066Q	PARTICIPANT	\N	PRESENT	0
624390	624148	19349W	PARTICIPANT	\N	PRESENT	0
624391	624148	20024T	PARTICIPANT	\N	PRESENT	0
624392	624148	14073Q	PARTICIPANT	\N	PRESENT	0
624393	624148	14031R	PARTICIPANT	\N	PRESENT	0
624407	624149	05012A	PARTICIPANT	\N	PRESENT	0
624473	624149	01048V	PARTICIPANT	\N	PRESENT	0
624398	624145	19798U	PARTICIPANT	\N	PRESENT	0
624399	624145	14042U	PARTICIPANT	\N	PRESENT	0
624400	624145	17965H	PARTICIPANT	\N	PRESENT	0
624401	624145	19301E	PARTICIPANT	\N	PRESENT	0
624402	624145	19367Y	PARTICIPANT	\N	PRESENT	0
624403	624145	04043D	PARTICIPANT	\N	PRESENT	0
624404	624145	10006L	PRESIDENT	0	PRESENT	0
624406	624149	19719D	PARTICIPANT	\N	PRESENT	0
624475	624149	20108W	PARTICIPANT	\N	PRESENT	0
624476	624149	14223L	PARTICIPANT	\N	PRESENT	0
624477	624149	19760E	PARTICIPANT	\N	PRESENT	0
624484	624149	19762G	PARTICIPANT	\N	PRESENT	0
624492	624149	19798U	PARTICIPANT	\N	PRESENT	0
624493	624149	01060R	PARTICIPANT	\N	PRESENT	0
624494	624149	20066E	PARTICIPANT	\N	PRESENT	0
624495	624149	19565D	PARTICIPANT	\N	PRESENT	0
624496	624149	01024M	PARTICIPANT	\N	PRESENT	0
624497	624149	18083K	PARTICIPANT	\N	PRESENT	0
624498	624149	14231L	PARTICIPANT	\N	PRESENT	0
624500	624149	14237S	PARTICIPANT	\N	PRESENT	0
624501	624149	01043Q	PARTICIPANT	\N	PRESENT	0
624517	624149	11040E	PARTICIPANT	\N	PRESENT	0
624503	624149	14031R	PARTICIPANT	\N	PRESENT	0
624504	624149	20252E	PARTICIPANT	\N	PRESENT	0
624505	624149	14105F	PARTICIPANT	\N	PRESENT	0
624506	624149	19533U	PARTICIPANT	\N	PRESENT	0
624507	624149	14151M	PARTICIPANT	\N	PRESENT	0
624508	624149	17737W	PARTICIPANT	\N	PRESENT	0
624509	624149	19543W	PARTICIPANT	\N	PRESENT	0
624510	624149	19711U	PARTICIPANT	\N	PRESENT	0
624511	624149	14357A	PARTICIPANT	\N	PRESENT	0
624513	624149	11053K	PARTICIPANT	\N	PRESENT	0
624514	624149	20054A	PARTICIPANT	\N	PRESENT	0
624515	624149	20174H	PARTICIPANT	\N	PRESENT	0
624516	624149	19679N	PARTICIPANT	\N	PRESENT	0
624518	624149	20110Q	PARTICIPANT	\N	PRESENT	0
624519	624149	14069U	PARTICIPANT	\N	PRESENT	0
624521	624149	19782L	PARTICIPANT	\N	PRESENT	0
624522	624149	20072C	PARTICIPANT	\N	PRESENT	0
624523	624149	19687N	PARTICIPANT	\N	PRESENT	0
624525	624149	19553Y	PARTICIPANT	\N	PRESENT	0
624526	624149	20040T	PARTICIPANT	\N	PRESENT	0
624527	624149	20104S	PARTICIPANT	\N	PRESENT	0
624529	624149	14042U	PARTICIPANT	\N	PRESENT	0
624530	624149	19467C	PARTICIPANT	\N	PRESENT	0
624531	624149	17965H	PARTICIPANT	\N	PRESENT	0
624532	624149	14053L	PARTICIPANT	\N	PRESENT	0
624533	624149	11033F	PARTICIPANT	\N	PRESENT	0
624534	624149	14195A	PARTICIPANT	\N	PRESENT	0
624536	624149	14111D	PARTICIPANT	\N	PRESENT	0
624537	624149	17023S	PARTICIPANT	\N	PRESENT	0
624538	624149	08060W	PARTICIPANT	\N	PRESENT	0
624539	624149	19507S	PARTICIPANT	\N	PRESENT	0
624540	624149	19703U	PARTICIPANT	\N	PRESENT	0
624541	624149	20056C	PARTICIPANT	\N	PRESENT	0
624542	624149	20020P	PARTICIPANT	\N	PRESENT	0
624543	624149	19673G	PARTICIPANT	\N	PRESENT	0
624544	624149	20172F	PARTICIPANT	\N	PRESENT	0
624545	624149	19669L	PARTICIPANT	\N	PRESENT	0
624620	624150	19719D	PARTICIPANT	\N	PRESENT	0
624547	624149	20136B	PARTICIPANT	\N	PRESENT	0
624621	624150	17965H	PARTICIPANT	\N	PRESENT	0
624622	624150	08060W	PARTICIPANT	\N	PRESENT	0
624623	624150	20100N	PARTICIPANT	\N	PRESENT	0
624624	624150	20110Q	PARTICIPANT	\N	PRESENT	0
624625	624150	19782L	PARTICIPANT	\N	PRESENT	0
624626	624150	20174H	PARTICIPANT	\N	PRESENT	0
624627	624150	19679N	PARTICIPANT	\N	PRESENT	0
624628	624150	11033F	PARTICIPANT	\N	PRESENT	0
624629	624150	19703U	PARTICIPANT	\N	PRESENT	0
624630	624150	14195A	PARTICIPANT	\N	PRESENT	0
624631	624150	14069U	PARTICIPANT	\N	PRESENT	0
624632	624150	19387D	PARTICIPANT	\N	PRESENT	0
624633	624150	17737W	PARTICIPANT	\N	PRESENT	0
624634	624150	20072C	PARTICIPANT	\N	PRESENT	0
624635	624150	20104S	PARTICIPANT	\N	PRESENT	0
624636	624150	20252E	PARTICIPANT	\N	PRESENT	0
624662	624150	19798U	PARTICIPANT	\N	PRESENT	0
624638	624150	19565D	PARTICIPANT	\N	PRESENT	0
624639	624150	19367Y	PARTICIPANT	\N	PRESENT	0
624640	624150	11031D	PARTICIPANT	\N	PRESENT	0
624641	624150	19760E	PARTICIPANT	\N	PRESENT	0
624642	624150	20056C	PARTICIPANT	\N	PRESENT	0
624643	624150	19673G	PARTICIPANT	\N	PRESENT	0
624644	624150	19758L	PARTICIPANT	\N	PRESENT	0
624645	624150	19711U	PARTICIPANT	\N	PRESENT	0
624646	624150	19507S	PARTICIPANT	\N	PRESENT	0
624647	624150	19687N	PARTICIPANT	\N	PRESENT	0
624648	624150	19383Y	PARTICIPANT	\N	PRESENT	0
624649	624150	19651A	PARTICIPANT	\N	PRESENT	0
624650	624150	19573D	PARTICIPANT	\N	PRESENT	0
624651	624150	19669L	PARTICIPANT	\N	PRESENT	0
624652	624150	11067R	PARTICIPANT	\N	PRESENT	0
624653	624150	19467C	PARTICIPANT	\N	PRESENT	0
624654	624150	20062A	PARTICIPANT	\N	PRESENT	0
624655	624150	01024M	PARTICIPANT	\N	PRESENT	0
624656	624150	14053L	PARTICIPANT	\N	PRESENT	0
624657	624150	19691J	PARTICIPANT	\N	PRESENT	0
624658	624150	20020P	PARTICIPANT	\N	PRESENT	0
624659	624150	18083K	PARTICIPANT	\N	PRESENT	0
624661	624150	05012A	PARTICIPANT	\N	PRESENT	0
624663	624150	20090E	PARTICIPANT	\N	PRESENT	0
624664	624150	19399H	PARTICIPANT	\N	PRESENT	0
624666	624150	14133K	PARTICIPANT	\N	PRESENT	0
624668	624150	10006L	PARTICIPANT	\N	PRESENT	0
624669	624150	20084G	PARTICIPANT	\N	PRESENT	0
624670	624150	20130U	PARTICIPANT	\N	PRESENT	0
624671	624150	20248J	PARTICIPANT	\N	PRESENT	0
609931	609930	20024T	PARTICIPANT	\N	PRESENT	0
609932	609930	14357A	PARTICIPANT	\N	PRESENT	0
609933	609930	19333N	PARTICIPANT	\N	PRESENT	0
609934	609930	11101A	PARTICIPANT	\N	PRESENT	0
609935	609930	08034U	PARTICIPANT	\N	PRESENT	0
609936	609930	19563B	PARTICIPANT	\N	PRESENT	0
609937	609930	14169X	PARTICIPANT	\N	PRESENT	0
609938	609930	20064C	PARTICIPANT	\N	PRESENT	0
610620	610619	04047H	PARTICIPANT	\N	PRESENT	0
610621	610619	14053L	PARTICIPANT	\N	PRESENT	0
610623	610619	11066Q	PARTICIPANT	\N	PRESENT	0
610698	610697	04085P	PARTICIPANT	\N	PRESENT	0
610699	610697	19667J	PARTICIPANT	\N	PRESENT	0
610700	610697	19711U	PARTICIPANT	\N	PRESENT	0
610704	610703	14255U	PARTICIPANT	\N	PRESENT	0
610705	610703	18083K	PARTICIPANT	\N	PRESENT	0
610706	610703	14179A	PARTICIPANT	\N	PRESENT	0
610707	610703	19591F	PARTICIPANT	\N	PRESENT	0
610708	610703	19669L	PARTICIPANT	\N	PRESENT	0
610709	610703	19413M	PARTICIPANT	\N	PRESENT	0
613030	613029	11031D	PARTICIPANT	\N	PRESENT	0
613031	613029	14169X	PARTICIPANT	\N	PRESENT	0
613032	613029	04071H	PARTICIPANT	\N	PRESENT	0
613033	613029	08073C	PARTICIPANT	\N	PRESENT	0
613034	613029	19565D	PARTICIPANT	\N	PRESENT	0
613036	613035	19573D	PARTICIPANT	\N	PRESENT	0
613037	613035	20124W	PARTICIPANT	\N	PRESENT	0
613038	613035	20152B	PARTICIPANT	\N	PRESENT	0
613039	613035	19057M	PARTICIPANT	\N	PRESENT	0
613040	613035	20132W	PARTICIPANT	\N	PRESENT	0
613041	613035	20264J	PARTICIPANT	\N	PRESENT	0
613042	613035	20180F	PARTICIPANT	\N	PRESENT	0
613061	612874	19681G	PARTICIPANT	\N	EXCUSE	0
613062	612874	14071N	PARTICIPANT	\N	EXCUSE	0
613063	612874	19782L	PARTICIPANT	\N	EXCUSE	0
616867	616390	20174H	PARTICIPANT	\N	PRESENT	0
616868	616390	14221J	PARTICIPANT	\N	PRESENT	0
616869	616390	18083K	PARTICIPANT	\N	PRESENT	0
616870	616390	20092G	PARTICIPANT	\N	PRESENT	0
616871	616390	19695N	PARTICIPANT	\N	PRESENT	0
616872	616390	19369B	PARTICIPANT	\N	PRESENT	0
616873	616390	14207L	PARTICIPANT	\N	PRESENT	0
616874	616390	19413M	PARTICIPANT	\N	PRESENT	0
616875	616390	14033T	PARTICIPANT	\N	PRESENT	0
616876	616390	20082E	PARTICIPANT	\N	PRESENT	0
616877	616390	20032T	PARTICIPANT	\N	PRESENT	0
616878	616390	20068G	PARTICIPANT	\N	PRESENT	0
616879	616390	20062A	PARTICIPANT	\N	PRESENT	0
616905	616390	14169X	PARTICIPANT	\N	PRESENT	0
616881	616390	20090E	PARTICIPANT	\N	PRESENT	0
616882	616390	01024M	PARTICIPANT	\N	PRESENT	0
616883	616390	19479G	PARTICIPANT	\N	PRESENT	0
616884	616390	19441R	PARTICIPANT	\N	PRESENT	0
616885	616390	14217N	PARTICIPANT	\N	PRESENT	0
616886	616390	14073Q	PARTICIPANT	\N	PRESENT	0
616887	616390	19467C	PARTICIPANT	\N	PRESENT	0
616888	616390	19782L	PARTICIPANT	\N	PRESENT	0
616889	616390	20028X	PARTICIPANT	\N	PRESENT	0
616890	616390	19503N	PARTICIPANT	\N	PRESENT	0
616900	616390	14213J	PARTICIPANT	\N	PRESENT	0
616892	616390	19347U	PARTICIPANT	\N	PRESENT	0
616893	616390	19533U	PARTICIPANT	\N	PRESENT	0
616865	616390	14026U	PARTICIPANT	\N	PRESENT	0
616866	616390	14219Q	PARTICIPANT	\N	PRESENT	0
616894	616390	20140W	PARTICIPANT	\N	PRESENT	0
616895	616390	19415P	PARTICIPANT	\N	PRESENT	0
616896	616390	19335Q	PARTICIPANT	\N	PRESENT	0
616897	616390	19713W	PARTICIPANT	\N	PRESENT	0
616898	616390	19739H	PARTICIPANT	\N	PRESENT	0
616899	616390	11097X	PARTICIPANT	\N	PRESENT	0
616901	616390	20046A	PARTICIPANT	\N	PRESENT	0
616902	616390	20102Q	PARTICIPANT	\N	PRESENT	0
616903	616390	20024T	PARTICIPANT	\N	PRESENT	0
616904	616390	20124W	PARTICIPANT	\N	PRESENT	0
616906	616390	19760E	PARTICIPANT	\N	PRESENT	0
616907	616390	20064C	PARTICIPANT	\N	PRESENT	0
616908	616390	20100N	PARTICIPANT	\N	PRESENT	0
616909	616390	14083S	PARTICIPANT	\N	PRESENT	0
616910	616390	14030Q	PARTICIPANT	\N	PRESENT	0
616911	616390	11012A	PARTICIPANT	\N	PRESENT	0
616912	616390	19719D	PARTICIPANT	\N	PRESENT	0
616913	616390	19333N	PARTICIPANT	\N	PRESENT	0
616914	616390	19599P	PARTICIPANT	\N	PRESENT	0
616955	616389	14053L	PARTICIPANT	\N	PRESENT	0
616956	616389	20100N	PARTICIPANT	\N	PRESENT	0
616957	616389	12041X	PARTICIPANT	\N	PRESENT	0
616958	616389	14267Y	PARTICIPANT	\N	PRESENT	0
616959	616389	20072C	PARTICIPANT	\N	PRESENT	0
616960	616389	19599P	PARTICIPANT	\N	PRESENT	0
616961	616389	20106U	PARTICIPANT	\N	PRESENT	0
616962	616389	14133K	PARTICIPANT	\N	PRESENT	0
616963	616389	11027H	PARTICIPANT	\N	PRESENT	0
616964	616389	14031R	PARTICIPANT	\N	PRESENT	0
616965	616389	19347U	PARTICIPANT	\N	PRESENT	0
616966	616389	19565D	PARTICIPANT	\N	PRESENT	0
616967	616389	18083K	PARTICIPANT	\N	PRESENT	0
616968	616389	19383Y	PARTICIPANT	\N	PRESENT	0
616969	616389	11064N	PARTICIPANT	\N	PRESENT	0
616970	616389	20180F	PARTICIPANT	\N	PRESENT	0
616971	616389	14083S	PARTICIPANT	\N	PRESENT	0
616972	616389	14147R	PARTICIPANT	\N	PRESENT	0
617456	616391	08028W	PARTICIPANT	\N	PRESENT	0
617457	616391	11090Q	PARTICIPANT	\N	PRESENT	0
617458	616391	05012A	PARTICIPANT	\N	PRESENT	0
617459	616391	19679N	PARTICIPANT	\N	PRESENT	0
617460	616391	01058X	PARTICIPANT	\N	PRESENT	0
617461	616391	99004R	PARTICIPANT	\N	PRESENT	0
617462	616391	08011M	PARTICIPANT	\N	PRESENT	0
617463	616391	19768N	PARTICIPANT	\N	PRESENT	0
617464	616391	19515S	PARTICIPANT	\N	PRESENT	0
617465	616391	20038A	PARTICIPANT	\N	PRESENT	0
617466	616391	97011G	PARTICIPANT	\N	PRESENT	0
617467	616391	08069G	PARTICIPANT	\N	PRESENT	0
617468	616391	19663E	PARTICIPANT	\N	PRESENT	0
617469	616391	20040T	PARTICIPANT	\N	PRESENT	0
617470	616391	17965H	PARTICIPANT	\N	PRESENT	0
617471	616391	14105F	PARTICIPANT	\N	PRESENT	0
617472	616391	19643A	PARTICIPANT	\N	PRESENT	0
617473	616391	19565D	PARTICIPANT	\N	PRESENT	0
617474	616391	19701S	PARTICIPANT	\N	PRESENT	0
617475	616391	20112S	PARTICIPANT	\N	PRESENT	0
616953	616389	19719D	PARTICIPANT	\N	PRESENT	0
616954	616389	20104S	PARTICIPANT	\N	PRESENT	0
617476	616391	14249W	PARTICIPANT	\N	PRESENT	0
617477	616391	19533U	PARTICIPANT	\N	PRESENT	0
617482	616391	20062A	PARTICIPANT	\N	PRESENT	0
617479	616391	20180F	PARTICIPANT	\N	PRESENT	0
617481	616391	11097X	PARTICIPANT	\N	PRESENT	0
617483	616391	19745F	PARTICIPANT	\N	PRESENT	0
617484	617480	19651A	PARTICIPANT	\N	PRESENT	1
617485	617480	14030Q	PARTICIPANT	\N	PRESENT	0
617486	617480	19643A	PARTICIPANT	\N	PRESENT	0
617487	617480	20152B	PARTICIPANT	\N	PRESENT	0
617488	617480	19621T	PARTICIPANT	\N	PRESENT	0
617489	616391	20110Q	PARTICIPANT	\N	PRESENT	0
617490	617480	19758L	PARTICIPANT	\N	PRESENT	0
617491	617480	19057M	PARTICIPANT	\N	PRESENT	0
617492	617480	20134Y	PARTICIPANT	\N	PRESENT	0
617493	617480	20132W	PARTICIPANT	\N	PRESENT	0
617494	617480	14123H	PARTICIPANT	\N	PRESENT	0
617495	617480	20048C	PARTICIPANT	\N	PRESENT	0
617496	617480	19693L	PARTICIPANT	\N	PRESENT	1
617497	617480	20056C	PARTICIPANT	\N	PRESENT	0
617498	617480	19611R	PRESIDENT	0	PRESENT	0
617499	617480	19735D	PARTICIPANT	\N	PRESENT	0
617500	617480	19699S	PARTICIPANT	\N	PRESENT	0
617501	617480	11104D	PARTICIPANT	\N	PRESENT	1
617502	617480	14109K	PARTICIPANT	\N	PRESENT	1
617503	617480	19593H	PARTICIPANT	\N	PRESENT	0
617504	617480	19573D	PARTICIPANT	\N	PRESENT	0
617505	617480	19533U	PARTICIPANT	\N	PRESENT	0
617506	617480	14229S	PARTICIPANT	\N	PRESENT	0
617507	617480	20098N	PARTICIPANT	\N	PRESENT	0
617508	617480	20084G	PARTICIPANT	\N	PRESENT	0
617509	617480	19527W	PARTICIPANT	\N	PRESENT	0
617510	617480	20026V	PARTICIPANT	\N	PRESENT	0
617511	617480	20058E	PARTICIPANT	\N	PRESENT	0
617512	617480	20124W	PARTICIPANT	\N	PRESENT	0
617513	616391	20144B	PARTICIPANT	\N	PRESENT	0
617514	617480	19673G	PARTICIPANT	\N	PRESENT	0
616346	616345	19782L	PARTICIPANT	\N	PRESENT	0
616347	616345	20062A	PARTICIPANT	\N	PRESENT	0
618601	618366	14223L	PARTICIPANT	\N	PRESENT	0
618602	618366	17779H	PARTICIPANT	\N	EXCUSE	0
618603	618365	18193Q	PARTICIPANT	\N	PRESENT	1
618604	618365	19543W	PARTICIPANT	\N	PRESENT	1
618605	618365	14069U	PARTICIPANT	\N	PRESENT	1
624985	624151	20116W	PARTICIPANT	\N	PRESENT	0
624986	624151	11097X	PARTICIPANT	\N	PRESENT	0
624987	624151	14217N	PARTICIPANT	\N	PRESENT	0
624988	624151	19569H	PARTICIPANT	\N	PRESENT	0
624989	624151	01024M	PARTICIPANT	\N	PRESENT	0
624990	624151	14105F	PARTICIPANT	\N	PRESENT	0
624991	624151	18083K	PARTICIPANT	\N	PRESENT	0
624992	624151	04033B	PARTICIPANT	\N	PRESENT	0
624993	624151	19533U	PARTICIPANT	\N	PRESENT	0
624994	624151	19621T	PARTICIPANT	\N	PRESENT	0
624995	624151	20092G	PARTICIPANT	\N	PRESENT	0
624996	624151	11065P	PARTICIPANT	\N	PRESENT	0
624997	624151	14147R	PARTICIPANT	\N	PRESENT	0
624998	624151	20138D	PARTICIPANT	\N	PRESENT	0
624999	624151	19575F	PARTICIPANT	\N	PRESENT	0
625000	624151	10006L	PARTICIPANT	\N	PRESENT	0
625001	624151	20130U	PARTICIPANT	\N	PRESENT	0
625002	624151	20048C	PARTICIPANT	\N	PRESENT	0
625003	624151	14033T	PARTICIPANT	\N	PRESENT	0
625004	624151	11048N	PARTICIPANT	\N	PRESENT	0
625005	624151	20062A	PARTICIPANT	\N	PRESENT	0
625006	624151	14213J	PARTICIPANT	\N	PRESENT	0
625007	624151	20140W	PARTICIPANT	\N	PRESENT	0
625009	625008	20024T	PARTICIPANT	\N	PRESENT	0
625010	625008	19367Y	PARTICIPANT	\N	PRESENT	0
625011	625008	19545Y	PARTICIPANT	\N	PRESENT	0
625012	625008	14357A	PARTICIPANT	\N	PRESENT	0
625013	625008	04035D	PARTICIPANT	\N	PRESENT	0
625014	625008	19333N	PARTICIPANT	\N	PRESENT	0
624983	624151	19747H	PARTICIPANT	\N	PRESENT	0
624984	624151	19691J	PARTICIPANT	\N	PRESENT	0
625194	624079	14237S	PARTICIPANT	\N	PRESENT	0
625016	625008	08034U	PARTICIPANT	\N	PRESENT	0
625017	625008	14147R	PARTICIPANT	\N	PRESENT	0
625018	625008	04045F	PARTICIPANT	\N	PRESENT	0
625192	624079	20100N	PARTICIPANT	\N	PRESENT	0
625193	624079	14033T	PARTICIPANT	\N	PRESENT	0
625195	624079	14331P	PRESIDENT	0	PRESENT	1
625196	624079	10015M	PARTICIPANT	\N	PRESENT	1
625197	624079	14001X	PARTICIPANT	\N	PRESENT	0
625198	624079	04045F	PARTICIPANT	\N	PRESENT	0
625199	624079	20104S	PARTICIPANT	\N	PRESENT	0
625200	624079	14189C	PARTICIPANT	\N	EXCUSE	0
625202	624079	08018U	PARTICIPANT	\N	EXCUSE	0
625204	624079	14207L	PARTICIPANT	\N	EXCUSE	0
625225	624079	19563B	PARTICIPANT	\N	PRESENT	1
625264	625263	14089Y	PARTICIPANT	\N	PRESENT	0
625265	625263	20104S	PARTICIPANT	\N	PRESENT	0
625266	625263	19701S	PARTICIPANT	\N	PRESENT	0
625267	625263	14357A	PARTICIPANT	\N	PRESENT	0
625289	625287	20248J	PARTICIPANT	\N	PRESENT	0
625269	625263	20100N	PARTICIPANT	\N	PRESENT	0
625270	625263	08018U	PARTICIPANT	\N	EXCUSE	0
625271	625263	11083R	PARTICIPANT	\N	PRESENT	0
625272	625263	14033T	PARTICIPANT	\N	PRESENT	0
625273	625263	20128B	PARTICIPANT	\N	PRESENT	0
625274	625263	11026G	PARTICIPANT	\N	PRESENT	0
625275	625263	08034U	PARTICIPANT	\N	PRESENT	0
625276	625263	14001X	PARTICIPANT	\N	PRESENT	0
625277	625263	04057K	PARTICIPANT	\N	PRESENT	0
625290	625287	11067R	PARTICIPANT	\N	PRESENT	0
625279	625263	14237S	PARTICIPANT	\N	PRESENT	0
625280	625263	14331P	PRESIDENT	0	PRESENT	1
625281	625263	04045F	PARTICIPANT	\N	PRESENT	0
625282	625263	14097Y	PARTICIPANT	\N	PRESENT	1
625283	625263	14133K	PARTICIPANT	\N	PRESENT	0
625284	625263	14189C	PARTICIPANT	\N	EXCUSE	0
625285	625263	14207L	PARTICIPANT	\N	EXCUSE	0
625288	625287	14217N	PARTICIPANT	\N	PRESENT	0
625292	625291	10006L	PARTICIPANT	\N	PRESENT	0
625293	625291	11031D	PARTICIPANT	\N	PRESENT	0
625294	625291	19703U	PARTICIPANT	\N	PRESENT	0
625295	625291	19713W	PARTICIPANT	\N	PRESENT	0
625296	625291	19723Y	PARTICIPANT	\N	PRESENT	0
625297	625291	04092N	PARTICIPANT	\N	PRESENT	0
625298	625291	20130U	PARTICIPANT	\N	PRESENT	0
625299	625291	19735D	PARTICIPANT	\N	PRESENT	0
625365	625364	14083S	PARTICIPANT	\N	PRESENT	0
625366	625364	14329V	PARTICIPANT	\N	PRESENT	0
625367	625364	08015R	PARTICIPANT	\N	PRESENT	0
625368	625364	04045F	PARTICIPANT	\N	PRESENT	0
625369	625364	19525U	PARTICIPANT	\N	PRESENT	0
625370	625364	19549D	PARTICIPANT	\N	PRESENT	0
625371	625364	20116W	PARTICIPANT	\N	PRESENT	0
625372	625364	20120S	PARTICIPANT	\N	PRESENT	0
625373	625364	19629C	PARTICIPANT	\N	PRESENT	0
625374	624080	14133K	PARTICIPANT	\N	PRESENT	0
625375	624080	19701S	PARTICIPANT	\N	PRESENT	0
625376	624080	19507S	PARTICIPANT	\N	PRESENT	0
625377	624080	20100N	PARTICIPANT	\N	PRESENT	0
625378	624080	14033T	PARTICIPANT	\N	PRESENT	0
625379	624080	11026G	PARTICIPANT	\N	PRESENT	0
625380	624080	14169X	PARTICIPANT	\N	PRESENT	0
625381	624080	14237S	PARTICIPANT	\N	PRESENT	0
625382	624080	14331P	PRESIDENT	0	PRESENT	1
625383	624080	14189C	PARTICIPANT	\N	EXCUSE	0
625384	624080	08018U	PARTICIPANT	\N	EXCUSE	0
625385	624080	20076G	PARTICIPANT	\N	PRESENT	0
625386	624080	20024T	PARTICIPANT	\N	PRESENT	0
625387	624080	19549D	PARTICIPANT	\N	PRESENT	0
625388	624080	17367Q	PARTICIPANT	\N	PRESENT	0
625389	624080	08060W	PARTICIPANT	\N	PRESENT	0
625390	624080	18083K	PARTICIPANT	\N	PRESENT	0
625391	624080	19525U	PARTICIPANT	\N	PRESENT	0
625392	624080	11065P	PARTICIPANT	\N	PRESENT	0
625393	624080	20140W	PARTICIPANT	\N	PRESENT	0
625394	624080	17229F	PARTICIPANT	\N	PRESENT	0
625395	624080	19251M	PARTICIPANT	\N	PRESENT	0
625396	624080	20038A	PARTICIPANT	\N	PRESENT	0
625397	624080	19599P	PARTICIPANT	\N	PRESENT	0
625398	624080	19820Y	PARTICIPANT	\N	PRESENT	0
625399	624080	19387D	PARTICIPANT	\N	PRESENT	1
625400	624080	20068G	PARTICIPANT	\N	PRESENT	0
625401	624080	20106U	PARTICIPANT	\N	PRESENT	0
625402	624080	19685L	PARTICIPANT	\N	PRESENT	0
625403	624080	20102Q	PARTICIPANT	\N	PRESENT	0
625404	624080	19333N	PARTICIPANT	\N	PRESENT	0
625405	624080	14219Q	PARTICIPANT	\N	PRESENT	0
625406	624080	14031R	PARTICIPANT	\N	PRESENT	0
625407	624080	19637C	PARTICIPANT	\N	PRESENT	0
625408	624080	19826F	PARTICIPANT	\N	PRESENT	0
625409	624080	14221J	PARTICIPANT	\N	PRESENT	0
625410	623502	11074Q	PARTICIPANT	\N	PRESENT	1
625411	623502	11110B	PARTICIPANT	\N	PRESENT	1
625412	623502	14121F	PARTICIPANT	\N	PRESENT	1
625413	624080	19745F	PARTICIPANT	\N	PRESENT	0
625414	624080	20118Y	PARTICIPANT	\N	PRESENT	0
625415	623502	19531S	PARTICIPANT	\N	PRESENT	1
625416	624080	05012A	PARTICIPANT	\N	PRESENT	0
625417	623502	20126Y	PARTICIPANT	\N	PRESENT	1
625418	624080	19503N	PARTICIPANT	\N	PRESENT	0
625419	623502	19711U	PARTICIPANT	\N	PRESENT	1
625420	624080	20020P	PARTICIPANT	\N	PRESENT	0
625421	624080	19619A	PARTICIPANT	\N	PRESENT	0
625422	623502	01048V	PARTICIPANT	\N	PRESENT	1
625423	624080	20046A	PARTICIPANT	\N	PRESENT	0
625424	623502	19335Q	PARTICIPANT	\N	PRESENT	1
625425	623502	20050V	PARTICIPANT	\N	PRESENT	1
625426	623502	14331P	PARTICIPANT	\N	PRESENT	1
625427	623502	11012A	PARTICIPANT	\N	PRESENT	1
625428	623502	19479G	PARTICIPANT	\N	PRESENT	1
625429	623502	19349W	PARTICIPANT	\N	PRESENT	0
625430	623502	08034U	PARTICIPANT	\N	PRESENT	0
625431	623502	20086J	PARTICIPANT	\N	PRESENT	0
625432	624170	14089Y	PARTICIPANT	\N	PRESENT	0
625433	624170	20104S	PARTICIPANT	\N	PRESENT	0
625434	624170	19701S	PARTICIPANT	\N	PRESENT	0
625435	624170	14357A	PARTICIPANT	\N	PRESENT	0
625436	624170	20100N	PARTICIPANT	\N	PRESENT	0
625437	624170	14033T	PARTICIPANT	\N	PRESENT	0
625438	624170	20128B	PARTICIPANT	\N	PRESENT	0
625439	624170	11026G	PARTICIPANT	\N	PRESENT	0
625440	624170	08034U	PARTICIPANT	\N	PRESENT	0
625441	624170	14001X	PARTICIPANT	\N	PRESENT	0
607577	605425	20094J	PARTICIPANT	\N	PRESENT	0
607578	605425	11101A	PARTICIPANT	\N	PRESENT	0
607579	605425	20100N	PARTICIPANT	\N	PRESENT	0
607580	605425	11083R	PARTICIPANT	\N	PRESENT	0
607581	605425	14033T	PARTICIPANT	\N	PRESENT	0
607582	605425	04045F	PARTICIPANT	\N	PRESENT	0
607583	605425	14237S	PARTICIPANT	\N	PRESENT	0
607584	605425	14331P	PRESIDENT	0	PRESENT	0
607585	605425	14001X	PARTICIPANT	\N	PRESENT	0
607586	605425	08034U	PARTICIPANT	\N	PRESENT	0
607587	605425	14073Q	PARTICIPANT	\N	PRESENT	0
607588	605425	19725B	PARTICIPANT	\N	PRESENT	0
607589	605425	12041X	PARTICIPANT	\N	PRESENT	0
607590	605425	19553Y	PARTICIPANT	\N	PRESENT	0
607591	605425	19531S	PARTICIPANT	\N	PRESENT	0
607592	605425	14357A	PARTICIPANT	\N	EXCUSE	0
607593	605425	14189C	PARTICIPANT	\N	EXCUSE	0
607594	605425	11026G	PARTICIPANT	\N	PRESENT	0
608226	606857	04045F	PARTICIPANT	\N	PRESENT	0
608227	606857	19705W	PARTICIPANT	\N	EXCUSE	0
608320	608319	20094J	PARTICIPANT	\N	PRESENT	0
609066	609063	19782L	PARTICIPANT	\N	PRESENT	0
608322	608319	04070G	PARTICIPANT	\N	PRESENT	0
609064	609063	11090Q	PARTICIPANT	\N	PRESENT	0
609065	609063	19575F	PARTICIPANT	\N	PRESENT	0
609067	609063	14038Y	PARTICIPANT	\N	PRESENT	0
609068	609063	14187A	PARTICIPANT	\N	PRESENT	0
609069	609063	14205J	PARTICIPANT	\N	PRESENT	0
609070	609063	20028X	PARTICIPANT	\N	PRESENT	0
609071	609063	20030R	PARTICIPANT	\N	PRESENT	0
609072	609063	20092G	PARTICIPANT	\N	PRESENT	0
609073	609063	04047H	PARTICIPANT	\N	PRESENT	0
609074	609063	19629C	PARTICIPANT	\N	PRESENT	0
609075	609063	19725B	PARTICIPANT	\N	PRESENT	0
609076	609063	14147R	PARTICIPANT	\N	PRESENT	0
612510	612506	14255U	PARTICIPANT	\N	PRESENT	0
614367	612794	01057W	PARTICIPANT	\N	PRESENT	0
612516	612506	14059S	PARTICIPANT	\N	PRESENT	0
612518	612506	14193X	PARTICIPANT	\N	PRESENT	0
612520	612506	14107H	PARTICIPANT	\N	PRESENT	0
612525	612506	14083S	PARTICIPANT	\N	PRESENT	0
614368	612794	11048N	PARTICIPANT	\N	PRESENT	0
614369	612794	14121F	PARTICIPANT	\N	PRESENT	0
614370	612794	20126Y	PARTICIPANT	\N	PRESENT	0
614371	612794	19711U	PARTICIPANT	\N	PRESENT	0
614372	612794	08010L	PARTICIPANT	\N	PRESENT	0
614373	612794	08009T	PARTICIPANT	\N	PRESENT	0
614374	612794	19349W	PARTICIPANT	\N	PRESENT	0
614381	612794	14225N	PARTICIPANT	\N	PRESENT	0
614382	612794	20044X	PARTICIPANT	\N	PRESENT	0
614383	612794	19479G	PARTICIPANT	\N	PRESENT	0
614384	612794	14173T	PARTICIPANT	\N	PRESENT	0
614385	612794	20118Y	PARTICIPANT	\N	PRESENT	0
614386	612794	20038A	PARTICIPANT	\N	PRESENT	0
614387	612794	14031R	PARTICIPANT	\N	PRESENT	0
614388	612794	17229F	PARTICIPANT	\N	PRESENT	0
614389	612794	20032T	PARTICIPANT	\N	PRESENT	0
614390	612794	19820Y	PARTICIPANT	\N	PRESENT	0
614391	612794	18083K	PARTICIPANT	\N	PRESENT	0
614393	612794	20102Q	PARTICIPANT	\N	PRESENT	0
614394	612794	05012A	PARTICIPANT	\N	PRESENT	0
614395	612794	19701S	PARTICIPANT	\N	PRESENT	0
614396	612794	19387D	PARTICIPANT	\N	PRESENT	0
614397	612794	19503N	PARTICIPANT	\N	PRESENT	0
614398	612794	19549D	PARTICIPANT	\N	PRESENT	0
614399	612794	19333N	PARTICIPANT	\N	PRESENT	0
614400	612794	20046A	PARTICIPANT	\N	PRESENT	0
614402	612794	14169X	PARTICIPANT	\N	PRESENT	0
614403	612794	17367Q	PARTICIPANT	\N	PRESENT	0
614404	612794	19745F	PARTICIPANT	\N	PRESENT	0
614406	612794	11101A	PARTICIPANT	\N	PRESENT	0
612416	612414	19631V	PARTICIPANT	\N	PRESENT	0
612417	612414	19515S	PARTICIPANT	\N	PRESENT	0
612418	612414	19707Y	PARTICIPANT	\N	PRESENT	0
612419	612414	19575F	PARTICIPANT	\N	PRESENT	0
612420	612414	20094J	PARTICIPANT	\N	PRESENT	0
612421	612414	20078J	PARTICIPANT	\N	PRESENT	0
612422	612414	20088L	PARTICIPANT	\N	PRESENT	0
612423	612414	19747H	PARTICIPANT	\N	PRESENT	0
612424	612414	19383Y	PARTICIPANT	\N	PRESENT	0
612425	612414	19782L	PARTICIPANT	\N	PRESENT	0
612426	612414	14207L	PARTICIPANT	\N	PRESENT	0
612427	612414	20104S	PARTICIPANT	\N	PRESENT	0
614407	612794	11065P	PARTICIPANT	\N	PRESENT	0
612429	612414	14329V	PARTICIPANT	\N	PRESENT	0
612430	612414	14038Y	PARTICIPANT	\N	PRESENT	0
612431	612414	08028W	PARTICIPANT	\N	PRESENT	0
612432	612414	20144B	PARTICIPANT	\N	PRESENT	0
612433	612414	19467C	PARTICIPANT	\N	PRESENT	0
612434	612414	14357A	PARTICIPANT	\N	PRESENT	0
612435	612414	19507S	PARTICIPANT	\N	PRESENT	0
612436	612414	14187A	PARTICIPANT	\N	PRESENT	0
612437	612414	20174H	PARTICIPANT	\N	PRESENT	0
612438	612414	01025N	PARTICIPANT	\N	PRESENT	0
612439	612414	19695N	PARTICIPANT	\N	PRESENT	0
612440	612414	14033T	PARTICIPANT	\N	PRESENT	0
614410	612794	19826F	PARTICIPANT	\N	PRESENT	0
612442	612414	19511N	PARTICIPANT	\N	PRESENT	0
614411	612794	19525U	PARTICIPANT	\N	PRESENT	0
612444	612414	08015R	PARTICIPANT	\N	PRESENT	0
612445	612414	01043Q	PARTICIPANT	\N	PRESENT	0
612446	612414	11077T	PARTICIPANT	\N	PRESENT	0
612447	612414	14205J	PARTICIPANT	\N	PRESENT	0
612448	612414	19441R	PARTICIPANT	\N	PRESENT	0
612449	612414	14251Q	PARTICIPANT	\N	PRESENT	0
612450	612414	19563B	PARTICIPANT	\N	PRESENT	0
612451	612414	20028X	PARTICIPANT	\N	PRESENT	0
612452	612414	20018V	PARTICIPANT	\N	PRESENT	0
612453	612414	19369B	PARTICIPANT	\N	PRESENT	0
612454	612414	14257W	PARTICIPANT	\N	PRESENT	0
612455	612414	19768N	PARTICIPANT	\N	PRESENT	0
614413	612794	20068G	PARTICIPANT	\N	PRESENT	0
612457	612414	20030R	PARTICIPANT	\N	PRESENT	0
612458	612414	11090Q	PRESIDENT	0	PRESENT	0
612459	612414	20082E	PARTICIPANT	\N	PRESENT	0
612460	612414	19705W	PARTICIPANT	\N	PRESENT	0
612461	612414	20054A	PARTICIPANT	\N	PRESENT	0
612462	612414	20092G	PARTICIPANT	\N	PRESENT	0
614414	612794	20024T	PARTICIPANT	\N	PRESENT	0
612464	612414	20062A	PARTICIPANT	\N	PRESENT	0
612465	612414	19413M	PARTICIPANT	\N	PRESENT	0
614415	612794	19367Y	PARTICIPANT	\N	PRESENT	0
614416	612794	20090E	PARTICIPANT	\N	PRESENT	0
614417	612794	10006L	PARTICIPANT	\N	PRESENT	0
614418	612794	14217N	PARTICIPANT	\N	PRESENT	0
614419	612794	20040T	PARTICIPANT	\N	PRESENT	0
614420	612794	20172F	PARTICIPANT	\N	PRESENT	0
614452	612794	19691J	PARTICIPANT	\N	PRESENT	0
614453	612794	19723Y	PARTICIPANT	\N	PRESENT	0
614455	612794	19679N	PARTICIPANT	\N	PRESENT	0
614457	612794	19798U	PARTICIPANT	\N	PRESENT	0
614458	612794	11097X	PARTICIPANT	\N	PRESENT	0
614459	612794	19703U	PARTICIPANT	\N	PRESENT	0
614463	612794	19631V	PARTICIPANT	\N	PRESENT	0
614465	612794	20078J	PARTICIPANT	\N	PRESENT	0
614466	612794	20088L	PARTICIPANT	\N	PRESENT	0
614467	612794	19747H	PARTICIPANT	\N	PRESENT	0
614469	612794	19383Y	PARTICIPANT	\N	PRESENT	0
614471	612794	19782L	PARTICIPANT	\N	PRESENT	0
614473	612794	14207L	PARTICIPANT	\N	PRESENT	0
614474	612794	14038Y	PARTICIPANT	\N	PRESENT	0
614476	612794	08028W	PARTICIPANT	\N	PRESENT	0
614478	612794	19507S	PARTICIPANT	\N	PRESENT	0
614480	612794	14187A	PARTICIPANT	\N	PRESENT	0
614481	612794	20174H	PARTICIPANT	\N	PRESENT	0
614483	612794	20034V	PARTICIPANT	\N	PRESENT	0
614485	612794	14205J	PARTICIPANT	\N	PRESENT	0
614486	612794	19441R	PARTICIPANT	\N	PRESENT	0
614490	612794	20028X	PARTICIPANT	\N	PRESENT	0
614491	612794	19369B	PARTICIPANT	\N	PRESENT	0
614492	612794	14257W	PARTICIPANT	\N	PRESENT	0
614493	612794	19768N	PARTICIPANT	\N	PRESENT	0
614494	612794	20030R	PARTICIPANT	\N	PRESENT	0
614495	612794	11090Q	PARTICIPANT	\N	PRESENT	0
614497	612794	20082E	PARTICIPANT	\N	PRESENT	0
614498	612794	20054A	PARTICIPANT	\N	PRESENT	0
614500	612794	04045F	PARTICIPANT	\N	PRESENT	0
614502	612794	20062A	PARTICIPANT	\N	PRESENT	0
614518	612793	14107H	PARTICIPANT	\N	EXCUSE	0
614721	614718	05008E	PARTICIPANT	\N	PRESENT	0
614723	614718	11033F	PARTICIPANT	\N	PRESENT	0
623383	621511	20074E	PARTICIPANT	\N	PRESENT	1
623384	621511	14179A	PARTICIPANT	\N	PRESENT	1
623385	621511	10015M	PARTICIPANT	\N	PRESENT	1
623386	621511	19675J	PARTICIPANT	\N	PRESENT	1
624405	620193	19798U	PARTICIPANT	\N	PRESENT	0
624478	624145	20066E	PARTICIPANT	\N	PRESENT	1
624479	624145	19715Y	PARTICIPANT	\N	PRESENT	1
624480	624145	20130U	PARTICIPANT	\N	PRESENT	1
624481	624145	19723Y	PARTICIPANT	\N	PRESENT	1
624483	624145	19697Q	PARTICIPANT	\N	PRESENT	1
624485	624145	19760E	PARTICIPANT	\N	PRESENT	1
624487	624145	04057K	PARTICIPANT	\N	PRESENT	1
624488	624145	14213J	PARTICIPANT	\N	PRESENT	1
624489	624145	19657G	PARTICIPANT	\N	PRESENT	1
624672	624150	19569H	PARTICIPANT	\N	PRESENT	0
624674	624150	20040T	PARTICIPANT	\N	PRESENT	0
624675	624150	14215L	PARTICIPANT	\N	PRESENT	0
624676	624150	01028R	PARTICIPANT	\N	PRESENT	0
624677	624150	20114U	PARTICIPANT	\N	PRESENT	0
624678	624150	14073Q	PARTICIPANT	\N	PRESENT	0
624679	624150	14231L	PARTICIPANT	\N	PRESENT	0
624680	624150	11012A	PARTICIPANT	\N	PRESENT	0
624681	624150	20038A	PARTICIPANT	\N	PRESENT	0
624682	624150	14249W	PARTICIPANT	\N	PRESENT	0
624683	624150	14042U	PARTICIPANT	\N	PRESENT	0
624684	624150	11066Q	PARTICIPANT	\N	PRESENT	0
624685	624150	20066E	PARTICIPANT	\N	PRESENT	0
624686	624150	20124W	PARTICIPANT	\N	PRESENT	0
624687	624150	20022R	PARTICIPANT	\N	PRESENT	0
624688	624150	14223L	PARTICIPANT	\N	PRESENT	0
624689	624150	19479G	PARTICIPANT	\N	PRESENT	0
624690	624150	17779H	PARTICIPANT	\N	PRESENT	0
624691	624150	20032T	PARTICIPANT	\N	PRESENT	0
624692	624150	11085T	PARTICIPANT	\N	PRESENT	0
624693	624150	20024T	PARTICIPANT	\N	PRESENT	0
624694	624150	20108W	PARTICIPANT	\N	PRESENT	0
624695	624150	01057W	PARTICIPANT	\N	PRESENT	0
624696	624150	19663E	PARTICIPANT	\N	PRESENT	0
624673	624150	20026V	PARTICIPANT	\N	PRESENT	0
624697	624150	14026U	PARTICIPANT	\N	PRESENT	0
624698	624150	04057K	PARTICIPANT	\N	PRESENT	0
624699	624150	19697Q	PARTICIPANT	\N	PRESENT	0
624700	624150	14031R	PARTICIPANT	\N	PRESENT	0
624701	624150	20136B	PARTICIPANT	\N	PRESENT	0
624702	624150	14083S	PARTICIPANT	\N	PRESENT	0
624703	624150	04035D	PARTICIPANT	\N	PRESENT	0
624704	624150	19335Q	PARTICIPANT	\N	PRESENT	0
624705	624150	20140W	PARTICIPANT	\N	PRESENT	0
624706	624150	11027H	PARTICIPANT	\N	PRESENT	0
624707	624150	19251M	PARTICIPANT	\N	PRESENT	0
624708	624150	14121F	PARTICIPANT	\N	PRESENT	0
624709	624150	14217N	PARTICIPANT	\N	PRESENT	0
624710	624150	19637C	PARTICIPANT	\N	PRESENT	0
624711	624150	19515S	PARTICIPANT	\N	PRESENT	0
624712	624150	14105F	PARTICIPANT	\N	PRESENT	0
624724	624150	19349W	PARTICIPANT	\N	PRESENT	0
624725	624150	11056N	PARTICIPANT	\N	PRESENT	0
624732	624150	14021P	PARTICIPANT	\N	PRESENT	0
624733	624150	14213J	PARTICIPANT	\N	PRESENT	0
624734	624665	19383Y	PARTICIPANT	\N	PRESENT	0
624735	624665	19768N	PARTICIPANT	\N	PRESENT	0
624736	624665	20092G	PARTICIPANT	\N	PRESENT	0
624737	624665	01043Q	PARTICIPANT	\N	PRESENT	0
624738	624665	14357A	PARTICIPANT	\N	PRESENT	0
624739	624665	19441R	PARTICIPANT	\N	PRESENT	0
624740	624665	04045F	PARTICIPANT	\N	PRESENT	0
624741	624665	19705W	PARTICIPANT	\N	PRESENT	1
624742	624665	19707Y	PARTICIPANT	\N	PRESENT	1
624743	624665	08015R	PARTICIPANT	\N	PRESENT	0
624744	624665	19575F	PARTICIPANT	\N	PRESENT	0
624745	624665	20018V	PARTICIPANT	\N	PRESENT	0
624746	624665	19511N	PARTICIPANT	\N	PRESENT	0
624747	624665	08028W	PARTICIPANT	\N	PRESENT	0
624748	624665	19563B	PARTICIPANT	\N	PRESENT	1
624749	624665	20028X	PARTICIPANT	\N	PRESENT	0
624750	624665	14038Y	PARTICIPANT	\N	PRESENT	0
624751	624665	19467C	PARTICIPANT	\N	PRESENT	0
624752	624665	14187A	PARTICIPANT	\N	PRESENT	0
624753	624665	11090Q	PRESIDENT	0	PRESENT	0
624754	624665	14033T	PARTICIPANT	\N	PRESENT	0
624755	624665	20060X	PARTICIPANT	\N	PRESENT	1
624756	624665	19507S	PARTICIPANT	\N	PRESENT	0
624757	624665	19747H	PARTICIPANT	\N	PRESENT	0
624758	624665	14257W	PARTICIPANT	\N	PRESENT	0
624759	624150	01048V	PARTICIPANT	\N	PRESENT	0
624760	624150	17637T	PARTICIPANT	\N	PRESENT	0
624761	623421	07029T	PARTICIPANT	\N	PRESENT	0
624762	623421	19711U	PARTICIPANT	\N	PRESENT	0
624763	623421	20252E	PARTICIPANT	\N	PRESENT	0
624764	623421	19531S	PARTICIPANT	\N	PRESENT	0
624765	623421	19349W	PARTICIPANT	\N	PRESENT	0
624766	623421	08010L	PARTICIPANT	\N	PRESENT	0
624767	623421	19667J	PARTICIPANT	\N	PRESENT	0
624768	623421	14253S	PARTICIPANT	\N	PRESENT	0
624769	623421	20116W	PARTICIPANT	\N	PRESENT	0
624770	623421	19335Q	PARTICIPANT	\N	PRESENT	0
624771	623421	20044X	PARTICIPANT	\N	PRESENT	0
624772	623421	20080C	PARTICIPANT	\N	EXCUSE	0
624773	623421	11053K	PARTICIPANT	\N	PRESENT	0
624774	623421	08009T	PARTICIPANT	\N	PRESENT	0
624775	623421	19762G	PARTICIPANT	\N	PRESENT	0
624776	624150	20052X	PARTICIPANT	\N	PRESENT	0
624777	624150	20138D	PARTICIPANT	\N	PRESENT	0
624785	623421	20086J	PARTICIPANT	\N	PRESENT	0
624786	624150	08015R	PARTICIPANT	\N	PRESENT	0
624787	624150	08028W	PARTICIPANT	\N	PRESENT	0
624788	623421	01048V	PARTICIPANT	\N	PRESENT	0
624789	623421	19545Y	PARTICIPANT	\N	PRESENT	0
624790	623421	19741B	PARTICIPANT	\N	PRESENT	0
624791	624150	11097X	PARTICIPANT	\N	PRESENT	0
624792	624150	07029T	PARTICIPANT	\N	PRESENT	0
624793	624150	19563B	PARTICIPANT	\N	PRESENT	0
624794	624150	20074E	PARTICIPANT	\N	PRESENT	0
624795	624150	19447X	PARTICIPANT	\N	PRESENT	0
624796	624150	14147R	PARTICIPANT	\N	PRESENT	0
624797	624150	20142Y	PARTICIPANT	\N	PRESENT	0
624798	624150	14259Y	PARTICIPANT	\N	PRESENT	0
624799	624150	20088L	PARTICIPANT	\N	PRESENT	0
624800	624150	20054A	PARTICIPANT	\N	PRESENT	0
624801	623421	19507S	PARTICIPANT	\N	PRESENT	0
624802	624170	14097Y	PARTICIPANT	\N	PRESENT	1
624803	624170	14105F	PARTICIPANT	\N	PRESENT	0
624804	624170	19443T	PARTICIPANT	\N	PRESENT	1
624805	624170	20064C	PARTICIPANT	\N	PRESENT	1
624806	624170	14133K	PRESIDENT	0	PRESENT	0
624807	624170	01058X	PARTICIPANT	\N	PRESENT	0
624808	624170	19347U	PARTICIPANT	\N	PRESENT	0
624809	624170	11027H	PARTICIPANT	\N	PRESENT	0
624810	624170	11083R	PARTICIPANT	\N	PRESENT	0
624811	624170	11066Q	PARTICIPANT	\N	PRESENT	0
624812	624170	14255U	PARTICIPANT	\N	PRESENT	0
624813	624170	14211G	PARTICIPANT	\N	EXCUSE	0
624814	624150	19415P	PARTICIPANT	\N	PRESENT	0
624816	624150	14187A	PARTICIPANT	\N	PRESENT	0
624817	624150	14059S	PARTICIPANT	\N	PRESENT	0
624818	624150	20120S	PARTICIPANT	\N	PRESENT	0
624819	624150	14038Y	PARTICIPANT	\N	PRESENT	0
624820	624150	20068G	PARTICIPANT	\N	PRESENT	0
624821	624150	01060R	PARTICIPANT	\N	PRESENT	0
624822	624150	19826F	PARTICIPANT	\N	PRESENT	0
624823	624150	19747H	PARTICIPANT	\N	PRESENT	0
624824	624150	20044X	PARTICIPANT	\N	PRESENT	0
624825	624150	19762G	PARTICIPANT	\N	PRESENT	0
624831	624150	20086J	PARTICIPANT	\N	PRESENT	0
624832	624150	14089Y	PARTICIPANT	\N	PRESENT	0
624833	624150	11048N	PARTICIPANT	\N	PRESENT	0
624834	624150	17023S	PARTICIPANT	\N	PRESENT	0
624835	624150	20042V	PARTICIPANT	\N	PRESENT	0
624836	624150	20028X	PARTICIPANT	\N	PRESENT	0
624837	624524	20132W	PARTICIPANT	\N	PRESENT	0
624838	624524	19954N	PARTICIPANT	\N	PRESENT	0
624839	624524	19533U	PRESIDENT	0	PRESENT	0
624840	624524	19820Y	PARTICIPANT	\N	PRESENT	1
624841	624524	14207L	PARTICIPANT	\N	PRESENT	0
624842	624524	19599P	PARTICIPANT	\N	PRESENT	0
624843	624524	20124W	PARTICIPANT	\N	PRESENT	0
624844	624524	20096L	PARTICIPANT	\N	PRESENT	0
624845	624524	20042V	PARTICIPANT	\N	PRESENT	0
624846	624524	20112S	PARTICIPANT	\N	PRESENT	0
624847	624524	19693L	PARTICIPANT	\N	PRESENT	0
600475	599368	20034V	PARTICIPANT	\N	PRESENT	1
600488	600487	20106U	PARTICIPANT	\N	PRESENT	0
600489	600487	12016W	PARTICIPANT	\N	PRESENT	0
600491	600490	11053K	PARTICIPANT	\N	PRESENT	0
600611	600607	11101A	PARTICIPANT	\N	PRESENT	0
600612	600608	11101A	PARTICIPANT	\N	PRESENT	0
600613	600609	11101A	PARTICIPANT	\N	PRESENT	0
600614	600610	11101A	PARTICIPANT	\N	PRESENT	0
600644	600643	04047H	PARTICIPANT	\N	PRESENT	0
600645	600643	14299H	PARTICIPANT	\N	PRESENT	0
600646	600643	11066Q	PARTICIPANT	\N	PRESENT	0
603494	603493	11026G	PARTICIPANT	\N	PRESENT	0
609047	609039	14109K	PARTICIPANT	\N	PRESENT	0
609042	609039	14030Q	PARTICIPANT	\N	PRESENT	0
609045	609039	19621T	PARTICIPANT	\N	PRESENT	0
609080	609039	20124W	PARTICIPANT	\N	PRESENT	0
609081	609039	20132W	PARTICIPANT	\N	PRESENT	1
611999	611997	19701S	PARTICIPANT	\N	PRESENT	0
612000	611997	19820Y	PARTICIPANT	\N	PRESENT	0
612001	611997	20038A	PARTICIPANT	\N	PRESENT	0
612002	611997	14213J	PARTICIPANT	\N	PRESENT	0
612003	611997	20096L	PARTICIPANT	\N	PRESENT	0
612004	611997	19387D	PARTICIPANT	\N	PRESENT	0
612005	611997	20124W	PARTICIPANT	\N	PRESENT	0
612006	611997	19549D	PARTICIPANT	\N	PRESENT	0
613066	613065	11043H	PARTICIPANT	\N	PRESENT	1
613067	613065	19533U	PARTICIPANT	\N	PRESENT	1
613295	612874	14327T	PARTICIPANT	\N	EXCUSE	0
617515	617480	11109J	PARTICIPANT	\N	EXCUSE	0
617516	616391	17589D	PARTICIPANT	\N	PRESENT	0
617517	616391	19413M	PARTICIPANT	\N	PRESENT	0
617518	616391	20248J	PARTICIPANT	\N	PRESENT	0
617519	616391	14213J	PARTICIPANT	\N	PRESENT	0
617525	616391	19551W	PARTICIPANT	\N	PRESENT	0
617526	616391	19749K	PARTICIPANT	\N	PRESENT	0
617780	616392	99004R	PARTICIPANT	\N	PRESENT	0
617788	616392	14267Y	PARTICIPANT	\N	PRESENT	0
617529	616237	07004J	PARTICIPANT	\N	PRESENT	1
617530	616391	05008E	PARTICIPANT	\N	PRESENT	0
617781	616237	19667J	PRESIDENT	0	PRESENT	0
617782	616237	19671E	PARTICIPANT	\N	PRESENT	1
617783	616237	04085P	PARTICIPANT	\N	PRESENT	0
617784	616392	04042C	PARTICIPANT	\N	PRESENT	0
617785	616392	07033P	PARTICIPANT	\N	PRESENT	0
617786	616392	19347U	PARTICIPANT	\N	PRESENT	0
617787	616392	12041X	PARTICIPANT	\N	PRESENT	0
617789	616392	20072C	PARTICIPANT	\N	PRESENT	0
617790	616392	11054L	PARTICIPANT	\N	PRESENT	0
617791	616392	08061X	PARTICIPANT	\N	PRESENT	0
617792	616392	11064N	PARTICIPANT	\N	PRESENT	0
617793	616392	97011G	PARTICIPANT	\N	PRESENT	0
617794	616392	01024M	PARTICIPANT	\N	PRESENT	0
617795	616237	20064C	PARTICIPANT	\N	PRESENT	0
617798	616392	11041F	PARTICIPANT	\N	PRESENT	0
617799	616392	19443T	PARTICIPANT	\N	PRESENT	0
617800	616237	20090E	PARTICIPANT	\N	PRESENT	0
617801	616237	19531S	PARTICIPANT	\N	PRESENT	0
617802	616237	14257W	PARTICIPANT	\N	PRESENT	0
617803	616237	20044X	PARTICIPANT	\N	PRESENT	0
617809	616392	20062A	PARTICIPANT	\N	PRESENT	0
617810	616392	19467C	PARTICIPANT	\N	PRESENT	0
617814	616392	19826F	PARTICIPANT	\N	PRESENT	0
617818	616392	11066Q	PARTICIPANT	\N	PRESENT	0
617820	616392	14133K	PARTICIPANT	\N	PRESENT	0
617821	616237	19711U	PARTICIPANT	\N	PRESENT	0
617822	616237	19741B	PARTICIPANT	\N	PRESENT	0
617823	616392	19758L	PARTICIPANT	\N	PRESENT	0
617824	616392	20024T	PARTICIPANT	\N	PRESENT	0
617826	616392	19551W	PARTICIPANT	\N	PRESENT	0
617827	616392	20038A	PARTICIPANT	\N	PRESENT	0
617828	616392	19387D	PARTICIPANT	\N	PRESENT	0
617829	616392	19565D	PARTICIPANT	\N	PRESENT	0
617830	616392	14107H	PARTICIPANT	\N	PRESENT	0
617831	616392	19479G	PARTICIPANT	\N	PRESENT	0
617832	616392	18083K	PARTICIPANT	\N	PRESENT	0
617833	616392	14038Y	PARTICIPANT	\N	PRESENT	0
617834	616392	14059S	PARTICIPANT	\N	PRESENT	0
617835	616392	14069U	PARTICIPANT	\N	PRESENT	0
617836	616392	20042V	PARTICIPANT	\N	PRESENT	0
617837	616392	14073Q	PARTICIPANT	\N	PRESENT	0
617838	616392	95063L	PARTICIPANT	\N	PRESENT	0
617839	616392	14255U	PARTICIPANT	\N	PRESENT	0
617840	616392	19533U	PARTICIPANT	\N	PRESENT	0
617841	616392	14193X	PARTICIPANT	\N	PRESENT	0
617842	616392	19515S	PARTICIPANT	\N	PRESENT	0
617843	616392	20030R	PARTICIPANT	\N	PRESENT	0
617844	616392	11056N	PARTICIPANT	\N	PRESENT	0
617847	616392	08047A	PARTICIPANT	\N	PRESENT	0
617848	616392	20034V	PARTICIPANT	\N	PRESENT	0
617850	616392	14147R	PARTICIPANT	\N	PRESENT	0
617851	616392	11012A	PARTICIPANT	\N	PRESENT	0
617852	616392	20100N	PARTICIPANT	\N	PRESENT	0
617853	616392	19413M	PARTICIPANT	\N	PRESENT	0
617854	616237	19681G	PARTICIPANT	\N	PRESENT	1
617855	616392	19745F	PARTICIPANT	\N	PRESENT	0
617856	616392	19441R	PARTICIPANT	\N	PRESENT	0
617857	616392	14231L	PARTICIPANT	\N	PRESENT	0
617858	616392	01058X	PARTICIPANT	\N	PRESENT	0
617859	616392	19349W	PARTICIPANT	\N	PRESENT	0
617860	616392	14357A	PARTICIPANT	\N	PRESENT	0
617861	616392	20052X	PARTICIPANT	\N	PRESENT	0
617862	616392	19629C	PARTICIPANT	\N	PRESENT	0
617863	616385	18083K	PARTICIPANT	\N	PRESENT	0
617864	616385	20100N	PARTICIPANT	\N	PRESENT	0
617865	616385	14031R	PARTICIPANT	\N	PRESENT	0
617866	616385	19681G	PARTICIPANT	\N	PRESENT	0
617867	616385	20024T	PARTICIPANT	\N	PRESENT	0
617868	616385	17229F	PARTICIPANT	\N	PRESENT	0
617869	616385	19701S	PARTICIPANT	\N	PRESENT	0
617870	616385	14219Q	PRESIDENT	0	PRESENT	0
617871	616385	20046A	PARTICIPANT	\N	PRESENT	0
617872	616385	19637C	PARTICIPANT	\N	PRESENT	0
617873	616385	19739H	PARTICIPANT	\N	PRESENT	0
617874	616385	14221J	PARTICIPANT	\N	PRESENT	0
617875	616392	19715Y	PARTICIPANT	\N	PRESENT	0
617876	616392	20032T	PARTICIPANT	\N	PRESENT	0
617878	616392	20128B	PARTICIPANT	\N	PRESENT	0
617879	616385	05012A	PARTICIPANT	\N	PRESENT	0
617880	616385	08060W	PARTICIPANT	\N	PRESENT	0
617881	616385	19503N	PARTICIPANT	\N	PRESENT	0
617882	616385	19745F	PARTICIPANT	\N	PRESENT	0
617883	616385	19251M	PARTICIPANT	\N	PRESENT	0
617884	616385	14169X	PARTICIPANT	\N	PRESENT	0
617885	616385	17367Q	PARTICIPANT	\N	PRESENT	0
617886	616385	20122U	PARTICIPANT	\N	PRESENT	0
617887	616385	20106U	PARTICIPANT	\N	PRESENT	0
617888	616385	19549D	PARTICIPANT	\N	PRESENT	0
617889	616385	20076G	PARTICIPANT	\N	PRESENT	0
617890	616385	19599P	PARTICIPANT	\N	PRESENT	0
617891	616385	20118Y	PARTICIPANT	\N	PRESENT	0
617892	616385	11065P	PARTICIPANT	\N	PRESENT	0
617893	616385	20102Q	PARTICIPANT	\N	PRESENT	0
617894	616385	14237S	PARTICIPANT	\N	PRESENT	0
617895	616385	19525U	PARTICIPANT	\N	PRESENT	0
617896	616392	07029T	PARTICIPANT	\N	PRESENT	0
617897	616392	20056C	PARTICIPANT	\N	PRESENT	0
617898	616385	19551W	PARTICIPANT	\N	PRESENT	0
617899	616392	11027H	PARTICIPANT	\N	PRESENT	0
617900	616392	04070G	PARTICIPANT	\N	PRESENT	0
617901	616392	14030Q	PARTICIPANT	\N	PRESENT	0
617902	616392	14053L	PARTICIPANT	\N	PRESENT	0
617903	616392	08009T	PARTICIPANT	\N	PRESENT	0
617904	616392	14257W	PARTICIPANT	\N	PRESENT	0
617905	616392	20090E	PARTICIPANT	\N	PRESENT	0
617906	616392	19335Q	PARTICIPANT	\N	PRESENT	0
617907	616392	19333N	PARTICIPANT	\N	PRESENT	0
617908	616385	19820Y	PARTICIPANT	\N	PRESENT	0
617909	616385	20068G	PARTICIPANT	\N	PRESENT	0
617910	616392	20110Q	PARTICIPANT	\N	PRESENT	0
617911	616385	11026G	PARTICIPANT	\N	PRESENT	0
624177	624176	14133K	PARTICIPANT	\N	PRESENT	0
625442	624170	04057K	PARTICIPANT	\N	PRESENT	0
625443	624170	14237S	PARTICIPANT	\N	PRESENT	0
625444	624170	14331P	PARTICIPANT	\N	PRESENT	0
625445	624170	04045F	PARTICIPANT	\N	PRESENT	0
625446	624170	19707Y	PARTICIPANT	\N	PRESENT	0
625447	624170	19575F	PARTICIPANT	\N	PRESENT	0
625448	624170	20078J	PARTICIPANT	\N	PRESENT	0
625449	624170	19747H	PARTICIPANT	\N	PRESENT	0
625450	624170	19383Y	PARTICIPANT	\N	PRESENT	0
625451	624170	20060X	PARTICIPANT	\N	PRESENT	0
625452	624170	14038Y	PARTICIPANT	\N	PRESENT	0
625453	624170	19467C	PARTICIPANT	\N	PRESENT	0
625454	624170	14187A	PARTICIPANT	\N	PRESENT	0
625455	624170	20174H	PARTICIPANT	\N	PRESENT	0
625456	624170	01043Q	PARTICIPANT	\N	PRESENT	0
625457	624170	14205J	PARTICIPANT	\N	PRESENT	0
625458	624170	14257W	PARTICIPANT	\N	PRESENT	0
625459	624170	19768N	PARTICIPANT	\N	PRESENT	0
625460	624170	11090Q	PARTICIPANT	\N	PRESENT	0
625461	624170	19705W	PARTICIPANT	\N	PRESENT	0
625462	624170	20092G	PARTICIPANT	\N	PRESENT	0
625463	624141	11103C	PARTICIPANT	\N	PRESENT	0
625464	624141	20248J	PARTICIPANT	\N	PRESENT	0
625465	624141	19301E	PARTICIPANT	\N	PRESENT	0
625466	624141	19723Y	PARTICIPANT	\N	PRESENT	0
625467	624141	11031D	PARTICIPANT	\N	PRESENT	0
625468	624141	14026U	PARTICIPANT	\N	PRESENT	0
625469	624141	20130U	PARTICIPANT	\N	PRESENT	0
625470	624141	11045K	PARTICIPANT	\N	PRESENT	0
625471	624141	19717B	PARTICIPANT	\N	PRESENT	0
625472	624141	19553Y	PARTICIPANT	\N	PRESENT	0
625473	624141	19663E	PARTICIPANT	\N	PRESENT	0
625474	624141	19591F	PARTICIPANT	\N	PRESENT	0
625475	624141	19295A	PARTICIPANT	\N	EXCUSE	0
625477	625476	19533U	PARTICIPANT	\N	PRESENT	0
625478	625476	14207L	PARTICIPANT	\N	PRESENT	0
625479	625476	20132W	PARTICIPANT	\N	PRESENT	1
625482	625476	20096L	PARTICIPANT	\N	PRESENT	0
625487	625476	20042V	PARTICIPANT	\N	PRESENT	1
625583	623834	14026U	PARTICIPANT	\N	PRESENT	0
625584	623834	19725B	PARTICIPANT	\N	PRESENT	0
625689	624512	14033T	PARTICIPANT	\N	PRESENT	0
625690	624512	12041X	PARTICIPANT	\N	PRESENT	0
625692	624512	14073Q	PARTICIPANT	\N	PRESENT	0
625697	625696	14073Q	PARTICIPANT	\N	PRESENT	0
625698	625696	14033T	PARTICIPANT	\N	PRESENT	0
625699	625696	12041X	PARTICIPANT	\N	PRESENT	0
625700	625696	14187A	PARTICIPANT	\N	PRESENT	0
625817	625815	20140W	PARTICIPANT	\N	PRESENT	0
625820	625819	20140W	PARTICIPANT	\N	PRESENT	0
625848	625847	19599P	PARTICIPANT	\N	PRESENT	0
625849	625847	19685L	PARTICIPANT	\N	PRESENT	0
626179	624154	18083K	PARTICIPANT	\N	PRESENT	0
626180	624154	19545Y	PARTICIPANT	\N	PRESENT	0
626181	624173	19531S	PARTICIPANT	\N	PRESENT	1
626183	624154	11031D	PARTICIPANT	\N	PRESENT	0
626184	624154	19479G	PARTICIPANT	\N	PRESENT	0
626185	624665	19701S	PARTICIPANT	\N	PRESENT	0
626186	624665	20100N	PARTICIPANT	\N	PRESENT	0
626189	624665	11026G	PARTICIPANT	\N	PRESENT	0
626190	624665	08034U	PARTICIPANT	\N	PRESENT	0
626191	624665	14001X	PARTICIPANT	\N	PRESENT	0
626192	624665	14237S	PARTICIPANT	\N	PRESENT	0
626193	624665	14331P	PARTICIPANT	\N	PRESENT	1
626194	624173	17737W	PARTICIPANT	\N	PRESENT	0
626195	624665	10015M	PARTICIPANT	\N	PRESENT	1
626196	624154	20252E	PARTICIPANT	\N	PRESENT	0
626197	624154	11056N	PARTICIPANT	\N	PRESENT	0
626198	624667	14133K	PARTICIPANT	\N	PRESENT	0
626199	624667	14089Y	PARTICIPANT	\N	PRESENT	0
626200	624667	19701S	PARTICIPANT	\N	PRESENT	0
626201	624667	20100N	PARTICIPANT	\N	PRESENT	0
626202	624667	11083R	PARTICIPANT	\N	PRESENT	0
626203	624667	20128B	PARTICIPANT	\N	PRESENT	0
626204	624667	14097Y	PARTICIPANT	\N	PRESENT	1
626205	624667	11026G	PARTICIPANT	\N	PRESENT	0
626206	624667	08034U	PARTICIPANT	\N	PRESENT	0
626207	624667	14001X	PARTICIPANT	\N	PRESENT	0
626208	624667	04057K	PARTICIPANT	\N	PRESENT	0
626209	624667	14237S	PARTICIPANT	\N	PRESENT	0
626210	624667	14331P	PARTICIPANT	\N	PRESENT	1
626211	624154	19551W	PARTICIPANT	\N	PRESENT	0
626212	624667	14105F	PARTICIPANT	\N	PRESENT	0
626213	624667	14255U	PARTICIPANT	\N	PRESENT	0
626214	624667	11027H	PARTICIPANT	\N	PRESENT	0
626215	624154	14073Q	PARTICIPANT	\N	PRESENT	0
626216	624667	19347U	PARTICIPANT	\N	PRESENT	0
626217	624154	19713W	PARTICIPANT	\N	PRESENT	0
626218	624154	19695N	PARTICIPANT	\N	PRESENT	0
626219	624667	19443T	PARTICIPANT	\N	PRESENT	1
626220	624667	01058X	PARTICIPANT	\N	PRESENT	0
626223	624667	11066Q	PARTICIPANT	\N	PRESENT	0
626224	624667	20064C	PARTICIPANT	\N	PRESENT	1
626225	624491	18083K	PRESIDENT	0	PRESENT	0
626226	624491	20266L	PARTICIPANT	\N	PRESENT	0
626227	624491	19575F	PARTICIPANT	\N	PRESENT	0
626228	624154	11043H	PARTICIPANT	\N	PRESENT	0
626229	624154	20174H	PARTICIPANT	\N	PRESENT	0
626230	624154	19349W	PARTICIPANT	\N	PRESENT	0
626231	624154	14257W	PARTICIPANT	\N	PRESENT	0
626232	624154	14225N	PARTICIPANT	\N	PRESENT	0
626233	624154	11012A	PARTICIPANT	\N	PRESENT	0
626234	624491	18193Q	PARTICIPANT	\N	PRESENT	0
626235	624154	19866P	PARTICIPANT	\N	PRESENT	0
626236	624154	20048C	PARTICIPANT	\N	PRESENT	0
626237	624154	07029T	PARTICIPANT	\N	PRESENT	0
626238	624154	19798U	PARTICIPANT	\N	PRESENT	0
626239	624154	19647E	PARTICIPANT	\N	PRESENT	0
626240	624154	11090Q	PARTICIPANT	\N	PRESENT	0
626241	624154	19467C	PARTICIPANT	\N	PRESENT	0
626242	624154	20094J	PARTICIPANT	\N	PRESENT	0
626277	624155	20094J	PARTICIPANT	\N	PRESENT	0
626278	624155	19551W	PARTICIPANT	\N	PRESENT	0
626279	624155	14225N	PARTICIPANT	\N	PRESENT	0
626280	624155	20092G	PARTICIPANT	\N	PRESENT	0
626281	624155	20130U	PARTICIPANT	\N	PRESENT	0
626282	624155	19349W	PARTICIPANT	\N	PRESENT	0
626283	624155	19651A	PARTICIPANT	\N	PRESENT	0
626284	624155	20106U	PARTICIPANT	\N	PRESENT	0
626285	624155	19545Y	PARTICIPANT	\N	PRESENT	0
626286	624155	17589D	PARTICIPANT	\N	PRESENT	0
626287	624155	19717B	PARTICIPANT	\N	PRESENT	0
626288	624155	19866P	PARTICIPANT	\N	PRESENT	0
626289	624155	20174H	PARTICIPANT	\N	PRESENT	0
626290	624155	19479G	PARTICIPANT	\N	PRESENT	0
626291	624155	14073Q	PARTICIPANT	\N	PRESENT	0
626292	624155	19798U	PARTICIPANT	\N	PRESENT	0
626293	624155	14217N	PARTICIPANT	\N	PRESENT	0
626294	624155	19954N	PARTICIPANT	\N	PRESENT	0
626295	624155	07029T	PARTICIPANT	\N	PRESENT	0
626296	624155	19467C	PARTICIPANT	\N	PRESENT	0
626297	624155	11048N	PARTICIPANT	\N	PRESENT	0
626298	624155	14133K	PARTICIPANT	\N	PRESENT	0
626299	624155	19747H	PARTICIPANT	\N	PRESENT	0
626300	624155	19693L	PARTICIPANT	\N	PRESENT	0
626301	624155	14033T	PARTICIPANT	\N	PRESENT	0
626302	624155	11090Q	PARTICIPANT	\N	PRESENT	0
626303	624155	19713W	PARTICIPANT	\N	PRESENT	0
626304	624155	20144B	PARTICIPANT	\N	PRESENT	0
626305	624155	19647E	PARTICIPANT	\N	PRESENT	0
626306	624155	19565D	PARTICIPANT	\N	PRESENT	0
626307	624155	19695N	PARTICIPANT	\N	PRESENT	0
626308	624155	19441R	PARTICIPANT	\N	PRESENT	0
626275	624155	11045K	PARTICIPANT	\N	PRESENT	0
626276	624155	08045X	PARTICIPANT	\N	PRESENT	0
626309	624155	20086J	PARTICIPANT	\N	PRESENT	0
626310	624155	14207L	PARTICIPANT	\N	PRESENT	0
626311	624155	14187A	PARTICIPANT	\N	PRESENT	0
626312	624155	14257W	PARTICIPANT	\N	PRESENT	0
626313	624155	20018V	PARTICIPANT	\N	PRESENT	0
626314	624155	04043D	PARTICIPANT	\N	PRESENT	0
626315	624155	14147R	PARTICIPANT	\N	PRESENT	0
626316	624155	20054A	PARTICIPANT	\N	PRESENT	0
626317	624155	19691J	PARTICIPANT	\N	PRESENT	0
626318	624155	20082E	PARTICIPANT	\N	PRESENT	0
626319	624155	08061X	PARTICIPANT	\N	PRESENT	0
626320	624173	14257W	PARTICIPANT	\N	PRESENT	1
626321	624155	20062A	PARTICIPANT	\N	PRESENT	0
626322	624155	14329V	PARTICIPANT	\N	PRESENT	0
626323	624491	20034V	PARTICIPANT	\N	PRESENT	0
600650	600649	19515S	PRESIDENT	0	PRESENT	0
600651	600649	14083S	PARTICIPANT	\N	PRESENT	0
600652	600649	19467C	PARTICIPANT	\N	PRESENT	0
600653	600649	14031R	PARTICIPANT	\N	PRESENT	0
600654	600649	20048C	PARTICIPANT	\N	PRESENT	0
600655	600649	19671E	PARTICIPANT	\N	PRESENT	0
600656	600649	19760E	PARTICIPANT	\N	EXCUSE	0
600657	600649	19717B	PARTICIPANT	\N	EXCUSE	0
600658	600649	19575F	PARTICIPANT	\N	EXCUSE	0
600659	600649	14030Q	PARTICIPANT	\N	EXCUSE	0
600660	600649	20094J	PARTICIPANT	\N	EXCUSE	0
600661	600649	08060W	PARTICIPANT	\N	EXCUSE	0
600662	600649	14105F	PARTICIPANT	\N	EXCUSE	0
600663	600649	19545Y	PARTICIPANT	\N	EXCUSE	0
600664	600649	20060X	PARTICIPANT	\N	EXCUSE	0
600665	600649	14329V	PARTICIPANT	\N	EXCUSE	0
600666	600649	14195A	PARTICIPANT	\N	EXCUSE	0
600667	600649	08028W	PARTICIPANT	\N	EXCUSE	0
600668	600649	14357A	PARTICIPANT	\N	EXCUSE	0
600669	600649	19251M	PARTICIPANT	\N	EXCUSE	0
600673	600649	14026U	PARTICIPANT	\N	EXCUSE	0
600671	600649	20040T	PARTICIPANT	\N	EXCUSE	0
600672	600649	19695N	PARTICIPANT	\N	EXCUSE	0
600674	600649	20126Y	PARTICIPANT	\N	EXCUSE	0
600675	600649	08015R	PARTICIPANT	\N	EXCUSE	0
600676	600649	16685X	PARTICIPANT	\N	EXCUSE	0
600677	600649	20030R	PARTICIPANT	\N	EXCUSE	0
600678	600649	17965H	PARTICIPANT	\N	EXCUSE	0
600679	600649	20082E	PARTICIPANT	\N	EXCUSE	0
600680	600649	20054A	PARTICIPANT	\N	EXCUSE	0
600681	600649	20092G	PARTICIPANT	\N	EXCUSE	0
600682	600649	19762G	PARTICIPANT	\N	EXCUSE	0
600683	600649	19301E	PARTICIPANT	\N	EXCUSE	0
600691	600690	19399H	PARTICIPANT	\N	PRESENT	0
603968	603967	19826F	PARTICIPANT	\N	PRESENT	0
603973	603971	19826F	PARTICIPANT	\N	PRESENT	0
603977	603975	19826F	PARTICIPANT	\N	PRESENT	0
608317	606436	19717B	PARTICIPANT	\N	PRESENT	1
610590	608662	14097Y	PARTICIPANT	\N	PRESENT	0
610591	608662	05008E	PARTICIPANT	\N	EXCUSE	0
610592	608662	19691J	PARTICIPANT	\N	EXCUSE	0
614724	614718	11053K	PARTICIPANT	\N	PRESENT	0
614726	614718	14357A	PARTICIPANT	\N	PRESENT	0
614727	614718	19719D	PARTICIPANT	\N	PRESENT	0
614728	614718	19673G	PARTICIPANT	\N	PRESENT	0
614729	614718	01025N	PARTICIPANT	\N	PRESENT	0
614730	614718	19599P	PARTICIPANT	\N	PRESENT	0
614731	614718	14033T	PARTICIPANT	\N	PRESENT	0
614734	614718	14123H	PARTICIPANT	\N	PRESENT	0
614735	614718	14026U	PARTICIPANT	\N	PRESENT	0
614737	614718	14179A	PARTICIPANT	\N	PRESENT	0
614738	614718	14213J	PARTICIPANT	\N	PRESENT	0
614740	614718	19715Y	PARTICIPANT	\N	PRESENT	0
614741	614718	99004R	PARTICIPANT	\N	PRESENT	0
614742	614718	86034E	PARTICIPANT	\N	PRESENT	0
614743	614718	12041X	PARTICIPANT	\N	PRESENT	0
614744	614718	01043Q	PARTICIPANT	\N	PRESENT	0
614745	614718	14147R	PARTICIPANT	\N	PRESENT	0
614747	614718	08073C	PARTICIPANT	\N	PRESENT	0
614748	614718	11045K	PARTICIPANT	\N	PRESENT	0
614749	614718	01028R	PARTICIPANT	\N	PRESENT	0
614751	614718	19301E	PARTICIPANT	\N	PRESENT	0
614752	614718	19413M	PARTICIPANT	\N	PRESENT	0
614886	612997	20086J	PARTICIPANT	\N	PRESENT	0
614887	612997	19826F	PARTICIPANT	\N	PRESENT	0
614888	612997	14187A	PARTICIPANT	\N	PRESENT	0
614889	612997	95063L	PRESIDENT	0	PRESENT	0
614890	612997	05008E	PARTICIPANT	\N	PRESENT	0
614891	612997	11056N	PRESIDENT	1	PRESENT	0
614892	612997	19749K	PARTICIPANT	\N	PRESENT	0
614894	612997	20040T	PARTICIPANT	\N	PRESENT	0
614895	612997	19563B	PARTICIPANT	\N	PRESENT	0
614896	612997	14089Y	PARTICIPANT	\N	PRESENT	0
614897	612997	20098N	PARTICIPANT	\N	EXCUSE	0
614898	612997	14107H	PARTICIPANT	\N	EXCUSE	0
614899	612997	11026G	PARTICIPANT	\N	EXCUSE	0
614900	612997	04047H	PARTICIPANT	\N	PRESENT	0
615183	615180	19673G	PARTICIPANT	\N	PRESENT	0
615224	613120	16685X	PARTICIPANT	\N	PRESENT	0
615518	615517	14030Q	PARTICIPANT	\N	PRESENT	0
615519	615517	14069U	PARTICIPANT	\N	PRESENT	0
615520	615517	17737W	PARTICIPANT	\N	PRESENT	0
615521	615517	08056B	PARTICIPANT	\N	PRESENT	0
615522	615517	19329S	PARTICIPANT	\N	PRESENT	0
615523	615517	14097Y	PARTICIPANT	\N	PRESENT	0
615524	615517	11026G	PARTICIPANT	\N	PRESENT	0
615525	615517	14219Q	PARTICIPANT	\N	PRESENT	0
615526	615517	19637C	PARTICIPANT	\N	PRESENT	0
615527	615517	04070G	PARTICIPANT	\N	PRESENT	0
615528	615517	14237S	PARTICIPANT	\N	PRESENT	0
615529	615517	14331P	PARTICIPANT	\N	PRESENT	0
615539	615536	14255U	PARTICIPANT	\N	PRESENT	0
615540	615536	19826F	PARTICIPANT	\N	PRESENT	0
615542	615536	04070G	PARTICIPANT	\N	PRESENT	0
615543	615536	14237S	PARTICIPANT	\N	PRESENT	0
615592	615587	14189C	PARTICIPANT	\N	PRESENT	0
615593	615587	20032T	PARTICIPANT	\N	PRESENT	0
615594	615587	20076G	PARTICIPANT	\N	PRESENT	0
615596	615587	14205J	PARTICIPANT	\N	PRESENT	0
615597	615587	20028X	PARTICIPANT	\N	PRESENT	0
615620	615617	14083S	PARTICIPANT	\N	PRESENT	0
615599	615587	19745F	PARTICIPANT	\N	PRESENT	0
615600	615587	20082E	PARTICIPANT	\N	PRESENT	0
615601	615587	20054A	PARTICIPANT	\N	PRESENT	0
615602	615587	11097X	PARTICIPANT	\N	PRESENT	0
615612	615587	14257W	PARTICIPANT	\N	PRESENT	0
615604	615587	04045F	PARTICIPANT	\N	PRESENT	0
615605	615587	19713W	PARTICIPANT	\N	PRESENT	0
615619	615617	19575F	PARTICIPANT	\N	PRESENT	0
615622	615617	19681G	PARTICIPANT	\N	PRESENT	0
615623	615617	14357A	PARTICIPANT	\N	PRESENT	0
615624	615617	20174H	PARTICIPANT	\N	PRESENT	0
615625	615617	14033T	PARTICIPANT	\N	PRESENT	0
615626	615617	19711U	PARTICIPANT	\N	PRESENT	0
615627	615617	14257W	PARTICIPANT	\N	PRESENT	0
615628	615617	19533U	PARTICIPANT	\N	PRESENT	0
615629	615617	20092G	PARTICIPANT	\N	PRESENT	0
615630	615617	20062A	PARTICIPANT	\N	PRESENT	0
615647	615646	11083R	PARTICIPANT	\N	PRESENT	0
615648	615646	14033T	PARTICIPANT	\N	PRESENT	0
615649	613102	19701S	PARTICIPANT	\N	PRESENT	0
615650	613102	14001X	PARTICIPANT	\N	PRESENT	0
615653	615651	14169X	PARTICIPANT	\N	PRESENT	0
615654	615651	04070G	PARTICIPANT	\N	PRESENT	0
615659	615658	04070G	PARTICIPANT	\N	PRESENT	0
615660	615658	14169X	PARTICIPANT	\N	PRESENT	0
615942	615941	20024T	PARTICIPANT	\N	PRESENT	0
615943	615941	14030Q	PARTICIPANT	\N	PRESENT	0
615944	615941	14109K	PARTICIPANT	\N	PRESENT	0
615985	615981	07004J	PARTICIPANT	\N	PRESENT	0
615983	615981	04085P	PARTICIPANT	\N	PRESENT	0
615984	615981	19667J	PARTICIPANT	\N	PRESENT	0
615986	615981	20038A	PARTICIPANT	\N	PRESENT	0
616092	613190	19747H	PARTICIPANT	\N	PRESENT	0
616093	613190	11056N	PARTICIPANT	\N	PRESENT	0
616094	613190	19399H	PARTICIPANT	\N	PRESENT	0
616095	613190	20044X	PARTICIPANT	\N	PRESENT	0
616096	613190	19717B	PARTICIPANT	\N	PRESENT	0
616097	613190	19673G	PARTICIPANT	\N	PRESENT	0
616098	613190	17023S	PARTICIPANT	\N	PRESENT	0
616099	613190	97011G	PARTICIPANT	\N	PRESENT	0
616100	613190	20034V	PARTICIPANT	\N	PRESENT	0
616101	613190	19715Y	PARTICIPANT	\N	PRESENT	0
616102	613190	14097Y	PARTICIPANT	\N	PRESENT	0
616103	613190	14147R	PARTICIPANT	\N	PRESENT	0
616104	613190	11072N	PARTICIPANT	\N	PRESENT	0
616105	613190	20148F	PARTICIPANT	\N	PRESENT	0
616106	613190	20146D	PARTICIPANT	\N	PRESENT	0
616107	613190	19319Q	PARTICIPANT	\N	PRESENT	0
616108	613190	20150Y	PARTICIPANT	\N	PRESENT	0
616109	613190	19577H	PARTICIPANT	\N	PRESENT	0
616114	616113	19723Y	PARTICIPANT	\N	PRESENT	0
616115	616113	19735D	PARTICIPANT	\N	PRESENT	0
616117	616113	01048V	PARTICIPANT	\N	EXCUSE	0
616118	616113	20128B	PARTICIPANT	\N	PRESENT	0
616119	616113	20072C	PARTICIPANT	\N	PRESENT	0
616120	616113	01058X	PARTICIPANT	\N	PRESENT	0
616121	616113	19503N	PARTICIPANT	\N	PRESENT	0
616123	616113	19693L	PARTICIPANT	\N	PRESENT	0
616267	616266	20062A	PARTICIPANT	\N	PRESENT	0
616268	616266	20092G	PARTICIPANT	\N	PRESENT	0
616269	616266	20082E	PARTICIPANT	\N	PRESENT	0
616271	616270	14151M	PARTICIPANT	\N	PRESENT	0
616272	616270	20110Q	PARTICIPANT	\N	PRESENT	0
616368	616367	11043H	PARTICIPANT	\N	PRESENT	1
616369	616367	19533U	PARTICIPANT	\N	PRESENT	1
616370	616367	08012N	PARTICIPANT	\N	PRESENT	1
616371	616365	11043H	PARTICIPANT	\N	PRESENT	1
616372	616365	08012N	PARTICIPANT	\N	PRESENT	1
616374	616373	11043H	PARTICIPANT	\N	PRESENT	1
616375	616366	11043H	PARTICIPANT	\N	PRESENT	1
618407	618351	04047H	PARTICIPANT	\N	EXCUSE	0
618837	618835	14083S	PRESIDENT	0	PRESENT	0
622157	621376	19717B	PARTICIPANT	\N	EXCUSE	0
622158	621376	20104S	PARTICIPANT	\N	PRESENT	0
622159	621376	14083S	PRESIDENT	0	PRESENT	0
622160	621376	20100N	PARTICIPANT	\N	PRESENT	0
622161	621376	17023S	PARTICIPANT	\N	PRESENT	0
622162	621376	19333N	PARTICIPANT	\N	PRESENT	0
622163	621376	19447X	PARTICIPANT	\N	PRESENT	0
622165	621376	14059S	PARTICIPANT	\N	PRESENT	0
622166	621376	20150Y	PARTICIPANT	\N	PRESENT	0
622167	621376	19503N	PARTICIPANT	\N	EXCUSE	0
622168	621376	19826F	PARTICIPANT	\N	PRESENT	0
622169	621376	14031R	PARTICIPANT	\N	PRESENT	0
622170	621376	20102Q	PARTICIPANT	\N	PRESENT	0
624848	624524	17023S	PARTICIPANT	\N	PRESENT	0
624849	624150	20116W	PARTICIPANT	\N	PRESENT	0
624850	624150	19713W	PARTICIPANT	\N	PRESENT	0
624851	624150	19599P	PARTICIPANT	\N	PRESENT	0
624852	624150	19685L	PARTICIPANT	\N	PRESENT	0
624853	624667	19383Y	PARTICIPANT	\N	PRESENT	0
624854	624667	14038Y	PARTICIPANT	\N	PRESENT	0
624855	624667	19467C	PARTICIPANT	\N	PRESENT	0
624856	624667	19768N	PARTICIPANT	\N	PRESENT	0
624857	624667	20092G	PARTICIPANT	\N	PRESENT	0
624858	624667	01043Q	PARTICIPANT	\N	PRESENT	0
624859	624667	14357A	PARTICIPANT	\N	PRESENT	0
624860	624667	14187A	PARTICIPANT	\N	PRESENT	0
624861	624667	14033T	PARTICIPANT	\N	PRESENT	0
624862	624667	11090Q	PRESIDENT	0	PRESENT	0
624863	624667	04045F	PARTICIPANT	\N	PRESENT	0
624864	624667	20104S	PARTICIPANT	\N	PRESENT	0
624865	624667	20174H	PARTICIPANT	\N	PRESENT	0
624866	624667	14205J	PARTICIPANT	\N	PRESENT	0
624867	624667	20060X	PARTICIPANT	\N	PRESENT	0
624868	624667	19705W	PARTICIPANT	\N	PRESENT	1
624869	624667	19707Y	PARTICIPANT	\N	PRESENT	1
624870	624667	19575F	PARTICIPANT	\N	PRESENT	0
624871	624667	19747H	PARTICIPANT	\N	PRESENT	0
624872	624667	14257W	PARTICIPANT	\N	PRESENT	0
624873	624667	20078J	PARTICIPANT	\N	PRESENT	0
625055	624152	19701S	PARTICIPANT	\N	PRESENT	0
625056	624152	20038A	PARTICIPANT	\N	PRESENT	0
625057	624152	20076G	PARTICIPANT	\N	PRESENT	0
625058	624152	19820Y	PARTICIPANT	\N	PRESENT	0
625059	624152	14219Q	PRESIDENT	0	PRESENT	0
625061	624152	20046A	PARTICIPANT	\N	PRESENT	0
625062	624152	14221J	PARTICIPANT	\N	PRESENT	0
625063	624152	17229F	PARTICIPANT	\N	PRESENT	0
625064	624152	19637C	PARTICIPANT	\N	PRESENT	0
625065	624152	20100N	PARTICIPANT	\N	PRESENT	0
625066	624152	18083K	PARTICIPANT	\N	PRESENT	0
625067	624152	20020P	PARTICIPANT	\N	PRESENT	0
625068	624152	17367Q	PARTICIPANT	\N	PRESENT	0
625069	624152	20024T	PARTICIPANT	\N	PRESENT	0
625070	624152	11065P	PARTICIPANT	\N	PRESENT	0
625072	624152	05012A	PARTICIPANT	\N	PRESENT	0
625073	624047	04047H	PRESIDENT	0	PRESENT	0
625074	624047	19673G	PARTICIPANT	\N	PRESENT	0
625075	624047	01028R	PARTICIPANT	\N	PRESENT	0
625076	624047	19447X	PARTICIPANT	\N	PRESENT	0
625077	624047	05008E	PARTICIPANT	\N	PRESENT	0
625078	624047	19954N	PARTICIPANT	\N	PRESENT	0
625079	624047	95063L	PARTICIPANT	\N	PRESENT	0
625080	624047	14179A	PARTICIPANT	\N	PRESENT	0
625081	624047	14147R	PARTICIPANT	\N	PRESENT	0
625082	624047	11085T	PARTICIPANT	\N	PRESENT	0
625083	624047	19749K	PARTICIPANT	\N	PRESENT	0
625084	624047	14259Y	PARTICIPANT	\N	PRESENT	0
625085	624047	20022R	PARTICIPANT	\N	PRESENT	0
625086	624152	19826F	PARTICIPANT	\N	PRESENT	0
625087	624152	19685L	PARTICIPANT	\N	PRESENT	0
625088	624152	14031R	PARTICIPANT	\N	PRESENT	0
625089	624152	14169X	PARTICIPANT	\N	PRESENT	0
625090	624047	19725B	PARTICIPANT	\N	PRESENT	0
625091	624047	19675J	PARTICIPANT	\N	PRESENT	0
625092	624152	19549D	PARTICIPANT	\N	PRESENT	0
625093	624152	08060W	PARTICIPANT	\N	PRESENT	0
625094	624047	14215L	PARTICIPANT	\N	PRESENT	0
625095	624047	19629C	PARTICIPANT	\N	PRESENT	0
625096	624152	14237S	PARTICIPANT	\N	PRESENT	0
625099	624047	14053L	PARTICIPANT	\N	PRESENT	0
625100	624047	14089Y	PARTICIPANT	\N	PRESENT	0
625101	623502	11040E	PARTICIPANT	\N	PRESENT	0
625102	623502	14083S	PARTICIPANT	\N	PRESENT	0
625103	623502	11048N	PARTICIPANT	\N	PRESENT	0
625104	623502	19647E	PARTICIPANT	\N	PRESENT	0
625105	623502	14253S	PARTICIPANT	\N	PRESENT	0
625106	623502	20116W	PARTICIPANT	\N	PRESENT	0
625107	623502	99004R	PARTICIPANT	\N	PRESENT	0
625108	623502	14225N	PRESIDENT	0	PRESENT	0
625109	623502	19671E	PARTICIPANT	\N	PRESENT	0
625110	623502	11070L	PARTICIPANT	\N	PRESENT	0
625111	623502	14173T	PARTICIPANT	\N	PRESENT	0
625114	623502	08009T	PARTICIPANT	\N	PRESENT	0
625115	623502	07029T	PARTICIPANT	\N	EXCUSE	0
625116	623502	20080C	PARTICIPANT	\N	PRESENT	1
625117	624047	17737W	PARTICIPANT	\N	PRESENT	0
625118	623502	20070A	PARTICIPANT	\N	PRESENT	0
625119	623502	20036X	PARTICIPANT	\N	PRESENT	0
625120	623502	08011M	PARTICIPANT	\N	PRESENT	0
625121	623502	19762G	PARTICIPANT	\N	PRESENT	0
625122	624047	14231L	PARTICIPANT	\N	PRESENT	0
625123	623502	19545Y	PARTICIPANT	\N	PRESENT	0
625124	623502	11053K	PARTICIPANT	\N	PRESENT	0
625286	624141	14281W	PARTICIPANT	\N	PRESENT	0
625306	624152	20136B	PARTICIPANT	\N	PRESENT	0
625721	625488	17023S	PARTICIPANT	\N	PRESENT	0
625723	625488	19569H	PARTICIPANT	\N	PRESENT	0
625724	625488	19721W	PARTICIPANT	\N	PRESENT	0
625725	625488	19369B	PARTICIPANT	\N	PRESENT	0
625726	625488	14030Q	PARTICIPANT	\N	PRESENT	0
625727	625488	95041E	PARTICIPANT	\N	PRESENT	0
625728	625488	19531S	PARTICIPANT	\N	PRESENT	0
625730	625729	14089Y	PARTICIPANT	\N	PRESENT	0
625731	625729	11056N	PARTICIPANT	\N	PRESENT	0
625732	625488	16685X	PARTICIPANT	\N	PRESENT	0
625733	625729	20024T	PARTICIPANT	\N	PRESENT	0
625734	625488	19441R	PARTICIPANT	\N	PRESENT	0
625735	625488	19826F	PARTICIPANT	\N	PRESENT	0
625736	625729	20098N	PARTICIPANT	\N	PRESENT	0
625737	625488	19619A	PARTICIPANT	\N	PRESENT	0
625738	625488	19713W	PARTICIPANT	\N	PRESENT	0
625739	625729	95063L	PARTICIPANT	\N	PRESENT	0
625740	625488	20040T	PARTICIPANT	\N	PRESENT	0
625741	625488	01043Q	PARTICIPANT	\N	PRESENT	0
625742	625488	19735D	PARTICIPANT	\N	PRESENT	0
625743	625488	19739H	PARTICIPANT	\N	PRESENT	0
625745	625488	01034P	PARTICIPANT	\N	PRESENT	0
625746	625488	14089Y	PARTICIPANT	\N	PRESENT	0
625747	625488	01024M	PARTICIPANT	\N	PRESENT	0
625749	625488	20066E	PARTICIPANT	\N	PRESENT	0
625750	625488	20286Q	PARTICIPANT	\N	PRESENT	0
600233	600232	11040E	PARTICIPANT	\N	PRESENT	0
600234	600232	14026U	PARTICIPANT	\N	PRESENT	0
600235	600232	01057W	PARTICIPANT	\N	PRESENT	0
600236	600232	14147R	PARTICIPANT	\N	PRESENT	0
603956	603952	14229S	PARTICIPANT	\N	PRESENT	1
603957	603952	19735D	PARTICIPANT	\N	PRESENT	1
603961	603959	14229S	PARTICIPANT	\N	PRESENT	0
603962	603959	19735D	PARTICIPANT	\N	PRESENT	0
608453	601129	14189C	PARTICIPANT	\N	EXCUSE	0
608454	601129	17737W	PARTICIPANT	\N	EXCUSE	0
608455	601129	20066E	PARTICIPANT	\N	EXCUSE	0
608456	601129	20118Y	PARTICIPANT	\N	EXCUSE	0
608457	601129	20098N	PARTICIPANT	\N	EXCUSE	0
608459	601129	20046A	PARTICIPANT	\N	EXCUSE	0
608465	601129	20024T	PARTICIPANT	\N	PRESENT	0
608466	601129	14030Q	PRESIDENT	0	PRESENT	0
608468	601129	20080C	PARTICIPANT	\N	PRESENT	0
608470	601129	11031D	PARTICIPANT	\N	PRESENT	0
608472	601129	19681G	PARTICIPANT	\N	PRESENT	0
608473	601129	19693L	PARTICIPANT	\N	PRESENT	0
608475	601129	19599P	PARTICIPANT	\N	PRESENT	0
608476	601129	20106U	PARTICIPANT	\N	PRESENT	0
608477	601129	19715Y	PARTICIPANT	\N	PRESENT	0
608478	601129	07029T	PARTICIPANT	\N	PRESENT	0
608479	601129	14109K	PARTICIPANT	\N	PRESENT	0
610278	610276	11043H	PARTICIPANT	\N	PRESENT	1
610279	610276	08012N	PARTICIPANT	\N	PRESENT	1
610280	610276	19533U	PARTICIPANT	\N	PRESENT	1
610337	608661	08015R	PARTICIPANT	\N	PRESENT	0
610338	608661	01043Q	PARTICIPANT	\N	PRESENT	0
610339	608661	11077T	PARTICIPANT	\N	PRESENT	0
610340	608661	14205J	PARTICIPANT	\N	PRESENT	0
610341	608661	19441R	PARTICIPANT	\N	PRESENT	0
610342	608661	14251Q	PARTICIPANT	\N	PRESENT	0
610343	608661	19563B	PARTICIPANT	\N	PRESENT	0
610344	608661	20028X	PARTICIPANT	\N	PRESENT	0
610345	608661	20018V	PARTICIPANT	\N	PRESENT	0
610346	608661	19369B	PARTICIPANT	\N	PRESENT	0
610347	608661	14257W	PARTICIPANT	\N	PRESENT	0
610348	608661	19768N	PARTICIPANT	\N	PRESENT	0
610349	608661	20030R	PARTICIPANT	\N	PRESENT	0
610350	608661	11090Q	PARTICIPANT	\N	PRESENT	0
610351	608661	20082E	PARTICIPANT	\N	PRESENT	0
610352	608661	19705W	PARTICIPANT	\N	PRESENT	0
610353	608661	20054A	PARTICIPANT	\N	PRESENT	0
610354	608661	20092G	PARTICIPANT	\N	PRESENT	0
610355	608661	04045F	PARTICIPANT	\N	PRESENT	0
610356	608661	20062A	PARTICIPANT	\N	PRESENT	0
610357	608661	19413M	PARTICIPANT	\N	PRESENT	0
611787	610702	14189C	PARTICIPANT	\N	EXCUSE	0
611791	610702	20094J	PARTICIPANT	\N	PRESENT	0
611794	610702	14089Y	PARTICIPANT	\N	PRESENT	0
611797	610702	19701S	PARTICIPANT	\N	PRESENT	0
613160	613158	07033P	PARTICIPANT	\N	PRESENT	0
611801	610702	20100N	PARTICIPANT	\N	PRESENT	0
611804	610702	11083R	PARTICIPANT	\N	PRESENT	0
611806	610702	19725B	PARTICIPANT	\N	PRESENT	0
611807	610702	20128B	PARTICIPANT	\N	PRESENT	0
611809	610702	19333N	PARTICIPANT	\N	PRESENT	0
611811	610702	14097Y	PARTICIPANT	\N	PRESENT	0
611813	610702	12041X	PARTICIPANT	\N	PRESENT	0
611816	610702	19711U	PARTICIPANT	\N	PRESENT	0
611818	610702	11026G	PARTICIPANT	\N	PRESENT	0
611820	610702	08034U	PARTICIPANT	\N	PRESENT	0
611823	610702	14001X	PARTICIPANT	\N	PRESENT	0
611826	610702	04070G	PARTICIPANT	\N	PRESENT	0
611828	610702	14169X	PARTICIPANT	\N	PRESENT	0
611832	610702	14237S	PARTICIPANT	\N	EXCUSE	0
611835	610702	14331P	PRESIDENT	0	PRESENT	0
611838	610702	10015M	PARTICIPANT	\N	PRESENT	0
611841	610702	04045F	PARTICIPANT	\N	PRESENT	0
611848	610702	14357A	PARTICIPANT	\N	PRESENT	0
613161	613158	14059S	PARTICIPANT	\N	PRESENT	0
613162	613158	19551W	PARTICIPANT	\N	PRESENT	0
613275	613274	20094J	PARTICIPANT	\N	PRESENT	0
613276	613274	20104S	PRESIDENT	0	PRESENT	0
613277	613274	19701S	PARTICIPANT	\N	PRESENT	0
613278	613274	20100N	PARTICIPANT	\N	PRESENT	0
613279	613274	04035D	PARTICIPANT	\N	PRESENT	0
613281	613274	14331P	PARTICIPANT	\N	EXCUSE	0
613282	613274	19631V	PARTICIPANT	\N	PRESENT	0
613283	613274	19747H	PARTICIPANT	\N	PRESENT	0
613284	613274	19467C	PARTICIPANT	\N	PRESENT	0
613285	613274	19369B	PARTICIPANT	\N	PRESENT	0
613286	613274	14357A	PARTICIPANT	\N	PRESENT	0
613287	613274	11090Q	PARTICIPANT	\N	PRESENT	0
613288	613274	20082E	PARTICIPANT	\N	PRESENT	0
613289	613274	20062A	PARTICIPANT	\N	PRESENT	0
613290	613274	11083R	PARTICIPANT	\N	PRESENT	0
613367	612794	14107H	PARTICIPANT	\N	EXCUSE	0
617962	616393	11056N	PARTICIPANT	\N	PRESENT	0
613369	612796	14107H	PARTICIPANT	\N	EXCUSE	0
613370	612796	19729F	PARTICIPANT	\N	EXCUSE	0
617963	616393	19758L	PARTICIPANT	\N	PRESENT	0
613372	612794	19729F	PARTICIPANT	\N	EXCUSE	0
617964	616393	19333N	PARTICIPANT	\N	PRESENT	0
617965	616393	14053L	PARTICIPANT	\N	PRESENT	0
617966	616393	19715Y	PARTICIPANT	\N	PRESENT	0
617967	616393	20038A	PARTICIPANT	\N	PRESENT	0
617968	616393	14257W	PARTICIPANT	\N	PRESENT	0
617969	616393	14357A	PARTICIPANT	\N	PRESENT	0
617970	616393	19349W	PARTICIPANT	\N	PRESENT	0
617971	616393	20056C	PARTICIPANT	\N	PRESENT	0
617972	616393	20128B	PARTICIPANT	\N	PRESENT	0
617973	616393	19515S	PARTICIPANT	\N	PRESENT	0
617974	616393	20082E	PARTICIPANT	\N	PRESENT	0
617975	616393	14038Y	PARTICIPANT	\N	PRESENT	0
617976	616393	11097X	PARTICIPANT	\N	PRESENT	0
617977	616393	20084G	PARTICIPANT	\N	PRESENT	0
617978	616393	08015R	PARTICIPANT	\N	PRESENT	0
617979	616393	20110Q	PARTICIPANT	\N	PRESENT	0
617980	616393	19347U	PARTICIPANT	\N	PRESENT	0
617981	616393	20032T	PARTICIPANT	\N	PRESENT	0
617982	616393	20072C	PARTICIPANT	\N	PRESENT	0
617983	616393	20062A	PARTICIPANT	\N	PRESENT	0
617984	616393	19387D	PARTICIPANT	\N	PRESENT	0
617985	616393	20090E	PARTICIPANT	\N	PRESENT	0
617986	616393	19443T	PARTICIPANT	\N	PRESENT	0
617987	616393	14107H	PARTICIPANT	\N	PRESENT	0
617988	616393	07029T	PARTICIPANT	\N	PRESENT	0
617989	616393	19629C	PARTICIPANT	\N	PRESENT	0
617990	616393	19467C	PARTICIPANT	\N	PRESENT	0
617991	616393	20034V	PARTICIPANT	\N	PRESENT	0
617992	616393	20018V	PARTICIPANT	\N	PRESENT	0
617993	616393	20030R	PARTICIPANT	\N	PRESENT	0
617994	616393	19335Q	PARTICIPANT	\N	PRESENT	0
617995	616393	19441R	PARTICIPANT	\N	PRESENT	0
617996	616385	20032T	PARTICIPANT	\N	EXCUSE	0
617997	616393	14111D	PARTICIPANT	\N	PRESENT	0
617998	616393	04070G	PARTICIPANT	\N	PRESENT	0
617960	616393	99004R	PARTICIPANT	\N	PRESENT	0
617961	616393	14231L	PARTICIPANT	\N	PRESENT	0
617999	616393	14030Q	PARTICIPANT	\N	PRESENT	0
618000	616393	01024M	PARTICIPANT	\N	PRESENT	0
618001	616393	19826F	PARTICIPANT	\N	PRESENT	0
618002	616393	14073Q	PARTICIPANT	\N	PRESENT	0
618003	616393	14069U	PARTICIPANT	\N	PRESENT	0
618004	616393	20086J	PARTICIPANT	\N	PRESENT	0
618005	616393	20026V	PARTICIPANT	\N	PRESENT	0
618006	616393	20024T	PARTICIPANT	\N	PRESENT	0
618007	616393	14147R	PARTICIPANT	\N	PRESENT	0
618008	616393	20066E	PARTICIPANT	\N	PRESENT	0
618009	616393	19563B	PARTICIPANT	\N	PRESENT	0
618010	616393	08009T	PARTICIPANT	\N	PRESENT	0
618011	616393	14033T	PARTICIPANT	\N	PRESENT	0
618013	616393	14021P	PARTICIPANT	\N	PRESENT	0
617167	616238	19675J	PARTICIPANT	\N	PRESENT	1
617168	616238	04047H	PARTICIPANT	\N	PRESENT	1
617169	616238	11033F	PARTICIPANT	\N	PRESENT	1
617171	616238	14179A	PARTICIPANT	\N	PRESENT	1
617172	616238	10015M	PARTICIPANT	\N	PRESENT	1
617173	616238	20114U	PARTICIPANT	\N	PRESENT	1
617174	616238	20128B	PARTICIPANT	\N	PRESENT	1
617175	616238	19725B	PARTICIPANT	\N	PRESENT	1
617177	616238	08018U	PARTICIPANT	\N	EXCUSE	0
617179	616238	07004J	PARTICIPANT	\N	EXCUSE	0
621380	621379	19621T	PARTICIPANT	\N	PRESENT	1
621381	621379	14030Q	PARTICIPANT	\N	PRESENT	1
621382	621379	14109K	PARTICIPANT	\N	PRESENT	1
621383	621378	19621T	PARTICIPANT	\N	PRESENT	1
621384	621378	14030Q	PARTICIPANT	\N	PRESENT	1
621385	621378	14109K	PARTICIPANT	\N	PRESENT	1
623722	623718	19515S	PRESIDENT	0	PRESENT	0
623723	623718	19671E	PARTICIPANT	\N	PRESENT	0
623724	623718	20054A	PARTICIPANT	\N	PRESENT	0
623725	623718	20126Y	PARTICIPANT	\N	PRESENT	0
623727	623718	14031R	PARTICIPANT	\N	PRESENT	0
623729	623718	20092G	PARTICIPANT	\N	PRESENT	0
623730	623718	14083S	PARTICIPANT	\N	PRESENT	0
623731	623718	19467C	PARTICIPANT	\N	PRESENT	0
623732	623718	19575F	PARTICIPANT	\N	PRESENT	0
623733	623718	20094J	PARTICIPANT	\N	PRESENT	0
623734	623718	19762G	PARTICIPANT	\N	PRESENT	0
623735	623718	19760E	PARTICIPANT	\N	PRESENT	0
623741	623718	20048C	PARTICIPANT	\N	PRESENT	0
623756	623718	14357A	PARTICIPANT	\N	PRESENT	0
623758	623718	14030Q	PARTICIPANT	\N	EXCUSE	0
623759	623718	08060W	PARTICIPANT	\N	EXCUSE	0
623760	623718	19545Y	PARTICIPANT	\N	EXCUSE	0
623762	623718	16685X	PARTICIPANT	\N	EXCUSE	0
623763	623718	20108W	PARTICIPANT	\N	EXCUSE	0
623764	623718	19866P	PARTICIPANT	\N	EXCUSE	0
625823	625816	20144B	PARTICIPANT	\N	PRESENT	0
626187	626182	20144B	PARTICIPANT	\N	PRESENT	0
626188	626182	20094J	PARTICIPANT	\N	PRESENT	0
626222	626221	20144B	PARTICIPANT	\N	PRESENT	0
626324	624155	19673G	PARTICIPANT	\N	PRESENT	0
626325	624155	19762G	PARTICIPANT	\N	PRESENT	0
626326	624155	01024M	PARTICIPANT	\N	PRESENT	0
626327	623939	10006L	PARTICIPANT	0	PRESENT	0
626328	623939	19703U	PARTICIPANT	\N	PRESENT	1
626329	623939	19683J	PRESIDENT	0	PRESENT	0
626330	623939	19691J	PARTICIPANT	\N	PRESENT	0
626331	623939	14147R	PARTICIPANT	\N	PRESENT	0
626332	623939	19735D	PARTICIPANT	\N	EXCUSE	0
626333	623939	19467C	PARTICIPANT	\N	PRESENT	1
626334	624155	19347U	PARTICIPANT	\N	PRESENT	0
626335	624155	01043Q	PARTICIPANT	\N	PRESENT	0
626336	624155	19739H	PARTICIPANT	\N	PRESENT	0
626337	624155	14026U	PARTICIPANT	\N	PRESENT	0
626338	624155	20024T	PARTICIPANT	\N	PRESENT	0
626339	624155	20034V	PARTICIPANT	\N	PRESENT	0
626340	624155	11043H	PARTICIPANT	\N	PRESENT	0
626341	624155	19447X	PARTICIPANT	\N	PRESENT	0
626342	624135	14059S	PARTICIPANT	\N	EXCUSE	0
626343	623939	19301E	PARTICIPANT	\N	PRESENT	1
626344	624155	08010L	PARTICIPANT	\N	PRESENT	0
626345	624155	18083K	PARTICIPANT	\N	PRESENT	0
626346	624155	19575F	PARTICIPANT	\N	PRESENT	0
626347	624155	14069U	PARTICIPANT	\N	PRESENT	0
626348	623939	19553Y	PARTICIPANT	\N	PRESENT	1
626349	624155	95041E	PARTICIPANT	\N	PRESENT	0
626350	624155	19749K	PARTICIPANT	\N	PRESENT	0
626351	624155	14053L	PARTICIPANT	\N	PRESENT	0
626352	624155	19399H	PARTICIPANT	\N	PRESENT	0
626353	624155	20058E	PARTICIPANT	\N	PRESENT	0
626354	624155	19533U	PARTICIPANT	\N	PRESENT	0
626355	624155	20108W	PARTICIPANT	\N	PRESENT	0
626356	624155	14357A	PARTICIPANT	\N	PRESENT	0
626357	624155	20122U	PARTICIPANT	\N	PRESENT	0
626358	624155	14031R	PARTICIPANT	\N	PRESENT	0
626359	624155	20104S	PARTICIPANT	\N	PRESENT	0
626360	624155	20136B	PARTICIPANT	\N	PRESENT	0
626361	624155	19701S	PARTICIPANT	\N	PRESENT	0
626362	624155	10006L	PARTICIPANT	\N	PRESENT	0
626363	624155	19629C	PARTICIPANT	\N	PRESENT	0
626364	624155	11012A	PARTICIPANT	\N	PRESENT	0
626423	624156	11090Q	PARTICIPANT	\N	PRESENT	0
626424	624156	19866P	PARTICIPANT	\N	PRESENT	0
626425	624156	19629C	PARTICIPANT	\N	PRESENT	0
626426	624156	20086J	PARTICIPANT	\N	PRESENT	0
626427	624156	19647E	PARTICIPANT	\N	PRESENT	0
626428	624156	19479G	PARTICIPANT	\N	PRESENT	0
626429	624156	20024T	PARTICIPANT	\N	PRESENT	0
626430	624156	11048N	PARTICIPANT	\N	PRESENT	0
626431	624156	20106U	PARTICIPANT	\N	PRESENT	0
626432	624156	20144B	PARTICIPANT	\N	PRESENT	0
626433	624156	14207L	PARTICIPANT	\N	PRESENT	0
626434	624156	20174H	PARTICIPANT	\N	PRESENT	0
626435	624156	19441R	PARTICIPANT	\N	PRESENT	0
626436	624156	07029T	PARTICIPANT	\N	PRESENT	0
626437	624156	14257W	PARTICIPANT	\N	PRESENT	0
626438	624156	20094J	PARTICIPANT	\N	PRESENT	0
626439	624156	19467C	PARTICIPANT	\N	PRESENT	0
626440	624156	19545Y	PARTICIPANT	\N	PRESENT	0
626441	624156	14187A	PARTICIPANT	\N	PRESENT	0
626442	624156	19347U	PARTICIPANT	\N	PRESENT	0
626443	624156	14042U	PARTICIPANT	\N	PRESENT	0
626444	624156	20132W	PARTICIPANT	\N	PRESENT	0
626445	624156	19695N	PARTICIPANT	\N	PRESENT	0
626446	624156	04043D	PARTICIPANT	\N	PRESENT	0
626447	624156	11067R	PARTICIPANT	\N	PRESENT	0
626448	624156	17589D	PARTICIPANT	\N	PRESENT	0
626449	624156	19531S	PARTICIPANT	\N	PRESENT	0
626450	624156	04085P	PARTICIPANT	\N	PRESENT	0
626451	624156	10006L	PARTICIPANT	\N	PRESENT	0
626452	624156	14329V	PARTICIPANT	\N	PRESENT	0
626453	624156	01024M	PARTICIPANT	\N	PRESENT	0
626454	624156	19762G	PARTICIPANT	\N	PRESENT	0
626455	624156	14053L	PARTICIPANT	\N	PRESENT	0
626456	624156	19747H	PARTICIPANT	\N	PRESENT	0
626457	624156	19717B	PARTICIPANT	\N	PRESENT	0
626458	624156	19575F	PARTICIPANT	\N	PRESENT	0
626459	624156	20034V	PARTICIPANT	\N	PRESENT	0
626460	624156	20062A	PARTICIPANT	\N	PRESENT	0
626461	624156	19749K	PARTICIPANT	\N	PRESENT	0
626462	624156	20082E	PARTICIPANT	\N	PRESENT	0
626463	624156	20266L	PARTICIPANT	\N	PRESENT	0
626464	624156	19447X	PARTICIPANT	\N	PRESENT	0
626465	624156	20026V	PARTICIPANT	\N	PRESENT	0
626466	624156	20180F	PARTICIPANT	\N	PRESENT	0
626513	624158	14026U	PARTICIPANT	\N	PRESENT	0
626514	624158	19447X	PARTICIPANT	\N	PRESENT	0
626515	624158	14215L	PARTICIPANT	\N	PRESENT	0
626153	626151	20144B	PARTICIPANT	\N	PRESENT	0
626154	626151	20094J	PARTICIPANT	\N	PRESENT	0
626516	624158	19347U	PARTICIPANT	\N	PRESENT	0
626517	624158	20266L	PARTICIPANT	\N	PRESENT	0
626518	624158	11067R	PARTICIPANT	\N	PRESENT	0
626519	624158	20094J	PARTICIPANT	\N	PRESENT	0
626520	624158	04085P	PARTICIPANT	\N	PRESENT	0
626521	624158	19695N	PARTICIPANT	\N	PRESENT	0
626522	624158	19545Y	PARTICIPANT	\N	PRESENT	0
626523	624158	17589D	PARTICIPANT	\N	PRESENT	0
626524	624158	19717B	PARTICIPANT	\N	PRESENT	0
626421	624156	14026U	PARTICIPANT	\N	PRESENT	0
626422	624156	14033T	PARTICIPANT	\N	PRESENT	0
626525	624158	19629C	PARTICIPANT	\N	PRESENT	0
626526	624158	20132W	PARTICIPANT	\N	PRESENT	0
626527	624158	20106U	PARTICIPANT	\N	PRESENT	0
626528	624158	20174H	PARTICIPANT	\N	PRESENT	0
626529	624158	19479G	PARTICIPANT	\N	PRESENT	0
626530	624158	19749K	PARTICIPANT	\N	PRESENT	0
626531	624158	14042U	PARTICIPANT	\N	PRESENT	0
626532	624158	20024T	PARTICIPANT	\N	PRESENT	0
626533	624158	14069U	PARTICIPANT	\N	PRESENT	0
626534	624158	20108W	PARTICIPANT	\N	PRESENT	0
626535	624158	07029T	PARTICIPANT	\N	PRESENT	0
626536	624158	20026V	PARTICIPANT	\N	PRESENT	0
626537	624158	20180F	PARTICIPANT	\N	PRESENT	0
626538	624158	19741B	PARTICIPANT	\N	PRESENT	0
626539	624158	20034V	PARTICIPANT	\N	PRESENT	0
626540	624158	20062A	PARTICIPANT	\N	PRESENT	0
626541	624158	14033T	PARTICIPANT	\N	PRESENT	0
626542	624158	95041E	PARTICIPANT	\N	PRESENT	0
626543	624158	14179A	PARTICIPANT	\N	PRESENT	0
626544	624158	20086J	PARTICIPANT	\N	PRESENT	0
610842	610841	14033T	PARTICIPANT	\N	PRESENT	0
610843	610830	19667J	PARTICIPANT	\N	PRESENT	0
610844	610830	04085P	PARTICIPANT	\N	PRESENT	0
610845	610830	20064C	PARTICIPANT	\N	PRESENT	0
615631	612796	17737W	PARTICIPANT	\N	EXCUSE	0
615632	612796	14021P	PARTICIPANT	\N	PRESENT	0
615704	613455	04059M	PARTICIPANT	\N	PRESENT	0
615705	613455	19651A	PARTICIPANT	\N	PRESENT	0
615706	613455	20086J	PARTICIPANT	\N	PRESENT	0
615707	613455	20132W	PARTICIPANT	\N	PRESENT	0
615708	613455	19399H	PARTICIPANT	\N	PRESENT	0
615709	613455	19611R	PRESIDENT	0	PRESENT	0
615710	613455	19699S	PARTICIPANT	\N	PRESENT	0
615711	613455	20142Y	PARTICIPANT	\N	PRESENT	0
615712	613455	14229S	PARTICIPANT	\N	PRESENT	0
615713	613455	20026V	PARTICIPANT	\N	PRESENT	0
616126	616113	11067R	PARTICIPANT	\N	EXCUSE	0
616173	614875	20048C	PARTICIPANT	\N	EXCUSE	0
616174	614875	20108W	PARTICIPANT	\N	EXCUSE	0
616186	616185	19709B	PARTICIPANT	\N	PRESENT	0
616187	616185	20264J	PARTICIPANT	\N	PRESENT	0
616188	616185	11027H	PARTICIPANT	\N	PRESENT	0
616189	616185	20266L	PARTICIPANT	\N	PRESENT	0
616190	616185	14147R	PARTICIPANT	\N	PRESENT	0
616191	616185	18083K	PARTICIPANT	\N	PRESENT	0
616193	616192	19711U	PARTICIPANT	\N	PRESENT	0
616194	616192	08034U	PARTICIPANT	\N	PRESENT	0
616195	616192	97011G	PARTICIPANT	\N	PRESENT	0
616196	616192	04033B	PARTICIPANT	\N	PRESENT	0
616197	616192	19515S	PARTICIPANT	\N	PRESENT	0
616198	616192	14357A	PARTICIPANT	\N	PRESENT	0
616206	616205	17737W	PARTICIPANT	\N	PRESENT	0
616208	616181	20062A	PARTICIPANT	\N	PRESENT	0
616209	616181	04045F	PARTICIPANT	\N	PRESENT	0
616210	616181	19782L	PARTICIPANT	\N	PRESENT	0
616211	616182	20062A	PARTICIPANT	\N	PRESENT	0
616212	616182	20092G	PARTICIPANT	\N	PRESENT	0
616213	616182	19782L	PARTICIPANT	\N	PRESENT	0
616214	616182	04045F	PARTICIPANT	\N	PRESENT	0
616215	616183	20062A	PARTICIPANT	\N	PRESENT	0
616216	616183	20092G	PARTICIPANT	\N	PRESENT	0
616217	616183	04045F	PARTICIPANT	\N	PRESENT	0
616218	616183	19782L	PARTICIPANT	\N	PRESENT	0
616219	616176	20062A	PARTICIPANT	\N	PRESENT	0
616220	616176	20092G	PARTICIPANT	\N	PRESENT	0
616221	616176	19782L	PARTICIPANT	\N	PRESENT	0
616222	616177	20062A	PARTICIPANT	\N	PRESENT	0
616223	616177	20092G	PARTICIPANT	\N	PRESENT	0
616224	616177	19782L	PARTICIPANT	\N	PRESENT	0
616225	616177	20082E	PARTICIPANT	\N	PRESENT	0
616226	616178	20062A	PARTICIPANT	\N	PRESENT	0
616227	616178	20092G	PARTICIPANT	\N	PRESENT	0
616228	616178	20082E	PARTICIPANT	\N	PRESENT	0
616229	616179	20062A	PARTICIPANT	\N	PRESENT	0
616230	616179	20092G	PARTICIPANT	\N	PRESENT	0
616231	616180	20062A	PARTICIPANT	\N	PRESENT	0
616232	616180	20092G	PARTICIPANT	\N	PRESENT	0
616233	616184	20062A	PARTICIPANT	\N	PRESENT	0
616234	616184	20092G	PARTICIPANT	\N	PRESENT	0
616235	616184	20082E	PARTICIPANT	\N	PRESENT	0
618125	618124	14133K	PARTICIPANT	\N	PRESENT	0
618126	618124	14189C	PARTICIPANT	\N	PRESENT	1
618127	618124	19701S	PARTICIPANT	\N	PRESENT	0
618129	618124	20100N	PARTICIPANT	\N	PRESENT	0
618131	618124	11083R	PARTICIPANT	\N	PRESENT	0
618133	618124	19725B	PARTICIPANT	\N	PRESENT	1
618134	618124	19333N	PARTICIPANT	\N	PRESENT	0
618135	618124	14097Y	PARTICIPANT	\N	PRESENT	1
618137	618124	19531S	PARTICIPANT	\N	PRESENT	0
618138	618124	14073Q	PARTICIPANT	\N	PRESENT	0
618139	618124	12041X	PARTICIPANT	\N	PRESENT	0
618140	618124	19711U	PARTICIPANT	\N	PRESENT	0
618141	618124	11026G	PARTICIPANT	\N	PRESENT	0
618548	618366	19697Q	PARTICIPANT	\N	PRESENT	0
618144	618124	19441R	PARTICIPANT	\N	PRESENT	0
618145	618124	14001X	PARTICIPANT	\N	PRESENT	1
618146	618124	04057K	PARTICIPANT	\N	PRESENT	0
618147	618124	19563B	PARTICIPANT	\N	EXCUSE	0
618148	618124	14169X	PARTICIPANT	\N	PRESENT	1
618149	618124	14331P	PRESIDENT	0	PRESENT	0
618151	618124	20098N	PARTICIPANT	\N	PRESENT	0
618152	618124	04045F	PARTICIPANT	\N	PRESENT	0
618155	618124	20128B	PARTICIPANT	\N	PRESENT	1
618158	618124	19553Y	PARTICIPANT	\N	PRESENT	0
618159	618124	04070G	PARTICIPANT	\N	PRESENT	1
618160	618124	20104S	PARTICIPANT	\N	EXCUSE	0
618549	618366	11067R	PARTICIPANT	\N	PRESENT	1
618550	618366	14355X	PARTICIPANT	\N	PRESENT	1
618551	618366	19798U	PARTICIPANT	\N	PRESENT	0
618552	618366	19569H	PARTICIPANT	\N	PRESENT	0
618553	618366	11097X	PARTICIPANT	\N	PRESENT	0
618554	618366	19415P	PARTICIPANT	\N	PRESENT	0
618555	618366	18193Q	PARTICIPANT	\N	PRESENT	1
618556	618366	19703U	PARTICIPANT	\N	PRESENT	0
618557	618366	19553Y	PARTICIPANT	\N	PRESENT	1
618558	618366	14281W	PARTICIPANT	\N	PRESENT	1
618559	618366	14042U	PARTICIPANT	\N	PRESENT	0
618560	618366	14195A	PARTICIPANT	\N	PRESENT	1
618561	618366	19367Y	PARTICIPANT	\N	PRESENT	0
618562	618366	14217N	PARTICIPANT	\N	PRESENT	0
618563	618366	10006L	PRESIDENT	0	PRESENT	0
618564	618366	19683J	PARTICIPANT	\N	PRESENT	0
618565	618366	20130U	PARTICIPANT	\N	PRESENT	0
618566	618366	19713W	PARTICIPANT	\N	PRESENT	0
618567	618366	11045K	PARTICIPANT	\N	PRESENT	0
618568	618366	19301E	PARTICIPANT	\N	PRESENT	1
618569	618366	17965H	PARTICIPANT	\N	PRESENT	0
618570	618366	19691J	PARTICIPANT	\N	PRESENT	0
618571	618366	19715Y	PARTICIPANT	\N	PRESENT	0
618572	618366	19717B	PARTICIPANT	\N	PRESENT	1
618573	618366	19295A	PARTICIPANT	\N	PRESENT	0
618574	618366	19723Y	PARTICIPANT	\N	PRESENT	0
618575	618366	20066E	PARTICIPANT	\N	PRESENT	1
618576	618366	20266L	PARTICIPANT	\N	PRESENT	1
618577	618366	19657G	PARTICIPANT	\N	PRESENT	0
618578	618366	04043D	PARTICIPANT	\N	PRESENT	1
618579	618366	19760E	PARTICIPANT	\N	PRESENT	0
618581	618365	19673G	PARTICIPANT	\N	PRESENT	0
618582	618365	14147R	PARTICIPANT	\N	PRESENT	1
618583	618365	10015M	PARTICIPANT	\N	PRESENT	1
618584	618365	14223L	PARTICIPANT	\N	PRESENT	1
618585	618365	14026U	PARTICIPANT	\N	PRESENT	0
618586	618365	17779H	PARTICIPANT	\N	PRESENT	1
618587	618365	14281W	PARTICIPANT	\N	PRESENT	1
618588	618365	20110Q	PARTICIPANT	\N	PRESENT	1
618589	618365	20114U	PARTICIPANT	\N	PRESENT	1
618590	618365	14213J	PARTICIPANT	\N	PRESENT	1
618591	618365	14215L	PARTICIPANT	\N	PRESENT	0
618592	618365	20128B	PARTICIPANT	\N	PRESENT	1
618593	618365	19591F	PARTICIPANT	\N	PRESENT	1
618594	618365	11045K	PARTICIPANT	\N	PRESENT	0
618595	618365	11026G	PARTICIPANT	\N	PRESENT	0
618596	618365	19295A	PARTICIPANT	\N	PRESENT	0
618597	618365	19723Y	PARTICIPANT	\N	PRESENT	0
618598	618365	19725B	PARTICIPANT	\N	PRESENT	1
618599	618365	11056N	PARTICIPANT	\N	PRESENT	1
618600	618365	11103C	PARTICIPANT	\N	PRESENT	1
618609	618083	14026U	PARTICIPANT	\N	PRESENT	0
618625	618083	04070G	PARTICIPANT	\N	PRESENT	0
618627	618083	20084G	PARTICIPANT	\N	PRESENT	0
618628	618083	19651A	PARTICIPANT	\N	PRESENT	0
618629	618083	19621T	PARTICIPANT	\N	PRESENT	0
618631	618083	17589D	PARTICIPANT	\N	PRESENT	0
618632	618083	20134Y	PARTICIPANT	\N	PRESENT	0
618635	618083	19593H	PARTICIPANT	\N	PRESENT	0
618636	618083	14030Q	PARTICIPANT	\N	PRESENT	0
618637	618083	11012A	PARTICIPANT	\N	PRESENT	0
618638	618083	19573D	PARTICIPANT	\N	PRESENT	0
618639	618358	20074E	PARTICIPANT	\N	PRESENT	0
618640	618358	04047H	PRESIDENT	0	PRESENT	0
618641	618358	19673G	PARTICIPANT	\N	PRESENT	0
618642	618358	01028R	PARTICIPANT	\N	PRESENT	0
618643	618358	05008E	PARTICIPANT	\N	PRESENT	0
618644	618358	19447X	PARTICIPANT	\N	PRESENT	0
618645	618358	14231L	PARTICIPANT	\N	PRESENT	0
618646	618358	19954N	PARTICIPANT	\N	PRESENT	0
618647	618358	17737W	PARTICIPANT	\N	PRESENT	0
618648	618358	20108W	PARTICIPANT	\N	PRESENT	0
623690	618874	14030Q	PARTICIPANT	\N	PRESENT	0
623691	618874	19673G	PARTICIPANT	\N	PRESENT	0
623692	618874	97011G	PARTICIPANT	\N	PRESENT	0
623693	618874	11083R	PARTICIPANT	\N	PRESENT	0
623694	618874	14179A	PARTICIPANT	\N	PRESENT	0
623695	618874	20056C	PARTICIPANT	\N	PRESENT	0
623696	618874	20054A	PARTICIPANT	\N	PRESENT	0
623709	619250	14189C	PARTICIPANT	\N	PRESENT	0
623711	619250	14030Q	PRESIDENT	0	PRESENT	0
623737	619250	20118Y	PARTICIPANT	\N	PRESENT	1
623715	619250	11031D	PARTICIPANT	\N	PRESENT	0
623717	619250	14109K	PARTICIPANT	\N	PRESENT	1
623719	619250	20056C	PARTICIPANT	\N	PRESENT	1
623720	619250	20114U	PARTICIPANT	\N	PRESENT	1
623721	619250	20138D	PARTICIPANT	\N	PRESENT	1
623739	619250	20024T	PARTICIPANT	\N	PRESENT	0
623743	619250	20106U	PARTICIPANT	\N	PRESENT	1
623744	619250	19715Y	PARTICIPANT	\N	PRESENT	1
623746	619250	19057M	PARTICIPANT	\N	PRESENT	1
624210	624209	19531S	PARTICIPANT	\N	PRESENT	0
624211	624209	14253S	PARTICIPANT	\N	PRESENT	0
624213	624212	19531S	PARTICIPANT	\N	PRESENT	0
624214	624212	14253S	PARTICIPANT	\N	PRESENT	0
624216	624215	19647E	PARTICIPANT	\N	PRESENT	0
624217	624215	11070L	PARTICIPANT	\N	PRESENT	0
625769	625488	20092G	PARTICIPANT	\N	PRESENT	0
625753	625488	19760E	PARTICIPANT	\N	PRESENT	0
625754	625488	04085P	PARTICIPANT	\N	PRESENT	0
625761	625488	20110Q	PARTICIPANT	\N	PRESENT	0
625756	625488	11040E	PARTICIPANT	\N	PRESENT	0
625757	625488	11031D	PARTICIPANT	\N	PRESENT	0
625758	625488	19695N	PARTICIPANT	\N	PRESENT	0
625759	625488	19565D	PARTICIPANT	\N	PRESENT	0
625760	625488	20102Q	PARTICIPANT	\N	PRESENT	0
625762	625488	20036X	PARTICIPANT	\N	PRESENT	0
625763	625488	20142Y	PARTICIPANT	\N	PRESENT	0
625764	625488	08045X	PARTICIPANT	\N	PRESENT	0
625765	625488	20144B	PARTICIPANT	\N	PRESENT	0
625767	625488	08073C	PARTICIPANT	\N	PRESENT	0
625768	625488	95063L	PARTICIPANT	\N	PRESENT	0
625770	625488	20266L	PARTICIPANT	\N	PRESENT	0
625771	625488	19543W	PARTICIPANT	\N	PRESENT	0
625772	624079	19707Y	PARTICIPANT	\N	PRESENT	1
625773	624079	19575F	PARTICIPANT	\N	PRESENT	0
625774	624079	19747H	PARTICIPANT	\N	PRESENT	0
625775	624079	19383Y	PARTICIPANT	\N	PRESENT	0
625776	624079	20060X	PARTICIPANT	\N	PRESENT	1
625777	624079	14038Y	PARTICIPANT	\N	PRESENT	0
625778	624079	08028W	PARTICIPANT	\N	PRESENT	0
625779	624079	19467C	PARTICIPANT	\N	PRESENT	0
625780	624079	14187A	PARTICIPANT	\N	PRESENT	0
625781	624079	19511N	PARTICIPANT	\N	PRESENT	0
625782	624079	08015R	PARTICIPANT	\N	PRESENT	0
625783	624079	01043Q	PARTICIPANT	\N	PRESENT	0
625784	624079	20028X	PARTICIPANT	\N	PRESENT	0
625785	624079	20018V	PARTICIPANT	\N	PRESENT	0
625786	624079	14257W	PARTICIPANT	\N	PRESENT	0
625787	624079	19768N	PARTICIPANT	\N	PRESENT	0
625788	624079	11090Q	PARTICIPANT	\N	PRESENT	0
625789	625488	17737W	PARTICIPANT	\N	PRESENT	0
625790	624079	19705W	PARTICIPANT	\N	PRESENT	1
625791	624079	20092G	PARTICIPANT	\N	PRESENT	0
625793	625488	19663E	PARTICIPANT	\N	PRESENT	0
625794	625488	11064N	PARTICIPANT	\N	PRESENT	0
625795	625488	14251Q	PARTICIPANT	\N	PRESENT	0
625796	625263	14105F	PARTICIPANT	\N	PRESENT	0
625797	625488	14221J	PARTICIPANT	\N	PRESENT	0
625798	625263	14255U	PARTICIPANT	\N	PRESENT	0
625799	625488	19637C	PARTICIPANT	\N	PRESENT	0
625800	625263	11027H	PARTICIPANT	\N	PRESENT	0
625806	625263	19443T	PARTICIPANT	\N	PRESENT	1
625808	625263	01058X	PARTICIPANT	\N	PRESENT	0
625803	625263	19347U	PARTICIPANT	\N	PRESENT	0
625804	625488	19387D	PARTICIPANT	\N	PRESENT	0
625807	625488	20128B	PARTICIPANT	\N	PRESENT	0
625809	625263	20064C	PARTICIPANT	\N	PRESENT	1
625810	625263	11066Q	PARTICIPANT	\N	PRESENT	0
625814	625488	19367Y	PARTICIPANT	\N	PRESENT	0
625822	625263	19707Y	PARTICIPANT	\N	PRESENT	1
625824	625263	19575F	PARTICIPANT	\N	PRESENT	0
625825	625263	20078J	PARTICIPANT	\N	PRESENT	0
625826	625263	19747H	PARTICIPANT	\N	PRESENT	0
625827	625263	19383Y	PARTICIPANT	\N	PRESENT	0
625828	625263	20060X	PARTICIPANT	\N	PRESENT	0
625829	625263	14038Y	PARTICIPANT	\N	PRESENT	0
625830	625263	19467C	PARTICIPANT	\N	PRESENT	0
625831	625488	20042V	PARTICIPANT	\N	PRESENT	0
625832	625263	14187A	PARTICIPANT	\N	PRESENT	0
625833	625488	14073Q	PARTICIPANT	\N	PRESENT	0
625834	625263	20174H	PARTICIPANT	\N	PRESENT	0
625835	625263	01043Q	PARTICIPANT	\N	PRESENT	0
625836	625263	14205J	PARTICIPANT	\N	PRESENT	0
625837	625488	19507S	PARTICIPANT	\N	PRESENT	0
625838	625488	14219Q	PARTICIPANT	\N	PRESENT	0
625839	625263	14257W	PARTICIPANT	\N	PRESENT	0
625840	625263	19768N	PARTICIPANT	\N	PRESENT	0
625841	625263	11090Q	PARTICIPANT	\N	PRESENT	0
625842	625263	19705W	PARTICIPANT	\N	PRESENT	1
625843	625263	20092G	PARTICIPANT	\N	PRESENT	0
625844	625488	20248J	PARTICIPANT	\N	PRESENT	0
625845	625488	14225N	PARTICIPANT	\N	PRESENT	0
625853	624173	19667J	PRESIDENT	0	PRESENT	0
625851	625488	14123H	PARTICIPANT	\N	PRESENT	0
625852	625488	20048C	PARTICIPANT	\N	PRESENT	0
625854	624173	04085P	PARTICIPANT	\N	PRESENT	0
625855	624173	19671E	PARTICIPANT	\N	EXCUSE	0
626110	624154	11045K	PARTICIPANT	\N	PRESENT	0
626111	624342	19593H	PARTICIPANT	\N	PRESENT	0
626112	624342	19643A	PARTICIPANT	\N	PRESENT	0
626113	624342	19699S	PARTICIPANT	\N	PRESENT	0
626114	624342	20134Y	PARTICIPANT	\N	PRESENT	1
626115	624342	19611R	PARTICIPANT	\N	PRESENT	0
626116	624342	01060R	PARTICIPANT	\N	PRESENT	0
626117	624342	20048C	PARTICIPANT	\N	PRESENT	0
626118	624342	20152B	PARTICIPANT	\N	PRESENT	0
626119	624342	14229S	PARTICIPANT	\N	PRESENT	0
626120	624342	14030Q	PARTICIPANT	\N	PRESENT	0
626121	624342	20098N	PARTICIPANT	\N	PRESENT	0
626122	624342	20056C	PARTICIPANT	\N	PRESENT	0
626123	624342	20180F	PARTICIPANT	\N	PRESENT	0
626124	624342	19573D	PARTICIPANT	\N	PRESENT	0
626125	624342	20264J	PARTICIPANT	\N	PRESENT	0
626126	624342	19057M	PARTICIPANT	\N	PRESENT	0
626127	624342	14109K	PARTICIPANT	\N	PRESENT	0
626128	624342	14123H	PARTICIPANT	\N	PRESENT	0
626129	624342	11104D	PARTICIPANT	\N	PRESENT	0
626130	624342	20124W	PARTICIPANT	\N	PRESENT	0
626131	624342	19758L	PARTICIPANT	\N	PRESENT	0
626132	624342	19621T	PARTICIPANT	\N	PRESENT	0
626133	624342	20084G	PARTICIPANT	\N	PRESENT	0
626134	624154	19679N	PARTICIPANT	\N	PRESENT	0
626135	624154	14217N	PARTICIPANT	\N	PRESENT	0
626169	624154	01058X	PARTICIPANT	\N	PRESENT	0
626137	624154	19687N	PARTICIPANT	\N	PRESENT	0
626138	624154	20248J	PARTICIPANT	\N	PRESENT	0
626139	624154	19717B	PARTICIPANT	\N	PRESENT	0
626140	624154	08045X	PARTICIPANT	\N	PRESENT	0
626141	624154	19301E	PARTICIPANT	\N	PRESENT	0
626170	624154	20072C	PARTICIPANT	\N	PRESENT	0
626150	624154	14215L	PARTICIPANT	\N	PRESENT	0
626155	626152	19663E	PARTICIPANT	\N	PRESENT	0
626156	624173	20090E	PARTICIPANT	\N	PRESENT	0
626157	624173	20038A	PARTICIPANT	\N	PRESENT	0
626158	624173	07004J	PARTICIPANT	\N	PRESENT	1
626159	624173	14249W	PARTICIPANT	\N	PRESENT	0
626160	626152	19553Y	PARTICIPANT	\N	PRESENT	0
626161	626152	19723Y	PARTICIPANT	\N	PRESENT	0
626162	626152	17965H	PARTICIPANT	\N	PRESENT	0
626171	624154	14033T	PARTICIPANT	\N	PRESENT	0
626164	624154	17737W	PARTICIPANT	\N	PRESENT	0
626165	624154	17589D	PARTICIPANT	\N	PRESENT	0
626166	624154	20100N	PARTICIPANT	\N	PRESENT	0
626167	624154	19691J	PARTICIPANT	\N	PRESENT	0
626168	624154	20082E	PARTICIPANT	\N	PRESENT	0
626172	624154	14133K	PARTICIPANT	\N	PRESENT	0
626173	624154	20130U	PARTICIPANT	\N	PRESENT	0
626174	624154	19447X	PARTICIPANT	\N	PRESENT	0
626175	624154	20108W	PARTICIPANT	\N	PRESENT	0
626176	624154	19565D	PARTICIPANT	\N	PRESENT	0
626177	624154	19651A	PARTICIPANT	\N	PRESENT	0
626178	624154	19507S	PARTICIPANT	\N	PRESENT	0
599321	597713	08018U	PARTICIPANT	\N	EXCUSE	0
599378	599377	11070L	PARTICIPANT	\N	PRESENT	0
599379	599377	19647E	PARTICIPANT	\N	PRESENT	0
599381	599380	11012A	PARTICIPANT	\N	PRESENT	0
599382	599380	14083S	PARTICIPANT	\N	PRESENT	0
599384	599383	11070L	PARTICIPANT	\N	PRESENT	0
599385	599383	19647E	PARTICIPANT	\N	PRESENT	0
599424	599423	11012A	PARTICIPANT	\N	PRESENT	0
599425	599423	14083S	PARTICIPANT	\N	PRESENT	0
599427	599426	14083S	PARTICIPANT	\N	PRESENT	0
599428	599426	11012A	PARTICIPANT	\N	PRESENT	0
599431	599430	11070L	PARTICIPANT	\N	PRESENT	0
599432	599430	19647E	PARTICIPANT	\N	PRESENT	0
599433	599429	11070L	PARTICIPANT	\N	PRESENT	0
599434	599429	19647E	PARTICIPANT	\N	PRESENT	0
600605	598078	11012A	PARTICIPANT	\N	PRESENT	0
600606	598078	12041X	PARTICIPANT	\N	PRESENT	0
600705	599364	19673G	PARTICIPANT	\N	PRESENT	0
600706	599364	11033F	PARTICIPANT	\N	PRESENT	0
600720	599364	19649G	PARTICIPANT	\N	PRESENT	0
600721	599364	11026G	PARTICIPANT	\N	PRESENT	0
600722	599364	20108W	PARTICIPANT	\N	PRESENT	0
600723	599364	20110Q	PARTICIPANT	\N	PRESENT	0
600724	599364	14179A	PARTICIPANT	\N	PRESENT	0
600725	599364	04047H	PRESIDENT	0	PRESENT	0
600726	599364	04085P	PARTICIPANT	\N	PRESENT	0
600727	599364	05008E	PARTICIPANT	\N	PRESENT	0
600728	598084	11031D	PARTICIPANT	\N	PRESENT	0
600729	598084	11056N	PARTICIPANT	\N	PRESENT	0
600730	598084	08045X	PARTICIPANT	\N	PRESENT	0
600731	598084	20130U	PARTICIPANT	\N	PRESENT	0
600732	598084	14217N	PARTICIPANT	\N	PRESENT	0
600733	598084	04057K	PARTICIPANT	\N	PRESENT	0
600734	598084	14207L	PARTICIPANT	\N	PRESENT	0
600735	598084	19583F	PARTICIPANT	\N	PRESENT	0
600736	598084	17589D	PARTICIPANT	\N	PRESENT	0
600689	598084	19719D	PARTICIPANT	\N	PRESENT	0
600696	599364	19729F	PARTICIPANT	\N	EXCUSE	0
600697	599364	08018U	PARTICIPANT	\N	EXCUSE	0
600737	598084	14195A	PARTICIPANT	\N	PRESENT	0
600738	598084	19585H	PARTICIPANT	\N	PRESENT	0
600739	598084	11012A	PARTICIPANT	\N	PRESENT	0
600740	598084	19399H	PARTICIPANT	\N	PRESENT	0
600741	598084	19467C	PARTICIPANT	\N	PRESENT	0
600742	598084	19723Y	PARTICIPANT	\N	PRESENT	0
600743	598084	14026U	PARTICIPANT	\N	PRESENT	0
600744	598084	19581D	PARTICIPANT	\N	PRESENT	0
600745	598084	20248J	PARTICIPANT	\N	PRESENT	0
600746	598084	20122U	PARTICIPANT	\N	PRESENT	0
600749	598084	11067R	PARTICIPANT	\N	PRESENT	0
600752	598084	19593H	PARTICIPANT	\N	PRESENT	0
600753	598084	19591F	PARTICIPANT	\N	PRESENT	0
600771	598084	11065P	PARTICIPANT	\N	PRESENT	0
600772	598084	19713W	PARTICIPANT	\N	PRESENT	0
600773	598084	14042U	PARTICIPANT	\N	PRESENT	0
600774	598084	19479G	PARTICIPANT	\N	PRESENT	0
600775	598084	14251Q	PARTICIPANT	\N	PRESENT	0
600776	598084	19551W	PARTICIPANT	\N	PRESENT	0
600777	598084	07004J	PARTICIPANT	\N	PRESENT	0
600778	598084	08010L	PARTICIPANT	\N	PRESENT	0
600780	598084	19543W	PARTICIPANT	\N	PRESENT	0
600782	599364	19543W	PARTICIPANT	\N	PRESENT	0
600783	599364	01028R	PARTICIPANT	\N	PRESENT	0
600784	599364	14215L	PARTICIPANT	\N	PRESENT	0
601008	601007	20032T	PARTICIPANT	\N	PRESENT	0
601009	601007	14038Y	PARTICIPANT	\N	PRESENT	0
601010	601007	19335Q	PARTICIPANT	\N	PRESENT	0
601011	601007	20128B	PARTICIPANT	\N	PRESENT	0
601012	601007	20056C	PARTICIPANT	\N	PRESENT	0
601013	601007	20140W	PARTICIPANT	\N	PRESENT	0
601014	601007	19387D	PARTICIPANT	\N	PRESENT	0
601015	601007	20042V	PARTICIPANT	\N	PRESENT	0
601016	601007	19723Y	PARTICIPANT	\N	PRESENT	0
601017	601007	19585H	PARTICIPANT	\N	PRESENT	0
601018	601007	14026U	PARTICIPANT	\N	PRESENT	0
601019	601007	20060X	PARTICIPANT	\N	PRESENT	0
601020	601007	19599P	PARTICIPANT	\N	PRESENT	0
601021	601007	19701S	PARTICIPANT	\N	PRESENT	0
601022	601007	20134Y	PARTICIPANT	\N	PRESENT	0
601064	601063	11109J	PARTICIPANT	\N	EXCUSE	0
601065	601063	14030Q	PARTICIPANT	\N	PRESENT	0
601066	601063	20152B	PARTICIPANT	\N	PRESENT	0
601067	601063	19643A	PARTICIPANT	\N	PRESENT	0
601068	601063	19621T	PARTICIPANT	\N	PRESENT	0
601069	601063	19758L	PARTICIPANT	\N	PRESENT	0
601070	601063	19057M	PARTICIPANT	\N	PRESENT	0
601071	601063	20264J	PARTICIPANT	\N	EXCUSE	0
601072	601063	19719D	PARTICIPANT	\N	PRESENT	0
601073	601063	20134Y	PARTICIPANT	\N	PRESENT	0
601074	601063	20124W	PARTICIPANT	\N	PRESENT	0
601075	601063	20132W	PARTICIPANT	\N	PRESENT	0
601076	601063	20180F	PARTICIPANT	\N	PRESENT	0
601077	601063	14123H	PARTICIPANT	\N	PRESENT	0
601078	601063	20048C	PARTICIPANT	\N	PRESENT	0
601079	601063	19399H	PARTICIPANT	\N	PRESENT	0
601080	601063	20056C	PARTICIPANT	\N	PRESENT	0
601081	601063	14073Q	PARTICIPANT	\N	EXCUSE	0
601082	601063	19611R	PRESIDENT	0	PRESENT	0
601083	601063	19735D	PARTICIPANT	\N	EXCUSE	0
601084	601063	20052X	PARTICIPANT	\N	PRESENT	0
601085	601063	11104D	PARTICIPANT	\N	PRESENT	0
601086	601063	19593H	PARTICIPANT	\N	PRESENT	0
601087	601063	19573D	PARTICIPANT	\N	PRESENT	0
601088	601063	19533U	PARTICIPANT	\N	PRESENT	0
601089	601063	14229S	PARTICIPANT	\N	PRESENT	0
601090	601063	20026V	PARTICIPANT	\N	PRESENT	0
601091	601063	20142Y	PARTICIPANT	\N	PRESENT	0
606425	601489	20034V	PARTICIPANT	\N	EXCUSE	0
606430	606429	20130U	PARTICIPANT	\N	PRESENT	0
606431	606429	19679N	PARTICIPANT	\N	PRESENT	0
606514	606436	14219Q	PARTICIPANT	\N	EXCUSE	0
606515	606436	14059S	PRESIDENT	0	PRESENT	0
610812	610811	05008E	PARTICIPANT	\N	PRESENT	0
610813	610811	11053K	PARTICIPANT	\N	PRESENT	0
610814	610811	01028R	PARTICIPANT	\N	PRESENT	0
610859	610668	19729F	PARTICIPANT	\N	EXCUSE	0
610916	610669	11083R	PARTICIPANT	\N	PRESENT	0
610917	610669	14097Y	PARTICIPANT	\N	PRESENT	0
610918	610669	04057K	PARTICIPANT	\N	PRESENT	0
610919	610669	14331P	PARTICIPANT	\N	PRESENT	0
610920	610669	14237S	PARTICIPANT	\N	PRESENT	0
625097	624665	19413M	PARTICIPANT	\N	EXCUSE	0
625098	624665	14207L	PARTICIPANT	\N	EXCUSE	0
625112	624667	14207L	PARTICIPANT	\N	EXCUSE	0
625113	624667	19413M	PARTICIPANT	\N	EXCUSE	0
625181	625180	19575F	PARTICIPANT	\N	PRESENT	0
625182	625180	17367Q	PARTICIPANT	\N	PRESENT	0
626146	626143	14169X	PARTICIPANT	\N	PRESENT	0
625184	625180	19719D	PARTICIPANT	\N	PRESENT	0
625185	625180	14053L	PARTICIPANT	\N	PRESENT	0
625186	625180	20038A	PARTICIPANT	\N	PRESENT	0
625187	625180	19826F	PARTICIPANT	\N	PRESENT	0
625188	625180	14071N	PARTICIPANT	\N	PRESENT	0
625189	625180	19798U	PARTICIPANT	\N	PRESENT	0
625190	625180	20084G	PARTICIPANT	\N	PRESENT	0
626144	626143	20118Y	PARTICIPANT	\N	PRESENT	0
626145	626143	08009T	PARTICIPANT	\N	PRESENT	0
626147	626143	11026G	PARTICIPANT	\N	PRESENT	0
626148	626143	19739H	PARTICIPANT	\N	PRESENT	0
626149	626143	19713W	PARTICIPANT	\N	PRESENT	0
626547	624273	20060X	PARTICIPANT	\N	PRESENT	0
626548	624273	20054A	PARTICIPANT	\N	PRESENT	0
626549	624273	14031R	PARTICIPANT	\N	PRESENT	0
626550	624273	19762G	PARTICIPANT	\N	PRESENT	0
626551	624273	19467C	PARTICIPANT	\N	PRESENT	0
626552	624273	20040T	PARTICIPANT	\N	PRESENT	0
626553	624273	19575F	PARTICIPANT	\N	PRESENT	0
626554	624273	20126Y	PARTICIPANT	\N	PRESENT	0
626555	624273	19760E	PARTICIPANT	\N	PRESENT	0
626556	624273	08015R	PARTICIPANT	\N	PRESENT	0
626557	624273	20082E	PARTICIPANT	\N	PRESENT	0
626558	624273	16685X	PARTICIPANT	\N	PRESENT	0
626559	624273	19671E	PARTICIPANT	\N	PRESENT	0
626561	626560	19533U	PARTICIPANT	\N	PRESENT	0
626545	624273	19515S	PRESIDENT	0	PRESENT	0
626546	624273	14083S	PARTICIPANT	\N	PRESENT	0
626562	626560	14207L	PARTICIPANT	\N	PRESENT	0
626563	626560	19599P	PARTICIPANT	\N	PRESENT	0
626566	626560	19820Y	PARTICIPANT	\N	PRESENT	1
626567	624159	08073C	PARTICIPANT	\N	PRESENT	0
626568	624159	19527W	PARTICIPANT	\N	PRESENT	0
626569	624159	14229S	PARTICIPANT	\N	PRESENT	0
626570	624159	19758L	PARTICIPANT	\N	PRESENT	0
626571	624159	19611R	PARTICIPANT	\N	PRESENT	0
626572	624159	19573D	PARTICIPANT	\N	PRESENT	0
626573	624159	19673G	PARTICIPANT	\N	PRESENT	0
626574	624159	19593H	PARTICIPANT	\N	PRESENT	0
626575	624159	20134Y	PARTICIPANT	\N	PRESENT	0
626576	624159	19057M	PARTICIPANT	\N	PRESENT	0
626577	624159	04057K	PARTICIPANT	\N	PRESENT	0
626578	624159	20248J	PARTICIPANT	\N	PRESENT	0
626579	624159	19691J	PARTICIPANT	\N	PRESENT	0
626580	624175	20038A	PARTICIPANT	\N	PRESENT	0
626581	624175	07004J	PARTICIPANT	\N	PRESENT	0
626582	624175	19667J	PRESIDENT	0	PRESENT	0
626583	624175	04085P	PARTICIPANT	\N	PRESENT	0
626584	624175	19531S	PARTICIPANT	\N	PRESENT	0
626585	624159	20132W	PARTICIPANT	\N	PRESENT	0
626586	624159	20106U	PARTICIPANT	\N	PRESENT	0
626587	624159	14030Q	PARTICIPANT	\N	PRESENT	0
626588	624159	19643A	PARTICIPANT	\N	PRESENT	0
626589	624159	20152B	PARTICIPANT	\N	PRESENT	0
626590	624159	20124W	PARTICIPANT	\N	PRESENT	0
626591	624159	20026V	PARTICIPANT	\N	PRESENT	0
626600	623940	19467C	PARTICIPANT	\N	PRESENT	0
626593	624159	20180F	PARTICIPANT	\N	PRESENT	0
626594	624159	19399H	PARTICIPANT	\N	PRESENT	0
626595	624159	20142Y	PARTICIPANT	\N	PRESENT	0
626596	623940	19713W	PARTICIPANT	\N	PRESENT	1
626597	624159	19621T	PARTICIPANT	\N	PRESENT	0
626598	623940	19683J	PRESIDENT	0	PRESENT	0
626599	624159	20024T	PARTICIPANT	\N	PRESENT	0
626601	623940	19735D	PARTICIPANT	\N	PRESENT	0
626602	623940	10006L	PARTICIPANT	\N	PRESENT	0
626603	624159	14133K	PARTICIPANT	\N	PRESENT	0
626604	623940	19723Y	PARTICIPANT	\N	PRESENT	1
626605	623940	20062A	PARTICIPANT	\N	PRESENT	1
626606	623940	19301E	PARTICIPANT	\N	PRESENT	1
626607	624159	19565D	PARTICIPANT	\N	PRESENT	0
626608	624159	14031R	PARTICIPANT	\N	PRESENT	0
626609	624159	20102Q	PARTICIPANT	\N	PRESENT	0
626610	624159	19447X	PARTICIPANT	\N	PRESENT	0
626611	624159	14259Y	PARTICIPANT	\N	PRESENT	0
626612	624159	19503N	PARTICIPANT	\N	PRESENT	0
626613	624159	20056C	PARTICIPANT	\N	PRESENT	0
626614	624135	19717B	PRESIDENT	0	PRESENT	0
626615	624159	20098N	PARTICIPANT	\N	PRESENT	0
626616	624135	14053L	PARTICIPANT	\N	PRESENT	0
626617	624135	18083K	PARTICIPANT	\N	PRESENT	0
626618	624135	17023S	PARTICIPANT	\N	PRESENT	0
626619	624135	20034V	PARTICIPANT	\N	PRESENT	1
626620	624135	19715Y	PARTICIPANT	\N	PRESENT	1
626621	624135	14097Y	PARTICIPANT	\N	PRESENT	1
626622	624135	14147R	PARTICIPANT	\N	PRESENT	1
626623	624135	20148F	PARTICIPANT	\N	PRESENT	1
626624	624135	20146D	PARTICIPANT	\N	PRESENT	0
626625	624135	19319Q	PARTICIPANT	\N	PRESENT	0
626626	624135	19447X	PARTICIPANT	\N	PRESENT	1
626627	624135	14083S	PARTICIPANT	\N	PRESENT	0
626628	624159	14053L	PARTICIPANT	\N	PRESENT	0
626629	624135	20104S	PARTICIPANT	\N	PRESENT	0
626630	624135	04043D	PARTICIPANT	\N	PRESENT	0
626631	624135	19503N	PARTICIPANT	\N	PRESENT	0
626632	624159	19693L	PARTICIPANT	\N	PRESENT	0
626633	624135	14219Q	PARTICIPANT	\N	EXCUSE	0
626634	623940	20130U	PARTICIPANT	\N	PRESENT	1
626635	624159	19739H	PARTICIPANT	\N	PRESENT	0
626636	624175	19711U	PARTICIPANT	\N	PRESENT	0
626637	624159	14021P	PARTICIPANT	\N	PRESENT	0
626638	624159	20264J	PARTICIPANT	\N	PRESENT	0
626639	624159	19701S	PARTICIPANT	\N	PRESENT	0
626640	624159	14179A	PARTICIPANT	\N	PRESENT	0
626641	624159	19441R	PARTICIPANT	\N	PRESENT	0
626642	624159	20104S	PARTICIPANT	\N	PRESENT	0
626643	624194	19533U	PRESIDENT	0	PRESENT	0
626644	624159	20096L	PARTICIPANT	\N	PRESENT	0
626645	624194	20042V	PARTICIPANT	\N	PRESENT	1
626646	624159	20018V	PARTICIPANT	\N	PRESENT	0
626647	624159	20052X	PARTICIPANT	\N	PRESENT	0
626648	624194	14207L	PARTICIPANT	\N	PRESENT	0
626649	624194	19599P	PRESIDENT	1	PRESENT	0
626650	624194	20132W	PARTICIPANT	\N	PRESENT	1
626653	624159	20082E	PARTICIPANT	\N	PRESENT	0
626654	624159	20058E	PARTICIPANT	\N	PRESENT	0
626655	623940	11031D	PARTICIPANT	\N	EXCUSE	0
626656	616410	14189C	PARTICIPANT	\N	EXCUSE	0
626657	616410	20024T	PARTICIPANT	\N	PRESENT	0
626658	616410	20138D	PARTICIPANT	\N	PRESENT	1
626659	616410	14030Q	PRESIDENT	0	PRESENT	0
626660	616410	20114U	PARTICIPANT	\N	PRESENT	1
626661	616410	11031D	PARTICIPANT	\N	PRESENT	0
626662	616410	19693L	PARTICIPANT	\N	PRESENT	0
626663	616410	19599P	PARTICIPANT	\N	PRESENT	0
626664	616410	04035D	PARTICIPANT	\N	PRESENT	1
626665	616410	20106U	PARTICIPANT	\N	PRESENT	1
626666	616410	14179A	PARTICIPANT	\N	PRESENT	1
626667	616410	14109K	PARTICIPANT	\N	PRESENT	1
626668	616410	19866P	PARTICIPANT	\N	EXCUSE	0
626669	616410	20130U	PARTICIPANT	\N	EXCUSE	0
626670	616410	11045K	PARTICIPANT	\N	PRESENT	1
626671	616410	20098N	PARTICIPANT	\N	EXCUSE	0
626672	616410	19527W	PARTICIPANT	\N	PRESENT	1
626673	616410	19749K	PARTICIPANT	\N	PRESENT	0
626674	624159	20108W	PARTICIPANT	\N	PRESENT	0
626675	624159	08010L	PARTICIPANT	\N	PRESENT	0
626676	624159	20114U	PARTICIPANT	\N	PRESENT	0
626677	624159	14215L	PARTICIPANT	\N	PRESENT	0
626678	624194	17023S	PARTICIPANT	\N	PRESENT	0
626679	624174	04085P	PARTICIPANT	\N	PRESENT	0
626680	624174	19667J	PARTICIPANT	\N	PRESENT	0
626681	624174	20038A	PARTICIPANT	\N	PRESENT	0
626682	624174	07004J	PARTICIPANT	\N	PRESENT	1
626683	624174	19531S	PARTICIPANT	\N	PRESENT	1
626684	624174	19711U	PARTICIPANT	\N	PRESENT	0
626685	624159	14083S	PARTICIPANT	\N	PRESENT	0
626686	624159	19711U	PARTICIPANT	\N	PRESENT	0
626687	624159	19667J	PARTICIPANT	\N	PRESENT	0
626688	624159	20094J	PARTICIPANT	\N	PRESENT	0
626690	626689	20094J	PARTICIPANT	\N	PRESENT	0
626691	624159	14069U	PARTICIPANT	\N	PRESENT	0
613366	608712	19631V	PARTICIPANT	\N	PRESENT	1
613500	613306	20108W	PARTICIPANT	\N	PRESENT	0
613501	613306	19954N	PARTICIPANT	\N	PRESENT	0
613502	613306	19415P	PARTICIPANT	\N	PRESENT	0
613503	613306	19711U	PARTICIPANT	\N	PRESENT	0
613504	613306	11048N	PARTICIPANT	\N	PRESENT	0
613505	613306	14179A	PARTICIPANT	\N	PRESENT	0
613506	613306	14109K	PARTICIPANT	\N	PRESENT	0
613507	613306	19691J	PARTICIPANT	\N	PRESENT	0
613508	613306	19479G	PARTICIPANT	\N	PRESENT	0
613509	613306	19683J	PARTICIPANT	\N	PRESENT	0
613510	613306	14207L	PARTICIPANT	\N	PRESENT	0
613511	613306	99004R	PARTICIPANT	\N	PRESENT	0
613512	613306	19657G	PARTICIPANT	\N	PRESENT	0
613513	613306	19447X	PARTICIPANT	\N	PRESENT	0
613514	613306	14205J	PARTICIPANT	\N	PRESENT	0
613515	613306	01057W	PARTICIPANT	\N	PRESENT	0
613516	613306	20116W	PARTICIPANT	\N	PRESENT	0
613517	613306	20150Y	PARTICIPANT	\N	PRESENT	0
613518	613306	11045K	PARTICIPANT	\N	PRESENT	0
613519	613306	20086J	PARTICIPANT	\N	PRESENT	0
613526	613306	11067R	PARTICIPANT	\N	PRESENT	0
613527	613306	19503N	PARTICIPANT	\N	PRESENT	0
613528	613306	19647E	PARTICIPANT	\N	PRESENT	0
613529	613306	11074Q	PARTICIPANT	\N	PRESENT	0
613530	613306	19687N	PARTICIPANT	\N	PRESENT	0
613531	613306	20050V	PARTICIPANT	\N	PRESENT	0
613532	613306	12028B	PARTICIPANT	\N	PRESENT	0
613533	613306	20100N	PARTICIPANT	\N	PRESENT	0
613534	613306	20132W	PARTICIPANT	\N	PRESENT	0
613535	613306	01043Q	PARTICIPANT	\N	PRESENT	0
613537	613306	19739H	PARTICIPANT	\N	PRESENT	0
613538	613306	19741B	PARTICIPANT	\N	PRESENT	0
613539	613306	07029T	PARTICIPANT	\N	PRESENT	0
613542	613306	20090E	PARTICIPANT	\N	PRESENT	0
613546	613306	14327T	PARTICIPANT	\N	PRESENT	0
613547	613306	19693L	PARTICIPANT	\N	PRESENT	0
613548	613306	20044X	PARTICIPANT	\N	PRESENT	0
613549	613306	14219Q	PARTICIPANT	\N	PRESENT	0
613550	613306	08011M	PARTICIPANT	\N	PRESENT	0
613551	613306	19689Q	PARTICIPANT	\N	PRESENT	0
613552	613306	20056C	PARTICIPANT	\N	PRESENT	0
613553	613306	19525U	PARTICIPANT	\N	PRESENT	0
613554	613306	14189C	PARTICIPANT	\N	PRESENT	0
613555	613306	20080C	PARTICIPANT	\N	PRESENT	0
613556	613306	14217N	PARTICIPANT	\N	PRESENT	0
613557	613306	19599P	PARTICIPANT	\N	PRESENT	0
613558	613306	20252E	PARTICIPANT	\N	PRESENT	0
613559	613306	19820Y	PARTICIPANT	\N	PRESENT	0
613560	613306	14111D	PARTICIPANT	\N	PRESENT	0
613561	613306	18193Q	PARTICIPANT	\N	PRESENT	0
613562	613306	20138D	PARTICIPANT	\N	PRESENT	0
613563	613306	08028W	PARTICIPANT	\N	PRESENT	0
613564	613306	20078J	PARTICIPANT	\N	PRESENT	0
613565	613306	14267Y	PARTICIPANT	\N	PRESENT	0
613566	613306	19489J	PARTICIPANT	\N	PRESENT	0
613567	613306	14229S	PARTICIPANT	\N	PRESENT	0
613568	613306	14225N	PARTICIPANT	\N	PRESENT	0
613569	613306	20084G	PARTICIPANT	\N	PRESENT	0
613570	613306	20134Y	PARTICIPANT	\N	PRESENT	0
613571	613306	08045X	PARTICIPANT	\N	PRESENT	0
613572	613306	20024T	PARTICIPANT	\N	PRESENT	0
613573	613306	14030Q	PARTICIPANT	\N	PRESENT	0
613574	613306	20286Q	PARTICIPANT	\N	PRESENT	0
613575	613306	20180F	PARTICIPANT	\N	PRESENT	0
613576	613306	19745F	PARTICIPANT	\N	PRESENT	0
613577	613306	20048C	PARTICIPANT	\N	PRESENT	0
613578	613306	14121F	PARTICIPANT	\N	PRESENT	0
613579	613306	20076G	PARTICIPANT	\N	PRESENT	0
613580	613306	19782L	PARTICIPANT	\N	PRESENT	0
613581	613306	20130U	PARTICIPANT	\N	PRESENT	0
613582	613306	19798U	PARTICIPANT	\N	PRESENT	0
613583	613306	14147R	PARTICIPANT	\N	PRESENT	0
613584	613306	19713W	PARTICIPANT	\N	PRESENT	0
613585	613306	19611R	PARTICIPANT	\N	PRESENT	0
613586	613306	11053K	PARTICIPANT	\N	PRESENT	0
613587	613306	20032T	PARTICIPANT	\N	PRESENT	0
613588	613306	20064C	PARTICIPANT	\N	PRESENT	0
613589	613306	19569H	PARTICIPANT	\N	PRESENT	0
613590	613306	04071H	PARTICIPANT	\N	PRESENT	0
613591	613306	19543W	PARTICIPANT	\N	PRESENT	0
613592	613306	14089Y	PARTICIPANT	\N	PRESENT	0
613593	613306	19762G	PARTICIPANT	\N	PRESENT	0
613594	613306	19533U	PARTICIPANT	\N	PRESENT	0
613595	613306	14213J	PARTICIPANT	\N	PRESENT	0
613596	613306	14053L	PARTICIPANT	\N	PRESENT	0
613597	613306	20062A	PARTICIPANT	\N	PRESENT	0
613598	613306	19507S	PARTICIPANT	\N	PRESENT	0
613599	613306	18083K	PARTICIPANT	\N	PRESENT	0
613600	613306	19703U	PARTICIPANT	\N	PRESENT	0
613601	613306	19387D	PARTICIPANT	\N	PRESENT	0
613602	613306	20098N	PARTICIPANT	\N	PRESENT	0
613603	613306	20082E	PARTICIPANT	\N	PRESENT	0
613604	613306	19467C	PARTICIPANT	\N	PRESENT	0
613605	613306	01028R	PARTICIPANT	\N	PRESENT	0
613606	613306	14253S	PARTICIPANT	\N	PRESENT	0
613607	613306	08034U	PARTICIPANT	\N	PRESENT	0
613608	613306	14069U	PARTICIPANT	\N	PRESENT	0
613609	613306	19715Y	PARTICIPANT	\N	PRESENT	0
613610	613306	20060X	PARTICIPANT	\N	PRESENT	0
613611	613306	20088L	PARTICIPANT	\N	PRESENT	0
613612	613306	14257W	PARTICIPANT	\N	PRESENT	0
613613	613306	14133K	PARTICIPANT	\N	PRESENT	0
613614	613306	14059S	PARTICIPANT	\N	PRESENT	0
613615	613306	20072C	PARTICIPANT	\N	PRESENT	0
613616	613306	19333N	PARTICIPANT	\N	PRESENT	0
613617	613306	20030R	PARTICIPANT	\N	PRESENT	0
613620	613306	14251Q	PARTICIPANT	\N	PRESENT	0
613624	613306	14083S	PARTICIPANT	\N	PRESENT	0
613626	613306	19367Y	PARTICIPANT	\N	PRESENT	0
613627	613306	19747H	PARTICIPANT	\N	PRESENT	0
613628	613306	20026V	PARTICIPANT	\N	PRESENT	0
613629	613306	20114U	PARTICIPANT	\N	PRESENT	0
613630	613306	19826F	PARTICIPANT	\N	PRESENT	0
613631	613306	17779H	PARTICIPANT	\N	PRESENT	0
613632	613306	20136B	PARTICIPANT	\N	PRESENT	0
613633	613306	19679N	PARTICIPANT	\N	PRESENT	0
613634	613306	11012A	PARTICIPANT	\N	PRESENT	0
613635	613306	08061X	PARTICIPANT	\N	PRESENT	0
613636	613306	19671E	PARTICIPANT	\N	PRESENT	0
613637	613306	19749K	PARTICIPANT	\N	PRESENT	0
613638	613306	19565D	PARTICIPANT	\N	PRESENT	0
613639	613306	14215L	PARTICIPANT	\N	PRESENT	0
613640	613306	20102Q	PARTICIPANT	\N	PRESENT	0
613728	613307	14026U	PARTICIPANT	\N	PRESENT	0
613729	613307	11031D	PARTICIPANT	\N	PRESENT	0
613730	613307	19565D	PARTICIPANT	\N	PRESENT	0
613731	613307	20102Q	PARTICIPANT	\N	PRESENT	0
613732	613307	18193Q	PARTICIPANT	\N	PRESENT	0
613733	613307	20114U	PARTICIPANT	\N	PRESENT	0
613734	613307	14121F	PARTICIPANT	\N	PRESENT	0
613735	613307	20130U	PARTICIPANT	\N	PRESENT	0
613736	613307	17779H	PARTICIPANT	\N	PRESENT	0
613737	613307	19387D	PARTICIPANT	\N	PRESENT	0
613738	613307	19713W	PARTICIPANT	\N	PRESENT	0
613739	613307	19543W	PARTICIPANT	\N	PRESENT	0
613740	613307	19479G	PARTICIPANT	\N	PRESENT	0
613741	613307	14083S	PARTICIPANT	\N	PRESENT	0
613742	613307	14179A	PARTICIPANT	\N	PRESENT	0
613743	613307	14042U	PARTICIPANT	\N	PRESENT	0
613744	613307	19749K	PARTICIPANT	\N	PRESENT	0
613745	613307	14327T	PARTICIPANT	\N	PRESENT	0
613746	613307	14030Q	PARTICIPANT	\N	PRESENT	0
613747	613307	14069U	PARTICIPANT	\N	PRESENT	0
613748	613307	19591F	PARTICIPANT	\N	PRESENT	0
613749	613307	11045K	PARTICIPANT	\N	PRESENT	0
613750	613307	11067R	PARTICIPANT	\N	PRESENT	0
613751	613307	20030R	PARTICIPANT	\N	PRESENT	0
613752	613307	14257W	PARTICIPANT	\N	PRESENT	0
613753	613307	20128B	PARTICIPANT	\N	PRESENT	0
613754	613307	08061X	PARTICIPANT	\N	PRESENT	0
613755	613307	04057K	PARTICIPANT	\N	PRESENT	0
613756	613307	19798U	PARTICIPANT	\N	PRESENT	0
613757	613307	14215L	PARTICIPANT	\N	PRESENT	0
613758	613307	19367Y	PARTICIPANT	\N	PRESENT	0
613759	613307	14217N	PARTICIPANT	\N	PRESENT	0
613760	613307	20062A	PARTICIPANT	\N	PRESENT	0
613761	613307	19762G	PARTICIPANT	\N	PRESENT	0
613762	613307	97011G	PARTICIPANT	\N	PRESENT	0
613763	613307	14213J	PARTICIPANT	\N	PRESENT	0
613764	613307	14147R	PARTICIPANT	\N	PRESENT	0
616973	616238	14053L	PARTICIPANT	\N	PRESENT	0
616974	616238	14111D	PARTICIPANT	\N	PRESENT	0
616975	616238	19581D	PARTICIPANT	\N	PRESENT	0
616976	616238	19673G	PARTICIPANT	\N	PRESENT	0
616977	616238	01028R	PARTICIPANT	\N	PRESENT	0
616978	616238	19447X	PARTICIPANT	\N	PRESENT	0
616979	616238	14231L	PARTICIPANT	\N	PRESENT	0
616980	616238	04085P	PARTICIPANT	\N	PRESENT	0
616981	616238	14089Y	PARTICIPANT	\N	PRESENT	0
616982	616238	19954N	PARTICIPANT	\N	PRESENT	0
616983	616238	19729F	PARTICIPANT	\N	PRESENT	0
616984	616238	14107H	PARTICIPANT	\N	PRESENT	0
616985	616238	20108W	PARTICIPANT	\N	PRESENT	0
616986	616238	20110Q	PARTICIPANT	\N	PRESENT	0
616987	616238	14147R	PARTICIPANT	\N	PRESENT	0
616988	616238	14151M	PARTICIPANT	\N	PRESENT	0
616989	616238	14215L	PRESIDENT	0	PRESENT	0
616990	616238	19749K	PARTICIPANT	\N	PRESENT	0
616991	616238	11072N	PARTICIPANT	\N	PRESENT	0
616992	616238	11026G	PARTICIPANT	\N	PRESENT	0
617088	616308	04070G	PARTICIPANT	\N	PRESENT	0
617089	616308	19699S	PARTICIPANT	\N	PRESENT	0
617090	616308	19533U	PARTICIPANT	\N	PRESENT	0
617091	616308	01060R	PARTICIPANT	\N	PRESENT	0
617092	616308	14229S	PARTICIPANT	\N	PRESENT	0
617093	616308	20098N	PARTICIPANT	\N	PRESENT	0
617094	616308	19573D	PARTICIPANT	\N	PRESENT	0
617095	616308	20112S	PARTICIPANT	\N	PRESENT	0
617096	616308	08012N	PARTICIPANT	\N	PRESENT	0
617097	616308	20124W	PARTICIPANT	\N	PRESENT	0
617098	616308	20026V	PARTICIPANT	\N	PRESENT	0
617099	616308	19593H	PARTICIPANT	\N	PRESENT	0
617100	616308	19527W	PARTICIPANT	\N	PRESENT	0
617101	616308	19643A	PARTICIPANT	\N	PRESENT	0
617102	616308	20132W	PARTICIPANT	\N	PRESENT	0
617103	616308	20134Y	PARTICIPANT	\N	PRESENT	0
617104	616308	14073Q	PARTICIPANT	\N	PRESENT	0
617105	616308	19651A	PARTICIPANT	\N	PRESENT	0
617106	616308	19611R	PARTICIPANT	\N	PRESENT	0
617107	616308	20138D	PARTICIPANT	\N	PRESENT	0
617108	616308	19693L	PARTICIPANT	\N	PRESENT	0
617109	616308	19399H	PARTICIPANT	\N	PRESENT	0
617110	616308	20052X	PARTICIPANT	\N	PRESENT	0
617111	616308	20152B	PARTICIPANT	\N	PRESENT	0
617112	616308	19719D	PARTICIPANT	\N	PRESENT	0
617113	616308	20172F	PARTICIPANT	\N	PRESENT	0
617114	616308	14030Q	PARTICIPANT	\N	PRESENT	0
617115	616308	20056C	PARTICIPANT	\N	PRESENT	0
617116	616308	20180F	PARTICIPANT	\N	PRESENT	0
617117	616308	04059M	PARTICIPANT	\N	PRESENT	0
617118	616308	20264J	PARTICIPANT	\N	PRESENT	0
617119	616308	14109K	PARTICIPANT	\N	PRESENT	0
617120	616308	14123H	PARTICIPANT	\N	PRESENT	0
617121	616308	11043H	PARTICIPANT	\N	PRESENT	0
617122	616308	11104D	PARTICIPANT	\N	PRESENT	0
617123	616308	17589D	PARTICIPANT	\N	PRESENT	0
617124	616308	20084G	PARTICIPANT	\N	PRESENT	0
617125	616308	19621T	PARTICIPANT	\N	PRESENT	0
617128	616348	19333N	PARTICIPANT	\N	PRESENT	0
617129	616348	08060W	PARTICIPANT	\N	PRESENT	0
617130	616348	19549D	PARTICIPANT	\N	PRESENT	0
617131	616348	19503N	PARTICIPANT	\N	PRESENT	0
617132	616348	19820Y	PARTICIPANT	\N	PRESENT	0
617133	616348	20076G	PARTICIPANT	\N	PRESENT	1
617136	616348	19701S	PARTICIPANT	\N	PRESENT	0
617137	616348	19387D	PARTICIPANT	\N	PRESENT	0
617138	616348	19826F	PARTICIPANT	\N	PRESENT	0
617139	616348	19637C	PARTICIPANT	\N	PRESENT	0
617140	616348	20096L	PARTICIPANT	\N	PRESENT	0
617141	616348	18083K	PARTICIPANT	\N	PRESENT	0
617142	616348	20100N	PARTICIPANT	\N	PRESENT	0
617143	616348	20106U	PARTICIPANT	\N	PRESENT	0
617144	616348	20118Y	PARTICIPANT	\N	PRESENT	0
617145	616348	20020P	PARTICIPANT	\N	PRESENT	0
617146	616348	17367Q	PARTICIPANT	\N	PRESENT	0
617147	616348	19681G	PARTICIPANT	\N	PRESENT	0
617148	616348	20024T	PARTICIPANT	\N	PRESENT	0
617149	616348	17637T	PARTICIPANT	\N	PRESENT	0
617150	616348	20038A	PARTICIPANT	\N	PRESENT	0
617151	616348	20140W	PARTICIPANT	\N	PRESENT	0
617152	616348	11026G	PARTICIPANT	\N	PRESENT	0
617153	616348	19251M	PARTICIPANT	\N	PRESENT	0
617154	616348	20046A	PARTICIPANT	\N	PRESENT	0
617155	616348	14169X	PARTICIPANT	\N	PRESENT	0
617156	616348	17229F	PARTICIPANT	\N	PRESENT	0
617157	616348	11101A	PARTICIPANT	\N	PRESENT	0
617158	616348	19739H	PARTICIPANT	\N	PRESENT	0
617159	616348	19745F	PARTICIPANT	\N	PRESENT	0
617160	616348	05012A	PARTICIPANT	\N	PRESENT	0
617161	616348	20032T	PARTICIPANT	\N	PRESENT	0
617162	616348	14237S	PARTICIPANT	\N	PRESENT	0
617163	616348	14031R	PARTICIPANT	\N	PRESENT	0
617164	616348	14219Q	PRESIDENT	0	PRESENT	0
617165	616348	11065P	PARTICIPANT	\N	PRESENT	0
617166	616348	19619A	PARTICIPANT	\N	PRESENT	1
617170	616348	19551W	PARTICIPANT	\N	PRESENT	0
617176	616348	19525U	PARTICIPANT	\N	PRESENT	0
617178	616348	20122U	PARTICIPANT	\N	EXCUSE	0
617180	616348	20102Q	PARTICIPANT	\N	PRESENT	0
617181	616308	19057M	PARTICIPANT	\N	PRESENT	0
617183	616406	20094J	PARTICIPANT	\N	PRESENT	1
617184	616348	20136B	PARTICIPANT	\N	PRESENT	0
617185	616348	14221J	PARTICIPANT	\N	PRESENT	0
617188	616348	19685L	PARTICIPANT	\N	PRESENT	0
617204	617203	19443T	PARTICIPANT	\N	PRESENT	0
617205	617203	19565D	PARTICIPANT	\N	PRESENT	0
617206	617203	20072C	PARTICIPANT	\N	PRESENT	0
617207	617203	01058X	PARTICIPANT	\N	PRESENT	0
617208	617203	11027H	PARTICIPANT	\N	PRESENT	0
617209	617203	16685X	PARTICIPANT	\N	PRESENT	0
617210	617203	04042C	PRESIDENT	0	PRESENT	0
617211	617203	11054L	PARTICIPANT	\N	PRESENT	0
617212	617203	19669L	PARTICIPANT	\N	PRESENT	0
617213	617203	11066Q	PARTICIPANT	\N	PRESENT	0
617214	617203	12028B	PARTICIPANT	\N	PRESENT	0
617215	617203	11115U	PARTICIPANT	\N	PRESENT	0
617216	617203	19421M	PARTICIPANT	\N	PRESENT	0
617217	617203	19709B	PARTICIPANT	\N	PRESENT	0
617218	617203	14193X	PARTICIPANT	\N	PRESENT	0
617219	617203	19347U	PARTICIPANT	\N	PRESENT	0
617220	617203	07033P	PARTICIPANT	\N	PRESENT	0
617221	617203	97011G	PARTICIPANT	\N	PRESENT	0
617222	617203	08061X	PARTICIPANT	\N	PRESENT	0
617223	617203	14249W	PARTICIPANT	\N	PRESENT	0
617224	617203	08047A	PARTICIPANT	\N	PRESENT	0
617225	617203	14059S	PARTICIPANT	\N	PRESENT	0
617226	617203	04035D	PARTICIPANT	\N	PRESENT	1
617227	617203	14133K	PARTICIPANT	\N	PRESENT	0
617228	617203	01062T	PARTICIPANT	\N	PRESENT	1
617229	617203	08069G	PARTICIPANT	\N	PRESENT	0
617259	616391	20068G	PARTICIPANT	\N	PRESENT	0
617231	617203	20042V	PARTICIPANT	\N	PRESENT	0
617232	617203	01024M	PARTICIPANT	\N	PRESENT	0
617233	617203	19721W	PARTICIPANT	\N	PRESENT	1
617234	617203	14105F	PARTICIPANT	\N	PRESENT	0
617235	617203	20064C	PARTICIPANT	\N	PRESENT	1
617236	617203	14267Y	PARTICIPANT	\N	PRESENT	0
617237	617203	11064N	PARTICIPANT	\N	PRESENT	0
617238	617203	11083R	PARTICIPANT	\N	PRESENT	1
617239	617203	14255U	PARTICIPANT	\N	PRESENT	0
617240	616348	20068G	PARTICIPANT	\N	PRESENT	0
617241	616391	86034E	PARTICIPANT	\N	PRESENT	0
617242	616391	11085T	PARTICIPANT	\N	PRESENT	0
617243	616391	04033B	PARTICIPANT	\N	PRESENT	0
617244	616391	19760E	PARTICIPANT	\N	PRESENT	0
617245	616391	19651A	PARTICIPANT	\N	PRESENT	0
617246	616391	19683J	PARTICIPANT	\N	PRESENT	0
617247	616391	19719D	PARTICIPANT	\N	PRESENT	0
617248	616391	19347U	PARTICIPANT	\N	PRESENT	0
617249	616391	14195A	PARTICIPANT	\N	PRESENT	0
617250	616391	19711U	PARTICIPANT	\N	PRESENT	0
617251	616391	14257W	PARTICIPANT	\N	PRESENT	0
617252	616391	14033T	PARTICIPANT	\N	PRESENT	0
617253	616391	19543W	PARTICIPANT	\N	PRESENT	0
617254	616391	14193X	PARTICIPANT	\N	PRESENT	0
617255	616391	11026G	PARTICIPANT	\N	PRESENT	0
617256	616391	07033P	PARTICIPANT	\N	PRESENT	0
617257	616391	14189C	PARTICIPANT	\N	PRESENT	0
617258	616391	20098N	PARTICIPANT	\N	PRESENT	0
617260	616391	20090E	PARTICIPANT	\N	PRESENT	0
617261	616391	20108W	PARTICIPANT	\N	PRESENT	0
606610	606303	01043Q	PARTICIPANT	\N	PRESENT	0
606611	606303	20116W	PARTICIPANT	\N	PRESENT	0
606612	606303	14331P	PARTICIPANT	\N	PRESENT	0
606613	606303	14225N	PARTICIPANT	\N	PRESENT	0
606614	606303	20094J	PARTICIPANT	\N	PRESENT	0
606615	606303	20080C	PARTICIPANT	\N	PRESENT	0
606617	606303	11048N	PARTICIPANT	\N	PRESENT	0
606618	606303	11040E	PARTICIPANT	\N	PRESENT	0
606619	606303	19687N	PARTICIPANT	\N	PRESENT	0
606620	606303	20100N	PARTICIPANT	\N	PRESENT	0
606621	606303	19667J	PARTICIPANT	\N	PRESENT	0
606622	606303	95063L	PARTICIPANT	\N	PRESENT	0
606623	606303	19711U	PARTICIPANT	\N	PRESENT	0
606624	606303	11070L	PARTICIPANT	\N	PRESENT	0
606625	606303	19671E	PARTICIPANT	\N	PRESENT	0
606626	606303	19349W	PARTICIPANT	\N	PRESENT	0
606627	606303	07029T	PARTICIPANT	\N	PRESENT	0
606628	606303	20044X	PARTICIPANT	\N	PRESENT	0
606629	606303	20138D	PARTICIPANT	\N	PRESENT	0
606631	606303	11053K	PARTICIPANT	\N	PRESENT	0
606632	606303	14083S	PARTICIPANT	\N	PRESENT	0
606633	606303	11099A	PARTICIPANT	\N	PRESENT	0
606634	606303	14327T	PARTICIPANT	\N	PRESENT	0
606635	606303	19479G	PARTICIPANT	\N	PRESENT	0
606636	606303	20070A	PARTICIPANT	\N	PRESENT	0
606637	606303	19619A	PARTICIPANT	\N	PRESENT	0
606638	606303	01048V	PARTICIPANT	\N	PRESENT	0
606639	606303	20086J	PARTICIPANT	\N	PRESENT	0
606641	606303	19335Q	PARTICIPANT	\N	PRESENT	0
606642	606303	19647E	PARTICIPANT	\N	PRESENT	0
606644	606303	19657G	PARTICIPANT	\N	PRESENT	0
606645	606303	14329V	PARTICIPANT	\N	PRESENT	0
606646	606303	19689Q	PARTICIPANT	\N	PRESENT	0
606647	606303	19715Y	PARTICIPANT	\N	PRESENT	0
606648	606303	19503N	PARTICIPANT	\N	PRESENT	0
606649	606303	08034U	PARTICIPANT	\N	PRESENT	0
606650	606303	20034V	PARTICIPANT	\N	PRESENT	0
606652	606303	04071H	PARTICIPANT	\N	PRESENT	0
606653	606303	11097X	PARTICIPANT	\N	PRESENT	0
606654	606303	08010L	PARTICIPANT	\N	PRESENT	0
606656	606303	20108W	PARTICIPANT	\N	PRESENT	0
606657	606303	19545Y	PARTICIPANT	\N	PRESENT	0
606663	606303	20036X	PARTICIPANT	\N	PRESENT	0
606664	606303	19301E	PARTICIPANT	\N	PRESENT	0
606665	606303	19551W	PARTICIPANT	\N	PRESENT	0
606666	606303	01057W	PARTICIPANT	\N	PRESENT	0
606667	606303	19347U	PARTICIPANT	\N	PRESENT	0
606668	606303	20136B	PARTICIPANT	\N	PRESENT	0
606712	606304	14357A	PARTICIPANT	\N	PRESENT	0
606713	606304	14327T	PARTICIPANT	\N	PRESENT	0
606714	606304	11040E	PARTICIPANT	\N	PRESENT	0
606715	606304	19687N	PARTICIPANT	\N	PRESENT	0
606716	606304	20094J	PARTICIPANT	\N	PRESENT	0
606717	606304	11048N	PARTICIPANT	\N	PRESENT	0
606718	606304	14225N	PARTICIPANT	\N	PRESENT	0
606719	606304	14331P	PARTICIPANT	\N	PRESENT	0
606720	606304	19667J	PARTICIPANT	\N	PRESENT	0
606721	606304	20116W	PARTICIPANT	\N	PRESENT	0
606722	606304	19545Y	PARTICIPANT	\N	PRESENT	0
606723	606304	19689Q	PARTICIPANT	\N	PRESENT	0
606724	606304	20100N	PARTICIPANT	\N	PRESENT	0
606725	606304	19349W	PARTICIPANT	\N	PRESENT	0
606726	606304	19335Q	PARTICIPANT	\N	PRESENT	0
606727	606304	14021P	PARTICIPANT	\N	PRESENT	0
606728	606304	07029T	PARTICIPANT	\N	PRESENT	0
606729	606304	20044X	PARTICIPANT	\N	PRESENT	0
606730	606304	20070A	PARTICIPANT	\N	PRESENT	0
606731	606304	20080C	PARTICIPANT	\N	PRESENT	0
606732	606304	01048V	PARTICIPANT	\N	PRESENT	0
606733	606304	19551W	PARTICIPANT	\N	PRESENT	0
606734	606304	11097X	PARTICIPANT	\N	PRESENT	0
606735	606304	20034V	PARTICIPANT	\N	PRESENT	0
606736	606304	11099A	PARTICIPANT	\N	PRESENT	0
606737	606304	14229S	PARTICIPANT	\N	PRESENT	0
606738	606304	08034U	PARTICIPANT	\N	PRESENT	0
606739	606304	19347U	PARTICIPANT	\N	PRESENT	0
606740	606304	19647E	PARTICIPANT	\N	PRESENT	0
606741	606304	20036X	PARTICIPANT	\N	PRESENT	0
606742	606304	19671E	PARTICIPANT	\N	PRESENT	0
606743	606304	14083S	PARTICIPANT	\N	PRESENT	0
606744	606304	19782L	PARTICIPANT	\N	PRESENT	0
606745	606304	19479G	PARTICIPANT	\N	PRESENT	0
606746	606304	11053K	PARTICIPANT	\N	PRESENT	0
606747	606304	14329V	PARTICIPANT	\N	PRESENT	0
606748	606304	19693L	PARTICIPANT	\N	PRESENT	0
606749	606304	14031R	PARTICIPANT	\N	PRESENT	0
606750	606304	95063L	PARTICIPANT	\N	PRESENT	0
606751	606304	04071H	PARTICIPANT	\N	PRESENT	0
606752	606304	20148F	PARTICIPANT	\N	PRESENT	0
606710	606304	99004R	PARTICIPANT	\N	PRESENT	0
606711	606304	19711U	PARTICIPANT	\N	PRESENT	0
606753	606304	19657G	PARTICIPANT	\N	PRESENT	0
606754	606304	20136B	PARTICIPANT	\N	PRESENT	0
606755	606304	01057W	PARTICIPANT	\N	PRESENT	0
606756	606304	19741B	PARTICIPANT	\N	PRESENT	0
606757	606304	20252E	PARTICIPANT	\N	PRESENT	0
606758	606304	19295A	PARTICIPANT	\N	PRESENT	0
606759	606304	19611R	PARTICIPANT	\N	PRESENT	0
606760	606304	19619A	PARTICIPANT	\N	PRESENT	0
606762	606304	20086J	PARTICIPANT	\N	PRESENT	0
606766	606304	01043Q	PARTICIPANT	\N	PRESENT	0
606767	606304	18083K	PARTICIPANT	\N	PRESENT	0
606769	606304	20140W	PARTICIPANT	\N	PRESENT	0
606770	606304	08010L	PARTICIPANT	\N	PRESENT	0
606775	606304	14219Q	PARTICIPANT	\N	PRESENT	0
606776	606304	19577H	PARTICIPANT	\N	PRESENT	0
606778	606304	20068G	PARTICIPANT	\N	PRESENT	0
606779	606304	19826F	PARTICIPANT	\N	PRESENT	0
606781	604468	20136B	PARTICIPANT	\N	PRESENT	0
606782	604468	20068G	PARTICIPANT	\N	PRESENT	0
606783	604468	19745F	PARTICIPANT	\N	PRESENT	0
606784	604468	20102Q	PARTICIPANT	\N	PRESENT	0
606785	604468	19251M	PARTICIPANT	\N	EXCUSE	0
606786	604468	14031R	PARTICIPANT	\N	PRESENT	0
606787	604468	14219Q	PRESIDENT	0	PRESENT	0
606788	604468	20140W	PARTICIPANT	\N	PRESENT	0
606789	604468	19826F	PARTICIPANT	\N	PRESENT	0
606790	606304	08061X	PARTICIPANT	\N	PRESENT	0
606791	604468	18083K	PARTICIPANT	\N	PRESENT	0
606792	604468	19333N	PARTICIPANT	\N	PRESENT	0
606793	604468	19619A	PARTICIPANT	\N	PRESENT	0
606794	604468	19549D	PARTICIPANT	\N	PRESENT	0
606795	604468	19820Y	PARTICIPANT	\N	PRESENT	0
606796	604468	19637C	PARTICIPANT	\N	PRESENT	0
606797	604468	19685L	PARTICIPANT	\N	PRESENT	0
606799	606304	14257W	PARTICIPANT	\N	PRESENT	0
606800	606304	04059M	PARTICIPANT	\N	PRESENT	0
606801	606304	04085P	PARTICIPANT	\N	PRESENT	0
606802	606304	11085T	PARTICIPANT	\N	PRESENT	0
606803	606304	10006L	PARTICIPANT	\N	PRESENT	0
606804	606304	08069G	PARTICIPANT	\N	PRESENT	0
606805	604468	20100N	PARTICIPANT	\N	PRESENT	0
606806	604468	19551W	PARTICIPANT	\N	PRESENT	0
606807	606304	19820Y	PARTICIPANT	\N	PRESENT	0
606810	606304	12041X	PARTICIPANT	\N	PRESENT	0
608358	608357	20094J	PARTICIPANT	\N	PRESENT	0
608359	608357	20018V	PARTICIPANT	\N	PRESENT	0
608360	608357	14097Y	PARTICIPANT	\N	PRESENT	0
608361	608357	14189C	PARTICIPANT	\N	PRESENT	0
608363	608362	14033T	PARTICIPANT	\N	PRESENT	0
608364	608362	20092G	PARTICIPANT	\N	PRESENT	0
608365	608362	14257W	PARTICIPANT	\N	PRESENT	0
608366	608362	19503N	PARTICIPANT	\N	PRESENT	0
608367	608362	19333N	PARTICIPANT	\N	PRESENT	0
608368	608362	19820Y	PARTICIPANT	\N	PRESENT	0
608369	608362	20062A	PARTICIPANT	\N	PRESENT	0
608370	608362	14038Y	PARTICIPANT	\N	PRESENT	0
608371	608362	14083S	PARTICIPANT	\N	PRESENT	0
608372	608362	19533U	PARTICIPANT	\N	PRESENT	0
608373	608362	19721W	PARTICIPANT	\N	PRESENT	0
608374	608362	20174H	PARTICIPANT	\N	PRESENT	0
608375	608362	19681G	PARTICIPANT	\N	PRESENT	0
608376	608362	20126Y	PARTICIPANT	\N	PRESENT	0
608377	608362	19369B	PARTICIPANT	\N	PRESENT	0
608378	608362	14031R	PARTICIPANT	\N	PRESENT	0
608379	608362	19619A	PARTICIPANT	\N	PRESENT	0
608380	608362	20038A	PARTICIPANT	\N	PRESENT	0
608381	608362	19575F	PARTICIPANT	\N	PRESENT	0
608383	602477	14329V	PARTICIPANT	0	PRESENT	0
608384	602477	19515S	PRESIDENT	0	PRESENT	0
608385	602477	19671E	PARTICIPANT	\N	PRESENT	0
624306	621458	11109J	PARTICIPANT	\N	EXCUSE	0
624307	621458	19735D	PARTICIPANT	\N	EXCUSE	0
624308	620189	11109J	PARTICIPANT	\N	EXCUSE	0
624309	620189	20124W	PARTICIPANT	\N	PRESENT	0
624310	620189	20056C	PARTICIPANT	\N	PRESENT	0
624311	620189	14109K	PARTICIPANT	\N	PRESENT	1
624312	620189	20058E	PARTICIPANT	\N	PRESENT	1
624313	620189	20134Y	PARTICIPANT	\N	PRESENT	0
624314	620189	20172F	PARTICIPANT	\N	PRESENT	0
624315	620189	19611R	PARTICIPANT	\N	PRESENT	0
624316	620189	19735D	PARTICIPANT	\N	PRESENT	0
624317	620189	19699S	PARTICIPANT	\N	PRESENT	1
624318	620189	11104D	PARTICIPANT	\N	PRESENT	1
624319	620189	20142Y	PARTICIPANT	\N	PRESENT	1
624320	620189	20052X	PARTICIPANT	\N	PRESENT	0
624321	620189	19573D	PARTICIPANT	\N	PRESENT	0
624322	620189	19593H	PARTICIPANT	\N	PRESENT	0
624323	620189	04033B	PARTICIPANT	\N	PRESENT	0
624324	620189	14229S	PARTICIPANT	\N	PRESENT	0
624325	620189	20084G	PARTICIPANT	\N	PRESENT	0
624326	620189	19643A	PARTICIPANT	\N	PRESENT	0
624327	620189	14030Q	PARTICIPANT	\N	PRESENT	0
624328	620189	17589D	PARTICIPANT	\N	PRESENT	0
624329	620189	20132W	PARTICIPANT	\N	PRESENT	0
624330	620189	20180F	PARTICIPANT	\N	PRESENT	0
624331	620189	14123H	PARTICIPANT	\N	PRESENT	0
624332	620189	19399H	PARTICIPANT	\N	PRESENT	0
624333	620189	20152B	PARTICIPANT	\N	PRESENT	0
624334	620189	19693L	PARTICIPANT	\N	PRESENT	0
624335	620189	14073Q	PARTICIPANT	\N	PRESENT	0
624336	620189	04070G	PARTICIPANT	\N	PRESENT	0
624337	620189	19651A	PARTICIPANT	\N	PRESENT	1
624338	620189	19621T	PARTICIPANT	\N	PRESENT	0
624339	620189	19758L	PARTICIPANT	\N	PRESENT	0
624340	620189	19057M	PARTICIPANT	\N	PRESENT	0
624341	620189	20026V	PARTICIPANT	\N	PRESENT	1
625601	624520	19333N	PARTICIPANT	\N	PRESENT	0
625317	623502	20044X	PARTICIPANT	\N	EXCUSE	0
625600	624520	08034U	PARTICIPANT	\N	PRESENT	0
625602	624520	14001X	PARTICIPANT	\N	PRESENT	0
625603	624520	19619A	PARTICIPANT	\N	PRESENT	0
626730	624168	19651A	PARTICIPANT	\N	PRESENT	0
626731	624168	95063L	PARTICIPANT	\N	PRESENT	0
626732	624168	20266L	PARTICIPANT	\N	PRESENT	0
626733	624168	99004R	PARTICIPANT	\N	PRESENT	0
626734	624168	11064N	PARTICIPANT	\N	PRESENT	0
626735	624168	11012A	PARTICIPANT	\N	PRESENT	0
626736	624168	19565D	PARTICIPANT	\N	PRESENT	0
626737	624168	19758L	PARTICIPANT	\N	PRESENT	0
626738	624168	01058X	PARTICIPANT	\N	PRESENT	0
626739	624168	19709B	PARTICIPANT	\N	PRESENT	0
626740	624168	20264J	PARTICIPANT	\N	PRESENT	0
626741	624168	11027H	PARTICIPANT	\N	PRESENT	0
626742	624168	11026G	PARTICIPANT	\N	PRESENT	0
626744	624168	08047A	PARTICIPANT	\N	PRESENT	0
626750	624168	14255U	PARTICIPANT	\N	PRESENT	0
626751	624168	14133K	PARTICIPANT	\N	PRESENT	0
626752	624168	20106U	PARTICIPANT	\N	PRESENT	0
626753	624168	19057M	PARTICIPANT	\N	PRESENT	0
626754	624168	04035D	PARTICIPANT	\N	PRESENT	0
626755	624168	04042C	PARTICIPANT	\N	PRESENT	0
626756	624168	20086J	PARTICIPANT	\N	PRESENT	0
626757	624168	20056C	PARTICIPANT	\N	PRESENT	0
626758	624168	19467C	PARTICIPANT	\N	PRESENT	0
626759	624168	19701S	PARTICIPANT	\N	PRESENT	0
626760	624168	19675J	PARTICIPANT	\N	PRESENT	0
626770	624168	19593H	PARTICIPANT	\N	PRESENT	0
626772	624168	19693L	PARTICIPANT	\N	PRESENT	0
626763	624168	19713W	PARTICIPANT	\N	PRESENT	0
626771	624168	19533U	PARTICIPANT	\N	PRESENT	0
626773	624168	14083S	PARTICIPANT	\N	PRESENT	0
626774	624168	19705W	PARTICIPANT	\N	PRESENT	0
626775	624168	19691J	PARTICIPANT	\N	PRESENT	0
626776	624168	20134Y	PARTICIPANT	\N	PRESENT	0
626777	624168	20058E	PARTICIPANT	\N	PRESENT	0
626778	624168	17023S	PARTICIPANT	\N	PRESENT	0
626779	624168	19573D	PARTICIPANT	\N	PRESENT	0
626780	624168	18083K	PARTICIPANT	\N	PRESENT	0
626781	624168	20132W	PARTICIPANT	\N	PRESENT	0
626782	624168	01048V	PARTICIPANT	\N	PRESENT	0
626783	624168	19673G	PARTICIPANT	\N	PRESENT	0
626785	626784	05008E	PARTICIPANT	\N	PRESENT	0
626786	626784	11053K	PARTICIPANT	\N	PRESENT	0
626787	626784	01028R	PARTICIPANT	\N	PRESENT	0
626788	624168	20152B	PARTICIPANT	\N	PRESENT	0
626789	624168	14030Q	PARTICIPANT	\N	PRESENT	0
626790	624168	04085P	PARTICIPANT	\N	PRESENT	0
626791	624168	08010L	PARTICIPANT	\N	PRESENT	0
626792	624168	20124W	PARTICIPANT	\N	PRESENT	0
626793	624168	19643A	PARTICIPANT	\N	PRESENT	0
626796	624168	19527W	PARTICIPANT	\N	PRESENT	0
626833	624169	20132W	PARTICIPANT	\N	PRESENT	0
626834	624169	04057K	PARTICIPANT	\N	PRESENT	0
626835	624169	19675J	PARTICIPANT	\N	PRESENT	0
626836	624169	19673G	PARTICIPANT	\N	PRESENT	0
626837	624169	19573D	PARTICIPANT	\N	PRESENT	0
626838	624169	04085P	PARTICIPANT	\N	PRESENT	0
626839	624169	19565D	PARTICIPANT	\N	PRESENT	0
626840	624169	20058E	PARTICIPANT	\N	PRESENT	0
626841	624169	19057M	PARTICIPANT	\N	PRESENT	0
626842	624169	14030Q	PARTICIPANT	\N	PRESENT	0
626843	624169	20124W	PARTICIPANT	\N	PRESENT	0
626844	624169	20152B	PARTICIPANT	\N	PRESENT	0
626845	624169	20106U	PARTICIPANT	\N	PRESENT	0
626846	624169	19758L	PARTICIPANT	\N	PRESENT	0
626847	624169	19643A	PARTICIPANT	\N	PRESENT	0
626848	626695	14259Y	PARTICIPANT	\N	PRESENT	0
626849	624169	20134Y	PARTICIPANT	\N	PRESENT	0
626850	624169	14255U	PARTICIPANT	\N	PRESENT	0
626851	626695	14275Y	PARTICIPANT	\N	PRESENT	0
626852	624169	20034V	PARTICIPANT	\N	PRESENT	0
626856	626855	11065P	PARTICIPANT	\N	PRESENT	0
626857	626855	19503N	PARTICIPANT	\N	PRESENT	0
626858	626855	19701S	PARTICIPANT	\N	PRESENT	0
626859	626855	19619A	PARTICIPANT	\N	PRESENT	0
626860	626855	19251M	PARTICIPANT	\N	PRESENT	0
626889	626888	19663E	PARTICIPANT	\N	PRESENT	0
626890	626888	20128B	PARTICIPANT	\N	PRESENT	0
626891	626888	19735D	PARTICIPANT	\N	PRESENT	0
626892	626888	01048V	PARTICIPANT	\N	PRESENT	0
626893	626888	11067R	PARTICIPANT	\N	PRESENT	0
626894	626888	01058X	PARTICIPANT	\N	PRESENT	0
626831	624169	99004R	PARTICIPANT	\N	PRESENT	0
626832	624169	19527W	PARTICIPANT	\N	PRESENT	0
626900	624342	11109J	PARTICIPANT	\N	EXCUSE	0
626901	624342	20112S	PARTICIPANT	\N	PRESENT	1
626902	624342	19651A	PARTICIPANT	\N	PRESENT	1
626903	624342	20058E	PARTICIPANT	\N	PRESENT	1
626904	624342	20052X	PARTICIPANT	\N	PRESENT	1
626905	624342	20132W	PARTICIPANT	\N	PRESENT	1
626906	626876	04059M	PARTICIPANT	\N	PRESENT	0
626907	626876	19651A	PARTICIPANT	\N	PRESENT	1
626908	626876	20086J	PARTICIPANT	\N	PRESENT	0
626927	626861	04059M	PARTICIPANT	\N	PRESENT	0
626948	626861	11053K	PARTICIPANT	\N	PRESENT	1
626949	626864	04059M	PARTICIPANT	\N	PRESENT	0
626950	626864	20086J	PARTICIPANT	\N	PRESENT	1
626951	626864	19725B	PARTICIPANT	\N	PRESENT	1
626952	626864	19399H	PARTICIPANT	\N	PRESENT	0
626953	626864	19611R	PARTICIPANT	\N	PRESENT	0
626916	626876	19399H	PARTICIPANT	\N	PRESENT	0
626954	626864	19699S	PARTICIPANT	\N	PRESENT	0
626918	626876	19611R	PRESIDENT	0	PRESENT	0
626919	626876	19699S	PARTICIPANT	\N	PRESENT	0
626955	626864	20142Y	PARTICIPANT	\N	PRESENT	0
626921	626876	20142Y	PARTICIPANT	\N	PRESENT	0
626936	626861	19725B	PARTICIPANT	\N	PRESENT	1
626923	626876	14229S	PARTICIPANT	\N	PRESENT	0
626937	626861	19399H	PARTICIPANT	\N	PRESENT	0
626938	626861	20056C	PARTICIPANT	\N	PRESENT	1
626939	626861	19611R	PRESIDENT	0	PRESENT	0
626940	626861	19699S	PARTICIPANT	\N	PRESENT	0
626956	626864	14229S	PARTICIPANT	\N	PRESENT	0
626942	626861	20142Y	PARTICIPANT	\N	PRESENT	0
626943	626861	19705W	PARTICIPANT	\N	PRESENT	1
626944	626861	14229S	PARTICIPANT	\N	PRESENT	0
626957	626864	19705W	PARTICIPANT	\N	PRESENT	1
626946	626861	20026V	PARTICIPANT	\N	PRESENT	0
626964	626959	10006L	PARTICIPANT	\N	PRESENT	0
603192	603191	19768N	PARTICIPANT	\N	PRESENT	0
603193	603191	19747H	PARTICIPANT	\N	PRESENT	0
603194	603191	19705W	PARTICIPANT	\N	PRESENT	0
603195	603191	20030R	PARTICIPANT	\N	PRESENT	0
603196	603191	11099A	PARTICIPANT	\N	PRESENT	0
603197	603191	14329V	PARTICIPANT	\N	PRESENT	0
603199	603198	19575F	PARTICIPANT	\N	PRESENT	0
603250	603249	04042C	PARTICIPANT	\N	PRESENT	0
603251	603249	14267Y	PARTICIPANT	\N	PRESENT	0
603252	603249	19443T	PARTICIPANT	\N	PRESENT	0
603253	603249	08056B	PARTICIPANT	\N	PRESENT	0
603254	603249	08047A	PARTICIPANT	\N	PRESENT	0
603255	603249	14249W	PARTICIPANT	\N	PRESENT	0
603256	603249	14133K	PARTICIPANT	\N	PRESENT	0
603257	603249	14105F	PARTICIPANT	\N	PRESENT	0
603258	603249	19347U	PARTICIPANT	\N	PRESENT	0
603259	603249	16685X	PARTICIPANT	\N	PRESENT	0
603260	603249	20064C	PARTICIPANT	\N	PRESENT	0
603265	603264	14133K	PARTICIPANT	\N	PRESENT	0
603266	603264	19565D	PARTICIPANT	\N	PRESENT	0
603267	603264	14267Y	PARTICIPANT	\N	PRESENT	0
603268	603264	14193X	PARTICIPANT	\N	PRESENT	0
603269	603264	11027H	PARTICIPANT	\N	PRESENT	0
603270	603264	12028B	PARTICIPANT	\N	PRESENT	0
603271	603264	11066Q	PARTICIPANT	\N	PRESENT	0
603279	603277	14133K	PARTICIPANT	\N	PRESENT	0
603281	603277	11066Q	PARTICIPANT	\N	PRESENT	0
603283	603282	01058X	PARTICIPANT	\N	PRESENT	0
603284	603282	19347U	PARTICIPANT	\N	PRESENT	0
603286	603285	01058X	PARTICIPANT	\N	PRESENT	0
603287	603285	19347U	PARTICIPANT	\N	PRESENT	0
603289	603288	11083R	PARTICIPANT	\N	PRESENT	0
603291	603290	14267Y	PARTICIPANT	\N	PRESENT	0
603292	603290	19565D	PARTICIPANT	\N	PRESENT	0
603486	603485	14030Q	PARTICIPANT	\N	PRESENT	0
603487	603485	14042U	PARTICIPANT	\N	PRESENT	0
603488	603485	11083R	PARTICIPANT	\N	PRESENT	0
603489	603485	19723Y	PARTICIPANT	\N	PRESENT	0
603490	603485	19503N	PARTICIPANT	\N	PRESENT	0
603492	603491	14231L	PARTICIPANT	\N	PRESENT	0
608561	608560	08012N	PARTICIPANT	\N	PRESENT	0
608562	608560	19533U	PARTICIPANT	\N	PRESENT	0
608563	608560	11043H	PARTICIPANT	\N	PRESENT	0
608564	608559	11043H	PARTICIPANT	\N	PRESENT	1
608565	608559	08012N	PARTICIPANT	\N	PRESENT	1
609410	609405	11043H	PARTICIPANT	\N	PRESENT	1
609411	609405	08012N	PARTICIPANT	\N	PRESENT	1
609412	609405	14073Q	PARTICIPANT	\N	PRESENT	1
610760	610740	14147R	PARTICIPANT	\N	PRESENT	0
610761	610741	14147R	PARTICIPANT	\N	EXCUSE	0
610763	610762	86034E	PARTICIPANT	\N	PRESENT	0
610764	610762	04085P	PARTICIPANT	\N	PRESENT	0
610765	610762	04047H	PARTICIPANT	\N	PRESENT	0
610766	610762	19629C	PARTICIPANT	\N	PRESENT	0
610767	610762	10006L	PARTICIPANT	\N	PRESENT	0
610768	610762	14042U	PARTICIPANT	\N	PRESENT	0
610769	610762	19347U	PARTICIPANT	\N	PRESENT	0
610770	610762	14026U	PARTICIPANT	\N	PRESENT	0
610771	610762	11048N	PARTICIPANT	\N	PRESENT	0
610772	610762	14021P	PARTICIPANT	\N	PRESENT	0
610773	610762	99004R	PARTICIPANT	\N	PRESENT	0
610774	610762	19611R	PARTICIPANT	\N	PRESENT	0
610775	610762	14219Q	PARTICIPANT	\N	PRESENT	0
610776	610762	11085T	PARTICIPANT	\N	PRESENT	0
610777	610762	14221J	PARTICIPANT	\N	PRESENT	0
610778	610762	08061X	PARTICIPANT	\N	PRESENT	0
610779	610762	08047A	PARTICIPANT	\N	PRESENT	0
610780	610762	14331P	PARTICIPANT	\N	PRESENT	0
610781	610762	14225N	PARTICIPANT	\N	PRESENT	0
610782	610762	04033B	PARTICIPANT	\N	PRESENT	0
610783	610762	01028R	PARTICIPANT	\N	PRESENT	0
612851	610740	19717B	PRESIDENT	0	PRESENT	0
612852	610740	18083K	PARTICIPANT	\N	PRESENT	0
612853	610740	19673G	PARTICIPANT	\N	PRESENT	0
612854	610740	17023S	PARTICIPANT	\N	PRESENT	0
612855	610740	19691J	PARTICIPANT	\N	PRESENT	0
612856	610740	20034V	PARTICIPANT	\N	EXCUSE	0
612857	610740	14059S	PARTICIPANT	\N	PRESENT	0
612858	610740	20028X	PARTICIPANT	\N	PRESENT	0
612859	610740	11072N	PARTICIPANT	\N	PRESENT	0
612860	610740	20148F	PARTICIPANT	\N	PRESENT	0
612861	610740	20146D	PARTICIPANT	\N	PRESENT	0
612863	610740	20150Y	PARTICIPANT	\N	PRESENT	0
612875	612874	14281W	PARTICIPANT	\N	PRESENT	0
612876	612874	14231L	PRESIDENT	0	PRESENT	0
612878	612874	19489J	PARTICIPANT	\N	PRESENT	0
612879	612874	19820Y	PARTICIPANT	\N	PRESENT	0
612882	612874	20084G	PARTICIPANT	\N	PRESENT	0
612883	612874	14217N	PARTICIPANT	\N	PRESENT	0
612884	612874	20090E	PARTICIPANT	\N	PRESENT	0
612885	612874	19333N	PARTICIPANT	\N	PRESENT	0
612886	612874	19565D	PARTICIPANT	\N	PRESENT	0
612887	612874	01057W	PARTICIPANT	\N	PRESENT	0
612888	612874	19447X	PARTICIPANT	\N	PRESENT	0
612889	612874	14187A	PARTICIPANT	\N	PRESENT	0
612890	612874	08010L	PARTICIPANT	\N	PRESENT	0
612891	612874	20022R	PARTICIPANT	\N	PRESENT	0
613767	613307	20108W	PARTICIPANT	\N	PRESENT	0
613768	613307	07029T	PARTICIPANT	\N	PRESENT	0
613769	613307	19467C	PARTICIPANT	\N	PRESENT	0
613770	613307	19447X	PARTICIPANT	\N	PRESENT	0
613771	613307	20038A	PARTICIPANT	\N	PRESENT	0
613772	613307	20044X	PARTICIPANT	\N	PRESENT	0
613774	613307	19679N	PARTICIPANT	\N	PRESENT	0
613775	613307	19693L	PARTICIPANT	\N	PRESENT	0
613776	613307	99004R	PARTICIPANT	\N	PRESENT	0
613778	613307	19703U	PARTICIPANT	\N	PRESENT	0
613779	613307	19747H	PARTICIPANT	\N	PRESENT	0
613780	613307	20180F	PARTICIPANT	\N	PRESENT	0
613781	613307	18083K	PARTICIPANT	\N	PRESENT	0
613782	613307	19415P	PARTICIPANT	\N	PRESENT	0
613783	613307	10006L	PARTICIPANT	\N	PRESENT	0
613784	613307	19691J	PARTICIPANT	\N	PRESENT	0
613785	613307	20248J	PARTICIPANT	\N	PRESENT	0
613786	613307	14073Q	PARTICIPANT	\N	PRESENT	0
613787	613307	20116W	PARTICIPANT	\N	PRESENT	0
613788	613307	14031R	PARTICIPANT	\N	PRESENT	0
613789	613307	19657G	PARTICIPANT	\N	PRESENT	0
613790	613307	20090E	PARTICIPANT	\N	PRESENT	0
613791	613307	20026V	PARTICIPANT	\N	PRESENT	0
613792	613307	19347U	PARTICIPANT	\N	PRESENT	0
613793	613307	01043Q	PARTICIPANT	\N	PRESENT	0
613794	613307	14053L	PARTICIPANT	\N	PRESENT	0
613795	613307	10015M	PARTICIPANT	\N	PRESENT	0
613796	613307	14105F	PARTICIPANT	\N	PRESENT	0
613797	613307	19715Y	PARTICIPANT	\N	PRESENT	0
613799	613307	20104S	PARTICIPANT	\N	PRESENT	0
613800	613307	20056C	PARTICIPANT	\N	PRESENT	0
613801	613307	20052X	PARTICIPANT	\N	PRESENT	0
613804	613307	11012A	PARTICIPANT	\N	PRESENT	0
613805	613307	08056B	PARTICIPANT	\N	PRESENT	0
613806	613307	19723Y	PARTICIPANT	\N	PRESENT	0
613807	613307	01024M	PARTICIPANT	\N	PRESENT	0
613808	613307	14253S	PARTICIPANT	\N	PRESENT	0
613809	613307	04092N	PARTICIPANT	\N	PRESENT	0
613810	613307	14109K	PARTICIPANT	\N	PRESENT	0
613811	613307	19251M	PARTICIPANT	\N	PRESENT	0
613818	613307	19383Y	PARTICIPANT	\N	PRESENT	0
613813	613307	11097X	PARTICIPANT	\N	PRESENT	0
613814	613307	14123H	PARTICIPANT	\N	PRESENT	0
613817	613307	20082E	PARTICIPANT	\N	PRESENT	0
613819	613307	01025N	PARTICIPANT	\N	PRESENT	0
613820	613307	14231L	PARTICIPANT	\N	PRESENT	0
613826	612992	20132W	PARTICIPANT	\N	PRESENT	0
613827	612992	19533U	PRESIDENT	0	PRESENT	0
613828	612992	19798U	PARTICIPANT	\N	PRESENT	0
613829	612992	19820Y	PARTICIPANT	\N	PRESENT	0
613765	613307	08028W	PARTICIPANT	\N	PRESENT	0
613830	612992	19693L	PARTICIPANT	\N	PRESENT	0
613831	612992	19599P	PARTICIPANT	\N	PRESENT	0
613832	612992	19954N	PARTICIPANT	\N	PRESENT	0
613833	612992	20264J	PARTICIPANT	\N	PRESENT	0
613834	612992	14267Y	PARTICIPANT	\N	PRESENT	0
613835	612992	20114U	PARTICIPANT	\N	PRESENT	0
613836	612992	14215L	PARTICIPANT	\N	PRESENT	0
613837	612992	14207L	PARTICIPANT	\N	PRESENT	0
613838	612992	20124W	PARTICIPANT	\N	PRESENT	0
613839	612992	17023S	PARTICIPANT	\N	PRESENT	0
613845	613307	14173T	PARTICIPANT	\N	PRESENT	0
613846	613307	20142Y	PARTICIPANT	\N	PRESENT	0
613847	613307	20054A	PARTICIPANT	\N	PRESENT	0
617262	616391	14026U	PARTICIPANT	\N	PRESENT	0
617263	616391	14059S	PARTICIPANT	\N	PRESENT	0
617264	616391	14331P	PARTICIPANT	\N	PRESENT	0
617265	616391	08060W	PARTICIPANT	\N	PRESENT	0
617266	616391	20032T	PARTICIPANT	\N	PRESENT	0
617267	616391	18083K	PARTICIPANT	\N	PRESENT	0
617268	616391	20028X	PARTICIPANT	\N	PRESENT	0
617269	616391	20046A	PARTICIPANT	\N	PRESENT	0
617270	616391	14231L	PARTICIPANT	\N	PRESENT	0
617271	616391	19866P	PARTICIPANT	\N	PRESENT	0
617272	616391	19747H	PARTICIPANT	\N	PRESENT	0
617273	616391	11101A	PARTICIPANT	\N	PRESENT	0
617274	616391	14173T	PARTICIPANT	\N	PRESENT	0
617275	616391	07029T	PARTICIPANT	\N	PRESENT	0
617276	616391	14073Q	PARTICIPANT	\N	PRESENT	0
617277	616391	17229F	PARTICIPANT	\N	PRESENT	0
617278	616391	11066Q	PARTICIPANT	\N	PRESENT	0
617279	616391	19387D	PARTICIPANT	\N	PRESENT	0
617280	616391	11033F	PARTICIPANT	\N	PRESENT	0
617281	616391	14221J	PARTICIPANT	\N	PRESENT	0
617282	616391	19782L	PARTICIPANT	\N	PRESENT	0
617283	616391	19349W	PARTICIPANT	\N	PRESENT	0
617284	616391	19479G	PARTICIPANT	\N	PRESENT	0
617285	616391	20130U	PARTICIPANT	\N	PRESENT	0
617286	616391	08045X	PARTICIPANT	\N	PRESENT	0
617287	616391	14151M	PARTICIPANT	\N	PRESENT	0
617288	616391	20082E	PARTICIPANT	\N	PRESENT	0
617289	616391	20088L	PARTICIPANT	\N	PRESENT	0
617290	616391	12041X	PARTICIPANT	\N	PRESENT	0
617291	616391	20030R	PARTICIPANT	\N	PRESENT	0
617292	616391	19669L	PARTICIPANT	\N	PRESENT	0
617293	616391	19758L	PARTICIPANT	\N	PRESENT	0
617294	616391	20264J	PARTICIPANT	\N	PRESENT	0
617295	616391	11012A	PARTICIPANT	\N	PRESENT	0
617296	616391	14207L	PARTICIPANT	\N	PRESENT	0
617297	616391	11054L	PARTICIPANT	\N	PRESENT	0
617298	616391	19333N	PARTICIPANT	\N	PRESENT	0
617299	616391	19549D	PARTICIPANT	\N	PRESENT	0
617300	616391	01028R	PARTICIPANT	\N	PRESENT	0
617301	616391	14225N	PARTICIPANT	\N	PRESENT	0
617302	616391	19599P	PARTICIPANT	\N	PRESENT	0
617303	616391	04059M	PARTICIPANT	\N	PRESENT	0
617304	616391	11027H	PARTICIPANT	\N	PRESENT	0
617305	616391	11045K	PARTICIPANT	\N	PRESENT	0
617306	616391	14229S	PARTICIPANT	\N	PRESENT	0
617307	616391	11041F	PARTICIPANT	\N	PRESENT	0
617308	616391	19820Y	PARTICIPANT	\N	PRESENT	0
617309	616391	19647E	PARTICIPANT	\N	PRESENT	0
617310	616391	20114U	PARTICIPANT	\N	PRESENT	0
617311	616391	19251M	PARTICIPANT	\N	PRESENT	0
617312	616391	12028B	PARTICIPANT	\N	PRESENT	0
617313	616391	19503N	PARTICIPANT	\N	PRESENT	0
617314	616391	18193Q	PARTICIPANT	\N	PRESENT	0
617315	616391	20070A	PARTICIPANT	\N	PRESENT	0
617316	616391	11067R	PARTICIPANT	\N	PRESENT	0
617317	616391	19531S	PARTICIPANT	\N	PRESENT	0
617318	616391	17637T	PARTICIPANT	\N	PRESENT	0
617319	616391	19527W	PARTICIPANT	\N	PRESENT	0
617320	616391	19631V	PARTICIPANT	\N	PRESENT	0
617321	616391	20058E	PARTICIPANT	\N	PRESENT	0
617322	616391	14038Y	PARTICIPANT	\N	PRESENT	0
617323	616391	20044X	PARTICIPANT	\N	PRESENT	0
617324	616391	11031D	PARTICIPANT	\N	PRESENT	0
617325	616391	11056N	PARTICIPANT	\N	PRESENT	0
617326	616391	04085P	PARTICIPANT	\N	PRESENT	0
617327	616391	19723Y	PARTICIPANT	\N	PRESENT	0
617328	616391	19593H	PARTICIPANT	\N	PRESENT	0
617329	616391	20102Q	PARTICIPANT	\N	PRESENT	0
617330	616391	20034V	PARTICIPANT	\N	PRESENT	0
617331	616391	19447X	PARTICIPANT	\N	PRESENT	0
617332	616391	19687N	PARTICIPANT	\N	PRESENT	0
617333	616391	19573D	PARTICIPANT	\N	PRESENT	0
617334	616391	20266L	PARTICIPANT	\N	PRESENT	0
617335	616391	19467C	PARTICIPANT	\N	PRESENT	0
617336	616391	20100N	PARTICIPANT	\N	PRESENT	0
617337	616391	20064C	PARTICIPANT	\N	PRESENT	0
617338	616391	17367Q	PARTICIPANT	\N	PRESENT	0
617339	616391	20086J	PARTICIPANT	\N	PRESENT	0
617340	616391	20060X	PARTICIPANT	\N	PRESENT	0
617341	616391	19575F	PARTICIPANT	\N	PRESENT	0
617342	616391	19443T	PARTICIPANT	\N	PRESENT	0
617343	616391	20018V	PARTICIPANT	\N	PRESENT	0
617344	616391	20056C	PARTICIPANT	\N	PRESENT	0
617345	616391	08061X	PARTICIPANT	\N	PRESENT	0
617346	616391	20106U	PARTICIPANT	\N	PRESENT	0
617347	616391	20096L	PARTICIPANT	\N	PRESENT	0
617348	616391	20128B	PARTICIPANT	\N	PRESENT	0
617349	616391	19673G	PARTICIPANT	\N	PRESENT	0
617350	616391	04045F	PARTICIPANT	\N	PRESENT	0
617351	616391	11072N	PARTICIPANT	\N	PRESENT	0
617352	616391	19637C	PARTICIPANT	\N	PRESENT	0
617353	616391	20026V	PARTICIPANT	\N	PRESENT	0
617354	616391	19591F	PARTICIPANT	\N	PRESENT	0
617355	616391	19057M	PARTICIPANT	\N	PRESENT	0
617356	616391	14031R	PARTICIPANT	\N	PRESENT	0
617357	616391	19525U	PARTICIPANT	\N	PRESENT	0
617361	616391	20174H	PARTICIPANT	\N	PRESENT	0
617359	616391	19741B	PARTICIPANT	\N	PRESENT	0
617360	616391	19954N	PARTICIPANT	\N	PRESENT	0
617362	616391	20140W	PARTICIPANT	\N	PRESENT	0
617363	616391	19301E	PARTICIPANT	\N	PRESENT	0
617364	616391	92040Q	PARTICIPANT	\N	PRESENT	0
617365	616391	11083R	PARTICIPANT	\N	PRESENT	0
617366	616391	20094J	PARTICIPANT	\N	PRESENT	0
617367	616391	08015R	PARTICIPANT	\N	PRESENT	0
617368	616391	14133K	PARTICIPANT	\N	PRESENT	0
617369	616391	20134Y	PARTICIPANT	\N	PRESENT	0
617370	616391	20092G	PARTICIPANT	\N	PRESENT	0
617371	616391	20104S	PARTICIPANT	\N	PRESENT	0
617372	616391	19729F	PARTICIPANT	\N	PRESENT	0
617373	616391	04071H	PARTICIPANT	\N	PRESENT	0
617374	616391	14111D	PARTICIPANT	\N	PRESENT	0
617375	616391	04057K	PARTICIPANT	\N	PRESENT	0
617376	616391	14251Q	PARTICIPANT	\N	PRESENT	0
617377	616391	19705W	PARTICIPANT	\N	PRESENT	0
617378	616391	19545Y	PARTICIPANT	\N	PRESENT	0
617379	616391	14053L	PARTICIPANT	\N	PRESENT	0
617380	616391	20050V	PARTICIPANT	\N	PRESENT	0
617381	616391	19563B	PARTICIPANT	\N	PRESENT	0
617382	616391	14253S	PARTICIPANT	\N	PRESENT	0
617383	616391	11064N	PARTICIPANT	\N	PRESENT	0
617384	616391	19707Y	PARTICIPANT	\N	PRESENT	0
617385	616391	20132W	PARTICIPANT	\N	PRESENT	0
617386	616391	20072C	PARTICIPANT	\N	PRESENT	0
617387	616391	17737W	PARTICIPANT	\N	PRESENT	0
617388	616391	14107H	PARTICIPANT	\N	PRESENT	0
617389	616391	20084G	PARTICIPANT	\N	PRESENT	0
617390	616391	14259Y	PARTICIPANT	\N	PRESENT	0
617391	616391	20136B	PARTICIPANT	\N	PRESENT	0
617392	616391	19629C	PARTICIPANT	\N	PRESENT	0
617393	616391	08047A	PARTICIPANT	\N	PRESENT	0
617394	616391	20024T	PARTICIPANT	\N	PRESENT	0
617395	616391	19681G	PARTICIPANT	\N	PRESENT	0
617396	616391	20138D	PARTICIPANT	\N	PRESENT	0
617397	616391	20172F	PARTICIPANT	\N	PRESENT	0
617398	616391	14147R	PARTICIPANT	\N	PRESENT	0
617399	616391	20052X	PARTICIPANT	\N	PRESENT	0
617400	616391	20042V	PARTICIPANT	\N	PRESENT	0
617401	616391	19699S	PARTICIPANT	\N	PRESENT	0
617402	616391	19441R	PARTICIPANT	\N	PRESENT	0
617403	616391	19735D	PARTICIPANT	\N	PRESENT	0
617404	616391	14219Q	PARTICIPANT	\N	PRESENT	0
617405	616391	20124W	PARTICIPANT	\N	PRESENT	0
617406	616391	19713W	PARTICIPANT	\N	PRESENT	0
617407	616391	20126Y	PARTICIPANT	\N	PRESENT	0
617408	616391	14042U	PARTICIPANT	\N	PRESENT	0
617409	616391	20286Q	PARTICIPANT	\N	PRESENT	0
617410	616391	19739H	PARTICIPANT	\N	PRESENT	0
617411	616391	20054A	PARTICIPANT	\N	PRESENT	0
617412	616391	16685X	PARTICIPANT	\N	PRESENT	0
617413	616391	19367Y	PARTICIPANT	\N	PRESENT	0
617414	616391	14205J	PARTICIPANT	\N	PRESENT	0
617415	616391	19621T	PARTICIPANT	\N	PRESENT	0
617416	616391	11053K	PARTICIPANT	\N	PRESENT	0
617417	616391	08009T	PARTICIPANT	\N	PRESENT	0
617418	616391	20152B	PARTICIPANT	\N	PRESENT	0
617419	616391	19369B	PARTICIPANT	\N	PRESENT	0
617420	616391	19611R	PARTICIPANT	\N	PRESENT	0
617421	616391	20020P	PARTICIPANT	\N	PRESENT	0
617422	616391	01034P	PARTICIPANT	\N	PRESENT	0
617423	616391	19762G	PARTICIPANT	\N	PRESENT	0
603356	603355	11048N	PARTICIPANT	\N	PRESENT	0
603358	603357	20070A	PARTICIPANT	\N	PRESENT	0
603359	603357	11110B	PARTICIPANT	\N	PRESENT	0
603361	603360	20050V	PARTICIPANT	\N	PRESENT	0
603364	603362	20050V	PARTICIPANT	\N	PRESENT	0
603370	603369	20086J	PARTICIPANT	\N	PRESENT	0
603375	603374	14073Q	PARTICIPANT	\N	PRESENT	0
603376	603374	20264J	PARTICIPANT	\N	PRESENT	0
603377	603374	20084G	PARTICIPANT	\N	PRESENT	0
606393	601486	17023S	PARTICIPANT	\N	PRESENT	0
606396	601489	19717B	PRESIDENT	0	PRESENT	0
606397	601489	20148F	PARTICIPANT	\N	PRESENT	0
606398	601489	14059S	PARTICIPANT	\N	EXCUSE	0
606399	601489	14147R	PARTICIPANT	\N	PRESENT	1
606400	601489	19691J	PARTICIPANT	\N	PRESENT	1
607175	607171	19631V	PARTICIPANT	\N	PRESENT	0
607176	607171	01043Q	PARTICIPANT	\N	PRESENT	0
607177	607170	01043Q	PARTICIPANT	\N	PRESENT	0
608386	602477	14105F	PARTICIPANT	\N	PRESENT	0
608387	602477	19467C	PARTICIPANT	\N	PRESENT	0
608388	602477	19762G	PARTICIPANT	\N	PRESENT	0
608396	602477	20108W	PARTICIPANT	\N	EXCUSE	0
608405	602477	20094J	PARTICIPANT	\N	PRESENT	0
608424	602477	14083S	PARTICIPANT	\N	PRESENT	0
608440	602477	20048C	PARTICIPANT	\N	PRESENT	0
610587	603495	19715Y	PARTICIPANT	\N	EXCUSE	0
610588	603495	07029T	PARTICIPANT	\N	EXCUSE	0
610589	603495	20098N	PARTICIPANT	\N	EXCUSE	0
610922	610669	19701S	PARTICIPANT	\N	PRESENT	0
610931	610669	14231L	PARTICIPANT	\N	PRESENT	0
610932	610669	19563B	PARTICIPANT	\N	PRESENT	0
610935	610669	19711U	PARTICIPANT	\N	PRESENT	0
610938	610669	19441R	PARTICIPANT	\N	PRESENT	0
610972	610669	08034U	PARTICIPANT	\N	PRESENT	0
612769	610754	99004R	PARTICIPANT	\N	PRESENT	0
612770	610754	19760E	PARTICIPANT	\N	PRESENT	0
612771	610754	11056N	PARTICIPANT	\N	PRESENT	0
612772	610754	19713W	PARTICIPANT	\N	PRESENT	0
612773	610754	19719D	PARTICIPANT	\N	PRESENT	0
612774	610754	08045X	PARTICIPANT	\N	PRESENT	0
612775	610754	19697Q	PARTICIPANT	\N	PRESENT	0
612776	610754	14195A	PARTICIPANT	\N	PRESENT	0
612777	610754	20118Y	PARTICIPANT	\N	PRESENT	0
612778	610754	20092G	PARTICIPANT	\N	PRESENT	0
612779	610754	19507S	PARTICIPANT	\N	PRESENT	0
612781	612780	20152B	PARTICIPANT	\N	PRESENT	0
612782	612780	19573D	PARTICIPANT	\N	PRESENT	0
612783	610754	19413M	PARTICIPANT	\N	PRESENT	0
612784	610754	14257W	PARTICIPANT	\N	PRESENT	0
612785	610754	20028X	PARTICIPANT	\N	PRESENT	0
612786	610754	20040T	PARTICIPANT	\N	PRESENT	0
612787	610754	04085P	PARTICIPANT	\N	PRESENT	0
612788	610754	19695N	PARTICIPANT	\N	PRESENT	0
612789	610754	11040E	PARTICIPANT	\N	PRESENT	0
612790	610754	19758L	PARTICIPANT	\N	PRESENT	0
612791	610754	20046A	PARTICIPANT	\N	PRESENT	0
612792	610754	20112S	PARTICIPANT	\N	PRESENT	0
612795	610754	11097X	PARTICIPANT	\N	PRESENT	0
612797	610754	20024T	PARTICIPANT	\N	PRESENT	0
612798	610754	19399H	PARTICIPANT	\N	PRESENT	0
612799	610754	14189C	PARTICIPANT	\N	PRESENT	0
612800	610754	14033T	PARTICIPANT	\N	PRESENT	0
612801	610754	10006L	PARTICIPANT	\N	PRESENT	0
612802	610840	18083K	PRESIDENT	0	PRESENT	0
612803	610840	19549D	PARTICIPANT	\N	PRESENT	0
612804	610840	20266L	PARTICIPANT	\N	PRESENT	0
612805	610840	17965H	PARTICIPANT	\N	PRESENT	0
612806	610840	11101A	PARTICIPANT	\N	EXCUSE	0
612807	610754	14147R	PARTICIPANT	\N	PRESENT	0
612808	610754	20032T	PARTICIPANT	\N	PRESENT	0
612809	610754	19443T	PARTICIPANT	\N	PRESENT	0
612810	610754	20126Y	PARTICIPANT	\N	PRESENT	0
612811	610754	14207L	PARTICIPANT	\N	PRESENT	0
612827	610840	19701S	PARTICIPANT	\N	PRESENT	0
612828	610754	11031D	PARTICIPANT	\N	PRESENT	0
612829	610754	19711U	PARTICIPANT	\N	PRESENT	0
612830	610754	17779H	PARTICIPANT	\N	PRESENT	0
612831	610536	20100N	PARTICIPANT	\N	PRESENT	0
612832	610536	19467C	PARTICIPANT	\N	PRESENT	0
612833	610536	20062A	PARTICIPANT	\N	PRESENT	0
612834	610536	04035D	PARTICIPANT	\N	PRESENT	0
612835	610536	14357A	PARTICIPANT	\N	PRESENT	0
612836	610536	11083R	PARTICIPANT	\N	PRESENT	0
612837	610536	11090Q	PRESIDENT	0	PRESENT	0
612838	610536	19369B	PARTICIPANT	\N	PRESENT	0
612839	610536	20094J	PARTICIPANT	\N	PRESENT	0
612840	610536	19747H	PARTICIPANT	\N	PRESENT	0
612841	610536	20104S	PARTICIPANT	\N	PRESENT	0
612842	610536	19631V	PARTICIPANT	\N	PRESENT	0
612843	610754	19563B	PARTICIPANT	\N	PRESENT	0
612844	610754	11012A	PARTICIPANT	\N	PRESENT	0
612845	610536	20082E	PARTICIPANT	\N	PRESENT	0
612846	610754	20030R	PARTICIPANT	\N	PRESENT	0
612847	610754	14215L	PARTICIPANT	\N	PRESENT	0
612848	610754	19687N	PARTICIPANT	\N	PRESENT	0
612849	610754	20022R	PARTICIPANT	\N	PRESENT	0
612850	610754	11054L	PARTICIPANT	\N	PRESENT	0
612862	610754	20152B	PARTICIPANT	\N	PRESENT	0
612864	610754	20130U	PARTICIPANT	\N	PRESENT	0
612865	610536	19701S	PARTICIPANT	\N	PRESENT	0
612866	610754	12041X	PARTICIPANT	\N	PRESENT	0
612867	610754	14069U	PARTICIPANT	\N	PRESENT	0
612868	610754	19467C	PARTICIPANT	\N	PRESENT	0
612869	610754	19573D	PARTICIPANT	\N	PRESENT	0
612870	610754	19503N	PARTICIPANT	\N	PRESENT	0
612871	610754	17737W	PARTICIPANT	\N	PRESENT	0
612872	610754	14357A	PARTICIPANT	\N	PRESENT	0
612873	610754	11033F	PARTICIPANT	\N	PRESENT	0
612892	610754	14255U	PARTICIPANT	\N	PRESENT	0
612893	610754	19295A	PARTICIPANT	\N	PRESENT	0
612894	610754	19565D	PARTICIPANT	\N	PRESENT	0
612895	610754	20078J	PARTICIPANT	\N	PRESENT	0
612947	610755	99004R	PARTICIPANT	\N	PRESENT	0
612948	610755	12041X	PARTICIPANT	\N	PRESENT	0
612949	610755	19295A	PARTICIPANT	\N	PRESENT	0
612984	610755	20132W	PARTICIPANT	\N	PRESENT	0
612951	610755	19551W	PARTICIPANT	\N	PRESENT	0
612952	610755	20030R	PARTICIPANT	\N	PRESENT	0
612953	610755	11054L	PARTICIPANT	\N	PRESENT	0
612954	610755	08045X	PARTICIPANT	\N	PRESENT	0
612955	610755	17779H	PARTICIPANT	\N	PRESENT	0
612956	610755	20130U	PARTICIPANT	\N	PRESENT	0
612957	610755	20092G	PARTICIPANT	\N	PRESENT	0
612958	610755	11033F	PARTICIPANT	\N	PRESENT	0
612959	610755	14249W	PARTICIPANT	\N	PRESENT	0
612960	610755	19719D	PARTICIPANT	\N	PRESENT	0
612961	610755	14195A	PARTICIPANT	\N	PRESENT	0
612962	610755	14255U	PARTICIPANT	\N	PRESENT	0
612975	610755	14357A	PARTICIPANT	\N	PRESENT	0
612964	610755	19695N	PARTICIPANT	\N	PRESENT	0
612965	610755	11056N	PARTICIPANT	\N	PRESENT	0
612966	610755	19760E	PARTICIPANT	\N	PRESENT	0
612967	610755	11031D	PARTICIPANT	\N	PRESENT	0
612968	610755	19758L	PARTICIPANT	\N	PRESENT	0
612969	610755	19687N	PARTICIPANT	\N	PRESENT	0
612970	610755	04085P	PARTICIPANT	\N	PRESENT	0
612971	610755	19565D	PARTICIPANT	\N	PRESENT	0
612972	610755	20046A	PARTICIPANT	\N	PRESENT	0
612973	610755	20040T	PARTICIPANT	\N	PRESENT	0
612974	610755	20090E	PARTICIPANT	\N	PRESENT	0
612976	610755	20152B	PARTICIPANT	\N	PRESENT	0
612977	610755	19711U	PARTICIPANT	\N	PRESENT	0
612978	610755	17737W	PARTICIPANT	\N	PRESENT	0
612979	610755	20078J	PARTICIPANT	\N	PRESENT	0
612980	610755	19399H	PARTICIPANT	\N	PRESENT	0
612981	610755	19563B	PARTICIPANT	\N	PRESENT	0
612982	610755	19443T	PARTICIPANT	\N	PRESENT	0
612983	610755	11012A	PARTICIPANT	\N	PRESENT	0
612985	610755	18083K	PARTICIPANT	\N	PRESENT	0
612986	610755	20024T	PARTICIPANT	\N	PRESENT	0
612987	610755	14217N	PARTICIPANT	\N	PRESENT	0
612988	610755	11097X	PARTICIPANT	\N	PRESENT	0
612989	612794	20074E	PARTICIPANT	\N	EXCUSE	0
612993	610755	11085T	PARTICIPANT	\N	PRESENT	0
612994	610755	14038Y	PARTICIPANT	\N	PRESENT	0
612995	610755	20112S	PARTICIPANT	\N	PRESENT	0
612996	610755	11045K	PARTICIPANT	\N	PRESENT	0
612998	610755	19713W	PARTICIPANT	\N	PRESENT	0
612999	610755	14069U	PARTICIPANT	\N	PRESENT	0
618826	618326	11109J	PARTICIPANT	\N	PRESENT	0
619639	618370	20090E	PARTICIPANT	\N	PRESENT	0
619640	618370	19798U	PARTICIPANT	\N	PRESENT	0
619641	618370	11097X	PARTICIPANT	\N	PRESENT	0
619642	618370	20040T	PARTICIPANT	\N	PRESENT	0
619643	618370	17965H	PARTICIPANT	\N	PRESENT	0
619644	618370	19691J	PARTICIPANT	\N	PRESENT	0
619645	618370	19715Y	PARTICIPANT	\N	PRESENT	0
619646	618370	18193Q	PARTICIPANT	\N	PRESENT	0
619647	618370	14223L	PARTICIPANT	\N	PRESENT	0
619648	618370	19703U	PARTICIPANT	\N	PRESENT	0
619649	618370	19679N	PARTICIPANT	\N	PRESENT	0
619650	618370	14042U	PARTICIPANT	\N	PRESENT	0
619651	618370	14195A	PARTICIPANT	\N	PRESENT	0
619652	618370	14213J	PARTICIPANT	\N	PRESENT	0
619653	618370	19367Y	PARTICIPANT	\N	PRESENT	0
619654	618370	14071N	PARTICIPANT	\N	PRESENT	0
619655	618370	14217N	PARTICIPANT	\N	PRESENT	0
619656	618370	10006L	PRESIDENT	0	PRESENT	0
619657	618364	20086J	PARTICIPANT	\N	PRESENT	0
619658	618364	14331P	PARTICIPANT	\N	PRESENT	0
619659	618364	19711U	PARTICIPANT	\N	PRESENT	0
619660	618364	19531S	PARTICIPANT	\N	PRESENT	0
619661	618364	01057W	PARTICIPANT	\N	PRESENT	0
619662	618364	20080C	PARTICIPANT	\N	PRESENT	0
619663	618364	11074Q	PARTICIPANT	\N	PRESENT	0
619664	618364	20044X	PARTICIPANT	\N	PRESENT	0
619665	618364	14225N	PRESIDENT	0	PRESENT	0
619666	618364	11040E	PARTICIPANT	\N	PRESENT	0
619667	618364	14083S	PARTICIPANT	\N	PRESENT	0
619668	618364	20070A	PARTICIPANT	\N	PRESENT	0
619669	618364	14253S	PARTICIPANT	\N	PRESENT	0
619670	618364	99004R	PARTICIPANT	\N	PRESENT	0
619671	618364	20116W	PARTICIPANT	\N	PRESENT	0
619672	618364	19335Q	PARTICIPANT	\N	PRESENT	0
619673	618364	19762G	PARTICIPANT	\N	PRESENT	0
619674	618364	19479G	PARTICIPANT	\N	PRESENT	0
619675	618370	11067R	PARTICIPANT	\N	PRESENT	0
619676	618370	19760E	PARTICIPANT	\N	PRESENT	0
619677	618370	20248J	PARTICIPANT	\N	EXCUSE	0
619678	618364	11048N	PARTICIPANT	\N	PRESENT	0
619679	618364	19741B	PARTICIPANT	\N	PRESENT	0
619680	618364	01048V	PARTICIPANT	\N	PRESENT	0
619681	618364	14189C	PARTICIPANT	\N	PRESENT	0
619682	618364	07029T	PARTICIPANT	\N	PRESENT	0
619683	616408	18083K	PARTICIPANT	\N	PRESENT	0
619684	616408	20136B	PARTICIPANT	\N	PRESENT	0
619685	616408	14031R	PRESIDENT	0	PRESENT	0
619686	616408	19826F	PARTICIPANT	\N	PRESENT	0
619687	616408	19599P	PARTICIPANT	\N	PRESENT	0
619688	616408	20024T	PARTICIPANT	\N	PRESENT	0
619689	618364	11053K	PARTICIPANT	\N	PRESENT	0
619690	616408	20032T	PARTICIPANT	\N	PRESENT	0
619691	616408	20038A	PARTICIPANT	\N	PRESENT	0
619692	616408	19387D	PARTICIPANT	\N	PRESENT	0
619693	616408	20102Q	PARTICIPANT	\N	PRESENT	0
619694	616408	20096L	PARTICIPANT	\N	PRESENT	0
619695	616408	17229F	PARTICIPANT	\N	PRESENT	0
619696	616408	20100N	PARTICIPANT	\N	PRESENT	0
619697	616408	08060W	PARTICIPANT	\N	PRESENT	0
619698	616408	11101A	PARTICIPANT	\N	PRESENT	0
619699	616408	19503N	PARTICIPANT	\N	PRESENT	0
619700	616408	17367Q	PARTICIPANT	\N	PRESENT	0
619701	616408	20076G	PARTICIPANT	\N	PRESENT	0
619702	616408	19619A	PARTICIPANT	\N	PRESENT	0
619703	616408	11065P	PARTICIPANT	\N	PRESENT	1
619704	616408	19637C	PARTICIPANT	\N	PRESENT	1
619705	616408	19549D	PARTICIPANT	\N	PRESENT	0
619706	616408	20046A	PARTICIPANT	\N	EXCUSE	0
619708	616408	20118Y	PARTICIPANT	\N	PRESENT	0
619709	616408	14219Q	PARTICIPANT	\N	EXCUSE	0
619710	616408	19251M	PARTICIPANT	\N	EXCUSE	0
619715	616408	14237S	PARTICIPANT	\N	PRESENT	0
619717	616408	19701S	PARTICIPANT	\N	PRESENT	0
619718	618370	19569H	PARTICIPANT	\N	PRESENT	0
619719	618370	19415P	PARTICIPANT	\N	PRESENT	0
619720	618370	11031D	PARTICIPANT	\N	PRESENT	0
619721	618370	19683J	PARTICIPANT	\N	PRESENT	0
619722	618370	04092N	PARTICIPANT	\N	PRESENT	0
619723	618370	19713W	PARTICIPANT	\N	PRESENT	0
619724	618370	11045K	PARTICIPANT	\N	PRESENT	0
619725	618370	19723Y	PARTICIPANT	\N	PRESENT	0
619741	616408	19820Y	PARTICIPANT	\N	PRESENT	0
619742	618090	86034E	PARTICIPANT	\N	PRESENT	0
619743	618361	14053L	PARTICIPANT	\N	PRESENT	0
619744	618361	14111D	PARTICIPANT	\N	PRESENT	0
619745	618361	19649G	PARTICIPANT	\N	PRESENT	0
619746	618361	20074E	PARTICIPANT	\N	PRESENT	0
619747	618361	10015M	PARTICIPANT	\N	PRESENT	0
619748	618361	19581D	PARTICIPANT	\N	PRESENT	0
619749	618361	04047H	PRESIDENT	0	PRESENT	0
619750	618361	19673G	PARTICIPANT	\N	PRESENT	0
619751	618361	19675J	PARTICIPANT	\N	PRESENT	0
619752	618361	01028R	PARTICIPANT	\N	PRESENT	0
619753	618361	14231L	PARTICIPANT	\N	PRESENT	0
619754	618361	19447X	PARTICIPANT	\N	PRESENT	0
619755	618361	95063L	PARTICIPANT	\N	PRESENT	0
619756	618361	20110Q	PARTICIPANT	\N	PRESENT	0
619757	618361	14147R	PARTICIPANT	\N	PRESENT	0
619758	618361	14179A	PARTICIPANT	\N	PRESENT	0
619759	618361	14151M	PARTICIPANT	\N	PRESENT	0
619760	618361	20114U	PARTICIPANT	\N	PRESENT	0
619761	618373	19383Y	PARTICIPANT	\N	PRESENT	0
619762	618373	19768N	PARTICIPANT	\N	PRESENT	0
619763	618373	20088L	PARTICIPANT	\N	PRESENT	1
619764	618373	20092G	PARTICIPANT	\N	PRESENT	0
619765	618373	14357A	PARTICIPANT	\N	PRESENT	0
619766	618373	19441R	PARTICIPANT	\N	PRESENT	0
619767	618373	20078J	PARTICIPANT	\N	PRESENT	0
619768	618373	19413M	PARTICIPANT	\N	PRESENT	0
619769	618373	20082E	PARTICIPANT	\N	PRESENT	0
619770	618373	19866P	PARTICIPANT	\N	PRESENT	0
619771	618373	20104S	PARTICIPANT	\N	PRESENT	0
619772	618373	19705W	PARTICIPANT	\N	PRESENT	1
619773	618373	19707Y	PARTICIPANT	\N	PRESENT	1
619774	618373	08015R	PARTICIPANT	\N	PRESENT	0
619775	618373	19575F	PARTICIPANT	\N	PRESENT	0
619776	618373	20018V	PARTICIPANT	\N	PRESENT	1
619777	618373	19511N	PARTICIPANT	\N	PRESENT	0
619778	618373	19563B	PARTICIPANT	\N	PRESENT	0
619779	618373	14329V	PARTICIPANT	\N	PRESENT	0
619780	618373	20028X	PARTICIPANT	\N	PRESENT	0
619781	618373	14038Y	PARTICIPANT	\N	PRESENT	0
619782	618373	20030R	PARTICIPANT	\N	PRESENT	0
619783	618373	19467C	PARTICIPANT	\N	PRESENT	0
619784	618373	14187A	PARTICIPANT	\N	PRESENT	0
619785	618373	20144B	PARTICIPANT	\N	PRESENT	0
619786	618373	19695N	PARTICIPANT	\N	PRESENT	0
619787	618373	11090Q	PRESIDENT	0	PRESENT	0
619788	618373	14033T	PARTICIPANT	\N	PRESENT	0
619789	618373	01025N	PARTICIPANT	\N	PRESENT	1
619790	618373	20054A	PARTICIPANT	\N	PRESENT	0
619791	618373	20174H	PARTICIPANT	\N	PRESENT	1
619792	618373	14205J	PARTICIPANT	\N	PRESENT	0
619793	618373	20060X	PARTICIPANT	\N	PRESENT	0
619794	618373	20062A	PARTICIPANT	\N	PRESENT	0
619795	618373	14251Q	PARTICIPANT	\N	PRESENT	1
619796	618373	19507S	PARTICIPANT	\N	PRESENT	0
619797	618373	20286Q	PARTICIPANT	\N	PRESENT	0
619798	618373	19747H	PARTICIPANT	\N	PRESENT	0
619799	618373	14207L	PARTICIPANT	\N	PRESENT	0
619800	618373	14257W	PARTICIPANT	\N	PRESENT	0
619801	618360	14053L	PARTICIPANT	\N	PRESENT	0
619802	618360	14111D	PARTICIPANT	\N	PRESENT	0
619803	618360	19649G	PARTICIPANT	\N	PRESENT	0
619804	618360	20074E	PARTICIPANT	\N	PRESENT	0
619805	618360	10015M	PARTICIPANT	\N	PRESENT	0
619806	618360	19543W	PARTICIPANT	\N	PRESENT	0
619807	618360	19581D	PARTICIPANT	\N	PRESENT	0
619808	618360	04047H	PRESIDENT	0	PRESENT	0
619809	618360	19673G	PARTICIPANT	\N	PRESENT	0
619810	618360	19675J	PARTICIPANT	\N	PRESENT	0
619811	618360	01028R	PARTICIPANT	\N	PRESENT	0
619812	618360	14231L	PARTICIPANT	\N	PRESENT	0
619813	618360	19447X	PARTICIPANT	\N	PRESENT	0
619814	618360	05008E	PARTICIPANT	\N	PRESENT	0
619815	618360	95063L	PARTICIPANT	\N	PRESENT	0
619816	618360	20110Q	PARTICIPANT	\N	PRESENT	0
619817	618360	14147R	PARTICIPANT	\N	PRESENT	0
619818	618360	14179A	PARTICIPANT	\N	PRESENT	0
619819	618360	14151M	PARTICIPANT	\N	PRESENT	0
599133	598018	14327T	PARTICIPANT	\N	PRESENT	0
599134	598018	08034U	PRESIDENT	0	PRESENT	0
599135	598018	20044X	PARTICIPANT	\N	PRESENT	0
599136	598018	14173T	PARTICIPANT	\N	PRESENT	0
599137	597713	14053L	PARTICIPANT	\N	PRESENT	0
599138	597713	20110Q	PARTICIPANT	\N	PRESENT	0
599139	597713	14151M	PARTICIPANT	\N	PRESENT	0
599140	597713	05008E	PARTICIPANT	\N	PRESENT	0
599141	597713	11056N	PARTICIPANT	\N	PRESENT	0
599142	598018	11040E	PARTICIPANT	\N	PRESENT	0
599143	598018	14331P	PARTICIPANT	\N	PRESENT	0
599144	598018	14083S	PARTICIPANT	\N	PRESENT	0
599145	598018	11048N	PARTICIPANT	\N	PRESENT	0
599146	598018	19711U	PARTICIPANT	\N	PRESENT	0
599147	598018	19689Q	PARTICIPANT	\N	PRESENT	0
599148	598018	20080C	PARTICIPANT	\N	PRESENT	0
599149	598018	14121F	PARTICIPANT	\N	PRESENT	0
599150	597713	19725B	PARTICIPANT	\N	PRESENT	0
599151	597713	14147R	PARTICIPANT	\N	PRESENT	0
599152	597713	19749K	PARTICIPANT	\N	PRESENT	0
599153	597713	11033F	PARTICIPANT	\N	PRESENT	0
599154	598018	01057W	PARTICIPANT	\N	PRESENT	0
599155	598018	19687N	PARTICIPANT	\N	PRESENT	0
599156	598018	14253S	PARTICIPANT	\N	PRESENT	0
599157	598018	99004R	PARTICIPANT	\N	PRESENT	0
599158	598018	14225N	PARTICIPANT	\N	EXCUSE	0
599159	598018	11053K	PARTICIPANT	\N	PRESENT	0
599160	598018	20070A	PARTICIPANT	\N	PRESENT	0
599161	598018	14189C	PARTICIPANT	\N	PRESENT	0
599162	597484	20056C	PARTICIPANT	\N	PRESENT	0
599163	597484	20180F	PARTICIPANT	\N	PRESENT	0
599164	597484	19533U	PARTICIPANT	\N	PRESENT	0
599165	597484	92040Q	PARTICIPANT	\N	PRESENT	0
599166	597484	19693L	PARTICIPANT	\N	PRESENT	0
599167	597484	20152B	PARTICIPANT	\N	PRESENT	0
599168	597484	19621T	PARTICIPANT	\N	PRESENT	0
599169	598018	01048V	PARTICIPANT	\N	PRESENT	0
599170	598018	19671E	PARTICIPANT	\N	PRESENT	0
599171	598018	19349W	PARTICIPANT	\N	PRESENT	0
599172	598018	19762G	PARTICIPANT	\N	PRESENT	0
599173	598018	04071H	PARTICIPANT	\N	PRESENT	0
599174	598018	07029T	PARTICIPANT	\N	PRESENT	0
599175	598018	19479G	PARTICIPANT	\N	PRESENT	0
599176	597484	19593H	PARTICIPANT	\N	PRESENT	0
599177	597484	20132W	PARTICIPANT	\N	PRESENT	0
599178	597484	19699S	PARTICIPANT	\N	PRESENT	0
599179	597484	19611R	PRESIDENT	0	PRESENT	0
599180	597484	20142Y	PARTICIPANT	\N	PRESENT	0
599181	597484	20048C	PARTICIPANT	\N	PRESENT	0
599182	597484	01060R	PARTICIPANT	\N	PRESENT	0
599183	597484	20052X	PARTICIPANT	\N	PRESENT	0
599184	597484	14030Q	PARTICIPANT	\N	PRESENT	0
599185	597484	20112S	PARTICIPANT	\N	PRESENT	0
599186	597484	08012N	PARTICIPANT	\N	PRESENT	0
599187	597484	11043H	PARTICIPANT	\N	PRESENT	0
599188	597484	20124W	PARTICIPANT	\N	PRESENT	0
599189	597484	19758L	PARTICIPANT	\N	PRESENT	0
599190	597484	20026V	PARTICIPANT	\N	PRESENT	0
599191	597484	20084G	PARTICIPANT	\N	PRESENT	0
599192	598018	08011M	PARTICIPANT	\N	PRESENT	0
599193	597484	20134Y	PARTICIPANT	\N	PRESENT	0
599194	597484	20058E	PARTICIPANT	\N	PRESENT	0
599195	597484	11109J	PARTICIPANT	\N	EXCUSE	0
599196	598018	20252E	PARTICIPANT	\N	PRESENT	0
599197	598018	08009T	PARTICIPANT	\N	PRESENT	0
599198	598018	19741B	PARTICIPANT	\N	PRESENT	0
599199	597484	11104D	PARTICIPANT	\N	PRESENT	0
599200	597484	20264J	PARTICIPANT	\N	EXCUSE	0
599241	598018	08010L	PARTICIPANT	\N	PRESENT	0
599262	597713	04047H	PRESIDENT	1	PRESENT	0
599263	597713	01028R	PARTICIPANT	\N	PRESENT	0
599264	597713	14231L	PARTICIPANT	\N	PRESENT	0
599265	597713	19447X	PARTICIPANT	\N	PRESENT	0
599266	597713	19954N	PARTICIPANT	\N	PRESENT	0
599267	597713	17737W	PARTICIPANT	\N	PRESENT	0
599268	597713	20114U	PARTICIPANT	\N	PRESENT	0
599269	597713	20022R	PARTICIPANT	\N	PRESENT	0
599270	597713	20128B	PARTICIPANT	\N	PRESENT	0
599271	597713	04085P	PARTICIPANT	\N	PRESENT	0
599272	597713	95063L	PARTICIPANT	\N	PRESENT	0
599273	597713	14069U	PARTICIPANT	\N	PRESENT	0
599274	597713	14021P	PARTICIPANT	\N	PRESENT	0
599275	597713	11026G	PARTICIPANT	\N	PRESENT	0
599276	597713	19729F	PARTICIPANT	\N	EXCUSE	0
599279	598018	19647E	PARTICIPANT	\N	PRESENT	0
599280	597484	19057M	PARTICIPANT	\N	PRESENT	0
599281	595688	19551W	PARTICIPANT	\N	PRESENT	0
599282	595688	20032T	PARTICIPANT	\N	PRESENT	0
599283	595688	08060W	PARTICIPANT	\N	PRESENT	0
599284	595688	20118Y	PARTICIPANT	\N	PRESENT	0
599285	595688	20076G	PARTICIPANT	\N	PRESENT	0
599286	595688	19739H	PARTICIPANT	\N	PRESENT	0
599287	595688	19251M	PARTICIPANT	\N	PRESENT	0
599288	595688	19745F	PARTICIPANT	\N	PRESENT	0
599289	595688	14221J	PARTICIPANT	\N	PRESENT	0
599290	595688	20102Q	PARTICIPANT	\N	PRESENT	0
599291	595688	20024T	PARTICIPANT	\N	PRESENT	0
599292	595688	11101A	PARTICIPANT	\N	PRESENT	0
599293	595688	19637C	PARTICIPANT	\N	PRESENT	0
599294	595688	20100N	PARTICIPANT	\N	PRESENT	0
599295	595688	20108W	PARTICIPANT	\N	PRESENT	0
599296	595688	14031R	PARTICIPANT	\N	PRESENT	0
599297	595688	14219Q	PRESIDENT	0	PRESENT	0
599298	595688	19820Y	PARTICIPANT	\N	PRESENT	0
599299	595688	20046A	PARTICIPANT	\N	PRESENT	0
599300	595688	19826F	PARTICIPANT	\N	PRESENT	0
599301	595688	20096L	PARTICIPANT	\N	PRESENT	0
599302	595688	17367Q	PARTICIPANT	\N	PRESENT	0
599303	595688	19333N	PARTICIPANT	\N	PRESENT	0
599304	595688	19503N	PARTICIPANT	\N	PRESENT	0
599305	595688	20120S	PARTICIPANT	\N	PRESENT	0
599306	595688	19549D	PARTICIPANT	\N	PRESENT	0
599307	595688	20136B	PARTICIPANT	\N	PRESENT	0
599308	595688	18083K	PARTICIPANT	\N	PRESENT	0
599309	595688	20038A	PARTICIPANT	\N	PRESENT	0
599310	595688	19599P	PARTICIPANT	\N	PRESENT	0
599311	595688	19701S	PARTICIPANT	\N	PRESENT	0
599312	595688	19387D	PARTICIPANT	\N	PRESENT	0
599313	595688	20122U	PARTICIPANT	\N	PRESENT	0
599314	595688	20068G	PARTICIPANT	\N	PRESENT	0
599315	595688	17229F	PARTICIPANT	\N	PRESENT	0
599316	595688	20106U	PARTICIPANT	\N	PRESENT	0
599322	595688	05012A	PARTICIPANT	\N	PRESENT	0
600359	596677	19725B	PARTICIPANT	\N	PRESENT	0
600360	596677	20100N	PARTICIPANT	\N	PRESENT	0
600361	596677	14097Y	PARTICIPANT	\N	PRESENT	0
600362	596677	14331P	PRESIDENT	0	PRESENT	0
600363	596677	11101A	PARTICIPANT	\N	PRESENT	0
600364	596677	10015M	PARTICIPANT	\N	PRESENT	0
600365	596677	11026G	PARTICIPANT	\N	PRESENT	0
600366	596677	12016W	PARTICIPANT	\N	PRESENT	0
600367	596677	11083R	PARTICIPANT	\N	PRESENT	0
600368	596677	04045F	PARTICIPANT	\N	PRESENT	0
600369	596677	04057K	PARTICIPANT	\N	EXCUSE	0
600370	596677	14026U	PARTICIPANT	\N	EXCUSE	0
600371	596677	08034U	PARTICIPANT	\N	PRESENT	0
600372	596677	14033T	PARTICIPANT	\N	PRESENT	0
600373	596677	19563B	PARTICIPANT	\N	PRESENT	0
600374	596677	19441R	PARTICIPANT	\N	EXCUSE	0
600375	596677	12041X	PARTICIPANT	\N	PRESENT	0
600421	600416	14195A	PARTICIPANT	\N	PRESENT	0
600422	600416	08073C	PARTICIPANT	\N	PRESENT	0
600427	600416	20082E	PARTICIPANT	\N	PRESENT	0
600428	600416	20046A	PARTICIPANT	\N	PRESENT	0
600429	600416	04045F	PARTICIPANT	\N	PRESENT	0
600430	600416	20032T	PARTICIPANT	\N	PRESENT	0
600431	600416	14327T	PARTICIPANT	\N	PRESENT	0
600432	600416	19725B	PARTICIPANT	\N	PRESENT	0
600433	600416	08012N	PARTICIPANT	\N	PRESENT	0
600434	600416	19683J	PARTICIPANT	\N	PRESENT	0
600435	600416	01028R	PARTICIPANT	\N	PRESENT	0
600436	600416	14097Y	PARTICIPANT	\N	PRESENT	0
600437	600416	20112S	PARTICIPANT	\N	PRESENT	0
600438	600416	19399H	PARTICIPANT	\N	PRESENT	0
600439	600416	14219Q	PARTICIPANT	\N	PRESENT	0
600440	600416	20116W	PARTICIPANT	\N	PRESENT	0
600441	600416	19531S	PARTICIPANT	\N	PRESENT	0
600442	600416	19629C	PARTICIPANT	\N	PRESENT	0
600445	600416	14001X	PARTICIPANT	\N	PRESENT	0
600446	600416	20018V	PARTICIPANT	\N	PRESENT	0
600447	600416	11101A	PARTICIPANT	\N	PRESENT	0
627654	626799	14042U	PARTICIPANT	\N	PRESENT	0
627677	626799	20130U	PARTICIPANT	\N	PRESENT	1
627678	626799	17779H	PARTICIPANT	\N	PRESENT	1
627679	626799	04043D	PARTICIPANT	\N	PRESENT	1
627680	626799	19295A	PARTICIPANT	\N	EXCUSE	0
628814	628813	20024T	PARTICIPANT	\N	PRESENT	0
628815	628813	19515S	PARTICIPANT	\N	PRESENT	0
628816	628813	19251M	PARTICIPANT	\N	PRESENT	0
628817	628813	19637C	PARTICIPANT	\N	PRESENT	0
628819	628818	20024T	PARTICIPANT	\N	PRESENT	0
628821	628820	20024T	PARTICIPANT	\N	PRESENT	0
628822	628820	19515S	PARTICIPANT	\N	PRESENT	0
631353	631351	19663E	PARTICIPANT	\N	PRESENT	0
631354	631351	19723Y	PARTICIPANT	\N	PRESENT	0
631355	631351	19713W	PARTICIPANT	\N	PRESENT	0
631356	631352	19663E	PARTICIPANT	\N	PRESENT	0
631357	631352	19723Y	PARTICIPANT	\N	PRESENT	0
639560	639559	20150Y	PARTICIPANT	\N	PRESENT	0
631359	631352	19713W	PARTICIPANT	\N	PRESENT	0
631360	631352	19691J	PARTICIPANT	\N	PRESENT	0
631704	631703	20094J	PARTICIPANT	\N	PRESENT	0
640551	640059	20104S	PARTICIPANT	\N	EXCUSE	0
640553	640059	20030R	PARTICIPANT	\N	PRESENT	1
640554	640059	20028X	PARTICIPANT	\N	PRESENT	1
640830	640829	11027H	PARTICIPANT	\N	PRESENT	0
640831	640829	20024T	PARTICIPANT	\N	PRESENT	0
641144	641143	11074Q	PARTICIPANT	\N	PRESENT	0
641145	641142	11074Q	PARTICIPANT	\N	PRESENT	0
641669	641650	19725B	PARTICIPANT	\N	PRESENT	0
641670	641650	19447X	PARTICIPANT	\N	PRESENT	0
641671	641650	14147R	PARTICIPANT	\N	PRESENT	0
642475	642185	11048N	PARTICIPANT	\N	PRESENT	0
642476	642185	19687N	PARTICIPANT	\N	PRESENT	0
642477	642185	20080C	PARTICIPANT	\N	PRESENT	0
642478	642185	19349W	PARTICIPANT	\N	PRESENT	0
642479	642185	20116W	PARTICIPANT	\N	PRESENT	0
642480	642185	14225N	PRESIDENT	0	PRESENT	0
642481	642185	14331P	PARTICIPANT	\N	EXCUSE	0
642482	642185	19762G	PARTICIPANT	\N	EXCUSE	0
642483	642185	20086J	PARTICIPANT	\N	PRESENT	0
642484	642185	19647E	PARTICIPANT	\N	PRESENT	0
642485	642185	19545Y	PARTICIPANT	\N	PRESENT	0
642486	642185	01057W	PARTICIPANT	\N	PRESENT	0
642487	642185	20050V	PARTICIPANT	\N	PRESENT	0
642488	642185	19671E	PARTICIPANT	\N	PRESENT	0
642489	642185	20252E	PARTICIPANT	\N	PRESENT	0
642490	642185	20070A	PARTICIPANT	\N	PRESENT	0
642491	642185	99004R	PARTICIPANT	\N	PRESENT	0
642495	642185	19479G	PARTICIPANT	\N	PRESENT	0
642496	642185	19667J	PARTICIPANT	\N	PRESENT	0
643729	643725	19369B	PARTICIPANT	\N	PRESENT	0
642498	642185	07029T	PARTICIPANT	\N	PRESENT	0
642500	642185	11053K	PARTICIPANT	\N	PRESENT	0
643728	643725	14033T	PARTICIPANT	\N	PRESENT	0
643730	643725	20018V	PARTICIPANT	\N	PRESENT	0
643731	643725	14357A	PARTICIPANT	\N	PRESENT	0
643732	643725	14257W	PARTICIPANT	\N	PRESENT	0
643733	643725	20062A	PARTICIPANT	\N	PRESENT	0
643734	643726	14033T	PARTICIPANT	\N	PRESENT	0
643735	643726	19369B	PARTICIPANT	\N	PRESENT	0
643736	643726	20018V	PARTICIPANT	\N	PRESENT	0
643737	643726	14357A	PARTICIPANT	\N	PRESENT	0
643738	643726	14257W	PARTICIPANT	\N	PRESENT	0
643739	643726	20062A	PARTICIPANT	\N	PRESENT	0
643740	643727	14033T	PARTICIPANT	\N	PRESENT	0
643741	643727	19369B	PARTICIPANT	\N	PRESENT	0
643742	643727	20018V	PARTICIPANT	\N	PRESENT	0
643743	643727	14357A	PARTICIPANT	\N	PRESENT	0
643744	643727	14257W	PARTICIPANT	\N	PRESENT	0
647671	646185	20032T	PARTICIPANT	\N	PRESENT	0
647672	646185	19515S	PARTICIPANT	\N	PRESENT	0
647673	646185	19707Y	PARTICIPANT	\N	PRESENT	0
647674	646185	05008E	PARTICIPANT	\N	PRESENT	0
647675	646185	19741B	PARTICIPANT	\N	PRESENT	0
647676	646185	20024T	PARTICIPANT	\N	PRESENT	0
647677	646185	20022R	PARTICIPANT	\N	PRESENT	0
647678	646185	19954N	PARTICIPANT	\N	PRESENT	0
647679	646185	19575F	PARTICIPANT	\N	PRESENT	0
647680	646185	17367Q	PARTICIPANT	\N	PRESENT	0
647681	646185	20086J	PARTICIPANT	\N	PRESENT	0
647682	646185	19367Y	PARTICIPANT	\N	PRESENT	0
647683	646185	14069U	PARTICIPANT	\N	PRESENT	0
647684	646185	19415P	PARTICIPANT	\N	PRESENT	0
647685	646185	20078J	PARTICIPANT	\N	PRESENT	0
647686	646185	20138D	PARTICIPANT	\N	PRESENT	0
647687	646185	14105F	PARTICIPANT	\N	PRESENT	0
647688	646185	19747H	PARTICIPANT	\N	PRESENT	0
647689	646185	20152B	PARTICIPANT	\N	PRESENT	0
647690	646185	19383Y	PARTICIPANT	\N	PRESENT	0
647691	646185	19621T	PARTICIPANT	\N	PRESENT	0
647692	646185	04047H	PARTICIPANT	\N	PRESENT	0
647693	646185	20090E	PARTICIPANT	\N	PRESENT	0
647694	646185	20104S	PARTICIPANT	\N	PRESENT	0
647695	646185	04042C	PARTICIPANT	\N	PRESENT	0
647696	646185	14083S	PARTICIPANT	\N	PRESENT	0
647697	646185	14038Y	PARTICIPANT	\N	PRESENT	0
647698	646185	11080N	PARTICIPANT	\N	PRESENT	0
647699	646185	08028W	PARTICIPANT	\N	PRESENT	0
647700	646185	19467C	PARTICIPANT	\N	PRESENT	0
647701	646185	18083K	PARTICIPANT	\N	PRESENT	0
647702	646185	14357A	PARTICIPANT	\N	PRESENT	0
647703	646185	19693L	PARTICIPANT	\N	PRESENT	0
647704	646185	14259Y	PARTICIPANT	\N	PRESENT	0
647705	646185	19663E	PARTICIPANT	\N	PRESENT	0
647706	646185	10006L	PARTICIPANT	\N	PRESENT	0
647707	646185	14217N	PARTICIPANT	\N	PRESENT	0
647708	646185	14215L	PARTICIPANT	\N	PRESENT	0
647709	646185	04071H	PARTICIPANT	\N	PRESENT	0
647710	646185	20124W	PARTICIPANT	\N	PRESENT	0
647711	646185	07033P	PARTICIPANT	\N	PRESENT	0
647712	646185	19507S	PARTICIPANT	\N	PRESENT	0
647713	646185	20074E	PARTICIPANT	\N	PRESENT	0
647714	646185	14187A	PARTICIPANT	\N	PRESENT	0
647715	646185	19673G	PARTICIPANT	\N	PRESENT	0
647716	646185	20038A	PARTICIPANT	\N	PRESENT	0
647717	646185	97011G	PARTICIPANT	\N	PRESENT	0
647718	646185	08018U	PARTICIPANT	\N	PRESENT	0
647719	646185	20120S	PARTICIPANT	\N	PRESENT	0
647720	646185	20180F	PARTICIPANT	\N	PRESENT	0
647721	646185	14211G	PARTICIPANT	\N	PRESENT	0
647722	646185	14033T	PARTICIPANT	\N	PRESENT	0
647723	646185	14123H	PARTICIPANT	\N	PRESENT	0
647724	646185	14026U	PARTICIPANT	\N	PRESENT	0
647725	646185	20068G	PARTICIPANT	\N	PRESENT	0
647726	646185	19399H	PARTICIPANT	\N	PRESENT	0
647727	646185	11048N	PARTICIPANT	\N	PRESENT	0
647728	646185	20034V	PARTICIPANT	\N	PRESENT	0
647729	646185	20056C	PARTICIPANT	\N	PRESENT	0
647730	646185	19447X	PARTICIPANT	\N	PRESENT	0
647731	646185	95041E	PARTICIPANT	\N	PRESENT	0
647732	646185	99004R	PARTICIPANT	\N	PRESENT	0
647733	646185	20126Y	PARTICIPANT	\N	PRESENT	0
647734	646185	86034E	PARTICIPANT	\N	PRESENT	0
647735	646185	19711U	PARTICIPANT	\N	PRESENT	0
647736	646185	20108W	PARTICIPANT	\N	PRESENT	0
647737	646185	08010L	PARTICIPANT	\N	PRESENT	0
647738	646185	08034U	PARTICIPANT	\N	PRESENT	0
647739	646185	19729F	PARTICIPANT	\N	PRESENT	0
647740	646185	19581D	PARTICIPANT	\N	PRESENT	0
647741	646185	01048V	PARTICIPANT	\N	PRESENT	0
647742	646185	14059S	PARTICIPANT	\N	PRESENT	0
647743	646185	14031R	PARTICIPANT	\N	PRESENT	0
647744	646185	20252E	PARTICIPANT	\N	PRESENT	0
647745	646185	14147R	PARTICIPANT	\N	PRESENT	0
647746	646185	20096L	PARTICIPANT	\N	PRESENT	0
647747	646185	14169X	PARTICIPANT	\N	PRESENT	0
647748	646185	19768N	PARTICIPANT	\N	PRESENT	0
647749	646185	14253S	PARTICIPANT	\N	PRESENT	0
647750	646185	19573D	PARTICIPANT	\N	PRESENT	0
647751	646185	14191V	PARTICIPANT	\N	PRESENT	0
647752	646185	17637T	PARTICIPANT	\N	PRESENT	0
647753	646185	14193X	PARTICIPANT	\N	PRESENT	0
647754	646185	20148F	PARTICIPANT	\N	PRESENT	0
647755	646185	19533U	PARTICIPANT	\N	PRESENT	0
647756	646185	05012A	PARTICIPANT	\N	PRESENT	0
647757	646185	11090Q	PARTICIPANT	\N	PRESENT	0
647758	646185	04043D	PARTICIPANT	\N	PRESENT	0
647759	646185	19443T	PARTICIPANT	\N	PRESENT	0
647760	646185	14331P	PARTICIPANT	\N	PRESENT	0
647761	646185	19766L	PARTICIPANT	\N	PRESENT	0
647762	646185	10015M	PARTICIPANT	\N	PRESENT	0
640606	640605	14331P	PARTICIPANT	\N	PRESENT	0
640607	640605	11026G	PARTICIPANT	\N	PRESENT	0
640948	640947	19575F	PARTICIPANT	\N	PRESENT	1
640949	640947	19629C	PARTICIPANT	\N	PRESENT	0
640950	640947	14038Y	PARTICIPANT	\N	PRESENT	0
640951	640947	14179A	PARTICIPANT	\N	PRESENT	1
640952	640947	14147R	PARTICIPANT	\N	PRESENT	1
640953	640947	20092G	PARTICIPANT	\N	PRESENT	0
640955	640954	19629C	PARTICIPANT	\N	PRESENT	0
640956	640954	14038Y	PARTICIPANT	\N	PRESENT	0
640957	640954	14147R	PARTICIPANT	\N	PRESENT	1
640958	640954	20092G	PARTICIPANT	\N	PRESENT	0
640962	640961	14083S	PARTICIPANT	\N	PRESENT	0
640963	640961	11083R	PARTICIPANT	\N	PRESENT	0
640964	640961	19387D	PARTICIPANT	\N	PRESENT	0
640965	640961	19553Y	PARTICIPANT	\N	PRESENT	0
640966	640961	19629C	PARTICIPANT	\N	PRESENT	0
641025	640959	20050V	PARTICIPANT	\N	EXCUSE	0
641194	641193	14259Y	PARTICIPANT	\N	PRESENT	0
641195	641193	14231L	PARTICIPANT	\N	PRESENT	0
641197	641196	14231L	PARTICIPANT	\N	PRESENT	0
641199	641196	14259Y	PARTICIPANT	\N	PRESENT	0
641201	641200	14231L	PARTICIPANT	\N	PRESENT	0
641202	641200	14259Y	PARTICIPANT	\N	PRESENT	0
641204	641203	14231L	PARTICIPANT	\N	PRESENT	0
641205	641203	14259Y	PARTICIPANT	\N	PRESENT	0
641207	641206	14231L	PARTICIPANT	\N	PRESENT	0
641208	641206	14259Y	PARTICIPANT	\N	PRESENT	0
641210	641209	14231L	PARTICIPANT	\N	PRESENT	0
641211	641209	14259Y	PARTICIPANT	\N	PRESENT	0
641213	641212	14033T	PARTICIPANT	\N	PRESENT	0
641214	641212	19369B	PARTICIPANT	\N	PRESENT	0
641215	641212	20018V	PARTICIPANT	\N	PRESENT	0
641216	641212	14257W	PARTICIPANT	\N	PRESENT	0
641218	641217	14033T	PARTICIPANT	\N	PRESENT	0
641219	641217	20018V	PARTICIPANT	\N	PRESENT	0
641851	641705	14147R	PARTICIPANT	\N	PRESENT	0
641852	641651	14147R	PARTICIPANT	\N	PRESENT	0
641853	641654	14147R	PARTICIPANT	\N	PRESENT	0
641854	641660	14147R	PARTICIPANT	\N	PRESENT	0
641855	641663	14147R	PARTICIPANT	\N	PRESENT	0
642260	642259	14225N	PARTICIPANT	\N	PRESENT	0
642261	642259	01057W	PARTICIPANT	\N	PRESENT	0
642903	642902	05008E	PARTICIPANT	\N	PRESENT	0
642904	642902	11033F	PARTICIPANT	\N	PRESENT	0
642905	642902	11053K	PARTICIPANT	\N	PRESENT	0
642906	642902	14357A	PARTICIPANT	\N	PRESENT	0
642907	642902	11070L	PARTICIPANT	\N	PRESENT	0
642908	642902	19719D	PARTICIPANT	\N	PRESENT	0
642909	642902	19673G	PARTICIPANT	\N	PRESENT	0
642910	642902	19599P	PARTICIPANT	\N	PRESENT	0
642911	642902	14033T	PARTICIPANT	\N	PRESENT	0
642912	642902	14026U	PARTICIPANT	\N	PRESENT	0
642913	642902	14179A	PARTICIPANT	\N	PRESENT	0
642914	642902	19715Y	PARTICIPANT	\N	PRESENT	0
642915	642902	99004R	PARTICIPANT	\N	PRESENT	0
642916	642902	12041X	PARTICIPANT	\N	PRESENT	0
642917	642902	01043Q	PARTICIPANT	\N	PRESENT	0
642918	642902	14147R	PARTICIPANT	\N	PRESENT	0
642919	642902	95063L	PARTICIPANT	\N	PRESENT	0
642920	642902	11045K	PARTICIPANT	\N	PRESENT	0
642921	642902	01028R	PARTICIPANT	\N	PRESENT	0
642922	642902	19413M	PARTICIPANT	\N	PRESENT	0
642925	642186	14033T	PARTICIPANT	\N	EXCUSE	0
642927	642926	19631V	PARTICIPANT	\N	PRESENT	0
642928	642926	14187A	PARTICIPANT	\N	PRESENT	0
642930	642929	19631V	PARTICIPANT	\N	PRESENT	0
642931	642929	14187A	PARTICIPANT	\N	PRESENT	0
642933	642932	19631V	PARTICIPANT	\N	PRESENT	0
642934	642932	14187A	PARTICIPANT	\N	PRESENT	0
643214	643213	20098N	PARTICIPANT	\N	PRESENT	0
643215	643213	04070G	PARTICIPANT	\N	PRESENT	0
643217	643216	04070G	PARTICIPANT	\N	PRESENT	0
643231	643230	19599P	PARTICIPANT	\N	PRESENT	0
643232	643230	14179A	PARTICIPANT	\N	PRESENT	0
643233	643230	19565D	PARTICIPANT	\N	PRESENT	0
643234	643230	11054L	PARTICIPANT	\N	PRESENT	1
644274	644004	19649G	PARTICIPANT	\N	PRESENT	0
644024	643651	14121F	PARTICIPANT	\N	PRESENT	1
644299	644154	20132W	PARTICIPANT	\N	PRESENT	0
644026	643651	19349W	PARTICIPANT	\N	PRESENT	1
644300	644154	20134Y	PARTICIPANT	\N	PRESENT	0
644028	643651	19687N	PARTICIPANT	\N	PRESENT	1
644029	643651	20112S	PARTICIPANT	\N	PRESENT	1
644030	643651	19758L	PARTICIPANT	\N	PRESENT	1
644031	643651	20134Y	PARTICIPANT	\N	PRESENT	1
644032	643651	20124W	PARTICIPANT	\N	PRESENT	1
644033	643651	20172F	PARTICIPANT	\N	PRESENT	1
644034	643651	20142Y	PARTICIPANT	\N	PRESENT	1
644036	643651	19479G	PARTICIPANT	\N	PRESENT	1
644275	644004	20138D	PARTICIPANT	\N	PRESENT	1
644276	644004	11026G	PARTICIPANT	\N	PRESENT	0
644277	644004	20142Y	PARTICIPANT	\N	PRESENT	1
644278	644004	20052X	PARTICIPANT	\N	PRESENT	1
644279	644004	19719D	PARTICIPANT	\N	PRESENT	1
644280	644004	11033F	PARTICIPANT	\N	PRESENT	0
644281	644004	04085P	PARTICIPANT	\N	PRESENT	0
644282	644004	20058E	PARTICIPANT	\N	PRESENT	1
644283	644004	11056N	PARTICIPANT	\N	PRESENT	1
644284	644004	19629C	PARTICIPANT	\N	PRESENT	1
644285	644004	04059M	PARTICIPANT	\N	PRESENT	0
644286	644004	14123H	PARTICIPANT	\N	PRESENT	1
644287	644004	11043H	PARTICIPANT	\N	PRESENT	0
644288	644004	19758L	PARTICIPANT	\N	PRESENT	1
644289	644004	14021P	PARTICIPANT	\N	PRESENT	0
644301	644154	19699S	PARTICIPANT	\N	PRESENT	0
644302	644154	19573D	PARTICIPANT	\N	PRESENT	0
644303	644154	04059M	PARTICIPANT	\N	PRESENT	0
644304	644154	14109K	PARTICIPANT	\N	PRESENT	0
644305	644154	08012N	PARTICIPANT	\N	PRESENT	0
644306	644154	11043H	PARTICIPANT	\N	PRESENT	0
644307	644154	14229S	PARTICIPANT	\N	PRESENT	0
644313	644312	20132W	PARTICIPANT	\N	PRESENT	0
644314	644312	20134Y	PARTICIPANT	\N	PRESENT	0
644315	644312	19699S	PARTICIPANT	\N	PRESENT	0
644316	644312	19533U	PARTICIPANT	\N	PRESENT	0
644317	644312	04059M	PARTICIPANT	\N	PRESENT	0
644318	644312	19611R	PRESIDENT	0	PRESENT	0
644319	644312	08012N	PARTICIPANT	\N	PRESENT	0
644320	644005	19766L	PARTICIPANT	\N	PRESENT	1
644321	644005	20132W	PARTICIPANT	\N	PRESENT	0
644322	644005	20134Y	PARTICIPANT	\N	PRESENT	0
644323	644005	19649G	PARTICIPANT	\N	PRESENT	0
644324	644005	19533U	PARTICIPANT	\N	PRESENT	0
644325	644005	19611R	PARTICIPANT	\N	PRESENT	0
644326	644005	11026G	PARTICIPANT	\N	PRESENT	0
644327	644005	04047H	PRESIDENT	0	PRESENT	0
644328	644005	19673G	PARTICIPANT	\N	PRESENT	0
644329	644005	11033F	PARTICIPANT	\N	PRESENT	1
644330	644005	11056N	PARTICIPANT	\N	PRESENT	1
644331	644005	19629C	PARTICIPANT	\N	PRESENT	1
644332	644005	04059M	PARTICIPANT	\N	PRESENT	0
644333	644005	20110Q	PARTICIPANT	\N	PRESENT	1
644334	644005	14147R	PARTICIPANT	\N	PRESENT	0
644335	644005	14151M	PARTICIPANT	\N	PRESENT	1
644336	644005	14123H	PARTICIPANT	\N	PRESENT	1
644337	644005	14215L	PARTICIPANT	\N	PRESENT	1
644338	644005	08012N	PARTICIPANT	\N	PRESENT	0
644339	644005	11043H	PARTICIPANT	\N	PRESENT	0
644340	644005	19758L	PARTICIPANT	\N	PRESENT	1
644341	644005	14021P	PARTICIPANT	\N	PRESENT	0
644342	644005	20022R	PARTICIPANT	\N	PRESENT	1
644343	644155	19699S	PARTICIPANT	\N	PRESENT	0
644344	644155	19533U	PARTICIPANT	\N	PRESENT	0
644345	644155	19611R	PRESIDENT	0	PRESENT	0
644346	644155	08012N	PARTICIPANT	\N	PRESENT	0
644347	644006	19766L	PARTICIPANT	\N	PRESENT	1
644348	644006	19649G	PARTICIPANT	\N	PRESENT	1
644349	644006	19533U	PARTICIPANT	\N	PRESENT	0
644350	644006	19611R	PARTICIPANT	\N	PRESENT	0
644351	644006	11026G	PARTICIPANT	\N	PRESENT	0
644352	644006	04047H	PRESIDENT	0	PRESENT	0
644353	644006	19673G	PARTICIPANT	\N	PRESENT	0
644354	644006	11033F	PARTICIPANT	\N	PRESENT	1
644355	644006	11056N	PARTICIPANT	\N	PRESENT	1
644356	644006	19629C	PARTICIPANT	\N	PRESENT	1
644357	644006	20110Q	PARTICIPANT	\N	PRESENT	1
644358	644006	14147R	PARTICIPANT	\N	PRESENT	0
644359	644006	14151M	PARTICIPANT	\N	PRESENT	1
644360	644006	14123H	PARTICIPANT	\N	PRESENT	1
644361	644006	14215L	PARTICIPANT	\N	PRESENT	1
627591	624282	19333N	PARTICIPANT	\N	PRESENT	0
627592	624282	20032T	PARTICIPANT	\N	PRESENT	0
627593	624282	14031R	PARTICIPANT	\N	PRESENT	0
627594	624282	20038A	PARTICIPANT	\N	PRESENT	0
627595	624282	19549D	PARTICIPANT	\N	PRESENT	0
627596	624282	19387D	PARTICIPANT	\N	PRESENT	0
627597	624282	14219Q	PRESIDENT	0	PRESENT	0
627598	624282	19826F	PARTICIPANT	\N	PRESENT	0
627599	624282	19599P	PARTICIPANT	\N	PRESENT	0
627600	624282	20102Q	PARTICIPANT	\N	PRESENT	0
627601	624282	18083K	PARTICIPANT	\N	PRESENT	0
627602	624282	20106U	PARTICIPANT	\N	PRESENT	0
627603	624282	11101A	PARTICIPANT	\N	PRESENT	0
627604	624282	19503N	PARTICIPANT	\N	PRESENT	0
627605	624282	20020P	PARTICIPANT	\N	PRESENT	0
627606	624282	19745F	PARTICIPANT	\N	PRESENT	0
627607	624282	20024T	PARTICIPANT	\N	PRESENT	0
627608	624282	19619A	PARTICIPANT	\N	PRESENT	0
627609	624282	20068G	PARTICIPANT	\N	PRESENT	1
627610	624282	19820Y	PARTICIPANT	\N	PRESENT	0
627611	624282	11065P	PARTICIPANT	\N	PRESENT	0
627612	624282	19701S	PARTICIPANT	\N	PRESENT	1
627613	624282	20140W	PARTICIPANT	\N	PRESENT	0
627614	624282	19251M	PARTICIPANT	\N	PRESENT	0
627615	624282	20046A	PARTICIPANT	\N	PRESENT	1
627616	624282	05012A	PARTICIPANT	\N	PRESENT	0
627771	626652	11040E	PARTICIPANT	\N	PRESENT	0
627772	626652	14331P	PARTICIPANT	\N	PRESENT	0
627773	626652	11048N	PARTICIPANT	\N	PRESENT	0
627774	626652	14189C	PARTICIPANT	\N	PRESENT	0
627775	626652	01057W	PARTICIPANT	\N	PRESENT	0
627776	626652	19349W	PARTICIPANT	\N	PRESENT	0
627777	626652	99004R	PARTICIPANT	\N	PRESENT	0
627778	626652	20044X	PARTICIPANT	\N	PRESENT	0
627779	626652	14225N	PRESIDENT	0	PRESENT	0
627780	626652	14173T	PARTICIPANT	\N	PRESENT	0
627781	626652	19762G	PARTICIPANT	\N	PRESENT	0
627782	626652	20050V	PARTICIPANT	\N	PRESENT	0
627783	626652	11074Q	PARTICIPANT	\N	PRESENT	0
627784	626652	20252E	PARTICIPANT	\N	PRESENT	0
627786	626652	14327T	PARTICIPANT	\N	PRESENT	0
627787	626652	19531S	PARTICIPANT	\N	PRESENT	0
627788	626652	19741B	PARTICIPANT	\N	PRESENT	0
627789	626652	20126Y	PARTICIPANT	\N	PRESENT	0
627790	626652	19647E	PARTICIPANT	\N	PRESENT	0
627794	626652	19479G	PARTICIPANT	\N	PRESENT	0
627795	626652	08009T	PARTICIPANT	\N	PRESENT	0
627796	626652	04071H	PARTICIPANT	\N	PRESENT	0
627797	626652	20080C	PARTICIPANT	\N	PRESENT	0
627798	626652	19335Q	PARTICIPANT	\N	PRESENT	0
627799	626652	20070A	PARTICIPANT	\N	PRESENT	0
627807	626652	19671E	PARTICIPANT	\N	PRESENT	0
627808	626652	14253S	PARTICIPANT	\N	PRESENT	0
627809	626652	11012A	PARTICIPANT	\N	PRESENT	0
627810	626652	07029T	PARTICIPANT	\N	PRESENT	0
627811	626652	19667J	PARTICIPANT	\N	PRESENT	0
627871	626652	19711U	PARTICIPANT	\N	PRESENT	0
627877	626898	19768N	PARTICIPANT	\N	PRESENT	1
627878	626898	20088L	PARTICIPANT	\N	PRESENT	0
627879	626898	19515S	PARTICIPANT	\N	PRESENT	0
627880	626898	19782L	PARTICIPANT	\N	PRESENT	0
627881	626898	20092G	PARTICIPANT	\N	PRESENT	0
627882	626898	19441R	PARTICIPANT	\N	PRESENT	0
627883	626898	20078J	PARTICIPANT	\N	PRESENT	1
627884	626898	20082E	PARTICIPANT	\N	PRESENT	1
627885	626898	20094J	PARTICIPANT	\N	PRESENT	0
627886	626898	04045F	PARTICIPANT	\N	PRESENT	0
627887	626898	19631V	PARTICIPANT	\N	PRESENT	0
627888	626898	20104S	PARTICIPANT	\N	PRESENT	0
627889	626898	19705W	PARTICIPANT	\N	PRESENT	1
627890	626898	19707Y	PARTICIPANT	\N	PRESENT	1
627891	626898	08015R	PARTICIPANT	\N	PRESENT	0
627892	626898	19575F	PARTICIPANT	\N	PRESENT	0
627893	626898	19369B	PARTICIPANT	\N	PRESENT	0
627894	626898	20018V	PARTICIPANT	\N	PRESENT	0
627895	626898	08028W	PARTICIPANT	\N	PRESENT	0
627896	626898	20028X	PARTICIPANT	\N	PRESENT	0
627897	626898	14038Y	PARTICIPANT	\N	PRESENT	0
627898	626898	20030R	PARTICIPANT	\N	PRESENT	0
627899	626898	19467C	PARTICIPANT	\N	PRESENT	0
627900	626898	20034V	PARTICIPANT	\N	PRESENT	0
627901	626898	20144B	PARTICIPANT	\N	PRESENT	0
627902	626898	19695N	PARTICIPANT	\N	PRESENT	1
627903	626898	11090Q	PRESIDENT	0	PRESENT	0
627904	626898	14033T	PARTICIPANT	\N	PRESENT	0
627905	626898	01025N	PARTICIPANT	\N	PRESENT	0
627906	626898	20054A	PARTICIPANT	\N	PRESENT	0
627907	626898	20174H	PARTICIPANT	\N	PRESENT	1
627908	626898	14205J	PARTICIPANT	\N	PRESENT	0
627909	626898	14251Q	PARTICIPANT	\N	PRESENT	0
627910	626898	19507S	PARTICIPANT	\N	PRESENT	0
627911	626898	19747H	PARTICIPANT	\N	PRESENT	0
627912	626898	14207L	PARTICIPANT	\N	PRESENT	1
627913	626898	19383Y	PARTICIPANT	\N	PRESENT	0
627914	626898	19413M	PARTICIPANT	\N	PRESENT	0
627915	626898	19866P	PARTICIPANT	\N	PRESENT	0
627916	626898	19511N	PARTICIPANT	\N	PRESENT	0
627917	626898	19563B	PARTICIPANT	\N	PRESENT	0
627945	626873	86034E	PARTICIPANT	\N	PRESENT	0
627946	626873	20152B	PARTICIPANT	\N	PRESENT	0
627947	626873	20090E	PARTICIPANT	\N	PRESENT	0
627948	626873	20108W	PARTICIPANT	\N	PRESENT	0
627949	626873	10006L	PARTICIPANT	\N	PRESENT	0
627950	626873	19866P	PARTICIPANT	\N	PRESENT	0
627951	626873	11054L	PARTICIPANT	\N	PRESENT	0
627952	626873	07004J	PARTICIPANT	\N	PRESENT	0
627953	626873	19553Y	PARTICIPANT	\N	PRESENT	0
627954	626873	20024T	PARTICIPANT	\N	PRESENT	0
627956	626873	14211G	PARTICIPANT	\N	PRESENT	0
627957	626873	14031R	PARTICIPANT	\N	PRESENT	0
627958	626873	14173T	PARTICIPANT	\N	PRESENT	0
627959	626873	14259Y	PARTICIPANT	\N	PRESENT	0
627960	626873	19383Y	PARTICIPANT	\N	PRESENT	0
627961	626873	19729F	PARTICIPANT	\N	PRESENT	0
627962	626873	20174H	PARTICIPANT	\N	PRESENT	0
627964	626873	19479G	PARTICIPANT	\N	PRESENT	0
627967	626873	08028W	PARTICIPANT	\N	PRESENT	0
627978	626873	14033T	PARTICIPANT	\N	PRESENT	0
627979	626873	14111D	PARTICIPANT	\N	PRESENT	0
627980	626873	14097Y	PARTICIPANT	\N	PRESENT	0
627981	626873	11101A	PARTICIPANT	\N	PRESENT	0
627982	626873	20032T	PARTICIPANT	\N	PRESENT	0
627983	626873	19507S	PARTICIPANT	\N	PRESENT	0
627984	626873	20138D	PARTICIPANT	\N	PRESENT	0
627985	626873	08056B	PARTICIPANT	\N	PRESENT	0
627987	626873	11045K	PARTICIPANT	\N	PRESENT	0
627990	626873	14107H	PARTICIPANT	\N	PRESENT	0
627991	626873	19515S	PARTICIPANT	\N	PRESENT	0
627994	626873	14026U	PARTICIPANT	\N	PRESENT	0
627997	626873	14133K	PARTICIPANT	\N	PRESENT	0
628004	626873	99004R	PARTICIPANT	\N	PRESENT	0
628005	626873	14083S	PARTICIPANT	\N	PRESENT	0
628006	626873	14231L	PARTICIPANT	\N	PRESENT	0
628007	626873	14205J	PARTICIPANT	\N	PRESENT	0
628008	626873	19443T	PARTICIPANT	\N	PRESENT	0
628009	626873	20044X	PARTICIPANT	\N	PRESENT	0
628010	626873	11010L	PARTICIPANT	\N	PRESENT	0
628011	626873	19399H	PARTICIPANT	\N	PRESENT	0
628013	626873	20056C	PARTICIPANT	\N	PRESENT	0
628016	626873	19673G	PARTICIPANT	\N	PRESENT	0
628017	626873	19747H	PARTICIPANT	\N	PRESENT	0
628021	626873	14121F	PARTICIPANT	\N	PRESENT	0
628023	626873	19593H	PARTICIPANT	\N	PRESENT	0
628030	626873	19349W	PARTICIPANT	\N	PRESENT	0
628031	626873	19649G	PARTICIPANT	\N	PRESENT	0
628032	626873	20042V	PARTICIPANT	\N	PRESENT	0
628033	626873	17779H	PARTICIPANT	\N	PRESENT	0
628034	626873	20264J	PARTICIPANT	\N	PRESENT	0
628035	626873	11027H	PARTICIPANT	\N	PRESENT	0
628036	626873	19766L	PARTICIPANT	\N	PRESENT	0
628037	626873	14187A	PARTICIPANT	\N	PRESENT	0
628038	627941	19954N	PARTICIPANT	\N	PRESENT	0
628039	627941	19533U	PRESIDENT	0	PRESENT	0
628040	627941	19798U	PARTICIPANT	\N	PRESENT	0
628041	627941	20110Q	PARTICIPANT	\N	PRESENT	0
628042	627941	19820Y	PARTICIPANT	\N	PRESENT	0
628043	627941	14207L	PARTICIPANT	\N	PRESENT	0
628044	627941	19599P	PARTICIPANT	\N	PRESENT	0
628045	627941	20124W	PARTICIPANT	\N	PRESENT	0
628046	627941	20096L	PARTICIPANT	\N	PRESENT	0
628047	626873	19569H	PARTICIPANT	\N	PRESENT	0
634397	631575	14033T	PARTICIPANT	\N	PRESENT	0
634398	631575	20082E	PARTICIPANT	\N	PRESENT	0
634399	631575	20094J	PARTICIPANT	\N	PRESENT	0
634400	631575	20018V	PARTICIPANT	\N	PRESENT	0
634401	631575	19631V	PARTICIPANT	\N	PRESENT	0
634402	631575	20092G	PARTICIPANT	\N	PRESENT	0
634403	631575	20100N	PARTICIPANT	\N	PRESENT	0
634420	631575	20034V	PARTICIPANT	\N	PRESENT	0
634405	631575	19545Y	PARTICIPANT	\N	PRESENT	0
634406	631575	20174H	PARTICIPANT	\N	PRESENT	0
634407	631575	01024M	PARTICIPANT	\N	PRESENT	0
634408	631575	14205J	PARTICIPANT	\N	PRESENT	0
634409	631575	20144B	PARTICIPANT	\N	PRESENT	0
634410	631575	19782L	PARTICIPANT	\N	PRESENT	0
634411	631575	19762G	PARTICIPANT	\N	PRESENT	0
634412	631575	14059S	PARTICIPANT	\N	PRESENT	0
634413	631575	20090E	PARTICIPANT	\N	PRESENT	0
634414	631575	20032T	PARTICIPANT	\N	PRESENT	0
634415	631575	19747H	PARTICIPANT	\N	PRESENT	0
634416	631575	19467C	PARTICIPANT	\N	PRESENT	0
634417	631575	19693L	PARTICIPANT	\N	PRESENT	0
634418	631575	19695N	PARTICIPANT	\N	PRESENT	0
634419	631575	14251Q	PARTICIPANT	\N	PRESENT	0
634422	631575	19647E	PARTICIPANT	\N	PRESENT	0
634426	631575	20122U	PARTICIPANT	\N	PRESENT	0
634427	631575	19701S	PARTICIPANT	\N	PRESENT	0
634395	631575	11070L	PARTICIPANT	\N	PRESENT	0
634396	631575	11090Q	PARTICIPANT	\N	PRESENT	0
634429	631575	19749K	PARTICIPANT	\N	PRESENT	0
634430	631575	20028X	PARTICIPANT	\N	PRESENT	0
634431	631575	20152B	PARTICIPANT	\N	PRESENT	0
634434	631575	11012A	PARTICIPANT	\N	PRESENT	0
634435	631575	19687N	PARTICIPANT	\N	PRESENT	0
634436	631575	07029T	PARTICIPANT	\N	PRESENT	0
634437	631575	01048V	PARTICIPANT	\N	PRESENT	0
634511	631576	19545Y	PARTICIPANT	\N	PRESENT	0
634512	631576	14219Q	PARTICIPANT	\N	PRESENT	0
634513	631576	01024M	PARTICIPANT	\N	PRESENT	0
634514	631576	20174H	PARTICIPANT	\N	PRESENT	0
634515	631576	20092G	PARTICIPANT	\N	PRESENT	0
634516	631576	20100N	PARTICIPANT	\N	PRESENT	0
634517	631576	19631V	PARTICIPANT	\N	PRESENT	0
634518	631576	20082E	PARTICIPANT	\N	PRESENT	0
634519	631576	20094J	PARTICIPANT	\N	PRESENT	0
634520	631576	14205J	PARTICIPANT	\N	PRESENT	0
634521	631576	19695N	PARTICIPANT	\N	PRESENT	0
634522	631576	20090E	PARTICIPANT	\N	PRESENT	0
634523	631576	20032T	PARTICIPANT	\N	PRESENT	0
634524	631576	07029T	PARTICIPANT	\N	PRESENT	0
634525	631576	14033T	PARTICIPANT	\N	PRESENT	0
634526	631576	01048V	PARTICIPANT	\N	PRESENT	0
634527	631576	19701S	PARTICIPANT	\N	PRESENT	0
634529	634528	14205J	PARTICIPANT	\N	PRESENT	0
634532	631576	20028X	PARTICIPANT	\N	PRESENT	0
634536	634534	19693L	PARTICIPANT	\N	EXCUSE	0
634537	634534	20128B	PARTICIPANT	\N	PRESENT	0
634538	634534	19735D	PARTICIPANT	\N	EXCUSE	0
634539	634534	01048V	PARTICIPANT	\N	PRESENT	0
634540	634534	11067R	PARTICIPANT	\N	PRESENT	0
634541	634534	19503N	PARTICIPANT	\N	PRESENT	0
634542	634534	04043D	PARTICIPANT	\N	PRESENT	0
634509	631576	11070L	PARTICIPANT	\N	PRESENT	0
634510	631576	11012A	PARTICIPANT	\N	PRESENT	0
634543	634534	01058X	PARTICIPANT	\N	PRESENT	0
634548	634535	19693L	PARTICIPANT	\N	EXCUSE	0
634549	634535	20128B	PARTICIPANT	\N	EXCUSE	0
634550	634535	19735D	PARTICIPANT	\N	EXCUSE	0
634551	634535	11067R	PARTICIPANT	\N	EXCUSE	0
634552	634535	19503N	PARTICIPANT	\N	PRESENT	0
634553	634535	04043D	PARTICIPANT	\N	PRESENT	0
634554	634535	01058X	PARTICIPANT	\N	PRESENT	0
634557	634535	19717B	PARTICIPANT	\N	PRESENT	0
634589	631139	10006L	PARTICIPANT	\N	PRESENT	0
634590	631139	11067R	PARTICIPANT	\N	PRESENT	0
634591	631139	14217N	PARTICIPANT	\N	PRESENT	0
634592	631139	11031D	PARTICIPANT	\N	PRESENT	0
634593	631139	19691J	PARTICIPANT	\N	PRESENT	0
634594	631139	20298U	PARTICIPANT	\N	PRESENT	0
634595	631139	19569H	PARTICIPANT	\N	PRESENT	1
634596	631139	20130U	PARTICIPANT	\N	PRESENT	1
634597	631139	14213J	PARTICIPANT	\N	PRESENT	1
634598	631139	19798U	PARTICIPANT	\N	PRESENT	1
634601	634600	10006L	PARTICIPANT	\N	PRESENT	0
634603	634602	10006L	PARTICIPANT	\N	PRESENT	0
634604	634602	01062T	PARTICIPANT	\N	PRESENT	0
634605	634602	19553Y	PARTICIPANT	\N	PRESENT	0
634706	634705	11101A	PARTICIPANT	\N	PRESENT	0
634707	634705	08028W	PARTICIPANT	\N	PRESENT	0
634826	634825	01048V	PARTICIPANT	\N	PRESENT	0
634827	634825	19735D	PARTICIPANT	\N	PRESENT	0
634828	634825	19503N	PARTICIPANT	\N	PRESENT	0
634829	634825	04043D	PARTICIPANT	\N	PRESENT	0
635292	635291	20024T	PARTICIPANT	\N	PRESENT	0
635775	634461	14281W	PARTICIPANT	\N	PRESENT	0
635776	634461	17779H	PARTICIPANT	\N	PRESENT	0
635782	634461	11045K	PARTICIPANT	\N	PRESENT	0
635784	634461	20298U	PARTICIPANT	\N	PRESENT	0
635786	635785	14089Y	PARTICIPANT	\N	PRESENT	0
635787	635785	11056N	PARTICIPANT	\N	PRESENT	0
635788	635785	95063L	PARTICIPANT	\N	PRESENT	0
635801	635800	14033T	PARTICIPANT	\N	PRESENT	0
635802	635800	14205J	PARTICIPANT	\N	PRESENT	0
635803	635800	19467C	PARTICIPANT	\N	PRESENT	0
635804	635800	14257W	PARTICIPANT	\N	PRESENT	0
635805	635800	19413M	PARTICIPANT	\N	PRESENT	0
635806	635800	20144B	PARTICIPANT	\N	PRESENT	0
635807	635800	01025N	PARTICIPANT	\N	PRESENT	0
635808	635800	19782L	PARTICIPANT	\N	PRESENT	0
635809	635800	14207L	PARTICIPANT	\N	PRESENT	0
635812	635811	19782L	PARTICIPANT	\N	PRESENT	0
635813	635811	14207L	PARTICIPANT	\N	PRESENT	0
635814	635811	14205J	PARTICIPANT	\N	PRESENT	0
635815	635811	14033T	PARTICIPANT	\N	PRESENT	0
635816	635811	20018V	PARTICIPANT	\N	PRESENT	0
635817	635811	14257W	PARTICIPANT	\N	PRESENT	0
635823	635822	19782L	PARTICIPANT	\N	PRESENT	0
635824	635822	14033T	PARTICIPANT	\N	PRESENT	0
635825	635822	14205J	PARTICIPANT	\N	PRESENT	0
635826	635822	14257W	PARTICIPANT	\N	PRESENT	0
635827	635822	20018V	PARTICIPANT	\N	PRESENT	0
635828	635822	19413M	PARTICIPANT	\N	PRESENT	0
635829	635822	20144B	PARTICIPANT	\N	PRESENT	0
635830	635822	14207L	PARTICIPANT	\N	PRESENT	0
635831	634461	19697Q	PARTICIPANT	\N	PRESENT	0
635839	635838	20070A	PARTICIPANT	\N	PRESENT	0
635840	635838	20106U	PARTICIPANT	\N	PRESENT	0
635841	635838	08015R	PARTICIPANT	\N	PRESENT	0
635842	635838	01043Q	PARTICIPANT	\N	PRESENT	0
635843	635838	14001X	PARTICIPANT	\N	PRESENT	0
635845	635838	14225N	PARTICIPANT	\N	PRESENT	0
635846	635838	19585H	PARTICIPANT	\N	PRESENT	0
635855	635852	10006L	PARTICIPANT	\N	PRESENT	0
635856	635852	19723Y	PARTICIPANT	\N	PRESENT	0
635857	635852	19703U	PARTICIPANT	\N	PRESENT	1
635858	635852	20130U	PARTICIPANT	\N	PRESENT	0
635867	634460	11048N	PARTICIPANT	\N	PRESENT	1
635868	634460	14121F	PARTICIPANT	\N	PRESENT	1
635871	634588	19760E	PARTICIPANT	\N	PRESENT	0
635872	634588	14195A	PARTICIPANT	\N	PRESENT	0
635873	634588	14026U	PARTICIPANT	\N	PRESENT	0
635874	634588	14281W	PARTICIPANT	\N	PRESENT	0
635875	634588	17779H	PARTICIPANT	\N	PRESENT	1
635876	634588	18193Q	PARTICIPANT	\N	PRESENT	0
635877	634588	08045X	PARTICIPANT	\N	PRESENT	1
635878	634588	14042U	PARTICIPANT	\N	PRESENT	0
635879	634588	19553Y	PARTICIPANT	\N	PRESENT	0
635880	634588	11097X	PRESIDENT	0	PRESENT	0
635906	634588	01034P	PARTICIPANT	\N	PRESENT	0
635907	634588	20066E	PARTICIPANT	\N	PRESENT	0
636182	635785	11026G	PARTICIPANT	\N	PRESENT	0
636183	635785	20108W	PARTICIPANT	\N	PRESENT	0
636227	636226	19507S	PARTICIPANT	\N	PRESENT	0
636228	636226	08015R	PARTICIPANT	\N	PRESENT	0
628847	626880	08073C	PARTICIPANT	\N	PRESENT	0
628860	626880	11065P	PARTICIPANT	\N	PRESENT	0
628861	626880	17737W	PARTICIPANT	\N	PRESENT	0
628862	626880	20090E	PARTICIPANT	\N	PRESENT	0
628863	626880	20052X	PARTICIPANT	\N	PRESENT	0
628864	626880	14038Y	PARTICIPANT	\N	PRESENT	0
628865	626880	14229S	PARTICIPANT	\N	PRESENT	0
628866	626880	19533U	PARTICIPANT	\N	PRESENT	0
628867	626880	14207L	PARTICIPANT	\N	PRESENT	0
628868	626880	19575F	PARTICIPANT	\N	PRESENT	0
628897	626880	20252E	PARTICIPANT	\N	PRESENT	0
628903	626880	20024T	PARTICIPANT	\N	PRESENT	0
628904	626880	19798U	PARTICIPANT	\N	PRESENT	0
628909	626880	17229F	PARTICIPANT	\N	PRESENT	0
628910	626880	16685X	PARTICIPANT	\N	PRESENT	0
628911	626880	17779H	PARTICIPANT	\N	PRESENT	0
628935	626880	19563B	PARTICIPANT	\N	PRESENT	0
628994	626880	19515S	PARTICIPANT	\N	PRESENT	0
628995	626880	19599P	PARTICIPANT	\N	PRESENT	0
628999	626880	18083K	PARTICIPANT	\N	PRESENT	0
629003	626880	20068G	PARTICIPANT	\N	PRESENT	0
629004	626880	19954N	PARTICIPANT	\N	PRESENT	0
629005	626880	19441R	PARTICIPANT	\N	PRESENT	0
629035	626880	20104S	PARTICIPANT	\N	PRESENT	0
629036	626880	19719D	PARTICIPANT	\N	PRESENT	0
629037	626880	14089Y	PARTICIPANT	\N	PRESENT	0
629038	626880	08010L	PARTICIPANT	\N	PRESENT	0
629039	626880	05012A	PARTICIPANT	\N	PRESENT	0
629046	626880	19691J	PARTICIPANT	\N	PRESENT	0
629080	626881	20040T	PARTICIPANT	\N	PRESENT	0
629081	626881	20116W	PARTICIPANT	\N	PRESENT	0
629082	626881	19251M	PARTICIPANT	\N	PRESENT	0
629083	626881	20174H	PARTICIPANT	\N	PRESENT	0
629065	626881	19719D	PARTICIPANT	\N	PRESENT	0
629079	626881	19347U	PARTICIPANT	\N	PRESENT	0
629084	626881	19629C	PARTICIPANT	\N	PRESENT	0
629085	626881	19301E	PARTICIPANT	\N	PRESENT	0
629086	626881	20050V	PARTICIPANT	\N	PRESENT	0
629087	626881	19515S	PARTICIPANT	\N	PRESENT	0
629088	626881	19689Q	PARTICIPANT	\N	PRESENT	0
629089	626881	11077T	PARTICIPANT	\N	PRESENT	0
629090	626881	19441R	PARTICIPANT	\N	PRESENT	0
629091	626881	19503N	PARTICIPANT	\N	PRESENT	0
629092	626881	14069U	PARTICIPANT	\N	PRESENT	0
629093	626881	20264J	PARTICIPANT	\N	PRESENT	0
629094	626881	19399H	PARTICIPANT	\N	PRESENT	0
629095	626881	14237S	PARTICIPANT	\N	PRESENT	0
629096	626881	19954N	PARTICIPANT	\N	PRESENT	0
629097	626881	20096L	PARTICIPANT	\N	PRESENT	0
629098	626881	20092G	PARTICIPANT	\N	PRESENT	0
629099	626881	11097X	PARTICIPANT	\N	PRESENT	0
629100	626881	14357A	PARTICIPANT	\N	PRESENT	0
629104	626881	14275Y	PARTICIPANT	\N	PRESENT	0
629106	626881	97011G	PARTICIPANT	\N	PRESENT	0
629108	626881	20090E	PARTICIPANT	\N	PRESENT	0
629109	626881	14038Y	PARTICIPANT	\N	PRESENT	0
629110	626881	11040E	PARTICIPANT	\N	PRESENT	0
629111	626881	11033F	PARTICIPANT	\N	PRESENT	0
629115	626881	19711U	PARTICIPANT	\N	PRESENT	0
629116	626881	19599P	PARTICIPANT	\N	PRESENT	0
629119	626881	14030Q	PARTICIPANT	\N	PRESENT	0
629121	626881	17023S	PARTICIPANT	\N	PRESENT	0
629125	626881	20024T	PARTICIPANT	\N	PRESENT	0
629126	626881	19693L	PARTICIPANT	\N	PRESENT	0
629127	626881	14195A	PARTICIPANT	\N	PRESENT	0
629128	626881	11085T	PARTICIPANT	\N	PRESENT	0
629129	626881	14026U	PARTICIPANT	\N	PRESENT	0
629131	626881	11045K	PARTICIPANT	\N	PRESENT	0
629132	626881	19649G	PARTICIPANT	\N	PRESENT	0
629133	626881	11072N	PARTICIPANT	\N	PRESENT	0
629134	626881	14189C	PARTICIPANT	\N	PRESENT	0
629170	626882	19629C	PARTICIPANT	\N	PRESENT	0
629171	626882	14195A	PARTICIPANT	\N	PRESENT	0
629172	626882	11040E	PARTICIPANT	\N	PRESENT	0
629173	626882	20024T	PARTICIPANT	\N	PRESENT	0
629174	626882	14030Q	PARTICIPANT	\N	PRESENT	0
629175	626882	11045K	PARTICIPANT	\N	PRESENT	0
629176	626882	19649G	PARTICIPANT	\N	PRESENT	0
629177	626882	19689Q	PARTICIPANT	\N	PRESENT	0
629178	626882	19599P	PARTICIPANT	\N	PRESENT	0
629179	626882	19693L	PARTICIPANT	\N	PRESENT	0
629183	626882	20264J	PARTICIPANT	\N	PRESENT	0
629181	626882	14189C	PARTICIPANT	\N	PRESENT	0
629182	626882	20098N	PARTICIPANT	\N	PRESENT	0
629184	626882	11077T	PARTICIPANT	\N	PRESENT	0
629185	626882	14275Y	PARTICIPANT	\N	PRESENT	0
629186	626882	14026U	PARTICIPANT	\N	PRESENT	0
629187	626882	19711U	PARTICIPANT	\N	PRESENT	0
629188	626882	14357A	PARTICIPANT	\N	PRESENT	0
629189	626882	11072N	PARTICIPANT	\N	PRESENT	0
629190	626882	20116W	PARTICIPANT	\N	PRESENT	0
629191	626882	11085T	PARTICIPANT	\N	PRESENT	0
629192	626882	19954N	PARTICIPANT	\N	PRESENT	0
629193	626882	19467C	PARTICIPANT	\N	PRESENT	0
629196	626882	17779H	PARTICIPANT	\N	PRESENT	0
629199	626882	11033F	PARTICIPANT	\N	PRESENT	0
629200	626882	19413M	PARTICIPANT	\N	PRESENT	0
629202	626882	19866P	PARTICIPANT	\N	PRESENT	0
629203	626882	19441R	PARTICIPANT	\N	PRESENT	0
629211	626882	20082E	PARTICIPANT	\N	PRESENT	0
629212	626882	19762G	PARTICIPANT	\N	PRESENT	0
629213	626882	20108W	PARTICIPANT	\N	PRESENT	0
629256	626882	19515S	PARTICIPANT	\N	PRESENT	0
629257	626882	19695N	PARTICIPANT	\N	PRESENT	0
629168	626882	19719D	PARTICIPANT	\N	PRESENT	0
629169	626882	11031D	PARTICIPANT	\N	PRESENT	0
629258	626882	19551W	PARTICIPANT	\N	PRESENT	0
629283	626884	19711U	PARTICIPANT	\N	PRESENT	0
629284	626884	19762G	PARTICIPANT	\N	PRESENT	0
629285	626884	19954N	PARTICIPANT	\N	PRESENT	0
629286	626884	19515S	PARTICIPANT	\N	PRESENT	0
629287	626884	14229S	PARTICIPANT	\N	PRESENT	0
629288	626884	20082E	PARTICIPANT	\N	PRESENT	0
629289	626884	19413M	PARTICIPANT	\N	PRESENT	0
629290	626884	19551W	PARTICIPANT	\N	PRESENT	0
629291	626884	14189C	PARTICIPANT	\N	PRESENT	0
629292	626884	19335Q	PARTICIPANT	\N	PRESENT	0
629293	626884	19695N	PARTICIPANT	\N	PRESENT	0
629294	626884	11031D	PARTICIPANT	\N	PRESENT	0
629295	626884	19591F	PARTICIPANT	\N	PRESENT	0
629296	626884	14251Q	PARTICIPANT	\N	PRESENT	0
629297	626884	19531S	PARTICIPANT	\N	PRESENT	0
629298	626884	19747H	PARTICIPANT	\N	PRESENT	0
629299	626884	14026U	PARTICIPANT	\N	PRESENT	0
629300	626884	19629C	PARTICIPANT	\N	PRESENT	0
629304	626884	19719D	PARTICIPANT	\N	PRESENT	0
631881	631641	19691J	PARTICIPANT	\N	EXCUSE	0
635568	634329	11033F	PARTICIPANT	\N	PRESENT	1
635569	634329	14107H	PARTICIPANT	\N	PRESENT	1
629281	626884	19866P	PARTICIPANT	\N	PRESENT	0
629282	626884	19689Q	PARTICIPANT	\N	PRESENT	0
635863	634330	11033F	PARTICIPANT	\N	PRESENT	1
635864	634330	14179A	PARTICIPANT	\N	PRESENT	1
635865	634330	19489J	PARTICIPANT	\N	PRESENT	1
635866	634330	19675J	PARTICIPANT	\N	PRESENT	1
637325	635772	14207L	PARTICIPANT	\N	EXCUSE	0
637326	635772	20094J	PARTICIPANT	\N	PRESENT	1
637327	635772	20104S	PARTICIPANT	\N	PRESENT	0
637328	635772	11101A	PARTICIPANT	\N	PRESENT	0
637329	635772	19701S	PARTICIPANT	\N	PRESENT	0
637330	635772	14357A	PARTICIPANT	\N	PRESENT	0
637331	635772	19507S	PARTICIPANT	\N	PRESENT	0
637332	635772	20100N	PARTICIPANT	\N	PRESENT	0
637333	635772	14033T	PARTICIPANT	\N	PRESENT	0
637334	635772	14026U	PARTICIPANT	\N	PRESENT	0
637335	635772	20128B	PARTICIPANT	\N	PRESENT	1
637336	635772	19333N	PARTICIPANT	\N	PRESENT	0
637337	635772	19531S	PARTICIPANT	\N	PRESENT	0
637338	635772	14097Y	PARTICIPANT	\N	PRESENT	0
637339	635772	14073Q	PARTICIPANT	\N	PRESENT	0
637340	635772	19711U	PARTICIPANT	\N	PRESENT	0
637341	635772	12041X	PARTICIPANT	\N	PRESENT	0
637342	635772	11026G	PARTICIPANT	\N	PRESENT	0
637343	635772	08034U	PARTICIPANT	\N	PRESENT	0
637344	635772	19441R	PARTICIPANT	\N	PRESENT	0
637345	635772	14001X	PARTICIPANT	\N	PRESENT	0
637346	635772	19563B	PARTICIPANT	\N	PRESENT	0
637347	635772	14169X	PARTICIPANT	\N	PRESENT	0
637348	635772	14237S	PARTICIPANT	\N	PRESENT	0
637349	635772	10015M	PARTICIPANT	\N	PRESENT	0
637350	635772	14331P	PRESIDENT	0	PRESENT	0
644362	644006	08012N	PARTICIPANT	\N	PRESENT	0
644363	644006	11043H	PARTICIPANT	\N	PRESENT	0
644364	644006	20022R	PARTICIPANT	\N	PRESENT	1
644365	644006	19758L	PARTICIPANT	\N	PRESENT	1
644366	644006	20026V	PARTICIPANT	\N	PRESENT	0
644367	644006	14021P	PARTICIPANT	\N	PRESENT	0
644369	644368	19741B	PARTICIPANT	\N	PRESENT	0
644778	644777	08010L	PARTICIPANT	\N	PRESENT	0
644779	644777	19693L	PARTICIPANT	\N	PRESENT	0
644808	644777	19479G	PARTICIPANT	\N	PRESENT	0
644809	644777	14151M	PARTICIPANT	\N	PRESENT	0
644821	644311	20076G	PARTICIPANT	\N	PRESENT	0
644822	644311	20024T	PARTICIPANT	\N	PRESENT	0
644823	644311	19549D	PARTICIPANT	\N	PRESENT	0
644824	644311	18083K	PARTICIPANT	\N	PRESENT	0
644825	644311	19701S	PARTICIPANT	\N	PRESENT	0
644834	644311	19681G	PARTICIPANT	\N	PRESENT	0
644835	644311	11065P	PARTICIPANT	\N	PRESENT	0
644836	644311	17229F	PARTICIPANT	\N	PRESENT	0
644837	644311	19251M	PARTICIPANT	\N	PRESENT	0
644838	644311	19333N	PARTICIPANT	\N	PRESENT	0
644839	644311	14219Q	PARTICIPANT	\N	PRESENT	0
644840	644311	14031R	PARTICIPANT	\N	PRESENT	0
644841	644311	19826F	PARTICIPANT	\N	PRESENT	0
644842	644311	19503N	PARTICIPANT	\N	PRESENT	0
644843	644311	20020P	PARTICIPANT	\N	PRESENT	0
644844	644311	20032T	PARTICIPANT	\N	PRESENT	1
644845	644311	17367Q	PARTICIPANT	\N	PRESENT	1
644846	644311	20140W	PARTICIPANT	\N	PRESENT	1
644847	644311	19577H	PARTICIPANT	\N	PRESENT	1
644848	644311	20120S	PARTICIPANT	\N	PRESENT	1
644849	644311	19387D	PARTICIPANT	\N	PRESENT	1
644850	644311	19637C	PARTICIPANT	\N	PRESENT	1
644851	644311	19745F	PARTICIPANT	\N	PRESENT	1
644852	644311	19739H	PARTICIPANT	\N	PRESENT	1
644853	644311	20046A	PARTICIPANT	\N	PRESENT	1
645199	645198	07033P	PARTICIPANT	\N	PRESENT	0
645200	645198	19443T	PARTICIPANT	\N	PRESENT	0
645493	645492	05008E	PARTICIPANT	\N	PRESENT	0
645494	645492	11053K	PARTICIPANT	\N	PRESENT	0
645495	645492	01028R	PARTICIPANT	\N	PRESENT	0
645547	645535	14257W	PARTICIPANT	\N	PRESENT	1
645548	645535	20042V	PARTICIPANT	\N	PRESENT	1
645647	645645	19631V	PARTICIPANT	\N	PRESENT	0
645648	645645	14187A	PARTICIPANT	\N	PRESENT	0
645650	645649	19631V	PARTICIPANT	\N	PRESENT	0
645651	645649	14187A	PARTICIPANT	\N	PRESENT	0
645653	645652	19631V	PARTICIPANT	\N	PRESENT	0
645654	645652	14187A	PARTICIPANT	\N	PRESENT	0
645657	645655	19631V	PARTICIPANT	\N	PRESENT	0
645658	645655	14187A	PARTICIPANT	\N	PRESENT	0
645659	645655	01043Q	PARTICIPANT	\N	PRESENT	0
645661	645660	19631V	PARTICIPANT	\N	PRESENT	0
645662	645660	14187A	PARTICIPANT	\N	PRESENT	0
645663	645660	01043Q	PARTICIPANT	\N	PRESENT	0
645665	645664	19631V	PARTICIPANT	\N	PRESENT	0
645666	645664	14187A	PARTICIPANT	\N	PRESENT	0
645667	645664	01043Q	PARTICIPANT	\N	PRESENT	0
645669	645668	19631V	PARTICIPANT	\N	PRESENT	0
645671	645670	19631V	PARTICIPANT	\N	PRESENT	0
645673	645672	19631V	PARTICIPANT	\N	PRESENT	0
645675	645674	19631V	PARTICIPANT	\N	PRESENT	0
645676	645674	14187A	PARTICIPANT	\N	PRESENT	0
645677	645674	01043Q	PARTICIPANT	\N	PRESENT	0
645679	645678	19631V	PARTICIPANT	\N	PRESENT	0
645680	645678	14187A	PARTICIPANT	\N	PRESENT	0
645685	645682	19631V	PARTICIPANT	\N	PRESENT	0
645688	645682	14187A	PARTICIPANT	\N	PRESENT	0
645690	645682	01043Q	PARTICIPANT	\N	PRESENT	0
645704	645703	14147R	PARTICIPANT	\N	PRESENT	0
645705	645703	19725B	PARTICIPANT	\N	PRESENT	0
645724	644649	19717B	PARTICIPANT	\N	PRESENT	1
645725	644649	19631V	PARTICIPANT	\N	EXCUSE	0
645726	644649	14053L	PARTICIPANT	\N	PRESENT	0
645727	644649	19577H	PARTICIPANT	\N	PRESENT	1
645728	644649	19329S	PARTICIPANT	\N	PRESENT	0
645729	644649	20034V	PARTICIPANT	\N	PRESENT	1
645730	644649	14097Y	PARTICIPANT	\N	EXCUSE	0
645731	644649	19657G	PARTICIPANT	\N	EXCUSE	0
645732	644649	14147R	PARTICIPANT	\N	PRESENT	1
645733	644649	11072N	PARTICIPANT	\N	PRESENT	0
645734	644649	08073C	PARTICIPANT	\N	PRESENT	0
645735	644649	20146D	PARTICIPANT	\N	PRESENT	0
645736	644649	14331P	PARTICIPANT	\N	EXCUSE	0
645737	644649	20150Y	PARTICIPANT	\N	PRESENT	1
645738	644649	19301E	PARTICIPANT	\N	PRESENT	0
645767	645579	04092N	PARTICIPANT	\N	PRESENT	0
645768	645579	20022R	PARTICIPANT	\N	PRESENT	1
645769	645579	16685X	PARTICIPANT	\N	PRESENT	0
645770	645579	14189C	PARTICIPANT	\N	PRESENT	0
645771	645579	20104S	PRESIDENT	1	PRESENT	0
645772	645579	19701S	PARTICIPANT	\N	PRESENT	0
645773	645579	19681G	PARTICIPANT	\N	PRESENT	0
645774	645579	20100N	PARTICIPANT	\N	PRESENT	0
645775	645579	08018U	PARTICIPANT	\N	PRESENT	0
645776	645579	19711U	PARTICIPANT	\N	PRESENT	0
645777	645579	11026G	PARTICIPANT	\N	PRESENT	0
645778	645579	14001X	PARTICIPANT	\N	PRESENT	0
645779	645579	14169X	PARTICIPANT	\N	PRESENT	0
645780	645579	04045F	PARTICIPANT	\N	PRESENT	0
645781	645579	10015M	PARTICIPANT	\N	PRESENT	0
645782	645579	14331P	PRESIDENT	0	PRESENT	0
645789	645490	14327T	PRESIDENT	0	PRESENT	0
645790	645490	20086J	PARTICIPANT	\N	PRESENT	0
645791	645490	14331P	PARTICIPANT	\N	PRESENT	0
645792	645490	11048N	PARTICIPANT	\N	PRESENT	0
645793	645490	19479G	PRESIDENT	1	PRESENT	0
645883	645312	11026G	PARTICIPANT	\N	PRESENT	1
645795	645490	20036X	PARTICIPANT	\N	PRESENT	0
645796	645490	19711U	PARTICIPANT	\N	PRESENT	0
645797	645490	14189C	PARTICIPANT	\N	PRESENT	0
645798	645490	20080C	PARTICIPANT	\N	PRESENT	0
645799	645490	19671E	PARTICIPANT	\N	PRESENT	0
645800	645490	20070A	PARTICIPANT	\N	PRESENT	0
645801	645490	19349W	PARTICIPANT	\N	PRESENT	0
645802	645490	08010L	PARTICIPANT	\N	PRESENT	0
645803	645490	99004R	PARTICIPANT	\N	PRESENT	0
645804	645490	14253S	PARTICIPANT	\N	PRESENT	0
645805	645490	19335Q	PARTICIPANT	\N	PRESENT	0
645806	645490	19762G	PARTICIPANT	\N	PRESENT	0
645807	645490	14225N	PARTICIPANT	\N	EXCUSE	0
645881	645312	20020P	PARTICIPANT	\N	PRESENT	0
645882	645312	20100N	PARTICIPANT	\N	PRESENT	0
645884	645312	17229F	PARTICIPANT	\N	PRESENT	0
645885	645312	19369B	PARTICIPANT	\N	PRESENT	0
645886	645312	14207L	PARTICIPANT	\N	PRESENT	1
645887	645312	19671E	PARTICIPANT	\N	PRESENT	0
645888	645312	14053L	PARTICIPANT	\N	PRESENT	0
645889	645312	17367Q	PARTICIPANT	\N	PRESENT	0
645890	645312	14001X	PARTICIPANT	\N	PRESENT	0
645891	645312	19701S	PARTICIPANT	\N	PRESENT	1
645892	645312	19681G	PARTICIPANT	\N	PRESENT	1
645893	645312	14179A	PARTICIPANT	\N	PRESENT	1
645894	645312	20140W	PARTICIPANT	\N	PRESENT	1
645895	645312	19577H	PARTICIPANT	\N	PRESENT	1
645896	645312	20068G	PARTICIPANT	\N	PRESENT	1
645897	645460	11067R	PARTICIPANT	\N	PRESENT	0
645898	645460	19569H	PARTICIPANT	\N	PRESENT	0
645899	645460	20040T	PARTICIPANT	\N	PRESENT	0
645900	645460	20248J	PARTICIPANT	\N	PRESENT	0
645908	645490	07029T	PARTICIPANT	\N	EXCUSE	0
645909	645312	20032T	PARTICIPANT	\N	PRESENT	0
645910	645312	20042V	PARTICIPANT	\N	PRESENT	1
645913	645312	19739H	PARTICIPANT	\N	PRESENT	1
645914	645312	18083K	PARTICIPANT	\N	PRESENT	1
645915	645312	19251M	PARTICIPANT	\N	EXCUSE	0
645925	645312	20120S	PARTICIPANT	\N	PRESENT	0
645926	645312	19569H	PARTICIPANT	\N	PRESENT	0
645927	645312	19383Y	PARTICIPANT	\N	PRESENT	1
645928	645335	04070G	PARTICIPANT	\N	PRESENT	0
645929	645335	04033B	PARTICIPANT	\N	PRESENT	0
645930	645335	14229S	PARTICIPANT	\N	PRESENT	0
645931	645335	20098N	PARTICIPANT	\N	PRESENT	0
645932	645335	19573D	PARTICIPANT	\N	PRESENT	0
645933	645335	20112S	PARTICIPANT	\N	PRESENT	0
645934	645335	20124W	PARTICIPANT	\N	PRESENT	0
645935	645335	19527W	PARTICIPANT	\N	PRESENT	0
645936	645335	19643A	PARTICIPANT	\N	PRESENT	0
645937	645335	20132W	PARTICIPANT	\N	PRESENT	0
645938	645335	20138D	PARTICIPANT	\N	PRESENT	0
645939	645335	19611R	PRESIDENT	0	PRESENT	0
628048	626873	20132W	PARTICIPANT	\N	PRESENT	0
628049	626873	19511N	PARTICIPANT	\N	PRESENT	0
628050	626873	19629C	PARTICIPANT	\N	PRESENT	0
628052	626873	19387D	PARTICIPANT	\N	PRESENT	0
628053	626873	11012A	PARTICIPANT	\N	PRESENT	0
628054	626873	20148F	PARTICIPANT	\N	PRESENT	0
628055	626873	20104S	PARTICIPANT	\N	PRESENT	0
628056	626873	19667J	PARTICIPANT	\N	PRESENT	0
628057	626873	11033F	PARTICIPANT	\N	PRESENT	0
628058	626873	19621T	PARTICIPANT	\N	PRESENT	0
628059	626873	19333N	PARTICIPANT	\N	PRESENT	0
628060	626873	20134Y	PARTICIPANT	\N	PRESENT	0
628061	626873	14207L	PARTICIPANT	\N	PRESENT	0
628062	626873	04059M	PARTICIPANT	\N	PRESENT	0
628063	626873	19599P	PARTICIPANT	\N	PRESENT	0
628064	626873	20052X	PARTICIPANT	\N	PRESENT	0
628065	626873	19826F	PARTICIPANT	\N	PRESENT	0
628066	626873	14267Y	PARTICIPANT	\N	PRESENT	0
628067	626873	01025N	PARTICIPANT	\N	PRESENT	0
628068	626873	19739H	PARTICIPANT	\N	PRESENT	0
628069	626873	19415P	PARTICIPANT	\N	PRESENT	0
628070	626873	11080N	PARTICIPANT	\N	PRESENT	0
628071	626873	19705W	PARTICIPANT	\N	PRESENT	0
628072	626873	19707Y	PARTICIPANT	\N	PRESENT	0
628073	626873	11097X	PARTICIPANT	\N	PRESENT	0
628074	626873	04092N	PARTICIPANT	\N	PRESENT	0
628075	626873	11040E	PARTICIPANT	\N	PRESENT	0
628076	626873	19758L	PARTICIPANT	\N	PRESENT	0
628077	626873	04085P	PARTICIPANT	\N	PRESENT	0
628078	626873	20102Q	PARTICIPANT	\N	PRESENT	0
628079	626873	19687N	PARTICIPANT	\N	PRESENT	0
628080	626873	19695N	PARTICIPANT	\N	PRESENT	0
628081	626873	19711U	PARTICIPANT	\N	PRESENT	0
628083	626873	17637T	PARTICIPANT	\N	PRESENT	0
628084	626873	19703U	PARTICIPANT	\N	PRESENT	0
628085	626873	20110Q	PARTICIPANT	\N	PRESENT	0
628086	626873	04035D	PARTICIPANT	\N	PRESENT	0
628087	626873	20130U	PARTICIPANT	\N	PRESENT	0
628088	626873	19689Q	PARTICIPANT	\N	PRESENT	0
628089	626873	19693L	PARTICIPANT	\N	PRESENT	0
628090	626873	19575F	PARTICIPANT	\N	PRESENT	0
628091	626873	19651A	PARTICIPANT	\N	PRESENT	0
628092	626873	08061X	PARTICIPANT	\N	PRESENT	0
628093	626873	11072N	PARTICIPANT	\N	PRESENT	0
628094	626873	19301E	PARTICIPANT	\N	PRESENT	0
628095	626873	19591F	PARTICIPANT	\N	PRESENT	0
628096	626873	04045F	PARTICIPANT	\N	PRESENT	0
628097	626873	08010L	PARTICIPANT	\N	PRESENT	0
628098	626873	20128B	PARTICIPANT	\N	PRESENT	0
628099	626873	11083R	PARTICIPANT	\N	PRESENT	0
628100	626873	20106U	PARTICIPANT	\N	PRESENT	0
628101	626873	04047H	PARTICIPANT	\N	PRESENT	0
628102	626873	19697Q	PARTICIPANT	\N	PRESENT	0
628103	626873	14249W	PARTICIPANT	\N	PRESENT	0
628104	626873	19782L	PARTICIPANT	\N	PRESENT	0
628105	626873	01058X	PARTICIPANT	\N	PRESENT	0
628106	626873	14195A	PARTICIPANT	\N	PRESENT	0
628107	626873	19679N	PARTICIPANT	\N	PRESENT	0
628108	626873	14251Q	PARTICIPANT	\N	PRESENT	0
628109	626873	20050V	PARTICIPANT	\N	PRESENT	0
628110	626873	20074E	PARTICIPANT	\N	PRESENT	0
628111	626873	19563B	PARTICIPANT	\N	PRESENT	0
628112	626873	11064N	PARTICIPANT	\N	PRESENT	0
628113	626873	04057K	PARTICIPANT	\N	PRESENT	0
628114	626873	19329S	PARTICIPANT	\N	PRESENT	0
628115	626873	19719D	PARTICIPANT	\N	PRESENT	0
628116	626873	18083K	PARTICIPANT	\N	PRESENT	0
628117	626873	04042C	PARTICIPANT	\N	PRESENT	0
628118	626873	14021P	PARTICIPANT	\N	PRESENT	0
628119	626873	11048N	PARTICIPANT	\N	PRESENT	0
628120	626873	14229S	PARTICIPANT	\N	PRESENT	0
628121	626873	19683J	PARTICIPANT	\N	PRESENT	0
628122	626873	19647E	PARTICIPANT	\N	PRESENT	0
628123	626873	14151M	PARTICIPANT	\N	PRESENT	0
628124	626873	20028X	PARTICIPANT	\N	PRESENT	0
628125	626873	14071N	PARTICIPANT	\N	PRESENT	0
628126	626873	11067R	PARTICIPANT	\N	PRESENT	0
628127	626873	19669L	PARTICIPANT	\N	PRESENT	0
628128	626873	11056N	PARTICIPANT	\N	PRESENT	0
628129	626873	04033B	PARTICIPANT	\N	PRESENT	0
628130	626873	01062T	PARTICIPANT	\N	PRESENT	0
628131	626873	19820Y	PARTICIPANT	\N	PRESENT	0
628132	626873	01048V	PARTICIPANT	\N	PRESENT	0
628133	626873	08012N	PARTICIPANT	\N	PRESENT	0
628134	626873	20070A	PARTICIPANT	\N	PRESENT	0
628135	626873	20080C	PARTICIPANT	\N	PRESENT	0
628136	626873	10015M	PARTICIPANT	\N	PRESENT	0
628137	626873	19413M	PARTICIPANT	\N	PRESENT	0
628138	626873	14281W	PARTICIPANT	\N	PRESENT	0
628139	626873	19549D	PARTICIPANT	\N	PRESENT	0
628140	626873	20142Y	PARTICIPANT	\N	PRESENT	0
628141	626873	01057W	PARTICIPANT	\N	PRESENT	0
628142	626873	20084G	PARTICIPANT	\N	PRESENT	0
628143	626873	20022R	PARTICIPANT	\N	PRESENT	0
628144	626873	19503N	PARTICIPANT	\N	PRESENT	0
628145	626873	12028B	PARTICIPANT	\N	PRESENT	0
628146	626873	20082E	PARTICIPANT	\N	PRESENT	0
628147	626873	05012A	PARTICIPANT	\N	PRESENT	0
628148	626873	12016W	PARTICIPANT	\N	PRESENT	0
628149	626873	20094J	PARTICIPANT	\N	PRESENT	0
628150	626873	04043D	PARTICIPANT	\N	PRESENT	0
628151	626873	20088L	PARTICIPANT	\N	PRESENT	0
628152	626873	19251M	PARTICIPANT	\N	PRESENT	0
628153	626873	14069U	PARTICIPANT	\N	PRESENT	0
628154	626873	19631V	PARTICIPANT	\N	PRESENT	0
628155	626873	14053L	PARTICIPANT	\N	PRESENT	0
628156	626873	14215L	PARTICIPANT	\N	PRESENT	0
628157	626873	01028R	PARTICIPANT	\N	PRESENT	0
628158	626873	14193X	PARTICIPANT	\N	PRESENT	0
628159	626873	11031D	PARTICIPANT	\N	PRESENT	0
628160	626873	19798U	PARTICIPANT	\N	PRESENT	0
628161	626873	19533U	PARTICIPANT	\N	PRESENT	0
628162	626873	20064C	PARTICIPANT	\N	PRESENT	0
628163	626873	17965H	PARTICIPANT	\N	PRESENT	0
628164	626873	95041E	PARTICIPANT	\N	PRESENT	0
628165	626873	20054A	PARTICIPANT	\N	PRESENT	0
628166	626873	20252E	PARTICIPANT	\N	PRESENT	0
628167	626873	14275Y	PARTICIPANT	\N	PRESENT	0
628168	626873	14217N	PARTICIPANT	\N	PRESENT	0
628169	626873	19319Q	PARTICIPANT	\N	PRESENT	0
628170	626873	19713W	PARTICIPANT	\N	PRESENT	0
628171	626873	97011G	PARTICIPANT	\N	PRESENT	0
628172	626873	14042U	PARTICIPANT	\N	PRESENT	0
628173	626873	20120S	PARTICIPANT	\N	PRESENT	0
628174	626873	14219Q	PARTICIPANT	\N	PRESENT	0
628175	626873	19619A	PARTICIPANT	\N	PRESENT	0
628176	626873	16685X	PARTICIPANT	\N	PRESENT	0
628177	626873	20020P	PARTICIPANT	\N	PRESENT	0
628178	626873	20144B	PARTICIPANT	\N	PRESENT	0
628179	626873	11053K	PARTICIPANT	\N	PRESENT	0
628180	626873	19762G	PARTICIPANT	\N	PRESENT	0
628181	626873	08009T	PARTICIPANT	\N	PRESENT	0
628182	626873	19369B	PARTICIPANT	\N	PRESENT	0
628183	626873	19347U	PARTICIPANT	\N	PRESENT	0
628184	626873	19671E	PARTICIPANT	\N	PRESENT	0
628185	626873	19611R	PARTICIPANT	\N	PRESENT	0
628186	626873	19691J	PARTICIPANT	\N	PRESENT	0
628187	626873	19745F	PARTICIPANT	\N	PRESENT	0
628188	626873	14357A	PARTICIPANT	\N	PRESENT	0
628189	626873	17229F	PARTICIPANT	\N	PRESENT	0
628190	626873	14030Q	PARTICIPANT	\N	PRESENT	0
628191	626873	14327T	PARTICIPANT	\N	PRESENT	0
628192	626873	20126Y	PARTICIPANT	\N	PRESENT	0
628193	626873	20092G	PARTICIPANT	\N	PRESENT	0
628194	626873	20124W	PARTICIPANT	\N	PRESENT	0
628195	626873	20066E	PARTICIPANT	\N	PRESENT	0
628196	626873	14059S	PARTICIPANT	\N	PRESENT	0
628197	626873	01024M	PARTICIPANT	\N	PRESENT	0
628198	626873	11070L	PARTICIPANT	\N	PRESENT	0
628199	626873	20038A	PARTICIPANT	\N	PRESENT	0
628200	626873	20286Q	PARTICIPANT	\N	PRESENT	0
628201	626873	20040T	PARTICIPANT	\N	PRESENT	0
628202	626873	11043H	PARTICIPANT	\N	PRESENT	0
628203	626873	19335Q	PARTICIPANT	\N	PRESENT	0
628205	626873	14253S	PARTICIPANT	\N	PRESENT	0
628206	626873	20136B	PARTICIPANT	\N	PRESENT	0
628207	626873	08034U	PARTICIPANT	\N	PRESENT	0
628209	626873	14147R	PARTICIPANT	\N	PRESENT	0
628210	626873	20172F	PARTICIPANT	\N	PRESENT	0
628213	626873	19954N	PARTICIPANT	\N	PRESENT	0
636229	636226	14059S	PARTICIPANT	\N	PRESENT	0
636230	636226	19637C	PARTICIPANT	\N	PRESENT	0
636231	636226	14357A	PARTICIPANT	\N	PRESENT	0
636232	636226	01025N	PARTICIPANT	\N	PRESENT	0
636233	636226	14169X	PARTICIPANT	\N	PRESENT	0
636234	636226	19575F	PARTICIPANT	\N	PRESENT	0
636235	636226	08028W	PARTICIPANT	\N	PRESENT	0
636236	636226	19413M	PARTICIPANT	\N	PRESENT	0
636237	636226	14033T	PARTICIPANT	\N	PRESENT	0
636238	636226	18083K	PARTICIPANT	\N	PRESENT	0
636239	636226	19954N	PARTICIPANT	\N	PRESENT	0
636240	636226	19467C	PARTICIPANT	\N	PRESENT	0
636241	636226	20118Y	PARTICIPANT	\N	PRESENT	0
636242	636226	19798U	PARTICIPANT	\N	PRESENT	0
636243	636226	17023S	PARTICIPANT	\N	PRESENT	0
636246	636245	19575F	PARTICIPANT	\N	PRESENT	0
636247	636245	19467C	PARTICIPANT	\N	PRESENT	0
636248	636245	14357A	PARTICIPANT	\N	PRESENT	0
636249	636245	01025N	PARTICIPANT	\N	PRESENT	0
636250	636245	08015R	PARTICIPANT	\N	PRESENT	0
636251	636245	14205J	PARTICIPANT	\N	PRESENT	0
636252	636245	05012A	PARTICIPANT	\N	PRESENT	0
636253	636245	19443T	PARTICIPANT	\N	PRESENT	0
636254	636245	20058E	PARTICIPANT	\N	PRESENT	0
636255	636245	19798U	PARTICIPANT	\N	PRESENT	0
636657	636655	19762G	PARTICIPANT	\N	PRESENT	0
636658	636655	14021P	PARTICIPANT	\N	PRESENT	0
636659	636655	11085T	PARTICIPANT	\N	PRESENT	0
636662	636655	11056N	PARTICIPANT	\N	PRESENT	0
636663	636655	07033P	PARTICIPANT	\N	PRESENT	0
636664	636655	99004R	PARTICIPANT	\N	PRESENT	0
636665	636655	11026G	PARTICIPANT	\N	PRESENT	0
636666	636655	10006L	PARTICIPANT	\N	PRESENT	0
636667	636655	14030Q	PARTICIPANT	\N	PRESENT	0
636668	636655	14223L	PARTICIPANT	\N	PRESENT	0
636669	636655	19621T	PARTICIPANT	\N	PRESENT	0
636670	636655	14255U	PARTICIPANT	\N	PRESENT	0
636678	636655	20124W	PARTICIPANT	\N	PRESENT	0
636679	636655	19643A	PARTICIPANT	\N	PRESENT	0
636680	636655	20114U	PARTICIPANT	\N	PRESENT	0
636682	636655	20042V	PARTICIPANT	\N	PRESENT	0
637124	637123	20082E	PARTICIPANT	\N	PRESENT	0
637125	637123	19693L	PARTICIPANT	\N	PRESENT	0
637126	637123	20126Y	PARTICIPANT	\N	PRESENT	0
637127	637123	19747H	PARTICIPANT	\N	PRESENT	0
637128	637123	20074E	PARTICIPANT	\N	EXCUSE	0
637129	637123	20050V	PARTICIPANT	\N	EXCUSE	0
637130	637123	19369B	PARTICIPANT	\N	EXCUSE	0
637319	637318	97011G	PARTICIPANT	\N	PRESENT	0
637320	637318	11026G	PARTICIPANT	\N	PRESENT	0
637321	637318	14255U	PARTICIPANT	\N	PRESENT	0
637322	637318	20252E	PARTICIPANT	\N	PRESENT	0
637431	635313	14097Y	PARTICIPANT	\N	PRESENT	0
637434	635313	11101A	PARTICIPANT	\N	PRESENT	0
637435	635313	19711U	PARTICIPANT	\N	PRESENT	0
637440	635313	10015M	PARTICIPANT	\N	PRESENT	0
637442	635313	19531S	PARTICIPANT	\N	PRESENT	0
637443	635313	04045F	PARTICIPANT	\N	PRESENT	0
637444	635313	20104S	PARTICIPANT	\N	PRESENT	0
637445	635313	19441R	PARTICIPANT	\N	PRESENT	0
637446	635313	19631V	PARTICIPANT	\N	PRESENT	0
637447	635313	20078J	PARTICIPANT	\N	PRESENT	0
637448	635313	19782L	PARTICIPANT	\N	PRESENT	0
637449	635313	19467C	PARTICIPANT	\N	PRESENT	0
637450	635313	20286Q	PARTICIPANT	\N	PRESENT	0
637451	635313	20018V	PARTICIPANT	\N	PRESENT	0
637452	635313	19369B	PARTICIPANT	\N	PRESENT	0
637453	635313	19768N	PARTICIPANT	\N	PRESENT	0
637454	635313	20062A	PARTICIPANT	\N	PRESENT	0
637455	635313	19705W	PARTICIPANT	\N	PRESENT	1
637457	637456	04047H	PARTICIPANT	\N	PRESENT	0
637458	637456	14053L	PARTICIPANT	\N	PRESENT	0
637461	637456	11066Q	PARTICIPANT	\N	PRESENT	0
637463	633888	10006L	PARTICIPANT	\N	PRESENT	0
637464	633888	19683J	PARTICIPANT	\N	PRESENT	0
637465	633888	19467C	PARTICIPANT	\N	PRESENT	0
637467	633888	19735D	PARTICIPANT	\N	PRESENT	1
637468	633888	20130U	PARTICIPANT	\N	PRESENT	1
637471	633888	11031D	PARTICIPANT	\N	PRESENT	0
637472	633888	19703U	PARTICIPANT	\N	PRESENT	1
637473	633888	20062A	PARTICIPANT	\N	PRESENT	0
637892	637591	86034E	PARTICIPANT	\N	PRESENT	0
637920	637591	19749K	PARTICIPANT	\N	PRESENT	0
637921	637591	20298U	PARTICIPANT	\N	PRESENT	0
637922	637591	14215L	PARTICIPANT	\N	PRESENT	0
637923	637591	95041E	PARTICIPANT	\N	PRESENT	0
637924	637591	19826F	PARTICIPANT	\N	PRESENT	0
637925	637591	19525U	PARTICIPANT	\N	PRESENT	0
637926	637591	19697Q	PARTICIPANT	\N	PRESENT	0
637927	637591	14053L	PARTICIPANT	\N	PRESENT	0
637928	637591	11033F	PARTICIPANT	\N	PRESENT	0
637929	637591	20142Y	PARTICIPANT	\N	PRESENT	0
637930	637591	14121F	PARTICIPANT	\N	PRESENT	0
637931	637591	08018U	PARTICIPANT	\N	PRESENT	0
637932	637591	19705W	PARTICIPANT	\N	PRESENT	0
637933	637591	19707Y	PARTICIPANT	\N	PRESENT	0
637934	637591	20020P	PARTICIPANT	\N	PRESENT	0
637935	637591	19577H	PARTICIPANT	\N	PRESENT	0
637936	637591	20174H	PARTICIPANT	\N	PRESENT	0
637937	637591	19637C	PARTICIPANT	\N	PRESENT	0
637938	637591	14251Q	PARTICIPANT	\N	PRESENT	0
637939	637591	19347U	PARTICIPANT	\N	PRESENT	0
637940	637591	20134Y	PARTICIPANT	\N	PRESENT	0
637941	637591	11110B	PARTICIPANT	\N	PRESENT	0
637942	637591	19333N	PARTICIPANT	\N	PRESENT	0
637943	637591	14331P	PARTICIPANT	\N	PRESENT	0
637944	637591	19543W	PARTICIPANT	\N	PRESENT	0
637945	637591	14021P	PARTICIPANT	\N	PRESENT	0
637946	637591	01028R	PARTICIPANT	\N	PRESENT	0
637947	637591	11080N	PARTICIPANT	\N	PRESENT	0
637948	637591	99004R	PARTICIPANT	\N	PRESENT	0
637949	637591	04047H	PARTICIPANT	\N	PRESENT	0
637950	637591	01062T	PARTICIPANT	\N	PRESENT	0
637951	637591	19301E	PARTICIPANT	\N	PRESENT	0
637952	637591	19689Q	PARTICIPANT	\N	PRESENT	0
637953	637591	11074Q	PARTICIPANT	\N	PRESENT	0
637954	637591	19649G	PARTICIPANT	\N	PRESENT	0
637955	637591	19443T	PARTICIPANT	\N	PRESENT	0
637956	637591	11012A	PARTICIPANT	\N	PRESENT	0
637957	637591	20018V	PARTICIPANT	\N	PRESENT	0
637958	637591	12041X	PARTICIPANT	\N	PRESENT	0
637959	637591	11031D	PARTICIPANT	\N	PRESENT	0
637960	637591	04085P	PARTICIPANT	\N	PRESENT	0
637961	637591	20022R	PARTICIPANT	\N	PRESENT	0
637962	637591	19667J	PARTICIPANT	\N	PRESENT	0
637963	637591	11085T	PARTICIPANT	\N	PRESENT	0
637980	637591	04033B	PARTICIPANT	\N	PRESENT	0
637978	637591	04042C	PARTICIPANT	\N	PRESENT	0
637979	637591	19657G	PARTICIPANT	\N	PRESENT	0
637967	637591	01048V	PARTICIPANT	\N	PRESENT	0
637984	637591	19647E	PARTICIPANT	\N	PRESENT	0
637983	637591	11083R	PARTICIPANT	\N	PRESENT	0
637982	637591	95063L	PARTICIPANT	\N	PRESENT	0
637971	637591	11045K	PARTICIPANT	\N	PRESENT	0
637972	637591	20064C	PARTICIPANT	\N	PRESENT	0
637986	637591	19715Y	PARTICIPANT	\N	PRESENT	0
637974	637591	14089Y	PARTICIPANT	\N	PRESENT	0
637975	637591	04071H	PARTICIPANT	\N	PRESENT	0
637976	637591	20074E	PARTICIPANT	\N	PRESENT	0
637977	637591	19711U	PARTICIPANT	\N	PRESENT	0
637981	637591	19687N	PARTICIPANT	\N	PRESENT	0
637985	637591	19599P	PARTICIPANT	\N	PRESENT	0
637987	637591	20110Q	PARTICIPANT	\N	PRESENT	0
637988	637591	20248J	PARTICIPANT	\N	PRESENT	0
637989	637591	11064N	PARTICIPANT	\N	PRESENT	0
637990	637591	19651A	PARTICIPANT	\N	PRESENT	0
638007	638006	19629C	PARTICIPANT	\N	PRESENT	0
638008	638006	11090Q	PARTICIPANT	\N	PRESENT	0
638009	638006	19575F	PARTICIPANT	\N	PRESENT	0
638010	638006	14147R	PARTICIPANT	\N	PRESENT	0
638011	638006	14038Y	PARTICIPANT	\N	PRESENT	0
638012	638006	20092G	PARTICIPANT	\N	PRESENT	0
638013	638006	20028X	PARTICIPANT	\N	PRESENT	0
638023	638022	04042C	PARTICIPANT	\N	PRESENT	0
637351	635772	04045F	PARTICIPANT	\N	PRESENT	0
637354	635772	19631V	PARTICIPANT	\N	PRESENT	0
637355	635772	19515S	PARTICIPANT	\N	PRESENT	0
637356	635772	20078J	PARTICIPANT	\N	PRESENT	0
637357	635772	19782L	PARTICIPANT	\N	PRESENT	0
637358	635772	14038Y	PARTICIPANT	\N	PRESENT	0
637359	635772	19467C	PARTICIPANT	\N	PRESENT	0
637360	635772	14187A	PARTICIPANT	\N	PRESENT	0
637361	635772	20286Q	PARTICIPANT	\N	PRESENT	0
637362	635772	08015R	PARTICIPANT	\N	PRESENT	0
637363	635772	20018V	PARTICIPANT	\N	PRESENT	0
637364	635772	19369B	PARTICIPANT	\N	PRESENT	0
637365	635772	14257W	PARTICIPANT	\N	PRESENT	0
637366	635772	19768N	PARTICIPANT	\N	PRESENT	0
637367	635772	11090Q	PARTICIPANT	\N	PRESENT	0
637368	635772	20092G	PARTICIPANT	\N	PRESENT	0
637369	635772	20062A	PARTICIPANT	\N	PRESENT	0
637370	635772	19413M	PARTICIPANT	\N	PRESENT	0
637371	635772	19707Y	PARTICIPANT	\N	PRESENT	1
637372	635772	14251Q	PARTICIPANT	\N	PRESENT	1
637373	635772	19747H	PARTICIPANT	\N	PRESENT	1
637374	635772	14205J	PARTICIPANT	\N	PRESENT	1
637375	635772	20082E	PARTICIPANT	\N	PRESENT	1
637376	635772	19705W	PARTICIPANT	\N	PRESENT	1
637422	635772	14219Q	PARTICIPANT	\N	PRESENT	0
637423	635772	20032T	PARTICIPANT	\N	PRESENT	0
637424	635772	19549D	PARTICIPANT	\N	PRESENT	0
637425	635772	18083K	PARTICIPANT	\N	PRESENT	0
637426	635772	17229F	PARTICIPANT	\N	PRESENT	0
637427	635772	19251M	PARTICIPANT	\N	PRESENT	1
637428	635772	20038A	PARTICIPANT	\N	PRESENT	0
637429	635772	19820Y	PARTICIPANT	\N	PRESENT	1
637430	635772	20106U	PARTICIPANT	\N	PRESENT	1
637432	635772	20102Q	PARTICIPANT	\N	PRESENT	0
637433	635772	14031R	PARTICIPANT	\N	PRESENT	0
637436	635772	19745F	PARTICIPANT	\N	PRESENT	0
637437	635772	19503N	PARTICIPANT	\N	PRESENT	0
637438	635772	20020P	PARTICIPANT	\N	PRESENT	0
637439	635772	19619A	PARTICIPANT	\N	PRESENT	0
637441	635772	20046A	PARTICIPANT	\N	PRESENT	1
637991	637894	19711U	PARTICIPANT	\N	PRESENT	0
638964	638961	11090Q	PARTICIPANT	\N	PRESENT	0
638965	638961	20286Q	PARTICIPANT	\N	PRESENT	0
638966	638961	14257W	PARTICIPANT	\N	PRESENT	1
638967	638961	20174H	PARTICIPANT	\N	PRESENT	1
638968	638961	08015R	PARTICIPANT	\N	PRESENT	1
638969	638962	11090Q	PARTICIPANT	\N	PRESENT	0
638970	638962	20286Q	PARTICIPANT	\N	PRESENT	0
638971	638962	14257W	PARTICIPANT	\N	PRESENT	1
638972	638963	11090Q	PARTICIPANT	\N	PRESENT	0
638973	638963	20286Q	PARTICIPANT	\N	PRESENT	1
638974	638963	14257W	PARTICIPANT	\N	PRESENT	1
639225	638885	11067R	PARTICIPANT	\N	PRESENT	0
639226	638885	20090E	PARTICIPANT	\N	PRESENT	0
639227	638885	20248J	PARTICIPANT	\N	PRESENT	1
639228	638885	11103C	PARTICIPANT	\N	PRESENT	1
639229	638885	11097X	PARTICIPANT	\N	PRESENT	0
639230	638885	19415P	PARTICIPANT	\N	PRESENT	0
639231	638885	19691J	PARTICIPANT	\N	PRESENT	1
639232	638885	14217N	PARTICIPANT	\N	PRESENT	0
639233	638885	18193Q	PARTICIPANT	\N	PRESENT	0
639234	638885	10006L	PRESIDENT	0	PRESENT	0
639235	638885	19760E	PARTICIPANT	\N	PRESENT	1
639237	638994	07004J	PARTICIPANT	\N	PRESENT	0
639238	638994	04085P	PARTICIPANT	\N	PRESENT	0
639241	638994	19667J	PRESIDENT	0	PRESENT	0
639242	638994	20044X	PARTICIPANT	\N	PRESENT	0
639243	638994	14249W	PARTICIPANT	\N	PRESENT	0
639244	638994	14257W	PARTICIPANT	\N	PRESENT	0
639245	638904	14213J	PARTICIPANT	\N	PRESENT	0
639246	638904	19679N	PARTICIPANT	\N	PRESENT	0
639247	638904	19697Q	PARTICIPANT	\N	PRESENT	0
639248	638904	14281W	PARTICIPANT	\N	PRESENT	0
639250	638902	19679N	PARTICIPANT	\N	PRESENT	0
639251	638902	19697Q	PARTICIPANT	\N	PRESENT	0
639252	638903	14281W	PARTICIPANT	\N	PRESENT	0
639253	638903	19697Q	PARTICIPANT	\N	PRESENT	0
639254	638903	19679N	PARTICIPANT	\N	PRESENT	0
639257	638994	19741B	PARTICIPANT	\N	PRESENT	0
639258	638994	19531S	PARTICIPANT	\N	PRESENT	0
639259	638994	17737W	PARTICIPANT	\N	PRESENT	0
639260	638994	20064C	PARTICIPANT	\N	PRESENT	0
639261	638994	19671E	PARTICIPANT	\N	PRESENT	1
639262	638901	14215L	PARTICIPANT	\N	PRESENT	0
639264	638901	04008A	PARTICIPANT	\N	PRESENT	0
639265	638901	14111D	PARTICIPANT	\N	PRESENT	0
639266	638901	10015M	PARTICIPANT	\N	PRESENT	0
639267	638901	14151M	PARTICIPANT	\N	PRESENT	0
639268	638901	04047H	PRESIDENT	0	PRESENT	0
639270	638994	19689Q	PARTICIPANT	\N	PRESENT	0
639271	638901	14147R	PARTICIPANT	\N	PRESENT	0
639287	638901	19543W	PARTICIPANT	\N	PRESENT	0
639347	638396	19415P	PARTICIPANT	\N	PRESENT	0
639348	638396	11067R	PARTICIPANT	\N	PRESENT	0
639349	638396	14213J	PARTICIPANT	\N	PRESENT	1
639350	638396	19715Y	PARTICIPANT	\N	PRESENT	1
639351	638396	18193Q	PARTICIPANT	\N	PRESENT	1
639352	639345	19415P	PARTICIPANT	\N	PRESENT	0
639353	639345	11067R	PARTICIPANT	\N	PRESENT	0
639354	639345	19715Y	PARTICIPANT	\N	PRESENT	1
639355	639345	14213J	PARTICIPANT	\N	PRESENT	1
639356	639346	19415P	PARTICIPANT	\N	PRESENT	0
639357	639346	11067R	PARTICIPANT	\N	PRESENT	0
639358	639346	14213J	PARTICIPANT	\N	PRESENT	1
639391	639335	11067R	PARTICIPANT	\N	PRESENT	0
639392	639335	19415P	PARTICIPANT	\N	PRESENT	1
639393	639335	19798U	PARTICIPANT	\N	PRESENT	0
639394	639335	11097X	PARTICIPANT	\N	PRESENT	1
639524	639523	20266L	PARTICIPANT	\N	PRESENT	0
639525	639523	18083K	PARTICIPANT	\N	PRESENT	0
639608	639605	19735D	PARTICIPANT	\N	PRESENT	0
639609	639606	19735D	PARTICIPANT	\N	PRESENT	0
639610	639607	19735D	PARTICIPANT	\N	PRESENT	0
639612	639611	04008A	PARTICIPANT	\N	PRESENT	0
639613	639611	19543W	PARTICIPANT	\N	PRESENT	0
639614	639611	14151M	PARTICIPANT	\N	PRESENT	0
640046	640045	04047H	PARTICIPANT	\N	PRESENT	0
640047	640045	10015M	PARTICIPANT	\N	PRESENT	0
640048	640045	11026G	PARTICIPANT	\N	PRESENT	0
640049	640045	11072N	PARTICIPANT	\N	PRESENT	1
640050	640045	14147R	PARTICIPANT	\N	PRESENT	0
640054	640053	08010L	PARTICIPANT	\N	PRESENT	0
640061	640060	14327T	PARTICIPANT	\N	PRESENT	0
640063	640062	01048V	PARTICIPANT	\N	PRESENT	0
640066	640065	14327T	PARTICIPANT	\N	PRESENT	0
640068	640067	14327T	PARTICIPANT	\N	PRESENT	0
640070	640069	99004R	PARTICIPANT	\N	PRESENT	0
640072	640071	99004R	PARTICIPANT	\N	PRESENT	0
640074	640073	99004R	PARTICIPANT	\N	PRESENT	0
640691	640690	05008E	PARTICIPANT	\N	PRESENT	0
640692	640690	11053K	PARTICIPANT	\N	PRESENT	0
640693	640690	01028R	PARTICIPANT	\N	PRESENT	0
640708	640707	14193X	PARTICIPANT	\N	PRESENT	0
640709	640707	19421M	PARTICIPANT	\N	PRESENT	0
640710	640707	16685X	PARTICIPANT	\N	PRESENT	0
640712	640711	19747H	PARTICIPANT	\N	PRESENT	0
640713	640711	19693L	PARTICIPANT	\N	PRESENT	0
640714	640711	20074E	PARTICIPANT	\N	EXCUSE	0
640715	640711	20066E	PARTICIPANT	\N	EXCUSE	0
640716	640711	20126Y	PARTICIPANT	\N	EXCUSE	0
640717	640711	11077T	PARTICIPANT	\N	EXCUSE	0
640718	640711	19369B	PARTICIPANT	\N	EXCUSE	0
640719	640711	20050V	PARTICIPANT	\N	PRESENT	0
640720	640711	20082E	PARTICIPANT	\N	PRESENT	0
640722	640721	14327T	PARTICIPANT	\N	PRESENT	0
640746	640630	14223L	PARTICIPANT	\N	PRESENT	1
640747	640630	19415P	PARTICIPANT	\N	PRESENT	0
640748	640630	11067R	PARTICIPANT	\N	PRESENT	0
640749	640706	19715Y	PARTICIPANT	\N	PRESENT	1
640750	640706	14223L	PARTICIPANT	\N	PRESENT	1
640751	640706	11067R	PARTICIPANT	\N	PRESENT	0
640752	640706	19415P	PARTICIPANT	\N	PRESENT	0
640753	640745	19415P	PARTICIPANT	\N	PRESENT	0
640754	640745	11067R	PARTICIPANT	\N	PRESENT	0
640755	640745	14223L	PARTICIPANT	\N	PRESENT	1
640756	640745	20130U	PARTICIPANT	\N	PRESENT	1
640758	640757	19415P	PARTICIPANT	\N	PRESENT	0
640759	640757	14213J	PARTICIPANT	\N	PRESENT	1
640760	640757	20130U	PARTICIPANT	\N	PRESENT	1
640761	640757	11067R	PARTICIPANT	\N	PRESENT	0
645940	645335	20142Y	PARTICIPANT	\N	PRESENT	0
645941	645335	20048C	PARTICIPANT	\N	PRESENT	0
645942	645335	19693L	PARTICIPANT	\N	PRESENT	0
645943	645335	20052X	PARTICIPANT	\N	PRESENT	0
645944	645335	20152B	PARTICIPANT	\N	PRESENT	0
645945	645335	14030Q	PARTICIPANT	\N	PRESENT	0
645946	645335	20180F	PARTICIPANT	\N	PRESENT	0
645947	645335	19735D	PARTICIPANT	\N	PRESENT	0
645948	645335	19057M	PARTICIPANT	\N	PRESENT	0
645949	645335	11043H	PARTICIPANT	\N	PRESENT	0
645950	645335	19758L	PARTICIPANT	\N	PRESENT	0
645951	645335	19621T	PARTICIPANT	\N	PRESENT	0
645952	645490	20116W	PARTICIPANT	\N	PRESENT	1
645953	645490	19545Y	PARTICIPANT	\N	PRESENT	1
645954	645490	20126Y	PARTICIPANT	\N	PRESENT	1
645955	645490	11012A	PARTICIPANT	\N	PRESENT	1
645956	645490	19687N	PARTICIPANT	\N	PRESENT	1
645964	643797	17023S	PARTICIPANT	\N	PRESENT	0
645965	643797	20034V	PARTICIPANT	\N	PRESENT	1
645966	643797	14097Y	PARTICIPANT	\N	EXCUSE	0
645967	643797	19657G	PARTICIPANT	\N	EXCUSE	0
645968	643797	19301E	PARTICIPANT	\N	PRESENT	0
645969	643797	08073C	PARTICIPANT	\N	PRESENT	0
645970	643797	11072N	PARTICIPANT	\N	PRESENT	1
645993	645992	20032T	PARTICIPANT	\N	PRESENT	0
645994	645992	19954N	PARTICIPANT	\N	PRESENT	0
645995	645992	20042V	PARTICIPANT	\N	EXCUSE	0
645996	645992	19643A	PARTICIPANT	\N	PRESENT	0
645997	645992	11056N	PARTICIPANT	\N	PRESENT	0
645998	645992	14259Y	PARTICIPANT	\N	PRESENT	0
645999	645992	20132W	PARTICIPANT	\N	PRESENT	0
646000	645992	20068G	PARTICIPANT	\N	PRESENT	0
646001	645992	19399H	PARTICIPANT	\N	EXCUSE	0
646002	645992	19711U	PARTICIPANT	\N	PRESENT	0
646003	645992	20050V	PARTICIPANT	\N	EXCUSE	0
646004	645992	95063L	PARTICIPANT	\N	PRESENT	0
646005	645992	20044X	PARTICIPANT	\N	PRESENT	0
646006	645992	11097X	PARTICIPANT	\N	EXCUSE	0
646007	645992	01028R	PARTICIPANT	\N	EXCUSE	0
646008	645459	19515S	PARTICIPANT	\N	EXCUSE	0
646009	645459	19575F	PARTICIPANT	\N	EXCUSE	0
646010	645459	20094J	PARTICIPANT	\N	PRESENT	0
646011	645459	14105F	PARTICIPANT	\N	EXCUSE	0
646012	645459	14083S	PARTICIPANT	\N	EXCUSE	0
646013	645459	19545Y	PARTICIPANT	\N	EXCUSE	0
646014	645459	20060X	PARTICIPANT	\N	EXCUSE	0
646015	645459	14329V	PARTICIPANT	\N	EXCUSE	0
646016	645459	14195A	PARTICIPANT	\N	EXCUSE	0
646017	645459	08028W	PARTICIPANT	\N	EXCUSE	0
646018	645459	19467C	PARTICIPANT	\N	EXCUSE	0
646019	645459	19251M	PARTICIPANT	\N	EXCUSE	0
646020	645459	20040T	PARTICIPANT	\N	EXCUSE	0
646021	645459	20048C	PARTICIPANT	\N	PRESENT	0
646022	645459	20126Y	PARTICIPANT	\N	EXCUSE	0
646023	645459	16685X	PRESIDENT	0	PRESENT	0
646024	645459	19697Q	PARTICIPANT	\N	EXCUSE	0
646025	645459	17965H	PARTICIPANT	\N	EXCUSE	0
646026	645459	20082E	PARTICIPANT	\N	PRESENT	0
646027	645459	20054A	PARTICIPANT	\N	EXCUSE	0
646028	645459	19762G	PARTICIPANT	\N	PRESENT	0
646200	646199	19711U	PARTICIPANT	\N	PRESENT	0
646202	646201	19711U	PARTICIPANT	\N	PRESENT	0
646204	646203	20070A	PARTICIPANT	\N	PRESENT	0
646206	646205	20070A	PARTICIPANT	\N	PRESENT	0
646207	646205	11110B	PARTICIPANT	\N	PRESENT	0
646212	646208	20070A	PARTICIPANT	\N	PRESENT	0
646213	646208	11110B	PARTICIPANT	\N	PRESENT	0
646214	646209	20070A	PARTICIPANT	\N	PRESENT	0
646215	646209	11110B	PARTICIPANT	\N	PRESENT	0
646216	646210	20070A	PARTICIPANT	\N	PRESENT	0
646217	646210	11110B	PARTICIPANT	\N	PRESENT	0
646219	646218	20070A	PARTICIPANT	\N	PRESENT	0
646220	646218	11110B	PARTICIPANT	\N	PRESENT	0
646221	646211	20070A	PARTICIPANT	\N	PRESENT	0
646222	646211	11110B	PARTICIPANT	\N	PRESENT	0
646264	643942	20150Y	PARTICIPANT	\N	EXCUSE	0
646265	643944	20150Y	PARTICIPANT	\N	EXCUSE	0
646267	646266	11048N	PARTICIPANT	\N	PRESENT	0
646268	646266	20086J	PARTICIPANT	\N	PRESENT	0
646270	646269	11048N	PARTICIPANT	\N	PRESENT	0
646278	646277	11053K	PARTICIPANT	\N	PRESENT	0
646284	646283	11048N	PARTICIPANT	\N	PRESENT	0
646288	646287	14225N	PARTICIPANT	\N	PRESENT	0
646289	646287	01057W	PARTICIPANT	\N	PRESENT	0
646411	646410	01028R	PARTICIPANT	\N	PRESENT	0
646414	646413	20056C	PARTICIPANT	\N	PRESENT	0
646415	646413	14151M	PARTICIPANT	\N	PRESENT	0
646416	646413	14189C	PARTICIPANT	\N	PRESENT	0
646417	646413	08010L	PARTICIPANT	\N	PRESENT	0
646418	646413	20052X	PARTICIPANT	\N	PRESENT	0
646419	646413	04070G	PARTICIPANT	\N	PRESENT	0
646420	646413	19766L	PARTICIPANT	\N	PRESENT	0
646421	646413	04043D	PARTICIPANT	\N	PRESENT	0
646422	646413	19479G	PARTICIPANT	\N	PRESENT	0
646423	646413	20248J	PARTICIPANT	\N	PRESENT	0
646424	646413	20128B	PARTICIPANT	\N	PRESENT	0
646425	646413	11090Q	PARTICIPANT	\N	PRESENT	0
646426	646413	20086J	PARTICIPANT	\N	PRESENT	0
646428	646413	20026V	PARTICIPANT	\N	PRESENT	0
646429	646413	20022R	PARTICIPANT	\N	PRESENT	0
646430	646413	20038A	PARTICIPANT	\N	PRESENT	0
646431	646413	19762G	PARTICIPANT	\N	PRESENT	0
646432	646413	19575F	PARTICIPANT	\N	PRESENT	0
646660	646187	11053K	PARTICIPANT	\N	PRESENT	1
646661	646187	19545Y	PARTICIPANT	\N	PRESENT	1
646662	646187	14327T	PARTICIPANT	\N	PRESENT	1
646663	646187	11110B	PARTICIPANT	\N	PRESENT	1
646664	646187	19647E	PARTICIPANT	\N	PRESENT	1
646665	646187	14121F	PARTICIPANT	\N	PRESENT	1
646666	646187	19671E	PARTICIPANT	\N	PRESENT	1
646668	646187	19335Q	PARTICIPANT	\N	PRESENT	1
646669	646187	20050V	PARTICIPANT	\N	PRESENT	1
646670	646187	20036X	PARTICIPANT	\N	PRESENT	1
647205	643942	14147R	PARTICIPANT	\N	PRESENT	0
646672	646187	07029T	PARTICIPANT	\N	EXCUSE	0
646673	646313	20070A	PARTICIPANT	\N	PRESENT	0
647206	643944	19347U	PARTICIPANT	\N	PRESENT	1
647649	646198	20080C	PARTICIPANT	\N	PRESENT	1
647650	646198	11053K	PARTICIPANT	\N	PRESENT	1
647651	646198	19545Y	PARTICIPANT	\N	PRESENT	1
647652	646198	20070A	PARTICIPANT	\N	PRESENT	1
647653	646198	14327T	PARTICIPANT	\N	PRESENT	1
647654	646198	11074Q	PARTICIPANT	\N	PRESENT	1
647655	646198	01057W	PARTICIPANT	\N	PRESENT	1
647656	646198	20126Y	PARTICIPANT	\N	PRESENT	1
647657	646198	08010L	PARTICIPANT	\N	PRESENT	1
647658	646198	01048V	PARTICIPANT	\N	PRESENT	1
647659	646198	12016W	PARTICIPANT	\N	PRESENT	1
647660	646198	19671E	PARTICIPANT	\N	PRESENT	1
647661	646198	20036X	PARTICIPANT	\N	PRESENT	1
647662	646198	19349W	PARTICIPANT	\N	PRESENT	1
647663	646198	20044X	PARTICIPANT	\N	PRESENT	1
647664	646198	19762G	PARTICIPANT	\N	PRESENT	1
647665	646198	19479G	PARTICIPANT	\N	PRESENT	1
647763	646185	19705W	PARTICIPANT	\N	PRESENT	0
647946	647945	11053K	PARTICIPANT	\N	PRESENT	0
647952	647951	14211G	PARTICIPANT	\N	PRESENT	0
647953	647951	11041F	PARTICIPANT	\N	PRESENT	0
648003	647517	20074E	PARTICIPANT	\N	PRESENT	1
648004	647517	19729F	PARTICIPANT	\N	PRESENT	1
648005	647517	10015M	PARTICIPANT	\N	PRESENT	1
648008	647517	08018U	PARTICIPANT	\N	EXCUSE	0
648165	648164	14257W	PARTICIPANT	\N	PRESENT	0
648166	648164	19349W	PARTICIPANT	\N	PRESENT	0
648167	648164	01057W	PARTICIPANT	\N	PRESENT	0
648168	648164	14281W	PARTICIPANT	\N	PRESENT	0
648169	648164	19735D	PARTICIPANT	\N	PRESENT	0
648170	648164	14231L	PRESIDENT	0	PRESENT	0
648171	648164	19565D	PARTICIPANT	\N	PRESENT	0
648172	648164	19758L	PARTICIPANT	\N	PRESENT	0
648173	648164	19333N	PARTICIPANT	\N	PRESENT	0
648174	648164	19820Y	PARTICIPANT	\N	PRESENT	0
648175	648164	14229S	PARTICIPANT	\N	PRESENT	0
648176	648164	20062A	PARTICIPANT	\N	PRESENT	0
648177	648164	19782L	PARTICIPANT	\N	PRESENT	0
648178	648164	14107H	PARTICIPANT	\N	PRESENT	0
648179	648164	14071N	PARTICIPANT	\N	PRESENT	0
648180	648164	14053L	PARTICIPANT	\N	PRESENT	0
648181	648164	20022R	PARTICIPANT	\N	PRESENT	0
648182	648164	14173T	PARTICIPANT	\N	PRESENT	0
648183	648164	14327T	PARTICIPANT	\N	PRESENT	0
628214	626873	20026V	PARTICIPANT	\N	PRESENT	0
628215	626873	20180F	PARTICIPANT	\N	PRESENT	0
628216	626873	20096L	PARTICIPANT	\N	PRESENT	0
628217	626873	19573D	PARTICIPANT	\N	PRESENT	0
628218	626873	19447X	PARTICIPANT	\N	PRESENT	0
628219	626873	14038Y	PARTICIPANT	\N	PRESENT	0
628220	626873	19723Y	PARTICIPANT	\N	PRESENT	0
628221	626873	20058E	PARTICIPANT	\N	PRESENT	0
628222	626873	19467C	PARTICIPANT	\N	PRESENT	0
628223	626873	20098N	PARTICIPANT	\N	PRESENT	0
628224	626873	19741B	PARTICIPANT	\N	PRESENT	0
628225	626873	08015R	PARTICIPANT	\N	PRESENT	0
628226	626873	07029T	PARTICIPANT	\N	PRESENT	0
628227	626873	14089Y	PARTICIPANT	\N	PRESENT	0
628228	626873	19663E	PARTICIPANT	\N	PRESENT	0
628229	626873	19531S	PARTICIPANT	\N	PRESENT	0
628230	626873	05008E	PARTICIPANT	\N	PRESENT	0
628231	626873	04070G	PARTICIPANT	\N	PRESENT	0
628232	626873	14105F	PARTICIPANT	\N	PRESENT	0
628238	626873	08011M	PARTICIPANT	\N	PRESENT	0
628234	626873	20248J	PARTICIPANT	\N	PRESENT	0
628235	626873	20048C	PARTICIPANT	\N	PRESENT	0
628236	626873	14331P	PARTICIPANT	\N	PRESENT	0
628237	626873	11090Q	PARTICIPANT	\N	PRESENT	0
628243	626873	14225N	PARTICIPANT	\N	PRESENT	0
628240	626873	11074Q	PARTICIPANT	\N	PRESENT	0
628241	626873	14189C	PARTICIPANT	\N	PRESENT	0
628242	626873	20140W	PARTICIPANT	\N	PRESENT	0
628244	626873	14179A	PARTICIPANT	\N	PRESENT	0
628245	626873	20060X	PARTICIPANT	\N	PRESENT	0
628246	626873	14123H	PARTICIPANT	\N	PRESENT	0
628492	626874	99004R	PARTICIPANT	\N	PRESENT	0
628493	626886	20090E	PARTICIPANT	\N	PRESENT	0
628494	626886	19667J	PRESIDENT	0	PRESENT	0
628495	626886	04085P	PARTICIPANT	\N	PRESENT	0
628496	626886	20038A	PARTICIPANT	\N	EXCUSE	0
628497	624394	20136B	PARTICIPANT	\N	PRESENT	0
628498	624394	14219Q	PRESIDENT	0	PRESENT	0
628499	626874	19479G	PARTICIPANT	\N	PRESENT	0
628500	626874	14121F	PARTICIPANT	\N	PRESENT	0
628501	626874	11048N	PARTICIPANT	\N	PRESENT	0
628502	626874	19347U	PARTICIPANT	\N	PRESENT	0
628503	626874	19695N	PARTICIPANT	\N	PRESENT	0
628504	624394	19333N	PARTICIPANT	\N	PRESENT	0
628505	624394	18083K	PARTICIPANT	\N	PRESENT	0
628506	624394	05012A	PARTICIPANT	\N	PRESENT	0
628507	624394	19503N	PARTICIPANT	\N	PRESENT	0
628508	624394	20102Q	PARTICIPANT	\N	PRESENT	0
628509	626874	08009T	PARTICIPANT	\N	PRESENT	0
628510	626874	19349W	PARTICIPANT	\N	PRESENT	0
628511	624394	20120S	PARTICIPANT	\N	PRESENT	0
628512	626874	19866P	PARTICIPANT	\N	PRESENT	0
628513	626874	19413M	PARTICIPANT	\N	PRESENT	0
628514	626874	14231L	PARTICIPANT	\N	PRESENT	0
628515	626874	20050V	PARTICIPANT	\N	PRESENT	0
628516	626886	19711U	PARTICIPANT	\N	PRESENT	0
628517	626886	14249W	PARTICIPANT	\N	PRESENT	0
628518	626874	14033T	PARTICIPANT	\N	PRESENT	0
628519	624394	19387D	PARTICIPANT	\N	PRESENT	0
628520	624394	19745F	PARTICIPANT	\N	PRESENT	0
628521	626874	19369B	PARTICIPANT	\N	PRESENT	0
628522	624394	20038A	PARTICIPANT	\N	PRESENT	0
628523	624394	19549D	PARTICIPANT	\N	PRESENT	0
628524	624394	20068G	PARTICIPANT	\N	PRESENT	0
628525	626874	20174H	PARTICIPANT	\N	PRESENT	0
628526	626886	20044X	PARTICIPANT	\N	PRESENT	0
628527	626886	19671E	PARTICIPANT	\N	PRESENT	0
628528	626886	19531S	PARTICIPANT	\N	PRESENT	0
628529	626886	20064C	PARTICIPANT	\N	PRESENT	0
628530	624394	20032T	PARTICIPANT	\N	PRESENT	0
628531	624394	20024T	PARTICIPANT	\N	PRESENT	0
628532	626874	20080C	PARTICIPANT	\N	PRESENT	0
628533	626874	11090Q	PARTICIPANT	\N	PRESENT	0
628534	624394	19619A	PARTICIPANT	\N	PRESENT	0
628535	624394	20076G	PARTICIPANT	\N	PRESENT	0
628536	624394	19701S	PARTICIPANT	\N	PRESENT	0
628537	626874	20070A	PARTICIPANT	\N	PRESENT	0
628538	626874	01048V	PARTICIPANT	\N	PRESENT	0
628539	626874	01058X	PARTICIPANT	\N	PRESENT	0
628540	626874	19758L	PARTICIPANT	\N	PRESENT	0
628542	624394	20118Y	PARTICIPANT	\N	PRESENT	0
628544	626874	19629C	PARTICIPANT	\N	PRESENT	0
628545	626874	19553Y	PARTICIPANT	\N	PRESENT	0
628547	626874	19631V	PARTICIPANT	\N	PRESENT	0
628551	626874	19575F	PARTICIPANT	\N	PRESENT	0
628552	626874	20092G	PARTICIPANT	\N	PRESENT	0
628555	626874	11056N	PARTICIPANT	\N	PRESENT	0
628559	626874	14031R	PARTICIPANT	\N	PRESENT	0
628560	626874	14123H	PARTICIPANT	\N	PRESENT	0
628561	626874	01024M	PARTICIPANT	\N	PRESENT	0
628562	626874	20048C	PARTICIPANT	\N	PRESENT	0
628563	626874	14275Y	PARTICIPANT	\N	PRESENT	0
628564	626874	11012A	PARTICIPANT	\N	PRESENT	0
628565	626874	20042V	PARTICIPANT	\N	PRESENT	0
628572	626874	20034V	PARTICIPANT	\N	PRESENT	0
628574	626874	14038Y	PARTICIPANT	\N	PRESENT	0
628575	626874	11097X	PARTICIPANT	\N	PRESENT	0
628576	626886	19741B	PARTICIPANT	\N	PRESENT	0
628577	626874	14021P	PARTICIPANT	\N	PRESENT	0
628578	626874	19563B	PARTICIPANT	\N	PRESENT	0
628579	626874	19467C	PARTICIPANT	\N	PRESENT	0
628580	626874	19441R	PARTICIPANT	\N	PRESENT	0
628581	626874	20024T	PARTICIPANT	\N	PRESENT	0
628582	626874	07029T	PARTICIPANT	\N	PRESENT	0
628583	626874	14195A	PARTICIPANT	\N	PRESENT	0
628584	624394	14031R	PARTICIPANT	\N	PRESENT	0
628585	624394	19251M	PARTICIPANT	\N	PRESENT	0
628586	624394	20106U	PARTICIPANT	\N	PRESENT	0
628588	626874	14030Q	PARTICIPANT	\N	PRESENT	0
628589	626874	19301E	PARTICIPANT	\N	PRESENT	0
628590	626874	97011G	PARTICIPANT	\N	PRESENT	0
628591	626874	18083K	PARTICIPANT	\N	PRESENT	0
628624	626875	20130U	PARTICIPANT	\N	PRESENT	0
628625	626875	11031D	PARTICIPANT	\N	PRESENT	0
628626	626875	19347U	PARTICIPANT	\N	PRESENT	0
628627	626875	14195A	PARTICIPANT	\N	PRESENT	0
628628	626875	19553Y	PARTICIPANT	\N	PRESENT	0
628629	626875	20116W	PARTICIPANT	\N	PRESENT	0
628630	626875	19629C	PARTICIPANT	\N	PRESENT	0
628631	626875	19866P	PARTICIPANT	\N	PRESENT	0
628632	626875	20066E	PARTICIPANT	\N	PRESENT	0
628633	626875	19719D	PARTICIPANT	\N	PRESENT	0
628634	626875	14281W	PARTICIPANT	\N	PRESENT	0
628635	626875	19301E	PARTICIPANT	\N	PRESENT	0
628636	626875	04057K	PARTICIPANT	\N	PRESENT	0
628637	626875	19711U	PARTICIPANT	\N	PRESENT	0
628638	626875	08034U	PARTICIPANT	\N	PRESENT	0
628639	626875	19533U	PARTICIPANT	\N	PRESENT	0
628640	626875	19739H	PARTICIPANT	\N	PRESENT	0
628648	626875	17737W	PARTICIPANT	\N	PRESENT	0
628649	626875	14217N	PARTICIPANT	\N	PRESENT	0
628650	626875	19599P	PARTICIPANT	\N	PRESENT	0
628651	626875	11097X	PARTICIPANT	\N	PRESENT	0
628652	626875	19798U	PARTICIPANT	\N	PRESENT	0
628653	626875	17229F	PARTICIPANT	\N	PRESENT	0
628654	626875	20148F	PARTICIPANT	\N	PRESENT	0
628655	626875	18083K	PARTICIPANT	\N	PRESENT	0
628656	626875	19563B	PARTICIPANT	\N	PRESENT	0
628657	626875	10006L	PARTICIPANT	\N	PRESENT	0
628658	626875	14033T	PARTICIPANT	\N	PRESENT	0
628659	626875	01024M	PARTICIPANT	\N	PRESENT	0
628660	626875	19441R	PARTICIPANT	\N	PRESENT	0
628622	626875	99004R	PARTICIPANT	\N	PRESENT	0
628623	626875	19569H	PARTICIPANT	\N	PRESENT	0
628661	626875	14030Q	PARTICIPANT	\N	PRESENT	0
628662	626875	97011G	PARTICIPANT	\N	PRESENT	0
628663	626875	11067R	PARTICIPANT	\N	PRESENT	0
628664	626875	19413M	PARTICIPANT	\N	PRESENT	0
628665	626875	20052X	PARTICIPANT	\N	PRESENT	0
628666	626875	20090E	PARTICIPANT	\N	PRESENT	0
628667	626875	20024T	PARTICIPANT	\N	PRESENT	0
628669	626875	17779H	PARTICIPANT	\N	PRESENT	0
628670	626875	19713W	PARTICIPANT	\N	PRESENT	0
628671	626875	20026V	PARTICIPANT	\N	PRESENT	0
628672	626875	14083S	PARTICIPANT	\N	PRESENT	0
628673	626875	20102Q	PARTICIPANT	\N	PRESENT	0
628674	626875	19691J	PARTICIPANT	\N	PRESENT	0
628675	626875	11053K	PARTICIPANT	\N	PRESENT	0
628676	626875	19467C	PARTICIPANT	\N	PRESENT	0
628677	626875	19573D	PARTICIPANT	\N	PRESENT	0
628678	626875	19447X	PARTICIPANT	\N	PRESENT	0
638024	638022	11064N	PARTICIPANT	\N	PRESENT	0
638365	638363	19685L	PARTICIPANT	\N	PRESENT	0
638026	638022	01062T	PARTICIPANT	\N	PRESENT	0
638027	638022	19443T	PARTICIPANT	\N	PRESENT	0
638074	638073	14221J	PARTICIPANT	\N	PRESENT	0
638364	638363	19599P	PARTICIPANT	\N	PRESENT	0
638368	638367	19599P	PARTICIPANT	\N	PRESENT	0
638369	638367	19685L	PARTICIPANT	\N	PRESENT	0
638370	638367	20024T	PARTICIPANT	\N	PRESENT	0
638371	638367	20100N	PARTICIPANT	\N	PRESENT	0
638378	638377	19415P	PARTICIPANT	\N	PRESENT	0
638486	638485	17737W	PARTICIPANT	\N	PRESENT	0
638487	638485	11026G	PARTICIPANT	\N	PRESENT	0
638488	638485	20024T	PARTICIPANT	\N	PRESENT	0
638489	638485	19745F	PARTICIPANT	\N	PRESENT	0
638499	638498	20266L	PARTICIPANT	\N	PRESENT	0
638500	638498	18083K	PARTICIPANT	\N	PRESENT	0
638501	638498	17965H	PARTICIPANT	\N	PRESENT	0
638502	638498	19575F	PARTICIPANT	\N	PRESENT	0
638527	638526	04059M	PARTICIPANT	\N	PRESENT	0
638528	638526	19651A	PARTICIPANT	\N	PRESENT	1
638529	638526	20086J	PARTICIPANT	\N	PRESENT	0
638639	638638	19507S	PARTICIPANT	\N	PRESENT	0
638531	638526	19621T	PARTICIPANT	\N	PRESENT	0
638532	638526	11053K	PARTICIPANT	\N	PRESENT	0
638641	638640	19441R	PARTICIPANT	\N	PRESENT	0
638645	631731	20180F	PARTICIPANT	\N	PRESENT	0
638643	631731	14255U	PARTICIPANT	\N	PRESENT	0
638644	631731	11053K	PARTICIPANT	\N	PRESENT	0
638537	638526	19399H	PARTICIPANT	\N	PRESENT	0
638646	631731	19333N	PARTICIPANT	\N	PRESENT	0
638539	638526	19611R	PRESIDENT	0	PRESENT	0
638540	638526	19699S	PARTICIPANT	\N	PRESENT	1
638541	638526	12041X	PARTICIPANT	\N	EXCUSE	0
638542	638526	20142Y	PARTICIPANT	\N	PRESENT	1
638543	638526	19705W	PARTICIPANT	\N	PRESENT	1
638544	638526	14229S	PARTICIPANT	\N	PRESENT	0
638647	631731	20056C	PARTICIPANT	\N	PRESENT	0
638546	638526	20026V	PARTICIPANT	\N	PRESENT	1
638648	631731	08012N	PARTICIPANT	\N	PRESENT	0
638649	631731	20148F	PARTICIPANT	\N	PRESENT	0
638650	631731	20026V	PARTICIPANT	\N	PRESENT	0
638651	631732	08012N	PARTICIPANT	\N	PRESENT	0
638652	631732	20056C	PARTICIPANT	\N	PRESENT	0
638653	631732	20026V	PARTICIPANT	\N	PRESENT	0
638654	631732	20180F	PARTICIPANT	\N	PRESENT	0
638809	638808	04057K	PARTICIPANT	\N	PRESENT	0
638839	637809	14030Q	PRESIDENT	0	PRESENT	1
638840	637809	11031D	PARTICIPANT	\N	PRESENT	0
638841	637809	20024T	PARTICIPANT	\N	PRESENT	0
638842	637809	11045K	PARTICIPANT	\N	PRESENT	0
638843	637809	14189C	PARTICIPANT	\N	EXCUSE	0
638844	637809	20118Y	PARTICIPANT	\N	EXCUSE	0
638845	637809	20080C	PARTICIPANT	\N	PRESENT	1
638846	637809	07029T	PARTICIPANT	\N	PRESENT	0
638905	638331	11067R	PARTICIPANT	\N	PRESENT	0
638906	638331	19415P	PARTICIPANT	\N	PRESENT	0
638907	638331	14213J	PARTICIPANT	\N	PRESENT	1
638908	638331	19760E	PARTICIPANT	\N	PRESENT	1
638909	638331	20298U	PARTICIPANT	\N	PRESENT	0
638910	638332	19415P	PARTICIPANT	\N	PRESENT	0
638911	638332	11067R	PARTICIPANT	\N	PRESENT	0
638912	638332	20298U	PARTICIPANT	\N	PRESENT	0
638913	638332	14042U	PARTICIPANT	\N	PRESENT	0
638914	638332	19691J	PARTICIPANT	\N	PRESENT	1
638915	638332	17965H	PARTICIPANT	\N	PRESENT	1
638916	638333	14042U	PARTICIPANT	\N	PRESENT	0
638917	638333	19415P	PARTICIPANT	\N	PRESENT	0
638918	638333	11067R	PARTICIPANT	\N	PRESENT	0
638919	638333	20298U	PARTICIPANT	\N	PRESENT	0
638920	638333	19691J	PARTICIPANT	\N	PRESENT	1
638921	638333	14213J	PARTICIPANT	\N	PRESENT	1
638922	638344	19415P	PARTICIPANT	\N	PRESENT	0
638923	638344	14213J	PARTICIPANT	\N	PRESENT	1
638924	638344	11067R	PARTICIPANT	\N	PRESENT	0
638925	638344	19760E	PARTICIPANT	\N	PRESENT	0
638926	638344	18193Q	PARTICIPANT	\N	PRESENT	0
638927	638344	11097X	PARTICIPANT	\N	PRESENT	1
638928	638372	19415P	PARTICIPANT	\N	PRESENT	0
638929	638372	11067R	PARTICIPANT	\N	PRESENT	0
638930	638372	14213J	PARTICIPANT	\N	PRESENT	1
638931	638372	18193Q	PARTICIPANT	\N	PRESENT	1
638975	638959	19735D	PARTICIPANT	\N	PRESENT	1
638976	638960	19735D	PARTICIPANT	\N	PRESENT	1
639164	638886	19553Y	PARTICIPANT	\N	PRESENT	0
639294	638885	19569H	PARTICIPANT	\N	PRESENT	0
639300	638901	20022R	PARTICIPANT	\N	PRESENT	1
639301	638901	19954N	PARTICIPANT	\N	PRESENT	1
639302	638901	20128B	PARTICIPANT	\N	PRESENT	1
639303	638901	19749K	PARTICIPANT	\N	PRESENT	1
639304	638901	14179A	PARTICIPANT	\N	PRESENT	1
639305	638901	11072N	PARTICIPANT	\N	PRESENT	1
639306	638901	08018U	PARTICIPANT	\N	EXCUSE	0
639307	638885	19703U	PARTICIPANT	\N	PRESENT	1
639309	639308	20050V	PARTICIPANT	\N	PRESENT	0
639310	639308	11077T	PARTICIPANT	\N	PRESENT	0
639311	639308	20144B	PARTICIPANT	\N	EXCUSE	0
639312	639308	19693L	PARTICIPANT	\N	EXCUSE	0
639313	639308	20074E	PARTICIPANT	\N	EXCUSE	0
639314	639308	20126Y	PARTICIPANT	\N	EXCUSE	0
639315	639308	19369B	PARTICIPANT	\N	EXCUSE	0
639317	638581	20024T	PARTICIPANT	\N	PRESENT	0
639318	638581	20042V	PARTICIPANT	\N	PRESENT	1
639319	638581	11053K	PARTICIPANT	\N	PRESENT	0
639320	638581	19681G	PARTICIPANT	\N	PRESENT	1
639321	638581	17229F	PARTICIPANT	\N	PRESENT	0
639322	638581	14179A	PARTICIPANT	\N	PRESENT	0
639323	638581	20056C	PARTICIPANT	\N	PRESENT	1
639324	638581	20052X	PARTICIPANT	\N	PRESENT	1
639325	638581	19349W	PARTICIPANT	\N	PRESENT	1
639326	638581	19671E	PARTICIPANT	\N	PRESENT	1
639327	638581	20044X	PARTICIPANT	\N	PRESENT	0
639328	638958	19717B	PARTICIPANT	\N	EXCUSE	0
639329	638958	14083S	PARTICIPANT	\N	EXCUSE	0
639330	638958	19333N	PARTICIPANT	\N	PRESENT	0
639331	638958	20100N	PRESIDENT	0	PRESENT	0
639332	638958	20150Y	PARTICIPANT	\N	PRESENT	0
639333	638958	20034V	PARTICIPANT	\N	EXCUSE	0
639334	638958	14031R	PARTICIPANT	\N	PRESENT	1
639343	638958	19503N	PARTICIPANT	\N	PRESENT	0
639387	639386	19599P	PARTICIPANT	\N	PRESENT	0
639388	639386	18083K	PARTICIPANT	\N	PRESENT	0
639390	639389	18083K	PARTICIPANT	\N	PRESENT	0
639395	638807	19515S	PARTICIPANT	\N	PRESENT	0
639396	638807	19707Y	PARTICIPANT	\N	PRESENT	0
639398	638807	19575F	PARTICIPANT	\N	PRESENT	0
639399	638807	19747H	PARTICIPANT	\N	PRESENT	0
639400	638807	19383Y	PARTICIPANT	\N	PRESENT	0
639401	638807	14207L	PARTICIPANT	\N	PRESENT	0
639402	638807	20104S	PARTICIPANT	\N	PRESENT	0
639403	638807	14329V	PARTICIPANT	\N	PRESENT	0
639404	638807	20144B	PARTICIPANT	\N	PRESENT	0
639405	638807	19507S	PARTICIPANT	\N	PRESENT	0
639406	638807	19511N	PARTICIPANT	\N	PRESENT	0
639407	638807	01043Q	PARTICIPANT	\N	PRESENT	0
639408	638807	19441R	PARTICIPANT	\N	PRESENT	0
639409	638807	11090Q	PARTICIPANT	\N	PRESENT	0
639410	638807	19705W	PARTICIPANT	\N	PRESENT	0
639411	638807	20062A	PARTICIPANT	\N	PRESENT	0
639413	638807	19782L	PARTICIPANT	\N	PRESENT	1
639417	638807	20174H	PARTICIPANT	\N	PRESENT	1
639418	638807	14033T	PARTICIPANT	\N	PRESENT	1
639419	638807	20286Q	PARTICIPANT	\N	PRESENT	1
639420	638807	14251Q	PARTICIPANT	\N	PRESENT	1
639421	638807	20018V	PARTICIPANT	\N	PRESENT	1
639422	638807	14257W	PARTICIPANT	\N	PRESENT	1
639424	638807	19768N	PARTICIPANT	\N	PRESENT	1
639427	638807	19866P	PARTICIPANT	\N	PRESENT	1
639429	638807	20030R	PARTICIPANT	\N	PRESENT	1
639441	639440	04035D	PARTICIPANT	\N	PRESENT	0
639442	639440	19709B	PARTICIPANT	\N	PRESENT	0
639443	639440	19421M	PARTICIPANT	\N	PRESENT	0
639444	639440	86034E	PARTICIPANT	\N	PRESENT	0
639445	639440	14255U	PARTICIPANT	\N	PRESENT	0
639446	639440	19647E	PARTICIPANT	\N	PRESENT	0
639447	639440	14026U	PARTICIPANT	\N	PRESENT	0
639448	639440	19057M	PARTICIPANT	\N	PRESENT	0
639449	639440	20266L	PARTICIPANT	\N	PRESENT	0
639450	639440	19515S	PARTICIPANT	\N	PRESENT	0
639451	639440	19705W	PARTICIPANT	\N	PRESENT	0
638582	638306	10006L	PARTICIPANT	\N	PRESENT	1
638583	638306	19723Y	PARTICIPANT	\N	PRESENT	1
638584	638306	20130U	PARTICIPANT	\N	PRESENT	1
638585	638306	14147R	PARTICIPANT	\N	PRESENT	1
638586	638306	19735D	PARTICIPANT	\N	PRESENT	1
638587	638306	19703U	PARTICIPANT	\N	PRESENT	1
638588	638307	10006L	PARTICIPANT	\N	PRESENT	0
638589	638307	19735D	PARTICIPANT	\N	PRESENT	0
638590	638307	14147R	PARTICIPANT	\N	PRESENT	0
638591	638307	20130U	PARTICIPANT	\N	PRESENT	0
638592	638307	19723Y	PARTICIPANT	\N	PRESENT	0
638593	635854	19697Q	PARTICIPANT	\N	PRESENT	0
638594	635854	19679N	PARTICIPANT	\N	PRESENT	0
638596	638595	19697Q	PARTICIPANT	\N	PRESENT	0
638597	638595	19679N	PARTICIPANT	\N	PRESENT	0
638599	638598	14213J	PARTICIPANT	\N	PRESENT	0
638600	638598	19697Q	PARTICIPANT	\N	PRESENT	0
638601	638598	19679N	PARTICIPANT	\N	PRESENT	0
638603	638602	19782L	PARTICIPANT	\N	PRESENT	0
638604	638602	14038Y	PARTICIPANT	\N	PRESENT	0
638605	638602	19629C	PARTICIPANT	\N	PRESENT	0
638606	638602	14147R	PARTICIPANT	\N	PRESENT	0
638607	638602	20092G	PARTICIPANT	\N	PRESENT	0
638608	638602	20062A	PARTICIPANT	\N	PRESENT	0
638609	638308	10006L	PARTICIPANT	\N	PRESENT	0
638610	638308	20130U	PARTICIPANT	\N	PRESENT	1
638611	638308	14147R	PARTICIPANT	\N	PRESENT	1
638612	638308	19735D	PARTICIPANT	\N	PRESENT	1
638613	638308	20062A	PARTICIPANT	\N	PRESENT	1
638614	638300	19515S	PRESIDENT	0	PRESENT	0
638615	638300	14031R	PARTICIPANT	\N	PRESENT	0
638616	638300	20040T	PARTICIPANT	\N	PRESENT	0
638617	638300	08060W	PARTICIPANT	\N	EXCUSE	0
638618	638300	14329V	PARTICIPANT	\N	EXCUSE	0
638619	638300	14195A	PARTICIPANT	\N	EXCUSE	0
638620	638300	14357A	PARTICIPANT	\N	EXCUSE	0
638628	638300	20048C	PARTICIPANT	\N	EXCUSE	0
638629	638300	20126Y	PARTICIPANT	\N	EXCUSE	0
638631	638300	08015R	PARTICIPANT	\N	EXCUSE	0
638632	638300	19671E	PARTICIPANT	\N	EXCUSE	0
638633	638300	19369B	PARTICIPANT	\N	EXCUSE	0
638634	638300	20054A	PARTICIPANT	\N	EXCUSE	0
638635	638300	20094J	PARTICIPANT	\N	PRESENT	0
638637	638300	19762G	PARTICIPANT	\N	PRESENT	0
638655	638300	16685X	PARTICIPANT	\N	PRESENT	0
638847	637992	20110Q	PARTICIPANT	\N	PRESENT	1
638848	637992	14207L	PARTICIPANT	\N	PRESENT	1
638849	637992	19798U	PARTICIPANT	\N	PRESENT	1
638850	637992	04045F	PARTICIPANT	\N	PRESENT	0
638856	637993	14207L	PARTICIPANT	\N	PRESENT	1
638857	637993	19798U	PARTICIPANT	\N	PRESENT	1
638858	637994	20042V	PARTICIPANT	\N	PRESENT	1
638859	637994	14207L	PARTICIPANT	\N	PRESENT	1
638860	637994	19599P	PARTICIPANT	\N	PRESENT	0
638861	637994	19533U	PARTICIPANT	\N	PRESENT	0
638862	637994	19798U	PARTICIPANT	\N	PRESENT	1
638863	637994	19820Y	PARTICIPANT	\N	PRESENT	1
638864	637995	14207L	PARTICIPANT	\N	PRESENT	1
638865	637995	19533U	PARTICIPANT	\N	PRESENT	0
638866	637995	19798U	PARTICIPANT	\N	PRESENT	1
638867	637995	19599P	PARTICIPANT	\N	PRESENT	0
638868	637995	20042V	PARTICIPANT	\N	PRESENT	1
638882	637995	19820Y	PARTICIPANT	\N	PRESENT	1
640108	639943	19697Q	PARTICIPANT	\N	PRESENT	0
640109	639943	19683J	PARTICIPANT	\N	PRESENT	0
640110	639943	19798U	PARTICIPANT	\N	PRESENT	0
640111	639943	20090E	PARTICIPANT	\N	PRESENT	0
640112	639943	14217N	PARTICIPANT	\N	PRESENT	0
640113	639943	19367Y	PARTICIPANT	\N	PRESENT	0
640114	639943	11067R	PARTICIPANT	\N	PRESENT	0
640115	639943	19415P	PARTICIPANT	\N	PRESENT	0
640116	639943	10006L	PRESIDENT	0	PRESENT	0
640127	639943	04043D	PARTICIPANT	\N	PRESENT	0
640118	639943	14042U	PARTICIPANT	\N	PRESENT	0
640119	639943	19760E	PARTICIPANT	\N	PRESENT	1
640120	639943	20130U	PARTICIPANT	\N	PRESENT	1
640121	639943	14355X	PARTICIPANT	\N	PRESENT	1
640122	639943	19657G	PARTICIPANT	\N	PRESENT	0
640123	639943	20298U	PARTICIPANT	\N	PRESENT	0
640124	639943	20266L	PARTICIPANT	\N	PRESENT	0
640125	639943	11097X	PARTICIPANT	\N	PRESENT	0
640128	639943	04057K	PARTICIPANT	\N	PRESENT	0
640129	639943	19723Y	PARTICIPANT	\N	PRESENT	0
640130	639943	14026U	PARTICIPANT	\N	PRESENT	0
640131	639943	19569H	PARTICIPANT	\N	PRESENT	0
640132	639943	20040T	PARTICIPANT	\N	PRESENT	0
640133	639943	20248J	PARTICIPANT	\N	PRESENT	0
640136	639943	19553Y	PARTICIPANT	\N	PRESENT	1
640137	639943	19691J	PARTICIPANT	\N	PRESENT	0
640138	639943	14195A	PARTICIPANT	\N	PRESENT	1
640197	639995	19683J	PRESIDENT	0	PRESENT	0
640198	639995	10006L	PARTICIPANT	\N	PRESENT	0
640199	639995	11031D	PARTICIPANT	\N	PRESENT	0
640200	639995	19691J	PARTICIPANT	\N	PRESENT	0
640201	639995	19553Y	PARTICIPANT	\N	PRESENT	0
640202	639995	19703U	PARTICIPANT	\N	PRESENT	0
640203	639995	19723Y	PARTICIPANT	\N	PRESENT	0
640204	639995	20062A	PARTICIPANT	\N	PRESENT	0
640205	639943	04092N	PARTICIPANT	\N	EXCUSE	0
640206	639995	04092N	PARTICIPANT	\N	EXCUSE	0
640211	639995	20130U	PARTICIPANT	\N	PRESENT	1
640217	639995	19301E	PARTICIPANT	\N	PRESENT	1
640223	639995	14147R	PARTICIPANT	\N	PRESENT	0
640225	639995	19735D	PARTICIPANT	\N	PRESENT	0
640230	639941	11067R	PARTICIPANT	\N	EXCUSE	0
640762	640518	19415P	PARTICIPANT	\N	PRESENT	0
640763	640518	11067R	PARTICIPANT	\N	PRESENT	0
640764	640518	14223L	PARTICIPANT	\N	PRESENT	1
641715	641714	11027H	PARTICIPANT	\N	PRESENT	0
641716	641714	20024T	PARTICIPANT	\N	PRESENT	0
640768	640765	19725B	PARTICIPANT	\N	PRESENT	0
640769	640765	19447X	PARTICIPANT	\N	PRESENT	0
640770	640765	14147R	PARTICIPANT	\N	PRESENT	1
640771	640765	20128B	PARTICIPANT	\N	PRESENT	1
640773	640772	19643A	PARTICIPANT	\N	PRESENT	0
640774	640772	20132W	PARTICIPANT	\N	PRESENT	0
640775	640772	19725B	PARTICIPANT	\N	PRESENT	0
640776	640772	19447X	PARTICIPANT	\N	PRESENT	0
640777	640772	14147R	PARTICIPANT	\N	PRESENT	1
640781	640779	07004J	PARTICIPANT	\N	PRESENT	0
640780	640779	04047H	PARTICIPANT	\N	PRESENT	0
640782	640779	11026G	PARTICIPANT	\N	PRESENT	0
640783	640779	20110Q	PARTICIPANT	\N	PRESENT	1
641157	641156	20080C	PARTICIPANT	\N	PRESENT	1
641158	641156	14083S	PARTICIPANT	\N	PRESENT	0
641159	641156	20072C	PARTICIPANT	\N	PRESENT	1
641160	641156	20036X	PARTICIPANT	\N	PRESENT	0
641181	641175	20110Q	PARTICIPANT	\N	PRESENT	0
641183	641182	04047H	PARTICIPANT	\N	PRESENT	0
641184	641182	14147R	PARTICIPANT	\N	PRESENT	0
641179	641175	04047H	PARTICIPANT	\N	PRESENT	0
641180	641175	11026G	PARTICIPANT	\N	PRESENT	0
641185	641182	20110Q	PARTICIPANT	\N	PRESENT	0
641221	641220	04047H	PARTICIPANT	\N	PRESENT	0
641222	641220	17737W	PARTICIPANT	\N	PRESENT	0
641223	641220	19629C	PARTICIPANT	\N	PRESENT	0
641224	641220	11026G	PARTICIPANT	\N	PRESENT	0
641225	641220	20110Q	PARTICIPANT	\N	PRESENT	0
641266	641265	19479G	PARTICIPANT	\N	PRESENT	0
642039	642038	04035D	PARTICIPANT	\N	PRESENT	0
642040	642038	14133K	PARTICIPANT	\N	PRESENT	0
642041	642038	20042V	PARTICIPANT	\N	PRESENT	0
642042	642038	01058X	PARTICIPANT	\N	PRESENT	0
642043	642038	16685X	PARTICIPANT	\N	PRESENT	0
642044	642038	04042C	PRESIDENT	0	PRESENT	0
642045	642038	01024M	PARTICIPANT	\N	PRESENT	0
642046	642038	11066Q	PARTICIPANT	\N	PRESENT	0
642047	642038	19319Q	PARTICIPANT	\N	PRESENT	0
642048	642038	14105F	PARTICIPANT	\N	PRESENT	0
642049	642038	19421M	PARTICIPANT	\N	PRESENT	0
642050	642038	19347U	PARTICIPANT	\N	PRESENT	0
642051	642038	14193X	PARTICIPANT	\N	PRESENT	0
642052	642038	08061X	PARTICIPANT	\N	PRESENT	0
642053	642038	08047A	PARTICIPANT	\N	PRESENT	0
642054	642038	14255U	PARTICIPANT	\N	PRESENT	0
642055	642038	17023S	PARTICIPANT	\N	PRESENT	0
642056	642038	11041F	PARTICIPANT	\N	PRESENT	1
642057	642038	11083R	PARTICIPANT	\N	PRESENT	1
642058	642038	14249W	PARTICIPANT	\N	PRESENT	0
642059	642038	20072C	PARTICIPANT	\N	PRESENT	1
642060	642038	11054L	PARTICIPANT	\N	PRESENT	1
648184	648164	20090E	PARTICIPANT	\N	PRESENT	0
648309	647645	20038A	PARTICIPANT	\N	PRESENT	0
648310	647645	01025N	PARTICIPANT	\N	PRESENT	0
648311	647645	20100N	PARTICIPANT	\N	PRESENT	0
648312	647645	19599P	PARTICIPANT	\N	PRESENT	0
648313	647645	17023S	PARTICIPANT	\N	PRESENT	0
648314	647645	14231L	PARTICIPANT	\N	PRESENT	0
648315	647645	20286Q	PARTICIPANT	\N	PRESENT	0
648316	647645	20172F	PARTICIPANT	\N	PRESENT	0
648317	647645	19347U	PARTICIPANT	\N	PRESENT	0
648318	647645	20180F	PARTICIPANT	\N	PRESENT	0
648319	647645	19565D	PARTICIPANT	\N	PRESENT	0
648320	647645	11064N	PARTICIPANT	\N	PRESENT	0
648321	647645	19691J	PARTICIPANT	\N	PRESENT	0
648322	647645	19553Y	PARTICIPANT	\N	PRESENT	0
648323	647645	20128B	PARTICIPANT	\N	PRESENT	0
648324	647645	20048C	PARTICIPANT	\N	PRESENT	0
648325	647645	19333N	PARTICIPANT	\N	PRESENT	0
648326	647645	19399H	PARTICIPANT	\N	PRESENT	0
648327	647645	14213J	PARTICIPANT	\N	PRESENT	0
648328	647645	20034V	PARTICIPANT	\N	PRESENT	0
648329	647645	19715Y	PARTICIPANT	\N	PRESENT	0
648330	647645	20056C	PARTICIPANT	\N	PRESENT	0
648331	647645	14021P	PARTICIPANT	\N	PRESENT	0
648332	647645	99004R	PARTICIPANT	\N	PRESENT	0
648333	647645	14073Q	PARTICIPANT	\N	PRESENT	0
648334	647645	11099A	PARTICIPANT	\N	PRESENT	0
648335	647645	19583F	PARTICIPANT	\N	PRESENT	0
648336	647645	20126Y	PARTICIPANT	\N	PRESENT	0
648337	647645	12041X	PARTICIPANT	\N	PRESENT	0
648338	647645	19711U	PARTICIPANT	\N	PRESENT	0
648340	647645	20108W	PARTICIPANT	\N	PRESENT	0
648342	647645	14037X	PARTICIPANT	\N	PRESENT	0
648343	647645	08034U	PARTICIPANT	\N	PRESENT	0
648344	647645	11026G	PARTICIPANT	\N	PRESENT	0
648345	647645	20052X	PARTICIPANT	\N	PRESENT	0
648346	647645	01048V	PARTICIPANT	\N	PRESENT	0
648347	647645	19441R	PARTICIPANT	\N	PRESENT	0
648349	647645	12016W	PARTICIPANT	\N	PRESENT	0
648351	647645	14251Q	PARTICIPANT	\N	PRESENT	0
648352	647645	14031R	PARTICIPANT	\N	PRESENT	0
648353	647645	19826F	PARTICIPANT	\N	PRESENT	0
648355	647645	14111D	PARTICIPANT	\N	PRESENT	0
648356	647645	11085T	PARTICIPANT	\N	PRESENT	0
648357	647645	01060R	PARTICIPANT	\N	PRESENT	0
648358	647645	19563B	PARTICIPANT	\N	PRESENT	0
648359	647645	14147R	PARTICIPANT	\N	PRESENT	0
648360	647645	14071N	PARTICIPANT	\N	PRESENT	0
648361	647645	20096L	PARTICIPANT	\N	PRESENT	0
648362	647645	14169X	PARTICIPANT	\N	PRESENT	0
648363	647645	19593H	PARTICIPANT	\N	PRESENT	0
648364	647645	14191V	PARTICIPANT	\N	PRESENT	0
648365	647645	20050V	PARTICIPANT	\N	PRESENT	0
648366	647645	08061X	PARTICIPANT	\N	PRESENT	0
648367	647645	14193X	PARTICIPANT	\N	PRESENT	0
648368	647645	20148F	PARTICIPANT	\N	PRESENT	0
648369	647645	19533U	PARTICIPANT	\N	PRESENT	0
648370	647645	17637T	PARTICIPANT	\N	PRESENT	0
648371	647645	19745F	PARTICIPANT	\N	PRESENT	0
648372	647645	11090Q	PARTICIPANT	\N	PRESENT	0
648373	647645	04043D	PARTICIPANT	\N	PRESENT	0
648374	647645	14331P	PARTICIPANT	\N	PRESENT	0
648375	647645	14225N	PARTICIPANT	\N	PRESENT	0
648376	647645	20082E	PARTICIPANT	\N	PRESENT	0
648377	647645	11012A	PARTICIPANT	\N	PRESENT	0
648378	647645	95063L	PARTICIPANT	\N	PRESENT	0
648379	647645	19798U	PARTICIPANT	\N	PRESENT	0
648380	647645	14229S	PARTICIPANT	\N	PRESENT	0
648381	647645	14107H	PARTICIPANT	\N	PRESENT	0
648382	647645	20092G	PARTICIPANT	\N	PRESENT	0
648383	647645	20044X	PARTICIPANT	\N	PRESENT	0
648384	647645	11097X	PARTICIPANT	\N	PRESENT	0
648385	647645	04045F	PARTICIPANT	\N	PRESENT	0
648386	647645	19762G	PARTICIPANT	\N	PRESENT	0
648387	647645	19713W	PARTICIPANT	\N	PRESENT	0
648388	647645	20062A	PARTICIPANT	\N	PRESENT	0
648389	647645	20064C	PARTICIPANT	\N	PRESENT	0
648390	647645	19479G	PARTICIPANT	\N	PRESENT	0
648392	647645	19549D	PARTICIPANT	\N	PRESENT	0
648393	647645	11083R	PARTICIPANT	\N	PRESENT	0
648394	647645	19749K	PARTICIPANT	\N	PRESENT	0
648395	647645	01058X	PARTICIPANT	\N	PRESENT	0
648397	647643	11067R	PARTICIPANT	\N	PRESENT	0
648405	648404	14249W	PARTICIPANT	\N	PRESENT	0
648406	648404	14111D	PARTICIPANT	\N	PRESENT	0
648407	648404	19563B	PARTICIPANT	\N	PRESENT	0
648433	648432	14069U	PARTICIPANT	\N	PRESENT	0
648434	648432	14147R	PARTICIPANT	\N	PRESENT	0
648435	648432	05012A	PARTICIPANT	\N	PRESENT	0
648436	648432	01062T	PARTICIPANT	\N	PRESENT	0
648438	647641	19760E	PARTICIPANT	\N	PRESENT	0
648439	647641	19717B	PARTICIPANT	\N	PRESENT	0
648441	647641	20130U	PARTICIPANT	\N	PRESENT	0
648442	647641	19683J	PARTICIPANT	\N	PRESENT	0
648443	647641	18193Q	PARTICIPANT	\N	PRESENT	0
648444	647641	17779H	PARTICIPANT	\N	PRESENT	0
648445	647641	10006L	PARTICIPANT	\N	PRESENT	0
648446	647641	19798U	PARTICIPANT	\N	PRESENT	0
648447	647641	20148F	PARTICIPANT	\N	PRESENT	0
648448	647641	14071N	PARTICIPANT	\N	PRESENT	0
648449	647641	11097X	PARTICIPANT	\N	PRESENT	0
648450	647641	14217N	PARTICIPANT	\N	PRESENT	0
648451	647641	14213J	PARTICIPANT	\N	PRESENT	0
648452	647641	19415P	PARTICIPANT	\N	PRESENT	0
648453	647641	11103C	PARTICIPANT	\N	PRESENT	1
648454	647641	19657G	PARTICIPANT	\N	PRESENT	1
648455	647641	19569H	PARTICIPANT	\N	PRESENT	0
648456	647641	04043D	PARTICIPANT	\N	PRESENT	0
648457	647641	14223L	PARTICIPANT	\N	PRESENT	1
648458	647641	20040T	PARTICIPANT	\N	PRESENT	1
648459	647641	20248J	PARTICIPANT	\N	PRESENT	1
648460	647641	01034P	PARTICIPANT	\N	PRESENT	1
648461	647641	19553Y	PARTICIPANT	\N	PRESENT	0
648462	647641	19691J	PARTICIPANT	\N	PRESENT	0
648463	647641	20066E	PARTICIPANT	\N	PRESENT	0
648464	647641	19713W	PARTICIPANT	\N	PRESENT	0
648465	647641	14042U	PARTICIPANT	\N	PRESENT	0
648469	647641	19679N	PARTICIPANT	\N	PRESENT	0
648470	647641	11067R	PARTICIPANT	\N	EXCUSE	0
648471	647641	19723Y	PARTICIPANT	\N	PRESENT	0
648472	647641	20090E	PARTICIPANT	\N	PRESENT	0
648521	646314	20068G	PARTICIPANT	\N	PRESENT	1
648522	646314	20038A	PARTICIPANT	\N	EXCUSE	0
648523	646314	20032T	PARTICIPANT	\N	PRESENT	0
648524	646314	19745F	PARTICIPANT	\N	PRESENT	0
648525	646314	20076G	PARTICIPANT	\N	PRESENT	0
648526	647641	11031D	PARTICIPANT	\N	PRESENT	0
648540	647518	19673G	PARTICIPANT	\N	PRESENT	0
648542	648541	14133K	PARTICIPANT	\N	PRESENT	0
648543	648541	14217N	PARTICIPANT	\N	PRESENT	0
648544	648541	10006L	PARTICIPANT	\N	PRESENT	0
648545	648541	19507S	PARTICIPANT	\N	PRESENT	0
648546	648541	14147R	PARTICIPANT	\N	PRESENT	0
648547	646314	19333N	PARTICIPANT	\N	PRESENT	0
648548	646314	14031R	PARTICIPANT	\N	PRESENT	0
648549	646314	14221J	PARTICIPANT	\N	PRESENT	0
648550	646314	19599P	PARTICIPANT	\N	PRESENT	0
648551	646314	17229F	PARTICIPANT	\N	PRESENT	0
648552	646314	19739H	PARTICIPANT	\N	PRESENT	0
648553	646314	19681G	PARTICIPANT	\N	PRESENT	0
648554	646314	19387D	PARTICIPANT	\N	PRESENT	1
648555	646314	20120S	PARTICIPANT	\N	PRESENT	1
648556	646314	20096L	PARTICIPANT	\N	PRESENT	0
648557	646314	20106U	PARTICIPANT	\N	PRESENT	0
648558	646314	19701S	PARTICIPANT	\N	PRESENT	0
648559	646314	20122U	PARTICIPANT	\N	PRESENT	1
648560	646314	11065P	PARTICIPANT	\N	PRESENT	1
648561	647669	20086J	PARTICIPANT	\N	PRESENT	0
648562	647669	14331P	PARTICIPANT	\N	PRESENT	0
648563	647669	04071H	PARTICIPANT	\N	PRESENT	0
648564	647669	20080C	PARTICIPANT	\N	PRESENT	0
648565	647669	19667J	PARTICIPANT	\N	PRESENT	0
648566	647669	14225N	PRESIDENT	0	PRESENT	0
648567	647669	19671E	PARTICIPANT	\N	PRESENT	0
648568	647669	19349W	PARTICIPANT	\N	PRESENT	0
648569	647669	20116W	PARTICIPANT	\N	PRESENT	0
648570	647669	14253S	PARTICIPANT	\N	PRESENT	0
648571	647669	20126Y	PARTICIPANT	\N	PRESENT	0
648572	647669	11048N	PARTICIPANT	\N	PRESENT	0
648573	647669	19647E	PARTICIPANT	\N	PRESENT	0
648574	647669	19711U	PARTICIPANT	\N	PRESENT	0
628681	626875	20034V	PARTICIPANT	\N	PRESENT	0
628682	626875	14069U	PARTICIPANT	\N	PRESENT	0
628683	626875	14147R	PARTICIPANT	\N	PRESENT	0
628684	626875	19723Y	PARTICIPANT	\N	PRESENT	0
628685	626875	14071N	PARTICIPANT	\N	PRESENT	0
628686	626875	14097Y	PARTICIPANT	\N	PRESENT	0
628687	626875	19591F	PARTICIPANT	\N	PRESENT	0
628741	626877	20130U	PARTICIPANT	\N	PRESENT	0
628742	626877	19591F	PARTICIPANT	\N	PRESENT	0
628743	626877	19413M	PARTICIPANT	\N	PRESENT	0
628744	626877	20082E	PARTICIPANT	\N	PRESENT	0
628745	626877	17737W	PARTICIPANT	\N	PRESENT	0
628746	626877	20026V	PARTICIPANT	\N	PRESENT	0
628747	626877	19399H	PARTICIPANT	\N	PRESENT	0
628770	626877	20102Q	PARTICIPANT	\N	PRESENT	0
628749	626877	19798U	PARTICIPANT	\N	PRESENT	0
628771	626877	19749K	PARTICIPANT	\N	PRESENT	0
628751	626877	19723Y	PARTICIPANT	\N	PRESENT	0
628752	626877	20034V	PARTICIPANT	\N	PRESENT	0
628753	626877	11097X	PARTICIPANT	\N	PRESENT	0
628754	626877	20066E	PARTICIPANT	\N	PRESENT	0
628755	626877	14097Y	PARTICIPANT	\N	PRESENT	0
628756	626877	19719D	PARTICIPANT	\N	PRESENT	0
628757	626877	11067R	PARTICIPANT	\N	PRESENT	0
628783	626877	14069U	PARTICIPANT	\N	PRESENT	0
628759	626877	11031D	PARTICIPANT	\N	PRESENT	0
628760	626877	14281W	PARTICIPANT	\N	PRESENT	0
628761	626877	19713W	PARTICIPANT	\N	PRESENT	0
628762	626877	19599P	PARTICIPANT	\N	PRESENT	0
628763	626877	01024M	PARTICIPANT	\N	PRESENT	0
628764	626877	14195A	PARTICIPANT	\N	PRESENT	0
628765	626877	14030Q	PARTICIPANT	\N	PRESENT	0
628766	626877	19691J	PARTICIPANT	\N	PRESENT	0
628767	626877	14071N	PARTICIPANT	\N	PRESENT	0
628768	626877	19553Y	PARTICIPANT	\N	PRESENT	0
628769	626877	17779H	PARTICIPANT	\N	PRESENT	0
628784	626877	14026U	PARTICIPANT	\N	PRESENT	0
628785	626877	14217N	PARTICIPANT	\N	PRESENT	0
628786	626877	11056N	PARTICIPANT	\N	PRESENT	0
628787	626877	20092G	PARTICIPANT	\N	PRESENT	0
628788	626877	20024T	PARTICIPANT	\N	PRESENT	0
628789	626877	10006L	PARTICIPANT	\N	PRESENT	0
630084	630083	20068G	PARTICIPANT	\N	PRESENT	0
630085	630083	14219Q	PRESIDENT	0	PRESENT	0
630086	630083	19745F	PARTICIPANT	\N	PRESENT	0
630087	630083	20032T	PARTICIPANT	\N	PRESENT	0
630088	630083	20102Q	PARTICIPANT	\N	PRESENT	0
630089	630083	19503N	PARTICIPANT	\N	PRESENT	0
630090	630083	20020P	PARTICIPANT	\N	PRESENT	0
630091	630083	19826F	PARTICIPANT	\N	PRESENT	0
630092	630083	19619A	PARTICIPANT	\N	PRESENT	0
630093	630083	17229F	PARTICIPANT	\N	PRESENT	0
630094	630083	19333N	PARTICIPANT	\N	PRESENT	0
630095	630083	20046A	PARTICIPANT	\N	PRESENT	0
630096	630083	17367Q	PARTICIPANT	\N	PRESENT	0
630097	630083	19549D	PARTICIPANT	\N	PRESENT	0
630098	630083	19637C	PARTICIPANT	\N	PRESENT	0
630099	630083	19387D	PARTICIPANT	\N	PRESENT	0
628739	626877	99004R	PARTICIPANT	\N	PRESENT	0
628740	626877	20142Y	PARTICIPANT	\N	PRESENT	0
630100	630083	20106U	PARTICIPANT	\N	PRESENT	1
630101	630083	20140W	PARTICIPANT	\N	PRESENT	1
630102	630083	20096L	PARTICIPANT	\N	PRESENT	0
630103	630083	19551W	PARTICIPANT	\N	PRESENT	0
630104	630083	20100N	PARTICIPANT	\N	PRESENT	0
630105	630083	19599P	PARTICIPANT	\N	PRESENT	0
630106	630083	14031R	PARTICIPANT	\N	PRESENT	0
630107	630083	19685L	PARTICIPANT	\N	PRESENT	0
630108	630083	08060W	PARTICIPANT	\N	PRESENT	0
630109	630083	20024T	PARTICIPANT	\N	PRESENT	0
630110	630083	11101A	PARTICIPANT	\N	PRESENT	0
630111	630083	19701S	PARTICIPANT	\N	PRESENT	0
630112	630083	18083K	PARTICIPANT	\N	PRESENT	1
630113	630083	14237S	PARTICIPANT	\N	PRESENT	0
630114	630083	20136B	PARTICIPANT	\N	PRESENT	0
630115	630083	20076G	PARTICIPANT	\N	PRESENT	0
630116	630083	19251M	PARTICIPANT	\N	EXCUSE	0
630118	630083	19820Y	PARTICIPANT	\N	PRESENT	0
630119	629022	20130U	PARTICIPANT	\N	PRESENT	1
630120	629022	11067R	PARTICIPANT	\N	PRESENT	0
630121	629022	04092N	PRESIDENT	0	PRESENT	0
630122	629022	19798U	PARTICIPANT	\N	PRESENT	0
630123	629022	19713W	PARTICIPANT	\N	PRESENT	0
630124	629022	11097X	PARTICIPANT	\N	PRESENT	0
630125	629022	19415P	PARTICIPANT	\N	PRESENT	0
630126	629022	19691J	PARTICIPANT	\N	PRESENT	0
630127	629022	20148F	PARTICIPANT	\N	PRESENT	0
630128	629022	18193Q	PARTICIPANT	\N	PRESENT	0
630129	629022	19723Y	PARTICIPANT	\N	PRESENT	0
630130	629022	19703U	PARTICIPANT	\N	PRESENT	0
630131	629022	11031D	PARTICIPANT	\N	PRESENT	1
630132	629022	19553Y	PARTICIPANT	\N	PRESENT	1
630133	629022	20066E	PARTICIPANT	\N	PRESENT	1
630134	629022	14042U	PARTICIPANT	\N	PRESENT	0
630135	629022	14217N	PARTICIPANT	\N	PRESENT	0
630136	629022	10006L	PARTICIPANT	\N	EXCUSE	0
630137	629022	19760E	PARTICIPANT	\N	PRESENT	1
630139	630083	14169X	PARTICIPANT	\N	PRESENT	0
630141	629957	19333N	PARTICIPANT	\N	PRESENT	0
630142	629957	19701S	PARTICIPANT	\N	PRESENT	0
630143	629957	19549D	PARTICIPANT	\N	PRESENT	0
630144	629957	20076G	PARTICIPANT	\N	PRESENT	0
630195	629957	14237S	PARTICIPANT	\N	PRESENT	0
630146	629957	14219Q	PRESIDENT	0	PRESENT	0
630147	629957	19820Y	PARTICIPANT	\N	PRESENT	0
630148	629957	19826F	PARTICIPANT	\N	PRESENT	0
630196	629957	20140W	PARTICIPANT	\N	PRESENT	1
630150	629957	19599P	PARTICIPANT	\N	PRESENT	0
630197	629957	18083K	PARTICIPANT	\N	PRESENT	0
630152	629957	20096L	PARTICIPANT	\N	PRESENT	0
630153	629957	19551W	PARTICIPANT	\N	PRESENT	0
630154	629957	20100N	PARTICIPANT	\N	PRESENT	0
630198	629957	19619A	PARTICIPANT	\N	PRESENT	0
630156	629957	08060W	PARTICIPANT	\N	PRESENT	0
630199	629957	14179A	PARTICIPANT	\N	PRESENT	1
628679	626875	20142Y	PARTICIPANT	\N	PRESENT	0
628680	626875	20082E	PARTICIPANT	\N	PRESENT	0
630158	629957	20020P	PARTICIPANT	\N	PRESENT	0
630159	629957	19685L	PARTICIPANT	\N	PRESENT	0
630160	629957	17367Q	PARTICIPANT	\N	PRESENT	0
630161	629957	20024T	PARTICIPANT	\N	PRESENT	0
630162	629957	20032T	PARTICIPANT	\N	PRESENT	0
630163	629957	20136B	PARTICIPANT	\N	PRESENT	0
630164	629957	14031R	PARTICIPANT	\N	PRESENT	0
630200	629957	20128B	PARTICIPANT	\N	PRESENT	1
630166	629957	17229F	PARTICIPANT	\N	PRESENT	0
630167	629957	14169X	PARTICIPANT	\N	PRESENT	0
630168	629957	20068G	PARTICIPANT	\N	PRESENT	0
630169	629957	11101A	PARTICIPANT	\N	PRESENT	0
630170	629957	19745F	PARTICIPANT	\N	PRESENT	0
630201	629957	14221J	PARTICIPANT	\N	PRESENT	0
630202	629205	14111D	PARTICIPANT	\N	PRESENT	0
630203	629205	19543W	PARTICIPANT	\N	PRESENT	0
630204	629205	04047H	PRESIDENT	0	PRESENT	0
630175	629957	19251M	PARTICIPANT	\N	PRESENT	0
630205	629205	19673G	PARTICIPANT	\N	PRESENT	0
630206	629205	19675J	PARTICIPANT	\N	PRESENT	0
630207	629205	14231L	PARTICIPANT	\N	PRESENT	0
630208	629205	11056N	PARTICIPANT	\N	PRESENT	0
630183	629957	19637C	PARTICIPANT	\N	PRESENT	0
630184	629957	20106U	PARTICIPANT	\N	PRESENT	1
630185	629957	08015R	PARTICIPANT	\N	PRESENT	0
630186	629957	20046A	PARTICIPANT	\N	PRESENT	0
630187	629957	14083S	PARTICIPANT	\N	PRESENT	0
630188	629957	20126Y	PARTICIPANT	\N	PRESENT	1
630191	629957	19387D	PARTICIPANT	\N	PRESENT	0
630192	629957	20102Q	PARTICIPANT	\N	PRESENT	0
630193	629957	19503N	PARTICIPANT	\N	PRESENT	0
630194	629957	19577H	PARTICIPANT	\N	PRESENT	1
630209	629205	19629C	PARTICIPANT	\N	PRESENT	0
630210	629205	20108W	PARTICIPANT	\N	PRESENT	0
630211	629205	20110Q	PARTICIPANT	\N	PRESENT	0
630212	629205	14147R	PARTICIPANT	\N	PRESENT	0
630213	629205	14215L	PARTICIPANT	\N	PRESENT	0
630214	629205	20022R	PARTICIPANT	\N	PRESENT	0
630215	629205	11072N	PARTICIPANT	\N	PRESENT	0
630216	629205	11085T	PARTICIPANT	\N	PRESENT	0
630217	629957	05012A	PARTICIPANT	\N	PRESENT	0
630218	629957	20038A	PARTICIPANT	\N	PRESENT	0
630220	629205	19581D	PARTICIPANT	\N	PRESENT	0
630221	629205	19585H	PARTICIPANT	\N	PRESENT	0
639452	639440	11026G	PARTICIPANT	\N	PRESENT	0
639453	639440	04042C	PARTICIPANT	\N	PRESENT	0
639454	639440	20264J	PARTICIPANT	\N	PRESENT	0
639455	639440	14147R	PARTICIPANT	\N	PRESENT	0
639456	639440	11027H	PARTICIPANT	\N	PRESENT	0
639457	639440	11070L	PARTICIPANT	\N	PRESENT	0
639458	639440	20120S	PARTICIPANT	\N	PRESENT	0
639474	639459	18003S	PARTICIPANT	\N	EXCUSE	0
639504	639503	19503N	PARTICIPANT	\N	PRESENT	0
639505	639503	20150Y	PARTICIPANT	\N	PRESENT	0
639506	639503	19333N	PARTICIPANT	\N	PRESENT	0
639508	639507	20150Y	PARTICIPANT	\N	PRESENT	0
639509	639507	19333N	PARTICIPANT	\N	PRESENT	0
639510	639507	19503N	PARTICIPANT	\N	PRESENT	0
639527	639526	20150Y	PARTICIPANT	\N	PRESENT	0
639528	639526	19333N	PARTICIPANT	\N	PRESENT	0
639545	639336	19415P	PARTICIPANT	\N	PRESENT	0
639549	639477	19691J	PARTICIPANT	\N	PRESENT	1
639547	639337	19415P	PARTICIPANT	\N	PRESENT	0
639548	639337	19798U	PARTICIPANT	\N	PRESENT	1
639550	639477	19415P	PARTICIPANT	\N	PRESENT	0
639588	639587	20050V	PARTICIPANT	\N	EXCUSE	0
639616	639615	04047H	PARTICIPANT	\N	PRESENT	0
639617	639615	10015M	PARTICIPANT	\N	PRESENT	0
639618	639615	07004J	PARTICIPANT	\N	PRESENT	0
639619	639615	11072N	PARTICIPANT	\N	PRESENT	1
639627	639624	11026G	PARTICIPANT	\N	PRESENT	1
639629	639628	20110Q	PARTICIPANT	\N	PRESENT	0
639631	639630	04047H	PARTICIPANT	\N	PRESENT	0
639632	639630	07004J	PARTICIPANT	\N	PRESENT	0
639633	639630	11026G	PARTICIPANT	\N	PRESENT	1
639635	639634	10015M	PARTICIPANT	\N	PRESENT	0
639636	639630	20110Q	PARTICIPANT	\N	PRESENT	1
639683	639682	19711U	PARTICIPANT	\N	PRESENT	0
639684	639682	19647E	PARTICIPANT	\N	PRESENT	1
639685	639682	20024T	PARTICIPANT	\N	PRESENT	0
639686	639682	08010L	PARTICIPANT	\N	PRESENT	0
639722	639476	19533U	PRESIDENT	0	PRESENT	0
639723	639476	20110Q	PARTICIPANT	\N	PRESENT	1
639724	639476	20114U	PARTICIPANT	\N	PRESENT	1
639725	639476	19798U	PARTICIPANT	\N	PRESENT	1
639726	639476	19820Y	PARTICIPANT	\N	PRESENT	1
639727	639476	14207L	PARTICIPANT	\N	PRESENT	1
639730	639476	19693L	PARTICIPANT	\N	PRESENT	0
639761	639759	20152B	PARTICIPANT	\N	PRESENT	0
639762	639759	19525U	PARTICIPANT	\N	PRESENT	0
639763	639759	86034E	PARTICIPANT	\N	PRESENT	0
639764	639759	11031D	PARTICIPANT	\N	PRESENT	0
639765	639759	19565D	PARTICIPANT	\N	PRESENT	0
639766	639759	11056N	PARTICIPANT	\N	PRESENT	0
639767	639759	01058X	PARTICIPANT	\N	PRESENT	0
639768	639759	12041X	PARTICIPANT	\N	PRESENT	0
639769	639759	19687N	PARTICIPANT	\N	PRESENT	0
639770	639759	04085P	PARTICIPANT	\N	PRESENT	0
639771	639759	19695N	PARTICIPANT	\N	PRESENT	0
639772	639759	19693L	PARTICIPANT	\N	PRESENT	0
639773	639759	99004R	PARTICIPANT	\N	PRESENT	0
639774	639759	19593H	PARTICIPANT	\N	PRESENT	0
639775	639759	17637T	PARTICIPANT	\N	PRESENT	0
639776	639759	20102Q	PARTICIPANT	\N	PRESENT	0
639777	639759	11077T	PARTICIPANT	\N	PRESENT	0
639778	639759	19663E	PARTICIPANT	\N	PRESENT	0
639779	639759	20044X	PARTICIPANT	\N	PRESENT	0
639780	639759	19689Q	PARTICIPANT	\N	PRESENT	0
639781	639759	20038A	PARTICIPANT	\N	PRESENT	0
639782	639759	19673G	PARTICIPANT	\N	PRESENT	0
639783	639759	20098N	PARTICIPANT	\N	PRESENT	0
639784	639759	14033T	PARTICIPANT	\N	PRESENT	0
639785	639759	07029T	PARTICIPANT	\N	PRESENT	0
639786	639759	19741B	PARTICIPANT	\N	PRESENT	0
639787	639759	14031R	PARTICIPANT	\N	PRESENT	0
639788	639759	19667J	PARTICIPANT	\N	PRESENT	0
639789	639759	19515S	PARTICIPANT	\N	PRESENT	0
639790	639759	11080N	PARTICIPANT	\N	PRESENT	0
639791	639759	14259Y	PARTICIPANT	\N	PRESENT	0
639792	639759	08047A	PARTICIPANT	\N	PRESENT	0
639793	639759	01028R	PARTICIPANT	\N	PRESENT	0
639794	639759	19705W	PARTICIPANT	\N	PRESENT	0
639795	639759	19707Y	PARTICIPANT	\N	PRESENT	0
639796	639759	20104S	PARTICIPANT	\N	PRESENT	0
639797	639759	20172F	PARTICIPANT	\N	PRESENT	0
639798	639759	20100N	PARTICIPANT	\N	PRESENT	0
639799	639759	20134Y	PARTICIPANT	\N	PRESENT	0
639800	639759	14147R	PARTICIPANT	\N	PRESENT	0
639801	639759	20032T	PARTICIPANT	\N	PRESENT	0
639802	639759	19347U	PARTICIPANT	\N	PRESENT	0
639803	639759	20062A	PARTICIPANT	\N	PRESENT	0
639804	639759	19443T	PARTICIPANT	\N	PRESENT	0
639805	639759	11012A	PARTICIPANT	\N	PRESENT	0
639806	639759	14357A	PARTICIPANT	\N	PRESENT	0
639807	639759	19387D	PARTICIPANT	\N	PRESENT	0
639808	639759	19383Y	PARTICIPANT	\N	PRESENT	0
639809	639759	19762G	PARTICIPANT	\N	PRESENT	0
639810	639759	19637C	PARTICIPANT	\N	PRESENT	0
639811	639759	19697Q	PARTICIPANT	\N	PRESENT	0
639812	639759	20054A	PARTICIPANT	\N	PRESENT	0
639813	639759	20174H	PARTICIPANT	\N	PRESENT	0
639814	639759	14251Q	PARTICIPANT	\N	PRESENT	0
639815	639759	11067R	PARTICIPANT	\N	PRESENT	0
639816	639759	19531S	PARTICIPANT	\N	PRESENT	0
639817	639759	20070A	PARTICIPANT	\N	PRESENT	0
639818	639759	19820Y	PARTICIPANT	\N	PRESENT	0
639819	639759	19333N	PARTICIPANT	\N	PRESENT	0
639820	639759	20022R	PARTICIPANT	\N	PRESENT	0
639821	639759	14257W	PARTICIPANT	\N	PRESENT	0
639822	639759	19647E	PARTICIPANT	\N	PRESENT	0
639823	639759	04042C	PARTICIPANT	\N	PRESENT	0
639824	639759	08060W	PARTICIPANT	\N	PRESENT	0
639825	639759	12016W	PARTICIPANT	\N	PRESENT	0
639826	639759	19643A	PARTICIPANT	\N	PRESENT	0
639827	639759	14217N	PARTICIPANT	\N	PRESENT	0
639828	639759	18193Q	PARTICIPANT	\N	PRESENT	0
639829	639759	97011G	PARTICIPANT	\N	PRESENT	0
639830	639759	20084G	PARTICIPANT	\N	PRESENT	0
639831	639759	20120S	PARTICIPANT	\N	PRESENT	0
639832	639759	19533U	PARTICIPANT	\N	PRESENT	0
639833	639759	08045X	PARTICIPANT	\N	PRESENT	0
639834	639759	11066Q	PARTICIPANT	\N	PRESENT	0
639835	639759	19527W	PARTICIPANT	\N	PRESENT	0
639836	639759	19621T	PARTICIPANT	\N	PRESENT	0
639837	639759	19503N	PARTICIPANT	\N	PRESENT	0
639838	639759	14053L	PARTICIPANT	\N	PRESENT	0
639839	639759	14121F	PARTICIPANT	\N	PRESENT	0
639840	639759	14069U	PARTICIPANT	\N	PRESENT	0
639841	639759	11054L	PARTICIPANT	\N	PRESENT	0
639842	639759	19798U	PARTICIPANT	\N	PRESENT	0
639843	639759	19631V	PARTICIPANT	\N	PRESENT	0
639844	639759	14195A	PARTICIPANT	\N	PRESENT	0
639845	639759	20050V	PARTICIPANT	\N	PRESENT	0
639846	639759	19651A	PARTICIPANT	\N	PRESENT	0
639847	639759	20126Y	PARTICIPANT	\N	PRESENT	0
639848	639759	04033B	PARTICIPANT	\N	PRESENT	0
639849	639759	14071N	PARTICIPANT	\N	PRESENT	0
639850	639759	18083K	PARTICIPANT	\N	PRESENT	0
639851	639759	20064C	PARTICIPANT	\N	PRESENT	0
639852	639759	04092N	PARTICIPANT	\N	PRESENT	0
639853	639759	19649G	PARTICIPANT	\N	PRESENT	0
639854	639759	11097X	PARTICIPANT	\N	PRESENT	0
639855	639759	14281W	PARTICIPANT	\N	PRESENT	0
639856	639759	19747H	PARTICIPANT	\N	PRESENT	0
639857	639759	08010L	PARTICIPANT	\N	PRESENT	0
639858	639759	20094J	PARTICIPANT	\N	PRESENT	0
639859	639759	04047H	PARTICIPANT	\N	PRESENT	0
639860	639759	14026U	PARTICIPANT	\N	PRESENT	0
639861	639759	20060X	PARTICIPANT	\N	PRESENT	0
639862	639759	19413M	PARTICIPANT	\N	PRESENT	0
639863	639759	19669L	PARTICIPANT	\N	PRESENT	0
639864	639759	20082E	PARTICIPANT	\N	PRESENT	0
639865	639759	14123H	PARTICIPANT	\N	PRESENT	0
639866	639759	20078J	PARTICIPANT	\N	PRESENT	0
639867	639759	11026G	PARTICIPANT	\N	PRESENT	0
639868	639759	20074E	PARTICIPANT	\N	PRESENT	0
639869	639759	04045F	PARTICIPANT	\N	PRESENT	0
639870	639759	20128B	PARTICIPANT	\N	PRESENT	0
639871	639759	14169X	PARTICIPANT	\N	PRESENT	0
639872	639759	11072N	PARTICIPANT	\N	PRESENT	0
639873	639759	04071H	PARTICIPANT	\N	PRESENT	0
639874	639759	08061X	PARTICIPANT	\N	PRESENT	0
639875	639759	01057W	PARTICIPANT	\N	PRESENT	0
639876	639759	11083R	PARTICIPANT	\N	PRESENT	0
637867	634665	14026U	PARTICIPANT	\N	PRESENT	0
637868	634665	14089Y	PARTICIPANT	\N	PRESENT	0
637869	634665	20022R	PARTICIPANT	\N	PRESENT	0
637870	634665	20110Q	PARTICIPANT	\N	PRESENT	0
637871	634665	11056N	PARTICIPANT	\N	PRESENT	0
637872	634665	19749K	PARTICIPANT	\N	PRESENT	0
637873	634665	19629C	PARTICIPANT	\N	PRESENT	0
637874	634665	11033F	PARTICIPANT	\N	PRESENT	0
637875	634665	01028R	PARTICIPANT	\N	PRESENT	0
637876	634665	95063L	PARTICIPANT	\N	PRESENT	0
637877	634665	20122U	PARTICIPANT	\N	PRESENT	0
637878	634665	14053L	PARTICIPANT	\N	PRESENT	0
637879	634665	11115U	PARTICIPANT	\N	PRESENT	0
637880	634665	19667J	PARTICIPANT	\N	PRESENT	0
637881	634665	01048V	PARTICIPANT	\N	PRESENT	0
637882	634665	20248J	PARTICIPANT	\N	PRESENT	0
637883	634665	11085T	PARTICIPANT	\N	PRESENT	0
637884	634665	19543W	PARTICIPANT	\N	PRESENT	0
637885	634665	20152B	PARTICIPANT	\N	PRESENT	0
637886	634665	04047H	PARTICIPANT	\N	PRESENT	0
637887	634665	14215L	PARTICIPANT	\N	PRESENT	0
637888	634665	19711U	PARTICIPANT	\N	PRESENT	0
637889	634665	04043D	PARTICIPANT	\N	PRESENT	0
637890	634665	19651A	PARTICIPANT	\N	PRESENT	0
637891	634665	11012A	PARTICIPANT	\N	PRESENT	0
638736	638445	14327T	PARTICIPANT	\N	PRESENT	0
638737	638445	14331P	PARTICIPANT	\N	PRESENT	0
638738	638445	11048N	PARTICIPANT	\N	PRESENT	0
638739	638445	08009T	PARTICIPANT	\N	PRESENT	0
638740	638445	01057W	PARTICIPANT	\N	PRESENT	0
638741	638445	19741B	PARTICIPANT	\N	PRESENT	0
638742	638445	99004R	PARTICIPANT	\N	PRESENT	0
638743	638445	20044X	PARTICIPANT	\N	PRESENT	0
638744	638445	14225N	PRESIDENT	0	PRESENT	0
638853	637993	19533U	PRESIDENT	0	PRESENT	0
638746	638445	19335Q	PARTICIPANT	\N	PRESENT	0
638747	638445	20086J	PARTICIPANT	\N	PRESENT	0
638748	638445	01048V	PARTICIPANT	\N	PRESENT	0
638749	638445	19667J	PARTICIPANT	\N	PRESENT	0
638750	638445	07029T	PARTICIPANT	\N	PRESENT	0
638751	638445	19349W	PARTICIPANT	\N	PRESENT	0
638752	638445	08010L	PARTICIPANT	\N	PRESENT	0
638753	638445	19762G	PARTICIPANT	\N	PRESENT	0
638754	638445	19479G	PARTICIPANT	\N	PRESENT	1
638755	638445	11012A	PARTICIPANT	\N	EXCUSE	0
638756	638445	14189C	PARTICIPANT	\N	EXCUSE	0
638757	638445	20050V	PARTICIPANT	\N	PRESENT	1
638768	638445	11053K	PARTICIPANT	\N	PRESENT	0
638769	638445	20116W	PARTICIPANT	\N	PRESENT	0
638778	638445	20252E	PARTICIPANT	\N	PRESENT	0
638779	638445	19711U	PARTICIPANT	\N	PRESENT	0
638800	638445	19647E	PARTICIPANT	\N	PRESENT	0
638801	638445	08034U	PARTICIPANT	\N	PRESENT	0
638802	638445	19689Q	PARTICIPANT	\N	PRESENT	0
638854	637993	20124W	PARTICIPANT	\N	PRESENT	0
638855	637993	19599P	PARTICIPANT	\N	PRESENT	0
639913	639481	19820Y	PARTICIPANT	\N	PRESENT	1
639915	639481	14207L	PARTICIPANT	\N	PRESENT	1
639928	639927	20082E	PARTICIPANT	\N	PRESENT	0
639929	639927	20050V	PARTICIPANT	\N	PRESENT	0
639930	639927	19515S	PARTICIPANT	\N	PRESENT	0
639931	639927	20126Y	PARTICIPANT	\N	PRESENT	0
639932	639927	20074E	PARTICIPANT	\N	EXCUSE	0
639933	639927	19369B	PARTICIPANT	\N	EXCUSE	0
639935	639934	20082E	PARTICIPANT	\N	PRESENT	0
639936	639934	20050V	PARTICIPANT	\N	PRESENT	0
639937	639934	19515S	PARTICIPANT	\N	PRESENT	0
639938	639934	19693L	PARTICIPANT	\N	PRESENT	0
639939	639934	20126Y	PARTICIPANT	\N	PRESENT	0
639940	639934	14213J	PARTICIPANT	\N	PRESENT	0
641594	641593	04057K	PARTICIPANT	\N	PRESENT	0
642061	642038	20064C	PARTICIPANT	\N	PRESENT	1
642062	642038	08056B	PARTICIPANT	\N	PRESENT	1
642063	642038	14097Y	PARTICIPANT	\N	PRESENT	1
642266	642011	19629C	PARTICIPANT	\N	EXCUSE	0
642267	641818	19333N	PARTICIPANT	\N	PRESENT	0
642268	641818	18083K	PARTICIPANT	\N	PRESENT	0
642269	641818	05012A	PARTICIPANT	\N	PRESENT	0
642270	641818	20068G	PARTICIPANT	\N	PRESENT	0
642271	641818	14031R	PARTICIPANT	\N	PRESENT	0
642272	641818	19503N	PARTICIPANT	\N	PRESENT	0
642273	641818	14219Q	PRESIDENT	0	PRESENT	0
642274	641818	19820Y	PARTICIPANT	\N	PRESENT	0
642275	641818	17367Q	PARTICIPANT	\N	PRESENT	0
642276	641818	20102Q	PARTICIPANT	\N	PRESENT	0
642277	641818	20024T	PARTICIPANT	\N	PRESENT	0
642278	641818	14169X	PARTICIPANT	\N	PRESENT	0
642279	641818	20136B	PARTICIPANT	\N	PRESENT	0
642280	641818	19387D	PARTICIPANT	\N	PRESENT	0
642281	641818	19619A	PARTICIPANT	\N	PRESENT	0
642282	641818	19599P	PARTICIPANT	\N	PRESENT	0
642283	641818	19685L	PARTICIPANT	\N	PRESENT	0
642284	641818	20076G	PARTICIPANT	\N	PRESENT	0
642285	641818	20100N	PARTICIPANT	\N	PRESENT	0
642286	641818	20032T	PARTICIPANT	\N	PRESENT	0
642287	641818	19549D	PARTICIPANT	\N	PRESENT	0
642288	641818	20140W	PARTICIPANT	\N	PRESENT	0
642289	641818	20038A	PARTICIPANT	\N	PRESENT	0
642290	641818	20096L	PARTICIPANT	\N	PRESENT	0
642291	641818	19637C	PARTICIPANT	\N	PRESENT	0
642292	642011	14053L	PARTICIPANT	\N	PRESENT	0
642293	642011	11010L	PARTICIPANT	\N	PRESENT	0
642294	642011	11026G	PARTICIPANT	\N	PRESENT	0
642295	642011	10015M	PARTICIPANT	\N	PRESENT	0
642296	642011	19543W	PARTICIPANT	\N	PRESENT	0
642297	642011	19581D	PARTICIPANT	\N	PRESENT	0
642298	642011	04047H	PRESIDENT	0	PRESENT	0
642299	642011	19673G	PARTICIPANT	\N	PRESENT	0
642300	642011	19675J	PARTICIPANT	\N	PRESENT	0
642301	642011	14231L	PARTICIPANT	\N	PRESENT	0
642302	642011	05008E	PARTICIPANT	\N	PRESENT	0
642303	642011	19447X	PARTICIPANT	\N	PRESENT	0
642304	642011	11056N	PARTICIPANT	\N	PRESENT	0
642305	642011	19729F	PARTICIPANT	\N	PRESENT	0
642306	642011	14151M	PARTICIPANT	\N	PRESENT	0
642307	642011	14215L	PRESIDENT	1	PRESENT	0
642308	642011	19749K	PARTICIPANT	\N	PRESENT	0
642309	642011	20022R	PARTICIPANT	\N	PRESENT	0
642310	642011	04008A	PARTICIPANT	\N	PRESENT	0
642311	642035	14073Q	PARTICIPANT	\N	EXCUSE	0
642312	642035	19735D	PARTICIPANT	\N	EXCUSE	0
642313	642035	11043H	PARTICIPANT	\N	EXCUSE	0
642314	642035	19399H	PARTICIPANT	\N	EXCUSE	0
642315	642035	17589D	PARTICIPANT	\N	EXCUSE	0
642316	642035	19621T	PARTICIPANT	\N	PRESENT	1
642317	642035	20048C	PARTICIPANT	\N	EXCUSE	0
642318	642035	19593H	PARTICIPANT	\N	PRESENT	0
642319	642035	19758L	PARTICIPANT	\N	PRESENT	0
642320	642035	20056C	PARTICIPANT	\N	PRESENT	0
642321	642035	19643A	PARTICIPANT	\N	PRESENT	0
642322	642035	19611R	PARTICIPANT	\N	PRESENT	0
642324	642035	19693L	PARTICIPANT	\N	PRESENT	0
642325	642035	20124W	PARTICIPANT	\N	PRESENT	0
642326	642035	20052X	PARTICIPANT	\N	PRESENT	0
642327	642035	20026V	PARTICIPANT	\N	PRESENT	0
642328	642035	19533U	PARTICIPANT	\N	PRESENT	0
642329	642035	20138D	PARTICIPANT	\N	PRESENT	0
642330	642035	19573D	PARTICIPANT	\N	PRESENT	0
642331	642035	20112S	PARTICIPANT	\N	PRESENT	0
642332	642035	20142Y	PARTICIPANT	\N	PRESENT	0
642333	642035	20172F	PARTICIPANT	\N	PRESENT	0
642334	642035	14229S	PARTICIPANT	\N	PRESENT	0
642335	642035	20058E	PARTICIPANT	\N	PRESENT	0
642336	642177	14133K	PARTICIPANT	\N	PRESENT	0
642337	642177	14105F	PARTICIPANT	\N	PRESENT	0
642338	642177	04042C	PRESIDENT	0	PRESENT	0
642339	642177	12028B	PARTICIPANT	\N	PRESENT	0
642340	642177	11027H	PARTICIPANT	\N	PRESENT	1
642341	642177	01024M	PARTICIPANT	\N	PRESENT	1
642342	642177	07033P	PARTICIPANT	\N	PRESENT	0
642343	642177	97011G	PARTICIPANT	\N	PRESENT	0
642344	642177	11083R	PARTICIPANT	\N	PRESENT	0
642345	642177	19347U	PARTICIPANT	\N	PRESENT	0
642346	642177	08056B	PARTICIPANT	\N	EXCUSE	0
642347	642177	19565D	PARTICIPANT	\N	PRESENT	1
642348	642177	11064N	PARTICIPANT	\N	PRESENT	1
642349	642035	20180F	PARTICIPANT	\N	PRESENT	0
642350	642177	08069G	PARTICIPANT	\N	PRESENT	0
642351	642177	95041E	PARTICIPANT	\N	PRESENT	0
642352	642177	16685X	PARTICIPANT	\N	PRESENT	0
648575	647669	19687N	PARTICIPANT	\N	PRESENT	0
648576	647669	20050V	PARTICIPANT	\N	PRESENT	0
648577	647669	08011M	PARTICIPANT	\N	PRESENT	0
648578	647669	11040E	PARTICIPANT	\N	PRESENT	0
648579	647669	14083S	PARTICIPANT	\N	PRESENT	0
648580	647669	20252E	PARTICIPANT	\N	PRESENT	0
648581	647669	20070A	PARTICIPANT	\N	PRESENT	0
648582	647669	19741B	PARTICIPANT	\N	PRESENT	0
648583	647669	99004R	PARTICIPANT	\N	PRESENT	0
648584	647669	20914V	PARTICIPANT	\N	PRESENT	0
648585	647669	19762G	PARTICIPANT	\N	PRESENT	0
652110	652088	20060X	PARTICIPANT	\N	PRESENT	0
652111	652088	19507S	PARTICIPANT	\N	PRESENT	0
652112	652088	14207L	PARTICIPANT	\N	PRESENT	0
652113	652088	19747H	PARTICIPANT	\N	PRESENT	0
652114	652088	14257W	PARTICIPANT	\N	PRESENT	0
652115	652088	20086J	PARTICIPANT	\N	PRESENT	0
652116	652088	20032T	PARTICIPANT	\N	PRESENT	0
652117	652088	11048N	PARTICIPANT	\N	PRESENT	0
652118	652088	14031R	PARTICIPANT	\N	PRESENT	0
652119	652088	20180F	PARTICIPANT	\N	PRESENT	0
652120	652088	20094J	PARTICIPANT	\N	PRESENT	0
652121	650958	19715Y	PARTICIPANT	\N	PRESENT	1
652122	652088	11099A	PARTICIPANT	\N	PRESENT	0
652123	652088	14357A	PARTICIPANT	\N	PRESENT	0
652146	650958	19760E	PARTICIPANT	\N	PRESENT	0
652147	650958	19663E	PARTICIPANT	\N	PRESENT	0
652159	652088	19707Y	PARTICIPANT	\N	PRESENT	1
652160	652088	08015R	PARTICIPANT	\N	PRESENT	1
652161	652088	20062A	PARTICIPANT	\N	PRESENT	0
652162	652088	14251Q	PARTICIPANT	\N	PRESENT	1
652164	650958	14026U	PARTICIPANT	\N	PRESENT	0
652217	652216	11048N	PARTICIPANT	\N	PRESENT	0
652218	652216	19711U	PARTICIPANT	\N	PRESENT	0
652284	651588	20032T	PARTICIPANT	\N	PRESENT	0
652285	651588	19667J	PARTICIPANT	\N	PRESENT	0
652286	651588	11010L	PARTICIPANT	\N	PRESENT	0
652287	651588	20038A	PARTICIPANT	\N	PRESENT	0
652288	651588	05008E	PARTICIPANT	\N	PRESENT	0
652289	651588	20180F	PARTICIPANT	\N	PRESENT	0
652290	651588	19573D	PARTICIPANT	\N	PRESENT	0
652291	651588	19954N	PARTICIPANT	\N	PRESENT	0
652292	651588	20140W	PARTICIPANT	\N	PRESENT	0
652293	651588	20138D	PARTICIPANT	\N	PRESENT	0
652294	651588	97011G	PARTICIPANT	\N	PRESENT	0
652295	651588	20120S	PARTICIPANT	\N	PRESENT	0
652296	651588	20252E	PARTICIPANT	\N	PRESENT	0
652297	651588	20152B	PARTICIPANT	\N	PRESENT	0
652298	651588	19762G	PARTICIPANT	\N	PRESENT	0
652299	651588	19383Y	PARTICIPANT	\N	PRESENT	0
652300	651588	14357A	PARTICIPANT	\N	PRESENT	0
652301	651588	14213J	PARTICIPANT	\N	PRESENT	0
652302	651588	20024T	PARTICIPANT	\N	PRESENT	0
652303	651588	20108W	PARTICIPANT	\N	PRESENT	0
652304	651588	20104S	PARTICIPANT	\N	PRESENT	0
652305	651588	19741B	PARTICIPANT	\N	PRESENT	0
652306	651588	14033T	PARTICIPANT	\N	PRESENT	0
652307	651588	19467C	PARTICIPANT	\N	PRESENT	0
652308	651588	20034V	PARTICIPANT	\N	PRESENT	0
652309	651588	20046A	PARTICIPANT	\N	PRESENT	0
652310	651588	19695N	PARTICIPANT	\N	PRESENT	0
652311	651588	14038Y	PARTICIPANT	\N	PRESENT	0
652312	651588	04035D	PARTICIPANT	\N	PRESENT	0
652422	651588	20060X	PARTICIPANT	\N	PRESENT	0
652314	651588	20058E	PARTICIPANT	\N	PRESENT	0
652315	651588	20086J	PARTICIPANT	\N	PRESENT	0
652316	651588	11056N	PARTICIPANT	\N	PRESENT	0
652317	651588	20044X	PARTICIPANT	\N	PRESENT	0
652318	651588	19758L	PARTICIPANT	\N	PRESENT	0
652319	651588	07029T	PARTICIPANT	\N	PRESENT	0
652320	651588	19729F	PARTICIPANT	\N	PRESENT	0
652321	651588	11040E	PARTICIPANT	\N	PRESENT	0
652322	651588	19768N	PARTICIPANT	\N	PRESENT	0
652323	651588	11031D	PARTICIPANT	\N	PRESENT	0
652324	651588	12041X	PARTICIPANT	\N	PRESENT	0
652325	651588	19593H	PARTICIPANT	\N	PRESENT	0
652326	651588	19707Y	PARTICIPANT	\N	PRESENT	0
652327	651588	19760E	PARTICIPANT	\N	PRESENT	0
652328	651588	04085P	PARTICIPANT	\N	PRESENT	0
652329	651588	20110Q	PARTICIPANT	\N	PRESENT	0
652330	651588	20124W	PARTICIPANT	\N	PRESENT	0
652331	651588	20126Y	PARTICIPANT	\N	PRESENT	0
652332	651588	20054A	PARTICIPANT	\N	PRESENT	0
652333	651588	20914V	PARTICIPANT	\N	PRESENT	0
652334	651588	11065P	PARTICIPANT	\N	PRESENT	0
652341	651588	20092G	PARTICIPANT	\N	PRESENT	0
652336	651588	11099A	PARTICIPANT	\N	PRESENT	0
652337	651588	20134Y	PARTICIPANT	\N	PRESENT	0
652339	651588	20100N	PARTICIPANT	\N	PRESENT	0
652340	651588	19347U	PARTICIPANT	\N	PRESENT	0
652342	651588	14249W	PARTICIPANT	\N	PRESENT	0
652343	651588	11083R	PARTICIPANT	\N	PRESENT	0
652344	651588	20106U	PARTICIPANT	\N	PRESENT	0
652345	651588	19591F	PARTICIPANT	\N	PRESENT	0
652346	651588	19826F	PARTICIPANT	\N	PRESENT	0
652347	651588	20146D	PARTICIPANT	\N	PRESENT	0
652348	651588	20128B	PARTICIPANT	\N	PRESENT	0
652349	651588	14255U	PARTICIPANT	\N	PRESENT	0
652350	651588	14037X	PARTICIPANT	\N	PRESENT	0
652351	651588	11053K	PARTICIPANT	\N	PRESENT	0
652352	651588	19637C	PARTICIPANT	\N	PRESENT	0
652353	651588	11072N	PARTICIPANT	\N	PRESENT	0
652354	651588	08061X	PARTICIPANT	\N	PRESENT	0
652355	651588	19349W	PARTICIPANT	\N	PRESENT	0
652356	651588	20066E	PARTICIPANT	\N	PRESENT	0
652357	651588	19735D	PARTICIPANT	\N	PRESENT	0
652358	651588	14042U	PARTICIPANT	\N	PRESENT	0
652359	651588	19301E	PARTICIPANT	\N	PRESENT	0
652360	651588	14207L	PARTICIPANT	\N	PRESENT	0
652361	651588	19697Q	PARTICIPANT	\N	PRESENT	0
652362	651588	19387D	PARTICIPANT	\N	PRESENT	0
652363	651588	19553Y	PARTICIPANT	\N	PRESENT	0
652364	651588	19629C	PARTICIPANT	\N	PRESENT	0
652365	651588	11012A	PARTICIPANT	\N	PRESENT	0
652366	651588	20132W	PARTICIPANT	\N	PRESENT	0
652367	651588	14111D	PARTICIPANT	\N	PRESENT	0
652368	651588	14211G	PARTICIPANT	\N	PRESENT	0
652369	651588	20050V	PARTICIPANT	\N	PRESENT	0
652370	651588	14251Q	PARTICIPANT	\N	PRESENT	0
652371	651588	19563B	PARTICIPANT	\N	PRESENT	0
652372	651588	11064N	PARTICIPANT	\N	PRESENT	0
652373	651588	04057K	PARTICIPANT	\N	PRESENT	0
652374	651588	19583F	PARTICIPANT	\N	PRESENT	0
652376	651588	19631V	PARTICIPANT	\N	PRESENT	0
652377	651588	04059M	PARTICIPANT	\N	PRESENT	0
652378	651588	19549D	PARTICIPANT	\N	PRESENT	0
652379	651588	01028R	PARTICIPANT	\N	PRESENT	0
652380	651588	14225N	PARTICIPANT	\N	PRESENT	0
652381	651588	19503N	PARTICIPANT	\N	PRESENT	0
652382	651588	19715Y	PARTICIPANT	\N	PRESENT	0
652383	651588	14257W	PARTICIPANT	\N	PRESENT	0
652385	651588	11045K	PARTICIPANT	\N	PRESENT	0
652386	651588	14021P	PARTICIPANT	\N	PRESENT	0
652387	651588	14229S	PARTICIPANT	\N	PRESENT	0
652388	651588	19683J	PARTICIPANT	\N	PRESENT	0
652390	651588	19649G	PARTICIPANT	\N	PRESENT	0
652391	651588	19333N	PARTICIPANT	\N	PRESENT	0
652392	651588	19687N	PARTICIPANT	\N	PRESENT	0
652393	651588	95063L	PARTICIPANT	\N	PRESENT	0
652395	651588	11074Q	PARTICIPANT	\N	PRESENT	0
652397	651588	19489J	PARTICIPANT	\N	PRESENT	0
652399	651588	14151M	PARTICIPANT	\N	PRESENT	0
652400	651588	19647E	PARTICIPANT	\N	PRESENT	0
652402	651588	14219Q	PARTICIPANT	\N	PRESENT	0
652403	651588	14109K	PARTICIPANT	\N	PRESENT	0
652406	651588	20028X	PARTICIPANT	\N	PRESENT	0
652407	651588	14275Y	PARTICIPANT	\N	PRESENT	0
652408	651588	19599P	PARTICIPANT	\N	PRESENT	0
652410	651588	11067R	PARTICIPANT	\N	PRESENT	0
652411	651588	19820Y	PARTICIPANT	\N	PRESENT	0
652412	651588	20070A	PARTICIPANT	\N	PRESENT	0
652413	651588	19749K	PARTICIPANT	\N	PRESENT	0
652414	651588	11027H	PARTICIPANT	\N	PRESENT	0
652415	651588	19577H	PARTICIPANT	\N	PRESENT	0
652416	651588	11066Q	PARTICIPANT	\N	PRESENT	0
652417	651588	14189C	PARTICIPANT	\N	PRESENT	0
652418	651588	20080C	PARTICIPANT	\N	PRESENT	0
652419	651588	20052X	PARTICIPANT	\N	PRESENT	0
652420	651588	17023S	PARTICIPANT	\N	PRESENT	0
652421	651588	20040T	PARTICIPANT	\N	PRESENT	0
627617	626799	19697Q	PARTICIPANT	\N	PRESENT	1
627618	626799	11067R	PARTICIPANT	\N	PRESENT	0
627619	626799	20090E	PARTICIPANT	\N	PRESENT	0
627620	626799	14355X	PARTICIPANT	\N	PRESENT	1
627621	626799	19798U	PARTICIPANT	\N	PRESENT	0
627622	626799	19569H	PARTICIPANT	\N	PRESENT	0
627623	626799	11097X	PARTICIPANT	\N	PRESENT	0
627624	626799	19415P	PARTICIPANT	\N	PRESENT	0
627625	626799	14223L	PARTICIPANT	\N	PRESENT	1
627626	626799	14026U	PARTICIPANT	\N	PRESENT	0
627627	626799	11031D	PARTICIPANT	\N	PRESENT	1
627628	626799	19703U	PARTICIPANT	\N	PRESENT	0
627629	626799	19553Y	PARTICIPANT	\N	PRESENT	1
627630	626799	19679N	PARTICIPANT	\N	PRESENT	0
627631	626799	14195A	PARTICIPANT	\N	PRESENT	0
627632	626799	14213J	PARTICIPANT	\N	PRESENT	1
627633	626799	14217N	PARTICIPANT	\N	PRESENT	0
627634	626799	10006L	PRESIDENT	0	PRESENT	0
627635	626799	19683J	PARTICIPANT	\N	PRESENT	1
627636	626799	01034P	PARTICIPANT	\N	PRESENT	1
627637	626799	04057K	PARTICIPANT	\N	PRESENT	0
627638	626799	04092N	PARTICIPANT	\N	PRESENT	0
627639	626799	11045K	PARTICIPANT	\N	PRESENT	1
627640	626799	20040T	PARTICIPANT	\N	PRESENT	0
627641	626799	19301E	PARTICIPANT	\N	PRESENT	1
627642	626799	17965H	PARTICIPANT	\N	PRESENT	0
627643	626799	19691J	PARTICIPANT	\N	PRESENT	0
627644	626799	20148F	PARTICIPANT	\N	PRESENT	1
627645	626799	19723Y	PARTICIPANT	\N	PRESENT	0
627646	626799	20248J	PARTICIPANT	\N	PRESENT	1
627647	626799	20066E	PARTICIPANT	\N	PRESENT	1
627648	626799	11103C	PARTICIPANT	\N	PRESENT	1
627649	626799	14071N	PARTICIPANT	\N	PRESENT	0
627650	626799	19657G	PARTICIPANT	\N	PRESENT	1
627651	626694	14275Y	PARTICIPANT	\N	PRESENT	0
627652	626694	04047H	PRESIDENT	0	PRESENT	0
627653	626694	14231L	PARTICIPANT	\N	PRESENT	0
627657	626694	14053L	PARTICIPANT	\N	PRESENT	0
627658	626694	14111D	PARTICIPANT	\N	PRESENT	0
627659	626694	20074E	PARTICIPANT	\N	PRESENT	0
627660	626694	19673G	PARTICIPANT	\N	PRESENT	0
627661	626694	01028R	PARTICIPANT	\N	PRESENT	0
627662	626694	19447X	PARTICIPANT	\N	PRESENT	0
627663	626694	14089Y	PARTICIPANT	\N	PRESENT	0
627664	626694	19954N	PARTICIPANT	\N	PRESENT	0
627665	626694	11056N	PARTICIPANT	\N	PRESENT	0
627666	626694	19729F	PARTICIPANT	\N	PRESENT	0
627667	626694	20110Q	PARTICIPANT	\N	PRESENT	0
627668	626694	14147R	PARTICIPANT	\N	PRESENT	0
627669	626694	14069U	PARTICIPANT	\N	PRESENT	0
627670	626694	14215L	PARTICIPANT	\N	PRESENT	0
627671	626694	14259Y	PARTICIPANT	\N	PRESENT	0
627672	626694	19749K	PARTICIPANT	\N	PRESENT	0
627673	626694	20022R	PARTICIPANT	\N	PRESENT	0
627674	626694	11072N	PARTICIPANT	\N	PRESENT	0
627675	624282	19739H	PARTICIPANT	\N	PRESENT	0
627676	624282	20136B	PARTICIPANT	\N	PRESENT	1
627681	626694	05008E	PARTICIPANT	\N	PRESENT	0
627682	626694	14179A	PARTICIPANT	\N	PRESENT	0
627683	626694	19581D	PARTICIPANT	\N	EXCUSE	0
627684	626694	08018U	PARTICIPANT	\N	EXCUSE	0
627685	626694	14021P	PARTICIPANT	\N	EXCUSE	0
627686	626794	19443T	PARTICIPANT	\N	PRESENT	0
627687	626794	12041X	PARTICIPANT	\N	PRESENT	1
627688	626794	19329S	PARTICIPANT	\N	PRESENT	0
627689	626794	01058X	PARTICIPANT	\N	PRESENT	0
627690	626794	11027H	PARTICIPANT	\N	PRESENT	0
627691	626794	16685X	PARTICIPANT	\N	PRESENT	0
627692	626794	04042C	PRESIDENT	0	PRESENT	0
627693	626794	11054L	PARTICIPANT	\N	PRESENT	0
627694	626794	11066Q	PARTICIPANT	\N	PRESENT	0
627695	626794	12028B	PARTICIPANT	\N	PRESENT	0
627696	626794	19421M	PARTICIPANT	\N	PRESENT	0
627697	626794	19709B	PARTICIPANT	\N	PRESENT	0
627698	626794	14193X	PARTICIPANT	\N	PRESENT	0
627699	626794	97011G	PARTICIPANT	\N	PRESENT	0
627700	626794	08061X	PARTICIPANT	\N	PRESENT	0
627701	626794	08047A	PARTICIPANT	\N	PRESENT	0
627702	626794	14059S	PARTICIPANT	\N	PRESENT	0
627703	626794	14097Y	PARTICIPANT	\N	PRESENT	0
627704	626794	04035D	PARTICIPANT	\N	PRESENT	0
627705	626794	14133K	PARTICIPANT	\N	PRESENT	0
627706	626794	01062T	PARTICIPANT	\N	PRESENT	0
627707	626794	11041F	PARTICIPANT	\N	PRESENT	1
627708	626794	20042V	PARTICIPANT	\N	PRESENT	0
627709	626794	01024M	PARTICIPANT	\N	PRESENT	0
627710	626794	14105F	PARTICIPANT	\N	PRESENT	0
627711	626794	20064C	PARTICIPANT	\N	PRESENT	0
627712	626794	14267Y	PARTICIPANT	\N	PRESENT	0
627713	626794	11064N	PARTICIPANT	\N	PRESENT	0
627714	626794	11083R	PARTICIPANT	\N	PRESENT	1
627715	626794	14211G	PARTICIPANT	\N	PRESENT	0
627716	626794	19565D	PARTICIPANT	\N	EXCUSE	0
627726	626897	19383Y	PARTICIPANT	\N	PRESENT	0
627727	626897	19768N	PARTICIPANT	\N	PRESENT	1
627728	626897	20088L	PARTICIPANT	\N	PRESENT	1
627729	626897	19515S	PARTICIPANT	\N	PRESENT	0
627730	626897	19782L	PARTICIPANT	\N	PRESENT	1
627731	626897	20092G	PARTICIPANT	\N	PRESENT	0
627732	626897	19441R	PARTICIPANT	\N	PRESENT	0
627733	626897	20078J	PARTICIPANT	\N	PRESENT	1
627734	626897	19413M	PARTICIPANT	\N	PRESENT	0
627735	626897	20082E	PARTICIPANT	\N	PRESENT	1
627736	626897	20094J	PARTICIPANT	\N	PRESENT	0
627737	626897	19866P	PARTICIPANT	\N	PRESENT	0
627738	626897	04045F	PARTICIPANT	\N	PRESENT	0
627739	626897	19631V	PARTICIPANT	\N	PRESENT	0
627740	626897	20104S	PARTICIPANT	\N	PRESENT	0
627741	626897	19705W	PARTICIPANT	\N	PRESENT	1
627742	626897	19707Y	PARTICIPANT	\N	PRESENT	1
627743	626897	08015R	PARTICIPANT	\N	PRESENT	0
627744	626897	19575F	PARTICIPANT	\N	PRESENT	0
627745	626897	19369B	PARTICIPANT	\N	PRESENT	0
627746	626897	20018V	PARTICIPANT	\N	PRESENT	1
627747	626897	19511N	PARTICIPANT	\N	PRESENT	0
627748	626897	19563B	PARTICIPANT	\N	PRESENT	0
627749	626897	08028W	PARTICIPANT	\N	PRESENT	0
627750	626897	20028X	PARTICIPANT	\N	PRESENT	0
627751	626897	14038Y	PARTICIPANT	\N	PRESENT	0
627752	626897	20030R	PARTICIPANT	\N	PRESENT	1
627753	626897	19467C	PARTICIPANT	\N	PRESENT	0
627754	626897	20034V	PARTICIPANT	\N	PRESENT	1
627755	626897	20144B	PARTICIPANT	\N	PRESENT	0
627756	626897	19695N	PARTICIPANT	\N	PRESENT	1
627757	626897	11090Q	PRESIDENT	0	PRESENT	0
627758	626897	14033T	PARTICIPANT	\N	PRESENT	0
627759	626897	01025N	PARTICIPANT	\N	PRESENT	0
627760	626897	20054A	PARTICIPANT	\N	PRESENT	0
627761	626897	20174H	PARTICIPANT	\N	PRESENT	1
627762	626897	14205J	PARTICIPANT	\N	PRESENT	1
627763	626897	14251Q	PARTICIPANT	\N	PRESENT	1
627764	626897	19507S	PARTICIPANT	\N	PRESENT	0
627765	626897	19747H	PARTICIPANT	\N	PRESENT	0
627766	626897	14207L	PARTICIPANT	\N	PRESENT	1
627768	626794	19347U	PARTICIPANT	\N	PRESENT	0
627769	626794	17023S	PARTICIPANT	\N	PRESENT	1
627770	624282	17637T	PARTICIPANT	\N	PRESENT	0
628839	616236	14030Q	PARTICIPANT	\N	PRESENT	0
628840	616236	14189C	PARTICIPANT	\N	EXCUSE	0
628841	616236	07029T	PARTICIPANT	\N	EXCUSE	0
628842	616236	19866P	PARTICIPANT	\N	EXCUSE	0
628843	616236	20138D	PARTICIPANT	\N	PRESENT	0
628844	616236	11031D	PARTICIPANT	\N	PRESENT	0
628845	616236	19599P	PARTICIPANT	\N	PRESENT	0
628846	616236	20080C	PARTICIPANT	\N	PRESENT	0
628848	616236	20024T	PARTICIPANT	\N	PRESENT	0
628849	616236	14179A	PARTICIPANT	\N	PRESENT	0
628850	616236	14109K	PARTICIPANT	\N	PRESENT	0
628851	616236	19798U	PARTICIPANT	\N	PRESENT	0
628852	616236	11045K	PARTICIPANT	\N	PRESENT	0
628853	616236	19527W	PARTICIPANT	\N	PRESENT	0
628854	616236	20046A	PARTICIPANT	\N	PRESENT	0
628855	616236	19749K	PARTICIPANT	\N	PRESENT	0
628891	628890	14147R	PARTICIPANT	\N	PRESENT	0
628892	628890	19749K	PARTICIPANT	\N	PRESENT	0
628894	628893	14147R	PARTICIPANT	\N	PRESENT	0
628900	628898	19749K	PARTICIPANT	\N	PRESENT	0
628896	628893	20114U	PARTICIPANT	\N	PRESENT	0
628899	628898	14147R	PARTICIPANT	\N	PRESENT	0
628901	628898	20114U	PARTICIPANT	\N	PRESENT	0
639877	639759	19745F	PARTICIPANT	\N	PRESENT	0
639878	639759	04057K	PARTICIPANT	\N	PRESENT	0
639879	639759	14073Q	PARTICIPANT	\N	PRESENT	0
639880	639759	19721W	PARTICIPANT	\N	PRESENT	0
639881	639759	19543W	PARTICIPANT	\N	PRESENT	0
639882	639759	17023S	PARTICIPANT	\N	PRESENT	0
639883	639759	20298U	PARTICIPANT	\N	PRESENT	0
639958	639957	19593H	PARTICIPANT	\N	PRESENT	0
639885	639759	19713W	PARTICIPANT	\N	PRESENT	0
639886	639759	14255U	PARTICIPANT	\N	PRESENT	0
639887	639759	20042V	PARTICIPANT	\N	PRESENT	0
639956	639955	11031D	PARTICIPANT	\N	PRESENT	0
639960	639959	19693L	PARTICIPANT	\N	PRESENT	0
639961	639959	20050V	PARTICIPANT	\N	PRESENT	0
639962	639959	20082E	PARTICIPANT	\N	PRESENT	0
639963	639959	19369B	PARTICIPANT	\N	EXCUSE	0
639964	639959	20074E	PARTICIPANT	\N	EXCUSE	0
640006	640005	01058X	PARTICIPANT	\N	PRESENT	0
640187	640186	14026U	PARTICIPANT	\N	PRESENT	0
640188	640186	19725B	PARTICIPANT	\N	PRESENT	0
640226	640107	20056C	PARTICIPANT	\N	PRESENT	0
640227	640107	19593H	PARTICIPANT	\N	PRESENT	0
640228	640107	20026V	PARTICIPANT	\N	PRESENT	0
640229	639623	20124W	PARTICIPANT	\N	PRESENT	0
640241	639995	01062T	PARTICIPANT	\N	EXCUSE	0
640285	640126	18083K	PRESIDENT	0	PRESENT	0
640286	640126	14031R	PARTICIPANT	\N	PRESENT	0
640287	640126	20266L	PARTICIPANT	\N	PRESENT	0
640315	640126	19575F	PARTICIPANT	\N	PRESENT	0
640316	640126	17965H	PARTICIPANT	\N	PRESENT	1
640319	640126	19760E	PARTICIPANT	\N	PRESENT	0
640417	640058	14237S	PARTICIPANT	\N	PRESENT	0
640447	640059	19383Y	PARTICIPANT	\N	PRESENT	0
640448	640059	19768N	PARTICIPANT	\N	PRESENT	0
640449	640059	19515S	PARTICIPANT	\N	PRESENT	0
640450	640059	14357A	PARTICIPANT	\N	PRESENT	0
640451	640059	20144B	PARTICIPANT	\N	PRESENT	0
640452	640059	20082E	PARTICIPANT	\N	PRESENT	0
640453	640059	11090Q	PRESIDENT	0	PRESENT	0
640454	640059	20094J	PARTICIPANT	\N	PRESENT	0
640455	640059	19631V	PARTICIPANT	\N	PRESENT	0
640456	640059	14205J	PARTICIPANT	\N	PRESENT	0
640457	640059	19507S	PARTICIPANT	\N	PRESENT	0
640458	640059	19575F	PARTICIPANT	\N	PRESENT	0
640459	640059	19747H	PARTICIPANT	\N	PRESENT	0
640460	640059	08028W	PARTICIPANT	\N	PRESENT	0
640461	640059	20078J	PARTICIPANT	\N	PRESENT	1
640462	640059	19413M	PARTICIPANT	\N	PRESENT	1
640463	640059	14251Q	PARTICIPANT	\N	PRESENT	1
640464	640059	19707Y	PARTICIPANT	\N	PRESENT	1
640465	640059	08015R	PARTICIPANT	\N	PRESENT	1
640466	640059	20286Q	PARTICIPANT	\N	PRESENT	1
640467	640059	14257W	PARTICIPANT	\N	PRESENT	1
640473	639705	11109J	PARTICIPANT	\N	EXCUSE	0
640474	639705	04059M	PARTICIPANT	\N	PRESENT	0
640475	639705	14030Q	PARTICIPANT	\N	EXCUSE	0
640476	639705	19643A	PARTICIPANT	\N	PRESENT	0
640477	639705	19621T	PARTICIPANT	\N	PRESENT	0
640478	639705	20056C	PARTICIPANT	\N	PRESENT	0
640479	639705	19611R	PRESIDENT	0	PRESENT	0
640480	639705	19699S	PARTICIPANT	\N	PRESENT	0
640481	639705	11104D	PARTICIPANT	\N	PRESENT	1
640482	639705	20142Y	PARTICIPANT	\N	PRESENT	0
640483	639705	14109K	PARTICIPANT	\N	PRESENT	0
640484	639705	04070G	PARTICIPANT	\N	PRESENT	1
640485	639705	19593H	PARTICIPANT	\N	PRESENT	0
640486	639705	19573D	PARTICIPANT	\N	PRESENT	0
640487	639705	14229S	PARTICIPANT	\N	PRESENT	0
640488	639705	20026V	PARTICIPANT	\N	PRESENT	0
640489	639705	20058E	PARTICIPANT	\N	PRESENT	1
640490	639705	19735D	PARTICIPANT	\N	PRESENT	0
640491	639705	19758L	PARTICIPANT	\N	PRESENT	1
640493	639705	20048C	PARTICIPANT	\N	PRESENT	1
640494	639705	19693L	PARTICIPANT	\N	PRESENT	0
640495	639705	20124W	PARTICIPANT	\N	PRESENT	0
640496	639705	20132W	PARTICIPANT	\N	PRESENT	0
640501	640059	14187A	PARTICIPANT	\N	PRESENT	0
640502	640059	14033T	PARTICIPANT	\N	PRESENT	1
640503	640059	19705W	PARTICIPANT	\N	PRESENT	1
640504	640059	19782L	PARTICIPANT	\N	PRESENT	1
640505	639968	19563B	PARTICIPANT	\N	PRESENT	1
640506	639968	14357A	PARTICIPANT	\N	PRESENT	0
640519	639970	14207L	PARTICIPANT	\N	PRESENT	0
640542	639968	19768N	PARTICIPANT	\N	PRESENT	1
640544	639968	19467C	PARTICIPANT	\N	PRESENT	1
640556	639479	14281W	PARTICIPANT	\N	PRESENT	0
640557	639479	19697Q	PARTICIPANT	\N	PRESENT	0
640558	639480	14281W	PARTICIPANT	\N	PRESENT	0
640559	639480	19697Q	PARTICIPANT	\N	PRESENT	0
640612	639944	20116W	PARTICIPANT	\N	PRESENT	1
640613	639944	11040E	PARTICIPANT	\N	PRESENT	1
640614	639944	20070A	PARTICIPANT	\N	PRESENT	1
640615	639944	01057W	PARTICIPANT	\N	PRESENT	1
640616	639944	20126Y	PARTICIPANT	\N	PRESENT	1
640617	639944	19335Q	PARTICIPANT	\N	PRESENT	1
640618	639944	20050V	PARTICIPANT	\N	EXCUSE	0
640619	639944	14225N	PARTICIPANT	\N	EXCUSE	0
640620	639944	19741B	PARTICIPANT	\N	PRESENT	0
640623	639944	08010L	PARTICIPANT	\N	PRESENT	0
640624	639944	11048N	PARTICIPANT	\N	PRESENT	0
640664	640663	19954N	PARTICIPANT	\N	PRESENT	0
640665	640663	11056N	PARTICIPANT	\N	PRESENT	0
640666	640663	95063L	PARTICIPANT	\N	PRESENT	0
640667	640663	19703U	PARTICIPANT	\N	PRESENT	0
640669	640668	19954N	PARTICIPANT	\N	PRESENT	0
640670	640668	11056N	PARTICIPANT	\N	PRESENT	0
640671	640668	95063L	PARTICIPANT	\N	PRESENT	0
640672	640668	19703U	PARTICIPANT	\N	PRESENT	0
640680	640679	11074Q	PARTICIPANT	\N	PRESENT	0
640681	640679	08056B	PARTICIPANT	\N	PRESENT	0
640682	640679	19745F	PARTICIPANT	\N	PRESENT	0
640796	640795	19723Y	PARTICIPANT	\N	PRESENT	0
640797	640795	19735D	PARTICIPANT	\N	PRESENT	0
640826	640825	11027H	PARTICIPANT	\N	PRESENT	0
640827	640825	11083R	PARTICIPANT	\N	PRESENT	0
640828	640825	11066Q	PARTICIPANT	\N	PRESENT	0
640833	640832	04042C	PARTICIPANT	\N	PRESENT	0
640836	640835	19575F	PARTICIPANT	\N	PRESENT	0
640837	640835	19782L	PARTICIPANT	\N	PRESENT	1
640838	640835	19629C	PARTICIPANT	\N	PRESENT	0
640839	640835	14038Y	PARTICIPANT	\N	PRESENT	0
640840	640835	19725B	PARTICIPANT	\N	PRESENT	0
640841	640835	14179A	PARTICIPANT	\N	PRESENT	1
640842	640835	14205J	PARTICIPANT	\N	PRESENT	0
640843	640835	14147R	PARTICIPANT	\N	PRESENT	0
640845	640844	19575F	PARTICIPANT	\N	PRESENT	0
640846	640844	19782L	PARTICIPANT	\N	PRESENT	1
640847	640844	19629C	PARTICIPANT	\N	PRESENT	0
640848	640844	14038Y	PARTICIPANT	\N	PRESENT	0
640849	640844	19725B	PARTICIPANT	\N	PRESENT	0
640850	640844	14179A	PARTICIPANT	\N	PRESENT	1
640851	640844	14205J	PARTICIPANT	\N	PRESENT	0
640852	640844	14147R	PARTICIPANT	\N	PRESENT	0
640853	640802	14213J	PARTICIPANT	\N	PRESENT	0
640854	640802	19679N	PARTICIPANT	\N	PRESENT	0
640855	640802	19697Q	PARTICIPANT	\N	PRESENT	0
640856	640802	14281W	PARTICIPANT	\N	PRESENT	0
640859	640858	19629C	PARTICIPANT	\N	PRESENT	0
640860	640858	14038Y	PARTICIPANT	\N	PRESENT	0
640861	640858	14147R	PARTICIPANT	\N	PRESENT	1
640862	640858	20028X	PARTICIPANT	\N	PRESENT	1
640863	640858	20092G	PARTICIPANT	\N	PRESENT	0
640865	640864	20150Y	PARTICIPANT	\N	PRESENT	1
640866	640864	19447X	PARTICIPANT	\N	EXCUSE	0
640867	640864	20034V	PARTICIPANT	\N	PRESENT	1
640868	640864	14083S	PRESIDENT	0	PRESENT	0
640869	640864	19717B	PARTICIPANT	\N	EXCUSE	0
640870	640864	19333N	PARTICIPANT	\N	PRESENT	0
640871	640864	11064N	PARTICIPANT	\N	PRESENT	1
640872	640864	20100N	PARTICIPANT	\N	PRESENT	1
640886	640885	19735D	PARTICIPANT	\N	PRESENT	0
640887	640885	19723Y	PARTICIPANT	\N	PRESENT	0
640890	640889	19735D	PARTICIPANT	\N	PRESENT	0
640891	640889	19723Y	PARTICIPANT	\N	PRESENT	0
640894	640893	19735D	PARTICIPANT	\N	PRESENT	0
640895	640893	19723Y	PARTICIPANT	\N	PRESENT	0
631551	631546	14189C	PARTICIPANT	\N	PRESENT	0
631552	631546	11033F	PARTICIPANT	\N	PRESENT	0
631553	631546	19683J	PRESIDENT	0	PRESENT	0
631554	631546	19447X	PARTICIPANT	\N	PRESENT	0
631555	631546	99004R	PARTICIPANT	\N	PRESENT	0
631556	631546	14207L	PARTICIPANT	\N	EXCUSE	0
631557	631546	10006L	PARTICIPANT	\N	EXCUSE	0
631558	631546	19699S	PARTICIPANT	\N	EXCUSE	0
631559	631546	11090Q	PARTICIPANT	\N	EXCUSE	0
638711	638710	10006L	PARTICIPANT	\N	PRESENT	0
638712	638710	19703U	PARTICIPANT	\N	PRESENT	0
638713	638710	20062A	PARTICIPANT	\N	PRESENT	0
638714	638709	10006L	PARTICIPANT	\N	PRESENT	0
638715	638709	19703U	PARTICIPANT	\N	PRESENT	0
638716	638709	19713W	PARTICIPANT	\N	PRESENT	0
638717	638709	20062A	PARTICIPANT	\N	PRESENT	0
638719	638463	04085P	PARTICIPANT	\N	PRESENT	1
638720	638463	20022R	PARTICIPANT	\N	PRESENT	1
638721	638463	20110Q	PARTICIPANT	\N	PRESENT	1
638722	638463	20114U	PARTICIPANT	\N	PRESENT	1
638723	638463	14151M	PARTICIPANT	\N	PRESENT	1
638724	638463	14179A	PARTICIPANT	\N	PRESENT	1
638725	638463	19447X	PARTICIPANT	\N	PRESENT	1
638726	638463	19649G	PARTICIPANT	\N	PRESENT	1
638727	638463	19729F	PARTICIPANT	\N	PRESENT	1
638728	638463	14001X	PARTICIPANT	\N	PRESENT	1
638729	638463	14147R	PARTICIPANT	\N	PRESENT	1
638730	638463	14107H	PARTICIPANT	\N	PRESENT	1
638731	638463	20286Q	PARTICIPANT	\N	PRESENT	1
638732	638463	14097Y	PARTICIPANT	\N	PRESENT	1
638733	638463	04045F	PARTICIPANT	\N	PRESENT	1
638825	638445	20080C	PARTICIPANT	\N	PRESENT	1
638826	638445	14121F	PARTICIPANT	\N	PRESENT	1
638827	638445	20126Y	PARTICIPANT	\N	PRESENT	1
638828	638445	19671E	PARTICIPANT	\N	PRESENT	1
638829	638445	20036X	PARTICIPANT	\N	PRESENT	1
638870	638869	19693L	PARTICIPANT	\N	PRESENT	0
638871	638869	01048V	PARTICIPANT	\N	PRESENT	0
638874	638869	20072C	PARTICIPANT	\N	PRESENT	0
638875	638869	20128B	PARTICIPANT	\N	PRESENT	0
638876	638869	19593H	PARTICIPANT	\N	PRESENT	0
638878	638869	01058X	PARTICIPANT	\N	EXCUSE	0
638879	638869	19503N	PARTICIPANT	\N	EXCUSE	0
638880	638869	11067R	PARTICIPANT	\N	EXCUSE	0
638881	638869	19735D	PARTICIPANT	\N	EXCUSE	0
639275	639274	11026G	PARTICIPANT	\N	PRESENT	0
640633	639945	20044X	PARTICIPANT	\N	PRESENT	0
640634	639945	20050V	PARTICIPANT	\N	PRESENT	1
640635	639945	14225N	PARTICIPANT	\N	EXCUSE	0
640641	639945	11048N	PARTICIPANT	\N	PRESENT	0
640642	639945	19711U	PARTICIPANT	\N	PRESENT	0
640643	639945	20080C	PARTICIPANT	\N	PRESENT	0
640644	639945	08010L	PARTICIPANT	\N	PRESENT	0
640645	639945	11070L	PARTICIPANT	\N	PRESENT	0
640651	639945	20086J	PARTICIPANT	\N	PRESENT	0
640652	639945	19647E	PARTICIPANT	\N	PRESENT	0
640653	639945	07029T	PARTICIPANT	\N	PRESENT	0
640654	639945	19479G	PARTICIPANT	\N	PRESENT	0
640655	639945	19689Q	PARTICIPANT	\N	PRESENT	0
640656	639945	20252E	PARTICIPANT	\N	PRESENT	0
640657	639945	19545Y	PRESIDENT	0	PRESENT	0
640658	639945	11053K	PARTICIPANT	\N	PRESENT	0
640659	639945	08011M	PARTICIPANT	\N	PRESENT	0
640660	639945	99004R	PARTICIPANT	\N	PRESENT	0
640661	639945	04071H	PARTICIPANT	\N	PRESENT	0
642353	642177	14059S	PARTICIPANT	\N	PRESENT	0
642354	642177	08061X	PARTICIPANT	\N	PRESENT	0
642355	642177	08047A	PARTICIPANT	\N	PRESENT	0
642356	642177	14193X	PARTICIPANT	\N	PRESENT	0
642357	642177	11054L	PARTICIPANT	\N	PRESENT	1
642358	642177	19421M	PARTICIPANT	\N	PRESENT	0
642359	642177	01058X	PARTICIPANT	\N	PRESENT	0
642360	642177	01062T	PARTICIPANT	\N	PRESENT	0
642361	642177	20064C	PARTICIPANT	\N	PRESENT	1
642362	642177	11066Q	PARTICIPANT	\N	PRESENT	0
642403	642402	14105F	PARTICIPANT	\N	PRESENT	0
642404	642402	14133K	PARTICIPANT	\N	PRESENT	0
642405	642402	04042C	PRESIDENT	0	PRESENT	0
642441	642035	11104D	PARTICIPANT	\N	PRESENT	1
642442	642035	14109K	PARTICIPANT	\N	PRESENT	1
642443	642035	08012N	PARTICIPANT	\N	PRESENT	1
642448	642066	11031D	PARTICIPANT	\N	PRESENT	0
642449	642066	14217N	PARTICIPANT	\N	PRESENT	0
642625	642624	12028B	PARTICIPANT	\N	PRESENT	0
642626	642624	08047A	PARTICIPANT	\N	PRESENT	0
642627	642624	01058X	PARTICIPANT	\N	PRESENT	0
642628	642624	11083R	PARTICIPANT	\N	PRESENT	0
642629	642624	14059S	PARTICIPANT	\N	PRESENT	0
642630	642624	14133K	PARTICIPANT	\N	PRESENT	0
642631	642624	14249W	PARTICIPANT	\N	PRESENT	0
642632	642624	19347U	PARTICIPANT	\N	PRESENT	0
642633	642624	19443T	PARTICIPANT	\N	PRESENT	1
642634	642624	20072C	PARTICIPANT	\N	PRESENT	1
642635	642624	01062T	PARTICIPANT	\N	PRESENT	1
642636	642624	11027H	PARTICIPANT	\N	PRESENT	1
642637	642624	01024M	PARTICIPANT	\N	PRESENT	1
642638	642624	19329S	PARTICIPANT	\N	PRESENT	1
642639	642624	11054L	PARTICIPANT	\N	PRESENT	1
642640	642624	04042C	PARTICIPANT	\N	PRESENT	0
642706	642705	14225N	PARTICIPANT	\N	PRESENT	0
642707	642705	11048N	PARTICIPANT	\N	PRESENT	0
642708	642705	14189C	PARTICIPANT	\N	PRESENT	0
642709	642705	19741B	PARTICIPANT	\N	PRESENT	0
642710	642705	11040E	PARTICIPANT	\N	PRESENT	1
642711	642705	14083S	PARTICIPANT	\N	PRESENT	1
642712	642705	20070A	PARTICIPANT	\N	PRESENT	1
642713	642705	20126Y	PARTICIPANT	\N	PRESENT	0
642714	642705	19671E	PARTICIPANT	\N	PRESENT	1
642715	642705	11012A	PARTICIPANT	\N	PRESENT	0
642716	642705	19479G	PARTICIPANT	\N	PRESENT	0
642718	642717	14225N	PARTICIPANT	\N	PRESENT	0
642719	642717	11048N	PARTICIPANT	\N	PRESENT	0
642720	642717	19741B	PARTICIPANT	\N	PRESENT	0
642721	642717	11040E	PARTICIPANT	\N	PRESENT	1
642722	642717	14083S	PARTICIPANT	\N	PRESENT	0
642723	642717	20126Y	PARTICIPANT	\N	PRESENT	1
642724	642717	19479G	PARTICIPANT	\N	PRESENT	0
642726	642725	19741B	PARTICIPANT	\N	PRESENT	0
642728	642727	11053K	PARTICIPANT	\N	PRESENT	0
642730	642729	20032T	PARTICIPANT	\N	PRESENT	0
642731	642729	19575F	PARTICIPANT	\N	PRESENT	0
642732	642729	14207L	PARTICIPANT	\N	PRESENT	0
642733	642729	14357A	PARTICIPANT	\N	PRESENT	0
642734	642729	20174H	PARTICIPANT	\N	PRESENT	0
642735	642729	20132W	PARTICIPANT	\N	PRESENT	0
642736	642729	20128B	PARTICIPANT	\N	PRESENT	0
642737	642729	08015R	PARTICIPANT	\N	PRESENT	0
642738	642729	14109K	PARTICIPANT	\N	PRESENT	0
642739	642729	19533U	PARTICIPANT	\N	PRESENT	0
642740	642729	11097X	PARTICIPANT	\N	PRESENT	0
642741	642729	20084G	PARTICIPANT	\N	PRESENT	0
642743	642742	19467C	PARTICIPANT	\N	PRESENT	0
642744	642742	20028X	PARTICIPANT	\N	PRESENT	0
642745	642742	19441R	PARTICIPANT	\N	PRESENT	0
642746	642742	19507S	PARTICIPANT	\N	PRESENT	0
642748	642747	19507S	PARTICIPANT	\N	PRESENT	0
642749	642747	19441R	PARTICIPANT	\N	PRESENT	0
642751	642750	19507S	PARTICIPANT	\N	PRESENT	0
642752	642750	19441R	PARTICIPANT	\N	PRESENT	0
642754	642753	19507S	PARTICIPANT	\N	PRESENT	0
642755	642753	19441R	PARTICIPANT	\N	PRESENT	0
642757	642756	19507S	PARTICIPANT	\N	PRESENT	0
642758	642756	19441R	PARTICIPANT	\N	PRESENT	0
642760	642759	19507S	PARTICIPANT	\N	PRESENT	0
642761	642759	19441R	PARTICIPANT	\N	PRESENT	0
642763	642762	19507S	PARTICIPANT	\N	PRESENT	0
642764	642762	19441R	PARTICIPANT	\N	PRESENT	0
642766	642765	19507S	PARTICIPANT	\N	PRESENT	0
642767	642765	19441R	PARTICIPANT	\N	PRESENT	0
643221	642868	20070A	PARTICIPANT	\N	PRESENT	1
643222	642868	14121F	PARTICIPANT	\N	PRESENT	1
643223	642868	19671E	PARTICIPANT	\N	PRESENT	1
643224	642868	19349W	PARTICIPANT	\N	PRESENT	1
643225	642868	14225N	PARTICIPANT	\N	EXCUSE	0
643226	642868	11048N	PARTICIPANT	\N	EXCUSE	0
643227	642868	20050V	PARTICIPANT	\N	EXCUSE	0
643228	642868	20080C	PARTICIPANT	\N	EXCUSE	0
649210	648779	01028R	PARTICIPANT	\N	PRESENT	0
649211	648779	11033F	PARTICIPANT	\N	PRESENT	0
649212	648779	19447X	PARTICIPANT	\N	PRESENT	0
649213	648779	14001X	PARTICIPANT	\N	PRESENT	0
649214	649089	19741B	PARTICIPANT	\N	EXCUSE	0
649215	649089	14083S	PARTICIPANT	\N	PRESENT	0
649216	649089	20914V	PARTICIPANT	\N	PRESENT	0
649217	648779	19649G	PARTICIPANT	\N	PRESENT	0
649218	648779	20074E	PARTICIPANT	\N	PRESENT	0
649219	648779	19585H	PARTICIPANT	\N	PRESENT	0
649220	648779	04047H	PRESIDENT	0	PRESENT	0
649221	649089	19711U	PARTICIPANT	\N	PRESENT	0
649222	649089	20252E	PARTICIPANT	\N	PRESENT	0
649223	648779	20110Q	PARTICIPANT	\N	PRESENT	0
649224	648779	19749K	PARTICIPANT	\N	PRESENT	0
649225	648779	05008E	PARTICIPANT	\N	PRESENT	0
649226	649089	08009T	PARTICIPANT	\N	PRESENT	0
649227	649089	19667J	PARTICIPANT	\N	PRESENT	0
649228	648779	11026G	PARTICIPANT	\N	PRESENT	0
649229	648779	14179A	PARTICIPANT	\N	PRESENT	0
649230	648779	20022R	PARTICIPANT	\N	PRESENT	0
649231	649089	14327T	PARTICIPANT	\N	PRESENT	0
649232	649089	11048N	PARTICIPANT	\N	PRESENT	0
649233	649089	19349W	PARTICIPANT	\N	PRESENT	0
649234	649089	20080C	PARTICIPANT	\N	PRESENT	0
649235	649089	20116W	PARTICIPANT	\N	PRESENT	0
649236	649089	14225N	PRESIDENT	0	PRESENT	0
649237	648779	11056N	PARTICIPANT	\N	PRESENT	0
649238	648779	08018U	PARTICIPANT	\N	PRESENT	0
649239	648779	11010L	PARTICIPANT	\N	PRESENT	0
649240	648779	14089Y	PARTICIPANT	\N	PRESENT	0
649241	648779	14151M	PARTICIPANT	\N	PRESENT	0
649242	648779	14231L	PARTICIPANT	\N	PRESENT	0
649243	649089	04071H	PARTICIPANT	\N	PRESENT	0
649244	649089	19647E	PARTICIPANT	\N	PRESENT	0
649245	649089	14189C	PARTICIPANT	\N	PRESENT	0
649246	649089	11053K	PARTICIPANT	\N	PRESENT	0
649247	649089	08011M	PARTICIPANT	\N	PRESENT	0
649248	649089	20070A	PARTICIPANT	\N	PRESENT	0
649249	649089	08010L	PARTICIPANT	\N	PRESENT	0
649250	649089	19762G	PARTICIPANT	\N	PRESENT	0
649251	649089	20044X	PARTICIPANT	\N	PRESENT	0
649252	649089	07029T	PARTICIPANT	\N	PRESENT	0
649255	649089	19687N	PARTICIPANT	\N	PRESENT	0
649256	649089	11012A	PARTICIPANT	\N	EXCUSE	0
649257	649089	20036X	PARTICIPANT	\N	PRESENT	0
649270	649089	11070L	PARTICIPANT	\N	PRESENT	0
649272	649089	11074Q	PARTICIPANT	\N	PRESENT	0
649321	648779	14259Y	PARTICIPANT	\N	PRESENT	0
649350	649159	86034E	PARTICIPANT	\N	PRESENT	0
649355	649160	11070L	PARTICIPANT	\N	PRESENT	0
649357	649160	19758L	PARTICIPANT	\N	PRESENT	0
649356	649160	19760E	PARTICIPANT	\N	PRESENT	0
649358	649160	04085P	PARTICIPANT	\N	PRESENT	0
649359	649160	20046A	PARTICIPANT	\N	PRESENT	0
649360	649160	12028B	PARTICIPANT	\N	PRESENT	0
649422	649160	19703U	PARTICIPANT	\N	PRESENT	0
649413	649160	19329S	PARTICIPANT	\N	PRESENT	0
649363	649160	14121F	PARTICIPANT	\N	PRESENT	0
649368	649160	19387D	PARTICIPANT	\N	PRESENT	0
649410	649160	19599P	PARTICIPANT	\N	PRESENT	0
649366	649160	11083R	PARTICIPANT	\N	PRESENT	0
649367	649160	20116W	PARTICIPANT	\N	PRESENT	0
649408	649160	19383Y	PARTICIPANT	\N	PRESENT	0
649370	649160	14207L	PARTICIPANT	\N	PRESENT	0
649371	649160	14107H	PARTICIPANT	\N	PRESENT	0
649372	649160	20072C	PARTICIPANT	\N	PRESENT	0
649373	649160	19569H	PARTICIPANT	\N	PRESENT	0
649374	649160	14275Y	PARTICIPANT	\N	PRESENT	0
649375	649160	19577H	PARTICIPANT	\N	PRESENT	0
649400	649160	08028W	PARTICIPANT	\N	PRESENT	0
649377	649160	19747H	PARTICIPANT	\N	PRESENT	0
649378	649160	14026U	PARTICIPANT	\N	PRESENT	0
649380	649160	20252E	PARTICIPANT	\N	PRESENT	0
649412	649160	19782L	PARTICIPANT	\N	PRESENT	0
649382	649160	20090E	PARTICIPANT	\N	PRESENT	0
649383	649160	20062A	PARTICIPANT	\N	PRESENT	0
649384	649160	19533U	PARTICIPANT	\N	PRESENT	0
649385	649160	20108W	PARTICIPANT	\N	PRESENT	0
649386	649160	97011G	PARTICIPANT	\N	PRESENT	0
649387	649160	20140W	PARTICIPANT	\N	PRESENT	0
649388	649160	20136B	PARTICIPANT	\N	PRESENT	0
649389	649160	18083K	PARTICIPANT	\N	PRESENT	0
649390	649160	20034V	PARTICIPANT	\N	PRESENT	0
649391	649160	20038A	PARTICIPANT	\N	PRESENT	0
649392	649160	14038Y	PARTICIPANT	\N	PRESENT	0
649393	649160	14189C	PARTICIPANT	\N	PRESENT	0
649394	649160	20914V	PARTICIPANT	\N	PRESENT	0
649395	649160	19479G	PARTICIPANT	\N	PRESENT	0
649396	649160	04057K	PARTICIPANT	\N	PRESENT	0
649397	649160	19447X	PARTICIPANT	\N	PRESENT	0
649398	649160	19798U	PARTICIPANT	\N	PRESENT	0
649399	649160	20098N	PARTICIPANT	\N	PRESENT	0
649401	649160	19443T	PARTICIPANT	\N	PRESENT	0
649402	649160	14031R	PARTICIPANT	\N	PRESENT	0
649403	649160	19711U	PARTICIPANT	\N	PRESENT	0
649404	649160	14249W	PARTICIPANT	\N	PRESENT	0
649405	649160	01058X	PARTICIPANT	\N	PRESENT	0
649406	649160	14255U	PARTICIPANT	\N	PRESENT	0
649407	649160	14073Q	PARTICIPANT	\N	PRESENT	0
649409	649160	19549D	PARTICIPANT	\N	PRESENT	0
649414	649160	08047A	PARTICIPANT	\N	PRESENT	0
649415	649160	20032T	PARTICIPANT	\N	PRESENT	0
649416	649160	19367Y	PARTICIPANT	\N	PRESENT	0
649417	649160	20074E	PARTICIPANT	\N	PRESENT	0
649418	649160	11077T	PARTICIPANT	\N	PRESENT	0
649419	649160	14257W	PARTICIPANT	\N	PRESENT	0
649420	649160	19349W	PARTICIPANT	\N	PRESENT	0
649421	649160	01057W	PARTICIPANT	\N	PRESENT	0
649423	649160	14223L	PARTICIPANT	\N	PRESENT	0
649424	649160	20036X	PARTICIPANT	\N	PRESENT	0
649425	649160	19347U	PARTICIPANT	\N	PRESENT	0
649426	649160	12041X	PARTICIPANT	\N	PRESENT	0
649427	649160	19629C	PARTICIPANT	\N	PRESENT	0
649428	649160	19503N	PARTICIPANT	\N	PRESENT	0
649429	649160	20064C	PARTICIPANT	\N	PRESENT	0
649430	649160	20086J	PARTICIPANT	\N	PRESENT	0
649431	649160	19507S	PARTICIPANT	\N	PRESENT	0
649432	649160	14083S	PARTICIPANT	\N	PRESENT	0
649433	649160	14105F	PARTICIPANT	\N	PRESENT	0
649435	649160	01062T	PARTICIPANT	\N	PRESENT	0
649437	649160	14097Y	PARTICIPANT	\N	PRESENT	0
649438	649160	20042V	PARTICIPANT	\N	PRESENT	0
649439	649160	19593H	PARTICIPANT	\N	PRESENT	0
649440	649160	20070A	PARTICIPANT	\N	PRESENT	0
649441	649160	07004J	PARTICIPANT	\N	PRESENT	0
649442	649160	01024M	PARTICIPANT	\N	PRESENT	0
649443	649160	20048C	PARTICIPANT	\N	PRESENT	0
649444	649160	14179A	PARTICIPANT	\N	PRESENT	0
649445	649160	20112S	PARTICIPANT	\N	PRESENT	0
649447	649160	19667J	PARTICIPANT	\N	PRESENT	0
649451	649160	08056B	PARTICIPANT	\N	PRESENT	0
649452	649160	04042C	PARTICIPANT	\N	PRESENT	0
649453	649160	11066Q	PARTICIPANT	\N	PRESENT	0
649454	649160	20056C	PARTICIPANT	\N	PRESENT	0
649455	649160	11056N	PARTICIPANT	\N	PRESENT	0
649456	649160	20172F	PARTICIPANT	\N	PRESENT	0
649457	649160	20180F	PARTICIPANT	\N	PRESENT	0
649458	649160	14071N	PARTICIPANT	\N	PRESENT	0
649459	649160	11103C	PARTICIPANT	\N	PRESENT	0
649460	649160	14221J	PARTICIPANT	\N	PRESENT	0
649461	649160	20058E	PARTICIPANT	\N	PRESENT	0
649462	649160	14225N	PARTICIPANT	\N	PRESENT	0
649463	649160	19723Y	PARTICIPANT	\N	PRESENT	0
649464	649160	19399H	PARTICIPANT	\N	PRESENT	0
649465	649160	14267Y	PARTICIPANT	\N	PRESENT	0
649466	649160	19545Y	PARTICIPANT	\N	PRESENT	0
649467	649160	19741B	PARTICIPANT	\N	PRESENT	0
649468	649160	01048V	PARTICIPANT	\N	PRESENT	0
649469	649160	20100N	PARTICIPANT	\N	PRESENT	0
649470	649160	11048N	PARTICIPANT	\N	PRESENT	0
628967	628965	20140W	PARTICIPANT	\N	PRESENT	0
628993	628992	20140W	PARTICIPANT	\N	PRESENT	0
629411	629410	19631V	PARTICIPANT	\N	PRESENT	0
629412	629410	19768N	PARTICIPANT	\N	PRESENT	0
629413	629410	20078J	PARTICIPANT	\N	PRESENT	0
629415	629414	20024T	PARTICIPANT	\N	PRESENT	0
629416	629414	19515S	PARTICIPANT	\N	PRESENT	0
629418	629417	20024T	PARTICIPANT	\N	PRESENT	0
629419	629417	19515S	PARTICIPANT	\N	PRESENT	0
630222	629205	01028R	PARTICIPANT	\N	PRESENT	0
630223	629205	19954N	PARTICIPANT	\N	PRESENT	0
630224	629205	14107H	PARTICIPANT	\N	PRESENT	0
630225	629205	14151M	PARTICIPANT	\N	PRESENT	0
630226	629205	11026G	PARTICIPANT	\N	PRESENT	0
630227	629205	19725B	PARTICIPANT	\N	PRESENT	0
630228	629205	14069U	PARTICIPANT	\N	PRESENT	0
630229	629205	19749K	PARTICIPANT	\N	PRESENT	0
630230	629305	19593H	PARTICIPANT	\N	PRESENT	0
630231	629305	19766L	PARTICIPANT	\N	PRESENT	1
630232	629305	20132W	PARTICIPANT	\N	PRESENT	0
630233	629305	20134Y	PARTICIPANT	\N	PRESENT	0
630234	629305	19699S	PARTICIPANT	\N	PRESENT	1
630235	629305	19533U	PARTICIPANT	\N	PRESENT	0
630236	629305	19651A	PARTICIPANT	\N	PRESENT	1
630237	629305	14073Q	PARTICIPANT	\N	PRESENT	0
630238	629305	19611R	PRESIDENT	0	PRESENT	0
630239	629305	20142Y	PARTICIPANT	\N	PRESENT	1
630240	629305	01060R	PARTICIPANT	\N	PRESENT	0
630241	629305	19693L	PARTICIPANT	\N	PRESENT	0
630242	629305	19399H	PARTICIPANT	\N	PRESENT	0
630243	629305	20052X	PARTICIPANT	\N	PRESENT	1
630244	629305	14229S	PARTICIPANT	\N	PRESENT	0
630245	629305	20098N	PARTICIPANT	\N	PRESENT	0
630246	629305	20056C	PARTICIPANT	\N	PRESENT	0
630247	629305	20180F	PARTICIPANT	\N	PRESENT	0
630248	629305	04059M	PARTICIPANT	\N	PRESENT	0
630249	629305	11043H	PARTICIPANT	\N	PRESENT	0
630250	629305	20124W	PARTICIPANT	\N	PRESENT	0
630251	629305	19758L	PARTICIPANT	\N	PRESENT	0
630252	629305	20026V	PARTICIPANT	\N	PRESENT	0
630253	629305	20084G	PARTICIPANT	\N	PRESENT	0
630254	629205	95063L	PARTICIPANT	\N	PRESENT	0
630255	629205	04008A	PARTICIPANT	\N	PRESENT	0
630256	629205	20074E	PARTICIPANT	\N	PRESENT	0
630257	629205	11033F	PARTICIPANT	\N	PRESENT	0
630295	629958	19333N	PARTICIPANT	\N	PRESENT	0
630380	629206	14089Y	PARTICIPANT	\N	PRESENT	0
630297	629958	20076G	PARTICIPANT	\N	PRESENT	0
630298	629958	19549D	PARTICIPANT	\N	PRESENT	0
630299	629958	19387D	PARTICIPANT	\N	PRESENT	0
630300	629958	19820Y	PARTICIPANT	\N	PRESENT	0
630301	629958	14219Q	PRESIDENT	0	PRESENT	0
630302	629958	19826F	PARTICIPANT	\N	PRESENT	0
630303	629958	14221J	PARTICIPANT	\N	PRESENT	0
630304	629958	19599P	PARTICIPANT	\N	PRESENT	0
630305	629958	20102Q	PARTICIPANT	\N	PRESENT	0
630306	629958	20096L	PARTICIPANT	\N	PRESENT	0
630307	629958	19637C	PARTICIPANT	\N	PRESENT	0
630308	629958	20100N	PARTICIPANT	\N	PRESENT	0
630309	629958	19551W	PARTICIPANT	\N	PRESENT	0
630382	629302	19383Y	PARTICIPANT	\N	PRESENT	0
630311	629958	05012A	PARTICIPANT	\N	PRESENT	0
630312	629958	08060W	PARTICIPANT	\N	PRESENT	0
630340	629958	20032T	PARTICIPANT	\N	PRESENT	0
630314	629958	19503N	PARTICIPANT	\N	PRESENT	0
630315	629958	20020P	PARTICIPANT	\N	PRESENT	0
630316	629958	19685L	PARTICIPANT	\N	PRESENT	0
630383	629302	19768N	PARTICIPANT	\N	PRESENT	0
630318	629958	20024T	PARTICIPANT	\N	PRESENT	0
630319	629958	20136B	PARTICIPANT	\N	PRESENT	0
630320	629958	14031R	PARTICIPANT	\N	PRESENT	0
630321	629958	20038A	PARTICIPANT	\N	PRESENT	0
630322	629958	19251M	PARTICIPANT	\N	PRESENT	0
630323	629958	20046A	PARTICIPANT	\N	PRESENT	0
630384	629302	20088L	PARTICIPANT	\N	PRESENT	1
630325	629958	14169X	PARTICIPANT	\N	PRESENT	0
630341	628668	19349W	PARTICIPANT	\N	PRESENT	0
630385	629302	19515S	PARTICIPANT	\N	PRESENT	0
630328	629958	11101A	PARTICIPANT	\N	PRESENT	0
630329	629958	19745F	PARTICIPANT	\N	PRESENT	0
630330	629958	19619A	PARTICIPANT	\N	PRESENT	0
630331	629958	18083K	PARTICIPANT	\N	PRESENT	1
630386	629302	19782L	PARTICIPANT	\N	PRESENT	0
630387	629302	20092G	PARTICIPANT	\N	PRESENT	0
630343	628668	19762G	PARTICIPANT	\N	PRESENT	0
630388	629302	01043Q	PARTICIPANT	\N	PRESENT	0
630344	628668	20080C	PARTICIPANT	\N	PRESENT	0
630345	628668	19335Q	PARTICIPANT	\N	PRESENT	0
630338	628668	07029T	PARTICIPANT	\N	PRESENT	0
630339	628668	11053K	PARTICIPANT	\N	PRESENT	0
630346	628668	19687N	PARTICIPANT	\N	PRESENT	0
630347	628668	20050V	PARTICIPANT	\N	PRESENT	0
630348	628668	20044X	PARTICIPANT	\N	PRESENT	0
630349	628668	08009T	PARTICIPANT	\N	PRESENT	0
630389	629302	14357A	PARTICIPANT	\N	PRESENT	0
630390	629302	19441R	PARTICIPANT	\N	PRESENT	0
630391	629302	20078J	PARTICIPANT	\N	PRESENT	0
630392	629302	20082E	PARTICIPANT	\N	PRESENT	1
630393	629302	20094J	PARTICIPANT	\N	PRESENT	0
630394	629302	04045F	PARTICIPANT	\N	PRESENT	0
630395	629302	19631V	PARTICIPANT	\N	PRESENT	0
630396	629302	20104S	PARTICIPANT	\N	PRESENT	0
630397	629302	19705W	PARTICIPANT	\N	PRESENT	1
630398	629302	19707Y	PARTICIPANT	\N	PRESENT	1
630399	629302	20018V	PARTICIPANT	\N	PRESENT	0
630400	629302	19511N	PARTICIPANT	\N	PRESENT	0
630401	629302	19563B	PARTICIPANT	\N	PRESENT	0
630402	629302	08028W	PARTICIPANT	\N	PRESENT	0
630403	629302	20028X	PARTICIPANT	\N	PRESENT	0
630404	629302	14038Y	PARTICIPANT	\N	PRESENT	0
630405	629302	20030R	PARTICIPANT	\N	PRESENT	1
630406	629302	19467C	PARTICIPANT	\N	PRESENT	0
630407	629302	20034V	PARTICIPANT	\N	PRESENT	1
630408	629302	14187A	PARTICIPANT	\N	PRESENT	0
630409	629302	20144B	PARTICIPANT	\N	PRESENT	0
630410	629302	19695N	PARTICIPANT	\N	PRESENT	1
630411	629302	11090Q	PRESIDENT	0	PRESENT	0
630412	629302	01025N	PARTICIPANT	\N	PRESENT	0
630413	629302	14033T	PARTICIPANT	\N	PRESENT	0
630414	629302	20054A	PARTICIPANT	\N	PRESENT	0
630415	629302	20174H	PARTICIPANT	\N	PRESENT	1
630416	629302	14205J	PARTICIPANT	\N	PRESENT	0
630417	629302	20060X	PARTICIPANT	\N	PRESENT	0
630418	629302	20062A	PARTICIPANT	\N	PRESENT	0
630419	629302	14251Q	PARTICIPANT	\N	PRESENT	1
630420	629302	19507S	PARTICIPANT	\N	PRESENT	0
630421	629302	20286Q	PARTICIPANT	\N	PRESENT	0
630422	629302	19747H	PARTICIPANT	\N	PRESENT	0
630423	629302	14207L	PARTICIPANT	\N	PRESENT	0
630424	629302	14257W	PARTICIPANT	\N	PRESENT	0
630431	629958	20140W	PARTICIPANT	\N	PRESENT	0
630451	629124	95041E	PARTICIPANT	\N	PRESENT	0
630452	629124	19443T	PARTICIPANT	\N	PRESENT	0
630453	629124	12041X	PARTICIPANT	\N	PRESENT	0
630454	629124	19565D	PARTICIPANT	\N	PRESENT	0
630455	629124	19329S	PARTICIPANT	\N	PRESENT	0
630456	629124	01058X	PARTICIPANT	\N	PRESENT	0
630457	629124	11027H	PARTICIPANT	\N	PRESENT	0
630458	629124	16685X	PARTICIPANT	\N	PRESENT	0
630459	629124	04042C	PRESIDENT	1	PRESENT	0
630460	629124	19669L	PARTICIPANT	\N	PRESENT	1
630461	629124	11066Q	PARTICIPANT	\N	PRESENT	0
630462	629124	08056B	PARTICIPANT	\N	PRESENT	0
630463	629124	12028B	PARTICIPANT	\N	PRESENT	0
630464	629124	19421M	PARTICIPANT	\N	PRESENT	0
630465	629124	19709B	PARTICIPANT	\N	PRESENT	0
630466	629124	14193X	PRESIDENT	0	PRESENT	0
630467	629124	19347U	PARTICIPANT	\N	PRESENT	0
630468	629124	97011G	PARTICIPANT	\N	PRESENT	0
630469	629124	08061X	PARTICIPANT	\N	PRESENT	0
630470	629124	14249W	PARTICIPANT	\N	PRESENT	0
630471	629124	08047A	PARTICIPANT	\N	PRESENT	0
630472	629124	14059S	PARTICIPANT	\N	PRESENT	0
630473	629124	14097Y	PARTICIPANT	\N	PRESENT	1
630474	629124	14133K	PARTICIPANT	\N	PRESENT	0
630475	629124	01062T	PARTICIPANT	\N	PRESENT	0
630476	629124	08069G	PARTICIPANT	\N	PRESENT	0
630477	629124	11041F	PARTICIPANT	\N	PRESENT	1
630478	629124	20042V	PARTICIPANT	\N	PRESENT	0
630479	629124	01024M	PARTICIPANT	\N	PRESENT	0
630480	629124	19319Q	PARTICIPANT	\N	PRESENT	0
640898	640897	20018V	PARTICIPANT	\N	PRESENT	0
640899	640897	11090Q	PARTICIPANT	\N	PRESENT	0
640900	640897	14257W	PARTICIPANT	\N	PRESENT	0
640901	640897	20286Q	PARTICIPANT	\N	PRESENT	0
640903	640902	19741B	PARTICIPANT	\N	PRESENT	0
640905	640904	19741B	PARTICIPANT	\N	PRESENT	0
640907	640906	99004R	PARTICIPANT	\N	PRESENT	0
640909	640908	19479G	PARTICIPANT	\N	PRESENT	0
640911	640910	19479G	PARTICIPANT	\N	PRESENT	0
640916	640912	14033T	PARTICIPANT	\N	PRESENT	0
640917	640912	19369B	PARTICIPANT	\N	PRESENT	0
640918	640912	20018V	PARTICIPANT	\N	PRESENT	0
640920	640919	14033T	PARTICIPANT	\N	PRESENT	0
640921	640919	19369B	PARTICIPANT	\N	PRESENT	0
640922	640919	20018V	PARTICIPANT	\N	PRESENT	0
640923	640919	20174H	PARTICIPANT	\N	PRESENT	0
640925	640924	14033T	PARTICIPANT	\N	PRESENT	0
640926	640924	19369B	PARTICIPANT	\N	PRESENT	0
640927	640924	20018V	PARTICIPANT	\N	PRESENT	0
640960	640959	11097X	PARTICIPANT	\N	EXCUSE	0
640969	640968	20132W	PARTICIPANT	\N	PRESENT	0
640970	640968	19643A	PARTICIPANT	\N	PRESENT	0
640971	640968	19725B	PARTICIPANT	\N	PRESENT	0
640972	640968	14147R	PARTICIPANT	\N	PRESENT	0
640974	640973	19741B	PARTICIPANT	\N	PRESENT	0
640976	640975	08073C	PARTICIPANT	\N	PRESENT	0
640977	640975	20150Y	PARTICIPANT	\N	PRESENT	0
640980	640979	99004R	PARTICIPANT	\N	PRESENT	0
640981	640979	19399H	PARTICIPANT	\N	PRESENT	0
640983	640982	11053K	PARTICIPANT	\N	PRESENT	0
640985	640984	11053K	PARTICIPANT	\N	PRESENT	0
640987	640986	11053K	PARTICIPANT	\N	PRESENT	0
640993	640988	14217N	PARTICIPANT	\N	PRESENT	0
640994	640988	11067R	PARTICIPANT	\N	PRESENT	0
640995	640989	14217N	PARTICIPANT	\N	PRESENT	0
640996	640989	11067R	PARTICIPANT	\N	PRESENT	0
640997	640990	14217N	PARTICIPANT	\N	PRESENT	0
640998	640990	11067R	PARTICIPANT	\N	PRESENT	0
640999	640991	14217N	PARTICIPANT	\N	PRESENT	0
641000	640991	11067R	PARTICIPANT	\N	PRESENT	0
641002	640992	14217N	PARTICIPANT	\N	PRESENT	0
641003	640992	20248J	PARTICIPANT	\N	PRESENT	0
641004	640992	11067R	PARTICIPANT	\N	PRESENT	0
641005	641001	14217N	PARTICIPANT	\N	PRESENT	0
641006	641001	11067R	PARTICIPANT	\N	PRESENT	0
641008	641007	19575F	PARTICIPANT	\N	PRESENT	0
641009	641007	01043Q	PARTICIPANT	\N	PRESENT	0
641010	641007	14187A	PARTICIPANT	\N	PRESENT	0
641151	641150	14038Y	PARTICIPANT	\N	PRESENT	0
641155	641150	20092G	PARTICIPANT	\N	PRESENT	0
641153	641150	19629C	PARTICIPANT	\N	PRESENT	0
641154	641150	14231L	PARTICIPANT	\N	PRESENT	0
641162	641161	11080N	PARTICIPANT	\N	PRESENT	0
641163	641161	19711U	PARTICIPANT	\N	PRESENT	0
641164	641161	05012A	PARTICIPANT	\N	PRESENT	0
641165	641161	19687N	PARTICIPANT	\N	PRESENT	0
641166	641161	19335Q	PARTICIPANT	\N	PRESENT	0
641167	641161	19347U	PARTICIPANT	\N	PRESENT	0
641168	641161	01057W	PARTICIPANT	\N	PRESENT	0
641425	641424	19725B	PARTICIPANT	\N	PRESENT	1
641426	641424	14147R	PARTICIPANT	\N	PRESENT	1
641427	641424	20128B	PARTICIPANT	\N	PRESENT	1
641482	641027	14089Y	PARTICIPANT	\N	EXCUSE	0
641489	641486	14213J	PARTICIPANT	\N	PRESENT	0
641174	641161	14121F	PARTICIPANT	\N	EXCUSE	0
641487	641486	19760E	PARTICIPANT	\N	PRESENT	0
641488	641486	14195A	PARTICIPANT	\N	PRESENT	0
641490	641486	11097X	PARTICIPANT	\N	PRESENT	0
641491	641486	18193Q	PARTICIPANT	\N	PRESENT	0
641494	641493	11074Q	PARTICIPANT	\N	PRESENT	0
641508	641507	14259Y	PARTICIPANT	\N	PRESENT	0
641509	641507	19333N	PARTICIPANT	\N	PRESENT	0
641546	641545	11048N	PARTICIPANT	\N	PRESENT	0
641547	641545	19553Y	PARTICIPANT	\N	PRESENT	0
641548	641545	19335Q	PARTICIPANT	\N	PRESENT	0
641550	641549	01057W	PARTICIPANT	\N	PRESENT	0
641551	641549	14225N	PARTICIPANT	\N	PRESENT	0
641553	641552	14225N	PARTICIPANT	\N	PRESENT	0
641554	641552	01057W	PARTICIPANT	\N	PRESENT	0
641556	641555	11053K	PARTICIPANT	\N	PRESENT	0
641559	641558	99004R	PARTICIPANT	\N	PRESENT	0
641560	641558	19399H	PARTICIPANT	\N	PRESENT	0
641562	641561	14327T	PARTICIPANT	\N	PRESENT	0
641565	641564	19533U	PARTICIPANT	\N	PRESENT	0
641566	641564	19693L	PARTICIPANT	\N	PRESENT	0
641567	641564	19593H	PARTICIPANT	\N	PRESENT	0
641568	641564	19651A	PARTICIPANT	\N	PRESENT	0
641579	641576	19593H	PARTICIPANT	\N	PRESENT	0
641571	641570	19533U	PARTICIPANT	\N	PRESENT	0
641572	641570	19693L	PARTICIPANT	\N	PRESENT	0
641573	641570	19593H	PARTICIPANT	\N	PRESENT	0
641574	641570	19651A	PARTICIPANT	\N	PRESENT	0
641575	641570	14229S	PARTICIPANT	\N	PRESENT	0
641577	641576	19693L	PARTICIPANT	\N	PRESENT	0
641578	641576	19533U	PARTICIPANT	\N	PRESENT	0
641580	641576	14229S	PARTICIPANT	\N	PRESENT	0
641582	641581	19693L	PARTICIPANT	\N	PRESENT	0
641583	641581	19593H	PARTICIPANT	\N	PRESENT	0
641584	641581	19533U	PARTICIPANT	\N	PRESENT	0
641623	641457	14147R	PARTICIPANT	\N	PRESENT	0
641636	641635	19447X	PARTICIPANT	\N	PRESENT	0
641637	641635	19725B	PARTICIPANT	\N	PRESENT	0
641638	641635	14147R	PARTICIPANT	\N	PRESENT	0
641750	641749	99004R	PARTICIPANT	\N	PRESENT	0
641640	641635	20128B	PARTICIPANT	\N	PRESENT	0
641641	641635	14179A	PARTICIPANT	\N	PRESENT	0
641652	641651	14231L	PARTICIPANT	\N	PRESENT	0
641653	641651	14259Y	PARTICIPANT	\N	PRESENT	0
641655	641654	14259Y	PARTICIPANT	\N	PRESENT	0
641656	641654	14231L	PARTICIPANT	\N	PRESENT	0
641658	641657	14259Y	PARTICIPANT	\N	PRESENT	0
641659	641657	14231L	PARTICIPANT	\N	PRESENT	0
641661	641660	14259Y	PARTICIPANT	\N	PRESENT	0
641662	641660	14231L	PARTICIPANT	\N	PRESENT	0
641664	641663	14259Y	PARTICIPANT	\N	PRESENT	0
641746	641745	14147R	PARTICIPANT	\N	PRESENT	0
641747	641745	19725B	PARTICIPANT	\N	PRESENT	0
641751	641749	19399H	PARTICIPANT	\N	PRESENT	0
641753	641752	04070G	PARTICIPANT	\N	PRESENT	0
641754	641752	11083R	PARTICIPANT	\N	PRESENT	0
641757	641755	11083R	PARTICIPANT	\N	PRESENT	0
641758	641755	04070G	PARTICIPANT	\N	PRESENT	0
641759	641756	04070G	PARTICIPANT	\N	PRESENT	0
641760	641756	11083R	PARTICIPANT	\N	PRESENT	0
641762	641761	14147R	PARTICIPANT	\N	PRESENT	0
641763	641761	19725B	PARTICIPANT	\N	PRESENT	0
641764	641761	20128B	PARTICIPANT	\N	PRESENT	0
641808	641807	14133K	PARTICIPANT	\N	PRESENT	0
641809	641807	19721W	PARTICIPANT	\N	PRESENT	0
641810	641807	11083R	PARTICIPANT	\N	PRESENT	0
641812	641811	14133K	PARTICIPANT	\N	PRESENT	0
641813	641811	11066Q	PARTICIPANT	\N	PRESENT	0
641860	641859	19333N	PARTICIPANT	\N	PRESENT	0
641861	641859	19717B	PARTICIPANT	\N	EXCUSE	0
641862	641859	14083S	PRESIDENT	0	PRESENT	0
641863	641859	20100N	PARTICIPANT	\N	PRESENT	0
641864	641859	20150Y	PARTICIPANT	\N	PRESENT	0
641865	641859	19503N	PARTICIPANT	\N	PRESENT	1
641866	641859	14031R	PARTICIPANT	\N	PRESENT	1
641867	641859	19447X	PARTICIPANT	\N	PRESENT	1
641877	641859	20034V	PARTICIPANT	\N	PRESENT	0
641898	641859	17023S	PARTICIPANT	\N	PRESENT	0
641974	641973	05008E	PARTICIPANT	\N	PRESENT	0
641975	641973	11053K	PARTICIPANT	\N	PRESENT	0
641976	641973	01028R	PARTICIPANT	\N	PRESENT	0
641992	641990	14033T	PARTICIPANT	\N	PRESENT	0
641993	641990	19369B	PARTICIPANT	\N	PRESENT	0
641994	641990	20018V	PARTICIPANT	\N	PRESENT	0
641995	641990	14257W	PARTICIPANT	\N	PRESENT	0
641996	641990	20092G	PARTICIPANT	\N	PRESENT	0
642064	642038	19565D	PARTICIPANT	\N	EXCUSE	0
642065	642038	07033P	PARTICIPANT	\N	EXCUSE	0
642068	641651	04047H	PARTICIPANT	\N	PRESENT	0
642069	641651	11056N	PARTICIPANT	\N	PRESENT	0
642070	641651	20110Q	PARTICIPANT	\N	PRESENT	0
642071	641651	14107H	PARTICIPANT	\N	PRESENT	0
642072	641651	14053L	PARTICIPANT	\N	PRESENT	0
642073	641654	04047H	PARTICIPANT	\N	PRESENT	0
642074	641654	01028R	PARTICIPANT	\N	PRESENT	0
631794	631702	19669L	PARTICIPANT	\N	PRESENT	1
631795	631702	11053K	PARTICIPANT	\N	PRESENT	1
631796	631702	19725B	PARTICIPANT	\N	PRESENT	1
631797	631702	14229S	PARTICIPANT	\N	PRESENT	0
631799	631798	19711U	PARTICIPANT	\N	PRESENT	0
631800	631798	20024T	PARTICIPANT	\N	PRESENT	0
631801	631798	14187A	PARTICIPANT	\N	PRESENT	1
631802	631798	20114U	PARTICIPANT	\N	PRESENT	1
631803	631798	11026G	PARTICIPANT	\N	PRESENT	1
631804	631798	08056B	PARTICIPANT	\N	PRESENT	0
631805	631798	19647E	PARTICIPANT	\N	PRESENT	0
633912	631368	20104S	PARTICIPANT	\N	EXCUSE	0
633913	631368	11083R	PARTICIPANT	\N	PRESENT	0
633914	631368	14033T	PARTICIPANT	\N	PRESENT	0
633915	631368	19725B	PARTICIPANT	\N	PRESENT	0
633916	631368	11026G	PARTICIPANT	\N	PRESENT	0
633917	631368	19441R	PARTICIPANT	\N	PRESENT	0
633918	631368	04045F	PARTICIPANT	\N	PRESENT	1
633919	631368	10015M	PARTICIPANT	\N	PRESENT	0
633920	631368	14331P	PRESIDENT	0	PRESENT	0
633921	631368	14001X	PARTICIPANT	\N	PRESENT	0
633922	631368	19531S	PARTICIPANT	\N	PRESENT	1
633923	631368	20098N	PARTICIPANT	\N	PRESENT	0
633924	631368	20128B	PARTICIPANT	\N	PRESENT	1
633925	631368	12041X	PARTICIPANT	\N	EXCUSE	0
633926	631368	14189C	PARTICIPANT	\N	EXCUSE	0
633927	631368	14207L	PARTICIPANT	\N	EXCUSE	0
633928	631368	20094J	PARTICIPANT	\N	EXCUSE	0
633929	631368	08034U	PARTICIPANT	\N	PRESENT	0
634004	631368	14073Q	PARTICIPANT	\N	PRESENT	0
634423	634171	19735D	PARTICIPANT	\N	EXCUSE	0
634424	634171	19782L	PARTICIPANT	\N	EXCUSE	0
634425	634171	04045F	PARTICIPANT	\N	EXCUSE	0
634428	634171	14071N	PARTICIPANT	\N	EXCUSE	0
641370	641369	19479G	PARTICIPANT	\N	PRESENT	0
641404	641403	20094J	PARTICIPANT	\N	PRESENT	0
641405	641403	20104S	PARTICIPANT	\N	PRESENT	0
641406	641403	04042C	PARTICIPANT	\N	PRESENT	0
641407	641403	18083K	PARTICIPANT	\N	PRESENT	0
641408	641403	08015R	PARTICIPANT	\N	PRESENT	0
641409	641403	01048V	PARTICIPANT	\N	PRESENT	0
641412	641403	14059S	PARTICIPANT	\N	PRESENT	0
641413	641403	19573D	PARTICIPANT	\N	PRESENT	0
641414	641403	19349W	PARTICIPANT	\N	PRESENT	0
641415	641403	20054A	PARTICIPANT	\N	PRESENT	0
641416	641403	20064C	PARTICIPANT	\N	PRESENT	0
641417	641403	05012A	PARTICIPANT	\N	PRESENT	0
641418	641403	04035D	PARTICIPANT	\N	PRESENT	0
641421	641420	05008E	PARTICIPANT	\N	PRESENT	0
641422	641420	11053K	PARTICIPANT	\N	PRESENT	0
641423	641420	01028R	PARTICIPANT	\N	PRESENT	0
643144	643041	14089Y	PARTICIPANT	\N	PRESENT	0
643145	643041	20104S	PARTICIPANT	\N	PRESENT	0
643146	643041	11101A	PARTICIPANT	\N	PRESENT	0
643147	643041	19701S	PARTICIPANT	\N	PRESENT	0
643148	643041	11083R	PARTICIPANT	\N	PRESENT	0
643149	643041	19725B	PARTICIPANT	\N	PRESENT	0
643150	643041	14073Q	PARTICIPANT	\N	PRESENT	0
643151	643041	19711U	PARTICIPANT	\N	PRESENT	0
643152	643041	11026G	PARTICIPANT	\N	PRESENT	0
643153	643041	04057K	PARTICIPANT	\N	PRESENT	0
643154	643041	14001X	PARTICIPANT	\N	EXCUSE	0
643155	643041	20098N	PARTICIPANT	\N	PRESENT	0
643156	643041	04045F	PARTICIPANT	\N	PRESENT	1
643157	643041	14331P	PRESIDENT	0	PRESENT	0
643158	643041	10015M	PARTICIPANT	\N	PRESENT	0
643159	643041	14237S	PARTICIPANT	\N	PRESENT	1
643160	643041	20286Q	PARTICIPANT	\N	PRESENT	0
643161	643041	14357A	PARTICIPANT	\N	PRESENT	0
643162	643041	19563B	PARTICIPANT	\N	EXCUSE	0
643163	643041	14026U	PARTICIPANT	\N	EXCUSE	0
643206	643205	04047H	PARTICIPANT	\N	PRESENT	0
643207	643205	14053L	PARTICIPANT	\N	PRESENT	0
643208	643205	11066Q	PARTICIPANT	\N	PRESENT	0
643218	642984	20042V	PARTICIPANT	\N	PRESENT	0
643219	642984	19347U	PARTICIPANT	\N	PRESENT	1
643220	642984	95041E	PARTICIPANT	\N	EXCUSE	0
643563	643561	19725B	PARTICIPANT	\N	PRESENT	0
643564	643561	14147R	PARTICIPANT	\N	PRESENT	0
643566	643565	19725B	PARTICIPANT	\N	PRESENT	0
643567	643565	14147R	PARTICIPANT	\N	PRESENT	0
643568	643565	20128B	PARTICIPANT	\N	PRESENT	0
643570	643569	19725B	PARTICIPANT	\N	PRESENT	0
643571	643569	14147R	PARTICIPANT	\N	PRESENT	0
643786	643785	19725B	PARTICIPANT	\N	PRESENT	0
643787	643785	19447X	PARTICIPANT	\N	PRESENT	0
643788	643785	20132W	PARTICIPANT	\N	PRESENT	0
643789	643785	19643A	PARTICIPANT	\N	PRESENT	0
643791	643790	19629C	PARTICIPANT	\N	PRESENT	0
643792	643790	19954N	PARTICIPANT	\N	PRESENT	0
643793	643790	14215L	PARTICIPANT	\N	PRESENT	0
643836	643719	20074E	PARTICIPANT	\N	PRESENT	0
643837	643719	04047H	PRESIDENT	0	PRESENT	0
643838	643719	14053L	PARTICIPANT	\N	PRESENT	0
643840	643719	05008E	PARTICIPANT	\N	PRESENT	0
643841	643719	01028R	PARTICIPANT	\N	PRESENT	0
643891	643719	20034V	PARTICIPANT	\N	PRESENT	1
643892	643719	10015M	PARTICIPANT	\N	PRESENT	1
643893	643719	19301E	PARTICIPANT	\N	PRESENT	1
643894	643719	19717B	PARTICIPANT	\N	PRESENT	1
643895	643719	20150Y	PARTICIPANT	\N	PRESENT	1
643896	643719	14147R	PARTICIPANT	\N	PRESENT	1
643897	643719	14151M	PARTICIPANT	\N	PRESENT	1
643899	643898	20124W	PARTICIPANT	\N	PRESENT	1
643900	643898	20026V	PARTICIPANT	\N	PRESENT	0
643901	643898	19593H	PARTICIPANT	\N	PRESENT	0
643903	643902	20026V	PARTICIPANT	\N	PRESENT	0
643904	643902	19593H	PARTICIPANT	\N	PRESENT	0
643923	643652	10006L	PRESIDENT	0	PRESENT	0
643924	643652	14213J	PARTICIPANT	\N	PRESENT	1
643925	643652	14223L	PARTICIPANT	\N	PRESENT	1
643926	643652	19798U	PARTICIPANT	\N	PRESENT	1
643927	643652	11103C	PARTICIPANT	\N	PRESENT	1
643928	643652	20090E	PARTICIPANT	\N	PRESENT	0
643929	643652	14071N	PARTICIPANT	\N	PRESENT	0
643930	643652	19683J	PARTICIPANT	\N	PRESENT	0
643931	643652	19691J	PARTICIPANT	\N	PRESENT	0
643932	643652	11097X	PARTICIPANT	\N	PRESENT	0
643933	643652	04043D	PARTICIPANT	\N	PRESENT	1
643934	643652	04092N	PARTICIPANT	\N	PRESENT	0
643935	643652	17779H	PARTICIPANT	\N	PRESENT	0
643936	643652	19703U	PARTICIPANT	\N	PRESENT	1
643937	643652	11031D	PARTICIPANT	\N	PRESENT	1
643938	643652	19569H	PARTICIPANT	\N	PRESENT	1
643939	643652	19723Y	PARTICIPANT	\N	PRESENT	0
643940	643652	19697Q	PARTICIPANT	\N	PRESENT	1
643941	643652	14042U	PARTICIPANT	\N	PRESENT	1
643946	643652	11067R	PARTICIPANT	\N	PRESENT	0
643947	643652	19367Y	PARTICIPANT	\N	EXCUSE	0
644010	643720	10015M	PARTICIPANT	\N	PRESENT	1
644011	643720	11026G	PARTICIPANT	\N	PRESENT	1
644012	643720	19543W	PARTICIPANT	\N	PRESENT	1
644013	643720	04047H	PRESIDENT	0	PRESENT	0
644014	643720	01028R	PARTICIPANT	\N	PRESENT	0
644015	643720	14231L	PARTICIPANT	\N	PRESENT	0
644016	643720	05008E	PARTICIPANT	\N	PRESENT	0
644038	643839	19593H	PARTICIPANT	\N	PRESENT	0
644018	643720	14147R	PARTICIPANT	\N	PRESENT	1
644019	643720	14179A	PARTICIPANT	\N	PRESENT	1
644020	643720	20022R	PARTICIPANT	\N	PRESENT	0
644021	643720	14021P	PARTICIPANT	\N	PRESENT	0
644035	643720	11010L	PARTICIPANT	\N	PRESENT	0
644037	643720	17023S	PARTICIPANT	\N	PRESENT	0
644039	643839	19643A	PARTICIPANT	\N	PRESENT	0
644040	643839	20132W	PARTICIPANT	\N	PRESENT	0
644041	643839	19699S	PARTICIPANT	\N	PRESENT	0
644042	643839	19533U	PARTICIPANT	\N	PRESENT	0
644043	643839	19611R	PRESIDENT	0	PRESENT	0
644044	643839	20138D	PARTICIPANT	\N	PRESENT	0
644045	643839	20048C	PARTICIPANT	\N	PRESENT	0
644046	643839	19399H	PARTICIPANT	\N	PRESENT	0
644047	643839	20152B	PARTICIPANT	\N	PRESENT	0
644048	643839	14229S	PARTICIPANT	\N	PRESENT	0
644049	643839	20058E	PARTICIPANT	\N	PRESENT	0
644050	643839	20098N	PARTICIPANT	\N	PRESENT	0
644051	643839	19573D	PARTICIPANT	\N	PRESENT	0
644052	643839	04059M	PARTICIPANT	\N	PRESENT	0
644053	643839	20026V	PARTICIPANT	\N	PRESENT	0
644054	643839	20084G	PARTICIPANT	\N	PRESENT	0
644055	643839	19621T	PARTICIPANT	\N	PRESENT	0
644056	643839	14073Q	PARTICIPANT	\N	EXCUSE	0
648675	647518	04085P	PARTICIPANT	\N	PRESENT	1
648676	647518	08018U	PARTICIPANT	\N	EXCUSE	0
648677	647518	17737W	PARTICIPANT	\N	PRESENT	1
648681	647518	20074E	PARTICIPANT	\N	PRESENT	1
648682	647518	20128B	PARTICIPANT	\N	PRESENT	1
648683	647518	14179A	PARTICIPANT	\N	PRESENT	1
648684	647518	19447X	PARTICIPANT	\N	PRESENT	0
648685	647518	10015M	PARTICIPANT	\N	PRESENT	1
648686	647518	14107H	PARTICIPANT	\N	PRESENT	1
648687	647518	19675J	PARTICIPANT	\N	PRESENT	1
648726	647641	20266L	PARTICIPANT	\N	PRESENT	0
648744	647641	04057K	PARTICIPANT	\N	PRESENT	0
648754	647641	17965H	PARTICIPANT	\N	PRESENT	0
648766	647519	17737W	PARTICIPANT	\N	PRESENT	1
648767	647519	20074E	PARTICIPANT	\N	PRESENT	1
648768	647519	20128B	PARTICIPANT	\N	PRESENT	1
648769	647519	14179A	PARTICIPANT	\N	PRESENT	1
648770	647519	19675J	PARTICIPANT	\N	PRESENT	1
648771	647519	08018U	PARTICIPANT	\N	EXCUSE	0
649875	647959	20136B	PARTICIPANT	\N	PRESENT	0
649876	647959	14031R	PARTICIPANT	\N	PRESENT	0
649877	647959	19599P	PARTICIPANT	\N	PRESENT	0
649878	647959	05012A	PARTICIPANT	\N	PRESENT	0
649879	647959	19681G	PARTICIPANT	\N	PRESENT	0
649880	647959	17229F	PARTICIPANT	\N	PRESENT	0
649881	648781	20110Q	PARTICIPANT	\N	PRESENT	0
649882	648781	20114U	PARTICIPANT	\N	PRESENT	0
649883	648781	19749K	PARTICIPANT	\N	PRESENT	0
649884	647959	20096L	PARTICIPANT	\N	PRESENT	0
649885	647959	20032T	PARTICIPANT	\N	PRESENT	0
649886	647959	11065P	PARTICIPANT	\N	PRESENT	0
649887	647959	20122U	PARTICIPANT	\N	PRESENT	0
649889	648781	19489J	PARTICIPANT	\N	PRESENT	0
649890	648781	19725B	PARTICIPANT	\N	EXCUSE	0
649891	647959	19549D	PARTICIPANT	\N	PRESENT	0
649892	649090	11012A	PARTICIPANT	\N	PRESENT	0
649893	647959	19637C	PARTICIPANT	\N	EXCUSE	0
649894	647959	20068G	PARTICIPANT	\N	PRESENT	0
649895	647959	14237S	PARTICIPANT	\N	PRESENT	0
649896	647959	19577H	PARTICIPANT	\N	PRESENT	1
649897	647959	19701S	PARTICIPANT	\N	PRESENT	0
649898	647959	19820Y	PARTICIPANT	\N	PRESENT	0
649899	649090	19531S	PARTICIPANT	\N	PRESENT	0
649900	648781	08018U	PARTICIPANT	\N	PRESENT	0
649901	647959	19768N	PARTICIPANT	\N	PRESENT	0
649902	647959	19515S	PARTICIPANT	\N	PRESENT	0
649903	647959	19782L	PARTICIPANT	\N	PRESENT	0
649904	647959	19866P	PARTICIPANT	\N	PRESENT	0
649905	647959	20018V	PARTICIPANT	\N	PRESENT	0
649906	647959	14038Y	PARTICIPANT	\N	PRESENT	0
649907	647959	14187A	PARTICIPANT	\N	PRESENT	0
649908	647959	20054A	PARTICIPANT	\N	PRESENT	0
649909	647959	14207L	PARTICIPANT	\N	PRESENT	0
649910	647959	14257W	PARTICIPANT	\N	PRESENT	0
649911	647959	20092G	PARTICIPANT	\N	PRESENT	0
649912	647959	01043Q	PARTICIPANT	\N	PRESENT	0
649913	647959	14357A	PARTICIPANT	\N	PRESENT	0
649914	647959	19413M	PARTICIPANT	\N	PRESENT	0
649915	647959	04045F	PARTICIPANT	\N	PRESENT	0
649916	647959	19631V	PARTICIPANT	\N	PRESENT	0
649917	647959	19575F	PARTICIPANT	\N	PRESENT	0
649918	647959	19369B	PARTICIPANT	\N	PRESENT	0
649919	647959	19511N	PARTICIPANT	\N	PRESENT	0
649920	647959	14329V	PARTICIPANT	\N	PRESENT	0
649921	647959	14033T	PARTICIPANT	\N	PRESENT	0
649922	647959	19507S	PARTICIPANT	\N	PRESENT	0
649923	647959	20286Q	PARTICIPANT	\N	PRESENT	0
649924	647959	19441R	PARTICIPANT	\N	PRESENT	0
649925	647959	19695N	PARTICIPANT	\N	PRESENT	0
649926	647959	20060X	PARTICIPANT	\N	PRESENT	0
649927	647959	20062A	PARTICIPANT	\N	PRESENT	0
649928	647959	20078J	PARTICIPANT	\N	PRESENT	0
649929	647959	08015R	PARTICIPANT	\N	PRESENT	0
649930	647959	08028W	PARTICIPANT	\N	PRESENT	0
649931	647959	19467C	PARTICIPANT	\N	PRESENT	0
649932	647959	20144B	PARTICIPANT	\N	PRESENT	0
649933	647959	14205J	PARTICIPANT	\N	PRESENT	0
649934	647959	19747H	PARTICIPANT	\N	PRESENT	0
649935	647959	11077T	PARTICIPANT	\N	PRESENT	1
649936	647959	14251Q	PARTICIPANT	\N	PRESENT	1
649937	647959	20094J	PARTICIPANT	\N	PRESENT	1
649938	647959	01025N	PARTICIPANT	\N	PRESENT	0
649939	647959	19383Y	PARTICIPANT	\N	PRESENT	0
649940	648781	19581D	PARTICIPANT	\N	PRESENT	0
649941	647948	19766L	PARTICIPANT	\N	PRESENT	0
649942	647948	04070G	PARTICIPANT	\N	PRESENT	1
649943	647948	19699S	PARTICIPANT	\N	PRESENT	0
649944	647948	19533U	PARTICIPANT	\N	PRESENT	0
649945	647948	14229S	PARTICIPANT	\N	PRESENT	0
649946	647948	20098N	PARTICIPANT	\N	PRESENT	0
649947	647948	20112S	PARTICIPANT	\N	PRESENT	0
649948	647948	20026V	PARTICIPANT	\N	PRESENT	0
649949	647948	19593H	PARTICIPANT	\N	PRESENT	0
649950	647948	20132W	PARTICIPANT	\N	PRESENT	0
649951	647948	14073Q	PARTICIPANT	\N	PRESENT	0
649952	647948	19611R	PRESIDENT	0	PRESENT	0
649953	647948	20138D	PARTICIPANT	\N	PRESENT	0
649954	647948	20142Y	PARTICIPANT	\N	PRESENT	0
649955	647948	20048C	PARTICIPANT	\N	PRESENT	0
649956	647948	19693L	PARTICIPANT	\N	PRESENT	0
649957	647948	19399H	PARTICIPANT	\N	PRESENT	0
649958	647948	20052X	PARTICIPANT	\N	PRESENT	0
649959	647948	20172F	PARTICIPANT	\N	PRESENT	0
649960	647948	20058E	PARTICIPANT	\N	PRESENT	0
649961	647948	14030Q	PARTICIPANT	\N	PRESENT	0
649962	647948	20056C	PARTICIPANT	\N	PRESENT	0
649963	647948	20180F	PARTICIPANT	\N	PRESENT	0
649964	647948	20264J	PARTICIPANT	\N	PRESENT	0
649965	647948	19735D	PARTICIPANT	\N	PRESENT	0
649966	647948	14109K	PARTICIPANT	\N	PRESENT	1
649967	647948	11043H	PARTICIPANT	\N	PRESENT	0
649968	647948	19758L	PARTICIPANT	\N	PRESENT	0
649969	647948	20084G	PARTICIPANT	\N	PRESENT	0
650039	649773	19768N	PARTICIPANT	\N	PRESENT	0
650040	649773	19515S	PARTICIPANT	\N	PRESENT	0
650041	649773	19782L	PARTICIPANT	\N	PRESENT	0
650042	649773	11077T	PARTICIPANT	\N	PRESENT	1
650043	649773	19441R	PARTICIPANT	\N	PRESENT	0
650044	649773	19866P	PARTICIPANT	\N	PRESENT	0
650045	649773	20018V	PARTICIPANT	\N	PRESENT	0
650046	649773	14038Y	PARTICIPANT	\N	PRESENT	0
650047	649773	14187A	PRESIDENT	0	PRESENT	0
650048	649773	19695N	PARTICIPANT	\N	PRESENT	0
650049	649773	01025N	PARTICIPANT	\N	PRESENT	1
650050	649773	20054A	PARTICIPANT	\N	PRESENT	0
650051	649773	20060X	PARTICIPANT	\N	PRESENT	0
650052	649773	20062A	PARTICIPANT	\N	PRESENT	0
650053	649773	14251Q	PARTICIPANT	\N	PRESENT	0
650054	649773	14207L	PARTICIPANT	\N	PRESENT	0
650055	649773	14257W	PARTICIPANT	\N	PRESENT	0
650056	649773	19383Y	PARTICIPANT	\N	PRESENT	0
650057	649773	20092G	PARTICIPANT	\N	PRESENT	0
650058	649773	01043Q	PARTICIPANT	\N	PRESENT	0
650059	649773	14357A	PARTICIPANT	\N	PRESENT	0
650060	649773	20078J	PARTICIPANT	\N	PRESENT	0
650061	649773	19413M	PARTICIPANT	\N	PRESENT	0
650062	649773	20082E	PARTICIPANT	\N	PRESENT	0
650063	649773	20094J	PARTICIPANT	\N	PRESENT	1
650064	649773	04045F	PARTICIPANT	\N	PRESENT	0
650065	649773	19631V	PARTICIPANT	\N	PRESENT	0
650066	649773	08015R	PARTICIPANT	\N	PRESENT	0
650067	649773	19575F	PARTICIPANT	\N	PRESENT	0
650068	649773	19369B	PARTICIPANT	\N	PRESENT	0
650069	649773	19511N	PARTICIPANT	\N	PRESENT	0
650070	649773	08028W	PARTICIPANT	\N	PRESENT	0
650071	649773	14329V	PARTICIPANT	\N	PRESENT	0
650072	649773	19467C	PARTICIPANT	\N	PRESENT	0
650073	649773	20144B	PARTICIPANT	\N	PRESENT	0
650074	649773	14033T	PARTICIPANT	\N	PRESENT	0
650132	648783	19649G	PARTICIPANT	\N	PRESENT	0
650076	649773	14205J	PARTICIPANT	\N	PRESENT	0
650133	648783	20074E	PARTICIPANT	\N	PRESENT	0
650079	649773	19507S	PARTICIPANT	\N	PRESENT	0
650080	649773	20286Q	PARTICIPANT	\N	PRESENT	0
650081	649773	19747H	PARTICIPANT	\N	PRESENT	0
650130	648783	04047H	PRESIDENT	0	PRESENT	0
650131	648783	14001X	PARTICIPANT	\N	EXCUSE	0
630481	629124	20064C	PARTICIPANT	\N	PRESENT	0
630482	629124	14267Y	PARTICIPANT	\N	PRESENT	0
630483	629124	11064N	PARTICIPANT	\N	PRESENT	0
630484	629124	11083R	PARTICIPANT	\N	PRESENT	0
630485	629124	14255U	PARTICIPANT	\N	PRESENT	0
630486	629124	17023S	PARTICIPANT	\N	PRESENT	1
630540	629207	14053L	PARTICIPANT	\N	PRESENT	0
630541	629207	11056N	PARTICIPANT	\N	PRESENT	0
630542	629207	20074E	PARTICIPANT	\N	PRESENT	0
630543	629207	14215L	PARTICIPANT	\N	PRESENT	0
630544	629207	04047H	PRESIDENT	0	PRESENT	0
630545	629207	19673G	PARTICIPANT	\N	PRESENT	0
630546	629207	19954N	PARTICIPANT	\N	PRESENT	0
630547	629207	05008E	PARTICIPANT	\N	PRESENT	0
630548	629207	14089Y	PARTICIPANT	\N	PRESENT	0
630549	629207	14147R	PARTICIPANT	\N	PRESENT	0
630550	629207	20022R	PARTICIPANT	\N	PRESENT	0
630551	629207	19489J	PARTICIPANT	\N	PRESENT	0
630552	629207	14151M	PARTICIPANT	\N	PRESENT	0
630553	629207	17737W	PARTICIPANT	\N	PRESENT	0
630554	629310	86034E	PARTICIPANT	\N	PRESENT	0
630555	630539	19643A	PARTICIPANT	\N	PRESENT	0
630556	630539	19533U	PRESIDENT	0	PRESENT	0
630557	630539	19798U	PARTICIPANT	\N	PRESENT	0
630558	630539	19820Y	PARTICIPANT	\N	PRESENT	0
630559	630539	14207L	PARTICIPANT	\N	PRESENT	0
630560	630539	19693L	PARTICIPANT	\N	PRESENT	0
630561	630539	19599P	PARTICIPANT	\N	PRESENT	0
630562	630539	20124W	PARTICIPANT	\N	PRESENT	0
630563	630539	20112S	PARTICIPANT	\N	PRESENT	1
630564	629310	17589D	PARTICIPANT	\N	PRESENT	0
630565	629310	14195A	PARTICIPANT	\N	PRESENT	0
630566	629310	11041F	PARTICIPANT	\N	PRESENT	0
630567	629310	14259Y	PARTICIPANT	\N	PRESENT	0
630568	629310	14173T	PARTICIPANT	\N	PRESENT	0
630569	629310	08028W	PARTICIPANT	\N	PRESENT	0
630570	629310	20090E	PARTICIPANT	\N	PRESENT	0
630571	629310	19762G	PARTICIPANT	\N	PRESENT	0
630572	629310	20110Q	PARTICIPANT	\N	PRESENT	0
630573	629310	20116W	PARTICIPANT	\N	PRESENT	0
630574	629310	19545Y	PARTICIPANT	\N	PRESENT	0
630575	629310	19565D	PARTICIPANT	\N	PRESENT	0
630576	629310	01048V	PARTICIPANT	\N	PRESENT	0
630577	629310	17229F	PARTICIPANT	\N	PRESENT	0
630578	629310	19659J	PARTICIPANT	\N	PRESENT	0
630579	629310	19683J	PARTICIPANT	\N	PRESENT	0
630580	629310	04092N	PARTICIPANT	\N	PRESENT	0
630581	629310	11067R	PARTICIPANT	\N	PRESENT	0
630582	629310	20024T	PARTICIPANT	\N	PRESENT	0
630583	629310	14033T	PARTICIPANT	\N	PRESENT	0
630584	629310	19675J	PARTICIPANT	\N	PRESENT	0
630585	629310	19383Y	PARTICIPANT	\N	PRESENT	0
630586	629310	14231L	PARTICIPANT	\N	PRESENT	0
630587	629310	19643A	PARTICIPANT	\N	PRESENT	0
630588	629310	19745F	PARTICIPANT	\N	PRESENT	0
630589	629310	17737W	PARTICIPANT	\N	PRESENT	0
630590	629310	19511N	PARTICIPANT	\N	PRESENT	0
630591	629310	19443T	PARTICIPANT	\N	PRESENT	0
630592	629310	20148F	PARTICIPANT	\N	PRESENT	0
630593	629310	19703U	PARTICIPANT	\N	PRESENT	0
630594	629310	20252E	PARTICIPANT	\N	PRESENT	0
630595	629310	19585H	PARTICIPANT	\N	PRESENT	0
630596	629310	19798U	PARTICIPANT	\N	PRESENT	0
630597	629310	20056C	PARTICIPANT	\N	PRESENT	0
630598	629310	20026V	PARTICIPANT	\N	PRESENT	0
630599	629310	20132W	PARTICIPANT	\N	PRESENT	0
630600	629310	19525U	PARTICIPANT	\N	PRESENT	0
630601	629310	19467C	PARTICIPANT	\N	PRESENT	0
630602	629310	19695N	PARTICIPANT	\N	PRESENT	0
630603	629310	14121F	PARTICIPANT	\N	PRESENT	0
630604	629310	17367Q	PARTICIPANT	\N	PRESENT	0
630605	629310	99004R	PARTICIPANT	\N	PRESENT	0
630606	629310	20062A	PARTICIPANT	\N	PRESENT	0
630607	629310	19479G	PARTICIPANT	\N	PRESENT	0
630608	629310	19399H	PARTICIPANT	\N	PRESENT	0
630609	629310	20298U	PARTICIPANT	\N	PRESENT	0
630610	629310	19329S	PARTICIPANT	\N	PRESENT	0
630611	629310	14207L	PARTICIPANT	\N	PRESENT	0
630612	629310	20144B	PARTICIPANT	\N	PRESENT	0
630613	629310	11066Q	PARTICIPANT	\N	PRESENT	0
630614	629310	19599P	PARTICIPANT	\N	PRESENT	0
630615	629310	14257W	PARTICIPANT	\N	PRESENT	0
630616	629310	19333N	PARTICIPANT	\N	PRESENT	0
630617	629310	19820Y	PARTICIPANT	\N	PRESENT	0
630618	629310	20036X	PARTICIPANT	\N	PRESENT	0
630620	629310	92040Q	PARTICIPANT	\N	PRESENT	0
630621	629310	19533U	PARTICIPANT	\N	PRESENT	0
630622	629310	20108W	PARTICIPANT	\N	PRESENT	0
630623	629310	19629C	PARTICIPANT	\N	PRESENT	0
630624	629310	19691J	PARTICIPANT	\N	PRESENT	0
630625	629310	08009T	PARTICIPANT	\N	PRESENT	0
630626	629310	14133K	PARTICIPANT	\N	PRESENT	0
630627	629310	19679N	PARTICIPANT	\N	PRESENT	0
630628	629310	11097X	PARTICIPANT	\N	PRESENT	0
630629	629310	20032T	PARTICIPANT	\N	PRESENT	0
630630	629310	11080N	PARTICIPANT	\N	PRESENT	0
630631	629310	14038Y	PARTICIPANT	\N	PRESENT	0
630632	629310	14329V	PARTICIPANT	\N	PRESENT	0
630633	629310	19719D	PARTICIPANT	\N	PRESENT	0
630634	629310	08060W	PARTICIPANT	\N	PRESENT	0
630635	629310	20142Y	PARTICIPANT	\N	PRESENT	0
630636	629310	14221J	PARTICIPANT	\N	PRESENT	0
630637	629310	14111D	PARTICIPANT	\N	PRESENT	0
630638	629310	20050V	PARTICIPANT	\N	PRESENT	0
630639	629310	04045F	PARTICIPANT	\N	PRESENT	0
630640	629310	20248J	PARTICIPANT	\N	PRESENT	0
630641	629310	11085T	PARTICIPANT	\N	PRESENT	0
630642	629310	14089Y	PARTICIPANT	\N	PRESENT	0
630643	629310	19739H	PARTICIPANT	\N	PRESENT	0
630644	629310	12041X	PARTICIPANT	\N	PRESENT	0
630645	629310	19611R	PARTICIPANT	\N	PRESENT	0
630646	629310	20102Q	PARTICIPANT	\N	PRESENT	0
630647	629310	20088L	PARTICIPANT	\N	PRESENT	0
630648	629310	19687N	PARTICIPANT	\N	PRESENT	0
630649	629310	19758L	PARTICIPANT	\N	PRESENT	0
630650	629310	95063L	PARTICIPANT	\N	PRESENT	0
630651	629310	12028B	PARTICIPANT	\N	PRESENT	0
630652	629310	17779H	PARTICIPANT	\N	PRESENT	0
630653	629310	20042V	PARTICIPANT	\N	PRESENT	0
630654	629310	20052X	PARTICIPANT	\N	PRESENT	0
630655	629310	14030Q	PARTICIPANT	\N	PRESENT	0
630656	629310	11040E	PARTICIPANT	\N	PRESENT	0
630657	629310	11056N	PARTICIPANT	\N	PRESENT	0
630658	629310	04085P	PARTICIPANT	\N	PRESENT	0
630659	629310	14249W	PARTICIPANT	\N	PRESENT	0
630660	629310	08061X	PARTICIPANT	\N	PRESENT	0
630661	629310	19619A	PARTICIPANT	\N	PRESENT	0
630662	629310	20020P	PARTICIPANT	\N	PRESENT	0
630663	629310	11048N	PARTICIPANT	\N	PRESENT	0
630664	629310	14053L	PARTICIPANT	\N	PRESENT	0
630665	629310	11072N	PARTICIPANT	\N	PRESENT	0
630666	629310	19699S	PARTICIPANT	\N	PRESENT	0
630667	629310	19563B	PARTICIPANT	\N	PRESENT	0
630668	629310	04057K	PARTICIPANT	\N	PRESENT	0
630669	629310	20080C	PARTICIPANT	\N	PRESENT	0
630670	629310	20264J	PARTICIPANT	\N	PRESENT	0
630671	629310	19760E	PARTICIPANT	\N	PRESENT	0
630672	629310	20174H	PARTICIPANT	\N	PRESENT	0
630673	629310	19711U	PARTICIPANT	\N	PRESENT	0
630674	629310	01043Q	PARTICIPANT	\N	PRESENT	0
630675	629310	04008A	PARTICIPANT	\N	PRESENT	0
630676	629310	19697Q	PARTICIPANT	\N	PRESENT	0
630677	629310	17637T	PARTICIPANT	\N	PRESENT	0
630678	629310	20128B	PARTICIPANT	\N	PRESENT	0
630679	629310	19549D	PARTICIPANT	\N	PRESENT	0
630680	629310	14229S	PARTICIPANT	\N	PRESENT	0
630681	629310	19349W	PARTICIPANT	\N	PRESENT	0
630682	629310	04059M	PARTICIPANT	\N	PRESENT	0
630683	629310	19593H	PARTICIPANT	\N	PRESENT	0
630684	629310	20030R	PARTICIPANT	\N	PRESENT	0
630685	629310	20064C	PARTICIPANT	\N	PRESENT	0
630686	629310	14026U	PARTICIPANT	\N	PRESENT	0
630687	629310	20018V	PARTICIPANT	\N	PRESENT	0
630688	629310	04047H	PARTICIPANT	\N	PRESENT	0
630689	629310	19347U	PARTICIPANT	\N	PRESENT	0
630690	629310	08010L	PARTICIPANT	\N	PRESENT	0
630691	629310	20092G	PARTICIPANT	\N	PRESENT	0
630692	629310	19689Q	PARTICIPANT	\N	PRESENT	0
630693	629310	01058X	PARTICIPANT	\N	PRESENT	0
630694	629310	20076G	PARTICIPANT	\N	PRESENT	0
642075	641654	14111D	PARTICIPANT	\N	PRESENT	0
642076	641654	11056N	PARTICIPANT	\N	PRESENT	0
642077	641654	14179A	PARTICIPANT	\N	PRESENT	0
642078	641654	14107H	PARTICIPANT	\N	PRESENT	0
642079	641654	14215L	PARTICIPANT	\N	PRESENT	0
642080	641654	20110Q	PARTICIPANT	\N	PRESENT	0
642081	641654	14053L	PARTICIPANT	\N	PRESENT	0
642082	641657	04047H	PARTICIPANT	\N	PRESENT	0
642083	641657	01028R	PARTICIPANT	\N	PRESENT	0
642084	641657	14111D	PARTICIPANT	\N	PRESENT	0
642085	641657	14053L	PARTICIPANT	\N	PRESENT	0
642086	641657	14215L	PARTICIPANT	\N	PRESENT	0
642087	641657	14107H	PARTICIPANT	\N	PRESENT	0
642088	641657	14147R	PARTICIPANT	\N	PRESENT	0
642089	641657	20110Q	PARTICIPANT	\N	PRESENT	0
642090	641657	11056N	PARTICIPANT	\N	PRESENT	0
642091	641660	04047H	PARTICIPANT	\N	PRESENT	0
642092	641660	01028R	PARTICIPANT	\N	PRESENT	0
642093	641660	14111D	PARTICIPANT	\N	PRESENT	0
642094	641660	11085T	PARTICIPANT	\N	PRESENT	0
642095	641660	20110Q	PARTICIPANT	\N	PRESENT	0
642096	641660	11056N	PARTICIPANT	\N	PRESENT	0
642097	641660	14215L	PARTICIPANT	\N	PRESENT	0
642098	641663	04047H	PARTICIPANT	\N	PRESENT	0
642099	641663	20110Q	PARTICIPANT	\N	PRESENT	0
642100	641663	14215L	PARTICIPANT	\N	PRESENT	0
642101	641705	95063L	PARTICIPANT	\N	PRESENT	0
642102	641705	20110Q	PARTICIPANT	\N	PRESENT	0
642103	641705	04047H	PARTICIPANT	\N	PRESENT	0
642104	641705	01028R	PARTICIPANT	\N	PRESENT	0
642145	641999	19760E	PARTICIPANT	\N	PRESENT	0
642146	641999	11097X	PARTICIPANT	\N	PRESENT	0
642147	642000	19760E	PARTICIPANT	\N	PRESENT	0
642148	642000	11097X	PARTICIPANT	\N	PRESENT	0
642150	642003	19673G	PARTICIPANT	\N	PRESENT	0
642151	642003	04035D	PARTICIPANT	\N	PRESENT	0
642152	642003	11083R	PARTICIPANT	\N	PRESENT	0
642153	642003	08069G	PARTICIPANT	\N	PRESENT	0
642163	642162	19515S	PARTICIPANT	\N	PRESENT	0
642172	642162	19575F	PARTICIPANT	\N	PRESENT	0
642188	642187	19735D	PARTICIPANT	\N	PRESENT	0
642166	642162	07033P	PARTICIPANT	\N	PRESENT	0
642167	642162	14187A	PARTICIPANT	\N	PRESENT	0
642168	642162	20180F	PARTICIPANT	\N	PRESENT	0
642169	642162	14059S	PARTICIPANT	\N	PRESENT	0
642170	642162	20096L	PARTICIPANT	\N	PRESENT	0
642171	642162	14069U	PARTICIPANT	\N	PRESENT	0
642189	642187	19723Y	PARTICIPANT	\N	PRESENT	0
642363	642066	04057K	PARTICIPANT	\N	PRESENT	0
642364	642066	11067R	PARTICIPANT	\N	PRESENT	0
642365	642066	19760E	PARTICIPANT	\N	PRESENT	0
642366	642067	19760E	PARTICIPANT	\N	PRESENT	0
642367	642067	14195A	PARTICIPANT	\N	PRESENT	1
642368	642066	10006L	PRESIDENT	0	PRESENT	0
642369	642067	11103C	PARTICIPANT	\N	PRESENT	1
642370	642067	10006L	PARTICIPANT	\N	EXCUSE	0
642371	642067	14042U	PARTICIPANT	\N	PRESENT	0
642372	642066	14071N	PARTICIPANT	\N	EXCUSE	0
642373	642067	14026U	PARTICIPANT	\N	PRESENT	0
642374	642067	14213J	PARTICIPANT	\N	PRESENT	0
642375	642067	04092N	PARTICIPANT	\N	PRESENT	0
642376	642067	20130U	PARTICIPANT	\N	PRESENT	1
642377	642067	11097X	PRESIDENT	0	PRESENT	0
642378	642067	01034P	PARTICIPANT	\N	PRESENT	0
642379	642066	20090E	PARTICIPANT	\N	PRESENT	0
642380	642067	11067R	PARTICIPANT	\N	PRESENT	0
642381	642066	11097X	PARTICIPANT	\N	PRESENT	0
642382	642067	11031D	PARTICIPANT	\N	PRESENT	0
642383	642067	20090E	PARTICIPANT	\N	PRESENT	0
642384	642066	04043D	PARTICIPANT	\N	PRESENT	0
642385	642067	19798U	PARTICIPANT	\N	PRESENT	1
642386	642067	20248J	PARTICIPANT	\N	PRESENT	1
642387	642066	19415P	PARTICIPANT	\N	PRESENT	0
642388	642067	04043D	PARTICIPANT	\N	PRESENT	1
642389	642067	19723Y	PARTICIPANT	\N	PRESENT	1
642390	642066	20298U	PARTICIPANT	\N	PRESENT	0
642391	642066	14042U	PARTICIPANT	\N	PRESENT	0
642392	642066	20040T	PARTICIPANT	\N	PRESENT	0
642393	642066	14026U	PARTICIPANT	\N	PRESENT	0
642394	642066	04092N	PARTICIPANT	\N	PRESENT	0
642395	642066	14213J	PARTICIPANT	\N	PRESENT	0
642396	642066	20130U	PARTICIPANT	\N	PRESENT	1
642397	642066	19798U	PARTICIPANT	\N	PRESENT	1
642398	642066	19723Y	PARTICIPANT	\N	PRESENT	1
642399	642066	20248J	PARTICIPANT	\N	PRESENT	1
642400	642066	14195A	PARTICIPANT	\N	PRESENT	1
642401	642066	11103C	PARTICIPANT	\N	PRESENT	1
642436	642066	19553Y	PARTICIPANT	\N	PRESENT	0
642437	642066	18193Q	PARTICIPANT	\N	PRESENT	1
642438	642066	14223L	PARTICIPANT	\N	PRESENT	1
642468	642465	11090Q	PARTICIPANT	\N	PRESENT	0
642469	642465	20286Q	PARTICIPANT	\N	PRESENT	0
642470	642465	14257W	PARTICIPANT	\N	PRESENT	0
642471	642466	20286Q	PARTICIPANT	\N	PRESENT	0
642472	642466	14257W	PARTICIPANT	\N	PRESENT	0
642473	642467	11090Q	PARTICIPANT	\N	PRESENT	0
642474	642467	20286Q	PARTICIPANT	\N	PRESENT	0
642590	642001	19760E	PARTICIPANT	\N	PRESENT	0
642591	642001	14042U	PARTICIPANT	\N	PRESENT	0
642592	642001	14213J	PARTICIPANT	\N	PRESENT	0
642593	642001	11097X	PARTICIPANT	\N	PRESENT	0
642594	642002	19760E	PARTICIPANT	\N	PRESENT	0
642595	642002	11097X	PARTICIPANT	\N	PRESENT	0
642596	642002	18193Q	PARTICIPANT	\N	PRESENT	0
642599	642597	19697Q	PARTICIPANT	\N	PRESENT	0
642600	642597	19679N	PARTICIPANT	\N	PRESENT	0
642601	642597	14281W	PARTICIPANT	\N	EXCUSE	0
642602	641998	14189C	PARTICIPANT	\N	EXCUSE	0
642603	641998	20024T	PARTICIPANT	\N	PRESENT	1
642604	641998	14030Q	PARTICIPANT	\N	PRESENT	0
642605	641998	20138D	PARTICIPANT	\N	PRESENT	0
642606	641998	17737W	PARTICIPANT	\N	EXCUSE	0
642607	641998	19621T	PARTICIPANT	\N	EXCUSE	0
642608	641998	11031D	PARTICIPANT	\N	PRESENT	0
642609	641998	20106U	PARTICIPANT	\N	EXCUSE	0
642610	641998	14179A	PARTICIPANT	\N	PRESENT	1
642611	641998	20118Y	PARTICIPANT	\N	EXCUSE	0
642612	641998	20130U	PARTICIPANT	\N	EXCUSE	0
642613	641998	19798U	PARTICIPANT	\N	PRESENT	1
642614	641998	11045K	PARTICIPANT	\N	PRESENT	0
642615	641998	20098N	PARTICIPANT	\N	EXCUSE	0
642616	641998	19749K	PARTICIPANT	\N	PRESENT	1
642684	642186	19631V	PARTICIPANT	\N	EXCUSE	0
642685	642186	05008E	PARTICIPANT	\N	EXCUSE	0
642686	642186	19715Y	PRESIDENT	0	PRESENT	0
642688	642687	19447X	PARTICIPANT	\N	PRESENT	0
642689	642687	19725B	PARTICIPANT	\N	PRESENT	0
642690	642687	14147R	PARTICIPANT	\N	PRESENT	0
642870	642186	08073C	PARTICIPANT	\N	EXCUSE	0
642872	642871	14217N	PARTICIPANT	\N	PRESENT	0
642873	642871	20248J	PARTICIPANT	\N	PRESENT	0
642874	642871	11031D	PARTICIPANT	\N	PRESENT	0
642875	642871	20130U	PARTICIPANT	\N	PRESENT	0
642936	642877	19515S	PARTICIPANT	\N	PRESENT	0
642937	642877	20060X	PARTICIPANT	\N	PRESENT	0
642938	642877	20018V	PARTICIPANT	\N	PRESENT	0
642939	642877	11090Q	PARTICIPANT	\N	PRESENT	0
642996	642995	04059M	PARTICIPANT	\N	PRESENT	0
642997	642995	14073Q	PARTICIPANT	\N	PRESENT	0
642999	642998	19693L	PARTICIPANT	\N	PRESENT	0
643000	642998	19593H	PARTICIPANT	\N	PRESENT	0
643001	642998	14229S	PARTICIPANT	\N	PRESENT	0
643003	643002	19693L	PARTICIPANT	\N	PRESENT	0
643004	643002	19593H	PARTICIPANT	\N	PRESENT	0
643005	643002	19611R	PARTICIPANT	\N	PRESENT	0
643007	643006	19693L	PARTICIPANT	\N	PRESENT	0
643008	643006	19593H	PARTICIPANT	\N	PRESENT	0
643009	643002	14229S	PARTICIPANT	\N	PRESENT	0
643011	643010	14001X	PARTICIPANT	\N	PRESENT	0
643012	643010	20100N	PARTICIPANT	\N	PRESENT	0
643014	643013	11080N	PARTICIPANT	\N	PRESENT	0
643015	643013	14121F	PARTICIPANT	\N	PRESENT	0
627965	627963	19629C	PARTICIPANT	\N	PRESENT	0
627966	627963	14038Y	PARTICIPANT	\N	PRESENT	0
627968	627963	19575F	PARTICIPANT	\N	PRESENT	1
627969	627963	19782L	PARTICIPANT	\N	PRESENT	0
627970	627963	14187A	PARTICIPANT	\N	PRESENT	0
627971	627963	19725B	PARTICIPANT	\N	PRESENT	1
627972	627963	14179A	PARTICIPANT	\N	PRESENT	0
627973	627963	14205J	PARTICIPANT	\N	PRESENT	1
627974	627963	14147R	PARTICIPANT	\N	PRESENT	0
627975	627963	19563B	PARTICIPANT	\N	PRESENT	0
627976	627963	20028X	PARTICIPANT	\N	PRESENT	0
627977	627963	20092G	PARTICIPANT	\N	PRESENT	0
627988	627986	19575F	PARTICIPANT	\N	PRESENT	1
627989	627986	19782L	PARTICIPANT	\N	PRESENT	0
627992	627986	19629C	PARTICIPANT	\N	PRESENT	0
627993	627986	14038Y	PARTICIPANT	\N	PRESENT	0
627995	627986	14187A	PARTICIPANT	\N	PRESENT	0
627996	627986	19725B	PARTICIPANT	\N	PRESENT	1
627998	627986	14179A	PARTICIPANT	\N	PRESENT	0
627999	627986	14205J	PARTICIPANT	\N	PRESENT	1
628000	627986	14147R	PARTICIPANT	\N	PRESENT	0
628001	627986	19563B	PARTICIPANT	\N	PRESENT	0
628002	627986	20028X	PARTICIPANT	\N	PRESENT	0
628003	627986	20092G	PARTICIPANT	\N	PRESENT	0
628014	628012	19575F	PARTICIPANT	\N	PRESENT	1
628015	628012	19782L	PARTICIPANT	\N	PRESENT	0
628018	628012	19629C	PARTICIPANT	\N	PRESENT	0
628019	628012	14038Y	PARTICIPANT	\N	PRESENT	0
628020	628012	14187A	PARTICIPANT	\N	PRESENT	0
628022	628012	19725B	PARTICIPANT	\N	PRESENT	1
628024	628012	14179A	PARTICIPANT	\N	PRESENT	0
628025	628012	14205J	PARTICIPANT	\N	PRESENT	1
628026	628012	14147R	PARTICIPANT	\N	PRESENT	0
628027	628012	19563B	PARTICIPANT	\N	PRESENT	0
628028	628012	20028X	PARTICIPANT	\N	PRESENT	0
628029	628012	20092G	PARTICIPANT	\N	PRESENT	0
628553	627944	19798U	PARTICIPANT	\N	PRESENT	0
628554	627944	19533U	PRESIDENT	0	PRESENT	0
628556	627944	14207L	PARTICIPANT	\N	PRESENT	0
628567	628566	14083S	PRESIDENT	0	PRESENT	0
628568	628566	11064N	PARTICIPANT	\N	PRESENT	1
628569	628566	19717B	PARTICIPANT	\N	EXCUSE	0
628570	628566	20150Y	PARTICIPANT	\N	PRESENT	0
628573	628566	19447X	PARTICIPANT	\N	PRESENT	1
628587	628566	20102Q	PARTICIPANT	\N	PRESENT	0
632331	632330	14083S	PARTICIPANT	\N	PRESENT	0
632332	632330	20102Q	PARTICIPANT	\N	PRESENT	0
632333	632330	20150Y	PARTICIPANT	\N	PRESENT	0
632374	632330	19503N	PARTICIPANT	\N	PRESENT	0
632387	632330	17023S	PARTICIPANT	\N	PRESENT	0
632563	632561	14083S	PARTICIPANT	\N	PRESENT	0
632565	632561	19503N	PARTICIPANT	\N	PRESENT	0
632566	632561	20102Q	PARTICIPANT	\N	PRESENT	0
632568	632561	17023S	PARTICIPANT	\N	PRESENT	0
632570	632561	20150Y	PARTICIPANT	\N	PRESENT	0
634644	634643	20024T	PARTICIPANT	\N	PRESENT	0
634673	634533	04059M	PARTICIPANT	\N	PRESENT	0
634674	634533	19651A	PARTICIPANT	\N	PRESENT	1
644062	644061	11056N	PARTICIPANT	\N	PRESENT	0
644063	644061	19954N	PARTICIPANT	\N	PRESENT	0
644064	644061	19703U	PARTICIPANT	\N	PRESENT	0
634678	634533	11053K	PARTICIPANT	\N	PRESENT	1
644066	644065	11056N	PARTICIPANT	\N	PRESENT	0
644067	644065	19703U	PARTICIPANT	\N	PRESENT	0
644069	644068	11056N	PARTICIPANT	\N	PRESENT	0
644070	644068	19703U	PARTICIPANT	\N	PRESENT	0
634683	634533	19399H	PARTICIPANT	\N	EXCUSE	0
644072	644071	11056N	PARTICIPANT	\N	PRESENT	0
634685	634533	19611R	PRESIDENT	0	PRESENT	0
634686	634533	19699S	PARTICIPANT	\N	PRESENT	0
644073	644071	19954N	PARTICIPANT	\N	PRESENT	0
634688	634533	20142Y	PARTICIPANT	\N	PRESENT	0
634689	634533	19705W	PARTICIPANT	\N	PRESENT	1
634690	634533	14229S	PARTICIPANT	\N	PRESENT	1
644074	644071	19703U	PARTICIPANT	\N	PRESENT	0
634692	634533	20026V	PARTICIPANT	\N	PRESENT	1
644075	643650	14189C	PARTICIPANT	\N	EXCUSE	0
644076	643650	20024T	PARTICIPANT	\N	PRESENT	1
644077	643650	20080C	PARTICIPANT	\N	EXCUSE	0
644078	643650	20056C	PARTICIPANT	\N	EXCUSE	0
644079	643650	20118Y	PARTICIPANT	\N	EXCUSE	0
644080	643650	11031D	PARTICIPANT	\N	PRESENT	0
644081	643650	20138D	PARTICIPANT	\N	PRESENT	0
644082	643650	19749K	PRESIDENT	0	PRESENT	0
644083	643650	07029T	PARTICIPANT	\N	PRESENT	0
644084	643650	11045K	PARTICIPANT	\N	PRESENT	1
644085	643650	04035D	PARTICIPANT	\N	PRESENT	1
644086	643650	20114U	PARTICIPANT	\N	PRESENT	1
644087	643650	14179A	PARTICIPANT	\N	PRESENT	0
644105	643650	19798U	PARTICIPANT	\N	PRESENT	1
644106	643650	19527W	PARTICIPANT	\N	PRESENT	1
644153	643650	14030Q	PARTICIPANT	\N	EXCUSE	0
644247	644244	19593H	PARTICIPANT	\N	PRESENT	0
644248	644244	20026V	PARTICIPANT	\N	PRESENT	0
644250	644245	19593H	PARTICIPANT	\N	PRESENT	0
644251	644245	20026V	PARTICIPANT	\N	PRESENT	0
644290	644246	19593H	PARTICIPANT	\N	PRESENT	0
644291	644246	20026V	PARTICIPANT	\N	PRESENT	0
644623	644622	14030Q	PARTICIPANT	\N	PRESENT	0
644624	644622	20138D	PARTICIPANT	\N	PRESENT	1
644625	644622	11031D	PARTICIPANT	\N	PRESENT	0
644626	644622	11045K	PARTICIPANT	\N	PRESENT	0
644627	644622	20024T	PARTICIPANT	\N	PRESENT	0
644648	644407	14219Q	PARTICIPANT	\N	EXCUSE	0
644651	643942	19717B	PRESIDENT	0	PRESENT	0
644652	643942	19631V	PARTICIPANT	\N	PRESENT	0
644654	643942	05008E	PARTICIPANT	\N	PRESENT	0
644657	643942	19673G	PARTICIPANT	\N	PRESENT	0
644659	643942	20034V	PARTICIPANT	\N	PRESENT	0
644660	643942	14331P	PARTICIPANT	\N	EXCUSE	0
644661	643942	11043H	PARTICIPANT	\N	EXCUSE	0
644662	643942	19301E	PARTICIPANT	\N	PRESENT	0
644663	643944	14331P	PARTICIPANT	\N	EXCUSE	0
644674	644569	20094J	PARTICIPANT	\N	PRESENT	0
644675	644569	19701S	PARTICIPANT	\N	PRESENT	0
644676	644569	04035D	PARTICIPANT	\N	PRESENT	0
644677	644569	11083R	PARTICIPANT	\N	PRESENT	0
644678	644569	19333N	PARTICIPANT	\N	PRESENT	0
644679	644569	14097Y	PARTICIPANT	\N	PRESENT	0
644680	644569	14073Q	PARTICIPANT	\N	PRESENT	0
644681	644569	11026G	PARTICIPANT	\N	PRESENT	0
644682	644569	14331P	PRESIDENT	0	PRESENT	0
644683	644569	10015M	PARTICIPANT	\N	PRESENT	0
644684	644569	19563B	PARTICIPANT	\N	EXCUSE	0
644685	644569	14189C	PARTICIPANT	\N	EXCUSE	0
644686	644569	20104S	PARTICIPANT	\N	EXCUSE	0
644687	644569	14357A	PARTICIPANT	\N	EXCUSE	0
644688	644569	20286Q	PARTICIPANT	\N	EXCUSE	0
644689	644570	14189C	PARTICIPANT	\N	EXCUSE	0
644690	644570	20094J	PARTICIPANT	\N	PRESENT	0
644691	644570	20104S	PARTICIPANT	\N	EXCUSE	0
644692	644570	19701S	PARTICIPANT	\N	PRESENT	0
644693	644570	14357A	PARTICIPANT	\N	EXCUSE	0
644694	644570	04035D	PARTICIPANT	\N	PRESENT	0
644695	644570	11083R	PARTICIPANT	\N	PRESENT	0
644696	644570	20286Q	PARTICIPANT	\N	EXCUSE	0
644697	644570	19333N	PARTICIPANT	\N	PRESENT	0
644698	644570	14097Y	PARTICIPANT	\N	PRESENT	0
644699	644570	14073Q	PARTICIPANT	\N	PRESENT	0
644700	644570	12041X	PARTICIPANT	\N	PRESENT	0
644701	644570	19711U	PARTICIPANT	\N	PRESENT	1
644702	644570	11026G	PARTICIPANT	\N	PRESENT	0
644703	644570	14001X	PARTICIPANT	\N	PRESENT	0
644704	644570	19563B	PARTICIPANT	\N	EXCUSE	0
644705	644570	04070G	PARTICIPANT	\N	PRESENT	0
644706	644570	14169X	PARTICIPANT	\N	PRESENT	0
644707	644570	14331P	PRESIDENT	0	PRESENT	0
644708	644570	10015M	PARTICIPANT	\N	PRESENT	0
644709	644570	04045F	PARTICIPANT	\N	PRESENT	1
644736	644423	07004J	PARTICIPANT	\N	EXCUSE	0
644737	644423	20022R	PARTICIPANT	\N	EXCUSE	0
644740	644423	14111D	PARTICIPANT	\N	PRESENT	0
644741	644423	19717B	PARTICIPANT	\N	PRESENT	0
644742	644423	04047H	PRESIDENT	0	PRESENT	0
644743	643817	19333N	PARTICIPANT	\N	PRESENT	0
644744	643817	19701S	PARTICIPANT	\N	PRESENT	0
644745	643817	14031R	PARTICIPANT	\N	PRESENT	0
644746	643817	19549D	PARTICIPANT	\N	PRESENT	0
648586	646314	05012A	PARTICIPANT	\N	PRESENT	0
648633	647669	07029T	PARTICIPANT	\N	PRESENT	0
648588	647519	19581D	PARTICIPANT	\N	PRESENT	0
648589	647519	04047H	PRESIDENT	0	PRESENT	0
648590	647519	19673G	PARTICIPANT	\N	PRESENT	0
648591	647519	01028R	PARTICIPANT	\N	PRESENT	0
649006	647648	11067R	PARTICIPANT	\N	PRESENT	0
648593	647519	14231L	PARTICIPANT	\N	PRESENT	0
648594	647519	20108W	PARTICIPANT	\N	PRESENT	0
648595	647519	20110Q	PARTICIPANT	\N	PRESENT	0
648596	647519	14147R	PARTICIPANT	\N	PRESENT	0
648597	647519	20114U	PARTICIPANT	\N	PRESENT	0
648598	647519	14151M	PARTICIPANT	\N	PRESENT	0
648599	647519	14215L	PARTICIPANT	\N	PRESENT	0
649042	647648	12016W	PARTICIPANT	\N	PRESENT	0
648601	647519	20022R	PARTICIPANT	\N	PRESENT	0
648602	647519	14259Y	PARTICIPANT	\N	PRESENT	0
648603	647519	14053L	PARTICIPANT	\N	PRESENT	0
648604	647519	14111D	PARTICIPANT	\N	PRESENT	0
648605	647519	19649G	PARTICIPANT	\N	PRESENT	0
649044	647648	19717B	PARTICIPANT	\N	PRESENT	0
649045	647648	20122U	PARTICIPANT	\N	PRESENT	0
648608	647519	11033F	PARTICIPANT	\N	PRESENT	0
648609	647519	11056N	PARTICIPANT	\N	PRESENT	0
649047	647648	14257W	PARTICIPANT	\N	PRESENT	0
649048	647648	17965H	PARTICIPANT	\N	PRESENT	0
648612	647519	19749K	PARTICIPANT	\N	PRESENT	0
648613	647519	14021P	PARTICIPANT	\N	PRESENT	0
649049	647648	19569H	PARTICIPANT	\N	PRESENT	0
648615	647519	14107H	PARTICIPANT	\N	PRESENT	0
649254	649253	19717B	PARTICIPANT	\N	PRESENT	0
649051	647648	20016T	PARTICIPANT	\N	PRESENT	0
649259	649258	14097Y	PARTICIPANT	\N	PRESENT	0
648620	646314	20136B	PARTICIPANT	\N	PRESENT	0
649260	649258	19657G	PARTICIPANT	\N	PRESENT	0
651308	649165	86034E	PARTICIPANT	\N	PRESENT	0
651309	649165	04042C	PARTICIPANT	\N	PRESENT	0
651310	649165	14249W	PARTICIPANT	\N	PRESENT	0
651311	649165	14251Q	PARTICIPANT	\N	PRESENT	0
651312	649165	99004R	PARTICIPANT	\N	PRESENT	0
651313	649165	19347U	PARTICIPANT	\N	PRESENT	0
648628	647519	11026G	PARTICIPANT	\N	PRESENT	0
651314	649165	20072C	PARTICIPANT	\N	PRESENT	0
651315	649165	12041X	PARTICIPANT	\N	PRESENT	0
651316	649165	17023S	PARTICIPANT	\N	PRESENT	0
648638	647519	05008E	PARTICIPANT	\N	PRESENT	0
648636	647669	14173T	PARTICIPANT	\N	PRESENT	0
651317	649165	14055N	PARTICIPANT	\N	PRESENT	0
648639	647519	14089Y	PARTICIPANT	\N	PRESENT	0
651318	649165	01062T	PARTICIPANT	\N	PRESENT	0
651319	649165	04035D	PARTICIPANT	\N	PRESENT	0
651349	649165	20090E	PARTICIPANT	\N	PRESENT	0
651350	649165	20042V	PARTICIPANT	\N	PRESENT	0
651351	649165	14073Q	PARTICIPANT	\N	PRESENT	0
651352	649165	20298U	PARTICIPANT	\N	PRESENT	0
651353	649165	19443T	PARTICIPANT	\N	PRESENT	0
648647	647669	11012A	PARTICIPANT	\N	EXCUSE	0
651354	649165	01058X	PARTICIPANT	\N	PRESENT	0
648728	647669	19479G	PARTICIPANT	\N	PRESENT	0
648730	647960	20138D	PARTICIPANT	\N	PRESENT	0
648731	647960	20058E	PARTICIPANT	\N	PRESENT	0
648732	647960	20180F	PARTICIPANT	\N	PRESENT	0
648733	646314	19525U	PARTICIPANT	\N	PRESENT	0
648746	647960	20048C	PARTICIPANT	\N	PRESENT	0
648747	647960	14109K	PARTICIPANT	\N	PRESENT	1
648748	647960	19527W	PARTICIPANT	\N	PRESENT	0
648756	648755	14073Q	PARTICIPANT	\N	EXCUSE	0
648757	645023	19577H	PARTICIPANT	\N	PRESENT	1
648758	645023	19347U	PARTICIPANT	\N	PRESENT	1
648759	645023	20034V	PARTICIPANT	\N	PRESENT	0
648760	645023	19715Y	PARTICIPANT	\N	PRESENT	0
648761	645023	14097Y	PARTICIPANT	\N	PRESENT	0
648762	645023	14059S	PARTICIPANT	\N	EXCUSE	0
648763	645023	19657G	PARTICIPANT	\N	PRESENT	1
648764	645023	20148F	PARTICIPANT	\N	PRESENT	0
648765	645023	19301E	PARTICIPANT	\N	PRESENT	1
648784	647648	86034E	PARTICIPANT	\N	PRESENT	0
648785	647648	20068G	PARTICIPANT	\N	PRESENT	0
648786	647648	20098N	PARTICIPANT	\N	PRESENT	0
648788	647648	19443T	PARTICIPANT	\N	PRESENT	0
648789	647648	14173T	PARTICIPANT	\N	PRESENT	0
648791	647648	08060W	PARTICIPANT	\N	PRESENT	0
648792	647648	19866P	PARTICIPANT	\N	PRESENT	0
648793	647648	19399H	PARTICIPANT	\N	PRESENT	0
648794	647648	07029T	PARTICIPANT	\N	PRESENT	0
648795	647648	19507S	PARTICIPANT	\N	PRESENT	0
648796	647648	05012A	PARTICIPANT	\N	PRESENT	0
648797	647648	19581D	PARTICIPANT	\N	PRESENT	0
648798	647648	20252E	PARTICIPANT	\N	PRESENT	0
648801	647648	19583F	PARTICIPANT	\N	PRESENT	0
648802	647648	19798U	PARTICIPANT	\N	PRESENT	0
648803	647648	17229F	PARTICIPANT	\N	PRESENT	0
648804	647648	11080N	PARTICIPANT	\N	PRESENT	0
648805	647648	14071N	PARTICIPANT	\N	PRESENT	0
648806	647648	14123H	PARTICIPANT	\N	PRESENT	0
648807	647648	20116W	PARTICIPANT	\N	PRESENT	0
648808	647648	11054L	PARTICIPANT	\N	PRESENT	0
648809	647648	11066Q	PARTICIPANT	\N	PRESENT	0
648810	647648	19333N	PARTICIPANT	\N	PRESENT	0
648816	647648	19621T	PARTICIPANT	\N	PRESENT	0
648817	647648	19711U	PARTICIPANT	\N	PRESENT	0
648818	647648	11031D	PARTICIPANT	\N	PRESENT	0
648819	647648	19760E	PARTICIPANT	\N	PRESENT	0
648820	647648	19758L	PARTICIPANT	\N	PRESENT	0
648821	647648	19687N	PARTICIPANT	\N	PRESENT	0
648822	647648	19747H	PARTICIPANT	\N	PRESENT	0
648823	647648	04085P	PARTICIPANT	\N	PRESENT	0
648824	647648	04047H	PARTICIPANT	\N	PRESENT	0
648825	647648	19695N	PARTICIPANT	\N	PRESENT	0
648826	647648	19593H	PARTICIPANT	\N	PRESENT	0
648827	647648	99004R	PARTICIPANT	\N	PRESENT	0
648828	647648	01058X	PARTICIPANT	\N	PRESENT	0
648829	647648	11048N	PARTICIPANT	\N	PRESENT	0
648830	647648	19565D	PARTICIPANT	\N	PRESENT	0
648831	647648	11056N	PARTICIPANT	\N	PRESENT	0
648833	647648	11077T	PARTICIPANT	\N	PRESENT	0
648835	647648	19679N	PARTICIPANT	\N	PRESENT	0
648836	647648	12041X	PARTICIPANT	\N	PRESENT	0
648837	647648	20076G	PARTICIPANT	\N	PRESENT	0
648838	647648	20102Q	PARTICIPANT	\N	PRESENT	0
648839	647648	18083K	PARTICIPANT	\N	PRESENT	0
648840	647648	20082E	PARTICIPANT	\N	PRESENT	0
648841	647648	20070A	PARTICIPANT	\N	PRESENT	0
648842	647648	14133K	PARTICIPANT	\N	PRESENT	0
648848	647648	20094J	PARTICIPANT	\N	PRESENT	0
648844	647648	19415P	PARTICIPANT	\N	PRESENT	0
648845	647648	11097X	PARTICIPANT	\N	PRESENT	0
648846	647648	05008E	PARTICIPANT	\N	PRESENT	0
648847	647648	12028B	PARTICIPANT	\N	PRESENT	0
648849	647648	14187A	PARTICIPANT	\N	PRESENT	0
648850	647648	04033B	PARTICIPANT	\N	PRESENT	0
648851	647648	08028W	PARTICIPANT	\N	PRESENT	0
648852	647648	11043H	PARTICIPANT	\N	PRESENT	0
648853	647648	04071H	PARTICIPANT	\N	PRESENT	0
648854	647648	19643A	PARTICIPANT	\N	PRESENT	0
648855	647648	19515S	PARTICIPANT	\N	PRESENT	0
648856	647648	19766L	PARTICIPANT	\N	PRESENT	0
648857	647648	04043D	PARTICIPANT	\N	PRESENT	0
648858	647648	19701S	PARTICIPANT	\N	PRESENT	0
648859	647648	14053L	PARTICIPANT	\N	PRESENT	0
648860	647648	14193X	PARTICIPANT	\N	PRESENT	0
648861	647648	19421M	PARTICIPANT	\N	PRESENT	0
648862	647648	19820Y	PARTICIPANT	\N	PRESENT	0
648863	647648	11045K	PARTICIPANT	\N	PRESENT	0
648864	647648	10006L	PARTICIPANT	\N	PRESENT	0
648865	647648	14331P	PARTICIPANT	\N	PRESENT	0
648866	647648	20032T	PARTICIPANT	\N	PRESENT	0
648867	647648	14253S	PARTICIPANT	\N	PRESENT	0
648868	647648	19667J	PARTICIPANT	\N	PRESENT	0
648869	647648	20066E	PARTICIPANT	\N	PRESENT	0
648870	647648	14219Q	PARTICIPANT	\N	PRESENT	0
648871	647648	11010L	PARTICIPANT	\N	PRESENT	0
648872	647648	19673G	PARTICIPANT	\N	PRESENT	0
648873	647648	17779H	PARTICIPANT	\N	PRESENT	0
648874	647648	19573D	PARTICIPANT	\N	PRESENT	0
648875	647648	20096L	PARTICIPANT	\N	PRESENT	0
648876	647648	20180F	PARTICIPANT	\N	PRESENT	0
648877	647648	92040Q	PARTICIPANT	\N	PRESENT	0
648878	647648	08047A	PARTICIPANT	\N	PRESENT	0
648879	647648	20172F	PARTICIPANT	\N	PRESENT	0
648880	647648	20138D	PARTICIPANT	\N	PRESENT	0
630695	629310	20100N	PARTICIPANT	\N	PRESENT	0
630696	629310	20074E	PARTICIPANT	\N	PRESENT	0
630697	629310	20078J	PARTICIPANT	\N	PRESENT	0
630698	629310	19387D	PARTICIPANT	\N	PRESENT	0
630699	629310	11012A	PARTICIPANT	\N	PRESENT	0
630701	629310	20266L	PARTICIPANT	\N	PRESENT	0
630702	629310	14123H	PARTICIPANT	\N	PRESENT	0
630703	629310	19413M	PARTICIPANT	\N	PRESENT	0
630704	629310	08034U	PARTICIPANT	\N	PRESENT	0
630705	629310	19415P	PARTICIPANT	\N	PRESENT	0
630706	629310	14219Q	PARTICIPANT	\N	PRESENT	0
630707	629310	14073Q	PARTICIPANT	\N	PRESENT	0
630708	629310	05008E	PARTICIPANT	\N	PRESENT	0
630709	629310	19251M	PARTICIPANT	\N	PRESENT	0
630710	629310	14187A	PARTICIPANT	\N	PRESENT	0
630711	629310	19631V	PARTICIPANT	\N	PRESENT	0
630712	629310	04033B	PARTICIPANT	\N	PRESENT	0
630716	629310	11043H	PARTICIPANT	\N	PRESENT	0
630717	629310	18193Q	PARTICIPANT	\N	PRESENT	0
630718	629310	19515S	PARTICIPANT	\N	PRESENT	0
630719	629310	14021P	PARTICIPANT	\N	PRESENT	0
630720	629310	19782L	PARTICIPANT	\N	PRESENT	0
630721	629310	19766L	PARTICIPANT	\N	PRESENT	0
630722	629310	19725B	PARTICIPANT	\N	PRESENT	0
630723	629310	01057W	PARTICIPANT	\N	PRESENT	0
630724	629310	20068G	PARTICIPANT	\N	PRESENT	0
630725	629310	05012A	PARTICIPANT	\N	PRESENT	0
630726	629310	11064N	PARTICIPANT	\N	PRESENT	0
630727	629310	14251Q	PARTICIPANT	\N	PRESENT	0
630728	629310	20022R	PARTICIPANT	\N	PRESENT	0
630729	629310	14069U	PARTICIPANT	\N	PRESENT	0
630730	629310	19701S	PARTICIPANT	\N	PRESENT	0
630731	629310	11031D	PARTICIPANT	\N	PRESENT	0
630732	629310	19715Y	PARTICIPANT	\N	PRESENT	0
630733	629310	14083S	PARTICIPANT	\N	PRESENT	0
630734	629310	19421M	PARTICIPANT	\N	PRESENT	0
630735	629310	14215L	PARTICIPANT	\N	PRESENT	0
630736	629310	14193X	PARTICIPANT	\N	PRESENT	0
630737	629310	14189C	PARTICIPANT	\N	PRESENT	0
630738	629310	11053K	PARTICIPANT	\N	PRESENT	0
630739	629310	14217N	PARTICIPANT	\N	PRESENT	0
630740	629310	14327T	PARTICIPANT	\N	PRESENT	0
630741	629310	14042U	PARTICIPANT	\N	PRESENT	0
630742	629310	04071H	PARTICIPANT	\N	PRESENT	0
630743	629310	19707Y	PARTICIPANT	\N	PRESENT	0
630744	629310	20094J	PARTICIPANT	\N	PRESENT	0
630745	629310	19705W	PARTICIPANT	\N	PRESENT	0
630746	629310	20136B	PARTICIPANT	\N	PRESENT	0
630748	629310	19667J	PARTICIPANT	\N	PRESENT	0
630750	629310	19673G	PARTICIPANT	\N	PRESENT	0
630752	629310	11010L	PARTICIPANT	\N	PRESENT	0
630753	629310	14179A	PARTICIPANT	\N	PRESENT	0
630754	629310	19685L	PARTICIPANT	\N	PRESENT	0
630755	629310	14031R	PARTICIPANT	\N	PRESENT	0
630756	629310	20038A	PARTICIPANT	\N	PRESENT	0
630757	629310	04042C	PARTICIPANT	\N	PRESENT	0
630758	629310	20180F	PARTICIPANT	\N	PRESENT	0
630759	629310	19954N	PARTICIPANT	\N	PRESENT	0
630760	629310	01028R	PARTICIPANT	\N	PRESENT	0
630761	629310	20140W	PARTICIPANT	\N	PRESENT	0
630762	629310	20084G	PARTICIPANT	\N	PRESENT	0
630763	629310	08047A	PARTICIPANT	\N	PRESENT	0
630764	629310	11054L	PARTICIPANT	\N	PRESENT	0
630765	629310	14151M	PARTICIPANT	\N	PRESENT	0
630766	629310	14147R	PARTICIPANT	\N	PRESENT	0
630767	629310	97011G	PARTICIPANT	\N	PRESENT	0
630768	629310	19749K	PARTICIPANT	\N	PRESENT	0
630769	629310	08045X	PARTICIPANT	\N	PRESENT	0
630770	629310	20120S	PARTICIPANT	\N	PRESENT	0
630771	629310	17965H	PARTICIPANT	\N	PRESENT	0
630772	629310	95041E	PARTICIPANT	\N	PRESENT	0
630773	629310	14281W	PARTICIPANT	\N	PRESENT	0
630774	629310	19581D	PARTICIPANT	\N	PRESENT	0
630775	629310	20060X	PARTICIPANT	\N	PRESENT	0
630776	629310	19621T	PARTICIPANT	\N	PRESENT	0
630777	629310	19367Y	PARTICIPANT	\N	PRESENT	0
630778	629310	20152B	PARTICIPANT	\N	PRESENT	0
630779	629310	11033F	PARTICIPANT	\N	PRESENT	0
630780	629310	19649G	PARTICIPANT	\N	PRESENT	0
630781	629310	20114U	PARTICIPANT	\N	PRESENT	0
630782	629310	19489J	PARTICIPANT	\N	PRESENT	0
630783	629310	19503N	PARTICIPANT	\N	PRESENT	0
630784	629310	04043D	PARTICIPANT	\N	PRESENT	0
630785	629310	08069G	PARTICIPANT	\N	PRESENT	0
630786	629310	20104S	PARTICIPANT	\N	PRESENT	0
630787	629310	14255U	PARTICIPANT	\N	PRESENT	0
630788	629310	19335Q	PARTICIPANT	\N	PRESENT	0
630789	629310	19826F	PARTICIPANT	\N	PRESENT	0
630790	629310	20098N	PARTICIPANT	\N	PRESENT	0
630791	629310	16685X	PARTICIPANT	\N	PRESENT	0
630792	629310	20096L	PARTICIPANT	\N	PRESENT	0
630793	629310	20034V	PARTICIPANT	\N	PRESENT	0
630794	629310	01024M	PARTICIPANT	\N	PRESENT	0
630795	629310	19723Y	PARTICIPANT	\N	PRESENT	0
630796	629310	20058E	PARTICIPANT	\N	PRESENT	0
630797	629310	08011M	PARTICIPANT	\N	PRESENT	0
630798	629310	20044X	PARTICIPANT	\N	PRESENT	0
630799	629310	19663E	PARTICIPANT	\N	PRESENT	0
630800	629310	08018U	PARTICIPANT	\N	PRESENT	0
630801	629310	19507S	PARTICIPANT	\N	PRESENT	0
630802	629310	08015R	PARTICIPANT	\N	PRESENT	0
630803	629310	19651A	PARTICIPANT	\N	PRESENT	0
630804	629310	19768N	PARTICIPANT	\N	PRESENT	0
630805	629310	19319Q	PARTICIPANT	\N	PRESENT	0
630806	629310	14059S	PARTICIPANT	\N	PRESENT	0
630807	629310	14253S	PARTICIPANT	\N	PRESENT	0
630808	629310	08056B	PARTICIPANT	\N	PRESENT	0
630809	629310	20126Y	PARTICIPANT	\N	PRESENT	0
630810	629310	20054A	PARTICIPANT	\N	PRESENT	0
630811	629310	19693L	PARTICIPANT	\N	PRESENT	0
630816	629310	19531S	PARTICIPANT	\N	PRESENT	0
630818	629310	14169X	PARTICIPANT	\N	PRESENT	0
630819	629310	19637C	PARTICIPANT	\N	PRESENT	0
630820	629310	19747H	PARTICIPANT	\N	PRESENT	0
630821	629310	11101A	PARTICIPANT	\N	PRESENT	0
630822	629310	20124W	PARTICIPANT	\N	PRESENT	0
630823	629310	11090Q	PARTICIPANT	\N	PRESENT	0
630824	629310	19591F	PARTICIPANT	\N	PRESENT	0
630826	629310	01034P	PARTICIPANT	\N	PRESENT	0
630832	629310	20286Q	PARTICIPANT	\N	PRESENT	0
630833	629310	14237S	PARTICIPANT	\N	PRESENT	0
630834	629310	19441R	PARTICIPANT	\N	PRESENT	0
630835	629310	11070L	PARTICIPANT	\N	PRESENT	0
630836	629310	14267Y	PARTICIPANT	\N	PRESENT	0
630841	629310	20048C	PARTICIPANT	\N	PRESENT	0
630842	629310	14205J	PARTICIPANT	\N	PRESENT	0
631100	629311	14026U	PARTICIPANT	\N	PRESENT	0
631101	629311	14259Y	PARTICIPANT	\N	PRESENT	0
631102	629311	04092N	PARTICIPANT	\N	PRESENT	0
631103	629311	20110Q	PARTICIPANT	\N	PRESENT	0
631104	629311	11056N	PARTICIPANT	\N	PRESENT	0
631105	629311	14231L	PARTICIPANT	\N	PRESENT	0
631106	629311	19629C	PARTICIPANT	\N	PRESENT	0
631107	629311	19489J	PARTICIPANT	\N	PRESENT	0
631108	629311	95063L	PARTICIPANT	\N	PRESENT	0
631109	629311	14111D	PARTICIPANT	\N	PRESENT	0
631113	629324	20064C	PARTICIPANT	\N	PRESENT	0
631114	629324	04085P	PARTICIPANT	\N	PRESENT	0
631115	629324	19667J	PRESIDENT	0	PRESENT	0
631116	629311	19685L	PARTICIPANT	\N	PRESENT	0
631117	629311	20132W	PARTICIPANT	\N	PRESENT	0
631118	629311	20090E	PARTICIPANT	\N	PRESENT	0
631119	629311	19507S	PARTICIPANT	\N	PRESENT	0
631120	629311	20108W	PARTICIPANT	\N	PRESENT	0
631121	629311	19651A	PARTICIPANT	\N	PRESENT	0
631124	629311	20044X	PARTICIPANT	\N	PRESENT	0
631126	629311	20068G	PARTICIPANT	\N	PRESENT	0
631127	629311	20252E	PARTICIPANT	\N	PRESENT	0
631128	627014	19701S	PARTICIPANT	\N	PRESENT	0
631129	627014	08060W	PARTICIPANT	\N	PRESENT	0
631130	627014	20136B	PARTICIPANT	\N	PRESENT	0
631131	627014	14031R	PARTICIPANT	\N	PRESENT	0
631132	627014	19387D	PARTICIPANT	\N	PRESENT	0
631133	627014	19820Y	PARTICIPANT	\N	PRESENT	0
631134	627014	14221J	PARTICIPANT	\N	PRESENT	0
631135	627014	19826F	PARTICIPANT	\N	PRESENT	0
631136	627014	19599P	PARTICIPANT	\N	PRESENT	0
631137	627014	17229F	PARTICIPANT	\N	PRESENT	0
631138	629311	11097X	PARTICIPANT	\N	PRESENT	0
631140	629311	14215L	PARTICIPANT	\N	PRESENT	0
631141	627014	18083K	PARTICIPANT	\N	PRESENT	1
643016	643013	01057W	PARTICIPANT	\N	PRESENT	0
643017	643013	19687N	PARTICIPANT	\N	PRESENT	0
643018	643013	19545Y	PARTICIPANT	\N	PRESENT	0
643019	643013	05012A	PARTICIPANT	\N	PRESENT	0
643020	643013	19711U	PARTICIPANT	\N	PRESENT	0
643021	643013	20116W	PARTICIPANT	\N	PRESENT	0
643023	643022	11080N	PARTICIPANT	\N	PRESENT	0
643024	643022	14121F	PARTICIPANT	\N	PRESENT	0
643025	643022	20116W	PARTICIPANT	\N	PRESENT	0
643026	643022	01057W	PARTICIPANT	\N	PRESENT	0
643027	643022	19687N	PARTICIPANT	\N	PRESENT	0
643029	643028	14217N	PARTICIPANT	\N	PRESENT	0
643030	643028	20248J	PARTICIPANT	\N	PRESENT	0
643031	643028	20130U	PARTICIPANT	\N	PRESENT	0
643033	643032	20080C	PARTICIPANT	\N	PRESENT	0
643035	643034	20080C	PARTICIPANT	\N	PRESENT	0
643037	643036	20080C	PARTICIPANT	\N	PRESENT	0
643039	643038	20080C	PARTICIPANT	\N	PRESENT	0
643082	642935	01034P	PARTICIPANT	\N	PRESENT	0
643083	642935	20090E	PARTICIPANT	\N	PRESENT	0
643084	642935	19569H	PARTICIPANT	\N	PRESENT	0
643085	642935	11097X	PARTICIPANT	\N	PRESENT	0
643086	642935	19663E	PARTICIPANT	\N	PRESENT	0
643087	642935	19691J	PARTICIPANT	\N	PRESENT	0
643088	642935	18193Q	PARTICIPANT	\N	PRESENT	0
643089	642935	14026U	PARTICIPANT	\N	PRESENT	0
643090	642935	19553Y	PARTICIPANT	\N	PRESENT	0
643091	642935	19703U	PARTICIPANT	\N	PRESENT	0
643092	642935	14281W	PARTICIPANT	\N	PRESENT	0
643093	642935	14213J	PARTICIPANT	\N	PRESENT	0
643094	642935	19657G	PARTICIPANT	\N	PRESENT	0
643095	642935	14217N	PARTICIPANT	\N	PRESENT	0
643096	642935	10006L	PRESIDENT	0	PRESENT	0
643097	642935	08045X	PARTICIPANT	\N	EXCUSE	0
643098	642935	20130U	PARTICIPANT	\N	PRESENT	1
643099	642935	19798U	PARTICIPANT	\N	PRESENT	1
643100	642935	19301E	PARTICIPANT	\N	PRESENT	1
643101	642935	11103C	PARTICIPANT	\N	PRESENT	1
643102	642935	14042U	PARTICIPANT	\N	PRESENT	1
643104	642869	20032T	PARTICIPANT	\N	PRESENT	0
643105	642869	20118Y	PARTICIPANT	\N	PRESENT	0
643106	642869	19739H	PARTICIPANT	\N	PRESENT	0
643107	642869	17367Q	PARTICIPANT	\N	PRESENT	0
643108	642868	11012A	PRESIDENT	0	PRESENT	0
643109	642868	19479G	PARTICIPANT	\N	PRESENT	0
643110	642868	01057W	PARTICIPANT	\N	PRESENT	0
643111	642868	12016W	PARTICIPANT	\N	PRESENT	0
643112	642868	99004R	PARTICIPANT	\N	PRESENT	0
643113	642868	11074Q	PARTICIPANT	\N	PRESENT	0
643114	642868	19335Q	PARTICIPANT	\N	PRESENT	0
643115	642868	11053K	PARTICIPANT	\N	PRESENT	0
643116	642868	20086J	PARTICIPANT	\N	PRESENT	0
643117	642868	19545Y	PARTICIPANT	\N	PRESENT	0
643118	642868	20044X	PARTICIPANT	\N	PRESENT	0
643119	642868	14083S	PARTICIPANT	\N	PRESENT	0
643120	642868	08010L	PARTICIPANT	\N	PRESENT	0
643121	642868	20126Y	PARTICIPANT	\N	PRESENT	0
643122	642868	19647E	PARTICIPANT	\N	PRESENT	0
643123	642868	19687N	PARTICIPANT	\N	PRESENT	0
643124	642869	19549D	PARTICIPANT	\N	PRESENT	0
643125	642868	14253S	PARTICIPANT	\N	PRESENT	0
643126	642868	20252E	PARTICIPANT	\N	PRESENT	0
643127	642868	20150Y	PARTICIPANT	\N	PRESENT	0
643128	642868	08073C	PARTICIPANT	\N	PRESENT	0
643129	642868	20116W	PARTICIPANT	\N	PRESENT	0
643178	642984	14097Y	PARTICIPANT	\N	PRESENT	0
643179	642984	01062T	PARTICIPANT	\N	PRESENT	0
643180	642984	19565D	PARTICIPANT	\N	PRESENT	0
643236	643235	16685X	PARTICIPANT	\N	PRESENT	0
643182	642984	16685X	PARTICIPANT	\N	PRESENT	0
643183	642984	04042C	PRESIDENT	0	PRESENT	0
643184	642984	01024M	PARTICIPANT	\N	PRESENT	0
643185	642984	11054L	PARTICIPANT	\N	PRESENT	1
643186	642984	11066Q	PARTICIPANT	\N	PRESENT	0
643187	642984	08056B	PARTICIPANT	\N	PRESENT	0
643188	642984	19319Q	PARTICIPANT	\N	PRESENT	0
643189	642984	12028B	PARTICIPANT	\N	PRESENT	1
643190	642984	14105F	PARTICIPANT	\N	PRESENT	0
643191	642984	14193X	PARTICIPANT	\N	PRESENT	0
643192	642984	14267Y	PARTICIPANT	\N	PRESENT	0
643193	642984	07033P	PARTICIPANT	\N	PRESENT	0
643194	642984	08061X	PARTICIPANT	\N	PRESENT	0
643195	642984	97011G	PARTICIPANT	\N	PRESENT	0
643196	642984	14249W	PARTICIPANT	\N	PRESENT	0
643197	642984	08047A	PARTICIPANT	\N	PRESENT	0
643198	642984	14255U	PARTICIPANT	\N	PRESENT	0
643200	643199	20026V	PARTICIPANT	\N	PRESENT	1
643201	643199	19593H	PARTICIPANT	\N	PRESENT	0
643202	643199	20142Y	PARTICIPANT	\N	PRESENT	0
643203	643171	20026V	PARTICIPANT	\N	PRESENT	1
643204	643171	20142Y	PARTICIPANT	\N	PRESENT	0
643238	643237	14249W	PARTICIPANT	\N	PRESENT	0
643239	643237	19647E	PARTICIPANT	\N	PRESENT	0
643240	643237	20056C	PARTICIPANT	\N	PRESENT	0
643241	643237	14073Q	PARTICIPANT	\N	PRESENT	0
643243	643242	14249W	PARTICIPANT	\N	PRESENT	0
643261	643040	14073Q	PARTICIPANT	\N	PRESENT	0
643262	643040	19333N	PARTICIPANT	\N	PRESENT	0
643263	643040	14089Y	PARTICIPANT	\N	PRESENT	0
643264	643040	14207L	PARTICIPANT	\N	PRESENT	0
643265	643040	20286Q	PARTICIPANT	\N	PRESENT	0
643266	643040	04035D	PARTICIPANT	\N	PRESENT	0
643267	643040	11083R	PARTICIPANT	\N	PRESENT	0
643268	643040	19553Y	PARTICIPANT	\N	PRESENT	0
643269	643040	14001X	PARTICIPANT	\N	PRESENT	1
643270	643040	11026G	PARTICIPANT	\N	PRESENT	0
643271	643040	10015M	PARTICIPANT	\N	PRESENT	0
643272	643040	20098N	PARTICIPANT	\N	PRESENT	0
643273	643040	14331P	PRESIDENT	0	PRESENT	0
643274	643040	12041X	PARTICIPANT	\N	PRESENT	0
643275	643040	14026U	PARTICIPANT	\N	EXCUSE	0
643276	643040	19563B	PARTICIPANT	\N	EXCUSE	0
643277	643040	14097Y	PARTICIPANT	\N	PRESENT	0
643285	643040	14169X	PARTICIPANT	\N	PRESENT	0
643287	643040	08018U	PARTICIPANT	\N	EXCUSE	0
643306	643305	14133K	PARTICIPANT	\N	PRESENT	0
643332	641985	19415P	PARTICIPANT	\N	PRESENT	0
643334	643333	19415P	PARTICIPANT	\N	PRESENT	0
643335	643333	14217N	PARTICIPANT	\N	PRESENT	0
643336	643333	19760E	PARTICIPANT	\N	PRESENT	0
643337	643333	14213J	PARTICIPANT	\N	PRESENT	0
643338	643333	19657G	PARTICIPANT	\N	PRESENT	0
643339	643333	11097X	PARTICIPANT	\N	PRESENT	0
643340	643333	19703U	PARTICIPANT	\N	PRESENT	0
643341	641986	19415P	PARTICIPANT	\N	PRESENT	0
643342	641986	14213J	PARTICIPANT	\N	PRESENT	0
643343	641986	19760E	PARTICIPANT	\N	PRESENT	0
643344	641986	19657G	PARTICIPANT	\N	PRESENT	0
643345	641986	20130U	PARTICIPANT	\N	PRESENT	0
643346	641986	19703U	PARTICIPANT	\N	PRESENT	0
643348	643347	19415P	PARTICIPANT	\N	PRESENT	0
643349	643347	14217N	PARTICIPANT	\N	PRESENT	0
643350	643347	14213J	PARTICIPANT	\N	PRESENT	0
643351	643347	19657G	PARTICIPANT	\N	PRESENT	0
643352	643347	20130U	PARTICIPANT	\N	PRESENT	0
643353	641987	19415P	PARTICIPANT	\N	PRESENT	0
643354	641987	20130U	PARTICIPANT	\N	PRESENT	0
643355	641987	19703U	PARTICIPANT	\N	PRESENT	0
643356	641988	19415P	PARTICIPANT	\N	PRESENT	0
643357	641988	20130U	PARTICIPANT	\N	PRESENT	0
643358	641988	19703U	PARTICIPANT	\N	PRESENT	0
643359	641989	19415P	PARTICIPANT	\N	PRESENT	0
643386	643288	20042V	PARTICIPANT	\N	EXCUSE	0
643361	641989	19691J	PARTICIPANT	\N	PRESENT	0
643362	641989	18193Q	PARTICIPANT	\N	PRESENT	0
643363	641989	20130U	PARTICIPANT	\N	PRESENT	0
643364	641989	19703U	PARTICIPANT	\N	PRESENT	0
643365	641989	11031D	PARTICIPANT	\N	PRESENT	0
643394	643393	19735D	PARTICIPANT	\N	PRESENT	0
643395	643393	19723Y	PARTICIPANT	\N	PRESENT	0
643399	643397	11026G	PARTICIPANT	\N	PRESENT	0
643400	643397	19729F	PARTICIPANT	\N	PRESENT	0
643401	643398	19954N	PARTICIPANT	\N	PRESENT	0
643402	643398	20110Q	PARTICIPANT	\N	PRESENT	0
643403	643398	19489J	PARTICIPANT	\N	PRESENT	0
643406	643405	99004R	PARTICIPANT	\N	PRESENT	0
643407	643405	19399H	PARTICIPANT	\N	PRESENT	0
643409	643408	99004R	PARTICIPANT	\N	PRESENT	0
643410	643408	19399H	PARTICIPANT	\N	PRESENT	0
643413	643412	19695N	PARTICIPANT	\N	PRESENT	0
629671	629399	14207L	PARTICIPANT	\N	EXCUSE	0
629672	629399	19866P	PARTICIPANT	\N	EXCUSE	0
629676	629399	19768N	PARTICIPANT	\N	PRESENT	0
631727	631726	05008E	PARTICIPANT	\N	PRESENT	0
631728	631726	11053K	PARTICIPANT	\N	PRESENT	0
631729	631726	01028R	PARTICIPANT	\N	PRESENT	0
632427	632423	11074Q	PARTICIPANT	\N	PRESENT	0
632425	632423	20042V	PARTICIPANT	\N	PRESENT	0
632426	632423	11080N	PARTICIPANT	\N	PRESENT	0
632428	632423	19347U	PARTICIPANT	\N	PRESENT	0
632429	632423	01057W	PARTICIPANT	\N	PRESENT	0
632430	632423	14121F	PARTICIPANT	\N	PRESENT	0
632431	632423	19711U	PARTICIPANT	\N	PRESENT	0
632432	632423	05012A	PARTICIPANT	\N	PRESENT	0
632452	632451	14038Y	PARTICIPANT	\N	PRESENT	0
632453	632451	19629C	PARTICIPANT	\N	PRESENT	0
632454	632451	14147R	PARTICIPANT	\N	PRESENT	0
632455	632451	19725B	PARTICIPANT	\N	PRESENT	0
632456	632451	20092G	PARTICIPANT	\N	PRESENT	0
632457	632451	20028X	PARTICIPANT	\N	PRESENT	0
632458	632451	19575F	PARTICIPANT	\N	PRESENT	1
632459	632451	14179A	PARTICIPANT	\N	PRESENT	1
632460	632451	14205J	PARTICIPANT	\N	PRESENT	1
632479	632472	19693L	PARTICIPANT	\N	PRESENT	0
632481	632472	20126Y	PARTICIPANT	\N	PRESENT	0
632482	632472	11077T	PARTICIPANT	\N	PRESENT	0
632483	632472	20050V	PARTICIPANT	\N	PRESENT	0
632484	632472	20082E	PARTICIPANT	\N	PRESENT	0
633960	633959	19782L	PARTICIPANT	\N	PRESENT	0
633961	633959	20248J	PARTICIPANT	\N	PRESENT	0
633962	633959	19251M	PARTICIPANT	\N	PRESENT	0
633963	633959	11026G	PARTICIPANT	\N	PRESENT	0
633964	633959	19593H	PARTICIPANT	\N	PRESENT	0
633965	633959	19515S	PARTICIPANT	\N	PRESENT	0
633966	633959	20084G	PARTICIPANT	\N	PRESENT	0
633967	633959	19647E	PARTICIPANT	\N	PRESENT	0
633969	633968	08069G	PARTICIPANT	\N	PRESENT	0
633970	633968	20024T	PARTICIPANT	\N	PRESENT	0
633971	633968	11026G	PARTICIPANT	\N	PRESENT	0
633973	631242	19667J	PARTICIPANT	\N	PRESENT	0
633974	631242	04085P	PARTICIPANT	\N	PRESENT	0
633985	631242	20038A	PARTICIPANT	\N	PRESENT	0
633986	631242	19531S	PARTICIPANT	\N	PRESENT	0
634014	631242	14257W	PARTICIPANT	\N	PRESENT	0
634023	631242	20044X	PARTICIPANT	\N	PRESENT	0
635598	634461	19415P	PARTICIPANT	\N	PRESENT	1
635599	634461	11103C	PARTICIPANT	\N	PRESENT	1
635600	634461	14213J	PARTICIPANT	\N	PRESENT	1
635601	634461	14026U	PARTICIPANT	\N	PRESENT	1
635602	634461	20130U	PARTICIPANT	\N	PRESENT	0
635603	634461	19760E	PARTICIPANT	\N	PRESENT	1
635604	634461	18193Q	PARTICIPANT	\N	PRESENT	0
635605	634461	11097X	PARTICIPANT	\N	PRESENT	0
635606	634461	11067R	PARTICIPANT	\N	PRESENT	0
635607	634461	19683J	PARTICIPANT	\N	PRESENT	0
635608	634461	19657G	PARTICIPANT	\N	PRESENT	1
635609	634461	11031D	PARTICIPANT	\N	PRESENT	1
635610	634461	14042U	PARTICIPANT	\N	PRESENT	0
635611	634461	20248J	PARTICIPANT	\N	PRESENT	0
635612	634461	19717B	PARTICIPANT	\N	PRESENT	0
635613	634461	19553Y	PARTICIPANT	\N	PRESENT	0
635614	634461	20090E	PARTICIPANT	\N	PRESENT	0
635615	634461	19679N	PARTICIPANT	\N	PRESENT	0
635616	634461	19691J	PARTICIPANT	\N	PRESENT	0
635617	634461	08045X	PARTICIPANT	\N	PRESENT	0
635618	634461	20040T	PARTICIPANT	\N	PRESENT	0
635619	634461	19713W	PARTICIPANT	\N	PRESENT	0
635620	634461	19569H	PARTICIPANT	\N	PRESENT	0
635621	634461	19703U	PARTICIPANT	\N	PRESENT	0
635622	634461	19367Y	PARTICIPANT	\N	PRESENT	0
635623	634461	14217N	PARTICIPANT	\N	PRESENT	0
635624	634461	14223L	PARTICIPANT	\N	PRESENT	0
635625	634461	04092N	PARTICIPANT	\N	PRESENT	0
635626	634461	14195A	PARTICIPANT	\N	PRESENT	0
635627	634461	19798U	PARTICIPANT	\N	PRESENT	0
635628	634461	10006L	PRESIDENT	0	PRESENT	0
635629	634461	19715Y	PARTICIPANT	\N	PRESENT	0
635630	634461	19723Y	PARTICIPANT	\N	PRESENT	0
635697	634461	01034P	PARTICIPANT	\N	PRESENT	1
635698	634461	17965H	PARTICIPANT	\N	PRESENT	0
635701	634461	04043D	PARTICIPANT	\N	PRESENT	0
635771	634461	20066E	PARTICIPANT	\N	PRESENT	0
635778	635777	14033T	PARTICIPANT	\N	PRESENT	0
635779	635777	14205J	PARTICIPANT	\N	PRESENT	0
639007	639006	19629C	PARTICIPANT	\N	PRESENT	0
639008	639006	14038Y	PARTICIPANT	\N	PRESENT	0
639009	639006	20092G	PARTICIPANT	\N	PRESENT	0
641383	640959	01028R	PARTICIPANT	\N	EXCUSE	0
641384	640959	19479G	PARTICIPANT	\N	EXCUSE	0
641451	641448	04070G	PARTICIPANT	\N	PRESENT	0
641452	641448	20094J	PARTICIPANT	\N	PRESENT	0
641453	641449	04070G	PARTICIPANT	\N	PRESENT	0
641454	641449	20094J	PARTICIPANT	\N	PRESENT	0
641455	641450	04070G	PARTICIPANT	\N	PRESENT	0
641456	641450	20094J	PARTICIPANT	\N	PRESENT	0
641458	641457	14215L	PARTICIPANT	\N	PRESENT	0
641459	641457	19629C	PARTICIPANT	\N	PRESENT	0
641586	641585	11026G	PARTICIPANT	\N	PRESENT	0
641587	641585	10015M	PARTICIPANT	\N	PRESENT	0
641589	641588	11026G	PARTICIPANT	\N	PRESENT	0
641590	641588	10015M	PARTICIPANT	\N	PRESENT	0
641592	641591	18083K	PARTICIPANT	\N	PRESENT	0
643826	643416	19415P	PARTICIPANT	\N	PRESENT	0
643827	643416	20090E	PARTICIPANT	\N	PRESENT	0
643828	643416	11067R	PARTICIPANT	\N	PRESENT	0
643829	643416	20130U	PARTICIPANT	\N	PRESENT	0
644514	644513	14231L	PARTICIPANT	\N	PRESENT	0
644515	644513	14259Y	PARTICIPANT	\N	PRESENT	0
644747	643817	14219Q	PARTICIPANT	\N	PRESENT	0
644748	643817	19251M	PARTICIPANT	\N	PRESENT	0
644749	643817	19826F	PARTICIPANT	\N	PRESENT	0
644750	643817	17229F	PARTICIPANT	\N	PRESENT	0
644751	643817	18083K	PARTICIPANT	\N	PRESENT	0
644752	643817	19503N	PARTICIPANT	\N	PRESENT	0
644753	643817	20020P	PARTICIPANT	\N	PRESENT	0
644754	643817	20024T	PARTICIPANT	\N	PRESENT	0
644755	643817	11065P	PARTICIPANT	\N	PRESENT	0
644756	644423	95063L	PARTICIPANT	\N	PRESENT	0
644757	644423	19691J	PARTICIPANT	\N	PRESENT	0
644758	644423	05008E	PARTICIPANT	\N	PRESENT	0
644759	644423	01028R	PARTICIPANT	\N	PRESENT	0
644760	644423	14231L	PARTICIPANT	\N	PRESENT	0
644761	643817	19681G	PARTICIPANT	\N	PRESENT	0
644762	644423	20034V	PARTICIPANT	\N	PRESENT	0
644881	644880	19725B	PARTICIPANT	\N	PRESENT	0
644882	644880	14331P	PARTICIPANT	\N	PRESENT	0
644884	643797	19691J	PARTICIPANT	\N	EXCUSE	0
644922	644424	07004J	PARTICIPANT	\N	EXCUSE	0
644967	644424	04047H	PRESIDENT	0	PRESENT	0
644968	644424	19673G	PARTICIPANT	\N	PRESENT	0
644969	644424	95063L	PARTICIPANT	\N	PRESENT	0
644972	644407	20106U	PARTICIPANT	\N	PRESENT	1
644973	644407	01024M	PARTICIPANT	\N	PRESENT	0
644980	644650	14331P	PARTICIPANT	\N	EXCUSE	0
644981	644424	19725B	PARTICIPANT	\N	PRESENT	0
644983	644982	01062T	PARTICIPANT	\N	PRESENT	0
644986	644985	19768N	PARTICIPANT	\N	PRESENT	0
644987	644985	19369B	PARTICIPANT	\N	PRESENT	0
644988	644985	04045F	PARTICIPANT	\N	PRESENT	0
644989	644985	19383Y	PARTICIPANT	\N	PRESENT	0
644991	644990	19768N	PARTICIPANT	\N	PRESENT	0
645041	645040	19593H	PARTICIPANT	\N	PRESENT	0
645042	645040	20026V	PARTICIPANT	\N	PRESENT	1
645043	644613	11109J	PARTICIPANT	\N	EXCUSE	0
645044	644613	08012N	PARTICIPANT	\N	PRESENT	0
645045	644613	19758L	PARTICIPANT	\N	PRESENT	0
645046	644613	04059M	PARTICIPANT	\N	PRESENT	0
645047	644613	19611R	PRESIDENT	0	PRESENT	0
645048	644613	19699S	PARTICIPANT	\N	PRESENT	0
645049	644613	19573D	PARTICIPANT	\N	PRESENT	0
645050	644613	19399H	PARTICIPANT	\N	PRESENT	0
649550	649161	20914V	PARTICIPANT	\N	PRESENT	0
649551	649161	14097Y	PARTICIPANT	\N	PRESENT	0
649552	649161	19687N	PARTICIPANT	\N	PRESENT	0
649553	649161	19695N	PARTICIPANT	\N	PRESENT	0
649554	649161	20112S	PARTICIPANT	\N	PRESENT	0
649555	649161	11056N	PARTICIPANT	\N	PRESENT	0
649556	649161	19549D	PARTICIPANT	\N	PRESENT	0
649557	649161	19599P	PARTICIPANT	\N	PRESENT	0
649558	649161	20080C	PARTICIPANT	\N	PRESENT	0
649559	649161	14121F	PARTICIPANT	\N	PRESENT	0
649561	649161	20036X	PARTICIPANT	\N	PRESENT	0
649564	649161	11077T	PARTICIPANT	\N	PRESENT	0
649567	649161	20100N	PARTICIPANT	\N	PRESENT	0
649570	649161	01062T	PARTICIPANT	\N	PRESENT	0
649571	649161	11048N	PARTICIPANT	\N	PRESENT	0
649572	649161	19399H	PARTICIPANT	\N	PRESENT	0
649573	649161	14225N	PARTICIPANT	\N	PRESENT	0
649574	649161	19349W	PARTICIPANT	\N	PRESENT	0
649575	649161	20116W	PARTICIPANT	\N	PRESENT	0
649576	649161	19387D	PARTICIPANT	\N	PRESENT	0
649577	649161	19545Y	PARTICIPANT	\N	PRESENT	0
649578	649161	19329S	PARTICIPANT	\N	PRESENT	0
649579	649161	11083R	PARTICIPANT	\N	PRESENT	0
649580	649161	14107H	PARTICIPANT	\N	PRESENT	0
649581	649161	19629C	PARTICIPANT	\N	PRESENT	0
649582	649161	19479G	PARTICIPANT	\N	PRESENT	0
649583	649161	01024M	PARTICIPANT	\N	PRESENT	0
649584	649161	20252E	PARTICIPANT	\N	PRESENT	0
649585	649161	19798U	PARTICIPANT	\N	PRESENT	0
649586	649161	20090E	PARTICIPANT	\N	PRESENT	0
649587	649161	19647E	PARTICIPANT	\N	PRESENT	0
649588	649161	20052X	PARTICIPANT	\N	PRESENT	0
649589	649161	11053K	PARTICIPANT	\N	PRESENT	0
649590	649161	11103C	PARTICIPANT	\N	PRESENT	0
649591	649161	97011G	PARTICIPANT	\N	PRESENT	0
649592	649161	14105F	PARTICIPANT	\N	PRESENT	0
649593	649161	14223L	PARTICIPANT	\N	PRESENT	0
649594	649161	20172F	PARTICIPANT	\N	PRESENT	0
649595	649161	19703U	PARTICIPANT	\N	PRESENT	0
649596	649161	14071N	PARTICIPANT	\N	PRESENT	0
649597	649161	20058E	PARTICIPANT	\N	PRESENT	0
649598	649161	20098N	PARTICIPANT	\N	PRESENT	0
649599	649161	20086J	PARTICIPANT	\N	PRESENT	0
649600	649161	19741B	PARTICIPANT	\N	PRESENT	0
649601	649161	20140W	PARTICIPANT	\N	PRESENT	0
649602	649161	20180F	PARTICIPANT	\N	PRESENT	0
649603	649161	19667J	PARTICIPANT	\N	PRESENT	0
649604	649161	20056C	PARTICIPANT	\N	PRESENT	0
649605	649161	19057M	PARTICIPANT	\N	PRESENT	0
649606	649161	19723Y	PARTICIPANT	\N	PRESENT	0
649607	649161	20038A	PARTICIPANT	\N	PRESENT	0
649608	649161	04071H	PARTICIPANT	\N	PRESENT	0
649609	649161	20074E	PARTICIPANT	\N	PRESENT	0
649610	649161	18083K	PARTICIPANT	\N	PRESENT	0
649611	649161	19711U	PARTICIPANT	\N	PRESENT	0
649612	649161	20044X	PARTICIPANT	\N	PRESENT	0
649613	649161	20022R	PARTICIPANT	\N	PRESENT	0
649614	649161	14083S	PARTICIPANT	\N	PRESENT	0
649615	649161	14217N	PARTICIPANT	\N	PRESENT	0
649616	649161	19421M	PARTICIPANT	\N	PRESENT	0
649617	649161	14327T	PARTICIPANT	\N	PRESENT	0
649618	649161	01057W	PARTICIPANT	\N	PRESENT	0
649619	649161	19762G	PARTICIPANT	\N	PRESENT	0
649620	649161	19531S	PARTICIPANT	\N	PRESENT	0
649621	649161	14042U	PARTICIPANT	\N	PRESENT	0
649622	649161	14219Q	PARTICIPANT	\N	PRESENT	0
649623	649161	14030Q	PARTICIPANT	\N	PRESENT	0
649548	649161	11070L	PARTICIPANT	\N	PRESENT	0
649549	649161	19758L	PARTICIPANT	\N	PRESENT	0
649624	649161	08010L	PARTICIPANT	\N	PRESENT	0
649625	649161	20126Y	PARTICIPANT	\N	PRESENT	0
649626	649161	07029T	PARTICIPANT	\N	PRESENT	0
649627	649161	14213J	PARTICIPANT	\N	PRESENT	0
649628	649161	14073Q	PARTICIPANT	\N	PRESENT	0
649629	649161	19760E	PARTICIPANT	\N	PRESENT	0
649630	649161	19577H	PARTICIPANT	\N	PRESENT	0
649631	649161	14089Y	PARTICIPANT	\N	PRESENT	0
649632	649161	19713W	PARTICIPANT	\N	PRESENT	0
649633	649161	14069U	PARTICIPANT	\N	PRESENT	0
649634	649161	14259Y	PARTICIPANT	\N	PRESENT	0
649635	649161	20024T	PARTICIPANT	\N	PRESENT	0
649636	649161	20102Q	PARTICIPANT	\N	PRESENT	0
649637	649161	20070A	PARTICIPANT	\N	PRESENT	0
649638	649161	20118Y	PARTICIPANT	\N	PRESENT	0
649639	649156	19443T	PARTICIPANT	\N	PRESENT	0
649640	649156	12041X	PARTICIPANT	\N	PRESENT	0
649641	649156	20072C	PARTICIPANT	\N	PRESENT	0
649642	649156	01058X	PARTICIPANT	\N	PRESENT	0
649643	649156	11027H	PARTICIPANT	\N	PRESENT	0
649644	649156	16685X	PARTICIPANT	\N	PRESENT	0
649645	649156	04042C	PRESIDENT	0	PRESENT	0
649646	649156	11054L	PARTICIPANT	\N	PRESENT	0
649647	649156	11066Q	PARTICIPANT	\N	PRESENT	0
649648	649156	08056B	PARTICIPANT	\N	PRESENT	0
649649	649156	12028B	PARTICIPANT	\N	PRESENT	0
649650	649156	19421M	PARTICIPANT	\N	PRESENT	0
651694	649319	20102Q	PARTICIPANT	\N	PRESENT	1
649652	649156	19347U	PARTICIPANT	\N	PRESENT	0
649653	649156	97011G	PARTICIPANT	\N	PRESENT	0
649654	649156	08061X	PARTICIPANT	\N	PRESENT	0
649655	649156	14249W	PARTICIPANT	\N	PRESENT	0
649656	649156	08047A	PARTICIPANT	\N	PRESENT	0
649657	649156	14097Y	PARTICIPANT	\N	PRESENT	0
649658	649156	04035D	PARTICIPANT	\N	PRESENT	0
649659	649156	14133K	PARTICIPANT	\N	PRESENT	1
649660	649156	01062T	PARTICIPANT	\N	PRESENT	0
649661	649156	11041F	PARTICIPANT	\N	PRESENT	0
649662	649156	20042V	PARTICIPANT	\N	PRESENT	0
649663	649156	01024M	PARTICIPANT	\N	PRESENT	0
649664	649156	14105F	PARTICIPANT	\N	PRESENT	0
649665	649156	20064C	PARTICIPANT	\N	PRESENT	0
649666	649156	14267Y	PARTICIPANT	\N	PRESENT	0
649667	649156	11083R	PARTICIPANT	\N	PRESENT	0
649668	649156	14211G	PARTICIPANT	\N	PRESENT	0
649669	649156	14255U	PARTICIPANT	\N	PRESENT	0
649670	649156	17023S	PARTICIPANT	\N	PRESENT	0
649671	649156	07033P	PARTICIPANT	\N	EXCUSE	0
649672	649161	19563B	PARTICIPANT	\N	PRESENT	0
649673	649161	11074Q	PARTICIPANT	\N	PRESENT	0
649677	649161	20054A	PARTICIPANT	\N	PRESENT	0
649678	649161	11045K	PARTICIPANT	\N	PRESENT	0
649679	649161	20130U	PARTICIPANT	\N	PRESENT	0
649680	649161	19739H	PARTICIPANT	\N	PRESENT	0
649681	649161	14151M	PARTICIPANT	\N	PRESENT	0
649682	649161	11012A	PARTICIPANT	\N	PRESENT	0
649683	649161	19699S	PARTICIPANT	\N	PRESENT	0
651692	649319	20032T	PARTICIPANT	\N	PRESENT	1
651693	649319	19659J	PARTICIPANT	\N	PRESENT	1
651695	649319	19333N	PARTICIPANT	\N	PRESENT	1
651696	649319	19525U	PARTICIPANT	\N	PRESENT	1
651697	649319	14169X	PARTICIPANT	\N	PRESENT	1
651698	649319	19387D	PARTICIPANT	\N	PRESENT	1
651699	649319	20046A	PARTICIPANT	\N	PRESENT	1
651700	649319	20068G	PARTICIPANT	\N	PRESENT	1
651701	649319	08060W	PARTICIPANT	\N	PRESENT	1
651702	649319	19745F	PARTICIPANT	\N	PRESENT	1
651703	649319	20100N	PARTICIPANT	\N	PRESENT	1
651704	649319	19637C	PARTICIPANT	\N	PRESENT	1
651705	649319	19549D	PARTICIPANT	\N	PRESENT	1
651706	649319	19251M	PARTICIPANT	\N	EXCUSE	0
651707	649319	05012A	PARTICIPANT	\N	EXCUSE	0
651728	651645	20078J	PARTICIPANT	\N	PRESENT	1
651729	651645	08028W	PARTICIPANT	\N	EXCUSE	0
651730	651645	19507S	PARTICIPANT	\N	EXCUSE	0
651731	651645	01043Q	PARTICIPANT	\N	PRESENT	1
651732	651645	19441R	PARTICIPANT	\N	EXCUSE	0
651733	651645	20028X	PARTICIPANT	\N	EXCUSE	0
651734	651645	20082E	PARTICIPANT	\N	PRESENT	1
651735	651645	19369B	PARTICIPANT	\N	EXCUSE	0
651736	651645	14205J	PARTICIPANT	\N	PRESENT	1
651737	650957	20248J	PARTICIPANT	\N	EXCUSE	0
651738	650957	14213J	PARTICIPANT	\N	PRESENT	1
651739	650957	14217N	PARTICIPANT	\N	PRESENT	1
651740	650957	19715Y	PARTICIPANT	\N	PRESENT	1
651741	650957	19798U	PARTICIPANT	\N	PRESENT	1
651742	650957	11103C	PARTICIPANT	\N	PRESENT	1
651743	650957	17779H	PARTICIPANT	\N	PRESENT	1
651744	650957	19591F	PARTICIPANT	\N	PRESENT	1
651745	650957	11067R	PARTICIPANT	\N	PRESENT	1
651746	650957	19569H	PARTICIPANT	\N	PRESENT	1
651747	650957	11097X	PARTICIPANT	\N	PRESENT	1
629881	628913	14133K	PARTICIPANT	\N	PRESENT	0
629882	628913	20104S	PARTICIPANT	\N	PRESENT	0
629883	628913	19701S	PARTICIPANT	\N	PRESENT	1
629884	628913	11101A	PARTICIPANT	\N	PRESENT	0
629885	628913	20100N	PARTICIPANT	\N	PRESENT	0
629886	628913	11083R	PARTICIPANT	\N	PRESENT	1
629887	628913	12016W	PARTICIPANT	\N	PRESENT	0
629888	628913	14073Q	PARTICIPANT	\N	PRESENT	0
629903	628913	20042V	PARTICIPANT	\N	PRESENT	0
629890	628913	14097Y	PARTICIPANT	\N	PRESENT	1
629891	628913	14189C	PARTICIPANT	\N	PRESENT	0
629892	628913	19333N	PARTICIPANT	\N	PRESENT	0
629893	628913	04057K	PARTICIPANT	\N	PRESENT	0
629895	628913	14331P	PRESIDENT	0	PRESENT	0
629904	628913	14255U	PARTICIPANT	\N	PRESENT	0
629905	628913	04042C	PARTICIPANT	\N	PRESENT	0
629906	628913	12028B	PARTICIPANT	\N	PRESENT	0
629907	628913	01024M	PARTICIPANT	\N	PRESENT	0
629908	628913	97011G	PARTICIPANT	\N	PRESENT	0
629909	628913	08056B	PARTICIPANT	\N	PRESENT	0
629910	628913	19565D	PARTICIPANT	\N	PRESENT	0
629911	628913	16685X	PARTICIPANT	\N	PRESENT	0
629912	628913	12041X	PARTICIPANT	\N	PRESENT	0
631142	627014	19251M	PARTICIPANT	\N	PRESENT	1
631143	629311	20174H	PARTICIPANT	\N	PRESENT	0
631144	629311	19758L	PARTICIPANT	\N	PRESENT	0
631145	627014	19745F	PARTICIPANT	\N	PRESENT	0
631146	629311	11031D	PARTICIPANT	\N	PRESENT	0
631147	629324	20038A	PARTICIPANT	\N	PRESENT	0
631148	629324	19585H	PARTICIPANT	\N	PRESENT	0
631149	627014	14169X	PARTICIPANT	\N	PRESENT	0
631151	627014	05012A	PARTICIPANT	\N	PRESENT	0
631152	627014	19525U	PARTICIPANT	\N	PRESENT	0
631153	629311	14030Q	PARTICIPANT	\N	PRESENT	0
631155	629311	97011G	PARTICIPANT	\N	PRESENT	0
631156	629311	20062A	PARTICIPANT	\N	PRESENT	0
631157	629311	14147R	PARTICIPANT	\N	PRESENT	0
631158	629311	01043Q	PARTICIPANT	\N	PRESENT	0
631159	629311	14179A	PARTICIPANT	\N	PRESENT	0
631160	629311	01024M	PARTICIPANT	\N	PRESENT	0
631161	629311	20056C	PARTICIPANT	\N	PRESENT	0
631162	629311	20098N	PARTICIPANT	\N	PRESENT	0
631163	629311	14189C	PARTICIPANT	\N	PRESENT	0
631164	629311	14217N	PARTICIPANT	\N	PRESENT	0
631165	629311	19697Q	PARTICIPANT	\N	PRESENT	0
631166	629311	20120S	PARTICIPANT	\N	PRESENT	0
631167	629311	20026V	PARTICIPANT	\N	PRESENT	0
631168	629311	20096L	PARTICIPANT	\N	PRESENT	0
631172	629311	20104S	PARTICIPANT	\N	PRESENT	0
631170	629311	20048C	PARTICIPANT	\N	PRESENT	0
631171	629311	20052X	PARTICIPANT	\N	PRESENT	0
631173	629311	19782L	PARTICIPANT	\N	PRESENT	0
631174	629311	08015R	PARTICIPANT	\N	PRESENT	0
631175	629311	20022R	PARTICIPANT	\N	PRESENT	0
631176	629311	20084G	PARTICIPANT	\N	PRESENT	0
631177	629311	19631V	PARTICIPANT	\N	PRESENT	0
631178	629311	14073Q	PARTICIPANT	\N	PRESENT	0
631179	629311	19954N	PARTICIPANT	\N	PRESENT	0
631180	629311	16685X	PARTICIPANT	\N	PRESENT	0
631181	629311	19739H	PARTICIPANT	\N	PRESENT	0
631182	629311	19479G	PARTICIPANT	\N	PRESENT	0
631183	629311	19619A	PARTICIPANT	\N	PRESENT	0
631184	629311	01028R	PARTICIPANT	\N	PRESENT	0
631186	629311	01034P	PARTICIPANT	\N	PRESENT	0
631187	629311	20180F	PARTICIPANT	\N	PRESENT	0
631188	629311	19747H	PARTICIPANT	\N	PRESENT	0
631189	629311	19611R	PARTICIPANT	\N	PRESENT	0
631190	629324	17737W	PARTICIPANT	\N	PRESENT	0
631191	629311	19441R	PARTICIPANT	\N	PRESENT	0
631192	629311	19673G	PARTICIPANT	\N	PRESENT	0
631193	627014	19549D	PARTICIPANT	\N	PRESENT	0
631194	627014	19637C	PARTICIPANT	\N	PRESENT	0
631195	627014	14237S	PARTICIPANT	\N	PRESENT	0
631196	627014	20100N	PARTICIPANT	\N	PRESENT	0
631197	629311	17637T	PARTICIPANT	\N	PRESENT	0
631208	629311	04047H	PARTICIPANT	\N	PRESENT	0
631209	629311	11053K	PARTICIPANT	\N	PRESENT	0
631210	629311	20286Q	PARTICIPANT	\N	PRESENT	0
631211	629311	20058E	PARTICIPANT	\N	PRESENT	0
631214	627014	14219Q	PRESIDENT	0	PRESENT	0
631215	627014	20032T	PARTICIPANT	\N	PRESENT	0
631216	627014	20102Q	PARTICIPANT	\N	PRESENT	0
631217	629311	19760E	PARTICIPANT	\N	PRESENT	0
631218	629311	19695N	PARTICIPANT	\N	PRESENT	0
631219	629324	19531S	PARTICIPANT	\N	PRESENT	0
631220	629311	14033T	PARTICIPANT	\N	PRESENT	0
631221	629311	11012A	PARTICIPANT	\N	PRESENT	0
631222	629311	19687N	PARTICIPANT	\N	PRESENT	0
631223	629311	19563B	PARTICIPANT	\N	PRESENT	0
631224	629324	14257W	PARTICIPANT	\N	PRESENT	0
631225	629311	19467C	PARTICIPANT	\N	PRESENT	0
631226	629311	01058X	PARTICIPANT	\N	PRESENT	0
631227	629311	19683J	PARTICIPANT	\N	PRESENT	0
631229	629311	20092G	PARTICIPANT	\N	PRESENT	0
631230	629311	20248J	PARTICIPANT	\N	PRESENT	0
631231	629311	14053L	PARTICIPANT	\N	PRESENT	0
631232	631228	18083K	PARTICIPANT	\N	PRESENT	0
631233	631228	20266L	PARTICIPANT	\N	PRESENT	0
631234	631228	17965H	PRESIDENT	0	PRESENT	0
631235	631228	19760E	PARTICIPANT	\N	PRESENT	0
631236	629311	11090Q	PARTICIPANT	\N	PRESENT	0
631237	629311	14105F	PARTICIPANT	\N	PRESENT	0
631238	629311	14195A	PARTICIPANT	\N	PRESENT	0
631239	629311	19719D	PARTICIPANT	\N	PRESENT	0
631240	627014	20024T	PARTICIPANT	\N	PRESENT	0
631244	630083	19577H	PARTICIPANT	\N	PRESENT	1
631245	629311	20130U	PARTICIPANT	\N	PRESENT	0
631246	629311	11067R	PARTICIPANT	\N	PRESENT	0
631247	629311	08061X	PARTICIPANT	\N	PRESENT	0
631248	629311	20032T	PARTICIPANT	\N	PRESENT	0
631249	629311	19691J	PARTICIPANT	\N	PRESENT	0
631250	629311	14151M	PARTICIPANT	\N	PRESENT	0
631313	629312	14026U	PARTICIPANT	\N	PRESENT	0
631314	629312	01034P	PARTICIPANT	\N	PRESENT	0
631315	629312	19691J	PARTICIPANT	\N	PRESENT	0
631316	629312	20130U	PARTICIPANT	\N	PRESENT	0
631317	629312	11031D	PARTICIPANT	\N	PRESENT	0
631318	629312	14042U	PARTICIPANT	\N	PRESENT	0
631319	629312	20132W	PARTICIPANT	\N	PRESENT	0
631320	629312	19683J	PARTICIPANT	\N	PRESENT	0
631321	629312	14151M	PARTICIPANT	\N	PRESENT	0
631322	629312	11067R	PARTICIPANT	\N	PRESENT	0
631323	629312	19697Q	PARTICIPANT	\N	PRESENT	0
631324	629312	19782L	PARTICIPANT	\N	PRESENT	0
631325	629312	20110Q	PARTICIPANT	\N	PRESENT	0
631326	629312	20092G	PARTICIPANT	\N	PRESENT	0
631327	629312	20062A	PARTICIPANT	\N	PRESENT	0
631328	629312	14217N	PARTICIPANT	\N	PRESENT	0
631329	629312	20096L	PARTICIPANT	\N	PRESENT	0
631330	629312	19651A	PARTICIPANT	\N	PRESENT	0
631331	629312	19629C	PARTICIPANT	\N	PRESENT	0
631332	629312	11012A	PARTICIPANT	\N	PRESENT	0
631333	629312	19719D	PARTICIPANT	\N	PRESENT	0
631334	629312	20248J	PARTICIPANT	\N	PRESENT	0
631335	629312	19441R	PARTICIPANT	\N	PRESENT	0
631336	629312	17637T	PARTICIPANT	\N	PRESENT	0
631337	629312	20024T	PARTICIPANT	\N	PRESENT	0
631338	629312	11097X	PARTICIPANT	\N	PRESENT	0
631339	629312	08061X	PARTICIPANT	\N	PRESENT	0
631340	629312	14038Y	PARTICIPANT	\N	PRESENT	0
631341	629312	14195A	PARTICIPANT	\N	PRESENT	0
631342	629312	01028R	PARTICIPANT	\N	PRESENT	0
631343	629312	19347U	PARTICIPANT	\N	PRESENT	0
631344	629312	97011G	PARTICIPANT	\N	PRESENT	0
631350	629312	01024M	PARTICIPANT	\N	PRESENT	0
631361	629312	14257W	PARTICIPANT	\N	PRESENT	0
631362	629312	19515S	PARTICIPANT	\N	PRESENT	0
631363	629312	20286Q	PARTICIPANT	\N	PRESENT	0
631364	629312	20018V	PARTICIPANT	\N	PRESENT	0
631365	629312	19768N	PARTICIPANT	\N	PRESENT	0
631366	629312	19695N	PARTICIPANT	\N	PRESENT	0
631367	629312	18193Q	PARTICIPANT	\N	PRESENT	0
643414	643412	01025N	PARTICIPANT	\N	PRESENT	0
643415	643412	20094J	PARTICIPANT	\N	PRESENT	0
643447	643446	05008E	PARTICIPANT	\N	PRESENT	0
643448	643446	11053K	PARTICIPANT	\N	PRESENT	0
643449	643446	01028R	PARTICIPANT	\N	PRESENT	0
643451	643450	14133K	PARTICIPANT	\N	PRESENT	1
643452	643450	20042V	PARTICIPANT	\N	PRESENT	0
643453	643450	14105F	PARTICIPANT	\N	PRESENT	1
643454	643450	04042C	PRESIDENT	0	PRESENT	0
643455	643450	11027H	PARTICIPANT	\N	PRESENT	0
643456	643450	01024M	PARTICIPANT	\N	PRESENT	1
643457	643450	07033P	PARTICIPANT	\N	EXCUSE	0
643458	643450	17023S	PARTICIPANT	\N	PRESENT	0
643459	643450	11083R	PARTICIPANT	\N	PRESENT	1
643460	643450	19347U	PARTICIPANT	\N	PRESENT	1
643461	643450	19565D	PARTICIPANT	\N	EXCUSE	0
643462	643450	20072C	PARTICIPANT	\N	PRESENT	1
643463	643450	08069G	PARTICIPANT	\N	PRESENT	0
643464	643450	16685X	PARTICIPANT	\N	PRESENT	0
643465	643450	08047A	PARTICIPANT	\N	PRESENT	0
643466	643450	19443T	PARTICIPANT	\N	PRESENT	0
643467	643450	11054L	PARTICIPANT	\N	PRESENT	1
643468	643450	01058X	PARTICIPANT	\N	PRESENT	0
643469	643450	01062T	PARTICIPANT	\N	PRESENT	0
643470	643450	20064C	PARTICIPANT	\N	EXCUSE	0
643471	643450	11066Q	PARTICIPANT	\N	PRESENT	0
643473	643450	14193X	PARTICIPANT	\N	PRESENT	1
643474	643450	19669L	PARTICIPANT	\N	PRESENT	1
643510	643509	11027H	PARTICIPANT	\N	PRESENT	0
643521	642864	19715Y	PRESIDENT	0	PRESENT	0
643534	643533	14030Q	PRESIDENT	0	PRESENT	0
643535	643533	14189C	PARTICIPANT	\N	EXCUSE	0
643536	643533	20024T	PARTICIPANT	\N	PRESENT	0
643537	643533	20138D	PARTICIPANT	\N	PRESENT	1
643538	643533	20080C	PARTICIPANT	\N	EXCUSE	0
643539	643533	11031D	PARTICIPANT	\N	PRESENT	0
643540	643533	07029T	PARTICIPANT	\N	EXCUSE	0
643541	643533	14109K	PARTICIPANT	\N	PRESENT	1
643542	643533	19798U	PARTICIPANT	\N	PRESENT	1
643543	643533	20098N	PARTICIPANT	\N	EXCUSE	0
643544	643533	19527W	PARTICIPANT	\N	PRESENT	1
643545	643533	19749K	PARTICIPANT	\N	PRESENT	1
643611	643392	19543W	PARTICIPANT	\N	PRESENT	1
643612	643392	20022R	PARTICIPANT	\N	PRESENT	1
643613	643392	20110Q	PARTICIPANT	\N	PRESENT	1
643614	643392	20114U	PARTICIPANT	\N	PRESENT	1
643615	643392	17737W	PARTICIPANT	\N	PRESENT	1
643616	643392	11056N	PARTICIPANT	\N	PRESENT	1
643617	643392	20074E	PARTICIPANT	\N	PRESENT	1
643618	643392	19725B	PARTICIPANT	\N	PRESENT	1
643619	643392	20128B	PARTICIPANT	\N	PRESENT	1
643620	643392	14179A	PARTICIPANT	\N	PRESENT	1
643621	643392	19489J	PARTICIPANT	\N	PRESENT	1
643622	643392	20108W	PARTICIPANT	\N	PRESENT	1
643623	643392	19581D	PARTICIPANT	\N	PRESENT	1
643624	643392	14147R	PARTICIPANT	\N	PRESENT	1
643625	643392	11072N	PARTICIPANT	\N	PRESENT	1
643626	643392	10015M	PARTICIPANT	\N	PRESENT	1
643627	643392	14107H	PARTICIPANT	\N	PRESENT	1
643628	643392	19749K	PARTICIPANT	\N	PRESENT	1
643629	643392	19585H	PARTICIPANT	\N	PRESENT	1
643630	643392	14109K	PARTICIPANT	\N	PRESENT	1
643631	643392	20124W	PARTICIPANT	\N	PRESENT	0
643632	643392	14231L	PARTICIPANT	\N	EXCUSE	0
643633	643392	08018U	PARTICIPANT	\N	EXCUSE	0
643634	643392	07004J	PARTICIPANT	\N	EXCUSE	0
643635	643392	19447X	PARTICIPANT	\N	EXCUSE	0
643636	642864	18083K	PARTICIPANT	\N	PRESENT	0
643637	642864	20034V	PARTICIPANT	\N	PRESENT	1
643638	642864	14097Y	PARTICIPANT	\N	PRESENT	0
643639	642864	19657G	PARTICIPANT	\N	PRESENT	1
643640	642864	14147R	PARTICIPANT	\N	PRESENT	1
643641	642864	20146D	PARTICIPANT	\N	PRESENT	0
643642	642864	19319Q	PARTICIPANT	\N	PRESENT	1
643643	642864	19387D	PARTICIPANT	\N	PRESENT	1
643644	642864	19659J	PARTICIPANT	\N	PRESENT	1
643645	642864	01024M	PARTICIPANT	\N	PRESENT	1
643646	642864	19577H	PARTICIPANT	\N	PRESENT	1
643647	642864	14073Q	PARTICIPANT	\N	PRESENT	1
643648	642864	14213J	PARTICIPANT	\N	PRESENT	1
643649	642864	19347U	PARTICIPANT	\N	PRESENT	1
643660	643659	11053K	PARTICIPANT	\N	PRESENT	0
643663	643662	99004R	PARTICIPANT	\N	PRESENT	0
643664	643662	19399H	PARTICIPANT	\N	PRESENT	0
643667	643665	19741B	PARTICIPANT	\N	PRESENT	0
643668	643666	19741B	PARTICIPANT	\N	PRESENT	0
643670	643669	14327T	PARTICIPANT	\N	PRESENT	0
643676	643675	14133K	PARTICIPANT	\N	PRESENT	1
643677	643675	11083R	PARTICIPANT	\N	PRESENT	1
643678	643675	11066Q	PARTICIPANT	\N	PRESENT	1
643679	643675	11027H	PARTICIPANT	\N	PRESENT	1
643681	643680	14133K	PARTICIPANT	\N	PRESENT	0
643682	643680	11083R	PARTICIPANT	\N	PRESENT	0
643683	643680	11066Q	PARTICIPANT	\N	PRESENT	0
643684	643680	11027H	PARTICIPANT	\N	PRESENT	0
643687	643686	19695N	PARTICIPANT	\N	PRESENT	0
643688	643686	01025N	PARTICIPANT	\N	PRESENT	0
643689	643686	20094J	PARTICIPANT	\N	PRESENT	0
643691	643690	19695N	PARTICIPANT	\N	PRESENT	1
643692	643690	20094J	PARTICIPANT	\N	PRESENT	1
643693	643690	01025N	PARTICIPANT	\N	PRESENT	1
643694	643690	20092G	PARTICIPANT	\N	PRESENT	1
643696	643695	19695N	PARTICIPANT	\N	PRESENT	0
643697	643695	20094J	PARTICIPANT	\N	PRESENT	0
643698	643695	01025N	PARTICIPANT	\N	PRESENT	0
643700	643699	20094J	PARTICIPANT	\N	PRESENT	1
643701	643699	01025N	PARTICIPANT	\N	PRESENT	1
643703	643702	20094J	PARTICIPANT	\N	PRESENT	1
643704	643702	01025N	PARTICIPANT	\N	PRESENT	1
643706	643705	20076G	PARTICIPANT	\N	PRESENT	0
643707	643705	14205J	PARTICIPANT	\N	PRESENT	0
643708	643705	19826F	PARTICIPANT	\N	PRESENT	0
643709	643705	20054A	PARTICIPANT	\N	PRESENT	0
643711	643710	20076G	PARTICIPANT	\N	PRESENT	0
643712	643710	19826F	PARTICIPANT	\N	PRESENT	0
643713	643710	20054A	PARTICIPANT	\N	PRESENT	0
643715	643714	20076G	PARTICIPANT	\N	PRESENT	0
643716	643714	20054A	PARTICIPANT	\N	PRESENT	0
643717	643714	19826F	PARTICIPANT	\N	PRESENT	0
643718	643714	14205J	PARTICIPANT	\N	PRESENT	0
643795	643794	20026V	PARTICIPANT	\N	PRESENT	0
643796	643794	19593H	PARTICIPANT	\N	PRESENT	0
643888	643759	19798U	PARTICIPANT	\N	PRESENT	1
643889	643759	20114U	PARTICIPANT	\N	PRESENT	1
643890	643759	19643A	PARTICIPANT	\N	PRESENT	1
643905	643651	14327T	PARTICIPANT	\N	PRESENT	0
643906	643651	11048N	PARTICIPANT	\N	PRESENT	0
643907	643651	14225N	PRESIDENT	0	PRESENT	0
643908	643651	14189C	PARTICIPANT	\N	EXCUSE	0
643909	643651	01057W	PARTICIPANT	\N	EXCUSE	0
643910	643651	20116W	PARTICIPANT	\N	EXCUSE	0
643912	643651	14331P	PARTICIPANT	\N	PRESENT	0
643913	643651	04071H	PARTICIPANT	\N	PRESENT	0
643914	643651	19711U	PARTICIPANT	\N	PRESENT	0
643916	643651	11040E	PARTICIPANT	\N	PRESENT	0
643917	643651	07029T	PARTICIPANT	\N	PRESENT	0
643918	643651	08010L	PARTICIPANT	\N	PRESENT	0
643920	643651	99004R	PARTICIPANT	\N	PRESENT	0
643921	643651	20126Y	PARTICIPANT	\N	PRESENT	1
643922	643651	19762G	PARTICIPANT	\N	PRESENT	0
643953	643951	14097Y	PARTICIPANT	\N	PRESENT	0
643954	643951	19515S	PARTICIPANT	\N	PRESENT	0
643955	643951	20074E	PARTICIPANT	\N	PRESENT	0
643956	643951	20082E	PRESIDENT	0	PRESENT	0
643957	643951	20050V	PARTICIPANT	\N	PRESENT	0
643958	643951	19369B	PARTICIPANT	\N	PRESENT	0
643959	643951	20126Y	PARTICIPANT	\N	PRESENT	0
643960	643951	20144B	PARTICIPANT	\N	PRESENT	0
643963	643651	08034U	PARTICIPANT	\N	PRESENT	0
643964	643651	11070L	PARTICIPANT	\N	PRESENT	0
643965	643651	19671E	PARTICIPANT	\N	PRESENT	0
643966	643651	19399H	PARTICIPANT	\N	PRESENT	0
643967	643651	19741B	PARTICIPANT	\N	PRESENT	0
643968	643651	20050V	PARTICIPANT	\N	EXCUSE	0
643970	643969	14083S	PARTICIPANT	\N	PRESENT	0
643971	643969	19553Y	PARTICIPANT	\N	PRESENT	0
643972	643720	14053L	PARTICIPANT	\N	PRESENT	0
631621	631620	04047H	PARTICIPANT	\N	PRESENT	0
631622	631620	04042C	PARTICIPANT	\N	PRESENT	0
631623	631620	14053L	PARTICIPANT	\N	PRESENT	0
631624	631620	11066Q	PARTICIPANT	\N	PRESENT	0
631648	631647	14259Y	PARTICIPANT	\N	PRESENT	0
631649	631647	14097Y	PARTICIPANT	\N	PRESENT	0
637605	637604	20116W	PARTICIPANT	\N	PRESENT	0
637606	637604	11080N	PARTICIPANT	\N	PRESENT	0
637607	637604	11074Q	PARTICIPANT	\N	PRESENT	0
637608	637604	01057W	PARTICIPANT	\N	PRESENT	0
637609	637604	19651A	PARTICIPANT	\N	EXCUSE	0
637610	637604	20042V	PARTICIPANT	\N	EXCUSE	0
637611	637604	19545Y	PARTICIPANT	\N	EXCUSE	0
637614	637604	14121F	PARTICIPANT	\N	PRESENT	0
637615	637604	19335Q	PARTICIPANT	\N	EXCUSE	0
637616	637604	19687N	PARTICIPANT	\N	PRESENT	0
637619	637604	19347U	PARTICIPANT	\N	EXCUSE	0
637620	637604	19711U	PARTICIPANT	\N	PRESENT	0
637621	637604	05012A	PARTICIPANT	\N	EXCUSE	0
637895	637894	11043H	PARTICIPANT	\N	PRESENT	0
637896	637894	19631V	PARTICIPANT	\N	PRESENT	0
637897	637894	20024T	PARTICIPANT	\N	PRESENT	0
637898	637894	19954N	PARTICIPANT	\N	PRESENT	0
637899	637894	19575F	PARTICIPANT	\N	PRESENT	0
638095	638087	14331P	PARTICIPANT	\N	PRESENT	0
637901	637894	14105F	PARTICIPANT	\N	PRESENT	0
637902	637894	20152B	PARTICIPANT	\N	PRESENT	0
638302	638301	11056N	PARTICIPANT	\N	PRESENT	1
637904	637894	19467C	PARTICIPANT	\N	PRESENT	0
638303	638301	14089Y	PARTICIPANT	\N	PRESENT	0
637906	637894	20134Y	PARTICIPANT	\N	PRESENT	0
638304	638301	20024T	PARTICIPANT	\N	PRESENT	0
637908	637894	20056C	PARTICIPANT	\N	PRESENT	0
637909	637894	14073Q	PARTICIPANT	\N	PRESENT	0
638305	638301	19749K	PARTICIPANT	\N	PRESENT	1
637911	637894	19699S	PARTICIPANT	\N	PRESENT	0
637912	637894	08012N	PARTICIPANT	\N	PRESENT	0
637913	637894	14221J	PARTICIPANT	\N	PRESENT	0
637914	637894	14193X	PARTICIPANT	\N	PRESENT	0
637915	637894	19533U	PARTICIPANT	\N	PRESENT	0
637916	637894	17965H	PARTICIPANT	\N	PRESENT	0
637917	637894	19349W	PARTICIPANT	\N	PRESENT	0
637918	637894	20098N	PARTICIPANT	\N	PRESENT	0
638408	638357	19575F	PARTICIPANT	\N	EXCUSE	0
638409	638357	08060W	PARTICIPANT	\N	EXCUSE	0
638410	638357	14105F	PARTICIPANT	\N	EXCUSE	0
638411	638357	19545Y	PARTICIPANT	\N	EXCUSE	0
638412	638357	20060X	PARTICIPANT	\N	EXCUSE	0
638413	638357	14329V	PARTICIPANT	\N	EXCUSE	0
638414	638357	14195A	PARTICIPANT	\N	EXCUSE	0
638415	638357	08028W	PARTICIPANT	\N	EXCUSE	0
638416	638357	19467C	PARTICIPANT	\N	EXCUSE	0
638417	638357	14357A	PARTICIPANT	\N	EXCUSE	0
638418	638357	20040T	PARTICIPANT	\N	EXCUSE	0
638419	638357	14026U	PARTICIPANT	\N	EXCUSE	0
638420	638357	20048C	PARTICIPANT	\N	EXCUSE	0
638421	638357	08015R	PARTICIPANT	\N	EXCUSE	0
638422	638357	14031R	PARTICIPANT	\N	EXCUSE	0
638423	638357	20082E	PARTICIPANT	\N	EXCUSE	0
638424	638357	20054A	PARTICIPANT	\N	EXCUSE	0
638781	638780	14097Y	PARTICIPANT	\N	PRESENT	0
638782	638780	20050V	PARTICIPANT	\N	PRESENT	0
638783	638780	20082E	PARTICIPANT	\N	PRESENT	0
638784	638780	20074E	PARTICIPANT	\N	EXCUSE	0
638785	638780	19369B	PARTICIPANT	\N	EXCUSE	0
638787	638786	19693L	PARTICIPANT	\N	PRESENT	0
638788	638786	20074E	PARTICIPANT	\N	PRESENT	0
638789	638786	14213J	PARTICIPANT	\N	PRESENT	0
638790	638786	14097Y	PARTICIPANT	\N	PRESENT	0
638791	638786	20050V	PARTICIPANT	\N	PRESENT	0
638792	638786	20082E	PARTICIPANT	\N	PRESENT	0
638793	638786	19369B	PARTICIPANT	\N	EXCUSE	0
638795	638794	20082E	PARTICIPANT	\N	PRESENT	0
638796	638794	20050V	PARTICIPANT	\N	PRESENT	0
638797	638794	14097Y	PARTICIPANT	\N	PRESENT	0
638798	638794	20074E	PARTICIPANT	\N	PRESENT	0
638799	638794	19369B	PARTICIPANT	\N	PRESENT	0
638822	638814	20050V	PARTICIPANT	\N	PRESENT	0
638823	638814	19693L	PARTICIPANT	\N	PRESENT	0
638824	638814	14213J	PARTICIPANT	\N	PRESENT	1
638979	638978	20024T	PARTICIPANT	\N	PRESENT	0
638980	638978	19599P	PARTICIPANT	\N	PRESENT	0
638820	638814	19369B	PARTICIPANT	\N	EXCUSE	0
638821	638814	20082E	PARTICIPANT	\N	PRESENT	0
638981	638978	19685L	PARTICIPANT	\N	PRESENT	0
638983	638982	01048V	PARTICIPANT	\N	PRESENT	0
638985	638984	01048V	PARTICIPANT	\N	PRESENT	0
638987	638986	19741B	PARTICIPANT	\N	PRESENT	0
638993	638992	20086J	PARTICIPANT	\N	PRESENT	0
639562	639561	14133K	PARTICIPANT	\N	PRESENT	1
639563	639561	14089Y	PARTICIPANT	\N	PRESENT	1
639564	639561	19701S	PARTICIPANT	\N	PRESENT	0
639565	639561	20100N	PARTICIPANT	\N	PRESENT	1
639566	639561	20286Q	PARTICIPANT	\N	PRESENT	1
639567	639561	11083R	PARTICIPANT	\N	PRESENT	0
639568	639561	19333N	PARTICIPANT	\N	PRESENT	0
639569	639561	12041X	PARTICIPANT	\N	PRESENT	1
639570	639561	11026G	PARTICIPANT	\N	PRESENT	0
639571	639561	19563B	PARTICIPANT	\N	PRESENT	1
639572	639561	04070G	PARTICIPANT	\N	PRESENT	1
639573	639561	04057K	PARTICIPANT	\N	PRESENT	1
639574	639561	14237S	PARTICIPANT	\N	PRESENT	1
639575	639561	14331P	PRESIDENT	0	PRESENT	0
639576	639561	10015M	PARTICIPANT	\N	PRESENT	1
639577	639561	14219Q	PARTICIPANT	\N	PRESENT	1
639578	639561	19347U	PARTICIPANT	\N	PRESENT	1
639579	639561	18083K	PARTICIPANT	\N	PRESENT	1
639580	639561	19533U	PARTICIPANT	\N	PRESENT	1
639581	639561	20022R	PARTICIPANT	\N	PRESENT	1
639582	639561	20264J	PARTICIPANT	\N	PRESENT	0
639583	639561	20114U	PARTICIPANT	\N	PRESENT	1
639584	639561	14179A	PARTICIPANT	\N	PRESENT	1
639585	639561	20180F	PARTICIPANT	\N	PRESENT	1
639586	639561	01024M	PARTICIPANT	\N	PRESENT	0
640098	640097	11080N	PARTICIPANT	\N	PRESENT	0
640099	640097	14121F	PARTICIPANT	\N	PRESENT	0
640100	640097	19687N	PARTICIPANT	\N	PRESENT	0
640101	640097	19711U	PARTICIPANT	\N	PRESENT	0
641667	641666	08010L	PARTICIPANT	\N	PRESENT	0
641668	641666	19693L	PARTICIPANT	\N	PRESENT	0
645051	644613	11043H	PARTICIPANT	\N	PRESENT	1
645052	644613	20132W	PARTICIPANT	\N	PRESENT	1
645053	644613	20026V	PARTICIPANT	\N	PRESENT	1
645054	644613	14073Q	PARTICIPANT	\N	PRESENT	1
645055	644613	20138D	PARTICIPANT	\N	PRESENT	1
645056	644613	19651A	PARTICIPANT	\N	PRESENT	1
645057	644613	04047H	PARTICIPANT	\N	PRESENT	0
645058	644613	19673G	PARTICIPANT	\N	PRESENT	0
645059	644613	19725B	PARTICIPANT	\N	PRESENT	0
645060	644613	95063L	PARTICIPANT	\N	PRESENT	0
645061	644613	20022R	PARTICIPANT	\N	PRESENT	0
645062	644613	14215L	PARTICIPANT	\N	PRESENT	0
645063	644613	20074E	PARTICIPANT	\N	PRESENT	0
645064	644613	20128B	PARTICIPANT	\N	PRESENT	0
645065	644613	14179A	PARTICIPANT	\N	PRESENT	0
645066	644613	14021P	PARTICIPANT	\N	PRESENT	0
645067	644613	19489J	PARTICIPANT	\N	PRESENT	0
645068	644613	19649G	PARTICIPANT	\N	PRESENT	0
645069	644613	14147R	PARTICIPANT	\N	PRESENT	0
645070	644613	10015M	PARTICIPANT	\N	PRESENT	0
645071	644613	01028R	PARTICIPANT	\N	PRESENT	0
645449	645448	07029T	PARTICIPANT	\N	PRESENT	0
645451	645450	11040E	PARTICIPANT	\N	PRESENT	0
645452	645450	11048N	PARTICIPANT	\N	PRESENT	0
645453	645450	20126Y	PARTICIPANT	\N	PRESENT	0
645454	645450	20252E	PARTICIPANT	\N	PRESENT	0
645455	645450	19671E	PARTICIPANT	\N	PRESENT	0
645456	645450	14225N	PARTICIPANT	\N	PRESENT	0
645457	645450	19762G	PARTICIPANT	\N	PRESENT	0
645458	645450	19479G	PARTICIPANT	\N	PRESENT	0
645536	645535	14038Y	PARTICIPANT	\N	PRESENT	0
645537	645535	19387D	PARTICIPANT	\N	PRESENT	1
645538	645535	19723Y	PARTICIPANT	\N	PRESENT	1
645539	645535	19643A	PARTICIPANT	\N	PRESENT	1
645540	645535	19820Y	PARTICIPANT	\N	PRESENT	1
645541	645535	20056C	PARTICIPANT	\N	PRESENT	1
645542	645535	19333N	PARTICIPANT	\N	PRESENT	0
645543	645535	14229S	PARTICIPANT	\N	PRESENT	0
645544	645535	19533U	PARTICIPANT	\N	PRESENT	0
645545	645535	20026V	PARTICIPANT	\N	PRESENT	1
645546	645535	19575F	PARTICIPANT	\N	PRESENT	1
649684	649446	19383Y	PARTICIPANT	\N	PRESENT	0
649685	649446	20088L	PARTICIPANT	\N	PRESENT	0
649686	649446	19768N	PARTICIPANT	\N	PRESENT	0
649687	649446	20092G	PARTICIPANT	\N	PRESENT	0
649688	649446	19782L	PARTICIPANT	\N	PRESENT	1
649689	649446	01043Q	PARTICIPANT	\N	PRESENT	0
649690	649446	14357A	PARTICIPANT	\N	PRESENT	0
649691	649446	19441R	PARTICIPANT	\N	PRESENT	0
649692	649446	20078J	PARTICIPANT	\N	PRESENT	0
649693	649446	19413M	PARTICIPANT	\N	PRESENT	0
649694	649446	20082E	PARTICIPANT	\N	PRESENT	1
649695	649446	20094J	PARTICIPANT	\N	PRESENT	0
649696	649446	04045F	PARTICIPANT	\N	PRESENT	0
649697	649446	19631V	PARTICIPANT	\N	PRESENT	0
649698	649446	11099A	PARTICIPANT	\N	PRESENT	0
649699	649446	19575F	PARTICIPANT	\N	PRESENT	0
649700	649446	19369B	PARTICIPANT	\N	PRESENT	0
649701	649446	20018V	PARTICIPANT	\N	PRESENT	0
649702	649446	08028W	PARTICIPANT	\N	PRESENT	0
649703	649446	19563B	PARTICIPANT	\N	PRESENT	0
649704	649446	14329V	PARTICIPANT	\N	PRESENT	0
649705	649446	14038Y	PARTICIPANT	\N	PRESENT	0
649706	649446	19467C	PARTICIPANT	\N	PRESENT	0
649707	649446	20034V	PARTICIPANT	\N	PRESENT	0
649708	649446	14187A	PARTICIPANT	\N	PRESENT	0
649709	649446	20144B	PARTICIPANT	\N	PRESENT	0
649710	649446	19695N	PARTICIPANT	\N	PRESENT	0
649711	649446	14033T	PARTICIPANT	\N	PRESENT	0
649712	649446	11090Q	PRESIDENT	0	PRESENT	0
649713	649446	20054A	PARTICIPANT	\N	PRESENT	0
649714	649446	14205J	PARTICIPANT	\N	PRESENT	0
649715	649446	20062A	PARTICIPANT	\N	PRESENT	0
649716	649446	19507S	PARTICIPANT	\N	PRESENT	0
649717	649446	20286Q	PARTICIPANT	\N	PRESENT	0
649718	649446	19747H	PARTICIPANT	\N	PRESENT	0
649719	649446	14207L	PARTICIPANT	\N	PRESENT	0
649720	649446	14257W	PARTICIPANT	\N	PRESENT	0
650134	648783	20108W	PARTICIPANT	\N	PRESENT	0
650135	648783	20110Q	PARTICIPANT	\N	PRESENT	0
650136	648783	19447X	PARTICIPANT	\N	PRESENT	0
650802	649163	04085P	PARTICIPANT	\N	PRESENT	0
650176	649162	19507S	PARTICIPANT	\N	PRESENT	0
650177	649162	19443T	PARTICIPANT	\N	PRESENT	0
650885	649163	20140W	PARTICIPANT	\N	PRESENT	0
650886	649163	19503N	PARTICIPANT	\N	PRESENT	0
650887	649163	19713W	PARTICIPANT	\N	PRESENT	0
650888	649163	19749K	PARTICIPANT	\N	PRESENT	0
650889	649163	19575F	PARTICIPANT	\N	PRESENT	0
650890	649163	20024T	PARTICIPANT	\N	PRESENT	0
650891	649163	19675J	PARTICIPANT	\N	PRESENT	0
650892	649163	20018V	PARTICIPANT	\N	PRESENT	0
650893	649163	14038Y	PARTICIPANT	\N	PRESENT	0
650894	649163	14055N	PARTICIPANT	\N	PRESENT	0
650895	649163	19695N	PARTICIPANT	\N	PRESENT	0
650896	649163	14329V	PARTICIPANT	\N	PRESENT	0
650897	649163	11033F	PARTICIPANT	\N	PRESENT	0
650898	649163	08056B	PARTICIPANT	\N	PRESENT	0
650899	649163	08015R	PARTICIPANT	\N	PRESENT	0
650900	649163	19657G	PARTICIPANT	\N	PRESENT	0
650901	649163	11026G	PARTICIPANT	\N	PRESENT	0
650902	649163	20056C	PARTICIPANT	\N	PRESENT	0
650903	649163	14217N	PARTICIPANT	\N	PRESENT	0
650904	649163	05008E	PARTICIPANT	\N	PRESENT	0
650905	649163	20034V	PARTICIPANT	\N	PRESENT	0
650906	649163	20026V	PARTICIPANT	\N	PRESENT	0
650907	649163	19399H	PARTICIPANT	\N	PRESENT	0
650909	649163	19760E	PARTICIPANT	\N	PRESENT	0
650910	647949	19699S	PARTICIPANT	\N	PRESENT	0
650911	647949	19533U	PARTICIPANT	\N	PRESENT	0
650912	647949	14229S	PARTICIPANT	\N	PRESENT	0
650913	647949	08012N	PARTICIPANT	\N	PRESENT	0
650914	647949	20026V	PARTICIPANT	\N	PRESENT	0
650915	647949	19527W	PARTICIPANT	\N	PRESENT	1
650916	647949	19593H	PARTICIPANT	\N	PRESENT	0
650917	647949	20132W	PARTICIPANT	\N	PRESENT	0
650918	647949	20134Y	PARTICIPANT	\N	PRESENT	0
650919	647949	20138D	PARTICIPANT	\N	PRESENT	0
650920	647949	19611R	PARTICIPANT	\N	PRESENT	0
650921	647949	20142Y	PARTICIPANT	\N	PRESENT	0
650922	647949	19693L	PARTICIPANT	\N	PRESENT	0
650923	647949	20152B	PARTICIPANT	\N	PRESENT	0
650924	647949	20052X	PARTICIPANT	\N	PRESENT	0
650925	647949	20172F	PARTICIPANT	\N	PRESENT	0
650926	647949	20058E	PARTICIPANT	\N	PRESENT	0
650927	647949	14030Q	PARTICIPANT	\N	PRESENT	0
650928	647949	20056C	PARTICIPANT	\N	PRESENT	0
650929	647949	20180F	PARTICIPANT	\N	PRESENT	0
650930	647949	20264J	PARTICIPANT	\N	PRESENT	0
650931	647949	19735D	PARTICIPANT	\N	PRESENT	0
650932	647949	14109K	PARTICIPANT	\N	PRESENT	1
650933	647949	14123H	PARTICIPANT	\N	PRESENT	0
650934	647949	11043H	PARTICIPANT	\N	PRESENT	0
650935	647949	19758L	PARTICIPANT	\N	PRESENT	0
650936	647949	20084G	PARTICIPANT	\N	PRESENT	0
650937	649163	14179A	PARTICIPANT	\N	PRESENT	0
650939	649163	20122U	PARTICIPANT	\N	PRESENT	0
650941	649163	19747H	PARTICIPANT	\N	PRESENT	0
650942	649163	20028X	PARTICIPANT	\N	PRESENT	0
650943	649163	20070A	PARTICIPANT	\N	PRESENT	0
650944	649163	14147R	PARTICIPANT	\N	PRESENT	0
650945	649163	19349W	PARTICIPANT	\N	PRESENT	0
650946	649163	11072N	PARTICIPANT	\N	PRESENT	0
650955	649163	20126Y	PARTICIPANT	\N	PRESENT	0
650956	649163	20094J	PARTICIPANT	\N	PRESENT	0
650961	649163	14207L	PARTICIPANT	\N	PRESENT	0
650962	649163	11012A	PARTICIPANT	\N	PRESENT	0
650967	649163	14357A	PARTICIPANT	\N	PRESENT	0
650968	649163	19663E	PARTICIPANT	\N	PRESENT	0
650969	649163	19549D	PARTICIPANT	\N	PRESENT	0
650970	649163	11027H	PARTICIPANT	\N	PRESENT	0
650971	649163	14042U	PARTICIPANT	\N	PRESENT	0
650972	649163	11053K	PARTICIPANT	\N	PRESENT	0
650973	649163	14083S	PARTICIPANT	\N	PRESENT	0
650974	649163	20152B	PARTICIPANT	\N	PRESENT	0
650975	649163	14053L	PARTICIPANT	\N	PRESENT	0
650976	649163	19591F	PARTICIPANT	\N	PRESENT	0
650977	649163	08073C	PARTICIPANT	\N	PRESENT	0
650978	649163	14069U	PARTICIPANT	\N	PRESENT	0
650979	649163	19866P	PARTICIPANT	\N	PRESENT	0
650980	649163	14033T	PARTICIPANT	\N	PRESENT	0
650981	649163	20080C	PARTICIPANT	\N	PRESENT	0
650982	649163	08018U	PARTICIPANT	\N	PRESENT	0
650983	649163	20172F	PARTICIPANT	\N	PRESENT	0
650984	649163	08010L	PARTICIPANT	\N	PRESENT	0
650985	649163	20046A	PARTICIPANT	\N	PRESENT	0
650989	649163	11010L	PARTICIPANT	\N	PRESENT	0
650990	649163	20266L	PARTICIPANT	\N	PRESENT	0
650992	649163	19717B	PARTICIPANT	\N	PRESENT	0
650993	649163	20104S	PARTICIPANT	\N	PRESENT	0
650994	649163	20264J	PARTICIPANT	\N	PRESENT	0
650995	649163	20138D	PARTICIPANT	\N	PRESENT	0
650996	649163	14151M	PARTICIPANT	\N	PRESENT	0
650998	649163	20058E	PARTICIPANT	\N	PRESENT	0
650999	649163	08061X	PARTICIPANT	\N	PRESENT	0
651000	649163	19347U	PARTICIPANT	\N	PRESENT	0
651001	649163	20134Y	PARTICIPANT	\N	PRESENT	0
651002	649163	20052X	PARTICIPANT	\N	PRESENT	0
651003	649163	20132W	PARTICIPANT	\N	PRESENT	0
651004	649163	17023S	PARTICIPANT	\N	PRESENT	0
651005	649163	20118Y	PARTICIPANT	\N	PRESENT	0
651006	649163	19531S	PARTICIPANT	\N	PRESENT	0
651007	649163	14030Q	PARTICIPANT	\N	PRESENT	0
651008	649163	01043Q	PARTICIPANT	\N	PRESENT	0
651009	649163	11085T	PARTICIPANT	\N	PRESENT	0
629421	629420	14053L	PARTICIPANT	\N	PRESENT	0
629422	629420	10015M	PARTICIPANT	\N	PRESENT	0
629424	629423	08045X	PARTICIPANT	\N	PRESENT	0
629425	629423	19715Y	PARTICIPANT	\N	PRESENT	0
629426	629423	20130U	PARTICIPANT	\N	PRESENT	0
629427	629423	18193Q	PARTICIPANT	\N	PRESENT	0
631395	629313	14038Y	PARTICIPANT	\N	PRESENT	0
631396	629313	19695N	PARTICIPANT	\N	PRESENT	0
631397	629313	11031D	PARTICIPANT	\N	PRESENT	0
631398	629313	20286Q	PARTICIPANT	\N	PRESENT	0
631399	629313	01024M	PARTICIPANT	\N	PRESENT	0
631400	629313	19691J	PARTICIPANT	\N	PRESENT	0
631401	629313	20062A	PARTICIPANT	\N	PRESENT	0
631402	629313	14147R	PARTICIPANT	\N	PRESENT	0
631403	629313	14217N	PARTICIPANT	\N	PRESENT	0
631404	629313	11012A	PARTICIPANT	\N	PRESENT	0
631405	629313	19629C	PARTICIPANT	\N	PRESENT	0
631406	629313	19651A	PARTICIPANT	\N	PRESENT	0
631407	629313	20134Y	PARTICIPANT	\N	PRESENT	0
631408	629313	11097X	PARTICIPANT	\N	PRESENT	0
631409	629313	14257W	PARTICIPANT	\N	PRESENT	0
631393	629313	14026U	PARTICIPANT	\N	PRESENT	0
631394	629313	19768N	PARTICIPANT	\N	PRESENT	0
631410	629313	20128B	PARTICIPANT	\N	PRESENT	0
631411	629313	04045F	PARTICIPANT	\N	PRESENT	0
631412	629313	19631V	PARTICIPANT	\N	PRESENT	0
631413	629313	11064N	PARTICIPANT	\N	PRESENT	0
631414	629313	04070G	PARTICIPANT	\N	PRESENT	0
631415	629313	19954N	PARTICIPANT	\N	PRESENT	0
631416	629313	14069U	PARTICIPANT	\N	PRESENT	0
631417	629313	20018V	PARTICIPANT	\N	PRESENT	0
631418	629313	20024T	PARTICIPANT	\N	PRESENT	0
631419	629313	19515S	PARTICIPANT	\N	PRESENT	0
631420	629313	19782L	PARTICIPANT	\N	PRESENT	0
631421	629313	20090E	PARTICIPANT	\N	PRESENT	0
631422	629313	19415P	PARTICIPANT	\N	PRESENT	0
631423	629313	14215L	PARTICIPANT	\N	PRESENT	0
631424	629313	04092N	PARTICIPANT	\N	PRESENT	0
631425	629313	08015R	PARTICIPANT	\N	PRESENT	0
631426	629313	19723Y	PARTICIPANT	\N	PRESENT	0
631511	631510	20076G	PARTICIPANT	\N	PRESENT	0
631512	631510	20024T	PARTICIPANT	\N	PRESENT	0
631513	631510	14069U	PARTICIPANT	\N	PRESENT	0
631514	631510	19782L	PARTICIPANT	\N	PRESENT	0
631515	631510	20090E	PARTICIPANT	\N	PRESENT	0
631516	631510	11103C	PARTICIPANT	\N	PRESENT	0
631517	631510	14329V	PARTICIPANT	\N	PRESENT	0
631518	631510	19467C	PARTICIPANT	\N	PRESENT	0
631519	631510	14357A	PARTICIPANT	\N	PRESENT	0
631520	631510	17589D	PARTICIPANT	\N	PRESENT	0
631521	631510	14187A	PARTICIPANT	\N	PRESENT	0
631522	631510	20038A	PARTICIPANT	\N	PRESENT	0
631523	631510	20126Y	PARTICIPANT	\N	PRESENT	0
631524	631510	16685X	PARTICIPANT	\N	PRESENT	0
631525	631510	14221J	PARTICIPANT	\N	PRESENT	0
631526	631510	19563B	PARTICIPANT	\N	PRESENT	0
631527	631510	20018V	PARTICIPANT	\N	PRESENT	0
631528	631510	14169X	PARTICIPANT	\N	PRESENT	0
631529	631510	20030R	PARTICIPANT	\N	PRESENT	0
631530	631510	05012A	PARTICIPANT	\N	PRESENT	0
631531	631510	14331P	PARTICIPANT	\N	PRESENT	0
631532	631510	20044X	PARTICIPANT	\N	PRESENT	0
631533	631510	19713W	PARTICIPANT	\N	PRESENT	0
631542	631445	08060W	PARTICIPANT	\N	EXCUSE	0
631543	631445	08028W	PARTICIPANT	\N	EXCUSE	0
631544	631445	14026U	PARTICIPANT	\N	EXCUSE	0
631545	631445	08015R	PARTICIPANT	\N	EXCUSE	0
631547	631445	20108W	PARTICIPANT	\N	EXCUSE	0
631548	631445	19369B	PARTICIPANT	\N	EXCUSE	0
631549	631445	19679N	PARTICIPANT	\N	EXCUSE	0
631550	631445	20082E	PARTICIPANT	\N	EXCUSE	0
631708	628916	14331P	PRESIDENT	0	PRESENT	0
631709	628916	14026U	PARTICIPANT	\N	PRESENT	0
631710	628916	19725B	PARTICIPANT	\N	PRESENT	0
631711	628916	19531S	PARTICIPANT	\N	PRESENT	0
631712	628916	11026G	PARTICIPANT	\N	PRESENT	0
631713	628916	14357A	PARTICIPANT	\N	PRESENT	0
631714	628916	08034U	PARTICIPANT	\N	PRESENT	0
631715	628916	14097Y	PARTICIPANT	\N	PRESENT	1
631716	628916	14073Q	PARTICIPANT	\N	PRESENT	1
631717	628916	11083R	PARTICIPANT	\N	PRESENT	1
631842	631806	14281W	PARTICIPANT	\N	PRESENT	0
631843	631806	20124W	PARTICIPANT	\N	PRESENT	0
631844	631806	20056C	PARTICIPANT	\N	PRESENT	0
631845	631806	20140W	PARTICIPANT	\N	PRESENT	0
631846	631806	19621T	PARTICIPANT	\N	PRESENT	0
631847	631806	14189C	PARTICIPANT	\N	PRESENT	0
631848	631806	19760E	PARTICIPANT	\N	PRESENT	0
631849	631806	08009T	PARTICIPANT	\N	PRESENT	0
631850	631806	19768N	PARTICIPANT	\N	PRESENT	0
631851	631806	20116W	PARTICIPANT	\N	PRESENT	0
631852	631806	20034V	PARTICIPANT	\N	PRESENT	0
631853	631806	19637C	PARTICIPANT	\N	PRESENT	0
631855	631854	14069U	PARTICIPANT	\N	PRESENT	0
631856	631854	14249W	PARTICIPANT	\N	PRESENT	0
631857	631854	11064N	PARTICIPANT	\N	PRESENT	0
631858	631854	14111D	PARTICIPANT	\N	PRESENT	0
631859	631854	04057K	PARTICIPANT	\N	PRESENT	0
631860	631854	20062A	PARTICIPANT	\N	PRESENT	0
631861	631854	19585H	PARTICIPANT	\N	PRESENT	0
631863	631806	19599P	PARTICIPANT	\N	PRESENT	0
631864	631806	14107H	PARTICIPANT	\N	PRESENT	0
631865	631806	20146D	PARTICIPANT	\N	PRESENT	0
631866	631806	14147R	PARTICIPANT	\N	PRESENT	0
631868	631867	19575F	PARTICIPANT	\N	PRESENT	0
631869	631862	20180F	PARTICIPANT	\N	PRESENT	1
631870	631867	04035D	PARTICIPANT	\N	PRESENT	0
631871	631867	14219Q	PARTICIPANT	\N	PRESENT	0
631872	631867	08012N	PARTICIPANT	\N	PRESENT	0
631873	631862	19735D	PARTICIPANT	\N	PRESENT	1
631874	631867	14001X	PARTICIPANT	\N	PRESENT	0
631875	631867	19319Q	PARTICIPANT	\N	PRESENT	0
631876	631867	04043D	PARTICIPANT	\N	PRESENT	0
631877	631806	11115U	PARTICIPANT	\N	PRESENT	0
631878	631806	14042U	PARTICIPANT	\N	PRESENT	0
631879	631806	14033T	PARTICIPANT	\N	PRESENT	0
631880	631806	18193Q	PARTICIPANT	\N	PRESENT	0
631882	631806	20022R	PARTICIPANT	\N	PRESENT	0
631883	631806	19553Y	PARTICIPANT	\N	PRESENT	0
631884	631806	14179A	PARTICIPANT	\N	PRESENT	0
631885	631806	14069U	PARTICIPANT	\N	PRESENT	0
631886	631806	20286Q	PARTICIPANT	\N	PRESENT	0
631887	631806	11048N	PARTICIPANT	\N	PRESENT	0
631888	631806	14031R	PARTICIPANT	\N	PRESENT	0
631889	631806	04042C	PARTICIPANT	\N	PRESENT	0
631890	631806	20134Y	PARTICIPANT	\N	PRESENT	0
631891	631806	14030Q	PARTICIPANT	\N	PRESENT	0
631892	631806	19399H	PARTICIPANT	\N	PRESENT	0
631893	631806	08073C	PARTICIPANT	\N	PRESENT	0
631896	631894	10006L	PARTICIPANT	\N	PRESENT	0
631897	631894	11031D	PARTICIPANT	\N	PRESENT	0
631898	631894	14147R	PARTICIPANT	\N	PRESENT	0
631899	631894	20130U	PARTICIPANT	\N	PRESENT	0
631900	631894	20062A	PARTICIPANT	\N	PRESENT	0
631901	631895	11031D	PARTICIPANT	\N	PRESENT	0
631902	631895	10006L	PARTICIPANT	\N	PRESENT	0
631903	631895	20130U	PARTICIPANT	\N	PRESENT	0
631904	631895	20062A	PARTICIPANT	\N	PRESENT	0
631916	631562	20108W	PARTICIPANT	\N	PRESENT	0
631917	631562	10015M	PARTICIPANT	\N	PRESENT	0
631918	631562	04047H	PRESIDENT	0	PRESENT	0
631919	631562	19673G	PARTICIPANT	\N	PRESENT	0
631920	631562	14069U	PARTICIPANT	\N	PRESENT	0
631921	631562	14215L	PARTICIPANT	\N	PRESENT	0
631922	631562	11010L	PARTICIPANT	\N	PRESENT	0
631923	631562	11056N	PARTICIPANT	\N	PRESENT	0
631913	631497	14026U	PARTICIPANT	\N	PRESENT	0
631914	631562	14147R	PARTICIPANT	\N	PRESENT	0
631915	631562	19447X	PARTICIPANT	\N	PRESENT	0
631924	631562	19543W	PARTICIPANT	\N	PRESENT	0
631925	631497	14255U	PARTICIPANT	\N	PRESENT	0
631926	631497	20042V	PARTICIPANT	\N	PRESENT	0
631927	631497	19387D	PARTICIPANT	\N	PRESENT	0
631928	631497	20064C	PARTICIPANT	\N	PRESENT	0
631929	631497	19591F	PARTICIPANT	\N	PRESENT	0
631930	631562	14151M	PARTICIPANT	\N	PRESENT	0
631931	631497	11064N	PARTICIPANT	\N	PRESENT	0
631932	631497	14105F	PARTICIPANT	\N	PRESENT	0
631933	631497	19347U	PARTICIPANT	\N	PRESENT	0
631934	631497	19565D	PARTICIPANT	\N	PRESENT	0
631963	631497	20054A	PARTICIPANT	\N	PRESENT	0
643973	643720	19717B	PARTICIPANT	\N	PRESENT	1
643974	643720	20034V	PARTICIPANT	\N	PRESENT	1
643976	643651	20080C	PARTICIPANT	\N	PRESENT	0
643977	643651	11053K	PARTICIPANT	\N	PRESENT	0
643978	643651	20098N	PARTICIPANT	\N	PRESENT	0
643979	643651	19593H	PARTICIPANT	\N	PRESENT	0
643980	643651	20132W	PARTICIPANT	\N	PRESENT	0
643981	643651	20138D	PARTICIPANT	\N	PRESENT	0
643982	643651	19611R	PARTICIPANT	\N	PRESENT	0
643983	643651	20048C	PARTICIPANT	\N	PRESENT	0
643984	643651	20152B	PARTICIPANT	\N	PRESENT	0
643985	643651	20058E	PARTICIPANT	\N	PRESENT	0
644414	642004	19673G	PARTICIPANT	\N	PRESENT	0
643987	643651	19621T	PARTICIPANT	\N	PRESENT	0
643988	643651	20084G	PARTICIPANT	\N	PRESENT	0
643990	643651	19533U	PARTICIPANT	\N	PRESENT	0
643991	643651	04059M	PARTICIPANT	\N	PRESENT	0
644007	643651	19699S	PARTICIPANT	\N	PRESENT	0
644008	643651	19573D	PARTICIPANT	\N	PRESENT	0
644009	643651	14229S	PARTICIPANT	\N	PRESENT	0
644088	643951	11077T	PARTICIPANT	\N	EXCUSE	0
644089	643951	19747H	PARTICIPANT	\N	EXCUSE	0
644094	644093	20024T	PARTICIPANT	\N	PRESENT	0
644095	644093	20114U	PARTICIPANT	\N	PRESENT	0
644096	644093	19575F	PARTICIPANT	\N	PRESENT	0
644097	644093	17589D	PARTICIPANT	\N	PRESENT	0
644098	644093	01024M	PARTICIPANT	\N	PRESENT	0
644099	644093	19691J	PARTICIPANT	\N	PRESENT	0
644100	644093	14179A	PARTICIPANT	\N	PRESENT	0
644101	644093	19657G	PARTICIPANT	\N	PRESENT	0
644102	644093	19745F	PARTICIPANT	\N	PRESENT	0
644103	644093	19798U	PARTICIPANT	\N	PRESENT	0
644112	644111	14189C	PARTICIPANT	\N	EXCUSE	0
644113	644111	19741B	PARTICIPANT	\N	PRESENT	0
644114	644111	20086J	PARTICIPANT	\N	PRESENT	0
644115	644111	11040E	PARTICIPANT	\N	PRESENT	0
644116	644111	14083S	PARTICIPANT	\N	PRESENT	0
644117	644111	11070L	PARTICIPANT	\N	PRESENT	0
644118	644111	14327T	PARTICIPANT	\N	PRESENT	0
644119	644111	04071H	PARTICIPANT	\N	PRESENT	0
644120	644111	11048N	PARTICIPANT	\N	PRESENT	0
644121	644111	99004R	PARTICIPANT	\N	PRESENT	0
644122	644111	07029T	PARTICIPANT	\N	PRESENT	0
644123	644111	19711U	PARTICIPANT	\N	PRESENT	0
644124	644111	08010L	PARTICIPANT	\N	PRESENT	0
644125	644111	08034U	PARTICIPANT	\N	PRESENT	0
644126	644111	01048V	PARTICIPANT	\N	PRESENT	0
644127	644111	19671E	PARTICIPANT	\N	PRESENT	0
644128	644111	14253S	PARTICIPANT	\N	PRESENT	0
644129	644111	14331P	PARTICIPANT	\N	PRESENT	0
644130	644111	14225N	PRESIDENT	0	PRESENT	0
644131	644111	19762G	PARTICIPANT	\N	PRESENT	0
644132	644111	19399H	PARTICIPANT	\N	PRESENT	0
644133	644111	20116W	PARTICIPANT	\N	EXCUSE	0
644134	644111	01057W	PARTICIPANT	\N	EXCUSE	0
644135	644111	20050V	PARTICIPANT	\N	EXCUSE	0
644136	644111	19545Y	PARTICIPANT	\N	PRESENT	1
644137	644111	14121F	PARTICIPANT	\N	PRESENT	1
644138	644111	20036X	PARTICIPANT	\N	PRESENT	1
644139	644111	19349W	PARTICIPANT	\N	PRESENT	1
644140	644111	11012A	PARTICIPANT	\N	PRESENT	1
644142	644111	19687N	PARTICIPANT	\N	PRESENT	1
644144	644111	20126Y	PARTICIPANT	\N	PRESENT	0
644151	643651	19643A	PARTICIPANT	\N	PRESENT	0
644152	643651	20026V	PARTICIPANT	\N	PRESENT	0
644226	644225	19693L	PARTICIPANT	\N	PRESENT	0
644227	644225	19735D	PARTICIPANT	\N	PRESENT	0
644228	644225	19723Y	PARTICIPANT	\N	PRESENT	0
644229	644225	01048V	PARTICIPANT	\N	PRESENT	0
644230	644225	11067R	PARTICIPANT	\N	EXCUSE	0
644231	644225	19503N	PARTICIPANT	\N	PRESENT	0
644232	644225	04043D	PARTICIPANT	\N	PRESENT	0
644233	644225	01058X	PARTICIPANT	\N	PRESENT	0
644243	644225	19663E	PARTICIPANT	\N	PRESENT	0
644292	643746	19415P	PARTICIPANT	\N	PRESENT	0
644293	643746	19691J	PARTICIPANT	\N	PRESENT	0
644294	643746	14213J	PARTICIPANT	\N	PRESENT	0
644295	643746	20090E	PARTICIPANT	\N	PRESENT	0
644296	643746	11067R	PARTICIPANT	\N	PRESENT	0
644297	643746	20130U	PARTICIPANT	\N	PRESENT	0
644298	643746	19657G	PARTICIPANT	\N	PRESENT	0
644308	643747	19415P	PARTICIPANT	\N	PRESENT	0
644309	643747	11067R	PARTICIPANT	\N	PRESENT	0
644310	643747	20130U	PARTICIPANT	\N	PRESENT	0
644408	644407	05008E	PARTICIPANT	\N	EXCUSE	0
644409	644407	14331P	PARTICIPANT	\N	EXCUSE	0
644415	642004	11083R	PARTICIPANT	\N	PRESENT	0
644419	644418	14097Y	PARTICIPANT	\N	PRESENT	0
644420	644418	14331P	PARTICIPANT	\N	PRESENT	0
644421	644418	10015M	PARTICIPANT	\N	PRESENT	0
644426	644425	17737W	PARTICIPANT	\N	PRESENT	0
644494	644493	19447X	PARTICIPANT	\N	PRESENT	0
644495	644493	19725B	PARTICIPANT	\N	PRESENT	0
644508	644507	04047H	PARTICIPANT	\N	PRESENT	0
644509	644507	05008E	PARTICIPANT	\N	PRESENT	0
644510	644507	01028R	PARTICIPANT	\N	PRESENT	0
644544	644422	20022R	PARTICIPANT	\N	PRESENT	1
644545	644422	14179A	PARTICIPANT	\N	PRESENT	1
644546	644422	19489J	PARTICIPANT	\N	PRESENT	1
644548	644422	14147R	PARTICIPANT	\N	PRESENT	1
644550	644422	14089Y	PARTICIPANT	\N	EXCUSE	0
644556	644422	20112S	PARTICIPANT	\N	PRESENT	1
644557	644422	19611R	PARTICIPANT	\N	PRESENT	0
644558	644422	04059M	PARTICIPANT	\N	PRESENT	0
644559	644422	14123H	PARTICIPANT	\N	PRESENT	1
644560	644422	20138D	PARTICIPANT	\N	PRESENT	1
644561	644422	19643A	PARTICIPANT	\N	PRESENT	1
644562	644422	20132W	PARTICIPANT	\N	PRESENT	1
644563	644422	19533U	PARTICIPANT	\N	PRESENT	1
644564	644422	11043H	PARTICIPANT	\N	PRESENT	1
644565	644422	20084G	PARTICIPANT	\N	PRESENT	1
644606	644422	20052X	PARTICIPANT	\N	PRESENT	0
644607	644422	08012N	PARTICIPANT	\N	PRESENT	0
644608	644422	20134Y	PARTICIPANT	\N	PRESENT	0
644609	644422	14073Q	PARTICIPANT	\N	PRESENT	0
644610	644422	14229S	PARTICIPANT	\N	PRESENT	0
644611	644422	20024T	PARTICIPANT	\N	PRESENT	0
644612	644422	19573D	PARTICIPANT	\N	PRESENT	0
644633	644422	19725B	PARTICIPANT	\N	EXCUSE	0
644634	644422	19447X	PARTICIPANT	\N	EXCUSE	0
644664	644374	20094J	PARTICIPANT	\N	PRESENT	0
644665	644374	19701S	PARTICIPANT	\N	PRESENT	0
644666	644374	04035D	PARTICIPANT	\N	PRESENT	0
644667	644374	11083R	PARTICIPANT	\N	PRESENT	0
644668	644374	19333N	PARTICIPANT	\N	PRESENT	0
644669	644374	14097Y	PARTICIPANT	\N	PRESENT	0
644670	644374	14073Q	PARTICIPANT	\N	PRESENT	0
644671	644374	14331P	PARTICIPANT	\N	PRESENT	0
644672	644374	19725B	PARTICIPANT	\N	EXCUSE	0
644673	644374	19447X	PARTICIPANT	\N	EXCUSE	0
644725	644572	14097Y	PARTICIPANT	\N	PRESENT	0
644726	644572	14331P	PRESIDENT	0	PRESENT	0
644727	644572	19725B	PARTICIPANT	\N	PRESENT	0
644728	644572	19333N	PARTICIPANT	\N	PRESENT	0
644729	644572	11026G	PARTICIPANT	\N	PRESENT	0
644730	644572	19701S	PARTICIPANT	\N	PRESENT	0
644731	644572	14237S	PARTICIPANT	\N	PRESENT	1
644732	644572	20286Q	PARTICIPANT	\N	PRESENT	1
644733	644572	04045F	PARTICIPANT	\N	PRESENT	1
644734	644572	19441R	PARTICIPANT	\N	PRESENT	1
644735	644572	14033T	PARTICIPANT	\N	PRESENT	1
644764	644763	11067R	PARTICIPANT	\N	PRESENT	0
644765	644763	19479G	PARTICIPANT	\N	PRESENT	0
644766	644763	14327T	PARTICIPANT	\N	PRESENT	0
644767	644763	19611R	PARTICIPANT	\N	PRESENT	0
644768	644407	14053L	PARTICIPANT	\N	EXCUSE	0
644769	644763	20114U	PARTICIPANT	\N	PRESENT	0
644780	644311	19383Y	PARTICIPANT	\N	PRESENT	1
644781	644311	20088L	PARTICIPANT	\N	PRESENT	0
644782	644311	19768N	PARTICIPANT	\N	PRESENT	1
644783	644311	19515S	PARTICIPANT	\N	PRESENT	1
644784	644311	19782L	PARTICIPANT	\N	PRESENT	1
644785	644311	20092G	PARTICIPANT	\N	PRESENT	0
644786	644311	11077T	PARTICIPANT	\N	PRESENT	1
644787	644311	19413M	PARTICIPANT	\N	PRESENT	1
644788	644311	20094J	PARTICIPANT	\N	PRESENT	0
644789	644311	04045F	PARTICIPANT	\N	PRESENT	1
630487	629302	19575F	PARTICIPANT	\N	PRESENT	1
630503	629124	19583F	PARTICIPANT	\N	EXCUSE	0
630527	630526	19251M	PARTICIPANT	\N	PRESENT	0
630528	630526	20084G	PARTICIPANT	\N	PRESENT	0
630529	630526	19515S	PARTICIPANT	\N	PRESENT	0
630530	630526	11074Q	PARTICIPANT	\N	PRESENT	0
630531	630526	12028B	PARTICIPANT	\N	PRESENT	0
630532	630526	11085T	PARTICIPANT	\N	PRESENT	0
630533	630526	19593H	PARTICIPANT	\N	PRESENT	0
630534	630526	20026V	PARTICIPANT	\N	PRESENT	0
630535	630526	20248J	PARTICIPANT	\N	PRESENT	0
630536	630526	11026G	PARTICIPANT	\N	PRESENT	0
630537	630526	20064C	PARTICIPANT	\N	PRESENT	0
630538	630526	14267Y	PARTICIPANT	\N	PRESENT	0
630747	629207	20128B	PARTICIPANT	\N	PRESENT	1
630749	629207	14179A	PARTICIPANT	\N	PRESENT	1
630751	629207	19447X	PARTICIPANT	\N	PRESENT	1
630839	629206	07004J	PARTICIPANT	\N	EXCUSE	0
630840	629207	07004J	PARTICIPANT	\N	EXCUSE	0
634709	634708	19693L	PARTICIPANT	\N	PRESENT	0
634710	634708	19593H	PARTICIPANT	\N	PRESENT	0
634713	634712	14189C	PARTICIPANT	\N	PRESENT	0
634714	634712	14255U	PARTICIPANT	\N	PRESENT	0
634715	634712	19647E	PARTICIPANT	\N	PRESENT	0
634716	634712	20180F	PARTICIPANT	\N	PRESENT	0
634717	634712	11026G	PARTICIPANT	\N	PRESENT	0
634718	634712	14147R	PARTICIPANT	\N	PRESENT	0
634719	634712	19593H	PARTICIPANT	\N	PRESENT	0
634720	634712	19503N	PARTICIPANT	\N	PRESENT	0
634721	634712	19713W	PARTICIPANT	\N	PRESENT	0
635718	635716	11097X	PARTICIPANT	\N	PRESENT	0
635719	635716	19820Y	PARTICIPANT	\N	PRESENT	0
635720	635716	19467C	PARTICIPANT	\N	PRESENT	0
635721	635716	19383Y	PARTICIPANT	\N	PRESENT	0
635722	635716	20110Q	PARTICIPANT	\N	PRESENT	0
635723	635716	01025N	PARTICIPANT	\N	PRESENT	0
635724	635716	14207L	PARTICIPANT	\N	PRESENT	0
635725	635716	19575F	PARTICIPANT	\N	PRESENT	0
635726	635716	14257W	PARTICIPANT	\N	PRESENT	0
635727	635716	19745F	PARTICIPANT	\N	PRESENT	0
635728	635716	19782L	PARTICIPANT	\N	PRESENT	0
635729	635716	08015R	PARTICIPANT	\N	PRESENT	0
635730	635716	05012A	PARTICIPANT	\N	PRESENT	0
635731	635716	20084G	PARTICIPANT	\N	PRESENT	0
635759	635757	19747H	PARTICIPANT	\N	PRESENT	0
635734	635716	20128B	PARTICIPANT	\N	PRESENT	0
635758	635757	20050V	PARTICIPANT	\N	PRESENT	0
635760	635757	19693L	PARTICIPANT	\N	PRESENT	0
635761	635757	20126Y	PARTICIPANT	\N	PRESENT	0
635763	635762	20082E	PARTICIPANT	\N	PRESENT	0
635764	635762	20050V	PARTICIPANT	\N	PRESENT	0
635765	635762	19515S	PARTICIPANT	\N	PRESENT	0
635766	635762	19747H	PARTICIPANT	\N	PRESENT	0
635767	635762	19693L	PARTICIPANT	\N	PRESENT	0
635768	635762	20126Y	PARTICIPANT	\N	PRESENT	0
635770	635762	14193X	PARTICIPANT	\N	PRESENT	0
639360	639359	20076G	PARTICIPANT	\N	PRESENT	0
639361	639359	20024T	PARTICIPANT	\N	PRESENT	0
639362	639359	14205J	PARTICIPANT	\N	PRESENT	0
639363	639359	20092G	PARTICIPANT	\N	PRESENT	0
639364	639359	11097X	PARTICIPANT	\N	PRESENT	0
639365	639359	19713W	PARTICIPANT	\N	PRESENT	0
639367	639366	19575F	PARTICIPANT	\N	PRESENT	0
639368	639366	19782L	PARTICIPANT	\N	PRESENT	1
639369	639366	14038Y	PARTICIPANT	\N	PRESENT	0
639370	639366	14179A	PARTICIPANT	\N	PRESENT	0
639371	639366	14147R	PARTICIPANT	\N	PRESENT	0
639372	639366	20092G	PARTICIPANT	\N	PRESENT	0
639373	639366	20062A	PARTICIPANT	\N	PRESENT	0
639375	639374	14038Y	PARTICIPANT	\N	PRESENT	0
639376	639374	14179A	PARTICIPANT	\N	PRESENT	1
639377	639374	14147R	PARTICIPANT	\N	PRESENT	0
639378	639374	20028X	PARTICIPANT	\N	PRESENT	1
639379	639374	20092G	PARTICIPANT	\N	PRESENT	0
639381	639380	14038Y	PARTICIPANT	\N	PRESENT	0
639382	639380	14179A	PARTICIPANT	\N	PRESENT	0
639383	639380	14205J	PARTICIPANT	\N	PRESENT	1
639384	639380	14147R	PARTICIPANT	\N	PRESENT	0
639385	639380	20092G	PARTICIPANT	\N	PRESENT	0
639412	639397	19515S	PARTICIPANT	\N	PRESENT	0
639414	639397	19369B	PARTICIPANT	\N	PRESENT	0
639415	639397	19575F	PARTICIPANT	\N	PRESENT	0
639416	639397	19762G	PARTICIPANT	\N	PRESENT	0
639423	639397	20094J	PARTICIPANT	\N	PRESENT	0
639425	639397	14031R	PARTICIPANT	\N	PRESENT	0
639426	639397	14329V	PARTICIPANT	\N	PRESENT	0
639428	639397	16685X	PARTICIPANT	\N	PRESENT	0
639430	639397	14030Q	PARTICIPANT	\N	EXCUSE	0
639431	639397	08060W	PARTICIPANT	\N	EXCUSE	0
639432	639397	14105F	PARTICIPANT	\N	EXCUSE	0
639433	639397	19545Y	PARTICIPANT	\N	EXCUSE	0
639434	639397	14195A	PARTICIPANT	\N	EXCUSE	0
639435	639397	20040T	PARTICIPANT	\N	EXCUSE	0
639436	639397	20126Y	PARTICIPANT	\N	EXCUSE	0
639437	639397	08015R	PARTICIPANT	\N	EXCUSE	0
639438	639397	20108W	PARTICIPANT	\N	EXCUSE	0
639439	639397	20054A	PARTICIPANT	\N	EXCUSE	0
640288	639942	10006L	PRESIDENT	0	PRESENT	0
640289	639942	14355X	PARTICIPANT	\N	PRESENT	1
640290	639942	14071N	PARTICIPANT	\N	PRESENT	0
640291	639942	11103C	PARTICIPANT	\N	PRESENT	1
640296	639942	11067R	PARTICIPANT	\N	PRESENT	0
640304	639942	19798U	PARTICIPANT	\N	PRESENT	1
640305	639942	20130U	PARTICIPANT	\N	PRESENT	1
640306	639942	19657G	PARTICIPANT	\N	PRESENT	1
640307	639942	19703U	PARTICIPANT	\N	PRESENT	0
640308	639942	20298U	PARTICIPANT	\N	PRESENT	0
640309	639942	19697Q	PARTICIPANT	\N	PRESENT	1
640310	639942	19553Y	PARTICIPANT	\N	PRESENT	1
640311	639942	20090E	PARTICIPANT	\N	PRESENT	1
640312	639942	14195A	PARTICIPANT	\N	PRESENT	1
640313	639942	19691J	PARTICIPANT	\N	PRESENT	1
640314	639942	11097X	PARTICIPANT	\N	PRESENT	0
640317	639942	14042U	PARTICIPANT	\N	PRESENT	0
640318	639942	08045X	PARTICIPANT	\N	PRESENT	1
640320	639942	20248J	PARTICIPANT	\N	PRESENT	1
640321	639942	11031D	PARTICIPANT	\N	PRESENT	0
640408	639942	14213J	PARTICIPANT	\N	PRESENT	1
640409	639942	19415P	PARTICIPANT	\N	PRESENT	0
640410	639942	14217N	PARTICIPANT	\N	PRESENT	0
640411	639942	20040T	PARTICIPANT	\N	PRESENT	0
640412	639942	14223L	PARTICIPANT	\N	PRESENT	1
640419	639942	19760E	PARTICIPANT	\N	PRESENT	0
640420	639942	18193Q	PARTICIPANT	\N	PRESENT	0
640472	639942	14026U	PARTICIPANT	\N	PRESENT	1
640492	639942	04092N	PARTICIPANT	\N	EXCUSE	0
640723	638888	17737W	PARTICIPANT	\N	PRESENT	0
640725	640724	20032T	PARTICIPANT	\N	PRESENT	0
640726	640724	20024T	PARTICIPANT	\N	PRESENT	0
640727	640724	20042V	PARTICIPANT	\N	PRESENT	0
640728	640724	19643A	PARTICIPANT	\N	PRESENT	0
640729	640724	17737W	PARTICIPANT	\N	PRESENT	0
640730	640724	11026G	PARTICIPANT	\N	PRESENT	0
640731	640724	19745F	PARTICIPANT	\N	PRESENT	0
640732	640724	14331P	PARTICIPANT	\N	PRESENT	0
641958	641957	19717B	PARTICIPANT	\N	EXCUSE	0
641959	641957	14083S	PRESIDENT	0	PRESENT	0
641960	641957	20100N	PARTICIPANT	\N	PRESENT	0
641961	641957	19333N	PARTICIPANT	\N	PRESENT	0
641962	641957	20034V	PARTICIPANT	\N	PRESENT	0
641963	641957	19447X	PARTICIPANT	\N	PRESENT	1
641964	641957	20150Y	PARTICIPANT	\N	PRESENT	0
641965	641957	19503N	PARTICIPANT	\N	PRESENT	1
641966	641957	14031R	PARTICIPANT	\N	PRESENT	1
641967	641957	17023S	PARTICIPANT	\N	PRESENT	0
643798	643797	14219Q	PARTICIPANT	\N	EXCUSE	0
643799	643797	19717B	PARTICIPANT	0	PRESENT	1
643800	643653	04092N	PARTICIPANT	\N	PRESENT	0
643801	643653	04057K	PARTICIPANT	\N	PRESENT	0
643802	643653	19683J	PARTICIPANT	\N	PRESENT	0
643803	643653	19569H	PARTICIPANT	\N	PRESENT	0
643804	643653	14042U	PARTICIPANT	\N	PRESENT	0
643805	643653	19691J	PARTICIPANT	\N	PRESENT	0
643806	643653	20040T	PARTICIPANT	\N	PRESENT	0
643807	643653	11031D	PARTICIPANT	\N	PRESENT	0
643808	643653	11097X	PARTICIPANT	\N	PRESENT	0
643809	643653	14026U	PARTICIPANT	\N	PRESENT	0
643810	643653	10006L	PRESIDENT	0	PRESENT	0
643811	643653	19663E	PARTICIPANT	\N	PRESENT	0
643812	643653	14071N	PARTICIPANT	\N	PRESENT	0
648881	647648	14151M	PARTICIPANT	\N	PRESENT	0
648882	647648	14147R	PARTICIPANT	\N	PRESENT	0
648883	647648	19647E	PARTICIPANT	\N	PRESENT	0
648884	647648	14217N	PARTICIPANT	\N	PRESENT	0
648885	647648	19762G	PARTICIPANT	\N	PRESENT	0
648886	647648	20020P	PARTICIPANT	\N	PRESENT	0
648887	647648	17737W	PARTICIPANT	\N	PRESENT	0
648888	647648	19675J	PARTICIPANT	\N	PRESENT	0
648889	647648	14357A	PARTICIPANT	\N	PRESENT	0
648890	647648	19649G	PARTICIPANT	\N	PRESENT	0
648891	647648	08012N	PARTICIPANT	\N	PRESENT	0
648892	647648	20110Q	PARTICIPANT	\N	PRESENT	0
648893	647648	19347U	PARTICIPANT	\N	PRESENT	0
648894	647648	20130U	PARTICIPANT	\N	PRESENT	0
648895	647648	20266L	PARTICIPANT	\N	PRESENT	0
648896	647648	20092G	PARTICIPANT	\N	PRESENT	0
648897	647648	20134Y	PARTICIPANT	\N	PRESENT	0
648898	647648	19782L	PARTICIPANT	\N	PRESENT	0
648899	647648	08061X	PARTICIPANT	\N	PRESENT	0
648900	647648	14213J	PARTICIPANT	\N	PRESENT	0
648901	647648	19057M	PARTICIPANT	\N	PRESENT	0
648902	647648	20024T	PARTICIPANT	\N	PRESENT	0
648903	647648	19525U	PARTICIPANT	\N	PRESENT	0
648904	647648	14249W	PARTICIPANT	\N	PRESENT	0
648905	647648	19659J	PARTICIPANT	\N	PRESENT	0
648906	647648	11083R	PARTICIPANT	\N	PRESENT	0
648907	647648	20108W	PARTICIPANT	\N	PRESENT	0
648908	647648	20148F	PARTICIPANT	\N	PRESENT	0
648909	647648	95063L	PARTICIPANT	\N	PRESENT	0
648910	647648	20104S	PARTICIPANT	\N	PRESENT	0
648911	647648	19591F	PARTICIPANT	\N	PRESENT	0
648912	647648	14069U	PARTICIPANT	\N	PRESENT	0
648913	647648	14037X	PARTICIPANT	\N	PRESENT	0
648914	647648	11090Q	PARTICIPANT	\N	PRESENT	0
648915	647648	04045F	PARTICIPANT	\N	PRESENT	0
648916	647648	11033F	PARTICIPANT	\N	PRESENT	0
648917	647648	19741B	PARTICIPANT	\N	PRESENT	0
648918	647648	14033T	PARTICIPANT	\N	PRESENT	0
648919	647648	20056C	PARTICIPANT	\N	PRESENT	0
648920	647648	19719D	PARTICIPANT	\N	PRESENT	0
648924	647648	19553Y	PARTICIPANT	\N	PRESENT	0
648922	647648	19467C	PARTICIPANT	\N	PRESENT	0
648923	647648	20034V	PARTICIPANT	\N	PRESENT	0
648925	647648	20132W	PARTICIPANT	\N	PRESENT	0
648926	647648	14038Y	PARTICIPANT	\N	PRESENT	0
648927	647648	20058E	PARTICIPANT	\N	PRESENT	0
648928	647648	14207L	PARTICIPANT	\N	PRESENT	0
648929	647648	19681G	PARTICIPANT	\N	PRESENT	0
648930	647648	17367Q	PARTICIPANT	\N	PRESENT	0
648931	647648	14107H	PARTICIPANT	\N	PRESENT	0
648932	647648	20086J	PARTICIPANT	\N	PRESENT	0
648933	647648	19545Y	PARTICIPANT	\N	PRESENT	0
648934	647648	14211G	PARTICIPANT	\N	PRESENT	0
648935	647648	17589D	PARTICIPANT	\N	PRESENT	0
648936	647648	11064N	PARTICIPANT	\N	PRESENT	0
648937	647648	14251Q	PARTICIPANT	\N	PRESENT	0
648938	647648	14111D	PARTICIPANT	\N	PRESENT	0
648939	647648	19768N	PARTICIPANT	\N	PRESENT	0
648940	647648	04057K	PARTICIPANT	\N	PRESENT	0
648941	647648	19563B	PARTICIPANT	\N	PRESENT	0
648942	647648	20062A	PARTICIPANT	\N	PRESENT	0
648943	647648	20090E	PARTICIPANT	\N	PRESENT	0
648944	647648	19631V	PARTICIPANT	\N	PRESENT	0
648945	647648	04059M	PARTICIPANT	\N	PRESENT	0
648946	647648	20124W	PARTICIPANT	\N	PRESENT	0
648947	647648	19549D	PARTICIPANT	\N	PRESENT	0
648948	647648	20054A	PARTICIPANT	\N	PRESENT	0
648949	647648	20080C	PARTICIPANT	\N	PRESENT	0
648950	647648	20264J	PARTICIPANT	\N	PRESENT	0
648951	647648	20152B	PARTICIPANT	\N	PRESENT	0
648952	647648	01062T	PARTICIPANT	\N	PRESENT	0
648953	647648	19599P	PARTICIPANT	\N	PRESENT	0
648954	647648	19715Y	PARTICIPANT	\N	PRESENT	0
648955	647648	19683J	PARTICIPANT	\N	PRESENT	0
648956	647648	14021P	PARTICIPANT	\N	PRESENT	0
648957	647648	18193Q	PARTICIPANT	\N	PRESENT	0
649067	649066	19443T	PARTICIPANT	\N	PRESENT	0
648959	647648	19503N	PARTICIPANT	\N	PRESENT	0
648960	647648	11026G	PARTICIPANT	\N	PRESENT	0
648961	647648	14229S	PARTICIPANT	\N	PRESENT	0
648962	647648	01028R	PARTICIPANT	\N	PRESENT	0
648963	647648	20084G	PARTICIPANT	\N	PRESENT	0
648964	647648	20064C	PARTICIPANT	\N	PRESENT	0
648965	647648	19669L	PARTICIPANT	\N	PRESENT	0
648966	647648	19441R	PARTICIPANT	\N	PRESENT	0
648967	647648	14030Q	PARTICIPANT	\N	PRESENT	0
648968	647648	20042V	PARTICIPANT	\N	PRESENT	0
648969	647648	14083S	PARTICIPANT	\N	PRESENT	0
648970	647648	20144B	PARTICIPANT	\N	PRESENT	0
648971	647648	14327T	PARTICIPANT	\N	PRESENT	0
648972	647648	01024M	PARTICIPANT	\N	PRESENT	0
648973	647648	01025N	PARTICIPANT	\N	PRESENT	0
648974	647648	20040T	PARTICIPANT	\N	PRESENT	0
648975	647648	20248J	PARTICIPANT	\N	PRESENT	0
648976	647648	17023S	PARTICIPANT	\N	PRESENT	0
648977	647648	14231L	PARTICIPANT	\N	PRESENT	0
648978	647648	19691J	PARTICIPANT	\N	PRESENT	0
648979	647648	20286Q	PARTICIPANT	\N	PRESENT	0
648980	647648	04042C	PARTICIPANT	\N	PRESENT	0
648981	647648	20048C	PARTICIPANT	\N	PRESENT	0
648982	647648	14042U	PARTICIPANT	\N	PRESENT	0
648983	647648	19611R	PARTICIPANT	\N	PRESENT	0
648984	647648	20052X	PARTICIPANT	\N	PRESENT	0
648985	647648	16685X	PARTICIPANT	\N	PRESENT	0
648986	647648	19826F	PARTICIPANT	\N	PRESENT	0
648987	647648	19739H	PARTICIPANT	\N	PRESENT	0
648988	647648	19745F	PARTICIPANT	\N	PRESENT	0
648989	647648	20298U	PARTICIPANT	\N	PRESENT	0
648990	647648	19619A	PARTICIPANT	\N	PRESENT	0
648991	647648	19713W	PARTICIPANT	\N	PRESENT	0
648992	647648	19749K	PARTICIPANT	\N	PRESENT	0
648993	647648	19479G	PARTICIPANT	\N	PRESENT	0
648994	647648	20106U	PARTICIPANT	\N	PRESENT	0
648995	647648	20100N	PARTICIPANT	\N	PRESENT	0
648996	647648	14001X	PARTICIPANT	\N	PRESENT	0
648997	647648	19369B	PARTICIPANT	\N	PRESENT	0
648998	647648	14205J	PARTICIPANT	\N	PRESENT	0
648999	647648	01043Q	PARTICIPANT	\N	PRESENT	0
649001	647648	14225N	PARTICIPANT	\N	PRESENT	0
649002	647648	19383Y	PARTICIPANT	\N	PRESENT	0
649003	647648	14089Y	PARTICIPANT	\N	PRESENT	0
649004	647648	20050V	PARTICIPANT	\N	PRESENT	0
649005	647962	19673G	PARTICIPANT	\N	EXCUSE	0
649053	649052	14357A	PARTICIPANT	\N	PRESENT	0
649054	649052	19443T	PARTICIPANT	\N	PRESENT	0
649069	649068	19443T	PARTICIPANT	\N	PRESENT	0
649261	648790	10006L	PRESIDENT	0	PRESENT	0
649262	648790	20040T	PARTICIPANT	\N	PRESENT	0
649263	648790	20130U	PARTICIPANT	\N	PRESENT	0
649264	648790	14042U	PARTICIPANT	\N	PRESENT	0
649265	648790	17965H	PARTICIPANT	\N	PRESENT	0
649266	648790	19679N	PARTICIPANT	\N	PRESENT	0
649267	648790	17779H	PARTICIPANT	\N	PRESENT	0
649268	648790	20090E	PARTICIPANT	\N	PRESENT	0
649269	648790	19683J	PARTICIPANT	\N	PRESENT	0
649271	648790	19760E	PARTICIPANT	\N	PRESENT	0
649273	648790	08045X	PARTICIPANT	\N	PRESENT	1
649274	648790	19703U	PARTICIPANT	\N	PRESENT	0
649275	648790	11045K	PARTICIPANT	\N	PRESENT	0
649276	648790	14071N	PARTICIPANT	\N	PRESENT	0
649277	648790	14213J	PARTICIPANT	\N	PRESENT	0
649278	648790	19798U	PARTICIPANT	\N	PRESENT	0
649279	648790	19697Q	PARTICIPANT	\N	PRESENT	1
649280	648790	14026U	PARTICIPANT	\N	PRESENT	1
649281	648790	14281W	PARTICIPANT	\N	PRESENT	0
649282	648790	19553Y	PARTICIPANT	\N	PRESENT	0
649283	648790	19717B	PARTICIPANT	\N	PRESENT	1
649284	648790	20066E	PARTICIPANT	\N	PRESENT	1
649285	648790	01034P	PARTICIPANT	\N	PRESENT	0
649287	648790	19715Y	PARTICIPANT	\N	EXCUSE	0
649288	648790	19591F	PARTICIPANT	\N	PRESENT	0
649294	648790	20248J	PARTICIPANT	\N	PRESENT	0
649295	648790	11097X	PARTICIPANT	\N	PRESENT	0
649296	648790	19713W	PARTICIPANT	\N	PRESENT	0
649297	648790	14223L	PARTICIPANT	\N	PRESENT	0
649299	648790	19657G	PARTICIPANT	\N	PRESENT	0
651355	649165	14097Y	PARTICIPANT	\N	PRESENT	0
651356	649165	95041E	PARTICIPANT	\N	PRESENT	0
651357	649165	95063L	PARTICIPANT	\N	PRESENT	0
651360	649165	19565D	PARTICIPANT	\N	PRESENT	0
651361	649165	20102Q	PARTICIPANT	\N	PRESENT	0
631964	631497	14215L	PARTICIPANT	\N	PRESENT	0
631965	631497	14147R	PARTICIPANT	\N	PRESENT	0
631966	631497	18083K	PARTICIPANT	\N	PRESENT	0
631967	631497	20108W	PARTICIPANT	\N	PRESENT	0
631968	631497	11056N	PARTICIPANT	\N	PRESENT	0
631969	631497	97011G	PARTICIPANT	\N	PRESENT	0
631970	631497	19699S	PARTICIPANT	\N	PRESENT	0
631971	631562	19629C	PARTICIPANT	\N	PRESENT	1
631972	631562	20128B	PARTICIPANT	\N	PRESENT	1
631973	631562	14107H	PARTICIPANT	\N	PRESENT	1
631974	631562	19749K	PARTICIPANT	\N	PRESENT	1
631975	631562	20022R	PARTICIPANT	\N	EXCUSE	0
631976	631497	95041E	PARTICIPANT	\N	PRESENT	0
631977	631497	19575F	PARTICIPANT	\N	PRESENT	0
631978	631497	20174H	PARTICIPANT	\N	PRESENT	0
631979	631497	20090E	PARTICIPANT	\N	PRESENT	0
631980	631497	01058X	PARTICIPANT	\N	PRESENT	0
631983	631497	19507S	PARTICIPANT	\N	PRESENT	0
631984	631497	20026V	PARTICIPANT	\N	PRESENT	0
632001	631497	19760E	PARTICIPANT	\N	PRESENT	0
632002	631497	19954N	PARTICIPANT	\N	PRESENT	0
632003	631497	19543W	PARTICIPANT	\N	PRESENT	0
632004	631497	08056B	PARTICIPANT	\N	PRESENT	0
632005	631497	14033T	PARTICIPANT	\N	PRESENT	0
632007	631497	14205J	PARTICIPANT	\N	PRESENT	0
632008	631497	11012A	PARTICIPANT	\N	PRESENT	0
632009	631497	20248J	PARTICIPANT	\N	PRESENT	0
632010	631497	20100N	PARTICIPANT	\N	PRESENT	0
632011	631497	14038Y	PARTICIPANT	\N	PRESENT	0
632012	631497	19467C	PARTICIPANT	\N	PRESENT	0
632015	631497	19798U	PARTICIPANT	\N	PRESENT	0
632017	631497	11040E	PARTICIPANT	\N	PRESENT	0
632020	631497	19593H	PARTICIPANT	\N	PRESENT	0
632021	631497	19782L	PARTICIPANT	\N	PRESENT	0
632022	631497	14259Y	PARTICIPANT	\N	PRESENT	0
632023	631497	12028B	PARTICIPANT	\N	PRESENT	0
632024	631497	19479G	PARTICIPANT	\N	PRESENT	0
632025	631497	14231L	PARTICIPANT	\N	PRESENT	0
632026	631497	14107H	PARTICIPANT	\N	PRESENT	0
632027	631460	11026G	PARTICIPANT	\N	PRESENT	1
632028	631497	04045F	PARTICIPANT	\N	PRESENT	0
632030	631497	11054L	PARTICIPANT	\N	PRESENT	0
632032	631497	14207L	PARTICIPANT	\N	PRESENT	0
632035	631497	16685X	PARTICIPANT	\N	PRESENT	0
632036	631497	20032T	PARTICIPANT	\N	PRESENT	0
632037	631497	20266L	PARTICIPANT	\N	PRESENT	0
632038	631935	19651A	PARTICIPANT	\N	PRESENT	0
632039	631935	19399H	PARTICIPANT	\N	EXCUSE	0
632040	631935	19735D	PARTICIPANT	\N	EXCUSE	0
632041	631935	20084G	PARTICIPANT	\N	PRESENT	0
632042	631935	19527W	PARTICIPANT	\N	PRESENT	0
632043	631935	20052X	PARTICIPANT	\N	PRESENT	0
632044	631935	11109J	PARTICIPANT	\N	EXCUSE	0
632046	631497	11104D	PARTICIPANT	\N	PRESENT	0
632047	631497	19741B	PARTICIPANT	\N	PRESENT	0
632048	631497	14073Q	PARTICIPANT	\N	PRESENT	0
632049	631497	12041X	PARTICIPANT	\N	PRESENT	0
632050	631497	20110Q	PARTICIPANT	\N	PRESENT	0
632053	631497	01043Q	PARTICIPANT	\N	PRESENT	0
632054	631497	11083R	PARTICIPANT	\N	PRESENT	0
632055	631497	17965H	PARTICIPANT	\N	PRESENT	0
632056	631497	07004J	PARTICIPANT	\N	PRESENT	0
632057	631497	14267Y	PARTICIPANT	\N	PRESENT	0
632058	631497	01060R	PARTICIPANT	\N	PRESENT	0
632059	631497	20056C	PARTICIPANT	\N	PRESENT	0
632114	631505	11012A	PARTICIPANT	\N	PRESENT	0
632115	631505	01060R	PARTICIPANT	\N	PRESENT	0
632116	631505	17965H	PARTICIPANT	\N	PRESENT	0
632117	631505	19591F	PARTICIPANT	\N	PRESENT	0
632118	631505	04045F	PARTICIPANT	\N	PRESENT	0
632119	631505	19387D	PARTICIPANT	\N	PRESENT	0
632120	631505	20266L	PARTICIPANT	\N	PRESENT	0
632121	631505	20110Q	PARTICIPANT	\N	PRESENT	0
632122	631505	19347U	PARTICIPANT	\N	PRESENT	0
632123	631505	20100N	PARTICIPANT	\N	PRESENT	0
632124	631505	19565D	PARTICIPANT	\N	PRESENT	0
632125	631505	19593H	PARTICIPANT	\N	PRESENT	0
632126	631505	14107H	PARTICIPANT	\N	PRESENT	0
632127	631505	20072C	PARTICIPANT	\N	PRESENT	0
632128	631505	14207L	PARTICIPANT	\N	PRESENT	0
632129	631505	11064N	PARTICIPANT	\N	PRESENT	0
632130	631505	19479G	PARTICIPANT	\N	PRESENT	0
632131	631505	14205J	PARTICIPANT	\N	PRESENT	0
632132	631505	16685X	PARTICIPANT	\N	PRESENT	0
632133	631505	11083R	PARTICIPANT	\N	PRESENT	0
632134	631505	01043Q	PARTICIPANT	\N	PRESENT	0
632135	631505	14073Q	PARTICIPANT	\N	PRESENT	0
632136	631505	19826F	PARTICIPANT	\N	PRESENT	0
632137	631505	14215L	PARTICIPANT	\N	PRESENT	0
632138	631505	19581D	PARTICIPANT	\N	PRESENT	0
632139	631505	19383Y	PARTICIPANT	\N	PRESENT	0
632140	631505	19762G	PARTICIPANT	\N	PRESENT	0
632141	631505	97011G	PARTICIPANT	\N	PRESENT	0
632142	631505	14121F	PARTICIPANT	\N	PRESENT	0
632143	631505	08056B	PARTICIPANT	\N	PRESENT	0
632144	631505	20090E	PARTICIPANT	\N	PRESENT	0
632145	631505	14105F	PARTICIPANT	\N	PRESENT	0
632146	631505	14038Y	PARTICIPANT	\N	PRESENT	0
632147	631505	20058E	PARTICIPANT	\N	PRESENT	0
632148	631505	20124W	PARTICIPANT	\N	PRESENT	0
632149	631505	20042V	PARTICIPANT	\N	PRESENT	0
632150	631505	14189C	PARTICIPANT	\N	PRESENT	0
632151	631505	20062A	PARTICIPANT	\N	PRESENT	0
632152	631505	20032T	PARTICIPANT	\N	PRESENT	0
632153	631505	20024T	PARTICIPANT	\N	PRESENT	0
632154	631505	19954N	PARTICIPANT	\N	PRESENT	0
632155	631505	18083K	PARTICIPANT	\N	PRESENT	0
632156	631505	14033T	PARTICIPANT	\N	PRESENT	0
632157	631505	19447X	PARTICIPANT	\N	PRESENT	0
632158	631505	14147R	PARTICIPANT	\N	PRESENT	0
632159	631505	01048V	PARTICIPANT	\N	PRESENT	0
632160	631505	11043H	PARTICIPANT	\N	PRESENT	0
632161	631505	19575F	PARTICIPANT	\N	PRESENT	0
632162	631505	20076G	PARTICIPANT	\N	PRESENT	0
632163	631505	11103C	PARTICIPANT	\N	PRESENT	0
632165	631505	08061X	PARTICIPANT	\N	PRESENT	0
632166	631505	10006L	PARTICIPANT	\N	PRESENT	0
632112	631505	14026U	PARTICIPANT	\N	PRESENT	0
632113	631505	19798U	PARTICIPANT	\N	PRESENT	0
632168	631505	19691J	PARTICIPANT	\N	PRESENT	0
632171	631505	19573D	PARTICIPANT	\N	PRESENT	0
632172	631505	20026V	PARTICIPANT	\N	PRESENT	0
632173	631505	20248J	PARTICIPANT	\N	PRESENT	0
632174	631505	14231L	PARTICIPANT	\N	PRESENT	0
632175	631505	20172F	PARTICIPANT	\N	PRESENT	0
632176	631505	20116W	PARTICIPANT	\N	PRESENT	0
632177	631505	20114U	PARTICIPANT	\N	PRESENT	0
632181	631505	19713W	PARTICIPANT	\N	PRESENT	0
632182	631505	08028W	PARTICIPANT	\N	PRESENT	0
632183	631505	20180F	PARTICIPANT	\N	PRESENT	0
632184	631505	20034V	PARTICIPANT	\N	PRESENT	0
632185	631505	11033F	PARTICIPANT	\N	PRESENT	0
632186	631505	19569H	PARTICIPANT	\N	PRESENT	0
632187	631505	20048C	PARTICIPANT	\N	PRESENT	0
632188	631505	14217N	PARTICIPANT	\N	PRESENT	0
632189	631505	19758L	PARTICIPANT	\N	PRESENT	0
632191	631505	20142Y	PARTICIPANT	\N	PRESENT	0
632192	631505	11097X	PARTICIPANT	\N	PRESENT	0
632193	631505	07029T	PARTICIPANT	\N	PRESENT	0
632194	631505	20088L	PARTICIPANT	\N	PRESENT	0
632195	631505	19703U	PARTICIPANT	\N	PRESENT	0
632196	631505	19563B	PARTICIPANT	\N	PRESENT	0
632197	631505	19467C	PARTICIPANT	\N	PRESENT	0
632198	631505	01024M	PARTICIPANT	\N	PRESENT	0
632199	631505	11067R	PARTICIPANT	\N	PRESENT	0
632200	631505	11072N	PARTICIPANT	\N	PRESENT	0
632201	631505	14179A	PARTICIPANT	\N	PRESENT	0
632203	631505	20174H	PARTICIPANT	\N	PRESENT	0
644790	644311	19631V	PARTICIPANT	\N	PRESENT	1
644791	644311	19705W	PARTICIPANT	\N	PRESENT	0
644792	644311	19707Y	PARTICIPANT	\N	PRESENT	1
644793	644311	19369B	PARTICIPANT	\N	PRESENT	1
644794	644311	14038Y	PARTICIPANT	\N	PRESENT	0
644795	644311	20030R	PARTICIPANT	\N	PRESENT	1
644796	644311	19467C	PARTICIPANT	\N	PRESENT	1
644797	644311	19695N	PARTICIPANT	\N	PRESENT	1
644798	644311	14033T	PARTICIPANT	\N	PRESENT	1
644799	644311	11090Q	PRESIDENT	0	PRESENT	0
644800	644311	20054A	PARTICIPANT	\N	PRESENT	1
644801	644311	14205J	PARTICIPANT	\N	PRESENT	0
644802	644311	20060X	PARTICIPANT	\N	PRESENT	1
644803	644311	20062A	PARTICIPANT	\N	PRESENT	1
644804	644311	20286Q	PARTICIPANT	\N	PRESENT	1
644805	644311	14207L	PARTICIPANT	\N	PRESENT	1
644806	644311	19747H	PARTICIPANT	\N	PRESENT	1
644807	644311	14257W	PARTICIPANT	\N	PRESENT	1
644810	643817	20076G	PARTICIPANT	\N	PRESENT	0
644811	643817	19387D	PARTICIPANT	\N	PRESENT	1
644812	643817	19637C	PARTICIPANT	\N	PRESENT	1
644813	643817	17367Q	PARTICIPANT	\N	PRESENT	1
644814	643817	20120S	PARTICIPANT	\N	PRESENT	1
644815	643817	20032T	PARTICIPANT	\N	PRESENT	1
644816	643817	20140W	PARTICIPANT	\N	PRESENT	1
644817	643817	20046A	PARTICIPANT	\N	PRESENT	1
644818	643817	19739H	PARTICIPANT	\N	PRESENT	1
644819	643817	19745F	PARTICIPANT	\N	PRESENT	1
644820	643817	19577H	PARTICIPANT	\N	PRESENT	1
644992	644424	20022R	PARTICIPANT	\N	PRESENT	1
644993	644424	14215L	PARTICIPANT	\N	PRESENT	1
644994	644424	20074E	PARTICIPANT	\N	PRESENT	1
644995	644424	20128B	PARTICIPANT	\N	PRESENT	1
644996	644424	14179A	PARTICIPANT	\N	PRESENT	1
644997	644424	14021P	PARTICIPANT	\N	PRESENT	1
644998	644424	19489J	PARTICIPANT	\N	PRESENT	1
644999	644424	19649G	PARTICIPANT	\N	PRESENT	1
645000	644424	14147R	PARTICIPANT	\N	PRESENT	1
645001	644424	10015M	PARTICIPANT	\N	PRESENT	1
645002	644424	01028R	PARTICIPANT	\N	PRESENT	1
645005	645004	04047H	PARTICIPANT	\N	PRESENT	0
645006	645004	14151M	PARTICIPANT	\N	PRESENT	0
645007	645004	19673G	PARTICIPANT	\N	PRESENT	0
645008	645004	19611R	PARTICIPANT	\N	PRESENT	0
645009	645004	19758L	PARTICIPANT	\N	PRESENT	0
645010	645004	20152B	PARTICIPANT	\N	PRESENT	0
645011	645004	04059M	PARTICIPANT	\N	PRESENT	0
645012	645004	19399H	PARTICIPANT	\N	PRESENT	0
645013	645004	08012N	PARTICIPANT	\N	PRESENT	0
645032	644833	20070A	PARTICIPANT	\N	PRESENT	0
645034	645033	19741B	PARTICIPANT	\N	PRESENT	0
645036	645035	19741B	PARTICIPANT	\N	PRESENT	0
645038	645037	07029T	PARTICIPANT	\N	PRESENT	0
645072	644424	04059M	PARTICIPANT	\N	PRESENT	0
645073	644424	19758L	PARTICIPANT	\N	PRESENT	0
645074	644424	19399H	PARTICIPANT	\N	PRESENT	0
645075	644424	19611R	PARTICIPANT	\N	PRESENT	0
645076	644424	19699S	PARTICIPANT	\N	PRESENT	0
645077	644424	08012N	PARTICIPANT	\N	PRESENT	0
645078	644424	19573D	PARTICIPANT	\N	PRESENT	0
645079	644424	19651A	PARTICIPANT	\N	PRESENT	1
645080	644424	20138D	PARTICIPANT	\N	PRESENT	1
645081	644424	19057M	PARTICIPANT	\N	PRESENT	1
645082	644424	20132W	PARTICIPANT	\N	PRESENT	1
645083	644424	14073Q	PARTICIPANT	\N	PRESENT	1
645084	644424	11043H	PARTICIPANT	\N	PRESENT	1
645085	644424	20084G	PARTICIPANT	\N	PRESENT	1
645086	644424	20026V	PARTICIPANT	\N	PRESENT	1
645087	644424	19533U	PARTICIPANT	\N	PRESENT	1
645114	645113	14215L	PARTICIPANT	\N	PRESENT	0
645115	645113	19629C	PARTICIPANT	\N	PRESENT	0
645116	645113	14275Y	PARTICIPANT	\N	PRESENT	0
645117	645113	19585H	PARTICIPANT	\N	PRESENT	0
645148	645145	20132W	PARTICIPANT	\N	PRESENT	0
645149	645145	19611R	PRESIDENT	0	PRESENT	0
645150	645145	20142Y	PARTICIPANT	\N	PRESENT	1
645151	645145	20112S	PARTICIPANT	\N	PRESENT	1
645152	645145	08012N	PARTICIPANT	\N	PRESENT	0
645153	645145	11043H	PARTICIPANT	\N	PRESENT	1
645154	645145	19399H	PARTICIPANT	\N	PRESENT	0
645155	645145	19758L	PARTICIPANT	\N	PRESENT	0
645156	645145	14229S	PARTICIPANT	\N	PRESENT	1
645157	645111	19533U	PARTICIPANT	\N	PRESENT	0
645158	645111	20074E	PARTICIPANT	\N	PRESENT	0
645159	645111	19585H	PARTICIPANT	\N	PRESENT	0
645160	645111	04047H	PRESIDENT	0	PRESENT	0
645161	645111	14229S	PARTICIPANT	\N	PRESENT	1
645162	645111	01028R	PARTICIPANT	\N	PRESENT	0
645163	645111	19573D	PARTICIPANT	\N	PRESENT	0
645164	645111	14179A	PARTICIPANT	\N	PRESENT	1
645165	645111	20112S	PARTICIPANT	\N	PRESENT	1
645166	645111	14147R	PARTICIPANT	\N	PRESENT	1
645167	645111	08012N	PARTICIPANT	\N	PRESENT	0
645168	645111	20022R	PARTICIPANT	\N	PRESENT	0
645169	645111	20024T	PARTICIPANT	\N	PRESENT	0
645170	645111	19527W	PARTICIPANT	\N	PRESENT	1
645171	645111	20132W	PARTICIPANT	\N	PRESENT	1
645172	645111	14111D	PARTICIPANT	\N	PRESENT	0
645173	645111	14073Q	PARTICIPANT	\N	PRESENT	1
645174	645111	19611R	PARTICIPANT	\N	PRESENT	0
645175	645111	20142Y	PARTICIPANT	\N	PRESENT	1
645176	645111	19399H	PARTICIPANT	\N	PRESENT	0
645177	645111	20152B	PARTICIPANT	\N	PRESENT	0
645178	645111	11033F	PARTICIPANT	\N	PRESENT	1
645179	645111	20172F	PARTICIPANT	\N	PRESENT	0
645180	645111	20056C	PARTICIPANT	\N	PRESENT	0
645181	645111	11056N	PARTICIPANT	\N	PRESENT	1
645182	645111	11043H	PARTICIPANT	\N	PRESENT	1
645183	645111	19758L	PARTICIPANT	\N	PRESENT	0
645184	645111	17737W	PARTICIPANT	\N	PRESENT	1
645185	645111	19489J	PARTICIPANT	\N	PRESENT	1
645186	645111	19649G	PARTICIPANT	\N	PRESENT	1
645187	645111	20138D	PARTICIPANT	\N	PRESENT	0
645188	645111	20058E	PARTICIPANT	\N	PRESENT	1
645189	645145	19527W	PARTICIPANT	\N	PRESENT	1
645190	645145	14073Q	PARTICIPANT	\N	PRESENT	1
645191	645145	19533U	PARTICIPANT	\N	PRESENT	0
645192	645145	20138D	PARTICIPANT	\N	PRESENT	0
645193	645145	20152B	PARTICIPANT	\N	PRESENT	0
645194	645145	20172F	PARTICIPANT	\N	PRESENT	0
645195	645145	20058E	PARTICIPANT	\N	PRESENT	1
645196	645145	20056C	PARTICIPANT	\N	PRESENT	0
645197	645145	19573D	PARTICIPANT	\N	PRESENT	0
645212	645111	05008E	PARTICIPANT	\N	EXCUSE	0
645286	645213	11026G	PARTICIPANT	\N	PRESENT	0
645287	645213	10015M	PARTICIPANT	\N	PRESENT	0
645304	645303	20024T	PARTICIPANT	\N	PRESENT	0
645305	645303	20042V	PARTICIPANT	\N	PRESENT	0
645306	645303	18083K	PARTICIPANT	\N	PRESENT	0
645307	645303	11026G	PARTICIPANT	\N	PRESENT	0
645308	645303	10015M	PARTICIPANT	\N	PRESENT	0
645313	645110	20132W	PARTICIPANT	\N	PRESENT	0
645314	645110	19649G	PARTICIPANT	\N	PRESENT	1
645315	645110	20074E	PARTICIPANT	\N	PRESENT	0
645316	645110	04047H	PRESIDENT	0	PRESENT	0
645317	645110	19399H	PARTICIPANT	\N	PRESENT	0
645318	645110	20052X	PARTICIPANT	\N	PRESENT	0
645319	645110	01028R	PARTICIPANT	\N	PRESENT	0
645320	645110	11033F	PARTICIPANT	\N	PRESENT	0
645321	645110	20058E	PARTICIPANT	\N	PRESENT	0
645322	645110	20056C	PARTICIPANT	\N	PRESENT	0
645323	645110	19573D	PARTICIPANT	\N	PRESENT	0
645324	645110	14147R	PARTICIPANT	\N	PRESENT	1
645325	645110	20112S	PARTICIPANT	\N	PRESENT	1
645326	645110	14179A	PARTICIPANT	\N	PRESENT	1
645327	645110	14123H	PARTICIPANT	\N	PRESENT	0
645328	645110	08012N	PARTICIPANT	\N	PRESENT	0
645329	645110	11043H	PARTICIPANT	\N	PRESENT	1
645330	645110	20022R	PARTICIPANT	\N	PRESENT	0
645331	645110	19758L	PARTICIPANT	\N	PRESENT	0
645332	645110	20024T	PARTICIPANT	\N	PRESENT	0
645333	645110	20026V	PARTICIPANT	\N	PRESENT	1
645334	645110	14021P	PARTICIPANT	\N	PRESENT	0
645337	645110	19699S	PARTICIPANT	\N	PRESENT	0
645338	645110	19533U	PARTICIPANT	\N	PRESENT	0
645339	645110	04085P	PARTICIPANT	\N	PRESENT	0
645340	645110	95063L	PARTICIPANT	\N	PRESENT	0
645341	645146	20132W	PARTICIPANT	\N	PRESENT	0
645342	645146	19573D	PARTICIPANT	\N	PRESENT	0
645343	645146	14123H	PARTICIPANT	\N	PRESENT	0
634646	634645	14211G	PARTICIPANT	\N	PRESENT	0
634668	634667	14331P	PARTICIPANT	\N	PRESENT	0
634669	634667	11083R	PARTICIPANT	\N	PRESENT	0
634670	634667	19725B	PARTICIPANT	\N	PRESENT	0
634671	634667	14073Q	PARTICIPANT	\N	PRESENT	0
634672	634667	14033T	PARTICIPANT	\N	PRESENT	0
634832	634433	10006L	PRESIDENT	0	PRESENT	0
634833	634433	19691J	PARTICIPANT	\N	PRESENT	1
634834	634433	19717B	PARTICIPANT	\N	PRESENT	1
634835	634433	19723Y	PARTICIPANT	\N	PRESENT	1
634836	634433	14213J	PARTICIPANT	\N	PRESENT	1
634837	634433	20066E	PARTICIPANT	\N	PRESENT	1
634838	634433	20148F	PARTICIPANT	\N	PRESENT	0
634839	634433	14223L	PARTICIPANT	\N	PRESENT	0
634840	634433	19798U	PARTICIPANT	\N	PRESENT	0
634841	634433	11067R	PARTICIPANT	\N	PRESENT	0
634842	634433	14042U	PARTICIPANT	\N	PRESENT	0
634843	634433	14026U	PARTICIPANT	\N	PRESENT	0
634844	634433	19569H	PARTICIPANT	\N	PRESENT	0
634845	634433	20090E	PARTICIPANT	\N	PRESENT	0
634846	634433	18193Q	PARTICIPANT	\N	PRESENT	0
634847	634433	20248J	PARTICIPANT	\N	EXCUSE	0
634848	634433	20040T	PARTICIPANT	\N	EXCUSE	0
634849	634433	14217N	PARTICIPANT	\N	PRESENT	0
634850	634433	20130U	PARTICIPANT	\N	PRESENT	0
638658	638464	19441R	PARTICIPANT	\N	PRESENT	0
638659	638464	19725B	PARTICIPANT	\N	PRESENT	0
634853	634433	19760E	PARTICIPANT	\N	PRESENT	1
638657	638464	14331P	PRESIDENT	0	PRESENT	0
638660	638464	19711U	PARTICIPANT	\N	PRESENT	0
638661	638464	10015M	PARTICIPANT	\N	PRESENT	0
638662	638464	20104S	PARTICIPANT	\N	PRESENT	0
638663	638464	20286Q	PARTICIPANT	\N	PRESENT	1
638664	638464	14001X	PARTICIPANT	\N	PRESENT	1
638665	638464	04045F	PARTICIPANT	\N	PRESENT	1
638666	638464	14097Y	PARTICIPANT	\N	PRESENT	1
638667	638464	11026G	PARTICIPANT	\N	PRESENT	0
638668	638464	14021P	PARTICIPANT	\N	PRESENT	0
638669	638464	05012A	PARTICIPANT	\N	PRESENT	0
638670	638464	95063L	PARTICIPANT	\N	PRESENT	0
638671	638464	07004J	PARTICIPANT	\N	PRESENT	0
638672	638464	05008E	PARTICIPANT	\N	PRESENT	0
638683	638464	04047H	PARTICIPANT	\N	PRESENT	0
638691	638464	19673G	PARTICIPANT	\N	PRESENT	0
638692	638464	19729F	PARTICIPANT	\N	PRESENT	1
638693	638464	20022R	PARTICIPANT	\N	PRESENT	1
638694	638464	14147R	PARTICIPANT	\N	PRESENT	1
638695	638464	04085P	PARTICIPANT	\N	PRESENT	1
638696	638464	14179A	PARTICIPANT	\N	PRESENT	1
638697	638464	19649G	PARTICIPANT	\N	PRESENT	1
638698	638464	19447X	PARTICIPANT	\N	PRESENT	1
638699	638464	20114U	PARTICIPANT	\N	PRESENT	1
638700	638464	14107H	PARTICIPANT	\N	PRESENT	1
638701	638464	20110Q	PARTICIPANT	\N	PRESENT	1
638704	638464	01028R	PARTICIPANT	\N	PRESENT	0
638705	638464	19543W	PARTICIPANT	\N	PRESENT	0
638706	638464	14111D	PARTICIPANT	\N	PRESENT	0
638707	638464	14151M	PARTICIPANT	\N	PRESENT	1
639291	639288	20056C	PARTICIPANT	\N	PRESENT	0
639292	639288	19573D	PARTICIPANT	\N	PRESENT	0
639293	639289	19573D	PARTICIPANT	\N	PRESENT	0
639295	639289	20056C	PARTICIPANT	\N	PRESENT	0
639296	639289	19593H	PARTICIPANT	\N	PRESENT	0
639297	639289	20124W	PARTICIPANT	\N	PRESENT	0
639298	639289	14109K	PARTICIPANT	\N	PRESENT	0
639299	639289	20180F	PARTICIPANT	\N	PRESENT	0
640367	640126	18193Q	PARTICIPANT	\N	PRESENT	0
640368	640058	19383Y	PARTICIPANT	\N	PRESENT	0
640369	640058	20030R	PARTICIPANT	\N	PRESENT	1
640370	640058	19515S	PARTICIPANT	\N	PRESENT	0
640371	640058	19782L	PARTICIPANT	\N	PRESENT	1
640372	640058	14357A	PARTICIPANT	\N	PRESENT	0
640373	640058	20078J	PARTICIPANT	\N	PRESENT	0
640374	640058	19413M	PARTICIPANT	\N	PRESENT	1
640375	640058	20144B	PARTICIPANT	\N	PRESENT	0
640376	640058	20082E	PARTICIPANT	\N	PRESENT	0
640377	640058	11090Q	PRESIDENT	0	PRESENT	0
640378	640058	20094J	PARTICIPANT	\N	PRESENT	0
640379	640058	19631V	PARTICIPANT	\N	PRESENT	0
640380	640058	20174H	PARTICIPANT	\N	PRESENT	1
640381	640058	14205J	PARTICIPANT	\N	PRESENT	0
640382	640058	19705W	PARTICIPANT	\N	PRESENT	1
640383	640058	19707Y	PARTICIPANT	\N	PRESENT	1
640384	640058	19507S	PARTICIPANT	\N	PRESENT	0
640385	640058	20286Q	PARTICIPANT	\N	PRESENT	1
640386	640058	19747H	PARTICIPANT	\N	PRESENT	0
640387	640058	08028W	PARTICIPANT	\N	PRESENT	0
640388	640058	14257W	PARTICIPANT	\N	PRESENT	1
640389	640058	20028X	PARTICIPANT	\N	PRESENT	1
640392	640058	19768N	PARTICIPANT	\N	PRESENT	0
640393	640058	08015R	PARTICIPANT	\N	PRESENT	1
640394	640058	19563B	PARTICIPANT	\N	PRESENT	1
640395	640058	14033T	PARTICIPANT	\N	PRESENT	0
640396	640058	14251Q	PARTICIPANT	\N	PRESENT	1
640397	640058	20104S	PARTICIPANT	\N	EXCUSE	0
640398	640058	19333N	PARTICIPANT	\N	PRESENT	0
640399	640058	14331P	PARTICIPANT	\N	PRESENT	0
640400	640058	14026U	PARTICIPANT	\N	PRESENT	0
640401	640058	20100N	PARTICIPANT	\N	PRESENT	0
640402	640058	14189C	PARTICIPANT	\N	PRESENT	0
640403	640058	11026G	PARTICIPANT	\N	PRESENT	0
640404	640058	10015M	PARTICIPANT	\N	PRESENT	0
640405	640058	14169X	PARTICIPANT	\N	PRESENT	0
640406	640058	19866P	PARTICIPANT	\N	PRESENT	1
640407	640058	19467C	PARTICIPANT	\N	PRESENT	1
640413	640058	19711U	PARTICIPANT	\N	PRESENT	1
640414	640058	04070G	PARTICIPANT	\N	PRESENT	1
640507	639967	20132W	PARTICIPANT	\N	PRESENT	0
640508	639967	19533U	PRESIDENT	0	PRESENT	0
640509	639967	19798U	PARTICIPANT	\N	PRESENT	1
640510	639967	20042V	PRESIDENT	1	PRESENT	0
640511	639967	19820Y	PARTICIPANT	\N	PRESENT	1
640512	639967	14207L	PARTICIPANT	\N	PRESENT	0
640513	639967	19599P	PARTICIPANT	\N	PRESENT	0
640591	639944	20086J	PARTICIPANT	\N	PRESENT	0
640592	639944	14327T	PARTICIPANT	\N	PRESENT	0
640593	639944	07029T	PARTICIPANT	\N	PRESENT	0
640594	639944	19479G	PARTICIPANT	\N	PRESENT	0
640595	639944	11012A	PARTICIPANT	\N	PRESENT	0
640596	639944	19711U	PARTICIPANT	\N	PRESENT	0
640597	639944	14189C	PARTICIPANT	\N	PRESENT	0
640598	639944	19545Y	PRESIDENT	0	PRESENT	0
640599	639944	19687N	PARTICIPANT	\N	PRESENT	0
640600	639944	20080C	PARTICIPANT	\N	PRESENT	0
640601	639944	19349W	PARTICIPANT	\N	PRESENT	0
640602	639944	99004R	PARTICIPANT	\N	PRESENT	0
642535	642252	14251Q	PARTICIPANT	\N	EXCUSE	0
642536	642252	19515S	PARTICIPANT	\N	EXCUSE	0
642537	642252	14329V	PARTICIPANT	\N	EXCUSE	0
643813	643653	14213J	PARTICIPANT	\N	PRESENT	0
643814	643653	20090E	PARTICIPANT	\N	PRESENT	0
643815	643653	11103C	PARTICIPANT	\N	PRESENT	1
643816	643653	17779H	PARTICIPANT	\N	PRESENT	1
643818	643653	08045X	PARTICIPANT	\N	PRESENT	1
643819	643653	19717B	PARTICIPANT	\N	PRESENT	1
643820	643653	19697Q	PARTICIPANT	\N	PRESENT	1
643821	643653	20130U	PARTICIPANT	\N	PRESENT	0
643822	643653	04043D	PARTICIPANT	\N	PRESENT	1
644252	644004	19766L	PARTICIPANT	\N	PRESENT	0
644253	644004	19533U	PARTICIPANT	\N	PRESENT	1
644254	644004	20074E	PARTICIPANT	\N	PRESENT	1
644255	644004	14001X	PARTICIPANT	\N	PRESENT	1
644256	644004	04047H	PRESIDENT	0	PRESENT	0
644257	644004	01028R	PARTICIPANT	\N	PRESENT	1
644258	644004	14229S	PARTICIPANT	\N	PRESENT	0
644259	644004	14231L	PARTICIPANT	\N	PRESENT	0
644260	644004	19489J	PARTICIPANT	\N	PRESENT	1
644261	644004	17737W	PARTICIPANT	\N	PRESENT	1
644262	644004	19573D	PARTICIPANT	\N	PRESENT	0
644263	644004	20110Q	PARTICIPANT	\N	PRESENT	1
644264	644004	14147R	PARTICIPANT	\N	PRESENT	1
644265	644004	14179A	PARTICIPANT	\N	PRESENT	1
644266	644004	14215L	PARTICIPANT	\N	PRESENT	1
644267	644004	08012N	PARTICIPANT	\N	PRESENT	0
644268	644004	20022R	PARTICIPANT	\N	PRESENT	1
644269	644004	20026V	PARTICIPANT	\N	PRESENT	1
644270	644004	14053L	PARTICIPANT	\N	PRESENT	1
644271	644004	20132W	PARTICIPANT	\N	PRESENT	0
644272	644004	19643A	PARTICIPANT	\N	PRESENT	1
644273	644004	20134Y	PARTICIPANT	\N	PRESENT	0
648619	647641	08045X	PARTICIPANT	\N	PRESENT	0
648680	647641	20298U	PARTICIPANT	\N	PRESENT	0
648691	647641	11045K	PARTICIPANT	\N	PRESENT	0
649289	649286	19717B	PARTICIPANT	\N	PRESENT	0
649290	649286	19329S	PARTICIPANT	\N	PRESENT	0
649291	649286	20034V	PARTICIPANT	\N	PRESENT	0
649292	649286	20016T	PARTICIPANT	\N	PRESENT	0
649293	649286	11072N	PARTICIPANT	\N	PRESENT	0
649315	649314	04047H	PARTICIPANT	\N	PRESENT	0
649316	649314	05008E	PARTICIPANT	\N	PRESENT	0
649317	649314	01028R	PARTICIPANT	\N	PRESENT	0
649318	649314	14147R	PARTICIPANT	\N	PRESENT	1
651303	651302	04047H	PARTICIPANT	\N	PRESENT	0
651304	651302	05008E	PARTICIPANT	\N	PRESENT	1
651321	651293	19533U	PARTICIPANT	\N	PRESENT	0
651330	651293	01048V	PARTICIPANT	\N	EXCUSE	0
651333	651331	19693L	PARTICIPANT	\N	EXCUSE	0
651334	651331	19663E	PARTICIPANT	\N	EXCUSE	0
651338	651331	20128B	PARTICIPANT	\N	EXCUSE	0
651340	651331	20066E	PARTICIPANT	\N	EXCUSE	0
651341	651331	19735D	PARTICIPANT	\N	EXCUSE	0
651342	651331	01048V	PARTICIPANT	\N	EXCUSE	0
651344	651331	11067R	PARTICIPANT	\N	EXCUSE	0
651345	651331	19533U	PARTICIPANT	\N	PRESENT	0
651346	651331	04043D	PARTICIPANT	\N	EXCUSE	0
651347	651331	01058X	PARTICIPANT	\N	EXCUSE	0
651599	651598	11053K	PARTICIPANT	\N	PRESENT	0
651602	651601	11048N	PARTICIPANT	\N	PRESENT	0
651605	651604	14225N	PARTICIPANT	\N	PRESENT	0
651606	651604	11048N	PARTICIPANT	\N	PRESENT	0
651607	651604	01057W	PARTICIPANT	\N	PRESENT	0
651610	651609	20078J	PARTICIPANT	\N	PRESENT	0
651611	651609	04045F	PARTICIPANT	\N	PRESENT	0
651612	651609	19768N	PARTICIPANT	\N	PRESENT	0
651613	651609	19515S	PARTICIPANT	\N	PRESENT	0
651614	651609	19575F	PARTICIPANT	\N	PRESENT	0
651615	651609	14038Y	PARTICIPANT	\N	PRESENT	0
651616	651609	20034V	PARTICIPANT	\N	PRESENT	0
651748	650957	14026U	PARTICIPANT	\N	PRESENT	1
651749	650957	11045K	PARTICIPANT	\N	PRESENT	1
651750	650957	01034P	PARTICIPANT	\N	PRESENT	1
651751	650957	18193Q	PARTICIPANT	\N	PRESENT	1
651752	650957	19553Y	PARTICIPANT	\N	PRESENT	1
651753	650957	04057K	PARTICIPANT	\N	PRESENT	1
651754	650957	19663E	PARTICIPANT	\N	PRESENT	0
651755	650957	10006L	PRESIDENT	0	PRESENT	0
651756	650957	14042U	PARTICIPANT	\N	PRESENT	0
651757	650957	20040T	PARTICIPANT	\N	PRESENT	0
651758	650957	14281W	PARTICIPANT	\N	PRESENT	0
651759	650957	19723Y	PARTICIPANT	\N	PRESENT	0
651760	650957	19697Q	PARTICIPANT	\N	PRESENT	0
651761	650957	14071N	PARTICIPANT	\N	PRESENT	0
651762	650957	20130U	PARTICIPANT	\N	PRESENT	0
651763	650957	17965H	PARTICIPANT	\N	PRESENT	0
651764	650957	19679N	PARTICIPANT	\N	PRESENT	0
651765	650957	20298U	PARTICIPANT	\N	PRESENT	0
651766	650957	20266L	PARTICIPANT	\N	PRESENT	0
651767	650957	19301E	PARTICIPANT	\N	PRESENT	1
651768	650957	20024T	PARTICIPANT	\N	PRESENT	0
651769	650957	14033T	PARTICIPANT	\N	PRESENT	0
651776	651586	14026U	PARTICIPANT	\N	PRESENT	0
651777	651586	10015M	PARTICIPANT	\N	PRESENT	0
651778	651586	19563B	PARTICIPANT	\N	PRESENT	0
651779	651586	20022R	PARTICIPANT	\N	PRESENT	0
651780	651586	20110Q	PARTICIPANT	\N	PRESENT	0
651781	651586	19593H	PARTICIPANT	\N	PRESENT	0
651782	651586	07004J	PARTICIPANT	\N	PRESENT	0
651783	651586	14107H	PARTICIPANT	\N	PRESENT	0
651784	651586	11033F	PARTICIPANT	\N	PRESENT	0
651785	651586	14151M	PARTICIPANT	\N	PRESENT	0
651786	651586	20128B	PARTICIPANT	\N	PRESENT	0
651787	651586	19583F	PARTICIPANT	\N	PRESENT	0
651788	651586	11077T	PARTICIPANT	\N	PRESENT	0
651789	651586	20034V	PARTICIPANT	\N	PRESENT	0
651790	651586	19671E	PARTICIPANT	\N	PRESENT	0
651791	651586	20090E	PARTICIPANT	\N	PRESENT	0
651792	651586	19826F	PARTICIPANT	\N	PRESENT	0
651793	651586	20252E	PARTICIPANT	\N	PRESENT	0
651794	651586	19701S	PARTICIPANT	\N	PRESENT	0
651795	651586	19741B	PARTICIPANT	\N	PRESENT	0
651796	651586	20026V	PARTICIPANT	\N	PRESENT	0
651797	651586	14207L	PARTICIPANT	\N	PRESENT	0
651798	651586	20140W	PARTICIPANT	\N	PRESENT	0
651799	651586	19673G	PARTICIPANT	\N	PRESENT	0
651800	651586	20106U	PARTICIPANT	\N	PRESENT	0
651801	651586	19651A	PARTICIPANT	\N	PRESENT	0
651802	651586	04047H	PARTICIPANT	\N	PRESENT	0
651803	651586	17229F	PARTICIPANT	\N	PRESENT	0
651804	651586	20052X	PARTICIPANT	\N	PRESENT	0
651805	651586	14205J	PARTICIPANT	\N	PRESENT	0
651806	651586	14031R	PARTICIPANT	\N	PRESENT	0
651807	651586	19729F	PARTICIPANT	\N	PRESENT	0
651808	651586	97011G	PARTICIPANT	\N	PRESENT	0
651809	651586	14215L	PARTICIPANT	\N	PRESENT	0
651810	651586	19747H	PARTICIPANT	\N	PRESENT	0
651811	651586	14038Y	PARTICIPANT	\N	PRESENT	0
651812	651586	20248J	PARTICIPANT	\N	PRESENT	0
651813	651586	01058X	PARTICIPANT	\N	PRESENT	0
651814	651586	19621T	PARTICIPANT	\N	PRESENT	0
651815	651586	19387D	PARTICIPANT	\N	PRESENT	0
651816	651586	11083R	PARTICIPANT	\N	PRESENT	0
651817	651586	11066Q	PARTICIPANT	\N	PRESENT	0
651818	651586	19565D	PARTICIPANT	\N	PRESENT	0
651819	651586	20098N	PARTICIPANT	\N	PRESENT	0
651820	651586	14111D	PARTICIPANT	\N	PRESENT	0
651821	651586	19697Q	PARTICIPANT	\N	PRESENT	0
651822	651586	19577H	PARTICIPANT	\N	PRESENT	0
651823	651586	19503N	PARTICIPANT	\N	PRESENT	0
651824	651586	19467C	PARTICIPANT	\N	PRESENT	0
651825	651586	95063L	PARTICIPANT	\N	PRESENT	0
651826	651586	14105F	PARTICIPANT	\N	PRESENT	0
651827	651586	20032T	PARTICIPANT	\N	PRESENT	0
651828	651586	20152B	PARTICIPANT	\N	PRESENT	0
651829	651586	19553Y	PARTICIPANT	\N	PRESENT	0
651830	651586	20096L	PARTICIPANT	\N	PRESENT	0
651831	651586	19723Y	PARTICIPANT	\N	PRESENT	0
651832	651586	19679N	PARTICIPANT	\N	PRESENT	0
651833	651586	19745F	PARTICIPANT	\N	PRESENT	0
651834	651586	19575F	PARTICIPANT	\N	PRESENT	0
651835	651586	99004R	PARTICIPANT	\N	PRESENT	0
651836	651586	19479G	PARTICIPANT	\N	PRESENT	0
651837	651586	20054A	PARTICIPANT	\N	PRESENT	0
651838	651586	20070A	PARTICIPANT	\N	PRESENT	0
651839	651586	14223L	PARTICIPANT	\N	PRESENT	0
651840	651586	11065P	PARTICIPANT	\N	PRESENT	0
651841	651586	08056B	PARTICIPANT	\N	PRESENT	0
651842	651586	19383Y	PARTICIPANT	\N	PRESENT	0
651843	651586	18083K	PARTICIPANT	\N	PRESENT	0
651844	651586	20108W	PARTICIPANT	\N	PRESENT	0
651845	651586	20038A	PARTICIPANT	\N	PRESENT	0
651846	651586	19349W	PARTICIPANT	\N	PRESENT	0
651847	651586	14237S	PARTICIPANT	\N	PRESENT	0
651848	651586	20068G	PARTICIPANT	\N	PRESENT	0
651849	651586	08034U	PARTICIPANT	\N	PRESENT	0
651850	651586	20042V	PARTICIPANT	\N	PRESENT	0
651851	651586	19739H	PARTICIPANT	\N	PRESENT	0
651852	651586	20066E	PARTICIPANT	\N	PRESENT	0
651853	651586	19649G	PARTICIPANT	\N	PRESENT	0
651854	651586	20084G	PARTICIPANT	\N	PRESENT	0
651855	651586	95041E	PARTICIPANT	\N	PRESENT	0
651856	651586	20030R	PARTICIPANT	\N	PRESENT	0
651857	651586	20018V	PARTICIPANT	\N	PRESENT	0
651858	651586	14249W	PARTICIPANT	\N	PRESENT	0
651859	651586	14021P	PARTICIPANT	\N	PRESENT	0
651860	651586	14089Y	PARTICIPANT	\N	PRESENT	0
651861	651586	08061X	PARTICIPANT	\N	PRESENT	0
629589	629021	11031D	PARTICIPANT	\N	PRESENT	0
629591	629021	19717B	PARTICIPANT	\N	PRESENT	1
629593	629021	19415P	PARTICIPANT	\N	PRESENT	0
629598	629021	14213J	PARTICIPANT	\N	PRESENT	0
629618	629021	14195A	PARTICIPANT	\N	PRESENT	0
629619	629021	20248J	PARTICIPANT	\N	PRESENT	1
629621	629021	19657G	PARTICIPANT	\N	PRESENT	1
629623	629021	19367Y	PARTICIPANT	\N	PRESENT	0
629624	629021	19703U	PARTICIPANT	\N	PRESENT	0
629625	629021	08045X	PARTICIPANT	\N	PRESENT	0
629626	629021	20130U	PARTICIPANT	\N	PRESENT	0
629628	629021	18193Q	PARTICIPANT	\N	PRESENT	0
629792	629021	14223L	PARTICIPANT	\N	PRESENT	0
630827	630502	14089Y	PARTICIPANT	\N	PRESENT	0
630828	630502	20098N	PARTICIPANT	\N	PRESENT	0
630829	630502	11026G	PARTICIPANT	\N	PRESENT	0
631985	631981	05008E	PARTICIPANT	\N	PRESENT	0
631986	631981	20024T	PARTICIPANT	\N	PRESENT	0
631987	631981	14030Q	PARTICIPANT	\N	PRESENT	0
631988	631981	17737W	PARTICIPANT	\N	PRESENT	0
631989	631981	11101A	PARTICIPANT	\N	PRESENT	0
631990	631981	19545Y	PARTICIPANT	\N	PRESENT	0
631991	631981	14357A	PARTICIPANT	\N	PRESENT	0
631992	631981	97011G	PARTICIPANT	\N	PRESENT	0
631993	631981	04035D	PARTICIPANT	\N	PRESENT	0
631994	631981	14026U	PARTICIPANT	\N	PRESENT	0
631995	631981	14179A	PARTICIPANT	\N	PRESENT	0
631996	631981	08034U	PARTICIPANT	\N	PRESENT	0
631997	631981	14147R	PARTICIPANT	\N	PRESENT	0
631998	631981	14169X	PARTICIPANT	\N	PRESENT	0
631999	631981	04045F	PARTICIPANT	\N	PRESENT	0
632000	631981	11041F	PARTICIPANT	\N	PRESENT	0
632006	631981	19711U	PARTICIPANT	\N	PRESENT	0
632033	632029	19723Y	PARTICIPANT	\N	PRESENT	0
632034	632029	19735D	PARTICIPANT	\N	PRESENT	0
632052	632051	19503N	PARTICIPANT	\N	PRESENT	0
632267	631506	04085P	PARTICIPANT	\N	PRESENT	0
632268	631506	20070A	PARTICIPANT	\N	PRESENT	0
632269	631506	19725B	PARTICIPANT	\N	PRESENT	0
632270	631506	20088L	PARTICIPANT	\N	PRESENT	0
632271	631506	20114U	PARTICIPANT	\N	PRESENT	0
632272	631506	14105F	PARTICIPANT	\N	PRESENT	0
632273	631506	19563B	PARTICIPANT	\N	PRESENT	0
632274	631506	11067R	PARTICIPANT	\N	PRESENT	0
632275	631506	20110Q	PARTICIPANT	\N	PRESENT	0
632276	631506	19954N	PARTICIPANT	\N	PRESENT	0
632277	631506	14147R	PARTICIPANT	\N	PRESENT	0
632278	631506	11072N	PARTICIPANT	\N	PRESENT	0
632279	631506	11033F	PARTICIPANT	\N	PRESENT	0
632280	631506	11064N	PARTICIPANT	\N	PRESENT	0
632281	631506	20266L	PARTICIPANT	\N	PRESENT	0
632282	631506	19387D	PARTICIPANT	\N	PRESENT	0
632283	631506	19713W	PARTICIPANT	\N	PRESENT	0
632284	631506	20174H	PARTICIPANT	\N	PRESENT	0
632285	631506	14179A	PARTICIPANT	\N	PRESENT	0
632286	631506	14231L	PARTICIPANT	\N	PRESENT	0
632287	631506	01024M	PARTICIPANT	\N	PRESENT	0
632288	631506	19749K	PARTICIPANT	\N	PRESENT	0
632289	631506	14205J	PARTICIPANT	\N	PRESENT	0
632290	631506	19581D	PARTICIPANT	\N	PRESENT	0
632291	631506	08028W	PARTICIPANT	\N	PRESENT	0
632292	631506	19467C	PARTICIPANT	\N	PRESENT	0
632293	631506	19798U	PARTICIPANT	\N	PRESENT	0
632294	631506	20090E	PARTICIPANT	\N	PRESENT	0
632295	631506	20248J	PARTICIPANT	\N	PRESENT	0
632296	631506	11097X	PARTICIPANT	\N	PRESENT	0
632297	631506	19703U	PARTICIPANT	\N	PRESENT	0
632298	631506	14151M	PARTICIPANT	\N	PRESENT	0
632299	631506	20172F	PARTICIPANT	\N	PRESENT	0
632300	631506	07029T	PARTICIPANT	\N	PRESENT	0
632301	631506	14069U	PARTICIPANT	\N	PRESENT	0
632302	631506	01048V	PARTICIPANT	\N	PRESENT	0
632303	631506	20180F	PARTICIPANT	\N	PRESENT	0
632304	631506	20026V	PARTICIPANT	\N	PRESENT	0
632305	631506	19447X	PARTICIPANT	\N	PRESENT	0
632306	631506	19573D	PARTICIPANT	\N	PRESENT	0
632307	631506	14211G	PARTICIPANT	\N	PRESENT	0
632308	631506	20032T	PARTICIPANT	\N	PRESENT	0
632309	631506	19691J	PARTICIPANT	\N	PRESENT	0
632310	631506	19762G	PARTICIPANT	\N	PRESENT	0
632265	631506	14026U	PARTICIPANT	\N	PRESENT	0
632266	631506	19565D	PARTICIPANT	\N	PRESENT	0
632311	631506	10006L	PARTICIPANT	\N	PRESENT	0
632312	631506	19747H	PARTICIPANT	\N	PRESENT	0
632313	631506	14257W	PARTICIPANT	\N	PRESENT	0
632314	631506	20046A	PARTICIPANT	\N	PRESENT	0
632315	631506	19758L	PARTICIPANT	\N	PRESENT	0
632318	632316	18083K	PARTICIPANT	\N	PRESENT	0
632319	632316	20266L	PARTICIPANT	\N	PRESENT	0
632325	631506	14121F	PARTICIPANT	\N	PRESENT	0
632326	631506	20042V	PARTICIPANT	\N	PRESENT	0
632327	631506	14193X	PARTICIPANT	\N	PRESENT	0
632328	631506	20100N	PARTICIPANT	\N	PRESENT	0
632329	631506	20142Y	PARTICIPANT	\N	PRESENT	0
632334	631506	14215L	PARTICIPANT	\N	PRESENT	0
632336	631506	04047H	PARTICIPANT	\N	PRESENT	0
632341	632340	18083K	PARTICIPANT	\N	PRESENT	0
632342	632340	20266L	PARTICIPANT	\N	PRESENT	0
632345	632343	20266L	PARTICIPANT	\N	PRESENT	0
632346	632343	18083K	PARTICIPANT	\N	PRESENT	0
632347	631506	19593H	PARTICIPANT	\N	PRESENT	0
632352	632351	18083K	PARTICIPANT	\N	PRESENT	0
632353	632351	20266L	PARTICIPANT	\N	PRESENT	0
632354	631506	04045F	PARTICIPANT	\N	PRESENT	0
632355	631506	14207L	PARTICIPANT	\N	PRESENT	0
632362	632360	20266L	PARTICIPANT	\N	PRESENT	0
632363	632360	18083K	PARTICIPANT	\N	PRESENT	0
632365	632364	20266L	PARTICIPANT	\N	PRESENT	0
632366	632364	18083K	PARTICIPANT	\N	PRESENT	0
632368	631506	20116W	PARTICIPANT	\N	PRESENT	0
632369	632367	18083K	PARTICIPANT	\N	PRESENT	0
632370	632367	20266L	PARTICIPANT	\N	PRESENT	0
632372	632371	20266L	PARTICIPANT	\N	PRESENT	0
632373	632371	18083K	PARTICIPANT	\N	PRESENT	0
632378	631506	19479G	PARTICIPANT	\N	PRESENT	0
632379	631506	20044X	PARTICIPANT	\N	PRESENT	0
632380	631506	20066E	PARTICIPANT	\N	PRESENT	0
632384	631506	20058E	PARTICIPANT	\N	PRESENT	0
632385	631506	20056C	PARTICIPANT	\N	PRESENT	0
632390	631506	20034V	PARTICIPANT	\N	PRESENT	0
632391	631506	01058X	PARTICIPANT	\N	PRESENT	0
632392	631506	19689Q	PARTICIPANT	\N	PRESENT	0
632396	631506	20124W	PARTICIPANT	\N	PRESENT	0
632397	631506	20152B	PARTICIPANT	\N	PRESENT	0
632401	631506	19575F	PARTICIPANT	\N	PRESENT	0
632402	631506	20108W	PARTICIPANT	\N	PRESENT	0
632403	631506	11053K	PARTICIPANT	\N	PRESENT	0
632404	631506	14053L	PARTICIPANT	\N	PRESENT	0
632405	631506	97011G	PARTICIPANT	\N	PRESENT	0
632408	631506	18193Q	PARTICIPANT	\N	PRESENT	0
632409	631506	07004J	PARTICIPANT	\N	PRESENT	0
632412	632410	14213J	PARTICIPANT	\N	PRESENT	0
632413	632410	14097Y	PARTICIPANT	\N	PRESENT	0
632414	632410	20050V	PARTICIPANT	\N	PRESENT	0
632415	632410	20082E	PARTICIPANT	\N	PRESENT	0
632417	631506	19553Y	PARTICIPANT	\N	PRESENT	0
632418	632416	19747H	PARTICIPANT	\N	PRESENT	0
632419	632416	19693L	PARTICIPANT	\N	PRESENT	0
632420	632416	20050V	PARTICIPANT	\N	PRESENT	0
632421	632416	20082E	PARTICIPANT	\N	PRESENT	0
632422	631506	20054A	PARTICIPANT	\N	PRESENT	0
632433	631506	14357A	PARTICIPANT	\N	PRESENT	0
632434	631506	19569H	PARTICIPANT	\N	PRESENT	0
632435	631506	14059S	PARTICIPANT	\N	PRESENT	0
632436	631506	20062A	PARTICIPANT	\N	PRESENT	0
632437	631506	14038Y	PARTICIPANT	\N	PRESENT	0
632438	631506	19383Y	PARTICIPANT	\N	PRESENT	0
632439	631506	14107H	PARTICIPANT	\N	PRESENT	0
632440	631506	19629C	PARTICIPANT	\N	PRESENT	0
632441	631506	19760E	PARTICIPANT	\N	PRESENT	0
632442	631506	11043H	PARTICIPANT	\N	PRESENT	0
632444	631506	11056N	PARTICIPANT	\N	PRESENT	0
632445	632443	19693L	PARTICIPANT	\N	PRESENT	0
632446	632443	19593H	PARTICIPANT	\N	PRESENT	0
632447	631506	19413M	PARTICIPANT	\N	PRESENT	0
632449	632448	19693L	PARTICIPANT	\N	PRESENT	0
632450	632448	19593H	PARTICIPANT	\N	PRESENT	0
632463	631506	20264J	PARTICIPANT	\N	PRESENT	0
632471	631506	19415P	PARTICIPANT	\N	PRESENT	0
645344	645146	08012N	PARTICIPANT	\N	PRESENT	0
645345	645146	11043H	PARTICIPANT	\N	PRESENT	1
645346	645146	19399H	PARTICIPANT	\N	PRESENT	0
645347	645146	19758L	PARTICIPANT	\N	PRESENT	0
645348	645146	20052X	PARTICIPANT	\N	PRESENT	0
645349	645110	05008E	PARTICIPANT	\N	EXCUSE	0
645350	645147	20132W	PARTICIPANT	\N	PRESENT	0
645351	645147	20112S	PARTICIPANT	\N	PRESENT	1
645352	645147	08012N	PARTICIPANT	\N	PRESENT	0
645353	645147	11043H	PARTICIPANT	\N	PRESENT	1
645354	645147	19758L	PARTICIPANT	\N	PRESENT	0
645355	645147	20026V	PARTICIPANT	\N	PRESENT	1
645356	645112	20132W	PARTICIPANT	\N	PRESENT	0
645357	645112	19649G	PARTICIPANT	\N	PRESENT	1
645358	645112	20074E	PARTICIPANT	\N	PRESENT	0
645359	645112	20076G	PARTICIPANT	\N	PRESENT	1
645360	645112	04047H	PRESIDENT	0	PRESENT	0
645361	645112	11033F	PARTICIPANT	\N	PRESENT	0
645362	645112	04085P	PARTICIPANT	\N	PRESENT	0
645363	645112	20058E	PARTICIPANT	\N	PRESENT	1
645364	645112	95063L	PARTICIPANT	\N	PRESENT	0
645365	645112	14147R	PARTICIPANT	\N	PRESENT	1
645366	645112	08012N	PARTICIPANT	\N	PRESENT	0
645367	645112	11043H	PARTICIPANT	\N	PRESENT	0
645368	645112	20022R	PARTICIPANT	\N	PRESENT	0
645369	645112	20024T	PARTICIPANT	\N	PRESENT	0
645370	645112	19758L	PARTICIPANT	\N	PRESENT	0
645371	645112	20026V	PARTICIPANT	\N	PRESENT	1
645372	645112	14021P	PARTICIPANT	\N	PRESENT	0
645373	645112	05008E	PARTICIPANT	\N	EXCUSE	0
645432	645031	19647E	PARTICIPANT	\N	PRESENT	1
645433	645031	14121F	PARTICIPANT	\N	PRESENT	1
645434	645031	19671E	PARTICIPANT	\N	PRESENT	1
645435	645031	20036X	PARTICIPANT	\N	PRESENT	1
645436	645031	19687N	PARTICIPANT	\N	PRESENT	1
645437	645031	19479G	PARTICIPANT	\N	PRESENT	1
645496	644650	19717B	PARTICIPANT	\N	PRESENT	1
645497	644650	19577H	PARTICIPANT	\N	PRESENT	1
645498	644650	19347U	PARTICIPANT	\N	PRESENT	1
645499	644650	19691J	PARTICIPANT	\N	PRESENT	0
645500	644650	20034V	PARTICIPANT	\N	EXCUSE	0
645501	644650	14097Y	PARTICIPANT	\N	PRESENT	0
645502	644650	19657G	PARTICIPANT	\N	PRESENT	0
645503	644650	14147R	PARTICIPANT	\N	PRESENT	1
645504	644650	19301E	PARTICIPANT	\N	PRESENT	0
645505	644650	20150Y	PARTICIPANT	\N	PRESENT	0
645506	644650	20146D	PRESIDENT	0	PRESENT	0
645507	644650	01024M	PARTICIPANT	\N	PRESENT	0
645513	645512	19629C	PARTICIPANT	\N	PRESENT	0
645514	645512	14215L	PARTICIPANT	\N	PRESENT	0
645516	645515	19629C	PARTICIPANT	\N	PRESENT	0
645517	645515	14215L	PARTICIPANT	\N	PRESENT	0
645550	645549	20126Y	PARTICIPANT	\N	PRESENT	0
645552	645551	20126Y	PARTICIPANT	\N	PRESENT	0
645554	645553	20126Y	PARTICIPANT	\N	PRESENT	0
645582	645581	14257W	PARTICIPANT	\N	PRESENT	0
645583	645581	11090Q	PARTICIPANT	\N	PRESENT	0
645584	645581	20286Q	PARTICIPANT	\N	PRESENT	0
645597	645595	19631V	PARTICIPANT	\N	PRESENT	0
645598	645595	14187A	PARTICIPANT	\N	PRESENT	0
645600	645599	19631V	PARTICIPANT	\N	PRESENT	0
645601	645599	14187A	PARTICIPANT	\N	PRESENT	0
645604	645602	19631V	PARTICIPANT	\N	PRESENT	0
645605	645602	14187A	PARTICIPANT	\N	PRESENT	1
645606	645602	01043Q	PARTICIPANT	\N	PRESENT	0
645611	645607	01043Q	PARTICIPANT	\N	PRESENT	0
645609	645607	19631V	PARTICIPANT	\N	PRESENT	0
645610	645607	14187A	PARTICIPANT	\N	PRESENT	0
645613	645612	19631V	PARTICIPANT	\N	PRESENT	0
645614	645612	14187A	PARTICIPANT	\N	PRESENT	1
645615	645612	01043Q	PARTICIPANT	\N	PRESENT	1
645617	645616	19631V	PARTICIPANT	\N	PRESENT	0
645618	645616	14187A	PARTICIPANT	\N	PRESENT	1
645621	645619	19631V	PARTICIPANT	\N	PRESENT	0
645622	645619	14187A	PARTICIPANT	\N	PRESENT	0
645624	645623	19631V	PARTICIPANT	\N	PRESENT	0
645625	645623	14187A	PARTICIPANT	\N	PRESENT	0
645627	645626	19631V	PARTICIPANT	\N	PRESENT	0
645628	645626	14187A	PARTICIPANT	\N	PRESENT	1
645630	645629	19631V	PARTICIPANT	\N	PRESENT	0
645684	645681	10015M	PARTICIPANT	\N	PRESENT	0
645687	645681	11026G	PARTICIPANT	\N	PRESENT	0
645692	645691	19631V	PARTICIPANT	\N	PRESENT	0
645693	645691	14187A	PARTICIPANT	\N	PRESENT	0
645695	645694	07033P	PARTICIPANT	\N	PRESENT	0
645696	645694	19443T	PARTICIPANT	\N	PRESENT	0
645698	645697	07033P	PARTICIPANT	\N	PRESENT	0
645699	645697	19443T	PARTICIPANT	\N	PRESENT	0
645700	644649	05008E	PARTICIPANT	\N	EXCUSE	0
645701	644649	14219Q	PARTICIPANT	\N	EXCUSE	0
645702	643797	05008E	PARTICIPANT	\N	EXCUSE	0
645708	645707	11040E	PARTICIPANT	\N	PRESENT	0
645709	645707	14331P	PARTICIPANT	\N	PRESENT	0
645710	645707	19349W	PARTICIPANT	\N	PRESENT	0
645711	645707	04035D	PARTICIPANT	\N	PRESENT	0
645712	645707	19643A	PARTICIPANT	\N	PRESENT	0
645714	645713	14038Y	PARTICIPANT	\N	PRESENT	0
645715	645713	20092G	PARTICIPANT	\N	PRESENT	0
645716	645713	19629C	PARTICIPANT	\N	PRESENT	0
645717	645713	14147R	PARTICIPANT	\N	PRESENT	0
645719	645718	14042U	PARTICIPANT	\N	PRESENT	0
645720	645718	11097X	PARTICIPANT	\N	PRESENT	0
645721	645718	20130U	PARTICIPANT	\N	PRESENT	0
645808	645335	19593H	PARTICIPANT	\N	PRESENT	0
645809	645490	19647E	PARTICIPANT	\N	PRESENT	0
645810	645490	19531S	PARTICIPANT	\N	PRESENT	0
645813	645460	19697Q	PARTICIPANT	\N	PRESENT	0
645814	645460	20090E	PARTICIPANT	\N	PRESENT	0
645815	645460	04092N	PARTICIPANT	\N	PRESENT	0
645816	645460	14281W	PARTICIPANT	\N	PRESENT	0
645817	645460	19679N	PARTICIPANT	\N	PRESENT	0
645818	645460	14213J	PARTICIPANT	\N	PRESENT	0
645819	645460	14217N	PARTICIPANT	\N	PRESENT	0
645820	645460	10006L	PRESIDENT	0	PRESENT	0
645821	645490	11053K	PARTICIPANT	\N	PRESENT	0
645822	645460	17965H	PARTICIPANT	\N	PRESENT	0
645823	645460	14071N	PARTICIPANT	\N	PRESENT	0
645824	645460	18193Q	PARTICIPANT	\N	PRESENT	0
645825	645460	20130U	PARTICIPANT	\N	EXCUSE	0
645826	645760	14038Y	PARTICIPANT	\N	PRESENT	0
645827	645760	20088L	PARTICIPANT	\N	PRESENT	0
645828	645760	14187A	PARTICIPANT	\N	PRESENT	0
645829	645760	19413M	PARTICIPANT	\N	PRESENT	0
645830	645760	19695N	PARTICIPANT	\N	PRESENT	0
645831	645760	20094J	PARTICIPANT	\N	PRESENT	1
645832	645760	11090Q	PRESIDENT	0	PRESENT	0
645833	645760	14033T	PARTICIPANT	\N	PRESENT	0
645834	645760	01025N	PARTICIPANT	\N	PRESENT	0
645835	645760	20104S	PARTICIPANT	\N	PRESENT	0
645836	645760	19507S	PARTICIPANT	\N	PRESENT	0
645837	645760	20018V	PARTICIPANT	\N	PRESENT	0
645838	645760	19747H	PARTICIPANT	\N	PRESENT	0
645839	645760	14257W	PARTICIPANT	\N	PRESENT	0
645840	645760	20034V	PARTICIPANT	\N	PRESENT	1
645841	645760	20092G	PARTICIPANT	\N	PRESENT	0
645842	645760	19782L	PARTICIPANT	\N	PRESENT	1
645843	645760	20078J	PARTICIPANT	\N	PRESENT	1
645844	645760	08015R	PARTICIPANT	\N	PRESENT	1
645845	645760	14207L	PARTICIPANT	\N	PRESENT	1
645846	645760	04045F	PARTICIPANT	\N	PRESENT	0
645847	645760	20286Q	PARTICIPANT	\N	PRESENT	1
645848	645760	19563B	PARTICIPANT	\N	PRESENT	0
645849	645490	14187A	PARTICIPANT	\N	PRESENT	0
645850	645760	01043Q	PARTICIPANT	\N	EXCUSE	0
645851	645760	19631V	PARTICIPANT	\N	EXCUSE	0
645852	645760	20028X	PARTICIPANT	\N	EXCUSE	0
645853	645760	11077T	PARTICIPANT	\N	PRESENT	0
645854	645312	20136B	PARTICIPANT	\N	PRESENT	0
645855	645312	19826F	PARTICIPANT	\N	PRESENT	0
645856	645312	19599P	PARTICIPANT	\N	PRESENT	0
645857	645760	19768N	PARTICIPANT	\N	PRESENT	1
645858	645760	20144B	PARTICIPANT	\N	PRESENT	0
645859	645460	19415P	PARTICIPANT	\N	PRESENT	0
645860	645312	08060W	PARTICIPANT	\N	PRESENT	0
645861	645312	14031R	PARTICIPANT	\N	PRESENT	0
645862	645312	14219Q	PRESIDENT	0	PRESENT	0
645863	645312	19820Y	PARTICIPANT	\N	PRESENT	0
645864	645312	19745F	PARTICIPANT	\N	PRESENT	0
645865	645312	20076G	PARTICIPANT	\N	PRESENT	1
645866	645312	19619A	PARTICIPANT	\N	PRESENT	0
645867	645312	19333N	PARTICIPANT	\N	PRESENT	0
627767	626799	14281W	PARTICIPANT	\N	PRESENT	0
627785	626799	19713W	PARTICIPANT	\N	PRESENT	0
627803	626799	19717B	PARTICIPANT	\N	PRESENT	1
628825	628823	19515S	PRESIDENT	0	PRESENT	0
628826	628823	19301E	PARTICIPANT	\N	PRESENT	0
628827	628823	19671E	PARTICIPANT	\N	PRESENT	0
628828	628823	20126Y	PARTICIPANT	\N	PRESENT	0
628829	628823	08028W	PARTICIPANT	\N	PRESENT	0
628830	628823	20082E	PARTICIPANT	\N	PRESENT	0
628831	628823	19762G	PARTICIPANT	\N	PRESENT	0
628832	628823	19575F	PARTICIPANT	\N	PRESENT	0
628833	628823	14030Q	PARTICIPANT	\N	EXCUSE	0
628834	628823	14105F	PARTICIPANT	\N	EXCUSE	0
628835	628823	19467C	PARTICIPANT	\N	EXCUSE	0
628856	628823	20060X	PARTICIPANT	\N	PRESENT	0
628912	628824	14231L	PRESIDENT	0	PRESENT	0
628914	628824	19515S	PARTICIPANT	\N	PRESENT	0
628915	628824	05012A	PARTICIPANT	\N	PRESENT	0
628917	628824	19333N	PARTICIPANT	\N	PRESENT	0
628918	628824	19251M	PARTICIPANT	\N	PRESENT	0
628919	628824	08028W	PARTICIPANT	\N	PRESENT	0
628920	628824	19762G	PARTICIPANT	\N	PRESENT	0
628921	628824	19575F	PARTICIPANT	\N	PRESENT	0
628922	628824	19631V	PARTICIPANT	\N	PRESENT	0
628926	628824	20090E	PARTICIPANT	\N	PRESENT	0
628924	628824	20082E	PARTICIPANT	\N	PRESENT	0
628925	628824	20084G	PARTICIPANT	\N	PRESENT	0
628927	628824	20024T	PARTICIPANT	\N	PRESENT	0
628928	628824	14215L	PARTICIPANT	\N	PRESENT	0
628929	628824	19739H	PARTICIPANT	\N	PRESENT	0
628930	628824	19369B	PARTICIPANT	\N	PRESENT	0
628931	628824	16685X	PARTICIPANT	\N	PRESENT	0
628933	628824	20092G	PARTICIPANT	\N	PRESENT	0
628934	628824	20110Q	PARTICIPANT	\N	PRESENT	0
628936	628824	17637T	PARTICIPANT	\N	PRESENT	0
628937	628824	19671E	PARTICIPANT	\N	PRESENT	0
628938	628824	20126Y	PARTICIPANT	\N	PRESENT	0
628939	628824	19735D	PARTICIPANT	\N	PRESENT	0
628940	628824	19782L	PARTICIPANT	\N	PRESENT	0
628941	628824	20286Q	PARTICIPANT	\N	PRESENT	0
628942	628824	14205J	PARTICIPANT	\N	PRESENT	0
628943	628824	19820Y	PARTICIPANT	\N	PRESENT	0
628944	628824	14107H	PARTICIPANT	\N	PRESENT	0
628945	628824	20078J	PARTICIPANT	\N	PRESENT	0
628946	628824	20062A	PARTICIPANT	\N	PRESENT	0
628947	628824	20022R	PARTICIPANT	\N	PRESENT	0
628948	628824	19349W	PARTICIPANT	\N	PRESENT	0
628949	628824	14229S	PARTICIPANT	\N	PRESENT	0
628950	628824	19619A	PARTICIPANT	\N	PRESENT	0
628951	628824	19681G	PARTICIPANT	\N	EXCUSE	0
628952	628824	14327T	PARTICIPANT	\N	EXCUSE	0
628953	628824	19565D	PARTICIPANT	\N	EXCUSE	0
628954	628824	19447X	PARTICIPANT	\N	EXCUSE	0
628955	628824	19563B	PARTICIPANT	\N	EXCUSE	0
628956	628824	19826F	PARTICIPANT	\N	EXCUSE	0
628957	628824	14071N	PARTICIPANT	\N	EXCUSE	0
628958	628824	04045F	PARTICIPANT	\N	EXCUSE	0
628959	628824	20122U	PARTICIPANT	\N	EXCUSE	0
628961	628823	16685X	PARTICIPANT	\N	PRESENT	0
628962	628823	19369B	PARTICIPANT	\N	PRESENT	0
628963	628823	14215L	PARTICIPANT	\N	PRESENT	0
628964	628823	19739H	PARTICIPANT	\N	PRESENT	0
628966	628823	20024T	PARTICIPANT	\N	PRESENT	0
628968	628823	20084G	PARTICIPANT	\N	PRESENT	0
628969	628823	20090E	PARTICIPANT	\N	PRESENT	0
628970	628823	19631V	PARTICIPANT	\N	PRESENT	0
628971	628823	19251M	PARTICIPANT	\N	PRESENT	0
628972	628823	14231L	PARTICIPANT	\N	PRESENT	0
628973	628823	05012A	PARTICIPANT	\N	PRESENT	0
628974	628823	19333N	PARTICIPANT	\N	PRESENT	0
628975	628823	20092G	PARTICIPANT	\N	PRESENT	0
628976	628823	20110Q	PARTICIPANT	\N	PRESENT	0
628977	628823	17637T	PARTICIPANT	\N	PRESENT	0
628978	628823	19735D	PARTICIPANT	\N	PRESENT	0
628979	628823	19619A	PARTICIPANT	\N	PRESENT	0
628980	628823	19782L	PARTICIPANT	\N	PRESENT	0
628981	628823	20286Q	PARTICIPANT	\N	PRESENT	0
628982	628823	14205J	PARTICIPANT	\N	PRESENT	0
628983	628823	19820Y	PARTICIPANT	\N	PRESENT	0
628984	628823	14107H	PARTICIPANT	\N	PRESENT	0
628986	628823	20078J	PARTICIPANT	\N	PRESENT	0
628987	628823	20062A	PARTICIPANT	\N	PRESENT	0
628988	628823	20022R	PARTICIPANT	\N	PRESENT	0
628989	628823	19349W	PARTICIPANT	\N	PRESENT	0
628990	628823	14229S	PARTICIPANT	\N	PRESENT	0
628996	628823	20048C	PARTICIPANT	\N	EXCUSE	0
628997	628823	08015R	PARTICIPANT	\N	EXCUSE	0
628998	628823	14031R	PARTICIPANT	\N	EXCUSE	0
629000	628823	19866P	PARTICIPANT	\N	EXCUSE	0
629006	628824	01057W	PARTICIPANT	\N	PRESENT	0
629007	628823	01057W	PARTICIPANT	\N	PRESENT	0
631464	629385	04059M	PARTICIPANT	\N	PRESENT	0
631465	629385	19669L	PARTICIPANT	\N	PRESENT	0
631466	629385	20142Y	PARTICIPANT	\N	PRESENT	0
631467	629385	19611R	PRESIDENT	0	PRESENT	0
631468	629385	19699S	PARTICIPANT	\N	PRESENT	0
631469	629385	19705W	PARTICIPANT	\N	PRESENT	0
631470	629385	20056C	PARTICIPANT	\N	PRESENT	0
631471	629385	19651A	PARTICIPANT	\N	PRESENT	0
631472	629385	19725B	PARTICIPANT	\N	PRESENT	0
631473	629385	14229S	PARTICIPANT	\N	PRESENT	0
631541	629385	19399H	PARTICIPANT	\N	EXCUSE	0
631579	629386	04059M	PARTICIPANT	\N	PRESENT	0
631580	629386	11080N	PARTICIPANT	\N	PRESENT	0
631581	629386	20132W	PARTICIPANT	\N	PRESENT	0
631582	629386	20056C	PARTICIPANT	\N	PRESENT	1
631583	629386	19611R	PRESIDENT	0	PRESENT	0
631584	629386	19699S	PARTICIPANT	\N	PRESENT	0
631585	629386	12041X	PARTICIPANT	\N	PRESENT	0
631586	629386	20142Y	PARTICIPANT	\N	PRESENT	0
631619	629386	19651A	PARTICIPANT	\N	PRESENT	1
631588	629386	19705W	PARTICIPANT	\N	PRESENT	1
631589	629386	19725B	PARTICIPANT	\N	PRESENT	0
631590	629386	14229S	PARTICIPANT	\N	PRESENT	0
631591	629386	20026V	PARTICIPANT	\N	PRESENT	1
632646	632645	20110Q	PARTICIPANT	\N	PRESENT	0
632647	632645	14255U	PARTICIPANT	\N	PRESENT	0
632648	632645	04035D	PARTICIPANT	\N	PRESENT	0
632649	632645	11083R	PARTICIPANT	\N	PRESENT	0
632650	632645	20056C	PARTICIPANT	\N	PRESENT	0
632651	632645	14073Q	PARTICIPANT	\N	PRESENT	0
632652	632645	95063L	PARTICIPANT	\N	PRESENT	0
632653	632645	11041F	PARTICIPANT	\N	PRESENT	0
632654	632645	19683J	PARTICIPANT	\N	PRESENT	0
635302	634459	20080C	PARTICIPANT	\N	PRESENT	1
635303	634459	14083S	PARTICIPANT	\N	PRESENT	1
635304	634459	14327T	PARTICIPANT	\N	PRESENT	1
635305	634459	19531S	PARTICIPANT	\N	PRESENT	1
635306	634459	20126Y	PARTICIPANT	\N	PRESENT	1
635307	634459	14073Q	PARTICIPANT	\N	PRESENT	1
635308	634459	14169X	PARTICIPANT	\N	PRESENT	1
636677	634366	19798U	PARTICIPANT	\N	PRESENT	1
636707	634738	04059M	PARTICIPANT	\N	PRESENT	0
636708	634738	19651A	PARTICIPANT	\N	PRESENT	1
639729	639728	19741B	PARTICIPANT	\N	PRESENT	0
639735	639731	11090Q	PARTICIPANT	\N	PRESENT	0
636711	634738	19621T	PARTICIPANT	\N	PRESENT	0
636712	634738	11053K	PARTICIPANT	\N	PRESENT	0
639736	639731	14257W	PARTICIPANT	\N	PRESENT	0
636714	634738	19673G	PARTICIPANT	\N	EXCUSE	0
639737	639731	20286Q	PARTICIPANT	\N	PRESENT	0
636716	634738	19725B	PARTICIPANT	\N	PRESENT	0
636717	634738	19399H	PARTICIPANT	\N	PRESENT	0
636718	634738	20056C	PARTICIPANT	\N	PRESENT	0
636719	634738	19611R	PRESIDENT	0	PRESENT	0
636720	634738	19699S	PARTICIPANT	\N	PRESENT	0
639738	639732	11090Q	PARTICIPANT	\N	PRESENT	0
636722	634738	20142Y	PARTICIPANT	\N	PRESENT	0
636723	634738	19705W	PARTICIPANT	\N	PRESENT	0
639739	639732	14257W	PARTICIPANT	\N	PRESENT	0
639740	639732	20286Q	PARTICIPANT	\N	PRESENT	0
636726	634738	20026V	PARTICIPANT	\N	PRESENT	1
639741	639732	20092G	PARTICIPANT	\N	PRESENT	0
639742	639733	11090Q	PARTICIPANT	\N	PRESENT	0
639743	639733	14257W	PARTICIPANT	\N	PRESENT	0
643210	643209	20098N	PARTICIPANT	\N	PRESENT	0
639745	639733	20092G	PARTICIPANT	\N	PRESENT	0
639746	639734	11090Q	PARTICIPANT	\N	PRESENT	0
643212	643209	14237S	PARTICIPANT	\N	PRESENT	0
639748	639734	20092G	PARTICIPANT	\N	PRESENT	0
643211	643209	04070G	PARTICIPANT	\N	PRESENT	0
648772	647669	11053K	PARTICIPANT	\N	PRESENT	1
648773	647669	01057W	PARTICIPANT	\N	PRESENT	1
648774	647669	14121F	PARTICIPANT	\N	PRESENT	1
648775	647669	19531S	PARTICIPANT	\N	PRESENT	1
648776	647669	08010L	PARTICIPANT	\N	PRESENT	1
648777	647669	12016W	PARTICIPANT	\N	PRESENT	1
648778	647669	20036X	PARTICIPANT	\N	PRESENT	1
648812	648811	20070A	PARTICIPANT	\N	PRESENT	0
648813	648811	11110B	PARTICIPANT	\N	PRESENT	0
648815	648814	11048N	PARTICIPANT	\N	PRESENT	0
649323	649322	19693L	PARTICIPANT	\N	EXCUSE	0
649324	649322	20072C	PARTICIPANT	\N	EXCUSE	0
649325	649322	20066E	PARTICIPANT	\N	EXCUSE	0
649326	649322	19683J	PARTICIPANT	\N	EXCUSE	0
649327	649322	19735D	PARTICIPANT	\N	EXCUSE	0
649328	649322	11067R	PARTICIPANT	\N	EXCUSE	0
649329	649322	19533U	PARTICIPANT	\N	EXCUSE	0
649330	649322	01058X	PARTICIPANT	\N	EXCUSE	0
649331	649322	20128B	PARTICIPANT	\N	PRESENT	0
649332	649322	19569H	PARTICIPANT	\N	EXCUSE	0
649333	649322	19723Y	PARTICIPANT	\N	PRESENT	0
649334	649322	01048V	PARTICIPANT	\N	PRESENT	0
649335	649322	14221J	PARTICIPANT	\N	PRESENT	0
649336	649322	19593H	PARTICIPANT	\N	PRESENT	0
649337	649322	19503N	PARTICIPANT	\N	PRESENT	0
649338	649322	04043D	PARTICIPANT	\N	PRESENT	0
649339	648779	19954N	PARTICIPANT	\N	PRESENT	1
649340	648779	19629C	PARTICIPANT	\N	PRESENT	1
649341	648779	14215L	PARTICIPANT	\N	PRESENT	1
649342	648779	20128B	PARTICIPANT	\N	PRESENT	1
649343	648779	19489J	PARTICIPANT	\N	PRESENT	1
649344	648779	14147R	PARTICIPANT	\N	PRESENT	1
649345	648779	14107H	PARTICIPANT	\N	PRESENT	1
649346	648779	10015M	PARTICIPANT	\N	PRESENT	1
649347	648779	95063L	PARTICIPANT	\N	PRESENT	1
649349	649348	14033T	PARTICIPANT	\N	PRESENT	1
651134	649164	19525U	PARTICIPANT	\N	PRESENT	0
651135	649164	14195A	PARTICIPANT	\N	PRESENT	0
651136	649164	11031D	PARTICIPANT	\N	PRESENT	0
651137	649164	20046A	PARTICIPANT	\N	PRESENT	0
651138	649164	11033F	PARTICIPANT	\N	PRESENT	0
651139	649164	12016W	PARTICIPANT	\N	PRESENT	0
651140	649164	20042V	PARTICIPANT	\N	PRESENT	0
651141	649164	19683J	PARTICIPANT	\N	PRESENT	0
651142	649164	14026U	PARTICIPANT	\N	PRESENT	0
651143	649164	20266L	PARTICIPANT	\N	PRESENT	0
651144	649164	20264J	PARTICIPANT	\N	PRESENT	0
651145	649164	04092N	PARTICIPANT	\N	PRESENT	0
651146	649164	04033B	PARTICIPANT	\N	PRESENT	0
651147	649164	14071N	PARTICIPANT	\N	PRESENT	0
651148	649164	14053L	PARTICIPANT	\N	PRESENT	0
651149	649164	04047H	PARTICIPANT	\N	PRESENT	0
651150	649164	08056B	PARTICIPANT	\N	PRESENT	0
651151	649164	05008E	PARTICIPANT	\N	PRESENT	0
651152	649164	08069G	PARTICIPANT	\N	PRESENT	0
651153	649164	19715Y	PARTICIPANT	\N	PRESENT	0
651154	649164	14169X	PARTICIPANT	\N	PRESENT	0
651155	649164	19367Y	PARTICIPANT	\N	PRESENT	0
651156	649164	19766L	PARTICIPANT	\N	PRESENT	0
651157	649164	20096L	PARTICIPANT	\N	PRESENT	0
651158	649164	19768N	PARTICIPANT	\N	PRESENT	0
651159	649164	19553Y	PARTICIPANT	\N	PRESENT	0
651160	649164	14179A	PARTICIPANT	\N	PRESENT	0
651161	649164	14089Y	PARTICIPANT	\N	PRESENT	0
651162	649164	20052X	PARTICIPANT	\N	PRESENT	0
651163	649164	14147R	PARTICIPANT	\N	PRESENT	0
651164	649164	20140W	PARTICIPANT	\N	PRESENT	0
651165	649164	19749K	PARTICIPANT	\N	PRESENT	0
651166	649164	20180F	PARTICIPANT	\N	PRESENT	0
651167	649164	11067R	PARTICIPANT	\N	PRESENT	0
651168	649164	20038A	PARTICIPANT	\N	PRESENT	0
651177	649164	20248J	PARTICIPANT	\N	PRESENT	0
651170	649164	01028R	PARTICIPANT	\N	PRESENT	0
651171	649164	14021P	PARTICIPANT	\N	PRESENT	0
651172	649164	20100N	PARTICIPANT	\N	PRESENT	0
651173	649164	20062A	PARTICIPANT	\N	PRESENT	0
651174	649164	19503N	PARTICIPANT	\N	PRESENT	0
651175	649164	11077T	PARTICIPANT	\N	PRESENT	0
651176	649164	95041E	PARTICIPANT	\N	PRESENT	0
651178	649164	04085P	PARTICIPANT	\N	PRESENT	0
651179	649164	14215L	PARTICIPANT	\N	PRESENT	0
651180	649164	14033T	PARTICIPANT	\N	PRESENT	0
651181	649164	19447X	PARTICIPANT	\N	PRESENT	0
651182	649164	20034V	PARTICIPANT	\N	PRESENT	0
651183	649164	20044X	PARTICIPANT	\N	PRESENT	0
651184	649164	14038Y	PARTICIPANT	\N	PRESENT	0
651185	649164	19467C	PARTICIPANT	\N	PRESENT	0
651186	649164	20090E	PARTICIPANT	\N	PRESENT	0
651187	649164	19649G	PARTICIPANT	\N	PRESENT	0
651188	649164	08073C	PARTICIPANT	\N	PRESENT	0
651189	649164	20026V	PARTICIPANT	\N	PRESENT	0
651190	649164	95063L	PARTICIPANT	\N	PRESENT	0
651191	649164	11072N	PARTICIPANT	\N	PRESENT	0
651192	649164	14255U	PARTICIPANT	\N	PRESENT	0
651193	649164	19301E	PARTICIPANT	\N	PRESENT	0
651194	649164	19697Q	PARTICIPANT	\N	PRESENT	0
651195	649164	11027H	PARTICIPANT	\N	PRESENT	0
651196	649164	11026G	PARTICIPANT	\N	PRESENT	0
651197	649164	20110Q	PARTICIPANT	\N	PRESENT	0
651198	649164	14042U	PARTICIPANT	\N	PRESENT	0
651199	649164	20298U	PARTICIPANT	\N	PRESENT	0
651200	649164	19533U	PARTICIPANT	\N	PRESENT	0
651201	649164	14329V	PARTICIPANT	\N	PRESENT	0
651202	649164	07029T	PARTICIPANT	\N	PRESENT	0
651203	649164	20130U	PARTICIPANT	\N	PRESENT	0
651204	649164	19717B	PARTICIPANT	\N	PRESENT	0
651205	649164	11045K	PARTICIPANT	\N	PRESENT	0
651206	649164	14231L	PARTICIPANT	\N	PRESENT	0
651207	649164	14097Y	PARTICIPANT	\N	PRESENT	0
651208	649164	14055N	PARTICIPANT	\N	PRESENT	0
651209	649164	19577H	PARTICIPANT	\N	PRESENT	0
651210	649164	20104S	PARTICIPANT	\N	PRESENT	0
651211	649164	19657G	PARTICIPANT	\N	PRESENT	0
651212	649164	19695N	PARTICIPANT	\N	PRESENT	0
651213	649164	19443T	PARTICIPANT	\N	PRESENT	0
651214	649164	20118Y	PARTICIPANT	\N	PRESENT	0
651215	649164	01024M	PARTICIPANT	\N	PRESENT	0
651216	649164	19762G	PARTICIPANT	\N	PRESENT	0
651217	649164	14193X	PARTICIPANT	\N	PRESENT	0
651218	649164	18083K	PARTICIPANT	\N	PRESENT	0
651219	649164	14187A	PARTICIPANT	\N	PRESENT	0
651220	649164	20058E	PARTICIPANT	\N	PRESENT	0
651221	649164	14331P	PARTICIPANT	\N	PRESENT	0
651222	649164	14357A	PARTICIPANT	\N	PRESENT	0
651223	649164	14217N	PARTICIPANT	\N	PRESENT	0
651224	649164	20024T	PARTICIPANT	\N	PRESENT	0
651225	649164	20066E	PARTICIPANT	\N	PRESENT	0
651226	649164	10006L	PARTICIPANT	\N	PRESENT	0
651227	649164	19347U	PARTICIPANT	\N	PRESENT	0
651228	649164	14083S	PARTICIPANT	\N	PRESENT	0
651229	649164	20252E	PARTICIPANT	\N	PRESENT	0
651230	649164	19563B	PARTICIPANT	\N	PRESENT	0
651231	649164	20126Y	PARTICIPANT	\N	PRESENT	0
651232	649164	20082E	PARTICIPANT	\N	PRESENT	0
651233	649164	11048N	PARTICIPANT	\N	PRESENT	0
651234	649164	14001X	PARTICIPANT	\N	PRESENT	0
651235	649164	19741B	PARTICIPANT	\N	PRESENT	0
651236	649164	11012A	PARTICIPANT	\N	PRESENT	0
651237	649164	20132W	PARTICIPANT	\N	PRESENT	0
651238	649164	14151M	PARTICIPANT	\N	PRESENT	0
651239	649164	20094J	PARTICIPANT	\N	PRESENT	0
651240	649164	20092G	PARTICIPANT	\N	PRESENT	0
651241	647962	18083K	PARTICIPANT	\N	PRESENT	1
651242	647962	19347U	PARTICIPANT	\N	PRESENT	1
651243	647962	20034V	PARTICIPANT	\N	PRESENT	0
651244	647962	14097Y	PARTICIPANT	\N	PRESENT	0
651245	647962	14059S	PARTICIPANT	\N	EXCUSE	0
651246	647962	19657G	PARTICIPANT	\N	PRESENT	0
651247	647962	14147R	PARTICIPANT	\N	PRESENT	1
651248	647962	20150Y	PARTICIPANT	\N	PRESENT	1
651249	647962	14275Y	PARTICIPANT	\N	PRESENT	0
651266	650242	14231L	PRESIDENT	0	PRESENT	0
651267	650242	08010L	PARTICIPANT	\N	PRESENT	0
651268	650242	14215L	PARTICIPANT	\N	PRESENT	0
651269	650242	14187A	PARTICIPANT	\N	PRESENT	0
651270	650242	20062A	PARTICIPANT	\N	PRESENT	0
651271	650242	14053L	PARTICIPANT	\N	PRESENT	0
651272	650242	05012A	PARTICIPANT	\N	PRESENT	0
651273	650242	20090E	PARTICIPANT	\N	PRESENT	0
651274	650242	14229S	PARTICIPANT	\N	PRESENT	0
651275	650242	19565D	PARTICIPANT	\N	PRESENT	0
627382	627379	11064N	PARTICIPANT	\N	PRESENT	1
627383	627379	20034V	PARTICIPANT	\N	PRESENT	1
627384	627379	19333N	PARTICIPANT	\N	PRESENT	0
627385	627379	14059S	PARTICIPANT	\N	PRESENT	0
627386	627379	20150Y	PARTICIPANT	\N	PRESENT	0
627411	627379	19447X	PARTICIPANT	\N	PRESENT	1
629209	629208	12041X	PARTICIPANT	\N	PRESENT	0
630138	629022	04043D	PARTICIPANT	\N	PRESENT	1
630140	629022	04057K	PARTICIPANT	\N	PRESENT	0
630180	629022	08045X	PARTICIPANT	\N	PRESENT	1
630181	629022	14213J	PARTICIPANT	\N	PRESENT	1
630182	629022	14195A	PARTICIPANT	\N	PRESENT	0
630189	629022	11103C	PARTICIPANT	\N	PRESENT	1
630190	629022	19715Y	PARTICIPANT	\N	PRESENT	1
630267	629022	20248J	PARTICIPANT	\N	PRESENT	1
630268	629022	19591F	PARTICIPANT	\N	PRESENT	1
630269	629022	19697Q	PARTICIPANT	\N	PRESENT	1
630342	629022	20040T	PARTICIPANT	\N	EXCUSE	0
630350	629022	19679N	PARTICIPANT	\N	PRESENT	0
630351	629022	19367Y	PARTICIPANT	\N	PRESENT	0
630352	629022	14223L	PARTICIPANT	\N	PRESENT	1
631626	631625	14151M	PARTICIPANT	\N	PRESENT	0
631627	631625	20052X	PARTICIPANT	\N	PRESENT	0
631628	631625	08010L	PARTICIPANT	\N	PRESENT	0
631629	631625	11026G	PARTICIPANT	\N	PRESENT	0
631630	631625	19479G	PARTICIPANT	\N	PRESENT	0
631631	631625	19489J	PARTICIPANT	\N	PRESENT	0
631632	631625	04043D	PARTICIPANT	\N	PRESENT	0
631633	631625	19766L	PARTICIPANT	\N	PRESENT	0
631634	631625	19467C	PARTICIPANT	\N	PRESENT	0
631635	631625	19693L	PARTICIPANT	\N	PRESENT	0
631636	631625	19647E	PARTICIPANT	\N	PRESENT	0
631637	631625	04035D	PARTICIPANT	\N	PRESENT	0
631638	631625	20120S	PARTICIPANT	\N	PRESENT	0
631639	631625	20056C	PARTICIPANT	\N	PRESENT	0
631640	631625	19687N	PARTICIPANT	\N	PRESENT	0
631669	631668	20020P	PARTICIPANT	\N	PRESENT	0
631671	631670	20020P	PARTICIPANT	\N	PRESENT	0
631673	631672	20020P	PARTICIPANT	\N	PRESENT	0
631686	631683	14097Y	PARTICIPANT	\N	PRESENT	0
631687	631683	20050V	PARTICIPANT	\N	PRESENT	0
631688	631683	20082E	PARTICIPANT	\N	PRESENT	0
632476	631506	14030Q	PARTICIPANT	\N	PRESENT	0
632478	631506	20132W	PARTICIPANT	\N	PRESENT	0
632485	631506	19693L	PARTICIPANT	\N	PRESENT	0
632486	631506	20024T	PARTICIPANT	\N	PRESENT	0
632487	631506	08061X	PARTICIPANT	\N	PRESENT	0
632488	631506	19782L	PARTICIPANT	\N	PRESENT	0
632489	631506	19549D	PARTICIPANT	\N	PRESENT	0
632490	631506	01060R	PARTICIPANT	\N	PRESENT	0
632491	631506	19679N	PARTICIPANT	\N	PRESENT	0
632492	631506	11083R	PARTICIPANT	\N	PRESENT	0
632493	631506	14033T	PARTICIPANT	\N	PRESENT	0
632495	631506	20134Y	PARTICIPANT	\N	PRESENT	0
632496	631506	20018V	PARTICIPANT	\N	PRESENT	0
632497	631506	20120S	PARTICIPANT	\N	PRESENT	0
632498	631506	19820Y	PARTICIPANT	\N	PRESENT	0
632499	631506	18083K	PARTICIPANT	\N	PRESENT	0
632550	631507	18083K	PARTICIPANT	\N	PRESENT	0
632551	631507	14033T	PARTICIPANT	\N	PRESENT	0
632552	631507	19573D	PARTICIPANT	\N	PRESENT	0
632553	631507	20132W	PARTICIPANT	\N	PRESENT	0
632554	631507	19553Y	PARTICIPANT	\N	PRESENT	0
632555	631507	04045F	PARTICIPANT	\N	PRESENT	0
632556	631507	11083R	PARTICIPANT	\N	PRESENT	0
632557	631507	11033F	PARTICIPANT	\N	PRESENT	0
632558	631507	20266L	PARTICIPANT	\N	PRESENT	0
632559	631507	20134Y	PARTICIPANT	\N	PRESENT	0
632560	631507	20100N	PARTICIPANT	\N	PRESENT	0
632562	631507	19679N	PARTICIPANT	\N	PRESENT	0
632564	631507	11043H	PARTICIPANT	\N	PRESENT	0
632567	631507	20114U	PARTICIPANT	\N	PRESENT	0
632569	631507	18193Q	PARTICIPANT	\N	PRESENT	0
632571	631507	19820Y	PARTICIPANT	\N	PRESENT	0
632572	631507	19549D	PARTICIPANT	\N	PRESENT	0
632573	631507	20018V	PARTICIPANT	\N	PRESENT	0
632574	631507	20084G	PARTICIPANT	\N	PRESENT	0
632575	631507	19749K	PARTICIPANT	\N	PRESENT	0
632576	631507	07004J	PARTICIPANT	\N	PRESENT	0
632577	631507	14215L	PARTICIPANT	\N	PRESENT	0
632578	631507	19747H	PARTICIPANT	\N	PRESENT	0
632579	631507	20032T	PARTICIPANT	\N	PRESENT	0
632580	631507	20124W	PARTICIPANT	\N	PRESENT	0
632581	631507	20090E	PARTICIPANT	\N	PRESENT	0
632582	631507	11064N	PARTICIPANT	\N	PRESENT	0
632583	631507	14231L	PARTICIPANT	\N	PRESENT	0
632584	631507	14147R	PARTICIPANT	\N	PRESENT	0
632585	631507	19415P	PARTICIPANT	\N	PRESENT	0
632586	631507	20180F	PARTICIPANT	\N	PRESENT	0
632587	631507	14217N	PARTICIPANT	\N	PRESENT	0
632588	631507	20152B	PARTICIPANT	\N	PRESENT	0
632589	631507	19701S	PARTICIPANT	\N	PRESENT	0
632590	631507	14030Q	PARTICIPANT	\N	PRESENT	0
632591	631507	19693L	PARTICIPANT	\N	PRESENT	0
632592	631507	20054A	PARTICIPANT	\N	PRESENT	0
632593	631507	07029T	PARTICIPANT	\N	PRESENT	0
632594	631507	19593H	PARTICIPANT	\N	PRESENT	0
632595	631507	19758L	PARTICIPANT	\N	PRESENT	0
632596	631507	14211G	PARTICIPANT	\N	PRESENT	0
632597	631507	20024T	PARTICIPANT	\N	PRESENT	0
632598	631507	20052X	PARTICIPANT	\N	PRESENT	0
632600	632599	86034E	PARTICIPANT	\N	PRESENT	0
632601	632599	04085P	PARTICIPANT	\N	PRESENT	0
632602	632599	04047H	PARTICIPANT	\N	PRESENT	0
632603	632599	11053K	PARTICIPANT	\N	PRESENT	0
632604	632599	11070L	PARTICIPANT	\N	PRESENT	0
632548	631507	14026U	PARTICIPANT	\N	PRESENT	0
632549	631507	20034V	PARTICIPANT	\N	PRESENT	0
632605	632599	14217N	PARTICIPANT	\N	PRESENT	0
632606	632599	14042U	PARTICIPANT	\N	PRESENT	0
632607	632599	14026U	PARTICIPANT	\N	PRESENT	0
632608	632599	14021P	PARTICIPANT	\N	PRESENT	0
632609	632599	19611R	PARTICIPANT	\N	PRESENT	0
632610	632599	08015R	PARTICIPANT	\N	PRESENT	0
632611	632599	12041X	PARTICIPANT	\N	PRESENT	0
632612	632599	01043Q	PARTICIPANT	\N	PRESENT	0
632613	632599	14219Q	PARTICIPANT	\N	PRESENT	0
632614	632599	14251Q	PARTICIPANT	\N	PRESENT	0
632615	632599	11085T	PARTICIPANT	\N	PRESENT	0
632616	632599	01060R	PARTICIPANT	\N	PRESENT	0
632617	632599	11072N	PARTICIPANT	\N	PRESENT	0
632618	632599	14193X	PARTICIPANT	\N	PRESENT	0
632619	632599	14331P	PARTICIPANT	\N	PRESENT	0
632620	632599	14225N	PARTICIPANT	\N	PRESENT	0
632621	632599	11012A	PARTICIPANT	\N	PRESENT	0
632622	632599	04033B	PARTICIPANT	\N	PRESENT	0
632623	632599	20266L	PARTICIPANT	\N	PRESENT	0
632624	631507	19507S	PARTICIPANT	\N	PRESENT	0
632625	631507	19671E	PARTICIPANT	\N	PRESENT	0
632626	631507	14021P	PARTICIPANT	\N	PRESENT	0
632718	632717	14189C	PARTICIPANT	\N	PRESENT	0
632719	632717	19741B	PARTICIPANT	\N	PRESENT	0
632720	632717	11040E	PARTICIPANT	\N	PRESENT	0
632722	632717	20070A	PARTICIPANT	\N	PRESENT	0
632723	632717	01057W	PARTICIPANT	\N	PRESENT	0
632724	632717	11048N	PARTICIPANT	\N	PRESENT	0
632725	632717	19711U	PARTICIPANT	\N	PRESENT	0
632726	632717	12016W	PARTICIPANT	\N	PRESENT	1
632727	632717	20252E	PARTICIPANT	\N	PRESENT	0
632728	632717	14225N	PARTICIPANT	\N	PRESENT	0
632729	632717	19762G	PARTICIPANT	\N	PRESENT	0
632730	632717	19689Q	PARTICIPANT	\N	PRESENT	0
632731	632717	19479G	PARTICIPANT	\N	PRESENT	0
632767	631111	14042U	PARTICIPANT	\N	PRESENT	0
632801	631111	20040T	PARTICIPANT	\N	PRESENT	0
632806	631111	01034P	PARTICIPANT	\N	PRESENT	0
632807	631111	19569H	PARTICIPANT	\N	PRESENT	0
632821	631111	20130U	PARTICIPANT	\N	PRESENT	1
632836	631213	11110B	PARTICIPANT	\N	PRESENT	1
632837	631213	14121F	PARTICIPANT	\N	PRESENT	1
632838	631213	19531S	PARTICIPANT	\N	PRESENT	1
632839	631213	20126Y	PARTICIPANT	\N	PRESENT	1
633542	633541	20264J	PARTICIPANT	\N	PRESENT	0
633543	633541	14069U	PARTICIPANT	\N	PRESENT	0
633551	633541	04070G	PARTICIPANT	\N	PRESENT	1
633552	633541	20064C	PARTICIPANT	\N	PRESENT	1
633553	633541	14083S	PARTICIPANT	\N	PRESENT	0
633568	631654	19533U	PRESIDENT	0	PRESENT	0
633569	631654	14207L	PARTICIPANT	\N	PRESENT	0
633570	631654	19798U	PARTICIPANT	\N	PRESENT	1
633656	633654	14069U	PARTICIPANT	\N	PRESENT	0
645868	645312	20024T	PARTICIPANT	\N	PRESENT	0
645869	645760	19441R	PARTICIPANT	\N	PRESENT	0
645870	645760	14205J	PARTICIPANT	\N	PRESENT	1
645871	645760	19467C	PARTICIPANT	\N	PRESENT	1
645872	645312	20088L	PARTICIPANT	\N	PRESENT	0
645873	645312	20092G	PARTICIPANT	\N	PRESENT	0
645874	645312	20074E	PARTICIPANT	\N	PRESENT	0
645875	645312	20038A	PARTICIPANT	\N	PRESENT	0
645876	645312	19387D	PARTICIPANT	\N	PRESENT	0
645877	645312	19413M	PARTICIPANT	\N	PRESENT	0
645878	645312	19637C	PARTICIPANT	\N	PRESENT	0
645879	645312	19503N	PARTICIPANT	\N	PRESENT	0
645880	645312	20018V	PARTICIPANT	\N	PRESENT	0
645918	645917	20128B	PARTICIPANT	\N	PRESENT	0
645920	645919	20128B	PARTICIPANT	\N	PRESENT	0
645922	645921	20128B	PARTICIPANT	\N	PRESENT	0
645924	645923	20128B	PARTICIPANT	\N	PRESENT	0
645957	645312	19533U	PARTICIPANT	\N	PRESENT	1
645958	645312	04045F	PARTICIPANT	\N	PRESENT	0
645959	645312	14147R	PARTICIPANT	\N	PRESENT	1
645961	645760	20050V	PARTICIPANT	\N	PRESENT	0
645962	645760	14251Q	PARTICIPANT	\N	PRESENT	0
645963	645760	20082E	PARTICIPANT	\N	PRESENT	0
645971	645336	19593H	PARTICIPANT	\N	PRESENT	0
645972	645336	19766L	PARTICIPANT	\N	PRESENT	0
645973	645336	19527W	PARTICIPANT	\N	PRESENT	0
645974	645336	04070G	PARTICIPANT	\N	PRESENT	0
645975	645336	20132W	PARTICIPANT	\N	PRESENT	0
645976	645336	19643A	PARTICIPANT	\N	PRESENT	0
645977	645336	19699S	PARTICIPANT	\N	PRESENT	0
645978	645336	19651A	PARTICIPANT	\N	PRESENT	0
645979	645336	19611R	PRESIDENT	0	PRESENT	0
645980	645336	20138D	PARTICIPANT	\N	PRESENT	0
645981	645336	20142Y	PARTICIPANT	\N	PRESENT	0
645982	645336	19693L	PARTICIPANT	\N	PRESENT	0
645983	645336	19399H	PARTICIPANT	\N	PRESENT	0
645984	645336	20152B	PARTICIPANT	\N	PRESENT	0
645985	645336	14229S	PARTICIPANT	\N	PRESENT	0
645986	645336	20180F	PARTICIPANT	\N	PRESENT	0
645987	645336	19573D	PARTICIPANT	\N	PRESENT	0
645988	645336	04059M	PARTICIPANT	\N	PRESENT	0
645989	645336	19735D	PARTICIPANT	\N	PRESENT	0
645990	645336	19057M	PARTICIPANT	\N	PRESENT	0
645991	645336	19758L	PARTICIPANT	\N	PRESENT	0
646029	645580	19701S	PARTICIPANT	\N	PRESENT	1
646030	645580	19553Y	PARTICIPANT	\N	PRESENT	1
646031	645580	04057K	PARTICIPANT	\N	PRESENT	1
646032	645580	20286Q	PARTICIPANT	\N	PRESENT	1
646033	645580	14237S	PARTICIPANT	\N	PRESENT	1
646034	645580	14169X	PARTICIPANT	\N	PRESENT	1
646035	645580	04045F	PARTICIPANT	\N	PRESENT	0
646036	645580	10015M	PARTICIPANT	\N	PRESENT	0
646037	645580	20104S	PARTICIPANT	\N	PRESENT	0
646038	645580	19333N	PARTICIPANT	\N	PRESENT	0
646039	645580	14001X	PARTICIPANT	\N	PRESENT	0
646040	645580	19563B	PARTICIPANT	\N	PRESENT	0
646041	645580	19531S	PARTICIPANT	\N	PRESENT	0
646042	645580	14089Y	PARTICIPANT	\N	PRESENT	0
646043	645580	14033T	PARTICIPANT	\N	PRESENT	0
646044	645580	11083R	PARTICIPANT	\N	PRESENT	0
646045	645580	20100N	PARTICIPANT	\N	PRESENT	0
646046	645580	04070G	PARTICIPANT	\N	PRESENT	0
646047	645580	14189C	PARTICIPANT	\N	PRESENT	0
646048	645580	19441R	PARTICIPANT	\N	PRESENT	0
646049	645580	19711U	PARTICIPANT	\N	PRESENT	0
646050	645580	19671E	PARTICIPANT	\N	PRESENT	1
646051	645580	14147R	PARTICIPANT	\N	PRESENT	1
646052	645580	19387D	PARTICIPANT	\N	PRESENT	1
646053	645580	20140W	PARTICIPANT	\N	PRESENT	1
646054	645580	20022R	PARTICIPANT	\N	PRESENT	1
646055	645580	20180F	PARTICIPANT	\N	PRESENT	1
646056	645580	20018V	PARTICIPANT	\N	PRESENT	0
646057	645580	14255U	PARTICIPANT	\N	PRESENT	0
646058	645580	14257W	PARTICIPANT	\N	PRESENT	0
646059	645580	14331P	PRESIDENT	0	PRESENT	0
646060	645742	14042U	PARTICIPANT	\N	PRESENT	0
646061	645743	14042U	PARTICIPANT	\N	PRESENT	0
646062	645743	20130U	PARTICIPANT	\N	PRESENT	0
646063	645744	14042U	PARTICIPANT	\N	PRESENT	0
646064	645744	20130U	PARTICIPANT	\N	PRESENT	0
646065	645745	14042U	PARTICIPANT	\N	PRESENT	0
646066	645745	20130U	PARTICIPANT	\N	PRESENT	0
646067	645745	18193Q	PARTICIPANT	\N	PRESENT	0
646069	646068	10015M	PARTICIPANT	\N	PRESENT	0
646070	646068	14147R	PARTICIPANT	\N	PRESENT	0
646071	646068	20128B	PARTICIPANT	\N	PRESENT	0
646072	646068	14179A	PARTICIPANT	\N	PRESENT	0
646081	646080	10015M	PARTICIPANT	\N	PRESENT	0
646082	646080	14147R	PARTICIPANT	\N	PRESENT	0
646083	646080	14151M	PARTICIPANT	\N	PRESENT	0
646084	646080	20128B	PARTICIPANT	\N	PRESENT	0
646085	646080	95063L	PARTICIPANT	\N	PRESENT	0
646087	646086	10015M	PARTICIPANT	\N	PRESENT	0
646088	646086	14147R	PARTICIPANT	\N	PRESENT	0
646089	646086	14151M	PARTICIPANT	\N	PRESENT	0
646091	646090	10015M	PARTICIPANT	\N	PRESENT	0
646092	646090	14147R	PARTICIPANT	\N	PRESENT	0
646093	646090	95063L	PARTICIPANT	\N	PRESENT	0
646094	646090	14151M	PARTICIPANT	\N	PRESENT	0
646096	646095	10015M	PARTICIPANT	\N	PRESENT	0
646097	646095	95063L	PARTICIPANT	\N	PRESENT	0
646098	646095	14147R	PARTICIPANT	\N	PRESENT	0
646099	646095	20128B	PARTICIPANT	\N	PRESENT	0
646100	646095	14179A	PARTICIPANT	\N	PRESENT	0
646101	646068	14151M	PARTICIPANT	\N	PRESENT	0
646145	646144	20092G	PARTICIPANT	\N	PRESENT	0
646146	646144	20032T	PARTICIPANT	\N	PRESENT	0
646147	646144	20082E	PARTICIPANT	\N	PRESENT	0
646148	646144	20128B	PARTICIPANT	\N	PRESENT	0
646149	646144	14205J	PARTICIPANT	\N	PRESENT	0
646150	646144	17023S	PARTICIPANT	\N	PRESENT	0
646151	646144	16685X	PARTICIPANT	\N	PRESENT	0
646173	643944	05008E	PARTICIPANT	\N	EXCUSE	0
646174	643944	19717B	PRESIDENT	0	PRESENT	0
646176	646175	08010L	PARTICIPANT	\N	PRESENT	0
646179	646178	19643A	PARTICIPANT	\N	PRESENT	1
646180	646178	20132W	PARTICIPANT	\N	PRESENT	1
646181	646178	14147R	PARTICIPANT	\N	PRESENT	1
646182	646178	19447X	PARTICIPANT	\N	PRESENT	1
646189	646188	14147R	PARTICIPANT	\N	PRESENT	0
646190	646188	19725B	PARTICIPANT	\N	PRESENT	0
646192	646191	14147R	PARTICIPANT	\N	PRESENT	0
646193	646191	19725B	PARTICIPANT	\N	PRESENT	0
646194	646191	14179A	PARTICIPANT	\N	PRESENT	0
646196	646195	14147R	PARTICIPANT	\N	PRESENT	0
646197	646195	19725B	PARTICIPANT	\N	PRESENT	0
646250	646249	14255U	PARTICIPANT	\N	PRESENT	0
646254	646253	20028X	PARTICIPANT	\N	PRESENT	0
646255	646253	14038Y	PARTICIPANT	\N	PRESENT	0
646256	646253	20092G	PARTICIPANT	\N	PRESENT	0
646257	646253	14147R	PARTICIPANT	\N	PRESENT	0
646258	646253	19629C	PARTICIPANT	\N	PRESENT	0
646272	646271	07033P	PARTICIPANT	\N	PRESENT	0
646273	646271	19443T	PARTICIPANT	\N	PRESENT	0
646275	646274	07033P	PARTICIPANT	\N	PRESENT	0
646276	646274	19443T	PARTICIPANT	\N	PRESENT	0
646280	646279	19443T	PARTICIPANT	\N	PRESENT	0
646282	646281	07033P	PARTICIPANT	\N	PRESENT	0
646286	646285	07033P	PARTICIPANT	\N	PRESENT	0
646294	643944	19631V	PARTICIPANT	\N	EXCUSE	0
646295	643944	20028X	PARTICIPANT	\N	EXCUSE	0
646296	643944	18083K	PARTICIPANT	\N	PRESENT	1
646297	643944	19691J	PARTICIPANT	\N	PRESENT	0
646298	643944	19715Y	PARTICIPANT	\N	PRESENT	0
646301	643944	19319Q	PARTICIPANT	\N	PRESENT	0
646302	643944	20148F	PARTICIPANT	\N	PRESENT	0
646303	643944	19659J	PARTICIPANT	\N	PRESENT	0
646304	643942	18083K	PARTICIPANT	\N	EXCUSE	0
646305	643942	19659J	PARTICIPANT	\N	PRESENT	0
646307	643942	19691J	PARTICIPANT	\N	PRESENT	0
646308	643942	19715Y	PARTICIPANT	\N	PRESENT	0
646309	643942	14097Y	PARTICIPANT	\N	PRESENT	0
627402	626863	14357A	PARTICIPANT	\N	PRESENT	0
627403	626863	19467C	PARTICIPANT	\N	PRESENT	0
627404	626863	14267Y	PARTICIPANT	\N	PRESENT	0
627405	626863	14211G	PARTICIPANT	\N	PRESENT	0
627416	626863	04047H	PARTICIPANT	\N	PRESENT	0
627417	626863	14089Y	PARTICIPANT	\N	PRESENT	0
627461	626865	01025N	PARTICIPANT	\N	PRESENT	0
627462	626865	14219Q	PARTICIPANT	\N	PRESENT	0
627463	626865	19479G	PARTICIPANT	\N	PRESENT	0
627464	626865	14030Q	PARTICIPANT	\N	PRESENT	0
627465	626865	14089Y	PARTICIPANT	\N	PRESENT	0
627466	626865	14267Y	PARTICIPANT	\N	PRESENT	0
627467	626865	95063L	PARTICIPANT	\N	PRESENT	0
627468	626865	19651A	PARTICIPANT	\N	PRESENT	0
627469	626865	19349W	PARTICIPANT	\N	PRESENT	0
627470	626865	14121F	PARTICIPANT	\N	PRESENT	0
627471	626865	19347U	PARTICIPANT	\N	PRESENT	0
627472	626865	11065P	PARTICIPANT	\N	PRESENT	0
627473	626865	14111D	PARTICIPANT	\N	PRESENT	0
627474	626865	11074Q	PARTICIPANT	\N	PRESENT	0
627475	626865	14107H	PARTICIPANT	\N	PRESENT	0
627476	626865	19387D	PARTICIPANT	\N	PRESENT	0
627477	626865	19383Y	PARTICIPANT	\N	PRESENT	0
627478	626865	19747H	PARTICIPANT	\N	PRESENT	0
627479	626865	20090E	PARTICIPANT	\N	PRESENT	0
627480	626865	11101A	PARTICIPANT	\N	PRESENT	0
627481	626865	97011G	PARTICIPANT	\N	PRESENT	0
627482	626865	14331P	PARTICIPANT	\N	PRESENT	0
627483	626865	20032T	PARTICIPANT	\N	PRESENT	0
627484	626865	11090Q	PARTICIPANT	\N	PRESENT	0
627485	626865	05012A	PARTICIPANT	\N	PRESENT	0
627486	626865	04047H	PARTICIPANT	\N	PRESENT	0
627487	626865	20022R	PARTICIPANT	\N	PRESENT	0
627488	626865	10006L	PARTICIPANT	\N	PRESENT	0
627489	626865	19826F	PARTICIPANT	\N	PRESENT	0
627490	626865	11067R	PARTICIPANT	\N	PRESENT	0
627491	626865	20024T	PARTICIPANT	\N	PRESENT	0
627492	626865	11097X	PARTICIPANT	\N	PRESENT	0
627493	626865	19467C	PARTICIPANT	\N	PRESENT	0
627494	626865	19447X	PARTICIPANT	\N	PRESENT	0
627495	626865	19691J	PARTICIPANT	\N	PRESENT	0
627459	626865	86034E	PARTICIPANT	\N	PRESENT	0
627460	626865	01024M	PARTICIPANT	\N	PRESENT	0
627496	626865	20102Q	PARTICIPANT	\N	PRESENT	0
627497	626865	11056N	PARTICIPANT	\N	PRESENT	0
627498	626865	14217N	PARTICIPANT	\N	PRESENT	0
627499	626865	14357A	PARTICIPANT	\N	PRESENT	0
627500	626865	19533U	PARTICIPANT	\N	PRESENT	0
627501	626865	20140W	PARTICIPANT	\N	PRESENT	0
627502	626865	19741B	PARTICIPANT	\N	PRESENT	0
627503	626865	19762G	PARTICIPANT	\N	PRESENT	0
627504	626865	14207L	PARTICIPANT	\N	PRESENT	0
627505	626865	14033T	PARTICIPANT	\N	PRESENT	0
627506	626865	14026U	PARTICIPANT	\N	PRESENT	0
627507	626865	20108W	PARTICIPANT	\N	PRESENT	0
627508	626865	01028R	PARTICIPANT	\N	PRESENT	0
627509	626865	19713W	PARTICIPANT	\N	PRESENT	0
627510	626865	11012A	PARTICIPANT	\N	PRESENT	0
627511	626865	14069U	PARTICIPANT	\N	PRESENT	0
627512	626865	14059S	PARTICIPANT	\N	PRESENT	0
627513	626865	19569H	PARTICIPANT	\N	PRESENT	0
627514	626865	14031R	PARTICIPANT	\N	PRESENT	0
627515	626865	11053K	PARTICIPANT	\N	PRESENT	0
627516	626865	08069G	PARTICIPANT	\N	PRESENT	0
627517	626865	20026V	PARTICIPANT	\N	PRESENT	0
627518	626865	19399H	PARTICIPANT	\N	PRESENT	0
627519	626865	19719D	PARTICIPANT	\N	PRESENT	0
627520	626865	19631V	PARTICIPANT	\N	PRESENT	0
627521	626865	04045F	PARTICIPANT	\N	PRESENT	0
627522	626865	20098N	PARTICIPANT	\N	PRESENT	0
627523	626865	04035D	PARTICIPANT	\N	PRESENT	0
627524	626865	14259Y	PARTICIPANT	\N	PRESENT	0
627525	626865	14147R	PARTICIPANT	\N	PRESENT	0
627526	626865	08056B	PARTICIPANT	\N	PRESENT	0
627527	626865	14105F	PARTICIPANT	\N	PRESENT	0
627566	626866	20050V	PARTICIPANT	\N	PRESENT	0
627567	626866	19533U	PARTICIPANT	\N	PRESENT	0
627568	626866	20134Y	PARTICIPANT	\N	PRESENT	0
627569	626866	19593H	PARTICIPANT	\N	PRESENT	0
627570	626866	20132W	PARTICIPANT	\N	PRESENT	0
627571	626866	14255U	PARTICIPANT	\N	PRESENT	0
627572	626866	19333N	PARTICIPANT	\N	PRESENT	0
627573	626866	11115U	PARTICIPANT	\N	PRESENT	0
627574	626866	19369B	PARTICIPANT	\N	PRESENT	0
627575	626866	20082E	PARTICIPANT	\N	PRESENT	0
627576	626866	19747H	PARTICIPANT	\N	PRESENT	0
627577	626866	11026G	PARTICIPANT	\N	PRESENT	0
627578	626866	14069U	PARTICIPANT	\N	PRESENT	0
627579	626866	20058E	PARTICIPANT	\N	PRESENT	0
627580	626866	20180F	PARTICIPANT	\N	PRESENT	0
627581	626866	17367Q	PARTICIPANT	\N	PRESENT	0
627582	626866	19387D	PARTICIPANT	\N	PRESENT	0
627583	626866	19651A	PARTICIPANT	\N	PRESENT	0
627587	626866	14147R	PARTICIPANT	\N	PRESENT	0
627585	626866	19758L	PARTICIPANT	\N	PRESENT	0
627586	626866	20142Y	PARTICIPANT	\N	PRESENT	0
627588	626866	20052X	PARTICIPANT	\N	PRESENT	0
627589	626866	11065P	PARTICIPANT	\N	PRESENT	0
627590	626866	19621T	PARTICIPANT	\N	PRESENT	0
627656	627655	08056B	PARTICIPANT	\N	PRESENT	0
627801	627800	14147R	PARTICIPANT	\N	PRESENT	0
627802	627800	20114U	PARTICIPANT	\N	PRESENT	0
627805	627804	14147R	PARTICIPANT	\N	PRESENT	0
627806	627804	20114U	PARTICIPANT	\N	PRESENT	0
627918	626652	20086J	PARTICIPANT	\N	PRESENT	1
627919	626652	14083S	PARTICIPANT	\N	PRESENT	1
627920	626652	11053K	PARTICIPANT	\N	PRESENT	1
627921	626652	11110B	PARTICIPANT	\N	PRESENT	1
627922	626652	14121F	PARTICIPANT	\N	PRESENT	1
627942	626887	19798U	PARTICIPANT	\N	PRESENT	0
628051	627941	19693L	PARTICIPANT	\N	PRESENT	1
627564	626866	01043Q	PARTICIPANT	\N	PRESENT	0
627565	626866	11083R	PARTICIPANT	\N	PRESENT	0
629767	629766	14255U	PARTICIPANT	\N	PRESENT	0
629768	629766	14267Y	PARTICIPANT	\N	PRESENT	0
629769	629766	14059S	PARTICIPANT	\N	PRESENT	0
629770	629766	14193X	PARTICIPANT	\N	PRESENT	0
629771	629766	19766L	PARTICIPANT	\N	PRESENT	0
629772	629766	14107H	PARTICIPANT	\N	PRESENT	0
629773	629766	19421M	PARTICIPANT	\N	PRESENT	0
630425	625813	14026U	PARTICIPANT	\N	PRESENT	0
630426	625813	19333N	PARTICIPANT	\N	PRESENT	0
630427	625813	08034U	PARTICIPANT	\N	PRESENT	0
630428	625813	14033T	PARTICIPANT	\N	PRESENT	0
630429	625821	14026U	PARTICIPANT	\N	PRESENT	0
630430	625821	19333N	PARTICIPANT	\N	PRESENT	0
630432	625821	19619A	PARTICIPANT	\N	PRESENT	0
631346	631345	19701S	PARTICIPANT	\N	PRESENT	0
631347	631345	01024M	PARTICIPANT	\N	PRESENT	0
631348	631345	20100N	PARTICIPANT	\N	PRESENT	0
631349	631345	20038A	PARTICIPANT	\N	PRESENT	0
634759	631936	11109J	PARTICIPANT	\N	EXCUSE	0
634760	631936	19399H	PARTICIPANT	\N	PRESENT	0
634761	631936	14123H	PARTICIPANT	\N	PRESENT	0
634762	631936	20084G	PARTICIPANT	\N	PRESENT	0
634763	631936	19593H	PARTICIPANT	\N	PRESENT	0
634764	631936	19758L	PARTICIPANT	\N	PRESENT	0
634765	631936	08012N	PARTICIPANT	\N	PRESENT	0
634766	631936	20142Y	PARTICIPANT	\N	PRESENT	0
634767	631936	19611R	PRESIDENT	0	PRESENT	0
634768	631936	14030Q	PARTICIPANT	\N	PRESENT	0
634769	631936	14073Q	PARTICIPANT	\N	PRESENT	0
634770	631936	20132W	PARTICIPANT	\N	PRESENT	0
634771	631936	20172F	PARTICIPANT	\N	PRESENT	0
634772	631936	19699S	PARTICIPANT	\N	PRESENT	0
634773	631936	20180F	PARTICIPANT	\N	PRESENT	0
634774	631936	20026V	PARTICIPANT	\N	PRESENT	0
634775	631936	14109K	PARTICIPANT	\N	PRESENT	0
634776	631936	20134Y	PARTICIPANT	\N	PRESENT	1
634777	631936	19693L	PARTICIPANT	\N	PRESENT	0
634778	631936	14229S	PARTICIPANT	\N	PRESENT	0
634779	631936	19573D	PARTICIPANT	\N	PRESENT	0
634780	631936	19533U	PARTICIPANT	\N	PRESENT	0
634781	631936	20264J	PARTICIPANT	\N	PRESENT	0
634782	631936	20048C	PARTICIPANT	\N	PRESENT	1
634783	631936	20124W	PARTICIPANT	\N	PRESENT	0
634784	631936	01060R	PARTICIPANT	\N	PRESENT	0
634785	631936	20098N	PARTICIPANT	\N	PRESENT	0
634786	631936	04059M	PARTICIPANT	\N	PRESENT	0
634787	631936	20056C	PARTICIPANT	\N	PRESENT	0
634788	631936	19735D	PARTICIPANT	\N	EXCUSE	0
647963	647517	20110Q	PARTICIPANT	\N	PRESENT	0
647966	647517	19673G	PARTICIPANT	\N	PRESENT	0
647989	647517	04047H	PRESIDENT	0	PRESENT	0
647991	647517	19954N	PARTICIPANT	\N	PRESENT	0
647992	647517	14215L	PARTICIPANT	\N	PRESENT	0
647994	647517	14147R	PARTICIPANT	\N	PRESENT	0
647998	647517	17737W	PARTICIPANT	\N	PRESENT	0
647999	647517	20108W	PARTICIPANT	\N	PRESENT	0
648000	647517	20022R	PARTICIPANT	\N	PRESENT	0
650965	650963	14211G	PARTICIPANT	\N	PRESENT	0
650966	650963	11041F	PARTICIPANT	\N	PRESENT	0
651294	651293	01058X	PARTICIPANT	\N	EXCUSE	0
651295	651293	20128B	PARTICIPANT	\N	EXCUSE	0
650089	649725	01043Q	PARTICIPANT	\N	PRESENT	0
651296	651293	04043D	PARTICIPANT	\N	EXCUSE	0
650094	649725	14251Q	PARTICIPANT	\N	PRESENT	1
651297	651293	20066E	PARTICIPANT	\N	EXCUSE	0
650102	649773	11090Q	PARTICIPANT	\N	EXCUSE	0
650964	650963	04042C	PARTICIPANT	\N	PRESENT	0
651298	651293	19693L	PARTICIPANT	\N	EXCUSE	0
651299	651293	19735D	PARTICIPANT	\N	EXCUSE	0
651300	651293	19663E	PARTICIPANT	\N	EXCUSE	0
651301	651293	11067R	PARTICIPANT	\N	EXCUSE	0
651371	649165	11077T	PARTICIPANT	\N	PRESENT	0
651375	649165	20044X	PARTICIPANT	\N	PRESENT	0
651377	649165	20122U	PARTICIPANT	\N	PRESENT	0
651378	649165	20024T	PARTICIPANT	\N	PRESENT	0
651708	651645	19383Y	PARTICIPANT	\N	PRESENT	0
651709	651645	14038Y	PARTICIPANT	\N	PRESENT	1
651710	651645	20030R	PARTICIPANT	\N	PRESENT	1
651711	651645	20034V	PARTICIPANT	\N	PRESENT	1
651712	651645	20092G	PARTICIPANT	\N	PRESENT	0
651713	651645	19782L	PARTICIPANT	\N	PRESENT	1
651714	651645	14357A	PARTICIPANT	\N	PRESENT	0
651715	651645	19695N	PARTICIPANT	\N	PRESENT	1
651716	651645	11090Q	PRESIDENT	0	PRESENT	0
651717	651645	20054A	PARTICIPANT	\N	PRESENT	0
651718	651645	19631V	PARTICIPANT	\N	PRESENT	0
651719	651645	14251Q	PARTICIPANT	\N	PRESENT	1
651720	651645	19705W	PARTICIPANT	\N	PRESENT	0
651721	651645	19707Y	PARTICIPANT	\N	PRESENT	0
651722	651645	20286Q	PARTICIPANT	\N	PRESENT	1
651723	651645	19747H	PARTICIPANT	\N	PRESENT	0
651724	651645	14207L	PARTICIPANT	\N	PRESENT	1
651725	651645	20018V	PARTICIPANT	\N	PRESENT	1
651726	651645	14037X	PARTICIPANT	\N	PRESENT	0
651727	651645	14257W	PARTICIPANT	\N	PRESENT	0
652124	651574	14111D	PARTICIPANT	\N	PRESENT	0
652125	651574	11010L	PARTICIPANT	\N	PRESENT	0
652126	651574	10015M	PARTICIPANT	\N	PRESENT	0
652127	651574	11026G	PARTICIPANT	\N	PRESENT	0
652128	651574	04047H	PRESIDENT	0	PRESENT	0
652129	651574	01028R	PARTICIPANT	\N	PRESENT	0
652130	651574	05008E	PARTICIPANT	\N	PRESENT	0
652131	651574	14231L	PARTICIPANT	\N	PRESENT	0
652132	651574	14089Y	PARTICIPANT	\N	PRESENT	0
652133	651574	19729F	PARTICIPANT	\N	PRESENT	0
652134	651574	95063L	PARTICIPANT	\N	PRESENT	0
652135	651574	14275Y	PARTICIPANT	\N	PRESENT	0
652136	651574	20108W	PARTICIPANT	\N	PRESENT	0
652137	651574	20110Q	PARTICIPANT	\N	PRESENT	0
652138	651574	14069U	PARTICIPANT	\N	PRESENT	0
652139	651574	14151M	PARTICIPANT	\N	PRESENT	0
652140	651574	14215L	PARTICIPANT	\N	PRESENT	0
652141	651574	19749K	PARTICIPANT	\N	PRESENT	0
652142	651574	20022R	PARTICIPANT	\N	PRESENT	0
652143	651574	14259Y	PARTICIPANT	\N	PRESENT	0
652144	651574	14021P	PARTICIPANT	\N	PRESENT	0
652145	651574	19725B	PARTICIPANT	\N	EXCUSE	0
652148	652088	19631V	PARTICIPANT	\N	PRESENT	0
652167	652165	19333N	PARTICIPANT	\N	PRESENT	0
652168	652165	19701S	PARTICIPANT	\N	PRESENT	0
652170	652165	19549D	PARTICIPANT	\N	PRESENT	0
652171	652165	19387D	PARTICIPANT	\N	PRESENT	0
652172	652165	14219Q	PRESIDENT	0	PRESENT	0
652173	652165	19826F	PARTICIPANT	\N	PRESENT	0
652174	652165	20102Q	PARTICIPANT	\N	PRESENT	0
652175	652165	19599P	PARTICIPANT	\N	PRESENT	0
652176	652165	19637C	PARTICIPANT	\N	PRESENT	0
652178	652165	18083K	PARTICIPANT	\N	PRESENT	0
652179	652165	14237S	PARTICIPANT	\N	PRESENT	0
652180	652165	20100N	PARTICIPANT	\N	PRESENT	0
652181	652165	05012A	PARTICIPANT	\N	PRESENT	0
652182	652165	08060W	PARTICIPANT	\N	PRESENT	0
652183	652165	19503N	PARTICIPANT	\N	PRESENT	0
652185	652165	20024T	PARTICIPANT	\N	PRESENT	0
652186	652165	11065P	PARTICIPANT	\N	PRESENT	0
652188	652165	19525U	PARTICIPANT	\N	PRESENT	0
652189	652165	20120S	PARTICIPANT	\N	PRESENT	0
652190	652165	20032T	PARTICIPANT	\N	PRESENT	0
652191	652165	20136B	PARTICIPANT	\N	PRESENT	0
652192	652165	14031R	PARTICIPANT	\N	PRESENT	0
652193	652165	20140W	PARTICIPANT	\N	PRESENT	0
652194	652165	19251M	PARTICIPANT	\N	PRESENT	0
652196	652165	19739H	PARTICIPANT	\N	PRESENT	0
652198	652197	20070A	PARTICIPANT	\N	PRESENT	0
652199	652165	19820Y	PARTICIPANT	\N	PRESENT	0
652200	651585	14133K	PARTICIPANT	\N	PRESENT	1
652201	651585	10015M	PARTICIPANT	\N	PRESENT	0
652202	651585	20100N	PARTICIPANT	\N	PRESENT	0
652203	651585	14189C	PARTICIPANT	\N	PRESENT	0
652204	651585	20286Q	PARTICIPANT	\N	PRESENT	0
652205	651585	14357A	PARTICIPANT	\N	PRESENT	0
652206	651585	19553Y	PARTICIPANT	\N	PRESENT	0
652207	651585	19333N	PARTICIPANT	\N	PRESENT	0
652208	651585	14026U	PARTICIPANT	\N	PRESENT	0
652209	651585	08034U	PARTICIPANT	\N	PRESENT	0
652210	651585	20098N	PARTICIPANT	\N	PRESENT	0
652211	651585	14033T	PARTICIPANT	\N	PRESENT	0
652212	651585	19531S	PARTICIPANT	\N	PRESENT	0
652213	651585	19701S	PARTICIPANT	\N	PRESENT	0
652214	651585	11026G	PARTICIPANT	\N	PRESENT	0
652215	651585	20128B	PARTICIPANT	\N	PRESENT	1
652219	651585	04057K	PARTICIPANT	\N	PRESENT	0
652220	651585	20094J	PARTICIPANT	\N	PRESENT	0
652221	651585	11101A	PARTICIPANT	\N	PRESENT	0
652222	651585	12016W	PARTICIPANT	\N	PRESENT	0
652223	651585	19619A	PARTICIPANT	\N	PRESENT	0
652225	651588	86034E	PARTICIPANT	\N	PRESENT	0
652226	651588	14259Y	PARTICIPANT	\N	PRESENT	0
652227	651588	19511N	PARTICIPANT	\N	PRESENT	0
652228	651588	20266L	PARTICIPANT	\N	PRESENT	0
652229	651588	19507S	PARTICIPANT	\N	PRESENT	0
652230	651588	11080N	PARTICIPANT	\N	PRESENT	0
652231	651588	19866P	PARTICIPANT	\N	PRESENT	0
652232	651588	17737W	PARTICIPANT	\N	PRESENT	0
652233	651588	14267Y	PARTICIPANT	\N	PRESENT	0
652234	651588	19703U	PARTICIPANT	\N	PRESENT	0
652235	651588	20098N	PARTICIPANT	\N	PRESENT	0
652236	651588	18193Q	PARTICIPANT	\N	PRESENT	0
652237	651588	08056B	PARTICIPANT	\N	PRESENT	0
652238	651588	20090E	PARTICIPANT	\N	PRESENT	0
652239	651588	14031R	PARTICIPANT	\N	PRESENT	0
652240	651588	20136B	PARTICIPANT	\N	PRESENT	0
652241	651588	19705W	PARTICIPANT	\N	PRESENT	0
652242	651588	20088L	PARTICIPANT	\N	PRESENT	0
652243	651588	14281W	PARTICIPANT	\N	PRESENT	0
652244	651588	20102Q	PARTICIPANT	\N	PRESENT	0
652245	651588	11054L	PARTICIPANT	\N	PRESENT	0
652246	651588	19711U	PARTICIPANT	\N	PRESENT	0
652247	651588	20026V	PARTICIPANT	\N	PRESENT	0
652248	651588	19525U	PARTICIPANT	\N	PRESENT	0
652249	651588	19719D	PARTICIPANT	\N	PRESENT	0
652250	651588	08060W	PARTICIPANT	\N	PRESENT	0
652251	651588	11033F	PARTICIPANT	\N	PRESENT	0
652252	651588	19621T	PARTICIPANT	\N	PRESENT	0
652253	651588	01058X	PARTICIPANT	\N	PRESENT	0
652254	651588	19679N	PARTICIPANT	\N	PRESENT	0
652255	651588	20078J	PARTICIPANT	\N	PRESENT	0
652256	651588	18083K	PARTICIPANT	\N	PRESENT	0
652257	651588	11048N	PARTICIPANT	\N	PRESENT	0
652258	651588	14123H	PARTICIPANT	\N	PRESENT	0
652259	651588	08034U	PARTICIPANT	\N	PRESENT	0
652260	651588	19747H	PARTICIPANT	\N	PRESENT	0
652261	651588	19643A	PARTICIPANT	\N	PRESENT	0
652262	651588	04071H	PARTICIPANT	\N	PRESENT	0
627854	627853	19758L	PARTICIPANT	\N	PRESENT	1
627855	627853	19735D	PARTICIPANT	\N	PRESENT	1
627856	627852	19735D	PARTICIPANT	\N	PRESENT	1
627857	627851	19735D	PARTICIPANT	\N	PRESENT	1
627858	627830	20024T	PARTICIPANT	\N	PRESENT	0
627859	627830	19954N	PARTICIPANT	\N	PRESENT	0
627860	627830	19575F	PARTICIPANT	\N	PRESENT	0
627861	627830	20152B	PARTICIPANT	\N	PRESENT	0
627862	627830	20134Y	PARTICIPANT	\N	PRESENT	0
627863	627830	20132W	PARTICIPANT	\N	PRESENT	0
627864	627830	14073Q	PARTICIPANT	\N	PRESENT	0
627865	627830	19699S	PARTICIPANT	\N	PRESENT	0
627866	627830	08012N	PARTICIPANT	\N	PRESENT	0
627867	627830	19533U	PARTICIPANT	\N	PRESENT	0
627868	627830	19349W	PARTICIPANT	\N	PRESENT	0
627869	627830	11043H	PARTICIPANT	\N	PRESENT	0
627870	627830	19611R	PARTICIPANT	\N	PRESENT	0
627872	626897	01043Q	PARTICIPANT	\N	EXCUSE	0
627873	626897	11056N	PARTICIPANT	\N	PRESENT	0
627874	626897	19479G	PARTICIPANT	\N	PRESENT	0
627875	626897	20134Y	PARTICIPANT	\N	PRESENT	1
627876	626897	20286Q	PARTICIPANT	\N	PRESENT	1
627923	626898	20286Q	PARTICIPANT	\N	PRESENT	1
627924	626898	01043Q	PARTICIPANT	\N	EXCUSE	0
627943	626694	95063L	PARTICIPANT	\N	EXCUSE	0
629739	629679	08045X	PARTICIPANT	\N	PRESENT	0
629740	629679	20130U	PARTICIPANT	\N	PRESENT	0
629742	629680	08045X	PARTICIPANT	\N	PRESENT	0
629743	629680	20130U	PARTICIPANT	\N	PRESENT	0
629745	629680	18193Q	PARTICIPANT	\N	PRESENT	0
633657	633654	19369B	PARTICIPANT	\N	PRESENT	0
633658	633654	20144B	PARTICIPANT	\N	PRESENT	0
633659	633654	19575F	PARTICIPANT	\N	PRESENT	0
633660	633654	19681G	PARTICIPANT	\N	PRESENT	0
633661	633654	20038A	PARTICIPANT	\N	PRESENT	0
633662	633654	19413M	PARTICIPANT	\N	PRESENT	0
633663	633654	19333N	PARTICIPANT	\N	PRESENT	0
633664	633654	14033T	PARTICIPANT	\N	PRESENT	0
633665	633654	14257W	PARTICIPANT	\N	PRESENT	0
633666	633654	19711U	PARTICIPANT	\N	PRESENT	0
633667	633654	20094J	PARTICIPANT	\N	PRESENT	0
633668	633654	14357A	PARTICIPANT	\N	PRESENT	0
633669	633654	19820Y	PARTICIPANT	\N	PRESENT	0
633670	633654	20174H	PARTICIPANT	\N	PRESENT	0
633677	632461	14231L	PRESIDENT	0	PRESENT	0
633678	632461	19489J	PARTICIPANT	\N	PRESENT	0
633679	632461	14053L	PARTICIPANT	\N	PRESENT	0
633680	632461	01057W	PARTICIPANT	\N	PRESENT	0
633681	632461	14173T	PARTICIPANT	\N	PRESENT	0
633682	632461	20110Q	PARTICIPANT	\N	PRESENT	0
633683	632461	20084G	PARTICIPANT	\N	PRESENT	0
633684	632461	19573D	PARTICIPANT	\N	PRESENT	0
633685	632461	20090E	PARTICIPANT	\N	PRESENT	0
633686	632461	04045F	PARTICIPANT	\N	PRESENT	0
633687	632461	19758L	PARTICIPANT	\N	PRESENT	0
633688	632461	14217N	PARTICIPANT	\N	PRESENT	0
633689	632461	14187A	PARTICIPANT	\N	PRESENT	0
633690	632461	14327T	PARTICIPANT	\N	PRESENT	0
633692	632461	14107H	PARTICIPANT	\N	PRESENT	0
633693	632461	20058E	PARTICIPANT	\N	PRESENT	0
633759	633757	01057W	PARTICIPANT	\N	PRESENT	0
633760	633757	14225N	PARTICIPANT	\N	PRESENT	0
633892	627019	20024T	PARTICIPANT	\N	PRESENT	0
633893	627019	14030Q	PRESIDENT	0	PRESENT	0
633894	627019	20114U	PARTICIPANT	\N	PRESENT	1
633895	627019	14109K	PARTICIPANT	\N	PRESENT	1
633896	627019	07029T	PARTICIPANT	\N	EXCUSE	0
633897	627019	20106U	PARTICIPANT	\N	PRESENT	1
633898	627019	11031D	PARTICIPANT	\N	PRESENT	0
633899	627019	19749K	PARTICIPANT	\N	PRESENT	0
633900	632204	19515S	PRESIDENT	0	PRESENT	0
633901	632204	20060X	PARTICIPANT	\N	PRESENT	0
633902	632204	20094J	PARTICIPANT	\N	PRESENT	0
633903	632204	16685X	PARTICIPANT	\N	PRESENT	0
633904	632204	19762G	PARTICIPANT	\N	PRESENT	0
633905	632204	19467C	PARTICIPANT	\N	PRESENT	0
633906	632204	20092G	PARTICIPANT	\N	PRESENT	0
633907	632204	19782L	PARTICIPANT	\N	PRESENT	0
633908	632204	19575F	PARTICIPANT	\N	PRESENT	0
633909	632204	20126Y	PARTICIPANT	\N	PRESENT	0
633910	632204	19760E	PARTICIPANT	\N	PRESENT	0
633911	627019	20138D	PARTICIPANT	\N	PRESENT	1
633930	631641	19717B	PRESIDENT	0	PRESENT	0
633931	631641	97011G	PARTICIPANT	\N	PRESENT	0
633932	631641	19347U	PARTICIPANT	\N	PRESENT	1
633933	631641	20034V	PARTICIPANT	\N	PRESENT	0
633934	631641	14097Y	PARTICIPANT	\N	PRESENT	0
633935	631641	14059S	PARTICIPANT	\N	PRESENT	0
633937	631641	20028X	PARTICIPANT	\N	PRESENT	0
633938	631641	11072N	PARTICIPANT	\N	PRESENT	1
633939	631641	20146D	PARTICIPANT	\N	PRESENT	0
633940	631641	19319Q	PARTICIPANT	\N	PRESENT	1
633941	631641	11043H	PARTICIPANT	\N	PRESENT	1
633942	631641	08073C	PARTICIPANT	\N	PRESENT	0
633952	631641	18083K	PARTICIPANT	\N	EXCUSE	0
633956	631641	14219Q	PARTICIPANT	\N	EXCUSE	0
633957	631641	17023S	PARTICIPANT	\N	EXCUSE	0
633958	631641	20150Y	PARTICIPANT	\N	EXCUSE	0
633978	630831	19683J	PRESIDENT	0	PRESENT	0
633979	630831	10006L	PARTICIPANT	\N	PRESENT	0
633980	630831	20130U	PARTICIPANT	\N	PRESENT	1
633984	630831	11031D	PARTICIPANT	\N	PRESENT	0
633997	630831	19703U	PARTICIPANT	\N	PRESENT	1
634018	634016	19735D	PARTICIPANT	\N	PRESENT	0
634019	634016	04043D	PARTICIPANT	\N	PRESENT	0
634045	631571	20024T	PARTICIPANT	\N	PRESENT	0
634048	631571	20090E	PARTICIPANT	\N	PRESENT	0
634049	630831	19735D	PARTICIPANT	\N	EXCUSE	0
634050	631571	19621T	PARTICIPANT	\N	PRESENT	0
634051	631571	19573D	PARTICIPANT	\N	PRESENT	0
634052	631571	19762G	PARTICIPANT	\N	PRESENT	0
634061	631571	14053L	PARTICIPANT	\N	PRESENT	0
634062	631571	14179A	PARTICIPANT	\N	PRESENT	0
634063	631571	19693L	PARTICIPANT	\N	PRESENT	0
634064	631571	14215L	PARTICIPANT	\N	PRESENT	0
634065	631571	20134Y	PARTICIPANT	\N	PRESENT	0
634067	631571	20052X	PARTICIPANT	\N	PRESENT	0
634068	631571	19758L	PARTICIPANT	\N	PRESENT	0
634070	634069	19599P	PARTICIPANT	\N	PRESENT	0
634071	634069	19515S	PARTICIPANT	\N	PRESENT	0
634072	631571	97011G	PARTICIPANT	\N	PRESENT	0
634074	634069	20020P	PARTICIPANT	\N	PRESENT	0
634075	634069	20140W	PARTICIPANT	\N	PRESENT	0
634081	634069	19685L	PARTICIPANT	\N	PRESENT	0
634085	634069	20024T	PARTICIPANT	\N	PRESENT	0
634099	634096	19599P	PARTICIPANT	\N	PRESENT	0
634102	634096	19685L	PARTICIPANT	\N	PRESENT	0
634103	634096	20024T	PARTICIPANT	\N	PRESENT	0
634105	634096	20020P	PARTICIPANT	\N	PRESENT	0
634107	634106	20024T	PARTICIPANT	\N	PRESENT	0
634108	634106	19685L	PARTICIPANT	\N	PRESENT	0
634142	631572	99004R	PARTICIPANT	\N	PRESENT	0
634143	631572	19573D	PARTICIPANT	\N	PRESENT	0
634144	631572	19758L	PARTICIPANT	\N	PRESENT	0
634145	631572	14073Q	PARTICIPANT	\N	PRESENT	0
634146	631572	20132W	PARTICIPANT	\N	PRESENT	0
634147	631572	19527W	PARTICIPANT	\N	PRESENT	0
634148	631572	20134Y	PARTICIPANT	\N	PRESENT	0
634149	631572	20036X	PARTICIPANT	\N	PRESENT	0
634150	631572	20090E	PARTICIPANT	\N	PRESENT	0
634151	631572	97011G	PARTICIPANT	\N	PRESENT	0
634152	631572	20096L	PARTICIPANT	\N	PRESENT	0
634154	631572	20098N	PARTICIPANT	\N	PRESENT	0
634155	631572	10015M	PARTICIPANT	\N	PRESENT	0
634156	634153	14033T	PARTICIPANT	\N	PRESENT	0
634157	634153	19369B	PARTICIPANT	\N	PRESENT	0
634158	634153	20018V	PARTICIPANT	\N	PRESENT	0
634159	631572	19954N	PARTICIPANT	\N	PRESENT	0
634160	631572	11012A	PARTICIPANT	\N	PRESENT	0
634161	631572	20106U	PARTICIPANT	\N	PRESENT	0
634162	631572	14215L	PARTICIPANT	\N	PRESENT	0
634163	631572	20052X	PARTICIPANT	\N	PRESENT	0
634164	631572	19762G	PARTICIPANT	\N	PRESENT	0
634165	631572	20152B	PARTICIPANT	\N	PRESENT	0
634166	631572	20124W	PARTICIPANT	\N	PRESENT	0
634167	631572	20032T	PARTICIPANT	\N	PRESENT	0
634168	631572	04057K	PARTICIPANT	\N	PRESENT	0
634169	631572	20084G	PARTICIPANT	\N	PRESENT	0
634170	631572	19621T	PARTICIPANT	\N	PRESENT	0
634172	631572	20102Q	PARTICIPANT	\N	PRESENT	0
647605	647604	14193X	PARTICIPANT	\N	PRESENT	1
646312	643942	20148F	PARTICIPANT	\N	PRESENT	0
646316	646315	19643A	PARTICIPANT	\N	PRESENT	0
646317	646315	20132W	PARTICIPANT	\N	PRESENT	0
646318	646315	19447X	PARTICIPANT	\N	PRESENT	0
646319	646315	19725B	PARTICIPANT	\N	PRESENT	0
646320	646315	14147R	PARTICIPANT	\N	PRESENT	0
646326	646325	20024T	PARTICIPANT	\N	PRESENT	0
646327	646325	20090E	PARTICIPANT	\N	PRESENT	0
646328	646325	14053L	PARTICIPANT	\N	PRESENT	0
646329	646325	11099A	PARTICIPANT	\N	PRESENT	0
646330	646325	19697Q	PARTICIPANT	\N	PRESENT	0
646331	646325	10015M	PARTICIPANT	\N	PRESENT	0
646433	646323	14189C	PARTICIPANT	\N	PRESENT	0
646434	646323	19741B	PARTICIPANT	\N	PRESENT	0
646435	646323	11040E	PARTICIPANT	\N	PRESENT	1
646436	646323	20070A	PARTICIPANT	\N	PRESENT	0
646437	646323	11048N	PARTICIPANT	\N	PRESENT	0
646438	646323	20126Y	PARTICIPANT	\N	PRESENT	0
646439	646323	12016W	PARTICIPANT	\N	PRESENT	0
646440	646323	14225N	PARTICIPANT	\N	PRESENT	0
646441	646323	19479G	PARTICIPANT	\N	PRESENT	0
646552	646157	14133K	PARTICIPANT	\N	PRESENT	0
646553	646157	20042V	PARTICIPANT	\N	PRESENT	0
646554	646157	04042C	PRESIDENT	0	PRESENT	0
646555	646157	12028B	PARTICIPANT	\N	PRESENT	0
646556	646157	14267Y	PARTICIPANT	\N	PRESENT	0
646557	646157	11027H	PARTICIPANT	\N	PRESENT	0
646558	646157	11115U	PARTICIPANT	\N	PRESENT	0
646559	646157	01024M	PARTICIPANT	\N	PRESENT	0
646560	646157	07033P	PARTICIPANT	\N	EXCUSE	0
646561	646157	14249W	PARTICIPANT	\N	PRESENT	0
646562	646157	17023S	PARTICIPANT	\N	PRESENT	0
646563	646157	97011G	PARTICIPANT	\N	PRESENT	0
646564	646157	04035D	PARTICIPANT	\N	PRESENT	1
646565	646157	19347U	PARTICIPANT	\N	PRESENT	0
646566	646157	08056B	PARTICIPANT	\N	PRESENT	0
646567	646157	19565D	PARTICIPANT	\N	PRESENT	0
646568	646157	11064N	PARTICIPANT	\N	PRESENT	0
646569	646157	20072C	PARTICIPANT	\N	PRESENT	0
646570	646157	08069G	PARTICIPANT	\N	PRESENT	0
646571	646157	14097Y	PARTICIPANT	\N	PRESENT	0
646572	646157	95041E	PARTICIPANT	\N	PRESENT	0
646573	646157	19583F	PARTICIPANT	\N	PRESENT	0
646574	646157	12041X	PARTICIPANT	\N	PRESENT	0
646575	646157	19709B	PARTICIPANT	\N	PRESENT	0
646576	646157	16685X	PARTICIPANT	\N	PRESENT	0
646577	646157	14059S	PARTICIPANT	\N	PRESENT	0
646578	646157	14191V	PARTICIPANT	\N	PRESENT	0
646579	646157	08061X	PARTICIPANT	\N	PRESENT	0
646580	646157	08047A	PARTICIPANT	\N	PRESENT	0
646581	646157	14193X	PRESIDENT	1	PRESENT	0
646582	646157	19443T	PARTICIPANT	\N	PRESENT	0
646583	646157	11054L	PARTICIPANT	\N	PRESENT	0
646584	646157	19421M	PARTICIPANT	\N	PRESENT	0
646585	646157	01058X	PARTICIPANT	\N	PRESENT	0
646586	646157	01062T	PARTICIPANT	\N	PRESENT	0
646587	646157	20064C	PARTICIPANT	\N	PRESENT	0
646588	646157	11041F	PARTICIPANT	\N	PRESENT	0
646589	646157	11066Q	PARTICIPANT	\N	PRESENT	0
646590	645740	14123H	PARTICIPANT	\N	PRESENT	1
646591	645740	11109J	PARTICIPANT	\N	EXCUSE	0
646667	646248	19705W	PARTICIPANT	\N	PRESENT	1
647585	646198	11048N	PARTICIPANT	\N	PRESENT	0
647586	646198	14225N	PRESIDENT	0	PRESENT	0
647587	646198	19741B	PARTICIPANT	\N	PRESENT	0
647606	647604	19421M	PARTICIPANT	\N	PRESENT	1
647608	647607	14193X	PARTICIPANT	\N	PRESENT	0
647609	647607	19421M	PARTICIPANT	\N	PRESENT	0
647610	647607	11083R	PARTICIPANT	\N	PRESENT	0
647611	647607	11064N	PARTICIPANT	\N	PRESENT	0
647613	647612	14193X	PARTICIPANT	\N	PRESENT	1
647614	647612	19421M	PARTICIPANT	\N	PRESENT	1
647615	647612	11083R	PARTICIPANT	\N	PRESENT	1
647616	647612	11064N	PARTICIPANT	\N	PRESENT	1
647618	647617	14193X	PARTICIPANT	\N	PRESENT	0
647619	647617	19421M	PARTICIPANT	\N	PRESENT	0
647620	647617	16685X	PARTICIPANT	\N	PRESENT	0
647621	647617	11083R	PARTICIPANT	\N	PRESENT	0
647623	647622	19669L	PARTICIPANT	\N	PRESENT	0
647624	647622	19421M	PARTICIPANT	\N	PRESENT	0
647625	647622	16685X	PARTICIPANT	\N	PRESENT	0
647626	647622	11083R	PARTICIPANT	\N	PRESENT	0
647628	647627	19669L	PARTICIPANT	\N	PRESENT	0
647629	647627	16685X	PARTICIPANT	\N	PRESENT	0
647631	647630	14193X	PARTICIPANT	\N	PRESENT	1
647632	647630	19669L	PARTICIPANT	\N	PRESENT	1
647634	647633	14211G	PARTICIPANT	\N	PRESENT	1
647636	647635	14211G	PARTICIPANT	\N	PRESENT	1
647637	647635	11041F	PARTICIPANT	\N	PRESENT	1
647639	647638	14211G	PARTICIPANT	\N	PRESENT	0
647640	647638	11041F	PARTICIPANT	\N	PRESENT	0
647764	646185	04033B	PARTICIPANT	\N	PRESENT	0
647765	646185	20054A	PARTICIPANT	\N	PRESENT	0
647766	646185	20020P	PARTICIPANT	\N	PRESENT	0
647767	646185	19421M	PARTICIPANT	\N	PRESENT	0
647768	646185	20044X	PARTICIPANT	\N	PRESENT	0
647769	646185	11097X	PARTICIPANT	\N	PRESENT	0
647770	646185	01058X	PARTICIPANT	\N	PRESENT	0
647771	646185	20062A	PARTICIPANT	\N	PRESENT	0
647772	646185	20136B	PARTICIPANT	\N	PRESENT	0
647773	646185	20026V	PARTICIPANT	\N	PRESENT	0
647774	646185	20058E	PARTICIPANT	\N	PRESENT	0
647775	646185	14173T	PARTICIPANT	\N	PRESENT	0
647776	646185	14189C	PARTICIPANT	\N	PRESENT	0
647777	646185	14030Q	PARTICIPANT	\N	PRESENT	0
647778	646185	14089Y	PARTICIPANT	\N	PRESENT	0
647779	646185	14267Y	PARTICIPANT	\N	PRESENT	0
647780	646185	14327T	PARTICIPANT	\N	PRESENT	0
647781	646185	20248J	PARTICIPANT	\N	PRESENT	0
647782	646185	19577H	PARTICIPANT	\N	PRESENT	0
647783	646185	01025N	PARTICIPANT	\N	PRESENT	0
647784	646185	20286Q	PARTICIPANT	\N	PRESENT	0
647785	646185	19685L	PARTICIPANT	\N	PRESENT	0
647786	646185	20066E	PARTICIPANT	\N	PRESENT	0
647787	646185	14073Q	PARTICIPANT	\N	PRESENT	0
647788	646185	01043Q	PARTICIPANT	\N	PRESENT	0
647789	646185	11085T	PARTICIPANT	\N	PRESENT	0
647790	646185	19826F	PARTICIPANT	\N	PRESENT	0
647791	646185	20042V	PARTICIPANT	\N	PRESENT	0
647792	646185	11053K	PARTICIPANT	\N	PRESENT	0
647793	646185	20144B	PARTICIPANT	\N	PRESENT	0
647794	646185	14042U	PARTICIPANT	\N	PRESENT	0
647795	646185	14231L	PARTICIPANT	\N	PRESENT	0
647796	646185	19691J	PARTICIPANT	\N	PRESENT	0
647797	646185	19569H	PARTICIPANT	\N	PRESENT	0
647798	646185	14179A	PARTICIPANT	\N	PRESENT	0
647799	646185	20048C	PARTICIPANT	\N	PRESENT	0
647800	646185	19511N	PARTICIPANT	\N	PRESENT	0
647801	646185	19611R	PARTICIPANT	\N	PRESENT	0
647802	646185	19699S	PARTICIPANT	\N	PRESENT	0
647803	646185	16685X	PARTICIPANT	\N	PRESENT	0
647804	646185	20052X	PARTICIPANT	\N	PRESENT	0
647805	646185	14205J	PARTICIPANT	\N	PRESENT	0
647806	646185	14219Q	PARTICIPANT	\N	PRESENT	0
647807	646185	08009T	PARTICIPANT	\N	PRESENT	0
647808	646185	19369B	PARTICIPANT	\N	PRESENT	0
647809	646185	19745F	PARTICIPANT	\N	PRESENT	0
647810	646185	19319Q	PARTICIPANT	\N	PRESENT	0
647811	646185	20298U	PARTICIPANT	\N	PRESENT	0
647812	646185	19619A	PARTICIPANT	\N	PRESENT	0
647813	646185	01034P	PARTICIPANT	\N	PRESENT	0
647814	646185	19479G	PARTICIPANT	\N	PRESENT	0
647815	646185	19631V	PARTICIPANT	\N	PRESENT	0
647816	646185	04059M	PARTICIPANT	\N	PRESENT	0
647817	646185	19549D	PARTICIPANT	\N	PRESENT	0
647818	646185	20094J	PARTICIPANT	\N	PRESENT	0
647819	646185	20088L	PARTICIPANT	\N	PRESENT	0
647820	646185	20080C	PARTICIPANT	\N	PRESENT	0
647821	646185	20060X	PARTICIPANT	\N	PRESENT	0
647822	646185	12028B	PARTICIPANT	\N	PRESENT	0
647823	646185	20264J	PARTICIPANT	\N	PRESENT	0
647824	646185	19295A	PARTICIPANT	\N	PRESENT	0
647825	646185	11027H	PARTICIPANT	\N	PRESENT	0
647826	646185	20070A	PARTICIPANT	\N	PRESENT	0
647827	646185	19251M	PARTICIPANT	\N	PRESENT	0
647828	646185	14151M	PARTICIPANT	\N	PRESENT	0
647829	646185	11074Q	PARTICIPANT	\N	PRESENT	0
647830	646185	11110B	PARTICIPANT	\N	PRESENT	0
647831	646185	14281W	PARTICIPANT	\N	PRESENT	0
647832	646185	08045X	PARTICIPANT	\N	PRESENT	0
634789	631936	11104D	PARTICIPANT	\N	PRESENT	0
634790	631936	19651A	PARTICIPANT	\N	PRESENT	1
636532	632799	10006L	PARTICIPANT	\N	PRESENT	0
636533	632799	19683J	PARTICIPANT	\N	PRESENT	0
636535	632799	19553Y	PARTICIPANT	\N	PRESENT	0
636536	632799	20130U	PARTICIPANT	\N	PRESENT	0
637036	635632	19467C	PARTICIPANT	\N	PRESENT	0
637037	635632	19768N	PARTICIPANT	\N	PRESENT	0
637038	635632	19515S	PARTICIPANT	\N	PRESENT	0
637039	635632	20092G	PARTICIPANT	\N	PRESENT	0
637040	635632	14187A	PARTICIPANT	\N	PRESENT	0
637041	635632	19441R	PARTICIPANT	\N	PRESENT	0
637042	635632	19413M	PARTICIPANT	\N	PRESENT	0
637043	635632	14033T	PARTICIPANT	\N	PRESENT	0
637044	635632	11090Q	PRESIDENT	0	PRESENT	0
637045	635632	20104S	PARTICIPANT	\N	PRESENT	0
637046	635632	20062A	PARTICIPANT	\N	PRESENT	0
637047	635632	19507S	PARTICIPANT	\N	PRESENT	0
637048	635632	08015R	PARTICIPANT	\N	PRESENT	0
637049	635632	19747H	PARTICIPANT	\N	PRESENT	1
637050	635632	14257W	PARTICIPANT	\N	PRESENT	0
637051	635632	14038Y	PARTICIPANT	\N	PRESENT	0
637052	635632	19782L	PARTICIPANT	\N	PRESENT	0
637053	635632	20018V	PARTICIPANT	\N	PRESENT	0
637054	635313	19333N	PARTICIPANT	\N	PRESENT	0
637055	635313	14038Y	PARTICIPANT	\N	PRESENT	0
637056	635313	20032T	PARTICIPANT	\N	PRESENT	0
637057	635313	14331P	PARTICIPANT	\N	PRESENT	0
637058	635313	19701S	PARTICIPANT	\N	PRESENT	0
637059	635313	12041X	PARTICIPANT	\N	PRESENT	0
637060	635313	20038A	PARTICIPANT	\N	PRESENT	0
637061	635313	14031R	PARTICIPANT	\N	PRESENT	0
637062	635313	14187A	PARTICIPANT	\N	PRESENT	0
637063	635313	19549D	PARTICIPANT	\N	PRESENT	0
637064	635313	14219Q	PRESIDENT	0	PRESENT	0
637065	635313	11090Q	PARTICIPANT	\N	PRESENT	0
637066	635313	14033T	PARTICIPANT	\N	PRESENT	0
637067	635313	20102Q	PARTICIPANT	\N	PRESENT	0
637068	635313	14169X	PARTICIPANT	\N	PRESENT	0
637069	635313	17229F	PARTICIPANT	\N	PRESENT	0
637070	635313	18083K	PARTICIPANT	\N	PRESENT	0
637071	635313	14237S	PARTICIPANT	\N	PRESENT	0
637072	635313	20100N	PARTICIPANT	\N	PRESENT	0
637073	635313	19503N	PARTICIPANT	\N	PRESENT	0
637074	635313	19745F	PARTICIPANT	\N	PRESENT	0
637075	635313	19619A	PARTICIPANT	\N	PRESENT	0
637076	635313	20106U	PARTICIPANT	\N	PRESENT	1
637077	635313	20046A	PARTICIPANT	\N	PRESENT	1
637078	635313	19251M	PARTICIPANT	\N	PRESENT	1
637079	635313	19820Y	PARTICIPANT	\N	PRESENT	0
637080	635313	14205J	PARTICIPANT	\N	PRESENT	0
637081	635313	14251Q	PARTICIPANT	\N	PRESENT	1
637082	635313	20094J	PARTICIPANT	\N	PRESENT	1
637083	635313	19747H	PARTICIPANT	\N	PRESENT	1
637084	635313	19707Y	PARTICIPANT	\N	PRESENT	1
637085	635313	20082E	PARTICIPANT	\N	PRESENT	1
637086	635313	19413M	PARTICIPANT	\N	PRESENT	0
637087	635313	14001X	PARTICIPANT	\N	PRESENT	0
637088	635632	14357A	PARTICIPANT	\N	PRESENT	0
637089	635632	19563B	PARTICIPANT	\N	PRESENT	0
637090	635313	19507S	PARTICIPANT	\N	PRESENT	0
637091	635313	14357A	PARTICIPANT	\N	PRESENT	0
637092	635632	20286Q	PARTICIPANT	\N	PRESENT	0
637093	635632	14205J	PARTICIPANT	\N	PRESENT	1
637094	635313	20092G	PARTICIPANT	\N	PRESENT	0
637095	635313	11026G	PARTICIPANT	\N	PRESENT	0
637096	635632	20082E	PARTICIPANT	\N	PRESENT	1
637097	635632	20094J	PARTICIPANT	\N	PRESENT	1
637098	635632	19707Y	PARTICIPANT	\N	PRESENT	1
637099	635632	14251Q	PARTICIPANT	\N	PRESENT	1
637100	635632	20078J	PARTICIPANT	\N	PRESENT	0
637101	635632	20034V	PARTICIPANT	\N	EXCUSE	0
637112	635313	20020P	PARTICIPANT	\N	PRESENT	0
637114	635313	14073Q	PARTICIPANT	\N	PRESENT	0
637115	635632	04045F	PARTICIPANT	\N	PRESENT	0
637118	635313	08015R	PARTICIPANT	\N	PRESENT	0
637119	635313	19563B	PARTICIPANT	\N	PRESENT	0
637120	635313	14257W	PARTICIPANT	\N	PRESENT	0
637121	635632	19631V	PARTICIPANT	\N	PRESENT	0
637122	635313	08034U	PARTICIPANT	\N	PRESENT	0
637132	637131	18083K	PARTICIPANT	\N	PRESENT	0
637133	637131	20266L	PARTICIPANT	\N	PRESENT	0
637150	634659	86034E	PARTICIPANT	\N	PRESENT	0
637151	634659	14225N	PARTICIPANT	\N	PRESENT	0
637152	634659	10006L	PARTICIPANT	\N	PRESENT	0
637153	634659	20116W	PARTICIPANT	\N	PRESENT	0
637154	634659	19647E	PARTICIPANT	\N	PRESENT	0
637155	634659	19349W	PARTICIPANT	\N	PRESENT	0
637156	634659	19583F	PARTICIPANT	\N	PRESENT	0
637157	634659	19762G	PARTICIPANT	\N	PRESENT	0
637158	634659	19689Q	PARTICIPANT	\N	PRESENT	0
637159	634659	11040E	PARTICIPANT	\N	PRESENT	0
637160	634659	11053K	PARTICIPANT	\N	PRESENT	0
637161	634659	20080C	PARTICIPANT	\N	PRESENT	0
637162	634659	20044X	PARTICIPANT	\N	PRESENT	0
637163	634659	11070L	PARTICIPANT	\N	PRESENT	0
637164	634659	19711U	PARTICIPANT	\N	PRESENT	0
637170	634659	19683J	PARTICIPANT	\N	PRESENT	0
637171	634659	14021P	PARTICIPANT	\N	PRESENT	0
637172	634659	01062T	PARTICIPANT	\N	PRESENT	0
637173	634659	11027H	PARTICIPANT	\N	PRESENT	0
637174	634659	19782L	PARTICIPANT	\N	PRESENT	0
637176	634659	20070A	PARTICIPANT	\N	PRESENT	0
637177	634659	14121F	PARTICIPANT	\N	PRESENT	0
637178	634659	12028B	PARTICIPANT	\N	PRESENT	0
637179	634659	20064C	PARTICIPANT	\N	PRESENT	0
637180	634659	19725B	PARTICIPANT	\N	PRESENT	0
637181	634659	19693L	PARTICIPANT	\N	PRESENT	0
637182	634659	19329S	PARTICIPANT	\N	PRESENT	0
637183	634659	11012A	PARTICIPANT	\N	PRESENT	0
637184	634659	11074Q	PARTICIPANT	\N	PRESENT	0
637185	634659	19651A	PARTICIPANT	\N	PRESENT	0
637186	634659	95063L	PARTICIPANT	\N	PRESENT	0
637187	634659	19629C	PARTICIPANT	\N	PRESENT	0
637188	634659	19715Y	PARTICIPANT	\N	PRESENT	0
637189	634659	01028R	PARTICIPANT	\N	PRESENT	0
637190	634659	20248J	PARTICIPANT	\N	PRESENT	0
637191	634659	20066E	PARTICIPANT	\N	PRESENT	0
637192	634659	01057W	PARTICIPANT	\N	PRESENT	0
637193	634659	10015M	PARTICIPANT	\N	PRESENT	0
637194	634659	19687N	PARTICIPANT	\N	PRESENT	0
637195	634659	14205J	PARTICIPANT	\N	PRESENT	0
637196	634659	19569H	PARTICIPANT	\N	PRESENT	0
637197	634659	20086J	PARTICIPANT	\N	PRESENT	0
637198	634659	20132W	PARTICIPANT	\N	PRESENT	0
637199	634659	07004J	PARTICIPANT	\N	PRESENT	0
637200	634659	11097X	PARTICIPANT	\N	PRESENT	0
637201	634659	14147R	PARTICIPANT	\N	PRESENT	0
637202	634659	14215L	PARTICIPANT	\N	PRESENT	0
637203	634659	99004R	PARTICIPANT	\N	PRESENT	0
637204	634659	19621T	PARTICIPANT	\N	PRESENT	0
637205	634659	20126Y	PARTICIPANT	\N	PRESENT	0
637206	634659	14187A	PARTICIPANT	\N	PRESENT	0
637207	634659	14217N	PARTICIPANT	\N	PRESENT	0
637208	634659	01048V	PARTICIPANT	\N	PRESENT	0
637209	634659	07033P	PARTICIPANT	\N	PRESENT	0
637210	634659	19399H	PARTICIPANT	\N	PRESENT	0
637211	634659	17779H	PARTICIPANT	\N	PRESENT	0
637212	634659	11010L	PARTICIPANT	\N	PRESENT	0
637213	634659	20180F	PARTICIPANT	\N	PRESENT	0
637214	634659	11067R	PARTICIPANT	\N	PRESENT	0
637215	634659	19631V	PARTICIPANT	\N	PRESENT	0
637216	634659	19447X	PARTICIPANT	\N	PRESENT	0
637217	634659	19443T	PARTICIPANT	\N	PRESENT	0
637218	634659	07029T	PARTICIPANT	\N	PRESENT	0
637219	634659	01058X	PARTICIPANT	\N	PRESENT	0
637220	634659	20090E	PARTICIPANT	\N	PRESENT	0
637227	634659	14059S	PARTICIPANT	\N	PRESENT	0
637230	634659	20142Y	PARTICIPANT	\N	PRESENT	0
637236	634659	01024M	PARTICIPANT	\N	PRESENT	0
637237	634659	14030Q	PARTICIPANT	\N	PRESENT	0
637238	634659	19699S	PARTICIPANT	\N	PRESENT	0
637239	634659	11085T	PARTICIPANT	\N	PRESENT	0
637245	634659	14231L	PARTICIPANT	\N	PRESENT	0
637242	634659	20032T	PARTICIPANT	\N	PRESENT	0
637243	634659	14031R	PARTICIPANT	\N	PRESENT	0
637244	634659	19503N	PARTICIPANT	\N	PRESENT	0
637246	634659	04045F	PARTICIPANT	\N	PRESENT	0
637247	634659	14073Q	PARTICIPANT	\N	PRESENT	0
637248	637241	19768N	PARTICIPANT	\N	PRESENT	0
649207	649206	05008E	PARTICIPANT	\N	PRESENT	0
649208	649206	11053K	PARTICIPANT	\N	PRESENT	0
649209	649206	01028R	PARTICIPANT	\N	PRESENT	0
649308	649089	19545Y	PARTICIPANT	\N	PRESENT	1
649309	649089	19531S	PARTICIPANT	\N	PRESENT	1
649310	649089	99004R	PARTICIPANT	\N	PRESENT	1
649311	649089	19671E	PARTICIPANT	\N	PRESENT	1
649312	649089	14331P	PARTICIPANT	\N	PRESENT	1
649313	649089	19479G	PARTICIPANT	\N	PRESENT	1
649320	649089	20126Y	PARTICIPANT	\N	PRESENT	0
649436	649434	07029T	PARTICIPANT	\N	PRESENT	0
649449	649448	19711U	PARTICIPANT	\N	PRESENT	0
649450	649448	11048N	PARTICIPANT	\N	PRESENT	0
650033	647962	19715Y	PARTICIPANT	\N	EXCUSE	0
651862	651586	14217N	PARTICIPANT	\N	PRESENT	0
651863	651586	20144B	PARTICIPANT	\N	PRESENT	0
651940	651587	20110Q	PARTICIPANT	\N	PRESENT	0
651941	651587	20022R	PARTICIPANT	\N	PRESENT	0
651942	651587	14089Y	PARTICIPANT	\N	PRESENT	0
651943	651587	04085P	PARTICIPANT	\N	PRESENT	0
651944	651587	19553Y	PARTICIPANT	\N	PRESENT	0
651945	651587	11033F	PARTICIPANT	\N	PRESENT	0
651946	651587	19649G	PARTICIPANT	\N	PRESENT	0
651947	651587	95063L	PARTICIPANT	\N	PRESENT	0
651948	651587	14111D	PARTICIPANT	\N	PRESENT	0
651949	651587	14151M	PARTICIPANT	\N	PRESENT	0
651950	651587	14021P	PARTICIPANT	\N	PRESENT	0
651951	651587	20030R	PARTICIPANT	\N	PRESENT	0
651952	651587	19503N	PARTICIPANT	\N	PRESENT	0
651953	651587	11067R	PARTICIPANT	\N	PRESENT	0
651954	651587	11026G	PARTICIPANT	\N	PRESENT	0
651955	651587	20018V	PARTICIPANT	\N	PRESENT	0
651956	651587	20084G	PARTICIPANT	\N	PRESENT	0
651957	651587	11083R	PARTICIPANT	\N	PRESENT	0
651958	651587	14249W	PARTICIPANT	\N	PRESENT	0
651959	651587	19697Q	PARTICIPANT	\N	PRESENT	0
651960	651587	19387D	PARTICIPANT	\N	PRESENT	0
651961	651587	19583F	PARTICIPANT	\N	PRESENT	0
651962	651587	20042V	PARTICIPANT	\N	PRESENT	0
651963	651587	20066E	PARTICIPANT	\N	PRESENT	0
651964	651587	19739H	PARTICIPANT	\N	PRESENT	0
651965	651587	14205J	PARTICIPANT	\N	PRESENT	0
651966	651587	14207L	PARTICIPANT	\N	PRESENT	0
651967	651587	20128B	PARTICIPANT	\N	PRESENT	0
651968	651587	19349W	PARTICIPANT	\N	PRESENT	0
651969	651587	11077T	PARTICIPANT	\N	PRESENT	0
651970	651587	20106U	PARTICIPANT	\N	PRESENT	0
651971	651587	19651A	PARTICIPANT	\N	PRESENT	0
651972	651587	20132W	PARTICIPANT	\N	PRESENT	0
651973	651587	19479G	PARTICIPANT	\N	PRESENT	0
651974	651587	19577H	PARTICIPANT	\N	PRESENT	0
651975	651587	19745F	PARTICIPANT	\N	PRESENT	0
651976	651587	08056B	PARTICIPANT	\N	PRESENT	0
651977	651587	95041E	PARTICIPANT	\N	PRESENT	0
651978	651587	19671E	PARTICIPANT	\N	PRESENT	0
651979	651587	14215L	PARTICIPANT	\N	PRESENT	0
651980	651587	19747H	PARTICIPANT	\N	PRESENT	0
651981	651587	08034U	PARTICIPANT	\N	PRESENT	0
651982	651587	20090E	PARTICIPANT	\N	PRESENT	0
651983	651587	20054A	PARTICIPANT	\N	PRESENT	0
651984	651587	20152B	PARTICIPANT	\N	PRESENT	0
651985	651587	14217N	PARTICIPANT	\N	PRESENT	0
651986	651587	97011G	PARTICIPANT	\N	PRESENT	0
651987	651587	14105F	PARTICIPANT	\N	PRESENT	0
651988	651587	99004R	PARTICIPANT	\N	PRESENT	0
651989	651587	01058X	PARTICIPANT	\N	PRESENT	0
651990	651587	14223L	PARTICIPANT	\N	PRESENT	0
651991	651587	20032T	PARTICIPANT	\N	PRESENT	0
651992	651587	20108W	PARTICIPANT	\N	PRESENT	0
651993	651587	20104S	PARTICIPANT	\N	PRESENT	0
651994	651587	20068G	PARTICIPANT	\N	PRESENT	0
651995	651587	18083K	PARTICIPANT	\N	PRESENT	0
651996	651587	14031R	PARTICIPANT	\N	PRESENT	0
651997	651587	19673G	PARTICIPANT	\N	PRESENT	0
651998	651587	20038A	PARTICIPANT	\N	PRESENT	0
651999	651587	20180F	PARTICIPANT	\N	PRESENT	0
652000	651587	19467C	PARTICIPANT	\N	PRESENT	0
652001	651587	20044X	PARTICIPANT	\N	PRESENT	0
652002	651587	10015M	PARTICIPANT	\N	PRESENT	0
652003	651587	19575F	PARTICIPANT	\N	PRESENT	0
652004	651587	14038Y	PARTICIPANT	\N	PRESENT	0
652005	651587	20058E	PARTICIPANT	\N	PRESENT	0
652006	651587	04057K	PARTICIPANT	\N	PRESENT	0
652007	651587	04047H	PARTICIPANT	\N	PRESENT	0
652011	651587	20252E	PARTICIPANT	\N	PRESENT	0
652009	651587	14189C	PARTICIPANT	\N	PRESENT	0
652010	651587	04092N	PARTICIPANT	\N	PRESENT	0
652012	651587	14213J	PARTICIPANT	\N	PRESENT	0
652013	651587	19723Y	PARTICIPANT	\N	PRESENT	0
652014	651587	19729F	PARTICIPANT	\N	PRESENT	0
651938	651587	14026U	PARTICIPANT	\N	PRESENT	0
651939	651587	05008E	PARTICIPANT	\N	PRESENT	0
652015	651587	19758L	PARTICIPANT	\N	PRESENT	0
652016	651587	19760E	PARTICIPANT	\N	PRESENT	0
652017	651587	20046A	PARTICIPANT	\N	PRESENT	0
652018	651587	19383Y	PARTICIPANT	\N	PRESENT	0
652019	651587	20140W	PARTICIPANT	\N	PRESENT	0
652020	651587	01028R	PARTICIPANT	\N	PRESENT	0
652021	651587	08061X	PARTICIPANT	\N	PRESENT	0
652022	651587	18193Q	PARTICIPANT	\N	PRESENT	0
652023	651587	20144B	PARTICIPANT	\N	PRESENT	0
652024	651587	19701S	PARTICIPANT	\N	PRESENT	0
652025	651587	20024T	PARTICIPANT	\N	PRESENT	0
652026	651587	08010L	PARTICIPANT	\N	PRESENT	0
652027	651587	14033T	PARTICIPANT	\N	PRESENT	0
652028	651587	19683J	PARTICIPANT	\N	PRESENT	0
652029	651587	19621T	PARTICIPANT	\N	PRESENT	0
652030	651587	20070A	PARTICIPANT	\N	PRESENT	0
652031	651587	11045K	PARTICIPANT	\N	PRESENT	0
652032	651587	20052X	PARTICIPANT	\N	PRESENT	0
652033	651587	16685X	PARTICIPANT	\N	PRESENT	0
652034	651587	14071N	PARTICIPANT	\N	PRESENT	0
652035	651587	20264J	PARTICIPANT	\N	PRESENT	0
652036	651587	14069U	PARTICIPANT	\N	PRESENT	0
652037	651587	19251M	PARTICIPANT	\N	PRESENT	0
652038	651587	20026V	PARTICIPANT	\N	PRESENT	0
652039	651587	14179A	PARTICIPANT	\N	PRESENT	0
652040	651587	19489J	PARTICIPANT	\N	PRESENT	0
652041	651587	14237S	PARTICIPANT	\N	PRESENT	0
652042	651587	14083S	PARTICIPANT	\N	PRESENT	0
652043	651587	20298U	PARTICIPANT	\N	PRESENT	0
652044	651587	20112S	PARTICIPANT	\N	PRESENT	0
652045	651587	20080C	PARTICIPANT	\N	PRESENT	0
652046	651587	14225N	PARTICIPANT	\N	PRESENT	0
652047	651587	19762G	PARTICIPANT	\N	PRESENT	0
652048	651587	19413M	PARTICIPANT	\N	PRESENT	0
652049	651587	07029T	PARTICIPANT	\N	PRESENT	0
652050	651587	20096L	PARTICIPANT	\N	PRESENT	0
652149	651574	19954N	PARTICIPANT	\N	PRESENT	1
652150	651574	11033F	PARTICIPANT	\N	PRESENT	1
652151	651574	20114U	PARTICIPANT	\N	PRESENT	1
652152	651574	17737W	PARTICIPANT	\N	PRESENT	1
652153	651574	19629C	PARTICIPANT	\N	PRESENT	1
652154	651574	11056N	PARTICIPANT	\N	PRESENT	1
652155	651574	19489J	PARTICIPANT	\N	PRESENT	1
652156	651574	14147R	PARTICIPANT	\N	PRESENT	1
652157	651574	14107H	PARTICIPANT	\N	PRESENT	1
652158	651574	19675J	PARTICIPANT	\N	PRESENT	1
652163	651574	08018U	PARTICIPANT	\N	EXCUSE	0
652166	650958	18193Q	PARTICIPANT	\N	PRESENT	0
652263	651588	10015M	PARTICIPANT	\N	PRESENT	0
652264	651588	11043H	PARTICIPANT	\N	PRESENT	0
652265	651588	14223L	PARTICIPANT	\N	PRESENT	0
652266	651588	14026U	PARTICIPANT	\N	PRESENT	0
652267	651588	04047H	PARTICIPANT	\N	PRESENT	0
652268	651588	08010L	PARTICIPANT	\N	PRESENT	0
652269	651588	11101A	PARTICIPANT	\N	PRESENT	0
652270	651588	99004R	PARTICIPANT	\N	PRESENT	0
652271	651588	19575F	PARTICIPANT	\N	PRESENT	0
652272	651588	04042C	PARTICIPANT	\N	PRESENT	0
652273	651588	14215L	PARTICIPANT	\N	PRESENT	0
652274	651588	14071N	PARTICIPANT	\N	PRESENT	0
652275	651588	04033B	PARTICIPANT	\N	PRESENT	0
652276	651588	01057W	PARTICIPANT	\N	PRESENT	0
652277	651588	20068G	PARTICIPANT	\N	PRESENT	0
652278	651588	20022R	PARTICIPANT	\N	PRESENT	0
652279	651588	05012A	PARTICIPANT	\N	PRESENT	0
652280	651588	11090Q	PARTICIPANT	\N	PRESENT	0
652281	651588	14237S	PARTICIPANT	\N	PRESENT	0
652282	651588	10006L	PARTICIPANT	\N	PRESENT	0
652283	651588	19533U	PARTICIPANT	\N	PRESENT	0
631595	631578	20068G	PARTICIPANT	\N	PRESENT	0
631596	631578	19703U	PARTICIPANT	\N	PRESENT	0
631597	631578	95063L	PARTICIPANT	\N	PRESENT	0
631598	631578	20050V	PARTICIPANT	\N	PRESENT	0
631599	631578	11097X	PARTICIPANT	\N	PRESENT	0
631600	631578	14259Y	PARTICIPANT	\N	PRESENT	0
631601	631578	11056N	PARTICIPANT	\N	PRESENT	0
631602	631578	19651A	PARTICIPANT	\N	PRESENT	0
631603	631578	19553Y	PARTICIPANT	\N	PRESENT	0
631605	631592	01048V	PARTICIPANT	\N	PRESENT	0
631606	631592	14221J	PARTICIPANT	\N	PRESENT	0
631607	631592	04043D	PARTICIPANT	\N	PRESENT	0
631608	631592	01058X	PARTICIPANT	\N	PRESENT	0
631611	631592	19503N	PARTICIPANT	\N	EXCUSE	0
631612	631592	11067R	PARTICIPANT	\N	EXCUSE	0
631613	631592	19735D	PARTICIPANT	\N	EXCUSE	0
631614	631578	19399H	PARTICIPANT	\N	EXCUSE	0
631615	631578	19551W	PARTICIPANT	\N	EXCUSE	0
631616	631578	20018V	PARTICIPANT	\N	EXCUSE	0
631617	631578	01028R	PARTICIPANT	\N	EXCUSE	0
631618	631578	20132W	PARTICIPANT	\N	PRESENT	0
631807	631806	12041X	PARTICIPANT	\N	PRESENT	0
631808	631806	19820Y	PARTICIPANT	\N	PRESENT	0
631809	631806	19725B	PARTICIPANT	\N	PRESENT	0
631810	631806	14111D	PARTICIPANT	\N	PRESENT	0
631811	631806	19693L	PARTICIPANT	\N	PRESENT	0
631812	631806	20024T	PARTICIPANT	\N	PRESENT	0
631813	631806	19581D	PARTICIPANT	\N	PRESENT	0
631814	631806	20046A	PARTICIPANT	\N	PRESENT	0
631815	631806	19749K	PARTICIPANT	\N	PRESENT	0
631816	631733	20056C	PARTICIPANT	\N	PRESENT	0
631817	631733	19593H	PARTICIPANT	\N	PRESENT	0
631818	631733	19643A	PARTICIPANT	\N	PRESENT	0
631819	631733	20180F	PARTICIPANT	\N	PRESENT	0
631820	631733	19573D	PARTICIPANT	\N	PRESENT	0
631821	631733	20048C	PARTICIPANT	\N	PRESENT	0
631822	631733	08012N	PARTICIPANT	\N	PRESENT	0
631823	631733	20124W	PARTICIPANT	\N	PRESENT	0
631824	631733	19399H	PARTICIPANT	\N	PRESENT	0
631825	631733	19758L	PARTICIPANT	\N	PRESENT	0
631826	631733	20172F	PARTICIPANT	\N	PRESENT	0
631827	631733	20026V	PARTICIPANT	\N	PRESENT	0
631828	631733	11104D	PARTICIPANT	\N	PRESENT	0
631829	631733	11109J	PARTICIPANT	\N	EXCUSE	0
631830	631733	19693L	PARTICIPANT	\N	PRESENT	0
631831	631733	14109K	PARTICIPANT	\N	PRESENT	1
631832	631733	11043H	PARTICIPANT	\N	PRESENT	0
631833	631806	19347U	PARTICIPANT	\N	PRESENT	0
631834	631806	20026V	PARTICIPANT	\N	PRESENT	0
631835	631806	14259Y	PARTICIPANT	\N	PRESENT	0
631836	631806	19573D	PARTICIPANT	\N	PRESENT	0
631837	631733	20134Y	PARTICIPANT	\N	PRESENT	1
631838	631733	14073Q	PARTICIPANT	\N	PRESENT	0
631839	631733	19611R	PARTICIPANT	\N	PRESENT	0
631840	631806	19335Q	PARTICIPANT	\N	PRESENT	0
631841	631806	19679N	PARTICIPANT	\N	PRESENT	0
631937	631562	05008E	PARTICIPANT	\N	PRESENT	0
631938	631562	14089Y	PARTICIPANT	\N	PRESENT	0
631939	631935	19593H	PARTICIPANT	\N	PRESENT	0
631940	631935	19643A	PARTICIPANT	\N	PRESENT	0
631941	631935	20132W	PARTICIPANT	\N	PRESENT	0
631942	631935	19699S	PARTICIPANT	\N	PRESENT	0
631943	631935	20134Y	PARTICIPANT	\N	PRESENT	0
631944	631935	14073Q	PARTICIPANT	\N	PRESENT	0
631945	631935	19611R	PRESIDENT	0	PRESENT	0
631946	631935	20048C	PARTICIPANT	\N	PRESENT	1
631947	631935	19693L	PARTICIPANT	\N	PRESENT	0
631948	631935	20152B	PARTICIPANT	\N	PRESENT	0
631949	631935	14229S	PARTICIPANT	\N	PRESENT	0
631950	631935	14030Q	PARTICIPANT	\N	PRESENT	0
631951	631935	20098N	PARTICIPANT	\N	PRESENT	0
631952	631935	20056C	PARTICIPANT	\N	PRESENT	0
631953	631935	20180F	PARTICIPANT	\N	PRESENT	0
631954	631935	19573D	PARTICIPANT	\N	PRESENT	0
631955	631935	04059M	PARTICIPANT	\N	PRESENT	0
633253	631641	14331P	PARTICIPANT	\N	EXCUSE	0
631957	631935	14109K	PARTICIPANT	\N	PRESENT	1
631958	631935	11104D	PARTICIPANT	\N	PRESENT	0
631959	631935	20124W	PARTICIPANT	\N	PRESENT	0
631960	631935	19758L	PARTICIPANT	\N	PRESENT	0
631961	631935	20026V	PARTICIPANT	\N	PRESENT	0
631962	631935	19621T	PARTICIPANT	\N	PRESENT	0
633244	631111	19367Y	PARTICIPANT	\N	EXCUSE	0
633254	631641	19657G	PARTICIPANT	\N	PRESENT	1
634175	631572	19673G	PARTICIPANT	\N	PRESENT	0
634176	631572	20100N	PARTICIPANT	\N	PRESENT	0
634177	627019	14189C	PARTICIPANT	\N	EXCUSE	0
634178	631572	19611R	PARTICIPANT	\N	PRESENT	0
634173	631572	19693L	PARTICIPANT	\N	PRESENT	0
634174	631572	01024M	PARTICIPANT	\N	PRESENT	0
634201	631573	19611R	PARTICIPANT	\N	PRESENT	0
634202	631573	19621T	PARTICIPANT	\N	PRESENT	0
634203	631573	20134Y	PARTICIPANT	\N	PRESENT	0
634204	631573	19758L	PARTICIPANT	\N	PRESENT	0
634205	631573	19673G	PARTICIPANT	\N	PRESENT	0
634206	631573	11064N	PARTICIPANT	\N	PRESENT	0
634221	631573	19527W	PARTICIPANT	\N	PRESENT	0
634208	631573	20100N	PARTICIPANT	\N	PRESENT	0
634209	631573	20152B	PARTICIPANT	\N	PRESENT	0
634211	634210	05008E	PARTICIPANT	\N	PRESENT	0
634212	634210	11053K	PARTICIPANT	\N	PRESENT	0
634213	634210	01028R	PARTICIPANT	\N	PRESENT	0
634214	631573	20090E	PARTICIPANT	\N	PRESENT	0
634215	631573	20050V	PARTICIPANT	\N	PRESENT	0
634216	631573	14073Q	PARTICIPANT	\N	PRESENT	0
634217	631573	20124W	PARTICIPANT	\N	PRESENT	0
634218	631573	19782L	PARTICIPANT	\N	PRESENT	0
634219	631573	11090Q	PARTICIPANT	\N	PRESENT	0
634220	631573	19695N	PARTICIPANT	\N	PRESENT	0
634222	631573	20144B	PARTICIPANT	\N	PRESENT	0
634199	631573	12041X	PARTICIPANT	\N	PRESENT	0
634200	631573	19573D	PARTICIPANT	\N	PRESENT	0
634223	631573	20132W	PARTICIPANT	\N	PRESENT	0
634224	631573	19701S	PARTICIPANT	\N	PRESENT	0
634225	631573	04057K	PARTICIPANT	\N	PRESENT	0
634226	631573	20174H	PARTICIPANT	\N	PRESENT	0
634227	631573	07029T	PARTICIPANT	\N	PRESENT	0
634229	631573	14059S	PARTICIPANT	\N	PRESENT	0
634246	634026	19866P	PARTICIPANT	\N	EXCUSE	0
634233	634230	20092G	PARTICIPANT	\N	PRESENT	0
634239	631573	20032T	PARTICIPANT	\N	PRESENT	0
634250	631573	20094J	PARTICIPANT	\N	PRESENT	0
634251	631573	14179A	PARTICIPANT	\N	PRESENT	0
634321	634307	20074E	PARTICIPANT	\N	PRESENT	1
634300	631574	20100N	PARTICIPANT	\N	PRESENT	0
634301	631574	20092G	PARTICIPANT	\N	PRESENT	0
634302	631574	20174H	PARTICIPANT	\N	PRESENT	0
634303	631574	20132W	PARTICIPANT	\N	PRESENT	0
634304	631574	14179A	PARTICIPANT	\N	PRESENT	0
634305	631574	19782L	PARTICIPANT	\N	PRESENT	0
634306	631574	01024M	PARTICIPANT	\N	PRESENT	0
634308	631574	19441R	PARTICIPANT	\N	PRESENT	0
634309	631574	20152B	PARTICIPANT	\N	PRESENT	0
634310	631574	14059S	PARTICIPANT	\N	PRESENT	0
634311	631574	20090E	PARTICIPANT	\N	PRESENT	0
634312	631574	20032T	PARTICIPANT	\N	PRESENT	0
634313	631574	97011G	PARTICIPANT	\N	PRESENT	0
634314	631574	14033T	PARTICIPANT	\N	PRESENT	0
634318	631574	11070L	PARTICIPANT	\N	PRESENT	0
634316	631574	11090Q	PARTICIPANT	\N	PRESENT	0
634317	631574	19693L	PARTICIPANT	\N	PRESENT	0
634319	631574	20018V	PARTICIPANT	\N	PRESENT	0
634320	634307	19693L	PARTICIPANT	\N	PRESENT	0
634322	634307	14097Y	PARTICIPANT	\N	PRESENT	0
634323	634307	20050V	PARTICIPANT	\N	PRESENT	0
634324	634307	20082E	PARTICIPANT	\N	PRESENT	0
634325	631574	19695N	PARTICIPANT	\N	PRESENT	0
634333	631574	14251Q	PARTICIPANT	\N	PRESENT	0
634348	631574	19631V	PARTICIPANT	\N	PRESENT	0
634297	631574	20144B	PARTICIPANT	\N	PRESENT	0
634298	631574	20094J	PARTICIPANT	\N	PRESENT	0
634360	631574	14217N	PARTICIPANT	\N	PRESENT	0
634361	631574	20082E	PARTICIPANT	\N	PRESENT	0
634362	631574	14205J	PARTICIPANT	\N	PRESENT	0
634364	631574	19747H	PARTICIPANT	\N	PRESENT	0
634365	631574	19467C	PARTICIPANT	\N	PRESENT	0
634367	631574	19762G	PARTICIPANT	\N	PRESENT	0
647833	646185	19599P	PARTICIPANT	\N	PRESENT	0
647834	646185	19725B	PARTICIPANT	\N	PRESENT	0
647835	646185	19333N	PARTICIPANT	\N	PRESENT	0
647836	646185	19715Y	PARTICIPANT	\N	PRESENT	0
647837	646185	19531S	PARTICIPANT	\N	PRESENT	0
647838	646185	19683J	PARTICIPANT	\N	PRESENT	0
647839	646185	14097Y	PARTICIPANT	\N	PRESENT	0
647840	646185	14021P	PARTICIPANT	\N	PRESENT	0
647841	646185	18193Q	PARTICIPANT	\N	PRESENT	0
647842	646185	17779H	PARTICIPANT	\N	PRESENT	0
647843	646185	12016W	PARTICIPANT	\N	PRESENT	0
647844	646185	14001X	PARTICIPANT	\N	PRESENT	0
647845	646185	20028X	PARTICIPANT	\N	PRESENT	0
647846	646185	11067R	PARTICIPANT	\N	PRESENT	0
647847	646185	20018V	PARTICIPANT	\N	PRESENT	0
647848	646185	14257W	PARTICIPANT	\N	PRESENT	0
647849	646185	20030R	PARTICIPANT	\N	PRESENT	0
647850	646185	17965H	PARTICIPANT	\N	PRESENT	0
647851	646185	19503N	PARTICIPANT	\N	PRESENT	0
647852	646185	14225N	PARTICIPANT	\N	PRESENT	0
647853	646185	20082E	PARTICIPANT	\N	PRESENT	0
647854	646185	14229S	PARTICIPANT	\N	PRESENT	0
647855	646185	11054L	PARTICIPANT	\N	PRESENT	0
647856	646185	11045K	PARTICIPANT	\N	PRESENT	0
647857	646185	20084G	PARTICIPANT	\N	PRESENT	0
647858	646185	01028R	PARTICIPANT	\N	PRESENT	0
647859	646185	19669L	PARTICIPANT	\N	PRESENT	0
647860	646185	19413M	PARTICIPANT	\N	PRESENT	0
647861	646185	01062T	PARTICIPANT	\N	PRESENT	0
647862	646185	20064C	PARTICIPANT	\N	PRESENT	0
647863	646185	11066Q	PARTICIPANT	\N	PRESENT	0
647864	646185	19760E	PARTICIPANT	\N	PRESENT	0
647865	646185	04085P	PARTICIPANT	\N	PRESENT	0
647866	646185	20112S	PARTICIPANT	\N	PRESENT	0
647867	646185	11040E	PARTICIPANT	\N	PRESENT	0
647868	646185	19758L	PARTICIPANT	\N	PRESENT	0
647869	646185	11031D	PARTICIPANT	\N	PRESENT	0
647870	646185	11056N	PARTICIPANT	\N	PRESENT	0
647871	646185	19695N	PARTICIPANT	\N	PRESENT	0
647872	646185	19565D	PARTICIPANT	\N	PRESENT	0
647873	646185	07029T	PARTICIPANT	\N	PRESENT	0
647874	646185	11077T	PARTICIPANT	\N	PRESENT	0
647875	646185	19593H	PARTICIPANT	\N	PRESENT	0
647876	646185	19687N	PARTICIPANT	\N	PRESENT	0
647877	646185	20046A	PARTICIPANT	\N	PRESENT	0
647878	646185	11033F	PARTICIPANT	\N	PRESENT	0
647879	646185	20110Q	PARTICIPANT	\N	PRESENT	0
647880	646185	20914V	PARTICIPANT	\N	PRESENT	0
647881	646185	11065P	PARTICIPANT	\N	PRESENT	0
647882	646185	20134Y	PARTICIPANT	\N	PRESENT	0
647883	646185	20100N	PARTICIPANT	\N	PRESENT	0
647884	646185	19347U	PARTICIPANT	\N	PRESENT	0
647885	646185	11099A	PARTICIPANT	\N	PRESENT	0
647886	646185	20142Y	PARTICIPANT	\N	PRESENT	0
647887	646185	20036X	PARTICIPANT	\N	PRESENT	0
647888	646185	20130U	PARTICIPANT	\N	PRESENT	0
647889	646185	20092G	PARTICIPANT	\N	PRESENT	0
647890	646185	20266L	PARTICIPANT	\N	PRESENT	0
647891	646185	19651A	PARTICIPANT	\N	PRESENT	0
647892	646185	19782L	PARTICIPANT	\N	PRESENT	0
647893	646185	19057M	PARTICIPANT	\N	PRESENT	0
647894	646185	19525U	PARTICIPANT	\N	PRESENT	0
647895	646185	19659J	PARTICIPANT	\N	PRESENT	0
647896	646185	14249W	PARTICIPANT	\N	PRESENT	0
647897	646185	20106U	PARTICIPANT	\N	PRESENT	0
647898	646185	19591F	PARTICIPANT	\N	PRESENT	0
647899	646185	14037X	PARTICIPANT	\N	PRESENT	0
647900	646185	19697Q	PARTICIPANT	\N	PRESENT	0
647901	646185	08061X	PARTICIPANT	\N	PRESENT	0
647902	646185	19349W	PARTICIPANT	\N	PRESENT	0
647903	646185	95063L	PARTICIPANT	\N	PRESENT	0
647904	646185	19301E	PARTICIPANT	\N	PRESENT	0
647905	646185	14195A	PARTICIPANT	\N	PRESENT	0
647906	646185	19583F	PARTICIPANT	\N	PRESENT	0
647907	646185	14251Q	PARTICIPANT	\N	PRESENT	0
647908	646185	14111D	PARTICIPANT	\N	PRESENT	0
647909	646185	19563B	PARTICIPANT	\N	PRESENT	0
647910	646185	20050V	PARTICIPANT	\N	PRESENT	0
647911	646185	20122U	PARTICIPANT	\N	PRESENT	0
647912	646185	19717B	PARTICIPANT	\N	PRESENT	0
647913	646185	20116W	PARTICIPANT	\N	PRESENT	0
647914	646185	14207L	PARTICIPANT	\N	PRESENT	0
647915	646185	19629C	PARTICIPANT	\N	PRESENT	0
647916	646185	19681G	PARTICIPANT	\N	PRESENT	0
647917	646185	19719D	PARTICIPANT	\N	PRESENT	0
647918	646185	20132W	PARTICIPANT	\N	PRESENT	0
647919	646185	19387D	PARTICIPANT	\N	PRESENT	0
647920	646185	98022P	PARTICIPANT	\N	PRESENT	0
647921	646185	19553Y	PARTICIPANT	\N	PRESENT	0
647922	646185	20072C	PARTICIPANT	\N	PRESENT	0
647923	646185	19866P	PARTICIPANT	\N	PRESENT	0
647924	646185	11012A	PARTICIPANT	\N	PRESENT	0
647925	646185	14107H	PARTICIPANT	\N	PRESENT	0
647927	647926	14147R	PARTICIPANT	\N	PRESENT	0
647928	647926	19725B	PARTICIPANT	\N	PRESENT	0
648012	648011	14033T	PARTICIPANT	\N	PRESENT	0
648013	648011	14205J	PARTICIPANT	\N	PRESENT	0
648015	648011	08028W	PARTICIPANT	\N	PRESENT	0
648016	648011	20018V	PARTICIPANT	\N	PRESENT	0
648017	648011	20054A	PARTICIPANT	\N	PRESENT	0
648018	648011	20092G	PARTICIPANT	\N	PRESENT	0
648019	648011	19782L	PARTICIPANT	\N	PRESENT	0
648020	648011	14207L	PARTICIPANT	\N	PRESENT	0
648185	648164	17637T	PARTICIPANT	\N	PRESENT	0
648186	648164	05012A	PARTICIPANT	\N	PRESENT	0
648187	648164	14215L	PARTICIPANT	\N	PRESENT	0
648190	648164	08010L	PARTICIPANT	\N	EXCUSE	0
648191	648164	20122U	PARTICIPANT	\N	EXCUSE	0
648201	648164	04045F	PARTICIPANT	\N	PRESENT	0
648205	648164	20058E	PARTICIPANT	\N	PRESENT	0
648234	647645	14133K	PARTICIPANT	\N	PRESENT	0
648238	647645	19631V	PARTICIPANT	\N	PRESENT	0
648239	647645	04085P	PARTICIPANT	\N	PRESENT	0
648240	647645	19515S	PARTICIPANT	\N	PRESENT	0
648242	647645	20076G	PARTICIPANT	\N	PRESENT	0
648244	647645	05008E	PARTICIPANT	\N	PRESENT	0
648246	647645	20024T	PARTICIPANT	\N	PRESENT	0
648247	647645	20022R	PARTICIPANT	\N	PRESENT	0
648249	647645	19954N	PARTICIPANT	\N	PRESENT	0
648250	647645	20110Q	PARTICIPANT	\N	PRESENT	0
648254	647645	20116W	PARTICIPANT	\N	PRESENT	0
648256	647645	14030Q	PARTICIPANT	\N	PRESENT	0
648257	647645	20086J	PARTICIPANT	\N	PRESENT	0
648258	647645	17367Q	PARTICIPANT	\N	PRESENT	0
648260	647645	14069U	PARTICIPANT	\N	PRESENT	0
648261	647645	19415P	PARTICIPANT	\N	PRESENT	0
648263	647645	20088L	PARTICIPANT	\N	PRESENT	0
648265	647645	19747H	PARTICIPANT	\N	PRESENT	0
648266	647645	20152B	PARTICIPANT	\N	PRESENT	0
648267	647645	19383Y	PARTICIPANT	\N	PRESENT	0
648268	647645	17737W	PARTICIPANT	\N	PRESENT	0
648270	647645	19758L	PARTICIPANT	\N	PRESENT	0
648271	647645	04047H	PARTICIPANT	\N	PRESENT	0
648274	647645	19782L	PARTICIPANT	\N	PRESENT	0
648278	647645	20090E	PARTICIPANT	\N	PRESENT	0
648279	647645	20914V	PARTICIPANT	\N	PRESENT	0
648281	647645	04042C	PARTICIPANT	\N	PRESENT	0
648282	647645	14053L	PARTICIPANT	\N	PRESENT	0
648283	647645	14083S	PARTICIPANT	\N	PRESENT	0
648285	647645	19545Y	PARTICIPANT	\N	PRESENT	0
648287	647645	11103C	PARTICIPANT	\N	PRESENT	0
648288	647645	12028B	PARTICIPANT	\N	PRESENT	0
648289	647645	14038Y	PARTICIPANT	\N	PRESENT	0
648290	647645	08028W	PARTICIPANT	\N	PRESENT	0
648292	647645	19467C	PARTICIPANT	\N	PRESENT	0
648293	647645	20144B	PARTICIPANT	\N	PRESENT	0
648294	647645	18083K	PARTICIPANT	\N	PRESENT	0
648295	647645	19701S	PARTICIPANT	\N	PRESENT	0
648296	647645	19681G	PARTICIPANT	\N	PRESENT	0
648297	647645	11056N	PARTICIPANT	\N	PRESENT	0
648298	647645	11070L	PARTICIPANT	\N	PRESENT	0
648299	647645	19719D	PARTICIPANT	\N	PRESENT	0
648300	647645	19659J	PARTICIPANT	\N	PRESENT	0
648301	647645	14215L	PARTICIPANT	\N	PRESENT	0
648302	647645	19507S	PARTICIPANT	\N	PRESENT	0
648303	647645	20134Y	PARTICIPANT	\N	PRESENT	0
648304	647645	20124W	PARTICIPANT	\N	PRESENT	0
648305	647645	14151M	PARTICIPANT	\N	PRESENT	0
648306	647645	14249W	PARTICIPANT	\N	PRESENT	0
648307	647645	14187A	PARTICIPANT	\N	PRESENT	0
648308	647645	19673G	PARTICIPANT	\N	PRESENT	0
629214	627075	04059M	PARTICIPANT	\N	PRESENT	0
629215	627075	19651A	PARTICIPANT	\N	PRESENT	1
629235	627076	04059M	PARTICIPANT	\N	PRESENT	0
629236	627076	19651A	PARTICIPANT	\N	PRESENT	1
631475	631474	19251M	PARTICIPANT	\N	PRESENT	0
629219	627075	11053K	PARTICIPANT	\N	PRESENT	0
631476	631474	19593H	PARTICIPANT	\N	PRESENT	0
631477	631474	20084G	PARTICIPANT	\N	PRESENT	0
629239	627076	19621T	PARTICIPANT	\N	PRESENT	0
629240	627076	11053K	PARTICIPANT	\N	PRESENT	0
629224	627075	19399H	PARTICIPANT	\N	PRESENT	0
629225	627075	20056C	PARTICIPANT	\N	PRESENT	1
629226	627075	19611R	PRESIDENT	0	PRESENT	0
629227	627075	19699S	PARTICIPANT	\N	PRESENT	1
631478	631474	14255U	PARTICIPANT	\N	PRESENT	0
629229	627075	20142Y	PARTICIPANT	\N	PRESENT	0
629230	627075	19705W	PARTICIPANT	\N	PRESENT	1
629231	627075	14229S	PARTICIPANT	\N	PRESENT	0
631480	631474	11026G	PARTICIPANT	\N	PRESENT	0
631482	631474	17737W	PARTICIPANT	\N	PRESENT	0
631484	631474	19782L	PARTICIPANT	\N	PRESENT	0
629244	627076	19725B	PARTICIPANT	\N	PRESENT	1
629245	627076	19399H	PARTICIPANT	\N	PRESENT	0
629246	627076	20056C	PARTICIPANT	\N	PRESENT	1
629247	627076	19611R	PRESIDENT	0	PRESENT	0
629248	627076	19699S	PARTICIPANT	\N	PRESENT	0
631486	631474	19515S	PARTICIPANT	\N	PRESENT	0
629250	627076	20142Y	PARTICIPANT	\N	PRESENT	0
629251	627076	19705W	PARTICIPANT	\N	PRESENT	1
629252	627076	14229S	PARTICIPANT	\N	PRESENT	0
629253	627076	19669L	PARTICIPANT	\N	PRESENT	1
631487	631474	19647E	PARTICIPANT	\N	PRESENT	0
631488	631474	14179A	PARTICIPANT	\N	PRESENT	0
631489	631474	11064N	PARTICIPANT	\N	PRESENT	0
631491	631490	08069G	PARTICIPANT	\N	PRESENT	0
631492	631490	20024T	PARTICIPANT	\N	PRESENT	0
631493	631490	11026G	PARTICIPANT	\N	PRESENT	0
637249	637241	19467C	PARTICIPANT	\N	PRESENT	0
637250	637241	19515S	PARTICIPANT	\N	PRESENT	0
637251	637241	20092G	PARTICIPANT	\N	PRESENT	0
637252	637241	14357A	PARTICIPANT	\N	PRESENT	0
637253	637241	19413M	PARTICIPANT	\N	PRESENT	0
637254	637241	11090Q	PRESIDENT	0	PRESENT	0
637255	637241	14033T	PARTICIPANT	\N	PRESENT	0
637256	637241	20174H	PARTICIPANT	\N	PRESENT	1
637257	637241	20062A	PARTICIPANT	\N	PRESENT	0
637258	637241	19507S	PARTICIPANT	\N	PRESENT	0
637259	637241	08015R	PARTICIPANT	\N	PRESENT	0
637260	637241	20286Q	PARTICIPANT	\N	PRESENT	0
637261	637241	19369B	PARTICIPANT	\N	PRESENT	0
637262	637241	20018V	PARTICIPANT	\N	PRESENT	0
637263	637241	14257W	PARTICIPANT	\N	PRESENT	0
637264	634659	14053L	PARTICIPANT	\N	PRESENT	0
637265	634659	19745F	PARTICIPANT	\N	PRESENT	0
637267	634659	20082E	PARTICIPANT	\N	PRESENT	0
637269	634659	19667J	PARTICIPANT	\N	PRESENT	0
637270	634659	20052X	PARTICIPANT	\N	PRESENT	0
637272	634659	19701S	PARTICIPANT	\N	PRESENT	0
637300	634659	11056N	PARTICIPANT	\N	PRESENT	0
637703	634662	19695N	PARTICIPANT	\N	PRESENT	0
637704	634662	19691J	PARTICIPANT	\N	PRESENT	0
637705	634662	19441R	PARTICIPANT	\N	PRESENT	0
637706	634662	20174H	PARTICIPANT	\N	PRESENT	0
637707	634662	07029T	PARTICIPANT	\N	PRESENT	0
637708	634662	19768N	PARTICIPANT	\N	PRESENT	0
637709	634662	18083K	PARTICIPANT	\N	PRESENT	0
637710	634662	14215L	PARTICIPANT	\N	PRESENT	0
637711	634662	11012A	PARTICIPANT	\N	PRESENT	0
637712	634662	19631V	PARTICIPANT	\N	PRESENT	0
637713	634662	19611R	PARTICIPANT	\N	PRESENT	0
637714	634662	11090Q	PARTICIPANT	\N	PRESENT	0
637715	634662	14021P	PARTICIPANT	\N	PRESENT	0
637750	634663	19768N	PARTICIPANT	\N	PRESENT	0
637751	634663	20286Q	PARTICIPANT	\N	PRESENT	0
637752	634663	19691J	PARTICIPANT	\N	PRESENT	0
637753	634663	19441R	PARTICIPANT	\N	PRESENT	0
637754	634663	11012A	PARTICIPANT	\N	PRESENT	0
637755	634663	19629C	PARTICIPANT	\N	PRESENT	0
637756	634663	20152B	PARTICIPANT	\N	PRESENT	0
637757	634663	19507S	PARTICIPANT	\N	PRESENT	0
637758	634663	11090Q	PARTICIPANT	\N	PRESENT	0
637759	634663	19631V	PARTICIPANT	\N	PRESENT	0
637760	634663	20064C	PARTICIPANT	\N	PRESENT	0
637761	634663	20082E	PARTICIPANT	\N	PRESENT	0
637762	634663	20088L	PARTICIPANT	\N	PRESENT	0
637763	634663	19715Y	PARTICIPANT	\N	PRESENT	0
637764	634663	20092G	PARTICIPANT	\N	PRESENT	0
637765	634663	19563B	PARTICIPANT	\N	PRESENT	0
637766	634663	14215L	PARTICIPANT	\N	PRESENT	0
637767	634663	20174H	PARTICIPANT	\N	PRESENT	0
637768	634663	11056N	PARTICIPANT	\N	PRESENT	0
637769	634663	19695N	PARTICIPANT	\N	PRESENT	0
637772	634663	14026U	PARTICIPANT	\N	PRESENT	0
637806	634663	04085P	PARTICIPANT	\N	PRESENT	0
637807	634663	19577H	PARTICIPANT	\N	PRESENT	0
637811	634663	19693L	PARTICIPANT	\N	PRESENT	0
637837	634664	20088L	PARTICIPANT	\N	PRESENT	0
637838	634664	20082E	PARTICIPANT	\N	PRESENT	0
637839	634664	04085P	PARTICIPANT	\N	PRESENT	0
637842	634664	20174H	PARTICIPANT	\N	PRESENT	0
637844	634664	11056N	PARTICIPANT	\N	PRESENT	0
637846	634664	19695N	PARTICIPANT	\N	PRESENT	0
637849	634664	11090Q	PARTICIPANT	\N	PRESENT	0
637851	634664	19629C	PARTICIPANT	\N	PRESENT	0
637748	634663	11045K	PARTICIPANT	\N	PRESENT	0
637749	634663	20062A	PARTICIPANT	\N	PRESENT	0
637852	634664	11012A	PARTICIPANT	\N	PRESENT	0
637853	634664	19563B	PARTICIPANT	\N	PRESENT	0
637854	634664	14215L	PARTICIPANT	\N	PRESENT	0
637855	634664	20062A	PARTICIPANT	\N	PRESENT	0
637856	634664	14026U	PARTICIPANT	\N	PRESENT	0
637857	634664	20134Y	PARTICIPANT	\N	PRESENT	0
637858	634664	19693L	PARTICIPANT	\N	PRESENT	0
637859	634664	19768N	PARTICIPANT	\N	PRESENT	0
637860	634664	20286Q	PARTICIPANT	\N	PRESENT	0
638379	638309	18083K	PRESIDENT	0	PRESENT	0
638380	638309	19701S	PARTICIPANT	\N	PRESENT	0
638381	638309	20266L	PARTICIPANT	\N	PRESENT	0
639646	639587	19643A	PARTICIPANT	\N	EXCUSE	0
639647	639587	11097X	PARTICIPANT	\N	PRESENT	0
639651	639650	20094J	PARTICIPANT	\N	PRESENT	0
637835	634664	11045K	PARTICIPANT	\N	PRESENT	0
637836	634664	19631V	PARTICIPANT	\N	PRESENT	0
639652	639650	01048V	PARTICIPANT	\N	PRESENT	0
639653	639650	14059S	PARTICIPANT	\N	PRESENT	0
639654	639650	05012A	PARTICIPANT	\N	PRESENT	0
639655	639650	19503N	PARTICIPANT	\N	PRESENT	0
639656	639650	19713W	PARTICIPANT	\N	PRESENT	0
639657	639650	20064C	PARTICIPANT	\N	PRESENT	0
639675	639587	01028R	PARTICIPANT	\N	EXCUSE	0
639688	639687	19717B	PARTICIPANT	\N	EXCUSE	0
639689	639687	14031R	PARTICIPANT	\N	PRESENT	1
639690	639687	20150Y	PARTICIPANT	\N	PRESENT	1
639691	639687	20034V	PARTICIPANT	\N	EXCUSE	0
639692	639687	14083S	PRESIDENT	0	PRESENT	0
639693	639687	20102Q	PARTICIPANT	\N	PRESENT	0
639694	639687	19503N	PARTICIPANT	\N	PRESENT	1
639695	639687	20100N	PARTICIPANT	\N	PRESENT	0
639709	639706	19745F	PARTICIPANT	\N	PRESENT	0
639711	639710	19745F	PARTICIPANT	\N	PRESENT	0
639713	639712	19745F	PARTICIPANT	\N	PRESENT	0
640052	640051	05008E	PARTICIPANT	\N	PRESENT	0
640520	639316	14030Q	PRESIDENT	0	PRESENT	0
640525	639316	19715Y	PARTICIPANT	\N	PRESENT	0
640527	639316	11045K	PARTICIPANT	\N	PRESENT	0
640529	639316	20024T	PARTICIPANT	\N	PRESENT	0
640532	639316	20138D	PARTICIPANT	\N	PRESENT	0
640534	639316	20080C	PARTICIPANT	\N	EXCUSE	0
640535	639316	20118Y	PARTICIPANT	\N	EXCUSE	0
640536	639316	20098N	PARTICIPANT	\N	EXCUSE	0
640537	639316	11031D	PARTICIPANT	\N	PRESENT	0
640555	639316	14179A	PARTICIPANT	\N	PRESENT	1
640560	639316	07029T	PARTICIPANT	\N	PRESENT	0
640577	639316	19693L	PARTICIPANT	\N	PRESENT	0
650021	650020	16685X	PARTICIPANT	\N	PRESENT	0
650022	650020	20024T	PARTICIPANT	\N	PRESENT	0
650023	650020	14083S	PARTICIPANT	\N	PRESENT	0
650256	647959	20082E	PARTICIPANT	\N	PRESENT	0
651276	650242	01057W	PARTICIPANT	\N	PRESENT	0
651277	650242	19758L	PARTICIPANT	\N	PRESENT	0
651278	650242	19820Y	PARTICIPANT	\N	PRESENT	0
651279	650242	20022R	PARTICIPANT	\N	PRESENT	0
651280	650242	19489J	PARTICIPANT	\N	PRESENT	0
651281	650242	14107H	PARTICIPANT	\N	PRESENT	0
651282	650242	19735D	PARTICIPANT	\N	PRESENT	0
651283	650242	20122U	PARTICIPANT	\N	PRESENT	0
651284	650242	19711U	PARTICIPANT	\N	PRESENT	0
651285	650242	14217N	PARTICIPANT	\N	EXCUSE	0
651286	650242	20120S	PARTICIPANT	\N	EXCUSE	0
651287	650242	19333N	PARTICIPANT	\N	EXCUSE	0
651288	650242	19447X	PARTICIPANT	\N	EXCUSE	0
651289	650242	19826F	PARTICIPANT	\N	EXCUSE	0
651290	650242	19563B	PARTICIPANT	\N	EXCUSE	0
651291	650242	20084G	PARTICIPANT	\N	EXCUSE	0
651292	650242	14173T	PARTICIPANT	\N	EXCUSE	0
651306	650242	20058E	PARTICIPANT	\N	PRESENT	0
651307	650242	19782L	PARTICIPANT	\N	PRESENT	0
651320	650242	04045F	PARTICIPANT	\N	PRESENT	0
651358	649061	14133K	PARTICIPANT	\N	PRESENT	1
651376	649061	20104S	PARTICIPANT	\N	PRESENT	0
651404	651403	19515S	PRESIDENT	0	PRESENT	0
651363	649061	20286Q	PARTICIPANT	\N	PRESENT	0
651364	649061	11083R	PARTICIPANT	\N	PRESENT	1
651365	649061	14033T	PARTICIPANT	\N	PRESENT	0
651366	649061	19333N	PARTICIPANT	\N	PRESENT	0
651367	649061	14001X	PARTICIPANT	\N	PRESENT	0
651368	649061	04070G	PARTICIPANT	\N	PRESENT	0
651369	649061	14169X	PARTICIPANT	\N	PRESENT	0
651370	649061	19593H	PARTICIPANT	\N	PRESENT	0
651372	649061	14331P	PRESIDENT	0	PRESENT	0
651373	649061	10015M	PARTICIPANT	\N	PRESENT	1
651374	649061	04045F	PARTICIPANT	\N	PRESENT	1
651405	651403	20094J	PARTICIPANT	\N	PRESENT	0
651406	651403	14083S	PARTICIPANT	\N	PRESENT	0
651407	651403	20060X	PARTICIPANT	\N	PRESENT	0
651409	651403	14329V	PARTICIPANT	\N	PRESENT	0
651410	651403	19467C	PARTICIPANT	\N	PRESENT	0
651411	651403	19251M	PARTICIPANT	\N	PRESENT	0
651412	651403	14026U	PARTICIPANT	\N	PRESENT	0
651413	651403	20126Y	PARTICIPANT	\N	PRESENT	0
651414	651403	16685X	PARTICIPANT	\N	PRESENT	0
651415	651403	19671E	PARTICIPANT	\N	PRESENT	0
651417	651403	20054A	PARTICIPANT	\N	PRESENT	0
651418	651403	20092G	PARTICIPANT	\N	PRESENT	0
651419	651403	19762G	PARTICIPANT	\N	PRESENT	0
651424	651403	19760E	PARTICIPANT	\N	EXCUSE	0
651425	651403	19717B	PARTICIPANT	\N	EXCUSE	0
651426	651403	19575F	PARTICIPANT	\N	EXCUSE	0
651427	651403	14030Q	PARTICIPANT	\N	EXCUSE	0
651428	651421	20128B	PARTICIPANT	\N	PRESENT	0
651429	651403	08060W	PARTICIPANT	\N	EXCUSE	0
651430	651403	14105F	PARTICIPANT	\N	EXCUSE	0
651431	651403	19545Y	PARTICIPANT	\N	EXCUSE	0
651432	651403	08028W	PARTICIPANT	\N	EXCUSE	0
651433	651403	14357A	PARTICIPANT	\N	EXCUSE	0
651434	651403	20040T	PARTICIPANT	\N	EXCUSE	0
651435	651403	20048C	PARTICIPANT	\N	EXCUSE	0
651436	651403	08015R	PARTICIPANT	\N	EXCUSE	0
651437	651403	19697Q	PARTICIPANT	\N	EXCUSE	0
651438	651403	14031R	PARTICIPANT	\N	EXCUSE	0
651439	651403	19369B	PARTICIPANT	\N	EXCUSE	0
651440	651403	19301E	PARTICIPANT	\N	EXCUSE	0
651447	651445	20082E	PARTICIPANT	\N	PRESENT	0
651448	651445	19667J	PARTICIPANT	\N	PRESENT	0
651449	651445	19467C	PARTICIPANT	\N	PRESENT	0
651450	651445	20090E	PARTICIPANT	\N	PRESENT	0
651451	651445	20066E	PARTICIPANT	\N	PRESENT	0
651452	651445	20038A	PARTICIPANT	\N	PRESENT	0
651649	651648	11048N	PARTICIPANT	\N	PRESENT	0
651650	651648	14121F	PARTICIPANT	\N	PRESENT	0
651651	650988	14225N	PRESIDENT	0	PRESENT	0
651652	650988	12016W	PARTICIPANT	\N	PRESENT	0
651653	650988	20914V	PARTICIPANT	\N	PRESENT	0
651654	650988	14327T	PARTICIPANT	\N	PRESENT	0
651655	650988	11048N	PARTICIPANT	\N	PRESENT	0
651656	650988	04071H	PARTICIPANT	\N	PRESENT	0
651657	650988	19647E	PARTICIPANT	\N	PRESENT	0
651658	650988	19479G	PARTICIPANT	\N	PRESENT	0
651659	650988	19711U	PARTICIPANT	\N	PRESENT	0
651660	650988	19687N	PARTICIPANT	\N	PRESENT	0
651661	650988	11053K	PARTICIPANT	\N	PRESENT	0
651662	650988	19667J	PARTICIPANT	\N	PRESENT	0
651663	650988	07029T	PARTICIPANT	\N	PRESENT	0
651664	650988	20070A	PARTICIPANT	\N	PRESENT	0
651665	650988	99004R	PARTICIPANT	\N	PRESENT	0
651666	650988	11070L	PARTICIPANT	\N	PRESENT	0
651667	649319	18083K	PARTICIPANT	\N	PRESENT	0
651668	649319	20136B	PARTICIPANT	\N	PRESENT	0
651669	649319	14031R	PARTICIPANT	\N	PRESENT	0
651670	649319	14219Q	PRESIDENT	0	PRESENT	0
651671	649319	19599P	PARTICIPANT	\N	PRESENT	0
651672	649319	19577H	PARTICIPANT	\N	PRESENT	0
651673	649319	20024T	PARTICIPANT	\N	PRESENT	0
651674	649319	11065P	PARTICIPANT	\N	PRESENT	0
651675	649319	20096L	PARTICIPANT	\N	PRESENT	0
651676	649319	20120S	PARTICIPANT	\N	PRESENT	0
651677	649319	20106U	PARTICIPANT	\N	PRESENT	0
651678	650988	19741B	PARTICIPANT	\N	PRESENT	1
651679	650988	11040E	PARTICIPANT	\N	PRESENT	1
651680	650988	20080C	PARTICIPANT	\N	PRESENT	1
651681	650988	14083S	PARTICIPANT	\N	PRESENT	1
651682	650988	19545Y	PARTICIPANT	\N	PRESENT	1
651683	650988	01057W	PARTICIPANT	\N	PRESENT	1
651684	650988	20126Y	PARTICIPANT	\N	PRESENT	1
651685	650988	08009T	PARTICIPANT	\N	PRESENT	1
651686	650988	19671E	PARTICIPANT	\N	PRESENT	1
651687	650988	20050V	PARTICIPANT	\N	PRESENT	1
651688	650988	20036X	PARTICIPANT	\N	PRESENT	1
651689	650988	19349W	PARTICIPANT	\N	PRESENT	1
651690	650988	19762G	PARTICIPANT	\N	PRESENT	1
651691	650988	11012A	PARTICIPANT	\N	EXCUSE	0
652065	650958	10006L	PRESIDENT	0	PRESENT	0
652066	650958	14217N	PARTICIPANT	\N	PRESENT	0
652067	650958	11067R	PARTICIPANT	\N	PRESENT	0
652068	650958	19683J	PARTICIPANT	\N	PRESENT	0
652069	650958	17965H	PARTICIPANT	\N	PRESENT	0
652070	650958	20040T	PARTICIPANT	\N	PRESENT	0
652071	650958	20066E	PARTICIPANT	\N	PRESENT	0
652072	650958	19679N	PARTICIPANT	\N	PRESENT	0
652073	650958	14213J	PARTICIPANT	\N	PRESENT	0
652074	650958	04092N	PARTICIPANT	\N	PRESENT	0
652075	650958	19703U	PARTICIPANT	\N	PRESENT	0
652076	650958	20090E	PARTICIPANT	\N	PRESENT	0
652077	650958	14223L	PARTICIPANT	\N	PRESENT	0
652078	650958	04057K	PARTICIPANT	\N	PRESENT	0
652079	650958	19723Y	PARTICIPANT	\N	PRESENT	1
652080	650958	11103C	PARTICIPANT	\N	PRESENT	1
652081	650958	20248J	PARTICIPANT	\N	PRESENT	1
652082	650958	19798U	PARTICIPANT	\N	PRESENT	1
652083	650958	19569H	PARTICIPANT	\N	PRESENT	1
652084	650958	19301E	PARTICIPANT	\N	PRESENT	0
652085	650958	11031D	PARTICIPANT	\N	PRESENT	0
652086	650958	14042U	PARTICIPANT	\N	PRESENT	0
652087	650958	19591F	PARTICIPANT	\N	PRESENT	0
652089	652088	19383Y	PARTICIPANT	\N	PRESENT	0
652090	652088	20088L	PARTICIPANT	\N	PRESENT	0
652091	652088	19768N	PARTICIPANT	\N	PRESENT	0
652092	652088	20092G	PARTICIPANT	\N	PRESENT	0
652093	652088	19413M	PARTICIPANT	\N	PRESENT	0
652094	652088	20082E	PARTICIPANT	\N	PRESENT	0
652095	652088	19866P	PARTICIPANT	\N	PRESENT	0
652096	652088	20104S	PARTICIPANT	\N	PRESENT	0
652097	652088	19705W	PARTICIPANT	\N	PRESENT	0
652098	652088	19575F	PARTICIPANT	\N	PRESENT	0
652099	652088	20018V	PARTICIPANT	\N	PRESENT	0
652100	652088	19511N	PARTICIPANT	\N	PRESENT	0
652101	652088	20028X	PARTICIPANT	\N	PRESENT	0
652102	652088	20030R	PARTICIPANT	\N	PRESENT	0
652103	652088	14038Y	PARTICIPANT	\N	PRESENT	0
652104	652088	19467C	PARTICIPANT	\N	PRESENT	0
652105	652088	20034V	PARTICIPANT	\N	PRESENT	0
652106	652088	19695N	PARTICIPANT	\N	PRESENT	0
652107	652088	11090Q	PRESIDENT	0	PRESENT	0
652108	652088	14033T	PARTICIPANT	\N	PRESENT	0
652109	652088	20054A	PARTICIPANT	\N	PRESENT	0
645487	645146	14147R	PARTICIPANT	\N	PRESENT	1
645488	645146	95063L	PARTICIPANT	\N	PRESENT	0
645489	645146	01028R	PARTICIPANT	\N	PRESENT	0
645519	645518	07029T	PARTICIPANT	\N	PRESENT	0
645521	645520	07029T	PARTICIPANT	\N	PRESENT	0
646475	646154	14021P	PARTICIPANT	\N	PRESENT	0
646476	646154	11033F	PARTICIPANT	\N	PRESENT	0
646477	645739	05012A	PARTICIPANT	\N	PRESENT	0
646478	645739	11065P	PARTICIPANT	\N	PRESENT	0
646479	646187	20086J	PARTICIPANT	\N	PRESENT	0
646480	646187	11048N	PARTICIPANT	\N	PRESENT	0
646481	646187	19711U	PARTICIPANT	\N	PRESENT	0
646482	646187	08034U	PARTICIPANT	\N	PRESENT	0
646483	646187	19687N	PARTICIPANT	\N	PRESENT	0
646484	646187	11074Q	PARTICIPANT	\N	PRESENT	0
646485	646187	20044X	PARTICIPANT	\N	PRESENT	0
646486	646187	14225N	PRESIDENT	0	PRESENT	0
646487	646187	11070L	PARTICIPANT	\N	PRESENT	0
646488	646187	11040E	PARTICIPANT	\N	PRESENT	0
646489	646187	14083S	PARTICIPANT	\N	PRESENT	0
646490	646187	11012A	PARTICIPANT	\N	PRESENT	0
646491	646187	08009T	PARTICIPANT	\N	PRESENT	0
646492	646187	19349W	PARTICIPANT	\N	PRESENT	0
646493	646187	19741B	PARTICIPANT	\N	PRESENT	0
646494	646187	08010L	PARTICIPANT	\N	PRESENT	0
646495	646187	99004R	PARTICIPANT	\N	PRESENT	0
646496	646187	20116W	PARTICIPANT	\N	PRESENT	0
646497	646187	20126Y	PARTICIPANT	\N	PRESENT	0
646498	646187	19762G	PARTICIPANT	\N	PRESENT	0
646499	646187	14331P	PARTICIPANT	\N	PRESENT	0
646500	646187	19479G	PARTICIPANT	\N	PRESENT	0
646501	646187	20080C	PARTICIPANT	\N	PRESENT	0
646502	646187	08011M	PARTICIPANT	\N	PRESENT	0
646503	646154	19954N	PARTICIPANT	\N	PRESENT	0
646504	646187	14189C	PARTICIPANT	\N	PRESENT	0
646592	646248	19383Y	PARTICIPANT	\N	PRESENT	0
646593	646248	19768N	PARTICIPANT	\N	PRESENT	0
646594	646248	20088L	PARTICIPANT	\N	PRESENT	0
646595	646248	19515S	PARTICIPANT	\N	PRESENT	0
646596	646248	19782L	PARTICIPANT	\N	PRESENT	0
646597	646248	11077T	PARTICIPANT	\N	PRESENT	0
646598	646248	20092G	PARTICIPANT	\N	PRESENT	0
646599	646248	01043Q	PARTICIPANT	\N	PRESENT	1
646600	646248	14357A	PARTICIPANT	\N	PRESENT	0
646601	646248	20078J	PARTICIPANT	\N	PRESENT	0
646602	646248	19413M	PARTICIPANT	\N	PRESENT	0
646603	646248	20082E	PARTICIPANT	\N	PRESENT	0
646604	646248	20094J	PARTICIPANT	\N	PRESENT	0
646605	646248	04045F	PARTICIPANT	\N	PRESENT	1
646606	646248	19866P	PARTICIPANT	\N	PRESENT	0
646607	646248	20104S	PARTICIPANT	\N	PRESENT	0
646608	646248	19631V	PARTICIPANT	\N	PRESENT	0
646609	646248	11099A	PARTICIPANT	\N	PRESENT	0
646610	646248	19707Y	PARTICIPANT	\N	PRESENT	1
646611	646248	08015R	PARTICIPANT	\N	PRESENT	1
646612	646248	19575F	PARTICIPANT	\N	PRESENT	0
646613	646248	19369B	PARTICIPANT	\N	PRESENT	0
646614	646248	20018V	PARTICIPANT	\N	PRESENT	0
646615	646248	19511N	PARTICIPANT	\N	PRESENT	0
646616	646248	08028W	PARTICIPANT	\N	PRESENT	0
646617	646248	19563B	PARTICIPANT	\N	PRESENT	0
646618	646248	20028X	PARTICIPANT	\N	PRESENT	0
646619	646248	14038Y	PARTICIPANT	\N	PRESENT	0
646620	646248	20030R	PARTICIPANT	\N	PRESENT	0
646621	646248	19467C	PARTICIPANT	\N	PRESENT	0
646622	646248	20034V	PARTICIPANT	\N	PRESENT	0
646623	646248	14187A	PARTICIPANT	\N	PRESENT	0
646624	646248	20144B	PARTICIPANT	\N	PRESENT	0
646625	646248	19695N	PARTICIPANT	\N	PRESENT	0
646626	646248	14033T	PARTICIPANT	\N	PRESENT	0
646627	646248	11090Q	PRESIDENT	0	PRESENT	0
646628	646248	01025N	PARTICIPANT	\N	PRESENT	0
646629	646248	20054A	PARTICIPANT	\N	PRESENT	0
646630	646248	14205J	PARTICIPANT	\N	PRESENT	0
646631	646248	20062A	PARTICIPANT	\N	PRESENT	0
646632	646248	14251Q	PARTICIPANT	\N	PRESENT	1
646633	646248	19507S	PARTICIPANT	\N	PRESENT	0
646634	646248	20286Q	PARTICIPANT	\N	PRESENT	0
646635	646248	19747H	PARTICIPANT	\N	PRESENT	0
646636	646248	14207L	PARTICIPANT	\N	PRESENT	0
646637	646248	14257W	PARTICIPANT	\N	PRESENT	0
646638	646155	19725B	PARTICIPANT	\N	PRESENT	0
646639	646155	19954N	PARTICIPANT	\N	PRESENT	0
646640	646155	14111D	PARTICIPANT	\N	PRESENT	0
646641	646155	20074E	PARTICIPANT	\N	PRESENT	0
646642	646155	20110Q	PARTICIPANT	\N	PRESENT	0
646643	646155	14069U	PARTICIPANT	\N	PRESENT	0
646644	646155	14215L	PARTICIPANT	\N	PRESENT	0
646645	646155	04047H	PRESIDENT	0	PRESENT	0
646646	646155	19749K	PARTICIPANT	\N	PRESENT	0
646647	646155	11033F	PARTICIPANT	\N	PRESENT	0
646648	646155	19649G	PARTICIPANT	\N	PRESENT	0
646649	646155	14107H	PARTICIPANT	\N	PRESENT	0
646650	646155	14179A	PARTICIPANT	\N	PRESENT	0
646651	646155	14001X	PARTICIPANT	\N	PRESENT	0
646652	646155	14147R	PARTICIPANT	\N	PRESENT	0
646653	646155	14151M	PARTICIPANT	\N	PRESENT	0
646654	646155	19581D	PARTICIPANT	\N	PRESENT	0
646655	646155	19673G	PARTICIPANT	\N	PRESENT	0
646656	646155	01028R	PARTICIPANT	\N	PRESENT	0
646657	646155	14021P	PARTICIPANT	\N	PRESENT	0
646658	646155	05008E	PARTICIPANT	\N	PRESENT	0
646659	646155	19447X	PARTICIPANT	\N	PRESENT	0
647208	646186	86034E	PARTICIPANT	\N	PRESENT	0
647210	646186	19693L	PARTICIPANT	\N	PRESENT	0
647209	646186	14211G	PARTICIPANT	\N	PRESENT	0
647211	646186	19711U	PARTICIPANT	\N	PRESENT	0
647212	646186	01058X	PARTICIPANT	\N	PRESENT	0
647213	646186	20074E	PARTICIPANT	\N	PRESENT	0
647214	646186	04047H	PARTICIPANT	\N	PRESENT	0
647215	646186	19747H	PARTICIPANT	\N	PRESENT	0
647216	646186	08034U	PARTICIPANT	\N	PRESENT	0
647217	646186	05008E	PARTICIPANT	\N	PRESENT	0
647218	646186	14215L	PARTICIPANT	\N	PRESENT	0
647219	646186	11097X	PARTICIPANT	\N	PRESENT	0
647220	646186	19581D	PARTICIPANT	\N	PRESENT	0
647221	646186	04071H	PARTICIPANT	\N	PRESENT	0
647222	646186	04033B	PARTICIPANT	\N	PRESENT	0
647223	646186	14187A	PARTICIPANT	\N	PRESENT	0
647224	646186	04042C	PARTICIPANT	\N	PRESENT	0
647225	646186	18083K	PARTICIPANT	\N	PRESENT	0
647226	646186	01048V	PARTICIPANT	\N	PRESENT	0
647227	646186	14053L	PARTICIPANT	\N	PRESENT	0
647228	646186	14069U	PARTICIPANT	\N	PRESENT	0
647229	646186	19701S	PARTICIPANT	\N	PRESENT	0
647230	646186	19533U	PARTICIPANT	\N	PRESENT	0
647231	646186	20120S	PARTICIPANT	\N	PRESENT	0
647232	646186	95041E	PARTICIPANT	\N	PRESENT	0
647233	646186	19367Y	PARTICIPANT	\N	PRESENT	0
647234	646186	20252E	PARTICIPANT	\N	PRESENT	0
647235	646186	19621T	PARTICIPANT	\N	PRESENT	0
647236	646186	14055N	PARTICIPANT	\N	PRESENT	0
647237	646186	20054A	PARTICIPANT	\N	PRESENT	0
647238	646186	20126Y	PARTICIPANT	\N	PRESENT	0
647239	646186	20124W	PARTICIPANT	\N	PRESENT	0
647240	646186	19383Y	PARTICIPANT	\N	PRESENT	0
647241	646186	20152B	PARTICIPANT	\N	PRESENT	0
647242	646186	14217N	PARTICIPANT	\N	PRESENT	0
647243	646186	19762G	PARTICIPANT	\N	PRESENT	0
647244	646186	14357A	PARTICIPANT	\N	PRESENT	0
647245	646186	20090E	PARTICIPANT	\N	PRESENT	0
647246	646186	20062A	PARTICIPANT	\N	PRESENT	0
647247	646186	20108W	PARTICIPANT	\N	PRESENT	0
647248	646186	08069G	PARTICIPANT	\N	PRESENT	0
647249	646186	11048N	PARTICIPANT	\N	PRESENT	0
647250	646186	19515S	PARTICIPANT	\N	PRESENT	0
647251	646186	11080N	PARTICIPANT	\N	PRESENT	0
647252	646186	19443T	PARTICIPANT	\N	PRESENT	0
647256	646186	05012A	PARTICIPANT	\N	PRESENT	0
647254	646186	20068G	PARTICIPANT	\N	PRESENT	0
647255	646186	20022R	PARTICIPANT	\N	PRESENT	0
647257	646186	11090Q	PARTICIPANT	\N	PRESENT	0
647258	646186	20032T	PARTICIPANT	\N	PRESENT	0
647259	646186	14147R	PARTICIPANT	\N	PRESENT	0
647260	646186	14191V	PARTICIPANT	\N	PRESENT	0
647261	646186	19766L	PARTICIPANT	\N	PRESENT	0
647262	646186	14031R	PARTICIPANT	\N	PRESENT	0
647263	646186	19673G	PARTICIPANT	\N	PRESENT	0
647264	646186	20038A	PARTICIPANT	\N	PRESENT	0
647265	646186	20026V	PARTICIPANT	\N	PRESENT	0
647266	646186	14033T	PARTICIPANT	\N	PRESENT	0
627388	627387	20124W	PARTICIPANT	\N	PRESENT	1
627389	627387	20180F	PARTICIPANT	\N	PRESENT	1
627390	627387	19573D	PARTICIPANT	\N	PRESENT	0
627391	627387	14109K	PARTICIPANT	\N	PRESENT	1
627392	627387	20056C	PARTICIPANT	\N	PRESENT	0
627394	627393	20124W	PARTICIPANT	\N	PRESENT	1
627395	627393	20056C	PARTICIPANT	\N	PRESENT	0
627396	627393	19573D	PARTICIPANT	\N	PRESENT	0
627397	627393	14109K	PARTICIPANT	\N	PRESENT	1
629333	629332	11048N	PARTICIPANT	\N	PRESENT	0
629335	629334	14331P	PARTICIPANT	\N	PRESENT	0
629336	629334	20252E	PARTICIPANT	\N	PRESENT	0
629338	629337	20180F	PARTICIPANT	\N	PRESENT	0
629339	629337	19593H	PARTICIPANT	\N	PRESENT	0
629341	629340	20180F	PARTICIPANT	\N	PRESENT	1
629342	629340	20132W	PARTICIPANT	\N	PRESENT	1
629343	629340	20134Y	PARTICIPANT	\N	PRESENT	1
629345	629344	20180F	PARTICIPANT	\N	PRESENT	1
629346	629344	20132W	PARTICIPANT	\N	PRESENT	1
629348	629347	20180F	PARTICIPANT	\N	PRESENT	0
629350	629349	20180F	PARTICIPANT	\N	PRESENT	1
629351	629349	20132W	PARTICIPANT	\N	PRESENT	1
629353	629352	20180F	PARTICIPANT	\N	PRESENT	1
629354	629352	20132W	PARTICIPANT	\N	PRESENT	1
629356	629355	20180F	PARTICIPANT	\N	PRESENT	1
629357	629355	20084G	PARTICIPANT	\N	PRESENT	1
629358	629355	20132W	PARTICIPANT	\N	PRESENT	1
629360	629359	20180F	PARTICIPANT	\N	PRESENT	0
629362	629361	20180F	PARTICIPANT	\N	PRESENT	1
629364	629363	20180F	PARTICIPANT	\N	PRESENT	0
629365	629363	20084G	PARTICIPANT	\N	PRESENT	0
629367	629366	20180F	PARTICIPANT	\N	PRESENT	0
629369	629368	10006L	PARTICIPANT	\N	PRESENT	0
629370	629368	19723Y	PARTICIPANT	\N	PRESENT	0
629371	629368	14147R	PARTICIPANT	\N	PRESENT	0
629372	629368	20130U	PARTICIPANT	\N	PRESENT	0
629435	629306	11045K	PARTICIPANT	\N	PRESENT	0
629436	629306	20094J	PARTICIPANT	\N	PRESENT	0
629437	629306	20128B	PARTICIPANT	\N	PRESENT	0
629438	629306	19563B	PARTICIPANT	\N	PRESENT	0
629439	629306	14215L	PARTICIPANT	\N	PRESENT	0
629472	629306	20108W	PARTICIPANT	\N	PRESENT	0
629481	629306	19758L	PARTICIPANT	\N	PRESENT	0
629442	629306	01025N	PARTICIPANT	\N	PRESENT	0
629443	629306	11012A	PARTICIPANT	\N	PRESENT	0
629444	629306	20084G	PARTICIPANT	\N	PRESENT	0
629445	629306	19525U	PARTICIPANT	\N	PRESENT	0
629446	629306	14089Y	PARTICIPANT	\N	PRESENT	0
629448	629306	19695N	PARTICIPANT	\N	PRESENT	0
629449	629306	14147R	PARTICIPANT	\N	PRESENT	0
629451	629306	19798U	PARTICIPANT	\N	PRESENT	0
629452	629306	20090E	PARTICIPANT	\N	PRESENT	0
629454	629306	19679N	PARTICIPANT	\N	PRESENT	0
629455	629306	19715Y	PARTICIPANT	\N	PRESENT	0
629456	629306	19651A	PARTICIPANT	\N	PRESENT	0
629457	629306	19387D	PARTICIPANT	\N	PRESENT	0
629458	629306	14069U	PARTICIPANT	\N	PRESENT	0
629459	629306	04047H	PARTICIPANT	\N	PRESENT	0
629460	629306	08056B	PARTICIPANT	\N	PRESENT	0
629461	629306	14169X	PARTICIPANT	\N	PRESENT	0
629462	629306	20048C	PARTICIPANT	\N	PRESENT	0
629465	629306	20024T	PARTICIPANT	\N	PRESENT	0
629487	629306	19515S	PARTICIPANT	\N	PRESENT	0
629467	629306	20266L	PARTICIPANT	\N	PRESENT	0
629469	629306	08018U	PARTICIPANT	\N	PRESENT	0
629471	629306	95063L	PARTICIPANT	\N	PRESENT	0
629473	629306	14231L	PARTICIPANT	\N	PRESENT	0
629474	629306	20038A	PARTICIPANT	\N	PRESENT	0
629475	629306	14059S	PARTICIPANT	\N	PRESENT	0
629476	629306	01024M	PARTICIPANT	\N	PRESENT	0
629477	629306	19349W	PARTICIPANT	\N	PRESENT	0
629478	629306	20144B	PARTICIPANT	\N	PRESENT	0
629479	629306	20064C	PARTICIPANT	\N	PRESENT	0
629480	629306	14253S	PARTICIPANT	\N	PRESENT	0
629482	629306	14107H	PARTICIPANT	\N	PRESENT	0
629484	629306	19782L	PARTICIPANT	\N	PRESENT	0
629485	629306	14033T	PARTICIPANT	\N	PRESENT	0
629486	629306	08028W	PARTICIPANT	\N	PRESENT	0
629488	629306	19747H	PARTICIPANT	\N	PRESENT	0
629531	629307	19515S	PARTICIPANT	\N	PRESENT	0
629532	629307	14033T	PARTICIPANT	\N	PRESENT	0
629533	629307	20038A	PARTICIPANT	\N	PRESENT	0
629534	629307	20024T	PARTICIPANT	\N	PRESENT	0
629535	629307	08028W	PARTICIPANT	\N	PRESENT	0
629536	629307	14059S	PARTICIPANT	\N	PRESENT	0
629537	629307	20062A	PARTICIPANT	\N	PRESENT	0
629538	629307	19747H	PARTICIPANT	\N	PRESENT	0
629539	629307	01025N	PARTICIPANT	\N	PRESENT	0
629540	629307	14179A	PARTICIPANT	\N	PRESENT	0
629541	629307	19441R	PARTICIPANT	\N	PRESENT	0
629542	629307	11012A	PARTICIPANT	\N	PRESENT	0
629543	629307	19387D	PARTICIPANT	\N	PRESENT	0
629544	629307	19651A	PARTICIPANT	\N	PRESENT	0
629545	629307	14231L	PARTICIPANT	\N	PRESENT	0
629546	629307	20134Y	PARTICIPANT	\N	PRESENT	0
629547	629307	20266L	PARTICIPANT	\N	PRESENT	0
629548	629307	20036X	PARTICIPANT	\N	PRESENT	0
629549	629307	19715Y	PARTICIPANT	\N	PRESENT	0
629550	629307	20094J	PARTICIPANT	\N	PRESENT	0
629551	629307	20064C	PARTICIPANT	\N	PRESENT	0
629552	629307	19758L	PARTICIPANT	\N	PRESENT	0
629553	629307	19563B	PARTICIPANT	\N	PRESENT	0
629554	629307	11090Q	PARTICIPANT	\N	PRESENT	0
629555	629307	20144B	PARTICIPANT	\N	PRESENT	0
629556	629307	14253S	PARTICIPANT	\N	PRESENT	0
629557	629307	20032T	PARTICIPANT	\N	PRESENT	0
629558	629307	19782L	PARTICIPANT	\N	PRESENT	0
629559	629307	14207L	PARTICIPANT	\N	PRESENT	0
629560	629307	11056N	PARTICIPANT	\N	PRESENT	0
629561	629307	14251Q	PARTICIPANT	\N	PRESENT	0
629562	629307	19768N	PARTICIPANT	\N	PRESENT	0
629563	629307	20030R	PARTICIPANT	\N	PRESENT	0
629564	629307	20088L	PARTICIPANT	\N	PRESENT	0
629565	629307	20098N	PARTICIPANT	\N	PRESENT	0
629566	629307	20018V	PARTICIPANT	\N	PRESENT	0
629567	629021	19697Q	PARTICIPANT	\N	PRESENT	1
629568	629021	20090E	PARTICIPANT	\N	PRESENT	0
629569	629021	04092N	PRESIDENT	0	PRESENT	0
629529	629307	11045K	PARTICIPANT	\N	PRESENT	0
629530	629307	20128B	PARTICIPANT	\N	PRESENT	0
629570	629021	19798U	PARTICIPANT	\N	PRESENT	0
629571	629021	11097X	PARTICIPANT	\N	PRESENT	0
629572	629021	17965H	PARTICIPANT	\N	PRESENT	0
629573	629021	19715Y	PARTICIPANT	\N	PRESENT	0
629574	629021	19691J	PARTICIPANT	\N	PRESENT	1
629575	629021	17779H	PARTICIPANT	\N	PRESENT	0
629576	629021	20066E	PARTICIPANT	\N	PRESENT	1
629577	629021	20266L	PARTICIPANT	\N	PRESENT	0
629578	629021	19679N	PARTICIPANT	\N	PRESENT	0
629579	629021	11103C	PARTICIPANT	\N	PRESENT	1
629580	629021	14042U	PARTICIPANT	\N	PRESENT	0
629581	629021	14217N	PARTICIPANT	\N	PRESENT	0
629582	629021	19760E	PARTICIPANT	\N	PRESENT	0
629583	629021	11067R	PARTICIPANT	\N	EXCUSE	0
629584	629021	20040T	PARTICIPANT	\N	EXCUSE	0
629585	629021	10006L	PARTICIPANT	\N	EXCUSE	0
629586	629307	19349W	PARTICIPANT	\N	PRESENT	0
629587	629307	14257W	PARTICIPANT	\N	PRESENT	0
629588	629307	19413M	PARTICIPANT	\N	PRESENT	0
629590	629307	14123H	PARTICIPANT	\N	PRESENT	0
629592	629307	19762G	PARTICIPANT	\N	PRESENT	0
629595	629307	19739H	PARTICIPANT	\N	PRESENT	0
629615	629307	19695N	PARTICIPANT	\N	PRESENT	0
629597	629307	20034V	PARTICIPANT	\N	PRESENT	0
629599	629122	14097Y	PARTICIPANT	\N	PRESENT	1
629600	629122	19443T	PARTICIPANT	\N	PRESENT	0
629601	629122	14133K	PARTICIPANT	\N	PRESENT	0
629602	629122	20042V	PARTICIPANT	\N	PRESENT	0
629603	629122	01058X	PARTICIPANT	\N	PRESENT	0
629604	629122	16685X	PARTICIPANT	\N	PRESENT	0
629605	629122	04042C	PRESIDENT	0	PRESENT	0
629606	629122	01024M	PARTICIPANT	\N	PRESENT	0
629607	629122	11066Q	PARTICIPANT	\N	PRESENT	0
629608	629122	08056B	PARTICIPANT	\N	PRESENT	0
629609	629122	12028B	PARTICIPANT	\N	PRESENT	0
629610	629122	11083R	PARTICIPANT	\N	PRESENT	1
629611	629122	97011G	PARTICIPANT	\N	PRESENT	0
629612	629122	14255U	PARTICIPANT	\N	PRESENT	0
629613	629122	14211G	PARTICIPANT	\N	EXCUSE	0
629614	629122	19583F	PARTICIPANT	\N	EXCUSE	0
629616	629307	01043Q	PARTICIPANT	\N	PRESENT	0
638932	638300	19693L	PARTICIPANT	\N	PRESENT	0
638933	638300	14109K	PARTICIPANT	\N	PRESENT	0
638934	638441	14189C	PARTICIPANT	\N	EXCUSE	0
638935	638441	14357A	PARTICIPANT	\N	PRESENT	0
638936	638441	08018U	PARTICIPANT	\N	PRESENT	1
638937	638441	11083R	PARTICIPANT	\N	PRESENT	0
638938	638441	14097Y	PARTICIPANT	\N	PRESENT	0
638939	638441	19711U	PARTICIPANT	\N	PRESENT	0
638940	638441	08034U	PARTICIPANT	\N	PRESENT	0
638941	638441	12016W	PARTICIPANT	\N	PRESENT	1
638942	638441	11026G	PARTICIPANT	\N	PRESENT	0
638943	638441	14331P	PARTICIPANT	\N	PRESENT	0
638944	638441	10015M	PARTICIPANT	\N	PRESENT	0
638945	638373	19760E	PARTICIPANT	\N	PRESENT	1
638946	638373	11067R	PARTICIPANT	\N	PRESENT	0
638947	638373	19415P	PARTICIPANT	\N	PRESENT	0
638948	638374	14213J	PARTICIPANT	\N	PRESENT	1
638949	638374	17965H	PARTICIPANT	\N	PRESENT	1
638950	638374	19415P	PARTICIPANT	\N	PRESENT	0
638951	638374	11067R	PARTICIPANT	\N	PRESENT	0
638953	638952	04047H	PARTICIPANT	\N	PRESENT	0
638954	638952	07004J	PARTICIPANT	\N	PRESENT	0
638955	638952	11026G	PARTICIPANT	\N	PRESENT	0
638989	638988	19415P	PARTICIPANT	\N	PRESENT	0
639011	639010	19415P	PARTICIPANT	\N	PRESENT	0
639014	638883	10006L	PRESIDENT	0	PRESENT	0
639015	638807	19333N	PARTICIPANT	\N	PRESENT	0
639016	638807	18083K	PARTICIPANT	\N	PRESENT	0
639017	638807	14219Q	PRESIDENT	0	PRESENT	0
639018	638807	20102Q	PARTICIPANT	\N	PRESENT	0
639019	638807	19599P	PARTICIPANT	\N	PRESENT	0
639020	638807	20024T	PARTICIPANT	\N	PRESENT	0
639021	638807	19619A	PARTICIPANT	\N	PRESENT	0
639022	638807	08060W	PARTICIPANT	\N	PRESENT	1
639023	638807	20136B	PARTICIPANT	\N	PRESENT	1
639024	638807	20140W	PARTICIPANT	\N	PRESENT	1
639025	638807	19251M	PARTICIPANT	\N	PRESENT	1
639026	638807	20046A	PARTICIPANT	\N	PRESENT	1
639027	638883	19723Y	PARTICIPANT	\N	PRESENT	0
639028	638883	14042U	PARTICIPANT	\N	PRESENT	0
639029	638883	18193Q	PARTICIPANT	\N	PRESENT	0
639030	638807	20068G	PARTICIPANT	\N	PRESENT	0
639031	638807	19820Y	PARTICIPANT	\N	PRESENT	0
639032	638807	17229F	PARTICIPANT	\N	PRESENT	0
639033	638883	20090E	PARTICIPANT	\N	PRESENT	0
639034	638883	14217N	PARTICIPANT	\N	PRESENT	0
639035	638883	19679N	PARTICIPANT	\N	PRESENT	1
639036	638883	19760E	PARTICIPANT	\N	PRESENT	1
639037	638883	19657G	PARTICIPANT	\N	PRESENT	1
639038	638883	20130U	PARTICIPANT	\N	PRESENT	1
639039	638883	11031D	PARTICIPANT	\N	EXCUSE	0
639040	638807	14031R	PARTICIPANT	\N	PRESENT	0
639041	638807	19503N	PARTICIPANT	\N	PRESENT	0
639042	638883	11067R	PARTICIPANT	\N	EXCUSE	0
639043	638883	20298U	PARTICIPANT	\N	PRESENT	0
639044	638883	19569H	PARTICIPANT	\N	PRESENT	0
639045	638883	01034P	PARTICIPANT	\N	PRESENT	1
639046	638883	14213J	PARTICIPANT	\N	PRESENT	1
639047	638883	19591F	PARTICIPANT	\N	PRESENT	1
639048	638807	20076G	PARTICIPANT	\N	PRESENT	0
639049	638807	20100N	PARTICIPANT	\N	PRESENT	0
639050	638990	20030R	PARTICIPANT	\N	PRESENT	1
639051	638990	19515S	PARTICIPANT	\N	PRESENT	0
639052	638990	01043Q	PARTICIPANT	\N	PRESENT	0
639053	638990	14033T	PARTICIPANT	\N	PRESENT	1
639054	638990	11090Q	PRESIDENT	0	PRESENT	0
639055	638990	20104S	PARTICIPANT	\N	PRESENT	0
639056	638990	20062A	PARTICIPANT	\N	PRESENT	0
639057	638990	19705W	PARTICIPANT	\N	PRESENT	0
639058	638990	14251Q	PARTICIPANT	\N	PRESENT	1
639059	638990	19707Y	PARTICIPANT	\N	PRESENT	0
639060	638990	19507S	PARTICIPANT	\N	PRESENT	0
639061	638990	19747H	PARTICIPANT	\N	PRESENT	0
639062	638990	20018V	PARTICIPANT	\N	PRESENT	1
639063	638990	19511N	PARTICIPANT	\N	PRESENT	0
639064	638990	14329V	PARTICIPANT	\N	PRESENT	0
639065	638990	14257W	PARTICIPANT	\N	PRESENT	1
639066	638883	19697Q	PARTICIPANT	\N	PRESENT	1
639067	638807	19549D	PARTICIPANT	\N	PRESENT	0
639068	638807	19387D	PARTICIPANT	\N	PRESENT	1
639069	638883	19301E	PARTICIPANT	\N	PRESENT	1
639070	638883	14223L	PARTICIPANT	\N	PRESENT	0
639071	638883	11097X	PARTICIPANT	\N	PRESENT	0
639072	638807	20118Y	PARTICIPANT	\N	PRESENT	0
639073	638807	19745F	PARTICIPANT	\N	PRESENT	0
639074	638990	19768N	PARTICIPANT	\N	PRESENT	1
639075	638990	20144B	PARTICIPANT	\N	PRESENT	0
639076	638990	20286Q	PARTICIPANT	\N	PRESENT	1
639077	638990	14207L	PARTICIPANT	\N	PRESENT	0
639078	638990	19575F	PARTICIPANT	\N	PRESENT	0
639079	638883	14195A	PARTICIPANT	\N	PRESENT	1
639080	638807	19685L	PARTICIPANT	\N	PRESENT	0
639081	638807	20120S	PARTICIPANT	\N	PRESENT	0
639082	638883	20066E	PARTICIPANT	\N	PRESENT	1
639083	638883	19553Y	PARTICIPANT	\N	PRESENT	0
639084	638883	19798U	PARTICIPANT	\N	PRESENT	0
639085	638807	20032T	PARTICIPANT	\N	PRESENT	0
639086	638883	17965H	PARTICIPANT	\N	PRESENT	1
639087	638883	20248J	PARTICIPANT	\N	PRESENT	0
639089	639088	04042C	PARTICIPANT	\N	PRESENT	0
639090	638990	19782L	PARTICIPANT	\N	PRESENT	1
639091	638886	10006L	PRESIDENT	0	PRESENT	0
639092	638886	11097X	PARTICIPANT	\N	PRESENT	0
639093	638886	14026U	PARTICIPANT	\N	PRESENT	0
639094	638886	14217N	PARTICIPANT	\N	PRESENT	0
639095	638886	14223L	PARTICIPANT	\N	PRESENT	0
639096	638886	11067R	PARTICIPANT	\N	PRESENT	0
639097	638886	19415P	PARTICIPANT	\N	PRESENT	0
639098	638886	19798U	PARTICIPANT	\N	PRESENT	0
639099	638886	20090E	PARTICIPANT	\N	PRESENT	0
639100	638886	19683J	PARTICIPANT	\N	PRESENT	0
639101	638886	18193Q	PARTICIPANT	\N	PRESENT	0
639102	638886	11031D	PARTICIPANT	\N	EXCUSE	0
639103	638886	20298U	PARTICIPANT	\N	PRESENT	0
639104	638886	19301E	PARTICIPANT	\N	PRESENT	1
639105	638886	20040T	PARTICIPANT	\N	PRESENT	0
639106	638886	19760E	PARTICIPANT	\N	PRESENT	1
639107	638886	14213J	PARTICIPANT	\N	PRESENT	1
639108	639012	18083K	PRESIDENT	0	PRESENT	0
639109	639012	20266L	PARTICIPANT	\N	PRESENT	0
639110	639012	19347U	PARTICIPANT	\N	PRESENT	0
639111	639012	19387D	PARTICIPANT	\N	PRESENT	0
639112	639012	19575F	PARTICIPANT	\N	EXCUSE	0
639113	639012	19760E	PARTICIPANT	\N	EXCUSE	0
639114	638886	20266L	PARTICIPANT	\N	PRESENT	0
639115	638886	19723Y	PARTICIPANT	\N	PRESENT	1
639116	638883	14026U	PARTICIPANT	\N	PRESENT	0
639117	638883	19713W	PARTICIPANT	\N	PRESENT	1
639127	638886	20066E	PARTICIPANT	\N	PRESENT	1
639128	638886	19569H	PARTICIPANT	\N	PRESENT	0
639138	638991	19383Y	PARTICIPANT	\N	PRESENT	0
639139	638991	20092G	PARTICIPANT	\N	PRESENT	0
639140	638991	14357A	PARTICIPANT	\N	PRESENT	0
639141	638991	19441R	PARTICIPANT	\N	PRESENT	0
639142	638991	20144B	PARTICIPANT	\N	PRESENT	0
639143	638991	20094J	PARTICIPANT	\N	PRESENT	0
639144	638991	11090Q	PRESIDENT	0	PRESENT	0
639145	638991	20062A	PARTICIPANT	\N	PRESENT	0
639146	638991	19705W	PARTICIPANT	\N	PRESENT	0
639147	638991	19507S	PARTICIPANT	\N	PRESENT	0
639148	638991	08015R	PARTICIPANT	\N	PRESENT	0
639149	638991	19575F	PARTICIPANT	\N	PRESENT	0
639150	638991	14207L	PARTICIPANT	\N	PRESENT	0
639151	638991	19747H	PARTICIPANT	\N	PRESENT	0
639152	638991	20028X	PARTICIPANT	\N	PRESENT	0
639153	638991	19768N	PARTICIPANT	\N	PRESENT	1
639154	638991	19782L	PARTICIPANT	\N	PRESENT	1
639155	638991	11077T	PARTICIPANT	\N	PRESENT	1
639156	638991	19413M	PARTICIPANT	\N	PRESENT	1
639157	638991	20018V	PARTICIPANT	\N	PRESENT	1
639158	638991	20030R	PARTICIPANT	\N	PRESENT	1
639159	638991	14033T	PARTICIPANT	\N	PRESENT	1
639160	638991	20054A	PARTICIPANT	\N	PRESENT	1
639161	638991	14205J	PARTICIPANT	\N	PRESENT	1
639162	638991	20286Q	PARTICIPANT	\N	PRESENT	1
639163	638991	14257W	PARTICIPANT	\N	PRESENT	1
639180	638990	19383Y	PARTICIPANT	\N	PRESENT	0
639181	638990	20174H	PARTICIPANT	\N	PRESENT	1
639182	638990	19441R	PARTICIPANT	\N	PRESENT	0
639183	638990	19866P	PARTICIPANT	\N	PRESENT	1
629390	628902	08045X	PARTICIPANT	\N	EXCUSE	0
632655	629433	20032T	PARTICIPANT	\N	PRESENT	0
632656	629433	20068G	PARTICIPANT	\N	PRESENT	0
632657	629433	19599P	PARTICIPANT	\N	PRESENT	0
632658	629433	20102Q	PARTICIPANT	\N	PRESENT	0
632659	629433	17229F	PARTICIPANT	\N	PRESENT	0
632660	629433	05012A	PARTICIPANT	\N	EXCUSE	0
632661	629433	08060W	PARTICIPANT	\N	EXCUSE	0
632662	629433	14221J	PARTICIPANT	\N	EXCUSE	0
632663	629433	19637C	PARTICIPANT	\N	EXCUSE	0
632664	629433	18083K	PARTICIPANT	\N	PRESENT	0
632665	629433	19826F	PARTICIPANT	\N	PRESENT	0
632666	629433	19333N	PARTICIPANT	\N	PRESENT	0
632667	629433	20136B	PARTICIPANT	\N	PRESENT	0
632668	629433	19503N	PARTICIPANT	\N	PRESENT	0
632669	629433	20046A	PARTICIPANT	\N	PRESENT	0
632670	629433	19549D	PARTICIPANT	\N	PRESENT	0
632671	629433	20024T	PARTICIPANT	\N	PRESENT	0
632672	629433	14219Q	PRESIDENT	0	PRESENT	0
632673	629433	19701S	PARTICIPANT	\N	PRESENT	0
632674	629433	20038A	PARTICIPANT	\N	PRESENT	0
632675	629433	20020P	PARTICIPANT	\N	PRESENT	0
632676	629433	19251M	PARTICIPANT	\N	PRESENT	0
632677	629433	19820Y	PARTICIPANT	\N	PRESENT	0
632678	629433	19387D	PARTICIPANT	\N	PRESENT	1
632679	629433	14031R	PARTICIPANT	\N	PRESENT	0
632680	629433	20106U	PARTICIPANT	\N	PRESENT	0
632681	629433	19745F	PARTICIPANT	\N	PRESENT	1
632682	629433	19619A	PARTICIPANT	\N	EXCUSE	0
632683	629433	14169X	PARTICIPANT	\N	PRESENT	0
632684	629433	20100N	PARTICIPANT	\N	PRESENT	0
632685	631111	19697Q	PARTICIPANT	\N	PRESENT	1
632686	631111	11067R	PARTICIPANT	\N	PRESENT	0
632687	631111	20090E	PARTICIPANT	\N	PRESENT	0
632688	631111	19798U	PARTICIPANT	\N	PRESENT	0
632689	631111	18193Q	PARTICIPANT	\N	PRESENT	0
632690	631111	19703U	PARTICIPANT	\N	PRESENT	0
632691	631111	11031D	PARTICIPANT	\N	PRESENT	1
632692	631111	14281W	PARTICIPANT	\N	PRESENT	1
632693	631111	19679N	PARTICIPANT	\N	PRESENT	0
632694	631111	14195A	PARTICIPANT	\N	PRESENT	0
632695	631111	14213J	PARTICIPANT	\N	PRESENT	1
632696	631111	14217N	PARTICIPANT	\N	PRESENT	0
632697	631111	10006L	PRESIDENT	0	PRESENT	0
632698	631111	19683J	PARTICIPANT	\N	PRESENT	0
632699	631111	04057K	PARTICIPANT	\N	PRESENT	1
632700	631111	04092N	PARTICIPANT	\N	PRESENT	0
632701	631111	19713W	PARTICIPANT	\N	PRESENT	0
632702	631111	11045K	PARTICIPANT	\N	PRESENT	0
632703	631111	08045X	PARTICIPANT	\N	PRESENT	0
632704	631111	17965H	PARTICIPANT	\N	PRESENT	0
632705	631111	19691J	PARTICIPANT	\N	PRESENT	0
632706	631111	20248J	PARTICIPANT	\N	PRESENT	0
632707	631111	11103C	PARTICIPANT	\N	PRESENT	1
632708	631111	20266L	PARTICIPANT	\N	PRESENT	1
632709	631111	20298U	PARTICIPANT	\N	PRESENT	0
632710	631111	14071N	PARTICIPANT	\N	PRESENT	0
632711	629433	19551W	PARTICIPANT	\N	PRESENT	0
632712	629433	20140W	PARTICIPANT	\N	PRESENT	1
632713	629433	20076G	PARTICIPANT	\N	PRESENT	0
632721	629433	19525U	PARTICIPANT	\N	PRESENT	0
632732	631564	14111D	PARTICIPANT	\N	PRESENT	0
632733	631564	11026G	PARTICIPANT	\N	PRESENT	0
632734	631564	10015M	PARTICIPANT	\N	PRESENT	0
632735	631564	19581D	PARTICIPANT	\N	PRESENT	0
632736	631564	04047H	PRESIDENT	0	PRESENT	0
632737	631564	19673G	PARTICIPANT	\N	PRESENT	0
632738	631564	01028R	PARTICIPANT	\N	PRESENT	0
632739	631564	14231L	PARTICIPANT	\N	PRESENT	0
632740	631564	19447X	PARTICIPANT	\N	PRESENT	0
632741	631564	14089Y	PARTICIPANT	\N	PRESENT	0
632742	631564	19725B	PARTICIPANT	\N	PRESENT	0
632743	631564	19954N	PARTICIPANT	\N	PRESENT	0
632744	631564	20110Q	PARTICIPANT	\N	PRESENT	0
632745	631564	14147R	PARTICIPANT	\N	PRESENT	0
632746	631564	14069U	PARTICIPANT	\N	PRESENT	0
632747	631564	14151M	PARTICIPANT	\N	PRESENT	0
632748	631564	14215L	PARTICIPANT	\N	PRESENT	0
632749	631564	04008A	PARTICIPANT	\N	PRESENT	0
632750	631564	19749K	PARTICIPANT	\N	PRESENT	0
632751	631564	20022R	PARTICIPANT	\N	PRESENT	0
632753	629433	17367Q	PARTICIPANT	\N	PRESENT	0
632755	631111	11097X	PARTICIPANT	\N	PRESENT	0
632756	631111	17779H	PARTICIPANT	\N	PRESENT	0
632757	631111	19553Y	PARTICIPANT	\N	PRESENT	0
632758	631111	19663E	PARTICIPANT	\N	PRESENT	0
632759	631111	19717B	PARTICIPANT	\N	PRESENT	1
632760	631111	20066E	PARTICIPANT	\N	PRESENT	1
632761	631111	19657G	PARTICIPANT	\N	PRESENT	1
632762	631111	04043D	PARTICIPANT	\N	PRESENT	0
632763	631111	19760E	PARTICIPANT	\N	PRESENT	0
632765	631111	19415P	PARTICIPANT	\N	PRESENT	0
632766	629433	20096L	PARTICIPANT	\N	PRESENT	0
632768	631213	20086J	PARTICIPANT	\N	PRESENT	0
632769	631213	14331P	PARTICIPANT	\N	PRESENT	0
632770	631213	11048N	PARTICIPANT	\N	PRESENT	0
632771	631213	19479G	PARTICIPANT	\N	PRESENT	0
632772	631213	20036X	PARTICIPANT	\N	PRESENT	0
632773	631213	14189C	PARTICIPANT	\N	PRESENT	0
632774	631213	01057W	PARTICIPANT	\N	PRESENT	0
632775	631213	20080C	PARTICIPANT	\N	PRESENT	0
632776	631213	20050V	PARTICIPANT	\N	PRESENT	0
632777	631213	08011M	PRESIDENT	0	PRESENT	0
632778	631213	11074Q	PARTICIPANT	\N	PRESENT	0
632779	631213	20044X	PARTICIPANT	\N	PRESENT	0
632780	631213	19671E	PARTICIPANT	\N	PRESENT	0
632781	631213	11070L	PARTICIPANT	\N	PRESENT	0
632782	631213	11040E	PARTICIPANT	\N	PRESENT	0
632783	631213	07029T	PARTICIPANT	\N	PRESENT	0
632784	631213	20252E	PARTICIPANT	\N	PRESENT	0
632785	631213	20070A	PARTICIPANT	\N	PRESENT	0
632786	631213	19349W	PARTICIPANT	\N	PRESENT	0
632787	631213	19741B	PARTICIPANT	\N	PRESENT	0
632788	631213	20116W	PARTICIPANT	\N	PRESENT	0
632789	631213	99004R	PARTICIPANT	\N	PRESENT	0
632790	631213	19762G	PARTICIPANT	\N	PRESENT	0
632791	631213	14173T	PARTICIPANT	\N	PRESENT	0
632800	631213	11053K	PARTICIPANT	\N	PRESENT	0
632805	631213	19687N	PARTICIPANT	\N	PRESENT	0
632808	631213	14225N	PARTICIPANT	\N	EXCUSE	0
632809	631213	11012A	PARTICIPANT	\N	PRESENT	0
632878	632714	08015R	PARTICIPANT	\N	PRESENT	0
632883	631565	14053L	PARTICIPANT	\N	PRESENT	0
632884	631565	11010L	PARTICIPANT	\N	PRESENT	0
632885	631565	11026G	PARTICIPANT	\N	PRESENT	0
632886	631565	10015M	PARTICIPANT	\N	PRESENT	0
632887	631565	14001X	PARTICIPANT	\N	PRESENT	0
632888	631565	04047H	PRESIDENT	0	PRESENT	0
632889	631565	01028R	PARTICIPANT	\N	PRESENT	0
632890	631565	14231L	PARTICIPANT	\N	PRESENT	0
632891	631565	19447X	PARTICIPANT	\N	PRESENT	0
632892	631565	05008E	PARTICIPANT	\N	PRESENT	0
632893	631565	19725B	PARTICIPANT	\N	PRESENT	0
632894	631565	19489J	PARTICIPANT	\N	PRESENT	0
632895	631565	95063L	PARTICIPANT	\N	PRESENT	0
632896	631565	19629C	PARTICIPANT	\N	PRESENT	0
632897	631565	14107H	PARTICIPANT	\N	PRESENT	0
632898	631565	20110Q	PARTICIPANT	\N	PRESENT	0
632899	631565	14147R	PARTICIPANT	\N	PRESENT	0
632900	631565	14151M	PARTICIPANT	\N	PRESENT	0
632901	631565	14215L	PARTICIPANT	\N	PRESENT	0
632902	631565	08018U	PARTICIPANT	\N	PRESENT	0
632903	631565	20022R	PARTICIPANT	\N	PRESENT	0
632904	631565	20128B	PARTICIPANT	\N	PRESENT	0
632905	631565	14021P	PARTICIPANT	\N	PRESENT	0
632906	631565	19954N	PARTICIPANT	\N	PRESENT	0
632907	631565	19581D	PARTICIPANT	\N	PRESENT	0
632916	631566	86034E	PARTICIPANT	\N	PRESENT	0
632917	631706	19565D	PARTICIPANT	\N	PRESENT	0
632918	631706	20072C	PARTICIPANT	\N	PRESENT	0
632919	631706	01058X	PARTICIPANT	\N	PRESENT	1
632920	631706	16685X	PARTICIPANT	\N	PRESENT	0
632921	631706	04042C	PRESIDENT	0	PRESENT	0
632922	631706	11054L	PARTICIPANT	\N	PRESENT	0
632923	631706	11066Q	PARTICIPANT	\N	PRESENT	0
632924	631706	08056B	PARTICIPANT	\N	PRESENT	0
632925	631706	12028B	PARTICIPANT	\N	PRESENT	0
632926	631706	19421M	PARTICIPANT	\N	PRESENT	0
632927	631706	14193X	PARTICIPANT	\N	PRESENT	0
632928	631706	19347U	PARTICIPANT	\N	PRESENT	0
632929	631706	07033P	PARTICIPANT	\N	PRESENT	0
647267	646186	20056C	PARTICIPANT	\N	PRESENT	0
647268	646186	20180F	PARTICIPANT	\N	PRESENT	0
647269	646186	19573D	PARTICIPANT	\N	PRESENT	0
647270	646186	19707Y	PARTICIPANT	\N	PRESENT	0
647271	646186	19705W	PARTICIPANT	\N	PRESENT	0
647272	646186	19447X	PARTICIPANT	\N	PRESENT	0
647273	646186	20034V	PARTICIPANT	\N	PRESENT	0
647274	646186	14038Y	PARTICIPANT	\N	PRESENT	0
647275	646186	20058E	PARTICIPANT	\N	PRESENT	0
647276	646186	20044X	PARTICIPANT	\N	PRESENT	0
647277	646186	19760E	PARTICIPANT	\N	PRESENT	0
647278	646186	04085P	PARTICIPANT	\N	PRESENT	0
647279	646186	20112S	PARTICIPANT	\N	PRESENT	0
647280	646186	20136B	PARTICIPANT	\N	PRESENT	0
647281	646186	11040E	PARTICIPANT	\N	PRESENT	0
647282	646186	19758L	PARTICIPANT	\N	PRESENT	0
647283	646186	11031D	PARTICIPANT	\N	PRESENT	0
647284	646186	11056N	PARTICIPANT	\N	PRESENT	0
647285	646186	19695N	PARTICIPANT	\N	PRESENT	0
647286	646186	19565D	PARTICIPANT	\N	PRESENT	0
647287	646186	20102Q	PARTICIPANT	\N	PRESENT	0
647288	646186	12041X	PARTICIPANT	\N	PRESENT	0
647289	646186	11077T	PARTICIPANT	\N	PRESENT	0
647290	646186	20138D	PARTICIPANT	\N	PRESENT	0
647291	646186	19593H	PARTICIPANT	\N	PRESENT	0
647292	646186	19687N	PARTICIPANT	\N	PRESENT	0
647293	646186	20046A	PARTICIPANT	\N	PRESENT	0
647294	646186	19715Y	PARTICIPANT	\N	PRESENT	0
647295	646186	11045K	PARTICIPANT	\N	PRESENT	0
647296	646186	14225N	PARTICIPANT	\N	PRESENT	0
647297	646186	19954N	PARTICIPANT	\N	PRESENT	0
647298	646186	01028R	PARTICIPANT	\N	PRESENT	0
647299	646186	19599P	PARTICIPANT	\N	PRESENT	0
647300	646186	14257W	PARTICIPANT	\N	PRESENT	0
647301	646186	17779H	PARTICIPANT	\N	PRESENT	0
647302	646186	11074Q	PARTICIPANT	\N	PRESENT	0
647303	646186	14151M	PARTICIPANT	\N	PRESENT	0
647304	646186	14001X	PARTICIPANT	\N	PRESENT	0
647305	646186	17737W	PARTICIPANT	\N	PRESENT	0
647306	646186	19333N	PARTICIPANT	\N	PRESENT	0
647307	646186	08045X	PARTICIPANT	\N	PRESENT	0
647308	646186	19649G	PARTICIPANT	\N	PRESENT	0
647309	646186	14021P	PARTICIPANT	\N	PRESENT	0
647310	646186	14229S	PARTICIPANT	\N	PRESENT	0
647311	646186	20084G	PARTICIPANT	\N	PRESENT	0
647312	646186	14097Y	PARTICIPANT	\N	PRESENT	0
647313	646186	11067R	PARTICIPANT	\N	PRESENT	0
647314	646186	20028X	PARTICIPANT	\N	PRESENT	0
647315	646186	08012N	PARTICIPANT	\N	PRESENT	0
647316	646186	20104S	PARTICIPANT	\N	PRESENT	0
647317	646186	12016W	PARTICIPANT	\N	PRESENT	0
647318	646186	11066Q	PARTICIPANT	\N	PRESENT	0
647319	646186	11054L	PARTICIPANT	\N	PRESENT	0
647320	646186	19531S	PARTICIPANT	\N	PRESENT	0
647321	646186	20148F	PARTICIPANT	\N	PRESENT	0
647322	646186	19725B	PARTICIPANT	\N	PRESENT	0
647323	646186	19413M	PARTICIPANT	\N	PRESENT	0
647324	646186	20094J	PARTICIPANT	\N	PRESENT	0
647325	646186	18193Q	PARTICIPANT	\N	PRESENT	0
647326	646186	14331P	PARTICIPANT	\N	PRESENT	0
647327	646186	20080C	PARTICIPANT	\N	PRESENT	0
647328	646186	20070A	PARTICIPANT	\N	PRESENT	0
647329	646186	14329V	PARTICIPANT	\N	PRESENT	0
647330	646186	20082E	PARTICIPANT	\N	PRESENT	0
647331	646186	12028B	PARTICIPANT	\N	PRESENT	0
647332	646186	19295A	PARTICIPANT	\N	PRESENT	0
647333	646186	19503N	PARTICIPANT	\N	PRESENT	0
647334	646186	11110B	PARTICIPANT	\N	PRESENT	0
647335	646186	14121F	PARTICIPANT	\N	PRESENT	0
647336	646186	19631V	PARTICIPANT	\N	PRESENT	0
647337	646186	20264J	PARTICIPANT	\N	PRESENT	0
647338	646186	19527W	PARTICIPANT	\N	PRESENT	0
647339	646186	19251M	PARTICIPANT	\N	PRESENT	0
647340	646186	20018V	PARTICIPANT	\N	PRESENT	0
647341	646186	20064C	PARTICIPANT	\N	PRESENT	0
647342	646186	17965H	PARTICIPANT	\N	PRESENT	0
647343	646186	20110Q	PARTICIPANT	\N	PRESENT	0
647344	646186	20914V	PARTICIPANT	\N	PRESENT	0
647345	646186	11065P	PARTICIPANT	\N	PRESENT	0
647346	646186	20134Y	PARTICIPANT	\N	PRESENT	0
647347	646186	20100N	PARTICIPANT	\N	PRESENT	0
647348	646186	19347U	PARTICIPANT	\N	PRESENT	0
647349	646186	20142Y	PARTICIPANT	\N	PRESENT	0
647350	646186	20036X	PARTICIPANT	\N	PRESENT	0
647351	646186	20130U	PARTICIPANT	\N	PRESENT	0
647352	646186	20266L	PARTICIPANT	\N	PRESENT	0
647353	646186	19651A	PARTICIPANT	\N	PRESENT	0
647354	646186	19782L	PARTICIPANT	\N	PRESENT	0
647355	646186	14259Y	PARTICIPANT	\N	PRESENT	0
647356	646186	19525U	PARTICIPANT	\N	PRESENT	0
647357	646186	14249W	PARTICIPANT	\N	PRESENT	0
647358	646186	14037X	PARTICIPANT	\N	PRESENT	0
647359	646186	08011M	PARTICIPANT	\N	PRESENT	0
647360	646186	19697Q	PARTICIPANT	\N	PRESENT	0
647361	646186	19349W	PARTICIPANT	\N	PRESENT	0
647362	646186	19659J	PARTICIPANT	\N	PRESENT	0
647363	646186	95063L	PARTICIPANT	\N	PRESENT	0
647364	646186	99004R	PARTICIPANT	\N	PRESENT	0
647365	646186	19301E	PARTICIPANT	\N	PRESENT	0
647366	646186	08061X	PARTICIPANT	\N	PRESENT	0
647367	646186	19591F	PARTICIPANT	\N	PRESENT	0
647368	646186	14111D	PARTICIPANT	\N	PRESENT	0
647369	646186	14221J	PARTICIPANT	\N	PRESENT	0
647370	646186	14195A	PARTICIPANT	\N	PRESENT	0
647371	646186	14251Q	PARTICIPANT	\N	PRESENT	0
647372	646186	19545Y	PARTICIPANT	\N	PRESENT	0
647373	646186	20122U	PARTICIPANT	\N	PRESENT	0
647374	646186	19717B	PARTICIPANT	\N	PRESENT	0
647375	646186	19387D	PARTICIPANT	\N	PRESENT	0
647376	646186	19719D	PARTICIPANT	\N	PRESENT	0
647377	646186	14073Q	PARTICIPANT	\N	PRESENT	0
647378	646186	11012A	PARTICIPANT	\N	PRESENT	0
647379	646186	20106U	PARTICIPANT	\N	PRESENT	0
647380	646186	19866P	PARTICIPANT	\N	PRESENT	0
647381	646186	20116W	PARTICIPANT	\N	PRESENT	0
647382	646186	20072C	PARTICIPANT	\N	PRESENT	0
647383	646186	98022P	PARTICIPANT	\N	PRESENT	0
647384	646186	19543W	PARTICIPANT	\N	PRESENT	0
647385	646186	14207L	PARTICIPANT	\N	PRESENT	0
647386	646186	20132W	PARTICIPANT	\N	PRESENT	0
647387	646186	19749K	PARTICIPANT	\N	PRESENT	0
647388	646186	19553Y	PARTICIPANT	\N	PRESENT	0
647389	646186	14253S	PARTICIPANT	\N	PRESENT	0
647390	646186	20248J	PARTICIPANT	\N	PRESENT	0
647391	646186	19681G	PARTICIPANT	\N	PRESENT	0
647392	646186	20060X	PARTICIPANT	\N	PRESENT	0
647393	646186	20042V	PARTICIPANT	\N	PRESENT	0
647394	646186	20052X	PARTICIPANT	\N	PRESENT	0
647395	646186	19699S	PARTICIPANT	\N	PRESENT	0
647396	646186	20048C	PARTICIPANT	\N	PRESENT	0
647427	646186	19713W	PARTICIPANT	\N	PRESENT	0
647398	646186	19441R	PARTICIPANT	\N	PRESENT	0
647399	646186	14219Q	PARTICIPANT	\N	PRESENT	0
647400	646186	14205J	PARTICIPANT	\N	PRESENT	0
647401	646186	14083S	PARTICIPANT	\N	PRESENT	0
647402	646186	19735D	PARTICIPANT	\N	PRESENT	0
647403	646186	16685X	PARTICIPANT	\N	PRESENT	0
647404	646186	20144B	PARTICIPANT	\N	PRESENT	0
647405	646186	11053K	PARTICIPANT	\N	PRESENT	0
647406	646186	14107H	PARTICIPANT	\N	PRESENT	0
647407	646186	19611R	PARTICIPANT	\N	PRESENT	0
647408	646186	08009T	PARTICIPANT	\N	PRESENT	0
647409	646186	14231L	PARTICIPANT	\N	PRESENT	0
647410	646186	14179A	PARTICIPANT	\N	PRESENT	0
647411	646186	19745F	PARTICIPANT	\N	PRESENT	0
647412	646186	20298U	PARTICIPANT	\N	PRESENT	0
647413	646186	14030Q	PARTICIPANT	\N	PRESENT	0
647414	646186	01043Q	PARTICIPANT	\N	PRESENT	0
647415	646186	14327T	PARTICIPANT	\N	PRESENT	0
647416	646186	01024M	PARTICIPANT	\N	PRESENT	0
647417	646186	04070G	PARTICIPANT	\N	PRESENT	0
647418	646186	11085T	PARTICIPANT	\N	PRESENT	0
647419	646186	14189C	PARTICIPANT	\N	PRESENT	0
647420	646186	19577H	PARTICIPANT	\N	PRESENT	0
647421	646186	19826F	PARTICIPANT	\N	PRESENT	0
647422	646186	17023S	PARTICIPANT	\N	PRESENT	0
647423	646186	19569H	PARTICIPANT	\N	PRESENT	0
647424	646186	14026U	PARTICIPANT	\N	PRESENT	0
647425	646186	20066E	PARTICIPANT	\N	PRESENT	0
647429	646186	20050V	PARTICIPANT	\N	PRESENT	0
647428	646186	08010L	PARTICIPANT	\N	PRESENT	0
629617	629307	19507S	PARTICIPANT	\N	PRESENT	0
629620	629307	19531S	PARTICIPANT	\N	PRESENT	0
629622	629122	19565D	PARTICIPANT	\N	PRESENT	0
629632	629307	14030Q	PARTICIPANT	\N	PRESENT	0
629636	629307	19711U	PARTICIPANT	\N	PRESENT	0
629637	629307	20054A	PARTICIPANT	\N	PRESENT	0
629638	629307	20026V	PARTICIPANT	\N	PRESENT	0
629639	629399	19383Y	PARTICIPANT	\N	PRESENT	0
629640	629399	20088L	PARTICIPANT	\N	PRESENT	0
629641	629399	19515S	PARTICIPANT	\N	PRESENT	0
629642	629399	20092G	PARTICIPANT	\N	PRESENT	0
629643	629399	14357A	PARTICIPANT	\N	PRESENT	0
629644	629399	20078J	PARTICIPANT	\N	PRESENT	0
629645	629399	19413M	PARTICIPANT	\N	PRESENT	0
629646	629399	20082E	PARTICIPANT	\N	PRESENT	1
629647	629399	04045F	PARTICIPANT	\N	PRESENT	1
629648	629399	19631V	PARTICIPANT	\N	PRESENT	1
629649	629399	19705W	PARTICIPANT	\N	PRESENT	1
629650	629399	19707Y	PARTICIPANT	\N	PRESENT	1
629651	629399	19575F	PARTICIPANT	\N	PRESENT	1
629652	629399	20018V	PARTICIPANT	\N	PRESENT	0
629653	629399	08028W	PARTICIPANT	\N	PRESENT	0
629654	629399	20028X	PARTICIPANT	\N	PRESENT	0
629655	629399	20030R	PARTICIPANT	\N	PRESENT	0
629656	629399	19467C	PARTICIPANT	\N	PRESENT	0
629657	629399	20034V	PARTICIPANT	\N	PRESENT	0
629658	629399	14187A	PARTICIPANT	\N	PRESENT	0
629659	629399	11090Q	PRESIDENT	0	PRESENT	0
629660	629399	14033T	PARTICIPANT	\N	PRESENT	0
629661	629399	20054A	PARTICIPANT	\N	PRESENT	0
629662	629399	20174H	PARTICIPANT	\N	PRESENT	1
629663	629399	20062A	PARTICIPANT	\N	PRESENT	0
629664	629399	19507S	PARTICIPANT	\N	PRESENT	0
629665	629399	19747H	PARTICIPANT	\N	PRESENT	0
629666	629399	14257W	PARTICIPANT	\N	PRESENT	0
629674	629307	14259Y	PARTICIPANT	\N	PRESENT	0
629668	629307	19251M	PARTICIPANT	\N	PRESENT	0
629669	629307	20116W	PARTICIPANT	\N	PRESENT	0
629670	629307	01048V	PARTICIPANT	\N	PRESENT	0
629673	629307	20090E	PARTICIPANT	\N	PRESENT	0
629675	629307	19543W	PARTICIPANT	\N	PRESENT	0
629678	629307	14189C	PARTICIPANT	\N	PRESENT	0
629681	629321	19533U	PRESIDENT	0	PRESENT	0
629682	629321	19820Y	PARTICIPANT	\N	PRESENT	0
629683	629321	14207L	PARTICIPANT	\N	PRESENT	0
629684	629321	19693L	PARTICIPANT	\N	PRESENT	0
629685	629321	04045F	PARTICIPANT	\N	PRESENT	0
629686	629321	19599P	PARTICIPANT	\N	PRESENT	0
629687	629321	20112S	PARTICIPANT	\N	EXCUSE	0
629741	629308	14253S	PARTICIPANT	\N	PRESENT	0
629744	629308	14251Q	PARTICIPANT	\N	PRESENT	0
629746	629308	11012A	PARTICIPANT	\N	PRESENT	0
629747	629308	14073Q	PARTICIPANT	\N	PRESENT	0
629748	629308	19413M	PARTICIPANT	\N	PRESENT	0
629749	629308	19251M	PARTICIPANT	\N	PRESENT	0
629750	629308	20088L	PARTICIPANT	\N	PRESENT	0
629751	629308	20030R	PARTICIPANT	\N	PRESENT	0
629752	629308	14257W	PARTICIPANT	\N	PRESENT	0
629753	629308	04045F	PARTICIPANT	\N	PRESENT	0
629754	629308	01025N	PARTICIPANT	\N	PRESENT	0
629755	629308	19739H	PARTICIPANT	\N	PRESENT	0
629756	629122	12041X	PARTICIPANT	\N	PRESENT	0
629837	629323	07004J	PARTICIPANT	\N	EXCUSE	0
629838	629323	14249W	PARTICIPANT	\N	EXCUSE	0
629839	629323	19667J	PRESIDENT	0	PRESENT	0
629840	629308	19399H	PARTICIPANT	\N	PRESENT	0
629841	629323	19711U	PARTICIPANT	\N	PRESENT	0
629835	629308	20116W	PARTICIPANT	\N	PRESENT	0
629836	629308	14207L	PARTICIPANT	\N	PRESENT	0
629842	629323	20038A	PARTICIPANT	\N	PRESENT	0
629843	629323	19511N	PARTICIPANT	\N	PRESENT	0
629844	629323	20064C	PARTICIPANT	\N	PRESENT	0
629845	629323	20044X	PARTICIPANT	\N	PRESENT	0
629846	629323	04085P	PARTICIPANT	\N	PRESENT	0
629847	629323	19585H	PARTICIPANT	\N	PRESENT	0
629848	629308	19383Y	PARTICIPANT	\N	PRESENT	0
629849	629308	19762G	PARTICIPANT	\N	PRESENT	0
629850	629308	20024T	PARTICIPANT	\N	PRESENT	0
629851	629308	14357A	PARTICIPANT	\N	PRESENT	0
629852	629308	19349W	PARTICIPANT	\N	PRESENT	0
629853	629308	19651A	PARTICIPANT	\N	PRESENT	0
629854	629308	19563B	PARTICIPANT	\N	PRESENT	0
629855	629308	20174H	PARTICIPANT	\N	PRESENT	0
629856	629308	14030Q	PARTICIPANT	\N	PRESENT	0
629872	629308	19367Y	PARTICIPANT	\N	PRESENT	0
629873	629308	01060R	PARTICIPANT	\N	PRESENT	0
629874	629308	20080C	PARTICIPANT	\N	PRESENT	0
629875	629323	17737W	PARTICIPANT	\N	PRESENT	0
629876	629308	20026V	PARTICIPANT	\N	PRESENT	0
629877	629308	14225N	PARTICIPANT	\N	PRESENT	0
629878	629308	20056C	PARTICIPANT	\N	PRESENT	0
629879	629308	19467C	PARTICIPANT	\N	PRESENT	0
629880	629308	19479G	PARTICIPANT	\N	PRESENT	0
629894	629308	14147R	PARTICIPANT	\N	PRESENT	0
629896	629308	01048V	PARTICIPANT	\N	PRESENT	0
629897	629308	20052X	PARTICIPANT	\N	PRESENT	0
629898	629308	19713W	PARTICIPANT	\N	PRESENT	0
629899	629308	11048N	PARTICIPANT	\N	PRESENT	0
629737	629308	19507S	PARTICIPANT	\N	PRESENT	0
629738	629308	19531S	PARTICIPANT	\N	PRESENT	0
629900	629308	19760E	PARTICIPANT	\N	PRESENT	0
629901	629308	19758L	PARTICIPANT	\N	PRESENT	0
629902	629308	20102Q	PARTICIPANT	\N	PRESENT	0
629913	629308	17229F	PARTICIPANT	\N	PRESENT	0
629914	629308	20082E	PARTICIPANT	\N	PRESENT	0
629915	629308	11097X	PARTICIPANT	\N	PRESENT	0
629916	629308	20058E	PARTICIPANT	\N	PRESENT	0
629917	629308	19820Y	PARTICIPANT	\N	PRESENT	0
629918	629308	19515S	PARTICIPANT	\N	PRESENT	0
629919	629308	20078J	PARTICIPANT	\N	PRESENT	0
629920	629308	19798U	PARTICIPANT	\N	PRESENT	0
629921	629308	20180F	PARTICIPANT	\N	PRESENT	0
629924	629308	14083S	PARTICIPANT	\N	PRESENT	0
629925	629308	08056B	PARTICIPANT	\N	PRESENT	0
629926	629308	14195A	PARTICIPANT	\N	PRESENT	0
629927	629308	19691J	PARTICIPANT	\N	PRESENT	0
629928	629308	01034P	PARTICIPANT	\N	PRESENT	0
629929	629308	14059S	PARTICIPANT	\N	PRESENT	0
629930	629308	20044X	PARTICIPANT	\N	PRESENT	0
629931	629308	17737W	PARTICIPANT	\N	PRESENT	0
629932	629308	19703U	PARTICIPANT	\N	PRESENT	0
629933	629308	20140W	PARTICIPANT	\N	PRESENT	0
629934	629308	19629C	PARTICIPANT	\N	PRESENT	0
629935	629308	01024M	PARTICIPANT	\N	PRESENT	0
629936	629308	14169X	PARTICIPANT	\N	PRESENT	0
629937	629308	11067R	PARTICIPANT	\N	PRESENT	0
629938	629308	14031R	PARTICIPANT	\N	PRESENT	0
629939	629308	20104S	PARTICIPANT	\N	PRESENT	0
629940	629308	97011G	PARTICIPANT	\N	PRESENT	0
629941	629308	19954N	PARTICIPANT	\N	PRESENT	0
629942	629308	14329V	PARTICIPANT	\N	PRESENT	0
629943	629308	20076G	PARTICIPANT	\N	PRESENT	0
629944	629308	19503N	PARTICIPANT	\N	PRESENT	0
629945	629308	20108W	PARTICIPANT	\N	PRESENT	0
629946	629308	19543W	PARTICIPANT	\N	PRESENT	0
629947	629308	18193Q	PARTICIPANT	\N	PRESENT	0
629948	629308	19749K	PARTICIPANT	\N	PRESENT	0
629949	629308	17637T	PARTICIPANT	\N	PRESENT	0
629950	629308	11101A	PARTICIPANT	\N	PRESENT	0
629951	629308	01057W	PARTICIPANT	\N	PRESENT	0
629952	629308	20126Y	PARTICIPANT	\N	PRESENT	0
629953	629308	19723Y	PARTICIPANT	\N	PRESENT	0
629954	629308	19415P	PARTICIPANT	\N	PRESENT	0
629955	629308	14133K	PARTICIPANT	\N	PRESENT	0
629956	629308	14217N	PARTICIPANT	\N	PRESENT	0
639184	638990	20032T	PARTICIPANT	\N	PRESENT	0
639185	638990	20076G	PARTICIPANT	\N	PRESENT	0
639186	638990	20024T	PARTICIPANT	\N	PRESENT	0
639187	638990	19549D	PARTICIPANT	\N	PRESENT	0
639188	638990	08060W	PARTICIPANT	\N	PRESENT	1
639189	638990	18083K	PARTICIPANT	\N	PRESENT	0
639190	638990	20140W	PARTICIPANT	\N	PRESENT	1
639191	638990	17229F	PARTICIPANT	\N	PRESENT	0
639192	638990	19251M	PARTICIPANT	\N	PRESENT	1
639193	638990	20100N	PARTICIPANT	\N	PRESENT	0
639194	638990	19599P	PARTICIPANT	\N	PRESENT	0
639195	638990	20120S	PARTICIPANT	\N	PRESENT	0
639196	638990	19820Y	PARTICIPANT	\N	PRESENT	0
639197	638990	19387D	PARTICIPANT	\N	PRESENT	1
639198	638990	20068G	PARTICIPANT	\N	PRESENT	0
639199	638990	19685L	PARTICIPANT	\N	PRESENT	0
639200	638990	19333N	PARTICIPANT	\N	PRESENT	0
639201	638990	20102Q	PARTICIPANT	\N	PRESENT	0
639202	638990	14219Q	PARTICIPANT	\N	PRESENT	0
639203	638990	14031R	PARTICIPANT	\N	PRESENT	0
639204	638990	19745F	PARTICIPANT	\N	PRESENT	0
639205	638990	20118Y	PARTICIPANT	\N	PRESENT	0
639206	638990	19503N	PARTICIPANT	\N	PRESENT	0
639207	638990	19619A	PARTICIPANT	\N	PRESENT	0
639208	638990	20136B	PARTICIPANT	\N	PRESENT	1
639209	638990	20046A	PARTICIPANT	\N	PRESENT	1
639236	638885	14213J	PARTICIPANT	\N	PRESENT	1
639239	638885	11031D	PARTICIPANT	\N	EXCUSE	0
639240	638885	19657G	PARTICIPANT	\N	PRESENT	1
639249	638885	14042U	PARTICIPANT	\N	PRESENT	0
639255	638885	20040T	PARTICIPANT	\N	PRESENT	0
639256	638885	14223L	PARTICIPANT	\N	PRESENT	0
639263	638885	20130U	PARTICIPANT	\N	PRESENT	1
639269	638885	19798U	PARTICIPANT	\N	PRESENT	1
639272	638885	19683J	PARTICIPANT	\N	PRESENT	1
639273	638885	19553Y	PARTICIPANT	\N	PRESENT	1
639276	638395	19415P	PARTICIPANT	\N	PRESENT	0
639277	638395	11067R	PARTICIPANT	\N	PRESENT	1
639278	638395	14213J	PARTICIPANT	\N	PRESENT	1
639279	638395	17965H	PARTICIPANT	\N	PRESENT	1
639280	638395	19760E	PARTICIPANT	\N	PRESENT	0
639281	638395	19715Y	PARTICIPANT	\N	PRESENT	0
639284	639282	19415P	PARTICIPANT	\N	PRESENT	0
639285	639282	19715Y	PARTICIPANT	\N	PRESENT	0
639286	639282	11067R	PARTICIPANT	\N	PRESENT	0
639473	639472	14030Q	PARTICIPANT	\N	PRESENT	0
639512	639511	19415P	PARTICIPANT	\N	PRESENT	0
639513	639511	11067R	PARTICIPANT	\N	PRESENT	0
639514	639511	19798U	PARTICIPANT	\N	PRESENT	1
639516	639515	05008E	PARTICIPANT	\N	PRESENT	0
639517	639515	11053K	PARTICIPANT	\N	PRESENT	0
639518	639515	01028R	PARTICIPANT	\N	PRESENT	0
639520	639519	14331P	PARTICIPANT	\N	PRESENT	0
639521	639519	19725B	PARTICIPANT	\N	PRESENT	0
639522	639519	11083R	PARTICIPANT	\N	PRESENT	0
639638	639637	04008A	PARTICIPANT	\N	PRESENT	0
639639	639637	19543W	PARTICIPANT	\N	PRESENT	0
639640	639637	14151M	PARTICIPANT	\N	PRESENT	0
639642	639641	14147R	PARTICIPANT	\N	PRESENT	0
639644	639643	17367Q	PARTICIPANT	\N	PRESENT	0
639645	639643	11083R	PARTICIPANT	\N	PRESENT	0
639649	639648	14327T	PARTICIPANT	\N	PRESENT	0
639659	639658	14225N	PARTICIPANT	\N	PRESENT	0
639660	639658	11048N	PARTICIPANT	\N	PRESENT	0
639661	639658	14331P	PARTICIPANT	\N	PRESENT	0
639662	639658	19335Q	PARTICIPANT	\N	PRESENT	0
639664	639663	20086J	PARTICIPANT	\N	PRESENT	0
639666	639665	20086J	PARTICIPANT	\N	PRESENT	0
639668	639667	20086J	PARTICIPANT	\N	PRESENT	0
639670	639669	99004R	PARTICIPANT	\N	PRESENT	0
639672	639671	99004R	PARTICIPANT	\N	PRESENT	0
639674	639673	14253S	PARTICIPANT	\N	PRESENT	0
639677	639676	14253S	PARTICIPANT	\N	PRESENT	0
639678	639676	08011M	PARTICIPANT	\N	PRESENT	0
639680	639679	14253S	PARTICIPANT	\N	PRESENT	0
639681	639679	08011M	PARTICIPANT	\N	PRESENT	0
639947	639946	14133K	PARTICIPANT	\N	PRESENT	0
639948	639946	11083R	PARTICIPANT	\N	PRESENT	0
639949	639946	19721W	PARTICIPANT	\N	PRESENT	0
639950	639946	11066Q	PARTICIPANT	\N	PRESENT	0
639952	639951	14133K	PARTICIPANT	\N	PRESENT	0
639953	639951	11083R	PARTICIPANT	\N	PRESENT	0
639972	639971	14207L	PARTICIPANT	\N	PRESENT	0
639973	639971	20042V	PARTICIPANT	\N	PRESENT	0
639974	639971	17589D	PARTICIPANT	\N	PRESENT	0
639976	639975	14207L	PARTICIPANT	\N	PRESENT	0
639977	639975	20124W	PARTICIPANT	\N	PRESENT	0
639978	639975	19533U	PARTICIPANT	\N	PRESENT	0
639980	639979	20110Q	PARTICIPANT	\N	PRESENT	0
639981	639979	14207L	PARTICIPANT	\N	PRESENT	0
639982	639979	20114U	PARTICIPANT	\N	PRESENT	0
639983	639979	19533U	PARTICIPANT	\N	PRESENT	0
640000	639998	19673G	PARTICIPANT	\N	PRESENT	0
639986	639985	14151M	PARTICIPANT	\N	PRESENT	0
639987	639985	04008A	PARTICIPANT	\N	PRESENT	0
639988	639985	19543W	PARTICIPANT	\N	PRESENT	0
639989	639985	14147R	PARTICIPANT	\N	PRESENT	0
639991	639990	14151M	PARTICIPANT	\N	PRESENT	0
639992	639990	19543W	PARTICIPANT	\N	PRESENT	0
639993	639990	14147R	PARTICIPANT	\N	PRESENT	0
639997	639996	01058X	PARTICIPANT	\N	PRESENT	0
639999	639998	18083K	PARTICIPANT	\N	PRESENT	0
640105	639623	19593H	PARTICIPANT	\N	PRESENT	0
640106	639623	20026V	PARTICIPANT	\N	PRESENT	0
640139	640064	20032T	PARTICIPANT	\N	PRESENT	0
640140	640064	19701S	PARTICIPANT	\N	PRESENT	0
640141	640064	14031R	PARTICIPANT	\N	PRESENT	0
640142	640064	20140W	PARTICIPANT	\N	PRESENT	0
640143	640064	14219Q	PARTICIPANT	\N	PRESENT	0
640144	640064	20046A	PARTICIPANT	\N	PRESENT	0
640145	640064	19599P	PARTICIPANT	\N	PRESENT	0
640146	640064	17229F	PARTICIPANT	\N	PRESENT	0
640147	640064	18083K	PARTICIPANT	\N	PRESENT	0
640148	640064	20100N	PARTICIPANT	\N	PRESENT	0
640149	640064	20068G	PARTICIPANT	\N	PRESENT	0
640150	640064	19745F	PARTICIPANT	\N	PRESENT	0
640151	640064	20024T	PARTICIPANT	\N	PRESENT	0
640152	640064	20076G	PARTICIPANT	\N	PRESENT	0
640153	640064	19387D	PARTICIPANT	\N	PRESENT	0
640154	640064	19659J	PARTICIPANT	\N	PRESENT	0
640155	637810	14189C	PARTICIPANT	\N	PRESENT	0
640156	637810	20024T	PARTICIPANT	\N	PRESENT	0
640157	637810	14030Q	PRESIDENT	0	PRESENT	0
640158	637810	20138D	PARTICIPANT	\N	EXCUSE	0
640159	637810	20080C	PARTICIPANT	\N	EXCUSE	0
640160	637810	11031D	PARTICIPANT	\N	PRESENT	0
640161	637810	19693L	PARTICIPANT	\N	PRESENT	0
640162	637810	14179A	PARTICIPANT	\N	PRESENT	1
640163	637810	20066E	PARTICIPANT	\N	EXCUSE	0
640164	637810	07029T	PARTICIPANT	\N	EXCUSE	0
640165	637810	14109K	PARTICIPANT	\N	PRESENT	1
640166	637810	20118Y	PARTICIPANT	\N	EXCUSE	0
640167	637810	11045K	PARTICIPANT	\N	PRESENT	1
640168	637810	20098N	PARTICIPANT	\N	EXCUSE	0
640169	640064	20038A	PARTICIPANT	\N	PRESENT	0
640170	640064	19549D	PARTICIPANT	\N	PRESENT	0
640171	640064	19820Y	PARTICIPANT	\N	PRESENT	0
640172	640064	20096L	PARTICIPANT	\N	PRESENT	0
640173	640064	20106U	PARTICIPANT	\N	PRESENT	0
640174	640064	19503N	PARTICIPANT	\N	PRESENT	0
640175	640064	20020P	PARTICIPANT	\N	PRESENT	0
640176	640064	19685L	PARTICIPANT	\N	PRESENT	0
640185	640064	19333N	PARTICIPANT	\N	PRESENT	0
640192	639954	11056N	PRESIDENT	0	PRESENT	0
640214	639954	11026G	PARTICIPANT	\N	PRESENT	0
640194	639954	20098N	PARTICIPANT	\N	EXCUSE	0
640195	639954	04047H	PARTICIPANT	\N	EXCUSE	0
640196	640064	19739H	PARTICIPANT	\N	PRESENT	0
640207	640064	19826F	PARTICIPANT	\N	PRESENT	0
640208	640064	20102Q	PARTICIPANT	\N	PRESENT	0
640209	640064	19251M	PARTICIPANT	\N	PRESENT	0
640210	640064	19681G	PARTICIPANT	\N	PRESENT	0
640212	639954	14089Y	PARTICIPANT	\N	PRESENT	0
640213	639954	20040T	PARTICIPANT	\N	PRESENT	0
640215	639954	19826F	PARTICIPANT	\N	PRESENT	0
640216	639954	20024T	PARTICIPANT	\N	PRESENT	0
640218	639954	20108W	PARTICIPANT	\N	PRESENT	0
640219	639954	17367Q	PARTICIPANT	\N	PRESENT	0
632930	631706	97011G	PARTICIPANT	\N	PRESENT	0
632931	631706	08061X	PARTICIPANT	\N	PRESENT	0
632932	631706	14249W	PARTICIPANT	\N	PRESENT	0
632933	631706	08047A	PARTICIPANT	\N	PRESENT	0
632934	631706	14059S	PARTICIPANT	\N	PRESENT	0
632935	631706	14097Y	PARTICIPANT	\N	PRESENT	0
632936	631706	04035D	PARTICIPANT	\N	PRESENT	0
632937	631706	01062T	PARTICIPANT	\N	PRESENT	1
632938	631706	08069G	PARTICIPANT	\N	PRESENT	0
632939	631706	01024M	PARTICIPANT	\N	PRESENT	0
632940	631706	14105F	PARTICIPANT	\N	PRESENT	0
632941	631706	11064N	PARTICIPANT	\N	PRESENT	0
632942	631706	11083R	PARTICIPANT	\N	PRESENT	0
632943	631706	14211G	PARTICIPANT	\N	PRESENT	0
632944	631706	14255U	PARTICIPANT	\N	PRESENT	0
632945	631706	17023S	PARTICIPANT	\N	PRESENT	0
632947	631706	95041E	PARTICIPANT	\N	EXCUSE	0
632973	631566	19527W	PARTICIPANT	\N	PRESENT	0
632974	631566	14331P	PARTICIPANT	\N	PRESENT	0
632975	631566	20062A	PARTICIPANT	\N	PRESENT	0
632976	631566	14105F	PARTICIPANT	\N	PRESENT	0
632977	631566	19383Y	PARTICIPANT	\N	PRESENT	0
632978	631566	08028W	PARTICIPANT	\N	PRESENT	0
632979	631566	14173T	PARTICIPANT	\N	PRESENT	0
632980	631566	14111D	PARTICIPANT	\N	PRESENT	0
632981	631566	11043H	PARTICIPANT	\N	PRESENT	0
632982	631566	20266L	PARTICIPANT	\N	PRESENT	0
632983	631566	14207L	PARTICIPANT	\N	PRESENT	0
632984	631566	14107H	PARTICIPANT	\N	PRESENT	0
632985	631566	14042U	PARTICIPANT	\N	PRESENT	0
632986	631566	20298U	PARTICIPANT	\N	PRESENT	0
632987	631566	14151M	PARTICIPANT	\N	PRESENT	0
632988	631566	11041F	PARTICIPANT	\N	PRESENT	0
632989	631566	20106U	PARTICIPANT	\N	PRESENT	0
632990	631566	19563B	PARTICIPANT	\N	PRESENT	0
632991	631566	17229F	PARTICIPANT	\N	PRESENT	0
632992	631566	14195A	PARTICIPANT	\N	PRESENT	0
632993	631566	20080C	PARTICIPANT	\N	PRESENT	0
632994	631566	19820Y	PARTICIPANT	\N	PRESENT	0
632995	631566	20030R	PARTICIPANT	\N	PRESENT	0
632996	631566	12028B	PARTICIPANT	\N	PRESENT	0
632997	631566	19631V	PARTICIPANT	\N	PRESENT	0
632998	631566	19251M	PARTICIPANT	\N	PRESENT	0
632999	631566	19599P	PARTICIPANT	\N	PRESENT	0
633000	631566	01028R	PARTICIPANT	\N	PRESENT	0
633001	631566	19347U	PARTICIPANT	\N	PRESENT	0
633002	631566	20036X	PARTICIPANT	\N	PRESENT	0
633003	631566	04045F	PARTICIPANT	\N	PRESENT	0
633004	631566	19349W	PARTICIPANT	\N	PRESENT	0
633005	631566	19717B	PARTICIPANT	\N	PRESENT	0
633006	631566	20084G	PARTICIPANT	\N	PRESENT	0
633007	631566	19725B	PARTICIPANT	\N	PRESENT	0
633011	631566	18193Q	PARTICIPANT	\N	PRESENT	0
633009	631566	14281W	PARTICIPANT	\N	PRESENT	0
633010	631566	11104D	PARTICIPANT	\N	PRESENT	0
633012	631566	11054L	PARTICIPANT	\N	PRESENT	0
633013	631566	17965H	PARTICIPANT	\N	PRESENT	0
633014	631566	20060X	PARTICIPANT	\N	PRESENT	0
633015	631566	08012N	PARTICIPANT	\N	PRESENT	0
633016	631566	20088L	PARTICIPANT	\N	PRESENT	0
633017	631566	14097Y	PARTICIPANT	\N	PRESENT	0
633018	631566	14231L	PARTICIPANT	\N	PRESENT	0
633019	631566	11045K	PARTICIPANT	\N	PRESENT	0
633020	631566	20092G	PARTICIPANT	\N	PRESENT	0
633021	631566	20110Q	PARTICIPANT	\N	PRESENT	0
633022	631566	20050V	PARTICIPANT	\N	PRESENT	0
633023	631566	19585H	PARTICIPANT	\N	PRESENT	0
633024	631566	04057K	PARTICIPANT	\N	PRESENT	0
633025	631566	11064N	PARTICIPANT	\N	PRESENT	0
633026	631566	20122U	PARTICIPANT	\N	PRESENT	0
633027	631566	20042V	PARTICIPANT	\N	PRESENT	0
633028	631566	14257W	PARTICIPANT	\N	PRESENT	0
633029	631566	19503N	PARTICIPANT	\N	PRESENT	0
633030	631566	19333N	PARTICIPANT	\N	PRESENT	0
633031	631566	14211G	PARTICIPANT	\N	PRESENT	0
633032	631566	11101A	PARTICIPANT	\N	PRESENT	0
633033	631566	19703U	PARTICIPANT	\N	PRESENT	0
633034	631566	20028X	PARTICIPANT	\N	PRESENT	0
633035	631566	04035D	PARTICIPANT	\N	PRESENT	0
633036	631566	19693L	PARTICIPANT	\N	PRESENT	0
633037	631566	19760E	PARTICIPANT	\N	PRESENT	0
633038	631566	19575F	PARTICIPANT	\N	PRESENT	0
633039	631566	04085P	PARTICIPANT	\N	PRESENT	0
633040	631566	01058X	PARTICIPANT	\N	PRESENT	0
633041	631566	11031D	PARTICIPANT	\N	PRESENT	0
633042	631566	99004R	PARTICIPANT	\N	PRESENT	0
633043	631566	19758L	PARTICIPANT	\N	PRESENT	0
633044	631566	04047H	PARTICIPANT	\N	PRESENT	0
633045	631566	11077T	PARTICIPANT	\N	PRESENT	0
633046	631566	19533U	PARTICIPANT	\N	PRESENT	0
633047	631566	08034U	PARTICIPANT	\N	PRESENT	0
633048	631566	11048N	PARTICIPANT	\N	PRESENT	0
633049	631566	18083K	PARTICIPANT	\N	PRESENT	0
633050	631566	20078J	PARTICIPANT	\N	PRESENT	0
633051	631566	20076G	PARTICIPANT	\N	PRESENT	0
633052	631566	19679N	PARTICIPANT	\N	PRESENT	0
633053	631566	19643A	PARTICIPANT	\N	PRESENT	0
633054	631566	14169X	PARTICIPANT	\N	PRESENT	0
633055	631566	20054A	PARTICIPANT	\N	PRESENT	0
633056	631566	04033B	PARTICIPANT	\N	PRESENT	0
633057	631566	14187A	PARTICIPANT	\N	PRESENT	0
633058	631566	14071N	PARTICIPANT	\N	PRESENT	0
633059	631566	11097X	PARTICIPANT	\N	PRESENT	0
633060	631566	04092N	PARTICIPANT	\N	PRESENT	0
633061	631566	14053L	PARTICIPANT	\N	PRESENT	0
633062	631566	19701S	PARTICIPANT	\N	PRESENT	0
633063	631566	14069U	PARTICIPANT	\N	PRESENT	0
633064	631566	04043D	PARTICIPANT	\N	PRESENT	0
633065	631566	19705W	PARTICIPANT	\N	PRESENT	0
633067	631566	19707Y	PARTICIPANT	\N	PRESENT	0
633068	631566	14033T	PARTICIPANT	\N	PRESENT	0
633069	631566	19954N	PARTICIPANT	\N	PRESENT	0
633073	631566	14357A	PARTICIPANT	\N	PRESENT	0
633074	631566	14259Y	PARTICIPANT	\N	PRESENT	0
633075	631566	01057W	PARTICIPANT	\N	PRESENT	0
633076	631566	20068G	PARTICIPANT	\N	PRESENT	0
633077	631566	20022R	PARTICIPANT	\N	PRESENT	0
633078	631566	14026U	PARTICIPANT	\N	PRESENT	0
633079	631566	04059M	PARTICIPANT	\N	PRESENT	0
633080	631566	14031R	PARTICIPANT	\N	PRESENT	0
633081	631566	19667J	PARTICIPANT	\N	PRESENT	0
633082	631566	20134Y	PARTICIPANT	\N	PRESENT	0
633083	631566	20180F	PARTICIPANT	\N	PRESENT	0
633084	631566	04071H	PARTICIPANT	\N	PRESENT	0
633085	631566	11033F	PARTICIPANT	\N	PRESENT	0
633086	631566	19651A	PARTICIPANT	\N	PRESENT	0
633087	631566	19782L	PARTICIPANT	\N	PRESENT	0
633088	631566	19762G	PARTICIPANT	\N	PRESENT	0
633089	631566	19729F	PARTICIPANT	\N	PRESENT	0
633090	631566	19525U	PARTICIPANT	\N	PRESENT	0
633091	631566	14249W	PARTICIPANT	\N	PRESENT	0
633092	631566	20174H	PARTICIPANT	\N	PRESENT	0
633093	631566	11083R	PARTICIPANT	\N	PRESENT	0
633094	631566	20020P	PARTICIPANT	\N	PRESENT	0
633095	631566	20128B	PARTICIPANT	\N	PRESENT	0
633096	631566	20252E	PARTICIPANT	\N	PRESENT	0
633097	631566	19671E	PARTICIPANT	\N	PRESENT	0
633098	631566	19697Q	PARTICIPANT	\N	PRESENT	0
633099	631566	19798U	PARTICIPANT	\N	PRESENT	0
633100	631566	08056B	PARTICIPANT	\N	PRESENT	0
633101	631566	11072N	PARTICIPANT	\N	PRESENT	0
633102	631566	20124W	PARTICIPANT	\N	PRESENT	0
633103	631566	08061X	PARTICIPANT	\N	PRESENT	0
633104	631566	20090E	PARTICIPANT	\N	PRESENT	0
633105	631566	95063L	PARTICIPANT	\N	PRESENT	0
633106	631566	20172F	PARTICIPANT	\N	PRESENT	0
633107	631566	04008A	PARTICIPANT	\N	PRESENT	0
633108	631566	20100N	PARTICIPANT	\N	PRESENT	0
633109	631566	17637T	PARTICIPANT	\N	PRESENT	0
633110	631566	20096L	PARTICIPANT	\N	PRESENT	0
633111	631566	11040E	PARTICIPANT	\N	PRESENT	0
633112	631566	19573D	PARTICIPANT	\N	PRESENT	0
633113	631566	19447X	PARTICIPANT	\N	PRESENT	0
633114	631566	11056N	PARTICIPANT	\N	PRESENT	0
633115	631566	19687N	PARTICIPANT	\N	PRESENT	0
633116	631566	20102Q	PARTICIPANT	\N	PRESENT	0
647430	646186	14105F	PARTICIPANT	\N	PRESENT	0
647431	646186	19741B	PARTICIPANT	\N	PRESENT	0
647432	646186	19479G	PARTICIPANT	\N	PRESENT	0
647433	646186	20286Q	PARTICIPANT	\N	PRESENT	0
647434	646186	14042U	PARTICIPANT	\N	PRESENT	0
647435	646186	20086J	PARTICIPANT	\N	PRESENT	0
647436	646186	19057M	PARTICIPANT	\N	PRESENT	0
647437	646186	19691J	PARTICIPANT	\N	PRESENT	0
647438	646186	19619A	PARTICIPANT	\N	PRESENT	0
647439	646108	14001X	PARTICIPANT	\N	PRESENT	0
647440	646108	12041X	PARTICIPANT	\N	PRESENT	0
647441	646108	04070G	PARTICIPANT	\N	PRESENT	1
647445	646108	19701S	PARTICIPANT	\N	PRESENT	1
647443	646108	20104S	PRESIDENT	0	PRESENT	0
647444	646108	20286Q	PARTICIPANT	\N	PRESENT	1
647446	646108	14026U	PARTICIPANT	\N	PRESENT	1
647447	646108	19725B	PARTICIPANT	\N	PRESENT	0
647448	646108	14073Q	PARTICIPANT	\N	PRESENT	0
647449	646108	14033T	PARTICIPANT	\N	PRESENT	0
647450	646108	14169X	PARTICIPANT	\N	PRESENT	0
647451	646108	11101A	PARTICIPANT	\N	PRESENT	1
647452	646108	14097Y	PARTICIPANT	\N	PRESENT	0
647455	643944	97011G	PARTICIPANT	\N	PRESENT	0
647456	643944	20034V	PARTICIPANT	\N	PRESENT	0
647457	643944	14219Q	PARTICIPANT	\N	EXCUSE	0
647458	643944	14147R	PARTICIPANT	\N	PRESENT	1
647459	643944	19301E	PARTICIPANT	\N	PRESENT	0
647460	643944	11043H	PARTICIPANT	\N	EXCUSE	0
647479	646156	19515S	PARTICIPANT	\N	PRESENT	0
647480	646156	19251M	PARTICIPANT	\N	PRESENT	0
647481	646156	20092G	PARTICIPANT	\N	PRESENT	0
647482	646156	14083S	PARTICIPANT	\N	PRESENT	0
647483	646156	14031R	PARTICIPANT	\N	PRESENT	0
647484	646156	16685X	PARTICIPANT	\N	PRESENT	0
647485	646156	05012A	PARTICIPANT	\N	PRESENT	0
647486	646156	14231L	PARTICIPANT	\N	PRESENT	0
647487	646156	19735D	PARTICIPANT	\N	PRESENT	0
647488	646156	14329V	PARTICIPANT	\N	PRESENT	1
647489	646156	19575F	PARTICIPANT	\N	PRESENT	1
647490	646156	19467C	PARTICIPANT	\N	PRESENT	1
647491	646156	14030Q	PARTICIPANT	\N	PRESENT	1
647492	646156	19758L	PARTICIPANT	\N	PRESENT	0
647493	646156	14229S	PARTICIPANT	\N	PRESENT	0
647494	646156	20084G	PARTICIPANT	\N	PRESENT	0
647495	646156	20070A	PARTICIPANT	\N	PRESENT	0
647496	646156	08010L	PARTICIPANT	\N	PRESENT	0
647497	646156	19826F	PARTICIPANT	\N	PRESENT	0
647498	646156	20110Q	PARTICIPANT	\N	PRESENT	0
647499	646156	19447X	PARTICIPANT	\N	PRESENT	0
647500	646156	19820Y	PARTICIPANT	\N	PRESENT	1
647501	646156	20024T	PARTICIPANT	\N	PRESENT	1
647502	646156	20058E	PARTICIPANT	\N	PRESENT	1
647503	646156	20120S	PARTICIPANT	\N	PRESENT	1
647504	646156	04045F	PARTICIPANT	\N	PRESENT	1
647505	646156	20090E	PARTICIPANT	\N	PRESENT	0
647506	646156	14205J	PARTICIPANT	\N	PRESENT	1
647507	646156	14257W	PARTICIPANT	\N	PRESENT	0
647509	647508	20134Y	PARTICIPANT	\N	PRESENT	0
647510	647508	19251M	PARTICIPANT	\N	PRESENT	0
647511	647508	19515S	PRESIDENT	0	PRESENT	0
647512	647508	14083S	PARTICIPANT	\N	PRESENT	0
647513	647508	16685X	PARTICIPANT	\N	PRESENT	0
647514	646156	20126Y	PARTICIPANT	\N	PRESENT	1
647515	646108	20094J	PARTICIPANT	\N	EXCUSE	0
647516	646108	08018U	PARTICIPANT	\N	EXCUSE	0
647520	646156	19349W	PARTICIPANT	\N	PRESENT	0
647523	647522	05008E	PARTICIPANT	\N	PRESENT	0
647524	647522	11053K	PARTICIPANT	\N	PRESENT	0
647525	647522	01028R	PARTICIPANT	\N	PRESENT	0
647529	647528	19826F	PARTICIPANT	\N	PRESENT	0
647530	647528	20076G	PARTICIPANT	\N	PRESENT	0
647531	647528	20054A	PARTICIPANT	\N	PRESENT	0
647533	647532	20054A	PARTICIPANT	\N	PRESENT	0
647534	647532	19826F	PARTICIPANT	\N	PRESENT	0
647535	647532	14205J	PARTICIPANT	\N	PRESENT	0
647580	645023	05008E	PARTICIPANT	\N	EXCUSE	0
647599	646198	20252E	PARTICIPANT	\N	PRESENT	0
647600	646198	19687N	PARTICIPANT	\N	PRESENT	0
647601	646198	99004R	PARTICIPANT	\N	PRESENT	0
647602	646198	11070L	PARTICIPANT	\N	PRESENT	0
647603	646198	11110B	PARTICIPANT	\N	PRESENT	0
647666	644417	19673G	PARTICIPANT	\N	PRESENT	0
647667	644417	20056C	PARTICIPANT	\N	PRESENT	0
647668	644417	19503N	PARTICIPANT	\N	PRESENT	0
647933	647932	14231L	PARTICIPANT	\N	PRESENT	0
647930	647929	14231L	PARTICIPANT	\N	PRESENT	0
647931	647929	14259Y	PARTICIPANT	\N	PRESENT	0
647934	647932	14259Y	PARTICIPANT	\N	PRESENT	0
647961	645522	07029T	PARTICIPANT	\N	PRESENT	0
647964	647642	19760E	PARTICIPANT	\N	PRESENT	0
647965	647642	11031D	PARTICIPANT	\N	PRESENT	0
647967	647642	20130U	PARTICIPANT	\N	PRESENT	0
647968	647642	17779H	PARTICIPANT	\N	PRESENT	0
647969	647642	04043D	PARTICIPANT	\N	PRESENT	0
647970	647642	10006L	PRESIDENT	0	PRESENT	0
647971	647642	19415P	PARTICIPANT	\N	PRESENT	0
647972	647642	11067R	PARTICIPANT	\N	PRESENT	0
647973	647642	19679N	PARTICIPANT	\N	PRESENT	0
647974	647642	20066E	PARTICIPANT	\N	PRESENT	0
647975	647642	01034P	PARTICIPANT	\N	PRESENT	0
647976	647642	14217N	PARTICIPANT	\N	PRESENT	0
647977	647642	14213J	PARTICIPANT	\N	PRESENT	0
647978	647642	19713W	PARTICIPANT	\N	PRESENT	0
647979	647642	14042U	PARTICIPANT	\N	PRESENT	0
647980	647642	19691J	PARTICIPANT	\N	PRESENT	0
647981	647642	19569H	PARTICIPANT	\N	PRESENT	0
647982	647642	19703U	PARTICIPANT	\N	PRESENT	0
647983	647642	14071N	PARTICIPANT	\N	PRESENT	0
647984	647642	19723Y	PARTICIPANT	\N	PRESENT	0
647985	647642	19798U	PARTICIPANT	\N	PRESENT	0
647986	647642	11097X	PARTICIPANT	\N	PRESENT	0
647987	647642	20090E	PARTICIPANT	\N	PRESENT	0
647988	647642	20148F	PARTICIPANT	\N	PRESENT	0
647990	647642	20040T	PARTICIPANT	\N	PRESENT	1
647993	647642	14355X	PARTICIPANT	\N	PRESENT	1
647995	647642	11103C	PARTICIPANT	\N	PRESENT	1
647996	647642	14223L	PARTICIPANT	\N	PRESENT	1
647997	647642	19301E	PARTICIPANT	\N	PRESENT	1
648001	647642	19553Y	PARTICIPANT	\N	PRESENT	1
648002	647642	19591F	PARTICIPANT	\N	PRESENT	0
648006	647642	18193Q	PARTICIPANT	\N	PRESENT	0
648007	647642	17965H	PARTICIPANT	\N	PRESENT	0
648076	647643	19760E	PARTICIPANT	\N	PRESENT	0
648077	647643	11031D	PARTICIPANT	\N	PRESENT	0
648078	647643	18193Q	PARTICIPANT	\N	PRESENT	0
648079	647643	20130U	PARTICIPANT	\N	PRESENT	0
648080	647643	17965H	PARTICIPANT	\N	PRESENT	0
648082	647643	17779H	PARTICIPANT	\N	PRESENT	0
648084	647643	10006L	PRESIDENT	0	PRESENT	0
648086	647643	19415P	PARTICIPANT	\N	PRESENT	0
648087	647643	19691J	PARTICIPANT	\N	PRESENT	0
648088	647643	14042U	PARTICIPANT	\N	PRESENT	0
648089	647643	19569H	PARTICIPANT	\N	PRESENT	0
648091	647643	14213J	PARTICIPANT	\N	PRESENT	0
648092	647643	14217N	PARTICIPANT	\N	PRESENT	0
648093	647643	20248J	PARTICIPANT	\N	PRESENT	0
648095	647643	19679N	PARTICIPANT	\N	PRESENT	0
648096	647643	20066E	PARTICIPANT	\N	PRESENT	0
648098	647643	14071N	PARTICIPANT	\N	PRESENT	0
648099	647643	19703U	PARTICIPANT	\N	PRESENT	0
648102	647643	20090E	PARTICIPANT	\N	PRESENT	0
648104	647643	20040T	PARTICIPANT	\N	PRESENT	1
648119	647643	11097X	PARTICIPANT	\N	PRESENT	0
648120	647643	19798U	PARTICIPANT	\N	PRESENT	0
648122	647643	19723Y	PARTICIPANT	\N	PRESENT	0
648192	648189	20128B	PARTICIPANT	\N	PRESENT	0
648194	648193	20128B	PARTICIPANT	\N	PRESENT	0
648196	648195	20128B	PARTICIPANT	\N	PRESENT	0
648198	648197	20128B	PARTICIPANT	\N	PRESENT	0
648200	648199	20128B	PARTICIPANT	\N	PRESENT	0
648412	647518	14053L	PARTICIPANT	\N	PRESENT	0
648413	647518	19649G	PARTICIPANT	\N	PRESENT	0
648414	647518	11026G	PARTICIPANT	\N	PRESENT	0
648415	647518	14001X	PARTICIPANT	\N	PRESENT	0
648416	647518	04047H	PRESIDENT	0	PRESENT	0
648417	647518	11033F	PARTICIPANT	\N	PRESENT	0
648418	647518	01028R	PARTICIPANT	\N	PRESENT	0
648419	647518	14231L	PARTICIPANT	\N	PRESENT	0
648420	647518	05008E	PARTICIPANT	\N	PRESENT	0
648421	647518	11056N	PARTICIPANT	\N	PRESENT	0
648422	647518	95063L	PARTICIPANT	\N	PRESENT	0
629447	628902	17367Q	PARTICIPANT	\N	PRESENT	0
629450	628902	05008E	PARTICIPANT	\N	PRESENT	0
629453	628902	14053L	PRESIDENT	1	PRESENT	0
629463	628902	11056N	PRESIDENT	0	PRESENT	0
629464	628902	14089Y	PARTICIPANT	\N	PRESENT	0
629468	628902	19826F	PARTICIPANT	\N	PRESENT	0
629470	628902	19749K	PARTICIPANT	\N	PRESENT	0
629483	628902	20108W	PARTICIPANT	\N	PRESENT	0
629489	628902	11026G	PARTICIPANT	\N	PRESENT	0
629633	628902	95063L	PARTICIPANT	\N	PRESENT	0
630024	629309	20100N	PARTICIPANT	\N	PRESENT	0
630025	629309	11090Q	PARTICIPANT	\N	PRESENT	0
630037	629309	20034V	PARTICIPANT	\N	PRESENT	0
630027	629309	20088L	PARTICIPANT	\N	PRESENT	0
630028	629309	19503N	PARTICIPANT	\N	PRESENT	0
630029	629309	20030R	PARTICIPANT	\N	PRESENT	0
630030	629309	14257W	PARTICIPANT	\N	PRESENT	0
630031	629309	20054A	PARTICIPANT	\N	PRESENT	0
630032	629309	19954N	PARTICIPANT	\N	PRESENT	0
630033	629309	01025N	PARTICIPANT	\N	PRESENT	0
630034	629309	20092G	PARTICIPANT	\N	PRESENT	0
630035	629309	20108W	PARTICIPANT	\N	PRESENT	0
630036	629309	19507S	PARTICIPANT	\N	PRESENT	0
630038	629309	19695N	PARTICIPANT	\N	PRESENT	0
630039	629309	20180F	PARTICIPANT	\N	PRESENT	0
630040	629309	20102Q	PARTICIPANT	\N	PRESENT	0
630041	629309	20076G	PARTICIPANT	\N	PRESENT	0
630042	629309	20174H	PARTICIPANT	\N	PRESENT	0
630043	629309	14207L	PARTICIPANT	\N	PRESENT	0
630044	629309	14071N	PARTICIPANT	\N	PRESENT	0
630045	629309	20140W	PARTICIPANT	\N	PRESENT	0
630046	629309	20026V	PARTICIPANT	\N	PRESENT	0
630050	629309	19347U	PARTICIPANT	\N	PRESENT	0
630048	629309	19782L	PARTICIPANT	\N	PRESENT	0
630049	629309	19441R	PARTICIPANT	\N	PRESENT	0
630051	629309	19762G	PARTICIPANT	\N	PRESENT	0
630052	629309	19760E	PARTICIPANT	\N	PRESENT	0
630053	629309	19565D	PARTICIPANT	\N	PRESENT	0
630054	629309	19758L	PARTICIPANT	\N	PRESENT	0
630055	629309	20090E	PARTICIPANT	\N	PRESENT	0
630056	629309	20032T	PARTICIPANT	\N	PRESENT	0
630057	629309	14189C	PARTICIPANT	\N	PRESENT	0
630058	629309	11097X	PARTICIPANT	\N	PRESENT	0
630059	629309	20120S	PARTICIPANT	\N	PRESENT	0
630060	629309	19715Y	PARTICIPANT	\N	PRESENT	0
630061	629309	19747H	PARTICIPANT	\N	PRESENT	0
630062	629309	19768N	PARTICIPANT	\N	PRESENT	0
630063	629309	08015R	PARTICIPANT	\N	PRESENT	0
630064	629309	19383Y	PARTICIPANT	\N	PRESENT	0
630065	629309	01024M	PARTICIPANT	\N	PRESENT	0
630066	629309	14329V	PARTICIPANT	\N	PRESENT	0
630067	629309	14133K	PARTICIPANT	\N	PRESENT	0
630068	629309	14123H	PARTICIPANT	\N	PRESENT	0
630069	629309	14187A	PARTICIPANT	\N	PRESENT	0
630070	629309	07029T	PARTICIPANT	\N	PRESENT	0
630071	629309	14033T	PARTICIPANT	\N	PRESENT	0
630072	629309	14215L	PARTICIPANT	\N	PRESENT	0
630022	629309	11070L	PARTICIPANT	\N	PRESENT	0
630023	629309	17229F	PARTICIPANT	\N	PRESENT	0
630073	629309	19531S	PARTICIPANT	\N	PRESENT	0
630074	629309	14357A	PARTICIPANT	\N	PRESENT	0
630075	629309	20114U	PARTICIPANT	\N	PRESENT	0
630076	629309	20052X	PARTICIPANT	\N	PRESENT	0
630077	629309	14026U	PARTICIPANT	\N	PRESENT	0
630078	629309	11012A	PARTICIPANT	\N	PRESENT	0
630079	629309	14083S	PARTICIPANT	\N	PRESENT	0
630080	629309	19563B	PARTICIPANT	\N	PRESENT	0
630081	629309	20126Y	PARTICIPANT	\N	PRESENT	0
630082	629309	14147R	PARTICIPANT	\N	PRESENT	0
630219	630083	05012A	PARTICIPANT	\N	PRESENT	0
631499	629329	19533U	PRESIDENT	0	PRESENT	0
631500	629329	14207L	PARTICIPANT	\N	PRESENT	0
631501	629329	19798U	PARTICIPANT	\N	PRESENT	1
631504	629329	20042V	PARTICIPANT	\N	PRESENT	0
631508	629329	19820Y	PARTICIPANT	\N	PRESENT	0
631645	631644	04033B	PARTICIPANT	\N	PRESENT	0
631646	631644	14193X	PARTICIPANT	\N	PRESENT	0
632167	631653	04045F	PRESIDENT	0	PRESENT	0
632170	631653	14207L	PARTICIPANT	\N	PRESENT	0
632178	631653	19820Y	PARTICIPANT	\N	PRESENT	0
632179	631653	20042V	PARTICIPANT	\N	PRESENT	1
632180	631653	20124W	PARTICIPANT	\N	PRESENT	0
632406	631653	19798U	PARTICIPANT	\N	PRESENT	0
632494	631653	19533U	PARTICIPANT	\N	EXCUSE	0
632879	632714	20094J	PARTICIPANT	\N	PRESENT	1
632880	632714	20062A	PARTICIPANT	\N	PRESENT	1
632881	632714	20082E	PARTICIPANT	\N	PRESENT	1
632882	632714	20030R	PARTICIPANT	\N	PRESENT	1
633226	631725	19954N	PARTICIPANT	\N	PRESENT	0
633228	631725	20264J	PARTICIPANT	\N	PRESENT	0
633229	631725	11074Q	PARTICIPANT	\N	PRESENT	0
633232	631725	08045X	PARTICIPANT	\N	PRESENT	0
633233	631725	11083R	PARTICIPANT	\N	PRESENT	0
633234	631725	20120S	PARTICIPANT	\N	PRESENT	0
633235	631725	08056B	PARTICIPANT	\N	PRESENT	0
633237	631725	19725B	PARTICIPANT	\N	PRESENT	0
633238	631725	18193Q	PARTICIPANT	\N	PRESENT	0
633239	631725	20028X	PARTICIPANT	\N	PRESENT	0
633240	631725	04043D	PARTICIPANT	\N	PRESENT	0
634855	634649	19719D	PARTICIPANT	\N	PRESENT	0
634856	634649	20032T	PARTICIPANT	\N	PRESENT	0
634857	634649	20106U	PARTICIPANT	\N	PRESENT	0
634858	634649	14221J	PARTICIPANT	\N	PRESENT	0
634859	634649	14031R	PARTICIPANT	\N	PRESENT	0
634860	634649	11065P	PARTICIPANT	\N	PRESENT	0
634861	634649	20046A	PARTICIPANT	\N	PRESENT	0
634862	634649	17229F	PARTICIPANT	\N	PRESENT	0
634863	634649	14207L	PARTICIPANT	\N	PRESENT	0
634864	634649	19549D	PARTICIPANT	\N	PRESENT	0
634871	634649	20076G	PARTICIPANT	\N	PRESENT	0
634872	634649	14217N	PARTICIPANT	\N	PRESENT	0
634873	634649	14219Q	PARTICIPANT	\N	PRESENT	0
634874	634649	20090E	PARTICIPANT	\N	PRESENT	0
634875	634649	19525U	PARTICIPANT	\N	PRESENT	0
634876	634649	19593H	PARTICIPANT	\N	PRESENT	0
634877	634649	20112S	PARTICIPANT	\N	PRESENT	0
634878	634649	01028R	PARTICIPANT	\N	PRESENT	0
634879	634649	14042U	PARTICIPANT	\N	PRESENT	0
634880	634649	20172F	PARTICIPANT	\N	PRESENT	0
634881	634649	19954N	PARTICIPANT	\N	PRESENT	0
634882	634649	18083K	PARTICIPANT	\N	PRESENT	0
634883	634649	14073Q	PARTICIPANT	\N	PRESENT	0
634884	634649	19782L	PARTICIPANT	\N	PRESENT	0
634885	634649	14133K	PARTICIPANT	\N	PRESENT	0
634886	634649	08060W	PARTICIPANT	\N	PRESENT	0
634887	634649	19745F	PARTICIPANT	\N	PRESENT	0
634888	634649	01024M	PARTICIPANT	\N	PRESENT	0
634889	634649	19683J	PARTICIPANT	\N	PRESENT	0
634890	634649	20072C	PARTICIPANT	\N	PRESENT	0
634891	634649	20102Q	PARTICIPANT	\N	PRESENT	0
634892	634649	19565D	PARTICIPANT	\N	PRESENT	0
634893	634649	14030Q	PARTICIPANT	\N	PRESENT	0
634894	634649	20042V	PARTICIPANT	\N	PRESENT	0
634895	634649	08056B	PARTICIPANT	\N	PRESENT	0
634896	634649	08015R	PARTICIPANT	\N	PRESENT	0
634897	634649	19383Y	PARTICIPANT	\N	PRESENT	0
634898	634649	11103C	PARTICIPANT	\N	PRESENT	0
634899	634649	14105F	PARTICIPANT	\N	PRESENT	0
634901	634649	97011G	PARTICIPANT	\N	PRESENT	0
634902	634649	20038A	PARTICIPANT	\N	PRESENT	0
634903	634649	14173T	PARTICIPANT	\N	PRESENT	0
634904	634649	14169X	PARTICIPANT	\N	PRESENT	0
634905	634649	20086J	PARTICIPANT	\N	PRESENT	0
634906	634649	19551W	PARTICIPANT	\N	PRESENT	0
634907	634649	14237S	PARTICIPANT	\N	PRESENT	0
634908	634649	19826F	PARTICIPANT	\N	PRESENT	0
634909	634649	19577H	PARTICIPANT	\N	PRESENT	0
634910	634649	20052X	PARTICIPANT	\N	PRESENT	0
634911	634649	01058X	PARTICIPANT	\N	PRESENT	0
634912	634649	19651A	PARTICIPANT	\N	PRESENT	0
634913	634649	19399H	PARTICIPANT	\N	PRESENT	0
634916	634432	20130U	PARTICIPANT	\N	PRESENT	1
634917	634432	19703U	PARTICIPANT	\N	PRESENT	0
634918	634432	20090E	PARTICIPANT	\N	PRESENT	0
634919	634432	11067R	PARTICIPANT	\N	PRESENT	0
634920	634432	19798U	PARTICIPANT	\N	PRESENT	0
634921	634432	11097X	PARTICIPANT	\N	PRESENT	0
634922	634432	17965H	PARTICIPANT	\N	PRESENT	0
634923	634432	19691J	PARTICIPANT	\N	PRESENT	1
634924	634432	20148F	PARTICIPANT	\N	PRESENT	0
640220	639954	14053L	PARTICIPANT	\N	PRESENT	0
640221	639954	95063L	PARTICIPANT	\N	PRESENT	0
640222	639954	19563B	PARTICIPANT	\N	EXCUSE	0
640224	639954	05008E	PARTICIPANT	\N	PRESENT	0
640242	639966	04035D	PARTICIPANT	\N	PRESENT	0
640243	639966	19443T	PARTICIPANT	\N	PRESENT	0
640244	639966	19565D	PARTICIPANT	\N	PRESENT	0
640245	639966	20072C	PARTICIPANT	\N	PRESENT	0
640246	639966	20042V	PARTICIPANT	\N	PRESENT	0
640247	639966	01058X	PARTICIPANT	\N	PRESENT	0
640248	639966	11027H	PARTICIPANT	\N	PRESENT	0
640249	639966	16685X	PARTICIPANT	\N	PRESENT	0
640250	639966	11066Q	PARTICIPANT	\N	PRESENT	0
640251	639966	08056B	PARTICIPANT	\N	PRESENT	0
640252	639966	12028B	PARTICIPANT	\N	PRESENT	0
640253	639966	14105F	PARTICIPANT	\N	PRESENT	0
640254	639966	19421M	PARTICIPANT	\N	PRESENT	0
640255	639966	14193X	PRESIDENT	0	PRESENT	0
640256	639966	19347U	PARTICIPANT	\N	PRESENT	0
640257	639966	97011G	PARTICIPANT	\N	PRESENT	0
640258	639966	14249W	PARTICIPANT	\N	PRESENT	0
640259	639966	17023S	PARTICIPANT	\N	PRESENT	0
640260	639966	04042C	PARTICIPANT	\N	EXCUSE	0
640261	639966	11054L	PARTICIPANT	\N	EXCUSE	0
640262	639966	08047A	PARTICIPANT	\N	EXCUSE	0
640263	639965	19533U	PRESIDENT	0	PRESENT	0
640264	639965	19798U	PARTICIPANT	\N	PRESENT	1
640265	639965	14147R	PARTICIPANT	\N	PRESENT	1
640266	639965	19820Y	PARTICIPANT	\N	PRESENT	1
640267	639965	19715Y	PARTICIPANT	\N	PRESENT	1
640268	639965	19693L	PARTICIPANT	\N	PRESENT	0
640269	639965	14207L	PARTICIPANT	\N	PRESENT	0
640270	639965	19717B	PARTICIPANT	\N	PRESENT	1
640292	639968	14169X	PARTICIPANT	\N	PRESENT	0
640293	639968	20100N	PARTICIPANT	\N	PRESENT	0
640294	639968	10015M	PARTICIPANT	\N	PRESENT	0
640295	639968	19333N	PARTICIPANT	\N	PRESENT	0
640297	639968	14189C	PARTICIPANT	\N	PRESENT	0
640298	639968	19507S	PARTICIPANT	\N	PRESENT	0
640299	639968	14033T	PARTICIPANT	\N	PRESENT	1
640300	639968	20286Q	PARTICIPANT	\N	PRESENT	1
640301	639968	14073Q	PARTICIPANT	\N	PRESENT	0
640302	639968	19711U	PARTICIPANT	\N	PRESENT	1
640303	639968	04070G	PARTICIPANT	\N	PRESENT	1
640322	639968	16685X	PARTICIPANT	\N	PRESENT	0
640323	639968	20126Y	PARTICIPANT	\N	PRESENT	0
640324	639968	14251Q	PARTICIPANT	\N	PRESENT	1
640325	639968	14257W	PARTICIPANT	\N	PRESENT	1
640326	639968	20030R	PARTICIPANT	\N	PRESENT	1
640327	639968	19705W	PARTICIPANT	\N	PRESENT	1
640328	639968	19782L	PARTICIPANT	\N	PRESENT	1
640329	639968	20078J	PARTICIPANT	\N	PRESENT	1
640330	639968	19707Y	PARTICIPANT	\N	PRESENT	1
640331	639968	20028X	PARTICIPANT	\N	PRESENT	1
640332	639968	08015R	PARTICIPANT	\N	PRESENT	1
640333	639968	20094J	PARTICIPANT	\N	PRESENT	0
640334	639968	11026G	PARTICIPANT	\N	PRESENT	0
640335	639968	14026U	PARTICIPANT	\N	PRESENT	0
640357	639968	19631V	PARTICIPANT	\N	PRESENT	0
640358	639968	19747H	PARTICIPANT	\N	PRESENT	0
640359	639968	19383Y	PARTICIPANT	\N	PRESENT	0
640360	639968	08028W	PARTICIPANT	\N	PRESENT	0
640361	639968	20144B	PARTICIPANT	\N	PRESENT	0
640362	639968	11090Q	PARTICIPANT	\N	PRESENT	0
640363	639968	20082E	PARTICIPANT	\N	PRESENT	0
640364	639968	14331P	PRESIDENT	0	PRESENT	0
640365	639968	19515S	PARTICIPANT	\N	PRESENT	0
640366	639968	20174H	PARTICIPANT	\N	PRESENT	1
640390	639968	19413M	PARTICIPANT	\N	PRESENT	1
640391	639968	14205J	PARTICIPANT	\N	PRESENT	0
640415	639968	19866P	PARTICIPANT	\N	PRESENT	1
640416	639968	20104S	PARTICIPANT	\N	EXCUSE	0
640418	639968	14237S	PARTICIPANT	\N	PRESENT	0
640422	640421	04047H	PARTICIPANT	\N	PRESENT	0
640423	640421	10015M	PARTICIPANT	\N	PRESENT	0
640424	640421	11026G	PARTICIPANT	\N	PRESENT	0
640425	640421	20110Q	PARTICIPANT	\N	PRESENT	0
640426	640421	19629C	PARTICIPANT	\N	PRESENT	0
640428	640427	04047H	PARTICIPANT	\N	PRESENT	0
640429	640427	10015M	PARTICIPANT	\N	PRESENT	0
640430	640427	20110Q	PARTICIPANT	\N	PRESENT	0
640432	640431	04047H	PARTICIPANT	\N	PRESENT	0
640433	640431	11026G	PARTICIPANT	\N	PRESENT	0
640434	640431	10015M	PARTICIPANT	\N	PRESENT	0
640436	640435	04047H	PARTICIPANT	\N	PRESENT	0
640437	640435	10015M	PARTICIPANT	\N	PRESENT	0
640438	640435	11026G	PARTICIPANT	\N	PRESENT	0
640439	640435	20110Q	PARTICIPANT	\N	PRESENT	0
640441	640440	04047H	PARTICIPANT	\N	PRESENT	0
640442	640440	10015M	PARTICIPANT	\N	PRESENT	0
640444	640443	19251M	PARTICIPANT	\N	PRESENT	0
640445	640443	19593H	PARTICIPANT	\N	PRESENT	0
640446	640443	19647E	PARTICIPANT	\N	PRESENT	0
640469	640468	19543W	PARTICIPANT	\N	PRESENT	0
640470	640468	14151M	PARTICIPANT	\N	PRESENT	0
640498	640497	14151M	PARTICIPANT	\N	PRESENT	0
640499	640497	19543W	PARTICIPANT	\N	PRESENT	0
640500	640497	14147R	PARTICIPANT	\N	PRESENT	0
640539	640538	19693L	PARTICIPANT	\N	EXCUSE	0
640540	640538	20074E	PARTICIPANT	\N	PRESENT	1
640541	640538	20066E	PARTICIPANT	\N	EXCUSE	0
640543	640538	11077T	PARTICIPANT	\N	EXCUSE	0
640546	640538	19369B	PARTICIPANT	\N	EXCUSE	0
640547	640538	20050V	PARTICIPANT	\N	PRESENT	0
640548	640538	20082E	PARTICIPANT	\N	EXCUSE	0
640552	640538	20126Y	PARTICIPANT	\N	PRESENT	1
640562	640561	04047H	PARTICIPANT	\N	PRESENT	0
640563	640561	14053L	PARTICIPANT	\N	PRESENT	0
640566	640561	11066Q	PARTICIPANT	\N	PRESENT	0
640579	640578	19575F	PARTICIPANT	\N	PRESENT	0
640580	640578	19515S	PARTICIPANT	\N	PRESENT	0
640581	640578	16685X	PARTICIPANT	\N	PRESENT	0
640582	640578	14083S	PARTICIPANT	\N	PRESENT	0
640583	640578	20094J	PARTICIPANT	\N	PRESENT	0
640584	640578	20060X	PARTICIPANT	\N	PRESENT	0
640585	640578	20054A	PARTICIPANT	\N	PRESENT	0
640586	640578	19251M	PARTICIPANT	\N	PRESENT	0
640587	640578	20126Y	PARTICIPANT	\N	PRESENT	0
640588	640578	19762G	PARTICIPANT	\N	PRESENT	0
640589	640578	19467C	PARTICIPANT	\N	PRESENT	0
640590	640578	19479G	PARTICIPANT	\N	PRESENT	0
640608	640538	19515S	PARTICIPANT	\N	EXCUSE	0
640609	640538	19747H	PARTICIPANT	\N	EXCUSE	0
640610	640538	20144B	PARTICIPANT	\N	EXCUSE	0
640611	640538	20092G	PARTICIPANT	\N	EXCUSE	0
640685	640684	20114U	PARTICIPANT	\N	PRESENT	0
640699	640698	04047H	PARTICIPANT	\N	PRESENT	0
640700	640698	14231L	PARTICIPANT	\N	PRESENT	0
640701	640698	14053L	PARTICIPANT	\N	PRESENT	0
640702	640698	01028R	PARTICIPANT	\N	PRESENT	0
640703	640698	11056N	PARTICIPANT	\N	PRESENT	0
640704	640698	20110Q	PARTICIPANT	\N	PRESENT	0
640705	640698	14215L	PARTICIPANT	\N	PRESENT	0
640785	640784	19723Y	PARTICIPANT	\N	PRESENT	0
640788	640787	19735D	PARTICIPANT	\N	PRESENT	0
640789	640787	19723Y	PARTICIPANT	\N	PRESENT	0
640792	640791	19723Y	PARTICIPANT	\N	PRESENT	0
640794	640791	19735D	PARTICIPANT	\N	PRESENT	0
640806	640805	08010L	PARTICIPANT	\N	PRESENT	0
640808	640807	19741B	PARTICIPANT	\N	PRESENT	0
640810	640809	14253S	PARTICIPANT	\N	PRESENT	0
640812	640811	19741B	PARTICIPANT	\N	PRESENT	0
640814	640813	19741B	PARTICIPANT	\N	PRESENT	0
640816	640815	99004R	PARTICIPANT	\N	PRESENT	0
640818	640817	99004R	PARTICIPANT	\N	PRESENT	0
640820	640819	20086J	PARTICIPANT	\N	PRESENT	0
640822	640821	19543W	PARTICIPANT	\N	PRESENT	0
640823	640821	04008A	PARTICIPANT	\N	PRESENT	0
640824	640821	14151M	PARTICIPANT	\N	PRESENT	0
640873	640801	14281W	PARTICIPANT	\N	PRESENT	0
640874	640801	19697Q	PARTICIPANT	\N	PRESENT	0
640875	640801	19679N	PARTICIPANT	\N	PRESENT	0
641029	641028	19399H	PARTICIPANT	\N	PRESENT	0
641030	641028	99004R	PARTICIPANT	\N	PRESENT	0
641032	641031	19735D	PARTICIPANT	\N	PRESENT	0
641033	641031	19723Y	PARTICIPANT	\N	PRESENT	0
633117	631566	19593H	PARTICIPANT	\N	PRESENT	0
633118	631566	20046A	PARTICIPANT	\N	PRESENT	0
633119	631566	14193X	PARTICIPANT	\N	PRESENT	0
633120	631566	19421M	PARTICIPANT	\N	PRESENT	0
633121	631566	19565D	PARTICIPANT	\N	PRESENT	0
633122	631566	19695N	PARTICIPANT	\N	PRESENT	0
633123	631566	11080N	PARTICIPANT	\N	PRESENT	0
633124	631566	19581D	PARTICIPANT	\N	PRESENT	0
633133	631566	20026V	PARTICIPANT	\N	PRESENT	0
633126	631566	20126Y	PARTICIPANT	\N	PRESENT	0
633127	631566	14329V	PARTICIPANT	\N	PRESENT	0
633128	631566	20024T	PARTICIPANT	\N	PRESENT	0
633129	631566	01048V	PARTICIPANT	\N	PRESENT	0
633130	631566	20116W	PARTICIPANT	\N	PRESENT	0
633131	631566	20098N	PARTICIPANT	\N	PRESENT	0
633132	631566	20142Y	PARTICIPANT	\N	PRESENT	0
633134	631566	19629C	PARTICIPANT	\N	PRESENT	0
633135	631566	19467C	PARTICIPANT	\N	PRESENT	0
633136	631566	20044X	PARTICIPANT	\N	PRESENT	0
633137	631566	20058E	PARTICIPANT	\N	PRESENT	0
633138	631566	19719D	PARTICIPANT	\N	PRESENT	0
633139	631566	19741B	PARTICIPANT	\N	PRESENT	0
633140	631566	19866P	PARTICIPANT	\N	PRESENT	0
633141	631566	11012A	PARTICIPANT	\N	PRESENT	0
633142	631566	19399H	PARTICIPANT	\N	PRESENT	0
633143	631566	19387D	PARTICIPANT	\N	PRESENT	0
633144	631566	20132W	PARTICIPANT	\N	PRESENT	0
633145	631566	19768N	PARTICIPANT	\N	PRESENT	0
633146	631566	14251Q	PARTICIPANT	\N	PRESENT	0
633147	631566	20104S	PARTICIPANT	\N	PRESENT	0
633148	631566	11090Q	PARTICIPANT	\N	PRESENT	0
633149	631566	14147R	PARTICIPANT	\N	PRESENT	0
633150	631566	19649G	PARTICIPANT	\N	PRESENT	0
633151	631566	97011G	PARTICIPANT	\N	PRESENT	0
633152	631566	19683J	PARTICIPANT	\N	PRESENT	0
633153	631566	19647E	PARTICIPANT	\N	PRESENT	0
633154	631566	19549D	PARTICIPANT	\N	PRESENT	0
633155	631566	08045X	PARTICIPANT	\N	PRESENT	0
633156	631566	11067R	PARTICIPANT	\N	PRESENT	0
633157	631566	19591F	PARTICIPANT	\N	PRESENT	0
633158	631566	14001X	PARTICIPANT	\N	PRESENT	0
633159	631566	20018V	PARTICIPANT	\N	PRESENT	0
633160	631566	19413M	PARTICIPANT	\N	PRESENT	0
633161	631566	19531S	PARTICIPANT	\N	PRESENT	0
633162	631566	20264J	PARTICIPANT	\N	PRESENT	0
633163	631566	20114U	PARTICIPANT	\N	PRESENT	0
633164	631566	11026G	PARTICIPANT	\N	PRESENT	0
633165	631566	20094J	PARTICIPANT	\N	PRESENT	0
633166	631566	19319Q	PARTICIPANT	\N	PRESENT	0
633200	631566	19749K	PARTICIPANT	\N	PRESENT	0
633168	631566	20038A	PARTICIPANT	\N	PRESENT	0
633169	631566	19673G	PARTICIPANT	\N	PRESENT	0
633170	631566	19507S	PARTICIPANT	\N	PRESENT	0
633171	631566	20056C	PARTICIPANT	\N	PRESENT	0
633205	631566	19826F	PARTICIPANT	\N	PRESENT	0
633173	631566	20052X	PARTICIPANT	\N	PRESENT	0
633174	631566	19699S	PARTICIPANT	\N	PRESENT	0
633175	631566	14189C	PARTICIPANT	\N	PRESENT	0
633176	631566	19713W	PARTICIPANT	\N	PRESENT	0
633177	631566	19441R	PARTICIPANT	\N	PRESENT	0
633178	631566	16685X	PARTICIPANT	\N	PRESENT	0
633179	631566	05008E	PARTICIPANT	\N	PRESENT	0
633180	631566	14205J	PARTICIPANT	\N	PRESENT	0
633181	631566	20144B	PARTICIPANT	\N	PRESENT	0
633182	631566	19569H	PARTICIPANT	\N	PRESENT	0
633183	631566	20032T	PARTICIPANT	\N	PRESENT	0
633184	631566	14219Q	PARTICIPANT	\N	PRESENT	0
633185	631566	19479G	PARTICIPANT	\N	PRESENT	0
633186	631566	11053K	PARTICIPANT	\N	PRESENT	0
633187	631566	01034P	PARTICIPANT	\N	PRESENT	0
633188	631566	19369B	PARTICIPANT	\N	PRESENT	0
633189	631566	19611R	PARTICIPANT	\N	PRESENT	0
633190	631566	19691J	PARTICIPANT	\N	PRESENT	0
633191	631566	01043Q	PARTICIPANT	\N	PRESENT	0
633192	631566	14030Q	PARTICIPANT	\N	PRESENT	0
633193	631566	19747H	PARTICIPANT	\N	PRESENT	0
633194	631566	14327T	PARTICIPANT	\N	PRESENT	0
633195	631566	01024M	PARTICIPANT	\N	PRESENT	0
633196	631566	01025N	PARTICIPANT	\N	PRESENT	0
633197	631566	20066E	PARTICIPANT	\N	PRESENT	0
633198	631566	20086J	PARTICIPANT	\N	PRESENT	0
633199	631566	11085T	PARTICIPANT	\N	PRESENT	0
633201	631566	14255U	PARTICIPANT	\N	PRESENT	0
633202	631566	11070L	PARTICIPANT	\N	PRESENT	0
633203	631566	19663E	PARTICIPANT	\N	PRESENT	0
633204	631566	14267Y	PARTICIPANT	\N	PRESENT	0
633206	631566	20248J	PARTICIPANT	\N	PRESENT	0
633207	631566	14073Q	PARTICIPANT	\N	PRESENT	0
633208	631566	19685L	PARTICIPANT	\N	PRESENT	0
633209	631566	17023S	PARTICIPANT	\N	PRESENT	0
633210	631566	20040T	PARTICIPANT	\N	PRESENT	0
633211	631566	14179A	PARTICIPANT	\N	PRESENT	0
633212	631566	14123H	PARTICIPANT	\N	PRESENT	0
633213	631566	10015M	PARTICIPANT	\N	PRESENT	0
633214	631566	20136B	PARTICIPANT	\N	PRESENT	0
633215	631566	20048C	PARTICIPANT	\N	PRESENT	0
633216	631566	14217N	PARTICIPANT	\N	PRESENT	0
633217	631566	14229S	PARTICIPANT	\N	PRESENT	0
633218	631566	95041E	PARTICIPANT	\N	PRESENT	0
633219	631566	19543W	PARTICIPANT	\N	PRESENT	0
633223	631566	19515S	PARTICIPANT	\N	PRESENT	0
633236	631566	14215L	PARTICIPANT	\N	PRESENT	0
633241	631566	14089Y	PARTICIPANT	\N	PRESENT	0
633242	631566	04042C	PARTICIPANT	\N	PRESENT	0
633243	631566	08069G	PARTICIPANT	\N	PRESENT	0
633247	631566	20082E	PARTICIPANT	\N	PRESENT	0
633248	631566	08018U	PARTICIPANT	\N	PRESENT	0
633249	631566	11010L	PARTICIPANT	\N	PRESENT	0
633504	631567	19719D	PARTICIPANT	\N	PRESENT	0
633251	631594	19667J	PRESIDENT	0	PRESENT	0
633252	631594	04085P	PARTICIPANT	\N	PRESENT	0
633255	631594	17737W	PARTICIPANT	\N	EXCUSE	0
633505	631567	14215L	PARTICIPANT	\N	PRESENT	0
633506	631567	20128B	PARTICIPANT	\N	PRESENT	0
633507	631567	14111D	PARTICIPANT	\N	PRESENT	0
633508	631567	20022R	PARTICIPANT	\N	PRESENT	0
633509	631567	19347U	PARTICIPANT	\N	PRESENT	0
633510	631567	11040E	PARTICIPANT	\N	PRESENT	0
633511	631567	07004J	PARTICIPANT	\N	PRESENT	0
633512	631567	19866P	PARTICIPANT	\N	PRESENT	0
633513	631567	11033F	PARTICIPANT	\N	PRESENT	0
633514	631567	14151M	PARTICIPANT	\N	PRESENT	0
633515	629594	19333N	PARTICIPANT	\N	PRESENT	0
633516	629594	19701S	PARTICIPANT	\N	PRESENT	0
633517	629594	19820Y	PARTICIPANT	\N	PRESENT	0
633518	629594	20120S	PARTICIPANT	\N	PRESENT	0
633519	629594	14219Q	PRESIDENT	0	PRESENT	0
633521	629594	20100N	PARTICIPANT	\N	PRESENT	0
633522	629594	17229F	PARTICIPANT	\N	PRESENT	0
633525	629594	20136B	PARTICIPANT	\N	PRESENT	0
633526	629594	14031R	PARTICIPANT	\N	PRESENT	0
633527	629594	19549D	PARTICIPANT	\N	PRESENT	0
633528	629594	19503N	PARTICIPANT	\N	PRESENT	0
633529	629594	19251M	PARTICIPANT	\N	PRESENT	0
633531	629594	19599P	PARTICIPANT	\N	PRESENT	0
633532	629594	14169X	PARTICIPANT	\N	PRESENT	0
633533	629594	20102Q	PARTICIPANT	\N	PRESENT	0
633534	629594	20068G	PARTICIPANT	\N	PRESENT	0
633535	629594	20032T	PARTICIPANT	\N	PRESENT	0
633536	629594	20046A	PARTICIPANT	\N	PRESENT	0
633537	629594	20024T	PARTICIPANT	\N	PRESENT	0
633538	629594	19525U	PARTICIPANT	\N	PRESENT	0
633539	631567	14205J	PARTICIPANT	\N	PRESENT	0
633540	631567	01025N	PARTICIPANT	\N	PRESENT	0
633544	631567	20090E	PARTICIPANT	\N	PRESENT	0
633545	631594	19531S	PARTICIPANT	\N	PRESENT	0
633546	631594	20038A	PARTICIPANT	\N	PRESENT	0
633547	631594	19741B	PARTICIPANT	\N	PRESENT	0
633548	631594	19585H	PARTICIPANT	\N	PRESENT	0
633549	631594	19671E	PARTICIPANT	\N	PRESENT	0
633550	631594	14257W	PARTICIPANT	\N	PRESENT	1
633554	631567	19629C	PARTICIPANT	\N	PRESENT	0
633555	631567	19387D	PARTICIPANT	\N	PRESENT	0
633556	631567	20180F	PARTICIPANT	\N	PRESENT	0
633557	631567	20026V	PARTICIPANT	\N	PRESENT	0
633558	631567	19479G	PARTICIPANT	\N	PRESENT	0
633559	631567	19631V	PARTICIPANT	\N	PRESENT	0
633560	631567	14030Q	PARTICIPANT	\N	PRESENT	0
633561	631567	01024M	PARTICIPANT	\N	PRESENT	0
633562	631567	14123H	PARTICIPANT	\N	PRESENT	0
633563	631567	20048C	PARTICIPANT	\N	PRESENT	0
648431	647518	14215L	PARTICIPANT	\N	PRESENT	0
648437	647518	14111D	PARTICIPANT	\N	PRESENT	0
648440	647518	14151M	PARTICIPANT	\N	PRESENT	0
648473	648466	19383Y	PARTICIPANT	\N	PRESENT	0
648474	648466	19768N	PARTICIPANT	\N	PRESENT	0
648475	648466	20088L	PARTICIPANT	\N	PRESENT	0
648476	648466	19782L	PARTICIPANT	\N	PRESENT	0
648477	648466	20092G	PARTICIPANT	\N	PRESENT	0
648478	648466	01043Q	PARTICIPANT	\N	PRESENT	0
648479	648466	14357A	PARTICIPANT	\N	PRESENT	0
648480	648466	20078J	PARTICIPANT	\N	PRESENT	1
648481	648466	19413M	PARTICIPANT	\N	PRESENT	1
648482	648466	20082E	PARTICIPANT	\N	PRESENT	0
648483	648466	20094J	PARTICIPANT	\N	PRESENT	0
648484	648466	04045F	PARTICIPANT	\N	PRESENT	0
648485	648466	19866P	PARTICIPANT	\N	PRESENT	0
648486	648466	20104S	PARTICIPANT	\N	PRESENT	0
648487	648466	19631V	PARTICIPANT	\N	PRESENT	0
648488	648466	19705W	PARTICIPANT	\N	PRESENT	0
648489	648466	19707Y	PARTICIPANT	\N	PRESENT	1
648490	648466	08015R	PARTICIPANT	\N	PRESENT	1
648491	648466	19369B	PARTICIPANT	\N	PRESENT	0
648492	648466	20018V	PARTICIPANT	\N	PRESENT	1
648493	648466	19511N	PARTICIPANT	\N	PRESENT	0
648494	648466	08028W	PARTICIPANT	\N	PRESENT	0
648495	648466	19563B	PARTICIPANT	\N	PRESENT	0
648496	648466	14329V	PARTICIPANT	\N	PRESENT	1
648497	648466	20028X	PARTICIPANT	\N	PRESENT	1
648498	648466	14037X	PARTICIPANT	\N	PRESENT	0
648499	648466	14038Y	PARTICIPANT	\N	PRESENT	0
648500	648466	19467C	PARTICIPANT	\N	PRESENT	0
648501	648466	20034V	PARTICIPANT	\N	PRESENT	0
648502	648466	14187A	PARTICIPANT	\N	PRESENT	0
648503	648466	20144B	PARTICIPANT	\N	PRESENT	0
648504	648466	19695N	PARTICIPANT	\N	PRESENT	0
648505	648466	14033T	PARTICIPANT	\N	PRESENT	0
648506	648466	11090Q	PRESIDENT	0	PRESENT	0
648507	648466	01025N	PARTICIPANT	\N	PRESENT	0
648508	648466	20054A	PARTICIPANT	\N	PRESENT	0
648509	648466	14205J	PARTICIPANT	\N	PRESENT	0
648510	648466	20062A	PARTICIPANT	\N	PRESENT	0
648511	648466	14251Q	PARTICIPANT	\N	PRESENT	1
648512	648466	19507S	PARTICIPANT	\N	PRESENT	0
648513	648466	20286Q	PARTICIPANT	\N	PRESENT	0
648514	648466	19747H	PARTICIPANT	\N	PRESENT	0
648515	648466	14207L	PARTICIPANT	\N	PRESENT	0
648516	648466	14257W	PARTICIPANT	\N	PRESENT	0
648517	648466	19515S	PARTICIPANT	\N	PRESENT	0
648518	646314	18083K	PARTICIPANT	\N	PRESENT	0
648519	646314	20102Q	PARTICIPANT	\N	PRESENT	0
648520	646314	20024T	PARTICIPANT	\N	PRESENT	0
648527	646314	19549D	PARTICIPANT	\N	PRESENT	0
648528	646314	14219Q	PRESIDENT	0	PRESENT	0
648529	646314	19820Y	PARTICIPANT	\N	PRESENT	0
648530	646314	19826F	PARTICIPANT	\N	PRESENT	0
648531	646314	20020P	PARTICIPANT	\N	PRESENT	0
648532	646314	17367Q	PARTICIPANT	\N	PRESENT	0
648533	646314	19619A	PARTICIPANT	\N	PRESENT	0
648534	646314	19503N	PARTICIPANT	\N	PRESENT	0
648535	646314	14169X	PARTICIPANT	\N	PRESENT	1
648536	646314	14237S	PARTICIPANT	\N	PRESENT	0
648537	646314	20100N	PARTICIPANT	\N	PRESENT	0
648538	646314	08060W	PARTICIPANT	\N	PRESENT	0
648539	648466	19441R	PARTICIPANT	\N	PRESENT	0
648648	647960	19766L	PARTICIPANT	\N	PRESENT	0
648649	647960	19533U	PARTICIPANT	\N	PRESENT	0
648650	647960	04033B	PARTICIPANT	\N	PRESENT	0
648651	647960	14229S	PARTICIPANT	\N	PRESENT	0
648652	647960	20098N	PARTICIPANT	\N	PRESENT	0
648653	647960	19573D	PARTICIPANT	\N	PRESENT	0
648654	647960	08012N	PARTICIPANT	\N	PRESENT	0
648655	647960	20026V	PARTICIPANT	\N	PRESENT	0
648656	647960	19593H	PARTICIPANT	\N	PRESENT	0
648657	647960	20132W	PARTICIPANT	\N	PRESENT	0
648658	647960	20134Y	PARTICIPANT	\N	PRESENT	0
648659	647960	19651A	PARTICIPANT	\N	PRESENT	1
648660	647960	19611R	PRESIDENT	0	PRESENT	0
648661	647960	19399H	PARTICIPANT	\N	PRESENT	0
648662	647960	20052X	PARTICIPANT	\N	PRESENT	0
648663	647960	20152B	PARTICIPANT	\N	PRESENT	0
648664	647960	20172F	PARTICIPANT	\N	PRESENT	0
648665	647960	14030Q	PARTICIPANT	\N	PRESENT	0
648666	647960	20056C	PARTICIPANT	\N	PRESENT	0
648667	647960	04059M	PARTICIPANT	\N	PRESENT	0
648668	647960	20264J	PARTICIPANT	\N	PRESENT	0
648669	647960	19735D	PARTICIPANT	\N	PRESENT	1
648670	647960	19057M	PARTICIPANT	\N	PRESENT	0
648671	647960	11043H	PARTICIPANT	\N	PRESENT	0
648672	647960	19758L	PARTICIPANT	\N	PRESENT	0
648673	647960	20084G	PARTICIPANT	\N	PRESENT	0
648674	647960	19621T	PARTICIPANT	\N	PRESENT	0
648678	647669	19545Y	PARTICIPANT	\N	PRESENT	0
648679	647669	14189C	PARTICIPANT	\N	EXCUSE	0
648688	647669	11070L	PARTICIPANT	\N	PRESENT	0
648689	647960	14123H	PARTICIPANT	\N	PRESENT	0
648690	647960	20124W	PARTICIPANT	\N	PRESENT	0
648692	646314	20046A	PARTICIPANT	\N	PRESENT	1
648693	647546	19443T	PARTICIPANT	\N	PRESENT	0
648694	647546	12041X	PARTICIPANT	\N	PRESENT	0
648695	647546	19565D	PARTICIPANT	\N	PRESENT	0
648696	647546	20072C	PARTICIPANT	\N	PRESENT	1
648697	647546	01058X	PARTICIPANT	\N	PRESENT	0
648698	647546	16685X	PARTICIPANT	\N	PRESENT	0
648699	647546	04042C	PRESIDENT	0	PRESENT	0
648700	647546	11054L	PARTICIPANT	\N	PRESENT	0
648701	647546	19669L	PARTICIPANT	\N	PRESENT	0
648702	647546	11066Q	PARTICIPANT	\N	PRESENT	0
648703	647546	12028B	PARTICIPANT	\N	PRESENT	0
648704	647546	19421M	PARTICIPANT	\N	PRESENT	0
648705	647546	14193X	PARTICIPANT	\N	PRESENT	0
648706	647546	19347U	PARTICIPANT	\N	PRESENT	0
648707	647546	08061X	PARTICIPANT	\N	PRESENT	0
648708	647546	14249W	PARTICIPANT	\N	PRESENT	0
648709	647546	08047A	PARTICIPANT	\N	PRESENT	0
648710	647546	14097Y	PARTICIPANT	\N	PRESENT	0
648711	647546	14133K	PRESIDENT	1	PRESENT	0
648712	647546	01062T	PARTICIPANT	\N	PRESENT	0
648713	647546	08069G	PARTICIPANT	\N	PRESENT	0
648714	647546	11041F	PARTICIPANT	\N	PRESENT	0
648715	647546	01024M	PARTICIPANT	\N	PRESENT	0
648716	647546	14191V	PARTICIPANT	\N	PRESENT	0
648717	647546	20064C	PARTICIPANT	\N	PRESENT	0
648718	647546	14267Y	PARTICIPANT	\N	PRESENT	0
648719	647546	11064N	PARTICIPANT	\N	PRESENT	0
648720	647546	11083R	PARTICIPANT	\N	PRESENT	0
648721	647546	14211G	PARTICIPANT	\N	PRESENT	0
648722	647546	19583F	PARTICIPANT	\N	PRESENT	0
648723	647546	17023S	PARTICIPANT	\N	PRESENT	0
648724	647546	07033P	PARTICIPANT	\N	EXCUSE	0
648725	647669	14327T	PARTICIPANT	\N	PRESENT	0
648734	648729	20032T	PARTICIPANT	\N	PRESENT	0
648735	648729	19954N	PARTICIPANT	\N	PRESENT	0
648736	648729	20138D	PARTICIPANT	\N	PRESENT	0
648737	648729	14259Y	PARTICIPANT	\N	PRESENT	0
648423	647518	20108W	PARTICIPANT	\N	PRESENT	0
648424	647518	20110Q	PARTICIPANT	\N	PRESENT	0
648425	647518	14147R	PARTICIPANT	\N	PRESENT	0
648426	647518	14069U	PARTICIPANT	\N	PRESENT	0
648427	647518	20114U	PARTICIPANT	\N	PRESENT	0
648428	647518	19749K	PARTICIPANT	\N	PRESENT	0
648429	647518	14021P	PARTICIPANT	\N	PRESENT	0
648430	647518	20022R	PARTICIPANT	\N	PRESENT	0
648738	648729	19673G	PARTICIPANT	\N	PRESENT	0
648739	648729	19531S	PARTICIPANT	\N	PRESENT	0
648740	648729	14097Y	PARTICIPANT	\N	PRESENT	0
648741	648729	20126Y	PARTICIPANT	\N	PRESENT	0
648742	648729	20052X	PARTICIPANT	\N	PRESENT	0
648743	648729	14071N	PARTICIPANT	\N	PRESENT	0
648745	648729	14225N	PARTICIPANT	\N	PRESENT	0
648749	648729	19719D	PARTICIPANT	\N	PRESENT	0
648751	648750	04033B	PARTICIPANT	\N	PRESENT	0
648752	648750	19711U	PARTICIPANT	\N	PRESENT	0
648753	648750	14357A	PARTICIPANT	\N	PRESENT	0
648787	647546	95041E	PARTICIPANT	\N	EXCUSE	0
648799	647546	11027H	PARTICIPANT	\N	PRESENT	1
649105	647960	05008E	PARTICIPANT	\N	PRESENT	0
649106	647960	20022R	PARTICIPANT	\N	PRESENT	0
649107	647960	20110Q	PARTICIPANT	\N	PRESENT	0
649108	647960	11033F	PARTICIPANT	\N	PRESENT	0
649109	647960	14089Y	PARTICIPANT	\N	PRESENT	0
649110	647960	20114U	PARTICIPANT	\N	PRESENT	0
631735	631641	19715Y	PARTICIPANT	\N	EXCUSE	0
631736	631734	04059M	PARTICIPANT	\N	PRESENT	0
631737	631734	19651A	PARTICIPANT	\N	PRESENT	1
631757	631734	20026V	PARTICIPANT	\N	PRESENT	1
631759	631758	19629C	PARTICIPANT	\N	PRESENT	0
631760	631758	20120S	PARTICIPANT	\N	PRESENT	0
631761	631758	19549D	PARTICIPANT	\N	PRESENT	0
631763	631762	19629C	PARTICIPANT	\N	PRESENT	0
631764	631762	20120S	PARTICIPANT	\N	PRESENT	0
631765	631762	19549D	PARTICIPANT	\N	PRESENT	0
634925	634432	14223L	PARTICIPANT	\N	PRESENT	0
631746	631734	19399H	PARTICIPANT	\N	PRESENT	0
634926	634432	10006L	PRESIDENT	0	PRESENT	0
631748	631734	19611R	PRESIDENT	0	PRESENT	0
631749	631734	19699S	PARTICIPANT	\N	PRESENT	0
634942	634649	20128B	PARTICIPANT	\N	PRESENT	0
631751	631734	20142Y	PARTICIPANT	\N	PRESENT	1
631752	631734	19705W	PARTICIPANT	\N	PRESENT	1
631753	631734	14229S	PARTICIPANT	\N	PRESENT	0
634943	634649	19387D	PARTICIPANT	\N	PRESENT	0
634944	634649	14107H	PARTICIPANT	\N	PRESENT	0
631756	631734	20122U	PARTICIPANT	\N	PRESENT	0
634945	634649	19563B	PARTICIPANT	\N	PRESENT	0
634946	634649	20068G	PARTICIPANT	\N	PRESENT	0
634949	634649	19333N	PARTICIPANT	\N	PRESENT	0
634950	634649	14069U	PARTICIPANT	\N	PRESENT	0
634951	634649	19503N	PARTICIPANT	\N	PRESENT	0
634952	634649	19349W	PARTICIPANT	\N	PRESENT	0
634953	634649	20022R	PARTICIPANT	\N	PRESENT	0
634954	634649	14211G	PARTICIPANT	\N	PRESENT	0
634955	634649	19251M	PARTICIPANT	\N	PRESENT	0
634956	634649	14121F	PARTICIPANT	\N	PRESENT	0
634957	634649	20132W	PARTICIPANT	\N	PRESENT	0
634958	634649	20062A	PARTICIPANT	\N	PRESENT	0
634960	634649	20026V	PARTICIPANT	\N	PRESENT	0
634962	634649	19701S	PARTICIPANT	\N	PRESENT	0
634963	634649	19479G	PARTICIPANT	\N	PRESENT	0
634965	634649	20048C	PARTICIPANT	\N	PRESENT	0
634976	634649	19798U	PARTICIPANT	\N	PRESENT	0
634980	634649	04070G	PARTICIPANT	\N	PRESENT	0
634982	634649	19631V	PARTICIPANT	\N	PRESENT	0
634983	634649	19637C	PARTICIPANT	\N	PRESENT	0
634984	634649	19758L	PARTICIPANT	\N	PRESENT	0
634985	634649	20058E	PARTICIPANT	\N	PRESENT	0
634986	634649	08028W	PARTICIPANT	\N	PRESENT	0
634987	634649	20110Q	PARTICIPANT	\N	PRESENT	0
634988	634649	19367Y	PARTICIPANT	\N	PRESENT	0
634989	634649	04047H	PARTICIPANT	\N	PRESENT	0
634990	634649	14223L	PARTICIPANT	\N	PRESENT	0
634991	634649	19693L	PARTICIPANT	\N	PRESENT	0
634992	634649	14225N	PARTICIPANT	\N	PRESENT	0
634993	634649	11101A	PARTICIPANT	\N	PRESENT	0
634994	634649	01048V	PARTICIPANT	\N	PRESENT	0
634995	634649	20104S	PARTICIPANT	\N	PRESENT	0
634996	634649	20056C	PARTICIPANT	\N	PRESENT	0
635066	634650	19503N	PARTICIPANT	\N	PRESENT	0
635067	634650	19631V	PARTICIPANT	\N	PRESENT	0
635068	634650	19637C	PARTICIPANT	\N	PRESENT	0
635069	634650	20128B	PARTICIPANT	\N	PRESENT	0
635070	634650	19651A	PARTICIPANT	\N	PRESENT	0
635071	634650	19760E	PARTICIPANT	\N	PRESENT	0
635072	634650	19758L	PARTICIPANT	\N	PRESENT	0
635073	634650	19954N	PARTICIPANT	\N	PRESENT	0
635074	634650	04047H	PARTICIPANT	\N	PRESENT	0
635075	634650	19387D	PARTICIPANT	\N	PRESENT	0
635076	634650	20132W	PARTICIPANT	\N	PRESENT	0
635077	634650	19745F	PARTICIPANT	\N	PRESENT	0
635078	634650	19479G	PARTICIPANT	\N	PRESENT	0
635079	634650	01024M	PARTICIPANT	\N	PRESENT	0
635080	634650	14189C	PARTICIPANT	\N	PRESENT	0
635081	634650	04070G	PARTICIPANT	\N	PRESENT	0
635082	634650	19367Y	PARTICIPANT	\N	PRESENT	0
635083	634650	14215L	PARTICIPANT	\N	PRESENT	0
635084	634650	14105F	PARTICIPANT	\N	PRESENT	0
635085	634650	20062A	PARTICIPANT	\N	PRESENT	0
635086	634650	20090E	PARTICIPANT	\N	PRESENT	0
635087	634650	19762G	PARTICIPANT	\N	PRESENT	0
635088	634650	14173T	PARTICIPANT	\N	PRESENT	0
635089	634650	08028W	PARTICIPANT	\N	PRESENT	0
635090	634650	08015R	PARTICIPANT	\N	PRESENT	0
635091	634650	20058E	PARTICIPANT	\N	PRESENT	0
635092	634650	20056C	PARTICIPANT	\N	PRESENT	0
635093	634650	20026V	PARTICIPANT	\N	PRESENT	0
635094	634650	18083K	PARTICIPANT	\N	PRESENT	0
635096	634650	19533U	PARTICIPANT	\N	PRESENT	0
635097	634650	19679N	PARTICIPANT	\N	PRESENT	0
635098	634650	11043H	PARTICIPANT	\N	PRESENT	0
635099	634650	14223L	PARTICIPANT	\N	PRESENT	0
635100	634650	20022R	PARTICIPANT	\N	PRESENT	0
635104	634650	20112S	PARTICIPANT	\N	PRESENT	0
635105	634650	20110Q	PARTICIPANT	\N	PRESENT	0
635108	634650	20106U	PARTICIPANT	\N	PRESENT	0
635110	634650	01043Q	PARTICIPANT	\N	PRESENT	0
635114	634650	19563B	PARTICIPANT	\N	PRESENT	0
635116	634650	14030Q	PARTICIPANT	\N	PRESENT	0
635120	634650	19693L	PARTICIPANT	\N	PRESENT	0
635121	634650	19467C	PARTICIPANT	\N	PRESENT	0
635122	634650	20038A	PARTICIPANT	\N	PRESENT	0
635123	634650	11101A	PARTICIPANT	\N	PRESENT	0
635124	634459	14237S	PARTICIPANT	\N	PRESENT	0
635125	634459	19711U	PARTICIPANT	\N	PRESENT	0
635126	634459	19701S	PARTICIPANT	\N	PRESENT	0
635127	634459	19349W	PARTICIPANT	\N	PRESENT	0
635128	634459	11053K	PARTICIPANT	\N	PRESENT	0
635129	634459	20050V	PARTICIPANT	\N	PRESENT	0
635130	634459	08010L	PARTICIPANT	\N	PRESENT	0
635131	634459	11074Q	PARTICIPANT	\N	PRESENT	0
635132	634459	99004R	PARTICIPANT	\N	PRESENT	0
635133	634459	19667J	PARTICIPANT	\N	PRESENT	0
635134	634459	14225N	PRESIDENT	0	PRESENT	0
635135	634650	19577H	PARTICIPANT	\N	PRESENT	0
635136	634650	20124W	PARTICIPANT	\N	PRESENT	0
635141	634650	20086J	PARTICIPANT	\N	PRESENT	0
635143	634650	19593H	PARTICIPANT	\N	PRESENT	0
635144	634650	01048V	PARTICIPANT	\N	PRESENT	0
635145	634650	20082E	PARTICIPANT	\N	PRESENT	0
635146	634459	14331P	PARTICIPANT	\N	PRESENT	0
635147	634459	11048N	PARTICIPANT	\N	PRESENT	0
635148	634459	19647E	PARTICIPANT	\N	PRESENT	0
635149	634459	10015M	PARTICIPANT	\N	PRESENT	0
635150	634459	01057W	PARTICIPANT	\N	PRESENT	0
635151	634459	19689Q	PARTICIPANT	\N	PRESENT	0
635064	634650	19719D	PARTICIPANT	\N	PRESENT	0
635065	634650	19251M	PARTICIPANT	\N	PRESENT	0
635152	634459	14001X	PARTICIPANT	\N	PRESENT	0
635153	634459	20044X	PARTICIPANT	\N	PRESENT	0
635154	634459	04045F	PARTICIPANT	\N	PRESENT	0
635155	634459	19741B	PARTICIPANT	\N	PRESENT	0
635156	634459	14253S	PARTICIPANT	\N	PRESENT	0
635157	634459	19335Q	PARTICIPANT	\N	PRESENT	0
635158	634650	20172F	PARTICIPANT	\N	PRESENT	0
635309	634651	19479G	PARTICIPANT	\N	PRESENT	0
635310	634651	14033T	PARTICIPANT	\N	PRESENT	0
635311	634651	14217N	PARTICIPANT	\N	PRESENT	0
635312	634651	14069U	PARTICIPANT	\N	PRESENT	0
635314	634651	19565D	PARTICIPANT	\N	PRESENT	0
635315	634651	20024T	PARTICIPANT	\N	PRESENT	0
635316	634651	11012A	PARTICIPANT	\N	PRESENT	0
635317	634651	19954N	PARTICIPANT	\N	PRESENT	0
635318	634651	14026U	PARTICIPANT	\N	PRESENT	0
635319	634651	20038A	PARTICIPANT	\N	PRESENT	0
635320	634651	20100N	PARTICIPANT	\N	PRESENT	0
635321	634651	11115U	PARTICIPANT	\N	PRESENT	0
635322	634651	19333N	PARTICIPANT	\N	PRESENT	0
635323	634651	14147R	PARTICIPANT	\N	PRESENT	0
635324	634651	14031R	PARTICIPANT	\N	PRESENT	0
635325	634651	08056B	PARTICIPANT	\N	PRESENT	0
635326	634651	20102Q	PARTICIPANT	\N	PRESENT	0
635327	634651	19703U	PARTICIPANT	\N	PRESENT	0
635328	634651	17965H	PARTICIPANT	\N	PRESENT	0
635329	634651	19697Q	PARTICIPANT	\N	PRESENT	0
635330	634651	14021P	PARTICIPANT	\N	PRESENT	0
635331	634651	17779H	PARTICIPANT	\N	PRESENT	0
635332	634651	10006L	PARTICIPANT	\N	PRESENT	0
635333	634651	19549D	PARTICIPANT	\N	PRESENT	0
635334	634651	19723Y	PARTICIPANT	\N	PRESENT	0
635335	634651	19663E	PARTICIPANT	\N	PRESENT	0
635336	634651	20120S	PARTICIPANT	\N	PRESENT	0
635337	634651	11067R	PARTICIPANT	\N	PRESENT	0
635369	634651	11043H	PARTICIPANT	\N	PRESENT	0
635373	634651	11031D	PARTICIPANT	\N	PRESENT	0
641036	641035	19735D	PARTICIPANT	\N	PRESENT	0
641037	641035	19723Y	PARTICIPANT	\N	PRESENT	0
641040	641039	19735D	PARTICIPANT	\N	PRESENT	0
641041	641039	19723Y	PARTICIPANT	\N	PRESENT	0
641044	641043	19735D	PARTICIPANT	\N	PRESENT	0
641045	641043	19723Y	PARTICIPANT	\N	PRESENT	0
641048	641047	19735D	PARTICIPANT	\N	PRESENT	0
641049	641047	19723Y	PARTICIPANT	\N	PRESENT	0
641052	641051	19735D	PARTICIPANT	\N	PRESENT	0
641053	641051	19723Y	PARTICIPANT	\N	PRESENT	0
641056	641055	19735D	PARTICIPANT	\N	PRESENT	0
641057	641055	19723Y	PARTICIPANT	\N	PRESENT	0
641060	641059	19735D	PARTICIPANT	\N	PRESENT	0
641061	641059	19723Y	PARTICIPANT	\N	PRESENT	0
641064	641063	19503N	PARTICIPANT	\N	PRESENT	0
641086	641085	14133K	PARTICIPANT	\N	PRESENT	1
641087	641085	11027H	PARTICIPANT	\N	PRESENT	1
641088	641085	11083R	PARTICIPANT	\N	PRESENT	1
641089	641085	11066Q	PARTICIPANT	\N	PRESENT	1
641091	641090	19713W	PARTICIPANT	\N	PRESENT	0
641092	641090	19369B	PARTICIPANT	\N	PRESENT	0
641093	641090	19745F	PARTICIPANT	\N	PRESENT	0
641095	641094	19713W	PARTICIPANT	\N	PRESENT	0
641096	641094	17229F	PARTICIPANT	\N	PRESENT	0
641097	641094	20120S	PARTICIPANT	\N	PRESENT	0
641098	641094	19553Y	PARTICIPANT	\N	PRESENT	0
641099	641094	19369B	PARTICIPANT	\N	PRESENT	0
641100	641094	19745F	PARTICIPANT	\N	PRESENT	0
641102	641101	19713W	PARTICIPANT	\N	PRESENT	0
641103	641101	14147R	PARTICIPANT	\N	PRESENT	0
641104	641101	11083R	PARTICIPANT	\N	PRESENT	0
641105	641101	20120S	PARTICIPANT	\N	PRESENT	0
641106	641101	11026G	PARTICIPANT	\N	PRESENT	0
641107	641101	19745F	PARTICIPANT	\N	PRESENT	0
641108	641101	14133K	PARTICIPANT	\N	PRESENT	0
641109	641101	04035D	PARTICIPANT	\N	PRESENT	0
641110	641101	19569H	PARTICIPANT	\N	PRESENT	0
641111	641101	08061X	PARTICIPANT	\N	PRESENT	0
641112	641101	01058X	PARTICIPANT	\N	PRESENT	0
641113	641094	14267Y	PARTICIPANT	\N	PRESENT	0
641114	641094	95041E	PARTICIPANT	\N	PRESENT	0
641115	641094	08047A	PARTICIPANT	\N	PRESENT	0
641116	641094	19443T	PARTICIPANT	\N	PRESENT	0
641117	641094	20064C	PARTICIPANT	\N	PRESENT	0
641118	640959	11040E	PARTICIPANT	\N	EXCUSE	0
641120	641119	20050V	PARTICIPANT	\N	PRESENT	0
641121	641119	20082E	PARTICIPANT	\N	PRESENT	0
641123	641122	20050V	PARTICIPANT	\N	PRESENT	0
641124	641122	20082E	PARTICIPANT	\N	PRESENT	1
641125	641122	19369B	PARTICIPANT	\N	EXCUSE	0
641126	641122	20126Y	PARTICIPANT	\N	PRESENT	1
641127	641122	19693L	PARTICIPANT	\N	PRESENT	1
641128	641122	20074E	PARTICIPANT	\N	EXCUSE	0
641129	641122	20066E	PARTICIPANT	\N	PRESENT	1
641187	641186	20034V	PARTICIPANT	\N	PRESENT	1
641132	641130	20126Y	PARTICIPANT	\N	PRESENT	1
641188	641186	20150Y	PARTICIPANT	\N	PRESENT	1
641134	641130	14213J	PARTICIPANT	\N	PRESENT	1
641137	641130	20050V	PARTICIPANT	\N	PRESENT	0
641136	641130	19693L	PARTICIPANT	\N	PRESENT	0
641189	641186	19717B	PARTICIPANT	\N	EXCUSE	0
641190	641186	14083S	PRESIDENT	0	PRESENT	0
641191	641186	19333N	PARTICIPANT	\N	EXCUSE	0
641192	641186	20100N	PARTICIPANT	\N	EXCUSE	0
641198	641186	19503N	PARTICIPANT	\N	PRESENT	0
641226	641027	20094J	PARTICIPANT	\N	PRESENT	1
641227	641027	20104S	PARTICIPANT	\N	PRESENT	0
641228	641027	14207L	PARTICIPANT	\N	PRESENT	0
641230	641027	14189C	PARTICIPANT	\N	EXCUSE	0
641231	641027	20098N	PARTICIPANT	\N	PRESENT	0
641232	641027	14237S	PARTICIPANT	\N	PRESENT	1
641233	641027	14331P	PRESIDENT	0	PRESENT	0
641234	641027	10015M	PARTICIPANT	\N	PRESENT	0
641235	641027	08034U	PARTICIPANT	\N	EXCUSE	0
641236	641027	19441R	PARTICIPANT	\N	PRESENT	1
641237	641027	14001X	PARTICIPANT	\N	PRESENT	1
641238	641027	14097Y	PARTICIPANT	\N	PRESENT	1
641239	641027	14073Q	PARTICIPANT	\N	PRESENT	1
641240	641027	19711U	PARTICIPANT	\N	PRESENT	0
641241	641027	11026G	PARTICIPANT	\N	PRESENT	1
641242	641027	14026U	PARTICIPANT	\N	PRESENT	0
641243	641027	14033T	PARTICIPANT	\N	PRESENT	0
641244	641027	11083R	PARTICIPANT	\N	PRESENT	0
641245	641027	12041X	PARTICIPANT	\N	PRESENT	0
641246	641027	19333N	PARTICIPANT	\N	PRESENT	0
641248	641247	19663E	PARTICIPANT	\N	PRESENT	0
641249	641247	10006L	PARTICIPANT	\N	PRESENT	0
641250	641247	19667J	PARTICIPANT	\N	PRESENT	0
641251	641247	20024T	PARTICIPANT	\N	PRESENT	0
641252	641247	19575F	PARTICIPANT	\N	PRESENT	0
641253	641247	14223L	PARTICIPANT	\N	PRESENT	0
641254	641247	19798U	PARTICIPANT	\N	PRESENT	0
641270	641267	20286Q	PARTICIPANT	\N	PRESENT	0
641271	641267	11090Q	PARTICIPANT	\N	PRESENT	0
641272	641267	14257W	PARTICIPANT	\N	PRESENT	0
641273	641268	11090Q	PARTICIPANT	\N	PRESENT	0
641274	641268	14257W	PARTICIPANT	\N	PRESENT	0
641275	641269	11090Q	PARTICIPANT	\N	PRESENT	0
641276	641269	14257W	PARTICIPANT	\N	PRESENT	0
641277	641193	04047H	PARTICIPANT	\N	PRESENT	0
641278	641193	20110Q	PARTICIPANT	\N	PRESENT	0
641279	641193	14053L	PARTICIPANT	\N	PRESENT	0
641280	641193	14107H	PARTICIPANT	\N	PRESENT	0
641281	641193	11056N	PARTICIPANT	\N	PRESENT	0
641282	641193	14215L	PARTICIPANT	\N	PRESENT	0
641283	641196	04047H	PARTICIPANT	\N	PRESENT	0
641284	641196	20110Q	PARTICIPANT	\N	PRESENT	0
641285	641196	14053L	PARTICIPANT	\N	PRESENT	0
641286	641196	14107H	PARTICIPANT	\N	PRESENT	0
641287	641200	04047H	PARTICIPANT	\N	PRESENT	0
641288	641200	20110Q	PARTICIPANT	\N	PRESENT	0
641289	641200	01028R	PARTICIPANT	\N	PRESENT	0
641290	641200	11056N	PARTICIPANT	\N	PRESENT	0
641291	641200	14053L	PARTICIPANT	\N	PRESENT	0
641292	641200	14107H	PARTICIPANT	\N	PRESENT	0
641293	641200	14215L	PARTICIPANT	\N	PRESENT	0
641294	641203	04047H	PARTICIPANT	\N	PRESENT	0
641295	641203	11056N	PARTICIPANT	\N	PRESENT	0
641296	641203	14053L	PARTICIPANT	\N	PRESENT	0
641297	641203	20110Q	PARTICIPANT	\N	PRESENT	0
641298	641206	04047H	PARTICIPANT	\N	PRESENT	0
641299	641206	14053L	PARTICIPANT	\N	PRESENT	0
641300	641206	01028R	PARTICIPANT	\N	PRESENT	0
641301	641209	04047H	PARTICIPANT	\N	PRESENT	0
641302	641209	20110Q	PARTICIPANT	\N	PRESENT	0
641303	641209	14053L	PARTICIPANT	\N	PRESENT	0
641304	641209	01028R	PARTICIPANT	\N	PRESENT	0
641305	641209	11056N	PARTICIPANT	\N	PRESENT	0
641306	640959	20032T	PARTICIPANT	\N	PRESENT	0
641308	641307	19543W	PARTICIPANT	\N	PRESENT	0
641309	641307	04008A	PARTICIPANT	\N	PRESENT	0
641310	641307	14147R	PARTICIPANT	\N	PRESENT	1
641311	640959	14259Y	PARTICIPANT	\N	PRESENT	0
641312	640959	20042V	PARTICIPANT	\N	PRESENT	0
641313	640959	99004R	PARTICIPANT	\N	PRESENT	0
641315	641314	04008A	PARTICIPANT	\N	PRESENT	0
641316	641314	14151M	PARTICIPANT	\N	PRESENT	0
641317	641314	14147R	PARTICIPANT	\N	PRESENT	1
641318	640959	20132W	PARTICIPANT	\N	PRESENT	0
641319	640959	19711U	PARTICIPANT	\N	PRESENT	0
641320	640959	11056N	PARTICIPANT	\N	PRESENT	0
641321	640959	19954N	PARTICIPANT	\N	PRESENT	0
641322	640959	19651A	PARTICIPANT	\N	PRESENT	0
641323	640959	20044X	PARTICIPANT	\N	PRESENT	0
641325	641324	04008A	PARTICIPANT	\N	PRESENT	0
641326	641324	14151M	PARTICIPANT	\N	PRESENT	0
641327	641324	14147R	PARTICIPANT	\N	PRESENT	1
641329	641328	04008A	PARTICIPANT	\N	PRESENT	0
641330	641328	14151M	PARTICIPANT	\N	PRESENT	0
641331	641328	19543W	PARTICIPANT	\N	PRESENT	0
641332	641328	20128B	PARTICIPANT	\N	PRESENT	1
633564	631567	20078J	PARTICIPANT	\N	PRESENT	0
633565	629594	20096L	PARTICIPANT	\N	PRESENT	0
633566	629594	19551W	PARTICIPANT	\N	PRESENT	0
633567	631567	14069U	PARTICIPANT	\N	PRESENT	0
633571	629594	20106U	PARTICIPANT	\N	PRESENT	0
633572	631567	19467C	PARTICIPANT	\N	PRESENT	0
633573	631594	20044X	PARTICIPANT	\N	PRESENT	0
633574	631567	14073Q	PARTICIPANT	\N	PRESENT	0
633580	629594	17637T	PARTICIPANT	\N	PRESENT	0
633581	629594	05012A	PARTICIPANT	\N	EXCUSE	0
633582	629594	08060W	PARTICIPANT	\N	EXCUSE	0
633583	629594	14221J	PARTICIPANT	\N	EXCUSE	0
633584	629594	19745F	PARTICIPANT	\N	EXCUSE	0
633585	629594	19619A	PARTICIPANT	\N	EXCUSE	0
633586	631567	08056B	PARTICIPANT	\N	PRESENT	0
633587	631567	19349W	PARTICIPANT	\N	PRESENT	0
633588	629594	18083K	PARTICIPANT	\N	PRESENT	0
633589	631567	04047H	PARTICIPANT	\N	PRESENT	0
633590	629594	19637C	PARTICIPANT	\N	EXCUSE	0
633592	631567	20134Y	PARTICIPANT	\N	PRESENT	0
633593	631567	20052X	PARTICIPANT	\N	PRESENT	0
633594	631567	19747H	PARTICIPANT	\N	PRESENT	0
633595	631567	19569H	PARTICIPANT	\N	PRESENT	0
633596	631567	11045K	PARTICIPANT	\N	PRESENT	0
633627	631568	08012N	PARTICIPANT	\N	PRESENT	0
633628	631568	19585H	PARTICIPANT	\N	PRESENT	0
633629	631568	11043H	PARTICIPANT	\N	PRESENT	0
633630	631568	20036X	PARTICIPANT	\N	PRESENT	0
633631	631568	14195A	PARTICIPANT	\N	PRESENT	0
633632	631568	19349W	PARTICIPANT	\N	PRESENT	0
633633	631568	20128B	PARTICIPANT	\N	PRESENT	0
633634	631568	01025N	PARTICIPANT	\N	PRESENT	0
633635	631568	14030Q	PARTICIPANT	\N	PRESENT	0
633636	631568	20132W	PARTICIPANT	\N	PRESENT	0
633637	631568	14073Q	PARTICIPANT	\N	PRESENT	0
633638	631568	20052X	PARTICIPANT	\N	PRESENT	0
633639	631568	01024M	PARTICIPANT	\N	PRESENT	0
633640	631568	07004J	PARTICIPANT	\N	PRESENT	0
633641	631568	14215L	PARTICIPANT	\N	PRESENT	0
633642	631568	19747H	PARTICIPANT	\N	PRESENT	0
633643	631568	20024T	PARTICIPANT	\N	PRESENT	0
633644	631568	20026V	PARTICIPANT	\N	PRESENT	0
633645	631568	20180F	PARTICIPANT	\N	PRESENT	0
633646	631568	20098N	PARTICIPANT	\N	PRESENT	0
633647	631568	19467C	PARTICIPANT	\N	PRESENT	0
633648	631568	14259Y	PARTICIPANT	\N	PRESENT	0
633649	631568	11067R	PARTICIPANT	\N	PRESENT	0
633650	631568	19758L	PARTICIPANT	\N	PRESENT	0
633651	631568	19387D	PARTICIPANT	\N	PRESENT	0
633652	631568	19673G	PARTICIPANT	\N	PRESENT	0
633653	631568	19569H	PARTICIPANT	\N	PRESENT	0
633655	631568	04092N	PARTICIPANT	\N	PRESENT	0
633625	631568	19719D	PARTICIPANT	\N	PRESENT	0
633626	631568	20134Y	PARTICIPANT	\N	PRESENT	0
633671	631568	19593H	PARTICIPANT	\N	PRESENT	0
633672	631568	20078J	PARTICIPANT	\N	PRESENT	0
633673	631568	19533U	PARTICIPANT	\N	PRESENT	0
633674	631568	20124W	PARTICIPANT	\N	PRESENT	0
633675	631568	20066E	PARTICIPANT	\N	PRESENT	0
633676	631568	14147R	PARTICIPANT	\N	PRESENT	0
633691	631568	19693L	PARTICIPANT	\N	PRESENT	0
633694	631568	20090E	PARTICIPANT	\N	PRESENT	0
633695	631568	97011G	PARTICIPANT	\N	PRESENT	0
633696	631568	20100N	PARTICIPANT	\N	PRESENT	0
633697	631568	20046A	PARTICIPANT	\N	PRESENT	0
633698	631568	20032T	PARTICIPANT	\N	PRESENT	0
633699	631568	19399H	PARTICIPANT	\N	PRESENT	0
633700	631568	19691J	PARTICIPANT	\N	PRESENT	0
633701	631568	01048V	PARTICIPANT	\N	PRESENT	0
633702	631568	20110Q	PARTICIPANT	\N	PRESENT	0
633704	631568	04045F	PARTICIPANT	\N	PRESENT	0
633705	631568	19333N	PARTICIPANT	\N	PRESENT	0
633706	631568	14121F	PARTICIPANT	\N	PRESENT	0
633710	631707	14097Y	PARTICIPANT	\N	PRESENT	0
633708	631568	14173T	PARTICIPANT	\N	PRESENT	0
633709	631568	20106U	PARTICIPANT	\N	PRESENT	0
633711	631707	04035D	PARTICIPANT	\N	PRESENT	0
633712	631707	19565D	PARTICIPANT	\N	PRESENT	0
633713	631707	20072C	PARTICIPANT	\N	PRESENT	0
633714	631707	01062T	PARTICIPANT	\N	PRESENT	1
633715	631707	11041F	PARTICIPANT	\N	PRESENT	0
633716	631707	20042V	PARTICIPANT	\N	PRESENT	0
633717	631707	01058X	PARTICIPANT	\N	PRESENT	0
633718	631707	16685X	PARTICIPANT	\N	PRESENT	0
633719	631707	04042C	PRESIDENT	0	PRESENT	0
633720	631707	11054L	PARTICIPANT	\N	PRESENT	0
633721	631707	12028B	PARTICIPANT	\N	PRESENT	0
633722	631707	19421M	PARTICIPANT	\N	PRESENT	0
633723	631707	14267Y	PARTICIPANT	\N	PRESENT	0
633724	631707	19347U	PARTICIPANT	\N	PRESENT	0
633725	631707	11064N	PARTICIPANT	\N	PRESENT	0
633726	631707	14193X	PARTICIPANT	\N	PRESENT	0
633727	631707	11083R	PARTICIPANT	\N	PRESENT	0
633728	631707	97011G	PARTICIPANT	\N	PRESENT	0
633729	631707	14249W	PARTICIPANT	\N	PRESENT	0
633730	631707	14211G	PARTICIPANT	\N	PRESENT	0
633731	631707	14255U	PARTICIPANT	\N	PRESENT	0
634036	631571	20152B	PARTICIPANT	\N	PRESENT	0
633891	631571	99004R	PARTICIPANT	\N	PRESENT	0
633943	631571	20032T	PARTICIPANT	\N	PRESENT	0
633944	631571	20100N	PARTICIPANT	\N	PRESENT	0
633945	631571	20102Q	PARTICIPANT	\N	PRESENT	0
633946	631571	14073Q	PARTICIPANT	\N	PRESENT	0
633947	631571	11012A	PARTICIPANT	\N	PRESENT	0
633948	631571	19551W	PARTICIPANT	\N	PRESENT	0
633949	631571	20128B	PARTICIPANT	\N	PRESENT	0
633950	631571	11064N	PARTICIPANT	\N	PRESENT	0
633951	631571	20098N	PARTICIPANT	\N	PRESENT	0
633953	631571	20096L	PARTICIPANT	\N	PRESENT	0
633954	631571	20124W	PARTICIPANT	\N	PRESENT	0
633972	631571	19415P	PARTICIPANT	\N	PRESENT	0
633975	631571	14217N	PARTICIPANT	\N	PRESENT	0
633976	631571	14219Q	PARTICIPANT	\N	PRESENT	0
633977	631571	19954N	PARTICIPANT	\N	PRESENT	0
633981	631571	20034V	PARTICIPANT	\N	PRESENT	0
633982	631571	10015M	PARTICIPANT	\N	PRESENT	0
633983	631571	20126Y	PARTICIPANT	\N	PRESENT	0
634002	631571	04045F	PARTICIPANT	\N	PRESENT	0
634003	631571	20048C	PARTICIPANT	\N	PRESENT	0
634005	631571	20036X	PARTICIPANT	\N	PRESENT	0
634013	631571	14267Y	PARTICIPANT	\N	PRESENT	0
634015	631571	20028X	PARTICIPANT	\N	PRESENT	0
634020	631571	14147R	PARTICIPANT	\N	PRESENT	0
634021	631571	19741B	PARTICIPANT	\N	PRESENT	0
634022	631571	19467C	PARTICIPANT	\N	PRESENT	0
634024	631571	19782L	PARTICIPANT	\N	PRESENT	0
634025	631571	20132W	PARTICIPANT	\N	PRESENT	0
634032	631571	19251M	PARTICIPANT	\N	PRESENT	0
634033	634026	20266L	PRESIDENT	0	PRESENT	0
634034	634026	18193Q	PARTICIPANT	\N	PRESENT	0
634698	634694	19735D	PARTICIPANT	\N	PRESENT	1
634699	634695	19735D	PARTICIPANT	\N	PRESENT	1
634700	634696	19735D	PARTICIPANT	\N	PRESENT	1
634701	634697	19735D	PARTICIPANT	\N	PRESENT	1
638997	638996	11083R	PARTICIPANT	\N	PRESENT	0
638998	638996	14331P	PARTICIPANT	\N	PRESENT	0
638999	638996	19725B	PARTICIPANT	\N	PRESENT	0
639888	639759	11085T	PARTICIPANT	\N	PRESENT	0
639889	639759	01025N	PARTICIPANT	\N	PRESENT	0
639890	639759	01043Q	PARTICIPANT	\N	PRESENT	0
639899	639759	14179A	PARTICIPANT	\N	PRESENT	0
639892	639759	14089Y	PARTICIPANT	\N	PRESENT	0
639893	639759	19866P	PARTICIPANT	\N	PRESENT	0
639895	639759	20072C	PARTICIPANT	\N	PRESENT	0
639896	639759	01024M	PARTICIPANT	\N	PRESENT	0
639897	639759	19441R	PARTICIPANT	\N	PRESENT	0
639898	639759	20286Q	PARTICIPANT	\N	PRESENT	0
639900	639759	14267Y	PARTICIPANT	\N	PRESENT	0
639901	639759	11053K	PARTICIPANT	\N	PRESENT	0
639902	639759	01034P	PARTICIPANT	\N	PRESENT	0
639903	639759	19691J	PARTICIPANT	\N	PRESENT	0
639904	639759	19611R	PARTICIPANT	\N	PRESENT	0
639905	639481	19533U	PRESIDENT	0	PRESENT	0
639906	639481	19798U	PARTICIPANT	\N	PRESENT	0
639907	639481	19693L	PARTICIPANT	\N	PRESENT	0
639908	639759	19685L	PARTICIPANT	\N	PRESENT	0
639916	639759	20248J	PARTICIPANT	\N	PRESENT	0
639910	639759	20116W	PARTICIPANT	\N	PRESENT	0
639911	639759	16685X	PARTICIPANT	\N	PRESENT	0
639912	639759	14327T	PARTICIPANT	\N	PRESENT	0
639914	639759	19369B	PARTICIPANT	\N	PRESENT	0
649111	647960	04047H	PARTICIPANT	\N	PRESENT	0
649112	647960	14053L	PARTICIPANT	\N	PRESENT	0
649113	647960	11056N	PARTICIPANT	\N	PRESENT	0
649114	647960	14259Y	PARTICIPANT	\N	PRESENT	0
649115	647960	14215L	PARTICIPANT	\N	PRESENT	0
649116	647960	14151M	PARTICIPANT	\N	PRESENT	0
649117	647960	19673G	PARTICIPANT	\N	PRESENT	0
649118	647960	14231L	PARTICIPANT	\N	PRESENT	0
649119	647960	14021P	PARTICIPANT	\N	PRESENT	0
649120	647960	19649G	PARTICIPANT	\N	PRESENT	0
649121	647960	11026G	PARTICIPANT	\N	PRESENT	0
649122	647960	20108W	PARTICIPANT	\N	PRESENT	0
649123	647960	19581D	PARTICIPANT	\N	PRESENT	0
649124	647960	14111D	PARTICIPANT	\N	PRESENT	0
649125	647960	14147R	PARTICIPANT	\N	PRESENT	0
649126	647960	14107H	PARTICIPANT	\N	PRESENT	0
649127	647960	01028R	PARTICIPANT	\N	PRESENT	0
649128	647960	19749K	PARTICIPANT	\N	PRESENT	0
649129	648755	19621T	PARTICIPANT	\N	PRESENT	0
649130	648755	20084G	PARTICIPANT	\N	PRESENT	0
649131	648755	20056C	PARTICIPANT	\N	PRESENT	0
649132	648755	19593H	PARTICIPANT	\N	PRESENT	0
649133	648755	20180F	PARTICIPANT	\N	PRESENT	0
649134	648755	19611R	PRESIDENT	0	PRESENT	0
649135	648755	19758L	PARTICIPANT	\N	PRESENT	0
649136	648755	04059M	PARTICIPANT	\N	PRESENT	1
649137	648755	20124W	PARTICIPANT	\N	PRESENT	0
649138	648755	20132W	PARTICIPANT	\N	PRESENT	0
649139	648755	20058E	PARTICIPANT	\N	PRESENT	0
649140	648755	20142Y	PARTICIPANT	\N	PRESENT	1
649141	648755	20134Y	PARTICIPANT	\N	PRESENT	1
649142	648755	19693L	PARTICIPANT	\N	PRESENT	0
649143	648755	19527W	PARTICIPANT	\N	PRESENT	1
649144	648755	08012N	PARTICIPANT	\N	PRESENT	0
649145	648755	19766L	PARTICIPANT	\N	PRESENT	1
649146	648755	19573D	PARTICIPANT	\N	PRESENT	0
649147	648755	14229S	PARTICIPANT	\N	PRESENT	0
649148	648755	20052X	PARTICIPANT	\N	PRESENT	0
649149	648755	19399H	PARTICIPANT	\N	PRESENT	0
649150	648755	14123H	PARTICIPANT	\N	PRESENT	0
649742	648800	20130U	PARTICIPANT	\N	PRESENT	1
649154	648755	11109J	PARTICIPANT	\N	EXCUSE	0
649153	648755	20264J	PARTICIPANT	\N	PRESENT	0
649155	648755	19735D	PARTICIPANT	\N	EXCUSE	0
649741	648800	19553Y	PARTICIPANT	\N	PRESENT	1
649743	648800	20066E	PARTICIPANT	\N	PRESENT	0
649747	648800	19717B	PARTICIPANT	\N	PRESENT	0
649748	648800	20298U	PARTICIPANT	\N	PRESENT	0
649749	648800	19683J	PARTICIPANT	\N	PRESENT	0
649750	648800	11067R	PARTICIPANT	\N	PRESENT	0
649751	648800	14195A	PARTICIPANT	\N	PRESENT	0
649752	648800	10006L	PRESIDENT	0	PRESENT	0
649753	648800	14042U	PARTICIPANT	\N	PRESENT	0
649754	648800	19798U	PARTICIPANT	\N	PRESENT	0
649756	648800	14071N	PARTICIPANT	\N	PRESENT	0
649757	648800	14217N	PARTICIPANT	\N	PRESENT	0
649758	648800	19723Y	PARTICIPANT	\N	PRESENT	0
649759	648800	20090E	PARTICIPANT	\N	PRESENT	0
649760	648800	19367Y	PARTICIPANT	\N	PRESENT	0
649761	648800	14223L	PARTICIPANT	\N	PRESENT	0
649762	648800	14213J	PARTICIPANT	\N	PRESENT	0
649763	648800	04092N	PARTICIPANT	\N	PRESENT	0
649764	648800	19703U	PARTICIPANT	\N	PRESENT	0
649765	648800	11097X	PARTICIPANT	\N	PRESENT	0
649767	648800	19663E	PARTICIPANT	\N	PRESENT	0
649768	648800	19679N	PARTICIPANT	\N	PRESENT	0
649770	648800	14026U	PARTICIPANT	\N	PRESENT	0
649771	648800	20040T	PARTICIPANT	\N	PRESENT	0
649772	648800	19713W	PARTICIPANT	\N	PRESENT	0
649774	648800	04043D	PARTICIPANT	\N	PRESENT	1
649775	648800	19657G	PARTICIPANT	\N	PRESENT	1
649776	648800	11103C	PARTICIPANT	\N	PRESENT	1
649778	648800	01034P	PARTICIPANT	\N	PRESENT	1
649806	648800	19715Y	PARTICIPANT	\N	EXCUSE	0
649807	648800	17779H	PARTICIPANT	\N	PRESENT	1
649852	648800	11031D	PARTICIPANT	\N	PRESENT	0
649873	648800	20248J	PARTICIPANT	\N	PRESENT	0
649874	648800	19760E	PARTICIPANT	\N	PRESENT	0
649888	648800	19569H	PARTICIPANT	\N	PRESENT	0
649970	648800	18193Q	PARTICIPANT	\N	PRESENT	1
653664	652897	14195A	PARTICIPANT	\N	PRESENT	0
653665	652897	14071N	PARTICIPANT	\N	PRESENT	0
653667	652897	19347U	PARTICIPANT	\N	PRESENT	0
653668	653666	04042C	PARTICIPANT	\N	PRESENT	0
653669	652897	01057W	PARTICIPANT	\N	PRESENT	0
653670	652897	14251Q	PARTICIPANT	\N	PRESENT	0
653671	652897	14089Y	PARTICIPANT	\N	PRESENT	0
653672	652897	20120S	PARTICIPANT	\N	PRESENT	0
653673	652897	14173T	PARTICIPANT	\N	PRESENT	0
653674	652897	20058E	PARTICIPANT	\N	PRESENT	0
653675	652897	20028X	PARTICIPANT	\N	PRESENT	0
653676	652897	19697Q	PARTICIPANT	\N	PRESENT	0
653677	652897	11099A	PARTICIPANT	\N	PRESENT	0
653678	652897	20090E	PARTICIPANT	\N	PRESENT	0
653679	652897	19758L	PARTICIPANT	\N	PRESENT	0
653680	652897	20094J	PARTICIPANT	\N	PRESENT	0
653681	652897	20142Y	PARTICIPANT	\N	PRESENT	0
653682	652897	11085T	PARTICIPANT	\N	PRESENT	0
653683	652897	19729F	PARTICIPANT	\N	PRESENT	0
653684	652897	20026V	PARTICIPANT	\N	PRESENT	0
653685	652897	14026U	PARTICIPANT	\N	PRESENT	0
653686	652897	14211G	PARTICIPANT	\N	PRESENT	0
653687	652897	20022R	PARTICIPANT	\N	PRESENT	0
653688	652897	19443T	PARTICIPANT	\N	PRESENT	0
653689	652897	95041E	PARTICIPANT	\N	PRESENT	0
653690	652897	20140W	PARTICIPANT	\N	PRESENT	0
653691	652897	19367Y	PARTICIPANT	\N	PRESENT	0
653692	652897	01028R	PARTICIPANT	\N	PRESENT	0
653693	652897	19531S	PARTICIPANT	\N	PRESENT	0
653694	652897	18083K	PARTICIPANT	\N	PRESENT	0
653695	652897	04035D	PARTICIPANT	\N	PRESENT	0
653788	652898	14026U	PARTICIPANT	\N	PRESENT	0
653789	652898	14191V	PARTICIPANT	\N	PRESENT	0
653790	652898	20914V	PARTICIPANT	\N	PRESENT	0
653791	652898	11065P	PARTICIPANT	\N	PRESENT	0
653792	652898	20100N	PARTICIPANT	\N	PRESENT	0
653793	652898	99004R	PARTICIPANT	\N	PRESENT	0
653794	652898	20252E	PARTICIPANT	\N	PRESENT	0
653795	652898	19701S	PARTICIPANT	\N	PRESENT	0
653796	652898	18083K	PARTICIPANT	\N	PRESENT	0
653797	652898	14195A	PARTICIPANT	\N	PRESENT	0
653798	652898	11012A	PARTICIPANT	\N	PRESENT	0
653799	652898	14033T	PARTICIPANT	\N	PRESENT	0
653800	652898	19697Q	PARTICIPANT	\N	PRESENT	0
653801	652898	14255U	PARTICIPANT	\N	PRESENT	0
653802	652898	20298U	PARTICIPANT	\N	PRESENT	0
653803	652898	19762G	PARTICIPANT	\N	PRESENT	0
653804	652898	20024T	PARTICIPANT	\N	PRESENT	0
653805	652898	19687N	PARTICIPANT	\N	PRESENT	0
653806	652898	11040E	PARTICIPANT	\N	PRESENT	0
653807	652898	12041X	PARTICIPANT	\N	PRESENT	0
653808	652898	19593H	PARTICIPANT	\N	PRESENT	0
653809	652898	19758L	PARTICIPANT	\N	PRESENT	0
653810	652898	20102Q	PARTICIPANT	\N	PRESENT	0
653811	652898	12028B	PARTICIPANT	\N	PRESENT	0
653812	652898	12016W	PARTICIPANT	\N	PRESENT	0
653813	652898	19503N	PARTICIPANT	\N	PRESENT	0
653814	652898	04071H	PARTICIPANT	\N	PRESENT	0
653815	652898	19820Y	PARTICIPANT	\N	PRESENT	0
653816	652898	19649G	PARTICIPANT	\N	PRESENT	0
653817	652898	20080C	PARTICIPANT	\N	PRESENT	0
653818	652898	19766L	PARTICIPANT	\N	PRESENT	0
653819	652898	19647E	PARTICIPANT	\N	PRESENT	0
653820	652898	14069U	PARTICIPANT	\N	PRESENT	0
653821	652898	11045K	PARTICIPANT	\N	PRESENT	0
653822	652898	20090E	PARTICIPANT	\N	PRESENT	0
653823	652898	19651A	PARTICIPANT	\N	PRESENT	0
653824	652898	20062A	PARTICIPANT	\N	PRESENT	0
653825	652898	20106U	PARTICIPANT	\N	PRESENT	0
653826	652898	20150Y	PARTICIPANT	\N	PRESENT	0
653827	652898	08010L	PARTICIPANT	\N	PRESENT	0
653828	652898	14053L	PARTICIPANT	\N	PRESENT	0
653829	652898	20142Y	PARTICIPANT	\N	PRESENT	0
653830	652898	14259Y	PARTICIPANT	\N	PRESENT	0
653831	652898	04033B	PARTICIPANT	\N	PRESENT	0
653832	652898	20032T	PARTICIPANT	\N	PRESENT	0
653833	652898	19399H	PARTICIPANT	\N	PRESENT	0
653834	652898	07029T	PARTICIPANT	\N	PRESENT	0
653835	652898	19443T	PARTICIPANT	\N	PRESENT	0
653836	652898	20092G	PARTICIPANT	\N	PRESENT	0
653837	652898	19301E	PARTICIPANT	\N	PRESENT	0
653838	652898	20086J	PARTICIPANT	\N	PRESENT	0
629010	629008	14030Q	PARTICIPANT	\N	PRESENT	0
629011	629008	20124W	PARTICIPANT	\N	PRESENT	0
629012	629008	20056C	PARTICIPANT	\N	PRESENT	0
629013	629008	19573D	PARTICIPANT	\N	PRESENT	0
629014	629008	14109K	PARTICIPANT	\N	PRESENT	0
629015	629009	19573D	PARTICIPANT	\N	PRESENT	0
629016	629009	20056C	PARTICIPANT	\N	PRESENT	0
629017	629009	14109K	PARTICIPANT	\N	PRESENT	0
629018	629009	20124W	PARTICIPANT	\N	PRESENT	0
635374	634651	19782L	PARTICIPANT	\N	PRESENT	0
635375	634651	19441R	PARTICIPANT	\N	PRESENT	0
635430	634652	19663E	PARTICIPANT	\N	PRESENT	0
635431	634652	11031D	PARTICIPANT	\N	PRESENT	0
635432	634652	19758L	PARTICIPANT	\N	PRESENT	0
635433	634652	19565D	PARTICIPANT	\N	PRESENT	0
635434	634652	19760E	PARTICIPANT	\N	PRESENT	0
635435	634652	20102Q	PARTICIPANT	\N	PRESENT	0
635436	634652	20070A	PARTICIPANT	\N	PRESENT	0
635437	634652	04092N	PARTICIPANT	\N	PRESENT	0
635438	634652	19549D	PARTICIPANT	\N	PRESENT	0
635439	634652	14026U	PARTICIPANT	\N	PRESENT	0
635440	634652	11067R	PARTICIPANT	\N	PRESENT	0
635441	634652	14147R	PARTICIPANT	\N	PRESENT	0
635442	634652	20066E	PARTICIPANT	\N	PRESENT	0
635443	634652	20024T	PARTICIPANT	\N	PRESENT	0
635444	634652	19441R	PARTICIPANT	\N	PRESENT	0
635445	634652	20026V	PARTICIPANT	\N	PRESENT	0
635446	634652	19713W	PARTICIPANT	\N	PRESENT	0
635447	634652	18083K	PARTICIPANT	\N	PRESENT	0
635448	634652	14231L	PARTICIPANT	\N	PRESENT	0
635449	634652	19691J	PARTICIPANT	\N	PRESENT	0
635450	634652	19723Y	PARTICIPANT	\N	PRESENT	0
635451	634652	01024M	PARTICIPANT	\N	PRESENT	0
635452	634652	19553Y	PARTICIPANT	\N	PRESENT	0
635453	634652	11064N	PARTICIPANT	\N	PRESENT	0
635454	634652	17965H	PARTICIPANT	\N	PRESENT	0
635455	634652	20140W	PARTICIPANT	\N	PRESENT	0
635456	634652	17779H	PARTICIPANT	\N	PRESENT	0
635457	634652	20134Y	PARTICIPANT	\N	PRESENT	0
635458	634652	19697Q	PARTICIPANT	\N	PRESENT	0
635459	634652	20090E	PARTICIPANT	\N	PRESENT	0
635460	634652	20050V	PARTICIPANT	\N	PRESENT	0
635461	634652	20032T	PARTICIPANT	\N	PRESENT	0
635465	634652	14217N	PARTICIPANT	\N	PRESENT	0
635463	634652	11097X	PARTICIPANT	\N	PRESENT	0
635464	634652	18193Q	PARTICIPANT	\N	PRESENT	0
635466	634652	20132W	PARTICIPANT	\N	PRESENT	0
635467	634652	19741B	PARTICIPANT	\N	PRESENT	0
635468	634652	20076G	PARTICIPANT	\N	PRESENT	0
635469	634652	19479G	PARTICIPANT	\N	PRESENT	0
635510	634653	19713W	PARTICIPANT	\N	PRESENT	0
635511	634653	20134Y	PARTICIPANT	\N	PRESENT	0
635512	634653	19553Y	PARTICIPANT	\N	PRESENT	0
635513	634653	17965H	PARTICIPANT	\N	PRESENT	0
635514	634653	19697Q	PARTICIPANT	\N	PRESENT	0
635515	634653	20050V	PARTICIPANT	\N	PRESENT	0
635516	634653	19723Y	PARTICIPANT	\N	PRESENT	0
635517	634653	19691J	PARTICIPANT	\N	PRESENT	0
635518	634653	20024T	PARTICIPANT	\N	PRESENT	0
635519	634653	18083K	PARTICIPANT	\N	PRESENT	0
635520	634653	10006L	PARTICIPANT	\N	PRESENT	0
635521	634653	19663E	PARTICIPANT	\N	PRESENT	0
635522	634653	19565D	PARTICIPANT	\N	PRESENT	0
635428	634652	19719D	PARTICIPANT	\N	PRESENT	0
635429	634652	10006L	PARTICIPANT	\N	PRESENT	0
635523	634653	20090E	PARTICIPANT	\N	PRESENT	0
635524	634653	14033T	PARTICIPANT	\N	PRESENT	0
635525	634653	20076G	PARTICIPANT	\N	PRESENT	0
635526	634653	11097X	PARTICIPANT	\N	PRESENT	0
635527	634653	18193Q	PARTICIPANT	\N	PRESENT	0
635528	634653	04092N	PARTICIPANT	\N	PRESENT	0
635529	634653	14105F	PARTICIPANT	\N	PRESENT	0
635530	634653	14217N	PARTICIPANT	\N	PRESENT	0
635531	634653	20140W	PARTICIPANT	\N	PRESENT	0
635532	634653	19760E	PARTICIPANT	\N	PRESENT	0
635533	634653	19703U	PARTICIPANT	\N	PRESENT	0
635534	634653	14147R	PARTICIPANT	\N	PRESENT	0
635535	634653	19679N	PARTICIPANT	\N	PRESENT	0
635536	634653	20032T	PARTICIPANT	\N	PRESENT	0
635537	634653	20070A	PARTICIPANT	\N	PRESENT	0
635538	634653	19657G	PARTICIPANT	\N	PRESENT	0
635539	634653	19383Y	PARTICIPANT	\N	PRESENT	0
635540	634653	07029T	PARTICIPANT	\N	PRESENT	0
635544	634653	19347U	PARTICIPANT	\N	PRESENT	0
635542	634653	14026U	PARTICIPANT	\N	PRESENT	0
635543	634653	20110Q	PARTICIPANT	\N	PRESENT	0
635545	634653	19798U	PARTICIPANT	\N	PRESENT	0
635847	635844	10006L	PARTICIPANT	\N	PRESENT	0
635848	635844	20148F	PARTICIPANT	\N	PRESENT	0
635849	635844	19723Y	PARTICIPANT	\N	PRESENT	0
635508	634653	99004R	PARTICIPANT	\N	PRESENT	0
635509	634653	11031D	PARTICIPANT	\N	PRESENT	0
635850	635844	19703U	PARTICIPANT	\N	PRESENT	0
635851	635844	20130U	PARTICIPANT	\N	PRESENT	1
636671	634366	20132W	PARTICIPANT	\N	PRESENT	0
636672	634366	19533U	PRESIDENT	0	PRESENT	0
636673	634366	20042V	PARTICIPANT	\N	PRESENT	0
636674	634366	14207L	PARTICIPANT	\N	PRESENT	0
636675	634366	20124W	PARTICIPANT	\N	PRESENT	0
636676	634366	20096L	PARTICIPANT	\N	EXCUSE	0
636681	634655	14121F	PARTICIPANT	\N	PRESENT	0
636683	634655	14237S	PARTICIPANT	\N	PRESENT	0
636684	634655	19631V	PARTICIPANT	\N	PRESENT	0
636685	634655	05008E	PARTICIPANT	\N	PRESENT	0
636686	634655	19760E	PARTICIPANT	\N	PRESENT	0
636687	634655	20090E	PARTICIPANT	\N	PRESENT	0
636688	634655	19467C	PARTICIPANT	\N	PRESENT	0
636689	634655	11064N	PARTICIPANT	\N	PRESENT	0
636690	634655	11097X	PARTICIPANT	\N	PRESENT	0
636691	634655	19441R	PARTICIPANT	\N	PRESENT	0
636692	634655	20130U	PARTICIPANT	\N	PRESENT	0
636693	634655	20180F	PARTICIPANT	\N	PRESENT	0
636694	634655	19954N	PARTICIPANT	\N	PRESENT	0
636695	634655	19657G	PARTICIPANT	\N	PRESENT	0
636696	634655	04057K	PARTICIPANT	\N	PRESENT	0
636697	634655	19697Q	PARTICIPANT	\N	PRESENT	0
636698	634655	19399H	PARTICIPANT	\N	PRESENT	0
636699	634655	20248J	PARTICIPANT	\N	PRESENT	0
636729	634655	19758L	PARTICIPANT	\N	PRESENT	0
636701	634655	14033T	PARTICIPANT	\N	PRESENT	0
636702	634655	19333N	PARTICIPANT	\N	PRESENT	0
636703	634655	20126Y	PARTICIPANT	\N	PRESENT	0
636704	634655	14001X	PARTICIPANT	\N	PRESENT	0
636705	634655	20082E	PARTICIPANT	\N	PRESENT	0
636706	634655	14281W	PARTICIPANT	\N	PRESENT	0
636728	634655	11031D	PARTICIPANT	\N	PRESENT	0
636730	634655	19447X	PARTICIPANT	\N	PRESENT	0
636731	634655	20080C	PARTICIPANT	\N	PRESENT	0
636797	634656	01043Q	PARTICIPANT	\N	PRESENT	0
636798	634656	14021P	PARTICIPANT	\N	PRESENT	0
636803	634656	10006L	PARTICIPANT	\N	PRESENT	0
636801	634656	19629C	PARTICIPANT	\N	PRESENT	0
636802	634656	08045X	PARTICIPANT	\N	PRESENT	0
636804	634656	20248J	PARTICIPANT	\N	PRESENT	0
636805	634656	14042U	PARTICIPANT	\N	PRESENT	0
636806	634656	19820Y	PARTICIPANT	\N	PRESENT	0
636807	634656	19715Y	PARTICIPANT	\N	PRESENT	0
636808	634656	14001X	PARTICIPANT	\N	PRESENT	0
636809	634656	14281W	PARTICIPANT	\N	PRESENT	0
636810	634656	11067R	PARTICIPANT	\N	PRESENT	0
636811	634656	14097Y	PARTICIPANT	\N	PRESENT	0
636812	634656	19631V	PARTICIPANT	\N	PRESENT	0
636813	634656	20080C	PARTICIPANT	\N	PRESENT	0
636814	634656	14151M	PARTICIPANT	\N	PRESENT	0
636815	634656	17965H	PARTICIPANT	\N	PRESENT	0
636816	634656	19333N	PARTICIPANT	\N	PRESENT	0
636817	634656	19503N	PARTICIPANT	\N	PRESENT	0
636818	634656	14121F	PARTICIPANT	\N	PRESENT	0
636819	634656	19413M	PARTICIPANT	\N	PRESENT	0
636820	634656	20082E	PARTICIPANT	\N	PRESENT	0
636821	634656	14257W	PARTICIPANT	\N	PRESENT	0
636822	634656	11031D	PARTICIPANT	\N	PRESENT	0
636823	634656	19760E	PARTICIPANT	\N	PRESENT	0
636824	634656	19758L	PARTICIPANT	\N	PRESENT	0
636825	634656	11077T	PARTICIPANT	\N	PRESENT	0
636826	634656	20130U	PARTICIPANT	\N	PRESENT	0
636827	634656	04057K	PARTICIPANT	\N	PRESENT	0
636828	634656	20090E	PARTICIPANT	\N	PRESENT	0
636829	634656	14187A	PARTICIPANT	\N	PRESENT	0
636830	634656	17779H	PARTICIPANT	\N	PRESENT	0
636831	634656	19551W	PARTICIPANT	\N	PRESENT	0
641333	641328	14147R	PARTICIPANT	\N	PRESENT	1
641339	641338	04008A	PARTICIPANT	\N	PRESENT	0
641340	641338	19543W	PARTICIPANT	\N	PRESENT	0
641341	641338	14151M	PARTICIPANT	\N	PRESENT	0
641342	641338	14147R	PARTICIPANT	\N	PRESENT	1
641344	641343	04008A	PARTICIPANT	\N	PRESENT	0
641345	641343	19543W	PARTICIPANT	\N	PRESENT	0
641346	641343	14151M	PARTICIPANT	\N	PRESENT	0
641349	641348	19543W	PARTICIPANT	\N	PRESENT	0
641350	641348	14151M	PARTICIPANT	\N	PRESENT	0
641351	641348	14147R	PARTICIPANT	\N	PRESENT	1
641358	641138	11067R	PARTICIPANT	\N	PRESENT	1
641359	641138	19415P	PARTICIPANT	\N	PRESENT	1
641361	641139	11067R	PARTICIPANT	\N	PRESENT	0
641362	641139	19415P	PARTICIPANT	\N	PRESENT	0
641363	641139	19723Y	PARTICIPANT	\N	PRESENT	1
641364	641140	19415P	PARTICIPANT	\N	PRESENT	0
641365	641140	11067R	PARTICIPANT	\N	PRESENT	0
641366	641140	19723Y	PARTICIPANT	\N	PRESENT	1
641367	641140	20090E	PARTICIPANT	\N	PRESENT	1
641368	641140	14213J	PARTICIPANT	\N	PRESENT	1
641371	641141	20130U	PARTICIPANT	\N	PRESENT	1
641372	641141	11067R	PARTICIPANT	\N	PRESENT	0
641373	641141	19691J	PARTICIPANT	\N	PRESENT	1
641374	641141	19415P	PARTICIPANT	\N	PRESENT	0
641375	641357	19553Y	PARTICIPANT	\N	PRESENT	0
641376	641357	20298U	PARTICIPANT	\N	PRESENT	0
641377	641357	11067R	PARTICIPANT	\N	PRESENT	0
641378	641357	19415P	PARTICIPANT	\N	PRESENT	0
641379	641357	20130U	PARTICIPANT	\N	PRESENT	1
641380	641357	19703U	PARTICIPANT	\N	PRESENT	1
641381	641357	11031D	PARTICIPANT	\N	PRESENT	1
641382	641357	14213J	PARTICIPANT	\N	PRESENT	1
641387	641354	14213J	PARTICIPANT	\N	PRESENT	0
641388	641354	19760E	PARTICIPANT	\N	PRESENT	0
641389	641354	18193Q	PARTICIPANT	\N	PRESENT	0
641390	641354	11097X	PARTICIPANT	\N	PRESENT	0
641391	641356	19760E	PARTICIPANT	\N	PRESENT	0
641392	641356	18193Q	PARTICIPANT	\N	PRESENT	0
641393	641356	11097X	PARTICIPANT	\N	PRESENT	0
641394	641355	18193Q	PARTICIPANT	\N	PRESENT	0
641395	641355	11097X	PARTICIPANT	\N	PRESENT	0
641397	641396	18193Q	PARTICIPANT	\N	PRESENT	0
641398	641396	11097X	PARTICIPANT	\N	PRESENT	0
641399	641385	18193Q	PARTICIPANT	\N	PRESENT	0
641400	641385	11097X	PARTICIPANT	\N	PRESENT	0
641401	641385	19760E	PARTICIPANT	\N	PRESENT	0
641402	641385	14213J	PARTICIPANT	\N	PRESENT	0
641411	641410	01048V	PARTICIPANT	\N	PRESENT	0
641419	640959	19643A	PARTICIPANT	\N	EXCUSE	0
641431	641429	19593H	PARTICIPANT	\N	PRESENT	0
641432	641429	20026V	PARTICIPANT	\N	PRESENT	0
641433	641430	20026V	PARTICIPANT	\N	PRESENT	0
641434	641430	19593H	PARTICIPANT	\N	PRESENT	0
641435	641430	20124W	PARTICIPANT	\N	PRESENT	0
641436	641428	20026V	PARTICIPANT	\N	PRESENT	0
641437	641428	14109K	PARTICIPANT	\N	PRESENT	0
641438	641428	19593H	PARTICIPANT	\N	PRESENT	0
641439	641428	20124W	PARTICIPANT	\N	PRESENT	0
641443	641440	20026V	PARTICIPANT	\N	PRESENT	0
641444	641440	19593H	PARTICIPANT	\N	PRESENT	0
641445	641440	20056C	PARTICIPANT	\N	PRESENT	1
641460	641440	20124W	PARTICIPANT	\N	PRESENT	0
641461	641441	20026V	PARTICIPANT	\N	PRESENT	0
641462	641441	19593H	PARTICIPANT	\N	PRESENT	0
641463	641441	20124W	PARTICIPANT	\N	PRESENT	0
641464	641442	20026V	PARTICIPANT	\N	PRESENT	0
641465	641442	19593H	PARTICIPANT	\N	PRESENT	0
641466	641442	20124W	PARTICIPANT	\N	PRESENT	0
641472	641386	19553Y	PARTICIPANT	\N	PRESENT	1
641473	641386	11067R	PARTICIPANT	\N	PRESENT	0
641469	641386	14213J	PARTICIPANT	\N	PRESENT	1
641475	641447	19415P	PARTICIPANT	\N	PRESENT	0
641471	641386	14223L	PARTICIPANT	\N	PRESENT	1
641474	641386	19415P	PARTICIPANT	\N	PRESENT	0
641476	641447	11067R	PARTICIPANT	\N	PRESENT	0
641477	641447	19553Y	PARTICIPANT	\N	PRESENT	1
641478	641446	19415P	PARTICIPANT	\N	PRESENT	0
641479	641446	11067R	PARTICIPANT	\N	PRESENT	0
641480	641446	19723Y	PARTICIPANT	\N	PRESENT	1
641495	641484	19760E	PARTICIPANT	\N	PRESENT	0
641496	641484	18193Q	PARTICIPANT	\N	PRESENT	0
641497	641484	14213J	PARTICIPANT	\N	PRESENT	0
641498	641484	11097X	PARTICIPANT	\N	PRESENT	0
641499	641483	20130U	PARTICIPANT	\N	PRESENT	1
641500	641483	19723Y	PARTICIPANT	\N	PRESENT	1
641501	641483	19415P	PARTICIPANT	\N	PRESENT	0
641502	641483	11067R	PARTICIPANT	\N	PRESENT	0
641504	641503	11083R	PARTICIPANT	\N	PRESENT	1
641505	641503	11027H	PARTICIPANT	\N	PRESENT	1
641506	641503	11066Q	PARTICIPANT	\N	PRESENT	1
641511	641510	19954N	PARTICIPANT	\N	PRESENT	0
641512	641510	95063L	PARTICIPANT	\N	PRESENT	0
641513	641510	19703U	PARTICIPANT	\N	PRESENT	0
641515	641514	19954N	PARTICIPANT	\N	PRESENT	0
641516	641514	19703U	PARTICIPANT	\N	PRESENT	0
641518	641517	19954N	PARTICIPANT	\N	PRESENT	0
641519	641517	95063L	PARTICIPANT	\N	PRESENT	0
641520	641517	19703U	PARTICIPANT	\N	PRESENT	0
641521	641517	11056N	PARTICIPANT	\N	PRESENT	0
641523	641522	11056N	PARTICIPANT	\N	PRESENT	0
641524	641522	19954N	PARTICIPANT	\N	PRESENT	0
641525	641492	19415P	PARTICIPANT	\N	PRESENT	0
641526	641492	20130U	PARTICIPANT	\N	PRESENT	1
641527	641492	11067R	PARTICIPANT	\N	PRESENT	0
641625	641624	19593H	PARTICIPANT	\N	PRESENT	0
641626	641624	20026V	PARTICIPANT	\N	PRESENT	1
641673	641672	19629C	PARTICIPANT	\N	PRESENT	0
641674	641672	04045F	PARTICIPANT	\N	PRESENT	0
641675	641672	14329V	PARTICIPANT	\N	PRESENT	0
641676	641672	19549D	PARTICIPANT	\N	PRESENT	0
641677	641672	20106U	PARTICIPANT	\N	PRESENT	0
641680	641678	04070G	PARTICIPANT	\N	PRESENT	0
641681	641678	14237S	PARTICIPANT	\N	PRESENT	0
641682	641678	11083R	PARTICIPANT	\N	PRESENT	0
641683	641679	04070G	PARTICIPANT	\N	PRESENT	0
641684	641679	14237S	PARTICIPANT	\N	PRESENT	0
641686	641685	19479G	PARTICIPANT	\N	PRESENT	0
641688	641687	19479G	PARTICIPANT	\N	PRESENT	0
641690	641689	14225N	PARTICIPANT	\N	PRESENT	0
641691	641689	01057W	PARTICIPANT	\N	PRESENT	0
641718	641717	19599P	PARTICIPANT	\N	PRESENT	0
641720	641719	19695N	PARTICIPANT	\N	PRESENT	0
641721	641719	01025N	PARTICIPANT	\N	PRESENT	0
641723	641722	19695N	PARTICIPANT	\N	PRESENT	0
641724	641722	01025N	PARTICIPANT	\N	PRESENT	0
641725	641722	19575F	PARTICIPANT	\N	PRESENT	0
641727	641726	19575F	PARTICIPANT	\N	PRESENT	0
641728	641726	18083K	PARTICIPANT	\N	PRESENT	1
641732	641731	11083R	PARTICIPANT	\N	PRESENT	0
641730	641726	14151M	PARTICIPANT	\N	PRESENT	1
641733	641731	14133K	PARTICIPANT	\N	PRESENT	0
641767	641766	20116W	PARTICIPANT	\N	PRESENT	0
641768	641766	11080N	PARTICIPANT	\N	PRESENT	0
641769	641766	19711U	PARTICIPANT	\N	PRESENT	0
641770	641766	11074Q	PARTICIPANT	\N	PRESENT	0
641771	641766	14121F	PARTICIPANT	\N	PRESENT	0
641772	641766	19687N	PARTICIPANT	\N	PRESENT	0
641773	641766	05012A	PARTICIPANT	\N	PRESENT	0
641774	641766	19335Q	PARTICIPANT	\N	PRESENT	0
641775	641766	20042V	PARTICIPANT	\N	PRESENT	0
641776	641644	19651A	PARTICIPANT	\N	PRESENT	1
641777	641644	14030Q	PARTICIPANT	\N	PRESENT	0
641778	641644	19643A	PARTICIPANT	\N	PRESENT	1
641779	641644	20152B	PARTICIPANT	\N	PRESENT	1
641780	641644	19621T	PARTICIPANT	\N	PRESENT	0
641781	641644	19758L	PARTICIPANT	\N	EXCUSE	0
641782	641644	19057M	PARTICIPANT	\N	PRESENT	1
641783	641644	20264J	PARTICIPANT	\N	PRESENT	0
641784	641644	20132W	PARTICIPANT	\N	PRESENT	0
641785	641644	20180F	PARTICIPANT	\N	PRESENT	1
641786	641644	20048C	PARTICIPANT	\N	PRESENT	0
641787	641644	19399H	PARTICIPANT	\N	PRESENT	0
641788	641644	20056C	PARTICIPANT	\N	PRESENT	0
632948	631667	19533U	PARTICIPANT	\N	PRESENT	0
632949	631667	14207L	PARTICIPANT	\N	PRESENT	0
632950	631667	20124W	PARTICIPANT	\N	PRESENT	0
637283	637280	01028R	PARTICIPANT	\N	PRESENT	0
637509	637507	17023S	PARTICIPANT	\N	PRESENT	0
637510	637507	14059S	PARTICIPANT	\N	PRESENT	0
637511	637507	20148F	PARTICIPANT	\N	PRESENT	0
637512	637507	20146D	PARTICIPANT	\N	PRESENT	0
637622	637221	20144B	PARTICIPANT	\N	EXCUSE	0
637623	637221	20018V	PARTICIPANT	\N	EXCUSE	0
637624	637221	01028R	PARTICIPANT	\N	EXCUSE	0
637625	637221	19399H	PARTICIPANT	\N	EXCUSE	0
637684	626899	14173T	PARTICIPANT	\N	EXCUSE	0
637688	626899	14071N	PARTICIPANT	\N	EXCUSE	0
637770	637175	08018U	PARTICIPANT	\N	PRESENT	0
637771	637175	14097Y	PARTICIPANT	\N	PRESENT	0
637841	637840	20024T	PARTICIPANT	\N	PRESENT	0
637843	637840	14255U	PARTICIPANT	\N	PRESENT	0
637845	637840	11101A	PARTICIPANT	\N	PRESENT	0
637847	637840	20052X	PARTICIPANT	\N	PRESENT	0
637848	637840	20018V	PARTICIPANT	\N	PRESENT	0
637850	637840	19703U	PARTICIPANT	\N	PRESENT	0
637862	637861	10006L	PARTICIPANT	\N	PRESENT	0
637864	637863	10006L	PARTICIPANT	\N	PRESENT	0
637865	637863	19691J	PARTICIPANT	\N	PRESENT	0
639917	639759	11110B	PARTICIPANT	\N	PRESENT	0
639918	639759	19585H	PARTICIPANT	\N	PRESENT	0
639919	639759	19709B	PARTICIPANT	\N	PRESENT	0
639920	639759	19399H	PARTICIPANT	\N	PRESENT	0
639921	639759	95041E	PARTICIPANT	\N	PRESENT	0
639922	639759	20068G	PARTICIPANT	\N	PRESENT	0
639923	639759	20024T	PARTICIPANT	\N	PRESENT	0
639924	639759	20252E	PARTICIPANT	\N	PRESENT	0
639925	639759	11090Q	PARTICIPANT	\N	PRESENT	0
639926	639759	14331P	PARTICIPANT	\N	PRESENT	0
640014	640007	14217N	PARTICIPANT	\N	PRESENT	0
640015	640007	20248J	PARTICIPANT	\N	PRESENT	0
640016	640007	11067R	PARTICIPANT	\N	PRESENT	0
640017	640008	14217N	PARTICIPANT	\N	PRESENT	0
640018	640008	20248J	PARTICIPANT	\N	PRESENT	0
637281	637280	05008E	PARTICIPANT	\N	PRESENT	0
637282	637280	11053K	PARTICIPANT	\N	PRESENT	0
640019	640008	11067R	PARTICIPANT	\N	PRESENT	0
640020	640009	14217N	PARTICIPANT	\N	PRESENT	0
640021	640009	11067R	PARTICIPANT	\N	PRESENT	0
640022	640009	11097X	PARTICIPANT	\N	PRESENT	0
640023	640010	14217N	PARTICIPANT	\N	PRESENT	0
640024	640010	11067R	PARTICIPANT	\N	PRESENT	0
640025	640011	14217N	PARTICIPANT	\N	PRESENT	0
640026	640011	20248J	PARTICIPANT	\N	PRESENT	0
640056	640055	14331P	PARTICIPANT	\N	PRESENT	0
640057	640055	14073Q	PARTICIPANT	\N	PRESENT	0
641646	641645	11090Q	PARTICIPANT	\N	PRESENT	0
641647	641645	20286Q	PARTICIPANT	\N	PRESENT	0
641648	641645	14257W	PARTICIPANT	\N	PRESENT	0
641649	641645	19575F	PARTICIPANT	\N	PRESENT	0
641819	641814	19760E	PARTICIPANT	\N	PRESENT	0
641820	641814	11097X	PARTICIPANT	\N	PRESENT	0
641821	641815	19760E	PARTICIPANT	\N	PRESENT	0
641822	641815	18193Q	PARTICIPANT	\N	PRESENT	0
641823	641815	11097X	PARTICIPANT	\N	PRESENT	0
641824	641816	19760E	PARTICIPANT	\N	PRESENT	0
641825	641816	18193Q	PARTICIPANT	\N	PRESENT	0
641826	641816	11097X	PARTICIPANT	\N	PRESENT	0
641827	641817	19760E	PARTICIPANT	\N	PRESENT	0
641828	641817	18193Q	PARTICIPANT	\N	PRESENT	0
641829	641817	11097X	PARTICIPANT	\N	PRESENT	0
641830	641817	14217N	PARTICIPANT	\N	PRESENT	0
641832	641831	19725B	PARTICIPANT	\N	PRESENT	0
641833	641831	14147R	PARTICIPANT	\N	PRESENT	0
641834	641831	20114U	PARTICIPANT	\N	PRESENT	0
641836	641835	11072N	PARTICIPANT	\N	PRESENT	0
641837	640857	20024T	PARTICIPANT	\N	PRESENT	0
641838	640857	14030Q	PARTICIPANT	\N	PRESENT	0
641839	640857	20138D	PARTICIPANT	\N	EXCUSE	0
641840	640857	17737W	PARTICIPANT	\N	EXCUSE	0
641841	640857	20080C	PARTICIPANT	\N	EXCUSE	0
641842	640857	11031D	PARTICIPANT	\N	EXCUSE	0
641843	640857	19693L	PARTICIPANT	\N	EXCUSE	0
641844	640857	19715Y	PARTICIPANT	\N	PRESENT	1
641845	640857	14109K	PARTICIPANT	\N	PRESENT	0
641846	640857	20118Y	PARTICIPANT	\N	EXCUSE	0
641847	640857	20098N	PARTICIPANT	\N	EXCUSE	0
641848	640857	19749K	PARTICIPANT	\N	PRESENT	1
641849	640857	11045K	PARTICIPANT	\N	PRESENT	0
641850	640857	20066E	PARTICIPANT	\N	PRESENT	1
641857	641856	14331P	PARTICIPANT	\N	PRESENT	0
641858	641856	20100N	PARTICIPANT	\N	PRESENT	0
642008	641997	11083R	PARTICIPANT	\N	PRESENT	0
642009	641997	04070G	PARTICIPANT	\N	PRESENT	0
642010	641997	14237S	PARTICIPANT	\N	PRESENT	0
642013	642012	20034V	PARTICIPANT	\N	PRESENT	1
642014	642012	19717B	PARTICIPANT	\N	EXCUSE	0
642015	642012	14083S	PRESIDENT	0	PRESENT	1
642016	642012	20150Y	PARTICIPANT	\N	PRESENT	1
642017	642012	20148F	PARTICIPANT	\N	PRESENT	1
642018	642012	20102Q	PARTICIPANT	\N	PRESENT	1
642019	642012	19715Y	PARTICIPANT	\N	PRESENT	1
642020	642012	14031R	PARTICIPANT	\N	PRESENT	1
642021	642012	19631V	PARTICIPANT	\N	PRESENT	1
642974	642973	11040E	PARTICIPANT	\N	PRESENT	1
642975	642973	01057W	PARTICIPANT	\N	PRESENT	1
642976	642973	11048N	PARTICIPANT	\N	PRESENT	0
642977	642973	20126Y	PARTICIPANT	\N	PRESENT	1
642978	642973	19711U	PARTICIPANT	\N	PRESENT	0
642979	642973	14225N	PARTICIPANT	\N	PRESENT	0
642980	642973	19479G	PARTICIPANT	\N	PRESENT	1
642982	642981	19741B	PARTICIPANT	\N	PRESENT	0
642987	642986	19545Y	PARTICIPANT	\N	PRESENT	0
642988	642986	19689Q	PARTICIPANT	\N	PRESENT	0
642990	642989	19545Y	PARTICIPANT	\N	PRESENT	0
642991	642989	19689Q	PARTICIPANT	\N	PRESENT	0
642993	642992	19711U	PARTICIPANT	\N	PRESENT	0
643992	643989	14259Y	PARTICIPANT	\N	PRESENT	0
643993	643989	11056N	PARTICIPANT	\N	PRESENT	0
643994	643989	20068G	PARTICIPANT	\N	PRESENT	0
643995	643989	20132W	PARTICIPANT	\N	PRESENT	0
643997	643989	95063L	PARTICIPANT	\N	PRESENT	0
643998	643989	11097X	PARTICIPANT	\N	PRESENT	0
643999	643989	20042V	PARTICIPANT	\N	EXCUSE	0
644000	643989	14038Y	PARTICIPANT	\N	EXCUSE	0
644001	643989	19399H	PARTICIPANT	\N	EXCUSE	0
644002	643989	20050V	PARTICIPANT	\N	EXCUSE	0
644003	643989	20044X	PARTICIPANT	\N	EXCUSE	0
644022	643989	19479G	PARTICIPANT	\N	PRESENT	0
644370	644005	19719D	PARTICIPANT	\N	PRESENT	1
644574	644571	20112S	PARTICIPANT	\N	PRESENT	1
644372	644006	20074E	PARTICIPANT	\N	PRESENT	1
644373	644006	19719D	PARTICIPANT	\N	PRESENT	1
644573	644571	11109J	PARTICIPANT	\N	EXCUSE	0
644575	644571	20134Y	PARTICIPANT	\N	PRESENT	0
644576	644571	20052X	PARTICIPANT	\N	PRESENT	0
644577	644571	08012N	PARTICIPANT	\N	PRESENT	0
644578	644571	19611R	PRESIDENT	0	PRESENT	0
644579	644571	14073Q	PARTICIPANT	\N	PRESENT	0
644580	644571	14229S	PARTICIPANT	\N	PRESENT	0
644581	644571	19573D	PARTICIPANT	\N	PRESENT	0
644582	644571	20084G	PARTICIPANT	\N	PRESENT	1
644583	644571	19593H	PARTICIPANT	\N	EXCUSE	0
644584	644571	20026V	PARTICIPANT	\N	EXCUSE	0
644585	644571	20124W	PARTICIPANT	\N	EXCUSE	0
644586	644571	04059M	PARTICIPANT	\N	PRESENT	0
644587	644571	19533U	PARTICIPANT	\N	PRESENT	1
644588	644571	11043H	PARTICIPANT	\N	PRESENT	1
644589	644571	20138D	PARTICIPANT	\N	PRESENT	1
644591	644571	14123H	PARTICIPANT	\N	PRESENT	1
644592	644571	19643A	PARTICIPANT	\N	PRESENT	1
644593	644571	20024T	PARTICIPANT	\N	PRESENT	0
644594	644590	19593H	PARTICIPANT	\N	PRESENT	0
644595	644590	20026V	PARTICIPANT	\N	PRESENT	1
644596	644590	20124W	PARTICIPANT	\N	PRESENT	1
644597	644571	05008E	PARTICIPANT	\N	PRESENT	0
644598	644571	04047H	PARTICIPANT	\N	PRESENT	0
644599	644571	14151M	PARTICIPANT	\N	PRESENT	0
644600	644571	19649G	PARTICIPANT	\N	PRESENT	0
644601	644571	10015M	PARTICIPANT	\N	PRESENT	0
644602	644571	20022R	PARTICIPANT	\N	PRESENT	1
644603	644571	14179A	PARTICIPANT	\N	PRESENT	1
644604	644571	19489J	PARTICIPANT	\N	PRESENT	1
644605	644571	14147R	PARTICIPANT	\N	PRESENT	1
644614	643472	18193Q	PARTICIPANT	\N	PRESENT	0
649188	649187	20076G	PARTICIPANT	\N	PRESENT	0
649189	649187	19826F	PARTICIPANT	\N	PRESENT	0
649190	649187	20054A	PARTICIPANT	\N	PRESENT	0
649192	649191	19467C	PARTICIPANT	\N	PRESENT	0
649193	649191	20090E	PARTICIPANT	\N	PRESENT	0
649194	649191	19667J	PARTICIPANT	\N	PRESENT	0
649195	649191	18083K	PARTICIPANT	\N	PRESENT	0
649196	649191	19762G	PARTICIPANT	\N	PRESENT	0
649197	649191	11033F	PARTICIPANT	\N	PRESENT	0
649198	649191	20062A	PARTICIPANT	\N	PRESENT	0
649199	649191	20082E	PARTICIPANT	\N	PRESENT	0
649200	649191	19713W	PARTICIPANT	\N	PRESENT	0
649201	649191	17023S	PARTICIPANT	\N	PRESENT	0
649202	649191	20022R	PARTICIPANT	\N	PRESENT	0
649203	649191	20066E	PARTICIPANT	\N	PRESENT	0
649204	649191	11097X	PARTICIPANT	\N	PRESENT	0
649205	649191	20024T	PARTICIPANT	\N	PRESENT	0
651500	645107	14189C	PARTICIPANT	\N	EXCUSE	0
651501	645107	20024T	PARTICIPANT	\N	PRESENT	0
651502	645107	14030Q	PRESIDENT	0	PRESENT	0
651503	645107	20138D	PARTICIPANT	\N	EXCUSE	0
651504	645107	17737W	PARTICIPANT	\N	EXCUSE	0
651505	645107	20080C	PARTICIPANT	\N	EXCUSE	0
651506	645107	11031D	PARTICIPANT	\N	EXCUSE	0
651507	645107	19681G	PARTICIPANT	\N	EXCUSE	0
651508	645107	19693L	PARTICIPANT	\N	PRESENT	0
651509	645107	20140W	PARTICIPANT	\N	EXCUSE	0
651510	645107	19599P	PARTICIPANT	\N	PRESENT	0
651511	645107	20066E	PARTICIPANT	\N	EXCUSE	0
651512	645107	19715Y	PARTICIPANT	\N	PRESENT	0
651513	645107	20056C	PARTICIPANT	\N	EXCUSE	0
651514	645107	07029T	PARTICIPANT	\N	EXCUSE	0
651515	645107	14109K	PARTICIPANT	\N	EXCUSE	0
651516	645107	19866P	PARTICIPANT	\N	PRESENT	0
651517	645107	20118Y	PARTICIPANT	\N	EXCUSE	0
651518	645107	20130U	PARTICIPANT	\N	EXCUSE	0
651519	645107	19798U	PARTICIPANT	\N	PRESENT	1
651520	645107	11045K	PARTICIPANT	\N	EXCUSE	0
651521	645107	20098N	PARTICIPANT	\N	EXCUSE	0
651522	645107	19527W	PARTICIPANT	\N	EXCUSE	0
651523	645107	20046A	PARTICIPANT	\N	PRESENT	0
651524	645107	19749K	PARTICIPANT	\N	PRESENT	0
651529	651528	86034E	PARTICIPANT	\N	PRESENT	0
651530	651528	99004R	PARTICIPANT	\N	PRESENT	0
651531	651528	95063L	PARTICIPANT	\N	PRESENT	0
651532	651528	12041X	PARTICIPANT	\N	PRESENT	0
651533	651528	14026U	PARTICIPANT	\N	PRESENT	0
651534	651528	11070L	PARTICIPANT	\N	PRESENT	0
651535	651528	01028R	PARTICIPANT	\N	PRESENT	0
651536	651528	11053K	PARTICIPANT	\N	PRESENT	0
651537	651528	11033F	PARTICIPANT	\N	PRESENT	0
651538	651528	14357A	PARTICIPANT	\N	PRESENT	0
651539	651528	01025N	PARTICIPANT	\N	PRESENT	0
651540	651528	19599P	PARTICIPANT	\N	PRESENT	0
651541	651528	14033T	PARTICIPANT	\N	PRESENT	0
651542	651528	14123H	PARTICIPANT	\N	PRESENT	0
651543	651528	14179A	PARTICIPANT	\N	PRESENT	0
651544	651528	19715Y	PARTICIPANT	\N	PRESENT	0
651545	651528	14147R	PARTICIPANT	\N	PRESENT	0
651546	651528	19301E	PARTICIPANT	\N	PRESENT	0
651547	651528	19413M	PARTICIPANT	\N	PRESENT	0
651549	651548	86034E	PARTICIPANT	\N	PRESENT	0
651550	651548	04085P	PARTICIPANT	\N	PRESENT	0
651551	651548	04047H	PARTICIPANT	\N	PRESENT	0
651552	651548	11070L	PARTICIPANT	\N	PRESENT	0
651553	651548	10006L	PARTICIPANT	\N	PRESENT	0
651554	651548	14042U	PARTICIPANT	\N	PRESENT	0
651555	651548	19347U	PARTICIPANT	\N	PRESENT	0
651556	651548	14026U	PARTICIPANT	\N	PRESENT	0
651557	651548	11048N	PARTICIPANT	\N	PRESENT	0
651558	651548	14021P	PARTICIPANT	\N	PRESENT	0
651559	651548	99004R	PARTICIPANT	\N	PRESENT	0
651560	651548	12041X	PARTICIPANT	\N	PRESENT	0
651561	651548	01043Q	PARTICIPANT	\N	PRESENT	0
651562	651548	14219Q	PARTICIPANT	\N	PRESENT	0
651563	651548	14251Q	PARTICIPANT	\N	PRESENT	0
651564	651548	08061X	PARTICIPANT	\N	PRESENT	0
651565	651548	14193X	PARTICIPANT	\N	PRESENT	0
651566	651548	11090Q	PARTICIPANT	\N	PRESENT	0
651567	651548	14331P	PARTICIPANT	\N	PRESENT	0
651568	651548	14225N	PARTICIPANT	\N	PRESENT	0
651569	651548	11012A	PARTICIPANT	\N	PRESENT	0
651570	651548	04033B	PARTICIPANT	\N	PRESENT	0
651571	651548	11045K	PARTICIPANT	\N	PRESENT	0
651572	651548	11043H	PARTICIPANT	\N	PRESENT	0
651573	651548	01028R	PARTICIPANT	\N	PRESENT	0
651577	649061	20094J	PARTICIPANT	\N	EXCUSE	0
651578	649061	14189C	PARTICIPANT	\N	EXCUSE	0
651579	649061	14357A	PARTICIPANT	\N	EXCUSE	0
651580	649061	12041X	PARTICIPANT	\N	EXCUSE	0
651581	649061	04057K	PARTICIPANT	\N	EXCUSE	0
653568	653089	11053K	PARTICIPANT	\N	PRESENT	1
653569	653089	19741B	PARTICIPANT	\N	PRESENT	1
654268	652906	14275Y	PARTICIPANT	\N	PRESENT	0
654269	652906	11090Q	PARTICIPANT	\N	PRESENT	0
654270	652906	19369B	PARTICIPANT	\N	PRESENT	0
654271	652906	04035D	PARTICIPANT	\N	PRESENT	0
654272	652906	04071H	PARTICIPANT	\N	PRESENT	0
654273	652906	19599P	PARTICIPANT	\N	PRESENT	0
654274	652906	19697Q	PARTICIPANT	\N	PRESENT	0
654275	652906	20130U	PARTICIPANT	\N	PRESENT	0
654276	652906	19629C	PARTICIPANT	\N	PRESENT	0
654277	652906	17779H	PARTICIPANT	\N	PRESENT	0
654278	652906	08034U	PARTICIPANT	\N	PRESENT	0
654279	652906	04085P	PARTICIPANT	\N	PRESENT	0
654280	652906	19593H	PARTICIPANT	\N	PRESENT	0
654281	652906	14259Y	PARTICIPANT	\N	PRESENT	0
654282	652906	17737W	PARTICIPANT	\N	PRESENT	0
654283	652906	18193Q	PARTICIPANT	\N	PRESENT	0
654284	652906	11085T	PARTICIPANT	\N	PRESENT	0
654285	652906	08015R	PARTICIPANT	\N	PRESENT	0
654286	652906	20124W	PARTICIPANT	\N	PRESENT	0
654287	652906	20044X	PARTICIPANT	\N	PRESENT	0
654288	652906	20126Y	PARTICIPANT	\N	PRESENT	0
654289	652906	14109K	PARTICIPANT	\N	PRESENT	0
654290	652906	19585H	PARTICIPANT	\N	PRESENT	0
654291	652906	11026G	PARTICIPANT	\N	PRESENT	0
654292	652906	19441R	PARTICIPANT	\N	PRESENT	0
654293	652906	19729F	PARTICIPANT	\N	PRESENT	0
654294	652906	11048N	PARTICIPANT	\N	PRESENT	0
654295	652906	14225N	PARTICIPANT	\N	PRESENT	0
654296	652906	19715Y	PARTICIPANT	\N	PRESENT	0
654297	652906	20058E	PARTICIPANT	\N	PRESENT	0
654298	652906	20050V	PARTICIPANT	\N	PRESENT	0
654302	652906	14105F	PARTICIPANT	\N	PRESENT	0
654303	652906	20094J	PARTICIPANT	\N	PRESENT	0
654304	652906	20120S	PARTICIPANT	\N	PRESENT	0
654305	652906	14026U	PARTICIPANT	\N	PRESENT	0
654306	652906	20048C	PARTICIPANT	\N	PRESENT	0
654307	652906	20060X	PARTICIPANT	\N	PRESENT	0
654308	652906	14042U	PARTICIPANT	\N	PRESENT	0
654424	652904	14026U	PARTICIPANT	\N	PRESENT	0
654425	652904	20914V	PARTICIPANT	\N	PRESENT	0
654426	652904	11099A	PARTICIPANT	\N	PRESENT	0
654427	652904	20264J	PARTICIPANT	\N	PRESENT	0
654428	652904	20084G	PARTICIPANT	\N	PRESENT	0
654429	652904	19599P	PARTICIPANT	\N	PRESENT	0
654430	652904	20088L	PARTICIPANT	\N	PRESENT	0
654431	652904	19503N	PARTICIPANT	\N	PRESENT	0
654432	652904	11026G	PARTICIPANT	\N	PRESENT	0
654433	652904	20092G	PARTICIPANT	\N	PRESENT	0
654434	652904	20076G	PARTICIPANT	\N	PRESENT	0
654435	652904	20142Y	PARTICIPANT	\N	PRESENT	0
654436	652904	19782L	PARTICIPANT	\N	PRESENT	0
654437	652904	20030R	PARTICIPANT	\N	PRESENT	0
654438	652904	99004R	PARTICIPANT	\N	PRESENT	0
654439	652904	14257W	PARTICIPANT	\N	PRESENT	0
654440	652904	17737W	PARTICIPANT	\N	PRESENT	0
654441	652904	20266L	PARTICIPANT	\N	PRESENT	0
654442	652904	19866P	PARTICIPANT	\N	PRESENT	0
654443	652904	08047A	PARTICIPANT	\N	PRESENT	0
654444	652904	19629C	PARTICIPANT	\N	PRESENT	0
654445	652904	19447X	PARTICIPANT	\N	PRESENT	0
654446	652904	14107H	PARTICIPANT	\N	PRESENT	0
654447	652904	14231L	PARTICIPANT	\N	PRESENT	0
654448	652904	20036X	PARTICIPANT	\N	PRESENT	0
654449	652904	20104S	PARTICIPANT	\N	PRESENT	0
654450	652904	14109K	PARTICIPANT	\N	PRESENT	0
654451	652904	07029T	PARTICIPANT	\N	PRESENT	0
654452	652904	19531S	PARTICIPANT	\N	PRESENT	0
654453	652904	19347U	PARTICIPANT	\N	PRESENT	0
627398	626863	19507S	PARTICIPANT	\N	PRESENT	0
627399	626651	20050V	PARTICIPANT	\N	EXCUSE	0
627400	626863	11012A	PARTICIPANT	\N	PRESENT	0
627401	626863	19631V	PARTICIPANT	\N	PRESENT	0
627406	626863	14331P	PARTICIPANT	\N	PRESENT	0
627407	626863	14026U	PARTICIPANT	\N	PRESENT	0
627408	626863	19347U	PARTICIPANT	\N	PRESENT	0
627409	626863	20082E	PARTICIPANT	\N	PRESENT	0
627410	626863	19747H	PARTICIPANT	\N	PRESENT	0
627412	626863	14030Q	PARTICIPANT	\N	PRESENT	0
627413	626863	20022R	PARTICIPANT	\N	PRESENT	0
628859	628858	14059S	PARTICIPANT	\N	PRESENT	1
628870	628869	19651A	PARTICIPANT	\N	PRESENT	0
628871	628869	19954N	PARTICIPANT	\N	PRESENT	0
628872	628869	20042V	PARTICIPANT	\N	PRESENT	0
628873	628869	20144B	PARTICIPANT	\N	EXCUSE	0
628874	628869	11056N	PARTICIPANT	\N	PRESENT	0
628875	628869	14259Y	PARTICIPANT	\N	PRESENT	0
628876	628869	20068G	PARTICIPANT	\N	PRESENT	0
628877	628869	19399H	PARTICIPANT	\N	EXCUSE	0
628878	628869	19551W	PARTICIPANT	\N	EXCUSE	0
628879	628869	99004R	PARTICIPANT	\N	PRESENT	0
628880	628869	19711U	PARTICIPANT	\N	PRESENT	0
628881	628869	20018V	PARTICIPANT	\N	PRESENT	0
628882	628869	20050V	PARTICIPANT	\N	EXCUSE	0
628883	628869	95063L	PARTICIPANT	\N	PRESENT	0
628884	628869	20044X	PARTICIPANT	\N	EXCUSE	0
628885	628869	11097X	PARTICIPANT	\N	PRESENT	0
628886	628869	19703U	PARTICIPANT	\N	PRESENT	0
628887	628869	01028R	PARTICIPANT	\N	EXCUSE	0
628888	628869	20032T	PARTICIPANT	\N	EXCUSE	0
628889	628869	19747H	PARTICIPANT	\N	EXCUSE	0
629067	629066	19663E	PARTICIPANT	\N	PRESENT	0
629068	629066	20072C	PARTICIPANT	\N	PRESENT	0
629069	629066	19735D	PARTICIPANT	\N	PRESENT	0
629070	629066	19723Y	PARTICIPANT	\N	PRESENT	0
629071	629066	01048V	PARTICIPANT	\N	PRESENT	0
629072	629066	11067R	PARTICIPANT	\N	PRESENT	0
629073	629066	19503N	PARTICIPANT	\N	PRESENT	0
629074	629066	04043D	PARTICIPANT	\N	PRESENT	0
629075	629066	01058X	PARTICIPANT	\N	PRESENT	0
631446	631445	19515S	PRESIDENT	0	PRESENT	0
631447	631445	20092G	PARTICIPANT	\N	PRESENT	0
631448	631445	19251M	PARTICIPANT	\N	PRESENT	0
631449	631445	14031R	PARTICIPANT	\N	PRESENT	0
631450	631445	14083S	PARTICIPANT	\N	PRESENT	0
631451	631445	14030Q	PARTICIPANT	\N	PRESENT	0
631452	631445	19467C	PARTICIPANT	\N	PRESENT	0
631453	631445	19575F	PARTICIPANT	\N	PRESENT	0
631454	631445	20094J	PARTICIPANT	\N	PRESENT	0
631455	631445	20048C	PARTICIPANT	\N	PRESENT	0
631456	631445	19762G	PARTICIPANT	\N	PRESENT	0
631457	631445	14329V	PARTICIPANT	\N	PRESENT	0
631458	631445	19671E	PARTICIPANT	\N	PRESENT	0
631496	631495	20020P	PARTICIPANT	\N	PRESENT	0
631503	631502	20020P	PARTICIPANT	\N	PRESENT	0
631535	631534	20024T	PARTICIPANT	\N	PRESENT	0
631536	631534	19515S	PARTICIPANT	\N	PRESENT	0
631537	631534	19251M	PARTICIPANT	\N	PRESENT	0
631539	631538	20024T	PARTICIPANT	\N	PRESENT	0
631540	631538	19515S	PARTICIPANT	\N	PRESENT	0
631560	629324	19711U	PARTICIPANT	\N	PRESENT	1
631561	629324	07004J	PARTICIPANT	\N	PRESENT	1
631767	631702	04059M	PARTICIPANT	\N	PRESENT	0
631768	631702	19651A	PARTICIPANT	\N	PRESENT	1
631769	631702	19399H	PARTICIPANT	\N	PRESENT	0
631770	631702	19611R	PRESIDENT	0	PRESENT	0
631771	631702	19699S	PARTICIPANT	\N	PRESENT	0
631772	631702	20142Y	PARTICIPANT	\N	PRESENT	0
631773	631702	19705W	PARTICIPANT	\N	PRESENT	1
631774	631702	20026V	PARTICIPANT	\N	PRESENT	1
634807	634806	14331P	PARTICIPANT	\N	PRESENT	0
634808	634806	20252E	PARTICIPANT	\N	PRESENT	0
634810	634809	19667J	PARTICIPANT	\N	PRESENT	0
634811	634809	14255U	PARTICIPANT	\N	PRESENT	0
634812	634809	19701S	PARTICIPANT	\N	PRESENT	0
634813	634809	11027H	PARTICIPANT	\N	PRESENT	0
634814	634809	19693L	PARTICIPANT	\N	PRESENT	0
634815	634809	20064C	PARTICIPANT	\N	PRESENT	0
634816	634809	19549D	PARTICIPANT	\N	PRESENT	0
634818	634817	14001X	PARTICIPANT	\N	PRESENT	0
634819	634817	14169X	PARTICIPANT	\N	PRESENT	0
636834	634656	19657G	PARTICIPANT	\N	PRESENT	0
636835	634656	07029T	PARTICIPANT	\N	PRESENT	0
636836	634656	19954N	PARTICIPANT	\N	PRESENT	0
636837	634656	20180F	PARTICIPANT	\N	PRESENT	0
636838	634656	19467C	PARTICIPANT	\N	PRESENT	0
636839	634656	19679N	PARTICIPANT	\N	PRESENT	0
636840	634656	18193Q	PARTICIPANT	\N	PRESENT	0
636841	634656	20114U	PARTICIPANT	\N	PRESENT	0
636842	634656	14033T	PARTICIPANT	\N	PRESENT	0
636843	634656	14217N	PARTICIPANT	\N	PRESENT	0
636844	634656	20126Y	PARTICIPANT	\N	PRESENT	0
636845	634656	19251M	PARTICIPANT	\N	PRESENT	0
636846	634656	20018V	PARTICIPANT	\N	PRESENT	0
636847	634656	19697Q	PARTICIPANT	\N	PRESENT	0
636848	634656	12028B	PARTICIPANT	\N	PRESENT	0
636849	634656	19447X	PARTICIPANT	\N	PRESENT	0
636898	636653	14021P	PARTICIPANT	\N	PRESENT	0
636921	636653	19758L	PARTICIPANT	\N	PRESENT	0
636900	636653	20248J	PARTICIPANT	\N	PRESENT	0
636901	636653	19629C	PARTICIPANT	\N	PRESENT	0
636902	636653	17779H	PARTICIPANT	\N	PRESENT	0
636903	636653	19697Q	PARTICIPANT	\N	PRESENT	0
636936	636653	19447X	PARTICIPANT	\N	PRESENT	0
636905	636653	19679N	PARTICIPANT	\N	PRESENT	0
636906	636653	20130U	PARTICIPANT	\N	PRESENT	0
636907	636653	19954N	PARTICIPANT	\N	PRESENT	0
636908	636653	20090E	PARTICIPANT	\N	PRESENT	0
636909	636653	20180F	PARTICIPANT	\N	PRESENT	0
636910	636653	19657G	PARTICIPANT	\N	PRESENT	0
636911	636653	10006L	PARTICIPANT	\N	PRESENT	0
636912	636653	11031D	PARTICIPANT	\N	PRESENT	0
636913	636653	11067R	PARTICIPANT	\N	PRESENT	0
636832	634656	11097X	PARTICIPANT	\N	PRESENT	0
636833	634656	20032T	PARTICIPANT	\N	PRESENT	0
636914	636653	19631V	PARTICIPANT	\N	PRESENT	0
636915	636653	20082E	PARTICIPANT	\N	PRESENT	0
636916	636653	19413M	PARTICIPANT	\N	PRESENT	0
636917	636653	20018V	PARTICIPANT	\N	PRESENT	0
636918	636653	18193Q	PARTICIPANT	\N	PRESENT	0
636919	636653	14257W	PARTICIPANT	\N	PRESENT	0
636920	636653	20064C	PARTICIPANT	\N	PRESENT	0
636922	636653	14033T	PARTICIPANT	\N	PRESENT	0
636923	636653	19333N	PARTICIPANT	\N	PRESENT	0
636924	636653	11097X	PARTICIPANT	\N	PRESENT	0
636925	636653	19577H	PARTICIPANT	\N	PRESENT	0
636926	636653	19251M	PARTICIPANT	\N	PRESENT	0
636927	636653	19503N	PARTICIPANT	\N	PRESENT	0
636928	636653	11064N	PARTICIPANT	\N	PRESENT	0
636929	636653	17965H	PARTICIPANT	\N	PRESENT	0
636930	636653	14217N	PARTICIPANT	\N	PRESENT	0
636931	636653	19549D	PARTICIPANT	\N	PRESENT	0
636932	636653	19715Y	PARTICIPANT	\N	PRESENT	0
636933	636653	14151M	PARTICIPANT	\N	PRESENT	0
636934	636653	14147R	PARTICIPANT	\N	PRESENT	0
636935	636653	19551W	PARTICIPANT	\N	PRESENT	0
636937	636653	07029T	PARTICIPANT	\N	PRESENT	0
636938	636653	19531S	PARTICIPANT	\N	PRESENT	0
636939	636653	14042U	PARTICIPANT	\N	PRESENT	0
636940	636653	20094J	PARTICIPANT	\N	PRESENT	0
636941	636653	20048C	PARTICIPANT	\N	PRESENT	0
636942	636653	11045K	PARTICIPANT	\N	PRESENT	0
636943	636653	95041E	PARTICIPANT	\N	PRESENT	0
636944	636653	20080C	PARTICIPANT	\N	PRESENT	0
636945	636653	20070A	PARTICIPANT	\N	PRESENT	0
636896	636653	14026U	PARTICIPANT	\N	PRESENT	0
636897	636653	08045X	PARTICIPANT	\N	PRESENT	0
641789	641644	14073Q	PARTICIPANT	\N	PRESENT	0
641790	641644	19611R	PRESIDENT	0	PRESENT	0
641791	641644	20052X	PARTICIPANT	\N	PRESENT	0
641792	641644	14109K	PARTICIPANT	\N	PRESENT	1
641793	641644	19593H	PARTICIPANT	\N	PRESENT	0
641794	641644	19533U	PARTICIPANT	\N	PRESENT	1
641795	641644	14229S	PARTICIPANT	\N	PRESENT	1
641796	641644	20084G	PARTICIPANT	\N	PRESENT	0
641797	641644	20026V	PARTICIPANT	\N	PRESENT	0
641798	641644	20058E	PARTICIPANT	\N	PRESENT	0
641799	641644	11109J	PARTICIPANT	\N	EXCUSE	0
641869	641868	20126Y	PARTICIPANT	\N	PRESENT	1
641870	641868	20082E	PRESIDENT	0	PRESENT	0
641871	641868	19693L	PARTICIPANT	\N	EXCUSE	0
641872	641868	20074E	PARTICIPANT	\N	EXCUSE	0
641873	641868	20066E	PARTICIPANT	\N	PRESENT	1
641874	641868	19369B	PARTICIPANT	\N	PRESENT	1
641875	641868	20050V	PARTICIPANT	\N	PRESENT	0
641876	641868	14193X	PARTICIPANT	\N	EXCUSE	0
641879	641878	19251M	PARTICIPANT	\N	PRESENT	0
641880	641878	17737W	PARTICIPANT	\N	PRESENT	0
641881	641878	20248J	PARTICIPANT	\N	PRESENT	0
641882	641878	11064N	PARTICIPANT	\N	PRESENT	0
641884	641883	20024T	PARTICIPANT	\N	PRESENT	0
641885	641883	20076G	PARTICIPANT	\N	PRESENT	0
641886	641883	14033T	PARTICIPANT	\N	PRESENT	0
641887	641883	20128B	PARTICIPANT	\N	PRESENT	0
641888	641883	20092G	PARTICIPANT	\N	PRESENT	0
641889	641883	04070G	PARTICIPANT	\N	PRESENT	0
641890	641883	04045F	PARTICIPANT	\N	PRESENT	0
641891	641883	11097X	PARTICIPANT	\N	PRESENT	0
641892	641883	14205J	PARTICIPANT	\N	PRESENT	0
641893	641883	19762G	PARTICIPANT	\N	PRESENT	0
641894	641883	20062A	PARTICIPANT	\N	PRESENT	0
641895	641883	19713W	PARTICIPANT	\N	PRESENT	0
641900	641899	14033T	PARTICIPANT	\N	PRESENT	0
641901	641899	19369B	PARTICIPANT	\N	PRESENT	0
641902	641899	20018V	PARTICIPANT	\N	PRESENT	0
641903	641899	14257W	PARTICIPANT	\N	PRESENT	0
641905	641904	14033T	PARTICIPANT	\N	PRESENT	0
641907	641906	14033T	PARTICIPANT	\N	PRESENT	0
641908	641906	19369B	PARTICIPANT	\N	PRESENT	0
641909	641906	20018V	PARTICIPANT	\N	PRESENT	0
641914	641911	20018V	PARTICIPANT	\N	PRESENT	0
641912	641911	14033T	PARTICIPANT	\N	PRESENT	0
641913	641911	19369B	PARTICIPANT	\N	PRESENT	0
641915	641911	20092G	PARTICIPANT	\N	PRESENT	0
641919	641918	14033T	PARTICIPANT	\N	PRESENT	0
641920	641918	19369B	PARTICIPANT	\N	PRESENT	0
641921	641918	20018V	PARTICIPANT	\N	PRESENT	0
641922	641918	20092G	PARTICIPANT	\N	PRESENT	0
641923	641918	14257W	PARTICIPANT	\N	PRESENT	0
641925	641924	14033T	PARTICIPANT	\N	PRESENT	0
641926	641924	19369B	PARTICIPANT	\N	PRESENT	0
641927	641924	20018V	PARTICIPANT	\N	PRESENT	0
641928	641924	20092G	PARTICIPANT	\N	PRESENT	0
641929	641924	14257W	PARTICIPANT	\N	PRESENT	0
641931	641930	14033T	PARTICIPANT	\N	PRESENT	0
641932	641930	19369B	PARTICIPANT	\N	PRESENT	0
641936	641930	14257W	PARTICIPANT	\N	PRESENT	0
641934	641930	20018V	PARTICIPANT	\N	PRESENT	0
641935	641930	20092G	PARTICIPANT	\N	PRESENT	0
641938	641916	19760E	PARTICIPANT	\N	PRESENT	0
641939	641916	11097X	PARTICIPANT	\N	PRESENT	0
641940	641916	18193Q	PARTICIPANT	\N	PRESENT	0
641941	641917	19760E	PARTICIPANT	\N	PRESENT	0
641942	641917	18193Q	PARTICIPANT	\N	PRESENT	0
641943	641917	11097X	PARTICIPANT	\N	PRESENT	0
641944	641937	19760E	PARTICIPANT	\N	PRESENT	0
641945	641937	11097X	PARTICIPANT	\N	PRESENT	0
641947	641946	20066E	PARTICIPANT	\N	PRESENT	1
641948	641946	14097Y	PARTICIPANT	\N	PRESENT	0
641949	641946	20050V	PARTICIPANT	\N	PRESENT	0
641950	641946	20082E	PARTICIPANT	\N	PRESENT	0
641951	641946	19693L	PARTICIPANT	\N	EXCUSE	0
641952	641946	14193X	PARTICIPANT	\N	EXCUSE	0
641953	641946	11077T	PARTICIPANT	\N	EXCUSE	0
641969	641968	11090Q	PARTICIPANT	\N	PRESENT	0
641955	641946	20074E	PARTICIPANT	\N	EXCUSE	0
641956	641946	19369B	PARTICIPANT	\N	PRESENT	0
641970	641968	14257W	PARTICIPANT	\N	PRESENT	0
641971	641968	20286Q	PARTICIPANT	\N	PRESENT	0
641972	641968	20092G	PARTICIPANT	\N	PRESENT	0
642107	642106	14083S	PRESIDENT	0	PRESENT	1
642108	642106	19717B	PARTICIPANT	\N	EXCUSE	0
642109	642106	20100N	PARTICIPANT	\N	PRESENT	1
642110	642106	19333N	PARTICIPANT	\N	PRESENT	1
642111	642106	20102Q	PARTICIPANT	\N	PRESENT	1
642112	642106	19447X	PARTICIPANT	\N	PRESENT	1
642113	642106	20150Y	PARTICIPANT	\N	PRESENT	1
642114	642106	14031R	PARTICIPANT	\N	PRESENT	1
642115	642106	20034V	PARTICIPANT	\N	PRESENT	1
642116	642106	19657G	PARTICIPANT	\N	PRESENT	1
642117	642106	19659J	PARTICIPANT	\N	PRESENT	1
642118	642106	11072N	PARTICIPANT	\N	PRESENT	1
642119	642106	19577H	PARTICIPANT	\N	PRESENT	1
642121	642120	19717B	PARTICIPANT	\N	EXCUSE	0
642122	642120	20034V	PARTICIPANT	\N	PRESENT	1
642123	642120	20102Q	PARTICIPANT	\N	PRESENT	1
642124	642120	19447X	PARTICIPANT	\N	PRESENT	1
642125	642120	14031R	PARTICIPANT	\N	PRESENT	1
642126	642120	14083S	PRESIDENT	0	PRESENT	1
642127	642120	20150Y	PARTICIPANT	\N	PRESENT	1
642128	642120	20100N	PARTICIPANT	\N	PRESENT	1
642129	642120	19319Q	PARTICIPANT	\N	PRESENT	1
642130	642120	19631V	PARTICIPANT	\N	PRESENT	1
642131	642120	20016T	PARTICIPANT	\N	PRESENT	1
642174	642173	19711U	PARTICIPANT	\N	PRESENT	0
642175	642173	14001X	PARTICIPANT	\N	PRESENT	0
642176	642173	20100N	PARTICIPANT	\N	PRESENT	0
642179	642178	19593H	PARTICIPANT	\N	PRESENT	0
642202	642200	19735D	PARTICIPANT	\N	PRESENT	0
642203	642200	19723Y	PARTICIPANT	\N	PRESENT	0
642206	642205	19735D	PARTICIPANT	\N	PRESENT	0
642207	642205	19723Y	PARTICIPANT	\N	PRESENT	0
642214	642209	19735D	PARTICIPANT	\N	PRESENT	0
642215	642209	19723Y	PARTICIPANT	\N	PRESENT	0
642224	642223	19735D	PARTICIPANT	\N	PRESENT	0
642225	642223	19723Y	PARTICIPANT	\N	PRESENT	0
642228	642227	19735D	PARTICIPANT	\N	PRESENT	0
642229	642227	19723Y	PARTICIPANT	\N	PRESENT	0
642232	642231	19735D	PARTICIPANT	\N	PRESENT	0
642233	642231	19723Y	PARTICIPANT	\N	PRESENT	0
642236	642235	19711U	PARTICIPANT	\N	PRESENT	0
642237	642235	20050V	PARTICIPANT	\N	PRESENT	0
642238	639010	19575F	PARTICIPANT	\N	PRESENT	0
642240	639010	20054A	PARTICIPANT	\N	PRESENT	0
642241	639010	14193X	PARTICIPANT	\N	PRESENT	0
642242	639010	19533U	PARTICIPANT	\N	PRESENT	0
642243	639010	20124W	PARTICIPANT	\N	PRESENT	0
642244	639010	14151M	PARTICIPANT	\N	PRESENT	0
642245	639010	19251M	PARTICIPANT	\N	PRESENT	0
642246	639010	19467C	PARTICIPANT	\N	PRESENT	0
642247	639010	20126Y	PARTICIPANT	\N	PRESENT	0
642407	642402	95041E	PARTICIPANT	\N	PRESENT	0
642408	642402	19565D	PARTICIPANT	\N	PRESENT	0
642409	642402	01058X	PARTICIPANT	\N	PRESENT	0
642410	642402	11027H	PARTICIPANT	\N	PRESENT	0
642411	642402	16685X	PARTICIPANT	\N	PRESENT	0
642412	642402	11054L	PARTICIPANT	\N	PRESENT	0
642413	642402	11066Q	PARTICIPANT	\N	PRESENT	0
642414	642402	12028B	PARTICIPANT	\N	PRESENT	0
642415	642402	19421M	PARTICIPANT	\N	PRESENT	0
642416	642402	14193X	PARTICIPANT	\N	PRESENT	0
642417	642402	19347U	PARTICIPANT	\N	PRESENT	0
642418	642402	07033P	PARTICIPANT	\N	PRESENT	0
642419	642402	97011G	PARTICIPANT	\N	PRESENT	0
642420	642402	08061X	PARTICIPANT	\N	PRESENT	0
642421	642402	08047A	PARTICIPANT	\N	PRESENT	0
642422	642402	14059S	PARTICIPANT	\N	PRESENT	0
642423	642402	01062T	PARTICIPANT	\N	PRESENT	0
642424	642402	08069G	PARTICIPANT	\N	PRESENT	0
642425	642402	01024M	PARTICIPANT	\N	PRESENT	0
642426	642402	20064C	PARTICIPANT	\N	PRESENT	0
642427	642402	11064N	PARTICIPANT	\N	PRESENT	0
630488	629122	14189C	PARTICIPANT	\N	PRESENT	0
630489	629122	20104S	PARTICIPANT	\N	PRESENT	0
630490	629122	11101A	PARTICIPANT	\N	PRESENT	0
630491	629122	19701S	PARTICIPANT	\N	PRESENT	0
630492	629122	20100N	PARTICIPANT	\N	PRESENT	0
630493	629122	19333N	PARTICIPANT	\N	PRESENT	0
630494	629122	14073Q	PARTICIPANT	\N	PRESENT	0
630495	629122	12016W	PARTICIPANT	\N	PRESENT	0
630496	629122	04057K	PARTICIPANT	\N	PRESENT	0
630497	629122	14331P	PARTICIPANT	\N	PRESENT	0
634723	634722	04043D	PARTICIPANT	\N	PRESENT	0
634725	632407	01048V	PARTICIPANT	\N	PRESENT	0
634726	632407	01058X	PARTICIPANT	\N	PRESENT	0
634727	632407	19693L	PARTICIPANT	\N	PRESENT	0
634728	632407	20128B	PARTICIPANT	\N	PRESENT	0
634729	632407	19723Y	PARTICIPANT	\N	PRESENT	0
634730	632407	19533U	PARTICIPANT	\N	PRESENT	0
634734	632407	11067R	PARTICIPANT	\N	EXCUSE	0
634735	632407	19735D	PARTICIPANT	\N	EXCUSE	0
634736	632206	04043D	PARTICIPANT	\N	PRESENT	0
634737	632206	19503N	PARTICIPANT	\N	PRESENT	0
635791	635790	14033T	PARTICIPANT	\N	PRESENT	0
635792	635790	14205J	PARTICIPANT	\N	PRESENT	0
635793	635790	19467C	PARTICIPANT	\N	PRESENT	0
635794	635790	14257W	PARTICIPANT	\N	PRESENT	0
635795	635790	19413M	PARTICIPANT	\N	PRESENT	0
635796	635790	20144B	PARTICIPANT	\N	PRESENT	0
635797	635790	01025N	PARTICIPANT	\N	PRESENT	0
635798	635790	19782L	PARTICIPANT	\N	PRESENT	0
635882	635881	11083R	PARTICIPANT	\N	PRESENT	1
635883	635881	11027H	PARTICIPANT	\N	PRESENT	1
635884	635881	20064C	PARTICIPANT	\N	PRESENT	0
635885	635881	19631V	PARTICIPANT	\N	PRESENT	0
635886	635881	14069U	PARTICIPANT	\N	PRESENT	0
635887	635881	19637C	PARTICIPANT	\N	PRESENT	0
635888	635881	14187A	PARTICIPANT	\N	PRESENT	0
635889	635881	19820Y	PARTICIPANT	\N	PRESENT	1
635890	635881	14255U	PARTICIPANT	\N	PRESENT	1
635892	635891	20064C	PARTICIPANT	\N	PRESENT	0
635893	635891	20264J	PARTICIPANT	\N	PRESENT	0
635894	635891	19820Y	PARTICIPANT	\N	PRESENT	0
635895	635881	20264J	PARTICIPANT	\N	PRESENT	0
636014	636010	01048V	PARTICIPANT	\N	PRESENT	0
636111	636091	19711U	PARTICIPANT	\N	PRESENT	0
636157	636155	19762G	PARTICIPANT	\N	PRESENT	0
636158	636155	19531S	PARTICIPANT	\N	PRESENT	0
636174	636173	08009T	PARTICIPANT	\N	PRESENT	0
636175	636173	20044X	PARTICIPANT	\N	PRESENT	0
637104	637103	20094J	PARTICIPANT	\N	PRESENT	0
637285	637284	20174H	PARTICIPANT	\N	PRESENT	0
637286	637284	14033T	PARTICIPANT	\N	PRESENT	0
637287	637284	20126Y	PARTICIPANT	\N	PRESENT	0
637288	637284	14257W	PARTICIPANT	\N	PRESENT	0
637289	637284	20092G	PARTICIPANT	\N	PRESENT	0
637293	637292	14195A	PARTICIPANT	\N	PRESENT	0
637294	637292	14205J	PARTICIPANT	\N	PRESENT	0
637295	637292	20082E	PARTICIPANT	\N	PRESENT	0
637296	637292	20054A	PARTICIPANT	\N	PRESENT	0
637297	637292	11097X	PARTICIPANT	\N	PRESENT	0
637298	637292	19713W	PARTICIPANT	\N	PRESENT	0
643132	642869	19251M	PARTICIPANT	\N	PRESENT	1
643133	642869	19577H	PARTICIPANT	\N	PRESENT	1
643134	642869	20100N	PARTICIPANT	\N	PRESENT	1
643135	642869	20120S	PARTICIPANT	\N	PRESENT	1
643136	642869	19820Y	PARTICIPANT	\N	PRESENT	1
643137	642869	19387D	PARTICIPANT	\N	PRESENT	1
643138	642869	20046A	PARTICIPANT	\N	PRESENT	1
643172	643061	11097X	PARTICIPANT	\N	PRESENT	0
643173	643061	01034P	PARTICIPANT	\N	PRESENT	0
643174	643061	20130U	PARTICIPANT	\N	PRESENT	0
643175	643061	18193Q	PARTICIPANT	\N	PRESENT	0
643176	643061	14042U	PARTICIPANT	\N	PRESENT	0
643177	643061	19760E	PARTICIPANT	\N	PRESENT	0
643574	643392	19766L	PARTICIPANT	\N	PRESENT	0
643575	643392	14229S	PARTICIPANT	\N	PRESENT	0
643576	643392	19573D	PARTICIPANT	\N	PRESENT	0
643577	643392	08012N	PARTICIPANT	\N	PRESENT	0
643578	643392	20134Y	PARTICIPANT	\N	PRESENT	0
643579	643392	20048C	PARTICIPANT	\N	PRESENT	0
643580	643392	20052X	PARTICIPANT	\N	PRESENT	0
643581	643392	20152B	PARTICIPANT	\N	PRESENT	0
644528	644422	14151M	PARTICIPANT	\N	PRESENT	0
643583	643392	14030Q	PARTICIPANT	\N	PRESENT	0
643584	643392	20056C	PARTICIPANT	\N	PRESENT	0
643585	643392	04059M	PARTICIPANT	\N	PRESENT	0
643586	643392	19533U	PARTICIPANT	\N	PRESENT	1
643587	643392	20026V	PARTICIPANT	\N	PRESENT	1
643588	643392	19643A	PARTICIPANT	\N	PRESENT	1
643589	643392	14073Q	PARTICIPANT	\N	PRESENT	1
643590	643392	19611R	PARTICIPANT	\N	PRESENT	1
643591	643392	19693L	PARTICIPANT	\N	PRESENT	1
643592	643392	19399H	PARTICIPANT	\N	PRESENT	0
643593	643392	20058E	PARTICIPANT	\N	PRESENT	0
643594	643392	14123H	PARTICIPANT	\N	PRESENT	1
643595	643392	17589D	PARTICIPANT	\N	PRESENT	1
643596	643392	20084G	PARTICIPANT	\N	PRESENT	1
643597	643392	20112S	PARTICIPANT	\N	PRESENT	1
643598	643392	20132W	PARTICIPANT	\N	PRESENT	1
643599	643392	20138D	PARTICIPANT	\N	PRESENT	1
643600	643392	20142Y	PARTICIPANT	\N	PRESENT	1
643601	643392	19719D	PARTICIPANT	\N	PRESENT	0
643602	643392	20172F	PARTICIPANT	\N	PRESENT	1
643603	643392	20264J	PARTICIPANT	\N	PRESENT	1
643604	643392	19735D	PARTICIPANT	\N	PRESENT	1
643605	643392	19057M	PARTICIPANT	\N	PRESENT	0
643606	643392	11043H	PARTICIPANT	\N	PRESENT	0
643607	643392	19758L	PARTICIPANT	\N	PRESENT	1
643610	643392	19527W	PARTICIPANT	\N	PRESENT	1
644529	644422	05008E	PARTICIPANT	\N	PRESENT	0
644530	644422	19649G	PARTICIPANT	\N	PRESENT	0
644536	644422	10015M	PARTICIPANT	\N	PRESENT	0
644615	643472	20130U	PARTICIPANT	\N	PRESENT	0
644616	643472	01034P	PARTICIPANT	\N	PRESENT	0
644617	643472	19691J	PARTICIPANT	\N	PRESENT	0
644618	643313	01034P	PARTICIPANT	\N	PRESENT	0
644619	643313	20130U	PARTICIPANT	\N	PRESENT	0
644642	644374	14259Y	PARTICIPANT	\N	PRESENT	0
644621	643313	18193Q	PARTICIPANT	\N	PRESENT	0
644641	644374	10015M	PARTICIPANT	\N	PRESENT	0
644643	644374	11026G	PARTICIPANT	\N	PRESENT	0
645400	644863	19760E	PARTICIPANT	\N	PRESENT	0
645401	644863	11031D	PARTICIPANT	\N	PRESENT	0
645402	644863	11045K	PARTICIPANT	\N	PRESENT	0
645403	644863	04092N	PARTICIPANT	\N	PRESENT	0
645404	644863	11097X	PARTICIPANT	\N	PRESENT	0
645405	644863	19703U	PARTICIPANT	\N	PRESENT	0
645406	644863	11067R	PARTICIPANT	\N	PRESENT	0
645407	644863	14217N	PARTICIPANT	\N	PRESENT	0
645408	644863	14071N	PARTICIPANT	\N	PRESENT	0
645409	644863	19415P	PARTICIPANT	\N	PRESENT	0
645410	644863	20090E	PARTICIPANT	\N	PRESENT	0
645411	644863	14223L	PARTICIPANT	\N	PRESENT	0
645412	644863	20040T	PARTICIPANT	\N	PRESENT	0
645413	644863	19691J	PARTICIPANT	\N	PRESENT	0
645414	644863	14042U	PARTICIPANT	\N	PRESENT	0
645415	644863	20130U	PARTICIPANT	\N	PRESENT	1
645416	644863	19591F	PARTICIPANT	\N	PRESENT	1
645424	644863	10006L	PRESIDENT	0	PRESENT	0
645425	644863	19569H	PARTICIPANT	\N	PRESENT	0
645426	644863	19295A	PARTICIPANT	\N	EXCUSE	0
645427	644863	14213J	PARTICIPANT	\N	PRESENT	1
645428	644863	19663E	PARTICIPANT	\N	PRESENT	1
645723	645722	20070A	PARTICIPANT	\N	PRESENT	0
645901	645460	19591F	PARTICIPANT	\N	PRESENT	1
645902	645460	11031D	PARTICIPANT	\N	PRESENT	1
645903	645460	04043D	PARTICIPANT	\N	PRESENT	1
645904	645460	17779H	PARTICIPANT	\N	PRESENT	1
645905	645460	19760E	PARTICIPANT	\N	PRESENT	1
645906	645460	19798U	PARTICIPANT	\N	PRESENT	1
645907	645460	11103C	PARTICIPANT	\N	PRESENT	1
645911	645460	14223L	PARTICIPANT	\N	PRESENT	1
645912	645460	08045X	PARTICIPANT	\N	PRESENT	1
645916	645460	19553Y	PARTICIPANT	\N	PRESENT	1
646159	646158	20028X	PARTICIPANT	\N	PRESENT	0
646160	646158	19441R	PARTICIPANT	\N	PRESENT	0
646161	646158	19507S	PARTICIPANT	\N	PRESENT	0
650241	649162	19798U	PARTICIPANT	\N	PRESENT	0
650243	649162	14257W	PARTICIPANT	\N	PRESENT	0
650244	649162	14231L	PARTICIPANT	\N	PRESENT	0
650245	649162	19525U	PARTICIPANT	\N	PRESENT	0
650246	649162	20098N	PARTICIPANT	\N	PRESENT	0
650247	649162	08010L	PARTICIPANT	\N	PRESENT	0
650248	649162	20036X	PARTICIPANT	\N	PRESENT	0
650249	649162	20252E	PARTICIPANT	\N	PRESENT	0
650250	648783	14179A	PARTICIPANT	\N	PRESENT	0
650251	648783	19749K	PARTICIPANT	\N	PRESENT	0
650252	648783	19725B	PARTICIPANT	\N	EXCUSE	0
650257	649162	19693L	PARTICIPANT	\N	PRESENT	0
650258	649162	19760E	PARTICIPANT	\N	PRESENT	0
650259	649162	01058X	PARTICIPANT	\N	PRESENT	0
650260	649162	19758L	PARTICIPANT	\N	PRESENT	0
650261	649162	19575F	PARTICIPANT	\N	PRESENT	0
650262	649162	99004R	PARTICIPANT	\N	PRESENT	0
650263	649162	11056N	PARTICIPANT	\N	PRESENT	0
650264	649162	19687N	PARTICIPANT	\N	PRESENT	0
650265	649162	04047H	PARTICIPANT	\N	PRESENT	0
650266	649162	14026U	PARTICIPANT	\N	PRESENT	0
650267	649162	04092N	PARTICIPANT	\N	PRESENT	0
650268	649162	20046A	PARTICIPANT	\N	PRESENT	0
650269	649162	04085P	PARTICIPANT	\N	PRESENT	0
650270	649162	01057W	PARTICIPANT	\N	PRESENT	0
650271	649162	12041X	PARTICIPANT	\N	PRESENT	0
650272	649162	11077T	PARTICIPANT	\N	PRESENT	0
650273	649162	19695N	PARTICIPANT	\N	PRESENT	0
650274	649162	20102Q	PARTICIPANT	\N	PRESENT	0
650275	649162	11031D	PARTICIPANT	\N	PRESENT	0
650276	649162	19347U	PARTICIPANT	\N	PRESENT	0
650277	649162	11065P	PARTICIPANT	\N	PRESENT	0
650278	649162	14071N	PARTICIPANT	\N	PRESENT	0
650279	649162	20914V	PARTICIPANT	\N	PRESENT	0
650280	649162	20142Y	PARTICIPANT	\N	PRESENT	0
650281	649162	14038Y	PARTICIPANT	\N	PRESENT	0
650282	649162	20092G	PARTICIPANT	\N	PRESENT	0
650283	649162	20038A	PARTICIPANT	\N	PRESENT	0
650284	649162	19447X	PARTICIPANT	\N	PRESENT	0
650285	649162	20034V	PARTICIPANT	\N	PRESENT	0
650286	649162	19723Y	PARTICIPANT	\N	PRESENT	0
650287	649162	20044X	PARTICIPANT	\N	PRESENT	0
650288	649162	20058E	PARTICIPANT	\N	PRESENT	0
650289	649162	19663E	PARTICIPANT	\N	PRESENT	0
650290	649162	19467C	PARTICIPANT	\N	PRESENT	0
650291	649162	08018U	PARTICIPANT	\N	PRESENT	0
650292	649162	20056C	PARTICIPANT	\N	PRESENT	0
650293	649162	11010L	PARTICIPANT	\N	PRESENT	0
650294	649162	20266L	PARTICIPANT	\N	PRESENT	0
650295	649162	19741B	PARTICIPANT	\N	PRESENT	0
650296	649162	19515S	PARTICIPANT	\N	PRESENT	0
650297	649162	20134Y	PARTICIPANT	\N	PRESENT	0
650298	649162	20180F	PARTICIPANT	\N	PRESENT	0
650299	649162	14259Y	PARTICIPANT	\N	PRESENT	0
650300	649162	19301E	PARTICIPANT	\N	PRESENT	0
650301	649162	11072N	PARTICIPANT	\N	PRESENT	0
650302	649162	95063L	PARTICIPANT	\N	PRESENT	0
650303	649162	19643A	PARTICIPANT	\N	PRESENT	0
650304	649162	20136B	PARTICIPANT	\N	PRESENT	0
650305	649162	04045F	PARTICIPANT	\N	PRESENT	0
650306	649162	20128B	PARTICIPANT	\N	PRESENT	0
650307	649162	20140W	PARTICIPANT	\N	PRESENT	0
650308	649162	20146D	PARTICIPANT	\N	PRESENT	0
650309	649162	08047A	PARTICIPANT	\N	PRESENT	0
650310	649162	19349W	PARTICIPANT	\N	PRESENT	0
650311	649162	08061X	PARTICIPANT	\N	PRESENT	0
650312	649162	14249W	PARTICIPANT	\N	PRESENT	0
650313	649162	20108W	PARTICIPANT	\N	PRESENT	0
650314	649162	19782L	PARTICIPANT	\N	PRESENT	0
650315	649162	08015R	PARTICIPANT	\N	PRESENT	0
650316	649162	19329S	PARTICIPANT	\N	PRESENT	0
650317	649162	19729F	PARTICIPANT	\N	PRESENT	0
650318	649162	19657G	PARTICIPANT	\N	PRESENT	0
650319	649162	19591F	PARTICIPANT	\N	PRESENT	0
650320	649162	20024T	PARTICIPANT	\N	PRESENT	0
650321	649162	14213J	PARTICIPANT	\N	PRESENT	0
650322	649162	20138D	PARTICIPANT	\N	PRESENT	0
650323	649162	19545Y	PARTICIPANT	\N	PRESENT	0
650324	649162	14195A	PARTICIPANT	\N	PRESENT	0
650325	649162	20100N	PARTICIPANT	\N	PRESENT	0
650326	649162	20090E	PARTICIPANT	\N	PRESENT	0
650327	649162	14221J	PARTICIPANT	\N	PRESENT	0
650328	649162	17367Q	PARTICIPANT	\N	PRESENT	0
650329	649162	04057K	PARTICIPANT	\N	PRESENT	0
650330	649162	14329V	PARTICIPANT	\N	PRESENT	0
650331	649162	14357A	PARTICIPANT	\N	PRESENT	0
650332	649162	19553Y	PARTICIPANT	\N	PRESENT	0
650333	649162	19675J	PARTICIPANT	\N	PRESENT	0
650334	649162	20122U	PARTICIPANT	\N	PRESENT	0
650335	649162	19383Y	PARTICIPANT	\N	PRESENT	0
650336	649162	14251Q	PARTICIPANT	\N	PRESENT	0
650337	649162	19762G	PARTICIPANT	\N	PRESENT	0
650338	649162	19681G	PARTICIPANT	\N	PRESENT	0
650339	649162	20020P	PARTICIPANT	\N	PRESENT	0
650340	649162	20132W	PARTICIPANT	\N	PRESENT	0
650341	649162	20152B	PARTICIPANT	\N	PRESENT	0
650342	649162	20072C	PARTICIPANT	\N	PRESENT	0
650343	649162	14207L	PARTICIPANT	\N	PRESENT	0
650344	649162	19367Y	PARTICIPANT	\N	PRESENT	0
650345	649162	19563B	PARTICIPANT	\N	PRESENT	0
650346	649162	19581D	PARTICIPANT	\N	PRESENT	0
650347	649162	20054A	PARTICIPANT	\N	PRESENT	0
650348	649162	11012A	PARTICIPANT	\N	PRESENT	0
650349	649162	20116W	PARTICIPANT	\N	PRESENT	0
650350	649162	20126Y	PARTICIPANT	\N	PRESENT	0
650351	649162	14121F	PARTICIPANT	\N	PRESENT	0
650352	649162	19631V	PARTICIPANT	\N	PRESENT	0
650354	649162	01028R	PARTICIPANT	\N	PRESENT	0
650356	649162	14021P	PARTICIPANT	\N	PRESENT	0
650357	649162	11027H	PARTICIPANT	\N	PRESENT	0
650358	649162	17779H	PARTICIPANT	\N	PRESENT	0
650359	649162	20120S	PARTICIPANT	\N	PRESENT	0
650360	649162	14229S	PARTICIPANT	\N	PRESENT	0
650361	649162	14217N	PARTICIPANT	\N	PRESENT	0
650362	649162	01062T	PARTICIPANT	\N	PRESENT	0
650363	649162	11074Q	PARTICIPANT	\N	PRESENT	0
650364	649162	97011G	PARTICIPANT	\N	PRESENT	0
650365	649162	19489J	PARTICIPANT	\N	PRESENT	0
650366	649162	14001X	PARTICIPANT	\N	PRESENT	0
650367	649162	14281W	PARTICIPANT	\N	PRESENT	0
650368	649162	20028X	PARTICIPANT	\N	PRESENT	0
650369	649162	20118Y	PARTICIPANT	\N	PRESENT	0
650370	649162	19333N	PARTICIPANT	\N	PRESENT	0
650371	649162	19533U	PARTICIPANT	\N	PRESENT	0
650372	649162	19683J	PARTICIPANT	\N	PRESENT	0
650373	649162	14147R	PARTICIPANT	\N	PRESENT	0
650374	649162	20082E	PARTICIPANT	\N	PRESENT	0
650375	649162	10006L	PARTICIPANT	\N	PRESENT	0
650376	649162	14193X	PARTICIPANT	\N	PRESENT	0
650377	649162	19421M	PARTICIPANT	\N	PRESENT	0
650378	649162	14215L	PARTICIPANT	\N	PRESENT	0
650379	649162	19549D	PARTICIPANT	\N	PRESENT	0
650380	649162	19701S	PARTICIPANT	\N	PRESENT	0
650381	649162	14069U	PARTICIPANT	\N	PRESENT	0
650382	649162	04033B	PARTICIPANT	\N	PRESENT	0
650383	649162	14187A	PARTICIPANT	\N	PRESENT	0
650384	649162	05008E	PARTICIPANT	\N	PRESENT	0
650385	649162	11097X	PARTICIPANT	\N	PRESENT	0
650386	649162	19415P	PARTICIPANT	\N	PRESENT	0
650387	649162	19747H	PARTICIPANT	\N	PRESENT	0
650388	649162	04042C	PARTICIPANT	\N	PRESENT	0
650389	649162	08069G	PARTICIPANT	\N	PRESENT	0
650390	649162	11045K	PARTICIPANT	\N	PRESENT	0
650391	649162	14123H	PARTICIPANT	\N	PRESENT	0
650392	649162	14225N	PARTICIPANT	\N	PRESENT	0
650393	649162	19715Y	PARTICIPANT	\N	PRESENT	0
650394	649162	19599P	PARTICIPANT	\N	PRESENT	0
650395	649162	14151M	PARTICIPANT	\N	PRESENT	0
650396	649162	18083K	PARTICIPANT	\N	PRESENT	0
650397	649162	11067R	PARTICIPANT	\N	PRESENT	0
650398	649162	20078J	PARTICIPANT	\N	PRESENT	0
650399	649162	20074E	PARTICIPANT	\N	PRESENT	0
650400	649162	20076G	PARTICIPANT	\N	PRESENT	0
650401	649162	14097Y	PARTICIPANT	\N	PRESENT	0
650402	649162	19679N	PARTICIPANT	\N	PRESENT	0
650403	649162	11066Q	PARTICIPANT	\N	PRESENT	0
650404	649162	11054L	PARTICIPANT	\N	PRESENT	0
650405	649162	19649G	PARTICIPANT	\N	PRESENT	0
650406	649162	19703U	PARTICIPANT	\N	PRESENT	0
634740	634647	12041X	PARTICIPANT	\N	PRESENT	0
634741	634647	14259Y	PARTICIPANT	\N	PRESENT	0
634742	634647	01028R	PARTICIPANT	\N	PRESENT	0
634743	634647	11072N	PARTICIPANT	\N	PRESENT	0
634744	634647	19583F	PARTICIPANT	\N	PRESENT	0
634745	634647	19447X	PARTICIPANT	\N	PRESENT	0
634746	634647	20110Q	PARTICIPANT	\N	PRESENT	0
634747	634647	04085P	PARTICIPANT	\N	PRESENT	0
634748	634647	14275Y	PARTICIPANT	\N	PRESENT	0
634749	634647	11012A	PARTICIPANT	\N	PRESENT	0
635546	634329	14053L	PARTICIPANT	\N	PRESENT	0
635547	634329	14111D	PARTICIPANT	\N	PRESENT	0
635548	634329	11010L	PARTICIPANT	\N	PRESENT	0
635549	634329	10015M	PARTICIPANT	\N	PRESENT	0
635550	634329	14001X	PARTICIPANT	\N	PRESENT	0
635551	634329	19543W	PARTICIPANT	\N	PRESENT	0
635552	634329	04047H	PRESIDENT	0	PRESENT	0
635553	634329	01028R	PARTICIPANT	\N	PRESENT	0
635554	634329	19447X	PARTICIPANT	\N	PRESENT	0
635555	634329	05008E	PARTICIPANT	\N	PRESENT	0
635556	634329	14231L	PARTICIPANT	\N	PRESENT	0
635557	634329	19725B	PARTICIPANT	\N	PRESENT	0
635558	634329	14089Y	PARTICIPANT	\N	PRESENT	0
635559	634329	19954N	PARTICIPANT	\N	PRESENT	0
635560	634329	14275Y	PARTICIPANT	\N	PRESENT	0
635561	634329	95063L	PARTICIPANT	\N	PRESENT	0
635562	634329	14147R	PARTICIPANT	\N	PRESENT	0
635563	634329	14151M	PARTICIPANT	\N	PRESENT	0
635564	634329	20022R	PARTICIPANT	\N	PRESENT	0
635565	634329	19749K	PARTICIPANT	\N	PRESENT	0
635566	634329	20128B	PARTICIPANT	\N	PRESENT	0
635567	634329	17737W	PARTICIPANT	\N	EXCUSE	0
635570	634330	14001X	PARTICIPANT	\N	PRESENT	0
635655	631793	14219Q	PRESIDENT	0	PRESENT	0
635572	634330	04047H	PRESIDENT	0	PRESENT	0
635573	634330	01028R	PARTICIPANT	\N	PRESENT	0
635574	634330	19447X	PARTICIPANT	\N	PRESENT	0
635575	634330	05008E	PARTICIPANT	\N	PRESENT	0
635576	634330	14231L	PARTICIPANT	\N	PRESENT	0
635577	634330	19954N	PARTICIPANT	\N	PRESENT	0
635578	634330	14275Y	PARTICIPANT	\N	PRESENT	0
635579	634330	14107H	PARTICIPANT	\N	PRESENT	0
635580	634330	14147R	PARTICIPANT	\N	PRESENT	0
635581	634330	14151M	PARTICIPANT	\N	PRESENT	0
635582	634330	14215L	PARTICIPANT	\N	PRESENT	0
635583	634330	08018U	PARTICIPANT	\N	PRESENT	0
635584	634330	20022R	PARTICIPANT	\N	PRESENT	0
635585	634330	14259Y	PARTICIPANT	\N	PRESENT	0
635586	634330	20128B	PARTICIPANT	\N	PRESENT	0
635587	634330	14053L	PARTICIPANT	\N	PRESENT	0
635588	634330	14111D	PARTICIPANT	\N	PRESENT	0
635589	634330	11010L	PARTICIPANT	\N	PRESENT	0
635590	634330	10015M	PARTICIPANT	\N	PRESENT	0
635591	634330	11026G	PARTICIPANT	\N	PRESENT	0
635592	634330	04085P	PARTICIPANT	\N	PRESENT	0
635593	634330	19725B	PARTICIPANT	\N	PRESENT	0
635594	634330	14089Y	PARTICIPANT	\N	PRESENT	0
635595	634330	95063L	PARTICIPANT	\N	PRESENT	0
635596	634330	19749K	PARTICIPANT	\N	PRESENT	0
635597	634330	17737W	PARTICIPANT	\N	EXCUSE	0
635631	634330	11085T	PARTICIPANT	\N	PRESENT	0
635635	631793	20032T	PARTICIPANT	\N	PRESENT	0
635636	631793	19701S	PARTICIPANT	\N	PRESENT	0
635637	631793	20136B	PARTICIPANT	\N	PRESENT	0
635638	631793	20038A	PARTICIPANT	\N	PRESENT	0
635639	631793	14031R	PARTICIPANT	\N	PRESENT	0
635640	631793	19387D	PARTICIPANT	\N	PRESENT	0
635641	631793	19826F	PARTICIPANT	\N	PRESENT	0
635642	631793	20046A	PARTICIPANT	\N	PRESENT	0
635643	631793	14221J	PARTICIPANT	\N	PRESENT	0
635644	631793	20102Q	PARTICIPANT	\N	PRESENT	0
635645	631793	17229F	PARTICIPANT	\N	PRESENT	0
635646	631793	20100N	PARTICIPANT	\N	PRESENT	0
635647	631793	19551W	PARTICIPANT	\N	PRESENT	0
635648	631793	18083K	PARTICIPANT	\N	PRESENT	0
635649	631793	20068G	PARTICIPANT	\N	PRESENT	0
635650	631793	20118Y	PARTICIPANT	\N	PRESENT	0
635651	631793	19745F	PARTICIPANT	\N	PRESENT	0
635652	631793	20024T	PARTICIPANT	\N	PRESENT	0
635653	631793	11065P	PARTICIPANT	\N	PRESENT	0
635654	631793	19619A	PARTICIPANT	\N	PRESENT	0
635656	631793	05012A	PARTICIPANT	\N	PRESENT	0
635657	631793	17367Q	PARTICIPANT	\N	PRESENT	0
635659	631793	19503N	PARTICIPANT	\N	PRESENT	0
635660	634330	19585H	PARTICIPANT	\N	PRESENT	0
635661	631793	14169X	PARTICIPANT	\N	PRESENT	0
635662	631793	20140W	PARTICIPANT	\N	PRESENT	0
635663	631793	19681G	PARTICIPANT	\N	PRESENT	1
635664	631793	20106U	PARTICIPANT	\N	PRESENT	1
635665	631793	19637C	PARTICIPANT	\N	PRESENT	1
635666	635633	19383Y	PARTICIPANT	\N	PRESENT	0
635667	635633	19768N	PARTICIPANT	\N	PRESENT	0
635668	635633	19515S	PARTICIPANT	\N	PRESENT	0
635669	635633	20092G	PARTICIPANT	\N	PRESENT	0
635670	635633	01043Q	PARTICIPANT	\N	PRESENT	0
635671	635633	14357A	PARTICIPANT	\N	PRESENT	0
635672	635633	19441R	PARTICIPANT	\N	PRESENT	0
635673	635633	20082E	PARTICIPANT	\N	PRESENT	0
635674	635633	19631V	PARTICIPANT	\N	PRESENT	0
635675	635633	20104S	PARTICIPANT	\N	PRESENT	0
635676	635633	19705W	PARTICIPANT	\N	PRESENT	1
635677	635633	19707Y	PARTICIPANT	\N	PRESENT	1
635678	635633	19575F	PARTICIPANT	\N	PRESENT	0
635679	635633	08028W	PARTICIPANT	\N	PRESENT	0
635680	635633	20028X	PARTICIPANT	\N	PRESENT	0
635681	635633	14038Y	PARTICIPANT	\N	PRESENT	0
635682	635633	19467C	PARTICIPANT	\N	PRESENT	0
635683	635633	14187A	PARTICIPANT	\N	PRESENT	0
635684	635633	19695N	PARTICIPANT	\N	PRESENT	0
635685	635633	01025N	PARTICIPANT	\N	PRESENT	0
635686	635633	11090Q	PRESIDENT	0	PRESENT	0
635687	635633	14033T	PARTICIPANT	\N	PRESENT	0
635688	635633	20054A	PARTICIPANT	\N	PRESENT	0
635689	635633	20174H	PARTICIPANT	\N	PRESENT	1
635690	635633	14205J	PARTICIPANT	\N	PRESENT	1
635691	635633	19507S	PARTICIPANT	\N	PRESENT	0
635692	635633	14207L	PARTICIPANT	\N	PRESENT	0
635693	635633	19747H	PARTICIPANT	\N	PRESENT	1
635694	635633	14257W	PARTICIPANT	\N	PRESENT	0
635695	635633	20034V	PARTICIPANT	\N	EXCUSE	0
635696	635633	19369B	PARTICIPANT	\N	PRESENT	0
635699	635633	20286Q	PARTICIPANT	\N	PRESENT	0
635700	634330	04008A	PARTICIPANT	\N	PRESENT	0
635702	635633	14251Q	PARTICIPANT	\N	PRESENT	1
635703	631793	20076G	PARTICIPANT	\N	PRESENT	0
635704	631793	19820Y	PARTICIPANT	\N	PRESENT	0
635705	635633	04045F	PARTICIPANT	\N	PRESENT	0
635706	635633	19563B	PARTICIPANT	\N	PRESENT	0
635707	634330	19649G	PARTICIPANT	\N	PRESENT	0
635708	635633	19782L	PARTICIPANT	\N	PRESENT	0
635709	634330	14021P	PARTICIPANT	\N	PRESENT	0
635710	631793	19599P	PARTICIPANT	\N	PRESENT	0
635711	631793	11101A	PARTICIPANT	\N	PRESENT	0
635712	634330	19629C	PARTICIPANT	\N	PRESENT	0
635713	631793	19549D	PARTICIPANT	\N	PRESENT	0
635714	634654	86034E	PARTICIPANT	\N	PRESENT	0
635715	635633	20018V	PARTICIPANT	\N	PRESENT	1
635717	631793	14237S	PARTICIPANT	\N	PRESENT	0
635733	635633	19413M	PARTICIPANT	\N	PRESENT	0
635735	634460	20086J	PARTICIPANT	\N	PRESENT	0
635736	634460	14331P	PARTICIPANT	\N	PRESENT	0
635737	634460	19479G	PARTICIPANT	\N	PRESENT	0
635738	634460	19711U	PARTICIPANT	\N	PRESENT	0
635739	634460	14189C	PARTICIPANT	\N	PRESENT	0
635740	634460	01057W	PARTICIPANT	\N	PRESENT	0
635741	634460	19687N	PARTICIPANT	\N	PRESENT	0
635742	634460	20080C	PARTICIPANT	\N	PRESENT	0
635743	634460	11053K	PARTICIPANT	\N	PRESENT	0
635744	634460	19667J	PARTICIPANT	\N	PRESENT	0
635745	634460	20044X	PARTICIPANT	\N	PRESENT	0
635746	634460	19693L	PARTICIPANT	\N	PRESENT	0
635747	634460	14225N	PRESIDENT	0	PRESENT	0
635748	634460	20252E	PARTICIPANT	\N	PRESENT	0
635749	634460	20070A	PARTICIPANT	\N	PRESENT	0
635750	634460	19349W	PARTICIPANT	\N	PRESENT	0
635751	634460	08010L	PARTICIPANT	\N	PRESENT	0
635752	634460	99004R	PARTICIPANT	\N	PRESENT	0
635753	634460	14253S	PARTICIPANT	\N	PRESENT	0
635754	634460	20116W	PARTICIPANT	\N	PRESENT	0
635755	634460	20126Y	PARTICIPANT	\N	PRESENT	0
635756	634460	19762G	PARTICIPANT	\N	PRESENT	0
642428	642402	11083R	PARTICIPANT	\N	PRESENT	0
642429	642406	14033T	PARTICIPANT	\N	PRESENT	0
642430	642406	19369B	PARTICIPANT	\N	PRESENT	0
642431	642406	20018V	PARTICIPANT	\N	PRESENT	0
642432	642035	20132W	PARTICIPANT	\N	PRESENT	0
642433	642035	20084G	PARTICIPANT	\N	PRESENT	0
642434	641818	19701S	PARTICIPANT	\N	PRESENT	0
642435	641818	19681G	PARTICIPANT	\N	PRESENT	0
642439	642011	14147R	PARTICIPANT	\N	PRESENT	0
642440	642011	95063L	PARTICIPANT	\N	PRESENT	0
642502	642501	11083R	PARTICIPANT	\N	PRESENT	1
642503	642501	14133K	PARTICIPANT	\N	PRESENT	1
642504	642501	11066Q	PARTICIPANT	\N	PRESENT	1
642505	642252	19383Y	PARTICIPANT	\N	PRESENT	0
642506	642252	19768N	PARTICIPANT	\N	PRESENT	1
642507	642252	20092G	PARTICIPANT	\N	PRESENT	1
642508	642252	01043Q	PARTICIPANT	\N	PRESENT	1
642509	642252	14357A	PARTICIPANT	\N	PRESENT	0
642510	642252	20078J	PARTICIPANT	\N	PRESENT	0
642511	642252	19441R	PARTICIPANT	\N	PRESENT	0
642512	642252	20082E	PARTICIPANT	\N	PRESENT	0
642513	642252	20104S	PARTICIPANT	\N	PRESENT	0
642514	642252	19631V	PARTICIPANT	\N	PRESENT	1
642515	642252	19575F	PARTICIPANT	\N	PRESENT	0
642516	642252	19369B	PARTICIPANT	\N	PRESENT	0
642517	642252	20018V	PARTICIPANT	\N	PRESENT	1
642518	642252	19563B	PARTICIPANT	\N	PRESENT	1
642519	642252	14038Y	PARTICIPANT	\N	PRESENT	1
642520	642252	20030R	PARTICIPANT	\N	PRESENT	1
642521	642252	20144B	PARTICIPANT	\N	PRESENT	0
642522	642252	11090Q	PRESIDENT	0	PRESENT	0
642523	642252	14033T	PARTICIPANT	\N	PRESENT	1
642524	642252	20174H	PARTICIPANT	\N	PRESENT	1
642525	642252	20062A	PARTICIPANT	\N	PRESENT	1
642526	642252	19507S	PARTICIPANT	\N	PRESENT	0
642527	642252	20286Q	PARTICIPANT	\N	PRESENT	1
642528	642252	19747H	PARTICIPANT	\N	PRESENT	0
642529	642252	14207L	PARTICIPANT	\N	PRESENT	0
642530	642252	14257W	PARTICIPANT	\N	PRESENT	0
642532	642531	14133K	PARTICIPANT	\N	PRESENT	0
642533	642531	14357A	PARTICIPANT	\N	PRESENT	0
642534	642531	11026G	PARTICIPANT	\N	PRESENT	0
642545	642185	14083S	PARTICIPANT	\N	PRESENT	0
642556	642555	14225N	PARTICIPANT	\N	PRESENT	0
642557	642555	01057W	PARTICIPANT	\N	PRESENT	0
642559	642558	08073C	PARTICIPANT	\N	PRESENT	0
642560	642558	20150Y	PARTICIPANT	\N	PRESENT	0
642562	642561	14327T	PARTICIPANT	\N	PRESENT	0
642564	642563	19479G	PARTICIPANT	\N	PRESENT	0
642566	642565	19575F	PARTICIPANT	\N	PRESENT	0
642567	642565	20116W	PARTICIPANT	\N	PRESENT	0
642568	642565	14083S	PARTICIPANT	\N	PRESENT	1
642569	642565	11053K	PARTICIPANT	\N	PRESENT	0
642570	642565	19251M	PARTICIPANT	\N	PRESENT	0
642571	642565	14179A	PARTICIPANT	\N	PRESENT	0
642572	642565	20056C	PARTICIPANT	\N	PRESENT	1
642573	642565	19349W	PARTICIPANT	\N	PRESENT	0
642574	642565	19671E	PARTICIPANT	\N	PRESENT	1
642575	642565	20044X	PARTICIPANT	\N	PRESENT	0
642576	641805	19415P	PARTICIPANT	\N	PRESENT	0
642577	641805	11067R	PARTICIPANT	\N	PRESENT	0
642578	641805	11097X	PARTICIPANT	\N	PRESENT	0
642579	641805	20090E	PARTICIPANT	\N	PRESENT	0
642580	641805	19760E	PARTICIPANT	\N	PRESENT	0
642581	641805	20130U	PARTICIPANT	\N	PRESENT	1
642582	641805	19798U	PARTICIPANT	\N	PRESENT	1
642584	641806	20090E	PARTICIPANT	\N	PRESENT	0
642621	642620	20124W	PARTICIPANT	\N	PRESENT	0
642586	641806	19415P	PARTICIPANT	\N	PRESENT	0
642587	641806	11067R	PARTICIPANT	\N	PRESENT	0
642588	641806	11097X	PARTICIPANT	\N	PRESENT	0
642589	641806	20130U	PARTICIPANT	\N	PRESENT	1
642618	642617	19575F	PARTICIPANT	\N	PRESENT	0
642619	642617	19715Y	PARTICIPANT	\N	PRESENT	0
642622	642620	19593H	PARTICIPANT	\N	PRESENT	0
642623	642620	20026V	PARTICIPANT	\N	PRESENT	0
642642	642641	11090Q	PARTICIPANT	\N	PRESENT	0
642643	642641	20286Q	PARTICIPANT	\N	PRESENT	0
642644	642641	14257W	PARTICIPANT	\N	PRESENT	0
642647	642645	20060X	PARTICIPANT	\N	PRESENT	0
642648	642645	14083S	PARTICIPANT	\N	PRESENT	0
642649	642645	20054A	PARTICIPANT	\N	PRESENT	0
642650	642645	16685X	PARTICIPANT	\N	PRESENT	0
642651	642646	20060X	PARTICIPANT	\N	PRESENT	0
642652	642646	14083S	PARTICIPANT	\N	PRESENT	0
642653	642646	20054A	PARTICIPANT	\N	PRESENT	0
642655	642654	14217N	PARTICIPANT	\N	PRESENT	0
642656	642654	20248J	PARTICIPANT	\N	PRESENT	0
642657	642654	11067R	PARTICIPANT	\N	PRESENT	0
642658	642654	20130U	PARTICIPANT	\N	PRESENT	0
642659	642005	18193Q	PARTICIPANT	\N	PRESENT	0
642660	642005	11097X	PARTICIPANT	\N	PRESENT	0
642661	642005	19760E	PARTICIPANT	\N	PRESENT	0
642662	642006	19760E	PARTICIPANT	\N	PRESENT	0
642663	642006	18193Q	PARTICIPANT	\N	PRESENT	0
642664	642006	11097X	PARTICIPANT	\N	PRESENT	0
642668	642007	19760E	PARTICIPANT	\N	PRESENT	0
642669	642007	18193Q	PARTICIPANT	\N	PRESENT	0
642670	642007	11097X	PARTICIPANT	\N	PRESENT	0
642672	642671	14225N	PARTICIPANT	\N	PRESENT	0
642673	642671	01057W	PARTICIPANT	\N	PRESENT	0
642674	642671	11048N	PARTICIPANT	\N	PRESENT	0
642676	642675	19479G	PARTICIPANT	\N	PRESENT	0
642679	642678	99004R	PARTICIPANT	\N	PRESENT	0
642680	642678	19399H	PARTICIPANT	\N	PRESENT	0
642682	642681	11053K	PARTICIPANT	\N	PRESENT	0
642769	642768	11027H	PARTICIPANT	\N	PRESENT	0
642770	642768	11083R	PARTICIPANT	\N	PRESENT	0
642771	642768	14133K	PARTICIPANT	\N	PRESENT	1
642772	642768	11066Q	PARTICIPANT	\N	PRESENT	0
642774	642773	11083R	PARTICIPANT	\N	PRESENT	0
642775	642773	14133K	PARTICIPANT	\N	PRESENT	0
642777	642776	11083R	PARTICIPANT	\N	PRESENT	0
642778	642776	14133K	PARTICIPANT	\N	PRESENT	0
642780	641563	19693L	PARTICIPANT	\N	PRESENT	0
642781	641563	19533U	PARTICIPANT	\N	PRESENT	0
642782	641563	19593H	PARTICIPANT	\N	PRESENT	0
642784	642783	19693L	PARTICIPANT	\N	PRESENT	0
642785	642783	19533U	PARTICIPANT	\N	PRESENT	0
642786	642783	19593H	PARTICIPANT	\N	PRESENT	0
642806	641800	14038Y	PARTICIPANT	\N	PRESENT	0
642807	641800	14083S	PARTICIPANT	\N	PRESENT	0
642808	641800	19533U	PARTICIPANT	\N	PRESENT	0
642809	641800	20026V	PARTICIPANT	\N	PRESENT	1
642810	641800	19333N	PARTICIPANT	\N	PRESENT	1
642811	641800	14257W	PARTICIPANT	\N	PRESENT	1
642812	641800	14205J	PARTICIPANT	\N	PRESENT	1
642813	641800	20140W	PARTICIPANT	\N	PRESENT	1
642814	641800	20056C	PARTICIPANT	\N	PRESENT	1
642815	641800	19798U	PARTICIPANT	\N	PRESENT	1
642816	641800	20032T	PARTICIPANT	\N	PRESENT	1
642817	641800	14169X	PARTICIPANT	\N	PRESENT	1
642818	641800	19701S	PARTICIPANT	\N	PRESENT	1
642844	638988	14179A	PARTICIPANT	\N	PRESENT	0
642848	642186	19701S	PARTICIPANT	\N	PRESENT	0
642849	642186	14331P	PARTICIPANT	\N	EXCUSE	0
642851	642850	19735D	PARTICIPANT	\N	EXCUSE	0
642852	642850	19723Y	PARTICIPANT	\N	EXCUSE	0
642853	642850	11067R	PARTICIPANT	\N	EXCUSE	0
642854	642850	04043D	PARTICIPANT	\N	PRESENT	0
642855	642850	20066E	PARTICIPANT	\N	PRESENT	0
642857	642850	20128B	PARTICIPANT	\N	PRESENT	0
642859	642850	01058X	PARTICIPANT	\N	PRESENT	0
642865	642850	19533U	PARTICIPANT	\N	EXCUSE	0
642866	642850	19503N	PARTICIPANT	\N	EXCUSE	0
642867	642850	01048V	PARTICIPANT	\N	EXCUSE	0
642879	642876	19479G	PARTICIPANT	\N	PRESENT	0
642880	642825	08011M	PARTICIPANT	\N	PRESENT	0
642881	642825	14253S	PARTICIPANT	\N	PRESENT	0
642883	642882	05008E	PARTICIPANT	\N	PRESENT	0
642884	642882	11053K	PARTICIPANT	\N	PRESENT	0
642885	642882	01028R	PARTICIPANT	\N	PRESENT	0
642887	642886	20086J	PARTICIPANT	\N	PRESENT	0
629316	629315	05008E	PARTICIPANT	\N	PRESENT	0
629317	629315	11053K	PARTICIPANT	\N	PRESENT	0
629318	629315	01028R	PARTICIPANT	\N	PRESENT	0
629320	629319	19553Y	PARTICIPANT	\N	PRESENT	0
629331	629330	19531S	PARTICIPANT	\N	PRESENT	0
630713	630700	08045X	PARTICIPANT	\N	PRESENT	0
630714	630700	18193Q	PARTICIPANT	\N	PRESENT	0
630715	630700	20130U	PARTICIPANT	\N	PRESENT	0
630813	630812	08045X	PARTICIPANT	\N	PRESENT	0
630814	630812	18193Q	PARTICIPANT	\N	PRESENT	0
630815	630812	17779H	PARTICIPANT	\N	PRESENT	0
630817	630812	20130U	PARTICIPANT	\N	PRESENT	0
630837	629431	11067R	PARTICIPANT	\N	PRESENT	0
630838	629432	11067R	PARTICIPANT	\N	PRESENT	0
631122	629325	14207L	PARTICIPANT	\N	PRESENT	0
631123	629325	04045F	PARTICIPANT	\N	PRESENT	0
631125	629325	19533U	PRESIDENT	0	PRESENT	0
631150	629325	20042V	PARTICIPANT	\N	PRESENT	1
631154	629325	20114U	PARTICIPANT	\N	PRESENT	0
631212	629325	19693L	PARTICIPANT	\N	PRESENT	0
631243	629325	19798U	PARTICIPANT	\N	PRESENT	1
631251	629325	20112S	PARTICIPANT	\N	EXCUSE	0
631593	631460	04047H	PARTICIPANT	\N	EXCUSE	0
631776	631775	08010L	PARTICIPANT	\N	PRESENT	0
634558	632752	19695N	PARTICIPANT	\N	PRESENT	0
634559	632752	19413M	PARTICIPANT	\N	PRESENT	0
634560	632752	20082E	PARTICIPANT	\N	PRESENT	0
634561	632752	19705W	PARTICIPANT	\N	PRESENT	1
634562	632752	19768N	PARTICIPANT	\N	PRESENT	0
634563	632752	14257W	PARTICIPANT	\N	PRESENT	0
634564	632752	19369B	PARTICIPANT	\N	PRESENT	0
634565	632752	20018V	PARTICIPANT	\N	PRESENT	0
634566	632752	20028X	PARTICIPANT	\N	PRESENT	0
634567	632752	11090Q	PRESIDENT	0	PRESENT	0
634568	632752	14251Q	PARTICIPANT	\N	PRESENT	0
634569	632752	19441R	PARTICIPANT	\N	PRESENT	0
634570	632752	14205J	PARTICIPANT	\N	PRESENT	0
634571	632752	01043Q	PARTICIPANT	\N	PRESENT	0
634572	632752	20034V	PARTICIPANT	\N	PRESENT	0
634573	632752	14033T	PARTICIPANT	\N	PRESENT	0
634574	632752	19747H	PARTICIPANT	\N	PRESENT	0
634575	632752	14357A	PARTICIPANT	\N	PRESENT	0
634576	632752	19515S	PARTICIPANT	\N	PRESENT	0
634577	632752	19707Y	PARTICIPANT	\N	PRESENT	1
634578	632752	19782L	PARTICIPANT	\N	PRESENT	0
634579	632752	20144B	PARTICIPANT	\N	PRESENT	0
634580	632752	19467C	PARTICIPANT	\N	PRESENT	0
634581	632752	14187A	PARTICIPANT	\N	PRESENT	0
634582	632752	20174H	PARTICIPANT	\N	PRESENT	1
634583	632752	20088L	PARTICIPANT	\N	PRESENT	1
634584	632752	14207L	PARTICIPANT	\N	EXCUSE	0
634585	632752	20104S	PARTICIPANT	\N	EXCUSE	0
634586	632752	20286Q	PARTICIPANT	\N	EXCUSE	0
634587	632752	20054A	PARTICIPANT	\N	EXCUSE	0
637105	627099	14189C	PARTICIPANT	\N	EXCUSE	0
637106	627099	14030Q	PRESIDENT	0	PRESENT	0
637107	627099	20080C	PARTICIPANT	\N	EXCUSE	0
637108	627099	19599P	PARTICIPANT	\N	PRESENT	0
637109	627099	14179A	PARTICIPANT	\N	PRESENT	1
637110	627099	19715Y	PARTICIPANT	\N	PRESENT	1
637111	627099	20130U	PARTICIPANT	\N	EXCUSE	0
637113	627099	19749K	PARTICIPANT	\N	PRESENT	0
637116	627099	20098N	PARTICIPANT	\N	PRESENT	1
637117	627099	07029T	PARTICIPANT	\N	PRESENT	0
637222	637221	19651A	PARTICIPANT	\N	PRESENT	0
637223	637221	19954N	PARTICIPANT	\N	PRESENT	0
637224	637221	20042V	PARTICIPANT	\N	PRESENT	0
637225	637221	11056N	PARTICIPANT	\N	PRESENT	0
637226	637221	14259Y	PARTICIPANT	\N	PRESENT	0
637228	637221	20132W	PARTICIPANT	\N	PRESENT	0
637229	637221	20068G	PARTICIPANT	\N	PRESENT	0
637231	637221	20050V	PARTICIPANT	\N	EXCUSE	0
637232	637221	95063L	PARTICIPANT	\N	PRESENT	0
637233	637221	20044X	PARTICIPANT	\N	PRESENT	0
637234	637221	11097X	PARTICIPANT	\N	PRESENT	0
637235	637221	19703U	PARTICIPANT	\N	PRESENT	0
637271	635658	19577H	PARTICIPANT	\N	PRESENT	0
637273	635658	19657G	PARTICIPANT	\N	PRESENT	0
638336	638335	20024T	PARTICIPANT	\N	PRESENT	0
638337	638335	19685L	PARTICIPANT	\N	PRESENT	0
638338	638335	20140W	PARTICIPANT	\N	PRESENT	0
638339	638335	20020P	PARTICIPANT	\N	PRESENT	0
638341	638340	20024T	PARTICIPANT	\N	PRESENT	0
638342	638340	20020P	PARTICIPANT	\N	PRESENT	0
638343	638340	20140W	PARTICIPANT	\N	PRESENT	0
638347	638346	19515S	PARTICIPANT	\N	PRESENT	0
638348	638346	20024T	PARTICIPANT	\N	PRESENT	0
638349	638346	20140W	PARTICIPANT	\N	PRESENT	0
638350	638346	19685L	PARTICIPANT	\N	PRESENT	0
638351	638346	20020P	PARTICIPANT	\N	PRESENT	0
638352	638346	20100N	PARTICIPANT	\N	PRESENT	0
638354	638353	19685L	PARTICIPANT	\N	PRESENT	0
638355	638353	20024T	PARTICIPANT	\N	PRESENT	0
638356	638353	20140W	PARTICIPANT	\N	PRESENT	0
638358	638357	19515S	PRESIDENT	0	PRESENT	0
638359	638357	20094J	PARTICIPANT	\N	PRESENT	0
638360	638357	19762G	PARTICIPANT	\N	PRESENT	0
638361	638357	16685X	PARTICIPANT	\N	PRESENT	0
638490	638376	11031D	PARTICIPANT	\N	PRESENT	0
638491	638376	10006L	PARTICIPANT	\N	PRESENT	0
638492	638376	08045X	PARTICIPANT	\N	PRESENT	0
638493	638376	19301E	PARTICIPANT	\N	PRESENT	0
638494	638375	10006L	PARTICIPANT	\N	PRESENT	0
638495	638375	11031D	PARTICIPANT	\N	PRESENT	0
638496	638375	19301E	PARTICIPANT	\N	PRESENT	0
638497	638375	08045X	PARTICIPANT	\N	PRESENT	0
638673	638463	14331P	PARTICIPANT	\N	PRESENT	0
638674	638463	14111D	PARTICIPANT	\N	PRESENT	0
638675	638463	19711U	PARTICIPANT	\N	PRESENT	0
638676	638463	20074E	PARTICIPANT	\N	PRESENT	0
638677	638463	10015M	PARTICIPANT	\N	PRESENT	0
638678	638463	11026G	PARTICIPANT	\N	PRESENT	0
638679	638463	19441R	PARTICIPANT	\N	PRESENT	0
638680	638463	19543W	PARTICIPANT	\N	PRESENT	0
638681	638463	04047H	PRESIDENT	0	PRESENT	0
638682	638463	19673G	PARTICIPANT	\N	PRESENT	0
638684	638463	20104S	PARTICIPANT	\N	PRESENT	0
638685	638463	05008E	PARTICIPANT	\N	PRESENT	0
638686	638463	19725B	PARTICIPANT	\N	PRESENT	0
638687	638463	05012A	PARTICIPANT	\N	PRESENT	0
638688	638463	95063L	PARTICIPANT	\N	PRESENT	0
638689	638463	07004J	PARTICIPANT	\N	PRESENT	0
638690	638463	14021P	PARTICIPANT	\N	PRESENT	0
638708	638463	01028R	PARTICIPANT	\N	PRESENT	0
642192	642191	08073C	PARTICIPANT	\N	PRESENT	0
642193	642191	20150Y	PARTICIPANT	\N	PRESENT	0
642195	642194	08073C	PARTICIPANT	\N	PRESENT	0
642196	642194	20150Y	PARTICIPANT	\N	PRESENT	0
642198	642197	14327T	PARTICIPANT	\N	PRESENT	0
642201	642199	20086J	PARTICIPANT	\N	PRESENT	0
642211	642210	20086J	PARTICIPANT	\N	PRESENT	0
642213	642212	19741B	PARTICIPANT	\N	PRESENT	0
642218	642217	11053K	PARTICIPANT	\N	PRESENT	0
642220	642219	11053K	PARTICIPANT	\N	PRESENT	0
642222	642221	11053K	PARTICIPANT	\N	PRESENT	0
642250	642249	99004R	PARTICIPANT	\N	PRESENT	0
642251	642249	19399H	PARTICIPANT	\N	PRESENT	0
642665	642186	19691J	PARTICIPANT	\N	EXCUSE	0
642666	642186	20034V	PARTICIPANT	\N	EXCUSE	0
642667	642186	14059S	PARTICIPANT	\N	EXCUSE	0
643289	643288	19643A	PARTICIPANT	\N	PRESENT	0
643290	643288	14038Y	PARTICIPANT	\N	EXCUSE	0
643291	643288	11056N	PARTICIPANT	\N	PRESENT	0
643292	643288	20068G	PARTICIPANT	\N	PRESENT	0
643293	643288	19399H	PARTICIPANT	\N	EXCUSE	0
643294	643288	99004R	PARTICIPANT	\N	PRESENT	0
643295	643288	19711U	PARTICIPANT	\N	PRESENT	0
643296	643288	04070G	PARTICIPANT	\N	EXCUSE	0
643297	643288	20050V	PARTICIPANT	\N	EXCUSE	0
643298	643288	14193X	PARTICIPANT	\N	EXCUSE	0
643299	643288	95063L	PARTICIPANT	\N	PRESENT	0
643300	643288	14259Y	PARTICIPANT	\N	EXCUSE	0
643301	643288	20044X	PARTICIPANT	\N	PRESENT	0
643302	643288	11097X	PARTICIPANT	\N	PRESENT	0
643303	643288	01028R	PARTICIPANT	\N	EXCUSE	0
643304	643288	19479G	PARTICIPANT	\N	PRESENT	0
643307	642878	11090Q	PARTICIPANT	\N	PRESENT	0
643308	642878	14033T	PARTICIPANT	\N	PRESENT	0
643309	642878	20286Q	PARTICIPANT	\N	PRESENT	0
643310	642878	19515S	PARTICIPANT	\N	PRESENT	0
643311	642878	20144B	PARTICIPANT	\N	PRESENT	0
653841	652898	08015R	PARTICIPANT	\N	PRESENT	0
653842	652898	08061X	PARTICIPANT	\N	PRESENT	0
653843	652898	08034U	PARTICIPANT	\N	PRESENT	0
653844	652898	19349W	PARTICIPANT	\N	PRESENT	0
653845	652898	19611R	PARTICIPANT	\N	PRESENT	0
653846	652898	14211G	PARTICIPANT	\N	PRESENT	0
653847	652898	20054A	PARTICIPANT	\N	PRESENT	0
653848	652898	08009T	PARTICIPANT	\N	PRESENT	0
653849	652898	11048N	PARTICIPANT	\N	PRESENT	0
653850	652898	14225N	PARTICIPANT	\N	PRESENT	0
653851	652898	19679N	PARTICIPANT	\N	PRESENT	0
653852	652898	19619A	PARTICIPANT	\N	PRESENT	0
653853	652898	19479G	PARTICIPANT	\N	PRESENT	0
653854	652898	19335Q	PARTICIPANT	\N	PRESENT	0
653855	652898	19671E	PARTICIPANT	\N	PRESENT	0
653856	652898	14089Y	PARTICIPANT	\N	PRESENT	0
653857	652898	19711U	PARTICIPANT	\N	PRESENT	0
653858	652898	01057W	PARTICIPANT	\N	PRESENT	0
653859	652898	20136B	PARTICIPANT	\N	PRESENT	0
653860	652898	08045X	PARTICIPANT	\N	PRESENT	0
653861	652898	20038A	PARTICIPANT	\N	PRESENT	0
653862	652898	20034V	PARTICIPANT	\N	PRESENT	0
653863	652898	20044X	PARTICIPANT	\N	PRESENT	0
653864	652898	14083S	PARTICIPANT	\N	PRESENT	0
653865	652898	14173T	PARTICIPANT	\N	PRESENT	0
653866	652898	19367Y	PARTICIPANT	\N	PRESENT	0
653867	652898	20134Y	PARTICIPANT	\N	PRESENT	0
653868	652898	04059M	PARTICIPANT	\N	PRESENT	0
653869	652898	20058E	PARTICIPANT	\N	PRESENT	0
653870	652898	20030R	PARTICIPANT	\N	PRESENT	0
653871	652898	05012A	PARTICIPANT	\N	PRESENT	0
653872	652898	20152B	PARTICIPANT	\N	PRESENT	0
653873	652898	19531S	PARTICIPANT	\N	PRESENT	0
653874	652898	20072C	PARTICIPANT	\N	PRESENT	0
653875	652898	20140W	PARTICIPANT	\N	PRESENT	0
653876	652898	20264J	PARTICIPANT	\N	PRESENT	0
653877	652898	01028R	PARTICIPANT	\N	PRESENT	0
653878	652898	20026V	PARTICIPANT	\N	PRESENT	0
653879	652898	20098N	PARTICIPANT	\N	PRESENT	0
653880	652898	19413M	PARTICIPANT	\N	PRESENT	0
653881	652898	19447X	PARTICIPANT	\N	PRESENT	0
653839	652898	19782L	PARTICIPANT	\N	PRESENT	0
653840	652898	14187A	PARTICIPANT	\N	PRESENT	0
653882	652898	20114U	PARTICIPANT	\N	PRESENT	0
653883	652898	20028X	PARTICIPANT	\N	PRESENT	0
653884	652898	20070A	PARTICIPANT	\N	PRESENT	0
653885	652898	20022R	PARTICIPANT	\N	PRESENT	0
653886	652898	14073Q	PARTICIPANT	\N	PRESENT	0
653887	652898	14109K	PARTICIPANT	\N	PRESENT	0
653888	652898	20126Y	PARTICIPANT	\N	PRESENT	0
653889	652898	20124W	PARTICIPANT	\N	PRESENT	0
653890	652898	14151M	PARTICIPANT	\N	PRESENT	0
653891	652898	11056N	PARTICIPANT	\N	PRESENT	0
653892	652898	11074Q	PARTICIPANT	\N	PRESENT	0
653893	652898	95041E	PARTICIPANT	\N	PRESENT	0
653894	652898	20094J	PARTICIPANT	\N	PRESENT	0
653895	652898	01043Q	PARTICIPANT	\N	PRESENT	0
653896	652898	11085T	PARTICIPANT	\N	PRESENT	0
653897	652898	07004J	PARTICIPANT	\N	PRESENT	0
653898	652898	19347U	PARTICIPANT	\N	PRESENT	0
653899	652898	20120S	PARTICIPANT	\N	PRESENT	0
653900	652898	19739H	PARTICIPANT	\N	PRESENT	0
653901	652898	20266L	PARTICIPANT	\N	PRESENT	0
653902	652898	11026G	PARTICIPANT	\N	PRESENT	0
654534	652904	19387D	PARTICIPANT	\N	PRESENT	0
654535	652904	14259Y	PARTICIPANT	\N	PRESENT	0
654536	652904	14255U	PARTICIPANT	\N	PRESENT	0
654537	652904	20022R	PARTICIPANT	\N	PRESENT	0
654538	652904	19525U	PARTICIPANT	\N	PRESENT	0
654539	652904	20286Q	PARTICIPANT	\N	PRESENT	0
654540	652904	19768N	PARTICIPANT	\N	PRESENT	0
654532	652904	14042U	PARTICIPANT	\N	PRESENT	0
654533	652904	20098N	PARTICIPANT	\N	PRESENT	0
654541	652904	11056N	PARTICIPANT	\N	PRESENT	0
654542	652904	20026V	PARTICIPANT	\N	PRESENT	0
654543	652904	20024T	PARTICIPANT	\N	PRESENT	0
654544	652904	20056C	PARTICIPANT	\N	PRESENT	0
654545	652904	20058E	PARTICIPANT	\N	PRESENT	0
654546	652904	20052X	PARTICIPANT	\N	PRESENT	0
654547	652904	20126Y	PARTICIPANT	\N	PRESENT	0
654548	652904	20124W	PARTICIPANT	\N	PRESENT	0
654549	652904	20152B	PARTICIPANT	\N	PRESENT	0
654550	652904	19766L	PARTICIPANT	\N	PRESENT	0
654551	652904	19441R	PARTICIPANT	\N	PRESENT	0
654552	652904	14073Q	PARTICIPANT	\N	PRESENT	0
654553	652904	11085T	PARTICIPANT	\N	PRESENT	0
654554	652904	20136B	PARTICIPANT	\N	PRESENT	0
654555	652904	20106U	PARTICIPANT	\N	PRESENT	0
654556	652904	14038Y	PARTICIPANT	\N	PRESENT	0
654557	652904	18193Q	PARTICIPANT	\N	PRESENT	0
654558	652904	20108W	PARTICIPANT	\N	PRESENT	0
654559	652904	19369B	PARTICIPANT	\N	PRESENT	0
654560	652904	04071H	PARTICIPANT	\N	PRESENT	0
654561	652904	20114U	PARTICIPANT	\N	PRESENT	0
654562	652904	04035D	PARTICIPANT	\N	PRESENT	0
654563	652904	95041E	PARTICIPANT	\N	PRESENT	0
654564	652904	14069U	PARTICIPANT	\N	PRESENT	0
654565	652904	05012A	PARTICIPANT	\N	PRESENT	0
654566	652904	19643A	PARTICIPANT	\N	PRESENT	0
654567	652904	14179A	PARTICIPANT	\N	PRESENT	0
654568	652904	04085P	PARTICIPANT	\N	PRESENT	0
654586	654585	19667J	PARTICIPANT	\N	PRESENT	0
654587	654585	11040E	PARTICIPANT	\N	PRESENT	0
654588	654585	20914V	PARTICIPANT	\N	PRESENT	0
654589	654585	20080C	PARTICIPANT	\N	PRESENT	0
654590	654585	19647E	PARTICIPANT	\N	PRESENT	0
654591	654585	11048N	PARTICIPANT	\N	PRESENT	0
654592	654585	19531S	PARTICIPANT	\N	PRESENT	0
654593	654585	99004R	PARTICIPANT	\N	PRESENT	0
654594	654585	07029T	PARTICIPANT	\N	PRESENT	0
654595	654585	19711U	PARTICIPANT	\N	PRESENT	0
654596	654585	08010L	PARTICIPANT	\N	PRESENT	0
654597	654585	08034U	PARTICIPANT	\N	PRESENT	0
654598	654585	20252E	PARTICIPANT	\N	PRESENT	0
654599	654585	20036X	PARTICIPANT	\N	PRESENT	0
654600	654585	19349W	PARTICIPANT	\N	PRESENT	0
654601	654585	14225N	PRESIDENT	0	PRESENT	0
654602	654585	20150Y	PARTICIPANT	\N	PRESENT	0
654603	654585	20044X	PARTICIPANT	\N	PRESENT	0
654604	654585	19687N	PARTICIPANT	\N	PRESENT	0
654605	654585	19479G	PARTICIPANT	\N	PRESENT	0
654606	654585	14173T	PARTICIPANT	\N	PRESENT	0
654607	654300	20088L	PARTICIPANT	\N	PRESENT	0
654608	654300	19768N	PARTICIPANT	\N	PRESENT	0
654609	654300	19782L	PARTICIPANT	\N	PRESENT	0
654610	654300	20092G	PARTICIPANT	\N	PRESENT	0
654611	654300	01043Q	PARTICIPANT	\N	PRESENT	0
654612	654300	14357A	PARTICIPANT	\N	PRESENT	0
654613	654300	19441R	PARTICIPANT	\N	PRESENT	0
654614	654300	19413M	PARTICIPANT	\N	PRESENT	0
654615	654300	20094J	PARTICIPANT	\N	PRESENT	0
654616	654300	04045F	PARTICIPANT	\N	PRESENT	0
654617	654300	20104S	PARTICIPANT	\N	PRESENT	0
654618	654300	11099A	PARTICIPANT	\N	PRESENT	0
654619	654300	19705W	PARTICIPANT	\N	PRESENT	0
654620	654300	19707Y	PARTICIPANT	\N	PRESENT	1
654621	654300	08015R	PARTICIPANT	\N	PRESENT	0
654622	654300	19575F	PARTICIPANT	\N	PRESENT	0
654623	654300	19369B	PARTICIPANT	\N	PRESENT	0
654624	654300	20018V	PARTICIPANT	\N	PRESENT	0
654625	654300	19563B	PARTICIPANT	\N	PRESENT	0
654626	654300	14329V	PARTICIPANT	\N	PRESENT	0
654627	654300	14037X	PARTICIPANT	\N	PRESENT	0
654628	654300	20028X	PARTICIPANT	\N	PRESENT	0
654629	654300	14038Y	PARTICIPANT	\N	PRESENT	0
654630	654300	20030R	PARTICIPANT	\N	PRESENT	1
654631	654300	19467C	PARTICIPANT	\N	PRESENT	0
654632	654300	20034V	PARTICIPANT	\N	PRESENT	0
654633	654300	14187A	PARTICIPANT	\N	PRESENT	0
654634	654300	20144B	PARTICIPANT	\N	PRESENT	0
654635	654300	11090Q	PRESIDENT	0	PRESENT	0
654636	654300	14033T	PARTICIPANT	\N	PRESENT	0
654637	654300	20054A	PARTICIPANT	\N	PRESENT	0
654638	654300	14205J	PARTICIPANT	\N	PRESENT	0
654639	654300	20062A	PARTICIPANT	\N	PRESENT	0
654640	654300	14251Q	PARTICIPANT	\N	PRESENT	0
654641	654300	20286Q	PARTICIPANT	\N	PRESENT	0
654642	654300	14207L	PARTICIPANT	\N	PRESENT	1
654643	654300	14257W	PARTICIPANT	\N	PRESENT	0
654644	654299	14038Y	PARTICIPANT	\N	PRESENT	0
654645	654299	19467C	PARTICIPANT	\N	PRESENT	0
654646	654299	20034V	PARTICIPANT	\N	PRESENT	0
631461	629328	04085P	PARTICIPANT	\N	PRESENT	0
631462	629328	19667J	PARTICIPANT	\N	PRESENT	0
631463	629328	17737W	PARTICIPANT	\N	PRESENT	0
631479	629328	19531S	PARTICIPANT	\N	PRESENT	1
631481	629328	20038A	PARTICIPANT	\N	PRESENT	0
631483	629328	14257W	PARTICIPANT	\N	PRESENT	0
631485	629328	19711U	PARTICIPANT	\N	PRESENT	1
631675	631674	19515S	PARTICIPANT	\N	PRESENT	0
631676	631674	20140W	PARTICIPANT	\N	PRESENT	0
631677	631674	20074E	PARTICIPANT	\N	PRESENT	0
631678	631674	14097Y	PARTICIPANT	\N	PRESENT	0
631679	631674	20126Y	PARTICIPANT	\N	PRESENT	0
631680	631674	11077T	PARTICIPANT	\N	PRESENT	0
631681	631674	20050V	PARTICIPANT	\N	PRESENT	0
631682	631674	20082E	PARTICIPANT	\N	PRESENT	0
631684	631683	19515S	PARTICIPANT	\N	PRESENT	0
631691	631689	19663E	PARTICIPANT	\N	PRESENT	0
631692	631689	19691J	PARTICIPANT	\N	PRESENT	0
631693	631690	19663E	PARTICIPANT	\N	PRESENT	0
631694	631690	19691J	PARTICIPANT	\N	PRESENT	0
631695	631690	19723Y	PARTICIPANT	\N	PRESENT	0
631696	631690	19798U	PARTICIPANT	\N	PRESENT	0
631698	631697	19663E	PARTICIPANT	\N	PRESENT	0
631699	631697	14213J	PARTICIPANT	\N	PRESENT	0
631700	631697	19723Y	PARTICIPANT	\N	PRESENT	0
631701	631697	17965H	PARTICIPANT	\N	PRESENT	0
634935	634432	04043D	PARTICIPANT	\N	PRESENT	0
634936	634432	18193Q	PARTICIPANT	\N	PRESENT	0
634937	634432	19367Y	PARTICIPANT	\N	PRESENT	0
634939	634432	20248J	PARTICIPANT	\N	EXCUSE	0
634940	634432	20040T	PARTICIPANT	\N	EXCUSE	0
634947	634432	14217N	PARTICIPANT	\N	PRESENT	0
634948	634432	14042U	PARTICIPANT	\N	PRESENT	0
634959	634432	11031D	PARTICIPANT	\N	PRESENT	1
634961	634432	19723Y	PARTICIPANT	\N	PRESENT	0
634964	634432	14213J	PARTICIPANT	\N	PRESENT	0
634966	634432	19760E	PARTICIPANT	\N	PRESENT	1
634968	634432	19663E	PARTICIPANT	\N	PRESENT	0
634979	634432	19697Q	PARTICIPANT	\N	PRESENT	1
635101	633733	14189C	PARTICIPANT	\N	PRESENT	0
635102	633733	14089Y	PARTICIPANT	\N	PRESENT	0
635103	633733	19701S	PARTICIPANT	\N	PRESENT	0
635106	633733	14026U	PARTICIPANT	\N	PRESENT	0
635107	633733	20128B	PARTICIPANT	\N	PRESENT	1
635109	633733	14097Y	PARTICIPANT	\N	PRESENT	0
635111	633733	19711U	PARTICIPANT	\N	PRESENT	0
635112	633733	11026G	PARTICIPANT	\N	PRESENT	1
635113	633733	19441R	PARTICIPANT	\N	PRESENT	0
635115	633733	14237S	PARTICIPANT	\N	PRESENT	0
635117	633733	14331P	PRESIDENT	0	PRESENT	0
635118	633733	10015M	PARTICIPANT	\N	PRESENT	0
635119	633733	04045F	PARTICIPANT	\N	PRESENT	1
635137	633733	20024T	PARTICIPANT	\N	PRESENT	0
635138	633733	20040T	PARTICIPANT	\N	PRESENT	0
635139	633733	20108W	PARTICIPANT	\N	PRESENT	0
635140	633733	95063L	PARTICIPANT	\N	PRESENT	0
635142	633733	11056N	PARTICIPANT	\N	PRESENT	0
635181	635180	19717B	PARTICIPANT	\N	EXCUSE	0
635183	635180	20104S	PRESIDENT	0	PRESENT	0
635184	635180	14083S	PARTICIPANT	\N	PRESENT	1
635185	635180	20150Y	PARTICIPANT	\N	PRESENT	1
635186	635180	20102Q	PARTICIPANT	\N	PRESENT	0
635187	635180	11064N	PARTICIPANT	\N	PRESENT	1
635188	635180	14031R	PARTICIPANT	\N	PRESENT	0
635189	635180	19447X	PARTICIPANT	\N	PRESENT	1
635190	635180	19503N	PARTICIPANT	\N	PRESENT	0
635301	635180	20100N	PARTICIPANT	\N	PRESENT	0
635769	631793	19333N	PARTICIPANT	\N	PRESENT	0
635780	634460	08034U	PARTICIPANT	\N	PRESENT	0
635781	634460	07029T	PARTICIPANT	\N	PRESENT	0
635783	631793	19251M	PARTICIPANT	\N	PRESENT	0
635832	634460	01048V	PARTICIPANT	\N	PRESENT	0
635833	634460	19647E	PARTICIPANT	\N	PRESENT	0
635834	634460	11012A	PARTICIPANT	\N	PRESENT	0
635835	634460	19741B	PARTICIPANT	\N	PRESENT	0
635836	634460	20050V	PARTICIPANT	\N	EXCUSE	0
635837	634460	19671E	PARTICIPANT	\N	EXCUSE	0
635859	634330	19543W	PARTICIPANT	\N	PRESENT	0
635860	634330	07004J	PARTICIPANT	\N	PRESENT	0
635861	634330	20114U	PARTICIPANT	\N	PRESENT	0
635862	634330	11056N	PARTICIPANT	\N	PRESENT	0
635896	634331	20074E	PARTICIPANT	\N	PRESENT	0
635897	634331	20108W	PARTICIPANT	\N	PRESENT	0
635898	634331	10015M	PARTICIPANT	\N	PRESENT	0
635899	634331	14147R	PARTICIPANT	\N	PRESENT	0
635900	634331	14215L	PARTICIPANT	\N	PRESENT	0
635901	634331	04047H	PRESIDENT	0	PRESENT	0
635902	634331	20022R	PARTICIPANT	\N	PRESENT	0
635903	634331	19749K	PARTICIPANT	\N	PRESENT	0
635904	634331	19447X	PARTICIPANT	\N	PRESENT	0
635905	634331	05008E	PARTICIPANT	\N	PRESENT	0
635908	634654	14147R	PARTICIPANT	\N	PRESENT	0
635909	634654	14073Q	PARTICIPANT	\N	PRESENT	0
635910	634654	14223L	PARTICIPANT	\N	PRESENT	0
635911	634654	20068G	PARTICIPANT	\N	PRESENT	0
635912	634654	19413M	PARTICIPANT	\N	PRESENT	0
635913	634654	19866P	PARTICIPANT	\N	PRESENT	0
635914	634654	20108W	PARTICIPANT	\N	PRESENT	0
635915	634654	11101A	PARTICIPANT	\N	PRESENT	0
635916	634654	14331P	PARTICIPANT	\N	PRESENT	0
635917	634654	20024T	PARTICIPANT	\N	PRESENT	0
635918	634654	17229F	PARTICIPANT	\N	PRESENT	0
635919	634654	99004R	PARTICIPANT	\N	PRESENT	0
635920	634654	19691J	PARTICIPANT	\N	PRESENT	0
635921	634654	14189C	PARTICIPANT	\N	PRESENT	0
635922	634654	19719D	PARTICIPANT	\N	PRESENT	0
635923	634654	14193X	PARTICIPANT	\N	PRESENT	0
635924	634654	19583F	PARTICIPANT	\N	PRESENT	0
635925	634654	07033P	PARTICIPANT	\N	PRESENT	0
635926	634654	20046A	PARTICIPANT	\N	PRESENT	0
635927	634654	20248J	PARTICIPANT	\N	PRESENT	0
635928	634654	19683J	PARTICIPANT	\N	PRESENT	0
635929	634654	11027H	PARTICIPANT	\N	PRESENT	0
635930	634654	19577H	PARTICIPANT	\N	PRESENT	0
635931	634654	19621T	PARTICIPANT	\N	PRESENT	0
635932	634654	20138D	PARTICIPANT	\N	PRESENT	0
635933	634654	07029T	PARTICIPANT	\N	PRESENT	0
635934	634654	19798U	PARTICIPANT	\N	PRESENT	0
635935	634654	08028W	PARTICIPANT	\N	PRESENT	0
635936	634654	14217N	PARTICIPANT	\N	PRESENT	0
635937	634654	20026V	PARTICIPANT	\N	PRESENT	0
635938	634654	20056C	PARTICIPANT	\N	PRESENT	0
635939	634654	20298U	PARTICIPANT	\N	PRESENT	0
635940	634654	19569H	PARTICIPANT	\N	PRESENT	0
635941	634654	19367Y	PARTICIPANT	\N	PRESENT	0
635942	634654	19443T	PARTICIPANT	\N	PRESENT	0
635943	634654	20072C	PARTICIPANT	\N	PRESENT	0
635944	634654	19479G	PARTICIPANT	\N	PRESENT	0
635945	634654	19705W	PARTICIPANT	\N	PRESENT	0
635946	634654	20132W	PARTICIPANT	\N	PRESENT	0
635947	634654	19347U	PARTICIPANT	\N	PRESENT	0
635948	634654	01028R	PARTICIPANT	\N	PRESENT	0
635949	634654	19333N	PARTICIPANT	\N	PRESENT	0
635950	634654	12028B	PARTICIPANT	\N	PRESENT	0
635951	634654	11066Q	PARTICIPANT	\N	PRESENT	0
635952	634654	19349W	PARTICIPANT	\N	PRESENT	0
635953	634654	01025N	PARTICIPANT	\N	PRESENT	0
635954	634654	19713W	PARTICIPANT	\N	PRESENT	0
635955	634654	10015M	PARTICIPANT	\N	PRESENT	0
635956	634654	11043H	PARTICIPANT	\N	PRESENT	0
635957	634654	11010L	PARTICIPANT	\N	PRESENT	0
635958	634654	19820Y	PARTICIPANT	\N	PRESENT	0
635959	634654	19387D	PARTICIPANT	\N	PRESENT	0
635960	634654	19721W	PARTICIPANT	\N	PRESENT	0
635961	634654	20106U	PARTICIPANT	\N	PRESENT	0
635962	634654	01043Q	PARTICIPANT	\N	PRESENT	0
635963	634654	04045F	PARTICIPANT	\N	PRESENT	0
635964	634654	19619A	PARTICIPANT	\N	PRESENT	0
635965	634654	04047H	PARTICIPANT	\N	PRESENT	0
635966	634654	19703U	PARTICIPANT	\N	PRESENT	0
635967	634654	19699S	PARTICIPANT	\N	PRESENT	0
635968	634654	20152B	PARTICIPANT	\N	PRESENT	0
635969	634654	97011G	PARTICIPANT	\N	PRESENT	0
635970	634654	14033T	PARTICIPANT	\N	PRESENT	0
635971	634654	19467C	PARTICIPANT	\N	PRESENT	0
635972	634654	14038Y	PARTICIPANT	\N	PRESENT	0
635973	634654	14225N	PARTICIPANT	\N	PRESENT	0
635974	634654	19649G	PARTICIPANT	\N	PRESENT	0
635975	634654	11104D	PARTICIPANT	\N	PRESENT	0
635976	634654	14121F	PARTICIPANT	\N	PRESENT	0
635977	634654	19637C	PARTICIPANT	\N	PRESENT	0
642888	642683	14189C	PARTICIPANT	\N	EXCUSE	0
642889	642683	20024T	PARTICIPANT	\N	PRESENT	0
642890	642683	14030Q	PRESIDENT	0	PRESENT	0
642891	642683	20080C	PARTICIPANT	\N	EXCUSE	0
642892	642683	20066E	PARTICIPANT	\N	EXCUSE	0
642893	642683	07029T	PARTICIPANT	\N	EXCUSE	0
642894	642683	20118Y	PARTICIPANT	\N	EXCUSE	0
642895	642683	20098N	PARTICIPANT	\N	EXCUSE	0
642896	642683	20138D	PARTICIPANT	\N	PRESENT	1
642897	642683	19527W	PARTICIPANT	\N	PRESENT	1
642898	642683	19749K	PARTICIPANT	\N	PRESENT	1
642899	642683	19715Y	PARTICIPANT	\N	PRESENT	1
642900	642683	19693L	PARTICIPANT	\N	PRESENT	0
642901	642683	19798U	PARTICIPANT	\N	PRESENT	1
642971	642186	14213J	PARTICIPANT	\N	PRESENT	1
642924	642186	19717B	PARTICIPANT	\N	PRESENT	1
642940	642186	20146D	PARTICIPANT	\N	PRESENT	0
642972	642186	19387D	PARTICIPANT	\N	PRESENT	1
642983	642186	01024M	PARTICIPANT	\N	PRESENT	1
643070	642869	18083K	PARTICIPANT	\N	PRESENT	0
642944	642186	18083K	PARTICIPANT	\N	PRESENT	0
643071	642869	19333N	PARTICIPANT	\N	PRESENT	0
643072	642869	19701S	PARTICIPANT	\N	PRESENT	0
643073	642869	20068G	PARTICIPANT	\N	PRESENT	0
643074	642869	14031R	PRESIDENT	0	PRESENT	0
643075	642869	20038A	PARTICIPANT	\N	PRESENT	0
643076	642869	20076G	PARTICIPANT	\N	PRESENT	0
643077	642869	19503N	PARTICIPANT	\N	PRESENT	0
642952	642186	19347U	PARTICIPANT	\N	PRESENT	1
643078	642869	19685L	PARTICIPANT	\N	PRESENT	0
642954	642186	14097Y	PARTICIPANT	\N	PRESENT	1
643079	642869	19599P	PARTICIPANT	\N	PRESENT	0
643080	642869	20024T	PARTICIPANT	\N	PRESENT	0
643081	642869	14169X	PARTICIPANT	\N	PRESENT	0
643140	643139	18083K	PARTICIPANT	\N	PRESENT	0
642959	642186	19657G	PARTICIPANT	\N	PRESENT	0
642960	642186	14147R	PARTICIPANT	\N	PRESENT	1
643141	643139	14257W	PARTICIPANT	\N	PRESENT	0
643142	643139	19467C	PARTICIPANT	\N	PRESENT	0
642963	642186	20148F	PARTICIPANT	\N	PRESENT	1
642964	642186	19319Q	PARTICIPANT	\N	PRESENT	0
643143	643139	19745F	PARTICIPANT	\N	PRESENT	0
643164	643139	19333N	PARTICIPANT	\N	PRESENT	0
643165	643139	20090E	PARTICIPANT	\N	PRESENT	0
643166	643139	20032T	PARTICIPANT	\N	PRESENT	0
643167	643139	20066E	PARTICIPANT	\N	PRESENT	0
643168	643139	20062A	PARTICIPANT	\N	PRESENT	0
643169	643139	20038A	PARTICIPANT	\N	PRESENT	0
643170	643139	19667J	PARTICIPANT	\N	PRESENT	0
643246	643245	14033T	PARTICIPANT	\N	PRESENT	0
643247	643245	20018V	PARTICIPANT	\N	PRESENT	0
643248	643245	20062A	PARTICIPANT	\N	PRESENT	0
643249	643245	20034V	PARTICIPANT	\N	PRESENT	0
643251	643250	20066E	PARTICIPANT	\N	PRESENT	0
643252	643250	19735D	PARTICIPANT	\N	PRESENT	0
643253	643250	19723Y	PARTICIPANT	\N	PRESENT	0
643254	643250	11067R	PARTICIPANT	\N	EXCUSE	0
643255	643250	19533U	PARTICIPANT	\N	PRESENT	0
643256	643250	19503N	PARTICIPANT	\N	EXCUSE	0
643257	643250	04043D	PARTICIPANT	\N	PRESENT	0
643258	643250	20096L	PARTICIPANT	\N	PRESENT	0
643279	643278	14083S	PRESIDENT	0	PRESENT	0
643280	643278	19333N	PARTICIPANT	\N	PRESENT	0
643281	643278	20150Y	PARTICIPANT	\N	PRESENT	0
643282	643278	19447X	PARTICIPANT	\N	EXCUSE	0
643283	643278	20034V	PARTICIPANT	\N	PRESENT	0
643284	643278	19717B	PARTICIPANT	\N	EXCUSE	0
643286	643278	19503N	PARTICIPANT	\N	PRESENT	0
643321	643320	19954N	PARTICIPANT	\N	PRESENT	0
643322	643320	11056N	PARTICIPANT	\N	PRESENT	0
643323	643320	95063L	PARTICIPANT	\N	PRESENT	0
643325	643324	19954N	PARTICIPANT	\N	PRESENT	0
643326	643324	11056N	PARTICIPANT	\N	PRESENT	0
643327	643324	95063L	PARTICIPANT	\N	PRESENT	0
643329	643328	19954N	PARTICIPANT	\N	PRESENT	0
643330	643328	11056N	PARTICIPANT	\N	PRESENT	0
643331	643328	95063L	PARTICIPANT	\N	PRESENT	0
643391	642864	14331P	PARTICIPANT	\N	EXCUSE	0
643477	643476	14217N	PARTICIPANT	\N	PRESENT	0
643478	643476	20248J	PARTICIPANT	\N	PRESENT	0
643479	643476	11067R	PARTICIPANT	\N	PRESENT	0
643480	643476	20130U	PARTICIPANT	\N	PRESENT	0
643481	643475	14217N	PARTICIPANT	\N	PRESENT	0
643482	643475	20248J	PARTICIPANT	\N	PRESENT	0
643483	643475	11067R	PARTICIPANT	\N	PRESENT	0
643484	643475	20130U	PARTICIPANT	\N	PRESENT	0
643485	643445	04070G	PARTICIPANT	\N	EXCUSE	0
643486	643445	20048C	PARTICIPANT	\N	PRESENT	0
643487	643445	20084G	PARTICIPANT	\N	PRESENT	1
643488	643445	19719D	PARTICIPANT	\N	PRESENT	0
643489	643445	20026V	PARTICIPANT	\N	PRESENT	1
643490	643445	19693L	PARTICIPANT	\N	PRESENT	1
643491	643445	19611R	PRESIDENT	0	PRESENT	1
643492	643445	20132W	PARTICIPANT	\N	PRESENT	1
643493	643445	14123H	PARTICIPANT	\N	PRESENT	1
643494	643445	19735D	PARTICIPANT	\N	PRESENT	1
643495	643445	14073Q	PARTICIPANT	\N	PRESENT	1
643496	643445	19766L	PARTICIPANT	\N	PRESENT	0
643497	643445	14030Q	PARTICIPANT	\N	PRESENT	0
643572	643392	01048V	PARTICIPANT	\N	PRESENT	0
643499	643445	20134Y	PARTICIPANT	\N	PRESENT	0
643573	643445	01048V	PARTICIPANT	\N	PRESENT	0
643501	643445	14229S	PARTICIPANT	\N	PRESENT	0
643502	643445	20052X	PARTICIPANT	\N	PRESENT	0
643503	643445	20056C	PARTICIPANT	\N	PRESENT	0
643504	643445	19573D	PARTICIPANT	\N	PRESENT	0
643505	643445	11043H	PARTICIPANT	\N	PRESENT	0
643530	643392	01028R	PARTICIPANT	\N	PRESENT	0
643507	643445	08012N	PARTICIPANT	\N	PRESENT	0
643508	643445	20172F	PARTICIPANT	\N	PRESENT	1
643511	643392	19649G	PARTICIPANT	\N	PRESENT	0
643512	643392	14111D	PARTICIPANT	\N	PRESENT	0
643513	643392	11010L	PARTICIPANT	\N	PRESENT	0
643514	643392	14151M	PARTICIPANT	\N	PRESENT	0
643515	643392	14069U	PARTICIPANT	\N	PRESENT	0
643516	643392	11085T	PARTICIPANT	\N	PRESENT	0
643517	643392	04047H	PRESIDENT	0	PRESENT	0
643518	643445	04059M	PARTICIPANT	\N	PRESENT	0
643519	643392	04071H	PARTICIPANT	\N	PRESENT	0
643520	643445	04071H	PARTICIPANT	\N	PRESENT	0
643522	643392	19673G	PARTICIPANT	\N	PRESENT	0
643523	643392	11033F	PARTICIPANT	\N	PRESENT	0
643524	643392	05008E	PARTICIPANT	\N	PRESENT	0
643525	643392	19629C	PARTICIPANT	\N	PRESENT	0
643526	643392	14215L	PARTICIPANT	\N	PRESENT	0
643527	643445	19533U	PARTICIPANT	\N	PRESENT	1
643528	643392	95063L	PARTICIPANT	\N	PRESENT	0
643529	643392	14089Y	PARTICIPANT	\N	PRESENT	0
643531	643445	20024T	PARTICIPANT	\N	PRESENT	0
643532	643445	19057M	PARTICIPANT	\N	PRESENT	0
643546	643445	20112S	PARTICIPANT	\N	PRESENT	1
643547	643445	20138D	PARTICIPANT	\N	PRESENT	1
643548	643445	19643A	PARTICIPANT	\N	PRESENT	1
643549	643445	20152B	PARTICIPANT	\N	PRESENT	0
643550	643445	19758L	PARTICIPANT	\N	PRESENT	1
643551	643445	20264J	PARTICIPANT	\N	PRESENT	1
643552	643445	17589D	PARTICIPANT	\N	PRESENT	1
643553	643445	19399H	PARTICIPANT	\N	PRESENT	0
643554	643445	20142Y	PARTICIPANT	\N	PRESENT	1
643555	643445	20058E	PARTICIPANT	\N	PRESENT	0
643556	643392	20024T	PARTICIPANT	\N	PRESENT	0
643608	643445	04047H	PARTICIPANT	\N	PRESENT	0
643609	643445	19527W	PARTICIPANT	\N	PRESENT	1
643672	643671	19711U	PARTICIPANT	\N	PRESENT	0
643673	643671	20050V	PARTICIPANT	\N	PRESENT	0
643754	643753	99004R	PARTICIPANT	\N	PRESENT	0
643755	643753	19399H	PARTICIPANT	\N	PRESENT	0
643757	643756	14147R	PARTICIPANT	\N	PRESENT	0
643758	643756	19725B	PARTICIPANT	\N	PRESENT	0
643761	643760	19507S	PARTICIPANT	\N	PRESENT	0
643762	643760	20028X	PARTICIPANT	\N	PRESENT	0
643763	643760	19441R	PARTICIPANT	\N	PRESENT	0
643765	643764	19507S	PARTICIPANT	\N	PRESENT	0
643766	643764	19441R	PARTICIPANT	\N	PRESENT	0
643767	643764	20028X	PARTICIPANT	\N	PRESENT	0
643769	643768	19507S	PARTICIPANT	\N	PRESENT	0
643770	643768	19441R	PARTICIPANT	\N	PRESENT	0
643771	643768	20028X	PARTICIPANT	\N	PRESENT	0
643773	643772	19507S	PARTICIPANT	\N	PRESENT	0
629629	629627	19717B	PARTICIPANT	\N	EXCUSE	0
629630	629627	20102Q	PARTICIPANT	\N	PRESENT	0
629631	629627	20150Y	PARTICIPANT	\N	PRESENT	0
629634	629627	14083S	PRESIDENT	0	PRESENT	0
629635	629627	19503N	PARTICIPANT	\N	PRESENT	0
629677	629627	20104S	PARTICIPANT	\N	PRESENT	0
629777	629627	11064N	PARTICIPANT	\N	PRESENT	1
630117	629123	11064N	PARTICIPANT	\N	PRESENT	0
630522	628668	14121F	PARTICIPANT	\N	PRESENT	0
630523	628668	19671E	PARTICIPANT	\N	PRESENT	0
630524	628668	20036X	PARTICIPANT	\N	PRESENT	0
630525	628668	11012A	PARTICIPANT	\N	PRESENT	0
632164	627014	19333N	PARTICIPANT	\N	PRESENT	0
642492	641818	19745F	PARTICIPANT	\N	EXCUSE	0
630520	628668	19741B	PARTICIPANT	\N	PRESENT	0
630521	628668	11110B	PARTICIPANT	\N	PRESENT	0
642493	641818	19251M	PARTICIPANT	\N	EXCUSE	0
642494	641818	19826F	PARTICIPANT	\N	EXCUSE	0
642546	642185	11040E	PARTICIPANT	\N	PRESENT	1
642547	642185	14327T	PARTICIPANT	\N	PRESENT	1
642548	642185	11110B	PARTICIPANT	\N	PRESENT	1
642549	642185	14121F	PARTICIPANT	\N	PRESENT	1
642550	642185	19531S	PARTICIPANT	\N	PRESENT	1
642551	642185	20126Y	PARTICIPANT	\N	PRESENT	1
642552	642185	08010L	PARTICIPANT	\N	PRESENT	1
642553	642185	11012A	PARTICIPANT	\N	PRESENT	1
642554	642185	20044X	PARTICIPANT	\N	PRESENT	1
642820	642819	11070L	PARTICIPANT	\N	PRESENT	0
642821	642819	19647E	PARTICIPANT	\N	PRESENT	0
642823	642822	11012A	PARTICIPANT	\N	PRESENT	0
642824	642822	14083S	PARTICIPANT	\N	PRESENT	0
642827	642826	20080C	PARTICIPANT	\N	PRESENT	0
642829	642828	20080C	PARTICIPANT	\N	PRESENT	0
642831	642830	20080C	PARTICIPANT	\N	PRESENT	0
642833	642832	20080C	PARTICIPANT	\N	PRESENT	0
643103	642935	11031D	PARTICIPANT	\N	PRESENT	0
643130	642935	20066E	PARTICIPANT	\N	PRESENT	0
643131	642935	19760E	PARTICIPANT	\N	PRESENT	0
643229	642935	19415P	PARTICIPANT	\N	PRESENT	0
643312	642878	19467C	PARTICIPANT	\N	PRESENT	0
643314	642864	05008E	PARTICIPANT	\N	EXCUSE	0
643318	643317	14147R	PARTICIPANT	\N	PRESENT	0
643316	642864	19717B	PARTICIPANT	\N	PRESENT	1
643319	643317	19725B	PARTICIPANT	\N	PRESENT	0
643420	643419	01028R	PARTICIPANT	\N	PRESENT	0
643422	643421	14331P	PARTICIPANT	\N	PRESENT	0
643423	643421	14073Q	PARTICIPANT	\N	PRESENT	0
643424	643411	14189C	PARTICIPANT	\N	PRESENT	0
643425	643411	14089Y	PARTICIPANT	\N	PRESENT	0
643426	643411	20094J	PARTICIPANT	\N	EXCUSE	0
643427	643411	19701S	PARTICIPANT	\N	PRESENT	1
643428	643411	20128B	PARTICIPANT	\N	PRESENT	1
643429	643411	14097Y	PARTICIPANT	\N	PRESENT	1
643430	643411	14073Q	PARTICIPANT	\N	PRESENT	0
643431	643411	04045F	PARTICIPANT	\N	PRESENT	1
643432	643411	14331P	PARTICIPANT	\N	PRESENT	0
643433	643411	20104S	PARTICIPANT	\N	EXCUSE	0
643434	643411	08018U	PARTICIPANT	\N	EXCUSE	0
643435	643062	19760E	PARTICIPANT	\N	PRESENT	0
643436	643062	20130U	PARTICIPANT	\N	PRESENT	0
643437	643062	01034P	PARTICIPANT	\N	PRESENT	0
643438	643062	19798U	PARTICIPANT	\N	PRESENT	0
643439	643063	01034P	PARTICIPANT	\N	PRESENT	0
643440	643063	20130U	PARTICIPANT	\N	PRESENT	0
643441	643063	19798U	PARTICIPANT	\N	PRESENT	0
643656	643654	20248J	PARTICIPANT	\N	PRESENT	0
643657	643654	11067R	PARTICIPANT	\N	PRESENT	0
643658	643654	20130U	PARTICIPANT	\N	PRESENT	0
643876	643875	19741B	PARTICIPANT	\N	PRESENT	0
643877	643875	11040E	PARTICIPANT	\N	PRESENT	1
643878	643875	14083S	PARTICIPANT	\N	PRESENT	0
643879	643875	11048N	PARTICIPANT	\N	PRESENT	0
643880	643875	20126Y	PARTICIPANT	\N	PRESENT	0
643881	643875	19711U	PARTICIPANT	\N	PRESENT	0
643882	643875	14225N	PARTICIPANT	\N	PRESENT	0
643883	643875	11012A	PARTICIPANT	\N	PRESENT	1
643884	643875	19762G	PARTICIPANT	\N	PRESENT	0
643885	643875	19479G	PARTICIPANT	\N	PRESENT	1
644091	644090	19711U	PARTICIPANT	\N	PRESENT	0
644092	644090	20050V	PARTICIPANT	\N	PRESENT	0
644108	644107	05008E	PARTICIPANT	\N	PRESENT	0
644109	644107	11053K	PARTICIPANT	\N	PRESENT	0
644110	644107	01028R	PARTICIPANT	\N	PRESENT	0
644145	644104	19725B	PARTICIPANT	\N	PRESENT	0
644146	644104	14026U	PARTICIPANT	\N	PRESENT	0
644147	644143	14026U	PARTICIPANT	\N	PRESENT	0
644148	644143	19725B	PARTICIPANT	\N	PRESENT	0
644149	644141	19725B	PARTICIPANT	\N	PRESENT	0
644150	644141	14026U	PARTICIPANT	\N	PRESENT	0
644773	644423	14179A	PARTICIPANT	\N	PRESENT	1
644774	644423	14147R	PARTICIPANT	\N	PRESENT	1
644775	644423	20128B	PARTICIPANT	\N	PRESENT	1
644776	644423	19631V	PARTICIPANT	\N	PRESENT	1
644886	644885	19782L	PARTICIPANT	\N	PRESENT	1
644887	644885	19629C	PARTICIPANT	\N	PRESENT	0
644888	644885	14038Y	PARTICIPANT	\N	PRESENT	0
644889	644885	14147R	PARTICIPANT	\N	PRESENT	1
644890	644885	20028X	PARTICIPANT	\N	PRESENT	1
644891	644885	20092G	PARTICIPANT	\N	PRESENT	0
644892	644311	19563B	PARTICIPANT	\N	EXCUSE	0
644893	644311	14357A	PARTICIPANT	\N	EXCUSE	0
644894	644311	01043Q	PARTICIPANT	\N	EXCUSE	0
644895	644311	08028W	PARTICIPANT	\N	EXCUSE	0
644896	644311	14329V	PARTICIPANT	\N	EXCUSE	0
644897	644311	20028X	PARTICIPANT	\N	EXCUSE	0
644899	644898	01062T	PARTICIPANT	\N	PRESENT	0
644901	644900	01028R	PARTICIPANT	\N	PRESENT	0
644904	644902	14147R	PARTICIPANT	\N	PRESENT	0
644905	644902	19725B	PARTICIPANT	\N	PRESENT	0
644906	644902	19447X	PARTICIPANT	\N	PRESENT	0
644907	644902	20132W	PARTICIPANT	\N	PRESENT	0
644908	644902	19643A	PARTICIPANT	\N	PRESENT	0
644910	644909	20024T	PARTICIPANT	\N	PRESENT	0
644911	644909	04035D	PARTICIPANT	\N	PRESENT	0
644912	644909	14147R	PARTICIPANT	\N	PRESENT	0
644913	644909	20064C	PARTICIPANT	\N	PRESENT	0
646163	646162	19441R	PARTICIPANT	\N	PRESENT	0
646164	646162	19507S	PARTICIPANT	\N	PRESENT	0
646165	646162	14207L	PARTICIPANT	\N	PRESENT	0
646166	646162	14033T	PARTICIPANT	\N	PRESENT	0
646167	646162	20092G	PARTICIPANT	\N	PRESENT	0
646168	646162	20062A	PARTICIPANT	\N	PRESENT	0
646170	646169	19507S	PARTICIPANT	\N	PRESENT	0
646171	646169	20092G	PARTICIPANT	\N	PRESENT	0
646172	646169	14033T	PARTICIPANT	\N	PRESENT	0
646226	646225	86034E	PARTICIPANT	\N	PRESENT	0
646227	646225	04085P	PARTICIPANT	\N	PRESENT	0
646228	646225	10006L	PARTICIPANT	\N	PRESENT	0
646229	646225	07004J	PARTICIPANT	\N	PRESENT	0
646230	646225	14026U	PARTICIPANT	\N	PRESENT	0
646231	646225	14021P	PARTICIPANT	\N	PRESENT	0
646232	646225	99004R	PARTICIPANT	\N	PRESENT	0
646233	646225	19611R	PARTICIPANT	\N	PRESENT	0
646234	646225	01043Q	PARTICIPANT	\N	PRESENT	0
646235	646225	14219Q	PARTICIPANT	\N	PRESENT	0
646236	646225	14251Q	PARTICIPANT	\N	PRESENT	0
646237	646225	11085T	PARTICIPANT	\N	PRESENT	0
646238	646225	14193X	PARTICIPANT	\N	PRESENT	0
646239	646225	11090Q	PARTICIPANT	\N	PRESENT	0
646240	646225	14331P	PARTICIPANT	\N	PRESENT	0
646241	646225	14225N	PARTICIPANT	\N	PRESENT	0
646242	646225	11012A	PARTICIPANT	\N	PRESENT	0
646243	646225	04033B	PARTICIPANT	\N	PRESENT	0
646244	646225	95063L	PARTICIPANT	\N	PRESENT	0
646245	646225	11045K	PARTICIPANT	\N	PRESENT	0
646246	646225	20092G	PARTICIPANT	\N	PRESENT	0
646247	646225	01028R	PARTICIPANT	\N	PRESENT	0
646345	646153	14053L	PARTICIPANT	\N	PRESENT	0
646346	646153	14111D	PARTICIPANT	\N	PRESENT	0
646347	646153	10015M	PARTICIPANT	\N	PRESENT	0
646348	646153	14001X	PARTICIPANT	\N	PRESENT	0
646349	646153	04047H	PRESIDENT	0	PRESENT	0
646350	646153	11033F	PARTICIPANT	\N	PRESENT	0
646351	646153	19447X	PARTICIPANT	\N	PRESENT	0
646352	646153	14231L	PARTICIPANT	\N	PRESENT	0
646353	646153	19725B	PARTICIPANT	\N	PRESENT	0
646354	646153	19729F	PARTICIPANT	\N	PRESENT	0
646355	646153	95063L	PARTICIPANT	\N	PRESENT	0
646356	646153	07004J	PARTICIPANT	\N	PRESENT	0
646357	646153	20110Q	PARTICIPANT	\N	PRESENT	0
646358	646153	14151M	PARTICIPANT	\N	PRESENT	0
650083	650034	19679N	PARTICIPANT	\N	PRESENT	0
650084	650034	04092N	PARTICIPANT	\N	PRESENT	0
650091	650035	19679N	PARTICIPANT	\N	PRESENT	0
650092	650035	20130U	PARTICIPANT	\N	PRESENT	1
650093	650035	04092N	PARTICIPANT	\N	PRESENT	0
650096	650036	19679N	PARTICIPANT	\N	PRESENT	0
650097	650036	11097X	PARTICIPANT	\N	PRESENT	0
650098	650037	19679N	PARTICIPANT	\N	PRESENT	0
650099	650037	11097X	PARTICIPANT	\N	PRESENT	0
650100	650038	19679N	PARTICIPANT	\N	PRESENT	0
650101	650038	11097X	PARTICIPANT	\N	PRESENT	0
650103	650038	17965H	PARTICIPANT	\N	PRESENT	0
650104	650038	20248J	PARTICIPANT	\N	PRESENT	1
650105	650038	20130U	PARTICIPANT	\N	PRESENT	1
650113	650112	20024T	PARTICIPANT	\N	PRESENT	0
650115	650114	20024T	PARTICIPANT	\N	PRESENT	0
650116	648781	19954N	PARTICIPANT	\N	PRESENT	1
650117	648781	20128B	PARTICIPANT	\N	PRESENT	1
650118	648781	14147R	PARTICIPANT	\N	PRESENT	1
650119	648781	11072N	PARTICIPANT	\N	PRESENT	1
650120	648781	10015M	PARTICIPANT	\N	PRESENT	1
650121	648781	14107H	PARTICIPANT	\N	PRESENT	1
650122	648781	19675J	PARTICIPANT	\N	PRESENT	1
650123	648782	19954N	PARTICIPANT	\N	PRESENT	1
650124	648782	20128B	PARTICIPANT	\N	PRESENT	1
650125	648782	14147R	PARTICIPANT	\N	PRESENT	1
650126	648782	11072N	PARTICIPANT	\N	PRESENT	1
650127	648782	10015M	PARTICIPANT	\N	PRESENT	1
650128	648782	14107H	PARTICIPANT	\N	PRESENT	1
650129	648782	19675J	PARTICIPANT	\N	PRESENT	1
650137	649725	11090Q	PARTICIPANT	\N	EXCUSE	0
650138	649725	20094J	PARTICIPANT	\N	EXCUSE	0
650139	649773	20032T	PARTICIPANT	\N	PRESENT	0
650140	649773	20076G	PARTICIPANT	\N	PRESENT	0
650141	649773	20024T	PARTICIPANT	\N	PRESENT	0
650143	649773	19549D	PARTICIPANT	\N	PRESENT	0
650144	649773	17367Q	PARTICIPANT	\N	PRESENT	0
650145	649773	18083K	PARTICIPANT	\N	PRESENT	0
650146	649773	19701S	PARTICIPANT	\N	PRESENT	0
650147	649773	19681G	PARTICIPANT	\N	PRESENT	0
650148	649773	19525U	PARTICIPANT	\N	PRESENT	0
650149	649773	11065P	PARTICIPANT	\N	PRESENT	0
650150	649773	20140W	PARTICIPANT	\N	PRESENT	0
650151	649773	17229F	PARTICIPANT	\N	PRESENT	0
650152	649773	19251M	PARTICIPANT	\N	PRESENT	0
650153	649773	19577H	PARTICIPANT	\N	PRESENT	0
650154	649773	20038A	PARTICIPANT	\N	PRESENT	0
650155	649773	20100N	PARTICIPANT	\N	PRESENT	0
650156	649773	19599P	PARTICIPANT	\N	PRESENT	0
650157	649773	20120S	PARTICIPANT	\N	PRESENT	0
650158	649773	19820Y	PARTICIPANT	\N	PRESENT	0
650159	649773	19387D	PARTICIPANT	\N	PRESENT	0
650160	649773	20068G	PARTICIPANT	\N	PRESENT	0
650161	649773	20102Q	PARTICIPANT	\N	PRESENT	0
650162	649773	14219Q	PARTICIPANT	\N	PRESENT	0
650163	649773	14031R	PARTICIPANT	\N	PRESENT	0
650164	649773	19826F	PARTICIPANT	\N	PRESENT	0
650165	649773	20096L	PARTICIPANT	\N	PRESENT	0
650166	649773	14169X	PARTICIPANT	\N	PRESENT	0
650167	649773	14237S	PARTICIPANT	\N	PRESENT	0
650168	649773	19745F	PARTICIPANT	\N	PRESENT	0
650169	649773	20118Y	PARTICIPANT	\N	PRESENT	0
650170	649773	05012A	PARTICIPANT	\N	PRESENT	0
650171	649773	19503N	PARTICIPANT	\N	PRESENT	0
650172	649773	19739H	PARTICIPANT	\N	PRESENT	0
650173	649773	20136B	PARTICIPANT	\N	PRESENT	0
650174	649773	20046A	PARTICIPANT	\N	PRESENT	0
650175	649773	20122U	PARTICIPANT	\N	PRESENT	0
650253	648783	14147R	PARTICIPANT	\N	PRESENT	1
650254	648783	10015M	PARTICIPANT	\N	PRESENT	0
650255	648783	14107H	PARTICIPANT	\N	PRESENT	1
651398	651397	14033T	PARTICIPANT	\N	PRESENT	0
651443	651442	20024T	PARTICIPANT	\N	PRESENT	0
651446	651444	20024T	PARTICIPANT	\N	PRESENT	0
653061	650987	11040E	PARTICIPANT	\N	PRESENT	1
653062	650987	11110B	PARTICIPANT	\N	PRESENT	1
653063	650987	01057W	PARTICIPANT	\N	PRESENT	1
653064	650987	20126Y	PARTICIPANT	\N	PRESENT	1
653065	650987	08009T	PARTICIPANT	\N	PRESENT	1
653069	650987	14331P	PARTICIPANT	\N	PRESENT	1
653070	650987	11012A	PARTICIPANT	\N	PRESENT	1
653086	650987	99004R	PARTICIPANT	\N	EXCUSE	0
654454	652904	20130U	PARTICIPANT	\N	PRESENT	0
654455	652904	20038A	PARTICIPANT	\N	PRESENT	0
654456	652904	19667J	PARTICIPANT	\N	PRESENT	0
654457	652904	19467C	PARTICIPANT	\N	PRESENT	0
654458	652904	14173T	PARTICIPANT	\N	PRESENT	0
654459	652904	19697Q	PARTICIPANT	\N	PRESENT	0
654460	652904	19349W	PARTICIPANT	\N	PRESENT	0
654461	652904	20110Q	PARTICIPANT	\N	PRESENT	0
654462	652904	20044X	PARTICIPANT	\N	PRESENT	0
654463	652904	20034V	PARTICIPANT	\N	PRESENT	0
654464	652904	20100N	PARTICIPANT	\N	PRESENT	0
654465	652904	20134Y	PARTICIPANT	\N	PRESENT	0
654466	652904	20028X	PARTICIPANT	\N	PRESENT	0
654467	652904	14191V	PARTICIPANT	\N	PRESENT	0
654468	652904	19687N	PARTICIPANT	\N	PRESENT	0
654469	652904	14105F	PARTICIPANT	\N	PRESENT	0
654470	652904	11040E	PARTICIPANT	\N	PRESENT	0
654471	652904	19593H	PARTICIPANT	\N	PRESENT	0
654472	652904	14329V	PARTICIPANT	\N	PRESENT	0
654473	652904	14189C	PARTICIPANT	\N	PRESENT	0
654474	652904	20032T	PARTICIPANT	\N	PRESENT	0
654475	652904	19479G	PARTICIPANT	\N	PRESENT	0
654476	652904	14053L	PARTICIPANT	\N	PRESENT	0
654477	652904	19443T	PARTICIPANT	\N	PRESENT	0
654478	652904	20252E	PARTICIPANT	\N	PRESENT	0
654479	652904	19820Y	PARTICIPANT	\N	PRESENT	0
654480	652904	01058X	PARTICIPANT	\N	PRESENT	0
654481	652904	20080C	PARTICIPANT	\N	PRESENT	0
654482	652904	19647E	PARTICIPANT	\N	PRESENT	0
654483	652904	19711U	PARTICIPANT	\N	PRESENT	0
654484	652904	19671E	PARTICIPANT	\N	PRESENT	0
654485	652904	19701S	PARTICIPANT	\N	PRESENT	0
654486	652904	20132W	PARTICIPANT	\N	PRESENT	0
654487	652904	19575F	PARTICIPANT	\N	PRESENT	0
654488	652904	11065P	PARTICIPANT	\N	PRESENT	0
654489	652904	08034U	PARTICIPANT	\N	PRESENT	0
654490	652904	20150Y	PARTICIPANT	\N	PRESENT	0
654491	652904	04033B	PARTICIPANT	\N	PRESENT	0
654492	652904	19549D	PARTICIPANT	\N	PRESENT	0
654493	652904	14071N	PARTICIPANT	\N	PRESENT	0
654494	652904	11104D	PARTICIPANT	\N	PRESENT	0
654495	652904	19679N	PARTICIPANT	\N	PRESENT	0
654496	652904	08010L	PARTICIPANT	\N	PRESENT	0
654497	652904	11090Q	PARTICIPANT	\N	PRESENT	0
654498	652904	18083K	PARTICIPANT	\N	PRESENT	0
654499	652904	20090E	PARTICIPANT	\N	PRESENT	0
654500	652904	20070A	PARTICIPANT	\N	PRESENT	0
654501	652904	08061X	PARTICIPANT	\N	PRESENT	0
654502	652904	20094J	PARTICIPANT	\N	PRESENT	0
654503	652904	14033T	PARTICIPANT	\N	PRESENT	0
654504	652904	20018V	PARTICIPANT	\N	PRESENT	0
654505	652904	20062A	PARTICIPANT	\N	PRESENT	0
654506	652904	11110B	PARTICIPANT	\N	PRESENT	0
654507	652904	20060X	PARTICIPANT	\N	PRESENT	0
654508	652904	20102Q	PARTICIPANT	\N	PRESENT	0
654509	652904	19762G	PARTICIPANT	\N	PRESENT	0
654510	652904	19335Q	PARTICIPANT	\N	PRESENT	0
654511	652904	14147R	PARTICIPANT	\N	PRESENT	0
654512	652904	20054A	PARTICIPANT	\N	PRESENT	0
654513	652904	19619A	PARTICIPANT	\N	PRESENT	0
654514	652904	19413M	PARTICIPANT	\N	PRESENT	0
654515	652904	19301E	PARTICIPANT	\N	PRESENT	0
654516	652904	19758L	PARTICIPANT	\N	PRESENT	0
654517	652904	19760E	PARTICIPANT	\N	PRESENT	0
654518	652904	12041X	PARTICIPANT	\N	PRESENT	0
654519	652904	20086J	PARTICIPANT	\N	PRESENT	0
654520	652904	14187A	PARTICIPANT	\N	PRESENT	0
654521	652904	19826F	PARTICIPANT	\N	PRESENT	0
654522	652904	19745F	PARTICIPANT	\N	PRESENT	0
654523	652904	20140W	PARTICIPANT	\N	PRESENT	0
654524	652904	11048N	PARTICIPANT	\N	PRESENT	0
654525	652904	14225N	PARTICIPANT	\N	PRESENT	0
654526	652904	14357A	PARTICIPANT	\N	PRESENT	0
654527	652904	14083S	PARTICIPANT	\N	PRESENT	0
654528	652904	07004J	PARTICIPANT	\N	PRESENT	0
654529	652906	12041X	PARTICIPANT	\N	PRESENT	0
654530	652904	20298U	PARTICIPANT	\N	PRESENT	0
654531	652904	19563B	PARTICIPANT	\N	PRESENT	0
634854	633245	11056N	PARTICIPANT	\N	PRESENT	0
635978	634654	20110Q	PARTICIPANT	\N	PRESENT	0
635979	634654	20142Y	PARTICIPANT	\N	PRESENT	0
635980	634654	19599P	PARTICIPANT	\N	PRESENT	0
635981	634654	08045X	PARTICIPANT	\N	PRESENT	0
635982	634654	17965H	PARTICIPANT	\N	PRESENT	0
635983	634654	20052X	PARTICIPANT	\N	PRESENT	0
635984	634654	19421M	PARTICIPANT	\N	PRESENT	0
635985	634654	14169X	PARTICIPANT	\N	PRESENT	0
635986	634654	04092N	PARTICIPANT	\N	PRESENT	0
635987	634654	05012A	PARTICIPANT	\N	PRESENT	0
635988	634654	20134Y	PARTICIPANT	\N	PRESENT	0
635989	634654	11054L	PARTICIPANT	\N	PRESENT	0
635990	634654	19647E	PARTICIPANT	\N	PRESENT	0
635991	634654	19531S	PARTICIPANT	\N	PRESENT	0
635992	634654	20064C	PARTICIPANT	\N	PRESENT	0
635993	634654	20114U	PARTICIPANT	\N	PRESENT	0
635994	634654	11045K	PARTICIPANT	\N	PRESENT	0
635995	634654	20080C	PARTICIPANT	\N	PRESENT	0
635996	634654	19503N	PARTICIPANT	\N	PRESENT	0
635997	634654	14249W	PARTICIPANT	\N	PRESENT	0
635998	634654	19697Q	PARTICIPANT	\N	PRESENT	0
635999	634654	19549D	PARTICIPANT	\N	PRESENT	0
636000	634654	14207L	PARTICIPANT	\N	PRESENT	0
636001	634654	11067R	PARTICIPANT	\N	PRESENT	0
636002	634654	08061X	PARTICIPANT	\N	PRESENT	0
636003	634654	14221J	PARTICIPANT	\N	PRESENT	0
636004	634654	19525U	PARTICIPANT	\N	PRESENT	0
636005	634654	04059M	PARTICIPANT	\N	PRESENT	0
636006	634654	20100N	PARTICIPANT	\N	PRESENT	0
636007	634654	20070A	PARTICIPANT	\N	PRESENT	0
636008	634654	20036X	PARTICIPANT	\N	PRESENT	0
636009	634654	08012N	PARTICIPANT	\N	PRESENT	0
636011	634654	20116W	PARTICIPANT	\N	PRESENT	0
636012	634654	14231L	PARTICIPANT	\N	PRESENT	0
636013	634654	14327T	PARTICIPANT	\N	PRESENT	0
636015	634654	11070L	PARTICIPANT	\N	PRESENT	0
636016	634654	19689Q	PARTICIPANT	\N	PRESENT	0
636017	634654	20112S	PARTICIPANT	\N	PRESENT	0
636018	634654	14281W	PARTICIPANT	\N	PRESENT	0
636019	634654	14211G	PARTICIPANT	\N	PRESENT	0
636020	634654	14030Q	PARTICIPANT	\N	PRESENT	0
636021	634654	19679N	PARTICIPANT	\N	PRESENT	0
636022	634654	20174H	PARTICIPANT	\N	PRESENT	0
636023	634654	19527W	PARTICIPANT	\N	PRESENT	0
636024	634654	20074E	PARTICIPANT	\N	PRESENT	0
636025	634654	19575F	PARTICIPANT	\N	PRESENT	0
636026	634654	19711U	PARTICIPANT	\N	PRESENT	0
636027	634654	01058X	PARTICIPANT	\N	PRESENT	0
636028	634654	14257W	PARTICIPANT	\N	PRESENT	0
636029	634654	20028X	PARTICIPANT	\N	PRESENT	0
636030	634654	20076G	PARTICIPANT	\N	PRESENT	0
636031	634654	18193Q	PARTICIPANT	\N	PRESENT	0
636032	634654	11026G	PARTICIPANT	\N	PRESENT	0
636033	634654	14021P	PARTICIPANT	\N	PRESENT	0
636034	634654	20018V	PARTICIPANT	\N	PRESENT	0
636035	634654	17367Q	PARTICIPANT	\N	PRESENT	0
636036	634654	11033F	PARTICIPANT	\N	PRESENT	0
636037	634654	17779H	PARTICIPANT	\N	PRESENT	0
636038	634654	19515S	PARTICIPANT	\N	PRESENT	0
636039	634654	19643A	PARTICIPANT	\N	PRESENT	0
636040	634654	20286Q	PARTICIPANT	\N	PRESENT	0
636041	634654	01057W	PARTICIPANT	\N	PRESENT	0
636042	634654	14151M	PARTICIPANT	\N	PRESENT	0
636043	634654	20094J	PARTICIPANT	\N	PRESENT	0
636044	634654	14001X	PARTICIPANT	\N	PRESENT	0
636045	634654	08010L	PARTICIPANT	\N	PRESENT	0
636046	634654	18083K	PARTICIPANT	\N	PRESENT	0
636047	634654	08034U	PARTICIPANT	\N	PRESENT	0
636048	634654	11097X	PARTICIPANT	\N	PRESENT	0
636049	634654	05008E	PARTICIPANT	\N	PRESENT	0
636050	634654	20264J	PARTICIPANT	\N	PRESENT	0
636051	634654	19631V	PARTICIPANT	\N	PRESENT	0
636052	634654	14187A	PARTICIPANT	\N	PRESENT	0
636053	634654	04033B	PARTICIPANT	\N	PRESENT	0
636054	634654	20092G	PARTICIPANT	\N	PRESENT	0
636055	634654	19725B	PARTICIPANT	\N	PRESENT	0
636056	634654	04071H	PARTICIPANT	\N	PRESENT	0
636057	634654	19687N	PARTICIPANT	\N	PRESENT	0
636058	634654	19760E	PARTICIPANT	\N	PRESENT	0
636059	634654	11080N	PARTICIPANT	\N	PRESENT	0
636060	634654	19758L	PARTICIPANT	\N	PRESENT	0
636061	634654	04085P	PARTICIPANT	\N	PRESENT	0
636062	634654	19695N	PARTICIPANT	\N	PRESENT	0
636063	634654	19593H	PARTICIPANT	\N	PRESENT	0
636064	634654	20022R	PARTICIPANT	\N	PRESENT	0
636065	634654	20102Q	PARTICIPANT	\N	PRESENT	0
636066	634654	11090Q	PARTICIPANT	\N	PRESENT	0
636067	634654	19629C	PARTICIPANT	\N	PRESENT	0
636068	634654	19701S	PARTICIPANT	\N	PRESENT	0
636069	634654	14053L	PARTICIPANT	\N	PRESENT	0
636070	634654	19553Y	PARTICIPANT	\N	PRESENT	0
636071	634654	11012A	PARTICIPANT	\N	PRESENT	0
636072	634654	14215L	PARTICIPANT	\N	PRESENT	0
636073	634654	20082E	PARTICIPANT	\N	PRESENT	0
636074	634654	19251M	PARTICIPANT	\N	PRESENT	0
636075	634654	10006L	PARTICIPANT	\N	PRESENT	0
636076	634654	19533U	PARTICIPANT	\N	PRESENT	0
636077	634654	20118Y	PARTICIPANT	\N	PRESENT	0
636078	634654	19715Y	PARTICIPANT	\N	PRESENT	0
636079	634654	04043D	PARTICIPANT	\N	PRESENT	0
636080	634654	14105F	PARTICIPANT	\N	PRESENT	0
636081	634654	20032T	PARTICIPANT	\N	PRESENT	0
636082	634654	17023S	PARTICIPANT	\N	PRESENT	0
636083	634654	20136B	PARTICIPANT	\N	PRESENT	0
636084	634654	20042V	PARTICIPANT	\N	PRESENT	0
636085	634654	14253S	PARTICIPANT	\N	PRESENT	0
636086	634654	11085T	PARTICIPANT	\N	PRESENT	0
636087	634654	19667J	PARTICIPANT	\N	PRESENT	0
636088	634654	19651A	PARTICIPANT	\N	PRESENT	0
636089	634654	14031R	PARTICIPANT	\N	PRESENT	0
636090	634654	19782L	PARTICIPANT	\N	PRESENT	0
636092	634654	11083R	PARTICIPANT	\N	PRESENT	0
636093	634654	20038A	PARTICIPANT	\N	PRESENT	0
636094	634654	19447X	PARTICIPANT	\N	PRESENT	0
636095	634654	19573D	PARTICIPANT	\N	PRESENT	0
636096	634654	20128B	PARTICIPANT	\N	PRESENT	0
636097	634654	20180F	PARTICIPANT	\N	PRESENT	0
636098	634654	14195A	PARTICIPANT	\N	PRESENT	0
636099	634654	20122U	PARTICIPANT	\N	PRESENT	0
636100	634654	19954N	PARTICIPANT	\N	PRESENT	0
636101	634654	14251Q	PARTICIPANT	\N	PRESENT	0
636102	634654	11064N	PARTICIPANT	\N	PRESENT	0
636103	634654	04057K	PARTICIPANT	\N	PRESENT	0
636104	634654	20172F	PARTICIPANT	\N	PRESENT	0
636105	634654	14026U	PARTICIPANT	\N	PRESENT	0
636106	634654	14111D	PARTICIPANT	\N	PRESENT	0
636107	634654	20120S	PARTICIPANT	\N	PRESENT	0
636108	634654	20252E	PARTICIPANT	\N	PRESENT	0
636109	634654	11053K	PARTICIPANT	\N	PRESENT	0
636110	634654	14267Y	PARTICIPANT	\N	PRESENT	0
636112	634654	01024M	PARTICIPANT	\N	PRESENT	0
636113	634654	14042U	PARTICIPANT	\N	PRESENT	0
636114	634654	20048C	PARTICIPANT	\N	PRESENT	0
636115	634654	19611R	PARTICIPANT	\N	PRESENT	0
636116	634654	19762G	PARTICIPANT	\N	PRESENT	0
636117	634654	14219Q	PARTICIPANT	\N	PRESENT	0
636118	634654	19441R	PARTICIPANT	\N	PRESENT	0
636119	634654	19383Y	PARTICIPANT	\N	PRESENT	0
636120	634654	19335Q	PARTICIPANT	\N	PRESENT	0
636121	634654	19369B	PARTICIPANT	\N	PRESENT	0
636122	634654	04070G	PARTICIPANT	\N	PRESENT	0
636123	634654	14357A	PARTICIPANT	\N	PRESENT	0
636124	634654	19745F	PARTICIPANT	\N	PRESENT	0
636125	634654	01034P	PARTICIPANT	\N	PRESENT	0
636126	634654	19768N	PARTICIPANT	\N	PRESENT	0
636127	634654	19329S	PARTICIPANT	\N	PRESENT	0
636128	634654	11040E	PARTICIPANT	\N	PRESENT	0
636129	634654	20124W	PARTICIPANT	\N	PRESENT	0
636130	634654	11031D	PARTICIPANT	\N	PRESENT	0
636131	634654	11077T	PARTICIPANT	\N	PRESENT	0
636132	634654	20104S	PARTICIPANT	\N	PRESENT	0
636133	634654	19399H	PARTICIPANT	\N	PRESENT	0
636134	634654	14255U	PARTICIPANT	\N	PRESENT	0
636135	634654	14089Y	PARTICIPANT	\N	PRESENT	0
636136	634654	19543W	PARTICIPANT	\N	PRESENT	0
636137	634654	20098N	PARTICIPANT	\N	PRESENT	0
636138	634654	19723Y	PARTICIPANT	\N	PRESENT	0
636139	634654	20058E	PARTICIPANT	\N	PRESENT	0
636141	634654	20086J	PARTICIPANT	\N	PRESENT	0
643774	643772	19441R	PARTICIPANT	\N	PRESENT	0
643775	643772	20028X	PARTICIPANT	\N	PRESENT	0
643777	643776	19507S	PARTICIPANT	\N	PRESENT	0
643778	643776	20028X	PARTICIPANT	\N	PRESENT	0
643779	643776	19441R	PARTICIPANT	\N	PRESENT	0
643781	643780	19507S	PARTICIPANT	\N	PRESENT	0
643782	643780	19441R	PARTICIPANT	\N	PRESENT	0
643783	643780	20028X	PARTICIPANT	\N	PRESENT	0
643832	643831	14083S	PARTICIPANT	\N	PRESENT	0
643833	643831	19629C	PARTICIPANT	\N	PRESENT	0
643834	643831	19549D	PARTICIPANT	\N	PRESENT	0
643835	643831	20116W	PARTICIPANT	\N	PRESENT	0
643843	643759	19954N	PARTICIPANT	\N	PRESENT	0
643844	643759	19533U	PRESIDENT	0	PRESENT	0
643943	643942	19657G	PARTICIPANT	\N	EXCUSE	0
643846	643759	19820Y	PARTICIPANT	\N	PRESENT	0
643847	643759	04045F	PARTICIPANT	\N	PRESENT	0
643848	643759	14207L	PARTICIPANT	\N	PRESENT	0
643849	643759	19693L	PARTICIPANT	\N	PRESENT	0
643850	643759	17589D	PARTICIPANT	\N	PRESENT	0
643851	643719	11010L	PARTICIPANT	\N	PRESENT	0
643852	643719	19631V	PARTICIPANT	\N	PRESENT	0
643853	643719	20022R	PARTICIPANT	\N	PRESENT	0
643855	643854	14038Y	PARTICIPANT	\N	PRESENT	0
643856	643854	14179A	PARTICIPANT	\N	PRESENT	0
643857	643854	19693L	PARTICIPANT	\N	PRESENT	0
643858	643854	20048C	PARTICIPANT	\N	PRESENT	0
643859	643854	14169X	PARTICIPANT	\N	PRESENT	0
643860	643854	20140W	PARTICIPANT	\N	PRESENT	0
643861	643854	19820Y	PARTICIPANT	\N	PRESENT	0
643862	643854	19575F	PARTICIPANT	\N	PRESENT	0
643863	643854	19701S	PARTICIPANT	\N	PRESENT	0
643864	643854	19533U	PARTICIPANT	\N	PRESENT	0
643865	643854	20032T	PARTICIPANT	\N	PRESENT	1
643866	643854	19387D	PARTICIPANT	\N	PRESENT	1
643867	643854	14026U	PARTICIPANT	\N	PRESENT	1
643868	643854	14257W	PARTICIPANT	\N	PRESENT	1
643869	643854	19349W	PARTICIPANT	\N	PRESENT	1
643870	643854	19798U	PARTICIPANT	\N	PRESENT	1
643872	643759	20124W	PARTICIPANT	\N	PRESENT	0
643873	643719	14179A	PARTICIPANT	\N	PRESENT	0
643886	643759	20096L	PARTICIPANT	\N	PRESENT	0
643945	643944	19657G	PARTICIPANT	\N	PRESENT	1
643948	643745	19760E	PARTICIPANT	\N	PRESENT	0
643949	643745	19415P	PARTICIPANT	\N	PRESENT	0
643950	643745	11067R	PARTICIPANT	\N	PRESENT	0
644156	643445	05008E	PARTICIPANT	\N	PRESENT	0
643962	643951	19693L	PARTICIPANT	\N	PRESENT	0
644057	643839	19758L	PARTICIPANT	\N	PRESENT	1
644058	643839	20172F	PARTICIPANT	\N	PRESENT	1
644059	643839	20142Y	PARTICIPANT	\N	PRESENT	1
644060	643839	20134Y	PARTICIPANT	\N	PRESENT	1
644157	643445	11033F	PARTICIPANT	\N	PRESENT	0
644158	643445	14069U	PARTICIPANT	\N	PRESENT	0
644159	643445	14089Y	PARTICIPANT	\N	PRESENT	0
644160	643445	19629C	PARTICIPANT	\N	PRESENT	0
644161	643445	14215L	PARTICIPANT	\N	PRESENT	0
644162	643445	14151M	PARTICIPANT	\N	PRESENT	0
644163	643445	19673G	PARTICIPANT	\N	PRESENT	0
644164	643445	11010L	PARTICIPANT	\N	PRESENT	0
644165	643445	19649G	PARTICIPANT	\N	PRESENT	0
644166	643445	14111D	PARTICIPANT	\N	PRESENT	0
644167	643445	11085T	PARTICIPANT	\N	PRESENT	0
644168	643445	95063L	PARTICIPANT	\N	PRESENT	0
644169	643445	01028R	PARTICIPANT	\N	PRESENT	0
644170	643445	19543W	PARTICIPANT	\N	PRESENT	1
644171	643445	20022R	PARTICIPANT	\N	PRESENT	1
644172	643445	20110Q	PARTICIPANT	\N	PRESENT	1
644173	643445	20114U	PARTICIPANT	\N	PRESENT	1
644174	643445	17737W	PARTICIPANT	\N	PRESENT	1
644175	643445	11056N	PARTICIPANT	\N	PRESENT	1
644176	643445	20074E	PARTICIPANT	\N	PRESENT	1
644177	643445	19725B	PARTICIPANT	\N	PRESENT	1
644178	643445	20128B	PARTICIPANT	\N	PRESENT	1
644179	643445	14179A	PARTICIPANT	\N	PRESENT	1
644180	643445	19489J	PARTICIPANT	\N	PRESENT	1
644181	643445	20108W	PARTICIPANT	\N	PRESENT	1
644182	643445	19581D	PARTICIPANT	\N	PRESENT	1
644183	643445	14147R	PARTICIPANT	\N	PRESENT	1
644184	643445	11072N	PARTICIPANT	\N	PRESENT	1
644185	643445	10015M	PARTICIPANT	\N	PRESENT	1
644186	643445	14107H	PARTICIPANT	\N	PRESENT	1
644187	643445	19749K	PARTICIPANT	\N	PRESENT	1
644188	643445	19585H	PARTICIPANT	\N	PRESENT	1
644189	643839	20112S	PARTICIPANT	\N	PRESENT	1
644190	643839	20124W	PARTICIPANT	\N	PRESENT	1
644191	643839	19741B	PARTICIPANT	\N	PRESENT	0
644427	644154	14123H	PARTICIPANT	\N	PRESENT	1
644193	643839	11040E	PARTICIPANT	\N	PRESENT	0
644194	643839	20080C	PARTICIPANT	\N	PRESENT	0
644428	644154	20026V	PARTICIPANT	\N	PRESENT	1
644196	643839	11053K	PARTICIPANT	\N	PRESENT	0
644197	643839	11070L	PARTICIPANT	\N	PRESENT	0
644198	643839	14327T	PARTICIPANT	\N	PRESENT	0
644199	643839	04071H	PARTICIPANT	\N	PRESENT	0
644200	643839	11048N	PARTICIPANT	\N	PRESENT	0
644201	643839	99004R	PARTICIPANT	\N	PRESENT	0
644202	643839	07029T	PARTICIPANT	\N	PRESENT	0
644203	643839	19711U	PARTICIPANT	\N	PRESENT	0
644204	643839	08010L	PARTICIPANT	\N	PRESENT	0
644205	643839	08034U	PARTICIPANT	\N	PRESENT	0
644431	644154	19766L	PARTICIPANT	\N	PRESENT	1
644207	643839	19671E	PARTICIPANT	\N	PRESENT	0
644432	644154	20142Y	PARTICIPANT	\N	PRESENT	1
644209	643839	14331P	PARTICIPANT	\N	PRESENT	0
644210	643839	14225N	PARTICIPANT	\N	PRESENT	0
644211	643839	19762G	PARTICIPANT	\N	PRESENT	0
644212	643839	14121F	PARTICIPANT	\N	PRESENT	1
644213	643839	20126Y	PARTICIPANT	\N	PRESENT	1
644214	643839	19349W	PARTICIPANT	\N	PRESENT	1
644215	643839	19687N	PARTICIPANT	\N	PRESENT	1
644216	643839	19479G	PARTICIPANT	\N	PRESENT	1
644218	644217	01028R	PARTICIPANT	\N	PRESENT	0
644220	644219	01028R	PARTICIPANT	\N	PRESENT	0
644237	644236	04047H	PARTICIPANT	\N	PRESENT	0
644238	644236	14053L	PARTICIPANT	\N	PRESENT	0
644239	644236	11066Q	PARTICIPANT	\N	PRESENT	0
644241	644240	11074Q	PARTICIPANT	\N	PRESENT	0
644242	644240	08045X	PARTICIPANT	\N	PRESENT	0
644376	644375	19725B	PARTICIPANT	\N	PRESENT	0
644377	644375	19447X	PARTICIPANT	\N	PRESENT	0
644378	644375	14147R	PARTICIPANT	\N	PRESENT	0
644380	644379	14147R	PARTICIPANT	\N	PRESENT	0
644381	644379	14179A	PARTICIPANT	\N	PRESENT	0
644382	644379	19725B	PARTICIPANT	\N	PRESENT	0
644383	644379	19447X	PARTICIPANT	\N	PRESENT	0
644385	644384	19782L	PARTICIPANT	\N	PRESENT	0
644386	644384	10006L	PARTICIPANT	\N	PRESENT	0
644387	644384	14217N	PARTICIPANT	\N	PRESENT	0
644388	644384	14073Q	PARTICIPANT	\N	PRESENT	0
644389	644384	12041X	PARTICIPANT	\N	PRESENT	0
644390	644384	01058X	PARTICIPANT	\N	PRESENT	0
644391	644384	19820Y	PARTICIPANT	\N	PRESENT	0
644393	644392	19741B	PARTICIPANT	\N	PRESENT	0
644394	644392	19782L	PARTICIPANT	\N	PRESENT	0
644395	644392	10006L	PARTICIPANT	\N	PRESENT	0
644396	644392	20126Y	PARTICIPANT	\N	PRESENT	0
644397	644392	19723Y	PARTICIPANT	\N	PRESENT	0
644398	644392	04092N	PARTICIPANT	\N	PRESENT	0
644399	644392	19745F	PARTICIPANT	\N	PRESENT	0
644401	644400	14097Y	PARTICIPANT	\N	PRESENT	0
644402	644400	10015M	PARTICIPANT	\N	PRESENT	0
644405	644404	14097Y	PARTICIPANT	\N	PRESENT	0
644406	644403	14001X	PARTICIPANT	\N	PRESENT	0
644411	644410	11083R	PARTICIPANT	\N	PRESENT	0
644412	644410	04070G	PARTICIPANT	\N	PRESENT	0
644413	644410	20098N	PARTICIPANT	\N	PRESENT	0
644429	644154	20052X	PARTICIPANT	\N	PRESENT	1
644430	644154	19758L	PARTICIPANT	\N	PRESENT	1
644433	644154	19719D	PARTICIPANT	\N	PRESENT	1
644434	644154	20138D	PARTICIPANT	\N	PRESENT	1
644435	644154	19611R	PRESIDENT	0	PRESENT	0
644436	644154	04085P	PARTICIPANT	\N	PRESENT	0
644437	644154	20022R	PARTICIPANT	\N	PRESENT	1
644438	644154	20110Q	PARTICIPANT	\N	PRESENT	1
644439	644154	11033F	PARTICIPANT	\N	PRESENT	0
644440	644154	17737W	PARTICIPANT	\N	PRESENT	1
644441	644154	04047H	PARTICIPANT	\N	PRESENT	0
638548	637866	11109J	PARTICIPANT	\N	EXCUSE	0
638549	637866	04059M	PARTICIPANT	\N	PRESENT	0
638550	637866	19651A	PARTICIPANT	\N	PRESENT	1
638551	637866	14030Q	PARTICIPANT	\N	PRESENT	0
638552	637866	19643A	PARTICIPANT	\N	PRESENT	0
638553	637866	20152B	PARTICIPANT	\N	PRESENT	0
638554	637866	19758L	PARTICIPANT	\N	PRESENT	0
638555	637866	20264J	PARTICIPANT	\N	PRESENT	0
638556	637866	19693L	PARTICIPANT	\N	PRESENT	0
638557	637866	20124W	PARTICIPANT	\N	PRESENT	0
638558	637866	20132W	PARTICIPANT	\N	PRESENT	0
638559	637866	20172F	PARTICIPANT	\N	PRESENT	0
638560	637866	20180F	PARTICIPANT	\N	PRESENT	0
638561	637866	14123H	PARTICIPANT	\N	PRESENT	0
638562	637866	20048C	PARTICIPANT	\N	PRESENT	1
638563	637866	19399H	PARTICIPANT	\N	PRESENT	0
638564	637866	20056C	PARTICIPANT	\N	PRESENT	0
638565	637866	14073Q	PARTICIPANT	\N	PRESENT	0
638566	637866	19611R	PRESIDENT	0	PRESENT	0
638567	637866	19735D	PARTICIPANT	\N	EXCUSE	0
638568	637866	19699S	PARTICIPANT	\N	PRESENT	0
638569	637866	20052X	PARTICIPANT	\N	PRESENT	0
638570	637866	11104D	PARTICIPANT	\N	PRESENT	0
638571	637866	20142Y	PARTICIPANT	\N	PRESENT	0
638572	637866	14109K	PARTICIPANT	\N	PRESENT	1
638573	637866	19593H	PARTICIPANT	\N	PRESENT	0
638574	637866	19533U	PARTICIPANT	\N	PRESENT	0
638575	637866	14229S	PARTICIPANT	\N	PRESENT	0
638576	637866	20098N	PARTICIPANT	\N	PRESENT	0
638577	637866	19527W	PARTICIPANT	\N	PRESENT	0
638578	637866	20026V	PARTICIPANT	\N	PRESENT	0
638579	637866	20058E	PARTICIPANT	\N	PRESENT	0
638805	638804	19701S	PARTICIPANT	\N	PRESENT	0
638806	638804	19671E	PARTICIPANT	\N	PRESENT	0
638830	638329	19760E	PARTICIPANT	\N	PRESENT	1
638831	638329	11097X	PARTICIPANT	\N	PRESENT	1
638832	638329	14213J	PARTICIPANT	\N	PRESENT	1
638833	638329	19415P	PARTICIPANT	\N	PRESENT	0
638834	638329	11067R	PARTICIPANT	\N	PRESENT	0
638835	638330	19415P	PARTICIPANT	\N	PRESENT	0
638836	638330	14213J	PARTICIPANT	\N	PRESENT	1
638837	638330	19760E	PARTICIPANT	\N	PRESENT	1
638838	638330	11067R	PARTICIPANT	\N	PRESENT	0
640929	640928	04033B	PARTICIPANT	\N	PRESENT	0
640930	640928	11033F	PARTICIPANT	\N	PRESENT	0
640931	640928	17737W	PARTICIPANT	\N	PRESENT	0
640932	640928	10006L	PARTICIPANT	\N	PRESENT	0
640933	640928	19251M	PARTICIPANT	\N	PRESENT	0
640934	640928	07033P	PARTICIPANT	\N	PRESENT	0
640935	640928	14187A	PARTICIPANT	\N	PRESENT	0
640936	640928	19673G	PARTICIPANT	\N	PRESENT	0
640937	640928	20172F	PARTICIPANT	\N	PRESENT	0
640938	640928	19569H	PARTICIPANT	\N	PRESENT	0
640939	640928	19711U	PARTICIPANT	\N	PRESENT	0
640940	640928	11085T	PARTICIPANT	\N	PRESENT	0
640941	640928	19671E	PARTICIPANT	\N	PRESENT	0
640942	640928	14147R	PARTICIPANT	\N	PRESENT	0
640943	640928	19593H	PARTICIPANT	\N	PRESENT	0
640944	640928	11041F	PARTICIPANT	\N	PRESENT	0
640945	640928	20248J	PARTICIPANT	\N	PRESENT	0
641606	641605	04047H	PARTICIPANT	\N	PRESENT	0
641607	641605	19629C	PARTICIPANT	\N	PRESENT	0
641608	641605	11026G	PARTICIPANT	\N	PRESENT	0
641609	641605	10015M	PARTICIPANT	\N	PRESENT	0
643750	643749	99004R	PARTICIPANT	\N	PRESENT	0
643751	643749	19399H	PARTICIPANT	\N	PRESENT	0
644645	644644	05008E	PARTICIPANT	\N	PRESENT	0
644646	644644	11053K	PARTICIPANT	\N	PRESENT	0
644647	644644	01028R	PARTICIPANT	\N	PRESENT	0
646359	646153	14021P	PARTICIPANT	\N	PRESENT	0
646360	646153	19673G	PARTICIPANT	\N	PRESENT	0
646361	646153	14215L	PARTICIPANT	\N	PRESENT	0
646442	646153	14089Y	PARTICIPANT	\N	PRESENT	1
646443	646153	19629C	PARTICIPANT	\N	PRESENT	1
646444	646153	19649G	PARTICIPANT	\N	PRESENT	1
646445	646153	19489J	PARTICIPANT	\N	PRESENT	1
646446	646153	17737W	PARTICIPANT	\N	EXCUSE	0
646505	645740	19766L	PARTICIPANT	\N	PRESENT	0
646506	645740	04070G	PARTICIPANT	\N	PRESENT	0
646507	645740	19699S	PARTICIPANT	\N	PRESENT	0
646508	645740	19533U	PARTICIPANT	\N	PRESENT	0
646509	645740	04033B	PARTICIPANT	\N	PRESENT	0
646510	645740	20098N	PARTICIPANT	\N	PRESENT	1
646511	645740	19573D	PARTICIPANT	\N	PRESENT	0
646512	645740	20112S	PARTICIPANT	\N	PRESENT	0
646513	645740	08012N	PARTICIPANT	\N	PRESENT	0
646514	645740	20124W	PARTICIPANT	\N	PRESENT	0
646515	645740	20026V	PARTICIPANT	\N	PRESENT	0
646516	645740	19527W	PARTICIPANT	\N	PRESENT	0
646517	645740	19593H	PARTICIPANT	\N	PRESENT	0
646518	645740	19643A	PARTICIPANT	\N	PRESENT	1
646519	645740	20132W	PARTICIPANT	\N	PRESENT	0
646520	645740	20134Y	PARTICIPANT	\N	PRESENT	0
646521	645740	14073Q	PARTICIPANT	\N	PRESENT	0
646522	645740	19651A	PARTICIPANT	\N	PRESENT	1
646523	645740	20138D	PARTICIPANT	\N	PRESENT	0
646524	645740	19611R	PRESIDENT	0	PRESENT	0
646525	645740	20142Y	PARTICIPANT	\N	PRESENT	0
646526	645740	20048C	PARTICIPANT	\N	PRESENT	0
646527	645740	19693L	PARTICIPANT	\N	PRESENT	0
646528	645740	19399H	PARTICIPANT	\N	PRESENT	0
646529	645740	20152B	PARTICIPANT	\N	PRESENT	0
646530	645740	20052X	PARTICIPANT	\N	PRESENT	1
646531	645740	19719D	PARTICIPANT	\N	PRESENT	0
646676	646675	14038Y	PARTICIPANT	\N	PRESENT	0
646533	645740	20058E	PARTICIPANT	\N	PRESENT	0
646534	645740	14030Q	PARTICIPANT	\N	PRESENT	0
646535	645740	20056C	PARTICIPANT	\N	PRESENT	0
646536	645740	20180F	PARTICIPANT	\N	PRESENT	0
646537	645740	20264J	PARTICIPANT	\N	PRESENT	0
646538	645740	19735D	PARTICIPANT	\N	PRESENT	0
646539	645740	19057M	PARTICIPANT	\N	PRESENT	0
646540	645740	14109K	PARTICIPANT	\N	PRESENT	0
646541	645740	11043H	PARTICIPANT	\N	PRESENT	0
646542	645740	11104D	PARTICIPANT	\N	PRESENT	0
646543	645740	19758L	PARTICIPANT	\N	PRESENT	0
646544	645740	20084G	PARTICIPANT	\N	PRESENT	0
646545	645740	19621T	PARTICIPANT	\N	PRESENT	0
646678	646677	14038Y	PARTICIPANT	\N	PRESENT	0
646547	646154	20114U	PARTICIPANT	\N	PRESENT	1
646548	646154	19629C	PARTICIPANT	\N	PRESENT	1
646549	646154	04085P	PARTICIPANT	\N	PRESENT	1
646550	646154	19489J	PARTICIPANT	\N	PRESENT	1
646551	646154	17737W	PARTICIPANT	\N	EXCUSE	0
646680	646679	14038Y	PARTICIPANT	\N	PRESENT	0
646694	646693	04047H	PARTICIPANT	\N	PRESENT	0
646695	646693	05008E	PARTICIPANT	\N	PRESENT	0
646696	646693	01028R	PARTICIPANT	\N	PRESENT	0
647201	646155	20114U	PARTICIPANT	\N	PRESENT	1
647202	646155	19629C	PARTICIPANT	\N	PRESENT	1
647203	646155	17737W	PARTICIPANT	\N	EXCUSE	0
647454	647453	14059S	PARTICIPANT	\N	PRESENT	0
647462	647461	14229S	PARTICIPANT	\N	PRESENT	0
647463	647461	14231L	PRESIDENT	0	PRESENT	0
647464	647461	19758L	PARTICIPANT	\N	PRESENT	0
647465	647461	20070A	PARTICIPANT	\N	PRESENT	0
647466	647461	19349W	PARTICIPANT	\N	PRESENT	0
647467	647461	20084G	PARTICIPANT	\N	PRESENT	0
647468	647461	19735D	PARTICIPANT	\N	PRESENT	0
647469	647461	08010L	PARTICIPANT	\N	PRESENT	0
647470	647461	19826F	PARTICIPANT	\N	PRESENT	0
647471	647461	19573D	PARTICIPANT	\N	PRESENT	0
647472	647461	20110Q	PARTICIPANT	\N	PRESENT	0
647473	647461	14151M	PARTICIPANT	\N	PRESENT	0
647474	647461	05012A	PARTICIPANT	\N	PRESENT	0
647475	647461	20090E	PARTICIPANT	\N	PRESENT	0
647476	647461	19447X	PARTICIPANT	\N	PRESENT	0
647477	647461	20022R	PARTICIPANT	\N	PRESENT	0
647478	647461	14215L	PARTICIPANT	\N	PRESENT	0
647521	646290	14121F	PARTICIPANT	\N	PRESENT	0
647588	646198	20914V	PARTICIPANT	\N	PRESENT	0
647589	646198	14331P	PARTICIPANT	\N	EXCUSE	0
647590	646198	11012A	PARTICIPANT	\N	EXCUSE	0
647591	646198	08034U	PARTICIPANT	\N	EXCUSE	0
647592	646198	14189C	PARTICIPANT	\N	EXCUSE	0
647593	645023	14331P	PARTICIPANT	\N	EXCUSE	0
647594	645023	19717B	PRESIDENT	0	PRESENT	0
647595	646198	14083S	PARTICIPANT	\N	PRESENT	0
647596	646198	04071H	PARTICIPANT	\N	PRESENT	0
647597	646198	19647E	PARTICIPANT	\N	PRESENT	0
647598	646198	19711U	PRESIDENT	1	PRESENT	0
649797	649779	04047H	PARTICIPANT	\N	PRESENT	0
649798	649779	05008E	PARTICIPANT	\N	PRESENT	0
649799	649779	14147R	PARTICIPANT	\N	PRESENT	1
650407	649162	11041F	PARTICIPANT	\N	PRESENT	0
650408	649162	20088L	PARTICIPANT	\N	PRESENT	0
650409	649162	11033F	PARTICIPANT	\N	PRESENT	0
650410	649162	14169X	PARTICIPANT	\N	PRESENT	0
650411	649162	20060X	PARTICIPANT	\N	PRESENT	0
650412	649162	04071H	PARTICIPANT	\N	PRESENT	0
650413	649162	11043H	PARTICIPANT	\N	PRESENT	0
650414	649162	11026G	PARTICIPANT	\N	PRESENT	0
650415	649162	18193Q	PARTICIPANT	\N	PRESENT	0
650416	649162	01048V	PARTICIPANT	\N	PRESENT	0
650417	649162	08012N	PARTICIPANT	\N	PRESENT	0
650418	649162	20070A	PARTICIPANT	\N	PRESENT	0
650419	649162	20080C	PARTICIPANT	\N	PRESENT	0
650420	649162	19413M	PARTICIPANT	\N	PRESENT	0
650421	649162	14223L	PARTICIPANT	\N	PRESENT	0
650422	649162	20130U	PARTICIPANT	\N	PRESENT	0
650423	649162	19671E	PARTICIPANT	\N	PRESENT	0
650424	649162	05012A	PARTICIPANT	\N	PRESENT	0
650425	649162	19531S	PARTICIPANT	\N	PRESENT	0
650426	649162	20022R	PARTICIPANT	\N	PRESENT	0
650427	649162	20264J	PARTICIPANT	\N	PRESENT	0
650428	649162	19251M	PARTICIPANT	\N	PRESENT	0
650429	649162	20018V	PARTICIPANT	\N	PRESENT	0
650430	649162	14331P	PARTICIPANT	\N	PRESENT	0
650431	649162	20094J	PARTICIPANT	\N	PRESENT	0
650432	649162	08056B	PARTICIPANT	\N	PRESENT	0
650433	649162	19503N	PARTICIPANT	\N	PRESENT	0
650434	649162	20172F	PARTICIPANT	\N	PRESENT	0
650435	649162	20026V	PARTICIPANT	\N	PRESENT	0
650436	649162	20084G	PARTICIPANT	\N	PRESENT	0
650437	649162	19399H	PARTICIPANT	\N	PRESENT	0
650438	649162	17965H	PARTICIPANT	\N	PRESENT	0
650439	649162	86034E	PARTICIPANT	\N	PRESENT	0
650440	649162	19669L	PARTICIPANT	\N	PRESENT	0
650446	649162	19441R	PARTICIPANT	\N	PRESENT	0
650442	649162	20064C	PARTICIPANT	\N	PRESENT	0
650443	649162	19713W	PARTICIPANT	\N	PRESENT	0
650444	649162	20052X	PARTICIPANT	\N	PRESENT	0
650445	649162	20042V	PARTICIPANT	\N	PRESENT	0
650447	649162	19619A	PARTICIPANT	\N	PRESENT	0
650448	649162	19479G	PARTICIPANT	\N	PRESENT	0
650449	649162	19735D	PARTICIPANT	\N	PRESENT	0
650450	649162	14219Q	PARTICIPANT	\N	PRESENT	0
650451	649162	14042U	PARTICIPANT	\N	PRESENT	0
650452	649162	19739H	PARTICIPANT	\N	PRESENT	0
650453	649162	16685X	PARTICIPANT	\N	PRESENT	0
650454	649162	14205J	PARTICIPANT	\N	PRESENT	0
650455	649162	20144B	PARTICIPANT	\N	PRESENT	0
650456	649162	11053K	PARTICIPANT	\N	PRESENT	0
650457	649162	19369B	PARTICIPANT	\N	PRESENT	0
650458	649162	19611R	PARTICIPANT	\N	PRESENT	0
650465	649162	19543W	PARTICIPANT	\N	PRESENT	0
650460	649162	14179A	PARTICIPANT	\N	PRESENT	0
650461	649162	19745F	PARTICIPANT	\N	PRESENT	0
650462	649162	14053L	PARTICIPANT	\N	PRESENT	0
650463	649162	17229F	PARTICIPANT	\N	PRESENT	0
650464	649162	20298U	PARTICIPANT	\N	PRESENT	0
650466	649162	17023S	PARTICIPANT	\N	PRESENT	0
650467	649162	14089Y	PARTICIPANT	\N	PRESENT	0
650468	649162	14083S	PARTICIPANT	\N	PRESENT	0
650469	649162	14073Q	PARTICIPANT	\N	PRESENT	0
650470	649162	20040T	PARTICIPANT	\N	PRESENT	0
650471	649162	19749K	PARTICIPANT	\N	PRESENT	0
650472	649162	14189C	PARTICIPANT	\N	PRESENT	0
650473	649162	14255U	PARTICIPANT	\N	PRESENT	0
650474	649162	20286Q	PARTICIPANT	\N	PRESENT	0
650475	649162	11085T	PARTICIPANT	\N	PRESENT	0
650476	649162	19577H	PARTICIPANT	\N	PRESENT	0
650477	649162	20066E	PARTICIPANT	\N	PRESENT	0
650478	649162	04070G	PARTICIPANT	\N	PRESENT	0
650479	649162	01024M	PARTICIPANT	\N	PRESENT	0
650480	649162	14030Q	PARTICIPANT	\N	PRESENT	0
650481	649162	14327T	PARTICIPANT	\N	PRESENT	0
650482	649162	01043Q	PARTICIPANT	\N	PRESENT	0
650483	649162	19699S	PARTICIPANT	\N	PRESENT	0
650484	649162	20248J	PARTICIPANT	\N	PRESENT	0
650485	649162	19717B	PARTICIPANT	\N	PRESENT	0
650486	649162	14107H	PARTICIPANT	\N	PRESENT	0
650487	649162	19583F	PARTICIPANT	\N	PRESENT	0
650488	649162	20050V	PARTICIPANT	\N	PRESENT	0
650501	649162	20086J	PARTICIPANT	\N	PRESENT	0
650490	649162	19565D	PARTICIPANT	\N	PRESENT	0
650502	649162	20104S	PARTICIPANT	\N	PRESENT	0
650492	649162	19057M	PARTICIPANT	\N	PRESENT	0
650493	649162	19820Y	PARTICIPANT	\N	PRESENT	0
650495	650494	05008E	PARTICIPANT	\N	PRESENT	0
650496	650494	11053K	PARTICIPANT	\N	PRESENT	0
650497	650494	01028R	PARTICIPANT	\N	PRESENT	0
650498	649162	07033P	PARTICIPANT	\N	PRESENT	0
650499	649162	19768N	PARTICIPANT	\N	PRESENT	0
650500	649162	95041E	PARTICIPANT	\N	PRESENT	0
650503	649162	04043D	PARTICIPANT	\N	PRESENT	0
650506	649162	14055N	PARTICIPANT	\N	PRESENT	0
650775	649163	99004R	PARTICIPANT	\N	PRESENT	0
650507	649162	20048C	PARTICIPANT	\N	PRESENT	0
650776	649163	11056N	PARTICIPANT	\N	PRESENT	0
650777	649163	95063L	PARTICIPANT	\N	PRESENT	0
650778	649163	04047H	PARTICIPANT	\N	PRESENT	0
650779	649163	19649G	PARTICIPANT	\N	PRESENT	0
650780	649163	19683J	PARTICIPANT	\N	PRESENT	0
650781	649163	11045K	PARTICIPANT	\N	PRESENT	0
650782	649163	18193Q	PARTICIPANT	\N	PRESENT	0
650783	649163	14121F	PARTICIPANT	\N	PRESENT	0
650784	649163	19715Y	PARTICIPANT	\N	PRESENT	0
650785	649163	11077T	PARTICIPANT	\N	PRESENT	0
650786	649163	14001X	PARTICIPANT	\N	PRESENT	0
650787	649163	19301E	PARTICIPANT	\N	PRESENT	0
650788	649163	20036X	PARTICIPANT	\N	PRESENT	0
650789	649163	20914V	PARTICIPANT	\N	PRESENT	0
650790	649163	19387D	PARTICIPANT	\N	PRESENT	0
650791	649163	19553Y	PARTICIPANT	\N	PRESENT	0
650792	649163	19545Y	PARTICIPANT	\N	PRESENT	0
650793	649163	04057K	PARTICIPANT	\N	PRESENT	0
650794	649163	14195A	PARTICIPANT	\N	PRESENT	0
650795	649163	19745F	PARTICIPANT	\N	PRESENT	0
650796	649163	14089Y	PARTICIPANT	\N	PRESENT	0
650797	649163	20066E	PARTICIPANT	\N	PRESENT	0
650798	649163	19577H	PARTICIPANT	\N	PRESENT	0
650799	649163	14215L	PARTICIPANT	\N	PRESENT	0
650800	649163	14021P	PARTICIPANT	\N	PRESENT	0
650801	649163	20110Q	PARTICIPANT	\N	PRESENT	0
650803	649163	20248J	PARTICIPANT	\N	PRESENT	0
650804	649163	20252E	PARTICIPANT	\N	PRESENT	0
650805	649163	19581D	PARTICIPANT	\N	PRESENT	0
650806	649163	19367Y	PARTICIPANT	\N	PRESENT	0
650807	649163	10006L	PARTICIPANT	\N	PRESENT	0
650808	649163	14187A	PARTICIPANT	\N	PRESENT	0
650809	649163	20074E	PARTICIPANT	\N	PRESENT	0
650810	649163	17367Q	PARTICIPANT	\N	PRESENT	0
650811	649163	20090E	PARTICIPANT	\N	PRESENT	0
650812	649163	20062A	PARTICIPANT	\N	PRESENT	0
650813	649163	18083K	PARTICIPANT	\N	PRESENT	0
650814	649163	19441R	PARTICIPANT	\N	PRESENT	0
650815	649163	20136B	PARTICIPANT	\N	PRESENT	0
650816	649163	20082E	PARTICIPANT	\N	PRESENT	0
650817	649163	19413M	PARTICIPANT	\N	PRESENT	0
650818	649163	14275Y	PARTICIPANT	\N	PRESENT	0
650819	649163	14281W	PARTICIPANT	\N	PRESENT	0
650820	649163	20038A	PARTICIPANT	\N	PRESENT	0
650821	649163	12016W	PARTICIPANT	\N	PRESENT	0
650822	649163	20130U	PARTICIPANT	\N	PRESENT	0
650823	649163	20286Q	PARTICIPANT	\N	PRESENT	0
650824	649163	20098N	PARTICIPANT	\N	PRESENT	0
650825	649163	19798U	PARTICIPANT	\N	PRESENT	0
650826	649163	14071N	PARTICIPANT	\N	PRESENT	0
650827	649163	20044X	PARTICIPANT	\N	PRESENT	0
650828	649163	04033B	PARTICIPANT	\N	PRESENT	0
650829	649163	19768N	PARTICIPANT	\N	PRESENT	0
650830	649163	19729F	PARTICIPANT	\N	PRESENT	0
650831	649163	20108W	PARTICIPANT	\N	PRESENT	0
650832	649163	19447X	PARTICIPANT	\N	PRESENT	0
650833	649163	19782L	PARTICIPANT	\N	PRESENT	0
650834	649163	19525U	PARTICIPANT	\N	PRESENT	0
650835	649163	11031D	PARTICIPANT	\N	PRESENT	0
650836	649163	19479G	PARTICIPANT	\N	PRESENT	0
650837	649163	20100N	PARTICIPANT	\N	PRESENT	0
650838	649163	01025N	PARTICIPANT	\N	PRESENT	0
650839	649163	04092N	PARTICIPANT	\N	PRESENT	0
631778	631777	19711U	PARTICIPANT	\N	PRESENT	0
633703	631641	19673G	PARTICIPANT	\N	EXCUSE	0
632013	631460	14089Y	PARTICIPANT	\N	PRESENT	0
632014	631460	17367Q	PARTICIPANT	\N	PRESENT	0
632016	631460	20108W	PARTICIPANT	\N	PRESENT	0
632018	631460	11056N	PRESIDENT	0	PRESENT	0
632019	631460	95063L	PARTICIPANT	\N	PRESENT	0
632045	631460	14053L	PARTICIPANT	\N	PRESENT	0
632190	631460	20040T	PARTICIPANT	\N	PRESENT	0
634236	634228	19369B	PARTICIPANT	\N	PRESENT	0
634234	634228	14033T	PARTICIPANT	\N	PRESENT	0
634235	634228	20018V	PARTICIPANT	\N	PRESENT	0
634334	634171	14231L	PRESIDENT	0	PRESENT	0
634335	634171	19489J	PARTICIPANT	\N	PRESENT	0
634336	634171	14151M	PARTICIPANT	\N	PRESENT	0
634337	634171	19758L	PARTICIPANT	\N	PRESENT	0
634338	634171	19349W	PARTICIPANT	\N	PRESENT	0
634339	634171	14215L	PARTICIPANT	\N	PRESENT	0
634340	634171	14217N	PARTICIPANT	\N	PRESENT	0
634341	634171	20090E	PARTICIPANT	\N	PRESENT	0
634342	634171	20110Q	PARTICIPANT	\N	PRESENT	0
634343	634171	01057W	PARTICIPANT	\N	PRESENT	0
634344	634171	19333N	PARTICIPANT	\N	PRESENT	0
634345	634171	14187A	PARTICIPANT	\N	PRESENT	0
634346	634171	20062A	PARTICIPANT	\N	PRESENT	0
634347	634171	17637T	PARTICIPANT	\N	PRESENT	0
634349	634171	19820Y	PARTICIPANT	\N	PRESENT	0
634350	634171	14053L	PARTICIPANT	\N	PRESENT	0
634351	634171	20084G	PARTICIPANT	\N	PRESENT	0
634352	634171	19826F	PARTICIPANT	\N	PRESENT	0
634353	634171	14229S	PARTICIPANT	\N	PRESENT	0
634354	634171	20070A	PARTICIPANT	\N	PRESENT	0
634355	634171	19447X	PARTICIPANT	\N	PRESENT	0
634356	634171	19565D	PARTICIPANT	\N	PRESENT	0
634357	634171	14257W	PARTICIPANT	\N	PRESENT	0
634358	634171	14205J	PARTICIPANT	\N	PRESENT	0
634359	634171	14327T	PARTICIPANT	\N	EXCUSE	0
634421	634026	18083K	PARTICIPANT	\N	EXCUSE	0
634438	631705	04059M	PARTICIPANT	\N	PRESENT	0
634439	631705	19651A	PARTICIPANT	\N	PRESENT	1
634462	634035	04059M	PARTICIPANT	\N	PRESENT	0
634463	634035	19651A	PARTICIPANT	\N	PRESENT	1
634750	634326	14275Y	PARTICIPANT	\N	PRESENT	0
634751	634326	11010L	PARTICIPANT	\N	PRESENT	0
634752	634326	20110Q	PARTICIPANT	\N	PRESENT	0
634467	634035	11053K	PARTICIPANT	\N	PRESENT	0
634753	634326	14215L	PRESIDENT	0	PRESENT	0
634447	631705	19725B	PARTICIPANT	\N	PRESENT	0
634448	631705	19399H	PARTICIPANT	\N	PRESENT	0
634754	634326	14259Y	PARTICIPANT	\N	PRESENT	0
634450	631705	19611R	PRESIDENT	0	PRESENT	0
634451	631705	19699S	PARTICIPANT	\N	PRESENT	0
634755	634326	01028R	PARTICIPANT	\N	PRESENT	0
634453	631705	20142Y	PARTICIPANT	\N	PRESENT	0
634454	631705	19705W	PARTICIPANT	\N	PRESENT	1
634455	631705	14229S	PARTICIPANT	\N	PRESENT	1
634756	634326	11072N	PARTICIPANT	\N	PRESENT	0
634791	634647	20108W	PARTICIPANT	\N	PRESENT	0
634471	634035	19725B	PARTICIPANT	\N	PRESENT	0
634472	634035	19399H	PARTICIPANT	\N	PRESENT	0
634473	634035	20056C	PARTICIPANT	\N	PRESENT	1
634474	634035	19611R	PRESIDENT	0	PRESENT	0
634475	634035	19699S	PARTICIPANT	\N	PRESENT	0
634792	634647	14215L	PARTICIPANT	\N	PRESENT	0
634477	634035	20142Y	PARTICIPANT	\N	PRESENT	0
634478	634035	19705W	PARTICIPANT	\N	PRESENT	1
634479	634035	14229S	PARTICIPANT	\N	PRESENT	1
634480	634035	19669L	PARTICIPANT	\N	PRESENT	1
634481	634035	20026V	PARTICIPANT	\N	PRESENT	1
634482	634035	20122U	PARTICIPANT	\N	PRESENT	0
634793	634647	11010L	PARTICIPANT	\N	PRESENT	0
634794	634647	20098N	PARTICIPANT	\N	PRESENT	0
634795	634647	19687N	PARTICIPANT	\N	PRESENT	0
634796	634647	19691J	PARTICIPANT	\N	PRESENT	0
634797	634647	14021P	PARTICIPANT	\N	PRESENT	0
634799	634647	19725B	PARTICIPANT	\N	PRESENT	0
634800	634647	11070L	PARTICIPANT	\N	PRESENT	0
634801	634647	11085T	PARTICIPANT	\N	PRESENT	0
634805	634647	20034V	PARTICIPANT	\N	PRESENT	0
636142	634654	20044X	PARTICIPANT	\N	PRESENT	0
636143	634654	19563B	PARTICIPANT	\N	PRESENT	0
636170	634654	01062T	PARTICIPANT	\N	PRESENT	0
636145	634654	19663E	PARTICIPANT	\N	PRESENT	0
636146	634654	19585H	PARTICIPANT	\N	PRESENT	0
636147	634654	19507S	PARTICIPANT	\N	PRESENT	0
636148	634654	08018U	PARTICIPANT	\N	PRESENT	0
636149	634654	19657G	PARTICIPANT	\N	PRESENT	0
636150	634654	14059S	PARTICIPANT	\N	PRESENT	0
636161	634654	04042C	PARTICIPANT	\N	PRESENT	0
636152	634654	08015R	PARTICIPANT	\N	PRESENT	0
636153	634654	20126Y	PARTICIPANT	\N	PRESENT	0
636154	634654	20054A	PARTICIPANT	\N	PRESENT	0
636156	634654	12041X	PARTICIPANT	\N	PRESENT	0
636159	634654	20066E	PARTICIPANT	\N	PRESENT	0
636160	634654	20090E	PARTICIPANT	\N	PRESENT	0
636163	634654	14205J	PARTICIPANT	\N	PRESENT	0
636164	634654	14097Y	PARTICIPANT	\N	PRESENT	0
636165	634654	14259Y	PARTICIPANT	\N	PRESENT	0
636169	634654	19709B	PARTICIPANT	\N	PRESENT	0
636167	634654	19707Y	PARTICIPANT	\N	PRESENT	0
636168	634654	14069U	PARTICIPANT	\N	PRESENT	0
636171	634654	19739H	PARTICIPANT	\N	PRESENT	0
636172	634654	04008A	PARTICIPANT	\N	PRESENT	0
636179	634654	08069G	PARTICIPANT	\N	PRESENT	0
636181	634654	19565D	PARTICIPANT	\N	PRESENT	0
636178	634654	01048V	PARTICIPANT	\N	PRESENT	0
636180	634654	14123H	PARTICIPANT	\N	PRESENT	0
636184	634654	19693L	PARTICIPANT	\N	PRESENT	0
636186	634654	16685X	PARTICIPANT	\N	PRESENT	0
636188	634654	95063L	PARTICIPANT	\N	PRESENT	0
636190	634654	20144B	PARTICIPANT	\N	PRESENT	0
636191	634654	01060R	PARTICIPANT	\N	PRESENT	0
636225	634654	19551W	PARTICIPANT	\N	PRESENT	0
636244	634654	20040T	PARTICIPANT	\N	PRESENT	0
636522	634655	86034E	PARTICIPANT	\N	PRESENT	0
636524	634655	01062T	PARTICIPANT	\N	PRESENT	0
636525	634655	14267Y	PARTICIPANT	\N	PRESENT	0
636526	634655	95063L	PARTICIPANT	\N	PRESENT	0
636527	634655	12041X	PARTICIPANT	\N	PRESENT	0
636528	634655	20072C	PARTICIPANT	\N	PRESENT	0
636529	634655	14251Q	PARTICIPANT	\N	PRESENT	0
636530	634655	19347U	PARTICIPANT	\N	PRESENT	0
636534	634655	17023S	PARTICIPANT	\N	PRESENT	0
636537	634655	14255U	PARTICIPANT	\N	PRESENT	0
636538	634655	19745F	PARTICIPANT	\N	PRESENT	0
636539	634655	19479G	PARTICIPANT	\N	PRESENT	0
636540	634655	20252E	PARTICIPANT	\N	PRESENT	0
636541	634655	07033P	PARTICIPANT	\N	PRESENT	0
636542	634655	18193Q	PARTICIPANT	\N	PRESENT	0
636543	634655	20264J	PARTICIPANT	\N	PRESENT	0
636544	634655	19683J	PARTICIPANT	\N	PRESENT	0
636545	634655	19413M	PARTICIPANT	\N	PRESENT	0
636546	634655	19637C	PARTICIPANT	\N	PRESENT	0
636547	634655	19565D	PARTICIPANT	\N	PRESENT	0
636548	634655	11056N	PARTICIPANT	\N	PRESENT	0
636549	634655	19525U	PARTICIPANT	\N	PRESENT	0
636550	634655	11026G	PARTICIPANT	\N	PRESENT	0
636551	634655	19515S	PARTICIPANT	\N	PRESENT	0
636552	634655	19443T	PARTICIPANT	\N	PRESENT	0
636553	634655	14225N	PARTICIPANT	\N	PRESENT	0
636554	634655	07029T	PARTICIPANT	\N	PRESENT	0
636555	634655	11077T	PARTICIPANT	\N	PRESENT	0
636556	634655	19507S	PARTICIPANT	\N	PRESENT	0
636557	634655	20044X	PARTICIPANT	\N	PRESENT	0
636558	634655	20172F	PARTICIPANT	\N	PRESENT	0
636559	634655	20064C	PARTICIPANT	\N	PRESENT	0
636560	634655	10015M	PARTICIPANT	\N	PRESENT	0
636561	634655	01028R	PARTICIPANT	\N	PRESENT	0
636562	634655	14193X	PARTICIPANT	\N	PRESENT	0
636563	634655	20084G	PARTICIPANT	\N	PRESENT	0
636564	634655	11054L	PARTICIPANT	\N	PRESENT	0
636565	634655	14187A	PARTICIPANT	\N	PRESENT	0
636566	634655	19695N	PARTICIPANT	\N	PRESENT	0
636567	634655	11012A	PARTICIPANT	\N	PRESENT	0
636568	634655	19583F	PARTICIPANT	\N	PRESENT	0
636569	634655	19647E	PARTICIPANT	\N	PRESENT	0
636570	634655	08034U	PARTICIPANT	\N	PRESENT	0
636571	634655	14073Q	PARTICIPANT	\N	PRESENT	0
636572	634655	04033B	PARTICIPANT	\N	PRESENT	0
636573	634655	20024T	PARTICIPANT	\N	PRESENT	0
644442	644154	14053L	PARTICIPANT	\N	PRESENT	1
644443	644154	19629C	PARTICIPANT	\N	PRESENT	1
644444	644154	11056N	PARTICIPANT	\N	PRESENT	1
644445	644154	14215L	PARTICIPANT	\N	PRESENT	1
644446	644154	20074E	PARTICIPANT	\N	PRESENT	1
644447	644154	14231L	PARTICIPANT	\N	PRESENT	0
644448	644154	14179A	PARTICIPANT	\N	PRESENT	1
644449	644154	14021P	PARTICIPANT	\N	PRESENT	0
644450	644154	19489J	PARTICIPANT	\N	PRESENT	1
644451	644154	19649G	PARTICIPANT	\N	PRESENT	0
644452	644154	11026G	PARTICIPANT	\N	PRESENT	0
644453	644154	14001X	PARTICIPANT	\N	PRESENT	1
644454	644154	14147R	PARTICIPANT	\N	PRESENT	1
644455	644154	01028R	PARTICIPANT	\N	PRESENT	1
644456	644312	20026V	PARTICIPANT	\N	PRESENT	1
644457	644312	19719D	PARTICIPANT	\N	PRESENT	1
644458	644312	19766L	PARTICIPANT	\N	PRESENT	1
644459	644312	14123H	PARTICIPANT	\N	PRESENT	1
644460	644312	19758L	PARTICIPANT	\N	PRESENT	1
644461	644312	20022R	PARTICIPANT	\N	PRESENT	1
644462	644312	20110Q	PARTICIPANT	\N	PRESENT	1
644463	644312	11033F	PARTICIPANT	\N	PRESENT	1
644464	644312	04047H	PARTICIPANT	\N	PRESENT	0
644465	644312	19629C	PARTICIPANT	\N	PRESENT	1
644466	644312	11056N	PARTICIPANT	\N	PRESENT	1
644467	644312	14215L	PARTICIPANT	\N	PRESENT	1
644468	644312	14151M	PARTICIPANT	\N	PRESENT	1
644469	644312	19673G	PARTICIPANT	\N	PRESENT	0
644470	644312	14021P	PARTICIPANT	\N	PRESENT	0
644471	644312	19649G	PARTICIPANT	\N	PRESENT	0
644472	644312	11026G	PARTICIPANT	\N	PRESENT	0
644473	644312	14147R	PARTICIPANT	\N	PRESENT	0
644474	644155	20026V	PARTICIPANT	\N	PRESENT	1
644475	644155	19719D	PARTICIPANT	\N	PRESENT	1
644476	644155	14123H	PARTICIPANT	\N	PRESENT	1
644477	644155	19766L	PARTICIPANT	\N	PRESENT	1
644478	644155	19758L	PARTICIPANT	\N	PRESENT	1
644479	644155	20022R	PARTICIPANT	\N	PRESENT	1
644480	644155	20110Q	PARTICIPANT	\N	PRESENT	1
644481	644155	11033F	PARTICIPANT	\N	PRESENT	1
644482	644155	04047H	PARTICIPANT	\N	PRESENT	0
644483	644155	19629C	PARTICIPANT	\N	PRESENT	1
644484	644155	11056N	PARTICIPANT	\N	PRESENT	1
644485	644155	14215L	PARTICIPANT	\N	PRESENT	1
644486	644155	20074E	PARTICIPANT	\N	PRESENT	1
644487	644155	14151M	PARTICIPANT	\N	PRESENT	1
644488	644155	19673G	PARTICIPANT	\N	PRESENT	0
644489	644155	14021P	PARTICIPANT	\N	PRESENT	0
644490	644155	19649G	PARTICIPANT	\N	PRESENT	1
644491	644155	11026G	PARTICIPANT	\N	PRESENT	0
644492	644155	14147R	PARTICIPANT	\N	PRESENT	0
644505	644493	20132W	PARTICIPANT	\N	PRESENT	0
644506	644493	19643A	PARTICIPANT	\N	PRESENT	0
644526	644422	07004J	PARTICIPANT	\N	EXCUSE	0
644527	644422	04047H	PRESIDENT	0	PRESENT	0
644531	644513	20110Q	PARTICIPANT	\N	PRESENT	0
644532	644513	04047H	PARTICIPANT	\N	PRESENT	0
644533	644513	14053L	PARTICIPANT	\N	PRESENT	0
644534	644513	14147R	PARTICIPANT	\N	PRESENT	0
644535	644513	14107H	PARTICIPANT	\N	PRESENT	0
644538	644537	19667J	PARTICIPANT	\N	PRESENT	0
644539	644537	11040E	PARTICIPANT	\N	PRESENT	0
644541	644540	07029T	PARTICIPANT	\N	PRESENT	0
644543	644542	20080C	PARTICIPANT	\N	PRESENT	0
644549	644547	20080C	PARTICIPANT	\N	PRESENT	0
644552	644551	20080C	PARTICIPANT	\N	PRESENT	0
644554	644553	20070A	PARTICIPANT	\N	PRESENT	0
644555	644553	11110B	PARTICIPANT	\N	PRESENT	0
644567	644566	20070A	PARTICIPANT	\N	PRESENT	0
644568	644566	11110B	PARTICIPANT	\N	PRESENT	0
644628	644374	14089Y	PARTICIPANT	\N	EXCUSE	0
644629	644374	19629C	PARTICIPANT	\N	EXCUSE	0
644630	644374	07004J	PARTICIPANT	\N	EXCUSE	0
644631	644374	20022R	PARTICIPANT	\N	EXCUSE	0
644632	644374	01028R	PARTICIPANT	\N	EXCUSE	0
644635	644374	20074E	PARTICIPANT	\N	PRESENT	0
644636	644374	04085P	PARTICIPANT	\N	PRESENT	0
644637	644374	95063L	PARTICIPANT	\N	PRESENT	0
644638	644374	19673G	PARTICIPANT	\N	PRESENT	0
644639	644374	14147R	PARTICIPANT	\N	PRESENT	0
644640	644374	04047H	PRESIDENT	0	PRESENT	0
644739	644738	14059S	PARTICIPANT	\N	PRESENT	0
644771	644770	19667J	PARTICIPANT	\N	PRESENT	0
644772	644770	11040E	PARTICIPANT	\N	PRESENT	0
644827	644826	07029T	PARTICIPANT	\N	PRESENT	0
644829	644828	07029T	PARTICIPANT	\N	PRESENT	0
644831	644830	20070A	PARTICIPANT	\N	PRESENT	0
644832	644830	11110B	PARTICIPANT	\N	PRESENT	0
644857	644855	19593H	PARTICIPANT	\N	PRESENT	0
644858	644855	20026V	PARTICIPANT	\N	PRESENT	1
644859	644855	20180F	PARTICIPANT	\N	PRESENT	1
644860	644855	14123H	PARTICIPANT	\N	PRESENT	1
644861	644856	20026V	PARTICIPANT	\N	PRESENT	1
644862	644856	19593H	PARTICIPANT	\N	PRESENT	0
644868	642970	14189C	PARTICIPANT	\N	EXCUSE	0
644869	642970	20024T	PARTICIPANT	\N	PRESENT	0
644870	642970	20138D	PARTICIPANT	\N	EXCUSE	0
644871	642970	20080C	PARTICIPANT	\N	EXCUSE	0
644872	642970	19621T	PARTICIPANT	\N	PRESENT	1
644873	642970	11031D	PARTICIPANT	\N	PRESENT	0
644874	642970	14179A	PARTICIPANT	\N	PRESENT	1
644875	642970	11045K	PARTICIPANT	\N	PRESENT	0
644876	642970	20098N	PARTICIPANT	\N	EXCUSE	0
644877	642970	19749K	PARTICIPANT	\N	PRESENT	1
644878	642970	20118Y	PARTICIPANT	\N	PRESENT	1
644879	642970	14030Q	PRESIDENT	0	PRESENT	0
644883	642970	14109K	PARTICIPANT	\N	PRESENT	1
644914	644407	19673G	PARTICIPANT	\N	EXCUSE	0
644916	644915	14255U	PARTICIPANT	\N	PRESENT	0
644917	644915	11056N	PARTICIPANT	\N	PRESENT	0
644918	644915	17229F	PARTICIPANT	\N	PRESENT	0
644919	644915	08012N	PARTICIPANT	\N	PRESENT	0
644920	644915	04043D	PARTICIPANT	\N	PRESENT	0
644921	644915	20084G	PARTICIPANT	\N	PRESENT	0
644924	644923	14193X	PARTICIPANT	\N	PRESENT	0
644925	644923	19565D	PARTICIPANT	\N	PRESENT	0
644926	644923	14097Y	PARTICIPANT	\N	PRESENT	0
644927	644923	04042C	PARTICIPANT	\N	PRESENT	0
644928	644923	01024M	PARTICIPANT	\N	PRESENT	0
644929	644923	08047A	PARTICIPANT	\N	PRESENT	0
644930	644923	14249W	PARTICIPANT	\N	PRESENT	0
644931	644923	14267Y	PARTICIPANT	\N	PRESENT	0
644932	644923	11066Q	PARTICIPANT	\N	PRESENT	0
644933	644923	19443T	PARTICIPANT	\N	PRESENT	0
644934	644923	20042V	PARTICIPANT	\N	PRESENT	0
644935	644923	16685X	PARTICIPANT	\N	PRESENT	0
644936	644923	17023S	PARTICIPANT	\N	PRESENT	0
644937	644923	11083R	PARTICIPANT	\N	PRESENT	0
644938	644407	19717B	PRESIDENT	0	PRESENT	0
644939	644407	19631V	PARTICIPANT	\N	PRESENT	1
644940	644407	18083K	PARTICIPANT	\N	PRESENT	1
644941	644407	19577H	PARTICIPANT	\N	PRESENT	1
644942	644407	19691J	PARTICIPANT	\N	PRESENT	0
644943	644407	20034V	PARTICIPANT	\N	EXCUSE	0
644944	644407	14097Y	PARTICIPANT	\N	PRESENT	0
644945	644407	19657G	PARTICIPANT	\N	PRESENT	1
644946	644407	14147R	PARTICIPANT	\N	PRESENT	1
644947	644407	19701S	PARTICIPANT	\N	PRESENT	1
644948	644407	14031R	PARTICIPANT	\N	PRESENT	1
644952	644951	20076G	PARTICIPANT	\N	PRESENT	0
644953	644951	19826F	PARTICIPANT	\N	PRESENT	0
644954	644951	14205J	PARTICIPANT	\N	PRESENT	0
644958	644957	20024T	PARTICIPANT	\N	PRESENT	0
644959	644957	14219Q	PARTICIPANT	\N	PRESENT	0
644960	644957	19549D	PARTICIPANT	\N	PRESENT	0
644961	644957	19251M	PARTICIPANT	\N	PRESENT	0
644964	644962	20076G	PARTICIPANT	\N	PRESENT	0
644965	644962	19826F	PARTICIPANT	\N	PRESENT	0
644966	644962	20054A	PARTICIPANT	\N	PRESENT	0
644970	644963	19701S	PARTICIPANT	\N	PRESENT	0
644971	644963	14001X	PARTICIPANT	\N	PRESENT	0
644978	644974	20054A	PARTICIPANT	\N	PRESENT	0
644976	644974	20076G	PARTICIPANT	\N	PRESENT	0
644977	644974	14205J	PARTICIPANT	\N	PRESENT	0
644979	644974	19826F	PARTICIPANT	\N	PRESENT	0
645126	645125	10015M	PARTICIPANT	\N	PRESENT	0
645128	645127	19699S	PARTICIPANT	\N	PRESENT	0
645130	645129	07029T	PARTICIPANT	\N	PRESENT	0
645132	645131	19667J	PARTICIPANT	\N	PRESENT	0
645133	645131	11040E	PARTICIPANT	\N	PRESENT	0
629118	629117	19619A	PARTICIPANT	\N	PRESENT	0
631780	631779	14225N	PARTICIPANT	\N	PRESENT	0
631781	631779	01057W	PARTICIPANT	\N	PRESENT	0
631782	631779	11048N	PARTICIPANT	\N	PRESENT	0
631784	631783	20252E	PARTICIPANT	\N	PRESENT	0
631785	630825	11031D	PARTICIPANT	\N	PRESENT	1
631786	630825	19467C	PARTICIPANT	\N	EXCUSE	0
631787	630825	10006L	PARTICIPANT	\N	PRESENT	0
631788	630825	19683J	PRESIDENT	0	PRESENT	0
631789	630825	20130U	PARTICIPANT	\N	PRESENT	1
631790	630825	14147R	PARTICIPANT	\N	PRESENT	1
631791	630825	19723Y	PARTICIPANT	\N	PRESENT	1
631792	630825	19553Y	PARTICIPANT	\N	PRESENT	0
633246	633245	14089Y	PARTICIPANT	\N	PRESENT	0
635869	634363	19533U	PRESIDENT	0	PRESENT	0
635870	634363	14207L	PARTICIPANT	\N	PRESENT	0
638029	635818	19697Q	PARTICIPANT	\N	PRESENT	0
638030	635818	19679N	PARTICIPANT	\N	PRESENT	0
638031	635818	14213J	PARTICIPANT	\N	PRESENT	0
638032	638028	14281W	PARTICIPANT	\N	PRESENT	0
638033	638028	14213J	PARTICIPANT	\N	PRESENT	0
638034	638028	19697Q	PARTICIPANT	\N	PRESENT	0
638035	638028	19679N	PARTICIPANT	\N	PRESENT	0
638075	638015	14133K	PARTICIPANT	\N	PRESENT	0
638076	638015	14089Y	PARTICIPANT	\N	PRESENT	0
638077	638015	14207L	PARTICIPANT	\N	EXCUSE	0
638078	638015	19725B	PARTICIPANT	\N	PRESENT	1
638079	638015	20128B	PARTICIPANT	\N	PRESENT	1
638080	638015	19333N	PARTICIPANT	\N	PRESENT	0
638081	638015	14097Y	PARTICIPANT	\N	PRESENT	0
638082	638015	11026G	PARTICIPANT	\N	PRESENT	0
638083	638015	14331P	PRESIDENT	0	PRESENT	0
638084	638015	04070G	PARTICIPANT	\N	PRESENT	0
638085	638015	14169X	PARTICIPANT	\N	PRESENT	0
638086	638015	14189C	PARTICIPANT	\N	PRESENT	0
639552	639551	14133K	PARTICIPANT	\N	PRESENT	1
639553	639551	11083R	PARTICIPANT	\N	PRESENT	1
639554	639551	11066Q	PARTICIPANT	\N	PRESENT	1
639556	639555	14133K	PARTICIPANT	\N	PRESENT	0
639557	639555	11027H	PARTICIPANT	\N	PRESENT	0
639558	639555	11083R	PARTICIPANT	\N	PRESENT	0
642254	642253	04047H	PARTICIPANT	\N	PRESENT	0
642255	642253	04042C	PARTICIPANT	\N	PRESENT	0
642256	642253	14053L	PARTICIPANT	\N	PRESENT	0
642258	642253	11066Q	PARTICIPANT	\N	PRESENT	0
642444	642011	20108W	PARTICIPANT	\N	PRESENT	1
642445	642011	14179A	PARTICIPANT	\N	PRESENT	1
642446	642011	20110Q	PARTICIPANT	\N	PRESENT	1
642265	642011	01028R	PARTICIPANT	\N	EXCUSE	0
642447	642011	14089Y	PARTICIPANT	\N	PRESENT	1
642451	642450	19629C	PARTICIPANT	\N	PRESENT	0
642452	642450	14038Y	PARTICIPANT	\N	PRESENT	0
642453	642450	14147R	PARTICIPANT	\N	PRESENT	0
642539	642499	14033T	PARTICIPANT	\N	PRESENT	0
642540	642499	19369B	PARTICIPANT	\N	PRESENT	0
642541	642499	20018V	PARTICIPANT	\N	PRESENT	0
642542	642538	14033T	PARTICIPANT	\N	PRESENT	0
642543	642538	20018V	PARTICIPANT	\N	PRESENT	0
642544	642538	14257W	PARTICIPANT	\N	PRESENT	0
645091	645090	19611R	PARTICIPANT	\N	PRESENT	0
645092	645090	08012N	PARTICIPANT	\N	PRESENT	0
645093	645090	20152B	PARTICIPANT	\N	PRESENT	0
645094	645090	19399H	PARTICIPANT	\N	PRESENT	0
645095	645090	19758L	PARTICIPANT	\N	PRESENT	0
645096	645090	04047H	PARTICIPANT	\N	PRESENT	0
645097	645090	19673G	PARTICIPANT	\N	PRESENT	0
645098	645090	14151M	PARTICIPANT	\N	PRESENT	0
645099	645088	19415P	PARTICIPANT	\N	PRESENT	0
645100	645088	11067R	PARTICIPANT	\N	PRESENT	1
645101	645088	18193Q	PARTICIPANT	\N	PRESENT	1
645102	645088	19798U	PARTICIPANT	\N	PRESENT	1
645103	645088	20130U	PARTICIPANT	\N	PRESENT	1
645104	645088	14213J	PARTICIPANT	\N	PRESENT	1
645105	645088	14217N	PARTICIPANT	\N	PRESENT	1
645109	645108	19673G	PARTICIPANT	\N	PRESENT	0
645418	645417	19415P	PARTICIPANT	\N	PRESENT	0
645419	645417	11067R	PARTICIPANT	\N	PRESENT	0
645420	645417	19760E	PARTICIPANT	\N	PRESENT	0
645421	645417	19691J	PARTICIPANT	\N	PRESENT	1
645422	645417	14213J	PARTICIPANT	\N	PRESENT	1
645429	645423	19415P	PARTICIPANT	\N	PRESENT	0
645430	645423	11067R	PARTICIPANT	\N	PRESENT	0
645431	645423	20248J	PARTICIPANT	\N	PRESENT	0
645438	645423	20130U	PARTICIPANT	\N	PRESENT	1
645440	645439	20060X	PARTICIPANT	\N	PRESENT	0
645441	645439	14083S	PARTICIPANT	\N	PRESENT	0
645442	645439	20054A	PARTICIPANT	\N	PRESENT	0
645444	645443	20094J	PARTICIPANT	\N	PRESENT	0
645445	645443	19575F	PARTICIPANT	\N	PRESENT	0
645446	645443	14083S	PARTICIPANT	\N	PRESENT	0
645447	645443	19671E	PARTICIPANT	\N	PRESENT	0
646362	646153	14107H	PARTICIPANT	\N	PRESENT	0
646363	646153	14069U	PARTICIPANT	\N	PRESENT	0
646364	646153	01028R	PARTICIPANT	\N	PRESENT	0
646365	646153	14147R	PARTICIPANT	\N	PRESENT	0
646366	646153	20074E	PARTICIPANT	\N	PRESENT	0
646367	646153	11056N	PARTICIPANT	\N	PRESENT	0
646368	646153	19749K	PARTICIPANT	\N	PRESENT	0
646369	646153	20022R	PARTICIPANT	\N	PRESENT	0
646370	645739	19333N	PARTICIPANT	\N	PRESENT	0
646371	645739	14031R	PARTICIPANT	\N	PRESENT	0
646372	645739	19387D	PARTICIPANT	\N	PRESENT	0
646373	645739	14219Q	PRESIDENT	0	PRESENT	0
646374	645739	19820Y	PARTICIPANT	\N	PRESENT	0
646375	645739	19251M	PARTICIPANT	\N	PRESENT	0
646376	645739	19826F	PARTICIPANT	\N	PRESENT	0
646377	645739	14221J	PARTICIPANT	\N	PRESENT	0
646378	645739	20046A	PARTICIPANT	\N	PRESENT	0
646379	645739	19599P	PARTICIPANT	\N	PRESENT	0
646380	645739	20102Q	PARTICIPANT	\N	PRESENT	0
646381	645739	17229F	PARTICIPANT	\N	PRESENT	0
646382	645739	18083K	PARTICIPANT	\N	PRESENT	0
646383	645739	20100N	PARTICIPANT	\N	PRESENT	0
646384	645739	19503N	PARTICIPANT	\N	PRESENT	0
646385	645739	20020P	PARTICIPANT	\N	PRESENT	0
646386	645739	19659J	PARTICIPANT	\N	PRESENT	0
646387	645739	20024T	PARTICIPANT	\N	PRESENT	0
646388	645739	19525U	PARTICIPANT	\N	PRESENT	0
646389	645739	19701S	PARTICIPANT	\N	PRESENT	1
646390	645739	20136B	PARTICIPANT	\N	PRESENT	0
646391	645739	20068G	PARTICIPANT	\N	PRESENT	0
646392	645739	20032T	PARTICIPANT	\N	PRESENT	0
646393	645739	19619A	PARTICIPANT	\N	PRESENT	0
646394	645739	19577H	PARTICIPANT	\N	PRESENT	0
646395	645739	20120S	PARTICIPANT	\N	PRESENT	0
646396	645739	19549D	PARTICIPANT	\N	PRESENT	0
646397	645739	19745F	PARTICIPANT	\N	PRESENT	0
646398	645739	19637C	PARTICIPANT	\N	PRESENT	1
646399	645739	20038A	PARTICIPANT	\N	PRESENT	0
646400	645739	14169X	PARTICIPANT	\N	PRESENT	0
646401	645739	20076G	PARTICIPANT	\N	PRESENT	1
646412	646153	14179A	PARTICIPANT	\N	PRESENT	0
646427	645739	19681G	PARTICIPANT	\N	PRESENT	0
646449	646154	20074E	PARTICIPANT	\N	PRESENT	0
646450	646154	14001X	PARTICIPANT	\N	PRESENT	0
646451	646154	19581D	PARTICIPANT	\N	PRESENT	0
646452	646154	04047H	PRESIDENT	0	PRESENT	0
646453	646154	19673G	PARTICIPANT	\N	PRESENT	0
646454	646154	01028R	PARTICIPANT	\N	PRESENT	0
646455	646154	19447X	PARTICIPANT	\N	PRESENT	0
646456	646154	14231L	PARTICIPANT	\N	PRESENT	0
646457	646154	05008E	PARTICIPANT	\N	PRESENT	0
646458	646154	07004J	PARTICIPANT	\N	PRESENT	0
646459	646154	14107H	PARTICIPANT	\N	PRESENT	0
646460	646154	20110Q	PARTICIPANT	\N	PRESENT	0
646461	646154	14147R	PARTICIPANT	\N	PRESENT	0
646462	646154	14179A	PARTICIPANT	\N	PRESENT	0
646463	646154	14151M	PARTICIPANT	\N	PRESENT	0
646464	646154	14215L	PARTICIPANT	\N	PRESENT	0
646465	646154	20022R	PARTICIPANT	\N	PRESENT	0
646466	646154	14053L	PARTICIPANT	\N	PRESENT	0
646467	646154	14111D	PARTICIPANT	\N	PRESENT	0
646468	646154	19649G	PARTICIPANT	\N	PRESENT	0
646469	646154	10015M	PARTICIPANT	\N	PRESENT	0
646470	646154	19725B	PARTICIPANT	\N	PRESENT	0
646471	646154	19729F	PARTICIPANT	\N	PRESENT	0
646472	646154	95063L	PARTICIPANT	\N	PRESENT	0
646473	646154	14069U	PARTICIPANT	\N	PRESENT	0
646474	646154	19749K	PARTICIPANT	\N	PRESENT	0
649848	649846	14237S	PARTICIPANT	\N	PRESENT	0
649849	649846	04070G	PARTICIPANT	\N	PRESENT	0
652578	650991	19251M	PARTICIPANT	\N	PRESENT	1
652579	650991	20038A	PARTICIPANT	\N	PRESENT	0
652580	650991	19659J	PARTICIPANT	\N	PRESENT	1
652581	650991	19820Y	PARTICIPANT	\N	PRESENT	1
652582	650991	19599P	PARTICIPANT	\N	PRESENT	1
652604	652165	14169X	PARTICIPANT	\N	PRESENT	1
652605	652165	14221J	PARTICIPANT	\N	PRESENT	1
652606	652165	17367Q	PARTICIPANT	\N	PRESENT	0
652607	652165	11101A	PARTICIPANT	\N	PRESENT	0
652608	652165	17229F	PARTICIPANT	\N	PRESENT	0
652609	652165	20038A	PARTICIPANT	\N	PRESENT	0
652610	652165	20068G	PARTICIPANT	\N	PRESENT	0
653910	652899	19531S	PARTICIPANT	\N	PRESENT	0
652612	652165	19745F	PARTICIPANT	\N	PRESENT	0
652613	652165	20122U	PARTICIPANT	\N	PRESENT	0
653903	652899	11045K	PARTICIPANT	\N	PRESENT	0
653909	652899	19715Y	PARTICIPANT	\N	PRESENT	0
653911	652899	19301E	PARTICIPANT	\N	PRESENT	0
653914	652899	20132W	PARTICIPANT	\N	PRESENT	0
653915	652899	20098N	PARTICIPANT	\N	PRESENT	0
653916	652899	11056N	PARTICIPANT	\N	PRESENT	0
653917	652899	14237S	PARTICIPANT	\N	PRESENT	0
653918	652899	19367Y	PARTICIPANT	\N	PRESENT	0
653919	652899	01024M	PARTICIPANT	\N	PRESENT	0
653920	652899	20054A	PARTICIPANT	\N	PRESENT	0
653922	652899	08010L	PARTICIPANT	\N	PRESENT	0
653925	652899	20024T	PARTICIPANT	\N	PRESENT	0
653926	652899	18083K	PARTICIPANT	\N	PRESENT	0
653927	652899	14187A	PARTICIPANT	\N	PRESENT	0
653928	652899	19335Q	PARTICIPANT	\N	PRESENT	0
653929	652899	20124W	PARTICIPANT	\N	PRESENT	0
653930	652899	19782L	PARTICIPANT	\N	PRESENT	0
653931	652899	14089Y	PARTICIPANT	\N	PRESENT	0
653932	652899	20032T	PARTICIPANT	\N	PRESENT	0
653933	652899	19599P	PARTICIPANT	\N	PRESENT	0
653934	652899	14205J	PARTICIPANT	\N	PRESENT	0
653935	652899	20140W	PARTICIPANT	\N	PRESENT	0
653936	652899	11026G	PARTICIPANT	\N	PRESENT	0
653937	652899	19347U	PARTICIPANT	\N	PRESENT	0
653938	652899	14083S	PARTICIPANT	\N	PRESENT	0
653944	652903	14191V	PARTICIPANT	\N	PRESENT	0
653945	652903	11048N	PARTICIPANT	\N	PRESENT	0
653946	652903	08009T	PARTICIPANT	\N	PRESENT	0
653942	652903	11045K	PARTICIPANT	\N	PRESENT	0
653943	652903	20914V	PARTICIPANT	\N	PRESENT	0
653947	652903	19387D	PARTICIPANT	\N	PRESENT	0
653948	652903	20080C	PARTICIPANT	\N	PRESENT	0
653949	652903	19349W	PARTICIPANT	\N	PRESENT	0
654011	652903	20100N	PARTICIPANT	\N	PRESENT	0
653951	652903	19711U	PARTICIPANT	\N	PRESENT	0
653952	652903	19687N	PARTICIPANT	\N	PRESENT	0
653953	652903	12016W	PARTICIPANT	\N	PRESENT	0
653954	652903	01057W	PARTICIPANT	\N	PRESENT	0
653955	652903	14105F	PARTICIPANT	\N	PRESENT	0
653956	652903	11066Q	PARTICIPANT	\N	PRESENT	0
653957	652903	97011G	PARTICIPANT	\N	PRESENT	0
653958	652903	19301E	PARTICIPANT	\N	PRESENT	0
653959	652903	19782L	PARTICIPANT	\N	PRESENT	0
653960	652903	14255U	PARTICIPANT	\N	PRESENT	0
653961	652903	20026V	PARTICIPANT	\N	PRESENT	0
653962	652903	19866P	PARTICIPANT	\N	PRESENT	0
653963	652903	20298U	PARTICIPANT	\N	PRESENT	0
653964	652903	20252E	PARTICIPANT	\N	PRESENT	0
653965	652903	19671E	PARTICIPANT	\N	PRESENT	0
653966	652903	20090E	PARTICIPANT	\N	PRESENT	0
653967	652903	11040E	PARTICIPANT	\N	PRESENT	0
653968	652903	20052X	PARTICIPANT	\N	PRESENT	0
653969	652903	20102Q	PARTICIPANT	\N	PRESENT	0
653970	652903	14083S	PARTICIPANT	\N	PRESENT	0
653971	652903	19441R	PARTICIPANT	\N	PRESENT	0
653972	652903	19747H	PARTICIPANT	\N	PRESENT	0
653973	652903	20034V	PARTICIPANT	\N	PRESENT	0
653974	652903	20044X	PARTICIPANT	\N	PRESENT	0
653975	652903	19479G	PARTICIPANT	\N	PRESENT	0
653976	652903	11074Q	PARTICIPANT	\N	PRESENT	0
653977	652903	20126Y	PARTICIPANT	\N	PRESENT	0
653978	652903	20054A	PARTICIPANT	\N	PRESENT	0
653979	652903	20032T	PARTICIPANT	\N	PRESENT	0
653980	652903	14173T	PARTICIPANT	\N	PRESENT	0
653981	652903	14038Y	PARTICIPANT	\N	PRESENT	0
653982	652903	08061X	PARTICIPANT	\N	PRESENT	0
653983	652903	19443T	PARTICIPANT	\N	PRESENT	0
653984	652903	19679N	PARTICIPANT	\N	PRESENT	0
653985	652903	14031R	PARTICIPANT	\N	PRESENT	0
653986	652903	20136B	PARTICIPANT	\N	PRESENT	0
653987	652903	20062A	PARTICIPANT	\N	PRESENT	0
653988	652903	19739H	PARTICIPANT	\N	PRESENT	0
653989	652903	07029T	PARTICIPANT	\N	PRESENT	0
653990	652903	14225N	PARTICIPANT	\N	PRESENT	0
653991	652903	20024T	PARTICIPANT	\N	PRESENT	0
653992	652903	20118Y	PARTICIPANT	\N	PRESENT	0
653993	652903	19447X	PARTICIPANT	\N	PRESENT	0
653994	652903	19335Q	PARTICIPANT	\N	PRESENT	0
653995	652903	11085T	PARTICIPANT	\N	PRESENT	0
653996	652903	14189C	PARTICIPANT	\N	PRESENT	0
653997	652903	20076G	PARTICIPANT	\N	PRESENT	0
653998	652903	19651A	PARTICIPANT	\N	PRESENT	0
653999	652903	17589D	PARTICIPANT	\N	PRESENT	0
654000	652903	19467C	PARTICIPANT	\N	PRESENT	0
654001	652903	08045X	PARTICIPANT	\N	PRESENT	0
654002	652903	14179A	PARTICIPANT	\N	PRESENT	0
654003	652903	19762G	PARTICIPANT	\N	PRESENT	0
654004	652903	14147R	PARTICIPANT	\N	PRESENT	0
654005	652903	14257W	PARTICIPANT	\N	PRESENT	0
654006	652903	20108W	PARTICIPANT	\N	PRESENT	0
654007	652903	20286Q	PARTICIPANT	\N	PRESENT	0
654008	652903	20152B	PARTICIPANT	\N	PRESENT	0
654009	652903	19591F	PARTICIPANT	\N	PRESENT	0
654010	652903	20086J	PARTICIPANT	\N	PRESENT	0
654012	652903	19647E	PARTICIPANT	\N	PRESENT	0
654013	652903	19593H	PARTICIPANT	\N	PRESENT	0
654014	652903	14033T	PARTICIPANT	\N	PRESENT	0
654015	652903	20038A	PARTICIPANT	\N	PRESENT	0
654016	652903	14151M	PARTICIPANT	\N	PRESENT	0
654017	652903	19563B	PARTICIPANT	\N	PRESENT	0
654018	652903	14205J	PARTICIPANT	\N	PRESENT	0
654019	652903	20056C	PARTICIPANT	\N	PRESENT	0
654020	652903	19367Y	PARTICIPANT	\N	PRESENT	0
654021	652903	01024M	PARTICIPANT	\N	PRESENT	0
654022	652903	14357A	PARTICIPANT	\N	PRESENT	0
654023	652903	20142Y	PARTICIPANT	\N	PRESENT	0
654024	652903	18193Q	PARTICIPANT	\N	PRESENT	0
654025	652903	19766L	PARTICIPANT	\N	PRESENT	0
654026	652903	20098N	PARTICIPANT	\N	PRESENT	0
654027	652903	14069U	PARTICIPANT	\N	PRESENT	0
654028	652903	19701S	PARTICIPANT	\N	PRESENT	0
654029	652903	20150Y	PARTICIPANT	\N	PRESENT	0
654030	652903	20094J	PARTICIPANT	\N	PRESENT	0
654031	652903	19673G	PARTICIPANT	\N	PRESENT	0
654032	652903	20070A	PARTICIPANT	\N	PRESENT	0
654033	652903	20028X	PARTICIPANT	\N	PRESENT	0
654034	652903	19549D	PARTICIPANT	\N	PRESENT	0
654035	652903	20072C	PARTICIPANT	\N	PRESENT	0
634757	634326	14179A	PARTICIPANT	\N	PRESENT	1
634758	634326	14147R	PARTICIPANT	\N	PRESENT	1
634802	631730	08012N	PARTICIPANT	\N	PRESENT	0
634803	631730	20056C	PARTICIPANT	\N	PRESENT	0
634804	631730	14255U	PARTICIPANT	\N	PRESENT	0
634821	634820	16685X	PARTICIPANT	\N	PRESENT	0
634822	634820	14249W	PARTICIPANT	\N	PRESENT	0
634823	634820	14073Q	PARTICIPANT	\N	PRESENT	0
634824	634820	19369B	PARTICIPANT	\N	PRESENT	0
636574	634655	08015R	PARTICIPANT	\N	PRESENT	0
636575	634655	11083R	PARTICIPANT	\N	PRESENT	0
636576	634655	08018U	PARTICIPANT	\N	PRESENT	0
636577	634655	19701S	PARTICIPANT	\N	PRESENT	0
636578	634655	01058X	PARTICIPANT	\N	PRESENT	0
636579	634655	19689Q	PARTICIPANT	\N	PRESENT	0
636580	634655	08061X	PARTICIPANT	\N	PRESENT	0
636581	634655	17367Q	PARTICIPANT	\N	PRESENT	0
636582	634655	04085P	PARTICIPANT	\N	PRESENT	0
636583	634655	97011G	PARTICIPANT	\N	PRESENT	0
636584	634655	19387D	PARTICIPANT	\N	PRESENT	0
636585	634655	14189C	PARTICIPANT	\N	PRESENT	0
636586	634655	20112S	PARTICIPANT	\N	PRESENT	0
636587	634655	19421M	PARTICIPANT	\N	PRESENT	0
636588	634655	20048C	PARTICIPANT	\N	PRESENT	0
636589	634655	20052X	PARTICIPANT	\N	PRESENT	0
636590	634655	19543W	PARTICIPANT	\N	PRESENT	0
636591	634655	14031R	PARTICIPANT	\N	PRESENT	0
636592	634655	19629C	PARTICIPANT	\N	PRESENT	0
636593	634655	19739H	PARTICIPANT	\N	PRESENT	0
636594	634655	14249W	PARTICIPANT	\N	PRESENT	0
636595	634655	20108W	PARTICIPANT	\N	PRESENT	0
636596	634655	20098N	PARTICIPANT	\N	PRESENT	0
636597	634655	14169X	PARTICIPANT	\N	PRESENT	0
636598	634655	20114U	PARTICIPANT	\N	PRESENT	0
636599	634655	14021P	PARTICIPANT	\N	PRESENT	0
636600	634655	19593H	PARTICIPANT	\N	PRESENT	0
636601	634655	12028B	PARTICIPANT	\N	PRESENT	0
636602	634655	17965H	PARTICIPANT	\N	PRESENT	0
636603	634655	19503N	PARTICIPANT	\N	PRESENT	0
636604	634655	11027H	PARTICIPANT	\N	PRESENT	0
636608	634655	11067R	PARTICIPANT	\N	PRESENT	0
636606	634655	19866P	PARTICIPANT	\N	PRESENT	0
636607	634655	19715Y	PARTICIPANT	\N	PRESENT	0
636609	634655	04042C	PARTICIPANT	\N	PRESENT	0
636610	634655	19549D	PARTICIPANT	\N	PRESENT	0
636611	634655	14257W	PARTICIPANT	\N	PRESENT	0
636612	634655	14097Y	PARTICIPANT	\N	PRESENT	0
636613	634655	14217N	PARTICIPANT	\N	PRESENT	0
636614	634655	10006L	PARTICIPANT	\N	PRESENT	0
636615	634655	14211G	PARTICIPANT	\N	PRESENT	0
636616	634655	20122U	PARTICIPANT	\N	PRESENT	0
636618	634655	08012N	PARTICIPANT	\N	PRESENT	0
636619	634655	11043H	PARTICIPANT	\N	PRESENT	0
636636	634655	01043Q	PARTICIPANT	\N	PRESENT	0
636640	634655	20086J	PARTICIPANT	\N	PRESENT	0
636644	634655	14147R	PARTICIPANT	\N	PRESENT	0
636645	634655	08045X	PARTICIPANT	\N	PRESENT	0
636648	634655	14069U	PARTICIPANT	\N	PRESENT	0
636649	634655	19711U	PARTICIPANT	\N	PRESENT	0
636650	634655	01048V	PARTICIPANT	\N	PRESENT	0
636651	634655	01057W	PARTICIPANT	\N	PRESENT	0
636652	634655	19679N	PARTICIPANT	\N	PRESENT	0
636654	634655	18083K	PARTICIPANT	\N	PRESENT	0
636656	634655	20032T	PARTICIPANT	\N	PRESENT	0
636660	634655	14151M	PARTICIPANT	\N	PRESENT	0
636661	634655	20068G	PARTICIPANT	\N	PRESENT	0
636994	634658	11067R	PARTICIPANT	\N	PRESENT	0
636995	634658	20130U	PARTICIPANT	\N	PRESENT	0
636996	634658	19531S	PARTICIPANT	\N	PRESENT	0
636997	634658	14151M	PARTICIPANT	\N	PRESENT	0
636998	634658	20094J	PARTICIPANT	\N	PRESENT	0
636999	634658	20018V	PARTICIPANT	\N	PRESENT	0
637000	634658	19413M	PARTICIPANT	\N	PRESENT	0
637001	634658	19551W	PARTICIPANT	\N	PRESENT	0
637002	634658	14257W	PARTICIPANT	\N	PRESENT	0
637003	634658	20082E	PARTICIPANT	\N	PRESENT	0
637004	634658	20070A	PARTICIPANT	\N	PRESENT	0
637005	634658	11031D	PARTICIPANT	\N	PRESENT	0
637006	634658	11097X	PARTICIPANT	\N	PRESENT	0
637007	634658	10006L	PARTICIPANT	\N	PRESENT	0
637008	634658	14217N	PARTICIPANT	\N	PRESENT	0
637009	634658	14147R	PARTICIPANT	\N	PRESENT	0
637010	634658	19758L	PARTICIPANT	\N	PRESENT	0
637011	634658	19679N	PARTICIPANT	\N	PRESENT	0
637012	634658	20114U	PARTICIPANT	\N	PRESENT	0
637013	634658	20090E	PARTICIPANT	\N	PRESENT	0
637014	634658	19715Y	PARTICIPANT	\N	PRESENT	0
637015	634658	19657G	PARTICIPANT	\N	PRESENT	0
637016	634658	17965H	PARTICIPANT	\N	PRESENT	0
637017	634658	19549D	PARTICIPANT	\N	PRESENT	0
637018	634658	18083K	PARTICIPANT	\N	PRESENT	0
637019	634658	14021P	PARTICIPANT	\N	PRESENT	0
637020	634658	19447X	PARTICIPANT	\N	PRESENT	0
637021	634658	08045X	PARTICIPANT	\N	PRESENT	0
637022	634658	95041E	PARTICIPANT	\N	PRESENT	0
637023	634658	19697Q	PARTICIPANT	\N	PRESENT	0
637024	634658	14042U	PARTICIPANT	\N	PRESENT	0
637025	634658	20248J	PARTICIPANT	\N	PRESENT	0
637026	634658	19577H	PARTICIPANT	\N	PRESENT	0
637027	634658	19333N	PARTICIPANT	\N	PRESENT	0
637028	634658	19503N	PARTICIPANT	\N	PRESENT	0
637029	634658	19631V	PARTICIPANT	\N	PRESENT	0
636992	634658	14026U	PARTICIPANT	\N	PRESENT	0
636993	634658	11045K	PARTICIPANT	\N	PRESENT	0
637030	634658	20080C	PARTICIPANT	\N	PRESENT	0
637031	634658	20064C	PARTICIPANT	\N	PRESENT	0
637032	634658	19629C	PARTICIPANT	\N	PRESENT	0
637033	634658	11064N	PARTICIPANT	\N	PRESENT	0
637034	634658	17779H	PARTICIPANT	\N	PRESENT	0
637035	634658	18193Q	PARTICIPANT	\N	PRESENT	0
637266	635632	19705W	PARTICIPANT	\N	PRESENT	1
637268	635632	19369B	PARTICIPANT	\N	PRESENT	0
637274	634659	18083K	PARTICIPANT	\N	PRESENT	0
637275	637241	19747H	PARTICIPANT	\N	PRESENT	1
637276	634659	19739H	PARTICIPANT	\N	PRESENT	0
637277	634659	19531S	PARTICIPANT	\N	PRESENT	0
637278	634659	20098N	PARTICIPANT	\N	PRESENT	0
637279	634659	20104S	PARTICIPANT	\N	PRESENT	0
637290	634659	14249W	PARTICIPANT	\N	PRESENT	0
637291	634659	19749K	PARTICIPANT	\N	PRESENT	0
637299	634659	14026U	PARTICIPANT	\N	PRESENT	0
637301	634659	20058E	PARTICIPANT	\N	PRESENT	0
637302	634659	97011G	PARTICIPANT	\N	PRESENT	0
637303	634659	05008E	PARTICIPANT	\N	PRESENT	0
637304	634659	04043D	PARTICIPANT	\N	PRESENT	0
637310	637309	04008A	PARTICIPANT	\N	PRESENT	0
637311	637309	14151M	PARTICIPANT	\N	PRESENT	0
637312	637309	19543W	PARTICIPANT	\N	PRESENT	0
637313	637309	14147R	PARTICIPANT	\N	PRESENT	0
637315	634659	18193Q	PARTICIPANT	\N	PRESENT	0
637316	634659	20152B	PARTICIPANT	\N	PRESENT	0
637317	634659	20140W	PARTICIPANT	\N	PRESENT	0
637323	634659	17965H	PARTICIPANT	\N	PRESENT	0
637324	634659	19441R	PARTICIPANT	\N	PRESENT	0
637352	634659	14033T	PARTICIPANT	\N	PRESENT	0
637353	634659	19467C	PARTICIPANT	\N	PRESENT	0
645135	645134	11040E	PARTICIPANT	\N	PRESENT	0
645137	645136	19545Y	PARTICIPANT	\N	PRESENT	0
645139	645138	14217N	PARTICIPANT	\N	PRESENT	0
645140	645138	20248J	PARTICIPANT	\N	PRESENT	0
645141	645138	11067R	PARTICIPANT	\N	PRESENT	0
645142	645138	20130U	PARTICIPANT	\N	PRESENT	0
645204	645202	19507S	PARTICIPANT	\N	EXCUSE	0
645144	645138	14213J	PARTICIPANT	\N	PRESENT	0
645203	645202	19717B	PARTICIPANT	\N	EXCUSE	0
645205	645202	20034V	PARTICIPANT	\N	EXCUSE	0
645206	645202	04043D	PARTICIPANT	\N	PRESENT	0
645207	645202	20150Y	PARTICIPANT	\N	PRESENT	0
645208	645202	20104S	PARTICIPANT	\N	PRESENT	0
645209	645202	14031R	PARTICIPANT	\N	PRESENT	0
645210	645202	14059S	PARTICIPANT	\N	PRESENT	0
645211	645202	14083S	PRESIDENT	0	PRESENT	0
645214	645106	20024T	PARTICIPANT	\N	PRESENT	0
645215	645106	14189C	PARTICIPANT	\N	EXCUSE	0
645216	645106	14030Q	PARTICIPANT	\N	EXCUSE	0
645217	645106	20080C	PARTICIPANT	\N	EXCUSE	0
645218	645106	19621T	PARTICIPANT	\N	EXCUSE	0
645219	645106	11031D	PRESIDENT	0	PRESENT	0
645220	645106	19693L	PARTICIPANT	\N	EXCUSE	0
645221	645106	19599P	PARTICIPANT	\N	PRESENT	0
645226	645106	20098N	PARTICIPANT	\N	EXCUSE	0
645223	645106	20046A	PARTICIPANT	\N	PRESENT	1
645224	645106	19749K	PARTICIPANT	\N	PRESENT	0
645225	645106	19798U	PARTICIPANT	\N	PRESENT	1
645227	645106	14179A	PARTICIPANT	\N	PRESENT	1
645265	645256	08010L	PARTICIPANT	\N	PRESENT	0
645272	645256	14151M	PARTICIPANT	\N	PRESENT	0
645269	645256	19693L	PARTICIPANT	\N	PRESENT	0
645270	645256	14255U	PARTICIPANT	\N	PRESENT	0
645273	645256	99004R	PARTICIPANT	\N	PRESENT	0
645277	645276	14259Y	PARTICIPANT	\N	PRESENT	0
645278	645276	14071N	PARTICIPANT	\N	PRESENT	0
645280	645279	95063L	PARTICIPANT	\N	PRESENT	0
645281	644854	14042U	PARTICIPANT	\N	PRESENT	0
645282	644854	19295A	PARTICIPANT	\N	EXCUSE	0
645283	644854	19798U	PARTICIPANT	\N	PRESENT	1
645284	644854	10006L	PRESIDENT	0	PRESENT	0
645285	644854	01034P	PARTICIPANT	\N	PRESENT	0
645374	645031	14225N	PRESIDENT	0	PRESENT	0
645375	645031	11012A	PARTICIPANT	\N	PRESENT	1
645376	645031	20070A	PARTICIPANT	\N	EXCUSE	0
645377	645031	20080C	PARTICIPANT	\N	EXCUSE	0
645378	645031	20050V	PARTICIPANT	\N	EXCUSE	0
645379	645031	19667J	PARTICIPANT	\N	PRESENT	0
645380	645031	08073C	PARTICIPANT	\N	PRESENT	0
645381	645031	20150Y	PARTICIPANT	\N	PRESENT	0
645382	645031	14331P	PARTICIPANT	\N	PRESENT	0
645383	645031	07029T	PARTICIPANT	\N	EXCUSE	0
645384	645031	11048N	PARTICIPANT	\N	PRESENT	0
645385	645031	99004R	PARTICIPANT	\N	PRESENT	0
645386	645031	11040E	PARTICIPANT	\N	PRESENT	0
645387	645031	11053K	PARTICIPANT	\N	PRESENT	0
645388	645031	08010L	PARTICIPANT	\N	PRESENT	0
645389	645031	11072N	PARTICIPANT	\N	PRESENT	0
645390	645031	08034U	PARTICIPANT	\N	PRESENT	0
645391	645031	01048V	PARTICIPANT	\N	PRESENT	0
645392	645031	14083S	PARTICIPANT	\N	PRESENT	0
645393	645031	19349W	PARTICIPANT	\N	PRESENT	0
645394	645031	20116W	PARTICIPANT	\N	PRESENT	0
645395	645031	20126Y	PARTICIPANT	\N	PRESENT	0
645396	645031	20044X	PARTICIPANT	\N	PRESENT	0
645397	645031	19335Q	PARTICIPANT	\N	PRESENT	0
645398	645031	19762G	PARTICIPANT	\N	PRESENT	0
645399	645031	14189C	PARTICIPANT	\N	EXCUSE	0
645509	645508	19725B	PARTICIPANT	\N	PRESENT	0
645510	645508	19447X	PARTICIPANT	\N	PRESENT	0
645511	645508	14147R	PARTICIPANT	\N	PRESENT	0
645524	645523	20124W	PARTICIPANT	\N	PRESENT	0
645525	645523	20106U	PARTICIPANT	\N	PRESENT	0
645526	645523	12016W	PARTICIPANT	\N	PRESENT	0
645527	645523	14083S	PARTICIPANT	\N	PRESENT	0
645533	645528	19713W	PARTICIPANT	\N	PRESENT	0
645565	645512	20128B	PARTICIPANT	\N	PRESENT	0
645567	645566	20128B	PARTICIPANT	\N	PRESENT	0
645569	645568	20128B	PARTICIPANT	\N	PRESENT	0
645573	644649	19715Y	PRESIDENT	0	PRESENT	0
645574	643797	11010L	PARTICIPANT	\N	EXCUSE	0
645572	644649	11010L	PARTICIPANT	\N	EXCUSE	0
645575	643797	19715Y	PRESIDENT	0	PRESENT	0
645586	645585	19631V	PARTICIPANT	\N	PRESENT	0
645587	645585	14187A	PARTICIPANT	\N	PRESENT	0
645588	645585	01043Q	PARTICIPANT	\N	PRESENT	0
645590	645589	19631V	PARTICIPANT	\N	PRESENT	0
645591	645589	14187A	PARTICIPANT	\N	PRESENT	0
645592	645589	01043Q	PARTICIPANT	\N	PRESENT	0
645594	645593	19631V	PARTICIPANT	\N	PRESENT	0
645746	645741	14042U	PARTICIPANT	\N	PRESENT	0
645747	645741	20130U	PARTICIPANT	\N	PRESENT	0
645748	645741	20090E	PARTICIPANT	\N	PRESENT	0
645749	643674	20024T	PARTICIPANT	\N	PRESENT	0
645750	643674	14069U	PARTICIPANT	\N	PRESENT	1
645751	643674	11053K	PARTICIPANT	\N	PRESENT	0
645752	643674	19681G	PARTICIPANT	\N	PRESENT	0
645753	643674	08045X	PARTICIPANT	\N	PRESENT	1
645754	643674	19349W	PARTICIPANT	\N	PRESENT	0
645755	643674	19333N	PARTICIPANT	\N	PRESENT	0
645756	643674	14169X	PARTICIPANT	\N	PRESENT	1
645757	643674	20090E	PARTICIPANT	\N	PRESENT	1
645758	643674	19251M	PARTICIPANT	\N	PRESENT	0
645763	645762	19735D	PARTICIPANT	\N	PRESENT	0
645764	645762	14229S	PARTICIPANT	\N	PRESENT	1
645765	645762	20052X	PARTICIPANT	\N	PRESENT	0
645766	645762	20180F	PARTICIPANT	\N	PRESENT	0
645783	645578	20132W	PARTICIPANT	\N	PRESENT	0
645784	645578	19643A	PARTICIPANT	\N	PRESENT	0
645785	645578	14147R	PARTICIPANT	\N	PRESENT	0
645786	645578	19447X	PARTICIPANT	\N	PRESENT	0
645787	645578	19725B	PARTICIPANT	\N	PRESENT	0
645960	645460	19717B	PARTICIPANT	\N	PRESENT	1
646103	646102	19725B	PARTICIPANT	\N	PRESENT	0
646104	646102	19447X	PARTICIPANT	\N	PRESENT	0
646105	646102	14147R	PARTICIPANT	\N	PRESENT	0
646106	646102	14179A	PARTICIPANT	\N	PRESENT	0
646107	646102	20128B	PARTICIPANT	\N	PRESENT	0
646110	646109	14205J	PARTICIPANT	\N	PRESENT	0
646111	646109	14231L	PRESIDENT	0	PRESENT	0
646112	646109	14053L	PARTICIPANT	\N	PRESENT	0
646113	646109	19333N	PARTICIPANT	\N	PRESENT	0
646114	646109	20022R	PARTICIPANT	\N	EXCUSE	0
646115	646109	20110Q	PARTICIPANT	\N	EXCUSE	0
646116	646109	14069U	PARTICIPANT	\N	EXCUSE	0
646117	646109	19782L	PARTICIPANT	\N	EXCUSE	0
646118	646109	20090E	PARTICIPANT	\N	EXCUSE	0
646119	646109	20070A	PARTICIPANT	\N	EXCUSE	0
646120	646109	14327T	PARTICIPANT	\N	EXCUSE	0
646121	646109	14215L	PARTICIPANT	\N	EXCUSE	0
646122	646109	14187A	PARTICIPANT	\N	EXCUSE	0
646123	646109	14281W	PARTICIPANT	\N	EXCUSE	0
646124	646109	20120S	PARTICIPANT	\N	EXCUSE	0
646125	646109	19565D	PARTICIPANT	\N	EXCUSE	0
646126	646109	01057W	PARTICIPANT	\N	EXCUSE	0
646127	646109	19447X	PARTICIPANT	\N	EXCUSE	0
646128	646109	19735D	PARTICIPANT	\N	EXCUSE	0
646129	646109	19711U	PARTICIPANT	\N	EXCUSE	0
646130	646109	08010L	PARTICIPANT	\N	EXCUSE	0
646131	646109	19826F	PARTICIPANT	\N	EXCUSE	0
646132	646109	08009T	PARTICIPANT	\N	EXCUSE	0
646133	646109	19563B	PARTICIPANT	\N	EXCUSE	0
646134	646109	14257W	PARTICIPANT	\N	EXCUSE	0
646135	646109	14071N	PARTICIPANT	\N	EXCUSE	0
646136	646109	19349W	PARTICIPANT	\N	EXCUSE	0
646137	646109	14229S	PARTICIPANT	\N	EXCUSE	0
646138	646109	04045F	PARTICIPANT	\N	EXCUSE	0
646139	646109	20062A	PARTICIPANT	\N	EXCUSE	0
646140	646109	20084G	PARTICIPANT	\N	EXCUSE	0
646141	646109	20122U	PARTICIPANT	\N	EXCUSE	0
646142	646109	20058E	PARTICIPANT	\N	EXCUSE	0
646143	646109	14173T	PARTICIPANT	\N	EXCUSE	0
646260	643942	14275Y	PARTICIPANT	\N	EXCUSE	0
646261	643944	14275Y	PARTICIPANT	\N	EXCUSE	0
646263	643942	19319Q	PARTICIPANT	\N	PRESENT	0
646293	646292	16685X	PARTICIPANT	\N	PRESENT	0
646403	646402	14225N	PARTICIPANT	\N	PRESENT	0
646404	646402	20050V	PARTICIPANT	\N	PRESENT	0
631198	631185	14237S	PARTICIPANT	\N	PRESENT	0
631199	631185	19383Y	PARTICIPANT	\N	PRESENT	0
631200	631185	20018V	PARTICIPANT	\N	PRESENT	0
631201	631185	19347U	PARTICIPANT	\N	PRESENT	0
631202	631185	14189C	PARTICIPANT	\N	PRESENT	0
631203	631185	19349W	PARTICIPANT	\N	PRESENT	0
631204	631185	19768N	PARTICIPANT	\N	PRESENT	0
631205	631185	20058E	PARTICIPANT	\N	PRESENT	0
631206	631185	20036X	PARTICIPANT	\N	PRESENT	0
631207	631185	20044X	PARTICIPANT	\N	PRESENT	0
632321	632320	01048V	PARTICIPANT	\N	PRESENT	0
632322	632320	01058X	PARTICIPANT	\N	PRESENT	0
632337	632335	19735D	PARTICIPANT	\N	PRESENT	0
632338	632335	19723Y	PARTICIPANT	\N	PRESENT	0
632348	632344	19735D	PARTICIPANT	\N	PRESENT	0
632349	632344	19723Y	PARTICIPANT	\N	PRESENT	0
632375	632361	19735D	PARTICIPANT	\N	PRESENT	0
632376	632361	19723Y	PARTICIPANT	\N	PRESENT	0
632382	632381	19735D	PARTICIPANT	\N	PRESENT	0
632383	632381	19723Y	PARTICIPANT	\N	PRESENT	0
632388	632386	19735D	PARTICIPANT	\N	PRESENT	0
632389	632386	19723Y	PARTICIPANT	\N	PRESENT	0
632394	632393	19735D	PARTICIPANT	\N	PRESENT	0
632395	632393	19723Y	PARTICIPANT	\N	PRESENT	0
632399	632398	19735D	PARTICIPANT	\N	PRESENT	0
632400	632398	19723Y	PARTICIPANT	\N	PRESENT	0
632822	631564	14001X	PARTICIPANT	\N	PRESENT	0
632823	631564	05008E	PARTICIPANT	\N	PRESENT	0
632824	631564	19489J	PARTICIPANT	\N	PRESENT	0
632825	631564	14107H	PARTICIPANT	\N	PRESENT	0
632826	631564	14179A	PARTICIPANT	\N	PRESENT	0
632827	631564	08018U	PARTICIPANT	\N	PRESENT	0
632828	631564	14259Y	PARTICIPANT	\N	PRESENT	0
632829	631564	14053L	PARTICIPANT	\N	PRESENT	0
632830	631564	11056N	PARTICIPANT	\N	PRESENT	0
632831	631564	19729F	PARTICIPANT	\N	PRESENT	0
632832	631564	95063L	PARTICIPANT	\N	PRESENT	0
632833	631564	11085T	PARTICIPANT	\N	PRESENT	0
632834	631564	14021P	PARTICIPANT	\N	PRESENT	0
632835	631213	19647E	PARTICIPANT	\N	PRESENT	0
632840	632714	19383Y	PARTICIPANT	\N	PRESENT	0
632841	632714	19768N	PARTICIPANT	\N	PRESENT	0
632842	632714	20088L	PARTICIPANT	\N	PRESENT	1
632843	632714	19515S	PARTICIPANT	\N	PRESENT	0
632844	632714	19782L	PARTICIPANT	\N	PRESENT	0
632845	632714	11077T	PARTICIPANT	\N	PRESENT	1
632846	632714	01043Q	PARTICIPANT	\N	PRESENT	0
632847	632714	14357A	PARTICIPANT	\N	PRESENT	0
632848	632714	20078J	PARTICIPANT	\N	PRESENT	0
632849	632714	19441R	PARTICIPANT	\N	PRESENT	0
632850	632714	19413M	PARTICIPANT	\N	PRESENT	0
632851	632714	19866P	PARTICIPANT	\N	PRESENT	0
632852	632714	04045F	PARTICIPANT	\N	PRESENT	1
632853	632714	19631V	PARTICIPANT	\N	PRESENT	0
632854	632714	20104S	PARTICIPANT	\N	PRESENT	0
632855	632714	19705W	PARTICIPANT	\N	PRESENT	1
632856	632714	19707Y	PARTICIPANT	\N	PRESENT	1
632857	632714	19575F	PARTICIPANT	\N	PRESENT	0
632858	632714	19369B	PARTICIPANT	\N	PRESENT	0
632859	632714	20018V	PARTICIPANT	\N	PRESENT	0
632860	632714	19563B	PARTICIPANT	\N	PRESENT	0
632861	632714	08028W	PARTICIPANT	\N	PRESENT	0
632862	632714	20028X	PARTICIPANT	\N	PRESENT	0
632863	632714	14038Y	PARTICIPANT	\N	PRESENT	1
632864	632714	19467C	PARTICIPANT	\N	PRESENT	0
632865	632714	14187A	PARTICIPANT	\N	PRESENT	0
632866	632714	19695N	PARTICIPANT	\N	PRESENT	0
632867	632714	11090Q	PRESIDENT	0	PRESENT	0
632868	632714	14033T	PARTICIPANT	\N	PRESENT	0
632869	632714	20174H	PARTICIPANT	\N	PRESENT	0
632870	632714	14205J	PARTICIPANT	\N	PRESENT	0
632871	632714	19507S	PARTICIPANT	\N	PRESENT	0
632872	632714	20286Q	PARTICIPANT	\N	PRESENT	0
632873	632714	14207L	PARTICIPANT	\N	PRESENT	0
632874	632714	19747H	PARTICIPANT	\N	PRESENT	0
632875	632714	14257W	PARTICIPANT	\N	PRESENT	0
632876	632714	01025N	PARTICIPANT	\N	PRESENT	1
632877	632714	14251Q	PARTICIPANT	\N	PRESENT	1
633735	631568	19413M	PARTICIPANT	\N	PRESENT	0
633736	631568	11064N	PARTICIPANT	\N	PRESENT	0
633737	631568	10006L	PARTICIPANT	\N	PRESENT	0
633738	631568	20062A	PARTICIPANT	\N	PRESENT	0
633739	631568	17965H	PARTICIPANT	\N	PRESENT	0
633740	631568	19820Y	PARTICIPANT	\N	PRESENT	0
633741	631568	20130U	PARTICIPANT	\N	PRESENT	0
633742	631568	11031D	PARTICIPANT	\N	PRESENT	0
633743	631568	20136B	PARTICIPANT	\N	PRESENT	0
633744	631568	14217N	PARTICIPANT	\N	PRESENT	0
633745	631568	20266L	PARTICIPANT	\N	PRESENT	0
633746	631568	19954N	PARTICIPANT	\N	PRESENT	0
633747	631568	20082E	PARTICIPANT	\N	PRESENT	0
633750	631568	20142Y	PARTICIPANT	\N	PRESENT	0
633751	631568	19717B	PARTICIPANT	\N	PRESENT	0
633752	631568	18193Q	PARTICIPANT	\N	PRESENT	0
633753	631568	20034V	PARTICIPANT	\N	PRESENT	0
633754	631568	14026U	PARTICIPANT	\N	PRESENT	0
633755	631568	14033T	PARTICIPANT	\N	PRESENT	0
633756	631568	11045K	PARTICIPANT	\N	PRESENT	0
633758	631568	11033F	PARTICIPANT	\N	PRESENT	0
633841	631569	19719D	PARTICIPANT	\N	PRESENT	0
633842	631569	04092N	PARTICIPANT	\N	PRESENT	0
633843	631569	11031D	PARTICIPANT	\N	PRESENT	0
633844	631569	10006L	PARTICIPANT	\N	PRESENT	0
633845	631569	11045K	PARTICIPANT	\N	PRESENT	0
633846	631569	14217N	PARTICIPANT	\N	PRESENT	0
633847	631569	19758L	PARTICIPANT	\N	PRESENT	0
633848	631569	14147R	PARTICIPANT	\N	PRESENT	0
633849	631569	11067R	PARTICIPANT	\N	PRESENT	0
633850	631569	14026U	PARTICIPANT	\N	PRESENT	0
633851	631569	19820Y	PARTICIPANT	\N	PRESENT	0
633852	631569	20124W	PARTICIPANT	\N	PRESENT	0
633853	631569	17965H	PARTICIPANT	\N	PRESENT	0
633854	631569	19954N	PARTICIPANT	\N	PRESENT	0
633855	631569	20180F	PARTICIPANT	\N	PRESENT	0
633856	631569	14033T	PARTICIPANT	\N	PRESENT	0
633857	631569	11012A	PARTICIPANT	\N	PRESENT	0
633858	631569	19387D	PARTICIPANT	\N	PRESENT	0
633859	631569	20098N	PARTICIPANT	\N	PRESENT	0
633860	631569	19717B	PARTICIPANT	\N	PRESENT	0
633861	631569	20034V	PARTICIPANT	\N	PRESENT	0
633862	631569	14195A	PARTICIPANT	\N	PRESENT	0
633863	631569	20266L	PARTICIPANT	\N	PRESENT	0
633864	631569	19415P	PARTICIPANT	\N	PRESENT	0
633865	631569	11033F	PARTICIPANT	\N	PRESENT	0
633866	631569	20090E	PARTICIPANT	\N	PRESENT	0
633867	631569	14030Q	PARTICIPANT	\N	PRESENT	0
633868	631569	19569H	PARTICIPANT	\N	PRESENT	0
633869	631569	11026G	PARTICIPANT	\N	PRESENT	0
633870	631569	18193Q	PARTICIPANT	\N	PRESENT	0
633871	631569	14121F	PARTICIPANT	\N	PRESENT	0
633872	631569	19413M	PARTICIPANT	\N	PRESENT	0
633873	631569	20142Y	PARTICIPANT	\N	PRESENT	0
633874	631569	20130U	PARTICIPANT	\N	PRESENT	0
633875	631569	20106U	PARTICIPANT	\N	PRESENT	0
633876	631569	04045F	PARTICIPANT	\N	PRESENT	0
633877	631569	20100N	PARTICIPANT	\N	PRESENT	0
633878	631569	01024M	PARTICIPANT	\N	PRESENT	0
633879	631569	19591F	PARTICIPANT	\N	PRESENT	0
633880	631569	19747H	PARTICIPANT	\N	PRESENT	0
633881	631569	20036X	PARTICIPANT	\N	PRESENT	0
633882	631569	20046A	PARTICIPANT	\N	PRESENT	0
633883	631569	20092G	PARTICIPANT	\N	PRESENT	0
633884	631569	20024T	PARTICIPANT	\N	PRESENT	0
633885	631569	20026V	PARTICIPANT	\N	PRESENT	0
633886	631569	01025N	PARTICIPANT	\N	PRESENT	0
633887	631569	19782L	PARTICIPANT	\N	PRESENT	0
633889	631569	19333N	PARTICIPANT	\N	PRESENT	0
633890	631569	20062A	PARTICIPANT	\N	PRESENT	0
634076	634073	05008E	PARTICIPANT	\N	PRESENT	0
634077	634073	11033F	PARTICIPANT	\N	PRESENT	0
634078	634073	11053K	PARTICIPANT	\N	PRESENT	0
634079	634073	14357A	PARTICIPANT	\N	PRESENT	0
634080	634073	11070L	PARTICIPANT	\N	PRESENT	0
634082	634073	19719D	PARTICIPANT	\N	PRESENT	0
634083	634073	19673G	PARTICIPANT	\N	PRESENT	0
634084	634073	01025N	PARTICIPANT	\N	PRESENT	0
649562	649560	19575F	PARTICIPANT	\N	PRESENT	0
649563	649560	18083K	PARTICIPANT	\N	PRESENT	0
649565	649560	14151M	PARTICIPANT	\N	PRESENT	0
649566	649560	17023S	PARTICIPANT	\N	PRESENT	0
649568	649560	20056C	PARTICIPANT	\N	PRESENT	0
649569	649560	05012A	PARTICIPANT	\N	PRESENT	0
649982	649971	20116W	PARTICIPANT	\N	PRESENT	0
649973	649971	20076G	PARTICIPANT	\N	PRESENT	0
649974	649971	20024T	PARTICIPANT	\N	PRESENT	0
649983	649971	19782L	PARTICIPANT	\N	PRESENT	0
649984	649971	20090E	PARTICIPANT	\N	PRESENT	0
649985	649971	14329V	PARTICIPANT	\N	PRESENT	0
649978	649971	11103C	PARTICIPANT	\N	PRESENT	0
649986	649971	18083K	PARTICIPANT	\N	PRESENT	0
649987	649971	14357A	PARTICIPANT	\N	PRESENT	0
649988	649971	20126Y	PARTICIPANT	\N	PRESENT	0
649989	649971	19713W	PARTICIPANT	\N	PRESENT	0
652466	652465	14237S	PARTICIPANT	\N	PRESENT	0
652467	652465	20058E	PARTICIPANT	\N	PRESENT	0
652468	652465	11101A	PARTICIPANT	\N	PRESENT	0
652469	652465	19631V	PARTICIPANT	\N	PRESENT	0
652470	652465	19575F	PARTICIPANT	\N	PRESENT	0
652471	652465	14189C	PARTICIPANT	\N	PRESENT	0
652472	652465	20066E	PARTICIPANT	\N	PRESENT	0
652492	648009	14179A	PARTICIPANT	\N	PRESENT	0
652921	651589	14133K	PARTICIPANT	\N	PRESENT	0
652922	651589	04085P	PARTICIPANT	\N	PRESENT	0
652923	651589	19760E	PARTICIPANT	\N	PRESENT	0
652924	651589	05008E	PARTICIPANT	\N	PRESENT	0
652925	651589	19741B	PARTICIPANT	\N	PRESENT	0
652926	651589	19667J	PARTICIPANT	\N	PRESENT	0
652927	651589	20024T	PARTICIPANT	\N	PRESENT	0
652928	651589	11033F	PARTICIPANT	\N	PRESENT	0
652929	651589	19575F	PARTICIPANT	\N	PRESENT	0
652930	651589	19549D	PARTICIPANT	\N	PRESENT	0
652931	651589	14030Q	PARTICIPANT	\N	PRESENT	0
652932	651589	08060W	PARTICIPANT	\N	PRESENT	0
652933	651589	20078J	PARTICIPANT	\N	PRESENT	0
652934	651589	19643A	PARTICIPANT	\N	PRESENT	0
652935	651589	19747H	PARTICIPANT	\N	PRESENT	0
652936	651589	20914V	PARTICIPANT	\N	PRESENT	0
652937	651589	20080C	PARTICIPANT	\N	PRESENT	0
652938	651589	20090E	PARTICIPANT	\N	PRESENT	0
652939	651589	14207L	PARTICIPANT	\N	PRESENT	0
652940	651589	20104S	PARTICIPANT	\N	PRESENT	0
652941	651589	14053L	PARTICIPANT	\N	PRESENT	0
652942	651589	14083S	PARTICIPANT	\N	PRESENT	0
652943	651589	11053K	PARTICIPANT	\N	PRESENT	0
652944	651589	19629C	PARTICIPANT	\N	PRESENT	0
652945	651589	20264J	PARTICIPANT	\N	PRESENT	0
652946	651589	19467C	PARTICIPANT	\N	PRESENT	0
652947	651589	18083K	PARTICIPANT	\N	PRESENT	0
652948	651589	11031D	PARTICIPANT	\N	PRESENT	0
652949	651589	11027H	PARTICIPANT	\N	PRESENT	0
652950	651589	20070A	PARTICIPANT	\N	PRESENT	0
652951	651589	11056N	PARTICIPANT	\N	PRESENT	0
652952	651589	14357A	PARTICIPANT	\N	PRESENT	0
652953	651589	19525U	PARTICIPANT	\N	PRESENT	0
652954	651589	11065P	PARTICIPANT	\N	PRESENT	0
652955	651589	14259Y	PARTICIPANT	\N	PRESENT	0
652956	651589	19719D	PARTICIPANT	\N	PRESENT	0
652957	651589	19663E	PARTICIPANT	\N	PRESENT	0
652958	651589	10006L	PARTICIPANT	\N	PRESENT	0
652959	651589	14217N	PARTICIPANT	\N	PRESENT	0
652960	651589	19577H	PARTICIPANT	\N	PRESENT	0
652961	651589	14042U	PARTICIPANT	\N	PRESENT	0
652962	651589	20134Y	PARTICIPANT	\N	PRESENT	0
652963	651589	14151M	PARTICIPANT	\N	PRESENT	0
652964	651589	14249W	PARTICIPANT	\N	PRESENT	0
652965	651589	11074Q	PARTICIPANT	\N	PRESENT	0
652966	651589	11110B	PARTICIPANT	\N	PRESENT	0
652967	651589	19673G	PARTICIPANT	\N	PRESENT	0
652968	651589	20038A	PARTICIPANT	\N	PRESENT	0
652969	651589	19647E	PARTICIPANT	\N	PRESENT	0
652970	651589	14281W	PARTICIPANT	\N	PRESENT	0
652971	651589	20100N	PARTICIPANT	\N	PRESENT	0
652972	651589	20132W	PARTICIPANT	\N	PRESENT	0
652973	651589	17023S	PARTICIPANT	\N	PRESENT	0
652974	651589	20286Q	PARTICIPANT	\N	PRESENT	0
652975	651589	20172F	PARTICIPANT	\N	PRESENT	0
652976	651589	19695N	PARTICIPANT	\N	PRESENT	0
652977	651589	19387D	PARTICIPANT	\N	PRESENT	0
652978	651589	19347U	PARTICIPANT	\N	PRESENT	0
652979	651589	20180F	PARTICIPANT	\N	PRESENT	0
652980	651589	07004J	PARTICIPANT	\N	PRESENT	0
652981	651589	19565D	PARTICIPANT	\N	PRESENT	0
652982	651589	14033T	PARTICIPANT	\N	PRESENT	0
652983	651589	20068G	PARTICIPANT	\N	PRESENT	0
652984	651589	19553Y	PARTICIPANT	\N	PRESENT	0
652985	651589	19583F	PARTICIPANT	\N	PRESENT	0
652986	651589	86034E	PARTICIPANT	\N	PRESENT	0
652987	651589	12041X	PARTICIPANT	\N	PRESENT	0
652988	651589	19711U	PARTICIPANT	\N	PRESENT	0
652989	651589	18193Q	PARTICIPANT	\N	PRESENT	0
652990	651589	08010L	PARTICIPANT	\N	PRESENT	0
652991	651589	08034U	PARTICIPANT	\N	PRESENT	0
652992	651589	14037X	PARTICIPANT	\N	PRESENT	0
652993	651589	01043Q	PARTICIPANT	\N	PRESENT	0
652994	651589	19697Q	PARTICIPANT	\N	PRESENT	0
652995	651589	14219Q	PARTICIPANT	\N	PRESENT	0
652996	651589	17779H	PARTICIPANT	\N	PRESENT	0
652997	651589	12016W	PARTICIPANT	\N	PRESENT	0
652998	651589	14031R	PARTICIPANT	\N	PRESENT	0
652999	651589	19637C	PARTICIPANT	\N	PRESENT	0
653000	651589	20028X	PARTICIPANT	\N	PRESENT	0
653001	651589	11067R	PARTICIPANT	\N	PRESENT	0
653002	651589	19671E	PARTICIPANT	\N	PRESENT	0
653003	651589	14223L	PARTICIPANT	\N	PRESENT	0
653004	651589	19369B	PARTICIPANT	\N	PRESENT	0
653005	651589	11072N	PARTICIPANT	\N	PRESENT	0
653006	651589	14257W	PARTICIPANT	\N	PRESENT	0
653007	651589	14071N	PARTICIPANT	\N	PRESENT	0
653008	651589	19593H	PARTICIPANT	\N	PRESENT	0
653009	651589	19573D	PARTICIPANT	\N	PRESENT	0
653010	651589	19866P	PARTICIPANT	\N	PRESENT	0
653011	651589	20050V	PARTICIPANT	\N	PRESENT	0
653012	651589	20036X	PARTICIPANT	\N	PRESENT	0
653013	651589	08061X	PARTICIPANT	\N	PRESENT	0
653014	651589	20146D	PARTICIPANT	\N	PRESENT	0
653015	651589	19533U	PARTICIPANT	\N	PRESENT	0
653016	651589	20130U	PARTICIPANT	\N	PRESENT	0
653017	651589	17965H	PARTICIPANT	\N	PRESENT	0
653018	651589	19503N	PARTICIPANT	\N	PRESENT	0
653019	651589	11090Q	PARTICIPANT	\N	PRESENT	0
653020	651589	19679N	PARTICIPANT	\N	PRESENT	0
653021	651589	20298U	PARTICIPANT	\N	PRESENT	0
653022	651589	14055N	PARTICIPANT	\N	PRESENT	0
653023	651589	14225N	PARTICIPANT	\N	PRESENT	0
653024	651589	20082E	PARTICIPANT	\N	PRESENT	0
653025	651589	10015M	PARTICIPANT	\N	PRESENT	0
653026	651589	04033B	PARTICIPANT	\N	PRESENT	0
653027	651589	11045K	PARTICIPANT	\N	PRESENT	0
653028	651589	20092G	PARTICIPANT	\N	PRESENT	0
653029	651589	20044X	PARTICIPANT	\N	PRESENT	0
653030	651589	11097X	PARTICIPANT	\N	PRESENT	0
653031	651589	19687N	PARTICIPANT	\N	PRESENT	0
653032	651589	19762G	PARTICIPANT	\N	PRESENT	0
653033	651589	20136B	PARTICIPANT	\N	PRESENT	0
653034	651589	19301E	PARTICIPANT	\N	PRESENT	0
653035	651589	01034P	PARTICIPANT	\N	PRESENT	0
653036	651589	20026V	PARTICIPANT	\N	PRESENT	0
653037	651589	19479G	PARTICIPANT	\N	PRESENT	0
653038	651589	14173T	PARTICIPANT	\N	PRESENT	0
653039	651589	19954N	PARTICIPANT	\N	PRESENT	0
653040	651589	20124W	PARTICIPANT	\N	PRESENT	0
653041	651589	19569H	PARTICIPANT	\N	PRESENT	0
653042	651589	19333N	PARTICIPANT	\N	PRESENT	0
653043	651589	11048N	PARTICIPANT	\N	PRESENT	0
653044	651589	19591F	PARTICIPANT	\N	PRESENT	0
653045	651589	14213J	PARTICIPANT	\N	PRESENT	0
653046	651589	20066E	PARTICIPANT	\N	PRESENT	0
653047	651589	20034V	PARTICIPANT	\N	PRESENT	0
653048	651589	19715Y	PARTICIPANT	\N	PRESENT	0
653049	651589	19683J	PARTICIPANT	\N	PRESENT	0
653050	651589	14021P	PARTICIPANT	\N	PRESENT	0
653051	651589	99004R	PARTICIPANT	\N	PRESENT	0
653052	651589	20018V	PARTICIPANT	\N	PRESENT	0
653053	651589	19349W	PARTICIPANT	\N	PRESENT	0
653073	653072	20076G	PARTICIPANT	\N	PRESENT	0
653074	653072	14205J	PARTICIPANT	\N	PRESENT	0
653075	653072	20054A	PARTICIPANT	\N	PRESENT	0
628541	627016	14331P	PARTICIPANT	\N	PRESENT	0
628543	627016	19531S	PARTICIPANT	\N	PRESENT	0
628557	627017	14331P	PARTICIPANT	\N	PRESENT	0
628558	627017	19531S	PARTICIPANT	\N	PRESENT	0
628837	628836	19820Y	PARTICIPANT	\N	PRESENT	1
628838	628836	14207L	PARTICIPANT	\N	PRESENT	0
628857	628836	19798U	PARTICIPANT	\N	PRESENT	1
629040	626565	14189C	PARTICIPANT	\N	PRESENT	0
629041	626565	20104S	PARTICIPANT	\N	PRESENT	0
629042	626565	14357A	PARTICIPANT	\N	PRESENT	0
629043	626565	11083R	PARTICIPANT	\N	PRESENT	1
629044	626565	14026U	PARTICIPANT	\N	PRESENT	0
629045	626565	20128B	PARTICIPANT	\N	PRESENT	1
629047	626565	14097Y	PARTICIPANT	\N	PRESENT	0
629048	626565	14073Q	PARTICIPANT	\N	PRESENT	1
629049	626565	12041X	PARTICIPANT	\N	PRESENT	0
629050	626565	19711U	PARTICIPANT	\N	PRESENT	0
629051	626565	11026G	PARTICIPANT	\N	PRESENT	0
629052	626565	08034U	PARTICIPANT	\N	PRESENT	0
629053	626565	19441R	PARTICIPANT	\N	PRESENT	0
629054	626565	04057K	PARTICIPANT	\N	PRESENT	1
629055	626565	04070G	PARTICIPANT	\N	PRESENT	0
629056	626565	14331P	PARTICIPANT	\N	PRESENT	0
629057	626565	10015M	PARTICIPANT	\N	PRESENT	0
629058	626565	14207L	PARTICIPANT	\N	EXCUSE	0
629101	626693	10006L	PARTICIPANT	\N	PRESENT	0
629102	626693	19723Y	PARTICIPANT	\N	PRESENT	1
629103	626693	20062A	PARTICIPANT	\N	PRESENT	1
629105	626693	14147R	PARTICIPANT	\N	PRESENT	1
629107	626693	11031D	PARTICIPANT	\N	EXCUSE	0
629112	626693	20130U	PARTICIPANT	\N	PRESENT	1
629113	626693	19683J	PRESIDENT	0	PRESENT	0
629114	626693	19467C	PARTICIPANT	\N	PRESENT	1
629120	626693	19735D	PARTICIPANT	\N	PRESENT	1
629130	626693	19691J	PARTICIPANT	\N	PRESENT	1
629201	626693	19553Y	PARTICIPANT	\N	PRESENT	1
629210	626693	19295A	PARTICIPANT	\N	EXCUSE	0
632464	632462	20050V	PARTICIPANT	\N	PRESENT	0
632466	632462	19693L	PARTICIPANT	\N	PRESENT	0
632467	632462	20126Y	PARTICIPANT	\N	PRESENT	0
632468	632462	11077T	PARTICIPANT	\N	PRESENT	0
637135	635658	19631V	PARTICIPANT	\N	PRESENT	0
637136	635658	19673G	PARTICIPANT	\N	EXCUSE	0
637137	635658	17023S	PARTICIPANT	\N	PRESENT	0
637138	635658	97011G	PARTICIPANT	\N	PRESENT	0
637139	635658	11010L	PARTICIPANT	\N	PRESENT	0
637140	635658	19691J	PARTICIPANT	\N	EXCUSE	0
637141	635658	20034V	PARTICIPANT	\N	PRESENT	1
637142	635658	14219Q	PARTICIPANT	\N	EXCUSE	0
637143	635658	14059S	PRESIDENT	0	PRESENT	0
637144	635658	14147R	PARTICIPANT	\N	PRESENT	0
637145	635658	20148F	PARTICIPANT	\N	PRESENT	0
637146	635658	20146D	PARTICIPANT	\N	PRESENT	0
637147	635658	14331P	PARTICIPANT	\N	EXCUSE	0
637148	635658	20150Y	PARTICIPANT	\N	EXCUSE	0
637149	635658	19715Y	PARTICIPANT	\N	PRESENT	0
637167	637166	20020P	PARTICIPANT	\N	PRESENT	0
637169	637168	20020P	PARTICIPANT	\N	PRESENT	0
637469	634660	11033F	PARTICIPANT	\N	PRESENT	0
637470	634660	20114U	PARTICIPANT	\N	PRESENT	0
637474	634660	04047H	PARTICIPANT	\N	PRESENT	0
637475	634660	04085P	PARTICIPANT	\N	PRESENT	0
637476	634660	19749K	PARTICIPANT	\N	PRESENT	0
637477	634660	19583F	PARTICIPANT	\N	PRESENT	0
637478	634660	20106U	PARTICIPANT	\N	PRESENT	0
637479	634660	20110Q	PARTICIPANT	\N	PRESENT	0
637480	634660	19866P	PARTICIPANT	\N	PRESENT	0
637481	634660	14215L	PARTICIPANT	\N	PRESENT	0
637482	634660	19443T	PARTICIPANT	\N	PRESENT	0
637483	634660	05008E	PARTICIPANT	\N	PRESENT	0
637484	634660	19693L	PARTICIPANT	\N	PRESENT	0
637485	634660	20090E	PARTICIPANT	\N	PRESENT	0
637486	634660	19715Y	PARTICIPANT	\N	PRESENT	0
637487	634660	11064N	PARTICIPANT	\N	PRESENT	0
637488	634660	20032T	PARTICIPANT	\N	PRESENT	0
637489	634660	14237S	PARTICIPANT	\N	PRESENT	0
637490	634660	11067R	PARTICIPANT	\N	PRESENT	0
637491	634660	18193Q	PARTICIPANT	\N	PRESENT	0
637492	634660	14021P	PARTICIPANT	\N	PRESENT	0
637493	634660	14217N	PARTICIPANT	\N	PRESENT	0
637494	634660	14026U	PARTICIPANT	\N	PRESENT	0
637462	634660	11045K	PARTICIPANT	\N	PRESENT	0
637466	634660	14147R	PARTICIPANT	\N	PRESENT	0
637495	634660	19782L	PARTICIPANT	\N	PRESENT	0
637496	634660	19543W	PARTICIPANT	\N	PRESENT	0
637497	634660	20248J	PARTICIPANT	\N	PRESENT	0
637499	637498	14151M	PARTICIPANT	\N	PRESENT	0
637500	637498	19543W	PARTICIPANT	\N	PRESENT	0
637501	632461	14281W	PARTICIPANT	\N	PRESENT	0
637502	632461	05012A	PARTICIPANT	\N	PRESENT	0
637503	632461	19447X	PARTICIPANT	\N	PRESENT	0
637504	632461	14069U	PARTICIPANT	\N	PRESENT	0
637505	632461	20070A	PARTICIPANT	\N	PRESENT	0
637506	632461	20120S	PARTICIPANT	\N	PRESENT	0
637508	632461	19954N	PARTICIPANT	\N	PRESENT	0
637513	634660	14073Q	PARTICIPANT	\N	PRESENT	0
637514	634660	19563B	PARTICIPANT	\N	PRESENT	0
637515	634660	20088L	PARTICIPANT	\N	PRESENT	0
637516	634660	19629C	PARTICIPANT	\N	PRESENT	0
637517	634660	19711U	PARTICIPANT	\N	PRESENT	0
637518	634660	19691J	PARTICIPANT	\N	PRESENT	0
637519	634660	20062A	PARTICIPANT	\N	PRESENT	0
637520	634660	20152B	PARTICIPANT	\N	PRESENT	0
637521	634660	14257W	PARTICIPANT	\N	PRESENT	0
637561	634661	14257W	PARTICIPANT	\N	PRESENT	0
637562	634661	20088L	PARTICIPANT	\N	PRESENT	0
637563	634661	19749K	PARTICIPANT	\N	PRESENT	0
637134	635658	19717B	PARTICIPANT	\N	PRESENT	1
637564	634661	14073Q	PARTICIPANT	\N	PRESENT	0
637565	634661	07029T	PARTICIPANT	\N	PRESENT	0
637566	634661	20090E	PARTICIPANT	\N	PRESENT	0
637567	634661	97011G	PARTICIPANT	\N	PRESENT	0
637568	634661	19711U	PARTICIPANT	\N	PRESENT	0
637569	634661	19691J	PARTICIPANT	\N	PRESENT	0
637570	634661	19715Y	PARTICIPANT	\N	PRESENT	0
637571	634661	20110Q	PARTICIPANT	\N	PRESENT	0
637572	634661	20174H	PARTICIPANT	\N	PRESENT	0
637573	634661	20106U	PARTICIPANT	\N	PRESENT	0
637574	634661	19782L	PARTICIPANT	\N	PRESENT	0
637575	634661	19563B	PARTICIPANT	\N	PRESENT	0
637576	634661	19583F	PARTICIPANT	\N	PRESENT	0
637577	634661	19693L	PARTICIPANT	\N	PRESENT	0
637578	637314	04008A	PARTICIPANT	\N	PRESENT	0
637579	637314	14151M	PARTICIPANT	\N	PRESENT	0
637580	634661	19629C	PARTICIPANT	\N	PRESENT	0
637581	637314	19543W	PARTICIPANT	\N	PRESENT	0
637582	634661	19866P	PARTICIPANT	\N	PRESENT	0
637583	634661	20152B	PARTICIPANT	\N	PRESENT	0
637584	634661	20248J	PARTICIPANT	\N	PRESENT	0
637585	634661	14215L	PARTICIPANT	\N	PRESENT	0
637586	634661	19443T	PARTICIPANT	\N	PRESENT	0
637587	634661	19611R	PARTICIPANT	\N	PRESENT	0
637588	634661	10006L	PARTICIPANT	\N	PRESENT	0
637589	634661	19695N	PARTICIPANT	\N	PRESENT	0
637590	634661	19507S	PARTICIPANT	\N	PRESENT	0
637592	634661	19467C	PARTICIPANT	\N	PRESENT	0
637593	634661	14205J	PARTICIPANT	\N	PRESENT	0
637595	637594	20104S	PARTICIPANT	\N	PRESENT	0
637596	637594	19701S	PARTICIPANT	\N	PRESENT	0
637597	634661	20064C	PARTICIPANT	\N	PRESENT	0
637598	634661	19697Q	PARTICIPANT	\N	PRESENT	0
637599	634661	14147R	PARTICIPANT	\N	PRESENT	0
637559	634661	11045K	PARTICIPANT	\N	PRESENT	0
637560	634661	20114U	PARTICIPANT	\N	PRESENT	0
637600	634661	20128B	PARTICIPANT	\N	PRESENT	0
637601	634661	11012A	PARTICIPANT	\N	PRESENT	0
637602	634661	14026U	PARTICIPANT	\N	PRESENT	0
637603	634661	20062A	PARTICIPANT	\N	PRESENT	0
637612	634661	14033T	PARTICIPANT	\N	PRESENT	0
637613	634661	20032T	PARTICIPANT	\N	PRESENT	0
637617	634661	19631V	PARTICIPANT	\N	PRESENT	0
637618	634661	17023S	PARTICIPANT	\N	PRESENT	0
637626	634661	19577H	PARTICIPANT	\N	PRESENT	0
637627	634661	20082E	PARTICIPANT	\N	PRESENT	0
637628	634661	14237S	PARTICIPANT	\N	PRESENT	0
637629	634661	20092G	PARTICIPANT	\N	PRESENT	0
646405	646402	18083K	PARTICIPANT	\N	PRESENT	0
646406	646402	19515S	PARTICIPANT	\N	PRESENT	0
646407	646402	95063L	PARTICIPANT	\N	PRESENT	0
646408	646402	14257W	PARTICIPANT	\N	PRESENT	0
646409	646402	14151M	PARTICIPANT	\N	PRESENT	0
646448	646447	01028R	PARTICIPANT	\N	PRESENT	0
647536	646324	19741B	PARTICIPANT	\N	PRESENT	0
647537	646324	11040E	PARTICIPANT	\N	PRESENT	1
647538	646324	14083S	PARTICIPANT	\N	PRESENT	0
647539	646324	20070A	PARTICIPANT	\N	PRESENT	0
647540	646324	11048N	PARTICIPANT	\N	PRESENT	0
647541	646324	20126Y	PARTICIPANT	\N	PRESENT	1
647542	646324	19711U	PARTICIPANT	\N	PRESENT	1
647543	646324	19671E	PARTICIPANT	\N	PRESENT	1
647544	646324	14225N	PARTICIPANT	\N	PRESENT	0
647545	646324	19479G	PARTICIPANT	\N	PRESENT	1
647548	647547	01028R	PARTICIPANT	\N	PRESENT	0
647550	647549	01028R	PARTICIPANT	\N	PRESENT	0
647552	647551	01028R	PARTICIPANT	\N	PRESENT	0
647553	647508	19717B	PARTICIPANT	\N	EXCUSE	0
647554	647508	20094J	PARTICIPANT	\N	EXCUSE	0
647555	647508	08060W	PARTICIPANT	\N	EXCUSE	0
647556	647508	19545Y	PARTICIPANT	\N	EXCUSE	0
647557	647508	20060X	PARTICIPANT	\N	EXCUSE	0
647558	647508	14195A	PARTICIPANT	\N	EXCUSE	0
647559	647508	20040T	PARTICIPANT	\N	EXCUSE	0
647560	647508	19695N	PARTICIPANT	\N	EXCUSE	0
647561	647508	14026U	PARTICIPANT	\N	EXCUSE	0
647562	647508	20108W	PARTICIPANT	\N	EXCUSE	0
647563	647508	19697Q	PARTICIPANT	\N	EXCUSE	0
647564	647508	19369B	PARTICIPANT	\N	EXCUSE	0
647565	647508	19866P	PARTICIPANT	\N	EXCUSE	0
647566	647508	08073C	PARTICIPANT	\N	EXCUSE	0
647567	647508	17965H	PARTICIPANT	\N	EXCUSE	0
647568	647508	20082E	PARTICIPANT	\N	EXCUSE	0
647569	647508	20054A	PARTICIPANT	\N	EXCUSE	0
647570	647508	19301E	PARTICIPANT	\N	EXCUSE	0
647571	647461	19333N	PARTICIPANT	\N	EXCUSE	0
647572	647461	19563B	PARTICIPANT	\N	EXCUSE	0
647573	647461	14053L	PARTICIPANT	\N	EXCUSE	0
647574	647461	14327T	PARTICIPANT	\N	EXCUSE	0
647575	647461	19565D	PARTICIPANT	\N	EXCUSE	0
647577	647461	19489J	PARTICIPANT	\N	EXCUSE	0
647579	647461	14071N	PARTICIPANT	\N	EXCUSE	0
647954	647950	14038Y	PARTICIPANT	\N	PRESENT	0
647955	647950	14147R	PARTICIPANT	\N	PRESENT	0
647956	647950	19629C	PARTICIPANT	\N	PRESENT	0
647957	647950	19575F	PARTICIPANT	\N	EXCUSE	0
647958	646291	14121F	PARTICIPANT	\N	PRESENT	0
648211	647646	95063L	PARTICIPANT	\N	PRESENT	0
648212	647646	19565D	PARTICIPANT	\N	PRESENT	0
648213	647646	19758L	PARTICIPANT	\N	PRESENT	0
648214	647646	14249W	PARTICIPANT	\N	PRESENT	0
648215	647646	20100N	PARTICIPANT	\N	PRESENT	0
648216	647646	19549D	PARTICIPANT	\N	PRESENT	0
648217	647646	18083K	PARTICIPANT	\N	PRESENT	0
648218	647646	01025N	PARTICIPANT	\N	PRESENT	0
648219	647646	01024M	PARTICIPANT	\N	PRESENT	0
648220	647646	14147R	PARTICIPANT	\N	PRESENT	0
648221	647646	20022R	PARTICIPANT	\N	PRESENT	0
648222	647646	20062A	PARTICIPANT	\N	PRESENT	0
648223	647646	19533U	PARTICIPANT	\N	PRESENT	0
648224	647646	20082E	PARTICIPANT	\N	PRESENT	0
648225	647646	14215L	PARTICIPANT	\N	PRESENT	0
648226	647646	04047H	PARTICIPANT	\N	PRESENT	0
648227	647646	14151M	PARTICIPANT	\N	PRESENT	0
648228	647646	12016W	PARTICIPANT	\N	PRESENT	0
648229	647646	19593H	PARTICIPANT	\N	PRESENT	0
648230	647646	11056N	PARTICIPANT	\N	PRESENT	0
648231	647646	11033F	PARTICIPANT	\N	PRESENT	0
648232	647646	20914V	PARTICIPANT	\N	PRESENT	0
648233	647646	20110Q	PARTICIPANT	\N	PRESENT	0
648235	647646	20134Y	PARTICIPANT	\N	PRESENT	0
648236	647646	11012A	PARTICIPANT	\N	PRESENT	0
648237	647646	19563B	PARTICIPANT	\N	PRESENT	0
648241	647646	19553Y	PARTICIPANT	\N	PRESENT	0
648243	647646	14107H	PARTICIPANT	\N	PRESENT	0
648245	647646	19629C	PARTICIPANT	\N	PRESENT	0
648248	647646	20142Y	PARTICIPANT	\N	PRESENT	0
648251	647646	19441R	PARTICIPANT	\N	PRESENT	0
648252	647646	14231L	PARTICIPANT	\N	PRESENT	0
648253	647646	14053L	PARTICIPANT	\N	PRESENT	0
648255	647646	19798U	PARTICIPANT	\N	PRESENT	0
648259	647646	20152B	PARTICIPANT	\N	PRESENT	0
648262	647646	20090E	PARTICIPANT	\N	PRESENT	0
648264	647646	20108W	PARTICIPANT	\N	PRESENT	0
648269	647646	19747H	PARTICIPANT	\N	PRESENT	0
648272	647646	20032T	PARTICIPANT	\N	PRESENT	0
648273	647646	14191V	PARTICIPANT	\N	PRESENT	0
648275	647646	20038A	PARTICIPANT	\N	PRESENT	0
648276	647646	19507S	PARTICIPANT	\N	PRESENT	0
648277	647646	20056C	PARTICIPANT	\N	PRESENT	0
648280	647646	19467C	PARTICIPANT	\N	PRESENT	0
648284	647646	20058E	PARTICIPANT	\N	PRESENT	0
648286	647646	17737W	PARTICIPANT	\N	PRESENT	0
648291	647646	20128B	PARTICIPANT	\N	PRESENT	0
648339	647646	19631V	PARTICIPANT	\N	PRESENT	0
648341	647646	20088L	PARTICIPANT	\N	PRESENT	0
648348	647646	20064C	PARTICIPANT	\N	PRESENT	0
648350	647646	20024T	PARTICIPANT	\N	PRESENT	0
648354	647646	19673G	PARTICIPANT	\N	PRESENT	0
648391	647646	19741B	PARTICIPANT	\N	PRESENT	0
648396	647646	14021P	PARTICIPANT	\N	PRESENT	0
648398	647646	19760E	PARTICIPANT	\N	PRESENT	0
648399	647646	01058X	PARTICIPANT	\N	PRESENT	0
648400	647646	14173T	PARTICIPANT	\N	PRESENT	0
648401	647646	19681G	PARTICIPANT	\N	PRESENT	0
648402	647646	04085P	PARTICIPANT	\N	PRESENT	0
648403	647646	19621T	PARTICIPANT	\N	PRESENT	0
648408	647646	19479G	PARTICIPANT	\N	PRESENT	0
648409	647646	19611R	PARTICIPANT	\N	PRESENT	0
648410	647646	20104S	PARTICIPANT	\N	PRESENT	0
648411	647646	14133K	PARTICIPANT	\N	PRESENT	0
648832	647962	19717B	PRESIDENT	0	PRESENT	0
648834	647962	05008E	PARTICIPANT	\N	EXCUSE	0
649007	647519	04059M	PARTICIPANT	\N	PRESENT	0
649008	647519	19651A	PARTICIPANT	\N	PRESENT	0
649009	647519	14030Q	PARTICIPANT	\N	PRESENT	0
649010	647519	20138D	PARTICIPANT	\N	PRESENT	0
649011	647519	20152B	PARTICIPANT	\N	PRESENT	0
649012	647519	19621T	PARTICIPANT	\N	PRESENT	0
649013	647519	19758L	PARTICIPANT	\N	PRESENT	0
649014	647519	19057M	PARTICIPANT	\N	PRESENT	0
649015	647519	20264J	PARTICIPANT	\N	PRESENT	0
649016	647519	20134Y	PARTICIPANT	\N	PRESENT	0
649017	647519	20124W	PARTICIPANT	\N	PRESENT	0
649018	647519	20132W	PARTICIPANT	\N	PRESENT	0
649019	647519	20172F	PARTICIPANT	\N	PRESENT	0
649020	647519	14123H	PARTICIPANT	\N	PRESENT	0
649021	647519	20180F	PARTICIPANT	\N	PRESENT	0
649022	647519	20048C	PARTICIPANT	\N	PRESENT	0
649023	647519	19399H	PARTICIPANT	\N	PRESENT	0
649024	647519	20056C	PARTICIPANT	\N	PRESENT	0
649025	647519	19735D	PARTICIPANT	\N	PRESENT	0
649026	647519	19611R	PARTICIPANT	\N	PRESENT	0
649027	647519	20052X	PARTICIPANT	\N	PRESENT	0
649028	647519	08012N	PARTICIPANT	\N	PRESENT	0
649029	647519	14109K	PARTICIPANT	\N	PRESENT	0
649030	647519	19593H	PARTICIPANT	\N	PRESENT	0
649031	647519	19573D	PARTICIPANT	\N	PRESENT	0
649032	647519	19533U	PARTICIPANT	\N	PRESENT	0
649033	647519	19766L	PARTICIPANT	\N	PRESENT	0
649034	647519	04033B	PARTICIPANT	\N	PRESENT	0
649035	647519	14229S	PARTICIPANT	\N	PRESENT	0
649036	647519	11043H	PARTICIPANT	\N	PRESENT	0
649037	647519	20098N	PARTICIPANT	\N	PRESENT	0
649038	647519	20084G	PARTICIPANT	\N	PRESENT	0
649039	647519	19527W	PARTICIPANT	\N	PRESENT	0
649040	647519	20026V	PARTICIPANT	\N	PRESENT	0
649041	647519	20058E	PARTICIPANT	\N	PRESENT	0
649055	648755	20152B	PARTICIPANT	\N	PRESENT	0
649056	648755	19057M	PARTICIPANT	\N	PRESENT	0
649058	648755	14109K	PARTICIPANT	\N	PRESENT	1
649059	648755	11104D	PARTICIPANT	\N	PRESENT	0
649060	648755	19533U	PARTICIPANT	\N	PRESENT	0
649062	648755	14030Q	PARTICIPANT	\N	PRESENT	0
649063	648755	20138D	PARTICIPANT	\N	PRESENT	0
649064	648755	19643A	PARTICIPANT	\N	PRESENT	0
649071	649070	14147R	PARTICIPANT	\N	PRESENT	0
649072	649070	14231L	PARTICIPANT	\N	PRESENT	0
627812	627015	11109J	PARTICIPANT	\N	EXCUSE	0
627813	627015	04059M	PARTICIPANT	\N	PRESENT	0
627814	627015	19651A	PARTICIPANT	\N	PRESENT	1
627815	627015	14030Q	PARTICIPANT	\N	PRESENT	0
627816	627015	19643A	PARTICIPANT	\N	PRESENT	1
627817	627015	20152B	PARTICIPANT	\N	PRESENT	0
627818	627015	19621T	PARTICIPANT	\N	PRESENT	0
627819	627015	19758L	PARTICIPANT	\N	PRESENT	0
627820	627015	20264J	PARTICIPANT	\N	PRESENT	0
627821	627015	19693L	PARTICIPANT	\N	PRESENT	0
627822	627015	20124W	PARTICIPANT	\N	PRESENT	0
627823	627015	20132W	PARTICIPANT	\N	PRESENT	0
627824	627015	20172F	PARTICIPANT	\N	PRESENT	0
627825	627015	20180F	PARTICIPANT	\N	PRESENT	0
627826	627015	14123H	PARTICIPANT	\N	PRESENT	0
627827	627015	19399H	PARTICIPANT	\N	PRESENT	0
627828	627015	20056C	PARTICIPANT	\N	PRESENT	0
627829	627015	14073Q	PARTICIPANT	\N	PRESENT	1
627831	627015	19611R	PRESIDENT	0	PRESENT	0
627832	627015	19735D	PARTICIPANT	\N	PRESENT	0
627833	627015	19699S	PARTICIPANT	\N	PRESENT	1
627834	627015	20052X	PARTICIPANT	\N	PRESENT	0
627835	627015	08012N	PARTICIPANT	\N	PRESENT	0
627836	627015	11104D	PARTICIPANT	\N	PRESENT	1
627837	627015	20142Y	PARTICIPANT	\N	PRESENT	0
627838	627015	14109K	PARTICIPANT	\N	PRESENT	1
627839	627015	19593H	PARTICIPANT	\N	PRESENT	0
627840	627015	19573D	PARTICIPANT	\N	PRESENT	0
627841	627015	19533U	PARTICIPANT	\N	PRESENT	0
627842	627015	19766L	PARTICIPANT	\N	PRESENT	0
627843	627015	04033B	PARTICIPANT	\N	PRESENT	0
627844	627015	14229S	PARTICIPANT	\N	PRESENT	0
627845	627015	11043H	PARTICIPANT	\N	PRESENT	0
627846	627015	20098N	PARTICIPANT	\N	PRESENT	0
627847	627015	19527W	PARTICIPANT	\N	PRESENT	0
627848	627015	20026V	PARTICIPANT	\N	PRESENT	0
627849	627015	20058E	PARTICIPANT	\N	PRESENT	0
627850	627015	20084G	PARTICIPANT	\N	PRESENT	0
628548	628546	14089Y	PARTICIPANT	\N	PRESENT	0
628549	628546	11056N	PARTICIPANT	\N	PRESENT	0
628550	628546	95063L	PARTICIPANT	\N	PRESENT	0
628571	627944	19599P	PARTICIPANT	\N	PRESENT	0
628642	628641	10006L	PARTICIPANT	\N	PRESENT	0
628643	628641	14147R	PARTICIPANT	\N	PRESENT	0
628644	628641	19703U	PARTICIPANT	\N	PRESENT	0
628645	628641	11031D	PARTICIPANT	\N	PRESENT	0
628646	628641	19691J	PARTICIPANT	\N	PRESENT	0
628647	628641	19723Y	PARTICIPANT	\N	PRESENT	0
628773	628772	20022R	PARTICIPANT	\N	PRESENT	0
628774	628772	18083K	PARTICIPANT	\N	PRESENT	0
628775	628772	11083R	PARTICIPANT	\N	PRESENT	0
628776	628772	20120S	PARTICIPANT	\N	PRESENT	0
628777	628772	11048N	PARTICIPANT	\N	PRESENT	0
628778	628772	19711U	PARTICIPANT	\N	PRESENT	0
628779	628772	14059S	PARTICIPANT	\N	PRESENT	0
628780	628772	20118Y	PARTICIPANT	\N	PRESENT	0
628781	628772	11043H	PARTICIPANT	\N	PRESENT	0
628782	628772	20058E	PARTICIPANT	\N	PRESENT	0
629858	629857	19747H	PARTICIPANT	\N	PRESENT	0
629859	629857	19693L	PARTICIPANT	\N	PRESENT	0
629860	629857	14097Y	PARTICIPANT	\N	PRESENT	0
629861	629857	11072N	PARTICIPANT	\N	PRESENT	0
629862	629857	20050V	PARTICIPANT	\N	PRESENT	0
629863	629857	14193X	PARTICIPANT	\N	PRESENT	0
629864	629857	20082E	PARTICIPANT	\N	PRESENT	0
632951	631766	14189C	PARTICIPANT	\N	PRESENT	0
632952	631766	20024T	PARTICIPANT	\N	PRESENT	0
632953	631766	19575F	PARTICIPANT	\N	PRESENT	0
632954	631766	20116W	PARTICIPANT	\N	PRESENT	0
632955	631766	14069U	PARTICIPANT	\N	PRESENT	0
632956	631766	20042V	PARTICIPANT	\N	PRESENT	0
632957	631766	20090E	PARTICIPANT	\N	PRESENT	0
632958	631766	11053K	PARTICIPANT	\N	PRESENT	0
632959	631766	14211G	PARTICIPANT	\N	PRESENT	0
632960	631766	14179A	PARTICIPANT	\N	PRESENT	0
632961	631766	19333N	PARTICIPANT	\N	PRESENT	0
632962	631766	20052X	PARTICIPANT	\N	PRESENT	0
632963	631766	19745F	PARTICIPANT	\N	PRESENT	0
632964	631766	19349W	PARTICIPANT	\N	PRESENT	0
632965	631766	19671E	PARTICIPANT	\N	PRESENT	0
632966	631766	20150Y	PARTICIPANT	\N	PRESENT	0
632967	631766	20044X	PARTICIPANT	\N	PRESENT	0
632968	631766	11097X	PARTICIPANT	\N	PRESENT	0
632970	632969	08010L	PARTICIPANT	\N	PRESENT	0
632972	632971	01048V	PARTICIPANT	\N	PRESENT	0
633221	633220	19549D	PARTICIPANT	\N	PRESENT	0
633222	633220	20024T	PARTICIPANT	\N	PRESENT	0
633224	633220	19747H	PARTICIPANT	\N	PRESENT	0
633225	633220	20090E	PARTICIPANT	\N	PRESENT	0
633227	633220	04035D	PARTICIPANT	\N	PRESENT	0
633230	633220	10015M	PARTICIPANT	\N	PRESENT	0
633231	633220	20084G	PARTICIPANT	\N	PRESENT	0
633520	630830	19735D	PARTICIPANT	\N	EXCUSE	0
633523	630830	10006L	PARTICIPANT	\N	PRESENT	0
633524	630830	19683J	PRESIDENT	0	PRESENT	0
633530	630830	20130U	PARTICIPANT	\N	PRESENT	0
633575	630830	11031D	PARTICIPANT	\N	PRESENT	0
633576	630830	19713W	PARTICIPANT	\N	PRESENT	0
633577	630830	19691J	PARTICIPANT	\N	PRESENT	0
633578	630830	20062A	PARTICIPANT	\N	PRESENT	0
633579	630830	14147R	PARTICIPANT	\N	PRESENT	0
633591	630830	19301E	PARTICIPANT	\N	PRESENT	1
633761	633748	04059M	PARTICIPANT	\N	PRESENT	0
633762	633748	19651A	PARTICIPANT	\N	PRESENT	1
633763	633748	20086J	PARTICIPANT	\N	PRESENT	0
634088	634073	14123H	PARTICIPANT	\N	PRESENT	0
634089	634073	14026U	PARTICIPANT	\N	PRESENT	0
633766	633748	11053K	PARTICIPANT	\N	PRESENT	0
634086	634073	19599P	PARTICIPANT	\N	PRESENT	0
634087	634073	14033T	PARTICIPANT	\N	PRESENT	0
634090	634073	11064N	PARTICIPANT	\N	PRESENT	0
633770	633748	19725B	PARTICIPANT	\N	PRESENT	0
633771	633748	19399H	PARTICIPANT	\N	PRESENT	0
634091	634073	14179A	PARTICIPANT	\N	PRESENT	0
633773	633748	19611R	PRESIDENT	0	PRESENT	0
633774	633748	19699S	PARTICIPANT	\N	PRESENT	0
634092	634073	19715Y	PARTICIPANT	\N	PRESENT	0
633776	633748	20142Y	PARTICIPANT	\N	PRESENT	0
633777	633748	19705W	PARTICIPANT	\N	PRESENT	1
633778	633748	14229S	PARTICIPANT	\N	PRESENT	0
634093	634073	99004R	PARTICIPANT	\N	PRESENT	0
634094	634073	86034E	PARTICIPANT	\N	PRESENT	0
634095	634073	01043Q	PARTICIPANT	\N	PRESENT	0
634097	634073	14147R	PARTICIPANT	\N	PRESENT	0
634098	634073	08073C	PARTICIPANT	\N	PRESENT	0
634100	634073	11045K	PARTICIPANT	\N	PRESENT	0
634101	634073	01028R	PARTICIPANT	\N	PRESENT	0
634104	634073	19413M	PARTICIPANT	\N	PRESENT	0
634238	634237	19515S	PARTICIPANT	\N	PRESENT	0
634240	634237	19693L	PARTICIPANT	\N	PRESENT	0
634241	634237	14213J	PARTICIPANT	\N	PRESENT	1
634242	634237	20066E	PARTICIPANT	\N	PRESENT	0
634243	634237	20126Y	PARTICIPANT	\N	PRESENT	1
634244	634237	20050V	PARTICIPANT	\N	PRESENT	0
634245	634237	20082E	PARTICIPANT	\N	PRESENT	0
634258	634252	20092G	PARTICIPANT	\N	PRESENT	0
634254	634252	19782L	PARTICIPANT	\N	PRESENT	0
634255	634252	19629C	PARTICIPANT	\N	PRESENT	0
634256	634252	14038Y	PARTICIPANT	\N	PRESENT	0
634257	634252	20028X	PARTICIPANT	\N	PRESENT	0
634260	634259	19782L	PARTICIPANT	\N	PRESENT	0
634261	634259	19629C	PARTICIPANT	\N	PRESENT	0
634262	634259	14038Y	PARTICIPANT	\N	PRESENT	0
634263	634259	20028X	PARTICIPANT	\N	PRESENT	0
634264	634259	20092G	PARTICIPANT	\N	PRESENT	0
634266	634265	19782L	PARTICIPANT	\N	PRESENT	0
634267	634265	19629C	PARTICIPANT	\N	PRESENT	0
634268	634265	14038Y	PARTICIPANT	\N	PRESENT	0
634269	634265	20028X	PARTICIPANT	\N	PRESENT	0
634270	634265	20092G	PARTICIPANT	\N	PRESENT	0
634865	633936	20108W	PRESIDENT	0	PRESENT	0
634866	633936	20024T	PARTICIPANT	\N	PRESENT	0
634867	633936	14089Y	PARTICIPANT	\N	PRESENT	0
634868	633936	20040T	PARTICIPANT	\N	PRESENT	0
634869	633936	11026G	PARTICIPANT	\N	PRESENT	1
634870	633936	95063L	PARTICIPANT	\N	PRESENT	0
634914	633936	14189C	PARTICIPANT	\N	PRESENT	0
634915	633936	19701S	PARTICIPANT	\N	PRESENT	0
634927	633936	14026U	PARTICIPANT	\N	PRESENT	0
634929	633936	19711U	PARTICIPANT	\N	PRESENT	0
649302	649298	19679N	PARTICIPANT	\N	PRESENT	0
649303	649298	20130U	PARTICIPANT	\N	PRESENT	1
649304	649300	19679N	PARTICIPANT	\N	PRESENT	0
649305	649300	20130U	PARTICIPANT	\N	PRESENT	1
649306	649301	19679N	PARTICIPANT	\N	PRESENT	0
649307	649301	19697Q	PARTICIPANT	\N	PRESENT	1
649411	647962	19631V	PARTICIPANT	\N	EXCUSE	0
650024	650018	14237S	PARTICIPANT	\N	PRESENT	0
650025	650018	19503N	PARTICIPANT	\N	PRESENT	0
650026	650018	14107H	PARTICIPANT	\N	PRESENT	0
650027	650018	19349W	PARTICIPANT	\N	PRESENT	0
650028	650018	19768N	PARTICIPANT	\N	PRESENT	0
650029	650018	20058E	PARTICIPANT	\N	PRESENT	0
650030	650018	20138D	PARTICIPANT	\N	PRESENT	0
650110	649090	19545Y	PARTICIPANT	\N	PRESENT	1
650111	649090	14121F	PARTICIPANT	\N	PRESENT	1
650178	649157	14133K	PARTICIPANT	\N	PRESENT	1
650179	649157	20042V	PARTICIPANT	\N	PRESENT	0
650180	649157	14105F	PARTICIPANT	\N	PRESENT	0
650181	649157	14255U	PARTICIPANT	\N	PRESENT	0
650182	649157	04042C	PRESIDENT	0	PRESENT	0
650183	649157	14267Y	PARTICIPANT	\N	PRESENT	0
650184	649157	11027H	PARTICIPANT	\N	PRESENT	0
650185	649157	01024M	PARTICIPANT	\N	PRESENT	0
650198	649157	14249W	PARTICIPANT	\N	PRESENT	0
650199	649157	17023S	PARTICIPANT	\N	PRESENT	0
650200	649157	97011G	PARTICIPANT	\N	PRESENT	0
650201	649157	19347U	PARTICIPANT	\N	PRESENT	0
650202	649157	08056B	PARTICIPANT	\N	PRESENT	0
650203	649157	14211G	PARTICIPANT	\N	PRESENT	0
650204	649157	19565D	PARTICIPANT	\N	PRESENT	0
650205	649157	20072C	PARTICIPANT	\N	PRESENT	0
650209	649157	08069G	PARTICIPANT	\N	PRESENT	0
650210	649157	14097Y	PARTICIPANT	\N	PRESENT	0
650211	649157	95041E	PARTICIPANT	\N	PRESENT	0
650212	649157	12041X	PARTICIPANT	\N	PRESENT	0
650213	649157	16685X	PARTICIPANT	\N	PRESENT	0
650214	649157	14191V	PARTICIPANT	\N	PRESENT	0
650215	649157	08061X	PARTICIPANT	\N	PRESENT	0
650216	649157	08047A	PARTICIPANT	\N	PRESENT	0
650217	649157	14193X	PARTICIPANT	\N	PRESENT	0
650218	649157	19443T	PARTICIPANT	\N	PRESENT	0
650219	649157	19421M	PARTICIPANT	\N	PRESENT	0
650220	649157	01058X	PARTICIPANT	\N	PRESENT	0
650221	649157	19669L	PARTICIPANT	\N	PRESENT	0
650222	649157	01062T	PARTICIPANT	\N	PRESENT	0
650223	649157	20064C	PARTICIPANT	\N	PRESENT	0
650224	649157	11066Q	PARTICIPANT	\N	PRESENT	0
650840	649163	01028R	PARTICIPANT	\N	PRESENT	0
650841	649163	08069G	PARTICIPANT	\N	PRESENT	0
650842	649163	14259Y	PARTICIPANT	\N	PRESENT	0
650843	649163	19766L	PARTICIPANT	\N	PRESENT	0
650844	649163	01048V	PARTICIPANT	\N	PRESENT	0
650845	649163	20022R	PARTICIPANT	\N	PRESENT	0
650846	649163	04043D	PARTICIPANT	\N	PRESENT	0
650847	649163	11097X	PARTICIPANT	\N	PRESENT	0
650848	649163	95041E	PARTICIPANT	\N	PRESENT	0
650849	649163	20096L	PARTICIPANT	\N	PRESENT	0
650850	649163	14213J	PARTICIPANT	\N	PRESENT	0
650851	649163	17637T	PARTICIPANT	\N	PRESENT	0
650852	649163	14331P	PARTICIPANT	\N	PRESENT	0
650853	649158	12041X	PARTICIPANT	\N	PRESENT	0
650854	649158	19443T	PARTICIPANT	\N	PRESENT	0
650855	649158	19565D	PARTICIPANT	\N	PRESENT	0
650856	649158	20072C	PARTICIPANT	\N	PRESENT	0
650857	649158	01058X	PARTICIPANT	\N	PRESENT	0
650858	649158	16685X	PARTICIPANT	\N	PRESENT	0
650859	649158	11027H	PARTICIPANT	\N	PRESENT	0
650860	649158	04042C	PRESIDENT	0	PRESENT	0
650861	649158	11054L	PARTICIPANT	\N	PRESENT	0
650862	649158	11066Q	PARTICIPANT	\N	PRESENT	0
650863	649158	19669L	PARTICIPANT	\N	PRESENT	0
650864	649158	19421M	PARTICIPANT	\N	PRESENT	0
650865	649158	19347U	PARTICIPANT	\N	PRESENT	0
650866	649158	14193X	PARTICIPANT	\N	PRESENT	0
650867	649158	07033P	PARTICIPANT	\N	PRESENT	0
650868	649158	08061X	PARTICIPANT	\N	PRESENT	0
650869	649158	14249W	PARTICIPANT	\N	PRESENT	0
650870	649158	08047A	PARTICIPANT	\N	PRESENT	0
650871	649158	14097Y	PARTICIPANT	\N	PRESENT	0
650872	649158	04035D	PARTICIPANT	\N	PRESENT	0
650873	649158	01062T	PARTICIPANT	\N	PRESENT	0
650874	649158	14133K	PARTICIPANT	\N	PRESENT	1
650875	649158	11041F	PARTICIPANT	\N	PRESENT	0
650876	649158	20042V	PARTICIPANT	\N	PRESENT	0
650877	649158	01024M	PARTICIPANT	\N	PRESENT	0
650878	649158	20064C	PARTICIPANT	\N	PRESENT	0
650879	649158	14267Y	PARTICIPANT	\N	PRESENT	0
650880	649158	19583F	PARTICIPANT	\N	PRESENT	0
650881	649158	17023S	PARTICIPANT	\N	PRESENT	0
650948	649163	11067R	PARTICIPANT	\N	PRESENT	0
650883	649163	20032T	PARTICIPANT	\N	PRESENT	0
650884	649163	11065P	PARTICIPANT	\N	PRESENT	0
650908	647948	11109J	PARTICIPANT	\N	EXCUSE	0
650947	649158	14255U	PARTICIPANT	\N	PRESENT	0
650940	647949	20124W	PARTICIPANT	\N	PRESENT	1
650949	649163	19701S	PARTICIPANT	\N	PRESENT	0
650950	649163	11074Q	PARTICIPANT	\N	PRESENT	0
650951	649163	19739H	PARTICIPANT	\N	PRESENT	0
650952	649163	20180F	PARTICIPANT	\N	PRESENT	0
650953	649163	14073Q	PARTICIPANT	\N	PRESENT	0
650954	649163	19543W	PARTICIPANT	\N	PRESENT	0
650997	649163	14231L	PARTICIPANT	\N	PRESENT	0
651250	649065	14189C	PARTICIPANT	\N	EXCUSE	0
651251	649065	20104S	PARTICIPANT	\N	PRESENT	0
651252	649065	19701S	PARTICIPANT	\N	PRESENT	0
651253	649065	14357A	PARTICIPANT	\N	EXCUSE	0
651254	649065	20286Q	PARTICIPANT	\N	PRESENT	0
651255	649065	20128B	PARTICIPANT	\N	PRESENT	1
651256	649065	19333N	PARTICIPANT	\N	PRESENT	0
651257	649065	14073Q	PARTICIPANT	\N	PRESENT	0
651258	649065	11026G	PARTICIPANT	\N	PRESENT	0
651259	649065	14001X	PARTICIPANT	\N	PRESENT	0
651260	649065	04045F	PARTICIPANT	\N	PRESENT	1
651261	649065	10015M	PARTICIPANT	\N	PRESENT	1
651262	649065	14331P	PRESIDENT	0	PRESENT	0
651263	649065	19593H	PARTICIPANT	\N	PRESENT	0
651264	649065	14169X	PARTICIPANT	\N	PRESENT	0
651265	649065	04070G	PARTICIPANT	\N	PRESENT	0
651458	651457	19443T	PARTICIPANT	\N	PRESENT	0
651498	651293	19503N	PARTICIPANT	\N	EXCUSE	0
651499	651331	19503N	PARTICIPANT	\N	EXCUSE	0
651576	651575	04042C	PARTICIPANT	\N	PRESENT	0
651622	651618	19679N	PARTICIPANT	\N	PRESENT	0
651623	651617	19679N	PARTICIPANT	\N	PRESENT	0
651624	651619	19679N	PARTICIPANT	\N	PRESENT	0
651625	651620	19679N	PARTICIPANT	\N	PRESENT	0
651626	651620	11067R	PARTICIPANT	\N	PRESENT	0
651627	651620	14213J	PARTICIPANT	\N	PRESENT	1
651628	651620	19760E	PARTICIPANT	\N	PRESENT	1
651629	651621	19679N	PARTICIPANT	\N	PRESENT	0
651630	651621	11067R	PARTICIPANT	\N	PRESENT	0
651631	651621	20130U	PARTICIPANT	\N	PRESENT	0
652473	648009	14030Q	PRESIDENT	0	PRESENT	0
652474	648009	20024T	PARTICIPANT	\N	PRESENT	0
652475	648009	19715Y	PARTICIPANT	\N	PRESENT	0
652476	648009	20046A	PARTICIPANT	\N	PRESENT	0
652477	648009	14275Y	PARTICIPANT	\N	PRESENT	0
652478	648009	11045K	PARTICIPANT	\N	PRESENT	0
652479	648009	20034V	PARTICIPANT	\N	PRESENT	0
652480	648009	19866P	PARTICIPANT	\N	PRESENT	0
652481	648009	14109K	PARTICIPANT	\N	PRESENT	0
652482	648009	20066E	PARTICIPANT	\N	PRESENT	0
652483	648009	20098N	PARTICIPANT	\N	PRESENT	0
652484	648009	19599P	PARTICIPANT	\N	PRESENT	0
652485	648009	11031D	PARTICIPANT	\N	PRESENT	0
652486	648009	19693L	PARTICIPANT	\N	PRESENT	0
652487	648009	20056C	PARTICIPANT	\N	EXCUSE	0
652488	648009	20118Y	PARTICIPANT	\N	EXCUSE	0
652489	648009	19749K	PARTICIPANT	\N	PRESENT	0
652490	648009	20080C	PARTICIPANT	\N	PRESENT	0
652491	648009	19527W	PARTICIPANT	\N	PRESENT	0
652722	652721	14069U	PARTICIPANT	\N	PRESENT	0
652723	652721	14255U	PARTICIPANT	\N	PRESENT	0
652724	652721	14083S	PARTICIPANT	\N	PRESENT	0
652725	652721	14249W	PARTICIPANT	\N	PRESENT	0
652726	652721	20126Y	PARTICIPANT	\N	PRESENT	0
652728	652727	11053K	PARTICIPANT	\N	PRESENT	0
627926	627925	19747H	PARTICIPANT	\N	PRESENT	0
627927	627925	19693L	PARTICIPANT	\N	PRESENT	0
627928	627925	14097Y	PARTICIPANT	\N	PRESENT	0
627929	627925	20126Y	PARTICIPANT	\N	PRESENT	1
627930	627925	11077T	PARTICIPANT	\N	PRESENT	1
627931	627925	20050V	PARTICIPANT	\N	PRESENT	0
627932	627925	20082E	PRESIDENT	0	PRESENT	0
627934	627933	19747H	PARTICIPANT	\N	PRESENT	0
627935	627933	19693L	PARTICIPANT	\N	PRESENT	0
627936	627933	14097Y	PARTICIPANT	\N	PRESENT	0
627937	627933	20126Y	PARTICIPANT	\N	PRESENT	0
627938	627933	11077T	PARTICIPANT	\N	PRESENT	0
627939	627933	20050V	PARTICIPANT	\N	PRESENT	0
627940	627933	20082E	PRESIDENT	0	PRESENT	0
631642	631641	05008E	PARTICIPANT	\N	EXCUSE	0
631643	631641	20148F	PARTICIPANT	\N	PRESENT	1
631651	631650	19599P	PARTICIPANT	\N	PRESENT	0
631652	631650	19685L	PARTICIPANT	\N	PRESENT	0
631657	631656	14038Y	PARTICIPANT	\N	PRESENT	0
631658	631656	14257W	PARTICIPANT	\N	PRESENT	1
631659	631656	20128B	PARTICIPANT	\N	PRESENT	1
631660	631656	19798U	PARTICIPANT	\N	PRESENT	1
631661	631656	19723Y	PARTICIPANT	\N	PRESENT	1
631662	631656	14083S	PARTICIPANT	\N	PRESENT	0
631663	631656	19711U	PARTICIPANT	\N	PRESENT	1
631664	631656	11083R	PARTICIPANT	\N	PRESENT	0
631665	631656	20042V	PARTICIPANT	\N	PRESENT	1
631666	631656	14179A	PARTICIPANT	\N	PRESENT	1
633955	632204	19251M	PARTICIPANT	\N	PRESENT	0
634006	632461	19782L	PARTICIPANT	\N	EXCUSE	0
634007	632461	19565D	PARTICIPANT	\N	EXCUSE	0
634008	632461	19735D	PARTICIPANT	\N	EXCUSE	0
634009	632461	08010L	PARTICIPANT	\N	EXCUSE	0
634010	632461	19563B	PARTICIPANT	\N	EXCUSE	0
634011	632461	14229S	PARTICIPANT	\N	EXCUSE	0
634012	632461	20122U	PARTICIPANT	\N	EXCUSE	0
634027	632204	14030Q	PARTICIPANT	\N	EXCUSE	0
634028	632204	08060W	PARTICIPANT	\N	EXCUSE	0
634029	632204	14105F	PARTICIPANT	\N	EXCUSE	0
634030	632204	19369B	PARTICIPANT	\N	EXCUSE	0
634031	632204	20054A	PARTICIPANT	\N	EXCUSE	0
634969	634967	19735D	PARTICIPANT	\N	PRESENT	0
634970	634967	19723Y	PARTICIPANT	\N	PRESENT	0
634971	634967	01048V	PARTICIPANT	\N	EXCUSE	0
634972	634967	11067R	PARTICIPANT	\N	EXCUSE	0
634973	634967	04043D	PARTICIPANT	\N	PRESENT	0
634974	634967	01058X	PARTICIPANT	\N	PRESENT	0
635159	634459	19441R	PARTICIPANT	\N	PRESENT	0
635160	634459	19479G	PARTICIPANT	\N	PRESENT	0
635161	634459	14189C	PARTICIPANT	\N	PRESENT	0
635162	634459	20252E	PARTICIPANT	\N	PRESENT	0
635163	634459	19762G	PARTICIPANT	\N	PRESENT	0
635164	634650	01025N	PARTICIPANT	\N	PRESENT	0
635165	634650	11104D	PARTICIPANT	\N	PRESENT	0
635166	634650	01028R	PARTICIPANT	\N	PRESENT	0
635167	634459	11026G	PARTICIPANT	\N	PRESENT	0
635168	634459	11012A	PARTICIPANT	\N	PRESENT	0
635169	634459	07029T	PARTICIPANT	\N	EXCUSE	0
635170	634459	19671E	PARTICIPANT	\N	EXCUSE	0
635171	634650	19553Y	PARTICIPANT	\N	PRESENT	0
635172	634650	20104S	PARTICIPANT	\N	PRESENT	0
635173	634650	14031R	PARTICIPANT	\N	PRESENT	0
635174	634650	20032T	PARTICIPANT	\N	PRESENT	0
635175	634650	20042V	PARTICIPANT	\N	PRESENT	0
635176	634650	20100N	PARTICIPANT	\N	PRESENT	0
635177	634650	20180F	PARTICIPANT	\N	PRESENT	0
635178	634650	19713W	PARTICIPANT	\N	PRESENT	0
635179	634650	19413M	PARTICIPANT	\N	PRESENT	0
635182	634650	19565D	PARTICIPANT	\N	PRESENT	0
635191	634650	19621T	PARTICIPANT	\N	PRESENT	0
635192	634650	20142Y	PARTICIPANT	\N	PRESENT	0
635193	634650	19691J	PARTICIPANT	\N	PRESENT	0
635194	634650	20140W	PARTICIPANT	\N	PRESENT	0
635195	634650	97011G	PARTICIPANT	\N	PRESENT	0
635196	634650	20108W	PARTICIPANT	\N	PRESENT	0
635197	634650	20066E	PARTICIPANT	\N	PRESENT	0
635198	634650	20148F	PARTICIPANT	\N	PRESENT	0
635199	634650	19399H	PARTICIPANT	\N	PRESENT	0
635252	634651	20148F	PARTICIPANT	\N	PRESENT	0
635253	634651	20142Y	PARTICIPANT	\N	PRESENT	0
635254	634651	19758L	PARTICIPANT	\N	PRESENT	0
635255	634651	11104D	PARTICIPANT	\N	PRESENT	0
635256	634651	20082E	PARTICIPANT	\N	PRESENT	0
635257	634651	19631V	PARTICIPANT	\N	PRESENT	0
635258	634651	19553Y	PARTICIPANT	\N	PRESENT	0
635259	634651	20132W	PARTICIPANT	\N	PRESENT	0
635260	634651	19713W	PARTICIPANT	\N	PRESENT	0
635261	634651	01028R	PARTICIPANT	\N	PRESENT	0
635262	634651	01043Q	PARTICIPANT	\N	PRESENT	0
635263	634651	01024M	PARTICIPANT	\N	PRESENT	0
635264	634651	19611R	PARTICIPANT	\N	PRESENT	0
635265	634651	19651A	PARTICIPANT	\N	PRESENT	0
635266	634651	14215L	PARTICIPANT	\N	PRESENT	0
635267	634651	20066E	PARTICIPANT	\N	PRESENT	0
635268	634651	19367Y	PARTICIPANT	\N	PRESENT	0
635269	634651	20124W	PARTICIPANT	\N	PRESENT	0
635270	634651	20090E	PARTICIPANT	\N	PRESENT	0
635271	634651	20062A	PARTICIPANT	\N	PRESENT	0
635272	634651	97011G	PARTICIPANT	\N	PRESENT	0
635273	634651	19533U	PARTICIPANT	\N	PRESENT	0
635274	634651	20108W	PARTICIPANT	\N	PRESENT	0
635275	634651	19399H	PARTICIPANT	\N	PRESENT	0
635276	634651	20140W	PARTICIPANT	\N	PRESENT	0
635277	634651	18083K	PARTICIPANT	\N	PRESENT	0
635278	634651	20180F	PARTICIPANT	\N	PRESENT	0
635279	634651	19693L	PARTICIPANT	\N	PRESENT	0
635280	634651	20032T	PARTICIPANT	\N	PRESENT	0
635281	634651	19593H	PARTICIPANT	\N	PRESENT	0
635282	634651	19691J	PARTICIPANT	\N	PRESENT	0
635283	634651	19569H	PARTICIPANT	\N	PRESENT	0
635284	634651	14030Q	PARTICIPANT	\N	PRESENT	0
635285	634651	20172F	PARTICIPANT	\N	PRESENT	0
635286	634651	14229S	PARTICIPANT	\N	PRESENT	0
635287	634459	20070A	PARTICIPANT	\N	PRESENT	0
635288	634651	20054A	PARTICIPANT	\N	PRESENT	0
635289	634651	01048V	PARTICIPANT	\N	PRESENT	0
635290	634651	20058E	PARTICIPANT	\N	PRESENT	0
635293	634651	20026V	PARTICIPANT	\N	PRESENT	0
635294	634651	19563B	PARTICIPANT	\N	PRESENT	0
635295	634651	19760E	PARTICIPANT	\N	PRESENT	0
635296	634651	19735D	PARTICIPANT	\N	PRESENT	0
635297	634651	14223L	PARTICIPANT	\N	PRESENT	0
635298	634651	14089Y	PARTICIPANT	\N	PRESENT	0
635299	634651	20174H	PARTICIPANT	\N	PRESENT	0
635300	634651	19467C	PARTICIPANT	\N	PRESENT	0
637674	634662	11045K	PARTICIPANT	\N	PRESENT	0
637675	634662	14205J	PARTICIPANT	\N	PRESENT	0
637676	634662	19697Q	PARTICIPANT	\N	PRESENT	0
635250	634651	19719D	PARTICIPANT	\N	PRESENT	0
635251	634651	19621T	PARTICIPANT	\N	PRESENT	0
637677	634662	20128B	PARTICIPANT	\N	PRESENT	0
637678	634662	19715Y	PARTICIPANT	\N	PRESENT	0
637679	634662	20114U	PARTICIPANT	\N	PRESENT	0
637680	634662	20082E	PARTICIPANT	\N	PRESENT	0
637681	634662	20088L	PARTICIPANT	\N	PRESENT	0
637682	634662	20064C	PARTICIPANT	\N	PRESENT	0
637683	634662	20092G	PARTICIPANT	\N	PRESENT	0
637685	634662	19782L	PARTICIPANT	\N	PRESENT	0
637686	634662	20110Q	PARTICIPANT	\N	PRESENT	0
637687	634662	11064N	PARTICIPANT	\N	PRESENT	0
637689	634662	19577H	PARTICIPANT	\N	PRESENT	0
637690	634662	20248J	PARTICIPANT	\N	PRESENT	0
637691	634662	20152B	PARTICIPANT	\N	PRESENT	0
637692	634662	19711U	PARTICIPANT	\N	PRESENT	0
637693	634662	20032T	PARTICIPANT	\N	PRESENT	0
637694	634662	14033T	PARTICIPANT	\N	PRESENT	0
637695	634662	14026U	PARTICIPANT	\N	PRESENT	0
637696	634662	08015R	PARTICIPANT	\N	PRESENT	0
637697	634662	19507S	PARTICIPANT	\N	PRESENT	0
637698	634662	20286Q	PARTICIPANT	\N	PRESENT	0
637699	634662	20062A	PARTICIPANT	\N	PRESENT	0
637700	634662	19693L	PARTICIPANT	\N	PRESENT	0
637701	634662	14237S	PARTICIPANT	\N	PRESENT	0
637702	634662	19563B	PARTICIPANT	\N	PRESENT	0
638036	638014	95041E	PARTICIPANT	\N	PRESENT	0
638037	638014	12041X	PARTICIPANT	\N	PRESENT	0
638038	638014	19443T	PARTICIPANT	\N	PRESENT	0
638039	638014	19565D	PARTICIPANT	\N	PRESENT	0
627381	627379	19717B	PARTICIPANT	\N	EXCUSE	0
649079	649077	14259Y	PARTICIPANT	\N	PRESENT	0
649080	649077	04047H	PARTICIPANT	\N	PRESENT	0
649078	649077	14231L	PARTICIPANT	\N	PRESENT	0
649082	649081	04047H	PARTICIPANT	\N	PRESENT	0
649083	649081	14231L	PARTICIPANT	\N	PRESENT	0
649084	649081	14259Y	PARTICIPANT	\N	PRESENT	0
649086	649085	14205J	PARTICIPANT	\N	PRESENT	0
649087	649085	19745F	PARTICIPANT	\N	PRESENT	0
649088	649085	20092G	PARTICIPANT	\N	PRESENT	0
649675	649674	14231L	PARTICIPANT	\N	PRESENT	0
649676	649674	14259Y	PARTICIPANT	\N	PRESENT	0
652524	652464	20024T	PARTICIPANT	\N	PRESENT	0
652525	652464	08028W	PARTICIPANT	\N	EXCUSE	0
652526	652464	19782L	PARTICIPANT	\N	EXCUSE	0
652540	652461	14038Y	PARTICIPANT	\N	PRESENT	0
652541	652461	20030R	PARTICIPANT	\N	PRESENT	0
652542	652461	19467C	PARTICIPANT	\N	PRESENT	0
652543	652461	20034V	PARTICIPANT	\N	PRESENT	0
649073	649070	14179A	PARTICIPANT	\N	PRESENT	0
652544	652461	14357A	PARTICIPANT	\N	PRESENT	0
652545	652461	19695N	PARTICIPANT	\N	PRESENT	0
652546	652461	20082E	PARTICIPANT	\N	PRESENT	0
652547	652461	14033T	PARTICIPANT	\N	PRESENT	0
652548	652461	11090Q	PRESIDENT	0	PRESENT	0
652549	652461	20104S	PARTICIPANT	\N	PRESENT	0
652550	652461	19705W	PARTICIPANT	\N	PRESENT	0
652551	652461	19707Y	PARTICIPANT	\N	PRESENT	1
652552	652461	08015R	PARTICIPANT	\N	PRESENT	1
652553	652461	20286Q	PARTICIPANT	\N	PRESENT	0
652554	652461	19747H	PARTICIPANT	\N	PRESENT	0
652555	652461	14207L	PARTICIPANT	\N	PRESENT	0
652556	652461	14257W	PARTICIPANT	\N	PRESENT	0
652557	652461	14037X	PARTICIPANT	\N	PRESENT	0
652558	652461	20028X	PARTICIPANT	\N	PRESENT	0
653079	653077	14205J	PARTICIPANT	\N	PRESENT	0
652560	652461	19631V	PARTICIPANT	\N	PRESENT	1
653080	653077	20076G	PARTICIPANT	\N	PRESENT	0
653082	653081	20076G	PARTICIPANT	\N	PRESENT	0
653083	653081	14205J	PARTICIPANT	\N	PRESENT	0
653084	653081	19826F	PARTICIPANT	\N	PRESENT	0
653085	653081	20054A	PARTICIPANT	\N	PRESENT	0
653504	653503	07029T	PARTICIPANT	\N	PRESENT	0
653540	653089	11040E	PARTICIPANT	\N	PRESENT	0
653541	653089	19687N	PARTICIPANT	\N	PRESENT	0
653542	653089	11074Q	PARTICIPANT	\N	PRESENT	0
653543	653089	14225N	PRESIDENT	0	PRESENT	0
653544	653089	20036X	PARTICIPANT	\N	EXCUSE	0
653545	653089	20086J	PARTICIPANT	\N	PRESENT	0
653546	653089	11048N	PARTICIPANT	\N	PRESENT	0
653547	653089	19647E	PARTICIPANT	\N	PRESENT	0
653548	653089	19479G	PARTICIPANT	\N	PRESENT	0
653549	653089	19711U	PARTICIPANT	\N	PRESENT	0
652577	650991	20136B	PARTICIPANT	\N	PRESENT	0
653076	653072	19826F	PARTICIPANT	\N	PRESENT	0
653078	653077	19826F	PARTICIPANT	\N	PRESENT	0
653550	653089	08034U	PARTICIPANT	\N	PRESENT	0
653551	653089	20080C	PARTICIPANT	\N	PRESENT	0
653552	653089	20050V	PARTICIPANT	\N	PRESENT	0
653553	653089	19667J	PARTICIPANT	\N	PRESENT	0
653554	653089	20044X	PARTICIPANT	\N	PRESENT	0
653555	653089	19671E	PARTICIPANT	\N	PRESENT	0
653556	653089	20150Y	PARTICIPANT	\N	PRESENT	0
653557	653089	07029T	PARTICIPANT	\N	PRESENT	0
653558	653089	20252E	PARTICIPANT	\N	PRESENT	0
653559	653089	08009T	PARTICIPANT	\N	PRESENT	0
653560	653089	20070A	PARTICIPANT	\N	PRESENT	0
653561	653089	99004R	PARTICIPANT	\N	PRESENT	0
653562	653089	20914V	PARTICIPANT	\N	PRESENT	0
653563	653089	20126Y	PARTICIPANT	\N	PRESENT	0
653564	653089	19762G	PARTICIPANT	\N	PRESENT	0
653565	653089	19335Q	PARTICIPANT	\N	PRESENT	0
653566	653089	14083S	PARTICIPANT	\N	PRESENT	0
653567	653089	08010L	PARTICIPANT	\N	PRESENT	0
653570	652897	99004R	PARTICIPANT	\N	PRESENT	0
653571	652897	14225N	PARTICIPANT	\N	PRESENT	0
653572	652897	19525U	PARTICIPANT	\N	PRESENT	0
653573	652897	20252E	PARTICIPANT	\N	PRESENT	0
653574	652897	19762G	PARTICIPANT	\N	PRESENT	0
653575	652897	20034V	PARTICIPANT	\N	PRESENT	0
653576	652897	19671E	PARTICIPANT	\N	PRESENT	0
653577	652897	19479G	PARTICIPANT	\N	PRESENT	0
653578	652897	14111D	PARTICIPANT	\N	PRESENT	0
653579	652897	14033T	PARTICIPANT	\N	PRESENT	0
653580	652897	19782L	PARTICIPANT	\N	PRESENT	0
653581	652897	20062A	PARTICIPANT	\N	PRESENT	0
653582	652897	19399H	PARTICIPANT	\N	PRESENT	0
653583	652897	19766L	PARTICIPANT	\N	PRESENT	0
653584	652897	20044X	PARTICIPANT	\N	PRESENT	0
653585	652897	20298U	PARTICIPANT	\N	PRESENT	0
653586	652897	20150Y	PARTICIPANT	\N	PRESENT	0
653587	652897	20914V	PARTICIPANT	\N	PRESENT	0
653588	652897	11012A	PARTICIPANT	\N	PRESENT	0
653589	652897	20050V	PARTICIPANT	\N	PRESENT	0
653590	652897	08009T	PARTICIPANT	\N	PRESENT	0
653591	652897	20086J	PARTICIPANT	\N	PRESENT	0
653592	652897	19687N	PARTICIPANT	\N	PRESENT	0
653593	652897	19593H	PARTICIPANT	\N	PRESENT	0
653594	652897	19619A	PARTICIPANT	\N	PRESENT	0
653595	652897	19711U	PARTICIPANT	\N	PRESENT	0
653596	652897	19637C	PARTICIPANT	\N	PRESENT	0
653597	652897	12016W	PARTICIPANT	\N	PRESENT	0
653598	652897	14187A	PARTICIPANT	\N	PRESENT	0
653599	652897	20038A	PARTICIPANT	\N	PRESENT	0
653600	652897	20126Y	PARTICIPANT	\N	PRESENT	0
653601	652897	11040E	PARTICIPANT	\N	PRESENT	0
653602	652897	11074Q	PARTICIPANT	\N	PRESENT	0
653603	652897	20264J	PARTICIPANT	\N	PRESENT	0
653604	652897	19651A	PARTICIPANT	\N	PRESENT	0
653605	652897	11065P	PARTICIPANT	\N	PRESENT	0
653606	652897	20030R	PARTICIPANT	\N	PRESENT	0
653607	652897	20080C	PARTICIPANT	\N	PRESENT	0
653608	652897	14109K	PARTICIPANT	\N	PRESENT	0
653609	652897	20134Y	PARTICIPANT	\N	PRESENT	0
653610	652897	20070A	PARTICIPANT	\N	PRESENT	0
653611	652897	19647E	PARTICIPANT	\N	PRESENT	0
653612	652897	20024T	PARTICIPANT	\N	PRESENT	0
653613	652897	19301E	PARTICIPANT	\N	PRESENT	0
653614	652897	14069U	PARTICIPANT	\N	PRESENT	0
653615	652897	04033B	PARTICIPANT	\N	PRESENT	0
653616	652897	19413M	PARTICIPANT	\N	PRESENT	0
653617	652897	08034U	PARTICIPANT	\N	PRESENT	0
653618	652897	19649G	PARTICIPANT	\N	PRESENT	0
653619	652897	86034E	PARTICIPANT	\N	PRESENT	0
653620	652897	04059M	PARTICIPANT	\N	PRESENT	0
653621	652897	08061X	PARTICIPANT	\N	PRESENT	0
653622	652897	20054A	PARTICIPANT	\N	PRESENT	0
653623	652897	07004J	PARTICIPANT	\N	PRESENT	0
653624	652897	14255U	PARTICIPANT	\N	PRESENT	0
653625	652897	07029T	PARTICIPANT	\N	PRESENT	0
653626	652897	11033F	PARTICIPANT	\N	PRESENT	0
653627	652897	20092G	PARTICIPANT	\N	PRESENT	0
653628	652897	19611R	PARTICIPANT	\N	PRESENT	0
653629	652897	19543W	PARTICIPANT	\N	PRESENT	0
653630	652897	14083S	PARTICIPANT	\N	PRESENT	0
653631	652897	19335Q	PARTICIPANT	\N	PRESENT	0
653632	652897	04042C	PARTICIPANT	\N	PRESENT	0
653633	652897	04085P	PARTICIPANT	\N	PRESENT	0
653634	652897	19349W	PARTICIPANT	\N	PRESENT	0
653635	652897	19954N	PARTICIPANT	\N	PRESENT	0
653636	652897	19503N	PARTICIPANT	\N	PRESENT	0
653637	652897	11048N	PARTICIPANT	\N	PRESENT	0
653638	652897	20152B	PARTICIPANT	\N	PRESENT	0
653639	652897	14059S	PARTICIPANT	\N	PRESENT	0
653640	652897	20102Q	PARTICIPANT	\N	PRESENT	0
653641	652897	20136B	PARTICIPANT	\N	PRESENT	0
653642	652897	14191V	PARTICIPANT	\N	PRESENT	0
653643	652897	14257W	PARTICIPANT	\N	PRESENT	0
653644	652897	08010L	PARTICIPANT	\N	PRESENT	0
653645	652897	20100N	PARTICIPANT	\N	PRESENT	0
653648	652897	11026G	PARTICIPANT	\N	PRESENT	0
653650	652897	14151M	PARTICIPANT	\N	PRESENT	0
653651	652897	19820Y	PARTICIPANT	\N	PRESENT	0
653652	652897	08045X	PARTICIPANT	\N	PRESENT	0
653653	652897	04071H	PARTICIPANT	\N	PRESENT	0
653654	652897	12028B	PARTICIPANT	\N	PRESENT	0
653655	652897	19701S	PARTICIPANT	\N	PRESENT	0
653656	652897	11045K	PARTICIPANT	\N	PRESENT	0
653657	652897	20036X	PARTICIPANT	\N	PRESENT	0
653658	652897	19667J	PARTICIPANT	\N	PRESENT	0
653659	652897	20108W	PARTICIPANT	\N	PRESENT	0
634930	633936	19441R	PARTICIPANT	\N	PRESENT	0
634931	633936	14237S	PARTICIPANT	\N	PRESENT	0
634932	633936	14331P	PARTICIPANT	\N	PRESENT	0
634933	633936	10015M	PARTICIPANT	\N	PRESENT	0
634934	633936	04045F	PARTICIPANT	\N	PRESENT	1
634938	633936	14097Y	PARTICIPANT	\N	PRESENT	0
634941	633936	20128B	PARTICIPANT	\N	PRESENT	1
634981	633936	11056N	PRESIDENT	1	PRESENT	0
635339	635338	17367Q	PARTICIPANT	\N	PRESENT	0
635340	635338	20114U	PARTICIPANT	\N	PRESENT	0
635341	635338	19621T	PARTICIPANT	\N	PRESENT	0
635342	635338	14255U	PARTICIPANT	\N	PRESENT	0
635343	635338	04042C	PARTICIPANT	\N	PRESENT	0
635344	635338	20264J	PARTICIPANT	\N	PRESENT	0
635345	635338	11080N	PARTICIPANT	\N	PRESENT	0
635346	635338	20070A	PARTICIPANT	\N	PRESENT	0
635347	635338	19525U	PARTICIPANT	\N	PRESENT	0
635348	635338	19693L	PARTICIPANT	\N	PRESENT	0
635349	635338	14327T	PARTICIPANT	\N	PRESENT	0
635350	635338	17229F	PARTICIPANT	\N	PRESENT	0
635351	635338	20124W	PARTICIPANT	\N	PRESENT	0
635352	635338	07033P	PARTICIPANT	\N	PRESENT	0
635353	635338	14187A	PARTICIPANT	\N	PRESENT	0
635354	635338	14281W	PARTICIPANT	\N	PRESENT	0
635355	635338	14231L	PARTICIPANT	\N	PRESENT	0
635356	635338	19347U	PARTICIPANT	\N	PRESENT	0
635357	635338	14211G	PARTICIPANT	\N	PRESENT	0
635358	635338	19565D	PARTICIPANT	\N	PRESENT	0
635359	635338	14026U	PARTICIPANT	\N	PRESENT	0
635360	635338	01057W	PARTICIPANT	\N	PRESENT	0
635361	635338	99004R	PARTICIPANT	\N	PRESENT	0
635362	635338	14073Q	PARTICIPANT	\N	PRESENT	0
635363	635338	11026G	PARTICIPANT	\N	PRESENT	0
635364	635338	08010L	PARTICIPANT	\N	PRESENT	0
635365	635338	11085T	PARTICIPANT	\N	PRESENT	0
635366	635338	08009T	PARTICIPANT	\N	PRESENT	0
635367	635338	20018V	PARTICIPANT	\N	PRESENT	0
635368	635338	04070G	PARTICIPANT	\N	PRESENT	0
635370	635338	19443T	PARTICIPANT	\N	PRESENT	0
635371	635338	20064C	PARTICIPANT	\N	PRESENT	0
635372	635338	11041F	PARTICIPANT	\N	PRESENT	0
636187	636185	19543W	PARTICIPANT	\N	PRESENT	0
636189	636185	14151M	PARTICIPANT	\N	PRESENT	0
636192	634531	20042V	PARTICIPANT	\N	PRESENT	0
636193	634531	14105F	PARTICIPANT	\N	PRESENT	0
636194	634531	04042C	PARTICIPANT	\N	PRESENT	0
636195	634531	12028B	PARTICIPANT	\N	PRESENT	0
636196	634531	14267Y	PARTICIPANT	\N	PRESENT	0
636197	634531	01024M	PARTICIPANT	\N	PRESENT	0
636198	634531	07033P	PARTICIPANT	\N	PRESENT	0
636199	634531	14249W	PARTICIPANT	\N	PRESENT	0
636200	634531	17023S	PARTICIPANT	\N	PRESENT	0
636201	634531	97011G	PARTICIPANT	\N	PRESENT	0
636202	634531	11083R	PARTICIPANT	\N	PRESENT	0
636203	634531	19347U	PARTICIPANT	\N	PRESENT	0
636204	634531	08056B	PARTICIPANT	\N	EXCUSE	0
636205	634531	19565D	PARTICIPANT	\N	PRESENT	0
636206	634531	11064N	PARTICIPANT	\N	PRESENT	0
637775	635632	18083K	PARTICIPANT	\N	PRESENT	0
636208	634531	14097Y	PARTICIPANT	\N	PRESENT	0
636209	634531	12041X	PARTICIPANT	\N	PRESENT	0
636210	634531	19709B	PARTICIPANT	\N	PRESENT	0
636211	634531	16685X	PARTICIPANT	\N	PRESENT	0
636212	634531	08061X	PARTICIPANT	\N	PRESENT	0
636213	634531	08047A	PARTICIPANT	\N	PRESENT	0
636214	634531	14193X	PARTICIPANT	\N	PRESENT	0
636215	634531	19443T	PARTICIPANT	\N	PRESENT	0
636216	634531	11054L	PARTICIPANT	\N	PRESENT	0
636217	634531	19421M	PARTICIPANT	\N	PRESENT	0
636218	634531	01058X	PARTICIPANT	\N	PRESENT	0
636219	634531	01062T	PARTICIPANT	\N	PRESENT	0
636220	634531	11041F	PARTICIPANT	\N	PRESENT	1
636221	634531	11066Q	PARTICIPANT	\N	PRESENT	0
636222	634531	20072C	PARTICIPANT	\N	PRESENT	1
636223	634531	14059S	PARTICIPANT	\N	PRESENT	0
637773	635632	20032T	PARTICIPANT	\N	PRESENT	0
637774	635632	19549D	PARTICIPANT	\N	PRESENT	0
637776	635632	19701S	PARTICIPANT	\N	PRESENT	0
637777	635632	17229F	PARTICIPANT	\N	PRESENT	0
637778	635632	19251M	PARTICIPANT	\N	PRESENT	1
637779	635632	20038A	PARTICIPANT	\N	PRESENT	0
637780	635632	20100N	PARTICIPANT	\N	PRESENT	0
637781	635632	19820Y	PARTICIPANT	\N	PRESENT	1
637782	635632	20106U	PARTICIPANT	\N	PRESENT	1
637783	635632	19333N	PARTICIPANT	\N	PRESENT	0
637784	635632	20102Q	PARTICIPANT	\N	PRESENT	0
637785	635632	14219Q	PARTICIPANT	\N	PRESENT	0
637786	635632	14031R	PARTICIPANT	\N	PRESENT	0
637787	635632	14169X	PARTICIPANT	\N	PRESENT	0
637788	635632	14237S	PARTICIPANT	\N	PRESENT	0
637789	635632	19745F	PARTICIPANT	\N	PRESENT	0
637790	635632	19503N	PARTICIPANT	\N	PRESENT	0
637791	635632	20020P	PARTICIPANT	\N	PRESENT	0
637792	635632	19619A	PARTICIPANT	\N	PRESENT	0
637793	635632	20046A	PARTICIPANT	\N	PRESENT	1
637794	635632	14001X	PARTICIPANT	\N	PRESENT	0
637795	635632	08034U	PARTICIPANT	\N	PRESENT	0
637796	635632	14097Y	PARTICIPANT	\N	PRESENT	0
637797	635632	14073Q	PARTICIPANT	\N	PRESENT	0
637798	635632	11101A	PARTICIPANT	\N	PRESENT	0
637799	635632	19711U	PARTICIPANT	\N	PRESENT	0
637800	635632	11026G	PARTICIPANT	\N	PRESENT	0
637801	635632	10015M	PARTICIPANT	\N	PRESENT	0
637802	635632	19531S	PARTICIPANT	\N	PRESENT	0
637803	635632	14026U	PARTICIPANT	\N	PRESENT	0
637804	635632	14331P	PARTICIPANT	\N	PRESENT	0
637805	635632	20128B	PARTICIPANT	\N	PRESENT	1
638466	638465	19629C	PARTICIPANT	\N	PRESENT	0
638467	638465	19549D	PARTICIPANT	\N	PRESENT	0
638468	638465	20120S	PARTICIPANT	\N	PRESENT	0
638469	638465	04045F	PARTICIPANT	\N	PRESENT	0
638471	638470	08010L	PARTICIPANT	\N	PRESENT	0
638810	637992	19533U	PRESIDENT	0	PRESENT	0
638811	637992	19693L	PARTICIPANT	\N	PRESENT	0
638812	637992	20124W	PARTICIPANT	\N	PRESENT	0
638813	637992	20128B	PARTICIPANT	\N	PRESENT	0
639166	639165	19643A	PARTICIPANT	\N	PRESENT	1
639167	639165	11053K	PARTICIPANT	\N	PRESENT	0
639168	639165	20248J	PARTICIPANT	\N	PRESENT	0
639169	639165	14151M	PARTICIPANT	\N	PRESENT	1
639170	639165	20120S	PARTICIPANT	\N	PRESENT	0
639171	639165	20056C	PARTICIPANT	\N	PRESENT	0
639172	639165	08010L	PARTICIPANT	\N	PRESENT	0
639173	639165	19479G	PARTICIPANT	\N	PRESENT	1
639174	639165	14257W	PARTICIPANT	\N	PRESENT	1
639175	639165	19515S	PARTICIPANT	\N	PRESENT	0
639176	639165	20094J	PARTICIPANT	\N	PRESENT	0
639177	639165	19671E	PARTICIPANT	\N	PRESENT	1
639178	639165	19762G	PARTICIPANT	\N	PRESENT	0
639179	639165	20054A	PARTICIPANT	\N	PRESENT	1
639339	639338	11033F	PARTICIPANT	\N	PRESENT	0
639340	639338	14151M	PARTICIPANT	\N	PRESENT	0
639342	639341	04047H	PARTICIPANT	\N	PRESENT	0
639483	639482	20032T	PARTICIPANT	\N	PRESENT	0
639484	639482	20076G	PARTICIPANT	\N	PRESENT	0
639489	639482	20100N	PARTICIPANT	\N	PRESENT	0
639486	639482	19549D	PARTICIPANT	\N	PRESENT	0
639487	639482	18083K	PARTICIPANT	\N	PRESENT	0
639488	639482	17229F	PARTICIPANT	\N	PRESENT	0
639490	639482	19599P	PARTICIPANT	\N	PRESENT	0
639491	639482	20120S	PARTICIPANT	\N	PRESENT	0
639492	639482	19820Y	PARTICIPANT	\N	PRESENT	0
639493	639482	20068G	PARTICIPANT	\N	PRESENT	0
639494	639482	19685L	PARTICIPANT	\N	PRESENT	0
639495	639482	19333N	PARTICIPANT	\N	PRESENT	0
639496	639482	20102Q	PARTICIPANT	\N	PRESENT	0
639497	639482	14219Q	PRESIDENT	0	PRESENT	0
639498	639482	14031R	PARTICIPANT	\N	PRESENT	0
639499	639482	19745F	PARTICIPANT	\N	PRESENT	0
639500	639482	20118Y	PARTICIPANT	\N	PRESENT	0
639501	639482	19503N	PARTICIPANT	\N	PRESENT	0
639502	639482	19619A	PARTICIPANT	\N	PRESENT	0
640134	639969	14207L	PARTICIPANT	\N	PRESENT	0
640135	639969	19533U	PARTICIPANT	\N	PRESENT	0
640178	640177	19333N	PARTICIPANT	\N	PRESENT	0
640179	640177	14030Q	PARTICIPANT	\N	PRESENT	0
640180	640177	14083S	PARTICIPANT	\N	PRESENT	0
640181	640177	20106U	PARTICIPANT	\N	PRESENT	0
640182	640177	20062A	PARTICIPANT	\N	PRESENT	0
640183	640177	20180F	PARTICIPANT	\N	PRESENT	0
640184	640177	20104S	PARTICIPANT	\N	PRESENT	0
651379	649165	19741B	PARTICIPANT	\N	PRESENT	0
651380	651305	14038Y	PARTICIPANT	\N	PRESENT	0
651381	651305	19467C	PARTICIPANT	\N	PRESENT	0
651382	651305	20082E	PARTICIPANT	\N	PRESENT	0
651383	651305	14033T	PARTICIPANT	\N	PRESENT	0
651384	651305	04045F	PARTICIPANT	\N	PRESENT	0
651385	651305	20104S	PARTICIPANT	\N	PRESENT	0
651386	651305	14205J	PARTICIPANT	\N	PRESENT	0
651387	651305	20060X	PARTICIPANT	\N	PRESENT	0
651388	651305	20286Q	PARTICIPANT	\N	PRESENT	0
651389	651305	19575F	PARTICIPANT	\N	PRESENT	0
651390	651305	14207L	PARTICIPANT	\N	PRESENT	0
651391	651305	19747H	PARTICIPANT	\N	PRESENT	0
651392	651305	14257W	PARTICIPANT	\N	PRESENT	0
651393	649165	14179A	PARTICIPANT	\N	PRESENT	0
651394	649165	20266L	PARTICIPANT	\N	PRESENT	0
651395	649165	14033T	PARTICIPANT	\N	PRESENT	0
651396	649165	01024M	PARTICIPANT	\N	PRESENT	0
651399	649165	14255U	PARTICIPANT	\N	PRESENT	0
651400	649165	19669L	PARTICIPANT	\N	PRESENT	0
651401	649165	20104S	PARTICIPANT	\N	PRESENT	0
651402	649165	20118Y	PARTICIPANT	\N	PRESENT	0
651408	649165	20062A	PARTICIPANT	\N	PRESENT	0
651416	649165	14191V	PARTICIPANT	\N	PRESENT	0
651420	649165	19747H	PARTICIPANT	\N	PRESENT	0
651422	649165	14038Y	PARTICIPANT	\N	PRESENT	0
651423	649165	14053L	PARTICIPANT	\N	PRESENT	0
651441	649165	14231L	PARTICIPANT	\N	PRESENT	0
651453	649165	19333N	PARTICIPANT	\N	PRESENT	0
651454	649165	14147R	PARTICIPANT	\N	PRESENT	0
651455	649165	14169X	PARTICIPANT	\N	PRESENT	0
651456	649165	11033F	PARTICIPANT	\N	PRESENT	0
651459	649165	14259Y	PARTICIPANT	\N	PRESENT	0
651460	649165	19413M	PARTICIPANT	\N	PRESENT	0
651462	651461	11048N	PARTICIPANT	\N	PRESENT	0
651463	651461	19711U	PARTICIPANT	\N	PRESENT	0
651465	651464	19711U	PARTICIPANT	\N	PRESENT	0
651467	651466	19711U	PARTICIPANT	\N	PRESENT	0
651469	651468	11048N	PARTICIPANT	\N	PRESENT	0
651470	651468	19711U	PARTICIPANT	\N	PRESENT	0
651472	651471	19711U	PARTICIPANT	\N	PRESENT	0
651473	651471	11048N	PARTICIPANT	\N	PRESENT	0
651474	645759	20024T	PARTICIPANT	\N	PRESENT	0
651475	645759	20116W	PARTICIPANT	\N	PRESENT	0
651476	645759	14083S	PARTICIPANT	\N	PRESENT	0
651477	645759	11053K	PARTICIPANT	\N	PRESENT	0
651478	645759	17229F	PARTICIPANT	\N	PRESENT	0
651479	645759	19251M	PARTICIPANT	\N	PRESENT	0
651480	645759	19333N	PARTICIPANT	\N	PRESENT	0
651481	645759	20056C	PARTICIPANT	\N	PRESENT	0
651482	645759	19735D	PARTICIPANT	\N	PRESENT	0
651483	645759	19611R	PARTICIPANT	\N	PRESENT	0
651484	645759	20052X	PARTICIPANT	\N	PRESENT	0
651485	645759	11077T	PARTICIPANT	\N	PRESENT	1
651486	645759	19671E	PARTICIPANT	\N	PRESENT	0
651487	645759	14169X	PARTICIPANT	\N	PRESENT	0
651488	645759	19745F	PARTICIPANT	\N	PRESENT	0
651489	645759	19739H	PARTICIPANT	\N	PRESENT	0
651490	645759	19349W	PARTICIPANT	\N	PRESENT	0
651491	645759	11097X	PARTICIPANT	\N	PRESENT	0
651493	651492	19711U	PARTICIPANT	\N	PRESENT	0
651494	651492	11048N	PARTICIPANT	\N	PRESENT	0
651496	651495	19711U	PARTICIPANT	\N	PRESENT	0
651497	651495	11048N	PARTICIPANT	\N	PRESENT	0
651526	651525	19711U	PARTICIPANT	\N	PRESENT	0
651527	651525	11048N	PARTICIPANT	\N	PRESENT	0
652423	651588	19739H	PARTICIPANT	\N	PRESENT	0
652424	651588	19745F	PARTICIPANT	\N	PRESENT	0
652425	651588	20114U	PARTICIPANT	\N	PRESENT	0
652426	651588	20048C	PARTICIPANT	\N	PRESENT	0
652427	651588	20264J	PARTICIPANT	\N	PRESENT	0
652428	651588	19251M	PARTICIPANT	\N	PRESENT	0
652429	651588	11110B	PARTICIPANT	\N	PRESENT	0
652430	651588	20042V	PARTICIPANT	\N	PRESENT	0
652431	651588	16685X	PARTICIPANT	\N	PRESENT	0
652432	651588	14121F	PARTICIPANT	\N	PRESENT	0
652433	651588	19531S	PARTICIPANT	\N	PRESENT	0
652434	651588	11026G	PARTICIPANT	\N	PRESENT	0
652435	651588	08012N	PARTICIPANT	\N	PRESENT	0
652436	651588	20144B	PARTICIPANT	\N	PRESENT	0
652437	651588	20094J	PARTICIPANT	\N	PRESENT	0
652438	651588	20018V	PARTICIPANT	\N	PRESENT	0
652439	651588	01024M	PARTICIPANT	\N	PRESENT	0
652440	651588	20030R	PARTICIPANT	\N	PRESENT	0
652441	651588	14030Q	PARTICIPANT	\N	PRESENT	0
652442	651588	17965H	PARTICIPANT	\N	PRESENT	0
652443	651588	19369B	PARTICIPANT	\N	PRESENT	0
652444	651588	20082E	PARTICIPANT	\N	PRESENT	0
652445	651588	20298U	PARTICIPANT	\N	PRESENT	0
652446	651588	19413M	PARTICIPANT	\N	PRESENT	0
652447	651588	20064C	PARTICIPANT	\N	PRESENT	0
652448	651588	14179A	PARTICIPANT	\N	PRESENT	0
652449	651588	14327T	PARTICIPANT	\N	PRESENT	0
652450	651588	14231L	PARTICIPANT	\N	PRESENT	0
652451	651588	14083S	PARTICIPANT	\N	PRESENT	0
652452	651588	17229F	PARTICIPANT	\N	PRESENT	0
652453	651588	20248J	PARTICIPANT	\N	PRESENT	0
652454	651588	20286Q	PARTICIPANT	\N	PRESENT	0
652455	651588	14205J	PARTICIPANT	\N	PRESENT	0
652456	651588	14217N	PARTICIPANT	\N	PRESENT	0
652457	651588	19565D	PARTICIPANT	\N	PRESENT	0
652458	651588	11077T	PARTICIPANT	\N	PRESENT	0
652459	651588	20096L	PARTICIPANT	\N	PRESENT	0
652460	651588	19701S	PARTICIPANT	\N	PRESENT	0
652462	651588	19057M	PARTICIPANT	\N	PRESENT	0
652463	651588	20016T	PARTICIPANT	\N	PRESENT	0
652493	652464	19383Y	PARTICIPANT	\N	PRESENT	0
652494	652464	19768N	PARTICIPANT	\N	PRESENT	0
652495	652464	20092G	PARTICIPANT	\N	PRESENT	0
652496	652464	14357A	PARTICIPANT	\N	PRESENT	0
652497	652464	20078J	PARTICIPANT	\N	PRESENT	0
652498	652464	19413M	PARTICIPANT	\N	PRESENT	0
652499	652464	20082E	PARTICIPANT	\N	PRESENT	0
652500	652464	20094J	PARTICIPANT	\N	PRESENT	0
652501	652464	19631V	PARTICIPANT	\N	PRESENT	0
652502	652464	20104S	PARTICIPANT	\N	PRESENT	0
652503	652464	19705W	PARTICIPANT	\N	PRESENT	0
652504	652464	19707Y	PARTICIPANT	\N	PRESENT	1
652505	652464	08015R	PARTICIPANT	\N	PRESENT	0
652506	652464	19575F	PARTICIPANT	\N	PRESENT	0
652507	652464	19369B	PARTICIPANT	\N	PRESENT	0
652508	652464	20018V	PARTICIPANT	\N	PRESENT	0
652509	652464	19563B	PARTICIPANT	\N	PRESENT	0
652510	652464	20028X	PARTICIPANT	\N	PRESENT	0
652511	652464	14038Y	PARTICIPANT	\N	PRESENT	0
652512	652464	20030R	PARTICIPANT	\N	PRESENT	1
652513	652464	19467C	PARTICIPANT	\N	PRESENT	0
652514	652464	20144B	PARTICIPANT	\N	PRESENT	0
652515	652464	19695N	PARTICIPANT	\N	PRESENT	0
652516	652464	11090Q	PRESIDENT	0	PRESENT	0
652517	652464	14033T	PARTICIPANT	\N	PRESENT	0
652518	652464	14205J	PARTICIPANT	\N	PRESENT	0
652519	652464	20060X	PARTICIPANT	\N	PRESENT	0
652520	652464	20286Q	PARTICIPANT	\N	PRESENT	0
652521	652464	14207L	PARTICIPANT	\N	PRESENT	0
652522	652464	19747H	PARTICIPANT	\N	PRESENT	0
652523	652464	14257W	PARTICIPANT	\N	PRESENT	0
652757	652714	11031D	PARTICIPANT	\N	PRESENT	0
652758	652714	18193Q	PARTICIPANT	\N	PRESENT	0
652760	652714	17965H	PARTICIPANT	\N	PRESENT	0
652762	652714	10006L	PRESIDENT	0	PRESENT	0
652763	652714	14042U	PARTICIPANT	\N	PRESENT	0
652764	652714	19569H	PARTICIPANT	\N	PRESENT	0
652765	652714	20090E	PARTICIPANT	\N	PRESENT	0
652766	652714	19663E	PARTICIPANT	\N	PRESENT	0
652769	652714	19760E	PARTICIPANT	\N	PRESENT	0
652770	652714	19553Y	PARTICIPANT	\N	PRESENT	1
652771	652714	01034P	PARTICIPANT	\N	PRESENT	0
652772	652714	19591F	PARTICIPANT	\N	PRESENT	0
652773	652714	19679N	PARTICIPANT	\N	PRESENT	0
652776	652714	11097X	PARTICIPANT	\N	PRESENT	0
652777	652714	14071N	PARTICIPANT	\N	PRESENT	0
653056	653055	12041X	PARTICIPANT	\N	PRESENT	0
653057	653055	10015M	PARTICIPANT	\N	PRESENT	0
653058	653055	11083R	PARTICIPANT	\N	PRESENT	0
653905	653904	19725B	PARTICIPANT	\N	PRESENT	0
653906	653904	19447X	PARTICIPANT	\N	PRESENT	0
653907	653904	20132W	PARTICIPANT	\N	PRESENT	0
653912	653908	19629C	PARTICIPANT	\N	PRESENT	0
653913	653908	14215L	PARTICIPANT	\N	PRESENT	0
653923	653921	19629C	PARTICIPANT	\N	PRESENT	0
636617	626899	14231L	PRESIDENT	0	PRESENT	0
636620	626899	14215L	PARTICIPANT	\N	PRESENT	0
636621	626899	14053L	PARTICIPANT	\N	PRESENT	0
636622	626899	14327T	PARTICIPANT	\N	PRESENT	0
636623	626899	19447X	PARTICIPANT	\N	PRESENT	0
636624	626899	14069U	PARTICIPANT	\N	PRESENT	0
636625	626899	20090E	PARTICIPANT	\N	PRESENT	0
636626	626899	20022R	PARTICIPANT	\N	PRESENT	0
636627	626899	14281W	PARTICIPANT	\N	PRESENT	0
636628	626899	05012A	PARTICIPANT	\N	PRESENT	0
636629	626899	08010L	PARTICIPANT	\N	PRESENT	0
636630	626899	04045F	PARTICIPANT	\N	PRESENT	0
636631	626899	19349W	PARTICIPANT	\N	PRESENT	0
636632	626899	20058E	PARTICIPANT	\N	PRESENT	0
636633	626899	20120S	PARTICIPANT	\N	PRESENT	0
636634	626899	20070A	PARTICIPANT	\N	PRESENT	0
636635	626899	20110Q	PARTICIPANT	\N	PRESENT	0
636637	626899	19782L	PARTICIPANT	\N	PRESENT	0
636638	626899	19758L	PARTICIPANT	\N	PRESENT	0
636639	626899	19565D	PARTICIPANT	\N	EXCUSE	0
636641	626899	19826F	PARTICIPANT	\N	EXCUSE	0
636642	626899	20084G	PARTICIPANT	\N	EXCUSE	0
636643	626899	19820Y	PARTICIPANT	\N	PRESENT	0
636646	626899	14147R	PARTICIPANT	\N	PRESENT	0
636647	626899	19954N	PARTICIPANT	\N	PRESENT	0
638071	638070	08018U	PARTICIPANT	\N	PRESENT	0
638072	638070	14097Y	PARTICIPANT	\N	PRESENT	0
638089	638088	19387D	PARTICIPANT	\N	PRESENT	0
638090	638088	19553Y	PARTICIPANT	\N	PRESENT	0
638091	638088	14097Y	PARTICIPANT	\N	PRESENT	0
638092	638088	14107H	PARTICIPANT	\N	PRESENT	1
638093	638088	20064C	PARTICIPANT	\N	PRESENT	0
638094	638088	19629C	PARTICIPANT	\N	PRESENT	0
638040	638014	19329S	PARTICIPANT	\N	PRESENT	0
638041	638014	01058X	PARTICIPANT	\N	PRESENT	0
638042	638014	16685X	PARTICIPANT	\N	PRESENT	0
638043	638014	04042C	PRESIDENT	0	PRESENT	0
638044	638014	11054L	PARTICIPANT	\N	PRESENT	0
638045	638014	19669L	PARTICIPANT	\N	PRESENT	0
638046	638014	11066Q	PARTICIPANT	\N	PRESENT	0
638047	638014	08056B	PARTICIPANT	\N	PRESENT	0
638048	638014	19421M	PARTICIPANT	\N	PRESENT	0
638049	638014	19709B	PARTICIPANT	\N	PRESENT	0
638050	638014	14193X	PARTICIPANT	\N	PRESENT	0
638051	638014	19347U	PARTICIPANT	\N	PRESENT	0
638052	638014	07033P	PARTICIPANT	\N	PRESENT	0
638053	638014	08061X	PARTICIPANT	\N	PRESENT	0
638054	638014	14249W	PARTICIPANT	\N	PRESENT	0
638055	638014	14059S	PARTICIPANT	\N	PRESENT	0
638056	638014	14133K	PARTICIPANT	\N	PRESENT	0
638057	638014	01062T	PARTICIPANT	\N	PRESENT	0
638058	638014	01024M	PARTICIPANT	\N	PRESENT	0
638059	638014	14105F	PARTICIPANT	\N	PRESENT	0
638060	638014	20064C	PARTICIPANT	\N	PRESENT	0
638061	638014	14267Y	PARTICIPANT	\N	PRESENT	0
638062	638014	11064N	PARTICIPANT	\N	PRESENT	0
638063	638014	14211G	PARTICIPANT	\N	PRESENT	0
638066	638014	14097Y	PARTICIPANT	\N	PRESENT	0
638096	638088	19713W	PARTICIPANT	\N	PRESENT	0
638098	638097	19629C	PARTICIPANT	\N	PRESENT	0
638099	638097	19387D	PARTICIPANT	\N	PRESENT	0
638100	638097	19553Y	PARTICIPANT	\N	PRESENT	0
638101	638097	14097Y	PARTICIPANT	\N	PRESENT	0
638102	638097	20064C	PARTICIPANT	\N	PRESENT	0
638103	638097	19713W	PARTICIPANT	\N	PRESENT	0
638104	637893	86034E	PARTICIPANT	\N	PRESENT	0
638105	637893	19413M	PARTICIPANT	\N	PRESENT	0
638106	637893	19569H	PARTICIPANT	\N	PRESENT	0
638107	637893	19479G	PARTICIPANT	\N	PRESENT	0
638108	637893	14033T	PARTICIPANT	\N	PRESENT	0
638109	637893	18083K	PARTICIPANT	\N	PRESENT	0
638110	637893	14217N	PARTICIPANT	\N	PRESENT	0
638111	637893	14053L	PARTICIPANT	\N	PRESENT	0
638112	637893	19826F	PARTICIPANT	\N	PRESENT	0
638113	637893	01048V	PARTICIPANT	\N	PRESENT	0
638114	637893	14189C	PARTICIPANT	\N	PRESENT	0
638115	637893	19745F	PARTICIPANT	\N	PRESENT	0
638116	637893	11010L	PARTICIPANT	\N	PRESENT	0
638117	637893	14231L	PARTICIPANT	\N	PRESENT	0
638118	637893	14030Q	PARTICIPANT	\N	PRESENT	0
638119	637893	20072C	PARTICIPANT	\N	PRESENT	0
638120	637893	20056C	PARTICIPANT	\N	PRESENT	0
638121	637893	19820Y	PARTICIPANT	\N	PRESENT	0
638122	637893	19563B	PARTICIPANT	\N	PRESENT	0
638123	637893	92040Q	PARTICIPANT	\N	PRESENT	0
638124	637893	07029T	PARTICIPANT	\N	PRESENT	0
638125	637893	08047A	PARTICIPANT	\N	PRESENT	0
638126	637893	14207L	PARTICIPANT	\N	PRESENT	0
638127	637893	11012A	PARTICIPANT	\N	PRESENT	0
638128	637893	11066Q	PARTICIPANT	\N	PRESENT	0
638129	637893	14281W	PARTICIPANT	\N	PRESENT	0
638130	637893	19715Y	PARTICIPANT	\N	PRESENT	0
638131	637893	14097Y	PARTICIPANT	\N	PRESENT	0
638132	637893	20088L	PARTICIPANT	\N	PRESENT	0
638133	637893	20028X	PARTICIPANT	\N	PRESENT	0
638134	637893	20068G	PARTICIPANT	\N	PRESENT	0
638135	637893	19766L	PARTICIPANT	\N	PRESENT	0
638136	637893	20128B	PARTICIPANT	\N	PRESENT	0
638137	637893	19747H	PARTICIPANT	\N	PRESENT	0
638138	637893	19553Y	PARTICIPANT	\N	PRESENT	0
638139	637893	14121F	PARTICIPANT	\N	PRESENT	0
638140	637893	19631V	PARTICIPANT	\N	PRESENT	0
638141	637893	11110B	PARTICIPANT	\N	PRESENT	0
638142	637893	20080C	PARTICIPANT	\N	PRESENT	0
638143	637893	20064C	PARTICIPANT	\N	PRESENT	0
638144	637893	08015R	PARTICIPANT	\N	PRESENT	0
638145	637893	04085P	PARTICIPANT	\N	PRESENT	0
638146	637893	19649G	PARTICIPANT	\N	PRESENT	0
638147	637893	19503N	PARTICIPANT	\N	PRESENT	0
638148	637893	20092G	PARTICIPANT	\N	PRESENT	0
638149	637893	20074E	PARTICIPANT	\N	PRESENT	0
638150	637893	19515S	PARTICIPANT	\N	PRESENT	0
638151	637893	19758L	PARTICIPANT	\N	PRESENT	0
638152	637893	01057W	PARTICIPANT	\N	PRESENT	0
638153	637893	19687N	PARTICIPANT	\N	PRESENT	0
638154	637893	11067R	PARTICIPANT	\N	PRESENT	0
638155	637893	05012A	PARTICIPANT	\N	PRESENT	0
638156	637893	19695N	PARTICIPANT	\N	PRESENT	0
638157	637893	01058X	PARTICIPANT	\N	PRESENT	0
638158	637893	14211G	PARTICIPANT	\N	PRESENT	0
638159	637893	17637T	PARTICIPANT	\N	PRESENT	0
638160	637893	08010L	PARTICIPANT	\N	PRESENT	0
638161	637893	04047H	PARTICIPANT	\N	PRESENT	0
638162	637893	14026U	PARTICIPANT	\N	PRESENT	0
638163	637893	04071H	PARTICIPANT	\N	PRESENT	0
638164	637893	14169X	PARTICIPANT	\N	PRESENT	0
638165	637893	14133K	PARTICIPANT	\N	PRESENT	0
638166	637893	04092N	PARTICIPANT	\N	PRESENT	0
638167	637893	11048N	PARTICIPANT	\N	PRESENT	0
638168	637893	20078J	PARTICIPANT	\N	PRESENT	0
638169	637893	20076G	PARTICIPANT	\N	PRESENT	0
638170	637893	11043H	PARTICIPANT	\N	PRESENT	0
638171	637893	04033B	PARTICIPANT	\N	PRESENT	0
638172	637893	14187A	PARTICIPANT	\N	PRESENT	0
638173	637893	11077T	PARTICIPANT	\N	PRESENT	0
638174	637893	05008E	PARTICIPANT	\N	PRESENT	0
638175	637893	20102Q	PARTICIPANT	\N	PRESENT	0
638176	637893	11097X	PARTICIPANT	\N	PRESENT	0
638177	637893	14215L	PARTICIPANT	\N	PRESENT	0
638178	637893	01028R	PARTICIPANT	\N	PRESENT	0
638179	637893	19701S	PARTICIPANT	\N	PRESENT	0
638180	637893	14225N	PARTICIPANT	\N	PRESENT	0
638181	637893	19443T	PARTICIPANT	\N	PRESENT	0
638182	637893	04043D	PARTICIPANT	\N	PRESENT	0
638183	637893	04059M	PARTICIPANT	\N	PRESENT	0
638184	637893	14021P	PARTICIPANT	\N	PRESENT	0
638185	637893	20022R	PARTICIPANT	\N	PRESENT	0
638186	637893	19647E	PARTICIPANT	\N	PRESENT	0
638187	637893	19333N	PARTICIPANT	\N	PRESENT	0
638197	637893	20060X	PARTICIPANT	\N	PRESENT	0
638189	637893	01062T	PARTICIPANT	\N	PRESENT	0
638190	637893	19549D	PARTICIPANT	\N	PRESENT	0
638191	637893	11054L	PARTICIPANT	\N	PRESENT	0
638192	637893	20018V	PARTICIPANT	\N	PRESENT	0
638193	637893	19669L	PARTICIPANT	\N	PRESENT	0
638194	637893	20082E	PARTICIPANT	\N	PRESENT	0
638195	637893	12028B	PARTICIPANT	\N	PRESENT	0
638196	637893	11090Q	PARTICIPANT	\N	PRESENT	0
638198	637893	19673G	PARTICIPANT	\N	PRESENT	0
638199	637893	19667J	PARTICIPANT	\N	PRESENT	0
638200	637893	14031R	PARTICIPANT	\N	PRESENT	0
652750	652747	14053L	PARTICIPANT	\N	PRESENT	0
652751	652747	11066Q	PARTICIPANT	\N	PRESENT	0
652894	650987	19711U	PARTICIPANT	\N	PRESENT	0
652895	651590	04042C	PARTICIPANT	\N	PRESENT	0
652896	650987	19667J	PARTICIPANT	\N	PRESENT	0
652900	650959	20248J	PARTICIPANT	\N	PRESENT	1
652901	650959	19798U	PARTICIPANT	\N	PRESENT	1
652902	650959	19715Y	PARTICIPANT	\N	PRESENT	1
652905	651590	12016W	PARTICIPANT	\N	PRESENT	0
652911	651590	11010L	PARTICIPANT	\N	PRESENT	0
652912	651590	11056N	PARTICIPANT	\N	PRESENT	0
652917	651590	19643A	PARTICIPANT	\N	PRESENT	0
652918	651590	19697Q	PARTICIPANT	\N	PRESENT	0
652919	651590	20152B	PARTICIPANT	\N	PRESENT	0
652920	651590	11072N	PARTICIPANT	\N	PRESENT	0
653054	651590	14275Y	PARTICIPANT	\N	PRESENT	0
653059	651590	19599P	PARTICIPANT	\N	PRESENT	0
653060	651590	11090Q	PARTICIPANT	\N	PRESENT	0
653066	651590	11048N	PARTICIPANT	\N	PRESENT	0
653067	651590	20092G	PARTICIPANT	\N	PRESENT	0
653068	651590	11070L	PARTICIPANT	\N	PRESENT	0
653071	651590	20150Y	PARTICIPANT	\N	PRESENT	0
653087	651590	14219Q	PARTICIPANT	\N	PRESENT	0
653088	651590	19649G	PARTICIPANT	\N	PRESENT	0
653091	651590	19057M	PARTICIPANT	\N	PRESENT	0
653092	651590	11110B	PARTICIPANT	\N	PRESENT	0
653093	651590	14225N	PARTICIPANT	\N	PRESENT	0
653094	651590	11053K	PARTICIPANT	\N	PRESENT	0
653095	651590	14055N	PARTICIPANT	\N	PRESENT	0
653096	651590	20134Y	PARTICIPANT	\N	PRESENT	0
653097	651590	20094J	PARTICIPANT	\N	PRESENT	0
653098	651590	19507S	PARTICIPANT	\N	PRESENT	0
653099	651590	07029T	PARTICIPANT	\N	PRESENT	0
653185	651591	20024T	PARTICIPANT	\N	PRESENT	0
653186	651591	18193Q	PARTICIPANT	\N	PRESENT	0
653187	651591	17965H	PARTICIPANT	\N	PRESENT	0
653188	651591	14281W	PARTICIPANT	\N	PRESENT	0
653189	651591	19715Y	PARTICIPANT	\N	PRESENT	0
653190	651591	11031D	PARTICIPANT	\N	PRESENT	0
653191	651591	19719D	PARTICIPANT	\N	PRESENT	0
653192	651591	14207L	PARTICIPANT	\N	PRESENT	0
653193	651591	20060X	PARTICIPANT	\N	PRESENT	0
653194	651591	12041X	PARTICIPANT	\N	PRESENT	0
653195	651591	11056N	PARTICIPANT	\N	PRESENT	0
653196	651591	20018V	PARTICIPANT	\N	PRESENT	0
653197	651591	19760E	PARTICIPANT	\N	PRESENT	0
653198	651591	19695N	PARTICIPANT	\N	PRESENT	0
653199	651591	19503N	PARTICIPANT	\N	PRESENT	0
653200	651591	20094J	PARTICIPANT	\N	PRESENT	0
653201	651591	19599P	PARTICIPANT	\N	PRESENT	0
653202	651591	17779H	PARTICIPANT	\N	PRESENT	0
653203	651591	11045K	PARTICIPANT	\N	PRESENT	0
653204	651591	20130U	PARTICIPANT	\N	PRESENT	0
653205	651591	20036X	PARTICIPANT	\N	PRESENT	0
653206	651591	20134Y	PARTICIPANT	\N	PRESENT	0
653207	651591	11065P	PARTICIPANT	\N	PRESENT	0
653208	651591	20092G	PARTICIPANT	\N	PRESENT	0
653209	651591	14037X	PARTICIPANT	\N	PRESENT	0
653210	651591	19301E	PARTICIPANT	\N	PRESENT	0
653211	651591	19553Y	PARTICIPANT	\N	PRESENT	0
653212	651591	19591F	PARTICIPANT	\N	PRESENT	0
653213	651591	10006L	PARTICIPANT	\N	PRESENT	0
653214	651591	19679N	PARTICIPANT	\N	PRESENT	0
653215	651591	14231L	PARTICIPANT	\N	PRESENT	0
653216	651591	20298U	PARTICIPANT	\N	PRESENT	0
653217	651591	19369B	PARTICIPANT	\N	PRESENT	0
653218	651591	07004J	PARTICIPANT	\N	PRESENT	0
653219	651591	14251Q	PARTICIPANT	\N	PRESENT	0
653220	651591	01043Q	PARTICIPANT	\N	PRESENT	0
653221	651591	19577H	PARTICIPANT	\N	PRESENT	0
653222	651591	14215L	PARTICIPANT	\N	PRESENT	0
653223	651591	19671E	PARTICIPANT	\N	PRESENT	0
653224	651591	11097X	PARTICIPANT	\N	PRESENT	0
653225	651591	19747H	PARTICIPANT	\N	PRESENT	0
653226	651591	14071N	PARTICIPANT	\N	PRESENT	0
653227	651591	14053L	PARTICIPANT	\N	PRESENT	0
653228	651591	04033B	PARTICIPANT	\N	PRESENT	0
653229	651591	08010L	PARTICIPANT	\N	PRESENT	0
653230	651591	19533U	PARTICIPANT	\N	PRESENT	0
653231	651591	19762G	PARTICIPANT	\N	PRESENT	0
653232	651591	20124W	PARTICIPANT	\N	PRESENT	0
653233	651591	14357A	PARTICIPANT	\N	PRESENT	0
653234	651591	04035D	PARTICIPANT	\N	PRESENT	0
653235	651591	14147R	PARTICIPANT	\N	PRESENT	0
653236	651591	19569H	PARTICIPANT	\N	PRESENT	0
653237	651591	19701S	PARTICIPANT	\N	PRESENT	0
653238	651591	19711U	PARTICIPANT	\N	PRESENT	0
653239	651591	18083K	PARTICIPANT	\N	PRESENT	0
653240	651591	20078J	PARTICIPANT	\N	PRESENT	0
653241	651591	07029T	PARTICIPANT	\N	PRESENT	0
652748	652747	04047H	PARTICIPANT	\N	PRESENT	0
652749	652747	04042C	PARTICIPANT	\N	PRESENT	0
653242	651591	19507S	PARTICIPANT	\N	PRESENT	0
653243	651591	19663E	PARTICIPANT	\N	PRESENT	0
653244	651591	20044X	PARTICIPANT	\N	PRESENT	0
653245	651591	20180F	PARTICIPANT	\N	PRESENT	0
653246	651591	20038A	PARTICIPANT	\N	PRESENT	0
653247	651591	20034V	PARTICIPANT	\N	PRESENT	0
653248	651591	14275Y	PARTICIPANT	\N	PRESENT	0
653249	651591	17023S	PARTICIPANT	\N	PRESENT	0
653250	651591	14217N	PARTICIPANT	\N	PRESENT	0
653251	651591	20172F	PARTICIPANT	\N	PRESENT	0
653252	651591	11110B	PARTICIPANT	\N	PRESENT	0
653253	651591	11072N	PARTICIPANT	\N	PRESENT	0
653254	651591	01034P	PARTICIPANT	\N	PRESENT	0
653255	651591	14151M	PARTICIPANT	\N	PRESENT	0
653256	651591	08069G	PARTICIPANT	\N	PRESENT	0
653257	651591	19709B	PARTICIPANT	\N	PRESENT	0
653258	651591	14257W	PARTICIPANT	\N	PRESENT	0
653259	651591	14033T	PARTICIPANT	\N	PRESENT	0
653260	651591	11090Q	PARTICIPANT	\N	PRESENT	0
653261	651591	14055N	PARTICIPANT	\N	PRESENT	0
653262	651591	01028R	PARTICIPANT	\N	PRESENT	0
653263	651591	19687N	PARTICIPANT	\N	PRESENT	0
653264	651591	19647E	PARTICIPANT	\N	PRESENT	0
653265	651591	20106U	PARTICIPANT	\N	PRESENT	0
653266	651591	14021P	PARTICIPANT	\N	PRESENT	0
653267	651591	19057M	PARTICIPANT	\N	PRESENT	0
653183	651591	11070L	PARTICIPANT	\N	PRESENT	0
653184	651591	12016W	PARTICIPANT	\N	PRESENT	0
653268	651591	19347U	PARTICIPANT	\N	PRESENT	0
653285	651592	19719D	PARTICIPANT	\N	PRESENT	0
653286	651592	20180F	PARTICIPANT	\N	PRESENT	0
653287	651592	20060X	PARTICIPANT	\N	PRESENT	0
653288	651592	19643A	PARTICIPANT	\N	PRESENT	0
653289	651592	20264J	PARTICIPANT	\N	PRESENT	0
653290	651592	20018V	PARTICIPANT	\N	PRESENT	0
653291	651592	19599P	PARTICIPANT	\N	PRESENT	0
653292	651592	14257W	PARTICIPANT	\N	PRESENT	0
653293	651592	14147R	PARTICIPANT	\N	PRESENT	0
653294	651592	14037X	PARTICIPANT	\N	PRESENT	0
653295	651592	19697Q	PARTICIPANT	\N	PRESENT	0
653296	651592	14357A	PARTICIPANT	\N	PRESENT	0
653297	651592	11033F	PARTICIPANT	\N	PRESENT	0
653298	651592	14207L	PARTICIPANT	\N	PRESENT	0
653299	651592	20298U	PARTICIPANT	\N	PRESENT	0
653300	651592	14231L	PARTICIPANT	\N	PRESENT	0
653301	651592	19369B	PARTICIPANT	\N	PRESENT	0
653302	651592	19747H	PARTICIPANT	\N	PRESENT	0
653303	651592	20040T	PARTICIPANT	\N	PRESENT	0
653304	651592	20092G	PARTICIPANT	\N	PRESENT	0
653305	651592	11097X	PARTICIPANT	\N	PRESENT	0
653306	651592	14071N	PARTICIPANT	\N	PRESENT	0
653307	651592	07004J	PARTICIPANT	\N	PRESENT	0
653308	651592	14215L	PARTICIPANT	\N	PRESENT	0
653309	651592	20024T	PARTICIPANT	\N	PRESENT	0
653310	651592	20172F	PARTICIPANT	\N	PRESENT	0
653311	651592	14053L	PARTICIPANT	\N	PRESENT	0
653312	651592	11010L	PARTICIPANT	\N	PRESENT	0
653313	651592	20038A	PARTICIPANT	\N	PRESENT	0
653314	651592	20252E	PARTICIPANT	\N	PRESENT	0
653315	651592	20106U	PARTICIPANT	\N	PRESENT	0
653316	651592	19577H	PARTICIPANT	\N	PRESENT	0
653317	651592	08010L	PARTICIPANT	\N	PRESENT	0
653318	651592	19507S	PARTICIPANT	\N	PRESENT	0
653319	651592	20078J	PARTICIPANT	\N	PRESENT	0
653320	651592	20044X	PARTICIPANT	\N	PRESENT	0
653321	651592	14038Y	PARTICIPANT	\N	PRESENT	0
653322	651592	10006L	PARTICIPANT	\N	PRESENT	0
653323	651592	19301E	PARTICIPANT	\N	PRESENT	0
653324	651592	14033T	PARTICIPANT	\N	PRESENT	0
628905	626692	10006L	PARTICIPANT	\N	PRESENT	0
628906	626692	19683J	PRESIDENT	0	PRESENT	0
628907	626692	20130U	PARTICIPANT	\N	PRESENT	1
628908	626692	14147R	PARTICIPANT	\N	PRESENT	1
628932	626692	19301E	PARTICIPANT	\N	PRESENT	1
628985	626692	11031D	PARTICIPANT	\N	EXCUSE	0
629001	626692	19691J	PARTICIPANT	\N	PRESENT	0
629002	626692	04092N	PARTICIPANT	\N	PRESENT	0
629023	626853	14213J	PARTICIPANT	\N	PRESENT	1
629024	626853	19301E	PARTICIPANT	\N	PRESENT	1
629025	626853	19569H	PARTICIPANT	\N	PRESENT	1
629026	626853	20130U	PARTICIPANT	\N	PRESENT	1
629027	626853	18193Q	PARTICIPANT	\N	PRESENT	1
629028	626853	20090E	PARTICIPANT	\N	PRESENT	0
629029	626853	11097X	PARTICIPANT	\N	PRESENT	0
629030	626853	10006L	PRESIDENT	0	PRESENT	0
629031	626853	14217N	PARTICIPANT	\N	PRESENT	0
629032	626853	11067R	PARTICIPANT	\N	PRESENT	0
629033	626853	04043D	PARTICIPANT	\N	PRESENT	0
629034	626853	19295A	PARTICIPANT	\N	EXCUSE	0
629059	626853	19697Q	PARTICIPANT	\N	PRESENT	1
629060	626853	19717B	PARTICIPANT	\N	PRESENT	1
629757	629308	19441R	PARTICIPANT	\N	PRESENT	0
629758	629308	01043Q	PARTICIPANT	\N	PRESENT	0
629759	629308	14179A	PARTICIPANT	\N	PRESENT	0
629760	629308	14189C	PARTICIPANT	\N	PRESENT	0
630356	629022	19717B	PARTICIPANT	\N	PRESENT	1
629762	629308	19768N	PARTICIPANT	\N	PRESENT	0
629763	629308	14033T	PARTICIPANT	\N	PRESENT	0
629764	629308	20098N	PARTICIPANT	\N	PRESENT	0
629765	629308	20090E	PARTICIPANT	\N	PRESENT	0
629774	629308	20064C	PARTICIPANT	\N	PRESENT	0
629775	629308	11090Q	PARTICIPANT	\N	PRESENT	0
629776	629308	20142Y	PARTICIPANT	\N	PRESENT	0
629778	629308	20062A	PARTICIPANT	\N	PRESENT	0
629779	629308	20034V	PARTICIPANT	\N	PRESENT	0
629780	629308	19637C	PARTICIPANT	\N	PRESENT	0
629781	629308	19747H	PARTICIPANT	\N	PRESENT	0
629782	629308	19533U	PARTICIPANT	\N	PRESENT	0
629783	629308	19695N	PARTICIPANT	\N	PRESENT	0
629784	629308	19549D	PARTICIPANT	\N	PRESENT	0
629785	629308	20054A	PARTICIPANT	\N	PRESENT	0
629786	629308	20038A	PARTICIPANT	\N	PRESENT	0
629787	629308	14069U	PARTICIPANT	\N	PRESENT	0
629788	629308	20032T	PARTICIPANT	\N	PRESENT	0
629789	629308	08015R	PARTICIPANT	\N	PRESENT	0
629790	629308	20018V	PARTICIPANT	\N	PRESENT	0
629791	629308	14123H	PARTICIPANT	\N	PRESENT	0
629793	629308	11053K	PARTICIPANT	\N	PRESENT	0
629794	629123	95041E	PARTICIPANT	\N	PRESENT	0
629795	629123	19443T	PARTICIPANT	\N	PRESENT	0
629796	629123	12041X	PARTICIPANT	\N	PRESENT	0
629797	629123	19565D	PARTICIPANT	\N	PRESENT	0
629798	629123	01058X	PARTICIPANT	\N	PRESENT	0
629799	629123	11027H	PARTICIPANT	\N	PRESENT	0
629800	629123	16685X	PARTICIPANT	\N	PRESENT	0
629801	629123	04042C	PRESIDENT	0	PRESENT	0
629802	629123	11054L	PARTICIPANT	\N	PRESENT	0
629803	629123	11066Q	PARTICIPANT	\N	PRESENT	0
629804	629123	08056B	PARTICIPANT	\N	PRESENT	0
629805	629123	12028B	PARTICIPANT	\N	PRESENT	0
629806	629123	19421M	PARTICIPANT	\N	PRESENT	0
629807	629123	14193X	PARTICIPANT	\N	PRESENT	0
629808	629123	97011G	PARTICIPANT	\N	PRESENT	0
629809	629123	08061X	PARTICIPANT	\N	PRESENT	0
629810	629123	14249W	PARTICIPANT	\N	PRESENT	0
629811	629123	08047A	PARTICIPANT	\N	PRESENT	0
629812	629123	14059S	PARTICIPANT	\N	PRESENT	0
630377	629022	20090E	PARTICIPANT	\N	PRESENT	0
629814	629123	14133K	PARTICIPANT	\N	PRESENT	0
629815	629123	01062T	PARTICIPANT	\N	PRESENT	0
629816	629123	20042V	PARTICIPANT	\N	PRESENT	0
629817	629123	01024M	PARTICIPANT	\N	PRESENT	0
629818	629123	19319Q	PARTICIPANT	\N	PRESENT	0
630381	629022	17965H	PARTICIPANT	\N	PRESENT	0
629820	629123	14267Y	PARTICIPANT	\N	PRESENT	0
629821	629123	11083R	PARTICIPANT	\N	PRESENT	0
629822	629123	14255U	PARTICIPANT	\N	PRESENT	0
629823	629123	14211G	PARTICIPANT	\N	EXCUSE	0
629824	629123	19583F	PARTICIPANT	\N	EXCUSE	0
629825	629308	20092G	PARTICIPANT	\N	PRESENT	0
629826	629308	19715Y	PARTICIPANT	\N	PRESENT	0
629827	629308	20100N	PARTICIPANT	\N	PRESENT	0
629828	629308	19782L	PARTICIPANT	\N	PRESENT	0
629829	629308	20084G	PARTICIPANT	\N	PRESENT	0
629922	629308	14231L	PARTICIPANT	\N	PRESENT	0
629923	629308	14107H	PARTICIPANT	\N	PRESENT	0
632792	632754	19683J	PARTICIPANT	\N	PRESENT	0
632793	632754	10006L	PARTICIPANT	\N	PRESENT	0
632794	632754	11031D	PARTICIPANT	\N	PRESENT	0
632795	632754	19295A	PARTICIPANT	\N	PRESENT	0
632796	632754	19723Y	PARTICIPANT	\N	PRESENT	0
632797	632754	20062A	PARTICIPANT	\N	PRESENT	0
632802	632764	10006L	PARTICIPANT	\N	PRESENT	0
632803	632764	11031D	PARTICIPANT	\N	PRESENT	0
632804	632764	19713W	PARTICIPANT	\N	PRESENT	0
638065	638064	11067R	PARTICIPANT	\N	PRESENT	0
638067	638064	19479G	PARTICIPANT	\N	PRESENT	0
638069	638068	08010L	PARTICIPANT	\N	PRESENT	0
638703	638702	20150Y	PARTICIPANT	\N	PRESENT	0
638735	638734	20150Y	PARTICIPANT	\N	PRESENT	0
639119	639118	19717B	PARTICIPANT	\N	EXCUSE	0
639120	639118	14083S	PARTICIPANT	\N	EXCUSE	0
639121	639118	20100N	PARTICIPANT	\N	PRESENT	0
639122	639118	19333N	PARTICIPANT	\N	PRESENT	0
639123	639118	20102Q	PARTICIPANT	\N	PRESENT	0
639124	639118	14059S	PARTICIPANT	\N	PRESENT	1
639125	639118	20150Y	PARTICIPANT	\N	PRESENT	0
639126	639118	19503N	PRESIDENT	0	PRESENT	0
639210	638991	14251Q	PARTICIPANT	\N	PRESENT	1
639460	639459	11067R	PARTICIPANT	\N	EXCUSE	0
639461	639459	19723Y	PARTICIPANT	\N	EXCUSE	0
639462	639459	19503N	PARTICIPANT	\N	PRESENT	0
639463	639459	01048V	PARTICIPANT	\N	PRESENT	0
639464	639459	04043D	PARTICIPANT	\N	EXCUSE	0
639465	639459	01058X	PARTICIPANT	\N	PRESENT	0
639467	639459	20066E	PARTICIPANT	\N	PRESENT	0
639469	639459	19693L	PARTICIPANT	\N	PRESENT	0
640077	640076	19954N	PARTICIPANT	\N	PRESENT	0
640078	640076	11056N	PARTICIPANT	\N	PRESENT	0
640103	639478	14281W	PARTICIPANT	\N	PRESENT	0
640104	639478	19697Q	PARTICIPANT	\N	PRESENT	0
640083	640081	19954N	PARTICIPANT	\N	PRESENT	0
640084	640081	11056N	PARTICIPANT	\N	PRESENT	0
640232	640231	20150Y	PARTICIPANT	\N	PRESENT	1
640086	640081	19703U	PARTICIPANT	\N	PRESENT	0
640088	640087	19954N	PARTICIPANT	\N	PRESENT	0
640089	640087	11056N	PARTICIPANT	\N	PRESENT	0
640233	640231	19503N	PARTICIPANT	\N	PRESENT	0
640091	640087	19703U	PARTICIPANT	\N	PRESENT	0
640093	640092	19954N	PARTICIPANT	\N	PRESENT	0
640094	640092	11056N	PARTICIPANT	\N	PRESENT	0
640095	640092	19703U	PARTICIPANT	\N	PRESENT	0
640234	640231	19333N	PARTICIPANT	\N	PRESENT	0
640235	640231	19717B	PARTICIPANT	\N	EXCUSE	0
640236	640231	20034V	PARTICIPANT	\N	EXCUSE	0
640237	640231	20102Q	PARTICIPANT	\N	EXCUSE	0
640238	640231	14083S	PRESIDENT	0	PRESENT	0
640239	640231	20100N	PARTICIPANT	\N	PRESENT	0
640240	640231	14031R	PARTICIPANT	\N	PRESENT	1
640336	640075	04059M	PARTICIPANT	\N	PRESENT	0
640337	640075	19651A	PARTICIPANT	\N	EXCUSE	0
640338	640075	20086J	PARTICIPANT	\N	EXCUSE	0
640339	640075	20152B	PARTICIPANT	\N	PRESENT	0
640340	640075	19621T	PARTICIPANT	\N	PRESENT	0
640341	640075	11053K	PARTICIPANT	\N	PRESENT	0
640342	640075	11080N	PARTICIPANT	\N	PRESENT	0
640343	640075	19673G	PARTICIPANT	\N	PRESENT	0
640344	640075	20132W	PARTICIPANT	\N	EXCUSE	0
640345	640075	19725B	PARTICIPANT	\N	PRESENT	0
640346	640075	19399H	PARTICIPANT	\N	PRESENT	0
651647	651646	07033P	PARTICIPANT	\N	PRESENT	0
652527	650991	19333N	PARTICIPANT	\N	PRESENT	0
652528	650991	14031R	PARTICIPANT	\N	PRESENT	0
652529	650991	19549D	PARTICIPANT	\N	PRESENT	0
652583	650959	19697Q	PARTICIPANT	\N	PRESENT	0
652531	650991	19387D	PARTICIPANT	\N	PRESENT	0
652532	650991	14219Q	PRESIDENT	0	PRESENT	0
652533	650991	20102Q	PARTICIPANT	\N	PRESENT	0
652534	650991	18083K	PARTICIPANT	\N	PRESENT	0
652535	650991	20106U	PARTICIPANT	\N	PRESENT	0
652536	650991	19503N	PARTICIPANT	\N	PRESENT	0
652537	650991	20024T	PARTICIPANT	\N	PRESENT	0
652753	651590	19715Y	PARTICIPANT	\N	PRESENT	0
652539	650991	19525U	PARTICIPANT	\N	PRESENT	0
652584	650959	11067R	PARTICIPANT	\N	PRESENT	0
652585	650959	20090E	PARTICIPANT	\N	PRESENT	0
652586	650959	01034P	PARTICIPANT	\N	PRESENT	0
652587	650959	11097X	PARTICIPANT	\N	PRESENT	0
652588	650959	20040T	PARTICIPANT	\N	PRESENT	0
652589	650959	19663E	PARTICIPANT	\N	PRESENT	0
652590	650959	17965H	PARTICIPANT	\N	PRESENT	0
652591	650959	18193Q	PARTICIPANT	\N	PRESENT	0
652592	650959	17779H	PARTICIPANT	\N	PRESENT	0
652593	650959	19553Y	PARTICIPANT	\N	PRESENT	0
652594	650959	11031D	PARTICIPANT	\N	PRESENT	0
652595	650959	14281W	PARTICIPANT	\N	PRESENT	0
652596	650959	20066E	PARTICIPANT	\N	PRESENT	0
652597	650959	19679N	PARTICIPANT	\N	PRESENT	0
652598	650959	14042U	PARTICIPANT	\N	PRESENT	0
652599	650959	20298U	PARTICIPANT	\N	PRESENT	0
652600	650959	14213J	PARTICIPANT	\N	PRESENT	0
652601	650959	14071N	PARTICIPANT	\N	PRESENT	0
652602	650959	14217N	PARTICIPANT	\N	PRESENT	0
652603	650959	10006L	PARTICIPANT	\N	PRESENT	0
652754	651590	19671E	PARTICIPANT	\N	PRESENT	0
652755	651590	19593H	PARTICIPANT	\N	PRESENT	0
652756	651590	19679N	PARTICIPANT	\N	PRESENT	0
652759	651590	11027H	PARTICIPANT	\N	PRESENT	0
652761	651590	20914V	PARTICIPANT	\N	PRESENT	0
652767	651590	08060W	PARTICIPANT	\N	PRESENT	0
652768	651590	19525U	PARTICIPANT	\N	PRESENT	0
652774	651590	14257W	PARTICIPANT	\N	PRESENT	0
652775	651590	11033F	PARTICIPANT	\N	PRESENT	0
652778	651590	14207L	PARTICIPANT	\N	PRESENT	0
652779	651590	20124W	PARTICIPANT	\N	PRESENT	0
652780	651590	20090E	PARTICIPANT	\N	PRESENT	0
652781	651590	17779H	PARTICIPANT	\N	PRESENT	0
652782	651590	14281W	PARTICIPANT	\N	PRESENT	0
652783	651590	11067R	PARTICIPANT	\N	PRESENT	0
652784	651590	19333N	PARTICIPANT	\N	PRESENT	0
652785	651590	20264J	PARTICIPANT	\N	PRESENT	0
652786	651590	19569H	PARTICIPANT	\N	PRESENT	0
652787	651590	14042U	PARTICIPANT	\N	PRESENT	0
652788	651590	19683J	PARTICIPANT	\N	PRESENT	0
652789	651590	17965H	PARTICIPANT	\N	PRESENT	0
652790	651590	19467C	PARTICIPANT	\N	PRESENT	0
652791	651590	20044X	PARTICIPANT	\N	PRESENT	0
652792	651590	20130U	PARTICIPANT	\N	PRESENT	0
652793	651590	20018V	PARTICIPANT	\N	PRESENT	0
652794	651590	19663E	PARTICIPANT	\N	PRESENT	0
652795	651590	20028X	PARTICIPANT	\N	PRESENT	0
652796	651590	18193Q	PARTICIPANT	\N	PRESENT	0
652797	651590	14071N	PARTICIPANT	\N	PRESENT	0
652798	651590	08034U	PARTICIPANT	\N	PRESENT	0
652799	651590	11045K	PARTICIPANT	\N	PRESENT	0
652800	651590	14021P	PARTICIPANT	\N	PRESENT	0
652801	651590	19747H	PARTICIPANT	\N	PRESENT	0
652802	651590	11031D	PARTICIPANT	\N	PRESENT	0
652803	651590	19760E	PARTICIPANT	\N	PRESENT	0
652804	651590	19695N	PARTICIPANT	\N	PRESENT	0
652805	651590	19687N	PARTICIPANT	\N	PRESENT	0
652806	651590	20078J	PARTICIPANT	\N	PRESENT	0
652807	651590	19637C	PARTICIPANT	\N	PRESENT	0
652808	651590	14037X	PARTICIPANT	\N	PRESENT	0
652809	651590	18083K	PARTICIPANT	\N	PRESENT	0
652810	651590	19349W	PARTICIPANT	\N	PRESENT	0
652811	651590	19301E	PARTICIPANT	\N	PRESENT	0
652812	651590	19954N	PARTICIPANT	\N	PRESENT	0
652813	651590	19591F	PARTICIPANT	\N	PRESENT	0
652814	651590	20180F	PARTICIPANT	\N	PRESENT	0
652815	651590	20070A	PARTICIPANT	\N	PRESENT	0
652816	651590	19866P	PARTICIPANT	\N	PRESENT	0
652817	651590	01034P	PARTICIPANT	\N	PRESENT	0
652818	651590	19479G	PARTICIPANT	\N	PRESENT	0
652819	651590	14215L	PARTICIPANT	\N	PRESENT	0
652820	651590	14083S	PARTICIPANT	\N	PRESENT	0
652821	651590	11097X	PARTICIPANT	\N	PRESENT	0
652822	651590	20034V	PARTICIPANT	\N	PRESENT	0
652823	651590	14053L	PARTICIPANT	\N	PRESENT	0
652824	651590	19565D	PARTICIPANT	\N	PRESENT	0
652825	651590	19762G	PARTICIPANT	\N	PRESENT	0
652826	651590	19503N	PARTICIPANT	\N	PRESENT	0
652827	651590	19577H	PARTICIPANT	\N	PRESENT	0
652828	651590	14217N	PARTICIPANT	\N	PRESENT	0
652829	651590	19711U	PARTICIPANT	\N	PRESENT	0
652830	651590	14357A	PARTICIPANT	\N	PRESENT	0
652831	651590	19369B	PARTICIPANT	\N	PRESENT	0
652832	651590	19347U	PARTICIPANT	\N	PRESENT	0
652833	651590	11065P	PARTICIPANT	\N	PRESENT	0
652834	651590	19719D	PARTICIPANT	\N	PRESENT	0
652835	651590	19629C	PARTICIPANT	\N	PRESENT	0
652836	651590	20038A	PARTICIPANT	\N	PRESENT	0
652837	651590	14030Q	PARTICIPANT	\N	PRESENT	0
652838	651590	20298U	PARTICIPANT	\N	PRESENT	0
652839	651590	04059M	PARTICIPANT	\N	PRESENT	0
652840	651590	14033T	PARTICIPANT	\N	PRESENT	0
652841	651590	19673G	PARTICIPANT	\N	PRESENT	0
652842	651590	20286Q	PARTICIPANT	\N	PRESENT	0
652843	651590	20060X	PARTICIPANT	\N	PRESENT	0
652844	651590	19553Y	PARTICIPANT	\N	PRESENT	0
652845	651590	05008E	PARTICIPANT	\N	PRESENT	0
652846	651590	10006L	PARTICIPANT	\N	PRESENT	0
652847	651590	08010L	PARTICIPANT	\N	PRESENT	0
652848	651590	20040T	PARTICIPANT	\N	PRESENT	0
652849	651590	20036X	PARTICIPANT	\N	PRESENT	0
652850	651590	14231L	PARTICIPANT	\N	PRESENT	0
652851	651590	19741B	PARTICIPANT	\N	PRESENT	0
652852	651590	01024M	PARTICIPANT	\N	PRESENT	0
652853	651590	20172F	PARTICIPANT	\N	PRESENT	0
652854	651590	14151M	PARTICIPANT	\N	PRESENT	0
652855	650987	19687N	PARTICIPANT	\N	PRESENT	0
652856	650987	19349W	PARTICIPANT	\N	PRESENT	0
652857	651590	01028R	PARTICIPANT	\N	PRESENT	0
652858	651590	20100N	PARTICIPANT	\N	PRESENT	0
652859	650987	20080C	PARTICIPANT	\N	PRESENT	0
652860	650987	11053K	PARTICIPANT	\N	PRESENT	0
652861	651590	04033B	PARTICIPANT	\N	PRESENT	0
652862	651590	19701S	PARTICIPANT	\N	PRESENT	0
652863	650987	11048N	PARTICIPANT	\N	PRESENT	0
652864	650987	19479G	PARTICIPANT	\N	PRESENT	0
652865	651590	11026G	PARTICIPANT	\N	PRESENT	0
652866	650987	04071H	PARTICIPANT	\N	PRESENT	0
652867	650987	20050V	PARTICIPANT	\N	PRESENT	0
652868	650987	19671E	PARTICIPANT	\N	PRESENT	0
652869	650987	11070L	PARTICIPANT	\N	PRESENT	0
652870	650987	14083S	PARTICIPANT	\N	PRESENT	0
652871	650987	08010L	PARTICIPANT	\N	PRESENT	0
652872	650987	19762G	PARTICIPANT	\N	PRESENT	0
652873	651590	14147R	PARTICIPANT	\N	PRESENT	0
652874	650987	11074Q	PARTICIPANT	\N	PRESENT	0
652875	650987	20044X	PARTICIPANT	\N	PRESENT	0
652876	650987	14225N	PRESIDENT	0	PRESENT	0
652877	650987	08034U	PARTICIPANT	\N	PRESENT	0
652878	650987	07029T	PARTICIPANT	\N	PRESENT	0
652879	650987	19647E	PARTICIPANT	\N	PRESENT	0
652880	651590	19573D	PARTICIPANT	\N	PRESENT	0
652881	650987	20070A	PARTICIPANT	\N	PRESENT	0
652882	650987	20914V	PARTICIPANT	\N	PRESENT	0
652883	651590	20104S	PARTICIPANT	\N	PRESENT	0
652746	651590	99004R	PARTICIPANT	\N	PRESENT	0
652752	651590	19583F	PARTICIPANT	\N	PRESENT	0
652884	651590	20266L	PARTICIPANT	\N	PRESENT	0
652885	651590	01043Q	PARTICIPANT	\N	PRESENT	0
652886	651590	19549D	PARTICIPANT	\N	PRESENT	0
652887	651590	19533U	PARTICIPANT	\N	PRESENT	0
652888	651590	08061X	PARTICIPANT	\N	PRESENT	0
652889	651590	07004J	PARTICIPANT	\N	PRESENT	0
652890	651590	17023S	PARTICIPANT	\N	PRESENT	0
652891	650987	19741B	PARTICIPANT	\N	PRESENT	0
652892	651590	20082E	PARTICIPANT	\N	PRESENT	0
652893	651590	19667J	PARTICIPANT	\N	PRESENT	0
627418	626651	14189C	PARTICIPANT	\N	PRESENT	1
627419	626651	20086J	PARTICIPANT	\N	PRESENT	1
627420	626651	19545Y	PARTICIPANT	\N	PRESENT	1
627421	626651	11074Q	PARTICIPANT	\N	PRESENT	1
627422	626651	99004R	PARTICIPANT	\N	PRESENT	1
627423	626651	20126Y	PARTICIPANT	\N	PRESENT	1
627717	626694	04085P	PARTICIPANT	\N	PRESENT	1
627718	626694	11033F	PARTICIPANT	\N	PRESENT	1
627719	626694	19629C	PARTICIPANT	\N	PRESENT	1
627720	626694	14107H	PARTICIPANT	\N	PRESENT	1
627721	626694	19675J	PARTICIPANT	\N	PRESENT	1
627722	626694	20128B	PARTICIPANT	\N	PRESENT	1
627791	626694	10015M	PARTICIPANT	\N	PRESENT	0
627792	626694	11026G	PARTICIPANT	\N	PRESENT	0
627793	626694	14151M	PARTICIPANT	\N	PRESENT	0
628208	626794	08056B	PARTICIPANT	\N	PRESENT	0
628211	626794	08069G	PARTICIPANT	\N	PRESENT	0
628212	626794	95041E	PARTICIPANT	\N	PRESENT	0
628790	627018	04059M	PARTICIPANT	\N	PRESENT	0
628791	627018	19651A	PARTICIPANT	\N	PRESENT	1
629392	629387	19663E	PARTICIPANT	\N	PRESENT	0
629393	629387	14213J	PARTICIPANT	\N	PRESENT	0
629394	629387	19723Y	PARTICIPANT	\N	PRESENT	0
628795	627018	11053K	PARTICIPANT	\N	PRESENT	0
629395	629387	17965H	PARTICIPANT	\N	PRESENT	0
628797	627018	19673G	PARTICIPANT	\N	PRESENT	0
628798	627018	20132W	PARTICIPANT	\N	PRESENT	0
628799	627018	19725B	PARTICIPANT	\N	PRESENT	1
628800	627018	19399H	PARTICIPANT	\N	PRESENT	0
628801	627018	20056C	PARTICIPANT	\N	PRESENT	0
628802	627018	19611R	PRESIDENT	0	PRESENT	0
628803	627018	19699S	PARTICIPANT	\N	PRESENT	1
628804	627018	12041X	PARTICIPANT	\N	PRESENT	0
628805	627018	20142Y	PARTICIPANT	\N	PRESENT	0
628806	627018	19705W	PARTICIPANT	\N	PRESENT	1
628807	627018	14229S	PARTICIPANT	\N	PRESENT	0
629396	629388	19663E	PARTICIPANT	\N	PRESENT	0
628809	627018	20026V	PARTICIPANT	\N	PRESENT	1
629397	629389	19663E	PARTICIPANT	\N	PRESENT	0
629398	629391	19663E	PARTICIPANT	\N	PRESENT	0
629401	629400	19333N	PARTICIPANT	\N	PRESENT	0
629402	629400	14026U	PARTICIPANT	\N	PRESENT	0
629404	629403	20020P	PARTICIPANT	\N	PRESENT	0
629405	629403	20046A	PARTICIPANT	\N	PRESENT	0
629407	629406	20020P	PARTICIPANT	\N	PRESENT	0
630433	629205	04085P	PARTICIPANT	\N	PRESENT	1
630434	629205	20114U	PARTICIPANT	\N	PRESENT	1
630435	629205	20128B	PARTICIPANT	\N	PRESENT	1
630436	629205	14179A	PARTICIPANT	\N	PRESENT	1
630437	629205	19447X	PARTICIPANT	\N	PRESENT	1
630438	629205	19729F	PARTICIPANT	\N	PRESENT	1
630500	629206	20128B	PARTICIPANT	\N	PRESENT	1
630444	629205	07004J	PARTICIPANT	\N	EXCUSE	0
630498	629206	04085P	PARTICIPANT	\N	PRESENT	1
630499	629206	20114U	PARTICIPANT	\N	PRESENT	1
630501	629206	19447X	PARTICIPANT	\N	PRESENT	1
632909	631564	04085P	PARTICIPANT	\N	PRESENT	1
632910	631564	11033F	PARTICIPANT	\N	PRESENT	1
632911	631564	19543W	PARTICIPANT	\N	PRESENT	1
632912	631564	20114U	PARTICIPANT	\N	PRESENT	1
632913	631564	19629C	PARTICIPANT	\N	PRESENT	0
632914	631564	20128B	PARTICIPANT	\N	PRESENT	0
632915	631564	17737W	PARTICIPANT	\N	EXCUSE	0
638201	637893	20266L	PARTICIPANT	\N	PRESENT	0
638202	637893	19347U	PARTICIPANT	\N	PRESENT	0
638203	637893	14253S	PARTICIPANT	\N	PRESENT	0
638204	637893	20100N	PARTICIPANT	\N	PRESENT	0
638205	637893	20032T	PARTICIPANT	\N	PRESENT	0
638206	637893	11026G	PARTICIPANT	\N	PRESENT	0
638207	637893	18193Q	PARTICIPANT	\N	PRESENT	0
638208	637893	20136B	PARTICIPANT	\N	PRESENT	0
638209	637893	14331P	PARTICIPANT	\N	PRESENT	0
638210	637893	14105F	PARTICIPANT	\N	PRESENT	0
638211	637893	17779H	PARTICIPANT	\N	PRESENT	0
638212	637893	19533U	PARTICIPANT	\N	PRESENT	0
638213	637893	19527W	PARTICIPANT	\N	PRESENT	0
638214	637893	14193X	PARTICIPANT	\N	PRESENT	0
638215	637893	20070A	PARTICIPANT	\N	PRESENT	0
638216	637893	19421M	PARTICIPANT	\N	PRESENT	0
638217	637893	95041E	PARTICIPANT	\N	PRESENT	0
638218	637893	20094J	PARTICIPANT	\N	PRESENT	0
638219	637893	20120S	PARTICIPANT	\N	PRESENT	0
638220	637893	19531S	PARTICIPANT	\N	PRESENT	0
638221	637893	07033P	PARTICIPANT	\N	PRESENT	0
638222	637893	20134Y	PARTICIPANT	\N	PRESENT	0
638223	637893	14147R	PARTICIPANT	\N	PRESENT	0
638224	637893	19651A	PARTICIPANT	\N	PRESENT	0
638225	637893	20174H	PARTICIPANT	\N	PRESENT	0
638226	637893	20140W	PARTICIPANT	\N	PRESENT	0
638227	637893	19659J	PARTICIPANT	\N	PRESENT	0
638228	637893	14249W	PARTICIPANT	\N	PRESENT	0
638229	637893	19782L	PARTICIPANT	\N	PRESENT	0
638230	637893	19637C	PARTICIPANT	\N	PRESENT	0
638231	637893	19349W	PARTICIPANT	\N	PRESENT	0
638232	637893	19697Q	PARTICIPANT	\N	PRESENT	0
638233	637893	19525U	PARTICIPANT	\N	PRESENT	0
638234	637893	08061X	PARTICIPANT	\N	PRESENT	0
638235	637893	11083R	PARTICIPANT	\N	PRESENT	0
638236	637893	19387D	PARTICIPANT	\N	PRESENT	0
638237	637893	19629C	PARTICIPANT	\N	PRESENT	0
638238	637893	14107H	PARTICIPANT	\N	PRESENT	0
638239	637893	20180F	PARTICIPANT	\N	PRESENT	0
638240	637893	20050V	PARTICIPANT	\N	PRESENT	0
638241	637893	20096L	PARTICIPANT	\N	PRESENT	0
638242	637893	14251Q	PARTICIPANT	\N	PRESENT	0
638243	637893	20026V	PARTICIPANT	\N	PRESENT	0
638244	637893	11064N	PARTICIPANT	\N	PRESENT	0
638245	637893	19573D	PARTICIPANT	\N	PRESENT	0
638246	637893	20122U	PARTICIPANT	\N	PRESENT	0
638247	637893	19447X	PARTICIPANT	\N	PRESENT	0
638248	637893	20098N	PARTICIPANT	\N	PRESENT	0
638249	637893	20042V	PARTICIPANT	\N	PRESENT	0
638250	637893	20052X	PARTICIPANT	\N	PRESENT	0
638251	637893	19619A	PARTICIPANT	\N	PRESENT	0
638252	637893	19713W	PARTICIPANT	\N	PRESENT	0
638253	637893	19741B	PARTICIPANT	\N	PRESENT	0
638254	637893	14042U	PARTICIPANT	\N	PRESENT	0
638255	637893	20104S	PARTICIPANT	\N	PRESENT	0
638256	637893	14219Q	PARTICIPANT	\N	PRESENT	0
638257	637893	20108W	PARTICIPANT	\N	PRESENT	0
638258	637893	19441R	PARTICIPANT	\N	PRESENT	0
638259	637893	16685X	PARTICIPANT	\N	PRESENT	0
638260	637893	20024T	PARTICIPANT	\N	PRESENT	0
638261	637893	19739H	PARTICIPANT	\N	PRESENT	0
638262	637893	14357A	PARTICIPANT	\N	PRESENT	0
638263	637893	14089Y	PARTICIPANT	\N	PRESENT	0
638264	637893	08009T	PARTICIPANT	\N	PRESENT	0
638265	637893	19383Y	PARTICIPANT	\N	PRESENT	0
638266	637893	11053K	PARTICIPANT	\N	PRESENT	0
638267	637893	20298U	PARTICIPANT	\N	PRESENT	0
638268	637893	20020P	PARTICIPANT	\N	PRESENT	0
638269	637893	19691J	PARTICIPANT	\N	PRESENT	0
638270	637893	19675J	PARTICIPANT	\N	PRESENT	0
638271	637893	19369B	PARTICIPANT	\N	PRESENT	0
638272	637893	19762G	PARTICIPANT	\N	PRESENT	0
638273	637893	20040T	PARTICIPANT	\N	PRESENT	0
638274	637893	20126Y	PARTICIPANT	\N	PRESENT	0
638275	637893	20066E	PARTICIPANT	\N	PRESENT	0
638276	637893	14179A	PARTICIPANT	\N	PRESENT	0
638277	637893	14327T	PARTICIPANT	\N	PRESENT	0
638278	637893	08056B	PARTICIPANT	\N	PRESENT	0
638279	637893	14059S	PARTICIPANT	\N	PRESENT	0
638280	637893	04070G	PARTICIPANT	\N	PRESENT	0
638281	637893	20062A	PARTICIPANT	\N	PRESENT	0
638282	637893	14267Y	PARTICIPANT	\N	PRESENT	0
638283	637893	20144B	PARTICIPANT	\N	PRESENT	0
638284	637893	17737W	PARTICIPANT	\N	PRESENT	0
638285	637893	20248J	PARTICIPANT	\N	PRESENT	0
638286	637893	19507S	PARTICIPANT	\N	PRESENT	0
638287	637893	19749K	PARTICIPANT	\N	PRESENT	0
638288	637893	19663E	PARTICIPANT	\N	PRESENT	0
638289	637893	19685L	PARTICIPANT	\N	PRESENT	0
638290	637893	20044X	PARTICIPANT	\N	PRESENT	0
638291	637893	20086J	PARTICIPANT	\N	PRESENT	0
638292	637893	20058E	PARTICIPANT	\N	PRESENT	0
638293	637893	20124W	PARTICIPANT	\N	PRESENT	0
638294	637893	01024M	PARTICIPANT	\N	PRESENT	0
638295	637893	19866P	PARTICIPANT	\N	PRESENT	0
638296	637893	20138D	PARTICIPANT	\N	PRESENT	0
638297	637893	19545Y	PARTICIPANT	\N	PRESENT	0
650031	647948	19643A	PARTICIPANT	\N	PRESENT	1
650032	647948	08012N	PARTICIPANT	\N	PRESENT	0
651770	647526	14331P	PRESIDENT	0	PRESENT	0
651771	647526	14133K	PARTICIPANT	\N	PRESENT	0
651772	647526	14001X	PARTICIPANT	\N	PRESENT	0
651773	647526	12016W	PARTICIPANT	\N	PRESENT	0
651774	647526	20104S	PARTICIPANT	\N	PRESENT	0
652224	652088	19782L	PARTICIPANT	\N	PRESENT	1
652384	652375	20104S	PARTICIPANT	\N	PRESENT	0
652389	652375	16685X	PARTICIPANT	\N	PRESENT	0
652394	652375	20034V	PARTICIPANT	\N	PRESENT	0
652396	652375	20180F	PARTICIPANT	\N	PRESENT	0
652398	652375	14030Q	PARTICIPANT	\N	PRESENT	0
652401	652375	19820Y	PARTICIPANT	\N	PRESENT	0
652404	652375	14083S	PARTICIPANT	\N	PRESENT	0
652405	652375	14213J	PARTICIPANT	\N	PRESENT	1
652409	652375	14221J	PARTICIPANT	\N	PRESENT	1
653924	653921	14215L	PARTICIPANT	\N	PRESENT	0
654127	652906	19349W	PARTICIPANT	\N	PRESENT	0
654128	652906	11065P	PARTICIPANT	\N	PRESENT	0
654129	652906	20142Y	PARTICIPANT	\N	PRESENT	0
654130	652906	20914V	PARTICIPANT	\N	PRESENT	0
654131	652906	11066Q	PARTICIPANT	\N	PRESENT	0
654132	652906	19549D	PARTICIPANT	\N	PRESENT	0
654133	652906	11074Q	PARTICIPANT	\N	PRESENT	0
654134	652906	20030R	PARTICIPANT	\N	PRESENT	0
654135	652906	20088L	PARTICIPANT	\N	PRESENT	0
654136	652906	14257W	PARTICIPANT	\N	PRESENT	0
654137	652906	12016W	PARTICIPANT	\N	PRESENT	0
654138	652906	20028X	PARTICIPANT	\N	PRESENT	0
654139	652906	20070A	PARTICIPANT	\N	PRESENT	0
654140	652906	19649G	PARTICIPANT	\N	PRESENT	0
654141	652906	14151M	PARTICIPANT	\N	PRESENT	0
654142	652906	20080C	PARTICIPANT	\N	PRESENT	0
654143	652906	19647E	PARTICIPANT	\N	PRESENT	0
654144	652906	20100N	PARTICIPANT	\N	PRESENT	0
654145	652906	19782L	PARTICIPANT	\N	PRESENT	0
654146	652906	19301E	PARTICIPANT	\N	PRESENT	0
654147	652906	20150Y	PARTICIPANT	\N	PRESENT	0
654148	652906	19563B	PARTICIPANT	\N	PRESENT	0
654149	652906	19651A	PARTICIPANT	\N	PRESENT	0
654150	652906	19591F	PARTICIPANT	\N	PRESENT	0
654151	652906	19503N	PARTICIPANT	\N	PRESENT	0
654152	652906	12028B	PARTICIPANT	\N	PRESENT	0
654153	652906	20264J	PARTICIPANT	\N	PRESENT	0
654154	652906	19866P	PARTICIPANT	\N	PRESENT	0
654155	652906	19387D	PARTICIPANT	\N	PRESENT	0
654156	652906	14195A	PARTICIPANT	\N	PRESENT	0
654157	652906	20072C	PARTICIPANT	\N	PRESENT	0
654158	652906	14107H	PARTICIPANT	\N	PRESENT	0
654159	652906	19525U	PARTICIPANT	\N	PRESENT	0
654160	652906	20036X	PARTICIPANT	\N	PRESENT	0
654161	652906	19479G	PARTICIPANT	\N	PRESENT	0
654162	652906	14205J	PARTICIPANT	\N	PRESENT	0
654163	652906	19739H	PARTICIPANT	\N	PRESENT	0
654164	652906	20286Q	PARTICIPANT	\N	PRESENT	0
654165	652906	08009T	PARTICIPANT	\N	PRESENT	0
654166	652906	20298U	PARTICIPANT	\N	PRESENT	0
654167	652906	14179A	PARTICIPANT	\N	PRESENT	0
654168	652906	20052X	PARTICIPANT	\N	PRESENT	0
654169	652906	14083S	PARTICIPANT	\N	PRESENT	0
654170	652906	01024M	PARTICIPANT	\N	PRESENT	0
654171	652906	14189C	PARTICIPANT	\N	PRESENT	0
654172	652906	20054A	PARTICIPANT	\N	PRESENT	0
654173	652906	19335Q	PARTICIPANT	\N	PRESENT	0
654174	652906	19367Y	PARTICIPANT	\N	PRESENT	0
654175	652906	19671E	PARTICIPANT	\N	PRESENT	0
654176	652906	14053L	PARTICIPANT	\N	PRESENT	0
654177	652906	19747H	PARTICIPANT	\N	PRESENT	0
654178	652906	20152B	PARTICIPANT	\N	PRESENT	0
654179	652906	20252E	PARTICIPANT	\N	PRESENT	0
654180	652906	19701S	PARTICIPANT	\N	PRESENT	0
654181	652906	14071N	PARTICIPANT	\N	PRESENT	0
654182	652906	14187A	PARTICIPANT	\N	PRESENT	0
654183	652906	14069U	PARTICIPANT	\N	PRESENT	0
654184	652906	14251Q	PARTICIPANT	\N	PRESENT	0
654185	652906	07029T	PARTICIPANT	\N	PRESENT	0
654186	652906	19762G	PARTICIPANT	\N	PRESENT	0
654187	652906	14059S	PARTICIPANT	\N	PRESENT	0
654188	652906	20062A	PARTICIPANT	\N	PRESENT	0
654189	652906	20090E	PARTICIPANT	\N	PRESENT	0
654190	652906	14357A	PARTICIPANT	\N	PRESENT	0
654191	652906	14329V	PARTICIPANT	\N	PRESENT	0
654125	652906	11045K	PARTICIPANT	\N	PRESENT	0
654126	652906	08061X	PARTICIPANT	\N	PRESENT	0
654192	652906	97011G	PARTICIPANT	\N	PRESENT	0
654193	652906	04033B	PARTICIPANT	\N	PRESENT	0
654194	652906	20118Y	PARTICIPANT	\N	PRESENT	0
654195	652906	20024T	PARTICIPANT	\N	PRESENT	0
654196	652906	14147R	PARTICIPANT	\N	PRESENT	0
654197	652906	20032T	PARTICIPANT	\N	PRESENT	0
654198	652906	19768N	PARTICIPANT	\N	PRESENT	0
654199	652906	20136B	PARTICIPANT	\N	PRESENT	0
654200	652906	20022R	PARTICIPANT	\N	PRESENT	0
654201	652906	05012A	PARTICIPANT	\N	PRESENT	0
654202	652906	19711U	PARTICIPANT	\N	PRESENT	0
654203	652906	01058X	PARTICIPANT	\N	PRESENT	0
654204	652906	18083K	PARTICIPANT	\N	PRESENT	0
654205	652906	19575F	PARTICIPANT	\N	PRESENT	0
654206	652906	19679N	PARTICIPANT	\N	PRESENT	0
654207	652906	20076G	PARTICIPANT	\N	PRESENT	0
654208	652906	14191V	PARTICIPANT	\N	PRESENT	0
654209	652906	20038A	PARTICIPANT	\N	PRESENT	0
654210	652906	19673G	PARTICIPANT	\N	PRESENT	0
654211	652906	14031R	PARTICIPANT	\N	PRESENT	0
654212	652906	19667J	PARTICIPANT	\N	PRESENT	0
654213	652906	20026V	PARTICIPANT	\N	PRESENT	0
654214	652906	08010L	PARTICIPANT	\N	PRESENT	0
654215	652906	20086J	PARTICIPANT	\N	PRESENT	0
654216	652906	20098N	PARTICIPANT	\N	PRESENT	0
654217	652906	20056C	PARTICIPANT	\N	PRESENT	0
654218	652906	19467C	PARTICIPANT	\N	PRESENT	0
654219	652906	20034V	PARTICIPANT	\N	PRESENT	0
654220	652906	14038Y	PARTICIPANT	\N	PRESENT	0
654221	652906	14173T	PARTICIPANT	\N	PRESENT	0
654222	652906	19447X	PARTICIPANT	\N	PRESENT	0
654223	652906	08047A	PARTICIPANT	\N	PRESENT	0
654224	652906	20108W	PARTICIPANT	\N	PRESENT	0
654225	652906	14033T	PARTICIPANT	\N	PRESENT	0
654226	652906	19443T	PARTICIPANT	\N	PRESENT	0
654227	652906	20040T	PARTICIPANT	\N	PRESENT	0
654228	652906	11056N	PARTICIPANT	\N	PRESENT	0
654229	652906	19687N	PARTICIPANT	\N	PRESENT	0
654230	652906	11040E	PARTICIPANT	\N	PRESENT	0
654231	652906	20102Q	PARTICIPANT	\N	PRESENT	0
654232	652906	20134Y	PARTICIPANT	\N	PRESENT	0
654233	652906	20092G	PARTICIPANT	\N	PRESENT	0
654234	652906	19347U	PARTICIPANT	\N	PRESENT	0
654235	652906	20110Q	PARTICIPANT	\N	PRESENT	0
654236	652906	99004R	PARTICIPANT	\N	PRESENT	0
654237	652906	11104D	PARTICIPANT	\N	PRESENT	0
654238	652906	20132W	PARTICIPANT	\N	PRESENT	0
654239	652906	19820Y	PARTICIPANT	\N	PRESENT	0
654240	652906	19766L	PARTICIPANT	\N	PRESENT	0
654241	652906	01057W	PARTICIPANT	\N	PRESENT	0
654242	652906	04043D	PARTICIPANT	\N	PRESENT	0
654243	652906	20018V	PARTICIPANT	\N	PRESENT	0
654244	652906	20140W	PARTICIPANT	\N	PRESENT	0
654245	652906	20266L	PARTICIPANT	\N	PRESENT	0
654246	652906	19758L	PARTICIPANT	\N	PRESENT	0
654247	652906	19826F	PARTICIPANT	\N	PRESENT	0
654248	652906	14073Q	PARTICIPANT	\N	PRESENT	0
654249	652906	04059M	PARTICIPANT	\N	PRESENT	0
654250	652906	19413M	PARTICIPANT	\N	PRESENT	0
654251	652906	19643A	PARTICIPANT	\N	PRESENT	0
654252	652906	07004J	PARTICIPANT	\N	PRESENT	0
654253	652906	19619A	PARTICIPANT	\N	PRESENT	0
654254	652906	11012A	PARTICIPANT	\N	PRESENT	0
654255	652906	20084G	PARTICIPANT	\N	PRESENT	0
654256	652906	19745F	PARTICIPANT	\N	PRESENT	0
654257	652906	01043Q	PARTICIPANT	\N	PRESENT	0
654258	652906	20104S	PARTICIPANT	\N	PRESENT	0
654259	652906	19760E	PARTICIPANT	\N	PRESENT	0
654260	652906	08045X	PARTICIPANT	\N	PRESENT	0
654261	652906	19531S	PARTICIPANT	\N	PRESENT	0
654262	652906	19543W	PARTICIPANT	\N	PRESENT	0
654263	652906	14231L	PARTICIPANT	\N	PRESENT	0
654264	652906	14255U	PARTICIPANT	\N	PRESENT	0
654265	652906	11033F	PARTICIPANT	\N	PRESENT	0
654266	652906	14121F	PARTICIPANT	\N	PRESENT	0
654267	652906	11099A	PARTICIPANT	\N	PRESENT	0
627724	627723	14147R	PARTICIPANT	\N	PRESENT	0
627725	627723	20114U	PARTICIPANT	\N	PRESENT	0
629195	629194	12028B	PARTICIPANT	\N	PRESENT	0
629198	629197	14255U	PARTICIPANT	\N	PRESENT	0
629429	629428	08045X	PARTICIPANT	\N	PRESENT	0
629430	629428	18193Q	PARTICIPANT	\N	PRESENT	0
630258	629205	20266L	PARTICIPANT	\N	PRESENT	0
630259	629305	04033B	PARTICIPANT	\N	PRESENT	0
630260	629305	92040Q	PARTICIPANT	\N	PRESENT	0
630261	629305	20112S	PARTICIPANT	\N	EXCUSE	0
630262	629305	19527W	PARTICIPANT	\N	PRESENT	0
630263	629305	20048C	PARTICIPANT	\N	PRESENT	0
630264	629305	20152B	PARTICIPANT	\N	PRESENT	0
630265	629305	14030Q	PARTICIPANT	\N	PRESENT	0
630266	629305	20058E	PARTICIPANT	\N	PRESENT	0
630270	629305	04070G	PARTICIPANT	\N	PRESENT	1
630271	629305	14123H	PARTICIPANT	\N	PRESENT	0
630272	628668	14327T	PARTICIPANT	\N	PRESENT	0
630273	628668	14331P	PARTICIPANT	\N	PRESENT	0
630274	628668	19479G	PARTICIPANT	\N	PRESENT	0
630275	628668	19711U	PARTICIPANT	\N	PRESENT	0
630276	628668	01048V	PARTICIPANT	\N	PRESENT	0
630277	628668	08034U	PARTICIPANT	\N	PRESENT	0
630278	628668	14189C	PARTICIPANT	\N	PRESENT	0
630279	628668	19545Y	PARTICIPANT	\N	PRESENT	0
630280	628668	01057W	PARTICIPANT	\N	PRESENT	0
630281	628668	11074Q	PARTICIPANT	\N	PRESENT	0
630282	628668	11070L	PARTICIPANT	\N	PRESENT	0
630283	628668	14225N	PRESIDENT	0	PRESENT	0
630284	628668	14173T	PARTICIPANT	\N	PRESENT	0
630285	628668	11040E	PARTICIPANT	\N	PRESENT	0
630286	628668	14083S	PARTICIPANT	\N	PRESENT	0
630287	628668	20252E	PARTICIPANT	\N	PRESENT	0
630288	628668	08010L	PARTICIPANT	\N	PRESENT	0
630289	628668	99004R	PARTICIPANT	\N	PRESENT	0
630290	628668	20116W	PARTICIPANT	\N	PRESENT	0
630291	628668	20126Y	PARTICIPANT	\N	PRESENT	0
630292	628668	11048N	PARTICIPANT	\N	PRESENT	0
630293	629205	05008E	PARTICIPANT	\N	PRESENT	0
630294	629305	19643A	PARTICIPANT	\N	PRESENT	0
630353	629205	17737W	PARTICIPANT	\N	PRESENT	0
630354	629205	19489J	PARTICIPANT	\N	PRESENT	0
630355	629205	14053L	PARTICIPANT	\N	PRESENT	0
630357	629206	14053L	PARTICIPANT	\N	PRESENT	0
630358	629206	20074E	PARTICIPANT	\N	PRESENT	0
630359	629206	11026G	PARTICIPANT	\N	PRESENT	0
630360	629206	19581D	PARTICIPANT	\N	PRESENT	0
630361	629206	04047H	PRESIDENT	0	PRESENT	0
630362	629206	01028R	PARTICIPANT	\N	PRESENT	0
630363	629206	11056N	PARTICIPANT	\N	PRESENT	0
630364	629206	19954N	PARTICIPANT	\N	PRESENT	0
630365	629206	17737W	PARTICIPANT	\N	PRESENT	0
630366	629206	19489J	PARTICIPANT	\N	PRESENT	0
630367	629206	95063L	PARTICIPANT	\N	PRESENT	0
630368	629206	20108W	PARTICIPANT	\N	PRESENT	0
630369	629206	14107H	PARTICIPANT	\N	PRESENT	0
630370	629206	20110Q	PARTICIPANT	\N	PRESENT	0
630371	629206	14179A	PARTICIPANT	\N	PRESENT	0
630372	629206	14215L	PARTICIPANT	\N	PRESENT	0
630373	629206	11085T	PARTICIPANT	\N	PRESENT	0
630374	629206	20022R	PARTICIPANT	\N	PRESENT	0
630375	629206	11072N	PARTICIPANT	\N	PRESENT	0
630376	629206	14147R	PARTICIPANT	\N	PRESENT	0
630378	629305	11109J	PARTICIPANT	\N	EXCUSE	0
630379	629958	11065P	PARTICIPANT	\N	PRESENT	0
633988	633987	20266L	PARTICIPANT	\N	PRESENT	0
633989	633987	18083K	PARTICIPANT	\N	PRESENT	0
633990	633987	19760E	PARTICIPANT	\N	PRESENT	0
633991	633987	18193Q	PARTICIPANT	\N	PRESENT	0
633992	633987	17965H	PARTICIPANT	\N	PRESENT	0
633994	633993	20266L	PARTICIPANT	\N	PRESENT	0
633995	633993	18083K	PARTICIPANT	\N	PRESENT	0
633996	633993	18193Q	PARTICIPANT	\N	PRESENT	0
633999	633998	20266L	PARTICIPANT	\N	PRESENT	0
634000	633998	18083K	PARTICIPANT	\N	PRESENT	0
634001	633998	18193Q	PARTICIPANT	\N	PRESENT	0
639749	639587	14259Y	PARTICIPANT	\N	PRESENT	0
639750	639587	19711U	PARTICIPANT	\N	PRESENT	0
639751	639587	19651A	PARTICIPANT	\N	PRESENT	0
639752	639587	20042V	PARTICIPANT	\N	PRESENT	0
639753	639587	20068G	PARTICIPANT	\N	PRESENT	0
639754	639587	19479G	PARTICIPANT	\N	PRESENT	0
639755	639587	19703U	PARTICIPANT	\N	PRESENT	0
639756	639587	11056N	PARTICIPANT	\N	PRESENT	0
639757	639587	20032T	PARTICIPANT	\N	PRESENT	0
639758	639587	20044X	PARTICIPANT	\N	PRESENT	0
640347	640075	20056C	PARTICIPANT	\N	PRESENT	0
640348	640075	19611R	PRESIDENT	0	PRESENT	0
640349	640075	19699S	PARTICIPANT	\N	PRESENT	0
640350	640075	12041X	PARTICIPANT	\N	PRESENT	0
640351	640075	20142Y	PARTICIPANT	\N	PRESENT	0
640352	640075	19705W	PARTICIPANT	\N	PRESENT	0
640353	640075	14229S	PARTICIPANT	\N	PRESENT	0
640354	640075	19669L	PARTICIPANT	\N	PRESENT	1
640355	640075	20026V	PARTICIPANT	\N	PRESENT	0
640356	640075	20122U	PARTICIPANT	\N	PRESENT	0
640521	639760	11097X	PRESIDENT	0	PRESENT	1
640522	639760	18193Q	PARTICIPANT	\N	PRESENT	0
640523	639760	14042U	PARTICIPANT	\N	PRESENT	0
640524	639760	19683J	PARTICIPANT	\N	PRESENT	0
640526	639760	11103C	PARTICIPANT	\N	PRESENT	1
640528	639760	14213J	PARTICIPANT	\N	PRESENT	1
640530	639760	20130U	PARTICIPANT	\N	PRESENT	1
640531	639760	04092N	PARTICIPANT	\N	EXCUSE	0
640533	639760	14071N	PARTICIPANT	\N	EXCUSE	0
640549	640545	14257W	PARTICIPANT	\N	PRESENT	0
640550	640545	11090Q	PARTICIPANT	\N	PRESENT	0
640567	639941	10006L	PRESIDENT	0	PRESENT	0
640568	639941	11097X	PARTICIPANT	\N	PRESENT	0
640569	639941	14213J	PARTICIPANT	\N	PRESENT	1
640570	639941	14042U	PARTICIPANT	\N	PRESENT	0
640571	639941	20040T	PARTICIPANT	\N	PRESENT	0
640572	639941	19798U	PARTICIPANT	\N	PRESENT	1
640574	640573	14257W	PARTICIPANT	\N	PRESENT	0
640575	640573	11090Q	PARTICIPANT	\N	PRESENT	0
640576	640573	20286Q	PARTICIPANT	\N	PRESENT	0
640603	639941	04092N	PARTICIPANT	\N	EXCUSE	0
640604	639941	14071N	PARTICIPANT	\N	EXCUSE	0
640625	640621	19593H	PARTICIPANT	\N	PRESENT	0
640626	640621	20026V	PARTICIPANT	\N	PRESENT	0
640627	640621	20056C	PARTICIPANT	\N	PRESENT	0
640628	640622	19593H	PARTICIPANT	\N	PRESENT	0
640629	640622	20026V	PARTICIPANT	\N	PRESENT	0
641611	641610	19631V	PARTICIPANT	\N	PRESENT	0
641612	641610	20024T	PARTICIPANT	\N	PRESENT	0
641613	641610	14030Q	PARTICIPANT	\N	PRESENT	0
641614	641610	19643A	PARTICIPANT	\N	PRESENT	0
641615	641610	19782L	PARTICIPANT	\N	PRESENT	0
641616	641610	01024M	PARTICIPANT	\N	PRESENT	0
641617	641610	11083R	PARTICIPANT	\N	PRESENT	0
641618	641610	14147R	PARTICIPANT	\N	PRESENT	0
641619	641610	19713W	PARTICIPANT	\N	PRESENT	0
641620	641610	19749K	PARTICIPANT	\N	PRESENT	0
641621	641610	97011G	PARTICIPANT	\N	PRESENT	0
641622	641610	17737W	PARTICIPANT	\N	PRESENT	0
641628	641627	14083S	PRESIDENT	0	PRESENT	0
641629	641627	19717B	PARTICIPANT	\N	EXCUSE	0
641630	641627	20034V	PARTICIPANT	\N	PRESENT	1
641631	641627	20150Y	PARTICIPANT	\N	PRESENT	1
641632	641627	14059S	PARTICIPANT	\N	EXCUSE	0
641633	641627	19447X	PARTICIPANT	\N	PRESENT	1
641634	641627	20102Q	PARTICIPANT	\N	PRESENT	0
642805	642186	14219Q	PARTICIPANT	\N	EXCUSE	0
642835	642834	19545Y	PARTICIPANT	\N	PRESENT	0
642836	642834	19689Q	PARTICIPANT	\N	PRESENT	0
642838	642837	20054A	PARTICIPANT	\N	PRESENT	0
642839	642837	14205J	PARTICIPANT	\N	PRESENT	0
642840	642837	20092G	PARTICIPANT	\N	PRESENT	0
643043	643042	20100N	PARTICIPANT	\N	PRESENT	0
642862	642861	19697Q	PARTICIPANT	\N	PRESENT	0
642863	642861	19679N	PARTICIPANT	\N	PRESENT	0
643044	643042	14001X	PARTICIPANT	\N	PRESENT	0
643045	643042	19711U	PARTICIPANT	\N	PRESENT	0
643047	643046	20100N	PARTICIPANT	\N	PRESENT	0
643048	643046	19711U	PARTICIPANT	\N	PRESENT	0
643049	643046	14001X	PARTICIPANT	\N	PRESENT	0
643051	643050	14001X	PARTICIPANT	\N	PRESENT	0
643052	643050	19711U	PARTICIPANT	\N	PRESENT	0
643054	643053	19711U	PARTICIPANT	\N	PRESENT	0
643055	643053	14001X	PARTICIPANT	\N	PRESENT	0
643056	643053	20100N	PARTICIPANT	\N	PRESENT	0
653325	651592	20124W	PARTICIPANT	\N	PRESENT	0
653326	651592	11072N	PARTICIPANT	\N	PRESENT	0
653327	651592	19679N	PARTICIPANT	\N	PRESENT	0
653328	651592	19563B	PARTICIPANT	\N	PRESENT	0
653329	651592	19758L	PARTICIPANT	\N	PRESENT	0
653330	651592	19695N	PARTICIPANT	\N	PRESENT	0
653331	651592	19760E	PARTICIPANT	\N	PRESENT	0
653332	651592	11110B	PARTICIPANT	\N	PRESENT	0
653333	651592	19715Y	PARTICIPANT	\N	PRESENT	0
653334	651592	20134Y	PARTICIPANT	\N	PRESENT	0
653335	651592	19673G	PARTICIPANT	\N	PRESENT	0
653336	651592	11090Q	PARTICIPANT	\N	PRESENT	0
653337	651592	19766L	PARTICIPANT	\N	PRESENT	0
653338	651592	04033B	PARTICIPANT	\N	PRESENT	0
653339	651592	19591F	PARTICIPANT	\N	PRESENT	0
653340	651592	01043Q	PARTICIPANT	\N	PRESENT	0
653341	651592	19553Y	PARTICIPANT	\N	PRESENT	0
653342	651592	19762G	PARTICIPANT	\N	PRESENT	0
653343	651592	20094J	PARTICIPANT	\N	PRESENT	0
653344	651592	19533U	PARTICIPANT	\N	PRESENT	0
653345	651592	19347U	PARTICIPANT	\N	PRESENT	0
653346	651592	19667J	PARTICIPANT	\N	PRESENT	0
653347	651592	08045X	PARTICIPANT	\N	PRESENT	0
653348	651592	19593H	PARTICIPANT	\N	PRESENT	0
653349	651592	20130U	PARTICIPANT	\N	PRESENT	0
653350	651592	14021P	PARTICIPANT	\N	PRESENT	0
653351	651592	14281W	PARTICIPANT	\N	PRESENT	0
653352	651592	11031D	PARTICIPANT	\N	PRESENT	0
653353	651592	20914V	PARTICIPANT	\N	PRESENT	0
653354	651592	20150Y	PARTICIPANT	\N	PRESENT	0
653355	651592	17965H	PARTICIPANT	\N	PRESENT	0
653356	651592	12016W	PARTICIPANT	\N	PRESENT	0
653357	651592	20034V	PARTICIPANT	\N	PRESENT	0
653361	651592	18193Q	PARTICIPANT	\N	PRESENT	0
653362	651592	20058E	PARTICIPANT	\N	PRESENT	0
653363	651592	04059M	PARTICIPANT	\N	PRESENT	0
653364	651592	19723Y	PARTICIPANT	\N	PRESENT	0
653365	651592	11065P	PARTICIPANT	\N	PRESENT	0
653366	651592	17023S	PARTICIPANT	\N	PRESENT	0
653367	651592	20016T	PARTICIPANT	\N	PRESENT	0
653368	651592	19057M	PARTICIPANT	\N	PRESENT	0
653369	651592	19649G	PARTICIPANT	\N	PRESENT	0
653424	651593	20024T	PARTICIPANT	\N	PRESENT	0
653425	651593	19507S	PARTICIPANT	\N	PRESENT	0
653426	651593	14033T	PARTICIPANT	\N	PRESENT	0
653427	651593	19701S	PARTICIPANT	\N	PRESENT	0
653428	651593	14038Y	PARTICIPANT	\N	PRESENT	0
653429	651593	20092G	PARTICIPANT	\N	PRESENT	0
653430	651593	11090Q	PARTICIPANT	\N	PRESENT	0
653431	651593	14053L	PARTICIPANT	\N	PRESENT	0
653432	651593	20134Y	PARTICIPANT	\N	PRESENT	0
653433	651593	19563B	PARTICIPANT	\N	PRESENT	0
653434	651593	14257W	PARTICIPANT	\N	PRESENT	0
653435	651593	19695N	PARTICIPANT	\N	PRESENT	0
653436	651593	19593H	PARTICIPANT	\N	PRESENT	0
653437	651593	19369B	PARTICIPANT	\N	PRESENT	0
653438	651593	14215L	PARTICIPANT	\N	PRESENT	0
653439	651593	20252E	PARTICIPANT	\N	PRESENT	0
653440	651593	18193Q	PARTICIPANT	\N	PRESENT	0
653441	651593	20180F	PARTICIPANT	\N	PRESENT	0
653442	651593	19301E	PARTICIPANT	\N	PRESENT	0
653443	651593	14207L	PARTICIPANT	\N	PRESENT	0
653444	651593	14037X	PARTICIPANT	\N	PRESENT	0
653445	651593	14021P	PARTICIPANT	\N	PRESENT	0
653446	651593	19599P	PARTICIPANT	\N	PRESENT	0
653447	651593	20044X	PARTICIPANT	\N	PRESENT	0
653448	651593	20106U	PARTICIPANT	\N	PRESENT	0
653449	651593	19747H	PARTICIPANT	\N	PRESENT	0
653450	651593	11065P	PARTICIPANT	\N	PRESENT	0
653451	651593	20914V	PARTICIPANT	\N	PRESENT	0
653452	651593	20146D	PARTICIPANT	\N	PRESENT	0
653453	651593	08010L	PARTICIPANT	\N	PRESENT	0
653454	651593	20018V	PARTICIPANT	\N	PRESENT	0
653455	651593	20264J	PARTICIPANT	\N	PRESENT	0
653456	651593	19649G	PARTICIPANT	\N	PRESENT	0
653457	651593	20038A	PARTICIPANT	\N	PRESENT	0
653458	651593	19723Y	PARTICIPANT	\N	PRESENT	0
653459	651593	20172F	PARTICIPANT	\N	PRESENT	0
653460	651593	20058E	PARTICIPANT	\N	PRESENT	0
653461	651593	19347U	PARTICIPANT	\N	PRESENT	0
653462	651593	19715Y	PARTICIPANT	\N	PRESENT	0
653463	651593	19667J	PARTICIPANT	\N	PRESENT	0
653464	651593	19760E	PARTICIPANT	\N	PRESENT	0
653465	651593	17965H	PARTICIPANT	\N	PRESENT	0
653466	651593	19553Y	PARTICIPANT	\N	PRESENT	0
653467	651593	11097X	PARTICIPANT	\N	PRESENT	0
653468	651593	20078J	PARTICIPANT	\N	PRESENT	0
653469	651593	14071N	PARTICIPANT	\N	PRESENT	0
653470	651593	14055N	PARTICIPANT	\N	PRESENT	0
653471	651593	19577H	PARTICIPANT	\N	PRESENT	0
653472	651593	20298U	PARTICIPANT	\N	PRESENT	0
653473	651593	19766L	PARTICIPANT	\N	PRESENT	0
653474	651593	14147R	PARTICIPANT	\N	PRESENT	0
653475	651593	04059M	PARTICIPANT	\N	PRESENT	0
653422	651593	12041X	PARTICIPANT	\N	PRESENT	0
653423	651593	19762G	PARTICIPANT	\N	PRESENT	0
653476	651593	19679N	PARTICIPANT	\N	PRESENT	0
653477	651593	12016W	PARTICIPANT	\N	PRESENT	0
653478	651593	19758L	PARTICIPANT	\N	PRESENT	0
653479	651593	08045X	PARTICIPANT	\N	PRESENT	0
653480	651593	20034V	PARTICIPANT	\N	PRESENT	0
653481	651593	19673G	PARTICIPANT	\N	PRESENT	0
653482	651593	19697Q	PARTICIPANT	\N	PRESENT	0
653483	651593	20138D	PARTICIPANT	\N	PRESENT	0
653484	651593	20060X	PARTICIPANT	\N	PRESENT	0
653485	651593	20124W	PARTICIPANT	\N	PRESENT	0
653486	651593	04033B	PARTICIPANT	\N	PRESENT	0
653487	651593	99004R	PARTICIPANT	\N	PRESENT	0
653488	651593	11010L	PARTICIPANT	\N	PRESENT	0
653489	651593	17023S	PARTICIPANT	\N	PRESENT	0
653490	651593	20094J	PARTICIPANT	\N	PRESENT	0
653501	651593	14281W	PARTICIPANT	\N	PRESENT	0
653492	651593	19647E	PARTICIPANT	\N	PRESENT	0
653493	651593	11110B	PARTICIPANT	\N	PRESENT	0
653494	651593	04035D	PARTICIPANT	\N	PRESENT	0
653495	651593	20130U	PARTICIPANT	\N	PRESENT	0
653496	651593	19671E	PARTICIPANT	\N	PRESENT	0
653497	651593	14357A	PARTICIPANT	\N	PRESENT	0
653498	651593	19591F	PARTICIPANT	\N	PRESENT	0
653499	651593	19057M	PARTICIPANT	\N	PRESENT	0
653500	651593	19583F	PARTICIPANT	\N	PRESENT	0
653507	651593	19533U	PARTICIPANT	\N	PRESENT	0
653505	651593	01028R	PARTICIPANT	\N	PRESENT	0
653506	651593	11083R	PARTICIPANT	\N	PRESENT	0
653508	651593	17779H	PARTICIPANT	\N	PRESENT	0
653509	651593	20122U	PARTICIPANT	\N	PRESENT	0
653510	651593	14026U	PARTICIPANT	\N	PRESENT	0
653511	651593	07004J	PARTICIPANT	\N	PRESENT	0
653512	651593	20036X	PARTICIPANT	\N	PRESENT	0
653647	653646	19347U	PARTICIPANT	\N	PRESENT	0
653649	653646	01058X	PARTICIPANT	\N	PRESENT	0
653660	652897	20124W	PARTICIPANT	\N	PRESENT	0
653661	652897	12041X	PARTICIPANT	\N	PRESENT	0
653662	652897	01034P	PARTICIPANT	\N	PRESENT	0
653663	652897	19679N	PARTICIPANT	\N	PRESENT	0
629866	629865	11065P	PARTICIPANT	\N	PRESENT	0
629867	629865	19619A	PARTICIPANT	\N	PRESENT	0
629868	629865	19251M	PARTICIPANT	\N	PRESENT	0
629869	629865	20076G	PARTICIPANT	\N	PRESENT	0
629870	629865	19637C	PARTICIPANT	\N	PRESENT	0
629871	629865	19503N	PARTICIPANT	\N	PRESENT	0
630440	630439	14173T	PARTICIPANT	\N	PRESENT	0
630441	630439	01043Q	PARTICIPANT	\N	PRESENT	0
630442	630439	20062A	PARTICIPANT	\N	PRESENT	0
632811	632810	14237S	PARTICIPANT	\N	PRESENT	0
632812	632810	20056C	PARTICIPANT	\N	PRESENT	0
632813	632810	20044X	PARTICIPANT	\N	PRESENT	0
632814	632810	20058E	PARTICIPANT	\N	PRESENT	0
632815	632810	97011G	PARTICIPANT	\N	PRESENT	0
632816	632810	19631V	PARTICIPANT	\N	PRESENT	0
632817	632810	14107H	PARTICIPANT	\N	PRESENT	0
632818	632810	19575F	PARTICIPANT	\N	PRESENT	0
632819	632810	20018V	PARTICIPANT	\N	PRESENT	0
632820	632810	20066E	PARTICIPANT	\N	PRESENT	0
632908	631111	14026U	PARTICIPANT	\N	PRESENT	0
634039	634038	19629C	PARTICIPANT	\N	PRESENT	0
634040	634038	14038Y	PARTICIPANT	\N	PRESENT	0
634041	634038	19575F	PARTICIPANT	\N	PRESENT	0
634042	634038	19782L	PARTICIPANT	\N	PRESENT	0
634043	634038	19725B	PARTICIPANT	\N	PRESENT	0
634044	634038	14179A	PARTICIPANT	\N	PRESENT	1
634046	634038	19563B	PARTICIPANT	\N	PRESENT	0
634047	634038	20028X	PARTICIPANT	\N	PRESENT	1
634054	634053	19515S	PARTICIPANT	\N	PRESENT	0
634055	634053	19693L	PARTICIPANT	\N	PRESENT	0
634056	634053	14213J	PARTICIPANT	\N	PRESENT	1
634057	634053	20066E	PARTICIPANT	\N	PRESENT	0
634058	634053	20126Y	PARTICIPANT	\N	PRESENT	1
634059	634053	20050V	PARTICIPANT	\N	PRESENT	0
634060	634053	20082E	PARTICIPANT	\N	PRESENT	0
634626	634625	01028R	PARTICIPANT	\N	PRESENT	0
634627	634625	19687N	PARTICIPANT	\N	PRESENT	0
634628	634625	14073Q	PARTICIPANT	\N	PRESENT	0
634629	634625	14179A	PARTICIPANT	\N	PRESENT	0
634630	634625	19647E	PARTICIPANT	\N	PRESENT	0
634632	634631	14073Q	PARTICIPANT	\N	PRESENT	0
634633	634631	14229S	PARTICIPANT	\N	PRESENT	0
634634	634631	01028R	PARTICIPANT	\N	PRESENT	0
634636	634635	20050V	PARTICIPANT	\N	PRESENT	0
634638	634637	20082E	PARTICIPANT	\N	PRESENT	0
634639	634637	20050V	PARTICIPANT	\N	PRESENT	0
634640	634637	20074E	PARTICIPANT	\N	PRESENT	0
634641	634637	14213J	PARTICIPANT	\N	PRESENT	0
638298	637893	14259Y	PARTICIPANT	\N	PRESENT	0
638299	637893	01060R	PARTICIPANT	\N	PRESENT	0
638311	638310	04042C	PARTICIPANT	\N	PRESENT	0
638312	638310	01062T	PARTICIPANT	\N	PRESENT	0
638313	638310	11064N	PARTICIPANT	\N	PRESENT	0
638314	638310	19443T	PARTICIPANT	\N	PRESENT	0
638315	638310	20064C	PARTICIPANT	\N	PRESENT	0
638317	638316	04033B	PARTICIPANT	\N	PRESENT	0
638318	638316	19954N	PARTICIPANT	\N	PRESENT	0
638319	638316	17737W	PARTICIPANT	\N	PRESENT	0
638320	638316	14215L	PARTICIPANT	\N	PRESENT	0
638321	638316	97011G	PARTICIPANT	\N	PRESENT	0
638322	638316	20038A	PARTICIPANT	\N	PRESENT	0
638323	638316	19447X	PARTICIPANT	\N	PRESENT	0
638324	638316	08015R	PARTICIPANT	\N	PRESENT	0
638325	638316	19711U	PARTICIPANT	\N	PRESENT	0
638326	638316	16685X	PARTICIPANT	\N	PRESENT	0
638327	638316	11043H	PARTICIPANT	\N	PRESENT	0
638328	638316	01058X	PARTICIPANT	\N	PRESENT	0
638383	638382	05008E	PARTICIPANT	\N	PRESENT	0
638384	638382	11053K	PARTICIPANT	\N	PRESENT	0
638385	638382	01028R	PARTICIPANT	\N	PRESENT	0
638390	638389	14281W	PARTICIPANT	\N	PRESENT	0
638391	638389	19697Q	PARTICIPANT	\N	PRESENT	0
638392	638389	19679N	PARTICIPANT	\N	PRESENT	0
638393	635821	14281W	PARTICIPANT	\N	PRESENT	0
638394	635821	19697Q	PARTICIPANT	\N	PRESENT	0
638399	638398	20024T	PARTICIPANT	\N	PRESENT	0
638400	638398	19515S	PARTICIPANT	\N	PRESENT	0
638402	638401	20024T	PARTICIPANT	\N	PRESENT	0
638405	638404	20140W	PARTICIPANT	\N	PRESENT	0
638406	638404	19515S	PARTICIPANT	\N	PRESENT	0
638407	638404	20024T	PARTICIPANT	\N	PRESENT	0
638426	638425	11053K	PARTICIPANT	\N	PRESENT	0
638427	638425	19693L	PARTICIPANT	\N	PRESENT	0
638428	638425	20120S	PARTICIPANT	\N	PRESENT	0
638429	638425	11026G	PARTICIPANT	\N	PRESENT	0
638430	638425	08010L	PARTICIPANT	\N	PRESENT	0
638431	638425	19479G	PARTICIPANT	\N	PRESENT	0
638432	638425	04043D	PARTICIPANT	\N	PRESENT	1
638433	638425	11074Q	PARTICIPANT	\N	PRESENT	0
638435	638434	20024T	PARTICIPANT	\N	PRESENT	0
638436	638434	20080C	PARTICIPANT	\N	PRESENT	0
638437	638434	14083S	PARTICIPANT	\N	PRESENT	0
638438	638434	20106U	PARTICIPANT	\N	PRESENT	1
638439	638434	05012A	PARTICIPANT	\N	PRESENT	0
638440	638434	14255U	PARTICIPANT	\N	PRESENT	0
638447	638446	14089Y	PARTICIPANT	\N	PRESENT	0
638448	638446	11026G	PARTICIPANT	\N	PRESENT	0
638449	638446	14053L	PARTICIPANT	\N	PRESENT	0
638450	638446	19749K	PARTICIPANT	\N	PRESENT	0
638451	638446	20040T	PARTICIPANT	\N	PRESENT	0
638452	638442	20050V	PARTICIPANT	\N	PRESENT	0
638453	638442	20074E	PARTICIPANT	\N	PRESENT	1
638454	638442	14213J	PARTICIPANT	\N	PRESENT	1
638455	638443	20082E	PARTICIPANT	\N	PRESENT	0
638456	638443	20050V	PARTICIPANT	\N	PRESENT	0
638457	638443	19369B	PARTICIPANT	\N	EXCUSE	0
638458	638444	20082E	PARTICIPANT	\N	PRESENT	0
638459	638444	19693L	PARTICIPANT	\N	PRESENT	1
638460	638444	14097Y	PARTICIPANT	\N	PRESENT	0
638461	638444	20050V	PARTICIPANT	\N	PRESENT	0
638462	638444	14213J	PARTICIPANT	\N	PRESENT	1
638517	638515	19693L	PARTICIPANT	\N	PRESENT	0
638518	638515	19533U	PARTICIPANT	\N	PRESENT	0
638519	638515	11067R	PARTICIPANT	\N	PRESENT	0
638520	638515	04043D	PARTICIPANT	\N	PRESENT	0
638521	638515	01058X	PARTICIPANT	\N	PRESENT	0
638524	638515	01048V	PARTICIPANT	\N	PRESENT	0
638621	637808	14189C	PARTICIPANT	\N	EXCUSE	0
638622	637808	14030Q	PRESIDENT	0	PRESENT	0
638623	637808	19693L	PARTICIPANT	\N	PRESENT	0
638624	637808	07029T	PARTICIPANT	\N	EXCUSE	0
638625	637808	14109K	PARTICIPANT	\N	PRESENT	1
638626	637808	20118Y	PARTICIPANT	\N	EXCUSE	0
638627	637808	20040T	PARTICIPANT	\N	PRESENT	0
638630	637808	14031R	PARTICIPANT	\N	PRESENT	1
638636	637808	20094J	PARTICIPANT	\N	PRESENT	0
638656	637808	16685X	PARTICIPANT	\N	PRESENT	0
638718	638464	20074E	PARTICIPANT	\N	PRESENT	0
638759	638758	19782L	PARTICIPANT	\N	PRESENT	0
638760	638758	14038Y	PARTICIPANT	\N	PRESENT	0
638761	638758	20028X	PARTICIPANT	\N	PRESENT	0
638762	638758	20092G	PARTICIPANT	\N	PRESENT	0
638763	638758	19629C	PARTICIPANT	\N	PRESENT	0
638764	638758	14187A	PARTICIPANT	\N	PRESENT	0
638765	638758	19725B	PARTICIPANT	\N	PRESENT	0
638766	638758	14179A	PARTICIPANT	\N	PRESENT	0
638767	638758	14147R	PARTICIPANT	\N	PRESENT	0
638771	638770	14281W	PARTICIPANT	\N	PRESENT	0
638772	638770	19679N	PARTICIPANT	\N	PRESENT	0
638773	638770	19697Q	PARTICIPANT	\N	PRESENT	0
638775	638774	19697Q	PARTICIPANT	\N	PRESENT	0
638776	638774	19679N	PARTICIPANT	\N	PRESENT	0
638777	638774	14281W	PARTICIPANT	\N	PRESENT	0
638890	638889	11048N	PARTICIPANT	\N	PRESENT	0
638892	638889	11040E	PARTICIPANT	\N	PRESENT	0
638893	638889	20070A	PARTICIPANT	\N	PRESENT	1
638894	638889	19711U	PARTICIPANT	\N	PRESENT	0
638895	638889	20252E	PARTICIPANT	\N	PRESENT	0
638896	638889	14225N	PARTICIPANT	\N	PRESENT	0
638897	638889	19762G	PARTICIPANT	\N	PRESENT	0
638898	638889	19689Q	PARTICIPANT	\N	PRESENT	0
638899	638889	19479G	PARTICIPANT	\N	PRESENT	1
649726	649090	19479G	PARTICIPANT	\N	PRESENT	0
649727	649090	11048N	PARTICIPANT	\N	PRESENT	0
649728	649090	01057W	PARTICIPANT	\N	PRESENT	0
649729	649090	08010L	PARTICIPANT	\N	PRESENT	0
649730	649090	20914V	PARTICIPANT	\N	PRESENT	0
649731	649090	20044X	PARTICIPANT	\N	PRESENT	0
649732	649090	14225N	PRESIDENT	0	PRESENT	0
649733	649090	20086J	PARTICIPANT	\N	PRESENT	0
649734	649090	19349W	PARTICIPANT	\N	PRESENT	0
649735	649090	20116W	PARTICIPANT	\N	PRESENT	0
649736	649090	14327T	PRESIDENT	1	PRESENT	0
649737	649090	20252E	PARTICIPANT	\N	PRESENT	0
649738	649090	99004R	PARTICIPANT	\N	PRESENT	0
649739	649090	14083S	PARTICIPANT	\N	PRESENT	0
649740	649090	19671E	PARTICIPANT	\N	PRESENT	0
649744	649090	19711U	PARTICIPANT	\N	PRESENT	0
649745	649090	11053K	PARTICIPANT	\N	PRESENT	0
649746	649090	20050V	PARTICIPANT	\N	PRESENT	0
649755	649090	20080C	PARTICIPANT	\N	PRESENT	0
649766	649090	14189C	PARTICIPANT	\N	PRESENT	0
649769	649090	19762G	PARTICIPANT	\N	PRESENT	0
649777	649090	19667J	PARTICIPANT	\N	PRESENT	0
649780	647959	20038A	PARTICIPANT	\N	PRESENT	0
649781	647959	20140W	PARTICIPANT	\N	PRESENT	0
649782	647959	20076G	PARTICIPANT	\N	PRESENT	0
649783	647959	19387D	PARTICIPANT	\N	PRESENT	0
649784	647959	19251M	PARTICIPANT	\N	PRESENT	0
649785	647959	14219Q	PRESIDENT	0	PRESENT	0
649786	647959	19826F	PARTICIPANT	\N	PRESENT	0
649787	647959	20046A	PARTICIPANT	\N	PRESENT	0
649788	647959	20102Q	PARTICIPANT	\N	PRESENT	0
649789	647959	18083K	PARTICIPANT	\N	PRESENT	0
649790	647959	20100N	PARTICIPANT	\N	PRESENT	0
649791	647959	19503N	PARTICIPANT	\N	PRESENT	0
649792	647959	19739H	PARTICIPANT	\N	PRESENT	0
649793	647959	19745F	PARTICIPANT	\N	PRESENT	0
649794	647959	17367Q	PARTICIPANT	\N	PRESENT	0
649795	647959	20024T	PARTICIPANT	\N	PRESENT	0
649796	647959	20120S	PARTICIPANT	\N	PRESENT	0
649800	647959	20118Y	PARTICIPANT	\N	PRESENT	0
649801	649090	20070A	PARTICIPANT	\N	PRESENT	0
649802	647959	14169X	PARTICIPANT	\N	PRESENT	0
649850	647959	19525U	PARTICIPANT	\N	PRESENT	0
649804	649090	19741B	PARTICIPANT	\N	PRESENT	0
649805	649090	14331P	PARTICIPANT	\N	PRESENT	0
649808	649725	19383Y	PARTICIPANT	\N	PRESENT	0
649809	649725	19768N	PARTICIPANT	\N	PRESENT	0
649810	649725	19515S	PARTICIPANT	\N	PRESENT	0
649811	649725	20092G	PARTICIPANT	\N	PRESENT	0
649812	649725	19782L	PARTICIPANT	\N	PRESENT	0
649813	649725	14357A	PARTICIPANT	\N	PRESENT	0
649814	649725	19441R	PARTICIPANT	\N	PRESENT	0
649815	649725	20078J	PARTICIPANT	\N	PRESENT	0
649816	649725	20082E	PARTICIPANT	\N	PRESENT	0
649817	649725	19866P	PARTICIPANT	\N	PRESENT	0
649818	649725	04045F	PARTICIPANT	\N	PRESENT	1
649819	649725	19631V	PARTICIPANT	\N	PRESENT	0
649820	649725	08015R	PARTICIPANT	\N	PRESENT	0
649821	649725	19575F	PARTICIPANT	\N	PRESENT	0
649822	649725	19369B	PARTICIPANT	\N	PRESENT	0
649823	649725	20018V	PARTICIPANT	\N	PRESENT	0
649824	649725	19511N	PARTICIPANT	\N	PRESENT	0
649825	649725	08028W	PARTICIPANT	\N	PRESENT	0
649826	649725	19563B	PARTICIPANT	\N	PRESENT	0
649827	649725	20028X	PARTICIPANT	\N	PRESENT	0
649828	649725	14329V	PARTICIPANT	\N	PRESENT	0
649829	649725	14038Y	PARTICIPANT	\N	PRESENT	0
649830	649725	19467C	PARTICIPANT	\N	PRESENT	0
649831	649725	20034V	PARTICIPANT	\N	PRESENT	0
649832	649725	14187A	PRESIDENT	0	PRESENT	0
650186	648783	19543W	PARTICIPANT	\N	PRESENT	0
649834	649725	14033T	PARTICIPANT	\N	PRESENT	0
649835	649725	20054A	PARTICIPANT	\N	PRESENT	0
649836	649725	14205J	PARTICIPANT	\N	PRESENT	0
649837	649725	20062A	PARTICIPANT	\N	PRESENT	0
649838	649725	19507S	PARTICIPANT	\N	PRESENT	0
649839	649725	20286Q	PARTICIPANT	\N	PRESENT	0
649840	649725	14207L	PARTICIPANT	\N	PRESENT	0
649841	649725	19747H	PARTICIPANT	\N	PRESENT	0
649842	649725	14257W	PARTICIPANT	\N	PRESENT	0
649847	649090	11074Q	PARTICIPANT	\N	PRESENT	0
649851	649090	12016W	PARTICIPANT	\N	PRESENT	0
649853	648781	14053L	PARTICIPANT	\N	PRESENT	0
649854	648781	20074E	PARTICIPANT	\N	PRESENT	0
649855	648781	11026G	PARTICIPANT	\N	PRESENT	0
649856	648781	04047H	PRESIDENT	0	PRESENT	0
649857	648781	11033F	PARTICIPANT	\N	PRESENT	0
649858	648781	01028R	PARTICIPANT	\N	PRESENT	0
649859	648781	05008E	PARTICIPANT	\N	PRESENT	0
649860	648781	19447X	PARTICIPANT	\N	PRESENT	0
649861	648781	14231L	PARTICIPANT	\N	PRESENT	0
649862	648781	14089Y	PARTICIPANT	\N	PRESENT	0
649863	648781	11056N	PARTICIPANT	\N	PRESENT	0
649864	648781	19729F	PARTICIPANT	\N	PRESENT	0
649865	648781	14275Y	PARTICIPANT	\N	PRESENT	0
649866	648781	20108W	PARTICIPANT	\N	PRESENT	0
649867	648781	14179A	PARTICIPANT	\N	PRESENT	0
649868	648781	14151M	PARTICIPANT	\N	PRESENT	0
649869	648781	14069U	PARTICIPANT	\N	PRESENT	0
649870	648781	14215L	PARTICIPANT	\N	PRESENT	0
649871	648781	14259Y	PARTICIPANT	\N	PRESENT	0
649872	648781	20022R	PARTICIPANT	\N	PRESENT	0
649990	649090	14179A	PARTICIPANT	\N	PRESENT	0
649991	648781	19649G	PARTICIPANT	\N	PRESENT	0
649992	648781	95063L	PARTICIPANT	\N	PRESENT	0
649993	648782	14053L	PARTICIPANT	\N	PRESENT	0
649994	648782	19649G	PARTICIPANT	\N	PRESENT	0
649995	648782	20074E	PARTICIPANT	\N	PRESENT	0
649996	648782	11026G	PARTICIPANT	\N	PRESENT	0
649997	648782	19543W	PARTICIPANT	\N	PRESENT	0
649998	648782	19581D	PARTICIPANT	\N	PRESENT	0
649999	648782	04047H	PRESIDENT	0	PRESENT	0
650000	648782	11033F	PARTICIPANT	\N	PRESENT	0
650001	648782	19447X	PARTICIPANT	\N	PRESENT	0
650002	648782	14231L	PARTICIPANT	\N	PRESENT	0
650003	648782	19729F	PARTICIPANT	\N	PRESENT	0
650004	648782	19489J	PARTICIPANT	\N	PRESENT	0
650005	648782	95063L	PARTICIPANT	\N	PRESENT	0
650006	648782	20108W	PARTICIPANT	\N	PRESENT	0
650007	648782	20110Q	PARTICIPANT	\N	PRESENT	0
650008	648782	14151M	PARTICIPANT	\N	PRESENT	0
650009	648782	20114U	PARTICIPANT	\N	PRESENT	0
650010	648782	14215L	PARTICIPANT	\N	PRESENT	0
650011	648782	08018U	PARTICIPANT	\N	PRESENT	0
650012	648782	20022R	PARTICIPANT	\N	PRESENT	0
650013	648782	19749K	PARTICIPANT	\N	PRESENT	0
650014	648782	19725B	PARTICIPANT	\N	EXCUSE	0
650015	647948	14123H	PARTICIPANT	\N	PRESENT	0
650016	647948	11104D	PARTICIPANT	\N	PRESENT	1
650017	648782	14001X	PARTICIPANT	\N	PRESENT	0
650019	649090	20126Y	PARTICIPANT	\N	PRESENT	0
650187	648783	01028R	PARTICIPANT	\N	PRESENT	0
650188	648783	05008E	PARTICIPANT	\N	PRESENT	0
650189	648783	14089Y	PARTICIPANT	\N	PRESENT	0
650190	648783	19729F	PARTICIPANT	\N	PRESENT	0
650191	648783	95063L	PARTICIPANT	\N	PRESENT	1
650192	648783	14151M	PARTICIPANT	\N	PRESENT	0
650193	648783	14215L	PARTICIPANT	\N	PRESENT	0
650194	648783	20022R	PARTICIPANT	\N	PRESENT	0
650195	648783	14259Y	PARTICIPANT	\N	PRESENT	0
650196	648783	11072N	PARTICIPANT	\N	PRESENT	0
650197	648783	11056N	PARTICIPANT	\N	PRESENT	0
650206	649162	17589D	PARTICIPANT	\N	PRESENT	0
650207	649162	19826F	PARTICIPANT	\N	PRESENT	0
650208	649162	01025N	PARTICIPANT	\N	PRESENT	0
650225	648783	11033F	PARTICIPANT	\N	PRESENT	0
650226	649162	19866P	PARTICIPANT	\N	PRESENT	0
650227	649162	14267Y	PARTICIPANT	\N	PRESENT	0
650228	649162	12016W	PARTICIPANT	\N	PRESENT	0
650229	649162	20112S	PARTICIPANT	\N	PRESENT	0
650230	649162	20032T	PARTICIPANT	\N	PRESENT	0
650231	649162	20062A	PARTICIPANT	\N	PRESENT	0
650232	649162	14191V	PARTICIPANT	\N	PRESENT	0
650233	649162	14275Y	PARTICIPANT	\N	PRESENT	0
650234	649162	11103C	PARTICIPANT	\N	PRESENT	0
650235	649162	14105F	PARTICIPANT	\N	PRESENT	0
650236	649162	19593H	PARTICIPANT	\N	PRESENT	0
650237	649162	19387D	PARTICIPANT	\N	PRESENT	0
650238	649162	19766L	PARTICIPANT	\N	PRESENT	0
650239	649162	14033T	PARTICIPANT	\N	PRESENT	0
650240	649162	20068G	PARTICIPANT	\N	PRESENT	0
631718	629386	19399H	PARTICIPANT	\N	EXCUSE	0
631719	629386	20122U	PARTICIPANT	\N	PRESENT	0
640631	640514	19415P	PARTICIPANT	\N	PRESENT	0
640632	640514	11067R	PARTICIPANT	\N	PRESENT	0
640639	640515	19415P	PARTICIPANT	\N	PRESENT	0
640637	640514	20130U	PARTICIPANT	\N	PRESENT	1
640638	640514	14223L	PARTICIPANT	\N	PRESENT	1
640640	640515	11067R	PARTICIPANT	\N	PRESENT	0
640646	640517	20130U	PARTICIPANT	\N	PRESENT	1
640647	640517	11067R	PARTICIPANT	\N	PRESENT	0
640648	640517	19415P	PARTICIPANT	\N	PRESENT	0
640649	640516	19415P	PARTICIPANT	\N	PRESENT	0
640650	640516	11067R	PARTICIPANT	\N	PRESENT	0
640673	639945	20070A	PARTICIPANT	\N	PRESENT	1
640674	639945	01057W	PARTICIPANT	\N	PRESENT	1
640675	639945	14121F	PARTICIPANT	\N	PRESENT	1
640676	639945	20126Y	PARTICIPANT	\N	PRESENT	1
640677	639945	19349W	PARTICIPANT	\N	PRESENT	1
640678	639945	11012A	PARTICIPANT	\N	PRESENT	1
640687	640686	20286Q	PARTICIPANT	\N	PRESENT	0
640688	640686	14257W	PARTICIPANT	\N	PRESENT	0
640689	640686	11090Q	PARTICIPANT	\N	PRESENT	0
640695	640694	11090Q	PARTICIPANT	\N	PRESENT	0
640696	640694	20286Q	PARTICIPANT	\N	PRESENT	0
640697	640694	14257W	PARTICIPANT	\N	PRESENT	0
641706	641705	14231L	PARTICIPANT	\N	PRESENT	0
643059	643057	11027H	PARTICIPANT	\N	PRESENT	0
642026	642025	19695N	PARTICIPANT	\N	PRESENT	0
642027	642025	20094J	PARTICIPANT	\N	PRESENT	0
642028	642025	01025N	PARTICIPANT	\N	PRESENT	0
642030	642029	19695N	PARTICIPANT	\N	PRESENT	0
642031	642029	01025N	PARTICIPANT	\N	PRESENT	0
642033	642032	19695N	PARTICIPANT	\N	PRESENT	0
642034	642032	01025N	PARTICIPANT	\N	PRESENT	0
642037	642036	19701S	PARTICIPANT	\N	PRESENT	0
643058	643057	04042C	PARTICIPANT	\N	PRESENT	0
643060	643057	12041X	PARTICIPANT	\N	PRESENT	0
643067	643066	04047H	PARTICIPANT	\N	PRESENT	0
643068	643066	14053L	PARTICIPANT	\N	PRESENT	0
643069	643066	11066Q	PARTICIPANT	\N	PRESENT	0
643387	643385	08073C	PARTICIPANT	\N	PRESENT	0
643388	643385	20150Y	PARTICIPANT	\N	PRESENT	0
643389	643065	14253S	PARTICIPANT	\N	PRESENT	0
643390	643065	08011M	PARTICIPANT	\N	PRESENT	0
643823	643653	11067R	PARTICIPANT	\N	PRESENT	0
643824	643653	20248J	PARTICIPANT	\N	EXCUSE	0
643825	643653	19367Y	PARTICIPANT	\N	EXCUSE	0
643830	643653	19798U	PARTICIPANT	\N	PRESENT	1
643842	643653	19723Y	PARTICIPANT	\N	PRESENT	0
643871	643653	19715Y	PARTICIPANT	\N	PRESENT	1
643874	643653	19415P	PARTICIPANT	\N	PRESENT	0
643887	643653	19657G	PARTICIPANT	\N	PRESENT	1
644518	644517	19643A	PARTICIPANT	\N	PRESENT	0
644519	644517	20132W	PARTICIPANT	\N	PRESENT	0
644521	644520	19643A	PARTICIPANT	\N	PRESENT	0
644522	644520	20132W	PARTICIPANT	\N	PRESENT	0
644524	644523	14097Y	PARTICIPANT	\N	PRESENT	0
644525	644523	10015M	PARTICIPANT	\N	PRESENT	0
644865	644864	19701S	PARTICIPANT	\N	PRESENT	0
645015	645014	19533U	PARTICIPANT	\N	PRESENT	1
644867	644864	04042C	PARTICIPANT	\N	PRESENT	0
645003	644650	19673G	PARTICIPANT	\N	EXCUSE	0
645016	645014	19643A	PARTICIPANT	\N	PRESENT	0
645017	645014	20132W	PARTICIPANT	\N	PRESENT	0
645018	645014	14147R	PARTICIPANT	\N	PRESENT	1
645019	645014	14179A	PARTICIPANT	\N	PRESENT	1
645020	645014	19651A	PARTICIPANT	\N	PRESENT	1
645021	645014	19725B	PARTICIPANT	\N	PRESENT	0
645022	645014	19447X	PARTICIPANT	\N	PRESENT	0
645025	643942	11109J	PARTICIPANT	\N	EXCUSE	0
645026	643944	11109J	PARTICIPANT	\N	EXCUSE	0
645027	644650	05008E	PARTICIPANT	\N	EXCUSE	0
645029	645028	19593H	PARTICIPANT	\N	PRESENT	0
645030	645028	20026V	PARTICIPANT	\N	PRESENT	1
645228	645202	19333N	PARTICIPANT	\N	PRESENT	0
645229	645202	19826F	PARTICIPANT	\N	PRESENT	0
645230	645202	19503N	PARTICIPANT	\N	PRESENT	0
645231	645202	17023S	PARTICIPANT	\N	PRESENT	0
645232	645202	19447X	PARTICIPANT	\N	PRESENT	0
645233	645202	20100N	PARTICIPANT	\N	PRESENT	0
645234	645145	20024T	PARTICIPANT	\N	PRESENT	0
645235	645145	20022R	PARTICIPANT	\N	PRESENT	0
645236	645145	11033F	PARTICIPANT	\N	PRESENT	1
645237	645145	17737W	PARTICIPANT	\N	PRESENT	1
645238	645145	04047H	PARTICIPANT	\N	PRESENT	0
645239	645145	11056N	PARTICIPANT	\N	PRESENT	1
645240	645145	20074E	PARTICIPANT	\N	PRESENT	0
645241	645145	14179A	PARTICIPANT	\N	PRESENT	0
645242	645145	19489J	PARTICIPANT	\N	PRESENT	1
645243	645145	19649G	PARTICIPANT	\N	PRESENT	1
645244	645145	14111D	PARTICIPANT	\N	PRESENT	0
645245	645145	14147R	PARTICIPANT	\N	PRESENT	1
645246	645145	01028R	PARTICIPANT	\N	PRESENT	0
645247	645145	19585H	PARTICIPANT	\N	PRESENT	0
645248	644854	19760E	PARTICIPANT	\N	PRESENT	0
645249	644854	11067R	PARTICIPANT	\N	PRESENT	0
645250	644854	19735D	PARTICIPANT	\N	PRESENT	0
645251	644854	11103C	PARTICIPANT	\N	PRESENT	1
645252	644854	19697Q	PARTICIPANT	\N	PRESENT	1
645253	644854	19657G	PARTICIPANT	\N	PRESENT	0
645254	644854	19569H	PARTICIPANT	\N	PRESENT	0
645255	644854	19691J	PARTICIPANT	\N	PRESENT	1
645257	644854	14355X	PARTICIPANT	\N	PRESENT	0
645258	644854	20090E	PARTICIPANT	\N	PRESENT	0
645259	644854	19367Y	PARTICIPANT	\N	PRESENT	0
645260	644854	19723Y	PARTICIPANT	\N	PRESENT	0
645261	644854	20040T	PARTICIPANT	\N	PRESENT	0
645262	644854	19415P	PARTICIPANT	\N	PRESENT	0
645263	644854	11097X	PARTICIPANT	\N	PRESENT	0
645264	644854	19703U	PARTICIPANT	\N	PRESENT	0
645267	644854	19663E	PARTICIPANT	\N	PRESENT	0
645268	644854	14026U	PARTICIPANT	\N	PRESENT	0
645271	644854	14213J	PARTICIPANT	\N	PRESENT	0
645274	645202	20096L	PARTICIPANT	\N	PRESENT	0
645275	644854	11031D	PARTICIPANT	\N	PRESENT	0
645288	644949	14331P	PRESIDENT	0	PRESENT	0
645289	644949	19701S	PARTICIPANT	\N	PRESENT	0
645290	644949	14001X	PARTICIPANT	\N	PRESENT	1
645291	644949	10015M	PARTICIPANT	\N	PRESENT	0
645292	644949	14133K	PARTICIPANT	\N	PRESENT	0
645293	644949	11026G	PARTICIPANT	\N	PRESENT	0
645294	644949	04057K	PARTICIPANT	\N	PRESENT	0
645295	644949	12041X	PARTICIPANT	\N	PRESENT	0
645296	644949	19333N	PARTICIPANT	\N	PRESENT	0
645297	644949	20104S	PARTICIPANT	\N	PRESENT	0
645298	644949	08034U	PARTICIPANT	\N	PRESENT	0
645299	644949	20286Q	PARTICIPANT	\N	PRESENT	1
645300	644949	14189C	PARTICIPANT	\N	EXCUSE	0
645301	644949	19531S	PARTICIPANT	\N	EXCUSE	0
645302	644949	19563B	PARTICIPANT	\N	EXCUSE	0
645309	644949	14089Y	PARTICIPANT	\N	PRESENT	0
645310	644949	04045F	PARTICIPANT	\N	PRESENT	1
645311	644949	20128B	PARTICIPANT	\N	PRESENT	1
645461	645147	20058E	PARTICIPANT	\N	PRESENT	0
645462	645147	20024T	PARTICIPANT	\N	PRESENT	0
645463	645147	04047H	PARTICIPANT	\N	PRESENT	0
645464	645147	04085P	PARTICIPANT	\N	PRESENT	0
645465	645147	20022R	PARTICIPANT	\N	PRESENT	0
645466	645147	11033F	PARTICIPANT	\N	PRESENT	0
645467	645147	20074E	PARTICIPANT	\N	PRESENT	0
645468	645147	14021P	PARTICIPANT	\N	PRESENT	0
645469	645147	19649G	PARTICIPANT	\N	PRESENT	1
645470	645147	14147R	PARTICIPANT	\N	PRESENT	1
645471	645147	95063L	PARTICIPANT	\N	PRESENT	0
645472	645146	20112S	PARTICIPANT	\N	PRESENT	1
645473	645146	20024T	PARTICIPANT	\N	PRESENT	0
645474	645146	20026V	PARTICIPANT	\N	PRESENT	1
645475	645146	20058E	PARTICIPANT	\N	PRESENT	0
645476	645146	19533U	PARTICIPANT	\N	PRESENT	0
645477	645146	19699S	PARTICIPANT	\N	PRESENT	0
645478	645146	20056C	PARTICIPANT	\N	PRESENT	0
645479	645146	04047H	PARTICIPANT	\N	PRESENT	0
645480	645146	04085P	PARTICIPANT	\N	PRESENT	0
645481	645146	20022R	PARTICIPANT	\N	PRESENT	0
645482	645146	11033F	PARTICIPANT	\N	PRESENT	0
645483	645146	20074E	PARTICIPANT	\N	PRESENT	0
645484	645146	14179A	PARTICIPANT	\N	PRESENT	1
645485	645146	14021P	PARTICIPANT	\N	PRESENT	0
645486	645146	19649G	PARTICIPANT	\N	PRESENT	1
666197	664672	19301E	PARTICIPANT	\N	EXCUSE	0
666199	664672	19585H	PARTICIPANT	\N	EXCUSE	0
666410	664672	04059M	PARTICIPANT	\N	PRESENT	0
666411	664672	20112S	PARTICIPANT	\N	PRESENT	0
666412	664672	19651A	PARTICIPANT	\N	PRESENT	0
666413	664672	14030Q	PARTICIPANT	\N	PRESENT	0
666414	664672	19643A	PARTICIPANT	\N	PRESENT	0
666415	664672	20134Y	PARTICIPANT	\N	PRESENT	0
666416	664672	20124W	PARTICIPANT	\N	PRESENT	0
666417	664672	20132W	PARTICIPANT	\N	PRESENT	0
666418	664672	20172F	PARTICIPANT	\N	PRESENT	0
666419	664672	20180F	PARTICIPANT	\N	PRESENT	0
666420	664672	19399H	PARTICIPANT	\N	PRESENT	0
666421	664672	20056C	PARTICIPANT	\N	PRESENT	0
666422	664672	14073Q	PARTICIPANT	\N	PRESENT	0
666423	664672	19611R	PARTICIPANT	\N	PRESENT	0
666424	664672	19699S	PARTICIPANT	\N	PRESENT	0
666425	664672	20052X	PARTICIPANT	\N	PRESENT	0
666426	664672	08012N	PARTICIPANT	\N	PRESENT	0
666427	664672	11104D	PARTICIPANT	\N	PRESENT	0
666428	664672	20142Y	PARTICIPANT	\N	PRESENT	0
666429	664672	19593H	PARTICIPANT	\N	PRESENT	0
666430	664672	19573D	PARTICIPANT	\N	PRESENT	0
666431	664672	19533U	PARTICIPANT	\N	PRESENT	0
666432	664672	14229S	PARTICIPANT	\N	PRESENT	0
666433	664672	11043H	PARTICIPANT	\N	PRESENT	0
666434	664672	20084G	PARTICIPANT	\N	PRESENT	0
666435	664672	19527W	PARTICIPANT	\N	PRESENT	0
666436	664672	20026V	PARTICIPANT	\N	PRESENT	0
666437	664672	20058E	PARTICIPANT	\N	PRESENT	0
667736	667735	19553Y	PARTICIPANT	\N	PRESENT	0
667737	667735	14213J	PARTICIPANT	\N	PRESENT	0
667739	667738	20124W	PARTICIPANT	\N	PRESENT	1
667740	667738	19735D	PARTICIPANT	\N	PRESENT	1
667741	667738	14030Q	PARTICIPANT	\N	PRESENT	1
670231	668918	17965H	PARTICIPANT	\N	PRESENT	0
670232	668918	11067R	PARTICIPANT	\N	PRESENT	0
670233	668918	11031D	PARTICIPANT	\N	PRESENT	0
670234	668918	14281W	PARTICIPANT	\N	PRESENT	0
670235	668918	14195A	PARTICIPANT	\N	PRESENT	0
670236	668918	20130U	PARTICIPANT	\N	PRESENT	0
670237	668918	19697Q	PARTICIPANT	\N	PRESENT	0
670238	668918	20066E	PARTICIPANT	\N	PRESENT	0
670239	668918	19367Y	PARTICIPANT	\N	PRESENT	0
670240	668918	01034P	PARTICIPANT	\N	PRESENT	0
670241	668918	14071N	PARTICIPANT	\N	PRESENT	0
670242	668918	19723Y	PARTICIPANT	\N	PRESENT	0
670243	668918	19703U	PARTICIPANT	\N	PRESENT	0
670244	668918	14217N	PARTICIPANT	\N	PRESENT	0
670245	668918	10006L	PRESIDENT	0	PRESENT	0
670246	668918	11097X	PARTICIPANT	\N	PRESENT	0
670247	668918	14213J	PARTICIPANT	\N	PRESENT	0
670248	668918	04043D	PARTICIPANT	\N	PRESENT	0
670249	668918	19569H	PARTICIPANT	\N	PRESENT	0
670250	668918	19553Y	PARTICIPANT	\N	PRESENT	0
670251	668918	14223L	PARTICIPANT	\N	PRESENT	0
670252	668918	20090E	PARTICIPANT	\N	PRESENT	0
670253	668918	20040T	PARTICIPANT	\N	PRESENT	0
670254	668918	19798U	PARTICIPANT	\N	PRESENT	0
670255	668918	19415P	PARTICIPANT	\N	PRESENT	0
670256	668918	19713W	PARTICIPANT	\N	PRESENT	0
670257	668918	19657G	PARTICIPANT	\N	PRESENT	0
670258	668918	14042U	PARTICIPANT	\N	PRESENT	0
670259	668918	11045K	PARTICIPANT	\N	PRESENT	0
670260	668918	18193Q	PARTICIPANT	\N	PRESENT	0
670261	668918	19760E	PARTICIPANT	\N	PRESENT	0
670262	668918	20148F	PARTICIPANT	\N	PRESENT	0
670263	668918	19679N	PARTICIPANT	\N	PRESENT	0
670264	668918	04092N	PARTICIPANT	\N	PRESENT	0
670653	670652	14211G	PARTICIPANT	\N	PRESENT	0
670655	670652	11083R	PARTICIPANT	\N	PRESENT	0
672222	669572	14331P	PARTICIPANT	\N	PRESENT	0
672223	669572	04047H	PRESIDENT	0	PRESENT	0
672224	669572	20110Q	PARTICIPANT	\N	PRESENT	0
672225	669572	14215L	PARTICIPANT	\N	PRESENT	0
672226	669572	14001X	PARTICIPANT	\N	PRESENT	0
672227	669572	10015M	PARTICIPANT	\N	PRESENT	0
672228	669572	20022R	PARTICIPANT	\N	PRESENT	0
672229	669572	11072N	PRESIDENT	1	PRESENT	0
672230	669572	95063L	PARTICIPANT	\N	PRESENT	0
672231	669572	20100N	PARTICIPANT	\N	PRESENT	0
672232	669572	04045F	PARTICIPANT	\N	PRESENT	0
672263	670027	01048V	PARTICIPANT	\N	PRESENT	0
672244	669572	14073Q	PARTICIPANT	\N	PRESENT	0
672267	670027	19503N	PARTICIPANT	\N	PRESENT	0
672268	670027	04043D	PARTICIPANT	\N	EXCUSE	0
672316	670027	20128B	PARTICIPANT	\N	PRESENT	0
672360	669898	19758L	PARTICIPANT	\N	PRESENT	0
672361	669898	19553Y	PARTICIPANT	\N	PRESENT	0
672362	669898	19691J	PARTICIPANT	\N	PRESENT	0
672363	669898	19515S	PARTICIPANT	\N	PRESENT	0
672364	669898	07004J	PARTICIPANT	\N	PRESENT	0
672365	669898	19697Q	PARTICIPANT	\N	PRESENT	0
672366	669898	04045F	PARTICIPANT	\N	PRESENT	0
672367	669898	20066E	PARTICIPANT	\N	PRESENT	0
672368	669898	14071N	PARTICIPANT	\N	PRESENT	0
672369	669898	14207L	PARTICIPANT	\N	PRESENT	0
672370	669898	19367Y	PARTICIPANT	\N	PRESENT	0
672371	669898	11067R	PARTICIPANT	\N	PRESENT	0
672372	669898	19693L	PARTICIPANT	\N	PRESENT	0
672373	669898	19673G	PARTICIPANT	\N	PRESENT	0
672374	669898	14042U	PARTICIPANT	\N	PRESENT	0
672375	669898	19399H	PARTICIPANT	\N	PRESENT	0
672376	669898	20092G	PARTICIPANT	\N	PRESENT	0
672377	669898	01058X	PARTICIPANT	\N	PRESENT	0
672378	669898	18193Q	PARTICIPANT	\N	PRESENT	0
672382	669898	10015M	PARTICIPANT	\N	PRESENT	0
672384	669898	20152B	PARTICIPANT	\N	PRESENT	0
672385	669898	19575F	PARTICIPANT	\N	PRESENT	0
672386	669560	08034U	PARTICIPANT	\N	PRESENT	0
672389	669898	01028R	PARTICIPANT	\N	PRESENT	0
672391	669898	14281W	PARTICIPANT	\N	PRESENT	0
672392	669898	19591F	PARTICIPANT	\N	PRESENT	0
672393	669898	20136B	PARTICIPANT	\N	PRESENT	0
672398	669898	08015R	PARTICIPANT	\N	PRESENT	0
672399	669898	20082E	PARTICIPANT	\N	PRESENT	0
672400	669898	20148F	PARTICIPANT	\N	PRESENT	0
672418	669898	08034U	PARTICIPANT	\N	PRESENT	0
672419	669898	19663E	PARTICIPANT	\N	PRESENT	0
672420	669898	11045K	PARTICIPANT	\N	PRESENT	0
672423	669898	14231L	PARTICIPANT	\N	PRESENT	0
672427	669898	19347U	PARTICIPANT	\N	PRESENT	0
672434	669898	19711U	PARTICIPANT	\N	PRESENT	0
672435	669898	01048V	PARTICIPANT	\N	PRESENT	0
672436	669898	14021P	PARTICIPANT	\N	PRESENT	0
672437	669898	19760E	PARTICIPANT	\N	PRESENT	0
672441	669898	19741B	PARTICIPANT	\N	PRESENT	0
672442	669898	19441R	PARTICIPANT	\N	PRESENT	0
672448	669898	17779H	PARTICIPANT	\N	PRESENT	0
658016	657790	20094J	PARTICIPANT	\N	PRESENT	0
658017	657790	19866P	PARTICIPANT	\N	PRESENT	0
658018	657790	04045F	PARTICIPANT	\N	PRESENT	0
658019	657790	19631V	PARTICIPANT	\N	PRESENT	0
658020	657790	19705W	PARTICIPANT	\N	PRESENT	0
658021	657790	08015R	PARTICIPANT	\N	PRESENT	0
658022	657790	19575F	PARTICIPANT	\N	PRESENT	0
658023	657790	19369B	PARTICIPANT	\N	PRESENT	0
658024	657790	20018V	PARTICIPANT	\N	PRESENT	0
658025	657790	19563B	PARTICIPANT	\N	PRESENT	0
658026	657790	08028W	PARTICIPANT	\N	PRESENT	0
658027	657790	20028X	PARTICIPANT	\N	PRESENT	0
658028	657790	14329V	PARTICIPANT	\N	PRESENT	0
658029	657790	14037X	PARTICIPANT	\N	PRESENT	0
658030	657790	20030R	PARTICIPANT	\N	PRESENT	0
658031	657790	19467C	PARTICIPANT	\N	PRESENT	0
658032	657790	20034V	PARTICIPANT	\N	PRESENT	0
658033	657790	14187A	PRESIDENT	0	PRESENT	0
658034	657790	20144B	PARTICIPANT	\N	PRESENT	0
658035	657790	19695N	PARTICIPANT	\N	PRESENT	0
658036	657790	14033T	PARTICIPANT	\N	PRESENT	0
658037	657790	20054A	PARTICIPANT	\N	PRESENT	0
658038	657790	14205J	PARTICIPANT	\N	PRESENT	0
658039	657790	20062A	PARTICIPANT	\N	PRESENT	0
658040	657790	14251Q	PARTICIPANT	\N	PRESENT	0
658041	657790	20298U	PARTICIPANT	\N	PRESENT	0
658042	657790	19747H	PARTICIPANT	\N	PRESENT	0
658043	657790	14207L	PARTICIPANT	\N	PRESENT	0
658044	657790	14257W	PARTICIPANT	\N	PRESENT	0
658053	656882	86034E	PARTICIPANT	\N	PRESENT	0
658056	656882	19511N	PARTICIPANT	\N	PRESENT	0
658057	656882	14173T	PARTICIPANT	\N	PRESENT	0
658058	656882	20098N	PARTICIPANT	\N	PRESENT	0
658059	656882	19443T	PARTICIPANT	\N	PRESENT	0
658060	656882	19585H	PARTICIPANT	\N	PRESENT	0
658061	656882	20146D	PARTICIPANT	\N	PRESENT	0
658062	656882	98022P	PARTICIPANT	\N	PRESENT	0
658063	656882	20034V	PARTICIPANT	\N	PRESENT	0
658064	656882	08028W	PARTICIPANT	\N	PRESENT	0
658065	656882	20068G	PARTICIPANT	\N	PRESENT	0
658066	656882	19782L	PARTICIPANT	\N	PRESENT	0
658067	656882	20090E	PARTICIPANT	\N	PRESENT	0
658068	656882	19798U	PARTICIPANT	\N	PRESENT	0
658069	656882	14191V	PARTICIPANT	\N	PRESENT	0
658070	656882	19621T	PARTICIPANT	\N	PRESENT	0
658071	656882	12028B	PARTICIPANT	\N	PRESENT	0
658072	656882	19866P	PARTICIPANT	\N	PRESENT	0
658073	656882	20046A	PARTICIPANT	\N	PRESENT	0
658074	656882	04008A	PARTICIPANT	\N	PRESENT	0
658075	656882	19715Y	PARTICIPANT	\N	PRESENT	0
658076	656882	11010L	PARTICIPANT	\N	PRESENT	0
658077	656882	14207L	PARTICIPANT	\N	PRESENT	0
658078	656882	17229F	PARTICIPANT	\N	PRESENT	0
658079	656882	19747H	PARTICIPANT	\N	PRESENT	0
658080	656882	08047A	PARTICIPANT	\N	PRESENT	0
658081	656882	19383Y	PARTICIPANT	\N	PRESENT	0
658082	656882	19673G	PARTICIPANT	\N	PRESENT	0
658083	656882	11033F	PARTICIPANT	\N	PRESENT	0
658084	656882	14189C	PARTICIPANT	\N	PRESENT	0
658085	656882	20102Q	PARTICIPANT	\N	PRESENT	0
658086	656882	14275Y	PARTICIPANT	\N	PRESENT	0
658087	656882	18083K	PARTICIPANT	\N	PRESENT	0
658088	656882	14042U	PARTICIPANT	\N	PRESENT	0
658089	656882	11027H	PARTICIPANT	\N	PRESENT	0
658090	656882	11041F	PARTICIPANT	\N	PRESENT	0
658094	656882	19649G	PARTICIPANT	\N	PRESENT	0
658095	656882	19599P	PARTICIPANT	\N	PRESENT	0
658096	656882	19681G	PARTICIPANT	\N	PRESENT	0
658097	656882	20066E	PARTICIPANT	\N	PRESENT	0
658098	656882	04045F	PARTICIPANT	\N	PRESENT	0
658099	656882	20072C	PARTICIPANT	\N	PRESENT	0
658100	656882	19745F	PARTICIPANT	\N	PRESENT	0
658101	656882	20248J	PARTICIPANT	\N	PRESENT	0
658102	656882	19333N	PARTICIPANT	\N	PRESENT	0
658103	656882	11066Q	PARTICIPANT	\N	PRESENT	0
658104	656882	19525U	PARTICIPANT	\N	PRESENT	0
658105	656882	20106U	PARTICIPANT	\N	PRESENT	0
658107	656882	19703U	PARTICIPANT	\N	PRESENT	0
658108	656882	11101A	PARTICIPANT	\N	PRESENT	0
658109	656882	19711U	PARTICIPANT	\N	PRESENT	0
658110	656882	04035D	PARTICIPANT	\N	PRESENT	0
658111	656882	19693L	PARTICIPANT	\N	PRESENT	0
658112	656882	19575F	PARTICIPANT	\N	PRESENT	0
658113	656882	01058X	PARTICIPANT	\N	PRESENT	0
658114	656882	08010L	PARTICIPANT	\N	PRESENT	0
658115	656882	04047H	PARTICIPANT	\N	PRESENT	0
658116	656882	14026U	PARTICIPANT	\N	PRESENT	0
658117	656882	08034U	PARTICIPANT	\N	PRESENT	0
658118	656882	11048N	PARTICIPANT	\N	PRESENT	0
658119	656882	04042C	PARTICIPANT	\N	PRESENT	0
658120	656882	14123H	PARTICIPANT	\N	PRESENT	0
658121	656882	20078J	PARTICIPANT	\N	PRESENT	0
658122	656882	20074E	PARTICIPANT	\N	PRESENT	0
658124	656882	17367Q	PARTICIPANT	\N	PRESENT	0
658125	656882	14223L	PARTICIPANT	\N	PRESENT	0
658126	656882	10015M	PARTICIPANT	\N	PRESENT	0
658127	656882	11043H	PARTICIPANT	\N	PRESENT	0
658128	656882	04033B	PARTICIPANT	\N	PRESENT	0
658129	656882	14187A	PARTICIPANT	\N	PRESENT	0
658130	656882	05008E	PARTICIPANT	\N	PRESENT	0
658132	656882	11097X	PARTICIPANT	\N	PRESENT	0
658133	656882	14215L	PARTICIPANT	\N	PRESENT	0
658134	656882	19421M	PARTICIPANT	\N	PRESENT	0
658135	656882	14053L	PARTICIPANT	\N	PRESENT	0
658137	656882	14069U	PARTICIPANT	\N	PRESENT	0
658139	656882	04043D	PARTICIPANT	\N	PRESENT	0
658141	656882	11090Q	PARTICIPANT	\N	PRESENT	0
658143	656882	05012A	PARTICIPANT	\N	PRESENT	0
658144	656882	20022R	PARTICIPANT	\N	PRESENT	0
658145	656882	01057W	PARTICIPANT	\N	PRESENT	0
658146	656882	11080N	PARTICIPANT	\N	PRESENT	0
658147	656882	19766L	PARTICIPANT	\N	PRESENT	0
658148	656882	08011M	PARTICIPANT	\N	PRESENT	0
658149	656882	19515S	PARTICIPANT	\N	PRESENT	0
658150	656882	20038A	PARTICIPANT	\N	PRESENT	0
658151	656882	14031R	PARTICIPANT	\N	PRESENT	0
658152	656882	19667J	PARTICIPANT	\N	PRESENT	0
658153	656882	11115U	PARTICIPANT	\N	PRESENT	0
658154	656882	14253S	PARTICIPANT	\N	PRESENT	0
658155	656882	20032T	PARTICIPANT	\N	PRESENT	0
658156	656882	14331P	PARTICIPANT	\N	PRESENT	0
658157	656882	19705W	PARTICIPANT	\N	PRESENT	0
658158	656882	20136B	PARTICIPANT	\N	PRESENT	0
658159	656882	20118Y	PARTICIPANT	\N	PRESENT	0
658160	656882	19533U	PARTICIPANT	\N	PRESENT	0
658161	656882	14193X	PARTICIPANT	\N	PRESENT	0
658162	656882	14237S	PARTICIPANT	\N	PRESENT	0
658163	656882	10006L	PARTICIPANT	\N	PRESENT	0
658164	656882	19671E	PARTICIPANT	\N	PRESENT	0
658165	656882	95041E	PARTICIPANT	\N	PRESENT	0
658166	656882	20252E	PARTICIPANT	\N	PRESENT	0
658167	656882	04071H	PARTICIPANT	\N	PRESENT	0
658168	656882	14217N	PARTICIPANT	\N	PRESENT	0
658169	656882	97011G	PARTICIPANT	\N	PRESENT	0
658170	656882	07033P	PARTICIPANT	\N	PRESENT	0
658171	656882	11103C	PARTICIPANT	\N	PRESENT	0
658172	656882	14147R	PARTICIPANT	\N	PRESENT	0
658173	656882	20172F	PARTICIPANT	\N	PRESENT	0
658174	656882	20138D	PARTICIPANT	\N	PRESENT	0
658175	656882	19954N	PARTICIPANT	\N	PRESENT	0
658176	656882	92040Q	PARTICIPANT	\N	PRESENT	0
658177	656882	20180F	PARTICIPANT	\N	PRESENT	0
658178	656882	20026V	PARTICIPANT	\N	PRESENT	0
658179	656882	19573D	PARTICIPANT	\N	PRESENT	0
658180	656882	19447X	PARTICIPANT	\N	PRESENT	0
658181	656882	19467C	PARTICIPANT	\N	PRESENT	0
658182	656882	14033T	PARTICIPANT	\N	PRESENT	0
658183	656882	11031D	PARTICIPANT	\N	PRESENT	0
658184	656882	19741B	PARTICIPANT	\N	PRESENT	0
658185	656882	11040E	PARTICIPANT	\N	PRESENT	0
658186	656882	19760E	PARTICIPANT	\N	PRESENT	0
658187	656882	19399H	PARTICIPANT	\N	PRESENT	0
658188	656882	20108W	PARTICIPANT	\N	PRESENT	0
658189	656882	19758L	PARTICIPANT	\N	PRESENT	0
658190	656882	19687N	PARTICIPANT	\N	PRESENT	0
658191	656882	20148F	PARTICIPANT	\N	PRESENT	0
658192	656882	14213J	PARTICIPANT	\N	PRESENT	0
658193	656882	04085P	PARTICIPANT	\N	PRESENT	0
658194	656882	20024T	PARTICIPANT	\N	PRESENT	0
658195	656882	14329V	PARTICIPANT	\N	PRESENT	0
654666	651775	20032T	PARTICIPANT	\N	PRESENT	0
654667	651775	19701S	PARTICIPANT	\N	PRESENT	0
654668	651775	20136B	PARTICIPANT	\N	PRESENT	0
654669	651775	20038A	PARTICIPANT	\N	PRESENT	0
654670	651775	14031R	PRESIDENT	0	PRESENT	0
654671	651775	20076G	PARTICIPANT	\N	PRESENT	0
654672	651775	19549D	PARTICIPANT	\N	PRESENT	0
654673	651775	19387D	PARTICIPANT	\N	PRESENT	0
654674	651775	19820Y	PARTICIPANT	\N	PRESENT	0
654675	651775	19826F	PARTICIPANT	\N	PRESENT	0
654676	651775	19599P	PARTICIPANT	\N	PRESENT	0
654677	651775	20102Q	PARTICIPANT	\N	PRESENT	0
654678	651775	18083K	PARTICIPANT	\N	PRESENT	0
654679	651775	20106U	PARTICIPANT	\N	PRESENT	0
654680	651775	19503N	PARTICIPANT	\N	PRESENT	0
654681	651775	19577H	PARTICIPANT	\N	PRESENT	1
654682	651775	20024T	PARTICIPANT	\N	PRESENT	0
654683	651775	19619A	PARTICIPANT	\N	PRESENT	0
654689	651775	20046A	PARTICIPANT	\N	PRESENT	1
654690	651775	19659J	PARTICIPANT	\N	PRESENT	1
654691	651775	19525U	PARTICIPANT	\N	PRESENT	0
654692	651775	20120S	PARTICIPANT	\N	PRESENT	1
654693	651775	19739H	PARTICIPANT	\N	PRESENT	0
654694	651775	11065P	PARTICIPANT	\N	PRESENT	0
654701	654299	19768N	PARTICIPANT	\N	PRESENT	0
654702	654299	19782L	PARTICIPANT	\N	PRESENT	0
654703	654299	20094J	PARTICIPANT	\N	PRESENT	0
654704	654299	04045F	PARTICIPANT	\N	PRESENT	0
654705	654299	20028X	PARTICIPANT	\N	PRESENT	0
654707	652907	19719D	PARTICIPANT	\N	PRESENT	0
654708	652907	01058X	PARTICIPANT	\N	PRESENT	0
654709	652907	14105F	PARTICIPANT	\N	PRESENT	0
654710	652907	20032T	PARTICIPANT	\N	PRESENT	0
654711	652907	14147R	PARTICIPANT	\N	PRESENT	0
654712	652907	20062A	PARTICIPANT	\N	PRESENT	0
654713	652907	20054A	PARTICIPANT	\N	PRESENT	0
654714	652907	20024T	PARTICIPANT	\N	PRESENT	0
654715	652907	20110Q	PARTICIPANT	\N	PRESENT	0
654716	652907	19673G	PARTICIPANT	\N	PRESENT	0
654717	652907	14215L	PARTICIPANT	\N	PRESENT	0
654718	652907	14259Y	PARTICIPANT	\N	PRESENT	0
654719	652907	19599P	PARTICIPANT	\N	PRESENT	0
654720	652907	20026V	PARTICIPANT	\N	PRESENT	0
654721	652907	01028R	PARTICIPANT	\N	PRESENT	0
654722	652907	19760E	PARTICIPANT	\N	PRESENT	0
654726	652907	19479G	PARTICIPANT	\N	PRESENT	0
654724	652907	07029T	PARTICIPANT	\N	PRESENT	0
654725	652907	04085P	PARTICIPANT	\N	PRESENT	0
654727	652907	14121F	PARTICIPANT	\N	PRESENT	0
654728	652907	01024M	PARTICIPANT	\N	PRESENT	0
654729	652907	14042U	PARTICIPANT	\N	PRESENT	0
654730	652907	97011G	PARTICIPANT	\N	PRESENT	0
654731	652907	20076G	PARTICIPANT	\N	PRESENT	0
654732	652907	20098N	PARTICIPANT	\N	PRESENT	0
654733	652907	20056C	PARTICIPANT	\N	PRESENT	0
654734	652907	12028B	PARTICIPANT	\N	PRESENT	0
654735	652907	19447X	PARTICIPANT	\N	PRESENT	0
654736	652907	14053L	PARTICIPANT	\N	PRESENT	0
654737	652907	20034V	PARTICIPANT	\N	PRESENT	0
654738	652907	14231L	PARTICIPANT	\N	PRESENT	0
654739	652907	19525U	PARTICIPANT	\N	PRESENT	0
654740	652907	19782L	PARTICIPANT	\N	PRESENT	0
654741	652907	14073Q	PARTICIPANT	\N	PRESENT	0
654742	652907	19563B	PARTICIPANT	\N	PRESENT	0
654743	652907	20126Y	PARTICIPANT	\N	PRESENT	0
654744	652907	14275Y	PARTICIPANT	\N	PRESENT	0
654745	652907	20150Y	PARTICIPANT	\N	PRESENT	0
654746	652907	08061X	PARTICIPANT	\N	PRESENT	0
654747	652907	20040T	PARTICIPANT	\N	PRESENT	0
654748	652907	19629C	PARTICIPANT	\N	PRESENT	0
654749	652907	14189C	PARTICIPANT	\N	PRESENT	0
654750	652907	20124W	PARTICIPANT	\N	PRESENT	0
654751	652907	20108W	PARTICIPANT	\N	PRESENT	0
654752	652907	19585H	PARTICIPANT	\N	PRESENT	0
654753	652907	14107H	PARTICIPANT	\N	PRESENT	0
654754	652907	20142Y	PARTICIPANT	\N	PRESENT	0
654755	652907	20088L	PARTICIPANT	\N	PRESENT	0
654756	652907	20086J	PARTICIPANT	\N	PRESENT	0
654757	652907	11012A	PARTICIPANT	\N	PRESENT	0
654761	652907	20102Q	PARTICIPANT	\N	PRESENT	0
654759	652907	19701S	PARTICIPANT	\N	PRESENT	0
654760	652907	04042C	PARTICIPANT	\N	PRESENT	0
654762	652907	20084G	PARTICIPANT	\N	PRESENT	0
654763	652907	20070A	PARTICIPANT	\N	PRESENT	0
654764	652907	20130U	PARTICIPANT	\N	PRESENT	0
654765	652907	19251M	PARTICIPANT	\N	PRESENT	0
654766	652907	20044X	PARTICIPANT	\N	PRESENT	0
654767	652907	19369B	PARTICIPANT	\N	PRESENT	0
654768	652907	19647E	PARTICIPANT	\N	PRESENT	0
654769	652907	19441R	PARTICIPANT	\N	PRESENT	0
654770	652907	11048N	PARTICIPANT	\N	PRESENT	0
654771	652907	19467C	PARTICIPANT	\N	PRESENT	0
654772	652907	19679N	PARTICIPANT	\N	PRESENT	0
654773	652907	14225N	PARTICIPANT	\N	PRESENT	0
654841	652909	19679N	PARTICIPANT	\N	PRESENT	0
654842	652909	20080C	PARTICIPANT	\N	PRESENT	0
654843	652909	99004R	PARTICIPANT	\N	PRESENT	0
654844	652909	19647E	PARTICIPANT	\N	PRESENT	0
654845	652909	20032T	PARTICIPANT	\N	PRESENT	0
654846	652909	20130U	PARTICIPANT	\N	PRESENT	0
654847	652909	19711U	PARTICIPANT	\N	PRESENT	0
654848	652909	20110Q	PARTICIPANT	\N	PRESENT	0
654849	652909	14121F	PARTICIPANT	\N	PRESENT	0
654850	652909	07029T	PARTICIPANT	\N	PRESENT	0
654851	652909	18193Q	PARTICIPANT	\N	PRESENT	0
654852	652909	20084G	PARTICIPANT	\N	PRESENT	0
654853	652909	20086J	PARTICIPANT	\N	PRESENT	0
654854	652909	20088L	PARTICIPANT	\N	PRESENT	0
654855	652909	20044X	PARTICIPANT	\N	PRESENT	0
654856	652909	19531S	PARTICIPANT	\N	PRESENT	0
654857	652909	20070A	PARTICIPANT	\N	PRESENT	0
654858	652909	19467C	PARTICIPANT	\N	PRESENT	0
654859	652909	19251M	PARTICIPANT	\N	PRESENT	0
654860	652909	20062A	PARTICIPANT	\N	PRESENT	0
654861	652909	12028B	PARTICIPANT	\N	PRESENT	0
654862	652909	20090E	PARTICIPANT	\N	PRESENT	0
654863	652909	19599P	PARTICIPANT	\N	PRESENT	0
654864	652909	20022R	PARTICIPANT	\N	PRESENT	0
654865	652909	20106U	PARTICIPANT	\N	PRESENT	0
654866	652909	19782L	PARTICIPANT	\N	PRESENT	0
654867	652909	19563B	PARTICIPANT	\N	PRESENT	0
654868	652909	20050V	PARTICIPANT	\N	PRESENT	0
654869	652909	14053L	PARTICIPANT	\N	PRESENT	0
654870	652909	20132W	PARTICIPANT	\N	PRESENT	0
654871	652909	14215L	PARTICIPANT	\N	PRESENT	0
654872	652909	11012A	PARTICIPANT	\N	PRESENT	0
654873	652909	19701S	PARTICIPANT	\N	PRESENT	0
654874	652909	19629C	PARTICIPANT	\N	PRESENT	0
654875	652909	18083K	PARTICIPANT	\N	PRESENT	0
654876	652909	20264J	PARTICIPANT	\N	PRESENT	0
654877	652909	20124W	PARTICIPANT	\N	PRESENT	0
654878	652909	14107H	PARTICIPANT	\N	PRESENT	0
654879	652909	19369B	PARTICIPANT	\N	PRESENT	0
654880	652909	97011G	PARTICIPANT	\N	PRESENT	0
654881	652909	19441R	PARTICIPANT	\N	PRESENT	0
654882	652909	19479G	PARTICIPANT	\N	PRESENT	0
654883	652909	14042U	PARTICIPANT	\N	PRESENT	0
654884	652909	19447X	PARTICIPANT	\N	PRESENT	0
654885	652909	14231L	PARTICIPANT	\N	PRESENT	0
654886	652909	14083S	PARTICIPANT	\N	PRESENT	0
654887	652909	20108W	PARTICIPANT	\N	PRESENT	0
654888	652909	14275Y	PARTICIPANT	\N	PRESENT	0
654889	652909	01058X	PARTICIPANT	\N	PRESENT	0
654890	652909	14073Q	PARTICIPANT	\N	PRESENT	0
654891	652909	20042V	PARTICIPANT	\N	PRESENT	0
654892	652909	01024M	PARTICIPANT	\N	PRESENT	0
654893	652909	14189C	PARTICIPANT	\N	PRESENT	0
654894	652909	20150Y	PARTICIPANT	\N	PRESENT	0
654895	652909	11048N	PARTICIPANT	\N	PRESENT	0
654896	652909	14225N	PARTICIPANT	\N	PRESENT	0
654897	652909	14059S	PARTICIPANT	\N	PRESENT	0
654898	652909	20102Q	PARTICIPANT	\N	PRESENT	0
654899	652909	20298U	PARTICIPANT	\N	PRESENT	0
654900	652909	14071N	PARTICIPANT	\N	PRESENT	0
654901	652909	20286Q	PARTICIPANT	\N	PRESENT	0
654902	652909	20040T	PARTICIPANT	\N	PRESENT	0
654903	652909	14033T	PARTICIPANT	\N	PRESENT	0
654904	652909	20114U	PARTICIPANT	\N	PRESENT	0
654905	652909	08061X	PARTICIPANT	\N	PRESENT	0
654839	652909	19719D	PARTICIPANT	\N	PRESENT	0
654840	652909	19687N	PARTICIPANT	\N	PRESENT	0
660576	659412	08011M	PARTICIPANT	\N	PRESENT	0
660577	659412	19525U	PARTICIPANT	\N	PRESENT	0
660578	659412	17637T	PARTICIPANT	\N	PRESENT	0
660579	659412	04045F	PARTICIPANT	\N	PRESENT	0
660580	659412	08061X	PARTICIPANT	\N	PRESENT	0
660581	659412	08073C	PARTICIPANT	\N	PRESENT	0
660582	659412	04008A	PARTICIPANT	\N	PRESENT	0
660583	659412	14037X	PARTICIPANT	\N	PRESENT	0
660584	659412	19591F	PARTICIPANT	\N	PRESENT	0
660585	659412	01058X	PARTICIPANT	\N	PRESENT	0
660586	659412	19301E	PARTICIPANT	\N	PRESENT	0
660587	659412	95063L	PARTICIPANT	\N	PRESENT	0
660588	659412	08010L	PARTICIPANT	\N	PRESENT	0
660589	659412	04047H	PARTICIPANT	\N	PRESENT	0
660590	659412	20106U	PARTICIPANT	\N	PRESENT	0
660591	659412	08034U	PARTICIPANT	\N	PRESENT	0
660592	659412	11072N	PARTICIPANT	\N	PRESENT	0
660593	659412	19415P	PARTICIPANT	\N	PRESENT	0
660594	659412	14133K	PARTICIPANT	\N	PRESENT	0
660595	659412	11033F	PARTICIPANT	\N	PRESENT	0
660596	659412	14055N	PARTICIPANT	\N	PRESENT	0
660597	659412	11048N	PARTICIPANT	\N	PRESENT	0
660598	659412	04042C	PARTICIPANT	\N	PRESENT	0
660599	659412	20116W	PARTICIPANT	\N	PRESENT	0
660600	659412	14207L	PARTICIPANT	\N	PRESENT	0
660601	659412	18083K	PARTICIPANT	\N	PRESENT	0
660602	659412	19629C	PARTICIPANT	\N	PRESENT	0
660603	659412	20078J	PARTICIPANT	\N	PRESENT	0
660604	659412	11012A	PARTICIPANT	\N	PRESENT	0
660605	659412	19679N	PARTICIPANT	\N	PRESENT	0
660606	659412	19719D	PARTICIPANT	\N	PRESENT	0
660607	659412	19703U	PARTICIPANT	\N	PRESENT	0
660608	659412	14223L	PARTICIPANT	\N	PRESENT	0
660609	659412	14251Q	PARTICIPANT	\N	PRESENT	0
660610	659412	10015M	PARTICIPANT	\N	PRESENT	0
660611	659412	14111D	PARTICIPANT	\N	PRESENT	0
660612	659412	14221J	PARTICIPANT	\N	PRESENT	0
660613	659412	11097X	PARTICIPANT	\N	PRESENT	0
660614	659412	19545Y	PARTICIPANT	\N	PRESENT	0
660615	659412	04092N	PARTICIPANT	\N	PRESENT	0
660616	659412	14211G	PARTICIPANT	\N	PRESENT	0
660617	659412	19583F	PARTICIPANT	\N	PRESENT	0
660618	659412	11064N	PARTICIPANT	\N	PRESENT	0
660619	659412	04057K	PARTICIPANT	\N	PRESENT	0
660620	659412	19563B	PARTICIPANT	\N	PRESENT	0
660621	659412	20050V	PARTICIPANT	\N	PRESENT	0
660622	659412	14169X	PARTICIPANT	\N	PRESENT	0
660623	659412	20122U	PARTICIPANT	\N	PRESENT	0
660624	659412	19585H	PARTICIPANT	\N	PRESENT	0
660625	659412	11090Q	PARTICIPANT	\N	PRESENT	0
660626	659412	20068G	PARTICIPANT	\N	PRESENT	0
660627	659412	14249W	PARTICIPANT	\N	PRESENT	0
660628	659412	01057W	PARTICIPANT	\N	PRESENT	0
660629	659412	01028R	PARTICIPANT	\N	PRESENT	0
660630	659412	14259Y	PARTICIPANT	\N	PRESENT	0
660631	659412	14225N	PARTICIPANT	\N	PRESENT	0
660632	659412	19515S	PARTICIPANT	\N	PRESENT	0
660633	659412	19599P	PARTICIPANT	\N	PRESENT	0
660634	659412	20038A	PARTICIPANT	\N	PRESENT	0
660635	659412	11031D	PARTICIPANT	\N	PRESENT	0
660636	659412	11056N	PARTICIPANT	\N	PRESENT	0
660637	659412	19667J	PARTICIPANT	\N	PRESENT	0
660638	659412	04059M	PARTICIPANT	\N	PRESENT	0
660639	659412	11115U	PARTICIPANT	\N	PRESENT	0
660640	659412	14021P	PARTICIPANT	\N	PRESENT	0
660641	659412	17779H	PARTICIPANT	\N	PRESENT	0
660642	659412	19954N	PARTICIPANT	\N	PRESENT	0
660643	659412	11027H	PARTICIPANT	\N	PRESENT	0
660644	659412	10006L	PARTICIPANT	\N	PRESENT	0
660645	659412	08045X	PARTICIPANT	\N	PRESENT	0
660646	659412	12016W	PARTICIPANT	\N	PRESENT	0
660647	659412	11074Q	PARTICIPANT	\N	PRESENT	0
660648	659412	04043D	PARTICIPANT	\N	PRESENT	0
660649	659412	19489J	PARTICIPANT	\N	PRESENT	0
660650	659412	14069U	PARTICIPANT	\N	PRESENT	0
660651	659412	14053L	PARTICIPANT	\N	PRESENT	0
660652	659412	14151M	PARTICIPANT	\N	PRESENT	0
660653	659412	14215L	PARTICIPANT	\N	PRESENT	0
660654	659412	19673G	PARTICIPANT	\N	PRESENT	0
660655	659412	04033B	PARTICIPANT	\N	PRESENT	0
660656	659412	19549D	PARTICIPANT	\N	PRESENT	0
660657	659412	14071N	PARTICIPANT	\N	PRESENT	0
660658	659412	19333N	PARTICIPANT	\N	PRESENT	0
660659	659412	14213J	PARTICIPANT	\N	PRESENT	0
660660	659412	14173T	PARTICIPANT	\N	PRESENT	0
660661	659412	11067R	PARTICIPANT	\N	PRESENT	0
660662	659412	19573D	PARTICIPANT	\N	PRESENT	0
660663	659412	20028X	PARTICIPANT	\N	PRESENT	0
660664	659412	20096L	PARTICIPANT	\N	PRESENT	0
660665	659412	20060X	PARTICIPANT	\N	PRESENT	0
660666	659412	20118Y	PARTICIPANT	\N	PRESENT	0
660667	659412	19820Y	PARTICIPANT	\N	PRESENT	0
660668	659412	14038Y	PARTICIPANT	\N	PRESENT	0
660669	659412	20070A	PARTICIPANT	\N	PRESENT	0
660670	659412	08012N	PARTICIPANT	\N	PRESENT	0
660671	659412	19447X	PARTICIPANT	\N	PRESENT	0
660672	659412	14109K	PARTICIPANT	\N	PRESENT	0
660673	659412	20026V	PARTICIPANT	\N	PRESENT	0
660674	659412	14281W	PARTICIPANT	\N	PRESENT	0
660676	659412	11104D	PARTICIPANT	\N	PRESENT	0
660678	659412	11066Q	PARTICIPANT	\N	PRESENT	0
660679	659412	20140W	PARTICIPANT	\N	PRESENT	0
660680	659412	11041F	PARTICIPANT	\N	PRESENT	0
660681	659412	19527W	PARTICIPANT	\N	PRESENT	0
660682	659412	14147R	PARTICIPANT	\N	PRESENT	0
660683	659412	20172F	PARTICIPANT	\N	PRESENT	0
660684	659412	19725B	PARTICIPANT	\N	PRESENT	0
660685	659412	08047A	PARTICIPANT	\N	PRESENT	0
660686	659412	18193Q	PARTICIPANT	\N	PRESENT	0
660687	659412	19413M	PARTICIPANT	\N	PRESENT	0
660688	659412	20080C	PARTICIPANT	\N	PRESENT	0
660690	659412	20138D	PARTICIPANT	\N	PRESENT	0
660691	659412	20082E	PARTICIPANT	\N	PRESENT	0
660692	659412	20034V	PARTICIPANT	\N	PRESENT	0
660693	659412	12028B	PARTICIPANT	\N	PRESENT	0
660694	659412	19295A	PARTICIPANT	\N	PRESENT	0
660695	659412	20044X	PARTICIPANT	\N	PRESENT	0
660696	659412	20058E	PARTICIPANT	\N	PRESENT	0
660697	659412	19503N	PARTICIPANT	\N	PRESENT	0
660698	659412	20084G	PARTICIPANT	\N	PRESENT	0
660699	659412	08018U	PARTICIPANT	\N	PRESENT	0
660700	659412	19467C	PARTICIPANT	\N	PRESENT	0
660701	659412	19705W	PARTICIPANT	\N	PRESENT	0
660702	659412	19723Y	PARTICIPANT	\N	PRESENT	0
660704	659412	20914V	PARTICIPANT	\N	PRESENT	0
660705	659412	20110Q	PARTICIPANT	\N	PRESENT	0
660706	659412	11065P	PARTICIPANT	\N	PRESENT	0
660707	659412	20036X	PARTICIPANT	\N	PRESENT	0
660708	659412	11110B	PARTICIPANT	\N	PRESENT	0
660709	659412	19399H	PARTICIPANT	\N	PRESENT	0
660710	659412	19507S	PARTICIPANT	\N	PRESENT	0
660712	659412	19657G	PARTICIPANT	\N	PRESENT	0
660713	659412	14059S	PARTICIPANT	\N	PRESENT	0
660714	659412	19669L	PARTICIPANT	\N	PRESENT	0
660715	659412	19768N	PARTICIPANT	\N	PRESENT	0
660716	659412	20018V	PARTICIPANT	\N	PRESENT	0
660717	659412	14257W	PARTICIPANT	\N	PRESENT	0
660718	659412	20024T	PARTICIPANT	\N	PRESENT	0
660719	659412	19421M	PARTICIPANT	\N	PRESENT	0
660720	659412	20054A	PARTICIPANT	\N	PRESENT	0
660721	659412	20064C	PARTICIPANT	\N	PRESENT	0
660722	659412	20126Y	PARTICIPANT	\N	PRESENT	0
660723	659412	17965H	PARTICIPANT	\N	PRESENT	0
660724	659412	20124W	PARTICIPANT	\N	PRESENT	0
660726	659412	01024M	PARTICIPANT	\N	PRESENT	0
660727	659412	08056B	PARTICIPANT	\N	PRESENT	0
660728	659412	19713W	PARTICIPANT	\N	PRESENT	0
660730	659412	19709B	PARTICIPANT	\N	PRESENT	0
660731	659412	14042U	PARTICIPANT	\N	PRESENT	0
660732	659412	20020P	PARTICIPANT	\N	PRESENT	0
660733	659412	19762G	PARTICIPANT	\N	PRESENT	0
660735	659412	11103C	PARTICIPANT	\N	PRESENT	0
660736	659412	20042V	PARTICIPANT	\N	PRESENT	0
660737	659412	20052X	PARTICIPANT	\N	PRESENT	0
660739	659412	07033P	PARTICIPANT	\N	PRESENT	0
660740	659412	20120S	PARTICIPANT	\N	PRESENT	0
660742	659412	20252E	PARTICIPANT	\N	PRESENT	0
660743	659412	19721W	PARTICIPANT	\N	PRESENT	0
660744	659412	19619A	PARTICIPANT	\N	PRESENT	0
654961	651775	20140W	PARTICIPANT	\N	PRESENT	0
654962	651775	19251M	PARTICIPANT	\N	PRESENT	0
654963	651775	19745F	PARTICIPANT	\N	PRESENT	0
655035	651775	19707Y	PARTICIPANT	\N	PRESENT	0
655037	651775	19575F	PARTICIPANT	\N	PRESENT	0
655039	651775	20094J	PARTICIPANT	\N	PRESENT	0
655040	651775	19782L	PARTICIPANT	\N	PRESENT	0
655042	651775	20104S	PARTICIPANT	\N	PRESENT	0
655043	651775	14329V	PARTICIPANT	\N	PRESENT	0
655044	651775	14038Y	PARTICIPANT	\N	PRESENT	0
655046	651775	20144B	PARTICIPANT	\N	PRESENT	0
655048	651775	19467C	PARTICIPANT	\N	PRESENT	0
655049	651775	14357A	PARTICIPANT	\N	PRESENT	0
655051	651775	14187A	PARTICIPANT	\N	PRESENT	0
655052	651775	14033T	PARTICIPANT	\N	PRESENT	0
655054	651775	20286Q	PARTICIPANT	\N	PRESENT	0
655055	651775	20034V	PARTICIPANT	\N	PRESENT	0
655056	651775	11099A	PARTICIPANT	\N	PRESENT	0
655057	651775	14205J	PARTICIPANT	\N	PRESENT	0
655059	651775	19441R	PARTICIPANT	\N	PRESENT	0
655060	651775	20028X	PARTICIPANT	\N	PRESENT	0
655063	651775	19369B	PARTICIPANT	\N	PRESENT	0
655064	651775	14257W	PARTICIPANT	\N	PRESENT	0
655066	651775	19768N	PARTICIPANT	\N	PRESENT	0
655068	651775	11090Q	PARTICIPANT	\N	PRESENT	0
655070	651775	19705W	PARTICIPANT	\N	PRESENT	0
655071	651775	20054A	PARTICIPANT	\N	PRESENT	0
655073	651775	20092G	PARTICIPANT	\N	PRESENT	0
655074	651775	04045F	PARTICIPANT	\N	PRESENT	0
655076	651775	20062A	PARTICIPANT	\N	PRESENT	0
655821	655819	19563B	PARTICIPANT	\N	PRESENT	0
655822	655819	19507S	PARTICIPANT	\N	PRESENT	0
655823	655819	20092G	PARTICIPANT	\N	PRESENT	0
655851	655819	08028W	PARTICIPANT	\N	PRESENT	0
655852	655819	04045F	PARTICIPANT	\N	PRESENT	0
655853	655820	19563B	PARTICIPANT	\N	PRESENT	0
655860	655858	14179A	PARTICIPANT	\N	PRESENT	0
655861	655858	04008A	PARTICIPANT	\N	PRESENT	0
655862	655858	14151M	PARTICIPANT	\N	PRESENT	0
655864	655863	04008A	PARTICIPANT	\N	PRESENT	0
655865	655863	14147R	PARTICIPANT	\N	PRESENT	0
655878	655863	14179A	PARTICIPANT	\N	PRESENT	0
655879	655863	14151M	PARTICIPANT	\N	PRESENT	0
655903	655902	04008A	PARTICIPANT	\N	PRESENT	0
655904	655902	14179A	PARTICIPANT	\N	PRESENT	0
655905	655902	14147R	PARTICIPANT	\N	PRESENT	0
655906	655902	14151M	PARTICIPANT	\N	PRESENT	0
655907	655902	20022R	PARTICIPANT	\N	PRESENT	0
655909	655908	14179A	PARTICIPANT	\N	PRESENT	0
655910	655908	20022R	PARTICIPANT	\N	PRESENT	0
655911	655908	14151M	PARTICIPANT	\N	PRESENT	0
655912	655908	14147R	PARTICIPANT	\N	PRESENT	0
655913	655908	04008A	PARTICIPANT	\N	PRESENT	0
655914	655908	08047A	PARTICIPANT	\N	PRESENT	0
656315	651603	14189C	PARTICIPANT	\N	PRESENT	0
656316	651603	20024T	PARTICIPANT	\N	PRESENT	0
656317	651603	14030Q	PRESIDENT	0	PRESENT	0
656318	651603	20138D	PARTICIPANT	\N	PRESENT	0
656319	651603	20114U	PARTICIPANT	\N	PRESENT	0
656320	651603	17737W	PARTICIPANT	\N	PRESENT	0
656321	651603	20080C	PARTICIPANT	\N	PRESENT	0
656322	651603	19621T	PARTICIPANT	\N	PRESENT	0
656323	651603	11031D	PARTICIPANT	\N	PRESENT	0
656324	651603	19693L	PARTICIPANT	\N	PRESENT	0
656325	651603	20140W	PARTICIPANT	\N	PRESENT	0
656326	651603	20034V	PARTICIPANT	\N	PRESENT	0
656327	651603	20056C	PARTICIPANT	\N	PRESENT	0
656328	651603	07029T	PARTICIPANT	\N	EXCUSE	0
656329	651603	14275Y	PARTICIPANT	\N	PRESENT	0
656330	651603	19749K	PARTICIPANT	\N	PRESENT	0
656331	651603	19715Y	PARTICIPANT	\N	PRESENT	0
656332	651603	20066E	PARTICIPANT	\N	PRESENT	0
656333	651603	04035D	PARTICIPANT	\N	PRESENT	0
656334	651603	19681G	PARTICIPANT	\N	EXCUSE	0
656335	651603	20118Y	PARTICIPANT	\N	EXCUSE	0
656336	651603	19798U	PARTICIPANT	\N	EXCUSE	0
656337	651603	20098N	PARTICIPANT	\N	EXCUSE	0
656338	651603	19527W	PARTICIPANT	\N	EXCUSE	0
656339	651603	14179A	PARTICIPANT	\N	PRESENT	0
656340	651603	19657G	PARTICIPANT	\N	EXCUSE	0
656341	651603	14109K	PARTICIPANT	\N	EXCUSE	0
656342	651603	19768N	PARTICIPANT	\N	EXCUSE	0
656426	656425	11066Q	PARTICIPANT	\N	PRESENT	0
659418	659417	07029T	PARTICIPANT	\N	PRESENT	0
659550	659549	07029T	PARTICIPANT	\N	PRESENT	0
661754	661753	11067R	PARTICIPANT	\N	PRESENT	0
661755	661753	14071N	PARTICIPANT	\N	PRESENT	0
661756	661753	20130U	PARTICIPANT	\N	PRESENT	0
661759	661758	14069U	PARTICIPANT	\N	PRESENT	0
661760	661758	14255U	PARTICIPANT	\N	PRESENT	0
661761	661758	19577H	PARTICIPANT	\N	PRESENT	0
661762	661758	20038A	PARTICIPANT	\N	PRESENT	0
661763	661758	19683J	PARTICIPANT	\N	PRESENT	0
661764	661758	14059S	PARTICIPANT	\N	PRESENT	0
661765	661758	19826F	PARTICIPANT	\N	PRESENT	0
661766	661758	19585H	PARTICIPANT	\N	PRESENT	0
661767	661758	19421M	PARTICIPANT	\N	PRESENT	0
661793	661792	19503N	PARTICIPANT	\N	PRESENT	0
661795	661794	19503N	PARTICIPANT	\N	PRESENT	0
661797	661796	19503N	PARTICIPANT	\N	PRESENT	0
662264	662261	11031D	PARTICIPANT	\N	PRESENT	0
662265	662261	20048C	PARTICIPANT	\N	PRESENT	0
662269	662261	14169X	PARTICIPANT	\N	PRESENT	0
662369	662366	11031D	PARTICIPANT	\N	PRESENT	0
662372	662366	20048C	PARTICIPANT	\N	PRESENT	0
662373	662366	14083S	PARTICIPANT	\N	PRESENT	0
662375	662366	18083K	PARTICIPANT	\N	PRESENT	0
662376	662366	20040T	PARTICIPANT	\N	PRESENT	0
662377	662366	20100N	PARTICIPANT	\N	PRESENT	0
662379	662366	19649G	PARTICIPANT	\N	PRESENT	0
662380	662366	11026G	PARTICIPANT	\N	PRESENT	0
662381	662366	20052X	PARTICIPANT	\N	PRESENT	0
662382	662366	08073C	PARTICIPANT	\N	PRESENT	0
662383	662366	11045K	PARTICIPANT	\N	PRESENT	0
662405	662403	11031D	PARTICIPANT	\N	PRESENT	0
662406	662403	20048C	PARTICIPANT	\N	PRESENT	0
662407	662403	11045K	PARTICIPANT	\N	PRESENT	0
662419	662417	11045K	PARTICIPANT	\N	PRESENT	0
662434	662432	11031D	PARTICIPANT	\N	PRESENT	0
662435	662432	20048C	PARTICIPANT	\N	PRESENT	0
662447	662446	11031D	PARTICIPANT	\N	PRESENT	0
662463	662462	11031D	PARTICIPANT	\N	PRESENT	0
662464	662462	20048C	PARTICIPANT	\N	PRESENT	0
662465	662462	14169X	PARTICIPANT	\N	PRESENT	0
662466	662462	19758L	PARTICIPANT	\N	PRESENT	0
662467	662462	14083S	PARTICIPANT	\N	PRESENT	0
662468	662462	20040T	PARTICIPANT	\N	PRESENT	0
662469	662462	20052X	PARTICIPANT	\N	PRESENT	0
668096	667819	11067R	PARTICIPANT	\N	EXCUSE	0
668114	668113	20024T	PARTICIPANT	\N	PRESENT	0
668115	668113	20042V	PARTICIPANT	\N	PRESENT	0
668116	668113	10015M	PARTICIPANT	\N	PRESENT	0
669885	669884	20914V	PARTICIPANT	\N	PRESENT	0
669886	669884	19545Y	PARTICIPANT	\N	PRESENT	0
669888	669887	20914V	PARTICIPANT	\N	PRESENT	0
669889	669887	19545Y	PARTICIPANT	\N	PRESENT	0
682003	676617	19729F	PARTICIPANT	\N	PRESENT	0
682004	676617	14030Q	PARTICIPANT	\N	PRESENT	0
682005	676617	17023S	PARTICIPANT	\N	PRESENT	0
682006	676617	19421M	PARTICIPANT	\N	PRESENT	0
682007	676617	20064C	PARTICIPANT	\N	PRESENT	0
682008	676617	14111D	PARTICIPANT	\N	PRESENT	0
682009	676617	95041E	PARTICIPANT	\N	PRESENT	0
682010	676617	97011G	PARTICIPANT	\N	PRESENT	0
682014	676617	19503N	PARTICIPANT	\N	PRESENT	0
682012	676617	14219Q	PARTICIPANT	\N	PRESENT	0
682013	676617	01024M	PARTICIPANT	\N	PRESENT	0
682016	681084	19383Y	PARTICIPANT	\N	PRESENT	0
682017	681084	19768N	PARTICIPANT	\N	PRESENT	0
682018	681084	19515S	PARTICIPANT	\N	PRESENT	0
682019	681084	20092G	PARTICIPANT	\N	PRESENT	0
682020	681084	19782L	PARTICIPANT	\N	PRESENT	0
682021	681084	11077T	PARTICIPANT	\N	PRESENT	0
682022	681084	14357A	PARTICIPANT	\N	PRESENT	0
682023	681084	20078J	PARTICIPANT	\N	PRESENT	0
682024	681084	19441R	PARTICIPANT	\N	PRESENT	0
682025	681084	19413M	PARTICIPANT	\N	PRESENT	0
682026	681084	20082E	PARTICIPANT	\N	PRESENT	0
658196	656882	19565D	PARTICIPANT	\N	PRESENT	0
658197	656882	12041X	PARTICIPANT	\N	PRESENT	0
658198	656882	20112S	PARTICIPANT	\N	PRESENT	0
658199	656882	19695N	PARTICIPANT	\N	PRESENT	0
658200	656882	19675J	PARTICIPANT	\N	PRESENT	0
658201	656882	19593H	PARTICIPANT	\N	PRESENT	0
658202	656882	20120S	PARTICIPANT	\N	PRESENT	0
658203	656882	19581D	PARTICIPANT	\N	PRESENT	0
658204	656882	17965H	PARTICIPANT	\N	PRESENT	0
658205	656882	20020P	PARTICIPANT	\N	PRESENT	0
658206	656882	20134Y	PARTICIPANT	\N	PRESENT	0
658207	656882	14357A	PARTICIPANT	\N	PRESENT	0
658208	656882	20130U	PARTICIPANT	\N	PRESENT	0
658209	656882	20054A	PARTICIPANT	\N	PRESENT	0
658210	656882	20092G	PARTICIPANT	\N	PRESENT	0
658211	656882	20914V	PARTICIPANT	\N	PRESENT	0
658212	656882	20110Q	PARTICIPANT	\N	PRESENT	0
658213	656882	19701S	PARTICIPANT	\N	PRESENT	0
658214	656882	19347U	PARTICIPANT	\N	PRESENT	0
658215	656882	20100N	PARTICIPANT	\N	PRESENT	0
658216	656882	20126Y	PARTICIPANT	\N	PRESENT	0
658217	656882	20124W	PARTICIPANT	\N	PRESENT	0
658218	656882	14059S	PARTICIPANT	\N	PRESENT	0
658219	656882	19057M	PARTICIPANT	\N	PRESENT	0
658220	656882	08056B	PARTICIPANT	\N	PRESENT	0
658221	656882	14037X	PARTICIPANT	\N	PRESENT	0
658222	656882	19697Q	PARTICIPANT	\N	PRESENT	0
658223	656882	95063L	PARTICIPANT	\N	PRESENT	0
658224	656882	11072N	PARTICIPANT	\N	PRESENT	0
658225	656882	20062A	PARTICIPANT	\N	PRESENT	0
658226	656882	08061X	PARTICIPANT	\N	PRESENT	0
658227	656882	19768N	PARTICIPANT	\N	PRESENT	0
658228	656882	19301E	PARTICIPANT	\N	PRESENT	0
658229	656882	19651A	PARTICIPANT	\N	PRESENT	0
658230	656882	08015R	PARTICIPANT	\N	PRESENT	0
658231	656882	19349W	PARTICIPANT	\N	PRESENT	0
658233	656882	19729F	PARTICIPANT	\N	PRESENT	0
658234	656882	19709B	PARTICIPANT	\N	PRESENT	0
658235	656882	08073C	PARTICIPANT	\N	PRESENT	0
658236	656882	20096L	PARTICIPANT	\N	PRESENT	0
658237	656882	19591F	PARTICIPANT	\N	PRESENT	0
658238	656882	08018U	PARTICIPANT	\N	PRESENT	0
658239	656882	20150Y	PARTICIPANT	\N	PRESENT	0
658240	656882	14355X	PARTICIPANT	\N	PRESENT	0
658241	656882	14055N	PARTICIPANT	\N	PRESENT	0
658242	656882	19717B	PARTICIPANT	\N	PRESENT	0
658243	656882	19663E	PARTICIPANT	\N	PRESENT	0
658244	656882	20116W	PARTICIPANT	\N	PRESENT	0
658245	656882	14107H	PARTICIPANT	\N	PRESENT	0
658246	656882	11012A	PARTICIPANT	\N	PRESENT	0
658247	656882	19553Y	PARTICIPANT	\N	PRESENT	0
658248	656882	20044X	PARTICIPANT	\N	PRESENT	0
658249	656882	19387D	PARTICIPANT	\N	PRESENT	0
658250	656882	20086J	PARTICIPANT	\N	PRESENT	0
658251	656882	20058E	PARTICIPANT	\N	PRESENT	0
658252	656882	20132W	PARTICIPANT	\N	PRESENT	0
658253	656882	20298U	PARTICIPANT	\N	PRESENT	0
658254	656882	14251Q	PARTICIPANT	\N	PRESENT	0
658255	656882	19545Y	PARTICIPANT	\N	PRESENT	0
658256	656882	14221J	PARTICIPANT	\N	PRESENT	0
658257	656882	04057K	PARTICIPANT	\N	PRESENT	0
658258	656882	19563B	PARTICIPANT	\N	PRESENT	0
658259	656882	20056C	PARTICIPANT	\N	PRESENT	0
658260	656882	20016T	PARTICIPANT	\N	PRESENT	0
658261	656882	11083R	PARTICIPANT	\N	PRESENT	0
658262	656882	19659J	PARTICIPANT	\N	PRESENT	0
658263	656882	14111D	PARTICIPANT	\N	PRESENT	0
658264	656882	14211G	PARTICIPANT	\N	PRESENT	0
658265	656882	14195A	PARTICIPANT	\N	PRESENT	0
658266	656882	17637T	PARTICIPANT	\N	PRESENT	0
658267	656882	19631V	PARTICIPANT	\N	PRESENT	0
658268	656882	19367Y	PARTICIPANT	\N	PRESENT	0
658269	656882	01028R	PARTICIPANT	\N	PRESENT	0
658270	656882	20030R	PARTICIPANT	\N	PRESENT	0
658271	656882	11067R	PARTICIPANT	\N	PRESENT	0
658272	656882	11104D	PARTICIPANT	\N	PRESENT	0
658273	656882	19643A	PARTICIPANT	\N	PRESENT	0
658274	656882	12016W	PARTICIPANT	\N	PRESENT	0
658275	656882	20080C	PARTICIPANT	\N	PRESENT	0
658276	656882	14257W	PARTICIPANT	\N	PRESENT	0
658277	656882	14021P	PARTICIPANT	\N	PRESENT	0
658278	656882	14229S	PARTICIPANT	\N	PRESENT	0
658279	656882	11045K	PARTICIPANT	\N	PRESENT	0
658280	656882	01062T	PARTICIPANT	\N	PRESENT	0
658281	656882	08060W	PARTICIPANT	\N	PRESENT	0
658282	656882	19549D	PARTICIPANT	\N	PRESENT	0
658283	656882	19669L	PARTICIPANT	\N	PRESENT	0
658284	656882	04092N	PARTICIPANT	\N	PRESENT	0
658285	656882	20064C	PARTICIPANT	\N	PRESENT	0
658286	656882	11054L	PARTICIPANT	\N	PRESENT	0
658287	656882	19723Y	PARTICIPANT	\N	PRESENT	0
658288	656882	14281W	PARTICIPANT	\N	PRESENT	0
658289	656882	19725B	PARTICIPANT	\N	PRESENT	0
658290	656882	14151M	PARTICIPANT	\N	PRESENT	0
658291	656882	14121F	PARTICIPANT	\N	PRESENT	0
658292	656882	11110B	PARTICIPANT	\N	PRESENT	0
658293	656882	14169X	PARTICIPANT	\N	PRESENT	0
658294	656882	19679N	PARTICIPANT	\N	PRESENT	0
658295	656882	20114U	PARTICIPANT	\N	PRESENT	0
658296	656882	20028X	PARTICIPANT	\N	PRESENT	0
658297	656882	19762G	PARTICIPANT	\N	PRESENT	0
658298	656882	14097Y	PARTICIPANT	\N	PRESENT	0
658299	656882	19527W	PARTICIPANT	\N	PRESENT	0
658300	656882	20264J	PARTICIPANT	\N	PRESENT	0
658301	656882	19531S	PARTICIPANT	\N	PRESENT	0
658302	656882	19251M	PARTICIPANT	\N	PRESENT	0
658303	656882	20094J	PARTICIPANT	\N	PRESENT	0
658304	656882	20088L	PARTICIPANT	\N	PRESENT	0
658305	656882	20070A	PARTICIPANT	\N	PRESENT	0
658306	656882	20084G	PARTICIPANT	\N	PRESENT	0
658307	656882	20082E	PARTICIPANT	\N	PRESENT	0
658308	656882	19503N	PARTICIPANT	\N	PRESENT	0
658309	656882	14225N	PARTICIPANT	\N	PRESENT	0
658310	656882	19647E	PARTICIPANT	\N	PRESENT	0
658311	656882	18193Q	PARTICIPANT	\N	PRESENT	0
658312	656882	20060X	PARTICIPANT	\N	PRESENT	0
658313	656882	14109K	PARTICIPANT	\N	PRESENT	0
658314	656882	08012N	PARTICIPANT	\N	PRESENT	0
658315	656882	19820Y	PARTICIPANT	\N	PRESENT	0
658316	656882	20142Y	PARTICIPANT	\N	PRESENT	0
658317	656882	19713W	PARTICIPANT	\N	PRESENT	0
658318	656882	19699S	PARTICIPANT	\N	PRESENT	0
658319	656882	20042V	PARTICIPANT	\N	PRESENT	0
658320	656882	14089Y	PARTICIPANT	\N	PRESENT	0
658321	656882	14267Y	PARTICIPANT	\N	PRESENT	0
658322	656882	19543W	PARTICIPANT	\N	PRESENT	0
658323	656882	19619A	PARTICIPANT	\N	PRESENT	0
658324	656882	19441R	PARTICIPANT	\N	PRESENT	0
658325	656882	19479G	PARTICIPANT	\N	PRESENT	0
658326	656882	14219Q	PARTICIPANT	\N	PRESENT	0
658327	656882	19721W	PARTICIPANT	\N	PRESENT	0
658328	656882	16685X	PARTICIPANT	\N	PRESENT	0
658329	656882	19735D	PARTICIPANT	\N	PRESENT	0
658330	656882	19569H	PARTICIPANT	\N	PRESENT	0
658331	656882	20144B	PARTICIPANT	\N	PRESENT	0
658332	656882	14205J	PARTICIPANT	\N	PRESENT	0
658333	656882	08009T	PARTICIPANT	\N	PRESENT	0
658334	656882	11053K	PARTICIPANT	\N	PRESENT	0
658335	656882	11064N	PARTICIPANT	\N	PRESENT	0
658336	656882	19369B	PARTICIPANT	\N	PRESENT	0
658337	656882	01034P	PARTICIPANT	\N	PRESENT	0
658338	656882	19611R	PARTICIPANT	\N	PRESENT	0
658339	656882	19691J	PARTICIPANT	\N	PRESENT	0
658340	656882	14231L	PARTICIPANT	\N	PRESENT	0
658341	656882	14179A	PARTICIPANT	\N	PRESENT	0
658342	656882	20286Q	PARTICIPANT	\N	PRESENT	0
658343	656882	19826F	PARTICIPANT	\N	PRESENT	0
658344	656882	01043Q	PARTICIPANT	\N	PRESENT	0
658345	656882	14030Q	PARTICIPANT	\N	PRESENT	0
658346	656882	14327T	PARTICIPANT	\N	PRESENT	0
658347	656882	01024M	PARTICIPANT	\N	PRESENT	0
658348	656882	04070G	PARTICIPANT	\N	PRESENT	0
658349	656882	19577H	PARTICIPANT	\N	PRESENT	0
658350	656882	14255U	PARTICIPANT	\N	PRESENT	0
658351	656882	11070L	PARTICIPANT	\N	PRESENT	0
658352	656882	14083S	PARTICIPANT	\N	PRESENT	0
658353	656882	14073Q	PARTICIPANT	\N	PRESENT	0
658354	656882	20040T	PARTICIPANT	\N	PRESENT	0
658355	656882	11085T	PARTICIPANT	\N	PRESENT	0
658360	656882	11056N	PARTICIPANT	\N	PRESENT	0
658361	656882	14001X	PARTICIPANT	\N	PRESENT	0
654906	652909	20128B	PARTICIPANT	\N	PRESENT	0
654907	652909	19575F	PARTICIPANT	\N	PRESENT	0
654908	652909	01028R	PARTICIPANT	\N	PRESENT	0
654909	652909	08034U	PARTICIPANT	\N	PRESENT	0
654910	652909	20104S	PARTICIPANT	\N	PRESENT	0
654911	652909	19826F	PARTICIPANT	\N	PRESENT	0
654912	652909	14105F	PARTICIPANT	\N	PRESENT	0
654913	652909	11083R	PARTICIPANT	\N	PRESENT	0
654914	652909	04085P	PARTICIPANT	\N	PRESENT	0
654915	652909	19760E	PARTICIPANT	\N	PRESENT	0
654916	652909	14259Y	PARTICIPANT	\N	PRESENT	0
654917	652909	20026V	PARTICIPANT	\N	PRESENT	0
654918	652909	20024T	PARTICIPANT	\N	PRESENT	0
654919	652909	19762G	PARTICIPANT	\N	PRESENT	0
654920	652909	19549D	PARTICIPANT	\N	PRESENT	0
654921	652909	20914V	PARTICIPANT	\N	PRESENT	0
654922	652909	11085T	PARTICIPANT	\N	PRESENT	0
654950	652909	95063L	PARTICIPANT	\N	PRESENT	0
654951	652909	14357A	PARTICIPANT	\N	PRESENT	0
654952	652909	04043D	PARTICIPANT	\N	PRESENT	0
654953	652909	19683J	PARTICIPANT	\N	PRESENT	0
654954	652909	19820Y	PARTICIPANT	\N	PRESENT	0
654955	652909	19591F	PARTICIPANT	\N	PRESENT	0
654956	652909	11090Q	PARTICIPANT	\N	PRESENT	0
654957	652909	19347U	PARTICIPANT	\N	PRESENT	0
654958	652909	11033F	PARTICIPANT	\N	PRESENT	0
654959	652909	19697Q	PARTICIPANT	\N	PRESENT	0
654960	652909	19673G	PARTICIPANT	\N	PRESENT	0
655041	652908	14225N	PARTICIPANT	\N	PRESENT	0
655045	652908	19679N	PARTICIPANT	\N	PRESENT	0
655047	652908	14071N	PARTICIPANT	\N	PRESENT	0
655050	652908	20128B	PARTICIPANT	\N	PRESENT	0
655053	652908	20132W	PARTICIPANT	\N	PRESENT	0
655058	652908	19820Y	PARTICIPANT	\N	PRESENT	0
655061	652908	20070A	PARTICIPANT	\N	PRESENT	0
655062	652908	19683J	PARTICIPANT	\N	PRESENT	0
655065	652908	19549D	PARTICIPANT	\N	PRESENT	0
655067	652908	18193Q	PARTICIPANT	\N	PRESENT	0
655069	652908	14257W	PARTICIPANT	\N	PRESENT	0
655072	652908	19251M	PARTICIPANT	\N	PRESENT	0
655075	652908	19347U	PARTICIPANT	\N	PRESENT	0
655077	652908	20914V	PARTICIPANT	\N	PRESENT	0
655078	652908	20130U	PARTICIPANT	\N	PRESENT	0
655079	652908	19697Q	PARTICIPANT	\N	PRESENT	0
655080	652908	11033F	PARTICIPANT	\N	PRESENT	0
655081	652908	19760E	PARTICIPANT	\N	PRESENT	0
655082	652908	20102Q	PARTICIPANT	\N	PRESENT	0
655083	652908	14121F	PARTICIPANT	\N	PRESENT	0
655084	652908	19563B	PARTICIPANT	\N	PRESENT	0
655085	652908	19441R	PARTICIPANT	\N	PRESENT	0
655086	652908	14083S	PARTICIPANT	\N	PRESENT	0
655087	652908	19479G	PARTICIPANT	\N	PRESENT	0
655088	652908	14042U	PARTICIPANT	\N	PRESENT	0
655089	652908	20286Q	PARTICIPANT	\N	PRESENT	0
655090	652908	20298U	PARTICIPANT	\N	PRESENT	0
655091	652908	20040T	PARTICIPANT	\N	PRESENT	0
655092	652908	19826F	PARTICIPANT	\N	PRESENT	0
655093	652908	20124W	PARTICIPANT	\N	PRESENT	0
655094	652908	20090E	PARTICIPANT	\N	PRESENT	0
655095	652908	97011G	PARTICIPANT	\N	PRESENT	0
655096	652908	04043D	PARTICIPANT	\N	PRESENT	0
655097	652908	14033T	PARTICIPANT	\N	PRESENT	0
655098	652908	07029T	PARTICIPANT	\N	PRESENT	0
655099	652908	20080C	PARTICIPANT	\N	PRESENT	0
655100	652908	19467C	PARTICIPANT	\N	PRESENT	0
655101	652908	20032T	PARTICIPANT	\N	PRESENT	0
655102	652908	18083K	PARTICIPANT	\N	PRESENT	0
655103	652908	19447X	PARTICIPANT	\N	PRESENT	0
655104	652908	19673G	PARTICIPANT	\N	PRESENT	0
655105	652908	99004R	PARTICIPANT	\N	PRESENT	0
655106	652908	20022R	PARTICIPANT	\N	PRESENT	0
655107	652908	11090Q	PARTICIPANT	\N	PRESENT	0
655108	652908	08034U	PARTICIPANT	\N	PRESENT	0
655109	652908	08061X	PARTICIPANT	\N	PRESENT	0
655110	652908	19719D	PARTICIPANT	\N	PRESENT	0
655111	652908	19369B	PARTICIPANT	\N	PRESENT	0
655112	652908	20042V	PARTICIPANT	\N	PRESENT	0
655113	652908	19591F	PARTICIPANT	\N	PRESENT	0
655114	652908	20084G	PARTICIPANT	\N	PRESENT	0
655115	652908	14059S	PARTICIPANT	\N	PRESENT	0
655116	652908	11012A	PARTICIPANT	\N	PRESENT	0
655117	652908	01028R	PARTICIPANT	\N	PRESENT	0
655118	652908	20104S	PARTICIPANT	\N	PRESENT	0
655119	652908	19701S	PARTICIPANT	\N	PRESENT	0
655120	652908	20110Q	PARTICIPANT	\N	PRESENT	0
655121	652908	20108W	PARTICIPANT	\N	PRESENT	0
655122	652908	20044X	PARTICIPANT	\N	PRESENT	0
655123	652908	14357A	PARTICIPANT	\N	PRESENT	0
655124	652908	19762G	PARTICIPANT	\N	PRESENT	0
655125	652908	04085P	PARTICIPANT	\N	PRESENT	0
655126	652908	19711U	PARTICIPANT	\N	PRESENT	0
655127	652908	20136B	PARTICIPANT	\N	PRESENT	0
655128	652908	19531S	PARTICIPANT	\N	PRESENT	0
655129	652908	01058X	PARTICIPANT	\N	PRESENT	0
655130	652908	01024M	PARTICIPANT	\N	PRESENT	0
656065	656064	20066E	PARTICIPANT	\N	EXCUSE	0
656066	656064	19593H	PARTICIPANT	\N	EXCUSE	0
656067	656064	19693L	PARTICIPANT	\N	PRESENT	0
656068	656064	19709B	PARTICIPANT	\N	EXCUSE	0
655036	652908	95063L	PARTICIPANT	\N	PRESENT	0
655038	652908	20264J	PARTICIPANT	\N	PRESENT	0
656069	656064	19723Y	PARTICIPANT	\N	EXCUSE	0
656070	656064	04043D	PARTICIPANT	\N	EXCUSE	0
656071	656064	11067R	PARTICIPANT	\N	EXCUSE	0
656072	656064	19735D	PARTICIPANT	\N	EXCUSE	0
656073	656064	19503N	PARTICIPANT	\N	PRESENT	0
656373	655742	20056C	PARTICIPANT	\N	PRESENT	0
656079	656064	01048V	PARTICIPANT	\N	PRESENT	0
656307	656175	11064N	PARTICIPANT	\N	PRESENT	0
656308	656175	19421M	PARTICIPANT	\N	EXCUSE	0
656309	656175	14267Y	PARTICIPANT	\N	EXCUSE	0
656310	656175	01058X	PARTICIPANT	\N	EXCUSE	0
656311	656175	11054L	PARTICIPANT	\N	EXCUSE	0
656312	656175	11066Q	PARTICIPANT	\N	EXCUSE	0
656313	656175	14211G	PARTICIPANT	\N	EXCUSE	0
656314	656175	19583F	PARTICIPANT	\N	EXCUSE	0
656364	655742	19611R	PRESIDENT	0	PRESENT	0
656365	655742	20142Y	PARTICIPANT	\N	PRESENT	0
656366	655742	19399H	PARTICIPANT	\N	PRESENT	0
656374	655742	04070G	PARTICIPANT	\N	PRESENT	0
656375	655742	19651A	PARTICIPANT	\N	PRESENT	0
656376	655742	04059M	PARTICIPANT	\N	PRESENT	0
656377	655742	19693L	PARTICIPANT	\N	PRESENT	0
656378	655742	19758L	PARTICIPANT	\N	PRESENT	0
656379	655742	20026V	PARTICIPANT	\N	PRESENT	0
656380	655742	20172F	PARTICIPANT	\N	PRESENT	0
656391	655742	20132W	PARTICIPANT	\N	PRESENT	0
656399	655742	14073Q	PARTICIPANT	\N	PRESENT	0
656400	655742	20052X	PARTICIPANT	\N	PRESENT	0
656401	655742	14229S	PARTICIPANT	\N	PRESENT	0
656419	655742	14030Q	PARTICIPANT	\N	PRESENT	0
657797	657524	20104S	PARTICIPANT	\N	EXCUSE	0
659664	659663	19533U	PARTICIPANT	\N	PRESENT	0
658358	658356	11026G	PARTICIPANT	\N	PRESENT	0
658359	658356	14042U	PARTICIPANT	\N	PRESENT	0
659669	659408	11010L	PARTICIPANT	\N	EXCUSE	0
659670	659409	11010L	PARTICIPANT	\N	EXCUSE	0
659968	659967	19699S	PARTICIPANT	\N	PRESENT	0
659969	659967	19643A	PARTICIPANT	\N	PRESENT	0
659970	659967	20052X	PARTICIPANT	\N	PRESENT	0
659974	659973	20172F	PARTICIPANT	\N	PRESENT	0
661267	661197	14042U	PARTICIPANT	\N	PRESENT	0
661268	661197	14071N	PARTICIPANT	\N	PRESENT	0
661269	661204	14071N	PARTICIPANT	\N	PRESENT	0
661271	661241	14213J	PARTICIPANT	\N	PRESENT	0
661272	661241	20130U	PARTICIPANT	\N	PRESENT	0
661277	661263	10006L	PARTICIPANT	\N	PRESENT	0
661278	661263	14042U	PARTICIPANT	\N	PRESENT	0
661279	661263	14213J	PARTICIPANT	\N	PRESENT	0
661280	661263	19415P	PARTICIPANT	\N	PRESENT	0
661281	661263	19691J	PARTICIPANT	\N	PRESENT	0
661282	661263	18193Q	PARTICIPANT	\N	PRESENT	0
661283	661263	20130U	PARTICIPANT	\N	PRESENT	0
661284	661263	17965H	PARTICIPANT	\N	PRESENT	0
661285	661263	19703U	PARTICIPANT	\N	PRESENT	0
661286	661263	04092N	PARTICIPANT	\N	PRESENT	0
660746	659412	19441R	PARTICIPANT	\N	PRESENT	0
660747	659412	11053K	PARTICIPANT	\N	PRESENT	0
660749	659412	14083S	PARTICIPANT	\N	PRESENT	0
660750	659412	14255U	PARTICIPANT	\N	PRESENT	0
660751	659412	17023S	PARTICIPANT	\N	PRESENT	0
660752	659412	01025N	PARTICIPANT	\N	PRESENT	0
660753	659412	19745F	PARTICIPANT	\N	PRESENT	0
660754	659412	19691J	PARTICIPANT	\N	PRESENT	0
660755	659412	14231L	PARTICIPANT	\N	PRESENT	0
660756	659412	20136B	PARTICIPANT	\N	PRESENT	0
660757	659412	17229F	PARTICIPANT	\N	PRESENT	0
660758	659412	19611R	PARTICIPANT	\N	PRESENT	0
660759	659412	19367Y	PARTICIPANT	\N	PRESENT	0
660760	659412	19581D	PARTICIPANT	\N	PRESENT	0
660761	659412	14187A	PARTICIPANT	\N	PRESENT	0
660762	659412	19575F	PARTICIPANT	\N	PRESENT	0
660763	659412	14275Y	PARTICIPANT	\N	PRESENT	0
660764	659412	19739H	PARTICIPANT	\N	PRESENT	0
660765	659412	19369B	PARTICIPANT	\N	PRESENT	0
660766	659412	01034P	PARTICIPANT	\N	PRESENT	0
660767	659412	20040T	PARTICIPANT	\N	PRESENT	0
660768	659412	20248J	PARTICIPANT	\N	PRESENT	0
660769	659412	19577H	PARTICIPANT	\N	PRESENT	0
660770	659412	14327T	PARTICIPANT	\N	PRESENT	0
660771	659412	14030Q	PARTICIPANT	\N	PRESENT	0
660772	659412	11070L	PARTICIPANT	\N	PRESENT	0
660773	659412	14205J	PARTICIPANT	\N	PRESENT	0
660774	659412	16685X	PARTICIPANT	\N	PRESENT	0
660775	659412	19479G	PARTICIPANT	\N	PRESENT	0
660776	659412	20066E	PARTICIPANT	\N	PRESENT	0
660777	659412	14179A	PARTICIPANT	\N	PRESENT	0
660778	659412	19699S	PARTICIPANT	\N	PRESENT	0
660779	659412	07029T	PARTICIPANT	\N	PRESENT	0
660780	659412	19543W	PARTICIPANT	\N	PRESENT	0
660781	659412	14189C	PARTICIPANT	\N	PRESENT	0
660782	659412	19553Y	PARTICIPANT	\N	PRESENT	0
660783	659412	01043Q	PARTICIPANT	\N	PRESENT	0
660784	659412	20286Q	PARTICIPANT	\N	PRESENT	0
660785	659412	14073Q	PARTICIPANT	\N	PRESENT	0
660786	659412	19826F	PARTICIPANT	\N	PRESENT	0
660787	659412	19335Q	PARTICIPANT	\N	PRESENT	0
660788	659412	14105F	PARTICIPANT	\N	PRESENT	0
660789	659412	05012A	PARTICIPANT	\N	PRESENT	0
660790	659412	19349W	PARTICIPANT	\N	PRESENT	0
660791	659412	11085T	PARTICIPANT	\N	PRESENT	0
660792	659412	19681G	PARTICIPANT	\N	PRESENT	0
660793	659412	20132W	PARTICIPANT	\N	PRESENT	0
660794	659412	20048C	PARTICIPANT	\N	PRESENT	0
660795	659412	20144B	PARTICIPANT	\N	PRESENT	0
660796	659412	14219Q	PARTICIPANT	\N	PRESENT	0
660797	659412	11043H	PARTICIPANT	\N	PRESENT	0
660798	659412	19531S	PARTICIPANT	\N	PRESENT	0
660801	659412	14193X	PARTICIPANT	\N	PRESENT	0
660802	659412	20094J	PARTICIPANT	\N	PRESENT	0
660803	659412	19717B	PARTICIPANT	\N	PRESENT	0
660804	659412	14121F	PARTICIPANT	\N	PRESENT	0
660805	659412	20086J	PARTICIPANT	\N	PRESENT	0
660806	659412	19663E	PARTICIPANT	\N	PRESENT	0
660807	659412	20128B	PARTICIPANT	\N	PRESENT	0
660808	659412	04071H	PARTICIPANT	\N	PRESENT	0
660809	659412	01060R	PARTICIPANT	\N	PRESENT	0
660810	659412	11054L	PARTICIPANT	\N	PRESENT	0
660811	659412	19251M	PARTICIPANT	\N	PRESENT	0
660816	659412	20266L	PARTICIPANT	\N	PRESENT	0
660819	659412	14031R	PARTICIPANT	\N	PRESENT	0
661113	659413	99004R	PARTICIPANT	\N	PRESENT	0
661114	659413	08073C	PARTICIPANT	\N	PRESENT	0
661115	659413	04008A	PARTICIPANT	\N	PRESENT	0
661121	659413	19057M	PARTICIPANT	\N	PRESENT	0
661117	659413	20090E	PARTICIPANT	\N	PRESENT	0
661118	659413	11043H	PARTICIPANT	\N	PRESENT	0
661119	659413	14109K	PARTICIPANT	\N	PRESENT	0
661132	659413	19782L	PARTICIPANT	\N	PRESENT	0
661140	659413	11045K	PARTICIPANT	\N	PRESENT	0
661123	659413	19545Y	PARTICIPANT	\N	PRESENT	0
661124	659413	20134Y	PARTICIPANT	\N	PRESENT	0
661125	659413	04085P	PARTICIPANT	\N	PRESENT	0
661138	659413	19441R	PARTICIPANT	\N	PRESENT	0
661127	659413	19507S	PARTICIPANT	\N	PRESENT	0
661128	659413	20110Q	PARTICIPANT	\N	PRESENT	0
661129	659413	14151M	PARTICIPANT	\N	PRESENT	0
661130	659413	19629C	PARTICIPANT	\N	PRESENT	0
661131	659413	07029T	PARTICIPANT	\N	PRESENT	0
661344	659413	20072C	PARTICIPANT	\N	PRESENT	0
661134	659413	19467C	PARTICIPANT	\N	PRESENT	0
661135	659413	08018U	PARTICIPANT	\N	PRESENT	0
661136	659413	19760E	PARTICIPANT	\N	PRESENT	0
661137	659413	14069U	PARTICIPANT	\N	PRESENT	0
661139	659413	14033T	PARTICIPANT	\N	PRESENT	0
661141	659413	95063L	PARTICIPANT	\N	PRESENT	0
661142	659413	19681G	PARTICIPANT	\N	PRESENT	0
661143	659413	20034V	PARTICIPANT	\N	PRESENT	0
661144	659413	04047H	PARTICIPANT	\N	PRESENT	0
661145	659413	19549D	PARTICIPANT	\N	PRESENT	0
661146	659361	14097Y	PARTICIPANT	\N	PRESENT	0
661147	659361	19443T	PARTICIPANT	\N	PRESENT	0
661148	659361	12041X	PARTICIPANT	\N	PRESENT	0
661149	659361	19565D	PARTICIPANT	\N	PRESENT	0
661150	659361	20072C	PARTICIPANT	\N	PRESENT	0
661151	659361	11041F	PARTICIPANT	\N	PRESENT	0
661152	659361	01058X	PARTICIPANT	\N	PRESENT	0
661153	659361	16685X	PARTICIPANT	\N	PRESENT	0
661154	659361	11027H	PARTICIPANT	\N	PRESENT	0
661155	659361	01024M	PARTICIPANT	\N	PRESENT	0
661156	659361	11054L	PARTICIPANT	\N	PRESENT	0
661157	659361	11066Q	PARTICIPANT	\N	PRESENT	0
661158	659361	19669L	PARTICIPANT	\N	PRESENT	0
661159	659361	08056B	PARTICIPANT	\N	PRESENT	0
661160	659361	12028B	PARTICIPANT	\N	PRESENT	0
661161	659361	20064C	PARTICIPANT	\N	PRESENT	0
661162	659361	19421M	PARTICIPANT	\N	PRESENT	0
661163	659361	19347U	PARTICIPANT	\N	PRESENT	0
661164	659361	08061X	PARTICIPANT	\N	PRESENT	0
661165	659361	14211G	PARTICIPANT	\N	PRESENT	0
661166	659361	19583F	PARTICIPANT	\N	PRESENT	0
661167	659361	08047A	PARTICIPANT	\N	PRESENT	0
661168	659413	20032T	PARTICIPANT	\N	PRESENT	0
661169	659413	19695N	PARTICIPANT	\N	PRESENT	0
661170	659413	04045F	PARTICIPANT	\N	PRESENT	0
661171	659413	19301E	PARTICIPANT	\N	PRESENT	0
661172	659413	10015M	PARTICIPANT	\N	PRESENT	0
661173	659413	20074E	PARTICIPANT	\N	PRESENT	0
661174	659361	04042C	PRESIDENT	0	PRESENT	0
661175	659361	14193X	PARTICIPANT	\N	PRESENT	0
661176	659361	14059S	PARTICIPANT	\N	PRESENT	0
661177	659361	04035D	PARTICIPANT	\N	PRESENT	0
661178	659361	14133K	PARTICIPANT	\N	PRESENT	0
661179	659361	14267Y	PARTICIPANT	\N	PRESENT	0
661180	659361	14255U	PARTICIPANT	\N	PRESENT	0
661181	659413	14021P	PARTICIPANT	\N	PRESENT	0
661182	659413	19581D	PARTICIPANT	\N	PRESENT	0
661183	659413	20066E	PARTICIPANT	\N	PRESENT	0
661184	659413	20114U	PARTICIPANT	\N	PRESENT	0
661185	659413	14147R	PARTICIPANT	\N	PRESENT	0
661186	659413	14215L	PARTICIPANT	\N	PRESENT	0
661187	659413	19251M	PARTICIPANT	\N	PRESENT	0
661188	659413	19747H	PARTICIPANT	\N	PRESENT	0
661189	659413	19667J	PARTICIPANT	\N	PRESENT	0
661190	659413	19826F	PARTICIPANT	\N	PRESENT	0
661191	659413	14037X	PARTICIPANT	\N	PRESENT	0
661192	659413	20122U	PARTICIPANT	\N	PRESENT	0
661193	659413	20106U	PARTICIPANT	\N	PRESENT	0
661194	659413	20024T	PARTICIPANT	\N	PRESENT	0
661195	659413	01048V	PARTICIPANT	\N	PRESENT	0
661196	659413	20120S	PARTICIPANT	\N	PRESENT	0
661198	659413	19768N	PARTICIPANT	\N	PRESENT	0
661199	659413	14053L	PARTICIPANT	\N	PRESENT	0
661200	659413	11072N	PARTICIPANT	\N	PRESENT	0
661201	659413	20266L	PARTICIPANT	\N	PRESENT	0
661202	659413	19447X	PARTICIPANT	\N	PRESENT	0
661203	659413	19525U	PARTICIPANT	\N	PRESENT	0
661205	659413	11097X	PARTICIPANT	\N	PRESENT	0
661342	659413	04071H	PARTICIPANT	\N	PRESENT	0
661343	659413	14267Y	PARTICIPANT	\N	PRESENT	0
661345	659413	19749K	PARTICIPANT	\N	PRESENT	0
661346	659413	14255U	PARTICIPANT	\N	PRESENT	0
661347	659413	14207L	PARTICIPANT	\N	PRESENT	0
661348	659413	19399H	PARTICIPANT	\N	PRESENT	0
661349	659413	14133K	PARTICIPANT	\N	PRESENT	0
661350	659413	20044X	PARTICIPANT	\N	PRESENT	0
661351	659413	20052X	PARTICIPANT	\N	PRESENT	0
656417	656416	14123H	PARTICIPANT	\N	PRESENT	0
661235	659085	20126Y	PARTICIPANT	\N	PRESENT	0
665817	664586	19717B	PARTICIPANT	\N	PRESENT	1
665818	664586	97011G	PARTICIPANT	\N	PRESENT	0
665819	664586	20034V	PRESIDENT	0	PRESENT	0
665822	664586	14059S	PARTICIPANT	\N	EXCUSE	0
665823	664586	12016W	PARTICIPANT	\N	EXCUSE	0
665824	664586	11043H	PARTICIPANT	\N	EXCUSE	0
665825	664586	14331P	PARTICIPANT	\N	EXCUSE	0
665861	664586	19715Y	PARTICIPANT	\N	EXCUSE	0
665862	664586	05008E	PARTICIPANT	\N	EXCUSE	0
665890	665889	14042U	PARTICIPANT	\N	PRESENT	0
665891	665889	11097X	PARTICIPANT	\N	PRESENT	0
666529	666528	14331P	PRESIDENT	0	PRESENT	0
666530	666528	11101A	PARTICIPANT	\N	PRESENT	0
666531	666528	19701S	PARTICIPANT	\N	PRESENT	0
666532	666528	14001X	PARTICIPANT	\N	PRESENT	0
666533	666528	04070G	PARTICIPANT	\N	PRESENT	0
666534	666528	20128B	PARTICIPANT	\N	PRESENT	0
666535	666528	14357A	PARTICIPANT	\N	PRESENT	0
666536	666528	19593H	PARTICIPANT	\N	PRESENT	0
666537	666528	19725B	PARTICIPANT	\N	PRESENT	0
666538	666528	20100N	PARTICIPANT	\N	PRESENT	0
666539	666528	04045F	PARTICIPANT	\N	PRESENT	0
666540	666528	20286Q	PARTICIPANT	\N	PRESENT	0
666541	666528	14097Y	PARTICIPANT	\N	PRESENT	0
666542	666528	14073Q	PARTICIPANT	\N	PRESENT	0
666543	666528	14133K	PARTICIPANT	\N	PRESENT	0
666544	666528	20094J	PARTICIPANT	\N	PRESENT	0
666545	666528	11026G	PARTICIPANT	\N	PRESENT	0
666546	666528	14026U	PARTICIPANT	\N	EXCUSE	0
666547	666528	19333N	PARTICIPANT	\N	PRESENT	0
666557	666528	08018U	PARTICIPANT	\N	EXCUSE	0
666558	666528	04057K	PARTICIPANT	\N	EXCUSE	0
672513	669899	14195A	PARTICIPANT	\N	PRESENT	0
672514	669899	19415P	PARTICIPANT	\N	PRESENT	0
672515	669899	20090E	PARTICIPANT	\N	PRESENT	0
672516	669899	19683J	PARTICIPANT	\N	PRESENT	0
672495	669899	11070L	PARTICIPANT	\N	PRESENT	0
672517	669899	11067R	PARTICIPANT	\N	PRESENT	0
672518	669899	19715Y	PARTICIPANT	\N	PRESENT	0
672519	669899	18193Q	PARTICIPANT	\N	PRESENT	0
672520	669899	11031D	PARTICIPANT	\N	PRESENT	0
672521	669899	14042U	PARTICIPANT	\N	PRESENT	0
672522	669899	11097X	PARTICIPANT	\N	PRESENT	0
672523	669899	19691J	PARTICIPANT	\N	PRESENT	0
672524	669899	19569H	PARTICIPANT	\N	PRESENT	0
672525	669899	14026U	PARTICIPANT	\N	PRESENT	0
672526	669899	99004R	PARTICIPANT	\N	PRESENT	0
672527	669899	19663E	PARTICIPANT	\N	PRESENT	0
672528	669899	20034V	PARTICIPANT	\N	PRESENT	0
672529	669899	19657G	PARTICIPANT	\N	PRESENT	0
672530	669899	14213J	PARTICIPANT	\N	PRESENT	0
672531	669899	10006L	PARTICIPANT	\N	PRESENT	0
672532	669899	20130U	PARTICIPANT	\N	PRESENT	0
672533	669899	17965H	PARTICIPANT	\N	PRESENT	0
672534	669899	14071N	PARTICIPANT	\N	PRESENT	0
672536	669899	20132W	PARTICIPANT	\N	PRESENT	0
672538	669899	04043D	PARTICIPANT	\N	PRESENT	0
672541	669899	19467C	PARTICIPANT	\N	PRESENT	0
672542	669899	14217N	PARTICIPANT	\N	PRESENT	0
672543	669899	20066E	PARTICIPANT	\N	PRESENT	0
672544	669899	20266L	PARTICIPANT	\N	PRESENT	0
672545	669899	19723Y	PARTICIPANT	\N	PRESENT	0
672546	669899	07004J	PARTICIPANT	\N	PRESENT	0
672547	669899	19697Q	PARTICIPANT	\N	PRESENT	0
672548	669899	19515S	PARTICIPANT	\N	PRESENT	0
672549	669899	19553Y	PARTICIPANT	\N	PRESENT	0
672550	669899	19591F	PARTICIPANT	\N	PRESENT	0
672553	669899	17779H	PARTICIPANT	\N	PRESENT	0
672554	669899	19711U	PARTICIPANT	\N	PRESENT	0
672555	669899	04085P	PARTICIPANT	\N	PRESENT	0
672556	669899	14281W	PARTICIPANT	\N	PRESENT	0
672557	669899	19747H	PARTICIPANT	\N	PRESENT	0
672558	669899	20092G	PARTICIPANT	\N	PRESENT	0
672559	669899	20148F	PARTICIPANT	\N	PRESENT	0
672563	669899	20082E	PARTICIPANT	\N	PRESENT	0
672564	669899	01028R	PARTICIPANT	\N	PRESENT	0
672565	669899	19673G	PARTICIPANT	\N	PRESENT	0
672566	669899	08034U	PARTICIPANT	\N	PRESENT	0
672567	669899	14357A	PARTICIPANT	\N	PRESENT	0
672568	669899	20022R	PARTICIPANT	\N	PRESENT	0
672569	669899	19347U	PARTICIPANT	\N	PRESENT	0
672579	669899	19577H	PARTICIPANT	\N	PRESENT	0
672585	669899	04047H	PARTICIPANT	\N	PRESENT	0
672586	669899	14251Q	PARTICIPANT	\N	PRESENT	0
672587	669899	20070A	PARTICIPANT	\N	PRESENT	0
672811	672808	14329V	PARTICIPANT	\N	PRESENT	0
677393	677304	14331P	PARTICIPANT	\N	PRESENT	0
677394	677304	20050V	PARTICIPANT	\N	PRESENT	0
677402	677304	19866P	PARTICIPANT	\N	EXCUSE	0
677403	677304	20062A	PARTICIPANT	\N	EXCUSE	0
678408	678407	14267Y	PARTICIPANT	\N	PRESENT	0
678410	678407	14133K	PARTICIPANT	\N	PRESENT	0
678411	678407	08047A	PARTICIPANT	\N	PRESENT	0
678412	678407	14059S	PARTICIPANT	\N	PRESENT	0
678424	678423	19399H	PARTICIPANT	\N	PRESENT	0
678425	678423	04070G	PARTICIPANT	\N	EXCUSE	0
678426	678423	20050V	PARTICIPANT	\N	EXCUSE	0
678427	678423	01028R	PARTICIPANT	\N	EXCUSE	0
678428	678423	14193X	PARTICIPANT	\N	EXCUSE	0
680917	678420	18193Q	PARTICIPANT	\N	PRESENT	0
680965	676614	14107H	PARTICIPANT	\N	PRESENT	0
680966	676614	14195A	PARTICIPANT	\N	PRESENT	0
680967	676614	20062A	PARTICIPANT	\N	PRESENT	0
680968	676614	11067R	PARTICIPANT	\N	PRESENT	0
680969	676614	11054L	PARTICIPANT	\N	PRESENT	0
680970	676614	11040E	PARTICIPANT	\N	PRESENT	0
680971	676614	19565D	PARTICIPANT	\N	PRESENT	0
680972	676614	11031D	PARTICIPANT	\N	PRESENT	0
680973	676614	19760E	PARTICIPANT	\N	PRESENT	0
680974	676614	19683J	PARTICIPANT	\N	PRESENT	0
680975	676614	20030R	PARTICIPANT	\N	PRESENT	0
680976	676614	19503N	PARTICIPANT	\N	PRESENT	0
680977	676614	19599P	PARTICIPANT	\N	PRESENT	0
680978	676614	17779H	PARTICIPANT	\N	PRESENT	0
680979	676614	20130U	PARTICIPANT	\N	PRESENT	0
680980	676614	19583F	PARTICIPANT	\N	PRESENT	0
680981	676614	14021P	PARTICIPANT	\N	PRESENT	0
680982	676614	19697Q	PARTICIPANT	\N	PRESENT	0
680983	676614	01034P	PARTICIPANT	\N	PRESENT	0
680984	676614	04045F	PARTICIPANT	\N	PRESENT	0
680985	676614	20248J	PARTICIPANT	\N	PRESENT	0
680986	676614	19671E	PARTICIPANT	\N	PRESENT	0
680987	676614	14217N	PARTICIPANT	\N	PRESENT	0
680988	676614	19591F	PARTICIPANT	\N	PRESENT	0
680989	676614	19553Y	PARTICIPANT	\N	PRESENT	0
680990	676614	19691J	PARTICIPANT	\N	PRESENT	0
680991	676614	14215L	PARTICIPANT	\N	PRESENT	0
680992	676614	11097X	PARTICIPANT	\N	PRESENT	0
680993	676614	19415P	PARTICIPANT	\N	PRESENT	0
680994	676614	14071N	PARTICIPANT	\N	PRESENT	0
680995	676614	19703U	PARTICIPANT	\N	PRESENT	0
680996	676614	97011G	PARTICIPANT	\N	PRESENT	0
680997	676614	20090E	PARTICIPANT	\N	PRESENT	0
680998	676614	14213J	PARTICIPANT	\N	PRESENT	0
680999	676614	20172F	PARTICIPANT	\N	PRESENT	0
681000	676614	19954N	PARTICIPANT	\N	PRESENT	0
680963	676614	14026U	PARTICIPANT	\N	PRESENT	0
680964	676614	19569H	PARTICIPANT	\N	PRESENT	0
681001	676614	19573D	PARTICIPANT	\N	PRESENT	0
681002	676614	20180F	PARTICIPANT	\N	PRESENT	0
681003	676614	14355X	PARTICIPANT	\N	PRESENT	0
681004	676614	20044X	PARTICIPANT	\N	PRESENT	0
681005	676614	18193Q	PARTICIPANT	\N	PRESENT	0
681006	676614	14121F	PARTICIPANT	\N	PRESENT	0
681007	676614	10006L	PARTICIPANT	\N	PRESENT	0
681009	676614	14042U	PARTICIPANT	\N	PRESENT	0
681010	676614	19651A	PARTICIPANT	\N	PRESENT	0
681011	676614	14267Y	PARTICIPANT	\N	PRESENT	0
681012	676614	08028W	PARTICIPANT	\N	PRESENT	0
681013	676614	14069U	PARTICIPANT	\N	PRESENT	0
681014	676614	19673G	PARTICIPANT	\N	PRESENT	0
681015	676614	20116W	PARTICIPANT	\N	PRESENT	0
681016	676614	04057K	PARTICIPANT	\N	PRESENT	0
681018	676614	18083K	PARTICIPANT	\N	PRESENT	0
681019	676614	08034U	PARTICIPANT	\N	PRESENT	0
681020	676614	20040T	PARTICIPANT	\N	PRESENT	0
681021	676614	08056B	PARTICIPANT	\N	PRESENT	0
681022	676614	11045K	PARTICIPANT	\N	PRESENT	0
681023	676614	19723Y	PARTICIPANT	\N	PRESENT	0
658362	656882	01060R	PARTICIPANT	\N	PRESENT	0
658363	656882	20128B	PARTICIPANT	\N	PRESENT	0
658364	656882	08069G	PARTICIPANT	\N	PRESENT	0
658365	656882	20048C	PARTICIPANT	\N	PRESENT	0
658366	656882	19749K	PARTICIPANT	\N	PRESENT	0
658367	656882	19685L	PARTICIPANT	\N	PRESENT	0
658368	656882	14071N	PARTICIPANT	\N	PRESENT	0
658369	656882	17737W	PARTICIPANT	\N	PRESENT	0
658370	656882	17023S	PARTICIPANT	\N	PRESENT	0
658371	656882	11099A	PARTICIPANT	\N	PRESENT	0
658372	656882	20152B	PARTICIPANT	\N	PRESENT	0
658373	656882	19551W	PARTICIPANT	\N	PRESENT	0
658374	656882	19637C	PARTICIPANT	\N	PRESENT	0
658735	656883	19057M	PARTICIPANT	\N	PRESENT	0
658736	656883	20124W	PARTICIPANT	\N	PRESENT	0
658737	656883	11033F	PARTICIPANT	\N	PRESENT	0
658738	656883	14251Q	PARTICIPANT	\N	PRESENT	0
658739	656883	19671E	PARTICIPANT	\N	PRESENT	0
658740	656883	19866P	PARTICIPANT	\N	PRESENT	0
658741	656883	20072C	PARTICIPANT	\N	PRESENT	0
658744	656883	19691J	PARTICIPANT	\N	PRESENT	0
658746	656883	19479G	PARTICIPANT	\N	PRESENT	0
658747	656178	11065P	PARTICIPANT	\N	EXCUSE	0
658748	656883	20042V	PARTICIPANT	\N	PRESENT	0
658749	656883	19577H	PARTICIPANT	\N	PRESENT	0
658750	656883	19421M	PARTICIPANT	\N	PRESENT	0
658751	656718	20130U	PARTICIPANT	\N	PRESENT	0
658752	656718	11067R	PARTICIPANT	\N	PRESENT	0
658753	656718	04092N	PARTICIPANT	\N	PRESENT	0
658754	656718	19798U	PARTICIPANT	\N	PRESENT	0
658755	656718	19569H	PARTICIPANT	\N	PRESENT	0
658756	656718	11097X	PARTICIPANT	\N	PRESENT	0
658757	656718	18193Q	PARTICIPANT	\N	PRESENT	0
658758	656718	14026U	PARTICIPANT	\N	PRESENT	0
658759	656718	19703U	PARTICIPANT	\N	PRESENT	0
658760	656718	20248J	PARTICIPANT	\N	PRESENT	0
658761	656718	20066E	PARTICIPANT	\N	PRESENT	0
658762	656718	14042U	PARTICIPANT	\N	PRESENT	0
658763	656718	14213J	PARTICIPANT	\N	PRESENT	0
658764	656718	14071N	PARTICIPANT	\N	PRESENT	0
658765	656718	10006L	PRESIDENT	0	PRESENT	0
658767	656178	17367Q	PARTICIPANT	\N	PRESENT	0
658768	656883	11031D	PARTICIPANT	\N	PRESENT	0
658771	656883	14033T	PARTICIPANT	\N	PRESENT	0
658773	656883	04035D	PARTICIPANT	\N	PRESENT	0
658774	656883	11045K	PARTICIPANT	\N	PRESENT	0
658775	656883	14030Q	PARTICIPANT	\N	PRESENT	0
658776	656883	14059S	PARTICIPANT	\N	PRESENT	0
658777	656883	20172F	PARTICIPANT	\N	PRESENT	0
658778	656883	14275Y	PARTICIPANT	\N	PRESENT	0
658779	656883	17737W	PARTICIPANT	\N	PRESENT	0
658780	656883	14151M	PARTICIPANT	\N	PRESENT	0
658781	656883	19611R	PARTICIPANT	\N	PRESENT	0
658783	656883	20034V	PARTICIPANT	\N	PRESENT	0
658784	656178	19701S	PARTICIPANT	\N	PRESENT	0
658785	656178	14169X	PARTICIPANT	\N	PRESENT	0
658786	656178	20068G	PARTICIPANT	\N	PRESENT	0
658790	656883	19545Y	PARTICIPANT	\N	PRESENT	0
658791	656883	14083S	PARTICIPANT	\N	PRESENT	0
658792	656883	19631V	PARTICIPANT	\N	PRESENT	0
658795	656883	19347U	PARTICIPANT	\N	PRESENT	0
658796	656883	08061X	PARTICIPANT	\N	PRESENT	0
658797	656883	14021P	PARTICIPANT	\N	PRESENT	0
658798	656718	01034P	PARTICIPANT	\N	PRESENT	0
658799	656718	17965H	PARTICIPANT	\N	PRESENT	0
658800	656718	19553Y	PARTICIPANT	\N	PRESENT	0
658801	656718	14217N	PARTICIPANT	\N	PRESENT	0
658802	656718	19415P	PARTICIPANT	\N	EXCUSE	0
658803	656718	19683J	PARTICIPANT	\N	EXCUSE	0
658804	656883	19715Y	PARTICIPANT	\N	PRESENT	0
658805	656883	19591F	PARTICIPANT	\N	PRESENT	0
658806	656883	14097Y	PARTICIPANT	\N	PRESENT	0
658807	656883	20030R	PARTICIPANT	\N	PRESENT	0
658808	656883	04085P	PARTICIPANT	\N	PRESENT	0
658810	656883	19697Q	PARTICIPANT	\N	PRESENT	0
658811	656883	20150Y	PARTICIPANT	\N	PRESENT	0
658812	656883	19695N	PARTICIPANT	\N	PRESENT	0
658813	656883	97011G	PARTICIPANT	\N	PRESENT	0
658814	656883	14109K	PARTICIPANT	\N	PRESENT	0
658815	656883	11012A	PARTICIPANT	\N	PRESENT	0
658816	656883	12016W	PARTICIPANT	\N	PRESENT	0
658817	656178	05012A	PARTICIPANT	\N	PRESENT	0
658818	656883	17023S	PARTICIPANT	\N	PRESENT	0
658860	656884	14083S	PARTICIPANT	\N	PRESENT	0
658861	656884	19717B	PARTICIPANT	\N	PRESENT	0
658862	656884	19715Y	PARTICIPANT	\N	PRESENT	0
658863	656884	14097Y	PARTICIPANT	\N	PRESENT	0
658864	656884	12016W	PARTICIPANT	\N	PRESENT	0
658865	656884	20028X	PARTICIPANT	\N	PRESENT	0
658866	656884	19631V	PARTICIPANT	\N	PRESENT	0
658867	656884	19301E	PARTICIPANT	\N	PRESENT	0
658868	656884	19057M	PARTICIPANT	\N	PRESENT	0
658869	656884	19563B	PARTICIPANT	\N	PRESENT	0
658870	656884	19866P	PARTICIPANT	\N	PRESENT	0
658871	656884	11012A	PARTICIPANT	\N	PRESENT	0
658872	656884	14059S	PARTICIPANT	\N	PRESENT	0
658873	656884	19577H	PARTICIPANT	\N	PRESENT	0
658874	656884	20146D	PARTICIPANT	\N	PRESENT	0
658875	656884	19565D	PARTICIPANT	\N	PRESENT	0
658876	656884	20034V	PARTICIPANT	\N	PRESENT	0
658877	656884	97011G	PARTICIPANT	\N	PRESENT	0
658878	656884	14275Y	PARTICIPANT	\N	PRESENT	0
658879	656884	14147R	PARTICIPANT	\N	PRESENT	0
658880	656884	20148F	PARTICIPANT	\N	PRESENT	0
658881	656884	20038A	PARTICIPANT	\N	PRESENT	0
658882	656884	14179A	PARTICIPANT	\N	PRESENT	0
658883	656884	20030R	PARTICIPANT	\N	PRESENT	0
658884	656884	19701S	PARTICIPANT	\N	PRESENT	0
658901	656884	08034U	PARTICIPANT	\N	PRESENT	0
658902	656884	18083K	PARTICIPANT	\N	PRESENT	0
658903	656884	20090E	PARTICIPANT	\N	PRESENT	0
658904	656884	18193Q	PARTICIPANT	\N	PRESENT	0
658905	656884	20062A	PARTICIPANT	\N	PRESENT	0
658906	656884	11045K	PARTICIPANT	\N	PRESENT	0
658907	656884	19399H	PARTICIPANT	\N	PRESENT	0
658908	656884	19533U	PARTICIPANT	\N	PRESENT	0
658732	656178	14237S	PARTICIPANT	\N	PRESENT	0
658733	656178	14031R	PARTICIPANT	\N	PRESENT	0
658734	656883	20266L	PARTICIPANT	\N	PRESENT	0
658909	656884	14031R	PARTICIPANT	\N	PRESENT	0
658910	656884	14331P	PARTICIPANT	\N	PRESENT	0
658911	656884	14089Y	PARTICIPANT	\N	PRESENT	0
658912	656884	20180F	PARTICIPANT	\N	PRESENT	0
658913	656884	20110Q	PARTICIPANT	\N	PRESENT	0
658858	656884	95063L	PARTICIPANT	\N	PRESENT	0
658859	656884	17023S	PARTICIPANT	\N	PRESENT	0
658914	656884	19747H	PARTICIPANT	\N	PRESENT	0
658915	656884	04047H	PARTICIPANT	\N	PRESENT	0
658916	656884	19515S	PARTICIPANT	\N	PRESENT	0
658946	656885	04047H	PARTICIPANT	\N	PRESENT	0
658947	656885	20110Q	PARTICIPANT	\N	PRESENT	0
658948	656885	11099A	PARTICIPANT	\N	PRESENT	0
658963	656885	14151M	PARTICIPANT	\N	PRESENT	0
658950	656885	19717B	PARTICIPANT	\N	PRESENT	0
658951	656885	14055N	PARTICIPANT	\N	PRESENT	0
658968	656885	20034V	PARTICIPANT	\N	PRESENT	0
658953	656885	19533U	PARTICIPANT	\N	PRESENT	0
658954	656885	20038A	PARTICIPANT	\N	PRESENT	0
658955	656885	20180F	PARTICIPANT	\N	PRESENT	0
658956	656885	19747H	PARTICIPANT	\N	PRESENT	0
658957	656885	19515S	PARTICIPANT	\N	PRESENT	0
658958	656885	14147R	PARTICIPANT	\N	PRESENT	0
658959	656885	14053L	PARTICIPANT	\N	PRESENT	0
658960	656885	14089Y	PARTICIPANT	\N	PRESENT	0
658961	656885	19563B	PARTICIPANT	\N	PRESENT	0
658962	656885	19333N	PARTICIPANT	\N	PRESENT	0
658964	656885	04085P	PARTICIPANT	\N	PRESENT	0
658965	656885	19301E	PARTICIPANT	\N	PRESENT	0
658966	656885	20090E	PARTICIPANT	\N	PRESENT	0
658967	656885	19715Y	PARTICIPANT	\N	PRESENT	0
658969	656885	14021P	PARTICIPANT	\N	PRESENT	0
658944	656885	11045K	PARTICIPANT	\N	PRESENT	0
658945	656885	11072N	PARTICIPANT	\N	PRESENT	0
656956	656877	14026U	PARTICIPANT	\N	PRESENT	0
656957	656877	14073Q	PARTICIPANT	\N	PRESENT	0
656958	656877	20090E	PARTICIPANT	\N	PRESENT	0
656959	656877	20098N	PARTICIPANT	\N	PRESENT	0
656960	656877	19593H	PARTICIPANT	\N	PRESENT	0
656961	656877	20068G	PARTICIPANT	\N	PRESENT	0
656962	656877	19367Y	PARTICIPANT	\N	PRESENT	0
656963	656877	20038A	PARTICIPANT	\N	PRESENT	0
656964	656877	19399H	PARTICIPANT	\N	PRESENT	0
656965	656877	08045X	PARTICIPANT	\N	PRESENT	0
656966	656877	11033F	PARTICIPANT	\N	PRESENT	0
656967	656877	04047H	PARTICIPANT	\N	PRESENT	0
656968	656877	19713W	PARTICIPANT	\N	PRESENT	0
656969	656877	20124W	PARTICIPANT	\N	PRESENT	0
656970	656877	20078J	PARTICIPANT	\N	PRESENT	0
656971	656877	20026V	PARTICIPANT	\N	PRESENT	0
656972	656877	19649G	PARTICIPANT	\N	PRESENT	0
656973	656877	01028R	PARTICIPANT	\N	PRESENT	0
656974	656877	04059M	PARTICIPANT	\N	PRESENT	0
656975	656877	19527W	PARTICIPANT	\N	PRESENT	0
656976	656877	20042V	PARTICIPANT	\N	PRESENT	0
656977	656877	20248J	PARTICIPANT	\N	PRESENT	0
656978	656877	19659J	PARTICIPANT	\N	PRESENT	0
656979	656877	19715Y	PARTICIPANT	\N	PRESENT	0
656980	656877	14225N	PARTICIPANT	\N	PRESENT	0
656981	656877	20080C	PARTICIPANT	\N	PRESENT	0
656982	656877	12028B	PARTICIPANT	\N	PRESENT	0
656983	656877	14021P	PARTICIPANT	\N	PRESENT	0
656984	656877	11045K	PARTICIPANT	\N	PRESENT	0
656985	656877	20116W	PARTICIPANT	\N	PRESENT	0
656986	656877	20072C	PARTICIPANT	\N	PRESENT	0
656987	656877	19782L	PARTICIPANT	\N	PRESENT	0
656988	656877	19749K	PARTICIPANT	\N	PRESENT	0
656989	656877	14215L	PARTICIPANT	\N	PRESENT	0
656990	656877	19725B	PARTICIPANT	\N	PRESENT	0
656991	656877	01062T	PARTICIPANT	\N	PRESENT	0
656992	656877	11040E	PARTICIPANT	\N	PRESENT	0
656993	656877	11074Q	PARTICIPANT	\N	PRESENT	0
656994	656877	19760E	PARTICIPANT	\N	PRESENT	0
656995	656877	11056N	PARTICIPANT	\N	PRESENT	0
656996	656877	11067R	PARTICIPANT	\N	PRESENT	0
656997	656877	18193Q	PARTICIPANT	\N	PRESENT	0
656998	656877	17965H	PARTICIPANT	\N	PRESENT	0
656999	656877	20070A	PARTICIPANT	\N	PRESENT	0
657000	656877	20110Q	PARTICIPANT	\N	PRESENT	0
657001	656877	11027H	PARTICIPANT	\N	PRESENT	0
657002	656877	20134Y	PARTICIPANT	\N	PRESENT	0
657003	656877	95063L	PARTICIPANT	\N	PRESENT	0
657004	656877	19585H	PARTICIPANT	\N	PRESENT	0
657005	656877	11104D	PARTICIPANT	\N	PRESENT	0
657006	656877	20084G	PARTICIPANT	\N	PRESENT	0
657007	656877	11026G	PARTICIPANT	\N	PRESENT	0
657008	656877	20028X	PARTICIPANT	\N	PRESENT	0
657009	656877	14211G	PARTICIPANT	\N	PRESENT	0
657010	656877	19745F	PARTICIPANT	\N	PRESENT	0
657011	656877	19826F	PARTICIPANT	\N	PRESENT	0
657012	656877	14189C	PARTICIPANT	\N	PRESENT	0
657013	656877	19577H	PARTICIPANT	\N	PRESENT	0
657014	656877	14053L	PARTICIPANT	\N	PRESENT	0
657015	656877	19798U	PARTICIPANT	\N	PRESENT	0
657016	656877	19651A	PARTICIPANT	\N	PRESENT	0
657017	656877	07033P	PARTICIPANT	\N	PRESENT	0
657018	656877	05008E	PARTICIPANT	\N	PRESENT	0
657019	656877	11103C	PARTICIPANT	\N	PRESENT	0
657020	656877	08056B	PARTICIPANT	\N	PRESENT	0
657021	656877	14253S	PARTICIPANT	\N	PRESENT	0
657022	656877	19711U	PARTICIPANT	\N	PRESENT	0
657023	656877	11077T	PARTICIPANT	\N	PRESENT	0
657024	656877	20108W	PARTICIPANT	\N	PRESENT	0
657025	656877	20024T	PARTICIPANT	\N	PRESENT	0
657026	656877	14147R	PARTICIPANT	\N	PRESENT	0
657027	656877	01024M	PARTICIPANT	\N	PRESENT	0
657028	656877	20138D	PARTICIPANT	\N	PRESENT	0
657029	656877	08028W	PARTICIPANT	\N	PRESENT	0
657030	656877	20032T	PARTICIPANT	\N	PRESENT	0
657031	656877	20030R	PARTICIPANT	\N	PRESENT	0
657032	656877	14223L	PARTICIPANT	\N	PRESENT	0
657033	656877	20052X	PARTICIPANT	\N	PRESENT	0
657034	656877	14089Y	PARTICIPANT	\N	PRESENT	0
657035	656877	20060X	PARTICIPANT	\N	PRESENT	0
657036	656877	20018V	PARTICIPANT	\N	PRESENT	0
657037	656877	04042C	PARTICIPANT	\N	PRESENT	0
657038	656877	14107H	PARTICIPANT	\N	PRESENT	0
657039	656877	20082E	PARTICIPANT	\N	PRESENT	0
657040	656877	11072N	PARTICIPANT	\N	PRESENT	0
657041	656877	19729F	PARTICIPANT	\N	PRESENT	0
657042	656877	14207L	PARTICIPANT	\N	PRESENT	0
657043	656877	19719D	PARTICIPANT	\N	PRESENT	0
657044	656877	19629C	PARTICIPANT	\N	PRESENT	0
657045	656877	19747H	PARTICIPANT	\N	PRESENT	0
657046	656877	20086J	PARTICIPANT	\N	PRESENT	0
657047	656877	20126Y	PARTICIPANT	\N	PRESENT	0
657048	656877	19671E	PARTICIPANT	\N	PRESENT	0
657050	656877	14237S	PARTICIPANT	\N	PRESENT	0
657051	656877	18083K	PARTICIPANT	\N	PRESENT	0
657052	656877	20074E	PARTICIPANT	\N	PRESENT	0
657053	656877	99004R	PARTICIPANT	\N	PRESENT	0
657054	656877	19575F	PARTICIPANT	\N	PRESENT	0
657055	656877	19693L	PARTICIPANT	\N	PRESENT	0
657056	656877	19621T	PARTICIPANT	\N	PRESENT	0
657057	656877	20112S	PARTICIPANT	\N	PRESENT	0
657058	656877	19515S	PARTICIPANT	\N	PRESENT	0
657059	656877	19447X	PARTICIPANT	\N	PRESENT	0
657060	656877	19573D	PARTICIPANT	\N	PRESENT	0
657061	656877	20056C	PARTICIPANT	\N	PRESENT	0
657062	656877	19507S	PARTICIPANT	\N	PRESENT	0
657063	656877	14355X	PARTICIPANT	\N	PRESENT	0
657064	656877	19441R	PARTICIPANT	\N	PRESENT	0
657065	656877	14151M	PARTICIPANT	\N	PRESENT	0
657066	656877	10015M	PARTICIPANT	\N	PRESENT	0
657067	656877	19954N	PARTICIPANT	\N	PRESENT	0
657068	656877	20022R	PARTICIPANT	\N	PRESENT	0
657069	656877	14133K	PARTICIPANT	\N	PRESENT	0
657070	656877	08018U	PARTICIPANT	\N	PRESENT	0
657072	656877	14259Y	PARTICIPANT	\N	PRESENT	0
657073	656877	20172F	PARTICIPANT	\N	PRESENT	0
657074	656877	20114U	PARTICIPANT	\N	PRESENT	0
657075	656877	14331P	PARTICIPANT	\N	PRESENT	0
657076	656877	97011G	PARTICIPANT	\N	PRESENT	0
657077	656877	20150Y	PARTICIPANT	\N	PRESENT	0
657078	656877	19681G	PARTICIPANT	\N	PRESENT	0
657079	656877	01025N	PARTICIPANT	\N	PRESENT	0
657080	656877	19739H	PARTICIPANT	\N	PRESENT	0
657081	656877	19383Y	PARTICIPANT	\N	PRESENT	0
657082	656877	19675J	PARTICIPANT	\N	PRESENT	0
657083	656877	04085P	PARTICIPANT	\N	PRESENT	0
657084	656877	20036X	PARTICIPANT	\N	PRESENT	0
657085	656877	20136B	PARTICIPANT	\N	PRESENT	0
657086	656877	20130U	PARTICIPANT	\N	PRESENT	0
657087	656877	14231L	PARTICIPANT	\N	PRESENT	0
657088	656877	19697Q	PARTICIPANT	\N	PRESENT	0
657089	656877	08010L	PARTICIPANT	\N	PRESENT	0
657090	656877	20286Q	PARTICIPANT	\N	PRESENT	0
657091	656877	19443T	PARTICIPANT	\N	PRESENT	0
657092	656877	19691J	PARTICIPANT	\N	PRESENT	0
657093	656877	19479G	PARTICIPANT	\N	PRESENT	0
657094	656877	11097X	PARTICIPANT	\N	PRESENT	0
657095	656877	14105F	PARTICIPANT	\N	PRESENT	0
657096	656877	08061X	PARTICIPANT	\N	PRESENT	0
657097	656877	04045F	PARTICIPANT	\N	PRESENT	0
657098	656877	20062A	PARTICIPANT	\N	PRESENT	0
657099	656877	19591F	PARTICIPANT	\N	PRESENT	0
657100	656877	20180F	PARTICIPANT	\N	PRESENT	0
657101	656877	19467C	PARTICIPANT	\N	PRESENT	0
657102	656877	10006L	PARTICIPANT	\N	PRESENT	0
657103	656877	20066E	PARTICIPANT	\N	PRESENT	0
657104	656877	11054L	PARTICIPANT	\N	PRESENT	0
657105	656877	14121F	PARTICIPANT	\N	PRESENT	0
657106	656877	19545Y	PARTICIPANT	\N	PRESENT	0
657107	656877	19553Y	PARTICIPANT	\N	PRESENT	0
657108	656877	14069U	PARTICIPANT	\N	PRESENT	0
657109	656877	19543W	PARTICIPANT	\N	PRESENT	0
657110	656877	19723Y	PARTICIPANT	\N	PRESENT	0
657111	656877	19581D	PARTICIPANT	\N	PRESENT	0
657112	656877	19599P	PARTICIPANT	\N	PRESENT	0
657113	656877	14275Y	PARTICIPANT	\N	PRESENT	0
657114	656878	14026U	PARTICIPANT	\N	PRESENT	0
657115	656878	20090E	PARTICIPANT	\N	PRESENT	0
657116	656878	20098N	PARTICIPANT	\N	PRESENT	0
657117	656878	20068G	PARTICIPANT	\N	PRESENT	0
657118	656878	19367Y	PARTICIPANT	\N	PRESENT	0
661352	659413	20098N	PARTICIPANT	\N	PRESENT	0
661353	659413	08015R	PARTICIPANT	\N	PRESENT	0
661354	659413	19563B	PARTICIPANT	\N	PRESENT	0
661355	659413	14205J	PARTICIPANT	\N	PRESENT	0
661356	659413	19413M	PARTICIPANT	\N	PRESENT	0
661357	659413	11012A	PARTICIPANT	\N	PRESENT	0
661358	659413	14030Q	PARTICIPANT	\N	PRESENT	0
661359	659413	11110B	PARTICIPANT	\N	PRESENT	0
661416	659414	14257W	PARTICIPANT	\N	PRESENT	0
661417	659414	19651A	PARTICIPANT	\N	PRESENT	0
661418	659414	04045F	PARTICIPANT	\N	PRESENT	0
661419	659414	11072N	PARTICIPANT	\N	PRESENT	0
661420	659414	14207L	PARTICIPANT	\N	PRESENT	0
661421	659414	19681G	PARTICIPANT	\N	PRESENT	0
661422	659414	20072C	PARTICIPANT	\N	PRESENT	0
661423	659414	19525U	PARTICIPANT	\N	PRESENT	0
661427	659414	14037X	PARTICIPANT	\N	PRESENT	0
661425	659414	19782L	PARTICIPANT	\N	PRESENT	0
661426	659414	04047H	PARTICIPANT	\N	PRESENT	0
661428	659414	14249W	PARTICIPANT	\N	PRESENT	0
661429	659414	20074E	PARTICIPANT	\N	PRESENT	0
661430	659414	19503N	PARTICIPANT	\N	PRESENT	0
661431	659414	18083K	PARTICIPANT	\N	PRESENT	0
661432	659414	99004R	PARTICIPANT	\N	PRESENT	0
661433	659414	20102Q	PARTICIPANT	\N	PRESENT	0
661434	659414	11048N	PARTICIPANT	\N	PRESENT	0
661435	659414	20046A	PARTICIPANT	\N	PRESENT	0
661436	659414	14193X	PARTICIPANT	\N	PRESENT	0
661437	659414	14187A	PARTICIPANT	\N	PRESENT	0
661438	659414	19593H	PARTICIPANT	\N	PRESENT	0
661439	659414	04033B	PARTICIPANT	\N	PRESENT	0
661440	659414	11090Q	PARTICIPANT	\N	PRESENT	0
661441	659414	14069U	PARTICIPANT	\N	PRESENT	0
661442	659414	19758L	PARTICIPANT	\N	PRESENT	0
661443	659414	14071N	PARTICIPANT	\N	PRESENT	0
661444	659414	11110B	PARTICIPANT	\N	PRESENT	0
661445	659414	20152B	PARTICIPANT	\N	PRESENT	0
661446	659414	19295A	PARTICIPANT	\N	PRESENT	0
661447	659414	14053L	PARTICIPANT	\N	PRESENT	0
661448	659414	19413M	PARTICIPANT	\N	PRESENT	0
661449	659414	19399H	PARTICIPANT	\N	PRESENT	0
661450	659414	20092G	PARTICIPANT	\N	PRESENT	0
661451	659414	19711U	PARTICIPANT	\N	PRESENT	0
661452	659414	19533U	PARTICIPANT	\N	PRESENT	0
661453	659414	20120S	PARTICIPANT	\N	PRESENT	0
661482	659414	19715Y	PARTICIPANT	\N	PRESENT	0
661455	659414	19695N	PARTICIPANT	\N	PRESENT	0
661456	659414	14147R	PARTICIPANT	\N	PRESENT	0
661457	659414	11077T	PARTICIPANT	\N	PRESENT	0
661458	659414	19705W	PARTICIPANT	\N	PRESENT	0
661459	659414	18193Q	PARTICIPANT	\N	PRESENT	0
661460	659414	19707Y	PARTICIPANT	\N	PRESENT	0
661461	659414	19443T	PARTICIPANT	\N	PRESENT	0
661462	659414	14038Y	PARTICIPANT	\N	PRESENT	0
661463	659414	20038A	PARTICIPANT	\N	PRESENT	0
661464	659414	08061X	PARTICIPANT	\N	PRESENT	0
661465	659414	20056C	PARTICIPANT	\N	PRESENT	0
661466	659414	20026V	PARTICIPANT	\N	PRESENT	0
661467	659414	14097Y	PARTICIPANT	\N	PRESENT	0
661468	659414	19657G	PARTICIPANT	\N	PRESENT	0
661469	659414	14033T	PARTICIPANT	\N	PRESENT	0
661470	659414	20094J	PARTICIPANT	\N	PRESENT	0
661414	659414	86034E	PARTICIPANT	\N	PRESENT	0
661415	659414	19333N	PARTICIPANT	\N	PRESENT	0
661471	659414	20086J	PARTICIPANT	\N	PRESENT	0
661472	659414	17965H	PARTICIPANT	\N	PRESENT	0
661473	659414	19575F	PARTICIPANT	\N	PRESENT	0
661474	659414	20044X	PARTICIPANT	\N	PRESENT	0
661475	659414	14031R	PARTICIPANT	\N	PRESENT	0
661476	659414	20034V	PARTICIPANT	\N	PRESENT	0
661477	659414	19663E	PARTICIPANT	\N	PRESENT	0
661478	659414	07029T	PARTICIPANT	\N	PRESENT	0
661479	659414	19621T	PARTICIPANT	\N	PRESENT	0
661480	659414	11043H	PARTICIPANT	\N	PRESENT	0
661481	659414	19251M	PARTICIPANT	\N	PRESENT	0
661483	659414	11026G	PARTICIPANT	\N	PRESENT	0
661484	659414	20126Y	PARTICIPANT	\N	PRESENT	0
661485	659414	95063L	PARTICIPANT	\N	PRESENT	0
661486	659414	19349W	PARTICIPANT	\N	PRESENT	0
661487	659414	19563B	PARTICIPANT	\N	PRESENT	0
661488	659414	14251Q	PARTICIPANT	\N	PRESENT	0
661489	659414	19687N	PARTICIPANT	\N	PRESENT	0
661490	659414	19629C	PARTICIPANT	\N	PRESENT	0
661491	659414	19447X	PARTICIPANT	\N	PRESENT	0
661492	659414	19441R	PARTICIPANT	\N	PRESENT	0
661493	659414	19713W	PARTICIPANT	\N	PRESENT	0
661494	659414	20048C	PARTICIPANT	\N	PRESENT	0
661495	659414	20052X	PARTICIPANT	\N	PRESENT	0
661496	659414	20144B	PARTICIPANT	\N	PRESENT	0
661497	659414	20298U	PARTICIPANT	\N	PRESENT	0
661498	659414	20040T	PARTICIPANT	\N	PRESENT	0
661499	659414	14083S	PARTICIPANT	\N	PRESENT	0
661500	659414	19543W	PARTICIPANT	\N	PRESENT	0
661501	659414	19369B	PARTICIPANT	\N	PRESENT	0
661502	659414	14030Q	PARTICIPANT	\N	PRESENT	0
661503	659414	19619A	PARTICIPANT	\N	PRESENT	0
661504	659414	14267Y	PARTICIPANT	\N	PRESENT	0
661505	659414	20066E	PARTICIPANT	\N	PRESENT	0
661506	659414	01024M	PARTICIPANT	\N	PRESENT	0
661507	659414	14189C	PARTICIPANT	\N	PRESENT	0
661508	659414	19735D	PARTICIPANT	\N	PRESENT	0
661530	659414	01057W	PARTICIPANT	\N	PRESENT	0
661510	659414	11070L	PARTICIPANT	\N	PRESENT	0
661511	659414	20100N	PARTICIPANT	\N	PRESENT	0
661512	659414	19057M	PARTICIPANT	\N	PRESENT	0
661513	659414	20114U	PARTICIPANT	\N	PRESENT	0
661514	659414	01028R	PARTICIPANT	\N	PRESENT	0
661515	659414	11012A	PARTICIPANT	\N	PRESENT	0
661516	659414	11053K	PARTICIPANT	\N	PRESENT	0
661517	659414	20058E	PARTICIPANT	\N	PRESENT	0
661528	659414	20252E	PARTICIPANT	\N	PRESENT	0
661519	659414	14073Q	PARTICIPANT	\N	PRESENT	0
661520	659414	14059S	PARTICIPANT	\N	PRESENT	0
661521	659414	20124W	PARTICIPANT	\N	PRESENT	0
661522	659414	14259Y	PARTICIPANT	\N	PRESENT	0
661527	659414	20098N	PARTICIPANT	\N	PRESENT	0
661529	659414	19768N	PARTICIPANT	\N	PRESENT	0
661525	659414	19647E	PARTICIPANT	\N	PRESENT	0
661526	659414	05008E	PARTICIPANT	\N	PRESENT	0
661531	659414	14169X	PARTICIPANT	\N	PRESENT	0
661532	659414	01048V	PARTICIPANT	\N	PRESENT	0
661533	659414	17023S	PARTICIPANT	\N	PRESENT	0
661534	659414	14026U	PARTICIPANT	\N	PRESENT	0
661535	659414	14055N	PARTICIPANT	\N	PRESENT	0
661536	659414	19553Y	PARTICIPANT	\N	PRESENT	0
661817	661816	14215L	PARTICIPANT	\N	PRESENT	0
663850	663847	19515S	PARTICIPANT	\N	PRESENT	0
664486	661838	20034V	PARTICIPANT	\N	PRESENT	0
664487	661838	19643A	PARTICIPANT	\N	PRESENT	0
664677	664676	14111D	PARTICIPANT	\N	PRESENT	0
665163	665158	14213J	PARTICIPANT	\N	PRESENT	0
665164	665158	20130U	PARTICIPANT	\N	PRESENT	0
665170	665160	11097X	PARTICIPANT	\N	PRESENT	0
665166	665159	14213J	PARTICIPANT	\N	PRESENT	0
665167	665159	11097X	PARTICIPANT	\N	PRESENT	0
665168	665160	10006L	PARTICIPANT	\N	PRESENT	0
665169	665160	14213J	PARTICIPANT	\N	PRESENT	0
665171	665162	14213J	PARTICIPANT	\N	PRESENT	0
665172	665162	11097X	PARTICIPANT	\N	PRESENT	0
665173	665161	14213J	PARTICIPANT	\N	PRESENT	0
665195	665194	19503N	PARTICIPANT	\N	PRESENT	0
665197	665196	19503N	PARTICIPANT	\N	PRESENT	0
665199	665198	19503N	PARTICIPANT	\N	PRESENT	0
665266	665262	14179A	PARTICIPANT	\N	PRESENT	0
665268	665267	14179A	PARTICIPANT	\N	PRESENT	0
665278	665277	12028B	PARTICIPANT	\N	PRESENT	0
665279	665277	11064N	PARTICIPANT	\N	PRESENT	0
665288	665287	19709B	PARTICIPANT	\N	EXCUSE	0
665289	665287	19723Y	PARTICIPANT	\N	PRESENT	0
665292	665287	19735D	PARTICIPANT	\N	EXCUSE	0
665744	665743	14255U	PARTICIPANT	\N	PRESENT	0
665745	665743	19719D	PARTICIPANT	\N	PRESENT	0
665746	665743	10015M	PARTICIPANT	\N	PRESENT	0
665747	665743	14169X	PARTICIPANT	\N	PRESENT	0
665749	665743	20120S	PARTICIPANT	\N	PRESENT	0
665750	665743	20022R	PARTICIPANT	\N	PRESENT	0
665811	665809	20074E	PARTICIPANT	\N	PRESENT	0
665812	665808	20074E	PARTICIPANT	\N	PRESENT	0
665813	665808	14147R	PARTICIPANT	\N	PRESENT	0
665864	665863	14213J	PARTICIPANT	\N	PRESENT	0
665865	665863	11097X	PARTICIPANT	\N	PRESENT	0
659077	656887	19719D	PARTICIPANT	\N	PRESENT	0
659078	656887	19715Y	PARTICIPANT	\N	PRESENT	0
659079	656887	19691J	PARTICIPANT	\N	PRESENT	0
659080	656887	20126Y	PARTICIPANT	\N	PRESENT	0
659081	656887	20086J	PARTICIPANT	\N	PRESENT	0
659082	656887	05012A	PARTICIPANT	\N	PRESENT	0
659083	656887	19643A	PARTICIPANT	\N	PRESENT	0
659086	656887	14205J	PARTICIPANT	\N	PRESENT	0
659087	656887	14147R	PARTICIPANT	\N	PRESENT	0
659088	656887	20082E	PARTICIPANT	\N	PRESENT	0
659094	656887	19741B	PARTICIPANT	\N	PRESENT	0
659095	656887	14001X	PARTICIPANT	\N	PRESENT	0
659096	656887	20062A	PARTICIPANT	\N	PRESENT	0
659098	656887	10015M	PARTICIPANT	\N	PRESENT	0
659099	656887	20136B	PARTICIPANT	\N	PRESENT	0
659100	656887	17737W	PARTICIPANT	\N	PRESENT	0
659101	656887	04045F	PARTICIPANT	\N	PRESENT	0
659103	656887	14030Q	PARTICIPANT	\N	PRESENT	0
659106	656887	19621T	PARTICIPANT	\N	PRESENT	0
659107	656887	20090E	PARTICIPANT	\N	PRESENT	0
659108	656887	19599P	PARTICIPANT	\N	PRESENT	0
659109	656887	19441R	PARTICIPANT	\N	PRESENT	0
659117	656887	97011G	PARTICIPANT	\N	PRESENT	0
659121	656887	19575F	PARTICIPANT	\N	PRESENT	0
659123	656887	10006L	PARTICIPANT	\N	PRESENT	0
659130	656887	01060R	PARTICIPANT	\N	PRESENT	0
659139	656887	20034V	PARTICIPANT	\N	PRESENT	0
659143	656887	11115U	PARTICIPANT	\N	PRESENT	0
659144	656887	20028X	PARTICIPANT	\N	PRESENT	0
659145	656887	04070G	PARTICIPANT	\N	PRESENT	0
659146	656887	11045K	PARTICIPANT	\N	PRESENT	0
659147	656887	19553Y	PARTICIPANT	\N	PRESENT	0
659148	656887	20172F	PARTICIPANT	\N	PRESENT	0
659164	656887	19693L	PARTICIPANT	\N	PRESENT	0
659169	656887	14042U	PARTICIPANT	\N	PRESENT	0
659249	656888	11077T	PARTICIPANT	\N	PRESENT	0
659250	656888	20082E	PARTICIPANT	\N	PRESENT	0
659251	656888	20050V	PARTICIPANT	\N	PRESENT	0
659252	656888	04045F	PARTICIPANT	\N	PRESENT	0
659246	656888	01043Q	PARTICIPANT	\N	PRESENT	0
659248	656888	20102Q	PARTICIPANT	\N	PRESENT	0
659253	656888	19866P	PARTICIPANT	\N	PRESENT	0
659254	656888	20090E	PARTICIPANT	\N	PRESENT	0
659255	656888	20032T	PARTICIPANT	\N	PRESENT	0
659256	656888	19798U	PARTICIPANT	\N	PRESENT	0
659257	656888	19693L	PARTICIPANT	\N	PRESENT	0
659258	656888	20054A	PARTICIPANT	\N	PRESENT	0
659259	656888	19533U	PARTICIPANT	\N	PRESENT	0
659260	656888	20034V	PARTICIPANT	\N	PRESENT	0
659261	656888	19515S	PARTICIPANT	\N	PRESENT	0
659262	656888	99004R	PARTICIPANT	\N	PRESENT	0
659263	656888	19369B	PARTICIPANT	\N	PRESENT	0
659264	656888	19301E	PARTICIPANT	\N	PRESENT	0
659265	656888	20150Y	PARTICIPANT	\N	PRESENT	0
659266	656888	14097Y	PARTICIPANT	\N	PRESENT	0
659267	656888	04057K	PARTICIPANT	\N	PRESENT	0
659268	656888	11090Q	PARTICIPANT	\N	PRESENT	0
659270	656888	20180F	PARTICIPANT	\N	PRESENT	0
659273	656888	19399H	PARTICIPANT	\N	PRESENT	0
659274	656888	19687N	PARTICIPANT	\N	PRESENT	0
659280	656888	97011G	PARTICIPANT	\N	PRESENT	0
659281	656888	11067R	PARTICIPANT	\N	PRESENT	0
659282	656888	14251Q	PARTICIPANT	\N	PRESENT	0
659283	656888	19715Y	PARTICIPANT	\N	PRESENT	0
659288	656888	08061X	PARTICIPANT	\N	PRESENT	0
659332	656889	11067R	PARTICIPANT	\N	PRESENT	0
659333	656889	14097Y	PARTICIPANT	\N	PRESENT	0
659334	656889	19715Y	PARTICIPANT	\N	PRESENT	0
659335	656889	20102Q	PARTICIPANT	\N	PRESENT	0
659336	656889	11077T	PARTICIPANT	\N	PRESENT	0
659337	656889	19687N	PARTICIPANT	\N	PRESENT	0
659338	656889	11012A	PARTICIPANT	\N	PRESENT	0
659339	656889	19591F	PARTICIPANT	\N	PRESENT	0
659340	656889	19301E	PARTICIPANT	\N	PRESENT	0
659341	656889	04057K	PARTICIPANT	\N	PRESENT	0
659342	656889	19569H	PARTICIPANT	\N	PRESENT	0
659343	656889	19798U	PARTICIPANT	\N	PRESENT	0
659344	656889	10006L	PARTICIPANT	\N	PRESENT	0
659345	656889	14071N	PARTICIPANT	\N	PRESENT	0
659346	656889	11090Q	PARTICIPANT	\N	PRESENT	0
659347	656889	20032T	PARTICIPANT	\N	PRESENT	0
659348	656889	20180F	PARTICIPANT	\N	PRESENT	0
659349	656889	19747H	PARTICIPANT	\N	PRESENT	0
659350	656889	20148F	PARTICIPANT	\N	PRESENT	0
659358	656889	19691J	PARTICIPANT	\N	PRESENT	0
659352	656889	04045F	PARTICIPANT	\N	PRESENT	0
659353	656889	11031D	PARTICIPANT	\N	PRESENT	0
659359	656889	19421M	PARTICIPANT	\N	PRESENT	0
659420	659419	20144B	PARTICIPANT	\N	PRESENT	0
659421	659419	19369B	PARTICIPANT	\N	PRESENT	0
659422	659419	20062A	PARTICIPANT	\N	PRESENT	0
659424	659423	20144B	PARTICIPANT	\N	PRESENT	0
659425	659423	14207L	PARTICIPANT	\N	PRESENT	0
659427	659426	14207L	PARTICIPANT	\N	PRESENT	0
659428	659426	08015R	PARTICIPANT	\N	PRESENT	0
659330	656889	01043Q	PARTICIPANT	\N	PRESENT	0
659331	656889	08061X	PARTICIPANT	\N	PRESENT	0
659429	659426	20144B	PARTICIPANT	\N	PRESENT	0
659431	659430	14207L	PARTICIPANT	\N	PRESENT	0
659432	659430	20144B	PARTICIPANT	\N	PRESENT	0
659435	659434	20144B	PARTICIPANT	\N	PRESENT	0
659436	659433	20144B	PARTICIPANT	\N	PRESENT	0
659437	659433	14207L	PARTICIPANT	\N	PRESENT	0
661612	659415	14033T	PARTICIPANT	\N	PRESENT	0
661617	659415	19747H	PARTICIPANT	\N	PRESENT	0
661618	659415	19667J	PARTICIPANT	\N	PRESENT	0
661624	659867	14038Y	PARTICIPANT	\N	PRESENT	0
661625	659867	14205J	PARTICIPANT	\N	PRESENT	0
661626	659867	01043Q	PARTICIPANT	\N	PRESENT	0
661627	659867	19441R	PARTICIPANT	\N	PRESENT	0
661628	659867	19413M	PARTICIPANT	\N	PRESENT	0
661629	659867	20144B	PARTICIPANT	\N	PRESENT	0
661630	659867	19575F	PARTICIPANT	\N	PRESENT	0
661631	659867	14033T	PARTICIPANT	\N	PRESENT	0
661632	659867	14207L	PARTICIPANT	\N	PRESENT	0
661633	659867	04045F	PARTICIPANT	\N	PRESENT	0
661634	659867	19747H	PARTICIPANT	\N	PRESENT	0
661669	659415	04085P	PARTICIPANT	\N	PRESENT	0
661680	659415	01028R	PARTICIPANT	\N	PRESENT	0
661681	659415	19721W	PARTICIPANT	\N	PRESENT	0
661684	659415	08018U	PARTICIPANT	\N	PRESENT	0
661685	659415	19701S	PARTICIPANT	\N	PRESENT	0
661687	659415	20092G	PARTICIPANT	\N	PRESENT	0
661691	659415	11026G	PARTICIPANT	\N	PRESENT	0
661692	659415	11053K	PARTICIPANT	\N	PRESENT	0
661720	659416	20090E	PARTICIPANT	\N	PRESENT	0
661723	659416	11045K	PARTICIPANT	\N	PRESENT	0
661724	659416	14151M	PARTICIPANT	\N	PRESENT	0
661725	659416	20110Q	PARTICIPANT	\N	PRESENT	0
661726	659416	11033F	PARTICIPANT	\N	PRESENT	0
661727	659416	19651A	PARTICIPANT	\N	PRESENT	0
661728	659416	20052X	PARTICIPANT	\N	PRESENT	0
661729	659416	07029T	PARTICIPANT	\N	PRESENT	0
661730	659416	19667J	PARTICIPANT	\N	PRESENT	0
661731	659416	20050V	PARTICIPANT	\N	PRESENT	0
661732	659416	19629C	PARTICIPANT	\N	PRESENT	0
661733	659416	19643A	PARTICIPANT	\N	PRESENT	0
661734	659416	20038A	PARTICIPANT	\N	PRESENT	0
661735	659416	14147R	PARTICIPANT	\N	PRESENT	0
661736	659416	19447X	PARTICIPANT	\N	PRESENT	0
661737	659416	04085P	PARTICIPANT	\N	PRESENT	0
661738	659416	19441R	PARTICIPANT	\N	PRESENT	0
661739	659416	14251Q	PARTICIPANT	\N	PRESENT	0
661740	659416	14179A	PARTICIPANT	\N	PRESENT	0
661741	659416	14038Y	PARTICIPANT	\N	PRESENT	0
661749	659416	19749K	PARTICIPANT	\N	PRESENT	0
661750	659416	95063L	PARTICIPANT	\N	PRESENT	0
661751	659416	19577H	PARTICIPANT	\N	PRESENT	0
661752	659416	19295A	PARTICIPANT	\N	PRESENT	0
661757	659416	01028R	PARTICIPANT	\N	PRESENT	0
661718	659416	04047H	PARTICIPANT	\N	PRESENT	0
661772	659416	08018U	PARTICIPANT	\N	PRESENT	0
661768	659416	19583F	PARTICIPANT	\N	PRESENT	0
661769	659416	14083S	PARTICIPANT	\N	PRESENT	0
661770	659416	14249W	PARTICIPANT	\N	PRESENT	0
661771	659416	11053K	PARTICIPANT	\N	PRESENT	0
661773	659416	01048V	PARTICIPANT	\N	PRESENT	0
661774	659416	04071H	PARTICIPANT	\N	PRESENT	0
661775	659416	99004R	PARTICIPANT	\N	PRESENT	0
661776	659416	19701S	PARTICIPANT	\N	PRESENT	0
661777	659416	19681G	PARTICIPANT	\N	PRESENT	0
658995	656886	04070G	PARTICIPANT	\N	PRESENT	0
658996	656886	20070A	PARTICIPANT	\N	PRESENT	0
658997	656886	20030R	PARTICIPANT	\N	PRESENT	0
658998	656886	20028X	PARTICIPANT	\N	PRESENT	0
658999	656886	20094J	PARTICIPANT	\N	PRESENT	0
659000	656886	19631V	PARTICIPANT	\N	PRESENT	0
659001	656886	14037X	PARTICIPANT	\N	PRESENT	0
659002	656886	19563B	PARTICIPANT	\N	PRESENT	0
659003	656886	14073Q	PARTICIPANT	\N	PRESENT	0
659004	656886	14205J	PARTICIPANT	\N	PRESENT	0
659005	656886	20286Q	PARTICIPANT	\N	PRESENT	0
659006	656886	11090Q	PARTICIPANT	\N	PRESENT	0
659007	656886	14257W	PARTICIPANT	\N	PRESENT	0
659008	656886	11077T	PARTICIPANT	\N	PRESENT	0
659009	656886	19515S	PARTICIPANT	\N	PRESENT	0
658993	656886	12041X	PARTICIPANT	\N	PRESENT	0
658994	656886	14331P	PARTICIPANT	\N	PRESENT	0
659010	656886	20054A	PARTICIPANT	\N	PRESENT	0
659011	656886	14033T	PARTICIPANT	\N	PRESENT	0
659012	656886	19695N	PARTICIPANT	\N	PRESENT	0
659013	656886	20102Q	PARTICIPANT	\N	PRESENT	0
659014	656886	14147R	PARTICIPANT	\N	PRESENT	0
659015	656886	14207L	PARTICIPANT	\N	PRESENT	0
659016	656886	18083K	PARTICIPANT	\N	PRESENT	0
659017	656886	20086J	PARTICIPANT	\N	PRESENT	0
659018	656886	20082E	PARTICIPANT	\N	PRESENT	0
659019	656886	11099A	PARTICIPANT	\N	PRESENT	0
659020	656886	20092G	PARTICIPANT	\N	PRESENT	0
659021	656886	11110B	PARTICIPANT	\N	PRESENT	0
659022	656886	14055N	PARTICIPANT	\N	PRESENT	0
659023	656886	19954N	PARTICIPANT	\N	PRESENT	0
659024	656886	20034V	PARTICIPANT	\N	PRESENT	0
659025	656886	20180F	PARTICIPANT	\N	PRESENT	0
659026	656886	14357A	PARTICIPANT	\N	PRESENT	0
659027	656886	07029T	PARTICIPANT	\N	PRESENT	0
659588	659587	19503N	PARTICIPANT	\N	PRESENT	0
659590	659589	19503N	PARTICIPANT	\N	PRESENT	0
659592	659591	19503N	PARTICIPANT	\N	PRESENT	0
659594	659593	19503N	PARTICIPANT	\N	PRESENT	0
659596	659595	11048N	PARTICIPANT	\N	PRESENT	0
659597	659595	14121F	PARTICIPANT	\N	PRESENT	0
659601	656810	11040E	PARTICIPANT	\N	PRESENT	0
659602	659598	11048N	PARTICIPANT	\N	PRESENT	0
659603	659598	14121F	PARTICIPANT	\N	PRESENT	0
659605	659604	11048N	PARTICIPANT	\N	PRESENT	0
659606	659604	14121F	PARTICIPANT	\N	PRESENT	0
659608	659607	11048N	PARTICIPANT	\N	PRESENT	0
659609	659607	19711U	PARTICIPANT	\N	PRESENT	0
659611	659610	19711U	PARTICIPANT	\N	PRESENT	1
659613	659612	04071H	PARTICIPANT	\N	PRESENT	0
665326	665325	14133K	PARTICIPANT	\N	PRESENT	0
665327	665325	11066Q	PARTICIPANT	\N	PRESENT	0
665329	665328	19709B	PARTICIPANT	\N	PRESENT	0
665330	665328	11041F	PARTICIPANT	\N	PRESENT	0
670139	669891	11064N	PARTICIPANT	\N	PRESENT	0
670140	669891	20264J	PARTICIPANT	\N	PRESENT	0
670141	669891	19687N	PARTICIPANT	\N	PRESENT	0
670142	669891	14223L	PARTICIPANT	\N	PRESENT	0
670150	669891	19703U	PARTICIPANT	\N	PRESENT	0
670151	669891	20134Y	PARTICIPANT	\N	PRESENT	0
670152	669891	14187A	PARTICIPANT	\N	PRESENT	0
670153	669891	20028X	PARTICIPANT	\N	PRESENT	0
670154	669891	20018V	PARTICIPANT	\N	PRESENT	0
670155	669891	20148F	PARTICIPANT	\N	PRESENT	0
670156	669891	19663E	PARTICIPANT	\N	PRESENT	0
670157	669891	20066E	PARTICIPANT	\N	PRESENT	0
670158	669891	97011G	PARTICIPANT	\N	PRESENT	0
670159	669891	17023S	PARTICIPANT	\N	PRESENT	0
670160	669891	19679N	PARTICIPANT	\N	PRESENT	0
670161	669891	14257W	PARTICIPANT	\N	PRESENT	0
670162	669891	01028R	PARTICIPANT	\N	PRESENT	0
670163	669891	14211G	PARTICIPANT	\N	PRESENT	0
670164	669891	20026V	PARTICIPANT	\N	PRESENT	0
670267	669892	20028X	PARTICIPANT	\N	PRESENT	0
670268	669892	11031D	PARTICIPANT	\N	PRESENT	0
670269	669892	19683J	PARTICIPANT	\N	PRESENT	0
670270	669892	17965H	PARTICIPANT	\N	PRESENT	0
670271	669892	19760E	PARTICIPANT	\N	PRESENT	0
670272	669892	14042U	PARTICIPANT	\N	PRESENT	0
670273	669892	20130U	PARTICIPANT	\N	PRESENT	0
670274	669892	19782L	PARTICIPANT	\N	PRESENT	0
670275	669892	20124W	PARTICIPANT	\N	PRESENT	0
670276	669892	11067R	PARTICIPANT	\N	PRESENT	0
670277	669892	14213J	PARTICIPANT	\N	PRESENT	0
670278	669892	20132W	PARTICIPANT	\N	PRESENT	0
670279	669892	14195A	PARTICIPANT	\N	PRESENT	0
670280	669892	20042V	PARTICIPANT	\N	PRESENT	0
670281	669892	19713W	PARTICIPANT	\N	PRESENT	0
670282	669892	20090E	PARTICIPANT	\N	PRESENT	0
670283	669892	19693L	PARTICIPANT	\N	PRESENT	0
670284	669892	20044X	PARTICIPANT	\N	PRESENT	0
670292	669892	20140W	PARTICIPANT	\N	PRESENT	0
670286	669892	20034V	PARTICIPANT	\N	PRESENT	0
670287	669892	14071N	PARTICIPANT	\N	PRESENT	0
670288	669892	19367Y	PARTICIPANT	\N	PRESENT	0
670289	669892	14281W	PARTICIPANT	\N	PRESENT	0
670290	669892	10006L	PARTICIPANT	\N	PRESENT	0
670291	669892	19347U	PARTICIPANT	\N	PRESENT	0
670293	669892	19798U	PARTICIPANT	\N	PRESENT	0
670294	669892	19569H	PARTICIPANT	\N	PRESENT	0
670295	669892	19703U	PARTICIPANT	\N	PRESENT	0
670296	669892	19679N	PARTICIPANT	\N	PRESENT	0
670297	669892	14223L	PARTICIPANT	\N	PRESENT	0
670298	669892	20024T	PARTICIPANT	\N	PRESENT	0
670299	669892	19657G	PARTICIPANT	\N	PRESENT	0
670300	669892	14187A	PARTICIPANT	\N	PRESENT	0
670301	669892	20026V	PARTICIPANT	\N	PRESENT	0
670302	669892	19687N	PARTICIPANT	\N	PRESENT	0
670303	669892	19697Q	PARTICIPANT	\N	PRESENT	0
670304	669892	19553Y	PARTICIPANT	\N	PRESENT	0
670305	669892	20040T	PARTICIPANT	\N	PRESENT	0
670306	669892	04092N	PARTICIPANT	\N	PRESENT	0
670307	669892	19577H	PARTICIPANT	\N	PRESENT	0
670308	669892	20018V	PARTICIPANT	\N	PRESENT	0
670309	669892	20266L	PARTICIPANT	\N	PRESENT	0
670310	669892	11097X	PARTICIPANT	\N	PRESENT	0
670311	669892	19415P	PARTICIPANT	\N	PRESENT	0
670312	669892	19663E	PARTICIPANT	\N	PRESENT	0
670313	669892	19723Y	PARTICIPANT	\N	PRESENT	0
670314	669892	20066E	PARTICIPANT	\N	PRESENT	0
670315	669892	08015R	PARTICIPANT	\N	PRESENT	0
670316	669892	17779H	PARTICIPANT	\N	PRESENT	0
670317	669892	08045X	PARTICIPANT	\N	PRESENT	0
670318	669892	01034P	PARTICIPANT	\N	PRESENT	0
670319	669892	20126Y	PARTICIPANT	\N	PRESENT	0
670320	669892	14217N	PARTICIPANT	\N	PRESENT	0
670321	669892	14026U	PARTICIPANT	\N	PRESENT	0
670322	669892	19715Y	PARTICIPANT	\N	PRESENT	0
670323	669892	20134Y	PARTICIPANT	\N	PRESENT	0
670324	669892	14211G	PARTICIPANT	\N	PRESENT	0
670325	669892	19691J	PARTICIPANT	\N	PRESENT	0
670326	669892	19591F	PARTICIPANT	\N	PRESENT	0
670327	669892	14073Q	PARTICIPANT	\N	PRESENT	0
670328	669892	14107H	PARTICIPANT	\N	PRESENT	0
670329	669892	19741B	PARTICIPANT	\N	PRESENT	0
670370	669893	95063L	PARTICIPANT	\N	PRESENT	0
670371	668919	19697Q	PARTICIPANT	\N	PRESENT	0
670372	668919	20090E	PARTICIPANT	\N	PRESENT	0
670373	668919	04057K	PARTICIPANT	\N	PRESENT	0
670265	669892	11045K	PARTICIPANT	\N	PRESENT	0
670266	669892	18193Q	PARTICIPANT	\N	PRESENT	0
670374	668919	14355X	PARTICIPANT	\N	PRESENT	0
670375	668919	19569H	PARTICIPANT	\N	PRESENT	0
670376	668919	19798U	PARTICIPANT	\N	PRESENT	0
670377	668919	11097X	PARTICIPANT	\N	PRESENT	0
670378	668919	20040T	PARTICIPANT	\N	PRESENT	0
670379	668919	14223L	PARTICIPANT	\N	PRESENT	0
670380	668919	20148F	PARTICIPANT	\N	PRESENT	0
670381	668919	14026U	PARTICIPANT	\N	PRESENT	0
670382	668919	19723Y	PARTICIPANT	\N	PRESENT	0
670383	668919	14042U	PARTICIPANT	\N	PRESENT	0
670384	668919	14195A	PARTICIPANT	\N	PRESENT	0
670385	668919	14213J	PARTICIPANT	\N	PRESENT	0
670386	668919	19367Y	PARTICIPANT	\N	PRESENT	0
670387	668919	14071N	PRESIDENT	0	PRESENT	0
670388	668919	19657G	PARTICIPANT	\N	PRESENT	0
670389	668919	14217N	PARTICIPANT	\N	PRESENT	0
670390	668919	19511N	PARTICIPANT	\N	PRESENT	0
670391	668919	04043D	PARTICIPANT	\N	PRESENT	0
670392	669893	14042U	PARTICIPANT	\N	PRESENT	0
670393	669893	11031D	PARTICIPANT	\N	PRESENT	0
657119	656878	20038A	PARTICIPANT	\N	PRESENT	0
657120	656878	08045X	PARTICIPANT	\N	PRESENT	0
657121	656878	11033F	PARTICIPANT	\N	PRESENT	0
657122	656878	04047H	PARTICIPANT	\N	PRESENT	0
657123	656878	20124W	PARTICIPANT	\N	PRESENT	0
657124	656878	20078J	PARTICIPANT	\N	PRESENT	0
657125	656878	20026V	PARTICIPANT	\N	PRESENT	0
657126	656878	19649G	PARTICIPANT	\N	PRESENT	0
657127	656878	01028R	PARTICIPANT	\N	PRESENT	0
657128	656878	19715Y	PARTICIPANT	\N	PRESENT	0
657129	656878	20080C	PARTICIPANT	\N	PRESENT	0
657130	656878	20116W	PARTICIPANT	\N	PRESENT	0
657131	656878	20072C	PARTICIPANT	\N	PRESENT	0
657132	656878	19782L	PARTICIPANT	\N	PRESENT	0
657133	656878	19749K	PARTICIPANT	\N	PRESENT	0
657134	656878	14215L	PARTICIPANT	\N	PRESENT	0
657135	656878	19725B	PARTICIPANT	\N	PRESENT	0
657136	656878	19760E	PARTICIPANT	\N	PRESENT	0
657137	656878	11067R	PARTICIPANT	\N	PRESENT	0
657138	656878	18193Q	PARTICIPANT	\N	PRESENT	0
657139	656878	17965H	PARTICIPANT	\N	PRESENT	0
657140	656878	95063L	PARTICIPANT	\N	PRESENT	0
657141	656878	19585H	PARTICIPANT	\N	PRESENT	0
657142	656878	11026G	PARTICIPANT	\N	PRESENT	0
657143	656878	14211G	PARTICIPANT	\N	PRESENT	0
657144	656878	19745F	PARTICIPANT	\N	PRESENT	0
657145	656878	19826F	PARTICIPANT	\N	PRESENT	0
657146	656878	14189C	PARTICIPANT	\N	PRESENT	0
657147	656878	19577H	PARTICIPANT	\N	PRESENT	0
657148	656878	14053L	PARTICIPANT	\N	PRESENT	0
657149	656878	19798U	PARTICIPANT	\N	PRESENT	0
657150	656878	19651A	PARTICIPANT	\N	PRESENT	0
657151	656878	05008E	PARTICIPANT	\N	PRESENT	0
657152	656878	14253S	PARTICIPANT	\N	PRESENT	0
657153	656878	11077T	PARTICIPANT	\N	PRESENT	0
657154	656878	01024M	PARTICIPANT	\N	PRESENT	0
657155	656878	08028W	PARTICIPANT	\N	PRESENT	0
657156	656878	20032T	PARTICIPANT	\N	PRESENT	0
657157	656878	20030R	PARTICIPANT	\N	PRESENT	0
657158	656878	14223L	PARTICIPANT	\N	PRESENT	0
657159	656878	14089Y	PARTICIPANT	\N	PRESENT	0
657160	656878	20060X	PARTICIPANT	\N	PRESENT	0
657161	656878	20018V	PARTICIPANT	\N	PRESENT	0
657162	656878	14107H	PARTICIPANT	\N	PRESENT	0
657163	656878	11072N	PARTICIPANT	\N	PRESENT	0
657164	656878	14207L	PARTICIPANT	\N	PRESENT	0
657165	656878	19629C	PARTICIPANT	\N	PRESENT	0
657166	656878	19747H	PARTICIPANT	\N	PRESENT	0
657167	656878	19671E	PARTICIPANT	\N	PRESENT	0
657168	656878	18083K	PARTICIPANT	\N	PRESENT	0
657169	656878	20074E	PARTICIPANT	\N	PRESENT	0
657170	656878	19693L	PARTICIPANT	\N	PRESENT	0
657171	656878	19621T	PARTICIPANT	\N	PRESENT	0
657172	656878	19515S	PARTICIPANT	\N	PRESENT	0
657173	656878	19573D	PARTICIPANT	\N	PRESENT	0
657174	656878	19507S	PARTICIPANT	\N	PRESENT	0
657175	656878	14355X	PARTICIPANT	\N	PRESENT	0
657176	656878	19954N	PARTICIPANT	\N	PRESENT	0
657177	656878	20172F	PARTICIPANT	\N	PRESENT	0
657178	656878	20114U	PARTICIPANT	\N	PRESENT	0
657179	656878	14331P	PARTICIPANT	\N	PRESENT	0
657180	656878	97011G	PARTICIPANT	\N	PRESENT	0
657181	656878	20150Y	PARTICIPANT	\N	PRESENT	0
657182	656878	19681G	PARTICIPANT	\N	PRESENT	0
657183	656878	01025N	PARTICIPANT	\N	PRESENT	0
657184	656878	19739H	PARTICIPANT	\N	PRESENT	0
657185	656878	19675J	PARTICIPANT	\N	PRESENT	0
657186	656878	20036X	PARTICIPANT	\N	PRESENT	0
657187	656878	20136B	PARTICIPANT	\N	PRESENT	0
657188	656878	14231L	PARTICIPANT	\N	PRESENT	0
657189	656878	19697Q	PARTICIPANT	\N	PRESENT	0
657190	656878	08010L	PARTICIPANT	\N	PRESENT	0
657191	656878	20286Q	PARTICIPANT	\N	PRESENT	0
657192	656878	19443T	PARTICIPANT	\N	PRESENT	0
657193	656878	19691J	PARTICIPANT	\N	PRESENT	0
657194	656878	19479G	PARTICIPANT	\N	PRESENT	0
657195	656878	11097X	PARTICIPANT	\N	PRESENT	0
657196	656878	14105F	PARTICIPANT	\N	PRESENT	0
657197	656878	08061X	PARTICIPANT	\N	PRESENT	0
657198	656878	04045F	PARTICIPANT	\N	PRESENT	0
657199	656878	20062A	PARTICIPANT	\N	PRESENT	0
657200	656878	19591F	PARTICIPANT	\N	PRESENT	0
657201	656878	20180F	PARTICIPANT	\N	PRESENT	0
657202	656878	19467C	PARTICIPANT	\N	PRESENT	0
657203	656878	10006L	PARTICIPANT	\N	PRESENT	0
657204	656878	11054L	PARTICIPANT	\N	PRESENT	0
657205	656878	14121F	PARTICIPANT	\N	PRESENT	0
657206	656878	19545Y	PARTICIPANT	\N	PRESENT	0
657207	656878	19553Y	PARTICIPANT	\N	PRESENT	0
657208	656878	14069U	PARTICIPANT	\N	PRESENT	0
657209	656878	19543W	PARTICIPANT	\N	PRESENT	0
657210	656878	19723Y	PARTICIPANT	\N	PRESENT	0
657211	656878	19581D	PARTICIPANT	\N	PRESENT	0
657212	656878	19599P	PARTICIPANT	\N	PRESENT	0
657213	656878	14275Y	PARTICIPANT	\N	PRESENT	0
657314	656879	14026U	PARTICIPANT	\N	PRESENT	0
657315	656879	19715Y	PARTICIPANT	\N	PRESENT	0
657316	656879	11031D	PARTICIPANT	\N	PRESENT	0
657317	656879	19760E	PARTICIPANT	\N	PRESENT	0
657318	656879	11067R	PARTICIPANT	\N	PRESENT	0
657319	656879	08045X	PARTICIPANT	\N	PRESENT	0
657320	656879	01028R	PARTICIPANT	\N	PRESENT	0
657321	656879	11054L	PARTICIPANT	\N	PRESENT	0
657322	656879	14121F	PARTICIPANT	\N	PRESENT	0
657323	656879	19725B	PARTICIPANT	\N	PRESENT	0
657324	656879	18193Q	PARTICIPANT	\N	PRESENT	0
657325	656879	17965H	PARTICIPANT	\N	PRESENT	0
657326	656879	14195A	PARTICIPANT	\N	PRESENT	0
657327	656879	19782L	PARTICIPANT	\N	PRESENT	0
657328	656879	19599P	PARTICIPANT	\N	PRESENT	0
657329	656879	19651A	PARTICIPANT	\N	PRESENT	0
657330	656879	04045F	PARTICIPANT	\N	PRESENT	0
657331	656879	19553Y	PARTICIPANT	\N	PRESENT	0
657332	656879	19745F	PARTICIPANT	\N	PRESENT	0
657333	656879	19691J	PARTICIPANT	\N	PRESENT	0
657334	656879	19479G	PARTICIPANT	\N	PRESENT	0
657335	656879	19543W	PARTICIPANT	\N	PRESENT	0
657336	656879	14275Y	PARTICIPANT	\N	PRESENT	0
657337	656879	01024M	PARTICIPANT	\N	PRESENT	0
657338	656879	14089Y	PARTICIPANT	\N	PRESENT	0
657339	656879	08061X	PARTICIPANT	\N	PRESENT	0
657340	656879	01025N	PARTICIPANT	\N	PRESENT	0
657341	656879	19569H	PARTICIPANT	\N	PRESENT	0
657342	656879	14189C	PARTICIPANT	\N	PRESENT	0
657343	656879	14215L	PARTICIPANT	\N	PRESENT	0
657344	656879	19747H	PARTICIPANT	\N	PRESENT	0
657345	656879	19671E	PARTICIPANT	\N	PRESENT	0
657346	656879	19367Y	PARTICIPANT	\N	PRESENT	0
657347	656879	20124W	PARTICIPANT	\N	PRESENT	0
657348	656879	20090E	PARTICIPANT	\N	PRESENT	0
657349	656879	20062A	PARTICIPANT	\N	PRESENT	0
657350	656879	19675J	PARTICIPANT	\N	PRESENT	0
657351	656879	97011G	PARTICIPANT	\N	PRESENT	0
657352	656879	19798U	PARTICIPANT	\N	PRESENT	0
657353	656879	10006L	PARTICIPANT	\N	PRESENT	0
657354	656879	14187A	PARTICIPANT	\N	PRESENT	0
657355	656879	14105F	PARTICIPANT	\N	PRESENT	0
657356	656879	14069U	PARTICIPANT	\N	PRESENT	0
657357	656879	11097X	PARTICIPANT	\N	PRESENT	0
657358	656879	19693L	PARTICIPANT	\N	PRESENT	0
657359	656879	20074E	PARTICIPANT	\N	PRESENT	0
657360	656879	20026V	PARTICIPANT	\N	PRESENT	0
657361	656879	20056C	PARTICIPANT	\N	PRESENT	0
657362	656879	19507S	PARTICIPANT	\N	PRESENT	0
657363	656879	19729F	PARTICIPANT	\N	PRESENT	0
657364	656879	19954N	PARTICIPANT	\N	PRESENT	0
657365	656879	18083K	PARTICIPANT	\N	PRESENT	0
657366	656879	14355X	PARTICIPANT	\N	PRESENT	0
657367	656879	19467C	PARTICIPANT	\N	PRESENT	0
657368	656879	19723Y	PARTICIPANT	\N	PRESENT	0
657369	656879	20180F	PARTICIPANT	\N	PRESENT	0
657370	656879	20038A	PARTICIPANT	\N	PRESENT	0
657371	656879	19515S	PARTICIPANT	\N	PRESENT	0
657372	656879	14331P	PARTICIPANT	\N	PRESENT	0
657373	656879	20032T	PARTICIPANT	\N	PRESENT	0
657374	656879	14147R	PARTICIPANT	\N	PRESENT	0
657375	656879	20024T	PARTICIPANT	\N	PRESENT	0
657376	656879	19703U	PARTICIPANT	\N	PRESENT	0
657377	656879	14223L	PARTICIPANT	\N	PRESENT	0
657378	656879	11077T	PARTICIPANT	\N	PRESENT	0
657379	656879	20130U	PARTICIPANT	\N	PRESENT	0
666504	666503	08018U	PARTICIPANT	\N	PRESENT	0
667205	664634	19717B	PARTICIPANT	\N	PRESENT	1
667206	664634	05008E	PARTICIPANT	\N	EXCUSE	0
667207	664634	19715Y	PARTICIPANT	\N	EXCUSE	0
667208	664634	14219Q	PARTICIPANT	\N	EXCUSE	0
667209	664634	20034V	PRESIDENT	0	PRESENT	0
667210	664634	12016W	PARTICIPANT	\N	EXCUSE	0
667211	664634	14331P	PARTICIPANT	\N	EXCUSE	0
667212	664634	11043H	PARTICIPANT	\N	EXCUSE	0
667476	664326	14327T	PARTICIPANT	\N	PRESENT	0
667477	664326	11040E	PARTICIPANT	\N	PRESENT	0
667478	664326	07029T	PARTICIPANT	\N	PRESENT	0
667479	664326	11048N	PARTICIPANT	\N	PRESENT	0
667480	664326	14042U	PARTICIPANT	\N	PRESENT	0
667481	664326	99004R	PARTICIPANT	\N	PRESENT	0
667482	664326	20914V	PARTICIPANT	\N	PRESENT	0
667483	664326	14225N	PRESIDENT	0	PRESENT	0
667484	664326	14173T	PARTICIPANT	\N	PRESENT	0
667486	667475	19741B	PARTICIPANT	\N	PRESENT	0
667487	664326	19647E	PARTICIPANT	\N	PRESENT	0
667488	664326	11070L	PARTICIPANT	\N	PRESENT	0
667489	667485	19741B	PARTICIPANT	\N	PRESENT	0
667490	664326	20044X	PARTICIPANT	\N	PRESENT	0
667491	664326	11053K	PARTICIPANT	\N	PRESENT	0
667492	664326	20116W	PARTICIPANT	\N	PRESENT	0
667493	664326	19671E	PARTICIPANT	\N	PRESENT	0
667494	664326	20070A	PARTICIPANT	\N	PRESENT	0
667495	664326	19711U	PARTICIPANT	\N	PRESENT	0
667496	664326	20126Y	PARTICIPANT	\N	PRESENT	0
667497	664326	08010L	PARTICIPANT	\N	PRESENT	0
667498	664326	14083S	PARTICIPANT	\N	PRESENT	0
667509	664326	04071H	PARTICIPANT	\N	PRESENT	0
667525	664326	19531S	PARTICIPANT	\N	PRESENT	0
667526	664326	20080C	PARTICIPANT	\N	EXCUSE	0
667541	664326	19687N	PARTICIPANT	\N	PRESENT	0
667542	664326	20050V	PARTICIPANT	\N	PRESENT	0
667543	664326	19667J	PARTICIPANT	\N	PRESENT	0
667569	667567	14173T	PARTICIPANT	\N	PRESENT	0
667570	667568	14173T	PARTICIPANT	\N	PRESENT	0
667572	667571	11053K	PARTICIPANT	\N	PRESENT	0
667575	667573	20126Y	PARTICIPANT	\N	PRESENT	0
667576	667574	20126Y	PARTICIPANT	\N	PRESENT	0
667578	667577	20086J	PARTICIPANT	\N	PRESENT	0
667579	664326	14331P	PARTICIPANT	\N	PRESENT	0
667606	659564	19701S	PARTICIPANT	\N	EXCUSE	0
667621	667620	01028R	PARTICIPANT	\N	PRESENT	0
667623	667622	11026G	PARTICIPANT	\N	PRESENT	0
667624	667622	19725B	PARTICIPANT	\N	PRESENT	0
667627	667625	14215L	PARTICIPANT	\N	PRESENT	0
667628	667625	14021P	PARTICIPANT	\N	PRESENT	0
667639	667638	14259Y	PARTICIPANT	\N	PRESENT	0
667640	667638	14097Y	PARTICIPANT	\N	PRESENT	0
667641	667638	99004R	PARTICIPANT	\N	PRESENT	0
667642	667638	20120S	PARTICIPANT	\N	PRESENT	0
667643	667638	14147R	PARTICIPANT	\N	PRESENT	0
667644	667638	14215L	PARTICIPANT	\N	PRESENT	0
667645	667638	20026V	PARTICIPANT	\N	PRESENT	0
667646	667638	14255U	PARTICIPANT	\N	PRESENT	0
667651	667648	20052X	PARTICIPANT	\N	PRESENT	0
667649	667648	14259Y	PARTICIPANT	\N	PRESENT	0
667650	667648	14097Y	PARTICIPANT	\N	PRESENT	0
667652	667648	14147R	PARTICIPANT	\N	PRESENT	0
667653	667648	20120S	PARTICIPANT	\N	PRESENT	0
667654	667648	14215L	PARTICIPANT	\N	PRESENT	0
667656	667648	20026V	PARTICIPANT	\N	PRESENT	0
667657	667648	19333N	PARTICIPANT	\N	PRESENT	0
667660	667659	19251M	PARTICIPANT	\N	PRESENT	0
667661	667659	19673G	PARTICIPANT	\N	PRESENT	0
667662	667659	19671E	PARTICIPANT	\N	PRESENT	0
667663	667659	19515S	PARTICIPANT	\N	PRESENT	0
667664	667659	17737W	PARTICIPANT	\N	PRESENT	0
667665	667659	19593H	PARTICIPANT	\N	PRESENT	0
667666	667659	17367Q	PARTICIPANT	\N	PRESENT	0
667667	667659	12028B	PARTICIPANT	\N	PRESENT	0
667668	667659	97011G	PARTICIPANT	\N	PRESENT	0
667669	667659	14109K	PARTICIPANT	\N	PRESENT	0
667670	667659	14147R	PARTICIPANT	\N	PRESENT	0
667671	667659	20112S	PARTICIPANT	\N	PRESENT	0
667673	667672	19647E	PARTICIPANT	\N	PRESENT	0
667674	667672	19709B	PARTICIPANT	\N	PRESENT	0
667678	667672	11012A	PARTICIPANT	\N	PRESENT	0
667676	667672	11026G	PARTICIPANT	\N	PRESENT	0
667677	667672	20264J	PARTICIPANT	\N	PRESENT	0
667679	667672	14255U	PARTICIPANT	\N	PRESENT	0
667681	667680	14259Y	PARTICIPANT	\N	PRESENT	0
667682	667680	14097Y	PARTICIPANT	\N	PRESENT	0
667684	667683	20114U	PARTICIPANT	\N	PRESENT	0
667685	667683	17737W	PARTICIPANT	\N	PRESENT	0
668095	667913	19383Y	PARTICIPANT	\N	PRESENT	0
667687	667683	04035D	PARTICIPANT	\N	PRESENT	0
667688	667683	14073Q	PARTICIPANT	\N	PRESENT	0
667689	667683	19699S	PARTICIPANT	\N	PRESENT	0
667690	667683	11026G	PARTICIPANT	\N	PRESENT	0
667691	667683	04070G	PARTICIPANT	\N	PRESENT	0
667692	667683	14357A	PARTICIPANT	\N	PRESENT	0
667703	667702	19629C	PARTICIPANT	\N	PRESENT	0
667694	667683	19333N	PARTICIPANT	\N	PRESENT	0
668094	665806	19719D	PARTICIPANT	\N	PRESENT	0
668097	667912	19383Y	PARTICIPANT	\N	PRESENT	0
668143	668138	19703U	PARTICIPANT	\N	PRESENT	0
668145	668144	19703U	PARTICIPANT	\N	PRESENT	0
668147	668146	19703U	PARTICIPANT	\N	PRESENT	1
668425	668424	04071H	PARTICIPANT	\N	PRESENT	0
668840	667226	14259Y	PARTICIPANT	\N	PRESENT	0
668841	667226	14069U	PARTICIPANT	\N	PRESENT	0
668851	667226	19585H	PARTICIPANT	\N	EXCUSE	0
669122	669121	11053K	PARTICIPANT	\N	PRESENT	0
669129	669128	08011M	PARTICIPANT	\N	PRESENT	0
669130	669128	14253S	PARTICIPANT	\N	PRESENT	0
669398	667725	11045K	PARTICIPANT	\N	PRESENT	0
669399	667725	20052X	PARTICIPANT	\N	PRESENT	0
669400	667725	20298U	PARTICIPANT	\N	PRESENT	0
669409	669408	20060X	PARTICIPANT	\N	PRESENT	0
669410	669408	20094J	PARTICIPANT	\N	PRESENT	0
669411	667725	20076G	PARTICIPANT	\N	PRESENT	0
669412	667725	18083K	PARTICIPANT	\N	PRESENT	0
669413	667725	19701S	PARTICIPANT	\N	PRESENT	0
669414	667725	20118Y	PARTICIPANT	\N	PRESENT	0
669415	667725	14329V	PARTICIPANT	\N	PRESENT	0
669416	667725	20024T	PARTICIPANT	\N	PRESENT	0
669417	667725	19695N	PARTICIPANT	\N	PRESENT	0
669418	667725	20102Q	PARTICIPANT	\N	PRESENT	0
669419	667725	20046A	PARTICIPANT	\N	PRESENT	0
669421	667725	14219Q	PARTICIPANT	\N	PRESENT	0
669422	667725	14031R	PARTICIPANT	\N	PRESENT	0
669423	667725	14231L	PARTICIPANT	\N	PRESENT	0
669424	667725	19577H	PARTICIPANT	\N	PRESENT	0
669425	667725	11074Q	PARTICIPANT	\N	PRESENT	0
669426	667725	19333N	PARTICIPANT	\N	PRESENT	0
669427	667725	08060W	PARTICIPANT	\N	PRESENT	0
669428	667725	14257W	PARTICIPANT	\N	PRESENT	0
669429	667725	19599P	PARTICIPANT	\N	PRESENT	0
669430	667725	19715Y	PARTICIPANT	\N	PRESENT	0
669431	667725	20028X	PARTICIPANT	\N	PRESENT	0
669432	667725	14205J	PARTICIPANT	\N	PRESENT	0
669433	667725	19820Y	PARTICIPANT	\N	PRESENT	0
669434	667725	20092G	PARTICIPANT	\N	PRESENT	0
669435	667725	19758L	PARTICIPANT	\N	PRESENT	0
669436	667725	19347U	PARTICIPANT	\N	PRESENT	0
669437	667725	11065P	PARTICIPANT	\N	PRESENT	0
669438	667725	14073Q	PARTICIPANT	\N	PRESENT	0
669439	667725	20142Y	PARTICIPANT	\N	PRESENT	0
669440	667725	19681G	PARTICIPANT	\N	PRESENT	0
669441	667725	19637C	PARTICIPANT	\N	PRESENT	0
669442	667725	19619A	PARTICIPANT	\N	PRESENT	0
669443	667725	14221J	PARTICIPANT	\N	PRESENT	0
669444	667725	20066E	PARTICIPANT	\N	PRESENT	0
669445	667725	19369B	PARTICIPANT	\N	PRESENT	0
669446	667725	19583F	PARTICIPANT	\N	PRESENT	0
669447	667725	19563B	PARTICIPANT	\N	PRESENT	0
669448	667725	14207L	PARTICIPANT	\N	PRESENT	0
669449	667725	19611R	PARTICIPANT	\N	PRESENT	0
669450	667725	17229F	PARTICIPANT	\N	PRESENT	0
669451	667725	20144B	PARTICIPANT	\N	PRESENT	0
655505	655425	19333N	PARTICIPANT	\N	PRESENT	0
655506	655425	20136B	PARTICIPANT	\N	PRESENT	0
655507	655425	14031R	PARTICIPANT	\N	PRESENT	0
655508	655425	14219Q	PRESIDENT	0	PRESENT	0
655509	655425	19820Y	PARTICIPANT	\N	PRESENT	0
655510	655425	19826F	PARTICIPANT	\N	PRESENT	0
655511	655425	17229F	PARTICIPANT	\N	PRESENT	0
655512	655425	19637C	PARTICIPANT	\N	PRESENT	0
655513	655425	18083K	PARTICIPANT	\N	PRESENT	0
655514	655425	19551W	PARTICIPANT	\N	PRESENT	0
655515	655425	20020P	PARTICIPANT	\N	PRESENT	0
655516	655425	19745F	PARTICIPANT	\N	PRESENT	0
655517	655425	20024T	PARTICIPANT	\N	PRESENT	0
655518	655425	19619A	PARTICIPANT	\N	PRESENT	0
655519	655425	19525U	PARTICIPANT	\N	PRESENT	0
655520	655425	20122U	PARTICIPANT	\N	PRESENT	0
655521	655425	19549D	PARTICIPANT	\N	PRESENT	0
655522	655425	20102Q	PARTICIPANT	\N	PRESENT	0
655523	655425	08060W	PARTICIPANT	\N	EXCUSE	0
655524	655425	20038A	PARTICIPANT	\N	EXCUSE	0
655525	655425	20076G	PARTICIPANT	\N	EXCUSE	0
655526	655425	19681G	PARTICIPANT	\N	EXCUSE	0
655527	655425	19599P	PARTICIPANT	\N	EXCUSE	0
655528	655425	14169X	PARTICIPANT	\N	EXCUSE	0
655529	655425	20100N	PARTICIPANT	\N	EXCUSE	0
655530	655425	19387D	PARTICIPANT	\N	PRESENT	0
655531	655425	20106U	PARTICIPANT	\N	PRESENT	0
655532	655425	19503N	PARTICIPANT	\N	PRESENT	0
655533	655465	19649G	PARTICIPANT	\N	PRESENT	0
655534	655465	20074E	PARTICIPANT	\N	PRESENT	0
655535	655465	11026G	PARTICIPANT	\N	PRESENT	0
655536	655465	04047H	PRESIDENT	1	PRESENT	0
655537	655465	11033F	PARTICIPANT	\N	PRESENT	0
655538	655465	01028R	PARTICIPANT	\N	PRESENT	0
655539	655465	19447X	PARTICIPANT	\N	PRESENT	0
655540	655465	11056N	PARTICIPANT	\N	PRESENT	0
655541	655465	95063L	PARTICIPANT	\N	PRESENT	0
655542	655465	19629C	PARTICIPANT	\N	PRESENT	0
655543	655465	07004J	PARTICIPANT	\N	PRESENT	0
655544	655465	20110Q	PARTICIPANT	\N	PRESENT	0
655545	655465	14147R	PARTICIPANT	\N	PRESENT	0
655546	655465	14151M	PARTICIPANT	\N	PRESENT	0
655547	655465	20114U	PARTICIPANT	\N	PRESENT	0
655548	655465	14215L	PRESIDENT	0	PRESENT	0
655549	655465	20022R	PARTICIPANT	\N	PRESENT	0
655550	655465	14021P	PARTICIPANT	\N	PRESENT	0
655622	655497	14038Y	PARTICIPANT	\N	PRESENT	0
655623	655497	19515S	PARTICIPANT	\N	PRESENT	0
655624	655497	20034V	PARTICIPANT	\N	PRESENT	0
655625	655497	20092G	PARTICIPANT	\N	PRESENT	0
655626	655497	19782L	PARTICIPANT	\N	PRESENT	0
655627	655497	01043Q	PARTICIPANT	\N	PRESENT	0
655628	655497	20082E	PARTICIPANT	\N	PRESENT	0
655629	655497	11090Q	PRESIDENT	0	PRESENT	0
655630	655497	14033T	PARTICIPANT	\N	PRESENT	0
655631	655497	04045F	PARTICIPANT	\N	PRESENT	0
655632	655497	19631V	PARTICIPANT	\N	PRESENT	0
655633	655497	14205J	PARTICIPANT	\N	PRESENT	0
655634	655497	20060X	PARTICIPANT	\N	PRESENT	0
655635	655497	20062A	PARTICIPANT	\N	PRESENT	0
655636	655497	19705W	PARTICIPANT	\N	PRESENT	0
655637	655497	14251Q	PARTICIPANT	\N	PRESENT	0
655638	655497	20286Q	PARTICIPANT	\N	PRESENT	0
655639	655497	20298U	PARTICIPANT	\N	PRESENT	0
655640	655497	19369B	PARTICIPANT	\N	PRESENT	0
655641	655497	19747H	PARTICIPANT	\N	PRESENT	0
655642	655497	20018V	PARTICIPANT	\N	PRESENT	0
655643	655497	19563B	PARTICIPANT	\N	PRESENT	0
655644	655497	14037X	PARTICIPANT	\N	PRESENT	0
655645	655497	14257W	PARTICIPANT	\N	PRESENT	0
659370	659369	19629C	PARTICIPANT	\N	PRESENT	0
659371	659369	20120S	PARTICIPANT	\N	PRESENT	0
659372	659369	20124W	PARTICIPANT	\N	PRESENT	0
661778	659416	17637T	PARTICIPANT	\N	PRESENT	0
661779	659416	20054A	PARTICIPANT	\N	PRESENT	0
661787	659416	19715Y	PARTICIPANT	\N	PRESENT	0
661790	659416	14030Q	PARTICIPANT	\N	PRESENT	0
661791	659416	19768N	PARTICIPANT	\N	PRESENT	0
661798	659416	19611R	PARTICIPANT	\N	PRESENT	0
661800	659416	19693L	PARTICIPANT	\N	PRESENT	0
661801	659416	08010L	PARTICIPANT	\N	PRESENT	0
661846	661845	19565D	PARTICIPANT	\N	PRESENT	0
661847	661845	14267Y	PARTICIPANT	\N	PRESENT	0
661849	661848	19565D	PARTICIPANT	\N	PRESENT	0
661850	661848	14267Y	PARTICIPANT	\N	PRESENT	0
661852	661851	19565D	PARTICIPANT	\N	PRESENT	0
661853	661851	14267Y	PARTICIPANT	\N	PRESENT	0
661855	661854	11070L	PARTICIPANT	\N	PRESENT	0
661856	661854	19647E	PARTICIPANT	\N	PRESENT	0
661858	661857	11012A	PARTICIPANT	\N	PRESENT	0
661859	661857	14083S	PARTICIPANT	\N	PRESENT	0
661861	661860	11012A	PARTICIPANT	\N	PRESENT	0
661862	661860	14083S	PARTICIPANT	\N	PRESENT	0
661864	661863	19667J	PARTICIPANT	\N	PRESENT	0
661865	661863	11040E	PARTICIPANT	\N	PRESENT	0
661867	661866	08034U	PARTICIPANT	\N	PRESENT	0
661869	661868	19667J	PARTICIPANT	\N	PRESENT	0
661870	661868	11040E	PARTICIPANT	\N	PRESENT	0
662931	662930	08010L	PARTICIPANT	\N	PRESENT	0
664576	664575	11090Q	PARTICIPANT	\N	PRESENT	0
664577	664575	19507S	PARTICIPANT	\N	PRESENT	0
664578	664575	11097X	PARTICIPANT	\N	PRESENT	0
664579	664575	04045F	PARTICIPANT	\N	PRESENT	0
664580	664575	19413M	PARTICIPANT	\N	PRESENT	0
664581	664575	14207L	PARTICIPANT	\N	PRESENT	0
664582	664575	14083S	PARTICIPANT	\N	PRESENT	0
664583	664575	20090E	PARTICIPANT	\N	PRESENT	0
664584	664575	20126Y	PARTICIPANT	\N	PRESENT	0
664585	664575	11099A	PARTICIPANT	\N	PRESENT	0
664660	664659	11067R	PARTICIPANT	\N	PRESENT	0
664661	664659	01048V	PARTICIPANT	\N	EXCUSE	0
664662	664659	19693L	PARTICIPANT	\N	EXCUSE	0
664664	664659	04043D	PARTICIPANT	\N	PRESENT	0
664665	664659	19723Y	PARTICIPANT	\N	EXCUSE	0
664666	664659	19735D	PARTICIPANT	\N	EXCUSE	0
665732	665731	04043D	PARTICIPANT	\N	PRESENT	0
665733	665731	10006L	PARTICIPANT	\N	PRESENT	0
666195	666192	14213J	PARTICIPANT	\N	PRESENT	0
666196	666192	19691J	PARTICIPANT	\N	PRESENT	0
666342	665174	20040T	PARTICIPANT	\N	PRESENT	0
666354	663456	04085P	PARTICIPANT	\N	PRESENT	0
666355	663456	19543W	PARTICIPANT	\N	PRESENT	0
666356	663456	20022R	PARTICIPANT	\N	PRESENT	0
666357	663456	20110Q	PARTICIPANT	\N	PRESENT	0
666358	663456	11033F	PARTICIPANT	\N	PRESENT	0
666359	663456	14069U	PARTICIPANT	\N	PRESENT	0
666360	663456	20114U	PARTICIPANT	\N	PRESENT	0
666361	663456	04047H	PARTICIPANT	\N	PRESENT	0
666362	663456	11056N	PARTICIPANT	\N	PRESENT	0
666363	663456	14215L	PARTICIPANT	\N	PRESENT	0
666364	663456	20074E	PARTICIPANT	\N	PRESENT	0
666365	663456	19673G	PARTICIPANT	\N	PRESENT	0
666366	663456	19725B	PARTICIPANT	\N	PRESENT	0
666367	663456	14179A	PARTICIPANT	\N	PRESENT	0
666368	663456	19447X	PARTICIPANT	\N	PRESENT	0
666369	663456	14021P	PARTICIPANT	\N	PRESENT	0
666370	663456	19649G	PARTICIPANT	\N	PRESENT	0
666371	663456	19729F	PARTICIPANT	\N	PRESENT	0
666372	663456	20108W	PARTICIPANT	\N	PRESENT	0
666373	663456	19581D	PARTICIPANT	\N	PRESENT	0
666374	663456	14001X	PARTICIPANT	\N	PRESENT	0
666375	663456	14147R	PARTICIPANT	\N	PRESENT	0
666398	666397	19251M	PARTICIPANT	\N	PRESENT	0
666399	666397	19593H	PARTICIPANT	\N	PRESENT	0
666400	666397	19515S	PARTICIPANT	\N	PRESENT	0
666401	666397	12028B	PARTICIPANT	\N	PRESENT	0
666402	666397	97011G	PARTICIPANT	\N	PRESENT	0
666403	666397	14109K	PARTICIPANT	\N	PRESENT	0
666404	666397	20112S	PARTICIPANT	\N	PRESENT	0
666405	666397	17737W	PARTICIPANT	\N	PRESENT	0
666406	666397	17367Q	PARTICIPANT	\N	PRESENT	0
666407	665705	17965H	PARTICIPANT	\N	PRESENT	0
666408	663863	17965H	PARTICIPANT	\N	PRESENT	0
666514	663863	19295A	PARTICIPANT	\N	PRESENT	0
666515	665705	19295A	PARTICIPANT	\N	PRESENT	0
666518	665705	19663E	PARTICIPANT	\N	PRESENT	0
666519	663863	19663E	PARTICIPANT	\N	PRESENT	0
667142	667141	04071H	PARTICIPANT	\N	PRESENT	0
667156	667155	20070A	PARTICIPANT	\N	PRESENT	0
670394	669893	14223L	PARTICIPANT	\N	PRESENT	0
670395	668919	20130U	PARTICIPANT	\N	PRESENT	0
670396	668919	19591F	PARTICIPANT	\N	PRESENT	0
670397	669893	19691J	PARTICIPANT	\N	PRESENT	0
670398	669893	14231L	PARTICIPANT	\N	PRESENT	0
670399	669893	14195A	PARTICIPANT	\N	PRESENT	0
670400	669893	19479G	PARTICIPANT	\N	PRESENT	0
670401	669893	19739H	PARTICIPANT	\N	PRESENT	0
670402	669893	19745F	PARTICIPANT	\N	PRESENT	0
670403	669893	20130U	PARTICIPANT	\N	PRESENT	0
670490	669893	19715Y	PARTICIPANT	\N	PRESENT	0
670405	669893	14073Q	PARTICIPANT	\N	PRESENT	0
670406	669893	14215L	PARTICIPANT	\N	PRESENT	0
670407	669893	14147R	PARTICIPANT	\N	PRESENT	0
670408	669893	14193X	PARTICIPANT	\N	PRESENT	0
670409	669893	19798U	PARTICIPANT	\N	PRESENT	0
670410	669893	19569H	PARTICIPANT	\N	PRESENT	0
670411	669893	20034V	PARTICIPANT	\N	PRESENT	0
670412	669893	20026V	PARTICIPANT	\N	PRESENT	0
670413	669893	19651A	PARTICIPANT	\N	PRESENT	0
670414	669893	20066E	PARTICIPANT	\N	PRESENT	0
670415	669893	14357A	PARTICIPANT	\N	PRESENT	0
670416	669893	20172F	PARTICIPANT	\N	PRESENT	0
670417	669893	20040T	PARTICIPANT	\N	PRESENT	0
670419	669893	20036X	PARTICIPANT	\N	PRESENT	0
670420	669893	20140W	PARTICIPANT	\N	PRESENT	0
670421	669893	08015R	PARTICIPANT	\N	PRESENT	0
670422	669893	20024T	PARTICIPANT	\N	PRESENT	0
670423	669893	20090E	PARTICIPANT	\N	PRESENT	0
670424	669893	19782L	PARTICIPANT	\N	PRESENT	0
670425	669893	14071N	PARTICIPANT	\N	PRESENT	0
670426	669893	04045F	PARTICIPANT	\N	PRESENT	0
670427	669893	20180F	PARTICIPANT	\N	PRESENT	0
670428	669893	14207L	PARTICIPANT	\N	PRESENT	0
670429	669893	20264J	PARTICIPANT	\N	PRESENT	0
670430	669893	08061X	PARTICIPANT	\N	PRESENT	0
670431	669893	14213J	PARTICIPANT	\N	PRESENT	0
670432	669893	19503N	PARTICIPANT	\N	PRESENT	0
670433	669893	18193Q	PARTICIPANT	\N	PRESENT	0
670434	669893	19760E	PARTICIPANT	\N	PRESENT	0
670435	669893	19683J	PARTICIPANT	\N	PRESENT	0
670436	669893	17779H	PARTICIPANT	\N	PRESENT	0
670437	669893	17965H	PARTICIPANT	\N	PRESENT	0
670438	669893	20132W	PARTICIPANT	\N	PRESENT	0
670439	669893	19697Q	PARTICIPANT	\N	PRESENT	0
670440	669893	01034P	PARTICIPANT	\N	PRESENT	0
670441	669893	14205J	PARTICIPANT	\N	PRESENT	0
670442	669893	19713W	PARTICIPANT	\N	PRESENT	0
670443	669893	20042V	PARTICIPANT	\N	PRESENT	0
670485	669893	19699S	PARTICIPANT	\N	PRESENT	0
670445	669893	11097X	PARTICIPANT	\N	PRESENT	0
670446	669893	04092N	PARTICIPANT	\N	PRESENT	0
670447	669893	08056B	PARTICIPANT	\N	PRESENT	0
670448	669893	04043D	PARTICIPANT	\N	PRESENT	0
670449	669893	20126Y	PARTICIPANT	\N	PRESENT	0
670450	669556	11048N	PARTICIPANT	\N	PRESENT	0
670451	669556	14225N	PRESIDENT	0	PRESENT	0
670452	669556	14173T	PARTICIPANT	\N	PRESENT	0
670453	669893	14217N	PARTICIPANT	\N	PRESENT	0
670454	669893	97011G	PARTICIPANT	\N	PRESENT	0
670455	669893	10015M	PARTICIPANT	\N	PRESENT	0
670456	669893	19443T	PARTICIPANT	\N	PRESENT	0
670457	669893	12041X	PARTICIPANT	\N	PRESENT	0
670458	669556	11012A	PARTICIPANT	\N	PRESENT	0
670459	669556	12016W	PARTICIPANT	\N	EXCUSE	0
670460	669893	14355X	PARTICIPANT	\N	PRESENT	0
670461	669893	19663E	PARTICIPANT	\N	PRESENT	0
670462	669893	14038Y	PARTICIPANT	\N	PRESENT	0
670463	669893	19399H	PARTICIPANT	\N	PRESENT	0
670464	669893	19533U	PARTICIPANT	\N	PRESENT	0
670465	669893	14281W	PARTICIPANT	\N	PRESENT	0
670466	669893	11067R	PARTICIPANT	\N	PRESENT	0
670467	669893	19387D	PARTICIPANT	\N	PRESENT	0
670468	669893	20098N	PARTICIPANT	\N	PRESENT	0
670469	669893	08018U	PARTICIPANT	\N	PRESENT	0
670470	669893	19723Y	PARTICIPANT	\N	PRESENT	0
670471	669893	07029T	PARTICIPANT	\N	PRESENT	0
670472	669893	19383Y	PARTICIPANT	\N	PRESENT	0
670473	669556	19711U	PARTICIPANT	\N	PRESENT	0
670474	669556	20050V	PARTICIPANT	\N	PRESENT	0
670475	669556	99004R	PARTICIPANT	\N	PRESENT	0
670476	669556	20116W	PARTICIPANT	\N	PRESENT	0
670477	669556	20044X	PARTICIPANT	\N	PRESENT	0
670478	669556	19671E	PARTICIPANT	\N	PRESENT	0
670479	669893	19826F	PARTICIPANT	\N	PRESENT	0
670480	669556	20086J	PARTICIPANT	\N	PRESENT	0
670481	669893	19747H	PARTICIPANT	\N	PRESENT	0
670482	669556	11040E	PARTICIPANT	\N	PRESENT	0
670483	669893	19369B	PARTICIPANT	\N	PRESENT	0
670484	669893	20048C	PARTICIPANT	\N	PRESENT	0
670486	669893	14189C	PARTICIPANT	\N	PRESENT	0
670487	669893	11054L	PARTICIPANT	\N	PRESENT	0
670488	669893	14173T	PARTICIPANT	\N	PRESENT	0
670493	669893	04059M	PARTICIPANT	\N	PRESENT	0
670491	669893	20018V	PARTICIPANT	\N	PRESENT	0
670492	669893	14169X	PARTICIPANT	\N	PRESENT	0
670494	669893	14107H	PARTICIPANT	\N	PRESENT	0
670495	669893	14026U	PARTICIPANT	\N	PRESENT	0
670496	669893	20056C	PARTICIPANT	\N	PRESENT	0
670497	669556	14327T	PARTICIPANT	\N	PRESENT	0
670498	669556	14331P	PARTICIPANT	\N	PRESENT	0
670499	669556	08034U	PARTICIPANT	\N	PRESENT	0
670500	669556	19531S	PARTICIPANT	\N	PRESENT	0
670501	669556	14083S	PARTICIPANT	\N	PRESENT	0
670502	669556	20252E	PARTICIPANT	\N	PRESENT	0
670503	669556	20070A	PARTICIPANT	\N	PRESENT	0
670504	669556	14253S	PARTICIPANT	\N	PRESENT	0
670505	669556	20914V	PARTICIPANT	\N	PRESENT	0
670506	669556	19762G	PARTICIPANT	\N	PRESENT	0
670507	669893	14031R	PARTICIPANT	\N	PRESENT	0
670508	669893	20032T	PARTICIPANT	\N	PRESENT	0
670509	669893	20088L	PARTICIPANT	\N	PRESENT	0
670510	669556	19647E	PARTICIPANT	\N	PRESENT	0
670511	669556	19667J	PARTICIPANT	\N	PRESENT	0
670512	669893	19649G	PARTICIPANT	\N	PRESENT	0
670513	669893	11103C	PARTICIPANT	\N	PRESENT	0
670514	669893	20028X	PARTICIPANT	\N	PRESENT	0
670515	669893	20030R	PARTICIPANT	\N	PRESENT	0
670516	669556	01048V	PARTICIPANT	\N	PRESENT	0
670517	669893	14059S	PARTICIPANT	\N	PRESENT	0
670518	669556	19693L	PARTICIPANT	\N	PRESENT	0
670519	669893	19679N	PARTICIPANT	\N	PRESENT	0
670520	669893	14259Y	PARTICIPANT	\N	PRESENT	0
670521	669893	01024M	PARTICIPANT	\N	PRESENT	0
670522	669893	14111D	PARTICIPANT	\N	PRESENT	0
670526	669893	11072N	PARTICIPANT	\N	PRESENT	0
670524	669893	19515S	PARTICIPANT	\N	PRESENT	0
670525	669556	14097Y	PARTICIPANT	\N	PRESENT	0
670527	669893	14257W	PARTICIPANT	\N	PRESENT	0
670528	669893	14030Q	PARTICIPANT	\N	PRESENT	0
670529	669893	04057K	PARTICIPANT	\N	PRESENT	0
670532	669893	19705W	PARTICIPANT	\N	PRESENT	0
670533	669893	14069U	PARTICIPANT	\N	PRESENT	0
670536	669893	19591F	PARTICIPANT	\N	PRESENT	0
670537	669893	19329S	PARTICIPANT	\N	PRESENT	0
670541	669893	19573D	PARTICIPANT	\N	PRESENT	0
670543	669556	19413M	PARTICIPANT	\N	PRESENT	0
670544	669556	08010L	PARTICIPANT	\N	PRESENT	0
670545	669556	01025N	PARTICIPANT	\N	PRESENT	0
670546	669556	19507S	PARTICIPANT	\N	PRESENT	0
670547	669893	20058E	PARTICIPANT	\N	PRESENT	0
670548	669893	19467C	PARTICIPANT	\N	PRESENT	0
670549	669893	20046A	PARTICIPANT	\N	PRESENT	0
670550	669893	11085T	PARTICIPANT	\N	PRESENT	0
670553	669893	19657G	PARTICIPANT	\N	PRESENT	0
670554	669893	08045X	PARTICIPANT	\N	PRESENT	0
670555	669556	19687N	PARTICIPANT	\N	PRESENT	0
670556	669893	20134Y	PARTICIPANT	\N	PRESENT	0
670558	669893	19703U	PARTICIPANT	\N	PRESENT	0
670560	669893	20062A	PARTICIPANT	\N	PRESENT	0
670561	669893	19347U	PARTICIPANT	\N	PRESENT	0
670562	669893	19581D	PARTICIPANT	\N	PRESENT	0
670569	669556	19533U	PARTICIPANT	\N	PRESENT	0
670565	669556	11074Q	PARTICIPANT	\N	PRESENT	0
670566	669556	19349W	PARTICIPANT	\N	PRESENT	0
670567	669893	14267Y	PARTICIPANT	\N	PRESENT	0
670568	669556	19479G	PARTICIPANT	\N	PRESENT	0
670574	669556	04071H	PARTICIPANT	\N	PRESENT	0
670577	669556	20126Y	PARTICIPANT	\N	PRESENT	0
657382	656879	19741B	PARTICIPANT	\N	PRESENT	0
657383	656879	19826F	PARTICIPANT	\N	PRESENT	0
657384	656879	17023S	PARTICIPANT	\N	PRESENT	0
657385	656879	19581D	PARTICIPANT	\N	PRESENT	0
657386	656879	14217N	PARTICIPANT	\N	PRESENT	0
657387	656879	20054A	PARTICIPANT	\N	PRESENT	0
657388	656879	17637T	PARTICIPANT	\N	PRESENT	0
657389	656879	14207L	PARTICIPANT	\N	PRESENT	0
657390	656879	17779H	PARTICIPANT	\N	PRESENT	0
657391	656879	14179A	PARTICIPANT	\N	PRESENT	0
657392	656879	14073Q	PARTICIPANT	\N	PRESENT	0
657393	656879	20030R	PARTICIPANT	\N	PRESENT	0
657394	656879	19399H	PARTICIPANT	\N	PRESENT	0
657395	656879	19681G	PARTICIPANT	\N	PRESENT	0
657396	656879	14213J	PARTICIPANT	\N	PRESENT	0
657397	656879	19593H	PARTICIPANT	\N	PRESENT	0
657398	656879	14071N	PARTICIPANT	\N	PRESENT	0
657399	656879	19768N	PARTICIPANT	\N	PRESENT	0
657400	656879	20100N	PARTICIPANT	\N	PRESENT	0
657401	656879	08028W	PARTICIPANT	\N	PRESENT	0
657402	656879	20034V	PARTICIPANT	\N	PRESENT	0
657408	656879	20286Q	PARTICIPANT	\N	PRESENT	0
657409	656879	20084G	PARTICIPANT	\N	PRESENT	0
657410	656879	19533U	PARTICIPANT	\N	PRESENT	0
657411	656879	20082E	PARTICIPANT	\N	PRESENT	0
657412	656879	14191V	PARTICIPANT	\N	PRESENT	0
657413	656879	19739H	PARTICIPANT	\N	PRESENT	0
657414	656879	11053K	PARTICIPANT	\N	PRESENT	0
657415	656879	11012A	PARTICIPANT	\N	PRESENT	0
657416	656879	01057W	PARTICIPANT	\N	PRESENT	0
657418	656840	95041E	PARTICIPANT	\N	PRESENT	0
657419	656840	19443T	PARTICIPANT	\N	PRESENT	0
657420	656840	12041X	PARTICIPANT	\N	PRESENT	0
657421	656840	19565D	PARTICIPANT	\N	PRESENT	0
657380	656879	19611R	PARTICIPANT	\N	PRESENT	0
657381	656879	19663E	PARTICIPANT	\N	PRESENT	0
657422	656840	20072C	PARTICIPANT	\N	PRESENT	0
657423	656840	01058X	PARTICIPANT	\N	PRESENT	0
657424	656840	16685X	PARTICIPANT	\N	PRESENT	0
657425	656840	04042C	PRESIDENT	0	PRESENT	0
657426	656840	11054L	PARTICIPANT	\N	PRESENT	0
657427	656840	19669L	PARTICIPANT	\N	PRESENT	0
657428	656840	08056B	PARTICIPANT	\N	PRESENT	0
657429	656840	12028B	PARTICIPANT	\N	PRESENT	0
657430	656840	14193X	PARTICIPANT	\N	PRESENT	0
657431	656840	19347U	PARTICIPANT	\N	PRESENT	0
657432	656840	07033P	PARTICIPANT	\N	PRESENT	0
657433	656840	97011G	PARTICIPANT	\N	PRESENT	0
657434	656840	08061X	PARTICIPANT	\N	PRESENT	0
657435	656840	08047A	PARTICIPANT	\N	PRESENT	0
657436	656840	14097Y	PARTICIPANT	\N	PRESENT	0
657437	656840	14059S	PARTICIPANT	\N	PRESENT	0
657438	656840	04035D	PARTICIPANT	\N	PRESENT	0
657439	656840	01062T	PARTICIPANT	\N	PRESENT	0
657440	656840	08069G	PARTICIPANT	\N	PRESENT	0
657441	656840	01024M	PARTICIPANT	\N	PRESENT	0
657442	656840	14105F	PARTICIPANT	\N	PRESENT	0
657443	656840	20064C	PARTICIPANT	\N	PRESENT	0
657444	656840	14267Y	PARTICIPANT	\N	PRESENT	0
657445	656840	11064N	PARTICIPANT	\N	PRESENT	0
657446	656840	11083R	PARTICIPANT	\N	PRESENT	0
657447	656840	14211G	PARTICIPANT	\N	PRESENT	0
657448	656840	14255U	PARTICIPANT	\N	PRESENT	0
657449	656840	17023S	PARTICIPANT	\N	PRESENT	0
657450	656840	11066Q	PARTICIPANT	\N	EXCUSE	0
657451	656879	19762G	PARTICIPANT	\N	PRESENT	0
657525	656880	20030R	PARTICIPANT	\N	PRESENT	0
657526	656880	20082E	PARTICIPANT	\N	PRESENT	0
657527	656880	20100N	PARTICIPANT	\N	PRESENT	0
657528	656880	20130U	PARTICIPANT	\N	PRESENT	0
657529	656880	19782L	PARTICIPANT	\N	PRESENT	0
657530	656880	04045F	PARTICIPANT	\N	PRESENT	0
657531	656880	19681G	PARTICIPANT	\N	PRESENT	0
657532	656880	04057K	PARTICIPANT	\N	PRESENT	0
657533	656880	14107H	PARTICIPANT	\N	PRESENT	0
657534	656880	11012A	PARTICIPANT	\N	PRESENT	0
657535	656880	19553Y	PARTICIPANT	\N	PRESENT	0
657536	656880	19479G	PARTICIPANT	\N	PRESENT	0
657537	656880	14030Q	PARTICIPANT	\N	PRESENT	0
657538	656880	14189C	PARTICIPANT	\N	PRESENT	0
657539	656880	20286Q	PARTICIPANT	\N	PRESENT	0
657540	656880	19367Y	PARTICIPANT	\N	PRESENT	0
657541	656880	19762G	PARTICIPANT	\N	PRESENT	0
657542	656880	14187A	PARTICIPANT	\N	PRESENT	0
657543	656880	04070G	PARTICIPANT	\N	PRESENT	0
657544	656880	20032T	PARTICIPANT	\N	PRESENT	0
657545	656880	14147R	PARTICIPANT	\N	PRESENT	0
657546	656880	18083K	PARTICIPANT	\N	PRESENT	0
657547	656880	14169X	PARTICIPANT	\N	PRESENT	0
657548	656880	14191V	PARTICIPANT	\N	PRESENT	0
657549	656880	19575F	PARTICIPANT	\N	PRESENT	0
657550	656880	14217N	PARTICIPANT	\N	PRESENT	0
657551	656880	14109K	PARTICIPANT	\N	PRESENT	0
657552	656880	11097X	PARTICIPANT	\N	PRESENT	0
657553	656880	20124W	PARTICIPANT	\N	PRESENT	0
657554	656880	19675J	PARTICIPANT	\N	PRESENT	0
657555	656880	20086J	PARTICIPANT	\N	PRESENT	0
657556	656880	19593H	PARTICIPANT	\N	PRESENT	0
657557	656880	11077T	PARTICIPANT	\N	PRESENT	0
657558	656880	19758L	PARTICIPANT	\N	PRESENT	0
657559	656880	14331P	PARTICIPANT	\N	PRESENT	0
657560	656880	11085T	PARTICIPANT	\N	PRESENT	0
657561	656880	20090E	PARTICIPANT	\N	PRESENT	0
657562	656880	18193Q	PARTICIPANT	\N	PRESENT	0
657563	656880	11083R	PARTICIPANT	\N	PRESENT	0
657586	656880	19399H	PARTICIPANT	\N	PRESENT	0
657565	656880	14173T	PARTICIPANT	\N	PRESENT	0
657566	656880	14071N	PARTICIPANT	\N	PRESENT	0
657607	656880	11104D	PARTICIPANT	\N	PRESENT	0
657608	656880	20108W	PARTICIPANT	\N	PRESENT	0
657609	656880	19637C	PARTICIPANT	\N	PRESENT	0
657610	656880	14031R	PARTICIPANT	\N	PRESENT	0
657611	656880	19467C	PARTICIPANT	\N	PRESENT	0
657612	656880	14213J	PARTICIPANT	\N	PRESENT	0
657679	656881	11070L	PARTICIPANT	\N	PRESENT	0
657680	656881	20150Y	PARTICIPANT	\N	PRESENT	0
657681	656881	20046A	PARTICIPANT	\N	PRESENT	0
657682	656881	20102Q	PARTICIPANT	\N	PRESENT	0
657683	656881	20100N	PARTICIPANT	\N	PRESENT	0
657684	656881	19577H	PARTICIPANT	\N	PRESENT	0
657685	656881	20116W	PARTICIPANT	\N	PRESENT	0
657686	656881	20072C	PARTICIPANT	\N	PRESENT	0
657687	656881	19717B	PARTICIPANT	\N	PRESENT	0
657688	656881	11064N	PARTICIPANT	\N	PRESENT	0
657689	656881	19333N	PARTICIPANT	\N	PRESENT	0
657690	656881	14147R	PARTICIPANT	\N	PRESENT	0
657691	656881	19549D	PARTICIPANT	\N	PRESENT	0
657692	656881	19447X	PARTICIPANT	\N	PRESENT	0
657693	656881	11077T	PARTICIPANT	\N	PRESENT	0
657694	656881	20034V	PARTICIPANT	\N	PRESENT	0
657695	656881	20030R	PARTICIPANT	\N	PRESENT	0
657696	656881	19659J	PARTICIPANT	\N	PRESENT	0
657697	656881	14033T	PARTICIPANT	\N	PRESENT	0
657698	656881	19503N	PARTICIPANT	\N	PRESENT	0
657699	656881	14083S	PARTICIPANT	\N	PRESENT	0
657700	656881	19347U	PARTICIPANT	\N	PRESENT	0
657522	656880	14026U	PARTICIPANT	\N	PRESENT	0
657523	656880	20084G	PARTICIPANT	\N	PRESENT	0
657701	656881	19387D	PARTICIPANT	\N	PRESENT	0
657702	656881	17023S	PARTICIPANT	\N	PRESENT	0
657703	656881	19349W	PARTICIPANT	\N	PRESENT	0
657704	656881	19782L	PARTICIPANT	\N	PRESENT	0
657705	656881	19383Y	PARTICIPANT	\N	PRESENT	0
657706	656881	20062A	PARTICIPANT	\N	PRESENT	0
657707	656881	18083K	PARTICIPANT	\N	PRESENT	0
657708	656881	14069U	PARTICIPANT	\N	PRESENT	0
657709	656881	20092G	PARTICIPANT	\N	PRESENT	0
657710	656881	07029T	PARTICIPANT	\N	PRESENT	0
657998	657997	07033P	PARTICIPANT	\N	PRESENT	0
657999	657997	14059S	PARTICIPANT	\N	PRESENT	0
658000	657997	04043D	PARTICIPANT	\N	PRESENT	0
658001	657997	14147R	PARTICIPANT	\N	PRESENT	0
658002	657997	19745F	PARTICIPANT	\N	PRESENT	0
658003	657997	19762G	PARTICIPANT	\N	PRESENT	0
659400	659399	04042C	PARTICIPANT	\N	PRESENT	0
659401	659399	20072C	PARTICIPANT	\N	PRESENT	0
659402	659399	14193X	PARTICIPANT	\N	PRESENT	0
659403	659399	20042V	PARTICIPANT	\N	PRESENT	0
659404	659399	01024M	PARTICIPANT	\N	PRESENT	0
659405	659399	20128B	PARTICIPANT	\N	PRESENT	0
659666	659665	05008E	PARTICIPANT	\N	PRESENT	0
669454	667725	20120S	PARTICIPANT	\N	PRESENT	0
669455	667725	14038Y	PARTICIPANT	\N	PRESENT	0
669456	667725	19383Y	PARTICIPANT	\N	PRESENT	0
669457	667725	14033T	PARTICIPANT	\N	PRESENT	0
669458	667725	14357A	PARTICIPANT	\N	PRESENT	0
669459	667725	08015R	PARTICIPANT	\N	PRESENT	0
669460	667725	20062A	PARTICIPANT	\N	PRESENT	0
669461	667725	19747H	PARTICIPANT	\N	PRESENT	0
669462	667725	19631V	PARTICIPANT	\N	PRESENT	0
669463	667725	11097X	PARTICIPANT	\N	PRESENT	0
669464	667725	20090E	PARTICIPANT	\N	PRESENT	0
669465	667725	20100N	PARTICIPANT	\N	PRESENT	0
669466	667725	20032T	PARTICIPANT	\N	PRESENT	0
669467	667725	19503N	PARTICIPANT	\N	PRESENT	0
669468	667725	20044X	PARTICIPANT	\N	PRESENT	0
669469	667725	20068G	PARTICIPANT	\N	PRESENT	0
669470	667725	20106U	PARTICIPANT	\N	PRESENT	0
669471	667725	19683J	PARTICIPANT	\N	PRESENT	0
669472	667725	19629C	PARTICIPANT	\N	PRESENT	0
669473	667698	14331P	PARTICIPANT	\N	EXCUSE	0
669474	667725	14169X	PARTICIPANT	\N	PRESENT	0
669475	667725	10015M	PARTICIPANT	\N	PRESENT	0
669476	667725	11090Q	PARTICIPANT	\N	PRESENT	0
669477	667725	14217N	PARTICIPANT	\N	PRESENT	0
669479	667725	20086J	PARTICIPANT	\N	PRESENT	0
669481	667725	19673G	PARTICIPANT	\N	PRESENT	0
669482	669480	14187A	PARTICIPANT	\N	PRESENT	0
669452	667725	19667J	PARTICIPANT	\N	PRESENT	0
669453	667725	20038A	PARTICIPANT	\N	PRESENT	0
669484	667725	19713W	PARTICIPANT	\N	PRESENT	0
669485	667725	19441R	PARTICIPANT	\N	PRESENT	0
669487	668105	01048V	PARTICIPANT	\N	EXCUSE	0
669488	669486	19631V	PARTICIPANT	\N	PRESENT	0
669491	669489	19631V	PARTICIPANT	\N	PRESENT	0
669493	669492	19631V	PARTICIPANT	\N	PRESENT	0
669494	667725	19711U	PARTICIPANT	\N	PRESENT	0
669495	667725	19719D	PARTICIPANT	\N	PRESENT	0
669496	667725	19467C	PARTICIPANT	\N	PRESENT	0
669497	667725	19549D	PARTICIPANT	\N	PRESENT	0
669498	667725	20082E	PARTICIPANT	\N	PRESENT	0
669499	667725	20070A	PARTICIPANT	\N	PRESENT	0
669500	667725	19387D	PARTICIPANT	\N	PRESENT	0
669501	667725	20060X	PARTICIPANT	\N	PRESENT	0
669502	667725	20058E	PARTICIPANT	\N	PRESENT	0
669503	667725	05012A	PARTICIPANT	\N	PRESENT	0
669504	667725	11033F	PARTICIPANT	\N	PRESENT	0
669505	667725	14123H	PARTICIPANT	\N	PRESENT	0
669506	667725	20172F	PARTICIPANT	\N	PRESENT	0
669507	667725	19651A	PARTICIPANT	\N	PRESENT	0
669508	667725	20136B	PARTICIPANT	\N	PRESENT	0
669509	667725	19533U	PARTICIPANT	\N	PRESENT	0
669510	667725	14071N	PARTICIPANT	\N	PRESENT	0
669511	667725	20252E	PARTICIPANT	\N	PRESENT	0
669512	667725	14069U	PARTICIPANT	\N	PRESENT	0
669514	669513	04042C	PARTICIPANT	\N	PRESENT	0
669515	669513	04035D	PARTICIPANT	\N	PRESENT	0
669516	669513	14249W	PARTICIPANT	\N	PRESENT	0
669517	669513	14193X	PARTICIPANT	\N	PRESENT	0
669518	669513	11054L	PARTICIPANT	\N	PRESENT	0
669519	667725	04043D	PARTICIPANT	\N	PRESENT	0
669520	667725	19687N	PARTICIPANT	\N	PRESENT	0
669521	667725	19593H	PARTICIPANT	\N	PRESENT	0
669522	667725	14021P	PARTICIPANT	\N	PRESENT	0
669523	667725	19515S	PARTICIPANT	\N	PRESENT	0
669524	667725	14229S	PARTICIPANT	\N	PRESENT	0
669525	667725	14215L	PARTICIPANT	\N	PRESENT	0
669526	667725	20264J	PARTICIPANT	\N	PRESENT	0
669527	667725	20134Y	PARTICIPANT	\N	PRESENT	0
669529	669528	14111D	PARTICIPANT	\N	PRESENT	0
669531	669530	14111D	PARTICIPANT	\N	PRESENT	0
669532	669530	11033F	PARTICIPANT	\N	PRESENT	0
669535	669533	14111D	PARTICIPANT	\N	PRESENT	0
669536	669533	11033F	PARTICIPANT	\N	PRESENT	0
669537	669534	14111D	PARTICIPANT	\N	PRESENT	0
669538	669534	11033F	PARTICIPANT	\N	PRESENT	0
669539	667725	14083S	PARTICIPANT	\N	PRESENT	0
669540	667725	07029T	PARTICIPANT	\N	PRESENT	0
669541	667725	19657G	PARTICIPANT	\N	PRESENT	0
669542	667725	19421M	PARTICIPANT	\N	PRESENT	0
669543	667725	20042V	PARTICIPANT	\N	PRESENT	0
669544	667725	19766L	PARTICIPANT	\N	PRESENT	0
669546	667725	14030Q	PARTICIPANT	\N	PRESENT	0
669562	669561	08010L	PARTICIPANT	\N	PRESENT	0
669563	667725	17023S	PARTICIPANT	\N	PRESENT	0
669564	667725	20022R	PARTICIPANT	\N	PRESENT	0
669565	667725	11085T	PARTICIPANT	\N	PRESENT	0
669631	667726	20024T	PARTICIPANT	\N	PRESENT	0
669632	667726	19533U	PARTICIPANT	\N	PRESENT	0
669633	667726	14031R	PARTICIPANT	\N	PRESENT	0
669634	667726	14219Q	PARTICIPANT	\N	PRESENT	0
669635	667726	20038A	PARTICIPANT	\N	PRESENT	0
669636	667726	20100N	PARTICIPANT	\N	PRESENT	0
669637	667726	11065P	PARTICIPANT	\N	PRESENT	0
669638	667726	11090Q	PARTICIPANT	\N	PRESENT	0
669639	667726	20062A	PARTICIPANT	\N	PRESENT	0
669640	667726	19820Y	PARTICIPANT	\N	PRESENT	0
669641	667726	20044X	PARTICIPANT	\N	PRESENT	0
669642	667726	19333N	PARTICIPANT	\N	PRESENT	0
669643	667726	19611R	PARTICIPANT	\N	PRESENT	0
669644	667726	19503N	PARTICIPANT	\N	PRESENT	0
669645	667726	19766L	PARTICIPANT	\N	PRESENT	0
669646	667726	20142Y	PARTICIPANT	\N	PRESENT	0
669647	667726	18083K	PARTICIPANT	\N	PRESENT	0
669648	667726	20092G	PARTICIPANT	\N	PRESENT	0
669649	667726	14169X	PARTICIPANT	\N	PRESENT	0
669650	667726	20102Q	PARTICIPANT	\N	PRESENT	0
669651	667726	20046A	PARTICIPANT	\N	PRESENT	0
669652	667726	19441R	PARTICIPANT	\N	PRESENT	0
669653	667726	19695N	PARTICIPANT	\N	PRESENT	0
669654	667726	19715Y	PARTICIPANT	\N	PRESENT	0
669655	667726	20082E	PARTICIPANT	\N	PRESENT	0
669656	667726	14207L	PARTICIPANT	\N	PRESENT	0
669657	667726	11077T	PARTICIPANT	\N	PRESENT	0
669658	667726	19563B	PARTICIPANT	\N	PRESENT	0
669659	667726	19347U	PARTICIPANT	\N	PRESENT	0
669660	667726	14221J	PARTICIPANT	\N	PRESENT	0
669661	667726	19599P	PARTICIPANT	\N	PRESENT	0
669662	667726	08060W	PARTICIPANT	\N	PRESENT	0
669663	667726	19619A	PARTICIPANT	\N	PRESENT	0
669664	667726	20172F	PARTICIPANT	\N	PRESENT	0
669665	667726	20076G	PARTICIPANT	\N	PRESENT	0
669666	667726	14257W	PARTICIPANT	\N	PRESENT	0
669667	667726	20106U	PARTICIPANT	\N	PRESENT	0
669668	667726	14033T	PARTICIPANT	\N	PRESENT	0
669669	667726	20144B	PARTICIPANT	\N	PRESENT	0
669670	667726	20118Y	PARTICIPANT	\N	PRESENT	0
669671	667726	14069U	PARTICIPANT	\N	PRESENT	0
669672	667726	14205J	PARTICIPANT	\N	PRESENT	0
669673	667726	20058E	PARTICIPANT	\N	PRESENT	0
669674	667726	20136B	PARTICIPANT	\N	PRESENT	0
669675	667726	19577H	PARTICIPANT	\N	PRESENT	0
669676	667726	19681G	PARTICIPANT	\N	PRESENT	0
669677	667726	19369B	PARTICIPANT	\N	PRESENT	0
669678	667726	05012A	PARTICIPANT	\N	PRESENT	0
669679	667726	14071N	PARTICIPANT	\N	PRESENT	0
669680	667726	20298U	PARTICIPANT	\N	PRESENT	0
669681	667726	14083S	PARTICIPANT	\N	PRESENT	0
669682	667726	07029T	PARTICIPANT	\N	PRESENT	0
669683	667726	14215L	PARTICIPANT	\N	PRESENT	0
669684	667726	19701S	PARTICIPANT	\N	PRESENT	0
669685	667726	11048N	PARTICIPANT	\N	PRESENT	0
669629	669628	08018U	PARTICIPANT	\N	PRESENT	0
669630	667726	11070L	PARTICIPANT	\N	PRESENT	0
669686	667726	19549D	PARTICIPANT	\N	PRESENT	0
669687	667726	20120S	PARTICIPANT	\N	PRESENT	0
669688	667726	19637C	PARTICIPANT	\N	PRESENT	0
669689	667726	14030Q	PARTICIPANT	\N	PRESENT	0
669690	667726	20052X	PARTICIPANT	\N	PRESENT	0
669757	669756	20136B	PARTICIPANT	\N	PRESENT	0
669817	669816	14267Y	PARTICIPANT	\N	PRESENT	0
669818	669816	08047A	PARTICIPANT	\N	PRESENT	0
669819	669816	14193X	PARTICIPANT	\N	PRESENT	0
669820	669816	14249W	PARTICIPANT	\N	PRESENT	0
669822	669816	20042V	PARTICIPANT	\N	PRESENT	0
669825	669816	14030Q	PARTICIPANT	\N	PRESENT	0
669826	669816	19251M	PARTICIPANT	\N	PRESENT	0
669880	669875	14215L	PARTICIPANT	\N	PRESENT	0
669881	669875	14021P	PARTICIPANT	\N	PRESENT	0
670143	667315	19301E	PARTICIPANT	\N	PRESENT	0
670144	667315	20148F	PARTICIPANT	\N	PRESENT	0
670145	667315	12016W	PARTICIPANT	\N	EXCUSE	0
655260	649043	19725B	PARTICIPANT	\N	PRESENT	0
655261	649043	14026U	PARTICIPANT	\N	PRESENT	0
655262	649046	19725B	PARTICIPANT	\N	PRESENT	0
655263	649046	14026U	PARTICIPANT	\N	PRESENT	0
655266	655264	20100N	PARTICIPANT	\N	PRESENT	0
655267	655264	19711U	PARTICIPANT	\N	PRESENT	0
655268	655264	14001X	PARTICIPANT	\N	PRESENT	0
655270	655269	19711U	PARTICIPANT	\N	PRESENT	0
655271	655269	20100N	PARTICIPANT	\N	PRESENT	0
655272	655269	14001X	PARTICIPANT	\N	PRESENT	0
655274	655273	20100N	PARTICIPANT	\N	PRESENT	0
655275	655273	14001X	PARTICIPANT	\N	PRESENT	0
655276	655273	19711U	PARTICIPANT	\N	PRESENT	0
655489	655488	07029T	PARTICIPANT	\N	PRESENT	0
656745	656157	20032T	PARTICIPANT	\N	PRESENT	0
656746	656157	14259Y	PARTICIPANT	\N	EXCUSE	0
656747	656157	11097X	PARTICIPANT	\N	PRESENT	0
656748	656157	20042V	PARTICIPANT	\N	PRESENT	0
656749	656157	11056N	PARTICIPANT	\N	PRESENT	0
656750	656157	20132W	PARTICIPANT	\N	PRESENT	0
656751	656157	19479G	PARTICIPANT	\N	PRESENT	0
656787	656786	01043Q	PARTICIPANT	\N	PRESENT	0
656788	656786	14205J	PARTICIPANT	\N	PRESENT	0
656789	656786	11090Q	PARTICIPANT	\N	PRESENT	0
656790	656786	20082E	PARTICIPANT	\N	PRESENT	0
656791	656786	20032T	PARTICIPANT	\N	PRESENT	0
656792	656786	05008E	PARTICIPANT	\N	PRESENT	0
656793	656786	20024T	PARTICIPANT	\N	PRESENT	0
656794	656786	19549D	PARTICIPANT	\N	PRESENT	0
656795	656786	20086J	PARTICIPANT	\N	PRESENT	0
656796	656786	19545Y	PARTICIPANT	\N	PRESENT	0
656797	656786	11065P	PARTICIPANT	\N	PRESENT	0
656798	656786	14259Y	PARTICIPANT	\N	PRESENT	0
656799	656786	11110B	PARTICIPANT	\N	PRESENT	0
656800	656786	14231L	PARTICIPANT	\N	PRESENT	0
656801	656786	19489J	PARTICIPANT	\N	PRESENT	0
656802	656786	14219Q	PARTICIPANT	\N	PRESENT	0
656803	656786	19349W	PARTICIPANT	\N	PRESENT	0
656804	656786	14225N	PARTICIPANT	\N	PRESENT	0
656805	656786	04047H	PARTICIPANT	\N	PRESENT	0
664552	661840	99004R	PARTICIPANT	\N	PRESENT	0
664598	661840	11033F	PARTICIPANT	\N	PRESENT	0
664599	661840	20046A	PARTICIPANT	\N	PRESENT	0
664600	661840	19760E	PARTICIPANT	\N	PRESENT	0
664601	661840	19565D	PARTICIPANT	\N	PRESENT	0
664602	661840	11031D	PARTICIPANT	\N	PRESENT	0
664603	661840	19569H	PARTICIPANT	\N	PRESENT	0
664604	661840	20040T	PARTICIPANT	\N	PRESENT	0
664605	661840	10015M	PARTICIPANT	\N	PRESENT	0
664606	661840	20090E	PARTICIPANT	\N	PRESENT	0
664607	661840	20098N	PARTICIPANT	\N	PRESENT	0
664608	661840	20138D	PARTICIPANT	\N	PRESENT	0
664612	661840	11045K	PARTICIPANT	\N	PRESENT	0
664614	661840	04057K	PARTICIPANT	\N	PRESENT	0
664615	661840	19591F	PARTICIPANT	\N	PRESENT	0
664617	661840	19387D	PARTICIPANT	\N	PRESENT	0
664618	661840	19619A	PARTICIPANT	\N	PRESENT	0
664619	661840	20298U	PARTICIPANT	\N	PRESENT	0
664621	661840	14083S	PARTICIPANT	\N	PRESENT	0
664627	661840	14071N	PARTICIPANT	\N	PRESENT	0
664628	661840	20066E	PARTICIPANT	\N	PRESENT	0
664629	661840	14259Y	PARTICIPANT	\N	PRESENT	0
664630	661840	20286Q	PARTICIPANT	\N	PRESENT	0
664631	661840	19693L	PARTICIPANT	\N	PRESENT	0
664632	661840	10006L	PARTICIPANT	\N	PRESENT	0
664633	661840	19691J	PARTICIPANT	\N	PRESENT	0
664635	661840	11067R	PARTICIPANT	\N	PRESENT	0
664636	661840	19599P	PARTICIPANT	\N	PRESENT	0
664637	661840	19715Y	PARTICIPANT	\N	PRESENT	0
664638	661840	14147R	PARTICIPANT	\N	PRESENT	0
664639	661840	19573D	PARTICIPANT	\N	PRESENT	0
664640	661840	17965H	PARTICIPANT	\N	PRESENT	0
664641	661840	18193Q	PARTICIPANT	\N	PRESENT	0
664642	661840	01043Q	PARTICIPANT	\N	PRESENT	0
664643	661840	14213J	PARTICIPANT	\N	PRESENT	0
664644	661840	14021P	PARTICIPANT	\N	PRESENT	0
664645	661840	19621T	PARTICIPANT	\N	PRESENT	0
664646	661840	14195A	PARTICIPANT	\N	PRESENT	0
664647	661840	14207L	PARTICIPANT	\N	PRESENT	0
664648	661840	20266L	PARTICIPANT	\N	PRESENT	0
664649	661840	19631V	PARTICIPANT	\N	PRESENT	0
664650	661840	20248J	PARTICIPANT	\N	PRESENT	0
664651	661840	19563B	PARTICIPANT	\N	PRESENT	0
664652	661840	11099A	PARTICIPANT	\N	PRESENT	0
664653	661840	14133K	PARTICIPANT	\N	PRESENT	0
664654	661840	19467C	PARTICIPANT	\N	PRESENT	0
664655	661840	19747H	PARTICIPANT	\N	PRESENT	0
664656	661840	14179A	PARTICIPANT	\N	PRESENT	0
664657	661840	08061X	PARTICIPANT	\N	PRESENT	0
664658	661840	11053K	PARTICIPANT	\N	PRESENT	0
664667	661840	14281W	PARTICIPANT	\N	PRESENT	0
664668	661840	20132W	PARTICIPANT	\N	PRESENT	0
664669	661840	18083K	PARTICIPANT	\N	PRESENT	0
664670	661840	20126Y	PARTICIPANT	\N	PRESENT	0
664673	661840	19701S	PARTICIPANT	\N	PRESENT	0
664674	661840	20130U	PARTICIPANT	\N	PRESENT	0
664675	661840	19697Q	PARTICIPANT	\N	PRESENT	0
664682	661840	19657G	PARTICIPANT	\N	PRESENT	0
664731	661841	11031D	PARTICIPANT	\N	PRESENT	0
664732	661841	10006L	PARTICIPANT	\N	PRESENT	0
664733	661841	20248J	PARTICIPANT	\N	PRESENT	0
664734	661841	18193Q	PARTICIPANT	\N	PRESENT	0
664735	661841	19599P	PARTICIPANT	\N	PRESENT	0
664736	661841	11067R	PARTICIPANT	\N	PRESENT	0
664737	661841	14281W	PARTICIPANT	\N	PRESENT	0
664738	661841	19715Y	PARTICIPANT	\N	PRESENT	0
664739	661841	11045K	PARTICIPANT	\N	PRESENT	0
664740	661841	11053K	PARTICIPANT	\N	PRESENT	0
664741	661841	20040T	PARTICIPANT	\N	PRESENT	0
664742	661841	19569H	PARTICIPANT	\N	PRESENT	0
664743	661841	04057K	PARTICIPANT	\N	PRESENT	0
664744	661841	19701S	PARTICIPANT	\N	PRESENT	0
664745	661841	14071N	PARTICIPANT	\N	PRESENT	0
664746	661841	19691J	PARTICIPANT	\N	PRESENT	0
664747	661841	19697Q	PARTICIPANT	\N	PRESENT	0
664750	661841	19619A	PARTICIPANT	\N	PRESENT	0
664752	661841	20130U	PARTICIPANT	\N	PRESENT	0
664780	664751	19569H	PARTICIPANT	\N	PRESENT	0
664781	664751	11067R	PARTICIPANT	\N	PRESENT	0
664782	664751	18193Q	PARTICIPANT	\N	PRESENT	0
664783	664751	19367Y	PARTICIPANT	\N	PRESENT	0
664784	664751	14069U	PARTICIPANT	\N	PRESENT	0
664785	664751	19599P	PARTICIPANT	\N	PRESENT	0
664786	664751	19619A	PARTICIPANT	\N	PRESENT	0
664787	664751	19760E	PARTICIPANT	\N	PRESENT	0
664788	664751	19715Y	PARTICIPANT	\N	PRESENT	0
664789	664751	19631V	PARTICIPANT	\N	PRESENT	0
664790	664751	19866P	PARTICIPANT	\N	PRESENT	0
664791	664751	19583F	PARTICIPANT	\N	PRESENT	0
664792	664751	04045F	PARTICIPANT	\N	PRESENT	0
664793	664751	04057K	PARTICIPANT	\N	PRESENT	0
664794	664751	20248J	PARTICIPANT	\N	PRESENT	0
664795	664751	14281W	PARTICIPANT	\N	PRESENT	0
664796	664751	11031D	PARTICIPANT	\N	PRESENT	0
664797	664751	14071N	PARTICIPANT	\N	PRESENT	0
664799	664751	20090E	PARTICIPANT	\N	PRESENT	0
664815	664751	19671E	PARTICIPANT	\N	PRESENT	0
664836	664751	01043Q	PARTICIPANT	\N	PRESENT	0
664778	664751	11070L	PARTICIPANT	\N	PRESENT	0
664779	664751	11097X	PARTICIPANT	\N	PRESENT	0
664837	664751	19467C	PARTICIPANT	\N	PRESENT	0
664838	664751	19691J	PARTICIPANT	\N	PRESENT	0
664839	664751	19739H	PARTICIPANT	\N	PRESENT	0
664729	661841	99004R	PARTICIPANT	\N	PRESENT	0
664730	661841	19760E	PARTICIPANT	\N	PRESENT	0
664840	664751	17779H	PARTICIPANT	\N	PRESENT	0
664864	664751	20070A	PARTICIPANT	\N	PRESENT	0
664873	664751	11053K	PARTICIPANT	\N	PRESENT	0
664875	664751	19687N	PARTICIPANT	\N	PRESENT	0
664876	664751	14042U	PARTICIPANT	\N	PRESENT	0
664877	664751	20130U	PARTICIPANT	\N	PRESENT	0
664878	664751	19251M	PARTICIPANT	\N	PRESENT	0
664879	664659	19503N	PARTICIPANT	\N	PRESENT	0
664881	664751	11085T	PARTICIPANT	\N	PRESENT	0
664882	664751	14267Y	PARTICIPANT	\N	PRESENT	0
664884	664659	20066E	PARTICIPANT	\N	EXCUSE	0
664934	664659	19715Y	PARTICIPANT	\N	PRESENT	0
667157	667155	11110B	PARTICIPANT	\N	PRESENT	0
667179	667176	11048N	PARTICIPANT	\N	PRESENT	0
670738	670737	14133K	PARTICIPANT	\N	PRESENT	0
670578	669893	01058X	PARTICIPANT	\N	PRESENT	0
670579	669893	19577H	PARTICIPANT	\N	PRESENT	0
670580	669556	14121F	PARTICIPANT	\N	PRESENT	0
670581	669893	19637C	PARTICIPANT	\N	PRESENT	0
670582	669893	14105F	PARTICIPANT	\N	PRESENT	0
670583	669893	20052X	PARTICIPANT	\N	PRESENT	0
670587	669893	11045K	PARTICIPANT	\N	PRESENT	0
670591	669893	19599P	PARTICIPANT	\N	PRESENT	0
670592	669893	19367Y	PARTICIPANT	\N	PRESENT	0
670593	669556	20080C	PARTICIPANT	\N	PRESENT	0
670594	669893	11033F	PARTICIPANT	\N	PRESENT	0
670597	669893	14021P	PARTICIPANT	\N	PRESENT	0
670598	669893	19553Y	PARTICIPANT	\N	PRESENT	0
670605	669893	19525U	PARTICIPANT	\N	PRESENT	0
670606	669893	19619A	PARTICIPANT	\N	PRESENT	0
670607	669893	19866P	PARTICIPANT	\N	PRESENT	0
670609	669893	20124W	PARTICIPANT	\N	PRESENT	0
670613	669893	20138D	PARTICIPANT	\N	PRESENT	0
670614	669893	18083K	PARTICIPANT	\N	PRESENT	0
670615	669893	98022P	PARTICIPANT	\N	PRESENT	0
670624	669893	14211G	PARTICIPANT	\N	PRESENT	0
670625	669893	19549D	PARTICIPANT	\N	PRESENT	0
670626	669893	01025N	PARTICIPANT	\N	PRESENT	0
670627	669893	19507S	PARTICIPANT	\N	PRESENT	0
670630	669893	19673G	PARTICIPANT	\N	PRESENT	0
670631	669893	11101A	PARTICIPANT	\N	PRESENT	0
670633	669893	19441R	PARTICIPANT	\N	PRESENT	0
670634	669893	10006L	PARTICIPANT	\N	PRESENT	0
670635	669893	14221J	PARTICIPANT	\N	PRESENT	0
670636	669893	11043H	PARTICIPANT	\N	PRESENT	0
670637	669893	20104S	PARTICIPANT	\N	PRESENT	0
670650	669893	19629C	PARTICIPANT	\N	PRESENT	0
670651	669566	04047H	PRESIDENT	0	PRESENT	0
670654	669893	20148F	PARTICIPANT	\N	PRESENT	0
670656	669566	14111D	PARTICIPANT	\N	PRESENT	0
670657	669566	14215L	PARTICIPANT	\N	PRESENT	0
670658	669566	19581D	PARTICIPANT	\N	PRESENT	0
670659	669893	20084G	PARTICIPANT	\N	PRESENT	0
670660	669566	14147R	PARTICIPANT	\N	PRESENT	0
670661	669556	08047A	PARTICIPANT	\N	PRESENT	0
670662	669566	19725B	PARTICIPANT	\N	PRESENT	0
670663	669566	04085P	PARTICIPANT	\N	PRESENT	0
670664	669566	10015M	PARTICIPANT	\N	PRESENT	0
670665	669566	19301E	PARTICIPANT	\N	PRESENT	0
670666	669566	19447X	PARTICIPANT	\N	PRESENT	0
670667	669566	14151M	PARTICIPANT	\N	PRESENT	0
670668	669566	20114U	PARTICIPANT	\N	PRESENT	0
670669	669566	20022R	PARTICIPANT	\N	PRESENT	0
670670	669566	11072N	PARTICIPANT	\N	PRESENT	0
670672	669893	14109K	PARTICIPANT	\N	PRESENT	0
670678	669760	19701S	PARTICIPANT	\N	PRESENT	0
670679	669760	20076G	PARTICIPANT	\N	PRESENT	0
670680	669760	19549D	PARTICIPANT	\N	PRESENT	0
670681	669760	19387D	PARTICIPANT	\N	PRESENT	0
670682	669760	14219Q	PRESIDENT	0	PRESENT	0
670683	669760	19826F	PARTICIPANT	\N	PRESENT	0
670684	669760	19599P	PARTICIPANT	\N	PRESENT	0
670685	669760	20102Q	PARTICIPANT	\N	PRESENT	0
670686	669760	19637C	PARTICIPANT	\N	PRESENT	0
670687	669760	20096L	PARTICIPANT	\N	PRESENT	0
670688	669760	18083K	PARTICIPANT	\N	PRESENT	0
670689	669760	20100N	PARTICIPANT	\N	PRESENT	0
670690	669760	05012A	PARTICIPANT	\N	PRESENT	0
670691	669760	20106U	PARTICIPANT	\N	PRESENT	0
670692	669760	20024T	PARTICIPANT	\N	PRESENT	0
670693	669760	20120S	PARTICIPANT	\N	PRESENT	0
670694	669760	19525U	PARTICIPANT	\N	PRESENT	0
670695	669760	20032T	PARTICIPANT	\N	PRESENT	0
670696	669760	20136B	PARTICIPANT	\N	PRESENT	0
670697	669760	20038A	PARTICIPANT	\N	PRESENT	0
670698	669760	14031R	PARTICIPANT	\N	PRESENT	0
670699	669760	20140W	PARTICIPANT	\N	PRESENT	0
670700	669760	19251M	PARTICIPANT	\N	PRESENT	0
670701	669760	20046A	PARTICIPANT	\N	PRESENT	0
670702	669760	11101A	PARTICIPANT	\N	PRESENT	0
670703	669760	19739H	PARTICIPANT	\N	PRESENT	0
670704	669760	19745F	PARTICIPANT	\N	PRESENT	0
670705	669760	19577H	PARTICIPANT	\N	PRESENT	0
670706	669760	19619A	PARTICIPANT	\N	PRESENT	0
670709	669893	11104D	PARTICIPANT	\N	PRESENT	0
670710	669893	19575F	PARTICIPANT	\N	PRESENT	0
670712	669566	19585H	PARTICIPANT	\N	PRESENT	0
670713	669893	14123H	PARTICIPANT	\N	PRESENT	0
670714	669893	20094J	PARTICIPANT	\N	PRESENT	0
670715	669893	20112S	PARTICIPANT	\N	PRESENT	0
670716	669893	14033T	PARTICIPANT	\N	PRESENT	0
670717	669556	07029T	PARTICIPANT	\N	PRESENT	0
670719	669893	20068G	PARTICIPANT	\N	PRESENT	0
670721	669566	14069U	PARTICIPANT	\N	PRESENT	0
670785	669893	20252E	PARTICIPANT	\N	PRESENT	0
670787	669893	19762G	PARTICIPANT	\N	PRESENT	0
670795	669567	14053L	PARTICIPANT	\N	PRESENT	0
670796	669567	14111D	PARTICIPANT	\N	PRESENT	0
670797	669567	19649G	PARTICIPANT	\N	PRESENT	0
670798	669567	10015M	PARTICIPANT	\N	PRESENT	0
670799	669567	14001X	PARTICIPANT	\N	PRESENT	0
670800	669567	19301E	PARTICIPANT	\N	PRESENT	0
670801	669567	19581D	PARTICIPANT	\N	PRESENT	0
670802	669567	19585H	PARTICIPANT	\N	PRESENT	0
670803	669567	04047H	PRESIDENT	0	PRESENT	0
670804	669567	19673G	PARTICIPANT	\N	PRESENT	0
670805	669567	01028R	PARTICIPANT	\N	PRESENT	0
670806	669567	19447X	PARTICIPANT	\N	PRESENT	0
670807	669567	19725B	PARTICIPANT	\N	PRESENT	0
670808	669567	19489J	PARTICIPANT	\N	PRESENT	0
670809	669567	19629C	PARTICIPANT	\N	PRESENT	0
670810	669567	14147R	PARTICIPANT	\N	PRESENT	0
670811	669567	14215L	PARTICIPANT	\N	PRESENT	0
670812	669567	20022R	PARTICIPANT	\N	PRESENT	0
670813	669567	11072N	PARTICIPANT	\N	PRESENT	0
670814	669567	14021P	PARTICIPANT	\N	PRESENT	0
670815	669567	14089Y	PARTICIPANT	\N	EXCUSE	0
670818	669893	20116W	PARTICIPANT	\N	PRESENT	0
670824	669893	14331P	PARTICIPANT	\N	PRESENT	0
670825	669893	19741B	PARTICIPANT	\N	PRESENT	0
670826	669567	11056N	PARTICIPANT	\N	PRESENT	0
670827	669893	14249W	PARTICIPANT	\N	PRESENT	0
670828	669893	20080C	PARTICIPANT	\N	PRESENT	0
670829	669567	20114U	PARTICIPANT	\N	PRESENT	0
670830	669893	20120S	PARTICIPANT	\N	PRESENT	0
670831	669893	16685X	PARTICIPANT	\N	PRESENT	0
670832	669893	20070A	PARTICIPANT	\N	PRESENT	0
670833	669893	20100N	PARTICIPANT	\N	PRESENT	0
670834	669567	05008E	PARTICIPANT	\N	PRESENT	0
670835	669893	14083S	PARTICIPANT	\N	PRESENT	0
670836	669893	19565D	PARTICIPANT	\N	PRESENT	0
670837	669893	11056N	PARTICIPANT	\N	PRESENT	0
670890	669894	11070L	PARTICIPANT	\N	PRESENT	0
670927	669894	18193Q	PARTICIPANT	\N	PRESENT	0
670928	669894	19683J	PARTICIPANT	\N	PRESENT	0
670929	669894	17965H	PARTICIPANT	\N	PRESENT	0
670930	669894	11067R	PARTICIPANT	\N	PRESENT	0
670931	669894	20028X	PARTICIPANT	\N	PRESENT	0
670960	669894	20148F	PARTICIPANT	\N	PRESENT	0
670933	669894	19349W	PARTICIPANT	\N	PRESENT	0
670934	669894	20180F	PARTICIPANT	\N	PRESENT	0
670935	669894	20130U	PARTICIPANT	\N	PRESENT	0
670936	669894	19782L	PARTICIPANT	\N	PRESENT	0
670937	669894	19954N	PARTICIPANT	\N	PRESENT	0
670938	669894	14195A	PARTICIPANT	\N	PRESENT	0
670939	669894	16685X	PARTICIPANT	\N	PRESENT	0
670940	669894	19467C	PARTICIPANT	\N	PRESENT	0
670941	669894	14073Q	PARTICIPANT	\N	PRESENT	0
670942	669894	20034V	PARTICIPANT	\N	PRESENT	0
670943	669894	20066E	PARTICIPANT	\N	PRESENT	0
670944	669894	20090E	PARTICIPANT	\N	PRESENT	0
670945	669894	19703U	PARTICIPANT	\N	PRESENT	0
670946	669894	19697Q	PARTICIPANT	\N	PRESENT	0
670947	669894	04092N	PARTICIPANT	\N	PRESENT	0
670948	669894	19553Y	PARTICIPANT	\N	PRESENT	0
670949	669894	14223L	PARTICIPANT	\N	PRESENT	0
670950	669894	14042U	PARTICIPANT	\N	PRESENT	0
670951	669894	20032T	PARTICIPANT	\N	PRESENT	0
670952	669894	10006L	PARTICIPANT	\N	PRESENT	0
670953	669894	19569H	PARTICIPANT	\N	PRESENT	0
670954	669894	20040T	PARTICIPANT	\N	PRESENT	0
670955	669894	19367Y	PARTICIPANT	\N	PRESENT	0
670956	669894	19798U	PARTICIPANT	\N	PRESENT	0
670957	669894	19415P	PARTICIPANT	\N	PRESENT	0
670958	669894	11097X	PARTICIPANT	\N	PRESENT	0
670961	669894	19387D	PARTICIPANT	\N	PRESENT	0
656218	656042	14327T	PARTICIPANT	\N	PRESENT	0
656219	656042	19479G	PARTICIPANT	\N	PRESENT	0
656220	656042	11048N	PARTICIPANT	\N	PRESENT	0
656221	656042	19711U	PARTICIPANT	\N	PRESENT	0
656222	656042	20080C	PARTICIPANT	\N	PRESENT	0
656223	656042	20050V	PARTICIPANT	\N	PRESENT	0
656224	656042	20914V	PARTICIPANT	\N	PRESENT	0
656225	656042	99004R	PARTICIPANT	\N	PRESENT	0
656226	656042	19335Q	PARTICIPANT	\N	PRESENT	0
656227	656042	19671E	PARTICIPANT	\N	PRESENT	0
656228	656042	07029T	PARTICIPANT	\N	EXCUSE	0
656229	656042	08034U	PARTICIPANT	\N	EXCUSE	0
656230	656042	20116W	PARTICIPANT	\N	EXCUSE	0
656231	656042	20044X	PARTICIPANT	\N	EXCUSE	0
656232	656042	11074Q	PARTICIPANT	\N	PRESENT	0
656233	656042	14225N	PRESIDENT	0	PRESENT	0
656234	656042	11012A	PARTICIPANT	\N	PRESENT	0
656235	656042	19687N	PARTICIPANT	\N	PRESENT	0
656236	656042	11040E	PARTICIPANT	\N	PRESENT	0
656237	656042	01057W	PARTICIPANT	\N	PRESENT	0
656238	656042	11110B	PARTICIPANT	\N	PRESENT	0
656239	656042	19647E	PARTICIPANT	\N	PRESENT	0
656240	656042	08011M	PARTICIPANT	\N	PRESENT	0
656241	656042	20070A	PARTICIPANT	\N	PRESENT	0
656242	656042	14189C	PARTICIPANT	\N	PRESENT	0
656243	656042	19762G	PARTICIPANT	\N	PRESENT	0
656244	656042	08073C	PARTICIPANT	\N	PRESENT	0
656588	656587	08010L	PARTICIPANT	\N	PRESENT	0
656589	656587	19479G	PARTICIPANT	\N	PRESENT	0
656590	656587	14151M	PARTICIPANT	\N	PRESENT	0
656591	656587	20054A	PARTICIPANT	\N	PRESENT	0
656919	656838	19798U	PARTICIPANT	\N	PRESENT	0
656917	656838	19760E	PARTICIPANT	\N	PRESENT	0
656918	656838	18193Q	PARTICIPANT	\N	PRESENT	0
656920	656838	19691J	PARTICIPANT	\N	PRESENT	0
656921	656837	19569H	PARTICIPANT	\N	PRESENT	0
656922	656837	19679N	PARTICIPANT	\N	PRESENT	0
656923	656837	20130U	PARTICIPANT	\N	PRESENT	0
659090	659089	19533U	PARTICIPANT	\N	PRESENT	0
659091	659089	19593H	PARTICIPANT	\N	PRESENT	0
659093	659092	19533U	PARTICIPANT	\N	PRESENT	0
659667	659665	11053K	PARTICIPANT	\N	PRESENT	0
659668	659665	01028R	PARTICIPANT	\N	PRESENT	0
659671	659409	19691J	PARTICIPANT	\N	EXCUSE	0
659680	659679	14189C	PARTICIPANT	\N	PRESENT	0
659681	659679	20094J	PARTICIPANT	\N	PRESENT	0
659682	659679	14089Y	PARTICIPANT	\N	EXCUSE	0
659683	659679	19701S	PARTICIPANT	\N	PRESENT	0
659684	659679	19681G	PARTICIPANT	\N	PRESENT	0
659685	659679	20100N	PARTICIPANT	\N	PRESENT	0
659686	659679	11083R	PARTICIPANT	\N	PRESENT	0
659687	659679	14033T	PARTICIPANT	\N	PRESENT	0
659688	659679	14026U	PARTICIPANT	\N	PRESENT	0
659689	659679	20128B	PARTICIPANT	\N	PRESENT	0
659690	659679	12041X	PARTICIPANT	\N	PRESENT	0
659691	659679	19711U	PARTICIPANT	\N	PRESENT	0
659692	659679	11026G	PARTICIPANT	\N	PRESENT	0
659693	659679	19441R	PARTICIPANT	\N	PRESENT	0
659694	659679	14169X	PARTICIPANT	\N	PRESENT	0
659695	659679	19593H	PARTICIPANT	\N	PRESENT	0
659696	659679	14237S	PARTICIPANT	\N	PRESENT	0
659697	659679	14331P	PRESIDENT	0	PRESENT	0
659698	659679	01024M	PARTICIPANT	\N	PRESENT	0
659699	659679	19954N	PARTICIPANT	\N	PRESENT	0
659700	659679	11048N	PARTICIPANT	\N	PRESENT	0
659701	659679	19333N	PARTICIPANT	\N	PRESENT	0
659702	659679	11064N	PARTICIPANT	\N	PRESENT	0
659925	659408	19577H	PARTICIPANT	\N	PRESENT	0
659926	659408	14275Y	PARTICIPANT	\N	PRESENT	0
659927	659408	19657G	PARTICIPANT	\N	PRESENT	0
659928	659408	14147R	PARTICIPANT	\N	PRESENT	0
659929	659408	18083K	PARTICIPANT	\N	PRESENT	0
659966	659965	08018U	PARTICIPANT	\N	PRESENT	0
659978	659977	04059M	PARTICIPANT	\N	PRESENT	0
659979	659977	20032T	PARTICIPANT	\N	PRESENT	0
659980	659977	20138D	PARTICIPANT	\N	PRESENT	0
659981	659977	14179A	PARTICIPANT	\N	PRESENT	0
659982	659977	20144B	PARTICIPANT	\N	PRESENT	0
659983	659977	20064C	PARTICIPANT	\N	PRESENT	0
659984	659977	11045K	PARTICIPANT	\N	PRESENT	0
659985	659977	19745F	PARTICIPANT	\N	PRESENT	0
659987	659986	20248J	PARTICIPANT	\N	PRESENT	0
659988	659986	19543W	PARTICIPANT	\N	PRESENT	0
659989	659986	19621T	PARTICIPANT	\N	PRESENT	0
659990	659986	11041F	PARTICIPANT	\N	PRESENT	0
659991	659986	14237S	PARTICIPANT	\N	PRESENT	0
659992	659986	14111D	PARTICIPANT	\N	PRESENT	0
659993	659408	12016W	PARTICIPANT	\N	PRESENT	0
660462	659084	20914V	PARTICIPANT	\N	EXCUSE	0
660469	660468	20128B	PARTICIPANT	\N	PRESENT	0
660481	660480	01062T	PARTICIPANT	\N	PRESENT	0
660485	660484	14105F	PARTICIPANT	\N	PRESENT	0
660487	660486	14105F	PARTICIPANT	\N	PRESENT	0
660490	660489	17023S	PARTICIPANT	\N	PRESENT	0
660496	660495	17023S	PARTICIPANT	\N	PRESENT	0
660498	660497	17023S	PARTICIPANT	\N	PRESENT	0
660500	660499	17023S	PARTICIPANT	\N	PRESENT	0
660505	659193	17779H	PARTICIPANT	\N	EXCUSE	0
661287	661263	11097X	PARTICIPANT	\N	PRESENT	0
661288	661263	19553Y	PARTICIPANT	\N	PRESENT	0
661558	661557	11043H	PARTICIPANT	\N	EXCUSE	0
661651	661639	11067R	PARTICIPANT	\N	PRESENT	0
661653	661639	14071N	PARTICIPANT	\N	PRESENT	0
661660	661649	14071N	PARTICIPANT	\N	PRESENT	0
661662	661649	11067R	PARTICIPANT	\N	PRESENT	0
661663	661649	20130U	PARTICIPANT	\N	PRESENT	0
661688	661686	20036X	PARTICIPANT	\N	PRESENT	0
661690	661689	20036X	PARTICIPANT	\N	PRESENT	0
661721	659867	19701S	PARTICIPANT	\N	PRESENT	0
661722	659867	19681G	PARTICIPANT	\N	PRESENT	0
661742	659867	20100N	PARTICIPANT	\N	PRESENT	0
661743	659867	19333N	PARTICIPANT	\N	PRESENT	0
661744	659867	14073Q	PARTICIPANT	\N	PRESENT	0
661745	659867	12041X	PARTICIPANT	\N	PRESENT	0
661746	659867	14331P	PARTICIPANT	\N	PRESENT	0
661747	659867	10015M	PARTICIPANT	\N	PRESENT	0
661748	659867	20098N	PARTICIPANT	\N	PRESENT	0
661889	661888	20110Q	PARTICIPANT	\N	PRESENT	0
661906	661799	01024M	PARTICIPANT	\N	EXCUSE	0
662908	661802	04047H	PRESIDENT	0	PRESENT	0
662917	662916	04047H	PARTICIPANT	\N	PRESENT	0
663098	661834	19711U	PARTICIPANT	\N	PRESENT	0
663099	661834	19679N	PARTICIPANT	\N	PRESENT	0
663100	661834	20062A	PARTICIPANT	\N	PRESENT	0
663101	661834	14147R	PARTICIPANT	\N	PRESENT	0
663102	661834	17737W	PARTICIPANT	\N	PRESENT	0
663103	661834	01057W	PARTICIPANT	\N	PRESENT	0
663104	661834	14223L	PARTICIPANT	\N	PRESENT	0
663105	661834	14187A	PARTICIPANT	\N	PRESENT	0
663106	661834	97011G	PARTICIPANT	\N	PRESENT	0
663107	661834	19741B	PARTICIPANT	\N	PRESENT	0
663108	661834	01058X	PARTICIPANT	\N	PRESENT	0
663109	661834	19667J	PARTICIPANT	\N	PRESENT	0
663110	661834	07029T	PARTICIPANT	\N	PRESENT	0
663111	661834	20140W	PARTICIPANT	\N	PRESENT	0
663112	661834	20038A	PARTICIPANT	\N	PRESENT	0
663113	661834	20180F	PARTICIPANT	\N	PRESENT	0
663114	661834	14189C	PARTICIPANT	\N	PRESENT	0
663115	661834	99004R	PARTICIPANT	\N	PRESENT	0
663116	661834	14055N	PARTICIPANT	\N	PRESENT	0
663117	661834	19798U	PARTICIPANT	\N	PRESENT	0
663118	661834	19413M	PARTICIPANT	\N	PRESENT	0
663119	661834	14037X	PARTICIPANT	\N	PRESENT	0
663120	661834	11110B	PARTICIPANT	\N	PRESENT	0
663121	661834	14215L	PARTICIPANT	\N	PRESENT	0
663122	661834	20122U	PARTICIPANT	\N	PRESENT	0
663123	661834	20086J	PARTICIPANT	\N	PRESENT	0
663124	661834	19525U	PARTICIPANT	\N	PRESENT	0
663125	661834	14249W	PARTICIPANT	\N	PRESENT	0
663126	661834	19703U	PARTICIPANT	\N	PRESENT	0
663127	661834	19599P	PARTICIPANT	\N	PRESENT	0
663128	661834	19762G	PARTICIPANT	\N	PRESENT	0
663129	661834	20064C	PARTICIPANT	\N	PRESENT	0
663130	661834	20024T	PARTICIPANT	\N	PRESENT	0
663131	661834	11040E	PARTICIPANT	\N	PRESENT	0
663132	661834	20054A	PARTICIPANT	\N	PRESENT	0
663133	661834	19729F	PARTICIPANT	\N	PRESENT	0
663134	661834	04045F	PARTICIPANT	\N	PRESENT	0
663135	661834	11097X	PARTICIPANT	\N	PRESENT	0
663136	661834	19782L	PARTICIPANT	\N	PRESENT	0
663137	661834	20090E	PARTICIPANT	\N	PRESENT	0
670146	667315	14059S	PARTICIPANT	\N	PRESENT	0
670147	667315	19717B	PARTICIPANT	\N	EXCUSE	0
670148	667315	19715Y	PARTICIPANT	\N	PRESENT	0
670149	667315	14219Q	PARTICIPANT	\N	EXCUSE	0
670330	667312	19399H	PARTICIPANT	\N	PRESENT	0
670332	670331	19745F	PARTICIPANT	\N	PRESENT	0
670333	670331	20024T	PARTICIPANT	\N	PRESENT	0
670334	670331	19251M	PARTICIPANT	\N	PRESENT	0
670340	670339	14257W	PARTICIPANT	\N	PRESENT	0
670350	670347	14257W	PARTICIPANT	\N	PRESENT	0
670352	670351	14257W	PARTICIPANT	\N	PRESENT	0
670368	670367	19533U	PARTICIPANT	\N	PRESENT	0
670534	670531	11090Q	PARTICIPANT	\N	PRESENT	0
670535	670531	14331P	PARTICIPANT	\N	PRESENT	0
670538	670531	14097Y	PARTICIPANT	\N	PRESENT	0
670539	670531	19515S	PARTICIPANT	\N	PRESENT	0
670540	670531	01024M	PARTICIPANT	\N	PRESENT	0
670542	670531	19575F	PARTICIPANT	\N	PRESENT	0
670610	670608	20066E	PARTICIPANT	\N	PRESENT	0
670612	670611	20066E	PARTICIPANT	\N	PRESENT	0
670618	670617	20066E	PARTICIPANT	\N	PRESENT	0
670621	670620	20066E	PARTICIPANT	\N	PRESENT	0
670632	670628	19369B	PARTICIPANT	\N	PRESENT	0
670723	669556	19741B	PARTICIPANT	\N	PRESENT	0
670724	669893	11012A	PARTICIPANT	\N	PRESENT	0
670726	669893	19415P	PARTICIPANT	\N	PRESENT	0
670727	669893	11053K	PARTICIPANT	\N	PRESENT	0
670728	669566	14231L	PARTICIPANT	\N	PRESENT	0
670729	669893	19669L	PARTICIPANT	\N	PRESENT	0
670730	669893	01062T	PARTICIPANT	\N	PRESENT	0
670731	669556	11053K	PARTICIPANT	\N	PRESENT	0
670732	669893	20114U	PARTICIPANT	\N	PRESENT	0
670733	665146	20094J	PARTICIPANT	\N	PRESENT	0
670735	669566	01028R	PARTICIPANT	\N	PRESENT	0
670749	669566	14053L	PARTICIPANT	\N	PRESENT	0
670751	669420	04070G	PARTICIPANT	\N	PRESENT	0
670752	669420	19699S	PARTICIPANT	\N	PRESENT	0
670753	669420	19533U	PARTICIPANT	\N	PRESENT	0
670754	669420	14229S	PARTICIPANT	\N	PRESENT	0
670755	669420	20098N	PARTICIPANT	\N	PRESENT	0
670756	669420	19573D	PARTICIPANT	\N	PRESENT	0
670757	669420	20124W	PARTICIPANT	\N	PRESENT	0
670758	669420	20026V	PARTICIPANT	\N	PRESENT	0
670759	669420	19593H	PARTICIPANT	\N	PRESENT	0
670760	669420	19527W	PARTICIPANT	\N	PRESENT	0
670761	669420	20132W	PARTICIPANT	\N	PRESENT	0
670762	669420	19651A	PARTICIPANT	\N	PRESENT	0
670763	669420	19611R	PARTICIPANT	\N	PRESENT	0
670764	669420	20142Y	PARTICIPANT	\N	PRESENT	0
670765	669420	20048C	PARTICIPANT	\N	PRESENT	0
670766	669420	19693L	PARTICIPANT	\N	PRESENT	0
670767	669420	19399H	PARTICIPANT	\N	PRESENT	0
670768	669420	20052X	PARTICIPANT	\N	PRESENT	0
670769	669420	20172F	PARTICIPANT	\N	PRESENT	0
670770	669420	14030Q	PARTICIPANT	\N	PRESENT	0
670771	669420	20058E	PARTICIPANT	\N	PRESENT	0
670772	669420	20056C	PARTICIPANT	\N	PRESENT	0
670773	669420	19735D	PARTICIPANT	\N	PRESENT	0
670774	669420	19057M	PARTICIPANT	\N	PRESENT	0
670775	669420	14109K	PARTICIPANT	\N	PRESENT	0
670776	669420	14123H	PARTICIPANT	\N	PRESENT	0
670777	669420	11104D	PARTICIPANT	\N	PRESENT	0
670778	669420	11043H	PARTICIPANT	\N	PRESENT	0
670779	669420	19758L	PARTICIPANT	\N	PRESENT	0
670780	669420	20084G	PARTICIPANT	\N	PRESENT	0
670781	669420	19621T	PARTICIPANT	\N	PRESENT	0
670782	669566	19489J	PARTICIPANT	\N	PRESENT	0
670783	669566	19629C	PARTICIPANT	\N	PRESENT	0
670784	669566	14089Y	PARTICIPANT	\N	EXCUSE	0
670792	669893	20044X	PARTICIPANT	\N	PRESENT	0
670794	670793	19369B	PARTICIPANT	\N	PRESENT	0
670820	669567	20110Q	PARTICIPANT	\N	PRESENT	0
670821	669567	14231L	PARTICIPANT	\N	PRESENT	0
670822	669567	14151M	PARTICIPANT	\N	PRESENT	0
670823	669893	20122U	PARTICIPANT	\N	PRESENT	0
670891	670722	19383Y	PARTICIPANT	\N	PRESENT	0
670892	670722	19768N	PARTICIPANT	\N	PRESENT	0
670893	670722	19515S	PARTICIPANT	\N	PRESENT	0
670894	670722	20092G	PARTICIPANT	\N	PRESENT	0
670895	670722	14357A	PARTICIPANT	\N	PRESENT	0
670896	670722	20094J	PARTICIPANT	\N	PRESENT	0
670897	670722	04045F	PARTICIPANT	\N	PRESENT	0
670898	670722	19866P	PARTICIPANT	\N	PRESENT	0
670899	670722	19631V	PARTICIPANT	\N	PRESENT	0
670900	670722	20104S	PARTICIPANT	\N	PRESENT	0
670901	670722	19705W	PARTICIPANT	\N	PRESENT	0
670902	670722	19575F	PARTICIPANT	\N	PRESENT	0
670903	670722	20018V	PARTICIPANT	\N	PRESENT	0
670904	670722	14038Y	PARTICIPANT	\N	PRESENT	0
670905	670722	19467C	PARTICIPANT	\N	PRESENT	0
670906	670722	20034V	PARTICIPANT	\N	PRESENT	0
670907	670722	14187A	PARTICIPANT	\N	PRESENT	0
670908	670722	20144B	PARTICIPANT	\N	PRESENT	0
670909	670722	14033T	PARTICIPANT	\N	PRESENT	0
670910	670722	11090Q	PRESIDENT	0	PRESENT	0
670911	670722	14205J	PARTICIPANT	\N	PRESENT	0
670912	670722	20060X	PARTICIPANT	\N	PRESENT	0
670913	670722	20062A	PARTICIPANT	\N	PRESENT	0
670914	670722	20286Q	PARTICIPANT	\N	PRESENT	0
670915	670722	20298U	PARTICIPANT	\N	PRESENT	0
670916	670722	19747H	PARTICIPANT	\N	PRESENT	0
670920	670919	14073Q	PARTICIPANT	\N	PRESENT	0
670922	670921	14073Q	PARTICIPANT	\N	PRESENT	0
670923	670921	04070G	PARTICIPANT	\N	PRESENT	0
671148	669558	14331P	PARTICIPANT	\N	PRESENT	0
671149	669478	19766L	PARTICIPANT	\N	PRESENT	0
671150	669478	04070G	PARTICIPANT	\N	PRESENT	0
671151	669478	19699S	PARTICIPANT	\N	PRESENT	0
671152	669478	19533U	PARTICIPANT	\N	PRESENT	0
671153	669478	01060R	PARTICIPANT	\N	PRESENT	0
671154	669478	14229S	PARTICIPANT	\N	PRESENT	0
671155	669478	20098N	PARTICIPANT	\N	PRESENT	0
671156	669478	20112S	PARTICIPANT	\N	PRESENT	0
671157	669478	92040Q	PARTICIPANT	\N	PRESENT	0
671158	669478	08012N	PARTICIPANT	\N	PRESENT	0
671159	669478	20016T	PARTICIPANT	\N	PRESENT	0
671160	669478	20124W	PARTICIPANT	\N	PRESENT	0
671161	669478	20026V	PARTICIPANT	\N	PRESENT	0
671162	669478	19593H	PARTICIPANT	\N	PRESENT	0
671163	669478	19527W	PARTICIPANT	\N	PRESENT	0
671164	669478	20132W	PARTICIPANT	\N	PRESENT	0
671165	669478	19611R	PARTICIPANT	\N	PRESENT	0
671166	669478	20142Y	PARTICIPANT	\N	PRESENT	0
671167	669478	20048C	PARTICIPANT	\N	PRESENT	0
671168	669478	19693L	PARTICIPANT	\N	PRESENT	0
671169	669478	19399H	PARTICIPANT	\N	PRESENT	0
671170	669478	20052X	PARTICIPANT	\N	PRESENT	0
671171	669478	20152B	PARTICIPANT	\N	PRESENT	0
671172	669478	20172F	PARTICIPANT	\N	PRESENT	0
671173	669478	20058E	PARTICIPANT	\N	PRESENT	0
671174	669478	14030Q	PARTICIPANT	\N	PRESENT	0
671175	669478	20056C	PARTICIPANT	\N	PRESENT	0
671176	669478	20180F	PARTICIPANT	\N	PRESENT	0
671177	669478	20264J	PARTICIPANT	\N	PRESENT	0
671178	669478	04059M	PARTICIPANT	\N	PRESENT	0
671179	669478	19735D	PARTICIPANT	\N	PRESENT	0
671180	669478	14109K	PARTICIPANT	\N	PRESENT	0
671181	669478	14123H	PARTICIPANT	\N	PRESENT	0
671182	669478	11043H	PARTICIPANT	\N	PRESENT	0
671183	669478	11104D	PARTICIPANT	\N	PRESENT	0
671184	669478	19758L	PARTICIPANT	\N	PRESENT	0
671185	669478	17589D	PARTICIPANT	\N	PRESENT	0
671186	669478	20084G	PARTICIPANT	\N	PRESENT	0
671187	669478	19621T	PARTICIPANT	\N	PRESENT	0
671188	669558	11070L	PARTICIPANT	\N	PRESENT	0
671189	669569	01028R	PARTICIPANT	\N	PRESENT	0
671190	669569	14179A	PARTICIPANT	\N	PRESENT	0
671191	669569	14259Y	PARTICIPANT	\N	PRESENT	0
671192	669569	19629C	PARTICIPANT	\N	PRESENT	0
671193	669558	20070A	PARTICIPANT	\N	PRESENT	0
671194	669558	14083S	PARTICIPANT	\N	PRESENT	0
671195	669558	11053K	PARTICIPANT	\N	PRESENT	0
671196	667816	20120S	PARTICIPANT	\N	PRESENT	0
671197	667816	20038A	PARTICIPANT	\N	PRESENT	0
671198	669558	01048V	PARTICIPANT	\N	PRESENT	0
671199	667816	19577H	PARTICIPANT	\N	PRESENT	0
671200	667816	14219Q	PARTICIPANT	\N	PRESENT	0
671201	669558	11074Q	PARTICIPANT	\N	PRESENT	0
671202	667816	20024T	PARTICIPANT	\N	PRESENT	0
671203	669569	14231L	PARTICIPANT	\N	PRESENT	0
659297	659296	19762G	PARTICIPANT	\N	PRESENT	0
659299	659298	19762G	PARTICIPANT	\N	PRESENT	0
659356	659354	19762G	PARTICIPANT	\N	PRESENT	0
659357	659355	19762G	PARTICIPANT	\N	PRESENT	0
659876	659875	08012N	PARTICIPANT	\N	PRESENT	0
659877	659875	19527W	PARTICIPANT	\N	PRESENT	0
661805	659416	19301E	PARTICIPANT	\N	PRESENT	0
661808	659416	11012A	PARTICIPANT	\N	PRESENT	0
664533	661844	14189C	PARTICIPANT	\N	EXCUSE	0
664534	661844	19681G	PARTICIPANT	\N	EXCUSE	0
664535	661844	04057K	PARTICIPANT	\N	EXCUSE	0
664536	661844	14357A	PARTICIPANT	\N	EXCUSE	0
664537	661905	19717B	PRESIDENT	0	PRESENT	0
664538	661905	20034V	PARTICIPANT	\N	PRESENT	0
664539	661905	14275Y	PARTICIPANT	\N	PRESENT	1
664556	664555	19768N	PARTICIPANT	\N	PRESENT	0
664557	664555	19631V	PARTICIPANT	\N	PRESENT	0
664558	664555	20078J	PARTICIPANT	\N	PRESENT	0
664559	664555	20034V	PARTICIPANT	\N	PRESENT	0
665006	660365	14030Q	PARTICIPANT	\N	EXCUSE	0
665007	660365	20084G	PARTICIPANT	\N	EXCUSE	0
665597	665287	04043D	PARTICIPANT	\N	PRESENT	0
665599	665287	11067R	PARTICIPANT	\N	EXCUSE	0
667235	667234	14147R	PARTICIPANT	\N	PRESENT	0
667236	667234	19729F	PARTICIPANT	\N	PRESENT	0
667238	667237	19729F	PARTICIPANT	\N	PRESENT	0
667241	667240	19729F	PARTICIPANT	\N	PRESENT	0
670739	670737	19719D	PARTICIPANT	\N	PRESENT	0
670740	670737	01024M	PARTICIPANT	\N	PRESENT	0
670741	670737	19691J	PARTICIPANT	\N	PRESENT	0
670742	670737	14179A	PARTICIPANT	\N	PRESENT	0
670743	670737	19333N	PARTICIPANT	\N	PRESENT	0
670744	670737	07029T	PARTICIPANT	\N	PRESENT	0
670745	670737	19745F	PARTICIPANT	\N	PRESENT	0
670746	670737	19349W	PARTICIPANT	\N	PRESENT	0
670747	670737	19798U	PARTICIPANT	\N	PRESENT	0
670748	670737	19713W	PARTICIPANT	\N	PRESENT	0
670917	670722	20078J	PARTICIPANT	\N	EXCUSE	0
670918	670722	20086J	PARTICIPANT	\N	PRESENT	0
672561	672560	14073Q	PARTICIPANT	\N	PRESENT	0
672562	672560	04070G	PARTICIPANT	\N	PRESENT	0
672813	672812	10006L	PRESIDENT	0	PRESENT	0
672814	672812	14213J	PARTICIPANT	\N	PRESENT	0
672815	672812	19697Q	PARTICIPANT	\N	PRESENT	0
672816	672812	14071N	PARTICIPANT	\N	PRESENT	0
674688	674681	19413M	PARTICIPANT	\N	PRESENT	0
674843	673345	20018V	PARTICIPANT	\N	EXCUSE	0
674848	674847	14255U	PARTICIPANT	\N	PRESENT	0
674849	674847	08009T	PARTICIPANT	\N	PRESENT	0
674850	674847	19826F	PARTICIPANT	\N	PRESENT	0
674851	674847	20056C	PARTICIPANT	\N	PRESENT	0
674852	674847	20022R	PARTICIPANT	\N	PRESENT	0
674853	674847	20084G	PARTICIPANT	\N	PRESENT	0
674855	669278	20120S	PARTICIPANT	\N	EXCUSE	0
675883	673349	11090Q	PRESIDENT	0	PRESENT	0
675884	673349	20082E	PARTICIPANT	\N	EXCUSE	0
675898	675897	14109K	PARTICIPANT	\N	PRESENT	0
676075	676070	19703U	PARTICIPANT	\N	PRESENT	0
673958	670750	19747H	PARTICIPANT	\N	PRESENT	0
676076	676070	18193Q	PARTICIPANT	\N	PRESENT	0
676101	676100	19735D	PARTICIPANT	\N	PRESENT	0
676102	676100	20084G	PARTICIPANT	\N	PRESENT	0
676103	676100	20114U	PARTICIPANT	\N	PRESENT	0
676104	676100	20142Y	PARTICIPANT	\N	PRESENT	0
676105	676100	19611R	PARTICIPANT	\N	PRESENT	0
676106	676100	20058E	PARTICIPANT	\N	PRESENT	0
674011	670750	19629C	PARTICIPANT	\N	PRESENT	0
676107	676100	20180F	PARTICIPANT	\N	PRESENT	0
676108	676100	14229S	PARTICIPANT	\N	PRESENT	0
676247	676246	11066Q	PARTICIPANT	\N	PRESENT	0
674016	670750	08028W	PARTICIPANT	\N	PRESENT	0
680366	680310	20130U	PARTICIPANT	\N	PRESENT	0
680367	680310	18193Q	PARTICIPANT	\N	PRESENT	0
674019	670750	11056N	PARTICIPANT	\N	PRESENT	0
680369	680315	18193Q	PARTICIPANT	\N	PRESENT	0
680370	680315	20130U	PARTICIPANT	\N	PRESENT	0
680371	680316	18193Q	PARTICIPANT	\N	PRESENT	0
680373	680316	20130U	PARTICIPANT	\N	PRESENT	0
680374	680353	18193Q	PARTICIPANT	\N	PRESENT	0
674682	674681	19507S	PARTICIPANT	\N	PRESENT	0
680375	680353	17965H	PARTICIPANT	\N	PRESENT	0
680376	680362	18193Q	PARTICIPANT	\N	PRESENT	0
680377	680362	17965H	PARTICIPANT	\N	PRESENT	0
680378	680363	18193Q	PARTICIPANT	\N	PRESENT	0
680379	680363	20130U	PARTICIPANT	\N	PRESENT	0
680380	680363	17965H	PARTICIPANT	\N	PRESENT	0
681024	676614	14083S	PARTICIPANT	\N	PRESENT	0
681026	676614	20066E	PARTICIPANT	\N	PRESENT	0
681027	676614	19739H	PARTICIPANT	\N	PRESENT	0
681029	676614	20266L	PARTICIPANT	\N	PRESENT	0
681030	676614	20084G	PARTICIPANT	\N	PRESENT	0
681031	676614	20058E	PARTICIPANT	\N	PRESENT	0
681085	676614	11056N	PARTICIPANT	\N	PRESENT	0
681088	676614	01024M	PARTICIPANT	\N	PRESENT	0
681089	676614	20052X	PARTICIPANT	\N	PRESENT	0
681090	676614	19543W	PARTICIPANT	\N	PRESENT	0
681091	676614	20088L	PARTICIPANT	\N	PRESENT	0
681092	676614	08061X	PARTICIPANT	\N	PRESENT	0
681093	676614	19725B	PARTICIPANT	\N	PRESENT	0
681094	676614	14073Q	PARTICIPANT	\N	PRESENT	0
681095	676614	14147R	PARTICIPANT	\N	PRESENT	0
681096	676614	95063L	PARTICIPANT	\N	PRESENT	0
681097	676614	20070A	PARTICIPANT	\N	PRESENT	0
681098	676614	20032T	PARTICIPANT	\N	PRESENT	0
681099	676614	14030Q	PARTICIPANT	\N	PRESENT	0
681100	676614	20152B	PARTICIPANT	\N	PRESENT	0
681101	676614	20026V	PARTICIPANT	\N	PRESENT	0
681102	676614	20038A	PARTICIPANT	\N	PRESENT	0
681103	676614	14105F	PARTICIPANT	\N	PRESENT	0
681104	676614	19647E	PARTICIPANT	\N	PRESENT	0
681106	676614	01058X	PARTICIPANT	\N	PRESENT	0
681107	676614	20142Y	PARTICIPANT	\N	PRESENT	0
681108	676614	14205J	PARTICIPANT	\N	PRESENT	0
681109	676614	19563B	PARTICIPANT	\N	PRESENT	0
681110	676614	08015R	PARTICIPANT	\N	PRESENT	0
681111	676614	19747H	PARTICIPANT	\N	PRESENT	0
681112	676614	20054A	PARTICIPANT	\N	PRESENT	0
681113	676614	20024T	PARTICIPANT	\N	PRESENT	0
681114	676614	19687N	PARTICIPANT	\N	PRESENT	0
681115	676614	20126Y	PARTICIPANT	\N	PRESENT	0
681119	676614	19637C	PARTICIPANT	\N	PRESENT	0
681120	676614	19741B	PARTICIPANT	\N	PRESENT	0
681121	676614	19729F	PARTICIPANT	\N	PRESENT	0
681122	676614	14211G	PARTICIPANT	\N	PRESENT	0
681123	676614	19667J	PARTICIPANT	\N	PRESENT	0
681124	676615	14026U	PARTICIPANT	\N	PRESENT	0
681125	676615	19569H	PARTICIPANT	\N	PRESENT	0
681128	676615	11067R	PARTICIPANT	\N	PRESENT	0
681131	676615	19565D	PARTICIPANT	\N	PRESENT	0
681132	676615	11031D	PARTICIPANT	\N	PRESENT	0
681136	676615	19503N	PARTICIPANT	\N	PRESENT	0
681138	676615	17779H	PARTICIPANT	\N	PRESENT	0
681139	676615	19583F	PARTICIPANT	\N	PRESENT	0
681142	676615	04045F	PARTICIPANT	\N	PRESENT	0
681144	676615	19671E	PARTICIPANT	\N	PRESENT	0
681145	676615	14217N	PARTICIPANT	\N	PRESENT	0
681147	676615	19553Y	PARTICIPANT	\N	PRESENT	0
681148	676615	19691J	PARTICIPANT	\N	PRESENT	0
681149	676615	14215L	PARTICIPANT	\N	PRESENT	0
681150	676615	11097X	PARTICIPANT	\N	PRESENT	0
681152	676615	14071N	PARTICIPANT	\N	PRESENT	0
681154	676615	97011G	PARTICIPANT	\N	PRESENT	0
681158	676615	19954N	PARTICIPANT	\N	PRESENT	0
670964	669894	14281W	PARTICIPANT	\N	PRESENT	0
670965	669894	11031D	PARTICIPANT	\N	PRESENT	0
670966	669894	14105F	PARTICIPANT	\N	PRESENT	0
670967	669894	19715Y	PARTICIPANT	\N	PRESENT	0
670968	669894	14207L	PARTICIPANT	\N	PRESENT	0
670969	669894	20026V	PARTICIPANT	\N	PRESENT	0
670970	669894	19565D	PARTICIPANT	\N	PRESENT	0
670971	669894	20140W	PARTICIPANT	\N	PRESENT	0
670972	669894	20056C	PARTICIPANT	\N	PRESENT	0
670973	669894	20132W	PARTICIPANT	\N	PRESENT	0
670974	669894	19577H	PARTICIPANT	\N	PRESENT	0
670975	669894	19657G	PARTICIPANT	\N	PRESENT	0
670976	669894	19747H	PARTICIPANT	\N	PRESENT	0
670977	669894	17779H	PARTICIPANT	\N	PRESENT	0
670978	669894	20124W	PARTICIPANT	\N	PRESENT	0
670979	669894	20062A	PARTICIPANT	\N	PRESENT	0
670980	669894	19533U	PARTICIPANT	\N	PRESENT	0
670981	669894	05008E	PARTICIPANT	\N	PRESENT	0
670962	669894	11012A	PARTICIPANT	\N	PRESENT	0
670963	669894	20048C	PARTICIPANT	\N	PRESENT	0
670982	669894	20266L	PARTICIPANT	\N	PRESENT	0
670983	669894	08015R	PARTICIPANT	\N	PRESENT	0
670984	669894	20024T	PARTICIPANT	\N	PRESENT	0
670985	669894	14217N	PARTICIPANT	\N	PRESENT	0
670986	669894	12041X	PARTICIPANT	\N	PRESENT	0
670987	669894	14033T	PARTICIPANT	\N	PRESENT	0
670988	669894	19723Y	PARTICIPANT	\N	PRESENT	0
670989	669894	19679N	PARTICIPANT	\N	PRESENT	0
670990	669894	19503N	PARTICIPANT	\N	PRESENT	0
670991	669894	20092G	PARTICIPANT	\N	PRESENT	0
670992	669894	14026U	PARTICIPANT	\N	PRESENT	0
670993	669894	20298U	PARTICIPANT	\N	PRESENT	0
670994	669894	14213J	PARTICIPANT	\N	PRESENT	0
670995	669894	19691J	PARTICIPANT	\N	PRESENT	0
670996	669894	08045X	PARTICIPANT	\N	PRESENT	0
670997	669894	17023S	PARTICIPANT	\N	PRESENT	0
670998	669894	19713W	PARTICIPANT	\N	PRESENT	0
670999	669894	20138D	PARTICIPANT	\N	PRESENT	0
671000	669894	19621T	PARTICIPANT	\N	PRESENT	0
671001	669894	14071N	PARTICIPANT	\N	PRESENT	0
671002	669894	19760E	PARTICIPANT	\N	PRESENT	0
671003	669894	14083S	PARTICIPANT	\N	PRESENT	0
671004	669894	14215L	PARTICIPANT	\N	PRESENT	0
671005	669894	19591F	PARTICIPANT	\N	PRESENT	0
671006	669894	14147R	PARTICIPANT	\N	PRESENT	0
671007	669894	14187A	PARTICIPANT	\N	PRESENT	0
671008	669894	20070A	PARTICIPANT	\N	PRESENT	0
671009	669894	20172F	PARTICIPANT	\N	PRESENT	0
671010	669894	04042C	PARTICIPANT	\N	PRESENT	0
671011	669894	19599P	PARTICIPANT	\N	PRESENT	0
671012	669894	07029T	PARTICIPANT	\N	PRESENT	0
671013	669894	19573D	PARTICIPANT	\N	PRESENT	0
671014	669894	19575F	PARTICIPANT	\N	PRESENT	0
671015	669894	01028R	PARTICIPANT	\N	PRESENT	0
671016	669894	19507S	PARTICIPANT	\N	PRESENT	0
671017	669894	18083K	PARTICIPANT	\N	PRESENT	0
671018	669894	11048N	PARTICIPANT	\N	PRESENT	0
671019	669894	20110Q	PARTICIPANT	\N	PRESENT	0
671020	669894	19383Y	PARTICIPANT	\N	PRESENT	0
671021	669894	14357A	PARTICIPANT	\N	PRESENT	0
671022	669894	10015M	PARTICIPANT	\N	PRESENT	0
671023	669894	14231L	PARTICIPANT	\N	PRESENT	0
671024	669894	14069U	PARTICIPANT	\N	PRESENT	0
671025	669894	20086J	PARTICIPANT	\N	PRESENT	0
671026	669894	20134Y	PARTICIPANT	\N	PRESENT	0
671027	669894	20058E	PARTICIPANT	\N	PRESENT	0
671028	669894	11056N	PARTICIPANT	\N	PRESENT	0
671237	667316	05008E	PARTICIPANT	\N	EXCUSE	0
672234	670085	19701S	PARTICIPANT	\N	EXCUSE	0
672235	670085	20098N	PARTICIPANT	\N	EXCUSE	0
672236	670085	04057K	PARTICIPANT	\N	EXCUSE	0
672237	670085	11026G	PARTICIPANT	\N	EXCUSE	0
672238	670085	19563B	PARTICIPANT	\N	EXCUSE	0
672239	670085	12041X	PARTICIPANT	\N	PRESENT	0
672240	670085	14357A	PARTICIPANT	\N	PRESENT	0
672241	670085	14073Q	PARTICIPANT	\N	PRESENT	0
672242	670085	20100N	PARTICIPANT	\N	PRESENT	0
672243	670085	19333N	PARTICIPANT	\N	PRESENT	0
672245	670085	04045F	PARTICIPANT	\N	PRESENT	0
672246	670085	10015M	PARTICIPANT	\N	PRESENT	0
672247	670085	14331P	PARTICIPANT	\N	PRESENT	0
672248	670085	14001X	PARTICIPANT	\N	PRESENT	0
672249	670085	04047H	PARTICIPANT	\N	PRESENT	0
672250	670085	11072N	PARTICIPANT	\N	PRESENT	0
672251	670085	95063L	PARTICIPANT	\N	PRESENT	0
672256	670085	19489J	PARTICIPANT	\N	PRESENT	0
672257	670085	14215L	PARTICIPANT	\N	PRESENT	0
672258	670085	20022R	PARTICIPANT	\N	PRESENT	0
672259	670085	20110Q	PARTICIPANT	\N	PRESENT	0
672265	670085	20094J	PARTICIPANT	\N	EXCUSE	0
672285	670085	01028R	PARTICIPANT	\N	PRESENT	0
672444	672443	14073Q	PARTICIPANT	\N	PRESENT	0
672445	672443	04059M	PARTICIPANT	\N	PRESENT	1
672446	672443	19533U	PARTICIPANT	\N	PRESENT	1
672447	672443	19611R	PARTICIPANT	\N	PRESENT	0
672501	672500	01058X	PARTICIPANT	\N	PRESENT	0
672502	672500	19347U	PARTICIPANT	\N	PRESENT	0
672504	672503	01058X	PARTICIPANT	\N	PRESENT	0
672505	672503	19347U	PARTICIPANT	\N	PRESENT	0
672507	672506	12028B	PARTICIPANT	\N	PRESENT	0
672508	672506	11064N	PARTICIPANT	\N	PRESENT	0
672510	672509	12028B	PARTICIPANT	\N	PRESENT	0
672511	672509	11064N	PARTICIPANT	\N	PRESENT	0
672592	672590	11056N	PARTICIPANT	\N	PRESENT	0
673860	670788	19611R	PRESIDENT	0	PRESENT	0
673861	670788	14109K	PARTICIPANT	\N	PRESENT	0
673862	670788	20264J	PARTICIPANT	\N	PRESENT	0
673863	670788	20142Y	PARTICIPANT	\N	PRESENT	0
673864	670788	20134Y	PARTICIPANT	\N	PRESENT	0
673865	670788	14229S	PARTICIPANT	\N	PRESENT	0
673866	670788	11104D	PARTICIPANT	\N	PRESENT	0
673867	670788	19758L	PARTICIPANT	\N	PRESENT	0
673868	670788	19651A	PARTICIPANT	\N	PRESENT	0
673869	670788	20132W	PARTICIPANT	\N	PRESENT	0
673870	670788	19735D	PARTICIPANT	\N	PRESENT	0
673871	670788	19693L	PARTICIPANT	\N	PRESENT	0
673872	670788	19533U	PARTICIPANT	\N	PRESENT	0
673873	670788	20098N	PARTICIPANT	\N	PRESENT	0
673875	670788	20048C	PARTICIPANT	\N	PRESENT	0
673876	670788	14030Q	PARTICIPANT	\N	PRESENT	0
673877	670788	20056C	PARTICIPANT	\N	PRESENT	0
673878	670788	20152B	PARTICIPANT	\N	PRESENT	0
673879	670788	14073Q	PARTICIPANT	\N	PRESENT	0
673880	670788	20026V	PARTICIPANT	\N	PRESENT	0
673881	670788	20180F	PARTICIPANT	\N	PRESENT	0
673882	670788	20058E	PARTICIPANT	\N	PRESENT	0
673883	670788	20124W	PARTICIPANT	\N	PRESENT	0
673884	670788	19399H	PARTICIPANT	\N	PRESENT	0
673885	670788	20052X	PARTICIPANT	\N	PRESENT	0
673886	670788	19621T	PARTICIPANT	\N	PRESENT	0
673887	670788	19573D	PARTICIPANT	\N	PRESENT	0
673888	670788	11043H	PARTICIPANT	\N	PRESENT	0
673933	670788	20084G	PARTICIPANT	\N	PRESENT	0
674169	671029	14021P	PARTICIPANT	\N	PRESENT	0
674170	671029	18083K	PARTICIPANT	\N	PRESENT	0
674171	671029	19533U	PARTICIPANT	\N	PRESENT	0
674172	671029	19399H	PARTICIPANT	\N	PRESENT	0
674173	671029	19762G	PARTICIPANT	\N	PRESENT	0
674174	671029	11072N	PARTICIPANT	\N	PRESENT	0
674175	671029	07029T	PARTICIPANT	\N	PRESENT	0
674176	671029	14151M	PARTICIPANT	\N	PRESENT	0
674177	671029	19782L	PARTICIPANT	\N	PRESENT	0
674178	671029	19565D	PARTICIPANT	\N	PRESENT	0
674179	671029	19741B	PARTICIPANT	\N	PRESENT	0
674180	671029	20116W	PARTICIPANT	\N	PRESENT	0
655234	655233	11090Q	PARTICIPANT	\N	PRESENT	0
655236	655235	20118Y	PARTICIPANT	\N	PRESENT	0
656948	656947	19699S	PARTICIPANT	\N	PRESENT	0
663138	661834	19695N	PARTICIPANT	\N	PRESENT	0
663139	661834	14257W	PARTICIPANT	\N	PRESENT	0
663143	661834	12016W	PARTICIPANT	\N	PRESENT	0
663141	661834	14053L	PARTICIPANT	\N	PRESENT	0
663142	661834	19467C	PARTICIPANT	\N	PRESENT	0
663144	661834	11056N	PARTICIPANT	\N	PRESENT	0
663145	661834	20142Y	PARTICIPANT	\N	PRESENT	0
663146	661834	14083S	PARTICIPANT	\N	PRESENT	0
663147	661834	19747H	PARTICIPANT	\N	PRESENT	0
663148	661834	20106U	PARTICIPANT	\N	PRESENT	0
663210	661835	14055N	PARTICIPANT	\N	PRESENT	0
663211	661835	11040E	PARTICIPANT	\N	PRESENT	0
663212	661835	04085P	PARTICIPANT	\N	PRESENT	0
663213	661835	04047H	PARTICIPANT	\N	PRESENT	0
663214	661835	11056N	PARTICIPANT	\N	PRESENT	0
663215	661835	19695N	PARTICIPANT	\N	PRESENT	0
663216	661835	20046A	PARTICIPANT	\N	PRESENT	0
663217	661835	11031D	PARTICIPANT	\N	PRESENT	0
663218	661835	14249W	PARTICIPANT	\N	PRESENT	0
663219	661835	20142Y	PARTICIPANT	\N	PRESENT	0
663220	661835	20110Q	PARTICIPANT	\N	PRESENT	0
663221	661835	20092G	PARTICIPANT	\N	PRESENT	0
663222	661835	14257W	PARTICIPANT	\N	PRESENT	0
663223	661835	20914V	PARTICIPANT	\N	PRESENT	0
663224	661835	14107H	PARTICIPANT	\N	PRESENT	0
663225	661835	19531S	PARTICIPANT	\N	PRESENT	0
663226	661835	19545Y	PARTICIPANT	\N	PRESENT	0
663227	661835	14231L	PARTICIPANT	\N	PRESENT	0
663228	661835	10015M	PARTICIPANT	\N	PRESENT	0
663229	661835	17737W	PARTICIPANT	\N	PRESENT	0
663230	661835	07004J	PARTICIPANT	\N	PRESENT	0
663231	661835	20090E	PARTICIPANT	\N	PRESENT	0
663232	661835	20032T	PARTICIPANT	\N	PRESENT	0
663233	661835	14147R	PARTICIPANT	\N	PRESENT	0
663234	661835	20054A	PARTICIPANT	\N	PRESENT	0
663235	661835	14053L	PARTICIPANT	\N	PRESENT	0
663236	661835	20064C	PARTICIPANT	\N	PRESENT	0
663237	661835	19667J	PARTICIPANT	\N	PRESENT	0
663238	661835	20034V	PARTICIPANT	\N	PRESENT	0
663239	661835	19447X	PARTICIPANT	\N	PRESENT	0
663240	661835	20044X	PARTICIPANT	\N	PRESENT	0
663241	661835	20026V	PARTICIPANT	\N	PRESENT	0
663242	661835	12041X	PARTICIPANT	\N	PRESENT	0
663243	661835	11077T	PARTICIPANT	\N	PRESENT	0
663244	661835	14215L	PARTICIPANT	\N	PRESENT	0
663245	661835	19723Y	PARTICIPANT	\N	PRESENT	0
663246	661835	07029T	PARTICIPANT	\N	PRESENT	0
663247	661835	19741B	PARTICIPANT	\N	PRESENT	0
663248	661835	19954N	PARTICIPANT	\N	PRESENT	0
663249	661835	14038Y	PARTICIPANT	\N	PRESENT	0
663250	661835	20180F	PARTICIPANT	\N	PRESENT	0
663251	661835	20096L	PARTICIPANT	\N	PRESENT	0
663252	661835	05008E	PARTICIPANT	\N	PRESENT	0
663253	661835	01028R	PARTICIPANT	\N	PRESENT	0
663254	661835	19549D	PARTICIPANT	\N	PRESENT	0
663255	661835	19760E	PARTICIPANT	\N	PRESENT	0
663208	661835	95063L	PARTICIPANT	\N	PRESENT	0
663209	661835	14033T	PARTICIPANT	\N	PRESENT	0
663256	661835	20266L	PARTICIPANT	\N	PRESENT	0
663258	661835	20030R	PARTICIPANT	\N	PRESENT	0
663259	661835	20080C	PARTICIPANT	\N	PRESENT	0
663262	661835	19387D	PARTICIPANT	\N	PRESENT	0
663263	661835	20070A	PARTICIPANT	\N	PRESENT	0
663264	661835	20042V	PARTICIPANT	\N	PRESENT	0
663265	661835	19782L	PARTICIPANT	\N	PRESENT	0
663266	661835	19758L	PARTICIPANT	\N	PRESENT	0
663267	661835	18083K	PARTICIPANT	\N	PRESENT	0
663268	661835	14213J	PARTICIPANT	\N	PRESENT	0
663269	661835	20048C	PARTICIPANT	\N	PRESENT	0
663270	661835	11012A	PARTICIPANT	\N	PRESENT	0
664540	661844	11083R	PARTICIPANT	\N	PRESENT	0
663589	663580	19335Q	PARTICIPANT	\N	PRESENT	0
663592	663585	19335Q	PARTICIPANT	\N	PRESENT	0
664541	661844	14026U	PARTICIPANT	\N	PRESENT	0
664542	661844	19725B	PARTICIPANT	\N	PRESENT	0
664543	661844	19333N	PARTICIPANT	\N	PRESENT	0
664544	661844	08034U	PARTICIPANT	\N	PRESENT	0
664545	661844	14331P	PARTICIPANT	\N	PRESENT	0
664546	661844	14097Y	PARTICIPANT	\N	PRESENT	0
664547	661844	10015M	PARTICIPANT	\N	PRESENT	0
664548	661844	04045F	PARTICIPANT	\N	PRESENT	0
664549	661844	20286Q	PARTICIPANT	\N	PRESENT	0
664550	661844	19531S	PARTICIPANT	\N	PRESENT	0
664553	661844	20094J	PARTICIPANT	\N	PRESENT	0
664568	661844	20098N	PARTICIPANT	\N	PRESENT	0
664952	664945	19762G	PARTICIPANT	\N	PRESENT	0
664953	664945	19531S	PARTICIPANT	\N	PRESENT	0
664955	664945	19507S	PARTICIPANT	\N	PRESENT	0
664956	664945	01025N	PARTICIPANT	\N	PRESENT	0
664978	664977	20036X	PARTICIPANT	\N	PRESENT	0
664984	664982	01048V	PARTICIPANT	\N	PRESENT	0
664988	664987	01048V	PARTICIPANT	\N	PRESENT	0
664992	664991	14327T	PARTICIPANT	\N	PRESENT	0
664999	664998	20116W	PARTICIPANT	\N	PRESENT	0
665005	665003	11053K	PARTICIPANT	\N	PRESENT	0
665009	665008	08009T	PARTICIPANT	\N	PRESENT	0
665010	665008	20044X	PARTICIPANT	\N	PRESENT	0
665014	665013	20126Y	PARTICIPANT	\N	PRESENT	0
665020	665019	19545Y	PARTICIPANT	\N	PRESENT	0
665021	665019	20914V	PARTICIPANT	\N	PRESENT	0
665031	665030	19545Y	PARTICIPANT	\N	PRESENT	0
665032	665030	20914V	PARTICIPANT	\N	PRESENT	0
665034	665033	19479G	PARTICIPANT	\N	PRESENT	0
665036	665035	11074Q	PARTICIPANT	\N	PRESENT	0
665037	665035	19349W	PARTICIPANT	\N	PRESENT	0
665869	665868	19673G	PARTICIPANT	\N	PRESENT	0
665870	665868	20124W	PARTICIPANT	\N	PRESENT	0
668422	668420	14193X	PARTICIPANT	\N	PRESENT	0
665872	665868	20056C	PARTICIPANT	\N	PRESENT	0
665900	665898	19399H	PARTICIPANT	\N	PRESENT	0
665901	665898	20142Y	PARTICIPANT	\N	PRESENT	0
665902	665899	19399H	PARTICIPANT	\N	PRESENT	0
666322	666321	11074Q	PARTICIPANT	\N	PRESENT	0
666323	666321	19349W	PARTICIPANT	\N	PRESENT	0
666325	666324	14253S	PARTICIPANT	\N	PRESENT	0
666336	666335	19711U	PARTICIPANT	\N	PRESENT	1
666340	666338	19711U	PARTICIPANT	\N	PRESENT	0
668335	667697	01057W	PARTICIPANT	\N	PRESENT	0
668421	668420	14255U	PARTICIPANT	\N	PRESENT	0
668423	668420	19421M	PARTICIPANT	\N	PRESENT	0
669078	667607	20042V	PARTICIPANT	\N	PRESENT	0
669079	667607	20132W	PARTICIPANT	\N	PRESENT	0
669080	667607	19711U	PARTICIPANT	\N	PRESENT	0
669081	667607	14259Y	PARTICIPANT	\N	PRESENT	0
669082	667607	95063L	PARTICIPANT	\N	PRESENT	0
669083	667607	20068G	PARTICIPANT	\N	PRESENT	0
669084	667607	20050V	PARTICIPANT	\N	PRESENT	0
669091	668105	19735D	PARTICIPANT	\N	PRESENT	0
669250	667724	14187A	PARTICIPANT	\N	PRESENT	0
669251	667724	19467C	PARTICIPANT	\N	PRESENT	0
669252	667724	11053K	PARTICIPANT	\N	PRESENT	0
669253	667724	20136B	PARTICIPANT	\N	PRESENT	0
669254	667724	14071N	PARTICIPANT	\N	PRESENT	0
669255	667724	05008E	PARTICIPANT	\N	PRESENT	0
669256	667724	19713W	PARTICIPANT	\N	PRESENT	0
669273	667724	19347U	PARTICIPANT	\N	PRESENT	0
669277	667724	17023S	PARTICIPANT	\N	PRESENT	0
669279	667724	20038A	PARTICIPANT	\N	PRESENT	0
669282	667724	19691J	PARTICIPANT	\N	PRESENT	0
669283	667698	14123H	PARTICIPANT	\N	PRESENT	0
669284	667698	14189C	PARTICIPANT	\N	EXCUSE	0
669285	667698	19671E	PARTICIPANT	\N	EXCUSE	0
669287	667724	20044X	PARTICIPANT	\N	PRESENT	0
669289	667724	14179A	PARTICIPANT	\N	PRESENT	0
669290	667724	19611R	PARTICIPANT	\N	PRESENT	0
669291	667724	07029T	PARTICIPANT	\N	PRESENT	0
671204	669569	19649G	PARTICIPANT	\N	PRESENT	0
671205	669569	04085P	PARTICIPANT	\N	PRESENT	0
671206	669569	19543W	PARTICIPANT	\N	PRESENT	0
671207	669478	19651A	PARTICIPANT	\N	PRESENT	0
671208	667816	14169X	PARTICIPANT	\N	PRESENT	0
671210	671209	14053L	PARTICIPANT	\N	PRESENT	0
671211	671209	19749K	PARTICIPANT	\N	PRESENT	0
671213	671212	14053L	PARTICIPANT	\N	PRESENT	0
671214	671212	19749K	PARTICIPANT	\N	PRESENT	0
671215	669478	20134Y	PARTICIPANT	\N	PRESENT	0
671216	669478	14073Q	PARTICIPANT	\N	PRESENT	0
671217	669478	19057M	PARTICIPANT	\N	PRESENT	0
671218	669558	08034U	PARTICIPANT	\N	PRESENT	0
671235	669558	11056N	PARTICIPANT	\N	PRESENT	0
671242	669895	14107H	PARTICIPANT	\N	PRESENT	0
671243	669895	19866P	PARTICIPANT	\N	PRESENT	0
671244	669895	19629C	PARTICIPANT	\N	PRESENT	0
671245	669895	98022P	PARTICIPANT	\N	PRESENT	0
671246	669895	19675J	PARTICIPANT	\N	PRESENT	0
671247	669895	20068G	PARTICIPANT	\N	PRESENT	0
671248	669895	14259Y	PARTICIPANT	\N	PRESENT	0
671249	669895	92040Q	PARTICIPANT	\N	PRESENT	0
671250	669895	20026V	PARTICIPANT	\N	PRESENT	0
671251	669895	19511N	PARTICIPANT	\N	PRESENT	0
671252	669895	20076G	PARTICIPANT	\N	PRESENT	0
671253	669895	20062A	PARTICIPANT	\N	PRESENT	0
671254	669895	19713W	PARTICIPANT	\N	PRESENT	0
671255	669895	20100N	PARTICIPANT	\N	PRESENT	0
671256	669895	14083S	PARTICIPANT	\N	PRESENT	0
671257	669895	12041X	PARTICIPANT	\N	PRESENT	0
671258	669895	19413M	PARTICIPANT	\N	PRESENT	0
671259	669895	07004J	PARTICIPANT	\N	PRESENT	0
671260	669895	11033F	PARTICIPANT	\N	PRESENT	0
671261	669895	14059S	PARTICIPANT	\N	PRESENT	0
671262	669895	18083K	PARTICIPANT	\N	PRESENT	0
671263	669895	19621T	PARTICIPANT	\N	PRESENT	0
671264	669895	19583F	PARTICIPANT	\N	PRESENT	0
671265	669895	20056C	PARTICIPANT	\N	PRESENT	0
671266	669895	20024T	PARTICIPANT	\N	PRESENT	0
671267	669895	20020P	PARTICIPANT	\N	PRESENT	0
671268	669895	20102Q	PARTICIPANT	\N	PRESENT	0
671269	669895	19721W	PARTICIPANT	\N	PRESENT	0
671270	669895	19695N	PARTICIPANT	\N	PRESENT	0
671271	669895	11101A	PARTICIPANT	\N	PRESENT	0
671272	669895	19747H	PARTICIPANT	\N	PRESENT	0
671273	669895	20036X	PARTICIPANT	\N	PRESENT	0
671274	669895	12028B	PARTICIPANT	\N	PRESENT	0
671275	669895	17965H	PARTICIPANT	\N	PRESENT	0
671276	669895	20028X	PARTICIPANT	\N	PRESENT	0
671277	669895	11045K	PARTICIPANT	\N	PRESENT	0
671278	669895	20140W	PARTICIPANT	\N	PRESENT	0
671279	669895	20098N	PARTICIPANT	\N	PRESENT	0
671280	669895	19643A	PARTICIPANT	\N	PRESENT	0
671281	669895	20106U	PARTICIPANT	\N	PRESENT	0
671282	669895	11104D	PARTICIPANT	\N	PRESENT	0
671283	669895	19349W	PARTICIPANT	\N	PRESENT	0
671284	669895	14219Q	PARTICIPANT	\N	PRESENT	0
671285	669895	19739H	PARTICIPANT	\N	PRESENT	0
671286	669895	19479G	PARTICIPANT	\N	PRESENT	0
671287	669895	19697Q	PARTICIPANT	\N	PRESENT	0
671288	669895	99004R	PARTICIPANT	\N	PRESENT	0
671289	669895	19387D	PARTICIPANT	\N	PRESENT	0
671290	669895	20120S	PARTICIPANT	\N	PRESENT	0
671291	669895	11067R	PARTICIPANT	\N	PRESENT	0
671292	669895	19599P	PARTICIPANT	\N	PRESENT	0
671293	669895	14121F	PARTICIPANT	\N	PRESENT	0
671294	669895	19798U	PARTICIPANT	\N	PRESENT	0
671295	669895	19711U	PARTICIPANT	\N	PRESENT	0
671296	669895	19741B	PARTICIPANT	\N	PRESENT	0
671297	669895	19533U	PARTICIPANT	\N	PRESENT	0
671298	669895	20090E	PARTICIPANT	\N	PRESENT	0
671299	669895	19687N	PARTICIPANT	\N	PRESENT	0
671300	669895	19565D	PARTICIPANT	\N	PRESENT	0
671301	669895	19593H	PARTICIPANT	\N	PRESENT	0
671302	669895	11040E	PARTICIPANT	\N	PRESENT	0
671303	669895	04085P	PARTICIPANT	\N	PRESENT	0
671304	669895	19760E	PARTICIPANT	\N	PRESENT	0
671305	669895	17637T	PARTICIPANT	\N	PRESENT	0
671306	669895	20092G	PARTICIPANT	\N	PRESENT	0
671307	669895	20142Y	PARTICIPANT	\N	PRESENT	0
671308	669895	04008A	PARTICIPANT	\N	PRESENT	0
671309	669895	11077T	PARTICIPANT	\N	PRESENT	0
671310	669895	19693L	PARTICIPANT	\N	PRESENT	0
671311	669895	19575F	PARTICIPANT	\N	PRESENT	0
671312	669895	20130U	PARTICIPANT	\N	PRESENT	0
671313	669895	20914V	PARTICIPANT	\N	PRESENT	0
671314	669895	20134Y	PARTICIPANT	\N	PRESENT	0
671315	669895	19525U	PARTICIPANT	\N	PRESENT	0
671316	669895	19782L	PARTICIPANT	\N	PRESENT	0
671317	669895	14037X	PARTICIPANT	\N	PRESENT	0
671318	669895	19679N	PARTICIPANT	\N	PRESENT	0
671319	669895	19637C	PARTICIPANT	\N	PRESENT	0
671320	669895	08073C	PARTICIPANT	\N	PRESENT	0
671321	669895	19591F	PARTICIPANT	\N	PRESENT	0
671322	669895	19703U	PARTICIPANT	\N	PRESENT	0
671323	669895	04045F	PARTICIPANT	\N	PRESENT	0
671324	669895	19301E	PARTICIPANT	\N	PRESENT	0
671325	669895	19329S	PARTICIPANT	\N	PRESENT	0
671326	669895	08010L	PARTICIPANT	\N	PRESENT	0
671327	669895	08061X	PARTICIPANT	\N	PRESENT	0
671328	669895	04047H	PARTICIPANT	\N	PRESENT	0
671329	669895	11072N	PARTICIPANT	\N	PRESENT	0
671330	669895	14026U	PARTICIPANT	\N	PRESENT	0
671331	669895	14123H	PARTICIPANT	\N	PRESENT	0
671332	669895	11048N	PARTICIPANT	\N	PRESENT	0
671333	669895	04092N	PARTICIPANT	\N	PRESENT	0
671334	669895	08034U	PARTICIPANT	\N	PRESENT	0
671335	669895	19415P	PARTICIPANT	\N	PRESENT	0
671336	669895	11097X	PARTICIPANT	\N	PRESENT	0
671337	669895	14071N	PARTICIPANT	\N	PRESENT	0
671338	669895	14187A	PARTICIPANT	\N	PRESENT	0
671339	669895	01060R	PARTICIPANT	\N	PRESENT	0
671340	669895	14055N	PARTICIPANT	\N	PRESENT	0
671341	669895	14223L	PARTICIPANT	\N	PRESENT	0
671342	669895	95063L	PARTICIPANT	\N	PRESENT	0
671343	669895	10015M	PARTICIPANT	\N	PRESENT	0
671344	669895	14249W	PARTICIPANT	\N	PRESENT	0
671345	669895	14169X	PARTICIPANT	\N	PRESENT	0
671346	669895	11056N	PARTICIPANT	\N	PRESENT	0
671347	669895	20116W	PARTICIPANT	\N	PRESENT	0
671348	669895	04071H	PARTICIPANT	\N	PRESENT	0
671349	669895	20128B	PARTICIPANT	\N	PRESENT	0
671350	669895	11043H	PARTICIPANT	\N	PRESENT	0
671351	669895	14207L	PARTICIPANT	\N	PRESENT	0
671352	669895	20122U	PARTICIPANT	\N	PRESENT	0
671353	669895	11064N	PARTICIPANT	\N	PRESENT	0
671354	669895	14251Q	PARTICIPANT	\N	PRESENT	0
671355	669895	17367Q	PARTICIPANT	\N	PRESENT	0
671356	669895	14221J	PARTICIPANT	\N	PRESENT	0
671357	669895	19515S	PARTICIPANT	\N	PRESENT	0
671358	669895	04057K	PARTICIPANT	\N	PRESENT	0
671359	669895	19563B	PARTICIPANT	\N	PRESENT	0
671360	669895	20050V	PARTICIPANT	\N	PRESENT	0
671361	669895	11080N	PARTICIPANT	\N	PRESENT	0
671362	669895	01057W	PARTICIPANT	\N	PRESENT	0
671363	669895	17589D	PARTICIPANT	\N	PRESENT	0
671364	669895	14195A	PARTICIPANT	\N	PRESENT	0
671365	669895	11090Q	PARTICIPANT	\N	PRESENT	0
671366	669895	11012A	PARTICIPANT	\N	PRESENT	0
671367	669895	14069U	PARTICIPANT	\N	PRESENT	0
671368	669895	14053L	PARTICIPANT	\N	PRESENT	0
671369	669895	19421M	PARTICIPANT	\N	PRESENT	0
671370	669895	14215L	PARTICIPANT	\N	PRESENT	0
671371	669895	20038A	PARTICIPANT	\N	PRESENT	0
671372	669895	20016T	PARTICIPANT	\N	PRESENT	0
671373	669895	19667J	PARTICIPANT	\N	PRESENT	0
671374	669895	19673G	PARTICIPANT	\N	PRESENT	0
671375	669895	19715Y	PARTICIPANT	\N	PRESENT	0
671376	669895	14253S	PARTICIPANT	\N	PRESENT	0
671377	669895	19647E	PARTICIPANT	\N	PRESENT	0
671378	669895	20136B	PARTICIPANT	\N	PRESENT	0
671379	669895	19347U	PARTICIPANT	\N	PRESENT	0
671380	669895	14105F	PARTICIPANT	\N	PRESENT	0
671381	669895	19631V	PARTICIPANT	\N	PRESENT	0
671382	669895	04059M	PARTICIPANT	\N	PRESENT	0
671383	669895	20032T	PARTICIPANT	\N	PRESENT	0
671384	669895	14021P	PARTICIPANT	\N	PRESENT	0
671385	669895	20118Y	PARTICIPANT	\N	PRESENT	0
671386	669895	19683J	PARTICIPANT	\N	PRESENT	0
671387	669895	14097Y	PARTICIPANT	\N	PRESENT	0
671388	669895	20022R	PARTICIPANT	\N	PRESENT	0
669691	667727	12041X	PARTICIPANT	\N	PRESENT	0
669692	667727	18083K	PARTICIPANT	\N	PRESENT	0
669693	667727	08060W	PARTICIPANT	\N	PRESENT	0
669694	667727	19333N	PARTICIPANT	\N	PRESENT	0
669695	667727	19503N	PARTICIPANT	\N	PRESENT	0
669696	667727	20082E	PARTICIPANT	\N	PRESENT	0
669697	667727	20102Q	PARTICIPANT	\N	PRESENT	0
669698	667727	20076G	PARTICIPANT	\N	PRESENT	0
669716	667727	14219Q	PARTICIPANT	\N	PRESENT	0
669700	667727	20038A	PARTICIPANT	\N	PRESENT	0
669701	667727	20100N	PARTICIPANT	\N	PRESENT	0
669702	667727	20044X	PARTICIPANT	\N	PRESENT	0
669703	667727	20142Y	PARTICIPANT	\N	PRESENT	0
669704	667727	20058E	PARTICIPANT	\N	PRESENT	0
669705	667727	14221J	PARTICIPANT	\N	PRESENT	0
669706	667727	19637C	PARTICIPANT	\N	PRESENT	0
669707	667727	11090Q	PARTICIPANT	\N	PRESENT	0
669708	667727	19549D	PARTICIPANT	\N	PRESENT	0
669709	667727	20062A	PARTICIPANT	\N	PRESENT	0
669710	667727	20144B	PARTICIPANT	\N	PRESENT	0
669711	667727	20024T	PARTICIPANT	\N	PRESENT	0
669712	667727	19619A	PARTICIPANT	\N	PRESENT	0
669713	667727	14207L	PARTICIPANT	\N	PRESENT	0
669714	667727	20046A	PARTICIPANT	\N	PRESENT	0
669715	667727	20120S	PARTICIPANT	\N	PRESENT	0
669717	667727	14031R	PARTICIPANT	\N	PRESENT	0
669718	667727	20092G	PARTICIPANT	\N	PRESENT	0
669719	667727	19695N	PARTICIPANT	\N	PRESENT	0
669720	667727	14215L	PARTICIPANT	\N	PRESENT	0
669721	667727	19651A	PARTICIPANT	\N	PRESENT	0
669722	667727	14033T	PARTICIPANT	\N	PRESENT	0
669723	667727	20106U	PARTICIPANT	\N	PRESENT	0
669724	667727	11065P	PARTICIPANT	\N	PRESENT	0
669725	667727	99004R	PARTICIPANT	\N	PRESENT	0
669726	667727	19577H	PARTICIPANT	\N	PRESENT	0
669727	667727	19681G	PARTICIPANT	\N	PRESENT	0
669728	667727	19369B	PARTICIPANT	\N	PRESENT	0
669729	667727	19533U	PARTICIPANT	\N	PRESENT	0
669730	667727	19599P	PARTICIPANT	\N	PRESENT	0
669734	667727	20118Y	PARTICIPANT	\N	PRESENT	0
669735	667727	14169X	PARTICIPANT	\N	PRESENT	0
669736	667727	19611R	PARTICIPANT	\N	PRESENT	0
669737	667727	20134Y	PARTICIPANT	\N	PRESENT	0
669738	667727	19715Y	PARTICIPANT	\N	PRESENT	0
669739	667727	20172F	PARTICIPANT	\N	PRESENT	0
669743	667727	05012A	PARTICIPANT	\N	PRESENT	0
669741	667727	19711U	PARTICIPANT	\N	PRESENT	0
669742	667727	19441R	PARTICIPANT	\N	PRESENT	0
669744	667727	14229S	PARTICIPANT	\N	PRESENT	0
669745	667727	14083S	PARTICIPANT	\N	PRESENT	0
669746	667727	19573D	PARTICIPANT	\N	PRESENT	0
669747	667727	19593H	PARTICIPANT	\N	PRESENT	0
669748	667727	14030Q	PARTICIPANT	\N	PRESENT	0
669749	667727	19347U	PARTICIPANT	\N	PRESENT	0
669750	667727	19667J	PARTICIPANT	\N	PRESENT	0
669751	667727	11085T	PARTICIPANT	\N	PRESENT	0
669752	667727	20070A	PARTICIPANT	\N	PRESENT	0
669753	667727	19820Y	PARTICIPANT	\N	PRESENT	0
669754	667727	14257W	PARTICIPANT	\N	PRESENT	0
669755	667727	04085P	PARTICIPANT	\N	PRESENT	0
669758	667727	20264J	PARTICIPANT	\N	PRESENT	0
669759	667727	17023S	PARTICIPANT	\N	PRESENT	0
669815	667728	14031R	PARTICIPANT	\N	PRESENT	0
669821	667728	20142Y	PARTICIPANT	\N	PRESENT	0
669823	667728	11090Q	PARTICIPANT	\N	PRESENT	0
669824	667728	20120S	PARTICIPANT	\N	PRESENT	0
669827	667728	20038A	PARTICIPANT	\N	PRESENT	0
669828	667728	20076G	PARTICIPANT	\N	PRESENT	0
669829	667728	20082E	PARTICIPANT	\N	PRESENT	0
669830	667728	14207L	PARTICIPANT	\N	PRESENT	0
669831	667728	20092G	PARTICIPANT	\N	PRESENT	0
669832	667728	20100N	PARTICIPANT	\N	PRESENT	0
669833	667728	19503N	PARTICIPANT	\N	PRESENT	0
669834	667728	20144B	PARTICIPANT	\N	PRESENT	0
669835	667728	19549D	PARTICIPANT	\N	PRESENT	0
669836	667728	14257W	PARTICIPANT	\N	PRESENT	0
669837	667728	19333N	PARTICIPANT	\N	PRESENT	0
669838	667728	19619A	PARTICIPANT	\N	PRESENT	0
669839	667728	19637C	PARTICIPANT	\N	PRESENT	0
669840	667728	19611R	PARTICIPANT	\N	PRESENT	0
669841	667728	19695N	PARTICIPANT	\N	PRESENT	0
669842	667728	20102Q	PARTICIPANT	\N	PRESENT	0
669843	667728	20106U	PARTICIPANT	\N	PRESENT	0
669844	667728	11065P	PARTICIPANT	\N	PRESENT	0
669845	667728	14033T	PARTICIPANT	\N	PRESENT	0
669846	667728	19820Y	PARTICIPANT	\N	PRESENT	0
669847	667728	20058E	PARTICIPANT	\N	PRESENT	0
669848	667728	08060W	PARTICIPANT	\N	PRESENT	0
669849	667728	18083K	PARTICIPANT	\N	PRESENT	0
669850	667728	20046A	PARTICIPANT	\N	PRESENT	0
669851	667728	20298U	PARTICIPANT	\N	PRESENT	0
669852	667728	19593H	PARTICIPANT	\N	PRESENT	0
669853	667728	14030Q	PARTICIPANT	\N	PRESENT	0
669854	667728	14215L	PARTICIPANT	\N	PRESENT	0
669855	667728	14219Q	PARTICIPANT	\N	PRESENT	0
669856	667728	99004R	PARTICIPANT	\N	PRESENT	0
669857	667728	19687N	PARTICIPANT	\N	PRESENT	0
669858	667728	20062A	PARTICIPANT	\N	PRESENT	0
669859	667728	14221J	PARTICIPANT	\N	PRESENT	0
669860	667728	20172F	PARTICIPANT	\N	PRESENT	0
669861	667728	19347U	PARTICIPANT	\N	PRESENT	0
669862	667728	14169X	PARTICIPANT	\N	PRESENT	0
669863	667728	19651A	PARTICIPANT	\N	PRESENT	0
669864	667728	19369B	PARTICIPANT	\N	PRESENT	0
669865	667728	19599P	PARTICIPANT	\N	PRESENT	0
669866	667728	19441R	PARTICIPANT	\N	PRESENT	0
669868	667728	19573D	PARTICIPANT	\N	PRESENT	0
669870	667728	14229S	PARTICIPANT	\N	PRESENT	0
669871	667728	11077T	PARTICIPANT	\N	PRESENT	0
669872	667728	04085P	PARTICIPANT	\N	PRESENT	0
669873	667728	19711U	PARTICIPANT	\N	PRESENT	0
669874	667728	20134Y	PARTICIPANT	\N	PRESENT	0
669876	667728	19657G	PARTICIPANT	\N	PRESENT	0
669877	667728	20068G	PARTICIPANT	\N	PRESENT	0
669813	667728	95063L	PARTICIPANT	\N	PRESENT	0
669814	667728	19681G	PARTICIPANT	\N	PRESENT	0
669878	667728	17023S	PARTICIPANT	\N	PRESENT	0
669879	667728	19715Y	PARTICIPANT	\N	PRESENT	0
669882	667728	20016T	PARTICIPANT	\N	PRESENT	0
669883	667728	20118Y	PARTICIPANT	\N	PRESENT	0
669890	667728	19577H	PARTICIPANT	\N	PRESENT	0
669903	667728	20060X	PARTICIPANT	\N	PRESENT	0
669946	667729	14026U	PARTICIPANT	\N	PRESENT	0
669947	667729	20092G	PARTICIPANT	\N	PRESENT	0
669948	667729	19599P	PARTICIPANT	\N	PRESENT	0
669949	667729	19820Y	PARTICIPANT	\N	PRESENT	0
669950	667729	19333N	PARTICIPANT	\N	PRESENT	0
669951	667729	19503N	PARTICIPANT	\N	PRESENT	0
669952	667729	20046A	PARTICIPANT	\N	PRESENT	0
669953	667729	20102Q	PARTICIPANT	\N	PRESENT	0
669954	667729	14221J	PARTICIPANT	\N	PRESENT	0
669955	667729	20298U	PARTICIPANT	\N	PRESENT	0
669956	667729	19619A	PARTICIPANT	\N	PRESENT	0
669957	667729	19577H	PARTICIPANT	\N	PRESENT	0
669958	667729	14257W	PARTICIPANT	\N	PRESENT	0
669959	667729	11077T	PARTICIPANT	\N	PRESENT	0
669960	667729	20062A	PARTICIPANT	\N	PRESENT	0
669961	667729	19711U	PARTICIPANT	\N	PRESENT	0
669962	667729	14031R	PARTICIPANT	\N	PRESENT	0
669963	667729	20038A	PARTICIPANT	\N	PRESENT	0
669964	667729	19681G	PARTICIPANT	\N	PRESENT	0
669965	667729	20144B	PARTICIPANT	\N	PRESENT	0
669966	667729	11090Q	PARTICIPANT	\N	PRESENT	0
669967	667729	20106U	PARTICIPANT	\N	PRESENT	0
669968	667729	19637C	PARTICIPANT	\N	PRESENT	0
669969	667729	19687N	PARTICIPANT	\N	PRESENT	0
669970	667729	11065P	PARTICIPANT	\N	PRESENT	0
669971	667729	19347U	PARTICIPANT	\N	PRESENT	0
669972	667729	20082E	PARTICIPANT	\N	PRESENT	0
669973	667729	18083K	PARTICIPANT	\N	PRESENT	0
669974	667729	14033T	PARTICIPANT	\N	PRESENT	0
669975	667729	14219Q	PARTICIPANT	\N	PRESENT	0
669976	667729	20058E	PARTICIPANT	\N	PRESENT	0
669977	667729	19369B	PARTICIPANT	\N	PRESENT	0
669978	667729	19549D	PARTICIPANT	\N	PRESENT	0
669979	667729	20100N	PARTICIPANT	\N	PRESENT	0
669980	667729	20060X	PARTICIPANT	\N	PRESENT	0
669981	667729	20134Y	PARTICIPANT	\N	PRESENT	0
669982	667729	14169X	PARTICIPANT	\N	PRESENT	0
669983	667729	20120S	PARTICIPANT	\N	PRESENT	0
669984	667729	14215L	PARTICIPANT	\N	PRESENT	0
674243	671030	14215L	PARTICIPANT	\N	PRESENT	0
674244	671030	14151M	PARTICIPANT	\N	PRESENT	0
674245	671030	14021P	PARTICIPANT	\N	PRESENT	0
674246	671030	19565D	PARTICIPANT	\N	PRESENT	0
674247	671030	20030R	PARTICIPANT	\N	PRESENT	0
674248	671030	20100N	PARTICIPANT	\N	PRESENT	0
674249	671030	20092G	PARTICIPANT	\N	PRESENT	0
674250	671030	19782L	PARTICIPANT	\N	PRESENT	0
674251	671030	20150Y	PARTICIPANT	\N	PRESENT	0
674252	671030	19715Y	PARTICIPANT	\N	PRESENT	0
674253	671030	14223L	PARTICIPANT	\N	PRESENT	0
674254	671030	10015M	PARTICIPANT	\N	PRESENT	0
674255	671030	20032T	PARTICIPANT	\N	PRESENT	0
674256	671030	18083K	PARTICIPANT	\N	PRESENT	0
674257	671030	14033T	PARTICIPANT	\N	PRESENT	0
674258	671030	20120S	PARTICIPANT	\N	PRESENT	0
674259	671030	14147R	PARTICIPANT	\N	PRESENT	0
674260	671030	20062A	PARTICIPANT	\N	PRESENT	0
674261	671030	19762G	PARTICIPANT	\N	PRESENT	0
674262	671030	07029T	PARTICIPANT	\N	PRESENT	0
674263	671030	19399H	PARTICIPANT	\N	PRESENT	0
674264	671030	20086J	PARTICIPANT	\N	PRESENT	0
674265	671030	19747H	PARTICIPANT	\N	PRESENT	0
674266	671030	05008E	PARTICIPANT	\N	PRESENT	0
674267	671030	20028X	PARTICIPANT	\N	PRESENT	0
674268	671030	19758L	PARTICIPANT	\N	PRESENT	0
674269	671030	11056N	PARTICIPANT	\N	PRESENT	0
674270	671030	07004J	PARTICIPANT	\N	PRESENT	0
674271	671030	20110Q	PARTICIPANT	\N	PRESENT	0
674272	671030	11064N	PARTICIPANT	\N	PRESENT	0
674273	671030	11012A	PARTICIPANT	\N	PRESENT	0
674274	671030	19866P	PARTICIPANT	\N	PRESENT	0
674275	671030	19629C	PARTICIPANT	\N	PRESENT	0
674276	671030	20116W	PARTICIPANT	\N	PRESENT	0
674277	671030	19387D	PARTICIPANT	\N	PRESENT	0
674278	671030	04045F	PARTICIPANT	\N	PRESENT	0
674279	671030	11072N	PARTICIPANT	\N	PRESENT	0
674280	671030	19725B	PARTICIPANT	\N	PRESENT	0
674281	671030	20138D	PARTICIPANT	\N	PRESENT	0
674282	671030	20140W	PARTICIPANT	\N	PRESENT	0
674283	671030	20072C	PARTICIPANT	\N	PRESENT	0
674284	671030	20124W	PARTICIPANT	\N	PRESENT	0
674285	671030	20056C	PARTICIPANT	\N	PRESENT	0
674286	671030	14107H	PARTICIPANT	\N	PRESENT	0
674241	671030	95063L	PARTICIPANT	\N	PRESENT	0
674242	671030	04047H	PARTICIPANT	\N	PRESENT	0
674287	671030	19760E	PARTICIPANT	\N	PRESENT	0
674288	671030	20106U	PARTICIPANT	\N	PRESENT	0
674289	671030	20024T	PARTICIPANT	\N	PRESENT	0
674290	671030	19447X	PARTICIPANT	\N	PRESENT	0
674291	671030	19369B	PARTICIPANT	\N	PRESENT	0
674292	671030	20172F	PARTICIPANT	\N	PRESENT	0
674343	674340	14215L	PARTICIPANT	\N	PRESENT	0
674344	674340	11072N	PARTICIPANT	\N	PRESENT	0
674345	674340	14021P	PARTICIPANT	\N	PRESENT	0
674346	674340	20022R	PARTICIPANT	\N	PRESENT	0
674347	674340	20092G	PARTICIPANT	\N	PRESENT	0
674348	674340	10015M	PARTICIPANT	\N	PRESENT	0
674349	674340	20110Q	PARTICIPANT	\N	PRESENT	0
674350	674340	20090E	PARTICIPANT	\N	PRESENT	0
674351	674340	11012A	PARTICIPANT	\N	PRESENT	0
674352	674340	20086J	PARTICIPANT	\N	PRESENT	0
674353	674340	11064N	PARTICIPANT	\N	PRESENT	0
674354	674340	19585H	PARTICIPANT	\N	PRESENT	0
674355	674340	14231L	PARTICIPANT	\N	PRESENT	0
674356	674340	14327T	PARTICIPANT	\N	PRESENT	0
674357	674340	20100N	PARTICIPANT	\N	PRESENT	0
674358	674340	19503N	PARTICIPANT	\N	PRESENT	0
674359	674340	20028X	PARTICIPANT	\N	PRESENT	0
674360	674340	19565D	PARTICIPANT	\N	PRESENT	0
674372	674340	07004J	PARTICIPANT	\N	PRESENT	0
674362	674340	19335Q	PARTICIPANT	\N	PRESENT	0
674363	674340	19387D	PARTICIPANT	\N	PRESENT	0
674364	674340	20072C	PARTICIPANT	\N	PRESENT	0
674365	674340	20116W	PARTICIPANT	\N	PRESENT	0
674366	674340	19629C	PARTICIPANT	\N	PRESENT	0
674367	674340	19866P	PARTICIPANT	\N	PRESENT	0
674368	674340	20132W	PARTICIPANT	\N	PRESENT	0
674369	674340	19719D	PARTICIPANT	\N	PRESENT	0
674370	674340	14275Y	PARTICIPANT	\N	PRESENT	0
674371	674340	14053L	PARTICIPANT	\N	PRESENT	0
674373	674340	20172F	PARTICIPANT	\N	PRESENT	0
674374	674340	11056N	PARTICIPANT	\N	PRESENT	0
674375	674340	19447X	PARTICIPANT	\N	PRESENT	0
674376	674340	20138D	PARTICIPANT	\N	PRESENT	0
674377	674340	19747H	PARTICIPANT	\N	PRESENT	0
674378	674340	20070A	PARTICIPANT	\N	PRESENT	0
674379	674340	14107H	PARTICIPANT	\N	PRESENT	0
674380	674340	14207L	PARTICIPANT	\N	PRESENT	0
674381	674340	19549D	PARTICIPANT	\N	PRESENT	0
674382	674340	20118Y	PARTICIPANT	\N	PRESENT	0
674383	674340	05008E	PARTICIPANT	\N	PRESENT	0
674384	674340	20106U	PARTICIPANT	\N	PRESENT	0
674385	674340	20032T	PARTICIPANT	\N	PRESENT	0
674386	674340	14151M	PARTICIPANT	\N	PRESENT	0
674387	674340	07029T	PARTICIPANT	\N	PRESENT	0
674388	674340	19954N	PARTICIPANT	\N	PRESENT	0
674389	674340	20180F	PARTICIPANT	\N	PRESENT	0
674390	674340	14147R	PARTICIPANT	\N	PRESENT	0
674341	674340	01043Q	PARTICIPANT	\N	PRESENT	0
674342	674340	04047H	PARTICIPANT	\N	PRESENT	0
674391	674340	20082E	PARTICIPANT	\N	PRESENT	0
674392	674340	19782L	PARTICIPANT	\N	PRESENT	0
674393	674340	20052X	PARTICIPANT	\N	PRESENT	0
674394	674340	19798U	PARTICIPANT	\N	PRESENT	0
674395	674340	19703U	PARTICIPANT	\N	PRESENT	0
674396	674340	14033T	PARTICIPANT	\N	PRESENT	0
674397	674340	19383Y	PARTICIPANT	\N	PRESENT	0
674398	674340	18083K	PARTICIPANT	\N	PRESENT	0
674399	674340	14083S	PARTICIPANT	\N	PRESENT	0
674400	674340	20266L	PARTICIPANT	\N	PRESENT	0
674401	674340	20122U	PARTICIPANT	\N	PRESENT	0
674402	674340	19507S	PARTICIPANT	\N	PRESENT	0
674457	671031	01043Q	PARTICIPANT	\N	PRESENT	0
674458	671031	04047H	PARTICIPANT	\N	PRESENT	0
674459	671031	19629C	PARTICIPANT	\N	PRESENT	0
674460	671031	19447X	PARTICIPANT	\N	PRESENT	0
674461	671031	11012A	PARTICIPANT	\N	PRESENT	0
674462	671031	14215L	PARTICIPANT	\N	PRESENT	0
674463	671031	20070A	PARTICIPANT	\N	PRESENT	0
674464	671031	14053L	PARTICIPANT	\N	PRESENT	0
674465	671031	14151M	PARTICIPANT	\N	PRESENT	0
674466	671031	14021P	PARTICIPANT	\N	PRESENT	0
674467	671031	20116W	PARTICIPANT	\N	PRESENT	0
674468	671031	07029T	PARTICIPANT	\N	PRESENT	0
674469	671031	14147R	PARTICIPANT	\N	PRESENT	0
674470	671031	19782L	PARTICIPANT	\N	PRESENT	0
674471	671031	19866P	PARTICIPANT	\N	PRESENT	0
674472	671031	19387D	PARTICIPANT	\N	PRESENT	0
674473	671031	14107H	PARTICIPANT	\N	PRESENT	0
674474	671031	20072C	PARTICIPANT	\N	PRESENT	0
674475	671031	20132W	PARTICIPANT	\N	PRESENT	0
674476	671031	20122U	PARTICIPANT	\N	PRESENT	0
674477	671031	20110Q	PARTICIPANT	\N	PRESENT	0
674478	671031	11056N	PARTICIPANT	\N	PRESENT	0
674479	671031	19565D	PARTICIPANT	\N	PRESENT	0
674480	671031	14207L	PARTICIPANT	\N	PRESENT	0
674481	671031	05008E	PARTICIPANT	\N	PRESENT	0
674482	671031	11072N	PARTICIPANT	\N	PRESENT	0
674483	671031	14231L	PARTICIPANT	\N	PRESENT	0
674484	671031	14275Y	PARTICIPANT	\N	PRESENT	0
674486	674485	19709B	PARTICIPANT	\N	PRESENT	0
674487	674485	14255U	PARTICIPANT	\N	PRESENT	0
674488	674485	14147R	PARTICIPANT	\N	PRESENT	0
674489	674485	14211G	PARTICIPANT	\N	PRESENT	0
674490	674485	20264J	PARTICIPANT	\N	PRESENT	0
674491	674485	20266L	PARTICIPANT	\N	PRESENT	0
674492	674485	11026G	PARTICIPANT	\N	PRESENT	0
674493	674485	08018U	PARTICIPANT	\N	PRESENT	0
674582	672498	10006L	PRESIDENT	0	PRESENT	0
674583	672498	18193Q	PARTICIPANT	\N	PRESENT	0
674585	672498	20130U	PARTICIPANT	\N	PRESENT	0
674586	672498	19683J	PARTICIPANT	\N	PRESENT	0
674587	672498	14281W	PARTICIPANT	\N	PRESENT	0
674588	672498	11067R	PARTICIPANT	\N	PRESENT	0
674589	672498	14195A	PARTICIPANT	\N	PRESENT	0
674590	672498	19511N	PARTICIPANT	\N	PRESENT	0
674591	672498	14217N	PARTICIPANT	\N	PRESENT	0
674592	672498	14042U	PARTICIPANT	\N	PRESENT	0
674593	672498	14213J	PARTICIPANT	\N	PRESENT	0
674594	672498	19569H	PARTICIPANT	\N	PRESENT	0
660156	659084	14327T	PARTICIPANT	\N	PRESENT	0
660157	659084	14331P	PARTICIPANT	\N	PRESENT	0
660158	659084	11048N	PARTICIPANT	\N	PRESENT	0
660159	659084	11012A	PARTICIPANT	\N	PRESENT	0
660160	659084	20036X	PARTICIPANT	\N	PRESENT	0
660161	659084	12016W	PARTICIPANT	\N	PRESENT	0
660162	659084	99004R	PARTICIPANT	\N	PRESENT	0
660163	659084	14225N	PRESIDENT	0	PRESENT	0
660164	659084	11074Q	PARTICIPANT	\N	PRESENT	0
660165	659084	20116W	PARTICIPANT	\N	PRESENT	0
660166	659084	19762G	PARTICIPANT	\N	PRESENT	0
660167	659084	01048V	PARTICIPANT	\N	PRESENT	0
660168	659084	01057W	PARTICIPANT	\N	PRESENT	0
660169	659084	20050V	PARTICIPANT	\N	PRESENT	0
660170	659084	19667J	PARTICIPANT	\N	PRESENT	0
660171	659084	20044X	PARTICIPANT	\N	PRESENT	0
660172	659084	19671E	PARTICIPANT	\N	PRESENT	0
660173	659084	11070L	PARTICIPANT	\N	PRESENT	0
660174	659084	07029T	PARTICIPANT	\N	PRESENT	0
660175	659084	08009T	PARTICIPANT	\N	PRESENT	0
660176	659084	20070A	PARTICIPANT	\N	PRESENT	0
660177	659084	19349W	PARTICIPANT	\N	PRESENT	0
660178	659084	14253S	PARTICIPANT	\N	PRESENT	0
660179	659084	20126Y	PARTICIPANT	\N	PRESENT	0
660180	659084	19711U	PARTICIPANT	\N	PRESENT	0
660181	659084	14189C	PARTICIPANT	\N	PRESENT	0
660182	659084	19687N	PARTICIPANT	\N	PRESENT	0
660183	659084	11053K	PARTICIPANT	\N	PRESENT	0
660184	659084	19531S	PARTICIPANT	\N	PRESENT	0
660185	659084	08011M	PARTICIPANT	\N	PRESENT	0
660186	659084	19741B	PARTICIPANT	\N	PRESENT	0
660187	659084	04071H	PARTICIPANT	\N	PRESENT	0
660188	659084	19545Y	PARTICIPANT	\N	PRESENT	0
660189	659084	08073C	PARTICIPANT	\N	PRESENT	0
660190	659084	20086J	PARTICIPANT	\N	PRESENT	0
660191	659084	20080C	PARTICIPANT	\N	PRESENT	0
660192	659084	19335Q	PARTICIPANT	\N	PRESENT	0
660193	659084	14121F	PARTICIPANT	\N	PRESENT	0
660194	659084	19479G	PARTICIPANT	\N	PRESENT	0
660195	659365	14053L	PARTICIPANT	\N	PRESENT	0
660196	659365	11056N	PARTICIPANT	\N	PRESENT	0
660197	659365	14275Y	PARTICIPANT	\N	PRESENT	0
660198	659365	14215L	PARTICIPANT	\N	PRESENT	0
660199	659365	08018U	PARTICIPANT	\N	PRESENT	0
660200	659365	19675J	PARTICIPANT	\N	PRESENT	0
660201	659365	19447X	PARTICIPANT	\N	PRESENT	0
660202	659365	14089Y	PARTICIPANT	\N	EXCUSE	0
660203	659365	14001X	PARTICIPANT	\N	EXCUSE	0
660204	659084	11110B	PARTICIPANT	\N	PRESENT	0
660205	659084	08010L	PARTICIPANT	\N	PRESENT	0
660206	656930	19333N	PARTICIPANT	\N	PRESENT	0
660207	656930	14031R	PARTICIPANT	\N	PRESENT	0
660208	656930	20076G	PARTICIPANT	\N	PRESENT	0
660209	656930	19387D	PARTICIPANT	\N	PRESENT	0
660210	656930	14219Q	PRESIDENT	0	PRESENT	0
660211	656930	19820Y	PARTICIPANT	\N	PRESENT	0
660212	656930	19826F	PARTICIPANT	\N	PRESENT	0
660213	656930	20046A	PARTICIPANT	\N	PRESENT	0
660214	656930	20102Q	PARTICIPANT	\N	PRESENT	0
660215	656930	17229F	PARTICIPANT	\N	PRESENT	0
660216	656930	18083K	PARTICIPANT	\N	PRESENT	0
660217	656930	20068G	PARTICIPANT	\N	PRESENT	0
660218	656930	19503N	PARTICIPANT	\N	PRESENT	0
660219	656930	20020P	PARTICIPANT	\N	PRESENT	0
660220	656930	19745F	PARTICIPANT	\N	PRESENT	0
660221	656930	20024T	PARTICIPANT	\N	PRESENT	0
660222	656930	19251M	PARTICIPANT	\N	PRESENT	0
660223	656930	14221J	PARTICIPANT	\N	PRESENT	0
660224	656930	19599P	PARTICIPANT	\N	PRESENT	0
660225	656930	14169X	PARTICIPANT	\N	PRESENT	0
660226	656930	20100N	PARTICIPANT	\N	PRESENT	0
660227	656930	19619A	PARTICIPANT	\N	PRESENT	0
660228	656930	20038A	PARTICIPANT	\N	PRESENT	0
660229	659365	20074E	PARTICIPANT	\N	PRESENT	0
660230	659365	10015M	PARTICIPANT	\N	PRESENT	0
660231	659365	19301E	PARTICIPANT	\N	PRESENT	0
660232	659365	04047H	PRESIDENT	0	PRESENT	0
660233	659365	01028R	PARTICIPANT	\N	PRESENT	0
660234	659365	11033F	PARTICIPANT	\N	PRESENT	0
660235	659365	04085P	PARTICIPANT	\N	PRESENT	0
660236	659365	19954N	PARTICIPANT	\N	PRESENT	0
660237	659365	95063L	PARTICIPANT	\N	PRESENT	0
660238	659365	19629C	PARTICIPANT	\N	PRESENT	0
660239	659365	07004J	PARTICIPANT	\N	PRESENT	0
660240	659365	14179A	PARTICIPANT	\N	PRESENT	0
660241	659365	14069U	PARTICIPANT	\N	PRESENT	0
660242	659365	04008A	PARTICIPANT	\N	PRESENT	0
660243	656930	17367Q	PARTICIPANT	\N	EXCUSE	0
660244	656930	19637C	PARTICIPANT	\N	EXCUSE	0
660245	659365	19585H	PARTICIPANT	\N	PRESENT	0
660246	659365	20108W	PARTICIPANT	\N	PRESENT	0
660247	659365	14107H	PARTICIPANT	\N	PRESENT	0
660248	659084	14083S	PARTICIPANT	\N	PRESENT	0
660249	659365	14151M	PARTICIPANT	\N	PRESENT	0
660250	659365	19725B	PARTICIPANT	\N	PRESENT	0
660251	657977	19593H	PARTICIPANT	\N	PRESENT	0
660252	657977	19527W	PARTICIPANT	\N	PRESENT	0
660253	657977	19643A	PARTICIPANT	\N	PRESENT	0
660254	657977	20132W	PARTICIPANT	\N	PRESENT	0
660255	657977	19651A	PARTICIPANT	\N	PRESENT	0
660256	657977	20138D	PARTICIPANT	\N	PRESENT	0
660257	657977	19611R	PRESIDENT	0	PRESENT	0
660258	657977	20142Y	PARTICIPANT	\N	PRESENT	0
660259	657977	20048C	PARTICIPANT	\N	PRESENT	0
660260	657977	20052X	PARTICIPANT	\N	PRESENT	0
660261	657977	20172F	PARTICIPANT	\N	PRESENT	0
660262	657977	14030Q	PARTICIPANT	\N	PRESENT	0
660263	657977	20098N	PARTICIPANT	\N	PRESENT	0
660264	657977	20056C	PARTICIPANT	\N	PRESENT	0
660265	657977	19573D	PARTICIPANT	\N	PRESENT	0
660266	657977	04059M	PARTICIPANT	\N	PRESENT	0
660267	657977	14109K	PARTICIPANT	\N	PRESENT	0
660268	657977	08012N	PARTICIPANT	\N	PRESENT	0
660269	657977	11043H	PARTICIPANT	\N	PRESENT	0
660270	657977	11104D	PARTICIPANT	\N	PRESENT	0
660271	657977	20124W	PARTICIPANT	\N	PRESENT	0
660272	657977	19758L	PARTICIPANT	\N	PRESENT	0
660273	657977	20026V	PARTICIPANT	\N	PRESENT	0
660274	657977	20084G	PARTICIPANT	\N	PRESENT	0
660275	659365	19543W	PARTICIPANT	\N	PRESENT	0
660276	659365	19489J	PARTICIPANT	\N	PRESENT	0
660277	659365	20110Q	PARTICIPANT	\N	PRESENT	0
660278	659365	14147R	PARTICIPANT	\N	PRESENT	0
660279	659365	14231L	PARTICIPANT	\N	PRESENT	0
660280	659365	14259Y	PARTICIPANT	\N	PRESENT	0
660281	659365	11085T	PARTICIPANT	\N	PRESENT	0
660282	659365	14021P	PARTICIPANT	\N	PRESENT	0
660314	659193	20248J	PARTICIPANT	\N	EXCUSE	0
660315	656930	11065P	PARTICIPANT	\N	PRESENT	0
660316	656930	11101A	PARTICIPANT	\N	PRESENT	0
660317	659365	19581D	PARTICIPANT	\N	PRESENT	0
660318	659365	11072N	PARTICIPANT	\N	PRESENT	0
660319	659193	20066E	PARTICIPANT	\N	PRESENT	0
660320	659193	19697Q	PARTICIPANT	\N	PRESENT	0
660321	659193	19679N	PARTICIPANT	\N	PRESENT	0
660322	659193	19663E	PARTICIPANT	\N	PRESENT	0
660323	656930	20118Y	PARTICIPANT	\N	PRESENT	0
660324	656930	20140W	PARTICIPANT	\N	PRESENT	0
660325	656930	19577H	PARTICIPANT	\N	PRESENT	0
660326	659085	14327T	PARTICIPANT	\N	PRESENT	0
660327	659085	20086J	PARTICIPANT	\N	PRESENT	0
660328	659085	14331P	PARTICIPANT	\N	PRESENT	0
660329	659085	04071H	PARTICIPANT	\N	PRESENT	0
660330	659085	01048V	PARTICIPANT	\N	PRESENT	0
660331	659085	19545Y	PARTICIPANT	\N	PRESENT	0
660332	659085	01057W	PARTICIPANT	\N	PRESENT	0
660333	659085	19667J	PARTICIPANT	\N	PRESENT	0
660334	659085	11074Q	PARTICIPANT	\N	PRESENT	0
660335	659085	14225N	PRESIDENT	0	PRESENT	0
660336	659085	19671E	PARTICIPANT	\N	PRESENT	0
660337	659085	11070L	PARTICIPANT	\N	PRESENT	0
660338	659085	11110B	PARTICIPANT	\N	PRESENT	0
660339	659085	07029T	PARTICIPANT	\N	PRESENT	0
660340	659085	19349W	PARTICIPANT	\N	PRESENT	0
660341	659085	08010L	PARTICIPANT	\N	PRESENT	0
660342	659085	20116W	PARTICIPANT	\N	PRESENT	0
660343	659085	19335Q	PARTICIPANT	\N	PRESENT	0
660344	659085	11048N	PARTICIPANT	\N	PRESENT	0
660345	659085	19479G	PARTICIPANT	\N	PRESENT	0
660346	659085	19647E	PARTICIPANT	\N	PRESENT	0
660347	659085	19711U	PARTICIPANT	\N	PRESENT	0
671389	669895	19649G	PARTICIPANT	\N	PRESENT	0
671390	669895	19333N	PARTICIPANT	\N	PRESENT	0
671391	669895	20070A	PARTICIPANT	\N	PRESENT	0
671392	669895	10006L	PARTICIPANT	\N	PRESENT	0
671393	669895	20088L	PARTICIPANT	\N	PRESENT	0
671394	669895	18193Q	PARTICIPANT	\N	PRESENT	0
671395	669895	19549D	PARTICIPANT	\N	PRESENT	0
671396	669895	20264J	PARTICIPANT	\N	PRESENT	0
671397	669895	11074Q	PARTICIPANT	\N	PRESENT	0
671398	669895	95041E	PARTICIPANT	\N	PRESENT	0
671399	669895	19531S	PARTICIPANT	\N	PRESENT	0
671400	669895	19581D	PARTICIPANT	\N	PRESENT	0
671401	669895	19367Y	PARTICIPANT	\N	PRESENT	0
671402	669895	20114U	PARTICIPANT	\N	PRESENT	0
671403	669895	19671E	PARTICIPANT	\N	PRESENT	0
671404	669895	19820Y	PARTICIPANT	\N	PRESENT	0
671405	669895	20252E	PARTICIPANT	\N	PRESENT	0
671406	669895	11027H	PARTICIPANT	\N	PRESENT	0
671407	669895	14217N	PARTICIPANT	\N	PRESENT	0
671408	669895	07033P	PARTICIPANT	\N	PRESENT	0
671409	669895	11103C	PARTICIPANT	\N	PRESENT	0
671410	669895	20060X	PARTICIPANT	\N	PRESENT	0
671411	669895	14147R	PARTICIPANT	\N	PRESENT	0
671412	669895	20172F	PARTICIPANT	\N	PRESENT	0
671413	669895	20080C	PARTICIPANT	\N	PRESENT	0
671414	669895	14213J	PARTICIPANT	\N	PRESENT	0
671415	669895	19251M	PARTICIPANT	\N	PRESENT	0
671416	669895	08069G	PARTICIPANT	\N	PRESENT	0
671417	669895	14229S	PARTICIPANT	\N	PRESENT	0
671418	669895	01028R	PARTICIPANT	\N	PRESENT	0
671419	669895	11066Q	PARTICIPANT	\N	PRESENT	0
671420	669895	20148F	PARTICIPANT	\N	PRESENT	0
671421	669895	20152B	PARTICIPANT	\N	PRESENT	0
671422	669895	20030R	PARTICIPANT	\N	PRESENT	0
671423	669895	19669L	PARTICIPANT	\N	PRESENT	0
671424	669895	01062T	PARTICIPANT	\N	PRESENT	0
671425	669895	14281W	PARTICIPANT	\N	PRESENT	0
671426	669895	19954N	PARTICIPANT	\N	PRESENT	0
671427	669895	20084G	PARTICIPANT	\N	PRESENT	0
671428	669895	19705W	PARTICIPANT	\N	PRESENT	0
671429	669895	19707Y	PARTICIPANT	\N	PRESENT	0
671430	669895	20054A	PARTICIPANT	\N	PRESENT	0
671431	669895	20124W	PARTICIPANT	\N	PRESENT	0
671432	669895	14189C	PARTICIPANT	\N	PRESENT	0
671433	669895	19543W	PARTICIPANT	\N	PRESENT	0
671442	669895	19577H	PARTICIPANT	\N	PRESENT	0
671435	669895	20042V	PARTICIPANT	\N	PRESENT	0
671436	669895	14030Q	PARTICIPANT	\N	PRESENT	0
671437	669895	11053K	PARTICIPANT	\N	PRESENT	0
671438	669895	20144B	PARTICIPANT	\N	PRESENT	0
671439	669895	19527W	PARTICIPANT	\N	PRESENT	0
671440	669895	14327T	PARTICIPANT	\N	PRESENT	0
671441	669895	08056B	PARTICIPANT	\N	PRESENT	0
671443	669895	01024M	PARTICIPANT	\N	PRESENT	0
671444	669895	14042U	PARTICIPANT	\N	PRESENT	0
671445	669895	14357A	PARTICIPANT	\N	PRESENT	0
671446	669895	05008E	PARTICIPANT	\N	PRESENT	0
671447	669895	01025N	PARTICIPANT	\N	PRESENT	0
671448	669895	17023S	PARTICIPANT	\N	PRESENT	0
671449	669895	14231L	PARTICIPANT	\N	PRESENT	0
671450	669895	19691J	PARTICIPANT	\N	PRESENT	0
671451	669895	97011G	PARTICIPANT	\N	PRESENT	0
671452	669895	19569H	PARTICIPANT	\N	PRESENT	0
671453	669895	14179A	PARTICIPANT	\N	PRESENT	0
671454	669895	19685L	PARTICIPANT	\N	PRESENT	0
671455	669895	20048C	PARTICIPANT	\N	PRESENT	0
671456	669895	20066E	PARTICIPANT	\N	PRESENT	0
671457	669895	14073Q	PARTICIPANT	\N	PRESENT	0
671458	669895	19768N	PARTICIPANT	\N	PRESENT	0
671459	669895	19699S	PARTICIPANT	\N	PRESENT	0
671460	669895	19399H	PARTICIPANT	\N	PRESENT	0
671461	669895	20104S	PARTICIPANT	\N	PRESENT	0
671462	669895	19735D	PARTICIPANT	\N	PRESENT	0
671463	669895	19611R	PARTICIPANT	\N	PRESENT	0
671464	669895	14237S	PARTICIPANT	\N	PRESENT	0
671465	669895	20286Q	PARTICIPANT	\N	PRESENT	0
671466	669895	20058E	PARTICIPANT	\N	PRESENT	0
671467	669895	20052X	PARTICIPANT	\N	PRESENT	0
671468	669895	20044X	PARTICIPANT	\N	PRESENT	0
671469	669895	16685X	PARTICIPANT	\N	PRESENT	0
671470	669895	14205J	PARTICIPANT	\N	PRESENT	0
671471	669895	14355X	PARTICIPANT	\N	PRESENT	0
671472	669895	19441R	PARTICIPANT	\N	PRESENT	0
671473	669895	11085T	PARTICIPANT	\N	PRESENT	0
671474	669895	19826F	PARTICIPANT	\N	PRESENT	0
671475	669895	08009T	PARTICIPANT	\N	PRESENT	0
671476	669895	19467C	PARTICIPANT	\N	PRESENT	0
671477	669895	19369B	PARTICIPANT	\N	PRESENT	0
671478	669895	20034V	PARTICIPANT	\N	PRESENT	0
671479	669895	04070G	PARTICIPANT	\N	PRESENT	0
671480	669895	19745F	PARTICIPANT	\N	PRESENT	0
671481	669895	14038Y	PARTICIPANT	\N	PRESENT	0
671482	669895	14173T	PARTICIPANT	\N	PRESENT	0
671483	669895	20298U	PARTICIPANT	\N	PRESENT	0
671484	669895	19619A	PARTICIPANT	\N	PRESENT	0
671485	669895	01034P	PARTICIPANT	\N	PRESENT	0
671486	669895	19447X	PARTICIPANT	\N	PRESENT	0
671487	669895	19383Y	PARTICIPANT	\N	PRESENT	0
671488	669895	19758L	PARTICIPANT	\N	PRESENT	0
671489	669895	11031D	PARTICIPANT	\N	PRESENT	0
671490	669895	20110Q	PARTICIPANT	\N	PRESENT	0
671491	669895	20266L	PARTICIPANT	\N	PRESENT	0
671492	669895	20108W	PARTICIPANT	\N	PRESENT	0
671493	669895	14151M	PARTICIPANT	\N	PRESENT	0
671494	669895	20132W	PARTICIPANT	\N	PRESENT	0
671495	669895	19553Y	PARTICIPANT	\N	PRESENT	0
671531	669895	01048V	PARTICIPANT	\N	PRESENT	0
671497	669895	19503N	PARTICIPANT	\N	PRESENT	0
671498	669895	11110B	PARTICIPANT	\N	PRESENT	0
671499	669895	19725B	PARTICIPANT	\N	PRESENT	0
671500	669895	19489J	PARTICIPANT	\N	PRESENT	0
671501	669895	08012N	PARTICIPANT	\N	PRESENT	0
671529	669895	19723Y	PARTICIPANT	\N	PRESENT	0
671528	669895	07029T	PARTICIPANT	\N	PRESENT	0
671526	669895	20086J	PARTICIPANT	\N	PRESENT	0
671505	669895	11041F	PARTICIPANT	\N	PRESENT	0
671506	669895	14257W	PARTICIPANT	\N	PRESENT	0
671507	669895	20018V	PARTICIPANT	\N	PRESENT	0
671530	669895	08015R	PARTICIPANT	\N	PRESENT	0
671509	669895	14109K	PARTICIPANT	\N	PRESENT	0
671527	669895	20126Y	PARTICIPANT	\N	PRESENT	0
671511	669895	19651A	PARTICIPANT	\N	PRESENT	0
671532	669895	19657G	PARTICIPANT	\N	PRESENT	0
671534	669895	14111D	PARTICIPANT	\N	PRESENT	0
671514	669895	20082E	PARTICIPANT	\N	PRESENT	0
671515	669895	19766L	PARTICIPANT	\N	PRESENT	0
671516	669895	19762G	PARTICIPANT	\N	PRESENT	0
671517	669895	20180F	PARTICIPANT	\N	PRESENT	0
671518	669895	14001X	PARTICIPANT	\N	PRESENT	0
671519	669895	08045X	PARTICIPANT	\N	PRESENT	0
671520	669895	19681G	PARTICIPANT	\N	PRESENT	0
671521	669895	11065P	PARTICIPANT	\N	PRESENT	0
671522	669895	19585H	PARTICIPANT	\N	PRESENT	0
671523	669895	14329V	PARTICIPANT	\N	PRESENT	0
671524	669895	19057M	PARTICIPANT	\N	PRESENT	0
671525	669895	19663E	PARTICIPANT	\N	PRESENT	0
671533	669895	11070L	PARTICIPANT	\N	PRESENT	0
671535	669895	20094J	PARTICIPANT	\N	PRESENT	0
671536	669895	19507S	PARTICIPANT	\N	PRESENT	0
671537	669895	14225N	PARTICIPANT	\N	PRESENT	0
656604	656596	19725B	PARTICIPANT	\N	PRESENT	0
656605	656596	12041X	PARTICIPANT	\N	PRESENT	0
656606	656596	11083R	PARTICIPANT	\N	PRESENT	0
656607	656596	14073Q	PARTICIPANT	\N	PRESENT	0
656608	656596	14331P	PARTICIPANT	\N	PRESENT	0
656892	656891	86034E	PARTICIPANT	\N	PRESENT	0
656893	656891	04047H	PARTICIPANT	\N	PRESENT	0
656894	656891	04042C	PARTICIPANT	\N	PRESENT	0
656895	656891	19719D	PARTICIPANT	\N	PRESENT	0
656896	656891	14217N	PARTICIPANT	\N	PRESENT	0
656898	656891	19347U	PARTICIPANT	\N	PRESENT	0
656899	656891	14026U	PARTICIPANT	\N	PRESENT	0
656900	656891	99004R	PARTICIPANT	\N	PRESENT	0
656901	656891	19611R	PARTICIPANT	\N	PRESENT	0
656902	656891	12041X	PARTICIPANT	\N	PRESENT	0
656903	656891	19711U	PARTICIPANT	\N	PRESENT	0
656904	656891	01043Q	PARTICIPANT	\N	PRESENT	0
656905	656891	14219Q	PARTICIPANT	\N	PRESENT	0
656906	656891	14251Q	PARTICIPANT	\N	PRESENT	0
656907	656891	11085T	PARTICIPANT	\N	PRESENT	0
656908	656891	01060R	PARTICIPANT	\N	PRESENT	0
656909	656891	08061X	PARTICIPANT	\N	PRESENT	0
656910	656891	11090Q	PARTICIPANT	\N	PRESENT	0
656911	656891	14331P	PARTICIPANT	\N	PRESENT	0
656912	656891	04033B	PARTICIPANT	\N	PRESENT	0
656913	656891	95063L	PARTICIPANT	\N	PRESENT	0
656914	656891	14229S	PARTICIPANT	\N	PRESENT	0
656915	656891	11045K	PARTICIPANT	\N	PRESENT	0
656916	656891	01028R	PARTICIPANT	\N	PRESENT	0
658106	658093	14053L	PARTICIPANT	\N	PRESENT	0
658680	656809	19585H	PARTICIPANT	\N	PRESENT	0
658681	656809	19649G	PARTICIPANT	\N	PRESENT	0
658683	656809	14215L	PARTICIPANT	\N	PRESENT	0
658684	656809	19954N	PARTICIPANT	\N	PRESENT	0
658685	656809	14089Y	PARTICIPANT	\N	PRESENT	0
658686	656809	19629C	PARTICIPANT	\N	PRESENT	0
658687	656809	20108W	PARTICIPANT	\N	PRESENT	0
658688	656809	19673G	PARTICIPANT	\N	PRESENT	0
658689	656809	14147R	PARTICIPANT	\N	PRESENT	0
658708	656809	04047H	PRESIDENT	0	PRESENT	0
658709	656809	17737W	PARTICIPANT	\N	PRESENT	0
658710	656809	19447X	PARTICIPANT	\N	PRESENT	0
658714	656809	19543W	PARTICIPANT	\N	PRESENT	0
658715	656809	14053L	PARTICIPANT	\N	PRESENT	0
658720	656809	10015M	PARTICIPANT	\N	PRESENT	0
658724	656809	11072N	PARTICIPANT	\N	PRESENT	0
658742	656809	08018U	PARTICIPANT	\N	PRESENT	0
658743	656809	14107H	PARTICIPANT	\N	PRESENT	0
658745	656809	20022R	PARTICIPANT	\N	PRESENT	0
658766	656809	14231L	PARTICIPANT	\N	EXCUSE	0
658769	656809	19581D	PARTICIPANT	\N	PRESENT	0
658770	656809	14111D	PARTICIPANT	\N	PRESENT	0
658772	656809	14179A	PARTICIPANT	\N	PRESENT	0
658782	656809	01028R	PARTICIPANT	\N	PRESENT	0
658787	656809	05008E	PARTICIPANT	\N	PRESENT	0
658788	656809	20114U	PARTICIPANT	\N	PRESENT	0
658789	656809	14001X	PARTICIPANT	\N	PRESENT	0
658809	656809	11056N	PARTICIPANT	\N	PRESENT	0
661613	661557	19673G	PARTICIPANT	\N	EXCUSE	0
661614	661557	11010L	PARTICIPANT	\N	EXCUSE	0
661615	661557	19691J	PARTICIPANT	\N	EXCUSE	0
661616	661557	19329S	PARTICIPANT	\N	EXCUSE	0
661620	661619	20092G	PARTICIPANT	\N	PRESENT	0
661621	661619	20144B	PARTICIPANT	\N	PRESENT	0
661623	661622	20144B	PARTICIPANT	\N	PRESENT	0
661671	661670	20144B	PARTICIPANT	\N	PRESENT	0
661672	661670	14033T	PARTICIPANT	\N	PRESENT	0
661674	661673	20144B	PARTICIPANT	\N	PRESENT	0
661675	661673	14033T	PARTICIPANT	\N	PRESENT	0
661676	661673	14207L	PARTICIPANT	\N	PRESENT	0
661678	661677	20144B	PARTICIPANT	\N	PRESENT	0
661679	661677	14033T	PARTICIPANT	\N	PRESENT	0
664885	664751	19695N	PARTICIPANT	\N	PRESENT	0
664886	664751	19747H	PARTICIPANT	\N	PRESENT	0
664888	664751	14257W	PARTICIPANT	\N	PRESENT	0
664936	661842	20082E	PARTICIPANT	\N	PRESENT	0
664937	661842	18193Q	PARTICIPANT	\N	PRESENT	0
664938	661842	14257W	PARTICIPANT	\N	PRESENT	0
664939	661842	19549D	PARTICIPANT	\N	PRESENT	0
664940	661842	19631V	PARTICIPANT	\N	PRESENT	0
664941	661842	20066E	PARTICIPANT	\N	PRESENT	0
664942	661842	04057K	PARTICIPANT	\N	PRESENT	0
664943	661842	14195A	PARTICIPANT	\N	PRESENT	0
664944	661842	20122U	PARTICIPANT	\N	PRESENT	0
664946	661842	14207L	PARTICIPANT	\N	PRESENT	0
664947	661842	14221J	PARTICIPANT	\N	PRESENT	0
664948	661842	04045F	PARTICIPANT	\N	PRESENT	0
664949	661842	19467C	PARTICIPANT	\N	PRESENT	0
664950	661842	19747H	PARTICIPANT	\N	PRESENT	0
664951	661842	19533U	PARTICIPANT	\N	PRESENT	0
664954	661842	19671E	PARTICIPANT	\N	PRESENT	0
664957	661842	19413M	PARTICIPANT	\N	PRESENT	0
664958	661842	19369B	PARTICIPANT	\N	PRESENT	0
664959	661842	20144B	PARTICIPANT	\N	PRESENT	0
664960	661842	01048V	PARTICIPANT	\N	PRESENT	0
664961	661842	19563B	PARTICIPANT	\N	PRESENT	0
664962	661842	11090Q	PARTICIPANT	\N	PRESENT	0
664963	661842	19593H	PARTICIPANT	\N	PRESENT	0
664964	661842	20050V	PARTICIPANT	\N	PRESENT	0
664965	661842	14219Q	PARTICIPANT	\N	PRESENT	0
664966	661842	19762G	PARTICIPANT	\N	PRESENT	0
664967	661842	14042U	PARTICIPANT	\N	PRESENT	0
664968	661842	19695N	PARTICIPANT	\N	PRESENT	0
664969	661842	19583F	PARTICIPANT	\N	PRESENT	0
664970	661842	07004J	PARTICIPANT	\N	PRESENT	0
664971	661842	20092G	PARTICIPANT	\N	PRESENT	0
664972	661842	20152B	PARTICIPANT	\N	PRESENT	0
664973	661842	19251M	PARTICIPANT	\N	PRESENT	0
664974	661842	20042V	PARTICIPANT	\N	PRESENT	0
664975	661842	04085P	PARTICIPANT	\N	PRESENT	0
664976	661842	19347U	PARTICIPANT	\N	PRESENT	0
664979	661842	11099A	PARTICIPANT	\N	PRESENT	0
664980	661842	20052X	PARTICIPANT	\N	PRESENT	0
664927	661842	11070L	PARTICIPANT	\N	PRESENT	0
664935	661842	17589D	PARTICIPANT	\N	PRESENT	0
664981	661842	18083K	PARTICIPANT	\N	PRESENT	0
664983	661842	14083S	PARTICIPANT	\N	PRESENT	0
664985	661842	14251Q	PARTICIPANT	\N	PRESENT	0
664986	661842	14069U	PARTICIPANT	\N	PRESENT	0
664989	661842	20914V	PARTICIPANT	\N	PRESENT	0
664995	661842	14205J	PARTICIPANT	\N	PRESENT	0
664996	661842	19687N	PARTICIPANT	\N	PRESENT	0
664997	661842	19619A	PARTICIPANT	\N	PRESENT	0
665001	661842	20070A	PARTICIPANT	\N	PRESENT	0
665002	661842	19503N	PARTICIPANT	\N	PRESENT	0
665004	661842	20126Y	PARTICIPANT	\N	PRESENT	0
665011	661842	14033T	PARTICIPANT	\N	PRESENT	0
665012	661842	20034V	PARTICIPANT	\N	PRESENT	0
665029	661842	20248J	PARTICIPANT	\N	PRESENT	0
665040	661842	07029T	PARTICIPANT	\N	PRESENT	0
665041	661842	01058X	PARTICIPANT	\N	PRESENT	0
665042	661842	20094J	PARTICIPANT	\N	PRESENT	0
665044	661842	19866P	PARTICIPANT	\N	PRESENT	0
674597	672498	19703U	PARTICIPANT	\N	PRESENT	0
674598	672498	11097X	PARTICIPANT	\N	PRESENT	0
674599	672498	19798U	PARTICIPANT	\N	PRESENT	0
674600	672498	19679N	PARTICIPANT	\N	PRESENT	0
674601	672498	20090E	PARTICIPANT	\N	PRESENT	0
674602	672498	20040T	PARTICIPANT	\N	PRESENT	0
674595	672498	19657G	PARTICIPANT	\N	PRESENT	0
674596	672498	19329S	PARTICIPANT	\N	PRESENT	0
674603	672498	19691J	PARTICIPANT	\N	PRESENT	0
674604	672498	20066E	PARTICIPANT	\N	PRESENT	0
674605	672498	04092N	PARTICIPANT	\N	PRESENT	0
674606	672498	19415P	PARTICIPANT	\N	PRESENT	0
674607	672498	11103C	PARTICIPANT	\N	PRESENT	0
674614	672498	19760E	PARTICIPANT	\N	PRESENT	0
674615	672498	14223L	PARTICIPANT	\N	PRESENT	0
674616	672498	20148F	PARTICIPANT	\N	PRESENT	0
674617	672498	14071N	PARTICIPANT	\N	PRESENT	0
674618	672498	19715Y	PARTICIPANT	\N	PRESENT	0
674620	672498	19713W	PARTICIPANT	\N	PRESENT	0
674621	672498	19553Y	PARTICIPANT	\N	PRESENT	0
674622	672498	19717B	PARTICIPANT	\N	PRESENT	0
674623	672498	11031D	PARTICIPANT	\N	PRESENT	0
674624	672498	11045K	PARTICIPANT	\N	PRESENT	0
674670	672498	20248J	PARTICIPANT	\N	PRESENT	0
674673	672498	08045X	PARTICIPANT	\N	PRESENT	0
674709	674703	19703U	PARTICIPANT	\N	PRESENT	0
674710	674703	18193Q	PARTICIPANT	\N	PRESENT	0
674711	674703	11067R	PARTICIPANT	\N	PRESENT	0
674712	674703	20130U	PARTICIPANT	\N	PRESENT	0
674713	674704	19703U	PARTICIPANT	\N	PRESENT	0
674714	674704	20130U	PARTICIPANT	\N	PRESENT	0
674727	670720	19663E	PARTICIPANT	\N	PRESENT	0
674728	670718	19663E	PARTICIPANT	\N	PRESENT	0
674791	673345	19768N	PARTICIPANT	\N	PRESENT	0
674792	673345	19515S	PARTICIPANT	\N	PRESENT	0
674793	673345	19782L	PARTICIPANT	\N	PRESENT	0
674794	673345	11077T	PARTICIPANT	\N	PRESENT	0
674795	673345	19441R	PARTICIPANT	\N	PRESENT	0
674796	673345	19866P	PARTICIPANT	\N	PRESENT	0
674797	673345	20028X	PARTICIPANT	\N	PRESENT	0
674798	673345	14037X	PARTICIPANT	\N	PRESENT	0
674799	673345	14038Y	PARTICIPANT	\N	PRESENT	0
674800	673345	20030R	PARTICIPANT	\N	PRESENT	0
674801	673345	20034V	PARTICIPANT	\N	PRESENT	0
674802	673345	14187A	PARTICIPANT	\N	PRESENT	0
674803	673345	19695N	PARTICIPANT	\N	PRESENT	0
674804	673345	11090Q	PRESIDENT	0	PRESENT	0
674805	673345	20054A	PARTICIPANT	\N	PRESENT	0
674806	673345	20060X	PARTICIPANT	\N	PRESENT	0
674807	673345	20062A	PARTICIPANT	\N	PRESENT	0
674808	673345	14251Q	PARTICIPANT	\N	PRESENT	0
674809	673345	14207L	PARTICIPANT	\N	PRESENT	0
674810	673345	14257W	PARTICIPANT	\N	PRESENT	0
674811	673345	19383Y	PARTICIPANT	\N	PRESENT	0
674812	673345	20088L	PARTICIPANT	\N	PRESENT	0
674813	673345	20092G	PARTICIPANT	\N	PRESENT	0
674814	673345	01043Q	PARTICIPANT	\N	PRESENT	0
674815	673345	14357A	PARTICIPANT	\N	PRESENT	0
674816	673345	20078J	PARTICIPANT	\N	PRESENT	0
674817	673345	19413M	PARTICIPANT	\N	PRESENT	0
674818	673345	20082E	PARTICIPANT	\N	PRESENT	0
674819	673345	20094J	PARTICIPANT	\N	PRESENT	0
674820	673345	04045F	PARTICIPANT	\N	PRESENT	0
674821	673345	19631V	PARTICIPANT	\N	PRESENT	0
674822	673345	20104S	PARTICIPANT	\N	PRESENT	0
674823	673345	19705W	PARTICIPANT	\N	PRESENT	0
674824	673345	19707Y	PARTICIPANT	\N	PRESENT	0
674825	673345	08015R	PARTICIPANT	\N	PRESENT	0
674826	673345	19575F	PARTICIPANT	\N	PRESENT	0
674827	673345	19369B	PARTICIPANT	\N	PRESENT	0
674828	673345	08028W	PARTICIPANT	\N	PRESENT	0
674829	673345	19563B	PARTICIPANT	\N	PRESENT	0
674830	673345	14329V	PARTICIPANT	\N	PRESENT	0
674831	673345	19467C	PARTICIPANT	\N	PRESENT	0
674832	673345	20144B	PARTICIPANT	\N	PRESENT	0
674833	673345	14033T	PARTICIPANT	\N	PRESENT	0
674846	672573	14179A	PARTICIPANT	\N	PRESENT	0
674835	673345	14205J	PARTICIPANT	\N	PRESENT	0
674854	672573	19671E	PARTICIPANT	\N	EXCUSE	0
674917	671032	19798U	PARTICIPANT	\N	PRESENT	0
674838	673345	19507S	PARTICIPANT	\N	PRESENT	0
674839	673345	20286Q	PARTICIPANT	\N	PRESENT	0
674840	673345	20298U	PARTICIPANT	\N	PRESENT	0
674841	673345	19747H	PARTICIPANT	\N	PRESENT	0
674918	671032	98022P	PARTICIPANT	\N	PRESENT	0
674919	671032	14038Y	PARTICIPANT	\N	PRESENT	0
674920	671032	20090E	PARTICIPANT	\N	PRESENT	0
674921	671032	19729F	PARTICIPANT	\N	PRESENT	0
674922	671032	19443T	PARTICIPANT	\N	PRESENT	0
674923	671032	17737W	PARTICIPANT	\N	PRESENT	0
674924	671032	14173T	PARTICIPANT	\N	PRESENT	0
674925	671032	19866P	PARTICIPANT	\N	PRESENT	0
674926	671032	07004J	PARTICIPANT	\N	PRESENT	0
674927	671032	08069G	PARTICIPANT	\N	PRESENT	0
674928	671032	19629C	PARTICIPANT	\N	PRESENT	0
674929	671032	19413M	PARTICIPANT	\N	PRESENT	0
674930	671032	20102Q	PARTICIPANT	\N	PRESENT	0
674931	671032	14215L	PARTICIPANT	\N	PRESENT	0
674932	671032	20024T	PARTICIPANT	\N	PRESENT	0
674933	671032	11080N	PARTICIPANT	\N	PRESENT	0
674934	671032	14133K	PARTICIPANT	\N	PRESENT	0
674935	671032	20180F	PARTICIPANT	\N	PRESENT	0
674936	671032	17589D	PARTICIPANT	\N	PRESENT	0
674937	671032	04042C	PARTICIPANT	\N	PRESENT	0
674938	671032	11085T	PARTICIPANT	\N	PRESENT	0
674939	671032	92040Q	PARTICIPANT	\N	PRESENT	0
674940	671032	08056B	PARTICIPANT	\N	PRESENT	0
674942	671032	14223L	PARTICIPANT	\N	PRESENT	0
674943	671032	19826F	PARTICIPANT	\N	PRESENT	0
674949	671032	19739H	PARTICIPANT	\N	PRESENT	0
674950	671032	19511N	PARTICIPANT	\N	PRESENT	0
675074	671032	20100N	PARTICIPANT	\N	PRESENT	0
675820	675819	11054L	PARTICIPANT	\N	PRESENT	0
675821	675819	19565D	PARTICIPANT	\N	PRESENT	0
675832	675831	11054L	PARTICIPANT	\N	PRESENT	0
675833	675831	19565D	PARTICIPANT	\N	PRESENT	0
675834	675831	20114U	PARTICIPANT	\N	PRESENT	0
675835	675831	14179A	PARTICIPANT	\N	PRESENT	0
675836	675831	11026G	PARTICIPANT	\N	PRESENT	0
675839	671033	19503N	PARTICIPANT	\N	PRESENT	0
675840	671033	19673G	PARTICIPANT	\N	PRESENT	0
675841	671033	19798U	PARTICIPANT	\N	PRESENT	0
675842	671033	19525U	PARTICIPANT	\N	PRESENT	0
675843	671033	14042U	PARTICIPANT	\N	PRESENT	0
675844	671033	19691J	PARTICIPANT	\N	PRESENT	0
675845	671033	18193Q	PARTICIPANT	\N	PRESENT	0
675846	671033	11097X	PARTICIPANT	\N	PRESENT	0
675847	671033	11067R	PARTICIPANT	\N	PRESENT	0
675848	671033	19715Y	PARTICIPANT	\N	PRESENT	0
675849	673349	19768N	PARTICIPANT	\N	PRESENT	0
675850	673349	19515S	PARTICIPANT	\N	PRESENT	0
675851	673349	11077T	PARTICIPANT	\N	PRESENT	0
675852	673349	19782L	PARTICIPANT	\N	PRESENT	0
675853	673349	20092G	PARTICIPANT	\N	PRESENT	0
675854	673349	01043Q	PARTICIPANT	\N	PRESENT	0
675855	673349	14357A	PARTICIPANT	\N	PRESENT	0
675856	673349	19441R	PARTICIPANT	\N	PRESENT	0
675857	673349	19413M	PARTICIPANT	\N	PRESENT	0
675858	673349	20094J	PARTICIPANT	\N	PRESENT	0
675859	673349	04045F	PARTICIPANT	\N	PRESENT	0
675860	673349	19866P	PARTICIPANT	\N	PRESENT	0
675861	673349	20104S	PARTICIPANT	\N	PRESENT	0
675862	673349	08015R	PARTICIPANT	\N	PRESENT	0
675863	673349	19575F	PARTICIPANT	\N	PRESENT	0
675864	673349	14329V	PARTICIPANT	\N	PRESENT	0
675865	673349	20028X	PARTICIPANT	\N	PRESENT	0
675866	673349	14038Y	PARTICIPANT	\N	PRESENT	0
675867	673349	19467C	PARTICIPANT	\N	PRESENT	0
675868	673349	20034V	PARTICIPANT	\N	PRESENT	0
675869	673349	20144B	PARTICIPANT	\N	PRESENT	0
675870	673349	19695N	PARTICIPANT	\N	PRESENT	0
675871	673349	14033T	PARTICIPANT	\N	PRESENT	0
675872	673349	20054A	PARTICIPANT	\N	PRESENT	0
675873	673349	14205J	PARTICIPANT	\N	PRESENT	0
675874	673349	20060X	PARTICIPANT	\N	PRESENT	0
675875	673349	20062A	PARTICIPANT	\N	PRESENT	0
675876	673349	14251Q	PARTICIPANT	\N	PRESENT	0
675877	673349	19507S	PARTICIPANT	\N	PRESENT	0
675878	673349	20286Q	PARTICIPANT	\N	PRESENT	0
675879	673349	14207L	PARTICIPANT	\N	PRESENT	0
675880	673349	19747H	PARTICIPANT	\N	PRESENT	0
656121	656120	14179A	PARTICIPANT	\N	PRESENT	0
656122	656120	04008A	PARTICIPANT	\N	PRESENT	0
656123	656120	20022R	PARTICIPANT	\N	PRESENT	0
656124	656120	20110Q	PARTICIPANT	\N	PRESENT	0
656126	656125	14179A	PARTICIPANT	\N	PRESENT	0
656127	656125	14147R	PARTICIPANT	\N	PRESENT	0
656128	656125	20022R	PARTICIPANT	\N	PRESENT	0
656130	656129	14179A	PARTICIPANT	\N	PRESENT	0
656131	656129	20022R	PARTICIPANT	\N	PRESENT	0
656132	656129	14147R	PARTICIPANT	\N	PRESENT	0
656133	656129	08047A	PARTICIPANT	\N	PRESENT	0
656135	656134	14179A	PARTICIPANT	\N	PRESENT	0
656136	656134	04008A	PARTICIPANT	\N	PRESENT	0
656137	656134	14151M	PARTICIPANT	\N	PRESENT	0
656138	656134	14147R	PARTICIPANT	\N	PRESENT	0
656139	656134	20022R	PARTICIPANT	\N	PRESENT	0
656141	656140	14179A	PARTICIPANT	\N	PRESENT	0
656142	656140	04008A	PARTICIPANT	\N	PRESENT	0
656143	656140	14151M	PARTICIPANT	\N	PRESENT	0
656144	656140	14147R	PARTICIPANT	\N	PRESENT	0
656145	656140	20022R	PARTICIPANT	\N	PRESENT	0
656146	656140	08047A	PARTICIPANT	\N	PRESENT	0
656148	656147	20022R	PARTICIPANT	\N	PRESENT	0
656149	656147	04008A	PARTICIPANT	\N	PRESENT	0
656154	656153	14147R	PARTICIPANT	\N	PRESENT	0
656151	656147	14179A	PARTICIPANT	\N	PRESENT	0
656152	656147	14147R	PARTICIPANT	\N	PRESENT	0
656155	656153	04008A	PARTICIPANT	\N	PRESENT	0
656156	656153	14179A	PARTICIPANT	\N	PRESENT	0
659040	655445	19717B	PRESIDENT	0	PRESENT	0
659041	655445	19631V	PARTICIPANT	\N	PRESENT	0
659042	655445	18083K	PARTICIPANT	\N	PRESENT	0
659043	655445	19659J	PARTICIPANT	\N	PRESENT	0
659044	655445	97011G	PARTICIPANT	\N	PRESENT	0
659045	655445	11010L	PARTICIPANT	\N	PRESENT	0
659046	655445	20034V	PARTICIPANT	\N	PRESENT	0
659047	655445	14097Y	PARTICIPANT	\N	PRESENT	0
659048	655445	20016T	PARTICIPANT	\N	PRESENT	0
659049	655445	14059S	PARTICIPANT	\N	PRESENT	0
659050	655445	08073C	PARTICIPANT	\N	PRESENT	0
659051	655445	20148F	PARTICIPANT	\N	PRESENT	0
659052	655445	20146D	PARTICIPANT	\N	PRESENT	0
659053	655445	20150Y	PARTICIPANT	\N	PRESENT	0
659054	655445	14275Y	PARTICIPANT	\N	PRESENT	0
659056	655445	19715Y	PARTICIPANT	\N	PRESENT	0
659067	655445	19301E	PARTICIPANT	\N	PRESENT	0
659068	655445	20028X	PARTICIPANT	\N	PRESENT	0
659105	659102	19651A	PARTICIPANT	\N	PRESENT	0
659585	659408	11043H	PARTICIPANT	\N	EXCUSE	0
659586	659409	11043H	PARTICIPANT	\N	EXCUSE	0
660348	659085	20036X	PARTICIPANT	\N	PRESENT	0
660349	659085	14189C	PARTICIPANT	\N	PRESENT	0
660350	659085	19531S	PARTICIPANT	\N	PRESENT	0
660351	659085	20050V	PARTICIPANT	\N	PRESENT	0
660352	659085	20044X	PARTICIPANT	\N	PRESENT	0
660353	659085	11040E	PARTICIPANT	\N	PRESENT	0
660354	659085	14083S	PARTICIPANT	\N	PRESENT	0
660355	659085	11012A	PARTICIPANT	\N	PRESENT	0
660356	659085	08073C	PARTICIPANT	\N	PRESENT	0
661239	659413	19591F	PARTICIPANT	\N	PRESENT	0
660358	659085	08009T	PARTICIPANT	\N	PRESENT	0
660359	659085	20070A	PARTICIPANT	\N	PRESENT	0
660360	659085	19741B	PARTICIPANT	\N	PRESENT	0
660361	659085	14121F	PARTICIPANT	\N	PRESENT	0
660363	659085	20080C	PARTICIPANT	\N	PRESENT	0
660364	659085	12016W	PARTICIPANT	\N	PRESENT	0
660369	659085	14253S	PARTICIPANT	\N	PRESENT	0
660370	659085	19762G	PARTICIPANT	\N	PRESENT	0
660371	659365	20114U	PARTICIPANT	\N	PRESENT	0
660372	659365	11026G	PARTICIPANT	\N	PRESENT	0
660373	656930	05012A	PARTICIPANT	\N	PRESENT	0
660429	660424	08012N	PARTICIPANT	\N	PRESENT	0
660430	660424	11043H	PARTICIPANT	\N	PRESENT	0
660431	660424	19527W	PARTICIPANT	\N	PRESENT	0
660432	660425	08012N	PARTICIPANT	\N	PRESENT	0
660433	660425	11043H	PARTICIPANT	\N	PRESENT	0
660434	660426	08012N	PARTICIPANT	\N	PRESENT	0
660435	660426	11043H	PARTICIPANT	\N	PRESENT	0
660436	660426	19527W	PARTICIPANT	\N	PRESENT	1
660437	660426	19611R	PARTICIPANT	\N	PRESENT	1
660439	660438	20124W	PARTICIPANT	\N	PRESENT	0
660440	660438	14109K	PARTICIPANT	\N	PRESENT	0
660441	660438	19735D	PARTICIPANT	\N	PRESENT	0
660447	657977	20134Y	PARTICIPANT	\N	PRESENT	0
660448	657977	14073Q	PARTICIPANT	\N	PRESENT	0
660449	657977	20058E	PARTICIPANT	\N	PRESENT	0
660450	657977	19735D	PARTICIPANT	\N	PRESENT	0
660451	657977	19057M	PARTICIPANT	\N	PRESENT	0
660452	657977	14123H	PARTICIPANT	\N	PRESENT	0
660453	657977	19621T	PARTICIPANT	\N	PRESENT	0
660454	657977	19399H	PARTICIPANT	\N	PRESENT	0
660458	659193	14281W	PARTICIPANT	\N	PRESENT	0
660459	659193	04057K	PARTICIPANT	\N	PRESENT	0
660460	659193	11045K	PARTICIPANT	\N	PRESENT	0
661206	657983	20098N	PARTICIPANT	\N	PRESENT	0
661207	657983	19573D	PARTICIPANT	\N	PRESENT	0
661208	657983	08012N	PARTICIPANT	\N	PRESENT	0
661209	657983	20026V	PARTICIPANT	\N	PRESENT	0
661210	657983	19527W	PARTICIPANT	\N	PRESENT	0
661211	657983	19593H	PARTICIPANT	\N	PRESENT	0
661212	657983	20132W	PARTICIPANT	\N	PRESENT	0
661213	657983	19651A	PARTICIPANT	\N	PRESENT	0
661214	657983	20138D	PARTICIPANT	\N	PRESENT	0
661215	657983	19611R	PRESIDENT	0	PRESENT	0
661216	657983	20142Y	PARTICIPANT	\N	PRESENT	0
661217	657983	19693L	PARTICIPANT	\N	PRESENT	0
661218	657983	19399H	PARTICIPANT	\N	PRESENT	0
661219	657983	20052X	PARTICIPANT	\N	PRESENT	0
661220	657983	20172F	PARTICIPANT	\N	PRESENT	0
661221	657983	20058E	PARTICIPANT	\N	PRESENT	0
661222	657983	14030Q	PARTICIPANT	\N	PRESENT	0
661223	657983	20056C	PARTICIPANT	\N	PRESENT	0
661224	657983	04059M	PARTICIPANT	\N	PRESENT	0
661225	657983	19735D	PARTICIPANT	\N	PRESENT	0
661226	657983	19057M	PARTICIPANT	\N	PRESENT	0
661227	657983	11043H	PARTICIPANT	\N	PRESENT	0
661228	657983	19758L	PARTICIPANT	\N	PRESENT	0
661229	657983	19621T	PARTICIPANT	\N	PRESENT	0
661230	657983	20084G	PARTICIPANT	\N	PRESENT	0
661231	659413	19657G	PARTICIPANT	\N	PRESENT	0
661232	659413	20038A	PARTICIPANT	\N	PRESENT	0
661233	659413	11033F	PARTICIPANT	\N	PRESENT	0
661234	659413	14179A	PARTICIPANT	\N	PRESENT	0
661236	659413	14189C	PARTICIPANT	\N	PRESENT	0
661237	659413	07004J	PARTICIPANT	\N	PRESENT	0
661240	659413	19515S	PARTICIPANT	\N	PRESENT	0
661242	659413	20054A	PARTICIPANT	\N	PRESENT	0
661247	659413	19347U	PARTICIPANT	\N	PRESENT	0
661257	659413	20128B	PARTICIPANT	\N	PRESENT	0
661273	659413	20048C	PARTICIPANT	\N	PRESENT	0
661274	659413	19543W	PARTICIPANT	\N	PRESENT	0
661275	659413	19719D	PARTICIPANT	\N	PRESENT	0
661276	659413	19553Y	PARTICIPANT	\N	PRESENT	0
661289	659413	11026G	PARTICIPANT	\N	PRESENT	0
661290	659413	14071N	PARTICIPANT	\N	PRESENT	0
661299	659413	19295A	PARTICIPANT	\N	PRESENT	0
661307	659413	14187A	PARTICIPANT	\N	PRESENT	0
661318	659413	11053K	PARTICIPANT	\N	PRESENT	0
661320	659413	20070A	PARTICIPANT	\N	PRESENT	0
661323	659413	19503N	PARTICIPANT	\N	PRESENT	0
661324	659413	14257W	PARTICIPANT	\N	PRESENT	0
661325	659413	19741B	PARTICIPANT	\N	PRESENT	0
661326	659413	20100N	PARTICIPANT	\N	PRESENT	0
661327	659413	19583F	PARTICIPANT	\N	PRESENT	0
661328	659413	19691J	PARTICIPANT	\N	PRESENT	0
661329	659413	20116W	PARTICIPANT	\N	PRESENT	0
661330	659413	14173T	PARTICIPANT	\N	PRESENT	0
661331	659413	14038Y	PARTICIPANT	\N	PRESENT	0
661332	659413	19711U	PARTICIPANT	\N	PRESENT	0
661333	659413	01028R	PARTICIPANT	\N	PRESENT	0
661334	659413	18083K	PARTICIPANT	\N	PRESENT	0
661335	659413	08034U	PARTICIPANT	\N	PRESENT	0
661336	659413	19349W	PARTICIPANT	\N	PRESENT	0
661337	659413	19599P	PARTICIPANT	\N	PRESENT	0
661338	659413	20060X	PARTICIPANT	\N	PRESENT	0
661339	659413	20068G	PARTICIPANT	\N	PRESENT	0
661340	659413	20026V	PARTICIPANT	\N	PRESENT	0
661341	659413	20056C	PARTICIPANT	\N	PRESENT	0
661545	659409	19717B	PRESIDENT	0	PRESENT	0
661546	659409	19577H	PARTICIPANT	\N	PRESENT	0
661547	659409	17023S	PARTICIPANT	\N	EXCUSE	0
671831	669896	12041X	PARTICIPANT	\N	PRESENT	0
671835	667818	14237S	PARTICIPANT	\N	PRESENT	0
671836	667818	18083K	PARTICIPANT	\N	PRESENT	0
671837	667818	20100N	PARTICIPANT	\N	PRESENT	0
671838	667818	20068G	PARTICIPANT	\N	PRESENT	0
671839	667818	20076G	PARTICIPANT	\N	PRESENT	0
671840	667818	19503N	PARTICIPANT	\N	PRESENT	0
671841	667818	20120S	PARTICIPANT	\N	PRESENT	0
671842	669896	11031D	PARTICIPANT	\N	PRESENT	0
671843	669896	10006L	PARTICIPANT	\N	PRESENT	0
671844	669896	19565D	PARTICIPANT	\N	PRESENT	0
671903	669896	14215L	PARTICIPANT	\N	PRESENT	0
671846	669896	14213J	PARTICIPANT	\N	PRESENT	0
671874	669559	19479G	PARTICIPANT	\N	PRESENT	0
671848	669896	19683J	PARTICIPANT	\N	PRESENT	0
671849	669896	10015M	PARTICIPANT	\N	PRESENT	0
671850	669896	19599P	PARTICIPANT	\N	PRESENT	0
671851	669896	19583F	PARTICIPANT	\N	PRESENT	0
671852	669896	14195A	PARTICIPANT	\N	PRESENT	0
671853	669896	14123H	PARTICIPANT	\N	PRESENT	0
671854	669896	20130U	PARTICIPANT	\N	PRESENT	0
671855	669896	19533U	PARTICIPANT	\N	PRESENT	0
671856	669896	14147R	PARTICIPANT	\N	PRESENT	0
671857	669896	14281W	PARTICIPANT	\N	PRESENT	0
671858	669896	18193Q	PARTICIPANT	\N	PRESENT	0
671859	669896	19713W	PARTICIPANT	\N	PRESENT	0
671860	669896	20090E	PARTICIPANT	\N	PRESENT	0
671861	669896	20062A	PARTICIPANT	\N	PRESENT	0
671862	669896	19553Y	PARTICIPANT	\N	PRESENT	0
671875	669559	19647E	PARTICIPANT	\N	PRESENT	0
671876	669559	19711U	PARTICIPANT	\N	PRESENT	0
671877	669559	19531S	PARTICIPANT	\N	PRESENT	0
671878	669559	11053K	PARTICIPANT	\N	PRESENT	0
671879	669559	20080C	PARTICIPANT	\N	PRESENT	0
671880	669559	11074Q	PARTICIPANT	\N	PRESENT	0
671881	669559	11070L	PARTICIPANT	\N	PRESENT	0
671882	669559	14225N	PRESIDENT	0	PRESENT	0
671883	669559	19671E	PARTICIPANT	\N	PRESENT	0
671884	669559	07029T	PARTICIPANT	\N	PRESENT	0
671885	669559	11012A	PARTICIPANT	\N	PRESENT	0
671886	669559	20252E	PARTICIPANT	\N	PRESENT	0
671887	669559	20070A	PARTICIPANT	\N	PRESENT	0
671888	669559	20914V	PARTICIPANT	\N	PRESENT	0
671889	669559	20116W	PARTICIPANT	\N	PRESENT	0
671890	669559	99004R	PARTICIPANT	\N	PRESENT	0
671895	667818	19333N	PARTICIPANT	\N	PRESENT	0
671896	667818	19387D	PARTICIPANT	\N	PRESENT	0
671897	667818	17367Q	PARTICIPANT	\N	PRESENT	0
671898	667818	20102Q	PARTICIPANT	\N	PRESENT	0
671899	667818	14169X	PARTICIPANT	\N	PRESENT	0
671904	669896	14026U	PARTICIPANT	\N	PRESENT	0
671907	669896	04092N	PARTICIPANT	\N	PRESENT	0
671910	669896	19415P	PARTICIPANT	\N	PRESENT	0
671911	669896	11097X	PARTICIPANT	\N	PRESENT	0
671912	669896	20132W	PARTICIPANT	\N	PRESENT	0
671913	669559	08034U	PARTICIPANT	\N	PRESENT	0
671914	669559	14083S	PARTICIPANT	\N	PRESENT	0
671915	669559	19421M	PARTICIPANT	\N	PRESENT	0
671916	669559	20126Y	PARTICIPANT	\N	PRESENT	0
671918	669896	19651A	PARTICIPANT	\N	PRESENT	0
671919	669896	19715Y	PARTICIPANT	\N	PRESENT	0
671920	669896	17965H	PARTICIPANT	\N	PRESENT	0
671921	669896	08045X	PARTICIPANT	\N	PRESENT	0
671922	669896	19745F	PARTICIPANT	\N	PRESENT	0
671923	669896	14223L	PARTICIPANT	\N	PRESENT	0
671925	669896	20266L	PARTICIPANT	\N	PRESENT	0
671926	669559	12016W	PARTICIPANT	\N	EXCUSE	0
671927	669896	20024T	PARTICIPANT	\N	PRESENT	0
671928	669896	19760E	PARTICIPANT	\N	PRESENT	0
671929	669896	08056B	PARTICIPANT	\N	PRESENT	0
671930	669896	19723Y	PARTICIPANT	\N	PRESENT	0
671931	669896	14042U	PARTICIPANT	\N	PRESENT	0
671932	669896	19657G	PARTICIPANT	\N	PRESENT	0
671934	669896	19798U	PARTICIPANT	\N	PRESENT	0
671935	669896	19591F	PARTICIPANT	\N	PRESENT	0
671936	669896	14030Q	PARTICIPANT	\N	PRESENT	0
671940	669559	20086J	PARTICIPANT	\N	PRESENT	0
671941	669559	11110B	PARTICIPANT	\N	PRESENT	0
671942	667818	19701S	PARTICIPANT	\N	PRESENT	0
671943	667818	14219Q	PRESIDENT	0	PRESENT	0
671944	667818	19820Y	PARTICIPANT	\N	PRESENT	0
671945	667818	14221J	PARTICIPANT	\N	PRESENT	0
671946	667818	19585H	PARTICIPANT	\N	PRESENT	0
671947	667818	19637C	PARTICIPANT	\N	PRESENT	0
671948	667818	11065P	PARTICIPANT	\N	PRESENT	0
671949	667818	20032T	PARTICIPANT	\N	PRESENT	0
671950	667818	20136B	PARTICIPANT	\N	PRESENT	0
671951	667818	20038A	PARTICIPANT	\N	PRESENT	0
671952	667818	19251M	PARTICIPANT	\N	PRESENT	0
671953	667818	19739H	PARTICIPANT	\N	PRESENT	0
671954	669896	20098N	PARTICIPANT	\N	PRESENT	0
671987	669896	14071N	PARTICIPANT	\N	PRESENT	0
671999	669896	04045F	PARTICIPANT	\N	PRESENT	0
672009	669896	11056N	PARTICIPANT	\N	PRESENT	0
672010	669896	20180F	PARTICIPANT	\N	PRESENT	0
672012	669896	20032T	PARTICIPANT	\N	PRESENT	0
672013	669896	19399H	PARTICIPANT	\N	PRESENT	0
672014	669896	20100N	PARTICIPANT	\N	PRESENT	0
672015	669559	04071H	PARTICIPANT	\N	PRESENT	0
672016	669559	14121F	PARTICIPANT	\N	PRESENT	0
672017	669896	14179A	PARTICIPANT	\N	PRESENT	0
672018	669896	19515S	PARTICIPANT	\N	PRESENT	0
672019	669896	14038Y	PARTICIPANT	\N	PRESENT	0
672020	669896	20128B	PARTICIPANT	\N	PRESENT	0
672021	669896	95041E	PARTICIPANT	\N	PRESENT	0
672022	669896	14069U	PARTICIPANT	\N	PRESENT	0
672036	669896	01028R	PARTICIPANT	\N	PRESENT	0
672037	669896	14329V	PARTICIPANT	\N	PRESENT	0
672038	669896	99004R	PARTICIPANT	\N	PRESENT	0
672039	669896	11012A	PARTICIPANT	\N	PRESENT	0
672040	669896	01057W	PARTICIPANT	\N	PRESENT	0
672041	669896	20044X	PARTICIPANT	\N	PRESENT	0
672042	669896	19467C	PARTICIPANT	\N	PRESENT	0
672043	669896	20126Y	PARTICIPANT	\N	PRESENT	0
672044	669896	14253S	PARTICIPANT	\N	PRESENT	0
672045	669896	20080C	PARTICIPANT	\N	PRESENT	0
672046	669896	07029T	PARTICIPANT	\N	PRESENT	0
672047	669896	08010L	PARTICIPANT	\N	PRESENT	0
672048	669896	19575F	PARTICIPANT	\N	PRESENT	0
672051	669896	19441R	PARTICIPANT	\N	PRESENT	0
672052	669896	20116W	PARTICIPANT	\N	PRESENT	0
672053	669896	20030R	PARTICIPANT	\N	PRESENT	0
672127	669897	11045K	PARTICIPANT	\N	PRESENT	0
672128	669897	14195A	PARTICIPANT	\N	PRESENT	0
672129	669897	19553Y	PARTICIPANT	\N	PRESENT	0
672130	669897	14073Q	PARTICIPANT	\N	PRESENT	0
672131	669897	20028X	PARTICIPANT	\N	PRESENT	0
672133	669897	19569H	PARTICIPANT	\N	PRESENT	0
672134	669897	19467C	PARTICIPANT	\N	PRESENT	0
672135	669897	18193Q	PARTICIPANT	\N	PRESENT	0
672136	669897	19683J	PARTICIPANT	\N	PRESENT	0
672137	669897	17965H	PARTICIPANT	\N	PRESENT	0
672138	669897	20130U	PARTICIPANT	\N	PRESENT	0
672139	669897	11031D	PARTICIPANT	\N	PRESENT	0
672140	669897	14071N	PARTICIPANT	\N	PRESENT	0
672141	669897	11097X	PARTICIPANT	\N	PRESENT	0
672142	669897	14213J	PARTICIPANT	\N	PRESENT	0
672143	669897	04092N	PARTICIPANT	\N	PRESENT	0
672144	669897	14042U	PARTICIPANT	\N	PRESENT	0
672161	669897	19723Y	PARTICIPANT	\N	PRESENT	0
672146	669897	19691J	PARTICIPANT	\N	PRESENT	0
672147	669897	19399H	PARTICIPANT	\N	PRESENT	0
672148	669897	19367Y	PARTICIPANT	\N	PRESENT	0
672149	669897	19657G	PARTICIPANT	\N	PRESENT	0
672150	669897	20030R	PARTICIPANT	\N	PRESENT	0
672151	669897	20044X	PARTICIPANT	\N	PRESENT	0
672152	669897	19715Y	PARTICIPANT	\N	PRESENT	0
672153	669897	11067R	PARTICIPANT	\N	PRESENT	0
672154	669897	20034V	PARTICIPANT	\N	PRESENT	0
672155	669897	14207L	PARTICIPANT	\N	PRESENT	0
672156	669897	20132W	PARTICIPANT	\N	PRESENT	0
672157	669897	20066E	PARTICIPANT	\N	PRESENT	0
672158	669897	19415P	PARTICIPANT	\N	PRESENT	0
672159	669897	20180F	PARTICIPANT	\N	PRESENT	0
672163	669897	20116W	PARTICIPANT	\N	PRESENT	0
672162	669897	20070A	PARTICIPANT	\N	PRESENT	0
672164	669897	14223L	PARTICIPANT	\N	PRESENT	0
672165	669897	19697Q	PARTICIPANT	\N	PRESENT	0
672166	669897	08061X	PARTICIPANT	\N	PRESENT	0
672167	669897	19782L	PARTICIPANT	\N	PRESENT	0
659615	659614	20124W	PARTICIPANT	\N	PRESENT	1
659616	659614	19735D	PARTICIPANT	\N	PRESENT	1
659622	659621	11104D	PARTICIPANT	\N	PRESENT	1
659623	659621	19527W	PARTICIPANT	\N	PRESENT	1
661319	661314	14042U	PARTICIPANT	\N	PRESENT	0
661321	661314	20130U	PARTICIPANT	\N	PRESENT	0
661322	661314	11097X	PARTICIPANT	\N	PRESENT	0
661942	661941	04071H	PARTICIPANT	\N	PRESENT	0
661944	661943	19687N	PARTICIPANT	\N	PRESENT	0
661946	661945	12016W	PARTICIPANT	\N	PRESENT	0
661948	661947	12016W	PARTICIPANT	\N	PRESENT	0
661950	661949	12016W	PARTICIPANT	\N	PRESENT	0
661952	661951	12016W	PARTICIPANT	\N	PRESENT	0
661954	661953	11048N	PARTICIPANT	\N	PRESENT	0
661955	661953	14225N	PARTICIPANT	\N	PRESENT	0
661956	661953	19741B	PARTICIPANT	\N	PRESENT	0
661957	661953	11040E	PARTICIPANT	\N	PRESENT	0
661958	661953	20914V	PARTICIPANT	\N	PRESENT	0
661959	661953	14083S	PARTICIPANT	\N	PRESENT	0
661960	661953	20070A	PARTICIPANT	\N	PRESENT	0
661961	661953	01057W	PARTICIPANT	\N	PRESENT	0
661962	661953	20126Y	PARTICIPANT	\N	PRESENT	0
661963	661953	19711U	PARTICIPANT	\N	PRESENT	0
661964	661953	12016W	PARTICIPANT	\N	PRESENT	0
661965	661953	11012A	PARTICIPANT	\N	PRESENT	0
661966	661953	19762G	PARTICIPANT	\N	PRESENT	0
661968	661967	14121F	PARTICIPANT	\N	PRESENT	0
661970	661969	14121F	PARTICIPANT	\N	PRESENT	0
661972	661971	11048N	PARTICIPANT	\N	PRESENT	0
661973	661971	14121F	PARTICIPANT	\N	PRESENT	0
661975	661974	14121F	PARTICIPANT	\N	PRESENT	0
661977	661976	11048N	PARTICIPANT	\N	PRESENT	0
661978	661976	20116W	PARTICIPANT	\N	PRESENT	0
661979	661976	14083S	PARTICIPANT	\N	PRESENT	0
661980	661976	11053K	PARTICIPANT	\N	PRESENT	0
661981	661976	20070A	PARTICIPANT	\N	PRESENT	0
661982	661976	11070L	PARTICIPANT	\N	PRESENT	0
661983	661976	01057W	PARTICIPANT	\N	PRESENT	0
661984	661976	19531S	PARTICIPANT	\N	PRESENT	0
661985	661976	19711U	PARTICIPANT	\N	PRESENT	0
661986	661976	12016W	PARTICIPANT	\N	PRESENT	0
661987	661976	20044X	PARTICIPANT	\N	PRESENT	0
661988	661976	19762G	PARTICIPANT	\N	PRESENT	0
662448	662440	14042U	PARTICIPANT	\N	PRESENT	0
662449	662440	19569H	PARTICIPANT	\N	PRESENT	0
662454	662453	19569H	PARTICIPANT	\N	PRESENT	0
662455	662453	20130U	PARTICIPANT	\N	PRESENT	0
662875	662874	19533U	PARTICIPANT	\N	PRESENT	0
662901	662898	20124W	PARTICIPANT	\N	PRESENT	0
662902	662898	19735D	PARTICIPANT	\N	PRESENT	0
662903	662898	14109K	PARTICIPANT	\N	PRESENT	1
662904	662900	20124W	PARTICIPANT	\N	PRESENT	0
662905	662900	19735D	PARTICIPANT	\N	PRESENT	0
662906	662900	14109K	PARTICIPANT	\N	PRESENT	0
663531	660362	19057M	PARTICIPANT	\N	PRESENT	0
663532	660362	11043H	PARTICIPANT	\N	PRESENT	0
663533	660362	20058E	PARTICIPANT	\N	PRESENT	0
663842	662441	19569H	PARTICIPANT	\N	PRESENT	0
663844	662441	20130U	PARTICIPANT	\N	PRESENT	0
663858	663857	14042U	PARTICIPANT	\N	PRESENT	0
663859	663857	11097X	PARTICIPANT	\N	PRESENT	0
664199	664196	19413M	PARTICIPANT	\N	PRESENT	0
664200	664196	01025N	PARTICIPANT	\N	PRESENT	0
664289	664288	14213J	PARTICIPANT	\N	PRESENT	0
664291	664290	14213J	PARTICIPANT	\N	PRESENT	0
664300	664298	14071N	PARTICIPANT	\N	PRESENT	0
664310	664285	20172F	PARTICIPANT	\N	PRESENT	1
664311	664285	14109K	PARTICIPANT	\N	PRESENT	1
664312	664285	20180F	PARTICIPANT	\N	PRESENT	1
664343	664342	19533U	PARTICIPANT	\N	PRESENT	0
664344	664342	19719D	PARTICIPANT	\N	PRESENT	0
664348	664347	20112S	PARTICIPANT	\N	PRESENT	0
664350	664347	20142Y	PARTICIPANT	\N	PRESENT	0
664351	664347	14229S	PARTICIPANT	\N	PRESENT	0
665086	661843	19695N	PARTICIPANT	\N	PRESENT	0
665087	661843	20070A	PARTICIPANT	\N	PRESENT	0
665088	661843	11099A	PARTICIPANT	\N	PRESENT	0
665089	661843	20092G	PARTICIPANT	\N	PRESENT	0
665090	661843	19762G	PARTICIPANT	\N	PRESENT	0
665091	661843	20050V	PARTICIPANT	\N	PRESENT	0
665092	661843	19583F	PARTICIPANT	\N	PRESENT	0
665093	661843	04057K	PARTICIPANT	\N	PRESENT	0
665094	661843	19545Y	PARTICIPANT	\N	PRESENT	0
665095	661843	14251Q	PARTICIPANT	\N	PRESENT	0
665096	661843	19369B	PARTICIPANT	\N	PRESENT	0
665084	661843	11070L	PARTICIPANT	\N	PRESENT	0
665085	661843	19687N	PARTICIPANT	\N	PRESENT	0
665097	661843	14205J	PARTICIPANT	\N	PRESENT	0
665098	661843	14221J	PARTICIPANT	\N	PRESENT	0
665099	661843	19866P	PARTICIPANT	\N	PRESENT	0
665100	661843	07029T	PARTICIPANT	\N	PRESENT	0
665101	661843	20034V	PARTICIPANT	\N	PRESENT	0
665102	661843	20152B	PARTICIPANT	\N	PRESENT	0
665103	661843	18083K	PARTICIPANT	\N	PRESENT	0
665104	661843	14219Q	PARTICIPANT	\N	PRESENT	0
665105	661843	11090Q	PARTICIPANT	\N	PRESENT	0
665258	665253	20074E	PARTICIPANT	\N	PRESENT	0
665359	665358	14267Y	PARTICIPANT	\N	PRESENT	0
665360	665358	19565D	PARTICIPANT	\N	PRESENT	0
665362	665361	14267Y	PARTICIPANT	\N	PRESENT	0
665363	665361	19565D	PARTICIPANT	\N	PRESENT	0
665365	665364	14193X	PARTICIPANT	\N	PRESENT	0
665366	665364	11083R	PARTICIPANT	\N	PRESENT	0
665372	665371	11053K	PARTICIPANT	\N	PRESENT	0
665373	665371	05008E	PARTICIPANT	\N	PRESENT	0
665374	665371	01028R	PARTICIPANT	\N	PRESENT	0
665377	665375	11104D	PARTICIPANT	\N	PRESENT	1
665378	665375	20058E	PARTICIPANT	\N	PRESENT	1
665529	665445	20130U	PARTICIPANT	\N	PRESENT	0
665530	665445	14026U	PARTICIPANT	\N	PRESENT	0
666521	666520	19447X	PARTICIPANT	\N	PRESENT	0
666522	666520	14089Y	PARTICIPANT	\N	PRESENT	0
666523	666520	11026G	PARTICIPANT	\N	PRESENT	0
667825	667819	19697Q	PARTICIPANT	\N	PRESENT	0
667826	667819	20090E	PARTICIPANT	\N	PRESENT	0
667827	667819	19569H	PARTICIPANT	\N	PRESENT	0
667828	667819	11097X	PARTICIPANT	\N	PRESENT	0
667829	667819	19329S	PARTICIPANT	\N	PRESENT	0
667830	667819	14026U	PARTICIPANT	\N	PRESENT	0
667831	667819	19553Y	PARTICIPANT	\N	PRESENT	0
667832	667819	19703U	PARTICIPANT	\N	PRESENT	0
667833	667819	14281W	PARTICIPANT	\N	PRESENT	0
667834	667819	14042U	PARTICIPANT	\N	PRESENT	0
667835	667819	14195A	PARTICIPANT	\N	PRESENT	0
667836	667819	14213J	PARTICIPANT	\N	PRESENT	0
667837	667819	14217N	PARTICIPANT	\N	PRESENT	0
667838	667819	19683J	PARTICIPANT	\N	PRESENT	0
667839	667819	10006L	PRESIDENT	0	PRESENT	0
667840	667819	20130U	PARTICIPANT	\N	PRESENT	0
667841	667819	19713W	PARTICIPANT	\N	PRESENT	0
667842	667819	17965H	PARTICIPANT	\N	PRESENT	0
667843	667819	19691J	PARTICIPANT	\N	PRESENT	0
667844	667819	20148F	PARTICIPANT	\N	PRESENT	0
667845	667819	19723Y	PARTICIPANT	\N	PRESENT	0
667846	667819	20066E	PARTICIPANT	\N	PRESENT	0
667847	667819	11103C	PARTICIPANT	\N	PRESENT	0
667848	667819	20266L	PARTICIPANT	\N	PRESENT	0
667849	667819	14071N	PARTICIPANT	\N	PRESENT	0
667850	667819	19657G	PARTICIPANT	\N	PRESENT	0
667851	667819	04043D	PARTICIPANT	\N	PRESENT	0
667852	667819	20040T	PARTICIPANT	\N	PRESENT	0
667853	667819	19760E	PARTICIPANT	\N	PRESENT	0
667854	665225	18083K	PARTICIPANT	\N	PRESENT	0
667855	665225	19577H	PARTICIPANT	\N	PRESENT	0
667856	665225	20102Q	PARTICIPANT	\N	PRESENT	0
667857	665225	14169X	PARTICIPANT	\N	PRESENT	0
667858	665225	19619A	PARTICIPANT	\N	PRESENT	0
667859	665225	20120S	PARTICIPANT	\N	PRESENT	0
667860	667819	11045K	PARTICIPANT	\N	PRESENT	0
667861	667696	20086J	PARTICIPANT	\N	PRESENT	0
667862	667696	14327T	PARTICIPANT	\N	PRESENT	0
667863	667696	11048N	PARTICIPANT	\N	PRESENT	0
667864	667696	19479G	PARTICIPANT	\N	PRESENT	0
667865	667696	19711U	PARTICIPANT	\N	PRESENT	0
667866	667696	19531S	PARTICIPANT	\N	PRESENT	0
667867	667696	19687N	PARTICIPANT	\N	PRESENT	0
667868	667696	20080C	PARTICIPANT	\N	PRESENT	0
667869	667696	11053K	PARTICIPANT	\N	PRESENT	0
675881	673349	14257W	PARTICIPANT	\N	PRESENT	0
675882	671033	14121F	PARTICIPANT	\N	PRESENT	0
675947	671035	14026U	PARTICIPANT	\N	PRESENT	0
675987	672576	19479G	PARTICIPANT	\N	PRESENT	0
675988	672576	11048N	PARTICIPANT	\N	PRESENT	0
675989	672576	19711U	PARTICIPANT	\N	PRESENT	0
675990	672576	20036X	PARTICIPANT	\N	PRESENT	0
675991	672576	08034U	PARTICIPANT	\N	PRESENT	0
675992	672576	19531S	PARTICIPANT	\N	PRESENT	0
675993	672576	01057W	PARTICIPANT	\N	PRESENT	0
675994	672576	20080C	PARTICIPANT	\N	PRESENT	0
675995	672576	20050V	PARTICIPANT	\N	PRESENT	0
675996	672576	20044X	PARTICIPANT	\N	PRESENT	0
675997	672576	14225N	PRESIDENT	0	PRESENT	0
675998	672576	11070L	PARTICIPANT	\N	PRESENT	0
675999	672576	11040E	PARTICIPANT	\N	PRESENT	0
676000	672576	07029T	PARTICIPANT	\N	PRESENT	0
676001	672576	20070A	PARTICIPANT	\N	PRESENT	0
676002	672576	14121F	PARTICIPANT	\N	PRESENT	0
676003	672576	08010L	PARTICIPANT	\N	PRESENT	0
676004	672576	99004R	PARTICIPANT	\N	PRESENT	0
676005	672576	19762G	PARTICIPANT	\N	PRESENT	0
676006	672576	14189C	PARTICIPANT	\N	EXCUSE	0
676007	672576	14083S	PARTICIPANT	\N	PRESENT	0
676008	672576	19349W	PARTICIPANT	\N	PRESENT	0
676009	672576	19667J	PARTICIPANT	\N	PRESENT	0
676010	672576	20116W	PARTICIPANT	\N	PRESENT	0
676011	672576	19335Q	PARTICIPANT	\N	PRESENT	0
676012	672576	20126Y	PARTICIPANT	\N	PRESENT	0
676013	672576	08011M	PARTICIPANT	\N	PRESENT	0
676014	672576	11012A	PARTICIPANT	\N	PRESENT	0
676015	672576	20252E	PARTICIPANT	\N	PRESENT	0
676016	671035	11067R	PARTICIPANT	\N	PRESENT	0
676017	671035	18193Q	PARTICIPANT	\N	PRESENT	0
676018	671035	19251M	PARTICIPANT	\N	PRESENT	0
676019	671035	19565D	PARTICIPANT	\N	PRESENT	0
676020	671035	11077T	PARTICIPANT	\N	PRESENT	0
676021	671035	20134Y	PARTICIPANT	\N	PRESENT	0
676022	671035	14207L	PARTICIPANT	\N	PRESENT	0
676023	671035	19866P	PARTICIPANT	\N	PRESENT	0
676024	671035	14219Q	PARTICIPANT	\N	PRESENT	0
676025	671035	20298U	PARTICIPANT	\N	PRESENT	0
676026	671035	20090E	PARTICIPANT	\N	PRESENT	0
676027	671035	14213J	PARTICIPANT	\N	PRESENT	0
676028	672576	11053K	PARTICIPANT	\N	PRESENT	0
676029	672576	19647E	PARTICIPANT	\N	PRESENT	0
676030	671035	19683J	PARTICIPANT	\N	PRESENT	0
676031	671035	14249W	PARTICIPANT	\N	PRESENT	0
676032	671035	19679N	PARTICIPANT	\N	PRESENT	0
676033	671035	14133K	PARTICIPANT	\N	PRESENT	0
676047	672576	19545Y	PARTICIPANT	\N	PRESENT	0
676050	671035	11097X	PARTICIPANT	\N	PRESENT	0
676051	671035	19798U	PARTICIPANT	\N	PRESENT	0
676052	671035	19693L	PARTICIPANT	\N	PRESENT	0
676053	671035	19347U	PARTICIPANT	\N	PRESENT	0
676054	671035	14021P	PARTICIPANT	\N	PRESENT	0
676055	671035	20130U	PARTICIPANT	\N	PRESENT	0
676056	671035	19697Q	PARTICIPANT	\N	PRESENT	0
676057	671035	17023S	PARTICIPANT	\N	PRESENT	0
676058	671035	20110Q	PARTICIPANT	\N	PRESENT	0
676059	672576	19741B	PARTICIPANT	\N	PRESENT	0
676060	671035	19413M	PARTICIPANT	\N	PRESENT	0
676061	671035	20050V	PARTICIPANT	\N	PRESENT	0
676063	676062	14331P	PRESIDENT	0	PRESENT	0
676064	676062	11026G	PARTICIPANT	\N	PRESENT	0
676065	676062	19531S	PARTICIPANT	\N	PRESENT	0
676066	676062	19593H	PARTICIPANT	\N	PRESENT	0
676067	676062	11083R	PARTICIPANT	\N	PRESENT	0
676068	676062	20100N	PARTICIPANT	\N	PRESENT	0
676069	676062	20104S	PARTICIPANT	\N	PRESENT	0
676071	676062	14001X	PARTICIPANT	\N	PRESENT	0
676072	676062	04057K	PARTICIPANT	\N	PRESENT	0
676073	676062	04070G	PARTICIPANT	\N	PRESENT	0
676074	676062	10015M	PARTICIPANT	\N	PRESENT	0
676077	672576	11074Q	PARTICIPANT	\N	PRESENT	0
676078	671035	20126Y	PARTICIPANT	\N	PRESENT	0
676079	671035	19669L	PARTICIPANT	\N	PRESENT	0
676080	671035	19525U	PARTICIPANT	\N	PRESENT	0
676081	671035	19467C	PARTICIPANT	\N	PRESENT	0
676082	671035	20104S	PARTICIPANT	\N	PRESENT	0
676083	671035	04057K	PARTICIPANT	\N	PRESENT	0
676084	671035	20034V	PARTICIPANT	\N	PRESENT	0
676087	671035	14030Q	PARTICIPANT	\N	PRESENT	0
676091	671035	14071N	PARTICIPANT	\N	PRESENT	0
676092	671035	19569H	PARTICIPANT	\N	PRESENT	0
676093	671035	20100N	PARTICIPANT	\N	PRESENT	0
676094	671035	20914V	PARTICIPANT	\N	PRESENT	0
676095	671035	20266L	PARTICIPANT	\N	PRESENT	0
676096	671035	19349W	PARTICIPANT	\N	PRESENT	0
676097	671035	19399H	PARTICIPANT	\N	PRESENT	0
676098	671035	19545Y	PARTICIPANT	\N	PRESENT	0
676099	671035	19741B	PARTICIPANT	\N	PRESENT	0
676109	671035	17779H	PARTICIPANT	\N	PRESENT	0
676110	671035	20036X	PARTICIPANT	\N	PRESENT	0
676160	671036	19679N	PARTICIPANT	\N	PRESENT	0
676161	671036	10006L	PARTICIPANT	\N	PRESENT	0
676162	671036	11067R	PARTICIPANT	\N	PRESENT	0
676163	671036	18193Q	PARTICIPANT	\N	PRESENT	0
676164	671036	17779H	PARTICIPANT	\N	PRESENT	0
676165	671036	20130U	PARTICIPANT	\N	PRESENT	0
676166	671036	19347U	PARTICIPANT	\N	PRESENT	0
676167	671036	20134Y	PARTICIPANT	\N	PRESENT	0
676168	671036	20036X	PARTICIPANT	\N	PRESENT	0
676169	671036	14249W	PARTICIPANT	\N	PRESENT	0
676170	671036	19479G	PARTICIPANT	\N	PRESENT	0
676171	671036	14030Q	PARTICIPANT	\N	PRESENT	0
676172	671036	19569H	PARTICIPANT	\N	PRESENT	0
676173	671036	19866P	PARTICIPANT	\N	PRESENT	0
676174	671036	19545Y	PARTICIPANT	\N	PRESENT	0
676175	671036	19697Q	PARTICIPANT	\N	PRESENT	0
676176	671036	14217N	PARTICIPANT	\N	PRESENT	0
676177	671036	11097X	PARTICIPANT	\N	PRESENT	0
676178	671036	14133K	PARTICIPANT	\N	PRESENT	0
676179	671036	19798U	PARTICIPANT	\N	PRESENT	0
676180	671036	19467C	PARTICIPANT	\N	PRESENT	0
676181	671036	19693L	PARTICIPANT	\N	PRESENT	0
676182	671036	14069U	PARTICIPANT	\N	PRESENT	0
676183	671036	20034V	PARTICIPANT	\N	PRESENT	0
676184	671036	14213J	PARTICIPANT	\N	PRESENT	0
676185	671036	01048V	PARTICIPANT	\N	PRESENT	0
676186	671036	14021P	PARTICIPANT	\N	PRESENT	0
676187	671036	11031D	PARTICIPANT	\N	PRESENT	0
676326	676320	14033T	PARTICIPANT	\N	PRESENT	0
676327	676321	14033T	PARTICIPANT	\N	PRESENT	0
676328	676322	14033T	PARTICIPANT	\N	PRESENT	0
676329	676323	14033T	PARTICIPANT	\N	PRESENT	0
676330	676324	14033T	PARTICIPANT	\N	PRESENT	0
676335	676334	14133K	PARTICIPANT	\N	PRESENT	0
676545	671041	11070L	PARTICIPANT	\N	PRESENT	0
676546	671041	20148F	PARTICIPANT	\N	PRESENT	0
676547	671041	99004R	PARTICIPANT	\N	PRESENT	0
676548	671041	19515S	PARTICIPANT	\N	PRESENT	0
676549	671041	19711U	PARTICIPANT	\N	PRESENT	0
676550	671041	19295A	PARTICIPANT	\N	PRESENT	0
676551	671041	19741B	PARTICIPANT	\N	PRESENT	0
676552	671041	11040E	PARTICIPANT	\N	PRESENT	0
676553	671041	07029T	PARTICIPANT	\N	PRESENT	0
676554	671041	20070A	PARTICIPANT	\N	PRESENT	0
676555	671041	19479G	PARTICIPANT	\N	PRESENT	0
676556	671041	11074Q	PARTICIPANT	\N	PRESENT	0
676158	671036	14026U	PARTICIPANT	\N	PRESENT	0
676159	671036	04085P	PARTICIPANT	\N	PRESENT	0
676557	671041	11072N	PARTICIPANT	\N	PRESENT	0
676558	671041	20044X	PARTICIPANT	\N	PRESENT	0
676559	671041	19525U	PARTICIPANT	\N	PRESENT	0
676560	671041	20914V	PARTICIPANT	\N	PRESENT	0
676561	671041	19657G	PARTICIPANT	\N	PRESENT	0
676562	671041	20130U	PARTICIPANT	\N	PRESENT	0
676563	671041	19301E	PARTICIPANT	\N	PRESENT	0
676565	671041	11012A	PARTICIPANT	\N	PRESENT	0
676566	671041	14191V	PARTICIPANT	\N	PRESENT	0
676567	671041	19593H	PARTICIPANT	\N	PRESENT	0
676568	671041	20050V	PARTICIPANT	\N	PRESENT	0
676569	671041	14327T	PARTICIPANT	\N	PRESENT	0
676570	671041	11048N	PARTICIPANT	\N	PRESENT	0
676571	671041	14225N	PARTICIPANT	\N	PRESENT	0
676572	671041	20112S	PARTICIPANT	\N	PRESENT	0
676573	671041	14083S	PARTICIPANT	\N	PRESENT	0
676574	671041	19693L	PARTICIPANT	\N	PRESENT	0
676575	671041	20034V	PARTICIPANT	\N	PRESENT	0
658140	658131	19631V	PARTICIPANT	\N	PRESENT	0
658136	658131	14109K	PARTICIPANT	\N	PRESENT	0
658138	658131	20028X	PARTICIPANT	\N	PRESENT	0
658142	658131	14059S	PARTICIPANT	\N	PRESENT	0
659171	659170	14033T	PARTICIPANT	\N	PRESENT	0
659172	659170	20054A	PARTICIPANT	\N	PRESENT	0
659176	659170	14205J	PARTICIPANT	\N	PRESENT	0
659178	659170	14189C	PARTICIPANT	\N	PRESENT	0
659179	659170	19723Y	PARTICIPANT	\N	PRESENT	0
659181	659170	20118Y	PARTICIPANT	\N	PRESENT	0
659184	659170	16685X	PARTICIPANT	\N	PRESENT	0
659185	659170	20044X	PARTICIPANT	\N	PRESENT	0
659186	659170	20082E	PARTICIPANT	\N	PRESENT	0
659187	659170	19563B	PARTICIPANT	\N	PRESENT	0
659188	659170	11097X	PARTICIPANT	\N	PRESENT	0
659189	659170	04045F	PARTICIPANT	\N	PRESENT	0
659191	659190	20144B	PARTICIPANT	\N	PRESENT	0
659192	659190	14033T	PARTICIPANT	\N	PRESENT	0
659194	659190	11070L	PARTICIPANT	\N	PRESENT	0
659195	659190	19721W	PARTICIPANT	\N	PRESENT	0
659196	659190	19563B	PARTICIPANT	\N	PRESENT	0
659197	659190	01024M	PARTICIPANT	\N	PRESENT	0
659198	659190	14257W	PARTICIPANT	\N	PRESENT	0
659271	659269	11070L	PARTICIPANT	\N	PRESENT	0
659272	659269	19647E	PARTICIPANT	\N	PRESENT	0
659276	659275	19531S	PARTICIPANT	\N	PRESENT	0
659277	659275	19762G	PARTICIPANT	\N	PRESENT	0
659279	659278	04071H	PARTICIPANT	\N	PRESENT	0
661548	659409	20034V	PARTICIPANT	\N	PRESENT	0
661549	659409	19715Y	PARTICIPANT	\N	PRESENT	0
661550	659409	14097Y	PARTICIPANT	\N	PRESENT	0
661551	659409	14059S	PARTICIPANT	\N	PRESENT	0
661552	659409	12016W	PARTICIPANT	\N	PRESENT	0
661553	659409	19657G	PARTICIPANT	\N	PRESENT	0
661554	659409	14147R	PARTICIPANT	\N	PRESENT	0
661555	659409	19301E	PARTICIPANT	\N	PRESENT	0
661556	659409	14331P	PARTICIPANT	\N	EXCUSE	0
661601	656811	14173T	PARTICIPANT	\N	PRESENT	0
661603	661602	19479G	PARTICIPANT	\N	PRESENT	0
661652	661650	19701S	PARTICIPANT	\N	PRESENT	0
661654	661650	19681G	PARTICIPANT	\N	PRESENT	0
661655	661650	20100N	PARTICIPANT	\N	PRESENT	0
661656	661650	14033T	PARTICIPANT	\N	PRESENT	0
661657	661650	19333N	PARTICIPANT	\N	PRESENT	0
661658	661650	14073Q	PARTICIPANT	\N	PRESENT	0
661659	661650	12041X	PARTICIPANT	\N	PRESENT	0
661661	661650	19441R	PARTICIPANT	\N	PRESENT	0
661664	661650	14331P	PRESIDENT	0	PRESENT	0
661665	661650	10015M	PARTICIPANT	\N	PRESENT	0
661666	661650	20098N	PARTICIPANT	\N	PRESENT	0
661667	661650	04045F	PARTICIPANT	\N	PRESENT	0
661668	661650	04070G	PARTICIPANT	\N	EXCUSE	0
661932	661931	19729F	PARTICIPANT	\N	PRESENT	0
662091	661238	19683J	PARTICIPANT	\N	PRESENT	0
662092	661238	14195A	PARTICIPANT	\N	PRESENT	0
662093	661238	14213J	PARTICIPANT	\N	PRESENT	0
662094	661238	10006L	PRESIDENT	0	PRESENT	0
662095	661238	14071N	PARTICIPANT	\N	PRESENT	0
662101	661238	19329S	PARTICIPANT	\N	PRESENT	0
662114	661238	14217N	PARTICIPANT	\N	PRESENT	0
662116	661238	19798U	PARTICIPANT	\N	PRESENT	0
662119	661238	20090E	PARTICIPANT	\N	PRESENT	0
662121	661238	14223L	PARTICIPANT	\N	PRESENT	0
662123	661238	19569H	PARTICIPANT	\N	PRESENT	0
662126	661238	20248J	PARTICIPANT	\N	PRESENT	0
662129	661238	14042U	PARTICIPANT	\N	PRESENT	0
662130	661238	20066E	PARTICIPANT	\N	PRESENT	0
662131	661238	11067R	PARTICIPANT	\N	PRESENT	0
662132	661238	17965H	PARTICIPANT	\N	PRESENT	0
662133	661238	19713W	PARTICIPANT	\N	PRESENT	0
662134	661238	19703U	PARTICIPANT	\N	PRESENT	0
662135	661238	19723Y	PARTICIPANT	\N	PRESENT	0
662136	661238	08045X	PARTICIPANT	\N	PRESENT	0
662137	661238	14355X	PARTICIPANT	\N	PRESENT	0
662138	661238	20130U	PARTICIPANT	\N	PRESENT	0
662139	661238	18193Q	PARTICIPANT	\N	PRESENT	0
662140	661238	19657G	PARTICIPANT	\N	PRESENT	0
662141	661238	14026U	PARTICIPANT	\N	PRESENT	0
662142	661238	19553Y	PARTICIPANT	\N	PRESENT	0
662143	661238	04057K	PARTICIPANT	\N	PRESENT	0
662144	661238	19679N	PARTICIPANT	\N	PRESENT	0
662145	661238	11097X	PARTICIPANT	\N	PRESENT	0
662146	661238	04092N	PARTICIPANT	\N	PRESENT	0
662147	661238	19760E	PARTICIPANT	\N	PRESENT	0
663272	659561	19333N	PARTICIPANT	\N	PRESENT	0
663273	659561	14031R	PARTICIPANT	\N	PRESENT	0
663274	659561	20140W	PARTICIPANT	\N	PRESENT	0
663275	659561	20076G	PARTICIPANT	\N	PRESENT	0
663276	659561	19387D	PARTICIPANT	\N	PRESENT	0
663277	659561	19251M	PARTICIPANT	\N	PRESENT	0
663278	659561	14219Q	PRESIDENT	0	PRESENT	0
663279	659561	20046A	PARTICIPANT	\N	PRESENT	0
663280	659561	19599P	PARTICIPANT	\N	PRESENT	0
663281	659561	20102Q	PARTICIPANT	\N	PRESENT	0
663282	659561	19637C	PARTICIPANT	\N	PRESENT	0
663283	659561	18083K	PARTICIPANT	\N	PRESENT	0
663284	659561	14237S	PARTICIPANT	\N	PRESENT	0
663285	659561	08060W	PARTICIPANT	\N	PRESENT	0
663286	659561	20068G	PARTICIPANT	\N	PRESENT	0
663287	659561	19503N	PARTICIPANT	\N	PRESENT	0
663288	659561	19739H	PARTICIPANT	\N	PRESENT	0
663289	659561	20024T	PARTICIPANT	\N	PRESENT	0
663290	659561	19619A	PARTICIPANT	\N	PRESENT	0
663291	659561	19549D	PARTICIPANT	\N	PRESENT	0
663292	659561	11101A	PARTICIPANT	\N	PRESENT	0
663293	659561	19551W	PARTICIPANT	\N	EXCUSE	0
663294	659561	19745F	PARTICIPANT	\N	EXCUSE	0
663295	659561	14221J	PARTICIPANT	\N	PRESENT	0
663296	659561	19826F	PARTICIPANT	\N	PRESENT	0
663297	659561	05012A	PARTICIPANT	\N	PRESENT	0
663298	659561	20100N	PARTICIPANT	\N	PRESENT	0
663306	659561	17229F	PARTICIPANT	\N	PRESENT	0
663327	659561	20144B	PARTICIPANT	\N	PRESENT	0
663328	661262	11048N	PARTICIPANT	\N	EXCUSE	0
663329	661262	14225N	PARTICIPANT	\N	EXCUSE	0
663331	659561	11065P	PARTICIPANT	\N	PRESENT	0
663332	659561	20118Y	PARTICIPANT	\N	PRESENT	0
663333	661262	11040E	PARTICIPANT	\N	PRESENT	0
663334	661262	14327T	PRESIDENT	0	PRESENT	0
663335	661262	07029T	PARTICIPANT	\N	PRESENT	0
663336	661262	19647E	PARTICIPANT	\N	PRESENT	0
663337	661262	19687N	PARTICIPANT	\N	PRESENT	0
663338	661262	19349W	PARTICIPANT	\N	PRESENT	0
663339	661262	12016W	PARTICIPANT	\N	PRESENT	0
663340	661262	20050V	PARTICIPANT	\N	PRESENT	0
663341	661262	20914V	PARTICIPANT	\N	PRESENT	0
663342	661262	20116W	PARTICIPANT	\N	PRESENT	0
663343	661262	08011M	PARTICIPANT	\N	PRESENT	0
663344	661262	19762G	PARTICIPANT	\N	PRESENT	0
663347	661262	14331P	PARTICIPANT	\N	PRESENT	0
663348	661262	99004R	PARTICIPANT	\N	PRESENT	0
663349	661262	14253S	PARTICIPANT	\N	PRESENT	0
663351	659561	19701S	PARTICIPANT	\N	PRESENT	0
663354	661262	20086J	PARTICIPANT	\N	PRESENT	0
663355	661262	19545Y	PARTICIPANT	\N	PRESENT	0
663356	661262	01057W	PARTICIPANT	\N	PRESENT	0
663357	661262	19671E	PARTICIPANT	\N	PRESENT	0
663358	661262	19575F	PARTICIPANT	\N	PRESENT	0
663359	661262	19335Q	PARTICIPANT	\N	PRESENT	0
663360	661262	19479G	PARTICIPANT	\N	PRESENT	0
663361	661262	19711U	PARTICIPANT	\N	PRESENT	0
663362	661262	20036X	PARTICIPANT	\N	PRESENT	0
663363	661262	19531S	PARTICIPANT	\N	PRESENT	0
663364	661262	20044X	PARTICIPANT	\N	PRESENT	0
663365	661262	14173T	PARTICIPANT	\N	PRESENT	0
663366	661262	14083S	PARTICIPANT	\N	PRESENT	0
663367	661262	19741B	PARTICIPANT	\N	PRESENT	0
663369	661262	08009T	PARTICIPANT	\N	PRESENT	0
663370	661262	14121F	PARTICIPANT	\N	PRESENT	0
663371	661262	11053K	PARTICIPANT	\N	PRESENT	0
663373	661262	20070A	PARTICIPANT	\N	PRESENT	0
663376	659561	19525U	PARTICIPANT	\N	PRESENT	0
663380	661262	20080C	PARTICIPANT	\N	PRESENT	0
663381	661262	11012A	PARTICIPANT	\N	PRESENT	0
663382	660362	04070G	PARTICIPANT	\N	PRESENT	0
663383	660362	19699S	PARTICIPANT	\N	PRESENT	0
663384	660362	19533U	PARTICIPANT	\N	PRESENT	0
663385	660362	14229S	PARTICIPANT	\N	PRESENT	0
663386	660362	20098N	PARTICIPANT	\N	PRESENT	0
663387	660362	19573D	PARTICIPANT	\N	PRESENT	0
672168	669897	10006L	PARTICIPANT	\N	PRESENT	0
672169	669897	19575F	PARTICIPANT	\N	PRESENT	0
672170	669897	04085P	PARTICIPANT	\N	PRESENT	0
672171	669897	14053L	PARTICIPANT	\N	PRESENT	0
672172	669897	19663E	PARTICIPANT	\N	PRESENT	0
672173	669897	14217N	PARTICIPANT	\N	PRESENT	0
672174	669897	20094J	PARTICIPANT	\N	PRESENT	0
672175	669897	14281W	PARTICIPANT	\N	PRESENT	0
672176	669897	19347U	PARTICIPANT	\N	PRESENT	0
672177	669897	04043D	PARTICIPANT	\N	PRESENT	0
672178	669897	14215L	PARTICIPANT	\N	PRESENT	0
672179	669897	19762G	PARTICIPANT	\N	PRESENT	0
672180	669897	20080C	PARTICIPANT	\N	PRESENT	0
672181	669897	20086J	PARTICIPANT	\N	PRESENT	0
672182	669897	19758L	PARTICIPANT	\N	PRESENT	0
672183	669897	20092G	PARTICIPANT	\N	PRESENT	0
672184	669897	20100N	PARTICIPANT	\N	PRESENT	0
672185	669897	19747H	PARTICIPANT	\N	PRESENT	0
672186	669897	14231L	PARTICIPANT	\N	PRESENT	0
672187	669897	19593H	PARTICIPANT	\N	PRESENT	0
672188	669897	19565D	PARTICIPANT	\N	PRESENT	0
672189	669897	19760E	PARTICIPANT	\N	PRESENT	0
672190	669897	08045X	PARTICIPANT	\N	PRESENT	0
672191	669897	20090E	PARTICIPANT	\N	PRESENT	0
672192	669897	20122U	PARTICIPANT	\N	PRESENT	0
672193	669897	14331P	PARTICIPANT	\N	PRESENT	0
672194	669897	08010L	PARTICIPANT	\N	PRESENT	0
672195	669897	19673G	PARTICIPANT	\N	PRESENT	0
672196	669897	14187A	PARTICIPANT	\N	PRESENT	0
672197	669897	19507S	PARTICIPANT	\N	PRESENT	0
672198	669897	19703U	PARTICIPANT	\N	PRESENT	0
672199	669897	14069U	PARTICIPANT	\N	PRESENT	0
672200	669897	20052X	PARTICIPANT	\N	PRESENT	0
672201	669897	20266L	PARTICIPANT	\N	PRESENT	0
672202	669897	11048N	PARTICIPANT	\N	PRESENT	0
672203	669897	14357A	PARTICIPANT	\N	PRESENT	0
672204	669897	17637T	PARTICIPANT	\N	PRESENT	0
672205	669897	01028R	PARTICIPANT	\N	PRESENT	0
672206	669897	14026U	PARTICIPANT	\N	PRESENT	0
672207	669897	20032T	PARTICIPANT	\N	PRESENT	0
672208	669897	19741B	PARTICIPANT	\N	PRESENT	0
672209	669897	19531S	PARTICIPANT	\N	PRESENT	0
672210	669897	20128B	PARTICIPANT	\N	PRESENT	0
672211	669897	20110Q	PARTICIPANT	\N	PRESENT	0
672212	669897	14021P	PARTICIPANT	\N	PRESENT	0
672213	669897	10015M	PARTICIPANT	\N	PRESENT	0
672214	669897	11077T	PARTICIPANT	\N	PRESENT	0
672215	669897	19647E	PARTICIPANT	\N	PRESENT	0
672216	669897	08015R	PARTICIPANT	\N	PRESENT	0
672217	669897	20058E	PARTICIPANT	\N	PRESENT	0
672218	669897	04045F	PARTICIPANT	\N	PRESENT	0
672219	669897	20082E	PARTICIPANT	\N	PRESENT	0
672220	669897	19591F	PARTICIPANT	\N	PRESENT	0
672221	669897	14083S	PARTICIPANT	\N	PRESENT	0
672266	671830	19762G	PARTICIPANT	\N	PRESENT	0
672286	671830	19515S	PARTICIPANT	\N	PRESENT	0
672287	671830	20094J	PARTICIPANT	\N	PRESENT	0
672288	671830	20078J	PARTICIPANT	\N	EXCUSE	0
672289	671830	19631V	PARTICIPANT	\N	EXCUSE	0
672290	671830	20088L	PARTICIPANT	\N	PRESENT	0
672291	671830	19747H	PARTICIPANT	\N	PRESENT	0
672292	671830	19782L	PARTICIPANT	\N	PRESENT	0
672293	671830	14207L	PARTICIPANT	\N	PRESENT	0
672294	671830	20060X	PARTICIPANT	\N	PRESENT	0
672295	671830	14329V	PARTICIPANT	\N	PRESENT	0
672296	671830	14038Y	PARTICIPANT	\N	PRESENT	0
672297	671830	20144B	PARTICIPANT	\N	PRESENT	0
672298	671830	19467C	PARTICIPANT	\N	PRESENT	0
672299	671830	14357A	PARTICIPANT	\N	PRESENT	0
672300	671830	19507S	PARTICIPANT	\N	PRESENT	0
672301	671830	14187A	PARTICIPANT	\N	PRESENT	0
672302	671830	01025N	PARTICIPANT	\N	PRESENT	0
672303	671830	20286Q	PARTICIPANT	\N	PRESENT	0
672304	671830	19695N	PARTICIPANT	\N	PRESENT	0
672309	671830	20034V	PARTICIPANT	\N	PRESENT	0
672424	672422	19369B	PARTICIPANT	\N	PRESENT	0
672426	672425	19369B	PARTICIPANT	\N	PRESENT	0
672429	672428	19369B	PARTICIPANT	\N	PRESENT	0
672440	672438	19631V	PARTICIPANT	\N	PRESENT	0
672792	672791	19629C	PARTICIPANT	\N	PRESENT	0
672793	672791	04045F	PARTICIPANT	\N	PRESENT	0
672794	672791	14097Y	PARTICIPANT	\N	PRESENT	0
672795	672791	19631V	PARTICIPANT	\N	PRESENT	0
672796	672791	20090E	PARTICIPANT	\N	PRESENT	0
672798	672797	19515S	PARTICIPANT	\N	PRESENT	0
672802	672801	05008E	PARTICIPANT	\N	PRESENT	0
672803	672801	11053K	PARTICIPANT	\N	PRESENT	0
672804	672801	01028R	PARTICIPANT	\N	PRESENT	0
672824	672812	20066E	PARTICIPANT	\N	PRESENT	0
672825	672812	19657G	PARTICIPANT	\N	PRESENT	0
672826	672812	19663E	PARTICIPANT	\N	PRESENT	0
672827	672812	04057K	PARTICIPANT	\N	PRESENT	0
672828	672812	19713W	PARTICIPANT	\N	PRESENT	0
672829	672812	19723Y	PARTICIPANT	\N	PRESENT	0
672830	672812	19691J	PARTICIPANT	\N	PRESENT	0
672831	672812	14026U	PARTICIPANT	\N	PRESENT	0
672832	672812	14042U	PARTICIPANT	\N	PRESENT	0
672833	672812	19569H	PARTICIPANT	\N	PRESENT	0
672834	672812	01034P	PARTICIPANT	\N	PRESENT	0
672838	672836	11026G	PARTICIPANT	\N	PRESENT	0
672972	672570	99004R	PARTICIPANT	\N	PRESENT	0
672973	672570	19335Q	PARTICIPANT	\N	PRESENT	0
672974	672260	14053L	PARTICIPANT	\N	PRESENT	0
672975	672260	19585H	PARTICIPANT	\N	PRESENT	0
672976	672260	01028R	PARTICIPANT	\N	PRESENT	0
672977	672260	19629C	PARTICIPANT	\N	PRESENT	0
672978	672260	20114U	PARTICIPANT	\N	PRESENT	0
672979	672260	14069U	PARTICIPANT	\N	PRESENT	0
672980	672260	14151M	PARTICIPANT	\N	PRESENT	0
672981	672260	14259Y	PARTICIPANT	\N	PRESENT	0
672982	672260	11072N	PARTICIPANT	\N	PRESENT	0
672983	672260	19729F	PARTICIPANT	\N	EXCUSE	0
672984	672260	14021P	PARTICIPANT	\N	EXCUSE	0
672987	672570	11040E	PARTICIPANT	\N	PRESENT	0
672993	672260	19581D	PARTICIPANT	\N	PRESENT	0
672994	672260	14231L	PARTICIPANT	\N	PRESENT	0
672999	670786	04070G	PARTICIPANT	\N	PRESENT	0
673000	670786	19533U	PARTICIPANT	\N	PRESENT	0
673001	670786	14229S	PARTICIPANT	\N	PRESENT	0
673002	670786	20098N	PARTICIPANT	\N	PRESENT	0
673003	670786	19573D	PARTICIPANT	\N	PRESENT	0
673004	670786	08012N	PARTICIPANT	\N	PRESENT	0
673005	670786	20124W	PARTICIPANT	\N	PRESENT	0
673006	670786	20026V	PARTICIPANT	\N	PRESENT	0
673007	670786	19593H	PARTICIPANT	\N	PRESENT	0
673008	670786	20132W	PARTICIPANT	\N	PRESENT	0
673009	670786	19643A	PARTICIPANT	\N	PRESENT	0
673010	670786	20134Y	PARTICIPANT	\N	PRESENT	0
673011	670786	19611R	PRESIDENT	0	PRESENT	0
673012	670786	20138D	PARTICIPANT	\N	PRESENT	0
673013	670786	20142Y	PARTICIPANT	\N	PRESENT	0
673014	670786	20048C	PARTICIPANT	\N	PRESENT	0
673015	670786	19693L	PARTICIPANT	\N	PRESENT	0
673016	670786	14030Q	PARTICIPANT	\N	PRESENT	0
673017	670786	20056C	PARTICIPANT	\N	PRESENT	0
673018	670786	20180F	PARTICIPANT	\N	PRESENT	0
673019	670786	19735D	PARTICIPANT	\N	PRESENT	0
673020	670786	14109K	PARTICIPANT	\N	PRESENT	0
673021	670786	14123H	PARTICIPANT	\N	PRESENT	0
673022	670786	11104D	PARTICIPANT	\N	PRESENT	0
673023	670786	19758L	PARTICIPANT	\N	PRESENT	0
673024	670786	20084G	PARTICIPANT	\N	PRESENT	0
673025	670786	19621T	PARTICIPANT	\N	PRESENT	0
673026	672260	14179A	PARTICIPANT	\N	PRESENT	0
673032	672997	86034E	PARTICIPANT	\N	PRESENT	0
673033	672997	19367Y	PARTICIPANT	\N	PRESENT	0
673035	672997	19866P	PARTICIPANT	\N	PRESENT	0
673036	672997	19685L	PARTICIPANT	\N	PRESENT	0
673037	672997	19683J	PARTICIPANT	\N	PRESENT	0
673038	672997	19629C	PARTICIPANT	\N	PRESENT	0
673039	672997	14191V	PARTICIPANT	\N	PRESENT	0
673040	672997	19703U	PARTICIPANT	\N	PRESENT	0
673041	672997	20040T	PARTICIPANT	\N	PRESENT	0
673042	672997	20074E	PARTICIPANT	\N	PRESENT	0
673043	672997	20100N	PARTICIPANT	\N	PRESENT	0
673044	672997	14275Y	PARTICIPANT	\N	PRESENT	0
673045	672997	19515S	PARTICIPANT	\N	PRESENT	0
673046	672997	19593H	PARTICIPANT	\N	PRESENT	0
673048	672997	14107H	PARTICIPANT	\N	PRESENT	0
673055	672997	14071N	PARTICIPANT	\N	PRESENT	0
673057	672997	19681G	PARTICIPANT	\N	PRESENT	0
656043	656037	20130U	PARTICIPANT	\N	PRESENT	0
656044	656038	20130U	PARTICIPANT	\N	PRESENT	0
656045	656039	20130U	PARTICIPANT	\N	PRESENT	0
656047	656040	20130U	PARTICIPANT	\N	PRESENT	0
656048	656041	20130U	PARTICIPANT	\N	PRESENT	0
656098	655678	14030Q	PARTICIPANT	\N	PRESENT	0
656099	655678	20138D	PARTICIPANT	\N	PRESENT	0
656100	655678	19643A	PARTICIPANT	\N	PRESENT	0
656101	655678	20152B	PARTICIPANT	\N	PRESENT	0
656102	655678	20264J	PARTICIPANT	\N	PRESENT	0
656103	655678	20134Y	PARTICIPANT	\N	PRESENT	0
656104	655678	20132W	PARTICIPANT	\N	PRESENT	0
656105	655678	20048C	PARTICIPANT	\N	PRESENT	0
656106	655678	14073Q	PARTICIPANT	\N	PRESENT	0
656107	655678	19735D	PARTICIPANT	\N	PRESENT	0
656108	655678	19611R	PARTICIPANT	\N	PRESENT	0
656109	655678	19699S	PARTICIPANT	\N	PRESENT	0
656110	655678	20052X	PARTICIPANT	\N	PRESENT	0
656111	655678	04070G	PARTICIPANT	\N	PRESENT	0
656112	655678	19573D	PARTICIPANT	\N	PRESENT	0
656113	655678	19533U	PARTICIPANT	\N	PRESENT	0
656114	655678	14229S	PARTICIPANT	\N	PRESENT	0
656115	655678	20084G	PARTICIPANT	\N	PRESENT	0
656158	656157	20044X	PARTICIPANT	\N	EXCUSE	0
656162	656161	14133K	PARTICIPANT	\N	PRESENT	0
656163	656161	11066Q	PARTICIPANT	\N	PRESENT	0
656165	656164	14255U	PARTICIPANT	\N	PRESENT	0
656170	656157	19551W	PARTICIPANT	\N	EXCUSE	0
656171	656157	19711U	PARTICIPANT	\N	EXCUSE	0
656172	656157	14193X	PARTICIPANT	\N	EXCUSE	0
656176	656157	20050V	PARTICIPANT	\N	EXCUSE	0
656428	656063	20032T	PARTICIPANT	\N	PRESENT	0
656429	656063	20038A	PARTICIPANT	\N	PRESENT	0
656430	656063	14031R	PARTICIPANT	\N	PRESENT	0
656431	656063	20140W	PARTICIPANT	\N	PRESENT	0
656432	656063	19387D	PARTICIPANT	\N	PRESENT	0
656433	656063	19820Y	PARTICIPANT	\N	PRESENT	0
656434	656063	14219Q	PRESIDENT	0	PRESENT	0
656435	656063	19826F	PARTICIPANT	\N	PRESENT	0
656436	656063	20102Q	PARTICIPANT	\N	PRESENT	0
656437	656063	19599P	PARTICIPANT	\N	PRESENT	0
656438	656063	20096L	PARTICIPANT	\N	PRESENT	0
656439	656063	19637C	PARTICIPANT	\N	PRESENT	0
656440	656063	18083K	PARTICIPANT	\N	PRESENT	0
656441	656063	14237S	PARTICIPANT	\N	PRESENT	0
656442	656063	08060W	PARTICIPANT	\N	PRESENT	0
656443	656063	19739H	PARTICIPANT	\N	PRESENT	0
656444	656063	19745F	PARTICIPANT	\N	PRESENT	0
656445	656063	19681G	PARTICIPANT	\N	PRESENT	0
656446	656063	20024T	PARTICIPANT	\N	PRESENT	0
656458	656046	14205J	PARTICIPANT	\N	PRESENT	0
656459	656046	11048N	PARTICIPANT	\N	PRESENT	0
656460	656046	14225N	PRESIDENT	0	PRESENT	0
656461	656046	11012A	PARTICIPANT	\N	EXCUSE	0
656462	656046	08034U	PARTICIPANT	\N	EXCUSE	0
656463	656046	14189C	PARTICIPANT	\N	EXCUSE	0
656464	656046	20050V	PARTICIPANT	\N	EXCUSE	0
665658	665149	11085T	PARTICIPANT	\N	PRESENT	0
665661	665149	20022R	PARTICIPANT	\N	PRESENT	0
665665	665149	14105F	PARTICIPANT	\N	PRESENT	0
665668	664322	14189C	PARTICIPANT	\N	PRESENT	0
665669	664322	99004R	PARTICIPANT	\N	PRESENT	0
665670	664322	14253S	PARTICIPANT	\N	PRESENT	0
665671	664322	14169X	PARTICIPANT	\N	PRESENT	0
665672	665149	14073Q	PARTICIPANT	\N	PRESENT	0
665673	665149	20248J	PARTICIPANT	\N	PRESENT	0
665674	665149	20026V	PARTICIPANT	\N	PRESENT	0
665675	665149	20114U	PARTICIPANT	\N	PRESENT	0
665676	665149	20020P	PARTICIPANT	\N	PRESENT	0
665677	665149	19543W	PARTICIPANT	\N	PRESENT	0
665678	664322	19711U	PARTICIPANT	\N	PRESENT	0
665679	664322	20044X	PARTICIPANT	\N	PRESENT	0
665680	664322	11040E	PARTICIPANT	\N	PRESENT	0
665681	664322	14083S	PARTICIPANT	\N	PRESENT	0
665682	664322	11012A	PARTICIPANT	\N	PRESENT	0
665683	664322	19349W	PARTICIPANT	\N	PRESENT	0
665684	664322	19335Q	PARTICIPANT	\N	PRESENT	0
665685	664322	08010L	PARTICIPANT	\N	PRESENT	0
665686	665149	14187A	PARTICIPANT	\N	PRESENT	0
665687	665149	20030R	PARTICIPANT	\N	PRESENT	0
665688	665149	14223L	PARTICIPANT	\N	PRESENT	0
665689	665149	11077T	PARTICIPANT	\N	PRESENT	0
665690	665149	20180F	PARTICIPANT	\N	PRESENT	0
665691	665149	01025N	PARTICIPANT	\N	PRESENT	0
665692	664322	19479G	PARTICIPANT	\N	PRESENT	0
665693	665149	19575F	PARTICIPANT	\N	PRESENT	0
665694	665149	14257W	PARTICIPANT	\N	PRESENT	0
665695	664322	19647E	PARTICIPANT	\N	PRESENT	0
665696	664322	19741B	PARTICIPANT	\N	PRESENT	0
665697	664322	20914V	PARTICIPANT	\N	PRESENT	0
665698	664322	20126Y	PARTICIPANT	\N	PRESENT	0
665699	665149	19691J	PARTICIPANT	\N	PRESENT	0
665877	665379	14207L	PARTICIPANT	\N	EXCUSE	0
665701	665149	19581D	PARTICIPANT	\N	PRESENT	0
665702	664322	20080C	PARTICIPANT	\N	PRESENT	0
665878	664672	14069U	PARTICIPANT	\N	PRESENT	0
665879	665149	10015M	PARTICIPANT	\N	PRESENT	0
665880	665149	19762G	PARTICIPANT	\N	PRESENT	0
665881	665149	17367Q	PARTICIPANT	\N	PRESENT	0
665882	665149	20252E	PARTICIPANT	\N	PRESENT	0
665883	665149	20116W	PARTICIPANT	\N	PRESENT	0
665886	665149	20122U	PARTICIPANT	\N	PRESENT	0
665887	665149	20044X	PARTICIPANT	\N	PRESENT	0
665888	665149	19479G	PARTICIPANT	\N	PRESENT	0
665892	663456	20142Y	PARTICIPANT	\N	PRESENT	0
665893	663456	20084G	PARTICIPANT	\N	PRESENT	0
665894	665149	11053K	PARTICIPANT	\N	PRESENT	0
665895	665149	19713W	PARTICIPANT	\N	PRESENT	0
665896	665149	01058X	PARTICIPANT	\N	PRESENT	0
665897	665149	07029T	PARTICIPANT	\N	PRESENT	0
665903	665149	20120S	PARTICIPANT	\N	PRESENT	0
665906	663457	19593H	PARTICIPANT	\N	PRESENT	0
665907	663457	20132W	PARTICIPANT	\N	PRESENT	0
665908	663457	04070G	PARTICIPANT	\N	PRESENT	0
665909	663457	19643A	PARTICIPANT	\N	PRESENT	0
665910	663457	19699S	PARTICIPANT	\N	PRESENT	0
665911	663457	19651A	PARTICIPANT	\N	PRESENT	0
665912	663457	19611R	PRESIDENT	0	PRESENT	0
665913	663457	20142Y	PARTICIPANT	\N	PRESENT	0
665914	663457	19399H	PARTICIPANT	\N	PRESENT	0
665915	663457	20052X	PARTICIPANT	\N	PRESENT	0
665916	663457	14229S	PARTICIPANT	\N	PRESENT	0
665917	663457	20058E	PARTICIPANT	\N	PRESENT	0
665918	663457	20056C	PARTICIPANT	\N	PRESENT	0
665919	663457	20180F	PARTICIPANT	\N	PRESENT	0
665920	663457	04059M	PARTICIPANT	\N	PRESENT	0
665921	663457	14109K	PARTICIPANT	\N	PRESENT	0
665922	663457	20112S	PARTICIPANT	\N	PRESENT	0
665923	663457	08012N	PARTICIPANT	\N	PRESENT	0
665924	663457	11104D	PARTICIPANT	\N	PRESENT	0
665925	663457	20124W	PARTICIPANT	\N	PRESENT	0
665926	663457	20026V	PARTICIPANT	\N	PRESENT	0
665927	663457	19621T	PARTICIPANT	\N	PRESENT	0
665928	663457	20084G	PARTICIPANT	\N	PRESENT	0
665935	665379	19383Y	PARTICIPANT	\N	PRESENT	0
665936	665379	14205J	PARTICIPANT	\N	PRESENT	0
676576	671041	19577H	PARTICIPANT	\N	PRESENT	0
676577	671041	19531S	PARTICIPANT	\N	PRESENT	0
676578	671041	19715Y	PARTICIPANT	\N	PRESENT	0
676579	671041	14257W	PARTICIPANT	\N	PRESENT	0
676580	671041	20080C	PARTICIPANT	\N	PRESENT	0
676581	671041	19647E	PARTICIPANT	\N	PRESENT	0
676582	671041	19713W	PARTICIPANT	\N	PRESENT	0
676583	671041	20134Y	PARTICIPANT	\N	PRESENT	0
676584	671041	20036X	PARTICIPANT	\N	PRESENT	0
676587	671041	20150Y	PARTICIPANT	\N	PRESENT	0
676589	671041	08034U	PARTICIPANT	\N	PRESENT	0
676590	671041	20086J	PARTICIPANT	\N	PRESENT	0
676591	671041	20094J	PARTICIPANT	\N	PRESENT	0
676595	671041	04071H	PARTICIPANT	\N	PRESENT	0
676607	671041	01043Q	PARTICIPANT	\N	PRESENT	0
676626	671041	19643A	PARTICIPANT	\N	PRESENT	0
676627	671041	19820Y	PARTICIPANT	\N	PRESENT	0
676678	671042	14225N	PARTICIPANT	\N	PRESENT	0
676679	671042	20036X	PARTICIPANT	\N	PRESENT	0
676680	671042	11040E	PARTICIPANT	\N	PRESENT	0
676681	671042	20080C	PARTICIPANT	\N	PRESENT	0
676682	671042	19711U	PARTICIPANT	\N	PRESENT	0
676683	671042	20094J	PARTICIPANT	\N	PRESENT	0
676684	671042	20914V	PARTICIPANT	\N	PRESENT	0
676685	671042	20086J	PARTICIPANT	\N	PRESENT	0
676686	671042	14327T	PARTICIPANT	\N	PRESENT	0
676687	671042	19693L	PARTICIPANT	\N	PRESENT	0
676688	671042	20112S	PARTICIPANT	\N	PRESENT	0
676689	671042	07029T	PARTICIPANT	\N	PRESENT	0
676690	671042	20050V	PARTICIPANT	\N	PRESENT	0
676691	671042	20044X	PARTICIPANT	\N	PRESENT	0
676692	671042	14331P	PARTICIPANT	\N	PRESENT	0
676693	671042	11074Q	PARTICIPANT	\N	PRESENT	0
676694	671042	19593H	PARTICIPANT	\N	PRESENT	0
676695	671042	19515S	PARTICIPANT	\N	PRESENT	0
676696	671042	14191V	PARTICIPANT	\N	PRESENT	0
676697	671042	19663E	PARTICIPANT	\N	PRESENT	0
676698	671042	20150Y	PARTICIPANT	\N	PRESENT	0
676699	671042	14083S	PARTICIPANT	\N	PRESENT	0
676703	671042	19820Y	PARTICIPANT	\N	PRESENT	0
676701	671042	19531S	PARTICIPANT	\N	PRESENT	0
676705	671042	11012A	PARTICIPANT	\N	PRESENT	0
676704	671042	14257W	PARTICIPANT	\N	PRESENT	0
676706	671042	19715Y	PARTICIPANT	\N	PRESENT	0
676707	671042	19717B	PARTICIPANT	\N	PRESENT	0
676708	671042	99004R	PARTICIPANT	\N	PRESENT	0
676709	671042	19621T	PARTICIPANT	\N	PRESENT	0
676710	671042	19647E	PARTICIPANT	\N	PRESENT	0
676711	671042	20070A	PARTICIPANT	\N	PRESENT	0
676712	671042	08034U	PARTICIPANT	\N	PRESENT	0
676713	671042	19479G	PARTICIPANT	\N	PRESENT	0
676714	671042	19667J	PARTICIPANT	\N	PRESENT	0
676715	671042	19657G	PARTICIPANT	\N	PRESENT	0
676716	671042	11053K	PARTICIPANT	\N	PRESENT	0
676717	671042	19573D	PARTICIPANT	\N	PRESENT	0
676718	671042	11085T	PARTICIPANT	\N	PRESENT	0
676719	671042	20054A	PARTICIPANT	\N	PRESENT	0
676720	671042	20034V	PARTICIPANT	\N	PRESENT	0
676721	671042	19713W	PARTICIPANT	\N	PRESENT	0
676722	671042	19701S	PARTICIPANT	\N	PRESENT	0
676723	671042	04043D	PARTICIPANT	\N	PRESENT	0
676724	671042	11070L	PARTICIPANT	\N	PRESENT	0
676725	671042	17637T	PARTICIPANT	\N	PRESENT	0
676726	671042	08010L	PARTICIPANT	\N	PRESENT	0
676676	671042	01043Q	PARTICIPANT	\N	PRESENT	0
676677	671042	11048N	PARTICIPANT	\N	PRESENT	0
676727	671042	19591F	PARTICIPANT	\N	PRESENT	0
676728	671042	19525U	PARTICIPANT	\N	PRESENT	0
676729	671042	19671E	PARTICIPANT	\N	PRESENT	0
676730	671042	19741B	PARTICIPANT	\N	PRESENT	0
676731	671042	20134Y	PARTICIPANT	\N	PRESENT	0
676732	671042	19762G	PARTICIPANT	\N	PRESENT	0
676733	671042	19577H	PARTICIPANT	\N	PRESENT	0
676734	671042	14173T	PARTICIPANT	\N	PRESENT	0
676735	671042	19295A	PARTICIPANT	\N	PRESENT	0
676736	671042	04071H	PARTICIPANT	\N	PRESENT	0
676737	671042	20138D	PARTICIPANT	\N	PRESENT	0
676738	671042	14026U	PARTICIPANT	\N	PRESENT	0
676792	671043	20134Y	PARTICIPANT	\N	PRESENT	0
676793	671043	20036X	PARTICIPANT	\N	PRESENT	0
676794	671043	20914V	PARTICIPANT	\N	PRESENT	0
676795	671043	19693L	PARTICIPANT	\N	PRESENT	0
676796	671043	20054A	PARTICIPANT	\N	PRESENT	0
676797	671043	20070A	PARTICIPANT	\N	PRESENT	0
676798	671043	20080C	PARTICIPANT	\N	PRESENT	0
676799	671043	14225N	PARTICIPANT	\N	PRESENT	0
676800	671043	11048N	PARTICIPANT	\N	PRESENT	0
676801	671043	20094J	PARTICIPANT	\N	PRESENT	0
676802	671043	11040E	PARTICIPANT	\N	PRESENT	0
676803	671043	20112S	PARTICIPANT	\N	PRESENT	0
676804	671043	19717B	PARTICIPANT	\N	PRESENT	0
676805	671043	11070L	PARTICIPANT	\N	PRESENT	0
676806	671043	20298U	PARTICIPANT	\N	PRESENT	0
676807	671043	19671E	PARTICIPANT	\N	PRESENT	0
676808	671043	20150Y	PARTICIPANT	\N	PRESENT	0
676809	671043	19762G	PARTICIPANT	\N	PRESENT	0
676810	671043	07033P	PARTICIPANT	\N	PRESENT	0
676811	671043	19701S	PARTICIPANT	\N	PRESENT	0
676812	671043	99004R	PARTICIPANT	\N	PRESENT	0
676813	671043	19479G	PARTICIPANT	\N	PRESENT	0
676814	671043	19711U	PARTICIPANT	\N	PRESENT	0
676815	671043	14331P	PARTICIPANT	\N	PRESENT	0
676816	671043	19667J	PARTICIPANT	\N	PRESENT	0
676817	671043	14191V	PARTICIPANT	\N	PRESENT	0
676818	671043	20086J	PARTICIPANT	\N	PRESENT	0
676819	671043	07029T	PARTICIPANT	\N	PRESENT	0
676820	671043	11053K	PARTICIPANT	\N	PRESENT	0
676821	671043	19657G	PARTICIPANT	\N	PRESENT	0
676822	671043	20044X	PARTICIPANT	\N	PRESENT	0
676823	671043	20034V	PARTICIPANT	\N	PRESENT	0
676824	671043	19647E	PARTICIPANT	\N	PRESENT	0
676825	671043	19741B	PARTICIPANT	\N	PRESENT	0
676826	671043	20138D	PARTICIPANT	\N	PRESENT	0
676827	671043	08010L	PARTICIPANT	\N	PRESENT	0
676828	671043	20050V	PARTICIPANT	\N	PRESENT	0
676829	671043	14083S	PARTICIPANT	\N	PRESENT	0
676830	671043	19577H	PARTICIPANT	\N	PRESENT	0
676831	671043	14257W	PARTICIPANT	\N	PRESENT	0
676832	671043	14173T	PARTICIPANT	\N	PRESENT	0
676833	671043	11085T	PARTICIPANT	\N	PRESENT	0
676834	671043	14327T	PARTICIPANT	\N	PRESENT	0
676835	671043	14179A	PARTICIPANT	\N	PRESENT	0
676836	671043	20120S	PARTICIPANT	\N	PRESENT	0
676837	671043	20148F	PARTICIPANT	\N	PRESENT	0
676838	671043	04071H	PARTICIPANT	\N	PRESENT	0
676839	671043	19687N	PARTICIPANT	\N	PRESENT	0
676840	671043	20124W	PARTICIPANT	\N	PRESENT	0
676841	671043	19621T	PARTICIPANT	\N	PRESENT	0
677219	676425	11070L	PARTICIPANT	\N	PRESENT	0
676790	671043	14026U	PARTICIPANT	\N	PRESENT	0
676791	671043	19525U	PARTICIPANT	\N	PRESENT	0
677220	676425	19413M	PARTICIPANT	\N	PRESENT	0
677221	676425	19583F	PARTICIPANT	\N	PRESENT	0
677222	676425	20028X	PARTICIPANT	\N	PRESENT	0
677223	676425	20914V	PARTICIPANT	\N	PRESENT	0
677224	676425	11072N	PARTICIPANT	\N	PRESENT	0
677225	676425	19349W	PARTICIPANT	\N	PRESENT	0
677226	676425	14327T	PARTICIPANT	\N	PRESENT	0
677227	676425	14231L	PARTICIPANT	\N	PRESENT	0
677228	676425	14030Q	PARTICIPANT	\N	PRESENT	0
677229	676425	19367Y	PARTICIPANT	\N	PRESENT	0
677230	676425	20120S	PARTICIPANT	\N	PRESENT	0
677231	676425	20090E	PARTICIPANT	\N	PRESENT	0
677232	676425	19657G	PARTICIPANT	\N	PRESENT	0
677233	676425	20034V	PARTICIPANT	\N	PRESENT	0
677234	676425	07029T	PARTICIPANT	\N	PRESENT	0
677235	676425	20044X	PARTICIPANT	\N	PRESENT	0
677236	676425	19549D	PARTICIPANT	\N	PRESENT	0
677237	676425	14219Q	PARTICIPANT	\N	PRESENT	0
677238	676425	20024T	PARTICIPANT	\N	PRESENT	0
677239	676425	20032T	PARTICIPANT	\N	PRESENT	0
677240	676425	19954N	PARTICIPANT	\N	PRESENT	0
677241	676425	14033T	PARTICIPANT	\N	PRESENT	0
677242	676425	20026V	PARTICIPANT	\N	PRESENT	0
677243	676425	20180F	PARTICIPANT	\N	PRESENT	0
677244	676425	19667J	PARTICIPANT	\N	PRESENT	0
677245	676425	20038A	PARTICIPANT	\N	PRESENT	0
677246	676425	19515S	PARTICIPANT	\N	PRESENT	0
677247	676425	20076G	PARTICIPANT	\N	PRESENT	0
677248	676425	19711U	PARTICIPANT	\N	PRESENT	0
677249	676425	11056N	PARTICIPANT	\N	PRESENT	0
656080	651600	20024T	PARTICIPANT	\N	PRESENT	0
656081	651600	14030Q	PRESIDENT	0	PRESENT	0
656082	651600	11031D	PARTICIPANT	\N	PRESENT	0
656083	651600	19693L	PARTICIPANT	\N	PRESENT	0
656084	651600	19599P	PARTICIPANT	\N	PRESENT	0
656085	651600	20034V	PARTICIPANT	\N	PRESENT	0
656086	651600	20046A	PARTICIPANT	\N	PRESENT	0
656087	651600	19749K	PARTICIPANT	\N	PRESENT	0
656088	651600	14189C	PARTICIPANT	\N	EXCUSE	0
656089	651600	20138D	PARTICIPANT	\N	EXCUSE	0
656090	651600	20080C	PARTICIPANT	\N	EXCUSE	0
656091	651600	19681G	PARTICIPANT	\N	EXCUSE	0
656092	651600	20066E	PARTICIPANT	\N	EXCUSE	0
656093	651600	20056C	PARTICIPANT	\N	EXCUSE	0
656094	651600	14109K	PARTICIPANT	\N	EXCUSE	0
656095	651600	20130U	PARTICIPANT	\N	EXCUSE	0
656096	651600	20098N	PARTICIPANT	\N	EXCUSE	0
656097	651600	11045K	PARTICIPANT	\N	PRESENT	0
656753	656752	14231L	PRESIDENT	0	PRESENT	0
656754	656752	14257W	PARTICIPANT	\N	PRESENT	0
656755	656752	19565D	PARTICIPANT	\N	PRESENT	0
656756	656752	19735D	PARTICIPANT	\N	PRESENT	0
656757	656752	14229S	PARTICIPANT	\N	PRESENT	0
656758	656752	14215L	PARTICIPANT	\N	PRESENT	0
656759	656752	19782L	PARTICIPANT	\N	PRESENT	0
656760	656752	20022R	PARTICIPANT	\N	PRESENT	0
656761	656752	19820Y	PARTICIPANT	\N	PRESENT	0
656762	656752	14327T	PARTICIPANT	\N	PRESENT	0
656763	656752	08010L	PARTICIPANT	\N	PRESENT	0
656764	656752	14217N	PARTICIPANT	\N	PRESENT	0
656765	656752	17637T	PARTICIPANT	\N	PRESENT	0
656766	656752	19349W	PARTICIPANT	\N	PRESENT	0
656767	656752	14053L	PARTICIPANT	\N	PRESENT	0
656768	656752	19489J	PARTICIPANT	\N	PRESENT	0
656769	656752	20110Q	PARTICIPANT	\N	EXCUSE	0
656770	656752	20090E	PARTICIPANT	\N	EXCUSE	0
656771	656752	19681G	PARTICIPANT	\N	EXCUSE	0
656772	656752	14187A	PARTICIPANT	\N	EXCUSE	0
656773	656752	19447X	PARTICIPANT	\N	EXCUSE	0
656774	656752	14205J	PARTICIPANT	\N	EXCUSE	0
656775	656752	19563B	PARTICIPANT	\N	EXCUSE	0
656776	656752	14071N	PARTICIPANT	\N	EXCUSE	0
656777	656752	14107H	PARTICIPANT	\N	EXCUSE	0
656778	656752	04045F	PARTICIPANT	\N	EXCUSE	0
656779	656752	20062A	PARTICIPANT	\N	EXCUSE	0
656780	656752	20084G	PARTICIPANT	\N	EXCUSE	0
656781	656752	20122U	PARTICIPANT	\N	EXCUSE	0
656782	656752	20058E	PARTICIPANT	\N	EXCUSE	0
656783	656752	14173T	PARTICIPANT	\N	EXCUSE	0
656784	656752	05012A	PARTICIPANT	\N	PRESENT	0
656806	656752	14069U	PARTICIPANT	\N	PRESENT	0
663388	660362	20112S	PARTICIPANT	\N	PRESENT	0
663389	660362	08012N	PARTICIPANT	\N	PRESENT	0
663390	660362	20124W	PARTICIPANT	\N	PRESENT	0
663391	660362	20026V	PARTICIPANT	\N	PRESENT	0
663392	660362	19593H	PARTICIPANT	\N	PRESENT	0
663393	660362	19643A	PARTICIPANT	\N	PRESENT	0
663394	660362	19651A	PARTICIPANT	\N	PRESENT	0
663395	660362	14073Q	PARTICIPANT	\N	PRESENT	0
663396	660362	20138D	PARTICIPANT	\N	PRESENT	0
663397	660362	19611R	PRESIDENT	0	PRESENT	0
663398	660362	20048C	PARTICIPANT	\N	PRESENT	0
663399	660362	19693L	PARTICIPANT	\N	PRESENT	0
663400	660362	19399H	PARTICIPANT	\N	PRESENT	0
663401	660362	20052X	PARTICIPANT	\N	PRESENT	0
663402	660362	14030Q	PARTICIPANT	\N	PRESENT	0
663403	660362	20056C	PARTICIPANT	\N	PRESENT	0
663404	660362	20180F	PARTICIPANT	\N	PRESENT	0
663405	660362	04059M	PARTICIPANT	\N	PRESENT	0
663406	660362	19735D	PARTICIPANT	\N	PRESENT	0
663407	660362	11104D	PARTICIPANT	\N	PRESENT	0
663408	660362	19758L	PARTICIPANT	\N	PRESENT	0
663409	660362	19621T	PARTICIPANT	\N	PRESENT	0
663410	660362	11109J	PARTICIPANT	\N	EXCUSE	0
663411	660362	14123H	PARTICIPANT	\N	PRESENT	0
663412	661262	08012N	PARTICIPANT	\N	PRESENT	0
663413	661262	11104D	PARTICIPANT	\N	PRESENT	0
663414	661262	08073C	PARTICIPANT	\N	PRESENT	0
663418	661799	12041X	PARTICIPANT	\N	PRESENT	0
663419	661799	19565D	PARTICIPANT	\N	PRESENT	0
663420	661799	20072C	PARTICIPANT	\N	PRESENT	0
663421	661799	01058X	PARTICIPANT	\N	PRESENT	0
663422	661799	11027H	PARTICIPANT	\N	PRESENT	0
663423	661799	16685X	PARTICIPANT	\N	PRESENT	0
663424	661799	04042C	PRESIDENT	0	PRESENT	0
663425	661799	11054L	PARTICIPANT	\N	PRESENT	0
663426	661799	11066Q	PARTICIPANT	\N	PRESENT	0
663427	661799	12028B	PARTICIPANT	\N	PRESENT	0
663428	661799	19421M	PARTICIPANT	\N	PRESENT	0
663429	661799	19709B	PARTICIPANT	\N	PRESENT	0
663430	661799	14193X	PARTICIPANT	\N	PRESENT	0
663431	661799	19347U	PARTICIPANT	\N	PRESENT	0
663432	661799	07033P	PARTICIPANT	\N	PRESENT	0
663433	661799	08061X	PARTICIPANT	\N	PRESENT	0
663434	661799	14249W	PARTICIPANT	\N	PRESENT	0
663435	661799	08047A	PARTICIPANT	\N	PRESENT	0
663436	661799	14059S	PARTICIPANT	\N	PRESENT	0
663437	661799	14097Y	PARTICIPANT	\N	PRESENT	0
663438	661799	14133K	PARTICIPANT	\N	PRESENT	0
663439	661799	08069G	PARTICIPANT	\N	PRESENT	0
663440	661799	11041F	PARTICIPANT	\N	PRESENT	0
663441	661799	20042V	PARTICIPANT	\N	PRESENT	0
663442	661799	14191V	PARTICIPANT	\N	PRESENT	0
663443	661799	14105F	PARTICIPANT	\N	PRESENT	0
663444	661799	20064C	PARTICIPANT	\N	PRESENT	0
663445	661799	98022P	PARTICIPANT	\N	PRESENT	0
663446	661799	14267Y	PARTICIPANT	\N	PRESENT	0
663447	661799	11064N	PARTICIPANT	\N	PRESENT	0
663448	661799	11083R	PARTICIPANT	\N	PRESENT	0
663449	661799	14211G	PARTICIPANT	\N	PRESENT	0
663450	659561	19820Y	PARTICIPANT	\N	PRESENT	0
663451	659561	20120S	PARTICIPANT	\N	PRESENT	0
663452	659561	20136B	PARTICIPANT	\N	PRESENT	0
663453	661836	86034E	PARTICIPANT	\N	PRESENT	0
663459	661261	19697Q	PARTICIPANT	\N	PRESENT	0
663460	661261	11067R	PARTICIPANT	\N	PRESENT	0
663461	661261	20090E	PARTICIPANT	\N	PRESENT	0
663462	661261	14355X	PARTICIPANT	\N	PRESENT	0
663463	661261	19569H	PARTICIPANT	\N	PRESENT	0
663464	661261	19798U	PARTICIPANT	\N	PRESENT	0
663465	661261	19329S	PARTICIPANT	\N	PRESENT	0
663466	661261	11097X	PARTICIPANT	\N	PRESENT	0
663467	661261	19415P	PARTICIPANT	\N	PRESENT	0
663468	661261	18193Q	PARTICIPANT	\N	PRESENT	0
663469	661261	14223L	PARTICIPANT	\N	PRESENT	0
663470	661261	14026U	PARTICIPANT	\N	PRESENT	0
663471	661261	17779H	PARTICIPANT	\N	PRESENT	0
663472	661261	11031D	PARTICIPANT	\N	PRESENT	0
663473	661261	19703U	PARTICIPANT	\N	PRESENT	0
663474	661261	14281W	PARTICIPANT	\N	PRESENT	0
663475	661261	19679N	PARTICIPANT	\N	PRESENT	0
663476	661261	14042U	PARTICIPANT	\N	PRESENT	0
663477	661261	14195A	PARTICIPANT	\N	PRESENT	0
663478	661261	19367Y	PARTICIPANT	\N	PRESENT	0
663479	661261	14213J	PARTICIPANT	\N	PRESENT	0
663481	661261	10006L	PRESIDENT	0	PRESENT	0
663482	661261	19683J	PARTICIPANT	\N	PRESENT	0
663483	661261	20130U	PARTICIPANT	\N	PRESENT	0
663484	661261	01034P	PARTICIPANT	\N	PRESENT	0
663485	661261	04057K	PARTICIPANT	\N	PRESENT	0
663486	661261	04092N	PARTICIPANT	\N	PRESENT	0
663487	661261	19713W	PARTICIPANT	\N	PRESENT	0
663488	661261	11045K	PARTICIPANT	\N	PRESENT	0
663489	661261	20040T	PARTICIPANT	\N	PRESENT	0
663490	661261	19691J	PARTICIPANT	\N	PRESENT	0
663491	661261	19717B	PARTICIPANT	\N	PRESENT	0
663493	661261	20248J	PARTICIPANT	\N	PRESENT	0
663494	661261	20066E	PARTICIPANT	\N	PRESENT	0
663495	661261	11103C	PARTICIPANT	\N	PRESENT	0
663496	661261	20298U	PARTICIPANT	\N	PRESENT	0
663497	661261	19657G	PARTICIPANT	\N	PRESENT	0
663498	661261	14071N	PARTICIPANT	\N	PRESENT	0
663499	661261	04043D	PARTICIPANT	\N	PRESENT	0
663500	659561	20106U	PARTICIPANT	\N	PRESENT	0
663501	659561	20122U	PARTICIPANT	\N	PRESENT	0
663504	659561	20038A	PARTICIPANT	\N	EXCUSE	0
663505	661270	20086J	PARTICIPANT	\N	PRESENT	0
663506	661270	14327T	PRESIDENT	0	PRESENT	0
663507	661270	19479G	PARTICIPANT	\N	PRESENT	0
663508	661270	19647E	PARTICIPANT	\N	PRESENT	0
673067	672997	10015M	PARTICIPANT	\N	PRESENT	0
673068	672997	20080C	PARTICIPANT	\N	PRESENT	0
673069	672997	18193Q	PARTICIPANT	\N	PRESENT	0
673070	672997	20122U	PARTICIPANT	\N	PRESENT	0
673071	672997	19545Y	PARTICIPANT	\N	PRESENT	0
673072	672997	14237S	PARTICIPANT	\N	PRESENT	0
673073	672997	18083K	PARTICIPANT	\N	PRESENT	0
673074	672997	19569H	PARTICIPANT	\N	PRESENT	0
673075	672997	19553Y	PARTICIPANT	\N	PRESENT	0
673076	672997	20116W	PARTICIPANT	\N	PRESENT	0
673077	672997	20072C	PARTICIPANT	\N	PRESENT	0
673078	672997	20146D	PARTICIPANT	\N	PRESENT	0
673079	672997	19715Y	PARTICIPANT	\N	PRESENT	0
673080	672997	04059M	PARTICIPANT	\N	PRESENT	0
673081	672997	19333N	PARTICIPANT	\N	PRESENT	0
673082	672997	19565D	PARTICIPANT	\N	PRESENT	0
673083	672997	20130U	PARTICIPANT	\N	PRESENT	0
673084	672997	19826F	PARTICIPANT	\N	PRESENT	0
673085	672997	19667J	PARTICIPANT	\N	PRESENT	0
673086	672997	08047A	PARTICIPANT	\N	PRESENT	0
673087	672997	19729F	PARTICIPANT	\N	PRESENT	0
673088	672997	19611R	PARTICIPANT	\N	PRESENT	0
673089	672997	19705W	PARTICIPANT	\N	PRESENT	0
673090	672997	19707Y	PARTICIPANT	\N	PRESENT	0
673091	672997	20070A	PARTICIPANT	\N	PRESENT	0
673092	672997	19711U	PARTICIPANT	\N	PRESENT	0
673093	672997	11040E	PARTICIPANT	\N	PRESENT	0
673094	672997	19693L	PARTICIPANT	\N	PRESENT	0
673095	672997	11031D	PARTICIPANT	\N	PRESENT	0
673096	672997	04085P	PARTICIPANT	\N	PRESENT	0
673097	672997	99004R	PARTICIPANT	\N	PRESENT	0
673098	672997	19695N	PARTICIPANT	\N	PRESENT	0
673099	672997	04047H	PARTICIPANT	\N	PRESENT	0
673100	672997	20102Q	PARTICIPANT	\N	PRESENT	0
673101	672997	14026U	PARTICIPANT	\N	PRESENT	0
673102	672997	20112S	PARTICIPANT	\N	PRESENT	0
673103	672997	19347U	PARTICIPANT	\N	PRESENT	0
673104	672997	08061X	PARTICIPANT	\N	PRESENT	0
673105	672997	95063L	PARTICIPANT	\N	PRESENT	0
673106	672997	19651A	PARTICIPANT	\N	PRESENT	0
673107	672997	19329S	PARTICIPANT	\N	PRESENT	0
673108	672997	11083R	PARTICIPANT	\N	PRESENT	0
673109	672997	19697Q	PARTICIPANT	\N	PRESENT	0
673110	672997	19659J	PARTICIPANT	\N	PRESENT	0
673111	672997	19782L	PARTICIPANT	\N	PRESENT	0
673112	672997	19525U	PARTICIPANT	\N	PRESENT	0
673113	672997	11033F	PARTICIPANT	\N	PRESENT	0
673114	672997	01060R	PARTICIPANT	\N	PRESENT	0
673115	672997	14207L	PARTICIPANT	\N	PRESENT	0
673116	672997	14133K	PARTICIPANT	\N	PRESENT	0
673117	672997	08034U	PARTICIPANT	\N	PRESENT	0
673118	672997	20132W	PARTICIPANT	\N	PRESENT	0
673119	672997	17367Q	PARTICIPANT	\N	PRESENT	0
673120	672997	98022P	PARTICIPANT	\N	PRESENT	0
673121	672997	14195A	PARTICIPANT	\N	PRESENT	0
673122	672997	04057K	PARTICIPANT	\N	PRESENT	0
673123	672997	20044X	PARTICIPANT	\N	PRESENT	0
673124	672997	19563B	PARTICIPANT	\N	PRESENT	0
673125	672997	19573D	PARTICIPANT	\N	PRESENT	0
673126	672997	19447X	PARTICIPANT	\N	PRESENT	0
673127	672997	20026V	PARTICIPANT	\N	PRESENT	0
673128	672997	19717B	PARTICIPANT	\N	PRESENT	0
673129	672997	20056C	PARTICIPANT	\N	PRESENT	0
673130	672997	19443T	PARTICIPANT	\N	PRESENT	0
673131	672997	14211G	PARTICIPANT	\N	PRESENT	0
673676	672571	19711U	PARTICIPANT	\N	PRESENT	0
673677	672571	08010L	PARTICIPANT	\N	PRESENT	0
673678	672571	14187A	PARTICIPANT	\N	PRESENT	0
673679	672571	11040E	PARTICIPANT	\N	PRESENT	0
673893	672571	20124W	PARTICIPANT	\N	PRESENT	0
673894	672571	14229S	PARTICIPANT	\N	PRESENT	0
673895	671029	95063L	PARTICIPANT	\N	PRESENT	0
673896	671029	11056N	PARTICIPANT	\N	PRESENT	0
674527	670816	19651A	PARTICIPANT	\N	PRESENT	0
673898	671029	19715Y	PARTICIPANT	\N	PRESENT	0
674528	670816	14073Q	PARTICIPANT	\N	PRESENT	0
673900	671029	20092G	PARTICIPANT	\N	PRESENT	0
673901	671029	20110Q	PARTICIPANT	\N	PRESENT	0
673902	671029	14037X	PARTICIPANT	\N	PRESENT	0
673903	671029	20128B	PARTICIPANT	\N	PRESENT	0
674529	670816	19611R	PRESIDENT	0	PRESENT	0
674530	670816	20142Y	PARTICIPANT	\N	PRESENT	0
674531	670816	19693L	PARTICIPANT	\N	PRESENT	0
674532	670816	19399H	PARTICIPANT	\N	PRESENT	0
673908	671029	19413M	PARTICIPANT	\N	PRESENT	0
674533	670816	20052X	PARTICIPANT	\N	PRESENT	0
673910	671029	19691J	PARTICIPANT	\N	PRESENT	0
673911	671029	07004J	PARTICIPANT	\N	PRESENT	0
673912	671029	01024M	PARTICIPANT	\N	PRESENT	0
673913	671029	19826F	PARTICIPANT	\N	PRESENT	0
673914	671029	20072C	PARTICIPANT	\N	PRESENT	0
673915	671029	14107H	PARTICIPANT	\N	PRESENT	0
673916	671029	19629C	PARTICIPANT	\N	PRESENT	0
673917	671029	19563B	PARTICIPANT	\N	PRESENT	0
674534	670816	20172F	PARTICIPANT	\N	PRESENT	0
673919	671029	20120S	PARTICIPANT	\N	PRESENT	0
673920	671029	20020P	PARTICIPANT	\N	PRESENT	0
674535	670816	14030Q	PARTICIPANT	\N	PRESENT	0
674536	670816	20056C	PARTICIPANT	\N	PRESENT	0
674537	670816	20180F	PARTICIPANT	\N	PRESENT	0
673927	671029	20032T	PARTICIPANT	\N	PRESENT	0
673925	671029	20062A	PARTICIPANT	\N	PRESENT	0
674025	670750	95063L	PARTICIPANT	\N	PRESENT	0
674538	670816	04059M	PARTICIPANT	\N	PRESENT	0
674539	670816	20264J	PARTICIPANT	\N	PRESENT	0
673930	671029	11097X	PARTICIPANT	\N	PRESENT	0
674540	670816	19735D	PARTICIPANT	\N	PRESENT	0
673932	671029	08028W	PARTICIPANT	\N	PRESENT	0
673934	671029	05012A	PARTICIPANT	\N	PRESENT	0
674541	670816	14109K	PARTICIPANT	\N	PRESENT	0
673936	671029	20026V	PARTICIPANT	\N	PRESENT	0
674542	670816	14123H	PARTICIPANT	\N	PRESENT	0
674543	670816	11104D	PARTICIPANT	\N	PRESENT	0
674544	670816	11043H	PARTICIPANT	\N	PRESENT	0
673940	671029	20044X	PARTICIPANT	\N	PRESENT	0
674545	670816	19758L	PARTICIPANT	\N	PRESENT	0
673942	671029	14327T	PARTICIPANT	\N	PRESENT	0
673943	671029	19747H	PARTICIPANT	\N	PRESENT	0
673944	671029	04047H	PARTICIPANT	\N	PRESENT	0
674513	670816	19533U	PARTICIPANT	\N	PRESENT	0
674027	670750	19715Y	PARTICIPANT	\N	PRESENT	0
674514	670816	04033B	PARTICIPANT	\N	PRESENT	0
674029	670750	20092G	PARTICIPANT	\N	PRESENT	0
674031	670750	14037X	PARTICIPANT	\N	PRESENT	0
674515	670816	01060R	PARTICIPANT	\N	PRESENT	0
674516	670816	14229S	PARTICIPANT	\N	PRESENT	0
674517	670816	19573D	PARTICIPANT	\N	PRESENT	0
674037	670750	19691J	PARTICIPANT	\N	PRESENT	0
674039	670750	01024M	PARTICIPANT	\N	PRESENT	0
674040	670750	19826F	PARTICIPANT	\N	PRESENT	0
674041	670750	20072C	PARTICIPANT	\N	PRESENT	0
674042	670750	14107H	PARTICIPANT	\N	PRESENT	0
674043	670750	19563B	PARTICIPANT	\N	PRESENT	0
674518	670816	92040Q	PARTICIPANT	\N	PRESENT	0
674519	670816	20112S	PARTICIPANT	\N	PRESENT	0
674520	670816	08012N	PARTICIPANT	\N	PRESENT	0
674521	670816	20124W	PARTICIPANT	\N	PRESENT	0
674522	670816	20026V	PARTICIPANT	\N	PRESENT	0
674523	670816	19593H	PARTICIPANT	\N	PRESENT	0
674054	670750	05012A	PARTICIPANT	\N	PRESENT	0
674524	670816	20132W	PARTICIPANT	\N	PRESENT	0
674525	670816	19643A	PARTICIPANT	\N	PRESENT	0
674526	670816	20134Y	PARTICIPANT	\N	PRESENT	0
674091	672571	19399H	PARTICIPANT	\N	PRESENT	0
674112	671029	20028X	PARTICIPANT	\N	PRESENT	0
674113	671029	20088L	PARTICIPANT	\N	PRESENT	0
674114	671029	19489J	PARTICIPANT	\N	PRESENT	0
674115	671029	19549D	PARTICIPANT	\N	PRESENT	0
674116	671029	19725B	PARTICIPANT	\N	PRESENT	0
655248	655246	14169X	PARTICIPANT	\N	PRESENT	0
655250	655249	04070G	PARTICIPANT	\N	PRESENT	0
655251	655249	14169X	PARTICIPANT	\N	PRESENT	0
655253	655252	14169X	PARTICIPANT	\N	PRESENT	0
655254	655252	04070G	PARTICIPANT	\N	PRESENT	0
655256	655255	19725B	PARTICIPANT	\N	PRESENT	0
655258	655257	19725B	PARTICIPANT	\N	PRESENT	0
655259	655257	14026U	PARTICIPANT	\N	PRESENT	0
655366	655365	97011G	PARTICIPANT	\N	PRESENT	0
655367	655365	18193Q	PARTICIPANT	\N	PRESENT	0
655368	655365	11026G	PARTICIPANT	\N	PRESENT	0
655369	655365	14255U	PARTICIPANT	\N	PRESENT	0
655370	655365	20252E	PARTICIPANT	\N	PRESENT	0
655371	655365	20024T	PARTICIPANT	\N	PRESENT	0
655373	655372	17229F	PARTICIPANT	\N	PRESENT	0
655374	655372	01025N	PARTICIPANT	\N	PRESENT	0
655375	655372	14213J	PARTICIPANT	\N	PRESENT	0
655376	655372	19745F	PARTICIPANT	\N	PRESENT	0
655377	655372	20248J	PARTICIPANT	\N	PRESENT	0
655378	655372	11026G	PARTICIPANT	\N	PRESENT	0
655380	655379	19713W	PARTICIPANT	\N	PRESENT	0
655381	655379	19369B	PARTICIPANT	\N	PRESENT	0
655382	655379	20024T	PARTICIPANT	\N	PRESENT	0
655383	655379	04035D	PARTICIPANT	\N	PRESENT	0
655384	655379	11026G	PARTICIPANT	\N	PRESENT	0
655988	655859	05008E	PARTICIPANT	\N	PRESENT	0
655989	655859	20022R	PARTICIPANT	\N	PRESENT	0
655990	655859	11033F	PARTICIPANT	\N	PRESENT	0
655991	655859	20114U	PARTICIPANT	\N	PRESENT	0
655992	655859	17737W	PARTICIPANT	\N	PRESENT	0
655993	655859	04047H	PARTICIPANT	\N	PRESENT	0
655994	655859	14053L	PARTICIPANT	\N	PRESENT	0
655995	655859	11056N	PARTICIPANT	\N	PRESENT	0
655996	655859	14215L	PARTICIPANT	\N	PRESENT	0
655997	655859	20074E	PARTICIPANT	\N	PRESENT	0
655998	655859	19673G	PARTICIPANT	\N	PRESENT	0
655999	655859	14231L	PARTICIPANT	\N	PRESENT	0
656000	655859	19725B	PARTICIPANT	\N	PRESENT	0
656001	655859	14179A	PARTICIPANT	\N	PRESENT	0
656002	655859	19447X	PARTICIPANT	\N	PRESENT	0
656003	655859	19729F	PARTICIPANT	\N	PRESENT	0
656004	655859	20108W	PARTICIPANT	\N	PRESENT	0
656005	655859	19581D	PARTICIPANT	\N	PRESENT	0
656006	655859	14111D	PARTICIPANT	\N	PRESENT	0
656007	655859	14147R	PARTICIPANT	\N	PRESENT	0
656008	655859	95063L	PARTICIPANT	\N	PRESENT	0
656009	655859	01028R	PARTICIPANT	\N	PRESENT	0
656011	655859	19749K	PARTICIPANT	\N	PRESENT	0
658049	657790	20104S	PARTICIPANT	\N	EXCUSE	0
658050	657790	11090Q	PARTICIPANT	\N	EXCUSE	0
663838	663836	20124W	PARTICIPANT	\N	PRESENT	0
663839	663836	19735D	PARTICIPANT	\N	PRESENT	0
663840	663836	14109K	PARTICIPANT	\N	PRESENT	0
663843	663841	08012N	PARTICIPANT	\N	PRESENT	0
663845	663841	19527W	PARTICIPANT	\N	PRESENT	0
663846	663841	11043H	PARTICIPANT	\N	PRESENT	0
665023	665022	19699S	PARTICIPANT	\N	PRESENT	0
665024	665022	20052X	PARTICIPANT	\N	PRESENT	0
665026	665025	19699S	PARTICIPANT	\N	PRESENT	0
665028	665027	19699S	PARTICIPANT	\N	PRESENT	0
665991	665150	20130U	PARTICIPANT	\N	PRESENT	0
665992	665150	11067R	PARTICIPANT	\N	PRESENT	0
665993	665150	19760E	PARTICIPANT	\N	PRESENT	0
665994	665150	20040T	PARTICIPANT	\N	PRESENT	0
665995	665150	19553Y	PARTICIPANT	\N	PRESENT	0
665996	665150	19629C	PARTICIPANT	\N	PRESENT	0
665997	665150	04045F	PARTICIPANT	\N	PRESENT	0
665998	665150	19697Q	PARTICIPANT	\N	PRESENT	0
665999	665150	19569H	PARTICIPANT	\N	PRESENT	0
666000	665150	19679N	PARTICIPANT	\N	PRESENT	0
666001	665150	20180F	PARTICIPANT	\N	PRESENT	0
666002	665150	19467C	PARTICIPANT	\N	PRESENT	0
666003	665150	20124W	PARTICIPANT	\N	PRESENT	0
666004	665150	19479G	PARTICIPANT	\N	PRESENT	0
666005	665150	04043D	PARTICIPANT	\N	PRESENT	0
666006	665150	20142Y	PARTICIPANT	\N	PRESENT	0
666007	665150	20066E	PARTICIPANT	\N	PRESENT	0
666008	665150	19663E	PARTICIPANT	\N	PRESENT	0
665978	665150	14026U	PARTICIPANT	\N	PRESENT	0
665990	665150	17779H	PARTICIPANT	\N	PRESENT	0
666009	665150	19758L	PARTICIPANT	\N	PRESENT	0
666010	665150	14223L	PARTICIPANT	\N	PRESENT	0
666011	665150	10006L	PARTICIPANT	\N	PRESENT	0
666012	665150	14215L	PARTICIPANT	\N	PRESENT	0
666013	665150	19415P	PARTICIPANT	\N	PRESENT	0
666014	665150	11097X	PARTICIPANT	\N	PRESENT	0
666015	665150	14187A	PARTICIPANT	\N	PRESENT	0
666016	665150	14133K	PARTICIPANT	\N	PRESENT	0
666017	665150	19798U	PARTICIPANT	\N	PRESENT	0
666018	665150	14217N	PARTICIPANT	\N	PRESENT	0
666019	665150	20090E	PARTICIPANT	\N	PRESENT	0
666020	665150	20140W	PARTICIPANT	\N	PRESENT	0
666021	665150	14033T	PARTICIPANT	\N	PRESENT	0
666022	665150	08045X	PARTICIPANT	\N	PRESENT	0
666023	665150	20026V	PARTICIPANT	\N	PRESENT	0
666024	665150	20062A	PARTICIPANT	\N	PRESENT	0
666025	665150	19723Y	PARTICIPANT	\N	PRESENT	0
666026	665150	17965H	PARTICIPANT	\N	PRESENT	0
666027	665150	19413M	PARTICIPANT	\N	PRESENT	0
666028	665150	19703U	PARTICIPANT	\N	PRESENT	0
666029	665150	14071N	PARTICIPANT	\N	PRESENT	0
666030	665150	20266L	PARTICIPANT	\N	PRESENT	0
666031	665150	20058E	PARTICIPANT	\N	PRESENT	0
666032	665150	20106U	PARTICIPANT	\N	PRESENT	0
666033	665150	20128B	PARTICIPANT	\N	PRESENT	0
666034	665150	14195A	PARTICIPANT	\N	PRESENT	0
666035	665150	17589D	PARTICIPANT	\N	PRESENT	0
666036	665150	11048N	PARTICIPANT	\N	PRESENT	0
666037	665150	20082E	PARTICIPANT	\N	PRESENT	0
666038	665150	17367Q	PARTICIPANT	\N	PRESENT	0
666039	665150	19621T	PARTICIPANT	\N	PRESENT	0
666040	665150	11065P	PARTICIPANT	\N	PRESENT	0
666041	665150	04092N	PARTICIPANT	\N	PRESENT	0
666042	665150	14147R	PARTICIPANT	\N	PRESENT	0
666043	665150	20052X	PARTICIPANT	\N	PRESENT	0
666044	665150	20032T	PARTICIPANT	\N	PRESENT	0
666045	665150	95063L	PARTICIPANT	\N	PRESENT	0
666046	665150	19747H	PARTICIPANT	\N	PRESENT	0
666047	665150	14213J	PARTICIPANT	\N	PRESENT	0
666048	665150	11056N	PARTICIPANT	\N	PRESENT	0
666049	665150	19631V	PARTICIPANT	\N	PRESENT	0
666050	665150	19695N	PARTICIPANT	\N	PRESENT	0
666051	665150	19782L	PARTICIPANT	\N	PRESENT	0
666052	665150	04035D	PARTICIPANT	\N	PRESENT	0
666053	665150	20264J	PARTICIPANT	\N	PRESENT	0
666054	665150	20070A	PARTICIPANT	\N	PRESENT	0
666055	665150	11077T	PARTICIPANT	\N	PRESENT	0
666056	665150	11043H	PARTICIPANT	\N	PRESENT	0
666057	665150	20126Y	PARTICIPANT	\N	PRESENT	0
666058	665150	01028R	PARTICIPANT	\N	PRESENT	0
667733	667732	14097Y	PARTICIPANT	\N	PRESENT	0
667734	667732	08047A	PARTICIPANT	\N	PRESENT	0
667870	667696	20050V	PARTICIPANT	\N	PRESENT	0
667871	667696	19667J	PARTICIPANT	\N	PRESENT	0
667872	667696	11074Q	PARTICIPANT	\N	PRESENT	0
667873	667696	20044X	PARTICIPANT	\N	PRESENT	0
667874	667696	14225N	PRESIDENT	0	PRESENT	0
667875	667696	11012A	PARTICIPANT	\N	PRESENT	0
667876	667696	08009T	PARTICIPANT	\N	PRESENT	0
667877	667696	20070A	PARTICIPANT	\N	PRESENT	0
667878	667696	19349W	PARTICIPANT	\N	PRESENT	0
667879	667696	99004R	PARTICIPANT	\N	PRESENT	0
667880	667696	20914V	PARTICIPANT	\N	PRESENT	0
667881	667696	14253S	PARTICIPANT	\N	PRESENT	0
667882	667696	20126Y	PARTICIPANT	\N	PRESENT	0
667883	667819	11031D	PARTICIPANT	\N	PRESENT	0
667884	667696	08010L	PARTICIPANT	\N	PRESENT	0
667885	667696	20116W	PARTICIPANT	\N	PRESENT	0
667886	667696	07029T	PARTICIPANT	\N	PRESENT	0
667887	667819	17779H	PARTICIPANT	\N	PRESENT	0
667888	667696	14083S	PARTICIPANT	\N	PRESENT	0
667889	667696	11070L	PARTICIPANT	\N	PRESENT	0
667890	667696	19647E	PARTICIPANT	\N	PRESENT	0
667891	665225	19333N	PARTICIPANT	\N	PRESENT	0
667892	665225	20140W	PARTICIPANT	\N	PRESENT	0
667893	665225	19387D	PARTICIPANT	\N	PRESENT	0
667894	665225	19251M	PARTICIPANT	\N	PRESENT	0
667895	665225	14219Q	PRESIDENT	0	PRESENT	0
667896	665225	19826F	PARTICIPANT	\N	PRESENT	0
667897	665225	17229F	PARTICIPANT	\N	PRESENT	0
667898	665225	20024T	PARTICIPANT	\N	PRESENT	0
677250	676425	14223L	PARTICIPANT	\N	PRESENT	0
677251	676425	11040E	PARTICIPANT	\N	PRESENT	0
677252	676425	08028W	PARTICIPANT	\N	PRESENT	0
677253	676425	20030R	PARTICIPANT	\N	PRESENT	0
677254	676425	14257W	PARTICIPANT	\N	PRESENT	0
677255	676425	20070A	PARTICIPANT	\N	PRESENT	0
677256	676425	20080C	PARTICIPANT	\N	PRESENT	0
677257	676425	14225N	PARTICIPANT	\N	PRESENT	0
677258	676425	11048N	PARTICIPANT	\N	PRESENT	0
677259	676425	20148F	PARTICIPANT	\N	PRESENT	0
677260	676425	04057K	PARTICIPANT	\N	PRESENT	0
677261	676425	19387D	PARTICIPANT	\N	PRESENT	0
677262	676425	20116W	PARTICIPANT	\N	PRESENT	0
677263	676425	14331P	PARTICIPANT	\N	PRESENT	0
677264	676425	19611R	PARTICIPANT	\N	PRESENT	0
677265	676425	11097X	PARTICIPANT	\N	PRESENT	0
677266	676425	19573D	PARTICIPANT	\N	PRESENT	0
677267	676425	19866P	PARTICIPANT	\N	PRESENT	0
677268	676425	19479G	PARTICIPANT	\N	PRESENT	0
677269	676425	20092G	PARTICIPANT	\N	PRESENT	0
677270	676425	20286Q	PARTICIPANT	\N	PRESENT	0
677271	676425	20058E	PARTICIPANT	\N	PRESENT	0
677272	676425	08009T	PARTICIPANT	\N	PRESENT	0
677273	676425	08034U	PARTICIPANT	\N	PRESENT	0
677274	676425	19741B	PARTICIPANT	\N	PRESENT	0
677275	676425	01025N	PARTICIPANT	\N	PRESENT	0
677276	676425	14097Y	PARTICIPANT	\N	PRESENT	0
677277	676425	19507S	PARTICIPANT	\N	PRESENT	0
677278	676425	19826F	PARTICIPANT	\N	PRESENT	0
677279	676425	19671E	PARTICIPANT	\N	PRESENT	0
677280	676425	20094J	PARTICIPANT	\N	PRESENT	0
677281	676425	19691J	PARTICIPANT	\N	PRESENT	0
677282	676425	20142Y	PARTICIPANT	\N	PRESENT	0
677287	676425	08045X	PARTICIPANT	\N	PRESENT	0
677284	676425	19699S	PARTICIPANT	\N	PRESENT	0
677285	676425	19723Y	PARTICIPANT	\N	PRESENT	0
677286	676425	19719D	PARTICIPANT	\N	PRESENT	0
677288	676425	20020P	PARTICIPANT	\N	PRESENT	0
677294	676425	19762G	PARTICIPANT	\N	PRESENT	0
677290	676425	11103C	PARTICIPANT	\N	PRESENT	0
677291	676425	20126Y	PARTICIPANT	\N	PRESENT	0
677292	676425	07004J	PARTICIPANT	\N	PRESENT	0
677293	676425	20074E	PARTICIPANT	\N	PRESENT	0
677295	676425	19621T	PARTICIPANT	\N	PRESENT	0
677296	676425	97011G	PARTICIPANT	\N	PRESENT	0
677297	676425	19629C	PARTICIPANT	\N	PRESENT	0
677298	676425	19467C	PARTICIPANT	\N	PRESENT	0
677299	676425	19782L	PARTICIPANT	\N	PRESENT	0
677300	676425	19399H	PARTICIPANT	\N	PRESENT	0
677301	676425	01024M	PARTICIPANT	\N	PRESENT	0
677302	676425	14151M	PARTICIPANT	\N	PRESENT	0
677303	676425	20066E	PARTICIPANT	\N	PRESENT	0
677305	676425	20040T	PARTICIPANT	\N	PRESENT	0
677306	676425	14189C	PARTICIPANT	\N	PRESENT	0
677307	676425	14147R	PARTICIPANT	\N	PRESENT	0
677308	676425	19569H	PARTICIPANT	\N	PRESENT	0
677309	676425	11065P	PARTICIPANT	\N	PRESENT	0
677310	676425	19531S	PARTICIPANT	\N	PRESENT	0
677311	676425	20108W	PARTICIPANT	\N	PRESENT	0
677312	676425	19295A	PARTICIPANT	\N	PRESENT	0
677313	676425	20100N	PARTICIPANT	\N	PRESENT	0
677314	676425	20138D	PARTICIPANT	\N	PRESENT	0
677315	676425	99004R	PARTICIPANT	\N	PRESENT	0
677316	676425	14213J	PARTICIPANT	\N	PRESENT	0
677317	676425	14001X	PARTICIPANT	\N	PRESENT	0
677318	676425	14107H	PARTICIPANT	\N	PRESENT	0
677319	676425	17779H	PARTICIPANT	\N	PRESENT	0
677320	676425	10015M	PARTICIPANT	\N	PRESENT	0
677321	676425	20098N	PARTICIPANT	\N	PRESENT	0
677322	676425	18083K	PARTICIPANT	\N	PRESENT	0
677323	676425	14031R	PARTICIPANT	\N	PRESENT	0
677324	676425	14083S	PARTICIPANT	\N	PRESENT	0
677325	676425	08061X	PARTICIPANT	\N	PRESENT	0
677326	676425	14073Q	PARTICIPANT	\N	PRESENT	0
677327	676425	19525U	PARTICIPANT	\N	PRESENT	0
677328	676425	14249W	PARTICIPANT	\N	PRESENT	0
677329	676425	20252E	PARTICIPANT	\N	PRESENT	0
677330	676425	20052X	PARTICIPANT	\N	PRESENT	0
677331	676425	19739H	PARTICIPANT	\N	PRESENT	0
677332	676425	19729F	PARTICIPANT	\N	PRESENT	0
677333	676425	01057W	PARTICIPANT	\N	PRESENT	0
677334	676425	20046A	PARTICIPANT	\N	PRESENT	0
677335	676425	20102Q	PARTICIPANT	\N	PRESENT	0
677336	676425	14237S	PARTICIPANT	\N	PRESENT	0
677337	676425	14179A	PARTICIPANT	\N	PRESENT	0
677338	676425	19251M	PARTICIPANT	\N	PRESENT	0
677339	676425	19333N	PARTICIPANT	\N	PRESENT	0
677340	676425	19709B	PARTICIPANT	\N	PRESENT	0
677341	676425	05012A	PARTICIPANT	\N	PRESENT	0
677342	676425	08060W	PARTICIPANT	\N	PRESENT	0
677343	676425	04033B	PARTICIPANT	\N	PRESENT	0
677344	676425	14021P	PARTICIPANT	\N	PRESENT	0
677345	676425	19673G	PARTICIPANT	\N	PRESENT	0
677346	676425	19335Q	PARTICIPANT	\N	PRESENT	0
677347	676425	14217N	PARTICIPANT	\N	PRESENT	0
677348	676425	19749K	PARTICIPANT	\N	PRESENT	0
677349	676425	20134Y	PARTICIPANT	\N	PRESENT	0
677350	676425	14215L	PARTICIPANT	\N	PRESENT	0
677351	676425	19543W	PARTICIPANT	\N	PRESENT	0
677352	676425	11053K	PARTICIPANT	\N	PRESENT	0
677353	676425	14357A	PARTICIPANT	\N	PRESENT	0
677354	676425	11110B	PARTICIPANT	\N	PRESENT	0
677355	676425	11067R	PARTICIPANT	\N	PRESENT	0
677356	676425	19647E	PARTICIPANT	\N	PRESENT	0
677357	676425	20056C	PARTICIPANT	\N	PRESENT	0
677358	676425	14211G	PARTICIPANT	\N	PRESENT	0
677359	676425	19489J	PARTICIPANT	\N	PRESENT	0
677360	676425	20266L	PARTICIPANT	\N	PRESENT	0
677361	676425	19798U	PARTICIPANT	\N	PRESENT	0
677362	676425	14069U	PARTICIPANT	\N	PRESENT	0
677363	677304	19383Y	PARTICIPANT	\N	PRESENT	0
677364	677304	19768N	PARTICIPANT	\N	PRESENT	0
677365	677304	20088L	PARTICIPANT	\N	PRESENT	0
677366	677304	19782L	PARTICIPANT	\N	PRESENT	0
677367	677304	20078J	PARTICIPANT	\N	PRESENT	0
677368	677304	19413M	PARTICIPANT	\N	PRESENT	0
677369	677304	20082E	PARTICIPANT	\N	PRESENT	0
677370	677304	20094J	PARTICIPANT	\N	PRESENT	0
677371	677304	19631V	PARTICIPANT	\N	PRESENT	0
677372	677304	20104S	PARTICIPANT	\N	PRESENT	0
677373	677304	08015R	PARTICIPANT	\N	PRESENT	0
677374	677304	19575F	PARTICIPANT	\N	PRESENT	0
677375	677304	19369B	PARTICIPANT	\N	PRESENT	0
677376	677304	08028W	PARTICIPANT	\N	PRESENT	0
677377	677304	20028X	PARTICIPANT	\N	PRESENT	0
677378	677304	14329V	PARTICIPANT	\N	PRESENT	0
677379	677304	20030R	PARTICIPANT	\N	PRESENT	0
677380	677304	20034V	PARTICIPANT	\N	PRESENT	0
677381	677304	14187A	PARTICIPANT	\N	PRESENT	0
677382	677304	20144B	PARTICIPANT	\N	PRESENT	0
677383	677304	19695N	PARTICIPANT	\N	PRESENT	0
677384	677304	11090Q	PRESIDENT	0	PRESENT	0
677385	677304	14033T	PARTICIPANT	\N	PRESENT	0
677386	677304	01025N	PARTICIPANT	\N	PRESENT	0
677387	677304	14205J	PARTICIPANT	\N	PRESENT	0
677388	677304	19507S	PARTICIPANT	\N	PRESENT	0
677389	677304	20286Q	PARTICIPANT	\N	PRESENT	0
677390	677304	20298U	PARTICIPANT	\N	PRESENT	0
677391	677304	19747H	PARTICIPANT	\N	PRESENT	0
677392	677304	14257W	PARTICIPANT	\N	PRESENT	0
677395	676425	14123H	PARTICIPANT	\N	PRESENT	0
677396	676425	19631V	PARTICIPANT	\N	PRESENT	0
677397	676425	08015R	PARTICIPANT	\N	PRESENT	0
677398	676425	19747H	PARTICIPANT	\N	PRESENT	0
677399	676425	04045F	PARTICIPANT	\N	PRESENT	0
677400	676425	20132W	PARTICIPANT	\N	PRESENT	0
677401	676425	98022P	PARTICIPANT	\N	PRESENT	0
677404	676425	19383Y	PARTICIPANT	\N	PRESENT	0
677405	676425	20144B	PARTICIPANT	\N	PRESENT	0
677406	676425	08010L	PARTICIPANT	\N	PRESENT	0
677407	676425	14053L	PARTICIPANT	\N	PRESENT	0
677408	676425	20152B	PARTICIPANT	\N	PRESENT	0
677409	676425	20062A	PARTICIPANT	\N	PRESENT	0
677410	676425	19347U	PARTICIPANT	\N	PRESENT	0
677411	676425	20048C	PARTICIPANT	\N	PRESENT	0
677415	676425	05008E	PARTICIPANT	\N	PRESENT	0
677413	676425	11012A	PARTICIPANT	\N	PRESENT	0
677414	676425	20082E	PARTICIPANT	\N	PRESENT	0
677416	676425	20106U	PARTICIPANT	\N	PRESENT	0
677417	676425	11043H	PARTICIPANT	\N	PRESENT	0
677418	676425	04059M	PARTICIPANT	\N	PRESENT	0
660492	660488	20118Y	PARTICIPANT	\N	PRESENT	0
656372	656369	14179A	PARTICIPANT	\N	PRESENT	0
656385	656383	14179A	PARTICIPANT	\N	PRESENT	0
656387	656383	04008A	PARTICIPANT	\N	PRESENT	0
656390	656383	14151M	PARTICIPANT	\N	PRESENT	0
660491	660488	14031R	PARTICIPANT	\N	PRESENT	0
660493	660488	14169X	PARTICIPANT	\N	PRESENT	0
660494	660488	20068G	PARTICIPANT	\N	PRESENT	0
660502	660501	14031R	PARTICIPANT	\N	PRESENT	0
660503	660501	20106U	PARTICIPANT	\N	PRESENT	0
660504	660501	20068G	PARTICIPANT	\N	PRESENT	0
661781	661780	04047H	PARTICIPANT	\N	PRESENT	0
661786	661780	11066Q	PARTICIPANT	\N	PRESENT	0
661789	661788	19651A	PARTICIPANT	\N	PRESENT	0
662035	656890	86034E	PARTICIPANT	\N	PRESENT	0
662037	656890	04085P	PARTICIPANT	\N	PRESENT	0
662038	656890	04047H	PARTICIPANT	\N	PRESENT	0
662039	656890	04042C	PARTICIPANT	\N	PRESENT	0
662040	656890	11053K	PARTICIPANT	\N	PRESENT	0
662041	656890	18083K	PARTICIPANT	\N	PRESENT	0
662042	656890	11070L	PARTICIPANT	\N	PRESENT	0
662043	656890	19719D	PARTICIPANT	\N	PRESENT	0
662044	656890	19347U	PARTICIPANT	\N	PRESENT	0
662045	656890	14026U	PARTICIPANT	\N	PRESENT	0
662046	656890	11048N	PARTICIPANT	\N	PRESENT	0
662047	656890	14225N	PARTICIPANT	\N	PRESENT	0
662048	656890	14021P	PARTICIPANT	\N	PRESENT	0
662049	656890	19611R	PARTICIPANT	\N	PRESENT	0
662050	656890	12041X	PARTICIPANT	\N	PRESENT	0
662051	656890	01043Q	PARTICIPANT	\N	PRESENT	0
662052	656890	11085T	PARTICIPANT	\N	PRESENT	0
662053	656890	01060R	PARTICIPANT	\N	PRESENT	0
662054	656890	19563B	PARTICIPANT	\N	PRESENT	0
662055	656890	14071N	PARTICIPANT	\N	PRESENT	0
662056	656890	11090Q	PARTICIPANT	\N	PRESENT	0
662057	656890	14331P	PARTICIPANT	\N	PRESENT	0
662058	656890	04033B	PARTICIPANT	\N	PRESENT	0
662474	662473	99004R	PARTICIPANT	\N	PRESENT	0
663509	661270	01057W	PRESIDENT	1	PRESENT	0
663510	661270	20080C	PARTICIPANT	\N	PRESENT	0
663511	661270	11053K	PARTICIPANT	\N	PRESENT	0
663512	661270	20050V	PARTICIPANT	\N	PRESENT	0
663513	661270	08011M	PARTICIPANT	\N	PRESENT	0
663514	661270	20044X	PARTICIPANT	\N	PRESENT	0
663515	661270	19671E	PARTICIPANT	\N	PRESENT	0
663516	661270	14083S	PARTICIPANT	\N	PRESENT	0
663517	661270	07029T	PARTICIPANT	\N	PRESENT	0
663518	661270	20070A	PARTICIPANT	\N	PRESENT	0
663519	661270	19349W	PARTICIPANT	\N	PRESENT	0
663520	661270	19741B	PARTICIPANT	\N	PRESENT	0
663521	661270	14121F	PARTICIPANT	\N	PRESENT	0
663522	661270	20914V	PARTICIPANT	\N	PRESENT	0
663523	661270	20126Y	PARTICIPANT	\N	PRESENT	0
663524	661270	19762G	PARTICIPANT	\N	PRESENT	0
663525	661270	11048N	PARTICIPANT	\N	EXCUSE	0
663526	661270	14225N	PARTICIPANT	\N	EXCUSE	0
663527	661262	20126Y	PARTICIPANT	\N	PRESENT	0
663528	661261	19553Y	PARTICIPANT	\N	PRESENT	0
663529	661261	17965H	PARTICIPANT	\N	PRESENT	0
663530	661261	19663E	PARTICIPANT	\N	PRESENT	0
663549	661270	14331P	PARTICIPANT	\N	PRESENT	0
663551	661799	11115U	PARTICIPANT	\N	PRESENT	0
663552	661799	19669L	PARTICIPANT	\N	PRESENT	0
663553	661261	19723Y	PARTICIPANT	\N	PRESENT	0
663554	661836	19701S	PARTICIPANT	\N	PRESENT	0
663555	661836	14105F	PARTICIPANT	\N	PRESENT	0
663556	661836	17737W	PARTICIPANT	\N	PRESENT	0
663557	661836	98022P	PARTICIPANT	\N	PRESENT	0
663558	661836	19383Y	PARTICIPANT	\N	PRESENT	0
663561	661836	01057W	PARTICIPANT	\N	PRESENT	0
663562	661836	19866P	PARTICIPANT	\N	PRESENT	0
663563	661836	14033T	PARTICIPANT	\N	PRESENT	0
663564	661836	14231L	PARTICIPANT	\N	PRESENT	0
663565	661836	19387D	PARTICIPANT	\N	PRESENT	0
663566	661836	14259Y	PARTICIPANT	\N	PRESENT	0
663567	661836	19447X	PARTICIPANT	\N	PRESENT	0
663568	661836	14331P	PARTICIPANT	\N	PRESENT	0
663569	661836	14191V	PARTICIPANT	\N	PRESENT	0
663570	661836	20052X	PARTICIPANT	\N	PRESENT	0
663571	661836	20090E	PARTICIPANT	\N	PRESENT	0
663572	661836	20116W	PARTICIPANT	\N	PRESENT	0
663573	661836	19479G	PARTICIPANT	\N	PRESENT	0
663574	661836	14173T	PARTICIPANT	\N	PRESENT	0
663575	661836	19515S	PARTICIPANT	\N	PRESENT	0
663576	661836	08047A	PARTICIPANT	\N	PRESENT	0
663577	661836	14267Y	PARTICIPANT	\N	PRESENT	0
663578	661836	14073Q	PARTICIPANT	\N	PRESENT	0
663579	661836	07004J	PARTICIPANT	\N	PRESENT	0
663581	661836	20144B	PARTICIPANT	\N	PRESENT	0
663582	661836	20088L	PARTICIPANT	\N	PRESENT	0
663583	661836	08060W	PARTICIPANT	\N	PRESENT	0
663584	661836	11033F	PARTICIPANT	\N	PRESENT	0
663586	661836	19719D	PARTICIPANT	\N	PRESENT	0
663587	661836	14001X	PARTICIPANT	\N	PRESENT	0
663588	661836	19565D	PARTICIPANT	\N	PRESENT	0
663590	661836	11040E	PARTICIPANT	\N	PRESENT	0
663591	661836	19687N	PARTICIPANT	\N	PRESENT	0
663593	661836	20914V	PARTICIPANT	\N	PRESENT	0
663594	661836	20248J	PARTICIPANT	\N	PRESENT	0
663595	661836	01025N	PARTICIPANT	\N	PRESENT	0
663596	661836	19695N	PARTICIPANT	\N	PRESENT	0
663597	661836	14207L	PARTICIPANT	\N	PRESENT	0
663598	661836	11045K	PARTICIPANT	\N	PRESENT	0
663599	661836	11104D	PARTICIPANT	\N	PRESENT	0
663600	661836	11041F	PARTICIPANT	\N	PRESENT	0
663601	661836	20036X	PARTICIPANT	\N	PRESENT	0
663602	661836	19637C	PARTICIPANT	\N	PRESENT	0
663603	661836	19349W	PARTICIPANT	\N	PRESENT	0
663604	661836	20106U	PARTICIPANT	\N	PRESENT	0
663605	661836	04045F	PARTICIPANT	\N	PRESENT	0
663606	661836	17779H	PARTICIPANT	\N	PRESENT	0
663607	661836	20028X	PARTICIPANT	\N	PRESENT	0
663608	661836	04059M	PARTICIPANT	\N	PRESENT	0
663609	661836	19621T	PARTICIPANT	\N	PRESENT	0
663610	661836	01028R	PARTICIPANT	\N	PRESENT	0
663611	661836	17637T	PARTICIPANT	\N	PRESENT	0
663612	661836	19715Y	PARTICIPANT	\N	PRESENT	0
663613	661836	19693L	PARTICIPANT	\N	PRESENT	0
663614	661836	08011M	PARTICIPANT	\N	PRESENT	0
663615	661836	19711U	PARTICIPANT	\N	PRESENT	0
663616	661836	19575F	PARTICIPANT	\N	PRESENT	0
663617	661836	01058X	PARTICIPANT	\N	PRESENT	0
663618	661836	99004R	PARTICIPANT	\N	PRESENT	0
663619	661836	20076G	PARTICIPANT	\N	PRESENT	0
663620	661836	19489J	PARTICIPANT	\N	PRESENT	0
663621	661836	11012A	PARTICIPANT	\N	PRESENT	0
663622	661836	20074E	PARTICIPANT	\N	PRESENT	0
663623	661836	19553Y	PARTICIPANT	\N	PRESENT	0
663624	661836	14107H	PARTICIPANT	\N	PRESENT	0
663625	661836	20078J	PARTICIPANT	\N	PRESENT	0
663626	661836	20072C	PARTICIPANT	\N	PRESENT	0
663627	661836	18083K	PARTICIPANT	\N	PRESENT	0
663628	661836	04042C	PARTICIPANT	\N	PRESENT	0
663629	661836	14123H	PARTICIPANT	\N	PRESENT	0
663630	661836	20110Q	PARTICIPANT	\N	PRESENT	0
663631	661836	20134Y	PARTICIPANT	\N	PRESENT	0
663632	661836	20100N	PARTICIPANT	\N	PRESENT	0
663633	661836	11101A	PARTICIPANT	\N	PRESENT	0
663634	661836	19703U	PARTICIPANT	\N	PRESENT	0
663635	661836	20142Y	PARTICIPANT	\N	PRESENT	0
663636	661836	20130U	PARTICIPANT	\N	PRESENT	0
663637	661836	14026U	PARTICIPANT	\N	PRESENT	0
663638	661836	04047H	PARTICIPANT	\N	PRESENT	0
663639	661836	19747H	PARTICIPANT	\N	PRESENT	0
663640	661836	08034U	PARTICIPANT	\N	PRESENT	0
663641	661836	04092N	PARTICIPANT	\N	PRESENT	0
663642	661836	19057M	PARTICIPANT	\N	PRESENT	0
663643	661836	14133K	PARTICIPANT	\N	PRESENT	0
663644	661836	19415P	PARTICIPANT	\N	PRESENT	0
663645	661836	19659J	PARTICIPANT	\N	PRESENT	0
663646	661836	11097X	PARTICIPANT	\N	PRESENT	0
663647	661836	05008E	PARTICIPANT	\N	PRESENT	0
663648	661836	14071N	PARTICIPANT	\N	PRESENT	0
663649	661836	14187A	PARTICIPANT	\N	PRESENT	0
663650	661836	04033B	PARTICIPANT	\N	PRESENT	0
674117	671029	04045F	PARTICIPANT	\N	PRESENT	0
674118	671029	19866P	PARTICIPANT	\N	PRESENT	0
674119	671029	19479G	PARTICIPANT	\N	PRESENT	0
674120	671029	01048V	PARTICIPANT	\N	PRESENT	0
674121	671029	20024T	PARTICIPANT	\N	PRESENT	0
674546	670816	17589D	PARTICIPANT	\N	PRESENT	0
674547	670816	20084G	PARTICIPANT	\N	PRESENT	0
674548	670816	19621T	PARTICIPANT	\N	PRESENT	0
674550	669278	19333N	PARTICIPANT	\N	PRESENT	0
674551	669278	19549D	PARTICIPANT	\N	PRESENT	0
674552	669278	20076G	PARTICIPANT	\N	PRESENT	0
674553	669278	19387D	PARTICIPANT	\N	PRESENT	0
674554	669278	19820Y	PARTICIPANT	\N	PRESENT	0
674555	669278	14219Q	PRESIDENT	0	PRESENT	0
674556	669278	19826F	PARTICIPANT	\N	PRESENT	0
674557	669278	19599P	PARTICIPANT	\N	PRESENT	0
674558	669278	20102Q	PARTICIPANT	\N	PRESENT	0
674559	669278	19637C	PARTICIPANT	\N	PRESENT	0
674560	669278	20096L	PARTICIPANT	\N	PRESENT	0
674561	669278	18083K	PARTICIPANT	\N	PRESENT	0
674562	669278	14237S	PARTICIPANT	\N	PRESENT	0
674563	669278	05012A	PARTICIPANT	\N	PRESENT	0
674564	669278	08060W	PARTICIPANT	\N	PRESENT	0
674565	669278	20106U	PARTICIPANT	\N	PRESENT	0
674566	669278	20118Y	PARTICIPANT	\N	PRESENT	0
674567	669278	19503N	PARTICIPANT	\N	PRESENT	0
674568	669278	20020P	PARTICIPANT	\N	PRESENT	0
674569	669278	20032T	PARTICIPANT	\N	PRESENT	0
674570	669278	14031R	PARTICIPANT	\N	PRESENT	0
674571	669278	20140W	PARTICIPANT	\N	PRESENT	0
674572	669278	19251M	PARTICIPANT	\N	PRESENT	0
674573	669278	20146D	PARTICIPANT	\N	PRESENT	0
674574	669278	14169X	PARTICIPANT	\N	PRESENT	0
674575	669278	20068G	PARTICIPANT	\N	PRESENT	0
674576	669278	19745F	PARTICIPANT	\N	PRESENT	0
674577	669278	19659J	PARTICIPANT	\N	PRESENT	0
674578	669278	19619A	PARTICIPANT	\N	PRESENT	0
674608	669278	20100N	PARTICIPANT	\N	PRESENT	0
674609	669278	20038A	PARTICIPANT	\N	PRESENT	0
674610	669278	19577H	PARTICIPANT	\N	PRESENT	0
674611	669278	19701S	PARTICIPANT	\N	EXCUSE	0
674612	669278	20046A	PARTICIPANT	\N	EXCUSE	0
674613	669278	17229F	PARTICIPANT	\N	EXCUSE	0
674619	669278	11101A	PARTICIPANT	\N	PRESENT	0
674625	669278	17367Q	PARTICIPANT	\N	PRESENT	0
674626	672573	14327T	PARTICIPANT	\N	PRESENT	0
674627	672573	14331P	PARTICIPANT	\N	PRESENT	0
674628	672573	04071H	PARTICIPANT	\N	PRESENT	0
674629	672573	01048V	PARTICIPANT	\N	PRESENT	0
674630	672573	19545Y	PARTICIPANT	\N	PRESENT	0
674631	672573	01057W	PARTICIPANT	\N	PRESENT	0
674632	672573	11053K	PARTICIPANT	\N	PRESENT	0
674633	672573	20080C	PARTICIPANT	\N	PRESENT	0
674634	672573	19667J	PARTICIPANT	\N	PRESENT	0
674635	672573	11074Q	PARTICIPANT	\N	PRESENT	0
674636	672573	14225N	PRESIDENT	0	PRESENT	0
674637	672573	11070L	PARTICIPANT	\N	PRESENT	0
674638	672573	11110B	PARTICIPANT	\N	PRESENT	0
674639	672573	07029T	PARTICIPANT	\N	PRESENT	0
674640	672573	19349W	PARTICIPANT	\N	PRESENT	0
674641	672573	08010L	PARTICIPANT	\N	PRESENT	0
674642	672573	20116W	PARTICIPANT	\N	PRESENT	0
674643	672573	19335Q	PARTICIPANT	\N	PRESENT	0
674644	672573	20126Y	PARTICIPANT	\N	PRESENT	0
674645	672573	11048N	PARTICIPANT	\N	PRESENT	0
674646	672573	19479G	PARTICIPANT	\N	PRESENT	0
674647	672573	19647E	PARTICIPANT	\N	PRESENT	0
674648	672573	19711U	PARTICIPANT	\N	PRESENT	0
674649	672573	20036X	PARTICIPANT	\N	PRESENT	0
674650	672573	20136B	PARTICIPANT	\N	PRESENT	0
674651	672573	19531S	PARTICIPANT	\N	PRESENT	0
674652	672573	20050V	PARTICIPANT	\N	PRESENT	0
674653	672573	08011M	PARTICIPANT	\N	PRESENT	0
674654	672573	20044X	PARTICIPANT	\N	PRESENT	0
674655	672573	20150Y	PARTICIPANT	\N	PRESENT	0
674656	672573	14173T	PARTICIPANT	\N	PRESENT	0
674657	672573	14083S	PARTICIPANT	\N	PRESENT	0
674658	672573	20070A	PARTICIPANT	\N	PRESENT	0
674659	672573	08009T	PARTICIPANT	\N	PRESENT	0
674660	672573	19741B	PARTICIPANT	\N	PRESENT	0
674661	672573	20914V	PARTICIPANT	\N	PRESENT	0
674662	672573	99004R	PARTICIPANT	\N	PRESENT	0
674663	672573	19762G	PARTICIPANT	\N	PRESENT	0
674664	672573	14189C	PARTICIPANT	\N	EXCUSE	0
674665	672322	19629C	PARTICIPANT	\N	PRESENT	0
674666	672322	14215L	PARTICIPANT	\N	PRESENT	0
674667	669278	20122U	PARTICIPANT	\N	PRESENT	0
674668	672322	19675J	PARTICIPANT	\N	PRESENT	0
674669	669278	19681G	PARTICIPANT	\N	PRESENT	0
674671	672322	07004J	PARTICIPANT	\N	PRESENT	0
674672	672322	20110Q	PARTICIPANT	\N	PRESENT	0
674674	670816	04070G	PARTICIPANT	\N	PRESENT	0
674675	670816	20098N	PARTICIPANT	\N	PRESENT	0
674676	670816	19057M	PARTICIPANT	\N	PRESENT	0
674677	670816	20138D	PARTICIPANT	\N	EXCUSE	0
674678	670816	11109J	PARTICIPANT	\N	EXCUSE	0
674679	672322	19585H	PARTICIPANT	\N	PRESENT	0
674680	672322	20074E	PARTICIPANT	\N	PRESENT	0
674683	672322	19725B	PARTICIPANT	\N	PRESENT	0
674684	672322	19954N	PARTICIPANT	\N	PRESENT	0
674685	672322	14111D	PARTICIPANT	\N	PRESENT	0
674686	672322	19581D	PARTICIPANT	\N	PRESENT	0
674687	672322	04047H	PRESIDENT	0	PRESENT	0
674689	669278	20024T	PARTICIPANT	\N	PRESENT	0
674690	672322	19649G	PARTICIPANT	\N	PRESENT	0
674691	672322	11026G	PARTICIPANT	\N	PRESENT	0
674692	672322	10015M	PARTICIPANT	\N	PRESENT	0
674693	672322	95063L	PARTICIPANT	\N	PRESENT	0
674694	672322	14275Y	PARTICIPANT	\N	PRESENT	0
674697	672322	14001X	PARTICIPANT	\N	PRESENT	0
674698	672322	04085P	PARTICIPANT	\N	PRESENT	0
674699	672322	14179A	PARTICIPANT	\N	PRESENT	0
674701	672322	19447X	PARTICIPANT	\N	PRESENT	0
674702	672322	14147R	PARTICIPANT	\N	PRESENT	0
674705	672322	01028R	PARTICIPANT	\N	PRESENT	0
674706	672322	14259Y	PARTICIPANT	\N	PRESENT	0
674707	672322	14231L	PARTICIPANT	\N	PRESENT	0
674708	672322	14021P	PARTICIPANT	\N	PRESENT	0
674715	672322	19489J	PARTICIPANT	\N	PRESENT	0
674716	672322	14053L	PARTICIPANT	\N	PRESENT	0
674717	672322	11033F	PARTICIPANT	\N	PRESENT	0
674719	672322	08018U	PARTICIPANT	\N	PRESENT	0
674722	672322	05008E	PARTICIPANT	\N	PRESENT	0
674723	672322	20114U	PARTICIPANT	\N	PRESENT	0
674724	672322	19729F	PARTICIPANT	\N	PRESENT	0
674725	672322	20022R	PARTICIPANT	\N	PRESENT	0
674726	672322	11056N	PARTICIPANT	\N	PRESENT	0
674730	670750	14147R	PARTICIPANT	\N	PRESENT	0
674731	669278	19685L	PARTICIPANT	\N	PRESENT	0
674732	672322	19543W	PARTICIPANT	\N	PRESENT	0
655682	655681	20044X	PARTICIPANT	\N	PRESENT	0
655683	655681	08009T	PARTICIPANT	\N	PRESENT	0
655932	655733	08060W	PARTICIPANT	\N	EXCUSE	0
655933	655733	14105F	PARTICIPANT	\N	EXCUSE	0
655934	655733	19545Y	PARTICIPANT	\N	EXCUSE	0
655935	655733	20060X	PARTICIPANT	\N	EXCUSE	0
655936	655733	14329V	PARTICIPANT	\N	EXCUSE	0
655937	655733	14195A	PARTICIPANT	\N	EXCUSE	0
655938	655733	08028W	PARTICIPANT	\N	EXCUSE	0
655939	655733	19467C	PARTICIPANT	\N	EXCUSE	0
655940	655733	14357A	PARTICIPANT	\N	EXCUSE	0
655941	655733	19251M	PARTICIPANT	\N	EXCUSE	0
655942	655733	20134Y	PARTICIPANT	\N	EXCUSE	0
655943	655733	20040T	PARTICIPANT	\N	EXCUSE	0
655944	655733	14026U	PARTICIPANT	\N	EXCUSE	0
655945	655733	20048C	PARTICIPANT	\N	EXCUSE	0
655946	655733	08015R	PARTICIPANT	\N	EXCUSE	0
655947	655733	16685X	PARTICIPANT	\N	EXCUSE	0
655948	655733	19866P	PARTICIPANT	\N	EXCUSE	0
655949	655733	08073C	PARTICIPANT	\N	EXCUSE	0
655950	655733	20082E	PARTICIPANT	\N	EXCUSE	0
655951	655733	20054A	PARTICIPANT	\N	EXCUSE	0
655952	655733	20092G	PARTICIPANT	\N	EXCUSE	0
655953	655733	19762G	PARTICIPANT	\N	EXCUSE	0
655954	655734	14030Q	PARTICIPANT	\N	EXCUSE	0
655955	655734	14083S	PARTICIPANT	\N	EXCUSE	0
655956	655734	08060W	PARTICIPANT	\N	EXCUSE	0
655957	655734	14105F	PARTICIPANT	\N	EXCUSE	0
655958	655734	19545Y	PARTICIPANT	\N	EXCUSE	0
655959	655734	20060X	PARTICIPANT	\N	EXCUSE	0
655960	655734	14329V	PARTICIPANT	\N	EXCUSE	0
655961	655734	08028W	PARTICIPANT	\N	EXCUSE	0
655962	655734	19467C	PARTICIPANT	\N	EXCUSE	0
655963	655734	14357A	PARTICIPANT	\N	EXCUSE	0
655964	655734	20134Y	PARTICIPANT	\N	EXCUSE	0
655965	655734	19251M	PARTICIPANT	\N	EXCUSE	0
655966	655734	20040T	PARTICIPANT	\N	EXCUSE	0
655967	655734	14026U	PARTICIPANT	\N	EXCUSE	0
655968	655734	20048C	PARTICIPANT	\N	EXCUSE	0
655969	655734	08015R	PARTICIPANT	\N	EXCUSE	0
655970	655734	16685X	PARTICIPANT	\N	EXCUSE	0
655971	655734	19866P	PARTICIPANT	\N	EXCUSE	0
655972	655734	08073C	PARTICIPANT	\N	EXCUSE	0
655973	655734	20082E	PARTICIPANT	\N	EXCUSE	0
655974	655734	20054A	PARTICIPANT	\N	EXCUSE	0
655975	655734	20092G	PARTICIPANT	\N	EXCUSE	0
655976	655734	19762G	PARTICIPANT	\N	EXCUSE	0
656012	655679	04047H	PRESIDENT	0	PRESENT	0
656013	655679	11033F	PARTICIPANT	\N	PRESENT	0
656014	655679	20110Q	PARTICIPANT	\N	PRESENT	0
656015	655679	19725B	PARTICIPANT	\N	PRESENT	0
656016	655679	95063L	PARTICIPANT	\N	PRESENT	0
656017	655679	04008A	PARTICIPANT	\N	PRESENT	0
656018	655679	14147R	PARTICIPANT	\N	PRESENT	0
656019	655679	14179A	PARTICIPANT	\N	PRESENT	0
656020	655679	20074E	PARTICIPANT	\N	PRESENT	0
656021	655679	20022R	PARTICIPANT	\N	PRESENT	0
656022	655679	19543W	PARTICIPANT	\N	PRESENT	0
656023	655679	14231L	PARTICIPANT	\N	PRESENT	0
656024	655679	11056N	PARTICIPANT	\N	PRESENT	0
656025	655679	10015M	PARTICIPANT	\N	PRESENT	0
656026	655679	19673G	PARTICIPANT	\N	PRESENT	0
656027	655679	20114U	PARTICIPANT	\N	PRESENT	0
656028	655679	01028R	PARTICIPANT	\N	PRESENT	0
656029	655679	14089Y	PARTICIPANT	\N	PRESENT	0
656030	655679	14069U	PARTICIPANT	\N	PRESENT	0
656031	655679	14021P	PARTICIPANT	\N	PRESENT	0
656032	655679	19729F	PARTICIPANT	\N	PRESENT	0
656033	655679	19649G	PARTICIPANT	\N	PRESENT	0
656034	655679	05008E	PARTICIPANT	\N	PRESENT	0
656035	655679	08018U	PARTICIPANT	\N	EXCUSE	0
656036	655679	20108W	PARTICIPANT	\N	PRESENT	0
656056	655679	17737W	PARTICIPANT	\N	PRESENT	0
661559	659415	95063L	PARTICIPANT	\N	PRESENT	0
661560	659415	19301E	PARTICIPANT	\N	PRESENT	0
661561	659415	19525U	PARTICIPANT	\N	PRESENT	0
661562	659415	11045K	PARTICIPANT	\N	PRESENT	0
661563	659415	14151M	PARTICIPANT	\N	PRESENT	0
661564	659415	11033F	PARTICIPANT	\N	PRESENT	0
661565	659415	14257W	PARTICIPANT	\N	PRESENT	0
661566	659415	19687N	PARTICIPANT	\N	PRESENT	0
661567	659415	19758L	PARTICIPANT	\N	PRESENT	0
661568	659415	19629C	PARTICIPANT	\N	PRESENT	0
661569	659415	14251Q	PARTICIPANT	\N	PRESENT	0
661570	659415	20114U	PARTICIPANT	\N	PRESENT	0
661571	659415	20048C	PARTICIPANT	\N	PRESENT	0
661572	659415	20052X	PARTICIPANT	\N	PRESENT	0
661573	659415	19749K	PARTICIPANT	\N	PRESENT	0
661574	659415	19619A	PARTICIPANT	\N	PRESENT	0
661575	659415	19719D	PARTICIPANT	\N	PRESENT	0
661576	659415	14267Y	PARTICIPANT	\N	PRESENT	0
661577	659415	17023S	PARTICIPANT	\N	PRESENT	0
661578	659415	14030Q	PARTICIPANT	\N	PRESENT	0
661579	659415	20054A	PARTICIPANT	\N	PRESENT	0
661580	659415	19581D	PARTICIPANT	\N	PRESENT	0
661581	659415	20090E	PARTICIPANT	\N	PRESENT	0
661582	659415	14215L	PARTICIPANT	\N	PRESENT	0
661583	659415	04008A	PARTICIPANT	\N	PRESENT	0
661584	659415	01048V	PARTICIPANT	\N	PRESENT	0
661585	659415	19782L	PARTICIPANT	\N	PRESENT	0
661586	659415	14147R	PARTICIPANT	\N	PRESENT	0
661587	659415	07029T	PARTICIPANT	\N	PRESENT	0
661588	659415	04071H	PARTICIPANT	\N	PRESENT	0
661589	659415	11043H	PARTICIPANT	\N	PRESENT	0
661590	659415	10015M	PARTICIPANT	\N	PRESENT	0
661591	659415	19467C	PARTICIPANT	\N	PRESENT	0
661592	659415	19533U	PARTICIPANT	\N	PRESENT	0
661593	659415	19573D	PARTICIPANT	\N	PRESENT	0
661594	659415	19447X	PARTICIPANT	\N	PRESENT	0
661595	659415	20038A	PARTICIPANT	\N	PRESENT	0
661596	659415	19693L	PARTICIPANT	\N	PRESENT	0
661597	659415	14179A	PARTICIPANT	\N	PRESENT	0
661598	659415	99004R	PARTICIPANT	\N	PRESENT	0
661599	659415	19399H	PARTICIPANT	\N	PRESENT	0
661600	659415	11012A	PARTICIPANT	\N	PRESENT	0
661604	659415	04047H	PARTICIPANT	\N	PRESENT	0
661605	659415	20110Q	PARTICIPANT	\N	PRESENT	0
661606	659415	20102Q	PARTICIPANT	\N	PRESENT	0
661607	659415	20046A	PARTICIPANT	\N	PRESENT	0
661608	659415	19441R	PARTICIPANT	\N	PRESENT	0
661609	659415	14073Q	PARTICIPANT	\N	PRESENT	0
661610	659415	14038Y	PARTICIPANT	\N	PRESENT	0
661611	659415	20100N	PARTICIPANT	\N	PRESENT	0
665347	665346	11054L	PARTICIPANT	\N	PRESENT	0
665348	665346	19599P	PARTICIPANT	\N	PRESENT	0
665349	665346	11031D	PARTICIPANT	\N	PRESENT	0
665350	665346	04085P	PARTICIPANT	\N	PRESENT	0
665352	665351	20124W	PARTICIPANT	\N	PRESENT	1
665353	665351	19735D	PARTICIPANT	\N	PRESENT	1
665354	665351	14109K	PARTICIPANT	\N	PRESENT	1
665356	665355	20124W	PARTICIPANT	\N	PRESENT	1
665357	665355	19735D	PARTICIPANT	\N	PRESENT	1
667899	667696	20252E	PARTICIPANT	\N	PRESENT	0
667900	665225	20032T	PARTICIPANT	\N	PRESENT	0
667901	665225	14031R	PARTICIPANT	\N	PRESENT	0
667902	665225	20046A	PARTICIPANT	\N	PRESENT	0
667903	665225	19599P	PARTICIPANT	\N	PRESENT	0
667904	665225	19637C	PARTICIPANT	\N	PRESENT	0
667905	665225	14237S	PARTICIPANT	\N	PRESENT	0
667906	667696	14189C	PARTICIPANT	\N	EXCUSE	0
667907	667696	19671E	PARTICIPANT	\N	EXCUSE	0
667908	667696	19762G	PARTICIPANT	\N	PRESENT	0
667909	667819	14355X	PARTICIPANT	\N	PRESENT	0
667910	667819	19679N	PARTICIPANT	\N	PRESENT	0
667911	667819	19663E	PARTICIPANT	\N	PRESENT	0
667914	667912	19768N	PARTICIPANT	\N	PRESENT	0
667915	667912	19515S	PARTICIPANT	\N	PRESENT	0
667916	667912	19782L	PARTICIPANT	\N	PRESENT	0
667917	667912	11077T	PARTICIPANT	\N	PRESENT	0
667918	667912	20092G	PARTICIPANT	\N	PRESENT	0
667919	667912	20078J	PARTICIPANT	\N	PRESENT	0
667920	667912	04045F	PARTICIPANT	\N	PRESENT	0
667921	667912	19705W	PARTICIPANT	\N	PRESENT	0
667922	667912	19707Y	PARTICIPANT	\N	PRESENT	0
667923	667912	08015R	PARTICIPANT	\N	PRESENT	0
667924	667912	19575F	PARTICIPANT	\N	PRESENT	0
667925	667912	19369B	PARTICIPANT	\N	PRESENT	0
667926	667912	20018V	PARTICIPANT	\N	PRESENT	0
667927	667912	14329V	PARTICIPANT	\N	PRESENT	0
667928	667912	14038Y	PARTICIPANT	\N	PRESENT	0
667929	667912	20030R	PARTICIPANT	\N	PRESENT	0
667930	667912	19467C	PARTICIPANT	\N	PRESENT	0
677419	676425	19695N	PARTICIPANT	\N	PRESENT	0
677420	676425	14193X	PARTICIPANT	\N	PRESENT	0
677421	676425	17023S	PARTICIPANT	\N	PRESENT	0
677422	676425	19679N	PARTICIPANT	\N	PRESENT	0
677423	676425	20086J	PARTICIPANT	\N	PRESENT	0
677424	676425	19768N	PARTICIPANT	\N	PRESENT	0
677425	676425	19701S	PARTICIPANT	\N	PRESENT	0
677431	676425	20172F	PARTICIPANT	\N	PRESENT	0
677432	676425	20112S	PARTICIPANT	\N	PRESENT	0
677433	676425	19687N	PARTICIPANT	\N	PRESENT	0
677434	676425	08018U	PARTICIPANT	\N	PRESENT	0
677435	676425	19581D	PARTICIPANT	\N	PRESENT	0
677436	676425	08069G	PARTICIPANT	\N	PRESENT	0
677437	676425	19713W	PARTICIPANT	\N	PRESENT	0
677438	676425	14205J	PARTICIPANT	\N	PRESENT	0
677439	676425	19703U	PARTICIPANT	\N	PRESENT	0
677440	676425	19663E	PARTICIPANT	\N	PRESENT	0
677441	676425	19503N	PARTICIPANT	\N	PRESENT	0
677442	676425	14037X	PARTICIPANT	\N	PRESENT	0
677443	676425	20136B	PARTICIPANT	\N	PRESENT	0
677444	676425	14111D	PARTICIPANT	\N	PRESENT	0
677445	676425	08056B	PARTICIPANT	\N	PRESENT	0
677446	676425	11074Q	PARTICIPANT	\N	PRESENT	0
677447	676425	14259Y	PARTICIPANT	\N	PRESENT	0
677448	676425	14169X	PARTICIPANT	\N	PRESENT	0
677449	676425	11083R	PARTICIPANT	\N	PRESENT	0
677450	676425	20084G	PARTICIPANT	\N	PRESENT	0
677451	676425	20104S	PARTICIPANT	\N	PRESENT	0
677452	676425	14042U	PARTICIPANT	\N	PRESENT	0
677453	676425	16685X	PARTICIPANT	\N	PRESENT	0
677454	676425	19447X	PARTICIPANT	\N	PRESENT	0
677455	676425	01058X	PARTICIPANT	\N	PRESENT	0
677456	676425	20124W	PARTICIPANT	\N	PRESENT	0
677457	676425	14221J	PARTICIPANT	\N	PRESENT	0
677458	676425	19563B	PARTICIPANT	\N	PRESENT	0
677459	676425	04047H	PARTICIPANT	\N	PRESENT	0
677460	676425	01043Q	PARTICIPANT	\N	PRESENT	0
677461	676425	20140W	PARTICIPANT	\N	PRESENT	0
677462	676425	14187A	PARTICIPANT	\N	PRESENT	0
677463	676425	19533U	PARTICIPANT	\N	PRESENT	0
677464	676425	11085T	PARTICIPANT	\N	PRESENT	0
677465	676425	19820Y	PARTICIPANT	\N	PRESENT	0
677466	676425	19415P	PARTICIPANT	\N	PRESENT	0
677467	676425	01034P	PARTICIPANT	\N	PRESENT	0
677473	676425	14071N	PARTICIPANT	\N	PRESENT	0
677479	676425	14191V	PARTICIPANT	\N	PRESENT	0
677480	676425	11064N	PARTICIPANT	\N	PRESENT	0
677481	676425	95063L	PARTICIPANT	\N	PRESENT	0
677482	676425	14173T	PARTICIPANT	\N	PRESENT	0
677484	676425	19441R	PARTICIPANT	\N	PRESENT	0
677485	676425	11077T	PARTICIPANT	\N	PRESENT	0
677486	676425	19443T	PARTICIPANT	\N	PRESENT	0
677487	676425	19553Y	PARTICIPANT	\N	PRESENT	0
677488	676425	19725B	PARTICIPANT	\N	PRESENT	0
677489	676425	17965H	PARTICIPANT	\N	PRESENT	0
677548	676426	14026U	PARTICIPANT	\N	PRESENT	0
677549	676426	14257W	PARTICIPANT	\N	PRESENT	0
677550	676426	20914V	PARTICIPANT	\N	PRESENT	0
677551	676426	11077T	PARTICIPANT	\N	PRESENT	0
677552	676426	19711U	PARTICIPANT	\N	PRESENT	0
677553	676426	14327T	PARTICIPANT	\N	PRESENT	0
677554	676426	19758L	PARTICIPANT	\N	PRESENT	0
677555	676426	11074Q	PARTICIPANT	\N	PRESENT	0
677556	676426	19629C	PARTICIPANT	\N	PRESENT	0
677557	676426	19479G	PARTICIPANT	\N	PRESENT	0
677558	676426	20144B	PARTICIPANT	\N	PRESENT	0
677559	676426	07004J	PARTICIPANT	\N	PRESENT	0
677560	676426	19631V	PARTICIPANT	\N	PRESENT	0
677561	676426	99004R	PARTICIPANT	\N	PRESENT	0
677562	676426	14069U	PARTICIPANT	\N	PRESENT	0
677563	676426	14357A	PARTICIPANT	\N	PRESENT	0
677564	676426	20090E	PARTICIPANT	\N	PRESENT	0
677565	676426	20044X	PARTICIPANT	\N	PRESENT	0
677566	676426	20120S	PARTICIPANT	\N	PRESENT	0
677567	676426	19798U	PARTICIPANT	\N	PRESENT	0
677568	676426	14053L	PARTICIPANT	\N	PRESENT	0
677569	676426	19701S	PARTICIPANT	\N	PRESENT	0
677570	676426	20038A	PARTICIPANT	\N	PRESENT	0
677571	676426	19673G	PARTICIPANT	\N	PRESENT	0
677572	676426	20076G	PARTICIPANT	\N	PRESENT	0
677573	676426	14147R	PARTICIPANT	\N	PRESENT	0
677574	676426	20062A	PARTICIPANT	\N	PRESENT	0
677575	676426	19545Y	PARTICIPANT	\N	PRESENT	0
677576	676426	19647E	PARTICIPANT	\N	PRESENT	0
677577	676426	19687N	PARTICIPANT	\N	PRESENT	0
677578	676426	05012A	PARTICIPANT	\N	PRESENT	0
677579	676426	10015M	PARTICIPANT	\N	PRESENT	0
677580	676426	20252E	PARTICIPANT	\N	PRESENT	0
677581	676426	95063L	PARTICIPANT	\N	PRESENT	0
677582	676426	19531S	PARTICIPANT	\N	PRESENT	0
677583	676426	19747H	PARTICIPANT	\N	PRESENT	0
677584	676426	14329V	PARTICIPANT	\N	PRESENT	0
677585	676426	17965H	PARTICIPANT	\N	PRESENT	0
677586	676426	19621T	PARTICIPANT	\N	PRESENT	0
677587	676426	07029T	PARTICIPANT	\N	PRESENT	0
677588	676426	19467C	PARTICIPANT	\N	PRESENT	0
677589	676426	19820Y	PARTICIPANT	\N	PRESENT	0
677590	676426	20116W	PARTICIPANT	\N	PRESENT	0
677591	676426	19335Q	PARTICIPANT	\N	PRESENT	0
677592	676426	11097X	PARTICIPANT	\N	PRESENT	0
677593	676426	19749K	PARTICIPANT	\N	PRESENT	0
677594	676426	20092G	PARTICIPANT	\N	PRESENT	0
677595	676426	20100N	PARTICIPANT	\N	PRESENT	0
677596	676426	20086J	PARTICIPANT	\N	PRESENT	0
677597	676426	20094J	PARTICIPANT	\N	PRESENT	0
677598	676426	20142Y	PARTICIPANT	\N	PRESENT	0
677599	676426	20134Y	PARTICIPANT	\N	PRESENT	0
677600	676426	20266L	PARTICIPANT	\N	PRESENT	0
677601	676426	19866P	PARTICIPANT	\N	PRESENT	0
677602	676426	19383Y	PARTICIPANT	\N	PRESENT	0
677603	676426	14037X	PARTICIPANT	\N	PRESENT	0
677604	676426	19954N	PARTICIPANT	\N	PRESENT	0
677605	676426	20180F	PARTICIPANT	\N	PRESENT	0
677606	676426	20036X	PARTICIPANT	\N	PRESENT	0
677607	676426	20110Q	PARTICIPANT	\N	PRESENT	0
677608	676426	08010L	PARTICIPANT	\N	PRESENT	0
677609	676426	14073Q	PARTICIPANT	\N	PRESENT	0
677610	676426	14249W	PARTICIPANT	\N	PRESENT	0
677611	676426	19611R	PARTICIPANT	\N	PRESENT	0
677612	676426	14189C	PARTICIPANT	\N	PRESENT	0
677613	676426	19533U	PARTICIPANT	\N	PRESENT	0
677614	676426	20052X	PARTICIPANT	\N	PRESENT	0
677615	676426	11026G	PARTICIPANT	\N	PRESENT	0
677616	676426	01057W	PARTICIPANT	\N	PRESENT	0
677617	676426	01043Q	PARTICIPANT	\N	PRESENT	0
677618	676426	11048N	PARTICIPANT	\N	PRESENT	0
677619	676426	14225N	PARTICIPANT	\N	PRESENT	0
677620	676426	11053K	PARTICIPANT	\N	PRESENT	0
677621	676426	14169X	PARTICIPANT	\N	PRESENT	0
677622	676426	20032T	PARTICIPANT	\N	PRESENT	0
677623	676426	14191V	PARTICIPANT	\N	PRESENT	0
677624	676426	19569H	PARTICIPANT	\N	PRESENT	0
677625	676426	20070A	PARTICIPANT	\N	PRESENT	0
677626	676426	20136B	PARTICIPANT	\N	PRESENT	0
677627	676426	19347U	PARTICIPANT	\N	PRESENT	0
677628	676426	19563B	PARTICIPANT	\N	PRESENT	0
677629	676426	19782L	PARTICIPANT	\N	PRESENT	0
677630	676426	19703U	PARTICIPANT	\N	PRESENT	0
677631	676426	19713W	PARTICIPANT	\N	PRESENT	0
677632	676426	14030Q	PARTICIPANT	\N	PRESENT	0
677633	676426	20298U	PARTICIPANT	\N	PRESENT	0
677634	676426	19349W	PARTICIPANT	\N	PRESENT	0
677635	676426	20040T	PARTICIPANT	\N	PRESENT	0
677636	676426	11110B	PARTICIPANT	\N	PRESENT	0
677637	676426	01028R	PARTICIPANT	\N	PRESENT	0
677638	676426	20054A	PARTICIPANT	\N	PRESENT	0
677639	676426	18083K	PARTICIPANT	\N	PRESENT	0
677640	676426	20124W	PARTICIPANT	\N	PRESENT	0
677641	676426	19369B	PARTICIPANT	\N	PRESENT	0
677642	676426	17367Q	PARTICIPANT	\N	PRESENT	0
677643	676426	20126Y	PARTICIPANT	\N	PRESENT	0
677644	676426	14213J	PARTICIPANT	\N	PRESENT	0
677645	676426	14031R	PARTICIPANT	\N	PRESENT	0
677646	676426	19399H	PARTICIPANT	\N	PRESENT	0
677647	676426	19413M	PARTICIPANT	\N	PRESENT	0
677648	676426	11056N	PARTICIPANT	\N	PRESENT	0
677649	676426	19301E	PARTICIPANT	\N	PRESENT	0
677650	676426	19553Y	PARTICIPANT	\N	PRESENT	0
677651	676426	20048C	PARTICIPANT	\N	PRESENT	0
677652	676426	19503N	PARTICIPANT	\N	PRESENT	0
677653	676426	14033T	PARTICIPANT	\N	PRESENT	0
656215	656157	19399H	PARTICIPANT	\N	EXCUSE	0
656669	655742	20138D	PARTICIPANT	\N	EXCUSE	0
656670	652051	20138D	PARTICIPANT	\N	EXCUSE	0
656813	656812	11056N	PARTICIPANT	\N	PRESENT	0
656814	656812	01028R	PARTICIPANT	\N	PRESENT	0
656816	656815	11056N	PARTICIPANT	\N	PRESENT	0
656817	656285	19691J	PARTICIPANT	\N	PRESENT	0
656820	656686	19691J	PARTICIPANT	\N	PRESENT	0
656821	656271	19679N	PARTICIPANT	\N	PRESENT	0
656822	656271	20130U	PARTICIPANT	\N	PRESENT	0
656823	656271	19569H	PARTICIPANT	\N	PRESENT	0
656826	656818	19569H	PARTICIPANT	\N	PRESENT	0
656827	656818	19679N	PARTICIPANT	\N	PRESENT	0
656828	656818	20130U	PARTICIPANT	\N	PRESENT	0
656830	656829	19569H	PARTICIPANT	\N	PRESENT	0
656831	656829	19679N	PARTICIPANT	\N	PRESENT	0
656832	656829	20130U	PARTICIPANT	\N	PRESENT	0
659624	659362	20110Q	PARTICIPANT	\N	PRESENT	0
659625	659362	14001X	PARTICIPANT	\N	EXCUSE	0
659626	659362	19301E	PARTICIPANT	\N	PRESENT	0
659627	659362	19447X	PARTICIPANT	\N	PRESENT	0
659628	659362	14151M	PARTICIPANT	\N	PRESENT	0
659629	659362	14215L	PARTICIPANT	\N	EXCUSE	0
659630	659362	14111D	PARTICIPANT	\N	PRESENT	0
659631	659362	20074E	PARTICIPANT	\N	PRESENT	0
659632	659362	19581D	PARTICIPANT	\N	PRESENT	0
659633	659362	19585H	PARTICIPANT	\N	PRESENT	0
659634	659362	19954N	PARTICIPANT	\N	PRESENT	0
659635	659362	19489J	PARTICIPANT	\N	PRESENT	0
659636	659362	95063L	PARTICIPANT	\N	PRESENT	0
659637	659362	20108W	PARTICIPANT	\N	PRESENT	0
659638	659362	14179A	PARTICIPANT	\N	PRESENT	0
659639	659362	04008A	PARTICIPANT	\N	PRESENT	0
659640	659362	14089Y	PARTICIPANT	\N	EXCUSE	0
659641	659362	14053L	PARTICIPANT	\N	PRESENT	0
659642	659362	20022R	PARTICIPANT	\N	PRESENT	0
659643	659362	14069U	PARTICIPANT	\N	PRESENT	0
659656	659362	04047H	PRESIDENT	0	PRESENT	0
659657	659362	14231L	PARTICIPANT	\N	PRESENT	0
659849	659410	19745F	PARTICIPANT	\N	PRESENT	0
659850	659410	20064C	PARTICIPANT	\N	PRESENT	0
659851	659410	08010L	PARTICIPANT	\N	PRESENT	0
659852	659410	11045K	PARTICIPANT	\N	PRESENT	0
659853	659410	14211G	PARTICIPANT	\N	PRESENT	0
659854	659410	04059M	PARTICIPANT	\N	PRESENT	0
659855	659410	14231L	PARTICIPANT	\N	PRESENT	0
659856	659410	01024M	PARTICIPANT	\N	PRESENT	0
659857	659410	14083S	PARTICIPANT	\N	PRESENT	0
659858	659410	19741B	PARTICIPANT	\N	PRESENT	0
659859	659410	20114U	PARTICIPANT	\N	PRESENT	0
659860	659410	19441R	PARTICIPANT	\N	PRESENT	0
659862	659410	20040T	PARTICIPANT	\N	PRESENT	0
659863	659410	20048C	PARTICIPANT	\N	PRESENT	0
659864	659410	08015R	PARTICIPANT	\N	PRESENT	0
659865	659410	14055N	PARTICIPANT	\N	PRESENT	0
659871	659410	19575F	PARTICIPANT	\N	PRESENT	0
659869	659410	20068G	PARTICIPANT	\N	PRESENT	0
659870	659410	20138D	PARTICIPANT	\N	PRESENT	0
659872	659410	11043H	PARTICIPANT	\N	PRESENT	0
659873	659410	14189C	PARTICIPANT	\N	PRESENT	0
659874	659410	20266L	PARTICIPANT	\N	PRESENT	0
659878	659410	11085T	PARTICIPANT	\N	PRESENT	0
659879	659410	11056N	PARTICIPANT	\N	PRESENT	0
659880	659410	19760E	PARTICIPANT	\N	PRESENT	0
659881	659410	01028R	PARTICIPANT	\N	PRESENT	0
659882	659410	20100N	PARTICIPANT	\N	PRESENT	0
659883	659410	12016W	PARTICIPANT	\N	PRESENT	0
659884	659410	20180F	PARTICIPANT	\N	PRESENT	0
659885	659410	19739H	PARTICIPANT	\N	PRESENT	0
659886	659166	19697Q	PARTICIPANT	\N	PRESENT	0
659887	659166	19415P	PARTICIPANT	\N	PRESENT	0
659888	659166	14223L	PARTICIPANT	\N	PRESENT	0
659889	659166	14026U	PARTICIPANT	\N	PRESENT	0
659890	659166	19679N	PARTICIPANT	\N	PRESENT	0
659891	659166	14195A	PARTICIPANT	\N	PRESENT	0
659892	659166	19367Y	PARTICIPANT	\N	PRESENT	0
660367	660366	14031R	PARTICIPANT	\N	PRESENT	0
660368	660366	14169X	PARTICIPANT	\N	PRESENT	0
660456	660455	14031R	PARTICIPANT	\N	PRESENT	0
660466	660465	14031R	PARTICIPANT	\N	PRESENT	0
660467	660465	20096L	PARTICIPANT	\N	PRESENT	0
660471	660470	14031R	PARTICIPANT	\N	PRESENT	0
660472	660470	20118Y	PARTICIPANT	\N	PRESENT	0
660473	660470	14169X	PARTICIPANT	\N	PRESENT	0
660474	660470	20096L	PARTICIPANT	\N	PRESENT	0
660475	660470	20068G	PARTICIPANT	\N	PRESENT	0
660477	660476	14327T	PARTICIPANT	\N	PRESENT	0
660479	660478	20050V	PARTICIPANT	\N	PRESENT	0
660483	660482	14189C	PARTICIPANT	\N	PRESENT	0
660555	659408	19673G	PARTICIPANT	\N	EXCUSE	0
660725	660703	19545Y	PARTICIPANT	\N	PRESENT	0
660729	660703	18083K	PARTICIPANT	\N	PRESENT	0
660734	660703	19447X	PARTICIPANT	\N	PRESENT	0
660738	660703	19735D	PARTICIPANT	\N	PRESENT	0
660741	660703	11097X	PARTICIPANT	\N	PRESENT	0
660745	660703	19762G	PARTICIPANT	\N	PRESENT	0
660748	660703	14173T	PARTICIPANT	\N	PRESENT	0
660813	660812	20094J	PARTICIPANT	\N	PRESENT	0
660814	660812	20110Q	PARTICIPANT	\N	PRESENT	0
660815	660812	19549D	PARTICIPANT	\N	PRESENT	0
662020	661799	08056B	PARTICIPANT	\N	EXCUSE	0
663378	663377	19507S	PARTICIPANT	\N	PRESENT	0
663379	663377	01025N	PARTICIPANT	\N	PRESENT	0
663651	661836	11083R	PARTICIPANT	\N	PRESENT	0
664316	664315	04045F	PARTICIPANT	\N	PRESENT	0
664317	664315	14329V	PARTICIPANT	\N	PRESENT	0
664338	664337	14215L	PARTICIPANT	\N	PRESENT	0
664349	661266	01034P	PARTICIPANT	\N	PRESENT	0
664352	661837	04057K	PARTICIPANT	\N	PRESENT	0
664353	661837	19719D	PARTICIPANT	\N	PRESENT	0
664354	661837	17779H	PARTICIPANT	\N	PRESENT	0
664355	661837	19691J	PARTICIPANT	\N	PRESENT	0
664356	661837	20020P	PARTICIPANT	\N	PRESENT	0
664357	661837	19663E	PARTICIPANT	\N	PRESENT	0
664358	661837	20048C	PARTICIPANT	\N	PRESENT	0
664359	661837	19715Y	PARTICIPANT	\N	PRESENT	0
664360	661837	19367Y	PARTICIPANT	\N	PRESENT	0
664361	661837	20066E	PARTICIPANT	\N	PRESENT	0
664362	661837	01034P	PARTICIPANT	\N	PRESENT	0
664363	661837	10006L	PARTICIPANT	\N	PRESENT	0
664364	661837	14042U	PARTICIPANT	\N	PRESENT	0
664365	661837	11053K	PARTICIPANT	\N	PRESENT	0
664366	661837	14195A	PARTICIPANT	\N	PRESENT	0
664448	661838	14026U	PARTICIPANT	\N	PRESENT	0
664449	661838	14195A	PARTICIPANT	\N	PRESENT	0
664450	661838	04057K	PARTICIPANT	\N	PRESENT	0
664451	661838	20130U	PARTICIPANT	\N	PRESENT	0
664452	661838	10006L	PARTICIPANT	\N	PRESENT	0
664453	661838	20914V	PARTICIPANT	\N	PRESENT	0
664454	661838	19347U	PARTICIPANT	\N	PRESENT	0
664455	661838	20134Y	PARTICIPANT	\N	PRESENT	0
664456	661838	14042U	PARTICIPANT	\N	PRESENT	0
664457	661838	11067R	PARTICIPANT	\N	PRESENT	0
664458	661838	19760E	PARTICIPANT	\N	PRESENT	0
664459	661838	19565D	PARTICIPANT	\N	PRESENT	0
664460	661838	17965H	PARTICIPANT	\N	PRESENT	0
664461	661838	18193Q	PARTICIPANT	\N	PRESENT	0
664462	661838	19591F	PARTICIPANT	\N	PRESENT	0
664463	661838	14147R	PARTICIPANT	\N	PRESENT	0
664464	661838	20024T	PARTICIPANT	\N	PRESENT	0
664465	661838	19533U	PARTICIPANT	\N	PRESENT	0
664466	661838	20090E	PARTICIPANT	\N	PRESENT	0
664467	661838	14059S	PARTICIPANT	\N	PRESENT	0
664468	661838	14055N	PARTICIPANT	\N	PRESENT	0
664469	661838	20100N	PARTICIPANT	\N	PRESENT	0
664470	661838	19675J	PARTICIPANT	\N	PRESENT	0
664471	661838	20056C	PARTICIPANT	\N	PRESENT	0
664472	661838	04043D	PARTICIPANT	\N	PRESENT	0
664473	661838	19663E	PARTICIPANT	\N	PRESENT	0
664474	661838	19367Y	PARTICIPANT	\N	PRESENT	0
664475	661838	11097X	PARTICIPANT	\N	PRESENT	0
664476	661838	01034P	PARTICIPANT	\N	PRESENT	0
664477	661838	19691J	PARTICIPANT	\N	PRESENT	0
664478	661838	20066E	PARTICIPANT	\N	PRESENT	0
664479	661838	11031D	PARTICIPANT	\N	PRESENT	0
664480	661838	17779H	PARTICIPANT	\N	PRESENT	0
664481	661838	20142Y	PARTICIPANT	\N	PRESENT	0
664482	661838	19758L	PARTICIPANT	\N	PRESENT	0
664483	661838	19866P	PARTICIPANT	\N	PRESENT	0
664484	661838	20054A	PARTICIPANT	\N	PRESENT	0
664485	661838	20026V	PARTICIPANT	\N	PRESENT	0
674784	672322	14069U	PARTICIPANT	\N	PRESENT	0
674785	672573	08034U	PRESIDENT	1	PRESENT	0
674786	672573	11012A	PARTICIPANT	\N	PRESENT	0
674787	672573	08073C	PARTICIPANT	\N	PRESENT	0
674788	672573	14121F	PARTICIPANT	\N	PRESENT	0
674789	669278	20136B	PARTICIPANT	\N	PRESENT	0
674790	669278	19739H	PARTICIPANT	\N	PRESENT	0
674856	672383	14053L	PARTICIPANT	\N	EXCUSE	0
674857	667316	14053L	PARTICIPANT	\N	EXCUSE	0
674858	672785	14189C	PARTICIPANT	\N	EXCUSE	0
674859	672785	20094J	PARTICIPANT	\N	PRESENT	0
674860	672785	19701S	PARTICIPANT	\N	EXCUSE	0
674861	672785	14357A	PARTICIPANT	\N	PRESENT	0
674862	672785	20286Q	PARTICIPANT	\N	EXCUSE	0
674863	672785	14033T	PARTICIPANT	\N	PRESENT	0
674864	672785	19725B	PARTICIPANT	\N	PRESENT	0
674865	672785	19593H	PARTICIPANT	\N	PRESENT	0
674866	672785	14331P	PRESIDENT	0	PRESENT	0
674867	672785	04045F	PARTICIPANT	\N	PRESENT	0
674868	672785	14001X	PARTICIPANT	\N	PRESENT	0
674869	672785	10015M	PARTICIPANT	\N	PRESENT	0
674870	672785	11101A	PARTICIPANT	\N	PRESENT	0
674871	672785	19507S	PARTICIPANT	\N	PRESENT	0
674872	672785	20128B	PARTICIPANT	\N	PRESENT	0
674873	672785	19631V	PARTICIPANT	\N	PRESENT	0
674874	672785	19383Y	PARTICIPANT	\N	PRESENT	0
674875	672785	19782L	PARTICIPANT	\N	PRESENT	0
674876	672785	14207L	PARTICIPANT	\N	PRESENT	0
674877	672785	14038Y	PARTICIPANT	\N	PRESENT	0
674878	672785	08015R	PARTICIPANT	\N	PRESENT	0
674879	672785	14205J	PARTICIPANT	\N	PRESENT	0
674880	672785	14257W	PARTICIPANT	\N	PRESENT	0
674881	672785	19705W	PARTICIPANT	\N	PRESENT	0
674882	672785	20054A	PARTICIPANT	\N	PRESENT	0
674883	672785	11090Q	PARTICIPANT	\N	PRESENT	0
674884	672785	19531S	PARTICIPANT	\N	PRESENT	0
674885	672785	19467C	PARTICIPANT	\N	PRESENT	0
674887	672574	14327T	PARTICIPANT	\N	PRESENT	0
674888	672574	11053K	PARTICIPANT	\N	PRESENT	0
674889	672574	20080C	PARTICIPANT	\N	PRESENT	0
674890	672574	11074Q	PARTICIPANT	\N	PRESENT	0
674891	672574	14225N	PRESIDENT	0	PRESENT	0
674892	672574	20150Y	PARTICIPANT	\N	PRESENT	0
674893	672574	14189C	PARTICIPANT	\N	EXCUSE	0
674894	672574	19741B	PARTICIPANT	\N	PRESENT	0
674895	672574	20050V	PARTICIPANT	\N	PRESENT	0
674896	672574	08034U	PARTICIPANT	\N	PRESENT	0
674897	672574	08073C	PARTICIPANT	\N	PRESENT	0
674898	672574	20126Y	PARTICIPANT	\N	PRESENT	0
674899	672574	11072N	PARTICIPANT	\N	PRESENT	0
674900	672574	19545Y	PARTICIPANT	\N	PRESENT	0
674901	672574	01057W	PARTICIPANT	\N	PRESENT	0
674902	672574	14121F	PARTICIPANT	\N	PRESENT	0
674903	672574	11048N	PARTICIPANT	\N	PRESENT	0
674904	672574	14253S	PARTICIPANT	\N	PRESENT	0
674905	672574	99004R	PARTICIPANT	\N	PRESENT	0
674906	672574	19479G	PARTICIPANT	\N	PRESENT	0
674907	672574	20034V	PARTICIPANT	\N	PRESENT	0
674908	672574	20044X	PARTICIPANT	\N	PRESENT	0
674909	672574	08010L	PARTICIPANT	\N	PRESENT	0
674910	672574	07029T	PARTICIPANT	\N	PRESENT	0
674911	671032	86034E	PARTICIPANT	\N	PRESENT	0
674912	672574	19711U	PARTICIPANT	\N	PRESENT	0
674913	672574	20070A	PARTICIPANT	\N	PRESENT	0
674914	672785	14169X	PARTICIPANT	\N	PRESENT	0
675328	674509	99004R	PARTICIPANT	\N	PRESENT	0
675983	672383	19715Y	PARTICIPANT	\N	PRESENT	0
675984	672383	17023S	PARTICIPANT	\N	PRESENT	0
675985	672383	19295A	PARTICIPANT	\N	EXCUSE	0
676034	667314	14189C	PARTICIPANT	\N	EXCUSE	0
676035	667314	20024T	PARTICIPANT	\N	EXCUSE	0
676036	667314	14030Q	PRESIDENT	0	PRESENT	0
676037	667314	11031D	PARTICIPANT	\N	PRESENT	0
676038	667314	19681G	PARTICIPANT	\N	EXCUSE	0
676039	667314	20066E	PARTICIPANT	\N	PRESENT	0
676040	667314	19715Y	PARTICIPANT	\N	PRESENT	0
676041	667314	07029T	PARTICIPANT	\N	PRESENT	0
676042	667314	14109K	PARTICIPANT	\N	PRESENT	0
676043	667314	20118Y	PARTICIPANT	\N	EXCUSE	0
676044	667314	19798U	PARTICIPANT	\N	PRESENT	0
676045	667314	11045K	PARTICIPANT	\N	PRESENT	0
676046	667314	20098N	PARTICIPANT	\N	PRESENT	0
676049	676048	20112S	PARTICIPANT	\N	PRESENT	0
676336	667316	19295A	PARTICIPANT	\N	PRESENT	0
676337	667316	19715Y	PARTICIPANT	\N	PRESENT	0
676338	667316	12016W	PARTICIPANT	\N	EXCUSE	0
676339	667316	20150Y	PARTICIPANT	\N	PRESENT	0
676360	672578	14327T	PARTICIPANT	\N	PRESENT	0
676341	667316	19301E	PARTICIPANT	\N	PRESENT	0
676343	671039	11045K	PARTICIPANT	\N	PRESENT	0
676344	672578	11048N	PARTICIPANT	\N	PRESENT	0
676345	672578	19647E	PARTICIPANT	\N	PRESENT	0
676346	672578	19545Y	PARTICIPANT	\N	PRESENT	0
676347	672578	20080C	PARTICIPANT	\N	PRESENT	0
676348	672578	11053K	PARTICIPANT	\N	PRESENT	0
676349	672578	20044X	PARTICIPANT	\N	PRESENT	0
676350	672578	14225N	PRESIDENT	0	PRESENT	0
676351	672578	11040E	PARTICIPANT	\N	PRESENT	0
676352	672578	07029T	PARTICIPANT	\N	PRESENT	0
676353	672578	20070A	PARTICIPANT	\N	PRESENT	0
676354	672578	19741B	PARTICIPANT	\N	PRESENT	0
676355	672578	08010L	PARTICIPANT	\N	PRESENT	0
676356	672578	99004R	PARTICIPANT	\N	PRESENT	0
676357	672578	20914V	PARTICIPANT	\N	PRESENT	0
676358	672578	14189C	PARTICIPANT	\N	EXCUSE	0
676359	672578	12016W	PARTICIPANT	\N	EXCUSE	0
676361	672578	19479G	PARTICIPANT	\N	PRESENT	0
676362	672578	04071H	PARTICIPANT	\N	PRESENT	0
676363	672578	19711U	PARTICIPANT	\N	PRESENT	0
676365	676364	05008E	PARTICIPANT	\N	PRESENT	0
676366	676364	11053K	PARTICIPANT	\N	PRESENT	0
676367	676364	01028R	PARTICIPANT	\N	PRESENT	0
676368	672578	01057W	PARTICIPANT	\N	PRESENT	0
676371	671039	11012A	PARTICIPANT	\N	PRESENT	0
676372	671039	11040E	PARTICIPANT	\N	PRESENT	0
676373	671039	20034V	PARTICIPANT	\N	PRESENT	0
676374	671039	20150Y	PARTICIPANT	\N	PRESENT	0
676375	671039	19515S	PARTICIPANT	\N	PRESENT	0
676376	671039	19711U	PARTICIPANT	\N	PRESENT	0
676377	671039	19741B	PARTICIPANT	\N	PRESENT	0
676378	671039	99004R	PARTICIPANT	\N	PRESENT	0
676379	671039	11048N	PARTICIPANT	\N	PRESENT	0
676380	671039	14225N	PARTICIPANT	\N	PRESENT	0
676381	671039	19593H	PARTICIPANT	\N	PRESENT	0
676382	671039	19545Y	PARTICIPANT	\N	PRESENT	0
676383	671039	14327T	PARTICIPANT	\N	PRESENT	0
676384	671039	20044X	PARTICIPANT	\N	PRESENT	0
676385	671039	14191V	PARTICIPANT	\N	PRESENT	0
676386	671039	11072N	PARTICIPANT	\N	PRESENT	0
676387	671039	19525U	PARTICIPANT	\N	PRESENT	0
676388	671039	19693L	PARTICIPANT	\N	PRESENT	0
676389	671039	19715Y	PARTICIPANT	\N	PRESENT	0
676390	671039	08010L	PARTICIPANT	\N	PRESENT	0
676391	671039	20914V	PARTICIPANT	\N	PRESENT	0
676392	671039	20130U	PARTICIPANT	\N	PRESENT	0
676393	671039	01057W	PARTICIPANT	\N	PRESENT	0
676394	671039	11070L	PARTICIPANT	\N	PRESENT	0
676395	671039	07004J	PARTICIPANT	\N	PRESENT	0
676396	671039	19577H	PARTICIPANT	\N	PRESENT	0
676397	671039	11053K	PARTICIPANT	\N	PRESENT	0
676398	671039	07029T	PARTICIPANT	\N	PRESENT	0
676399	671039	20080C	PARTICIPANT	\N	PRESENT	0
676400	671039	20264J	PARTICIPANT	\N	PRESENT	0
676401	671039	14257W	PARTICIPANT	\N	PRESENT	0
655978	655977	14123H	PARTICIPANT	\N	PRESENT	0
655979	655977	14109K	PARTICIPANT	\N	PRESENT	1
655980	655977	19533U	PARTICIPANT	\N	PRESENT	1
655981	655977	19057M	PARTICIPANT	\N	PRESENT	1
655983	655982	14123H	PARTICIPANT	\N	PRESENT	0
655984	655982	14109K	PARTICIPANT	\N	PRESENT	1
655985	655982	20142Y	PARTICIPANT	\N	PRESENT	1
655986	655982	19533U	PARTICIPANT	\N	PRESENT	1
655987	655982	19057M	PARTICIPANT	\N	PRESENT	1
656010	655715	14109K	PARTICIPANT	\N	PRESENT	1
656049	655715	14030Q	PARTICIPANT	\N	PRESENT	0
656050	655715	20152B	PARTICIPANT	\N	PRESENT	0
656051	655977	14030Q	PARTICIPANT	\N	PRESENT	0
656053	655977	19621T	PARTICIPANT	\N	PRESENT	0
656054	655982	14030Q	PARTICIPANT	\N	PRESENT	0
656055	655982	19621T	PARTICIPANT	\N	PRESENT	0
656183	656182	04042C	PARTICIPANT	\N	PRESENT	0
656184	656182	19647E	PARTICIPANT	\N	PRESENT	0
656185	656182	20098N	PARTICIPANT	\N	PRESENT	0
656186	656182	19673G	PARTICIPANT	\N	PRESENT	0
656187	656182	19443T	PARTICIPANT	\N	PRESENT	0
656188	656182	14030Q	PARTICIPANT	\N	PRESENT	0
656189	656182	12028B	PARTICIPANT	\N	PRESENT	0
656190	656182	19507S	PARTICIPANT	\N	PRESENT	0
656191	656182	04033B	PARTICIPANT	\N	PRESENT	0
656192	656182	19515S	PARTICIPANT	\N	PRESENT	0
656193	656182	19569H	PARTICIPANT	\N	PRESENT	0
656194	656182	17737W	PARTICIPANT	\N	PRESENT	0
657711	656717	19697Q	PARTICIPANT	\N	PRESENT	0
657712	656717	11067R	PARTICIPANT	\N	PRESENT	0
657713	656717	20090E	PARTICIPANT	\N	PRESENT	0
657714	656717	14355X	PARTICIPANT	\N	PRESENT	0
657715	656717	19798U	PARTICIPANT	\N	PRESENT	0
657716	656717	19569H	PARTICIPANT	\N	PRESENT	0
657717	656717	11097X	PARTICIPANT	\N	PRESENT	0
657718	656717	18193Q	PARTICIPANT	\N	PRESENT	0
657719	656717	14223L	PARTICIPANT	\N	PRESENT	0
657720	656717	19553Y	PARTICIPANT	\N	PRESENT	0
657721	656717	19703U	PARTICIPANT	\N	PRESENT	0
657722	656717	11031D	PARTICIPANT	\N	PRESENT	0
657723	656717	14281W	PARTICIPANT	\N	PRESENT	0
657724	656717	19679N	PARTICIPANT	\N	PRESENT	0
657725	656717	14042U	PARTICIPANT	\N	PRESENT	0
657726	656717	14195A	PARTICIPANT	\N	PRESENT	0
657727	656717	14213J	PARTICIPANT	\N	PRESENT	0
657728	656717	19367Y	PARTICIPANT	\N	PRESENT	0
657729	656717	14217N	PRESIDENT	1	PRESENT	0
657730	656717	19511N	PARTICIPANT	\N	PRESENT	0
657731	656717	10006L	PRESIDENT	0	PRESENT	0
657732	656717	20130U	PARTICIPANT	\N	PRESENT	0
657733	656717	19713W	PARTICIPANT	\N	PRESENT	0
657735	656717	11045K	PARTICIPANT	\N	PRESENT	0
657737	656717	08045X	PARTICIPANT	\N	PRESENT	0
657738	656717	20040T	PARTICIPANT	\N	PRESENT	0
657740	656717	17965H	PARTICIPANT	\N	PRESENT	0
657741	656717	19691J	PARTICIPANT	\N	PRESENT	0
657744	656717	19715Y	PARTICIPANT	\N	PRESENT	0
657746	656717	20248J	PARTICIPANT	\N	PRESENT	0
657748	656717	20066E	PARTICIPANT	\N	PRESENT	0
657749	656717	11103C	PARTICIPANT	\N	PRESENT	0
657750	656717	14071N	PARTICIPANT	\N	PRESENT	0
657753	656717	04043D	PARTICIPANT	\N	PRESENT	0
657756	656717	19760E	PARTICIPANT	\N	PRESENT	0
657937	656717	01034P	PARTICIPANT	\N	PRESENT	0
657938	656717	04092N	PARTICIPANT	\N	PRESENT	0
657939	656824	14253S	PARTICIPANT	\N	PRESENT	0
657940	656177	19333N	PARTICIPANT	\N	PRESENT	0
657941	656177	20032T	PARTICIPANT	\N	PRESENT	0
657942	656177	19701S	PARTICIPANT	\N	PRESENT	0
657943	656177	20136B	PARTICIPANT	\N	PRESENT	0
657944	656177	14031R	PARTICIPANT	\N	PRESENT	0
657945	656177	20038A	PARTICIPANT	\N	PRESENT	0
657946	656177	19549D	PARTICIPANT	\N	PRESENT	0
657947	656177	19387D	PARTICIPANT	\N	PRESENT	0
657948	656177	19251M	PARTICIPANT	\N	PRESENT	0
657949	656177	14219Q	PRESIDENT	0	PRESENT	0
657950	656177	20046A	PARTICIPANT	\N	PRESENT	0
657951	656177	14221J	PARTICIPANT	\N	PRESENT	0
657952	656177	19826F	PARTICIPANT	\N	PRESENT	0
657953	656177	14169X	PARTICIPANT	\N	PRESENT	0
657954	656177	18083K	PARTICIPANT	\N	PRESENT	0
657955	656177	19551W	PARTICIPANT	\N	PRESENT	0
657956	656177	08060W	PARTICIPANT	\N	PRESENT	0
657957	656177	20106U	PARTICIPANT	\N	PRESENT	0
657958	656177	20068G	PARTICIPANT	\N	PRESENT	0
657959	656177	19739H	PARTICIPANT	\N	PRESENT	0
657960	656177	20020P	PARTICIPANT	\N	PRESENT	0
657961	656177	17367Q	PARTICIPANT	\N	PRESENT	0
657962	656177	19659J	PARTICIPANT	\N	PRESENT	0
657963	656177	20024T	PARTICIPANT	\N	PRESENT	0
657964	656177	19503N	PARTICIPANT	\N	PRESENT	0
657965	656177	11065P	PARTICIPANT	\N	EXCUSE	0
657966	656177	17229F	PARTICIPANT	\N	EXCUSE	0
657967	656177	05012A	PARTICIPANT	\N	PRESENT	0
657968	656177	19525U	PARTICIPANT	\N	PRESENT	0
657969	656177	11101A	PARTICIPANT	\N	PRESENT	0
657970	656177	20100N	PARTICIPANT	\N	PRESENT	0
657971	656177	19820Y	PARTICIPANT	\N	PRESENT	0
657972	656824	19335Q	PARTICIPANT	\N	PRESENT	0
657973	656824	07029T	PARTICIPANT	\N	PRESENT	0
657974	656177	20096L	PARTICIPANT	\N	PRESENT	0
657975	656177	14237S	PARTICIPANT	\N	PRESENT	0
657976	656177	20118Y	PARTICIPANT	\N	PRESENT	0
657978	656177	20102Q	PARTICIPANT	\N	PRESENT	0
657979	656824	20086J	PARTICIPANT	\N	PRESENT	0
657980	656824	14331P	PARTICIPANT	\N	PRESENT	0
657981	656824	19647E	PARTICIPANT	\N	PRESENT	0
657982	656824	14173T	PARTICIPANT	\N	PRESENT	0
657985	656177	19745F	PARTICIPANT	\N	PRESENT	0
657986	656824	19545Y	PARTICIPANT	\N	PRESENT	0
657987	656824	19762G	PARTICIPANT	\N	PRESENT	0
657988	656824	12016W	PARTICIPANT	\N	PRESENT	0
657989	656824	20050V	PARTICIPANT	\N	PRESENT	0
657990	656824	99004R	PARTICIPANT	\N	EXCUSE	0
657991	656824	20150Y	PARTICIPANT	\N	PRESENT	0
657992	656808	08018U	PARTICIPANT	\N	PRESENT	0
657993	656808	19543W	PARTICIPANT	\N	PRESENT	0
657994	656177	19599P	PARTICIPANT	\N	PRESENT	0
657995	656177	19685L	PARTICIPANT	\N	PRESENT	0
657996	656177	20120S	PARTICIPANT	\N	PRESENT	0
658682	656883	95063L	PARTICIPANT	\N	PRESENT	0
658690	656178	20032T	PARTICIPANT	\N	PRESENT	0
658691	656178	20136B	PARTICIPANT	\N	PRESENT	0
658692	656178	19549D	PARTICIPANT	\N	PRESENT	0
658693	656178	19387D	PARTICIPANT	\N	PRESENT	0
658694	656178	14219Q	PRESIDENT	0	PRESENT	0
658695	656178	19251M	PARTICIPANT	\N	PRESENT	0
658696	656178	19820Y	PARTICIPANT	\N	PRESENT	0
658697	656178	20046A	PARTICIPANT	\N	PRESENT	0
658698	656178	20102Q	PARTICIPANT	\N	PRESENT	0
658699	656178	19599P	PARTICIPANT	\N	PRESENT	0
658700	656178	17229F	PARTICIPANT	\N	PRESENT	0
658701	656178	20100N	PARTICIPANT	\N	PRESENT	0
658702	656178	18083K	PARTICIPANT	\N	PRESENT	0
658703	656178	19551W	PARTICIPANT	\N	PRESENT	0
658704	656178	20106U	PARTICIPANT	\N	PRESENT	0
658705	656178	08060W	PARTICIPANT	\N	PRESENT	0
658706	656178	19503N	PARTICIPANT	\N	PRESENT	0
658707	656178	19619A	PARTICIPANT	\N	PRESENT	0
658711	656178	20038A	PARTICIPANT	\N	PRESENT	0
658712	656178	19826F	PARTICIPANT	\N	PRESENT	0
658713	656178	19685L	PARTICIPANT	\N	PRESENT	0
658716	656178	19333N	PARTICIPANT	\N	PRESENT	0
658717	656178	19745F	PARTICIPANT	\N	PRESENT	0
658718	656178	19637C	PARTICIPANT	\N	PRESENT	0
658719	656178	19525U	PARTICIPANT	\N	PRESENT	0
658721	656883	12041X	PARTICIPANT	\N	PRESENT	0
658722	656883	19565D	PARTICIPANT	\N	PRESENT	0
658723	656883	12028B	PARTICIPANT	\N	PRESENT	0
658725	656883	20080C	PARTICIPANT	\N	PRESENT	0
658726	656883	20264J	PARTICIPANT	\N	PRESENT	0
658727	656178	14221J	PARTICIPANT	\N	PRESENT	0
658728	656178	20120S	PARTICIPANT	\N	PRESENT	0
658729	656883	20082E	PARTICIPANT	\N	PRESENT	0
658730	656883	20064C	PARTICIPANT	\N	PRESENT	0
658731	656883	11026G	PARTICIPANT	\N	PRESENT	0
658885	656884	11064N	PARTICIPANT	\N	PRESENT	0
658886	656884	11099A	PARTICIPANT	\N	PRESENT	0
658900	656884	11072N	PARTICIPANT	\N	PRESENT	0
659059	659058	19515S	PRESIDENT	0	PRESENT	0
659060	659058	19762G	PARTICIPANT	\N	PRESENT	0
677654	676426	20080C	PARTICIPANT	\N	PRESENT	0
677655	676426	19741B	PARTICIPANT	\N	PRESENT	0
677656	676426	20172F	PARTICIPANT	\N	PRESENT	0
677657	676426	14219Q	PARTICIPANT	\N	PRESENT	0
677658	676426	19768N	PARTICIPANT	\N	PRESENT	0
677659	676426	19387D	PARTICIPANT	\N	PRESENT	0
677660	676426	14083S	PARTICIPANT	\N	PRESENT	0
677724	675257	10006L	PARTICIPANT	\N	PRESENT	0
677725	675257	14195A	PARTICIPANT	\N	PRESENT	0
677726	675257	11031D	PARTICIPANT	\N	PRESENT	0
677727	675257	19367Y	PARTICIPANT	\N	PRESENT	0
677728	675257	18193Q	PARTICIPANT	\N	PRESENT	0
677729	675257	20040T	PARTICIPANT	\N	PRESENT	0
677730	675257	19798U	PARTICIPANT	\N	PRESENT	0
677731	675257	14223L	PARTICIPANT	\N	PRESENT	0
677732	675257	19511N	PARTICIPANT	\N	PRESENT	0
677733	675257	14071N	PARTICIPANT	\N	PRESENT	0
677734	675257	19679N	PARTICIPANT	\N	PRESENT	0
677735	675257	19553Y	PARTICIPANT	\N	PRESENT	0
677736	675257	11103C	PARTICIPANT	\N	PRESENT	0
677737	675257	19703U	PARTICIPANT	\N	PRESENT	0
677738	675257	11067R	PARTICIPANT	\N	PRESENT	0
677739	675257	20130U	PARTICIPANT	\N	PRESENT	0
677740	675257	14281W	PARTICIPANT	\N	PRESENT	0
677741	675257	19691J	PARTICIPANT	\N	PRESENT	0
677742	675257	04092N	PARTICIPANT	\N	PRESENT	0
677743	675257	14213J	PARTICIPANT	\N	PRESENT	0
677744	675257	14217N	PARTICIPANT	\N	PRESENT	0
677745	675257	11097X	PARTICIPANT	\N	PRESENT	0
677746	675257	19663E	PARTICIPANT	\N	PRESENT	0
677747	675257	14355X	PARTICIPANT	\N	PRESENT	0
677748	675257	19717B	PARTICIPANT	\N	PRESENT	0
677749	675257	19329S	PARTICIPANT	\N	PRESENT	0
677750	675257	19715Y	PARTICIPANT	\N	PRESENT	0
677751	675257	20148F	PARTICIPANT	\N	PRESENT	0
677752	675257	11045K	PARTICIPANT	\N	PRESENT	0
677753	675257	14042U	PARTICIPANT	\N	PRESENT	0
677778	675257	19657G	PARTICIPANT	\N	PRESENT	0
677781	675257	14026U	PARTICIPANT	\N	PRESENT	0
677782	675257	17779H	PARTICIPANT	\N	PRESENT	0
677784	675257	19713W	PARTICIPANT	\N	PRESENT	0
677796	675257	20248J	PARTICIPANT	\N	PRESENT	0
677797	675257	20066E	PARTICIPANT	\N	PRESENT	0
677801	675257	08045X	PARTICIPANT	\N	PRESENT	0
677815	675257	01034P	PARTICIPANT	\N	PRESENT	0
677828	675257	04043D	PARTICIPANT	\N	PRESENT	0
677855	675257	19697Q	PARTICIPANT	\N	PRESENT	0
677856	675257	04057K	PARTICIPANT	\N	PRESENT	0
677857	675257	17965H	PARTICIPANT	\N	PRESENT	0
677862	675257	19723Y	PARTICIPANT	\N	PRESENT	0
677863	675257	19295A	PARTICIPANT	\N	PRESENT	0
677865	675257	19569H	PARTICIPANT	\N	PRESENT	0
677871	675257	20266L	PARTICIPANT	\N	PRESENT	0
677875	675257	19591F	PARTICIPANT	\N	PRESENT	0
677876	675257	19760E	PARTICIPANT	\N	PRESENT	0
678031	677483	08028W	PARTICIPANT	\N	EXCUSE	0
678032	677483	14205J	PARTICIPANT	\N	PRESENT	0
678034	677483	19762G	PARTICIPANT	\N	PRESENT	0
678035	677483	20086J	PARTICIPANT	\N	PRESENT	0
678740	674845	20050V	PARTICIPANT	\N	PRESENT	0
678741	674845	11074Q	PARTICIPANT	\N	PRESENT	0
678742	674845	14331P	PARTICIPANT	\N	PRESENT	0
678873	678872	20024T	PARTICIPANT	\N	PRESENT	0
678874	678872	19643A	PARTICIPANT	\N	PRESENT	0
678875	678872	19782L	PARTICIPANT	\N	PRESENT	0
678876	678872	19525U	PARTICIPANT	\N	PRESENT	0
678877	678872	17229F	PARTICIPANT	\N	PRESENT	0
678878	678872	01024M	PARTICIPANT	\N	PRESENT	0
678879	678872	14042U	PARTICIPANT	\N	PRESENT	0
678880	678872	01025N	PARTICIPANT	\N	PRESENT	0
678881	678872	04035D	PARTICIPANT	\N	PRESENT	0
678882	678872	11026G	PARTICIPANT	\N	PRESENT	0
678883	678872	08009T	PARTICIPANT	\N	PRESENT	0
678884	678872	14147R	PARTICIPANT	\N	PRESENT	0
678885	678872	14223L	PARTICIPANT	\N	PRESENT	0
678886	678872	19798U	PARTICIPANT	\N	PRESENT	0
678887	678872	19713W	PARTICIPANT	\N	PRESENT	0
679167	678423	19954N	PARTICIPANT	\N	PRESENT	0
679168	678423	11056N	PARTICIPANT	\N	PRESENT	0
679169	678423	14259Y	PARTICIPANT	\N	PRESENT	0
679170	678423	95063L	PARTICIPANT	\N	PRESENT	0
679171	678423	19703U	PARTICIPANT	\N	PRESENT	0
679172	678423	19747H	PARTICIPANT	\N	PRESENT	0
679173	678423	20068G	PARTICIPANT	\N	PRESENT	0
679174	678423	20132W	PARTICIPANT	\N	PRESENT	0
679175	678423	11097X	PARTICIPANT	\N	PRESENT	0
679176	678423	20044X	PARTICIPANT	\N	PRESENT	0
679177	678423	20018V	PARTICIPANT	\N	PRESENT	0
681219	676615	19467C	PARTICIPANT	\N	PRESENT	0
681218	676615	14038Y	PARTICIPANT	\N	PRESENT	0
681161	676615	20044X	PARTICIPANT	\N	PRESENT	0
681162	676615	18193Q	PARTICIPANT	\N	PRESENT	0
681212	676615	19760E	PARTICIPANT	\N	PRESENT	0
681213	676615	20130U	PARTICIPANT	\N	PRESENT	0
681165	676615	19651A	PARTICIPANT	\N	PRESENT	0
681214	676615	14147R	PARTICIPANT	\N	PRESENT	0
681167	676615	08028W	PARTICIPANT	\N	PRESENT	0
681220	676615	14223L	PARTICIPANT	\N	PRESENT	0
681169	676615	04057K	PARTICIPANT	\N	PRESENT	0
681221	676615	11040E	PARTICIPANT	\N	PRESENT	0
681171	676615	08034U	PARTICIPANT	\N	PRESENT	0
681215	676615	14030Q	PARTICIPANT	\N	PRESENT	0
681216	676615	19533U	PARTICIPANT	\N	PRESENT	0
681217	676615	20062A	PARTICIPANT	\N	PRESENT	0
681222	676615	19703U	PARTICIPANT	\N	PRESENT	0
681176	676615	14083S	PARTICIPANT	\N	PRESENT	0
681223	676615	19591F	PARTICIPANT	\N	PRESENT	0
681178	676615	20266L	PARTICIPANT	\N	PRESENT	0
681179	676615	20084G	PARTICIPANT	\N	PRESENT	0
681180	676615	20058E	PARTICIPANT	\N	PRESENT	0
681224	676615	14121F	PARTICIPANT	\N	PRESENT	0
681182	676615	01024M	PARTICIPANT	\N	PRESENT	0
681225	676615	14107H	PARTICIPANT	\N	PRESENT	0
681226	676615	20252E	PARTICIPANT	\N	PRESENT	0
681227	676615	20090E	PARTICIPANT	\N	PRESENT	0
681228	676615	19525U	PARTICIPANT	\N	PRESENT	0
681229	676615	20116W	PARTICIPANT	\N	PRESENT	0
681230	676615	18083K	PARTICIPANT	\N	PRESENT	0
681189	676615	95063L	PARTICIPANT	\N	PRESENT	0
681231	676615	14133K	PARTICIPANT	\N	PRESENT	0
681232	676615	19575F	PARTICIPANT	\N	PRESENT	0
681233	676615	20056C	PARTICIPANT	\N	PRESENT	0
681193	676615	20026V	PARTICIPANT	\N	PRESENT	0
681194	676615	20038A	PARTICIPANT	\N	PRESENT	0
681234	676615	20024T	PARTICIPANT	\N	PRESENT	0
681235	676615	14195A	PARTICIPANT	\N	PRESENT	0
681197	676615	01058X	PARTICIPANT	\N	PRESENT	0
681198	676615	20142Y	PARTICIPANT	\N	PRESENT	0
681236	676615	19479G	PARTICIPANT	\N	PRESENT	0
681237	676615	19739H	PARTICIPANT	\N	PRESENT	0
681238	676615	14033T	PARTICIPANT	\N	PRESENT	0
681202	676615	19747H	PARTICIPANT	\N	PRESENT	0
681239	676615	19387D	PARTICIPANT	\N	PRESENT	0
681240	676615	14042U	PARTICIPANT	\N	PRESENT	0
681241	676615	20114U	PARTICIPANT	\N	PRESENT	0
681242	676615	19599P	PARTICIPANT	\N	PRESENT	0
681207	676615	19637C	PARTICIPANT	\N	PRESENT	0
681208	676615	19741B	PARTICIPANT	\N	PRESENT	0
681243	676615	19723Y	PARTICIPANT	\N	PRESENT	0
681244	676615	19725B	PARTICIPANT	\N	PRESENT	0
681211	676615	19667J	PARTICIPANT	\N	PRESENT	0
681245	676615	19762G	PARTICIPANT	\N	PRESENT	0
681246	676615	14031R	PARTICIPANT	\N	PRESENT	0
681251	676615	11033F	PARTICIPANT	\N	PRESENT	0
681252	676615	14237S	PARTICIPANT	\N	PRESENT	0
681253	676615	19683J	PARTICIPANT	\N	PRESENT	0
681254	676615	20082E	PARTICIPANT	\N	PRESENT	0
681255	676615	11053K	PARTICIPANT	\N	PRESENT	0
681256	676615	20140W	PARTICIPANT	\N	PRESENT	0
681257	676615	19729F	PARTICIPANT	\N	PRESENT	0
681258	676615	14073Q	PARTICIPANT	\N	PRESENT	0
681259	676615	20064C	PARTICIPANT	\N	PRESENT	0
681260	676615	20040T	PARTICIPANT	\N	PRESENT	0
681261	676615	08015R	PARTICIPANT	\N	PRESENT	0
681262	676615	14105F	PARTICIPANT	\N	PRESENT	0
681263	676615	11045K	PARTICIPANT	\N	PRESENT	0
681264	676615	01025N	PARTICIPANT	\N	PRESENT	0
681265	676615	14173T	PARTICIPANT	\N	PRESENT	0
681266	676615	10006L	PARTICIPANT	\N	PRESENT	0
681267	676615	19441R	PARTICIPANT	\N	PRESENT	0
681268	676615	20054A	PARTICIPANT	\N	PRESENT	0
656344	656343	19565D	PARTICIPANT	\N	PRESENT	0
656345	656052	14133K	PARTICIPANT	\N	EXCUSE	0
656346	656052	14189C	PARTICIPANT	\N	PRESENT	0
656347	656052	20104S	PARTICIPANT	\N	EXCUSE	0
656348	656052	19507S	PARTICIPANT	\N	PRESENT	0
656349	656052	11083R	PARTICIPANT	\N	PRESENT	0
656350	656052	19725B	PARTICIPANT	\N	PRESENT	0
656351	656052	19531S	PARTICIPANT	\N	PRESENT	0
656352	656052	14073Q	PARTICIPANT	\N	PRESENT	0
656353	656052	12041X	PARTICIPANT	\N	PRESENT	0
656354	656052	11026G	PARTICIPANT	\N	PRESENT	0
656355	656052	19441R	PARTICIPANT	\N	PRESENT	0
656392	656052	14001X	PARTICIPANT	\N	PRESENT	0
656393	656052	19563B	PARTICIPANT	\N	PRESENT	0
656394	656052	04070G	PARTICIPANT	\N	EXCUSE	0
656395	656052	19593H	PARTICIPANT	\N	EXCUSE	0
656396	656052	14237S	PARTICIPANT	\N	PRESENT	0
656397	656052	14331P	PRESIDENT	0	PRESENT	0
656398	656052	04045F	PARTICIPANT	\N	PRESENT	0
656466	656119	19725B	PARTICIPANT	\N	PRESENT	0
656467	656119	14111D	PARTICIPANT	\N	PRESENT	0
656468	656119	95063L	PARTICIPANT	\N	PRESENT	0
656469	656119	07004J	PARTICIPANT	\N	PRESENT	0
656470	656119	20108W	PARTICIPANT	\N	PRESENT	0
656471	656119	14147R	PARTICIPANT	\N	PRESENT	0
656472	656119	14215L	PARTICIPANT	\N	PRESENT	0
656473	656119	04047H	PARTICIPANT	\N	PRESENT	0
656474	656119	11072N	PARTICIPANT	\N	PRESENT	0
656475	656119	05008E	PARTICIPANT	\N	PRESENT	0
656476	656046	19479G	PARTICIPANT	\N	PRESENT	0
656477	656046	19711U	PARTICIPANT	\N	PRESENT	0
656478	656046	20070A	PARTICIPANT	\N	PRESENT	0
656479	656046	19349W	PARTICIPANT	\N	PRESENT	0
656480	656046	11053K	PARTICIPANT	\N	PRESENT	0
656481	656046	99004R	PARTICIPANT	\N	PRESENT	0
656482	656046	14253S	PARTICIPANT	\N	PRESENT	0
656483	656046	11110B	PARTICIPANT	\N	PRESENT	0
656484	656046	20044X	PARTICIPANT	\N	PRESENT	0
656485	656119	10015M	PARTICIPANT	\N	PRESENT	0
656486	656119	20110Q	PARTICIPANT	\N	PRESENT	0
656487	656119	08018U	PARTICIPANT	\N	PRESENT	0
656488	656046	20080C	PARTICIPANT	\N	PRESENT	0
656489	652051	19527W	PARTICIPANT	\N	PRESENT	0
656490	652051	20132W	PARTICIPANT	\N	PRESENT	0
656491	652051	19643A	PARTICIPANT	\N	PRESENT	0
656492	652051	04070G	PARTICIPANT	\N	PRESENT	0
656493	652051	19533U	PARTICIPANT	\N	PRESENT	0
656494	652051	19611R	PARTICIPANT	\N	PRESENT	0
656495	652051	20142Y	PARTICIPANT	\N	PRESENT	0
656496	652051	19693L	PARTICIPANT	\N	PRESENT	0
656497	652051	19399H	PARTICIPANT	\N	PRESENT	0
656498	652051	20052X	PARTICIPANT	\N	PRESENT	0
656499	652051	20152B	PARTICIPANT	\N	PRESENT	0
656500	652051	20056C	PARTICIPANT	\N	PRESENT	0
656501	652051	04059M	PARTICIPANT	\N	PRESENT	0
656502	652051	20124W	PARTICIPANT	\N	PRESENT	0
656503	652051	19758L	PARTICIPANT	\N	PRESENT	0
656504	652051	20026V	PARTICIPANT	\N	PRESENT	0
656505	656046	19667J	PARTICIPANT	\N	PRESENT	0
656506	652051	20048C	PARTICIPANT	\N	PRESENT	0
656507	652051	14229S	PARTICIPANT	\N	PRESENT	0
656508	652051	08012N	PARTICIPANT	\N	PRESENT	0
656509	652051	19593H	PARTICIPANT	\N	EXCUSE	0
656510	652051	11109J	PARTICIPANT	\N	EXCUSE	0
656511	652051	14109K	PARTICIPANT	\N	EXCUSE	0
656512	652051	14030Q	PARTICIPANT	\N	EXCUSE	0
656513	656046	19335Q	PARTICIPANT	\N	PRESENT	0
656514	656119	19649G	PARTICIPANT	\N	PRESENT	0
656515	656119	01028R	PARTICIPANT	\N	PRESENT	0
656516	656119	11056N	PARTICIPANT	\N	PRESENT	0
656517	656119	19489J	PARTICIPANT	\N	PRESENT	0
656518	656119	14151M	PARTICIPANT	\N	PRESENT	0
656519	656119	20022R	PARTICIPANT	\N	PRESENT	0
656520	656119	17737W	PARTICIPANT	\N	PRESENT	0
656521	656119	14069U	PARTICIPANT	\N	PRESENT	0
656523	656119	14259Y	PARTICIPANT	\N	PRESENT	0
656524	656119	19729F	PARTICIPANT	\N	EXCUSE	0
656525	656119	14231L	PARTICIPANT	\N	EXCUSE	0
656526	656119	14107H	PARTICIPANT	\N	PRESENT	0
656527	656119	14089Y	PARTICIPANT	\N	PRESENT	0
656528	656119	19629C	PARTICIPANT	\N	PRESENT	0
656529	656046	19647E	PARTICIPANT	\N	PRESENT	0
656530	656046	07029T	PARTICIPANT	\N	PRESENT	0
656531	656046	08010L	PARTICIPANT	\N	PRESENT	0
656532	656046	19741B	PARTICIPANT	\N	PRESENT	0
656533	656046	20126Y	PARTICIPANT	\N	PRESENT	0
656534	656119	14179A	PARTICIPANT	\N	PRESENT	0
656535	656119	11026G	PARTICIPANT	\N	PRESENT	0
656553	656119	20114U	PARTICIPANT	\N	PRESENT	0
656563	656119	11010L	PARTICIPANT	\N	PRESENT	0
656564	656119	14021P	PARTICIPANT	\N	PRESENT	0
656566	656046	20086J	PARTICIPANT	\N	PRESENT	0
656578	652051	19651A	PARTICIPANT	\N	PRESENT	0
656579	652051	14073Q	PARTICIPANT	\N	PRESENT	0
656580	652051	19573D	PARTICIPANT	\N	PRESENT	0
656581	652051	19621T	PARTICIPANT	\N	PRESENT	0
656583	656063	20136B	PARTICIPANT	\N	PRESENT	0
656609	656582	20086J	PARTICIPANT	\N	PRESENT	0
656610	656582	11048N	PARTICIPANT	\N	PRESENT	0
656611	656582	19711U	PARTICIPANT	\N	PRESENT	0
656612	656582	19349W	PARTICIPANT	\N	PRESENT	0
656613	656582	11053K	PARTICIPANT	\N	PRESENT	0
656614	656582	19741B	PARTICIPANT	\N	PRESENT	0
656615	656582	20914V	PARTICIPANT	\N	PRESENT	0
656616	656582	14253S	PARTICIPANT	\N	PRESENT	0
656617	656582	19671E	PARTICIPANT	\N	PRESENT	0
656618	656582	14225N	PRESIDENT	0	PRESENT	0
656619	656582	20126Y	PARTICIPANT	\N	PRESENT	0
656620	656582	11012A	PARTICIPANT	\N	EXCUSE	0
656621	656582	08034U	PARTICIPANT	\N	EXCUSE	0
656622	656582	14189C	PARTICIPANT	\N	EXCUSE	0
656623	656582	20050V	PARTICIPANT	\N	EXCUSE	0
656624	656582	19667J	PARTICIPANT	\N	PRESENT	0
656625	656582	20080C	PARTICIPANT	\N	PRESENT	0
656626	656582	01057W	PARTICIPANT	\N	PRESENT	0
656627	656582	20070A	PARTICIPANT	\N	PRESENT	0
656628	656582	19647E	PARTICIPANT	\N	PRESENT	0
656629	656582	99004R	PARTICIPANT	\N	PRESENT	0
656630	656582	20044X	PARTICIPANT	\N	PRESENT	0
656631	656465	19383Y	PARTICIPANT	\N	PRESENT	0
656632	656465	19768N	PARTICIPANT	\N	PRESENT	0
656633	656465	19515S	PARTICIPANT	\N	PRESENT	0
656634	656465	19782L	PARTICIPANT	\N	PRESENT	0
656635	656465	20092G	PARTICIPANT	\N	PRESENT	0
656636	656465	19441R	PARTICIPANT	\N	PRESENT	0
656637	656465	20094J	PARTICIPANT	\N	PRESENT	0
656638	656465	04045F	PARTICIPANT	\N	PRESENT	0
656639	656465	19866P	PARTICIPANT	\N	PRESENT	0
656640	656465	11099A	PARTICIPANT	\N	PRESENT	0
656641	656465	19705W	PARTICIPANT	\N	PRESENT	0
656642	656465	19575F	PARTICIPANT	\N	PRESENT	0
656643	656465	19369B	PARTICIPANT	\N	PRESENT	0
656644	656465	20018V	PARTICIPANT	\N	PRESENT	0
656645	656465	19563B	PARTICIPANT	\N	PRESENT	0
656646	656465	20028X	PARTICIPANT	\N	PRESENT	0
656647	656465	20030R	PARTICIPANT	\N	PRESENT	0
656648	656465	20144B	PARTICIPANT	\N	PRESENT	0
656649	656465	11090Q	PRESIDENT	0	PRESENT	0
656650	656465	14033T	PARTICIPANT	\N	PRESENT	0
656651	656465	20054A	PARTICIPANT	\N	PRESENT	0
656652	656465	14205J	PARTICIPANT	\N	PRESENT	0
656653	656465	20060X	PARTICIPANT	\N	PRESENT	0
656654	656465	20062A	PARTICIPANT	\N	PRESENT	0
656655	656465	14251Q	PARTICIPANT	\N	PRESENT	0
656656	656465	19507S	PARTICIPANT	\N	PRESENT	0
656657	656465	14207L	PARTICIPANT	\N	PRESENT	0
656658	656465	19747H	PARTICIPANT	\N	PRESENT	0
656659	656465	14257W	PARTICIPANT	\N	PRESENT	0
656660	656582	07029T	PARTICIPANT	\N	PRESENT	0
656661	656582	11110B	PARTICIPANT	\N	PRESENT	0
656662	656582	14327T	PARTICIPANT	\N	PRESENT	0
656663	656582	14083S	PARTICIPANT	\N	PRESENT	0
656667	656582	19762G	PARTICIPANT	\N	PRESENT	0
659567	659565	19593H	PARTICIPANT	\N	PRESENT	0
660283	659193	11067R	PARTICIPANT	\N	PRESENT	0
660284	659193	20090E	PARTICIPANT	\N	PRESENT	0
660285	659193	19569H	PARTICIPANT	\N	PRESENT	0
659566	659565	19651A	PARTICIPANT	\N	PRESENT	0
660286	659193	11097X	PARTICIPANT	\N	PRESENT	0
660287	659193	19415P	PARTICIPANT	\N	PRESENT	0
660288	659193	18193Q	PARTICIPANT	\N	PRESENT	0
676402	671039	20070A	PARTICIPANT	\N	PRESENT	0
676403	671039	19647E	PARTICIPANT	\N	PRESENT	0
676404	671039	08073C	PARTICIPANT	\N	PRESENT	0
676405	671039	19335Q	PARTICIPANT	\N	PRESENT	0
676406	671039	01048V	PARTICIPANT	\N	PRESENT	0
676407	671039	19671E	PARTICIPANT	\N	PRESENT	0
676408	671039	19713W	PARTICIPANT	\N	PRESENT	0
676409	671039	19651A	PARTICIPANT	\N	PRESENT	0
676410	671039	19479G	PARTICIPANT	\N	PRESENT	0
676411	671039	19295A	PARTICIPANT	\N	PRESENT	0
676421	671039	19657G	PARTICIPANT	\N	PRESENT	0
676428	671039	11074Q	PARTICIPANT	\N	PRESENT	0
676430	671039	11026G	PARTICIPANT	\N	PRESENT	0
676438	671039	04071H	PARTICIPANT	\N	PRESENT	0
676444	671039	20086J	PARTICIPANT	\N	PRESENT	0
676442	671039	19691J	PARTICIPANT	\N	PRESENT	0
676443	671039	19820Y	PARTICIPANT	\N	PRESENT	0
676445	671039	08034U	PARTICIPANT	\N	PRESENT	0
676446	671039	20094J	PARTICIPANT	\N	PRESENT	0
676447	671039	19301E	PARTICIPANT	\N	PRESENT	0
676448	671039	20148F	PARTICIPANT	\N	PRESENT	0
676449	671039	20134Y	PARTICIPANT	\N	PRESENT	0
676496	671040	14191V	PARTICIPANT	\N	PRESENT	0
676497	671040	11040E	PARTICIPANT	\N	PRESENT	0
676498	671040	20134Y	PARTICIPANT	\N	PRESENT	0
676499	671040	19301E	PARTICIPANT	\N	PRESENT	0
676500	671040	20094J	PARTICIPANT	\N	PRESENT	0
676501	671040	20130U	PARTICIPANT	\N	PRESENT	0
676502	671040	19593H	PARTICIPANT	\N	PRESENT	0
676503	671040	19647E	PARTICIPANT	\N	PRESENT	0
676504	671040	19525U	PARTICIPANT	\N	PRESENT	0
676505	671040	20150Y	PARTICIPANT	\N	PRESENT	0
676506	671040	19717B	PARTICIPANT	\N	PRESENT	0
676507	671040	11048N	PARTICIPANT	\N	PRESENT	0
676508	671040	14225N	PARTICIPANT	\N	PRESENT	0
676509	671040	14257W	PARTICIPANT	\N	PRESENT	0
676510	671040	19479G	PARTICIPANT	\N	PRESENT	0
676511	671040	19515S	PARTICIPANT	\N	PRESENT	0
676512	671040	19691J	PARTICIPANT	\N	PRESENT	0
676513	671040	19577H	PARTICIPANT	\N	PRESENT	0
676514	671040	99004R	PARTICIPANT	\N	PRESENT	0
676515	671040	07004J	PARTICIPANT	\N	PRESENT	0
676523	671040	20070A	PARTICIPANT	\N	PRESENT	0
676517	671040	08034U	PARTICIPANT	\N	PRESENT	0
676518	671040	19711U	PARTICIPANT	\N	PRESENT	0
676519	671040	20044X	PARTICIPANT	\N	PRESENT	0
676520	671040	19657G	PARTICIPANT	\N	PRESENT	0
676521	671040	20148F	PARTICIPANT	\N	PRESENT	0
676522	671040	19741B	PARTICIPANT	\N	PRESENT	0
676524	671040	19820Y	PARTICIPANT	\N	PRESENT	0
676525	671040	20080C	PARTICIPANT	\N	PRESENT	0
676526	671040	11026G	PARTICIPANT	\N	PRESENT	0
676527	671040	14327T	PARTICIPANT	\N	PRESENT	0
676528	671040	20034V	PARTICIPANT	\N	PRESENT	0
676529	671040	07029T	PARTICIPANT	\N	PRESENT	0
676530	671040	01057W	PARTICIPANT	\N	PRESENT	0
676531	671040	08010L	PARTICIPANT	\N	PRESENT	0
676532	671040	19545Y	PARTICIPANT	\N	PRESENT	0
676533	671040	19715Y	PARTICIPANT	\N	PRESENT	0
676534	671040	20086J	PARTICIPANT	\N	PRESENT	0
676535	671040	14205J	PARTICIPANT	\N	PRESENT	0
676536	671040	14083S	PARTICIPANT	\N	PRESENT	0
676537	671040	19295A	PARTICIPANT	\N	PRESENT	0
676538	671040	04071H	PARTICIPANT	\N	PRESENT	0
676539	671040	11074Q	PARTICIPANT	\N	PRESENT	0
677427	677426	20022R	PARTICIPANT	\N	PRESENT	0
676494	671040	95063L	PARTICIPANT	\N	PRESENT	0
676495	671040	20914V	PARTICIPANT	\N	PRESENT	0
677429	677428	20022R	PARTICIPANT	\N	PRESENT	0
677430	677428	14151M	PARTICIPANT	\N	PRESENT	0
677959	677928	20066E	PARTICIPANT	\N	PRESENT	0
677963	677961	20066E	PARTICIPANT	\N	PRESENT	0
677965	677964	20066E	PARTICIPANT	\N	PRESENT	0
677967	677966	20066E	PARTICIPANT	\N	PRESENT	0
677971	677969	19533U	PARTICIPANT	\N	PRESENT	0
678099	674845	04070G	PARTICIPANT	\N	EXCUSE	0
678891	678423	19643A	PARTICIPANT	\N	EXCUSE	0
678939	678938	19447X	PARTICIPANT	\N	PRESENT	0
678940	678938	20114U	PARTICIPANT	\N	PRESENT	0
680577	679535	19741B	PARTICIPANT	\N	PRESENT	0
680922	678420	19511N	PARTICIPANT	\N	PRESENT	0
680953	680952	17737W	PARTICIPANT	\N	PRESENT	0
680954	680952	19760E	PARTICIPANT	\N	PRESENT	0
680955	680952	14069U	PARTICIPANT	\N	PRESENT	0
680956	680952	19643A	PARTICIPANT	\N	PRESENT	0
680957	680952	11026G	PARTICIPANT	\N	PRESENT	0
680958	680952	19713W	PARTICIPANT	\N	PRESENT	0
681025	676613	19719D	PARTICIPANT	\N	PRESENT	0
681028	676613	07029T	PARTICIPANT	\N	PRESENT	0
681032	676613	20032T	PARTICIPANT	\N	PRESENT	0
681033	676613	04085P	PARTICIPANT	\N	PRESENT	0
681034	676613	19954N	PARTICIPANT	\N	PRESENT	0
681035	676613	20086J	PARTICIPANT	\N	PRESENT	0
681036	676613	14069U	PARTICIPANT	\N	PRESENT	0
681037	676613	20088L	PARTICIPANT	\N	PRESENT	0
681038	676613	14105F	PARTICIPANT	\N	PRESENT	0
681039	676613	20090E	PARTICIPANT	\N	PRESENT	0
681040	676613	14053L	PARTICIPANT	\N	PRESENT	0
681041	676613	18083K	PARTICIPANT	\N	PRESENT	0
681042	676613	19681G	PARTICIPANT	\N	PRESENT	0
681043	676613	20070A	PARTICIPANT	\N	PRESENT	0
681044	676613	20140W	PARTICIPANT	\N	PRESENT	0
681045	676613	19251M	PARTICIPANT	\N	PRESENT	0
681046	676613	14249W	PARTICIPANT	\N	PRESENT	0
681047	676613	19673G	PARTICIPANT	\N	PRESENT	0
681048	676613	19647E	PARTICIPANT	\N	PRESENT	0
681049	676613	14231L	PARTICIPANT	\N	PRESENT	0
681050	676613	19695N	PARTICIPANT	\N	PRESENT	0
681051	676613	19387D	PARTICIPANT	\N	PRESENT	0
681052	676613	19347U	PARTICIPANT	\N	PRESENT	0
681053	676613	19565D	PARTICIPANT	\N	PRESENT	0
681054	676613	14026U	PARTICIPANT	\N	PRESENT	0
681055	676613	19691J	PARTICIPANT	\N	PRESENT	0
681056	676613	19725B	PARTICIPANT	\N	PRESENT	0
681057	676613	20128B	PARTICIPANT	\N	PRESENT	0
681058	676613	20066E	PARTICIPANT	\N	PRESENT	0
681059	676613	14097Y	PARTICIPANT	\N	PRESENT	0
681060	676613	19735D	PARTICIPANT	\N	PRESENT	0
681061	676613	19611R	PARTICIPANT	\N	PRESENT	0
681062	676613	18193Q	PARTICIPANT	\N	PRESENT	0
681063	676613	14037X	PARTICIPANT	\N	PRESENT	0
681064	676613	14205J	PARTICIPANT	\N	PRESENT	0
681065	676613	14147R	PARTICIPANT	\N	PRESENT	0
681066	676613	11072N	PARTICIPANT	\N	PRESENT	0
681067	676613	19768N	PARTICIPANT	\N	PRESENT	0
681068	676613	19573D	PARTICIPANT	\N	PRESENT	0
681069	676613	14193X	PARTICIPANT	\N	PRESENT	0
681070	676613	19533U	PARTICIPANT	\N	PRESENT	0
681071	676613	19319Q	PARTICIPANT	\N	PRESENT	0
681072	676613	19443T	PARTICIPANT	\N	PRESENT	0
681073	676613	11054L	PARTICIPANT	\N	PRESENT	0
681074	676613	14107H	PARTICIPANT	\N	PRESENT	0
681075	676613	20092G	PARTICIPANT	\N	PRESENT	0
681076	676613	04045F	PARTICIPANT	\N	PRESENT	0
681077	676613	01058X	PARTICIPANT	\N	PRESENT	0
681078	676613	01028R	PARTICIPANT	\N	PRESENT	0
681079	676613	11066Q	PARTICIPANT	\N	PRESENT	0
681080	676613	19749K	PARTICIPANT	\N	PRESENT	0
681081	676613	20122U	PARTICIPANT	\N	PRESENT	0
681082	676613	19585H	PARTICIPANT	\N	PRESENT	0
681434	681433	14053L	PARTICIPANT	\N	PRESENT	0
681437	681433	11066Q	PARTICIPANT	\N	PRESENT	0
681645	679178	19447X	PARTICIPANT	\N	PRESENT	0
681646	679178	20074E	PARTICIPANT	\N	PRESENT	0
681647	679178	14111D	PARTICIPANT	\N	PRESENT	0
681648	679178	19629C	PARTICIPANT	\N	PRESENT	0
681649	679178	14215L	PARTICIPANT	\N	PRESENT	0
681650	679178	19725B	PARTICIPANT	\N	PRESENT	0
681651	679178	19954N	PARTICIPANT	\N	PRESENT	0
681652	679178	04047H	PRESIDENT	0	PRESENT	0
681653	679538	14327T	PARTICIPANT	\N	PRESENT	0
681654	679538	20036X	PARTICIPANT	\N	PRESENT	0
681655	679538	19531S	PARTICIPANT	\N	PRESENT	0
681656	679538	01057W	PARTICIPANT	\N	PRESENT	0
681657	679538	08011M	PARTICIPANT	\N	PRESENT	0
681658	679538	14225N	PRESIDENT	0	PRESENT	0
681659	679538	14173T	PARTICIPANT	\N	PRESENT	0
681660	679538	11012A	PARTICIPANT	\N	PRESENT	0
659061	659058	19251M	PARTICIPANT	\N	PRESENT	0
659062	659058	19575F	PARTICIPANT	\N	PRESENT	0
659063	659058	20126Y	PARTICIPANT	\N	PRESENT	0
659064	659058	14083S	PARTICIPANT	\N	PRESENT	0
659065	659058	20054A	PARTICIPANT	\N	PRESENT	0
659066	659058	20060X	PARTICIPANT	\N	PRESENT	0
659069	659058	16685X	PARTICIPANT	\N	PRESENT	0
659076	659070	04043D	PARTICIPANT	\N	PRESENT	0
661635	659867	11090Q	PARTICIPANT	\N	PRESENT	0
661682	659867	20018V	PARTICIPANT	\N	EXCUSE	0
661683	659867	19563B	PARTICIPANT	\N	EXCUSE	0
666341	665705	20066E	PARTICIPANT	\N	PRESENT	0
666382	665705	19713W	PARTICIPANT	\N	PRESENT	0
666391	663863	19713W	PARTICIPANT	\N	PRESENT	0
667931	667912	14187A	PARTICIPANT	\N	PRESENT	0
667932	667912	20144B	PARTICIPANT	\N	PRESENT	0
667933	667912	19695N	PARTICIPANT	\N	PRESENT	0
667934	667912	11090Q	PRESIDENT	0	PRESENT	0
667935	667912	20062A	PARTICIPANT	\N	PRESENT	0
667936	667912	14251Q	PARTICIPANT	\N	PRESENT	0
667937	667912	20298U	PARTICIPANT	\N	PRESENT	0
667938	667912	19747H	PARTICIPANT	\N	PRESENT	0
667939	667912	14207L	PARTICIPANT	\N	PRESENT	0
667940	667912	14257W	PARTICIPANT	\N	PRESENT	0
668088	667819	04092N	PARTICIPANT	\N	PRESENT	0
668089	665225	14221J	PARTICIPANT	\N	PRESENT	0
668090	665225	20136B	PARTICIPANT	\N	PRESENT	0
668091	667696	19335Q	PARTICIPANT	\N	PRESENT	0
668092	665225	20118Y	PARTICIPANT	\N	PRESENT	0
668093	665225	20068G	PARTICIPANT	\N	PRESENT	0
668098	667696	01057W	PARTICIPANT	\N	PRESENT	0
668099	667696	01048V	PARTICIPANT	\N	PRESENT	0
668100	665225	19701S	PARTICIPANT	\N	PRESENT	0
668101	665225	20106U	PARTICIPANT	\N	PRESENT	0
668102	665225	20172F	PARTICIPANT	\N	PRESENT	0
668117	667697	11012A	PRESIDENT	0	PRESENT	0
668118	667697	14331P	PARTICIPANT	\N	PRESENT	0
668133	667697	14083S	PARTICIPANT	\N	PRESENT	0
668120	667697	11048N	PARTICIPANT	\N	PRESENT	0
668121	667697	11053K	PARTICIPANT	\N	PRESENT	0
668122	667697	20080C	PARTICIPANT	\N	PRESENT	0
668123	667697	08010L	PARTICIPANT	\N	PRESENT	0
668124	667697	14121F	PARTICIPANT	\N	PRESENT	0
668125	667697	20116W	PARTICIPANT	\N	PRESENT	0
668729	667226	10015M	PARTICIPANT	\N	PRESENT	0
668127	667697	19335Q	PARTICIPANT	\N	PRESENT	0
668128	667697	19711U	PARTICIPANT	\N	PRESENT	0
668129	667697	19531S	PARTICIPANT	\N	PRESENT	0
668130	667697	07029T	PARTICIPANT	\N	PRESENT	0
668131	667697	19647E	PARTICIPANT	\N	PRESENT	0
668132	667697	20070A	PARTICIPANT	\N	PRESENT	0
668139	667697	19545Y	PARTICIPANT	\N	PRESENT	0
668140	667697	14225N	PRESIDENT	1	PRESENT	0
668142	667240	20114U	PARTICIPANT	\N	PRESENT	0
668148	667697	19479G	PARTICIPANT	\N	PRESENT	0
668149	667697	14189C	PARTICIPANT	\N	EXCUSE	0
668150	667697	19671E	PARTICIPANT	\N	EXCUSE	0
668151	667719	20028X	PARTICIPANT	\N	PRESENT	0
668152	667719	19826F	PARTICIPANT	\N	PRESENT	0
668153	667719	19707Y	PARTICIPANT	\N	PRESENT	0
668154	667719	19705W	PARTICIPANT	\N	PRESENT	0
668155	667719	98022P	PARTICIPANT	\N	PRESENT	0
668156	667719	19629C	PARTICIPANT	\N	PRESENT	0
668157	667719	92040Q	PARTICIPANT	\N	PRESENT	0
668158	667719	19583F	PARTICIPANT	\N	PRESENT	0
668159	667719	17589D	PARTICIPANT	\N	PRESENT	0
668160	667719	20144B	PARTICIPANT	\N	PRESENT	0
668161	667719	14267Y	PARTICIPANT	\N	PRESENT	0
668162	667719	11103C	PARTICIPANT	\N	PRESENT	0
668163	667719	19719D	PARTICIPANT	\N	PRESENT	0
668164	667719	11066Q	PARTICIPANT	\N	PRESENT	0
668165	667719	11104D	PARTICIPANT	\N	PRESENT	0
668166	667719	14097Y	PARTICIPANT	\N	PRESENT	0
668167	667719	19399H	PARTICIPANT	\N	PRESENT	0
668168	667719	20078J	PARTICIPANT	\N	PRESENT	0
668169	667719	14355X	PARTICIPANT	\N	PRESENT	0
668170	667719	19675J	PARTICIPANT	\N	PRESENT	0
668171	667719	20088L	PARTICIPANT	\N	PRESENT	0
668172	667719	14001X	PARTICIPANT	\N	PRESENT	0
668173	667719	19681G	PARTICIPANT	\N	PRESENT	0
668174	667719	14331P	PARTICIPANT	\N	PRESENT	0
668175	667719	17779H	PARTICIPANT	\N	PRESENT	0
668176	667719	20082E	PARTICIPANT	\N	PRESENT	0
668177	667719	19669L	PARTICIPANT	\N	PRESENT	0
668178	667719	20102Q	PARTICIPANT	\N	PRESENT	0
668179	667719	19760E	PARTICIPANT	\N	PRESENT	0
668180	667719	19599P	PARTICIPANT	\N	PRESENT	0
668181	667719	17229F	PARTICIPANT	\N	PRESENT	0
668182	667719	08018U	PARTICIPANT	\N	PRESENT	0
668727	667226	19447X	PARTICIPANT	\N	PRESENT	0
668728	667226	19954N	PARTICIPANT	\N	PRESENT	0
668730	667226	14215L	PARTICIPANT	\N	PRESENT	0
668733	667226	19581D	PARTICIPANT	\N	PRESENT	0
668734	667226	20114U	PARTICIPANT	\N	PRESENT	0
668738	667226	14147R	PARTICIPANT	\N	PRESENT	0
668744	667226	20022R	PARTICIPANT	\N	PRESENT	0
668745	667226	14151M	PARTICIPANT	\N	PRESENT	0
668749	667226	19649G	PARTICIPANT	\N	PRESENT	0
668758	667226	04047H	PRESIDENT	0	PRESENT	0
668760	667226	17737W	PARTICIPANT	\N	PRESENT	0
668761	667226	05008E	PARTICIPANT	\N	PRESENT	0
668763	667226	01028R	PARTICIPANT	\N	PRESENT	0
668780	667226	20108W	PARTICIPANT	\N	PRESENT	0
668781	667226	14231L	PARTICIPANT	\N	PRESENT	0
668818	667226	19729F	PARTICIPANT	\N	PRESENT	0
670005	667729	19695N	PARTICIPANT	\N	PRESENT	0
670083	669891	99004R	PARTICIPANT	\N	PRESENT	0
670086	669891	14042U	PARTICIPANT	\N	PRESENT	0
669985	667729	11056N	PARTICIPANT	\N	PRESENT	0
669986	667729	20252E	PARTICIPANT	\N	PRESENT	0
670087	669891	14213J	PARTICIPANT	\N	PRESENT	0
670088	669891	14026U	PARTICIPANT	\N	PRESENT	0
670089	669891	11097X	PARTICIPANT	\N	PRESENT	0
670090	669891	19569H	PARTICIPANT	\N	PRESENT	0
670091	669891	14071N	PARTICIPANT	\N	PRESENT	0
670092	669891	20126Y	PARTICIPANT	\N	PRESENT	0
670093	669891	10006L	PARTICIPANT	\N	PRESENT	0
670097	669891	19697Q	PARTICIPANT	\N	PRESENT	0
670095	669891	11031D	PARTICIPANT	\N	PRESENT	0
670096	669891	14195A	PARTICIPANT	\N	PRESENT	0
670098	669891	11033F	PARTICIPANT	\N	PRESENT	0
670099	669891	19715Y	PARTICIPANT	\N	PRESENT	0
670100	669891	14281W	PARTICIPANT	\N	PRESENT	0
670101	669891	19691J	PARTICIPANT	\N	PRESENT	0
670102	669891	19683J	PARTICIPANT	\N	PRESENT	0
670103	669891	04092N	PARTICIPANT	\N	PRESENT	0
670104	669891	11045K	PARTICIPANT	\N	PRESENT	0
670105	669891	14355X	PARTICIPANT	\N	PRESENT	0
670106	669891	19798U	PARTICIPANT	\N	PRESENT	0
670107	669891	19367Y	PARTICIPANT	\N	PRESENT	0
670108	669891	20266L	PARTICIPANT	\N	PRESENT	0
670109	669891	19713W	PARTICIPANT	\N	PRESENT	0
670110	669891	20130U	PARTICIPANT	\N	PRESENT	0
670111	669891	17965H	PARTICIPANT	\N	PRESENT	0
670112	669891	19577H	PARTICIPANT	\N	PRESENT	0
670113	669891	19651A	PARTICIPANT	\N	PRESENT	0
670114	669891	14217N	PARTICIPANT	\N	PRESENT	0
670115	669891	01034P	PARTICIPANT	\N	PRESENT	0
670116	669891	08045X	PARTICIPANT	\N	PRESENT	0
670117	669891	11067R	PARTICIPANT	\N	PRESENT	0
670118	669891	14021P	PARTICIPANT	\N	PRESENT	0
670119	669891	19553Y	PARTICIPANT	\N	PRESENT	0
670120	669891	20040T	PARTICIPANT	\N	PRESENT	0
670121	669891	19301E	PARTICIPANT	\N	PRESENT	0
670122	669891	20914V	PARTICIPANT	\N	PRESENT	0
670123	669891	18193Q	PARTICIPANT	\N	PRESENT	0
670124	669891	19723Y	PARTICIPANT	\N	PRESENT	0
670125	669891	19657G	PARTICIPANT	\N	PRESENT	0
670126	669891	04085P	PARTICIPANT	\N	PRESENT	0
670127	669891	19329S	PARTICIPANT	\N	PRESENT	0
670128	669891	19760E	PARTICIPANT	\N	PRESENT	0
670129	669891	19591F	PARTICIPANT	\N	PRESENT	0
670130	669891	20034V	PARTICIPANT	\N	PRESENT	0
670131	669891	20090E	PARTICIPANT	\N	PRESENT	0
670132	669891	17779H	PARTICIPANT	\N	PRESENT	0
670133	669891	14111D	PARTICIPANT	\N	PRESENT	0
670134	669891	14107H	PARTICIPANT	\N	PRESENT	0
670135	669891	08061X	PARTICIPANT	\N	PRESENT	0
670136	669891	20136B	PARTICIPANT	\N	PRESENT	0
670137	669891	19415P	PARTICIPANT	\N	PRESENT	0
670138	669891	04043D	PARTICIPANT	\N	PRESENT	0
681269	676615	20180F	PARTICIPANT	\N	PRESENT	0
681270	676615	14123H	PARTICIPANT	\N	PRESENT	0
681271	676615	14193X	PARTICIPANT	\N	PRESENT	0
681272	669286	19333N	PARTICIPANT	\N	PRESENT	0
681273	669286	19701S	PARTICIPANT	\N	PRESENT	0
681274	669286	20038A	PARTICIPANT	\N	PRESENT	0
681275	669286	19549D	PARTICIPANT	\N	PRESENT	0
681276	669286	14219Q	PRESIDENT	0	PRESENT	0
681277	669286	19820Y	PARTICIPANT	\N	PRESENT	0
681278	669286	19251M	PARTICIPANT	\N	PRESENT	0
681279	669286	19826F	PARTICIPANT	\N	PRESENT	0
681280	669286	19599P	PARTICIPANT	\N	PRESENT	0
681281	669286	20102Q	PARTICIPANT	\N	PRESENT	0
681282	669286	19637C	PARTICIPANT	\N	PRESENT	0
681283	669286	19503N	PARTICIPANT	\N	PRESENT	0
681284	669286	19745F	PARTICIPANT	\N	PRESENT	0
681285	669286	19619A	PARTICIPANT	\N	PRESENT	0
681286	669286	20120S	PARTICIPANT	\N	PRESENT	0
681287	669286	19525U	PARTICIPANT	\N	PRESENT	0
681288	669286	14237S	PARTICIPANT	\N	PRESENT	0
681289	676615	14109K	PARTICIPANT	\N	PRESENT	0
681290	676615	14069U	PARTICIPANT	\N	PRESENT	0
681291	676615	19663E	PARTICIPANT	\N	PRESENT	0
681292	676615	19443T	PARTICIPANT	\N	PRESENT	0
681293	676615	11072N	PARTICIPANT	\N	PRESENT	0
681294	669286	14221J	PARTICIPANT	\N	PRESENT	0
681295	669286	20106U	PARTICIPANT	\N	PRESENT	0
681296	669286	20024T	PARTICIPANT	\N	PRESENT	0
681297	669286	14031R	PARTICIPANT	\N	PRESENT	0
681298	669286	20140W	PARTICIPANT	\N	PRESENT	0
681299	669286	20146D	PARTICIPANT	\N	PRESENT	0
681300	669286	20046A	PARTICIPANT	\N	PRESENT	0
681301	669286	17229F	PARTICIPANT	\N	PRESENT	0
681320	676615	20248J	PARTICIPANT	\N	PRESENT	0
681303	676615	20076G	PARTICIPANT	\N	PRESENT	0
681304	669286	20136B	PARTICIPANT	\N	PRESENT	0
681305	676615	19507S	PARTICIPANT	\N	PRESENT	0
681306	669286	17367Q	PARTICIPANT	\N	PRESENT	0
681307	669286	18083K	PARTICIPANT	\N	PRESENT	0
681309	676615	19531S	PARTICIPANT	\N	PRESENT	0
681310	676615	20132W	PARTICIPANT	\N	PRESENT	0
681311	676615	14213J	PARTICIPANT	\N	PRESENT	0
681312	676615	17023S	PARTICIPANT	\N	PRESENT	0
681313	669286	20076G	PARTICIPANT	\N	PRESENT	0
681314	669286	19387D	PARTICIPANT	\N	PRESENT	0
681315	669286	19681G	PARTICIPANT	\N	PRESENT	0
681318	676615	07029T	PARTICIPANT	\N	PRESENT	0
681319	676615	14231L	PARTICIPANT	\N	PRESENT	0
681321	676615	20106U	PARTICIPANT	\N	PRESENT	0
681322	676615	14207L	PARTICIPANT	\N	PRESENT	0
681323	676615	19415P	PARTICIPANT	\N	PRESENT	0
681324	676615	14211G	PARTICIPANT	\N	PRESENT	0
681325	676615	14221J	PARTICIPANT	\N	PRESENT	0
681326	676615	19681G	PARTICIPANT	\N	PRESENT	0
681327	676615	19549D	PARTICIPANT	\N	PRESENT	0
681328	676615	19563B	PARTICIPANT	\N	PRESENT	0
681329	676615	04035D	PARTICIPANT	\N	PRESENT	0
681330	676615	11012A	PARTICIPANT	\N	PRESENT	0
681331	676615	20032T	PARTICIPANT	\N	PRESENT	0
681332	676615	14097Y	PARTICIPANT	\N	PRESENT	0
681333	676615	14205J	PARTICIPANT	\N	PRESENT	0
681334	676615	20126Y	PARTICIPANT	\N	PRESENT	0
681335	676615	11048N	PARTICIPANT	\N	PRESENT	0
681336	676615	14225N	PARTICIPANT	\N	PRESENT	0
681337	676615	19413M	PARTICIPANT	\N	PRESENT	0
681344	676615	20052X	PARTICIPANT	\N	PRESENT	0
681345	676615	20100N	PARTICIPANT	\N	PRESENT	0
681346	676615	01057W	PARTICIPANT	\N	PRESENT	0
681347	676615	14111D	PARTICIPANT	\N	PRESENT	0
681348	676615	19399H	PARTICIPANT	\N	PRESENT	0
681349	676615	19782L	PARTICIPANT	\N	PRESENT	0
681350	676615	07004J	PARTICIPANT	\N	PRESENT	0
681351	676615	20092G	PARTICIPANT	\N	PRESENT	0
681352	676616	14026U	PARTICIPANT	\N	PRESENT	0
681417	676616	07029T	PARTICIPANT	\N	PRESENT	0
681354	676616	11067R	PARTICIPANT	\N	PRESENT	0
681355	676616	19565D	PARTICIPANT	\N	PRESENT	0
681356	676616	11031D	PARTICIPANT	\N	PRESENT	0
681357	676616	19503N	PARTICIPANT	\N	PRESENT	0
681358	676616	17779H	PARTICIPANT	\N	PRESENT	0
681359	676616	20130U	PARTICIPANT	\N	PRESENT	0
681418	676616	11097X	PARTICIPANT	\N	PRESENT	0
681361	676616	14217N	PARTICIPANT	\N	PRESENT	0
681362	676616	19553Y	PARTICIPANT	\N	PRESENT	0
681363	676616	19691J	PARTICIPANT	\N	PRESENT	0
681364	676616	14071N	PARTICIPANT	\N	PRESENT	0
681365	676616	19954N	PARTICIPANT	\N	PRESENT	0
681366	676616	20044X	PARTICIPANT	\N	PRESENT	0
681367	676616	18193Q	PARTICIPANT	\N	PRESENT	0
681368	676616	20116W	PARTICIPANT	\N	PRESENT	0
681419	676616	20054A	PARTICIPANT	\N	PRESENT	0
681420	676616	20132W	PARTICIPANT	\N	PRESENT	0
681371	676616	20058E	PARTICIPANT	\N	PRESENT	0
681421	676616	14107H	PARTICIPANT	\N	PRESENT	0
681422	676616	19301E	PARTICIPANT	\N	PRESENT	0
681374	676616	20142Y	PARTICIPANT	\N	PRESENT	0
681375	676616	19747H	PARTICIPANT	\N	PRESENT	0
681423	676616	19349W	PARTICIPANT	\N	PRESENT	0
681424	676616	19663E	PARTICIPANT	\N	PRESENT	0
681425	676616	19515S	PARTICIPANT	\N	PRESENT	0
681379	676616	19467C	PARTICIPANT	\N	PRESENT	0
681426	676616	19599P	PARTICIPANT	\N	PRESENT	0
681427	676616	19507S	PARTICIPANT	\N	PRESENT	0
681382	676616	19703U	PARTICIPANT	\N	PRESENT	0
681383	676616	19591F	PARTICIPANT	\N	PRESENT	0
681384	676616	20090E	PARTICIPANT	\N	PRESENT	0
681385	676616	14195A	PARTICIPANT	\N	PRESENT	0
681386	676616	19387D	PARTICIPANT	\N	PRESENT	0
681387	676616	14042U	PARTICIPANT	\N	PRESENT	0
681388	676616	19762G	PARTICIPANT	\N	PRESENT	0
681428	676616	01025N	PARTICIPANT	\N	PRESENT	0
681429	676616	20040T	PARTICIPANT	\N	PRESENT	0
681391	676616	19683J	PARTICIPANT	\N	PRESENT	0
681430	676616	20134Y	PARTICIPANT	\N	PRESENT	0
681431	676616	14105F	PARTICIPANT	\N	PRESENT	0
681485	681432	19663E	PARTICIPANT	\N	PRESENT	0
681395	676616	10006L	PARTICIPANT	\N	PRESENT	0
681396	676616	19441R	PARTICIPANT	\N	PRESENT	0
681397	676616	14109K	PARTICIPANT	\N	PRESENT	0
681483	681432	01043Q	PARTICIPANT	\N	PRESENT	0
681484	681432	11031D	PARTICIPANT	\N	PRESENT	0
681400	676616	14213J	PARTICIPANT	\N	PRESENT	0
681401	676616	14231L	PARTICIPANT	\N	PRESENT	0
681402	676616	14207L	PARTICIPANT	\N	PRESENT	0
681403	676616	19415P	PARTICIPANT	\N	PRESENT	0
681486	681432	20126Y	PARTICIPANT	\N	PRESENT	0
681487	681432	19683J	PARTICIPANT	\N	PRESENT	0
681406	676616	14097Y	PARTICIPANT	\N	PRESENT	0
681407	676616	20126Y	PARTICIPANT	\N	PRESENT	0
681408	676616	14225N	PARTICIPANT	\N	PRESENT	0
681409	676616	19413M	PARTICIPANT	\N	PRESENT	0
681488	681432	18193Q	PARTICIPANT	\N	PRESENT	0
681411	676616	20100N	PARTICIPANT	\N	PRESENT	0
681489	681432	11067R	PARTICIPANT	\N	PRESENT	0
681413	676616	19399H	PARTICIPANT	\N	PRESENT	0
681414	676616	19782L	PARTICIPANT	\N	PRESENT	0
681415	676616	07004J	PARTICIPANT	\N	PRESENT	0
681416	676616	20092G	PARTICIPANT	\N	PRESENT	0
681490	681432	14097Y	PARTICIPANT	\N	PRESENT	0
681491	681432	19551W	PARTICIPANT	\N	PRESENT	0
681492	681432	19599P	PARTICIPANT	\N	PRESENT	0
681493	681432	20100N	PARTICIPANT	\N	PRESENT	0
681494	681432	20130U	PARTICIPANT	\N	PRESENT	0
681495	681432	19301E	PARTICIPANT	\N	PRESENT	0
681496	681432	19782L	PARTICIPANT	\N	PRESENT	0
681497	681432	20092G	PARTICIPANT	\N	PRESENT	0
681498	681432	19563B	PARTICIPANT	\N	PRESENT	0
681499	681432	14195A	PARTICIPANT	\N	PRESENT	0
681500	681432	20132W	PARTICIPANT	\N	PRESENT	0
681501	681432	19553Y	PARTICIPANT	\N	PRESENT	0
681502	681432	19415P	PARTICIPANT	\N	PRESENT	0
681503	681432	11097X	PARTICIPANT	\N	PRESENT	0
681504	681432	14071N	PARTICIPANT	\N	PRESENT	0
681505	681432	20054A	PARTICIPANT	\N	PRESENT	0
681506	681432	14217N	PARTICIPANT	\N	PRESENT	0
681507	681432	19515S	PARTICIPANT	\N	PRESENT	0
681508	681432	20044X	PARTICIPANT	\N	PRESENT	0
681509	681432	20134Y	PARTICIPANT	\N	PRESENT	0
681510	681432	10006L	PARTICIPANT	\N	PRESENT	0
681511	681432	14213J	PARTICIPANT	\N	PRESENT	0
681512	681432	14042U	PARTICIPANT	\N	PRESENT	0
656180	656179	20130U	PARTICIPANT	\N	PRESENT	0
656834	656833	12028B	PARTICIPANT	\N	PRESENT	0
656835	656833	19565D	PARTICIPANT	\N	PRESENT	0
656836	656833	14267Y	PARTICIPANT	\N	PRESENT	0
657673	657524	19671E	PARTICIPANT	\N	PRESENT	0
657674	657524	14195A	PARTICIPANT	\N	PRESENT	0
657675	657524	19760E	PARTICIPANT	\N	PRESENT	0
657676	657524	19251M	PARTICIPANT	\N	PRESENT	0
657677	657524	14030Q	PARTICIPANT	\N	PRESENT	0
657678	657524	19762G	PARTICIPANT	\N	PRESENT	0
659644	642994	14030Q	PARTICIPANT	\N	PRESENT	0
659645	642994	20124W	PARTICIPANT	\N	PRESENT	0
660309	656930	19549D	PARTICIPANT	\N	PRESENT	0
659647	642994	04035D	PARTICIPANT	\N	PRESENT	0
659648	642994	11083R	PARTICIPANT	\N	PRESENT	0
659649	642994	14026U	PARTICIPANT	\N	PRESENT	0
659650	642994	20056C	PARTICIPANT	\N	PRESENT	0
659652	642994	19503N	PARTICIPANT	\N	PRESENT	0
660289	659193	14223L	PARTICIPANT	\N	PRESENT	0
660290	659193	19553Y	PARTICIPANT	\N	PRESENT	0
660291	659193	19703U	PARTICIPANT	\N	PRESENT	0
660292	659193	14042U	PARTICIPANT	\N	PRESENT	0
660293	659193	14195A	PARTICIPANT	\N	PRESENT	0
660294	659193	19367Y	PARTICIPANT	\N	PRESENT	0
660295	659193	14213J	PARTICIPANT	\N	PRESENT	0
660296	659193	19683J	PARTICIPANT	\N	PRESENT	0
660297	659193	10006L	PRESIDENT	0	PRESENT	0
660298	659193	19591F	PARTICIPANT	\N	PRESENT	0
660299	659193	20130U	PARTICIPANT	\N	PRESENT	0
660300	659193	20040T	PARTICIPANT	\N	PRESENT	0
660301	659193	17965H	PARTICIPANT	\N	PRESENT	0
660302	659193	19691J	PARTICIPANT	\N	PRESENT	0
660303	659193	19715Y	PARTICIPANT	\N	PRESENT	0
660304	659193	11103C	PARTICIPANT	\N	PRESENT	0
660305	659193	14071N	PARTICIPANT	\N	PRESENT	0
660306	659193	19657G	PARTICIPANT	\N	PRESENT	0
660307	659193	04043D	PARTICIPANT	\N	PRESENT	0
660308	659193	19760E	PARTICIPANT	\N	PRESENT	0
660310	656930	14237S	PARTICIPANT	\N	PRESENT	0
660311	656930	19525U	PARTICIPANT	\N	PRESENT	0
660312	656930	20120S	PARTICIPANT	\N	PRESENT	0
660313	656930	20032T	PARTICIPANT	\N	PRESENT	0
660374	659085	08011M	PARTICIPANT	\N	PRESENT	0
660375	659085	20914V	PARTICIPANT	\N	EXCUSE	0
660376	656930	20136B	PARTICIPANT	\N	PRESENT	0
660377	659193	14026U	PARTICIPANT	\N	PRESENT	0
660378	659193	11031D	PARTICIPANT	\N	PRESENT	0
660379	659193	01034P	PARTICIPANT	\N	PRESENT	0
660380	659193	04092N	PARTICIPANT	\N	PRESENT	0
660381	659193	08045X	PARTICIPANT	\N	PRESENT	0
660382	659866	20088L	PARTICIPANT	\N	PRESENT	0
660383	659866	19768N	PARTICIPANT	\N	PRESENT	0
660384	659866	19515S	PARTICIPANT	\N	PRESENT	0
660385	659866	20092G	PARTICIPANT	\N	PRESENT	0
660386	659866	19782L	PARTICIPANT	\N	PRESENT	0
660387	659866	11077T	PARTICIPANT	\N	PRESENT	0
660388	659866	19441R	PARTICIPANT	\N	PRESENT	0
660389	659866	20078J	PARTICIPANT	\N	PRESENT	0
660390	659866	19413M	PARTICIPANT	\N	PRESENT	0
660391	659866	20082E	PARTICIPANT	\N	PRESENT	0
660392	659866	20094J	PARTICIPANT	\N	PRESENT	0
660393	659866	04045F	PARTICIPANT	\N	PRESENT	0
660394	659866	19631V	PARTICIPANT	\N	PRESENT	0
660395	659866	11099A	PARTICIPANT	\N	PRESENT	0
660396	659866	19705W	PARTICIPANT	\N	PRESENT	0
660397	659866	08015R	PARTICIPANT	\N	PRESENT	0
660398	659866	19575F	PARTICIPANT	\N	PRESENT	0
660399	659866	19369B	PARTICIPANT	\N	PRESENT	0
660400	659866	20018V	PARTICIPANT	\N	PRESENT	0
660401	659866	08028W	PARTICIPANT	\N	PRESENT	0
660402	659866	19563B	PARTICIPANT	\N	PRESENT	0
660403	659866	19467C	PARTICIPANT	\N	PRESENT	0
660404	659866	20034V	PARTICIPANT	\N	PRESENT	0
660405	659866	14187A	PARTICIPANT	\N	PRESENT	0
660406	659866	20144B	PARTICIPANT	\N	PRESENT	0
660407	659866	19695N	PARTICIPANT	\N	PRESENT	0
660408	659866	01025N	PARTICIPANT	\N	PRESENT	0
660409	659866	14033T	PARTICIPANT	\N	PRESENT	0
660410	659866	11090Q	PRESIDENT	0	PRESENT	0
660411	659866	20054A	PARTICIPANT	\N	PRESENT	0
660412	659866	14205J	PARTICIPANT	\N	PRESENT	0
660413	659866	20060X	PARTICIPANT	\N	PRESENT	0
660414	659866	19507S	PARTICIPANT	\N	PRESENT	0
660415	659866	20298U	PARTICIPANT	\N	PRESENT	0
660416	659866	19747H	PARTICIPANT	\N	PRESENT	0
660417	659866	14207L	PARTICIPANT	\N	PRESENT	0
660418	659866	14257W	PARTICIPANT	\N	PRESENT	0
660419	659866	14037X	PARTICIPANT	\N	PRESENT	0
660421	656930	20106U	PARTICIPANT	\N	PRESENT	0
660422	659365	20266L	PARTICIPANT	\N	PRESENT	0
660423	659085	11053K	PARTICIPANT	\N	PRESENT	0
660506	659412	86034E	PARTICIPANT	\N	PRESENT	0
660507	659412	19387D	PARTICIPANT	\N	PRESENT	0
660508	659412	98022P	PARTICIPANT	\N	PRESENT	0
660509	659412	20298U	PARTICIPANT	\N	PRESENT	0
660510	659412	19735D	PARTICIPANT	\N	PRESENT	0
660511	659412	11045K	PARTICIPANT	\N	PRESENT	0
660512	659412	95041E	PARTICIPANT	\N	PRESENT	0
660513	659412	20046A	PARTICIPANT	\N	PRESENT	0
660514	659412	14195A	PARTICIPANT	\N	PRESENT	0
660515	659412	14331P	PARTICIPANT	\N	PRESENT	0
660516	659412	08069G	PARTICIPANT	\N	PRESENT	0
660517	659412	08028W	PARTICIPANT	\N	PRESENT	0
660518	659412	20114U	PARTICIPANT	\N	PRESENT	0
660519	659412	20108W	PARTICIPANT	\N	PRESENT	0
660520	659412	20016T	PARTICIPANT	\N	PRESENT	0
660521	659412	19631V	PARTICIPANT	\N	PRESENT	0
660522	659412	11101A	PARTICIPANT	\N	PRESENT	0
660523	659412	20088L	PARTICIPANT	\N	PRESENT	0
660524	659412	07004J	PARTICIPANT	\N	PRESENT	0
660525	659412	01048V	PARTICIPANT	\N	PRESENT	0
660526	659412	20102Q	PARTICIPANT	\N	PRESENT	0
660527	659412	19741B	PARTICIPANT	\N	PRESENT	0
660528	659412	19747H	PARTICIPANT	\N	PRESENT	0
660529	659412	92040Q	PARTICIPANT	\N	PRESENT	0
660530	659412	14107H	PARTICIPANT	\N	PRESENT	0
660531	659412	11040E	PARTICIPANT	\N	PRESENT	0
660532	659412	08009T	PARTICIPANT	\N	PRESENT	0
660533	659412	20032T	PARTICIPANT	\N	PRESENT	0
660534	659412	20056C	PARTICIPANT	\N	PRESENT	0
660535	659412	20098N	PARTICIPANT	\N	PRESENT	0
660536	659412	19443T	PARTICIPANT	\N	PRESENT	0
660537	659412	14123H	PARTICIPANT	\N	PRESENT	0
660538	659412	14097Y	PARTICIPANT	\N	PRESENT	0
660539	659412	19711U	PARTICIPANT	\N	PRESENT	0
660540	659412	19683J	PARTICIPANT	\N	PRESENT	0
660541	659412	20072C	PARTICIPANT	\N	PRESENT	0
660542	659412	19697Q	PARTICIPANT	\N	PRESENT	0
660543	659412	19569H	PARTICIPANT	\N	PRESENT	0
660544	659412	14267Y	PARTICIPANT	\N	PRESENT	0
660545	659412	20134Y	PARTICIPANT	\N	PRESENT	0
660546	659412	20090E	PARTICIPANT	\N	PRESENT	0
660547	659412	04035D	PARTICIPANT	\N	PRESENT	0
660548	659412	14033T	PARTICIPANT	\N	PRESENT	0
660549	659412	19715Y	PARTICIPANT	\N	PRESENT	0
660550	659412	99004R	PARTICIPANT	\N	PRESENT	0
660551	659412	19760E	PARTICIPANT	\N	PRESENT	0
660552	659412	19758L	PARTICIPANT	\N	PRESENT	0
660553	659412	20074E	PARTICIPANT	\N	PRESENT	0
660554	659412	19687N	PARTICIPANT	\N	PRESENT	0
660556	659412	19565D	PARTICIPANT	\N	PRESENT	0
660557	659412	20076G	PARTICIPANT	\N	PRESENT	0
660558	659412	19643A	PARTICIPANT	\N	PRESENT	0
660559	659412	04085P	PARTICIPANT	\N	PRESENT	0
660560	659412	19695N	PARTICIPANT	\N	PRESENT	0
660561	659412	11080N	PARTICIPANT	\N	PRESENT	0
660562	659412	19593H	PARTICIPANT	\N	PRESENT	0
660563	659412	11077T	PARTICIPANT	\N	PRESENT	0
660564	659412	19693L	PARTICIPANT	\N	PRESENT	0
660565	659412	11099A	PARTICIPANT	\N	PRESENT	0
660566	659412	19347U	PARTICIPANT	\N	PRESENT	0
660567	659412	20142Y	PARTICIPANT	\N	PRESENT	0
660568	659412	19707Y	PARTICIPANT	\N	PRESENT	0
660569	659412	20100N	PARTICIPANT	\N	PRESENT	0
660570	659412	20130U	PARTICIPANT	\N	PRESENT	0
660571	659412	20092G	PARTICIPANT	\N	PRESENT	0
660572	659412	19621T	PARTICIPANT	\N	PRESENT	0
660573	659412	19651A	PARTICIPANT	\N	PRESENT	0
660574	659412	19782L	PARTICIPANT	\N	PRESENT	0
660575	659412	19057M	PARTICIPANT	\N	PRESENT	0
681661	679538	19349W	PARTICIPANT	\N	PRESENT	0
681662	679538	99004R	PARTICIPANT	\N	PRESENT	0
681663	679538	20116W	PARTICIPANT	\N	PRESENT	0
681664	679538	20914V	PARTICIPANT	\N	PRESENT	0
681665	679538	20126Y	PARTICIPANT	\N	PRESENT	0
681666	679538	19762G	PARTICIPANT	\N	PRESENT	0
681667	679538	08010L	PARTICIPANT	\N	EXCUSE	0
681668	679538	20086J	PARTICIPANT	\N	PRESENT	0
681669	679538	14331P	PARTICIPANT	\N	PRESENT	0
681670	679538	19671E	PARTICIPANT	\N	PRESENT	0
681671	679538	14253S	PARTICIPANT	\N	PRESENT	0
681672	679538	14121F	PARTICIPANT	\N	PRESENT	0
681673	679538	11048N	PARTICIPANT	\N	PRESENT	0
681674	679178	14053L	PARTICIPANT	\N	PRESENT	0
681675	679178	19301E	PARTICIPANT	\N	PRESENT	0
681676	679178	19729F	PARTICIPANT	\N	PRESENT	0
681677	679178	07004J	PARTICIPANT	\N	PRESENT	0
681678	679178	11072N	PARTICIPANT	\N	PRESENT	0
681679	679178	19591F	PARTICIPANT	\N	PRESENT	0
681680	679538	20044X	PARTICIPANT	\N	PRESENT	0
681681	679538	11053K	PARTICIPANT	\N	PRESENT	0
681682	679538	19741B	PARTICIPANT	\N	PRESENT	0
681683	679538	20080C	PARTICIPANT	\N	PRESENT	0
681684	679538	19687N	PARTICIPANT	\N	PRESENT	0
681685	679538	11110B	PARTICIPANT	\N	PRESENT	0
681686	679538	14189C	PARTICIPANT	\N	PRESENT	0
681687	679538	07029T	PARTICIPANT	\N	PRESENT	0
681688	679538	11074Q	PARTICIPANT	\N	PRESENT	0
681689	679178	14001X	PARTICIPANT	\N	PRESENT	0
681690	679178	19543W	PARTICIPANT	\N	PRESENT	0
681691	679178	19585H	PARTICIPANT	\N	PRESENT	0
681692	679178	11033F	PARTICIPANT	\N	PRESENT	0
681693	679178	05008E	PARTICIPANT	\N	PRESENT	0
681694	679178	95063L	PARTICIPANT	\N	PRESENT	0
681695	679178	20108W	PARTICIPANT	\N	PRESENT	0
681696	679178	14069U	PARTICIPANT	\N	PRESENT	0
681697	679178	20022R	PARTICIPANT	\N	PRESENT	0
681698	679538	19545Y	PARTICIPANT	\N	PRESENT	0
681699	679538	19647E	PARTICIPANT	\N	PRESENT	0
681700	679178	14107H	PARTICIPANT	\N	PRESENT	0
681701	679178	20114U	PARTICIPANT	\N	PRESENT	0
681702	679178	11085T	PARTICIPANT	\N	PRESENT	0
681703	679178	19673G	PARTICIPANT	\N	PRESENT	0
681704	679178	08018U	PARTICIPANT	\N	EXCUSE	0
681705	679538	20252E	PARTICIPANT	\N	PRESENT	0
681706	679538	08073C	PARTICIPANT	\N	PRESENT	0
681707	679538	08009T	PARTICIPANT	\N	PRESENT	0
681769	669288	20032T	PARTICIPANT	\N	PRESENT	0
681770	669288	14031R	PARTICIPANT	\N	PRESENT	0
681771	669288	20076G	PARTICIPANT	\N	PRESENT	0
681772	669288	20140W	PARTICIPANT	\N	PRESENT	0
681773	669288	14219Q	PRESIDENT	0	PRESENT	0
681774	669288	19251M	PARTICIPANT	\N	PRESENT	0
681775	669288	19820Y	PARTICIPANT	\N	PRESENT	0
681776	669288	19826F	PARTICIPANT	\N	PRESENT	0
681777	669288	20046A	PARTICIPANT	\N	PRESENT	0
681778	669288	20102Q	PARTICIPANT	\N	PRESENT	0
681779	669288	14237S	PARTICIPANT	\N	PRESENT	0
681780	669288	19503N	PARTICIPANT	\N	PRESENT	0
681781	669288	20020P	PARTICIPANT	\N	PRESENT	0
681782	669288	19745F	PARTICIPANT	\N	PRESENT	0
681783	669288	17367Q	PARTICIPANT	\N	PRESENT	0
681784	669288	20024T	PARTICIPANT	\N	PRESENT	0
681785	669288	19525U	PARTICIPANT	\N	PRESENT	0
681788	679538	19335Q	PARTICIPANT	\N	PRESENT	0
681789	679178	19489J	PARTICIPANT	\N	PRESENT	0
681790	679178	11056N	PARTICIPANT	\N	PRESENT	0
681791	669288	19701S	PARTICIPANT	\N	PRESENT	0
681792	669288	20096L	PARTICIPANT	\N	PRESENT	0
681793	669288	05012A	PARTICIPANT	\N	PRESENT	0
681794	669288	20106U	PARTICIPANT	\N	PRESENT	0
681795	669288	19637C	PARTICIPANT	\N	EXCUSE	0
681827	669288	19549D	PARTICIPANT	\N	PRESENT	0
681828	669288	19739H	PARTICIPANT	\N	PRESENT	0
681831	679179	20074E	PARTICIPANT	\N	PRESENT	0
681832	679179	14001X	PARTICIPANT	\N	PRESENT	0
681833	679179	19543W	PARTICIPANT	\N	PRESENT	0
681834	679179	19585H	PARTICIPANT	\N	PRESENT	0
681835	679179	04047H	PRESIDENT	0	PRESENT	0
681836	679179	19673G	PARTICIPANT	\N	PRESENT	0
681837	679179	01028R	PARTICIPANT	\N	PRESENT	0
681838	679179	19447X	PARTICIPANT	\N	PRESENT	0
681839	679179	05008E	PARTICIPANT	\N	PRESENT	0
681840	679179	14231L	PARTICIPANT	\N	PRESENT	0
681841	679179	19954N	PARTICIPANT	\N	PRESENT	0
681842	679179	19489J	PARTICIPANT	\N	PRESENT	0
681843	679179	07004J	PARTICIPANT	\N	PRESENT	0
681844	679179	20108W	PARTICIPANT	\N	PRESENT	0
681845	679179	14107H	PARTICIPANT	\N	PRESENT	0
681846	679179	14147R	PARTICIPANT	\N	PRESENT	0
681847	679179	20114U	PARTICIPANT	\N	PRESENT	0
681848	679179	14151M	PARTICIPANT	\N	PRESENT	0
681849	679179	14215L	PARTICIPANT	\N	PRESENT	0
681850	679179	20022R	PARTICIPANT	\N	PRESENT	0
681851	679179	11072N	PARTICIPANT	\N	PRESENT	0
681997	676617	14151M	PARTICIPANT	\N	PRESENT	0
681853	679179	14053L	PARTICIPANT	\N	PRESENT	0
681854	679179	14111D	PARTICIPANT	\N	PRESENT	0
681855	679179	10015M	PARTICIPANT	\N	PRESENT	0
681856	679179	19301E	PARTICIPANT	\N	PRESENT	0
681857	679179	19693L	PARTICIPANT	\N	PRESENT	0
681858	679179	19719D	PARTICIPANT	\N	PRESENT	0
681859	679179	11033F	PARTICIPANT	\N	PRESENT	0
681860	679179	19725B	PARTICIPANT	\N	PRESENT	0
681861	679179	11056N	PARTICIPANT	\N	PRESENT	0
681862	679179	19729F	PARTICIPANT	\N	PRESENT	0
681863	679179	95063L	PARTICIPANT	\N	PRESENT	0
681864	679179	19629C	PARTICIPANT	\N	PRESENT	0
681865	679179	14069U	PARTICIPANT	\N	PRESENT	0
681866	679179	11085T	PARTICIPANT	\N	PRESENT	0
681867	679179	19749K	PARTICIPANT	\N	PRESENT	0
681868	679179	08018U	PARTICIPANT	\N	EXCUSE	0
681869	676617	11070L	PARTICIPANT	\N	PRESENT	0
681870	676617	01057W	PARTICIPANT	\N	PRESENT	0
681871	676617	14225N	PARTICIPANT	\N	PRESENT	0
681872	676617	14179A	PARTICIPANT	\N	PRESENT	0
681877	679492	12041X	PARTICIPANT	\N	PRESENT	0
681878	679492	19443T	PARTICIPANT	\N	PRESENT	0
681879	679492	19565D	PARTICIPANT	\N	PRESENT	0
681880	679492	01058X	PARTICIPANT	\N	PRESENT	0
681881	679492	11027H	PARTICIPANT	\N	PRESENT	0
681882	679492	16685X	PARTICIPANT	\N	PRESENT	0
681883	679492	11054L	PARTICIPANT	\N	PRESENT	0
681884	679492	11066Q	PARTICIPANT	\N	PRESENT	0
681885	679492	08056B	PARTICIPANT	\N	PRESENT	0
681886	679492	12028B	PARTICIPANT	\N	PRESENT	0
681887	679492	19421M	PARTICIPANT	\N	PRESENT	0
681888	679492	14193X	PRESIDENT	0	PRESENT	0
681889	679492	19347U	PARTICIPANT	\N	PRESENT	0
681890	679492	97011G	PARTICIPANT	\N	PRESENT	0
681891	679492	14249W	PARTICIPANT	\N	PRESENT	0
681892	679492	20128B	PARTICIPANT	\N	PRESENT	0
681893	679492	08047A	PARTICIPANT	\N	PRESENT	0
681894	679492	14059S	PARTICIPANT	\N	PRESENT	0
681895	679492	14133K	PARTICIPANT	\N	PRESENT	0
681896	679492	11041F	PARTICIPANT	\N	PRESENT	0
681897	679492	01024M	PARTICIPANT	\N	PRESENT	0
681898	679492	14191V	PARTICIPANT	\N	PRESENT	0
681899	679492	19319Q	PARTICIPANT	\N	PRESENT	0
681900	679492	14105F	PARTICIPANT	\N	PRESENT	0
681901	679492	20064C	PARTICIPANT	\N	PRESENT	0
681902	679492	14267Y	PARTICIPANT	\N	PRESENT	0
681903	679492	11083R	PARTICIPANT	\N	PRESENT	0
681904	679492	14255U	PARTICIPANT	\N	PRESENT	0
681905	679492	98022P	PARTICIPANT	\N	EXCUSE	0
681906	679492	19709B	PARTICIPANT	\N	EXCUSE	0
681907	679492	20042V	PARTICIPANT	\N	EXCUSE	0
681908	679492	04042C	PARTICIPANT	\N	EXCUSE	0
681909	669288	19333N	PARTICIPANT	\N	PRESENT	0
681910	669288	20120S	PARTICIPANT	\N	PRESENT	0
681911	676617	19479G	PARTICIPANT	\N	PRESENT	0
681915	669288	14221J	PARTICIPANT	\N	PRESENT	0
681916	679179	19649G	PARTICIPANT	\N	PRESENT	0
681917	679179	04085P	PARTICIPANT	\N	PRESENT	0
681995	676617	19768N	PARTICIPANT	\N	PRESENT	0
681996	676617	19563B	PARTICIPANT	\N	PRESENT	0
681998	676617	11072N	PARTICIPANT	\N	PRESENT	0
681999	676617	14105F	PARTICIPANT	\N	PRESENT	0
682000	676617	14331P	PARTICIPANT	\N	PRESENT	0
682001	676617	14031R	PARTICIPANT	\N	PRESENT	0
682002	676617	14071N	PARTICIPANT	\N	PRESENT	0
656181	656157	04070G	PARTICIPANT	\N	EXCUSE	0
657781	656808	20108W	PARTICIPANT	\N	PRESENT	0
657782	656808	19581D	PARTICIPANT	\N	PRESENT	0
657783	656808	04008A	PARTICIPANT	\N	PRESENT	0
657784	656808	08047A	PARTICIPANT	\N	PRESENT	0
657785	656808	14111D	PARTICIPANT	\N	PRESENT	0
657786	656808	20074E	PARTICIPANT	\N	PRESENT	0
657787	656808	19749K	PARTICIPANT	\N	PRESENT	0
657788	656808	19675J	PARTICIPANT	\N	PRESENT	0
657791	656808	14147R	PARTICIPANT	\N	PRESENT	0
657792	656808	14151M	PARTICIPANT	\N	PRESENT	0
657793	656808	19301E	PARTICIPANT	\N	PRESENT	0
657794	656808	11033F	PARTICIPANT	\N	PRESENT	0
657795	656808	14097Y	PARTICIPANT	\N	PRESENT	0
657796	656808	19447X	PARTICIPANT	\N	PRESENT	0
657800	655685	19699S	PARTICIPANT	\N	PRESENT	0
657801	655685	19533U	PARTICIPANT	\N	PRESENT	0
657802	655685	14229S	PARTICIPANT	\N	PRESENT	0
657803	655685	19573D	PARTICIPANT	\N	PRESENT	0
657804	655685	20112S	PARTICIPANT	\N	PRESENT	0
657805	655685	08012N	PARTICIPANT	\N	PRESENT	0
657806	655685	20124W	PARTICIPANT	\N	PRESENT	0
657807	655685	20026V	PARTICIPANT	\N	PRESENT	0
657808	655685	19593H	PARTICIPANT	\N	PRESENT	0
657809	655685	20132W	PARTICIPANT	\N	PRESENT	0
657810	655685	19643A	PARTICIPANT	\N	PRESENT	0
657811	655685	14073Q	PARTICIPANT	\N	PRESENT	0
657812	655685	19611R	PRESIDENT	0	PRESENT	0
657813	655685	20138D	PARTICIPANT	\N	PRESENT	0
657814	655685	20142Y	PARTICIPANT	\N	PRESENT	0
657815	655685	20048C	PARTICIPANT	\N	PRESENT	0
657816	655685	19693L	PARTICIPANT	\N	PRESENT	0
657817	655685	19399H	PARTICIPANT	\N	PRESENT	0
657818	655685	20152B	PARTICIPANT	\N	PRESENT	0
657819	655685	20172F	PARTICIPANT	\N	PRESENT	0
657820	655685	14030Q	PARTICIPANT	\N	PRESENT	0
657821	655685	20056C	PARTICIPANT	\N	PRESENT	0
657822	655685	20180F	PARTICIPANT	\N	PRESENT	0
657823	655685	20264J	PARTICIPANT	\N	PRESENT	0
657824	655685	11043H	PARTICIPANT	\N	PRESENT	0
657825	655685	11104D	PARTICIPANT	\N	PRESENT	0
657826	655685	19758L	PARTICIPANT	\N	PRESENT	0
657827	655685	20084G	PARTICIPANT	\N	PRESENT	0
657828	656808	19673G	PARTICIPANT	\N	PRESENT	0
657829	656808	19954N	PARTICIPANT	\N	PRESENT	0
657830	656808	14275Y	PARTICIPANT	\N	PRESENT	0
657831	656808	14107H	PARTICIPANT	\N	PRESENT	0
657832	656808	14179A	PARTICIPANT	\N	PRESENT	0
657833	656808	14215L	PARTICIPANT	\N	PRESENT	0
657834	656808	20022R	PARTICIPANT	\N	PRESENT	0
657835	656808	11072N	PARTICIPANT	\N	PRESENT	0
657836	656808	10015M	PARTICIPANT	\N	PRESENT	0
657837	656808	19725B	PARTICIPANT	\N	PRESENT	0
657838	656808	19729F	PARTICIPANT	\N	PRESENT	0
657839	656808	14069U	PARTICIPANT	\N	PRESENT	0
657840	655685	19527W	PARTICIPANT	\N	PRESENT	0
657841	655685	20134Y	PARTICIPANT	\N	PRESENT	0
657842	655685	14109K	PARTICIPANT	\N	PRESENT	0
657843	655685	14123H	PARTICIPANT	\N	PRESENT	0
657844	655685	19621T	PARTICIPANT	\N	PRESENT	0
657845	655685	19735D	PARTICIPANT	\N	EXCUSE	0
657846	655685	11109J	PARTICIPANT	\N	EXCUSE	0
657847	656841	19443T	PARTICIPANT	\N	PRESENT	0
657848	656841	12041X	PARTICIPANT	\N	PRESENT	0
657849	656841	20072C	PARTICIPANT	\N	PRESENT	0
657850	656841	19565D	PARTICIPANT	\N	PRESENT	0
657851	656841	01058X	PARTICIPANT	\N	PRESENT	0
657852	656841	16685X	PARTICIPANT	\N	PRESENT	0
657853	656841	11027H	PARTICIPANT	\N	PRESENT	0
657854	656841	11054L	PARTICIPANT	\N	PRESENT	0
657855	656841	04042C	PRESIDENT	0	PRESENT	0
657856	656841	11066Q	PARTICIPANT	\N	PRESENT	0
657857	656841	19669L	PARTICIPANT	\N	PRESENT	0
657858	656841	12028B	PARTICIPANT	\N	PRESENT	0
657859	656841	19421M	PARTICIPANT	\N	PRESENT	0
657860	656841	19347U	PARTICIPANT	\N	PRESENT	0
657861	656841	14193X	PARTICIPANT	\N	PRESENT	0
657862	656841	97011G	PARTICIPANT	\N	PRESENT	0
657863	656841	08061X	PARTICIPANT	\N	PRESENT	0
657864	656841	14249W	PARTICIPANT	\N	PRESENT	0
657865	656841	14059S	PARTICIPANT	\N	PRESENT	0
657866	656841	04035D	PARTICIPANT	\N	PRESENT	0
657867	656841	01062T	PARTICIPANT	\N	PRESENT	0
657868	656841	14133K	PARTICIPANT	\N	PRESENT	0
657869	656841	11041F	PARTICIPANT	\N	PRESENT	0
657870	656841	08069G	PARTICIPANT	\N	PRESENT	0
657871	656841	20042V	PARTICIPANT	\N	PRESENT	0
657872	656841	01024M	PARTICIPANT	\N	PRESENT	0
657873	656841	14191V	PARTICIPANT	\N	PRESENT	0
657874	656841	20064C	PARTICIPANT	\N	PRESENT	0
657875	656841	98022P	PARTICIPANT	\N	PRESENT	0
657876	656841	11064N	PARTICIPANT	\N	PRESENT	0
657877	656841	14267Y	PARTICIPANT	\N	PRESENT	0
657878	656841	11083R	PARTICIPANT	\N	PRESENT	0
657879	656841	14211G	PARTICIPANT	\N	PRESENT	0
657880	656841	14255U	PARTICIPANT	\N	PRESENT	0
657881	656841	95041E	PARTICIPANT	\N	PRESENT	0
657882	656808	14001X	PARTICIPANT	\N	PRESENT	0
657883	656808	04047H	PARTICIPANT	\N	PRESENT	0
657884	656808	01028R	PARTICIPANT	\N	PRESENT	0
657885	656808	05008E	PARTICIPANT	\N	PRESENT	0
657886	656808	20110Q	PARTICIPANT	\N	PRESENT	0
657887	656808	19649G	PARTICIPANT	\N	PRESENT	0
657888	656808	04085P	PARTICIPANT	\N	PRESENT	0
657889	656808	14089Y	PARTICIPANT	\N	PRESENT	0
657890	656808	95063L	PARTICIPANT	\N	PRESENT	0
657891	656808	19629C	PARTICIPANT	\N	PRESENT	0
657892	656808	14021P	PARTICIPANT	\N	PRESENT	0
657893	656717	14026U	PARTICIPANT	\N	PRESENT	0
657894	656717	17779H	PARTICIPANT	\N	PRESENT	0
657895	656717	04057K	PARTICIPANT	\N	PRESENT	0
657896	656717	19663E	PARTICIPANT	\N	PRESENT	0
657897	656717	19717B	PARTICIPANT	\N	PRESENT	0
657898	656717	19723Y	PARTICIPANT	\N	PRESENT	0
657899	656717	20266L	PARTICIPANT	\N	PRESENT	0
657900	656717	19415P	PARTICIPANT	\N	EXCUSE	0
657901	656717	19683J	PARTICIPANT	\N	EXCUSE	0
657902	656808	19585H	PARTICIPANT	\N	PRESENT	0
657903	656808	20114U	PARTICIPANT	\N	PRESENT	0
657904	656808	14259Y	PARTICIPANT	\N	PRESENT	0
657905	656808	11026G	PARTICIPANT	\N	PRESENT	0
657907	656824	11048N	PARTICIPANT	\N	PRESENT	0
657908	656824	19479G	PARTICIPANT	\N	PRESENT	0
657909	656824	19711U	PARTICIPANT	\N	PRESENT	0
657910	656824	20036X	PARTICIPANT	\N	PRESENT	0
657911	656824	08034U	PARTICIPANT	\N	PRESENT	0
657912	656824	14189C	PARTICIPANT	\N	PRESENT	0
657913	656824	11053K	PARTICIPANT	\N	PRESENT	0
657914	656824	20080C	PARTICIPANT	\N	PRESENT	0
657915	656824	14225N	PRESIDENT	0	PRESENT	0
657916	656824	11070L	PARTICIPANT	\N	PRESENT	0
657917	656824	19671E	PARTICIPANT	\N	PRESENT	0
657918	656824	14083S	PARTICIPANT	\N	PRESENT	0
657919	656824	11012A	PARTICIPANT	\N	PRESENT	0
657920	656824	20252E	PARTICIPANT	\N	PRESENT	0
657921	656824	08009T	PARTICIPANT	\N	PRESENT	0
657922	656824	20070A	PARTICIPANT	\N	PRESENT	0
657923	656824	19349W	PARTICIPANT	\N	PRESENT	0
657924	656824	08010L	PARTICIPANT	\N	PRESENT	0
657925	656824	19741B	PARTICIPANT	\N	PRESENT	0
657926	656824	20116W	PARTICIPANT	\N	PRESENT	0
657927	656824	20126Y	PARTICIPANT	\N	PRESENT	0
657928	656808	17737W	PARTICIPANT	\N	PRESENT	0
657929	656808	11056N	PARTICIPANT	\N	PRESENT	0
657930	656824	04071H	PARTICIPANT	\N	PRESENT	0
657931	656824	11110B	PARTICIPANT	\N	PRESENT	0
657932	656824	14193X	PARTICIPANT	\N	PRESENT	0
657933	656824	19687N	PARTICIPANT	\N	PRESENT	0
657934	656824	20044X	PARTICIPANT	\N	PRESENT	0
657935	656824	11040E	PARTICIPANT	\N	PRESENT	0
657936	656824	14121F	PARTICIPANT	\N	PRESENT	0
658006	657790	19383Y	PARTICIPANT	\N	PRESENT	0
658007	657790	20088L	PARTICIPANT	\N	PRESENT	0
658008	657790	19768N	PARTICIPANT	\N	PRESENT	0
658009	657790	19515S	PARTICIPANT	\N	PRESENT	0
658010	657790	19782L	PARTICIPANT	\N	PRESENT	0
658011	657790	20092G	PARTICIPANT	\N	PRESENT	0
658012	657790	01043Q	PARTICIPANT	\N	PRESENT	0
658013	657790	20078J	PARTICIPANT	\N	PRESENT	0
658014	657790	19441R	PARTICIPANT	\N	PRESENT	0
658015	657790	20082E	PARTICIPANT	\N	PRESENT	0
681515	681432	14225N	PARTICIPANT	\N	PRESENT	0
681516	681432	19387D	PARTICIPANT	\N	PRESENT	0
681517	681432	20114U	PARTICIPANT	\N	PRESENT	0
681518	681432	19723Y	PARTICIPANT	\N	PRESENT	0
681519	681432	20142Y	PARTICIPANT	\N	PRESENT	0
681520	681432	19531S	PARTICIPANT	\N	PRESENT	0
681521	681432	19565D	PARTICIPANT	\N	PRESENT	0
681522	681432	19443T	PARTICIPANT	\N	PRESENT	0
681523	681432	14069U	PARTICIPANT	\N	PRESENT	0
681524	681432	20032T	PARTICIPANT	\N	PRESENT	0
681525	681432	14083S	PARTICIPANT	\N	PRESENT	0
681526	681432	20080C	PARTICIPANT	\N	PRESENT	0
681527	681432	07004J	PARTICIPANT	\N	PRESENT	0
681528	681432	11048N	PARTICIPANT	\N	PRESENT	0
681513	681432	14231L	PARTICIPANT	\N	PRESENT	0
681514	681432	19467C	PARTICIPANT	\N	PRESENT	0
681529	681432	14033T	PARTICIPANT	\N	PRESENT	0
681530	681432	20086J	PARTICIPANT	\N	PRESENT	0
681531	681432	20172F	PARTICIPANT	\N	PRESENT	0
681532	681432	18083K	PARTICIPANT	\N	PRESENT	0
681533	681432	14215L	PARTICIPANT	\N	PRESENT	0
681534	681432	20128B	PARTICIPANT	\N	PRESENT	0
681535	681432	19489J	PARTICIPANT	\N	PRESENT	0
681536	681432	14147R	PARTICIPANT	\N	PRESENT	0
681537	681432	20034V	PARTICIPANT	\N	PRESENT	0
681538	681432	14037X	PARTICIPANT	\N	PRESENT	0
681539	681432	20058E	PARTICIPANT	\N	PRESENT	0
681540	681432	20082E	PARTICIPANT	\N	PRESENT	0
681541	681432	19762G	PARTICIPANT	\N	PRESENT	0
681542	681432	19768N	PARTICIPANT	\N	PRESENT	0
681543	681432	20252E	PARTICIPANT	\N	PRESENT	0
681544	681432	19383Y	PARTICIPANT	\N	PRESENT	0
681545	681432	14179A	PARTICIPANT	\N	PRESENT	0
681546	681432	14026U	PARTICIPANT	\N	PRESENT	0
681610	676593	20130U	PARTICIPANT	\N	PRESENT	0
681611	676593	20082E	PARTICIPANT	\N	PRESENT	0
681612	676593	20114U	PARTICIPANT	\N	PRESENT	0
681613	676593	19715Y	PARTICIPANT	\N	PRESENT	0
681614	676593	14097Y	PARTICIPANT	\N	PRESENT	0
681615	676593	20094J	PARTICIPANT	\N	PRESENT	0
681616	676593	19782L	PARTICIPANT	\N	PRESENT	0
681617	676593	20128B	PARTICIPANT	\N	PRESENT	0
681618	676593	14037X	PARTICIPANT	\N	PRESENT	0
681619	676593	14225N	PARTICIPANT	\N	PRESENT	0
681620	676593	20252E	PARTICIPANT	\N	PRESENT	0
681621	676593	19387D	PARTICIPANT	\N	PRESENT	0
681622	676593	19563B	PARTICIPANT	\N	PRESENT	0
681623	676593	19553Y	PARTICIPANT	\N	PRESENT	0
681624	676593	14231L	PARTICIPANT	\N	PRESENT	0
681625	676593	14083S	PARTICIPANT	\N	PRESENT	0
681626	676593	19687N	PARTICIPANT	\N	PRESENT	0
681627	676593	14215L	PARTICIPANT	\N	PRESENT	0
681628	676593	20054A	PARTICIPANT	\N	PRESENT	0
681629	676593	20126Y	PARTICIPANT	\N	PRESENT	0
681630	676593	19762G	PARTICIPANT	\N	PRESENT	0
681631	676593	14213J	PARTICIPANT	\N	PRESENT	0
681632	676593	14147R	PARTICIPANT	\N	PRESENT	0
681633	676593	14026U	PARTICIPANT	\N	PRESENT	0
681634	676593	20032T	PARTICIPANT	\N	PRESENT	0
681635	676593	20086J	PARTICIPANT	\N	PRESENT	0
681636	676593	20034V	PARTICIPANT	\N	PRESENT	0
681637	676593	19515S	PARTICIPANT	\N	PRESENT	0
681638	676593	20044X	PARTICIPANT	\N	PRESENT	0
681639	676593	19349W	PARTICIPANT	\N	PRESENT	0
681640	676593	20080C	PARTICIPANT	\N	PRESENT	0
681641	676593	11031D	PARTICIPANT	\N	PRESENT	0
682027	681084	20094J	PARTICIPANT	\N	PRESENT	0
681643	676593	11048N	PARTICIPANT	\N	PRESENT	0
681644	676593	20058E	PARTICIPANT	\N	PRESENT	0
682028	681084	04045F	PARTICIPANT	\N	PRESENT	0
682029	681084	19631V	PARTICIPANT	\N	PRESENT	0
682030	681084	11099A	PARTICIPANT	\N	PRESENT	0
682031	681084	19705W	PARTICIPANT	\N	PRESENT	0
682032	681084	19707Y	PARTICIPANT	\N	PRESENT	0
682033	681084	08015R	PARTICIPANT	\N	PRESENT	0
682034	681084	19575F	PARTICIPANT	\N	PRESENT	0
682035	681084	08028W	PARTICIPANT	\N	PRESENT	0
682036	681084	19563B	PARTICIPANT	\N	PRESENT	0
682037	681084	14037X	PARTICIPANT	\N	PRESENT	0
682038	681084	14038Y	PARTICIPANT	\N	PRESENT	0
682039	681084	20030R	PARTICIPANT	\N	PRESENT	0
682040	681084	19467C	PARTICIPANT	\N	PRESENT	0
682041	681084	20034V	PARTICIPANT	\N	PRESENT	0
682042	681084	14187A	PARTICIPANT	\N	PRESENT	0
682043	681084	20144B	PARTICIPANT	\N	PRESENT	0
682044	681084	19695N	PARTICIPANT	\N	PRESENT	0
682045	681084	11090Q	PARTICIPANT	\N	PRESENT	0
682046	681084	01025N	PARTICIPANT	\N	PRESENT	0
682047	681084	14033T	PARTICIPANT	\N	PRESENT	0
682048	681084	20054A	PARTICIPANT	\N	PRESENT	0
682049	681084	14205J	PARTICIPANT	\N	PRESENT	0
682050	681084	20060X	PARTICIPANT	\N	PRESENT	0
682051	681084	20062A	PARTICIPANT	\N	PRESENT	0
682052	681084	14251Q	PARTICIPANT	\N	PRESENT	0
682053	681084	19507S	PARTICIPANT	\N	PRESENT	0
681608	676593	01043Q	PARTICIPANT	\N	PRESENT	0
681609	676593	20092G	PARTICIPANT	\N	PRESENT	0
682054	681084	20286Q	PARTICIPANT	\N	PRESENT	0
682055	681084	20298U	PARTICIPANT	\N	PRESENT	0
682056	681084	19747H	PARTICIPANT	\N	PRESENT	0
682057	681084	14207L	PARTICIPANT	\N	PRESENT	0
682058	681084	14257W	PARTICIPANT	\N	PRESENT	0
682059	679492	17023S	PARTICIPANT	\N	PRESENT	0
682064	676617	14053L	PARTICIPANT	\N	PRESENT	0
682065	676617	20030R	PARTICIPANT	\N	PRESENT	0
682066	676617	08056B	PARTICIPANT	\N	PRESENT	0
682067	676617	19715Y	PARTICIPANT	\N	PRESENT	0
682068	676617	19549D	PARTICIPANT	\N	PRESENT	0
682069	676617	20090E	PARTICIPANT	\N	PRESENT	0
682070	676617	19447X	PARTICIPANT	\N	PRESENT	0
682071	676617	19531S	PARTICIPANT	\N	PRESENT	0
682072	676617	19691J	PARTICIPANT	\N	PRESENT	0
682075	676617	19826F	PARTICIPANT	\N	PRESENT	0
682078	676617	11097X	PARTICIPANT	\N	PRESENT	0
682079	676617	19739H	PARTICIPANT	\N	PRESENT	0
682080	676617	19415P	PARTICIPANT	\N	PRESENT	0
682081	676617	20066E	PARTICIPANT	\N	PRESENT	0
682082	676617	19565D	PARTICIPANT	\N	PRESENT	0
682083	676617	14217N	PARTICIPANT	\N	PRESENT	0
682084	676617	19657G	PARTICIPANT	\N	PRESENT	0
682085	676617	14213J	PARTICIPANT	\N	PRESENT	0
682086	676617	11048N	PARTICIPANT	\N	PRESENT	0
682087	676617	20130U	PARTICIPANT	\N	PRESENT	0
682088	676617	19820Y	PARTICIPANT	\N	PRESENT	0
682092	676617	19583F	PARTICIPANT	\N	PRESENT	0
682093	676617	20126Y	PARTICIPANT	\N	PRESENT	0
682094	676617	19679N	PARTICIPANT	\N	PRESENT	0
682095	676617	14205J	PARTICIPANT	\N	PRESENT	0
682096	676617	14133K	PARTICIPANT	\N	PRESENT	0
682097	676617	20132W	PARTICIPANT	\N	PRESENT	0
682098	676617	19719D	PARTICIPANT	\N	PRESENT	0
682099	676617	19591F	PARTICIPANT	\N	PRESENT	0
682100	676617	19723Y	PARTICIPANT	\N	PRESENT	0
682101	676617	14033T	PARTICIPANT	\N	PRESENT	0
682102	676617	17965H	PARTICIPANT	\N	PRESENT	0
682103	676617	18193Q	PARTICIPANT	\N	PRESENT	0
682104	676617	20058E	PARTICIPANT	\N	PRESENT	0
682105	676617	20026V	PARTICIPANT	\N	PRESENT	0
682106	676617	20056C	PARTICIPANT	\N	PRESENT	0
654647	654299	20092G	PARTICIPANT	\N	PRESENT	0
654648	654299	14357A	PARTICIPANT	\N	PRESENT	0
654649	654299	14187A	PARTICIPANT	\N	PRESENT	0
654650	654299	19441R	PARTICIPANT	\N	PRESENT	0
654651	654299	20144B	PARTICIPANT	\N	PRESENT	0
660135	659411	20064C	PARTICIPANT	\N	PRESENT	0
654653	654299	11090Q	PRESIDENT	0	PRESENT	0
654654	654299	20054A	PARTICIPANT	\N	PRESENT	0
654655	654299	20104S	PARTICIPANT	\N	PRESENT	0
654656	654299	14205J	PARTICIPANT	\N	PRESENT	0
654657	654299	11099A	PARTICIPANT	\N	PRESENT	0
654658	654299	20062A	PARTICIPANT	\N	PRESENT	0
654659	654299	19705W	PARTICIPANT	\N	PRESENT	0
654660	654299	19707Y	PARTICIPANT	\N	PRESENT	1
654661	654299	19575F	PARTICIPANT	\N	PRESENT	0
654662	654299	20286Q	PARTICIPANT	\N	PRESENT	0
654663	654299	19369B	PARTICIPANT	\N	PRESENT	0
654664	654299	14329V	PARTICIPANT	\N	PRESENT	0
654665	654299	14257W	PARTICIPANT	\N	PRESENT	0
660133	659411	14053L	PARTICIPANT	\N	PRESENT	0
660134	659411	14231L	PARTICIPANT	\N	PRESENT	0
660136	659411	04045F	PARTICIPANT	\N	PRESENT	0
660137	659411	20106U	PARTICIPANT	\N	PRESENT	0
660138	659411	20172F	PARTICIPANT	\N	PRESENT	0
660139	659411	19573D	PARTICIPANT	\N	PRESENT	0
660140	659411	14033T	PARTICIPANT	\N	PRESENT	0
660141	659411	01028R	PARTICIPANT	\N	PRESENT	0
660142	659411	20086J	PARTICIPANT	\N	PRESENT	0
660143	659411	11043H	PARTICIPANT	\N	PRESENT	0
660144	659411	14213J	PARTICIPANT	\N	PRESENT	0
660145	659411	14107H	PARTICIPANT	\N	PRESENT	0
660146	659411	14111D	PARTICIPANT	\N	PRESENT	0
660147	659411	20114U	PARTICIPANT	\N	PRESENT	0
660148	659411	18083K	PARTICIPANT	\N	PRESENT	0
660149	659411	11077T	PARTICIPANT	\N	PRESENT	0
660150	659411	19349W	PARTICIPANT	\N	PRESENT	0
660151	659411	14083S	PARTICIPANT	\N	PRESENT	0
660152	659411	19782L	PARTICIPANT	\N	PRESENT	0
660153	659411	14026U	PARTICIPANT	\N	PRESENT	0
660154	659411	20070A	PARTICIPANT	\N	PRESENT	0
660155	659411	19545Y	PARTICIPANT	\N	PRESENT	0
661907	661799	19443T	PARTICIPANT	\N	EXCUSE	0
663070	661834	11031D	PARTICIPANT	\N	PRESENT	0
663071	661834	19715Y	PARTICIPANT	\N	PRESENT	0
663072	661834	19531S	PARTICIPANT	\N	PRESENT	0
663073	661834	19725B	PARTICIPANT	\N	PRESENT	0
663074	661834	19631V	PARTICIPANT	\N	PRESENT	0
663075	661834	20028X	PARTICIPANT	\N	PRESENT	0
663076	661834	20080C	PARTICIPANT	\N	PRESENT	0
663077	661834	20070A	PARTICIPANT	\N	PRESENT	0
663078	661834	19687N	PARTICIPANT	\N	PRESENT	0
663079	661834	20914V	PARTICIPANT	\N	PRESENT	0
663080	661834	19347U	PARTICIPANT	\N	PRESENT	0
663081	661834	20092G	PARTICIPANT	\N	PRESENT	0
663082	661834	14021P	PARTICIPANT	\N	PRESENT	0
663083	661834	95063L	PARTICIPANT	\N	PRESENT	0
663084	661834	19349W	PARTICIPANT	\N	PRESENT	0
663085	661834	20072C	PARTICIPANT	\N	PRESENT	0
663086	661834	19553Y	PARTICIPANT	\N	PRESENT	0
663087	661834	14107H	PARTICIPANT	\N	PRESENT	0
663088	661834	11012A	PARTICIPANT	\N	PRESENT	0
663089	661834	19387D	PARTICIPANT	\N	PRESENT	0
663090	661834	14195A	PARTICIPANT	\N	PRESENT	0
663091	661834	19545Y	PARTICIPANT	\N	PRESENT	0
663092	661834	20036X	PARTICIPANT	\N	PRESENT	0
663093	661834	20100N	PARTICIPANT	\N	PRESENT	0
663094	661834	08009T	PARTICIPANT	\N	PRESENT	0
663095	661834	19441R	PARTICIPANT	\N	PRESENT	0
663096	661834	19479G	PARTICIPANT	\N	PRESENT	0
663097	661834	19691J	PARTICIPANT	\N	PRESENT	0
663652	661836	08028W	PARTICIPANT	\N	PRESENT	0
663654	661836	11043H	PARTICIPANT	\N	PRESENT	0
663655	661836	10015M	PARTICIPANT	\N	PRESENT	0
663656	661836	19591F	PARTICIPANT	\N	PRESENT	0
663657	661836	14223L	PARTICIPANT	\N	PRESENT	0
663658	661836	14037X	PARTICIPANT	\N	PRESENT	0
663659	661836	19643A	PARTICIPANT	\N	PRESENT	0
663660	661836	19697Q	PARTICIPANT	\N	PRESENT	0
663661	661836	11072N	PARTICIPANT	\N	PRESENT	0
663662	661836	19525U	PARTICIPANT	\N	PRESENT	0
663663	661836	11080N	PARTICIPANT	\N	PRESENT	0
663664	661836	19301E	PARTICIPANT	\N	PRESENT	0
663665	661836	95063L	PARTICIPANT	\N	PRESENT	0
663666	661836	20068G	PARTICIPANT	\N	PRESENT	0
663667	661836	05012A	PARTICIPANT	\N	PRESENT	0
663668	661836	19679N	PARTICIPANT	\N	PRESENT	0
663669	661836	01060R	PARTICIPANT	\N	PRESENT	0
663670	661836	14053L	PARTICIPANT	\N	PRESENT	0
663671	661836	14193X	PARTICIPANT	\N	PRESENT	0
663672	661836	19798U	PARTICIPANT	\N	PRESENT	0
663673	661836	04085P	PARTICIPANT	\N	PRESENT	0
663674	661836	19758L	PARTICIPANT	\N	PRESENT	0
663675	661836	19533U	PARTICIPANT	\N	PRESENT	0
663676	661836	20118Y	PARTICIPANT	\N	PRESENT	0
663677	661836	11031D	PARTICIPANT	\N	PRESENT	0
663679	661836	12041X	PARTICIPANT	\N	PRESENT	0
663680	661836	19593H	PARTICIPANT	\N	PRESENT	0
663681	661836	20136B	PARTICIPANT	\N	PRESENT	0
663682	661836	11115U	PARTICIPANT	\N	PRESENT	0
663683	661836	19667J	PARTICIPANT	\N	PRESENT	0
663684	661836	20102Q	PARTICIPANT	\N	PRESENT	0
663685	661836	14031R	PARTICIPANT	\N	PRESENT	0
663686	661836	11010L	PARTICIPANT	\N	PRESENT	0
663687	661836	19545Y	PARTICIPANT	\N	PRESENT	0
663688	661836	14195A	PARTICIPANT	\N	PRESENT	0
663689	661836	14211G	PARTICIPANT	\N	PRESENT	0
663690	661836	19573D	PARTICIPANT	\N	PRESENT	0
663691	661836	11064N	PARTICIPANT	\N	PRESENT	0
663692	661836	20026V	PARTICIPANT	\N	PRESENT	0
663693	661836	20096L	PARTICIPANT	\N	PRESENT	0
663694	661836	14251Q	PARTICIPANT	\N	PRESENT	0
663695	661836	20180F	PARTICIPANT	\N	PRESENT	0
663696	661836	14111D	PARTICIPANT	\N	PRESENT	0
663697	661836	92040Q	PARTICIPANT	\N	PRESENT	0
663698	661836	04057K	PARTICIPANT	\N	PRESENT	0
663699	661836	19954N	PARTICIPANT	\N	PRESENT	0
663700	661836	20140W	PARTICIPANT	\N	PRESENT	0
663701	661836	19563B	PARTICIPANT	\N	PRESENT	0
663702	661836	20050V	PARTICIPANT	\N	PRESENT	0
663703	661836	19585H	PARTICIPANT	\N	PRESENT	0
663704	661836	20138D	PARTICIPANT	\N	PRESENT	0
663705	661836	20172F	PARTICIPANT	\N	PRESENT	0
663706	661836	08069G	PARTICIPANT	\N	PRESENT	0
663707	661836	19527W	PARTICIPANT	\N	PRESENT	0
663708	661836	14253S	PARTICIPANT	\N	PRESENT	0
663709	661836	11103C	PARTICIPANT	\N	PRESENT	0
663710	661836	07033P	PARTICIPANT	\N	PRESENT	0
663711	661836	20120S	PARTICIPANT	\N	PRESENT	0
663712	661836	19671E	PARTICIPANT	\N	PRESENT	0
663713	661836	20114U	PARTICIPANT	\N	PRESENT	0
663068	661834	12041X	PARTICIPANT	\N	PRESENT	0
663069	661834	11074Q	PARTICIPANT	\N	PRESENT	0
663714	661836	19367Y	PARTICIPANT	\N	PRESENT	0
663715	661836	20080C	PARTICIPANT	\N	PRESENT	0
663716	661836	20060X	PARTICIPANT	\N	PRESENT	0
663717	661836	19581D	PARTICIPANT	\N	PRESENT	0
663718	661836	12028B	PARTICIPANT	\N	PRESENT	0
663719	661836	19762G	PARTICIPANT	\N	PRESENT	0
663720	661836	11027H	PARTICIPANT	\N	PRESENT	0
663721	661836	20070A	PARTICIPANT	\N	PRESENT	0
663722	661836	19549D	PARTICIPANT	\N	PRESENT	0
663723	661836	19251M	PARTICIPANT	\N	PRESENT	0
663724	661836	20152B	PARTICIPANT	\N	PRESENT	0
663725	661836	20020P	PARTICIPANT	\N	PRESENT	0
663726	661836	19647E	PARTICIPANT	\N	PRESENT	0
663727	661836	14281W	PARTICIPANT	\N	PRESENT	0
663728	661836	19675J	PARTICIPANT	\N	PRESENT	0
663729	661836	14357A	PARTICIPANT	\N	PRESENT	0
663730	661836	14329V	PARTICIPANT	\N	PRESENT	0
656550	656269	20130U	PARTICIPANT	\N	PRESENT	0
656551	656269	19569H	PARTICIPANT	\N	PRESENT	0
656552	656269	19679N	PARTICIPANT	\N	PRESENT	0
656569	656416	14109K	PARTICIPANT	\N	PRESENT	1
657568	657567	20092G	PARTICIPANT	\N	PRESENT	0
657569	657567	19515S	PRESIDENT	0	PRESENT	0
657570	657567	20094J	PARTICIPANT	\N	PRESENT	0
657571	657567	20030R	PARTICIPANT	\N	PRESENT	0
657572	657567	19251M	PARTICIPANT	\N	PRESENT	0
657573	657567	20054A	PARTICIPANT	\N	PRESENT	0
657574	657567	20082E	PARTICIPANT	\N	PRESENT	0
657575	657567	19760E	PARTICIPANT	\N	PRESENT	0
657576	657567	19695N	PARTICIPANT	\N	PRESENT	0
657577	657567	19671E	PARTICIPANT	\N	PRESENT	0
657578	657567	14195A	PARTICIPANT	\N	PRESENT	0
657579	657567	19369B	PARTICIPANT	\N	PRESENT	0
657580	657567	19467C	PARTICIPANT	\N	PRESENT	0
657581	657567	08015R	PARTICIPANT	\N	PRESENT	0
657582	657567	08028W	PARTICIPANT	\N	PRESENT	0
657583	657567	19575F	PARTICIPANT	\N	PRESENT	0
657584	657567	14030Q	PARTICIPANT	\N	PRESENT	0
657585	657567	19762G	PARTICIPANT	\N	PRESENT	0
657587	657567	14257W	PARTICIPANT	\N	PRESENT	0
657588	657567	20018V	PARTICIPANT	\N	PRESENT	0
657589	657567	19631V	PARTICIPANT	\N	PRESENT	0
657590	657567	20028X	PARTICIPANT	\N	PRESENT	0
657591	657567	20088L	PARTICIPANT	\N	PRESENT	0
657592	657567	14207L	PARTICIPANT	\N	PRESENT	0
657593	657567	19782L	PARTICIPANT	\N	PRESENT	0
657594	657567	14187A	PARTICIPANT	\N	PRESENT	0
657595	657567	19441R	PARTICIPANT	\N	PRESENT	0
657596	657567	19747H	PARTICIPANT	\N	PRESENT	0
657597	657567	20286Q	PARTICIPANT	\N	PRESENT	0
657598	657567	14037X	PARTICIPANT	\N	PRESENT	0
657599	657567	14033T	PARTICIPANT	\N	PRESENT	0
657600	657567	19383Y	PARTICIPANT	\N	PRESENT	0
657601	657567	20062A	PARTICIPANT	\N	PRESENT	0
657602	657567	01025N	PARTICIPANT	\N	PRESENT	0
657603	657567	19563B	PARTICIPANT	\N	PRESENT	0
657604	657567	20078J	PARTICIPANT	\N	PRESENT	0
657605	657567	20034V	PARTICIPANT	\N	PRESENT	0
657606	657567	19768N	PARTICIPANT	\N	PRESENT	0
657613	657567	14205J	PARTICIPANT	\N	PRESENT	0
657615	657567	11090Q	PARTICIPANT	\N	PRESENT	0
659028	656929	14030Q	PRESIDENT	0	PRESENT	0
659029	656929	11031D	PARTICIPANT	\N	PRESENT	0
659030	656929	14109K	PARTICIPANT	\N	PRESENT	0
659031	656929	20066E	PARTICIPANT	\N	PRESENT	0
659032	656929	20118Y	PARTICIPANT	\N	EXCUSE	0
659033	656929	19681G	PARTICIPANT	\N	EXCUSE	0
659034	656929	20024T	PARTICIPANT	\N	EXCUSE	0
659035	656929	14189C	PARTICIPANT	\N	EXCUSE	0
659036	656929	20130U	PARTICIPANT	\N	EXCUSE	0
659037	656929	20106U	PARTICIPANT	\N	EXCUSE	0
659038	656929	19693L	PARTICIPANT	\N	PRESENT	0
659039	656929	20080C	PARTICIPANT	\N	PRESENT	0
659055	656929	20114U	PARTICIPANT	\N	PRESENT	0
659057	656929	07029T	PARTICIPANT	\N	PRESENT	0
664683	664681	01028R	PARTICIPANT	\N	PRESENT	0
664749	664748	08018U	PARTICIPANT	\N	PRESENT	0
667445	664634	14059S	PARTICIPANT	\N	PRESENT	0
667446	664634	20146D	PARTICIPANT	\N	PRESENT	0
667447	664634	14147R	PARTICIPANT	\N	PRESENT	0
667448	664634	11072N	PARTICIPANT	\N	EXCUSE	0
667449	664634	19329S	PARTICIPANT	\N	EXCUSE	0
667533	665153	14147R	PARTICIPANT	\N	PRESENT	0
672379	667316	11043H	PARTICIPANT	\N	EXCUSE	0
672380	667316	19717B	PRESIDENT	0	PRESENT	0
672381	667316	20034V	PARTICIPANT	\N	PRESENT	0
672394	672383	05008E	PARTICIPANT	\N	EXCUSE	0
672395	672383	19717B	PRESIDENT	0	PRESENT	0
672396	672383	11043H	PARTICIPANT	\N	EXCUSE	0
672397	672383	20034V	PARTICIPANT	\N	PRESENT	0
672401	671830	08015R	PARTICIPANT	\N	PRESENT	0
672402	671830	14037X	PARTICIPANT	\N	PRESENT	0
672403	671830	14205J	PARTICIPANT	\N	PRESENT	0
672404	671830	19441R	PARTICIPANT	\N	PRESENT	0
672405	671830	19563B	PARTICIPANT	\N	PRESENT	0
672406	671830	20028X	PARTICIPANT	\N	PRESENT	0
672407	671830	20018V	PARTICIPANT	\N	PRESENT	0
672408	671830	19369B	PARTICIPANT	\N	PRESENT	0
672409	671830	14257W	PARTICIPANT	\N	PRESENT	0
672410	671830	19768N	PARTICIPANT	\N	PRESENT	0
672411	671830	20030R	PARTICIPANT	\N	PRESENT	0
672412	671830	11090Q	PRESIDENT	0	PRESENT	0
672413	671830	20298U	PARTICIPANT	\N	PRESENT	0
672414	671830	20082E	PARTICIPANT	\N	PRESENT	0
672415	671830	20092G	PARTICIPANT	\N	PRESENT	0
672416	671830	20062A	PARTICIPANT	\N	PRESENT	0
672417	671830	19413M	PARTICIPANT	\N	PRESENT	0
672421	671830	14251Q	PARTICIPANT	\N	PRESENT	0
682912	682911	04043D	PARTICIPANT	\N	PRESENT	0
682913	682911	19693L	PARTICIPANT	\N	PRESENT	0
682925	674944	18083K	PARTICIPANT	\N	PRESENT	0
682927	674944	19715Y	PARTICIPANT	\N	PRESENT	0
682928	674944	19301E	PARTICIPANT	\N	PRESENT	0
682929	674944	20146D	PARTICIPANT	\N	PRESENT	0
682930	674946	11043H	PARTICIPANT	\N	EXCUSE	0
683272	676623	14253S	PARTICIPANT	\N	PRESENT	0
683340	676624	19711U	PARTICIPANT	\N	PRESENT	0
683341	676624	08009T	PARTICIPANT	\N	PRESENT	0
683342	676624	20044X	PARTICIPANT	\N	PRESENT	0
683343	676624	11090Q	PARTICIPANT	\N	PRESENT	0
683344	676624	19599P	PARTICIPANT	\N	PRESENT	0
683345	676624	20914V	PARTICIPANT	\N	PRESENT	0
683346	676624	14219Q	PARTICIPANT	\N	PRESENT	0
683347	676624	11053K	PARTICIPANT	\N	PRESENT	0
683348	676624	14033T	PARTICIPANT	\N	PRESENT	0
683349	676624	19545Y	PARTICIPANT	\N	PRESENT	0
683350	676624	20136B	PARTICIPANT	\N	PRESENT	0
683351	676624	19745F	PARTICIPANT	\N	PRESENT	0
683352	676624	19820Y	PARTICIPANT	\N	PRESENT	0
683353	676624	19826F	PARTICIPANT	\N	PRESENT	0
683354	676624	19637C	PARTICIPANT	\N	PRESENT	0
683355	676624	18083K	PARTICIPANT	\N	PRESENT	0
683356	676624	20024T	PARTICIPANT	\N	PRESENT	0
683357	676624	11101A	PARTICIPANT	\N	PRESENT	0
683358	676624	20046A	PARTICIPANT	\N	PRESENT	0
683359	676624	11065P	PARTICIPANT	\N	PRESENT	0
683360	676624	19717B	PARTICIPANT	\N	PRESENT	0
683361	676624	14069U	PARTICIPANT	\N	PRESENT	0
683362	676624	14257W	PARTICIPANT	\N	PRESENT	0
683363	676624	19619A	PARTICIPANT	\N	PRESENT	0
683364	676624	99004R	PARTICIPANT	\N	PRESENT	0
683365	676624	20120S	PARTICIPANT	\N	PRESENT	0
683366	676624	20102Q	PARTICIPANT	\N	PRESENT	0
683367	676624	11012A	PARTICIPANT	\N	PRESENT	0
683368	676624	19631V	PARTICIPANT	\N	PRESENT	0
683335	676624	12041X	PARTICIPANT	\N	PRESENT	0
683339	676624	20032T	PARTICIPANT	\N	PRESENT	0
683369	680766	19333N	PARTICIPANT	\N	PRESENT	0
683370	676624	19651A	PARTICIPANT	\N	PRESENT	0
683371	676624	20100N	PARTICIPANT	\N	PRESENT	0
683372	676624	19693L	PARTICIPANT	\N	PRESENT	0
683373	676624	20088L	PARTICIPANT	\N	PRESENT	0
683374	676624	14225N	PARTICIPANT	\N	PRESENT	0
683375	676624	11048N	PARTICIPANT	\N	PRESENT	0
683376	676624	19527W	PARTICIPANT	\N	PRESENT	0
683377	676624	20142Y	PARTICIPANT	\N	PRESENT	0
683378	676624	19577H	PARTICIPANT	\N	PRESENT	0
683379	676624	07004J	PARTICIPANT	\N	PRESENT	0
683380	676624	08034U	PARTICIPANT	\N	PRESENT	0
683381	676624	20086J	PARTICIPANT	\N	PRESENT	0
683382	645528	11083R	PARTICIPANT	\N	PRESENT	0
683383	645528	11026G	PARTICIPANT	\N	PRESENT	0
683384	645528	04035D	PARTICIPANT	\N	PRESENT	0
683386	676624	14357A	PARTICIPANT	\N	PRESENT	0
683387	676624	19295A	PARTICIPANT	\N	PRESENT	0
683388	676624	20054A	PARTICIPANT	\N	PRESENT	0
683389	676624	19657G	PARTICIPANT	\N	PRESENT	0
683390	676624	14253S	PARTICIPANT	\N	PRESENT	0
683391	676624	19647E	PARTICIPANT	\N	PRESENT	0
683392	676624	07029T	PARTICIPANT	\N	PRESENT	0
683393	676624	04071H	PARTICIPANT	\N	PRESENT	0
683394	676624	20152B	PARTICIPANT	\N	PRESENT	0
683396	683271	19711U	PARTICIPANT	\N	PRESENT	0
683399	683271	11090Q	PARTICIPANT	\N	PRESENT	0
683400	683271	19599P	PARTICIPANT	\N	PRESENT	0
665787	663456	19573D	PARTICIPANT	\N	PRESENT	0
665788	663456	04059M	PARTICIPANT	\N	PRESENT	0
665789	663456	20112S	PARTICIPANT	\N	PRESENT	0
665790	663456	08012N	PARTICIPANT	\N	PRESENT	0
665791	663456	11104D	PARTICIPANT	\N	PRESENT	0
665792	663456	20124W	PARTICIPANT	\N	PRESENT	0
665793	663456	20026V	PARTICIPANT	\N	PRESENT	0
665794	664672	20110Q	PARTICIPANT	\N	PRESENT	0
665795	665149	14133K	PARTICIPANT	\N	PRESENT	0
665796	665149	20128B	PARTICIPANT	\N	PRESENT	0
665797	664672	14001X	PARTICIPANT	\N	PRESENT	0
665798	663456	14229S	PARTICIPANT	\N	PRESENT	0
665799	663456	19593H	PARTICIPANT	\N	PRESENT	0
665800	663456	11043H	PARTICIPANT	\N	PRESENT	0
665801	663456	19651A	PARTICIPANT	\N	PRESENT	0
665802	665149	20060X	PARTICIPANT	\N	PRESENT	0
665803	665149	19503N	PARTICIPANT	\N	PRESENT	0
665804	665149	04092N	PARTICIPANT	\N	PRESENT	0
665805	665149	01048V	PARTICIPANT	\N	PRESENT	0
665810	664322	19762G	PARTICIPANT	\N	PRESENT	0
665815	664672	11056N	PARTICIPANT	\N	PRESENT	0
665816	665149	16685X	PARTICIPANT	\N	PRESENT	0
665820	665149	20042V	PARTICIPANT	\N	PRESENT	0
665821	665149	19295A	PARTICIPANT	\N	PRESENT	0
665826	665379	19768N	PARTICIPANT	\N	PRESENT	0
665827	665379	19515S	PARTICIPANT	\N	PRESENT	0
665828	665379	19782L	PARTICIPANT	\N	PRESENT	0
665829	665379	20092G	PARTICIPANT	\N	PRESENT	0
665830	665379	19413M	PARTICIPANT	\N	PRESENT	0
665831	665379	20094J	PARTICIPANT	\N	PRESENT	0
665832	665379	04045F	PARTICIPANT	\N	PRESENT	0
665833	665379	19866P	PARTICIPANT	\N	PRESENT	0
665834	665379	19631V	PARTICIPANT	\N	PRESENT	0
665835	665379	08015R	PARTICIPANT	\N	PRESENT	0
665836	665379	19575F	PARTICIPANT	\N	PRESENT	0
665837	665379	19369B	PARTICIPANT	\N	PRESENT	0
665838	665379	20018V	PARTICIPANT	\N	PRESENT	0
665839	665379	08028W	PARTICIPANT	\N	PRESENT	0
665840	665379	19563B	PARTICIPANT	\N	PRESENT	0
665841	665379	14037X	PARTICIPANT	\N	PRESENT	0
665842	665379	20028X	PARTICIPANT	\N	PRESENT	0
665843	665379	14038Y	PARTICIPANT	\N	PRESENT	0
665844	665379	19467C	PARTICIPANT	\N	PRESENT	0
665845	665379	14187A	PARTICIPANT	\N	PRESENT	0
665846	665379	20144B	PARTICIPANT	\N	PRESENT	0
665847	665379	14033T	PARTICIPANT	\N	PRESENT	0
665848	665379	11090Q	PRESIDENT	0	PRESENT	0
665849	665379	01025N	PARTICIPANT	\N	PRESENT	0
665850	665379	20054A	PARTICIPANT	\N	PRESENT	0
665851	665379	20062A	PARTICIPANT	\N	PRESENT	0
665852	665379	14251Q	PARTICIPANT	\N	PRESENT	0
665853	665379	19507S	PARTICIPANT	\N	PRESENT	0
665854	665379	20286Q	PARTICIPANT	\N	PRESENT	0
665855	665379	20298U	PARTICIPANT	\N	PRESENT	0
665856	665379	19747H	PARTICIPANT	\N	PRESENT	0
665857	665379	14257W	PARTICIPANT	\N	PRESENT	0
665858	665379	20030R	PARTICIPANT	\N	EXCUSE	0
665859	665379	20104S	PARTICIPANT	\N	EXCUSE	0
665860	665149	14331P	PARTICIPANT	\N	PRESENT	0
665866	665149	19619A	PARTICIPANT	\N	PRESENT	0
665867	665149	14059S	PARTICIPANT	\N	PRESENT	0
665873	665149	14031R	PARTICIPANT	\N	PRESENT	0
665874	665379	19441R	PARTICIPANT	\N	PRESENT	0
665875	664322	14173T	PARTICIPANT	\N	PRESENT	0
665876	665149	19723Y	PARTICIPANT	\N	PRESENT	0
665929	665149	14083S	PARTICIPANT	\N	PRESENT	0
666376	661264	14189C	PARTICIPANT	\N	PRESENT	0
665931	665149	19719D	PARTICIPANT	\N	PRESENT	0
665932	665149	19631V	PARTICIPANT	\N	PRESENT	0
665933	665149	14215L	PARTICIPANT	\N	PRESENT	0
665934	665149	19768N	PARTICIPANT	\N	PRESENT	0
666377	661264	20024T	PARTICIPANT	\N	PRESENT	0
666378	661264	14030Q	PARTICIPANT	\N	PRESENT	0
666379	661264	20138D	PARTICIPANT	\N	EXCUSE	0
666380	661264	17737W	PARTICIPANT	\N	PRESENT	0
666381	661264	20080C	PARTICIPANT	\N	EXCUSE	0
666383	661264	11031D	PARTICIPANT	\N	PRESENT	0
666384	661264	19693L	PARTICIPANT	\N	PRESENT	0
666385	661264	19599P	PARTICIPANT	\N	PRESENT	0
666386	661264	14179A	PARTICIPANT	\N	PRESENT	0
666387	661264	20066E	PARTICIPANT	\N	PRESENT	0
666388	661264	19715Y	PARTICIPANT	\N	EXCUSE	0
666389	661264	14221J	PARTICIPANT	\N	EXCUSE	0
666390	661264	14109K	PARTICIPANT	\N	PRESENT	0
666392	661264	20130U	PARTICIPANT	\N	EXCUSE	0
666393	661264	11045K	PARTICIPANT	\N	PRESENT	0
666394	661264	20098N	PARTICIPANT	\N	EXCUSE	0
666395	661264	20046A	PARTICIPANT	\N	PRESENT	0
666396	661264	19749K	PARTICIPANT	\N	PRESENT	0
666502	665380	20104S	PARTICIPANT	\N	EXCUSE	0
666549	666548	11054L	PARTICIPANT	\N	PRESENT	0
666550	666548	01024M	PARTICIPANT	\N	PRESENT	0
666551	666548	01058X	PARTICIPANT	\N	PRESENT	0
666552	666548	14267Y	PARTICIPANT	\N	PRESENT	0
666553	666548	19347U	PARTICIPANT	\N	PRESENT	0
666554	666548	12041X	PARTICIPANT	\N	PRESENT	0
666555	666548	12028B	PARTICIPANT	\N	PRESENT	0
666556	666548	14059S	PARTICIPANT	\N	PRESENT	0
666571	666569	19507S	PARTICIPANT	\N	PRESENT	0
666572	666569	01025N	PARTICIPANT	\N	PRESENT	0
666573	666569	19413M	PARTICIPANT	\N	PRESENT	0
666700	665151	08010L	PARTICIPANT	\N	PRESENT	0
666701	665151	14249W	PARTICIPANT	\N	PRESENT	0
666702	665151	04047H	PARTICIPANT	\N	PRESENT	0
666703	665151	14026U	PARTICIPANT	\N	PRESENT	0
666704	665151	20106U	PARTICIPANT	\N	PRESENT	0
666705	665151	19349W	PARTICIPANT	\N	PRESENT	0
666706	665151	11101A	PARTICIPANT	\N	PRESENT	0
666707	665151	20146D	PARTICIPANT	\N	PRESENT	0
666708	665151	19703U	PARTICIPANT	\N	PRESENT	0
666710	665151	11033F	PARTICIPANT	\N	PRESENT	0
666711	665151	08069G	PARTICIPANT	\N	PRESENT	0
666712	665151	99004R	PARTICIPANT	\N	PRESENT	0
666713	665151	20116W	PARTICIPANT	\N	PRESENT	0
666715	665151	20132W	PARTICIPANT	\N	PRESENT	0
666716	665151	19679N	PARTICIPANT	\N	PRESENT	0
666717	665151	19387D	PARTICIPANT	\N	PRESENT	0
666718	665151	20076G	PARTICIPANT	\N	PRESENT	0
666720	665151	14123H	PARTICIPANT	\N	PRESENT	0
666721	665151	19629C	PARTICIPANT	\N	PRESENT	0
666722	665151	01058X	PARTICIPANT	\N	PRESENT	0
666723	665151	19575F	PARTICIPANT	\N	PRESENT	0
666724	665151	20072C	PARTICIPANT	\N	PRESENT	0
666725	665151	04033B	PARTICIPANT	\N	PRESENT	0
666726	665151	19866P	PARTICIPANT	\N	PRESENT	0
666727	665151	11012A	PARTICIPANT	\N	PRESENT	0
666728	665151	14195A	PARTICIPANT	\N	PRESENT	0
666729	665151	17589D	PARTICIPANT	\N	PRESENT	0
666730	665151	14211G	PARTICIPANT	\N	PRESENT	0
666731	665151	14251Q	PARTICIPANT	\N	PRESENT	0
666732	665151	19525U	PARTICIPANT	\N	PRESENT	0
666733	665151	14055N	PARTICIPANT	\N	PRESENT	0
666734	665151	19553Y	PARTICIPANT	\N	PRESENT	0
666735	665151	04057K	PARTICIPANT	\N	PRESENT	0
666736	665151	19563B	PARTICIPANT	\N	PRESENT	0
666737	665151	20050V	PARTICIPANT	\N	PRESENT	0
666738	665151	20122U	PARTICIPANT	\N	PRESENT	0
666739	665151	19631V	PARTICIPANT	\N	PRESENT	0
666740	665151	04059M	PARTICIPANT	\N	PRESENT	0
666741	665151	17779H	PARTICIPANT	\N	PRESENT	0
666742	665151	14021P	PARTICIPANT	\N	PRESENT	0
666743	665151	14229S	PARTICIPANT	\N	PRESENT	0
666744	665151	19647E	PARTICIPANT	\N	PRESENT	0
666745	665151	19573D	PARTICIPANT	\N	PRESENT	0
666746	665151	19683J	PARTICIPANT	\N	PRESENT	0
666747	665151	08045X	PARTICIPANT	\N	PRESENT	0
666748	665151	19549D	PARTICIPANT	\N	PRESENT	0
666749	665151	20094J	PARTICIPANT	\N	PRESENT	0
666750	665151	11048N	PARTICIPANT	\N	PRESENT	0
666751	665151	14033T	PARTICIPANT	\N	PRESENT	0
667186	667185	19447X	PARTICIPANT	\N	PRESENT	0
667187	667185	14089Y	PARTICIPANT	\N	PRESENT	0
667188	667185	11026G	PARTICIPANT	\N	PRESENT	0
667248	667246	19349W	PARTICIPANT	\N	PRESENT	0
667302	667301	19629C	PARTICIPANT	\N	PRESENT	0
667303	667301	19525U	PARTICIPANT	\N	PRESENT	0
667305	667304	11054L	PARTICIPANT	\N	PRESENT	0
667306	667304	17737W	PARTICIPANT	\N	PRESENT	0
667450	665175	20040T	PARTICIPANT	\N	PRESENT	0
667451	665175	11067R	PARTICIPANT	\N	PRESENT	0
667452	665175	18193Q	PARTICIPANT	\N	PRESENT	0
654686	654685	05008E	PARTICIPANT	\N	PRESENT	0
654687	654685	11053K	PARTICIPANT	\N	PRESENT	0
654688	654685	01028R	PARTICIPANT	\N	PRESENT	0
654696	654695	20264J	PARTICIPANT	\N	PRESENT	0
654697	654695	19637C	PARTICIPANT	\N	PRESENT	0
654698	654695	19525U	PARTICIPANT	\N	PRESENT	0
654699	654695	14357A	PARTICIPANT	\N	PRESENT	0
654700	654695	19631V	PARTICIPANT	\N	PRESENT	1
654923	654299	14031R	PARTICIPANT	\N	PRESENT	0
654924	654299	19826F	PARTICIPANT	\N	PRESENT	0
654925	654299	19701S	PARTICIPANT	\N	PRESENT	0
654926	654299	20076G	PARTICIPANT	\N	PRESENT	0
654927	654299	19251M	PARTICIPANT	\N	PRESENT	0
654928	654299	19820Y	PARTICIPANT	\N	PRESENT	0
654929	654299	20024T	PARTICIPANT	\N	PRESENT	0
654930	654299	19503N	PARTICIPANT	\N	PRESENT	0
654931	654299	19619A	PARTICIPANT	\N	PRESENT	0
654932	654299	18083K	PARTICIPANT	\N	PRESENT	0
654933	654299	20032T	PARTICIPANT	\N	PRESENT	0
654934	654299	19549D	PARTICIPANT	\N	PRESENT	0
654935	654299	19525U	PARTICIPANT	\N	PRESENT	0
654936	654299	19387D	PARTICIPANT	\N	PRESENT	0
654937	654299	20038A	PARTICIPANT	\N	PRESENT	0
654938	654299	19599P	PARTICIPANT	\N	PRESENT	0
654939	654299	20106U	PARTICIPANT	\N	PRESENT	0
654940	654299	19739H	PARTICIPANT	\N	PRESENT	0
654941	654299	20102Q	PARTICIPANT	\N	PRESENT	0
654942	654299	20140W	PARTICIPANT	\N	PRESENT	0
654943	654299	19745F	PARTICIPANT	\N	PRESENT	0
654944	654299	20136B	PARTICIPANT	\N	PRESENT	0
654945	654299	11065P	PARTICIPANT	\N	PRESENT	0
654946	654299	19659J	PARTICIPANT	\N	PRESENT	1
654947	654299	20046A	PARTICIPANT	\N	PRESENT	1
654948	654299	20120S	PARTICIPANT	\N	PRESENT	1
654949	654299	19577H	PARTICIPANT	\N	PRESENT	1
656264	656042	01048V	PARTICIPANT	\N	PRESENT	0
656404	656403	04059M	PARTICIPANT	\N	PRESENT	0
656405	656403	20152B	PARTICIPANT	\N	PRESENT	0
656406	656403	20132W	PARTICIPANT	\N	PRESENT	1
656407	656403	14123H	PARTICIPANT	\N	PRESENT	0
656408	656403	20056C	PARTICIPANT	\N	PRESENT	1
656409	656403	14073Q	PARTICIPANT	\N	PRESENT	0
656410	656403	19611R	PARTICIPANT	\N	PRESENT	0
656411	656403	20052X	PARTICIPANT	\N	PRESENT	0
656412	656403	08012N	PARTICIPANT	\N	PRESENT	0
656413	656403	20142Y	PARTICIPANT	\N	PRESENT	1
656414	656403	14021P	PARTICIPANT	\N	PRESENT	0
656415	656403	19745F	PARTICIPANT	\N	PRESENT	0
656418	656403	20128B	PARTICIPANT	\N	PRESENT	0
660428	660427	20116W	PARTICIPANT	\N	PRESENT	0
660443	660442	11048N	PARTICIPANT	\N	PRESENT	0
660444	660442	19711U	PARTICIPANT	\N	PRESENT	0
660446	660445	11053K	PARTICIPANT	\N	PRESENT	0
660461	660457	19741B	PARTICIPANT	\N	PRESENT	0
660464	660463	14331P	PARTICIPANT	\N	PRESENT	1
663560	661259	08045X	PARTICIPANT	\N	PRESENT	0
665128	665043	14031R	PARTICIPANT	\N	PRESENT	0
665178	665177	18083K	PARTICIPANT	\N	PRESENT	0
665181	665179	20066E	PARTICIPANT	\N	PRESENT	0
665183	665182	20066E	PARTICIPANT	\N	PRESENT	0
665185	665184	20066E	PARTICIPANT	\N	PRESENT	0
665187	665186	20066E	PARTICIPANT	\N	PRESENT	0
665189	665188	20066E	PARTICIPANT	\N	PRESENT	0
665191	665190	18083K	PARTICIPANT	\N	PRESENT	0
665193	665192	18083K	PARTICIPANT	\N	PRESENT	0
665201	665200	20128B	PARTICIPANT	\N	PRESENT	0
665203	665202	20128B	PARTICIPANT	\N	PRESENT	0
672327	669560	14225N	PARTICIPANT	\N	PRESENT	0
672328	669898	19683J	PARTICIPANT	\N	PRESENT	0
672329	669898	19715Y	PARTICIPANT	\N	PRESENT	0
672330	669898	19531S	PARTICIPANT	\N	PRESENT	0
672331	669898	17965H	PARTICIPANT	\N	PRESENT	0
672332	669898	11031D	PARTICIPANT	\N	PRESENT	0
672333	669898	19599P	PARTICIPANT	\N	PRESENT	0
672334	669898	20130U	PARTICIPANT	\N	PRESENT	0
672335	669898	14195A	PARTICIPANT	\N	PRESENT	0
672336	669898	10006L	PARTICIPANT	\N	PRESENT	0
672337	669898	14213J	PARTICIPANT	\N	PRESENT	0
672338	669898	19713W	PARTICIPANT	\N	PRESENT	0
672339	669898	14073Q	PARTICIPANT	\N	PRESENT	0
672340	669560	19647E	PARTICIPANT	\N	PRESENT	0
672341	669898	19569H	PARTICIPANT	\N	PRESENT	0
672342	669898	19415P	PARTICIPANT	\N	PRESENT	0
672343	669898	11097X	PARTICIPANT	\N	PRESENT	0
672344	669898	14215L	PARTICIPANT	\N	PRESENT	0
672345	669898	14223L	PARTICIPANT	\N	PRESENT	0
672346	669898	14217N	PARTICIPANT	\N	PRESENT	0
672347	669898	14187A	PARTICIPANT	\N	PRESENT	0
672348	669898	04092N	PARTICIPANT	\N	PRESENT	0
672349	669898	14133K	PARTICIPANT	\N	PRESENT	0
672350	669898	04043D	PARTICIPANT	\N	PRESENT	0
672352	669898	20090E	PARTICIPANT	\N	PRESENT	0
672353	669898	14069U	PARTICIPANT	\N	PRESENT	0
672354	669898	19657G	PARTICIPANT	\N	PRESENT	0
672355	669898	20034V	PARTICIPANT	\N	PRESENT	0
672357	669898	19467C	PARTICIPANT	\N	PRESENT	0
672358	669898	19747H	PARTICIPANT	\N	PRESENT	0
672359	669898	20132W	PARTICIPANT	\N	PRESENT	0
672730	672729	11074Q	PARTICIPANT	\N	PRESENT	0
672731	672729	19349W	PARTICIPANT	\N	PRESENT	0
672733	672732	14225N	PARTICIPANT	\N	PRESENT	0
672734	672732	01057W	PARTICIPANT	\N	PRESENT	0
672736	672735	08010L	PARTICIPANT	\N	PRESENT	0
672738	672737	08010L	PARTICIPANT	\N	PRESENT	0
672740	672739	08010L	PARTICIPANT	\N	PRESENT	0
672742	672741	11048N	PARTICIPANT	\N	PRESENT	0
672744	672743	11048N	PARTICIPANT	\N	PRESENT	0
672746	672745	20086J	PARTICIPANT	\N	PRESENT	0
672748	672747	20086J	PARTICIPANT	\N	PRESENT	0
672750	672749	20086J	PARTICIPANT	\N	PRESENT	0
672752	672751	11048N	PARTICIPANT	\N	PRESENT	0
672754	672753	11053K	PARTICIPANT	\N	PRESENT	0
672756	672755	08009T	PARTICIPANT	\N	PRESENT	0
672757	672755	20044X	PARTICIPANT	\N	PRESENT	0
672759	672758	08009T	PARTICIPANT	\N	PRESENT	0
672760	672758	20044X	PARTICIPANT	\N	PRESENT	0
672762	672761	08009T	PARTICIPANT	\N	PRESENT	0
672763	672761	20044X	PARTICIPANT	\N	PRESENT	0
672765	672764	20044X	PARTICIPANT	\N	PRESENT	0
682541	676618	14069U	PARTICIPANT	\N	PRESENT	0
682542	676618	14089Y	PARTICIPANT	\N	PRESENT	0
682543	676618	19631V	PARTICIPANT	\N	PRESENT	0
682544	676618	20116W	PARTICIPANT	\N	PRESENT	0
682545	676618	18083K	PARTICIPANT	\N	PRESENT	0
682546	676618	20062A	PARTICIPANT	\N	PRESENT	0
682547	676618	19723Y	PARTICIPANT	\N	PRESENT	0
682548	676618	20286Q	PARTICIPANT	\N	PRESENT	0
682549	676618	19347U	PARTICIPANT	\N	PRESENT	0
682550	676618	19713W	PARTICIPANT	\N	PRESENT	0
682551	676618	20142Y	PARTICIPANT	\N	PRESENT	0
682552	676618	20102Q	PARTICIPANT	\N	PRESENT	0
682553	676618	14215L	PARTICIPANT	\N	PRESENT	0
682554	676618	17023S	PARTICIPANT	\N	PRESENT	0
682555	676618	14331P	PARTICIPANT	\N	PRESENT	0
682556	676618	19387D	PARTICIPANT	\N	PRESENT	0
682557	676618	01028R	PARTICIPANT	\N	PRESENT	0
682558	676618	20028X	PARTICIPANT	\N	PRESENT	0
682559	676618	11056N	PARTICIPANT	\N	PRESENT	0
682560	676618	11077T	PARTICIPANT	\N	PRESENT	0
682561	676618	14219Q	PARTICIPANT	\N	PRESENT	0
682562	676618	11048N	PARTICIPANT	\N	PRESENT	0
682563	676618	14083S	PARTICIPANT	\N	PRESENT	0
682564	676618	20094J	PARTICIPANT	\N	PRESENT	0
682565	676618	20126Y	PARTICIPANT	\N	PRESENT	0
682566	676618	14026U	PARTICIPANT	\N	PRESENT	0
682567	676618	19647E	PARTICIPANT	\N	PRESENT	0
682568	676618	14147R	PARTICIPANT	\N	PRESENT	0
682574	679539	20086J	PARTICIPANT	\N	PRESENT	0
682575	679539	14327T	PARTICIPANT	\N	PRESENT	0
682576	679539	11048N	PARTICIPANT	\N	PRESENT	0
682539	676618	19719D	PARTICIPANT	\N	PRESENT	0
682540	676618	20180F	PARTICIPANT	\N	PRESENT	0
682577	679539	08073C	PARTICIPANT	\N	PRESENT	0
682578	679539	01057W	PARTICIPANT	\N	PRESENT	0
682579	679539	20070A	PARTICIPANT	\N	PRESENT	0
682580	679539	20080C	PARTICIPANT	\N	PRESENT	0
682581	679539	20116W	PARTICIPANT	\N	PRESENT	0
682582	679539	99004R	PARTICIPANT	\N	PRESENT	0
682583	679539	19671E	PARTICIPANT	\N	PRESENT	0
682584	679539	14225N	PRESIDENT	0	PRESENT	0
682585	679539	20126Y	PARTICIPANT	\N	PRESENT	0
663731	661836	14213J	PARTICIPANT	\N	PRESENT	0
664564	664560	19533U	PARTICIPANT	\N	PRESENT	0
664566	664560	20132W	PARTICIPANT	\N	PRESENT	0
664567	664560	14229S	PARTICIPANT	\N	PRESENT	0
664755	664754	14213J	PARTICIPANT	\N	PRESENT	0
664756	664754	20130U	PARTICIPANT	\N	PRESENT	0
664933	662442	19569H	PARTICIPANT	\N	PRESENT	0
665246	665245	04042C	PARTICIPANT	\N	PRESENT	0
665247	665245	14267Y	PARTICIPANT	\N	PRESENT	0
665248	665245	07033P	PARTICIPANT	\N	PRESENT	0
665249	665245	20072C	PARTICIPANT	\N	PRESENT	0
665250	665245	08047A	PARTICIPANT	\N	PRESENT	0
665251	665245	01058X	PARTICIPANT	\N	PRESENT	0
665252	665245	14193X	PARTICIPANT	\N	PRESENT	0
665256	665255	19545Y	PARTICIPANT	\N	PRESENT	0
665257	665255	20914V	PARTICIPANT	\N	PRESENT	0
665260	665259	14253S	PARTICIPANT	\N	PRESENT	0
665261	665259	08011M	PARTICIPANT	\N	PRESENT	0
665264	665263	14253S	PARTICIPANT	\N	PRESENT	0
665265	665263	08011M	PARTICIPANT	\N	PRESENT	0
665270	665269	19741B	PARTICIPANT	\N	PRESENT	0
665273	665271	11053K	PARTICIPANT	\N	PRESENT	0
665274	665272	11053K	PARTICIPANT	\N	PRESENT	0
665276	665275	14331P	PARTICIPANT	\N	PRESENT	0
665281	665280	01048V	PARTICIPANT	\N	PRESENT	0
665283	665282	14331P	PARTICIPANT	\N	PRESENT	0
665285	665284	08073C	PARTICIPANT	\N	PRESENT	0
665286	665284	20150Y	PARTICIPANT	\N	PRESENT	0
665291	665290	08073C	PARTICIPANT	\N	PRESENT	0
665293	665290	20150Y	PARTICIPANT	\N	PRESENT	0
665295	665294	19711U	PARTICIPANT	\N	PRESENT	1
665297	665296	11048N	PARTICIPANT	\N	PRESENT	1
665298	665296	14121F	PARTICIPANT	\N	PRESENT	0
665300	665299	14189C	PARTICIPANT	\N	PRESENT	0
665302	665301	14189C	PARTICIPANT	\N	PRESENT	0
665305	665304	11048N	PARTICIPANT	\N	PRESENT	1
665306	665304	19671E	PARTICIPANT	\N	PRESENT	0
665307	665304	19545Y	PARTICIPANT	\N	PRESENT	0
665308	665304	11053K	PARTICIPANT	\N	PRESENT	0
665309	665304	14083S	PARTICIPANT	\N	PRESENT	0
665310	665304	20126Y	PARTICIPANT	\N	PRESENT	0
665311	665304	14331P	PARTICIPANT	\N	PRESENT	0
665312	665304	20044X	PARTICIPANT	\N	PRESENT	0
665314	665313	19335Q	PARTICIPANT	\N	PRESENT	0
665316	665315	19762G	PARTICIPANT	\N	PRESENT	0
665317	665315	19531S	PARTICIPANT	\N	PRESENT	0
665318	665315	01025N	PARTICIPANT	\N	PRESENT	0
665319	665315	19413M	PARTICIPANT	\N	PRESENT	0
665321	665320	19762G	PARTICIPANT	\N	PRESENT	0
665322	665320	19531S	PARTICIPANT	\N	PRESENT	0
665323	665320	19507S	PARTICIPANT	\N	PRESENT	0
665324	665320	19413M	PARTICIPANT	\N	PRESENT	0
665332	665331	20044X	PARTICIPANT	\N	PRESENT	0
665334	665333	08034U	PARTICIPANT	\N	PRESENT	0
665336	665335	19667J	PARTICIPANT	\N	PRESENT	0
665337	665335	11040E	PARTICIPANT	\N	PRESENT	0
665339	665338	08034U	PARTICIPANT	\N	PRESENT	0
665341	665340	08034U	PARTICIPANT	\N	PRESENT	0
665343	665342	99004R	PARTICIPANT	\N	PRESENT	0
665345	665331	20136B	PARTICIPANT	\N	PRESENT	0
665368	665367	19741B	PARTICIPANT	\N	PRESENT	0
665370	665369	19741B	PARTICIPANT	\N	PRESENT	0
665459	665458	14231L	PARTICIPANT	\N	PRESENT	0
665460	665458	19349W	PARTICIPANT	\N	PRESENT	0
665461	665458	19489J	PARTICIPANT	\N	PRESENT	0
665462	665458	01043Q	PARTICIPANT	\N	PRESENT	0
665464	665458	20086J	PARTICIPANT	\N	PRESENT	0
665465	665458	20082E	PARTICIPANT	\N	PRESENT	0
665466	665458	11056N	PARTICIPANT	\N	PRESENT	0
665469	665468	19695N	PARTICIPANT	\N	PRESENT	0
665470	665468	19383Y	PARTICIPANT	\N	PRESENT	0
665471	665468	01043Q	PARTICIPANT	\N	PRESENT	0
665472	665468	20086J	PARTICIPANT	\N	PRESENT	0
665473	665468	11056N	PARTICIPANT	\N	PRESENT	0
665474	665468	14205J	PARTICIPANT	\N	PRESENT	0
665475	665468	19489J	PARTICIPANT	\N	PRESENT	0
665476	665468	20082E	PARTICIPANT	\N	PRESENT	0
665478	665477	19695N	PARTICIPANT	\N	PRESENT	0
665479	665477	20082E	PARTICIPANT	\N	PRESENT	0
665480	665477	20086J	PARTICIPANT	\N	PRESENT	0
665481	665477	19383Y	PARTICIPANT	\N	PRESENT	0
665482	665477	01043Q	PARTICIPANT	\N	PRESENT	0
665483	665477	19489J	PARTICIPANT	\N	PRESENT	0
665484	665477	11056N	PARTICIPANT	\N	PRESENT	0
665485	665477	19549D	PARTICIPANT	\N	PRESENT	0
665488	665487	19489J	PARTICIPANT	\N	PRESENT	0
665489	665487	14205J	PARTICIPANT	\N	PRESENT	0
665490	665487	11056N	PARTICIPANT	\N	PRESENT	0
665491	665487	19383Y	PARTICIPANT	\N	PRESENT	0
665492	665487	19695N	PARTICIPANT	\N	PRESENT	0
665493	665487	01043Q	PARTICIPANT	\N	PRESENT	0
665494	665487	20086J	PARTICIPANT	\N	PRESENT	0
665495	665487	20082E	PARTICIPANT	\N	PRESENT	0
665496	665487	19549D	PARTICIPANT	\N	PRESENT	0
665502	665498	19489J	PARTICIPANT	\N	PRESENT	0
665504	665498	19383Y	PARTICIPANT	\N	PRESENT	0
665505	665498	01043Q	PARTICIPANT	\N	PRESENT	0
665506	665498	20086J	PARTICIPANT	\N	PRESENT	0
665508	665507	01043Q	PARTICIPANT	\N	PRESENT	0
665509	665507	20086J	PARTICIPANT	\N	PRESENT	0
665510	665507	20082E	PARTICIPANT	\N	PRESENT	0
665511	665507	11056N	PARTICIPANT	\N	PRESENT	0
665512	665507	19489J	PARTICIPANT	\N	PRESENT	0
665518	665517	20082E	PARTICIPANT	\N	PRESENT	0
665519	665517	01043Q	PARTICIPANT	\N	PRESENT	0
665520	665517	20086J	PARTICIPANT	\N	PRESENT	0
665521	665517	11056N	PARTICIPANT	\N	PRESENT	0
665526	665525	14042U	PARTICIPANT	\N	PRESENT	0
665555	663861	14217N	PRESIDENT	0	PRESENT	0
665556	663861	11031D	PARTICIPANT	\N	PRESENT	0
665557	663861	04092N	PARTICIPANT	\N	PRESENT	0
665558	663861	19679N	PARTICIPANT	\N	PRESENT	0
665559	663861	19798U	PARTICIPANT	\N	PRESENT	0
665560	663861	19569H	PARTICIPANT	\N	PRESENT	0
665561	663861	17779H	PARTICIPANT	\N	PRESENT	0
665562	663861	20130U	PARTICIPANT	\N	PRESENT	0
665563	663861	14026U	PARTICIPANT	\N	PRESENT	0
665564	663861	19715Y	PARTICIPANT	\N	EXCUSE	0
665565	663861	10006L	PARTICIPANT	\N	EXCUSE	0
665566	663861	04043D	PARTICIPANT	\N	PRESENT	0
665567	663861	14071N	PARTICIPANT	\N	PRESENT	0
665568	663861	19697Q	PARTICIPANT	\N	PRESENT	0
665569	663861	11067R	PARTICIPANT	\N	PRESENT	0
665570	663861	19663E	PARTICIPANT	\N	PRESENT	0
665571	663861	19723Y	PARTICIPANT	\N	PRESENT	0
665572	663861	14213J	PARTICIPANT	\N	PRESENT	0
665573	663861	20090E	PARTICIPANT	\N	PRESENT	0
665574	663861	20066E	PARTICIPANT	\N	PRESENT	0
665575	663861	08045X	PARTICIPANT	\N	PRESENT	0
665577	663861	19703U	PARTICIPANT	\N	PRESENT	0
665578	663861	19415P	PARTICIPANT	\N	PRESENT	0
665659	665657	20034V	PARTICIPANT	\N	PRESENT	0
665662	665660	20034V	PARTICIPANT	\N	PRESENT	0
665664	665663	20034V	PARTICIPANT	\N	PRESENT	0
665667	665666	20034V	PARTICIPANT	\N	PRESENT	0
665885	665884	14173T	PARTICIPANT	\N	PRESENT	0
665989	665988	11066Q	PARTICIPANT	\N	PRESENT	0
666526	666525	19515S	PARTICIPANT	\N	PRESENT	0
666574	666570	19729F	PARTICIPANT	\N	PRESENT	0
666579	666578	19729F	PARTICIPANT	\N	PRESENT	0
666752	665151	19399H	PARTICIPANT	\N	PRESENT	0
666753	665151	20286Q	PARTICIPANT	\N	PRESENT	0
666754	665151	19251M	PARTICIPANT	\N	PRESENT	0
666755	665151	20114U	PARTICIPANT	\N	PRESENT	0
666756	665151	20080C	PARTICIPANT	\N	PRESENT	0
666757	665151	11027H	PARTICIPANT	\N	PRESENT	0
667704	665151	19681G	PARTICIPANT	\N	PRESENT	0
667715	665151	07029T	PARTICIPANT	\N	PRESENT	0
667706	665151	19599P	PARTICIPANT	\N	PRESENT	0
667707	665151	20138D	PARTICIPANT	\N	PRESENT	0
667708	665151	14097Y	PARTICIPANT	\N	PRESENT	0
667709	665151	20104S	PARTICIPANT	\N	PRESENT	0
667710	665151	20018V	PARTICIPANT	\N	PRESENT	0
667711	665151	17023S	PARTICIPANT	\N	PRESENT	0
667712	665151	20078J	PARTICIPANT	\N	PRESENT	0
667713	665151	01043Q	PARTICIPANT	\N	PRESENT	0
667714	665151	04042C	PARTICIPANT	\N	PRESENT	0
667716	665151	20136B	PARTICIPANT	\N	PRESENT	0
668830	667720	19563B	PARTICIPANT	\N	PRESENT	0
668845	668844	19447X	PARTICIPANT	\N	PRESENT	0
668846	668844	14089Y	PARTICIPANT	\N	PRESENT	0
655750	655749	11056N	PARTICIPANT	\N	PRESENT	0
655751	655749	19954N	PARTICIPANT	\N	PRESENT	0
655753	655752	11056N	PARTICIPANT	\N	PRESENT	0
655754	655752	19954N	PARTICIPANT	\N	PRESENT	0
655755	655752	95063L	PARTICIPANT	\N	PRESENT	0
655757	655756	11056N	PARTICIPANT	\N	PRESENT	0
655758	655756	19954N	PARTICIPANT	\N	PRESENT	0
655759	655756	95063L	PARTICIPANT	\N	PRESENT	0
655761	655760	05008E	PARTICIPANT	\N	PRESENT	0
655762	655760	11053K	PARTICIPANT	\N	PRESENT	0
655763	655760	01028R	PARTICIPANT	\N	PRESENT	0
655766	655764	20130U	PARTICIPANT	\N	PRESENT	0
656850	656845	14213J	PARTICIPANT	\N	PRESENT	0
655768	655765	20130U	PARTICIPANT	\N	PRESENT	0
655769	655765	11031D	PARTICIPANT	\N	PRESENT	0
656851	656845	17965H	PARTICIPANT	\N	PRESENT	0
656853	656852	14042U	PARTICIPANT	\N	PRESENT	0
656854	656852	19553Y	PARTICIPANT	\N	PRESENT	0
656855	656852	14213J	PARTICIPANT	\N	PRESENT	0
656856	656852	17965H	PARTICIPANT	\N	PRESENT	0
656857	656852	11097X	PARTICIPANT	\N	PRESENT	0
656858	656846	14042U	PARTICIPANT	\N	PRESENT	0
656859	656846	14213J	PARTICIPANT	\N	PRESENT	0
656860	656846	19553Y	PARTICIPANT	\N	PRESENT	0
656861	656846	17965H	PARTICIPANT	\N	PRESENT	0
656862	656846	11097X	PARTICIPANT	\N	PRESENT	0
656863	656846	18193Q	PARTICIPANT	\N	PRESENT	0
656864	656847	14217N	PARTICIPANT	\N	PRESENT	0
656865	656847	14213J	PARTICIPANT	\N	PRESENT	0
656866	656847	17965H	PARTICIPANT	\N	PRESENT	0
656867	656847	11097X	PARTICIPANT	\N	PRESENT	0
656868	656848	14213J	PARTICIPANT	\N	PRESENT	0
656869	656848	04092N	PARTICIPANT	\N	PRESENT	0
656870	656848	11097X	PARTICIPANT	\N	PRESENT	0
656871	656849	20248J	PARTICIPANT	\N	PRESENT	0
656872	656849	14281W	PARTICIPANT	\N	PRESENT	0
656873	656849	19679N	PARTICIPANT	\N	PRESENT	0
656874	656844	20248J	PARTICIPANT	\N	PRESENT	0
656875	656844	14281W	PARTICIPANT	\N	PRESENT	0
656876	656844	20130U	PARTICIPANT	\N	PRESENT	0
657071	657049	11056N	PARTICIPANT	\N	PRESENT	0
658054	655445	19673G	PARTICIPANT	\N	EXCUSE	0
658055	655445	14219Q	PARTICIPANT	\N	EXCUSE	0
658092	658091	14073Q	PARTICIPANT	\N	PRESENT	0
658232	658131	08015R	PARTICIPANT	\N	PRESENT	0
661292	661291	20032T	PARTICIPANT	\N	PRESENT	0
661296	661291	14069U	PARTICIPANT	\N	PRESENT	0
661294	661291	20076G	PARTICIPANT	\N	PRESENT	0
661295	661291	20116W	PARTICIPANT	\N	PRESENT	0
661297	661291	19782L	PARTICIPANT	\N	PRESENT	0
661298	661291	20090E	PARTICIPANT	\N	PRESENT	0
661300	661291	11103C	PARTICIPANT	\N	PRESENT	0
661301	661291	14329V	PARTICIPANT	\N	PRESENT	0
661302	661291	19467C	PARTICIPANT	\N	PRESENT	0
661303	661291	18083K	PARTICIPANT	\N	PRESENT	0
661304	661291	20140W	PARTICIPANT	\N	PRESENT	0
661305	661291	20038A	PARTICIPANT	\N	PRESENT	0
661306	661291	08056B	PARTICIPANT	\N	PRESENT	0
661308	661291	20126Y	PARTICIPANT	\N	PRESENT	0
661309	661291	16685X	PARTICIPANT	\N	PRESENT	0
661310	661291	14221J	PARTICIPANT	\N	PRESENT	0
661311	661291	20018V	PARTICIPANT	\N	PRESENT	0
661312	661291	20118Y	PARTICIPANT	\N	PRESENT	0
661313	661291	19739H	PARTICIPANT	\N	PRESENT	0
661315	661291	19619A	PARTICIPANT	\N	PRESENT	0
661316	661291	20092G	PARTICIPANT	\N	PRESENT	0
661317	661291	20064C	PARTICIPANT	\N	PRESENT	0
668112	668105	04043D	PARTICIPANT	\N	PRESENT	0
672839	670734	99004R	PARTICIPANT	\N	PRESENT	0
672840	670734	19621T	PARTICIPANT	\N	PRESENT	0
672841	670734	19758L	PARTICIPANT	\N	PRESENT	0
672842	670734	20122U	PARTICIPANT	\N	PRESENT	0
672843	670734	20026V	PARTICIPANT	\N	PRESENT	0
672844	670734	20142Y	PARTICIPANT	\N	PRESENT	0
672845	670734	14249W	PARTICIPANT	\N	PRESENT	0
672846	670734	14109K	PARTICIPANT	\N	PRESENT	0
672847	670734	11012A	PARTICIPANT	\N	PRESENT	0
672848	670734	14187A	PARTICIPANT	\N	PRESENT	0
672849	670734	20264J	PARTICIPANT	\N	PRESENT	0
672850	670734	20048C	PARTICIPANT	\N	PRESENT	0
672851	670734	19533U	PARTICIPANT	\N	PRESENT	0
672852	670734	14281W	PARTICIPANT	\N	PRESENT	0
672853	670734	20180F	PARTICIPANT	\N	PRESENT	0
672854	670734	11115U	PARTICIPANT	\N	PRESENT	0
672858	670734	14030Q	PARTICIPANT	\N	PRESENT	0
672859	670734	14038Y	PARTICIPANT	\N	PRESENT	0
672860	670734	20148F	PARTICIPANT	\N	PRESENT	0
672861	670734	19593H	PARTICIPANT	\N	PRESENT	0
672862	670734	20056C	PARTICIPANT	\N	PRESENT	0
672863	670734	19782L	PARTICIPANT	\N	PRESENT	0
672864	670734	19611R	PARTICIPANT	\N	PRESENT	0
672865	670734	20098N	PARTICIPANT	\N	PRESENT	0
672866	670734	14229S	PARTICIPANT	\N	PRESENT	0
672867	670734	08061X	PARTICIPANT	\N	PRESENT	0
672896	670736	20056C	PARTICIPANT	\N	PRESENT	0
672897	670736	20142Y	PARTICIPANT	\N	PRESENT	0
672898	670736	20134Y	PARTICIPANT	\N	PRESENT	0
672899	670736	14229S	PARTICIPANT	\N	PRESENT	0
672900	670736	19553Y	PARTICIPANT	\N	PRESENT	0
672901	670736	20026V	PARTICIPANT	\N	PRESENT	0
672902	670736	19621T	PARTICIPANT	\N	PRESENT	0
672903	670736	19593H	PARTICIPANT	\N	PRESENT	0
672904	670736	19533U	PARTICIPANT	\N	PRESENT	0
672905	670736	14249W	PARTICIPANT	\N	PRESENT	0
672906	670736	20132W	PARTICIPANT	\N	PRESENT	0
672907	670736	20140W	PARTICIPANT	\N	PRESENT	0
672908	670736	20048C	PARTICIPANT	\N	PRESENT	0
672909	670736	08061X	PARTICIPANT	\N	PRESENT	0
672935	670736	95063L	PARTICIPANT	\N	PRESENT	0
672936	670736	17589D	PARTICIPANT	\N	PRESENT	0
672937	670736	14123H	PARTICIPANT	\N	PRESENT	0
672938	670736	20114U	PARTICIPANT	\N	PRESENT	0
672939	670736	11064N	PARTICIPANT	\N	PRESENT	0
674579	674549	19735D	PARTICIPANT	\N	PRESENT	0
674580	674549	08010L	PARTICIPANT	\N	PRESENT	0
674581	674549	20252E	PARTICIPANT	\N	PRESENT	0
674584	674549	11083R	PARTICIPANT	\N	PRESENT	0
674945	672785	19441R	PARTICIPANT	\N	PRESENT	0
674947	672785	08028W	PARTICIPANT	\N	PRESENT	0
674948	672785	20028X	PARTICIPANT	\N	PRESENT	0
672894	670736	12041X	PARTICIPANT	\N	PRESENT	0
672895	670736	19758L	PARTICIPANT	\N	PRESENT	0
683401	683271	20914V	PARTICIPANT	\N	PRESENT	0
683402	683271	14219Q	PARTICIPANT	\N	PRESENT	0
683433	683271	11048N	PARTICIPANT	\N	PRESENT	0
683434	683271	20044X	PARTICIPANT	\N	PRESENT	0
683435	683271	11053K	PARTICIPANT	\N	PRESENT	0
683406	683271	19745F	PARTICIPANT	\N	PRESENT	0
683407	683271	19820Y	PARTICIPANT	\N	PRESENT	0
683436	683271	11012A	PARTICIPANT	\N	PRESENT	0
683409	683271	19637C	PARTICIPANT	\N	PRESENT	0
683410	683271	11101A	PARTICIPANT	\N	PRESENT	0
683411	683271	20046A	PARTICIPANT	\N	PRESENT	0
683412	683271	19717B	PARTICIPANT	\N	PRESENT	0
683413	683271	19619A	PARTICIPANT	\N	PRESENT	0
683414	683271	20102Q	PARTICIPANT	\N	PRESENT	0
683416	683271	20100N	PARTICIPANT	\N	PRESENT	0
683438	683271	20136B	PARTICIPANT	\N	PRESENT	0
683418	683271	14225N	PARTICIPANT	\N	PRESENT	0
683439	683271	20086J	PARTICIPANT	\N	PRESENT	0
683440	683271	08009T	PARTICIPANT	\N	PRESENT	0
683441	683271	19826F	PARTICIPANT	\N	PRESENT	0
683442	683271	14033T	PARTICIPANT	\N	PRESENT	0
683423	683271	14357A	PARTICIPANT	\N	PRESENT	0
683424	683271	20054A	PARTICIPANT	\N	PRESENT	0
683443	683271	19647E	PARTICIPANT	\N	PRESENT	0
683426	683271	14253S	PARTICIPANT	\N	PRESENT	0
683427	683271	07029T	PARTICIPANT	\N	PRESENT	0
683444	683271	19545Y	PARTICIPANT	\N	PRESENT	0
683429	683271	20152B	PARTICIPANT	\N	PRESENT	0
683445	683271	07004J	PARTICIPANT	\N	PRESENT	0
683431	683271	95063L	PARTICIPANT	\N	PRESENT	0
683432	683271	20120S	PARTICIPANT	\N	PRESENT	0
683446	683271	04071H	PARTICIPANT	\N	PRESENT	0
667454	667453	19703U	PARTICIPANT	\N	PRESENT	1
667456	667455	14026U	PARTICIPANT	\N	PRESENT	0
667536	667535	11065P	PARTICIPANT	\N	PRESENT	0
667537	667535	19701S	PARTICIPANT	\N	PRESENT	0
667538	667535	19503N	PARTICIPANT	\N	PRESENT	0
667539	667535	19637C	PARTICIPANT	\N	PRESENT	0
667540	667535	19619A	PARTICIPANT	\N	PRESENT	0
667545	667544	20136B	PARTICIPANT	\N	PRESENT	0
667548	667546	20136B	PARTICIPANT	\N	PRESENT	0
667554	667553	20136B	PARTICIPANT	\N	PRESENT	0
667566	667565	19820Y	PARTICIPANT	\N	PRESENT	0
667588	667587	14213J	PARTICIPANT	\N	PRESENT	0
667589	667587	20130U	PARTICIPANT	\N	PRESENT	0
667591	664874	19760E	PARTICIPANT	\N	EXCUSE	0
667592	664874	08060W	PARTICIPANT	\N	EXCUSE	0
667593	664874	19545Y	PARTICIPANT	\N	EXCUSE	0
667594	664874	14329V	PARTICIPANT	\N	EXCUSE	0
667595	664874	08028W	PARTICIPANT	\N	EXCUSE	0
667596	664874	19467C	PARTICIPANT	\N	EXCUSE	0
667597	664874	20040T	PARTICIPANT	\N	EXCUSE	0
667598	664874	14026U	PARTICIPANT	\N	EXCUSE	0
667599	664874	20048C	PARTICIPANT	\N	EXCUSE	0
667600	664874	08015R	PARTICIPANT	\N	EXCUSE	0
667601	664874	19697Q	PARTICIPANT	\N	EXCUSE	0
667602	664874	14031R	PARTICIPANT	\N	EXCUSE	0
667603	664874	19369B	PARTICIPANT	\N	EXCUSE	0
667604	664874	20054A	PARTICIPANT	\N	EXCUSE	0
667629	667626	11056N	PARTICIPANT	\N	PRESENT	0
667631	667630	11056N	PARTICIPANT	\N	PRESENT	0
667633	667632	11056N	PARTICIPANT	\N	PRESENT	0
667635	667634	11056N	PARTICIPANT	\N	PRESENT	0
667637	667636	11056N	PARTICIPANT	\N	PRESENT	0
667658	667655	19637C	PARTICIPANT	\N	PRESENT	0
667731	667730	20050V	PARTICIPANT	\N	PRESENT	0
667757	667756	19709B	PARTICIPANT	\N	PRESENT	0
667759	667758	11041F	PARTICIPANT	\N	PRESENT	0
667760	667758	19709B	PARTICIPANT	\N	PRESENT	0
667762	667761	19709B	PARTICIPANT	\N	PRESENT	0
667764	667763	19709B	PARTICIPANT	\N	PRESENT	0
667766	667765	14133K	PARTICIPANT	\N	PRESENT	0
667767	667765	11066Q	PARTICIPANT	\N	PRESENT	0
667769	667768	14255U	PARTICIPANT	\N	PRESENT	0
667770	667768	20064C	PARTICIPANT	\N	PRESENT	0
667772	667771	14255U	PARTICIPANT	\N	PRESENT	0
667773	667771	20064C	PARTICIPANT	\N	PRESENT	0
667775	667774	14255U	PARTICIPANT	\N	PRESENT	0
667777	667776	14255U	PARTICIPANT	\N	PRESENT	0
667779	667778	14255U	PARTICIPANT	\N	PRESENT	0
667781	667780	99004R	PARTICIPANT	\N	PRESENT	0
667782	667780	07033P	PARTICIPANT	\N	PRESENT	0
667783	667780	11080N	PARTICIPANT	\N	PRESENT	0
667784	667780	14187A	PARTICIPANT	\N	PRESENT	0
667785	667780	14073Q	PARTICIPANT	\N	PRESENT	0
667786	667780	08010L	PARTICIPANT	\N	PRESENT	0
667787	667780	19503N	PARTICIPANT	\N	PRESENT	0
668815	668783	19533U	PARTICIPANT	\N	PRESENT	0
669086	667315	05008E	PARTICIPANT	\N	EXCUSE	0
669085	667315	20034V	PRESIDENT	0	PRESENT	0
669092	667315	14331P	PARTICIPANT	\N	EXCUSE	0
669114	668827	20128B	PARTICIPANT	\N	PRESENT	0
669120	669119	20128B	PARTICIPANT	\N	PRESENT	0
669131	667315	19673G	PARTICIPANT	\N	EXCUSE	0
669199	667315	11043H	PARTICIPANT	\N	EXCUSE	0
669212	669211	20098N	PARTICIPANT	\N	PRESENT	0
669213	669211	14169X	PARTICIPANT	\N	PRESENT	0
669214	669211	19563B	PARTICIPANT	\N	PRESENT	0
669215	669211	04057K	PARTICIPANT	\N	PRESENT	0
669216	669211	14001X	PARTICIPANT	\N	PRESENT	0
669217	669211	19593H	PARTICIPANT	\N	PRESENT	0
669218	669211	14331P	PRESIDENT	0	PRESENT	0
669219	669211	14073Q	PARTICIPANT	\N	PRESENT	0
669220	669211	20100N	PARTICIPANT	\N	PRESENT	0
669221	669211	19441R	PARTICIPANT	\N	PRESENT	0
669222	669211	20128B	PARTICIPANT	\N	PRESENT	0
669223	669211	14033T	PARTICIPANT	\N	PRESENT	0
669226	669211	04045F	PARTICIPANT	\N	EXCUSE	0
669229	669211	14189C	PARTICIPANT	\N	EXCUSE	0
669230	669211	20094J	PARTICIPANT	\N	EXCUSE	0
669231	669211	11083R	PARTICIPANT	\N	EXCUSE	0
670337	670336	20136B	PARTICIPANT	\N	PRESENT	0
670338	670336	19820Y	PARTICIPANT	\N	PRESENT	0
670354	670353	19820Y	PARTICIPANT	\N	PRESENT	0
670356	670355	20136B	PARTICIPANT	\N	PRESENT	0
670357	670355	19820Y	PARTICIPANT	\N	PRESENT	0
670575	670572	20110Q	PARTICIPANT	\N	PRESENT	0
670924	669566	19729F	PARTICIPANT	\N	EXCUSE	0
670925	669566	14021P	PARTICIPANT	\N	EXCUSE	0
670926	669567	19729F	PARTICIPANT	\N	EXCUSE	0
671834	671833	19575F	PARTICIPANT	\N	PRESENT	0
672584	672580	11066Q	PARTICIPANT	\N	PRESENT	0
672589	672588	19503N	PARTICIPANT	\N	PRESENT	0
672856	672855	04043D	PARTICIPANT	\N	PRESENT	0
673029	673028	14231L	PARTICIPANT	\N	PRESENT	0
673031	673030	20080C	PARTICIPANT	\N	PRESENT	0
673138	672997	20058E	PARTICIPANT	\N	PRESENT	0
673139	672997	11045K	PARTICIPANT	\N	PRESENT	0
673140	672997	19709B	PARTICIPANT	\N	PRESENT	0
673141	672997	01028R	PARTICIPANT	\N	PRESENT	0
673142	672997	08018U	PARTICIPANT	\N	PRESENT	0
673143	672997	11074Q	PARTICIPANT	\N	PRESENT	0
673144	672997	20096L	PARTICIPANT	\N	PRESENT	0
673145	672997	17779H	PARTICIPANT	\N	PRESENT	0
673146	672997	07029T	PARTICIPANT	\N	PRESENT	0
673147	672997	14021P	PARTICIPANT	\N	PRESENT	0
673148	672997	20038A	PARTICIPANT	\N	PRESENT	0
673149	672997	19649G	PARTICIPANT	\N	PRESENT	0
673150	672997	19489J	PARTICIPANT	\N	PRESENT	0
673151	672997	19766L	PARTICIPANT	\N	PRESENT	0
673152	672997	11067R	PARTICIPANT	\N	PRESENT	0
673153	672997	04071H	PARTICIPANT	\N	PRESENT	0
673154	672997	08045X	PARTICIPANT	\N	PRESENT	0
673155	672997	92040Q	PARTICIPANT	\N	PRESENT	0
673156	672997	11054L	PARTICIPANT	\N	PRESENT	0
673157	672997	11041F	PARTICIPANT	\N	PRESENT	0
673158	672997	11066Q	PARTICIPANT	\N	PRESENT	0
673159	672997	14281W	PARTICIPANT	\N	PRESENT	0
673160	672997	19954N	PARTICIPANT	\N	PRESENT	0
673161	672997	19820Y	PARTICIPANT	\N	PRESENT	0
673162	672997	20060X	PARTICIPANT	\N	PRESENT	0
673163	672997	19531S	PARTICIPANT	\N	PRESENT	0
673164	672997	19399H	PARTICIPANT	\N	PRESENT	0
673165	672997	19503N	PARTICIPANT	\N	PRESENT	0
673166	672997	12028B	PARTICIPANT	\N	PRESENT	0
673167	672997	19251M	PARTICIPANT	\N	PRESENT	0
673168	672997	20264J	PARTICIPANT	\N	PRESENT	0
673169	672997	20138D	PARTICIPANT	\N	PRESENT	0
673170	672997	20082E	PARTICIPANT	\N	PRESENT	0
673171	672997	20172F	PARTICIPANT	\N	PRESENT	0
673172	672997	20030R	PARTICIPANT	\N	PRESENT	0
673173	672997	20140W	PARTICIPANT	\N	PRESENT	0
673174	672997	11072N	PARTICIPANT	\N	PRESENT	0
673175	672997	19349W	PARTICIPANT	\N	PRESENT	0
673176	672997	19507S	PARTICIPANT	\N	PRESENT	0
673177	672997	14253S	PARTICIPANT	\N	PRESENT	0
673178	672997	04045F	PARTICIPANT	\N	PRESENT	0
673179	672997	17737W	PARTICIPANT	\N	PRESENT	0
673180	672997	20036X	PARTICIPANT	\N	PRESENT	0
673181	672997	20068G	PARTICIPANT	\N	PRESENT	0
673182	672997	20266L	PARTICIPANT	\N	PRESENT	0
673183	672997	01057W	PARTICIPANT	\N	PRESENT	0
673184	672997	20134Y	PARTICIPANT	\N	PRESENT	0
673185	672997	20142Y	PARTICIPANT	\N	PRESENT	0
673186	672997	19643A	PARTICIPANT	\N	PRESENT	0
673187	672997	14229S	PARTICIPANT	\N	PRESENT	0
673188	672997	20084G	PARTICIPANT	\N	PRESENT	0
673189	672997	14169X	PARTICIPANT	\N	PRESENT	0
673190	672997	11043H	PARTICIPANT	\N	PRESENT	0
673191	672997	08028W	PARTICIPANT	\N	PRESENT	0
673192	672997	20048C	PARTICIPANT	\N	PRESENT	0
673193	672997	19511N	PARTICIPANT	\N	PRESENT	0
673194	672997	19575F	PARTICIPANT	\N	PRESENT	0
673195	672997	19619A	PARTICIPANT	\N	PRESENT	0
673196	672997	19721W	PARTICIPANT	\N	PRESENT	0
673197	672997	07004J	PARTICIPANT	\N	PRESENT	0
673198	672997	19621T	PARTICIPANT	\N	PRESENT	0
673199	672997	19739H	PARTICIPANT	\N	PRESENT	0
673200	672997	20144B	PARTICIPANT	\N	PRESENT	0
656447	656160	19723Y	PARTICIPANT	\N	PRESENT	0
656448	656160	14213J	PARTICIPANT	\N	PRESENT	0
656449	656160	20148F	PARTICIPANT	\N	PRESENT	0
656450	656160	11097X	PARTICIPANT	\N	PRESENT	0
656451	656160	20066E	PARTICIPANT	\N	PRESENT	0
656452	656160	19798U	PARTICIPANT	\N	PRESENT	0
656453	656160	14217N	PARTICIPANT	0	PRESENT	0
656454	656160	11067R	PARTICIPANT	\N	PRESENT	0
656455	656160	17965H	PARTICIPANT	\N	PRESENT	0
656456	656160	18193Q	PARTICIPANT	\N	PRESENT	0
656457	656160	14026U	PARTICIPANT	\N	PRESENT	0
656522	656160	19569H	PARTICIPANT	\N	PRESENT	0
656536	656160	10006L	PRESIDENT	0	PRESENT	0
656537	656160	14195A	PARTICIPANT	\N	PRESENT	0
656538	656160	20130U	PARTICIPANT	\N	PRESENT	0
656539	656160	17779H	PARTICIPANT	\N	PRESENT	0
656540	656160	19691J	PARTICIPANT	\N	PRESENT	0
656541	656160	04043D	PARTICIPANT	\N	PRESENT	0
656542	656160	14042U	PARTICIPANT	\N	PRESENT	0
656543	656160	19679N	PARTICIPANT	\N	PRESENT	0
656544	656160	20090E	PARTICIPANT	\N	PRESENT	0
656545	656160	14071N	PARTICIPANT	\N	PRESENT	0
656548	656160	14281W	PARTICIPANT	\N	PRESENT	0
656549	656160	04092N	PARTICIPANT	\N	PRESENT	0
656554	656160	01034P	PARTICIPANT	\N	PRESENT	0
656555	656160	14355X	PARTICIPANT	\N	PRESENT	0
656565	656160	19591F	PARTICIPANT	\N	PRESENT	0
656567	656160	19715Y	PARTICIPANT	\N	PRESENT	0
656568	656160	08045X	PARTICIPANT	\N	PRESENT	0
656570	656160	19683J	PARTICIPANT	\N	PRESENT	0
656664	656465	08028W	PARTICIPANT	\N	EXCUSE	0
656665	656465	08015R	PARTICIPANT	\N	EXCUSE	0
656666	656465	20082E	PARTICIPANT	\N	EXCUSE	0
659676	659070	19735D	PARTICIPANT	\N	EXCUSE	0
659677	659070	11067R	PARTICIPANT	\N	EXCUSE	0
662024	662023	11056N	PARTICIPANT	\N	PRESENT	0
662025	662023	14231L	PARTICIPANT	\N	PRESENT	0
662026	662023	11065P	PARTICIPANT	\N	PRESENT	0
662027	662023	01043Q	PARTICIPANT	\N	PRESENT	0
662028	662023	20086J	PARTICIPANT	\N	PRESENT	0
662029	662023	19549D	PARTICIPANT	\N	PRESENT	0
662030	662023	19489J	PARTICIPANT	\N	PRESENT	0
662031	662023	11110B	PARTICIPANT	\N	PRESENT	0
662032	662023	20082E	PARTICIPANT	\N	PRESENT	0
662033	662023	14205J	PARTICIPANT	\N	PRESENT	0
662034	662023	17737W	PARTICIPANT	\N	PRESENT	0
662036	662023	19349W	PARTICIPANT	\N	PRESENT	0
662062	662061	20032T	PARTICIPANT	\N	PRESENT	0
662063	662061	11110B	PARTICIPANT	\N	PRESENT	0
662064	662061	20082E	PARTICIPANT	\N	PRESENT	0
662065	662061	14327T	PARTICIPANT	\N	PRESENT	0
662066	662061	11056N	PARTICIPANT	\N	PRESENT	0
662067	662061	19489J	PARTICIPANT	\N	PRESENT	0
662068	662061	20086J	PARTICIPANT	\N	PRESENT	0
662069	662061	01043Q	PARTICIPANT	\N	PRESENT	0
662070	662061	11065P	PARTICIPANT	\N	PRESENT	0
662071	662061	19383Y	PARTICIPANT	\N	PRESENT	0
662073	662072	20032T	PARTICIPANT	\N	PRESENT	0
662081	662072	11110B	PARTICIPANT	\N	PRESENT	0
662085	662072	11056N	PARTICIPANT	\N	PRESENT	0
662083	662072	19383Y	PARTICIPANT	\N	PRESENT	0
662084	662072	20082E	PARTICIPANT	\N	PRESENT	0
662086	662072	19489J	PARTICIPANT	\N	PRESENT	0
662087	662072	01043Q	PARTICIPANT	\N	PRESENT	0
662088	662072	20086J	PARTICIPANT	\N	PRESENT	0
662089	662072	14205J	PARTICIPANT	\N	PRESENT	0
662090	662072	11065P	PARTICIPANT	\N	PRESENT	0
662097	662096	20082E	PARTICIPANT	\N	PRESENT	0
662098	662096	19489J	PARTICIPANT	\N	PRESENT	0
662099	662096	11110B	PARTICIPANT	\N	PRESENT	0
662100	662096	20032T	PARTICIPANT	\N	PRESENT	0
662102	662096	14205J	PARTICIPANT	\N	PRESENT	0
662104	662096	11056N	PARTICIPANT	\N	PRESENT	0
662105	662096	19383Y	PARTICIPANT	\N	PRESENT	0
662106	662096	11065P	PARTICIPANT	\N	PRESENT	0
662107	662096	17367Q	PARTICIPANT	\N	PRESENT	0
662108	662096	01043Q	PARTICIPANT	\N	PRESENT	0
662110	662109	11056N	PARTICIPANT	\N	PRESENT	0
662111	662109	20032T	PARTICIPANT	\N	PRESENT	0
662112	662109	19383Y	PARTICIPANT	\N	PRESENT	0
662113	662109	19489J	PARTICIPANT	\N	PRESENT	0
662115	662109	20086J	PARTICIPANT	\N	PRESENT	0
662117	662109	14205J	PARTICIPANT	\N	PRESENT	0
662118	662109	20082E	PARTICIPANT	\N	PRESENT	0
662122	662120	20086J	PARTICIPANT	\N	PRESENT	0
662124	662120	20082E	PARTICIPANT	\N	PRESENT	0
662125	662120	20032T	PARTICIPANT	\N	PRESENT	0
662127	662120	11056N	PARTICIPANT	\N	PRESENT	0
662128	662120	19489J	PARTICIPANT	\N	PRESENT	0
663678	661261	08045X	PARTICIPANT	\N	EXCUSE	0
665980	665979	20042V	PARTICIPANT	\N	PRESENT	0
665981	665979	11027H	PARTICIPANT	\N	PRESENT	0
665982	665979	17229F	PARTICIPANT	\N	PRESENT	0
665983	665979	04035D	PARTICIPANT	\N	PRESENT	0
665984	665979	07004J	PARTICIPANT	\N	PRESENT	0
665985	665979	19531S	PARTICIPANT	\N	PRESENT	0
665986	665979	10015M	PARTICIPANT	\N	PRESENT	0
665987	665979	20084G	PARTICIPANT	\N	PRESENT	0
666090	659563	20032T	PARTICIPANT	\N	PRESENT	0
666091	659563	20102Q	PARTICIPANT	\N	PRESENT	0
666092	659563	20120S	PARTICIPANT	\N	PRESENT	0
666095	664324	14327T	PARTICIPANT	\N	PRESENT	0
666096	664324	20086J	PARTICIPANT	\N	PRESENT	0
666097	664324	14331P	PARTICIPANT	\N	PRESENT	0
666098	664324	04071H	PARTICIPANT	\N	PRESENT	0
666099	664324	01048V	PARTICIPANT	\N	PRESENT	0
666100	664324	01057W	PARTICIPANT	\N	PRESENT	0
666101	664324	11053K	PARTICIPANT	\N	PRESENT	0
666102	664324	20080C	PARTICIPANT	\N	PRESENT	0
666103	664324	19667J	PARTICIPANT	\N	PRESENT	0
666104	664324	11070L	PARTICIPANT	\N	PRESENT	0
666105	664324	14225N	PRESIDENT	0	PRESENT	0
666106	664324	19671E	PARTICIPANT	\N	PRESENT	0
666107	664324	11110B	PARTICIPANT	\N	PRESENT	0
666108	664324	07029T	PARTICIPANT	\N	PRESENT	0
666109	664324	19349W	PARTICIPANT	\N	PRESENT	0
666110	664324	08010L	PARTICIPANT	\N	PRESENT	0
666111	664324	20116W	PARTICIPANT	\N	PRESENT	0
666112	664324	14253S	PARTICIPANT	\N	PRESENT	0
666113	664324	19335Q	PARTICIPANT	\N	PRESENT	0
666114	664324	19479G	PARTICIPANT	\N	PRESENT	0
666115	664324	11048N	PARTICIPANT	\N	PRESENT	0
666116	664324	19647E	PARTICIPANT	\N	PRESENT	0
666117	664324	19711U	PARTICIPANT	\N	PRESENT	0
666118	664324	14189C	PARTICIPANT	\N	PRESENT	0
666119	664324	19531S	PARTICIPANT	\N	PRESENT	0
666120	664324	19687N	PARTICIPANT	\N	PRESENT	0
666121	664324	20050V	PARTICIPANT	\N	PRESENT	0
666122	664324	20044X	PARTICIPANT	\N	PRESENT	0
666123	664324	14173T	PARTICIPANT	\N	PRESENT	0
666124	664324	11040E	PARTICIPANT	\N	PRESENT	0
666125	664324	14083S	PARTICIPANT	\N	PRESENT	0
666126	664324	11012A	PARTICIPANT	\N	PRESENT	0
666127	664324	08073C	PARTICIPANT	\N	PRESENT	0
666128	664324	20070A	PARTICIPANT	\N	PRESENT	0
666129	664324	14121F	PARTICIPANT	\N	PRESENT	0
666130	664324	19741B	PARTICIPANT	\N	PRESENT	0
666131	664324	99004R	PARTICIPANT	\N	PRESENT	0
666132	664324	20914V	PARTICIPANT	\N	PRESENT	0
666133	664324	19762G	PARTICIPANT	\N	PRESENT	0
666138	659563	20100N	PARTICIPANT	\N	PRESENT	0
666139	659563	20136B	PARTICIPANT	\N	PRESENT	0
666140	659563	14031R	PARTICIPANT	\N	PRESENT	0
666141	659563	20076G	PARTICIPANT	\N	PRESENT	0
666142	659563	20140W	PARTICIPANT	\N	PRESENT	0
666143	659563	14169X	PARTICIPANT	\N	PRESENT	0
666144	659563	17229F	PARTICIPANT	\N	PRESENT	0
666145	659563	19333N	PARTICIPANT	\N	PRESENT	0
666146	659563	20068G	PARTICIPANT	\N	PRESENT	0
666147	659563	20020P	PARTICIPANT	\N	PRESENT	0
666148	659563	19387D	PARTICIPANT	\N	PRESENT	0
666149	659563	14219Q	PRESIDENT	0	PRESENT	0
666150	659563	19599P	PARTICIPANT	\N	PRESENT	0
666151	659563	19739H	PARTICIPANT	\N	PRESENT	0
666152	659563	20046A	PARTICIPANT	\N	PRESENT	0
666153	659563	19637C	PARTICIPANT	\N	PRESENT	0
666155	659563	19701S	PARTICIPANT	\N	PRESENT	0
666156	659563	08060W	PARTICIPANT	\N	PRESENT	0
666157	659563	19681G	PARTICIPANT	\N	PRESENT	0
666158	659563	11065P	PARTICIPANT	\N	PRESENT	0
666159	659563	19525U	PARTICIPANT	\N	PRESENT	0
664930	664928	19399H	PARTICIPANT	\N	PRESENT	0
664931	664928	19643A	PARTICIPANT	\N	PRESENT	0
664932	664929	19399H	PARTICIPANT	\N	PRESENT	0
665018	665015	19719D	PARTICIPANT	\N	PRESENT	0
668103	667607	14038Y	PARTICIPANT	\N	PRESENT	0
668104	667607	20144B	PARTICIPANT	\N	EXCUSE	0
668106	668105	19503N	PARTICIPANT	\N	EXCUSE	0
668107	668105	20066E	PARTICIPANT	\N	EXCUSE	0
668108	668105	19569H	PARTICIPANT	\N	EXCUSE	0
668109	668105	11067R	PARTICIPANT	\N	EXCUSE	0
668111	667607	19399H	PARTICIPANT	\N	PRESENT	0
668847	668844	11033F	PARTICIPANT	\N	PRESENT	0
668849	668848	19447X	PARTICIPANT	\N	PRESENT	0
668850	668848	14089Y	PARTICIPANT	\N	PRESENT	0
669088	669087	14073Q	PARTICIPANT	\N	PRESENT	0
669089	669087	20100N	PARTICIPANT	\N	PRESENT	0
669090	669087	14331P	PARTICIPANT	\N	PRESENT	0
669094	669093	20136B	PARTICIPANT	\N	PRESENT	0
669258	669257	20066E	PARTICIPANT	\N	PRESENT	0
669260	669259	20066E	PARTICIPANT	\N	PRESENT	0
669262	669261	20066E	PARTICIPANT	\N	PRESENT	0
669264	669263	20066E	PARTICIPANT	\N	PRESENT	0
669266	669265	20066E	PARTICIPANT	\N	PRESENT	0
669268	669267	20066E	PARTICIPANT	\N	PRESENT	0
669270	669269	20066E	PARTICIPANT	\N	PRESENT	0
669272	669271	20066E	PARTICIPANT	\N	PRESENT	0
669275	669274	19533U	PARTICIPANT	\N	PRESENT	0
669547	669545	11056N	PARTICIPANT	\N	PRESENT	0
669551	669550	14151M	PARTICIPANT	\N	PRESENT	0
669552	669550	20022R	PARTICIPANT	\N	PRESENT	0
669554	669553	20022R	PARTICIPANT	\N	PRESENT	0
669555	669553	14151M	PARTICIPANT	\N	PRESENT	0
669732	669731	14255U	PARTICIPANT	\N	PRESENT	0
669733	669731	20064C	PARTICIPANT	\N	PRESENT	0
670552	670551	14205J	PARTICIPANT	\N	PRESENT	0
670559	670557	14205J	PARTICIPANT	\N	PRESENT	0
670571	670570	14205J	PARTICIPANT	\N	PRESENT	0
670576	670573	14205J	PARTICIPANT	\N	PRESENT	0
670586	670584	14205J	PARTICIPANT	\N	PRESENT	0
670639	670638	11090Q	PARTICIPANT	\N	PRESENT	0
670640	670638	19563B	PARTICIPANT	\N	PRESENT	0
670641	670638	19782L	PARTICIPANT	\N	PRESENT	0
670642	670638	20144B	PARTICIPANT	\N	PRESENT	0
670643	670638	19467C	PARTICIPANT	\N	PRESENT	0
670644	670638	14357A	PARTICIPANT	\N	PRESENT	0
670645	670638	14033T	PARTICIPANT	\N	PRESENT	0
670646	670638	19441R	PARTICIPANT	\N	PRESENT	0
670647	670638	19369B	PARTICIPANT	\N	PRESENT	0
670648	670638	20054A	PARTICIPANT	\N	PRESENT	0
670649	670638	20092G	PARTICIPANT	\N	PRESENT	0
672387	669572	14089Y	PARTICIPANT	\N	EXCUSE	0
672388	669572	14021P	PARTICIPANT	\N	EXCUSE	0
672390	669572	19729F	PARTICIPANT	\N	EXCUSE	0
672431	672430	11053K	PARTICIPANT	\N	PRESENT	0
672432	672430	05008E	PARTICIPANT	\N	PRESENT	0
672433	672430	01028R	PARTICIPANT	\N	PRESENT	0
672537	672535	11066Q	PARTICIPANT	\N	PRESENT	0
672540	672539	11041F	PARTICIPANT	\N	PRESENT	0
672551	671222	14053L	PARTICIPANT	\N	PRESENT	0
672552	671222	19749K	PARTICIPANT	\N	PRESENT	0
672810	672809	14257W	PARTICIPANT	\N	PRESENT	0
672819	672817	14329V	PARTICIPANT	\N	PRESENT	0
672821	672820	14329V	PARTICIPANT	\N	PRESENT	0
672823	672822	14329V	PARTICIPANT	\N	PRESENT	0
672837	672835	20110Q	PARTICIPANT	\N	PRESENT	0
672911	672910	86034E	PARTICIPANT	\N	PRESENT	0
672912	672910	04085P	PARTICIPANT	\N	PRESENT	0
672913	672910	04042C	PARTICIPANT	\N	PRESENT	0
672914	672910	11053K	PARTICIPANT	\N	PRESENT	0
672915	672910	10006L	PARTICIPANT	\N	PRESENT	0
672916	672910	14215L	PARTICIPANT	\N	PRESENT	0
672917	672910	14042U	PARTICIPANT	\N	PRESENT	0
672918	672910	19347U	PARTICIPANT	\N	PRESENT	0
672919	672910	14021P	PARTICIPANT	\N	PRESENT	0
672920	672910	99004R	PARTICIPANT	\N	PRESENT	0
672921	672910	12041X	PARTICIPANT	\N	PRESENT	0
672922	672910	01043Q	PARTICIPANT	\N	PRESENT	0
672923	672910	14251Q	PARTICIPANT	\N	PRESENT	0
672924	672910	11085T	PARTICIPANT	\N	PRESENT	0
672925	672910	01060R	PARTICIPANT	\N	PRESENT	0
672926	672910	08061X	PARTICIPANT	\N	PRESENT	0
672927	672910	19533U	PARTICIPANT	\N	PRESENT	0
672928	672910	11090Q	PARTICIPANT	\N	PRESENT	0
672929	672910	14331P	PARTICIPANT	\N	PRESENT	0
672930	672910	14225N	PARTICIPANT	\N	PRESENT	0
672931	672910	11012A	PARTICIPANT	\N	PRESENT	0
672932	672910	04033B	PARTICIPANT	\N	PRESENT	0
672933	672910	95063L	PARTICIPANT	\N	PRESENT	0
672934	672910	11045K	PARTICIPANT	\N	PRESENT	0
672990	672989	14229S	PARTICIPANT	\N	PRESENT	1
672991	672989	19735D	PARTICIPANT	\N	PRESENT	1
672992	672989	04070G	PARTICIPANT	\N	PRESENT	1
673027	672570	14083S	PARTICIPANT	\N	PRESENT	0
673047	672280	20022R	PARTICIPANT	\N	PRESENT	0
673049	672280	14069U	PARTICIPANT	\N	PRESENT	0
673050	672280	04047H	PRESIDENT	0	PRESENT	0
673051	672280	14053L	PARTICIPANT	\N	PRESENT	0
673052	672280	19629C	PARTICIPANT	\N	PRESENT	0
673053	672280	14215L	PARTICIPANT	\N	PRESENT	0
673054	672280	20074E	PARTICIPANT	\N	PRESENT	0
673056	672280	14231L	PARTICIPANT	\N	PRESENT	0
673058	672280	14179A	PARTICIPANT	\N	PRESENT	0
673059	672280	19447X	PARTICIPANT	\N	PRESENT	0
673060	672280	14021P	PARTICIPANT	\N	EXCUSE	0
673061	672280	19489J	PARTICIPANT	\N	PRESENT	0
673062	672280	19729F	PARTICIPANT	\N	PRESENT	0
673063	672280	14147R	PARTICIPANT	\N	PRESENT	0
673064	672280	11072N	PARTICIPANT	\N	PRESENT	0
673065	672280	10015M	PARTICIPANT	\N	PRESENT	0
673066	672280	14107H	PARTICIPANT	\N	PRESENT	0
673704	672383	14147R	PARTICIPANT	\N	EXCUSE	0
673705	667316	14147R	PARTICIPANT	\N	EXCUSE	0
673824	673823	14030Q	PARTICIPANT	\N	PRESENT	0
673825	673823	19643A	PARTICIPANT	\N	PRESENT	0
673826	673823	17229F	PARTICIPANT	\N	PRESENT	0
673827	673823	20248J	PARTICIPANT	\N	PRESENT	0
673828	673823	20120S	PARTICIPANT	\N	PRESENT	0
673829	673823	11026G	PARTICIPANT	\N	PRESENT	0
673830	673823	14223L	PARTICIPANT	\N	PRESENT	0
673831	673823	19503N	PARTICIPANT	\N	PRESENT	0
673832	673823	19798U	PARTICIPANT	\N	PRESENT	0
673833	673823	19713W	PARTICIPANT	\N	PRESENT	0
673834	673823	11066Q	PARTICIPANT	\N	PRESENT	0
673836	673835	11026G	PARTICIPANT	\N	PRESENT	0
673837	673835	01025N	PARTICIPANT	\N	PRESENT	0
673838	673835	19739H	PARTICIPANT	\N	PRESENT	0
673840	673835	19525U	PARTICIPANT	\N	PRESENT	0
673841	673835	20024T	PARTICIPANT	\N	PRESENT	0
673842	673835	19713W	PARTICIPANT	\N	PRESENT	0
673843	673835	14213J	PARTICIPANT	\N	PRESENT	0
673845	673835	19503N	PARTICIPANT	\N	PRESENT	0
673846	673835	14223L	PARTICIPANT	\N	PRESENT	0
673848	673835	20120S	PARTICIPANT	\N	PRESENT	0
674495	674494	11083R	PARTICIPANT	\N	PRESENT	0
674496	674494	19713W	PARTICIPANT	\N	PRESENT	0
674498	674497	04035D	PARTICIPANT	\N	PRESENT	0
674499	674497	19713W	PARTICIPANT	\N	PRESENT	0
674501	674500	19713W	PARTICIPANT	\N	PRESENT	0
674502	674500	19503N	PARTICIPANT	\N	PRESENT	0
674503	674500	14331P	PARTICIPANT	\N	PRESENT	0
674504	674500	14147R	PARTICIPANT	\N	PRESENT	0
674505	674500	04057K	PARTICIPANT	\N	PRESENT	0
674506	674500	20120S	PARTICIPANT	\N	PRESENT	0
674507	674500	19798U	PARTICIPANT	\N	PRESENT	0
674508	674500	19782L	PARTICIPANT	\N	PRESENT	0
674510	674509	19713W	PARTICIPANT	\N	PRESENT	0
674511	674509	11026G	PARTICIPANT	\N	PRESENT	0
674512	674509	95063L	PARTICIPANT	\N	PRESENT	0
674695	672498	17779H	PARTICIPANT	\N	PRESENT	0
674696	672498	19697Q	PARTICIPANT	\N	PRESENT	0
674700	672498	20266L	PARTICIPANT	\N	PRESENT	0
674718	672498	19367Y	PARTICIPANT	\N	PRESENT	0
674720	672498	19723Y	PARTICIPANT	\N	PRESENT	0
674721	672498	04057K	PARTICIPANT	\N	PRESENT	0
674781	672498	19663E	PARTICIPANT	\N	PRESENT	0
674782	672498	04043D	PARTICIPANT	\N	PRESENT	0
674783	672498	19591F	PARTICIPANT	\N	PRESENT	0
675817	672574	12016W	PARTICIPANT	\N	EXCUSE	0
675930	672383	19347U	PARTICIPANT	\N	PRESENT	0
675931	672383	12016W	PARTICIPANT	\N	EXCUSE	0
663535	663534	19741B	PARTICIPANT	\N	PRESENT	0
663536	663534	20024T	PARTICIPANT	\N	PRESENT	0
663537	663534	11101A	PARTICIPANT	\N	PRESENT	0
663538	663534	19545Y	PARTICIPANT	\N	PRESENT	0
663539	663534	97011G	PARTICIPANT	\N	PRESENT	0
663540	663534	14026U	PARTICIPANT	\N	PRESENT	0
663541	663534	08015R	PARTICIPANT	\N	PRESENT	0
663542	663534	08034U	PARTICIPANT	\N	PRESENT	0
663543	663534	14147R	PARTICIPANT	\N	PRESENT	0
663544	663534	19735D	PARTICIPANT	\N	PRESENT	0
663545	663534	20026V	PARTICIPANT	\N	PRESENT	0
663546	663534	19593H	PARTICIPANT	\N	PRESENT	0
663547	663534	14179A	PARTICIPANT	\N	PRESENT	0
664588	664587	14083S	PARTICIPANT	\N	PRESENT	0
667941	667696	19545Y	PARTICIPANT	\N	PRESENT	0
667942	667696	14121F	PARTICIPANT	\N	PRESENT	0
667943	667912	20034V	PARTICIPANT	\N	EXCUSE	0
667944	667912	20286Q	PARTICIPANT	\N	EXCUSE	0
667945	667912	08028W	PARTICIPANT	\N	EXCUSE	0
667946	667912	20104S	PARTICIPANT	\N	EXCUSE	0
667947	667912	20028X	PARTICIPANT	\N	EXCUSE	0
667948	667912	14357A	PARTICIPANT	\N	PRESENT	0
667949	667912	14033T	PARTICIPANT	\N	PRESENT	0
667950	665225	20122U	PARTICIPANT	\N	PRESENT	0
667951	665225	19820Y	PARTICIPANT	\N	PRESENT	0
667952	665225	20100N	PARTICIPANT	\N	PRESENT	0
667953	665225	19739H	PARTICIPANT	\N	PRESENT	0
667954	665225	19549D	PARTICIPANT	\N	PRESENT	0
667955	665225	19681G	PARTICIPANT	\N	PRESENT	0
667956	667912	19631V	PARTICIPANT	\N	PRESENT	0
667957	665225	20038A	PARTICIPANT	\N	PRESENT	0
667958	665225	08060W	PARTICIPANT	\N	EXCUSE	0
667959	665225	11065P	PARTICIPANT	\N	PRESENT	0
667960	667611	14097Y	PARTICIPANT	\N	PRESENT	0
667961	667611	95041E	PARTICIPANT	\N	PRESENT	0
667962	667611	19443T	PARTICIPANT	\N	PRESENT	0
667963	667611	12041X	PARTICIPANT	\N	PRESENT	0
668184	667719	19581D	PARTICIPANT	\N	PRESENT	0
667965	667611	20042V	PARTICIPANT	\N	PRESENT	0
667966	667611	04042C	PRESIDENT	0	PRESENT	0
667967	667611	01024M	PARTICIPANT	\N	PRESENT	0
667968	667611	19669L	PARTICIPANT	\N	PRESENT	0
667969	667611	11066Q	PARTICIPANT	\N	PRESENT	0
667970	667611	14105F	PARTICIPANT	\N	PRESENT	0
667971	667611	20064C	PARTICIPANT	\N	PRESENT	0
667972	667611	19421M	PARTICIPANT	\N	PRESENT	0
667973	667611	98022P	PARTICIPANT	\N	PRESENT	0
667974	667611	14193X	PARTICIPANT	\N	PRESENT	0
667975	667611	08047A	PARTICIPANT	\N	PRESENT	0
667976	667611	20128B	PARTICIPANT	\N	PRESENT	0
667977	667611	14255U	PARTICIPANT	\N	PRESENT	0
667978	667611	16685X	PARTICIPANT	\N	PRESENT	0
667979	667611	19347U	PARTICIPANT	\N	PRESENT	0
667980	667912	19441R	PARTICIPANT	\N	PRESENT	0
667981	667912	01043Q	PARTICIPANT	\N	PRESENT	0
667982	667912	20094J	PARTICIPANT	\N	PRESENT	0
667983	667912	01025N	PARTICIPANT	\N	PRESENT	0
667984	667611	11064N	PARTICIPANT	\N	PRESENT	0
667985	667611	14249W	PARTICIPANT	\N	PRESENT	0
667986	667912	19563B	PARTICIPANT	\N	PRESENT	0
667987	667696	08011M	PARTICIPANT	\N	PRESENT	0
667988	667719	86034E	PARTICIPANT	\N	PRESENT	0
667989	665225	19503N	PARTICIPANT	\N	PRESENT	0
667990	665225	19525U	PARTICIPANT	\N	PRESENT	0
667991	665225	11101A	PARTICIPANT	\N	PRESENT	0
667992	665225	19745F	PARTICIPANT	\N	PRESENT	0
667993	667819	04057K	PARTICIPANT	\N	PRESENT	0
667994	667611	01062T	PARTICIPANT	\N	PRESENT	0
667995	667611	12028B	PARTICIPANT	\N	EXCUSE	0
667996	667611	19565D	PARTICIPANT	\N	EXCUSE	0
667997	667611	14267Y	PARTICIPANT	\N	PRESENT	0
667998	667696	14331P	PARTICIPANT	\N	PRESENT	0
667999	667912	20082E	PARTICIPANT	\N	PRESENT	0
668004	665806	19766L	PARTICIPANT	\N	PRESENT	0
668005	665806	04070G	PARTICIPANT	\N	PRESENT	0
668006	665806	19699S	PARTICIPANT	\N	PRESENT	0
668007	665806	19533U	PARTICIPANT	\N	PRESENT	0
668008	665806	04033B	PARTICIPANT	\N	PRESENT	0
668009	665806	20098N	PARTICIPANT	\N	PRESENT	0
668010	665806	20112S	PARTICIPANT	\N	PRESENT	0
668011	665806	92040Q	PARTICIPANT	\N	PRESENT	0
668012	665806	20016T	PARTICIPANT	\N	PRESENT	0
668013	665806	20124W	PARTICIPANT	\N	PRESENT	0
668014	665806	19593H	PARTICIPANT	\N	PRESENT	0
668015	665806	19527W	PARTICIPANT	\N	PRESENT	0
668016	665806	20132W	PARTICIPANT	\N	PRESENT	0
668017	665806	20134Y	PARTICIPANT	\N	PRESENT	0
668018	665806	19651A	PARTICIPANT	\N	PRESENT	0
668019	665806	19611R	PARTICIPANT	\N	PRESENT	0
668020	665806	20138D	PARTICIPANT	\N	PRESENT	0
668021	665806	20142Y	PARTICIPANT	\N	PRESENT	0
668022	665806	20048C	PARTICIPANT	\N	PRESENT	0
668023	665806	19399H	PARTICIPANT	\N	PRESENT	0
668024	665806	20152B	PARTICIPANT	\N	PRESENT	0
668025	665806	20052X	PARTICIPANT	\N	PRESENT	0
668026	665806	20172F	PARTICIPANT	\N	PRESENT	0
668027	665806	20058E	PARTICIPANT	\N	PRESENT	0
668028	665806	14030Q	PARTICIPANT	\N	PRESENT	0
668029	665806	20056C	PARTICIPANT	\N	PRESENT	0
668030	665806	04059M	PARTICIPANT	\N	PRESENT	0
668031	665806	20264J	PARTICIPANT	\N	PRESENT	0
668032	665806	19735D	PARTICIPANT	\N	PRESENT	0
668033	665806	14123H	PARTICIPANT	\N	PRESENT	0
668034	665806	11104D	PARTICIPANT	\N	PRESENT	0
668035	665806	19758L	PARTICIPANT	\N	PRESENT	0
668036	665806	17589D	PARTICIPANT	\N	PRESENT	0
668037	665806	20084G	PARTICIPANT	\N	PRESENT	0
668038	667611	08056B	PARTICIPANT	\N	EXCUSE	0
668039	667913	19768N	PARTICIPANT	\N	PRESENT	0
668040	667913	19515S	PARTICIPANT	\N	PRESENT	0
668041	667913	19782L	PARTICIPANT	\N	PRESENT	0
668042	667913	11077T	PARTICIPANT	\N	PRESENT	0
668043	667913	20092G	PARTICIPANT	\N	PRESENT	0
668044	667913	01043Q	PARTICIPANT	\N	PRESENT	0
668045	667913	14357A	PARTICIPANT	\N	PRESENT	0
668046	667913	20078J	PARTICIPANT	\N	PRESENT	0
668047	667913	19441R	PARTICIPANT	\N	PRESENT	0
668048	667913	20082E	PARTICIPANT	\N	PRESENT	0
668049	667913	20094J	PARTICIPANT	\N	PRESENT	0
668050	667913	04045F	PARTICIPANT	\N	PRESENT	0
668051	667913	19631V	PARTICIPANT	\N	PRESENT	0
668052	667913	19705W	PARTICIPANT	\N	PRESENT	0
668053	667913	19707Y	PARTICIPANT	\N	PRESENT	0
668054	667913	08015R	PARTICIPANT	\N	PRESENT	0
668055	667913	19575F	PARTICIPANT	\N	PRESENT	0
668056	667913	19369B	PARTICIPANT	\N	PRESENT	0
668057	667913	20018V	PARTICIPANT	\N	PRESENT	0
668058	667913	19563B	PARTICIPANT	\N	PRESENT	0
668059	667913	14329V	PARTICIPANT	\N	PRESENT	0
668060	667913	14038Y	PARTICIPANT	\N	PRESENT	0
668061	667913	20030R	PARTICIPANT	\N	PRESENT	0
668062	667913	19467C	PARTICIPANT	\N	PRESENT	0
668063	667913	14187A	PARTICIPANT	\N	PRESENT	0
668064	667913	20144B	PARTICIPANT	\N	PRESENT	0
668065	667913	19695N	PARTICIPANT	\N	PRESENT	0
668066	667913	11090Q	PRESIDENT	0	PRESENT	0
668067	667913	14033T	PARTICIPANT	\N	PRESENT	0
668068	667913	01025N	PARTICIPANT	\N	PRESENT	0
668069	667913	20062A	PARTICIPANT	\N	PRESENT	0
668070	667913	14251Q	PARTICIPANT	\N	PRESENT	0
668071	667913	20298U	PARTICIPANT	\N	PRESENT	0
668072	667913	19747H	PARTICIPANT	\N	PRESENT	0
668073	667913	14207L	PARTICIPANT	\N	PRESENT	0
668074	667913	14257W	PARTICIPANT	\N	PRESENT	0
668075	667913	20034V	PARTICIPANT	\N	EXCUSE	0
668076	667913	20286Q	PARTICIPANT	\N	EXCUSE	0
668077	667913	08028W	PARTICIPANT	\N	EXCUSE	0
668078	667913	20104S	PARTICIPANT	\N	EXCUSE	0
668079	667913	20028X	PARTICIPANT	\N	EXCUSE	0
668080	667819	01034P	PARTICIPANT	\N	PRESENT	0
668081	667611	11054L	PARTICIPANT	\N	PRESENT	0
668082	665806	01060R	PARTICIPANT	\N	PRESENT	0
668083	665806	11043H	PARTICIPANT	\N	PRESENT	0
668084	667819	18193Q	PARTICIPANT	\N	PRESENT	0
668085	665806	19573D	PARTICIPANT	\N	PRESENT	0
668086	665806	14073Q	PARTICIPANT	\N	EXCUSE	0
668087	665806	11109J	PARTICIPANT	\N	EXCUSE	0
668183	667719	20090E	PARTICIPANT	\N	PRESENT	0
668185	667719	95041E	PARTICIPANT	\N	PRESENT	0
668186	667719	19701S	PARTICIPANT	\N	PRESENT	0
668187	667719	19479G	PARTICIPANT	\N	PRESENT	0
669293	669292	14237S	PARTICIPANT	\N	PRESENT	0
669294	669292	19383Y	PARTICIPANT	\N	PRESENT	0
669295	669292	20032T	PARTICIPANT	\N	PRESENT	0
669296	669292	19349W	PARTICIPANT	\N	PRESENT	0
669297	669292	19768N	PARTICIPANT	\N	PRESENT	0
669298	669292	14107H	PARTICIPANT	\N	PRESENT	0
669299	669292	20058E	PARTICIPANT	\N	PRESENT	0
669300	669292	20138D	PARTICIPANT	\N	PRESENT	0
669301	669292	14189C	PARTICIPANT	\N	PRESENT	0
669302	669292	19575F	PARTICIPANT	\N	PRESENT	0
669304	669292	19503N	PARTICIPANT	\N	PRESENT	0
669352	669292	11043H	PARTICIPANT	\N	PRESENT	0
673201	672997	16685X	PARTICIPANT	\N	PRESENT	0
673202	672997	19479G	PARTICIPANT	\N	PRESENT	0
673203	672997	17229F	PARTICIPANT	\N	PRESENT	0
673204	672997	19691J	PARTICIPANT	\N	PRESENT	0
673205	672997	08009T	PARTICIPANT	\N	PRESENT	0
673206	672997	14267Y	PARTICIPANT	\N	PRESENT	0
673207	672997	20052X	PARTICIPANT	\N	PRESENT	0
673208	672997	04008A	PARTICIPANT	\N	PRESENT	0
673209	672997	14255U	PARTICIPANT	\N	PRESENT	0
673210	672997	19747H	PARTICIPANT	\N	PRESENT	0
673211	672997	20066E	PARTICIPANT	\N	PRESENT	0
673212	672997	19415P	PARTICIPANT	\N	PRESENT	0
673213	672997	04070G	PARTICIPANT	\N	PRESENT	0
673214	672997	14215L	PARTICIPANT	\N	PRESENT	0
673215	672997	04033B	PARTICIPANT	\N	PRESENT	0
673216	672997	14249W	PARTICIPANT	\N	PRESENT	0
673217	672997	14187A	PARTICIPANT	\N	PRESENT	0
673218	672997	11097X	PARTICIPANT	\N	PRESENT	0
673219	672997	19701S	PARTICIPANT	\N	PRESENT	0
673220	672997	14053L	PARTICIPANT	\N	PRESENT	0
673221	672997	14069U	PARTICIPANT	\N	PRESENT	0
673222	672997	19533U	PARTICIPANT	\N	PRESENT	0
673223	672997	04043D	PARTICIPANT	\N	PRESENT	0
673224	672997	19798U	PARTICIPANT	\N	PRESENT	0
673225	672997	20118Y	PARTICIPANT	\N	PRESENT	0
673226	672997	05012A	PARTICIPANT	\N	PRESENT	0
673227	672997	14259Y	PARTICIPANT	\N	PRESENT	0
673228	672997	11056N	PARTICIPANT	\N	PRESENT	0
673229	672997	14225N	PARTICIPANT	\N	PRESENT	0
673230	672997	14329V	PARTICIPANT	\N	PRESENT	0
673231	672997	19549D	PARTICIPANT	\N	PRESENT	0
673232	672997	11026G	PARTICIPANT	\N	PRESENT	0
673233	672997	14105F	PARTICIPANT	\N	PRESENT	0
673234	672997	14147R	PARTICIPANT	\N	PRESENT	0
673235	672997	14121F	PARTICIPANT	\N	PRESENT	0
673236	672997	20062A	PARTICIPANT	\N	PRESENT	0
673237	672997	14055N	PARTICIPANT	\N	PRESENT	0
673238	672997	19679N	PARTICIPANT	\N	PRESENT	0
673239	672997	11103C	PARTICIPANT	\N	PRESENT	0
673240	672997	19657G	PARTICIPANT	\N	PRESENT	0
673241	672997	14257W	PARTICIPANT	\N	PRESENT	0
673242	672997	08069G	PARTICIPANT	\N	PRESENT	0
673243	672997	14073Q	PARTICIPANT	\N	PRESENT	0
673244	672997	11070L	PARTICIPANT	\N	PRESENT	0
673245	672997	14357A	PARTICIPANT	\N	PRESENT	0
673246	672997	19675J	PARTICIPANT	\N	PRESENT	0
673247	672997	14111D	PARTICIPANT	\N	PRESENT	0
673248	672997	19383Y	PARTICIPANT	\N	PRESENT	0
673249	672997	19762G	PARTICIPANT	\N	PRESENT	0
673250	672997	20020P	PARTICIPANT	\N	PRESENT	0
673251	672997	20152B	PARTICIPANT	\N	PRESENT	0
673252	672997	14059S	PARTICIPANT	\N	PRESENT	0
673253	672997	20090E	PARTICIPANT	\N	PRESENT	0
673254	672997	20024T	PARTICIPANT	\N	PRESENT	0
673255	672997	08015R	PARTICIPANT	\N	PRESENT	0
673256	672997	14217N	PARTICIPANT	\N	PRESENT	0
673257	672997	14213J	PARTICIPANT	\N	PRESENT	0
673258	672997	19723Y	PARTICIPANT	\N	PRESENT	0
673259	672997	20076G	PARTICIPANT	\N	PRESENT	0
673260	672997	11104D	PARTICIPANT	\N	PRESENT	0
673261	672997	04092N	PARTICIPANT	\N	PRESENT	0
673262	672997	14193X	PARTICIPANT	\N	PRESENT	0
673263	672997	19671E	PARTICIPANT	\N	PRESENT	0
673270	672997	14231L	PARTICIPANT	\N	PRESENT	0
673265	672997	19467C	PARTICIPANT	\N	PRESENT	0
673266	672997	20098N	PARTICIPANT	\N	PRESENT	0
673267	672997	08056B	PARTICIPANT	\N	PRESENT	0
673268	672997	20150Y	PARTICIPANT	\N	PRESENT	0
673269	672997	19335Q	PARTICIPANT	\N	PRESENT	0
673271	672997	08010L	PARTICIPANT	\N	PRESENT	0
673272	672997	19369B	PARTICIPANT	\N	PRESENT	0
673273	672997	20248J	PARTICIPANT	\N	PRESENT	0
673274	672997	14205J	PARTICIPANT	\N	PRESENT	0
673275	672997	20120S	PARTICIPANT	\N	PRESENT	0
673276	672997	20298U	PARTICIPANT	\N	PRESENT	0
673277	672997	10006L	PARTICIPANT	\N	PRESENT	0
673278	672997	14042U	PARTICIPANT	\N	PRESENT	0
673279	672997	14030Q	PARTICIPANT	\N	PRESENT	0
673280	672997	19741B	PARTICIPANT	\N	PRESENT	0
673281	672997	01024M	PARTICIPANT	\N	PRESENT	0
673282	672997	08060W	PARTICIPANT	\N	PRESENT	0
673283	672997	20094J	PARTICIPANT	\N	PRESENT	0
673284	672997	11101A	PARTICIPANT	\N	PRESENT	0
673285	672997	19669L	PARTICIPANT	\N	PRESENT	0
673286	672997	19735D	PARTICIPANT	\N	PRESENT	0
673287	672997	14223L	PARTICIPANT	\N	PRESENT	0
673288	672997	20028X	PARTICIPANT	\N	PRESENT	0
673289	672997	20124W	PARTICIPANT	\N	PRESENT	0
673290	672997	20126Y	PARTICIPANT	\N	PRESENT	0
673291	672997	14123H	PARTICIPANT	\N	PRESENT	0
673292	672997	11115U	PARTICIPANT	\N	PRESENT	0
673293	672997	20088L	PARTICIPANT	\N	PRESENT	0
673294	672997	20018V	PARTICIPANT	\N	PRESENT	0
673295	672997	19768N	PARTICIPANT	\N	PRESENT	0
673296	672997	19421M	PARTICIPANT	\N	PRESENT	0
673297	672997	14033T	PARTICIPANT	\N	PRESENT	0
673298	672997	14109K	PARTICIPANT	\N	PRESENT	0
673299	672997	01048V	PARTICIPANT	\N	PRESENT	0
673300	672997	11027H	PARTICIPANT	\N	PRESENT	0
673301	672997	14151M	PARTICIPANT	\N	PRESENT	0
673302	672997	19585H	PARTICIPANT	\N	PRESENT	0
673303	672997	20050V	PARTICIPANT	\N	PRESENT	0
673304	672997	14251Q	PARTICIPANT	\N	PRESENT	0
673305	672997	19413M	PARTICIPANT	\N	PRESENT	0
673306	672997	20914V	PARTICIPANT	\N	PRESENT	0
673307	672997	11064N	PARTICIPANT	\N	PRESENT	0
673308	672997	19591F	PARTICIPANT	\N	PRESENT	0
673309	672997	19760E	PARTICIPANT	\N	PRESENT	0
673310	672997	20032T	PARTICIPANT	\N	PRESENT	0
673311	672997	20148F	PARTICIPANT	\N	PRESENT	0
673312	672997	20108W	PARTICIPANT	\N	PRESENT	0
673313	672997	19577H	PARTICIPANT	\N	PRESENT	0
673314	672997	17589D	PARTICIPANT	\N	PRESENT	0
673315	672997	19725B	PARTICIPANT	\N	PRESENT	0
673316	672997	05008E	PARTICIPANT	\N	PRESENT	0
673317	672997	19647E	PARTICIPANT	\N	PRESENT	0
673318	672997	20064C	PARTICIPANT	\N	PRESENT	0
673319	672997	11090Q	PARTICIPANT	\N	PRESENT	0
673320	672997	19637C	PARTICIPANT	\N	PRESENT	0
673321	672997	95041E	PARTICIPANT	\N	PRESENT	0
673322	672997	20252E	PARTICIPANT	\N	PRESENT	0
673323	672997	01043Q	PARTICIPANT	\N	PRESENT	0
673324	672997	20104S	PARTICIPANT	\N	PRESENT	0
673325	672997	20106U	PARTICIPANT	\N	PRESENT	0
673326	672997	11012A	PARTICIPANT	\N	PRESENT	0
673327	672997	19387D	PARTICIPANT	\N	PRESENT	0
673328	672997	20054A	PARTICIPANT	\N	PRESENT	0
673329	672997	07033P	PARTICIPANT	\N	PRESENT	0
673330	672997	14031R	PARTICIPANT	\N	PRESENT	0
673331	672997	19719D	PARTICIPANT	\N	PRESENT	0
673332	672997	20022R	PARTICIPANT	\N	PRESENT	0
673333	672997	19631V	PARTICIPANT	\N	PRESENT	0
673334	672997	20180F	PARTICIPANT	\N	PRESENT	0
673335	672997	20114U	PARTICIPANT	\N	PRESENT	0
673336	672997	01034P	PARTICIPANT	\N	PRESENT	0
673337	672997	14037X	PARTICIPANT	\N	PRESENT	0
673338	672997	20136B	PARTICIPANT	\N	PRESENT	0
673339	672997	11048N	PARTICIPANT	\N	PRESENT	0
673340	672997	20086J	PARTICIPANT	\N	PRESENT	0
673341	672997	11053K	PARTICIPANT	\N	PRESENT	0
673342	672997	11085T	PARTICIPANT	\N	PRESENT	0
673343	672997	20078J	PARTICIPANT	\N	PRESENT	0
673344	672997	19713W	PARTICIPANT	\N	PRESENT	0
673347	672997	20286Q	PARTICIPANT	\N	PRESENT	0
673348	672997	12041X	PARTICIPANT	\N	PRESENT	0
673350	672997	19581D	PARTICIPANT	\N	PRESENT	0
673351	672997	14179A	PARTICIPANT	\N	PRESENT	0
673353	672997	04042C	PARTICIPANT	\N	PRESENT	0
673354	672997	08012N	PARTICIPANT	\N	PRESENT	0
655134	652910	14225N	PARTICIPANT	\N	PRESENT	0
655132	652910	99004R	PARTICIPANT	\N	PRESENT	0
655133	652910	11048N	PARTICIPANT	\N	PRESENT	0
655135	652910	95063L	PARTICIPANT	\N	PRESENT	0
655136	652910	14251Q	PARTICIPANT	\N	PRESENT	0
655137	652910	19762G	PARTICIPANT	\N	PRESENT	0
655140	652910	20914V	PARTICIPANT	\N	PRESENT	0
655142	652910	04085P	PARTICIPANT	\N	PRESENT	0
655143	652910	19479G	PARTICIPANT	\N	PRESENT	0
655144	652910	11012A	PARTICIPANT	\N	PRESENT	0
655145	652910	19647E	PARTICIPANT	\N	PRESENT	0
655146	652910	11033F	PARTICIPANT	\N	PRESENT	0
655147	652910	20298U	PARTICIPANT	\N	PRESENT	0
655148	652910	20032T	PARTICIPANT	\N	PRESENT	0
655149	652910	20044X	PARTICIPANT	\N	PRESENT	0
655150	652910	11074Q	PARTICIPANT	\N	PRESENT	0
655151	652910	19369B	PARTICIPANT	\N	PRESENT	0
655152	652910	04059M	PARTICIPANT	\N	PRESENT	0
655153	652910	20070A	PARTICIPANT	\N	PRESENT	0
655154	652910	14219Q	PARTICIPANT	\N	PRESENT	0
655155	652910	19549D	PARTICIPANT	\N	PRESENT	0
655156	652910	20090E	PARTICIPANT	\N	PRESENT	0
655157	652910	20136B	PARTICIPANT	\N	PRESENT	0
655158	652910	19447X	PARTICIPANT	\N	PRESENT	0
655159	652910	20062A	PARTICIPANT	\N	PRESENT	0
655160	652910	14123H	PARTICIPANT	\N	PRESENT	0
655161	652910	20080C	PARTICIPANT	\N	PRESENT	0
655162	652910	14257W	PARTICIPANT	\N	PRESENT	0
655163	652910	19503N	PARTICIPANT	\N	PRESENT	0
655164	652910	08010L	PARTICIPANT	\N	PRESENT	0
655165	652910	20110Q	PARTICIPANT	\N	PRESENT	0
655166	652910	20130U	PARTICIPANT	\N	PRESENT	0
655167	652910	20152B	PARTICIPANT	\N	PRESENT	0
655168	652910	11085T	PARTICIPANT	\N	PRESENT	0
655169	652910	19697Q	PARTICIPANT	\N	PRESENT	0
655170	652910	20106U	PARTICIPANT	\N	PRESENT	0
666160	659563	19549D	PARTICIPANT	\N	PRESENT	0
666161	659563	05012A	PARTICIPANT	\N	PRESENT	0
666162	659563	20144B	PARTICIPANT	\N	PRESENT	0
666163	659563	20172F	PARTICIPANT	\N	PRESENT	0
666164	659563	19619A	PARTICIPANT	\N	PRESENT	0
666165	659563	20118Y	PARTICIPANT	\N	PRESENT	0
666166	659563	19503N	PARTICIPANT	\N	PRESENT	0
666167	659563	20024T	PARTICIPANT	\N	PRESENT	0
666168	659563	20038A	PARTICIPANT	\N	PRESENT	0
666169	659563	19251M	PARTICIPANT	\N	PRESENT	0
666170	659563	11101A	PARTICIPANT	\N	PRESENT	0
666171	663458	20132W	PARTICIPANT	\N	PRESENT	0
666172	663458	19643A	PARTICIPANT	\N	PRESENT	0
666173	663458	19699S	PARTICIPANT	\N	PRESENT	0
666174	663458	19611R	PRESIDENT	0	PRESENT	0
666175	663458	20142Y	PARTICIPANT	\N	PRESENT	0
666176	663458	19399H	PARTICIPANT	\N	PRESENT	0
666177	663458	20052X	PARTICIPANT	\N	PRESENT	0
666178	663458	14229S	PARTICIPANT	\N	PRESENT	0
666179	663458	14030Q	PARTICIPANT	\N	PRESENT	0
666180	663458	20098N	PARTICIPANT	\N	PRESENT	0
666181	663458	20056C	PARTICIPANT	\N	PRESENT	0
666182	663458	20180F	PARTICIPANT	\N	PRESENT	0
666183	663458	20264J	PARTICIPANT	\N	PRESENT	0
666184	663458	14109K	PARTICIPANT	\N	PRESENT	0
666185	663458	08012N	PARTICIPANT	\N	PRESENT	0
666186	663458	11104D	PARTICIPANT	\N	PRESENT	0
666187	663458	11043H	PARTICIPANT	\N	PRESENT	0
666188	663458	19758L	PARTICIPANT	\N	PRESENT	0
666189	663458	20026V	PARTICIPANT	\N	PRESENT	0
666190	663458	20084G	PARTICIPANT	\N	PRESENT	0
666191	663458	19621T	PARTICIPANT	\N	PRESENT	0
666193	664324	20126Y	PARTICIPANT	\N	PRESENT	0
666194	664324	20150Y	PARTICIPANT	\N	PRESENT	0
666237	664990	19443T	PARTICIPANT	\N	PRESENT	0
666238	664990	12041X	PARTICIPANT	\N	PRESENT	0
666239	664990	20072C	PARTICIPANT	\N	PRESENT	0
666240	664990	01058X	PARTICIPANT	\N	PRESENT	0
666241	664990	11027H	PARTICIPANT	\N	PRESENT	0
666242	664990	16685X	PARTICIPANT	\N	PRESENT	0
666243	664990	11054L	PARTICIPANT	\N	PRESENT	0
666244	664990	04042C	PRESIDENT	0	PRESENT	0
666245	664990	11066Q	PARTICIPANT	\N	PRESENT	0
666246	664990	19669L	PARTICIPANT	\N	PRESENT	0
666247	664990	12028B	PARTICIPANT	\N	PRESENT	0
666248	664990	11115U	PARTICIPANT	\N	PRESENT	0
666249	664990	14055N	PARTICIPANT	\N	PRESENT	0
666250	664990	19421M	PARTICIPANT	\N	PRESENT	0
666251	664990	19709B	PARTICIPANT	\N	PRESENT	0
666252	664990	19347U	PARTICIPANT	\N	PRESENT	0
666253	664990	14193X	PARTICIPANT	\N	PRESENT	0
666254	664990	07033P	PARTICIPANT	\N	PRESENT	0
666255	664990	97011G	PARTICIPANT	\N	PRESENT	0
666256	664990	08061X	PARTICIPANT	\N	PRESENT	0
666257	664990	14249W	PARTICIPANT	\N	PRESENT	0
666258	664990	08047A	PARTICIPANT	\N	PRESENT	0
666259	664990	20128B	PARTICIPANT	\N	PRESENT	0
666260	664990	14097Y	PARTICIPANT	\N	PRESENT	0
666261	664990	14059S	PARTICIPANT	\N	PRESENT	0
666262	664990	01062T	PARTICIPANT	\N	PRESENT	0
666263	664990	14133K	PARTICIPANT	\N	PRESENT	0
666264	664990	08069G	PARTICIPANT	\N	PRESENT	0
666265	664990	11041F	PARTICIPANT	\N	PRESENT	0
666266	664990	20042V	PARTICIPANT	\N	PRESENT	0
666267	664990	01024M	PARTICIPANT	\N	PRESENT	0
666268	664990	19721W	PARTICIPANT	\N	PRESENT	0
666269	664990	14105F	PARTICIPANT	\N	PRESENT	0
666270	664990	20064C	PARTICIPANT	\N	PRESENT	0
666271	664990	98022P	PARTICIPANT	\N	PRESENT	0
666272	664990	14267Y	PARTICIPANT	\N	PRESENT	0
666273	664990	11083R	PARTICIPANT	\N	PRESENT	0
666274	664990	14211G	PARTICIPANT	\N	PRESENT	0
666275	664990	19583F	PARTICIPANT	\N	PRESENT	0
666276	664990	17023S	PARTICIPANT	\N	PRESENT	0
666277	664990	14255U	PARTICIPANT	\N	PRESENT	0
666278	664990	19565D	PARTICIPANT	\N	EXCUSE	0
666279	664993	19443T	PARTICIPANT	\N	PRESENT	0
666280	664993	12041X	PARTICIPANT	\N	PRESENT	0
666281	664993	20072C	PARTICIPANT	\N	PRESENT	0
666282	664993	01058X	PARTICIPANT	\N	PRESENT	0
666283	664993	11027H	PARTICIPANT	\N	PRESENT	0
666284	664993	16685X	PARTICIPANT	\N	PRESENT	0
666285	664993	11054L	PARTICIPANT	\N	PRESENT	0
666286	664993	04042C	PRESIDENT	0	PRESENT	0
666287	664993	11066Q	PARTICIPANT	\N	PRESENT	0
666288	664993	19669L	PARTICIPANT	\N	PRESENT	0
666289	664993	12028B	PARTICIPANT	\N	PRESENT	0
666290	664993	11115U	PARTICIPANT	\N	PRESENT	0
666291	664993	14055N	PARTICIPANT	\N	PRESENT	0
666292	664993	19421M	PARTICIPANT	\N	PRESENT	0
666293	664993	19709B	PARTICIPANT	\N	PRESENT	0
666294	664993	19347U	PARTICIPANT	\N	PRESENT	0
666295	664993	14193X	PARTICIPANT	\N	PRESENT	0
666296	664993	07033P	PARTICIPANT	\N	PRESENT	0
666297	664993	97011G	PARTICIPANT	\N	PRESENT	0
666298	664993	08061X	PARTICIPANT	\N	PRESENT	0
666299	664993	14249W	PARTICIPANT	\N	PRESENT	0
666300	664993	08047A	PARTICIPANT	\N	PRESENT	0
666301	664993	20128B	PARTICIPANT	\N	PRESENT	0
666302	664993	14097Y	PARTICIPANT	\N	PRESENT	0
666303	664993	14059S	PARTICIPANT	\N	PRESENT	0
666304	664993	01062T	PARTICIPANT	\N	PRESENT	0
666305	664993	14133K	PARTICIPANT	\N	PRESENT	0
666306	664993	08069G	PARTICIPANT	\N	PRESENT	0
666307	664993	11041F	PARTICIPANT	\N	PRESENT	0
666308	664993	20042V	PARTICIPANT	\N	PRESENT	0
666309	664993	01024M	PARTICIPANT	\N	PRESENT	0
666310	664993	19721W	PARTICIPANT	\N	PRESENT	0
666311	664993	14105F	PARTICIPANT	\N	PRESENT	0
666312	664993	20064C	PARTICIPANT	\N	PRESENT	0
666313	664993	98022P	PARTICIPANT	\N	PRESENT	0
666314	664993	14267Y	PARTICIPANT	\N	PRESENT	0
666315	664993	11083R	PARTICIPANT	\N	PRESENT	0
666316	664993	14211G	PARTICIPANT	\N	PRESENT	0
666317	664993	19583F	PARTICIPANT	\N	PRESENT	0
666318	664993	17023S	PARTICIPANT	\N	PRESENT	0
666319	664993	14255U	PARTICIPANT	\N	PRESENT	0
666320	664993	19565D	PARTICIPANT	\N	EXCUSE	0
666326	659563	19820Y	PARTICIPANT	\N	PRESENT	0
666327	659563	20096L	PARTICIPANT	\N	PRESENT	0
666328	659563	14237S	PARTICIPANT	\N	PRESENT	0
666329	659563	20106U	PARTICIPANT	\N	PRESENT	0
666330	659563	19685L	PARTICIPANT	\N	PRESENT	0
666331	659563	17367Q	PARTICIPANT	\N	PRESENT	0
666332	659563	20122U	PARTICIPANT	\N	PRESENT	0
675932	672383	19657G	PARTICIPANT	\N	PRESENT	0
675933	672383	11072N	PARTICIPANT	\N	PRESENT	0
675934	672383	20150Y	PARTICIPANT	\N	PRESENT	0
675935	672383	20148F	PARTICIPANT	\N	PRESENT	0
675946	675945	19507S	PARTICIPANT	\N	PRESENT	0
675949	668110	14231L	PRESIDENT	0	PRESENT	0
675950	668110	20090E	PARTICIPANT	\N	PRESENT	0
675951	668110	14229S	PARTICIPANT	\N	PRESENT	0
675952	668110	14281W	PARTICIPANT	\N	PRESENT	0
675953	668110	14215L	PARTICIPANT	\N	PRESENT	0
675954	668110	14217N	PARTICIPANT	\N	PRESENT	0
675955	668110	19565D	PARTICIPANT	\N	PRESENT	0
675956	668110	20120S	PARTICIPANT	\N	PRESENT	0
675957	668110	20022R	PARTICIPANT	\N	PRESENT	0
675958	668110	20070A	PARTICIPANT	\N	PRESENT	0
675959	668110	05012A	PARTICIPANT	\N	PRESENT	0
675960	668110	01057W	PARTICIPANT	\N	PRESENT	0
675961	668110	14053L	PARTICIPANT	\N	PRESENT	0
675962	668110	19826F	PARTICIPANT	\N	PRESENT	0
675963	668110	19735D	PARTICIPANT	\N	PRESENT	0
675964	668110	14257W	PARTICIPANT	\N	PRESENT	0
675965	668110	08010L	PARTICIPANT	\N	PRESENT	0
675966	668110	04045F	PARTICIPANT	\N	PRESENT	0
675967	668110	19820Y	PARTICIPANT	\N	PRESENT	0
675968	668110	17637T	PARTICIPANT	\N	PRESENT	0
675969	668110	14187A	PARTICIPANT	\N	PRESENT	0
675970	668110	19631V	PARTICIPANT	\N	PRESENT	0
675971	668110	19758L	PARTICIPANT	\N	EXCUSE	0
675972	668110	19782L	PARTICIPANT	\N	EXCUSE	0
675973	668110	14327T	PARTICIPANT	\N	EXCUSE	0
675974	668110	19333N	PARTICIPANT	\N	EXCUSE	0
675975	668110	19447X	PARTICIPANT	\N	EXCUSE	0
675976	668110	19711U	PARTICIPANT	\N	EXCUSE	0
675977	668110	14205J	PARTICIPANT	\N	EXCUSE	0
675978	668110	19563B	PARTICIPANT	\N	EXCUSE	0
675979	668110	19349W	PARTICIPANT	\N	EXCUSE	0
675980	668110	14107H	PARTICIPANT	\N	EXCUSE	0
675981	668110	20062A	PARTICIPANT	\N	EXCUSE	0
675982	668110	20058E	PARTICIPANT	\N	EXCUSE	0
675986	668110	20084G	PARTICIPANT	\N	PRESENT	0
676089	676088	14255U	PARTICIPANT	\N	PRESENT	0
676090	676088	19585H	PARTICIPANT	\N	PRESENT	0
676191	670725	19663E	PARTICIPANT	\N	PRESENT	0
677133	676424	20914V	PARTICIPANT	\N	PRESENT	0
677134	676424	20134Y	PARTICIPANT	\N	PRESENT	0
677135	676424	20100N	PARTICIPANT	\N	PRESENT	0
677136	676424	19347U	PARTICIPANT	\N	PRESENT	0
677137	676424	11012A	PARTICIPANT	\N	PRESENT	0
677138	676424	11048N	PARTICIPANT	\N	PRESENT	0
677139	676424	14225N	PARTICIPANT	\N	PRESENT	0
677140	676424	20080C	PARTICIPANT	\N	PRESENT	0
677141	676424	20050V	PARTICIPANT	\N	PRESENT	0
677142	676424	19349W	PARTICIPANT	\N	PRESENT	0
677143	676424	19820Y	PARTICIPANT	\N	PRESENT	0
677144	676424	99004R	PARTICIPANT	\N	PRESENT	0
677145	676424	14073Q	PARTICIPANT	\N	PRESENT	0
677146	676424	20298U	PARTICIPANT	\N	PRESENT	0
677147	676424	19671E	PARTICIPANT	\N	PRESENT	0
677148	676424	20052X	PARTICIPANT	\N	PRESENT	0
677149	676424	19711U	PARTICIPANT	\N	PRESENT	0
677150	676424	14327T	PARTICIPANT	\N	PRESENT	0
677151	676424	20024T	PARTICIPANT	\N	PRESENT	0
677152	676424	20056C	PARTICIPANT	\N	PRESENT	0
677153	676424	20026V	PARTICIPANT	\N	PRESENT	0
677154	676424	20124W	PARTICIPANT	\N	PRESENT	0
677155	676424	20034V	PARTICIPANT	\N	PRESENT	0
677156	676424	20044X	PARTICIPANT	\N	PRESENT	0
677157	676424	11110B	PARTICIPANT	\N	PRESENT	0
677158	676424	19531S	PARTICIPANT	\N	PRESENT	0
677131	676424	19719D	PARTICIPANT	\N	PRESENT	0
677132	676424	11077T	PARTICIPANT	\N	PRESENT	0
677159	676424	08009T	PARTICIPANT	\N	PRESENT	0
677160	676424	14205J	PARTICIPANT	\N	PRESENT	0
677161	676424	20116W	PARTICIPANT	\N	PRESENT	0
677162	676424	14257W	PARTICIPANT	\N	PRESENT	0
677163	676424	14083S	PARTICIPANT	\N	PRESENT	0
677164	676424	14331P	PARTICIPANT	\N	PRESENT	0
677165	676424	19577H	PARTICIPANT	\N	PRESENT	0
677166	676424	20086J	PARTICIPANT	\N	PRESENT	0
677167	676424	20136B	PARTICIPANT	\N	PRESENT	0
677168	676424	07029T	PARTICIPANT	\N	PRESENT	0
677169	676424	20180F	PARTICIPANT	\N	PRESENT	0
677170	676424	14187A	PARTICIPANT	\N	PRESENT	0
677171	676424	11097X	PARTICIPANT	\N	PRESENT	0
677172	676424	20054A	PARTICIPANT	\N	PRESENT	0
677173	676424	19657G	PARTICIPANT	\N	PRESENT	0
677174	676424	14042U	PARTICIPANT	\N	PRESENT	0
677175	676424	14219Q	PARTICIPANT	\N	PRESENT	0
677176	676424	14191V	PARTICIPANT	\N	PRESENT	0
677177	676424	08010L	PARTICIPANT	\N	PRESENT	0
677178	676424	11053K	PARTICIPANT	\N	PRESENT	0
677179	676424	20148F	PARTICIPANT	\N	PRESENT	0
677180	676424	19647E	PARTICIPANT	\N	PRESENT	0
677181	676424	19782L	PARTICIPANT	\N	PRESENT	0
677182	676424	20252E	PARTICIPANT	\N	PRESENT	0
677183	676424	14231L	PARTICIPANT	\N	PRESENT	0
677184	676424	20092G	PARTICIPANT	\N	PRESENT	0
677185	676424	20070A	PARTICIPANT	\N	PRESENT	0
677186	676424	20032T	PARTICIPANT	\N	PRESENT	0
677187	676424	20132W	PARTICIPANT	\N	PRESENT	0
677188	676424	14037X	PARTICIPANT	\N	PRESENT	0
677189	676424	14173T	PARTICIPANT	\N	PRESENT	0
677190	676424	19687N	PARTICIPANT	\N	PRESENT	0
677191	676424	20142Y	PARTICIPANT	\N	PRESENT	0
677192	676424	01057W	PARTICIPANT	\N	PRESENT	0
677193	676424	19741B	PARTICIPANT	\N	PRESENT	0
677194	676424	04047H	PARTICIPANT	\N	PRESENT	0
677195	676424	11065P	PARTICIPANT	\N	PRESENT	0
677196	676424	19387D	PARTICIPANT	\N	PRESENT	0
677197	676424	20018V	PARTICIPANT	\N	PRESENT	0
677198	676424	19621T	PARTICIPANT	\N	PRESENT	0
677199	676424	19479G	PARTICIPANT	\N	PRESENT	0
677200	676424	14001X	PARTICIPANT	\N	PRESENT	0
677201	676424	14071N	PARTICIPANT	\N	PRESENT	0
677202	676424	20094J	PARTICIPANT	\N	PRESENT	0
677203	676424	20028X	PARTICIPANT	\N	PRESENT	0
677204	676424	14107H	PARTICIPANT	\N	PRESENT	0
677205	676424	19569H	PARTICIPANT	\N	PRESENT	0
677206	676424	08061X	PARTICIPANT	\N	PRESENT	0
677207	676424	19295A	PARTICIPANT	\N	PRESENT	0
677208	676424	14097Y	PARTICIPANT	\N	PRESENT	0
677209	676424	19369B	PARTICIPANT	\N	PRESENT	0
677210	676424	20172F	PARTICIPANT	\N	PRESENT	0
677211	676424	20108W	PARTICIPANT	\N	PRESENT	0
677212	676424	14069U	PARTICIPANT	\N	PRESENT	0
677213	676424	14211G	PARTICIPANT	\N	PRESENT	0
677214	676424	11056N	PARTICIPANT	\N	PRESENT	0
677215	676424	20120S	PARTICIPANT	\N	PRESENT	0
677216	676424	19709B	PARTICIPANT	\N	PRESENT	0
677218	677217	20108W	PARTICIPANT	\N	PRESENT	0
677661	676189	10015M	PARTICIPANT	\N	PRESENT	0
677662	676189	14179A	PARTICIPANT	\N	PRESENT	0
677663	676189	08018U	PRESIDENT	0	PRESENT	0
677664	676189	19673G	PARTICIPANT	\N	PRESENT	0
677665	676189	19447X	PARTICIPANT	\N	PRESENT	0
677666	676189	19954N	PARTICIPANT	\N	PRESENT	0
677667	676189	19729F	PARTICIPANT	\N	PRESENT	0
677668	676189	07004J	PARTICIPANT	\N	PRESENT	0
677669	676189	14001X	PARTICIPANT	\N	PRESENT	0
677670	676189	14259Y	PARTICIPANT	\N	PRESENT	0
677671	676189	19725B	PARTICIPANT	\N	PRESENT	0
677672	676189	14089Y	PARTICIPANT	\N	PRESENT	0
677673	676189	14151M	PARTICIPANT	\N	PRESENT	0
677674	676189	05008E	PARTICIPANT	\N	PRESENT	0
677675	676189	14147R	PARTICIPANT	\N	PRESENT	0
677676	676189	01028R	PARTICIPANT	\N	PRESENT	0
677677	676189	20022R	PARTICIPANT	\N	PRESENT	0
677678	676189	14107H	PARTICIPANT	\N	PRESENT	0
677679	676189	11085T	PARTICIPANT	\N	PRESENT	0
677680	676189	04008A	PARTICIPANT	\N	PRESENT	0
677681	676189	20074E	PARTICIPANT	\N	PRESENT	0
677682	676189	11033F	PARTICIPANT	\N	PRESENT	0
677683	676189	19489J	PARTICIPANT	\N	PRESENT	0
677684	676189	14053L	PARTICIPANT	\N	PRESENT	0
677685	676189	11056N	PARTICIPANT	\N	PRESENT	0
677686	676189	20110Q	PARTICIPANT	\N	PRESENT	0
677687	676189	20114U	PARTICIPANT	\N	PRESENT	0
677688	676189	14069U	PARTICIPANT	\N	PRESENT	0
677689	674845	19593H	PARTICIPANT	\N	PRESENT	0
677690	674845	19643A	PARTICIPANT	\N	PRESENT	0
677691	674845	19699S	PARTICIPANT	\N	PRESENT	0
655486	655485	14205J	PARTICIPANT	\N	PRESENT	0
655487	655485	20092G	PARTICIPANT	\N	PRESENT	0
655671	655496	19954N	PARTICIPANT	\N	PRESENT	0
655672	655496	14089Y	PARTICIPANT	\N	PRESENT	0
655673	655496	17737W	PARTICIPANT	\N	PRESENT	0
655676	655674	11066Q	PARTICIPANT	\N	PRESENT	0
656278	656265	19569H	PARTICIPANT	\N	PRESENT	0
656279	656265	19679N	PARTICIPANT	\N	PRESENT	0
656280	656265	20130U	PARTICIPANT	\N	PRESENT	0
656281	656266	19569H	PARTICIPANT	\N	PRESENT	0
656282	656266	20130U	PARTICIPANT	\N	PRESENT	0
656283	656266	19679N	PARTICIPANT	\N	PRESENT	0
656721	656159	11045K	PARTICIPANT	\N	PRESENT	0
656722	656159	17965H	PARTICIPANT	\N	PRESENT	0
668188	667719	14083S	PARTICIPANT	\N	PRESENT	0
668189	667719	08009T	PARTICIPANT	\N	PRESENT	0
668190	667719	19683J	PARTICIPANT	\N	PRESENT	0
668191	667719	19649G	PARTICIPANT	\N	PRESENT	0
668192	667719	08060W	PARTICIPANT	\N	PRESENT	0
668193	667719	18193Q	PARTICIPANT	\N	PRESENT	0
668194	667719	04059M	PARTICIPANT	\N	PRESENT	0
668195	667719	04057K	PARTICIPANT	\N	PRESENT	0
668196	667719	19619A	PARTICIPANT	\N	PRESENT	0
668197	667719	14225N	PARTICIPANT	\N	PRESENT	0
668198	667719	19820Y	PARTICIPANT	\N	PRESENT	0
668199	667719	19637C	PARTICIPANT	\N	PRESENT	0
668200	667719	20030R	PARTICIPANT	\N	PRESENT	0
668201	667719	17965H	PARTICIPANT	\N	PRESENT	0
668202	667719	20018V	PARTICIPANT	\N	PRESENT	0
668203	667719	14327T	PARTICIPANT	\N	PRESENT	0
668204	667719	08047A	PARTICIPANT	\N	PRESENT	0
668205	667719	11043H	PARTICIPANT	\N	PRESENT	0
668206	667719	19673G	PARTICIPANT	\N	PRESENT	0
668207	667719	14187A	PARTICIPANT	\N	PRESENT	0
668208	667719	14195A	PARTICIPANT	\N	PRESENT	0
668209	667719	11064N	PARTICIPANT	\N	PRESENT	0
668210	667719	14211G	PARTICIPANT	\N	PRESENT	0
668211	667719	17023S	PARTICIPANT	\N	PRESENT	0
668212	667719	19251M	PARTICIPANT	\N	PRESENT	0
668213	667719	20080C	PARTICIPANT	\N	PRESENT	0
668214	667719	14121F	PARTICIPANT	\N	PRESENT	0
668215	667719	20060X	PARTICIPANT	\N	PRESENT	0
668216	667719	20092G	PARTICIPANT	\N	PRESENT	0
668217	667719	20100N	PARTICIPANT	\N	PRESENT	0
668218	667719	19711U	PARTICIPANT	\N	PRESENT	0
668219	667719	19575F	PARTICIPANT	\N	PRESENT	0
668220	667719	99004R	PARTICIPANT	\N	PRESENT	0
668221	667719	04047H	PARTICIPANT	\N	PRESENT	0
668222	667719	08010L	PARTICIPANT	\N	PRESENT	0
668223	667719	18083K	PARTICIPANT	\N	PRESENT	0
668224	667719	19643A	PARTICIPANT	\N	PRESENT	0
668225	667719	10015M	PARTICIPANT	\N	PRESENT	0
668226	667719	08069G	PARTICIPANT	\N	PRESENT	0
668227	667719	20098N	PARTICIPANT	\N	PRESENT	0
668228	667719	20038A	PARTICIPANT	\N	PRESENT	0
668229	667719	19573D	PARTICIPANT	\N	PRESENT	0
668230	667719	19467C	PARTICIPANT	\N	PRESENT	0
668231	667719	19723Y	PARTICIPANT	\N	PRESENT	0
668232	667719	19709B	PARTICIPANT	\N	PRESENT	0
668233	667719	20044X	PARTICIPANT	\N	PRESENT	0
668234	667719	14038Y	PARTICIPANT	\N	PRESENT	0
668235	667719	20056C	PARTICIPANT	\N	PRESENT	0
668236	667719	20022R	PARTICIPANT	\N	PRESENT	0
668237	667719	19657G	PARTICIPANT	\N	PRESENT	0
668238	667719	07029T	PARTICIPANT	\N	PRESENT	0
668239	667719	14033T	PARTICIPANT	\N	PRESENT	0
668240	667719	19667J	PARTICIPANT	\N	PRESENT	0
668241	667719	11115U	PARTICIPANT	\N	PRESENT	0
668242	667719	19515S	PARTICIPANT	\N	PRESENT	0
668243	667719	11080N	PARTICIPANT	\N	PRESENT	0
668244	667719	19766L	PARTICIPANT	\N	PRESENT	0
668245	667719	14259Y	PARTICIPANT	\N	PRESENT	0
668246	667719	01057W	PARTICIPANT	\N	PRESENT	0
668247	667719	19729F	PARTICIPANT	\N	PRESENT	0
668248	667719	01048V	PARTICIPANT	\N	PRESENT	0
668249	667719	11090Q	PARTICIPANT	\N	PRESENT	0
668250	667719	05012A	PARTICIPANT	\N	PRESENT	0
668251	667719	20068G	PARTICIPANT	\N	PRESENT	0
668252	667719	14253S	PARTICIPANT	\N	PRESENT	0
668253	667719	20108W	PARTICIPANT	\N	PRESENT	0
668254	667719	20148F	PARTICIPANT	\N	PRESENT	0
668255	667719	20024T	PARTICIPANT	\N	PRESENT	0
668256	667719	19768N	PARTICIPANT	\N	PRESENT	0
668257	667719	08015R	PARTICIPANT	\N	PRESENT	0
668258	667719	20086J	PARTICIPANT	\N	PRESENT	0
668259	667719	19954N	PARTICIPANT	\N	PRESENT	0
668260	667719	14213J	PARTICIPANT	\N	PRESENT	0
668261	667719	14329V	PARTICIPANT	\N	PRESENT	0
668262	667719	20062A	PARTICIPANT	\N	PRESENT	0
668263	667719	19687N	PARTICIPANT	\N	PRESENT	0
668264	667719	19758L	PARTICIPANT	\N	PRESENT	0
668265	667719	14357A	PARTICIPANT	\N	PRESENT	0
668266	667719	20124W	PARTICIPANT	\N	PRESENT	0
668267	667719	20126Y	PARTICIPANT	\N	PRESENT	0
668268	667719	20152B	PARTICIPANT	\N	PRESENT	0
668269	667719	14071N	PARTICIPANT	\N	PRESENT	0
668270	667719	20252E	PARTICIPANT	\N	PRESENT	0
668271	667719	20120S	PARTICIPANT	\N	PRESENT	0
668272	667719	14217N	PARTICIPANT	\N	PRESENT	0
668273	667719	04085P	PARTICIPANT	\N	PRESENT	0
668274	667719	20136B	PARTICIPANT	\N	PRESENT	0
668275	667719	11077T	PARTICIPANT	\N	PRESENT	0
668276	667719	20046A	PARTICIPANT	\N	PRESENT	0
668277	667719	19593H	PARTICIPANT	\N	PRESENT	0
668278	667719	04043D	PARTICIPANT	\N	PRESENT	0
668279	667719	20118Y	PARTICIPANT	\N	PRESENT	0
668280	667719	14105F	PARTICIPANT	\N	PRESENT	0
668281	667719	14169X	PARTICIPANT	\N	PRESENT	0
668282	667719	19533U	PARTICIPANT	\N	PRESENT	0
668283	667719	10006L	PARTICIPANT	\N	PRESENT	0
668284	667719	14237S	PARTICIPANT	\N	PRESENT	0
668285	667719	14193X	PARTICIPANT	\N	PRESENT	0
668286	667719	14215L	PARTICIPANT	\N	PRESENT	0
668287	667719	19421M	PARTICIPANT	\N	PRESENT	0
668288	667719	14069U	PARTICIPANT	\N	PRESENT	0
668289	667719	04033B	PARTICIPANT	\N	PRESENT	0
668290	667719	05008E	PARTICIPANT	\N	PRESENT	0
668291	667719	11097X	PARTICIPANT	\N	PRESENT	0
668292	667719	19747H	PARTICIPANT	\N	PRESENT	0
668293	667719	11048N	PARTICIPANT	\N	PRESENT	0
668294	667719	14026U	PARTICIPANT	\N	PRESENT	0
668295	667719	11101A	PARTICIPANT	\N	PRESENT	0
668296	667719	19703U	PARTICIPANT	\N	PRESENT	0
668297	667719	08011M	PARTICIPANT	\N	PRESENT	0
668298	667719	19679N	PARTICIPANT	\N	PRESENT	0
668299	667719	20076G	PARTICIPANT	\N	PRESENT	0
668300	667719	04042C	PARTICIPANT	\N	PRESENT	0
668301	667719	14031R	PARTICIPANT	\N	PRESENT	0
668302	667719	20112S	PARTICIPANT	\N	PRESENT	0
668303	667719	20138D	PARTICIPANT	\N	PRESENT	0
668304	667719	20172F	PARTICIPANT	\N	PRESENT	0
668305	667719	01058X	PARTICIPANT	\N	PRESENT	0
668306	667719	20914V	PARTICIPANT	\N	PRESENT	0
668307	667719	11065P	PARTICIPANT	\N	PRESENT	0
668308	667719	20134Y	PARTICIPANT	\N	PRESENT	0
668309	667719	19762G	PARTICIPANT	\N	PRESENT	0
668310	667719	19347U	PARTICIPANT	\N	PRESENT	0
668311	667719	20142Y	PARTICIPANT	\N	PRESENT	0
668312	667719	19383Y	PARTICIPANT	\N	PRESENT	0
668313	667719	20130U	PARTICIPANT	\N	PRESENT	0
668314	667719	19651A	PARTICIPANT	\N	PRESENT	0
668315	667719	20058E	PARTICIPANT	\N	PRESENT	0
668316	667719	19057M	PARTICIPANT	\N	PRESENT	0
668317	667719	19447X	PARTICIPANT	\N	PRESENT	0
668318	667719	19782L	PARTICIPANT	\N	PRESENT	0
668319	667719	20016T	PARTICIPANT	\N	PRESENT	0
668320	667719	19525U	PARTICIPANT	\N	PRESENT	0
668321	667719	20128B	PARTICIPANT	\N	PRESENT	0
668322	667719	19329S	PARTICIPANT	\N	PRESENT	0
668323	667719	19697Q	PARTICIPANT	\N	PRESENT	0
668324	667719	20146D	PARTICIPANT	\N	PRESENT	0
668325	667719	08061X	PARTICIPANT	\N	PRESENT	0
668326	667719	95063L	PARTICIPANT	\N	PRESENT	0
668327	667719	20106U	PARTICIPANT	\N	PRESENT	0
668328	667719	19349W	PARTICIPANT	\N	PRESENT	0
668329	667719	04045F	PARTICIPANT	\N	PRESENT	0
668330	667719	11033F	PARTICIPANT	\N	PRESENT	0
668331	667719	20116W	PARTICIPANT	\N	PRESENT	0
668332	667719	14207L	PARTICIPANT	\N	PRESENT	0
668334	667719	19387D	PARTICIPANT	\N	PRESENT	0
673355	672997	17637T	PARTICIPANT	\N	PRESENT	0
673356	672997	08011M	PARTICIPANT	\N	PRESENT	0
673357	672997	11080N	PARTICIPANT	\N	PRESENT	0
673358	672571	20086J	PARTICIPANT	\N	PRESENT	0
673359	672571	19479G	PARTICIPANT	\N	PRESENT	0
673360	672571	20044X	PARTICIPANT	\N	PRESENT	0
673361	672571	20040T	PARTICIPANT	\N	PRESENT	0
673362	672571	14253S	PARTICIPANT	\N	PRESENT	0
673363	672571	19631V	PARTICIPANT	\N	PRESENT	0
673364	672571	14173T	PARTICIPANT	\N	PRESENT	0
673365	672571	19545Y	PARTICIPANT	\N	PRESENT	0
673366	672571	14225N	PRESIDENT	0	PRESENT	0
673367	672571	19741B	PARTICIPANT	\N	PRESENT	0
673368	672571	20116W	PARTICIPANT	\N	PRESENT	0
673369	672571	20914V	PARTICIPANT	\N	PRESENT	0
673370	672571	19335Q	PARTICIPANT	\N	PRESENT	0
673371	672571	14111D	PARTICIPANT	\N	PRESENT	0
673372	672571	14327T	PARTICIPANT	\N	PRESENT	0
675111	674844	19593H	PARTICIPANT	\N	PRESENT	0
673681	672571	01057W	PARTICIPANT	\N	PRESENT	0
673682	672571	11074Q	PARTICIPANT	\N	PRESENT	0
673683	672571	19667J	PARTICIPANT	\N	PRESENT	0
673684	672571	07029T	PARTICIPANT	\N	PRESENT	0
673685	672571	20126Y	PARTICIPANT	\N	PRESENT	0
673686	672571	11048N	PARTICIPANT	\N	PRESENT	0
673687	672571	19531S	PARTICIPANT	\N	PRESENT	0
673688	672571	99004R	PARTICIPANT	\N	PRESENT	0
673689	672571	20070A	PARTICIPANT	\N	PRESENT	0
673690	672571	20080C	PARTICIPANT	\N	PRESENT	0
673691	672571	08034U	PARTICIPANT	\N	PRESENT	0
673692	672571	14083S	PARTICIPANT	\N	PRESENT	0
673693	672571	11012A	PARTICIPANT	\N	PRESENT	0
674064	670750	20140W	PARTICIPANT	\N	PRESENT	0
675113	674844	14331P	PARTICIPANT	\N	PRESENT	0
675128	674844	14001X	PARTICIPANT	\N	PRESENT	0
675130	674844	19725B	PARTICIPANT	\N	PRESENT	0
675132	674844	11101A	PARTICIPANT	\N	PRESENT	0
675137	674844	20128B	PARTICIPANT	\N	PRESENT	0
675140	674844	10015M	PARTICIPANT	\N	PRESENT	0
675143	674844	19531S	PARTICIPANT	\N	PRESENT	0
675147	674844	14169X	PARTICIPANT	\N	PRESENT	0
675180	671032	04071H	PARTICIPANT	\N	PRESENT	0
675181	671032	14033T	PARTICIPANT	\N	PRESENT	0
675182	671032	19741B	PARTICIPANT	\N	PRESENT	0
675183	671032	11026G	PARTICIPANT	\N	PRESENT	0
675184	671032	20104S	PARTICIPANT	\N	PRESENT	0
675185	671032	20108W	PARTICIPANT	\N	PRESENT	0
675186	671032	14213J	PARTICIPANT	\N	PRESENT	0
675187	671032	14357A	PARTICIPANT	\N	PRESENT	0
675188	671032	19531S	PARTICIPANT	\N	PRESENT	0
675189	671032	14329V	PARTICIPANT	\N	PRESENT	0
675190	671032	11066Q	PARTICIPANT	\N	PRESENT	0
675191	671032	19675J	PARTICIPANT	\N	PRESENT	0
675192	671032	19383Y	PARTICIPANT	\N	PRESENT	0
675193	671032	19762G	PARTICIPANT	\N	PRESENT	0
675194	671032	20020P	PARTICIPANT	\N	PRESENT	0
675195	671032	19713W	PARTICIPANT	\N	PRESENT	0
675196	671032	20038A	PARTICIPANT	\N	PRESENT	0
675197	671032	19543W	PARTICIPANT	\N	PRESENT	0
673723	672571	11053K	PARTICIPANT	\N	PRESENT	0
675198	671032	08018U	PARTICIPANT	\N	PRESENT	0
675199	671032	20052X	PARTICIPANT	\N	PRESENT	0
674094	670750	14223L	PARTICIPANT	\N	PRESENT	0
675200	671032	14275Y	PARTICIPANT	\N	PRESENT	0
675201	671032	19367Y	PARTICIPANT	\N	PRESENT	0
674097	670750	19866P	PARTICIPANT	\N	PRESENT	0
675202	671032	05012A	PARTICIPANT	\N	PRESENT	0
675203	671032	20132W	PARTICIPANT	\N	PRESENT	0
675204	671032	20054A	PARTICIPANT	\N	PRESENT	0
675205	671032	20124W	PARTICIPANT	\N	PRESENT	0
675206	671032	20126Y	PARTICIPANT	\N	PRESENT	0
675207	671032	14059S	PARTICIPANT	\N	PRESENT	0
675208	671032	20062A	PARTICIPANT	\N	PRESENT	0
675209	671032	19745F	PARTICIPANT	\N	PRESENT	0
675210	671032	19691J	PARTICIPANT	\N	PRESENT	0
674107	670750	04045F	PARTICIPANT	\N	PRESENT	0
675211	671032	19707Y	PARTICIPANT	\N	PRESENT	0
675212	671032	19705W	PARTICIPANT	\N	PRESENT	0
675213	671032	19768N	PARTICIPANT	\N	PRESENT	0
675214	671032	20144B	PARTICIPANT	\N	PRESENT	0
674886	670750	20056C	PARTICIPANT	\N	PRESENT	0
675215	671032	19569H	PARTICIPANT	\N	PRESENT	0
675216	671032	08015R	PARTICIPANT	\N	PRESENT	0
675217	671032	19657G	PARTICIPANT	\N	PRESENT	0
675218	671032	14205J	PARTICIPANT	\N	PRESENT	0
675219	671032	07029T	PARTICIPANT	\N	PRESENT	0
675220	671032	19441R	PARTICIPANT	\N	PRESENT	0
675221	671032	19335Q	PARTICIPANT	\N	PRESENT	0
675222	671032	20040T	PARTICIPANT	\N	PRESENT	0
675223	671032	20248J	PARTICIPANT	\N	PRESENT	0
675224	671032	20148F	PARTICIPANT	\N	PRESENT	0
675225	671032	14231L	PARTICIPANT	\N	PRESENT	0
675226	671032	17229F	PARTICIPANT	\N	PRESENT	0
675227	671032	16685X	PARTICIPANT	\N	PRESENT	0
675228	671032	19721W	PARTICIPANT	\N	PRESENT	0
675229	671032	19735D	PARTICIPANT	\N	PRESENT	0
675230	671032	19577H	PARTICIPANT	\N	PRESENT	0
675231	671032	20066E	PARTICIPANT	\N	PRESENT	0
675232	671032	04070G	PARTICIPANT	\N	PRESENT	0
675233	671032	08009T	PARTICIPANT	\N	PRESENT	0
675234	671032	19369B	PARTICIPANT	\N	PRESENT	0
675235	671032	11053K	PARTICIPANT	\N	PRESENT	0
675236	671032	01024M	PARTICIPANT	\N	PRESENT	0
673767	672571	19349W	PARTICIPANT	\N	PRESENT	0
675237	671032	01043Q	PARTICIPANT	\N	PRESENT	0
673769	672571	20252E	PARTICIPANT	\N	PRESENT	0
675238	671032	14030Q	PARTICIPANT	\N	PRESENT	0
673771	672571	01048V	PARTICIPANT	\N	PRESENT	0
675239	671032	14327T	PARTICIPANT	\N	PRESENT	0
675240	671032	14083S	PARTICIPANT	\N	PRESENT	0
675241	671032	14219Q	PARTICIPANT	\N	PRESENT	0
675242	671032	14042U	PARTICIPANT	\N	PRESENT	0
675243	671032	01060R	PARTICIPANT	\N	PRESENT	0
673777	672571	19671E	PARTICIPANT	\N	PRESENT	0
675244	671032	20116W	PARTICIPANT	\N	PRESENT	0
675245	671032	19057M	PARTICIPANT	\N	PRESENT	0
673780	672571	14189C	PARTICIPANT	\N	EXCUSE	0
675246	671032	20128B	PARTICIPANT	\N	PRESENT	0
675247	671032	20106U	PARTICIPANT	\N	PRESENT	0
675248	671032	19719D	PARTICIPANT	\N	PRESENT	0
675249	671032	14251Q	PARTICIPANT	\N	PRESENT	0
673785	672571	14053L	PARTICIPANT	\N	PRESENT	0
675250	671032	20122U	PARTICIPANT	\N	PRESENT	0
675251	671032	19347U	PARTICIPANT	\N	PRESENT	0
675252	671032	11070L	PARTICIPANT	\N	PRESENT	0
675253	671032	11097X	PARTICIPANT	\N	PRESENT	0
675254	671032	04045F	PARTICIPANT	\N	PRESENT	0
675255	671032	19387D	PARTICIPANT	\N	PRESENT	0
675256	671032	20064C	PARTICIPANT	\N	PRESENT	0
675258	671032	20266L	PARTICIPANT	\N	PRESENT	0
675259	671032	20914V	PARTICIPANT	\N	PRESENT	0
675260	671032	19717B	PARTICIPANT	\N	PRESENT	0
673796	673034	14030Q	PARTICIPANT	\N	PRESENT	0
673797	673034	19367Y	PARTICIPANT	\N	PRESENT	0
673798	673034	20138D	PARTICIPANT	\N	PRESENT	0
673799	673034	19643A	PARTICIPANT	\N	PRESENT	0
673800	673034	17737W	PARTICIPANT	\N	PRESENT	0
673801	673034	14255U	PARTICIPANT	\N	PRESENT	0
675261	671032	19669L	PARTICIPANT	\N	PRESENT	0
673803	673034	11056N	PARTICIPANT	\N	PRESENT	0
673804	673034	10006L	PARTICIPANT	\N	PRESENT	0
673805	673034	20248J	PARTICIPANT	\N	PRESENT	0
673806	673034	20124W	PARTICIPANT	\N	PRESENT	0
673807	673034	99004R	PARTICIPANT	\N	PRESENT	0
673808	673034	14179A	PARTICIPANT	\N	PRESENT	0
673809	673034	20052X	PARTICIPANT	\N	PRESENT	0
673810	673034	14223L	PARTICIPANT	\N	PRESENT	0
673811	673034	04070G	PARTICIPANT	\N	PRESENT	0
673812	673034	19573D	PARTICIPANT	\N	PRESENT	0
673813	673034	10015M	PARTICIPANT	\N	PRESENT	0
673814	673034	11043H	PARTICIPANT	\N	PRESENT	0
673815	673034	04045F	PARTICIPANT	\N	PRESENT	0
675262	671032	20084G	PARTICIPANT	\N	PRESENT	0
675263	671032	14229S	PARTICIPANT	\N	PRESENT	0
675264	671032	14249W	PARTICIPANT	\N	PRESENT	0
675265	671032	19711U	PARTICIPANT	\N	PRESENT	0
675266	671032	11048N	PARTICIPANT	\N	PRESENT	0
675267	671032	14267Y	PARTICIPANT	\N	PRESENT	0
675268	671032	17023S	PARTICIPANT	\N	PRESENT	0
675269	674844	19575F	PARTICIPANT	\N	EXCUSE	0
675270	674844	20082E	PARTICIPANT	\N	EXCUSE	0
655687	655686	17737W	PARTICIPANT	\N	PRESENT	0
655688	655686	19709B	PARTICIPANT	\N	PRESENT	0
655689	655686	11026G	PARTICIPANT	\N	PRESENT	0
655691	655690	17737W	PARTICIPANT	\N	PRESENT	0
655692	655690	19709B	PARTICIPANT	\N	PRESENT	0
655694	655693	17737W	PARTICIPANT	\N	PRESENT	0
655708	655707	11072N	PARTICIPANT	\N	PRESENT	0
655710	655709	11072N	PARTICIPANT	\N	PRESENT	0
656209	656208	17737W	PARTICIPANT	\N	PRESENT	0
656210	656208	11026G	PARTICIPANT	\N	PRESENT	0
656211	656208	01048V	PARTICIPANT	\N	PRESENT	0
656212	656208	04035D	PARTICIPANT	\N	PRESENT	0
656213	656208	19503N	PARTICIPANT	\N	PRESENT	0
656214	656208	19713W	PARTICIPANT	\N	PRESENT	0
656216	656157	19954N	PARTICIPANT	\N	EXCUSE	0
656217	656157	11040E	PARTICIPANT	\N	EXCUSE	0
659658	659408	19717B	PRESIDENT	0	PRESENT	0
659659	659408	20034V	PARTICIPANT	\N	PRESENT	0
659660	659408	14059S	PARTICIPANT	\N	EXCUSE	0
659662	659661	11083R	PARTICIPANT	\N	PRESENT	0
661909	661908	11104D	PARTICIPANT	\N	PRESENT	0
661910	661908	19527W	PARTICIPANT	\N	PRESENT	0
662933	662932	97011G	PARTICIPANT	\N	PRESENT	0
662934	662932	11026G	PARTICIPANT	\N	PRESENT	0
662935	662932	20252E	PARTICIPANT	\N	PRESENT	0
662936	662932	19798U	PARTICIPANT	\N	PRESENT	0
662937	662932	20024T	PARTICIPANT	\N	PRESENT	0
662947	662946	20024T	PARTICIPANT	\N	PRESENT	0
662948	662946	20080C	PARTICIPANT	\N	PRESENT	0
662949	662946	20116W	PARTICIPANT	\N	PRESENT	0
662950	662946	14083S	PARTICIPANT	\N	PRESENT	0
662951	662946	11027H	PARTICIPANT	\N	PRESENT	0
662952	662946	20124W	PARTICIPANT	\N	PRESENT	0
662953	662946	20106U	PARTICIPANT	\N	PRESENT	0
662954	662946	12016W	PARTICIPANT	\N	PRESENT	0
662955	662946	14225N	PARTICIPANT	\N	PRESENT	1
662956	662946	19619A	PARTICIPANT	\N	PRESENT	0
662957	662946	05012A	PARTICIPANT	\N	PRESENT	0
663150	663149	08018U	PARTICIPANT	\N	PRESENT	0
663151	663149	14073Q	PARTICIPANT	\N	PRESENT	0
663152	663149	11027H	PARTICIPANT	\N	PRESENT	0
663153	663149	20038A	PARTICIPANT	\N	PRESENT	0
663154	663149	20048C	PARTICIPANT	\N	PRESENT	0
663155	663149	08069G	PARTICIPANT	\N	PRESENT	0
663157	663156	14071N	PARTICIPANT	\N	PRESENT	0
663159	663158	14053L	PARTICIPANT	\N	PRESENT	0
663161	663158	11066Q	PARTICIPANT	\N	PRESENT	0
663260	663257	14133K	PARTICIPANT	\N	PRESENT	0
663261	663257	14097Y	PARTICIPANT	\N	PRESENT	0
663299	661259	10006L	PRESIDENT	0	PRESENT	0
663300	661259	19683J	PARTICIPANT	\N	PRESENT	0
663301	661259	14195A	PARTICIPANT	\N	PRESENT	0
663302	661259	20130U	PARTICIPANT	\N	PRESENT	0
663303	661259	19367Y	PARTICIPANT	\N	PRESENT	0
663304	661259	20248J	PARTICIPANT	\N	PRESENT	0
663305	661259	20066E	PARTICIPANT	\N	PRESENT	0
663307	661259	19691J	PARTICIPANT	\N	PRESENT	0
663308	661259	19657G	PARTICIPANT	\N	PRESENT	0
663309	661259	14071N	PARTICIPANT	\N	PRESENT	0
663310	661259	19569H	PARTICIPANT	\N	PRESENT	0
663311	661259	19703U	PARTICIPANT	\N	PRESENT	0
663312	661259	11097X	PARTICIPANT	\N	PRESENT	0
663313	661259	14213J	PARTICIPANT	\N	PRESENT	0
663314	661259	14223L	PARTICIPANT	\N	PRESENT	0
663315	661259	19415P	PARTICIPANT	\N	PRESENT	0
663316	661259	14355X	PARTICIPANT	\N	PRESENT	0
663317	661259	11103C	PARTICIPANT	\N	PRESENT	0
663318	661259	20090E	PARTICIPANT	\N	PRESENT	0
663319	661259	17965H	PARTICIPANT	\N	PRESENT	0
663320	661259	18193Q	PARTICIPANT	\N	PRESENT	0
663321	661259	04092N	PARTICIPANT	\N	PRESENT	0
663322	661259	19717B	PARTICIPANT	\N	PRESENT	0
663323	661259	14042U	PARTICIPANT	\N	PRESENT	0
663324	661259	19713W	PARTICIPANT	\N	PRESENT	0
663325	661259	19798U	PARTICIPANT	\N	PRESENT	0
663326	661259	11067R	PARTICIPANT	\N	PRESENT	0
663330	661259	20040T	PARTICIPANT	\N	PRESENT	0
663345	661259	11045K	PARTICIPANT	\N	PRESENT	0
663346	661259	19679N	PARTICIPANT	\N	PRESENT	0
663350	661259	19329S	PARTICIPANT	\N	PRESENT	0
663352	661259	01034P	PARTICIPANT	\N	EXCUSE	0
663353	661259	11031D	PARTICIPANT	\N	PRESENT	0
663368	661259	04043D	PARTICIPANT	\N	PRESENT	0
663374	661259	19723Y	PARTICIPANT	\N	PRESENT	0
663375	661259	14026U	PARTICIPANT	\N	PRESENT	0
663415	661259	14281W	PARTICIPANT	\N	PRESENT	0
663416	661259	19697Q	PARTICIPANT	\N	PRESENT	0
663417	661259	17779H	PARTICIPANT	\N	PRESENT	0
663454	661259	04057K	PARTICIPANT	\N	PRESENT	0
666333	659563	19745F	PARTICIPANT	\N	PRESENT	0
666343	663458	19533U	PARTICIPANT	\N	PRESENT	0
666344	663458	04033B	PARTICIPANT	\N	PRESENT	0
666345	663458	19573D	PARTICIPANT	\N	PRESENT	0
666346	663458	20112S	PARTICIPANT	\N	PRESENT	0
666347	663458	19527W	PARTICIPANT	\N	PRESENT	0
666348	663458	20134Y	PARTICIPANT	\N	PRESENT	0
666349	663458	19651A	PARTICIPANT	\N	PRESENT	0
666350	663458	20172F	PARTICIPANT	\N	PRESENT	0
666351	663458	20058E	PARTICIPANT	\N	PRESENT	0
666352	663458	04059M	PARTICIPANT	\N	PRESENT	0
666353	663458	14123H	PARTICIPANT	\N	PRESENT	0
666409	664324	08009T	PARTICIPANT	\N	PRESENT	0
666438	664325	20086J	PARTICIPANT	\N	PRESENT	0
666439	664325	07029T	PARTICIPANT	\N	PRESENT	0
666440	664325	01043Q	PARTICIPANT	\N	PRESENT	0
666441	664325	08009T	PARTICIPANT	\N	PRESENT	0
666442	664325	19349W	PARTICIPANT	\N	PRESENT	0
666443	664325	20080C	PARTICIPANT	\N	PRESENT	0
666444	664325	99004R	PARTICIPANT	\N	PRESENT	0
666445	664325	19667J	PARTICIPANT	\N	PRESENT	0
666446	664325	20914V	PARTICIPANT	\N	PRESENT	0
666447	664325	19671E	PARTICIPANT	\N	PRESENT	0
666448	664325	14225N	PRESIDENT	0	PRESENT	0
666449	664325	20150Y	PARTICIPANT	\N	PRESENT	0
666450	665380	19383Y	PARTICIPANT	\N	PRESENT	0
666451	665380	19768N	PARTICIPANT	\N	PRESENT	0
666452	665380	20088L	PARTICIPANT	\N	PRESENT	0
666453	665380	19515S	PARTICIPANT	\N	PRESENT	0
666454	665380	20092G	PARTICIPANT	\N	PRESENT	0
666455	665380	19782L	PARTICIPANT	\N	PRESENT	0
666456	665380	11077T	PARTICIPANT	\N	PRESENT	0
666457	665380	01043Q	PARTICIPANT	\N	PRESENT	0
666458	665380	14357A	PARTICIPANT	\N	PRESENT	0
666459	665380	19441R	PARTICIPANT	\N	PRESENT	0
666460	665380	19413M	PARTICIPANT	\N	PRESENT	0
666461	665380	20082E	PARTICIPANT	\N	PRESENT	0
666462	665380	20094J	PARTICIPANT	\N	PRESENT	0
666463	665380	04045F	PARTICIPANT	\N	PRESENT	0
666464	665380	19866P	PARTICIPANT	\N	PRESENT	0
666465	665380	19631V	PARTICIPANT	\N	PRESENT	0
666466	665380	11099A	PARTICIPANT	\N	PRESENT	0
666467	665380	19705W	PARTICIPANT	\N	PRESENT	0
666468	665380	08015R	PARTICIPANT	\N	PRESENT	0
666469	665380	19575F	PARTICIPANT	\N	PRESENT	0
666470	665380	19369B	PARTICIPANT	\N	PRESENT	0
666471	665380	20018V	PARTICIPANT	\N	PRESENT	0
666472	665380	19563B	PARTICIPANT	\N	PRESENT	0
666473	665380	08028W	PARTICIPANT	\N	PRESENT	0
666474	665380	14329V	PARTICIPANT	\N	PRESENT	0
666475	665380	14037X	PARTICIPANT	\N	PRESENT	0
666476	665380	20028X	PARTICIPANT	\N	PRESENT	0
666477	665380	20030R	PARTICIPANT	\N	PRESENT	0
666478	665380	19467C	PARTICIPANT	\N	PRESENT	0
666479	665380	20034V	PARTICIPANT	\N	PRESENT	0
666480	665380	14187A	PARTICIPANT	\N	PRESENT	0
666481	665380	19695N	PARTICIPANT	\N	PRESENT	0
666482	665380	14033T	PARTICIPANT	\N	PRESENT	0
666483	665380	01025N	PARTICIPANT	\N	PRESENT	0
666484	665380	11090Q	PRESIDENT	0	PRESENT	0
666485	665380	20054A	PARTICIPANT	\N	PRESENT	0
666486	665380	14205J	PARTICIPANT	\N	PRESENT	0
666487	665380	20060X	PARTICIPANT	\N	PRESENT	0
666488	665380	20062A	PARTICIPANT	\N	PRESENT	0
666489	665380	14251Q	PARTICIPANT	\N	PRESENT	0
666490	665380	19507S	PARTICIPANT	\N	PRESENT	0
666491	665380	20286Q	PARTICIPANT	\N	PRESENT	0
666492	665380	20298U	PARTICIPANT	\N	PRESENT	0
666493	665380	14207L	PARTICIPANT	\N	PRESENT	0
666494	665380	19747H	PARTICIPANT	\N	PRESENT	0
677692	674845	14073Q	PARTICIPANT	\N	PRESENT	0
677693	674845	19651A	PARTICIPANT	\N	PRESENT	0
677694	674845	19611R	PRESIDENT	0	PRESENT	0
677695	674845	20138D	PARTICIPANT	\N	PRESENT	0
677696	674845	20142Y	PARTICIPANT	\N	PRESENT	0
677697	674845	19693L	PARTICIPANT	\N	PRESENT	0
677698	674845	19399H	PARTICIPANT	\N	PRESENT	0
677699	674845	20052X	PARTICIPANT	\N	PRESENT	0
677700	674845	20152B	PARTICIPANT	\N	PRESENT	0
677701	674845	14229S	PARTICIPANT	\N	PRESENT	0
677702	674845	20098N	PARTICIPANT	\N	PRESENT	0
677703	674845	20056C	PARTICIPANT	\N	PRESENT	0
677704	674845	19735D	PARTICIPANT	\N	PRESENT	0
677705	674845	20112S	PARTICIPANT	\N	PRESENT	0
677706	674845	08012N	PARTICIPANT	\N	PRESENT	0
677707	674845	20026V	PARTICIPANT	\N	PRESENT	0
677708	676189	11010L	PARTICIPANT	\N	PRESENT	0
677709	674845	92040Q	PARTICIPANT	\N	PRESENT	0
677710	674845	20124W	PARTICIPANT	\N	PRESENT	0
677711	674845	19527W	PARTICIPANT	\N	PRESENT	0
677712	674845	20172F	PARTICIPANT	\N	PRESENT	0
677713	674845	14030Q	PARTICIPANT	\N	PRESENT	0
677714	674845	20180F	PARTICIPANT	\N	PRESENT	0
677715	674845	04059M	PARTICIPANT	\N	PRESENT	0
677716	674845	14109K	PARTICIPANT	\N	PRESENT	0
677717	674845	11043H	PARTICIPANT	\N	PRESENT	0
677718	674845	20084G	PARTICIPANT	\N	PRESENT	0
677719	674845	11109J	PARTICIPANT	\N	EXCUSE	0
677720	676189	14275Y	PARTICIPANT	\N	PRESENT	0
677721	676189	11072N	PARTICIPANT	\N	PRESENT	0
677722	674845	20264J	PARTICIPANT	\N	PRESENT	0
677723	676189	14231L	PARTICIPANT	\N	EXCUSE	0
677754	676086	19333N	PARTICIPANT	\N	PRESENT	0
677755	676086	19701S	PARTICIPANT	\N	PRESENT	0
677756	676086	20136B	PARTICIPANT	\N	PRESENT	0
677757	676086	20038A	PARTICIPANT	\N	PRESENT	0
677758	676086	20076G	PARTICIPANT	\N	PRESENT	0
677759	676086	20140W	PARTICIPANT	\N	PRESENT	0
677760	676086	19387D	PARTICIPANT	\N	PRESENT	0
677761	676086	14219Q	PRESIDENT	0	PRESENT	0
677762	676086	19820Y	PARTICIPANT	\N	PRESENT	0
677763	676086	19826F	PARTICIPANT	\N	PRESENT	0
677764	676086	20046A	PARTICIPANT	\N	PRESENT	0
677765	676086	19599P	PARTICIPANT	\N	PRESENT	0
677766	676086	20096L	PARTICIPANT	\N	PRESENT	0
677767	676086	17229F	PARTICIPANT	\N	PRESENT	0
677768	676086	19637C	PARTICIPANT	\N	PRESENT	0
677769	676086	18083K	PARTICIPANT	\N	PRESENT	0
677770	676086	20100N	PARTICIPANT	\N	PRESENT	0
677771	676086	08060W	PARTICIPANT	\N	PRESENT	0
677772	676086	20118Y	PARTICIPANT	\N	PRESENT	0
677773	676086	20068G	PARTICIPANT	\N	PRESENT	0
677774	676086	19503N	PARTICIPANT	\N	PRESENT	0
677775	676086	19659J	PARTICIPANT	\N	PRESENT	0
677776	676086	19577H	PARTICIPANT	\N	PRESENT	0
677777	676086	19525U	PARTICIPANT	\N	PRESENT	0
677779	676086	20020P	PARTICIPANT	\N	PRESENT	0
677780	676086	11101A	PARTICIPANT	\N	PRESENT	0
677783	676086	19251M	PARTICIPANT	\N	PRESENT	0
677785	676189	19543W	PARTICIPANT	\N	PRESENT	0
677786	676189	14111D	PARTICIPANT	\N	PRESENT	0
677787	676086	19551W	PARTICIPANT	\N	PRESENT	0
677788	676086	20024T	PARTICIPANT	\N	PRESENT	0
677789	676086	20032T	PARTICIPANT	\N	PRESENT	0
677790	676086	20146D	PARTICIPANT	\N	PRESENT	0
677791	676086	14169X	PARTICIPANT	\N	PRESENT	0
677792	676086	14031R	PARTICIPANT	\N	PRESENT	0
677793	676086	08009T	PARTICIPANT	\N	PRESENT	0
677794	676086	20102Q	PARTICIPANT	\N	EXCUSE	0
677795	676189	19649G	PARTICIPANT	\N	PRESENT	0
677798	676086	05012A	PARTICIPANT	\N	PRESENT	0
677799	676086	19549D	PARTICIPANT	\N	PRESENT	0
677800	676086	14237S	PARTICIPANT	\N	PRESENT	0
677802	676319	11080N	PARTICIPANT	\N	PRESENT	0
677803	676319	20072C	PARTICIPANT	\N	PRESENT	0
677804	676319	11041F	PARTICIPANT	\N	PRESENT	0
677805	676319	11027H	PARTICIPANT	\N	PRESENT	0
677806	676319	04042C	PRESIDENT	0	PRESENT	0
677807	676319	11054L	PARTICIPANT	\N	PRESENT	0
677808	676319	01024M	PARTICIPANT	\N	PRESENT	0
677809	676319	11066Q	PARTICIPANT	\N	PRESENT	0
677810	676319	12028B	PARTICIPANT	\N	PRESENT	0
677811	676319	19319Q	PARTICIPANT	\N	PRESENT	0
677812	676319	98022P	PARTICIPANT	\N	PRESENT	0
677813	676319	14267Y	PARTICIPANT	\N	PRESENT	0
677814	676319	19583F	PARTICIPANT	\N	PRESENT	0
677816	676189	04085P	PARTICIPANT	\N	PRESENT	0
677817	676086	11065P	PARTICIPANT	\N	PRESENT	0
677818	676086	20044X	PARTICIPANT	\N	PRESENT	0
677819	674845	19766L	PARTICIPANT	\N	PRESENT	0
677820	674845	19533U	PARTICIPANT	\N	PRESENT	0
677821	674845	19573D	PARTICIPANT	\N	PRESENT	0
677822	674845	20132W	PARTICIPANT	\N	PRESENT	0
677823	674845	20134Y	PARTICIPANT	\N	PRESENT	0
677824	674845	19719D	PARTICIPANT	\N	PRESENT	0
677825	674845	20058E	PARTICIPANT	\N	PRESENT	0
677826	674845	14123H	PARTICIPANT	\N	PRESENT	0
677827	674845	11104D	PARTICIPANT	\N	PRESENT	0
677829	676086	19681G	PARTICIPANT	\N	PRESENT	0
677866	676319	20128B	PARTICIPANT	\N	PRESENT	0
677867	674845	20048C	PARTICIPANT	\N	PRESENT	0
677868	676086	20106U	PARTICIPANT	\N	PRESENT	0
677869	676189	04047H	PRESIDENT	1	PRESENT	0
677870	676086	14221J	PARTICIPANT	\N	PRESENT	0
677872	676086	20120S	PARTICIPANT	\N	PRESENT	0
677873	674845	19621T	PARTICIPANT	\N	PRESENT	0
677874	676319	11083R	PARTICIPANT	\N	PRESENT	0
677877	676319	17023S	PARTICIPANT	\N	PRESENT	0
677878	676427	19719D	PARTICIPANT	\N	PRESENT	0
677879	676086	19619A	PARTICIPANT	\N	PRESENT	0
677985	677483	19383Y	PARTICIPANT	\N	PRESENT	0
677986	677483	20088L	PARTICIPANT	\N	PRESENT	0
677987	677483	19768N	PARTICIPANT	\N	PRESENT	0
677988	677483	19515S	PARTICIPANT	\N	PRESENT	0
677989	677483	19782L	PARTICIPANT	\N	PRESENT	0
677990	677483	11077T	PARTICIPANT	\N	PRESENT	0
677991	677483	20092G	PARTICIPANT	\N	PRESENT	0
677992	677483	01043Q	PARTICIPANT	\N	PRESENT	0
677993	677483	14357A	PARTICIPANT	\N	PRESENT	0
677994	677483	20078J	PARTICIPANT	\N	PRESENT	0
677995	677483	19441R	PARTICIPANT	\N	PRESENT	0
677996	677483	19413M	PARTICIPANT	\N	PRESENT	0
677997	677483	20094J	PARTICIPANT	\N	PRESENT	0
677998	677483	04045F	PARTICIPANT	\N	PRESENT	0
677999	677483	19866P	PARTICIPANT	\N	PRESENT	0
678000	677483	19631V	PARTICIPANT	\N	PRESENT	0
678001	677483	11099A	PARTICIPANT	\N	PRESENT	0
678002	677483	19705W	PARTICIPANT	\N	PRESENT	0
678003	677483	19707Y	PARTICIPANT	\N	PRESENT	0
678004	677483	08015R	PARTICIPANT	\N	PRESENT	0
678005	677483	19575F	PARTICIPANT	\N	PRESENT	0
678006	677483	19369B	PARTICIPANT	\N	PRESENT	0
678007	677483	20018V	PARTICIPANT	\N	PRESENT	0
678008	677483	19563B	PARTICIPANT	\N	PRESENT	0
678009	677483	20028X	PARTICIPANT	\N	PRESENT	0
678010	677483	14329V	PARTICIPANT	\N	PRESENT	0
678011	677483	14037X	PARTICIPANT	\N	PRESENT	0
678012	677483	20030R	PARTICIPANT	\N	PRESENT	0
678013	677483	14038Y	PARTICIPANT	\N	PRESENT	0
678014	677483	19467C	PARTICIPANT	\N	PRESENT	0
678015	677483	20034V	PARTICIPANT	\N	PRESENT	0
678016	677483	14187A	PARTICIPANT	\N	PRESENT	0
678017	677483	20144B	PARTICIPANT	\N	PRESENT	0
678018	677483	14033T	PARTICIPANT	\N	PRESENT	0
678019	677483	01025N	PARTICIPANT	\N	PRESENT	0
678020	677483	11090Q	PRESIDENT	0	PRESENT	0
678021	677483	20054A	PARTICIPANT	\N	PRESENT	0
678022	677483	20060X	PARTICIPANT	\N	PRESENT	0
678023	677483	20062A	PARTICIPANT	\N	PRESENT	0
678024	677483	19507S	PARTICIPANT	\N	PRESENT	0
678025	677483	20286Q	PARTICIPANT	\N	PRESENT	0
678026	677483	20298U	PARTICIPANT	\N	PRESENT	0
678027	677483	14207L	PARTICIPANT	\N	PRESENT	0
678028	677483	19747H	PARTICIPANT	\N	PRESENT	0
678029	677483	14257W	PARTICIPANT	\N	PRESENT	0
678036	676427	04043D	PARTICIPANT	\N	PRESENT	0
678037	676427	17637T	PARTICIPANT	\N	PRESENT	0
678038	676427	01043Q	PARTICIPANT	\N	PRESENT	0
678039	676427	19631V	PARTICIPANT	\N	PRESENT	0
678040	676427	19533U	PARTICIPANT	\N	PRESENT	0
678041	676427	20150Y	PARTICIPANT	\N	PRESENT	0
658052	656878	14147R	PARTICIPANT	\N	PRESENT	0
658889	658888	01043Q	PARTICIPANT	\N	PRESENT	0
658890	658888	20086J	PARTICIPANT	\N	PRESENT	0
658891	658888	20024T	PARTICIPANT	\N	PRESENT	0
658892	658888	14219Q	PARTICIPANT	\N	PRESENT	0
658893	658888	19545Y	PARTICIPANT	\N	PRESENT	0
658894	658888	14259Y	PARTICIPANT	\N	PRESENT	0
658895	658888	20082E	PARTICIPANT	\N	PRESENT	0
658896	658888	19383Y	PARTICIPANT	\N	PRESENT	0
658897	658888	19349W	PARTICIPANT	\N	PRESENT	0
658898	658888	19549D	PARTICIPANT	\N	PRESENT	0
658899	658888	14231L	PARTICIPANT	\N	PRESENT	0
660001	659998	19693L	PARTICIPANT	\N	PRESENT	0
660002	659998	19593H	PARTICIPANT	\N	PRESENT	0
660006	660004	19693L	PARTICIPANT	\N	PRESENT	0
660007	660004	19593H	PARTICIPANT	\N	PRESENT	0
660013	660012	14229S	PARTICIPANT	\N	PRESENT	0
660014	660012	19735D	PARTICIPANT	\N	PRESENT	0
660015	660012	20084G	PARTICIPANT	\N	PRESENT	0
661637	661636	11043H	PARTICIPANT	\N	PRESENT	0
661638	661636	19251M	PARTICIPANT	\N	PRESENT	0
661640	661636	14073Q	PARTICIPANT	\N	PRESENT	0
661641	661636	08012N	PARTICIPANT	\N	PRESENT	0
661642	661636	19349W	PARTICIPANT	\N	PRESENT	0
661643	661636	20024T	PARTICIPANT	\N	PRESENT	0
661644	661636	19954N	PARTICIPANT	\N	PRESENT	0
661645	661636	19575F	PARTICIPANT	\N	PRESENT	0
661646	661636	20138D	PARTICIPANT	\N	PRESENT	0
661647	661636	19643A	PARTICIPANT	\N	PRESENT	0
661648	661636	20132W	PARTICIPANT	\N	PRESENT	0
668336	667719	19553Y	PARTICIPANT	\N	PRESENT	0
668337	667719	20132W	PARTICIPANT	\N	PRESENT	0
668338	667719	11012A	PARTICIPANT	\N	PRESENT	0
668339	667719	19545Y	PARTICIPANT	\N	PRESENT	0
668340	667719	14251Q	PARTICIPANT	\N	PRESENT	0
668341	667719	19563B	PARTICIPANT	\N	PRESENT	0
668343	667719	14221J	PARTICIPANT	\N	PRESENT	0
668344	667719	20050V	PARTICIPANT	\N	PRESENT	0
668345	667719	20122U	PARTICIPANT	\N	PRESENT	0
668347	667719	19631V	PARTICIPANT	\N	PRESENT	0
668348	667719	19549D	PARTICIPANT	\N	PRESENT	0
668350	667719	20114U	PARTICIPANT	\N	PRESENT	0
668352	667719	20070A	PARTICIPANT	\N	PRESENT	0
668353	667719	20264J	PARTICIPANT	\N	PRESENT	0
668355	667719	14151M	PARTICIPANT	\N	PRESENT	0
668357	667719	14281W	PARTICIPANT	\N	PRESENT	0
668359	667719	20140W	PARTICIPANT	\N	PRESENT	0
668362	667719	19531S	PARTICIPANT	\N	PRESENT	0
668363	667719	14021P	PARTICIPANT	\N	PRESENT	0
668364	667719	19647E	PARTICIPANT	\N	PRESENT	0
668365	667719	08012N	PARTICIPANT	\N	PRESENT	0
668366	667719	11045K	PARTICIPANT	\N	PRESENT	0
668367	667719	11054L	PARTICIPANT	\N	PRESENT	0
668368	667719	20094J	PARTICIPANT	\N	PRESENT	0
668369	667719	14257W	PARTICIPANT	\N	PRESENT	0
668370	667719	19503N	PARTICIPANT	\N	PRESENT	0
668371	667719	19333N	PARTICIPANT	\N	PRESENT	0
668372	667719	20266L	PARTICIPANT	\N	PRESENT	0
668373	667719	20084G	PARTICIPANT	\N	PRESENT	0
668374	667719	01028R	PARTICIPANT	\N	PRESENT	0
668375	667719	01062T	PARTICIPANT	\N	PRESENT	0
668376	667719	19527W	PARTICIPANT	\N	PRESENT	0
668377	667719	20064C	PARTICIPANT	\N	PRESENT	0
668378	667719	14030Q	PARTICIPANT	\N	PRESENT	0
668379	667719	14255U	PARTICIPANT	\N	PRESENT	0
668380	667719	11053K	PARTICIPANT	\N	PRESENT	0
668381	667719	19721W	PARTICIPANT	\N	PRESENT	0
668382	667719	11070L	PARTICIPANT	\N	PRESENT	0
668383	667719	01024M	PARTICIPANT	\N	PRESENT	0
668384	667719	19577H	PARTICIPANT	\N	PRESENT	0
668385	667719	17737W	PARTICIPANT	\N	PRESENT	0
668386	667719	14042U	PARTICIPANT	\N	PRESENT	0
668387	667719	20040T	PARTICIPANT	\N	PRESENT	0
668388	667719	01025N	PARTICIPANT	\N	PRESENT	0
668389	667719	14231L	PARTICIPANT	\N	PRESENT	0
668390	667719	19569H	PARTICIPANT	\N	PRESENT	0
668391	667719	20048C	PARTICIPANT	\N	PRESENT	0
668392	667719	19663E	PARTICIPANT	\N	PRESENT	0
668393	667719	20066E	PARTICIPANT	\N	PRESENT	0
668394	667719	14073Q	PARTICIPANT	\N	PRESENT	0
668395	667719	19735D	PARTICIPANT	\N	PRESENT	0
668396	667719	19611R	PARTICIPANT	\N	PRESENT	0
668397	667719	19699S	PARTICIPANT	\N	PRESENT	0
668398	667719	20052X	PARTICIPANT	\N	PRESENT	0
668399	667719	16685X	PARTICIPANT	\N	PRESENT	0
668400	667719	14219Q	PARTICIPANT	\N	PRESENT	0
668401	667719	11085T	PARTICIPANT	\N	PRESENT	0
668402	667719	19335Q	PARTICIPANT	\N	PRESENT	0
668403	667719	19369B	PARTICIPANT	\N	PRESENT	0
668404	667719	19691J	PARTICIPANT	\N	PRESENT	0
668405	667719	04070G	PARTICIPANT	\N	PRESENT	0
668406	667719	19745F	PARTICIPANT	\N	PRESENT	0
668407	667719	19739H	PARTICIPANT	\N	PRESENT	0
668408	667719	20298U	PARTICIPANT	\N	PRESENT	0
668409	667719	19713W	PARTICIPANT	\N	PRESENT	0
668410	667719	01034P	PARTICIPANT	\N	PRESENT	0
668411	667719	19749K	PARTICIPANT	\N	PRESENT	0
668412	667719	14249W	PARTICIPANT	\N	PRESENT	0
668413	667719	14123H	PARTICIPANT	\N	PRESENT	0
668415	667719	11031D	PARTICIPANT	\N	PRESENT	0
668416	667719	19695N	PARTICIPANT	\N	PRESENT	0
668426	667719	01043Q	PARTICIPANT	\N	PRESENT	0
668418	667719	19441R	PARTICIPANT	\N	PRESENT	0
668419	667719	01060R	PARTICIPANT	\N	PRESENT	0
668445	667719	14147R	PARTICIPANT	\N	PRESENT	0
668446	667719	14111D	PARTICIPANT	\N	PRESENT	0
668447	667719	20032T	PARTICIPANT	\N	PRESENT	0
668456	667719	04035D	PARTICIPANT	\N	PRESENT	0
668724	667720	19719D	PARTICIPANT	\N	PRESENT	0
668731	667720	07029T	PARTICIPANT	\N	PRESENT	0
668732	667720	19533U	PARTICIPANT	\N	PRESENT	0
668735	667720	20080C	PARTICIPANT	\N	PRESENT	0
668736	667720	95063L	PARTICIPANT	\N	PRESENT	0
668737	667720	20116W	PARTICIPANT	\N	PRESENT	0
668739	667720	19629C	PARTICIPANT	\N	PRESENT	0
668740	667720	19583F	PARTICIPANT	\N	PRESENT	0
668741	667720	17589D	PARTICIPANT	\N	PRESENT	0
668742	667720	19441R	PARTICIPANT	\N	PRESENT	0
668743	667720	19479G	PARTICIPANT	\N	PRESENT	0
668746	667720	14069U	PARTICIPANT	\N	PRESENT	0
668747	667720	20090E	PARTICIPANT	\N	PRESENT	0
668748	667720	19762G	PARTICIPANT	\N	PRESENT	0
668750	667720	19383Y	PARTICIPANT	\N	PRESENT	0
668751	667720	14033T	PARTICIPANT	\N	PRESENT	0
668752	667720	01057W	PARTICIPANT	\N	PRESENT	0
668753	667720	19515S	PARTICIPANT	\N	PRESENT	0
668754	667720	14083S	PARTICIPANT	\N	PRESENT	0
668755	667720	14327T	PARTICIPANT	\N	PRESENT	0
668756	667720	20914V	PARTICIPANT	\N	PRESENT	0
668757	667720	19647E	PARTICIPANT	\N	PRESENT	0
668759	667720	14021P	PARTICIPANT	\N	PRESENT	0
668762	667720	14042U	PARTICIPANT	\N	PRESENT	0
668764	667720	14225N	PARTICIPANT	\N	PRESENT	0
668765	667720	11048N	PARTICIPANT	\N	PRESENT	0
668766	667720	20126Y	PARTICIPANT	\N	PRESENT	0
668767	667720	19711U	PARTICIPANT	\N	PRESENT	0
668768	667720	04033B	PARTICIPANT	\N	PRESENT	0
668769	667720	01048V	PARTICIPANT	\N	PRESENT	0
668770	667720	20056C	PARTICIPANT	\N	PRESENT	0
668771	667720	01058X	PARTICIPANT	\N	PRESENT	0
668772	667720	19575F	PARTICIPANT	\N	PRESENT	0
668773	667720	11012A	PARTICIPANT	\N	PRESENT	0
668774	667720	19349W	PARTICIPANT	\N	PRESENT	0
668775	667720	19545Y	PARTICIPANT	\N	PRESENT	0
668776	667720	11033F	PARTICIPANT	\N	PRESENT	0
668777	667720	14281W	PARTICIPANT	\N	PRESENT	0
668778	667720	19687N	PARTICIPANT	\N	PRESENT	0
668779	667720	11077T	PARTICIPANT	\N	PRESENT	0
668782	667720	08015R	PARTICIPANT	\N	PRESENT	0
668784	667720	19651A	PARTICIPANT	\N	PRESENT	0
668785	667720	20062A	PARTICIPANT	\N	PRESENT	0
668786	659678	19333N	PARTICIPANT	\N	PRESENT	0
668787	659678	19549D	PARTICIPANT	\N	PRESENT	0
668788	659678	19387D	PARTICIPANT	\N	PRESENT	0
668789	659678	14219Q	PRESIDENT	0	PRESENT	0
668790	659678	19820Y	PARTICIPANT	\N	PRESENT	0
668791	659678	14221J	PARTICIPANT	\N	PRESENT	0
668792	659678	19826F	PARTICIPANT	\N	PRESENT	0
668793	659678	20102Q	PARTICIPANT	\N	PRESENT	0
668794	659678	19599P	PARTICIPANT	\N	PRESENT	0
668795	659678	19637C	PARTICIPANT	\N	PRESENT	0
664798	659562	19739H	PARTICIPANT	\N	PRESENT	0
664800	659562	19515S	PARTICIPANT	\N	PRESENT	0
664801	659562	19707Y	PARTICIPANT	\N	PRESENT	0
664802	659562	19575F	PARTICIPANT	\N	PRESENT	0
664803	659562	20094J	PARTICIPANT	\N	PRESENT	0
664804	659562	19747H	PARTICIPANT	\N	PRESENT	0
664805	659562	19383Y	PARTICIPANT	\N	PRESENT	0
664806	659562	14207L	PARTICIPANT	\N	PRESENT	0
664807	659562	20060X	PARTICIPANT	\N	PRESENT	0
664808	659562	14329V	PARTICIPANT	\N	PRESENT	0
664809	659562	20144B	PARTICIPANT	\N	PRESENT	0
664810	659562	19467C	PARTICIPANT	\N	PRESENT	0
664811	659562	14357A	PARTICIPANT	\N	PRESENT	0
664812	659562	19507S	PARTICIPANT	\N	PRESENT	0
664813	659562	14187A	PARTICIPANT	\N	PRESENT	0
664814	659562	19695N	PARTICIPANT	\N	PRESENT	0
664816	659562	14033T	PARTICIPANT	\N	PRESENT	0
664817	659562	20286Q	PARTICIPANT	\N	PRESENT	0
664818	659562	20034V	PARTICIPANT	\N	PRESENT	0
664819	659562	11099A	PARTICIPANT	\N	PRESENT	0
664820	659562	08015R	PARTICIPANT	\N	PRESENT	0
664821	659562	14037X	PARTICIPANT	\N	PRESENT	0
664822	659562	11077T	PARTICIPANT	\N	PRESENT	0
664823	659562	14205J	PARTICIPANT	\N	PRESENT	0
664824	659562	19441R	PARTICIPANT	\N	PRESENT	0
664825	659562	14251Q	PARTICIPANT	\N	PRESENT	0
664826	659562	19563B	PARTICIPANT	\N	PRESENT	0
664827	659562	14257W	PARTICIPANT	\N	PRESENT	0
664828	659562	19768N	PARTICIPANT	\N	PRESENT	0
664829	659562	19866P	PARTICIPANT	\N	PRESENT	0
664830	659562	20030R	PARTICIPANT	\N	PRESENT	0
664831	659562	11090Q	PARTICIPANT	\N	PRESENT	0
664832	659562	19705W	PARTICIPANT	\N	PRESENT	0
664833	659562	20054A	PARTICIPANT	\N	PRESENT	0
664834	659562	20298U	PARTICIPANT	\N	PRESENT	0
664835	659562	04045F	PARTICIPANT	\N	PRESENT	0
664841	662021	20076G	PARTICIPANT	\N	PRESENT	0
664842	662021	20024T	PARTICIPANT	\N	PRESENT	0
664843	662021	19549D	PARTICIPANT	\N	PRESENT	0
664844	662021	08060W	PARTICIPANT	\N	PRESENT	0
664845	662021	11101A	PARTICIPANT	\N	PRESENT	0
664846	662021	18083K	PARTICIPANT	\N	PRESENT	0
664847	662021	19701S	PARTICIPANT	\N	PRESENT	0
664848	662021	19525U	PARTICIPANT	\N	PRESENT	0
664849	662021	11065P	PARTICIPANT	\N	PRESENT	0
664850	662021	17229F	PARTICIPANT	\N	PRESENT	0
664851	662021	19251M	PARTICIPANT	\N	PRESENT	0
664852	662021	19599P	PARTICIPANT	\N	PRESENT	0
664853	662021	20120S	PARTICIPANT	\N	PRESENT	0
664854	662021	19820Y	PARTICIPANT	\N	PRESENT	0
664855	662021	19387D	PARTICIPANT	\N	PRESENT	0
664856	662021	20068G	PARTICIPANT	\N	PRESENT	0
664857	662021	20106U	PARTICIPANT	\N	PRESENT	0
664858	662021	19685L	PARTICIPANT	\N	PRESENT	0
664859	662021	19333N	PARTICIPANT	\N	PRESENT	0
664860	662021	20102Q	PARTICIPANT	\N	PRESENT	0
664861	662021	14219Q	PARTICIPANT	\N	PRESENT	0
664862	662021	14031R	PARTICIPANT	\N	PRESENT	0
664863	662021	19637C	PARTICIPANT	\N	PRESENT	0
664865	662021	14221J	PARTICIPANT	\N	PRESENT	0
664866	662021	20118Y	PARTICIPANT	\N	PRESENT	0
664867	662021	19503N	PARTICIPANT	\N	PRESENT	0
664868	662021	19739H	PARTICIPANT	\N	PRESENT	0
664869	662021	20020P	PARTICIPANT	\N	PRESENT	0
664870	662021	19619A	PARTICIPANT	\N	PRESENT	0
664871	662021	20136B	PARTICIPANT	\N	PRESENT	0
664872	662021	20046A	PARTICIPANT	\N	PRESENT	0
667605	659563	19826F	PARTICIPANT	\N	EXCUSE	0
675276	671032	11027H	PARTICIPANT	\N	PRESENT	0
675274	671032	20080C	PARTICIPANT	\N	PRESENT	0
673850	672571	14121F	PARTICIPANT	\N	PRESENT	0
673851	672571	08011M	PARTICIPANT	\N	PRESENT	0
673852	672571	19762G	PARTICIPANT	\N	PRESENT	0
675275	671032	19685L	PARTICIPANT	\N	PRESENT	0
675285	672800	14133K	PARTICIPANT	\N	PRESENT	0
675278	671032	01048V	PARTICIPANT	\N	PRESENT	0
675279	671032	19651A	PARTICIPANT	\N	PRESENT	0
675280	671032	20022R	PARTICIPANT	\N	PRESENT	0
675281	672799	19583F	PARTICIPANT	\N	EXCUSE	0
675282	671032	14151M	PARTICIPANT	\N	PRESENT	0
675283	671032	19399H	PARTICIPANT	\N	PRESENT	0
675284	671032	20058E	PARTICIPANT	\N	PRESENT	0
675286	672800	14105F	PARTICIPANT	\N	PRESENT	0
675287	672800	14255U	PARTICIPANT	\N	PRESENT	0
675288	672800	04042C	PRESIDENT	0	PRESENT	0
675271	671032	14053L	PARTICIPANT	\N	PRESENT	0
675272	671032	14255U	PARTICIPANT	\N	PRESENT	0
675295	672800	11115U	PARTICIPANT	\N	PRESENT	0
675290	672800	12028B	PARTICIPANT	\N	PRESENT	0
675291	672800	11080N	PARTICIPANT	\N	PRESENT	0
675292	672800	14267Y	PARTICIPANT	\N	PRESENT	0
675293	671032	14123H	PARTICIPANT	\N	PRESENT	0
675294	672800	19721W	PARTICIPANT	\N	PRESENT	0
675296	672800	01024M	PARTICIPANT	\N	PRESENT	0
675297	672800	14249W	PARTICIPANT	\N	PRESENT	0
675298	672800	17023S	PARTICIPANT	\N	PRESENT	0
675299	672800	04035D	PARTICIPANT	\N	PRESENT	0
675300	672800	11083R	PARTICIPANT	\N	PRESENT	0
675301	672800	19347U	PARTICIPANT	\N	PRESENT	0
675302	672800	08056B	PARTICIPANT	\N	PRESENT	0
675303	672800	14211G	PARTICIPANT	\N	PRESENT	0
675304	672800	19565D	PARTICIPANT	\N	PRESENT	0
675305	672800	11064N	PARTICIPANT	\N	PRESENT	0
675306	672800	20072C	PARTICIPANT	\N	PRESENT	0
675307	672800	20128B	PARTICIPANT	\N	PRESENT	0
675308	672800	08069G	PARTICIPANT	\N	PRESENT	0
675309	672800	95041E	PARTICIPANT	\N	PRESENT	0
675310	672800	19583F	PARTICIPANT	\N	EXCUSE	0
675311	672800	19709B	PARTICIPANT	\N	PRESENT	0
675312	672800	16685X	PARTICIPANT	\N	PRESENT	0
675313	672800	14059S	PARTICIPANT	\N	PRESENT	0
675314	672800	08061X	PARTICIPANT	\N	PRESENT	0
675315	672800	08047A	PARTICIPANT	\N	PRESENT	0
675316	672800	19443T	PARTICIPANT	\N	PRESENT	0
675317	672800	11054L	PARTICIPANT	\N	PRESENT	0
675318	672800	19421M	PARTICIPANT	\N	PRESENT	0
675319	672800	01058X	PARTICIPANT	\N	PRESENT	0
675320	672800	19669L	PARTICIPANT	\N	PRESENT	0
675321	672800	20064C	PARTICIPANT	\N	PRESENT	0
675322	672800	11041F	PARTICIPANT	\N	PRESENT	0
675323	672800	11066Q	PARTICIPANT	\N	PRESENT	0
675324	672800	01062T	PARTICIPANT	\N	EXCUSE	0
675325	672800	14193X	PARTICIPANT	\N	PRESENT	0
675326	672800	14191V	PARTICIPANT	\N	PRESENT	0
675327	672800	12041X	PARTICIPANT	\N	PRESENT	0
675329	671032	19507S	PARTICIPANT	\N	PRESENT	0
675330	671032	08034U	PARTICIPANT	\N	PRESENT	0
675331	671032	20048C	PARTICIPANT	\N	PRESENT	0
675332	672800	98022P	PARTICIPANT	\N	PRESENT	0
675333	672800	11027H	PARTICIPANT	\N	PRESENT	0
675334	671032	14109K	PARTICIPANT	\N	PRESENT	0
675335	671032	20286Q	PARTICIPANT	\N	PRESENT	0
675336	672573	12016W	PARTICIPANT	\N	EXCUSE	0
675630	671033	11045K	PARTICIPANT	\N	PRESENT	0
675631	671033	20132W	PARTICIPANT	\N	PRESENT	0
675632	671033	14225N	PARTICIPANT	\N	PRESENT	0
675633	671033	19820Y	PARTICIPANT	\N	PRESENT	0
675634	671033	20080C	PARTICIPANT	\N	PRESENT	0
675635	671033	19545Y	PARTICIPANT	\N	PRESENT	0
675636	671033	20914V	PARTICIPANT	\N	PRESENT	0
675637	671033	19745F	PARTICIPANT	\N	PRESENT	0
675638	671033	19479G	PARTICIPANT	\N	PRESENT	0
675639	671033	19671E	PARTICIPANT	\N	PRESENT	0
675640	671033	20116W	PARTICIPANT	\N	PRESENT	0
675641	671033	14215L	PARTICIPANT	\N	PRESENT	0
675642	671033	01057W	PARTICIPANT	\N	PRESENT	0
675643	671033	20172F	PARTICIPANT	\N	PRESENT	0
675644	671033	20108W	PARTICIPANT	\N	PRESENT	0
675645	672498	19295A	PARTICIPANT	\N	EXCUSE	0
675646	671033	19667J	PARTICIPANT	\N	PRESENT	0
675647	671033	20070A	PARTICIPANT	\N	PRESENT	0
675648	671033	20036X	PARTICIPANT	\N	PRESENT	0
675649	672496	20130U	PARTICIPANT	\N	PRESENT	0
675650	672496	11067R	PARTICIPANT	\N	PRESENT	0
675651	672496	20090E	PARTICIPANT	\N	PRESENT	0
675652	672496	19798U	PARTICIPANT	\N	PRESENT	0
675653	672496	11097X	PARTICIPANT	\N	PRESENT	0
675654	672496	19415P	PARTICIPANT	\N	PRESENT	0
675655	672496	18193Q	PARTICIPANT	\N	PRESENT	0
675656	672496	19703U	PARTICIPANT	\N	PRESENT	0
675657	672496	20266L	PARTICIPANT	\N	PRESENT	0
675658	672496	19679N	PARTICIPANT	\N	PRESENT	0
666495	665380	14257W	PARTICIPANT	\N	PRESENT	0
666496	664325	14327T	PARTICIPANT	\N	PRESENT	0
666497	664325	11048N	PARTICIPANT	\N	PRESENT	0
666498	664325	19647E	PARTICIPANT	\N	PRESENT	0
666499	664325	19711U	PARTICIPANT	\N	PRESENT	0
666500	664325	01057W	PARTICIPANT	\N	PRESENT	0
666501	664325	19335Q	PARTICIPANT	\N	PRESENT	0
666527	665151	86034E	PARTICIPANT	\N	PRESENT	0
666835	665151	19685L	PARTICIPANT	\N	PRESENT	0
666836	665151	19749K	PARTICIPANT	\N	PRESENT	0
666837	665151	19663E	PARTICIPANT	\N	PRESENT	0
666838	665151	14357A	PARTICIPANT	\N	PRESENT	0
666839	665151	14327T	PARTICIPANT	\N	PRESENT	0
666840	665151	14121F	PARTICIPANT	\N	PRESENT	0
666841	665151	20112S	PARTICIPANT	\N	PRESENT	0
666842	665151	20082E	PARTICIPANT	\N	PRESENT	0
666843	665151	11056N	PARTICIPANT	\N	PRESENT	0
666844	665151	20130U	PARTICIPANT	\N	PRESENT	0
666845	665151	08073C	PARTICIPANT	\N	PRESENT	0
666846	665151	20248J	PARTICIPANT	\N	PRESENT	0
666848	665151	11054L	PARTICIPANT	\N	PRESENT	0
666849	665151	19527W	PARTICIPANT	\N	PRESENT	0
667140	665154	11045K	PARTICIPANT	\N	PRESENT	0
667143	659564	19681G	PARTICIPANT	\N	PRESENT	0
667144	659564	17229F	PARTICIPANT	\N	PRESENT	0
667145	659564	19333N	PARTICIPANT	\N	PRESENT	0
667146	659564	20032T	PARTICIPANT	\N	PRESENT	0
667147	659564	20076G	PARTICIPANT	\N	PRESENT	0
667148	659564	20140W	PARTICIPANT	\N	PRESENT	0
667149	659564	19387D	PARTICIPANT	\N	PRESENT	0
667150	659564	19599P	PARTICIPANT	\N	PRESENT	0
667151	659564	20102Q	PARTICIPANT	\N	PRESENT	0
667152	659564	19525U	PARTICIPANT	\N	PRESENT	0
667153	659564	14237S	PARTICIPANT	\N	PRESENT	0
667154	659564	20046A	PARTICIPANT	\N	PRESENT	0
667158	665154	20914V	PARTICIPANT	\N	PRESENT	0
667159	659564	14031R	PARTICIPANT	\N	PRESENT	0
667160	659564	19820Y	PARTICIPANT	\N	PRESENT	0
667161	659564	19637C	PARTICIPANT	\N	PRESENT	0
667162	659564	19739H	PARTICIPANT	\N	PRESENT	0
667163	659564	19619A	PARTICIPANT	\N	PRESENT	0
667164	665154	20286Q	PARTICIPANT	\N	PRESENT	0
667165	665154	19479G	PARTICIPANT	\N	PRESENT	0
667166	665154	19782L	PARTICIPANT	\N	PRESENT	0
667167	665154	19347U	PARTICIPANT	\N	PRESENT	0
667168	665154	11041F	PARTICIPANT	\N	PRESENT	0
667169	665154	20264J	PARTICIPANT	\N	PRESENT	0
667170	665154	11083R	PARTICIPANT	\N	PRESENT	0
667171	659564	20136B	PARTICIPANT	\N	PRESENT	0
667172	659564	14169X	PARTICIPANT	\N	PRESENT	0
667173	659564	20100N	PARTICIPANT	\N	PRESENT	0
667174	659564	20024T	PARTICIPANT	\N	PRESENT	0
667175	659564	20120S	PARTICIPANT	\N	PRESENT	0
667177	665154	14255U	PARTICIPANT	\N	PRESENT	0
667178	665154	19543W	PARTICIPANT	\N	PRESENT	0
667180	665154	20124W	PARTICIPANT	\N	PRESENT	0
667181	665154	20090E	PARTICIPANT	\N	PRESENT	0
667182	665154	01058X	PARTICIPANT	\N	PRESENT	0
667183	665154	14147R	PARTICIPANT	\N	PRESENT	0
667184	665154	19651A	PARTICIPANT	\N	PRESENT	0
667189	659564	19549D	PARTICIPANT	\N	PRESENT	0
667190	659564	19503N	PARTICIPANT	\N	PRESENT	0
667191	659564	17367Q	PARTICIPANT	\N	PRESENT	0
667192	665154	20266L	PARTICIPANT	\N	PRESENT	0
667193	665154	19443T	PARTICIPANT	\N	PRESENT	0
667194	665154	19669L	PARTICIPANT	\N	PRESENT	0
667195	665154	04085P	PARTICIPANT	\N	PRESENT	0
667196	665154	12028B	PARTICIPANT	\N	PRESENT	0
667197	665154	20082E	PARTICIPANT	\N	PRESENT	0
667198	665154	20030R	PARTICIPANT	\N	PRESENT	0
667199	665154	04057K	PARTICIPANT	\N	PRESENT	0
667200	665154	17023S	PARTICIPANT	\N	PRESENT	0
667201	665154	20072C	PARTICIPANT	\N	PRESENT	0
667202	665154	01062T	PARTICIPANT	\N	PRESENT	0
667203	665154	14105F	PARTICIPANT	\N	PRESENT	0
667204	665154	04042C	PARTICIPANT	\N	PRESENT	0
667213	659564	14219Q	PRESIDENT	0	PRESENT	0
667214	665154	11085T	PARTICIPANT	\N	PRESENT	0
667215	665154	20098N	PARTICIPANT	\N	PRESENT	0
667216	659564	05012A	PARTICIPANT	\N	PRESENT	0
667217	665154	19421M	PARTICIPANT	\N	PRESENT	0
667218	665154	20034V	PARTICIPANT	\N	PRESENT	0
667219	665154	19671E	PARTICIPANT	\N	PRESENT	0
667220	659564	20118Y	PARTICIPANT	\N	PRESENT	0
667221	665154	14033T	PARTICIPANT	\N	PRESENT	0
667222	665154	20142Y	PARTICIPANT	\N	PRESENT	0
667224	665154	14059S	PARTICIPANT	\N	PRESENT	0
667225	665154	20062A	PARTICIPANT	\N	PRESENT	0
667227	665154	20064C	PARTICIPANT	\N	PRESENT	0
667230	665154	11012A	PARTICIPANT	\N	PRESENT	0
667231	665154	20038A	PARTICIPANT	\N	PRESENT	0
667232	665154	19533U	PARTICIPANT	\N	PRESENT	0
667233	665154	14038Y	PARTICIPANT	\N	PRESENT	0
667239	665154	20042V	PARTICIPANT	\N	PRESENT	0
667242	665154	19691J	PARTICIPANT	\N	PRESENT	0
667243	665154	97011G	PARTICIPANT	\N	PRESENT	0
667244	665154	08061X	PARTICIPANT	\N	PRESENT	0
667245	665154	19467C	PARTICIPANT	\N	PRESENT	0
667247	665154	20070A	PARTICIPANT	\N	PRESENT	0
667249	665154	20136B	PARTICIPANT	\N	PRESENT	0
667250	659564	19251M	PARTICIPANT	\N	PRESENT	0
667251	665154	20058E	PARTICIPANT	\N	PRESENT	0
667252	665154	20128B	PARTICIPANT	\N	PRESENT	0
667253	665154	14083S	PARTICIPANT	\N	PRESENT	0
667254	665154	16685X	PARTICIPANT	\N	PRESENT	0
667255	665154	19679N	PARTICIPANT	\N	PRESENT	0
667256	665154	19569H	PARTICIPANT	\N	PRESENT	0
667318	665153	19333N	PARTICIPANT	\N	PRESENT	0
667319	665153	19531S	PARTICIPANT	\N	PRESENT	0
667320	665153	19725B	PARTICIPANT	\N	PRESENT	0
667321	665153	19599P	PARTICIPANT	\N	PRESENT	0
667322	665153	20080C	PARTICIPANT	\N	PRESENT	0
667323	665153	19820Y	PARTICIPANT	\N	PRESENT	0
667324	665153	12041X	PARTICIPANT	\N	PRESENT	0
667325	665153	20084G	PARTICIPANT	\N	PRESENT	0
667326	665153	12028B	PARTICIPANT	\N	PRESENT	0
667327	665153	20082E	PARTICIPANT	\N	PRESENT	0
667328	665153	20264J	PARTICIPANT	\N	PRESENT	0
667329	665153	20142Y	PARTICIPANT	\N	PRESENT	0
667330	665153	04085P	PARTICIPANT	\N	PRESENT	0
667331	665153	19593H	PARTICIPANT	\N	PRESENT	0
667332	665153	11067R	PARTICIPANT	\N	PRESENT	0
667333	665153	19631V	PARTICIPANT	\N	PRESENT	0
667334	665153	19251M	PARTICIPANT	\N	PRESENT	0
667335	665153	19669L	PARTICIPANT	\N	PRESENT	0
667336	665153	01028R	PARTICIPANT	\N	PRESENT	0
667337	665153	19647E	PARTICIPANT	\N	PRESENT	0
667338	665153	14021P	PARTICIPANT	\N	PRESENT	0
667339	665153	11026G	PARTICIPANT	\N	PRESENT	0
667340	665153	20064C	PARTICIPANT	\N	PRESENT	0
667341	665153	19697Q	PARTICIPANT	\N	PRESENT	0
667342	665153	11083R	PARTICIPANT	\N	PRESENT	0
667343	665153	19637C	PARTICIPANT	\N	PRESENT	0
667344	665153	19651A	PARTICIPANT	\N	PRESENT	0
667345	665153	19782L	PARTICIPANT	\N	PRESENT	0
667346	665153	95063L	PARTICIPANT	\N	PRESENT	0
667347	665153	19525U	PARTICIPANT	\N	PRESENT	0
667348	665153	19679N	PARTICIPANT	\N	PRESENT	0
667349	665153	04045F	PARTICIPANT	\N	PRESENT	0
667350	665153	19503N	PARTICIPANT	\N	PRESENT	0
667351	665153	04042C	PARTICIPANT	\N	PRESENT	0
667352	665153	11090Q	PARTICIPANT	\N	PRESENT	0
667353	665153	19711U	PARTICIPANT	\N	PRESENT	0
667354	665153	08061X	PARTICIPANT	\N	PRESENT	0
667355	665153	01062T	PARTICIPANT	\N	PRESENT	0
667356	665153	99004R	PARTICIPANT	\N	PRESENT	0
667357	665153	20062A	PARTICIPANT	\N	PRESENT	0
667358	665153	20070A	PARTICIPANT	\N	PRESENT	0
667359	665153	19549D	PARTICIPANT	\N	PRESENT	0
667360	665153	20136B	PARTICIPANT	\N	PRESENT	0
667361	665153	14169X	PARTICIPANT	\N	PRESENT	0
667313	659564	20106U	PARTICIPANT	\N	PRESENT	0
667317	665153	86034E	PARTICIPANT	\N	PRESENT	0
667362	665153	11012A	PARTICIPANT	\N	PRESENT	0
667363	665153	04071H	PARTICIPANT	\N	PRESENT	0
667364	665153	20072C	PARTICIPANT	\N	PRESENT	0
667365	665153	16685X	PARTICIPANT	\N	PRESENT	0
667366	665153	14105F	PARTICIPANT	\N	PRESENT	0
667367	665153	19441R	PARTICIPANT	\N	PRESENT	0
667368	665153	20048C	PARTICIPANT	\N	PRESENT	0
667369	665153	14187A	PARTICIPANT	\N	PRESENT	0
669200	669197	20124W	PARTICIPANT	\N	PRESENT	0
669201	669197	19735D	PARTICIPANT	\N	PRESENT	0
669202	669197	04070G	PARTICIPANT	\N	PRESENT	0
669203	669197	19593H	PARTICIPANT	\N	PRESENT	0
669204	669197	20056C	PARTICIPANT	\N	PRESENT	0
669397	669396	19693L	PARTICIPANT	\N	PRESENT	0
671905	671902	14151M	PARTICIPANT	\N	PRESENT	0
671906	671902	20022R	PARTICIPANT	\N	PRESENT	0
671908	671902	20114U	PARTICIPANT	\N	PRESENT	0
671909	671902	20110Q	PARTICIPANT	\N	PRESENT	0
671937	671933	14151M	PARTICIPANT	\N	PRESENT	0
671938	671933	20022R	PARTICIPANT	\N	PRESENT	0
671939	671933	20110Q	PARTICIPANT	\N	PRESENT	0
678042	676427	19679N	PARTICIPANT	\N	PRESENT	0
678043	676427	14193X	PARTICIPANT	\N	PRESENT	0
678044	676427	14105F	PARTICIPANT	\N	PRESENT	0
678045	676427	14169X	PARTICIPANT	\N	PRESENT	0
678046	676427	14173T	PARTICIPANT	\N	PRESENT	0
678047	676427	04085P	PARTICIPANT	\N	PRESENT	0
678048	676427	14031R	PARTICIPANT	\N	PRESENT	0
678049	676427	19657G	PARTICIPANT	\N	PRESENT	0
678050	676427	19545Y	PARTICIPANT	\N	PRESENT	0
678051	676427	04033B	PARTICIPANT	\N	PRESENT	0
678052	676427	11085T	PARTICIPANT	\N	PRESENT	0
678053	676427	20152B	PARTICIPANT	\N	PRESENT	0
678094	676429	14275Y	PARTICIPANT	\N	PRESENT	0
678095	676429	19349W	PARTICIPANT	\N	PRESENT	0
678096	676429	19295A	PARTICIPANT	\N	PRESENT	0
678097	676429	19715Y	PARTICIPANT	\N	PRESENT	0
678098	676429	19569H	PARTICIPANT	\N	PRESENT	0
678100	671042	20024T	PARTICIPANT	\N	PRESENT	0
678101	671042	14213J	PARTICIPANT	\N	PRESENT	0
678102	676429	19760E	PARTICIPANT	\N	PRESENT	0
678103	676429	04085P	PARTICIPANT	\N	PRESENT	0
678104	676429	11056N	PARTICIPANT	\N	PRESENT	0
678105	676429	11040E	PARTICIPANT	\N	PRESENT	0
678106	676429	20058E	PARTICIPANT	\N	PRESENT	0
678107	676429	12041X	PARTICIPANT	\N	PRESENT	0
678108	676429	19687N	PARTICIPANT	\N	PRESENT	0
678109	676429	20086J	PARTICIPANT	\N	PRESENT	0
678110	676429	19758L	PARTICIPANT	\N	PRESENT	0
678111	676429	20044X	PARTICIPANT	\N	PRESENT	0
678112	676429	19507S	PARTICIPANT	\N	PRESENT	0
678113	676429	20034V	PARTICIPANT	\N	PRESENT	0
678114	676429	11031D	PARTICIPANT	\N	PRESENT	0
678115	676429	20102Q	PARTICIPANT	\N	PRESENT	0
678116	676429	20038A	PARTICIPANT	\N	PRESENT	0
678117	676429	11077T	PARTICIPANT	\N	PRESENT	0
678118	676429	20046A	PARTICIPANT	\N	PRESENT	0
678119	676429	19447X	PARTICIPANT	\N	PRESENT	0
678120	676429	19723Y	PARTICIPANT	\N	PRESENT	0
678121	676429	19573D	PARTICIPANT	\N	PRESENT	0
678122	676429	19695N	PARTICIPANT	\N	PRESENT	0
678123	676429	20112S	PARTICIPANT	\N	PRESENT	0
678124	676429	19593H	PARTICIPANT	\N	PRESENT	0
678125	676429	19663E	PARTICIPANT	\N	PRESENT	0
678126	676429	19443T	PARTICIPANT	\N	PRESENT	0
678127	676429	20056C	PARTICIPANT	\N	PRESENT	0
678128	676429	20026V	PARTICIPANT	\N	PRESENT	0
678129	676429	20098N	PARTICIPANT	\N	PRESENT	0
678130	676429	20914V	PARTICIPANT	\N	PRESENT	0
678131	676429	11065P	PARTICIPANT	\N	PRESENT	0
678132	676429	20096L	PARTICIPANT	\N	PRESENT	0
678092	676429	86034E	PARTICIPANT	\N	PRESENT	0
678093	676429	19319Q	PARTICIPANT	\N	PRESENT	0
678133	676429	20134Y	PARTICIPANT	\N	PRESENT	0
678134	676429	20100N	PARTICIPANT	\N	PRESENT	0
678135	676429	14033T	PARTICIPANT	\N	PRESENT	0
678136	676429	20142Y	PARTICIPANT	\N	PRESENT	0
678137	676429	14038Y	PARTICIPANT	\N	PRESENT	0
678138	676429	19467C	PARTICIPANT	\N	PRESENT	0
678139	676429	14355X	PARTICIPANT	\N	PRESENT	0
678140	676429	19709B	PARTICIPANT	\N	PRESENT	0
678141	676429	19515S	PARTICIPANT	\N	PRESENT	0
678142	676429	19347U	PARTICIPANT	\N	PRESENT	0
678143	676429	20036X	PARTICIPANT	\N	PRESENT	0
678144	676429	19673G	PARTICIPANT	\N	PRESENT	0
678145	676429	20092G	PARTICIPANT	\N	PRESENT	0
678146	676429	14191V	PARTICIPANT	\N	PRESENT	0
678147	676429	20130U	PARTICIPANT	\N	PRESENT	0
678148	676429	11099A	PARTICIPANT	\N	PRESENT	0
678149	676429	20266L	PARTICIPANT	\N	PRESENT	0
678150	676429	11010L	PARTICIPANT	\N	PRESENT	0
678151	676429	19651A	PARTICIPANT	\N	PRESENT	0
678152	676429	14259Y	PARTICIPANT	\N	PRESENT	0
678153	676429	19782L	PARTICIPANT	\N	PRESENT	0
678154	676429	19766L	PARTICIPANT	\N	PRESENT	0
678155	676429	19525U	PARTICIPANT	\N	PRESENT	0
678156	676429	19659J	PARTICIPANT	\N	PRESENT	0
678157	676429	14249W	PARTICIPANT	\N	PRESENT	0
678158	676429	11083R	PARTICIPANT	\N	PRESENT	0
678159	676429	11080N	PARTICIPANT	\N	PRESENT	0
678160	676429	19329S	PARTICIPANT	\N	PRESENT	0
678161	676429	14253S	PARTICIPANT	\N	PRESENT	0
678162	676429	20106U	PARTICIPANT	\N	PRESENT	0
678163	676429	17367Q	PARTICIPANT	\N	PRESENT	0
678164	676429	19643A	PARTICIPANT	\N	PRESENT	0
678165	676429	19697Q	PARTICIPANT	\N	PRESENT	0
678166	676429	19679N	PARTICIPANT	\N	PRESENT	0
678167	676429	14223L	PARTICIPANT	\N	PRESENT	0
678168	676429	10015M	PARTICIPANT	\N	PRESENT	0
678169	676429	19301E	PARTICIPANT	\N	PRESENT	0
678170	676429	20078J	PARTICIPANT	\N	PRESENT	0
678171	676429	04045F	PARTICIPANT	\N	PRESENT	0
678172	676429	18083K	PARTICIPANT	\N	PRESENT	0
678173	676429	20150Y	PARTICIPANT	\N	PRESENT	0
678174	676429	95063L	PARTICIPANT	\N	PRESENT	0
678175	676429	20146D	PARTICIPANT	\N	PRESENT	0
678176	676429	20074E	PARTICIPANT	\N	PRESENT	0
678177	676429	08061X	PARTICIPANT	\N	PRESENT	0
678178	676429	20076G	PARTICIPANT	\N	PRESENT	0
678179	676429	11072N	PARTICIPANT	\N	PRESENT	0
678180	676429	04035D	PARTICIPANT	\N	PRESENT	0
678181	676429	19637C	PARTICIPANT	\N	PRESENT	0
678182	676429	14037X	PARTICIPANT	\N	PRESENT	0
678183	676429	19693L	PARTICIPANT	\N	PRESENT	0
678184	676429	11033F	PARTICIPANT	\N	PRESENT	0
678185	676429	14055N	PARTICIPANT	\N	PRESENT	0
678186	676429	19575F	PARTICIPANT	\N	PRESENT	0
678187	676429	99004R	PARTICIPANT	\N	PRESENT	0
678188	676429	19711U	PARTICIPANT	\N	PRESENT	0
678189	676429	04059M	PARTICIPANT	\N	PRESENT	0
678190	676429	20116W	PARTICIPANT	\N	PRESENT	0
678191	676429	19621T	PARTICIPANT	\N	PRESENT	0
678192	676429	19629C	PARTICIPANT	\N	PRESENT	0
678193	676429	04008A	PARTICIPANT	\N	PRESENT	0
678194	676429	19681G	PARTICIPANT	\N	PRESENT	0
678195	676429	11101A	PARTICIPANT	\N	PRESENT	0
678196	676429	98022P	PARTICIPANT	\N	PRESENT	0
678197	676429	19387D	PARTICIPANT	\N	PRESENT	0
678198	676429	19703U	PARTICIPANT	\N	PRESENT	0
678199	676429	20132W	PARTICIPANT	\N	PRESENT	0
678200	676429	08010L	PARTICIPANT	\N	PRESENT	0
678201	676429	14207L	PARTICIPANT	\N	PRESENT	0
678202	676429	19553Y	PARTICIPANT	\N	PRESENT	0
678203	676429	04047H	PARTICIPANT	\N	PRESENT	0
678204	676429	20072C	PARTICIPANT	\N	PRESENT	0
678205	676429	19866P	PARTICIPANT	\N	PRESENT	0
678206	676429	04092N	PARTICIPANT	\N	PRESENT	0
678207	676429	11048N	PARTICIPANT	\N	PRESENT	0
678208	676429	14107H	PARTICIPANT	\N	PRESENT	0
678209	676429	14133K	PARTICIPANT	\N	PRESENT	0
678210	676429	19545Y	PARTICIPANT	\N	PRESENT	0
678211	676429	14195A	PARTICIPANT	\N	PRESENT	0
678212	676429	19747H	PARTICIPANT	\N	PRESENT	0
678213	676429	20128B	PARTICIPANT	\N	PRESENT	0
678214	676429	19415P	PARTICIPANT	\N	PRESENT	0
678215	676429	14211G	PARTICIPANT	\N	PRESENT	0
678216	676429	11097X	PARTICIPANT	\N	PRESENT	0
678217	676429	14071N	PARTICIPANT	\N	PRESENT	0
678218	676429	14221J	PARTICIPANT	\N	PRESENT	0
678219	676429	14187A	PARTICIPANT	\N	PRESENT	0
678220	676429	14111D	PARTICIPANT	\N	PRESENT	0
678221	676429	04033B	PARTICIPANT	\N	PRESENT	0
678222	676429	19583F	PARTICIPANT	\N	PRESENT	0
678223	676429	08028W	PARTICIPANT	\N	PRESENT	0
678224	676429	11064N	PARTICIPANT	\N	PRESENT	0
678225	676429	04042C	PARTICIPANT	\N	PRESENT	0
678226	676429	04057K	PARTICIPANT	\N	PRESENT	0
678227	676429	01048V	PARTICIPANT	\N	PRESENT	0
678228	676429	19563B	PARTICIPANT	\N	PRESENT	0
668001	668000	05008E	PARTICIPANT	\N	PRESENT	0
668002	668000	11053K	PARTICIPANT	\N	PRESENT	0
668003	668000	01028R	PARTICIPANT	\N	PRESENT	0
668796	659678	14237S	PARTICIPANT	\N	PRESENT	0
668797	659678	18083K	PARTICIPANT	\N	PRESENT	0
668798	659678	20100N	PARTICIPANT	\N	PRESENT	0
668799	659678	05012A	PARTICIPANT	\N	PRESENT	0
668800	659678	08060W	PARTICIPANT	\N	PRESENT	0
668801	659678	20106U	PARTICIPANT	\N	PRESENT	0
668802	659678	19503N	PARTICIPANT	\N	PRESENT	0
668803	659678	20024T	PARTICIPANT	\N	PRESENT	0
668804	659678	11065P	PARTICIPANT	\N	PRESENT	0
668805	659678	20120S	PARTICIPANT	\N	PRESENT	0
668806	659678	20136B	PARTICIPANT	\N	PRESENT	0
668807	659678	20038A	PARTICIPANT	\N	PRESENT	0
668808	659678	20140W	PARTICIPANT	\N	PRESENT	0
668809	659678	19251M	PARTICIPANT	\N	PRESENT	0
668810	659678	20046A	PARTICIPANT	\N	PRESENT	0
668811	659678	14169X	PARTICIPANT	\N	PRESENT	0
668812	659678	17229F	PARTICIPANT	\N	PRESENT	0
668813	659678	19745F	PARTICIPANT	\N	PRESENT	0
668814	659678	19577H	PARTICIPANT	\N	PRESENT	0
668817	667720	20030R	PARTICIPANT	\N	PRESENT	0
668819	667720	20070A	PARTICIPANT	\N	PRESENT	0
668820	667720	20044X	PARTICIPANT	\N	PRESENT	0
668821	667720	20088L	PARTICIPANT	\N	PRESENT	0
668822	667720	20132W	PARTICIPANT	\N	PRESENT	0
668823	667720	10006L	PARTICIPANT	\N	PRESENT	0
668824	667720	19467C	PARTICIPANT	\N	PRESENT	0
668825	667720	20068G	PARTICIPANT	\N	PRESENT	0
671228	671227	11056N	PARTICIPANT	\N	PRESENT	0
671232	671229	11056N	PARTICIPANT	\N	PRESENT	0
671234	671233	11056N	PARTICIPANT	\N	PRESENT	0
672252	669572	19333N	PARTICIPANT	\N	PRESENT	0
672253	669572	14357A	PARTICIPANT	\N	PRESENT	0
672254	669572	12041X	PARTICIPANT	\N	PRESENT	0
672255	669572	19489J	PARTICIPANT	\N	PRESENT	0
672284	669572	01028R	PARTICIPANT	\N	PRESENT	0
672605	669900	11070L	PARTICIPANT	\N	PRESENT	0
672606	669900	14071N	PARTICIPANT	\N	PRESENT	0
672607	669900	17779H	PARTICIPANT	\N	PRESENT	0
672608	669900	19693L	PARTICIPANT	\N	PRESENT	0
672609	669900	19577H	PARTICIPANT	\N	PRESENT	0
672610	669900	20130U	PARTICIPANT	\N	PRESENT	0
672611	669900	19683J	PARTICIPANT	\N	PRESENT	0
672612	669900	18193Q	PARTICIPANT	\N	PRESENT	0
672613	669900	11031D	PARTICIPANT	\N	PRESENT	0
672614	669900	11067R	PARTICIPANT	\N	PRESENT	0
672615	669900	11097X	PARTICIPANT	\N	PRESENT	0
672616	669900	11090Q	PARTICIPANT	\N	PRESENT	0
672617	669900	20132W	PARTICIPANT	\N	PRESENT	0
672618	669900	19697Q	PARTICIPANT	\N	PRESENT	0
672619	669900	20148F	PARTICIPANT	\N	PRESENT	0
672620	669900	14042U	PARTICIPANT	\N	PRESENT	0
672621	669900	10006L	PARTICIPANT	\N	PRESENT	0
672622	669900	19691J	PARTICIPANT	\N	PRESENT	0
672623	669900	14213J	PARTICIPANT	\N	PRESENT	0
672624	669900	19569H	PARTICIPANT	\N	PRESENT	0
672625	669900	19713W	PARTICIPANT	\N	PRESENT	0
672626	669900	19553Y	PARTICIPANT	\N	PRESENT	0
672627	669900	19657G	PARTICIPANT	\N	PRESENT	0
672628	669900	20034V	PARTICIPANT	\N	PRESENT	0
672629	669900	04057K	PARTICIPANT	\N	PRESENT	0
672630	669900	19667J	PARTICIPANT	\N	PRESENT	0
672631	669900	19723Y	PARTICIPANT	\N	PRESENT	0
672632	669900	20066E	PARTICIPANT	\N	PRESENT	0
672633	669900	19591F	PARTICIPANT	\N	PRESENT	0
672634	669900	19663E	PARTICIPANT	\N	PRESENT	0
672635	669900	04043D	PARTICIPANT	\N	PRESENT	0
672636	669900	19329S	PARTICIPANT	\N	PRESENT	0
672637	669900	20024T	PARTICIPANT	\N	PRESENT	0
672638	669900	19715Y	PARTICIPANT	\N	PRESENT	0
672639	669900	20252E	PARTICIPANT	\N	PRESENT	0
672640	669900	14331P	PARTICIPANT	\N	PRESENT	0
672641	669900	04092N	PARTICIPANT	\N	PRESENT	0
672642	669900	01034P	PARTICIPANT	\N	PRESENT	0
672643	669900	20098N	PARTICIPANT	\N	PRESENT	0
672644	669900	20264J	PARTICIPANT	\N	PRESENT	0
672645	669900	19760E	PARTICIPANT	\N	PRESENT	0
672646	669900	11085T	PARTICIPANT	\N	PRESENT	0
672647	669900	01048V	PARTICIPANT	\N	PRESENT	0
672691	669901	19591F	PARTICIPANT	\N	PRESENT	0
672692	669901	20914V	PARTICIPANT	\N	PRESENT	0
672693	669901	19683J	PARTICIPANT	\N	PRESENT	0
672694	669901	18193Q	PARTICIPANT	\N	PRESENT	0
672695	669901	19715Y	PARTICIPANT	\N	PRESENT	0
672696	669901	19713W	PARTICIPANT	\N	PRESENT	0
672697	669901	14042U	PARTICIPANT	\N	PRESENT	0
672698	669901	19691J	PARTICIPANT	\N	PRESENT	0
672699	669901	20130U	PARTICIPANT	\N	PRESENT	0
672700	669901	11031D	PARTICIPANT	\N	PRESENT	0
672701	669901	19577H	PARTICIPANT	\N	PRESENT	0
672702	669901	10006L	PARTICIPANT	\N	PRESENT	0
672703	669901	14026U	PARTICIPANT	\N	PRESENT	0
672704	669901	19569H	PARTICIPANT	\N	PRESENT	0
672705	669901	01034P	PARTICIPANT	\N	PRESENT	0
672706	669901	11097X	PARTICIPANT	\N	PRESENT	0
672707	669901	14071N	PARTICIPANT	\N	PRESENT	0
672708	669901	20024T	PARTICIPANT	\N	PRESENT	0
672709	669901	20148F	PARTICIPANT	\N	PRESENT	0
672710	669901	19657G	PARTICIPANT	\N	PRESENT	0
672711	669901	19663E	PARTICIPANT	\N	PRESENT	0
672712	669901	19723Y	PARTICIPANT	\N	PRESENT	0
672713	669901	19667J	PARTICIPANT	\N	PRESENT	0
672714	669901	11090Q	PARTICIPANT	\N	PRESENT	0
672715	669901	19697Q	PARTICIPANT	\N	PRESENT	0
672716	669901	19760E	PARTICIPANT	\N	PRESENT	0
672717	669901	20132W	PARTICIPANT	\N	PRESENT	0
672718	669901	19553Y	PARTICIPANT	\N	PRESENT	0
672719	669901	04057K	PARTICIPANT	\N	PRESENT	0
672720	669901	14213J	PARTICIPANT	\N	PRESENT	0
672721	669901	20034V	PARTICIPANT	\N	PRESENT	0
672722	669901	19693L	PARTICIPANT	\N	PRESENT	0
672723	669901	11067R	PARTICIPANT	\N	PRESENT	0
672724	669901	04092N	PARTICIPANT	\N	PRESENT	0
672725	669901	20066E	PARTICIPANT	\N	PRESENT	0
672726	669901	04043D	PARTICIPANT	\N	PRESENT	0
672727	669901	17589D	PARTICIPANT	\N	PRESENT	0
672728	669901	17779H	PARTICIPANT	\N	PRESENT	0
672986	672985	14257W	PARTICIPANT	\N	PRESENT	0
672998	672995	14229S	PARTICIPANT	\N	PRESENT	0
674916	671032	20068G	PARTICIPANT	\N	PRESENT	0
672689	669901	99004R	PARTICIPANT	\N	PRESENT	0
672690	669901	14331P	PARTICIPANT	\N	PRESENT	0
674951	671032	19683J	PARTICIPANT	\N	PRESENT	0
674952	671032	12028B	PARTICIPANT	\N	PRESENT	0
674953	671032	14121F	PARTICIPANT	\N	PRESENT	0
674954	671032	19525U	PARTICIPANT	\N	PRESENT	0
674955	671032	19681G	PARTICIPANT	\N	PRESENT	0
674956	671032	11041F	PARTICIPANT	\N	PRESENT	0
674957	671032	14179A	PARTICIPANT	\N	PRESENT	0
674958	671032	20050V	PARTICIPANT	\N	PRESENT	0
674959	671032	11054L	PARTICIPANT	\N	PRESENT	0
674960	671032	14207L	PARTICIPANT	\N	PRESENT	0
674961	671032	19599P	PARTICIPANT	\N	PRESENT	0
674962	671032	19611R	PARTICIPANT	\N	PRESENT	0
674963	671032	08045X	PARTICIPANT	\N	PRESENT	0
674964	671032	19760E	PARTICIPANT	\N	PRESENT	0
674965	671032	14001X	PARTICIPANT	\N	PRESENT	0
674966	671032	20110Q	PARTICIPANT	\N	PRESENT	0
674967	671032	20112S	PARTICIPANT	\N	PRESENT	0
674968	671032	20060X	PARTICIPANT	\N	PRESENT	0
674969	671032	14281W	PARTICIPANT	\N	PRESENT	0
674970	671032	19637C	PARTICIPANT	\N	PRESENT	0
674971	671032	20146D	PARTICIPANT	\N	PRESENT	0
674972	671032	19591F	PARTICIPANT	\N	PRESENT	0
674973	671032	08073C	PARTICIPANT	\N	PRESENT	0
674974	671032	20150Y	PARTICIPANT	\N	PRESENT	0
674975	671032	20072C	PARTICIPANT	\N	PRESENT	0
674976	671032	19479G	PARTICIPANT	\N	PRESENT	0
674977	671032	14073Q	PARTICIPANT	\N	PRESENT	0
674978	672799	19443T	PARTICIPANT	\N	PRESENT	0
674979	672799	12041X	PARTICIPANT	\N	PRESENT	0
674980	672799	95041E	PARTICIPANT	\N	PRESENT	0
674981	672799	11080N	PARTICIPANT	\N	PRESENT	0
674982	672799	19565D	PARTICIPANT	\N	PRESENT	0
674983	672799	20072C	PARTICIPANT	\N	PRESENT	0
674984	672799	01058X	PARTICIPANT	\N	PRESENT	0
674985	672799	11027H	PARTICIPANT	\N	PRESENT	0
674986	672799	16685X	PARTICIPANT	\N	PRESENT	0
674987	672799	04042C	PRESIDENT	0	PRESENT	0
674988	672799	11054L	PARTICIPANT	\N	PRESENT	0
675659	672496	14042U	PARTICIPANT	\N	PRESENT	0
675660	672496	14195A	PARTICIPANT	\N	PRESENT	0
675661	672496	19367Y	PARTICIPANT	\N	PRESENT	0
675662	672496	14213J	PARTICIPANT	\N	PRESENT	0
675663	672496	10006L	PRESIDENT	0	PRESENT	0
675664	671033	11053K	PARTICIPANT	\N	PRESENT	0
675665	672496	20248J	PARTICIPANT	\N	EXCUSE	0
675666	672496	19295A	PARTICIPANT	\N	EXCUSE	0
675667	671033	11070L	PARTICIPANT	\N	PRESENT	0
675668	671033	01024M	PARTICIPANT	\N	PRESENT	0
675669	671033	14069U	PARTICIPANT	\N	PRESENT	0
675670	671033	20044X	PARTICIPANT	\N	PRESENT	0
675671	672496	17779H	PARTICIPANT	\N	PRESENT	0
675672	671033	19347U	PARTICIPANT	\N	PRESENT	0
675673	671033	19349W	PARTICIPANT	\N	PRESENT	0
675674	671033	20072C	PARTICIPANT	\N	PRESENT	0
675675	672496	04092N	PARTICIPANT	\N	PRESENT	0
675676	672496	19657G	PARTICIPANT	\N	PRESENT	0
675677	671033	20032T	PARTICIPANT	\N	PRESENT	0
675678	671033	14147R	PARTICIPANT	\N	PRESENT	0
675679	671033	20126Y	PARTICIPANT	\N	PRESENT	0
675680	671033	19335Q	PARTICIPANT	\N	PRESENT	0
675681	672496	14217N	PARTICIPANT	\N	PRESENT	0
675682	671033	20102Q	PARTICIPANT	\N	PRESENT	0
675683	671033	04085P	PARTICIPANT	\N	PRESENT	0
675684	671033	07029T	PARTICIPANT	\N	PRESENT	0
675685	672496	19691J	PARTICIPANT	\N	PRESENT	0
675686	672496	14026U	PARTICIPANT	\N	PRESENT	0
675687	672496	14071N	PRESIDENT	1	PRESENT	0
675688	671033	20128B	PARTICIPANT	\N	PRESENT	0
675689	671033	10015M	PARTICIPANT	\N	PRESENT	0
675690	672496	04057K	PARTICIPANT	\N	PRESENT	0
675691	672496	19663E	PARTICIPANT	\N	PRESENT	0
675692	672496	20066E	PARTICIPANT	\N	PRESENT	0
675693	672496	11031D	PARTICIPANT	\N	PRESENT	0
675694	672496	19715Y	PARTICIPANT	\N	PRESENT	0
675695	671033	19563B	PARTICIPANT	\N	PRESENT	0
675696	671033	19543W	PARTICIPANT	\N	PRESENT	0
675700	670750	20112S	PARTICIPANT	\N	PRESENT	0
675698	670750	04085P	PARTICIPANT	\N	PRESENT	0
675699	670750	04059M	PARTICIPANT	\N	PRESENT	0
675701	670750	19707Y	PARTICIPANT	\N	PRESENT	0
675702	670750	19954N	PARTICIPANT	\N	PRESENT	0
675703	670750	17367Q	PARTICIPANT	\N	PRESENT	0
675704	670750	19367Y	PARTICIPANT	\N	PRESENT	0
675705	670750	08060W	PARTICIPANT	\N	PRESENT	0
675706	670750	20078J	PARTICIPANT	\N	PRESENT	0
675707	670750	14105F	PARTICIPANT	\N	PRESENT	0
675708	670750	20114U	PARTICIPANT	\N	PRESENT	0
675709	670750	19383Y	PARTICIPANT	\N	PRESENT	0
675710	670750	17737W	PARTICIPANT	\N	PRESENT	0
675711	670750	19782L	PARTICIPANT	\N	PRESENT	0
675712	670750	20090E	PARTICIPANT	\N	PRESENT	0
675713	670750	04042C	PARTICIPANT	\N	PRESENT	0
675714	670750	12028B	PARTICIPANT	\N	PRESENT	0
675715	671033	14083S	PARTICIPANT	\N	PRESENT	0
675716	670750	19721W	PARTICIPANT	\N	PRESENT	0
675717	670750	14038Y	PARTICIPANT	\N	PRESENT	0
675718	670750	20264J	PARTICIPANT	\N	PRESENT	0
675719	670750	14195A	PARTICIPANT	\N	PRESENT	0
675720	670750	18083K	PARTICIPANT	\N	PRESENT	0
675721	671033	19711U	PARTICIPANT	\N	PRESENT	0
675722	670750	19681G	PARTICIPANT	\N	PRESENT	0
675723	670750	14259Y	PARTICIPANT	\N	PRESENT	0
675724	670750	17589D	PARTICIPANT	\N	PRESENT	0
675725	670750	19719D	PARTICIPANT	\N	PRESENT	0
675726	670750	10006L	PARTICIPANT	\N	PRESENT	0
675727	670750	14217N	PARTICIPANT	\N	PRESENT	0
675728	670750	20248J	PARTICIPANT	\N	PRESENT	0
675729	670750	19251M	PARTICIPANT	\N	PRESENT	0
675730	670750	14215L	PARTICIPANT	\N	PRESENT	0
675731	670750	14042U	PARTICIPANT	\N	PRESENT	0
675732	670750	14249W	PARTICIPANT	\N	PRESENT	0
675733	670750	19647E	PARTICIPANT	\N	PRESENT	0
675734	670750	20100N	PARTICIPANT	\N	PRESENT	0
675735	670750	08018U	PARTICIPANT	\N	PRESENT	0
675736	670750	19347U	PARTICIPANT	\N	PRESENT	0
675737	670750	08056B	PARTICIPANT	\N	PRESENT	0
675738	670750	98022P	PARTICIPANT	\N	PRESENT	0
675739	670750	11064N	PARTICIPANT	\N	PRESENT	0
675740	670750	19553Y	PARTICIPANT	\N	PRESENT	0
675741	670750	19329S	PARTICIPANT	\N	PRESENT	0
675742	670750	20128B	PARTICIPANT	\N	PRESENT	0
675743	670750	08069G	PARTICIPANT	\N	PRESENT	0
675744	670750	19447X	PARTICIPANT	\N	PRESENT	0
675745	670750	95041E	PARTICIPANT	\N	PRESENT	0
675746	670750	14021P	PARTICIPANT	\N	PRESENT	0
675747	670750	19649G	PARTICIPANT	\N	PRESENT	0
675748	670750	20102Q	PARTICIPANT	\N	PRESENT	0
675749	670750	19723Y	PARTICIPANT	\N	PRESENT	0
675750	671033	08061X	PARTICIPANT	\N	PRESENT	0
675751	670750	12041X	PARTICIPANT	\N	PRESENT	0
675752	670750	19709B	PARTICIPANT	\N	PRESENT	0
675753	670750	16685X	PARTICIPANT	\N	PRESENT	0
675754	670750	20108W	PARTICIPANT	\N	PRESENT	0
675755	671033	07004J	PARTICIPANT	\N	PRESENT	0
675756	670750	19581D	PARTICIPANT	\N	PRESENT	0
675757	670750	19637C	PARTICIPANT	\N	PRESENT	0
675758	670750	11085T	PARTICIPANT	\N	PRESENT	0
675759	671033	19713W	PARTICIPANT	\N	PRESENT	0
675760	670750	04057K	PARTICIPANT	\N	PRESENT	0
675761	670750	14109K	PARTICIPANT	\N	PRESENT	0
675762	670750	19593H	PARTICIPANT	\N	PRESENT	0
675763	671033	19651A	PARTICIPANT	\N	PRESENT	0
675764	670750	14191V	PARTICIPANT	\N	PRESENT	0
675765	670750	08061X	PARTICIPANT	\N	PRESENT	0
675766	670750	17637T	PARTICIPANT	\N	PRESENT	0
675767	670750	20030R	PARTICIPANT	\N	PRESENT	0
675768	671033	11012A	PARTICIPANT	\N	PRESENT	0
675769	670750	19679N	PARTICIPANT	\N	PRESENT	0
675770	670750	19443T	PARTICIPANT	\N	PRESENT	0
675771	670750	20082E	PARTICIPANT	\N	PRESENT	0
675772	670750	19705W	PARTICIPANT	\N	PRESENT	0
675773	670750	04033B	PARTICIPANT	\N	PRESENT	0
675774	670750	19798U	PARTICIPANT	\N	PRESENT	0
675775	670750	11054L	PARTICIPANT	\N	PRESENT	0
675776	670750	19713W	PARTICIPANT	\N	PRESENT	0
675777	670750	20084G	PARTICIPANT	\N	PRESENT	0
675778	670750	01028R	PARTICIPANT	\N	PRESENT	0
675779	670750	19675J	PARTICIPANT	\N	PRESENT	0
675780	670750	20064C	PARTICIPANT	\N	PRESENT	0
675781	670750	20122U	PARTICIPANT	\N	PRESENT	0
675782	670750	19585H	PARTICIPANT	\N	PRESENT	0
675783	671033	08010L	PARTICIPANT	\N	PRESENT	0
675784	671033	01048V	PARTICIPANT	\N	PRESENT	0
675785	671033	20150Y	PARTICIPANT	\N	PRESENT	0
675786	671033	11048N	PARTICIPANT	\N	PRESENT	0
675787	670750	07004J	PARTICIPANT	\N	PRESENT	0
675788	671033	99004R	PARTICIPANT	\N	PRESENT	0
675789	671033	19762G	PARTICIPANT	\N	PRESENT	0
675790	671033	14021P	PARTICIPANT	\N	PRESENT	0
675791	672496	19591F	PARTICIPANT	\N	PRESENT	0
675792	671033	08034U	PARTICIPANT	\N	PRESENT	0
675793	671033	19826F	PARTICIPANT	\N	PRESENT	0
675794	672496	14281W	PARTICIPANT	\N	PRESENT	0
675795	670817	19593H	PARTICIPANT	\N	PRESENT	0
675796	670817	20132W	PARTICIPANT	\N	PRESENT	0
675797	670817	14073Q	PARTICIPANT	\N	PRESENT	0
675798	670817	19611R	PRESIDENT	0	PRESENT	0
675799	670817	20142Y	PARTICIPANT	\N	PRESENT	0
675800	670817	20048C	PARTICIPANT	\N	PRESENT	0
675801	670817	19693L	PARTICIPANT	\N	PRESENT	0
675802	670817	19719D	PARTICIPANT	\N	PRESENT	0
675803	670817	20052X	PARTICIPANT	\N	PRESENT	0
675804	670817	14229S	PARTICIPANT	\N	PRESENT	0
675805	670817	14030Q	PARTICIPANT	\N	PRESENT	0
675806	670817	20056C	PARTICIPANT	\N	PRESENT	0
675807	670817	20180F	PARTICIPANT	\N	PRESENT	0
675808	670817	19735D	PARTICIPANT	\N	PRESENT	0
675809	670817	14109K	PARTICIPANT	\N	PRESENT	0
675810	670817	08012N	PARTICIPANT	\N	PRESENT	0
675811	670817	11104D	PARTICIPANT	\N	PRESENT	0
675812	670817	20124W	PARTICIPANT	\N	PRESENT	0
675813	670817	19758L	PARTICIPANT	\N	PRESENT	0
675814	670817	20026V	PARTICIPANT	\N	PRESENT	0
675815	670817	20084G	PARTICIPANT	\N	PRESENT	0
675816	671033	14331P	PARTICIPANT	\N	PRESENT	0
675818	671033	20252E	PARTICIPANT	\N	PRESENT	0
675822	671033	14327T	PARTICIPANT	\N	PRESENT	0
675823	671033	19577H	PARTICIPANT	\N	PRESENT	0
675824	671033	19531S	PARTICIPANT	\N	PRESENT	0
655491	655490	11041F	PARTICIPANT	\N	PRESENT	0
667372	665153	11065P	PARTICIPANT	\N	PRESENT	0
667373	665153	20144B	PARTICIPANT	\N	PRESENT	0
667374	665153	11053K	PARTICIPANT	\N	PRESENT	0
667375	665153	11048N	PARTICIPANT	\N	PRESENT	0
667376	665153	20092G	PARTICIPANT	\N	PRESENT	0
667377	665153	20100N	PARTICIPANT	\N	PRESENT	0
667378	665153	19347U	PARTICIPANT	\N	PRESENT	0
667379	665153	04070G	PARTICIPANT	\N	PRESENT	0
667380	665153	20298U	PARTICIPANT	\N	PRESENT	0
667381	665153	19533U	PARTICIPANT	\N	PRESENT	0
667382	665153	19543W	PARTICIPANT	\N	PRESENT	0
667383	665153	20138D	PARTICIPANT	\N	PRESENT	0
667384	665153	17023S	PARTICIPANT	\N	PRESENT	0
667385	665153	19673G	PARTICIPANT	\N	PRESENT	0
667386	665153	20040T	PARTICIPANT	\N	PRESENT	0
667387	665153	14255U	PARTICIPANT	\N	PRESENT	0
667388	665153	20038A	PARTICIPANT	\N	PRESENT	0
667389	665153	19691J	PARTICIPANT	\N	PRESENT	0
667390	665153	19399H	PARTICIPANT	\N	PRESENT	0
667391	665153	14251Q	PARTICIPANT	\N	PRESENT	0
667392	665153	14253S	PARTICIPANT	\N	PRESENT	0
667393	665153	01024M	PARTICIPANT	\N	PRESENT	0
667394	665153	14030Q	PARTICIPANT	\N	PRESENT	0
667395	665153	20034V	PARTICIPANT	\N	PRESENT	0
667396	665153	14327T	PARTICIPANT	\N	PRESENT	0
667397	665153	14038Y	PARTICIPANT	\N	PRESENT	0
667398	665153	17965H	PARTICIPANT	\N	PRESENT	0
667406	665153	20124W	PARTICIPANT	\N	PRESENT	0
667405	665153	19421M	PARTICIPANT	\N	PRESENT	0
667403	665153	11101A	PARTICIPANT	\N	PRESENT	0
667402	665153	19747H	PARTICIPANT	\N	PRESENT	0
667404	665153	14215L	PARTICIPANT	\N	PRESENT	0
667407	665153	20126Y	PARTICIPANT	\N	PRESENT	0
667422	665153	20098N	PARTICIPANT	\N	PRESENT	0
667411	665153	11054L	PARTICIPANT	\N	PRESENT	0
667424	665153	20090E	PARTICIPANT	\N	PRESENT	0
667413	665153	11010L	PARTICIPANT	\N	PRESENT	0
667414	665153	14059S	PARTICIPANT	\N	PRESENT	0
667415	665153	20044X	PARTICIPANT	\N	PRESENT	0
667416	665153	05012A	PARTICIPANT	\N	PRESENT	0
667417	665153	20076G	PARTICIPANT	\N	PRESENT	0
667418	665153	14357A	PARTICIPANT	\N	PRESENT	0
667419	665153	14219Q	PARTICIPANT	\N	PRESENT	0
667420	665153	20120S	PARTICIPANT	\N	PRESENT	0
667421	665153	20086J	PARTICIPANT	\N	PRESENT	0
667423	665153	17367Q	PARTICIPANT	\N	PRESENT	0
667425	665153	08047A	PARTICIPANT	\N	PRESENT	0
667426	665153	19621T	PARTICIPANT	\N	PRESENT	0
667427	665153	07029T	PARTICIPANT	\N	PRESENT	0
667428	665153	20094J	PARTICIPANT	\N	PRESENT	0
667429	665153	20248J	PARTICIPANT	\N	PRESENT	0
667430	665153	14083S	PARTICIPANT	\N	PRESENT	0
667431	665153	08010L	PARTICIPANT	\N	PRESENT	0
667432	665153	14213J	PARTICIPANT	\N	PRESENT	0
667436	665153	18193Q	PARTICIPANT	\N	PRESENT	0
667434	665153	14133K	PARTICIPANT	\N	PRESENT	0
667435	665153	20110Q	PARTICIPANT	\N	PRESENT	0
667437	665153	19629C	PARTICIPANT	\N	PRESENT	0
667438	665153	19643A	PARTICIPANT	\N	PRESENT	0
667439	665153	20024T	PARTICIPANT	\N	PRESENT	0
667440	665153	17637T	PARTICIPANT	\N	PRESENT	0
667441	665153	14055N	PARTICIPANT	\N	PRESENT	0
667442	665153	19369B	PARTICIPANT	\N	PRESENT	0
667443	665153	14193X	PARTICIPANT	\N	PRESENT	0
667444	665153	20018V	PARTICIPANT	\N	PRESENT	0
667457	665254	14331P	PRESIDENT	0	PRESENT	0
667458	665254	14189C	PARTICIPANT	\N	EXCUSE	0
667474	665254	14169X	PARTICIPANT	\N	PRESENT	0
667460	665254	11101A	PARTICIPANT	\N	PRESENT	0
667461	665254	20100N	PARTICIPANT	\N	PRESENT	0
667462	665254	11083R	PARTICIPANT	\N	PRESENT	0
667463	665254	19333N	PARTICIPANT	\N	PRESENT	0
667464	665254	19531S	PARTICIPANT	\N	PRESENT	0
667465	665254	12041X	PARTICIPANT	\N	PRESENT	0
667466	665254	19711U	PARTICIPANT	\N	PRESENT	0
667467	665254	11026G	PARTICIPANT	\N	PRESENT	0
667468	665254	04057K	PARTICIPANT	\N	PRESENT	0
667469	665254	04070G	PARTICIPANT	\N	PRESENT	0
667470	665254	10015M	PARTICIPANT	\N	PRESENT	0
667471	665254	20098N	PARTICIPANT	\N	PRESENT	0
667472	665254	04045F	PARTICIPANT	\N	PRESENT	0
667473	665254	20286Q	PARTICIPANT	\N	PRESENT	0
667580	664634	19673G	PARTICIPANT	\N	EXCUSE	0
667583	667582	14213J	PARTICIPANT	\N	PRESENT	0
667584	667582	19553Y	PARTICIPANT	\N	PRESENT	0
667585	667582	20130U	PARTICIPANT	\N	PRESENT	0
667586	664326	01048V	PARTICIPANT	\N	EXCUSE	0
667608	667607	11056N	PARTICIPANT	\N	EXCUSE	0
667609	667607	19479G	PARTICIPANT	\N	EXCUSE	0
667610	667607	19551W	PARTICIPANT	\N	EXCUSE	0
667612	667607	11040E	PARTICIPANT	\N	EXCUSE	0
667618	667311	19399H	PARTICIPANT	\N	PRESENT	0
667619	667311	19643A	PARTICIPANT	\N	PRESENT	0
667700	667699	04035D	PARTICIPANT	\N	PRESENT	0
669869	669867	14215L	PARTICIPANT	\N	PRESENT	0
670025	668917	17779H	PARTICIPANT	\N	EXCUSE	0
670026	668918	17779H	PARTICIPANT	\N	EXCUSE	0
670028	670027	11067R	PARTICIPANT	\N	PRESENT	0
670029	670027	19735D	PARTICIPANT	\N	EXCUSE	0
670030	670027	19723Y	PARTICIPANT	\N	PRESENT	0
670048	668917	10006L	PRESIDENT	0	PRESENT	0
670049	668917	11031D	PARTICIPANT	\N	PRESENT	0
670050	668917	19760E	PARTICIPANT	\N	PRESENT	0
670051	668917	17965H	PARTICIPANT	\N	PRESENT	0
670052	668917	18193Q	PARTICIPANT	\N	PRESENT	0
670053	668917	19591F	PARTICIPANT	\N	PRESENT	0
670054	668917	08045X	PARTICIPANT	\N	PRESENT	0
670055	668917	19697Q	PARTICIPANT	\N	PRESENT	0
670056	668917	11067R	PARTICIPANT	\N	PRESENT	0
670057	668917	14281W	PARTICIPANT	\N	PRESENT	0
670058	668917	14195A	PARTICIPANT	\N	PRESENT	0
670059	668917	20130U	PARTICIPANT	\N	PRESENT	0
670060	668917	19553Y	PARTICIPANT	\N	PRESENT	0
670061	668917	19691J	PARTICIPANT	\N	PRESENT	0
670062	668917	19679N	PARTICIPANT	\N	PRESENT	0
670081	668917	19657G	PARTICIPANT	\N	PRESENT	0
670064	668917	19723Y	PARTICIPANT	\N	PRESENT	0
670065	668917	04092N	PARTICIPANT	\N	PRESENT	0
670066	668917	14026U	PARTICIPANT	\N	PRESENT	0
670067	668917	19569H	PARTICIPANT	\N	PRESENT	0
670068	668917	14355X	PARTICIPANT	\N	PRESENT	0
670069	668917	04043D	PARTICIPANT	\N	PRESENT	0
670070	668917	14071N	PARTICIPANT	\N	PRESENT	0
670071	668917	11097X	PARTICIPANT	\N	PRESENT	0
670072	668917	14217N	PARTICIPANT	\N	PRESENT	0
670073	668917	11045K	PARTICIPANT	\N	PRESENT	0
670074	668917	19663E	PARTICIPANT	\N	PRESENT	0
670075	668917	14042U	PARTICIPANT	\N	PRESENT	0
670076	668917	14213J	PARTICIPANT	\N	PRESENT	0
670077	668917	19798U	PARTICIPANT	\N	PRESENT	0
670078	668917	20266L	PARTICIPANT	\N	PRESENT	0
670079	668917	20040T	PARTICIPANT	\N	PRESENT	0
670080	668917	20148F	PARTICIPANT	\N	PRESENT	0
670082	668917	19715Y	PARTICIPANT	\N	PRESENT	0
670084	668917	19713W	PARTICIPANT	\N	PRESENT	0
670345	670343	19679N	PARTICIPANT	\N	PRESENT	0
670346	670344	19679N	PARTICIPANT	\N	PRESENT	0
670348	670341	19679N	PARTICIPANT	\N	PRESENT	0
670349	670342	19679N	PARTICIPANT	\N	PRESENT	0
670359	670358	19415P	PARTICIPANT	\N	PRESENT	0
670360	665146	19575F	PARTICIPANT	\N	PRESENT	0
670361	665146	19415P	PARTICIPANT	\N	PRESENT	0
672269	669560	11048N	PARTICIPANT	\N	PRESENT	0
670363	665146	14179A	PARTICIPANT	\N	PRESENT	0
672270	669560	19711U	PRESIDENT	0	PRESENT	0
670365	665146	11012A	PARTICIPANT	\N	PRESENT	0
670366	665147	19415P	PARTICIPANT	\N	PRESENT	0
671236	669558	08011M	PARTICIPANT	\N	EXCUSE	0
672271	669560	01057W	PARTICIPANT	\N	PRESENT	0
667370	665153	19713W	PARTICIPANT	\N	PRESENT	0
667371	665153	14071N	PARTICIPANT	\N	PRESENT	0
672272	669560	19741B	PARTICIPANT	\N	PRESENT	0
672273	669560	20914V	PARTICIPANT	\N	PRESENT	0
672274	669560	20116W	PARTICIPANT	\N	PRESENT	0
672275	669560	99004R	PARTICIPANT	\N	PRESENT	0
672277	669560	19671E	PARTICIPANT	\N	PRESENT	0
672278	669560	07029T	PARTICIPANT	\N	EXCUSE	0
672279	669560	12016W	PARTICIPANT	\N	EXCUSE	0
678229	676429	11043H	PARTICIPANT	\N	PRESENT	0
678230	676429	20050V	PARTICIPANT	\N	PRESENT	0
678231	676429	19717B	PARTICIPANT	\N	PRESENT	0
678232	676429	20022R	PARTICIPANT	\N	PRESENT	0
678233	676429	05012A	PARTICIPANT	\N	PRESENT	0
678234	676429	11090Q	PARTICIPANT	\N	PRESENT	0
678235	676429	19631V	PARTICIPANT	\N	PRESENT	0
678236	676429	04043D	PARTICIPANT	\N	PRESENT	0
678237	676429	14069U	PARTICIPANT	\N	PRESENT	0
678238	676429	14225N	PARTICIPANT	\N	PRESENT	0
678239	676429	19701S	PARTICIPANT	\N	PRESENT	0
678240	676429	19503N	PARTICIPANT	\N	PRESENT	0
678241	676429	04071H	PARTICIPANT	\N	PRESENT	0
678242	676429	20030R	PARTICIPANT	\N	PRESENT	0
678243	676429	14053L	PARTICIPANT	\N	PRESENT	0
678244	676429	14257W	PARTICIPANT	\N	PRESENT	0
678245	676429	19421M	PARTICIPANT	\N	PRESENT	0
678246	676429	11067R	PARTICIPANT	\N	PRESENT	0
678247	676429	14215L	PARTICIPANT	\N	PRESENT	0
678248	676429	14151M	PARTICIPANT	\N	PRESENT	0
678249	676429	11074Q	PARTICIPANT	\N	PRESENT	0
678250	676429	11110B	PARTICIPANT	\N	PRESENT	0
678251	676429	19647E	PARTICIPANT	\N	PRESENT	0
678355	676429	08009T	PARTICIPANT	\N	PRESENT	0
678253	676429	19683J	PARTICIPANT	\N	PRESENT	0
678254	676429	19798U	PARTICIPANT	\N	PRESENT	0
678255	676429	19725B	PARTICIPANT	\N	PRESENT	0
678256	676429	19333N	PARTICIPANT	\N	PRESENT	0
678257	676429	10006L	PARTICIPANT	\N	PRESENT	0
678258	676429	19533U	PARTICIPANT	\N	PRESENT	0
678259	676429	14105F	PARTICIPANT	\N	PRESENT	0
678260	676429	20028X	PARTICIPANT	\N	PRESENT	0
678261	676429	20032T	PARTICIPANT	\N	PRESENT	0
678262	676429	14331P	PARTICIPANT	\N	PRESENT	0
678263	676429	20136B	PARTICIPANT	\N	PRESENT	0
678264	676429	20138D	PARTICIPANT	\N	PRESENT	0
678265	676429	11027H	PARTICIPANT	\N	PRESENT	0
678266	676429	19954N	PARTICIPANT	\N	PRESENT	0
678267	676429	01028R	PARTICIPANT	\N	PRESENT	0
678268	676429	19649G	PARTICIPANT	\N	PRESENT	0
678269	676429	14001X	PARTICIPANT	\N	PRESENT	0
678270	676429	14147R	PARTICIPANT	\N	PRESENT	0
678271	676429	20172F	PARTICIPANT	\N	PRESENT	0
678272	676429	20114U	PARTICIPANT	\N	PRESENT	0
678273	676429	19531S	PARTICIPANT	\N	PRESENT	0
678274	676429	14097Y	PARTICIPANT	\N	PRESENT	0
678275	676429	97011G	PARTICIPANT	\N	PRESENT	0
678276	676429	08045X	PARTICIPANT	\N	PRESENT	0
678277	676429	19549D	PARTICIPANT	\N	PRESENT	0
678278	676429	14021P	PARTICIPANT	\N	PRESENT	0
678279	676429	14357A	PARTICIPANT	\N	PRESENT	0
678280	676429	11066Q	PARTICIPANT	\N	PRESENT	0
678281	676429	11041F	PARTICIPANT	\N	PRESENT	0
678282	676429	11104D	PARTICIPANT	\N	PRESENT	0
678283	676429	19383Y	PARTICIPANT	\N	PRESENT	0
678284	676429	14281W	PARTICIPANT	\N	PRESENT	0
678285	676429	14109K	PARTICIPANT	\N	PRESENT	0
678286	676429	19820Y	PARTICIPANT	\N	PRESENT	0
678287	676429	11103C	PARTICIPANT	\N	PRESENT	0
678288	676429	19413M	PARTICIPANT	\N	PRESENT	0
678289	676429	07033P	PARTICIPANT	\N	PRESENT	0
678290	676429	20110Q	PARTICIPANT	\N	PRESENT	0
678291	676429	12028B	PARTICIPANT	\N	PRESENT	0
678292	676429	20082E	PARTICIPANT	\N	PRESENT	0
678293	676429	19367Y	PARTICIPANT	\N	PRESENT	0
678294	676429	19527W	PARTICIPANT	\N	PRESENT	0
678295	676429	19581D	PARTICIPANT	\N	PRESENT	0
678296	676429	20252E	PARTICIPANT	\N	PRESENT	0
678297	676429	17965H	PARTICIPANT	\N	PRESENT	0
678298	676429	20054A	PARTICIPANT	\N	PRESENT	0
678299	676429	20084G	PARTICIPANT	\N	PRESENT	0
678300	676429	20126Y	PARTICIPANT	\N	PRESENT	0
678301	676429	08056B	PARTICIPANT	\N	PRESENT	0
678302	676429	19251M	PARTICIPANT	\N	PRESENT	0
678303	676429	18193Q	PARTICIPANT	\N	PRESENT	0
678304	676429	20090E	PARTICIPANT	\N	PRESENT	0
678305	676429	14059S	PARTICIPANT	\N	PRESENT	0
678306	676429	20062A	PARTICIPANT	\N	PRESENT	0
678307	676429	20088L	PARTICIPANT	\N	PRESENT	0
678308	676429	19707Y	PARTICIPANT	\N	PRESENT	0
678309	676429	19705W	PARTICIPANT	\N	PRESENT	0
678310	676429	20080C	PARTICIPANT	\N	PRESENT	0
678311	676429	20060X	PARTICIPANT	\N	PRESENT	0
678312	676429	20024T	PARTICIPANT	\N	PRESENT	0
678313	676429	14213J	PARTICIPANT	\N	PRESENT	0
678314	676429	20148F	PARTICIPANT	\N	PRESENT	0
678315	676429	20264J	PARTICIPANT	\N	PRESENT	0
678316	676429	20104S	PARTICIPANT	\N	PRESENT	0
678317	676429	14329V	PARTICIPANT	\N	PRESENT	0
678318	676429	19399H	PARTICIPANT	\N	PRESENT	0
678319	676429	19741B	PARTICIPANT	\N	PRESENT	0
678320	676429	08060W	PARTICIPANT	\N	PRESENT	0
678321	676429	19657G	PARTICIPANT	\N	PRESENT	0
678322	676429	11054L	PARTICIPANT	\N	PRESENT	0
678323	676429	19729F	PARTICIPANT	\N	PRESENT	0
678324	676429	19669L	PARTICIPANT	\N	PRESENT	0
678325	676429	19768N	PARTICIPANT	\N	PRESENT	0
678326	676429	14219Q	PARTICIPANT	\N	PRESENT	0
678327	676429	20042V	PARTICIPANT	\N	PRESENT	0
678328	676429	20052X	PARTICIPANT	\N	PRESENT	0
678329	676429	19511N	PARTICIPANT	\N	PRESENT	0
678330	676429	14042U	PARTICIPANT	\N	PRESENT	0
678331	676429	19739H	PARTICIPANT	\N	PRESENT	0
678332	676429	19735D	PARTICIPANT	\N	PRESENT	0
678333	676429	20180F	PARTICIPANT	\N	PRESENT	0
678334	676429	14031R	PARTICIPANT	\N	PRESENT	0
678335	676429	19479G	PARTICIPANT	\N	PRESENT	0
678337	676429	14073Q	PARTICIPANT	\N	PRESENT	0
678338	676429	20066E	PARTICIPANT	\N	PRESENT	0
678339	676429	08015R	PARTICIPANT	\N	PRESENT	0
678340	676429	07004J	PARTICIPANT	\N	PRESENT	0
678341	676429	08018U	PARTICIPANT	\N	PRESENT	0
678342	676429	19691J	PARTICIPANT	\N	PRESENT	0
678343	676429	01025N	PARTICIPANT	\N	PRESENT	0
678344	676429	20248J	PARTICIPANT	\N	PRESENT	0
678345	676429	20040T	PARTICIPANT	\N	PRESENT	0
678346	676429	19577H	PARTICIPANT	\N	PRESENT	0
678347	676429	01024M	PARTICIPANT	\N	PRESENT	0
678348	676429	19611R	PARTICIPANT	\N	PRESENT	0
678349	676429	01057W	PARTICIPANT	\N	PRESENT	0
678350	676429	17229F	PARTICIPANT	\N	PRESENT	0
678351	676429	14231L	PARTICIPANT	\N	PRESENT	0
678352	676429	14267Y	PARTICIPANT	\N	PRESENT	0
678353	676429	19826F	PARTICIPANT	\N	PRESENT	0
678354	676429	14193X	PARTICIPANT	\N	PRESENT	0
678356	678336	04059M	PARTICIPANT	\N	PRESENT	0
678357	676429	19369B	PARTICIPANT	\N	PRESENT	0
678358	678336	14073Q	PARTICIPANT	\N	PRESENT	0
678359	676429	20298U	PARTICIPANT	\N	PRESENT	0
678360	678336	19611R	PARTICIPANT	\N	PRESENT	0
678361	676429	17737W	PARTICIPANT	\N	PRESENT	0
678362	676429	19713W	PARTICIPANT	\N	PRESENT	0
678363	676429	14083S	PARTICIPANT	\N	PRESENT	0
678364	676429	11053K	PARTICIPANT	\N	PRESENT	0
678365	676429	14205J	PARTICIPANT	\N	PRESENT	0
678366	676429	19667J	PARTICIPANT	\N	PRESENT	0
678418	676429	19599P	PARTICIPANT	\N	PRESENT	0
678419	676429	19619A	PARTICIPANT	\N	PRESENT	0
655206	655205	86034E	PARTICIPANT	\N	PRESENT	0
655207	655205	04085P	PARTICIPANT	\N	PRESENT	0
655208	655205	19621T	PARTICIPANT	\N	PRESENT	0
655209	655205	04047H	PARTICIPANT	\N	PRESENT	0
655210	655205	20104S	PARTICIPANT	\N	PRESENT	0
655211	655205	04042C	PARTICIPANT	\N	PRESENT	0
655212	655205	19719D	PARTICIPANT	\N	PRESENT	0
655213	655205	14217N	PARTICIPANT	\N	PRESENT	0
655214	655205	14042U	PARTICIPANT	\N	PRESENT	0
655215	655205	19347U	PARTICIPANT	\N	PRESENT	0
655216	655205	14026U	PARTICIPANT	\N	PRESENT	0
655217	655205	11048N	PARTICIPANT	\N	PRESENT	0
655218	655205	14021P	PARTICIPANT	\N	PRESENT	0
655219	655205	99004R	PARTICIPANT	\N	PRESENT	0
655223	655205	14219Q	PARTICIPANT	\N	PRESENT	0
655221	655205	12041X	PARTICIPANT	\N	PRESENT	0
655222	655205	01043Q	PARTICIPANT	\N	PRESENT	0
655224	655205	14251Q	PARTICIPANT	\N	PRESENT	0
655225	655205	08061X	PARTICIPANT	\N	PRESENT	0
655226	655205	11090Q	PARTICIPANT	\N	PRESENT	0
655227	655205	14225N	PARTICIPANT	\N	PRESENT	0
655228	655205	11012A	PARTICIPANT	\N	PRESENT	0
655229	655205	04033B	PARTICIPANT	\N	PRESENT	0
655230	655205	95063L	PARTICIPANT	\N	PRESENT	0
655231	655205	11045K	PARTICIPANT	\N	PRESENT	0
655232	655205	01028R	PARTICIPANT	\N	PRESENT	0
655814	655677	17737W	PARTICIPANT	\N	PRESENT	0
655815	655677	14089Y	PARTICIPANT	\N	PRESENT	0
655816	655677	14069U	PARTICIPANT	\N	PRESENT	0
655817	655677	19543W	PARTICIPANT	\N	PRESENT	0
655818	655677	19581D	PARTICIPANT	\N	PRESENT	0
655824	655684	95041E	PARTICIPANT	\N	PRESENT	0
655825	655684	19443T	PARTICIPANT	\N	PRESENT	0
655826	655684	12041X	PARTICIPANT	\N	PRESENT	0
655827	655684	01058X	PARTICIPANT	\N	PRESENT	0
655828	655684	16685X	PARTICIPANT	\N	PRESENT	0
655829	655684	11027H	PARTICIPANT	\N	PRESENT	0
655830	655684	04042C	PRESIDENT	0	PRESENT	0
655831	655684	11066Q	PARTICIPANT	\N	PRESENT	0
655832	655684	19669L	PARTICIPANT	\N	PRESENT	0
655833	655684	12028B	PARTICIPANT	\N	PRESENT	0
655834	655684	19421M	PARTICIPANT	\N	PRESENT	0
655835	655684	07033P	PARTICIPANT	\N	PRESENT	0
655836	655684	97011G	PARTICIPANT	\N	PRESENT	0
655837	655684	08061X	PARTICIPANT	\N	PRESENT	0
655838	655684	14249W	PARTICIPANT	\N	PRESENT	0
655839	655684	08047A	PARTICIPANT	\N	PRESENT	0
655840	655684	20128B	PARTICIPANT	\N	PRESENT	0
655841	655684	01062T	PARTICIPANT	\N	PRESENT	0
655842	655684	14133K	PARTICIPANT	\N	PRESENT	0
655843	655684	11041F	PARTICIPANT	\N	PRESENT	0
655844	655684	01024M	PARTICIPANT	\N	PRESENT	0
655845	655684	14105F	PARTICIPANT	\N	PRESENT	0
655846	655684	20064C	PARTICIPANT	\N	PRESENT	0
655847	655684	11064N	PARTICIPANT	\N	PRESENT	0
655848	655684	14267Y	PARTICIPANT	\N	PRESENT	0
655849	655684	14211G	PARTICIPANT	\N	PRESENT	0
655850	655684	14255U	PARTICIPANT	\N	PRESENT	0
655854	655684	14059S	PARTICIPANT	\N	EXCUSE	0
655855	655684	19565D	PARTICIPANT	\N	EXCUSE	0
655856	655684	11054L	PARTICIPANT	\N	EXCUSE	0
655857	655684	04035D	PARTICIPANT	\N	PRESENT	0
656726	656724	11066Q	PARTICIPANT	\N	PRESENT	0
665106	656842	20094J	PARTICIPANT	\N	PRESENT	0
665107	656842	14026U	PARTICIPANT	\N	PRESENT	0
665108	656842	19725B	PARTICIPANT	\N	PRESENT	0
665109	656842	14097Y	PARTICIPANT	\N	PRESENT	0
665110	656842	19711U	PARTICIPANT	\N	PRESENT	0
665125	665039	19479G	PARTICIPANT	\N	PRESENT	0
665112	656842	19441R	PARTICIPANT	\N	PRESENT	0
665113	656842	14001X	PARTICIPANT	\N	PRESENT	0
665114	656842	19593H	PARTICIPANT	\N	PRESENT	0
665115	656842	10015M	PARTICIPANT	\N	PRESENT	0
665116	656842	14073Q	PARTICIPANT	\N	PRESENT	0
665117	656842	14331P	PRESIDENT	0	PRESENT	0
665118	656842	20286Q	PARTICIPANT	\N	PRESENT	0
665119	656842	12016W	PARTICIPANT	\N	PRESENT	0
665120	656842	04057K	PARTICIPANT	\N	PRESENT	0
665121	656842	14089Y	PARTICIPANT	\N	PRESENT	0
665122	656842	19701S	PARTICIPANT	\N	PRESENT	0
665123	656842	14237S	PARTICIPANT	\N	PRESENT	0
665124	665038	19479G	PARTICIPANT	\N	PRESENT	0
665131	665129	14031R	PARTICIPANT	\N	PRESENT	0
665132	665129	20118Y	PARTICIPANT	\N	PRESENT	0
665133	665129	20096L	PARTICIPANT	\N	PRESENT	0
665136	665134	14031R	PARTICIPANT	\N	PRESENT	0
665137	665134	19503N	PARTICIPANT	\N	PRESENT	0
665138	665134	20120S	PARTICIPANT	\N	PRESENT	0
665140	665139	14031R	PARTICIPANT	\N	PRESENT	0
665141	665139	19599P	PARTICIPANT	\N	PRESENT	0
665143	665142	14031R	PARTICIPANT	\N	PRESENT	0
665145	665144	14031R	PARTICIPANT	\N	PRESENT	0
665206	665205	20110Q	PARTICIPANT	\N	PRESENT	0
665208	665207	20110Q	PARTICIPANT	\N	PRESENT	0
669099	667698	19349W	PARTICIPANT	\N	PRESENT	0
669100	667698	19711U	PARTICIPANT	\N	PRESENT	0
669101	667698	14225N	PRESIDENT	0	PRESENT	0
669102	667698	19667J	PARTICIPANT	\N	PRESENT	0
669103	667698	19335Q	PARTICIPANT	\N	PRESENT	0
669104	667698	20044X	PARTICIPANT	\N	PRESENT	0
669105	667698	20086J	PARTICIPANT	\N	PRESENT	0
669106	667698	19762G	PARTICIPANT	\N	PRESENT	0
669107	667698	08010L	PARTICIPANT	\N	PRESENT	0
669108	667698	20116W	PARTICIPANT	\N	PRESENT	0
669109	667698	20126Y	PARTICIPANT	\N	PRESENT	0
669110	667698	20080C	PARTICIPANT	\N	PRESENT	0
669112	667698	11070L	PARTICIPANT	\N	PRESENT	0
669113	667698	20914V	PARTICIPANT	\N	PRESENT	0
669115	667698	01057W	PARTICIPANT	\N	PRESENT	0
669116	667698	99004R	PARTICIPANT	\N	PRESENT	0
669117	667698	11048N	PARTICIPANT	\N	PRESENT	0
669118	667698	11053K	PARTICIPANT	\N	PRESENT	0
669123	667724	99004R	PARTICIPANT	\N	PRESENT	0
669124	667698	04071H	PARTICIPANT	\N	PRESENT	0
669125	667698	19647E	PARTICIPANT	\N	PRESENT	0
669126	667698	07029T	PARTICIPANT	\N	PRESENT	0
669127	667698	20050V	PARTICIPANT	\N	PRESENT	0
669132	667698	14083S	PARTICIPANT	\N	PRESENT	0
669133	667724	20102Q	PARTICIPANT	\N	PRESENT	0
669134	667724	20046A	PARTICIPANT	\N	PRESENT	0
669135	667724	19333N	PARTICIPANT	\N	PRESENT	0
669136	667724	19549D	PARTICIPANT	\N	PRESENT	0
669137	667724	08060W	PARTICIPANT	\N	PRESENT	0
669138	667724	19503N	PARTICIPANT	\N	PRESENT	0
669139	667724	11065P	PARTICIPANT	\N	PRESENT	0
669140	667724	19637C	PARTICIPANT	\N	PRESENT	0
669141	667724	20106U	PARTICIPANT	\N	PRESENT	0
669142	667724	08061X	PARTICIPANT	\N	PRESENT	0
669143	667724	20082E	PARTICIPANT	\N	PRESENT	0
669144	667724	19599P	PARTICIPANT	\N	PRESENT	0
669145	667724	19820Y	PARTICIPANT	\N	PRESENT	0
669146	667724	01028R	PARTICIPANT	\N	PRESENT	0
669147	667724	19681G	PARTICIPANT	\N	PRESENT	0
669148	667724	14221J	PARTICIPANT	\N	PRESENT	0
669149	667724	14195A	PARTICIPANT	\N	PRESENT	0
669150	667724	19387D	PARTICIPANT	\N	PRESENT	0
669151	667724	14257W	PARTICIPANT	\N	PRESENT	0
669152	667724	95063L	PARTICIPANT	\N	PRESENT	0
669153	667724	14219Q	PARTICIPANT	\N	PRESENT	0
669154	667724	14031R	PARTICIPANT	\N	PRESENT	0
669155	667724	19695N	PARTICIPANT	\N	PRESENT	0
669156	667724	14231L	PARTICIPANT	\N	PRESENT	0
669157	667724	17229F	PARTICIPANT	\N	PRESENT	0
669158	667724	20298U	PARTICIPANT	\N	PRESENT	0
669159	667724	19369B	PARTICIPANT	\N	PRESENT	0
669095	667698	11012A	PARTICIPANT	\N	PRESENT	0
669096	667698	01048V	PARTICIPANT	\N	PRESENT	0
669097	667698	14121F	PARTICIPANT	\N	PRESENT	0
669098	667698	11074Q	PARTICIPANT	\N	PRESENT	0
669160	667724	19619A	PARTICIPANT	\N	PRESENT	0
669161	667724	14207L	PARTICIPANT	\N	PRESENT	0
669162	667724	14033T	PARTICIPANT	\N	PRESENT	0
669163	667724	20100N	PARTICIPANT	\N	PRESENT	0
669164	667724	19701S	PARTICIPANT	\N	PRESENT	0
669165	667724	11090Q	PARTICIPANT	\N	PRESENT	0
669166	667724	14147R	PARTICIPANT	\N	PRESENT	0
669167	667724	14123H	PARTICIPANT	\N	PRESENT	0
669168	667724	18083K	PARTICIPANT	\N	PRESENT	0
665000	664551	19657G	PARTICIPANT	\N	PRESENT	0
666758	665151	19467C	PARTICIPANT	\N	PRESENT	0
666759	665151	20060X	PARTICIPANT	\N	PRESENT	0
666760	665151	12028B	PARTICIPANT	\N	PRESENT	0
666761	665151	20070A	PARTICIPANT	\N	PRESENT	0
666762	665151	20264J	PARTICIPANT	\N	PRESENT	0
666763	665151	14109K	PARTICIPANT	\N	PRESENT	0
666764	665151	20058E	PARTICIPANT	\N	PRESENT	0
666765	665151	20088L	PARTICIPANT	\N	PRESENT	0
666766	665151	19649G	PARTICIPANT	\N	PRESENT	0
666767	665151	14038Y	PARTICIPANT	\N	PRESENT	0
666768	665151	11045K	PARTICIPANT	\N	PRESENT	0
666769	665151	20064C	PARTICIPANT	\N	PRESENT	0
666770	665151	20034V	PARTICIPANT	\N	PRESENT	0
666771	665151	19333N	PARTICIPANT	\N	PRESENT	0
666772	665151	19725B	PARTICIPANT	\N	PRESENT	0
666773	665151	19643A	PARTICIPANT	\N	PRESENT	0
666774	665151	19489J	PARTICIPANT	\N	PRESENT	0
666775	665151	19413M	PARTICIPANT	\N	PRESENT	0
666776	665151	01062T	PARTICIPANT	\N	PRESENT	0
666777	665151	01028R	PARTICIPANT	\N	PRESENT	0
666778	665151	14225N	PARTICIPANT	\N	PRESENT	0
666779	665151	19503N	PARTICIPANT	\N	PRESENT	0
666780	665151	20030R	PARTICIPANT	\N	PRESENT	0
666781	665151	17965H	PARTICIPANT	\N	PRESENT	0
666782	665151	14189C	PARTICIPANT	\N	PRESENT	0
666783	665151	20028X	PARTICIPANT	\N	PRESENT	0
666784	665151	11104D	PARTICIPANT	\N	PRESENT	0
666785	665151	20022R	PARTICIPANT	\N	PRESENT	0
666786	665151	08012N	PARTICIPANT	\N	PRESENT	0
666787	665151	11067R	PARTICIPANT	\N	PRESENT	0
666788	665151	19820Y	PARTICIPANT	\N	PRESENT	0
666789	665151	11066Q	PARTICIPANT	\N	PRESENT	0
666790	665151	19669L	PARTICIPANT	\N	PRESENT	0
666791	665151	11026G	PARTICIPANT	\N	PRESENT	0
666792	665151	18193Q	PARTICIPANT	\N	PRESENT	0
666793	665151	11110B	PARTICIPANT	\N	PRESENT	0
666794	665151	19531S	PARTICIPANT	\N	PRESENT	0
666795	665151	14267Y	PARTICIPANT	\N	PRESENT	0
666796	665151	14083S	PARTICIPANT	\N	PRESENT	0
666797	665151	11070L	PARTICIPANT	\N	PRESENT	0
666798	665151	14205J	PARTICIPANT	\N	PRESENT	0
666799	665151	14255U	PARTICIPANT	\N	PRESENT	0
666800	665151	11085T	PARTICIPANT	\N	PRESENT	0
666801	665151	20066E	PARTICIPANT	\N	PRESENT	0
666802	665151	19619A	PARTICIPANT	\N	PRESENT	0
666803	665151	19713W	PARTICIPANT	\N	PRESENT	0
666804	665151	19699S	PARTICIPANT	\N	PRESENT	0
666805	665151	20048C	PARTICIPANT	\N	PRESENT	0
666806	665151	20052X	PARTICIPANT	\N	PRESENT	0
666807	665151	20042V	PARTICIPANT	\N	PRESENT	0
666808	665151	19721W	PARTICIPANT	\N	PRESENT	0
666809	665151	19441R	PARTICIPANT	\N	PRESENT	0
666810	665151	19479G	PARTICIPANT	\N	PRESENT	0
666811	665151	14219Q	PARTICIPANT	\N	PRESENT	0
666812	665151	19569H	PARTICIPANT	\N	PRESENT	0
666813	665151	14042U	PARTICIPANT	\N	PRESENT	0
666814	665151	16685X	PARTICIPANT	\N	PRESENT	0
666815	665151	19739H	PARTICIPANT	\N	PRESENT	0
666816	665151	19507S	PARTICIPANT	\N	PRESENT	0
666817	665151	20144B	PARTICIPANT	\N	PRESENT	0
666818	665151	11053K	PARTICIPANT	\N	PRESENT	0
666819	665151	01034P	PARTICIPANT	\N	PRESENT	0
666820	665151	20084G	PARTICIPANT	\N	PRESENT	0
666821	665151	20040T	PARTICIPANT	\N	PRESENT	0
666822	665151	19369B	PARTICIPANT	\N	PRESENT	0
666823	665151	19611R	PARTICIPANT	\N	PRESENT	0
666824	665151	20298U	PARTICIPANT	\N	PRESENT	0
666825	665151	19691J	PARTICIPANT	\N	PRESENT	0
666826	665151	19745F	PARTICIPANT	\N	PRESENT	0
666827	665151	17229F	PARTICIPANT	\N	PRESENT	0
666828	665151	14231L	PARTICIPANT	\N	PRESENT	0
666829	665151	19515S	PARTICIPANT	\N	PRESENT	0
666830	665151	14030Q	PARTICIPANT	\N	PRESENT	0
666831	665151	01025N	PARTICIPANT	\N	PRESENT	0
666832	665151	04070G	PARTICIPANT	\N	PRESENT	0
666833	665151	01024M	PARTICIPANT	\N	PRESENT	0
666834	665151	01060R	PARTICIPANT	\N	PRESENT	0
675825	671033	20136B	PARTICIPANT	\N	PRESENT	0
675826	671033	11074Q	PARTICIPANT	\N	PRESENT	0
675827	671033	11056N	PARTICIPANT	\N	PRESENT	0
675828	671033	20090E	PARTICIPANT	\N	PRESENT	0
675829	670817	19621T	PARTICIPANT	\N	PRESENT	0
675830	671033	20058E	PARTICIPANT	\N	PRESENT	0
675837	672496	19569H	PARTICIPANT	\N	PRESENT	0
675887	671033	19467C	PARTICIPANT	\N	PRESENT	0
675885	671033	04045F	PARTICIPANT	\N	PRESENT	0
675886	671033	14038Y	PARTICIPANT	\N	PRESENT	0
675888	671033	14205J	PARTICIPANT	\N	PRESENT	0
675889	671033	19413M	PARTICIPANT	\N	PRESENT	0
675890	671033	20100N	PARTICIPANT	\N	PRESENT	0
675891	671033	20106U	PARTICIPANT	\N	PRESENT	0
675892	671033	19782L	PARTICIPANT	\N	PRESENT	0
675893	671033	19747H	PARTICIPANT	\N	PRESENT	0
675894	671033	19367Y	PARTICIPANT	\N	PRESENT	0
675895	671033	20180F	PARTICIPANT	\N	PRESENT	0
675896	671033	20034V	PARTICIPANT	\N	PRESENT	0
675899	671033	08073C	PARTICIPANT	\N	PRESENT	0
675900	671033	20104S	PARTICIPANT	\N	PRESENT	0
675901	671033	20026V	PARTICIPANT	\N	PRESENT	0
675902	671033	19758L	PARTICIPANT	\N	PRESENT	0
675903	671033	20022R	PARTICIPANT	\N	PRESENT	0
675904	671033	14030Q	PARTICIPANT	\N	PRESENT	0
675905	671033	14357A	PARTICIPANT	\N	PRESENT	0
675906	671033	19719D	PARTICIPANT	\N	PRESENT	0
675907	671033	14213J	PARTICIPANT	\N	PRESENT	0
675908	671033	14217N	PARTICIPANT	\N	PRESENT	0
675922	671033	11026G	PARTICIPANT	\N	PRESENT	0
675910	671033	11090Q	PARTICIPANT	\N	PRESENT	0
675911	671033	14231L	PARTICIPANT	\N	PRESENT	0
675912	671033	14071N	PARTICIPANT	\N	PRESENT	0
675913	671033	04071H	PARTICIPANT	\N	PRESENT	0
675914	671033	19621T	PARTICIPANT	\N	PRESENT	0
675915	671033	14187A	PARTICIPANT	\N	PRESENT	0
675916	671033	14249W	PARTICIPANT	\N	PRESENT	0
675917	671033	19569H	PARTICIPANT	\N	PRESENT	0
675918	671033	19399H	PARTICIPANT	\N	PRESENT	0
675919	671033	20124W	PARTICIPANT	\N	PRESENT	0
675920	671033	20054A	PARTICIPANT	\N	PRESENT	0
675921	671033	20092G	PARTICIPANT	\N	PRESENT	0
675923	671033	19533U	PARTICIPANT	\N	PRESENT	0
675924	671033	19565D	PARTICIPANT	\N	PRESENT	0
675925	671033	17023S	PARTICIPANT	\N	PRESENT	0
675926	671033	20028X	PARTICIPANT	\N	PRESENT	0
675927	671033	20110Q	PARTICIPANT	\N	PRESENT	0
675928	671033	19741B	PARTICIPANT	\N	PRESENT	0
675929	671033	19631V	PARTICIPANT	\N	PRESENT	0
676111	672576	12016W	PARTICIPANT	\N	EXCUSE	0
676190	671037	86034E	PARTICIPANT	\N	PRESENT	0
676192	671037	11048N	PARTICIPANT	\N	PRESENT	0
676193	671037	14225N	PARTICIPANT	\N	PRESENT	0
676194	671037	11040E	PARTICIPANT	\N	PRESENT	0
676195	671037	20080C	PARTICIPANT	\N	PRESENT	0
676196	671037	19695N	PARTICIPANT	\N	PRESENT	0
676197	671037	01057W	PARTICIPANT	\N	PRESENT	0
676198	671037	20914V	PARTICIPANT	\N	PRESENT	0
676199	671037	20044X	PARTICIPANT	\N	PRESENT	0
676200	671037	11033F	PARTICIPANT	\N	PRESENT	0
676201	671037	19531S	PARTICIPANT	\N	PRESENT	0
676202	671037	99004R	PARTICIPANT	\N	PRESENT	0
676203	671037	19545Y	PARTICIPANT	\N	PRESENT	0
676204	671037	20150Y	PARTICIPANT	\N	PRESENT	0
676205	671037	20252E	PARTICIPANT	\N	PRESENT	0
676206	671037	19745F	PARTICIPANT	\N	PRESENT	0
676207	671037	19367Y	PARTICIPANT	\N	PRESENT	0
676208	671037	19479G	PARTICIPANT	\N	PRESENT	0
676209	671037	14327T	PARTICIPANT	\N	PRESENT	0
676210	671037	19741B	PARTICIPANT	\N	PRESENT	0
676211	671037	11053K	PARTICIPANT	\N	PRESENT	0
676212	671037	07004J	PARTICIPANT	\N	PRESENT	0
676213	671037	20132W	PARTICIPANT	\N	PRESENT	0
676214	671037	11012A	PARTICIPANT	\N	PRESENT	0
676215	671037	20034V	PARTICIPANT	\N	PRESENT	0
676216	671037	19649G	PARTICIPANT	\N	PRESENT	0
676217	671037	20070A	PARTICIPANT	\N	PRESENT	0
676218	671037	19667J	PARTICIPANT	\N	PRESENT	0
676219	671037	19347U	PARTICIPANT	\N	PRESENT	0
676220	671037	14021P	PARTICIPANT	\N	PRESENT	0
676221	671037	20090E	PARTICIPANT	\N	PRESENT	0
676222	671037	20126Y	PARTICIPANT	\N	PRESENT	0
676223	671037	20152B	PARTICIPANT	\N	PRESENT	0
655725	655724	20110Q	PARTICIPANT	\N	PRESENT	0
655727	655726	14255U	PARTICIPANT	\N	PRESENT	0
655785	655677	14053L	PARTICIPANT	\N	PRESENT	0
655786	655677	20074E	PARTICIPANT	\N	PRESENT	0
655787	655677	04047H	PRESIDENT	0	PRESENT	0
655788	655677	19673G	PARTICIPANT	\N	PRESENT	0
655789	655677	11033F	PARTICIPANT	\N	PRESENT	0
655790	655677	01028R	PARTICIPANT	\N	PRESENT	0
655791	655677	19447X	PARTICIPANT	\N	PRESENT	0
655792	655677	14231L	PARTICIPANT	\N	PRESENT	0
655793	655677	19725B	PARTICIPANT	\N	PRESENT	0
655794	655677	11056N	PARTICIPANT	\N	PRESENT	0
655795	655677	95063L	PARTICIPANT	\N	PRESENT	0
655796	655677	20108W	PARTICIPANT	\N	PRESENT	0
655797	655677	20110Q	PARTICIPANT	\N	PRESENT	0
655798	655677	14179A	PARTICIPANT	\N	PRESENT	0
655799	655677	14151M	PARTICIPANT	\N	PRESENT	0
655800	655677	14215L	PARTICIPANT	\N	PRESENT	0
655801	655677	04008A	PARTICIPANT	\N	PRESENT	0
655802	655677	19749K	PARTICIPANT	\N	PRESENT	0
655803	655677	20022R	PARTICIPANT	\N	PRESENT	0
655804	655677	11026G	PARTICIPANT	\N	PRESENT	0
655805	655677	05008E	PARTICIPANT	\N	PRESENT	0
655806	655677	19489J	PARTICIPANT	\N	PRESENT	0
655807	655677	14147R	PARTICIPANT	\N	PRESENT	0
655808	655677	14111D	PARTICIPANT	\N	PRESENT	0
655809	655677	19649G	PARTICIPANT	\N	PRESENT	0
655810	655677	11010L	PARTICIPANT	\N	EXCUSE	0
655811	655677	08018U	PARTICIPANT	\N	EXCUSE	0
655812	655677	14021P	PARTICIPANT	\N	EXCUSE	0
655813	655677	20114U	PARTICIPANT	\N	PRESENT	0
655866	655859	19643A	PARTICIPANT	\N	PRESENT	0
655867	655859	20132W	PARTICIPANT	\N	PRESENT	0
655868	655859	04070G	PARTICIPANT	\N	PRESENT	0
655869	655859	19699S	PARTICIPANT	\N	PRESENT	0
655870	655859	20134Y	PARTICIPANT	\N	PRESENT	0
655871	655859	19573D	PARTICIPANT	\N	PRESENT	0
655872	655859	19533U	PARTICIPANT	\N	PRESENT	0
655873	655859	19611R	PRESIDENT	0	PRESENT	0
655874	655859	20264J	PARTICIPANT	\N	PRESENT	0
655875	655859	20048C	PARTICIPANT	\N	PRESENT	0
655876	655859	20052X	PARTICIPANT	\N	PRESENT	0
655877	655859	20152B	PARTICIPANT	\N	PRESENT	0
655880	655678	14053L	PARTICIPANT	\N	PRESENT	0
655881	655678	14111D	PARTICIPANT	\N	PRESENT	0
655882	655678	20074E	PARTICIPANT	\N	PRESENT	0
655883	655678	19581D	PARTICIPANT	\N	PRESENT	0
655884	655678	04047H	PRESIDENT	0	PRESENT	0
655885	655678	19673G	PARTICIPANT	\N	PRESENT	0
655886	655678	01028R	PARTICIPANT	\N	PRESENT	0
655887	655678	11033F	PARTICIPANT	\N	PRESENT	0
655888	655678	19447X	PARTICIPANT	\N	PRESENT	0
655889	655678	05008E	PARTICIPANT	\N	PRESENT	0
655890	655678	19725B	PARTICIPANT	\N	PRESENT	0
655891	655678	11056N	PARTICIPANT	\N	PRESENT	0
655892	655678	19729F	PARTICIPANT	\N	PRESENT	0
655893	655678	17737W	PARTICIPANT	\N	PRESENT	0
655894	655678	95063L	PARTICIPANT	\N	PRESENT	0
655895	655678	20108W	PARTICIPANT	\N	PRESENT	0
655896	655678	14179A	PARTICIPANT	\N	PRESENT	0
655897	655678	14147R	PARTICIPANT	\N	PRESENT	0
655898	655678	20114U	PARTICIPANT	\N	PRESENT	0
655899	655678	14215L	PARTICIPANT	\N	PRESENT	0
655900	655678	19749K	PARTICIPANT	\N	PRESENT	0
655901	655678	20022R	PARTICIPANT	\N	PRESENT	0
655915	655859	14073Q	PARTICIPANT	\N	PRESENT	0
655916	655859	14229S	PARTICIPANT	\N	PRESENT	0
655917	655859	19735D	PARTICIPANT	\N	PRESENT	0
655918	655859	20084G	PARTICIPANT	\N	PRESENT	0
655919	655859	19593H	PARTICIPANT	\N	EXCUSE	0
655920	655859	11109J	PARTICIPANT	\N	EXCUSE	0
655921	655859	20112S	PARTICIPANT	\N	EXCUSE	0
655922	655859	11043H	PARTICIPANT	\N	EXCUSE	0
655923	655859	19693L	PARTICIPANT	\N	EXCUSE	0
655924	655859	19399H	PARTICIPANT	\N	EXCUSE	0
655925	655859	19758L	PARTICIPANT	\N	EXCUSE	0
655926	655859	20058E	PARTICIPANT	\N	EXCUSE	0
655927	655678	14231L	PARTICIPANT	\N	PRESENT	0
655928	655678	08018U	PARTICIPANT	\N	EXCUSE	0
655929	655678	14021P	PARTICIPANT	\N	EXCUSE	0
655930	655859	20138D	PARTICIPANT	\N	PRESENT	0
655931	655859	14030Q	PARTICIPANT	\N	PRESENT	0
669071	669070	14213J	PARTICIPANT	\N	PRESENT	0
671047	669569	14111D	PARTICIPANT	\N	PRESENT	0
671048	669569	14215L	PARTICIPANT	\N	PRESENT	0
671049	669569	19675J	PARTICIPANT	\N	PRESENT	0
671050	669569	11033F	PARTICIPANT	\N	PRESENT	0
671051	669569	19729F	PARTICIPANT	\N	EXCUSE	0
671052	669569	07004J	PARTICIPANT	\N	PRESENT	0
671053	669569	10015M	PARTICIPANT	\N	PRESENT	0
671054	669569	20110Q	PARTICIPANT	\N	PRESENT	0
671055	669569	04047H	PRESIDENT	0	PRESENT	0
671056	669569	19673G	PARTICIPANT	\N	PRESENT	0
671057	669569	05008E	PARTICIPANT	\N	PRESENT	0
671058	669569	19447X	PARTICIPANT	\N	PRESENT	0
671059	667816	19333N	PARTICIPANT	\N	PRESENT	0
671060	667816	20032T	PARTICIPANT	\N	PRESENT	0
671061	667816	19701S	PARTICIPANT	\N	PRESENT	0
671062	667816	14031R	PARTICIPANT	\N	PRESENT	0
671063	667816	20076G	PARTICIPANT	\N	PRESENT	0
671064	667816	20140W	PARTICIPANT	\N	PRESENT	0
671065	667816	19387D	PARTICIPANT	\N	PRESENT	0
671066	667816	19251M	PARTICIPANT	\N	PRESENT	0
671067	667816	19820Y	PARTICIPANT	\N	PRESENT	0
671068	667816	20046A	PARTICIPANT	\N	PRESENT	0
671069	667816	14221J	PARTICIPANT	\N	PRESENT	0
671070	667816	19826F	PARTICIPANT	\N	PRESENT	0
671071	667816	19599P	PARTICIPANT	\N	PRESENT	0
671072	667816	20102Q	PARTICIPANT	\N	PRESENT	0
671073	667816	19637C	PARTICIPANT	\N	PRESENT	0
671074	667816	18083K	PARTICIPANT	\N	PRESENT	0
671075	667816	20100N	PARTICIPANT	\N	PRESENT	0
671076	667816	19739H	PARTICIPANT	\N	PRESENT	0
671077	667816	20020P	PARTICIPANT	\N	PRESENT	0
671078	667816	19745F	PARTICIPANT	\N	PRESENT	0
671079	667816	17367Q	PARTICIPANT	\N	PRESENT	0
671080	669558	20086J	PARTICIPANT	\N	PRESENT	0
671081	669558	14327T	PARTICIPANT	\N	PRESENT	0
671082	669558	01057W	PARTICIPANT	\N	PRESENT	0
671083	669558	20080C	PARTICIPANT	\N	PRESENT	0
671084	669558	19671E	PARTICIPANT	\N	PRESENT	0
671085	669558	14225N	PRESIDENT	1	PRESENT	0
671086	669558	11110B	PARTICIPANT	\N	PRESENT	0
671087	669558	19349W	PARTICIPANT	\N	PRESENT	0
671088	669558	20116W	PARTICIPANT	\N	PRESENT	0
671089	669558	14253S	PARTICIPANT	\N	PRESENT	0
671090	669558	20126Y	PARTICIPANT	\N	PRESENT	0
671091	669558	19479G	PARTICIPANT	\N	PRESENT	0
671092	669558	11048N	PARTICIPANT	\N	PRESENT	0
671093	669558	20036X	PARTICIPANT	\N	PRESENT	0
671094	669558	19711U	PRESIDENT	0	PRESENT	0
671095	669558	14189C	PARTICIPANT	\N	PRESENT	0
671096	669558	19687N	PARTICIPANT	\N	PRESENT	0
671097	669558	20050V	PARTICIPANT	\N	PRESENT	0
671098	669558	20044X	PARTICIPANT	\N	PRESENT	0
671099	669558	14173T	PARTICIPANT	\N	PRESENT	0
671100	669558	11012A	PARTICIPANT	\N	PRESENT	0
671101	669558	08073C	PARTICIPANT	\N	PRESENT	0
671102	669558	20252E	PARTICIPANT	\N	PRESENT	0
671103	669558	08009T	PARTICIPANT	\N	PRESENT	0
671104	669558	14121F	PARTICIPANT	\N	PRESENT	0
671105	669558	99004R	PARTICIPANT	\N	PRESENT	0
671106	669558	20914V	PARTICIPANT	\N	PRESENT	0
671107	669558	12016W	PARTICIPANT	\N	EXCUSE	0
671108	669558	08010L	PARTICIPANT	\N	PRESENT	0
671109	669558	07029T	PARTICIPANT	\N	PRESENT	0
671110	669558	19667J	PARTICIPANT	\N	PRESENT	0
671111	669569	14001X	PARTICIPANT	\N	PRESENT	0
671112	669569	19301E	PARTICIPANT	\N	PRESENT	0
671113	669569	19585H	PARTICIPANT	\N	PRESENT	0
671114	669569	19725B	PARTICIPANT	\N	PRESENT	0
671115	669569	19954N	PARTICIPANT	\N	PRESENT	0
671116	669569	95063L	PARTICIPANT	\N	PRESENT	0
671117	669569	14107H	PARTICIPANT	\N	PRESENT	0
671118	669569	14147R	PARTICIPANT	\N	PRESENT	0
671119	669569	04008A	PARTICIPANT	\N	PRESENT	0
671120	669569	20022R	PARTICIPANT	\N	PRESENT	0
671121	669569	11072N	PARTICIPANT	\N	PRESENT	0
671122	669558	04071H	PARTICIPANT	\N	PRESENT	0
671123	669569	14089Y	PARTICIPANT	\N	EXCUSE	0
671124	669558	19531S	PARTICIPANT	\N	PRESENT	0
671239	671238	19507S	PARTICIPANT	\N	PRESENT	0
671240	671238	19413M	PARTICIPANT	\N	PRESENT	0
671241	671238	01025N	PARTICIPANT	\N	PRESENT	0
671539	671538	14109K	PARTICIPANT	\N	PRESENT	0
671540	671538	14105F	PARTICIPANT	\N	PRESENT	0
671541	671538	19782L	PARTICIPANT	\N	PRESENT	0
671542	671538	20028X	PARTICIPANT	\N	PRESENT	0
671867	669570	95063L	PARTICIPANT	\N	PRESENT	0
671869	669570	04047H	PRESIDENT	0	PRESENT	0
671870	669570	05008E	PARTICIPANT	\N	PRESENT	0
671871	669570	19954N	PARTICIPANT	\N	PRESENT	0
671872	669570	20110Q	PARTICIPANT	\N	PRESENT	0
671873	669570	11056N	PARTICIPANT	\N	PRESENT	0
671891	669570	20022R	PARTICIPANT	\N	PRESENT	0
671892	669570	14259Y	PARTICIPANT	\N	PRESENT	0
671893	669570	19649G	PARTICIPANT	\N	PRESENT	0
671894	669570	14001X	PARTICIPANT	\N	PRESENT	0
671900	669570	14053L	PARTICIPANT	\N	PRESENT	0
671901	669570	19301E	PARTICIPANT	\N	PRESENT	0
671917	669570	14231L	PARTICIPANT	\N	PRESENT	0
671924	669570	10015M	PARTICIPANT	\N	PRESENT	0
671961	669570	19543W	PARTICIPANT	\N	PRESENT	0
671962	669570	19489J	PARTICIPANT	\N	PRESENT	0
671977	669570	01028R	PARTICIPANT	\N	PRESENT	0
671981	669570	14069U	PARTICIPANT	\N	PRESENT	0
671988	669571	04047H	PRESIDENT	0	PRESENT	0
671989	669571	10015M	PARTICIPANT	\N	PRESENT	0
671990	669571	95063L	PARTICIPANT	\N	PRESENT	0
671991	669571	11072N	PARTICIPANT	\N	PRESENT	0
671992	669571	19954N	PARTICIPANT	\N	PRESENT	0
671993	669571	19649G	PARTICIPANT	\N	PRESENT	0
671994	669571	01028R	PARTICIPANT	\N	PRESENT	0
671995	669571	14053L	PARTICIPANT	\N	PRESENT	0
671996	669571	14069U	PARTICIPANT	\N	PRESENT	0
671997	669571	14151M	PARTICIPANT	\N	PRESENT	0
671998	669571	20022R	PARTICIPANT	\N	PRESENT	0
672000	669571	14021P	PARTICIPANT	\N	PRESENT	0
672001	669570	14089Y	PARTICIPANT	\N	EXCUSE	0
672002	669570	14021P	PARTICIPANT	\N	EXCUSE	0
672003	669570	19729F	PARTICIPANT	\N	EXCUSE	0
672004	669571	14259Y	PARTICIPANT	\N	PRESENT	0
672005	669571	14231L	PARTICIPANT	\N	PRESENT	0
672006	669571	20110Q	PARTICIPANT	\N	PRESENT	0
672007	669571	05008E	PARTICIPANT	\N	PRESENT	0
672008	669571	19489J	PARTICIPANT	\N	PRESENT	0
672011	669571	20114U	PARTICIPANT	\N	PRESENT	0
672049	669571	14089Y	PARTICIPANT	\N	EXCUSE	0
672050	669571	19729F	PARTICIPANT	\N	EXCUSE	0
678739	676431	95063L	PARTICIPANT	\N	PRESENT	0
678743	676431	20082E	PARTICIPANT	\N	PRESENT	0
678744	676431	19711U	PARTICIPANT	\N	PRESENT	0
678746	676431	19647E	PARTICIPANT	\N	PRESENT	0
678747	676431	11040E	PARTICIPANT	\N	PRESENT	0
678749	676431	14257W	PARTICIPANT	\N	PRESENT	0
678750	676431	14251Q	PARTICIPANT	\N	PRESENT	0
678751	676431	14069U	PARTICIPANT	\N	PRESENT	0
678752	676431	19583F	PARTICIPANT	\N	PRESENT	0
678754	676431	20252E	PARTICIPANT	\N	PRESENT	0
678755	676431	20090E	PARTICIPANT	\N	PRESENT	0
678757	676431	19671E	PARTICIPANT	\N	PRESENT	0
678758	676431	19533U	PARTICIPANT	\N	PRESENT	0
678759	676431	10006L	PARTICIPANT	\N	PRESENT	0
678760	676431	20116W	PARTICIPANT	\N	PRESENT	0
678787	676431	19667J	PARTICIPANT	\N	PRESENT	0
678762	676431	14225N	PARTICIPANT	\N	PRESENT	0
678763	676431	97011G	PARTICIPANT	\N	PRESENT	0
678764	676431	19349W	PARTICIPANT	\N	PRESENT	0
678765	676431	11053K	PARTICIPANT	\N	PRESENT	0
678766	676431	19703U	PARTICIPANT	\N	PRESENT	0
678767	676431	14191V	PARTICIPANT	\N	PRESENT	0
678768	676431	19693L	PARTICIPANT	\N	PRESENT	0
678769	676431	14033T	PARTICIPANT	\N	PRESENT	0
678772	676431	19467C	PARTICIPANT	\N	PRESENT	0
678775	676431	11097X	PARTICIPANT	\N	PRESENT	0
678777	676431	19820Y	PARTICIPANT	\N	PRESENT	0
678780	676431	19649G	PARTICIPANT	\N	PRESENT	0
678779	676431	20094J	PARTICIPANT	\N	PRESENT	0
678783	676431	11070L	PARTICIPANT	\N	PRESENT	0
678788	676431	20914V	PARTICIPANT	\N	PRESENT	0
678789	676431	19637C	PARTICIPANT	\N	PRESENT	0
678790	676431	19747H	PARTICIPANT	\N	PRESENT	0
678791	676431	14215L	PARTICIPANT	\N	PRESENT	0
678796	676431	20044X	PARTICIPANT	\N	PRESENT	0
678797	676431	10015M	PARTICIPANT	\N	PRESENT	0
678798	676431	08028W	PARTICIPANT	\N	PRESENT	0
678799	676431	19335Q	PARTICIPANT	\N	PRESENT	0
678800	676431	14329V	PARTICIPANT	\N	PRESENT	0
678804	676431	20024T	PARTICIPANT	\N	PRESENT	0
678805	676431	11048N	PARTICIPANT	\N	PRESENT	0
678806	676431	14147R	PARTICIPANT	\N	PRESENT	0
678807	676431	20108W	PARTICIPANT	\N	PRESENT	0
678808	676431	19399H	PARTICIPANT	\N	PRESENT	0
678809	676431	07029T	PARTICIPANT	\N	PRESENT	0
678810	676431	18083K	PARTICIPANT	\N	PRESENT	0
678811	676431	14169X	PARTICIPANT	\N	PRESENT	0
678812	676431	20070A	PARTICIPANT	\N	PRESENT	0
678813	676431	20058E	PARTICIPANT	\N	PRESENT	0
678814	676431	14071N	PARTICIPANT	\N	PRESENT	0
678815	676431	14331P	PARTICIPANT	\N	PRESENT	0
678816	676431	20080C	PARTICIPANT	\N	PRESENT	0
678817	676431	20130U	PARTICIPANT	\N	PRESENT	0
678818	676431	11012A	PARTICIPANT	\N	PRESENT	0
678819	676431	20286Q	PARTICIPANT	\N	PRESENT	0
678820	676431	17023S	PARTICIPANT	\N	PRESENT	0
678821	676431	20028X	PARTICIPANT	\N	PRESENT	0
678822	676431	14038Y	PARTICIPANT	\N	PRESENT	0
678823	676431	19593H	PARTICIPANT	\N	PRESENT	0
678824	676431	01058X	PARTICIPANT	\N	PRESENT	0
678825	676431	19713W	PARTICIPANT	\N	PRESENT	0
678826	676431	20180F	PARTICIPANT	\N	PRESENT	0
678827	676431	19651A	PARTICIPANT	\N	PRESENT	0
678828	676431	20054A	PARTICIPANT	\N	PRESENT	0
678829	676431	20032T	PARTICIPANT	\N	PRESENT	0
678830	676431	20136B	PARTICIPANT	\N	PRESENT	0
678831	676431	99004R	PARTICIPANT	\N	PRESENT	0
678832	676431	14083S	PARTICIPANT	\N	PRESENT	0
678833	676431	19673G	PARTICIPANT	\N	PRESENT	0
678834	676431	19507S	PARTICIPANT	\N	PRESENT	0
678835	676431	19629C	PARTICIPANT	\N	PRESENT	0
678836	676431	12041X	PARTICIPANT	\N	PRESENT	0
678837	676431	14030Q	PARTICIPANT	\N	PRESENT	0
678838	676431	19691J	PARTICIPANT	\N	PRESENT	0
678839	676431	19798U	PARTICIPANT	\N	PRESENT	0
678840	676431	20152B	PARTICIPANT	\N	PRESENT	0
678841	676431	11104D	PARTICIPANT	\N	PRESENT	0
678842	676431	19301E	PARTICIPANT	\N	PRESENT	0
678843	676431	20052X	PARTICIPANT	\N	PRESENT	0
678844	676431	14189C	PARTICIPANT	\N	PRESENT	0
678845	676431	19619A	PARTICIPANT	\N	PRESENT	0
678846	676431	19739H	PARTICIPANT	\N	PRESENT	0
678847	676431	20036X	PARTICIPANT	\N	PRESENT	0
678848	676431	20120S	PARTICIPANT	\N	PRESENT	0
678849	676431	04057K	PARTICIPANT	\N	PRESENT	0
678850	676431	14105F	PARTICIPANT	\N	PRESENT	0
678851	676431	14073Q	PARTICIPANT	\N	PRESENT	0
678852	676431	19479G	PARTICIPANT	\N	PRESENT	0
678853	676431	04043D	PARTICIPANT	\N	PRESENT	0
678854	676431	14259Y	PARTICIPANT	\N	PRESENT	0
678855	676431	19367Y	PARTICIPANT	\N	PRESENT	0
678856	676431	19503N	PARTICIPANT	\N	PRESENT	0
678857	676431	08061X	PARTICIPANT	\N	PRESENT	0
678858	676431	05012A	PARTICIPANT	\N	PRESENT	0
678859	676431	20140W	PARTICIPANT	\N	PRESENT	0
678860	676431	04071H	PARTICIPANT	\N	PRESENT	0
678861	676431	14109K	PARTICIPANT	\N	PRESENT	0
678862	676431	14223L	PARTICIPANT	\N	PRESENT	0
678863	676431	20040T	PARTICIPANT	\N	PRESENT	0
678864	676431	11064N	PARTICIPANT	\N	PRESENT	0
678865	676431	19543W	PARTICIPANT	\N	PRESENT	0
678866	676431	20086J	PARTICIPANT	\N	PRESENT	0
678867	676431	01057W	PARTICIPANT	\N	PRESENT	0
678868	676431	20102Q	PARTICIPANT	\N	PRESENT	0
678869	676431	20126Y	PARTICIPANT	\N	PRESENT	0
678870	676431	08009T	PARTICIPANT	\N	PRESENT	0
678871	676431	20096L	PARTICIPANT	\N	PRESENT	0
678888	676431	20038A	PARTICIPANT	\N	PRESENT	0
678889	676431	20104S	PARTICIPANT	\N	PRESENT	0
678890	676431	04085P	PARTICIPANT	\N	PRESENT	0
678892	676431	08034U	PARTICIPANT	\N	PRESENT	0
678893	676431	19515S	PARTICIPANT	\N	PRESENT	0
678894	676431	19631V	PARTICIPANT	\N	PRESENT	0
658005	658004	19565D	PARTICIPANT	\N	PRESENT	0
659465	659464	04047H	PARTICIPANT	\N	PRESENT	0
659466	659464	19749K	PARTICIPANT	\N	PRESENT	0
659468	659464	14147R	PARTICIPANT	\N	PRESENT	0
659470	659464	14231L	PARTICIPANT	\N	PRESENT	0
659552	659551	19954N	PARTICIPANT	\N	PRESENT	0
659553	659551	20114U	PARTICIPANT	\N	PRESENT	0
659554	659551	20074E	PARTICIPANT	\N	PRESENT	0
659555	659551	20038A	PARTICIPANT	\N	PRESENT	0
659556	659551	14179A	PARTICIPANT	\N	PRESENT	0
659557	659551	19709B	PARTICIPANT	\N	PRESENT	0
659558	659551	04057K	PARTICIPANT	\N	PRESENT	0
659559	659551	14193X	PARTICIPANT	\N	PRESENT	0
659560	659551	19503N	PARTICIPANT	\N	PRESENT	0
659600	659599	20066E	PARTICIPANT	\N	PRESENT	0
663503	663502	14026U	PARTICIPANT	\N	PRESENT	0
669169	667724	01058X	PARTICIPANT	\N	PRESENT	0
669170	667724	20062A	PARTICIPANT	\N	PRESENT	0
669171	667724	20076G	PARTICIPANT	\N	PRESENT	0
669172	667724	20090E	PARTICIPANT	\N	PRESENT	0
669173	667724	19515S	PARTICIPANT	\N	PRESENT	0
669174	667724	14357A	PARTICIPANT	\N	PRESENT	0
669175	667724	19383Y	PARTICIPANT	\N	PRESENT	0
669176	667724	20032T	PARTICIPANT	\N	PRESENT	0
669177	667724	20172F	PARTICIPANT	\N	PRESENT	0
669178	667724	19747H	PARTICIPANT	\N	PRESENT	0
669179	667724	19533U	PARTICIPANT	\N	PRESENT	0
669180	667724	19573D	PARTICIPANT	\N	PRESENT	0
669181	667724	20118Y	PARTICIPANT	\N	PRESENT	0
669182	667724	20092G	PARTICIPANT	\N	PRESENT	0
669183	667724	19575F	PARTICIPANT	\N	PRESENT	0
669184	667724	19758L	PARTICIPANT	\N	PRESENT	0
669185	667724	01043Q	PARTICIPANT	\N	PRESENT	0
669186	667724	05012A	PARTICIPANT	\N	PRESENT	0
669187	667724	19577H	PARTICIPANT	\N	PRESENT	0
669188	667724	19563B	PARTICIPANT	\N	PRESENT	0
669189	667724	19719D	PARTICIPANT	\N	PRESENT	0
669190	667724	20144B	PARTICIPANT	\N	PRESENT	0
669191	667724	19715Y	PARTICIPANT	\N	PRESENT	0
669192	667724	04085P	PARTICIPANT	\N	PRESENT	0
669193	667724	20040T	PARTICIPANT	\N	PRESENT	0
669194	667724	14205J	PARTICIPANT	\N	PRESENT	0
669195	667724	20024T	PARTICIPANT	\N	PRESENT	0
669196	667724	14169X	PARTICIPANT	\N	PRESENT	0
669198	667724	14042U	PARTICIPANT	\N	PRESENT	0
669205	667724	20068G	PARTICIPANT	\N	PRESENT	0
669206	667724	14021P	PARTICIPANT	\N	PRESENT	0
669207	667698	20070A	PARTICIPANT	\N	PRESENT	0
669208	667724	20142Y	PARTICIPANT	\N	PRESENT	0
669209	667724	20028X	PARTICIPANT	\N	PRESENT	0
669210	667724	20048C	PARTICIPANT	\N	PRESENT	0
669224	667724	19441R	PARTICIPANT	\N	PRESENT	0
669225	667724	20098N	PARTICIPANT	\N	PRESENT	0
669227	667724	11097X	PARTICIPANT	\N	PRESENT	0
669228	667724	20066E	PARTICIPANT	\N	PRESENT	0
669232	667724	20134Y	PARTICIPANT	\N	PRESENT	0
669233	667724	19697Q	PARTICIPANT	\N	PRESENT	0
669234	667724	19749K	PARTICIPANT	\N	PRESENT	0
669235	667724	14038Y	PARTICIPANT	\N	PRESENT	0
669236	667724	08015R	PARTICIPANT	\N	PRESENT	0
669237	667724	11031D	PARTICIPANT	\N	PRESENT	0
669238	667724	11012A	PARTICIPANT	\N	PRESENT	0
669239	667724	14215L	PARTICIPANT	\N	PRESENT	0
669240	667724	19651A	PARTICIPANT	\N	PRESENT	0
669241	667724	11077T	PARTICIPANT	\N	PRESENT	0
669242	667724	19673G	PARTICIPANT	\N	PRESENT	0
669243	667724	20058E	PARTICIPANT	\N	PRESENT	0
669244	667724	14069U	PARTICIPANT	\N	PRESENT	0
669245	667724	19629C	PARTICIPANT	\N	PRESENT	0
669246	667724	20264J	PARTICIPANT	\N	PRESENT	0
669247	667724	20086J	PARTICIPANT	\N	PRESENT	0
669248	667724	18193Q	PARTICIPANT	\N	PRESENT	0
669249	667724	14111D	PARTICIPANT	\N	PRESENT	0
672351	672323	11101A	PARTICIPANT	\N	PRESENT	0
672356	672326	11101A	PARTICIPANT	\N	PRESENT	0
674989	672799	19669L	PARTICIPANT	\N	PRESENT	0
674990	672799	11066Q	PARTICIPANT	\N	PRESENT	0
674991	672799	08056B	PARTICIPANT	\N	PRESENT	0
674992	672799	12028B	PARTICIPANT	\N	PRESENT	0
674993	672799	11115U	PARTICIPANT	\N	PRESENT	0
674994	672799	19421M	PARTICIPANT	\N	PRESENT	0
674995	672799	19709B	PARTICIPANT	\N	PRESENT	0
674996	672799	14193X	PARTICIPANT	\N	PRESENT	0
674997	672799	19347U	PARTICIPANT	\N	PRESENT	0
674998	672799	08061X	PARTICIPANT	\N	PRESENT	0
674999	672799	14249W	PARTICIPANT	\N	PRESENT	0
675000	672799	08047A	PARTICIPANT	\N	PRESENT	0
675001	672799	20128B	PARTICIPANT	\N	PRESENT	0
675002	672799	14059S	PARTICIPANT	\N	PRESENT	0
675003	672799	04035D	PARTICIPANT	\N	PRESENT	0
675004	672799	14133K	PARTICIPANT	\N	PRESENT	0
675005	672799	11041F	PARTICIPANT	\N	PRESENT	0
675006	672799	08069G	PARTICIPANT	\N	PRESENT	0
675007	672799	01024M	PARTICIPANT	\N	PRESENT	0
675008	672799	14191V	PARTICIPANT	\N	PRESENT	0
675009	672799	19721W	PARTICIPANT	\N	PRESENT	0
675010	672799	14105F	PARTICIPANT	\N	PRESENT	0
675011	672799	20064C	PARTICIPANT	\N	PRESENT	0
675012	672799	98022P	PARTICIPANT	\N	PRESENT	0
675013	672799	14267Y	PARTICIPANT	\N	PRESENT	0
675014	672799	11064N	PARTICIPANT	\N	PRESENT	0
675015	672799	11083R	PARTICIPANT	\N	PRESENT	0
675016	672799	14211G	PARTICIPANT	\N	PRESENT	0
675017	672799	14255U	PARTICIPANT	\N	PRESENT	0
675018	672799	17023S	PARTICIPANT	\N	PRESENT	0
675019	672799	01062T	PARTICIPANT	\N	EXCUSE	0
675020	671032	20044X	PARTICIPANT	\N	PRESENT	0
675021	671032	20034V	PARTICIPANT	\N	PRESENT	0
675022	671032	19467C	PARTICIPANT	\N	PRESENT	0
675023	671032	19573D	PARTICIPANT	\N	PRESENT	0
675024	671032	20098N	PARTICIPANT	\N	PRESENT	0
675025	671032	20056C	PARTICIPANT	\N	PRESENT	0
675026	671032	20026V	PARTICIPANT	\N	PRESENT	0
675027	671032	19703U	PARTICIPANT	\N	PRESENT	0
675028	671032	11101A	PARTICIPANT	\N	PRESENT	0
675029	671032	17637T	PARTICIPANT	\N	PRESENT	0
675030	671032	04035D	PARTICIPANT	\N	PRESENT	0
675031	671032	08011M	PARTICIPANT	\N	PRESENT	0
675032	671032	19693L	PARTICIPANT	\N	PRESENT	0
675033	671032	19575F	PARTICIPANT	\N	PRESENT	0
675034	671032	99004R	PARTICIPANT	\N	PRESENT	0
675035	671032	08010L	PARTICIPANT	\N	PRESENT	0
675036	671032	04047H	PARTICIPANT	\N	PRESENT	0
675037	671032	14026U	PARTICIPANT	\N	PRESENT	0
675038	671032	19747H	PARTICIPANT	\N	PRESENT	0
675039	671032	04092N	PARTICIPANT	\N	PRESENT	0
675040	671032	18083K	PARTICIPANT	\N	PRESENT	0
675041	671032	20076G	PARTICIPANT	\N	PRESENT	0
675042	671032	20074E	PARTICIPANT	\N	PRESENT	0
675043	671032	20078J	PARTICIPANT	\N	PRESENT	0
675044	671032	17367Q	PARTICIPANT	\N	PRESENT	0
675045	671032	19715Y	PARTICIPANT	\N	PRESENT	0
675046	671032	19565D	PARTICIPANT	\N	PRESENT	0
675047	671032	19643A	PARTICIPANT	\N	PRESENT	0
675048	671032	10015M	PARTICIPANT	\N	PRESENT	0
675049	671032	19758L	PARTICIPANT	\N	PRESENT	0
675050	671032	11031D	PARTICIPANT	\N	PRESENT	0
675051	671032	11043H	PARTICIPANT	\N	PRESENT	0
675052	671032	04085P	PARTICIPANT	\N	PRESENT	0
675053	671032	19695N	PARTICIPANT	\N	PRESENT	0
675054	671032	08028W	PARTICIPANT	\N	PRESENT	0
675055	671032	04033B	PARTICIPANT	\N	PRESENT	0
675056	671032	11077T	PARTICIPANT	\N	PRESENT	0
675057	671032	19593H	PARTICIPANT	\N	PRESENT	0
675058	671032	14187A	PARTICIPANT	\N	PRESENT	0
675059	671032	20036X	PARTICIPANT	\N	PRESENT	0
675060	671032	14071N	PARTICIPANT	\N	PRESENT	0
675061	671032	20142Y	PARTICIPANT	\N	PRESENT	0
675062	671032	05008E	PARTICIPANT	\N	PRESENT	0
675063	671032	20134Y	PARTICIPANT	\N	PRESENT	0
675064	671032	19415P	PARTICIPANT	\N	PRESENT	0
675065	671032	19421M	PARTICIPANT	\N	PRESENT	0
675066	674844	19383Y	PARTICIPANT	\N	PRESENT	0
675067	674844	14038Y	PARTICIPANT	\N	PRESENT	0
675068	674844	19467C	PARTICIPANT	\N	PRESENT	0
675069	674844	19782L	PARTICIPANT	\N	PRESENT	0
675070	674844	14357A	PARTICIPANT	\N	PRESENT	0
675071	674844	19441R	PARTICIPANT	\N	PRESENT	0
675072	674844	20094J	PARTICIPANT	\N	PRESENT	0
675073	674844	11090Q	PRESIDENT	0	PRESENT	0
675075	674844	14033T	PARTICIPANT	\N	PRESENT	0
667790	667789	08034U	PARTICIPANT	\N	PRESENT	0
667792	667791	08034U	PARTICIPANT	\N	PRESENT	0
667794	667793	20914V	PARTICIPANT	\N	PRESENT	0
667796	667795	20080C	PARTICIPANT	\N	PRESENT	0
667798	667797	20080C	PARTICIPANT	\N	PRESENT	0
667800	667799	20080C	PARTICIPANT	\N	PRESENT	0
667802	667801	11048N	PARTICIPANT	\N	PRESENT	0
667804	667803	20050V	PARTICIPANT	\N	PRESENT	0
667806	667805	14331P	PARTICIPANT	\N	PRESENT	0
667807	667805	20050V	PARTICIPANT	\N	PRESENT	0
667809	667808	14331P	PARTICIPANT	\N	PRESENT	0
667811	667810	20050V	PARTICIPANT	\N	PRESENT	0
667813	667812	08010L	PARTICIPANT	\N	PRESENT	0
667815	667814	20252E	PARTICIPANT	\N	PRESENT	0
676226	671037	14133K	PARTICIPANT	\N	PRESENT	0
676227	671037	19711U	PARTICIPANT	\N	PRESENT	0
676228	671037	14215L	PARTICIPANT	\N	PRESENT	0
676229	671037	20130U	PARTICIPANT	\N	PRESENT	0
676230	671037	19525U	PARTICIPANT	\N	PRESENT	0
676231	671037	20298U	PARTICIPANT	\N	PRESENT	0
676232	671037	19621T	PARTICIPANT	\N	PRESENT	0
676233	671037	08034U	PARTICIPANT	\N	PRESENT	0
676234	671037	17023S	PARTICIPANT	\N	PRESENT	0
676235	671037	19693L	PARTICIPANT	\N	PRESENT	0
676236	671037	14069U	PARTICIPANT	\N	PRESENT	0
676239	671037	11097X	PARTICIPANT	\N	PRESENT	0
676242	671037	14030Q	PARTICIPANT	\N	PRESENT	0
676248	671037	07029T	PARTICIPANT	\N	PRESENT	0
676253	671037	08073C	PARTICIPANT	\N	PRESENT	0
676257	671037	14026U	PARTICIPANT	\N	PRESENT	0
676258	671037	14257W	PARTICIPANT	\N	PRESENT	0
676263	671037	19651A	PARTICIPANT	\N	PRESENT	0
676264	671037	20050V	PARTICIPANT	\N	PRESENT	0
676265	671037	19467C	PARTICIPANT	\N	PRESENT	0
676224	671037	11074Q	PARTICIPANT	\N	PRESENT	0
676225	671037	04085P	PARTICIPANT	\N	PRESENT	0
676266	671037	11026G	PARTICIPANT	\N	PRESENT	0
676267	671037	19671E	PARTICIPANT	\N	PRESENT	0
676268	671037	19866P	PARTICIPANT	\N	PRESENT	0
676269	671037	14331P	PARTICIPANT	\N	PRESENT	0
676270	671037	20264J	PARTICIPANT	\N	PRESENT	0
676271	671037	19647E	PARTICIPANT	\N	PRESENT	0
676272	671037	19747H	PARTICIPANT	\N	PRESENT	0
676273	671037	14231L	PARTICIPANT	\N	PRESENT	0
676274	671037	08011M	PARTICIPANT	\N	PRESENT	0
676275	671037	04071H	PARTICIPANT	\N	PRESENT	0
676276	671037	11031D	PARTICIPANT	\N	PRESENT	0
676277	671037	20136B	PARTICIPANT	\N	PRESENT	0
676278	671037	01048V	PARTICIPANT	\N	PRESENT	0
676279	671037	19577H	PARTICIPANT	\N	PRESENT	0
676280	671037	19611R	PARTICIPANT	\N	PRESENT	0
676281	671037	19335Q	PARTICIPANT	\N	PRESENT	0
676282	671037	01024M	PARTICIPANT	\N	PRESENT	0
676283	671037	20124W	PARTICIPANT	\N	PRESENT	0
676284	671037	18193Q	PARTICIPANT	\N	PRESENT	0
676285	671037	14219Q	PARTICIPANT	\N	PRESENT	0
676286	671037	19657G	PARTICIPANT	\N	PRESENT	0
676287	671037	19719D	PARTICIPANT	\N	PRESENT	0
676288	671037	08010L	PARTICIPANT	\N	PRESENT	0
676289	670816	20058E	PARTICIPANT	\N	PRESENT	0
676290	670816	20048C	PARTICIPANT	\N	PRESENT	0
676292	671037	05012A	PARTICIPANT	\N	PRESENT	0
676293	670819	19593H	PARTICIPANT	\N	PRESENT	0
676294	670819	19758L	PARTICIPANT	\N	PRESENT	0
676295	670819	14109K	PARTICIPANT	\N	PRESENT	0
676296	670819	20264J	PARTICIPANT	\N	PRESENT	0
676297	670819	20084G	PARTICIPANT	\N	PRESENT	0
676298	670819	14229S	PARTICIPANT	\N	PRESENT	0
676299	670819	19643A	PARTICIPANT	\N	PRESENT	0
676300	670819	19735D	PARTICIPANT	\N	PRESENT	0
676301	670819	20124W	PARTICIPANT	\N	PRESENT	0
676302	670819	20152B	PARTICIPANT	\N	PRESENT	0
676303	670819	20052X	PARTICIPANT	\N	PRESENT	0
676304	670819	14030Q	PARTICIPANT	\N	PRESENT	0
676305	670819	19533U	PARTICIPANT	\N	PRESENT	0
676306	670819	19621T	PARTICIPANT	\N	PRESENT	0
676307	670819	19611R	PRESIDENT	0	PRESENT	0
676308	670819	19719D	PARTICIPANT	\N	PRESENT	0
676309	671037	20120S	PARTICIPANT	\N	PRESENT	0
676310	671037	20100N	PARTICIPANT	\N	PRESENT	0
676312	676311	04047H	PARTICIPANT	\N	PRESENT	0
676313	676311	20108W	PARTICIPANT	\N	PRESENT	0
676315	676314	20108W	PARTICIPANT	\N	PRESENT	0
676316	671037	14275Y	PARTICIPANT	\N	PRESENT	0
676317	671037	14073Q	PARTICIPANT	\N	PRESENT	0
676318	671037	20040T	PARTICIPANT	\N	PRESENT	0
676331	671037	11083R	PARTICIPANT	\N	PRESENT	0
676332	671037	19715Y	PARTICIPANT	\N	PRESENT	0
676333	671037	19782L	PARTICIPANT	\N	PRESENT	0
676342	667316	11072N	PARTICIPANT	\N	PRESENT	0
676413	676412	11027H	PARTICIPANT	\N	PRESENT	0
676414	676412	14193X	PARTICIPANT	\N	PRESENT	0
676416	676415	11027H	PARTICIPANT	\N	PRESENT	0
676417	676415	14193X	PARTICIPANT	\N	PRESENT	0
676419	676418	11027H	PARTICIPANT	\N	PRESENT	0
676420	676418	14193X	PARTICIPANT	\N	PRESENT	0
676437	676433	11064N	PARTICIPANT	\N	PRESENT	0
676845	676440	14327T	PARTICIPANT	\N	PRESENT	0
676436	676433	12028B	PARTICIPANT	\N	PRESENT	0
676846	676440	20086J	PARTICIPANT	\N	PRESENT	0
676847	676440	11040E	PARTICIPANT	\N	PRESENT	0
676848	676440	14083S	PARTICIPANT	\N	PRESENT	0
676849	676440	11048N	PARTICIPANT	\N	PRESENT	0
676850	676440	19711U	PARTICIPANT	\N	PRESENT	0
676851	676440	08009T	PARTICIPANT	\N	PRESENT	0
676852	676440	99004R	PARTICIPANT	\N	PRESENT	0
676853	676440	20914V	PARTICIPANT	\N	PRESENT	0
676854	676440	20044X	PARTICIPANT	\N	PRESENT	0
676855	676440	14225N	PRESIDENT	0	PRESENT	0
676856	676440	07029T	PARTICIPANT	\N	EXCUSE	0
676857	676440	19671E	PARTICIPANT	\N	EXCUSE	0
676858	676440	20050V	PARTICIPANT	\N	PRESENT	0
676861	676440	20080C	PARTICIPANT	\N	PRESENT	0
676862	676440	19647E	PARTICIPANT	\N	PRESENT	0
676863	676440	19667J	PARTICIPANT	\N	PRESENT	0
676867	676440	19741B	PARTICIPANT	\N	PRESENT	0
677469	677468	14109K	PARTICIPANT	\N	PRESENT	1
677470	677468	19527W	PARTICIPANT	\N	PRESENT	1
677471	677468	20058E	PARTICIPANT	\N	PRESENT	1
677472	677468	14030Q	PARTICIPANT	\N	PRESENT	0
677475	677474	14109K	PARTICIPANT	\N	PRESENT	1
677476	677474	14229S	PARTICIPANT	\N	PRESENT	1
677477	677474	20058E	PARTICIPANT	\N	PRESENT	1
677478	677474	19527W	PARTICIPANT	\N	PRESENT	1
677830	676319	19443T	PARTICIPANT	\N	PRESENT	0
677831	676319	12041X	PARTICIPANT	\N	PRESENT	0
677832	676319	19565D	PARTICIPANT	\N	PRESENT	0
677833	676319	01058X	PARTICIPANT	\N	PRESENT	0
677834	676319	19669L	PARTICIPANT	\N	PRESENT	0
677835	676319	08056B	PARTICIPANT	\N	PRESENT	0
677836	676319	11115U	PARTICIPANT	\N	PRESENT	0
677837	676319	14055N	PARTICIPANT	\N	PRESENT	0
677838	676319	19421M	PARTICIPANT	\N	PRESENT	0
677839	676319	14193X	PARTICIPANT	\N	PRESENT	0
677840	676319	19347U	PARTICIPANT	\N	PRESENT	0
677841	676319	07033P	PARTICIPANT	\N	PRESENT	0
677842	676319	97011G	PARTICIPANT	\N	PRESENT	0
677843	676319	08061X	PARTICIPANT	\N	PRESENT	0
677844	676319	08047A	PARTICIPANT	\N	PRESENT	0
677845	676319	14059S	PARTICIPANT	\N	PRESENT	0
677846	676319	04035D	PARTICIPANT	\N	PRESENT	0
677847	676319	14133K	PARTICIPANT	\N	PRESENT	0
677848	676319	08069G	PARTICIPANT	\N	PRESENT	0
677849	676319	20042V	PARTICIPANT	\N	PRESENT	0
677850	676319	14105F	PARTICIPANT	\N	PRESENT	0
677851	676319	11064N	PARTICIPANT	\N	PRESENT	0
677852	676319	14211G	PARTICIPANT	\N	PRESENT	0
677853	676319	19709B	PARTICIPANT	\N	PRESENT	0
677854	676319	14191V	PARTICIPANT	\N	PRESENT	0
677858	676319	16685X	PARTICIPANT	\N	PRESENT	0
677859	676319	14249W	PARTICIPANT	\N	PRESENT	0
677860	676319	14097Y	PARTICIPANT	\N	PRESENT	0
677861	676319	20064C	PARTICIPANT	\N	PRESENT	0
677864	676319	01062T	PARTICIPANT	\N	EXCUSE	0
677880	676427	11048N	PARTICIPANT	\N	PRESENT	0
677881	676427	10015M	PARTICIPANT	\N	PRESENT	0
677882	676427	20076G	PARTICIPANT	\N	PRESENT	0
677883	676427	14225N	PARTICIPANT	\N	PRESENT	0
677884	676427	14191V	PARTICIPANT	\N	PRESENT	0
677885	676427	20028X	PARTICIPANT	\N	PRESENT	0
677886	676427	19693L	PARTICIPANT	\N	PRESENT	0
670034	670033	20024T	PARTICIPANT	\N	PRESENT	0
670035	670033	19691J	PARTICIPANT	\N	PRESENT	0
670036	670033	14026U	PARTICIPANT	\N	PRESENT	0
670037	670033	14097Y	PARTICIPANT	\N	PRESENT	0
670038	670033	07029T	PARTICIPANT	\N	PRESENT	0
670039	670033	19657G	PARTICIPANT	\N	PRESENT	0
670040	670033	19713W	PARTICIPANT	\N	PRESENT	0
670047	670031	19691J	PARTICIPANT	\N	PRESENT	0
670042	670032	19691J	PARTICIPANT	\N	PRESENT	0
671125	669558	19741B	PARTICIPANT	\N	PRESENT	0
671126	667816	19549D	PARTICIPANT	\N	PRESENT	0
670045	670032	11097X	PARTICIPANT	\N	PRESENT	0
670046	670032	10006L	PARTICIPANT	\N	PRESENT	0
671127	667816	20106U	PARTICIPANT	\N	PRESENT	0
671128	667816	19503N	PARTICIPANT	\N	PRESENT	0
671129	667816	11065P	PARTICIPANT	\N	PRESENT	0
671130	667816	08060W	PARTICIPANT	\N	EXCUSE	0
671131	669569	19489J	PARTICIPANT	\N	PRESENT	0
671132	669569	20114U	PARTICIPANT	\N	PRESENT	0
671133	669569	14151M	PARTICIPANT	\N	PRESENT	0
671134	669569	14053L	PARTICIPANT	\N	PRESENT	0
671135	669569	14069U	PARTICIPANT	\N	PRESENT	0
671136	669569	14021P	PARTICIPANT	\N	PRESENT	0
671138	667816	20096L	PARTICIPANT	\N	PRESENT	0
671139	667816	20122U	PARTICIPANT	\N	PRESENT	0
671144	669558	19762G	PARTICIPANT	\N	PRESENT	0
671145	669558	19647E	PARTICIPANT	\N	PRESENT	0
671146	667816	11101A	PARTICIPANT	\N	PRESENT	0
671147	669558	11040E	PARTICIPANT	\N	PRESENT	0
671219	667816	20118Y	PARTICIPANT	\N	PRESENT	0
671220	667816	19685L	PARTICIPANT	\N	PRESENT	0
671221	667816	20136B	PARTICIPANT	\N	PRESENT	0
671230	669569	11056N	PARTICIPANT	\N	PRESENT	0
671231	669569	19581D	PARTICIPANT	\N	PRESENT	0
671956	669896	19329S	PARTICIPANT	\N	PRESENT	0
671864	669896	19569H	PARTICIPANT	\N	PRESENT	0
671865	669896	19691J	PARTICIPANT	\N	PRESENT	0
671866	669896	19367Y	PARTICIPANT	\N	PRESENT	0
671868	669896	14217N	PARTICIPANT	\N	PRESENT	0
671955	669896	19663E	PARTICIPANT	\N	PRESENT	0
671957	669896	11045K	PARTICIPANT	\N	PRESENT	0
671958	667818	20020P	PARTICIPANT	\N	PRESENT	0
671959	667818	20024T	PARTICIPANT	\N	PRESENT	0
671960	667818	19745F	PARTICIPANT	\N	PRESENT	0
671963	669896	17779H	PARTICIPANT	\N	PRESENT	0
671964	669896	20042V	PARTICIPANT	\N	PRESENT	0
671965	669896	20172F	PARTICIPANT	\N	PRESENT	0
671966	669896	08061X	PARTICIPANT	\N	PRESENT	0
671967	669559	01048V	PARTICIPANT	\N	PRESENT	0
671968	669559	08010L	PARTICIPANT	\N	PRESENT	0
671969	669896	20052X	PARTICIPANT	\N	PRESENT	0
671970	669896	19697Q	PARTICIPANT	\N	PRESENT	0
671971	669896	19758L	PARTICIPANT	\N	PRESENT	0
671972	669896	20138D	PARTICIPANT	\N	PRESENT	0
671973	669896	20134Y	PARTICIPANT	\N	PRESENT	0
671974	669896	20122U	PARTICIPANT	\N	PRESENT	0
671975	669896	04057K	PARTICIPANT	\N	PRESENT	0
671976	667818	20106U	PARTICIPANT	\N	PRESENT	0
671978	669559	19515S	PARTICIPANT	\N	PRESENT	0
671979	669559	11048N	PARTICIPANT	\N	PRESENT	0
671980	669559	19741B	PARTICIPANT	\N	PRESENT	0
671982	669896	20148F	PARTICIPANT	\N	PRESENT	0
671983	669896	14073Q	PARTICIPANT	\N	PRESENT	0
671984	669896	01034P	PARTICIPANT	\N	PRESENT	0
671985	669896	20066E	PARTICIPANT	\N	PRESENT	0
671986	669896	11067R	PARTICIPANT	\N	PRESENT	0
672023	669559	01057W	PARTICIPANT	\N	PRESENT	0
672024	669559	19762G	PARTICIPANT	\N	PRESENT	0
672025	669896	14331P	PARTICIPANT	\N	PRESENT	0
672026	669896	14257W	PARTICIPANT	\N	PRESENT	0
672027	669896	20092G	PARTICIPANT	\N	PRESENT	0
672028	669896	14053L	PARTICIPANT	\N	PRESENT	0
672029	669896	14231L	PARTICIPANT	\N	PRESENT	0
672030	669896	19747H	PARTICIPANT	\N	PRESENT	0
672031	669896	20034V	PARTICIPANT	\N	PRESENT	0
672032	669896	20082E	PARTICIPANT	\N	PRESENT	0
672033	669896	19782L	PARTICIPANT	\N	PRESENT	0
672034	669896	20028X	PARTICIPANT	\N	PRESENT	0
672035	669896	08015R	PARTICIPANT	\N	PRESENT	0
672283	669560	14121F	PARTICIPANT	\N	PRESENT	0
672305	669560	19531S	PARTICIPANT	\N	PRESENT	0
672306	669560	08010L	PARTICIPANT	\N	PRESENT	0
672307	669560	20126Y	PARTICIPANT	\N	PRESENT	0
672308	669560	19762G	PARTICIPANT	\N	PRESENT	0
672310	669560	20070A	PARTICIPANT	\N	PRESENT	0
672311	669560	20050V	PARTICIPANT	\N	PRESENT	0
672312	669560	11053K	PARTICIPANT	\N	PRESENT	0
672313	669560	20080C	PARTICIPANT	\N	PRESENT	0
672314	669560	14083S	PARTICIPANT	\N	PRESENT	0
672315	669560	19545Y	PARTICIPANT	\N	PRESENT	0
672317	669898	14026U	PARTICIPANT	\N	PRESENT	0
672320	669560	11070L	PARTICIPANT	\N	PRESENT	0
672789	672787	19533U	PARTICIPANT	\N	PRESENT	0
674122	671029	14033T	PARTICIPANT	\N	PRESENT	0
674123	671029	14169X	PARTICIPANT	\N	PRESENT	0
674124	671029	19667J	PARTICIPANT	\N	PRESENT	0
674125	671029	20140W	PARTICIPANT	\N	PRESENT	0
674126	671029	20180F	PARTICIPANT	\N	PRESENT	0
674127	671029	20034V	PARTICIPANT	\N	PRESENT	0
674128	671029	14223L	PARTICIPANT	\N	PRESENT	0
676868	676422	11045K	PARTICIPANT	\N	PRESENT	0
676869	676422	14037X	PARTICIPANT	\N	PRESENT	0
674131	670750	20088L	PARTICIPANT	\N	PRESENT	0
676870	676422	20070A	PARTICIPANT	\N	PRESENT	0
674133	670750	19549D	PARTICIPANT	\N	PRESENT	0
676871	676422	99004R	PARTICIPANT	\N	PRESENT	0
676872	676422	19693L	PARTICIPANT	\N	PRESENT	0
676873	676422	19621T	PARTICIPANT	\N	PRESENT	0
674137	670750	20024T	PARTICIPANT	\N	PRESENT	0
676874	676422	14191V	PARTICIPANT	\N	PRESENT	0
676875	676422	14001X	PARTICIPANT	\N	PRESENT	0
676876	676422	19711U	PARTICIPANT	\N	PRESENT	0
676877	676422	20914V	PARTICIPANT	\N	PRESENT	0
676878	676422	20134Y	PARTICIPANT	\N	PRESENT	0
676879	676422	20086J	PARTICIPANT	\N	PRESENT	0
674144	671029	14133K	PARTICIPANT	\N	PRESENT	0
674145	671029	18193Q	PARTICIPANT	\N	PRESENT	0
674146	671029	14281W	PARTICIPANT	\N	PRESENT	0
674147	671029	20070A	PARTICIPANT	\N	PRESENT	0
674148	671029	11012A	PARTICIPANT	\N	PRESENT	0
674149	671029	19383Y	PARTICIPANT	\N	PRESENT	0
674150	671029	14038Y	PARTICIPANT	\N	PRESENT	0
674151	671029	14191V	PARTICIPANT	\N	PRESENT	0
674152	671029	20030R	PARTICIPANT	\N	PRESENT	0
674153	671029	20086J	PARTICIPANT	\N	PRESENT	0
674154	671029	19585H	PARTICIPANT	\N	PRESENT	0
674155	671029	19719D	PARTICIPANT	\N	PRESENT	0
674156	671029	14147R	PARTICIPANT	\N	PRESENT	0
674157	671029	19675J	PARTICIPANT	\N	PRESENT	0
674158	671029	20100N	PARTICIPANT	\N	PRESENT	0
674159	671029	11027H	PARTICIPANT	\N	PRESENT	0
674160	671029	20066E	PARTICIPANT	\N	PRESENT	0
674161	671029	19369B	PARTICIPANT	\N	PRESENT	0
674162	671029	14259Y	PARTICIPANT	\N	PRESENT	0
674163	671029	19679N	PARTICIPANT	\N	PRESENT	0
674164	671029	11064N	PARTICIPANT	\N	PRESENT	0
674165	671029	19758L	PARTICIPANT	\N	PRESENT	0
674166	671029	20118Y	PARTICIPANT	\N	PRESENT	0
674167	671029	14031R	PARTICIPANT	\N	PRESENT	0
674168	671029	20058E	PARTICIPANT	\N	PRESENT	0
676880	676422	19687N	PARTICIPANT	\N	PRESENT	0
676881	676422	11040E	PARTICIPANT	\N	PRESENT	0
676882	676422	11048N	PARTICIPANT	\N	PRESENT	0
676883	676422	14225N	PARTICIPANT	\N	PRESENT	0
676884	676422	14257W	PARTICIPANT	\N	PRESENT	0
676885	676422	19647E	PARTICIPANT	\N	PRESENT	0
676886	676422	19741B	PARTICIPANT	\N	PRESENT	0
676887	676422	20044X	PARTICIPANT	\N	PRESENT	0
676888	676422	07029T	PARTICIPANT	\N	PRESENT	0
676889	676422	14021P	PARTICIPANT	\N	PRESENT	0
676890	676422	19335Q	PARTICIPANT	\N	PRESENT	0
676891	676422	20148F	PARTICIPANT	\N	PRESENT	0
676892	676422	14083S	PARTICIPANT	\N	PRESENT	0
676893	676422	11070L	PARTICIPANT	\N	PRESENT	0
676894	676422	04071H	PARTICIPANT	\N	PRESENT	0
676895	676422	11053K	PARTICIPANT	\N	PRESENT	0
676896	676422	01048V	PARTICIPANT	\N	PRESENT	0
676897	676422	19667J	PARTICIPANT	\N	PRESENT	0
676898	676422	14327T	PARTICIPANT	\N	PRESENT	0
676899	676422	20050V	PARTICIPANT	\N	PRESENT	0
667501	665287	20072C	PARTICIPANT	\N	PRESENT	0
667504	665287	01048V	PARTICIPANT	\N	PRESENT	0
667505	665287	19593H	PARTICIPANT	\N	PRESENT	0
667506	665287	19533U	PARTICIPANT	\N	PRESENT	0
667508	665287	19503N	PARTICIPANT	\N	PRESENT	0
667523	667522	19691J	PARTICIPANT	\N	PRESENT	0
667524	667522	14071N	PARTICIPANT	\N	PRESENT	0
667529	667527	14213J	PARTICIPANT	\N	PRESENT	0
667530	667528	14042U	PARTICIPANT	\N	PRESENT	0
667531	667528	14213J	PARTICIPANT	\N	PRESENT	0
667532	667528	20130U	PARTICIPANT	\N	PRESENT	0
667717	665151	08009T	PARTICIPANT	\N	PRESENT	0
667718	665151	14107H	PARTICIPANT	\N	PRESENT	0
678895	676431	19443T	PARTICIPANT	\N	PRESENT	0
678896	676431	20110Q	PARTICIPANT	\N	PRESENT	0
678897	676431	19565D	PARTICIPANT	\N	PRESENT	0
678898	676431	19563B	PARTICIPANT	\N	PRESENT	0
678899	676431	11101A	PARTICIPANT	\N	PRESENT	0
678900	676431	19573D	PARTICIPANT	\N	PRESENT	0
678901	676431	19762G	PARTICIPANT	\N	PRESENT	0
678902	676431	11085T	PARTICIPANT	\N	PRESENT	0
678903	676431	20134Y	PARTICIPANT	\N	PRESENT	0
678904	676431	20018V	PARTICIPANT	\N	PRESENT	0
678905	676431	20062A	PARTICIPANT	\N	PRESENT	0
678906	676431	14021P	PARTICIPANT	\N	PRESENT	0
678907	676431	20056C	PARTICIPANT	\N	PRESENT	0
678908	676431	19621T	PARTICIPANT	\N	PRESENT	0
678909	676431	04047H	PARTICIPANT	\N	PRESENT	0
678910	676431	19715Y	PARTICIPANT	\N	PRESENT	0
678911	676431	14187A	PARTICIPANT	\N	PRESENT	0
678912	676431	19333N	PARTICIPANT	\N	PRESENT	0
678913	676431	11056N	PARTICIPANT	\N	PRESENT	0
678914	676431	19695N	PARTICIPANT	\N	PRESENT	0
678915	676431	11090Q	PARTICIPANT	\N	PRESENT	0
678916	676431	08056B	PARTICIPANT	\N	PRESENT	0
678917	676431	01025N	PARTICIPANT	\N	PRESENT	0
678918	676431	20142Y	PARTICIPANT	\N	PRESENT	0
678919	676431	20026V	PARTICIPANT	\N	PRESENT	0
678920	676431	19643A	PARTICIPANT	\N	PRESENT	0
678921	676431	14249W	PARTICIPANT	\N	PRESENT	0
678922	676431	14327T	PARTICIPANT	\N	PRESENT	0
678923	676431	14217N	PARTICIPANT	\N	PRESENT	0
678924	676431	20022R	PARTICIPANT	\N	PRESENT	0
678925	676431	04042C	PARTICIPANT	\N	PRESENT	0
678926	676431	19545Y	PARTICIPANT	\N	PRESENT	0
678927	676431	19387D	PARTICIPANT	\N	PRESENT	0
678928	676431	19663E	PARTICIPANT	\N	PRESENT	0
678929	676431	19760E	PARTICIPANT	\N	PRESENT	0
678930	676431	19599P	PARTICIPANT	\N	PRESENT	0
678931	676431	14001X	PARTICIPANT	\N	PRESENT	0
678932	676431	19549D	PARTICIPANT	\N	PRESENT	0
678933	676431	17965H	PARTICIPANT	\N	PRESENT	0
678934	676431	11110B	PARTICIPANT	\N	PRESENT	0
678935	676431	20098N	PARTICIPANT	\N	PRESENT	0
678936	676431	14357A	PARTICIPANT	\N	PRESENT	0
678937	676431	19295A	PARTICIPANT	\N	PRESENT	0
678941	676431	20100N	PARTICIPANT	\N	PRESENT	0
678942	676431	19489J	PARTICIPANT	\N	PRESENT	0
678943	676431	08010L	PARTICIPANT	\N	PRESENT	0
679052	676432	11070L	PARTICIPANT	\N	PRESENT	0
679053	676432	11056N	PARTICIPANT	\N	PRESENT	0
679054	676432	19295A	PARTICIPANT	\N	PRESENT	0
679055	676432	20914V	PARTICIPANT	\N	PRESENT	0
679056	676432	20116W	PARTICIPANT	\N	PRESENT	0
679057	676432	19349W	PARTICIPANT	\N	PRESENT	0
679058	676432	11048N	PARTICIPANT	\N	PRESENT	0
679059	676432	20044X	PARTICIPANT	\N	PRESENT	0
679060	676432	11031D	PARTICIPANT	\N	PRESENT	0
679061	676432	19691J	PARTICIPANT	\N	PRESENT	0
679062	676432	14327T	PARTICIPANT	\N	PRESENT	0
679063	676432	07029T	PARTICIPANT	\N	PRESENT	0
679064	676432	19643A	PARTICIPANT	\N	PRESENT	0
679065	676432	14187A	PARTICIPANT	\N	PRESENT	0
679066	676432	19711U	PARTICIPANT	\N	PRESENT	0
679067	676432	14215L	PARTICIPANT	\N	PRESENT	0
679068	676432	20070A	PARTICIPANT	\N	PRESENT	0
679069	676432	19687N	PARTICIPANT	\N	PRESENT	0
679070	676432	19673G	PARTICIPANT	\N	PRESENT	0
679071	676432	19647E	PARTICIPANT	\N	PRESENT	0
679072	676432	19335Q	PARTICIPANT	\N	PRESENT	0
679073	676432	20056C	PARTICIPANT	\N	PRESENT	0
679074	676432	20108W	PARTICIPANT	\N	PRESENT	0
679075	676432	20062A	PARTICIPANT	\N	PRESENT	0
679076	676432	19489J	PARTICIPANT	\N	PRESENT	0
679077	676432	14191V	PARTICIPANT	\N	PRESENT	0
679078	676432	11040E	PARTICIPANT	\N	PRESENT	0
679079	676432	11090Q	PARTICIPANT	\N	PRESENT	0
679080	676432	19565D	PARTICIPANT	\N	PRESENT	0
679081	676432	20080C	PARTICIPANT	\N	PRESENT	0
679082	676432	19563B	PARTICIPANT	\N	PRESENT	0
679083	676432	20100N	PARTICIPANT	\N	PRESENT	0
679084	676432	19543W	PARTICIPANT	\N	PRESENT	0
679085	676432	19671E	PARTICIPANT	\N	PRESENT	0
679086	676432	19820Y	PARTICIPANT	\N	PRESENT	0
679087	676432	20142Y	PARTICIPANT	\N	PRESENT	0
679088	676432	19760E	PARTICIPANT	\N	PRESENT	0
679089	676432	11077T	PARTICIPANT	\N	PRESENT	0
679090	676432	04085P	PARTICIPANT	\N	PRESENT	0
679091	676432	19447X	PARTICIPANT	\N	PRESENT	0
679092	676432	18083K	PARTICIPANT	\N	PRESENT	0
679093	676432	19545Y	PARTICIPANT	\N	PRESENT	0
679094	676432	20098N	PARTICIPANT	\N	PRESENT	0
679095	676432	14259Y	PARTICIPANT	\N	PRESENT	0
679096	676432	20252E	PARTICIPANT	\N	PRESENT	0
679097	676432	14037X	PARTICIPANT	\N	PRESENT	0
679098	676432	20058E	PARTICIPANT	\N	PRESENT	0
679099	676432	14257W	PARTICIPANT	\N	PRESENT	0
679100	676432	20134Y	PARTICIPANT	\N	PRESENT	0
679101	676432	01028R	PARTICIPANT	\N	PRESENT	0
679102	676432	20092G	PARTICIPANT	\N	PRESENT	0
679103	676432	19515S	PARTICIPANT	\N	PRESENT	0
679104	676432	19715Y	PARTICIPANT	\N	PRESENT	0
679105	676432	18193Q	PARTICIPANT	\N	PRESENT	0
679106	676432	19443T	PARTICIPANT	\N	PRESENT	0
679107	676432	19954N	PARTICIPANT	\N	PRESENT	0
679108	676432	19399H	PARTICIPANT	\N	PRESENT	0
679109	676432	20130U	PARTICIPANT	\N	PRESENT	0
679110	676432	20266L	PARTICIPANT	\N	PRESENT	0
679111	676432	14033T	PARTICIPANT	\N	PRESENT	0
679112	676432	19553Y	PARTICIPANT	\N	PRESENT	0
679113	676432	14026U	PARTICIPANT	\N	PRESENT	0
679114	676432	20104S	PARTICIPANT	\N	PRESENT	0
679115	676432	20086J	PARTICIPANT	\N	PRESENT	0
679116	676432	19679N	PARTICIPANT	\N	PRESENT	0
679117	676432	14225N	PARTICIPANT	\N	PRESENT	0
679118	676432	11043H	PARTICIPANT	\N	PRESENT	0
679119	676432	14053L	PARTICIPANT	\N	PRESENT	0
679120	676432	01043Q	PARTICIPANT	\N	PRESENT	0
679121	676432	19768N	PARTICIPANT	\N	PRESENT	0
679122	676432	19826F	PARTICIPANT	\N	PRESENT	0
679123	676432	20120S	PARTICIPANT	\N	PRESENT	0
679124	676432	19479G	PARTICIPANT	\N	PRESENT	0
679125	676432	19741B	PARTICIPANT	\N	PRESENT	0
679126	676432	14083S	PARTICIPANT	\N	PRESENT	0
679127	676432	20082E	PARTICIPANT	\N	PRESENT	0
679128	676432	14231L	PARTICIPANT	\N	PRESENT	0
679129	676432	04071H	PARTICIPANT	\N	PRESENT	0
679130	676432	05012A	PARTICIPANT	\N	PRESENT	0
679131	676432	20090E	PARTICIPANT	\N	PRESENT	0
679132	676432	19533U	PARTICIPANT	\N	PRESENT	0
679133	676432	20076G	PARTICIPANT	\N	PRESENT	0
679134	676432	20084G	PARTICIPANT	\N	PRESENT	0
679135	676432	19347U	PARTICIPANT	\N	PRESENT	0
679136	676432	19573D	PARTICIPANT	\N	PRESENT	0
679137	676432	20110Q	PARTICIPANT	\N	PRESENT	0
679138	676432	20054A	PARTICIPANT	\N	PRESENT	0
679139	676432	20180F	PARTICIPANT	\N	PRESENT	0
679140	676432	20038A	PARTICIPANT	\N	PRESENT	0
679141	676432	19369B	PARTICIPANT	\N	PRESENT	0
679142	676432	11110B	PARTICIPANT	\N	PRESENT	0
679143	676432	14069U	PARTICIPANT	\N	PRESENT	0
679144	676432	14237S	PARTICIPANT	\N	PRESENT	0
679145	676432	19713W	PARTICIPANT	\N	PRESENT	0
679146	676432	14073Q	PARTICIPANT	\N	PRESENT	0
679147	676432	19531S	PARTICIPANT	\N	PRESENT	0
679148	676432	14071N	PARTICIPANT	\N	PRESENT	0
654706	654299	14033T	PARTICIPANT	\N	PRESENT	0
656671	656267	19569H	PARTICIPANT	\N	PRESENT	0
656672	656267	20130U	PARTICIPANT	\N	PRESENT	0
656673	656267	19679N	PARTICIPANT	\N	PRESENT	0
656674	656268	19569H	PARTICIPANT	\N	PRESENT	0
656675	656268	20130U	PARTICIPANT	\N	PRESENT	0
656676	656268	19679N	PARTICIPANT	\N	PRESENT	0
656677	656270	18193Q	PARTICIPANT	\N	PRESENT	0
656678	656270	17965H	PARTICIPANT	\N	PRESENT	0
656679	656270	20130U	PARTICIPANT	\N	PRESENT	0
656680	656270	19569H	PARTICIPANT	\N	PRESENT	0
656681	656270	19679N	PARTICIPANT	\N	PRESENT	0
656682	656424	20130U	PARTICIPANT	\N	PRESENT	0
656683	656424	19679N	PARTICIPANT	\N	PRESENT	0
656684	656424	19760E	PARTICIPANT	\N	PRESENT	0
656685	656424	19569H	PARTICIPANT	\N	PRESENT	0
667556	667555	19467C	PARTICIPANT	\N	PRESENT	0
667557	667555	20082E	PARTICIPANT	\N	PRESENT	0
667558	667555	19511N	PARTICIPANT	\N	PRESENT	0
667559	667555	19507S	PARTICIPANT	\N	PRESENT	0
667560	667555	19531S	PARTICIPANT	\N	PRESENT	0
667561	667555	20092G	PARTICIPANT	\N	PRESENT	0
667562	667555	14033T	PARTICIPANT	\N	PRESENT	0
667563	667555	14205J	PARTICIPANT	\N	PRESENT	0
667564	667555	16685X	PARTICIPANT	\N	PRESENT	0
668834	667720	11070L	PARTICIPANT	\N	PRESENT	0
668832	667720	14038Y	PARTICIPANT	\N	PRESENT	0
668833	667720	11097X	PARTICIPANT	\N	PRESENT	0
668835	667720	17965H	PARTICIPANT	\N	PRESENT	0
668836	667720	20086J	PARTICIPANT	\N	PRESENT	0
669040	667721	19747H	PARTICIPANT	\N	PRESENT	0
669041	667721	19447X	PARTICIPANT	\N	PRESENT	0
669042	667721	19349W	PARTICIPANT	\N	PRESENT	0
669043	667721	20080C	PARTICIPANT	\N	PRESENT	0
669044	667721	20070A	PARTICIPANT	\N	PRESENT	0
669045	667721	20134Y	PARTICIPANT	\N	PRESENT	0
669046	667721	14083S	PARTICIPANT	\N	PRESENT	0
669047	667721	14207L	PARTICIPANT	\N	PRESENT	0
669048	667721	20116W	PARTICIPANT	\N	PRESENT	0
669049	667721	14147R	PARTICIPANT	\N	PRESENT	0
669050	667721	19251M	PARTICIPANT	\N	PRESENT	0
669051	667721	20028X	PARTICIPANT	\N	PRESENT	0
669052	667721	07029T	PARTICIPANT	\N	PRESENT	0
669053	667721	14331P	PARTICIPANT	\N	PRESENT	0
669054	667721	14215L	PARTICIPANT	\N	PRESENT	0
669055	667721	20298U	PARTICIPANT	\N	PRESENT	0
669056	667721	14231L	PARTICIPANT	\N	PRESENT	0
669057	667721	08061X	PARTICIPANT	\N	PRESENT	0
669058	667721	19545Y	PARTICIPANT	\N	PRESENT	0
669059	667721	19619A	PARTICIPANT	\N	PRESENT	0
669060	667721	20024T	PARTICIPANT	\N	PRESENT	0
669061	667721	18083K	PARTICIPANT	\N	PRESENT	0
669062	667721	19531S	PARTICIPANT	\N	PRESENT	0
669063	667721	20126Y	PARTICIPANT	\N	PRESENT	0
669064	667721	19762G	PARTICIPANT	\N	PRESENT	0
669065	667721	14213J	PARTICIPANT	\N	PRESENT	0
669066	667721	11097X	PARTICIPANT	\N	PRESENT	0
669067	667721	20042V	PARTICIPANT	\N	PRESENT	0
669068	667721	14217N	PARTICIPANT	\N	PRESENT	0
669069	667721	14179A	PARTICIPANT	\N	PRESENT	0
669072	667721	19387D	PARTICIPANT	\N	PRESENT	0
669073	667721	20128B	PARTICIPANT	\N	PRESENT	0
669074	667721	11065P	PARTICIPANT	\N	PRESENT	0
669075	667721	20032T	PARTICIPANT	\N	PRESENT	0
669076	667721	20112S	PARTICIPANT	\N	PRESENT	0
669077	667721	20058E	PARTICIPANT	\N	PRESENT	0
675076	674844	04045F	PARTICIPANT	\N	PRESENT	0
675077	674844	20054A	PARTICIPANT	\N	PRESENT	0
675078	674844	19631V	PARTICIPANT	\N	PRESENT	0
675079	674844	14205J	PARTICIPANT	\N	PRESENT	0
675080	674844	19705W	PARTICIPANT	\N	PRESENT	0
675081	674844	19507S	PARTICIPANT	\N	PRESENT	0
675082	674844	08015R	PARTICIPANT	\N	PRESENT	0
675083	674844	14207L	PARTICIPANT	\N	PRESENT	0
675084	674844	08028W	PARTICIPANT	\N	PRESENT	0
675085	674844	14257W	PARTICIPANT	\N	PRESENT	0
675086	674844	20028X	PARTICIPANT	\N	PRESENT	0
675087	671032	20130U	PARTICIPANT	\N	PRESENT	0
675088	671032	19621T	PARTICIPANT	\N	PRESENT	0
675089	671032	11033F	PARTICIPANT	\N	PRESENT	0
675090	671032	14069U	PARTICIPANT	\N	PRESENT	0
675091	671032	19697Q	PARTICIPANT	\N	PRESENT	0
675092	671032	04043D	PARTICIPANT	\N	PRESENT	0
675093	671032	14037X	PARTICIPANT	\N	PRESENT	0
675094	671032	19782L	PARTICIPANT	\N	PRESENT	0
675095	671032	01057W	PARTICIPANT	\N	PRESENT	0
675096	671032	14259Y	PARTICIPANT	\N	PRESENT	0
675097	671032	20092G	PARTICIPANT	\N	PRESENT	0
675098	671032	19515S	PARTICIPANT	\N	PRESENT	0
675099	671032	11072N	PARTICIPANT	\N	PRESENT	0
675100	671032	19659J	PARTICIPANT	\N	PRESENT	0
675101	671032	11083R	PARTICIPANT	\N	PRESENT	0
675102	671032	19349W	PARTICIPANT	\N	PRESENT	0
675103	671032	08061X	PARTICIPANT	\N	PRESENT	0
675104	671032	19673G	PARTICIPANT	\N	PRESENT	0
675105	671032	95063L	PARTICIPANT	\N	PRESENT	0
675106	671032	11090Q	PARTICIPANT	\N	PRESENT	0
675107	671032	11012A	PARTICIPANT	\N	PRESENT	0
675108	671032	14031R	PARTICIPANT	\N	PRESENT	0
675109	671032	19667J	PARTICIPANT	\N	PRESENT	0
675110	671032	11115U	PARTICIPANT	\N	PRESENT	0
675112	671032	14253S	PARTICIPANT	\N	PRESENT	0
675114	671032	20136B	PARTICIPANT	\N	PRESENT	0
675115	671032	19545Y	PARTICIPANT	\N	PRESENT	0
675116	671032	14195A	PARTICIPANT	\N	PRESENT	0
675117	671032	14211G	PARTICIPANT	\N	PRESENT	0
675118	671032	20032T	PARTICIPANT	\N	PRESENT	0
675119	671032	04057K	PARTICIPANT	\N	PRESENT	0
675120	671032	19585H	PARTICIPANT	\N	PRESENT	0
675121	671032	14331P	PARTICIPANT	\N	PRESENT	0
675122	671032	14105F	PARTICIPANT	\N	PRESENT	0
675123	671032	19533U	PARTICIPANT	\N	PRESENT	0
675124	671032	10006L	PARTICIPANT	\N	PRESENT	0
675125	671032	19563B	PARTICIPANT	\N	PRESENT	0
675126	671032	14111D	PARTICIPANT	\N	PRESENT	0
675127	671032	14193X	PARTICIPANT	\N	PRESENT	0
675129	671032	04059M	PARTICIPANT	\N	PRESENT	0
675131	671032	14021P	PARTICIPANT	\N	PRESENT	0
675133	671032	19671E	PARTICIPANT	\N	PRESENT	0
675134	671032	19489J	PARTICIPANT	\N	PRESENT	0
675135	671032	95041E	PARTICIPANT	\N	PRESENT	0
675136	671032	19503N	PARTICIPANT	\N	PRESENT	0
675138	671032	20252E	PARTICIPANT	\N	PRESENT	0
675139	671032	14257W	PARTICIPANT	\N	PRESENT	0
675141	671032	14217N	PARTICIPANT	\N	PRESENT	0
675142	671032	01028R	PARTICIPANT	\N	PRESENT	0
675144	671032	19631V	PARTICIPANT	\N	PRESENT	0
675145	671032	14147R	PARTICIPANT	\N	PRESENT	0
675146	671032	11045K	PARTICIPANT	\N	PRESENT	0
675148	671032	20028X	PARTICIPANT	\N	PRESENT	0
675149	671032	19549D	PARTICIPANT	\N	PRESENT	0
675150	671032	17779H	PARTICIPANT	\N	PRESENT	0
675151	671032	20172F	PARTICIPANT	\N	PRESENT	0
675152	671032	18193Q	PARTICIPANT	\N	PRESENT	0
675153	671032	20138D	PARTICIPANT	\N	PRESENT	0
675154	671032	19649G	PARTICIPANT	\N	PRESENT	0
675155	671032	08047A	PARTICIPANT	\N	PRESENT	0
675156	671032	11067R	PARTICIPANT	\N	PRESENT	0
675157	671032	20114U	PARTICIPANT	\N	PRESENT	0
675158	671032	20094J	PARTICIPANT	\N	PRESENT	0
675159	671032	19954N	PARTICIPANT	\N	PRESENT	0
675160	671032	20070A	PARTICIPANT	\N	PRESENT	0
675161	671032	20088L	PARTICIPANT	\N	PRESENT	0
675162	671032	08060W	PARTICIPANT	\N	PRESENT	0
675163	671032	14225N	PARTICIPANT	\N	PRESENT	0
675164	671032	20030R	PARTICIPANT	\N	PRESENT	0
675165	671032	20096L	PARTICIPANT	\N	PRESENT	0
675166	671032	20264J	PARTICIPANT	\N	PRESENT	0
675167	671032	19679N	PARTICIPANT	\N	PRESENT	0
675168	671032	19251M	PARTICIPANT	\N	PRESENT	0
675169	671032	08012N	PARTICIPANT	\N	PRESENT	0
675170	671032	19447X	PARTICIPANT	\N	PRESENT	0
675171	671032	11104D	PARTICIPANT	\N	PRESENT	0
675172	671032	11110B	PARTICIPANT	\N	PRESENT	0
675173	671032	11056N	PARTICIPANT	\N	PRESENT	0
675174	671032	19723Y	PARTICIPANT	\N	PRESENT	0
675175	671032	19581D	PARTICIPANT	\N	PRESENT	0
675176	671032	11074Q	PARTICIPANT	\N	PRESENT	0
675177	671032	19333N	PARTICIPANT	\N	PRESENT	0
675178	671032	19725B	PARTICIPANT	\N	PRESENT	0
675179	671032	19820Y	PARTICIPANT	\N	PRESENT	0
667742	661836	20058E	PARTICIPANT	\N	PRESENT	0
667746	667745	20086J	PARTICIPANT	\N	PRESENT	0
667748	667747	20086J	PARTICIPANT	\N	PRESENT	0
667750	667749	11012A	PARTICIPANT	\N	PRESENT	0
667751	667749	14083S	PARTICIPANT	\N	PRESENT	0
667753	667752	19647E	PARTICIPANT	\N	PRESENT	0
667755	667754	04071H	PARTICIPANT	\N	PRESENT	0
668346	668342	20024T	PARTICIPANT	\N	PRESENT	0
668349	668342	11103C	PARTICIPANT	\N	PRESENT	0
668351	668342	14329V	PARTICIPANT	\N	PRESENT	0
668354	668342	14357A	PARTICIPANT	\N	PRESENT	0
668356	668342	20038A	PARTICIPANT	\N	PRESENT	0
668358	668342	16685X	PARTICIPANT	\N	PRESENT	0
668360	668342	20118Y	PARTICIPANT	\N	PRESENT	0
668361	668342	05012A	PARTICIPANT	\N	PRESENT	0
676238	676237	20022R	PARTICIPANT	\N	PRESENT	0
676240	676237	14151M	PARTICIPANT	\N	PRESENT	0
676241	676237	19581D	PARTICIPANT	\N	PRESENT	0
676244	676243	20022R	PARTICIPANT	\N	PRESENT	0
676245	676243	14151M	PARTICIPANT	\N	PRESENT	0
676250	676249	20022R	PARTICIPANT	\N	PRESENT	0
676251	676249	14151M	PARTICIPANT	\N	PRESENT	0
676252	676249	20114U	PARTICIPANT	\N	PRESENT	0
676255	676254	20022R	PARTICIPANT	\N	PRESENT	0
676256	676254	14151M	PARTICIPANT	\N	PRESENT	0
676260	676259	20022R	PARTICIPANT	\N	PRESENT	0
676261	676259	14151M	PARTICIPANT	\N	PRESENT	0
676262	676259	14053L	PARTICIPANT	\N	PRESENT	0
677887	676427	11110B	PARTICIPANT	\N	PRESENT	0
677888	676427	14069U	PARTICIPANT	\N	PRESENT	0
677889	676427	08034U	PARTICIPANT	\N	PRESENT	0
677890	676427	11074Q	PARTICIPANT	\N	PRESENT	0
677891	676427	20030R	PARTICIPANT	\N	PRESENT	0
677892	676427	14071N	PARTICIPANT	\N	PRESENT	0
677893	676427	20036X	PARTICIPANT	\N	PRESENT	0
677894	676427	20914V	PARTICIPANT	\N	PRESENT	0
677895	676427	14111D	PARTICIPANT	\N	PRESENT	0
677896	676427	01057W	PARTICIPANT	\N	PRESENT	0
677897	676427	19531S	PARTICIPANT	\N	PRESENT	0
677898	676427	14037X	PARTICIPANT	\N	PRESENT	0
677899	676427	20068G	PARTICIPANT	\N	PRESENT	0
677900	676427	11012A	PARTICIPANT	\N	PRESENT	0
677901	676427	19711U	PARTICIPANT	\N	PRESENT	0
677902	676427	19629C	PARTICIPANT	\N	PRESENT	0
677903	676427	11070L	PARTICIPANT	\N	PRESENT	0
677904	676427	20142Y	PARTICIPANT	\N	PRESENT	0
677905	676427	19301E	PARTICIPANT	\N	PRESENT	0
677906	676427	20032T	PARTICIPANT	\N	PRESENT	0
677907	676427	20024T	PARTICIPANT	\N	PRESENT	0
677908	676427	19954N	PARTICIPANT	\N	PRESENT	0
677909	676427	07029T	PARTICIPANT	\N	PRESENT	0
677910	676427	04045F	PARTICIPANT	\N	PRESENT	0
677911	676427	99004R	PARTICIPANT	\N	PRESENT	0
677912	676427	19651A	PARTICIPANT	\N	PRESENT	0
677913	676427	19349W	PARTICIPANT	\N	PRESENT	0
677914	676427	19621T	PARTICIPANT	\N	PRESENT	0
677915	676427	19335Q	PARTICIPANT	\N	PRESENT	0
677916	676427	14083S	PARTICIPANT	\N	PRESENT	0
677917	676427	19667J	PARTICIPANT	\N	PRESENT	0
677918	676427	19663E	PARTICIPANT	\N	PRESENT	0
677919	676427	20044X	PARTICIPANT	\N	PRESENT	0
677920	676427	14147R	PARTICIPANT	\N	PRESENT	0
677921	676427	04057K	PARTICIPANT	\N	PRESENT	0
677922	676427	14026U	PARTICIPANT	\N	PRESENT	0
677923	676427	19687N	PARTICIPANT	\N	PRESENT	0
677924	676427	20054A	PARTICIPANT	\N	PRESENT	0
677925	676427	20070A	PARTICIPANT	\N	PRESENT	0
677926	676427	14038Y	PARTICIPANT	\N	PRESENT	0
677927	676427	20080C	PARTICIPANT	\N	PRESENT	0
677930	676427	19479G	PARTICIPANT	\N	PRESENT	0
677931	676427	19647E	PARTICIPANT	\N	PRESENT	0
677932	676427	14107H	PARTICIPANT	\N	PRESENT	0
677933	676427	14253S	PARTICIPANT	\N	PRESENT	0
677934	676427	19575F	PARTICIPANT	\N	PRESENT	0
677935	676427	08018U	PARTICIPANT	\N	PRESENT	0
677936	676427	20252E	PARTICIPANT	\N	PRESENT	0
677937	676427	14033T	PARTICIPANT	\N	PRESENT	0
677938	676427	11043H	PARTICIPANT	\N	PRESENT	0
677939	676427	14073Q	PARTICIPANT	\N	PRESENT	0
677940	676427	20098N	PARTICIPANT	\N	PRESENT	0
677941	676427	14327T	PARTICIPANT	\N	PRESENT	0
677942	676427	14259Y	PARTICIPANT	\N	PRESENT	0
677943	676427	19611R	PARTICIPANT	\N	PRESENT	0
677944	676427	19573D	PARTICIPANT	\N	PRESENT	0
677945	676427	19515S	PARTICIPANT	\N	PRESENT	0
677946	676427	05012A	PARTICIPANT	\N	PRESENT	0
677947	676427	19725B	PARTICIPANT	\N	PRESENT	0
677948	676427	19701S	PARTICIPANT	\N	PRESENT	0
677949	676427	08015R	PARTICIPANT	\N	PRESENT	0
677950	676427	19581D	PARTICIPANT	\N	PRESENT	0
677951	676427	14089Y	PARTICIPANT	\N	PRESENT	0
677952	676427	17367Q	PARTICIPANT	\N	PRESENT	0
677956	676427	19507S	PARTICIPANT	\N	PRESENT	0
677954	676427	14179A	PARTICIPANT	\N	PRESENT	0
677955	676427	95063L	PARTICIPANT	\N	PRESENT	0
677957	676427	19467C	PARTICIPANT	\N	PRESENT	0
677958	676427	14257W	PARTICIPANT	\N	PRESENT	0
677960	676427	20104S	PARTICIPANT	\N	PRESENT	0
677962	676427	14237S	PARTICIPANT	\N	PRESENT	0
677968	676427	20082E	PARTICIPANT	\N	PRESENT	0
677972	676427	19758L	PARTICIPANT	\N	PRESENT	0
677973	676427	19713W	PARTICIPANT	\N	PRESENT	0
677974	676427	20134Y	PARTICIPANT	\N	PRESENT	0
677975	676427	19699S	PARTICIPANT	\N	PRESENT	0
677976	676427	19798U	PARTICIPANT	\N	PRESENT	0
677977	676427	17023S	PARTICIPANT	\N	PRESENT	0
677978	676427	97011G	PARTICIPANT	\N	PRESENT	0
677979	676427	19333N	PARTICIPANT	\N	PRESENT	0
677980	676427	20100N	PARTICIPANT	\N	PRESENT	0
677981	676427	18083K	PARTICIPANT	\N	PRESENT	0
677982	676427	11053K	PARTICIPANT	\N	PRESENT	0
677983	676427	19441R	PARTICIPANT	\N	PRESENT	0
677984	676427	20092G	PARTICIPANT	\N	PRESENT	0
678030	676427	20034V	PARTICIPANT	\N	PRESENT	0
678033	676427	20120S	PARTICIPANT	\N	PRESENT	0
678367	676429	11085T	PARTICIPANT	\N	PRESENT	0
678368	676429	14030Q	PARTICIPANT	\N	PRESENT	0
678369	676429	19699S	PARTICIPANT	\N	PRESENT	0
678370	676429	19441R	PARTICIPANT	\N	PRESENT	0
678371	676429	20108W	PARTICIPANT	\N	PRESENT	0
678372	676429	20144B	PARTICIPANT	\N	PRESENT	0
678373	676429	19335Q	PARTICIPANT	\N	PRESENT	0
678374	676429	14169X	PARTICIPANT	\N	PRESENT	0
678375	676429	07029T	PARTICIPANT	\N	PRESENT	0
678376	676429	14229S	PARTICIPANT	\N	PRESENT	0
678377	676429	19565D	PARTICIPANT	\N	PRESENT	0
678378	676429	19719D	PARTICIPANT	\N	PRESENT	0
678379	676429	20070A	PARTICIPANT	\N	PRESENT	0
678380	676429	14123H	PARTICIPANT	\N	PRESENT	0
678381	676429	01043Q	PARTICIPANT	\N	PRESENT	0
678382	676429	01034P	PARTICIPANT	\N	PRESENT	0
678383	676429	14189C	PARTICIPANT	\N	PRESENT	0
678384	676429	20094J	PARTICIPANT	\N	PRESENT	0
678385	676429	08011M	PARTICIPANT	\N	PRESENT	0
678386	676429	20286Q	PARTICIPANT	\N	PRESENT	0
678387	676429	17023S	PARTICIPANT	\N	PRESENT	0
678388	676429	20018V	PARTICIPANT	\N	PRESENT	0
678389	676429	11026G	PARTICIPANT	\N	PRESENT	0
678393	676429	19671E	PARTICIPANT	\N	PRESENT	0
678394	676429	17637T	PARTICIPANT	\N	PRESENT	0
678392	676429	20152B	PARTICIPANT	\N	PRESENT	0
678395	676429	08012N	PARTICIPANT	\N	PRESENT	0
678396	676429	92040Q	PARTICIPANT	\N	PRESENT	0
678397	676429	16685X	PARTICIPANT	\N	PRESENT	0
678401	676429	14089Y	PARTICIPANT	\N	PRESENT	0
678399	676429	14251Q	PARTICIPANT	\N	PRESENT	0
678400	676429	01058X	PARTICIPANT	\N	PRESENT	0
678402	676429	14179A	PARTICIPANT	\N	PRESENT	0
678403	676429	20048C	PARTICIPANT	\N	PRESENT	0
678404	676429	19591F	PARTICIPANT	\N	PRESENT	0
678405	676429	14237S	PARTICIPANT	\N	PRESENT	0
678414	676429	17779H	PARTICIPANT	\N	PRESENT	0
678409	676429	05008E	PARTICIPANT	\N	PRESENT	0
678413	676429	20120S	PARTICIPANT	\N	PRESENT	0
678415	676429	20064C	PARTICIPANT	\N	PRESENT	0
678417	676429	19489J	PARTICIPANT	\N	PRESENT	0
678770	678748	19415P	PARTICIPANT	\N	PRESENT	0
678771	678748	14042U	PARTICIPANT	\N	PRESENT	0
678773	678748	18193Q	PARTICIPANT	\N	PRESENT	0
678774	678748	20130U	PARTICIPANT	\N	PRESENT	0
678776	678748	17965H	PARTICIPANT	\N	PRESENT	0
655186	655185	11083R	PARTICIPANT	\N	PRESENT	0
655188	655187	19826F	PARTICIPANT	\N	PRESENT	0
655189	655187	14071N	PARTICIPANT	\N	PRESENT	0
655191	655190	19766L	PARTICIPANT	\N	PRESENT	0
655192	655190	11083R	PARTICIPANT	\N	PRESENT	0
655193	655190	99004R	PARTICIPANT	\N	PRESENT	0
657405	657403	14042U	PARTICIPANT	\N	PRESENT	0
657406	657403	14213J	PARTICIPANT	\N	PRESENT	1
657407	657404	14042U	PARTICIPANT	\N	PRESENT	0
667223	666524	14042U	PARTICIPANT	\N	PRESENT	0
667228	666524	11097X	PARTICIPANT	\N	PRESENT	0
667229	666524	01034P	PARTICIPANT	\N	PRESENT	0
667615	667614	05008E	PARTICIPANT	\N	PRESENT	0
667616	667614	11053K	PARTICIPANT	\N	PRESENT	0
667617	667614	01028R	PARTICIPANT	\N	PRESENT	0
676900	676422	11012A	PARTICIPANT	\N	PRESENT	0
676901	676422	08009T	PARTICIPANT	\N	PRESENT	0
676902	676422	20080C	PARTICIPANT	\N	PRESENT	0
676903	676422	14059S	PARTICIPANT	\N	PRESENT	0
676904	676422	11110B	PARTICIPANT	\N	PRESENT	0
676905	676422	20124W	PARTICIPANT	\N	PRESENT	0
676906	676422	20030R	PARTICIPANT	\N	PRESENT	0
676907	676422	19657G	PARTICIPANT	\N	PRESENT	0
676914	676422	20152B	PARTICIPANT	\N	PRESENT	0
676915	676422	11097X	PARTICIPANT	\N	PRESENT	0
676916	676422	19691J	PARTICIPANT	\N	PRESENT	0
676917	676422	20096L	PARTICIPANT	\N	PRESENT	0
676921	676422	19643A	PARTICIPANT	\N	PRESENT	0
676919	676422	14173T	PARTICIPANT	\N	PRESENT	0
676920	676422	20252E	PARTICIPANT	\N	PRESENT	0
676922	676422	20142Y	PARTICIPANT	\N	PRESENT	0
676923	676422	20136B	PARTICIPANT	\N	PRESENT	0
676924	676422	20092G	PARTICIPANT	\N	PRESENT	0
676925	676422	20094J	PARTICIPANT	\N	PRESENT	0
676926	676422	14205J	PARTICIPANT	\N	PRESENT	0
676927	676422	19577H	PARTICIPANT	\N	PRESENT	0
676928	676422	19479G	PARTICIPANT	\N	PRESENT	0
676929	676422	95063L	PARTICIPANT	\N	PRESENT	0
676930	676422	08061X	PARTICIPANT	\N	PRESENT	0
676931	676422	11077T	PARTICIPANT	\N	PRESENT	0
676932	676422	19820Y	PARTICIPANT	\N	PRESENT	0
676933	676422	19543W	PARTICIPANT	\N	PRESENT	0
676987	676423	11040E	PARTICIPANT	\N	PRESENT	0
676988	676423	19820Y	PARTICIPANT	\N	PRESENT	0
676989	676423	14257W	PARTICIPANT	\N	PRESENT	0
676990	676423	01048V	PARTICIPANT	\N	PRESENT	0
676991	676423	20080C	PARTICIPANT	\N	PRESENT	0
676992	676423	19711U	PARTICIPANT	\N	PRESENT	0
676993	676423	20100N	PARTICIPANT	\N	PRESENT	0
676994	676423	20092G	PARTICIPANT	\N	PRESENT	0
676995	676423	20136B	PARTICIPANT	\N	PRESENT	0
676996	676423	20142Y	PARTICIPANT	\N	PRESENT	0
676997	676423	20914V	PARTICIPANT	\N	PRESENT	0
676998	676423	20024T	PARTICIPANT	\N	PRESENT	0
676999	676423	14021P	PARTICIPANT	\N	PRESENT	0
677000	676423	20074E	PARTICIPANT	\N	PRESENT	0
677001	676423	20044X	PARTICIPANT	\N	PRESENT	0
677002	676423	14037X	PARTICIPANT	\N	PRESENT	0
677003	676423	95063L	PARTICIPANT	\N	PRESENT	0
677004	676423	19693L	PARTICIPANT	\N	PRESENT	0
677005	676423	20134Y	PARTICIPANT	\N	PRESENT	0
677006	676423	14327T	PARTICIPANT	\N	PRESENT	0
677007	676423	19479G	PARTICIPANT	\N	PRESENT	0
677008	676423	20086J	PARTICIPANT	\N	PRESENT	0
677009	676423	14211G	PARTICIPANT	\N	PRESENT	0
677010	676423	11097X	PARTICIPANT	\N	PRESENT	0
677011	676423	11070L	PARTICIPANT	\N	PRESENT	0
677012	676423	19741B	PARTICIPANT	\N	PRESENT	0
677013	676423	14038Y	PARTICIPANT	\N	PRESENT	0
677014	676423	19687N	PARTICIPANT	\N	PRESENT	0
677015	676423	14205J	PARTICIPANT	\N	PRESENT	0
677016	676423	19543W	PARTICIPANT	\N	PRESENT	0
677017	676423	14083S	PARTICIPANT	\N	PRESENT	0
677018	676423	14219Q	PARTICIPANT	\N	PRESENT	0
677019	676423	20180F	PARTICIPANT	\N	PRESENT	0
677020	676423	20124W	PARTICIPANT	\N	PRESENT	0
677021	676423	20094J	PARTICIPANT	\N	PRESENT	0
677022	676423	07029T	PARTICIPANT	\N	PRESENT	0
677023	676423	19369B	PARTICIPANT	\N	PRESENT	0
677024	676423	19621T	PARTICIPANT	\N	PRESENT	0
677025	676423	19667J	PARTICIPANT	\N	PRESENT	0
677026	676423	14331P	PARTICIPANT	\N	PRESENT	0
677027	676423	19649G	PARTICIPANT	\N	PRESENT	0
677028	676423	19647E	PARTICIPANT	\N	PRESENT	0
677029	676423	19583F	PARTICIPANT	\N	PRESENT	0
677030	676423	14253S	PARTICIPANT	\N	PRESENT	0
677031	676423	20070A	PARTICIPANT	\N	PRESENT	0
677032	676423	11053K	PARTICIPANT	\N	PRESENT	0
677033	676423	19591F	PARTICIPANT	\N	PRESENT	0
677034	676423	19335Q	PARTICIPANT	\N	PRESENT	0
677035	676423	11048N	PARTICIPANT	\N	PRESENT	0
677036	676423	20096L	PARTICIPANT	\N	PRESENT	0
677037	676423	14225N	PARTICIPANT	\N	PRESENT	0
676985	676423	99004R	PARTICIPANT	\N	PRESENT	0
676986	676423	11012A	PARTICIPANT	\N	PRESENT	0
677038	676423	19531S	PARTICIPANT	\N	PRESENT	0
677039	676423	11110B	PARTICIPANT	\N	PRESENT	0
677040	676423	04043D	PARTICIPANT	\N	PRESENT	0
677041	676423	14191V	PARTICIPANT	\N	PRESENT	0
677042	676423	14173T	PARTICIPANT	\N	PRESENT	0
677043	676423	19651A	PARTICIPANT	\N	PRESENT	0
677044	676423	20108W	PARTICIPANT	\N	PRESENT	0
677045	676423	20018V	PARTICIPANT	\N	PRESENT	0
677046	676423	11077T	PARTICIPANT	\N	PRESENT	0
677047	676423	11045K	PARTICIPANT	\N	PRESENT	0
677048	676423	19671E	PARTICIPANT	\N	PRESENT	0
677049	676423	14237S	PARTICIPANT	\N	PRESENT	0
677050	676423	14215L	PARTICIPANT	\N	PRESENT	0
677051	676423	19347U	PARTICIPANT	\N	PRESENT	0
677052	676423	14001X	PARTICIPANT	\N	PRESENT	0
677053	676423	08009T	PARTICIPANT	\N	PRESENT	0
677054	676423	14187A	PARTICIPANT	\N	PRESENT	0
677055	676423	08061X	PARTICIPANT	\N	PRESENT	0
677056	676423	20252E	PARTICIPANT	\N	PRESENT	0
677057	676423	19709B	PARTICIPANT	\N	PRESENT	0
677058	676423	05008E	PARTICIPANT	\N	PRESENT	0
677059	676423	14069U	PARTICIPANT	\N	PRESENT	0
677060	676423	20148F	PARTICIPANT	\N	PRESENT	0
677061	676423	19301E	PARTICIPANT	\N	PRESENT	0
677062	676423	11056N	PARTICIPANT	\N	PRESENT	0
677063	676423	19295A	PARTICIPANT	\N	PRESENT	0
677064	676423	19691J	PARTICIPANT	\N	PRESENT	0
677065	676423	20030R	PARTICIPANT	\N	PRESENT	0
677066	676423	19657G	PARTICIPANT	\N	PRESENT	0
677067	676423	19577H	PARTICIPANT	\N	PRESENT	0
677068	676423	20026V	PARTICIPANT	\N	PRESENT	0
677074	676423	04047H	PARTICIPANT	\N	PRESENT	0
677070	676423	14151M	PARTICIPANT	\N	PRESENT	0
677071	676423	19349W	PARTICIPANT	\N	PRESENT	0
677072	676423	19719D	PARTICIPANT	\N	PRESENT	0
677073	676423	04071H	PARTICIPANT	\N	PRESENT	0
677075	676423	20050V	PARTICIPANT	\N	PRESENT	0
677076	676423	20058E	PARTICIPANT	\N	PRESENT	0
677077	676423	14073Q	PARTICIPANT	\N	PRESENT	0
679149	676432	19782L	PARTICIPANT	\N	PRESENT	0
679150	676432	19503N	PARTICIPANT	\N	PRESENT	0
679151	676432	20126Y	PARTICIPANT	\N	PRESENT	0
679152	676432	20124W	PARTICIPANT	\N	PRESENT	0
679153	676432	20040T	PARTICIPANT	\N	PRESENT	0
679154	676432	20298U	PARTICIPANT	\N	PRESENT	0
679165	676432	08061X	PARTICIPANT	\N	PRESENT	0
679166	676585	12041X	PARTICIPANT	\N	PRESENT	0
679180	676441	14327T	PARTICIPANT	\N	PRESENT	0
679181	676441	04071H	PARTICIPANT	\N	PRESENT	0
679182	676441	11048N	PARTICIPANT	\N	PRESENT	0
679183	676441	19479G	PARTICIPANT	\N	PRESENT	0
679184	676441	19711U	PRESIDENT	0	PRESENT	0
679200	676441	19531S	PARTICIPANT	\N	PRESENT	0
679186	676441	01057W	PARTICIPANT	\N	PRESENT	0
679187	676441	20080C	PARTICIPANT	\N	PRESENT	0
679188	676441	20044X	PARTICIPANT	\N	PRESENT	0
679189	676441	20252E	PARTICIPANT	\N	PRESENT	0
679190	676441	20070A	PARTICIPANT	\N	PRESENT	0
679191	676441	19349W	PARTICIPANT	\N	PRESENT	0
679192	676441	14121F	PARTICIPANT	\N	PRESENT	0
679193	676441	19741B	PARTICIPANT	\N	PRESENT	0
679194	676441	08010L	PARTICIPANT	\N	PRESENT	0
679195	676441	99004R	PARTICIPANT	\N	PRESENT	0
679196	676441	14253S	PARTICIPANT	\N	PRESENT	0
679197	676441	07029T	PARTICIPANT	\N	PRESENT	0
679198	676441	20126Y	PARTICIPANT	\N	PRESENT	0
679199	676441	14225N	PARTICIPANT	\N	PRESENT	0
679202	676585	20080C	PARTICIPANT	\N	PRESENT	0
679203	676585	20070A	PARTICIPANT	\N	PRESENT	0
679204	676585	19820Y	PARTICIPANT	\N	PRESENT	0
679205	676585	19693L	PARTICIPANT	\N	PRESENT	0
679206	676585	14121F	PARTICIPANT	\N	PRESENT	0
679207	676585	99004R	PARTICIPANT	\N	PRESENT	0
679208	676585	01048V	PARTICIPANT	\N	PRESENT	0
679209	676585	19503N	PARTICIPANT	\N	PRESENT	0
679210	676585	20084G	PARTICIPANT	\N	PRESENT	0
679211	676585	19711U	PARTICIPANT	\N	PRESENT	0
679212	676585	11104D	PARTICIPANT	\N	PRESENT	0
679213	676585	19443T	PARTICIPANT	\N	PRESENT	0
679214	676585	20106U	PARTICIPANT	\N	PRESENT	0
679215	676585	05012A	PARTICIPANT	\N	PRESENT	0
679216	676585	14021P	PARTICIPANT	\N	PRESENT	0
679217	676585	14253S	PARTICIPANT	\N	PRESENT	0
679218	676585	20134Y	PARTICIPANT	\N	PRESENT	0
679219	676585	14069U	PARTICIPANT	\N	PRESENT	0
679220	676585	20038A	PARTICIPANT	\N	PRESENT	0
679221	676585	19659J	PARTICIPANT	\N	PRESENT	0
679222	676585	20044X	PARTICIPANT	\N	PRESENT	0
679223	676585	14257W	PARTICIPANT	\N	PRESENT	0
679224	676585	07029T	PARTICIPANT	\N	PRESENT	0
679225	676585	14033T	PARTICIPANT	\N	PRESENT	0
679226	676585	14207L	PARTICIPANT	\N	PRESENT	0
679227	676585	19741B	PARTICIPANT	\N	PRESENT	0
679228	676585	20132W	PARTICIPANT	\N	PRESENT	0
679229	676585	19399H	PARTICIPANT	\N	PRESENT	0
679230	676585	11012A	PARTICIPANT	\N	PRESENT	0
679231	676585	14327T	PARTICIPANT	\N	PRESENT	0
679232	676585	20062A	PARTICIPANT	\N	PRESENT	0
679233	676585	19479G	PARTICIPANT	\N	PRESENT	0
679234	676585	20090E	PARTICIPANT	\N	PRESENT	0
679235	676585	14189C	PARTICIPANT	\N	PRESENT	0
679236	676585	19762G	PARTICIPANT	\N	PRESENT	0
679237	676585	20252E	PARTICIPANT	\N	PRESENT	0
679238	676585	14215L	PARTICIPANT	\N	PRESENT	0
679239	676585	14225N	PARTICIPANT	\N	PRESENT	0
679240	676585	19533U	PARTICIPANT	\N	PRESENT	0
679241	676585	01057W	PARTICIPANT	\N	PRESENT	0
679242	676585	11048N	PARTICIPANT	\N	PRESENT	0
679243	676585	10015M	PARTICIPANT	\N	PRESENT	0
679244	676585	04071H	PARTICIPANT	\N	PRESENT	0
679246	676585	14083S	PARTICIPANT	\N	PRESENT	0
679247	676585	20914V	PARTICIPANT	\N	PRESENT	0
679248	676585	11040E	PARTICIPANT	\N	PRESENT	0
679254	676585	20104S	PARTICIPANT	\N	PRESENT	0
679257	676585	14187A	PARTICIPANT	\N	PRESENT	0
679260	676585	19826F	PARTICIPANT	\N	PRESENT	0
679261	676585	20024T	PARTICIPANT	\N	PRESENT	0
679262	676585	20032T	PARTICIPANT	\N	PRESENT	0
679263	676585	20142Y	PARTICIPANT	\N	PRESENT	0
679264	676585	19333N	PARTICIPANT	\N	PRESENT	0
679265	676585	04059M	PARTICIPANT	\N	PRESENT	0
679266	676585	19349W	PARTICIPANT	\N	PRESENT	0
679267	676585	20048C	PARTICIPANT	\N	PRESENT	0
679268	676585	20136B	PARTICIPANT	\N	PRESENT	0
679269	676585	19335Q	PARTICIPANT	\N	PRESENT	0
679270	676585	19531S	PARTICIPANT	\N	PRESENT	0
679271	676585	19545Y	PARTICIPANT	\N	PRESENT	0
679272	676585	14059S	PARTICIPANT	\N	PRESENT	0
679273	676585	97011G	PARTICIPANT	\N	PRESENT	0
679274	676585	11070L	PARTICIPANT	\N	PRESENT	0
679275	676585	19687N	PARTICIPANT	\N	PRESENT	0
679276	676585	08010L	PARTICIPANT	\N	PRESENT	0
679277	676585	19747H	PARTICIPANT	\N	PRESENT	0
679278	676585	11074Q	PARTICIPANT	\N	PRESENT	0
679279	676585	18083K	PARTICIPANT	\N	PRESENT	0
679280	676585	19573D	PARTICIPANT	\N	PRESENT	0
679281	676585	11056N	PARTICIPANT	\N	PRESENT	0
679282	676585	08012N	PARTICIPANT	\N	PRESENT	0
679283	676585	20056C	PARTICIPANT	\N	PRESENT	0
679284	676585	01043Q	PARTICIPANT	\N	PRESENT	0
679285	676585	19715Y	PARTICIPANT	\N	PRESENT	0
679286	676585	19651A	PARTICIPANT	\N	PRESENT	0
679287	676585	14111D	PARTICIPANT	\N	PRESENT	0
679288	676585	19441R	PARTICIPANT	\N	PRESENT	0
679289	676585	01024M	PARTICIPANT	\N	PRESENT	0
679290	676585	19647E	PARTICIPANT	\N	PRESENT	0
679291	676585	19667J	PARTICIPANT	\N	PRESENT	0
679292	676585	20264J	PARTICIPANT	\N	PRESENT	0
679293	676585	04085P	PARTICIPANT	\N	PRESENT	0
679297	676585	20068G	PARTICIPANT	\N	PRESENT	0
679295	676585	19629C	PARTICIPANT	\N	PRESENT	0
679296	676585	19719D	PARTICIPANT	\N	PRESENT	0
679298	676585	14001X	PARTICIPANT	\N	PRESENT	0
679299	676585	20066E	PARTICIPANT	\N	PRESENT	0
679300	676585	20082E	PARTICIPANT	\N	PRESENT	0
679301	676585	14229S	PARTICIPANT	\N	PRESENT	0
679302	676585	20180F	PARTICIPANT	\N	PRESENT	0
679314	676585	11065P	PARTICIPANT	\N	PRESENT	0
679304	676585	20298U	PARTICIPANT	\N	PRESENT	0
679305	676585	19760E	PARTICIPANT	\N	PRESENT	0
679306	676585	20018V	PARTICIPANT	\N	PRESENT	0
679307	676585	19347U	PARTICIPANT	\N	PRESENT	0
679308	676585	19739H	PARTICIPANT	\N	PRESENT	0
679309	676585	19866P	PARTICIPANT	\N	PRESENT	0
679310	676585	19683J	PARTICIPANT	\N	PRESENT	0
679311	676585	11097X	PARTICIPANT	\N	PRESENT	0
679312	676585	04047H	PARTICIPANT	\N	PRESENT	0
679313	676585	20098N	PARTICIPANT	\N	PRESENT	0
679315	676585	20052X	PARTICIPANT	\N	PRESENT	0
679316	676585	14031R	PARTICIPANT	\N	PRESENT	0
679317	676585	14249W	PARTICIPANT	\N	PRESENT	0
679318	667581	14189C	PARTICIPANT	\N	PRESENT	0
679319	667581	20024T	PARTICIPANT	\N	PRESENT	0
679320	667581	14030Q	PARTICIPANT	\N	PRESENT	0
679321	667581	20080C	PARTICIPANT	\N	EXCUSE	0
679322	667581	19621T	PARTICIPANT	\N	PRESENT	0
679323	667581	11031D	PARTICIPANT	\N	PRESENT	0
679324	667581	19693L	PARTICIPANT	\N	PRESENT	0
679325	667581	19599P	PARTICIPANT	\N	PRESENT	0
679326	667581	04035D	PARTICIPANT	\N	PRESENT	0
679327	667581	14179A	PARTICIPANT	\N	PRESENT	0
679328	667581	20066E	PARTICIPANT	\N	PRESENT	0
679329	667581	19715Y	PARTICIPANT	\N	PRESENT	0
679330	667581	20056C	PARTICIPANT	\N	PRESENT	0
679331	667581	14109K	PARTICIPANT	\N	PRESENT	0
679332	667581	19866P	PARTICIPANT	\N	EXCUSE	0
679333	667581	20130U	PARTICIPANT	\N	EXCUSE	0
679334	667581	11045K	PARTICIPANT	\N	PRESENT	0
679335	667581	12041X	PARTICIPANT	\N	PRESENT	0
679336	667581	14021P	PARTICIPANT	\N	PRESENT	0
679337	676585	19565D	PARTICIPANT	\N	PRESENT	0
679338	676585	14179A	PARTICIPANT	\N	PRESENT	0
679339	676585	20110Q	PARTICIPANT	\N	PRESENT	0
679340	676585	11053K	PARTICIPANT	\N	PRESENT	0
679341	676585	14073Q	PARTICIPANT	\N	PRESENT	0
655582	655581	19347U	PARTICIPANT	\N	PRESENT	0
655612	655611	11090Q	PARTICIPANT	\N	PRESENT	0
655613	655611	04047H	PARTICIPANT	\N	PRESENT	0
655614	655611	19782L	PARTICIPANT	\N	PRESENT	0
655615	655611	19629C	PARTICIPANT	\N	PRESENT	0
655616	655611	14038Y	PARTICIPANT	\N	PRESENT	0
655617	655611	11056N	PARTICIPANT	\N	PRESENT	0
655618	655611	14179A	PARTICIPANT	\N	PRESENT	0
655619	655611	14205J	PARTICIPANT	\N	PRESENT	0
655620	655611	14147R	PARTICIPANT	\N	PRESENT	0
655621	655611	20092G	PARTICIPANT	\N	PRESENT	0
668837	667720	19531S	PARTICIPANT	\N	PRESENT	0
668838	667720	08010L	PARTICIPANT	\N	PRESENT	0
668839	667720	14121F	PARTICIPANT	\N	PRESENT	0
668842	667720	19747H	PARTICIPANT	\N	PRESENT	0
668843	667720	04085P	PARTICIPANT	\N	PRESENT	0
668852	667720	20066E	PARTICIPANT	\N	PRESENT	0
668853	667720	19782L	PARTICIPANT	\N	PRESENT	0
668854	659678	19701S	PARTICIPANT	\N	PRESENT	0
668855	659678	19681G	PARTICIPANT	\N	PRESENT	0
668856	659678	20032T	PARTICIPANT	\N	PRESENT	0
668857	659678	11101A	PARTICIPANT	\N	PRESENT	0
668858	659678	19739H	PARTICIPANT	\N	PRESENT	0
668859	659678	19619A	PARTICIPANT	\N	PRESENT	0
668860	667720	20042V	PARTICIPANT	\N	PRESENT	0
668861	665814	19766L	PARTICIPANT	\N	PRESENT	0
668862	665814	19699S	PARTICIPANT	\N	PRESENT	0
668863	665814	19533U	PARTICIPANT	\N	PRESENT	0
668864	665814	19573D	PARTICIPANT	\N	PRESENT	0
668865	665814	20112S	PARTICIPANT	\N	PRESENT	0
668866	665814	20016T	PARTICIPANT	\N	PRESENT	0
668867	665814	08012N	PARTICIPANT	\N	PRESENT	0
668868	665814	20124W	PARTICIPANT	\N	PRESENT	0
668869	665814	19593H	PARTICIPANT	\N	PRESENT	0
668870	665814	19527W	PARTICIPANT	\N	PRESENT	0
668871	665814	20132W	PARTICIPANT	\N	PRESENT	0
668872	665814	20134Y	PARTICIPANT	\N	PRESENT	0
668873	665814	14073Q	PARTICIPANT	\N	PRESENT	0
668874	665814	19651A	PARTICIPANT	\N	PRESENT	0
668875	665814	19611R	PARTICIPANT	\N	PRESENT	0
668876	665814	20142Y	PARTICIPANT	\N	PRESENT	0
668877	665814	20048C	PARTICIPANT	\N	PRESENT	0
668878	665814	19399H	PARTICIPANT	\N	PRESENT	0
668879	665814	20052X	PARTICIPANT	\N	PRESENT	0
668880	665814	20152B	PARTICIPANT	\N	PRESENT	0
668881	665814	20172F	PARTICIPANT	\N	PRESENT	0
668882	665814	14030Q	PARTICIPANT	\N	PRESENT	0
668883	665814	20056C	PARTICIPANT	\N	PRESENT	0
668884	665814	04059M	PARTICIPANT	\N	PRESENT	0
668885	665814	20264J	PARTICIPANT	\N	PRESENT	0
668886	665814	19735D	PARTICIPANT	\N	PRESENT	0
668887	665814	14123H	PARTICIPANT	\N	PRESENT	0
668888	665814	11043H	PARTICIPANT	\N	PRESENT	0
668889	667720	19667J	PARTICIPANT	\N	PRESENT	0
668890	667720	99004R	PARTICIPANT	\N	PRESENT	0
668891	667720	14331P	PARTICIPANT	\N	PRESENT	0
668892	667720	08061X	PARTICIPANT	\N	PRESENT	0
668893	667720	20048C	PARTICIPANT	\N	PRESENT	0
668894	667720	20128B	PARTICIPANT	\N	PRESENT	0
668895	667720	14031R	PARTICIPANT	\N	PRESENT	0
668896	659678	14031R	PARTICIPANT	\N	PRESENT	0
668897	667720	11053K	PARTICIPANT	\N	PRESENT	0
668898	667720	20112S	PARTICIPANT	\N	PRESENT	0
668899	667720	14001X	PARTICIPANT	\N	PRESENT	0
668900	667720	20024T	PARTICIPANT	\N	PRESENT	0
668901	667720	20092G	PARTICIPANT	\N	PRESENT	0
668902	667720	20082E	PARTICIPANT	\N	PRESENT	0
668903	667720	19695N	PARTICIPANT	\N	PRESENT	0
668916	667720	19691J	PARTICIPANT	\N	PRESENT	0
668922	667720	14207L	PARTICIPANT	\N	PRESENT	0
668923	667720	14073Q	PARTICIPANT	\N	PRESENT	0
668924	667720	14030Q	PARTICIPANT	\N	PRESENT	0
668925	667720	19399H	PARTICIPANT	\N	PRESENT	0
668926	667720	20108W	PARTICIPANT	\N	PRESENT	0
668927	667720	14213J	PARTICIPANT	\N	PRESENT	0
668928	667720	14123H	PARTICIPANT	\N	PRESENT	0
668929	667720	20052X	PARTICIPANT	\N	PRESENT	0
668930	667720	14251Q	PARTICIPANT	\N	PRESENT	0
668931	667720	14217N	PARTICIPANT	\N	PRESENT	0
668932	667720	19577H	PARTICIPANT	\N	PRESENT	0
668933	667720	14147R	PARTICIPANT	\N	PRESENT	0
668934	667720	19758L	PARTICIPANT	\N	PRESENT	0
668935	667720	19673G	PARTICIPANT	\N	PRESENT	0
668936	667720	14211G	PARTICIPANT	\N	PRESENT	0
668937	667720	14231L	PARTICIPANT	\N	PRESENT	0
668938	667720	14097Y	PARTICIPANT	\N	PRESENT	0
668939	667720	14071N	PARTICIPANT	\N	PRESENT	0
668940	667720	19347U	PARTICIPANT	\N	PRESENT	0
668941	667720	14215L	PARTICIPANT	\N	PRESENT	0
668942	667720	19681G	PARTICIPANT	\N	PRESENT	0
668943	667720	14187A	PARTICIPANT	\N	PRESENT	0
668944	667720	20032T	PARTICIPANT	\N	PRESENT	0
668945	667720	19387D	PARTICIPANT	\N	PRESENT	0
668946	667720	19820Y	PARTICIPANT	\N	PRESENT	0
668947	667720	04035D	PARTICIPANT	\N	PRESENT	0
668948	667720	14357A	PARTICIPANT	\N	PRESENT	0
668949	667720	20142Y	PARTICIPANT	\N	PRESENT	0
668950	667720	19631V	PARTICIPANT	\N	PRESENT	0
668951	667720	19611R	PARTICIPANT	\N	PRESENT	0
668952	667720	19701S	PARTICIPANT	\N	PRESENT	0
668953	667720	19447X	PARTICIPANT	\N	PRESENT	0
669015	667721	95063L	PARTICIPANT	\N	PRESENT	0
669018	667721	20914V	PARTICIPANT	\N	PRESENT	0
669019	667721	19687N	PARTICIPANT	\N	PRESENT	0
669020	667721	19758L	PARTICIPANT	\N	PRESENT	0
669021	667721	20100N	PARTICIPANT	\N	PRESENT	0
669022	667721	19629C	PARTICIPANT	\N	PRESENT	0
669023	667721	19711U	PARTICIPANT	\N	PRESENT	0
669024	667721	20090E	PARTICIPANT	\N	PRESENT	0
669025	667721	14357A	PARTICIPANT	\N	PRESENT	0
669026	667721	20038A	PARTICIPANT	\N	PRESENT	0
669027	667721	01057W	PARTICIPANT	\N	PRESENT	0
669028	667721	11053K	PARTICIPANT	\N	PRESENT	0
669029	667721	19826F	PARTICIPANT	\N	PRESENT	0
669030	667721	20044X	PARTICIPANT	\N	PRESENT	0
669031	667721	14327T	PARTICIPANT	\N	PRESENT	0
669032	667721	19651A	PARTICIPANT	\N	PRESENT	0
669033	667721	11048N	PARTICIPANT	\N	PRESENT	0
669034	667721	14225N	PARTICIPANT	\N	PRESENT	0
669035	667721	08010L	PARTICIPANT	\N	PRESENT	0
669036	667721	19647E	PARTICIPANT	\N	PRESENT	0
669037	667721	20062A	PARTICIPANT	\N	PRESENT	0
669038	667721	14187A	PARTICIPANT	\N	PRESENT	0
669039	667721	19383Y	PARTICIPANT	\N	PRESENT	0
672940	672570	14327T	PARTICIPANT	\N	PRESENT	0
672941	672570	11048N	PARTICIPANT	\N	PRESENT	0
672942	672570	19711U	PARTICIPANT	\N	PRESENT	0
672943	672570	20252E	PARTICIPANT	\N	PRESENT	0
672944	672570	08009T	PARTICIPANT	\N	PRESENT	0
672945	672570	19349W	PARTICIPANT	\N	PRESENT	0
672946	672570	20080C	PARTICIPANT	\N	PRESENT	0
672947	672570	20914V	PARTICIPANT	\N	PRESENT	0
672948	672570	20044X	PARTICIPANT	\N	PRESENT	0
672949	672570	14225N	PRESIDENT	0	PRESENT	0
672950	672570	19762G	PARTICIPANT	\N	PRESENT	0
672951	672570	01048V	PARTICIPANT	\N	PRESENT	0
672952	672570	08011M	PARTICIPANT	\N	PRESENT	0
672953	672570	19741B	PARTICIPANT	\N	PRESENT	0
672954	672570	20036X	PARTICIPANT	\N	PRESENT	0
672955	672570	11053K	PARTICIPANT	\N	PRESENT	0
672956	672570	11074Q	PARTICIPANT	\N	PRESENT	0
672957	672570	08010L	PARTICIPANT	\N	PRESENT	0
672958	672570	11070L	PARTICIPANT	\N	PRESENT	0
672959	672570	07029T	PARTICIPANT	\N	EXCUSE	0
672960	672570	14189C	PARTICIPANT	\N	EXCUSE	0
672961	672570	20070A	PARTICIPANT	\N	PRESENT	0
672962	672570	20050V	PARTICIPANT	\N	PRESENT	0
672963	672570	20116W	PARTICIPANT	\N	PRESENT	0
672964	672260	19447X	PARTICIPANT	\N	PRESENT	0
672965	672260	11056N	PARTICIPANT	\N	PRESENT	0
672966	672260	14111D	PARTICIPANT	\N	PRESENT	0
672967	672260	20074E	PARTICIPANT	\N	PRESENT	0
672968	672260	04047H	PRESIDENT	0	PRESENT	0
672969	672260	05008E	PARTICIPANT	\N	PRESENT	0
672970	672260	19489J	PARTICIPANT	\N	PRESENT	0
673132	672997	14173T	PARTICIPANT	\N	PRESENT	0
673133	672997	11077T	PARTICIPANT	\N	PRESENT	0
673134	672997	20034V	PARTICIPANT	\N	PRESENT	0
673135	672997	19758L	PARTICIPANT	\N	PRESENT	0
673136	672997	14038Y	PARTICIPANT	\N	PRESENT	0
673137	672997	19663E	PARTICIPANT	\N	PRESENT	0
668428	668427	01043Q	PARTICIPANT	\N	PRESENT	0
668429	668427	20086J	PARTICIPANT	\N	PRESENT	0
668430	668427	20082E	PARTICIPANT	\N	PRESENT	0
668431	668427	19489J	PARTICIPANT	\N	PRESENT	0
668432	668427	11065P	PARTICIPANT	\N	PRESENT	0
668433	668427	14205J	PARTICIPANT	\N	PRESENT	0
668434	668427	20032T	PARTICIPANT	\N	PRESENT	0
668435	668427	19383Y	PARTICIPANT	\N	PRESENT	0
668437	668436	01043Q	PARTICIPANT	\N	PRESENT	0
668438	668436	20086J	PARTICIPANT	\N	PRESENT	0
668439	668436	20082E	PARTICIPANT	\N	PRESENT	0
668440	668436	19489J	PARTICIPANT	\N	PRESENT	0
668441	668436	11065P	PARTICIPANT	\N	PRESENT	0
668442	668436	14205J	PARTICIPANT	\N	PRESENT	0
668443	668436	20032T	PARTICIPANT	\N	PRESENT	0
668444	668436	19383Y	PARTICIPANT	\N	PRESENT	0
668449	668448	01043Q	PARTICIPANT	\N	PRESENT	0
668450	668448	20086J	PARTICIPANT	\N	PRESENT	0
668451	668448	20082E	PARTICIPANT	\N	PRESENT	0
668452	668448	19489J	PARTICIPANT	\N	PRESENT	0
668453	668448	14205J	PARTICIPANT	\N	PRESENT	0
668454	668448	20032T	PARTICIPANT	\N	PRESENT	0
668455	668448	19383Y	PARTICIPANT	\N	PRESENT	0
668458	668457	01043Q	PARTICIPANT	\N	PRESENT	0
668459	668457	20086J	PARTICIPANT	\N	PRESENT	0
668460	668457	20082E	PARTICIPANT	\N	PRESENT	0
668461	668457	05008E	PARTICIPANT	\N	PRESENT	0
668726	668725	19515S	PARTICIPANT	\N	PRESENT	0
668905	668904	19745F	PARTICIPANT	\N	PRESENT	0
668906	668904	20024T	PARTICIPANT	\N	PRESENT	0
668907	668904	19251M	PARTICIPANT	\N	PRESENT	0
668909	668908	19745F	PARTICIPANT	\N	PRESENT	0
668910	668908	20024T	PARTICIPANT	\N	PRESENT	0
668912	668911	19745F	PARTICIPANT	\N	PRESENT	0
668914	668913	19745F	PARTICIPANT	\N	PRESENT	0
668915	668913	20024T	PARTICIPANT	\N	PRESENT	0
678781	678753	14042U	PARTICIPANT	\N	PRESENT	0
678782	678753	08045X	PARTICIPANT	\N	PRESENT	0
678784	678753	18193Q	PARTICIPANT	\N	PRESENT	0
678785	678753	20130U	PARTICIPANT	\N	PRESENT	0
678786	678753	17965H	PARTICIPANT	\N	PRESENT	0
678792	678756	14213J	PARTICIPANT	\N	PRESENT	0
678793	678756	18193Q	PARTICIPANT	\N	PRESENT	0
678794	678756	20130U	PARTICIPANT	\N	PRESENT	0
678795	678756	17965H	PARTICIPANT	\N	PRESENT	0
678801	678745	18193Q	PARTICIPANT	\N	PRESENT	0
678802	678745	20130U	PARTICIPANT	\N	PRESENT	0
678803	678745	17965H	PARTICIPANT	\N	PRESENT	0
679249	679245	20050V	PARTICIPANT	\N	PRESENT	0
679250	679245	11097X	PARTICIPANT	\N	PRESENT	0
679251	679245	20076G	PARTICIPANT	\N	PRESENT	0
679252	679245	14205J	PARTICIPANT	\N	PRESENT	0
679253	679245	20118Y	PARTICIPANT	\N	PRESENT	0
679255	679245	14033T	PARTICIPANT	\N	PRESENT	0
679256	679245	19723Y	PARTICIPANT	\N	PRESENT	0
679258	679245	19782L	PARTICIPANT	\N	PRESENT	0
679259	679245	14097Y	PARTICIPANT	\N	PRESENT	0
680007	679652	20032T	PARTICIPANT	\N	PRESENT	0
680008	679652	19717B	PARTICIPANT	\N	PRESENT	0
680009	679652	19631V	PARTICIPANT	\N	PRESENT	0
680010	679652	19515S	PARTICIPANT	\N	PRESENT	0
680011	679652	05008E	PARTICIPANT	\N	PRESENT	0
680012	679652	19543W	PARTICIPANT	\N	PRESENT	0
680013	679652	19575F	PARTICIPANT	\N	PRESENT	0
680017	679652	20094J	PARTICIPANT	\N	PRESENT	0
680015	679652	19667J	PARTICIPANT	\N	PRESENT	0
680016	679652	20116W	PARTICIPANT	\N	PRESENT	0
680021	679652	20914V	PARTICIPANT	\N	PRESENT	0
680019	679652	11040E	PARTICIPANT	\N	PRESENT	0
680020	679652	14069U	PARTICIPANT	\N	PRESENT	0
680022	679652	20080C	PARTICIPANT	\N	PRESENT	0
680023	679652	04047H	PARTICIPANT	\N	PRESENT	0
680024	679652	14083S	PARTICIPANT	\N	PRESENT	0
680026	679652	19629C	PARTICIPANT	\N	PRESENT	0
680027	679652	20070A	PARTICIPANT	\N	PRESENT	0
680028	679652	19719D	PARTICIPANT	\N	PRESENT	0
680029	679652	14215L	PARTICIPANT	\N	PRESENT	0
680030	679652	20124W	PARTICIPANT	\N	PRESENT	0
680031	679652	11074Q	PARTICIPANT	\N	PRESENT	0
680032	679652	20038A	PARTICIPANT	\N	PRESENT	0
680033	679652	07004J	PARTICIPANT	\N	PRESENT	0
680034	679652	19333N	PARTICIPANT	\N	PRESENT	0
680035	679652	11048N	PARTICIPANT	\N	PRESENT	0
680036	679652	20034V	PARTICIPANT	\N	PRESENT	0
680037	679652	14121F	PARTICIPANT	\N	PRESENT	0
680038	679652	99004R	PARTICIPANT	\N	PRESENT	0
680039	679652	07029T	PARTICIPANT	\N	PRESENT	0
680040	679652	19711U	PARTICIPANT	\N	PRESENT	0
680041	679652	14205J	PARTICIPANT	\N	PRESENT	0
680042	679652	14251Q	PARTICIPANT	\N	PRESENT	0
680043	679652	20252E	PARTICIPANT	\N	PRESENT	0
680044	679652	19563B	PARTICIPANT	\N	PRESENT	0
680045	679652	08011M	PARTICIPANT	\N	PRESENT	0
680046	679652	14253S	PARTICIPANT	\N	PRESENT	0
680047	679652	19866P	PARTICIPANT	\N	PRESENT	0
680048	679652	14237S	PARTICIPANT	\N	PRESENT	0
680049	679652	20298U	PARTICIPANT	\N	PRESENT	0
680050	679652	19443T	PARTICIPANT	\N	PRESENT	0
680051	679652	19349W	PARTICIPANT	\N	PRESENT	0
680052	679652	14225N	PARTICIPANT	\N	PRESENT	0
680053	679652	20092G	PARTICIPANT	\N	PRESENT	0
680054	679652	20044X	PARTICIPANT	\N	PRESENT	0
680055	679652	19703U	PARTICIPANT	\N	PRESENT	0
680056	679652	11097X	PARTICIPANT	\N	PRESENT	0
680057	679652	14275Y	PARTICIPANT	\N	PRESENT	0
680058	679652	19301E	PARTICIPANT	\N	PRESENT	0
680059	679652	19479G	PARTICIPANT	\N	PRESENT	0
680099	676596	11070L	PARTICIPANT	\N	PRESENT	0
680100	676596	11053K	PARTICIPANT	\N	PRESENT	0
680101	676596	20914V	PARTICIPANT	\N	PRESENT	0
680102	676596	19349W	PARTICIPANT	\N	PRESENT	0
680103	676596	20116W	PARTICIPANT	\N	PRESENT	0
680104	676596	14225N	PARTICIPANT	\N	PRESENT	0
680105	676596	14253S	PARTICIPANT	\N	PRESENT	0
680106	676596	14111D	PARTICIPANT	\N	PRESENT	0
680107	676596	11040E	PARTICIPANT	\N	PRESENT	0
680108	676596	20074E	PARTICIPANT	\N	PRESENT	0
680109	676596	11048N	PARTICIPANT	\N	PRESENT	0
680110	676596	20044X	PARTICIPANT	\N	PRESENT	0
680111	676596	14173T	PARTICIPANT	\N	PRESENT	0
680112	676596	14053L	PARTICIPANT	\N	PRESENT	0
680113	676596	20080C	PARTICIPANT	\N	PRESENT	0
680114	676596	20070A	PARTICIPANT	\N	PRESENT	0
680115	676596	14097Y	PARTICIPANT	\N	PRESENT	0
680116	676596	20022R	PARTICIPANT	\N	PRESENT	0
680117	676596	20132W	PARTICIPANT	\N	PRESENT	0
680118	676596	20152B	PARTICIPANT	\N	PRESENT	0
680119	676596	20058E	PARTICIPANT	\N	PRESENT	0
680120	676596	11104D	PARTICIPANT	\N	PRESENT	0
680121	676596	19629C	PARTICIPANT	\N	PRESENT	0
680122	676596	11056N	PARTICIPANT	\N	PRESENT	0
680126	676596	08010L	PARTICIPANT	\N	PRESENT	0
680127	676596	14083S	PARTICIPANT	\N	PRESENT	0
680128	676596	07004J	PARTICIPANT	\N	PRESENT	0
680129	676596	19729F	PARTICIPANT	\N	PRESENT	0
680130	676596	07029T	PARTICIPANT	\N	PRESENT	0
680131	676596	14251Q	PARTICIPANT	\N	PRESENT	0
680132	676596	20098N	PARTICIPANT	\N	PRESENT	0
680133	676596	04071H	PARTICIPANT	\N	PRESENT	0
680134	676596	14121F	PARTICIPANT	\N	PRESENT	0
680135	676596	04047H	PARTICIPANT	\N	PRESENT	0
680136	676596	20134Y	PARTICIPANT	\N	PRESENT	0
680137	676596	95063L	PARTICIPANT	\N	PRESENT	0
680138	676596	14021P	PARTICIPANT	\N	PRESENT	0
655386	655385	01028R	PARTICIPANT	\N	PRESENT	0
655388	655387	01028R	PARTICIPANT	\N	PRESENT	0
656286	656175	14059S	PARTICIPANT	\N	PRESENT	0
656287	656175	19443T	PARTICIPANT	\N	PRESENT	0
656288	656175	01062T	PARTICIPANT	\N	PRESENT	0
656289	656175	19565D	PARTICIPANT	\N	PRESENT	0
656290	656175	11041F	PARTICIPANT	\N	PRESENT	0
656291	656175	20042V	PARTICIPANT	\N	PRESENT	0
656292	656175	16685X	PARTICIPANT	\N	PRESENT	0
656293	656175	04042C	PRESIDENT	0	PRESENT	0
656294	656175	19669L	PARTICIPANT	\N	PRESENT	0
656295	656175	12028B	PARTICIPANT	\N	PRESENT	0
656296	656175	14105F	PARTICIPANT	\N	PRESENT	0
656297	656175	20064C	PARTICIPANT	\N	PRESENT	0
656298	656175	19347U	PARTICIPANT	\N	PRESENT	0
656299	656175	07033P	PARTICIPANT	\N	PRESENT	0
656300	656175	97011G	PARTICIPANT	\N	PRESENT	0
656301	656175	08047A	PARTICIPANT	\N	PRESENT	0
656302	656175	20128B	PARTICIPANT	\N	PRESENT	0
661912	661911	14229S	PARTICIPANT	\N	PRESENT	0
661913	661911	19735D	PARTICIPANT	\N	PRESENT	1
661915	661914	14229S	PARTICIPANT	\N	PRESENT	0
661916	661914	19735D	PARTICIPANT	\N	PRESENT	1
661917	661914	20084G	PARTICIPANT	\N	PRESENT	1
661919	661918	14229S	PARTICIPANT	\N	PRESENT	0
661920	661918	20134Y	PARTICIPANT	\N	PRESENT	1
661921	661918	20084G	PARTICIPANT	\N	PRESENT	1
661922	661918	19735D	PARTICIPANT	\N	PRESENT	1
661924	661923	14229S	PARTICIPANT	\N	PRESENT	0
661925	661923	19735D	PARTICIPANT	\N	PRESENT	1
661926	661923	20180F	PARTICIPANT	\N	PRESENT	1
661928	661927	14229S	PARTICIPANT	\N	PRESENT	0
661929	661927	20084G	PARTICIPANT	\N	PRESENT	1
661930	661927	19735D	PARTICIPANT	\N	PRESENT	1
661934	661933	14229S	PARTICIPANT	\N	PRESENT	0
661935	661933	20084G	PARTICIPANT	\N	PRESENT	1
661936	661933	19735D	PARTICIPANT	\N	PRESENT	1
661938	661937	14229S	PARTICIPANT	\N	PRESENT	0
661939	661937	19735D	PARTICIPANT	\N	PRESENT	1
661940	661937	20084G	PARTICIPANT	\N	PRESENT	1
661991	661256	11048N	PARTICIPANT	\N	EXCUSE	0
661992	661256	14225N	PARTICIPANT	\N	EXCUSE	0
661993	661256	14173T	PARTICIPANT	\N	PRESENT	0
661994	661256	99004R	PARTICIPANT	\N	PRESENT	0
661995	661256	11012A	PARTICIPANT	\N	PRESENT	0
661996	661256	08009T	PARTICIPANT	\N	PRESENT	0
661997	661256	08011M	PARTICIPANT	\N	PRESENT	0
661998	661256	19671E	PARTICIPANT	\N	PRESENT	0
661999	661256	20086J	PARTICIPANT	\N	PRESENT	0
662000	661256	19711U	PARTICIPANT	\N	PRESENT	0
662001	661256	20252E	PARTICIPANT	\N	PRESENT	0
662002	661256	11053K	PARTICIPANT	\N	PRESENT	0
662003	661256	19349W	PARTICIPANT	\N	PRESENT	0
662004	661256	19741B	PARTICIPANT	\N	PRESENT	0
662005	661256	14327T	PRESIDENT	0	PRESENT	0
662006	661256	20070A	PARTICIPANT	\N	PRESENT	0
662007	661256	14121F	PARTICIPANT	\N	PRESENT	0
662008	661256	08010L	PARTICIPANT	\N	PRESENT	0
662009	661256	07029T	PARTICIPANT	\N	PRESENT	0
662010	661256	20914V	PARTICIPANT	\N	PRESENT	0
662011	661256	20080C	PARTICIPANT	\N	PRESENT	0
662012	661256	19762G	PARTICIPANT	\N	PRESENT	0
662013	661256	20050V	PARTICIPANT	\N	PRESENT	0
662014	661256	01048V	PARTICIPANT	\N	PRESENT	0
662015	661256	20116W	PARTICIPANT	\N	PRESENT	0
662016	661256	19647E	PARTICIPANT	\N	PRESENT	0
662017	661256	11074Q	PARTICIPANT	\N	PRESENT	0
662074	661802	11056N	PARTICIPANT	\N	PRESENT	0
662075	661802	20108W	PARTICIPANT	\N	PRESENT	0
662076	661802	10015M	PARTICIPANT	\N	PRESENT	0
662077	661802	14179A	PARTICIPANT	\N	PRESENT	0
662078	661802	19543W	PARTICIPANT	\N	PRESENT	0
662079	661802	19447X	PARTICIPANT	\N	PRESENT	0
662080	661802	14231L	PARTICIPANT	\N	PRESENT	0
662103	662018	86034E	PARTICIPANT	\N	PRESENT	0
662148	661802	14053L	PARTICIPANT	\N	PRESENT	0
662149	661802	20074E	PARTICIPANT	\N	PRESENT	0
662150	661802	01028R	PARTICIPANT	\N	PRESENT	0
662151	661802	05008E	PARTICIPANT	\N	PRESENT	0
662152	661802	19729F	PARTICIPANT	\N	PRESENT	0
662153	661802	20022R	PARTICIPANT	\N	PRESENT	0
662154	661802	19489J	PARTICIPANT	\N	PRESENT	0
662155	661802	14147R	PARTICIPANT	\N	PRESENT	0
662156	662018	14151M	PARTICIPANT	\N	PRESENT	0
662157	662018	11045K	PARTICIPANT	\N	PRESENT	0
662158	662018	04059M	PARTICIPANT	\N	PRESENT	0
662159	662018	11027H	PARTICIPANT	\N	PRESENT	0
662160	662018	11066Q	PARTICIPANT	\N	PRESENT	0
662161	662018	19387D	PARTICIPANT	\N	PRESENT	0
662162	662018	14107H	PARTICIPANT	\N	PRESENT	0
662163	662018	18193Q	PARTICIPANT	\N	PRESENT	0
662164	662018	17965H	PARTICIPANT	\N	PRESENT	0
662165	662018	20088L	PARTICIPANT	\N	PRESENT	0
662166	662018	19413M	PARTICIPANT	\N	PRESENT	0
662167	662018	11067R	PARTICIPANT	\N	PRESENT	0
662168	662018	19649G	PARTICIPANT	\N	PRESENT	0
662169	662018	08073C	PARTICIPANT	\N	PRESENT	0
662170	662018	01028R	PARTICIPANT	\N	PRESENT	0
662171	662018	19717B	PARTICIPANT	\N	PRESENT	0
662172	662018	11031D	PARTICIPANT	\N	PRESENT	0
662173	662018	11056N	PARTICIPANT	\N	PRESENT	0
662174	662018	04085P	PARTICIPANT	\N	PRESENT	0
662175	662018	20102Q	PARTICIPANT	\N	PRESENT	0
662176	662018	11077T	PARTICIPANT	\N	PRESENT	0
662177	662018	20046A	PARTICIPANT	\N	PRESENT	0
662178	662018	11074Q	PARTICIPANT	\N	PRESENT	0
662179	662018	14257W	PARTICIPANT	\N	PRESENT	0
662180	662018	17779H	PARTICIPANT	\N	PRESENT	0
662181	662018	14021P	PARTICIPANT	\N	PRESENT	0
662182	662018	19683J	PARTICIPANT	\N	PRESENT	0
662183	662018	19333N	PARTICIPANT	\N	PRESENT	0
662184	662018	14097Y	PARTICIPANT	\N	PRESENT	0
662185	662018	08045X	PARTICIPANT	\N	PRESENT	0
662186	662018	14187A	PARTICIPANT	\N	PRESENT	0
662187	662018	14071N	PARTICIPANT	\N	PRESENT	0
662188	662018	19711U	PARTICIPANT	\N	PRESENT	0
662189	662018	20110Q	PARTICIPANT	\N	PRESENT	0
662190	662018	20036X	PARTICIPANT	\N	PRESENT	0
662191	662018	14223L	PARTICIPANT	\N	PRESENT	0
662192	662018	11072N	PARTICIPANT	\N	PRESENT	0
662193	662018	08061X	PARTICIPANT	\N	PRESENT	0
662194	662018	95063L	PARTICIPANT	\N	PRESENT	0
662195	662018	04045F	PARTICIPANT	\N	PRESENT	0
662196	662018	04092N	PARTICIPANT	\N	PRESENT	0
662197	662018	20128B	PARTICIPANT	\N	PRESENT	0
662198	662018	19349W	PARTICIPANT	\N	PRESENT	0
662199	662018	19703U	PARTICIPANT	\N	PRESENT	0
662200	662018	19329S	PARTICIPANT	\N	PRESENT	0
662201	662018	19782L	PARTICIPANT	\N	PRESENT	0
662202	662018	19525U	PARTICIPANT	\N	PRESENT	0
662203	662018	14026U	PARTICIPANT	\N	PRESENT	0
662218	662018	19719D	PARTICIPANT	\N	PRESENT	0
662215	662018	19681G	PARTICIPANT	\N	PRESENT	0
662206	662018	14030Q	PARTICIPANT	\N	PRESENT	0
662214	662018	99004R	PARTICIPANT	\N	PRESENT	0
662213	662018	14207L	PARTICIPANT	\N	PRESENT	0
662209	662018	19693L	PARTICIPANT	\N	PRESENT	0
662210	662018	19575F	PARTICIPANT	\N	PRESENT	0
662211	662018	11012A	PARTICIPANT	\N	PRESENT	0
662212	662018	01058X	PARTICIPANT	\N	PRESENT	0
662216	662018	11083R	PARTICIPANT	\N	PRESENT	0
662217	662018	01060R	PARTICIPANT	\N	PRESENT	0
662219	662018	10015M	PARTICIPANT	\N	PRESENT	0
662220	662018	19553Y	PARTICIPANT	\N	PRESENT	0
662221	662018	14195A	PARTICIPANT	\N	PRESENT	0
662222	662018	14221J	PARTICIPANT	\N	PRESENT	0
662223	662018	19545Y	PARTICIPANT	\N	PRESENT	0
662224	662018	14251Q	PARTICIPANT	\N	PRESENT	0
662225	662018	14211G	PARTICIPANT	\N	PRESENT	0
662226	662018	19415P	PARTICIPANT	\N	PRESENT	0
662227	662018	04057K	PARTICIPANT	\N	PRESENT	0
662228	662018	19583F	PARTICIPANT	\N	PRESENT	0
662229	662018	19585H	PARTICIPANT	\N	PRESENT	0
662230	662018	20050V	PARTICIPANT	\N	PRESENT	0
662231	662018	20122U	PARTICIPANT	\N	PRESENT	0
662232	662018	11097X	PARTICIPANT	\N	PRESENT	0
662233	662018	19715Y	PARTICIPANT	\N	PRESENT	0
662234	662018	14229S	PARTICIPANT	\N	PRESENT	0
662235	662018	08060W	PARTICIPANT	\N	PRESENT	0
662236	662018	19549D	PARTICIPANT	\N	PRESENT	0
662237	662018	19669L	PARTICIPANT	\N	PRESENT	0
679393	679392	11048N	PARTICIPANT	\N	PRESENT	0
679394	679392	20252E	PARTICIPANT	\N	PRESENT	0
679395	679392	20116W	PARTICIPANT	\N	PRESENT	0
679396	679392	20914V	PARTICIPANT	\N	PRESENT	0
679397	679392	99004R	PARTICIPANT	\N	PRESENT	0
679398	679392	14225N	PRESIDENT	0	PRESENT	0
679399	679392	19671E	PARTICIPANT	\N	PRESENT	0
679400	679392	19762G	PARTICIPANT	\N	PRESENT	0
679401	679392	19479G	PARTICIPANT	\N	PRESENT	0
679402	679392	19711U	PARTICIPANT	\N	PRESENT	0
679403	679392	19545Y	PARTICIPANT	\N	PRESENT	0
679404	679392	20080C	PARTICIPANT	\N	PRESENT	0
679405	679392	19667J	PARTICIPANT	\N	PRESENT	0
679406	679392	08011M	PARTICIPANT	\N	PRESENT	0
679407	679392	11074Q	PARTICIPANT	\N	PRESENT	0
679408	679392	20044X	PARTICIPANT	\N	PRESENT	0
679409	679392	11040E	PARTICIPANT	\N	PRESENT	0
679410	679392	07029T	PARTICIPANT	\N	PRESENT	0
679411	679392	20070A	PARTICIPANT	\N	PRESENT	0
679412	679392	14253S	PARTICIPANT	\N	PRESENT	0
679413	676586	19319Q	PARTICIPANT	\N	PRESENT	0
679414	676586	20062A	PARTICIPANT	\N	PRESENT	0
679415	676586	14105F	PARTICIPANT	\N	PRESENT	0
679416	676586	19295A	PARTICIPANT	\N	PRESENT	0
679417	676586	20134Y	PARTICIPANT	\N	PRESENT	0
679418	676586	20092G	PARTICIPANT	\N	PRESENT	0
679419	676586	14033T	PARTICIPANT	\N	PRESENT	0
679420	676586	14038Y	PARTICIPANT	\N	PRESENT	0
679421	676586	01048V	PARTICIPANT	\N	PRESENT	0
679422	676586	19515S	PARTICIPANT	\N	PRESENT	0
679423	676586	19691J	PARTICIPANT	\N	PRESENT	0
679424	676586	14257W	PARTICIPANT	\N	PRESENT	0
679425	676586	19695N	PARTICIPANT	\N	PRESENT	0
679426	676586	14037X	PARTICIPANT	\N	PRESENT	0
679427	676586	11110B	PARTICIPANT	\N	PRESENT	0
679428	676586	19533U	PARTICIPANT	\N	PRESENT	0
679429	676586	10015M	PARTICIPANT	\N	PRESENT	0
679430	676586	19329S	PARTICIPANT	\N	PRESENT	0
679431	676586	19251M	PARTICIPANT	\N	PRESENT	0
679432	676586	11027H	PARTICIPANT	\N	PRESENT	0
679433	676586	19649G	PARTICIPANT	\N	PRESENT	0
679388	676586	19719D	PARTICIPANT	\N	PRESENT	0
679390	679389	19503N	PARTICIPANT	\N	PRESENT	0
679434	676586	20142Y	PARTICIPANT	\N	PRESENT	0
679435	676586	20088L	PARTICIPANT	\N	PRESENT	0
679436	679392	01057W	PARTICIPANT	\N	PRESENT	0
679437	679392	19349W	PARTICIPANT	\N	PRESENT	0
679438	679392	19647E	PARTICIPANT	\N	PRESENT	0
679439	679392	19741B	PARTICIPANT	\N	PRESENT	0
679440	679392	14121F	PARTICIPANT	\N	PRESENT	0
679441	676586	19333N	PARTICIPANT	\N	PRESENT	0
679442	676586	19683J	PARTICIPANT	\N	PRESENT	0
679443	676586	19647E	PARTICIPANT	\N	PRESENT	0
679444	676586	20110Q	PARTICIPANT	\N	PRESENT	0
679445	676586	19687N	PARTICIPANT	\N	PRESENT	0
679446	676586	17965H	PARTICIPANT	\N	PRESENT	0
679447	676586	19631V	PARTICIPANT	\N	PRESENT	0
679448	676586	14205J	PARTICIPANT	\N	PRESENT	0
679449	676586	20132W	PARTICIPANT	\N	PRESENT	0
679450	676586	14215L	PARTICIPANT	\N	PRESENT	0
679451	676586	14069U	PARTICIPANT	\N	PRESENT	0
679452	676586	18193Q	PARTICIPANT	\N	PRESENT	0
679453	676586	14053L	PARTICIPANT	\N	PRESENT	0
679454	676586	20090E	PARTICIPANT	\N	PRESENT	0
679455	676586	20032T	PARTICIPANT	\N	PRESENT	0
679456	676586	19347U	PARTICIPANT	\N	PRESENT	0
679457	676586	20084G	PARTICIPANT	\N	PRESENT	0
679458	676586	20038A	PARTICIPANT	\N	PRESENT	0
679459	679392	04071H	PARTICIPANT	\N	PRESENT	0
679460	679392	01048V	PARTICIPANT	\N	PRESENT	0
679461	676586	19503N	PARTICIPANT	\N	PRESENT	0
679462	676586	19599P	PARTICIPANT	\N	PRESENT	0
679463	679392	11110B	PARTICIPANT	\N	PRESENT	0
679464	679392	19531S	PARTICIPANT	\N	PRESENT	0
679465	676586	14237S	PARTICIPANT	\N	PRESENT	0
679466	676586	14083S	PARTICIPANT	\N	PRESENT	0
679467	676586	17023S	PARTICIPANT	\N	PRESENT	0
679468	676586	17779H	PARTICIPANT	\N	PRESENT	0
679469	676586	19760E	PARTICIPANT	\N	PRESENT	0
679470	676586	07004J	PARTICIPANT	\N	PRESENT	0
679471	676586	20022R	PARTICIPANT	\N	PRESENT	0
679472	676586	11097X	PARTICIPANT	\N	PRESENT	0
679473	676586	19693L	PARTICIPANT	\N	PRESENT	0
679474	676586	20298U	PARTICIPANT	\N	PRESENT	0
679475	676586	20180F	PARTICIPANT	\N	PRESENT	0
679476	676586	19747H	PARTICIPANT	\N	PRESENT	0
679477	676586	01028R	PARTICIPANT	\N	PRESENT	0
679478	676586	04085P	PARTICIPANT	\N	PRESENT	0
679479	676586	14275Y	PARTICIPANT	\N	PRESENT	0
679480	676586	19301E	PARTICIPANT	\N	PRESENT	0
679481	676586	19443T	PARTICIPANT	\N	PRESENT	0
679482	676586	19629C	PARTICIPANT	\N	PRESENT	0
679483	676586	20024T	PARTICIPANT	\N	PRESENT	0
679484	676586	19335Q	PARTICIPANT	\N	PRESENT	0
679485	676586	19826F	PARTICIPANT	\N	PRESENT	0
679486	676586	19715Y	PARTICIPANT	\N	PRESENT	0
679487	676586	20086J	PARTICIPANT	\N	PRESENT	0
679488	676586	20128B	PARTICIPANT	\N	PRESENT	0
679489	676586	20082E	PARTICIPANT	\N	PRESENT	0
679490	676586	19866P	PARTICIPANT	\N	PRESENT	0
679491	676586	14255U	PARTICIPANT	\N	PRESENT	0
679493	676586	11010L	PARTICIPANT	\N	PRESENT	0
679494	676586	20286Q	PARTICIPANT	\N	PRESENT	0
679495	676586	20264J	PARTICIPANT	\N	PRESENT	0
679496	676586	20124W	PARTICIPANT	\N	PRESENT	0
679497	679392	20086J	PARTICIPANT	\N	PRESENT	0
679498	679392	08010L	PARTICIPANT	\N	PRESENT	0
679499	679392	19335Q	PARTICIPANT	\N	PRESENT	0
679500	679392	14083S	PARTICIPANT	\N	PRESENT	0
679501	676586	14253S	PARTICIPANT	\N	PRESENT	0
679502	676586	99004R	PARTICIPANT	\N	PRESENT	0
679503	676586	20080C	PARTICIPANT	\N	PRESENT	0
679504	676586	14121F	PARTICIPANT	\N	PRESENT	0
679505	676586	01057W	PARTICIPANT	\N	PRESENT	0
679506	676586	19349W	PARTICIPANT	\N	PRESENT	0
679507	676586	19545Y	PARTICIPANT	\N	PRESENT	0
679508	676586	20116W	PARTICIPANT	\N	PRESENT	0
679509	676586	19479G	PARTICIPANT	\N	PRESENT	0
679510	676586	14189C	PARTICIPANT	\N	PRESENT	0
679511	676586	20034V	PARTICIPANT	\N	PRESENT	0
679512	676586	20044X	PARTICIPANT	\N	PRESENT	0
679513	676586	07029T	PARTICIPANT	\N	PRESENT	0
679514	676586	19741B	PARTICIPANT	\N	PRESENT	0
679515	676586	19531S	PARTICIPANT	\N	PRESENT	0
679516	676586	20070A	PARTICIPANT	\N	PRESENT	0
679517	676586	11074Q	PARTICIPANT	\N	PRESENT	0
679518	676586	19711U	PARTICIPANT	\N	PRESENT	0
679519	676586	08010L	PARTICIPANT	\N	PRESENT	0
679520	676586	11070L	PARTICIPANT	\N	PRESENT	0
679521	676586	19671E	PARTICIPANT	\N	PRESENT	0
679522	676586	08011M	PARTICIPANT	\N	PRESENT	0
679523	676586	19667J	PARTICIPANT	\N	PRESENT	0
679524	676586	11048N	PARTICIPANT	\N	PRESENT	0
679525	676586	14225N	PARTICIPANT	\N	PRESENT	0
679526	676586	20914V	PARTICIPANT	\N	PRESENT	0
679527	676586	19563B	PARTICIPANT	\N	PRESENT	0
679528	676586	05008E	PARTICIPANT	\N	PRESENT	0
679529	676586	19703U	PARTICIPANT	\N	PRESENT	0
679530	676586	11040E	PARTICIPANT	\N	PRESENT	0
679531	676586	20094J	PARTICIPANT	\N	PRESENT	0
679532	676586	14327T	PARTICIPANT	\N	PRESENT	0
679533	676586	11045K	PARTICIPANT	\N	PRESENT	0
679534	676586	14097Y	PARTICIPANT	\N	PRESENT	0
679536	676586	11104D	PARTICIPANT	\N	PRESENT	0
679541	676586	04047H	PARTICIPANT	\N	PRESENT	0
679542	676586	14179A	PARTICIPANT	\N	PRESENT	0
679543	676586	19762G	PARTICIPANT	\N	PRESENT	0
679544	676586	14021P	PARTICIPANT	\N	PRESENT	0
679545	676586	11090Q	PARTICIPANT	\N	PRESENT	0
679546	676586	19717B	PARTICIPANT	\N	PRESENT	0
679547	676586	19575F	PARTICIPANT	\N	PRESENT	0
679548	676586	20252E	PARTICIPANT	\N	PRESENT	0
679549	676586	14251Q	PARTICIPANT	\N	PRESENT	0
656058	656057	20024T	PARTICIPANT	\N	PRESENT	0
656059	656057	14255U	PARTICIPANT	\N	PRESENT	0
656060	656057	14053L	PARTICIPANT	\N	PRESENT	0
656061	656057	11027H	PARTICIPANT	\N	PRESENT	0
656062	656057	10015M	PARTICIPANT	\N	PRESENT	0
656117	656116	11056N	PARTICIPANT	\N	PRESENT	0
656926	656843	14213J	PARTICIPANT	\N	PRESENT	0
656928	656927	19691J	PARTICIPANT	\N	PRESENT	0
656932	656559	20110Q	PARTICIPANT	\N	PRESENT	0
656934	656933	14053L	PARTICIPANT	\N	PRESENT	0
656935	656933	14147R	PARTICIPANT	\N	PRESENT	0
656937	656936	14053L	PARTICIPANT	\N	PRESENT	0
656939	656938	14053L	PARTICIPANT	\N	PRESENT	0
656941	656940	14053L	PARTICIPANT	\N	PRESENT	0
656942	656940	11033F	PARTICIPANT	\N	PRESENT	0
656944	656943	14053L	PARTICIPANT	\N	PRESENT	0
656946	656945	14053L	PARTICIPANT	\N	PRESENT	0
656950	656949	19699S	PARTICIPANT	\N	PRESENT	0
656951	656949	20052X	PARTICIPANT	\N	PRESENT	0
666505	664325	11053K	PARTICIPANT	\N	PRESENT	0
666506	664325	20044X	PARTICIPANT	\N	PRESENT	0
666507	664325	14083S	PARTICIPANT	\N	PRESENT	0
666508	664325	19741B	PARTICIPANT	\N	PRESENT	0
666509	664325	08010L	PARTICIPANT	\N	PRESENT	0
666510	664325	20126Y	PARTICIPANT	\N	PRESENT	0
666511	664325	19762G	PARTICIPANT	\N	PRESENT	0
666512	664325	11012A	PARTICIPANT	\N	PRESENT	0
666513	664325	19479G	PARTICIPANT	\N	PRESENT	0
666516	664325	20070A	PARTICIPANT	\N	PRESENT	0
666517	664325	01048V	PARTICIPANT	\N	PRESENT	0
666559	665151	98022P	PARTICIPANT	\N	PRESENT	0
666560	665151	19511N	PARTICIPANT	\N	PRESENT	0
666561	665151	19583F	PARTICIPANT	\N	PRESENT	0
666562	665151	19295A	PARTICIPANT	\N	PRESENT	0
666563	665151	20100N	PARTICIPANT	\N	PRESENT	0
666564	665151	07004J	PARTICIPANT	\N	PRESENT	0
666565	665151	11041F	PARTICIPANT	\N	PRESENT	0
666566	665151	20046A	PARTICIPANT	\N	PRESENT	0
666567	665151	19719D	PARTICIPANT	\N	PRESENT	0
666568	665151	14207L	PARTICIPANT	\N	PRESENT	0
666575	665151	19621T	PARTICIPANT	\N	PRESENT	0
666576	665151	17637T	PARTICIPANT	\N	PRESENT	0
666577	665151	19711U	PARTICIPANT	\N	PRESENT	0
666580	665151	20038A	PARTICIPANT	\N	PRESENT	0
666581	665151	14173T	PARTICIPANT	\N	PRESENT	0
666582	665151	19447X	PARTICIPANT	\N	PRESENT	0
666583	665151	19723Y	PARTICIPANT	\N	PRESENT	0
666584	665151	20044X	PARTICIPANT	\N	PRESENT	0
666585	665151	20056C	PARTICIPANT	\N	PRESENT	0
666586	665151	19709B	PARTICIPANT	\N	PRESENT	0
666587	665151	19443T	PARTICIPANT	\N	PRESENT	0
666588	665151	20098N	PARTICIPANT	\N	PRESENT	0
666589	665151	19673G	PARTICIPANT	\N	PRESENT	0
666590	665151	11010L	PARTICIPANT	\N	PRESENT	0
666591	665151	20026V	PARTICIPANT	\N	PRESENT	0
666592	665151	92040Q	PARTICIPANT	\N	PRESENT	0
666593	665151	20180F	PARTICIPANT	\N	PRESENT	0
666594	665151	20096L	PARTICIPANT	\N	PRESENT	0
666595	665151	19667J	PARTICIPANT	\N	PRESENT	0
666596	665151	11115U	PARTICIPANT	\N	PRESENT	0
666597	665151	20086J	PARTICIPANT	\N	PRESENT	0
666598	665151	14031R	PARTICIPANT	\N	PRESENT	0
666599	665151	11080N	PARTICIPANT	\N	PRESENT	0
666600	665151	08047A	PARTICIPANT	\N	PRESENT	0
666601	665151	01057W	PARTICIPANT	\N	PRESENT	0
666602	665151	19766L	PARTICIPANT	\N	PRESENT	0
666603	665151	19768N	PARTICIPANT	\N	PRESENT	0
666604	665151	08015R	PARTICIPANT	\N	PRESENT	0
666605	665151	19729F	PARTICIPANT	\N	PRESENT	0
666606	665151	19741B	PARTICIPANT	\N	PRESENT	0
666607	665151	20140W	PARTICIPANT	\N	PRESENT	0
666608	665151	20108W	PARTICIPANT	\N	PRESENT	0
666609	665151	14259Y	PARTICIPANT	\N	PRESENT	0
666610	665151	20068G	PARTICIPANT	\N	PRESENT	0
666611	665151	14253S	PARTICIPANT	\N	PRESENT	0
666612	665151	20032T	PARTICIPANT	\N	PRESENT	0
666613	665151	17367Q	PARTICIPANT	\N	PRESENT	0
666614	665151	04071H	PARTICIPANT	\N	PRESENT	0
666615	665151	14169X	PARTICIPANT	\N	PRESENT	0
666616	665151	14223L	PARTICIPANT	\N	PRESENT	0
666617	665151	11043H	PARTICIPANT	\N	PRESENT	0
666618	665151	10015M	PARTICIPANT	\N	PRESENT	0
666619	665151	08028W	PARTICIPANT	\N	PRESENT	0
666620	665151	01048V	PARTICIPANT	\N	PRESENT	0
666621	665151	05012A	PARTICIPANT	\N	PRESENT	0
666622	665151	11090Q	PARTICIPANT	\N	PRESENT	0
666623	665151	19707Y	PARTICIPANT	\N	PRESENT	0
666624	665151	20024T	PARTICIPANT	\N	PRESENT	0
666625	665151	19705W	PARTICIPANT	\N	PRESENT	0
666626	665151	20062A	PARTICIPANT	\N	PRESENT	0
666627	665151	20090E	PARTICIPANT	\N	PRESENT	0
666628	665151	14329V	PARTICIPANT	\N	PRESENT	0
666629	665151	14059S	PARTICIPANT	\N	PRESENT	0
666630	665151	14147R	PARTICIPANT	\N	PRESENT	0
666631	665151	20172F	PARTICIPANT	\N	PRESENT	0
666632	665151	14213J	PARTICIPANT	\N	PRESENT	0
666633	665151	19675J	PARTICIPANT	\N	PRESENT	0
666634	665151	19383Y	PARTICIPANT	\N	PRESENT	0
666635	665151	19762G	PARTICIPANT	\N	PRESENT	0
666636	665151	19760E	PARTICIPANT	\N	PRESENT	0
666637	665151	19758L	PARTICIPANT	\N	PRESENT	0
666638	665151	20020P	PARTICIPANT	\N	PRESENT	0
666639	665151	11031D	PARTICIPANT	\N	PRESENT	0
666640	665151	20252E	PARTICIPANT	\N	PRESENT	0
666641	665151	20120S	PARTICIPANT	\N	PRESENT	0
666642	665151	11040E	PARTICIPANT	\N	PRESENT	0
666643	665151	04085P	PARTICIPANT	\N	PRESENT	0
666644	665151	14217N	PARTICIPANT	\N	PRESENT	0
666645	665151	19687N	PARTICIPANT	\N	PRESENT	0
666646	665151	07033P	PARTICIPANT	\N	PRESENT	0
666647	665151	12041X	PARTICIPANT	\N	PRESENT	0
666648	665151	14105F	PARTICIPANT	\N	PRESENT	0
666649	665151	11077T	PARTICIPANT	\N	PRESENT	0
666650	665151	20118Y	PARTICIPANT	\N	PRESENT	0
666651	665151	19593H	PARTICIPANT	\N	PRESENT	0
666652	665151	20102Q	PARTICIPANT	\N	PRESENT	0
666653	665151	19533U	PARTICIPANT	\N	PRESENT	0
666654	665151	19798U	PARTICIPANT	\N	PRESENT	0
666655	665151	19671E	PARTICIPANT	\N	PRESENT	0
666656	665151	19695N	PARTICIPANT	\N	PRESENT	0
666657	665151	19581D	PARTICIPANT	\N	PRESENT	0
666658	665151	20914V	PARTICIPANT	\N	PRESENT	0
666659	665151	19367Y	PARTICIPANT	\N	PRESENT	0
666660	665151	19347U	PARTICIPANT	\N	PRESENT	0
666661	665151	20054A	PARTICIPANT	\N	PRESENT	0
666662	665151	20110Q	PARTICIPANT	\N	PRESENT	0
666663	665151	20126Y	PARTICIPANT	\N	PRESENT	0
666664	665151	11065P	PARTICIPANT	\N	PRESENT	0
666665	665151	11099A	PARTICIPANT	\N	PRESENT	0
666666	665151	20124W	PARTICIPANT	\N	PRESENT	0
666667	665151	20142Y	PARTICIPANT	\N	PRESENT	0
666669	665151	20092G	PARTICIPANT	\N	PRESENT	0
666670	665151	14071N	PARTICIPANT	\N	PRESENT	0
666671	665151	19421M	PARTICIPANT	\N	PRESENT	0
666672	665151	20266L	PARTICIPANT	\N	PRESENT	0
666673	665151	20134Y	PARTICIPANT	\N	PRESENT	0
666674	665151	14215L	PARTICIPANT	\N	PRESENT	0
666676	665151	14237S	PARTICIPANT	\N	PRESENT	0
666677	665151	14193X	PARTICIPANT	\N	PRESENT	0
666678	665151	19651A	PARTICIPANT	\N	PRESENT	0
666679	665151	19782L	PARTICIPANT	\N	PRESENT	0
666680	665151	11083R	PARTICIPANT	\N	PRESENT	0
666681	665151	19701S	PARTICIPANT	\N	PRESENT	0
666682	665151	19697Q	PARTICIPANT	\N	PRESENT	0
666683	665151	14037X	PARTICIPANT	\N	PRESENT	0
666684	665151	10006L	PARTICIPANT	\N	PRESENT	0
666685	665151	08061X	PARTICIPANT	\N	PRESENT	0
666686	665151	04043D	PARTICIPANT	\N	PRESENT	0
666687	665151	11072N	PARTICIPANT	\N	PRESENT	0
666688	665151	19637C	PARTICIPANT	\N	PRESENT	0
666689	665151	14187A	PARTICIPANT	\N	PRESENT	0
666690	665151	04092N	PARTICIPANT	\N	PRESENT	0
666691	665151	04045F	PARTICIPANT	\N	PRESENT	0
666692	665151	11097X	PARTICIPANT	\N	PRESENT	0
666693	665151	20150Y	PARTICIPANT	\N	PRESENT	0
666694	665151	14133K	PARTICIPANT	\N	PRESENT	0
666695	665151	20128B	PARTICIPANT	\N	PRESENT	0
666696	665151	19747H	PARTICIPANT	\N	PRESENT	0
666697	665151	95063L	PARTICIPANT	\N	PRESENT	0
666698	665151	19415P	PARTICIPANT	\N	PRESENT	0
666699	665151	19329S	PARTICIPANT	\N	PRESENT	0
680177	676597	19629C	PARTICIPANT	\N	PRESENT	0
680178	676597	14121F	PARTICIPANT	\N	PRESENT	0
680179	676597	11104D	PARTICIPANT	\N	PRESENT	0
680180	676597	20914V	PARTICIPANT	\N	PRESENT	0
680181	676597	20134Y	PARTICIPANT	\N	PRESENT	0
680182	676597	11056N	PARTICIPANT	\N	PRESENT	0
680183	676597	20116W	PARTICIPANT	\N	PRESENT	0
680184	676597	04085P	PARTICIPANT	\N	PRESENT	0
680185	676597	04071H	PARTICIPANT	\N	PRESENT	0
680186	676597	14173T	PARTICIPANT	\N	PRESENT	0
680187	676597	14083S	PARTICIPANT	\N	PRESENT	0
680188	676597	07004J	PARTICIPANT	\N	PRESENT	0
680189	676597	14225N	PARTICIPANT	\N	PRESENT	0
680190	676597	11048N	PARTICIPANT	\N	PRESENT	0
680191	676597	14097Y	PARTICIPANT	\N	PRESENT	0
680192	676597	20080C	PARTICIPANT	\N	PRESENT	0
680193	676597	19649G	PARTICIPANT	\N	PRESENT	0
680194	676597	14021P	PARTICIPANT	\N	PRESENT	0
680195	676597	19729F	PARTICIPANT	\N	PRESENT	0
680175	676597	11070L	PARTICIPANT	\N	PRESENT	0
680176	676597	20070A	PARTICIPANT	\N	PRESENT	0
680196	676597	14253S	PARTICIPANT	\N	PRESENT	0
680197	676597	20034V	PARTICIPANT	\N	PRESENT	0
680198	676597	20022R	PARTICIPANT	\N	PRESENT	0
680199	676597	20152B	PARTICIPANT	\N	PRESENT	0
680200	676597	20074E	PARTICIPANT	\N	PRESENT	0
680201	676597	19349W	PARTICIPANT	\N	PRESENT	0
680202	676597	04047H	PARTICIPANT	\N	PRESENT	0
680203	676597	08010L	PARTICIPANT	\N	PRESENT	0
680204	676597	95063L	PARTICIPANT	\N	PRESENT	0
680205	676597	14111D	PARTICIPANT	\N	PRESENT	0
680206	676597	07029T	PARTICIPANT	\N	PRESENT	0
680207	676597	19631V	PARTICIPANT	\N	PRESENT	0
680220	676597	14053L	PARTICIPANT	\N	PRESENT	0
680221	676597	20098N	PARTICIPANT	\N	PRESENT	0
680222	676597	11072N	PARTICIPANT	\N	PRESENT	0
680223	676597	04035D	PARTICIPANT	\N	PRESENT	0
680275	680273	99004R	PARTICIPANT	\N	PRESENT	0
680276	680273	20098N	PARTICIPANT	\N	PRESENT	0
680277	680273	20134Y	PARTICIPANT	\N	PRESENT	0
680278	680273	14173T	PARTICIPANT	\N	PRESENT	0
680279	680273	14021P	PARTICIPANT	\N	PRESENT	0
680280	680273	20116W	PARTICIPANT	\N	PRESENT	0
680281	680273	19629C	PARTICIPANT	\N	PRESENT	0
680282	680273	07004J	PARTICIPANT	\N	PRESENT	0
680283	680273	14073Q	PARTICIPANT	\N	PRESENT	0
680284	680273	04071H	PARTICIPANT	\N	PRESENT	0
680285	680273	14225N	PARTICIPANT	\N	PRESENT	0
680286	680273	19631V	PARTICIPANT	\N	PRESENT	0
680287	680273	11056N	PARTICIPANT	\N	PRESENT	0
680288	680273	14053L	PARTICIPANT	\N	PRESENT	0
680289	680273	04047H	PARTICIPANT	\N	PRESENT	0
680290	680273	11104D	PARTICIPANT	\N	PRESENT	0
680291	680273	11072N	PARTICIPANT	\N	PRESENT	0
680292	680273	04085P	PARTICIPANT	\N	PRESENT	0
680293	680273	19651A	PARTICIPANT	\N	PRESENT	0
680294	680273	19593H	PARTICIPANT	\N	PRESENT	0
680295	680273	08010L	PARTICIPANT	\N	PRESENT	0
680296	680273	19349W	PARTICIPANT	\N	PRESENT	0
680297	680273	20124W	PARTICIPANT	\N	PRESENT	0
680298	680273	14111D	PARTICIPANT	\N	PRESENT	0
680299	680273	19649G	PARTICIPANT	\N	PRESENT	0
680308	680273	19611R	PARTICIPANT	\N	PRESENT	0
680309	680273	19553Y	PARTICIPANT	\N	PRESENT	0
680311	680273	20058E	PARTICIPANT	\N	PRESENT	0
680312	680273	11043H	PARTICIPANT	\N	PRESENT	0
680313	680273	14121F	PARTICIPANT	\N	PRESENT	0
680314	680273	14253S	PARTICIPANT	\N	PRESENT	0
680317	680224	99004R	PARTICIPANT	\N	PRESENT	0
680318	680224	20098N	PARTICIPANT	\N	PRESENT	0
680319	680224	20134Y	PARTICIPANT	\N	PRESENT	0
680348	680224	19527W	PARTICIPANT	\N	PRESENT	0
680321	680224	14021P	PARTICIPANT	\N	PRESENT	0
680322	680224	20116W	PARTICIPANT	\N	PRESENT	0
680323	680224	19629C	PARTICIPANT	\N	PRESENT	0
680324	680224	14073Q	PARTICIPANT	\N	PRESENT	0
680349	680224	20132W	PARTICIPANT	\N	PRESENT	0
680326	680224	14225N	PARTICIPANT	\N	PRESENT	0
680327	680224	19631V	PARTICIPANT	\N	PRESENT	0
680328	680224	11056N	PARTICIPANT	\N	PRESENT	0
680329	680224	14053L	PARTICIPANT	\N	PRESENT	0
680330	680224	04047H	PARTICIPANT	\N	PRESENT	0
680331	680224	11104D	PARTICIPANT	\N	PRESENT	0
680332	680224	04085P	PARTICIPANT	\N	PRESENT	0
680333	680224	19651A	PARTICIPANT	\N	PRESENT	0
680334	680224	19593H	PARTICIPANT	\N	PRESENT	0
680335	680224	08010L	PARTICIPANT	\N	PRESENT	0
680336	680224	19349W	PARTICIPANT	\N	PRESENT	0
680337	680224	20124W	PARTICIPANT	\N	PRESENT	0
680338	680224	14111D	PARTICIPANT	\N	PRESENT	0
680339	680224	19649G	PARTICIPANT	\N	PRESENT	0
680340	680224	19611R	PARTICIPANT	\N	PRESENT	0
680341	680224	19553Y	PARTICIPANT	\N	PRESENT	0
680342	680224	20058E	PARTICIPANT	\N	PRESENT	0
680343	680224	11043H	PARTICIPANT	\N	PRESENT	0
680344	680224	14121F	PARTICIPANT	\N	PRESENT	0
680345	680224	14253S	PARTICIPANT	\N	PRESENT	0
680346	680224	08012N	PARTICIPANT	\N	PRESENT	0
680350	680224	20034V	PARTICIPANT	\N	PRESENT	0
680351	680347	20062A	PARTICIPANT	\N	PRESENT	0
680352	680347	14033T	PARTICIPANT	\N	PRESENT	0
680355	680354	20062A	PARTICIPANT	\N	PRESENT	0
680356	680354	14033T	PARTICIPANT	\N	PRESENT	0
680357	680224	11033F	PARTICIPANT	\N	PRESENT	0
680358	680224	14083S	PARTICIPANT	\N	PRESENT	0
680359	680224	20080C	PARTICIPANT	\N	PRESENT	0
680365	680360	19697Q	PARTICIPANT	\N	PRESENT	0
680368	680361	19697Q	PARTICIPANT	\N	PRESENT	0
680372	680364	19697Q	PARTICIPANT	\N	PRESENT	0
680383	680224	19543W	PARTICIPANT	\N	PRESENT	0
680385	680381	19697Q	PARTICIPANT	\N	PRESENT	0
680386	680382	19697Q	PARTICIPANT	\N	PRESENT	0
680387	680384	19697Q	PARTICIPANT	\N	PRESENT	0
680388	680224	11045K	PARTICIPANT	\N	PRESENT	0
680390	680389	19565D	PARTICIPANT	\N	PRESENT	0
680391	680389	14267Y	PARTICIPANT	\N	PRESENT	0
680392	680224	19749K	PARTICIPANT	\N	PRESENT	0
680393	680224	11072N	PARTICIPANT	\N	PRESENT	0
680394	680224	14033T	PARTICIPANT	\N	PRESENT	0
680395	680224	19717B	PARTICIPANT	\N	PRESENT	0
680396	680224	19531S	PARTICIPANT	\N	PRESENT	0
680397	676599	99004R	PARTICIPANT	\N	PRESENT	0
680398	676599	20134Y	PARTICIPANT	\N	PRESENT	0
680399	676599	14021P	PARTICIPANT	\N	PRESENT	0
680400	676599	20116W	PARTICIPANT	\N	PRESENT	0
680403	676599	14225N	PARTICIPANT	\N	PRESENT	0
680404	676599	11056N	PARTICIPANT	\N	PRESENT	0
680405	676599	14053L	PARTICIPANT	\N	PRESENT	0
680406	676599	04047H	PARTICIPANT	\N	PRESENT	0
680408	676599	08010L	PARTICIPANT	\N	PRESENT	0
680409	676599	19349W	PARTICIPANT	\N	PRESENT	0
680411	676599	19649G	PARTICIPANT	\N	PRESENT	0
680413	676599	20058E	PARTICIPANT	\N	PRESENT	0
656585	656584	11048N	PARTICIPANT	\N	PRESENT	0
656586	656584	20086J	PARTICIPANT	\N	PRESENT	0
656594	656593	11048N	PARTICIPANT	\N	PRESENT	0
656595	656593	14121F	PARTICIPANT	\N	PRESENT	0
656598	656597	11048N	PARTICIPANT	\N	PRESENT	0
656599	656597	14121F	PARTICIPANT	\N	PRESENT	0
656602	656601	19399H	PARTICIPANT	\N	PRESENT	0
656603	656601	99004R	PARTICIPANT	\N	PRESENT	0
656723	656207	19711U	PARTICIPANT	\N	PRESENT	0
656897	655445	14331P	PARTICIPANT	\N	EXCUSE	0
662238	662018	14281W	PARTICIPANT	\N	PRESENT	0
662239	662018	05012A	PARTICIPANT	\N	PRESENT	0
662240	662018	14109K	PARTICIPANT	\N	PRESENT	0
662241	662018	19820Y	PARTICIPANT	\N	PRESENT	0
662242	662018	20070A	PARTICIPANT	\N	PRESENT	0
662243	662018	20028X	PARTICIPANT	\N	PRESENT	0
662244	662018	19725B	PARTICIPANT	\N	PRESENT	0
662245	662018	19503N	PARTICIPANT	\N	PRESENT	0
662246	662018	20022R	PARTICIPANT	\N	PRESENT	0
662247	662018	12028B	PARTICIPANT	\N	PRESENT	0
662248	662018	20082E	PARTICIPANT	\N	PRESENT	0
662249	662018	11054L	PARTICIPANT	\N	PRESENT	0
662250	662018	12016W	PARTICIPANT	\N	PRESENT	0
662251	662018	14121F	PARTICIPANT	\N	PRESENT	0
662252	662018	20114U	PARTICIPANT	\N	PRESENT	0
662253	662018	19531S	PARTICIPANT	\N	PRESENT	0
662254	662018	20064C	PARTICIPANT	\N	PRESENT	0
662255	662018	20030R	PARTICIPANT	\N	PRESENT	0
662256	662018	19701S	PARTICIPANT	\N	PRESENT	0
662257	662018	19631V	PARTICIPANT	\N	PRESENT	0
662258	662018	11065P	PARTICIPANT	\N	PRESENT	0
662259	662018	20142Y	PARTICIPANT	\N	PRESENT	0
662260	662018	14053L	PARTICIPANT	\N	PRESENT	0
662262	662018	19659J	PARTICIPANT	\N	PRESENT	0
662263	662018	19533U	PARTICIPANT	\N	PRESENT	0
662266	662018	14105F	PARTICIPANT	\N	PRESENT	0
662267	662018	19713W	PARTICIPANT	\N	PRESENT	0
662268	662018	19745F	PARTICIPANT	\N	PRESENT	0
662270	662018	17229F	PARTICIPANT	\N	PRESENT	0
662271	662018	14231L	PARTICIPANT	\N	PRESENT	0
662272	662018	19369B	PARTICIPANT	\N	PRESENT	0
662273	662018	20298U	PARTICIPANT	\N	PRESENT	0
662274	662018	19611R	PARTICIPANT	\N	PRESENT	0
662275	662018	01034P	PARTICIPANT	\N	PRESENT	0
662276	662018	08009T	PARTICIPANT	\N	PRESENT	0
662277	662018	11085T	PARTICIPANT	\N	PRESENT	0
662278	662018	19577H	PARTICIPANT	\N	PRESENT	0
662279	662018	20066E	PARTICIPANT	\N	PRESENT	0
662280	662018	01025N	PARTICIPANT	\N	PRESENT	0
662281	662018	01043Q	PARTICIPANT	\N	PRESENT	0
662282	662018	10006L	PARTICIPANT	\N	PRESENT	0
662283	662018	16685X	PARTICIPANT	\N	PRESENT	0
662284	662018	19735D	PARTICIPANT	\N	PRESENT	0
662285	662018	14042U	PARTICIPANT	\N	PRESENT	0
662286	662018	11070L	PARTICIPANT	\N	PRESENT	0
662287	662018	20040T	PARTICIPANT	\N	PRESENT	0
662288	662018	07004J	PARTICIPANT	\N	PRESENT	0
662289	662018	19826F	PARTICIPANT	\N	PRESENT	0
662290	662018	14083S	PARTICIPANT	\N	PRESENT	0
662291	662018	14073Q	PARTICIPANT	\N	PRESENT	0
662292	662018	14267Y	PARTICIPANT	\N	PRESENT	0
662293	662018	19685L	PARTICIPANT	\N	PRESENT	0
662294	662018	19543W	PARTICIPANT	\N	PRESENT	0
662295	662018	20052X	PARTICIPANT	\N	PRESENT	0
662296	662018	19721W	PARTICIPANT	\N	PRESENT	0
662297	662018	19619A	PARTICIPANT	\N	PRESENT	0
662298	662018	19699S	PARTICIPANT	\N	PRESENT	0
662299	662018	11064N	PARTICIPANT	\N	PRESENT	0
662300	662018	08069G	PARTICIPANT	\N	PRESENT	0
662301	662018	19760E	PARTICIPANT	\N	PRESENT	0
662302	662018	20076G	PARTICIPANT	\N	PRESENT	0
662303	662018	19565D	PARTICIPANT	\N	PRESENT	0
662304	662018	11104D	PARTICIPANT	\N	PRESENT	0
662305	662018	20074E	PARTICIPANT	\N	PRESENT	0
662306	662018	20094J	PARTICIPANT	\N	PRESENT	0
662307	662018	20060X	PARTICIPANT	\N	PRESENT	0
662308	662018	20080C	PARTICIPANT	\N	PRESENT	0
662309	662018	18083K	PARTICIPANT	\N	PRESENT	0
662310	662018	19593H	PARTICIPANT	\N	PRESENT	0
662311	662018	08028W	PARTICIPANT	\N	PRESENT	0
662312	662018	11099A	PARTICIPANT	\N	PRESENT	0
662313	662018	20068G	PARTICIPANT	\N	PRESENT	0
662314	662018	20032T	PARTICIPANT	\N	PRESENT	0
662315	662018	07029T	PARTICIPANT	\N	PRESENT	0
662316	662018	08018U	PARTICIPANT	\N	PRESENT	0
662317	662018	19709B	PARTICIPANT	\N	PRESENT	0
662318	662018	14355X	PARTICIPANT	\N	PRESENT	0
662319	662018	19663E	PARTICIPANT	\N	PRESENT	0
662320	662018	20086J	PARTICIPANT	\N	PRESENT	0
662321	662018	20044X	PARTICIPANT	\N	PRESENT	0
662322	662018	20058E	PARTICIPANT	\N	PRESENT	0
662323	662018	19723Y	PARTICIPANT	\N	PRESENT	0
662324	662018	20034V	PARTICIPANT	\N	PRESENT	0
662325	662018	19467C	PARTICIPANT	\N	PRESENT	0
662326	662018	20056C	PARTICIPANT	\N	PRESENT	0
662327	662018	20098N	PARTICIPANT	\N	PRESENT	0
662328	662018	92040Q	PARTICIPANT	\N	PRESENT	0
662329	662018	20026V	PARTICIPANT	\N	PRESENT	0
662330	662018	19573D	PARTICIPANT	\N	PRESENT	0
662331	662018	14031R	PARTICIPANT	\N	PRESENT	0
662332	662018	19667J	PARTICIPANT	\N	PRESENT	0
662333	662018	19515S	PARTICIPANT	\N	PRESENT	0
662334	662018	20038A	PARTICIPANT	\N	PRESENT	0
662335	662018	11010L	PARTICIPANT	\N	PRESENT	0
662336	662018	14191V	PARTICIPANT	\N	PRESENT	0
662337	662018	11080N	PARTICIPANT	\N	PRESENT	0
662338	662018	20078J	PARTICIPANT	\N	PRESENT	0
662339	662018	04042C	PARTICIPANT	\N	PRESENT	0
662340	662018	11043H	PARTICIPANT	\N	PRESENT	0
662341	662018	14253S	PARTICIPANT	\N	PRESENT	0
662342	662018	20172F	PARTICIPANT	\N	PRESENT	0
662343	662018	14147R	PARTICIPANT	\N	PRESENT	0
662344	662018	20138D	PARTICIPANT	\N	PRESENT	0
662345	662018	20140W	PARTICIPANT	\N	PRESENT	0
662346	662018	08047A	PARTICIPANT	\N	PRESENT	0
662347	662018	19741B	PARTICIPANT	\N	PRESENT	0
662348	662018	19399H	PARTICIPANT	\N	PRESENT	0
662349	662018	19657G	PARTICIPANT	\N	PRESENT	0
662350	662018	19729F	PARTICIPANT	\N	PRESENT	0
662351	662018	20108W	PARTICIPANT	\N	PRESENT	0
662352	662018	20024T	PARTICIPANT	\N	PRESENT	0
662353	662018	19707Y	PARTICIPANT	\N	PRESENT	0
662354	662018	08015R	PARTICIPANT	\N	PRESENT	0
662355	662018	19768N	PARTICIPANT	\N	PRESENT	0
662356	662018	19705W	PARTICIPANT	\N	PRESENT	0
662357	662018	20062A	PARTICIPANT	\N	PRESENT	0
662358	662018	20090E	PARTICIPANT	\N	PRESENT	0
662359	662018	19675J	PARTICIPANT	\N	PRESENT	0
662360	662018	14059S	PARTICIPANT	\N	PRESENT	0
662361	662018	19383Y	PARTICIPANT	\N	PRESENT	0
662362	662018	14329V	PARTICIPANT	\N	PRESENT	0
662363	662018	20020P	PARTICIPANT	\N	PRESENT	0
662364	662018	20252E	PARTICIPANT	\N	PRESENT	0
662365	662018	97011G	PARTICIPANT	\N	PRESENT	0
662367	662018	07033P	PARTICIPANT	\N	PRESENT	0
662368	662018	14217N	PARTICIPANT	\N	PRESENT	0
662370	662018	04008A	PARTICIPANT	\N	PRESENT	0
662371	662018	04047H	PARTICIPANT	\N	PRESENT	0
662374	662018	05008E	PARTICIPANT	\N	PRESENT	0
662378	662018	11101A	PARTICIPANT	\N	PRESENT	0
662384	662018	20042V	PARTICIPANT	\N	PRESENT	0
662385	662018	20126Y	PARTICIPANT	\N	PRESENT	0
662386	662018	20118Y	PARTICIPANT	\N	PRESENT	0
662387	662018	19762G	PARTICIPANT	\N	PRESENT	0
662388	662018	04043D	PARTICIPANT	\N	PRESENT	0
662389	662018	04033B	PARTICIPANT	\N	PRESENT	0
662390	662018	19747H	PARTICIPANT	\N	PRESENT	0
662391	662018	19421M	PARTICIPANT	\N	PRESENT	0
662392	662018	14193X	PARTICIPANT	\N	PRESENT	0
662393	662018	95041E	PARTICIPANT	\N	PRESENT	0
662394	662018	19581D	PARTICIPANT	\N	PRESENT	0
662395	662018	20248J	PARTICIPANT	\N	PRESENT	0
662396	662018	14055N	PARTICIPANT	\N	PRESENT	0
662397	662018	19621T	PARTICIPANT	\N	PRESENT	0
662398	662018	12041X	PARTICIPANT	\N	PRESENT	0
662399	662018	11040E	PARTICIPANT	\N	PRESENT	0
662400	662018	19647E	PARTICIPANT	\N	PRESENT	0
662401	662018	11026G	PARTICIPANT	\N	PRESENT	0
662409	662018	19599P	PARTICIPANT	\N	PRESENT	0
662404	662018	20914V	PARTICIPANT	\N	PRESENT	0
679626	676588	19629C	PARTICIPANT	\N	PRESENT	0
679627	676588	19333N	PARTICIPANT	\N	PRESENT	0
679628	676588	20092G	PARTICIPANT	\N	PRESENT	0
679629	676588	19717B	PARTICIPANT	\N	PRESENT	0
679630	676588	19349W	PARTICIPANT	\N	PRESENT	0
679631	676588	20298U	PARTICIPANT	\N	PRESENT	0
679632	676588	07004J	PARTICIPANT	\N	PRESENT	0
679633	676588	20252E	PARTICIPANT	\N	PRESENT	0
679634	676588	14069U	PARTICIPANT	\N	PRESENT	0
679635	676588	04047H	PARTICIPANT	\N	PRESENT	0
679636	676588	07029T	PARTICIPANT	\N	PRESENT	0
679637	676588	19443T	PARTICIPANT	\N	PRESENT	0
679638	676588	19575F	PARTICIPANT	\N	PRESENT	0
679639	676588	19723Y	PARTICIPANT	\N	PRESENT	0
679640	676588	14253S	PARTICIPANT	\N	PRESENT	0
679641	676588	20070A	PARTICIPANT	\N	PRESENT	0
679642	676588	14257W	PARTICIPANT	\N	PRESENT	0
679643	676588	20044X	PARTICIPANT	\N	PRESENT	0
679644	676588	19515S	PARTICIPANT	\N	PRESENT	0
679645	676588	14251Q	PARTICIPANT	\N	PRESENT	0
679646	676588	14215L	PARTICIPANT	\N	PRESENT	0
679647	676588	14275Y	PARTICIPANT	\N	PRESENT	0
679648	676588	11090Q	PARTICIPANT	\N	PRESENT	0
679649	676588	19631V	PARTICIPANT	\N	PRESENT	0
679650	676588	20094J	PARTICIPANT	\N	PRESENT	0
679651	676588	14225N	PARTICIPANT	\N	PRESENT	0
679624	676588	95063L	PARTICIPANT	\N	PRESENT	0
679625	676588	19866P	PARTICIPANT	\N	PRESENT	0
680001	676588	14037X	PARTICIPANT	\N	PRESENT	0
680002	676588	11110B	PARTICIPANT	\N	PRESENT	0
680003	676588	19479G	PARTICIPANT	\N	PRESENT	0
680004	676588	19563B	PARTICIPANT	\N	PRESENT	0
680005	676588	11040E	PARTICIPANT	\N	PRESENT	0
680006	676588	19695N	PARTICIPANT	\N	PRESENT	0
680025	676588	14205J	PARTICIPANT	\N	PRESENT	0
680060	676588	20034V	PARTICIPANT	\N	PRESENT	0
680061	676588	08010L	PARTICIPANT	\N	PRESENT	0
680062	676588	14083S	PARTICIPANT	\N	PRESENT	0
680063	676592	95063L	PARTICIPANT	\N	PRESENT	0
680064	676592	19866P	PARTICIPANT	\N	PRESENT	0
680065	676592	19629C	PARTICIPANT	\N	PRESENT	0
680066	676592	19333N	PARTICIPANT	\N	PRESENT	0
680067	676592	20092G	PARTICIPANT	\N	PRESENT	0
680068	676592	19717B	PARTICIPANT	\N	PRESENT	0
680069	676592	19349W	PARTICIPANT	\N	PRESENT	0
680070	676592	07004J	PARTICIPANT	\N	PRESENT	0
680071	676592	20252E	PARTICIPANT	\N	PRESENT	0
680072	676592	14069U	PARTICIPANT	\N	PRESENT	0
680073	676592	07029T	PARTICIPANT	\N	PRESENT	0
680074	676592	19575F	PARTICIPANT	\N	PRESENT	0
680075	676592	19723Y	PARTICIPANT	\N	PRESENT	0
680076	676592	14253S	PARTICIPANT	\N	PRESENT	0
680077	676592	20070A	PARTICIPANT	\N	PRESENT	0
680078	676592	14257W	PARTICIPANT	\N	PRESENT	0
680079	676592	20044X	PARTICIPANT	\N	PRESENT	0
680080	676592	19515S	PARTICIPANT	\N	PRESENT	0
680081	676592	14215L	PARTICIPANT	\N	PRESENT	0
680082	676592	11090Q	PARTICIPANT	\N	PRESENT	0
680083	676592	19631V	PARTICIPANT	\N	PRESENT	0
680084	676592	20094J	PARTICIPANT	\N	PRESENT	0
680085	676592	14037X	PARTICIPANT	\N	PRESENT	0
680086	676592	11110B	PARTICIPANT	\N	PRESENT	0
680087	676592	19479G	PARTICIPANT	\N	PRESENT	0
680088	676592	19563B	PARTICIPANT	\N	PRESENT	0
680089	676592	11040E	PARTICIPANT	\N	PRESENT	0
680090	676592	19695N	PARTICIPANT	\N	PRESENT	0
680091	676592	14205J	PARTICIPANT	\N	PRESENT	0
680092	676592	20034V	PARTICIPANT	\N	PRESENT	0
680093	676592	08010L	PARTICIPANT	\N	PRESENT	0
680094	676592	14083S	PARTICIPANT	\N	PRESENT	0
680095	676592	20298U	PARTICIPANT	\N	PRESENT	0
680096	676592	14225N	PARTICIPANT	\N	PRESENT	0
680097	676592	19531S	PARTICIPANT	\N	PRESENT	0
680098	676592	19715Y	PARTICIPANT	\N	PRESENT	0
680124	680123	20022R	PARTICIPANT	\N	PRESENT	0
680125	680123	14151M	PARTICIPANT	\N	PRESENT	0
680208	674941	05008E	PARTICIPANT	\N	EXCUSE	0
680209	674941	11010L	PARTICIPANT	\N	EXCUSE	0
680210	678416	05008E	PARTICIPANT	\N	EXCUSE	0
680211	678416	11010L	PARTICIPANT	\N	EXCUSE	0
680212	674944	05008E	PARTICIPANT	\N	EXCUSE	0
680213	674944	11010L	PARTICIPANT	\N	EXCUSE	0
680214	674944	19717B	PRESIDENT	0	PRESENT	0
680215	674944	20034V	PARTICIPANT	\N	PRESENT	0
680216	674941	19717B	PRESIDENT	0	PRESENT	0
680217	674941	20034V	PARTICIPANT	\N	PRESENT	0
680218	678416	19717B	PRESIDENT	0	PRESENT	0
680219	678416	20034V	PARTICIPANT	\N	PRESENT	0
680301	680300	20114U	PARTICIPANT	\N	PRESENT	0
680302	680300	11074Q	PARTICIPANT	\N	PRESENT	0
680303	680300	14179A	PARTICIPANT	\N	PRESENT	0
680304	680300	19669L	PARTICIPANT	\N	PRESENT	0
680306	680305	14249W	PARTICIPANT	\N	PRESENT	0
680307	680305	20056C	PARTICIPANT	\N	PRESENT	0
681017	681008	14026U	PARTICIPANT	\N	PRESENT	0
681248	681247	20066E	PARTICIPANT	\N	PRESENT	0
681250	681249	20066E	PARTICIPANT	\N	PRESENT	0
681317	681316	19507S	PARTICIPANT	\N	PRESENT	0
681339	681338	20090E	PARTICIPANT	\N	PRESENT	0
681340	681338	14255U	PARTICIPANT	\N	PRESENT	0
681341	681338	14267Y	PARTICIPANT	\N	PRESENT	0
681342	681338	11026G	PARTICIPANT	\N	PRESENT	0
681343	681338	10015M	PARTICIPANT	\N	PRESENT	0
681750	681083	19369B	PARTICIPANT	\N	EXCUSE	0
681751	681083	20018V	PARTICIPANT	\N	EXCUSE	0
681752	681083	20104S	PARTICIPANT	\N	EXCUSE	0
681753	681083	14329V	PARTICIPANT	\N	EXCUSE	0
681757	681083	11103C	PARTICIPANT	\N	PRESENT	0
681758	681083	19739H	PARTICIPANT	\N	PRESENT	0
681759	681083	20038A	PARTICIPANT	\N	PRESENT	0
681760	681083	11097X	PARTICIPANT	\N	PRESENT	0
681763	681083	17367Q	PARTICIPANT	\N	PRESENT	0
681764	681083	05012A	PARTICIPANT	\N	PRESENT	0
681796	678422	14217N	PRESIDENT	0	PRESENT	0
681797	678422	14195A	PARTICIPANT	\N	PRESENT	0
681798	678422	19591F	PARTICIPANT	\N	PRESENT	0
681799	678422	17779H	PARTICIPANT	\N	PRESENT	0
681800	678422	19683J	PARTICIPANT	\N	PRESENT	0
681801	678422	18193Q	PARTICIPANT	\N	PRESENT	0
681802	678422	20248J	PARTICIPANT	\N	PRESENT	0
681803	678422	17965H	PARTICIPANT	\N	PRESENT	0
681804	678422	19717B	PARTICIPANT	\N	PRESENT	0
681805	678422	20130U	PARTICIPANT	\N	PRESENT	0
681806	678422	20040T	PARTICIPANT	\N	PRESENT	0
681807	678422	19553Y	PARTICIPANT	\N	PRESENT	0
681808	678422	14042U	PARTICIPANT	\N	PRESENT	0
681809	678422	14026U	PARTICIPANT	\N	PRESENT	0
681810	678422	14355X	PARTICIPANT	\N	PRESENT	0
681811	678422	19703U	PARTICIPANT	\N	PRESENT	0
681812	678422	19691J	PARTICIPANT	\N	PRESENT	0
681813	678422	19679N	PARTICIPANT	\N	PRESENT	0
681814	678422	14071N	PARTICIPANT	\N	PRESENT	0
681815	678422	14223L	PARTICIPANT	\N	PRESENT	0
681816	678422	14213J	PARTICIPANT	\N	PRESENT	0
681817	678422	19511N	PARTICIPANT	\N	PRESENT	0
681818	678422	11097X	PARTICIPANT	\N	PRESENT	0
681819	678422	04092N	PARTICIPANT	\N	EXCUSE	0
681820	678422	19798U	PARTICIPANT	\N	EXCUSE	0
681821	678422	19697Q	PARTICIPANT	\N	PRESENT	0
681825	678422	04057K	PARTICIPANT	\N	PRESENT	0
681823	678422	19295A	PARTICIPANT	\N	EXCUSE	0
681824	678422	19367Y	PARTICIPANT	\N	EXCUSE	0
681826	678422	19723Y	PARTICIPANT	\N	PRESENT	0
681829	678422	10006L	PARTICIPANT	\N	PRESENT	0
681830	678422	20266L	PARTICIPANT	\N	PRESENT	0
681873	678422	19657G	PARTICIPANT	\N	PRESENT	0
681874	678422	20066E	PARTICIPANT	\N	PRESENT	0
681875	678422	20090E	PARTICIPANT	\N	PRESENT	0
681876	678422	19713W	PARTICIPANT	\N	PRESENT	0
681912	678422	11031D	PARTICIPANT	\N	PRESENT	0
681913	678422	19760E	PARTICIPANT	\N	EXCUSE	0
681914	678422	11067R	PARTICIPANT	\N	PRESENT	0
681918	678422	19415P	PARTICIPANT	\N	PRESENT	0
681952	681950	14001X	PARTICIPANT	\N	PRESENT	0
681987	678422	19569H	PARTICIPANT	\N	PRESENT	0
682015	678422	19663E	PARTICIPANT	\N	PRESENT	0
682569	674941	18083K	PARTICIPANT	\N	PRESENT	0
682570	674941	19659J	PARTICIPANT	\N	PRESENT	0
682571	674941	97011G	PARTICIPANT	\N	PRESENT	0
682572	674941	14147R	PARTICIPANT	\N	PRESENT	0
682573	674941	11072N	PARTICIPANT	\N	PRESENT	0
661872	661871	11048N	PARTICIPANT	\N	PRESENT	0
661873	661871	01057W	PARTICIPANT	\N	PRESENT	0
661875	661874	19667J	PARTICIPANT	\N	PRESENT	0
661876	661874	11040E	PARTICIPANT	\N	PRESENT	0
661878	661877	20116W	PARTICIPANT	\N	PRESENT	0
661880	661879	20116W	PARTICIPANT	\N	PRESENT	0
661882	661881	19711U	PARTICIPANT	\N	PRESENT	0
661884	661883	11053K	PARTICIPANT	\N	PRESENT	0
661886	661885	19531S	PARTICIPANT	\N	PRESENT	0
661887	661885	19762G	PARTICIPANT	\N	PRESENT	0
661891	661890	20252E	PARTICIPANT	\N	PRESENT	0
661893	661892	19741B	PARTICIPANT	\N	PRESENT	0
664561	662021	20104S	PARTICIPANT	\N	EXCUSE	0
664562	662021	08028W	PARTICIPANT	\N	EXCUSE	0
664563	662021	20018V	PARTICIPANT	\N	EXCUSE	0
664565	662021	19369B	PARTICIPANT	\N	EXCUSE	0
664887	664883	14042U	PARTICIPANT	\N	PRESENT	0
665403	665148	19719D	PARTICIPANT	\N	PRESENT	0
665408	665148	20142Y	PARTICIPANT	\N	PRESENT	0
665409	665148	01062T	PARTICIPANT	\N	PRESENT	0
665410	665148	11027H	PARTICIPANT	\N	PRESENT	0
665411	665148	12028B	PARTICIPANT	\N	PRESENT	0
665412	665148	14217N	PARTICIPANT	\N	PRESENT	0
665413	665148	20060X	PARTICIPANT	\N	PRESENT	0
665414	665148	07033P	PARTICIPANT	\N	PRESENT	0
665415	665148	17589D	PARTICIPANT	\N	PRESENT	0
665416	665148	20150Y	PARTICIPANT	\N	PRESENT	0
665417	665148	19681G	PARTICIPANT	\N	PRESENT	0
665418	665148	19507S	PARTICIPANT	\N	PRESENT	0
665419	665148	20914V	PARTICIPANT	\N	PRESENT	0
665420	665148	14059S	PARTICIPANT	\N	PRESENT	0
665421	663455	19593H	PARTICIPANT	\N	PRESENT	0
665422	663455	19699S	PARTICIPANT	\N	PRESENT	0
665423	663455	20134Y	PARTICIPANT	\N	PRESENT	0
665424	663455	14073Q	PARTICIPANT	\N	PRESENT	0
665425	663455	19533U	PARTICIPANT	\N	PRESENT	0
665426	663455	19611R	PRESIDENT	0	PRESENT	0
665427	663455	20142Y	PARTICIPANT	\N	PRESENT	0
665428	663455	19693L	PARTICIPANT	\N	PRESENT	0
665429	663455	14229S	PARTICIPANT	\N	PRESENT	0
665430	663455	20172F	PARTICIPANT	\N	PRESENT	0
665431	663455	20056C	PARTICIPANT	\N	PRESENT	0
665432	663455	20180F	PARTICIPANT	\N	PRESENT	0
665433	663455	19573D	PARTICIPANT	\N	PRESENT	0
665434	663455	20264J	PARTICIPANT	\N	PRESENT	0
665435	663455	04059M	PARTICIPANT	\N	PRESENT	0
665436	663455	14109K	PARTICIPANT	\N	PRESENT	0
665437	663455	11104D	PARTICIPANT	\N	PRESENT	0
665438	663455	20124W	PARTICIPANT	\N	PRESENT	0
665439	663455	19758L	PARTICIPANT	\N	PRESENT	0
665440	663455	20026V	PARTICIPANT	\N	PRESENT	0
665441	663455	20084G	PARTICIPANT	\N	PRESENT	0
665442	663455	19621T	PARTICIPANT	\N	PRESENT	0
665443	665148	01025N	PARTICIPANT	\N	PRESENT	0
665444	665148	19723Y	PARTICIPANT	\N	PRESENT	0
665446	665148	19511N	PARTICIPANT	\N	PRESENT	0
665447	665148	14229S	PARTICIPANT	\N	PRESENT	0
665448	665148	17779H	PARTICIPANT	\N	PRESENT	0
665449	665148	14038Y	PARTICIPANT	\N	PRESENT	0
665454	665148	20034V	PARTICIPANT	\N	PRESENT	0
665451	665148	20026V	PARTICIPANT	\N	PRESENT	0
665452	665148	20068G	PARTICIPANT	\N	PRESENT	0
665453	665148	14207L	PARTICIPANT	\N	PRESENT	0
665455	665148	19527W	PARTICIPANT	\N	PRESENT	0
665456	665148	20054A	PARTICIPANT	\N	PRESENT	0
665457	665148	04043D	PARTICIPANT	\N	PRESENT	0
665463	665148	20024T	PARTICIPANT	\N	PRESENT	0
665467	665148	14189C	PARTICIPANT	\N	PRESENT	0
665486	665148	19685L	PARTICIPANT	\N	PRESENT	0
665497	665148	20100N	PARTICIPANT	\N	PRESENT	0
665499	665148	14033T	PARTICIPANT	\N	PRESENT	0
665500	665148	08009T	PARTICIPANT	\N	PRESENT	0
665501	665148	19631V	PARTICIPANT	\N	PRESENT	0
665503	665148	14147R	PARTICIPANT	\N	PRESENT	0
665513	665148	19413M	PARTICIPANT	\N	PRESENT	0
665514	665148	08073C	PARTICIPANT	\N	PRESENT	0
665515	665148	19758L	PARTICIPANT	\N	PRESENT	0
665516	665148	17229F	PARTICIPANT	\N	PRESENT	0
665522	665148	14069U	PARTICIPANT	\N	PRESENT	0
665523	665148	19637C	PARTICIPANT	\N	PRESENT	0
665524	665148	19621T	PARTICIPANT	\N	PRESENT	0
665527	665148	11043H	PARTICIPANT	\N	PRESENT	0
665528	665148	19760E	PARTICIPANT	\N	PRESENT	0
665531	665148	19399H	PARTICIPANT	\N	PRESENT	0
665532	665148	01024M	PARTICIPANT	\N	PRESENT	0
665533	665148	19335Q	PARTICIPANT	\N	PRESENT	0
665534	665148	11031D	PARTICIPANT	\N	PRESENT	0
665535	665148	11115U	PARTICIPANT	\N	PRESENT	0
665536	665148	20056C	PARTICIPANT	\N	PRESENT	0
665537	665148	04092N	PARTICIPANT	\N	PRESENT	0
665538	665148	08010L	PARTICIPANT	\N	PRESENT	0
665539	665148	19741B	PARTICIPANT	\N	PRESENT	0
665543	665148	19349W	PARTICIPANT	\N	PRESENT	0
665580	665149	19569H	PARTICIPANT	\N	PRESENT	0
665581	665149	11031D	PARTICIPANT	\N	PRESENT	0
665582	665149	01034P	PARTICIPANT	\N	PRESENT	0
665583	665149	19629C	PARTICIPANT	\N	PRESENT	0
665584	665149	14026U	PARTICIPANT	\N	PRESENT	0
665585	665149	04057K	PARTICIPANT	\N	PRESENT	0
665586	665149	20130U	PARTICIPANT	\N	PRESENT	0
665587	665149	19697Q	PARTICIPANT	\N	PRESENT	0
665588	665149	17779H	PARTICIPANT	\N	PRESENT	0
665589	665149	20066E	PARTICIPANT	\N	PRESENT	0
665590	665149	19782L	PARTICIPANT	\N	PRESENT	0
665576	665149	95063L	PARTICIPANT	\N	PRESENT	0
665579	665149	19679N	PARTICIPANT	\N	PRESENT	0
665591	665149	19367Y	PARTICIPANT	\N	PRESENT	0
665592	665149	14097Y	PARTICIPANT	\N	PRESENT	0
665593	665149	14217N	PARTICIPANT	\N	PRESENT	0
665594	665149	08028W	PARTICIPANT	\N	PRESENT	0
665595	665149	20264J	PARTICIPANT	\N	PRESENT	0
665596	665149	19649G	PARTICIPANT	\N	PRESENT	0
665598	665149	19683J	PARTICIPANT	\N	PRESENT	0
665600	665149	11045K	PARTICIPANT	\N	PRESENT	0
665601	665149	19525U	PARTICIPANT	\N	PRESENT	0
665602	665149	19583F	PARTICIPANT	\N	PRESENT	0
665603	665149	19651A	PARTICIPANT	\N	PRESENT	0
665604	665149	04085P	PARTICIPANT	\N	PRESENT	0
665605	665149	19760E	PARTICIPANT	\N	PRESENT	0
665606	665149	11067R	PARTICIPANT	\N	PRESENT	0
665607	665149	11033F	PARTICIPANT	\N	PRESENT	0
665608	665149	08061X	PARTICIPANT	\N	PRESENT	0
665609	665149	14033T	PARTICIPANT	\N	PRESENT	0
665610	665149	20072C	PARTICIPANT	\N	PRESENT	0
665611	665149	20040T	PARTICIPANT	\N	PRESENT	0
665612	665149	04043D	PARTICIPANT	\N	PRESENT	0
665613	665149	19663E	PARTICIPANT	\N	PRESENT	0
665614	665149	19701S	PARTICIPANT	\N	PRESENT	0
665615	665149	19798U	PARTICIPANT	\N	PRESENT	0
665616	665149	11097X	PARTICIPANT	\N	PRESENT	0
665617	665149	20024T	PARTICIPANT	\N	PRESENT	0
665618	665149	19415P	PARTICIPANT	\N	PRESENT	0
665619	665149	19729F	PARTICIPANT	\N	PRESENT	0
665620	665149	20062A	PARTICIPANT	\N	PRESENT	0
665621	665149	11043H	PARTICIPANT	\N	PRESENT	0
665622	665149	20090E	PARTICIPANT	\N	PRESENT	0
665623	665149	19507S	PARTICIPANT	\N	PRESENT	0
665624	665149	20056C	PARTICIPANT	\N	PRESENT	0
665625	665149	19573D	PARTICIPANT	\N	PRESENT	0
665626	665149	14038Y	PARTICIPANT	\N	PRESENT	0
665627	665149	14213J	PARTICIPANT	\N	PRESENT	0
665631	665149	10006L	PARTICIPANT	\N	PRESENT	0
665629	665149	11101A	PARTICIPANT	\N	PRESENT	0
665630	665149	19703U	PARTICIPANT	\N	PRESENT	0
665632	665149	14219Q	PARTICIPANT	\N	PRESENT	0
665633	665149	20058E	PARTICIPANT	\N	PRESENT	0
665634	665149	97011G	PARTICIPANT	\N	PRESENT	0
665635	665149	20054A	PARTICIPANT	\N	PRESENT	0
665636	665149	17965H	PARTICIPANT	\N	PRESENT	0
665637	665149	14021P	PARTICIPANT	\N	PRESENT	0
665638	665149	20076G	PARTICIPANT	\N	PRESENT	0
665639	665149	19531S	PARTICIPANT	\N	PRESENT	0
665640	665149	19333N	PARTICIPANT	\N	PRESENT	0
665641	665149	14195A	PARTICIPANT	\N	PRESENT	0
665642	665149	19563B	PARTICIPANT	\N	PRESENT	0
665643	665149	19447X	PARTICIPANT	\N	PRESENT	0
665644	665149	14069U	PARTICIPANT	\N	PRESENT	0
665645	665149	11012A	PARTICIPANT	\N	PRESENT	0
665646	665149	19673G	PARTICIPANT	\N	PRESENT	0
665647	665149	14173T	PARTICIPANT	\N	PRESENT	0
665648	665149	08045X	PARTICIPANT	\N	PRESENT	0
665541	665540	11048N	PARTICIPANT	\N	PRESENT	0
665542	665540	19711U	PARTICIPANT	\N	PRESENT	0
680430	676599	14111D	PARTICIPANT	\N	PRESENT	0
680431	676599	19629C	PARTICIPANT	\N	PRESENT	0
680432	676599	01028R	PARTICIPANT	\N	PRESENT	0
680433	676599	20034V	PARTICIPANT	\N	PRESENT	0
680434	676599	20132W	PARTICIPANT	\N	PRESENT	0
680435	676599	19533U	PARTICIPANT	\N	PRESENT	0
680437	680436	14109K	PARTICIPANT	\N	PRESENT	0
680438	680436	14229S	PARTICIPANT	\N	PRESENT	0
680439	680436	20058E	PARTICIPANT	\N	PRESENT	0
680441	680440	14109K	PARTICIPANT	\N	PRESENT	1
680442	680440	14030Q	PARTICIPANT	\N	PRESENT	1
680443	680440	14229S	PARTICIPANT	\N	PRESENT	1
680444	680440	20058E	PARTICIPANT	\N	PRESENT	1
680445	680440	19057M	PARTICIPANT	\N	PRESENT	1
680447	680446	14109K	PARTICIPANT	\N	PRESENT	1
680448	680446	20058E	PARTICIPANT	\N	PRESENT	1
680449	680446	14229S	PARTICIPANT	\N	PRESENT	1
680450	680446	19057M	PARTICIPANT	\N	PRESENT	1
680452	680451	14109K	PARTICIPANT	\N	PRESENT	1
680453	680451	19057M	PARTICIPANT	\N	PRESENT	1
680454	680451	14229S	PARTICIPANT	\N	PRESENT	1
680455	676599	19647E	PARTICIPANT	\N	PRESENT	0
680456	676599	19301E	PARTICIPANT	\N	PRESENT	0
680457	676599	11048N	PARTICIPANT	\N	PRESENT	0
680458	676599	20914V	PARTICIPANT	\N	PRESENT	0
680459	676599	04085P	PARTICIPANT	\N	PRESENT	0
680489	676600	11045K	PARTICIPANT	\N	PRESENT	0
680490	676600	19741B	PARTICIPANT	\N	PRESENT	0
680491	676600	20094J	PARTICIPANT	\N	PRESENT	0
680492	676600	14225N	PARTICIPANT	\N	PRESENT	0
680493	676600	20034V	PARTICIPANT	\N	PRESENT	0
680494	676600	11056N	PARTICIPANT	\N	PRESENT	0
680495	676600	04085P	PARTICIPANT	\N	PRESENT	0
680496	676600	04047H	PARTICIPANT	\N	PRESENT	0
680497	676600	14053L	PARTICIPANT	\N	PRESENT	0
680498	676600	20914V	PARTICIPANT	\N	PRESENT	0
680499	676600	20132W	PARTICIPANT	\N	PRESENT	0
680500	676600	20116W	PARTICIPANT	\N	PRESENT	0
680501	676600	19301E	PARTICIPANT	\N	PRESENT	0
680502	676600	19629C	PARTICIPANT	\N	PRESENT	0
680503	676600	14111D	PARTICIPANT	\N	PRESENT	0
680504	676600	07004J	PARTICIPANT	\N	PRESENT	0
680505	676600	20080C	PARTICIPANT	\N	PRESENT	0
680506	676600	11072N	PARTICIPANT	\N	PRESENT	0
680507	676600	14069U	PARTICIPANT	\N	PRESENT	0
680508	676594	11045K	PARTICIPANT	\N	PRESENT	0
680509	676594	19741B	PARTICIPANT	\N	PRESENT	0
680510	676594	20094J	PARTICIPANT	\N	PRESENT	0
680511	676594	14225N	PARTICIPANT	\N	PRESENT	0
680512	676594	20034V	PARTICIPANT	\N	PRESENT	0
680513	676594	11056N	PARTICIPANT	\N	PRESENT	0
680514	676594	04085P	PARTICIPANT	\N	PRESENT	0
680515	676594	04047H	PARTICIPANT	\N	PRESENT	0
680516	676594	14053L	PARTICIPANT	\N	PRESENT	0
680517	676594	20914V	PARTICIPANT	\N	PRESENT	0
680527	676594	20080C	PARTICIPANT	\N	PRESENT	0
680519	676594	20116W	PARTICIPANT	\N	PRESENT	0
680559	679535	04071H	PARTICIPANT	\N	PRESENT	0
680521	676594	19629C	PARTICIPANT	\N	PRESENT	0
680528	676594	19749K	PARTICIPANT	\N	PRESENT	0
680523	676594	07004J	PARTICIPANT	\N	PRESENT	0
680529	676594	14111D	PARTICIPANT	\N	PRESENT	0
680525	676594	11072N	PARTICIPANT	\N	PRESENT	0
680545	679535	11048N	PARTICIPANT	\N	PRESENT	0
680546	679535	19711U	PARTICIPANT	\N	PRESENT	0
680547	679535	11053K	PARTICIPANT	\N	PRESENT	0
680548	679535	20050V	PARTICIPANT	\N	PRESENT	0
680549	679535	11074Q	PARTICIPANT	\N	PRESENT	0
680550	679535	20044X	PARTICIPANT	\N	PRESENT	0
680551	679535	14225N	PRESIDENT	0	PRESENT	0
680552	679535	07029T	PARTICIPANT	\N	PRESENT	0
680553	679535	20252E	PARTICIPANT	\N	PRESENT	0
680554	679535	20070A	PARTICIPANT	\N	PRESENT	0
680555	679535	20914V	PARTICIPANT	\N	PRESENT	0
680556	679535	99004R	PARTICIPANT	\N	PRESENT	0
680557	679535	20116W	PARTICIPANT	\N	PRESENT	0
680558	679535	11012A	PARTICIPANT	\N	EXCUSE	0
680560	679535	19545Y	PARTICIPANT	\N	PRESENT	0
680561	676608	95063L	PARTICIPANT	\N	PRESENT	0
680562	679535	14083S	PARTICIPANT	\N	PRESENT	0
680563	676608	19545Y	PARTICIPANT	\N	PRESENT	0
680564	676608	20914V	PARTICIPANT	\N	PRESENT	0
680565	676608	19679N	PARTICIPANT	\N	PRESENT	0
680414	676599	11043H	PARTICIPANT	\N	PRESENT	0
680415	676599	14121F	PARTICIPANT	\N	PRESENT	0
680416	676599	14253S	PARTICIPANT	\N	PRESENT	0
680417	676599	08012N	PARTICIPANT	\N	PRESENT	0
680589	676608	19741B	PARTICIPANT	\N	PRESENT	0
680567	676608	19760E	PARTICIPANT	\N	PRESENT	0
680420	676599	11033F	PARTICIPANT	\N	PRESENT	0
680421	676599	14083S	PARTICIPANT	\N	PRESENT	0
680422	676599	20080C	PARTICIPANT	\N	PRESENT	0
680423	676599	19543W	PARTICIPANT	\N	PRESENT	0
680424	676599	11045K	PARTICIPANT	\N	PRESENT	0
680425	676599	19749K	PARTICIPANT	\N	PRESENT	0
680426	676599	11072N	PARTICIPANT	\N	PRESENT	0
680568	676608	19569H	PARTICIPANT	\N	PRESENT	0
680428	676599	19717B	PARTICIPANT	\N	PRESENT	0
680429	676599	19531S	PARTICIPANT	\N	PRESENT	0
680569	676608	19717B	PARTICIPANT	\N	PRESENT	0
680570	676608	19643A	PARTICIPANT	\N	PRESENT	0
680571	676608	11064N	PARTICIPANT	\N	PRESENT	0
680572	676608	20130U	PARTICIPANT	\N	PRESENT	0
680573	676608	19697Q	PARTICIPANT	\N	PRESENT	0
680574	676608	11115U	PARTICIPANT	\N	PRESENT	0
680575	679535	19647E	PARTICIPANT	\N	PRESENT	0
680576	676608	19715Y	PARTICIPANT	\N	PRESENT	0
680578	676608	19683J	PARTICIPANT	\N	PRESENT	0
680579	676608	20116W	PARTICIPANT	\N	PRESENT	0
680580	676608	19711U	PARTICIPANT	\N	PRESENT	0
680581	676608	11048N	PARTICIPANT	\N	PRESENT	0
680582	676608	20252E	PARTICIPANT	\N	PRESENT	0
680583	676608	19651A	PARTICIPANT	\N	PRESENT	0
680584	676608	14225N	PARTICIPANT	\N	PRESENT	0
680588	676608	11031D	PARTICIPANT	\N	PRESENT	0
680586	676608	10006L	PARTICIPANT	\N	PRESENT	0
680587	676608	07029T	PARTICIPANT	\N	PRESENT	0
680590	676608	14083S	PARTICIPANT	\N	PRESENT	0
680591	676608	11074Q	PARTICIPANT	\N	PRESENT	0
680592	676608	20266L	PARTICIPANT	\N	PRESENT	0
680593	676608	11097X	PARTICIPANT	\N	PRESENT	0
680594	676608	20044X	PARTICIPANT	\N	PRESENT	0
680595	676608	19693L	PARTICIPANT	\N	PRESENT	0
680596	676608	20070A	PARTICIPANT	\N	PRESENT	0
680597	676608	19647E	PARTICIPANT	\N	PRESENT	0
680598	676608	14021P	PARTICIPANT	\N	PRESENT	0
680599	676608	11083R	PARTICIPANT	\N	PRESENT	0
680600	676608	19719D	PARTICIPANT	\N	PRESENT	0
680632	676609	19691J	PARTICIPANT	\N	PRESENT	0
680633	676609	19760E	PARTICIPANT	\N	PRESENT	0
680634	676609	20248J	PARTICIPANT	\N	PRESENT	0
680635	676609	19719D	PARTICIPANT	\N	PRESENT	0
680636	676609	11115U	PARTICIPANT	\N	PRESENT	0
680651	676609	19349W	PARTICIPANT	\N	PRESENT	0
680638	676609	20130U	PARTICIPANT	\N	PRESENT	0
680639	676609	11083R	PARTICIPANT	\N	PRESENT	0
680640	676609	19715Y	PARTICIPANT	\N	PRESENT	0
680641	676609	20050V	PARTICIPANT	\N	PRESENT	0
680642	676609	11097X	PARTICIPANT	\N	PRESENT	0
680643	676609	20044X	PARTICIPANT	\N	PRESENT	0
680644	676609	19593H	PARTICIPANT	\N	PRESENT	0
680645	676609	20124W	PARTICIPANT	\N	PRESENT	0
680646	676609	19699S	PARTICIPANT	\N	PRESENT	0
680647	676609	11048N	PARTICIPANT	\N	PRESENT	0
680648	676609	19611R	PARTICIPANT	\N	PRESENT	0
680649	676609	20252E	PARTICIPANT	\N	PRESENT	0
680650	676609	11074Q	PARTICIPANT	\N	PRESENT	0
680652	676609	19651A	PARTICIPANT	\N	PRESENT	0
680653	676609	19693L	PARTICIPANT	\N	PRESENT	0
680654	676609	14083S	PARTICIPANT	\N	PRESENT	0
680655	676609	11054L	PARTICIPANT	\N	PRESENT	0
680656	676609	20142Y	PARTICIPANT	\N	PRESENT	0
680657	676609	20108W	PARTICIPANT	\N	PRESENT	0
680658	676609	20084G	PARTICIPANT	\N	PRESENT	0
680659	676609	20132W	PARTICIPANT	\N	PRESENT	0
680660	676609	20134Y	PARTICIPANT	\N	PRESENT	0
680661	676609	20112S	PARTICIPANT	\N	PRESENT	0
680630	676609	11045K	PARTICIPANT	\N	PRESENT	0
680631	676609	07029T	PARTICIPANT	\N	PRESENT	0
655551	655465	05008E	PARTICIPANT	\N	PRESENT	0
655552	655465	19729F	PARTICIPANT	\N	EXCUSE	0
655553	655465	19301E	PARTICIPANT	\N	EXCUSE	0
655554	655465	08018U	PARTICIPANT	\N	EXCUSE	0
655555	655465	19673G	PARTICIPANT	\N	EXCUSE	0
655556	655465	14231L	PARTICIPANT	\N	EXCUSE	0
655557	655425	14237S	PARTICIPANT	\N	PRESENT	0
655558	655496	14038Y	PARTICIPANT	\N	PRESENT	0
655559	655496	19768N	PARTICIPANT	\N	PRESENT	0
655560	655496	19515S	PARTICIPANT	\N	PRESENT	0
655561	655496	19782L	PARTICIPANT	\N	PRESENT	0
655562	655496	20092G	PARTICIPANT	\N	PRESENT	0
655563	655496	01043Q	PARTICIPANT	\N	PRESENT	0
655564	655496	20082E	PARTICIPANT	\N	PRESENT	0
655565	655496	11090Q	PRESIDENT	0	PRESENT	0
655566	655496	14033T	PARTICIPANT	\N	PRESENT	0
655567	655496	04045F	PARTICIPANT	\N	PRESENT	0
655568	655496	19631V	PARTICIPANT	\N	PRESENT	0
655569	655496	14205J	PARTICIPANT	\N	PRESENT	0
655570	655496	20062A	PARTICIPANT	\N	PRESENT	0
655571	655496	19705W	PARTICIPANT	\N	PRESENT	0
655572	655496	19575F	PARTICIPANT	\N	PRESENT	0
655573	655496	20286Q	PARTICIPANT	\N	PRESENT	0
655574	655496	20298U	PARTICIPANT	\N	PRESENT	0
655575	655496	19369B	PARTICIPANT	\N	PRESENT	0
655576	655496	20018V	PARTICIPANT	\N	PRESENT	0
655577	655496	19747H	PARTICIPANT	\N	PRESENT	0
655578	655496	19563B	PARTICIPANT	\N	PRESENT	0
655579	655496	14257W	PARTICIPANT	\N	PRESENT	0
655580	655496	14037X	PARTICIPANT	\N	PRESENT	0
662410	662018	11110B	PARTICIPANT	\N	PRESENT	0
662411	662018	19749K	PARTICIPANT	\N	PRESENT	0
662412	662018	19479G	PARTICIPANT	\N	PRESENT	0
662413	662018	19441R	PARTICIPANT	\N	PRESENT	0
662414	662018	14179A	PARTICIPANT	\N	PRESENT	0
662415	662018	20048C	PARTICIPANT	\N	PRESENT	0
662416	662018	14219Q	PARTICIPANT	\N	PRESENT	0
662418	662018	19507S	PARTICIPANT	\N	PRESENT	0
662420	662018	17737W	PARTICIPANT	\N	PRESENT	0
662421	662018	19563B	PARTICIPANT	\N	PRESENT	0
662422	662018	19301E	PARTICIPANT	\N	PRESENT	0
662423	662018	14237S	PARTICIPANT	\N	PRESENT	0
662424	662018	19591F	PARTICIPANT	\N	PRESENT	0
662425	662018	20096L	PARTICIPANT	\N	PRESENT	0
662426	662018	19057M	PARTICIPANT	\N	PRESENT	0
662427	662018	19651A	PARTICIPANT	\N	PRESENT	0
662428	662018	14259Y	PARTICIPANT	\N	PRESENT	0
662429	662018	04071H	PARTICIPANT	\N	PRESENT	0
662430	662018	08034U	PARTICIPANT	\N	PRESENT	0
662431	662018	19798U	PARTICIPANT	\N	PRESENT	0
662433	662018	19443T	PARTICIPANT	\N	PRESENT	0
662436	662018	19367Y	PARTICIPANT	\N	PRESENT	0
662437	662018	14033T	PARTICIPANT	\N	PRESENT	0
662438	662018	14038Y	PARTICIPANT	\N	PRESENT	0
662439	662018	20054A	PARTICIPANT	\N	PRESENT	0
662443	662018	11090Q	PARTICIPANT	\N	PRESENT	0
662444	662018	19527W	PARTICIPANT	\N	PRESENT	0
662445	662018	98022P	PARTICIPANT	\N	PRESENT	0
662450	662018	20136B	PARTICIPANT	\N	PRESENT	0
662451	662018	19637C	PARTICIPANT	\N	PRESENT	0
662452	662018	14037X	PARTICIPANT	\N	PRESENT	0
662456	662018	14189C	PARTICIPANT	\N	PRESENT	0
662457	662018	14213J	PARTICIPANT	\N	PRESENT	0
662458	662018	19447X	PARTICIPANT	\N	PRESENT	0
662459	662018	14173T	PARTICIPANT	\N	PRESENT	0
662460	662018	08012N	PARTICIPANT	\N	PRESENT	0
662461	662018	14111D	PARTICIPANT	\N	PRESENT	0
662470	662018	19691J	PARTICIPANT	\N	PRESENT	0
662471	662018	19671E	PARTICIPANT	\N	PRESENT	0
662472	662018	14249W	PARTICIPANT	\N	PRESENT	0
662475	662018	19687N	PARTICIPANT	\N	PRESENT	0
662476	662018	19489J	PARTICIPANT	\N	PRESENT	0
662480	662018	19643A	PARTICIPANT	\N	PRESENT	0
662481	662018	11053K	PARTICIPANT	\N	PRESENT	0
662479	662018	19335Q	PARTICIPANT	\N	PRESENT	0
662482	662018	20180F	PARTICIPANT	\N	PRESENT	0
662483	662018	14327T	PARTICIPANT	\N	PRESENT	0
662484	662018	11103C	PARTICIPANT	\N	PRESENT	0
662485	662018	20092G	PARTICIPANT	\N	PRESENT	0
662486	662018	19679N	PARTICIPANT	\N	PRESENT	0
662487	662018	20116W	PARTICIPANT	\N	PRESENT	0
662488	662018	20106U	PARTICIPANT	\N	PRESENT	0
662770	661833	12041X	PARTICIPANT	\N	PRESENT	0
662771	661833	10006L	PARTICIPANT	\N	PRESENT	0
662772	661833	14213J	PARTICIPANT	\N	PRESENT	0
662773	661833	04033B	PARTICIPANT	\N	PRESENT	0
662774	661833	20090E	PARTICIPANT	\N	PRESENT	0
662775	661833	20062A	PARTICIPANT	\N	PRESENT	0
662776	661833	17737W	PARTICIPANT	\N	PRESENT	0
662777	661833	20114U	PARTICIPANT	\N	PRESENT	0
662778	661833	12016W	PARTICIPANT	\N	PRESENT	0
662779	661833	14121F	PARTICIPANT	\N	PRESENT	0
662780	661833	18193Q	PARTICIPANT	\N	PRESENT	0
662781	661833	11067R	PARTICIPANT	\N	PRESENT	0
662782	661833	20070A	PARTICIPANT	\N	PRESENT	0
662783	661833	19531S	PARTICIPANT	\N	PRESENT	0
662784	661833	20080C	PARTICIPANT	\N	PRESENT	0
662785	661833	11031D	PARTICIPANT	\N	PRESENT	0
662786	661833	19593H	PARTICIPANT	\N	PRESENT	0
662787	661833	14281W	PARTICIPANT	\N	PRESENT	0
662788	661833	08045X	PARTICIPANT	\N	PRESENT	0
662789	661833	19549D	PARTICIPANT	\N	PRESENT	0
662790	661833	08060W	PARTICIPANT	\N	PRESENT	0
662791	661833	19649G	PARTICIPANT	\N	PRESENT	0
662792	661833	19683J	PARTICIPANT	\N	PRESENT	0
662793	661833	17965H	PARTICIPANT	\N	PRESENT	0
662794	661833	19387D	PARTICIPANT	\N	PRESENT	0
662795	661833	20130U	PARTICIPANT	\N	PRESENT	0
662796	661833	20914V	PARTICIPANT	\N	PRESENT	0
662797	661833	14195A	PARTICIPANT	\N	PRESENT	0
662798	661833	19545Y	PARTICIPANT	\N	PRESENT	0
662799	661833	11012A	PARTICIPANT	\N	PRESENT	0
662800	661833	20116W	PARTICIPANT	\N	PRESENT	0
662801	661833	14207L	PARTICIPANT	\N	PRESENT	0
662802	661833	14107H	PARTICIPANT	\N	PRESENT	0
662803	661833	19553Y	PARTICIPANT	\N	PRESENT	0
662804	661833	04045F	PARTICIPANT	\N	PRESENT	0
662805	661833	19329S	PARTICIPANT	\N	PRESENT	0
662806	661833	19651A	PARTICIPANT	\N	PRESENT	0
662807	661833	19691J	PARTICIPANT	\N	PRESENT	0
662808	661833	08009T	PARTICIPANT	\N	PRESENT	0
662809	661833	19569H	PARTICIPANT	\N	PRESENT	0
662810	661833	19699S	PARTICIPANT	\N	PRESENT	0
662811	661833	14083S	PARTICIPANT	\N	PRESENT	0
662812	661833	14189C	PARTICIPANT	\N	PRESENT	0
662813	661833	20066E	PARTICIPANT	\N	PRESENT	0
662814	661833	14030Q	PARTICIPANT	\N	PRESENT	0
662815	661833	19713W	PARTICIPANT	\N	PRESENT	0
662816	661833	19415P	PARTICIPANT	\N	PRESENT	0
662817	661833	11097X	PARTICIPANT	\N	PRESENT	0
662818	661833	08061X	PARTICIPANT	\N	PRESENT	0
662819	661833	19747H	PARTICIPANT	\N	PRESENT	0
662820	661833	11040E	PARTICIPANT	\N	PRESENT	0
662821	661833	19671E	PARTICIPANT	\N	PRESENT	0
662822	661833	19367Y	PARTICIPANT	\N	PRESENT	0
662823	661833	19581D	PARTICIPANT	\N	PRESENT	0
662824	661833	14055N	PARTICIPANT	\N	PRESENT	0
662825	661833	19685L	PARTICIPANT	\N	PRESENT	0
662826	661833	19760E	PARTICIPANT	\N	PRESENT	0
662827	661833	19681G	PARTICIPANT	\N	PRESENT	0
662828	661833	20020P	PARTICIPANT	\N	PRESENT	0
662829	661833	20120S	PARTICIPANT	\N	PRESENT	0
662830	661833	19533U	PARTICIPANT	\N	PRESENT	0
662831	661833	19383Y	PARTICIPANT	\N	PRESENT	0
662832	661833	14071N	PARTICIPANT	\N	PRESENT	0
662833	661833	19703U	PARTICIPANT	\N	PRESENT	0
662834	661833	04092N	PARTICIPANT	\N	PRESENT	0
662835	661833	01048V	PARTICIPANT	\N	PRESENT	0
662836	661833	14059S	PARTICIPANT	\N	PRESENT	0
662837	661833	11103C	PARTICIPANT	\N	PRESENT	0
662838	661833	20172F	PARTICIPANT	\N	PRESENT	0
662839	661833	08015R	PARTICIPANT	\N	PRESENT	0
662840	661833	20032T	PARTICIPANT	\N	PRESENT	0
662841	661833	20022R	PARTICIPANT	\N	PRESENT	0
662842	661833	14223L	PARTICIPANT	\N	PRESENT	0
662843	661833	19711U	PARTICIPANT	\N	PRESENT	0
662844	661833	14187A	PARTICIPANT	\N	PRESENT	0
662845	661833	20078J	PARTICIPANT	\N	PRESENT	0
662846	661833	10015M	PARTICIPANT	\N	PRESENT	0
662847	661833	18083K	PARTICIPANT	\N	PRESENT	0
662848	661833	08028W	PARTICIPANT	\N	PRESENT	0
664589	661905	05008E	PARTICIPANT	\N	EXCUSE	0
664590	661905	19577H	PARTICIPANT	\N	EXCUSE	0
664591	661905	19715Y	PARTICIPANT	\N	EXCUSE	0
664592	661905	14219Q	PARTICIPANT	\N	EXCUSE	0
664593	661905	14059S	PARTICIPANT	\N	EXCUSE	0
664594	661905	11010L	PARTICIPANT	\N	EXCUSE	0
664595	661905	14331P	PARTICIPANT	\N	EXCUSE	0
664596	661905	11043H	PARTICIPANT	\N	EXCUSE	0
664597	661905	12016W	PARTICIPANT	\N	EXCUSE	0
664609	664551	19717B	PRESIDENT	0	PRESENT	0
664610	664551	20034V	PARTICIPANT	\N	PRESENT	0
664611	664551	05008E	PARTICIPANT	\N	EXCUSE	0
664613	664551	19577H	PARTICIPANT	\N	EXCUSE	0
664616	664551	19715Y	PARTICIPANT	\N	EXCUSE	0
664620	664551	14059S	PARTICIPANT	\N	EXCUSE	0
664622	664551	11010L	PARTICIPANT	\N	EXCUSE	0
664623	664551	14219Q	PARTICIPANT	\N	EXCUSE	0
664624	664551	11043H	PARTICIPANT	\N	EXCUSE	0
664625	664551	14331P	PARTICIPANT	\N	EXCUSE	0
664626	664551	12016W	PARTICIPANT	\N	EXCUSE	0
667510	664874	19515S	PRESIDENT	0	PRESENT	0
667511	664874	20126Y	PARTICIPANT	\N	PRESENT	0
667512	664874	14083S	PARTICIPANT	\N	PRESENT	0
667513	664874	14105F	PARTICIPANT	\N	PRESENT	0
667514	664874	14030Q	PARTICIPANT	\N	PRESENT	0
667515	664874	19671E	PARTICIPANT	\N	PRESENT	0
667516	664874	20060X	PARTICIPANT	\N	PRESENT	0
667517	664874	19251M	PARTICIPANT	\N	PRESENT	0
667518	664874	20082E	PARTICIPANT	\N	PRESENT	0
667519	664874	20094J	PARTICIPANT	\N	PRESENT	0
667520	664874	19575F	PARTICIPANT	\N	PRESENT	0
667521	664874	16685X	PARTICIPANT	\N	PRESENT	0
676860	676859	20062A	PARTICIPANT	\N	PRESENT	0
676865	676864	20062A	PARTICIPANT	\N	PRESENT	0
676866	676864	14033T	PARTICIPANT	\N	PRESENT	0
676913	676910	20062A	PARTICIPANT	\N	PRESENT	0
682586	679539	08010L	PARTICIPANT	\N	EXCUSE	0
682587	679539	20050V	PARTICIPANT	\N	EXCUSE	0
682591	682073	14221J	PARTICIPANT	\N	PRESENT	0
682592	679539	19479G	PARTICIPANT	\N	PRESENT	0
682595	679539	08034U	PARTICIPANT	\N	PRESENT	0
682596	682073	04043D	PARTICIPANT	\N	PRESENT	0
682619	676619	99004R	PARTICIPANT	\N	PRESENT	0
682620	682073	11067R	PARTICIPANT	\N	PRESENT	0
682621	682588	14026U	PARTICIPANT	\N	PRESENT	0
682622	682588	11067R	PARTICIPANT	\N	PRESENT	0
682623	682594	14026U	PARTICIPANT	\N	PRESENT	0
682624	682594	11067R	PARTICIPANT	\N	PRESENT	0
682625	682597	14069U	PARTICIPANT	\N	PRESENT	0
682626	682611	14026U	PARTICIPANT	\N	PRESENT	0
682627	682611	11067R	PARTICIPANT	\N	PRESENT	0
682628	681105	14026U	PARTICIPANT	\N	PRESENT	0
682629	681105	11067R	PARTICIPANT	\N	PRESENT	0
682630	676369	19673G	PARTICIPANT	\N	PRESENT	0
682631	676369	14026U	PARTICIPANT	\N	PRESENT	0
682632	676369	14030Q	PARTICIPANT	\N	PRESENT	0
682633	680766	19507S	PARTICIPANT	\N	PRESENT	0
682634	680766	12041X	PARTICIPANT	\N	PRESENT	0
682635	680766	19593H	PARTICIPANT	\N	PRESENT	0
682636	680766	20100N	PARTICIPANT	\N	PRESENT	0
682637	680766	14073Q	PARTICIPANT	\N	PRESENT	0
682638	680766	10015M	PARTICIPANT	\N	PRESENT	0
682639	680766	14033T	PARTICIPANT	\N	PRESENT	0
682640	680766	19711U	PARTICIPANT	\N	PRESENT	0
682641	680766	14189C	PARTICIPANT	\N	PRESENT	0
682642	680766	14331P	PRESIDENT	0	PRESENT	0
682643	680766	20094J	PARTICIPANT	\N	PRESENT	0
682644	680766	19515S	PARTICIPANT	\N	PRESENT	0
682645	680766	19747H	PARTICIPANT	\N	PRESENT	0
682646	680766	19467C	PARTICIPANT	\N	PRESENT	0
682647	680766	20054A	PARTICIPANT	\N	PRESENT	0
682648	680766	20028X	PARTICIPANT	\N	PRESENT	0
682649	680766	20018V	PARTICIPANT	\N	PRESENT	0
682650	680766	14257W	PARTICIPANT	\N	PRESENT	0
682651	680766	20144B	PARTICIPANT	\N	PRESENT	0
682652	680766	04045F	PARTICIPANT	\N	PRESENT	0
682653	680766	20092G	PARTICIPANT	\N	PRESENT	0
682654	676619	11026G	PARTICIPANT	\N	PRESENT	0
682655	676619	19629C	PARTICIPANT	\N	PRESENT	0
682656	676619	04085P	PARTICIPANT	\N	PRESENT	0
682657	676619	14225N	PARTICIPANT	\N	PRESENT	0
682658	676619	19671E	PARTICIPANT	\N	PRESENT	0
682659	676619	11012A	PARTICIPANT	\N	PRESENT	0
682660	676619	19583F	PARTICIPANT	\N	PRESENT	0
682661	676619	07004J	PARTICIPANT	\N	PRESENT	0
682662	676619	20110Q	PARTICIPANT	\N	PRESENT	0
682663	676619	14215L	PARTICIPANT	\N	PRESENT	0
682664	676619	14147R	PARTICIPANT	\N	PRESENT	0
682665	676619	18083K	PARTICIPANT	\N	PRESENT	0
682666	676619	11033F	PARTICIPANT	\N	PRESENT	0
682667	676619	14021P	PARTICIPANT	\N	PRESENT	0
682668	676619	14249W	PARTICIPANT	\N	PRESENT	0
682669	676619	04047H	PARTICIPANT	\N	PRESENT	0
682670	676619	20086J	PARTICIPANT	\N	PRESENT	0
682671	676619	19479G	PARTICIPANT	\N	PRESENT	0
682672	676619	14267Y	PARTICIPANT	\N	PRESENT	0
682673	676619	19447X	PARTICIPANT	\N	PRESENT	0
682674	676619	17637T	PARTICIPANT	\N	PRESENT	0
682675	676619	08073C	PARTICIPANT	\N	PRESENT	0
682676	676619	20064C	PARTICIPANT	\N	PRESENT	0
682677	676619	14189C	PARTICIPANT	\N	PRESENT	0
682678	676619	14055N	PARTICIPANT	\N	PRESENT	0
682679	676619	11043H	PARTICIPANT	\N	PRESENT	0
682680	676619	19673G	PARTICIPANT	\N	PRESENT	0
682681	676619	20078J	PARTICIPANT	\N	PRESENT	0
682682	676619	20252E	PARTICIPANT	\N	PRESENT	0
682683	676619	19599P	PARTICIPANT	\N	PRESENT	0
682684	682597	20070A	PARTICIPANT	\N	PRESENT	0
682685	676619	11067R	PARTICIPANT	\N	PRESENT	0
682686	676619	20080C	PARTICIPANT	\N	PRESENT	0
682687	679201	19527W	PARTICIPANT	\N	PRESENT	0
682688	679201	19611R	PRESIDENT	0	PRESENT	0
682689	679201	20138D	PARTICIPANT	\N	PRESENT	0
682690	679201	20142Y	PARTICIPANT	\N	PRESENT	0
682691	679201	20052X	PARTICIPANT	\N	PRESENT	0
682692	679201	14229S	PARTICIPANT	\N	PRESENT	0
682693	679201	14030Q	PARTICIPANT	\N	PRESENT	0
682694	679201	20264J	PARTICIPANT	\N	PRESENT	0
682695	679201	14109K	PARTICIPANT	\N	PRESENT	0
682696	679201	14123H	PARTICIPANT	\N	PRESENT	0
682697	679201	19758L	PARTICIPANT	\N	PRESENT	0
682698	679201	20084G	PARTICIPANT	\N	PRESENT	0
682699	679201	19621T	PARTICIPANT	\N	PRESENT	0
682700	679201	11109J	PARTICIPANT	\N	EXCUSE	0
682701	681087	19467C	PARTICIPANT	\N	PRESENT	0
682702	681087	19515S	PARTICIPANT	\N	PRESENT	0
682703	681087	20092G	PARTICIPANT	\N	PRESENT	0
682704	681087	20144B	PARTICIPANT	\N	PRESENT	0
682705	681087	14033T	PARTICIPANT	\N	PRESENT	0
682706	681087	20094J	PARTICIPANT	\N	PRESENT	0
682707	681087	04045F	PARTICIPANT	\N	PRESENT	0
682708	681087	20054A	PARTICIPANT	\N	PRESENT	0
682709	681087	19507S	PARTICIPANT	\N	PRESENT	0
682710	681087	20018V	PARTICIPANT	\N	PRESENT	0
682711	681087	19747H	PARTICIPANT	\N	PRESENT	0
682712	681087	14257W	PRESIDENT	0	PRESENT	0
682713	681087	20028X	PARTICIPANT	\N	PRESENT	0
682714	676619	19387D	PARTICIPANT	\N	PRESENT	0
682715	676619	20036X	PARTICIPANT	\N	PRESENT	0
682716	676619	20028X	PARTICIPANT	\N	PRESENT	0
682717	676619	20046A	PARTICIPANT	\N	PRESENT	0
682718	676619	20102Q	PARTICIPANT	\N	PRESENT	0
682719	678416	19715Y	PARTICIPANT	\N	PRESENT	0
682720	678416	97011G	PARTICIPANT	\N	PRESENT	0
682721	681087	12041X	PARTICIPANT	\N	PRESENT	0
682722	681087	19593H	PARTICIPANT	\N	PRESENT	0
682723	681087	20100N	PARTICIPANT	\N	PRESENT	0
682724	681087	14073Q	PARTICIPANT	\N	PRESENT	0
682725	681087	10015M	PARTICIPANT	\N	PRESENT	0
682726	681087	19711U	PARTICIPANT	\N	PRESENT	0
682727	681087	14189C	PARTICIPANT	\N	PRESENT	0
682728	681087	14331P	PARTICIPANT	\N	PRESENT	0
682729	674941	19715Y	PARTICIPANT	\N	EXCUSE	0
682730	674946	19717B	PARTICIPANT	\N	PRESENT	0
682731	674946	05008E	PARTICIPANT	\N	EXCUSE	0
682732	681087	14329V	PARTICIPANT	\N	EXCUSE	0
682733	681087	20062A	PARTICIPANT	\N	EXCUSE	0
682734	681087	20082E	PARTICIPANT	\N	EXCUSE	0
682735	676619	19681G	PARTICIPANT	\N	PRESENT	0
655238	655237	14169X	PARTICIPANT	\N	PRESENT	0
655239	655237	04070G	PARTICIPANT	\N	PRESENT	0
655241	655240	14169X	PARTICIPANT	\N	PRESENT	0
655242	655240	04070G	PARTICIPANT	\N	PRESENT	0
655244	655243	14169X	PARTICIPANT	\N	PRESENT	0
655245	655243	04070G	PARTICIPANT	\N	PRESENT	0
655712	655711	04071H	PARTICIPANT	\N	PRESENT	0
655714	655713	07029T	PARTICIPANT	\N	PRESENT	0
655716	655715	19533U	PARTICIPANT	\N	PRESENT	1
655717	655715	19057M	PARTICIPANT	\N	PRESENT	1
655718	655405	14123H	PARTICIPANT	\N	PRESENT	0
655719	655405	14030Q	PARTICIPANT	\N	PRESENT	1
655720	655405	14109K	PARTICIPANT	\N	PRESENT	1
655721	655405	20142Y	PARTICIPANT	\N	PRESENT	1
655722	655405	14229S	PARTICIPANT	\N	PRESENT	1
655723	655715	14123H	PARTICIPANT	\N	PRESENT	0
656167	656166	20130U	PARTICIPANT	\N	PRESENT	0
656168	656166	17965H	PARTICIPANT	\N	PRESENT	0
656169	656166	18193Q	PARTICIPANT	\N	PRESENT	0
659110	659097	20144B	PARTICIPANT	\N	PRESENT	0
659111	659097	19369B	PARTICIPANT	\N	PRESENT	0
659113	659112	20144B	PARTICIPANT	\N	PRESENT	0
659115	659114	20144B	PARTICIPANT	\N	PRESENT	0
659118	659116	14257W	PARTICIPANT	\N	PRESENT	0
659119	659116	20088L	PARTICIPANT	\N	PRESENT	0
659120	659116	20144B	PARTICIPANT	\N	PRESENT	0
659124	659122	20144B	PARTICIPANT	\N	PRESENT	0
659125	659122	14257W	PARTICIPANT	\N	PRESENT	0
659126	659122	14205J	PARTICIPANT	\N	PRESENT	0
659128	659127	20144B	PARTICIPANT	\N	PRESENT	0
659129	659127	14257W	PARTICIPANT	\N	PRESENT	0
659132	659131	14205J	PARTICIPANT	\N	PRESENT	0
659133	659131	20144B	PARTICIPANT	\N	PRESENT	0
659135	659134	14205J	PARTICIPANT	\N	PRESENT	0
659136	659134	20144B	PARTICIPANT	\N	PRESENT	0
659138	659137	20144B	PARTICIPANT	\N	PRESENT	0
659155	659154	20144B	PARTICIPANT	\N	PRESENT	0
659156	659154	20298U	PARTICIPANT	\N	PRESENT	0
659158	659157	20144B	PARTICIPANT	\N	PRESENT	0
659161	659160	14207L	PARTICIPANT	\N	PRESENT	0
659162	659160	20144B	PARTICIPANT	\N	PRESENT	0
659165	659163	20144B	PARTICIPANT	\N	PRESENT	0
659167	659163	14207L	PARTICIPANT	\N	PRESENT	0
659168	659163	20092G	PARTICIPANT	\N	PRESENT	0
659174	659173	20144B	PARTICIPANT	\N	PRESENT	0
659175	659173	14207L	PARTICIPANT	\N	PRESENT	0
659177	659173	20092G	PARTICIPANT	\N	PRESENT	0
659182	659180	20144B	PARTICIPANT	\N	PRESENT	0
659183	659180	20092G	PARTICIPANT	\N	PRESENT	0
659285	659284	14237S	PARTICIPANT	\N	PRESENT	0
659286	659284	19631V	PARTICIPANT	\N	PRESENT	0
659287	659284	20018V	PARTICIPANT	\N	PRESENT	0
659289	659284	20066E	PARTICIPANT	\N	PRESENT	0
659290	659284	20058E	PARTICIPANT	\N	PRESENT	0
659291	659284	19575F	PARTICIPANT	\N	PRESENT	0
659292	659284	20138D	PARTICIPANT	\N	PRESENT	0
659293	659284	11043H	PARTICIPANT	\N	PRESENT	0
659294	659284	19349W	PARTICIPANT	\N	PRESENT	0
659295	659284	14179A	PARTICIPANT	\N	PRESENT	0
659373	659368	05008E	PARTICIPANT	\N	PRESENT	0
659374	659368	11033F	PARTICIPANT	\N	PRESENT	0
659375	659368	11053K	PARTICIPANT	\N	PRESENT	0
659376	659368	14357A	PARTICIPANT	\N	PRESENT	0
659377	659368	11070L	PARTICIPANT	\N	PRESENT	0
659378	659368	19719D	PARTICIPANT	\N	PRESENT	0
659379	659368	19673G	PARTICIPANT	\N	PRESENT	0
663732	661836	19820Y	PARTICIPANT	\N	PRESENT	0
659381	659368	19599P	PARTICIPANT	\N	PRESENT	0
659382	659368	14033T	PARTICIPANT	\N	PRESENT	0
663733	661836	20024T	PARTICIPANT	\N	PRESENT	0
659384	659368	14026U	PARTICIPANT	\N	PRESENT	0
659385	659368	11064N	PARTICIPANT	\N	PRESENT	0
663734	661836	19725B	PARTICIPANT	\N	PRESENT	0
659387	659368	14213J	PARTICIPANT	\N	PRESENT	0
659388	659368	19715Y	PARTICIPANT	\N	PRESENT	0
659389	659368	99004R	PARTICIPANT	\N	PRESENT	0
659390	659368	86034E	PARTICIPANT	\N	PRESENT	0
659391	659368	12041X	PARTICIPANT	\N	PRESENT	0
659392	659368	01043Q	PARTICIPANT	\N	PRESENT	0
659393	659368	14147R	PARTICIPANT	\N	PRESENT	0
663735	661836	19399H	PARTICIPANT	\N	PRESENT	0
659395	659368	11045K	PARTICIPANT	\N	PRESENT	0
659396	659368	01028R	PARTICIPANT	\N	PRESENT	0
659397	659368	19301E	PARTICIPANT	\N	PRESENT	0
663736	661836	19333N	PARTICIPANT	\N	PRESENT	0
663737	661836	20098N	PARTICIPANT	\N	PRESENT	0
663738	661836	20056C	PARTICIPANT	\N	PRESENT	0
663739	661836	14121F	PARTICIPANT	\N	PRESENT	0
663740	661836	19531S	PARTICIPANT	\N	PRESENT	0
663741	661836	19683J	PARTICIPANT	\N	PRESENT	0
663742	661836	19467C	PARTICIPANT	\N	PRESENT	0
663743	661836	20034V	PARTICIPANT	\N	PRESENT	0
663744	661836	14021P	PARTICIPANT	\N	PRESENT	0
663745	661836	19723Y	PARTICIPANT	\N	PRESENT	0
663746	661836	18193Q	PARTICIPANT	\N	PRESENT	0
663747	661836	08012N	PARTICIPANT	\N	PRESENT	0
663748	661836	20044X	PARTICIPANT	\N	PRESENT	0
663749	661836	14355X	PARTICIPANT	\N	PRESENT	0
663750	661836	19709B	PARTICIPANT	\N	PRESENT	0
663751	661836	08018U	PARTICIPANT	\N	PRESENT	0
663752	661836	07029T	PARTICIPANT	\N	PRESENT	0
663753	661836	19657G	PARTICIPANT	\N	PRESENT	0
663754	661836	11067R	PARTICIPANT	\N	PRESENT	0
663755	661836	19729F	PARTICIPANT	\N	PRESENT	0
663756	661836	08015R	PARTICIPANT	\N	PRESENT	0
663757	661836	19768N	PARTICIPANT	\N	PRESENT	0
663758	661836	14109K	PARTICIPANT	\N	PRESENT	0
663759	661836	19705W	PARTICIPANT	\N	PRESENT	0
663760	661836	19707Y	PARTICIPANT	\N	PRESENT	0
663761	661836	20062A	PARTICIPANT	\N	PRESENT	0
663762	661836	20030R	PARTICIPANT	\N	PRESENT	0
663763	661836	14059S	PARTICIPANT	\N	PRESENT	0
663764	661836	19663E	PARTICIPANT	\N	PRESENT	0
663765	661836	17965H	PARTICIPANT	\N	PRESENT	0
663766	661836	19503N	PARTICIPANT	\N	PRESENT	0
663781	661836	14221J	PARTICIPANT	\N	PRESENT	0
663768	661836	20126Y	PARTICIPANT	\N	PRESENT	0
663769	661836	20082E	PARTICIPANT	\N	PRESENT	0
663770	661836	14229S	PARTICIPANT	\N	PRESENT	0
663771	661836	11054L	PARTICIPANT	\N	PRESENT	0
663772	661836	19669L	PARTICIPANT	\N	PRESENT	0
663773	661836	19413M	PARTICIPANT	\N	PRESENT	0
663774	661836	20064C	PARTICIPANT	\N	PRESENT	0
663775	661836	19421M	PARTICIPANT	\N	PRESENT	0
663776	661836	04043D	PARTICIPANT	\N	PRESENT	0
663777	661836	11066Q	PARTICIPANT	\N	PRESENT	0
663784	661836	14179A	PARTICIPANT	\N	PRESENT	0
663779	661836	20054A	PARTICIPANT	\N	PRESENT	0
663780	661836	20124W	PARTICIPANT	\N	PRESENT	0
663782	661836	14147R	PARTICIPANT	\N	PRESENT	0
663783	661836	14249W	PARTICIPANT	\N	PRESENT	0
663785	661836	19569H	PARTICIPANT	\N	PRESENT	0
663786	661836	14219Q	PARTICIPANT	\N	PRESENT	0
663787	661836	04070G	PARTICIPANT	\N	PRESENT	0
663788	661836	19735D	PARTICIPANT	\N	PRESENT	0
663789	661836	14189C	PARTICIPANT	\N	PRESENT	0
663790	661836	14083S	PARTICIPANT	\N	PRESENT	0
663791	661836	11053K	PARTICIPANT	\N	PRESENT	0
663792	661836	14327T	PARTICIPANT	\N	PRESENT	0
663793	661836	17229F	PARTICIPANT	\N	PRESENT	0
663794	661836	14042U	PARTICIPANT	\N	PRESENT	0
663795	661836	20040T	PARTICIPANT	\N	PRESENT	0
663796	661836	19739H	PARTICIPANT	\N	PRESENT	0
663797	661836	19369B	PARTICIPANT	\N	PRESENT	0
663798	661836	20298U	PARTICIPANT	\N	PRESENT	0
663799	661836	19611R	PARTICIPANT	\N	PRESENT	0
663800	661836	19691J	PARTICIPANT	\N	PRESENT	0
663801	661836	01034P	PARTICIPANT	\N	PRESENT	0
663802	661836	19699S	PARTICIPANT	\N	PRESENT	0
663803	661836	19713W	PARTICIPANT	\N	PRESENT	0
663804	661836	19507S	PARTICIPANT	\N	PRESENT	0
663805	661836	19441R	PARTICIPANT	\N	PRESENT	0
663806	661836	16685X	PARTICIPANT	\N	PRESENT	0
663807	661836	14205J	PARTICIPANT	\N	PRESENT	0
663808	661836	20066E	PARTICIPANT	\N	PRESENT	0
663809	661836	19335Q	PARTICIPANT	\N	PRESENT	0
663810	661836	20086J	PARTICIPANT	\N	PRESENT	0
663811	661836	01043Q	PARTICIPANT	\N	PRESENT	0
663812	661836	20286Q	PARTICIPANT	\N	PRESENT	0
663813	661836	11077T	PARTICIPANT	\N	PRESENT	0
663814	661836	19760E	PARTICIPANT	\N	PRESENT	0
668135	668134	14151M	PARTICIPANT	\N	PRESENT	0
668136	668134	20022R	PARTICIPANT	\N	PRESENT	0
668137	668134	20114U	PARTICIPANT	\N	PRESENT	0
668141	668105	20072C	PARTICIPANT	\N	EXCUSE	0
680662	676609	04042C	PARTICIPANT	\N	PRESENT	0
680663	676609	20116W	PARTICIPANT	\N	PRESENT	0
680664	676609	14109K	PARTICIPANT	\N	PRESENT	0
680665	676609	19649G	PARTICIPANT	\N	PRESENT	0
680666	676609	19621T	PARTICIPANT	\N	PRESENT	0
680667	676609	19758L	PARTICIPANT	\N	PRESENT	0
680668	676610	11045K	PARTICIPANT	\N	PRESENT	0
680669	676610	07029T	PARTICIPANT	\N	PRESENT	0
680670	676610	19691J	PARTICIPANT	\N	PRESENT	0
680671	676610	19760E	PARTICIPANT	\N	PRESENT	0
680672	676610	20248J	PARTICIPANT	\N	PRESENT	0
680673	676610	19719D	PARTICIPANT	\N	PRESENT	0
680674	676610	20130U	PARTICIPANT	\N	PRESENT	0
680706	676610	20056C	PARTICIPANT	\N	PRESENT	0
680676	676610	19715Y	PARTICIPANT	\N	PRESENT	0
680677	676610	20050V	PARTICIPANT	\N	PRESENT	0
680678	676610	20044X	PARTICIPANT	\N	PRESENT	0
680679	676610	19593H	PARTICIPANT	\N	PRESENT	0
680680	676610	20124W	PARTICIPANT	\N	PRESENT	0
680681	676610	19699S	PARTICIPANT	\N	PRESENT	0
680682	676610	11048N	PARTICIPANT	\N	PRESENT	0
680683	676610	19611R	PARTICIPANT	\N	PRESENT	0
680684	676610	20252E	PARTICIPANT	\N	PRESENT	0
680685	676610	11074Q	PARTICIPANT	\N	PRESENT	0
680686	676610	19349W	PARTICIPANT	\N	PRESENT	0
680687	676610	19651A	PARTICIPANT	\N	PRESENT	0
680688	676610	19693L	PARTICIPANT	\N	PRESENT	0
680689	676610	14083S	PARTICIPANT	\N	PRESENT	0
680690	676610	11054L	PARTICIPANT	\N	PRESENT	0
680691	676610	20142Y	PARTICIPANT	\N	PRESENT	0
680692	676610	20108W	PARTICIPANT	\N	PRESENT	0
680693	676610	20084G	PARTICIPANT	\N	PRESENT	0
680694	676610	20132W	PARTICIPANT	\N	PRESENT	0
680695	676610	20134Y	PARTICIPANT	\N	PRESENT	0
680696	676610	20112S	PARTICIPANT	\N	PRESENT	0
680697	676610	04042C	PARTICIPANT	\N	PRESENT	0
680698	676610	20116W	PARTICIPANT	\N	PRESENT	0
680699	676610	19649G	PARTICIPANT	\N	PRESENT	0
680700	676610	19621T	PARTICIPANT	\N	PRESENT	0
680701	676610	19758L	PARTICIPANT	\N	PRESENT	0
680702	676610	14109K	PARTICIPANT	\N	PRESENT	0
680703	676610	14229S	PARTICIPANT	\N	PRESENT	0
680704	676610	19735D	PARTICIPANT	\N	PRESENT	0
680705	676610	20048C	PARTICIPANT	\N	PRESENT	0
680707	676610	19749K	PARTICIPANT	\N	PRESENT	0
680708	676610	14253S	PARTICIPANT	\N	PRESENT	0
680709	676610	20026V	PARTICIPANT	\N	PRESENT	0
680710	676610	20914V	PARTICIPANT	\N	PRESENT	0
680711	676610	19533U	PARTICIPANT	\N	PRESENT	0
680712	676610	99004R	PARTICIPANT	\N	PRESENT	0
680713	676610	19643A	PARTICIPANT	\N	PRESENT	0
680714	676610	19637C	PARTICIPANT	\N	PRESENT	0
680715	676610	17023S	PARTICIPANT	\N	PRESENT	0
680716	676610	11064N	PARTICIPANT	\N	PRESENT	0
680717	676610	11097X	PARTICIPANT	\N	PRESENT	0
680718	676610	19399H	PARTICIPANT	\N	PRESENT	0
680719	676610	19647E	PARTICIPANT	\N	PRESENT	0
680720	676610	98022P	PARTICIPANT	\N	PRESENT	0
680721	676610	04035D	PARTICIPANT	\N	PRESENT	0
680722	676610	04059M	PARTICIPANT	\N	PRESENT	0
680723	676611	11045K	PARTICIPANT	\N	PRESENT	0
680724	676611	07029T	PARTICIPANT	\N	PRESENT	0
680725	676611	19715Y	PARTICIPANT	\N	PRESENT	0
680726	676611	20050V	PARTICIPANT	\N	PRESENT	0
680727	676611	19593H	PARTICIPANT	\N	PRESENT	0
680728	676611	20124W	PARTICIPANT	\N	PRESENT	0
680729	676611	19699S	PARTICIPANT	\N	PRESENT	0
680730	676611	19611R	PARTICIPANT	\N	PRESENT	0
680731	676611	11074Q	PARTICIPANT	\N	PRESENT	0
680732	676611	19349W	PARTICIPANT	\N	PRESENT	0
680733	676611	19651A	PARTICIPANT	\N	PRESENT	0
680734	676611	19693L	PARTICIPANT	\N	PRESENT	0
680735	676611	14083S	PARTICIPANT	\N	PRESENT	0
680736	676611	20142Y	PARTICIPANT	\N	PRESENT	0
680737	676611	20084G	PARTICIPANT	\N	PRESENT	0
680738	676611	20132W	PARTICIPANT	\N	PRESENT	0
680739	676611	20134Y	PARTICIPANT	\N	PRESENT	0
680740	676611	20112S	PARTICIPANT	\N	PRESENT	0
680741	676611	20116W	PARTICIPANT	\N	PRESENT	0
680742	676611	19621T	PARTICIPANT	\N	PRESENT	0
680743	676611	19758L	PARTICIPANT	\N	PRESENT	0
680744	676611	14109K	PARTICIPANT	\N	PRESENT	0
680745	676611	14229S	PARTICIPANT	\N	PRESENT	0
680746	676611	19735D	PARTICIPANT	\N	PRESENT	0
680747	676611	20056C	PARTICIPANT	\N	PRESENT	0
680748	676611	14253S	PARTICIPANT	\N	PRESENT	0
680749	676611	20026V	PARTICIPANT	\N	PRESENT	0
680750	676611	20914V	PARTICIPANT	\N	PRESENT	0
680751	676611	19533U	PARTICIPANT	\N	PRESENT	0
680752	676611	19643A	PARTICIPANT	\N	PRESENT	0
680753	676611	11064N	PARTICIPANT	\N	PRESENT	0
680754	676611	11097X	PARTICIPANT	\N	PRESENT	0
680755	676611	19399H	PARTICIPANT	\N	PRESENT	0
680756	676611	19647E	PARTICIPANT	\N	PRESENT	0
680757	676611	98022P	PARTICIPANT	\N	PRESENT	0
680758	676611	04035D	PARTICIPANT	\N	PRESENT	0
680759	676611	04059M	PARTICIPANT	\N	PRESENT	0
680760	676611	99004R	PARTICIPANT	\N	PRESENT	0
680761	676611	19760E	PARTICIPANT	\N	PRESENT	0
680762	676611	20264J	PARTICIPANT	\N	PRESENT	0
680763	676611	11083R	PARTICIPANT	\N	PRESENT	0
680764	676611	20070A	PARTICIPANT	\N	PRESENT	0
680765	676611	08010L	PARTICIPANT	\N	PRESENT	0
680767	676611	20048C	PARTICIPANT	\N	PRESENT	0
680768	676611	20152B	PARTICIPANT	\N	PRESENT	0
680769	676611	19637C	PARTICIPANT	\N	PRESENT	0
680770	676611	19479G	PARTICIPANT	\N	PRESENT	0
680771	676611	19369B	PARTICIPANT	\N	PRESENT	0
680772	676611	14221J	PARTICIPANT	\N	PRESENT	0
680773	676611	20030R	PARTICIPANT	\N	PRESENT	0
680774	676611	11090Q	PARTICIPANT	\N	PRESENT	0
680775	676611	14331P	PARTICIPANT	\N	PRESENT	0
680776	676611	19553Y	PARTICIPANT	\N	PRESENT	0
680777	676611	20054A	PARTICIPANT	\N	PRESENT	0
680778	676611	14021P	PARTICIPANT	\N	PRESENT	0
680779	676611	20034V	PARTICIPANT	\N	PRESENT	0
680780	676611	17023S	PARTICIPANT	\N	PRESENT	0
680781	676611	14111D	PARTICIPANT	\N	PRESENT	0
680782	676611	14030Q	PARTICIPANT	\N	PRESENT	0
680826	676612	11045K	PARTICIPANT	\N	PRESENT	0
680827	676612	20050V	PARTICIPANT	\N	PRESENT	0
680828	676612	14331P	PARTICIPANT	\N	PRESENT	0
680829	676612	19369B	PARTICIPANT	\N	PRESENT	0
680830	676612	19637C	PARTICIPANT	\N	PRESENT	0
680831	676612	19693L	PARTICIPANT	\N	PRESENT	0
680832	676612	19533U	PARTICIPANT	\N	PRESENT	0
680833	676612	20132W	PARTICIPANT	\N	PRESENT	0
680834	676612	19621T	PARTICIPANT	\N	PRESENT	0
680835	676612	14221J	PARTICIPANT	\N	PRESENT	0
680836	676612	20142Y	PARTICIPANT	\N	PRESENT	0
680837	676612	19651A	PARTICIPANT	\N	PRESENT	0
680838	676612	20264J	PARTICIPANT	\N	PRESENT	0
680839	676612	19593H	PARTICIPANT	\N	PRESENT	0
680840	676612	20048C	PARTICIPANT	\N	PRESENT	0
680841	676612	14123H	PARTICIPANT	\N	PRESENT	0
680842	676612	20066E	PARTICIPANT	\N	PRESENT	0
680843	676612	14030Q	PARTICIPANT	\N	PRESENT	0
680844	676612	19735D	PARTICIPANT	\N	PRESENT	0
680845	676612	14219Q	PARTICIPANT	\N	PRESENT	0
680846	676612	19758L	PARTICIPANT	\N	PRESENT	0
680847	676612	20082E	PARTICIPANT	\N	PRESENT	0
680848	676612	14229S	PARTICIPANT	\N	PRESENT	0
680849	676612	19349W	PARTICIPANT	\N	PRESENT	0
680850	676612	20134Y	PARTICIPANT	\N	PRESENT	0
680851	676612	19611R	PARTICIPANT	\N	PRESENT	0
680852	676612	20054A	PARTICIPANT	\N	PRESENT	0
680853	676612	08010L	PARTICIPANT	\N	PRESENT	0
680854	676612	19553Y	PARTICIPANT	\N	PRESENT	0
680855	676612	19569H	PARTICIPANT	\N	PRESENT	0
680856	676612	14073Q	PARTICIPANT	\N	PRESENT	0
680857	676612	20140W	PARTICIPANT	\N	PRESENT	0
680858	676612	11097X	PARTICIPANT	\N	PRESENT	0
680859	676612	20112S	PARTICIPANT	\N	PRESENT	0
680860	676612	19760E	PARTICIPANT	\N	PRESENT	0
680861	676612	19715Y	PARTICIPANT	\N	PRESENT	0
680862	676612	14042U	PARTICIPANT	\N	PRESENT	0
680863	676612	20124W	PARTICIPANT	\N	PRESENT	0
655447	655446	11056N	PARTICIPANT	\N	PRESENT	0
655448	655446	19703U	PARTICIPANT	\N	PRESENT	0
655450	655449	19703U	PARTICIPANT	\N	PRESENT	0
655451	655449	95063L	PARTICIPANT	\N	PRESENT	0
655452	655449	11056N	PARTICIPANT	\N	PRESENT	0
655454	655453	11056N	PARTICIPANT	\N	PRESENT	0
655456	655455	11056N	PARTICIPANT	\N	PRESENT	0
655457	655455	19954N	PARTICIPANT	\N	PRESENT	0
655459	655458	11056N	PARTICIPANT	\N	PRESENT	0
655583	655496	08028W	PARTICIPANT	\N	EXCUSE	0
655584	655496	20144B	PARTICIPANT	\N	EXCUSE	0
655585	655496	14207L	PARTICIPANT	\N	EXCUSE	0
655586	655496	20034V	PARTICIPANT	\N	PRESENT	0
655587	655465	19631V	PARTICIPANT	\N	PRESENT	0
655588	655465	19515S	PARTICIPANT	\N	PRESENT	0
655589	655465	19575F	PARTICIPANT	\N	PRESENT	0
655590	655465	19747H	PARTICIPANT	\N	PRESENT	0
655591	655465	19782L	PARTICIPANT	\N	PRESENT	0
655592	655465	14038Y	PARTICIPANT	\N	PRESENT	0
655593	655465	14033T	PARTICIPANT	\N	PRESENT	0
655594	655465	20286Q	PARTICIPANT	\N	PRESENT	0
655595	655465	20034V	PARTICIPANT	\N	PRESENT	0
655596	655465	14037X	PARTICIPANT	\N	PRESENT	0
655597	655465	01043Q	PARTICIPANT	\N	PRESENT	0
655598	655465	14205J	PARTICIPANT	\N	PRESENT	0
655599	655465	19563B	PARTICIPANT	\N	PRESENT	0
655600	655465	20018V	PARTICIPANT	\N	PRESENT	0
655601	655465	19369B	PARTICIPANT	\N	PRESENT	0
655602	655465	14257W	PARTICIPANT	\N	PRESENT	0
655603	655465	19768N	PARTICIPANT	\N	PRESENT	0
655604	655465	11090Q	PARTICIPANT	\N	PRESENT	0
655605	655465	20082E	PARTICIPANT	\N	PRESENT	0
655606	655465	19705W	PARTICIPANT	\N	PRESENT	0
655607	655465	20298U	PARTICIPANT	\N	PRESENT	0
655608	655465	20092G	PARTICIPANT	\N	PRESENT	0
655609	655465	04045F	PARTICIPANT	\N	PRESENT	0
655610	655465	20062A	PARTICIPANT	\N	PRESENT	0
655646	655497	08028W	PARTICIPANT	\N	EXCUSE	0
655647	655497	14207L	PARTICIPANT	\N	EXCUSE	0
655648	655497	20144B	PARTICIPANT	\N	EXCUSE	0
655649	655496	05008E	PARTICIPANT	\N	PRESENT	0
655650	655496	20022R	PARTICIPANT	\N	PRESENT	0
655651	655496	20110Q	PARTICIPANT	\N	PRESENT	0
655652	655496	11033F	PARTICIPANT	\N	PRESENT	0
655653	655496	20114U	PARTICIPANT	\N	PRESENT	0
655654	655496	04047H	PARTICIPANT	\N	PRESENT	0
655655	655496	19629C	PARTICIPANT	\N	PRESENT	0
655656	655496	11056N	PARTICIPANT	\N	PRESENT	0
655657	655496	14215L	PARTICIPANT	\N	PRESENT	0
655658	655496	20074E	PARTICIPANT	\N	PRESENT	0
655659	655496	14151M	PARTICIPANT	\N	PRESENT	0
655660	655496	07004J	PARTICIPANT	\N	PRESENT	0
655661	655496	19447X	PARTICIPANT	\N	PRESENT	0
655662	655496	14021P	PARTICIPANT	\N	PRESENT	0
655663	655496	19649G	PARTICIPANT	\N	PRESENT	0
655664	655496	11026G	PARTICIPANT	\N	PRESENT	0
655665	655496	14147R	PARTICIPANT	\N	PRESENT	0
655666	655496	95063L	PARTICIPANT	\N	PRESENT	0
655667	655496	01028R	PARTICIPANT	\N	PRESENT	0
655668	655465	17737W	PARTICIPANT	\N	PRESENT	0
655669	655465	14089Y	PARTICIPANT	\N	PRESENT	0
655670	655465	19954N	PARTICIPANT	\N	PRESENT	0
656205	656157	20018V	PARTICIPANT	\N	EXCUSE	0
661819	661818	19693L	PARTICIPANT	\N	PRESENT	0
661820	661818	19593H	PARTICIPANT	\N	PRESENT	0
661821	661818	20132W	PARTICIPANT	\N	PRESENT	0
662849	661833	20140W	PARTICIPANT	\N	PRESENT	0
662850	661833	19399H	PARTICIPANT	\N	PRESENT	0
662851	661833	19657G	PARTICIPANT	\N	PRESENT	0
662852	661833	07029T	PARTICIPANT	\N	PRESENT	0
662853	661833	20034V	PARTICIPANT	\N	PRESENT	0
662854	661833	19663E	PARTICIPANT	\N	PRESENT	0
662855	661833	20044X	PARTICIPANT	\N	PRESENT	0
662856	661833	19447X	PARTICIPANT	\N	PRESENT	0
662857	661833	19467C	PARTICIPANT	\N	PRESENT	0
662858	661833	20056C	PARTICIPANT	\N	PRESENT	0
662859	661833	20026V	PARTICIPANT	\N	PRESENT	0
662860	661833	20180F	PARTICIPANT	\N	PRESENT	0
662861	661833	19515S	PARTICIPANT	\N	PRESENT	0
662862	661833	14191V	PARTICIPANT	\N	PRESENT	0
662863	661833	19723Y	PARTICIPANT	\N	PRESENT	0
662864	661833	14038Y	PARTICIPANT	\N	PRESENT	0
662865	661833	19693L	PARTICIPANT	\N	PRESENT	0
662866	661833	14021P	PARTICIPANT	\N	PRESENT	0
662867	661833	14042U	PARTICIPANT	\N	PRESENT	0
662868	661833	19715Y	PARTICIPANT	\N	PRESENT	0
662869	661833	08012N	PARTICIPANT	\N	PRESENT	0
662870	661833	95063L	PARTICIPANT	\N	PRESENT	0
662871	661833	20036X	PARTICIPANT	\N	PRESENT	0
662872	661833	20142Y	PARTICIPANT	\N	PRESENT	0
662873	661833	07033P	PARTICIPANT	\N	PRESENT	0
662876	661833	19479G	PARTICIPANT	\N	PRESENT	0
662877	661833	19719D	PARTICIPANT	\N	PRESENT	0
662878	661833	20048C	PARTICIPANT	\N	PRESENT	0
662879	661833	20040T	PARTICIPANT	\N	PRESENT	0
662880	661833	19679N	PARTICIPANT	\N	PRESENT	0
662881	661833	20100N	PARTICIPANT	\N	PRESENT	0
662882	661833	19741B	PARTICIPANT	\N	PRESENT	0
662883	661833	20138D	PARTICIPANT	\N	PRESENT	0
662884	661833	14259Y	PARTICIPANT	\N	PRESENT	0
662885	661833	19798U	PARTICIPANT	\N	PRESENT	0
662886	661833	14217N	PARTICIPANT	\N	PRESENT	0
662887	661833	14133K	PARTICIPANT	\N	PRESENT	0
662888	661833	08069G	PARTICIPANT	\N	PRESENT	0
662889	661833	07004J	PARTICIPANT	\N	PRESENT	0
662890	661833	14151M	PARTICIPANT	\N	PRESENT	0
662891	661833	14355X	PARTICIPANT	\N	PRESENT	0
662892	661833	20076G	PARTICIPANT	\N	PRESENT	0
662893	661833	20054A	PARTICIPANT	\N	PRESENT	0
662894	661833	20024T	PARTICIPANT	\N	PRESENT	0
662895	661833	20052X	PARTICIPANT	\N	PRESENT	0
662896	661833	11027H	PARTICIPANT	\N	PRESENT	0
662897	661833	01028R	PARTICIPANT	\N	PRESENT	0
662907	661833	20098N	PARTICIPANT	\N	PRESENT	0
662909	661833	19782L	PARTICIPANT	\N	PRESENT	0
662910	661833	20088L	PARTICIPANT	\N	PRESENT	0
662911	661833	20042V	PARTICIPANT	\N	PRESENT	0
662912	661833	14147R	PARTICIPANT	\N	PRESENT	0
662913	661833	19631V	PARTICIPANT	\N	PRESENT	0
662914	661833	01057W	PARTICIPANT	\N	PRESENT	0
662915	661833	19413M	PARTICIPANT	\N	PRESENT	0
662918	661833	17779H	PARTICIPANT	\N	PRESENT	0
662919	661833	19251M	PARTICIPANT	\N	PRESENT	0
662920	661833	19735D	PARTICIPANT	\N	PRESENT	0
662921	661833	19441R	PARTICIPANT	\N	PRESENT	0
662922	661833	14109K	PARTICIPANT	\N	PRESENT	0
662923	661833	19349W	PARTICIPANT	\N	PRESENT	0
662924	661833	99004R	PARTICIPANT	\N	PRESENT	0
662925	661833	14215L	PARTICIPANT	\N	PRESENT	0
662926	661833	20092G	PARTICIPANT	\N	PRESENT	0
662927	661833	19565D	PARTICIPANT	\N	PRESENT	0
662928	661833	14033T	PARTICIPANT	\N	PRESENT	0
662929	661833	19507S	PARTICIPANT	\N	PRESENT	0
662938	661833	19669L	PARTICIPANT	\N	PRESENT	0
662939	661833	19725B	PARTICIPANT	\N	PRESENT	0
662940	661833	20028X	PARTICIPANT	\N	PRESENT	0
662941	661833	20072C	PARTICIPANT	\N	PRESENT	0
662942	661833	97011G	PARTICIPANT	\N	PRESENT	0
662943	661833	19762G	PARTICIPANT	\N	PRESENT	0
662944	661833	01058X	PARTICIPANT	\N	PRESENT	0
662945	661833	19347U	PARTICIPANT	\N	PRESENT	0
682736	681087	20104S	PARTICIPANT	\N	EXCUSE	0
682737	681087	19866P	PARTICIPANT	\N	EXCUSE	0
682738	681087	19333N	PARTICIPANT	\N	PRESENT	0
682739	681087	11090Q	PARTICIPANT	\N	EXCUSE	0
682740	676619	14026U	PARTICIPANT	\N	PRESENT	0
682741	676619	14069U	PARTICIPANT	\N	PRESENT	0
682742	676619	14257W	PARTICIPANT	\N	PRESENT	0
682743	676619	08034U	PARTICIPANT	\N	PRESENT	0
682744	676619	14031R	PARTICIPANT	\N	PRESENT	0
682745	676619	04043D	PARTICIPANT	\N	PRESENT	0
682746	676619	14033T	PARTICIPANT	\N	PRESENT	0
682748	682747	19507S	PARTICIPANT	\N	PRESENT	0
682749	676619	20070A	PARTICIPANT	\N	PRESENT	0
682750	676619	14083S	PARTICIPANT	\N	PRESENT	0
682751	676619	10015M	PARTICIPANT	\N	PRESENT	0
682752	676619	14073Q	PARTICIPANT	\N	PRESENT	0
682753	676619	11072N	PARTICIPANT	\N	PRESENT	0
682754	676619	19467C	PARTICIPANT	\N	PRESENT	0
682755	676619	20116W	PARTICIPANT	\N	PRESENT	0
682756	676619	20092G	PARTICIPANT	\N	PRESENT	0
682757	676619	20022R	PARTICIPANT	\N	PRESENT	0
682758	676619	14187A	PARTICIPANT	\N	PRESENT	0
682759	676619	14053L	PARTICIPANT	\N	PRESENT	0
682760	676619	14179A	PARTICIPANT	\N	PRESENT	0
682761	679201	19643A	PARTICIPANT	\N	PRESENT	0
682762	679201	20132W	PARTICIPANT	\N	PRESENT	0
682763	679201	04033B	PARTICIPANT	\N	PRESENT	0
682764	679201	20180F	PARTICIPANT	\N	PRESENT	0
682765	679201	04059M	PARTICIPANT	\N	PRESENT	0
682766	676619	20032T	PARTICIPANT	\N	PRESENT	0
682767	676619	14123H	PARTICIPANT	\N	PRESENT	0
682769	676619	19741B	PARTICIPANT	\N	PRESENT	0
682770	676619	19782L	PARTICIPANT	\N	PRESENT	0
682771	682768	14026U	PARTICIPANT	\N	PRESENT	0
682772	682768	11067R	PARTICIPANT	\N	PRESENT	0
682828	676620	19629C	PARTICIPANT	\N	PRESENT	0
682829	676620	11072N	PARTICIPANT	\N	PRESENT	0
682830	676620	11026G	PARTICIPANT	\N	PRESENT	0
682831	676620	20080C	PARTICIPANT	\N	PRESENT	0
682832	676620	20070A	PARTICIPANT	\N	PRESENT	0
682833	676620	19599P	PARTICIPANT	\N	PRESENT	0
682834	676620	04085P	PARTICIPANT	\N	PRESENT	0
682835	676620	20046A	PARTICIPANT	\N	PRESENT	0
682836	676620	20102Q	PARTICIPANT	\N	PRESENT	0
682837	676620	10015M	PARTICIPANT	\N	PRESENT	0
682838	676620	20064C	PARTICIPANT	\N	PRESENT	0
682839	676620	20110Q	PARTICIPANT	\N	PRESENT	0
682840	676620	11043H	PARTICIPANT	\N	PRESENT	0
682841	676620	20078J	PARTICIPANT	\N	PRESENT	0
682842	676620	14031R	PARTICIPANT	\N	PRESENT	0
682843	676620	19741B	PARTICIPANT	\N	PRESENT	0
682844	676620	01028R	PARTICIPANT	\N	PRESENT	0
682845	676620	20092G	PARTICIPANT	\N	PRESENT	0
682846	676620	20032T	PARTICIPANT	\N	PRESENT	0
682847	676620	14083S	PARTICIPANT	\N	PRESENT	0
682848	676620	04043D	PARTICIPANT	\N	PRESENT	0
682849	676620	07004J	PARTICIPANT	\N	PRESENT	0
682850	676620	14187A	PARTICIPANT	\N	PRESENT	0
682851	676620	19671E	PARTICIPANT	\N	PRESENT	0
682852	676620	14055N	PARTICIPANT	\N	PRESENT	0
682853	676620	19673G	PARTICIPANT	\N	PRESENT	0
682854	676620	20116W	PARTICIPANT	\N	PRESENT	0
682855	676620	20036X	PARTICIPANT	\N	PRESENT	0
682856	676620	14255U	PARTICIPANT	\N	PRESENT	0
682857	676620	11053K	PARTICIPANT	\N	PRESENT	0
682858	676620	19583F	PARTICIPANT	\N	PRESENT	0
682859	674946	20146D	PARTICIPANT	\N	EXCUSE	0
682860	676620	19745F	PARTICIPANT	\N	PRESENT	0
682861	676620	11012A	PARTICIPANT	\N	PRESENT	0
682862	676620	20298U	PARTICIPANT	\N	PRESENT	0
682863	676620	14189C	PARTICIPANT	\N	PRESENT	0
682864	676620	12041X	PARTICIPANT	\N	PRESENT	0
682868	682867	19768N	PARTICIPANT	\N	PRESENT	0
682869	682867	14037X	PARTICIPANT	\N	PRESENT	0
682870	682867	19515S	PARTICIPANT	\N	PRESENT	0
682871	682867	20078J	PARTICIPANT	\N	PRESENT	0
682903	682866	11012A	PARTICIPANT	\N	PRESENT	0
682904	682866	14069U	PARTICIPANT	\N	PRESENT	0
682905	682866	19583F	PARTICIPANT	\N	PRESENT	0
682906	682866	20092G	PARTICIPANT	\N	PRESENT	0
682907	682866	11072N	PARTICIPANT	\N	PRESENT	0
682908	682866	20080C	PARTICIPANT	\N	PRESENT	0
682909	682866	20036X	PARTICIPANT	\N	PRESENT	0
682910	682866	19745F	PARTICIPANT	\N	PRESENT	0
682914	682866	10015M	PARTICIPANT	\N	PRESENT	0
682915	682866	14083S	PARTICIPANT	\N	PRESENT	0
682916	682866	20078J	PARTICIPANT	\N	PRESENT	0
682917	682866	04085P	PARTICIPANT	\N	PRESENT	0
682826	676620	99004R	PARTICIPANT	\N	PRESENT	0
682827	676620	14225N	PARTICIPANT	\N	PRESENT	0
682918	682866	20116W	PARTICIPANT	\N	PRESENT	0
682919	682866	20064C	PARTICIPANT	\N	PRESENT	0
682920	682866	14189C	PARTICIPANT	\N	PRESENT	0
682921	682866	14225N	PARTICIPANT	\N	PRESENT	0
682922	682866	08034U	PARTICIPANT	\N	PRESENT	0
682923	682866	20110Q	PARTICIPANT	\N	PRESENT	0
682924	682866	01028R	PARTICIPANT	\N	PRESENT	0
682926	682866	19741B	PARTICIPANT	\N	PRESENT	0
682931	682866	19593H	PARTICIPANT	\N	PRESENT	0
682932	682866	04047H	PARTICIPANT	\N	PRESENT	0
682933	682866	11026G	PARTICIPANT	\N	PRESENT	0
682934	682866	19659J	PARTICIPANT	\N	PRESENT	0
682935	682866	19387D	PARTICIPANT	\N	PRESENT	0
682936	682866	14219Q	PARTICIPANT	\N	PRESENT	0
682937	682866	14030Q	PARTICIPANT	\N	PRESENT	0
682938	682866	19711U	PARTICIPANT	\N	PRESENT	0
682939	682866	19747H	PARTICIPANT	\N	PRESENT	0
682901	682866	11045K	PARTICIPANT	\N	PRESENT	0
682902	682866	19319Q	PARTICIPANT	\N	PRESENT	0
682940	682866	19347U	PARTICIPANT	\N	PRESENT	0
682941	682866	19599P	PARTICIPANT	\N	PRESENT	0
682942	682866	07004J	PARTICIPANT	\N	PRESENT	0
682943	682866	19762G	PARTICIPANT	\N	PRESENT	0
682945	682866	19611R	PARTICIPANT	\N	PRESENT	0
682946	682866	14255U	PARTICIPANT	\N	PRESENT	0
682947	682866	20070A	PARTICIPANT	\N	PRESENT	0
682948	682866	11053K	PARTICIPANT	\N	PRESENT	0
682949	682866	20028X	PARTICIPANT	\N	PRESENT	0
682950	682866	20150Y	PARTICIPANT	\N	PRESENT	0
682951	682866	19631V	PARTICIPANT	\N	PRESENT	0
682952	682866	20084G	PARTICIPANT	\N	PRESENT	0
682954	682953	04047H	PARTICIPANT	\N	PRESENT	0
682955	682953	01028R	PARTICIPANT	\N	PRESENT	0
682956	682953	20110Q	PARTICIPANT	\N	PRESENT	0
682957	682953	14231L	PARTICIPANT	\N	PRESENT	0
682958	682953	14259Y	PARTICIPANT	\N	PRESENT	0
682959	682866	20148F	PARTICIPANT	\N	PRESENT	0
682960	682866	19577H	PARTICIPANT	\N	PRESENT	0
682961	682866	19657G	PARTICIPANT	\N	PRESENT	0
682963	682866	19467C	PARTICIPANT	\N	PRESENT	0
682964	682962	12028B	PARTICIPANT	\N	EXCUSE	0
683006	676621	11045K	PARTICIPANT	\N	PRESENT	0
683007	676621	04085P	PARTICIPANT	\N	PRESENT	0
683008	676621	11072N	PARTICIPANT	\N	PRESENT	0
683009	676621	11012A	PARTICIPANT	\N	PRESENT	0
683013	676621	19631V	PARTICIPANT	\N	PRESENT	0
683011	676621	20084G	PARTICIPANT	\N	PRESENT	0
683012	676621	19599P	PARTICIPANT	\N	PRESENT	0
683014	676621	20070A	PARTICIPANT	\N	PRESENT	0
683015	676621	20092G	PARTICIPANT	\N	PRESENT	0
683016	676621	20036X	PARTICIPANT	\N	PRESENT	0
683017	676621	19347U	PARTICIPANT	\N	PRESENT	0
683018	676621	19659J	PARTICIPANT	\N	PRESENT	0
683019	676621	19583F	PARTICIPANT	\N	PRESENT	0
683020	676621	19717B	PARTICIPANT	\N	PRESENT	0
683021	676621	19319Q	PARTICIPANT	\N	PRESENT	0
683022	676621	19745F	PARTICIPANT	\N	PRESENT	0
683023	676621	14030Q	PARTICIPANT	\N	PRESENT	0
683024	676621	14083S	PARTICIPANT	\N	PRESENT	0
683030	676621	08034U	PARTICIPANT	\N	PRESENT	0
683026	676621	19715Y	PARTICIPANT	\N	PRESENT	0
683027	676621	19577H	PARTICIPANT	\N	PRESENT	0
683028	676621	19747H	PARTICIPANT	\N	PRESENT	0
683029	676621	19762G	PARTICIPANT	\N	PRESENT	0
683031	676621	20032T	PARTICIPANT	\N	PRESENT	0
683032	676621	20148F	PARTICIPANT	\N	PRESENT	0
683033	676621	19657G	PARTICIPANT	\N	PRESENT	0
683034	676621	19467C	PARTICIPANT	\N	PRESENT	0
683035	676621	20034V	PARTICIPANT	\N	PRESENT	0
683036	676621	05008E	PARTICIPANT	\N	PRESENT	0
683037	676621	19301E	PARTICIPANT	\N	PRESENT	0
655495	655492	11066Q	PARTICIPANT	\N	PRESENT	0
656273	656272	19507S	PARTICIPANT	\N	PRESENT	0
656274	656272	19441R	PARTICIPANT	\N	PRESENT	0
656275	656272	20028X	PARTICIPANT	\N	PRESENT	0
656276	656157	20144B	PARTICIPANT	\N	EXCUSE	0
656303	656160	19760E	PARTICIPANT	\N	PRESENT	0
656304	656160	19367Y	PARTICIPANT	\N	EXCUSE	0
656305	656160	19553Y	PARTICIPANT	\N	EXCUSE	0
656306	656160	04057K	PARTICIPANT	\N	EXCUSE	0
656420	655742	11109J	PARTICIPANT	\N	EXCUSE	0
656421	655742	14109K	PARTICIPANT	\N	EXCUSE	0
656422	655742	19735D	PARTICIPANT	\N	EXCUSE	0
656423	655742	19593H	PARTICIPANT	\N	EXCUSE	0
659141	656929	20098N	PARTICIPANT	\N	EXCUSE	0
659142	656929	19621T	PARTICIPANT	\N	PRESENT	0
659149	658793	14231L	PRESIDENT	0	PRESENT	0
659150	658793	20058E	PARTICIPANT	\N	PRESENT	0
659151	658793	14107H	PARTICIPANT	\N	PRESENT	0
659152	658793	20070A	PARTICIPANT	\N	PRESENT	0
659153	658793	20062A	PARTICIPANT	\N	PRESENT	0
659203	658793	14205J	PARTICIPANT	\N	PRESENT	0
659204	658793	19782L	PARTICIPANT	\N	PRESENT	0
659205	658793	14257W	PARTICIPANT	\N	PRESENT	0
659206	658793	14173T	PARTICIPANT	\N	PRESENT	0
659207	658793	04045F	PARTICIPANT	\N	PRESENT	0
659208	658793	20090E	PARTICIPANT	\N	PRESENT	0
659209	658793	19735D	PARTICIPANT	\N	PRESENT	0
659210	658793	19758L	PARTICIPANT	\N	PRESENT	0
659211	658793	01057W	PARTICIPANT	\N	PRESENT	0
659212	658793	05012A	PARTICIPANT	\N	PRESENT	0
659213	658793	14327T	PARTICIPANT	\N	PRESENT	0
659214	658793	19349W	PARTICIPANT	\N	PRESENT	0
659215	658793	19573D	PARTICIPANT	\N	PRESENT	0
659216	658793	20084G	PARTICIPANT	\N	PRESENT	0
659217	658793	14187A	PARTICIPANT	\N	PRESENT	0
659218	658793	14229S	PARTICIPANT	\N	PRESENT	0
659219	658793	08010L	PARTICIPANT	\N	PRESENT	0
659220	658793	17637T	PARTICIPANT	\N	PRESENT	0
659221	658793	20022R	PARTICIPANT	\N	EXCUSE	0
659222	658793	14069U	PARTICIPANT	\N	EXCUSE	0
659223	658793	14215L	PARTICIPANT	\N	EXCUSE	0
659224	658793	20120S	PARTICIPANT	\N	EXCUSE	0
659225	658793	19820Y	PARTICIPANT	\N	EXCUSE	0
659226	658793	19565D	PARTICIPANT	\N	EXCUSE	0
659227	658793	19333N	PARTICIPANT	\N	EXCUSE	0
659228	658793	19447X	PARTICIPANT	\N	EXCUSE	0
659229	658793	14071N	PARTICIPANT	\N	EXCUSE	0
659230	659058	19760E	PARTICIPANT	\N	EXCUSE	0
659231	659058	14030Q	PARTICIPANT	\N	EXCUSE	0
659232	659058	14105F	PARTICIPANT	\N	EXCUSE	0
659233	659058	19545Y	PARTICIPANT	\N	EXCUSE	0
659234	659058	14329V	PARTICIPANT	\N	EXCUSE	0
659235	659058	08028W	PARTICIPANT	\N	EXCUSE	0
659236	659058	19467C	PARTICIPANT	\N	EXCUSE	0
659237	659058	20048C	PARTICIPANT	\N	EXCUSE	0
659238	659058	08015R	PARTICIPANT	\N	EXCUSE	0
659239	659058	14031R	PARTICIPANT	\N	EXCUSE	0
659240	659058	19671E	PARTICIPANT	\N	EXCUSE	0
659241	659058	20082E	PARTICIPANT	\N	EXCUSE	0
659247	655445	19577H	PARTICIPANT	\N	PRESENT	0
659654	659653	11048N	PARTICIPANT	\N	PRESENT	1
659655	659653	19711U	PARTICIPANT	\N	PRESENT	1
659673	659672	14225N	PARTICIPANT	\N	PRESENT	0
659674	659672	19335Q	PARTICIPANT	\N	PRESENT	0
659675	659672	20044X	PARTICIPANT	\N	PRESENT	0
661806	661804	19611R	PARTICIPANT	\N	PRESENT	0
661807	661804	08012N	PARTICIPANT	\N	PRESENT	0
661809	661557	19717B	PARTICIPANT	\N	PRESENT	0
661810	661557	20034V	PARTICIPANT	\N	PRESENT	0
661811	661557	14059S	PARTICIPANT	\N	PRESENT	0
661812	661557	12016W	PARTICIPANT	\N	EXCUSE	0
661813	661557	19657G	PARTICIPANT	\N	PRESENT	0
661814	661557	14147R	PARTICIPANT	\N	EXCUSE	0
661815	661557	14331P	PARTICIPANT	\N	EXCUSE	0
661827	661826	19719D	PARTICIPANT	\N	PRESENT	0
661828	661825	11104D	PARTICIPANT	\N	PRESENT	0
661829	661825	19527W	PARTICIPANT	\N	PRESENT	0
661830	661825	20058E	PARTICIPANT	\N	PRESENT	0
661831	661824	11104D	PARTICIPANT	\N	PRESENT	0
661832	657983	11109J	PARTICIPANT	\N	EXCUSE	0
663815	661836	20046A	PARTICIPANT	\N	PRESENT	0
663816	661836	19651A	PARTICIPANT	\N	PRESENT	0
663817	661836	08073C	PARTICIPANT	\N	PRESENT	0
663818	661836	14055N	PARTICIPANT	\N	PRESENT	0
663819	661836	20266L	PARTICIPANT	\N	PRESENT	0
663820	661836	11099A	PARTICIPANT	\N	PRESENT	0
663821	661836	19631V	PARTICIPANT	\N	PRESENT	0
663822	661836	12016W	PARTICIPANT	\N	PRESENT	0
663823	661836	20094J	PARTICIPANT	\N	PRESENT	0
663824	661836	19347U	PARTICIPANT	\N	PRESENT	0
663825	661836	20132W	PARTICIPANT	\N	PRESENT	0
663826	661836	19649G	PARTICIPANT	\N	PRESENT	0
663827	661836	11074Q	PARTICIPANT	\N	PRESENT	0
663828	661836	19599P	PARTICIPANT	\N	PRESENT	0
663829	661836	14257W	PARTICIPANT	\N	PRESENT	0
663830	661836	20122U	PARTICIPANT	\N	PRESENT	0
663831	661836	19685L	PARTICIPANT	\N	PRESENT	0
663832	661836	11085T	PARTICIPANT	\N	PRESENT	0
663833	661836	19826F	PARTICIPANT	\N	PRESENT	0
663855	661836	20112S	PARTICIPANT	\N	PRESENT	0
663835	661836	08009T	PARTICIPANT	\N	PRESENT	0
663837	661836	19749K	PARTICIPANT	\N	PRESENT	0
663848	661836	97011G	PARTICIPANT	\N	PRESENT	0
663849	661836	20252E	PARTICIPANT	\N	PRESENT	0
663851	661836	11026G	PARTICIPANT	\N	PRESENT	0
663852	661836	20042V	PARTICIPANT	\N	PRESENT	0
663853	661836	19717B	PARTICIPANT	\N	PRESENT	0
663854	661836	19443T	PARTICIPANT	\N	PRESENT	0
663856	661836	14151M	PARTICIPANT	\N	PRESENT	0
663865	661836	14097Y	PARTICIPANT	\N	PRESENT	0
663866	661836	20048C	PARTICIPANT	\N	PRESENT	0
663867	661836	11056N	PARTICIPANT	\N	PRESENT	0
664152	661837	14053L	PARTICIPANT	\N	PRESENT	0
664153	661837	14026U	PARTICIPANT	\N	PRESENT	0
664154	661837	20266L	PARTICIPANT	\N	PRESENT	0
664155	661837	14055N	PARTICIPANT	\N	PRESENT	0
664156	661837	19717B	PARTICIPANT	\N	PRESENT	0
664157	661837	19447X	PARTICIPANT	\N	PRESENT	0
664158	661837	20122U	PARTICIPANT	\N	PRESENT	0
664159	661837	19347U	PARTICIPANT	\N	PRESENT	0
664160	661837	11031D	PARTICIPANT	\N	PRESENT	0
664161	661837	18193Q	PARTICIPANT	\N	PRESENT	0
664162	661837	20080C	PARTICIPANT	\N	PRESENT	0
664163	661837	95063L	PARTICIPANT	\N	PRESENT	0
664164	661837	19866P	PARTICIPANT	\N	PRESENT	0
664165	661837	20072C	PARTICIPANT	\N	PRESENT	0
664166	661837	11045K	PARTICIPANT	\N	PRESENT	0
664167	661837	19565D	PARTICIPANT	\N	PRESENT	0
664168	661837	11033F	PARTICIPANT	\N	PRESENT	0
664169	661837	20130U	PARTICIPANT	\N	PRESENT	0
664170	661837	11065P	PARTICIPANT	\N	PRESENT	0
664171	661837	19649G	PARTICIPANT	\N	PRESENT	0
664172	661837	14179A	PARTICIPANT	\N	PRESENT	0
664173	661837	19479G	PARTICIPANT	\N	PRESENT	0
664174	661837	19826F	PARTICIPANT	\N	PRESENT	0
664175	661837	20062A	PARTICIPANT	\N	PRESENT	0
664176	661837	14147R	PARTICIPANT	\N	PRESENT	0
664177	661837	07029T	PARTICIPANT	\N	PRESENT	0
664178	659562	19333N	PARTICIPANT	\N	PRESENT	0
664179	659562	20136B	PARTICIPANT	\N	PRESENT	0
664180	659562	19820Y	PARTICIPANT	\N	PRESENT	0
664181	659562	14219Q	PARTICIPANT	\N	PRESENT	0
664182	659562	19599P	PARTICIPANT	\N	PRESENT	0
664183	659562	19637C	PARTICIPANT	\N	PRESENT	0
664184	659562	18083K	PARTICIPANT	\N	PRESENT	0
664185	659562	08060W	PARTICIPANT	\N	PRESENT	0
664186	659562	20118Y	PARTICIPANT	\N	PRESENT	0
664187	659562	11101A	PARTICIPANT	\N	PRESENT	0
664188	659562	19503N	PARTICIPANT	\N	PRESENT	0
664189	659562	20024T	PARTICIPANT	\N	PRESENT	0
664190	659562	19525U	PARTICIPANT	\N	PRESENT	0
664191	661837	12016W	PARTICIPANT	\N	PRESENT	0
664192	661837	14001X	PARTICIPANT	\N	PRESENT	0
664193	661837	14021P	PARTICIPANT	\N	PRESENT	0
664194	661837	19527W	PARTICIPANT	\N	PRESENT	0
664195	661837	04059M	PARTICIPANT	\N	PRESENT	0
664197	661837	20110Q	PARTICIPANT	\N	PRESENT	0
664198	661837	20036X	PARTICIPANT	\N	PRESENT	0
664201	661837	20914V	PARTICIPANT	\N	PRESENT	0
664202	661837	20100N	PARTICIPANT	\N	PRESENT	0
680866	676612	20034V	PARTICIPANT	\N	PRESENT	0
680867	676612	19573D	PARTICIPANT	\N	PRESENT	0
680868	676612	19647E	PARTICIPANT	\N	PRESENT	0
680869	676612	14083S	PARTICIPANT	\N	PRESENT	0
680870	676612	11065P	PARTICIPANT	\N	PRESENT	0
680864	676612	20026V	PARTICIPANT	\N	PRESENT	0
680865	676612	20056C	PARTICIPANT	\N	PRESENT	0
680871	676612	20298U	PARTICIPANT	\N	PRESENT	0
680872	676612	20114U	PARTICIPANT	\N	PRESENT	0
680873	676612	20030R	PARTICIPANT	\N	PRESENT	0
680874	676612	20070A	PARTICIPANT	\N	PRESENT	0
680875	676612	07029T	PARTICIPANT	\N	PRESENT	0
681748	679538	08034U	PARTICIPANT	\N	PRESENT	0
681749	679178	10015M	PARTICIPANT	\N	PRESENT	0
681754	669288	20068G	PARTICIPANT	\N	PRESENT	0
681755	669288	19387D	PARTICIPANT	\N	PRESENT	0
681756	669288	17229F	PARTICIPANT	\N	PRESENT	0
681761	679538	04071H	PARTICIPANT	\N	PRESENT	0
681762	679538	19479G	PARTICIPANT	\N	PRESENT	0
681765	679538	14083S	PARTICIPANT	\N	PRESENT	0
681766	679178	14147R	PARTICIPANT	\N	PRESENT	0
680885	678420	19703U	PARTICIPANT	\N	PRESENT	0
680886	678420	14355X	PARTICIPANT	\N	PRESENT	0
680887	678420	20066E	PARTICIPANT	\N	PRESENT	0
680888	678420	11097X	PARTICIPANT	\N	PRESENT	0
680889	678420	20040T	PARTICIPANT	\N	PRESENT	0
680890	678420	14042U	PARTICIPANT	\N	PRESENT	0
680891	678420	14213J	PARTICIPANT	\N	PRESENT	0
680892	678420	14071N	PARTICIPANT	\N	PRESENT	0
680893	678420	14217N	PARTICIPANT	\N	PRESENT	0
680894	678420	10006L	PRESIDENT	0	PRESENT	0
681767	679538	20070A	PARTICIPANT	\N	PRESENT	0
680896	678420	20130U	PARTICIPANT	\N	PRESENT	0
680897	678420	19553Y	PARTICIPANT	\N	PRESENT	0
680898	678420	14195A	PARTICIPANT	\N	PRESENT	0
680899	678420	11031D	PARTICIPANT	\N	EXCUSE	0
680900	678420	04057K	PARTICIPANT	\N	EXCUSE	0
680901	678420	04092N	PARTICIPANT	\N	EXCUSE	0
680902	678420	19798U	PARTICIPANT	\N	EXCUSE	0
680903	678420	19367Y	PARTICIPANT	\N	EXCUSE	0
680904	678420	19295A	PARTICIPANT	\N	EXCUSE	0
681768	679178	01028R	PARTICIPANT	\N	PRESENT	0
681786	669288	20038A	PARTICIPANT	\N	PRESENT	0
681787	669288	19599P	PARTICIPANT	\N	PRESENT	0
681919	676617	14001X	PARTICIPANT	\N	PRESENT	0
681920	676617	20110Q	PARTICIPANT	\N	PRESENT	0
681921	676617	19585H	PARTICIPANT	\N	PRESENT	0
680911	678420	19697Q	PARTICIPANT	\N	PRESENT	0
680912	678420	19691J	PARTICIPANT	\N	PRESENT	0
680913	678420	19723Y	PARTICIPANT	\N	PRESENT	0
680914	678420	20248J	PARTICIPANT	\N	PRESENT	0
680915	678420	14223L	PARTICIPANT	\N	PRESENT	0
681938	676617	20032T	PARTICIPANT	\N	PRESENT	0
681708	681083	19383Y	PARTICIPANT	\N	PRESENT	0
681709	681083	19768N	PARTICIPANT	\N	PRESENT	0
681710	681083	19515S	PARTICIPANT	\N	PRESENT	0
681711	681083	20092G	PARTICIPANT	\N	PRESENT	0
681712	681083	19782L	PARTICIPANT	\N	PRESENT	0
681713	681083	11077T	PARTICIPANT	\N	PRESENT	0
681714	681083	20078J	PARTICIPANT	\N	PRESENT	0
681715	681083	19441R	PARTICIPANT	\N	PRESENT	0
681716	681083	19413M	PARTICIPANT	\N	PRESENT	0
681717	681083	20082E	PARTICIPANT	\N	PRESENT	0
681718	681083	04045F	PARTICIPANT	\N	PRESENT	0
681719	681083	19631V	PARTICIPANT	\N	PRESENT	0
681720	681083	19705W	PARTICIPANT	\N	PRESENT	0
681721	681083	19707Y	PARTICIPANT	\N	PRESENT	0
681722	681083	08015R	PARTICIPANT	\N	PRESENT	0
681723	681083	19575F	PARTICIPANT	\N	PRESENT	0
681724	681083	08028W	PARTICIPANT	\N	PRESENT	0
681725	681083	19563B	PARTICIPANT	\N	PRESENT	0
681726	681083	14037X	PARTICIPANT	\N	PRESENT	0
681727	681083	14038Y	PARTICIPANT	\N	PRESENT	0
681728	681083	20030R	PARTICIPANT	\N	PRESENT	0
681729	681083	19467C	PARTICIPANT	\N	PRESENT	0
681730	681083	20034V	PARTICIPANT	\N	PRESENT	0
681731	681083	14187A	PARTICIPANT	\N	PRESENT	0
681732	681083	20144B	PARTICIPANT	\N	PRESENT	0
681733	681083	19695N	PARTICIPANT	\N	PRESENT	0
681734	681083	11090Q	PRESIDENT	0	PRESENT	0
681735	681083	01025N	PARTICIPANT	\N	PRESENT	0
681736	681083	14033T	PARTICIPANT	\N	PRESENT	0
681737	681083	20054A	PARTICIPANT	\N	PRESENT	0
681738	681083	14205J	PARTICIPANT	\N	PRESENT	0
681739	681083	20062A	PARTICIPANT	\N	PRESENT	0
681740	681083	14251Q	PARTICIPANT	\N	PRESENT	0
681741	681083	19507S	PARTICIPANT	\N	PRESENT	0
681742	681083	20286Q	PARTICIPANT	\N	PRESENT	0
681743	681083	20298U	PARTICIPANT	\N	PRESENT	0
681744	681083	19747H	PARTICIPANT	\N	PRESENT	0
681745	681083	14207L	PARTICIPANT	\N	PRESENT	0
681746	681083	14257W	PARTICIPANT	\N	PRESENT	0
681747	679538	11070L	PARTICIPANT	\N	PRESENT	0
681923	676617	14231L	PARTICIPANT	\N	PRESENT	0
681924	676617	19681G	PARTICIPANT	\N	PRESENT	0
681925	676617	14191V	PARTICIPANT	\N	PRESENT	0
681926	676617	11012A	PARTICIPANT	\N	PRESENT	0
681927	676617	19954N	PARTICIPANT	\N	PRESENT	0
681928	676617	20080C	PARTICIPANT	\N	PRESENT	0
681929	676617	19349W	PARTICIPANT	\N	PRESENT	0
681930	676617	19399H	PARTICIPANT	\N	PRESENT	0
681931	676617	19651A	PARTICIPANT	\N	PRESENT	0
681932	676617	07029T	PARTICIPANT	\N	PRESENT	0
681933	676617	19649G	PARTICIPANT	\N	PRESENT	0
681934	676617	11056N	PARTICIPANT	\N	PRESENT	0
681935	676617	20024T	PARTICIPANT	\N	PRESENT	0
681936	676617	20068G	PARTICIPANT	\N	PRESENT	0
681937	676617	20116W	PARTICIPANT	\N	PRESENT	0
681939	676617	08009T	PARTICIPANT	\N	PRESENT	0
681940	676617	20022R	PARTICIPANT	\N	PRESENT	0
681941	676617	04070G	PARTICIPANT	\N	PRESENT	0
681942	676617	14069U	PARTICIPANT	\N	PRESENT	0
681943	676617	14215L	PARTICIPANT	\N	PRESENT	0
681944	676617	14107H	PARTICIPANT	\N	PRESENT	0
681945	676617	20076G	PARTICIPANT	\N	PRESENT	0
681946	676617	19543W	PARTICIPANT	\N	PRESENT	0
681947	676617	04047H	PARTICIPANT	\N	PRESENT	0
681948	676617	11074Q	PARTICIPANT	\N	PRESENT	0
681949	676617	20108W	PARTICIPANT	\N	PRESENT	0
681951	676617	19758L	PARTICIPANT	\N	PRESENT	0
681953	676617	14327T	PARTICIPANT	\N	PRESENT	0
681954	676617	14055N	PARTICIPANT	\N	PRESENT	0
681955	676617	20044X	PARTICIPANT	\N	PRESENT	0
681956	676617	19735D	PARTICIPANT	\N	PRESENT	0
681957	676617	20120S	PARTICIPANT	\N	PRESENT	0
681958	676617	14173T	PARTICIPANT	\N	PRESENT	0
681959	676617	20140W	PARTICIPANT	\N	PRESENT	0
681960	676617	05012A	PARTICIPANT	\N	PRESENT	0
681961	676617	20074E	PARTICIPANT	\N	PRESENT	0
681962	676617	19725B	PARTICIPANT	\N	PRESENT	0
681966	676617	07004J	PARTICIPANT	\N	PRESENT	0
681964	676617	14147R	PARTICIPANT	\N	PRESENT	0
681965	676617	20070A	PARTICIPANT	\N	PRESENT	0
681967	676617	19693L	PARTICIPANT	\N	PRESENT	0
681968	676617	19621T	PARTICIPANT	\N	PRESENT	0
681969	676617	19762G	PARTICIPANT	\N	PRESENT	0
681970	676617	19629C	PARTICIPANT	\N	PRESENT	0
681971	676617	08034U	PARTICIPANT	\N	PRESENT	0
681972	676617	19673G	PARTICIPANT	\N	PRESENT	0
681973	676617	14083S	PARTICIPANT	\N	PRESENT	0
681974	676617	19335Q	PARTICIPANT	\N	PRESENT	0
681975	676617	19545Y	PARTICIPANT	\N	PRESENT	0
681976	676617	10015M	PARTICIPANT	\N	PRESENT	0
681977	676617	14121F	PARTICIPANT	\N	PRESENT	0
681978	676617	20172F	PARTICIPANT	\N	PRESENT	0
681979	676617	19741B	PARTICIPANT	\N	PRESENT	0
681980	676617	19489J	PARTICIPANT	\N	PRESENT	0
681981	676617	20914V	PARTICIPANT	\N	PRESENT	0
681982	676617	95063L	PARTICIPANT	\N	PRESENT	0
681983	676617	20252E	PARTICIPANT	\N	PRESENT	0
681984	676617	14021P	PARTICIPANT	\N	PRESENT	0
681985	676617	20038A	PARTICIPANT	\N	PRESENT	0
681986	676617	19251M	PARTICIPANT	\N	PRESENT	0
681988	676617	01028R	PARTICIPANT	\N	PRESENT	0
681989	676617	19647E	PARTICIPANT	\N	PRESENT	0
681990	676617	14189C	PARTICIPANT	\N	PRESENT	0
681991	676617	20046A	PARTICIPANT	\N	PRESENT	0
681992	679492	95041E	PARTICIPANT	\N	PRESENT	0
681993	679492	11064N	PARTICIPANT	\N	PRESENT	0
681994	676617	20102Q	PARTICIPANT	\N	PRESENT	0
682060	681083	14357A	PARTICIPANT	\N	PRESENT	0
656246	656245	19563B	PARTICIPANT	\N	PRESENT	0
656247	656245	14207L	PARTICIPANT	\N	PRESENT	0
656248	656245	08028W	PARTICIPANT	\N	PRESENT	0
656249	656245	20092G	PARTICIPANT	\N	PRESENT	0
656251	656250	19563B	PARTICIPANT	\N	PRESENT	0
656252	656250	14207L	PARTICIPANT	\N	PRESENT	0
656253	656250	08028W	PARTICIPANT	\N	PRESENT	0
656254	656250	20092G	PARTICIPANT	\N	PRESENT	0
656255	656250	20018V	PARTICIPANT	\N	PRESENT	0
656257	656256	19563B	PARTICIPANT	\N	PRESENT	0
656258	656256	08028W	PARTICIPANT	\N	PRESENT	0
656259	656256	20018V	PARTICIPANT	\N	PRESENT	0
656261	656260	19563B	PARTICIPANT	\N	PRESENT	0
656262	656260	14207L	PARTICIPANT	\N	PRESENT	0
656263	656260	14357A	PARTICIPANT	\N	PRESENT	0
656360	656358	19563B	PARTICIPANT	\N	PRESENT	0
656362	656358	20018V	PARTICIPANT	\N	PRESENT	0
656363	656358	20092G	PARTICIPANT	\N	PRESENT	0
656368	656367	19563B	PARTICIPANT	\N	PRESENT	0
656381	656370	19563B	PARTICIPANT	\N	PRESENT	0
656382	656370	19782L	PARTICIPANT	\N	PRESENT	0
656384	656370	19467C	PARTICIPANT	\N	PRESENT	0
656386	656370	20018V	PARTICIPANT	\N	PRESENT	0
656388	656370	20092G	PARTICIPANT	\N	PRESENT	0
656389	656370	20062A	PARTICIPANT	\N	PRESENT	0
656560	656559	14053L	PARTICIPANT	\N	PRESENT	0
656575	656574	14053L	PARTICIPANT	\N	PRESENT	0
656576	656574	14147R	PARTICIPANT	\N	PRESENT	0
656577	656574	11033F	PARTICIPANT	\N	PRESENT	0
656668	656157	01028R	PARTICIPANT	\N	EXCUSE	0
657614	656880	14042U	PARTICIPANT	\N	PRESENT	0
659073	659070	01048V	PARTICIPANT	\N	PRESENT	0
659074	659070	19533U	PARTICIPANT	\N	PRESENT	0
659075	659070	19503N	PARTICIPANT	\N	PRESENT	0
659439	659438	14031R	PARTICIPANT	\N	PRESENT	0
659440	659438	19637C	PARTICIPANT	\N	PRESENT	0
659442	659441	14031R	PARTICIPANT	\N	PRESENT	0
659443	659441	19637C	PARTICIPANT	\N	PRESENT	0
659445	659444	14031R	PARTICIPANT	\N	PRESENT	0
659446	659444	14169X	PARTICIPANT	\N	PRESENT	0
659448	659447	14031R	PARTICIPANT	\N	PRESENT	0
659449	659447	19637C	PARTICIPANT	\N	PRESENT	0
659450	659447	20096L	PARTICIPANT	\N	PRESENT	0
659452	659451	14031R	PARTICIPANT	\N	PRESENT	0
659454	659453	14031R	PARTICIPANT	\N	PRESENT	0
659455	659453	20106U	PARTICIPANT	\N	PRESENT	0
659456	659453	19599P	PARTICIPANT	\N	PRESENT	0
659457	659453	14169X	PARTICIPANT	\N	PRESENT	0
659459	659458	14031R	PARTICIPANT	\N	PRESENT	0
659460	659458	20106U	PARTICIPANT	\N	PRESENT	0
659461	659458	19599P	PARTICIPANT	\N	PRESENT	0
659462	659458	14169X	PARTICIPANT	\N	PRESENT	0
657639	657524	19383Y	PARTICIPANT	\N	PRESENT	0
657640	657524	20088L	PARTICIPANT	\N	PRESENT	0
657641	657524	19768N	PARTICIPANT	\N	PRESENT	0
657642	657524	19515S	PARTICIPANT	\N	PRESENT	0
657643	657524	19782L	PARTICIPANT	\N	PRESENT	0
657644	657524	20092G	PARTICIPANT	\N	PRESENT	0
657645	657524	19441R	PARTICIPANT	\N	PRESENT	0
657646	657524	20078J	PARTICIPANT	\N	PRESENT	0
657647	657524	20082E	PARTICIPANT	\N	PRESENT	0
657648	657524	20094J	PARTICIPANT	\N	PRESENT	0
657649	657524	19631V	PARTICIPANT	\N	PRESENT	0
657650	657524	08015R	PARTICIPANT	\N	PRESENT	0
657651	657524	19575F	PARTICIPANT	\N	PRESENT	0
657652	657524	19369B	PARTICIPANT	\N	PRESENT	0
657653	657524	20018V	PARTICIPANT	\N	PRESENT	0
657654	657524	19563B	PARTICIPANT	\N	PRESENT	0
657655	657524	08028W	PARTICIPANT	\N	PRESENT	0
657656	657524	20028X	PARTICIPANT	\N	PRESENT	0
657657	657524	14037X	PARTICIPANT	\N	PRESENT	0
657658	657524	20030R	PARTICIPANT	\N	PRESENT	0
657659	657524	19467C	PARTICIPANT	\N	PRESENT	0
657660	657524	20034V	PARTICIPANT	\N	PRESENT	0
657661	657524	14187A	PARTICIPANT	\N	PRESENT	0
657662	657524	19695N	PARTICIPANT	\N	PRESENT	0
657663	657524	01025N	PARTICIPANT	\N	PRESENT	0
657664	657524	14033T	PARTICIPANT	\N	PRESENT	0
657665	657524	11090Q	PRESIDENT	0	PRESENT	0
657666	657524	20054A	PARTICIPANT	\N	PRESENT	0
657667	657524	20062A	PARTICIPANT	\N	PRESENT	0
657668	657524	20286Q	PARTICIPANT	\N	PRESENT	0
657669	657524	19747H	PARTICIPANT	\N	PRESENT	0
657670	657524	14207L	PARTICIPANT	\N	PRESENT	0
657671	657524	14257W	PARTICIPANT	\N	PRESENT	0
657672	657524	14205J	PARTICIPANT	\N	PRESENT	0
659467	659463	14031R	PARTICIPANT	\N	PRESENT	0
659469	659463	14169X	PARTICIPANT	\N	PRESENT	0
659471	659463	19599P	PARTICIPANT	\N	PRESENT	0
659472	659463	19820Y	PARTICIPANT	\N	PRESENT	0
659477	659474	19599P	PARTICIPANT	\N	PRESENT	0
659475	659474	14031R	PARTICIPANT	\N	PRESENT	0
659476	659474	14169X	PARTICIPANT	\N	PRESENT	0
659478	659474	19820Y	PARTICIPANT	\N	PRESENT	0
659479	659474	11065P	PARTICIPANT	\N	PRESENT	0
659481	659480	14031R	PARTICIPANT	\N	PRESENT	0
659482	659480	14169X	PARTICIPANT	\N	PRESENT	0
659483	659480	19599P	PARTICIPANT	\N	PRESENT	0
659484	659480	19820Y	PARTICIPANT	\N	PRESENT	0
659486	659485	14031R	PARTICIPANT	\N	PRESENT	0
659487	659485	14169X	PARTICIPANT	\N	PRESENT	0
659488	659485	20106U	PARTICIPANT	\N	PRESENT	0
659489	659485	19820Y	PARTICIPANT	\N	PRESENT	0
659491	659490	14031R	PARTICIPANT	\N	PRESENT	0
659492	659490	19599P	PARTICIPANT	\N	PRESENT	0
659494	659493	14031R	PARTICIPANT	\N	PRESENT	0
659496	659495	14031R	PARTICIPANT	\N	PRESENT	0
659498	659497	14031R	PARTICIPANT	\N	PRESENT	0
659499	659497	20106U	PARTICIPANT	\N	PRESENT	0
659501	659500	14031R	PARTICIPANT	\N	PRESENT	0
659502	659500	20106U	PARTICIPANT	\N	PRESENT	0
659504	659503	14031R	PARTICIPANT	\N	PRESENT	0
659505	659503	20106U	PARTICIPANT	\N	PRESENT	0
659507	659506	14031R	PARTICIPANT	\N	PRESENT	0
659508	659506	20106U	PARTICIPANT	\N	PRESENT	0
659509	659506	20096L	PARTICIPANT	\N	PRESENT	0
659511	659510	14031R	PARTICIPANT	\N	PRESENT	0
659512	659510	20096L	PARTICIPANT	\N	PRESENT	0
659513	659510	14169X	PARTICIPANT	\N	PRESENT	0
659515	659514	14031R	PARTICIPANT	\N	PRESENT	0
659516	659514	20106U	PARTICIPANT	\N	PRESENT	0
659517	659514	19251M	PARTICIPANT	\N	PRESENT	0
659518	659514	20096L	PARTICIPANT	\N	PRESENT	0
659520	659519	14031R	PARTICIPANT	\N	PRESENT	0
659521	659519	20106U	PARTICIPANT	\N	PRESENT	0
659522	659519	20096L	PARTICIPANT	\N	PRESENT	0
659524	659523	14031R	PARTICIPANT	\N	PRESENT	0
659525	659523	20106U	PARTICIPANT	\N	PRESENT	0
659526	659523	20096L	PARTICIPANT	\N	PRESENT	0
659528	659527	14031R	PARTICIPANT	\N	PRESENT	0
659529	659527	20096L	PARTICIPANT	\N	PRESENT	0
659530	659527	19333N	PARTICIPANT	\N	PRESENT	0
659532	659531	14031R	PARTICIPANT	\N	PRESENT	0
659533	659531	20038A	PARTICIPANT	\N	PRESENT	0
659535	659534	14031R	PARTICIPANT	\N	PRESENT	0
659536	659534	20106U	PARTICIPANT	\N	PRESENT	0
659538	659537	14031R	PARTICIPANT	\N	PRESENT	0
659539	659537	20106U	PARTICIPANT	\N	PRESENT	0
659541	659540	14031R	PARTICIPANT	\N	PRESENT	0
659542	659540	14169X	PARTICIPANT	\N	PRESENT	0
659544	659543	14031R	PARTICIPANT	\N	PRESENT	0
659704	659166	20130U	PARTICIPANT	\N	PRESENT	0
659547	659546	14031R	PARTICIPANT	\N	PRESENT	0
659548	659543	19820Y	PARTICIPANT	\N	PRESENT	0
659703	659410	01043Q	PARTICIPANT	\N	PRESENT	0
659705	659166	19703U	PARTICIPANT	\N	PRESENT	0
659706	659166	20090E	PARTICIPANT	\N	PRESENT	0
659707	659166	11067R	PARTICIPANT	\N	PRESENT	0
659708	659166	11097X	PARTICIPANT	\N	PRESENT	0
659709	659166	14213J	PARTICIPANT	\N	PRESENT	0
659710	659166	14071N	PARTICIPANT	\N	PRESENT	0
659711	659166	14217N	PARTICIPANT	\N	PRESENT	0
659712	659166	18193Q	PARTICIPANT	\N	PRESENT	0
659713	659166	10006L	PRESIDENT	0	PRESENT	0
659714	659166	17779H	PARTICIPANT	\N	PRESENT	0
666059	665904	20124W	PARTICIPANT	\N	PRESENT	1
666061	666060	20124W	PARTICIPANT	\N	PRESENT	0
666062	666060	14109K	PARTICIPANT	\N	PRESENT	0
666063	663863	10006L	PRESIDENT	0	PRESENT	0
666064	663863	14042U	PARTICIPANT	\N	PRESENT	0
666065	663863	14195A	PARTICIPANT	\N	PRESENT	0
666066	663863	08045X	PARTICIPANT	\N	PRESENT	0
666067	663863	19697Q	PARTICIPANT	\N	PRESENT	0
666068	663863	19329S	PARTICIPANT	\N	PRESENT	0
666069	663863	20130U	PARTICIPANT	\N	PRESENT	0
666070	663863	19683J	PARTICIPANT	\N	PRESENT	0
666071	663863	17779H	PARTICIPANT	\N	PRESENT	0
666072	663863	19723Y	PARTICIPANT	\N	PRESENT	0
666073	663863	19679N	PARTICIPANT	\N	PRESENT	0
666074	663863	19553Y	PARTICIPANT	\N	PRESENT	0
666075	663863	20040T	PARTICIPANT	\N	PRESENT	0
666076	663863	14071N	PARTICIPANT	\N	PRESENT	0
666077	663863	20090E	PARTICIPANT	\N	PRESENT	0
666078	663863	14223L	PARTICIPANT	\N	PRESENT	0
666079	663863	19691J	PARTICIPANT	\N	PRESENT	0
666080	663863	19415P	PARTICIPANT	\N	PRESENT	0
666081	663863	19798U	PARTICIPANT	\N	PRESENT	0
666082	663863	19367Y	PARTICIPANT	\N	PRESENT	0
666083	663863	20248J	PARTICIPANT	\N	PRESENT	0
666084	663863	04092N	PARTICIPANT	\N	PRESENT	0
666085	663863	19511N	PARTICIPANT	\N	PRESENT	0
666086	663863	19703U	PARTICIPANT	\N	PRESENT	0
666087	663863	11067R	PARTICIPANT	\N	PRESENT	0
666088	663863	19715Y	PARTICIPANT	\N	EXCUSE	0
666089	663863	11097X	PARTICIPANT	\N	PRESENT	0
666093	663863	04057K	PARTICIPANT	\N	PRESENT	0
666094	663863	14026U	PARTICIPANT	\N	PRESENT	0
666134	663863	19569H	PARTICIPANT	\N	PRESENT	0
666135	663863	18193Q	PARTICIPANT	\N	PRESENT	0
666136	663863	04043D	PARTICIPANT	\N	PRESENT	0
666137	663863	14217N	PARTICIPANT	\N	PRESENT	0
666154	663863	19760E	PARTICIPANT	\N	PRESENT	0
666198	663863	20266L	PARTICIPANT	\N	PRESENT	0
666200	665705	19760E	PARTICIPANT	\N	PRESENT	0
666201	665705	19367Y	PARTICIPANT	\N	PRESENT	0
666202	665705	19415P	PARTICIPANT	\N	PRESENT	0
666203	665705	20090E	PARTICIPANT	\N	PRESENT	0
666204	665705	14195A	PARTICIPANT	\N	PRESENT	0
666205	665705	10006L	PRESIDENT	0	PRESENT	0
666206	665705	14217N	PARTICIPANT	\N	PRESENT	0
666207	665705	20248J	PARTICIPANT	\N	PRESENT	0
666208	665705	14042U	PARTICIPANT	\N	PRESENT	0
666209	665705	20040T	PARTICIPANT	\N	PRESENT	0
666210	665705	08045X	PARTICIPANT	\N	PRESENT	0
666211	665705	14026U	PARTICIPANT	\N	PRESENT	0
666212	665705	19691J	PARTICIPANT	\N	PRESENT	0
666213	665705	19553Y	PARTICIPANT	\N	PRESENT	0
666214	665705	19329S	PARTICIPANT	\N	PRESENT	0
666215	665705	19569H	PARTICIPANT	\N	PRESENT	0
666216	665705	19511N	PARTICIPANT	\N	PRESENT	0
666217	665705	19715Y	PARTICIPANT	\N	EXCUSE	0
666218	665705	19683J	PARTICIPANT	\N	PRESENT	0
666219	665705	19723Y	PARTICIPANT	\N	PRESENT	0
666220	665705	18193Q	PARTICIPANT	\N	PRESENT	0
666221	665705	19697Q	PARTICIPANT	\N	PRESENT	0
666222	665705	17779H	PARTICIPANT	\N	PRESENT	0
666223	665705	04057K	PARTICIPANT	\N	PRESENT	0
666224	665705	14223L	PARTICIPANT	\N	PRESENT	0
666225	665705	11067R	PARTICIPANT	\N	PRESENT	0
666226	665705	04092N	PARTICIPANT	\N	PRESENT	0
666227	665705	14071N	PARTICIPANT	\N	PRESENT	0
666228	665705	20130U	PARTICIPANT	\N	PRESENT	0
666229	665705	04043D	PARTICIPANT	\N	PRESENT	0
666230	665705	19679N	PARTICIPANT	\N	PRESENT	0
666231	665705	19798U	PARTICIPANT	\N	PRESENT	0
666232	665705	11097X	PARTICIPANT	\N	PRESENT	0
666233	665705	19703U	PARTICIPANT	\N	PRESENT	0
666234	665705	20266L	PARTICIPANT	\N	PRESENT	0
666235	665705	14213J	PARTICIPANT	\N	PRESENT	0
666236	663863	14213J	PARTICIPANT	\N	PRESENT	0
666334	665705	11031D	PARTICIPANT	\N	PRESENT	0
666337	663863	11031D	PARTICIPANT	\N	PRESENT	0
666339	663863	20066E	PARTICIPANT	\N	PRESENT	0
667613	665176	20040T	PARTICIPANT	\N	PRESENT	0
671137	669760	08060W	PARTICIPANT	\N	EXCUSE	0
671140	669760	19333N	PARTICIPANT	\N	PRESENT	0
671141	669760	17637T	PARTICIPANT	\N	PRESENT	0
671142	669760	11065P	PARTICIPANT	\N	PRESENT	0
671143	669760	19820Y	PARTICIPANT	\N	PRESENT	0
671224	671223	19507S	PARTICIPANT	\N	PRESENT	0
671225	671223	01025N	PARTICIPANT	\N	PRESENT	0
671226	671223	19413M	PARTICIPANT	\N	PRESENT	0
683041	676621	18083K	PARTICIPANT	\N	PRESENT	0
683042	676621	11043H	PARTICIPANT	\N	PRESENT	0
683043	676621	19741B	PARTICIPANT	\N	PRESENT	0
683044	676621	20150Y	PARTICIPANT	\N	PRESENT	0
683045	676621	20142Y	PARTICIPANT	\N	PRESENT	0
683046	676621	04057K	PARTICIPANT	\N	PRESENT	0
683047	676621	20040T	PARTICIPANT	\N	PRESENT	0
683048	676621	20086J	PARTICIPANT	\N	PRESENT	0
683049	676621	19593H	PARTICIPANT	\N	PRESENT	0
683050	676621	11026G	PARTICIPANT	\N	PRESENT	0
683051	676621	04047H	PARTICIPANT	\N	PRESENT	0
683038	676621	08073C	PARTICIPANT	\N	PRESENT	0
683039	676621	19295A	PARTICIPANT	\N	PRESENT	0
683040	676621	20180F	PARTICIPANT	\N	PRESENT	0
683052	676621	19533U	PARTICIPANT	\N	PRESENT	0
683053	676621	14253S	PARTICIPANT	\N	PRESENT	0
683054	676621	19573D	PARTICIPANT	\N	PRESENT	0
683058	676621	14225N	PARTICIPANT	\N	PRESENT	0
683059	676621	20100N	PARTICIPANT	\N	PRESENT	0
683060	676621	19758L	PARTICIPANT	\N	PRESENT	0
683061	676621	14026U	PARTICIPANT	\N	PRESENT	0
683063	683062	19673G	PARTICIPANT	\N	PRESENT	0
683064	683062	11083R	PARTICIPANT	\N	PRESENT	0
683065	676621	20264J	PARTICIPANT	\N	PRESENT	0
683066	676621	19057M	PARTICIPANT	\N	PRESENT	0
683067	676621	19621T	PARTICIPANT	\N	PRESENT	0
683068	676621	19673G	PARTICIPANT	\N	PRESENT	0
683069	676621	01048V	PARTICIPANT	\N	PRESENT	0
683070	676621	19387D	PARTICIPANT	\N	PRESENT	0
683071	676621	19719D	PARTICIPANT	\N	PRESENT	0
683072	676621	14109K	PARTICIPANT	\N	PRESENT	0
683116	676622	11045K	PARTICIPANT	\N	PRESENT	0
683117	676622	11012A	PARTICIPANT	\N	PRESENT	0
683118	676622	19719D	PARTICIPANT	\N	PRESENT	0
683119	676622	19387D	PARTICIPANT	\N	PRESENT	0
683120	676622	01048V	PARTICIPANT	\N	PRESENT	0
683121	676622	14225N	PARTICIPANT	\N	PRESENT	0
683122	676622	20142Y	PARTICIPANT	\N	PRESENT	0
683123	676622	20100N	PARTICIPANT	\N	PRESENT	0
683124	676622	19651A	PARTICIPANT	\N	PRESENT	0
683125	676622	19057M	PARTICIPANT	\N	PRESENT	0
683126	676622	14109K	PARTICIPANT	\N	PRESENT	0
683127	676622	14229S	PARTICIPANT	\N	PRESENT	0
683128	676622	20264J	PARTICIPANT	\N	PRESENT	0
683129	676622	19758L	PARTICIPANT	\N	PRESENT	0
683130	676622	19593H	PARTICIPANT	\N	PRESENT	0
683131	676622	19583F	PARTICIPANT	\N	PRESENT	0
683132	676622	14030Q	PARTICIPANT	\N	PRESENT	0
683133	676622	19533U	PARTICIPANT	\N	PRESENT	0
683134	676622	14026U	PARTICIPANT	\N	PRESENT	0
683135	676622	04047H	PARTICIPANT	\N	PRESENT	0
683136	676622	20032T	PARTICIPANT	\N	PRESENT	0
683137	676622	14123H	PARTICIPANT	\N	PRESENT	0
683138	676622	19573D	PARTICIPANT	\N	PRESENT	0
683139	676622	20180F	PARTICIPANT	\N	PRESENT	0
683140	676622	19621T	PARTICIPANT	\N	PRESENT	0
683141	676622	11048N	PARTICIPANT	\N	PRESENT	0
683142	676622	19631V	PARTICIPANT	\N	PRESENT	0
683143	676622	14187A	PARTICIPANT	\N	PRESENT	0
683144	676622	19643A	PARTICIPANT	\N	PRESENT	0
683145	676622	11043H	PARTICIPANT	\N	PRESENT	0
683146	676622	04057K	PARTICIPANT	\N	PRESENT	0
683147	676622	19673G	PARTICIPANT	\N	PRESENT	0
683148	676622	14083S	PARTICIPANT	\N	PRESENT	0
683150	676622	14069U	PARTICIPANT	\N	PRESENT	0
655286	655285	19711U	PARTICIPANT	\N	PRESENT	0
655287	655285	14001X	PARTICIPANT	\N	PRESENT	0
655288	655285	20100N	PARTICIPANT	\N	PRESENT	0
655290	655289	19711U	PARTICIPANT	\N	PRESENT	0
655291	655289	14001X	PARTICIPANT	\N	PRESENT	0
655292	655289	20100N	PARTICIPANT	\N	PRESENT	0
655294	655293	14001X	PARTICIPANT	\N	PRESENT	0
655295	655293	20100N	PARTICIPANT	\N	PRESENT	0
655296	655293	19711U	PARTICIPANT	\N	PRESENT	0
655298	655297	14026U	PARTICIPANT	\N	PRESENT	0
655299	655297	19725B	PARTICIPANT	\N	PRESENT	0
655301	655300	14026U	PARTICIPANT	\N	PRESENT	0
655302	655300	19725B	PARTICIPANT	\N	PRESENT	0
655304	655303	14026U	PARTICIPANT	\N	PRESENT	0
655305	655303	19725B	PARTICIPANT	\N	PRESENT	0
655307	655306	14026U	PARTICIPANT	\N	PRESENT	0
655308	655306	19725B	PARTICIPANT	\N	PRESENT	0
655310	655309	19725B	PARTICIPANT	\N	PRESENT	0
655311	655309	14026U	PARTICIPANT	\N	PRESENT	0
655313	655312	14026U	PARTICIPANT	\N	PRESENT	0
655314	655312	19725B	PARTICIPANT	\N	PRESENT	0
655316	655315	14026U	PARTICIPANT	\N	PRESENT	0
655317	655315	19725B	PARTICIPANT	\N	PRESENT	0
655319	655318	14026U	PARTICIPANT	\N	PRESENT	0
655320	655318	19725B	PARTICIPANT	\N	PRESENT	0
655322	655321	11083R	PARTICIPANT	\N	PRESENT	0
655324	655323	14237S	PARTICIPANT	\N	PRESENT	0
655325	655323	04070G	PARTICIPANT	\N	PRESENT	0
655326	655323	20094J	PARTICIPANT	\N	PRESENT	0
655328	655327	20094J	PARTICIPANT	\N	PRESENT	0
655329	655327	04070G	PARTICIPANT	\N	PRESENT	0
655331	655330	20094J	PARTICIPANT	\N	PRESENT	0
655332	655330	04070G	PARTICIPANT	\N	PRESENT	0
655334	655333	20094J	PARTICIPANT	\N	PRESENT	0
655335	655333	04070G	PARTICIPANT	\N	PRESENT	0
655337	655336	20094J	PARTICIPANT	\N	PRESENT	0
655338	655336	04070G	PARTICIPANT	\N	PRESENT	0
655340	655339	14331P	PARTICIPANT	\N	PRESENT	0
655341	655339	11083R	PARTICIPANT	\N	PRESENT	0
655342	655339	14205J	PARTICIPANT	\N	PRESENT	0
655344	655343	14331P	PARTICIPANT	\N	PRESENT	0
655345	655343	11083R	PARTICIPANT	\N	PRESENT	0
655346	655343	14205J	PARTICIPANT	\N	PRESENT	0
655348	655347	14331P	PARTICIPANT	\N	PRESENT	0
655349	655347	11083R	PARTICIPANT	\N	PRESENT	0
655350	655347	14205J	PARTICIPANT	\N	PRESENT	0
655352	655351	11083R	PARTICIPANT	\N	PRESENT	0
655353	655351	14205J	PARTICIPANT	\N	PRESENT	0
655355	655354	14331P	PARTICIPANT	\N	PRESENT	0
655357	655356	14205J	PARTICIPANT	\N	PRESENT	0
655359	655358	14205J	PARTICIPANT	\N	PRESENT	0
655361	655360	11083R	PARTICIPANT	\N	PRESENT	0
656284	656157	14038Y	PARTICIPANT	\N	EXCUSE	0
656357	656356	11056N	PARTICIPANT	\N	PRESENT	0
656361	656359	11056N	PARTICIPANT	\N	PRESENT	0
658819	655685	19651A	PARTICIPANT	\N	PRESENT	0
659200	659140	19735D	PARTICIPANT	\N	PRESENT	1
659201	659140	14109K	PARTICIPANT	\N	PRESENT	1
659202	659140	20124W	PARTICIPANT	\N	PRESENT	0
660420	659866	20062A	PARTICIPANT	\N	EXCUSE	0
663548	660362	20084G	PARTICIPANT	\N	EXCUSE	0
663550	660362	20132W	PARTICIPANT	\N	EXCUSE	0
664203	661837	11027H	PARTICIPANT	\N	PRESENT	0
664204	661837	17965H	PARTICIPANT	\N	PRESENT	0
664205	661837	99004R	PARTICIPANT	\N	PRESENT	0
664206	661837	19643A	PARTICIPANT	\N	PRESENT	0
664207	661837	20026V	PARTICIPANT	\N	PRESENT	0
664208	661837	20140W	PARTICIPANT	\N	PRESENT	0
664209	661837	20098N	PARTICIPANT	\N	PRESENT	0
664210	661837	20056C	PARTICIPANT	\N	PRESENT	0
664211	661837	19489J	PARTICIPANT	\N	PRESENT	0
664212	661837	20114U	PARTICIPANT	\N	PRESENT	0
664213	661837	20172F	PARTICIPANT	\N	PRESENT	0
664214	661837	19301E	PARTICIPANT	\N	PRESENT	0
664215	661837	19591F	PARTICIPANT	\N	PRESENT	0
664216	659562	19701S	PARTICIPANT	\N	PRESENT	0
664217	659562	20076G	PARTICIPANT	\N	PRESENT	0
664218	659562	19387D	PARTICIPANT	\N	PRESENT	0
664219	659562	19251M	PARTICIPANT	\N	PRESENT	0
664220	659562	20046A	PARTICIPANT	\N	PRESENT	0
664221	659562	20068G	PARTICIPANT	\N	PRESENT	0
664222	659562	20020P	PARTICIPANT	\N	PRESENT	0
664223	659562	19685L	PARTICIPANT	\N	PRESENT	0
664224	659562	20120S	PARTICIPANT	\N	PRESENT	0
664225	659562	19551W	PARTICIPANT	\N	EXCUSE	0
664226	659562	20038A	PARTICIPANT	\N	EXCUSE	0
664227	659562	19745F	PARTICIPANT	\N	EXCUSE	0
664228	661837	20134Y	PARTICIPANT	\N	PRESENT	0
664229	659562	20102Q	PARTICIPANT	\N	PRESENT	0
664230	659562	14031R	PARTICIPANT	\N	PRESENT	0
664231	659562	19619A	PARTICIPANT	\N	PRESENT	0
664232	661837	14109K	PARTICIPANT	\N	PRESENT	0
664233	661837	04085P	PARTICIPANT	\N	PRESENT	0
664234	661266	19697Q	PARTICIPANT	\N	PRESENT	0
664235	661266	11067R	PARTICIPANT	\N	PRESENT	0
664236	661266	20090E	PARTICIPANT	\N	PRESENT	0
664237	661266	14355X	PARTICIPANT	\N	PRESENT	0
664238	661266	19798U	PARTICIPANT	\N	PRESENT	0
664239	661266	19569H	PARTICIPANT	\N	PRESENT	0
664240	661266	11097X	PARTICIPANT	\N	PRESENT	0
664241	661266	19415P	PARTICIPANT	\N	PRESENT	0
664242	661266	17779H	PARTICIPANT	\N	PRESENT	0
664243	661266	19553Y	PARTICIPANT	\N	PRESENT	0
664244	661266	19703U	PARTICIPANT	\N	PRESENT	0
664245	661266	14281W	PARTICIPANT	\N	PRESENT	0
664246	661266	14042U	PARTICIPANT	\N	PRESENT	0
664247	661266	14195A	PARTICIPANT	\N	PRESENT	0
664248	661266	19367Y	PARTICIPANT	\N	PRESENT	0
664249	661266	14213J	PARTICIPANT	\N	PRESENT	0
664250	661266	19683J	PARTICIPANT	\N	PRESENT	0
664251	661266	10006L	PRESIDENT	0	PRESENT	0
664252	661266	04057K	PARTICIPANT	\N	PRESENT	0
664253	661266	04092N	PARTICIPANT	\N	PRESENT	0
664254	661266	19713W	PARTICIPANT	\N	PRESENT	0
664255	661266	19663E	PARTICIPANT	\N	PRESENT	0
664256	661266	19715Y	PARTICIPANT	\N	PRESENT	0
664257	661266	19691J	PARTICIPANT	\N	PRESENT	0
664258	661266	19723Y	PARTICIPANT	\N	PRESENT	0
664259	661266	20248J	PARTICIPANT	\N	PRESENT	0
664260	661266	20066E	PARTICIPANT	\N	PRESENT	0
664261	661266	20266L	PARTICIPANT	\N	PRESENT	0
664262	661266	04043D	PARTICIPANT	\N	PRESENT	0
664263	661266	19760E	PARTICIPANT	\N	PRESENT	0
664264	661266	08045X	PARTICIPANT	\N	EXCUSE	0
664265	661837	05008E	PARTICIPANT	\N	PRESENT	0
664266	661837	19647E	PARTICIPANT	\N	PRESENT	0
664267	661837	20142Y	PARTICIPANT	\N	PRESENT	0
664268	660365	19593H	PARTICIPANT	\N	PRESENT	0
664269	660365	19699S	PARTICIPANT	\N	PRESENT	0
664270	660365	14073Q	PARTICIPANT	\N	PRESENT	0
664271	660365	19533U	PARTICIPANT	\N	PRESENT	0
664272	660365	20138D	PARTICIPANT	\N	PRESENT	0
664273	660365	19611R	PRESIDENT	0	PRESENT	0
664274	660365	19693L	PARTICIPANT	\N	PRESENT	0
664275	660365	20052X	PARTICIPANT	\N	PRESENT	0
664276	660365	14229S	PARTICIPANT	\N	PRESENT	0
664277	660365	20058E	PARTICIPANT	\N	PRESENT	0
664278	660365	19573D	PARTICIPANT	\N	PRESENT	0
664279	660365	14123H	PARTICIPANT	\N	PRESENT	0
664280	660365	08012N	PARTICIPANT	\N	PRESENT	0
664281	660365	20124W	PARTICIPANT	\N	PRESENT	0
664282	660365	19621T	PARTICIPANT	\N	PRESENT	0
664283	661837	14059S	PARTICIPANT	\N	PRESENT	0
664284	661837	04047H	PARTICIPANT	\N	PRESENT	0
664286	661837	12028B	PARTICIPANT	\N	PRESENT	0
664287	661837	19683J	PARTICIPANT	\N	PRESENT	0
664292	659562	19549D	PARTICIPANT	\N	PRESENT	0
664293	659562	14221J	PARTICIPANT	\N	PRESENT	0
664294	659562	20106U	PARTICIPANT	\N	PRESENT	0
664295	659562	11065P	PARTICIPANT	\N	PRESENT	0
664296	659562	17229F	PARTICIPANT	\N	PRESENT	0
664297	661837	01058X	PARTICIPANT	\N	PRESENT	0
664301	661837	11064N	PARTICIPANT	\N	PRESENT	0
664302	661837	14073Q	PARTICIPANT	\N	PRESENT	0
664303	661837	10015M	PARTICIPANT	\N	PRESENT	0
664304	661837	08034U	PARTICIPANT	\N	PRESENT	0
664305	661837	20298U	PARTICIPANT	\N	PRESENT	0
664306	661837	20024T	PARTICIPANT	\N	PRESENT	0
664307	661837	20070A	PARTICIPANT	\N	PRESENT	0
664308	661837	19585H	PARTICIPANT	\N	PRESENT	0
664309	661837	14231L	PARTICIPANT	\N	PRESENT	0
664679	664678	19507S	PARTICIPANT	\N	PRESENT	0
664680	664678	19413M	PARTICIPANT	\N	PRESENT	0
682061	681083	11099A	PARTICIPANT	\N	PRESENT	0
682062	681083	20094J	PARTICIPANT	\N	PRESENT	0
682063	681083	20060X	PARTICIPANT	\N	PRESENT	0
682074	682073	20072C	PARTICIPANT	\N	EXCUSE	0
682076	682073	20066E	PARTICIPANT	\N	EXCUSE	0
682077	682073	01048V	PARTICIPANT	\N	EXCUSE	0
682089	682073	19503N	PARTICIPANT	\N	EXCUSE	0
682090	682073	19735D	PARTICIPANT	\N	EXCUSE	0
682091	682073	19723Y	PARTICIPANT	\N	PRESENT	0
682155	682107	19693L	PARTICIPANT	\N	PRESENT	0
682156	682107	14105F	PARTICIPANT	\N	PRESENT	0
682157	682107	14253S	PARTICIPANT	\N	PRESENT	0
682158	682107	07029T	PARTICIPANT	\N	PRESENT	0
682159	682107	14173T	PARTICIPANT	\N	PRESENT	0
682160	682107	20076G	PARTICIPANT	\N	PRESENT	0
682161	682107	99004R	PARTICIPANT	\N	PRESENT	0
682162	682107	20130U	PARTICIPANT	\N	PRESENT	0
682163	682107	04045F	PARTICIPANT	\N	PRESENT	0
682164	682107	19349W	PARTICIPANT	\N	PRESENT	0
682165	682107	11097X	PARTICIPANT	\N	PRESENT	0
682169	682107	20126Y	PARTICIPANT	\N	PRESENT	0
682167	682107	20020P	PARTICIPANT	\N	PRESENT	0
682168	682107	14001X	PARTICIPANT	\N	PRESENT	0
682170	682107	20084G	PARTICIPANT	\N	PRESENT	0
682171	682107	08015R	PARTICIPANT	\N	PRESENT	0
682172	682107	19583F	PARTICIPANT	\N	PRESENT	0
682173	682107	14327T	PARTICIPANT	\N	PRESENT	0
682174	682107	14231L	PARTICIPANT	\N	PRESENT	0
682175	682107	19543W	PARTICIPANT	\N	PRESENT	0
682176	682107	20110Q	PARTICIPANT	\N	PRESENT	0
682177	682107	20120S	PARTICIPANT	\N	PRESENT	0
682178	682107	14179A	PARTICIPANT	\N	PRESENT	0
682153	682107	01043Q	PARTICIPANT	\N	PRESENT	0
682154	682107	14191V	PARTICIPANT	\N	PRESENT	0
682179	682107	14193X	PARTICIPANT	\N	PRESENT	0
682180	682107	20100N	PARTICIPANT	\N	PRESENT	0
682181	682107	20116W	PARTICIPANT	\N	PRESENT	0
682182	682107	20090E	PARTICIPANT	\N	PRESENT	0
682183	682107	20026V	PARTICIPANT	\N	PRESENT	0
682184	682107	20056C	PARTICIPANT	\N	PRESENT	0
682185	682107	19467C	PARTICIPANT	\N	PRESENT	0
682186	682107	20044X	PARTICIPANT	\N	PRESENT	0
682187	682107	19383Y	PARTICIPANT	\N	PRESENT	0
682188	682107	20058E	PARTICIPANT	\N	PRESENT	0
682189	682107	19651A	PARTICIPANT	\N	PRESENT	0
682190	682107	14147R	PARTICIPANT	\N	PRESENT	0
682191	682107	04047H	PARTICIPANT	\N	PRESENT	0
682192	682107	05012A	PARTICIPANT	\N	PRESENT	0
682193	682107	14223L	PARTICIPANT	\N	PRESENT	0
682194	682107	11074Q	PARTICIPANT	\N	PRESENT	0
682195	682107	08028W	PARTICIPANT	\N	PRESENT	0
682196	682107	19711U	PARTICIPANT	\N	PRESENT	0
682197	682107	20140W	PARTICIPANT	\N	PRESENT	0
682198	682107	20142Y	PARTICIPANT	\N	PRESENT	0
682199	682107	19347U	PARTICIPANT	\N	PRESENT	0
682200	682107	19782L	PARTICIPANT	\N	PRESENT	0
682201	682107	20030R	PARTICIPANT	\N	PRESENT	0
682202	682107	20064C	PARTICIPANT	\N	PRESENT	0
682203	682107	18193Q	PARTICIPANT	\N	PRESENT	0
682204	682107	14053L	PARTICIPANT	\N	PRESENT	0
682205	682107	20040T	PARTICIPANT	\N	PRESENT	0
682206	682107	14219Q	PARTICIPANT	\N	PRESENT	0
682207	682107	19715Y	PARTICIPANT	\N	PRESENT	0
682208	682107	19768N	PARTICIPANT	\N	PRESENT	0
682209	682107	14073Q	PARTICIPANT	\N	PRESENT	0
682210	682107	19489J	PARTICIPANT	\N	PRESENT	0
682211	682107	20032T	PARTICIPANT	\N	PRESENT	0
682212	682107	19725B	PARTICIPANT	\N	PRESENT	0
682213	682107	19503N	PARTICIPANT	\N	PRESENT	0
682214	682107	14205J	PARTICIPANT	\N	PRESENT	0
682215	682107	20034V	PARTICIPANT	\N	PRESENT	0
682216	682107	20096L	PARTICIPANT	\N	PRESENT	0
682217	682107	20128B	PARTICIPANT	\N	PRESENT	0
682218	682107	19647E	PARTICIPANT	\N	PRESENT	0
682219	682107	10015M	PARTICIPANT	\N	PRESENT	0
682220	682107	14031R	PARTICIPANT	\N	PRESENT	0
682221	682107	14083S	PARTICIPANT	\N	PRESENT	0
682222	682107	19549D	PARTICIPANT	\N	PRESENT	0
682223	682107	19533U	PARTICIPANT	\N	PRESENT	0
682224	682107	20172F	PARTICIPANT	\N	PRESENT	0
682225	682107	01057W	PARTICIPANT	\N	PRESENT	0
682226	682107	14225N	PARTICIPANT	\N	PRESENT	0
682227	682107	14042U	PARTICIPANT	\N	PRESENT	0
682228	682107	20062A	PARTICIPANT	\N	PRESENT	0
682229	682107	19415P	PARTICIPANT	\N	PRESENT	0
682230	682107	19681G	PARTICIPANT	\N	PRESENT	0
682231	682107	14207L	PARTICIPANT	\N	PRESENT	0
682232	682107	14357A	PARTICIPANT	\N	PRESENT	0
682233	682107	20022R	PARTICIPANT	\N	PRESENT	0
682234	682107	19335Q	PARTICIPANT	\N	PRESENT	0
682235	682107	19531S	PARTICIPANT	\N	PRESENT	0
682236	682107	08061X	PARTICIPANT	\N	PRESENT	0
682237	682107	20074E	PARTICIPANT	\N	PRESENT	0
682238	682107	19333N	PARTICIPANT	\N	PRESENT	0
682239	682107	17965H	PARTICIPANT	\N	PRESENT	0
682240	682107	14069U	PARTICIPANT	\N	PRESENT	0
682241	682107	08034U	PARTICIPANT	\N	PRESENT	0
682242	682107	19507S	PARTICIPANT	\N	PRESENT	0
682243	682107	14133K	PARTICIPANT	\N	PRESENT	0
682244	682107	19413M	PARTICIPANT	\N	PRESENT	0
682245	682107	14215L	PARTICIPANT	\N	PRESENT	0
682246	682107	20052X	PARTICIPANT	\N	PRESENT	0
682247	682107	08073C	PARTICIPANT	\N	PRESENT	0
682248	682107	11056N	PARTICIPANT	\N	PRESENT	0
682249	682107	19695N	PARTICIPANT	\N	PRESENT	0
682250	682107	14033T	PARTICIPANT	\N	PRESENT	0
682251	682107	19599P	PARTICIPANT	\N	PRESENT	0
682252	682107	19820Y	PARTICIPANT	\N	PRESENT	0
682253	682107	14331P	PARTICIPANT	\N	PRESENT	0
682254	682107	19563B	PARTICIPANT	\N	PRESENT	0
682255	682107	01025N	PARTICIPANT	\N	PRESENT	0
682256	682107	19691J	PARTICIPANT	\N	PRESENT	0
682257	682107	11064N	PARTICIPANT	\N	PRESENT	0
682258	682107	20080C	PARTICIPANT	\N	PRESENT	0
682259	682107	20286Q	PARTICIPANT	\N	PRESENT	0
682260	682107	08012N	PARTICIPANT	\N	PRESENT	0
682261	682107	20018V	PARTICIPANT	\N	PRESENT	0
682262	682107	19441R	PARTICIPANT	\N	PRESENT	0
682263	682107	14037X	PARTICIPANT	\N	PRESENT	0
682264	682107	19723Y	PARTICIPANT	\N	PRESENT	0
682265	682107	14267Y	PARTICIPANT	\N	PRESENT	0
682267	682266	14001X	PARTICIPANT	\N	PRESENT	0
682268	682107	04043D	PARTICIPANT	\N	PRESENT	0
682269	682107	19671E	PARTICIPANT	\N	PRESENT	0
682270	682107	20180F	PARTICIPANT	\N	PRESENT	0
682271	682107	11070L	PARTICIPANT	\N	PRESENT	0
682272	682107	19954N	PARTICIPANT	\N	PRESENT	0
682273	682107	20066E	PARTICIPANT	\N	PRESENT	0
682274	682107	97011G	PARTICIPANT	\N	PRESENT	0
682275	682107	20038A	PARTICIPANT	\N	PRESENT	0
682277	682276	14033T	PARTICIPANT	\N	PRESENT	0
682278	682276	14257W	PARTICIPANT	\N	PRESENT	0
682279	682276	19820Y	PARTICIPANT	\N	PRESENT	0
682280	682276	19369B	PARTICIPANT	\N	PRESENT	0
682281	682276	20096L	PARTICIPANT	\N	PRESENT	0
682282	682276	19575F	PARTICIPANT	\N	PRESENT	0
682283	682276	19533U	PARTICIPANT	\N	PRESENT	0
682284	682107	14187A	PARTICIPANT	\N	PRESENT	0
682285	682107	01024M	PARTICIPANT	\N	PRESENT	0
682286	682107	20252E	PARTICIPANT	\N	PRESENT	0
682287	682276	20034V	PARTICIPANT	\N	PRESENT	0
682288	682276	14038Y	PARTICIPANT	\N	PRESENT	0
682289	682107	20094J	PARTICIPANT	\N	PRESENT	0
682290	682276	20018V	PARTICIPANT	\N	PRESENT	0
682291	682276	19333N	PARTICIPANT	\N	PRESENT	0
682292	682276	14031R	PARTICIPANT	\N	PRESENT	0
682293	682276	20126Y	PARTICIPANT	\N	PRESENT	0
682294	682276	20120S	PARTICIPANT	\N	PRESENT	0
682295	682276	20062A	PARTICIPANT	\N	PRESENT	0
682297	682276	19711U	PARTICIPANT	\N	PRESENT	0
682298	682276	14071N	PARTICIPANT	\N	PRESENT	0
682299	682276	17367Q	PARTICIPANT	\N	PRESENT	0
682300	682107	04057K	PARTICIPANT	\N	PRESENT	0
682301	682107	14111D	PARTICIPANT	\N	PRESENT	0
682302	682107	20082E	PARTICIPANT	\N	PRESENT	0
682303	682107	19675J	PARTICIPANT	\N	PRESENT	0
682304	682107	14237S	PARTICIPANT	\N	PRESENT	0
682308	679178	17737W	PARTICIPANT	\N	EXCUSE	0
682309	682276	14357A	PARTICIPANT	\N	PRESENT	0
655729	655728	14053L	PARTICIPANT	\N	PRESENT	0
655732	655728	11066Q	PARTICIPANT	\N	PRESENT	0
655735	655733	19515S	PRESIDENT	0	PRESENT	0
655736	655733	19575F	PARTICIPANT	\N	PRESENT	0
655737	655733	20094J	PARTICIPANT	\N	PRESENT	0
655738	655733	14083S	PARTICIPANT	\N	PRESENT	0
655739	655733	20126Y	PARTICIPANT	\N	PRESENT	0
655740	655733	19671E	PARTICIPANT	\N	PRESENT	0
655741	655733	14030Q	PARTICIPANT	\N	PRESENT	0
655743	655734	19515S	PRESIDENT	0	PRESENT	0
655744	655734	19575F	PARTICIPANT	\N	PRESENT	0
655745	655734	20094J	PARTICIPANT	\N	PRESENT	0
655746	655734	20126Y	PARTICIPANT	\N	PRESENT	0
655747	655734	19671E	PARTICIPANT	\N	PRESENT	0
656687	656159	19760E	PARTICIPANT	\N	EXCUSE	0
656688	656159	19367Y	PARTICIPANT	\N	EXCUSE	0
656689	656159	19553Y	PARTICIPANT	\N	PRESENT	0
656690	656159	04057K	PARTICIPANT	\N	EXCUSE	0
656691	656159	17779H	PARTICIPANT	\N	PRESENT	0
656692	656159	14281W	PARTICIPANT	\N	PRESENT	0
656693	656159	19329S	PARTICIPANT	\N	PRESENT	0
656694	656159	20130U	PARTICIPANT	\N	PRESENT	0
656695	656159	19591F	PARTICIPANT	\N	PRESENT	0
656696	656159	18193Q	PARTICIPANT	\N	PRESENT	0
656697	656159	14195A	PARTICIPANT	\N	PRESENT	0
656698	656159	14042U	PARTICIPANT	\N	PRESENT	0
656699	656159	10006L	PRESIDENT	0	PRESENT	0
656700	656159	04092N	PARTICIPANT	\N	PRESENT	0
656701	656159	20148F	PARTICIPANT	\N	PRESENT	0
656702	656159	14026U	PARTICIPANT	\N	PRESENT	0
656703	656159	14213J	PARTICIPANT	\N	PRESENT	0
656704	656159	14071N	PARTICIPANT	\N	PRESENT	0
656705	656159	19679N	PARTICIPANT	\N	PRESENT	0
656706	656159	19569H	PARTICIPANT	\N	PRESENT	0
656707	656159	04043D	PARTICIPANT	\N	PRESENT	0
656708	656159	20066E	PARTICIPANT	\N	PRESENT	0
656709	656159	01034P	PARTICIPANT	\N	PRESENT	0
656710	656159	11097X	PARTICIPANT	\N	PRESENT	0
656711	656159	19798U	PARTICIPANT	\N	PRESENT	0
656712	656159	19723Y	PARTICIPANT	\N	PRESENT	0
656713	656159	14217N	PARTICIPANT	\N	PRESENT	0
656714	656159	19715Y	PARTICIPANT	\N	PRESENT	0
656715	656159	19663E	PARTICIPANT	\N	PRESENT	0
656716	656159	14355X	PARTICIPANT	\N	PRESENT	0
656719	656159	19691J	PARTICIPANT	\N	PRESENT	0
656720	656159	11031D	PARTICIPANT	\N	PRESENT	0
659715	659166	04092N	PARTICIPANT	\N	EXCUSE	0
659716	659166	19713W	PARTICIPANT	\N	PRESENT	0
659717	659166	19691J	PARTICIPANT	\N	PRESENT	0
659718	659166	19723Y	PARTICIPANT	\N	PRESENT	0
659719	659166	19657G	PARTICIPANT	\N	PRESENT	0
659720	659166	19760E	PARTICIPANT	\N	PRESENT	0
659721	659166	17965H	PARTICIPANT	\N	PRESENT	0
659722	659166	14042U	PARTICIPANT	\N	PRESENT	0
659723	659410	19629C	PARTICIPANT	\N	PRESENT	0
659724	659410	04071H	PARTICIPANT	\N	PRESENT	0
659725	659410	19515S	PARTICIPANT	\N	PRESENT	0
659726	659410	19479G	PARTICIPANT	\N	PRESENT	0
659727	659410	04008A	PARTICIPANT	\N	PRESENT	0
659728	659410	14331P	PARTICIPANT	\N	PRESENT	0
659729	659410	14033T	PARTICIPANT	\N	PRESENT	0
659730	659410	19699S	PARTICIPANT	\N	PRESENT	0
659731	659410	20054A	PARTICIPANT	\N	PRESENT	0
659732	659410	20038A	PARTICIPANT	\N	PRESENT	0
659733	659410	19729F	PARTICIPANT	\N	PRESENT	0
659734	659410	14053L	PARTICIPANT	\N	PRESENT	0
659735	659410	14109K	PARTICIPANT	\N	PRESENT	0
659736	659410	04047H	PARTICIPANT	\N	PRESENT	0
659737	659410	99004R	PARTICIPANT	\N	PRESENT	0
659738	659410	14151M	PARTICIPANT	\N	PRESENT	0
659739	659410	20042V	PARTICIPANT	\N	PRESENT	0
659740	659410	14097Y	PARTICIPANT	\N	PRESENT	0
659741	659410	14173T	PARTICIPANT	\N	PRESENT	0
659742	659410	01025N	PARTICIPANT	\N	PRESENT	0
659743	659410	11066Q	PARTICIPANT	\N	PRESENT	0
659744	659410	18083K	PARTICIPANT	\N	PRESENT	0
659745	659410	20298U	PARTICIPANT	\N	PRESENT	0
659746	659410	20142Y	PARTICIPANT	\N	PRESENT	0
659747	659410	19503N	PARTICIPANT	\N	PRESENT	0
659748	659410	20110Q	PARTICIPANT	\N	PRESENT	0
659749	659410	19301E	PARTICIPANT	\N	PRESENT	0
659750	659410	19782L	PARTICIPANT	\N	PRESENT	0
659751	659410	19695N	PARTICIPANT	\N	PRESENT	0
659752	659410	19565D	PARTICIPANT	\N	PRESENT	0
659753	659410	19611R	PARTICIPANT	\N	PRESENT	0
659754	659410	19701S	PARTICIPANT	\N	PRESENT	0
659755	659410	19749K	PARTICIPANT	\N	PRESENT	0
659756	659410	14107H	PARTICIPANT	\N	PRESENT	0
659757	659410	11103C	PARTICIPANT	\N	PRESENT	0
659758	659410	14251Q	PARTICIPANT	\N	PRESENT	0
659759	659410	08047A	PARTICIPANT	\N	PRESENT	0
659760	659410	14111D	PARTICIPANT	\N	PRESENT	0
659761	659410	20122U	PARTICIPANT	\N	PRESENT	0
659762	659410	04085P	PARTICIPANT	\N	PRESENT	0
659763	659410	14021P	PARTICIPANT	\N	PRESENT	0
659764	659410	19826F	PARTICIPANT	\N	PRESENT	0
659765	659410	19533U	PARTICIPANT	\N	PRESENT	0
659766	659410	20132W	PARTICIPANT	\N	PRESENT	0
659767	659410	19725B	PARTICIPANT	\N	PRESENT	0
659768	659410	14267Y	PARTICIPANT	\N	PRESENT	0
659769	659410	95063L	PARTICIPANT	\N	PRESENT	0
659770	659410	20108W	PARTICIPANT	\N	PRESENT	0
659771	659410	20024T	PARTICIPANT	\N	PRESENT	0
659772	659410	19573D	PARTICIPANT	\N	PRESENT	0
659773	659410	14187A	PARTICIPANT	\N	PRESENT	0
659774	659410	14069U	PARTICIPANT	\N	PRESENT	0
659775	659410	14038Y	PARTICIPANT	\N	PRESENT	0
659776	659410	20022R	PARTICIPANT	\N	PRESENT	0
659777	659410	19651A	PARTICIPANT	\N	PRESENT	0
659778	659410	19585H	PARTICIPANT	\N	PRESENT	0
659779	659410	14205J	PARTICIPANT	\N	PRESENT	0
659780	659410	20128B	PARTICIPANT	\N	PRESENT	0
659781	659410	20084G	PARTICIPANT	\N	PRESENT	0
659782	659410	20062A	PARTICIPANT	\N	PRESENT	0
659783	659410	19954N	PARTICIPANT	\N	PRESENT	0
659784	659410	20090E	PARTICIPANT	\N	PRESENT	0
659785	659410	20076G	PARTICIPANT	\N	PRESENT	0
659786	659410	08028W	PARTICIPANT	\N	PRESENT	0
659787	659410	19295A	PARTICIPANT	\N	PRESENT	0
659788	659410	19489J	PARTICIPANT	\N	PRESENT	0
659789	659410	08073C	PARTICIPANT	\N	PRESENT	0
659790	659410	08061X	PARTICIPANT	\N	PRESENT	0
659791	659410	11072N	PARTICIPANT	\N	PRESENT	0
659792	659410	19687N	PARTICIPANT	\N	PRESENT	0
659793	659410	14030Q	PARTICIPANT	\N	PRESENT	0
659794	659410	20052X	PARTICIPANT	\N	PRESENT	0
659795	659410	14207L	PARTICIPANT	\N	PRESENT	0
659796	659410	19583F	PARTICIPANT	\N	PRESENT	0
659797	659410	19347U	PARTICIPANT	\N	PRESENT	0
659798	659410	20914V	PARTICIPANT	\N	PRESENT	0
659799	659410	01058X	PARTICIPANT	\N	PRESENT	0
659800	659410	19507S	PARTICIPANT	\N	PRESENT	0
659801	659410	20056C	PARTICIPANT	\N	PRESENT	0
659802	659410	20026V	PARTICIPANT	\N	PRESENT	0
659803	659410	20172F	PARTICIPANT	\N	PRESENT	0
659804	659410	14037X	PARTICIPANT	\N	PRESENT	0
659805	659410	20016T	PARTICIPANT	\N	PRESENT	0
659806	659166	04057K	PARTICIPANT	\N	PRESENT	0
659807	659166	19715Y	PARTICIPANT	\N	PRESENT	0
659808	659410	14275Y	PARTICIPANT	\N	PRESENT	0
659809	659410	19543W	PARTICIPANT	\N	PRESENT	0
659810	659410	19591F	PARTICIPANT	\N	PRESENT	0
659811	659410	19525U	PARTICIPANT	\N	PRESENT	0
659812	659410	11083R	PARTICIPANT	\N	PRESENT	0
659813	659410	11054L	PARTICIPANT	\N	PRESENT	0
659814	659410	20036X	PARTICIPANT	\N	PRESENT	0
659815	659410	20032T	PARTICIPANT	\N	PRESENT	0
659816	659410	14179A	PARTICIPANT	\N	PRESENT	0
659817	659410	14255U	PARTICIPANT	\N	PRESENT	0
659818	659410	19577H	PARTICIPANT	\N	PRESENT	0
659819	659410	19643A	PARTICIPANT	\N	PRESENT	0
659820	659410	11033F	PARTICIPANT	\N	PRESENT	0
659828	659410	04045F	PARTICIPANT	\N	PRESENT	0
659822	659410	08060W	PARTICIPANT	\N	PRESENT	0
659823	659410	19349W	PARTICIPANT	\N	PRESENT	0
659824	659410	19697Q	PARTICIPANT	\N	PRESENT	0
659825	659410	20070A	PARTICIPANT	\N	PRESENT	0
659826	659410	19549D	PARTICIPANT	\N	PRESENT	0
659827	659410	20080C	PARTICIPANT	\N	PRESENT	0
665382	665381	20124W	PARTICIPANT	\N	PRESENT	1
665383	665381	14109K	PARTICIPANT	\N	PRESENT	1
665384	665381	19735D	PARTICIPANT	\N	PRESENT	1
665385	663860	19683J	PARTICIPANT	\N	PRESENT	0
665386	663860	17965H	PARTICIPANT	\N	PRESENT	0
665387	663860	17779H	PARTICIPANT	\N	PRESENT	0
665388	663860	14195A	PARTICIPANT	\N	PRESENT	0
665389	663860	19715Y	PARTICIPANT	\N	EXCUSE	0
665390	663860	19511N	PARTICIPANT	\N	PRESENT	0
665391	663860	19713W	PARTICIPANT	\N	PRESENT	0
665392	663860	19569H	PARTICIPANT	\N	PRESENT	0
665393	663860	19679N	PARTICIPANT	\N	PRESENT	0
665394	663860	14042U	PARTICIPANT	\N	PRESENT	0
665395	663860	14217N	PARTICIPANT	\N	PRESENT	0
665396	663860	14071N	PARTICIPANT	\N	PRESENT	0
665397	663860	19703U	PARTICIPANT	\N	PRESENT	0
665398	663860	10006L	PRESIDENT	0	PRESENT	0
665399	663860	19553Y	PARTICIPANT	\N	PRESENT	0
665400	663860	14026U	PARTICIPANT	\N	PRESENT	0
665401	663860	08045X	PARTICIPANT	\N	PRESENT	0
665402	663860	14223L	PARTICIPANT	\N	PRESENT	0
665404	663860	19697Q	PARTICIPANT	\N	PRESENT	0
665405	663860	19723Y	PARTICIPANT	\N	PRESENT	0
665406	663860	19798U	PARTICIPANT	\N	PRESENT	0
665407	663860	14213J	PARTICIPANT	\N	PRESENT	0
666709	666668	19719D	PARTICIPANT	\N	PRESENT	0
666714	666668	14030Q	PARTICIPANT	\N	PRESENT	0
666719	666668	14109K	PARTICIPANT	\N	PRESENT	0
667309	667307	19399H	PARTICIPANT	\N	PRESENT	0
667310	667308	20112S	PARTICIPANT	\N	PRESENT	0
670590	670588	19631V	PARTICIPANT	\N	PRESENT	0
670596	670595	14187A	PARTICIPANT	\N	PRESENT	0
670600	670599	14187A	PARTICIPANT	\N	PRESENT	0
670602	670601	14187A	PARTICIPANT	\N	PRESENT	0
670604	670603	14187A	PARTICIPANT	\N	PRESENT	0
670619	670616	19369B	PARTICIPANT	\N	PRESENT	0
670623	670622	19369B	PARTICIPANT	\N	PRESENT	0
682598	682597	14231L	PRESIDENT	0	PRESENT	0
682599	682597	05012A	PARTICIPANT	\N	PRESENT	0
682600	682597	19782L	PARTICIPANT	\N	PRESENT	0
682601	682597	14187A	PARTICIPANT	\N	PRESENT	0
682602	682597	17637T	PARTICIPANT	\N	PRESENT	0
682603	682597	20084G	PARTICIPANT	\N	PRESENT	0
682604	682597	20022R	PARTICIPANT	\N	PRESENT	0
682605	682597	14053L	PARTICIPANT	\N	PRESENT	0
682606	682597	14217N	PARTICIPANT	\N	EXCUSE	0
682607	682597	14215L	PARTICIPANT	\N	EXCUSE	0
682608	682597	14281W	PARTICIPANT	\N	EXCUSE	0
682609	682597	19565D	PARTICIPANT	\N	EXCUSE	0
682610	682597	01057W	PARTICIPANT	\N	PRESENT	0
682612	682597	19447X	PARTICIPANT	\N	EXCUSE	0
682613	682597	19826F	PARTICIPANT	\N	EXCUSE	0
682614	682597	19563B	PARTICIPANT	\N	EXCUSE	0
682615	682597	14071N	PARTICIPANT	\N	EXCUSE	0
682616	682597	04045F	PARTICIPANT	\N	EXCUSE	0
682617	682597	20062A	PARTICIPANT	\N	EXCUSE	0
682618	682597	14229S	PARTICIPANT	\N	PRESENT	0
683184	683149	11070L	PARTICIPANT	\N	PRESENT	0
683185	683149	19533U	PARTICIPANT	\N	PRESENT	0
683186	683149	19758L	PARTICIPANT	\N	PRESENT	0
683187	683149	18083K	PARTICIPANT	\N	PRESENT	0
683188	683149	20264J	PARTICIPANT	\N	PRESENT	0
683189	683149	14229S	PARTICIPANT	\N	PRESENT	0
683190	683149	19387D	PARTICIPANT	\N	PRESENT	0
683191	683149	04057K	PARTICIPANT	\N	PRESENT	0
683192	683149	19593H	PARTICIPANT	\N	PRESENT	0
683193	683149	01048V	PARTICIPANT	\N	PRESENT	0
683194	683149	14109K	PARTICIPANT	\N	PRESENT	0
683195	683149	19527W	PARTICIPANT	\N	PRESENT	0
683196	683149	20142Y	PARTICIPANT	\N	PRESENT	0
683197	683149	19621T	PARTICIPANT	\N	PRESENT	0
683198	683149	20180F	PARTICIPANT	\N	PRESENT	0
683199	683149	19693L	PARTICIPANT	\N	PRESENT	0
683200	683149	14187A	PARTICIPANT	\N	PRESENT	0
683201	683149	19719D	PARTICIPANT	\N	PRESENT	0
683202	683149	14030Q	PARTICIPANT	\N	PRESENT	0
683203	683149	14219Q	PARTICIPANT	\N	PRESENT	0
683204	683149	14123H	PARTICIPANT	\N	PRESENT	0
683205	683149	19611R	PARTICIPANT	\N	PRESENT	0
683182	683181	11083R	PARTICIPANT	\N	PRESENT	0
683183	683181	14231L	PARTICIPANT	\N	PRESENT	0
683206	683149	19057M	PARTICIPANT	\N	PRESENT	0
683207	683149	20100N	PARTICIPANT	\N	PRESENT	0
683208	683149	19573D	PARTICIPANT	\N	PRESENT	0
683209	683149	19631V	PARTICIPANT	\N	PRESENT	0
683210	683149	11043H	PARTICIPANT	\N	PRESENT	0
683211	683149	14083S	PARTICIPANT	\N	PRESENT	0
683212	683149	20086J	PARTICIPANT	\N	PRESENT	0
683213	683149	14026U	PARTICIPANT	\N	PRESENT	0
683214	683149	12041X	PARTICIPANT	\N	PRESENT	0
683215	683149	19671E	PARTICIPANT	\N	PRESENT	0
683216	683149	19643A	PARTICIPANT	\N	PRESENT	0
683217	683149	20032T	PARTICIPANT	\N	PRESENT	0
683218	683149	04035D	PARTICIPANT	\N	PRESENT	0
683219	683149	14069U	PARTICIPANT	\N	PRESENT	0
683235	676623	14026U	PARTICIPANT	\N	PRESENT	0
683236	676623	20086J	PARTICIPANT	\N	PRESENT	0
683237	676623	14327T	PARTICIPANT	\N	PRESENT	0
683238	676623	14187A	PARTICIPANT	\N	PRESENT	0
683239	676623	19631V	PARTICIPANT	\N	PRESENT	0
683240	676623	20040T	PARTICIPANT	\N	PRESENT	0
683241	676623	14169X	PARTICIPANT	\N	PRESENT	0
683242	679540	14225N	PRESIDENT	0	PRESENT	0
683243	679540	07029T	PARTICIPANT	\N	EXCUSE	0
683244	679540	08010L	PARTICIPANT	\N	EXCUSE	0
683245	679540	20050V	PARTICIPANT	\N	EXCUSE	0
683246	679540	14327T	PARTICIPANT	\N	PRESENT	0
683247	679540	20086J	PARTICIPANT	\N	PRESENT	0
683248	679540	14083S	PARTICIPANT	\N	PRESENT	0
683249	679540	11048N	PARTICIPANT	\N	PRESENT	0
683250	679540	08009T	PARTICIPANT	\N	PRESENT	0
683251	679540	11053K	PARTICIPANT	\N	PRESENT	0
683252	679540	14253S	PARTICIPANT	\N	PRESENT	0
683253	679540	20044X	PARTICIPANT	\N	PRESENT	0
683254	679540	19671E	PARTICIPANT	\N	PRESENT	0
683255	679540	08034U	PARTICIPANT	\N	PRESENT	0
683256	679540	19711U	PARTICIPANT	\N	PRESENT	0
683257	676623	20100N	PARTICIPANT	\N	PRESENT	0
683258	676623	14251Q	PARTICIPANT	\N	PRESENT	0
683259	676623	20106U	PARTICIPANT	\N	PRESENT	0
683260	676623	20088L	PARTICIPANT	\N	PRESENT	0
683261	676623	11077T	PARTICIPANT	\N	PRESENT	0
683262	676623	01043Q	PARTICIPANT	\N	PRESENT	0
683263	676623	20130U	PARTICIPANT	\N	PRESENT	0
683264	676623	14069U	PARTICIPANT	\N	PRESENT	0
683265	676623	19599P	PARTICIPANT	\N	PRESENT	0
683266	676623	20032T	PARTICIPANT	\N	PRESENT	0
683267	676623	20046A	PARTICIPANT	\N	PRESENT	0
683268	676623	19387D	PARTICIPANT	\N	PRESENT	0
683269	676623	20044X	PARTICIPANT	\N	PRESENT	0
683274	676623	14225N	PARTICIPANT	\N	PRESENT	0
683275	676623	19711U	PARTICIPANT	\N	PRESENT	0
683277	676623	14219Q	PARTICIPANT	\N	PRESENT	0
683278	676623	14083S	PARTICIPANT	\N	PRESENT	0
683279	676623	19715Y	PARTICIPANT	\N	PRESENT	0
683280	676623	14033T	PARTICIPANT	\N	PRESENT	0
683281	676623	19693L	PARTICIPANT	\N	PRESENT	0
683282	676623	11090Q	PARTICIPANT	\N	PRESENT	0
683283	676623	19295A	PARTICIPANT	\N	PRESENT	0
683284	676623	20024T	PARTICIPANT	\N	PRESENT	0
683285	676623	20120S	PARTICIPANT	\N	PRESENT	0
683286	676623	19745F	PARTICIPANT	\N	PRESENT	0
683287	676623	20078J	PARTICIPANT	\N	PRESENT	0
683288	676623	11048N	PARTICIPANT	\N	PRESENT	0
683289	676623	08034U	PARTICIPANT	\N	PRESENT	0
683290	676623	19820Y	PARTICIPANT	\N	PRESENT	0
683291	676623	08009T	PARTICIPANT	\N	PRESENT	0
683293	683292	05008E	PARTICIPANT	\N	PRESENT	0
683294	683292	11053K	PARTICIPANT	\N	PRESENT	0
683295	683292	01028R	PARTICIPANT	\N	PRESENT	0
683296	676623	11101A	PARTICIPANT	\N	PRESENT	0
683297	676623	11012A	PARTICIPANT	\N	PRESENT	0
683298	676623	20142Y	PARTICIPANT	\N	PRESENT	0
683299	676623	14257W	PARTICIPANT	\N	PRESENT	0
683300	676623	19826F	PARTICIPANT	\N	PRESENT	0
683301	676623	18083K	PARTICIPANT	\N	PRESENT	0
683302	676623	20054A	PARTICIPANT	\N	PRESENT	0
683303	676623	19637C	PARTICIPANT	\N	PRESENT	0
683304	676623	11065P	PARTICIPANT	\N	PRESENT	0
658046	658045	05008E	PARTICIPANT	\N	PRESENT	0
658047	658045	11053K	PARTICIPANT	\N	PRESENT	0
658048	658045	01028R	PARTICIPANT	\N	PRESENT	0
660689	660675	20128B	PARTICIPANT	\N	PRESENT	0
660799	659409	19673G	PARTICIPANT	\N	EXCUSE	0
660800	659409	19329S	PARTICIPANT	\N	EXCUSE	0
660818	660817	20066E	PARTICIPANT	\N	PRESENT	0
661823	661822	20110Q	PARTICIPANT	\N	PRESENT	0
664318	660365	20132W	PARTICIPANT	\N	PRESENT	0
664319	660365	20048C	PARTICIPANT	\N	PRESENT	0
664320	660365	19735D	PARTICIPANT	\N	PRESENT	0
664321	660365	19758L	PARTICIPANT	\N	PRESENT	0
664323	661837	14083S	PARTICIPANT	\N	PRESENT	0
664327	661837	01028R	PARTICIPANT	\N	PRESENT	0
664328	661837	19525U	PARTICIPANT	\N	PRESENT	0
664329	661837	08061X	PARTICIPANT	\N	PRESENT	0
664330	661837	20042V	PARTICIPANT	\N	PRESENT	0
664331	661837	14253S	PARTICIPANT	\N	PRESENT	0
664332	661837	19675J	PARTICIPANT	\N	PRESENT	0
664333	661837	14133K	PARTICIPANT	\N	PRESENT	0
664334	661837	20054A	PARTICIPANT	\N	PRESENT	0
664335	661837	20034V	PARTICIPANT	\N	PRESENT	0
664336	661837	14327T	PARTICIPANT	\N	PRESENT	0
664339	661837	20180F	PARTICIPANT	\N	PRESENT	0
664340	661837	19387D	PARTICIPANT	\N	PRESENT	0
664341	661837	14249W	PARTICIPANT	\N	PRESENT	0
664345	661837	14229S	PARTICIPANT	\N	PRESENT	0
664346	661837	11067R	PARTICIPANT	\N	PRESENT	0
664488	662021	19383Y	PARTICIPANT	\N	PRESENT	0
664489	662021	19768N	PARTICIPANT	\N	PRESENT	0
664490	662021	19515S	PARTICIPANT	\N	PRESENT	0
664491	662021	11077T	PARTICIPANT	\N	PRESENT	0
664492	662021	14357A	PARTICIPANT	\N	PRESENT	0
664493	662021	19441R	PARTICIPANT	\N	PRESENT	0
664494	662021	20094J	PARTICIPANT	\N	PRESENT	0
664495	662021	04045F	PARTICIPANT	\N	PRESENT	0
664496	662021	19866P	PARTICIPANT	\N	PRESENT	0
664497	662021	11099A	PARTICIPANT	\N	PRESENT	0
664498	662021	19705W	PARTICIPANT	\N	PRESENT	0
664499	662021	19707Y	PARTICIPANT	\N	PRESENT	0
664500	662021	08015R	PARTICIPANT	\N	PRESENT	0
664501	662021	19575F	PARTICIPANT	\N	PRESENT	0
664502	662021	19563B	PARTICIPANT	\N	PRESENT	0
664503	662021	14329V	PARTICIPANT	\N	PRESENT	0
664504	662021	14037X	PARTICIPANT	\N	PRESENT	0
664505	662021	20030R	PARTICIPANT	\N	PRESENT	0
664506	662021	19467C	PARTICIPANT	\N	PRESENT	0
664507	662021	20034V	PARTICIPANT	\N	PRESENT	0
664508	662021	14187A	PARTICIPANT	\N	PRESENT	0
664509	662021	20144B	PARTICIPANT	\N	PRESENT	0
664510	662021	19695N	PARTICIPANT	\N	PRESENT	0
664511	662021	14033T	PARTICIPANT	\N	PRESENT	0
664512	662021	11090Q	PRESIDENT	0	PRESENT	0
664513	662021	20054A	PARTICIPANT	\N	PRESENT	0
664514	662021	14205J	PARTICIPANT	\N	PRESENT	0
664515	662021	20060X	PARTICIPANT	\N	PRESENT	0
664516	662021	14251Q	PARTICIPANT	\N	PRESENT	0
664517	662021	19507S	PARTICIPANT	\N	PRESENT	0
664518	662021	20286Q	PARTICIPANT	\N	PRESENT	0
664519	662021	20298U	PARTICIPANT	\N	PRESENT	0
664520	662021	14207L	PARTICIPANT	\N	PRESENT	0
664521	662021	19747H	PARTICIPANT	\N	PRESENT	0
664522	662021	14257W	PARTICIPANT	\N	PRESENT	0
664523	661838	19747H	PARTICIPANT	\N	PRESENT	0
664524	661838	19467C	PARTICIPANT	\N	PRESENT	0
664525	661838	11065P	PARTICIPANT	\N	PRESENT	0
664526	661838	14217N	PARTICIPANT	\N	PRESENT	0
664527	661838	14213J	PARTICIPANT	\N	PRESENT	0
664528	661838	19563B	PARTICIPANT	\N	PRESENT	0
664529	661838	19621T	PARTICIPANT	\N	PRESENT	0
664530	661838	11099A	PARTICIPANT	\N	PRESENT	0
664531	661838	20180F	PARTICIPANT	\N	PRESENT	0
664532	661838	19447X	PARTICIPANT	\N	PRESENT	0
664569	661905	20150Y	PARTICIPANT	\N	PRESENT	0
664570	661905	19701S	PARTICIPANT	\N	PRESENT	0
664571	661905	14097Y	PARTICIPANT	\N	PRESENT	0
664572	661905	19657G	PARTICIPANT	\N	PRESENT	0
664573	661905	11072N	PARTICIPANT	\N	PRESENT	0
664574	661905	14147R	PARTICIPANT	\N	PRESENT	0
665649	664322	11048N	PARTICIPANT	\N	PRESENT	0
665650	664322	14225N	PRESIDENT	0	PRESENT	0
665651	664322	19671E	PARTICIPANT	\N	EXCUSE	0
665652	664322	14327T	PARTICIPANT	\N	PRESENT	0
665653	664322	20036X	PARTICIPANT	\N	PRESENT	0
665654	664322	20116W	PARTICIPANT	\N	PRESENT	0
665655	665149	14071N	PARTICIPANT	\N	PRESENT	0
665656	665149	20032T	PARTICIPANT	\N	PRESENT	0
665703	664322	08034U	PARTICIPANT	\N	PRESENT	0
665704	664322	19687N	PARTICIPANT	\N	PRESENT	0
665706	664322	11053K	PARTICIPANT	\N	PRESENT	0
665707	665149	20142Y	PARTICIPANT	\N	PRESENT	0
665708	665149	19533U	PARTICIPANT	\N	PRESENT	0
665709	665149	20112S	PARTICIPANT	\N	PRESENT	0
665710	665149	19739H	PARTICIPANT	\N	PRESENT	0
665711	664322	04071H	PARTICIPANT	\N	PRESENT	0
665712	664322	11026G	PARTICIPANT	\N	PRESENT	0
665713	665149	19637C	PARTICIPANT	\N	PRESENT	0
665714	665149	19467C	PARTICIPANT	\N	PRESENT	0
665715	665149	17737W	PARTICIPANT	\N	PRESENT	0
665716	665149	08060W	PARTICIPANT	\N	PRESENT	0
665717	665149	19747H	PARTICIPANT	\N	PRESENT	0
665718	665149	17023S	PARTICIPANT	\N	PRESENT	0
665719	665149	14249W	PARTICIPANT	\N	PRESENT	0
665720	665149	01024M	PARTICIPANT	\N	PRESENT	0
665721	665149	01028R	PARTICIPANT	\N	PRESENT	0
665722	664322	14121F	PARTICIPANT	\N	PRESENT	0
665723	665149	19695N	PARTICIPANT	\N	PRESENT	0
665724	665149	20266L	PARTICIPANT	\N	PRESENT	0
665725	665149	20106U	PARTICIPANT	\N	PRESENT	0
665726	665149	14030Q	PARTICIPANT	\N	PRESENT	0
665727	665149	20110Q	PARTICIPANT	\N	PRESENT	0
665728	665149	14147R	PARTICIPANT	\N	PRESENT	0
665729	665149	20052X	PARTICIPANT	\N	PRESENT	0
665730	665149	20108W	PARTICIPANT	\N	PRESENT	0
665734	665149	20092G	PARTICIPANT	\N	PRESENT	0
665735	665149	11104D	PARTICIPANT	\N	PRESENT	0
665736	665149	08015R	PARTICIPANT	\N	PRESENT	0
665737	665149	20028X	PARTICIPANT	\N	PRESENT	0
665738	665149	19621T	PARTICIPANT	\N	PRESENT	0
665739	665149	04045F	PARTICIPANT	\N	PRESENT	0
665740	665149	04059M	PARTICIPANT	\N	PRESENT	0
665742	665149	14189C	PARTICIPANT	\N	PRESENT	0
665748	665149	19553Y	PARTICIPANT	\N	PRESENT	0
665751	665149	19387D	PARTICIPANT	\N	PRESENT	0
665752	664672	19649G	PARTICIPANT	\N	PRESENT	0
665753	664672	20074E	PARTICIPANT	\N	PRESENT	0
665754	664672	19543W	PARTICIPANT	\N	PRESENT	0
665755	664672	19581D	PARTICIPANT	\N	PRESENT	0
665756	664672	04047H	PRESIDENT	0	PRESENT	0
665757	664672	19447X	PARTICIPANT	\N	PRESENT	0
665758	664672	04085P	PARTICIPANT	\N	PRESENT	0
665759	664672	19725B	PARTICIPANT	\N	PRESENT	0
665760	664672	19729F	PARTICIPANT	\N	PRESENT	0
665761	664672	20108W	PARTICIPANT	\N	PRESENT	0
665762	664672	14147R	PARTICIPANT	\N	PRESENT	0
665763	664672	20114U	PARTICIPANT	\N	PRESENT	0
665764	664672	14215L	PARTICIPANT	\N	PRESENT	0
665765	665149	19369B	PARTICIPANT	\N	PRESENT	0
665766	664672	14179A	PARTICIPANT	\N	PRESENT	0
665767	664672	20022R	PARTICIPANT	\N	PRESENT	0
665768	664672	14021P	PARTICIPANT	\N	PRESENT	0
665769	664322	07029T	PARTICIPANT	\N	PRESENT	0
665770	664672	19673G	PARTICIPANT	\N	PRESENT	0
665771	664672	11033F	PARTICIPANT	\N	PRESENT	0
665772	663456	19527W	PARTICIPANT	\N	PRESENT	0
664313	661837	20136B	PARTICIPANT	\N	PRESENT	0
664314	661837	11026G	PARTICIPANT	\N	PRESENT	0
665773	663456	20132W	PARTICIPANT	\N	PRESENT	0
665774	663456	19643A	PARTICIPANT	\N	PRESENT	0
665775	663456	19699S	PARTICIPANT	\N	PRESENT	0
665776	663456	20134Y	PARTICIPANT	\N	PRESENT	0
665777	663456	19533U	PARTICIPANT	\N	PRESENT	0
665778	663456	14073Q	PARTICIPANT	\N	PRESENT	0
665779	663456	19611R	PRESIDENT	0	PRESENT	0
665780	663456	19399H	PARTICIPANT	\N	PRESENT	0
665781	663456	20052X	PARTICIPANT	\N	PRESENT	0
665782	663456	20172F	PARTICIPANT	\N	PRESENT	0
665783	663456	20058E	PARTICIPANT	\N	PRESENT	0
665784	663456	14030Q	PARTICIPANT	\N	PRESENT	0
665785	663456	20056C	PARTICIPANT	\N	PRESENT	0
665786	663456	20180F	PARTICIPANT	\N	PRESENT	0
675939	672261	01048V	PARTICIPANT	\N	PRESENT	0
675940	672261	04043D	PARTICIPANT	\N	PRESENT	0
675941	672261	20066E	PARTICIPANT	\N	EXCUSE	0
675942	672261	20072C	PARTICIPANT	\N	EXCUSE	0
675943	672261	19735D	PARTICIPANT	\N	EXCUSE	0
675944	672261	14221J	PARTICIPANT	\N	EXCUSE	0
682310	682107	07004J	PARTICIPANT	\N	PRESENT	0
682311	682107	19479G	PARTICIPANT	\N	PRESENT	0
682312	682107	11043H	PARTICIPANT	\N	PRESENT	0
682313	682276	19619A	PARTICIPANT	\N	PRESENT	0
682314	682107	11110B	PARTICIPANT	\N	PRESENT	0
682315	682107	19673G	PARTICIPANT	\N	PRESENT	0
682316	682107	19719D	PARTICIPANT	\N	PRESENT	0
682317	682107	19747H	PARTICIPANT	\N	PRESENT	0
682318	682107	18083K	PARTICIPANT	\N	PRESENT	0
682319	682107	11067R	PARTICIPANT	\N	PRESENT	0
682320	682107	19545Y	PARTICIPANT	\N	PRESENT	0
682321	682107	19593H	PARTICIPANT	\N	PRESENT	0
682322	682107	19758L	PARTICIPANT	\N	PRESENT	0
682323	682107	19713W	PARTICIPANT	\N	PRESENT	0
682324	682107	19387D	PARTICIPANT	\N	PRESENT	0
682325	682107	19621T	PARTICIPANT	\N	PRESENT	0
682326	682107	19569H	PARTICIPANT	\N	PRESENT	0
682327	682107	11048N	PARTICIPANT	\N	PRESENT	0
682328	682107	14123H	PARTICIPANT	\N	PRESENT	0
682329	682107	08009T	PARTICIPANT	\N	PRESENT	0
682330	682107	19687N	PARTICIPANT	\N	PRESENT	0
682331	682107	19745F	PARTICIPANT	\N	PRESENT	0
682332	682107	14109K	PARTICIPANT	\N	PRESENT	0
682333	682107	14257W	PARTICIPANT	\N	PRESENT	0
682334	682107	11085T	PARTICIPANT	\N	PRESENT	0
682335	682107	11012A	PARTICIPANT	\N	PRESENT	0
682336	682107	14217N	PARTICIPANT	\N	PRESENT	0
682337	682107	19637C	PARTICIPANT	\N	PRESENT	0
682339	682107	08056B	PARTICIPANT	\N	PRESENT	0
682340	682107	19591F	PARTICIPANT	\N	PRESENT	0
682342	682107	19301E	PARTICIPANT	\N	PRESENT	0
682343	682107	14213J	PARTICIPANT	\N	PRESENT	0
682344	682107	14038Y	PARTICIPANT	\N	PRESENT	0
682345	682107	01028R	PARTICIPANT	\N	PRESENT	0
682346	682107	14021P	PARTICIPANT	\N	PRESENT	0
682347	682107	20046A	PARTICIPANT	\N	PRESENT	0
682348	682107	19649G	PARTICIPANT	\N	PRESENT	0
682349	682107	11090Q	PARTICIPANT	\N	PRESENT	0
682350	682107	19631V	PARTICIPANT	\N	PRESENT	0
682351	682107	19749K	PARTICIPANT	\N	PRESENT	0
682352	674941	14059S	PARTICIPANT	\N	EXCUSE	0
682353	674941	12016W	PARTICIPANT	\N	EXCUSE	0
682354	678416	14059S	PARTICIPANT	\N	EXCUSE	0
682355	678416	12016W	PARTICIPANT	\N	EXCUSE	0
682356	674944	14059S	PARTICIPANT	\N	EXCUSE	0
682358	674944	12016W	PARTICIPANT	\N	EXCUSE	0
682359	682107	20054A	PARTICIPANT	\N	PRESENT	0
682361	682107	14221J	PARTICIPANT	\N	PRESENT	0
682362	682357	14259Y	PARTICIPANT	\N	PRESENT	0
682363	682357	14231L	PARTICIPANT	\N	PRESENT	0
682364	682357	04047H	PARTICIPANT	\N	PRESENT	0
682369	682107	19762G	PARTICIPANT	\N	PRESENT	0
682366	682360	14231L	PARTICIPANT	\N	PRESENT	0
682367	682360	11048N	PARTICIPANT	\N	PRESENT	0
682368	682360	04047H	PARTICIPANT	\N	PRESENT	0
682370	682107	20138D	PARTICIPANT	\N	PRESENT	0
682371	681083	19866P	PARTICIPANT	\N	EXCUSE	0
682372	681084	19866P	PARTICIPANT	\N	EXCUSE	0
682373	681084	20104S	PARTICIPANT	\N	EXCUSE	0
682377	681084	14329V	PARTICIPANT	\N	EXCUSE	0
682375	681084	20018V	PARTICIPANT	\N	EXCUSE	0
682376	681084	19369B	PARTICIPANT	\N	EXCUSE	0
682378	681086	20060X	PARTICIPANT	\N	PRESENT	0
682379	681086	11099A	PARTICIPANT	\N	PRESENT	0
682380	681086	20094J	PARTICIPANT	\N	PRESENT	0
682381	681086	14357A	PARTICIPANT	\N	PRESENT	0
682382	681086	20092G	PARTICIPANT	\N	PRESENT	0
682383	681086	19782L	PARTICIPANT	\N	PRESENT	0
682384	681086	19768N	PARTICIPANT	\N	PRESENT	0
682385	681086	19515S	PARTICIPANT	\N	PRESENT	0
682386	681086	19441R	PARTICIPANT	\N	PRESENT	0
682387	681086	19413M	PARTICIPANT	\N	PRESENT	0
682388	681086	11077T	PARTICIPANT	\N	PRESENT	0
682389	681086	20078J	PARTICIPANT	\N	PRESENT	0
682390	681086	19383Y	PARTICIPANT	\N	PRESENT	0
682391	681086	14038Y	PARTICIPANT	\N	PRESENT	0
682392	681086	20030R	PARTICIPANT	\N	PRESENT	0
682393	681086	19563B	PARTICIPANT	\N	PRESENT	0
682394	681086	14037X	PARTICIPANT	\N	PRESENT	0
682395	681086	14187A	PARTICIPANT	\N	PRESENT	0
682396	681086	19866P	PARTICIPANT	\N	EXCUSE	0
682397	681086	20144B	PARTICIPANT	\N	PRESENT	0
682398	681086	19467C	PARTICIPANT	\N	PRESENT	0
682399	681086	20034V	PARTICIPANT	\N	PRESENT	0
682400	681086	19631V	PARTICIPANT	\N	PRESENT	0
682401	681086	19705W	PARTICIPANT	\N	PRESENT	0
682402	681086	20082E	PARTICIPANT	\N	PRESENT	0
682403	681086	04045F	PARTICIPANT	\N	PRESENT	0
682404	681086	19575F	PARTICIPANT	\N	PRESENT	0
682405	681086	08028W	PARTICIPANT	\N	PRESENT	0
682406	681086	19707Y	PARTICIPANT	\N	PRESENT	0
682407	681086	08015R	PARTICIPANT	\N	PRESENT	0
682408	681086	20298U	PARTICIPANT	\N	PRESENT	0
682409	681086	19747H	PARTICIPANT	\N	PRESENT	0
682410	681086	19507S	PARTICIPANT	\N	PRESENT	0
682411	681086	20286Q	PARTICIPANT	\N	PRESENT	0
682412	681086	14207L	PARTICIPANT	\N	PRESENT	0
682413	681086	14257W	PARTICIPANT	\N	PRESENT	0
682414	681086	01025N	PARTICIPANT	\N	PRESENT	0
682415	681086	14033T	PARTICIPANT	\N	PRESENT	0
682416	681086	19695N	PARTICIPANT	\N	PRESENT	0
682417	681086	11090Q	PRESIDENT	\N	PRESENT	0
682418	681086	20062A	PARTICIPANT	\N	PRESENT	0
682419	681086	14251Q	PARTICIPANT	\N	PRESENT	0
682420	681086	20054A	PARTICIPANT	\N	PRESENT	0
682421	681086	14205J	PARTICIPANT	\N	PRESENT	0
682432	682107	19611R	PARTICIPANT	\N	PRESENT	0
682433	682107	14026U	PARTICIPANT	\N	PRESENT	0
682434	682107	17023S	PARTICIPANT	\N	PRESENT	0
682435	682107	14030Q	PARTICIPANT	\N	PRESENT	0
682436	682107	16685X	PARTICIPANT	\N	PRESENT	0
682437	682107	20298U	PARTICIPANT	\N	PRESENT	0
682428	681086	20018V	PARTICIPANT	\N	EXCUSE	0
682429	681086	20104S	PARTICIPANT	\N	EXCUSE	0
682430	681086	19369B	PARTICIPANT	\N	EXCUSE	0
682431	681086	14329V	PARTICIPANT	\N	EXCUSE	0
682504	676618	12041X	PARTICIPANT	\N	PRESENT	0
682505	676618	19531S	PARTICIPANT	\N	PRESENT	0
682506	676618	19762G	PARTICIPANT	\N	PRESENT	0
682507	676618	19507S	PARTICIPANT	\N	PRESENT	0
682508	676618	01025N	PARTICIPANT	\N	PRESENT	0
682509	676618	19413M	PARTICIPANT	\N	PRESENT	0
682510	676618	20084G	PARTICIPANT	\N	PRESENT	0
682511	676618	20030R	PARTICIPANT	\N	PRESENT	0
682512	676618	20082E	PARTICIPANT	\N	PRESENT	0
682513	676618	14257W	PARTICIPANT	\N	PRESENT	0
682514	676618	20092G	PARTICIPANT	\N	PRESENT	0
682515	676618	11090Q	PARTICIPANT	\N	PRESENT	0
682516	676618	19782L	PARTICIPANT	\N	PRESENT	0
682517	676618	08061X	PARTICIPANT	\N	PRESENT	0
682518	676618	19563B	PARTICIPANT	\N	PRESENT	0
682519	676618	19441R	PARTICIPANT	\N	PRESENT	0
682520	676618	14207L	PARTICIPANT	\N	PRESENT	0
682521	676618	19715Y	PARTICIPANT	\N	PRESENT	0
682522	676618	14205J	PARTICIPANT	\N	PRESENT	0
682523	676618	20054A	PARTICIPANT	\N	PRESENT	0
682524	676618	20100N	PARTICIPANT	\N	PRESENT	0
682525	676618	20046A	PARTICIPANT	\N	PRESENT	0
682526	676618	20044X	PARTICIPANT	\N	PRESENT	0
682527	676618	14033T	PARTICIPANT	\N	PRESENT	0
682528	676618	14187A	PARTICIPANT	\N	PRESENT	0
682529	676618	20090E	PARTICIPANT	\N	PRESENT	0
682530	676618	14357A	PARTICIPANT	\N	PRESENT	0
682531	676618	20032T	PARTICIPANT	\N	PRESENT	0
682532	676618	19467C	PARTICIPANT	\N	PRESENT	0
682533	676618	20026V	PARTICIPANT	\N	PRESENT	0
682534	676618	19503N	PARTICIPANT	\N	PRESENT	0
682535	676618	20076G	PARTICIPANT	\N	PRESENT	0
682536	676618	20298U	PARTICIPANT	\N	PRESENT	0
682537	676618	19695N	PARTICIPANT	\N	PRESENT	0
682538	676618	11099A	PARTICIPANT	\N	PRESENT	0
655139	655138	11048N	PARTICIPANT	\N	PRESENT	0
655141	655138	14121F	PARTICIPANT	\N	PRESENT	0
659829	659410	20074E	PARTICIPANT	\N	PRESENT	0
659830	659410	19415P	PARTICIPANT	\N	PRESENT	0
659831	659410	19747H	PARTICIPANT	\N	PRESENT	0
659832	659410	08034U	PARTICIPANT	\N	PRESENT	0
659833	659410	07029T	PARTICIPANT	\N	PRESENT	0
659834	659410	20140W	PARTICIPANT	\N	PRESENT	0
659835	659410	19399H	PARTICIPANT	\N	PRESENT	0
659836	659166	19569H	PARTICIPANT	\N	PRESENT	0
659837	659166	19683J	PARTICIPANT	\N	PRESENT	0
659838	659410	19581D	PARTICIPANT	\N	PRESENT	0
659839	659410	19467C	PARTICIPANT	\N	PRESENT	0
659840	659410	19447X	PARTICIPANT	\N	PRESENT	0
659841	659410	19621T	PARTICIPANT	\N	PRESENT	0
659842	659410	20086J	PARTICIPANT	\N	PRESENT	0
659843	659410	14059S	PARTICIPANT	\N	PRESENT	0
659844	659410	14123H	PARTICIPANT	\N	PRESENT	0
659845	659410	14133K	PARTICIPANT	\N	PRESENT	0
659846	659410	19563B	PARTICIPANT	\N	PRESENT	0
659847	659410	12028B	PARTICIPANT	\N	PRESENT	0
659848	659410	14237S	PARTICIPANT	\N	PRESENT	0
659861	659166	19591F	PARTICIPANT	\N	PRESENT	0
659893	659410	19387D	PARTICIPANT	\N	PRESENT	0
659894	659410	14147R	PARTICIPANT	\N	PRESENT	0
659895	659410	20098N	PARTICIPANT	\N	PRESENT	0
659896	659410	20058E	PARTICIPANT	\N	PRESENT	0
659897	659410	04042C	PARTICIPANT	\N	PRESENT	0
659898	659410	17737W	PARTICIPANT	\N	PRESENT	0
659899	659410	19719D	PARTICIPANT	\N	PRESENT	0
659900	659410	19413M	PARTICIPANT	\N	PRESENT	0
659901	659410	19251M	PARTICIPANT	\N	PRESENT	0
659902	659410	14259Y	PARTICIPANT	\N	PRESENT	0
659903	659410	20136B	PARTICIPANT	\N	PRESENT	0
659904	659410	20248J	PARTICIPANT	\N	PRESENT	0
659905	659410	20116W	PARTICIPANT	\N	PRESENT	0
659906	659410	14121F	PARTICIPANT	\N	PRESENT	0
659907	659410	11027H	PARTICIPANT	\N	PRESENT	0
659908	659410	20134Y	PARTICIPANT	\N	PRESENT	0
659909	659410	07004J	PARTICIPANT	\N	PRESENT	0
659910	659410	01062T	PARTICIPANT	\N	PRESENT	0
659911	659410	19657G	PARTICIPANT	\N	PRESENT	0
659912	659410	14257W	PARTICIPANT	\N	PRESENT	0
659913	659410	14249W	PARTICIPANT	\N	PRESENT	0
659914	659410	20082E	PARTICIPANT	\N	PRESENT	0
659915	659410	14219Q	PARTICIPANT	\N	PRESENT	0
659916	659166	14281W	PARTICIPANT	\N	PRESENT	0
659917	659410	20088L	PARTICIPANT	\N	PRESENT	0
659918	659410	14223L	PARTICIPANT	\N	PRESENT	0
659919	659410	19713W	PARTICIPANT	\N	PRESENT	0
659920	659410	11026G	PARTICIPANT	\N	PRESENT	0
659921	659410	19703U	PARTICIPANT	\N	PRESENT	0
659922	659410	11067R	PARTICIPANT	\N	PRESENT	0
659923	659410	08056B	PARTICIPANT	\N	PRESENT	0
659924	659410	19675J	PARTICIPANT	\N	PRESENT	0
659930	659410	14217N	PARTICIPANT	\N	PRESENT	0
659931	659360	19443T	PARTICIPANT	\N	PRESENT	0
659932	659360	12041X	PARTICIPANT	\N	PRESENT	0
659933	659360	20072C	PARTICIPANT	\N	PRESENT	0
659934	659360	19565D	PARTICIPANT	\N	PRESENT	0
659935	659360	01058X	PARTICIPANT	\N	PRESENT	0
659936	659360	11027H	PARTICIPANT	\N	PRESENT	0
659937	659360	11054L	PARTICIPANT	\N	PRESENT	0
659938	659360	04042C	PRESIDENT	0	PRESENT	0
659939	659360	11066Q	PARTICIPANT	\N	PRESENT	0
659940	659360	19669L	PARTICIPANT	\N	PRESENT	0
659941	659360	08056B	PARTICIPANT	\N	PRESENT	0
659942	659360	12028B	PARTICIPANT	\N	PRESENT	0
659943	659360	14055N	PARTICIPANT	\N	PRESENT	0
659944	659360	19421M	PARTICIPANT	\N	PRESENT	0
659945	659360	19347U	PARTICIPANT	\N	PRESENT	0
659946	659360	14193X	PARTICIPANT	\N	PRESENT	0
659947	659360	08061X	PARTICIPANT	\N	PRESENT	0
659948	659360	14249W	PARTICIPANT	\N	PRESENT	0
659949	659360	20128B	PARTICIPANT	\N	PRESENT	0
659950	659360	14097Y	PARTICIPANT	\N	PRESENT	0
659951	659360	14059S	PARTICIPANT	\N	PRESENT	0
659952	659360	14133K	PARTICIPANT	\N	PRESENT	0
659953	659360	08034U	PARTICIPANT	\N	PRESENT	0
659954	659360	01062T	PARTICIPANT	\N	PRESENT	0
659955	659360	11041F	PARTICIPANT	\N	PRESENT	0
659956	659360	20042V	PARTICIPANT	\N	PRESENT	0
659957	659360	19721W	PARTICIPANT	\N	PRESENT	0
659958	659360	20064C	PARTICIPANT	\N	PRESENT	0
659959	659360	11064N	PARTICIPANT	\N	PRESENT	0
659960	659360	14267Y	PARTICIPANT	\N	PRESENT	0
659961	659360	11083R	PARTICIPANT	\N	PRESENT	0
659962	659360	19583F	PARTICIPANT	\N	PRESENT	0
659963	659360	14255U	PARTICIPANT	\N	PRESENT	0
659964	659360	08047A	PARTICIPANT	\N	EXCUSE	0
659971	659410	01048V	PARTICIPANT	\N	PRESENT	0
659972	659410	20018V	PARTICIPANT	\N	PRESENT	0
659994	659410	11012A	PARTICIPANT	\N	PRESENT	0
659995	659410	20102Q	PARTICIPANT	\N	PRESENT	0
659996	659410	19569H	PARTICIPANT	\N	PRESENT	0
659997	659410	19679N	PARTICIPANT	\N	PRESENT	0
660000	659410	14071N	PARTICIPANT	\N	PRESENT	0
660003	659410	11097X	PARTICIPANT	\N	PRESENT	0
660008	659410	19762G	PARTICIPANT	\N	PRESENT	0
660009	659410	14031R	PARTICIPANT	\N	PRESENT	0
660010	659410	19758L	PARTICIPANT	\N	PRESENT	0
660011	659410	19820Y	PARTICIPANT	\N	PRESENT	0
660016	659410	20092G	PARTICIPANT	\N	PRESENT	0
660017	659410	19669L	PARTICIPANT	\N	PRESENT	0
660018	659410	19531S	PARTICIPANT	\N	PRESENT	0
660077	659411	14151M	PARTICIPANT	\N	PRESENT	0
660078	659411	04047H	PARTICIPANT	\N	PRESENT	0
660079	659411	04008A	PARTICIPANT	\N	PRESENT	0
660080	659411	20090E	PARTICIPANT	\N	PRESENT	0
660081	659411	19820Y	PARTICIPANT	\N	PRESENT	0
660082	659411	20100N	PARTICIPANT	\N	PRESENT	0
660083	659411	20914V	PARTICIPANT	\N	PRESENT	0
660084	659411	08047A	PARTICIPANT	\N	PRESENT	0
660085	659411	19954N	PARTICIPANT	\N	PRESENT	0
660086	659411	20180F	PARTICIPANT	\N	PRESENT	0
660087	659411	20074E	PARTICIPANT	\N	PRESENT	0
660088	659411	20092G	PARTICIPANT	\N	PRESENT	0
660089	659411	19703U	PARTICIPANT	\N	PRESENT	0
660090	659411	20076G	PARTICIPANT	\N	PRESENT	0
660091	659411	20134Y	PARTICIPANT	\N	PRESENT	0
660092	659411	14097Y	PARTICIPANT	\N	PRESENT	0
660093	659411	19443T	PARTICIPANT	\N	PRESENT	0
660094	659411	19531S	PARTICIPANT	\N	PRESENT	0
660095	659411	20084G	PARTICIPANT	\N	PRESENT	0
660096	659411	19295A	PARTICIPANT	\N	PRESENT	0
660097	659411	11056N	PARTICIPANT	\N	PRESENT	0
660098	659411	19749K	PARTICIPANT	\N	PRESENT	0
660099	659411	07004J	PARTICIPANT	\N	PRESENT	0
660100	659411	20054A	PARTICIPANT	\N	PRESENT	0
660101	659411	19347U	PARTICIPANT	\N	PRESENT	0
660102	659411	19747H	PARTICIPANT	\N	PRESENT	0
660103	659411	19629C	PARTICIPANT	\N	PRESENT	0
660104	659411	19585H	PARTICIPANT	\N	PRESENT	0
660105	659411	14215L	PARTICIPANT	\N	PRESENT	0
660106	659411	07029T	PARTICIPANT	\N	PRESENT	0
660107	659411	20038A	PARTICIPANT	\N	PRESENT	0
660108	659411	19447X	PARTICIPANT	\N	PRESENT	0
660109	659411	14187A	PARTICIPANT	\N	PRESENT	0
660110	659411	14147R	PARTICIPANT	\N	PRESENT	0
660111	659411	20032T	PARTICIPANT	\N	PRESENT	0
660112	659411	19565D	PARTICIPANT	\N	PRESENT	0
660113	659411	20102Q	PARTICIPANT	\N	PRESENT	0
660114	659411	04085P	PARTICIPANT	\N	PRESENT	0
660115	659411	14179A	PARTICIPANT	\N	PRESENT	0
660116	659411	14038Y	PARTICIPANT	\N	PRESENT	0
660117	659411	14071N	PARTICIPANT	\N	PRESENT	0
660118	659411	11090Q	PARTICIPANT	\N	PRESENT	0
660119	659411	19489J	PARTICIPANT	\N	PRESENT	0
660128	659411	19467C	PARTICIPANT	\N	PRESENT	0
660121	659411	19503N	PARTICIPANT	\N	PRESENT	0
660122	659411	19631V	PARTICIPANT	\N	PRESENT	0
660123	659411	20110Q	PARTICIPANT	\N	PRESENT	0
660124	659411	08061X	PARTICIPANT	\N	PRESENT	0
660125	659411	11072N	PARTICIPANT	\N	PRESENT	0
660126	659411	18193Q	PARTICIPANT	\N	PRESENT	0
660127	659411	19301E	PARTICIPANT	\N	PRESENT	0
660129	659411	19387D	PARTICIPANT	\N	PRESENT	0
660130	659411	14069U	PARTICIPANT	\N	PRESENT	0
660131	659411	14219Q	PARTICIPANT	\N	PRESENT	0
660132	659411	19725B	PARTICIPANT	\N	PRESENT	0
683537	682962	11054L	PARTICIPANT	\N	EXCUSE	0
685429	683642	01043Q	PARTICIPANT	\N	EXCUSE	0
688845	686745	19507S	PARTICIPANT	\N	PRESENT	0
695279	694841	14021P	PARTICIPANT	\N	EXCUSE	0
695280	694841	19729F	PARTICIPANT	\N	EXCUSE	0
695842	694042	14331P	PARTICIPANT	\N	PRESENT	0
695843	694042	01025N	PRESIDENT	0	PRESENT	0
695844	694042	19629C	PRESIDENT	1	PRESENT	0
695846	694042	14259Y	PARTICIPANT	\N	PRESENT	0
695868	694042	19954N	PARTICIPANT	\N	PRESENT	0
695872	694042	11056N	PARTICIPANT	\N	PRESENT	0
695873	694042	20248J	PARTICIPANT	\N	PRESENT	0
695878	694042	14329V	PARTICIPANT	\N	PRESENT	0
695879	694042	19421M	PARTICIPANT	\N	PRESENT	0
695880	694042	19383Y	PARTICIPANT	\N	PRESENT	0
695885	694042	20110Q	PARTICIPANT	\N	PRESENT	0
695886	694042	19489J	PARTICIPANT	\N	PRESENT	0
695890	694042	19467C	PARTICIPANT	\N	PRESENT	0
695892	694042	14189C	PARTICIPANT	\N	PRESENT	0
695895	694042	14001X	PARTICIPANT	\N	PRESENT	0
704364	704300	20104S	PRESIDENT	0	PRESENT	0
704365	704300	19387D	PARTICIPANT	\N	PRESENT	0
704366	704300	19768N	PARTICIPANT	\N	PRESENT	0
704367	704300	20046A	PARTICIPANT	\N	PRESENT	0
704368	704300	20076G	PARTICIPANT	\N	EXCUSE	0
704369	704300	20094J	PARTICIPANT	\N	PRESENT	0
704370	704300	20914V	PARTICIPANT	\N	EXCUSE	0
704371	704300	19820Y	PARTICIPANT	\N	PRESENT	0
704372	704300	05012A	PARTICIPANT	\N	EXCUSE	0
704373	704300	19745F	PARTICIPANT	\N	PRESENT	0
704374	704300	20118Y	PARTICIPANT	\N	PRESENT	0
704375	704300	14229S	PARTICIPANT	\N	PRESENT	0
704441	704300	14259Y	PARTICIPANT	\N	PRESENT	0
704442	704300	14205J	PARTICIPANT	\N	PRESENT	0
711305	708188	20152B	PARTICIPANT	\N	PRESENT	0
711306	708188	19762G	PARTICIPANT	\N	PRESENT	0
711307	708188	14211G	PARTICIPANT	\N	PRESENT	0
711308	708188	14207L	PARTICIPANT	\N	PRESENT	0
711309	708188	20054A	PARTICIPANT	\N	PRESENT	0
711310	708188	20126Y	PARTICIPANT	\N	PRESENT	0
711311	708188	11027H	PARTICIPANT	\N	PRESENT	0
711312	708188	14059S	PARTICIPANT	\N	PRESENT	0
711313	708188	14281W	PARTICIPANT	\N	PRESENT	0
711314	708188	20090E	PARTICIPANT	\N	PRESENT	0
711315	708188	19729F	PARTICIPANT	\N	PRESENT	0
711316	708188	20102Q	PARTICIPANT	\N	PRESENT	0
711317	708188	20046A	PARTICIPANT	\N	PRESENT	0
711318	708188	97011G	PARTICIPANT	\N	PRESENT	0
711319	708188	20132W	PARTICIPANT	\N	PRESENT	0
711320	708188	14213J	PARTICIPANT	\N	PRESENT	0
711321	708188	20072C	PARTICIPANT	\N	PRESENT	0
711322	708188	14223L	PARTICIPANT	\N	PRESENT	0
711323	708188	18193Q	PARTICIPANT	\N	PRESENT	0
711324	708188	19703U	PARTICIPANT	\N	PRESENT	0
711325	708188	08028W	PARTICIPANT	\N	PRESENT	0
711326	708188	08012N	PARTICIPANT	\N	PRESENT	0
711327	708188	14123H	PARTICIPANT	\N	PRESENT	0
711328	708188	19527W	PARTICIPANT	\N	PRESENT	0
711329	708188	14253S	PARTICIPANT	\N	PRESENT	0
711330	708188	20094J	PARTICIPANT	\N	PRESENT	0
711331	708188	20180F	PARTICIPANT	\N	PRESENT	0
711332	708188	14031R	PARTICIPANT	\N	PRESENT	0
711333	708188	20038A	PARTICIPANT	\N	PRESENT	0
711334	708188	14221J	PARTICIPANT	\N	PRESENT	0
711335	708188	19515S	PARTICIPANT	\N	PRESENT	0
711336	708188	20042V	PARTICIPANT	\N	PRESENT	0
711337	708188	14267Y	PARTICIPANT	\N	PRESENT	0
711338	708188	19723Y	PARTICIPANT	\N	PRESENT	0
711339	708188	19691J	PARTICIPANT	\N	PRESENT	0
711340	708188	19745F	PARTICIPANT	\N	PRESENT	0
711341	708188	17367Q	PARTICIPANT	\N	PRESENT	0
711342	708188	20084G	PARTICIPANT	\N	PRESENT	0
711343	708188	11099A	PARTICIPANT	\N	PRESENT	0
711344	708188	19467C	PARTICIPANT	\N	PRESENT	0
711345	705810	20114U	PARTICIPANT	\N	PRESENT	0
711346	708188	20144B	PARTICIPANT	\N	PRESENT	0
711347	708188	19739H	PARTICIPANT	\N	PRESENT	0
711348	708188	14327T	PARTICIPANT	\N	PRESENT	0
711349	708188	20098N	PARTICIPANT	\N	PRESENT	0
711350	708188	19369B	PARTICIPANT	\N	PRESENT	0
711351	708188	14089Y	PARTICIPANT	\N	PRESENT	0
711352	708188	19826F	PARTICIPANT	\N	PRESENT	0
711353	708188	20040T	PARTICIPANT	\N	PRESENT	0
711354	708188	14083S	PARTICIPANT	\N	PRESENT	0
711355	708188	19367Y	PARTICIPANT	\N	PRESENT	0
711356	708188	19347U	PARTICIPANT	\N	PRESENT	0
711357	708188	14215L	PARTICIPANT	\N	PRESENT	0
711358	708188	20034V	PARTICIPANT	\N	PRESENT	0
711359	708188	19531S	PARTICIPANT	\N	PRESENT	0
711360	708188	20026V	PARTICIPANT	\N	PRESENT	0
711361	708188	19697Q	PARTICIPANT	\N	PRESENT	0
711362	708188	14069U	PARTICIPANT	\N	PRESENT	0
711363	708188	20142Y	PARTICIPANT	\N	PRESENT	0
711364	708188	19621T	PARTICIPANT	\N	PRESENT	0
711365	708188	19569H	PARTICIPANT	\N	PRESENT	0
711366	705810	19599P	PARTICIPANT	\N	PRESENT	0
711367	708188	08010L	PARTICIPANT	\N	PRESENT	0
711368	708188	04092N	PARTICIPANT	\N	PRESENT	0
711369	708188	11048N	PARTICIPANT	\N	PRESENT	0
711370	705810	14231L	PARTICIPANT	\N	PRESENT	0
711371	708188	95041E	PARTICIPANT	\N	PRESENT	0
711372	708188	19657G	PARTICIPANT	\N	PRESENT	0
711373	708188	14151M	PARTICIPANT	\N	PRESENT	0
711374	708188	20298U	PARTICIPANT	\N	PRESENT	0
711375	708188	99004R	PARTICIPANT	\N	PRESENT	0
711376	708188	19479G	PARTICIPANT	\N	PRESENT	0
711377	708188	19631V	PARTICIPANT	\N	PRESENT	0
711378	708188	19725B	PARTICIPANT	\N	PRESENT	0
711379	708188	19251M	PARTICIPANT	\N	PRESENT	0
711380	704238	19747H	PARTICIPANT	\N	PRESENT	0
711381	704238	11056N	PARTICIPANT	\N	PRESENT	0
711382	704238	14259Y	PARTICIPANT	\N	PRESENT	0
711383	704238	99004R	PARTICIPANT	\N	PRESENT	0
711384	704238	20018V	PARTICIPANT	\N	PRESENT	0
711385	704238	11040E	PARTICIPANT	\N	EXCUSE	0
711386	704238	20042V	PARTICIPANT	\N	EXCUSE	0
711387	704238	20144B	PARTICIPANT	\N	EXCUSE	0
711388	704238	20132W	PARTICIPANT	\N	EXCUSE	0
711389	708188	20252E	PARTICIPANT	\N	PRESENT	0
711390	704238	95063L	PARTICIPANT	\N	EXCUSE	0
711391	704238	11097X	PARTICIPANT	\N	EXCUSE	0
711392	704238	01028R	PARTICIPANT	\N	EXCUSE	0
711393	708188	19619A	PARTICIPANT	\N	PRESENT	0
711395	704258	01048V	PARTICIPANT	\N	PRESENT	0
711396	704258	19735D	PARTICIPANT	\N	PRESENT	0
711397	704258	11067R	PARTICIPANT	\N	PRESENT	0
711400	708188	14229S	PARTICIPANT	\N	PRESENT	0
711401	708188	11110B	PARTICIPANT	\N	PRESENT	0
711402	708188	18083K	PARTICIPANT	\N	PRESENT	0
711403	708188	14026U	PARTICIPANT	\N	PRESENT	0
711404	708188	20062A	PARTICIPANT	\N	PRESENT	0
711408	708188	20024T	PARTICIPANT	\N	PRESENT	0
711406	708188	19747H	PARTICIPANT	\N	PRESENT	0
711407	705810	20066E	PARTICIPANT	\N	PRESENT	0
711409	708188	10015M	PARTICIPANT	\N	PRESENT	0
711410	708188	04057K	PARTICIPANT	\N	PRESENT	0
711411	708188	20100N	PARTICIPANT	\N	PRESENT	0
711412	708188	20064C	PARTICIPANT	\N	PRESENT	0
711413	708188	20082E	PARTICIPANT	\N	PRESENT	0
711415	711414	20094J	PARTICIPANT	\N	PRESENT	0
711416	711414	20104S	PARTICIPANT	\N	PRESENT	0
711417	711414	19820Y	PARTICIPANT	\N	PRESENT	0
711418	711414	20914V	PARTICIPANT	\N	PRESENT	0
711419	711414	05012A	PRESIDENT	0	PRESENT	0
711420	711414	19745F	PARTICIPANT	\N	PRESENT	0
711421	711414	14205J	PARTICIPANT	\N	PRESENT	0
711422	708188	04045F	PARTICIPANT	\N	PRESENT	0
711423	708188	20060X	PARTICIPANT	\N	PRESENT	0
711424	708188	20150Y	PARTICIPANT	\N	PRESENT	0
711425	708188	11026G	PARTICIPANT	\N	PRESENT	0
711426	708188	14073Q	PARTICIPANT	\N	PRESENT	0
711427	708188	20112S	PARTICIPANT	\N	PRESENT	0
711428	708188	20266L	PARTICIPANT	\N	PRESENT	0
711429	708188	01057W	PARTICIPANT	\N	PRESENT	0
711430	708188	11033F	PARTICIPANT	\N	PRESENT	0
711431	705810	20098N	PARTICIPANT	\N	PRESENT	0
711432	711251	19515S	PRESIDENT	0	PRESENT	0
711433	711251	19467C	PARTICIPANT	\N	PRESENT	0
691909	690827	20042V	PARTICIPANT	\N	PRESENT	0
691910	690827	14255U	PARTICIPANT	\N	PRESENT	0
691911	690827	19721W	PARTICIPANT	\N	PRESENT	0
691912	690827	14267Y	PARTICIPANT	\N	PRESENT	0
691913	690827	11070L	PARTICIPANT	\N	PRESENT	0
691914	690827	14327T	PARTICIPANT	\N	PRESENT	0
691915	690827	17229F	PARTICIPANT	\N	PRESENT	0
691916	690827	01024M	PARTICIPANT	\N	PRESENT	0
691917	690827	14189C	PARTICIPANT	\N	PRESENT	0
691918	690827	14042U	PARTICIPANT	\N	PRESENT	0
691919	690827	20132W	PARTICIPANT	\N	PRESENT	0
691920	690827	20248J	PARTICIPANT	\N	PRESENT	0
691921	690827	01025N	PARTICIPANT	\N	PRESENT	0
691933	690827	12041X	PARTICIPANT	\N	PRESENT	0
691923	690827	20052X	PARTICIPANT	\N	PRESENT	0
691924	690827	19691J	PARTICIPANT	\N	PRESENT	0
691925	690827	19577H	PARTICIPANT	\N	PRESENT	0
691926	690827	19441R	PARTICIPANT	\N	PRESENT	0
691927	690827	19369B	PARTICIPANT	\N	PRESENT	0
691928	690827	19739H	PARTICIPANT	\N	PRESENT	0
691929	690827	19319Q	PARTICIPANT	\N	PRESENT	0
691930	690827	19745F	PARTICIPANT	\N	PRESENT	0
691931	690827	19479G	PARTICIPANT	\N	PRESENT	0
691932	690827	19735D	PARTICIPANT	\N	PRESENT	0
691934	690827	19695N	PARTICIPANT	\N	PRESENT	0
691935	690827	19631V	PARTICIPANT	\N	PRESENT	0
691936	690827	19549D	PARTICIPANT	\N	PRESENT	0
691937	690827	20094J	PARTICIPANT	\N	PRESENT	0
691938	690827	08060W	PARTICIPANT	\N	PRESENT	0
691939	690827	20114U	PARTICIPANT	\N	PRESENT	0
691940	690827	20080C	PARTICIPANT	\N	PRESENT	0
691941	690827	12028B	PARTICIPANT	\N	PRESENT	0
691942	690827	11027H	PARTICIPANT	\N	PRESENT	0
691943	690827	20088L	PARTICIPANT	\N	PRESENT	0
691944	690827	20018V	PARTICIPANT	\N	PRESENT	0
691945	690827	14109K	PARTICIPANT	\N	PRESENT	0
691946	690827	19295A	PARTICIPANT	\N	PRESENT	0
691947	690827	20112S	PARTICIPANT	\N	PRESENT	0
691948	690827	11074Q	PARTICIPANT	\N	PRESENT	0
691949	690827	01062T	PARTICIPANT	\N	PRESENT	0
691950	690827	11041F	PARTICIPANT	\N	PRESENT	0
691951	690827	19563B	PARTICIPANT	\N	PRESENT	0
691952	690827	14231L	PARTICIPANT	\N	PRESENT	0
691953	690827	19585H	PARTICIPANT	\N	PRESENT	0
691954	690827	19619A	PARTICIPANT	\N	PRESENT	0
691955	690827	19647E	PARTICIPANT	\N	PRESENT	0
691956	690827	14229S	PARTICIPANT	\N	PRESENT	0
691957	690827	14121F	PARTICIPANT	\N	PRESENT	0
691958	690827	19333N	PARTICIPANT	\N	PRESENT	0
691959	690827	11054L	PARTICIPANT	\N	PRESENT	0
691960	690827	19683J	PARTICIPANT	\N	PRESENT	0
691961	690827	19713W	PARTICIPANT	\N	PRESENT	0
691962	690827	19693L	PARTICIPANT	\N	PRESENT	0
691963	690827	19621T	PARTICIPANT	\N	PRESENT	0
691964	690827	19711U	PARTICIPANT	\N	PRESENT	0
691965	690827	01058X	PARTICIPANT	\N	PRESENT	0
691966	690827	99004R	PARTICIPANT	\N	PRESENT	0
691967	690827	04035D	PARTICIPANT	\N	PRESENT	0
691968	690827	19575F	PARTICIPANT	\N	PRESENT	0
691969	690827	14038Y	PARTICIPANT	\N	PRESENT	0
691970	690827	20058E	PARTICIPANT	\N	PRESENT	0
691971	690827	20086J	PARTICIPANT	\N	PRESENT	0
691972	690827	20044X	PARTICIPANT	\N	PRESENT	0
691973	690827	19467C	PARTICIPANT	\N	PRESENT	0
691974	690827	20034V	PARTICIPANT	\N	PRESENT	0
691975	690827	19723Y	PARTICIPANT	\N	PRESENT	0
691976	690827	14173T	PARTICIPANT	\N	PRESENT	0
691977	690827	19447X	PARTICIPANT	\N	PRESENT	0
691978	690827	20038A	PARTICIPANT	\N	PRESENT	0
691979	690827	19573D	PARTICIPANT	\N	PRESENT	0
691980	690827	19709B	PARTICIPANT	\N	PRESENT	0
691981	690827	19515S	PARTICIPANT	\N	PRESENT	0
691982	690827	20056C	PARTICIPANT	\N	PRESENT	0
691983	690827	20980G	PARTICIPANT	\N	PRESENT	0
691984	690827	20096L	PARTICIPANT	\N	PRESENT	0
691985	690827	20098N	PARTICIPANT	\N	PRESENT	0
691986	690827	14033T	PARTICIPANT	\N	PRESENT	0
691987	690827	20180F	PARTICIPANT	\N	PRESENT	0
691988	690827	14031R	PARTICIPANT	\N	PRESENT	0
691989	690827	19667J	PARTICIPANT	\N	PRESENT	0
691990	690827	11080N	PARTICIPANT	\N	PRESENT	0
691991	690827	14259Y	PARTICIPANT	\N	PRESENT	0
691992	690827	01057W	PARTICIPANT	\N	PRESENT	0
691993	690827	17367Q	PARTICIPANT	\N	PRESENT	0
691994	690827	19643A	PARTICIPANT	\N	PRESENT	0
691995	690827	04071H	PARTICIPANT	\N	PRESENT	0
691996	690827	14169X	PARTICIPANT	\N	PRESENT	0
691997	690827	14223L	PARTICIPANT	\N	PRESENT	0
691998	690827	19679N	PARTICIPANT	\N	PRESENT	0
691999	690827	20076G	PARTICIPANT	\N	PRESENT	0
692000	690827	20074E	PARTICIPANT	\N	PRESENT	0
692001	690827	20078J	PARTICIPANT	\N	PRESENT	0
692002	690827	18083K	PARTICIPANT	\N	PRESENT	0
692003	690827	17637T	PARTICIPANT	\N	PRESENT	0
692004	690827	11101A	PARTICIPANT	\N	PRESENT	0
692005	690827	19703U	PARTICIPANT	\N	PRESENT	0
692006	690827	14026U	PARTICIPANT	\N	PRESENT	0
692007	690827	04047H	PARTICIPANT	\N	PRESENT	0
692008	690827	08010L	PARTICIPANT	\N	PRESENT	0
692009	690827	19747H	PARTICIPANT	\N	PRESENT	0
692010	690827	08034U	PARTICIPANT	\N	PRESENT	0
692011	690827	14133K	PARTICIPANT	\N	PRESENT	0
692012	690827	04092N	PARTICIPANT	\N	PRESENT	0
692013	690827	11048N	PARTICIPANT	\N	PRESENT	0
692014	690827	19415P	PARTICIPANT	\N	PRESENT	0
692015	690827	11097X	PARTICIPANT	\N	PRESENT	0
692016	690827	14071N	PARTICIPANT	\N	PRESENT	0
692017	690827	14187A	PARTICIPANT	\N	PRESENT	0
692018	690827	04033B	PARTICIPANT	\N	PRESENT	0
692019	690827	08028W	PARTICIPANT	\N	PRESENT	0
692020	690827	01048V	PARTICIPANT	\N	PRESENT	0
692021	690827	19782L	PARTICIPANT	\N	PRESENT	0
692022	690827	11043H	PARTICIPANT	\N	PRESENT	0
692023	690827	11099A	PARTICIPANT	\N	PRESENT	0
692024	690827	11065P	PARTICIPANT	\N	PRESENT	0
692025	690827	10015M	PARTICIPANT	\N	PRESENT	0
692026	690827	20914V	PARTICIPANT	\N	PRESENT	0
692027	690827	04042C	PARTICIPANT	\N	PRESENT	0
692028	690827	08069G	PARTICIPANT	\N	PRESENT	0
692029	690827	19687N	PARTICIPANT	\N	PRESENT	0
692030	690827	11031D	PARTICIPANT	\N	PRESENT	0
692031	690827	14123H	PARTICIPANT	\N	PRESENT	0
692032	690827	14215L	PARTICIPANT	\N	PRESENT	0
692033	690827	19659J	PARTICIPANT	\N	PRESENT	0
692034	690827	19421M	PARTICIPANT	\N	PRESENT	0
692035	690827	14053L	PARTICIPANT	\N	PRESENT	0
692036	690827	11083R	PARTICIPANT	\N	PRESENT	0
692037	690827	19701S	PARTICIPANT	\N	PRESENT	0
692038	690827	20106U	PARTICIPANT	\N	PRESENT	0
692039	690827	20146D	PARTICIPANT	\N	PRESENT	0
692040	690827	14069U	PARTICIPANT	\N	PRESENT	0
692041	690827	20150Y	PARTICIPANT	\N	PRESENT	0
692042	690827	04043D	PARTICIPANT	\N	PRESENT	0
692043	690827	19349W	PARTICIPANT	\N	PRESENT	0
692044	690827	11090Q	PARTICIPANT	\N	PRESENT	0
692045	690827	05012A	PARTICIPANT	\N	PRESENT	0
692046	690827	04045F	PARTICIPANT	\N	PRESENT	0
692047	690827	20022R	PARTICIPANT	\N	PRESENT	0
692048	690827	20068G	PARTICIPANT	\N	PRESENT	0
692049	690827	14037X	PARTICIPANT	\N	PRESENT	0
692050	690827	14193X	PARTICIPANT	\N	PRESENT	0
692051	690827	19798U	PARTICIPANT	\N	PRESENT	0
692052	690827	19525U	PARTICIPANT	\N	PRESENT	0
692053	690827	10006L	PARTICIPANT	\N	PRESENT	0
692054	690827	14251Q	PARTICIPANT	\N	PRESENT	0
692055	690827	19533U	PARTICIPANT	\N	PRESENT	0
692056	690827	14221J	PARTICIPANT	\N	PRESENT	0
692057	690827	04057K	PARTICIPANT	\N	PRESENT	0
692058	690827	14105F	PARTICIPANT	\N	PRESENT	0
692059	690827	14111D	PARTICIPANT	\N	PRESENT	0
692060	690827	19671E	PARTICIPANT	\N	PRESENT	0
692061	690827	14211G	PARTICIPANT	\N	PRESENT	0
692062	690827	95041E	PARTICIPANT	\N	PRESENT	0
692063	690827	20120S	PARTICIPANT	\N	PRESENT	0
692064	690827	20252E	PARTICIPANT	\N	PRESENT	0
692065	690827	19717B	PARTICIPANT	\N	PRESENT	0
692066	690827	11012A	PARTICIPANT	\N	PRESENT	0
692067	690827	14217N	PARTICIPANT	\N	PRESENT	0
692068	690827	20072C	PARTICIPANT	\N	PRESENT	0
692069	690827	14357A	PARTICIPANT	\N	PRESENT	0
692070	690827	97011G	PARTICIPANT	\N	PRESENT	0
688825	688745	12016W	PARTICIPANT	\N	EXCUSE	0
704978	704078	19762G	PARTICIPANT	\N	PRESENT	0
704979	704078	19383Y	PARTICIPANT	\N	PRESENT	0
704980	704078	14026U	PARTICIPANT	\N	PRESENT	0
704981	704078	19631V	PARTICIPANT	\N	PRESENT	0
704982	704078	14357A	PARTICIPANT	\N	PRESENT	0
704983	704078	19549D	PARTICIPANT	\N	PRESENT	0
704984	704078	20060X	PARTICIPANT	\N	PRESENT	0
704985	704078	20062A	PARTICIPANT	\N	PRESENT	0
704986	704078	14059S	PARTICIPANT	\N	PRESENT	0
704987	704078	20070A	PARTICIPANT	\N	PRESENT	0
704988	704078	11027H	PARTICIPANT	\N	PRESENT	0
704989	704078	20124W	PARTICIPANT	\N	PRESENT	0
704990	704078	20054A	PARTICIPANT	\N	PRESENT	0
704991	704078	19251M	PARTICIPANT	\N	PRESENT	0
704992	704078	14151M	PARTICIPANT	\N	PRESENT	0
704993	704078	11074Q	PARTICIPANT	\N	PRESENT	0
704994	704078	14213J	PARTICIPANT	\N	PRESENT	0
704995	704078	11110B	PARTICIPANT	\N	PRESENT	0
704996	704078	19647E	PARTICIPANT	\N	PRESENT	0
704997	704078	20148F	PARTICIPANT	\N	PRESENT	0
704998	704078	14281W	PARTICIPANT	\N	PRESENT	0
704999	704078	20108W	PARTICIPANT	\N	PRESENT	0
705000	704078	20104S	PARTICIPANT	\N	PRESENT	0
705001	704078	19725B	PARTICIPANT	\N	PRESENT	0
705002	704078	19399H	PARTICIPANT	\N	PRESENT	0
705003	704078	19820Y	PARTICIPANT	\N	PRESENT	0
705004	704078	08045X	PARTICIPANT	\N	PRESENT	0
705005	704078	07029T	PARTICIPANT	\N	PRESENT	0
705006	704078	20114U	PARTICIPANT	\N	PRESENT	0
705007	704078	19693L	PARTICIPANT	\N	PRESENT	0
705008	704078	19531S	PARTICIPANT	\N	PRESENT	0
705009	704078	14121F	PARTICIPANT	\N	PRESENT	0
705010	704078	01048V	PARTICIPANT	\N	PRESENT	0
705011	704078	19715Y	PARTICIPANT	\N	PRESENT	0
705012	704078	14038Y	PARTICIPANT	\N	PRESENT	0
705013	704078	20058E	PARTICIPANT	\N	PRESENT	0
705014	704078	19723Y	PARTICIPANT	\N	PRESENT	0
705015	704078	19467C	PARTICIPANT	\N	PRESENT	0
705016	704078	14229S	PARTICIPANT	\N	PRESENT	0
705017	704078	20082E	PARTICIPANT	\N	PRESENT	0
705018	704078	20056C	PARTICIPANT	\N	PRESENT	0
705019	704078	11045K	PARTICIPANT	\N	PRESENT	0
705020	704078	20098N	PARTICIPANT	\N	PRESENT	0
705021	704078	01028R	PARTICIPANT	\N	PRESENT	0
705022	704078	19669L	PARTICIPANT	\N	PRESENT	0
705023	704078	14021P	PARTICIPANT	\N	PRESENT	0
705024	704078	19573D	PARTICIPANT	\N	PRESENT	0
705025	704078	14257W	PARTICIPANT	\N	PRESENT	0
705026	704078	20030R	PARTICIPANT	\N	PRESENT	0
705107	704327	19583F	PARTICIPANT	\N	EXCUSE	0
705114	705112	19533U	PARTICIPANT	\N	PRESENT	0
705124	705122	19533U	PARTICIPANT	\N	PRESENT	0
705458	705456	19335Q	PARTICIPANT	\N	PRESENT	0
705459	705456	20056C	PARTICIPANT	\N	PRESENT	0
705460	705456	20980G	PARTICIPANT	\N	PRESENT	0
705461	705456	20026V	PARTICIPANT	\N	PRESENT	0
705462	705456	14109K	PARTICIPANT	\N	PRESENT	0
705463	705456	20106U	PARTICIPANT	\N	PRESENT	0
705469	699132	17023S	PARTICIPANT	\N	EXCUSE	0
705560	705105	19820Y	PARTICIPANT	\N	PRESENT	0
705562	705105	05012A	PARTICIPANT	\N	PRESENT	0
705565	705105	19745F	PARTICIPANT	\N	PRESENT	0
705598	705105	14229S	PARTICIPANT	\N	PRESENT	0
705599	705105	14169X	PARTICIPANT	\N	PRESENT	0
705601	705105	20914V	PARTICIPANT	\N	PRESENT	0
705618	705105	20128B	PARTICIPANT	\N	PRESENT	0
705619	705105	20094J	PARTICIPANT	\N	PRESENT	0
705790	699132	19673G	PARTICIPANT	\N	EXCUSE	0
705791	704140	19693L	PARTICIPANT	\N	PRESENT	0
705792	704140	20098N	PARTICIPANT	\N	PRESENT	0
705793	704140	19798U	PARTICIPANT	\N	PRESENT	0
705794	704140	14030Q	PRESIDENT	0	PRESENT	0
705795	704140	11045K	PARTICIPANT	\N	PRESENT	0
705796	704083	95063L	PARTICIPANT	\N	PRESENT	0
705797	704140	14109K	PARTICIPANT	\N	PRESENT	0
705798	704140	20066E	PARTICIPANT	\N	PRESENT	0
705799	699132	19717B	PRESIDENT	0	PRESENT	0
705800	699132	19631V	PARTICIPANT	\N	PRESENT	0
705801	699132	19577H	PARTICIPANT	\N	PRESENT	1
705802	699132	20034V	PARTICIPANT	\N	PRESENT	0
705803	699132	19715Y	PARTICIPANT	\N	PRESENT	0
705804	699132	14059S	PARTICIPANT	\N	PRESENT	0
705862	704083	08045X	PARTICIPANT	\N	PRESENT	0
705806	699132	11072N	PARTICIPANT	\N	PRESENT	0
705807	699132	20148F	PARTICIPANT	\N	PRESENT	0
705808	704140	11031D	PARTICIPANT	\N	PRESENT	0
705809	699132	97011G	PARTICIPANT	\N	PRESENT	0
705819	704185	14231L	PARTICIPANT	\N	PRESENT	0
705820	704185	08010L	PARTICIPANT	\N	PRESENT	0
705822	704185	14327T	PARTICIPANT	\N	PRESENT	0
705824	704185	14071N	PARTICIPANT	\N	PRESENT	0
705826	704185	20062A	PARTICIPANT	\N	PRESENT	0
705827	704185	14187A	PARTICIPANT	\N	PRESENT	0
705828	704185	19573D	PARTICIPANT	\N	PRESENT	0
705829	704185	01057W	PARTICIPANT	\N	PRESENT	0
705830	704185	20022R	PARTICIPANT	\N	PRESENT	0
705831	704185	19758L	PARTICIPANT	\N	PRESENT	0
705832	704185	14151M	PARTICIPANT	\N	PRESENT	0
705837	704185	20110Q	PARTICIPANT	\N	EXCUSE	0
705838	704185	19782L	PARTICIPANT	\N	EXCUSE	0
705839	704185	20090E	PARTICIPANT	\N	EXCUSE	0
705840	704185	14053L	PARTICIPANT	\N	EXCUSE	0
705841	704185	14217N	PARTICIPANT	\N	EXCUSE	0
705842	704185	14215L	PARTICIPANT	\N	EXCUSE	0
705843	704185	19820Y	PARTICIPANT	\N	EXCUSE	0
705844	704185	20120S	PARTICIPANT	\N	EXCUSE	0
705845	704185	19447X	PARTICIPANT	\N	EXCUSE	0
705846	704185	19489J	PARTICIPANT	\N	EXCUSE	0
705847	704185	19563B	PARTICIPANT	\N	EXCUSE	0
705848	704185	17637T	PARTICIPANT	\N	EXCUSE	0
705849	704185	05012A	PARTICIPANT	\N	EXCUSE	0
705850	704185	14229S	PARTICIPANT	\N	EXCUSE	0
705851	704185	20058E	PARTICIPANT	\N	EXCUSE	0
705852	704185	20084G	PARTICIPANT	\N	EXCUSE	0
705857	704185	04045F	PARTICIPANT	\N	PRESENT	0
705861	704185	19826F	PARTICIPANT	\N	PRESENT	0
705863	704083	19347U	PARTICIPANT	\N	PRESENT	0
705864	704083	19531S	PARTICIPANT	\N	PRESENT	0
705865	704083	10006L	PARTICIPANT	\N	PRESENT	0
705866	704140	19715Y	PARTICIPANT	\N	EXCUSE	0
705867	704140	20118Y	PARTICIPANT	\N	EXCUSE	0
705868	704140	20024T	PARTICIPANT	\N	EXCUSE	0
705869	704140	20080C	PARTICIPANT	\N	EXCUSE	0
705870	704083	20066E	PARTICIPANT	\N	PRESENT	0
705871	704083	18193Q	PARTICIPANT	\N	PRESENT	0
705872	704083	14038Y	PARTICIPANT	\N	PRESENT	0
705873	704083	14179A	PARTICIPANT	\N	PRESENT	0
705874	704083	19693L	PARTICIPANT	\N	PRESENT	0
705875	704083	19798U	PARTICIPANT	\N	PRESENT	0
705876	704083	19565D	PARTICIPANT	\N	PRESENT	0
705878	704083	20032T	PARTICIPANT	\N	PRESENT	0
705879	704083	07033P	PARTICIPANT	\N	PRESENT	0
705880	704083	20128B	PARTICIPANT	\N	PRESENT	0
705881	704083	20286Q	PARTICIPANT	\N	PRESENT	0
705885	704083	17737W	PARTICIPANT	\N	PRESENT	0
705886	704083	04045F	PARTICIPANT	\N	PRESENT	0
705887	704083	20914V	PARTICIPANT	\N	PRESENT	0
705888	704083	19685L	PARTICIPANT	\N	PRESENT	0
705889	704083	14001X	PARTICIPANT	\N	PRESENT	0
705890	704083	14205J	PARTICIPANT	\N	PRESENT	0
705891	704083	20070A	PARTICIPANT	\N	PRESENT	0
705892	704083	19335Q	PARTICIPANT	\N	PRESENT	0
705893	704083	14207L	PARTICIPANT	\N	PRESENT	0
705894	704083	19691J	PARTICIPANT	\N	PRESENT	0
705895	704083	19479G	PARTICIPANT	\N	PRESENT	0
705906	704084	86034E	PARTICIPANT	\N	PRESENT	0
705907	704218	11067R	PARTICIPANT	\N	PRESENT	0
705908	704218	04092N	PARTICIPANT	\N	PRESENT	0
705909	704218	14355X	PARTICIPANT	\N	PRESENT	0
705910	704218	19798U	PARTICIPANT	\N	PRESENT	0
705911	704218	11097X	PARTICIPANT	\N	PRESENT	0
705912	704218	20040T	PARTICIPANT	\N	PRESENT	0
705913	704218	19691J	PARTICIPANT	\N	PRESENT	0
705914	704218	14223L	PARTICIPANT	\N	PRESENT	0
705915	704218	20148F	PARTICIPANT	\N	PRESENT	0
705916	704218	14026U	PARTICIPANT	\N	PRESENT	0
705917	704218	19553Y	PARTICIPANT	\N	PRESENT	0
705918	704218	19703U	PARTICIPANT	\N	PRESENT	0
703617	701647	17637T	PARTICIPANT	\N	PRESENT	0
703621	701647	20034V	PARTICIPANT	\N	PRESENT	0
703622	701647	20126Y	PARTICIPANT	\N	PRESENT	0
703623	701647	08069G	PARTICIPANT	\N	PRESENT	0
703624	701647	20048C	PARTICIPANT	\N	PRESENT	0
703626	701647	20022R	PARTICIPANT	\N	PRESENT	0
703628	701647	20054A	PARTICIPANT	\N	PRESENT	0
703629	701647	20094J	PARTICIPANT	\N	PRESENT	0
703636	701647	08015R	PARTICIPANT	\N	PRESENT	0
703640	701647	19565D	PARTICIPANT	\N	PRESENT	0
703641	701647	19762G	PARTICIPANT	\N	PRESENT	0
703646	701647	20066E	PARTICIPANT	\N	PRESENT	0
703647	701647	08034U	PARTICIPANT	\N	PRESENT	0
703648	701647	19467C	PARTICIPANT	\N	PRESENT	0
703650	701647	19533U	PARTICIPANT	\N	PRESENT	0
703653	701647	14030Q	PARTICIPANT	\N	PRESENT	0
703655	701647	19713W	PARTICIPANT	\N	PRESENT	0
703690	701647	08018U	PARTICIPANT	\N	PRESENT	0
703692	701647	11110B	PARTICIPANT	\N	PRESENT	0
703725	701647	19741B	PARTICIPANT	\N	PRESENT	0
703732	701647	11048N	PARTICIPANT	\N	PRESENT	0
703733	701647	20052X	PARTICIPANT	\N	PRESENT	0
703734	701647	19621T	PARTICIPANT	\N	PRESENT	0
703735	701647	14071N	PARTICIPANT	\N	PRESENT	0
703736	701647	14059S	PARTICIPANT	\N	PRESENT	0
703737	701647	11097X	PARTICIPANT	\N	PRESENT	0
703738	701647	14217N	PARTICIPANT	\N	PRESENT	0
703739	701647	20038A	PARTICIPANT	\N	PRESENT	0
703740	701647	11085T	PARTICIPANT	\N	PRESENT	0
703741	701647	20120S	PARTICIPANT	\N	PRESENT	0
703742	701647	14042U	PARTICIPANT	\N	PRESENT	0
703743	701647	20100N	PARTICIPANT	\N	PRESENT	0
703752	701647	19693L	PARTICIPANT	\N	PRESENT	0
703753	701647	11053K	PARTICIPANT	\N	PRESENT	0
703754	701647	20106U	PARTICIPANT	\N	PRESENT	0
703755	701647	19369B	PARTICIPANT	\N	PRESENT	0
704283	704282	19701S	PARTICIPANT	\N	PRESENT	0
704285	704284	19701S	PARTICIPANT	\N	PRESENT	0
704296	704295	19447X	PARTICIPANT	\N	PRESENT	0
704297	704295	14089Y	PARTICIPANT	\N	PRESENT	0
704298	704268	14042U	PARTICIPANT	\N	PRESENT	1
704299	704268	11097X	PARTICIPANT	\N	PRESENT	1
704303	704301	19447X	PARTICIPANT	\N	PRESENT	0
704304	704301	14089Y	PARTICIPANT	\N	PRESENT	0
707128	704097	19591F	PARTICIPANT	\N	PRESENT	0
707182	704097	19367Y	PARTICIPANT	\N	PRESENT	0
707130	704097	19745F	PARTICIPANT	\N	PRESENT	0
707177	704097	20020P	PARTICIPANT	\N	PRESENT	0
707132	704097	19649G	PARTICIPANT	\N	PRESENT	0
707185	704097	11074Q	PARTICIPANT	\N	PRESENT	0
707180	704097	14037X	PARTICIPANT	\N	PRESENT	0
707181	704097	20042V	PARTICIPANT	\N	PRESENT	0
707136	704097	19669L	PARTICIPANT	\N	PRESENT	0
707183	704097	19667J	PARTICIPANT	\N	PRESENT	0
707172	704097	01058X	PARTICIPANT	\N	PRESENT	0
707188	704097	14073Q	PARTICIPANT	\N	PRESENT	0
707179	704097	19333N	PARTICIPANT	\N	PRESENT	0
707141	704227	19697Q	PARTICIPANT	\N	PRESENT	0
707142	704227	01034P	PARTICIPANT	\N	PRESENT	0
707143	704227	04092N	PARTICIPANT	\N	PRESENT	0
707144	704227	19798U	PARTICIPANT	\N	PRESENT	0
707145	704227	08045X	PARTICIPANT	\N	PRESENT	0
707146	704227	11097X	PARTICIPANT	\N	PRESENT	0
707147	704227	20040T	PARTICIPANT	\N	PRESENT	0
707148	704227	19691J	PARTICIPANT	\N	PRESENT	0
707149	704227	14223L	PARTICIPANT	\N	PRESENT	0
707150	704227	20148F	PARTICIPANT	\N	PRESENT	0
707151	704227	14026U	PARTICIPANT	\N	PRESENT	0
707152	704227	19723Y	PARTICIPANT	\N	PRESENT	0
707153	704227	19703U	PARTICIPANT	\N	PRESENT	0
707154	704227	19679N	PARTICIPANT	\N	PRESENT	0
707155	704227	14042U	PARTICIPANT	\N	PRESENT	0
707156	704227	14195A	PARTICIPANT	\N	PRESENT	0
707157	704227	19367Y	PARTICIPANT	\N	PRESENT	0
707158	704227	14213J	PARTICIPANT	\N	PRESENT	0
707159	704227	14071N	PARTICIPANT	\N	PRESENT	0
707160	704227	19657G	PARTICIPANT	\N	PRESENT	0
707161	704227	10006L	PRESIDENT	0	PRESENT	0
707162	704227	17965H	PARTICIPANT	\N	PRESENT	0
707163	704227	18193Q	PARTICIPANT	\N	PRESENT	0
707164	704227	14281W	PARTICIPANT	\N	PRESENT	0
707165	704227	04057K	PARTICIPANT	\N	EXCUSE	0
707166	704227	20248J	PARTICIPANT	\N	EXCUSE	0
707167	704227	19295A	PARTICIPANT	\N	EXCUSE	0
707168	704097	14251Q	PARTICIPANT	\N	PRESENT	0
707169	704097	20050V	PARTICIPANT	\N	PRESENT	0
707170	704097	19717B	PARTICIPANT	\N	PRESENT	0
707171	704097	20120S	PARTICIPANT	\N	PRESENT	0
707173	704097	19798U	PARTICIPANT	\N	PRESENT	0
707174	704097	86034E	PARTICIPANT	\N	PRESENT	0
707175	704097	20116W	PARTICIPANT	\N	PRESENT	0
707176	704097	04059M	PARTICIPANT	\N	PRESENT	0
707178	704097	20148F	PARTICIPANT	\N	PRESENT	0
707184	704097	14021P	PARTICIPANT	\N	PRESENT	0
707186	704097	19611R	PARTICIPANT	\N	PRESENT	0
707187	704097	20052X	PARTICIPANT	\N	PRESENT	0
707189	704097	19619A	PARTICIPANT	\N	PRESENT	0
707190	704097	20122U	PARTICIPANT	\N	PRESENT	0
707191	704097	14195A	PARTICIPANT	\N	PRESENT	0
707192	704097	14026U	PARTICIPANT	\N	PRESENT	0
707193	704097	17737W	PARTICIPANT	\N	PRESENT	0
707194	704097	04033B	PARTICIPANT	\N	PRESENT	0
707195	704097	19657G	PARTICIPANT	\N	PRESENT	0
707196	704097	19643A	PARTICIPANT	\N	PRESENT	0
707197	704097	19762G	PARTICIPANT	\N	PRESENT	0
707198	704097	19383Y	PARTICIPANT	\N	PRESENT	0
707199	704097	20044X	PARTICIPANT	\N	PRESENT	0
707200	704097	19421M	PARTICIPANT	\N	PRESENT	0
707201	704097	19369B	PARTICIPANT	\N	PRESENT	0
707202	704097	19507S	PARTICIPANT	\N	PRESENT	0
707203	704097	98022P	PARTICIPANT	\N	PRESENT	0
707204	704097	08015R	PARTICIPANT	\N	PRESENT	0
707205	704097	19701S	PARTICIPANT	\N	PRESENT	0
707206	704097	11012A	PARTICIPANT	\N	PRESENT	0
707207	704097	17779H	PARTICIPANT	\N	PRESENT	0
707208	704097	14071N	PARTICIPANT	\N	PRESENT	0
707209	704097	14069U	PARTICIPANT	\N	PRESENT	0
707210	704097	14329V	PARTICIPANT	\N	PRESENT	0
707211	704097	19531S	PARTICIPANT	\N	PRESENT	0
707212	704097	01048V	PARTICIPANT	\N	PRESENT	0
707213	704097	17965H	PARTICIPANT	\N	PRESENT	0
707214	704097	11110B	PARTICIPANT	\N	PRESENT	0
707215	704097	08061X	PARTICIPANT	\N	PRESENT	0
707216	704097	20142Y	PARTICIPANT	\N	PRESENT	0
707217	704097	20068G	PARTICIPANT	\N	PRESENT	0
707218	704097	20152B	PARTICIPANT	\N	PRESENT	0
707219	704097	04035D	PARTICIPANT	\N	PRESENT	0
707220	704097	19533U	PARTICIPANT	\N	PRESENT	0
707221	704097	19673G	PARTICIPANT	\N	PRESENT	0
707222	704097	04043D	PARTICIPANT	\N	PRESENT	0
707223	704097	11070L	PARTICIPANT	\N	PRESENT	0
707224	704097	04008A	PARTICIPANT	\N	PRESENT	0
707225	704097	12016W	PARTICIPANT	\N	PRESENT	0
707226	704097	19723Y	PARTICIPANT	\N	PRESENT	0
707227	704097	04085P	PARTICIPANT	\N	PRESENT	0
707228	704097	20058E	PARTICIPANT	\N	PRESENT	0
707229	704097	20070A	PARTICIPANT	\N	PRESENT	0
707230	704097	20298U	PARTICIPANT	\N	PRESENT	0
707231	704097	01024M	PARTICIPANT	\N	PRESENT	0
707232	704097	19349W	PARTICIPANT	\N	PRESENT	0
707233	704097	11077T	PARTICIPANT	\N	PRESENT	0
707234	704097	20096L	PARTICIPANT	\N	PRESENT	0
707235	704097	14169X	PARTICIPANT	\N	PRESENT	0
707236	704097	17367Q	PARTICIPANT	\N	PRESENT	0
707237	704097	17637T	PARTICIPANT	\N	PRESENT	0
707238	704097	19581D	PARTICIPANT	\N	PRESENT	0
707239	704097	14255U	PARTICIPANT	\N	PRESENT	0
707240	704097	20266L	PARTICIPANT	\N	PRESENT	0
707241	704097	11115U	PARTICIPANT	\N	PRESENT	0
707242	704097	11045K	PARTICIPANT	\N	PRESENT	0
707243	704097	20114U	PARTICIPANT	\N	PRESENT	0
707244	704097	16685X	PARTICIPANT	\N	PRESENT	0
707245	704097	14033T	PARTICIPANT	\N	PRESENT	0
686253	683655	20066E	PARTICIPANT	\N	PRESENT	0
686254	683655	11045K	PARTICIPANT	\N	PRESENT	0
686255	683655	11031D	PARTICIPANT	\N	PRESENT	0
686256	683655	14030Q	PRESIDENT	0	PRESENT	0
686257	683655	20130U	PARTICIPANT	\N	PRESENT	0
686258	683655	14109K	PARTICIPANT	\N	PRESENT	0
688387	688386	20112S	PARTICIPANT	\N	PRESENT	1
688388	688386	19735D	PARTICIPANT	\N	PRESENT	1
688389	688386	19643A	PARTICIPANT	\N	PRESENT	1
688390	688386	20142Y	PARTICIPANT	\N	PRESENT	1
692665	692456	14033T	PARTICIPANT	\N	EXCUSE	0
692666	692456	19631V	PARTICIPANT	\N	EXCUSE	0
692667	692456	20144B	PARTICIPANT	\N	EXCUSE	0
692668	692456	20286Q	PARTICIPANT	\N	EXCUSE	0
695034	695033	19703U	PARTICIPANT	\N	PRESENT	1
696029	693561	18083K	PARTICIPANT	\N	PRESENT	0
696031	693561	19295A	PARTICIPANT	\N	PRESENT	1
696032	693561	97011G	PARTICIPANT	\N	PRESENT	0
696033	693561	14275Y	PARTICIPANT	\N	PRESENT	0
696034	693561	19319Q	PARTICIPANT	\N	PRESENT	0
699887	698745	10006L	PRESIDENT	0	PRESENT	0
699888	698745	14195A	PARTICIPANT	\N	PRESENT	0
699889	698745	20130U	PARTICIPANT	\N	PRESENT	0
699890	698745	19329S	PARTICIPANT	\N	PRESENT	0
699891	698745	19553Y	PARTICIPANT	\N	PRESENT	0
699892	698745	19691J	PARTICIPANT	\N	PRESENT	0
699893	698745	19479G	PARTICIPANT	\N	PRESENT	0
699894	698745	14355X	PARTICIPANT	\N	PRESENT	0
699895	698745	20090E	PARTICIPANT	\N	PRESENT	0
699896	698745	19798U	PARTICIPANT	\N	PRESENT	0
699897	698745	14223L	PARTICIPANT	\N	PRESENT	0
699898	698745	19511N	PARTICIPANT	\N	PRESENT	0
699899	698745	14213J	PARTICIPANT	\N	PRESENT	0
699900	698745	14217N	PARTICIPANT	\N	PRESENT	0
699901	698745	19703U	PARTICIPANT	\N	PRESENT	0
699917	698745	14071N	PARTICIPANT	\N	PRESENT	0
699918	698745	20148F	PARTICIPANT	\N	PRESENT	0
699919	698745	14042U	PARTICIPANT	\N	PRESENT	0
699920	698745	11097X	PARTICIPANT	\N	PRESENT	0
699921	698745	04092N	PARTICIPANT	\N	PRESENT	0
699922	698745	19723Y	PARTICIPANT	\N	PRESENT	0
699923	698745	18193Q	PARTICIPANT	\N	PRESENT	0
699925	698745	19295A	PARTICIPANT	\N	EXCUSE	0
699926	698745	04057K	PARTICIPANT	\N	EXCUSE	0
699927	698745	19760E	PARTICIPANT	\N	PRESENT	0
699928	698745	20066E	PARTICIPANT	\N	PRESENT	0
699929	698745	11031D	PARTICIPANT	\N	PRESENT	0
699931	698745	14026U	PARTICIPANT	\N	PRESENT	0
699932	698745	19715Y	PARTICIPANT	\N	PRESENT	0
699933	698745	19657G	PARTICIPANT	\N	PRESENT	0
699934	698745	19713W	PARTICIPANT	\N	PRESENT	0
699958	698745	19569H	PARTICIPANT	\N	PRESENT	0
699959	698745	17779H	PARTICIPANT	\N	PRESENT	0
699960	698745	11067R	PARTICIPANT	\N	PRESENT	0
699961	698745	17965H	PARTICIPANT	\N	PRESENT	0
699962	698745	20266L	PARTICIPANT	\N	PRESENT	0
699963	698745	20248J	PARTICIPANT	\N	PRESENT	0
699971	698745	19415P	PARTICIPANT	\N	PRESENT	0
700089	698744	19697Q	PARTICIPANT	\N	PRESENT	0
699973	698745	19683J	PARTICIPANT	\N	PRESENT	0
699974	698745	04043D	PARTICIPANT	\N	PRESENT	0
699975	698745	20040T	PARTICIPANT	\N	PRESENT	0
700005	698744	19760E	PARTICIPANT	\N	PRESENT	0
702554	700257	19533U	PARTICIPANT	\N	PRESENT	0
700046	698744	19591F	PARTICIPANT	\N	PRESENT	0
700047	698744	20066E	PARTICIPANT	\N	PRESENT	0
700048	698744	19511N	PARTICIPANT	\N	PRESENT	0
700049	698744	19683J	PARTICIPANT	\N	PRESENT	0
700050	698744	19715Y	PARTICIPANT	\N	PRESENT	0
700051	698744	18193Q	PARTICIPANT	\N	PRESENT	0
700052	698744	19723Y	PARTICIPANT	\N	PRESENT	0
700053	698744	19657G	PARTICIPANT	\N	PRESENT	0
700054	698744	17779H	PARTICIPANT	\N	PRESENT	0
700055	698744	04057K	PARTICIPANT	\N	EXCUSE	0
700056	698744	11067R	PARTICIPANT	\N	PRESENT	0
700057	698744	19569H	PARTICIPANT	\N	PRESENT	0
700058	698744	14213J	PARTICIPANT	\N	PRESENT	0
700062	698744	20248J	PARTICIPANT	\N	PRESENT	0
700060	698744	11031D	PARTICIPANT	\N	PRESENT	0
700061	698744	14217N	PARTICIPANT	\N	PRESENT	0
700063	698744	14042U	PARTICIPANT	\N	PRESENT	0
700064	698744	19553Y	PARTICIPANT	\N	PRESENT	0
700065	698744	19329S	PARTICIPANT	\N	PRESENT	0
700066	698744	14223L	PARTICIPANT	\N	PRESENT	0
700067	698744	04092N	PARTICIPANT	\N	PRESENT	0
700068	698744	14071N	PARTICIPANT	\N	PRESENT	0
700069	698744	20090E	PARTICIPANT	\N	PRESENT	0
700070	698744	14195A	PARTICIPANT	\N	PRESENT	0
700071	698744	10006L	PRESIDENT	0	PRESENT	0
700072	698744	20040T	PARTICIPANT	\N	PRESENT	0
700073	698744	14281W	PARTICIPANT	\N	PRESENT	0
702555	700257	20098N	PARTICIPANT	\N	PRESENT	0
702556	700257	20134Y	PARTICIPANT	\N	PRESENT	0
700076	698744	19691J	PARTICIPANT	\N	PRESENT	0
700077	698744	20130U	PARTICIPANT	\N	PRESENT	0
702557	700257	19651A	PARTICIPANT	\N	PRESENT	0
700079	698744	17965H	PARTICIPANT	\N	PRESENT	0
702558	700257	20264J	PARTICIPANT	\N	PRESENT	0
700081	698744	19798U	PARTICIPANT	\N	PRESENT	0
700085	698744	19703U	PARTICIPANT	\N	PRESENT	0
700083	698744	20266L	PARTICIPANT	\N	PRESENT	0
700084	698744	19713W	PARTICIPANT	\N	PRESENT	0
700086	698744	11097X	PARTICIPANT	\N	PRESENT	0
700087	698744	19295A	PARTICIPANT	\N	EXCUSE	0
700088	698745	19591F	PARTICIPANT	\N	PRESENT	0
700254	698744	11045K	PARTICIPANT	\N	PRESENT	0
702528	700257	04070G	PARTICIPANT	\N	PRESENT	0
702529	700257	14229S	PARTICIPANT	\N	PRESENT	0
702530	700257	20112S	PARTICIPANT	\N	PRESENT	0
702531	700257	08012N	PARTICIPANT	\N	PRESENT	0
702532	700257	20124W	PARTICIPANT	\N	PRESENT	0
702533	700257	20026V	PARTICIPANT	\N	PRESENT	0
702534	700257	19593H	PARTICIPANT	\N	PRESENT	0
702535	700257	20132W	PARTICIPANT	\N	PRESENT	0
702536	700257	19643A	PARTICIPANT	\N	PRESENT	0
702537	700257	14073Q	PARTICIPANT	\N	PRESENT	0
702538	700257	19611R	PRESIDENT	0	PRESENT	0
702539	700257	20142Y	PARTICIPANT	\N	PRESENT	0
702540	700257	20048C	PARTICIPANT	\N	PRESENT	0
702541	700257	19399H	PARTICIPANT	\N	PRESENT	0
702542	700257	20152B	PARTICIPANT	\N	PRESENT	0
702543	700257	20052X	PARTICIPANT	\N	PRESENT	0
702544	700257	14030Q	PARTICIPANT	\N	PRESENT	0
702545	700257	20056C	PARTICIPANT	\N	PRESENT	0
702546	700257	20180F	PARTICIPANT	\N	PRESENT	0
702547	700257	04059M	PARTICIPANT	\N	PRESENT	0
702548	700257	11104D	PARTICIPANT	\N	PRESENT	0
702549	700257	11043H	PARTICIPANT	\N	PRESENT	0
702550	700257	19758L	PARTICIPANT	\N	PRESENT	0
702551	700257	20084G	PARTICIPANT	\N	PRESENT	0
702552	700257	11109J	PARTICIPANT	\N	EXCUSE	0
702553	700257	20058E	PARTICIPANT	\N	EXCUSE	0
702559	700257	14123H	PARTICIPANT	\N	PRESENT	0
702560	700257	20980G	PARTICIPANT	\N	PRESENT	0
702561	700257	19621T	PARTICIPANT	\N	PRESENT	0
702719	701687	95041E	PARTICIPANT	\N	PRESENT	0
702720	701687	12041X	PARTICIPANT	\N	PRESENT	0
702721	701687	11080N	PARTICIPANT	\N	PRESENT	0
702722	701687	19565D	PARTICIPANT	\N	PRESENT	0
702723	701687	20072C	PARTICIPANT	\N	PRESENT	0
702724	701687	01058X	PARTICIPANT	\N	PRESENT	0
702725	701687	16685X	PARTICIPANT	\N	PRESENT	0
702726	701687	11027H	PARTICIPANT	\N	PRESENT	0
702727	701687	04042C	PRESIDENT	0	PRESENT	0
702728	701687	11054L	PARTICIPANT	\N	PRESENT	0
702729	701687	19669L	PARTICIPANT	\N	PRESENT	0
702730	701687	11066Q	PARTICIPANT	\N	PRESENT	0
702731	701687	12028B	PARTICIPANT	\N	PRESENT	0
702732	701687	19421M	PARTICIPANT	\N	PRESENT	0
702733	701687	19347U	PARTICIPANT	\N	PRESENT	0
702734	701687	07033P	PARTICIPANT	\N	PRESENT	0
702735	701687	08061X	PARTICIPANT	\N	PRESENT	0
702736	701687	97011G	PARTICIPANT	\N	PRESENT	0
702737	701687	14249W	PARTICIPANT	\N	PRESENT	0
702738	701687	08047A	PARTICIPANT	\N	PRESENT	0
702739	701687	20128B	PARTICIPANT	\N	PRESENT	0
702740	701687	14059S	PARTICIPANT	\N	PRESENT	0
702741	701687	14133K	PARTICIPANT	\N	PRESENT	0
702742	701687	01062T	PARTICIPANT	\N	PRESENT	0
702743	701687	11041F	PARTICIPANT	\N	PRESENT	0
702744	701687	20042V	PARTICIPANT	\N	PRESENT	0
692071	690827	01060R	PARTICIPANT	\N	PRESENT	0
692072	690827	14055N	PARTICIPANT	\N	PRESENT	0
692073	690827	07033P	PARTICIPANT	\N	PRESENT	0
692074	690827	19367Y	PARTICIPANT	\N	PRESENT	0
692075	690827	19581D	PARTICIPANT	\N	PRESENT	0
692076	690827	20020P	PARTICIPANT	\N	PRESENT	0
692077	690827	11045K	PARTICIPANT	\N	PRESENT	0
692078	690827	20152B	PARTICIPANT	\N	PRESENT	0
692079	690827	20082E	PARTICIPANT	\N	PRESENT	0
692080	690827	20084G	PARTICIPANT	\N	PRESENT	0
692081	690827	19762G	PARTICIPANT	\N	PRESENT	0
692082	690827	01028R	PARTICIPANT	\N	PRESENT	0
692083	690827	19383Y	PARTICIPANT	\N	PRESENT	0
692084	690827	11104D	PARTICIPANT	\N	PRESENT	0
692085	690827	14329V	PARTICIPANT	\N	PRESENT	0
692086	690827	14001X	PARTICIPANT	\N	PRESENT	0
692087	690827	20028X	PARTICIPANT	\N	PRESENT	0
692088	690827	20062A	PARTICIPANT	\N	PRESENT	0
692089	690827	11067R	PARTICIPANT	\N	PRESENT	0
692090	690827	20030R	PARTICIPANT	\N	PRESENT	0
692091	690827	19675J	PARTICIPANT	\N	PRESENT	0
692092	690827	20060X	PARTICIPANT	\N	PRESENT	0
692093	690827	14059S	PARTICIPANT	\N	PRESENT	0
692094	690827	08056B	PARTICIPANT	\N	PRESENT	0
692095	690827	19669L	PARTICIPANT	\N	PRESENT	0
692096	690827	20124W	PARTICIPANT	\N	PRESENT	0
692097	690827	19413M	PARTICIPANT	\N	PRESENT	0
692098	690827	20126Y	PARTICIPANT	\N	PRESENT	0
692099	690827	07004J	PARTICIPANT	\N	PRESENT	0
692100	690827	20054A	PARTICIPANT	\N	PRESENT	0
692101	690827	08045X	PARTICIPANT	\N	PRESENT	0
692102	690827	19707Y	PARTICIPANT	\N	PRESENT	0
692103	690827	19705W	PARTICIPANT	\N	PRESENT	0
692104	690827	20264J	PARTICIPANT	\N	PRESENT	0
692105	690827	19251M	PARTICIPANT	\N	PRESENT	0
692106	690827	19729F	PARTICIPANT	\N	PRESENT	0
692107	690827	19657G	PARTICIPANT	\N	PRESENT	0
692108	690827	14281W	PARTICIPANT	\N	PRESENT	0
692109	690827	07029T	PARTICIPANT	\N	PRESENT	0
692110	690827	19741B	PARTICIPANT	\N	PRESENT	0
692111	690827	19527W	PARTICIPANT	\N	PRESENT	0
692112	690827	19399H	PARTICIPANT	\N	PRESENT	0
692113	690827	11066Q	PARTICIPANT	\N	PRESENT	0
692114	690827	20108W	PARTICIPANT	\N	PRESENT	0
692115	690827	20148F	PARTICIPANT	\N	PRESENT	0
692116	690827	20024T	PARTICIPANT	\N	PRESENT	0
692117	690827	14257W	PARTICIPANT	\N	PRESENT	0
692118	690827	14213J	PARTICIPANT	\N	PRESENT	0
692119	690827	14147R	PARTICIPANT	\N	PRESENT	0
692120	690827	20172F	PARTICIPANT	\N	PRESENT	0
692121	690827	14021P	PARTICIPANT	\N	PRESENT	0
692122	690827	20138D	PARTICIPANT	\N	PRESENT	0
692123	690827	14225N	PARTICIPANT	\N	PRESENT	0
692124	690827	19503N	PARTICIPANT	\N	PRESENT	0
692125	690827	08047A	PARTICIPANT	\N	PRESENT	0
692126	690827	17965H	PARTICIPANT	\N	PRESENT	0
692127	690827	20140W	PARTICIPANT	\N	PRESENT	0
692128	690827	12016W	PARTICIPANT	\N	PRESENT	0
692129	690827	14253S	PARTICIPANT	\N	PRESENT	0
692130	690827	17779H	PARTICIPANT	\N	PRESENT	0
692131	690827	20136B	PARTICIPANT	\N	PRESENT	0
692132	690827	08012N	PARTICIPANT	\N	PRESENT	0
692133	690827	17737W	PARTICIPANT	\N	PRESENT	0
692134	690827	18193Q	PARTICIPANT	\N	PRESENT	0
692135	690827	20032T	PARTICIPANT	\N	PRESENT	0
692136	690827	14331P	PARTICIPANT	\N	PRESENT	0
692137	690827	19715Y	PARTICIPANT	\N	PRESENT	0
692138	690827	19725B	PARTICIPANT	\N	PRESENT	0
692139	690827	20026V	PARTICIPANT	\N	PRESENT	0
692140	690827	14097Y	PARTICIPANT	\N	PRESENT	0
692141	690827	14151M	PARTICIPANT	\N	PRESENT	0
692142	690827	04059M	PARTICIPANT	\N	PRESENT	0
692143	690827	20070A	PARTICIPANT	\N	PRESENT	0
692144	690827	19387D	PARTICIPANT	\N	PRESENT	0
692145	690827	14249W	PARTICIPANT	\N	PRESENT	0
692146	690827	19820Y	PARTICIPANT	\N	PRESENT	0
692147	690827	19531S	PARTICIPANT	\N	PRESENT	0
692148	690827	19507S	PARTICIPANT	\N	PRESENT	0
692149	690827	19673G	PARTICIPANT	\N	PRESENT	0
692150	690827	20048C	PARTICIPANT	\N	PRESENT	0
692151	690827	20144B	PARTICIPANT	\N	PRESENT	0
692152	690827	11085T	PARTICIPANT	\N	PRESENT	0
692153	690827	14219Q	PARTICIPANT	\N	PRESENT	0
692154	690827	19768N	PARTICIPANT	\N	PRESENT	0
692155	690827	19335Q	PARTICIPANT	\N	PRESENT	0
692156	690827	19699S	PARTICIPANT	\N	PRESENT	0
692157	690827	14083S	PARTICIPANT	\N	PRESENT	0
692158	690827	20040T	PARTICIPANT	\N	PRESENT	0
692159	690827	11053K	PARTICIPANT	\N	PRESENT	0
692160	690827	20286Q	PARTICIPANT	\N	PRESENT	0
692161	690827	19569H	PARTICIPANT	\N	PRESENT	0
692162	690827	20298U	PARTICIPANT	\N	PRESENT	0
692163	690827	19511N	PARTICIPANT	\N	PRESENT	0
692164	690827	14073Q	PARTICIPANT	\N	PRESENT	0
692165	690827	19611R	PARTICIPANT	\N	PRESENT	0
692166	690827	01043Q	PARTICIPANT	\N	PRESENT	0
692167	690827	14205J	PARTICIPANT	\N	PRESENT	0
692168	690827	16685X	PARTICIPANT	\N	PRESENT	0
692169	690827	08009T	PARTICIPANT	\N	PRESENT	0
692170	690827	19826F	PARTICIPANT	\N	PRESENT	0
692171	690827	01034P	PARTICIPANT	\N	PRESENT	0
692172	690827	20066E	PARTICIPANT	\N	PRESENT	0
692173	690827	14089Y	PARTICIPANT	\N	PRESENT	0
692174	690827	19749K	PARTICIPANT	\N	PRESENT	0
692175	690827	19057M	PARTICIPANT	\N	PRESENT	0
692176	690827	14237S	PARTICIPANT	\N	PRESENT	0
692191	690827	20122U	PARTICIPANT	\N	PRESENT	0
692205	690827	19551W	PARTICIPANT	\N	PRESENT	0
692292	692291	11048N	PARTICIPANT	\N	PRESENT	0
692293	692291	08011M	PARTICIPANT	\N	PRESENT	0
692298	692297	11048N	PARTICIPANT	\N	PRESENT	0
692299	692297	08011M	PARTICIPANT	\N	PRESENT	0
692301	692300	11048N	PARTICIPANT	\N	PRESENT	0
692302	692300	08011M	PARTICIPANT	\N	PRESENT	0
692449	690710	04042C	PARTICIPANT	\N	PRESENT	0
692536	692529	10006L	PARTICIPANT	0	PRESENT	0
692537	692529	14071N	PRESIDENT	0	PRESENT	0
692540	692529	19723Y	PARTICIPANT	\N	PRESENT	0
692541	692529	14281W	PARTICIPANT	\N	PRESENT	0
692542	692529	19798U	PARTICIPANT	\N	PRESENT	0
692543	692529	19679N	PARTICIPANT	\N	PRESENT	0
692544	692529	14213J	PARTICIPANT	\N	PRESENT	0
692545	692529	20148F	PARTICIPANT	\N	PRESENT	0
692546	692529	14042U	PARTICIPANT	\N	PRESENT	0
692552	692529	20066E	PARTICIPANT	\N	PRESENT	0
692553	692529	19511N	PARTICIPANT	\N	PRESENT	0
692554	692529	19697Q	PARTICIPANT	\N	PRESENT	0
692555	692529	14026U	PARTICIPANT	\N	PRESENT	0
692556	692529	20130U	PARTICIPANT	\N	PRESENT	0
692557	692529	04057K	PARTICIPANT	\N	EXCUSE	0
692559	692529	14355X	PARTICIPANT	\N	EXCUSE	0
692560	692529	19760E	PARTICIPANT	\N	EXCUSE	0
692566	692529	19703U	PARTICIPANT	\N	EXCUSE	0
692568	692529	04092N	PARTICIPANT	\N	EXCUSE	0
692569	692532	19760E	PARTICIPANT	\N	PRESENT	0
692570	692532	19703U	PARTICIPANT	\N	EXCUSE	0
692571	692532	04092N	PARTICIPANT	\N	EXCUSE	0
692572	692532	04057K	PARTICIPANT	\N	PRESENT	0
692573	692532	14355X	PARTICIPANT	\N	EXCUSE	0
692574	692533	19760E	PARTICIPANT	\N	PRESENT	0
692575	692533	19703U	PARTICIPANT	\N	EXCUSE	0
692595	692533	04092N	PARTICIPANT	\N	EXCUSE	0
692596	692533	04057K	PARTICIPANT	\N	PRESENT	0
692597	692533	14355X	PARTICIPANT	\N	EXCUSE	0
693525	692322	12041X	PARTICIPANT	\N	PRESENT	0
693526	692322	20072C	PARTICIPANT	\N	PRESENT	0
693527	692322	04042C	PRESIDENT	0	PRESENT	0
693528	692322	11054L	PARTICIPANT	\N	PRESENT	0
693529	692322	11066Q	PARTICIPANT	\N	PRESENT	0
693530	692322	12028B	PARTICIPANT	\N	PRESENT	0
693531	692322	19421M	PARTICIPANT	\N	PRESENT	0
693532	692322	14193X	PARTICIPANT	\N	PRESENT	0
693533	692322	08061X	PARTICIPANT	\N	PRESENT	0
693534	692322	08047A	PARTICIPANT	\N	PRESENT	0
693535	692322	14097Y	PARTICIPANT	\N	PRESENT	0
693536	692322	14059S	PARTICIPANT	\N	PRESENT	0
693537	692322	01062T	PARTICIPANT	\N	PRESENT	0
693538	692322	14133K	PARTICIPANT	\N	PRESENT	0
693539	692322	08069G	PARTICIPANT	\N	PRESENT	0
683637	683635	20066E	PARTICIPANT	\N	PRESENT	0
686441	686440	04047H	PARTICIPANT	\N	PRESENT	0
686442	686440	14053L	PARTICIPANT	\N	PRESENT	0
686446	686440	11066Q	PARTICIPANT	\N	PRESENT	0
687525	687523	14259Y	PARTICIPANT	\N	PRESENT	0
687520	687518	14231L	PARTICIPANT	\N	PRESENT	0
687521	687518	14259Y	PARTICIPANT	\N	PRESENT	0
687522	687518	11048N	PARTICIPANT	\N	PRESENT	0
687524	687523	14231L	PARTICIPANT	\N	PRESENT	0
687526	687523	11048N	PARTICIPANT	\N	PRESENT	0
687544	687543	20032T	PARTICIPANT	\N	PRESENT	0
687545	687543	20076G	PARTICIPANT	\N	PRESENT	0
687546	687543	20024T	PARTICIPANT	\N	PRESENT	0
687547	687543	19383Y	PARTICIPANT	\N	PRESENT	0
687548	687543	20090E	PARTICIPANT	\N	PRESENT	0
687549	687543	11103C	PARTICIPANT	\N	PRESENT	0
687550	687543	14329V	PARTICIPANT	\N	PRESENT	0
687551	687543	19467C	PARTICIPANT	\N	PRESENT	0
687552	687543	14357A	PARTICIPANT	\N	PRESENT	0
687553	687543	20038A	PARTICIPANT	\N	PRESENT	0
687554	687543	14179A	PARTICIPANT	\N	PRESENT	0
687555	687543	14213J	PARTICIPANT	\N	PRESENT	0
687556	687543	20126Y	PARTICIPANT	\N	PRESENT	0
687557	687543	19723Y	PARTICIPANT	\N	PRESENT	0
687558	687543	16685X	PARTICIPANT	\N	PRESENT	0
687559	687543	05012A	PARTICIPANT	\N	PRESENT	0
687560	687543	19679N	PARTICIPANT	\N	PRESENT	0
687561	687543	14331P	PARTICIPANT	\N	PRESENT	0
690421	690420	14026U	PARTICIPANT	\N	PRESENT	0
690422	690420	19725B	PARTICIPANT	\N	PRESENT	0
693921	693561	11043H	PARTICIPANT	\N	EXCUSE	0
693922	693586	11043H	PARTICIPANT	\N	EXCUSE	0
693923	693587	11043H	PARTICIPANT	\N	EXCUSE	0
695008	695007	19629C	PARTICIPANT	\N	PRESENT	0
695009	695007	04045F	PARTICIPANT	\N	PRESENT	0
695010	695007	20090E	PARTICIPANT	\N	PRESENT	0
695011	695007	19549D	PARTICIPANT	\N	PRESENT	0
695012	695007	20120S	PARTICIPANT	\N	PRESENT	0
695013	695007	08015R	PARTICIPANT	\N	PRESENT	0
698944	698943	19735D	PARTICIPANT	\N	EXCUSE	0
699642	699641	04070G	PARTICIPANT	\N	PRESENT	0
699644	699641	20132W	PARTICIPANT	\N	PRESENT	0
699645	699641	20134Y	PARTICIPANT	\N	PRESENT	1
699648	699647	20132W	PARTICIPANT	\N	PRESENT	0
699649	699647	14229S	PARTICIPANT	\N	PRESENT	0
699653	699652	20132W	PARTICIPANT	\N	PRESENT	0
699654	699652	14229S	PARTICIPANT	\N	PRESENT	1
704498	704497	19701S	PARTICIPANT	\N	PRESENT	0
705919	704218	11031D	PARTICIPANT	\N	PRESENT	0
705920	704218	20066E	PARTICIPANT	\N	PRESENT	0
705921	704218	14042U	PARTICIPANT	\N	PRESENT	0
705922	704218	14071N	PARTICIPANT	\N	PRESENT	0
705923	704218	19657G	PARTICIPANT	\N	PRESENT	0
705924	704218	14217N	PARTICIPANT	\N	PRESENT	0
705925	704218	19683J	PARTICIPANT	\N	PRESENT	0
705926	704218	10006L	PRESIDENT	0	PRESENT	0
705927	704218	19295A	PARTICIPANT	\N	EXCUSE	0
705928	704218	14195A	PARTICIPANT	\N	PRESENT	0
705929	704218	19697Q	PARTICIPANT	\N	PRESENT	0
705930	704218	19723Y	PARTICIPANT	\N	PRESENT	0
705931	704218	20248J	PARTICIPANT	\N	PRESENT	0
705932	704218	18193Q	PARTICIPANT	\N	PRESENT	0
705933	704218	19479G	PARTICIPANT	\N	PRESENT	0
705934	704218	17965H	PARTICIPANT	\N	PRESENT	0
705935	704084	19593H	PARTICIPANT	\N	PRESENT	0
705936	704084	19565D	PARTICIPANT	\N	PRESENT	0
705937	704084	19766L	PARTICIPANT	\N	PRESENT	0
705938	704084	08060W	PARTICIPANT	\N	PRESENT	0
705939	704084	14189C	PARTICIPANT	\N	PRESENT	0
705940	704084	20068G	PARTICIPANT	\N	PRESENT	0
706013	704084	19723Y	PARTICIPANT	\N	PRESENT	0
705942	704084	17779H	PARTICIPANT	\N	PRESENT	0
705943	704084	14133K	PARTICIPANT	\N	PRESENT	0
705944	704084	11080N	PARTICIPANT	\N	PRESENT	0
705945	704084	17737W	PARTICIPANT	\N	PRESENT	0
705946	704084	14071N	PARTICIPANT	\N	PRESENT	0
705947	704084	04085P	PARTICIPANT	\N	PRESENT	0
705948	704084	20152B	PARTICIPANT	\N	PRESENT	0
705949	704084	14053L	PARTICIPANT	\N	PRESENT	0
705950	704084	19695N	PARTICIPANT	\N	PRESENT	0
705951	704084	20036X	PARTICIPANT	\N	PRESENT	0
705952	704084	20052X	PARTICIPANT	\N	PRESENT	0
705953	704084	11041F	PARTICIPANT	\N	PRESENT	0
705954	704084	19798U	PARTICIPANT	\N	PRESENT	0
705955	704084	14223L	PARTICIPANT	\N	PRESENT	0
705956	704084	04092N	PARTICIPANT	\N	PRESENT	0
705957	704084	19703U	PARTICIPANT	\N	PRESENT	0
705958	704084	19657G	PARTICIPANT	\N	PRESENT	0
705959	704084	97011G	PARTICIPANT	\N	PRESENT	0
705960	704084	19621T	PARTICIPANT	\N	PRESENT	0
705961	704084	20038A	PARTICIPANT	\N	PRESENT	0
705962	704084	07029T	PARTICIPANT	\N	PRESENT	0
705963	704084	14355X	PARTICIPANT	\N	PRESENT	0
705964	704084	20066E	PARTICIPANT	\N	PRESENT	0
705965	704084	19611R	PARTICIPANT	\N	PRESENT	0
705966	704084	95063L	PARTICIPANT	\N	PRESENT	0
705967	704084	14037X	PARTICIPANT	\N	PRESENT	0
705968	704084	08073C	PARTICIPANT	\N	PRESENT	0
705969	704084	20980G	PARTICIPANT	\N	PRESENT	0
705970	704084	11090Q	PARTICIPANT	\N	PRESENT	0
705971	704084	99004R	PARTICIPANT	\N	PRESENT	0
705972	704084	19581D	PARTICIPANT	\N	PRESENT	0
705973	704084	12041X	PARTICIPANT	\N	PRESENT	0
705974	704084	01058X	PARTICIPANT	\N	PRESENT	0
705975	704084	11031D	PARTICIPANT	\N	PRESENT	0
705976	704084	19758L	PARTICIPANT	\N	PRESENT	0
705977	704084	11077T	PARTICIPANT	\N	PRESENT	0
705978	704084	20046A	PARTICIPANT	\N	PRESENT	0
705979	704084	20102Q	PARTICIPANT	\N	PRESENT	0
705980	704084	19760E	PARTICIPANT	\N	PRESENT	0
705981	704084	20914V	PARTICIPANT	\N	PRESENT	0
705982	704084	11040E	PARTICIPANT	\N	PRESENT	0
705983	704084	08010L	PARTICIPANT	\N	PRESENT	0
705984	704084	19687N	PARTICIPANT	\N	PRESENT	0
705985	704084	20100N	PARTICIPANT	\N	PRESENT	0
705986	704084	14187A	PARTICIPANT	\N	PRESENT	0
705987	704084	19525U	PARTICIPANT	\N	PRESENT	0
705988	704084	19697Q	PARTICIPANT	\N	PRESENT	0
705989	704084	04045F	PARTICIPANT	\N	PRESENT	0
705990	704084	04033B	PARTICIPANT	\N	PRESENT	0
705991	704084	08061X	PARTICIPANT	\N	PRESENT	0
705992	704084	17367Q	PARTICIPANT	\N	PRESENT	0
705993	704084	19545Y	PARTICIPANT	\N	PRESENT	0
705994	704084	14195A	PARTICIPANT	\N	PRESENT	0
705995	704084	14251Q	PARTICIPANT	\N	PRESENT	0
705996	704084	19347U	PARTICIPANT	\N	PRESENT	0
705997	704084	20130U	PARTICIPANT	\N	PRESENT	0
705998	704084	19717B	PARTICIPANT	\N	PRESENT	0
705999	704084	19629C	PARTICIPANT	\N	PRESENT	0
706000	704084	20132W	PARTICIPANT	\N	PRESENT	0
706001	704084	19553Y	PARTICIPANT	\N	PRESENT	0
706002	704084	14107H	PARTICIPANT	\N	PRESENT	0
706012	704084	20146D	PARTICIPANT	\N	PRESENT	0
706004	704084	14207L	PARTICIPANT	\N	PRESENT	0
706005	704084	19866P	PARTICIPANT	\N	PRESENT	0
706006	704084	20072C	PARTICIPANT	\N	PRESENT	0
706007	704084	01028R	PARTICIPANT	\N	PRESENT	0
706008	704084	19515S	PARTICIPANT	\N	PRESENT	0
706009	704084	04059M	PARTICIPANT	\N	PRESENT	0
706010	704084	14225N	PARTICIPANT	\N	PRESENT	0
706011	704084	20022R	PARTICIPANT	\N	PRESENT	0
706014	704084	14257W	PARTICIPANT	\N	PRESENT	0
706015	704084	19649G	PARTICIPANT	\N	PRESENT	0
706016	704084	20108W	PARTICIPANT	\N	PRESENT	0
706017	704084	19683J	PARTICIPANT	\N	PRESENT	0
706018	704084	19647E	PARTICIPANT	\N	PRESENT	0
706019	704084	08015R	PARTICIPANT	\N	PRESENT	0
706020	704084	14281W	PARTICIPANT	\N	PRESENT	0
706021	704084	08045X	PARTICIPANT	\N	PRESENT	0
706022	704084	20062A	PARTICIPANT	\N	PRESENT	0
706023	704084	14021P	PARTICIPANT	\N	PRESENT	0
706024	704084	20134Y	PARTICIPANT	\N	PRESENT	0
706025	704084	14026U	PARTICIPANT	\N	PRESENT	0
706026	704084	19631V	PARTICIPANT	\N	PRESENT	0
706027	704084	14217N	PARTICIPANT	\N	PRESENT	0
706028	704084	20088L	PARTICIPANT	\N	PRESENT	0
706029	704084	20060X	PARTICIPANT	\N	PRESENT	0
706030	704084	19251M	PARTICIPANT	\N	PRESENT	0
707362	704098	11097X	PARTICIPANT	\N	PRESENT	0
707363	704098	14042U	PARTICIPANT	\N	PRESENT	0
707364	704098	14195A	PARTICIPANT	\N	PRESENT	0
707365	704098	17779H	PARTICIPANT	\N	PRESENT	0
707366	704098	98022P	PARTICIPANT	\N	PRESENT	0
707367	704098	19387D	PARTICIPANT	\N	PRESENT	0
707368	704098	19347U	PARTICIPANT	\N	PRESENT	0
707369	704098	19760E	PARTICIPANT	\N	PRESENT	0
707370	704098	11031D	PARTICIPANT	\N	PRESENT	0
707371	704098	20130U	PARTICIPANT	\N	PRESENT	0
707372	704098	17965H	PARTICIPANT	\N	PRESENT	0
707373	704098	19399H	PARTICIPANT	\N	PRESENT	0
707374	704098	08015R	PARTICIPANT	\N	PRESENT	0
707375	704098	12041X	PARTICIPANT	\N	PRESENT	0
707376	704098	19715Y	PARTICIPANT	\N	PRESENT	0
707377	704098	19525U	PARTICIPANT	\N	PRESENT	0
707378	704098	04092N	PARTICIPANT	\N	PRESENT	0
707379	704098	20086J	PARTICIPANT	\N	PRESENT	0
707380	704098	11115U	PARTICIPANT	\N	PRESENT	0
707381	704098	19703U	PARTICIPANT	\N	PRESENT	0
707382	704098	14213J	PARTICIPANT	\N	PRESENT	0
707383	704098	08069G	PARTICIPANT	\N	PRESENT	0
707384	704098	19701S	PARTICIPANT	\N	PRESENT	0
707385	704098	19798U	PARTICIPANT	\N	PRESENT	0
707386	704098	14207L	PARTICIPANT	\N	PRESENT	0
707387	704098	04043D	PARTICIPANT	\N	PRESENT	0
707388	704098	19679N	PARTICIPANT	\N	PRESENT	0
707389	704098	14215L	PARTICIPANT	\N	PRESENT	0
707390	704098	20056C	PARTICIPANT	\N	PRESENT	0
707391	704098	20074E	PARTICIPANT	\N	PRESENT	0
707360	704098	14026U	PARTICIPANT	\N	PRESENT	0
707361	704098	10006L	PARTICIPANT	\N	PRESENT	0
707392	704098	20142Y	PARTICIPANT	\N	PRESENT	0
707393	704098	20080C	PARTICIPANT	\N	PRESENT	0
707394	704098	12016W	PARTICIPANT	\N	PRESENT	0
707395	704098	14281W	PARTICIPANT	\N	PRESENT	0
707396	704098	20264J	PARTICIPANT	\N	PRESENT	0
707397	704098	11045K	PARTICIPANT	\N	PRESENT	0
707398	704098	19649G	PARTICIPANT	\N	PRESENT	0
707399	704098	20082E	PARTICIPANT	\N	PRESENT	0
707400	704098	19531S	PARTICIPANT	\N	PRESENT	0
707401	704098	19503N	PARTICIPANT	\N	PRESENT	0
707402	704098	14109K	PARTICIPANT	\N	PRESENT	0
707403	704098	20914V	PARTICIPANT	\N	PRESENT	0
707404	704098	08045X	PARTICIPANT	\N	PRESENT	0
707405	704098	14037X	PARTICIPANT	\N	PRESENT	0
707406	704098	19349W	PARTICIPANT	\N	PRESENT	0
707407	704098	14257W	PARTICIPANT	\N	PRESENT	0
707408	704098	18193Q	PARTICIPANT	\N	PRESENT	0
707409	704098	20122U	PARTICIPANT	\N	PRESENT	0
707410	704098	19563B	PARTICIPANT	\N	PRESENT	0
707411	704098	20298U	PARTICIPANT	\N	PRESENT	0
707412	704098	01024M	PARTICIPANT	\N	PRESENT	0
707413	704098	20116W	PARTICIPANT	\N	PRESENT	0
707414	704098	20042V	PARTICIPANT	\N	PRESENT	0
707415	704098	19691J	PARTICIPANT	\N	PRESENT	0
707416	704098	11077T	PARTICIPANT	\N	PRESENT	0
707417	704098	04085P	PARTICIPANT	\N	PRESENT	0
707418	704098	11074Q	PARTICIPANT	\N	PRESENT	0
707419	704098	14189C	PARTICIPANT	\N	PRESENT	0
707420	704098	14217N	PARTICIPANT	\N	PRESENT	0
707421	704098	08010L	PARTICIPANT	\N	PRESENT	0
707422	704098	14133K	PARTICIPANT	\N	PRESENT	0
707423	704098	14071N	PARTICIPANT	\N	PRESENT	0
707424	704098	14069U	PARTICIPANT	\N	PRESENT	0
707425	704098	19533U	PARTICIPANT	\N	PRESENT	0
707426	704098	05008E	PARTICIPANT	\N	PRESENT	0
707427	704098	14329V	PARTICIPANT	\N	PRESENT	0
707428	704098	20062A	PARTICIPANT	\N	PRESENT	0
707429	704098	20152B	PARTICIPANT	\N	PRESENT	0
707430	704098	19383Y	PARTICIPANT	\N	PRESENT	0
707431	704098	20120S	PARTICIPANT	\N	PRESENT	0
707432	704098	19507S	PARTICIPANT	\N	PRESENT	0
707433	704098	17737W	PARTICIPANT	\N	PRESENT	0
707434	704098	20148F	PARTICIPANT	\N	PRESENT	0
707435	704098	19657G	PARTICIPANT	\N	PRESENT	0
707436	704098	08018U	PARTICIPANT	\N	PRESENT	0
707437	704098	20044X	PARTICIPANT	\N	PRESENT	0
707438	704098	14033T	PARTICIPANT	\N	PRESENT	0
707439	704098	17367Q	PARTICIPANT	\N	PRESENT	0
707440	704098	19673G	PARTICIPANT	\N	PRESENT	0
707441	704098	11043H	PARTICIPANT	\N	PRESENT	0
707442	704098	99004R	PARTICIPANT	\N	PRESENT	0
707443	704098	11048N	PARTICIPANT	\N	PRESENT	0
707444	704098	14223L	PARTICIPANT	\N	PRESENT	0
707445	704098	20022R	PARTICIPANT	\N	PRESENT	0
707446	704098	14331P	PARTICIPANT	\N	PRESENT	0
707447	704098	20108W	PARTICIPANT	\N	PRESENT	0
707448	704098	19954N	PARTICIPANT	\N	PRESENT	0
707449	704098	20032T	PARTICIPANT	\N	PRESENT	0
707450	704098	19766L	PARTICIPANT	\N	PRESENT	0
707451	704098	19723Y	PARTICIPANT	\N	PRESENT	0
707452	704098	19621T	PARTICIPANT	\N	PRESENT	0
707453	704098	20058E	PARTICIPANT	\N	PRESENT	0
707454	704098	20266L	PARTICIPANT	\N	PRESENT	0
707455	704098	20134Y	PARTICIPANT	\N	PRESENT	0
707456	704098	20100N	PARTICIPANT	\N	PRESENT	0
707457	704098	20114U	PARTICIPANT	\N	PRESENT	0
707458	704098	19551W	PARTICIPANT	\N	PRESENT	0
707459	704098	20094J	PARTICIPANT	\N	PRESENT	0
707460	704098	11110B	PARTICIPANT	\N	PRESENT	0
707461	704098	19591F	PARTICIPANT	\N	PRESENT	0
707462	704098	19697Q	PARTICIPANT	\N	PRESENT	0
707463	704098	19367Y	PARTICIPANT	\N	PRESENT	0
707464	704098	19671E	PARTICIPANT	\N	PRESENT	0
707465	704098	19762G	PARTICIPANT	\N	PRESENT	0
707466	704098	19421M	PARTICIPANT	\N	PRESENT	0
707467	704098	11026G	PARTICIPANT	\N	PRESENT	0
707468	704098	19553Y	PARTICIPANT	\N	PRESENT	0
707469	704098	20096L	PARTICIPANT	\N	PRESENT	0
707470	704098	08061X	PARTICIPANT	\N	PRESENT	0
707471	704098	01058X	PARTICIPANT	\N	PRESENT	0
707472	704098	20066E	PARTICIPANT	\N	PRESENT	0
707473	704098	04035D	PARTICIPANT	\N	PRESENT	0
707474	704098	04033B	PARTICIPANT	\N	PRESENT	0
707475	704098	20040T	PARTICIPANT	\N	PRESENT	0
707476	704098	14225N	PARTICIPANT	\N	PRESENT	0
707485	704099	86034E	PARTICIPANT	\N	PRESENT	0
707486	704099	20108W	PARTICIPANT	\N	PRESENT	0
707487	704099	19593H	PARTICIPANT	\N	PRESENT	0
707488	704099	14109K	PARTICIPANT	\N	PRESENT	0
707489	704099	19421M	PARTICIPANT	\N	PRESENT	0
707490	704099	17779H	PARTICIPANT	\N	PRESENT	0
707491	704099	19673G	PARTICIPANT	\N	PRESENT	0
707492	704099	14329V	PARTICIPANT	\N	PRESENT	0
707493	704099	20062A	PARTICIPANT	\N	PRESENT	0
707494	704099	19691J	PARTICIPANT	\N	PRESENT	0
707495	704099	08061X	PARTICIPANT	\N	PRESENT	0
707496	704099	20130U	PARTICIPANT	\N	PRESENT	0
707497	704099	19715Y	PARTICIPANT	\N	PRESENT	0
707498	704099	17367Q	PARTICIPANT	\N	PRESENT	0
707499	704099	04092N	PARTICIPANT	\N	PRESENT	0
707500	704099	14071N	PARTICIPANT	\N	PRESENT	0
707501	704099	11048N	PARTICIPANT	\N	PRESENT	0
707502	704099	19717B	PARTICIPANT	\N	PRESENT	0
707503	704099	18193Q	PARTICIPANT	\N	PRESENT	0
707504	704099	08045X	PARTICIPANT	\N	PRESENT	0
707505	704099	20122U	PARTICIPANT	\N	PRESENT	0
707506	704099	19671E	PARTICIPANT	\N	PRESENT	0
707507	704099	20074E	PARTICIPANT	\N	PRESENT	0
707508	704099	19387D	PARTICIPANT	\N	PRESENT	0
707509	704099	11031D	PARTICIPANT	\N	PRESENT	0
707510	704099	19760E	PARTICIPANT	\N	PRESENT	0
707511	704099	12041X	PARTICIPANT	\N	PRESENT	0
707512	704099	19565D	PARTICIPANT	\N	PRESENT	0
707513	704099	14207L	PARTICIPANT	\N	PRESENT	0
707514	704099	11026G	PARTICIPANT	\N	PRESENT	0
707515	704099	14037X	PARTICIPANT	\N	PRESENT	0
707516	704099	19711U	PARTICIPANT	\N	PRESENT	0
707517	704099	01058X	PARTICIPANT	\N	PRESENT	0
707518	704099	14213J	PARTICIPANT	\N	PRESENT	0
707519	704099	19766L	PARTICIPANT	\N	PRESENT	0
707520	704099	20914V	PARTICIPANT	\N	PRESENT	0
707521	704099	20082E	PARTICIPANT	\N	PRESENT	0
707522	704099	11110B	PARTICIPANT	\N	PRESENT	0
707523	704099	20080C	PARTICIPANT	\N	PRESENT	0
707524	704099	14217N	PARTICIPANT	\N	PRESENT	0
707525	704099	20056C	PARTICIPANT	\N	PRESENT	0
707526	704099	10006L	PARTICIPANT	\N	PRESENT	0
707527	704099	11097X	PARTICIPANT	\N	PRESENT	0
707528	704099	14042U	PARTICIPANT	\N	PRESENT	0
690428	683947	08010L	PARTICIPANT	\N	PRESENT	0
690606	688421	14133K	PARTICIPANT	\N	PRESENT	0
690607	688421	20104S	PARTICIPANT	\N	PRESENT	0
690608	688421	11083R	PARTICIPANT	\N	PRESENT	0
690609	688421	19333N	PARTICIPANT	\N	PRESENT	0
690610	688421	19531S	PARTICIPANT	\N	PRESENT	0
690611	688421	19441R	PARTICIPANT	\N	PRESENT	0
690612	688421	14331P	PARTICIPANT	\N	PRESENT	0
690613	688421	10015M	PARTICIPANT	\N	PRESENT	0
690614	688421	14073Q	PARTICIPANT	\N	PRESENT	0
690615	688421	11026G	PARTICIPANT	\N	PRESENT	0
690637	690632	14331P	PARTICIPANT	\N	PRESENT	0
690638	690632	14073Q	PARTICIPANT	\N	PRESENT	0
690639	690632	11083R	PARTICIPANT	\N	PRESENT	0
691153	691148	19711U	PARTICIPANT	\N	PRESENT	1
691185	691184	04047H	PARTICIPANT	\N	PRESENT	0
691186	691184	04042C	PARTICIPANT	\N	PRESENT	0
691191	691190	11048N	PARTICIPANT	\N	PRESENT	0
691193	691190	08011M	PARTICIPANT	\N	PRESENT	0
691256	690697	14187A	PARTICIPANT	\N	PRESENT	0
691257	690697	10015M	PARTICIPANT	\N	PRESENT	0
692615	692614	14133K	PARTICIPANT	\N	PRESENT	0
692616	692614	14097Y	PARTICIPANT	\N	PRESENT	0
692617	692614	11066Q	PARTICIPANT	\N	PRESENT	0
692619	692618	16685X	PARTICIPANT	\N	PRESENT	0
695122	694937	19760E	PARTICIPANT	\N	PRESENT	0
695123	694937	14030Q	PARTICIPANT	\N	PRESENT	0
695124	694937	17737W	PARTICIPANT	\N	PRESENT	0
695125	694937	20090E	PARTICIPANT	\N	PRESENT	0
695126	694937	19693L	PARTICIPANT	\N	PRESENT	0
695127	694937	19719D	PARTICIPANT	\N	PRESENT	0
695128	694937	10006L	PARTICIPANT	\N	PRESENT	0
695129	694937	14217N	PARTICIPANT	\N	PRESENT	0
695130	694937	08018U	PARTICIPANT	\N	PRESENT	0
695131	694937	19691J	PARTICIPANT	\N	PRESENT	0
695132	694937	19591F	PARTICIPANT	\N	PRESENT	0
695133	694937	14213J	PARTICIPANT	\N	PRESENT	0
695134	694937	20066E	PARTICIPANT	\N	PRESENT	0
695135	694937	19447X	PARTICIPANT	\N	PRESENT	0
695136	694937	14059S	PARTICIPANT	\N	PRESENT	0
695137	694937	14147R	PARTICIPANT	\N	PRESENT	0
695138	694937	11067R	PARTICIPANT	\N	PRESENT	0
695139	694937	14071N	PARTICIPANT	\N	PRESENT	0
695140	694937	20130U	PARTICIPANT	\N	PRESENT	0
695141	694937	04057K	PARTICIPANT	\N	PRESENT	0
702745	701687	01024M	PARTICIPANT	\N	PRESENT	0
702746	701687	19721W	PARTICIPANT	\N	PRESENT	0
702747	701687	14191V	PARTICIPANT	\N	PRESENT	0
702748	701687	19319Q	PARTICIPANT	\N	PRESENT	0
702749	701687	14105F	PARTICIPANT	\N	PRESENT	0
702750	701687	20064C	PARTICIPANT	\N	PRESENT	0
702751	701687	98022P	PARTICIPANT	\N	PRESENT	0
702752	701687	14267Y	PARTICIPANT	\N	PRESENT	0
702753	701687	11064N	PARTICIPANT	\N	PRESENT	0
702754	701687	11083R	PARTICIPANT	\N	PRESENT	0
702755	701687	14211G	PARTICIPANT	\N	PRESENT	0
702756	701687	14255U	PARTICIPANT	\N	PRESENT	0
702757	701687	17023S	PARTICIPANT	\N	PRESENT	0
702758	701687	19443T	PARTICIPANT	\N	EXCUSE	0
702761	701789	19383Y	PARTICIPANT	\N	PRESENT	0
702762	701789	20088L	PARTICIPANT	\N	PRESENT	0
702763	701789	19515S	PARTICIPANT	\N	PRESENT	0
702764	701789	19782L	PARTICIPANT	\N	PRESENT	0
702765	701789	01043Q	PARTICIPANT	\N	PRESENT	0
702766	701789	14357A	PARTICIPANT	\N	PRESENT	0
702767	701789	19441R	PARTICIPANT	\N	PRESENT	0
702768	701789	20078J	PARTICIPANT	\N	PRESENT	0
702769	701789	20082E	PARTICIPANT	\N	PRESENT	0
702770	701789	20094J	PARTICIPANT	\N	PRESENT	0
702771	701789	19866P	PARTICIPANT	\N	PRESENT	0
702772	701789	04045F	PARTICIPANT	\N	PRESENT	0
702773	701789	20104S	PARTICIPANT	\N	PRESENT	0
702774	701789	11099A	PARTICIPANT	\N	PRESENT	0
702775	701789	19705W	PARTICIPANT	\N	PRESENT	0
702776	701789	08015R	PARTICIPANT	\N	PRESENT	0
702777	701789	19369B	PARTICIPANT	\N	PRESENT	0
702778	701789	20018V	PARTICIPANT	\N	PRESENT	0
702779	701789	08028W	PARTICIPANT	\N	PRESENT	0
702780	701789	19563B	PARTICIPANT	\N	PRESENT	0
702781	701789	14329V	PARTICIPANT	\N	PRESENT	0
702782	701789	14037X	PARTICIPANT	\N	PRESENT	0
702783	701789	20028X	PARTICIPANT	\N	PRESENT	0
702784	701789	14038Y	PARTICIPANT	\N	PRESENT	0
702785	701789	20030R	PARTICIPANT	\N	PRESENT	0
702786	701789	19467C	PARTICIPANT	\N	PRESENT	0
702787	701789	20034V	PARTICIPANT	\N	PRESENT	0
702788	701789	14187A	PARTICIPANT	\N	PRESENT	0
702789	701789	20144B	PARTICIPANT	\N	PRESENT	0
702790	701789	19695N	PARTICIPANT	\N	PRESENT	0
702791	701789	14033T	PARTICIPANT	\N	PRESENT	0
702792	701789	11090Q	PRESIDENT	0	PRESENT	0
702793	701789	01025N	PARTICIPANT	\N	PRESENT	0
702794	701789	20054A	PARTICIPANT	\N	PRESENT	0
702795	701789	14205J	PARTICIPANT	\N	PRESENT	0
702796	701789	20060X	PARTICIPANT	\N	PRESENT	0
702797	701789	20062A	PARTICIPANT	\N	PRESENT	0
702798	701789	19507S	PARTICIPANT	\N	PRESENT	0
702799	701789	20286Q	PARTICIPANT	\N	PRESENT	0
702800	701789	20298U	PARTICIPANT	\N	PRESENT	0
702801	701789	19747H	PARTICIPANT	\N	PRESENT	0
702802	701789	14207L	PARTICIPANT	\N	PRESENT	0
702803	701789	14257W	PARTICIPANT	\N	PRESENT	0
702804	701789	19413M	PARTICIPANT	\N	EXCUSE	0
702805	701789	19631V	PARTICIPANT	\N	EXCUSE	0
702813	701791	19383Y	PARTICIPANT	\N	PRESENT	0
702814	701791	20088L	PARTICIPANT	\N	PRESENT	0
702815	701791	19515S	PARTICIPANT	\N	PRESENT	0
702816	701791	19782L	PARTICIPANT	\N	PRESENT	0
702817	701791	01043Q	PARTICIPANT	\N	PRESENT	0
702818	701791	14357A	PARTICIPANT	\N	PRESENT	0
702819	701791	19441R	PARTICIPANT	\N	PRESENT	0
702820	701791	20078J	PARTICIPANT	\N	PRESENT	0
702821	701791	20082E	PARTICIPANT	\N	PRESENT	0
702822	701791	20094J	PARTICIPANT	\N	PRESENT	0
702823	701791	19866P	PARTICIPANT	\N	PRESENT	0
702824	701791	04045F	PARTICIPANT	\N	PRESENT	0
702825	701791	20104S	PARTICIPANT	\N	PRESENT	0
702826	701791	11099A	PARTICIPANT	\N	PRESENT	0
702827	701791	19705W	PARTICIPANT	\N	PRESENT	0
702828	701791	19707Y	PARTICIPANT	\N	PRESENT	0
702829	701791	08015R	PARTICIPANT	\N	PRESENT	0
702830	701791	19369B	PARTICIPANT	\N	PRESENT	0
702831	701791	20018V	PARTICIPANT	\N	PRESENT	0
702832	701791	08028W	PARTICIPANT	\N	PRESENT	0
702833	701791	19563B	PARTICIPANT	\N	PRESENT	0
702834	701791	14329V	PARTICIPANT	\N	PRESENT	0
702835	701791	14037X	PARTICIPANT	\N	PRESENT	0
702836	701791	20028X	PARTICIPANT	\N	PRESENT	0
702837	701791	14038Y	PARTICIPANT	\N	PRESENT	0
702838	701791	20030R	PARTICIPANT	\N	PRESENT	0
702839	701791	19467C	PARTICIPANT	\N	PRESENT	0
702840	701791	20034V	PARTICIPANT	\N	PRESENT	0
702841	701791	14187A	PARTICIPANT	\N	PRESENT	0
702842	701791	20144B	PARTICIPANT	\N	PRESENT	0
702843	701791	19695N	PARTICIPANT	\N	PRESENT	0
702844	701791	14033T	PARTICIPANT	\N	PRESENT	0
702845	701791	11090Q	PRESIDENT	0	PRESENT	0
702846	701791	01025N	PARTICIPANT	\N	PRESENT	0
702847	701791	20054A	PARTICIPANT	\N	PRESENT	0
702848	701791	14205J	PARTICIPANT	\N	PRESENT	0
702849	701791	20060X	PARTICIPANT	\N	PRESENT	0
702850	701791	20062A	PARTICIPANT	\N	PRESENT	0
702851	701791	14251Q	PARTICIPANT	\N	PRESENT	0
702852	701791	19507S	PARTICIPANT	\N	PRESENT	0
702853	701791	20286Q	PARTICIPANT	\N	PRESENT	0
702854	701791	20298U	PARTICIPANT	\N	PRESENT	0
702855	701791	19747H	PARTICIPANT	\N	PRESENT	0
702856	701791	14207L	PARTICIPANT	\N	PRESENT	0
702857	701791	14257W	PARTICIPANT	\N	PRESENT	0
702858	701791	19413M	PARTICIPANT	\N	EXCUSE	0
702859	701791	19631V	PARTICIPANT	\N	EXCUSE	0
702901	701687	14055N	PARTICIPANT	\N	PRESENT	0
702902	702661	07029T	PARTICIPANT	\N	PRESENT	0
702953	701645	98022P	PARTICIPANT	\N	PRESENT	0
702954	701645	19511N	PARTICIPANT	\N	PRESENT	0
702957	701645	19319Q	PARTICIPANT	\N	PRESENT	0
702958	701645	14195A	PARTICIPANT	\N	PRESENT	0
702959	701645	14107H	PARTICIPANT	\N	PRESENT	0
702960	701645	19866P	PARTICIPANT	\N	PRESENT	0
693540	692322	20042V	PARTICIPANT	\N	PRESENT	0
693541	692322	01024M	PARTICIPANT	\N	PRESENT	0
693542	692322	14191V	PARTICIPANT	\N	PRESENT	0
693543	692322	19319Q	PARTICIPANT	\N	PRESENT	0
693544	692322	14105F	PARTICIPANT	\N	PRESENT	0
693545	692322	20064C	PARTICIPANT	\N	PRESENT	0
693546	692322	98022P	PARTICIPANT	\N	PRESENT	0
693547	692322	11064N	PARTICIPANT	\N	PRESENT	0
693548	692322	14267Y	PARTICIPANT	\N	PRESENT	0
693549	692322	11083R	PARTICIPANT	\N	PRESENT	0
693550	692322	14211G	PARTICIPANT	\N	PRESENT	0
693551	692322	14255U	PARTICIPANT	\N	PRESENT	0
693552	692322	08056B	PARTICIPANT	\N	EXCUSE	0
693553	692322	19443T	PARTICIPANT	\N	EXCUSE	0
693554	692322	11041F	PARTICIPANT	\N	EXCUSE	0
693555	692966	11048N	PARTICIPANT	\N	EXCUSE	0
693556	692966	14189C	PARTICIPANT	\N	EXCUSE	0
693557	692322	16685X	PARTICIPANT	\N	PRESENT	0
693558	692322	19669L	PARTICIPANT	\N	PRESENT	0
693559	692966	14225N	PRESIDENT	0	PRESENT	0
693560	692322	19721W	PARTICIPANT	\N	PRESENT	0
693562	691611	19527W	PARTICIPANT	\N	PRESENT	0
693563	691611	20132W	PARTICIPANT	\N	PRESENT	0
693564	691611	19643A	PARTICIPANT	\N	PRESENT	0
693565	691611	04070G	PARTICIPANT	\N	PRESENT	0
693566	691611	19699S	PARTICIPANT	\N	PRESENT	0
693567	691611	19533U	PARTICIPANT	\N	PRESENT	0
693568	691611	19611R	PRESIDENT	0	PRESENT	0
693569	691611	20142Y	PARTICIPANT	\N	PRESENT	0
693570	691611	20048C	PARTICIPANT	\N	PRESENT	0
693571	691611	19693L	PARTICIPANT	\N	PRESENT	0
693572	691611	20152B	PARTICIPANT	\N	PRESENT	0
693573	691611	20052X	PARTICIPANT	\N	PRESENT	0
693574	691611	14229S	PARTICIPANT	\N	PRESENT	0
693575	691611	14030Q	PARTICIPANT	\N	PRESENT	0
693576	691611	20058E	PARTICIPANT	\N	PRESENT	0
693577	691611	20056C	PARTICIPANT	\N	PRESENT	0
693578	691611	20264J	PARTICIPANT	\N	PRESENT	0
693579	691611	04059M	PARTICIPANT	\N	PRESENT	0
693580	691611	14109K	PARTICIPANT	\N	PRESENT	0
693581	691611	20112S	PARTICIPANT	\N	PRESENT	0
693582	691611	11104D	PARTICIPANT	\N	PRESENT	0
693583	691611	20124W	PARTICIPANT	\N	PRESENT	0
693584	691611	19758L	PARTICIPANT	\N	PRESENT	0
693585	691611	20026V	PARTICIPANT	\N	PRESENT	0
693591	692966	20086J	PARTICIPANT	\N	PRESENT	0
693592	692966	20036X	PARTICIPANT	\N	PRESENT	0
693593	692966	20252E	PARTICIPANT	\N	PRESENT	0
693594	692966	14121F	PARTICIPANT	\N	PRESENT	0
693595	692966	08011M	PARTICIPANT	\N	PRESENT	0
693596	692966	20116W	PARTICIPANT	\N	PRESENT	0
693597	692966	99004R	PARTICIPANT	\N	PRESENT	0
693598	692966	11074Q	PARTICIPANT	\N	PRESENT	0
693599	692966	20914V	PARTICIPANT	\N	PRESENT	0
693604	692322	19565D	PARTICIPANT	\N	PRESENT	0
693620	692966	14327T	PARTICIPANT	\N	PRESENT	0
693621	692966	14331P	PARTICIPANT	\N	PRESENT	0
693622	692966	20080C	PARTICIPANT	\N	PRESENT	0
693623	692966	19667J	PARTICIPANT	\N	PRESENT	0
693624	692966	20044X	PARTICIPANT	\N	PRESENT	0
693625	692966	14173T	PARTICIPANT	\N	PRESENT	0
693626	692966	08009T	PARTICIPANT	\N	PRESENT	0
693627	692966	08010L	PARTICIPANT	\N	PRESENT	0
693628	692966	14253S	PARTICIPANT	\N	PRESENT	0
693656	692966	01057W	PARTICIPANT	\N	PRESENT	0
693633	692322	11027H	PARTICIPANT	\N	PRESENT	0
693634	692966	19671E	PARTICIPANT	\N	PRESENT	0
693635	692966	07029T	PARTICIPANT	\N	PRESENT	0
693636	692966	20126Y	PARTICIPANT	\N	PRESENT	0
693637	692966	11065P	PARTICIPANT	\N	PRESENT	0
693638	692966	19711U	PARTICIPANT	\N	PRESENT	0
693639	692966	19687N	PARTICIPANT	\N	PRESENT	0
693640	692966	11040E	PARTICIPANT	\N	PRESENT	0
693641	692966	14083S	PARTICIPANT	\N	PRESENT	0
693642	692966	08073C	PARTICIPANT	\N	PRESENT	0
693643	692966	20050V	PARTICIPANT	\N	PRESENT	0
693644	692322	01058X	PARTICIPANT	\N	PRESENT	0
693649	692966	11070L	PARTICIPANT	\N	PRESENT	0
693650	692966	19349W	PARTICIPANT	\N	PRESENT	0
693651	692966	20070A	PARTICIPANT	\N	PRESENT	0
693653	691611	19593H	PARTICIPANT	\N	PRESENT	0
693654	691611	20172F	PARTICIPANT	\N	PRESENT	0
693657	692966	19647E	PARTICIPANT	\N	PRESENT	0
693658	692966	19479G	PARTICIPANT	\N	PRESENT	0
693660	692322	11080N	PARTICIPANT	\N	PRESENT	0
693664	691611	14073Q	PARTICIPANT	\N	PRESENT	0
693665	692321	14001X	PARTICIPANT	\N	PRESENT	0
693667	692322	07033P	PARTICIPANT	\N	PRESENT	0
693668	692322	14055N	PARTICIPANT	\N	PRESENT	0
693669	692322	14249W	PARTICIPANT	\N	PRESENT	0
693672	692966	11012A	PARTICIPANT	\N	PRESENT	0
693673	692966	19762G	PARTICIPANT	\N	PRESENT	0
693675	692966	19741B	PARTICIPANT	\N	PRESENT	0
693676	692457	19383Y	PARTICIPANT	\N	PRESENT	0
693677	692457	19768N	PARTICIPANT	\N	PRESENT	0
693678	692457	20088L	PARTICIPANT	\N	PRESENT	0
693679	692457	19515S	PARTICIPANT	\N	PRESENT	0
693680	692457	20092G	PARTICIPANT	\N	PRESENT	0
693681	692457	19782L	PARTICIPANT	\N	PRESENT	0
693682	692457	19441R	PARTICIPANT	\N	PRESENT	0
693683	692457	20078J	PARTICIPANT	\N	PRESENT	0
693684	692457	20082E	PARTICIPANT	\N	PRESENT	0
693685	692457	20094J	PARTICIPANT	\N	PRESENT	0
693686	692457	04045F	PARTICIPANT	\N	PRESENT	0
693687	692457	19866P	PARTICIPANT	\N	PRESENT	0
693688	692457	19631V	PARTICIPANT	\N	PRESENT	0
693689	692457	20104S	PARTICIPANT	\N	PRESENT	0
693690	692457	19705W	PARTICIPANT	\N	PRESENT	0
693691	692457	19707Y	PARTICIPANT	\N	PRESENT	0
693692	692457	08015R	PARTICIPANT	\N	PRESENT	0
693693	692457	19575F	PARTICIPANT	\N	PRESENT	0
693694	692457	20018V	PARTICIPANT	\N	PRESENT	0
693695	692457	19563B	PARTICIPANT	\N	PRESENT	0
693696	692457	20028X	PARTICIPANT	\N	PRESENT	0
693697	692457	14037X	PARTICIPANT	\N	PRESENT	0
693698	692457	14329V	PARTICIPANT	\N	PRESENT	0
693699	692457	14038Y	PARTICIPANT	\N	PRESENT	0
693700	692457	19467C	PARTICIPANT	\N	PRESENT	0
693701	692457	20034V	PARTICIPANT	\N	PRESENT	0
693702	692457	14187A	PARTICIPANT	\N	PRESENT	0
693703	692457	19695N	PARTICIPANT	\N	PRESENT	0
693704	692457	11090Q	PRESIDENT	0	PRESENT	0
693705	692457	20054A	PARTICIPANT	\N	PRESENT	0
693706	692457	14205J	PARTICIPANT	\N	PRESENT	0
693707	692457	20062A	PARTICIPANT	\N	PRESENT	0
693708	692457	19507S	PARTICIPANT	\N	PRESENT	0
693709	692457	20286Q	PARTICIPANT	\N	PRESENT	0
693710	692457	20298U	PARTICIPANT	\N	PRESENT	0
693711	692457	19747H	PARTICIPANT	\N	PRESENT	0
693712	692457	14207L	PARTICIPANT	\N	PRESENT	0
693713	690706	19333N	PARTICIPANT	\N	PRESENT	0
693714	690706	19549D	PARTICIPANT	\N	PRESENT	0
693715	690706	19387D	PARTICIPANT	\N	PRESENT	0
693716	690706	14219Q	PRESIDENT	0	PRESENT	0
693717	690706	19820Y	PARTICIPANT	\N	PRESENT	0
693718	690706	19826F	PARTICIPANT	\N	PRESENT	0
693719	690706	14221J	PARTICIPANT	\N	PRESENT	0
693720	690706	20102Q	PARTICIPANT	\N	PRESENT	0
693721	690706	19599P	PARTICIPANT	\N	PRESENT	0
693722	690706	19637C	PARTICIPANT	\N	PRESENT	0
693723	690706	20096L	PARTICIPANT	\N	PRESENT	0
693724	690706	18083K	PARTICIPANT	\N	PRESENT	0
693725	690706	20100N	PARTICIPANT	\N	PRESENT	0
693726	690706	05012A	PARTICIPANT	\N	PRESENT	0
693727	690706	20118Y	PARTICIPANT	\N	PRESENT	0
693728	690706	19503N	PARTICIPANT	\N	PRESENT	0
693729	690706	20020P	PARTICIPANT	\N	PRESENT	0
693730	690706	17367Q	PARTICIPANT	\N	PRESENT	0
693731	690706	20024T	PARTICIPANT	\N	PRESENT	0
693732	690706	20120S	PARTICIPANT	\N	PRESENT	0
693733	690706	20032T	PARTICIPANT	\N	PRESENT	0
693734	690706	14031R	PARTICIPANT	\N	PRESENT	0
693735	690706	20038A	PARTICIPANT	\N	PRESENT	0
693736	690706	14169X	PARTICIPANT	\N	PRESENT	0
693737	690706	17229F	PARTICIPANT	\N	PRESENT	0
693738	690706	20068G	PARTICIPANT	\N	PRESENT	0
693739	690706	19745F	PARTICIPANT	\N	PRESENT	0
693740	692322	11115U	PARTICIPANT	\N	PRESENT	0
693741	692322	19347U	PARTICIPANT	\N	PRESENT	0
693742	692322	19583F	PARTICIPANT	\N	PRESENT	0
693743	690706	08060W	PARTICIPANT	\N	PRESENT	0
686259	683231	95063L	PARTICIPANT	\N	PRESENT	0
686305	683231	19697Q	PARTICIPANT	\N	PRESENT	0
686306	683231	11064N	PARTICIPANT	\N	PRESENT	0
686307	683231	20266L	PARTICIPANT	\N	PRESENT	0
686308	683231	20106U	PARTICIPANT	\N	PRESENT	0
686309	683231	17779H	PARTICIPANT	\N	PRESENT	0
686310	683231	19760E	PARTICIPANT	\N	PRESENT	0
686311	683231	19713W	PARTICIPANT	\N	PRESENT	0
686312	683231	19553Y	PARTICIPANT	\N	PRESENT	0
686313	683231	14187A	PARTICIPANT	\N	PRESENT	0
686329	683231	14089Y	PARTICIPANT	\N	PRESENT	0
686330	683231	14073Q	PARTICIPANT	\N	PRESENT	0
686331	683231	14071N	PARTICIPANT	\N	PRESENT	0
686333	683231	19525U	PARTICIPANT	\N	PRESENT	0
686334	683231	14213J	PARTICIPANT	\N	PRESENT	0
686335	683231	19415P	PARTICIPANT	\N	PRESENT	0
686336	683231	04045F	PARTICIPANT	\N	PRESENT	0
686337	683231	08061X	PARTICIPANT	\N	PRESENT	0
686338	683231	14069U	PARTICIPANT	\N	PRESENT	0
686339	683231	20152B	PARTICIPANT	\N	PRESENT	0
686340	683231	20100N	PARTICIPANT	\N	PRESENT	0
686341	683231	18193Q	PARTICIPANT	\N	PRESENT	0
686342	683231	17965H	PARTICIPANT	\N	PRESENT	0
686344	683231	01058X	PARTICIPANT	\N	PRESENT	0
686345	683231	19629C	PARTICIPANT	\N	PRESENT	0
686350	683231	14037X	PARTICIPANT	\N	PRESENT	0
686351	683231	20084G	PARTICIPANT	\N	PRESENT	0
686358	683231	20130U	PARTICIPANT	\N	PRESENT	0
686359	683231	19798U	PARTICIPANT	\N	PRESENT	0
686361	683231	19729F	PARTICIPANT	\N	PRESENT	0
686362	683231	19651A	PARTICIPANT	\N	PRESENT	0
686368	683231	11031D	PARTICIPANT	\N	PRESENT	0
686366	683231	04057K	PARTICIPANT	\N	PRESENT	0
686367	683231	19057M	PARTICIPANT	\N	PRESENT	0
686369	683231	20114U	PARTICIPANT	\N	PRESENT	0
686370	683231	14255U	PARTICIPANT	\N	PRESENT	0
686371	683231	11067R	PARTICIPANT	\N	PRESENT	0
686372	683231	11045K	PARTICIPANT	\N	PRESENT	0
686373	683231	19591F	PARTICIPANT	\N	PRESENT	0
686374	683231	19301E	PARTICIPANT	\N	PRESENT	0
686375	683231	20180F	PARTICIPANT	\N	PRESENT	0
686376	683231	14221J	PARTICIPANT	\N	PRESENT	0
686377	683231	19447X	PARTICIPANT	\N	PRESENT	0
686378	683231	14259Y	PARTICIPANT	\N	PRESENT	0
686379	683231	20092G	PARTICIPANT	\N	PRESENT	0
686380	683231	01024M	PARTICIPANT	\N	PRESENT	0
686381	683232	95063L	PARTICIPANT	\N	PRESENT	0
686418	683232	20114U	PARTICIPANT	\N	PRESENT	0
686383	683232	20266L	PARTICIPANT	\N	PRESENT	0
686384	683232	20106U	PARTICIPANT	\N	PRESENT	0
686419	683232	14083S	PARTICIPANT	\N	PRESENT	0
686386	683232	19760E	PARTICIPANT	\N	PRESENT	0
686420	683232	19415P	PARTICIPANT	\N	PRESENT	0
686388	683232	19553Y	PARTICIPANT	\N	PRESENT	0
686421	683232	19697Q	PARTICIPANT	\N	PRESENT	0
686422	683232	11027H	PARTICIPANT	\N	PRESENT	0
686391	683232	19525U	PARTICIPANT	\N	PRESENT	0
686392	683232	14213J	PARTICIPANT	\N	PRESENT	0
686393	683232	04045F	PARTICIPANT	\N	PRESENT	0
686394	683232	08061X	PARTICIPANT	\N	PRESENT	0
686423	683232	19649G	PARTICIPANT	\N	PRESENT	0
686396	683232	20100N	PARTICIPANT	\N	PRESENT	0
686397	683232	18193Q	PARTICIPANT	\N	PRESENT	0
686398	683232	17965H	PARTICIPANT	\N	PRESENT	0
686399	683232	19629C	PARTICIPANT	\N	PRESENT	0
686400	683232	19798U	PARTICIPANT	\N	PRESENT	0
686401	683232	19729F	PARTICIPANT	\N	PRESENT	0
686402	683232	19651A	PARTICIPANT	\N	PRESENT	0
686403	683232	04057K	PARTICIPANT	\N	PRESENT	0
686404	683232	19057M	PARTICIPANT	\N	PRESENT	0
686405	683232	11031D	PARTICIPANT	\N	PRESENT	0
686424	683232	14071N	PARTICIPANT	\N	PRESENT	0
686407	683232	14255U	PARTICIPANT	\N	PRESENT	0
686408	683232	11067R	PARTICIPANT	\N	PRESENT	0
686409	683232	11045K	PARTICIPANT	\N	PRESENT	0
686410	683232	19591F	PARTICIPANT	\N	PRESENT	0
686411	683232	19301E	PARTICIPANT	\N	PRESENT	0
686412	683232	20180F	PARTICIPANT	\N	PRESENT	0
686413	683232	14221J	PARTICIPANT	\N	PRESENT	0
686414	683232	19447X	PARTICIPANT	\N	PRESENT	0
686425	683232	14259Y	PARTICIPANT	\N	PRESENT	0
686416	683232	20092G	PARTICIPANT	\N	PRESENT	0
686417	683232	01024M	PARTICIPANT	\N	PRESENT	0
686426	683232	20090E	PARTICIPANT	\N	PRESENT	0
686427	683232	14089Y	PARTICIPANT	\N	PRESENT	0
686429	683232	19715Y	PARTICIPANT	\N	PRESENT	0
686432	683232	20098N	PARTICIPANT	\N	PRESENT	0
686433	683232	11033F	PARTICIPANT	\N	PRESENT	0
686434	683232	11101A	PARTICIPANT	\N	PRESENT	0
686435	683232	20070A	PARTICIPANT	\N	PRESENT	0
686436	683232	19441R	PARTICIPANT	\N	PRESENT	0
686437	683232	19577H	PARTICIPANT	\N	PRESENT	0
686438	683232	11072N	PARTICIPANT	\N	PRESENT	0
686439	683232	04047H	PARTICIPANT	\N	PRESENT	0
686484	683233	19057M	PARTICIPANT	\N	PRESENT	0
686485	683233	19527W	PARTICIPANT	\N	PRESENT	0
686486	683233	19758L	PARTICIPANT	\N	PRESENT	0
686487	683233	14030Q	PARTICIPANT	\N	PRESENT	0
686488	683233	20132W	PARTICIPANT	\N	PRESENT	0
686489	683233	14071N	PARTICIPANT	\N	PRESENT	0
686490	683233	17589D	PARTICIPANT	\N	PRESENT	0
686491	683233	20134Y	PARTICIPANT	\N	PRESENT	0
686492	683233	20058E	PARTICIPANT	\N	PRESENT	0
686498	683233	20062A	PARTICIPANT	\N	PRESENT	0
686499	683233	20032T	PARTICIPANT	\N	PRESENT	0
686500	683233	20142Y	PARTICIPANT	\N	PRESENT	0
686501	683233	17965H	PARTICIPANT	\N	PRESENT	0
686503	683233	18193Q	PARTICIPANT	\N	PRESENT	0
686504	683233	19631V	PARTICIPANT	\N	PRESENT	0
686505	683233	14021P	PARTICIPANT	\N	PRESENT	0
686514	683233	19683J	PARTICIPANT	\N	PRESENT	0
686516	683233	19333N	PARTICIPANT	\N	PRESENT	0
686517	683233	20060X	PARTICIPANT	\N	PRESENT	0
686518	683233	20264J	PARTICIPANT	\N	PRESENT	0
686520	683233	14229S	PARTICIPANT	\N	PRESENT	0
686522	683233	08045X	PARTICIPANT	\N	PRESENT	0
686526	683233	20080C	PARTICIPANT	\N	PRESENT	0
686527	683233	19611R	PARTICIPANT	\N	PRESENT	0
686528	683233	19691J	PARTICIPANT	\N	PRESENT	0
686529	683233	14213J	PARTICIPANT	\N	PRESENT	0
686530	683233	20152B	PARTICIPANT	\N	PRESENT	0
686531	683233	19599P	PARTICIPANT	\N	PRESENT	0
686538	683233	19347U	PARTICIPANT	\N	PRESENT	0
686542	683233	11067R	PARTICIPANT	\N	PRESENT	0
686553	683233	19533U	PARTICIPANT	\N	PRESENT	0
686556	683233	20092G	PARTICIPANT	\N	PRESENT	0
686557	683233	19669L	PARTICIPANT	\N	PRESENT	0
686558	683233	11085T	PARTICIPANT	\N	PRESENT	0
686559	683233	14231L	PARTICIPANT	\N	PRESENT	0
686482	683233	11045K	PARTICIPANT	\N	PRESENT	0
686483	683233	14109K	PARTICIPANT	\N	PRESENT	0
686560	683233	19585H	PARTICIPANT	\N	PRESENT	0
686561	683233	19503N	PARTICIPANT	\N	PRESENT	0
686562	683233	20070A	PARTICIPANT	\N	PRESENT	0
686563	683233	19647E	PARTICIPANT	\N	PRESENT	0
686564	683233	20082E	PARTICIPANT	\N	PRESENT	0
686565	683233	08012N	PARTICIPANT	\N	PRESENT	0
686569	683233	14195A	PARTICIPANT	\N	PRESENT	0
686570	683233	11027H	PARTICIPANT	\N	PRESENT	0
686571	683233	11064N	PARTICIPANT	\N	PRESENT	0
686573	683233	08061X	PARTICIPANT	\N	PRESENT	0
686575	683233	17779H	PARTICIPANT	\N	PRESENT	0
686576	683233	19715Y	PARTICIPANT	\N	PRESENT	0
686578	683233	19693L	PARTICIPANT	\N	PRESENT	0
686579	683233	19531S	PARTICIPANT	\N	PRESENT	0
686580	683233	20114U	PARTICIPANT	\N	PRESENT	0
686582	683233	20130U	PARTICIPANT	\N	PRESENT	0
686583	683233	20068G	PARTICIPANT	\N	PRESENT	0
686584	683233	19553Y	PARTICIPANT	\N	PRESENT	0
686585	683233	19713W	PARTICIPANT	\N	PRESENT	0
686586	683233	11012A	PARTICIPANT	\N	PRESENT	0
686587	683233	20094J	PARTICIPANT	\N	PRESENT	0
686588	683234	11045K	PARTICIPANT	\N	PRESENT	0
686590	683234	19057M	PARTICIPANT	\N	PRESENT	0
686596	683234	17589D	PARTICIPANT	\N	PRESENT	0
707529	704099	98022P	PARTICIPANT	\N	PRESENT	0
707530	704099	17965H	PARTICIPANT	\N	PRESENT	0
707531	704099	20100N	PARTICIPANT	\N	PRESENT	0
707532	704099	19549D	PARTICIPANT	\N	PRESENT	0
707533	704099	14281W	PARTICIPANT	\N	PRESENT	0
707534	704099	19507S	PARTICIPANT	\N	PRESENT	0
707535	704099	19533U	PARTICIPANT	\N	PRESENT	0
707536	704099	19649G	PARTICIPANT	\N	PRESENT	0
707537	704099	11045K	PARTICIPANT	\N	PRESENT	0
707538	704099	14257W	PARTICIPANT	\N	PRESENT	0
707539	704099	11074Q	PARTICIPANT	\N	PRESENT	0
707540	704099	19695N	PARTICIPANT	\N	PRESENT	0
707541	704099	20052X	PARTICIPANT	\N	PRESENT	0
707542	704099	19745F	PARTICIPANT	\N	PRESENT	0
707543	704099	20142Y	PARTICIPANT	\N	PRESENT	0
707544	704099	19383Y	PARTICIPANT	\N	PRESENT	0
707545	704099	14331P	PARTICIPANT	\N	PRESENT	0
707546	704099	11090Q	PARTICIPANT	\N	PRESENT	0
707547	704099	04033B	PARTICIPANT	\N	PRESENT	0
707548	704099	14223L	PARTICIPANT	\N	PRESENT	0
707549	704099	19697Q	PARTICIPANT	\N	PRESENT	0
707550	704099	08010L	PARTICIPANT	\N	PRESENT	0
707551	704099	19703U	PARTICIPANT	\N	PRESENT	0
707552	704099	19657G	PARTICIPANT	\N	PRESENT	0
707553	704099	14169X	PARTICIPANT	\N	PRESENT	0
707554	704099	20044X	PARTICIPANT	\N	PRESENT	0
707555	704099	19399H	PARTICIPANT	\N	PRESENT	0
707556	704099	19679N	PARTICIPANT	\N	PRESENT	0
707557	704099	14225N	PARTICIPANT	\N	PRESENT	0
707558	704099	20264J	PARTICIPANT	\N	PRESENT	0
707559	704099	20040T	PARTICIPANT	\N	PRESENT	0
707560	704099	19577H	PARTICIPANT	\N	PRESENT	0
707561	704099	11053K	PARTICIPANT	\N	PRESENT	0
707562	704099	19569H	PARTICIPANT	\N	PRESENT	0
707563	704099	19367Y	PARTICIPANT	\N	PRESENT	0
707564	704099	05008E	PARTICIPANT	\N	PRESENT	0
707565	704099	19581D	PARTICIPANT	\N	PRESENT	0
707566	704099	20266L	PARTICIPANT	\N	PRESENT	0
707567	704099	20094J	PARTICIPANT	\N	PRESENT	0
707568	704099	11077T	PARTICIPANT	\N	PRESENT	0
707569	704099	14033T	PARTICIPANT	\N	PRESENT	0
707570	704099	20096L	PARTICIPANT	\N	PRESENT	0
707571	704099	20020P	PARTICIPANT	\N	PRESENT	0
707572	704099	17737W	PARTICIPANT	\N	PRESENT	0
707573	704099	20032T	PARTICIPANT	\N	PRESENT	0
707574	704099	20022R	PARTICIPANT	\N	PRESENT	0
707575	704099	19551W	PARTICIPANT	\N	PRESENT	0
707576	704099	11072N	PARTICIPANT	\N	PRESENT	0
707577	704099	19553Y	PARTICIPANT	\N	PRESENT	0
707578	704099	19621T	PARTICIPANT	\N	PRESENT	0
707579	704099	20116W	PARTICIPANT	\N	PRESENT	0
707580	704099	19723Y	PARTICIPANT	\N	PRESENT	0
707581	704099	19369B	PARTICIPANT	\N	PRESENT	0
707582	704099	20134Y	PARTICIPANT	\N	PRESENT	0
707583	704099	14083S	PARTICIPANT	\N	PRESENT	0
707584	704099	14189C	PARTICIPANT	\N	PRESENT	0
707585	704099	19687N	PARTICIPANT	\N	PRESENT	0
707586	704099	14021P	PARTICIPANT	\N	PRESENT	0
707587	704099	11043H	PARTICIPANT	\N	PRESENT	0
707588	704099	08015R	PARTICIPANT	\N	PRESENT	0
707589	704099	19667J	PARTICIPANT	\N	PRESENT	0
707590	704099	20298U	PARTICIPANT	\N	PRESENT	0
707591	704099	19701S	PARTICIPANT	\N	PRESENT	0
707592	704099	14255U	PARTICIPANT	\N	PRESENT	0
707593	704099	19525U	PARTICIPANT	\N	PRESENT	0
707594	704099	14133K	PARTICIPANT	\N	PRESENT	0
707595	704099	08069G	PARTICIPANT	\N	PRESENT	0
707596	704099	20058E	PARTICIPANT	\N	PRESENT	0
707597	704099	19349W	PARTICIPANT	\N	PRESENT	0
707598	704099	20066E	PARTICIPANT	\N	PRESENT	0
707599	704099	08018U	PARTICIPANT	\N	PRESENT	0
707600	704099	19643A	PARTICIPANT	\N	PRESENT	0
707601	704099	19503N	PARTICIPANT	\N	PRESENT	0
707602	704099	11115U	PARTICIPANT	\N	PRESENT	0
707603	704099	14069U	PARTICIPANT	\N	PRESENT	0
707604	704099	20086J	PARTICIPANT	\N	PRESENT	0
707605	704099	14097Y	PARTICIPANT	\N	PRESENT	0
707606	704099	19762G	PARTICIPANT	\N	PRESENT	0
707607	704099	20252E	PARTICIPANT	\N	PRESENT	0
707608	704099	20068G	PARTICIPANT	\N	PRESENT	0
707609	704099	14026U	PARTICIPANT	\N	PRESENT	0
707610	704099	16685X	PARTICIPANT	\N	PRESENT	0
707611	704099	19591F	PARTICIPANT	\N	PRESENT	0
707612	704099	20148F	PARTICIPANT	\N	PRESENT	0
707613	704099	04043D	PARTICIPANT	\N	PRESENT	0
707614	704099	14251Q	PARTICIPANT	\N	PRESENT	0
707712	704100	12041X	PARTICIPANT	\N	PRESENT	0
707713	704100	11097X	PARTICIPANT	\N	PRESENT	0
707714	704100	14042U	PARTICIPANT	\N	PRESENT	0
707715	704100	10006L	PARTICIPANT	\N	PRESENT	0
707716	704100	11026G	PARTICIPANT	\N	PRESENT	0
707717	704100	19503N	PARTICIPANT	\N	PRESENT	0
707718	704100	20264J	PARTICIPANT	\N	PRESENT	0
707719	704100	11110B	PARTICIPANT	\N	PRESENT	0
707720	704100	11074Q	PARTICIPANT	\N	PRESENT	0
707721	704100	19565D	PARTICIPANT	\N	PRESENT	0
707722	704100	11031D	PARTICIPANT	\N	PRESENT	0
707723	704100	04085P	PARTICIPANT	\N	PRESENT	0
707724	704100	19687N	PARTICIPANT	\N	PRESENT	0
707725	704100	19695N	PARTICIPANT	\N	PRESENT	0
707726	704100	19593H	PARTICIPANT	\N	PRESENT	0
707727	704100	11077T	PARTICIPANT	\N	PRESENT	0
707728	704100	20028X	PARTICIPANT	\N	PRESENT	0
707729	704100	14097Y	PARTICIPANT	\N	PRESENT	0
707730	704100	17965H	PARTICIPANT	\N	PRESENT	0
707731	704100	14021P	PARTICIPANT	\N	PRESENT	0
707732	704100	20142Y	PARTICIPANT	\N	PRESENT	0
707733	704100	19549D	PARTICIPANT	\N	PRESENT	0
707734	704100	12028B	PARTICIPANT	\N	PRESENT	0
707735	704100	20080C	PARTICIPANT	\N	PRESENT	0
707736	704100	14109K	PARTICIPANT	\N	PRESENT	0
707737	704100	08045X	PARTICIPANT	\N	PRESENT	0
707738	704100	20914V	PARTICIPANT	\N	PRESENT	0
707739	704100	20130U	PARTICIPANT	\N	PRESENT	0
707740	704100	20266L	PARTICIPANT	\N	PRESENT	0
707741	704100	14225N	PARTICIPANT	\N	PRESENT	0
707742	704100	19349W	PARTICIPANT	\N	PRESENT	0
707743	704100	14037X	PARTICIPANT	\N	PRESENT	0
707744	704100	11012A	PARTICIPANT	\N	PRESENT	0
707745	704100	14207L	PARTICIPANT	\N	PRESENT	0
707746	704100	98022P	PARTICIPANT	\N	PRESENT	0
707747	704100	19611R	PARTICIPANT	\N	PRESENT	0
707748	704100	20040T	PARTICIPANT	\N	PRESENT	0
707749	704100	20120S	PARTICIPANT	\N	PRESENT	0
707750	704100	05008E	PARTICIPANT	\N	PRESENT	0
707751	704100	01058X	PARTICIPANT	\N	PRESENT	0
707752	704100	20148F	PARTICIPANT	\N	PRESENT	0
707753	704100	20062A	PARTICIPANT	\N	PRESENT	0
707754	704100	19657G	PARTICIPANT	\N	PRESENT	0
707755	704100	20094J	PARTICIPANT	\N	PRESENT	0
707756	704100	11045K	PARTICIPANT	\N	PRESENT	0
707757	704100	14329V	PARTICIPANT	\N	PRESENT	0
707758	704100	19533U	PARTICIPANT	\N	PRESENT	0
707759	704100	14213J	PARTICIPANT	\N	PRESENT	0
707760	704100	20108W	PARTICIPANT	\N	PRESENT	0
707761	704100	14169X	PARTICIPANT	\N	PRESENT	0
707762	704100	20086J	PARTICIPANT	\N	PRESENT	0
707763	704100	19399H	PARTICIPANT	\N	PRESENT	0
707764	704100	19679N	PARTICIPANT	\N	PRESENT	0
707765	704100	11043H	PARTICIPANT	\N	PRESENT	0
707766	704100	20032T	PARTICIPANT	\N	PRESENT	0
707767	704100	20022R	PARTICIPANT	\N	PRESENT	0
707768	704100	14223L	PARTICIPANT	\N	PRESENT	0
707769	704100	14071N	PARTICIPANT	\N	PRESENT	0
707770	704100	19701S	PARTICIPANT	\N	PRESENT	0
707771	704100	19798U	PARTICIPANT	\N	PRESENT	0
707772	704100	19671E	PARTICIPANT	\N	PRESENT	0
707773	704100	11048N	PARTICIPANT	\N	PRESENT	0
707774	704100	04092N	PARTICIPANT	\N	PRESENT	0
707775	704100	17637T	PARTICIPANT	\N	PRESENT	0
707776	704100	20074E	PARTICIPANT	\N	PRESENT	0
707777	704100	19621T	PARTICIPANT	\N	PRESENT	0
707778	704100	19643A	PARTICIPANT	\N	PRESENT	0
707779	704100	19673G	PARTICIPANT	\N	PRESENT	0
707780	704100	20044X	PARTICIPANT	\N	PRESENT	0
707781	704100	20058E	PARTICIPANT	\N	PRESENT	0
707782	704100	19383Y	PARTICIPANT	\N	PRESENT	0
707783	704100	14133K	PARTICIPANT	\N	PRESENT	0
707784	704100	04042C	PARTICIPANT	\N	PRESENT	0
707785	704100	17779H	PARTICIPANT	\N	PRESENT	0
707786	704100	19581D	PARTICIPANT	\N	PRESENT	0
707787	704100	08069G	PARTICIPANT	\N	PRESENT	0
707788	704100	14281W	PARTICIPANT	\N	PRESENT	0
684946	684945	14030Q	PARTICIPANT	\N	PRESENT	0
684947	684945	14255U	PARTICIPANT	\N	PRESENT	0
684948	684945	14121F	PARTICIPANT	\N	PRESENT	0
684949	684945	19369B	PARTICIPANT	\N	PRESENT	0
684950	684945	04043D	PARTICIPANT	\N	PRESENT	0
684951	684945	20062A	PARTICIPANT	\N	PRESENT	0
684952	684945	20084G	PARTICIPANT	\N	PRESENT	0
684953	684945	01034P	PARTICIPANT	\N	PRESENT	0
684954	684945	20132W	PARTICIPANT	\N	PRESENT	0
698915	698914	04042C	PARTICIPANT	\N	PRESENT	0
698916	698914	14193X	PARTICIPANT	\N	PRESENT	0
698917	698914	07033P	PARTICIPANT	\N	PRESENT	0
698918	698914	20064C	PARTICIPANT	\N	PRESENT	0
698919	698914	01024M	PARTICIPANT	\N	PRESENT	0
698920	698914	11027H	PARTICIPANT	\N	PRESENT	0
698987	698986	11026G	PARTICIPANT	\N	PRESENT	0
698922	698914	19565D	PARTICIPANT	\N	PRESENT	0
698923	698914	17023S	PARTICIPANT	\N	PRESENT	0
698984	698983	14089Y	PARTICIPANT	\N	PRESENT	0
698985	698983	19447X	PARTICIPANT	\N	PRESENT	0
698988	698986	14089Y	PARTICIPANT	\N	PRESENT	0
698989	698986	19447X	PARTICIPANT	\N	PRESENT	0
698991	698990	11026G	PARTICIPANT	\N	PRESENT	0
698992	698990	19447X	PARTICIPANT	\N	PRESENT	0
698993	698990	14089Y	PARTICIPANT	\N	PRESENT	0
698995	698994	19735D	PARTICIPANT	\N	PRESENT	1
698996	698994	20112S	PARTICIPANT	\N	PRESENT	1
699022	699021	11048N	PARTICIPANT	\N	PRESENT	0
701867	701865	04070G	PARTICIPANT	\N	PRESENT	0
701868	701865	20134Y	PARTICIPANT	\N	PRESENT	0
701869	701865	19593H	PARTICIPANT	\N	PRESENT	0
702961	701645	20914V	PARTICIPANT	\N	PRESENT	0
702962	701645	11054L	PARTICIPANT	\N	PRESENT	0
702963	701645	20108W	PARTICIPANT	\N	PRESENT	0
702964	701645	20086J	PARTICIPANT	\N	PRESENT	0
702965	701645	11043H	PARTICIPANT	\N	PRESENT	0
702966	701645	99004R	PARTICIPANT	\N	PRESENT	0
702967	701645	20032T	PARTICIPANT	\N	PRESENT	0
702968	701645	19467C	PARTICIPANT	\N	PRESENT	0
702969	701645	19507S	PARTICIPANT	\N	PRESENT	0
702970	701645	14211G	PARTICIPANT	\N	PRESENT	0
702971	701645	17589D	PARTICIPANT	\N	PRESENT	0
702972	701645	20050V	PARTICIPANT	\N	PRESENT	0
702973	701645	14221J	PARTICIPANT	\N	PRESENT	0
702974	701645	19820Y	PARTICIPANT	\N	PRESENT	0
702975	701645	14281W	PARTICIPANT	\N	PRESENT	0
702976	701645	19549D	PARTICIPANT	\N	PRESENT	0
702977	701645	11041F	PARTICIPANT	\N	PRESENT	0
702978	701645	08061X	PARTICIPANT	\N	PRESENT	0
702979	701645	19697Q	PARTICIPANT	\N	PRESENT	0
702980	701645	19591F	PARTICIPANT	\N	PRESENT	0
702981	701645	19565D	PARTICIPANT	\N	PRESENT	0
702982	701645	19695N	PARTICIPANT	\N	PRESENT	0
702983	701645	20102Q	PARTICIPANT	\N	PRESENT	0
702984	701645	11040E	PARTICIPANT	\N	PRESENT	0
702985	701645	08045X	PARTICIPANT	\N	PRESENT	0
702986	701645	14257W	PARTICIPANT	\N	PRESENT	0
702987	701645	19747H	PARTICIPANT	\N	PRESENT	0
702988	701645	08034U	PARTICIPANT	\N	PRESENT	0
702989	701645	19533U	PARTICIPANT	\N	PRESENT	0
702990	701645	20078J	PARTICIPANT	\N	PRESENT	0
702991	701645	20076G	PARTICIPANT	\N	PRESENT	0
702992	701645	20074E	PARTICIPANT	\N	PRESENT	0
702993	701645	14191V	PARTICIPANT	\N	PRESENT	0
702994	701645	19766L	PARTICIPANT	\N	PRESENT	0
702995	701645	14219Q	PARTICIPANT	\N	PRESENT	0
702996	701645	14231L	PARTICIPANT	\N	PRESENT	0
702997	701645	14073Q	PARTICIPANT	\N	PRESENT	0
702998	701645	86034E	PARTICIPANT	\N	PRESENT	0
702999	701645	19745F	PARTICIPANT	\N	PRESENT	0
703000	701645	19683J	PARTICIPANT	\N	PRESENT	0
703001	701645	08060W	PARTICIPANT	\N	PRESENT	0
703002	701645	20028X	PARTICIPANT	\N	PRESENT	0
703003	701645	20036X	PARTICIPANT	\N	PRESENT	0
703004	701645	20092G	PARTICIPANT	\N	PRESENT	0
703005	701645	19527W	PARTICIPANT	\N	PRESENT	0
703006	701645	20080C	PARTICIPANT	\N	PRESENT	0
703007	701645	19503N	PARTICIPANT	\N	PRESENT	0
703008	701645	19621T	PARTICIPANT	\N	PRESENT	0
703009	701645	17637T	PARTICIPANT	\N	PRESENT	0
703010	701645	04085P	PARTICIPANT	\N	PRESENT	0
703011	701645	12041X	PARTICIPANT	\N	PRESENT	0
703012	701645	19711U	PARTICIPANT	\N	PRESENT	0
703013	701645	20112S	PARTICIPANT	\N	PRESENT	0
703014	701645	04008A	PARTICIPANT	\N	PRESENT	0
703015	701645	19593H	PARTICIPANT	\N	PRESENT	0
703016	701645	20046A	PARTICIPANT	\N	PRESENT	0
703017	701645	08011M	PARTICIPANT	\N	PRESENT	0
703018	701645	20142Y	PARTICIPANT	\N	PRESENT	0
703019	701645	19693L	PARTICIPANT	\N	PRESENT	0
703020	701645	01058X	PARTICIPANT	\N	PRESENT	0
703021	701645	19782L	PARTICIPANT	\N	PRESENT	0
703022	701645	18083K	PARTICIPANT	\N	PRESENT	0
703023	701645	19643A	PARTICIPANT	\N	PRESENT	0
703024	701645	14223L	PARTICIPANT	\N	PRESENT	0
703025	701645	10015M	PARTICIPANT	\N	PRESENT	0
703026	701645	08028W	PARTICIPANT	\N	PRESENT	0
703027	701645	19515S	PARTICIPANT	\N	PRESENT	0
703028	701645	01057W	PARTICIPANT	\N	PRESENT	0
703029	701645	20068G	PARTICIPANT	\N	PRESENT	0
703030	701645	05012A	PARTICIPANT	\N	PRESENT	0
703031	701645	14169X	PARTICIPANT	\N	PRESENT	0
703032	701645	20022R	PARTICIPANT	\N	PRESENT	0
703033	701645	20150Y	PARTICIPANT	\N	PRESENT	0
703034	701645	11080N	PARTICIPANT	\N	PRESENT	0
703035	701645	14249W	PARTICIPANT	\N	PRESENT	0
703036	701645	19525U	PARTICIPANT	\N	PRESENT	0
703037	701645	11010L	PARTICIPANT	\N	PRESENT	0
703038	701645	08073C	PARTICIPANT	\N	PRESENT	0
703039	701645	20146D	PARTICIPANT	\N	PRESENT	0
703040	701645	95063L	PARTICIPANT	\N	PRESENT	0
703041	701645	11072N	PARTICIPANT	\N	PRESENT	0
703042	701645	14031R	PARTICIPANT	\N	PRESENT	0
703043	701645	19667J	PARTICIPANT	\N	PRESENT	0
703044	701645	04045F	PARTICIPANT	\N	PRESENT	0
703045	701645	19349W	PARTICIPANT	\N	PRESENT	0
703046	701645	19651A	PARTICIPANT	\N	PRESENT	0
703047	701645	20038A	PARTICIPANT	\N	PRESENT	0
703048	701645	19347U	PARTICIPANT	\N	PRESENT	0
703049	701645	20100N	PARTICIPANT	\N	PRESENT	0
703050	701645	20110Q	PARTICIPANT	\N	PRESENT	0
703051	701645	14173T	PARTICIPANT	\N	PRESENT	0
703052	701645	20130U	PARTICIPANT	\N	PRESENT	0
703053	701645	20980G	PARTICIPANT	\N	PRESENT	0
703054	701645	19573D	PARTICIPANT	\N	PRESENT	0
703055	701645	11033F	PARTICIPANT	\N	PRESENT	0
703056	701645	14055N	PARTICIPANT	\N	PRESENT	0
703057	701645	20128B	PARTICIPANT	\N	PRESENT	0
703058	701645	20106U	PARTICIPANT	\N	PRESENT	0
703059	701645	20026V	PARTICIPANT	\N	PRESENT	0
703060	701645	20134Y	PARTICIPANT	\N	PRESENT	0
703061	701645	20116W	PARTICIPANT	\N	PRESENT	0
703062	701645	14038Y	PARTICIPANT	\N	PRESENT	0
703063	701645	14207L	PARTICIPANT	\N	PRESENT	0
703064	701645	19681G	PARTICIPANT	\N	PRESENT	0
703065	701645	19719D	PARTICIPANT	\N	PRESENT	0
703066	701645	20132W	PARTICIPANT	\N	PRESENT	0
703067	701645	19387D	PARTICIPANT	\N	PRESENT	0
703068	701645	20072C	PARTICIPANT	\N	PRESENT	0
703069	701645	11012A	PARTICIPANT	\N	PRESENT	0
703070	701645	20044X	PARTICIPANT	\N	PRESENT	0
703071	701645	14037X	PARTICIPANT	\N	PRESENT	0
703072	701645	20034V	PARTICIPANT	\N	PRESENT	0
703073	701645	17965H	PARTICIPANT	\N	PRESENT	0
703074	701645	11090Q	PARTICIPANT	\N	PRESENT	0
703075	701645	14225N	PARTICIPANT	\N	PRESENT	0
703076	701645	11027H	PARTICIPANT	\N	PRESENT	0
703077	701645	20056C	PARTICIPANT	\N	PRESENT	0
703078	701645	11045K	PARTICIPANT	\N	PRESENT	0
703079	701645	19673G	PARTICIPANT	\N	PRESENT	0
703080	701645	19715Y	PARTICIPANT	\N	PRESENT	0
703081	701645	20096L	PARTICIPANT	\N	PRESENT	0
703082	701645	19599P	PARTICIPANT	\N	PRESENT	0
703083	701645	12016W	PARTICIPANT	\N	PRESENT	0
703084	701645	11031D	PARTICIPANT	\N	PRESENT	0
703085	701645	19760E	PARTICIPANT	\N	PRESENT	0
703086	701645	11056N	PARTICIPANT	\N	PRESENT	0
703087	701645	08018U	PARTICIPANT	\N	PRESENT	0
703088	701645	20180F	PARTICIPANT	\N	PRESENT	0
703089	701645	04059M	PARTICIPANT	\N	PRESENT	0
703090	701645	19741B	PARTICIPANT	\N	PRESENT	0
693744	690706	20046A	PARTICIPANT	\N	PRESENT	0
693745	690706	19701S	PARTICIPANT	\N	EXCUSE	0
693746	690706	20076G	PARTICIPANT	\N	EXCUSE	0
693747	690706	19251M	PARTICIPANT	\N	EXCUSE	0
693748	690706	19619A	PARTICIPANT	\N	EXCUSE	0
693749	690706	20140W	PARTICIPANT	\N	PRESENT	0
693750	692966	04071H	PARTICIPANT	\N	PRESENT	0
693751	692321	14053L	PARTICIPANT	\N	PRESENT	0
693752	692321	19729F	PARTICIPANT	\N	PRESENT	0
693753	692321	19629C	PARTICIPANT	\N	PRESENT	0
693755	692321	07004J	PARTICIPANT	\N	PRESENT	0
693757	692321	20074E	PARTICIPANT	\N	PRESENT	0
693758	692321	14187A	PARTICIPANT	\N	PRESENT	0
693759	692321	19585H	PARTICIPANT	\N	PRESENT	0
693760	690706	19681G	PARTICIPANT	\N	PRESENT	0
693761	692322	20128B	PARTICIPANT	\N	PRESENT	0
693762	692966	01048V	PARTICIPANT	\N	PRESENT	0
693763	692966	11053K	PARTICIPANT	\N	PRESENT	0
693764	692323	12041X	PARTICIPANT	\N	PRESENT	0
693765	692323	20072C	PARTICIPANT	\N	PRESENT	0
693766	692323	19565D	PARTICIPANT	\N	PRESENT	0
693767	692323	11080N	PARTICIPANT	\N	PRESENT	0
693768	692323	01058X	PARTICIPANT	\N	PRESENT	0
693769	692323	16685X	PARTICIPANT	\N	PRESENT	0
693770	692323	11027H	PARTICIPANT	\N	PRESENT	0
693771	692323	04042C	PRESIDENT	0	PRESENT	0
693772	692323	11054L	PARTICIPANT	\N	PRESENT	0
693773	692323	11066Q	PARTICIPANT	\N	PRESENT	0
693774	692323	19669L	PARTICIPANT	\N	PRESENT	0
693775	692323	12028B	PARTICIPANT	\N	PRESENT	0
693776	692323	11115U	PARTICIPANT	\N	PRESENT	0
693777	692323	14055N	PARTICIPANT	\N	PRESENT	0
693778	692323	19421M	PARTICIPANT	\N	PRESENT	0
693779	692323	14193X	PARTICIPANT	\N	PRESENT	0
693780	692323	19347U	PARTICIPANT	\N	PRESENT	0
693781	692323	07033P	PARTICIPANT	\N	PRESENT	0
693782	692323	08061X	PARTICIPANT	\N	PRESENT	0
693783	692323	14249W	PARTICIPANT	\N	PRESENT	0
693784	692323	08047A	PARTICIPANT	\N	PRESENT	0
693785	692323	20128B	PARTICIPANT	\N	PRESENT	0
693786	692323	14097Y	PARTICIPANT	\N	PRESENT	0
693787	692323	14059S	PARTICIPANT	\N	PRESENT	0
693788	692323	01062T	PARTICIPANT	\N	PRESENT	0
693789	692323	14133K	PARTICIPANT	\N	PRESENT	0
693790	692323	08069G	PARTICIPANT	\N	PRESENT	0
693791	692323	20042V	PARTICIPANT	\N	PRESENT	0
693792	692323	01024M	PARTICIPANT	\N	PRESENT	0
693793	692323	14191V	PARTICIPANT	\N	PRESENT	0
693794	692323	19721W	PARTICIPANT	\N	PRESENT	0
693795	692323	19319Q	PARTICIPANT	\N	PRESENT	0
693796	692323	14105F	PARTICIPANT	\N	PRESENT	0
693797	692323	20064C	PARTICIPANT	\N	PRESENT	0
693799	692323	98022P	PARTICIPANT	\N	PRESENT	0
693800	692323	11064N	PARTICIPANT	\N	PRESENT	0
693802	692323	14267Y	PARTICIPANT	\N	PRESENT	0
693804	692323	11083R	PARTICIPANT	\N	PRESENT	0
693807	692323	14211G	PARTICIPANT	\N	PRESENT	0
693809	692323	19583F	PARTICIPANT	\N	PRESENT	0
693810	692323	14255U	PARTICIPANT	\N	PRESENT	0
693812	692323	08056B	PARTICIPANT	\N	EXCUSE	0
693813	692323	19443T	PARTICIPANT	\N	EXCUSE	0
693815	692323	11041F	PARTICIPANT	\N	EXCUSE	0
693924	692323	17023S	PARTICIPANT	\N	PRESENT	0
693927	692321	14107H	PARTICIPANT	\N	EXCUSE	0
693929	693928	14331P	PARTICIPANT	\N	PRESENT	0
693930	693928	19647E	PARTICIPANT	\N	PRESENT	0
693931	693928	04071H	PARTICIPANT	\N	PRESENT	0
693932	693928	19711U	PARTICIPANT	\N	PRESENT	0
693933	693928	01048V	PARTICIPANT	\N	PRESENT	0
693934	693928	08034U	PARTICIPANT	\N	PRESENT	0
693935	693928	01057W	PARTICIPANT	\N	PRESENT	0
693936	693928	11053K	PARTICIPANT	\N	PRESENT	0
693937	693928	19667J	PARTICIPANT	\N	PRESENT	0
693938	693928	20044X	PARTICIPANT	\N	PRESENT	0
693939	693928	14225N	PRESIDENT	0	PRESENT	0
693941	693928	11040E	PARTICIPANT	\N	PRESENT	0
693942	693928	07029T	PARTICIPANT	\N	PRESENT	0
693943	693928	14083S	PARTICIPANT	\N	PRESENT	0
693944	693928	08009T	PARTICIPANT	\N	PRESENT	0
693945	693928	19349W	PARTICIPANT	\N	PRESENT	0
693946	693928	08010L	PARTICIPANT	\N	PRESENT	0
693947	693928	19741B	PARTICIPANT	\N	PRESENT	0
693948	693928	99004R	PARTICIPANT	\N	PRESENT	0
693949	693928	14253S	PARTICIPANT	\N	PRESENT	0
693950	693928	19762G	PARTICIPANT	\N	PRESENT	0
693951	693928	11048N	PARTICIPANT	\N	EXCUSE	0
693952	693928	14189C	PARTICIPANT	\N	EXCUSE	0
693953	693928	20080C	PARTICIPANT	\N	PRESENT	0
693956	692324	12041X	PARTICIPANT	\N	PRESENT	0
693957	692324	20072C	PARTICIPANT	\N	PRESENT	0
693958	692324	19565D	PARTICIPANT	\N	PRESENT	0
693959	692324	11080N	PARTICIPANT	\N	PRESENT	0
693960	692324	01058X	PARTICIPANT	\N	PRESENT	0
693961	692324	16685X	PARTICIPANT	\N	PRESENT	0
693962	692324	11027H	PARTICIPANT	\N	PRESENT	0
693963	692324	04042C	PRESIDENT	0	PRESENT	0
693964	692324	11054L	PARTICIPANT	\N	PRESENT	0
693965	692324	11066Q	PARTICIPANT	\N	PRESENT	0
693966	692324	19669L	PARTICIPANT	\N	PRESENT	0
693967	692324	12028B	PARTICIPANT	\N	PRESENT	0
693969	692324	14055N	PARTICIPANT	\N	PRESENT	0
693970	692324	19421M	PARTICIPANT	\N	PRESENT	0
693971	692324	14193X	PARTICIPANT	\N	PRESENT	0
693972	692324	19347U	PARTICIPANT	\N	PRESENT	0
693973	692324	07033P	PARTICIPANT	\N	PRESENT	0
693974	692324	08061X	PARTICIPANT	\N	PRESENT	0
693976	692324	08047A	PARTICIPANT	\N	PRESENT	0
693978	692324	14059S	PARTICIPANT	\N	PRESENT	0
693979	692324	04035D	PARTICIPANT	\N	PRESENT	0
693980	692324	01062T	PARTICIPANT	\N	PRESENT	0
693981	692324	14133K	PARTICIPANT	\N	PRESENT	0
693982	692324	08069G	PARTICIPANT	\N	PRESENT	0
693983	692324	20042V	PARTICIPANT	\N	PRESENT	0
693984	692324	01024M	PARTICIPANT	\N	PRESENT	0
693985	692324	14191V	PARTICIPANT	\N	PRESENT	0
693987	692324	19319Q	PARTICIPANT	\N	PRESENT	0
693988	692324	14105F	PARTICIPANT	\N	PRESENT	0
693989	692324	20064C	PARTICIPANT	\N	PRESENT	0
693990	692324	98022P	PARTICIPANT	\N	PRESENT	0
693991	692324	11064N	PARTICIPANT	\N	PRESENT	0
693992	692324	11083R	PARTICIPANT	\N	PRESENT	0
693993	692324	14211G	PARTICIPANT	\N	PRESENT	0
693994	692324	19583F	PARTICIPANT	\N	PRESENT	0
693995	692324	14255U	PARTICIPANT	\N	PRESENT	0
693996	692324	17023S	PARTICIPANT	\N	PRESENT	0
693999	692324	08056B	PARTICIPANT	\N	EXCUSE	0
694000	692324	19443T	PARTICIPANT	\N	EXCUSE	0
694001	692324	11041F	PARTICIPANT	\N	EXCUSE	0
694002	692458	19383Y	PARTICIPANT	\N	PRESENT	0
694003	692458	19768N	PARTICIPANT	\N	PRESENT	0
694004	692458	20088L	PARTICIPANT	\N	PRESENT	0
694005	692458	19515S	PARTICIPANT	\N	PRESENT	0
694006	692458	19782L	PARTICIPANT	\N	PRESENT	0
694007	692458	20092G	PARTICIPANT	\N	PRESENT	0
694008	692458	01043Q	PARTICIPANT	\N	PRESENT	0
694009	692458	20078J	PARTICIPANT	\N	PRESENT	0
694010	692458	19441R	PARTICIPANT	\N	PRESENT	0
694011	692458	20082E	PARTICIPANT	\N	PRESENT	0
694012	692458	20094J	PARTICIPANT	\N	PRESENT	0
694013	692458	04045F	PARTICIPANT	\N	PRESENT	0
694014	692458	19866P	PARTICIPANT	\N	PRESENT	0
694015	692458	19631V	PARTICIPANT	\N	PRESENT	0
694016	692458	19705W	PARTICIPANT	\N	PRESENT	0
694017	692458	08015R	PARTICIPANT	\N	PRESENT	0
694018	692458	19575F	PARTICIPANT	\N	PRESENT	0
694019	692458	20018V	PARTICIPANT	\N	PRESENT	0
694020	692458	19563B	PARTICIPANT	\N	PRESENT	0
694021	692458	08028W	PARTICIPANT	\N	PRESENT	0
694022	692458	14329V	PARTICIPANT	\N	PRESENT	0
694023	692458	20028X	PARTICIPANT	\N	PRESENT	0
694024	692458	14037X	PARTICIPANT	\N	PRESENT	0
694025	692458	14038Y	PARTICIPANT	\N	PRESENT	0
694026	692458	19467C	PARTICIPANT	\N	PRESENT	0
694027	692458	20034V	PARTICIPANT	\N	PRESENT	0
683549	683548	14205J	PARTICIPANT	\N	PRESENT	0
683550	683548	01043Q	PRESIDENT	0	PRESENT	0
683551	683548	20032T	PARTICIPANT	\N	PRESENT	0
683552	683548	05008E	PARTICIPANT	\N	PRESENT	0
683553	683548	20086J	PARTICIPANT	\N	PRESENT	0
683554	683548	19383Y	PARTICIPANT	\N	PRESENT	0
683555	683548	19545Y	PARTICIPANT	\N	PRESENT	0
683556	683548	11110B	PARTICIPANT	\N	PRESENT	0
683557	683548	19489J	PARTICIPANT	\N	PRESENT	0
683558	683548	19349W	PARTICIPANT	\N	PRESENT	0
686597	683234	20134Y	PARTICIPANT	\N	PRESENT	0
686647	683234	14231L	PARTICIPANT	\N	PRESENT	0
686599	683234	20062A	PARTICIPANT	\N	PRESENT	0
686600	683234	20032T	PARTICIPANT	\N	PRESENT	0
686641	683234	11031D	PARTICIPANT	\N	PRESENT	0
686642	683234	19683J	PARTICIPANT	\N	PRESENT	0
686603	683234	18193Q	PARTICIPANT	\N	PRESENT	0
686604	683234	19631V	PARTICIPANT	\N	PRESENT	0
686605	683234	14021P	PARTICIPANT	\N	PRESENT	0
686643	683234	19333N	PARTICIPANT	\N	PRESENT	0
686644	683234	14071N	PARTICIPANT	\N	PRESENT	0
686608	683234	20060X	PARTICIPANT	\N	PRESENT	0
686609	683234	20264J	PARTICIPANT	\N	PRESENT	0
686610	683234	14229S	PARTICIPANT	\N	PRESENT	0
686611	683234	08045X	PARTICIPANT	\N	PRESENT	0
686612	683234	20080C	PARTICIPANT	\N	PRESENT	0
686648	683234	19531S	PARTICIPANT	\N	PRESENT	0
686614	683234	14213J	PARTICIPANT	\N	PRESENT	0
686615	683234	20152B	PARTICIPANT	\N	PRESENT	0
686649	683234	19503N	PARTICIPANT	\N	PRESENT	0
686617	683234	11067R	PARTICIPANT	\N	PRESENT	0
686618	683234	20092G	PARTICIPANT	\N	PRESENT	0
686619	683234	19669L	PARTICIPANT	\N	PRESENT	0
686645	683234	19585H	PARTICIPANT	\N	PRESENT	0
686646	683234	19649G	PARTICIPANT	\N	PRESENT	0
686650	683234	20082E	PARTICIPANT	\N	PRESENT	0
686651	683234	19599P	PARTICIPANT	\N	PRESENT	0
686652	683234	08012N	PARTICIPANT	\N	PRESENT	0
686653	683234	11012A	PARTICIPANT	\N	PRESENT	0
686654	683234	19347U	PARTICIPANT	\N	PRESENT	0
686627	683234	14195A	PARTICIPANT	\N	PRESENT	0
686655	683234	17965H	PARTICIPANT	\N	PRESENT	0
686629	683234	08061X	PARTICIPANT	\N	PRESENT	0
686630	683234	17779H	PARTICIPANT	\N	PRESENT	0
686631	683234	19715Y	PARTICIPANT	\N	PRESENT	0
686632	683234	19693L	PARTICIPANT	\N	PRESENT	0
686656	683234	20070A	PARTICIPANT	\N	PRESENT	0
686634	683234	20114U	PARTICIPANT	\N	PRESENT	0
686635	683234	20130U	PARTICIPANT	\N	PRESENT	0
686636	683234	20068G	PARTICIPANT	\N	PRESENT	0
686637	683234	19553Y	PARTICIPANT	\N	PRESENT	0
686638	683234	19713W	PARTICIPANT	\N	PRESENT	0
686657	683234	14109K	PARTICIPANT	\N	PRESENT	0
686640	683234	20094J	PARTICIPANT	\N	PRESENT	0
686658	683234	20034V	PARTICIPANT	\N	PRESENT	0
686665	683234	20132W	PARTICIPANT	\N	PRESENT	0
686666	683234	01028R	PARTICIPANT	\N	PRESENT	0
686667	683234	14179A	PARTICIPANT	\N	PRESENT	0
688272	688271	14053L	PARTICIPANT	\N	PRESENT	0
688275	688271	11066Q	PARTICIPANT	\N	PRESENT	0
688771	688745	14331P	PARTICIPANT	\N	EXCUSE	0
688772	688745	11072N	PARTICIPANT	\N	PRESENT	0
688773	688745	20146D	PARTICIPANT	\N	PRESENT	0
688774	688745	19301E	PARTICIPANT	\N	EXCUSE	0
688775	688745	19657G	PARTICIPANT	\N	PRESENT	0
688776	688745	19715Y	PARTICIPANT	\N	PRESENT	0
688778	688745	19691J	PARTICIPANT	\N	EXCUSE	0
688780	688745	18083K	PARTICIPANT	\N	PRESENT	0
688781	688745	14097Y	PARTICIPANT	\N	PRESENT	0
688955	688954	19647E	PARTICIPANT	\N	PRESENT	0
688956	688954	14249W	PARTICIPANT	\N	PRESENT	0
688957	688954	19503N	PARTICIPANT	\N	PRESENT	0
697992	697990	20042V	PARTICIPANT	\N	PRESENT	0
697993	697990	14207L	PARTICIPANT	\N	PRESENT	0
697994	697990	14357A	PARTICIPANT	\N	PRESENT	0
697995	697990	19719D	PARTICIPANT	\N	PRESENT	0
697996	697990	01024M	PARTICIPANT	\N	PRESENT	0
697997	697990	19820Y	PARTICIPANT	\N	PRESENT	0
697998	697990	19725B	PARTICIPANT	\N	PRESENT	0
697999	697990	20126Y	PARTICIPANT	\N	PRESENT	0
698000	697990	19723Y	PARTICIPANT	\N	PRESENT	0
698001	697990	08015R	PARTICIPANT	\N	PRESENT	0
698002	697990	14109K	PARTICIPANT	\N	PRESENT	0
698003	697990	19745F	PARTICIPANT	\N	PRESENT	0
698004	697990	05012A	PARTICIPANT	\N	PRESENT	0
698005	697990	04045F	PARTICIPANT	\N	PRESENT	0
698016	698015	19515S	PARTICIPANT	\N	PRESENT	0
698019	698015	20042V	PARTICIPANT	\N	PRESENT	0
698022	698015	19782L	PARTICIPANT	\N	PRESENT	0
698023	698015	14207L	PARTICIPANT	\N	PRESENT	0
698024	698015	14329V	PARTICIPANT	\N	PRESENT	0
698025	698015	01024M	PARTICIPANT	\N	PRESENT	0
698100	698015	08056B	PARTICIPANT	\N	PRESENT	0
698101	698015	08015R	PARTICIPANT	\N	PRESENT	0
698102	698015	19745F	PARTICIPANT	\N	PRESENT	0
698103	698015	20030R	PARTICIPANT	\N	PRESENT	0
698452	693587	19717B	PRESIDENT	0	PRESENT	1
698453	693587	20034V	PARTICIPANT	\N	PRESENT	0
698454	693587	19715Y	PARTICIPANT	\N	PRESENT	0
698455	693587	14059S	PARTICIPANT	\N	PRESENT	0
698456	693587	19657G	PARTICIPANT	\N	PRESENT	0
698457	693587	19319Q	PARTICIPANT	\N	PRESENT	0
698458	693587	18083K	PARTICIPANT	\N	PRESENT	0
698459	693587	20146D	PARTICIPANT	\N	PRESENT	0
698460	693587	20098N	PARTICIPANT	\N	PRESENT	0
698461	693587	14030Q	PARTICIPANT	\N	PRESENT	0
698463	693587	20024T	PARTICIPANT	\N	PRESENT	0
698464	693587	19693L	PARTICIPANT	\N	PRESENT	0
699062	688802	04047H	PARTICIPANT	\N	PRESENT	0
699063	688802	14053L	PARTICIPANT	\N	PRESENT	0
699064	688802	19447X	PARTICIPANT	\N	PRESENT	0
699065	688802	14089Y	PARTICIPANT	\N	PRESENT	0
699066	688802	20110Q	PARTICIPANT	\N	PRESENT	0
699067	688802	19629C	PARTICIPANT	\N	PRESENT	0
699068	688802	11072N	PARTICIPANT	\N	PRESENT	0
699070	688802	14215L	PARTICIPANT	\N	PRESENT	0
701538	701537	14133K	PARTICIPANT	\N	PRESENT	0
701540	701539	14133K	PARTICIPANT	\N	PRESENT	0
701542	701541	14133K	PARTICIPANT	\N	PRESENT	0
701563	701562	14133K	PARTICIPANT	\N	PRESENT	0
701569	701567	14133K	PARTICIPANT	\N	PRESENT	0
703625	702465	20022R	PARTICIPANT	\N	PRESENT	0
703631	703630	19335Q	PARTICIPANT	\N	PRESENT	0
703632	703630	20106U	PARTICIPANT	\N	PRESENT	0
703633	703630	20152B	PARTICIPANT	\N	PRESENT	0
703634	703630	14109K	PARTICIPANT	\N	PRESENT	0
703635	703630	20142Y	PARTICIPANT	\N	PRESENT	0
703639	703638	20112S	PARTICIPANT	\N	PRESENT	0
703642	703630	19758L	PARTICIPANT	\N	PRESENT	0
703643	703638	19643A	PARTICIPANT	\N	PRESENT	0
703644	703638	19735D	PARTICIPANT	\N	PRESENT	1
703645	703638	19693L	PARTICIPANT	\N	PRESENT	0
703651	703649	20132W	PARTICIPANT	\N	PRESENT	0
703652	703649	14229S	PARTICIPANT	\N	PRESENT	0
703674	703637	04092N	PARTICIPANT	\N	PRESENT	0
703686	703671	04092N	PARTICIPANT	\N	PRESENT	0
703691	701790	11090Q	PARTICIPANT	\N	PRESENT	0
703693	701790	19515S	PARTICIPANT	\N	PRESENT	0
703694	701790	19707Y	PARTICIPANT	\N	PRESENT	0
703695	701790	20094J	PARTICIPANT	\N	PRESENT	0
703696	701790	20078J	PARTICIPANT	\N	PRESENT	0
703697	701790	20088L	PARTICIPANT	\N	PRESENT	0
703698	701790	19747H	PARTICIPANT	\N	PRESENT	0
703699	701790	19383Y	PARTICIPANT	\N	PRESENT	0
703700	701790	19782L	PARTICIPANT	\N	PRESENT	0
703701	701790	14207L	PARTICIPANT	\N	PRESENT	0
703702	701790	20104S	PARTICIPANT	\N	PRESENT	0
703703	701790	20060X	PARTICIPANT	\N	PRESENT	0
703704	701790	14329V	PARTICIPANT	\N	PRESENT	0
703705	701790	14038Y	PARTICIPANT	\N	PRESENT	0
703706	701790	08028W	PARTICIPANT	\N	PRESENT	0
703707	701790	20144B	PARTICIPANT	\N	PRESENT	0
703708	701790	19467C	PARTICIPANT	\N	PRESENT	0
703709	701790	14357A	PARTICIPANT	\N	PRESENT	0
703710	701790	19507S	PARTICIPANT	\N	PRESENT	0
703711	701790	14187A	PARTICIPANT	\N	PRESENT	0
703712	701790	01025N	PARTICIPANT	\N	PRESENT	0
703713	701790	20286Q	PARTICIPANT	\N	PRESENT	0
703714	701790	19695N	PARTICIPANT	\N	PRESENT	0
707791	704100	19762G	PARTICIPANT	\N	PRESENT	0
707792	704100	04033B	PARTICIPANT	\N	PRESENT	0
707793	704100	19553Y	PARTICIPANT	\N	PRESENT	0
707794	704100	20122U	PARTICIPANT	\N	PRESENT	0
707795	704100	20116W	PARTICIPANT	\N	PRESENT	0
707796	704100	19569H	PARTICIPANT	\N	PRESENT	0
707797	704100	19577H	PARTICIPANT	\N	PRESENT	0
707798	704100	19715Y	PARTICIPANT	\N	PRESENT	0
707799	704100	17737W	PARTICIPANT	\N	PRESENT	0
707800	704100	18193Q	PARTICIPANT	\N	PRESENT	0
707801	704100	19766L	PARTICIPANT	\N	PRESENT	0
707802	704100	20068G	PARTICIPANT	\N	PRESENT	0
707803	704100	19667J	PARTICIPANT	\N	PRESENT	0
707804	704100	19367Y	PARTICIPANT	\N	PRESENT	0
707805	704100	19760E	PARTICIPANT	\N	PRESENT	0
707806	704100	19717B	PARTICIPANT	\N	PRESENT	0
707807	704100	14026U	PARTICIPANT	\N	PRESENT	0
707808	704100	14033T	PARTICIPANT	\N	PRESENT	0
707809	704100	19551W	PARTICIPANT	\N	PRESENT	0
707810	704100	14257W	PARTICIPANT	\N	PRESENT	0
707789	704100	20298U	PARTICIPANT	\N	PRESENT	0
707790	704100	19691J	PARTICIPANT	\N	PRESENT	0
707811	704100	20152B	PARTICIPANT	\N	PRESENT	0
707812	704100	20252E	PARTICIPANT	\N	PRESENT	0
707813	704100	19723Y	PARTICIPANT	\N	PRESENT	0
707814	704100	08061X	PARTICIPANT	\N	PRESENT	0
707815	704100	19591F	PARTICIPANT	\N	PRESENT	0
707816	704100	20056C	PARTICIPANT	\N	PRESENT	0
707817	704100	08010L	PARTICIPANT	\N	PRESENT	0
707818	704100	14189C	PARTICIPANT	\N	PRESENT	0
707819	704100	19649G	PARTICIPANT	\N	PRESENT	0
707820	704100	19745F	PARTICIPANT	\N	PRESENT	0
707821	704100	19387D	PARTICIPANT	\N	PRESENT	0
707822	704100	14217N	PARTICIPANT	\N	PRESENT	0
707823	704100	20100N	PARTICIPANT	\N	PRESENT	0
707824	704100	19525U	PARTICIPANT	\N	PRESENT	0
707825	704100	01048V	PARTICIPANT	\N	PRESENT	0
707826	704100	04043D	PARTICIPANT	\N	PRESENT	0
707827	704100	14251Q	PARTICIPANT	\N	PRESENT	0
707828	704100	08018U	PARTICIPANT	\N	PRESENT	0
707829	704100	19711U	PARTICIPANT	\N	PRESENT	0
707830	704100	08015R	PARTICIPANT	\N	PRESENT	0
707831	704100	04059M	PARTICIPANT	\N	PRESENT	0
707832	704100	95063L	PARTICIPANT	\N	PRESENT	0
707833	704100	19369B	PARTICIPANT	\N	PRESENT	0
707834	704100	14255U	PARTICIPANT	\N	PRESENT	0
707835	704100	19647E	PARTICIPANT	\N	PRESENT	0
707836	704100	99004R	PARTICIPANT	\N	PRESENT	0
707837	704100	08011M	PARTICIPANT	\N	PRESENT	0
707838	704100	20134Y	PARTICIPANT	\N	PRESENT	0
707839	704100	20066E	PARTICIPANT	\N	PRESENT	0
707840	704100	19507S	PARTICIPANT	\N	PRESENT	0
707841	704100	19489J	PARTICIPANT	\N	PRESENT	0
707850	704100	16685X	PARTICIPANT	\N	PRESENT	0
707843	704100	20096L	PARTICIPANT	\N	PRESENT	0
707844	704100	95041E	PARTICIPANT	\N	PRESENT	0
707845	704100	14083S	PARTICIPANT	\N	PRESENT	0
707851	704100	14030Q	PARTICIPANT	\N	PRESENT	0
707847	704100	19421M	PARTICIPANT	\N	PRESENT	0
707848	704100	19697Q	PARTICIPANT	\N	PRESENT	0
707849	704100	17367Q	PARTICIPANT	\N	PRESENT	0
707852	704100	14231L	PARTICIPANT	\N	PRESENT	0
707946	704101	19565D	PARTICIPANT	\N	PRESENT	0
707947	704101	08069G	PARTICIPANT	\N	PRESENT	0
707948	704101	11031D	PARTICIPANT	\N	PRESENT	0
707949	704101	19643A	PARTICIPANT	\N	PRESENT	0
707950	704101	17965H	PARTICIPANT	\N	PRESENT	0
707951	704101	99004R	PARTICIPANT	\N	PRESENT	0
707952	704101	17779H	PARTICIPANT	\N	PRESENT	0
707953	704101	04042C	PARTICIPANT	\N	PRESENT	0
707954	704101	20914V	PARTICIPANT	\N	PRESENT	0
707955	704101	14223L	PARTICIPANT	\N	PRESENT	0
707956	704101	08045X	PARTICIPANT	\N	PRESENT	0
707957	704101	20100N	PARTICIPANT	\N	PRESENT	0
707958	704101	14071N	PARTICIPANT	\N	PRESENT	0
707959	704101	20130U	PARTICIPANT	\N	PRESENT	0
707960	704101	95041E	PARTICIPANT	\N	PRESENT	0
707961	704101	20142Y	PARTICIPANT	\N	PRESENT	0
707962	704101	19367Y	PARTICIPANT	\N	PRESENT	0
707963	704101	19553Y	PARTICIPANT	\N	PRESENT	0
707964	704101	19798U	PARTICIPANT	\N	PRESENT	0
707965	704101	19766L	PARTICIPANT	\N	PRESENT	0
707966	704101	19593H	PARTICIPANT	\N	PRESENT	0
707967	704101	11077T	PARTICIPANT	\N	PRESENT	0
707968	704101	14187A	PARTICIPANT	\N	PRESENT	0
707969	704101	19715Y	PARTICIPANT	\N	PRESENT	0
707970	704101	19701S	PARTICIPANT	\N	PRESENT	0
707971	704101	14281W	PARTICIPANT	\N	PRESENT	0
707972	704101	20056C	PARTICIPANT	\N	PRESENT	0
707973	704101	19503N	PARTICIPANT	\N	PRESENT	0
707974	704101	14213J	PARTICIPANT	\N	PRESENT	0
707975	704101	08010L	PARTICIPANT	\N	PRESENT	0
707976	704101	19489J	PARTICIPANT	\N	PRESENT	0
707977	704101	11048N	PARTICIPANT	\N	PRESENT	0
707978	704101	11026G	PARTICIPANT	\N	PRESENT	0
707979	704101	14189C	PARTICIPANT	\N	PRESENT	0
707980	704101	18193Q	PARTICIPANT	\N	PRESENT	0
707981	704101	19569H	PARTICIPANT	\N	PRESENT	0
707982	704101	19649G	PARTICIPANT	\N	PRESENT	0
707983	704101	14030Q	PARTICIPANT	\N	PRESENT	0
707984	704101	20266L	PARTICIPANT	\N	PRESENT	0
707985	704101	20074E	PARTICIPANT	\N	PRESENT	0
707986	704101	05008E	PARTICIPANT	\N	PRESENT	0
707987	704101	11072N	PARTICIPANT	\N	PRESENT	0
707988	704101	20058E	PARTICIPANT	\N	PRESENT	0
707989	704101	08061X	PARTICIPANT	\N	PRESENT	0
707990	704101	14217N	PARTICIPANT	\N	PRESENT	0
707991	704101	04085P	PARTICIPANT	\N	PRESENT	0
707992	704101	14231L	PARTICIPANT	\N	PRESENT	0
707993	704101	20028X	PARTICIPANT	\N	PRESENT	0
707994	704101	19717B	PARTICIPANT	\N	PRESENT	0
707995	704101	14037X	PARTICIPANT	\N	PRESENT	0
707996	704101	14033T	PARTICIPANT	\N	PRESENT	0
707997	704101	20122U	PARTICIPANT	\N	PRESENT	0
707998	704101	19577H	PARTICIPANT	\N	PRESENT	0
707999	704101	19349W	PARTICIPANT	\N	PRESENT	0
708000	704101	12028B	PARTICIPANT	\N	PRESENT	0
708001	704101	19399H	PARTICIPANT	\N	PRESENT	0
708002	704101	19673G	PARTICIPANT	\N	PRESENT	0
708003	704101	14173T	PARTICIPANT	\N	PRESENT	0
708004	704101	10006L	PARTICIPANT	\N	PRESENT	0
708005	704101	19657G	PARTICIPANT	\N	PRESENT	0
708006	704101	14042U	PARTICIPANT	\N	PRESENT	0
708007	704101	20080C	PARTICIPANT	\N	PRESENT	0
708008	704101	20094J	PARTICIPANT	\N	PRESENT	0
708009	704101	04092N	PARTICIPANT	\N	PRESENT	0
708010	704101	14257W	PARTICIPANT	\N	PRESENT	0
708011	704101	19671E	PARTICIPANT	\N	PRESENT	0
708012	704101	95063L	PARTICIPANT	\N	PRESENT	0
708013	704101	19421M	PARTICIPANT	\N	PRESENT	0
708014	704101	20044X	PARTICIPANT	\N	PRESENT	0
708015	704101	01048V	PARTICIPANT	\N	PRESENT	0
708016	704101	19723Y	PARTICIPANT	\N	PRESENT	0
708017	704101	20086J	PARTICIPANT	\N	PRESENT	0
708018	704101	14151M	PARTICIPANT	\N	PRESENT	0
708019	704101	14211G	PARTICIPANT	\N	PRESENT	0
708020	704101	20066E	PARTICIPANT	\N	PRESENT	0
708021	704101	20120S	PARTICIPANT	\N	PRESENT	0
708022	704101	14109K	PARTICIPANT	\N	PRESENT	0
708023	704101	17367Q	PARTICIPANT	\N	PRESENT	0
708024	704101	14089Y	PARTICIPANT	\N	PRESENT	0
708025	704101	19549D	PARTICIPANT	\N	PRESENT	0
708026	704101	04033B	PARTICIPANT	\N	PRESENT	0
708027	704101	19687N	PARTICIPANT	\N	PRESENT	0
708028	704101	12041X	PARTICIPANT	\N	PRESENT	0
708029	704101	14083S	PARTICIPANT	\N	PRESENT	0
708030	704101	20062A	PARTICIPANT	\N	PRESENT	0
708031	704101	20022R	PARTICIPANT	\N	PRESENT	0
708032	704101	20032T	PARTICIPANT	\N	PRESENT	0
708033	704101	14329V	PARTICIPANT	\N	PRESENT	0
708034	704101	19369B	PARTICIPANT	\N	PRESENT	0
708035	704101	19507S	PARTICIPANT	\N	PRESENT	0
708036	704101	19591F	PARTICIPANT	\N	PRESENT	0
707944	704101	14026U	PARTICIPANT	\N	PRESENT	0
707945	704101	11097X	PARTICIPANT	\N	PRESENT	0
708037	704101	19383Y	PARTICIPANT	\N	PRESENT	0
708038	706244	19798U	PARTICIPANT	\N	PRESENT	0
708039	706244	11067R	PARTICIPANT	\N	PRESENT	0
708040	706244	11097X	PARTICIPANT	\N	PRESENT	0
708041	706244	19657G	PARTICIPANT	\N	PRESENT	0
708042	706244	14213J	PARTICIPANT	\N	PRESENT	0
708043	706244	10006L	PARTICIPANT	\N	PRESENT	0
688566	688565	11031D	PARTICIPANT	\N	PRESENT	0
688567	676370	19673G	PARTICIPANT	\N	PRESENT	0
688568	676370	11083R	PARTICIPANT	\N	PRESENT	0
688569	676370	14030Q	PARTICIPANT	\N	PRESENT	0
688570	676370	20056C	PARTICIPANT	\N	PRESENT	0
690605	688651	95063L	PARTICIPANT	\N	PRESENT	0
690660	688651	19715Y	PARTICIPANT	\N	PRESENT	0
690661	688651	12041X	PARTICIPANT	\N	PRESENT	0
690662	688651	20032T	PARTICIPANT	\N	PRESENT	0
690663	688651	04092N	PARTICIPANT	\N	PRESENT	0
690664	688651	14071N	PARTICIPANT	\N	PRESENT	0
690665	688651	20110Q	PARTICIPANT	\N	PRESENT	0
690666	688651	14147R	PARTICIPANT	\N	PRESENT	0
690667	688651	14189C	PARTICIPANT	\N	PRESENT	0
690668	688651	19335Q	PARTICIPANT	\N	PRESENT	0
690669	688651	07033P	PARTICIPANT	\N	PRESENT	0
690673	688651	19531S	PARTICIPANT	\N	PRESENT	0
690674	688651	01028R	PARTICIPANT	\N	PRESENT	0
690675	688651	05012A	PARTICIPANT	\N	PRESENT	0
690685	688651	20090E	PARTICIPANT	\N	PRESENT	0
690686	688651	20094J	PARTICIPANT	\N	PRESENT	0
690687	688651	08073C	PARTICIPANT	\N	PRESENT	0
690688	688651	19820Y	PARTICIPANT	\N	PRESENT	0
690689	688651	20126Y	PARTICIPANT	\N	PRESENT	0
690690	688651	11115U	PARTICIPANT	\N	PRESENT	0
690691	688651	19713W	PARTICIPANT	\N	PRESENT	0
690692	688651	19569H	PARTICIPANT	\N	PRESENT	0
690698	688651	17229F	PARTICIPANT	\N	PRESENT	0
690699	688651	14107H	PARTICIPANT	\N	PRESENT	0
690702	688651	18083K	PARTICIPANT	\N	PRESENT	0
690703	688651	14179A	PARTICIPANT	\N	PRESENT	0
690704	688651	19573D	PARTICIPANT	\N	PRESENT	0
690705	688651	14038Y	PARTICIPANT	\N	PRESENT	0
690707	688651	14187A	PARTICIPANT	\N	PRESENT	0
690711	688651	19693L	PARTICIPANT	\N	PRESENT	0
690739	688652	14257W	PARTICIPANT	\N	PRESENT	0
690740	688652	19333N	PARTICIPANT	\N	PRESENT	0
690741	688652	19695N	PARTICIPANT	\N	PRESENT	0
690742	688652	20102Q	PARTICIPANT	\N	PRESENT	0
690726	688652	99004R	PARTICIPANT	\N	PRESENT	0
690729	688652	20090E	PARTICIPANT	\N	PRESENT	0
690743	688652	19758L	PARTICIPANT	\N	PRESENT	0
690744	688652	12041X	PARTICIPANT	\N	PRESENT	0
690745	688652	19347U	PARTICIPANT	\N	PRESENT	0
690746	688652	19413M	PARTICIPANT	\N	PRESENT	0
690747	688652	14207L	PARTICIPANT	\N	PRESENT	0
690751	688652	11083R	PARTICIPANT	\N	PRESENT	0
690749	688652	20042V	PARTICIPANT	\N	PRESENT	0
690750	688652	19533U	PARTICIPANT	\N	PRESENT	0
690752	688652	04085P	PARTICIPANT	\N	PRESENT	0
690753	688652	19583F	PARTICIPANT	\N	PRESENT	0
690754	688652	19515S	PARTICIPANT	\N	PRESENT	0
690759	688652	01048V	PARTICIPANT	\N	PRESENT	0
690760	688652	11077T	PARTICIPANT	\N	PRESENT	0
690761	688652	20120S	PARTICIPANT	\N	PRESENT	0
690762	688652	19693L	PARTICIPANT	\N	PRESENT	0
690763	688652	19573D	PARTICIPANT	\N	PRESENT	0
690784	688652	19593H	PARTICIPANT	\N	PRESENT	0
695143	695142	14329V	PARTICIPANT	\N	PRESENT	0
695144	690950	20106U	PARTICIPANT	\N	EXCUSE	0
695145	690950	14189C	PARTICIPANT	\N	EXCUSE	0
697828	695157	99004R	PARTICIPANT	\N	PRESENT	0
697830	695157	10006L	PARTICIPANT	\N	PRESENT	0
697831	695157	11045K	PARTICIPANT	\N	PRESENT	0
697834	695157	14021P	PARTICIPANT	\N	PRESENT	0
697835	695157	14229S	PARTICIPANT	\N	PRESENT	0
697836	695157	08060W	PARTICIPANT	\N	PRESENT	0
697838	695157	17965H	PARTICIPANT	\N	PRESENT	0
697839	695157	19565D	PARTICIPANT	\N	PRESENT	0
697841	695157	20064C	PARTICIPANT	\N	PRESENT	0
697842	695157	20030R	PARTICIPANT	\N	PRESENT	0
697844	695157	19551W	PARTICIPANT	\N	PRESENT	0
697845	695157	20114U	PARTICIPANT	\N	PRESENT	0
697847	695157	20088L	PARTICIPANT	\N	PRESENT	0
697848	695157	20264J	PARTICIPANT	\N	PRESENT	0
697849	695157	14281W	PARTICIPANT	\N	PRESENT	0
697850	695157	20914V	PARTICIPANT	\N	PRESENT	0
697851	695157	19697Q	PARTICIPANT	\N	PRESENT	0
697852	695157	19329S	PARTICIPANT	\N	PRESENT	0
697853	695157	20128B	PARTICIPANT	\N	PRESENT	0
697854	695157	19651A	PARTICIPANT	\N	PRESENT	0
697856	695157	20018V	PARTICIPANT	\N	PRESENT	0
697857	695157	14195A	PARTICIPANT	\N	PRESENT	0
697858	695157	20132W	PARTICIPANT	\N	PRESENT	0
697859	695157	20072C	PARTICIPANT	\N	PRESENT	0
697860	695157	19553Y	PARTICIPANT	\N	PRESENT	0
697861	695157	14107H	PARTICIPANT	\N	PRESENT	0
697862	695157	19745F	PARTICIPANT	\N	PRESENT	0
697864	695157	19479G	PARTICIPANT	\N	PRESENT	0
697865	695157	14327T	PARTICIPANT	\N	PRESENT	0
697866	695157	11067R	PARTICIPANT	\N	PRESENT	0
697867	695157	19691J	PARTICIPANT	\N	PRESENT	0
697868	695157	19569H	PARTICIPANT	\N	PRESENT	0
697869	695157	14189C	PARTICIPANT	\N	PRESENT	0
697870	695157	14083S	PARTICIPANT	\N	PRESENT	0
697871	695157	20090E	PARTICIPANT	\N	PRESENT	0
697872	695157	20062A	PARTICIPANT	\N	PRESENT	0
697873	695157	97011G	PARTICIPANT	\N	PRESENT	0
697874	695157	01028R	PARTICIPANT	\N	PRESENT	0
697875	695157	14147R	PARTICIPANT	\N	PRESENT	0
697876	695157	11056N	PARTICIPANT	\N	PRESENT	0
697877	695157	07029T	PARTICIPANT	\N	PRESENT	0
697878	695157	19954N	PARTICIPANT	\N	PRESENT	0
697879	695157	11031D	PARTICIPANT	\N	PRESENT	0
697880	695157	20130U	PARTICIPANT	\N	PRESENT	0
697881	695157	19447X	PARTICIPANT	\N	PRESENT	0
697882	695157	14217N	PARTICIPANT	\N	PRESENT	0
697883	695157	20266L	PARTICIPANT	\N	PRESENT	0
697884	695157	19649G	PARTICIPANT	\N	PRESENT	0
697885	695157	11012A	PARTICIPANT	\N	PRESENT	0
697886	695157	19629C	PARTICIPANT	\N	PRESENT	0
697888	695157	01024M	PARTICIPANT	\N	PRESENT	0
697890	695157	19747H	PARTICIPANT	\N	PRESENT	0
697893	695157	19683J	PARTICIPANT	\N	PRESENT	0
697894	695157	04045F	PARTICIPANT	\N	PRESENT	0
697895	695157	14069U	PARTICIPANT	\N	PRESENT	0
697896	695157	19657G	PARTICIPANT	\N	PRESENT	0
697898	695157	19543W	PARTICIPANT	\N	PRESENT	0
697899	695157	19749K	PARTICIPANT	\N	PRESENT	0
697900	695157	18193Q	PARTICIPANT	\N	PRESENT	0
697901	695157	19549D	PARTICIPANT	\N	PRESENT	0
697902	695157	14026U	PARTICIPANT	\N	PRESENT	0
697903	695157	11097X	PARTICIPANT	\N	PRESENT	0
697904	695157	19591F	PARTICIPANT	\N	PRESENT	0
697905	695157	19631V	PARTICIPANT	\N	PRESENT	0
697907	695157	08045X	PARTICIPANT	\N	PRESENT	0
697908	695157	04092N	PARTICIPANT	\N	PRESENT	0
697910	695157	20060X	PARTICIPANT	\N	PRESENT	0
697918	695157	19367Y	PARTICIPANT	\N	PRESENT	0
697919	695157	20112S	PARTICIPANT	\N	PRESENT	0
697920	695157	14030Q	PARTICIPANT	\N	PRESENT	0
697921	695157	20152B	PARTICIPANT	\N	PRESENT	0
697923	695157	19782L	PARTICIPANT	\N	PRESENT	0
697924	695157	14275Y	PARTICIPANT	\N	PRESENT	0
697926	695157	20040T	PARTICIPANT	\N	PRESENT	0
697974	695157	20024T	PARTICIPANT	\N	PRESENT	0
697975	695157	14213J	PARTICIPANT	\N	PRESENT	0
697976	695157	20142Y	PARTICIPANT	\N	PRESENT	0
697977	695157	19489J	PARTICIPANT	\N	PRESENT	0
697978	695157	11027H	PARTICIPANT	\N	PRESENT	0
697979	695157	20172F	PARTICIPANT	\N	PRESENT	0
697980	695157	14257W	PARTICIPANT	\N	PRESENT	0
697981	695157	19673G	PARTICIPANT	\N	PRESENT	0
697982	695157	19713W	PARTICIPANT	\N	PRESENT	0
697986	695157	14053L	PARTICIPANT	\N	PRESENT	0
697988	695157	20098N	PARTICIPANT	\N	PRESENT	0
698006	695157	19533U	PARTICIPANT	\N	PRESENT	0
698007	695157	19527W	PARTICIPANT	\N	PRESENT	0
698008	695157	19621T	PARTICIPANT	\N	PRESENT	0
698009	695157	04057K	PARTICIPANT	\N	PRESENT	0
698010	695157	14042U	PARTICIPANT	\N	PRESENT	0
698011	695157	20110Q	PARTICIPANT	\N	PRESENT	0
698012	695157	20026V	PARTICIPANT	\N	PRESENT	0
698013	695157	11033F	PARTICIPANT	\N	PRESENT	0
698014	695157	20134Y	PARTICIPANT	\N	PRESENT	0
698026	695158	99004R	PARTICIPANT	\N	PRESENT	0
698028	695158	11045K	PARTICIPANT	\N	PRESENT	0
698030	695158	19565D	PARTICIPANT	\N	PRESENT	0
694028	692458	14187A	PARTICIPANT	\N	PRESENT	0
694029	692458	19695N	PARTICIPANT	\N	PRESENT	0
694030	692458	11090Q	PRESIDENT	0	PRESENT	0
694031	692458	01025N	PARTICIPANT	\N	PRESENT	0
694032	692458	14033T	PARTICIPANT	\N	PRESENT	0
694033	692458	20054A	PARTICIPANT	\N	PRESENT	0
694034	692458	14205J	PARTICIPANT	\N	PRESENT	0
694035	692458	20062A	PARTICIPANT	\N	PRESENT	0
694036	692458	19507S	PARTICIPANT	\N	PRESENT	0
694037	692458	20286Q	PARTICIPANT	\N	PRESENT	0
694038	692458	20298U	PARTICIPANT	\N	PRESENT	0
694039	692458	19747H	PARTICIPANT	\N	PRESENT	0
694040	692458	14207L	PARTICIPANT	\N	PRESENT	0
694041	692458	14257W	PARTICIPANT	\N	PRESENT	0
694048	690706	11065P	PARTICIPANT	\N	PRESENT	0
694068	692388	20072C	PARTICIPANT	\N	EXCUSE	0
694358	694357	19543W	PARTICIPANT	\N	PRESENT	0
694359	694357	11026G	PARTICIPANT	\N	PRESENT	0
694648	694646	20112S	PARTICIPANT	\N	PRESENT	0
694349	694345	20024T	PARTICIPANT	\N	PRESENT	0
694350	694345	14267Y	PARTICIPANT	\N	PRESENT	0
694351	694345	14037X	PARTICIPANT	\N	PRESENT	0
694352	694345	14219Q	PARTICIPANT	\N	PRESENT	0
694353	694345	10015M	PARTICIPANT	\N	PRESENT	0
694355	694354	14083S	PARTICIPANT	\N	PRESENT	0
694356	694354	20054A	PARTICIPANT	\N	PRESENT	0
694649	694646	19643A	PARTICIPANT	\N	PRESENT	0
694650	694646	19735D	PARTICIPANT	\N	PRESENT	0
694651	694646	19693L	PARTICIPANT	\N	PRESENT	0
694653	692431	19649G	PARTICIPANT	\N	PRESENT	0
694654	692431	20100N	PARTICIPANT	\N	PRESENT	0
694655	692431	20134Y	PARTICIPANT	\N	PRESENT	0
694656	692431	20016T	PARTICIPANT	\N	PRESENT	0
694657	692431	20110Q	PARTICIPANT	\N	PRESENT	0
694658	692431	08012N	PARTICIPANT	\N	PRESENT	0
694659	692431	20064C	PARTICIPANT	\N	PRESENT	0
694660	692431	14229S	PARTICIPANT	\N	PRESENT	0
694661	692431	20142Y	PARTICIPANT	\N	PRESENT	0
694662	692431	19441R	PARTICIPANT	\N	PRESENT	0
694663	692431	19565D	PARTICIPANT	\N	PRESENT	0
694664	692431	11043H	PARTICIPANT	\N	PRESENT	0
694665	692431	20102Q	PARTICIPANT	\N	PRESENT	0
694666	692431	20112S	PARTICIPANT	\N	PRESENT	0
694667	692431	20068G	PARTICIPANT	\N	PRESENT	0
694668	692431	20132W	PARTICIPANT	\N	PRESENT	0
694669	692431	17737W	PARTICIPANT	\N	PRESENT	0
694670	692431	14215L	PARTICIPANT	\N	PRESENT	0
694671	692431	01058X	PARTICIPANT	\N	PRESENT	0
694672	692431	20152B	PARTICIPANT	\N	PRESENT	0
694673	692431	14069U	PARTICIPANT	\N	PRESENT	0
694674	692431	19675J	PARTICIPANT	\N	PRESENT	0
694675	692431	20062A	PARTICIPANT	\N	PRESENT	0
694676	692431	14147R	PARTICIPANT	\N	PRESENT	0
694677	692431	14053L	PARTICIPANT	\N	PRESENT	0
694678	692431	04047H	PARTICIPANT	\N	PRESENT	0
694679	692431	20034V	PARTICIPANT	\N	PRESENT	0
694680	692431	20074E	PARTICIPANT	\N	PRESENT	0
694681	692431	19543W	PARTICIPANT	\N	PRESENT	0
694682	692431	19583F	PARTICIPANT	\N	PRESENT	0
694683	692431	14073Q	PARTICIPANT	\N	PRESENT	0
694684	694652	14331P	PARTICIPANT	\N	PRESENT	0
694685	694652	14083S	PARTICIPANT	\N	PRESENT	0
694686	694652	07029T	PARTICIPANT	\N	PRESENT	0
694687	694652	14121F	PARTICIPANT	\N	PRESENT	0
694688	694652	20116W	PARTICIPANT	\N	PRESENT	0
694689	694652	20914V	PARTICIPANT	\N	PRESENT	0
694690	694652	19667J	PARTICIPANT	\N	PRESENT	0
694691	694652	99004R	PARTICIPANT	\N	PRESENT	0
694692	694652	20044X	PARTICIPANT	\N	PRESENT	0
694693	694652	14225N	PRESIDENT	0	PRESENT	0
694694	694652	19671E	PARTICIPANT	\N	PRESENT	0
694695	694652	11048N	PARTICIPANT	\N	EXCUSE	0
694696	694652	14189C	PARTICIPANT	\N	EXCUSE	0
694697	694652	01057W	PARTICIPANT	\N	PRESENT	0
694698	694652	20080C	PARTICIPANT	\N	PRESENT	0
694699	694652	08034U	PARTICIPANT	\N	PRESENT	0
694700	692431	14133K	PARTICIPANT	\N	PRESENT	0
694701	692431	19611R	PARTICIPANT	\N	PRESENT	0
694702	692431	04085P	PARTICIPANT	\N	PRESENT	0
694703	694652	20070A	PARTICIPANT	\N	PRESENT	0
694704	692431	19693L	PARTICIPANT	\N	PRESENT	0
694705	692431	19399H	PARTICIPANT	\N	PRESENT	0
694706	692431	20264J	PARTICIPANT	\N	PRESENT	0
694707	692431	19533U	PARTICIPANT	\N	PRESENT	0
694708	692431	19479G	PARTICIPANT	\N	PRESENT	0
694709	692431	19593H	PARTICIPANT	\N	PRESENT	0
694710	692431	19301E	PARTICIPANT	\N	PRESENT	0
694711	694652	08010L	PARTICIPANT	\N	PRESENT	0
694712	692431	20022R	PARTICIPANT	\N	PRESENT	0
694713	692431	20084G	PARTICIPANT	\N	PRESENT	0
694714	694652	19479G	PARTICIPANT	\N	PRESENT	0
694715	692431	14357A	PARTICIPANT	\N	PRESENT	0
694716	692431	11080N	PARTICIPANT	\N	PRESENT	0
694717	694652	19531S	PARTICIPANT	\N	PRESENT	0
694718	692431	11012A	PARTICIPANT	\N	PRESENT	0
694719	692431	14179A	PARTICIPANT	\N	PRESENT	0
694720	692431	20032T	PARTICIPANT	\N	PRESENT	0
694721	692431	08061X	PARTICIPANT	\N	PRESENT	0
694722	692431	20252E	PARTICIPANT	\N	PRESENT	0
694723	692431	14031R	PARTICIPANT	\N	PRESENT	0
694724	692431	19723Y	PARTICIPANT	\N	PRESENT	0
694725	692431	12041X	PARTICIPANT	\N	PRESENT	0
694726	692431	20136B	PARTICIPANT	\N	PRESENT	0
694727	692431	14257W	PARTICIPANT	\N	PRESENT	0
694728	692431	04071H	PARTICIPANT	\N	PRESENT	0
694729	692431	19782L	PARTICIPANT	\N	PRESENT	0
694730	692431	17023S	PARTICIPANT	\N	PRESENT	0
694731	692431	14021P	PARTICIPANT	\N	PRESENT	0
694732	692431	19701S	PARTICIPANT	\N	PRESENT	0
694733	692431	04057K	PARTICIPANT	\N	PRESENT	0
694734	692431	20914V	PARTICIPANT	\N	PRESENT	0
694742	692431	19415P	PARTICIPANT	\N	PRESENT	0
694750	692431	14121F	PARTICIPANT	\N	PRESENT	0
694751	694652	11053K	PARTICIPANT	\N	PRESENT	0
694752	692431	19447X	PARTICIPANT	\N	PRESENT	0
694753	692431	14033T	PARTICIPANT	\N	PRESENT	0
694754	692431	19697Q	PARTICIPANT	\N	PRESENT	0
694755	692431	14030Q	PARTICIPANT	\N	PRESENT	0
694756	692431	19591F	PARTICIPANT	\N	PRESENT	0
694757	692431	14059S	PARTICIPANT	\N	PRESENT	0
694758	692431	20048C	PARTICIPANT	\N	PRESENT	0
694759	692431	20052X	PARTICIPANT	\N	PRESENT	0
694760	692431	20298U	PARTICIPANT	\N	PRESENT	0
694785	692431	14083S	PARTICIPANT	\N	PRESENT	0
694786	692431	07029T	PARTICIPANT	\N	PRESENT	0
694787	692431	08011M	PARTICIPANT	\N	PRESENT	0
694788	692431	19549D	PARTICIPANT	\N	PRESENT	0
694789	692431	20038A	PARTICIPANT	\N	PRESENT	0
694790	692431	18083K	PARTICIPANT	\N	PRESENT	0
694791	692431	01024M	PARTICIPANT	\N	PRESENT	0
694792	692431	20092G	PARTICIPANT	\N	PRESENT	0
694825	691220	20132W	PARTICIPANT	\N	PRESENT	0
694826	691220	20068G	PARTICIPANT	\N	PRESENT	0
694827	691220	19643A	PARTICIPANT	\N	PRESENT	0
694828	691220	95063L	PARTICIPANT	\N	PRESENT	0
694834	692316	19717B	PRESIDENT	0	PRESENT	0
694835	692316	18083K	PARTICIPANT	\N	PRESENT	0
694836	692316	19577H	PARTICIPANT	\N	PRESENT	1
694837	692316	19329S	PARTICIPANT	\N	PRESENT	1
694838	692316	20034V	PARTICIPANT	\N	PRESENT	0
694839	692316	11043H	PARTICIPANT	\N	EXCUSE	0
694840	692316	19319Q	PARTICIPANT	\N	PRESENT	0
694843	693561	17023S	PARTICIPANT	\N	EXCUSE	0
694844	693586	17023S	PARTICIPANT	\N	EXCUSE	0
694846	693587	17023S	PARTICIPANT	\N	EXCUSE	0
694872	692316	19715Y	PARTICIPANT	\N	PRESENT	1
694882	692388	19693L	PARTICIPANT	\N	PRESENT	0
694883	692388	20128B	PARTICIPANT	\N	PRESENT	0
694885	692388	01048V	PARTICIPANT	\N	PRESENT	0
694886	692388	14221J	PARTICIPANT	\N	PRESENT	0
694887	692388	11067R	PARTICIPANT	\N	PRESENT	0
694888	692388	19533U	PARTICIPANT	\N	PRESENT	0
694889	692388	19503N	PARTICIPANT	\N	PRESENT	0
694939	692388	04043D	PARTICIPANT	\N	PRESENT	0
695109	695107	19709B	PARTICIPANT	\N	EXCUSE	0
686801	686800	14033T	PARTICIPANT	\N	PRESENT	0
686802	686800	20018V	PARTICIPANT	\N	PRESENT	0
686809	686804	14033T	PARTICIPANT	\N	PRESENT	0
686810	686804	19782L	PARTICIPANT	\N	PRESENT	0
686811	686804	14207L	PARTICIPANT	\N	PRESENT	0
686812	686805	14033T	PARTICIPANT	\N	PRESENT	0
686813	686805	14207L	PARTICIPANT	\N	PRESENT	0
686814	686806	14033T	PARTICIPANT	\N	PRESENT	0
686815	686806	20092G	PARTICIPANT	\N	PRESENT	0
686816	686806	14207L	PARTICIPANT	\N	PRESENT	0
686817	686807	14033T	PARTICIPANT	\N	PRESENT	0
686829	686819	14033T	PARTICIPANT	\N	PRESENT	0
686830	686819	20062A	PARTICIPANT	\N	PRESENT	0
686831	686821	14033T	PARTICIPANT	\N	PRESENT	0
686832	686821	20062A	PARTICIPANT	\N	PRESENT	0
686833	686821	20092G	PARTICIPANT	\N	PRESENT	0
686834	686822	14033T	PARTICIPANT	\N	PRESENT	0
686835	686824	14033T	PARTICIPANT	\N	PRESENT	0
688357	688356	05008E	PARTICIPANT	\N	PRESENT	0
688358	688356	11033F	PARTICIPANT	\N	PRESENT	0
688359	688356	11053K	PARTICIPANT	\N	PRESENT	0
688360	688356	14357A	PARTICIPANT	\N	PRESENT	0
688361	688356	11070L	PARTICIPANT	\N	PRESENT	0
690888	690884	17965H	PARTICIPANT	\N	PRESENT	0
688363	688356	19673G	PARTICIPANT	\N	PRESENT	0
688364	688356	01025N	PARTICIPANT	\N	PRESENT	0
690889	690884	11045K	PARTICIPANT	\N	PRESENT	0
688366	688356	14033T	PARTICIPANT	\N	PRESENT	0
690890	690885	11045K	PARTICIPANT	\N	PRESENT	0
688368	688356	14026U	PARTICIPANT	\N	PRESENT	0
688369	688356	11064N	PARTICIPANT	\N	PRESENT	0
690891	690885	19683J	PARTICIPANT	\N	PRESENT	0
688371	688356	14213J	PARTICIPANT	\N	PRESENT	0
688372	688356	19715Y	PARTICIPANT	\N	PRESENT	0
688373	688356	99004R	PARTICIPANT	\N	PRESENT	0
688374	688356	86034E	PARTICIPANT	\N	PRESENT	0
688375	688356	12041X	PARTICIPANT	\N	PRESENT	0
688376	688356	01043Q	PARTICIPANT	\N	PRESENT	0
688377	688356	14147R	PARTICIPANT	\N	PRESENT	0
688378	688356	95063L	PARTICIPANT	\N	PRESENT	0
688379	688356	11045K	PARTICIPANT	\N	PRESENT	0
688380	688356	01028R	PARTICIPANT	\N	PRESENT	0
688381	688356	19301E	PARTICIPANT	\N	PRESENT	0
688382	688356	19413M	PARTICIPANT	\N	PRESENT	0
690892	690885	17965H	PARTICIPANT	\N	PRESENT	0
690924	690886	14026U	PARTICIPANT	\N	PRESENT	0
699129	698964	20068G	PARTICIPANT	\N	EXCUSE	0
699865	698937	14053L	PARTICIPANT	\N	PRESENT	0
699866	698937	19629C	PARTICIPANT	\N	PRESENT	0
699867	698937	07004J	PARTICIPANT	\N	PRESENT	0
699868	698937	20074E	PARTICIPANT	\N	PRESENT	0
699869	698937	14215L	PARTICIPANT	\N	PRESENT	0
699870	698937	04047H	PRESIDENT	0	PRESENT	0
699871	698937	19681G	PARTICIPANT	\N	PRESENT	0
699872	698937	19673G	PARTICIPANT	\N	PRESENT	0
699873	698937	19675J	PARTICIPANT	\N	PRESENT	0
699874	698937	19447X	PARTICIPANT	\N	PRESENT	0
699875	698937	14231L	PARTICIPANT	\N	PRESENT	0
699876	698937	20108W	PARTICIPANT	\N	PRESENT	0
699877	698937	20038A	PARTICIPANT	\N	PRESENT	0
699878	698937	19387D	PARTICIPANT	\N	PRESENT	0
699879	698937	20050V	PARTICIPANT	\N	PRESENT	0
699880	698937	11056N	PARTICIPANT	\N	PRESENT	0
699881	698937	14107H	PARTICIPANT	\N	PRESENT	0
699882	698937	14111D	PARTICIPANT	\N	PRESENT	0
699883	698937	19543W	PARTICIPANT	\N	PRESENT	0
699884	698937	19585H	PARTICIPANT	\N	PRESENT	0
699885	698937	05008E	PARTICIPANT	\N	PRESENT	0
699886	698937	08018U	PARTICIPANT	\N	PRESENT	0
699902	698937	14001X	PARTICIPANT	\N	PRESENT	0
699903	698937	19954N	PARTICIPANT	\N	PRESENT	0
699904	698937	14147R	PARTICIPANT	\N	PRESENT	0
699905	698937	20114U	PARTICIPANT	\N	PRESENT	0
699906	698937	20022R	PARTICIPANT	\N	PRESENT	0
699907	698937	11072N	PARTICIPANT	\N	PRESENT	0
699908	698937	11033F	PARTICIPANT	\N	PRESENT	0
699909	698937	14089Y	PARTICIPANT	\N	PRESENT	0
699910	698937	19729F	PARTICIPANT	\N	PRESENT	0
699911	698937	95063L	PARTICIPANT	\N	PRESENT	0
699912	698937	14069U	PARTICIPANT	\N	PRESENT	0
699913	698937	04008A	PARTICIPANT	\N	PRESENT	0
699914	698937	11085T	PARTICIPANT	\N	PRESENT	0
699915	698937	17737W	PARTICIPANT	\N	EXCUSE	0
700335	700334	20110Q	PARTICIPANT	\N	PRESENT	0
699924	698937	14179A	PARTICIPANT	\N	PRESENT	0
699930	698937	14151M	PARTICIPANT	\N	PRESENT	0
699956	698937	19489J	PARTICIPANT	\N	PRESENT	0
699957	698937	14021P	PARTICIPANT	\N	PRESENT	0
700444	698970	86034E	PARTICIPANT	\N	PRESENT	0
700337	700334	14083S	PARTICIPANT	\N	PRESENT	0
700400	699099	19383Y	PARTICIPANT	\N	PRESENT	0
700401	699099	19768N	PARTICIPANT	\N	PRESENT	0
700402	699099	19515S	PARTICIPANT	\N	PRESENT	0
700403	699099	20092G	PARTICIPANT	\N	PRESENT	0
700404	699099	19782L	PARTICIPANT	\N	PRESENT	0
700405	699099	11077T	PARTICIPANT	\N	PRESENT	0
700406	699099	14357A	PARTICIPANT	\N	PRESENT	0
700407	699099	20078J	PARTICIPANT	\N	PRESENT	0
700408	699099	20082E	PARTICIPANT	\N	PRESENT	0
700409	699099	20094J	PARTICIPANT	\N	PRESENT	0
701370	698976	20100N	PARTICIPANT	\N	PRESENT	0
700411	699099	04045F	PARTICIPANT	\N	PRESENT	0
700412	699099	19866P	PARTICIPANT	\N	PRESENT	0
700413	699099	20104S	PARTICIPANT	\N	PRESENT	0
700414	699099	19631V	PARTICIPANT	\N	PRESENT	0
700415	699099	19705W	PARTICIPANT	\N	PRESENT	0
700416	699099	08015R	PARTICIPANT	\N	PRESENT	0
700417	699099	19369B	PARTICIPANT	\N	PRESENT	0
700418	699099	20018V	PARTICIPANT	\N	PRESENT	0
700419	699099	08028W	PARTICIPANT	\N	PRESENT	0
700420	699099	19563B	PARTICIPANT	\N	PRESENT	0
700421	699099	20028X	PARTICIPANT	\N	PRESENT	0
700422	699099	14037X	PARTICIPANT	\N	PRESENT	0
700423	699099	20030R	PARTICIPANT	\N	PRESENT	0
700424	699099	19467C	PARTICIPANT	\N	PRESENT	0
700425	699099	20034V	PARTICIPANT	\N	PRESENT	0
700426	699099	14187A	PARTICIPANT	\N	PRESENT	0
700427	699099	20144B	PARTICIPANT	\N	PRESENT	0
700428	699099	19695N	PARTICIPANT	\N	PRESENT	0
700429	699099	14033T	PARTICIPANT	\N	PRESENT	0
700430	699099	11090Q	PRESIDENT	0	PRESENT	0
700431	699099	20054A	PARTICIPANT	\N	PRESENT	0
700432	699099	14205J	PARTICIPANT	\N	PRESENT	0
700433	699099	20060X	PARTICIPANT	\N	PRESENT	0
700434	699099	20062A	PARTICIPANT	\N	PRESENT	0
700435	699099	14251Q	PARTICIPANT	\N	PRESENT	0
700436	699099	19507S	PARTICIPANT	\N	PRESENT	0
700437	699099	20286Q	PARTICIPANT	\N	PRESENT	0
700438	699099	20298U	PARTICIPANT	\N	PRESENT	0
700439	699099	19747H	PARTICIPANT	\N	PRESENT	0
700440	699099	14207L	PARTICIPANT	\N	PRESENT	0
700441	699099	14257W	PARTICIPANT	\N	PRESENT	0
700442	699099	19413M	PARTICIPANT	\N	EXCUSE	0
700443	699099	01025N	PARTICIPANT	\N	EXCUSE	0
701369	698976	19347U	PARTICIPANT	\N	PRESENT	0
701371	698976	20086J	PARTICIPANT	\N	PRESENT	0
701372	698976	20128B	PARTICIPANT	\N	PRESENT	0
701373	698976	14069U	PARTICIPANT	\N	PRESENT	0
701374	698976	14026U	PARTICIPANT	\N	PRESENT	0
701375	698976	20070A	PARTICIPANT	\N	PRESENT	0
703715	701790	14033T	PARTICIPANT	\N	PRESENT	0
703716	701790	20034V	PARTICIPANT	\N	PRESENT	0
703717	701790	11099A	PARTICIPANT	\N	PRESENT	0
703718	701790	08015R	PARTICIPANT	\N	PRESENT	0
703719	701790	14037X	PARTICIPANT	\N	PRESENT	0
703720	701790	14205J	PARTICIPANT	\N	PRESENT	0
703721	701790	19441R	PARTICIPANT	\N	PRESENT	0
703722	701790	14251Q	PARTICIPANT	\N	PRESENT	0
703723	701790	19563B	PARTICIPANT	\N	PRESENT	0
703724	701790	20028X	PARTICIPANT	\N	PRESENT	0
703726	701790	20018V	PARTICIPANT	\N	PRESENT	0
703727	701790	19369B	PARTICIPANT	\N	PRESENT	0
703728	701790	14257W	PARTICIPANT	\N	PRESENT	0
703729	701790	19866P	PARTICIPANT	\N	PRESENT	0
703730	701790	20030R	PARTICIPANT	\N	PRESENT	0
703731	701790	20298U	PARTICIPANT	\N	PRESENT	0
703780	701649	99004R	PARTICIPANT	\N	PRESENT	0
703781	701651	99004R	PARTICIPANT	\N	PRESENT	0
703832	701651	19691J	PARTICIPANT	\N	PRESENT	0
703835	701651	14033T	PARTICIPANT	\N	PRESENT	0
703836	701651	01058X	PARTICIPANT	\N	PRESENT	0
708044	706244	14217N	PARTICIPANT	\N	PRESENT	0
708045	706244	04092N	PARTICIPANT	\N	PRESENT	0
708046	706244	19691J	PARTICIPANT	\N	PRESENT	0
708047	706244	14071N	PARTICIPANT	\N	PRESENT	0
708048	706244	19723Y	PARTICIPANT	\N	PRESENT	0
708049	706244	14026U	PARTICIPANT	\N	PRESENT	0
708435	708434	19549D	PARTICIPANT	\N	PRESENT	0
708436	708434	19701S	PARTICIPANT	\N	PRESENT	0
708437	708434	19525U	PARTICIPANT	\N	PRESENT	0
708438	708434	14187A	PRESIDENT	0	PRESENT	0
708439	708434	20286Q	PARTICIPANT	\N	PRESENT	0
708440	708434	19347U	PARTICIPANT	\N	PRESENT	0
708441	708434	20018V	PARTICIPANT	\N	PRESENT	0
708442	708434	14257W	PARTICIPANT	\N	PRESENT	0
708443	708434	20298U	PARTICIPANT	\N	PRESENT	0
708444	708434	20090E	PARTICIPANT	\N	EXCUSE	0
708445	708434	19681G	PARTICIPANT	\N	EXCUSE	0
708456	708455	05008E	PARTICIPANT	\N	PRESENT	0
708457	708455	11053K	PARTICIPANT	\N	PRESENT	0
708458	708455	01028R	PARTICIPANT	\N	PRESENT	0
708845	708844	20058E	PARTICIPANT	\N	PRESENT	0
708846	708148	14026U	PARTICIPANT	\N	PRESENT	0
708847	706245	19703U	PARTICIPANT	\N	PRESENT	0
708848	706245	20090E	PARTICIPANT	\N	PRESENT	0
708849	706245	04057K	PARTICIPANT	\N	PRESENT	0
708850	706245	19798U	PARTICIPANT	\N	PRESENT	0
708851	706245	11097X	PARTICIPANT	\N	PRESENT	0
708852	706245	19367Y	PARTICIPANT	\N	PRESENT	0
708853	706245	14213J	PARTICIPANT	\N	PRESENT	0
708854	706245	14071N	PRESIDENT	0	PRESENT	0
708855	706245	19657G	PARTICIPANT	\N	PRESENT	0
708856	706245	14223L	PARTICIPANT	\N	PRESENT	0
708857	708844	14109K	PARTICIPANT	\N	PRESENT	0
708858	708148	11040E	PARTICIPANT	\N	PRESENT	0
708859	708148	19760E	PARTICIPANT	\N	PRESENT	0
708860	708148	11056N	PARTICIPANT	\N	PRESENT	0
708861	708148	19758L	PARTICIPANT	\N	PRESENT	0
708862	708148	19565D	PARTICIPANT	\N	PRESENT	0
708863	708148	11077T	PARTICIPANT	\N	PRESENT	0
708864	708148	20046A	PARTICIPANT	\N	PRESENT	0
708865	708148	20102Q	PARTICIPANT	\N	PRESENT	0
708866	708148	20112S	PARTICIPANT	\N	PRESENT	0
708867	708148	14257W	PARTICIPANT	\N	PRESENT	0
708868	708148	11067R	PARTICIPANT	\N	PRESENT	0
708869	708148	20074E	PARTICIPANT	\N	PRESENT	0
708870	708148	11045K	PARTICIPANT	\N	PRESENT	0
708871	708148	19649G	PARTICIPANT	\N	PRESENT	0
708872	708148	99004R	PARTICIPANT	\N	PRESENT	0
708873	708148	19669L	PARTICIPANT	\N	PRESENT	0
708874	708148	11097X	PARTICIPANT	\N	PRESENT	0
708875	708148	19515S	PARTICIPANT	\N	PRESENT	0
708876	708148	14042U	PARTICIPANT	\N	PRESENT	0
708877	708148	20038A	PARTICIPANT	\N	PRESENT	0
708878	708148	14151M	PARTICIPANT	\N	PRESENT	0
708879	708148	10015M	PARTICIPANT	\N	PRESENT	0
708880	708148	17965H	PARTICIPANT	\N	PRESENT	0
708881	708148	14021P	PARTICIPANT	\N	PRESENT	0
708882	708148	20026V	PARTICIPANT	\N	PRESENT	0
708883	708148	19599P	PARTICIPANT	\N	PRESENT	0
708884	708148	07029T	PARTICIPANT	\N	PRESENT	0
708885	706245	19713W	PARTICIPANT	\N	PRESENT	0
708886	706245	20040T	PARTICIPANT	\N	PRESENT	0
708887	706245	19415P	PARTICIPANT	\N	PRESENT	0
708888	706245	19723Y	PARTICIPANT	\N	PRESENT	0
708889	706245	14042U	PARTICIPANT	\N	PRESENT	0
708890	706245	14217N	PARTICIPANT	\N	PRESENT	0
708891	708148	11027H	PARTICIPANT	\N	PRESENT	0
708892	708148	17779H	PARTICIPANT	\N	PRESENT	0
708893	708148	08060W	PARTICIPANT	\N	PRESENT	0
708894	708148	11066Q	PARTICIPANT	\N	PRESENT	0
708895	708148	14281W	PARTICIPANT	\N	PRESENT	0
708897	708148	14229S	PARTICIPANT	\N	PRESENT	0
708898	708148	08018U	PARTICIPANT	\N	PRESENT	0
708899	708148	20092G	PARTICIPANT	\N	PRESENT	0
708900	708148	20100N	PARTICIPANT	\N	PRESENT	0
708901	708148	19657G	PARTICIPANT	\N	PRESENT	0
708902	708148	20130U	PARTICIPANT	\N	PRESENT	0
708903	708148	08015R	PARTICIPANT	\N	PRESENT	0
708904	708148	20036X	PARTICIPANT	\N	PRESENT	0
708905	708148	01058X	PARTICIPANT	\N	PRESENT	0
708906	708148	19531S	PARTICIPANT	\N	PRESENT	0
708907	708148	20090E	PARTICIPANT	\N	PRESENT	0
708908	708148	18193Q	PARTICIPANT	\N	PRESENT	0
708909	708148	19503N	PARTICIPANT	\N	PRESENT	0
708910	708148	08056B	PARTICIPANT	\N	PRESENT	0
708911	708148	19631V	PARTICIPANT	\N	PRESENT	0
708912	708148	19527W	PARTICIPANT	\N	PRESENT	0
708913	708148	20064C	PARTICIPANT	\N	PRESENT	0
708914	708148	14329V	PARTICIPANT	\N	PRESENT	0
708915	708148	19413M	PARTICIPANT	\N	PRESENT	0
708916	708148	20032T	PARTICIPANT	\N	PRESENT	0
708917	708148	20080C	PARTICIPANT	\N	PRESENT	0
708918	708148	14223L	PARTICIPANT	\N	PRESENT	0
708919	708148	12028B	PARTICIPANT	\N	PRESENT	0
708920	708148	19703U	PARTICIPANT	\N	PRESENT	0
708921	708148	08028W	PARTICIPANT	\N	PRESENT	0
708922	708148	11104D	PARTICIPANT	\N	PRESENT	0
708923	708148	04033B	PARTICIPANT	\N	PRESENT	0
708925	708148	19701S	PARTICIPANT	\N	PRESENT	0
708927	708148	19367Y	PARTICIPANT	\N	PRESENT	0
708928	708148	20114U	PARTICIPANT	\N	PRESENT	0
708929	708148	20252E	PARTICIPANT	\N	PRESENT	0
708930	708148	20028X	PARTICIPANT	\N	PRESENT	0
708931	708924	19621T	PARTICIPANT	\N	PRESENT	0
708932	708148	12016W	PARTICIPANT	\N	PRESENT	0
708933	708924	14030Q	PARTICIPANT	\N	PRESENT	0
708934	708924	14109K	PARTICIPANT	\N	PRESENT	0
708935	708148	20060X	PARTICIPANT	\N	PRESENT	0
708938	708148	19747H	PARTICIPANT	\N	PRESENT	0
708939	708148	19415P	PARTICIPANT	\N	PRESENT	0
708940	708924	20058E	PARTICIPANT	\N	PRESENT	0
708941	708148	20094J	PARTICIPANT	\N	PRESENT	0
708942	708148	14071N	PARTICIPANT	\N	PRESENT	0
708943	708148	20084G	PARTICIPANT	\N	PRESENT	0
708944	708148	08034U	PARTICIPANT	\N	PRESENT	0
708945	708148	20018V	PARTICIPANT	\N	PRESENT	0
708946	708148	04092N	PARTICIPANT	\N	PRESENT	0
708947	708148	19637C	PARTICIPANT	\N	PRESENT	0
708948	708148	19349W	PARTICIPANT	\N	PRESENT	0
708949	708148	10006L	PARTICIPANT	\N	PRESENT	0
708950	708148	04045F	PARTICIPANT	\N	PRESENT	0
708951	708148	95063L	PARTICIPANT	\N	PRESENT	0
708952	708148	20136B	PARTICIPANT	\N	PRESENT	0
708953	708148	20106U	PARTICIPANT	\N	PRESENT	0
708954	708148	19525U	PARTICIPANT	\N	PRESENT	0
708955	708148	14207L	PARTICIPANT	\N	PRESENT	0
708956	708148	19387D	PARTICIPANT	\N	PRESENT	0
708957	708148	20072C	PARTICIPANT	\N	PRESENT	0
708958	708148	20132W	PARTICIPANT	\N	PRESENT	0
708959	708148	14107H	PARTICIPANT	\N	PRESENT	0
708960	708148	04057K	PARTICIPANT	\N	PRESENT	0
708961	708148	14111D	PARTICIPANT	\N	PRESENT	0
708962	708148	19585H	PARTICIPANT	\N	PRESENT	0
708963	708148	20052X	PARTICIPANT	\N	PRESENT	0
708964	708148	14267Y	PARTICIPANT	\N	PRESENT	0
708965	708148	14211G	PARTICIPANT	\N	PRESENT	0
708966	708148	14255U	PARTICIPANT	\N	PRESENT	0
708967	708148	01043Q	PARTICIPANT	\N	PRESENT	0
708968	708148	19619A	PARTICIPANT	\N	PRESENT	0
708969	708148	19749K	PARTICIPANT	\N	PRESENT	0
708970	708148	14327T	PARTICIPANT	\N	PRESENT	0
708971	708148	19691J	PARTICIPANT	\N	PRESENT	0
708972	708148	01024M	PARTICIPANT	\N	PRESENT	0
708973	708148	11085T	PARTICIPANT	\N	PRESENT	0
708974	708148	20066E	PARTICIPANT	\N	PRESENT	0
708975	708148	19739H	PARTICIPANT	\N	PRESENT	0
708976	708148	08045X	PARTICIPANT	\N	PRESENT	0
708977	708148	20078J	PARTICIPANT	\N	PRESENT	0
708978	708148	19347U	PARTICIPANT	\N	PRESENT	0
708979	708148	20134Y	PARTICIPANT	\N	PRESENT	0
708980	708148	14259Y	PARTICIPANT	\N	PRESENT	0
708981	708148	20108W	PARTICIPANT	\N	PRESENT	0
708982	708148	19489J	PARTICIPANT	\N	PRESENT	0
708983	708148	20264J	PARTICIPANT	\N	PRESENT	0
708984	708148	19762G	PARTICIPANT	\N	PRESENT	0
708985	708148	20144B	PARTICIPANT	\N	PRESENT	0
708986	708148	14030Q	PARTICIPANT	\N	PRESENT	0
708987	708148	14073Q	PARTICIPANT	\N	PRESENT	0
708988	708148	11074Q	PARTICIPANT	\N	PRESENT	0
708989	708148	20914V	PARTICIPANT	\N	PRESENT	0
690894	690887	14038Y	PARTICIPANT	\N	PRESENT	0
690895	690887	11090Q	PRESIDENT	0	PRESENT	0
690896	690887	08028W	PARTICIPANT	\N	PRESENT	0
690897	690887	19369B	PARTICIPANT	\N	PRESENT	0
690898	690887	20088L	PARTICIPANT	\N	PRESENT	0
690899	690887	19782L	PARTICIPANT	\N	PRESENT	0
690900	690887	20092G	PARTICIPANT	\N	PRESENT	0
690901	690887	19413M	PARTICIPANT	\N	PRESENT	0
690902	690887	20082E	PARTICIPANT	\N	PRESENT	0
690903	690887	20094J	PARTICIPANT	\N	PRESENT	0
690904	690887	04045F	PARTICIPANT	\N	PRESENT	0
690905	690887	19705W	PARTICIPANT	\N	PRESENT	0
690906	690887	08015R	PARTICIPANT	\N	PRESENT	0
690907	690887	19575F	PARTICIPANT	\N	PRESENT	0
690908	690887	20018V	PARTICIPANT	\N	PRESENT	0
690909	690887	14329V	PARTICIPANT	\N	PRESENT	0
690910	690887	20028X	PARTICIPANT	\N	PRESENT	0
690911	690887	14037X	PARTICIPANT	\N	PRESENT	0
690912	690887	20030R	PARTICIPANT	\N	PRESENT	0
690913	690887	20034V	PARTICIPANT	\N	PRESENT	0
690914	690887	14187A	PARTICIPANT	\N	PRESENT	0
690915	690887	20144B	PARTICIPANT	\N	PRESENT	0
690916	690887	19695N	PARTICIPANT	\N	PRESENT	0
690917	690887	14033T	PARTICIPANT	\N	PRESENT	0
690918	690887	20054A	PARTICIPANT	\N	PRESENT	0
690919	690887	20062A	PARTICIPANT	\N	PRESENT	0
690920	690887	14251Q	PARTICIPANT	\N	PRESENT	0
690921	690887	20286Q	PARTICIPANT	\N	PRESENT	0
690922	690887	20298U	PARTICIPANT	\N	PRESENT	0
690923	690887	19747H	PARTICIPANT	\N	PRESENT	0
690925	690887	14257W	PARTICIPANT	\N	PRESENT	0
690926	690416	19593H	PARTICIPANT	\N	PRESENT	0
690927	690416	19643A	PARTICIPANT	\N	PRESENT	0
690928	690416	19699S	PARTICIPANT	\N	PRESENT	0
690929	690416	20134Y	PARTICIPANT	\N	PRESENT	0
690930	690416	14073Q	PARTICIPANT	\N	PRESENT	0
690931	690416	19611R	PRESIDENT	0	PRESENT	0
690932	690416	20142Y	PARTICIPANT	\N	PRESENT	0
690933	690416	19399H	PARTICIPANT	\N	PRESENT	0
690934	690416	20052X	PARTICIPANT	\N	PRESENT	0
690935	690416	14229S	PARTICIPANT	\N	PRESENT	0
690936	690416	20098N	PARTICIPANT	\N	PRESENT	0
690937	690416	20056C	PARTICIPANT	\N	PRESENT	0
690938	690416	19573D	PARTICIPANT	\N	PRESENT	0
690939	690416	04059M	PARTICIPANT	\N	PRESENT	0
690940	690416	19735D	PARTICIPANT	\N	PRESENT	0
690941	690416	08012N	PARTICIPANT	\N	PRESENT	0
690942	690416	14123H	PARTICIPANT	\N	PRESENT	0
690943	690416	20980G	PARTICIPANT	\N	PRESENT	0
690944	690416	20124W	PARTICIPANT	\N	PRESENT	0
690945	690416	20026V	PARTICIPANT	\N	PRESENT	0
690946	690416	20084G	PARTICIPANT	\N	PRESENT	0
690947	690416	19533U	PARTICIPANT	\N	PRESENT	0
690948	690416	20132W	PARTICIPANT	\N	PRESENT	0
690949	690416	20180F	PARTICIPANT	\N	PRESENT	0
690960	690822	14026U	PARTICIPANT	\N	PRESENT	0
690961	690822	14033T	PARTICIPANT	\N	PRESENT	0
690962	690822	19826F	PARTICIPANT	\N	PRESENT	0
690963	690822	14055N	PARTICIPANT	\N	PRESENT	0
690964	690822	19719D	PARTICIPANT	\N	PRESENT	0
690965	690822	19251M	PARTICIPANT	\N	PRESENT	0
690966	690822	20092G	PARTICIPANT	\N	PRESENT	0
690967	690822	11090Q	PARTICIPANT	\N	PRESENT	0
690968	690822	19563B	PARTICIPANT	\N	PRESENT	0
690969	690822	11065P	PARTICIPANT	\N	PRESENT	0
690970	690822	19782L	PARTICIPANT	\N	PRESENT	0
690971	690822	14257W	PARTICIPANT	\N	PRESENT	0
690972	690822	19695N	PARTICIPANT	\N	PRESENT	0
690973	690822	19369B	PARTICIPANT	\N	PRESENT	0
690974	690822	19533U	PARTICIPANT	\N	PRESENT	0
690975	690822	17229F	PARTICIPANT	\N	PRESENT	0
690976	690822	14331P	PARTICIPANT	\N	PRESENT	0
690977	690822	20136B	PARTICIPANT	\N	PRESENT	0
690978	690822	20062A	PARTICIPANT	\N	PRESENT	0
690979	690822	20076G	PARTICIPANT	\N	PRESENT	0
690980	690822	19583F	PARTICIPANT	\N	PRESENT	0
690981	690822	20046A	PARTICIPANT	\N	PRESENT	0
690982	690822	19798U	PARTICIPANT	\N	PRESENT	0
690983	690822	20100N	PARTICIPANT	\N	PRESENT	0
690984	690822	08028W	PARTICIPANT	\N	PRESENT	0
690985	690822	20032T	PARTICIPANT	\N	PRESENT	0
690986	690822	19399H	PARTICIPANT	\N	PRESENT	0
690987	690822	19637C	PARTICIPANT	\N	PRESENT	0
690988	690822	20072C	PARTICIPANT	\N	PRESENT	0
690989	690822	20102Q	PARTICIPANT	\N	PRESENT	0
690990	690822	19593H	PARTICIPANT	\N	PRESENT	0
690991	690822	19525U	PARTICIPANT	\N	PRESENT	0
690992	690822	19683J	PARTICIPANT	\N	PRESENT	0
690993	690822	19447X	PARTICIPANT	\N	PRESENT	0
690994	690822	19565D	PARTICIPANT	\N	PRESENT	0
690995	690822	95063L	PARTICIPANT	\N	PRESENT	0
690996	690822	20086J	PARTICIPANT	\N	PRESENT	0
690997	690822	08061X	PARTICIPANT	\N	PRESENT	0
690998	690822	19333N	PARTICIPANT	\N	PRESENT	0
690999	690822	19347U	PARTICIPANT	\N	PRESENT	0
691000	690822	19549D	PARTICIPANT	\N	PRESENT	0
691001	690822	14207L	PARTICIPANT	\N	PRESENT	0
691002	690822	20030R	PARTICIPANT	\N	PRESENT	0
691003	690822	14267Y	PARTICIPANT	\N	PRESENT	0
691004	690822	20034V	PARTICIPANT	\N	PRESENT	0
691005	690822	14357A	PARTICIPANT	\N	PRESENT	0
691006	690822	20298U	PARTICIPANT	\N	PRESENT	0
691007	690822	19659J	PARTICIPANT	\N	PRESENT	0
691008	690822	86034E	PARTICIPANT	\N	PRESENT	0
691009	690822	20026V	PARTICIPANT	\N	PRESENT	0
691010	690822	20078J	PARTICIPANT	\N	PRESENT	0
691011	690823	14026U	PARTICIPANT	\N	PRESENT	0
691012	690823	14033T	PARTICIPANT	\N	PRESENT	0
691013	690823	19826F	PARTICIPANT	\N	PRESENT	0
691014	690823	14055N	PARTICIPANT	\N	PRESENT	0
691015	690823	19719D	PARTICIPANT	\N	PRESENT	0
691016	690823	20092G	PARTICIPANT	\N	PRESENT	0
691017	690823	11090Q	PARTICIPANT	\N	PRESENT	0
691018	690823	19563B	PARTICIPANT	\N	PRESENT	0
691019	690823	19782L	PARTICIPANT	\N	PRESENT	0
691020	690823	14257W	PARTICIPANT	\N	PRESENT	0
691021	690823	19695N	PARTICIPANT	\N	PRESENT	0
691022	690823	19369B	PARTICIPANT	\N	PRESENT	0
691023	690823	19533U	PARTICIPANT	\N	PRESENT	0
691024	690823	17229F	PARTICIPANT	\N	PRESENT	0
691025	690823	14331P	PARTICIPANT	\N	PRESENT	0
691026	690823	20136B	PARTICIPANT	\N	PRESENT	0
691027	690823	20062A	PARTICIPANT	\N	PRESENT	0
691028	690823	20076G	PARTICIPANT	\N	PRESENT	0
691029	690823	19583F	PARTICIPANT	\N	PRESENT	0
691030	690823	20046A	PARTICIPANT	\N	PRESENT	0
691031	690823	19798U	PARTICIPANT	\N	PRESENT	0
691032	690823	20100N	PARTICIPANT	\N	PRESENT	0
691033	690823	08028W	PARTICIPANT	\N	PRESENT	0
691034	690823	20032T	PARTICIPANT	\N	PRESENT	0
691035	690823	19399H	PARTICIPANT	\N	PRESENT	0
691036	690823	19637C	PARTICIPANT	\N	PRESENT	0
691037	690823	20072C	PARTICIPANT	\N	PRESENT	0
691038	690823	20102Q	PARTICIPANT	\N	PRESENT	0
691039	690823	19593H	PARTICIPANT	\N	PRESENT	0
691040	690823	19525U	PARTICIPANT	\N	PRESENT	0
691041	690823	19683J	PARTICIPANT	\N	PRESENT	0
691042	690823	19447X	PARTICIPANT	\N	PRESENT	0
691043	690823	19565D	PARTICIPANT	\N	PRESENT	0
691044	690823	95063L	PARTICIPANT	\N	PRESENT	0
691045	690823	20086J	PARTICIPANT	\N	PRESENT	0
691046	690823	08061X	PARTICIPANT	\N	PRESENT	0
691047	690823	19333N	PARTICIPANT	\N	PRESENT	0
691048	690823	19347U	PARTICIPANT	\N	PRESENT	0
691049	690823	19549D	PARTICIPANT	\N	PRESENT	0
691050	690823	14207L	PARTICIPANT	\N	PRESENT	0
691051	690823	20030R	PARTICIPANT	\N	PRESENT	0
691052	690823	14267Y	PARTICIPANT	\N	PRESENT	0
691053	690823	20034V	PARTICIPANT	\N	PRESENT	0
691054	690823	14357A	PARTICIPANT	\N	PRESENT	0
691055	690823	20298U	PARTICIPANT	\N	PRESENT	0
691056	690823	86034E	PARTICIPANT	\N	PRESENT	0
691057	690823	20026V	PARTICIPANT	\N	PRESENT	0
691058	690823	20078J	PARTICIPANT	\N	PRESENT	0
691059	690825	14026U	PARTICIPANT	\N	PRESENT	0
691060	690825	14033T	PARTICIPANT	\N	PRESENT	0
691061	690825	19826F	PARTICIPANT	\N	PRESENT	0
691062	690825	14055N	PARTICIPANT	\N	PRESENT	0
691063	690825	19719D	PARTICIPANT	\N	PRESENT	0
691064	690825	20092G	PARTICIPANT	\N	PRESENT	0
691065	690825	11090Q	PARTICIPANT	\N	PRESENT	0
695110	690950	20066E	PARTICIPANT	\N	EXCUSE	0
695164	695112	20112S	PARTICIPANT	\N	PRESENT	0
695218	694941	04092N	PARTICIPANT	\N	EXCUSE	0
695219	694941	19295A	PARTICIPANT	\N	EXCUSE	0
695220	694941	19760E	PARTICIPANT	\N	EXCUSE	0
695221	695213	19319Q	PARTICIPANT	\N	PRESENT	0
695222	695193	14331P	PARTICIPANT	\N	PRESENT	0
695223	695193	07029T	PARTICIPANT	\N	PRESENT	0
695224	695193	11048N	PARTICIPANT	\N	PRESENT	0
695225	695193	20080C	PARTICIPANT	\N	PRESENT	0
695226	695193	08010L	PARTICIPANT	\N	PRESENT	0
695227	695193	19667J	PARTICIPANT	\N	PRESENT	0
695228	695193	20044X	PARTICIPANT	\N	PRESENT	0
695229	695193	14225N	PRESIDENT	0	PRESENT	0
695230	695193	19687N	PARTICIPANT	\N	PRESENT	0
695231	695193	08011M	PARTICIPANT	\N	PRESENT	0
695232	695193	14083S	PARTICIPANT	\N	PRESENT	0
695233	695193	14253S	PARTICIPANT	\N	PRESENT	0
695234	695193	11074Q	PARTICIPANT	\N	PRESENT	0
695235	695193	20252E	PARTICIPANT	\N	PRESENT	0
695236	694841	14053L	PARTICIPANT	\N	PRESENT	0
695237	694841	19954N	PARTICIPANT	\N	PRESENT	0
695238	694841	17737W	PARTICIPANT	\N	PRESENT	0
695239	694841	14111D	PARTICIPANT	\N	PRESENT	0
695240	694841	14147R	PARTICIPANT	\N	PRESENT	0
695241	694841	14151M	PARTICIPANT	\N	PRESENT	0
695242	694841	19585H	PARTICIPANT	\N	PRESENT	0
695243	694841	14259Y	PARTICIPANT	\N	PRESENT	0
695244	694841	04047H	PRESIDENT	0	PRESENT	0
695245	694841	19675J	PARTICIPANT	\N	PRESENT	0
695246	694841	05008E	PARTICIPANT	\N	PRESENT	0
695247	694841	19447X	PARTICIPANT	\N	PRESENT	0
695248	695193	19545Y	PARTICIPANT	\N	PRESENT	0
695249	695193	20126Y	PARTICIPANT	\N	PRESENT	0
695250	694841	14069U	PARTICIPANT	\N	PRESENT	0
695251	695193	19647E	PARTICIPANT	\N	PRESENT	0
695252	695193	19762G	PARTICIPANT	\N	PRESENT	0
695253	695193	19479G	PARTICIPANT	\N	PRESENT	0
695254	695193	20036X	PARTICIPANT	\N	PRESENT	0
695255	695193	19711U	PARTICIPANT	\N	PRESENT	0
695256	694841	14089Y	PARTICIPANT	\N	PRESENT	0
695257	694841	14179A	PARTICIPANT	\N	PRESENT	0
695258	694841	14215L	PARTICIPANT	\N	PRESENT	0
695292	695213	14001X	PARTICIPANT	\N	PRESENT	0
695296	695213	19826F	PARTICIPANT	\N	PRESENT	0
695294	695213	19659J	PARTICIPANT	\N	PRESENT	0
695295	695213	20074E	PARTICIPANT	\N	PRESENT	0
695297	695213	19479G	PARTICIPANT	\N	PRESENT	0
695298	695213	14097Y	PARTICIPANT	\N	PRESENT	0
695299	694941	11031D	PARTICIPANT	\N	PRESENT	0
695385	695213	08073C	PARTICIPANT	\N	PRESENT	0
695386	695213	18083K	PARTICIPANT	\N	PRESENT	0
695387	695213	11083R	PARTICIPANT	\N	PRESENT	0
695388	695213	99004R	PARTICIPANT	\N	PRESENT	0
695389	695213	95063L	PARTICIPANT	\N	PRESENT	0
695390	695213	19643A	PARTICIPANT	\N	PRESENT	0
695391	695213	08061X	PARTICIPANT	\N	PRESENT	0
695392	695213	11072N	PARTICIPANT	\N	PRESENT	0
695393	695213	14111D	PARTICIPANT	\N	PRESENT	0
695394	695213	14221J	PARTICIPANT	\N	PRESENT	0
695395	695213	14169X	PARTICIPANT	\N	PRESENT	0
695396	695213	04057K	PARTICIPANT	\N	PRESENT	0
695397	695213	14251Q	PARTICIPANT	\N	PRESENT	0
695398	695213	20122U	PARTICIPANT	\N	PRESENT	0
695399	695213	11064N	PARTICIPANT	\N	PRESENT	0
695400	695213	14055N	PARTICIPANT	\N	PRESENT	0
695401	695213	19553Y	PARTICIPANT	\N	PRESENT	0
695402	695213	20132W	PARTICIPANT	\N	PRESENT	0
695403	695213	10015M	PARTICIPANT	\N	PRESENT	0
695404	695213	11101A	PARTICIPANT	\N	PRESENT	0
695405	695213	19549D	PARTICIPANT	\N	PRESENT	0
695406	695213	20088L	PARTICIPANT	\N	PRESENT	0
695407	695213	08011M	PARTICIPANT	\N	PRESENT	0
695408	695213	19591F	PARTICIPANT	\N	PRESENT	0
695409	695213	08010L	PARTICIPANT	\N	PRESENT	0
695410	695213	11027H	PARTICIPANT	\N	PRESENT	0
695411	695213	19251M	PARTICIPANT	\N	PRESENT	0
695412	695213	11043H	PARTICIPANT	\N	PRESENT	0
695413	695213	19545Y	PARTICIPANT	\N	PRESENT	0
695414	695213	14223L	PARTICIPANT	\N	PRESENT	0
695415	695213	11074Q	PARTICIPANT	\N	PRESENT	0
695416	695213	11110B	PARTICIPANT	\N	PRESENT	0
695417	695213	14281W	PARTICIPANT	\N	PRESENT	0
695418	695213	04042C	PARTICIPANT	\N	PRESENT	0
695419	695213	19820Y	PARTICIPANT	\N	PRESENT	0
695420	695213	14133K	PARTICIPANT	\N	PRESENT	0
695421	695213	19599P	PARTICIPANT	\N	PRESENT	0
695422	695213	04033B	PARTICIPANT	\N	PRESENT	0
695423	695213	14193X	PARTICIPANT	\N	PRESENT	0
695424	695213	19415P	PARTICIPANT	\N	PRESENT	0
695425	695213	19647E	PARTICIPANT	\N	PRESENT	0
695426	695213	14021P	PARTICIPANT	\N	PRESENT	0
695427	695213	05012A	PARTICIPANT	\N	PRESENT	0
695428	695213	11104D	PARTICIPANT	\N	PRESENT	0
695429	695213	17779H	PARTICIPANT	\N	PRESENT	0
695430	695213	20022R	PARTICIPANT	\N	PRESENT	0
695431	695213	01057W	PARTICIPANT	\N	PRESENT	0
695432	695213	11067R	PARTICIPANT	\N	PRESENT	0
695433	695213	14259Y	PARTICIPANT	\N	PRESENT	0
695434	695213	20030R	PARTICIPANT	\N	PRESENT	0
695435	695213	19766L	PARTICIPANT	\N	PRESENT	0
695436	695213	11080N	PARTICIPANT	\N	PRESENT	0
695437	695213	20094J	PARTICIPANT	\N	PRESENT	0
695438	695213	11056N	PARTICIPANT	\N	PRESENT	0
695439	695213	19673G	PARTICIPANT	\N	PRESENT	0
695440	695213	14229S	PARTICIPANT	\N	PRESENT	0
695441	695213	11045K	PARTICIPANT	\N	PRESENT	0
695442	695213	14031R	PARTICIPANT	\N	PRESENT	0
695443	695213	19667J	PARTICIPANT	\N	PRESENT	0
695444	695213	14253S	PARTICIPANT	\N	PRESENT	0
695445	695213	17737W	PARTICIPANT	\N	PRESENT	0
695446	695213	11041F	PARTICIPANT	\N	PRESENT	0
695447	695213	10006L	PARTICIPANT	\N	PRESENT	0
695448	695213	14069U	PARTICIPANT	\N	PRESENT	0
695449	695213	14187A	PARTICIPANT	\N	PRESENT	0
695450	695213	20134Y	PARTICIPANT	\N	PRESENT	0
695451	695213	19421M	PARTICIPANT	\N	PRESENT	0
695452	695213	17637T	PARTICIPANT	\N	PRESENT	0
695453	695213	19543W	PARTICIPANT	\N	PRESENT	0
695454	695213	14217N	PARTICIPANT	\N	PRESENT	0
695455	695213	01043Q	PARTICIPANT	\N	PRESENT	0
695456	695213	07033P	PARTICIPANT	\N	PRESENT	0
695457	695213	14089Y	PARTICIPANT	\N	PRESENT	0
695458	695213	19711U	PARTICIPANT	\N	PRESENT	0
695459	695213	19503N	PARTICIPANT	\N	PRESENT	0
695460	695213	14147R	PARTICIPANT	\N	PRESENT	0
695461	695213	08047A	PARTICIPANT	\N	PRESENT	0
695462	695213	14189C	PARTICIPANT	\N	PRESENT	0
695463	695213	97011G	PARTICIPANT	\N	PRESENT	0
695464	695213	20138D	PARTICIPANT	\N	PRESENT	0
695465	695213	20140W	PARTICIPANT	\N	PRESENT	0
695466	695213	01024M	PARTICIPANT	\N	PRESENT	0
695467	695213	20026V	PARTICIPANT	\N	PRESENT	0
695468	695213	14042U	PARTICIPANT	\N	PRESENT	0
695469	695213	11010L	PARTICIPANT	\N	PRESENT	0
695470	695213	20040T	PARTICIPANT	\N	PRESENT	0
695471	695213	17965H	PARTICIPANT	\N	PRESENT	0
695472	695213	20096L	PARTICIPANT	\N	PRESENT	0
695473	695213	20980G	PARTICIPANT	\N	PRESENT	0
695474	695213	20048C	PARTICIPANT	\N	PRESENT	0
695475	695213	19447X	PARTICIPANT	\N	PRESENT	0
695476	695213	20066E	PARTICIPANT	\N	PRESENT	0
695477	695213	14026U	PARTICIPANT	\N	PRESENT	0
695478	695213	19741B	PARTICIPANT	\N	PRESENT	0
695479	695213	20052X	PARTICIPANT	\N	PRESENT	0
695480	695213	16685X	PARTICIPANT	\N	PRESENT	0
695481	695213	14205J	PARTICIPANT	\N	PRESENT	0
695482	695213	14219Q	PARTICIPANT	\N	PRESENT	0
695483	695213	11097X	PARTICIPANT	\N	PRESENT	0
695484	695213	11085T	PARTICIPANT	\N	PRESENT	0
695485	695213	20034V	PARTICIPANT	\N	PRESENT	0
695486	695213	19467C	PARTICIPANT	\N	PRESENT	0
695487	695213	19739H	PARTICIPANT	\N	PRESENT	0
695488	695213	20056C	PARTICIPANT	\N	PRESENT	0
695489	695213	20098N	PARTICIPANT	\N	PRESENT	0
695490	695213	11053K	PARTICIPANT	\N	PRESENT	0
695491	695213	20298U	PARTICIPANT	\N	PRESENT	0
695492	695213	19399H	PARTICIPANT	\N	PRESENT	0
695493	695213	14213J	PARTICIPANT	\N	PRESENT	0
695494	695213	14357A	PARTICIPANT	\N	PRESENT	0
695495	695213	20020P	PARTICIPANT	\N	PRESENT	0
690731	690730	14193X	PARTICIPANT	\N	PRESENT	0
690732	690730	14059S	PARTICIPANT	\N	PRESENT	0
690733	690730	19565D	PARTICIPANT	\N	PRESENT	0
690734	690730	11083R	PARTICIPANT	\N	PRESENT	0
690736	690735	20042V	PARTICIPANT	\N	PRESENT	0
690737	690735	14059S	PARTICIPANT	\N	PRESENT	0
690738	690735	14193X	PARTICIPANT	\N	PRESENT	0
690756	690755	19329S	PARTICIPANT	\N	PRESENT	0
690757	690755	11026G	PARTICIPANT	\N	PRESENT	0
690758	690755	10015M	PARTICIPANT	\N	PRESENT	0
690952	690951	14255U	PARTICIPANT	\N	PRESENT	0
690953	690951	08009T	PARTICIPANT	\N	PRESENT	0
690954	690951	19719D	PARTICIPANT	\N	PRESENT	0
690955	690951	14221J	PARTICIPANT	\N	PRESENT	0
690957	690956	04047H	PARTICIPANT	\N	PRESENT	0
690959	690958	04047H	PARTICIPANT	\N	PRESENT	0
694797	694796	20054A	PARTICIPANT	\N	PRESENT	0
694799	694798	20054A	PARTICIPANT	\N	PRESENT	0
694801	694800	20054A	PARTICIPANT	\N	PRESENT	0
694802	694800	19467C	PARTICIPANT	\N	PRESENT	0
694804	694803	20054A	PARTICIPANT	\N	PRESENT	0
694805	694803	19467C	PARTICIPANT	\N	PRESENT	0
694806	694803	14207L	PARTICIPANT	\N	PRESENT	0
694808	694807	20054A	PARTICIPANT	\N	PRESENT	0
694809	694807	14207L	PARTICIPANT	\N	PRESENT	0
694811	694810	20054A	PARTICIPANT	\N	PRESENT	0
701601	701599	19709B	PARTICIPANT	\N	EXCUSE	0
701603	701600	19709B	PARTICIPANT	\N	EXCUSE	0
701610	701609	19693L	PARTICIPANT	\N	PRESENT	0
701611	701609	20142Y	PARTICIPANT	\N	PRESENT	0
701612	701609	20112S	PARTICIPANT	\N	PRESENT	0
701613	701609	19643A	PARTICIPANT	\N	PRESENT	0
701614	701609	19735D	PARTICIPANT	\N	PRESENT	0
701616	701615	19643A	PARTICIPANT	\N	PRESENT	0
701617	701615	20112S	PARTICIPANT	\N	PRESENT	0
701618	701615	19735D	PARTICIPANT	\N	PRESENT	0
701619	701615	19693L	PARTICIPANT	\N	PRESENT	0
701964	701963	20090E	PARTICIPANT	\N	PRESENT	1
701965	701963	19691J	PARTICIPANT	\N	PRESENT	0
703803	700269	19691J	PARTICIPANT	\N	PRESENT	0
703804	700269	14109K	PARTICIPANT	\N	PRESENT	0
703805	700269	20106U	PARTICIPANT	\N	PRESENT	0
703807	700269	19758L	PARTICIPANT	\N	PRESENT	0
703808	700269	19335Q	PRESIDENT	0	PRESENT	0
703810	700269	19621T	PARTICIPANT	\N	PRESENT	0
703812	700269	20152B	PARTICIPANT	\N	PRESENT	0
703813	700269	20038A	PARTICIPANT	\N	PRESENT	0
703815	700269	20980G	PARTICIPANT	\N	PRESENT	0
703837	701651	14071N	PARTICIPANT	\N	PRESENT	0
703838	701651	14207L	PARTICIPANT	\N	PRESENT	0
703839	701651	19565D	PARTICIPANT	\N	PRESENT	0
703840	701651	11031D	PARTICIPANT	\N	PRESENT	0
703841	701651	14109K	PARTICIPANT	\N	PRESENT	0
703842	701651	01043Q	PARTICIPANT	\N	PRESENT	0
703843	701651	19507S	PARTICIPANT	\N	PRESENT	0
703844	701651	17737W	PARTICIPANT	\N	PRESENT	0
703845	701651	04057K	PARTICIPANT	\N	PRESENT	0
703846	701651	11045K	PARTICIPANT	\N	PRESENT	0
703847	701651	20266L	PARTICIPANT	\N	PRESENT	0
703855	701651	19715Y	PARTICIPANT	\N	PRESENT	0
703862	701651	19441R	PARTICIPANT	\N	PRESENT	0
703869	701651	20100N	PARTICIPANT	\N	PRESENT	0
703864	701651	19798U	PARTICIPANT	\N	PRESENT	0
703865	701651	19621T	PARTICIPANT	\N	PRESENT	0
703867	701651	14030Q	PARTICIPANT	\N	PRESENT	0
703868	701651	19387D	PARTICIPANT	\N	PRESENT	0
703871	701651	14121F	PARTICIPANT	\N	PRESENT	0
703872	701651	14191V	PARTICIPANT	\N	PRESENT	0
703875	701651	20098N	PARTICIPANT	\N	PRESENT	0
703877	701651	19467C	PARTICIPANT	\N	PRESENT	0
703878	701651	20054A	PARTICIPANT	\N	PRESENT	0
703879	701651	20106U	PARTICIPANT	\N	PRESENT	0
703880	701651	14026U	PARTICIPANT	\N	PRESENT	0
703883	701651	14069U	PARTICIPANT	\N	PRESENT	0
703884	701651	14281W	PARTICIPANT	\N	PRESENT	0
703888	701651	19687N	PARTICIPANT	\N	PRESENT	0
703889	701652	99004R	PARTICIPANT	\N	PRESENT	0
703890	701652	19691J	PARTICIPANT	\N	PRESENT	0
703891	701652	14071N	PARTICIPANT	\N	PRESENT	0
703892	701652	14207L	PARTICIPANT	\N	PRESENT	0
703893	701652	19565D	PARTICIPANT	\N	PRESENT	0
703894	701652	11031D	PARTICIPANT	\N	PRESENT	0
703916	701652	17737W	PARTICIPANT	\N	PRESENT	0
703896	701652	19507S	PARTICIPANT	\N	PRESENT	0
703917	701652	19673G	PARTICIPANT	\N	PRESENT	0
703898	701652	04057K	PARTICIPANT	\N	PRESENT	0
703918	701652	11053K	PARTICIPANT	\N	PRESENT	0
703900	701652	19798U	PARTICIPANT	\N	PRESENT	0
703901	701652	19621T	PARTICIPANT	\N	PRESENT	0
703922	701652	19719D	PARTICIPANT	\N	PRESENT	0
703923	698867	14042U	PARTICIPANT	\N	PRESENT	0
703904	701652	14121F	PARTICIPANT	\N	PRESENT	0
703905	701652	14191V	PARTICIPANT	\N	PRESENT	0
703906	701652	20098N	PARTICIPANT	\N	PRESENT	0
703907	701652	19467C	PARTICIPANT	\N	PRESENT	0
703908	701652	20054A	PARTICIPANT	\N	PRESENT	0
703909	701652	20106U	PARTICIPANT	\N	PRESENT	0
703910	701652	14026U	PARTICIPANT	\N	PRESENT	0
703911	701652	14069U	PARTICIPANT	\N	PRESENT	0
703912	701652	14281W	PARTICIPANT	\N	PRESENT	0
703913	701652	19687N	PARTICIPANT	\N	PRESENT	0
703914	701652	20100N	PARTICIPANT	\N	PRESENT	0
703924	698867	11097X	PARTICIPANT	\N	PRESENT	0
703925	698867	20090E	PARTICIPANT	\N	PRESENT	0
703926	698867	19479G	PARTICIPANT	\N	PRESENT	0
703927	698870	14217N	PARTICIPANT	\N	PRESENT	0
703928	698870	14042U	PARTICIPANT	\N	PRESENT	0
703929	701652	14215L	PARTICIPANT	\N	PRESENT	0
703930	698870	11097X	PARTICIPANT	\N	PRESENT	0
703931	701653	99004R	PARTICIPANT	\N	PRESENT	0
703932	701653	19691J	PARTICIPANT	\N	PRESENT	0
703958	701653	14069U	PARTICIPANT	\N	PRESENT	0
703959	701653	20110Q	PARTICIPANT	\N	PRESENT	0
703935	701653	19565D	PARTICIPANT	\N	PRESENT	0
703936	701653	11031D	PARTICIPANT	\N	PRESENT	0
703937	701653	19507S	PARTICIPANT	\N	PRESENT	0
703960	701653	11026G	PARTICIPANT	\N	PRESENT	0
703961	701653	14251Q	PARTICIPANT	\N	PRESENT	0
703964	703962	04092N	PARTICIPANT	\N	PRESENT	0
703965	703963	04092N	PARTICIPANT	\N	PRESENT	0
704164	703816	19691J	PARTICIPANT	\N	PRESENT	0
703943	701653	14191V	PARTICIPANT	\N	PRESENT	0
703944	701653	19467C	PARTICIPANT	\N	PRESENT	0
703945	701653	20054A	PARTICIPANT	\N	PRESENT	0
703946	701653	20106U	PARTICIPANT	\N	PRESENT	0
703947	701653	14026U	PARTICIPANT	\N	PRESENT	0
703948	701653	14281W	PARTICIPANT	\N	PRESENT	0
704165	703816	20090E	PARTICIPANT	\N	PRESENT	1
703950	701653	17737W	PARTICIPANT	\N	PRESENT	0
703951	701653	19673G	PARTICIPANT	\N	PRESENT	0
703952	701653	19719D	PARTICIPANT	\N	PRESENT	0
703953	701653	14215L	PARTICIPANT	\N	PRESENT	0
703954	698872	14042U	PARTICIPANT	\N	PRESENT	0
703955	698872	14217N	PARTICIPANT	\N	PRESENT	0
703956	698872	11097X	PARTICIPANT	\N	PRESENT	0
703957	698872	19479G	PARTICIPANT	\N	PRESENT	0
704248	704247	14121F	PARTICIPANT	\N	PRESENT	0
704250	704249	99004R	PARTICIPANT	\N	PRESENT	0
704252	704251	99004R	PARTICIPANT	\N	PRESENT	0
704254	704253	19479G	PARTICIPANT	\N	PRESENT	0
704287	704286	19447X	PARTICIPANT	\N	PRESENT	0
704288	704286	14089Y	PARTICIPANT	\N	PRESENT	0
704290	704289	19447X	PARTICIPANT	\N	PRESENT	0
704291	704289	14089Y	PARTICIPANT	\N	PRESENT	0
704293	704292	19447X	PARTICIPANT	\N	PRESENT	0
704294	704292	14089Y	PARTICIPANT	\N	PRESENT	0
706032	704084	19599P	PARTICIPANT	\N	PRESENT	0
706033	704084	19715Y	PARTICIPANT	\N	PRESENT	0
706031	704084	14151M	PARTICIPANT	\N	PRESENT	0
704600	704599	14053L	PARTICIPANT	\N	PRESENT	0
704601	704599	11066Q	PARTICIPANT	\N	PRESENT	0
706034	704084	14121F	PARTICIPANT	\N	PRESENT	0
706035	704084	20080C	PARTICIPANT	\N	PRESENT	0
706036	704084	18193Q	PARTICIPANT	\N	PRESENT	0
706037	704084	08012N	PARTICIPANT	\N	PRESENT	0
706038	704084	19489J	PARTICIPANT	\N	PRESENT	0
706039	704084	20028X	PARTICIPANT	\N	PRESENT	0
706040	704084	11067R	PARTICIPANT	\N	PRESENT	0
706041	704084	20030R	PARTICIPANT	\N	PRESENT	0
706042	704084	19820Y	PARTICIPANT	\N	PRESENT	0
708990	708148	14215L	PARTICIPANT	\N	PRESENT	0
708991	708148	11054L	PARTICIPANT	\N	PRESENT	0
708992	708148	20098N	PARTICIPANT	\N	PRESENT	0
708993	708148	14331P	PARTICIPANT	\N	PRESENT	0
708994	708148	14053L	PARTICIPANT	\N	PRESENT	0
708995	708148	14357A	PARTICIPANT	\N	PRESENT	0
708996	708148	97011G	PARTICIPANT	\N	PRESENT	0
708997	708148	04059M	PARTICIPANT	\N	PRESENT	0
708998	708148	05008E	PARTICIPANT	\N	PRESENT	0
708999	708148	20062A	PARTICIPANT	\N	PRESENT	0
709000	708148	14189C	PARTICIPANT	\N	PRESENT	0
709001	708148	19581D	PARTICIPANT	\N	PRESENT	0
709002	708148	19671E	PARTICIPANT	\N	PRESENT	0
709003	708148	19729F	PARTICIPANT	\N	PRESENT	0
709004	708148	20024T	PARTICIPANT	\N	PRESENT	0
709005	708148	14213J	PARTICIPANT	\N	PRESENT	0
709006	708148	20044X	PARTICIPANT	\N	PRESENT	0
709007	708148	19683J	PARTICIPANT	\N	PRESENT	0
709008	708148	01034P	PARTICIPANT	\N	PRESENT	0
709009	708148	19798U	PARTICIPANT	\N	PRESENT	0
709010	708148	19699S	PARTICIPANT	\N	PRESENT	0
709011	708148	08061X	PARTICIPANT	\N	PRESENT	0
709012	708148	20020P	PARTICIPANT	\N	PRESENT	0
709013	708148	14169X	PARTICIPANT	\N	PRESENT	0
709014	708148	05012A	PARTICIPANT	\N	PRESENT	0
709015	708148	19573D	PARTICIPANT	\N	PRESENT	0
709016	708148	19551W	PARTICIPANT	\N	PRESENT	0
709017	708148	19577H	PARTICIPANT	\N	PRESENT	0
709018	708148	20140W	PARTICIPANT	\N	PRESENT	0
709019	708148	01057W	PARTICIPANT	\N	PRESENT	0
709020	708148	20120S	PARTICIPANT	\N	PRESENT	0
709021	708148	14059S	PARTICIPANT	\N	PRESENT	0
709022	708148	08009T	PARTICIPANT	\N	PRESENT	0
709023	708148	19569H	PARTICIPANT	\N	PRESENT	0
709024	708148	19251M	PARTICIPANT	\N	PRESENT	0
709025	708148	19545Y	PARTICIPANT	\N	PRESENT	0
709026	708148	19329S	PARTICIPANT	\N	PRESENT	0
709027	708148	11070L	PARTICIPANT	\N	PRESENT	0
709028	708148	19745F	PARTICIPANT	\N	PRESENT	0
709029	708148	20248J	PARTICIPANT	\N	PRESENT	0
709030	708148	20058E	PARTICIPANT	\N	PRESENT	0
709031	708148	19866P	PARTICIPANT	\N	PRESENT	0
709032	708148	19782L	PARTICIPANT	\N	PRESENT	0
709033	708148	14083S	PARTICIPANT	\N	PRESENT	0
709034	708148	19659J	PARTICIPANT	\N	PRESENT	0
709035	708148	20266L	PARTICIPANT	\N	PRESENT	0
709036	708148	20142Y	PARTICIPANT	\N	PRESENT	0
709037	708148	20286Q	PARTICIPANT	\N	PRESENT	0
709038	708148	19687N	PARTICIPANT	\N	PRESENT	0
709039	708148	14147R	PARTICIPANT	\N	PRESENT	0
709040	708148	11090Q	PARTICIPANT	\N	PRESENT	0
709041	708148	20126Y	PARTICIPANT	\N	PRESENT	0
709042	708148	20128B	PARTICIPANT	\N	PRESENT	0
709043	708148	20070A	PARTICIPANT	\N	PRESENT	0
709044	708148	11033F	PARTICIPANT	\N	PRESENT	0
709045	708148	19369B	PARTICIPANT	\N	PRESENT	0
709046	708148	19768N	PARTICIPANT	\N	PRESENT	0
709047	708148	08073C	PARTICIPANT	\N	PRESENT	0
709048	708148	19591F	PARTICIPANT	\N	PRESENT	0
709049	708148	11053K	PARTICIPANT	\N	PRESENT	0
709050	708148	19820Y	PARTICIPANT	\N	PRESENT	0
709051	708148	20088L	PARTICIPANT	\N	PRESENT	0
709052	708148	14033T	PARTICIPANT	\N	PRESENT	0
709053	708148	19713W	PARTICIPANT	\N	PRESENT	0
709058	706157	14053L	PRESIDENT	0	PRESENT	0
709055	708148	14231L	PARTICIPANT	\N	PRESENT	0
709056	708148	20082E	PARTICIPANT	\N	PRESENT	0
709059	706157	19866P	PARTICIPANT	\N	PRESENT	0
709060	708148	19695N	PARTICIPANT	\N	PRESENT	0
709061	708148	14037X	PARTICIPANT	\N	PRESENT	0
709062	708148	14195A	PARTICIPANT	\N	PRESENT	0
709063	708148	11048N	PARTICIPANT	\N	PRESENT	0
709064	708148	17229F	PARTICIPANT	\N	PRESENT	0
709065	708148	20138D	PARTICIPANT	\N	PRESENT	0
709066	708148	19479G	PARTICIPANT	\N	PRESENT	0
709067	708148	18083K	PARTICIPANT	\N	PRESENT	0
709068	708148	20180F	PARTICIPANT	\N	PRESENT	0
709069	708148	14031R	PARTICIPANT	\N	PRESENT	0
709070	708148	14225N	PARTICIPANT	\N	PRESENT	0
709071	708148	19711U	PARTICIPANT	\N	PRESENT	0
709072	708148	14219Q	PARTICIPANT	\N	PRESENT	0
709073	708148	19717B	PARTICIPANT	\N	PRESENT	0
709074	708148	20056C	PARTICIPANT	\N	PRESENT	0
709075	708148	01060R	PARTICIPANT	\N	PRESENT	0
709076	706157	19533U	PARTICIPANT	\N	PRESENT	0
709077	706157	10015M	PARTICIPANT	\N	PRESENT	0
709078	706157	19687N	PARTICIPANT	\N	PRESENT	0
709079	706157	20042V	PARTICIPANT	\N	PRESENT	0
709080	706157	12016W	PARTICIPANT	\N	PRESENT	0
709081	706157	20080C	PARTICIPANT	\N	PRESENT	0
709082	706157	14033T	PARTICIPANT	\N	PRESENT	0
709083	706157	20044X	PARTICIPANT	\N	PRESENT	0
709084	706157	19585H	PARTICIPANT	\N	PRESENT	0
709085	706157	11070L	PARTICIPANT	\N	PRESENT	0
709086	706157	19631V	PARTICIPANT	\N	PRESENT	0
709087	706157	14231L	PARTICIPANT	\N	PRESENT	0
709088	706157	05012A	PARTICIPANT	\N	PRESENT	0
709089	706157	08073C	PARTICIPANT	\N	PRESENT	0
709090	706157	14249W	PARTICIPANT	\N	PRESENT	0
709091	706157	19619A	PARTICIPANT	\N	PRESENT	0
709092	706157	19667J	PARTICIPANT	\N	EXCUSE	0
709093	708148	11031D	PARTICIPANT	\N	PRESENT	0
709094	708148	19725B	PARTICIPANT	\N	PRESENT	0
709095	708148	14221J	PARTICIPANT	\N	PRESENT	0
709096	708148	14217N	PARTICIPANT	\N	PRESENT	0
709097	708148	01048V	PARTICIPANT	\N	PRESENT	0
709098	708148	19553Y	PARTICIPANT	\N	PRESENT	0
709099	708148	14069U	PARTICIPANT	\N	PRESENT	0
709100	708148	19295A	PARTICIPANT	\N	PRESENT	0
709101	708148	04047H	PARTICIPANT	\N	PRESENT	0
709102	708148	14187A	PARTICIPANT	\N	PRESENT	0
709103	706157	19741B	PARTICIPANT	\N	EXCUSE	0
709104	708148	11083R	PARTICIPANT	\N	PRESENT	0
709105	708148	19593H	PARTICIPANT	\N	PRESENT	0
709106	708148	12041X	PARTICIPANT	\N	PRESENT	0
709107	708148	08010L	PARTICIPANT	\N	PRESENT	0
709108	708148	20096L	PARTICIPANT	\N	PRESENT	0
709109	708148	19335Q	PARTICIPANT	\N	PRESENT	0
709110	708148	14038Y	PARTICIPANT	\N	PRESENT	0
709111	708148	17367Q	PARTICIPANT	\N	PRESENT	0
709112	708148	11012A	PARTICIPANT	\N	PRESENT	0
709113	706157	08010L	PARTICIPANT	\N	PRESENT	0
709114	708148	14173T	PARTICIPANT	\N	PRESENT	0
709123	708148	20054A	PARTICIPANT	\N	PRESENT	0
709124	708148	20040T	PARTICIPANT	\N	PRESENT	0
709125	708148	11110B	PARTICIPANT	\N	PRESENT	0
709126	708148	19629C	PARTICIPANT	\N	PRESENT	0
709127	708148	20980G	PARTICIPANT	\N	PRESENT	0
709128	708148	11026G	PARTICIPANT	\N	PRESENT	0
709129	708148	01028R	PARTICIPANT	\N	PRESENT	0
709130	708148	19399H	PARTICIPANT	\N	PRESENT	0
709131	708148	14249W	PARTICIPANT	\N	PRESENT	0
709132	708148	95041E	PARTICIPANT	\N	PRESENT	0
709133	708148	08012N	PARTICIPANT	\N	PRESENT	0
709134	708148	19735D	PARTICIPANT	\N	PRESENT	0
709135	708148	19643A	PARTICIPANT	\N	PRESENT	0
709136	708148	04035D	PARTICIPANT	\N	PRESENT	0
709137	708148	20122U	PARTICIPANT	\N	PRESENT	0
709138	708148	17737W	PARTICIPANT	\N	PRESENT	0
709141	709139	14123H	PARTICIPANT	\N	PRESENT	0
709142	709139	19593H	PARTICIPANT	\N	PRESENT	0
709143	709140	14123H	PARTICIPANT	\N	PRESENT	0
709144	709140	19593H	PARTICIPANT	\N	PRESENT	0
709145	708148	20076G	PARTICIPANT	\N	PRESENT	0
709146	708148	08069G	PARTICIPANT	\N	PRESENT	0
709147	708148	20110Q	PARTICIPANT	\N	PRESENT	0
709148	708148	14133K	PARTICIPANT	\N	PRESENT	0
709149	708148	19826F	PARTICIPANT	\N	PRESENT	0
709150	708148	14205J	PARTICIPANT	\N	PRESENT	0
709151	708148	20298U	PARTICIPANT	\N	PRESENT	0
709152	708148	17637T	PARTICIPANT	\N	PRESENT	0
709153	708148	19723Y	PARTICIPANT	\N	PRESENT	0
709154	708148	19563B	PARTICIPANT	\N	PRESENT	0
709155	706234	19673G	PARTICIPANT	\N	EXCUSE	0
683501	683500	04047H	PARTICIPANT	\N	PRESENT	0
683502	683500	14231L	PARTICIPANT	\N	PRESENT	0
683503	683500	14107H	PARTICIPANT	\N	PRESENT	0
683504	683500	01028R	PARTICIPANT	\N	PRESENT	0
683505	683500	20110Q	PARTICIPANT	\N	PRESENT	0
683506	683500	11056N	PARTICIPANT	\N	PRESENT	0
688278	686708	14331P	PRESIDENT	0	PRESENT	0
688279	686708	20100N	PARTICIPANT	\N	PRESENT	0
688280	686708	10015M	PARTICIPANT	\N	PRESENT	0
688281	686708	19441R	PARTICIPANT	\N	PRESENT	0
688282	686708	11083R	PARTICIPANT	\N	PRESENT	0
688283	686708	14097Y	PARTICIPANT	\N	PRESENT	0
688284	686708	11026G	PARTICIPANT	\N	PRESENT	0
688285	686708	14001X	PARTICIPANT	\N	PRESENT	0
688286	686708	19701S	PARTICIPANT	\N	PRESENT	0
688287	686708	14133K	PARTICIPANT	\N	PRESENT	0
688288	686708	04092N	PARTICIPANT	\N	PRESENT	0
688289	686708	20094J	PARTICIPANT	\N	PRESENT	0
688290	686708	20286Q	PARTICIPANT	\N	PRESENT	0
688291	686708	04045F	PARTICIPANT	\N	EXCUSE	0
688292	686708	14073Q	PARTICIPANT	\N	EXCUSE	0
688293	686708	19333N	PARTICIPANT	\N	EXCUSE	0
688294	686708	19563B	PARTICIPANT	\N	EXCUSE	0
688469	688468	14033T	PARTICIPANT	\N	PRESENT	0
688470	688468	20092G	PARTICIPANT	\N	PRESENT	0
688471	688468	14257W	PARTICIPANT	\N	PRESENT	0
688473	688472	14033T	PARTICIPANT	\N	PRESENT	0
688474	688472	20092G	PARTICIPANT	\N	PRESENT	0
688475	688472	14257W	PARTICIPANT	\N	PRESENT	0
688476	688472	19826F	PARTICIPANT	\N	PRESENT	0
688478	688477	14033T	PARTICIPANT	\N	PRESENT	0
688479	688477	20092G	PARTICIPANT	\N	PRESENT	0
688484	688483	14033T	PARTICIPANT	\N	PRESENT	0
688481	688477	19369B	PARTICIPANT	\N	PRESENT	0
688482	688477	19826F	PARTICIPANT	\N	PRESENT	0
688485	688483	20092G	PARTICIPANT	\N	PRESENT	0
688486	688483	14257W	PARTICIPANT	\N	PRESENT	0
688487	688483	19826F	PARTICIPANT	\N	PRESENT	0
688489	688488	14033T	PARTICIPANT	\N	PRESENT	0
688490	688488	20092G	PARTICIPANT	\N	PRESENT	0
688491	688488	19826F	PARTICIPANT	\N	PRESENT	0
688493	688492	14033T	PARTICIPANT	\N	PRESENT	0
688494	688492	20092G	PARTICIPANT	\N	PRESENT	0
688495	688492	14257W	PARTICIPANT	\N	PRESENT	0
688496	688492	19826F	PARTICIPANT	\N	PRESENT	0
688498	688497	14033T	PARTICIPANT	\N	PRESENT	0
688499	688497	14257W	PARTICIPANT	\N	PRESENT	0
688500	688497	20018V	PARTICIPANT	\N	PRESENT	0
688501	688497	19826F	PARTICIPANT	\N	PRESENT	0
688503	688502	14033T	PARTICIPANT	\N	PRESENT	0
688504	688502	20018V	PARTICIPANT	\N	PRESENT	0
688506	688505	14033T	PARTICIPANT	\N	PRESENT	0
688508	688507	14033T	PARTICIPANT	\N	PRESENT	0
688509	688507	19826F	PARTICIPANT	\N	PRESENT	0
691066	690825	19563B	PARTICIPANT	\N	PRESENT	0
691067	690825	19782L	PARTICIPANT	\N	PRESENT	0
691068	690825	14257W	PARTICIPANT	\N	PRESENT	0
691069	690825	19695N	PARTICIPANT	\N	PRESENT	0
691070	690825	19369B	PARTICIPANT	\N	PRESENT	0
691071	690825	19533U	PARTICIPANT	\N	PRESENT	0
691072	690825	17229F	PARTICIPANT	\N	PRESENT	0
691073	690825	14331P	PARTICIPANT	\N	PRESENT	0
691074	690825	20136B	PARTICIPANT	\N	PRESENT	0
691075	690825	20062A	PARTICIPANT	\N	PRESENT	0
691076	690825	20076G	PARTICIPANT	\N	PRESENT	0
691077	690825	19583F	PARTICIPANT	\N	PRESENT	0
691078	690825	20046A	PARTICIPANT	\N	PRESENT	0
691079	690825	19798U	PARTICIPANT	\N	PRESENT	0
691080	690825	20100N	PARTICIPANT	\N	PRESENT	0
691081	690825	08028W	PARTICIPANT	\N	PRESENT	0
691082	690825	20032T	PARTICIPANT	\N	PRESENT	0
691083	690825	19399H	PARTICIPANT	\N	PRESENT	0
691084	690825	19637C	PARTICIPANT	\N	PRESENT	0
691085	690825	20072C	PARTICIPANT	\N	PRESENT	0
691086	690825	20102Q	PARTICIPANT	\N	PRESENT	0
691087	690825	19593H	PARTICIPANT	\N	PRESENT	0
691088	690825	19525U	PARTICIPANT	\N	PRESENT	0
691089	690825	19683J	PARTICIPANT	\N	PRESENT	0
691090	690825	19447X	PARTICIPANT	\N	PRESENT	0
691091	690825	19565D	PARTICIPANT	\N	PRESENT	0
691092	690825	95063L	PARTICIPANT	\N	PRESENT	0
691093	690825	20086J	PARTICIPANT	\N	PRESENT	0
691094	690825	08061X	PARTICIPANT	\N	PRESENT	0
691095	690825	19333N	PARTICIPANT	\N	PRESENT	0
691096	690825	19347U	PARTICIPANT	\N	PRESENT	0
691097	690825	19549D	PARTICIPANT	\N	PRESENT	0
691098	690825	14207L	PARTICIPANT	\N	PRESENT	0
691099	690825	20030R	PARTICIPANT	\N	PRESENT	0
691100	690825	14267Y	PARTICIPANT	\N	PRESENT	0
691101	690825	20034V	PARTICIPANT	\N	PRESENT	0
691102	690825	14357A	PARTICIPANT	\N	PRESENT	0
691103	690825	20298U	PARTICIPANT	\N	PRESENT	0
691104	690825	86034E	PARTICIPANT	\N	PRESENT	0
691105	690825	20026V	PARTICIPANT	\N	PRESENT	0
691106	690825	20078J	PARTICIPANT	\N	PRESENT	0
691107	690825	20022R	PARTICIPANT	\N	PRESENT	0
691108	690825	19729F	PARTICIPANT	\N	PRESENT	0
691109	690825	20018V	PARTICIPANT	\N	PRESENT	0
691110	690825	19251M	PARTICIPANT	\N	PRESENT	0
691111	690825	19954N	PARTICIPANT	\N	PRESENT	0
691112	690825	20064C	PARTICIPANT	\N	PRESENT	0
691113	690825	19503N	PARTICIPANT	\N	PRESENT	0
691114	690825	19681G	PARTICIPANT	\N	PRESENT	0
691115	690825	19651A	PARTICIPANT	\N	PRESENT	0
691116	690825	14111D	PARTICIPANT	\N	PRESENT	0
691117	690825	14221J	PARTICIPANT	\N	PRESENT	0
691118	690825	20052X	PARTICIPANT	\N	PRESENT	0
691119	690825	20180F	PARTICIPANT	\N	PRESENT	0
691120	690825	20096L	PARTICIPANT	\N	PRESENT	0
691121	690825	01057W	PARTICIPANT	\N	PRESENT	0
691122	690825	20118Y	PARTICIPANT	\N	PRESENT	0
691123	690825	19711U	PARTICIPANT	\N	PRESENT	0
691124	690825	11040E	PARTICIPANT	\N	PRESENT	0
691125	690825	17965H	PARTICIPANT	\N	PRESENT	0
691126	690825	01024M	PARTICIPANT	\N	PRESENT	0
691127	690825	01048V	PARTICIPANT	\N	PRESENT	0
691128	690825	14223L	PARTICIPANT	\N	PRESENT	0
691129	690825	20124W	PARTICIPANT	\N	PRESENT	0
691130	690825	14219Q	PARTICIPANT	\N	PRESENT	0
691131	690825	11065P	PARTICIPANT	\N	PRESENT	0
691132	690825	20074E	PARTICIPANT	\N	PRESENT	0
691133	690825	11031D	PARTICIPANT	\N	PRESENT	0
691134	690825	19599P	PARTICIPANT	\N	PRESENT	0
691135	690825	20286Q	PARTICIPANT	\N	PRESENT	0
691136	690825	20040T	PARTICIPANT	\N	PRESENT	0
691137	690825	19745F	PARTICIPANT	\N	PRESENT	0
691138	690825	19739H	PARTICIPANT	\N	PRESENT	0
691139	690825	19659J	PARTICIPANT	\N	PRESENT	0
691140	690825	14251Q	PARTICIPANT	\N	PRESENT	0
691141	690825	19820Y	PARTICIPANT	\N	PRESENT	0
691142	690825	20144B	PARTICIPANT	\N	PRESENT	0
691143	690825	14073Q	PARTICIPANT	\N	PRESENT	0
691144	690825	19715Y	PARTICIPANT	\N	PRESENT	0
691145	690825	08010L	PARTICIPANT	\N	PRESENT	0
691146	690825	14069U	PARTICIPANT	\N	PRESENT	0
691147	690825	20088L	PARTICIPANT	\N	PRESENT	0
691149	690825	14259Y	PARTICIPANT	\N	PRESENT	0
691150	690825	14038Y	PARTICIPANT	\N	PRESENT	0
691151	690825	20134Y	PARTICIPANT	\N	PRESENT	0
691152	690825	05012A	PARTICIPANT	\N	PRESENT	0
691154	690825	19747H	PARTICIPANT	\N	PRESENT	0
691155	690825	19383Y	PARTICIPANT	\N	PRESENT	0
691156	690825	19573D	PARTICIPANT	\N	PRESENT	0
691157	690825	08015R	PARTICIPANT	\N	PRESENT	0
691158	690825	20142Y	PARTICIPANT	\N	PRESENT	0
691159	690825	14021P	PARTICIPANT	\N	PRESENT	0
691160	690825	07004J	PARTICIPANT	\N	PRESENT	0
691161	690825	20106U	PARTICIPANT	\N	PRESENT	0
691162	690825	04045F	PARTICIPANT	\N	PRESENT	0
691163	690825	20264J	PARTICIPANT	\N	PRESENT	0
691164	690825	19367Y	PARTICIPANT	\N	PRESENT	0
691165	690825	01058X	PARTICIPANT	\N	PRESENT	0
691166	690825	19467C	PARTICIPANT	\N	PRESENT	0
691167	690825	20056C	PARTICIPANT	\N	PRESENT	0
691168	690825	20914V	PARTICIPANT	\N	PRESENT	0
691169	690825	19479G	PARTICIPANT	\N	PRESENT	0
691170	690825	20104S	PARTICIPANT	\N	PRESENT	0
691171	690825	19741B	PARTICIPANT	\N	PRESENT	0
691172	690825	20098N	PARTICIPANT	\N	PRESENT	0
691173	690825	14215L	PARTICIPANT	\N	PRESENT	0
691174	690825	20036X	PARTICIPANT	\N	PRESENT	0
695496	695213	19367Y	PARTICIPANT	\N	PRESENT	0
695923	695150	95063L	PARTICIPANT	\N	PRESENT	0
695985	695150	11074Q	PARTICIPANT	\N	PRESENT	0
695925	695150	20134Y	PARTICIPANT	\N	PRESENT	0
695983	695150	18083K	PARTICIPANT	\N	PRESENT	0
695980	695150	19479G	PARTICIPANT	\N	PRESENT	0
695928	695150	19599P	PARTICIPANT	\N	PRESENT	0
695929	695150	19782L	PARTICIPANT	\N	PRESENT	0
695981	695150	19762G	PARTICIPANT	\N	PRESENT	0
695982	695150	19399H	PARTICIPANT	\N	PRESENT	0
695932	695150	14107H	PARTICIPANT	\N	PRESENT	0
695933	695150	20092G	PARTICIPANT	\N	PRESENT	0
695986	695150	19629C	PARTICIPANT	\N	PRESENT	0
695984	695150	20080C	PARTICIPANT	\N	PRESENT	0
695987	695150	99004R	PARTICIPANT	\N	PRESENT	0
695988	695150	19575F	PARTICIPANT	\N	PRESENT	0
695938	695150	11012A	PARTICIPANT	\N	PRESENT	0
695939	695150	19711U	PARTICIPANT	\N	PRESENT	0
695940	695150	14083S	PARTICIPANT	\N	PRESENT	0
695941	695150	20252E	PARTICIPANT	\N	PRESENT	0
695989	695150	20050V	PARTICIPANT	\N	PRESENT	0
695943	695150	20062A	PARTICIPANT	\N	PRESENT	0
695990	695150	20026V	PARTICIPANT	\N	PRESENT	0
695991	695150	20090E	PARTICIPANT	\N	PRESENT	0
695992	695150	08009T	PARTICIPANT	\N	PRESENT	0
695947	695150	04043D	PARTICIPANT	\N	PRESENT	0
695993	695150	08011M	PARTICIPANT	\N	PRESENT	0
695994	695150	20040T	PARTICIPANT	\N	PRESENT	0
695995	695150	14237S	PARTICIPANT	\N	PRESENT	0
695996	695150	20108W	PARTICIPANT	\N	PRESENT	0
695997	695150	19673G	PARTICIPANT	\N	PRESENT	0
695998	695150	10015M	PARTICIPANT	\N	PRESENT	0
695999	695150	20980G	PARTICIPANT	\N	PRESENT	0
695955	695150	19747H	PARTICIPANT	\N	PRESENT	0
696000	695150	07029T	PARTICIPANT	\N	PRESENT	0
696001	695150	07004J	PARTICIPANT	\N	PRESENT	0
695958	695150	19319Q	PARTICIPANT	\N	PRESENT	0
696002	695150	11056N	PARTICIPANT	\N	PRESENT	0
696003	695150	01025N	PARTICIPANT	\N	PRESENT	0
696004	695150	01024M	PARTICIPANT	\N	PRESENT	0
696005	695150	19739H	PARTICIPANT	\N	PRESENT	0
695963	695150	14275Y	PARTICIPANT	\N	PRESENT	0
695964	695150	20128B	PARTICIPANT	\N	PRESENT	0
696006	695150	14097Y	PARTICIPANT	\N	PRESENT	0
696007	695150	19447X	PARTICIPANT	\N	PRESENT	0
696009	695150	20030R	PARTICIPANT	\N	PRESENT	0
695968	695150	20088L	PARTICIPANT	\N	PRESENT	0
696010	695150	20028X	PARTICIPANT	\N	PRESENT	0
696011	695150	20126Y	PARTICIPANT	\N	PRESENT	0
695971	695150	19741B	PARTICIPANT	\N	PRESENT	0
696012	695150	04045F	PARTICIPANT	\N	PRESENT	0
695973	695150	20032T	PARTICIPANT	\N	PRESENT	0
695974	695150	20914V	PARTICIPANT	\N	PRESENT	0
695975	695150	08073C	PARTICIPANT	\N	PRESENT	0
695976	695150	11048N	PARTICIPANT	\N	PRESENT	0
695977	695150	14225N	PARTICIPANT	\N	PRESENT	0
695978	695150	19647E	PARTICIPANT	\N	PRESENT	0
695979	695150	19687N	PARTICIPANT	\N	PRESENT	0
696013	695150	19467C	PARTICIPANT	\N	PRESENT	0
696014	695150	19675J	PARTICIPANT	\N	PRESENT	0
696015	695150	08056B	PARTICIPANT	\N	PRESENT	0
696016	695150	19383Y	PARTICIPANT	\N	PRESENT	0
696017	695150	20056C	PARTICIPANT	\N	PRESENT	0
696018	695150	19713W	PARTICIPANT	\N	PRESENT	0
696019	695150	97011G	PARTICIPANT	\N	PRESENT	0
696020	695150	14031R	PARTICIPANT	\N	PRESENT	0
696021	695150	14147R	PARTICIPANT	\N	PRESENT	0
696022	695150	20104S	PARTICIPANT	\N	PRESENT	0
696023	695150	14179A	PARTICIPANT	\N	PRESENT	0
696024	695150	19569H	PARTICIPANT	\N	PRESENT	0
696025	695150	14069U	PARTICIPANT	\N	PRESENT	0
696026	695150	14217N	PARTICIPANT	\N	PRESENT	0
696027	695150	14030Q	PARTICIPANT	\N	PRESENT	0
696028	695150	20066E	PARTICIPANT	\N	PRESENT	0
696030	695150	19631V	PARTICIPANT	\N	PRESENT	0
696035	695150	14213J	PARTICIPANT	\N	PRESENT	0
696036	695150	20044X	PARTICIPANT	\N	PRESENT	0
696037	695150	19349W	PARTICIPANT	\N	PRESENT	0
696038	695150	01057W	PARTICIPANT	\N	PRESENT	0
696039	695150	20048C	PARTICIPANT	\N	PRESENT	0
696040	695150	20070A	PARTICIPANT	\N	PRESENT	0
696041	695150	14021P	PARTICIPANT	\N	PRESENT	0
696082	696042	20914V	PARTICIPANT	\N	PRESENT	0
696083	696042	11077T	PARTICIPANT	\N	PRESENT	0
696084	696042	19687N	PARTICIPANT	\N	PRESENT	0
696085	696042	20050V	PARTICIPANT	\N	PRESENT	0
696086	696042	20090E	PARTICIPANT	\N	PRESENT	0
696087	696042	14053L	PARTICIPANT	\N	PRESENT	0
696088	696042	19673G	PARTICIPANT	\N	PRESENT	0
696089	696042	19711U	PARTICIPANT	\N	PRESENT	0
696090	696042	08011M	PARTICIPANT	\N	PRESENT	0
696091	696042	11048N	PARTICIPANT	\N	PRESENT	0
696092	696042	19647E	PARTICIPANT	\N	PRESENT	0
696093	696042	20100N	PARTICIPANT	\N	PRESENT	0
696094	696042	17737W	PARTICIPANT	\N	PRESENT	0
696095	696042	19747H	PARTICIPANT	\N	PRESENT	0
696096	696042	19057M	PARTICIPANT	\N	PRESENT	0
696097	696042	07029T	PARTICIPANT	\N	PRESENT	0
696098	696042	20122U	PARTICIPANT	\N	PRESENT	0
696099	696042	19479G	PARTICIPANT	\N	PRESENT	0
696100	696042	04043D	PARTICIPANT	\N	PRESENT	0
696101	696042	20252E	PARTICIPANT	\N	PRESENT	0
696102	696042	20110Q	PARTICIPANT	\N	PRESENT	0
696103	696042	20140W	PARTICIPANT	\N	PRESENT	0
696104	696042	19954N	PARTICIPANT	\N	PRESENT	0
696105	696042	20026V	PARTICIPANT	\N	PRESENT	0
696106	696042	20044X	PARTICIPANT	\N	PRESENT	0
696107	696042	14231L	PARTICIPANT	\N	PRESENT	0
696108	696042	20056C	PARTICIPANT	\N	PRESENT	0
696109	696042	20096L	PARTICIPANT	\N	PRESENT	0
696110	696042	19631V	PARTICIPANT	\N	PRESENT	0
696111	696042	11056N	PARTICIPANT	\N	PRESENT	0
696112	696042	19349W	PARTICIPANT	\N	PRESENT	0
696113	696042	07004J	PARTICIPANT	\N	PRESENT	0
696114	696042	14187A	PARTICIPANT	\N	PRESENT	0
696115	696042	04047H	PARTICIPANT	\N	PRESENT	0
696116	696042	20088L	PARTICIPANT	\N	PRESENT	0
696117	696042	19347U	PARTICIPANT	\N	PRESENT	0
696118	696042	14083S	PARTICIPANT	\N	PRESENT	0
696080	696042	14026U	PARTICIPANT	\N	PRESENT	0
696119	696042	19629C	PARTICIPANT	\N	PRESENT	0
696120	696042	14107H	PARTICIPANT	\N	PRESENT	0
696121	696042	01043Q	PARTICIPANT	\N	PRESENT	0
696122	696042	14257W	PARTICIPANT	\N	PRESENT	0
696123	696042	14055N	PARTICIPANT	\N	PRESENT	0
696124	696042	14069U	PARTICIPANT	\N	PRESENT	0
696125	696042	20070A	PARTICIPANT	\N	PRESENT	0
696126	695153	14026U	PARTICIPANT	\N	PRESENT	0
696127	695153	20914V	PARTICIPANT	\N	PRESENT	0
696128	695153	11077T	PARTICIPANT	\N	PRESENT	0
696129	695153	19687N	PARTICIPANT	\N	PRESENT	0
696131	695153	20090E	PARTICIPANT	\N	PRESENT	0
696132	695153	19673G	PARTICIPANT	\N	PRESENT	0
696136	695153	19647E	PARTICIPANT	\N	PRESENT	0
696137	695153	20100N	PARTICIPANT	\N	PRESENT	0
696138	695153	17737W	PARTICIPANT	\N	PRESENT	0
696139	695153	19747H	PARTICIPANT	\N	PRESENT	0
696140	695153	19057M	PARTICIPANT	\N	PRESENT	0
696141	695153	07029T	PARTICIPANT	\N	PRESENT	0
696142	695153	20122U	PARTICIPANT	\N	PRESENT	0
696143	695153	19479G	PARTICIPANT	\N	PRESENT	0
696144	695153	04043D	PARTICIPANT	\N	PRESENT	0
696145	695153	20252E	PARTICIPANT	\N	PRESENT	0
696146	695153	20140W	PARTICIPANT	\N	PRESENT	0
696147	695153	19954N	PARTICIPANT	\N	PRESENT	0
696148	695153	20026V	PARTICIPANT	\N	PRESENT	0
696149	695153	20044X	PARTICIPANT	\N	PRESENT	0
696150	695153	14231L	PARTICIPANT	\N	PRESENT	0
696151	695153	20056C	PARTICIPANT	\N	PRESENT	0
696152	695153	20096L	PARTICIPANT	\N	PRESENT	0
696153	695153	19631V	PARTICIPANT	\N	PRESENT	0
696154	695153	11056N	PARTICIPANT	\N	PRESENT	0
696155	695153	19349W	PARTICIPANT	\N	PRESENT	0
696156	695153	07004J	PARTICIPANT	\N	PRESENT	0
696157	695153	14187A	PARTICIPANT	\N	PRESENT	0
696158	695153	04047H	PARTICIPANT	\N	PRESENT	0
696159	695153	20088L	PARTICIPANT	\N	PRESENT	0
694057	692458	20144B	PARTICIPANT	\N	EXCUSE	0
694058	692458	14251Q	PARTICIPANT	\N	EXCUSE	0
694059	692458	20030R	PARTICIPANT	\N	EXCUSE	0
705583	703673	20094J	PARTICIPANT	\N	PRESENT	0
705584	703673	19701S	PARTICIPANT	\N	PRESENT	0
705586	703673	14357A	PARTICIPANT	\N	PRESENT	0
705587	703673	20100N	PARTICIPANT	\N	PRESENT	0
705588	703673	20286Q	PARTICIPANT	\N	PRESENT	0
705589	703673	14026U	PARTICIPANT	\N	PRESENT	0
705590	703673	20128B	PARTICIPANT	\N	PRESENT	0
705592	703673	19531S	PARTICIPANT	\N	PRESENT	0
705594	703673	14073Q	PARTICIPANT	\N	PRESENT	0
705595	703673	11026G	PARTICIPANT	\N	PRESENT	0
705597	703673	08034U	PARTICIPANT	\N	PRESENT	0
705600	703673	19441R	PARTICIPANT	\N	PRESENT	0
705602	703673	14001X	PARTICIPANT	\N	PRESENT	0
705604	703673	14169X	PARTICIPANT	\N	PRESENT	0
705605	703673	19593H	PARTICIPANT	\N	PRESENT	0
705606	703673	14237S	PARTICIPANT	\N	PRESENT	0
705607	703673	14331P	PRESIDENT	0	PRESENT	0
705608	703673	10015M	PARTICIPANT	\N	PRESENT	0
705609	703673	04045F	PARTICIPANT	\N	PRESENT	0
705610	703673	20054A	PARTICIPANT	\N	PRESENT	0
706043	704084	11045K	PARTICIPANT	\N	PRESENT	0
706044	704084	20084G	PARTICIPANT	\N	PRESENT	0
706045	704084	19701S	PARTICIPANT	\N	PRESENT	0
706046	704084	19413M	PARTICIPANT	\N	PRESENT	0
706047	704084	20064C	PARTICIPANT	\N	PRESENT	0
706048	704084	12016W	PARTICIPANT	\N	PRESENT	0
706049	704084	19531S	PARTICIPANT	\N	PRESENT	0
706050	704084	19301E	PARTICIPANT	\N	PRESENT	0
706051	704084	19619A	PARTICIPANT	\N	PRESENT	0
706052	704084	14030Q	PARTICIPANT	\N	PRESENT	0
706053	704084	19745F	PARTICIPANT	\N	PRESENT	0
706054	704084	14073Q	PARTICIPANT	\N	PRESENT	0
706055	704084	01048V	PARTICIPANT	\N	PRESENT	0
706056	704084	20040T	PARTICIPANT	\N	PRESENT	0
706057	704084	01034P	PARTICIPANT	\N	PRESENT	0
706058	704084	19479G	PARTICIPANT	\N	PRESENT	0
706059	704084	14231L	PARTICIPANT	\N	PRESENT	0
706060	704084	20136B	PARTICIPANT	\N	PRESENT	0
706061	704084	20248J	PARTICIPANT	\N	PRESENT	0
706062	704084	19691J	PARTICIPANT	\N	PRESENT	0
706063	704084	20144B	PARTICIPANT	\N	PRESENT	0
706064	704084	04035D	PARTICIPANT	\N	PRESENT	0
706065	704084	20128B	PARTICIPANT	\N	PRESENT	0
706066	704084	14042U	PARTICIPANT	\N	PRESENT	0
706067	704084	10006L	PARTICIPANT	\N	PRESENT	0
706068	704084	20286Q	PARTICIPANT	\N	PRESENT	0
706069	704084	14031R	PARTICIPANT	\N	PRESENT	0
706070	704084	19441R	PARTICIPANT	\N	PRESENT	0
706071	704084	11097X	PARTICIPANT	\N	PRESENT	0
706072	704084	14327T	PARTICIPANT	\N	PRESENT	0
706073	704084	10015M	PARTICIPANT	\N	PRESENT	0
706079	704084	19573D	PARTICIPANT	\N	PRESENT	0
706075	704084	20098N	PARTICIPANT	\N	PRESENT	0
706076	704084	20142Y	PARTICIPANT	\N	PRESENT	0
706077	704084	20034V	PARTICIPANT	\N	PRESENT	0
706078	704084	19671E	PARTICIPANT	\N	PRESENT	0
706080	704084	08034U	PARTICIPANT	\N	PRESENT	0
706084	704084	17965H	PARTICIPANT	\N	PRESENT	0
706082	704084	19747H	PARTICIPANT	\N	PRESENT	0
706083	704084	14249W	PARTICIPANT	\N	PRESENT	0
706085	704084	11033F	PARTICIPANT	\N	PRESENT	0
706086	704084	14097Y	PARTICIPANT	\N	PRESENT	0
706087	704084	19643A	PARTICIPANT	\N	PRESENT	0
706088	704084	11074Q	PARTICIPANT	\N	PRESENT	0
706089	704084	19057M	PARTICIPANT	\N	PRESENT	0
706093	704084	01024M	PARTICIPANT	\N	PRESENT	0
706091	704084	11053K	PARTICIPANT	\N	PRESENT	0
706092	704084	11072N	PARTICIPANT	\N	PRESENT	0
706094	704084	04070G	PARTICIPANT	\N	PRESENT	0
706099	704084	05012A	PARTICIPANT	\N	PRESENT	0
706096	704084	11085T	PARTICIPANT	\N	PRESENT	0
706097	704084	20070A	PARTICIPANT	\N	PRESENT	0
706100	704084	14215L	PARTICIPANT	\N	PRESENT	0
706101	704084	19667J	PARTICIPANT	\N	PRESENT	0
706102	704084	08018U	PARTICIPANT	\N	PRESENT	0
706126	704084	20082E	PARTICIPANT	\N	PRESENT	0
706127	704084	19527W	PARTICIPANT	\N	PRESENT	0
706129	704084	20124W	PARTICIPANT	\N	PRESENT	0
706154	704084	04042C	PARTICIPANT	\N	PRESENT	0
706155	704084	19762G	PARTICIPANT	\N	PRESENT	0
706160	704084	20054A	PARTICIPANT	\N	PRESENT	0
706161	704084	19549D	PARTICIPANT	\N	PRESENT	0
706162	704084	20264J	PARTICIPANT	\N	PRESENT	0
706163	704084	11012A	PARTICIPANT	\N	PRESENT	0
706164	704084	14038Y	PARTICIPANT	\N	PRESENT	0
706226	704084	14357A	PARTICIPANT	\N	PRESENT	0
706232	704084	19637C	PARTICIPANT	\N	PRESENT	0
706233	704084	19533U	PARTICIPANT	\N	PRESENT	0
706237	704084	20032T	PARTICIPANT	\N	PRESENT	0
706239	704084	04043D	PARTICIPANT	\N	PRESENT	0
706246	704084	20148F	PARTICIPANT	\N	PRESENT	0
706287	706249	86034E	PARTICIPANT	\N	PRESENT	0
706292	706249	08015R	PARTICIPANT	\N	PRESENT	0
706293	706249	19758L	PARTICIPANT	\N	PRESENT	0
706294	706249	20084G	PARTICIPANT	\N	PRESENT	0
706295	706249	14021P	PARTICIPANT	\N	PRESENT	0
706296	706249	04059M	PARTICIPANT	\N	PRESENT	0
706297	706249	11012A	PARTICIPANT	\N	PRESENT	0
706298	706249	14281W	PARTICIPANT	\N	PRESENT	0
706299	706249	01058X	PARTICIPANT	\N	PRESENT	0
706300	706249	20080C	PARTICIPANT	\N	PRESENT	0
706301	706249	99004R	PARTICIPANT	\N	PRESENT	0
706302	706249	19347U	PARTICIPANT	\N	PRESENT	0
706303	706249	14217N	PARTICIPANT	\N	PRESENT	0
706304	706249	19413M	PARTICIPANT	\N	PRESENT	0
706305	706249	19657G	PARTICIPANT	\N	PRESENT	0
706306	706249	11097X	PARTICIPANT	\N	PRESENT	0
706307	706249	19760E	PARTICIPANT	\N	PRESENT	0
706308	706249	04092N	PARTICIPANT	\N	PRESENT	0
706309	706249	11031D	PARTICIPANT	\N	PRESENT	0
706310	706249	14133K	PARTICIPANT	\N	PRESENT	0
706311	706249	20060X	PARTICIPANT	\N	PRESENT	0
706312	706249	20022R	PARTICIPANT	\N	PRESENT	0
706313	706249	19333N	PARTICIPANT	\N	PRESENT	0
706314	706249	18193Q	PARTICIPANT	\N	PRESENT	0
706315	706249	14071N	PARTICIPANT	\N	PRESENT	0
706316	706249	20094J	PARTICIPANT	\N	PRESENT	0
706317	706249	14042U	PARTICIPANT	\N	PRESENT	0
706318	706249	04085P	PARTICIPANT	\N	PRESENT	0
706319	706249	20102Q	PARTICIPANT	\N	PRESENT	0
706320	706249	19569H	PARTICIPANT	\N	PRESENT	0
706321	706249	08010L	PARTICIPANT	\N	PRESENT	0
706322	706249	11077T	PARTICIPANT	\N	PRESENT	0
706323	706249	19715Y	PARTICIPANT	\N	PRESENT	0
706324	706249	14223L	PARTICIPANT	\N	PRESENT	0
706325	706249	19621T	PARTICIPANT	\N	PRESENT	0
706326	706249	12041X	PARTICIPANT	\N	PRESENT	0
706327	706249	04033B	PARTICIPANT	\N	PRESENT	0
706328	706249	20066E	PARTICIPANT	\N	PRESENT	0
706329	706249	19619A	PARTICIPANT	\N	PRESENT	0
706330	706249	19479G	PARTICIPANT	\N	PRESENT	0
706331	706249	19611R	PARTICIPANT	\N	PRESENT	0
706332	706249	20064C	PARTICIPANT	\N	PRESENT	0
706333	706249	14207L	PARTICIPANT	\N	PRESENT	0
706334	706249	14257W	PARTICIPANT	\N	PRESENT	0
706335	706249	19631V	PARTICIPANT	\N	PRESENT	0
706336	706249	20130U	PARTICIPANT	\N	PRESENT	0
706337	706249	20914V	PARTICIPANT	\N	PRESENT	0
706338	706249	19301E	PARTICIPANT	\N	PRESENT	0
706339	706249	14195A	PARTICIPANT	\N	PRESENT	0
706340	706249	17779H	PARTICIPANT	\N	PRESENT	0
706341	706249	19549D	PARTICIPANT	\N	PRESENT	0
706342	706249	14037X	PARTICIPANT	\N	PRESENT	0
706343	706249	08045X	PARTICIPANT	\N	PRESENT	0
706344	706249	11041F	PARTICIPANT	\N	PRESENT	0
706345	706249	17965H	PARTICIPANT	\N	PRESENT	0
706346	706249	19525U	PARTICIPANT	\N	PRESENT	0
706347	706249	19697Q	PARTICIPANT	\N	PRESENT	0
706348	706249	20070A	PARTICIPANT	\N	PRESENT	0
706349	706249	14187A	PARTICIPANT	\N	PRESENT	0
706350	706249	19798U	PARTICIPANT	\N	PRESENT	0
706351	706249	11053K	PARTICIPANT	\N	PRESENT	0
706352	706249	20096L	PARTICIPANT	\N	PRESENT	0
706353	706249	19723Y	PARTICIPANT	\N	PRESENT	0
706354	706249	20044X	PARTICIPANT	\N	PRESENT	0
706355	706249	19683J	PARTICIPANT	\N	PRESENT	0
706356	706249	04043D	PARTICIPANT	\N	PRESENT	0
706357	706249	19647E	PARTICIPANT	\N	PRESENT	0
709338	708160	86034E	PARTICIPANT	\N	PRESENT	0
709339	708160	11097X	PARTICIPANT	\N	PRESENT	0
709340	708160	19697Q	PARTICIPANT	\N	PRESENT	0
709341	708160	11072N	PARTICIPANT	\N	PRESENT	0
709342	708160	14037X	PARTICIPANT	\N	PRESENT	0
709343	708160	17779H	PARTICIPANT	\N	PRESENT	0
709344	708160	08045X	PARTICIPANT	\N	PRESENT	0
709345	708160	20028X	PARTICIPANT	\N	PRESENT	0
709346	708160	12028B	PARTICIPANT	\N	PRESENT	0
709347	708160	11033F	PARTICIPANT	\N	PRESENT	0
709348	708160	19631V	PARTICIPANT	\N	PRESENT	0
709349	708160	20018V	PARTICIPANT	\N	PRESENT	0
709350	708160	19683J	PARTICIPANT	\N	PRESENT	0
709351	708160	99004R	PARTICIPANT	\N	PRESENT	0
709352	708160	18083K	PARTICIPANT	\N	PRESENT	0
709353	708160	08028W	PARTICIPANT	\N	PRESENT	0
709354	708160	11040E	PARTICIPANT	\N	PRESENT	0
709355	708160	14223L	PARTICIPANT	\N	PRESENT	0
709356	708160	95041E	PARTICIPANT	\N	PRESENT	0
709357	708160	11110B	PARTICIPANT	\N	PRESENT	0
709358	708160	19447X	PARTICIPANT	\N	PRESENT	0
709359	708160	20092G	PARTICIPANT	\N	PRESENT	0
709360	708160	14173T	PARTICIPANT	\N	PRESENT	0
709361	708160	20100N	PARTICIPANT	\N	PRESENT	0
709362	708160	20914V	PARTICIPANT	\N	PRESENT	0
709363	708160	14195A	PARTICIPANT	\N	PRESENT	0
709364	708160	14038Y	PARTICIPANT	\N	PRESENT	0
709365	708160	04092N	PARTICIPANT	\N	PRESENT	0
709366	708160	14133K	PARTICIPANT	\N	PRESENT	0
709367	708160	20134Y	PARTICIPANT	\N	PRESENT	0
709368	708160	19798U	PARTICIPANT	\N	PRESENT	0
709369	708160	14225N	PARTICIPANT	\N	PRESENT	0
709370	708160	14215L	PARTICIPANT	\N	PRESENT	0
709371	708160	11031D	PARTICIPANT	\N	PRESENT	0
709372	708160	19760E	PARTICIPANT	\N	PRESENT	0
709373	708160	19758L	PARTICIPANT	\N	PRESENT	0
709374	708160	19367Y	PARTICIPANT	\N	PRESENT	0
709375	708160	20102Q	PARTICIPANT	\N	PRESENT	0
709376	708160	20046A	PARTICIPANT	\N	PRESENT	0
709377	708160	19695N	PARTICIPANT	\N	PRESENT	0
709378	708160	20054A	PARTICIPANT	\N	PRESENT	0
709379	708160	19565D	PARTICIPANT	\N	PRESENT	0
709380	708160	19593H	PARTICIPANT	\N	PRESENT	0
709381	708160	14357A	PARTICIPANT	\N	PRESENT	0
709382	708160	11045K	PARTICIPANT	\N	PRESENT	0
709383	708160	19649G	PARTICIPANT	\N	PRESENT	0
709384	708160	11026G	PARTICIPANT	\N	PRESENT	0
709385	708160	20090E	PARTICIPANT	\N	PRESENT	0
709386	708160	20118Y	PARTICIPANT	\N	PRESENT	0
709387	708160	19599P	PARTICIPANT	\N	PRESENT	0
709388	708160	20062A	PARTICIPANT	\N	PRESENT	0
709389	708160	11104D	PARTICIPANT	\N	PRESENT	0
709390	708160	08060W	PARTICIPANT	\N	PRESENT	0
709391	708160	08012N	PARTICIPANT	\N	PRESENT	0
709392	708160	20024T	PARTICIPANT	\N	PRESENT	0
709393	708160	20064C	PARTICIPANT	\N	PRESENT	0
709400	708160	11056N	PARTICIPANT	\N	PRESENT	0
709395	708160	19503N	PARTICIPANT	\N	PRESENT	0
709396	708160	20080C	PARTICIPANT	\N	PRESENT	0
709397	708160	19515S	PARTICIPANT	\N	PRESENT	0
709398	708160	19531S	PARTICIPANT	\N	PRESENT	0
709399	708160	19703U	PARTICIPANT	\N	PRESENT	0
709401	708160	14169X	PARTICIPANT	\N	PRESENT	0
709402	708160	18193Q	PARTICIPANT	\N	PRESENT	0
709403	708160	19725B	PARTICIPANT	\N	PRESENT	0
709404	708160	14229S	PARTICIPANT	\N	PRESENT	0
709405	708160	19621T	PARTICIPANT	\N	PRESENT	0
709406	708160	20264J	PARTICIPANT	\N	PRESENT	0
709407	708160	19551W	PARTICIPANT	\N	PRESENT	0
709408	708160	14217N	PARTICIPANT	\N	PRESENT	0
709409	708160	17965H	PARTICIPANT	\N	PRESENT	0
709410	708160	97011G	PARTICIPANT	\N	PRESENT	0
709411	708160	19669L	PARTICIPANT	\N	PRESENT	0
709412	708160	14281W	PARTICIPANT	\N	PRESENT	0
709413	708160	19581D	PARTICIPANT	\N	PRESENT	0
709414	708160	11066Q	PARTICIPANT	\N	PRESENT	0
709415	708160	19659J	PARTICIPANT	\N	PRESENT	0
709416	708160	19387D	PARTICIPANT	\N	PRESENT	0
709417	708160	19717B	PARTICIPANT	\N	PRESENT	0
709418	708160	14213J	PARTICIPANT	\N	PRESENT	0
709419	708160	19553Y	PARTICIPANT	\N	PRESENT	0
709420	708160	19637C	PARTICIPANT	\N	PRESENT	0
709421	708160	20038A	PARTICIPANT	\N	PRESENT	0
709422	708160	19866P	PARTICIPANT	\N	PRESENT	0
709423	708160	11067R	PARTICIPANT	\N	PRESENT	0
709424	708160	14257W	PARTICIPANT	\N	PRESENT	0
709425	708160	20044X	PARTICIPANT	\N	PRESENT	0
709426	708160	20088L	PARTICIPANT	\N	PRESENT	0
709427	708160	14021P	PARTICIPANT	\N	PRESENT	0
709428	708160	04059M	PARTICIPANT	\N	PRESENT	0
709429	708160	19573D	PARTICIPANT	\N	PRESENT	0
709430	708160	01028R	PARTICIPANT	\N	PRESENT	0
709431	708160	10006L	PARTICIPANT	\N	PRESENT	0
709432	708160	14071N	PARTICIPANT	\N	PRESENT	0
709433	708160	14042U	PARTICIPANT	\N	PRESENT	0
709434	708160	19747H	PARTICIPANT	\N	PRESENT	0
709435	708160	14151M	PARTICIPANT	\N	PRESENT	0
709436	708160	19295A	PARTICIPANT	\N	PRESENT	0
709437	708160	19415P	PARTICIPANT	\N	PRESENT	0
709438	708160	20110Q	PARTICIPANT	\N	PRESENT	0
709439	708160	12016W	PARTICIPANT	\N	PRESENT	0
709440	708160	20130U	PARTICIPANT	\N	PRESENT	0
709441	708160	19525U	PARTICIPANT	\N	PRESENT	0
709442	708160	19629C	PARTICIPANT	\N	PRESENT	0
709443	708160	20152B	PARTICIPANT	\N	PRESENT	0
709444	708160	14107H	PARTICIPANT	\N	PRESENT	0
709445	708160	04057K	PARTICIPANT	\N	PRESENT	0
709446	708160	05008E	PARTICIPANT	\N	PRESENT	0
709447	708160	14207L	PARTICIPANT	\N	PRESENT	0
709448	708160	20132W	PARTICIPANT	\N	PRESENT	0
709449	708160	19575F	PARTICIPANT	\N	PRESENT	0
709450	708160	20072C	PARTICIPANT	\N	PRESENT	0
709451	708160	20060X	PARTICIPANT	\N	PRESENT	0
709452	708160	19657G	PARTICIPANT	\N	PRESENT	0
709453	708160	20142Y	PARTICIPANT	\N	PRESENT	0
709454	708160	19713W	PARTICIPANT	\N	PRESENT	0
709455	708160	14219Q	PARTICIPANT	\N	PRESENT	0
709456	708160	19479G	PARTICIPANT	\N	PRESENT	0
709457	708160	04047H	PARTICIPANT	\N	PRESENT	0
709458	708160	01024M	PARTICIPANT	\N	PRESENT	0
709459	708160	20298U	PARTICIPANT	\N	PRESENT	0
709460	708160	20076G	PARTICIPANT	\N	PRESENT	0
709461	708160	19569H	PARTICIPANT	\N	PRESENT	0
709462	708160	20040T	PARTICIPANT	\N	PRESENT	0
709463	708160	19619A	PARTICIPANT	\N	PRESENT	0
709464	708160	20078J	PARTICIPANT	\N	PRESENT	0
709465	708160	19691J	PARTICIPANT	\N	PRESENT	0
709466	708160	14255U	PARTICIPANT	\N	PRESENT	0
709467	708160	19057M	PARTICIPANT	\N	PRESENT	0
709468	708160	19421M	PARTICIPANT	\N	PRESENT	0
709469	708160	20266L	PARTICIPANT	\N	PRESENT	0
709470	708160	19782L	PARTICIPANT	\N	PRESENT	0
709471	708160	20096L	PARTICIPANT	\N	PRESENT	0
709472	708160	19577H	PARTICIPANT	\N	PRESENT	0
709473	708160	20180F	PARTICIPANT	\N	PRESENT	0
709474	708160	11027H	PARTICIPANT	\N	PRESENT	0
709475	708160	19347U	PARTICIPANT	\N	PRESENT	0
709476	708160	19719D	PARTICIPANT	\N	PRESENT	0
709477	708160	11074Q	PARTICIPANT	\N	PRESENT	0
709478	708160	12041X	PARTICIPANT	\N	PRESENT	0
709479	708160	20082E	PARTICIPANT	\N	PRESENT	0
709480	708160	14189C	PARTICIPANT	\N	PRESENT	0
709481	708160	20248J	PARTICIPANT	\N	PRESENT	0
709482	708160	04045F	PARTICIPANT	\N	PRESENT	0
709483	708160	14249W	PARTICIPANT	\N	PRESENT	0
709484	708160	11043H	PARTICIPANT	\N	PRESENT	0
709485	708160	10015M	PARTICIPANT	\N	PRESENT	0
709486	708160	20098N	PARTICIPANT	\N	PRESENT	0
709487	708160	14259Y	PARTICIPANT	\N	PRESENT	0
709488	708160	08061X	PARTICIPANT	\N	PRESENT	0
709489	708160	19349W	PARTICIPANT	\N	PRESENT	0
709490	708160	11077T	PARTICIPANT	\N	PRESENT	0
709491	708160	14026U	PARTICIPANT	\N	PRESENT	0
709492	708160	01057W	PARTICIPANT	\N	PRESENT	0
709493	708160	19489J	PARTICIPANT	\N	PRESENT	0
709494	708160	01058X	PARTICIPANT	\N	PRESENT	0
709495	708160	19399H	PARTICIPANT	\N	PRESENT	0
709496	708160	17737W	PARTICIPANT	\N	PRESENT	0
709497	708160	20084G	PARTICIPANT	\N	PRESENT	0
709498	708160	14187A	PARTICIPANT	\N	PRESENT	0
709499	708160	04033B	PARTICIPANT	\N	PRESENT	0
686567	686566	14213J	PARTICIPANT	\N	PRESENT	0
686568	686566	11067R	PARTICIPANT	\N	PRESENT	0
687307	685293	20100N	PARTICIPANT	\N	PRESENT	0
687308	685293	20068G	PARTICIPANT	\N	PRESENT	0
687309	685293	14031R	PARTICIPANT	\N	PRESENT	0
687310	685293	19549D	PARTICIPANT	\N	PRESENT	0
687311	685293	20140W	PARTICIPANT	\N	PRESENT	0
687312	685293	14219Q	PRESIDENT	0	PRESENT	0
687313	685293	20020P	PARTICIPANT	\N	PRESENT	0
687314	685293	19826F	PARTICIPANT	\N	PRESENT	0
687315	685293	20046A	PARTICIPANT	\N	PRESENT	0
687316	685293	20102Q	PARTICIPANT	\N	PRESENT	0
687317	685293	19637C	PARTICIPANT	\N	PRESENT	0
687318	685293	19387D	PARTICIPANT	\N	PRESENT	0
687319	685293	19599P	PARTICIPANT	\N	PRESENT	0
687320	685293	19251M	PARTICIPANT	\N	PRESENT	0
687321	685293	14221J	PARTICIPANT	\N	PRESENT	0
687322	685293	08060W	PARTICIPANT	\N	PRESENT	0
687323	685293	19503N	PARTICIPANT	\N	PRESENT	0
687324	685293	20032T	PARTICIPANT	\N	PRESENT	0
687325	685293	19701S	PARTICIPANT	\N	PRESENT	0
687326	685293	20076G	PARTICIPANT	\N	PRESENT	0
687327	685293	20024T	PARTICIPANT	\N	PRESENT	0
687328	685293	19820Y	PARTICIPANT	\N	PRESENT	0
687329	685293	05012A	PARTICIPANT	\N	PRESENT	0
687330	685293	19333N	PARTICIPANT	\N	EXCUSE	0
687331	685293	18083K	PARTICIPANT	\N	EXCUSE	0
687332	685293	19619A	PARTICIPANT	\N	EXCUSE	0
687333	685293	20136B	PARTICIPANT	\N	EXCUSE	0
687334	685293	17367Q	PARTICIPANT	\N	EXCUSE	0
687335	685293	20038A	PARTICIPANT	\N	PRESENT	0
687336	685293	20096L	PARTICIPANT	\N	PRESENT	0
687337	685293	19745F	PARTICIPANT	\N	PRESENT	0
687338	686365	20108W	PARTICIPANT	\N	PRESENT	0
687339	686365	19673G	PARTICIPANT	\N	PRESENT	0
687340	686365	11033F	PARTICIPANT	\N	PRESENT	0
687341	686365	04047H	PRESIDENT	0	PRESENT	0
687342	686365	14331P	PARTICIPANT	\N	PRESENT	0
687343	686365	14021P	PARTICIPANT	\N	PRESENT	0
687344	686365	14151M	PARTICIPANT	\N	PRESENT	0
687345	686365	14215L	PARTICIPANT	\N	PRESENT	0
687346	686365	10015M	PARTICIPANT	\N	PRESENT	0
687347	686365	11026G	PARTICIPANT	\N	PRESENT	0
687348	686365	14001X	PARTICIPANT	\N	PRESENT	0
687349	686365	11072N	PARTICIPANT	\N	PRESENT	0
687350	686365	14179A	PARTICIPANT	\N	PRESENT	0
687351	686365	14069U	PARTICIPANT	\N	PRESENT	0
687356	686365	11085T	PARTICIPANT	\N	PRESENT	0
687359	686365	20022R	PARTICIPANT	\N	PRESENT	0
687367	686365	05008E	PARTICIPANT	\N	PRESENT	0
687368	686365	14111D	PARTICIPANT	\N	PRESENT	0
687369	686365	14053L	PARTICIPANT	\N	PRESENT	0
687370	686365	14147R	PARTICIPANT	\N	PRESENT	0
687371	686365	19585H	PARTICIPANT	\N	PRESENT	0
687372	686365	19489J	PARTICIPANT	\N	PRESENT	0
687395	686365	19581D	PARTICIPANT	\N	PRESENT	0
687396	685293	19525U	PARTICIPANT	\N	PRESENT	0
687399	686365	01028R	PARTICIPANT	\N	PRESENT	0
687410	686365	19729F	PARTICIPANT	\N	EXCUSE	0
687412	685293	20122U	PARTICIPANT	\N	PRESENT	0
687414	686704	86034E	PARTICIPANT	\N	PRESENT	0
687424	686365	14089Y	PARTICIPANT	\N	PRESENT	0
687446	686365	19543W	PARTICIPANT	\N	PRESENT	0
687447	686581	19443T	PARTICIPANT	\N	PRESENT	0
687448	686581	12041X	PARTICIPANT	\N	PRESENT	0
687449	686581	19565D	PARTICIPANT	\N	PRESENT	0
687450	686581	01058X	PARTICIPANT	\N	PRESENT	0
687451	686581	16685X	PARTICIPANT	\N	PRESENT	0
687452	686581	04042C	PRESIDENT	0	PRESENT	0
687453	686581	11054L	PARTICIPANT	\N	PRESENT	0
687454	686581	19669L	PARTICIPANT	\N	PRESENT	0
687455	686581	11066Q	PARTICIPANT	\N	PRESENT	0
687456	686581	12028B	PARTICIPANT	\N	PRESENT	0
687457	686581	19421M	PARTICIPANT	\N	PRESENT	0
687458	686581	19709B	PARTICIPANT	\N	PRESENT	0
687459	686581	14193X	PARTICIPANT	\N	PRESENT	0
687460	686581	19347U	PARTICIPANT	\N	PRESENT	0
687461	686581	97011G	PARTICIPANT	\N	PRESENT	0
687462	686581	08061X	PARTICIPANT	\N	PRESENT	0
687463	686581	14249W	PARTICIPANT	\N	PRESENT	0
687464	686581	08047A	PARTICIPANT	\N	PRESENT	0
687465	686581	20128B	PARTICIPANT	\N	PRESENT	0
687466	686581	14059S	PARTICIPANT	\N	PRESENT	0
687467	686581	14097Y	PARTICIPANT	\N	PRESENT	0
687468	686581	04035D	PARTICIPANT	\N	PRESENT	0
687469	686581	14133K	PARTICIPANT	\N	PRESENT	0
687470	686581	01062T	PARTICIPANT	\N	PRESENT	0
687471	686581	08069G	PARTICIPANT	\N	PRESENT	0
687472	686581	11041F	PARTICIPANT	\N	PRESENT	0
687473	686581	20042V	PARTICIPANT	\N	PRESENT	0
687474	686581	19721W	PARTICIPANT	\N	PRESENT	0
687475	686581	19319Q	PARTICIPANT	\N	PRESENT	0
687476	686581	14105F	PARTICIPANT	\N	PRESENT	0
687477	686581	20064C	PARTICIPANT	\N	PRESENT	0
687478	686581	98022P	PARTICIPANT	\N	PRESENT	0
687479	686581	14267Y	PARTICIPANT	\N	PRESENT	0
687480	686581	11064N	PARTICIPANT	\N	PRESENT	0
687481	686581	11083R	PARTICIPANT	\N	PRESENT	0
687482	686581	07033P	PARTICIPANT	\N	EXCUSE	0
687483	686581	19583F	PARTICIPANT	\N	EXCUSE	0
687542	686581	11115U	PARTICIPANT	\N	PRESENT	0
687562	687357	19383Y	PARTICIPANT	\N	PRESENT	0
687563	687357	20088L	PARTICIPANT	\N	PRESENT	0
687564	687357	19768N	PARTICIPANT	\N	PRESENT	0
687565	687357	19515S	PARTICIPANT	\N	PRESENT	0
687566	687357	20092G	PARTICIPANT	\N	PRESENT	0
687567	687357	11077T	PARTICIPANT	\N	PRESENT	0
687568	687357	01043Q	PARTICIPANT	\N	PRESENT	0
687569	687357	14357A	PARTICIPANT	\N	PRESENT	0
687570	687357	19413M	PARTICIPANT	\N	PRESENT	0
687571	687357	20082E	PARTICIPANT	\N	PRESENT	0
687572	687357	20094J	PARTICIPANT	\N	PRESENT	0
687573	687357	04045F	PARTICIPANT	\N	PRESENT	0
687574	687357	19631V	PARTICIPANT	\N	PRESENT	0
687575	687357	20104S	PARTICIPANT	\N	PRESENT	0
687576	687357	19705W	PARTICIPANT	\N	PRESENT	0
687577	687357	08015R	PARTICIPANT	\N	PRESENT	0
687578	687357	19575F	PARTICIPANT	\N	PRESENT	0
687579	687357	19369B	PARTICIPANT	\N	PRESENT	0
687580	687357	20018V	PARTICIPANT	\N	PRESENT	0
687581	687357	19563B	PARTICIPANT	\N	PRESENT	0
687582	687357	20028X	PARTICIPANT	\N	PRESENT	0
687583	687357	14329V	PARTICIPANT	\N	PRESENT	0
687584	687357	14038Y	PARTICIPANT	\N	PRESENT	0
687585	687357	19467C	PARTICIPANT	\N	PRESENT	0
687586	687357	20034V	PARTICIPANT	\N	PRESENT	0
687587	687357	14187A	PARTICIPANT	\N	PRESENT	0
687588	687357	20144B	PARTICIPANT	\N	PRESENT	0
687589	687357	19695N	PARTICIPANT	\N	PRESENT	0
687590	687357	11090Q	PRESIDENT	0	PRESENT	0
687591	687357	14033T	PARTICIPANT	\N	PRESENT	0
687592	687357	20054A	PARTICIPANT	\N	PRESENT	0
687593	687357	14205J	PARTICIPANT	\N	PRESENT	0
687594	687357	20060X	PARTICIPANT	\N	PRESENT	0
687595	687357	20062A	PARTICIPANT	\N	PRESENT	0
687596	687357	19507S	PARTICIPANT	\N	PRESENT	0
687597	687357	20286Q	PARTICIPANT	\N	PRESENT	0
687598	687357	20298U	PARTICIPANT	\N	PRESENT	0
687599	687357	14257W	PARTICIPANT	\N	PRESENT	0
687600	687357	08028W	PARTICIPANT	\N	PRESENT	0
687662	686704	20090E	PARTICIPANT	\N	PRESENT	0
687663	686704	14195A	PARTICIPANT	\N	PRESENT	0
687664	686704	19511N	PARTICIPANT	\N	PRESENT	0
687665	686704	08069G	PARTICIPANT	\N	PRESENT	0
687666	686704	07004J	PARTICIPANT	\N	PRESENT	0
687667	686704	11054L	PARTICIPANT	\N	PRESENT	0
687668	686704	11048N	PARTICIPANT	\N	PRESENT	0
687669	686704	19443T	PARTICIPANT	\N	PRESENT	0
687670	686704	20110Q	PARTICIPANT	\N	PRESENT	0
687671	686704	92040Q	PARTICIPANT	\N	PRESENT	0
687672	686704	19741B	PARTICIPANT	\N	PRESENT	0
687673	686704	19507S	PARTICIPANT	\N	PRESENT	0
687674	686704	17589D	PARTICIPANT	\N	PRESENT	0
687675	686704	14038Y	PARTICIPANT	\N	PRESENT	0
687676	686704	14105F	PARTICIPANT	\N	PRESENT	0
687677	686704	20068G	PARTICIPANT	\N	PRESENT	0
687678	686704	20180F	PARTICIPANT	\N	PRESENT	0
687679	686704	19705W	PARTICIPANT	\N	PRESENT	0
687681	686704	19798U	PARTICIPANT	\N	PRESENT	0
687682	686704	19527W	PARTICIPANT	\N	PRESENT	0
687683	686704	11041F	PARTICIPANT	\N	PRESENT	0
696160	695153	19347U	PARTICIPANT	\N	PRESENT	0
696161	695153	14083S	PARTICIPANT	\N	PRESENT	0
696174	695153	19629C	PARTICIPANT	\N	PRESENT	0
696163	695153	14107H	PARTICIPANT	\N	PRESENT	0
696164	695153	01043Q	PARTICIPANT	\N	PRESENT	0
696165	695153	14257W	PARTICIPANT	\N	PRESENT	0
696166	695153	14055N	PARTICIPANT	\N	PRESENT	0
696167	695153	14069U	PARTICIPANT	\N	PRESENT	0
696168	695153	20070A	PARTICIPANT	\N	PRESENT	0
696169	695153	14033T	PARTICIPANT	\N	PRESENT	0
696170	695153	10015M	PARTICIPANT	\N	PRESENT	0
696171	695153	20062A	PARTICIPANT	\N	PRESENT	0
696172	695153	20110Q	PARTICIPANT	\N	PRESENT	0
696173	695153	04045F	PARTICIPANT	\N	PRESENT	0
696175	695153	20108W	PARTICIPANT	\N	PRESENT	0
696176	695153	08061X	PARTICIPANT	\N	PRESENT	0
696177	695153	20092G	PARTICIPANT	\N	PRESENT	0
696178	695153	14053L	PARTICIPANT	\N	PRESENT	0
696179	695153	20034V	PARTICIPANT	\N	PRESENT	0
696180	695153	19447X	PARTICIPANT	\N	PRESENT	0
696181	695153	14147R	PARTICIPANT	\N	PRESENT	0
696182	695153	20128B	PARTICIPANT	\N	PRESENT	0
696183	695153	11053K	PARTICIPANT	\N	PRESENT	0
696184	695153	14215L	PARTICIPANT	\N	PRESENT	0
696185	695153	18083K	PARTICIPANT	\N	PRESENT	0
696186	695153	20180F	PARTICIPANT	\N	PRESENT	0
696187	695153	20030R	PARTICIPANT	\N	PRESENT	0
696188	695153	20032T	PARTICIPANT	\N	PRESENT	0
696189	695153	19383Y	PARTICIPANT	\N	PRESENT	0
696190	695153	14213J	PARTICIPANT	\N	PRESENT	0
696191	695153	20058E	PARTICIPANT	\N	PRESENT	0
697821	694877	04047H	PRESIDENT	0	PRESENT	0
697822	694877	14001X	PARTICIPANT	\N	PRESENT	0
697823	694877	11072N	PARTICIPANT	\N	PRESENT	0
697824	694877	95063L	PARTICIPANT	\N	PRESENT	0
697825	694877	14053L	PARTICIPANT	\N	PRESENT	0
697826	694877	10015M	PARTICIPANT	\N	PRESENT	0
697827	694877	11026G	PARTICIPANT	\N	PRESENT	0
697829	694877	04070G	PARTICIPANT	\N	PRESENT	0
697832	694877	12041X	PARTICIPANT	\N	PRESENT	0
697833	694877	14097Y	PARTICIPANT	\N	PRESENT	0
697837	694877	20286Q	PARTICIPANT	\N	PRESENT	0
697840	694877	20094J	PARTICIPANT	\N	PRESENT	0
697843	694877	14133K	PARTICIPANT	\N	PRESENT	0
697846	694877	08034U	PARTICIPANT	\N	PRESENT	0
697855	694877	14331P	PARTICIPANT	\N	PRESENT	0
697863	694877	20022R	PARTICIPANT	\N	PRESENT	0
697887	694877	05008E	PARTICIPANT	\N	PRESENT	0
697889	694877	14089Y	PARTICIPANT	\N	PRESENT	0
697891	694877	14147R	PARTICIPANT	\N	PRESENT	0
697892	694877	19681G	PARTICIPANT	\N	PRESENT	0
697906	694877	04045F	PARTICIPANT	\N	PRESENT	0
697913	694877	20110Q	PARTICIPANT	\N	PRESENT	0
697914	694877	14357A	PARTICIPANT	\N	PRESENT	0
698031	695158	20064C	PARTICIPANT	\N	PRESENT	0
698032	695158	19551W	PARTICIPANT	\N	PRESENT	0
698033	695158	20088L	PARTICIPANT	\N	PRESENT	0
698034	695158	14281W	PARTICIPANT	\N	PRESENT	0
698035	695158	20914V	PARTICIPANT	\N	PRESENT	0
698036	695158	19697Q	PARTICIPANT	\N	PRESENT	0
698123	694950	11097X	PARTICIPANT	\N	PRESENT	0
698038	695158	20018V	PARTICIPANT	\N	PRESENT	0
698114	695158	14169X	PARTICIPANT	\N	PRESENT	0
698040	695158	20072C	PARTICIPANT	\N	PRESENT	0
698041	695158	19553Y	PARTICIPANT	\N	PRESENT	0
698042	695158	14107H	PARTICIPANT	\N	PRESENT	0
698043	695158	19745F	PARTICIPANT	\N	PRESENT	0
698115	695158	20040T	PARTICIPANT	\N	PRESENT	0
698045	695158	14327T	PARTICIPANT	\N	PRESENT	0
698046	695158	11067R	PARTICIPANT	\N	PRESENT	0
698111	695158	20086J	PARTICIPANT	\N	PRESENT	0
698113	695158	19713W	PARTICIPANT	\N	PRESENT	0
698049	695158	20090E	PARTICIPANT	\N	PRESENT	0
698050	695158	20062A	PARTICIPANT	\N	PRESENT	0
698051	695158	97011G	PARTICIPANT	\N	PRESENT	0
698052	695158	01028R	PARTICIPANT	\N	PRESENT	0
698053	695158	14147R	PARTICIPANT	\N	PRESENT	0
698054	695158	11056N	PARTICIPANT	\N	PRESENT	0
698055	695158	07029T	PARTICIPANT	\N	PRESENT	0
698056	695158	11031D	PARTICIPANT	\N	PRESENT	0
698057	695158	20130U	PARTICIPANT	\N	PRESENT	0
698058	695158	19447X	PARTICIPANT	\N	PRESENT	0
698059	695158	14217N	PARTICIPANT	\N	PRESENT	0
698060	695158	20266L	PARTICIPANT	\N	PRESENT	0
698061	695158	11012A	PARTICIPANT	\N	PRESENT	0
698062	695158	19747H	PARTICIPANT	\N	PRESENT	0
698127	695158	11026G	PARTICIPANT	\N	PRESENT	0
698064	695158	04045F	PARTICIPANT	\N	PRESENT	0
698065	695158	19657G	PARTICIPANT	\N	PRESENT	0
698066	695158	19543W	PARTICIPANT	\N	PRESENT	0
698067	695158	19749K	PARTICIPANT	\N	PRESENT	0
698068	695158	18193Q	PARTICIPANT	\N	PRESENT	0
698069	695158	19549D	PARTICIPANT	\N	PRESENT	0
698070	695158	14026U	PARTICIPANT	\N	PRESENT	0
698120	695158	19621T	PARTICIPANT	\N	PRESENT	0
698072	695158	19631V	PARTICIPANT	\N	PRESENT	0
698073	695158	08045X	PARTICIPANT	\N	PRESENT	0
698074	695158	04092N	PARTICIPANT	\N	PRESENT	0
698148	695158	14033T	PARTICIPANT	\N	PRESENT	0
698076	695158	14030Q	PARTICIPANT	\N	PRESENT	0
698077	695158	20152B	PARTICIPANT	\N	PRESENT	0
698078	695158	19782L	PARTICIPANT	\N	PRESENT	0
698079	695158	14275Y	PARTICIPANT	\N	PRESENT	0
698080	695158	20024T	PARTICIPANT	\N	PRESENT	0
698081	695158	14213J	PARTICIPANT	\N	PRESENT	0
698082	695158	20142Y	PARTICIPANT	\N	PRESENT	0
698083	695158	19489J	PARTICIPANT	\N	PRESENT	0
698084	695158	11027H	PARTICIPANT	\N	PRESENT	0
698085	695158	20172F	PARTICIPANT	\N	PRESENT	0
698086	695158	14257W	PARTICIPANT	\N	PRESENT	0
698087	695158	19673G	PARTICIPANT	\N	PRESENT	0
698116	695158	20298U	PARTICIPANT	\N	PRESENT	0
698089	695158	14053L	PARTICIPANT	\N	PRESENT	0
698090	695158	20098N	PARTICIPANT	\N	PRESENT	0
698112	695158	17779H	PARTICIPANT	\N	PRESENT	0
698092	695158	19527W	PARTICIPANT	\N	PRESENT	0
698117	695158	14215L	PARTICIPANT	\N	PRESENT	0
698094	695158	04057K	PARTICIPANT	\N	PRESENT	0
698095	695158	14042U	PARTICIPANT	\N	PRESENT	0
698096	695158	20110Q	PARTICIPANT	\N	PRESENT	0
698097	695158	20026V	PARTICIPANT	\N	PRESENT	0
698098	695158	11033F	PARTICIPANT	\N	PRESENT	0
698099	695158	20134Y	PARTICIPANT	\N	PRESENT	0
698104	695158	05008E	PARTICIPANT	\N	PRESENT	0
698105	695158	19735D	PARTICIPANT	\N	PRESENT	0
698106	695158	01024M	PARTICIPANT	\N	PRESENT	0
698107	695158	19826F	PARTICIPANT	\N	PRESENT	0
698108	695158	19577H	PARTICIPANT	\N	PRESENT	0
698109	695158	20022R	PARTICIPANT	\N	PRESENT	0
698110	695158	04033B	PARTICIPANT	\N	PRESENT	0
698118	695158	14055N	PARTICIPANT	\N	PRESENT	0
698119	695158	08034U	PARTICIPANT	\N	PRESENT	0
698121	695158	20032T	PARTICIPANT	\N	PRESENT	0
698122	695158	14021P	PARTICIPANT	\N	PRESENT	0
698124	694950	14042U	PARTICIPANT	\N	PRESENT	0
698125	694950	14217N	PARTICIPANT	\N	PRESENT	0
698126	694950	10006L	PRESIDENT	0	PRESENT	0
698128	695158	19503N	PARTICIPANT	\N	PRESENT	0
698129	695158	20100N	PARTICIPANT	\N	PRESENT	0
698130	695158	14225N	PARTICIPANT	\N	PRESENT	0
698131	695158	14229S	PARTICIPANT	\N	PRESENT	0
698132	695158	19649G	PARTICIPANT	\N	PRESENT	0
698133	695158	19647E	PARTICIPANT	\N	PRESENT	0
698134	695158	19333N	PARTICIPANT	\N	PRESENT	0
698135	695158	14097Y	PARTICIPANT	\N	PRESENT	0
698136	695158	20264J	PARTICIPANT	\N	PRESENT	0
698137	694950	19703U	PARTICIPANT	\N	EXCUSE	0
698138	694950	04092N	PARTICIPANT	\N	EXCUSE	0
698139	694950	19760E	PARTICIPANT	\N	EXCUSE	0
698140	695158	19349W	PARTICIPANT	\N	PRESENT	0
698141	695158	19413M	PARTICIPANT	\N	PRESENT	0
698142	695158	20094J	PARTICIPANT	\N	PRESENT	0
698143	695158	14109K	PARTICIPANT	\N	PRESENT	0
698144	695158	20028X	PARTICIPANT	\N	PRESENT	0
698145	695158	19758L	PARTICIPANT	\N	PRESENT	0
698146	695158	20070A	PARTICIPANT	\N	PRESENT	0
698147	695158	20060X	PARTICIPANT	\N	PRESENT	0
698149	695158	20102Q	PARTICIPANT	\N	PRESENT	0
698150	695158	11074Q	PARTICIPANT	\N	PRESENT	0
698151	695158	19591F	PARTICIPANT	\N	PRESENT	0
698152	695158	08010L	PARTICIPANT	\N	PRESENT	0
686750	686749	08018U	PARTICIPANT	\N	PRESENT	0
686751	686749	19503N	PARTICIPANT	\N	PRESENT	0
686752	686749	19631V	PARTICIPANT	\N	PRESENT	0
686753	686749	11027H	PARTICIPANT	\N	PRESENT	0
686754	686749	11083R	PARTICIPANT	\N	PRESENT	0
686758	686757	01043Q	PARTICIPANT	\N	PRESENT	0
686759	686757	20086J	PARTICIPANT	\N	PRESENT	0
688805	688692	20056C	PARTICIPANT	\N	EXCUSE	0
688806	688745	19583F	PARTICIPANT	\N	EXCUSE	0
688807	688745	19295A	PARTICIPANT	\N	PRESENT	0
694971	692487	08060W	PARTICIPANT	\N	EXCUSE	0
694972	692487	19545Y	PARTICIPANT	\N	EXCUSE	0
694973	692487	14329V	PARTICIPANT	\N	EXCUSE	0
694974	692487	14195A	PARTICIPANT	\N	EXCUSE	0
694975	692487	08028W	PARTICIPANT	\N	EXCUSE	0
694976	692487	19467C	PARTICIPANT	\N	EXCUSE	0
694977	692487	19525U	PARTICIPANT	\N	EXCUSE	0
694978	692487	14026U	PARTICIPANT	\N	EXCUSE	0
694979	692487	20126Y	PARTICIPANT	\N	EXCUSE	0
694980	692487	08015R	PARTICIPANT	\N	EXCUSE	0
694981	692487	20048C	PARTICIPANT	\N	EXCUSE	0
694982	692487	16685X	PARTICIPANT	\N	EXCUSE	0
694983	692487	19697Q	PARTICIPANT	\N	EXCUSE	0
694984	692487	19369B	PARTICIPANT	\N	EXCUSE	0
694985	692487	20082E	PARTICIPANT	\N	EXCUSE	0
694986	692486	08060W	PARTICIPANT	\N	EXCUSE	0
694987	692486	19545Y	PARTICIPANT	\N	EXCUSE	0
694988	692486	14329V	PARTICIPANT	\N	EXCUSE	0
694989	692486	14195A	PARTICIPANT	\N	EXCUSE	0
694990	692486	08028W	PARTICIPANT	\N	EXCUSE	0
694991	692486	19467C	PARTICIPANT	\N	EXCUSE	0
694992	692486	19525U	PARTICIPANT	\N	EXCUSE	0
694993	692486	14026U	PARTICIPANT	\N	EXCUSE	0
694994	692486	20048C	PARTICIPANT	\N	EXCUSE	0
694995	692486	20126Y	PARTICIPANT	\N	EXCUSE	0
694996	692486	08015R	PARTICIPANT	\N	EXCUSE	0
694997	692486	16685X	PARTICIPANT	\N	EXCUSE	0
694998	692486	19697Q	PARTICIPANT	\N	EXCUSE	0
694999	692486	19369B	PARTICIPANT	\N	EXCUSE	0
695000	692486	20082E	PARTICIPANT	\N	EXCUSE	0
703627	702922	07029T	PARTICIPANT	\N	EXCUSE	0
706358	706249	20032T	PARTICIPANT	\N	PRESENT	0
706359	706249	19545Y	PARTICIPANT	\N	PRESENT	0
706360	706249	20082E	PARTICIPANT	\N	PRESENT	0
706361	706249	20148F	PARTICIPANT	\N	PRESENT	0
706362	706249	14189C	PARTICIPANT	\N	PRESENT	0
706363	706249	19762G	PARTICIPANT	\N	PRESENT	0
706364	706249	01048V	PARTICIPANT	\N	PRESENT	0
706365	706249	10006L	PARTICIPANT	\N	PRESENT	0
706366	706249	11072N	PARTICIPANT	\N	PRESENT	0
706381	706234	14331P	PARTICIPANT	\N	EXCUSE	0
706382	706249	19057M	PARTICIPANT	\N	PRESENT	0
706383	706249	17367Q	PARTICIPANT	\N	PRESENT	0
706506	704086	14331P	PARTICIPANT	\N	PRESENT	0
706507	704086	19657G	PARTICIPANT	\N	PRESENT	0
706508	704086	14281W	PARTICIPANT	\N	PRESENT	0
706509	704086	20074E	PARTICIPANT	\N	PRESENT	0
706510	704086	19766L	PARTICIPANT	\N	PRESENT	0
706511	704086	08018U	PARTICIPANT	\N	PRESENT	0
706512	704086	20056C	PARTICIPANT	\N	PRESENT	0
706513	704086	17367Q	PARTICIPANT	\N	PRESENT	0
706514	704086	20032T	PARTICIPANT	\N	PRESENT	0
706515	704086	14217N	PARTICIPANT	\N	PRESENT	0
706516	704086	14223L	PARTICIPANT	\N	PRESENT	0
706517	704086	14133K	PARTICIPANT	\N	PRESENT	0
706518	704086	14071N	PARTICIPANT	\N	PRESENT	0
706519	704086	19621T	PARTICIPANT	\N	PRESENT	0
706520	704086	17637T	PARTICIPANT	\N	PRESENT	0
706521	704086	04092N	PARTICIPANT	\N	PRESENT	0
706522	704086	19415P	PARTICIPANT	\N	PRESENT	0
706523	704086	19413M	PARTICIPANT	\N	PRESENT	0
706524	704086	14026U	PARTICIPANT	\N	PRESENT	0
706525	704086	20264J	PARTICIPANT	\N	PRESENT	0
706526	704086	14257W	PARTICIPANT	\N	PRESENT	0
706527	704086	19715Y	PARTICIPANT	\N	PRESENT	0
706528	704086	19631V	PARTICIPANT	\N	PRESENT	0
706529	704086	19679N	PARTICIPANT	\N	PRESENT	0
706530	704086	20080C	PARTICIPANT	\N	PRESENT	0
706531	704086	19667J	PARTICIPANT	\N	PRESENT	0
706532	704086	19758L	PARTICIPANT	\N	PRESENT	0
706533	704086	11031D	PARTICIPANT	\N	PRESENT	0
706534	704086	19399H	PARTICIPANT	\N	PRESENT	0
706535	704086	19760E	PARTICIPANT	\N	PRESENT	0
706536	704086	20102Q	PARTICIPANT	\N	PRESENT	0
706537	704086	04085P	PARTICIPANT	\N	PRESENT	0
706538	704086	11077T	PARTICIPANT	\N	PRESENT	0
706539	704086	19687N	PARTICIPANT	\N	PRESENT	0
706540	704086	18193Q	PARTICIPANT	\N	PRESENT	0
706541	704086	11045K	PARTICIPANT	\N	PRESENT	0
706542	704086	19333N	PARTICIPANT	\N	PRESENT	0
706543	704086	20086J	PARTICIPANT	\N	PRESENT	0
706544	704086	19649G	PARTICIPANT	\N	PRESENT	0
706545	704086	17965H	PARTICIPANT	\N	PRESENT	0
706546	704086	01058X	PARTICIPANT	\N	PRESENT	0
706547	704086	08015R	PARTICIPANT	\N	PRESENT	0
706548	704086	19383Y	PARTICIPANT	\N	PRESENT	0
706549	704086	20130U	PARTICIPANT	\N	PRESENT	0
706550	704086	19347U	PARTICIPANT	\N	PRESENT	0
706551	704086	19581D	PARTICIPANT	\N	PRESENT	0
706552	704086	20914V	PARTICIPANT	\N	PRESENT	0
706553	704086	08045X	PARTICIPANT	\N	PRESENT	0
706554	704086	14021P	PARTICIPANT	\N	PRESENT	0
706555	704086	19367Y	PARTICIPANT	\N	PRESENT	0
706556	704086	04059M	PARTICIPANT	\N	PRESENT	0
706557	704086	17779H	PARTICIPANT	\N	PRESENT	0
706558	704086	20066E	PARTICIPANT	\N	PRESENT	0
706559	704086	14037X	PARTICIPANT	\N	PRESENT	0
706560	704086	19611R	PARTICIPANT	\N	PRESENT	0
706561	704086	19525U	PARTICIPANT	\N	PRESENT	0
706562	704086	01048V	PARTICIPANT	\N	PRESENT	0
706563	704086	95063L	PARTICIPANT	\N	PRESENT	0
706564	704086	19591F	PARTICIPANT	\N	PRESENT	0
706565	704086	19697Q	PARTICIPANT	\N	PRESENT	0
706566	704086	99004R	PARTICIPANT	\N	PRESENT	0
706567	704086	10006L	PARTICIPANT	\N	PRESENT	0
706568	704086	14042U	PARTICIPANT	\N	PRESENT	0
706569	704086	20070A	PARTICIPANT	\N	PRESENT	0
706570	704086	11012A	PARTICIPANT	\N	PRESENT	0
706571	704086	20152B	PARTICIPANT	\N	PRESENT	0
706572	704086	14207L	PARTICIPANT	\N	PRESENT	0
706573	704086	20116W	PARTICIPANT	\N	PRESENT	0
706574	704086	14195A	PARTICIPANT	\N	PRESENT	0
706575	704086	19543W	PARTICIPANT	\N	PRESENT	0
706576	704086	19569H	PARTICIPANT	\N	PRESENT	0
706581	704086	20064C	PARTICIPANT	\N	PRESENT	0
706578	704086	20120S	PARTICIPANT	\N	PRESENT	0
706579	704086	19619A	PARTICIPANT	\N	PRESENT	0
706580	704086	01034P	PARTICIPANT	\N	PRESENT	0
706582	704086	12041X	PARTICIPANT	\N	PRESENT	0
706583	704086	19671E	PARTICIPANT	\N	PRESENT	0
706476	704340	19697Q	PARTICIPANT	\N	PRESENT	0
706477	704340	19569H	PARTICIPANT	\N	PRESENT	0
706478	704340	11097X	PARTICIPANT	\N	PRESENT	0
706479	704340	19415P	PARTICIPANT	\N	PRESENT	0
706480	704340	18193Q	PARTICIPANT	\N	PRESENT	0
706481	704340	14223L	PARTICIPANT	\N	PRESENT	0
706482	704340	14026U	PARTICIPANT	\N	PRESENT	0
706483	704340	17779H	PARTICIPANT	\N	PRESENT	0
706484	704340	11031D	PARTICIPANT	\N	PRESENT	0
706485	704340	14281W	PARTICIPANT	\N	PRESENT	0
706486	704340	19679N	PARTICIPANT	\N	PRESENT	0
706487	704340	14042U	PARTICIPANT	\N	PRESENT	0
706488	704340	14195A	PARTICIPANT	\N	PRESENT	0
706489	704340	19367Y	PARTICIPANT	\N	PRESENT	0
706490	704340	14217N	PARTICIPANT	\N	PRESENT	0
706491	704340	10006L	PRESIDENT	0	PRESENT	0
706492	704340	19591F	PARTICIPANT	\N	PRESENT	0
706493	704340	01034P	PARTICIPANT	\N	PRESENT	0
706494	704340	04092N	PARTICIPANT	\N	PRESENT	0
706495	704340	08045X	PARTICIPANT	\N	PRESENT	0
706496	704340	20040T	PARTICIPANT	\N	PRESENT	0
706497	704340	17965H	PARTICIPANT	\N	PRESENT	0
706498	704340	20148F	PARTICIPANT	\N	PRESENT	0
706499	704340	19723Y	PARTICIPANT	\N	PRESENT	0
706500	704340	20066E	PARTICIPANT	\N	PRESENT	0
706501	704340	14071N	PARTICIPANT	\N	PRESENT	0
706502	704340	19657G	PARTICIPANT	\N	PRESENT	0
706503	704340	04057K	PARTICIPANT	\N	EXCUSE	0
706504	704340	19295A	PARTICIPANT	\N	EXCUSE	0
706505	704086	86034E	PARTICIPANT	\N	PRESENT	0
706584	704086	11097X	PARTICIPANT	\N	PRESENT	0
706585	704086	11074Q	PARTICIPANT	\N	PRESENT	0
709502	708160	19735D	PARTICIPANT	\N	PRESENT	0
709503	708160	14069U	PARTICIPANT	\N	PRESENT	0
709504	708160	16685X	PARTICIPANT	\N	PRESENT	0
709505	708160	20052X	PARTICIPANT	\N	PRESENT	0
709506	708160	14327T	PARTICIPANT	\N	PRESENT	0
709507	708160	14205J	PARTICIPANT	\N	PRESENT	0
709508	708160	08018U	PARTICIPANT	\N	PRESENT	0
709509	708160	14331P	PARTICIPANT	\N	PRESENT	0
709510	708160	19729F	PARTICIPANT	\N	PRESENT	0
709511	708160	19768N	PARTICIPANT	\N	PRESENT	0
709512	708160	20070A	PARTICIPANT	\N	PRESENT	0
709513	708160	19591F	PARTICIPANT	\N	PRESENT	0
709514	708160	19251M	PARTICIPANT	\N	PRESENT	0
709500	708160	19643A	PARTICIPANT	\N	PRESENT	0
709501	708160	14053L	PARTICIPANT	\N	PRESENT	0
709515	708160	14059S	PARTICIPANT	\N	PRESENT	0
709516	708160	20286Q	PARTICIPANT	\N	PRESENT	0
709517	708160	14073Q	PARTICIPANT	\N	PRESENT	0
709518	708160	20032T	PARTICIPANT	\N	PRESENT	0
709519	708160	14147R	PARTICIPANT	\N	PRESENT	0
709520	708160	20058E	PARTICIPANT	\N	PRESENT	0
709521	708160	08015R	PARTICIPANT	\N	PRESENT	0
709522	708160	14267Y	PARTICIPANT	\N	PRESENT	0
709523	708160	20094J	PARTICIPANT	\N	PRESENT	0
709524	708160	19533U	PARTICIPANT	\N	PRESENT	0
709525	708160	19826F	PARTICIPANT	\N	PRESENT	0
709526	708160	14211G	PARTICIPANT	\N	PRESENT	0
709527	708160	20252E	PARTICIPANT	\N	PRESENT	0
709528	708160	14231L	PARTICIPANT	\N	PRESENT	0
709529	708160	19820Y	PARTICIPANT	\N	PRESENT	0
709530	708160	07029T	PARTICIPANT	\N	PRESENT	0
709531	708160	14033T	PARTICIPANT	\N	PRESENT	0
709532	708160	20106U	PARTICIPANT	\N	PRESENT	0
709533	708160	20066E	PARTICIPANT	\N	PRESENT	0
709534	708160	07033P	PARTICIPANT	\N	PRESENT	0
709535	708160	14089Y	PARTICIPANT	\N	PRESENT	0
709536	708160	19545Y	PARTICIPANT	\N	PRESENT	0
709537	708160	20136B	PARTICIPANT	\N	PRESENT	0
709538	708160	20140W	PARTICIPANT	\N	PRESENT	0
709539	708160	20086J	PARTICIPANT	\N	PRESENT	0
709540	708160	11080N	PARTICIPANT	\N	PRESENT	0
709541	708160	20056C	PARTICIPANT	\N	PRESENT	0
709542	708160	08010L	PARTICIPANT	\N	PRESENT	0
709543	708160	19563B	PARTICIPANT	\N	PRESENT	0
709544	708160	04042C	PARTICIPANT	\N	PRESENT	0
709545	708160	19369B	PARTICIPANT	\N	PRESENT	0
709546	708160	11085T	PARTICIPANT	\N	PRESENT	0
709547	708160	11048N	PARTICIPANT	\N	PRESENT	0
709548	708160	20980G	PARTICIPANT	\N	PRESENT	0
709549	708160	20026V	PARTICIPANT	\N	PRESENT	0
709550	708160	04070G	PARTICIPANT	\N	PRESENT	0
709551	708160	14109K	PARTICIPANT	\N	PRESENT	0
709552	708160	17637T	PARTICIPANT	\N	PRESENT	0
709553	708160	19413M	PARTICIPANT	\N	PRESENT	0
709554	708160	20120S	PARTICIPANT	\N	PRESENT	0
709555	708160	11090Q	PARTICIPANT	\N	PRESENT	0
709556	708160	05012A	PARTICIPANT	\N	PRESENT	0
709557	708160	17367Q	PARTICIPANT	\N	PRESENT	0
709558	708160	95063L	PARTICIPANT	\N	PRESENT	0
709559	708160	14179A	PARTICIPANT	\N	PRESENT	0
709560	708160	14123H	PARTICIPANT	\N	PRESENT	0
709561	708160	20126Y	PARTICIPANT	\N	PRESENT	0
709562	708160	14237S	PARTICIPANT	\N	PRESENT	0
709621	706166	14229S	PARTICIPANT	\N	PRESENT	0
709622	706166	08012N	PARTICIPANT	\N	PRESENT	0
709623	706166	11104D	PARTICIPANT	\N	PRESENT	0
709624	706166	20026V	PARTICIPANT	\N	PRESENT	0
709625	709564	19717B	PARTICIPANT	\N	PRESENT	0
709626	709564	19295A	PARTICIPANT	\N	PRESENT	0
709627	706166	19643A	PARTICIPANT	\N	PRESENT	0
709628	706166	20056C	PARTICIPANT	\N	PRESENT	0
709629	709563	11045K	PARTICIPANT	\N	PRESENT	0
709630	709563	11031D	PARTICIPANT	\N	PRESENT	0
709631	709563	19717B	PARTICIPANT	\N	PRESENT	0
709632	709563	11097X	PARTICIPANT	\N	PRESENT	0
709633	709563	18193Q	PARTICIPANT	\N	PRESENT	0
709634	709563	14281W	PARTICIPANT	\N	PRESENT	0
709635	709563	20130U	PARTICIPANT	\N	PRESENT	0
709636	709563	10006L	PRESIDENT	0	PRESENT	0
709637	709563	17779H	PARTICIPANT	\N	PRESENT	0
709638	709563	17965H	PARTICIPANT	\N	PRESENT	0
709639	709563	11067R	PARTICIPANT	\N	PRESENT	0
709640	709563	19683J	PARTICIPANT	\N	PRESENT	0
709641	709563	19591F	PARTICIPANT	\N	PRESENT	0
709642	709563	20266L	PARTICIPANT	\N	PRESENT	0
709643	709563	20248J	PARTICIPANT	\N	PRESENT	0
709644	709563	19713W	PARTICIPANT	\N	PRESENT	0
709645	709563	19553Y	PARTICIPANT	\N	PRESENT	0
709646	709563	19415P	PARTICIPANT	\N	PRESENT	0
709647	709563	04092N	PARTICIPANT	\N	PRESENT	0
709648	709563	19657G	PARTICIPANT	\N	PRESENT	0
709649	709563	20066E	PARTICIPANT	\N	PRESENT	0
709650	709563	19691J	PARTICIPANT	\N	PRESENT	0
709651	709563	19569H	PARTICIPANT	\N	PRESENT	0
709652	709563	14223L	PARTICIPANT	\N	PRESENT	0
709653	709563	14071N	PARTICIPANT	\N	PRESENT	0
709654	709563	14042U	PARTICIPANT	\N	PRESENT	0
709655	709563	20090E	PARTICIPANT	\N	PRESENT	0
709656	709563	14217N	PARTICIPANT	\N	PRESENT	0
709657	709563	14213J	PARTICIPANT	\N	PRESENT	0
709658	709563	19723Y	PARTICIPANT	\N	PRESENT	0
709659	706385	14059S	PARTICIPANT	\N	PRESENT	0
709660	706385	14133K	PRESIDENT	0	PRESENT	0
709661	706385	20072C	PARTICIPANT	\N	PRESENT	0
709662	706385	11041F	PARTICIPANT	\N	PRESENT	0
709663	706385	01058X	PARTICIPANT	\N	PRESENT	0
709664	706385	11027H	PARTICIPANT	\N	PRESENT	0
709665	706385	01024M	PARTICIPANT	\N	PRESENT	0
709666	706385	11066Q	PARTICIPANT	\N	PRESENT	0
709667	706385	08056B	PARTICIPANT	\N	PRESENT	0
709668	706385	14055N	PARTICIPANT	\N	PRESENT	0
709669	706385	19421M	PARTICIPANT	\N	PRESENT	0
709670	706385	19709B	PARTICIPANT	\N	PRESENT	0
709671	706385	14267Y	PARTICIPANT	\N	PRESENT	0
709672	706385	11083R	PARTICIPANT	\N	PRESENT	0
709673	706385	97011G	PARTICIPANT	\N	PRESENT	0
709674	706385	14211G	PARTICIPANT	\N	PRESENT	0
709675	706385	08047A	PARTICIPANT	\N	PRESENT	0
709676	706385	20128B	PARTICIPANT	\N	PRESENT	0
709677	706385	19443T	PARTICIPANT	\N	EXCUSE	0
709678	709563	19798U	PARTICIPANT	\N	PRESENT	0
709679	709563	19367Y	PARTICIPANT	\N	PRESENT	0
709680	709563	19703U	PARTICIPANT	\N	PRESENT	0
709681	709563	14026U	PARTICIPANT	\N	PRESENT	0
709682	709563	19295A	PARTICIPANT	\N	PRESENT	0
709683	706166	20098N	PARTICIPANT	\N	PRESENT	0
709684	706166	14073Q	PARTICIPANT	\N	PRESENT	0
709685	706166	20138D	PARTICIPANT	\N	PRESENT	0
709686	706166	20048C	PARTICIPANT	\N	PRESENT	0
709687	706166	20152B	PARTICIPANT	\N	PRESENT	0
709688	706166	20058E	PARTICIPANT	\N	PRESENT	0
709689	706166	20180F	PARTICIPANT	\N	PRESENT	0
709690	706166	14109K	PARTICIPANT	\N	PRESENT	0
709691	706166	14123H	PARTICIPANT	\N	PRESENT	0
709692	706166	20980G	PARTICIPANT	\N	PRESENT	0
709693	706166	11043H	PARTICIPANT	\N	PRESENT	0
709694	706166	19621T	PARTICIPANT	\N	PRESENT	0
709695	706385	20042V	PARTICIPANT	\N	PRESENT	0
709696	706385	11064N	PARTICIPANT	\N	PRESENT	0
709697	706385	14249W	PARTICIPANT	\N	PRESENT	0
709698	706385	19565D	PARTICIPANT	\N	PRESENT	0
709699	706385	01062T	PARTICIPANT	\N	PRESENT	0
709700	706385	11054L	PARTICIPANT	\N	PRESENT	0
709701	706166	19533U	PARTICIPANT	\N	PRESENT	0
709702	706166	19693L	PARTICIPANT	\N	PRESENT	0
709703	706166	20172F	PARTICIPANT	\N	PRESENT	0
709704	706166	19057M	PARTICIPANT	\N	PRESENT	0
709705	706385	04035D	PARTICIPANT	\N	PRESENT	0
709706	706385	08069G	PARTICIPANT	\N	PRESENT	0
709707	706385	14255U	PARTICIPANT	\N	PRESENT	0
709708	706166	19527W	PARTICIPANT	\N	PRESENT	0
709709	706166	14030Q	PARTICIPANT	\N	PRESENT	0
709710	705855	14053L	PARTICIPANT	\N	PRESENT	0
709711	705855	14111D	PARTICIPANT	\N	PRESENT	0
709712	705855	20074E	PARTICIPANT	\N	PRESENT	0
709713	705855	10015M	PARTICIPANT	\N	PRESENT	0
709714	705855	19581D	PARTICIPANT	\N	PRESENT	0
709715	705855	19585H	PARTICIPANT	\N	PRESENT	0
709716	705855	04047H	PRESIDENT	0	PRESENT	0
709717	705855	19447X	PARTICIPANT	\N	PRESENT	0
709718	705855	19725B	PARTICIPANT	\N	PRESENT	0
687684	686704	14225N	PARTICIPANT	\N	PRESENT	0
687685	686704	14207L	PARTICIPANT	\N	PRESENT	0
687686	686704	01025N	PARTICIPANT	\N	PRESENT	0
687687	686704	08061X	PARTICIPANT	\N	PRESENT	0
687688	686704	20036X	PARTICIPANT	\N	PRESENT	0
687689	686704	08060W	PARTICIPANT	\N	PRESENT	0
687690	686704	20116W	PARTICIPANT	\N	PRESENT	0
687691	686704	20072C	PARTICIPANT	\N	PRESENT	0
687692	686704	20018V	PARTICIPANT	\N	PRESENT	0
687693	686704	19569H	PARTICIPANT	\N	PRESENT	0
687694	686704	14267Y	PARTICIPANT	\N	PRESENT	0
687695	686704	17229F	PARTICIPANT	\N	PRESENT	0
687696	686704	20152B	PARTICIPANT	\N	PRESENT	0
687697	686704	20056C	PARTICIPANT	\N	PRESENT	0
687698	686704	08047A	PARTICIPANT	\N	PRESENT	0
687699	686704	20020P	PARTICIPANT	\N	PRESENT	0
687700	686704	20026V	PARTICIPANT	\N	PRESENT	0
687701	686704	20076G	PARTICIPANT	\N	PRESENT	0
687702	686704	19703U	PARTICIPANT	\N	PRESENT	0
687703	686704	19525U	PARTICIPANT	\N	PRESENT	0
687704	686704	19683J	PARTICIPANT	\N	PRESENT	0
687705	686704	11104D	PARTICIPANT	\N	PRESENT	0
687706	686704	14215L	PARTICIPANT	\N	PRESENT	0
687707	686704	14231L	PARTICIPANT	\N	PRESENT	0
687708	686704	19319Q	PARTICIPANT	\N	PRESENT	0
687709	686704	11012A	PARTICIPANT	\N	PRESENT	0
687710	686704	20144B	PARTICIPANT	\N	PRESENT	0
687711	686704	20120S	PARTICIPANT	\N	PRESENT	0
687712	686704	11033F	PARTICIPANT	\N	PRESENT	0
687713	686704	11027H	PARTICIPANT	\N	PRESENT	0
687714	686704	11083R	PARTICIPANT	\N	PRESENT	0
687715	686704	20264J	PARTICIPANT	\N	PRESENT	0
687716	686704	19820Y	PARTICIPANT	\N	PRESENT	0
687717	686704	20914V	PARTICIPANT	\N	PRESENT	0
687718	686704	17637T	PARTICIPANT	\N	PRESENT	0
687719	686704	04008A	PARTICIPANT	\N	PRESENT	0
687720	686704	19621T	PARTICIPANT	\N	PRESENT	0
687721	686704	04035D	PARTICIPANT	\N	PRESENT	0
687722	686704	19575F	PARTICIPANT	\N	PRESENT	0
687723	686704	01058X	PARTICIPANT	\N	PRESENT	0
687724	686704	99004R	PARTICIPANT	\N	PRESENT	0
687725	686704	08010L	PARTICIPANT	\N	PRESENT	0
687726	686704	19760E	PARTICIPANT	\N	PRESENT	0
687727	686704	04085P	PARTICIPANT	\N	PRESENT	0
687728	686704	11040E	PARTICIPANT	\N	PRESENT	0
687729	686704	19758L	PARTICIPANT	\N	PRESENT	0
687730	686704	11031D	PARTICIPANT	\N	PRESENT	0
687731	686704	20102Q	PARTICIPANT	\N	PRESENT	0
687732	686704	12041X	PARTICIPANT	\N	PRESENT	0
687733	686704	11077T	PARTICIPANT	\N	PRESENT	0
687734	686704	19687N	PARTICIPANT	\N	PRESENT	0
687735	686704	19593H	PARTICIPANT	\N	PRESENT	0
687736	686704	20142Y	PARTICIPANT	\N	PRESENT	0
687737	686704	20100N	PARTICIPANT	\N	PRESENT	0
687738	686704	19651A	PARTICIPANT	\N	PRESENT	0
687739	686704	19637C	PARTICIPANT	\N	PRESENT	0
687740	686704	11072N	PARTICIPANT	\N	PRESENT	0
687741	686704	19349W	PARTICIPANT	\N	PRESENT	0
687742	686704	95063L	PARTICIPANT	\N	PRESENT	0
687743	686704	04045F	PARTICIPANT	\N	PRESENT	0
687744	686704	19301E	PARTICIPANT	\N	PRESENT	0
687745	686704	14055N	PARTICIPANT	\N	PRESENT	0
687746	686704	20128B	PARTICIPANT	\N	PRESENT	0
687747	686704	19719D	PARTICIPANT	\N	PRESENT	0
687748	686704	19387D	PARTICIPANT	\N	PRESENT	0
687749	686704	19553Y	PARTICIPANT	\N	PRESENT	0
687750	686704	11064N	PARTICIPANT	\N	PRESENT	0
687751	686704	14251Q	PARTICIPANT	\N	PRESENT	0
687752	686704	14111D	PARTICIPANT	\N	PRESENT	0
687753	686704	14221J	PARTICIPANT	\N	PRESENT	0
687754	686704	04057K	PARTICIPANT	\N	PRESENT	0
687755	686704	19563B	PARTICIPANT	\N	PRESENT	0
687756	686704	19585H	PARTICIPANT	\N	PRESENT	0
687757	686704	19591F	PARTICIPANT	\N	PRESENT	0
687758	686704	19693L	PARTICIPANT	\N	PRESENT	0
687759	686704	19643A	PARTICIPANT	\N	PRESENT	0
687760	686704	14026U	PARTICIPANT	\N	PRESENT	0
687761	686704	08034U	PARTICIPANT	\N	PRESENT	0
687762	686704	19631V	PARTICIPANT	\N	PRESENT	0
687763	686704	04047H	PARTICIPANT	\N	PRESENT	0
687764	686704	04059M	PARTICIPANT	\N	PRESENT	0
687765	686704	14133K	PARTICIPANT	\N	PRESENT	0
687766	686704	04042C	PARTICIPANT	\N	PRESENT	0
687767	686704	20088L	PARTICIPANT	\N	PRESENT	0
687768	686704	20080C	PARTICIPANT	\N	PRESENT	0
687769	686704	19679N	PARTICIPANT	\N	PRESENT	0
687770	686704	20060X	PARTICIPANT	\N	PRESENT	0
687771	686704	10015M	PARTICIPANT	\N	PRESENT	0
687772	686704	12028B	PARTICIPANT	\N	PRESENT	0
687773	686704	08028W	PARTICIPANT	\N	PRESENT	0
687774	686704	19251M	PARTICIPANT	\N	PRESENT	0
687775	686704	04033B	PARTICIPANT	\N	PRESENT	0
687776	686704	14151M	PARTICIPANT	\N	PRESENT	0
687777	686704	14187A	PARTICIPANT	\N	PRESENT	0
687778	686704	11074Q	PARTICIPANT	\N	PRESENT	0
687779	686704	14281W	PARTICIPANT	\N	PRESENT	0
687780	686704	19725B	PARTICIPANT	\N	PRESENT	0
687781	686704	14071N	PARTICIPANT	\N	PRESENT	0
687782	686704	05008E	PARTICIPANT	\N	PRESENT	0
687783	686704	19715Y	PARTICIPANT	\N	PRESENT	0
687784	686704	14121F	PARTICIPANT	\N	PRESENT	0
687785	686704	11097X	PARTICIPANT	\N	PRESENT	0
687786	686704	19531S	PARTICIPANT	\N	PRESENT	0
687787	686704	19415P	PARTICIPANT	\N	PRESENT	0
687788	686704	14021P	PARTICIPANT	\N	PRESENT	0
687789	686704	19421M	PARTICIPANT	\N	PRESENT	0
687790	686704	19649G	PARTICIPANT	\N	PRESENT	0
687791	686704	14053L	PARTICIPANT	\N	PRESENT	0
687792	686704	11026G	PARTICIPANT	\N	PRESENT	0
687793	686704	19701S	PARTICIPANT	\N	PRESENT	0
687794	686704	14069U	PARTICIPANT	\N	PRESENT	0
687795	686704	18193Q	PARTICIPANT	\N	PRESENT	0
687796	686704	11090Q	PARTICIPANT	\N	PRESENT	0
687797	686704	05012A	PARTICIPANT	\N	PRESENT	0
687798	686704	20022R	PARTICIPANT	\N	PRESENT	0
687799	686704	01057W	PARTICIPANT	\N	PRESENT	0
687800	686704	14259Y	PARTICIPANT	\N	PRESENT	0
687801	686704	19515S	PARTICIPANT	\N	PRESENT	0
687802	686704	14001X	PARTICIPANT	\N	PRESENT	0
687803	686704	11080N	PARTICIPANT	\N	PRESENT	0
687804	686704	20028X	PARTICIPANT	\N	PRESENT	0
687805	686704	01060R	PARTICIPANT	\N	PRESENT	0
687806	686704	20038A	PARTICIPANT	\N	PRESENT	0
687807	686704	19673G	PARTICIPANT	\N	PRESENT	0
687808	686704	14031R	PARTICIPANT	\N	PRESENT	0
687809	686704	20114U	PARTICIPANT	\N	PRESENT	0
687810	686704	11067R	PARTICIPANT	\N	PRESENT	0
687811	686704	19503N	PARTICIPANT	\N	PRESENT	0
687812	686704	19667J	PARTICIPANT	\N	PRESENT	0
687813	686704	20140W	PARTICIPANT	\N	PRESENT	0
687814	686704	14253S	PARTICIPANT	\N	PRESENT	0
687815	686704	19549D	PARTICIPANT	\N	PRESENT	0
687816	686704	01028R	PARTICIPANT	\N	PRESENT	0
687817	686704	14331P	PARTICIPANT	\N	PRESENT	0
687818	686704	01062T	PARTICIPANT	\N	PRESENT	0
687819	686704	20064C	PARTICIPANT	\N	PRESENT	0
687820	686704	19413M	PARTICIPANT	\N	PRESENT	0
687821	686704	19669L	PARTICIPANT	\N	PRESENT	0
687822	686704	19533U	PARTICIPANT	\N	PRESENT	0
687823	686704	10006L	PARTICIPANT	\N	PRESENT	0
687824	686704	20094J	PARTICIPANT	\N	PRESENT	0
687825	686704	14193X	PARTICIPANT	\N	PRESENT	0
687826	686704	19671E	PARTICIPANT	\N	PRESENT	0
687827	686704	20084G	PARTICIPANT	\N	PRESENT	0
687828	686704	20252E	PARTICIPANT	\N	PRESENT	0
687829	686704	14229S	PARTICIPANT	\N	PRESENT	0
687830	686704	17779H	PARTICIPANT	\N	PRESENT	0
687831	686704	14217N	PARTICIPANT	\N	PRESENT	0
687832	686704	97011G	PARTICIPANT	\N	PRESENT	0
687833	686704	20032T	PARTICIPANT	\N	PRESENT	0
687834	686704	14189C	PARTICIPANT	\N	PRESENT	0
687835	686704	14147R	PARTICIPANT	\N	PRESENT	0
687836	686704	19543W	PARTICIPANT	\N	PRESENT	0
687837	686704	20138D	PARTICIPANT	\N	PRESENT	0
687838	686704	20172F	PARTICIPANT	\N	PRESENT	0
687839	686704	19954N	PARTICIPANT	\N	PRESENT	0
687840	686704	14089Y	PARTICIPANT	\N	PRESENT	0
687841	686704	11053K	PARTICIPANT	\N	PRESENT	0
687842	686704	20096L	PARTICIPANT	\N	PRESENT	0
687843	686704	19721W	PARTICIPANT	\N	PRESENT	0
687844	686704	19573D	PARTICIPANT	\N	PRESENT	0
698155	695158	20080C	PARTICIPANT	\N	PRESENT	0
698156	695158	18083K	PARTICIPANT	\N	PRESENT	0
698157	695158	14001X	PARTICIPANT	\N	PRESENT	0
698158	695158	11065P	PARTICIPANT	\N	PRESENT	0
698159	695158	20058E	PARTICIPANT	\N	PRESENT	0
698160	695158	14089Y	PARTICIPANT	\N	PRESENT	0
698161	695158	14083S	PARTICIPANT	\N	PRESENT	0
698162	695158	01058X	PARTICIPANT	\N	PRESENT	0
698163	695158	20126Y	PARTICIPANT	\N	PRESENT	0
698164	695158	05012A	PARTICIPANT	\N	PRESENT	0
698165	695158	19399H	PARTICIPANT	\N	PRESENT	0
698166	695158	20042V	PARTICIPANT	\N	PRESENT	0
698167	695158	04047H	PARTICIPANT	\N	PRESENT	0
698168	695158	19347U	PARTICIPANT	\N	PRESENT	0
698170	695158	19251M	PARTICIPANT	\N	PRESENT	0
698171	695158	19619A	PARTICIPANT	\N	PRESENT	0
698172	693393	19333N	PARTICIPANT	\N	PRESENT	0
698173	693393	20032T	PARTICIPANT	\N	PRESENT	0
698174	693393	19701S	PARTICIPANT	\N	PRESENT	0
698175	693393	20038A	PARTICIPANT	\N	PRESENT	0
698176	693393	14031R	PARTICIPANT	\N	PRESENT	0
698177	693393	19820Y	PARTICIPANT	\N	PRESENT	0
698178	693393	14219Q	PRESIDENT	0	PRESENT	0
698179	693393	19826F	PARTICIPANT	\N	PRESENT	0
698180	693393	19599P	PARTICIPANT	\N	PRESENT	0
698181	693393	20102Q	PARTICIPANT	\N	PRESENT	0
698182	693393	19637C	PARTICIPANT	\N	PRESENT	0
698183	693393	14169X	PARTICIPANT	\N	PRESENT	0
698184	693393	18083K	PARTICIPANT	\N	PRESENT	0
698185	693393	14237S	PARTICIPANT	\N	PRESENT	0
698186	693393	20106U	PARTICIPANT	\N	PRESENT	0
698187	693393	20068G	PARTICIPANT	\N	PRESENT	0
698188	693393	19503N	PARTICIPANT	\N	PRESENT	0
698189	693393	20024T	PARTICIPANT	\N	PRESENT	0
698190	693393	11065P	PARTICIPANT	\N	PRESENT	0
698191	693393	19619A	PARTICIPANT	\N	PRESENT	0
698192	693393	20136B	PARTICIPANT	\N	EXCUSE	0
698193	693393	20046A	PARTICIPANT	\N	EXCUSE	0
698194	693393	17367Q	PARTICIPANT	\N	EXCUSE	0
698195	695158	20124W	PARTICIPANT	\N	PRESENT	0
698196	695158	19766L	PARTICIPANT	\N	PRESENT	0
698197	695158	17965H	PARTICIPANT	\N	PRESENT	0
698198	695158	14187A	PARTICIPANT	\N	PRESENT	0
698199	695158	14179A	PARTICIPANT	\N	PRESENT	0
698200	695158	19531S	PARTICIPANT	\N	PRESENT	0
698201	695158	14249W	PARTICIPANT	\N	PRESENT	0
698202	695158	14357A	PARTICIPANT	\N	PRESENT	0
698203	695158	19683J	PARTICIPANT	\N	PRESENT	0
698204	695158	19651A	PARTICIPANT	\N	PRESENT	0
698205	695158	11053K	PARTICIPANT	\N	PRESENT	0
698206	695158	14151M	PARTICIPANT	\N	PRESENT	0
698207	695158	08061X	PARTICIPANT	\N	PRESENT	0
698208	695158	19707Y	PARTICIPANT	\N	PRESENT	0
698209	695158	19705W	PARTICIPANT	\N	PRESENT	0
698210	695158	19467C	PARTICIPANT	\N	PRESENT	0
698211	695158	19629C	PARTICIPANT	\N	PRESENT	0
698212	695158	19533U	PARTICIPANT	\N	PRESENT	0
698228	698227	14259Y	PARTICIPANT	\N	PRESENT	0
698229	698227	20044X	PARTICIPANT	\N	PRESENT	0
698230	698227	19349W	PARTICIPANT	\N	PRESENT	0
698370	698369	14255U	PARTICIPANT	\N	PRESENT	0
698371	698369	11064N	PARTICIPANT	\N	PRESENT	0
698372	698369	20056C	PARTICIPANT	\N	PRESENT	0
698373	698369	14219Q	PARTICIPANT	\N	PRESENT	0
698374	698369	11072N	PARTICIPANT	\N	PRESENT	0
698153	695158	11080N	PARTICIPANT	\N	PRESENT	0
698154	695158	20092G	PARTICIPANT	\N	PRESENT	0
698375	698369	11041F	PARTICIPANT	\N	PRESENT	0
698376	698369	95063L	PARTICIPANT	\N	PRESENT	0
698377	698369	14237S	PARTICIPANT	\N	PRESENT	0
698378	698369	20052X	PARTICIPANT	\N	PRESENT	0
698444	695162	14147R	PARTICIPANT	\N	PRESENT	0
698472	695160	11070L	PARTICIPANT	\N	PRESENT	0
698474	695160	11065P	PARTICIPANT	\N	PRESENT	0
698475	695160	20086J	PARTICIPANT	\N	PRESENT	0
698476	695160	11012A	PARTICIPANT	\N	PRESENT	0
698477	695160	20032T	PARTICIPANT	\N	PRESENT	0
698478	695160	04057K	PARTICIPANT	\N	PRESENT	0
698479	695160	20914V	PARTICIPANT	\N	PRESENT	0
698480	695160	14249W	PARTICIPANT	\N	PRESENT	0
698481	695160	20080C	PARTICIPANT	\N	PRESENT	0
698482	695160	19687N	PARTICIPANT	\N	PRESENT	0
698483	695160	14189C	PARTICIPANT	\N	PRESENT	0
698484	695160	19621T	PARTICIPANT	\N	PRESENT	0
698487	693587	19577H	PARTICIPANT	\N	PRESENT	0
698488	693586	19577H	PARTICIPANT	\N	EXCUSE	0
698494	695160	20092G	PARTICIPANT	\N	PRESENT	0
698495	695160	20036X	PARTICIPANT	\N	PRESENT	0
698497	695160	20064C	PARTICIPANT	\N	PRESENT	0
698499	695160	19631V	PARTICIPANT	\N	PRESENT	0
698500	695160	19747H	PARTICIPANT	\N	PRESENT	0
698501	695160	08010L	PARTICIPANT	\N	PRESENT	0
698502	695160	18083K	PARTICIPANT	\N	PRESENT	0
698503	695160	20024T	PARTICIPANT	\N	PRESENT	0
698504	695160	14225N	PARTICIPANT	\N	PRESENT	0
698505	695160	20128B	PARTICIPANT	\N	PRESENT	0
698506	695160	11010L	PARTICIPANT	\N	PRESENT	0
698507	695160	20048C	PARTICIPANT	\N	PRESENT	0
698508	695160	19693L	PARTICIPANT	\N	PRESENT	0
698509	695160	20142Y	PARTICIPANT	\N	PRESENT	0
698510	695160	14215L	PARTICIPANT	\N	PRESENT	0
698511	695160	14107H	PARTICIPANT	\N	PRESENT	0
698514	695160	14267Y	PARTICIPANT	\N	PRESENT	0
698515	695160	14147R	PARTICIPANT	\N	PRESENT	0
698516	695160	20072C	PARTICIPANT	\N	PRESENT	0
698517	694940	14231L	PRESIDENT	0	PRESENT	0
698518	694940	14257W	PARTICIPANT	\N	PRESENT	0
698519	694940	14151M	PARTICIPANT	\N	PRESENT	0
698520	694940	20070A	PARTICIPANT	\N	PRESENT	0
698521	694940	19573D	PARTICIPANT	\N	PRESENT	0
698522	694940	14215L	PARTICIPANT	\N	PRESENT	0
698523	694940	14229S	PARTICIPANT	\N	PRESENT	0
698524	694940	14107H	PARTICIPANT	\N	PRESENT	0
698525	694940	19447X	PARTICIPANT	\N	PRESENT	0
698526	694940	19782L	PARTICIPANT	\N	PRESENT	0
698527	694940	14187A	PARTICIPANT	\N	PRESENT	0
698528	694940	04045F	PARTICIPANT	\N	PRESENT	0
698529	694940	19349W	PARTICIPANT	\N	PRESENT	0
698530	694940	19826F	PARTICIPANT	\N	PRESENT	0
698531	694940	05012A	PARTICIPANT	\N	PRESENT	0
698532	694940	14327T	PARTICIPANT	\N	PRESENT	0
698533	694940	20090E	PARTICIPANT	\N	PRESENT	0
698534	694940	08010L	PARTICIPANT	\N	PRESENT	0
698535	694940	01057W	PARTICIPANT	\N	PRESENT	0
698536	694940	19758L	PARTICIPANT	\N	PRESENT	0
698537	694940	19333N	PARTICIPANT	\N	PRESENT	0
698538	695160	14083S	PARTICIPANT	\N	PRESENT	0
698539	695160	19565D	PARTICIPANT	\N	PRESENT	0
698540	695160	19553Y	PARTICIPANT	\N	PRESENT	0
698541	695160	97011G	PARTICIPANT	\N	PRESENT	0
698542	695160	01058X	PARTICIPANT	\N	PRESENT	0
698543	695160	14069U	PARTICIPANT	\N	PRESENT	0
698544	694940	20022R	PARTICIPANT	\N	EXCUSE	0
698545	694940	20110Q	PARTICIPANT	\N	EXCUSE	0
698546	694940	14053L	PARTICIPANT	\N	EXCUSE	0
698547	695160	14217N	PARTICIPANT	\N	PRESENT	0
698548	695160	19711U	PARTICIPANT	\N	PRESENT	0
698549	695160	20100N	PARTICIPANT	\N	PRESENT	0
698552	695160	19399H	PARTICIPANT	\N	PRESENT	0
698553	695160	20018V	PARTICIPANT	\N	PRESENT	0
698554	695160	19479G	PARTICIPANT	\N	PRESENT	0
698555	695160	19347U	PARTICIPANT	\N	PRESENT	0
698556	695160	07029T	PARTICIPANT	\N	PRESENT	0
698557	695160	95041E	PARTICIPANT	\N	PRESENT	0
698558	695160	08034U	PARTICIPANT	\N	PRESENT	0
698560	695160	01048V	PARTICIPANT	\N	PRESENT	0
698563	695160	11110B	PARTICIPANT	\N	PRESENT	0
698564	695160	14133K	PARTICIPANT	\N	PRESENT	0
698565	695160	14021P	PARTICIPANT	\N	PRESENT	0
698566	695160	19647E	PARTICIPANT	\N	PRESENT	0
698567	695160	14059S	PARTICIPANT	\N	PRESENT	0
698568	695160	01024M	PARTICIPANT	\N	PRESENT	0
698569	695160	19543W	PARTICIPANT	\N	PRESENT	0
698574	695160	20070A	PARTICIPANT	\N	PRESENT	0
698571	695160	14026U	PARTICIPANT	\N	PRESENT	0
698572	695160	20130U	PARTICIPANT	\N	PRESENT	0
698573	695160	19619A	PARTICIPANT	\N	PRESENT	0
698575	695160	11066Q	PARTICIPANT	\N	PRESENT	0
698576	695160	20034V	PARTICIPANT	\N	PRESENT	0
698577	695160	14257W	PARTICIPANT	\N	PRESENT	0
698578	695160	11083R	PARTICIPANT	\N	PRESENT	0
689447	689280	20088L	PARTICIPANT	\N	EXCUSE	0
689448	689280	20104S	PARTICIPANT	\N	PRESENT	0
690694	690693	10015M	PARTICIPANT	\N	PRESENT	0
690695	690693	14187A	PARTICIPANT	\N	PRESENT	0
690701	690700	19723Y	PARTICIPANT	\N	PRESENT	0
690793	690792	20054A	PARTICIPANT	\N	PRESENT	0
699499	699498	14329V	PARTICIPANT	\N	PRESENT	0
699500	699498	19782L	PARTICIPANT	\N	PRESENT	0
699502	699501	14329V	PARTICIPANT	\N	PRESENT	0
702808	701536	04057K	PARTICIPANT	\N	PRESENT	0
702809	701536	20066E	PARTICIPANT	\N	PRESENT	0
702810	701536	19713W	PARTICIPANT	\N	PRESENT	0
702930	701724	19333N	PARTICIPANT	\N	PRESENT	0
702931	701724	11083R	PARTICIPANT	\N	PRESENT	0
702932	701724	19593H	PARTICIPANT	\N	PRESENT	0
702933	701724	14073Q	PARTICIPANT	\N	PRESENT	0
702934	701724	14331P	PRESIDENT	0	PRESENT	0
702935	701724	04070G	PARTICIPANT	\N	PRESENT	0
702936	701724	20128B	PARTICIPANT	\N	PRESENT	0
702940	701724	04045F	PARTICIPANT	\N	PRESENT	0
702941	701724	10015M	PARTICIPANT	\N	PRESENT	0
702942	702938	14331P	PARTICIPANT	\N	PRESENT	0
702943	702938	11083R	PARTICIPANT	\N	PRESENT	0
702944	702938	14073Q	PARTICIPANT	\N	PRESENT	0
706587	704086	19691J	PARTICIPANT	\N	PRESENT	0
703881	703820	11026G	PARTICIPANT	\N	PRESENT	0
706586	704086	14189C	PARTICIPANT	\N	PRESENT	0
706588	704086	20094J	PARTICIPANT	\N	PRESENT	0
706589	704086	19421M	PARTICIPANT	\N	PRESENT	0
706590	704086	19723Y	PARTICIPANT	\N	PRESENT	0
706591	704086	20980G	PARTICIPANT	\N	PRESENT	0
706592	704086	19647E	PARTICIPANT	\N	PRESENT	0
706593	704086	14329V	PARTICIPANT	\N	PRESENT	0
706594	704086	19798U	PARTICIPANT	\N	PRESENT	0
706595	704086	04033B	PARTICIPANT	\N	PRESENT	0
706596	704086	11085T	PARTICIPANT	\N	PRESENT	0
706597	704086	20062A	PARTICIPANT	\N	PRESENT	0
706598	704086	19673G	PARTICIPANT	\N	PRESENT	0
706599	704086	05008E	PARTICIPANT	\N	PRESENT	0
706600	704086	20082E	PARTICIPANT	\N	PRESENT	0
706605	706603	19553Y	PARTICIPANT	\N	PRESENT	0
706606	704086	19762G	PARTICIPANT	\N	PRESENT	0
706609	706608	14147R	PARTICIPANT	\N	PRESENT	0
706610	706607	19553Y	PARTICIPANT	\N	PRESENT	0
706611	704086	19954N	PARTICIPANT	\N	PRESENT	0
706612	704086	17737W	PARTICIPANT	\N	PRESENT	0
706615	704086	20096L	PARTICIPANT	\N	PRESENT	0
706616	704086	12016W	PARTICIPANT	\N	PRESENT	0
706617	704086	20148F	PARTICIPANT	\N	PRESENT	0
706618	704086	19533U	PARTICIPANT	\N	PRESENT	0
706619	704086	20142Y	PARTICIPANT	\N	PRESENT	0
706620	704086	01028R	PARTICIPANT	\N	PRESENT	0
706621	704086	14001X	PARTICIPANT	\N	PRESENT	0
706622	704086	04008A	PARTICIPANT	\N	PRESENT	0
706623	704086	19551W	PARTICIPANT	\N	PRESENT	0
706624	704086	14251Q	PARTICIPANT	\N	PRESENT	0
706625	704086	20114U	PARTICIPANT	\N	PRESENT	0
706626	704086	11048N	PARTICIPANT	\N	PRESENT	0
706627	704086	20134Y	PARTICIPANT	\N	PRESENT	0
706628	704086	20040T	PARTICIPANT	\N	PRESENT	0
706629	704086	20136B	PARTICIPANT	\N	PRESENT	0
706630	704086	19701S	PARTICIPANT	\N	PRESENT	0
706631	704086	11026G	PARTICIPANT	\N	PRESENT	0
706632	704086	01024M	PARTICIPANT	\N	PRESENT	0
706633	704086	19507S	PARTICIPANT	\N	PRESENT	0
706634	704086	01043Q	PARTICIPANT	\N	PRESENT	0
706635	704086	04042C	PARTICIPANT	\N	PRESENT	0
706748	704088	01043Q	PARTICIPANT	\N	PRESENT	0
706749	704088	19758L	PARTICIPANT	\N	PRESENT	0
706750	704088	11074Q	PARTICIPANT	\N	PRESENT	0
706751	704088	17779H	PARTICIPANT	\N	PRESENT	0
706752	704088	14225N	PARTICIPANT	\N	PRESENT	0
706753	704088	20914V	PARTICIPANT	\N	PRESENT	0
706754	704088	20142Y	PARTICIPANT	\N	PRESENT	0
706755	704088	14021P	PARTICIPANT	\N	PRESENT	0
706756	704088	20074E	PARTICIPANT	\N	PRESENT	0
706757	704088	11048N	PARTICIPANT	\N	PRESENT	0
706758	704088	17965H	PARTICIPANT	\N	PRESENT	0
706759	704088	19649G	PARTICIPANT	\N	PRESENT	0
706760	704088	11097X	PARTICIPANT	\N	PRESENT	0
706761	704088	20080C	PARTICIPANT	\N	PRESENT	0
706762	704088	01048V	PARTICIPANT	\N	PRESENT	0
706763	704088	14223L	PARTICIPANT	\N	PRESENT	0
706764	704088	14071N	PARTICIPANT	\N	PRESENT	0
706765	704088	20082E	PARTICIPANT	\N	PRESENT	0
706766	704088	04092N	PARTICIPANT	\N	PRESENT	0
706767	704088	12041X	PARTICIPANT	\N	PRESENT	0
706768	704088	04033B	PARTICIPANT	\N	PRESENT	0
706769	704088	05008E	PARTICIPANT	\N	PRESENT	0
706770	704088	19766L	PARTICIPANT	\N	PRESENT	0
706771	704088	14331P	PARTICIPANT	\N	PRESENT	0
706772	704088	11040E	PARTICIPANT	\N	PRESENT	0
706773	704088	11031D	PARTICIPANT	\N	PRESENT	0
706774	704088	19533U	PARTICIPANT	\N	PRESENT	0
706775	704088	19798U	PARTICIPANT	\N	PRESENT	0
706776	704088	19695N	PARTICIPANT	\N	PRESENT	0
706777	704088	95041E	PARTICIPANT	\N	PRESENT	0
706778	704088	19687N	PARTICIPANT	\N	PRESENT	0
706779	704088	20114U	PARTICIPANT	\N	PRESENT	0
706780	704088	19581D	PARTICIPANT	\N	PRESENT	0
706781	704088	04008A	PARTICIPANT	\N	PRESENT	0
706782	704088	19954N	PARTICIPANT	\N	PRESENT	0
706783	704088	19399H	PARTICIPANT	\N	PRESENT	0
706784	704088	11045K	PARTICIPANT	\N	PRESENT	0
706785	704088	20096L	PARTICIPANT	\N	PRESENT	0
706786	704088	20064C	PARTICIPANT	\N	PRESENT	0
706787	704088	14215L	PARTICIPANT	\N	PRESENT	0
706788	704088	19415P	PARTICIPANT	\N	PRESENT	0
706789	704088	20298U	PARTICIPANT	\N	PRESENT	0
706790	704088	11053K	PARTICIPANT	\N	PRESENT	0
706791	704088	18193Q	PARTICIPANT	\N	PRESENT	0
706792	704088	20062A	PARTICIPANT	\N	PRESENT	0
706793	704088	14037X	PARTICIPANT	\N	PRESENT	0
706794	704088	14189C	PARTICIPANT	\N	PRESENT	0
706795	704088	19631V	PARTICIPANT	\N	PRESENT	0
706796	704088	01034P	PARTICIPANT	\N	PRESENT	0
706797	704088	14207L	PARTICIPANT	\N	PRESENT	0
706798	704088	20134Y	PARTICIPANT	\N	PRESENT	0
706799	704088	11012A	PARTICIPANT	\N	PRESENT	0
706800	704088	19347U	PARTICIPANT	\N	PRESENT	0
706802	704088	20130U	PARTICIPANT	\N	PRESENT	0
706803	704088	14217N	PARTICIPANT	\N	PRESENT	0
706804	704088	11026G	PARTICIPANT	\N	PRESENT	0
706805	704088	20086J	PARTICIPANT	\N	PRESENT	0
706806	704088	17367Q	PARTICIPANT	\N	PRESENT	0
706807	704088	20032T	PARTICIPANT	\N	PRESENT	0
706808	704088	14026U	PARTICIPANT	\N	PRESENT	0
706809	704088	19701S	PARTICIPANT	\N	PRESENT	0
706810	704088	20066E	PARTICIPANT	\N	PRESENT	0
706811	704088	11043H	PARTICIPANT	\N	PRESENT	0
706812	704088	17737W	PARTICIPANT	\N	PRESENT	0
706813	704088	19760E	PARTICIPANT	\N	PRESENT	0
706814	704088	19715Y	PARTICIPANT	\N	PRESENT	0
706815	704088	20094J	PARTICIPANT	\N	PRESENT	0
706816	704088	19697Q	PARTICIPANT	\N	PRESENT	0
706817	704088	19591F	PARTICIPANT	\N	PRESENT	0
706818	704088	20070A	PARTICIPANT	\N	PRESENT	0
706819	704088	19503N	PARTICIPANT	\N	PRESENT	0
706820	704088	19551W	PARTICIPANT	\N	PRESENT	0
706821	704088	19367Y	PARTICIPANT	\N	PRESENT	0
706822	704088	19333N	PARTICIPANT	\N	PRESENT	0
706823	704088	14001X	PARTICIPANT	\N	PRESENT	0
706824	704088	20102Q	PARTICIPANT	\N	PRESENT	0
706825	704088	19569H	PARTICIPANT	\N	PRESENT	0
706826	704088	12016W	PARTICIPANT	\N	PRESENT	0
706827	704088	19421M	PARTICIPANT	\N	PRESENT	0
706828	704088	19413M	PARTICIPANT	\N	PRESENT	0
706829	704088	20264J	PARTICIPANT	\N	PRESENT	0
706830	704088	14257W	PARTICIPANT	\N	PRESENT	0
706831	704088	14281W	PARTICIPANT	\N	PRESENT	0
706832	704088	19647E	PARTICIPANT	\N	PRESENT	0
706833	704088	01028R	PARTICIPANT	\N	PRESENT	0
706834	704088	10006L	PARTICIPANT	\N	PRESENT	0
706835	704088	14042U	PARTICIPANT	\N	PRESENT	0
706836	704088	04043D	PARTICIPANT	\N	PRESENT	0
709719	705855	14089Y	PRESIDENT	1	PRESENT	0
709720	705855	17737W	PARTICIPANT	\N	PRESENT	0
709721	705855	95063L	PARTICIPANT	\N	PRESENT	0
709722	705855	19629C	PARTICIPANT	\N	PRESENT	0
709723	705855	07004J	PARTICIPANT	\N	PRESENT	0
709724	705855	14107H	PARTICIPANT	\N	PRESENT	0
709725	705855	14147R	PARTICIPANT	\N	PRESENT	0
709726	705855	14215L	PARTICIPANT	\N	PRESENT	0
709727	705855	19749K	PARTICIPANT	\N	PRESENT	0
709728	705855	14259Y	PARTICIPANT	\N	PRESENT	0
709729	705855	14001X	PARTICIPANT	\N	EXCUSE	0
709730	705855	20022R	PARTICIPANT	\N	EXCUSE	0
709731	705855	11033F	PARTICIPANT	\N	EXCUSE	0
709732	702233	20140W	PARTICIPANT	\N	PRESENT	0
709733	702233	20102Q	PARTICIPANT	\N	PRESENT	0
709734	702233	20024T	PARTICIPANT	\N	PRESENT	0
709735	702233	17229F	PARTICIPANT	\N	PRESENT	0
709736	705855	19729F	PARTICIPANT	\N	PRESENT	0
709737	706385	16685X	PARTICIPANT	\N	PRESENT	0
709738	706385	12028B	PARTICIPANT	\N	PRESENT	0
709739	705855	11072N	PARTICIPANT	\N	PRESENT	0
709740	702233	19387D	PARTICIPANT	\N	PRESENT	0
709741	702233	20046A	PARTICIPANT	\N	PRESENT	0
709742	702233	19659J	PARTICIPANT	\N	PRESENT	0
709743	702233	17367Q	PARTICIPANT	\N	PRESENT	0
709744	705855	14231L	PARTICIPANT	\N	PRESENT	0
709745	705855	20114U	PARTICIPANT	\N	PRESENT	0
709746	702233	19333N	PARTICIPANT	\N	PRESENT	0
709747	702233	19619A	PARTICIPANT	\N	PRESENT	0
709748	705855	05008E	PARTICIPANT	\N	PRESENT	0
709749	705855	14069U	PARTICIPANT	\N	PRESENT	0
709750	702233	18083K	PARTICIPANT	\N	PRESENT	0
709751	702233	14038Y	PARTICIPANT	\N	PRESENT	0
709752	702233	19251M	PARTICIPANT	\N	PRESENT	0
709753	702233	19599P	PARTICIPANT	\N	PRESENT	0
709754	702233	20076G	PARTICIPANT	\N	PRESENT	0
709755	702233	19820Y	PARTICIPANT	\N	PRESENT	0
709756	702233	20106U	PARTICIPANT	\N	PRESENT	0
709757	702233	19739H	PARTICIPANT	\N	PRESENT	0
709758	702233	14031R	PARTICIPANT	\N	PRESENT	0
709759	706166	17589D	PARTICIPANT	\N	PRESENT	0
709760	702233	20096L	PARTICIPANT	\N	PRESENT	0
709761	702233	19826F	PARTICIPANT	\N	PRESENT	0
709762	702233	20038A	PARTICIPANT	\N	PRESENT	0
709763	706166	04070G	PARTICIPANT	\N	PRESENT	0
709764	706166	19573D	PARTICIPANT	\N	PRESENT	0
709765	702233	19551W	PARTICIPANT	\N	PRESENT	0
709766	702233	19577H	PARTICIPANT	\N	PRESENT	0
709767	702233	20032T	PARTICIPANT	\N	PRESENT	0
709768	706385	07033P	PARTICIPANT	\N	PRESENT	0
709769	705855	19673G	PARTICIPANT	\N	PRESENT	0
709770	705855	19543W	PARTICIPANT	\N	PRESENT	0
709772	709771	14255U	PARTICIPANT	\N	PRESENT	0
709773	709771	08009T	PARTICIPANT	\N	PRESENT	0
709774	709771	14169X	PARTICIPANT	\N	PRESENT	0
709775	709771	19585H	PARTICIPANT	\N	PRESENT	0
709776	702233	17637T	PARTICIPANT	\N	PRESENT	0
709777	702233	14169X	PARTICIPANT	\N	PRESENT	0
709778	702233	20020P	PARTICIPANT	\N	PRESENT	0
709779	702233	20068G	PARTICIPANT	\N	PRESENT	0
709780	702233	14221J	PARTICIPANT	\N	PRESENT	0
709781	702233	14219Q	PRESIDENT	0	PRESENT	0
709782	702233	14237S	PARTICIPANT	\N	PRESENT	0
709783	702233	19745F	PARTICIPANT	\N	PRESENT	0
709784	706385	08061X	PARTICIPANT	\N	PRESENT	0
709785	702233	20136B	PARTICIPANT	\N	PRESENT	0
709786	702233	20118Y	PARTICIPANT	\N	PRESENT	0
709787	706385	04042C	PARTICIPANT	\N	PRESENT	0
709788	706248	19697Q	PARTICIPANT	\N	PRESENT	0
709789	706248	11067R	PARTICIPANT	\N	PRESENT	0
709790	706248	20090E	PARTICIPANT	\N	PRESENT	0
709791	706248	04092N	PARTICIPANT	\N	PRESENT	0
709792	706248	19798U	PARTICIPANT	\N	PRESENT	0
709793	706248	19329S	PARTICIPANT	\N	PRESENT	0
709794	706248	19415P	PARTICIPANT	\N	PRESENT	0
709795	706248	19717B	PARTICIPANT	\N	PRESENT	0
709796	706248	18193Q	PARTICIPANT	\N	PRESENT	0
709797	706248	14223L	PARTICIPANT	\N	PRESENT	0
709798	706248	19723Y	PARTICIPANT	\N	PRESENT	0
709799	706248	19553Y	PARTICIPANT	\N	PRESENT	0
709800	706248	14195A	PARTICIPANT	\N	PRESENT	0
709801	706248	19367Y	PARTICIPANT	\N	PRESENT	0
709802	706248	14213J	PARTICIPANT	\N	PRESENT	0
709803	706248	14071N	PRESIDENT	1	PRESENT	0
709804	706248	19657G	PARTICIPANT	\N	PRESENT	0
709805	706248	14217N	PARTICIPANT	\N	PRESENT	0
709806	706248	04043D	PARTICIPANT	\N	PRESENT	0
709807	706248	10006L	PRESIDENT	0	PRESENT	0
709808	706248	19683J	PARTICIPANT	\N	PRESENT	0
709809	706248	19703U	PARTICIPANT	\N	PRESENT	0
709810	706248	20248J	PARTICIPANT	\N	PRESENT	0
709811	702233	19701S	PARTICIPANT	\N	EXCUSE	0
709812	702233	19637C	PARTICIPANT	\N	EXCUSE	0
709813	706248	19295A	PARTICIPANT	\N	PRESENT	0
709814	706386	20072C	PARTICIPANT	\N	PRESENT	0
709815	706386	19565D	PARTICIPANT	\N	PRESENT	0
709816	706386	01058X	PARTICIPANT	\N	PRESENT	0
709817	706386	11027H	PARTICIPANT	\N	PRESENT	0
709818	706386	16685X	PARTICIPANT	\N	PRESENT	0
709819	706386	11054L	PARTICIPANT	\N	PRESENT	0
709820	706386	04042C	PRESIDENT	0	PRESENT	0
709821	706386	11066Q	PARTICIPANT	\N	PRESENT	0
709822	706386	08056B	PARTICIPANT	\N	PRESENT	0
709823	706386	12028B	PARTICIPANT	\N	PRESENT	0
709824	706386	14055N	PARTICIPANT	\N	PRESENT	0
709825	706386	19421M	PARTICIPANT	\N	PRESENT	0
709826	706386	19709B	PARTICIPANT	\N	PRESENT	0
709827	706386	07033P	PARTICIPANT	\N	PRESENT	0
709828	706386	97011G	PARTICIPANT	\N	PRESENT	0
709829	706386	08061X	PARTICIPANT	\N	PRESENT	0
709830	706386	14249W	PARTICIPANT	\N	PRESENT	0
709831	706386	08047A	PARTICIPANT	\N	PRESENT	0
709832	706386	20128B	PARTICIPANT	\N	PRESENT	0
709833	706386	14059S	PARTICIPANT	\N	PRESENT	0
709834	706386	04035D	PARTICIPANT	\N	PRESENT	0
709835	706386	14133K	PARTICIPANT	\N	PRESENT	0
709836	706386	01062T	PARTICIPANT	\N	PRESENT	0
709837	706386	11041F	PARTICIPANT	\N	PRESENT	0
709838	706386	08069G	PARTICIPANT	\N	PRESENT	0
709839	706386	20042V	PARTICIPANT	\N	PRESENT	0
709840	706386	01024M	PARTICIPANT	\N	PRESENT	0
709841	706386	14267Y	PARTICIPANT	\N	PRESENT	0
709842	706386	11064N	PARTICIPANT	\N	PRESENT	0
709843	706386	11083R	PARTICIPANT	\N	PRESENT	0
709844	706386	14211G	PARTICIPANT	\N	PRESENT	0
709845	706386	14255U	PARTICIPANT	\N	PRESENT	0
709846	706386	19443T	PARTICIPANT	\N	EXCUSE	0
709847	706248	11097X	PARTICIPANT	\N	PRESENT	0
709848	706248	14042U	PARTICIPANT	\N	PRESENT	0
709849	706248	04057K	PARTICIPANT	\N	PRESENT	0
709850	706248	19691J	PARTICIPANT	\N	PRESENT	0
709851	705855	14179A	PARTICIPANT	\N	PRESENT	0
709852	705855	14151M	PARTICIPANT	\N	PRESENT	0
709853	702233	19503N	PARTICIPANT	\N	PRESENT	0
709856	708473	20086J	PARTICIPANT	\N	PRESENT	0
709857	708473	14331P	PARTICIPANT	\N	PRESENT	0
709858	708473	01048V	PARTICIPANT	\N	PRESENT	0
709859	708473	01057W	PARTICIPANT	\N	PRESENT	0
709860	708473	20080C	PARTICIPANT	\N	PRESENT	0
709861	708473	11053K	PARTICIPANT	\N	PRESENT	0
709862	708473	07029T	PARTICIPANT	\N	PRESENT	0
709863	708473	19479G	PARTICIPANT	\N	PRESENT	0
709864	708473	20044X	PARTICIPANT	\N	PRESENT	0
709865	708473	14173T	PARTICIPANT	\N	PRESENT	0
709866	708473	14083S	PARTICIPANT	\N	PRESENT	0
709867	708473	08073C	PARTICIPANT	\N	PRESENT	0
709868	708473	20070A	PARTICIPANT	\N	PRESENT	0
709869	708473	14121F	PARTICIPANT	\N	PRESENT	0
709870	708473	99004R	PARTICIPANT	\N	PRESENT	0
709871	708473	11104D	PARTICIPANT	\N	PRESENT	0
709872	706248	20066E	PARTICIPANT	\N	PRESENT	0
709873	706248	17965H	PARTICIPANT	\N	PRESENT	0
709874	706248	19713W	PARTICIPANT	\N	PRESENT	0
709875	709570	20088L	PARTICIPANT	\N	PRESENT	0
709876	709570	19768N	PARTICIPANT	\N	PRESENT	0
709877	709570	19515S	PARTICIPANT	\N	PRESENT	0
709878	709570	19782L	PARTICIPANT	\N	PRESENT	0
709879	709570	20092G	PARTICIPANT	\N	PRESENT	0
709880	709570	11077T	PARTICIPANT	\N	PRESENT	0
709881	709570	20078J	PARTICIPANT	\N	PRESENT	0
709882	709570	19413M	PARTICIPANT	\N	PRESENT	0
687484	687362	04070G	PARTICIPANT	\N	PRESENT	0
687485	687362	19699S	PARTICIPANT	\N	PRESENT	0
687486	687362	04033B	PARTICIPANT	\N	PRESENT	0
687487	687362	14229S	PARTICIPANT	\N	PRESENT	0
687488	687362	20098N	PARTICIPANT	\N	PRESENT	0
687489	687362	19573D	PARTICIPANT	\N	PRESENT	0
687490	687362	20124W	PARTICIPANT	\N	PRESENT	0
687491	687362	20026V	PARTICIPANT	\N	PRESENT	0
687492	687362	19527W	PARTICIPANT	\N	PRESENT	0
687493	687362	19643A	PARTICIPANT	\N	PRESENT	0
687494	687362	20134Y	PARTICIPANT	\N	PRESENT	0
687495	687362	14073Q	PARTICIPANT	\N	PRESENT	0
687496	687362	19651A	PARTICIPANT	\N	PRESENT	0
687497	687362	19611R	PRESIDENT	0	PRESENT	0
687498	687362	20138D	PARTICIPANT	\N	PRESENT	0
687499	687362	20142Y	PARTICIPANT	\N	PRESENT	0
687500	687362	20048C	PARTICIPANT	\N	PRESENT	0
687501	687362	19693L	PARTICIPANT	\N	PRESENT	0
687502	687362	19399H	PARTICIPANT	\N	PRESENT	0
687503	687362	20052X	PARTICIPANT	\N	PRESENT	0
687504	687362	19719D	PARTICIPANT	\N	PRESENT	0
687505	687362	20172F	PARTICIPANT	\N	PRESENT	0
687506	687362	20058E	PARTICIPANT	\N	PRESENT	0
687507	687362	14030Q	PARTICIPANT	\N	PRESENT	0
687508	687362	20056C	PARTICIPANT	\N	PRESENT	0
687509	687362	20180F	PARTICIPANT	\N	PRESENT	0
687510	687362	20264J	PARTICIPANT	\N	PRESENT	0
687511	687362	04059M	PARTICIPANT	\N	PRESENT	0
687512	687362	14123H	PARTICIPANT	\N	PRESENT	0
687513	687362	11104D	PARTICIPANT	\N	PRESENT	0
687514	687362	11043H	PARTICIPANT	\N	PRESENT	0
687515	687362	19758L	PARTICIPANT	\N	PRESENT	0
687516	687362	19621T	PARTICIPANT	\N	PRESENT	0
687517	687362	20084G	PARTICIPANT	\N	PRESENT	0
687845	686704	14083S	PARTICIPANT	\N	PRESENT	0
687846	686704	11070L	PARTICIPANT	\N	PRESENT	0
687847	686704	14327T	PARTICIPANT	\N	PRESENT	0
687848	686704	19723Y	PARTICIPANT	\N	PRESENT	0
687849	686704	01024M	PARTICIPANT	\N	PRESENT	0
687850	686704	20034V	PARTICIPANT	\N	PRESENT	0
687851	686704	14042U	PARTICIPANT	\N	PRESENT	0
687852	686704	19467C	PARTICIPANT	\N	PRESENT	0
687853	686704	14033T	PARTICIPANT	\N	PRESENT	0
687854	686704	19399H	PARTICIPANT	\N	PRESENT	0
687855	686704	17023S	PARTICIPANT	\N	PRESENT	0
687856	686704	20104S	PARTICIPANT	\N	PRESENT	0
687857	686704	20286Q	PARTICIPANT	\N	PRESENT	0
687858	686704	20108W	PARTICIPANT	\N	PRESENT	0
687859	686704	19691J	PARTICIPANT	\N	PRESENT	0
687860	686704	14179A	PARTICIPANT	\N	PRESENT	0
687861	686704	20024T	PARTICIPANT	\N	PRESENT	0
687862	686704	20048C	PARTICIPANT	\N	PRESENT	0
687863	686704	14073Q	PARTICIPANT	\N	PRESENT	0
687864	686704	14213J	PARTICIPANT	\N	PRESENT	0
687865	686704	19735D	PARTICIPANT	\N	PRESENT	0
687866	686704	19611R	PARTICIPANT	\N	PRESENT	0
687867	686704	14329V	PARTICIPANT	\N	PRESENT	0
687868	686704	19699S	PARTICIPANT	\N	PRESENT	0
687869	686704	14357A	PARTICIPANT	\N	PRESENT	0
687870	686704	19675J	PARTICIPANT	\N	PRESENT	0
687871	686704	20052X	PARTICIPANT	\N	PRESENT	0
687872	686704	16685X	PARTICIPANT	\N	PRESENT	0
687873	686704	14205J	PARTICIPANT	\N	PRESENT	0
687874	686704	19762G	PARTICIPANT	\N	PRESENT	0
687875	686704	14219Q	PARTICIPANT	\N	PRESENT	0
687876	686704	11085T	PARTICIPANT	\N	PRESENT	0
687877	686704	19383Y	PARTICIPANT	\N	PRESENT	0
687878	686704	19826F	PARTICIPANT	\N	PRESENT	0
687879	686704	19335Q	PARTICIPANT	\N	PRESENT	0
687880	686704	19581D	PARTICIPANT	\N	PRESENT	0
687881	686704	08009T	PARTICIPANT	\N	PRESENT	0
687882	686704	19369B	PARTICIPANT	\N	PRESENT	0
687883	686704	19367Y	PARTICIPANT	\N	PRESENT	0
687884	686704	04070G	PARTICIPANT	\N	PRESENT	0
687885	686704	20054A	PARTICIPANT	\N	PRESENT	0
687886	686704	19745F	PARTICIPANT	\N	PRESENT	0
687887	686704	20124W	PARTICIPANT	\N	PRESENT	0
687888	686704	14059S	PARTICIPANT	\N	PRESENT	0
687889	686704	20298U	PARTICIPANT	\N	PRESENT	0
687890	686704	20062A	PARTICIPANT	\N	PRESENT	0
687891	686704	01034P	PARTICIPANT	\N	PRESENT	0
687892	686704	19479G	PARTICIPANT	\N	PRESENT	0
687893	686704	19657G	PARTICIPANT	\N	PRESENT	0
687894	686704	07029T	PARTICIPANT	\N	PRESENT	0
687895	686704	08018U	PARTICIPANT	\N	PRESENT	0
687896	686704	20134Y	PARTICIPANT	\N	PRESENT	0
687897	686704	19709B	PARTICIPANT	\N	PRESENT	0
687898	686704	20044X	PARTICIPANT	\N	PRESENT	0
687899	686704	20058E	PARTICIPANT	\N	PRESENT	0
687900	686704	20082E	PARTICIPANT	\N	PRESENT	0
687901	686704	20092G	PARTICIPANT	\N	PRESENT	0
687902	686704	19695N	PARTICIPANT	\N	PRESENT	0
687903	686704	14123H	PARTICIPANT	\N	PRESENT	0
687904	686704	19739H	PARTICIPANT	\N	PRESENT	0
687905	686704	11109J	PARTICIPANT	\N	PRESENT	0
687906	686704	20112S	PARTICIPANT	\N	PRESENT	0
687907	686704	19747H	PARTICIPANT	\N	PRESENT	0
687908	686704	08012N	PARTICIPANT	\N	PRESENT	0
687909	686704	11066Q	PARTICIPANT	\N	PRESENT	0
687910	686704	20132W	PARTICIPANT	\N	PRESENT	0
687911	686704	08015R	PARTICIPANT	\N	PRESENT	0
687912	686704	20122U	PARTICIPANT	\N	PRESENT	0
687913	686704	19713W	PARTICIPANT	\N	PRESENT	0
687914	686704	20098N	PARTICIPANT	\N	PRESENT	0
687915	686704	11045K	PARTICIPANT	\N	PRESENT	0
687916	686704	01043Q	PARTICIPANT	\N	PRESENT	0
687917	686704	19347U	PARTICIPANT	\N	PRESENT	0
687918	686704	20086J	PARTICIPANT	\N	PRESENT	0
687919	686704	20126Y	PARTICIPANT	\N	PRESENT	0
687920	686704	14257W	PARTICIPANT	\N	PRESENT	0
687922	686704	20040T	PARTICIPANT	\N	PRESENT	0
687923	686704	19565D	PARTICIPANT	\N	PRESENT	0
687924	686704	11056N	PARTICIPANT	\N	PRESENT	0
687925	686704	19685L	PARTICIPANT	\N	PRESENT	0
687926	686704	19749K	PARTICIPANT	\N	PRESENT	0
687927	686704	14037X	PARTICIPANT	\N	PRESENT	0
687928	686704	14249W	PARTICIPANT	\N	PRESENT	0
687929	686704	19599P	PARTICIPANT	\N	PRESENT	0
688197	686705	01043Q	PARTICIPANT	\N	PRESENT	0
688200	686705	04008A	PARTICIPANT	\N	PRESENT	0
688207	686705	14179A	PARTICIPANT	\N	PRESENT	0
688208	686705	14151M	PARTICIPANT	\N	PRESENT	0
688209	686705	14215L	PARTICIPANT	\N	PRESENT	0
688210	686705	19585H	PARTICIPANT	\N	PRESENT	0
688211	686705	20110Q	PARTICIPANT	\N	PRESENT	0
688213	686705	95063L	PARTICIPANT	\N	PRESENT	0
688214	686705	04085P	PARTICIPANT	\N	PRESENT	0
688215	686705	19543W	PARTICIPANT	\N	PRESENT	0
688216	686705	14083S	PARTICIPANT	\N	PRESENT	0
688218	686705	20062A	PARTICIPANT	\N	PRESENT	0
688221	686705	19649G	PARTICIPANT	\N	PRESENT	0
688224	686705	20090E	PARTICIPANT	\N	PRESENT	0
688226	686705	14059S	PARTICIPANT	\N	PRESENT	0
688229	686705	19479G	PARTICIPANT	\N	PRESENT	0
688233	686705	20102Q	PARTICIPANT	\N	PRESENT	0
688234	686705	20022R	PARTICIPANT	\N	PRESENT	0
688247	686705	11012A	PARTICIPANT	\N	PRESENT	0
688236	686705	14133K	PARTICIPANT	\N	PRESENT	0
688237	686705	20044X	PARTICIPANT	\N	PRESENT	0
688238	686705	20052X	PARTICIPANT	\N	PRESENT	0
688239	686705	20138D	PARTICIPANT	\N	PRESENT	0
688240	686705	97011G	PARTICIPANT	\N	PRESENT	0
688241	686705	14231L	PARTICIPANT	\N	PRESENT	0
688242	686705	19762G	PARTICIPANT	\N	PRESENT	0
688243	686705	20032T	PARTICIPANT	\N	PRESENT	0
688244	686705	14073Q	PARTICIPANT	\N	PRESENT	0
688245	686705	19349W	PARTICIPANT	\N	PRESENT	0
688246	686705	14031R	PARTICIPANT	\N	PRESENT	0
688248	686705	14021P	PARTICIPANT	\N	PRESENT	0
688249	686705	14147R	PARTICIPANT	\N	PRESENT	0
688250	686705	20024T	PARTICIPANT	\N	PRESENT	0
688251	686705	01058X	PARTICIPANT	\N	PRESENT	0
688252	686705	20082E	PARTICIPANT	\N	PRESENT	0
688253	686705	20080C	PARTICIPANT	\N	PRESENT	0
688254	686705	20092G	PARTICIPANT	\N	PRESENT	0
688255	686705	20100N	PARTICIPANT	\N	PRESENT	0
688257	686705	20132W	PARTICIPANT	\N	PRESENT	0
688264	686705	04047H	PARTICIPANT	\N	PRESENT	0
688270	686705	17023S	PARTICIPANT	\N	PRESENT	0
688295	686430	11040E	PARTICIPANT	\N	PRESENT	0
688296	686430	07029T	PARTICIPANT	\N	PRESENT	0
698579	695160	20098N	PARTICIPANT	\N	PRESENT	0
698580	695160	19669L	PARTICIPANT	\N	PRESENT	0
698581	695160	11054L	PARTICIPANT	\N	PRESENT	0
698582	695160	20110Q	PARTICIPANT	\N	PRESENT	0
698583	695160	20058E	PARTICIPANT	\N	PRESENT	0
698584	694877	14237S	PARTICIPANT	\N	PRESENT	0
698585	695161	11070L	PARTICIPANT	\N	PRESENT	0
698634	695161	14030Q	PARTICIPANT	\N	PRESENT	0
698641	695161	14042U	PARTICIPANT	\N	PRESENT	0
698635	695161	97011G	PARTICIPANT	\N	PRESENT	0
698589	695161	20032T	PARTICIPANT	\N	PRESENT	0
698590	695161	04057K	PARTICIPANT	\N	PRESENT	0
698636	695161	11010L	PARTICIPANT	\N	PRESENT	0
698592	695161	14249W	PARTICIPANT	\N	PRESENT	0
698637	695161	14267Y	PARTICIPANT	\N	PRESENT	0
698594	695161	19687N	PARTICIPANT	\N	PRESENT	0
698638	695161	11085T	PARTICIPANT	\N	PRESENT	0
698596	695161	19621T	PARTICIPANT	\N	PRESENT	0
698639	695161	19347U	PARTICIPANT	\N	PRESENT	0
698598	695161	20036X	PARTICIPANT	\N	PRESENT	0
698599	695161	20064C	PARTICIPANT	\N	PRESENT	0
698640	695161	08061X	PARTICIPANT	\N	PRESENT	0
698601	695161	19747H	PARTICIPANT	\N	PRESENT	0
698642	695161	08034U	PARTICIPANT	\N	PRESENT	0
698643	695161	20110Q	PARTICIPANT	\N	PRESENT	0
698644	695161	11065P	PARTICIPANT	\N	PRESENT	0
698696	698656	20102Q	PARTICIPANT	\N	PRESENT	0
698606	695161	14215L	PARTICIPANT	\N	PRESENT	0
698697	698656	20914V	PARTICIPANT	\N	PRESENT	0
698608	695161	20072C	PARTICIPANT	\N	PRESENT	0
698609	695161	19565D	PARTICIPANT	\N	PRESENT	0
698698	698656	19421M	PARTICIPANT	\N	PRESENT	0
698611	695161	20100N	PARTICIPANT	\N	PRESENT	0
698699	698656	14133K	PARTICIPANT	\N	PRESENT	0
698613	695161	20018V	PARTICIPANT	\N	PRESENT	0
698700	698656	08047A	PARTICIPANT	\N	PRESENT	0
698615	695161	07029T	PARTICIPANT	\N	PRESENT	0
698701	698656	11066Q	PARTICIPANT	\N	PRESENT	0
698617	695161	01048V	PARTICIPANT	\N	PRESENT	0
698702	698656	11054L	PARTICIPANT	\N	PRESENT	0
698619	695161	14133K	PARTICIPANT	\N	PRESENT	0
698703	698656	14267Y	PARTICIPANT	\N	PRESENT	0
698704	698656	07029T	PARTICIPANT	\N	PRESENT	0
698622	695161	01024M	PARTICIPANT	\N	PRESENT	0
698705	698656	11083R	PARTICIPANT	\N	PRESENT	0
698624	695161	20130U	PARTICIPANT	\N	PRESENT	0
698625	695161	20070A	PARTICIPANT	\N	PRESENT	0
698626	695161	11066Q	PARTICIPANT	\N	PRESENT	0
698627	695161	14257W	PARTICIPANT	\N	PRESENT	0
698628	695161	11083R	PARTICIPANT	\N	PRESENT	0
698629	695161	19669L	PARTICIPANT	\N	PRESENT	0
698630	695161	11054L	PARTICIPANT	\N	PRESENT	0
698706	698656	11010L	PARTICIPANT	\N	PRESENT	0
698632	695161	20058E	PARTICIPANT	\N	PRESENT	0
698633	695161	08010L	PARTICIPANT	\N	PRESENT	0
698707	698656	20092G	PARTICIPANT	\N	PRESENT	0
698708	698656	20110Q	PARTICIPANT	\N	PRESENT	0
698709	698656	20088L	PARTICIPANT	\N	PRESENT	0
698710	698656	20072C	PARTICIPANT	\N	PRESENT	0
698711	698656	01024M	PARTICIPANT	\N	PRESENT	0
698712	698656	11065P	PARTICIPANT	\N	PRESENT	0
698713	698656	20100N	PARTICIPANT	\N	PRESENT	0
698714	698656	20080C	PARTICIPANT	\N	PRESENT	0
698715	698656	20024T	PARTICIPANT	\N	PRESENT	0
698716	698656	08010L	PARTICIPANT	\N	PRESENT	0
698717	698656	20090E	PARTICIPANT	\N	PRESENT	0
698718	698656	20266L	PARTICIPANT	\N	PRESENT	0
698719	698656	04042C	PARTICIPANT	\N	PRESENT	0
698720	698656	19691J	PARTICIPANT	\N	PRESENT	0
698721	698656	19565D	PARTICIPANT	\N	PRESENT	0
698722	698656	20070A	PARTICIPANT	\N	PRESENT	0
698723	698656	20018V	PARTICIPANT	\N	PRESENT	0
698724	698656	19413M	PARTICIPANT	\N	PRESENT	0
698725	698656	14257W	PARTICIPANT	\N	PRESENT	0
698726	698656	19669L	PARTICIPANT	\N	PRESENT	0
698727	698656	17965H	PARTICIPANT	\N	PRESENT	0
698728	698656	14059S	PARTICIPANT	\N	PRESENT	0
698729	698656	11097X	PARTICIPANT	\N	PRESENT	0
698730	698656	97011G	PARTICIPANT	\N	PRESENT	0
698731	698656	20032T	PARTICIPANT	\N	PRESENT	0
698732	698656	19711U	PARTICIPANT	\N	PRESENT	0
698694	698656	14026U	PARTICIPANT	\N	PRESENT	0
698695	698656	19347U	PARTICIPANT	\N	PRESENT	0
698734	698656	08061X	PARTICIPANT	\N	PRESENT	0
698736	698656	19701S	PARTICIPANT	\N	PRESENT	0
698737	698656	19543W	PARTICIPANT	\N	PRESENT	0
698738	698656	19667J	PARTICIPANT	\N	PRESENT	0
698739	698656	04057K	PARTICIPANT	\N	PRESENT	0
698740	698656	20064C	PARTICIPANT	\N	PRESENT	0
698741	698656	20152B	PARTICIPANT	\N	PRESENT	0
698742	698656	01058X	PARTICIPANT	\N	PRESENT	0
698743	698656	19693L	PARTICIPANT	\N	PRESENT	0
698746	698656	14187A	PARTICIPANT	\N	PRESENT	0
698747	698656	19631V	PARTICIPANT	\N	PRESENT	0
698748	698656	19747H	PARTICIPANT	\N	PRESENT	0
698749	698656	19643A	PARTICIPANT	\N	PRESENT	0
698750	698656	19749K	PARTICIPANT	\N	PRESENT	0
698751	698656	20130U	PARTICIPANT	\N	PRESENT	0
698752	698656	19573D	PARTICIPANT	\N	PRESENT	0
698757	698656	99004R	PARTICIPANT	\N	PRESENT	0
698766	698656	14215L	PARTICIPANT	\N	PRESENT	0
698767	698656	10015M	PARTICIPANT	\N	PRESENT	0
698769	698656	01043Q	PARTICIPANT	\N	PRESENT	0
698770	698656	07004J	PARTICIPANT	\N	PRESENT	0
698771	698656	04085P	PARTICIPANT	\N	PRESENT	0
698780	698656	04047H	PARTICIPANT	\N	PRESENT	0
698781	698656	11012A	PARTICIPANT	\N	PRESENT	0
698782	698656	19647E	PARTICIPANT	\N	PRESENT	0
698783	698656	19719D	PARTICIPANT	\N	PRESENT	0
698847	695554	14026U	PARTICIPANT	\N	PRESENT	0
698848	695554	10015M	PARTICIPANT	\N	PRESENT	0
698851	695554	19693L	PARTICIPANT	\N	PRESENT	0
698852	695554	11010L	PARTICIPANT	\N	PRESENT	0
698853	695554	07029T	PARTICIPANT	\N	PRESENT	0
698855	695554	11012A	PARTICIPANT	\N	PRESENT	0
698869	695554	20102Q	PARTICIPANT	\N	PRESENT	0
698858	695554	20130U	PARTICIPANT	\N	PRESENT	0
698859	695554	20100N	PARTICIPANT	\N	PRESENT	0
698860	695554	19647E	PARTICIPANT	\N	PRESENT	0
698861	695554	19631V	PARTICIPANT	\N	PRESENT	0
698862	695554	20088L	PARTICIPANT	\N	PRESENT	0
698863	695554	20914V	PARTICIPANT	\N	PRESENT	0
698865	695554	20092G	PARTICIPANT	\N	PRESENT	0
698866	695554	20110Q	PARTICIPANT	\N	PRESENT	0
698868	695554	14257W	PARTICIPANT	\N	PRESENT	0
698871	695554	04085P	PARTICIPANT	\N	PRESENT	0
698873	695554	04047H	PARTICIPANT	\N	PRESENT	0
698874	695554	01043Q	PARTICIPANT	\N	PRESENT	0
698876	695554	07004J	PARTICIPANT	\N	PRESENT	0
698877	695554	14215L	PARTICIPANT	\N	PRESENT	0
698879	695554	19701S	PARTICIPANT	\N	PRESENT	0
698880	695554	19711U	PARTICIPANT	\N	PRESENT	0
698881	695554	14187A	PARTICIPANT	\N	PRESENT	0
698882	695554	19747H	PARTICIPANT	\N	PRESENT	0
698883	695554	19673G	PARTICIPANT	\N	PRESENT	0
698884	695554	20106U	PARTICIPANT	\N	PRESENT	0
698885	695554	19543W	PARTICIPANT	\N	PRESENT	0
698892	695554	20264J	PARTICIPANT	\N	PRESENT	0
698887	695554	19697Q	PARTICIPANT	\N	PRESENT	0
698888	695554	19413M	PARTICIPANT	\N	PRESENT	0
698889	695554	04043D	PARTICIPANT	\N	PRESENT	0
698890	695554	17965H	PARTICIPANT	\N	PRESENT	0
698891	695554	01024M	PARTICIPANT	\N	PRESENT	0
698893	695554	20032T	PARTICIPANT	\N	PRESENT	0
698894	695554	19667J	PARTICIPANT	\N	PRESENT	0
698895	695554	11109J	PARTICIPANT	\N	PRESENT	0
698896	695554	19649G	PARTICIPANT	\N	PRESENT	0
698897	695554	20180F	PARTICIPANT	\N	PRESENT	0
698898	695554	20122U	PARTICIPANT	\N	PRESENT	0
698899	695554	14217N	PARTICIPANT	\N	PRESENT	0
698901	695554	11053K	PARTICIPANT	\N	PRESENT	0
698913	695554	19549D	PARTICIPANT	\N	PRESENT	0
698924	695554	19691J	PARTICIPANT	\N	PRESENT	0
698925	695554	11077T	PARTICIPANT	\N	PRESENT	0
698950	698949	19703U	PARTICIPANT	\N	PRESENT	1
698951	698949	08045X	PARTICIPANT	\N	PRESENT	1
698953	698952	14205J	PARTICIPANT	\N	PRESENT	0
698954	698952	14033T	PARTICIPANT	\N	PRESENT	0
698956	698955	14205J	PARTICIPANT	\N	PRESENT	0
698958	698957	14205J	PARTICIPANT	\N	PRESENT	0
698960	698959	14205J	PARTICIPANT	\N	PRESENT	0
686314	685741	14189C	PARTICIPANT	\N	EXCUSE	0
686315	685741	20094J	PARTICIPANT	\N	PRESENT	0
686316	685741	14089Y	PARTICIPANT	\N	PRESENT	0
686317	685741	19701S	PARTICIPANT	\N	PRESENT	0
686318	685741	14357A	PARTICIPANT	\N	PRESENT	0
686319	685741	20100N	PARTICIPANT	\N	PRESENT	0
686320	685741	11083R	PARTICIPANT	\N	PRESENT	0
686321	685741	19531S	PARTICIPANT	\N	PRESENT	0
686322	685741	14073Q	PARTICIPANT	\N	PRESENT	0
686323	685741	08034U	PARTICIPANT	\N	PRESENT	0
686324	685741	14001X	PARTICIPANT	\N	PRESENT	0
686325	685741	04070G	PARTICIPANT	\N	PRESENT	0
686326	685741	14331P	PRESIDENT	0	PRESENT	0
686327	685741	10015M	PRESIDENT	1	PRESENT	0
686328	685741	04045F	PARTICIPANT	\N	PRESENT	0
687210	687209	14151M	PARTICIPANT	\N	PRESENT	0
687211	687209	20022R	PARTICIPANT	\N	PRESENT	0
687213	687212	14151M	PARTICIPANT	\N	PRESENT	0
687214	687212	20022R	PARTICIPANT	\N	PRESENT	0
687215	687212	20114U	PARTICIPANT	\N	PRESENT	0
687216	687212	19649G	PARTICIPANT	\N	PRESENT	0
687219	687217	20022R	PARTICIPANT	\N	PRESENT	0
687220	687217	14151M	PARTICIPANT	\N	PRESENT	0
687429	687428	20094J	PARTICIPANT	\N	PRESENT	0
687430	687428	20114U	PARTICIPANT	\N	PRESENT	0
687431	687428	20074E	PARTICIPANT	\N	PRESENT	0
687432	687428	20056C	PARTICIPANT	\N	PRESENT	0
687433	687428	14001X	PARTICIPANT	\N	PRESENT	0
687434	687428	04070G	PARTICIPANT	\N	PRESENT	0
687435	687428	20028X	PARTICIPANT	\N	PRESENT	0
688844	688745	14219Q	PARTICIPANT	\N	PRESENT	0
689334	688394	20038A	PARTICIPANT	\N	EXCUSE	0
689335	688394	19637C	PARTICIPANT	\N	EXCUSE	0
691707	690432	19713W	PARTICIPANT	\N	PRESENT	0
691708	690432	01034P	PARTICIPANT	\N	PRESENT	0
691710	690432	19591F	PARTICIPANT	\N	PRESENT	0
691844	690787	14331P	PRESIDENT	0	PRESENT	0
691845	690787	04057K	PARTICIPANT	\N	PRESENT	0
691846	690787	11083R	PARTICIPANT	\N	PRESENT	0
691847	690787	14001X	PARTICIPANT	\N	PRESENT	0
691848	690787	19333N	PARTICIPANT	\N	PRESENT	0
691849	690787	19725B	PARTICIPANT	\N	PRESENT	0
691850	690787	19441R	PARTICIPANT	\N	PRESENT	0
691851	690787	11101A	PARTICIPANT	\N	PRESENT	0
691852	690787	10015M	PARTICIPANT	\N	PRESENT	0
691853	690787	20100N	PARTICIPANT	\N	PRESENT	0
691854	690787	20098N	PARTICIPANT	\N	PRESENT	0
691855	690787	14073Q	PARTICIPANT	\N	PRESENT	0
691856	690787	20286Q	PARTICIPANT	\N	PRESENT	0
691857	690787	04045F	PARTICIPANT	\N	EXCUSE	0
691858	690787	14357A	PARTICIPANT	\N	PRESENT	0
691859	690787	14089Y	PARTICIPANT	\N	PRESENT	0
692178	692177	19611R	PARTICIPANT	\N	PRESENT	0
692179	692177	19651A	PARTICIPANT	\N	PRESENT	0
692180	692177	14030Q	PARTICIPANT	\N	PRESENT	0
692181	692177	19643A	PARTICIPANT	\N	PRESENT	0
692182	692177	19621T	PARTICIPANT	\N	PRESENT	0
692183	692177	19693L	PARTICIPANT	\N	PRESENT	0
692184	692177	20980G	PARTICIPANT	\N	PRESENT	0
692185	692177	19719D	PARTICIPANT	\N	PRESENT	0
692186	692177	20124W	PARTICIPANT	\N	PRESENT	0
692187	692177	20172F	PARTICIPANT	\N	PRESENT	0
692188	692177	20180F	PARTICIPANT	\N	PRESENT	0
692203	690416	14030Q	PARTICIPANT	\N	EXCUSE	0
692190	692177	14123H	PARTICIPANT	\N	PRESENT	0
692192	692177	20056C	PARTICIPANT	\N	PRESENT	0
692193	692177	19735D	PARTICIPANT	\N	PRESENT	0
692194	692177	19699S	PARTICIPANT	\N	PRESENT	0
692195	692177	20052X	PARTICIPANT	\N	PRESENT	0
692196	692177	11104D	PARTICIPANT	\N	PRESENT	0
692197	692177	20142Y	PARTICIPANT	\N	PRESENT	0
692198	692177	14109K	PARTICIPANT	\N	PRESENT	0
692199	692177	20098N	PARTICIPANT	\N	PRESENT	0
692200	692177	19527W	PARTICIPANT	\N	PRESENT	0
692201	692177	20026V	PARTICIPANT	\N	PRESENT	0
692202	690416	11109J	PARTICIPANT	\N	EXCUSE	0
692204	690386	11109J	PARTICIPANT	\N	EXCUSE	0
702760	702759	20132W	PARTICIPANT	\N	PRESENT	1
703262	701623	19729F	PARTICIPANT	\N	EXCUSE	0
706839	704088	19525U	PARTICIPANT	\N	PRESENT	0
706840	704088	19657G	PARTICIPANT	\N	PRESENT	0
706841	704088	11077T	PARTICIPANT	\N	PRESENT	0
706842	704088	14083S	PARTICIPANT	\N	PRESENT	0
706843	704088	20116W	PARTICIPANT	\N	PRESENT	0
706844	704088	14195A	PARTICIPANT	\N	PRESENT	0
706845	704088	20040T	PARTICIPANT	\N	PRESENT	0
706849	704088	19691J	PARTICIPANT	\N	PRESENT	0
706847	704088	20120S	PARTICIPANT	\N	PRESENT	0
706848	704088	19621T	PARTICIPANT	\N	PRESENT	0
706850	704088	04035D	PARTICIPANT	\N	PRESENT	0
706851	704088	20152B	PARTICIPANT	\N	PRESENT	0
706852	704088	20056C	PARTICIPANT	\N	PRESENT	0
706853	704088	04085P	PARTICIPANT	\N	PRESENT	0
706854	704088	20022R	PARTICIPANT	\N	PRESENT	0
706855	704088	19619A	PARTICIPANT	\N	PRESENT	0
706856	704088	19723Y	PARTICIPANT	\N	PRESENT	0
706857	704088	19383Y	PARTICIPANT	\N	PRESENT	0
706858	704088	19762G	PARTICIPANT	\N	PRESENT	0
706859	704088	08015R	PARTICIPANT	\N	PRESENT	0
706860	704088	01024M	PARTICIPANT	\N	PRESENT	0
706861	704088	95063L	PARTICIPANT	\N	PRESENT	0
706862	704088	19507S	PARTICIPANT	\N	PRESENT	0
706837	704088	19387D	PARTICIPANT	\N	PRESENT	0
706838	704088	01058X	PARTICIPANT	\N	PRESENT	0
706863	704088	14329V	PARTICIPANT	\N	PRESENT	0
706864	704088	08018U	PARTICIPANT	\N	PRESENT	0
706865	704088	19679N	PARTICIPANT	\N	PRESENT	0
706866	704088	20136B	PARTICIPANT	\N	PRESENT	0
706867	704088	14133K	PARTICIPANT	\N	PRESENT	0
706868	704088	04042C	PARTICIPANT	\N	PRESENT	0
706869	704088	07029T	PARTICIPANT	\N	PRESENT	0
706870	704088	11110B	PARTICIPANT	\N	PRESENT	0
706871	704088	19369B	PARTICIPANT	\N	PRESENT	0
706885	704096	99004R	PARTICIPANT	\N	PRESENT	0
706886	704096	19695N	PARTICIPANT	\N	PRESENT	0
706887	704096	12041X	PARTICIPANT	\N	PRESENT	0
706888	704096	11077T	PARTICIPANT	\N	PRESENT	0
706889	704096	17779H	PARTICIPANT	\N	PRESENT	0
706890	704096	19758L	PARTICIPANT	\N	PRESENT	0
706891	704096	20102Q	PARTICIPANT	\N	PRESENT	0
706892	704096	20130U	PARTICIPANT	\N	PRESENT	0
706895	704096	20914V	PARTICIPANT	\N	PRESENT	0
706896	704096	11026G	PARTICIPANT	\N	PRESENT	0
706897	704096	14281W	PARTICIPANT	\N	PRESENT	0
706898	704096	12016W	PARTICIPANT	\N	PRESENT	0
706899	704096	19413M	PARTICIPANT	\N	PRESENT	0
706900	704096	01028R	PARTICIPANT	\N	PRESENT	0
706901	704096	07029T	PARTICIPANT	\N	PRESENT	0
706902	704096	19525U	PARTICIPANT	\N	PRESENT	0
706903	704096	20142Y	PARTICIPANT	\N	PRESENT	0
706904	704096	14223L	PARTICIPANT	\N	PRESENT	0
706905	704096	04092N	PARTICIPANT	\N	PRESENT	0
706906	704096	19347U	PARTICIPANT	\N	PRESENT	0
706907	704096	14225N	PARTICIPANT	\N	PRESENT	0
706908	704096	20074E	PARTICIPANT	\N	PRESENT	0
706909	704096	08045X	PARTICIPANT	\N	PRESENT	0
706910	704096	19679N	PARTICIPANT	\N	PRESENT	0
706911	704096	14021P	PARTICIPANT	\N	PRESENT	0
706912	704096	04035D	PARTICIPANT	\N	PRESENT	0
706913	704096	19766L	PARTICIPANT	\N	PRESENT	0
706914	704096	19333N	PARTICIPANT	\N	PRESENT	0
706915	704096	14001X	PARTICIPANT	\N	PRESENT	0
706916	704096	17367Q	PARTICIPANT	\N	PRESENT	0
706917	704096	11045K	PARTICIPANT	\N	PRESENT	0
706918	704096	19657G	PARTICIPANT	\N	PRESENT	0
706919	704096	19715Y	PARTICIPANT	\N	PRESENT	0
706920	704096	20070A	PARTICIPANT	\N	PRESENT	0
706921	704096	11074Q	PARTICIPANT	\N	PRESENT	0
706922	704096	11031D	PARTICIPANT	\N	PRESENT	0
706923	704096	19760E	PARTICIPANT	\N	PRESENT	0
706924	704096	14133K	PARTICIPANT	\N	PRESENT	0
706925	704096	05008E	PARTICIPANT	\N	PRESENT	0
706926	704096	19619A	PARTICIPANT	\N	PRESENT	0
706927	704096	14071N	PARTICIPANT	\N	PRESENT	0
706928	704096	14083S	PARTICIPANT	\N	PRESENT	0
706929	704096	20040T	PARTICIPANT	\N	PRESENT	0
706930	704096	20298U	PARTICIPANT	\N	PRESENT	0
706931	704096	20022R	PARTICIPANT	\N	PRESENT	0
706932	704096	20042V	PARTICIPANT	\N	PRESENT	0
709883	709570	19826F	PARTICIPANT	\N	PRESENT	0
709884	709570	04045F	PARTICIPANT	\N	PRESENT	0
709885	709570	11099A	PARTICIPANT	\N	PRESENT	0
709886	709570	19705W	PARTICIPANT	\N	PRESENT	0
709887	709570	08015R	PARTICIPANT	\N	PRESENT	0
709888	709570	19575F	PARTICIPANT	\N	PRESENT	0
709889	709570	19369B	PARTICIPANT	\N	PRESENT	0
709890	709570	20018V	PARTICIPANT	\N	PRESENT	0
709891	709570	19563B	PARTICIPANT	\N	PRESENT	0
709892	709570	08028W	PARTICIPANT	\N	PRESENT	0
709893	709570	20028X	PARTICIPANT	\N	PRESENT	0
709894	709570	20034V	PARTICIPANT	\N	PRESENT	0
709895	709570	14187A	PARTICIPANT	\N	PRESENT	0
709896	709570	20144B	PARTICIPANT	\N	PRESENT	0
709897	709570	14033T	PARTICIPANT	\N	PRESENT	0
709898	709570	11090Q	PRESIDENT	0	PRESENT	0
709899	709570	14205J	PARTICIPANT	\N	PRESENT	0
709900	709570	20062A	PARTICIPANT	\N	PRESENT	0
709901	709570	20286Q	PARTICIPANT	\N	PRESENT	0
709902	709570	19747H	PARTICIPANT	\N	PRESENT	0
709903	709570	14207L	PARTICIPANT	\N	PRESENT	0
709904	709570	14257W	PARTICIPANT	\N	PRESENT	0
709905	709570	20030R	PARTICIPANT	\N	EXCUSE	0
709907	706248	17779H	PARTICIPANT	\N	PRESENT	0
709908	706248	08045X	PARTICIPANT	\N	PRESENT	0
709909	706248	20266L	PARTICIPANT	\N	PRESENT	0
709910	706248	19760E	PARTICIPANT	\N	PRESENT	0
709911	709906	19768N	PARTICIPANT	\N	PRESENT	0
709912	709906	20088L	PARTICIPANT	\N	PRESENT	0
709913	709906	19515S	PARTICIPANT	\N	PRESENT	0
709914	709906	19782L	PARTICIPANT	\N	PRESENT	0
709915	709906	11077T	PARTICIPANT	\N	PRESENT	0
709916	709906	20092G	PARTICIPANT	\N	PRESENT	0
709917	709906	20078J	PARTICIPANT	\N	PRESENT	0
709918	709906	19413M	PARTICIPANT	\N	PRESENT	0
709919	709906	20082E	PARTICIPANT	\N	PRESENT	0
709920	709906	04045F	PARTICIPANT	\N	PRESENT	0
709921	709906	19866P	PARTICIPANT	\N	PRESENT	0
709922	709906	19631V	PARTICIPANT	\N	PRESENT	0
709923	709906	20104S	PARTICIPANT	\N	PRESENT	0
709924	709906	11099A	PARTICIPANT	\N	PRESENT	0
709925	709906	19705W	PARTICIPANT	\N	PRESENT	0
709926	709906	08015R	PARTICIPANT	\N	PRESENT	0
709927	709906	19575F	PARTICIPANT	\N	PRESENT	0
709928	709906	19369B	PARTICIPANT	\N	PRESENT	0
709929	709906	20018V	PARTICIPANT	\N	PRESENT	0
709930	709906	19563B	PARTICIPANT	\N	PRESENT	0
709931	709906	08028W	PARTICIPANT	\N	PRESENT	0
709932	709906	14037X	PARTICIPANT	\N	PRESENT	0
709933	709906	20028X	PARTICIPANT	\N	PRESENT	0
709934	709906	20034V	PARTICIPANT	\N	PRESENT	0
709935	709906	14187A	PRESIDENT	0	PRESENT	0
709936	709906	20144B	PARTICIPANT	\N	PRESENT	0
709937	709906	14033T	PARTICIPANT	\N	PRESENT	0
709938	709906	14205J	PARTICIPANT	\N	PRESENT	0
709939	709906	20062A	PARTICIPANT	\N	PRESENT	0
709940	709906	14251Q	PARTICIPANT	\N	PRESENT	0
709941	709906	20286Q	PARTICIPANT	\N	PRESENT	0
709942	709906	20298U	PARTICIPANT	\N	PRESENT	0
709943	709906	19747H	PARTICIPANT	\N	PRESENT	0
709944	709906	14207L	PARTICIPANT	\N	PRESENT	0
709945	709906	14257W	PARTICIPANT	\N	PRESENT	0
709946	709906	20030R	PARTICIPANT	\N	EXCUSE	0
709947	709906	11090Q	PARTICIPANT	\N	EXCUSE	0
709949	709948	20058E	PARTICIPANT	\N	PRESENT	1
709950	709948	14109K	PARTICIPANT	\N	PRESENT	1
709952	709951	20076G	PARTICIPANT	\N	PRESENT	0
709953	709951	20054A	PARTICIPANT	\N	PRESENT	0
709954	709951	19826F	PARTICIPANT	\N	PRESENT	0
709955	709951	14205J	PARTICIPANT	\N	PRESENT	0
709956	709951	19820Y	PARTICIPANT	\N	PRESENT	0
709957	709951	14033T	PARTICIPANT	\N	PRESENT	0
709958	709951	19725B	PARTICIPANT	\N	PRESENT	0
709959	709951	19723Y	PARTICIPANT	\N	PRESENT	0
709960	709951	16685X	PARTICIPANT	\N	PRESENT	0
709961	709951	20118Y	PARTICIPANT	\N	PRESENT	0
709962	709951	19719D	PARTICIPANT	\N	PRESENT	1
709963	709951	20140W	PARTICIPANT	\N	PRESENT	1
709964	709951	20090E	PARTICIPANT	\N	PRESENT	1
709966	709965	20076G	PARTICIPANT	\N	PRESENT	0
709967	709965	14205J	PARTICIPANT	\N	PRESENT	0
709968	709965	20054A	PARTICIPANT	\N	PRESENT	0
709969	709965	19826F	PARTICIPANT	\N	PRESENT	0
709970	709965	19725B	PARTICIPANT	\N	PRESENT	0
709971	709965	19723Y	PARTICIPANT	\N	PRESENT	0
709972	709965	16685X	PARTICIPANT	\N	PRESENT	0
709973	709965	20118Y	PARTICIPANT	\N	PRESENT	0
709974	709965	19719D	PARTICIPANT	\N	PRESENT	1
709975	709965	20140W	PARTICIPANT	\N	PRESENT	1
709976	709965	20090E	PARTICIPANT	\N	PRESENT	1
709978	709977	20076G	PARTICIPANT	\N	PRESENT	0
709979	709977	14205J	PARTICIPANT	\N	PRESENT	0
709980	709977	19826F	PARTICIPANT	\N	PRESENT	0
709981	709977	16685X	PARTICIPANT	\N	PRESENT	0
709982	709977	20114U	PARTICIPANT	\N	PRESENT	0
709983	709977	20026V	PARTICIPANT	\N	PRESENT	1
709984	709977	20140W	PARTICIPANT	\N	PRESENT	1
709985	709977	20090E	PARTICIPANT	\N	PRESENT	1
709986	709977	19725B	PARTICIPANT	\N	PRESENT	1
709987	709977	19820Y	PARTICIPANT	\N	PRESENT	1
709988	709977	19719D	PARTICIPANT	\N	PRESENT	1
709990	709989	20076G	PARTICIPANT	\N	PRESENT	0
709991	709989	14205J	PARTICIPANT	\N	PRESENT	0
709992	709989	19826F	PARTICIPANT	\N	PRESENT	0
709993	709989	16685X	PARTICIPANT	\N	PRESENT	0
709994	709989	20142Y	PARTICIPANT	\N	PRESENT	0
709995	709989	19723Y	PARTICIPANT	\N	PRESENT	0
709997	709996	20076G	PARTICIPANT	\N	PRESENT	0
709998	709996	14205J	PARTICIPANT	\N	PRESENT	0
709999	709996	19826F	PARTICIPANT	\N	PRESENT	0
710000	709996	20114U	PARTICIPANT	\N	PRESENT	0
710001	709996	20142Y	PARTICIPANT	\N	PRESENT	0
710002	709996	20026V	PARTICIPANT	\N	PRESENT	1
710003	709996	20090E	PARTICIPANT	\N	PRESENT	0
710004	705126	14331P	PARTICIPANT	\N	PRESENT	0
710005	705126	14237S	PARTICIPANT	\N	PRESENT	0
710006	705126	14089Y	PARTICIPANT	\N	PRESENT	0
710007	705126	11083R	PARTICIPANT	\N	PRESENT	0
710008	705126	14073Q	PARTICIPANT	\N	PRESENT	0
710009	705126	14357A	PARTICIPANT	\N	PRESENT	0
710010	705126	20104S	PARTICIPANT	\N	PRESENT	0
710011	705126	14133K	PARTICIPANT	\N	PRESENT	0
710012	705126	08034U	PARTICIPANT	\N	PRESENT	0
710013	705126	11026G	PARTICIPANT	\N	PRESENT	0
710014	705126	14189C	PARTICIPANT	\N	EXCUSE	0
710015	705126	19701S	PARTICIPANT	\N	EXCUSE	0
710017	710016	19693L	PARTICIPANT	\N	PRESENT	0
710018	705126	20128B	PARTICIPANT	\N	PRESENT	0
710019	705126	04092N	PARTICIPANT	\N	PRESENT	0
710020	705126	16685X	PARTICIPANT	\N	PRESENT	0
710022	710021	19820Y	PARTICIPANT	\N	PRESENT	0
710023	710021	05012A	PRESIDENT	0	PRESENT	0
710024	710021	19768N	PARTICIPANT	\N	PRESENT	0
710025	710021	14237S	PARTICIPANT	\N	PRESENT	0
710026	710021	20128B	PARTICIPANT	\N	PRESENT	0
710028	710021	20914V	PARTICIPANT	\N	EXCUSE	0
710029	710021	20094J	PARTICIPANT	\N	PRESENT	0
710030	708155	86034E	PARTICIPANT	\N	PRESENT	0
710031	705126	20100N	PARTICIPANT	\N	PRESENT	0
710032	705126	19711U	PARTICIPANT	\N	PRESENT	0
710033	710021	19745F	PARTICIPANT	\N	PRESENT	0
710034	708155	19525U	PARTICIPANT	\N	PRESENT	0
710035	708155	14151M	PARTICIPANT	\N	PRESENT	0
710036	708155	20090E	PARTICIPANT	\N	PRESENT	0
710037	708155	19671E	PARTICIPANT	\N	PRESENT	0
710038	708155	19533U	PARTICIPANT	\N	PRESENT	0
710039	708155	08028W	PARTICIPANT	\N	PRESENT	0
710040	708155	95041E	PARTICIPANT	\N	PRESENT	0
710041	708155	04092N	PARTICIPANT	\N	PRESENT	0
710042	708155	19675J	PARTICIPANT	\N	PRESENT	0
710043	708155	08056B	PARTICIPANT	\N	PRESENT	0
710044	708155	14133K	PARTICIPANT	\N	PRESENT	0
710045	708155	20024T	PARTICIPANT	\N	PRESENT	0
710046	708155	14217N	PARTICIPANT	\N	PRESENT	0
710047	708155	11080N	PARTICIPANT	\N	PRESENT	0
710048	708155	19527W	PARTICIPANT	\N	PRESENT	0
710049	708155	12016W	PARTICIPANT	\N	PRESENT	0
710050	708155	14033T	PARTICIPANT	\N	PRESENT	0
710051	708155	20086J	PARTICIPANT	\N	PRESENT	0
710052	708155	20076G	PARTICIPANT	\N	PRESENT	0
710053	708155	14223L	PARTICIPANT	\N	PRESENT	0
688297	686430	11048N	PARTICIPANT	\N	PRESENT	0
688298	686430	19479G	PARTICIPANT	\N	PRESENT	0
688299	686430	01048V	PARTICIPANT	\N	PRESENT	0
688300	686430	19687N	PARTICIPANT	\N	PRESENT	0
688301	686430	01057W	PARTICIPANT	\N	PRESENT	0
688302	686430	20080C	PARTICIPANT	\N	PRESENT	0
688303	686430	14121F	PARTICIPANT	\N	PRESENT	0
688304	686430	20914V	PARTICIPANT	\N	PRESENT	0
688305	686430	14225N	PRESIDENT	0	PRESENT	0
688306	686430	11070L	PARTICIPANT	\N	PRESENT	0
688307	686430	08034U	PARTICIPANT	\N	PRESENT	0
688308	686430	20044X	PARTICIPANT	\N	PRESENT	0
688309	686430	19762G	PARTICIPANT	\N	PRESENT	0
688310	686430	20050V	PARTICIPANT	\N	EXCUSE	0
688311	686430	08011M	PARTICIPANT	\N	PRESENT	0
688312	686706	99004R	PARTICIPANT	\N	PRESENT	0
688313	686430	11012A	PARTICIPANT	\N	PRESENT	0
688314	686706	20044X	PARTICIPANT	\N	PRESENT	0
688315	686706	19667J	PARTICIPANT	\N	PRESENT	0
688316	686706	11048N	PARTICIPANT	\N	PRESENT	0
688317	686706	14225N	PARTICIPANT	\N	PRESENT	0
688318	686706	20024T	PARTICIPANT	\N	PRESENT	0
688319	686706	20080C	PARTICIPANT	\N	PRESENT	0
688320	686706	07029T	PARTICIPANT	\N	PRESENT	0
688321	686706	14121F	PARTICIPANT	\N	PRESENT	0
688322	686706	19762G	PARTICIPANT	\N	PRESENT	0
688323	686706	11040E	PARTICIPANT	\N	PRESENT	0
688324	686706	19747H	PARTICIPANT	\N	PRESENT	0
688325	686706	20100N	PARTICIPANT	\N	PRESENT	0
688326	686706	20090E	PARTICIPANT	\N	PRESENT	0
688327	686706	20914V	PARTICIPANT	\N	PRESENT	0
688328	686706	11070L	PARTICIPANT	\N	PRESENT	0
688329	686706	19687N	PARTICIPANT	\N	PRESENT	0
688330	686706	11012A	PARTICIPANT	\N	PRESENT	0
688331	686706	19479G	PARTICIPANT	\N	PRESENT	0
688332	686706	20132W	PARTICIPANT	\N	PRESENT	0
688333	686706	01057W	PARTICIPANT	\N	PRESENT	0
688334	686706	95063L	PARTICIPANT	\N	PRESENT	0
688335	686706	11083R	PARTICIPANT	\N	PRESENT	0
688336	686706	19719D	PARTICIPANT	\N	PRESENT	0
688337	686706	14217N	PARTICIPANT	\N	PRESENT	0
688338	686706	11064N	PARTICIPANT	\N	PRESENT	0
688339	686706	10015M	PARTICIPANT	\N	PRESENT	0
688340	686706	18083K	PARTICIPANT	\N	PRESENT	0
688341	686706	20098N	PARTICIPANT	\N	PRESENT	0
688342	686706	14021P	PARTICIPANT	\N	PRESENT	0
688343	686706	14133K	PARTICIPANT	\N	PRESENT	0
688344	686706	14033T	PARTICIPANT	\N	PRESENT	0
688345	686706	08034U	PARTICIPANT	\N	PRESENT	0
688346	686706	19543W	PARTICIPANT	\N	PRESENT	0
688347	686706	19347U	PARTICIPANT	\N	PRESENT	0
688348	686706	19683J	PARTICIPANT	\N	PRESENT	0
688349	686706	11067R	PARTICIPANT	\N	PRESENT	0
688350	686706	19441R	PARTICIPANT	\N	PRESENT	0
688351	686706	11053K	PARTICIPANT	\N	PRESENT	0
688352	686706	19333N	PARTICIPANT	\N	PRESENT	0
688353	686706	14357A	PARTICIPANT	\N	PRESENT	0
688354	686706	20034V	PARTICIPANT	\N	PRESENT	0
688355	686706	20048C	PARTICIPANT	\N	PRESENT	0
688383	686706	19735D	PARTICIPANT	\N	PRESENT	0
688384	686706	14083S	PARTICIPANT	\N	PRESENT	0
688385	686706	17023S	PARTICIPANT	\N	PRESENT	0
688579	688578	19709B	PARTICIPANT	\N	PRESENT	0
688580	688578	11026G	PARTICIPANT	\N	PRESENT	0
688585	688581	20026V	PARTICIPANT	\N	PRESENT	0
688586	688581	08012N	PARTICIPANT	\N	PRESENT	0
688591	688590	14001X	PARTICIPANT	\N	PRESENT	0
688593	688592	14001X	PARTICIPANT	\N	PRESENT	0
688594	688592	20074E	PARTICIPANT	\N	PRESENT	0
688605	688603	14033T	PARTICIPANT	\N	PRESENT	0
688606	688603	14257W	PARTICIPANT	\N	PRESENT	0
688608	688607	14033T	PARTICIPANT	\N	PRESENT	0
688609	688607	14257W	PARTICIPANT	\N	PRESENT	0
688611	688610	14033T	PARTICIPANT	\N	PRESENT	0
688612	688610	14257W	PARTICIPANT	\N	PRESENT	0
688614	688613	14033T	PARTICIPANT	\N	PRESENT	0
688615	688613	14257W	PARTICIPANT	\N	PRESENT	0
688617	688616	14033T	PARTICIPANT	\N	PRESENT	0
688618	688616	14257W	PARTICIPANT	\N	PRESENT	0
688754	688745	14053L	PARTICIPANT	\N	EXCUSE	0
688755	688745	14059S	PARTICIPANT	\N	PRESENT	0
688763	688745	20150Y	PARTICIPANT	\N	EXCUSE	0
688766	688765	19723Y	PARTICIPANT	\N	PRESENT	0
688768	688767	14073Q	PARTICIPANT	\N	PRESENT	0
688769	688767	20132W	PARTICIPANT	\N	PRESENT	0
688770	688767	08012N	PARTICIPANT	\N	PRESENT	0
688782	688745	19631V	PARTICIPANT	\N	EXCUSE	0
688783	688745	05008E	PARTICIPANT	\N	EXCUSE	0
688784	688745	19673G	PARTICIPANT	\N	EXCUSE	0
688785	688745	14033T	PARTICIPANT	\N	EXCUSE	0
688786	688745	08034U	PARTICIPANT	\N	EXCUSE	0
688787	688745	20028X	PARTICIPANT	\N	EXCUSE	0
688789	688788	14073Q	PARTICIPANT	\N	PRESENT	0
688790	688788	08012N	PARTICIPANT	\N	PRESENT	0
688791	688788	14229S	PARTICIPANT	\N	PRESENT	0
688792	688788	19651A	PARTICIPANT	\N	PRESENT	0
688793	688788	20132W	PARTICIPANT	\N	PRESENT	0
688799	688745	20148F	PARTICIPANT	\N	EXCUSE	0
688875	688841	14053L	PARTICIPANT	\N	PRESENT	0
688876	688841	14151M	PARTICIPANT	\N	PRESENT	0
688877	688841	19723Y	PARTICIPANT	\N	PRESENT	0
688879	688878	14053L	PARTICIPANT	\N	PRESENT	0
688880	688878	14151M	PARTICIPANT	\N	PRESENT	0
688882	688881	14053L	PARTICIPANT	\N	PRESENT	0
688883	688881	14151M	PARTICIPANT	\N	PRESENT	0
688884	688881	19723Y	PARTICIPANT	\N	PRESENT	0
688887	688885	19723Y	PARTICIPANT	\N	PRESENT	0
688888	688886	19723Y	PARTICIPANT	\N	PRESENT	0
688890	688889	04008A	PARTICIPANT	\N	PRESENT	0
690395	690394	19643A	PARTICIPANT	\N	PRESENT	0
688892	688889	14147R	PARTICIPANT	\N	PRESENT	0
690396	690394	14069U	PARTICIPANT	\N	PRESENT	0
689985	688725	11109J	PARTICIPANT	\N	EXCUSE	0
689986	688725	19651A	PARTICIPANT	\N	PRESENT	0
689987	688725	14030Q	PARTICIPANT	\N	PRESENT	0
689988	688725	20138D	PARTICIPANT	\N	PRESENT	0
689989	688725	20980G	PARTICIPANT	\N	PRESENT	0
689990	688725	19611R	PRESIDENT	0	PRESENT	0
689991	688725	19699S	PARTICIPANT	\N	PRESENT	0
689992	688725	20052X	PARTICIPANT	\N	PRESENT	0
689993	688725	08012N	PARTICIPANT	\N	PRESENT	0
689994	688725	19621T	PARTICIPANT	\N	PRESENT	0
689995	688725	19693L	PARTICIPANT	\N	PRESENT	0
689997	688725	20132W	PARTICIPANT	\N	PRESENT	0
689998	688725	20112S	PARTICIPANT	\N	EXCUSE	0
689999	688725	14123H	PARTICIPANT	\N	PRESENT	0
690000	688725	20172F	PARTICIPANT	\N	EXCUSE	0
690001	688725	11104D	PARTICIPANT	\N	PRESENT	0
690003	688725	19527W	PARTICIPANT	\N	PRESENT	0
690004	688725	20084G	PARTICIPANT	\N	PRESENT	0
690005	688725	11043H	PARTICIPANT	\N	PRESENT	0
690006	688725	14229S	PARTICIPANT	\N	PRESENT	0
690007	688725	19533U	PARTICIPANT	\N	PRESENT	0
690008	688725	20142Y	PARTICIPANT	\N	PRESENT	0
690010	688725	14073Q	PARTICIPANT	\N	PRESENT	0
690011	688725	20180F	PARTICIPANT	\N	PRESENT	0
690012	688725	04059M	PARTICIPANT	\N	EXCUSE	0
690022	690021	19723Y	PARTICIPANT	\N	PRESENT	0
690363	688889	11026G	PARTICIPANT	\N	PRESENT	0
690397	690394	14147R	PARTICIPANT	\N	PRESENT	0
690398	690394	14267Y	PARTICIPANT	\N	PRESENT	0
690399	690394	14193X	PARTICIPANT	\N	PRESENT	0
690400	690394	14083S	PARTICIPANT	\N	PRESENT	0
690403	690402	17737W	PARTICIPANT	\N	PRESENT	0
690407	690402	14259Y	PARTICIPANT	\N	PRESENT	0
691175	690825	14147R	PARTICIPANT	\N	PRESENT	0
691176	690825	19649G	PARTICIPANT	\N	PRESENT	0
691177	690825	11067R	PARTICIPANT	\N	PRESENT	0
691178	690825	20116W	PARTICIPANT	\N	PRESENT	0
691179	690825	11085T	PARTICIPANT	\N	PRESENT	0
691180	690825	14151M	PARTICIPANT	\N	PRESENT	0
691181	690825	14213J	PARTICIPANT	\N	PRESENT	0
691182	690825	01025N	PARTICIPANT	\N	PRESENT	0
691183	690825	11053K	PARTICIPANT	\N	PRESENT	0
691192	690825	20108W	PARTICIPANT	\N	PRESENT	0
691194	690825	20044X	PARTICIPANT	\N	PRESENT	0
691195	690825	14133K	PARTICIPANT	\N	PRESENT	0
691196	690825	11033F	PARTICIPANT	\N	PRESENT	0
691197	690825	19723Y	PARTICIPANT	\N	PRESENT	0
691198	690825	11101A	PARTICIPANT	\N	PRESENT	0
691199	690825	19569H	PARTICIPANT	\N	PRESENT	0
699102	699100	12041X	PARTICIPANT	\N	PRESENT	0
699935	698926	14042U	PARTICIPANT	\N	PRESENT	0
699936	698926	20130U	PARTICIPANT	\N	PRESENT	0
699937	698926	11097X	PARTICIPANT	\N	PRESENT	0
699938	698926	19479G	PARTICIPANT	\N	PRESENT	0
699939	698927	14042U	PARTICIPANT	\N	PRESENT	0
699940	698927	11097X	PARTICIPANT	\N	PRESENT	0
699941	698927	20130U	PARTICIPANT	\N	PRESENT	0
699942	698927	19479G	PARTICIPANT	\N	PRESENT	0
699943	698928	14042U	PARTICIPANT	\N	PRESENT	0
699944	698928	11097X	PARTICIPANT	\N	PRESENT	0
698962	698961	14205J	PARTICIPANT	\N	PRESENT	0
699101	699100	11054L	PARTICIPANT	\N	PRESENT	0
699945	698928	20130U	PARTICIPANT	\N	PRESENT	0
699946	698928	19553Y	PARTICIPANT	\N	PRESENT	0
699947	698928	19479G	PARTICIPANT	\N	PRESENT	0
699948	698929	14042U	PARTICIPANT	\N	PRESENT	0
699949	698929	11097X	PARTICIPANT	\N	PRESENT	0
699950	698929	20130U	PARTICIPANT	\N	PRESENT	0
699951	698929	19479G	PARTICIPANT	\N	PRESENT	0
699952	698930	14042U	PARTICIPANT	\N	PRESENT	0
699953	698930	11097X	PARTICIPANT	\N	PRESENT	0
699954	698930	20130U	PARTICIPANT	\N	PRESENT	0
699955	698930	19479G	PARTICIPANT	\N	PRESENT	0
700324	699145	20086J	PARTICIPANT	\N	PRESENT	0
700325	699145	19621T	PARTICIPANT	\N	PRESENT	0
700326	699145	12028B	PARTICIPANT	\N	PRESENT	0
700327	699145	20038A	PARTICIPANT	\N	PRESENT	0
700328	699145	20106U	PARTICIPANT	\N	PRESENT	0
700329	699145	19685L	PARTICIPANT	\N	PRESENT	0
700330	699145	19335Q	PRESIDENT	1	PRESENT	0
700331	699145	19739H	PRESIDENT	0	PRESENT	0
700332	699145	20152B	PARTICIPANT	\N	PRESENT	0
700333	699145	20264J	PARTICIPANT	\N	PRESENT	0
700338	699145	19691J	PARTICIPANT	\N	EXCUSE	0
700339	699145	14109K	PARTICIPANT	\N	EXCUSE	0
700340	699145	19758L	PARTICIPANT	\N	EXCUSE	0
700341	699145	20132W	PARTICIPANT	\N	EXCUSE	0
700343	700342	19701S	PARTICIPANT	\N	PRESENT	0
700344	700342	19762G	PARTICIPANT	\N	PRESENT	0
700345	700342	04092N	PARTICIPANT	\N	PRESENT	0
700346	700342	19671E	PARTICIPANT	\N	PRESENT	0
700347	700342	11026G	PARTICIPANT	\N	PRESENT	0
700348	700342	04035D	PARTICIPANT	\N	PRESENT	0
700349	700342	20064C	PARTICIPANT	\N	PRESENT	0
700382	692496	19631V	PARTICIPANT	\N	EXCUSE	0
700383	692496	19715Y	PARTICIPANT	\N	PRESENT	0
700384	692496	19717B	PARTICIPANT	\N	PRESENT	1
700385	698900	19631V	PARTICIPANT	\N	EXCUSE	0
700554	692496	19657G	PARTICIPANT	\N	EXCUSE	0
700555	698900	19657G	PARTICIPANT	\N	EXCUSE	0
700571	698943	20128B	PARTICIPANT	\N	PRESENT	0
700675	698941	14255U	PARTICIPANT	\N	PRESENT	0
700678	698941	17023S	PARTICIPANT	\N	PRESENT	0
700681	698941	19709B	PARTICIPANT	\N	PRESENT	0
700683	698941	14193X	PARTICIPANT	\N	PRESENT	0
700767	700747	19335Q	PARTICIPANT	\N	PRESENT	0
700769	700747	20106U	PARTICIPANT	\N	PRESENT	0
700770	700747	20980G	PARTICIPANT	\N	PRESENT	0
700771	700747	20038A	PARTICIPANT	\N	PRESENT	0
700779	700747	19685L	PARTICIPANT	\N	PRESENT	0
700782	700747	14109K	PARTICIPANT	\N	PRESENT	1
700783	700747	19691J	PARTICIPANT	\N	PRESENT	1
700784	700747	20264J	PARTICIPANT	\N	PRESENT	1
701105	701103	19503N	PARTICIPANT	\N	PRESENT	0
701135	699133	19549D	PARTICIPANT	\N	PRESENT	0
701136	699133	20090E	PARTICIPANT	\N	PRESENT	0
701137	699133	11101A	PARTICIPANT	\N	PRESENT	0
701138	699133	18083K	PARTICIPANT	\N	PRESENT	0
701139	699133	19701S	PARTICIPANT	\N	PRESENT	0
701140	699133	19681G	PARTICIPANT	\N	PRESENT	0
701141	699133	19525U	PARTICIPANT	\N	PRESENT	0
701143	699133	20124W	PARTICIPANT	\N	PRESENT	0
701144	699133	14187A	PRESIDENT	0	PRESENT	0
701145	699133	17023S	PARTICIPANT	\N	PRESENT	0
701146	699133	19347U	PARTICIPANT	\N	PRESENT	0
701147	699133	14221J	PARTICIPANT	\N	PRESENT	0
701148	699133	20018V	PARTICIPANT	\N	PRESENT	0
701149	699133	20298U	PARTICIPANT	\N	PRESENT	0
701150	699133	20062A	PARTICIPANT	\N	PRESENT	0
701512	692496	20034V	PARTICIPANT	\N	EXCUSE	0
701516	698900	19717B	PRESIDENT	0	PRESENT	1
701517	698900	18083K	PARTICIPANT	\N	PRESENT	0
701518	698900	19295A	PARTICIPANT	\N	PRESENT	0
701519	698900	20034V	PARTICIPANT	\N	PRESENT	0
701520	698900	19715Y	PARTICIPANT	\N	PRESENT	0
701521	698900	14147R	PARTICIPANT	\N	EXCUSE	0
701522	698900	20146D	PARTICIPANT	\N	PRESENT	0
701523	692496	19295A	PARTICIPANT	\N	EXCUSE	0
701524	692496	18083K	PARTICIPANT	\N	EXCUSE	0
701527	698900	19577H	PARTICIPANT	\N	PRESENT	1
701632	701630	14231L	PARTICIPANT	\N	PRESENT	0
701633	701630	14259Y	PARTICIPANT	\N	PRESENT	0
701634	701630	20044X	PARTICIPANT	\N	PRESENT	0
701636	701635	08009T	PARTICIPANT	\N	PRESENT	0
701638	701637	14253S	PARTICIPANT	\N	PRESENT	0
701655	701654	19479G	PARTICIPANT	\N	PRESENT	0
701660	701659	19479G	PARTICIPANT	\N	PRESENT	0
701662	701661	19479G	PARTICIPANT	\N	PRESENT	0
701664	701663	19479G	PARTICIPANT	\N	PRESENT	0
701666	701665	19479G	PARTICIPANT	\N	PRESENT	0
701668	701667	19479G	PARTICIPANT	\N	PRESENT	0
701690	701689	14267Y	PARTICIPANT	\N	PRESENT	0
701691	701689	07033P	PARTICIPANT	\N	PRESENT	0
701692	701689	14133K	PARTICIPANT	\N	PRESENT	0
701693	701689	11054L	PARTICIPANT	\N	PRESENT	0
701694	701689	20042V	PARTICIPANT	\N	PRESENT	0
701695	701689	12028B	PARTICIPANT	\N	PRESENT	0
701696	701689	08056B	PARTICIPANT	\N	PRESENT	0
701698	701697	14267Y	PARTICIPANT	\N	PRESENT	0
701699	701697	07033P	PARTICIPANT	\N	PRESENT	0
701700	701697	14133K	PARTICIPANT	\N	PRESENT	0
701701	701697	11054L	PARTICIPANT	\N	PRESENT	0
701702	701697	20042V	PARTICIPANT	\N	PRESENT	0
701703	701697	08056B	PARTICIPANT	\N	PRESENT	0
701704	701697	14249W	PARTICIPANT	\N	PRESENT	0
701706	701705	19565D	PARTICIPANT	\N	PRESENT	0
701707	701705	14267Y	PARTICIPANT	\N	PRESENT	0
701709	701708	20112S	PARTICIPANT	\N	PRESENT	1
701710	701708	19643A	PARTICIPANT	\N	PRESENT	1
701711	701708	19735D	PARTICIPANT	\N	PRESENT	1
701712	701708	19693L	PARTICIPANT	\N	PRESENT	1
701713	701599	11067R	PARTICIPANT	\N	EXCUSE	0
701714	701600	11067R	PARTICIPANT	\N	EXCUSE	0
701716	701715	20132W	PARTICIPANT	\N	PRESENT	0
701718	701717	20132W	PARTICIPANT	\N	PRESENT	0
701719	701717	14229S	PARTICIPANT	\N	PRESENT	0
701721	701720	20132W	PARTICIPANT	\N	PRESENT	0
701723	701722	20132W	PARTICIPANT	\N	PRESENT	0
701725	701720	14229S	PARTICIPANT	\N	PRESENT	0
701893	701534	19697Q	PARTICIPANT	\N	PRESENT	0
701894	701534	14026U	PARTICIPANT	\N	PRESENT	0
701895	701534	19723Y	PARTICIPANT	\N	PRESENT	0
701896	701534	20248J	PARTICIPANT	\N	PRESENT	0
701897	701534	20066E	PARTICIPANT	\N	PRESENT	0
701898	701534	20266L	PARTICIPANT	\N	PRESENT	0
701899	701534	14195A	PARTICIPANT	\N	PRESENT	0
692234	692233	14147R	PARTICIPANT	\N	PRESENT	0
692235	692233	01057W	PARTICIPANT	\N	PRESENT	0
692236	692233	11074Q	PARTICIPANT	\N	PRESENT	0
692237	692233	20064C	PARTICIPANT	\N	PRESENT	0
698981	698980	11064N	PARTICIPANT	\N	PRESENT	0
698982	692358	19415P	PARTICIPANT	\N	PRESENT	0
706933	704096	11048N	PARTICIPANT	\N	PRESENT	0
706934	704096	19691J	PARTICIPANT	\N	PRESENT	0
706935	704096	19703U	PARTICIPANT	\N	PRESENT	0
706936	704096	19569H	PARTICIPANT	\N	PRESENT	0
706937	704096	14217N	PARTICIPANT	\N	PRESENT	0
706938	704096	14215L	PARTICIPANT	\N	PRESENT	0
706939	704096	20134Y	PARTICIPANT	\N	PRESENT	0
706940	704096	19621T	PARTICIPANT	\N	PRESENT	0
706941	704096	14213J	PARTICIPANT	\N	PRESENT	0
706942	704096	19647E	PARTICIPANT	\N	PRESENT	0
706943	704096	20032T	PARTICIPANT	\N	PRESENT	0
706944	704096	17965H	PARTICIPANT	\N	PRESENT	0
706945	704096	20096L	PARTICIPANT	\N	PRESENT	0
706946	704096	20056C	PARTICIPANT	\N	PRESENT	0
706947	704096	20080C	PARTICIPANT	\N	PRESENT	0
706948	704096	19399H	PARTICIPANT	\N	PRESENT	0
706949	704096	20094J	PARTICIPANT	\N	PRESENT	0
706950	704096	19507S	PARTICIPANT	\N	PRESENT	0
706951	704096	19503N	PARTICIPANT	\N	PRESENT	0
706952	704096	19723Y	PARTICIPANT	\N	PRESENT	0
706953	704096	18193Q	PARTICIPANT	\N	PRESENT	0
706954	704096	19367Y	PARTICIPANT	\N	PRESENT	0
706955	704096	19581D	PARTICIPANT	\N	PRESENT	0
706956	704096	14207L	PARTICIPANT	\N	PRESENT	0
706957	704096	19671E	PARTICIPANT	\N	PRESENT	0
706958	704096	14195A	PARTICIPANT	\N	PRESENT	0
706959	704096	11097X	PARTICIPANT	\N	PRESENT	0
706960	704096	11070L	PARTICIPANT	\N	PRESENT	0
706961	704096	20020P	PARTICIPANT	\N	PRESENT	0
706962	704096	19762G	PARTICIPANT	\N	PRESENT	0
706963	704096	19383Y	PARTICIPANT	\N	PRESENT	0
706964	704096	01058X	PARTICIPANT	\N	PRESENT	0
706965	704096	19697Q	PARTICIPANT	\N	PRESENT	0
706966	704096	20062A	PARTICIPANT	\N	PRESENT	0
706967	704096	10006L	PARTICIPANT	\N	PRESENT	0
706968	704096	14042U	PARTICIPANT	\N	PRESENT	0
706969	704096	19954N	PARTICIPANT	\N	PRESENT	0
706970	704096	11043H	PARTICIPANT	\N	PRESENT	0
706971	704096	04033B	PARTICIPANT	\N	PRESENT	0
706972	704096	04043D	PARTICIPANT	\N	PRESENT	0
706973	704096	20264J	PARTICIPANT	\N	PRESENT	0
706974	704096	19701S	PARTICIPANT	\N	PRESENT	0
706975	704096	19798U	PARTICIPANT	\N	PRESENT	0
706976	704096	14257W	PARTICIPANT	\N	PRESENT	0
706977	704096	14329V	PARTICIPANT	\N	PRESENT	0
706978	704096	19687N	PARTICIPANT	\N	PRESENT	0
706979	704096	19631V	PARTICIPANT	\N	PRESENT	0
706980	704096	19515S	PARTICIPANT	\N	PRESENT	0
706981	704096	19387D	PARTICIPANT	\N	PRESENT	0
706982	704096	14073Q	PARTICIPANT	\N	PRESENT	0
706983	704096	20066E	PARTICIPANT	\N	PRESENT	0
706984	704096	95041E	PARTICIPANT	\N	PRESENT	0
706985	704096	19533U	PARTICIPANT	\N	PRESENT	0
706986	704096	20148F	PARTICIPANT	\N	PRESENT	0
706987	704096	04008A	PARTICIPANT	\N	PRESENT	0
706988	704096	19531S	PARTICIPANT	\N	PRESENT	0
706989	704096	19369B	PARTICIPANT	\N	PRESENT	0
706990	704096	20086J	PARTICIPANT	\N	PRESENT	0
706991	704096	20082E	PARTICIPANT	\N	PRESENT	0
706992	704096	19599P	PARTICIPANT	\N	PRESENT	0
706993	704096	14189C	PARTICIPANT	\N	PRESENT	0
706994	704096	20116W	PARTICIPANT	\N	PRESENT	0
706995	704096	01048V	PARTICIPANT	\N	PRESENT	0
706996	704096	19551W	PARTICIPANT	\N	PRESENT	0
706997	704096	19643A	PARTICIPANT	\N	PRESENT	0
706998	704096	19673G	PARTICIPANT	\N	PRESENT	0
706999	704096	14026U	PARTICIPANT	\N	PRESENT	0
707000	704096	14069U	PARTICIPANT	\N	PRESENT	0
707001	704096	08015R	PARTICIPANT	\N	PRESENT	0
707002	704096	20100N	PARTICIPANT	\N	PRESENT	0
707003	704096	17637T	PARTICIPANT	\N	PRESENT	0
707004	704096	19667J	PARTICIPANT	\N	PRESENT	0
707005	704096	01034P	PARTICIPANT	\N	PRESENT	0
707006	704096	08018U	PARTICIPANT	\N	PRESENT	0
707007	704096	11056N	PARTICIPANT	\N	PRESENT	0
707008	704096	14331P	PARTICIPANT	\N	PRESENT	0
707009	704096	20044X	PARTICIPANT	\N	PRESENT	0
707010	704096	20122U	PARTICIPANT	\N	PRESENT	0
707011	704096	19591F	PARTICIPANT	\N	PRESENT	0
707012	704096	20052X	PARTICIPANT	\N	PRESENT	0
707013	704096	19745F	PARTICIPANT	\N	PRESENT	0
707014	704096	19421M	PARTICIPANT	\N	PRESENT	0
707015	704096	19649G	PARTICIPANT	\N	PRESENT	0
707016	704096	98022P	PARTICIPANT	\N	PRESENT	0
707017	704096	20152B	PARTICIPANT	\N	PRESENT	0
707018	704096	17737W	PARTICIPANT	\N	PRESENT	0
707019	704096	19669L	PARTICIPANT	\N	PRESENT	0
707020	704096	01024M	PARTICIPANT	\N	PRESENT	0
707021	704096	08073C	PARTICIPANT	\N	PRESENT	0
707022	704096	14037X	PARTICIPANT	\N	PRESENT	0
707023	704096	11110B	PARTICIPANT	\N	PRESENT	0
707024	704096	20058E	PARTICIPANT	\N	PRESENT	0
707025	704097	99004R	PARTICIPANT	\N	PRESENT	0
707026	704097	19695N	PARTICIPANT	\N	PRESENT	0
707027	704097	12041X	PARTICIPANT	\N	PRESENT	0
707030	704097	19758L	PARTICIPANT	\N	PRESENT	0
707032	704097	20130U	PARTICIPANT	\N	PRESENT	0
707033	704097	20914V	PARTICIPANT	\N	PRESENT	0
707034	704097	11026G	PARTICIPANT	\N	PRESENT	0
707035	704097	14281W	PARTICIPANT	\N	PRESENT	0
707038	704097	07029T	PARTICIPANT	\N	PRESENT	0
707040	704097	14223L	PARTICIPANT	\N	PRESENT	0
707041	704097	04092N	PARTICIPANT	\N	PRESENT	0
707042	704097	19347U	PARTICIPANT	\N	PRESENT	0
707043	704097	14225N	PARTICIPANT	\N	PRESENT	0
707044	704097	20074E	PARTICIPANT	\N	PRESENT	0
707045	704097	08045X	PARTICIPANT	\N	PRESENT	0
707046	704097	19679N	PARTICIPANT	\N	PRESENT	0
707048	704097	19766L	PARTICIPANT	\N	PRESENT	0
707049	704097	14001X	PARTICIPANT	\N	PRESENT	0
707053	704097	19715Y	PARTICIPANT	\N	PRESENT	0
707054	704097	11031D	PARTICIPANT	\N	PRESENT	0
707055	704097	19760E	PARTICIPANT	\N	PRESENT	0
707056	704097	14133K	PARTICIPANT	\N	PRESENT	0
707057	704097	05008E	PARTICIPANT	\N	PRESENT	0
707059	704097	14083S	PARTICIPANT	\N	PRESENT	0
707060	704097	20040T	PARTICIPANT	\N	PRESENT	0
707062	704097	20022R	PARTICIPANT	\N	PRESENT	0
707063	704097	11048N	PARTICIPANT	\N	PRESENT	0
707064	704097	19691J	PARTICIPANT	\N	PRESENT	0
707065	704097	19703U	PARTICIPANT	\N	PRESENT	0
707066	704097	14217N	PARTICIPANT	\N	PRESENT	0
707067	704097	14215L	PARTICIPANT	\N	PRESENT	0
707068	704097	20134Y	PARTICIPANT	\N	PRESENT	0
707069	704097	19621T	PARTICIPANT	\N	PRESENT	0
707070	704097	14213J	PARTICIPANT	\N	PRESENT	0
707072	704097	20032T	PARTICIPANT	\N	PRESENT	0
707074	704097	20056C	PARTICIPANT	\N	PRESENT	0
707075	704097	20080C	PARTICIPANT	\N	PRESENT	0
707076	704097	19399H	PARTICIPANT	\N	PRESENT	0
707077	704097	20094J	PARTICIPANT	\N	PRESENT	0
707079	704097	19503N	PARTICIPANT	\N	PRESENT	0
707081	704097	18193Q	PARTICIPANT	\N	PRESENT	0
707083	704097	14207L	PARTICIPANT	\N	PRESENT	0
707084	704097	19671E	PARTICIPANT	\N	PRESENT	0
707086	704097	11097X	PARTICIPANT	\N	PRESENT	0
710054	708155	20108W	PARTICIPANT	\N	PRESENT	0
710055	708155	08047A	PARTICIPANT	\N	PRESENT	0
710056	708155	14031R	PARTICIPANT	\N	PRESENT	0
710057	708155	20078J	PARTICIPANT	\N	PRESENT	0
710058	708155	14229S	PARTICIPANT	\N	PRESENT	0
710059	708155	11054L	PARTICIPANT	\N	PRESENT	0
710060	708155	18193Q	PARTICIPANT	\N	PRESENT	0
710061	708155	19295A	PARTICIPANT	\N	PRESENT	0
710062	708155	19782L	PARTICIPANT	\N	PRESENT	0
710063	708155	14111D	PARTICIPANT	\N	PRESENT	0
710064	708155	14221J	PARTICIPANT	\N	PRESENT	0
710065	708155	14109K	PARTICIPANT	\N	PRESENT	0
710066	708155	01062T	PARTICIPANT	\N	PRESENT	0
710067	708155	17589D	PARTICIPANT	\N	PRESENT	0
710068	708155	14211G	PARTICIPANT	\N	PRESENT	0
710069	708155	19866P	PARTICIPANT	\N	PRESENT	0
710070	708155	14107H	PARTICIPANT	\N	PRESENT	0
710071	708155	19629C	PARTICIPANT	\N	PRESENT	0
710072	708155	04045F	PARTICIPANT	\N	PRESENT	0
710073	708155	11066Q	PARTICIPANT	\N	PRESENT	0
710074	708155	08060W	PARTICIPANT	\N	PRESENT	0
710075	708155	11104D	PARTICIPANT	\N	PRESENT	0
710076	708155	11027H	PARTICIPANT	\N	PRESENT	0
710077	708155	14281W	PARTICIPANT	\N	PRESENT	0
710078	708155	19599P	PARTICIPANT	\N	PRESENT	0
710079	708155	20088L	PARTICIPANT	\N	PRESENT	0
710080	708155	20064C	PARTICIPANT	\N	PRESENT	0
710081	708155	14021P	PARTICIPANT	\N	PRESENT	0
710082	708155	19333N	PARTICIPANT	\N	PRESENT	0
710083	708155	20082E	PARTICIPANT	\N	PRESENT	0
710084	708155	11045K	PARTICIPANT	\N	PRESENT	0
710085	708155	19621T	PARTICIPANT	\N	PRESENT	0
710086	708155	19711U	PARTICIPANT	\N	PRESENT	0
710087	708155	01058X	PARTICIPANT	\N	PRESENT	0
710088	708155	19693L	PARTICIPANT	\N	PRESENT	0
710089	708155	04035D	PARTICIPANT	\N	PRESENT	0
710090	708155	99004R	PARTICIPANT	\N	PRESENT	0
710091	708155	08010L	PARTICIPANT	\N	PRESENT	0
710092	708155	14123H	PARTICIPANT	\N	PRESENT	0
710093	708155	19703U	PARTICIPANT	\N	PRESENT	0
710094	708155	17637T	PARTICIPANT	\N	PRESENT	0
710095	708155	19575F	PARTICIPANT	\N	PRESENT	0
710096	708155	04047H	PARTICIPANT	\N	PRESENT	0
710097	708155	14026U	PARTICIPANT	\N	PRESENT	0
710098	708155	19747H	PARTICIPANT	\N	PRESENT	0
710099	708155	08034U	PARTICIPANT	\N	PRESENT	0
710100	708155	04042C	PARTICIPANT	\N	PRESENT	0
710101	708155	20074E	PARTICIPANT	\N	PRESENT	0
710102	708155	17367Q	PARTICIPANT	\N	PRESENT	0
710103	708155	19643A	PARTICIPANT	\N	PRESENT	0
710104	708155	10015M	PARTICIPANT	\N	PRESENT	0
710105	708155	11043H	PARTICIPANT	\N	PRESENT	0
710106	708155	04033B	PARTICIPANT	\N	PRESENT	0
710107	708155	14071N	PARTICIPANT	\N	PRESENT	0
710108	708155	05008E	PARTICIPANT	\N	PRESENT	0
710109	708155	19415P	PARTICIPANT	\N	PRESENT	0
710110	708155	14215L	PARTICIPANT	\N	PRESENT	0
710111	708155	14053L	PARTICIPANT	\N	PRESENT	0
710112	708155	14069U	PARTICIPANT	\N	PRESENT	0
710113	708155	19701S	PARTICIPANT	\N	PRESENT	0
710114	708155	05012A	PARTICIPANT	\N	PRESENT	0
710115	708155	14259Y	PARTICIPANT	\N	PRESENT	0
710116	708155	19515S	PARTICIPANT	\N	PRESENT	0
710117	708155	20038A	PARTICIPANT	\N	PRESENT	0
710118	708155	19673G	PARTICIPANT	\N	PRESENT	0
710119	708155	14253S	PARTICIPANT	\N	PRESENT	0
710120	708155	17737W	PARTICIPANT	\N	PRESENT	0
710121	708155	20032T	PARTICIPANT	\N	PRESENT	0
710122	708155	20136B	PARTICIPANT	\N	PRESENT	0
710123	708155	14331P	PARTICIPANT	\N	PRESENT	0
710124	708155	19760E	PARTICIPANT	\N	PRESENT	0
710125	708155	20112S	PARTICIPANT	\N	PRESENT	0
710127	708155	19695N	PARTICIPANT	\N	PRESENT	0
710128	708155	10006L	PARTICIPANT	\N	PRESENT	0
710129	708155	20102Q	PARTICIPANT	\N	PRESENT	0
710130	708155	12041X	PARTICIPANT	\N	PRESENT	0
710131	708155	19798U	PARTICIPANT	\N	PRESENT	0
710132	708155	19687N	PARTICIPANT	\N	PRESENT	0
710133	708155	20046A	PARTICIPANT	\N	PRESENT	0
710134	708155	14237S	PARTICIPANT	\N	PRESENT	0
710135	708155	11031D	PARTICIPANT	\N	PRESENT	0
710136	708155	11040E	PARTICIPANT	\N	PRESENT	0
710138	708155	19421M	PARTICIPANT	\N	PRESENT	0
710139	708155	11077T	PARTICIPANT	\N	PRESENT	0
710140	708155	11056N	PARTICIPANT	\N	PRESENT	0
710141	708155	04085P	PARTICIPANT	\N	PRESENT	0
710142	708155	19593H	PARTICIPANT	\N	PRESENT	0
710143	708155	19758L	PARTICIPANT	\N	PRESENT	0
710144	708155	20252E	PARTICIPANT	\N	PRESENT	0
710145	708155	20110Q	PARTICIPANT	\N	PRESENT	0
710146	708155	20914V	PARTICIPANT	\N	PRESENT	0
710147	708155	20120S	PARTICIPANT	\N	PRESENT	0
710148	708155	11065P	PARTICIPANT	\N	PRESENT	0
710149	708155	20134Y	PARTICIPANT	\N	PRESENT	0
710150	708155	20100N	PARTICIPANT	\N	PRESENT	0
710151	708155	19347U	PARTICIPANT	\N	PRESENT	0
710152	708155	11099A	PARTICIPANT	\N	PRESENT	0
710153	708155	11115U	PARTICIPANT	\N	PRESENT	0
710154	708155	20142Y	PARTICIPANT	\N	PRESENT	0
710155	708155	07033P	PARTICIPANT	\N	PRESENT	0
710156	708155	97011G	PARTICIPANT	\N	PRESENT	0
710157	708155	20130U	PARTICIPANT	\N	PRESENT	0
710158	708155	20092G	PARTICIPANT	\N	PRESENT	0
710159	708155	14147R	PARTICIPANT	\N	PRESENT	0
710160	708155	20266L	PARTICIPANT	\N	PRESENT	0
710161	708155	19651A	PARTICIPANT	\N	PRESENT	0
710162	708155	19057M	PARTICIPANT	\N	PRESENT	0
710163	708155	20138D	PARTICIPANT	\N	PRESENT	0
710164	708155	19659J	PARTICIPANT	\N	PRESENT	0
710165	708155	14249W	PARTICIPANT	\N	PRESENT	0
710166	708155	11083R	PARTICIPANT	\N	PRESENT	0
710167	708155	19329S	PARTICIPANT	\N	PRESENT	0
710168	708155	20106U	PARTICIPANT	\N	PRESENT	0
710169	708155	20140W	PARTICIPANT	\N	PRESENT	0
710170	708155	20128B	PARTICIPANT	\N	PRESENT	0
710171	708155	19591F	PARTICIPANT	\N	PRESENT	0
710172	708155	20026V	PARTICIPANT	\N	PRESENT	0
710173	708155	14037X	PARTICIPANT	\N	PRESENT	0
710174	708155	20180F	PARTICIPANT	\N	PRESENT	0
710175	708155	19697Q	PARTICIPANT	\N	PRESENT	0
710176	708155	20096L	PARTICIPANT	\N	PRESENT	0
710177	708155	11072N	PARTICIPANT	\N	PRESENT	0
710178	708155	08073C	PARTICIPANT	\N	PRESENT	0
710179	708155	20980G	PARTICIPANT	\N	PRESENT	0
710180	708155	20146D	PARTICIPANT	\N	PRESENT	0
710181	708155	19573D	PARTICIPANT	\N	PRESENT	0
710182	708155	19447X	PARTICIPANT	\N	PRESENT	0
710183	708155	14055N	PARTICIPANT	\N	PRESENT	0
710184	708155	14038Y	PARTICIPANT	\N	PRESENT	0
710185	708155	11033F	PARTICIPANT	\N	PRESENT	0
710186	708155	19723Y	PARTICIPANT	\N	PRESENT	0
710187	708155	20034V	PARTICIPANT	\N	PRESENT	0
710188	708155	20056C	PARTICIPANT	\N	PRESENT	0
710189	708155	20098N	PARTICIPANT	\N	PRESENT	0
710190	708155	14207L	PARTICIPANT	\N	PRESENT	0
710191	708155	19399H	PARTICIPANT	\N	PRESENT	0
710192	708155	19681G	PARTICIPANT	\N	PRESENT	0
710193	708155	19719D	PARTICIPANT	\N	PRESENT	0
710194	708155	20132W	PARTICIPANT	\N	PRESENT	0
710195	708155	19387D	PARTICIPANT	\N	PRESENT	0
710196	708155	20104S	PARTICIPANT	\N	PRESENT	0
710197	708155	19553Y	PARTICIPANT	\N	PRESENT	0
710198	708155	20072C	PARTICIPANT	\N	PRESENT	0
710199	708155	11012A	PARTICIPANT	\N	PRESENT	0
710200	708155	19545Y	PARTICIPANT	\N	PRESENT	0
710201	708155	14213J	PARTICIPANT	\N	PRESENT	0
710202	708155	14195A	PARTICIPANT	\N	PRESENT	0
710203	708155	14357A	PARTICIPANT	\N	PRESENT	0
710204	708155	19762G	PARTICIPANT	\N	PRESENT	0
710205	708155	14251Q	PARTICIPANT	\N	PRESENT	0
710206	708155	20020P	PARTICIPANT	\N	PRESENT	0
710207	708155	04057K	PARTICIPANT	\N	PRESENT	0
710208	708155	19563B	PARTICIPANT	\N	PRESENT	0
710210	708155	20152B	PARTICIPANT	\N	PRESENT	0
710211	708155	19581D	PARTICIPANT	\N	PRESENT	0
710212	708155	19585H	PARTICIPANT	\N	PRESENT	0
710213	708155	08069G	PARTICIPANT	\N	PRESENT	0
710214	708155	19367Y	PARTICIPANT	\N	PRESENT	0
683971	683055	20114U	PARTICIPANT	\N	EXCUSE	0
683973	683055	19729F	PARTICIPANT	\N	EXCUSE	0
685016	685015	20032T	PARTICIPANT	\N	PRESENT	0
685017	685015	05008E	PARTICIPANT	\N	PRESENT	0
685018	685015	19549D	PARTICIPANT	\N	PRESENT	0
685019	685015	20116W	PARTICIPANT	\N	PRESENT	0
685020	685015	20086J	PARTICIPANT	\N	PRESENT	0
685021	685015	19383Y	PARTICIPANT	\N	PRESENT	0
685022	685015	19545Y	PARTICIPANT	\N	PRESENT	0
685023	685015	11056N	PARTICIPANT	\N	PRESENT	0
685024	685015	14259Y	PARTICIPANT	\N	PRESENT	0
685025	685015	11110B	PARTICIPANT	\N	PRESENT	0
685026	685015	14231L	PARTICIPANT	\N	PRESENT	0
685027	685015	19349W	PARTICIPANT	\N	PRESENT	0
685028	685015	20082E	PARTICIPANT	\N	PRESENT	0
685029	685015	01043Q	PARTICIPANT	\N	PRESENT	0
685030	685015	14205J	PARTICIPANT	\N	PRESENT	0
686229	686228	20032T	PARTICIPANT	\N	PRESENT	0
686230	686228	19549D	PARTICIPANT	\N	PRESENT	0
686231	686228	20086J	PARTICIPANT	\N	PRESENT	0
686232	686228	19545Y	PARTICIPANT	\N	PRESENT	0
686233	686228	11056N	PARTICIPANT	\N	PRESENT	0
686235	686228	11110B	PARTICIPANT	\N	PRESENT	0
686236	686228	19489J	PARTICIPANT	\N	PRESENT	0
686237	686228	01043Q	PARTICIPANT	\N	PRESENT	0
686238	686228	14205J	PARTICIPANT	\N	PRESENT	0
686239	686228	14219Q	PARTICIPANT	\N	PRESENT	0
686240	686228	20082E	PARTICIPANT	\N	PRESENT	0
686290	674946	19631V	PARTICIPANT	\N	PRESENT	0
686294	674946	20034V	PARTICIPANT	\N	PRESENT	0
686292	674946	19659J	PARTICIPANT	\N	PRESENT	0
686293	674946	19577H	PARTICIPANT	\N	PRESENT	0
686295	674946	19715Y	PARTICIPANT	\N	EXCUSE	0
686296	674946	14097Y	PARTICIPANT	\N	PRESENT	0
686297	674946	20016T	PARTICIPANT	\N	PRESENT	0
686298	674946	14059S	PARTICIPANT	\N	EXCUSE	0
686299	674946	12016W	PARTICIPANT	\N	EXCUSE	0
686300	674946	19657G	PARTICIPANT	\N	PRESENT	0
686301	674946	20148F	PARTICIPANT	\N	PRESENT	0
686302	674946	19701S	PARTICIPANT	\N	PRESENT	0
688528	688526	14133K	PARTICIPANT	\N	PRESENT	0
688529	688526	04085P	PARTICIPANT	\N	PRESENT	0
688530	688526	04047H	PARTICIPANT	\N	PRESENT	0
688531	688526	11053K	PARTICIPANT	\N	PRESENT	0
688532	688526	19719D	PARTICIPANT	\N	PRESENT	0
688533	688526	10006L	PARTICIPANT	\N	PRESENT	0
688534	688526	14042U	PARTICIPANT	\N	PRESENT	0
688535	688526	19347U	PARTICIPANT	\N	PRESENT	0
688536	688526	14026U	PARTICIPANT	\N	PRESENT	0
688537	688526	11048N	PARTICIPANT	\N	PRESENT	0
688538	688526	14021P	PARTICIPANT	\N	PRESENT	0
688539	688526	99004R	PARTICIPANT	\N	PRESENT	0
688540	688526	19611R	PARTICIPANT	\N	PRESENT	0
688541	688526	20090E	PARTICIPANT	\N	PRESENT	0
688542	688526	14219Q	PARTICIPANT	\N	PRESENT	0
688543	688526	14251Q	PARTICIPANT	\N	PRESENT	0
688544	688526	11085T	PARTICIPANT	\N	PRESENT	0
688545	688526	14071N	PARTICIPANT	\N	PRESENT	0
688546	688526	11090Q	PARTICIPANT	\N	PRESENT	0
688547	688526	14331P	PARTICIPANT	\N	PRESENT	0
688548	688526	14225N	PARTICIPANT	\N	PRESENT	0
688549	688526	11012A	PARTICIPANT	\N	PRESENT	0
688550	688526	95063L	PARTICIPANT	\N	PRESENT	0
688551	688526	11045K	PARTICIPANT	\N	PRESENT	0
688553	688552	17229F	PARTICIPANT	\N	PRESENT	0
688554	688552	14151M	PARTICIPANT	\N	PRESENT	0
688555	688552	14037X	PARTICIPANT	\N	PRESENT	0
688556	688552	20252E	PARTICIPANT	\N	PRESENT	0
688557	688552	08010L	PARTICIPANT	\N	PRESENT	0
688559	688558	11067R	PARTICIPANT	\N	PRESENT	0
688561	688560	08010L	PARTICIPANT	\N	PRESENT	0
688655	688654	19575F	PARTICIPANT	\N	PRESENT	0
688727	688726	10006L	PARTICIPANT	\N	PRESENT	0
691201	690825	14107H	PARTICIPANT	\N	PRESENT	0
688729	688726	20056C	PARTICIPANT	\N	PRESENT	0
688730	688726	14073Q	PARTICIPANT	\N	PRESENT	0
688731	688726	20126Y	PARTICIPANT	\N	PRESENT	0
688732	688726	20066E	PARTICIPANT	\N	PRESENT	0
691200	690825	04085P	PARTICIPANT	\N	PRESENT	0
691202	690825	19387D	PARTICIPANT	\N	PRESENT	0
691203	690825	19515S	PARTICIPANT	\N	PRESENT	0
691204	690825	20126Y	PARTICIPANT	\N	PRESENT	0
691210	690825	14030Q	PARTICIPANT	\N	PRESENT	0
691211	690825	97011G	PARTICIPANT	\N	PRESENT	0
691212	690825	14189C	PARTICIPANT	\N	PRESENT	0
691213	690825	01062T	PARTICIPANT	\N	PRESENT	0
691214	690825	20020P	PARTICIPANT	\N	PRESENT	0
691215	690825	20024T	PARTICIPANT	\N	PRESENT	0
691216	690825	08060W	PARTICIPANT	\N	PRESENT	0
691217	690825	19697Q	PARTICIPANT	\N	PRESENT	0
691218	690825	20252E	PARTICIPANT	\N	PRESENT	0
691219	690825	19413M	PARTICIPANT	\N	PRESENT	0
691221	690825	16685X	PARTICIPANT	\N	PRESENT	0
691223	690825	11104D	PARTICIPANT	\N	PRESENT	0
691224	690825	19703U	PARTICIPANT	\N	PRESENT	0
691225	690825	98022P	PARTICIPANT	\N	PRESENT	0
691226	690825	20980G	PARTICIPANT	\N	PRESENT	0
691227	690825	19758L	PARTICIPANT	\N	PRESENT	0
691228	690825	11097X	PARTICIPANT	\N	PRESENT	0
691229	690825	20028X	PARTICIPANT	\N	PRESENT	0
691230	690825	19575F	PARTICIPANT	\N	PRESENT	0
691231	690825	08018U	PARTICIPANT	\N	PRESENT	0
691232	690825	14071N	PARTICIPANT	\N	PRESENT	0
688511	688510	11074Q	PARTICIPANT	\N	PRESENT	0
688527	688526	86034E	PARTICIPANT	\N	PRESENT	0
691233	690825	19699S	PARTICIPANT	\N	PRESENT	0
691234	690825	20172F	PARTICIPANT	\N	PRESENT	0
691235	690825	20082E	PARTICIPANT	\N	PRESENT	0
691236	690825	99004R	PARTICIPANT	\N	PRESENT	0
691246	690825	14031R	PARTICIPANT	\N	PRESENT	0
691247	690825	19691J	PARTICIPANT	\N	PRESENT	0
691248	690825	20138D	PARTICIPANT	\N	PRESENT	0
691249	690825	19762G	PARTICIPANT	\N	PRESENT	0
691250	690825	11045K	PARTICIPANT	\N	PRESENT	0
691251	690825	14211G	PARTICIPANT	\N	PRESENT	0
691252	690825	14053L	PARTICIPANT	\N	PRESENT	0
691253	690825	14329V	PARTICIPANT	\N	PRESENT	0
691254	690825	04092N	PARTICIPANT	\N	PRESENT	0
691255	690825	20070A	PARTICIPANT	\N	PRESENT	0
691258	690825	14001X	PARTICIPANT	\N	PRESENT	0
691259	690825	19421M	PARTICIPANT	\N	PRESENT	0
691260	690825	14217N	PARTICIPANT	\N	PRESENT	0
691261	690825	19673G	PARTICIPANT	\N	PRESENT	0
691262	690825	01043Q	PARTICIPANT	\N	PRESENT	0
691263	690825	11056N	PARTICIPANT	\N	PRESENT	0
691264	690825	11054L	PARTICIPANT	\N	PRESENT	0
691265	690825	14083S	PARTICIPANT	\N	PRESENT	0
691266	690825	17023S	PARTICIPANT	\N	PRESENT	0
691267	690825	95041E	PARTICIPANT	\N	PRESENT	0
691268	690825	04057K	PARTICIPANT	\N	PRESENT	0
691269	690825	19441R	PARTICIPANT	\N	PRESENT	0
691270	690825	11048N	PARTICIPANT	\N	PRESENT	0
691271	690825	11012A	PARTICIPANT	\N	PRESENT	0
691272	690825	14193X	PARTICIPANT	\N	PRESENT	0
691273	690825	17637T	PARTICIPANT	\N	PRESENT	0
691274	690825	19581D	PARTICIPANT	\N	PRESENT	0
701900	701534	14217N	PARTICIPANT	\N	PRESENT	0
701901	701642	17965H	PARTICIPANT	\N	PRESENT	0
701902	701642	11067R	PARTICIPANT	\N	PRESENT	0
701903	701642	19760E	PARTICIPANT	\N	PRESENT	0
701904	701642	11031D	PARTICIPANT	\N	PRESENT	0
701905	701642	20266L	PARTICIPANT	\N	PRESENT	0
701906	701642	95063L	PARTICIPANT	\N	PRESENT	0
701907	701642	19569H	PARTICIPANT	\N	PRESENT	0
701908	701642	20248J	PARTICIPANT	\N	PRESENT	0
701909	701642	20066E	PARTICIPANT	\N	PRESENT	0
701910	701642	11064N	PARTICIPANT	\N	PRESENT	0
701911	701642	19697Q	PARTICIPANT	\N	PRESENT	0
701912	701642	19683J	PARTICIPANT	\N	PRESENT	0
701913	701642	19719D	PARTICIPANT	\N	PRESENT	0
701914	701642	19553Y	PARTICIPANT	\N	PRESENT	0
701915	701642	20072C	PARTICIPANT	\N	PRESENT	0
701916	701642	18193Q	PARTICIPANT	\N	PRESENT	0
701917	701642	20040T	PARTICIPANT	\N	PRESENT	0
701918	701642	19745F	PARTICIPANT	\N	PRESENT	0
701919	701642	08028W	PARTICIPANT	\N	PRESENT	0
701920	701642	18083K	PARTICIPANT	\N	PRESENT	0
701921	701642	20074E	PARTICIPANT	\N	PRESENT	0
701922	701642	20076G	PARTICIPANT	\N	PRESENT	0
701923	701642	19515S	PARTICIPANT	\N	PRESENT	0
701924	701642	01057W	PARTICIPANT	\N	PRESENT	0
701925	701642	20026V	PARTICIPANT	\N	PRESENT	0
701926	701642	19723Y	PARTICIPANT	\N	PRESENT	0
701927	701642	20108W	PARTICIPANT	\N	PRESENT	0
701928	701642	14223L	PARTICIPANT	\N	PRESENT	0
701929	701642	19713W	PARTICIPANT	\N	PRESENT	0
701930	701642	04045F	PARTICIPANT	\N	PRESENT	0
701931	701642	19798U	PARTICIPANT	\N	PRESENT	0
701932	701642	19703U	PARTICIPANT	\N	PRESENT	0
701933	701642	20046A	PARTICIPANT	\N	PRESENT	0
701934	701642	19367Y	PARTICIPANT	\N	PRESENT	0
701935	701642	11040E	PARTICIPANT	\N	PRESENT	0
701936	701642	20130U	PARTICIPANT	\N	PRESENT	0
701937	701642	19421M	PARTICIPANT	\N	PRESENT	0
701938	701642	20980G	PARTICIPANT	\N	PRESENT	0
701939	701642	14038Y	PARTICIPANT	\N	PRESENT	0
701940	701642	20038A	PARTICIPANT	\N	PRESENT	0
701941	701642	14071N	PARTICIPANT	\N	PRESENT	0
701942	701642	14026U	PARTICIPANT	\N	PRESENT	0
701943	701642	14213J	PARTICIPANT	\N	PRESENT	0
701944	701642	14107H	PARTICIPANT	\N	PRESENT	0
701945	701642	20062A	PARTICIPANT	\N	PRESENT	0
701946	701642	14249W	PARTICIPANT	\N	PRESENT	0
701947	701642	04092N	PARTICIPANT	\N	PRESENT	0
701948	701642	10006L	PARTICIPANT	\N	PRESENT	0
701949	701642	08045X	PARTICIPANT	\N	PRESENT	0
701950	701642	20102Q	PARTICIPANT	\N	PRESENT	0
701954	701642	20056C	PARTICIPANT	\N	PRESENT	0
701952	701642	20036X	PARTICIPANT	\N	PRESENT	0
701953	701642	97011G	PARTICIPANT	\N	PRESENT	0
701955	701642	17779H	PARTICIPANT	\N	PRESENT	0
701956	701642	20144B	PARTICIPANT	\N	PRESENT	0
701957	701642	20052X	PARTICIPANT	\N	PRESENT	0
701958	701642	14111D	PARTICIPANT	\N	PRESENT	0
701959	701642	14189C	PARTICIPANT	\N	PRESENT	0
701960	701642	20034V	PARTICIPANT	\N	PRESENT	0
701961	701642	19591F	PARTICIPANT	\N	PRESENT	0
701962	701642	20048C	PARTICIPANT	\N	PRESENT	0
701966	701642	19543W	PARTICIPANT	\N	PRESENT	0
701967	701642	14030Q	PARTICIPANT	\N	PRESENT	0
701968	701642	19629C	PARTICIPANT	\N	PRESENT	0
701969	701642	20068G	PARTICIPANT	\N	PRESENT	0
701970	701642	20112S	PARTICIPANT	\N	PRESENT	0
701971	701642	01025N	PARTICIPANT	\N	PRESENT	0
701972	701642	11012A	PARTICIPANT	\N	PRESENT	0
701973	701642	11101A	PARTICIPANT	\N	PRESENT	0
701974	701642	11045K	PARTICIPANT	\N	PRESENT	0
701975	701642	14217N	PARTICIPANT	\N	PRESENT	0
701976	701642	19741B	PARTICIPANT	\N	PRESENT	0
701977	701642	19679N	PARTICIPANT	\N	PRESENT	0
701978	701642	19671E	PARTICIPANT	\N	PRESENT	0
701979	701642	19758L	PARTICIPANT	\N	PRESENT	0
701980	701642	19563B	PARTICIPANT	\N	PRESENT	0
701981	701642	14123H	PARTICIPANT	\N	PRESENT	0
701982	701642	14187A	PARTICIPANT	\N	PRESENT	0
701983	701642	20070A	PARTICIPANT	\N	PRESENT	0
701988	701642	20252E	PARTICIPANT	\N	PRESENT	0
701985	701642	14195A	PARTICIPANT	\N	PRESENT	0
701986	701642	20078J	PARTICIPANT	\N	PRESENT	0
701987	701642	11115U	PARTICIPANT	\N	PRESENT	0
701989	701642	19826F	PARTICIPANT	\N	PRESENT	0
701990	701642	20142Y	PARTICIPANT	\N	PRESENT	0
701991	701642	14229S	PARTICIPANT	\N	PRESENT	0
701994	701642	19333N	PARTICIPANT	\N	PRESENT	0
701995	701642	14147R	PARTICIPANT	\N	PRESENT	0
701996	701642	14073Q	PARTICIPANT	\N	PRESENT	0
701997	701642	20044X	PARTICIPANT	\N	PRESENT	0
701998	701642	11083R	PARTICIPANT	\N	PRESENT	0
701999	701642	20116W	PARTICIPANT	\N	PRESENT	0
702000	701642	19711U	PARTICIPANT	\N	PRESENT	0
702001	701642	19747H	PARTICIPANT	\N	PRESENT	0
702002	701642	14083S	PARTICIPANT	\N	PRESENT	0
702003	701642	11080N	PARTICIPANT	\N	PRESENT	0
702004	701642	01058X	PARTICIPANT	\N	PRESENT	0
702005	701642	11110B	PARTICIPANT	\N	PRESENT	0
702006	701642	04057K	PARTICIPANT	\N	PRESENT	0
702007	701642	14211G	PARTICIPANT	\N	PRESENT	0
702008	701642	19954N	PARTICIPANT	\N	PRESENT	0
702009	701642	14037X	PARTICIPANT	\N	PRESENT	0
702010	701642	98022P	PARTICIPANT	\N	PRESENT	0
702011	701642	14257W	PARTICIPANT	\N	PRESENT	0
702012	701642	04043D	PARTICIPANT	\N	PRESENT	0
702013	701642	14069U	PARTICIPANT	\N	PRESENT	0
702014	701642	20104S	PARTICIPANT	\N	PRESENT	0
702015	701642	14267Y	PARTICIPANT	\N	PRESENT	0
702017	701642	14033T	PARTICIPANT	\N	PRESENT	0
702018	701642	14169X	PARTICIPANT	\N	PRESENT	0
702019	701642	20180F	PARTICIPANT	\N	PRESENT	0
702020	701642	20124W	PARTICIPANT	\N	PRESENT	0
702021	701642	01048V	PARTICIPANT	\N	PRESENT	0
702024	701642	20140W	PARTICIPANT	\N	PRESENT	0
702025	701642	19581D	PARTICIPANT	\N	PRESENT	0
702029	701642	14021P	PARTICIPANT	\N	PRESENT	0
702030	701642	14357A	PARTICIPANT	\N	PRESENT	0
702031	701992	20086J	PARTICIPANT	\N	PRESENT	0
702032	701992	19383Y	PARTICIPANT	\N	PRESENT	0
702033	701992	20032T	PARTICIPANT	\N	PRESENT	0
702034	701992	01043Q	PRESIDENT	0	PRESENT	0
702035	701992	19545Y	PARTICIPANT	\N	PRESENT	0
702036	701992	19387D	PARTICIPANT	\N	PRESENT	0
702037	701992	20082E	PARTICIPANT	\N	PRESENT	0
702038	701992	20046A	PARTICIPANT	\N	PRESENT	0
702039	701992	19399H	PARTICIPANT	\N	PRESENT	0
702040	701992	20098N	PARTICIPANT	\N	PRESENT	0
702041	701992	14231L	PARTICIPANT	\N	PRESENT	0
702042	701992	11056N	PARTICIPANT	\N	PRESENT	0
702043	701992	19489J	PARTICIPANT	\N	PRESENT	0
702044	701992	19735D	PARTICIPANT	\N	PRESENT	0
702045	701992	14069U	PARTICIPANT	\N	PRESENT	0
702046	701992	20020P	PARTICIPANT	\N	PRESENT	0
702047	701992	20298U	PARTICIPANT	\N	PRESENT	0
702048	701642	19715Y	PARTICIPANT	\N	PRESENT	0
702049	701642	20028X	PARTICIPANT	\N	PRESENT	0
702050	701642	19691J	PARTICIPANT	\N	PRESENT	0
702051	701642	14031R	PARTICIPANT	\N	PRESENT	0
702052	701992	11110B	PARTICIPANT	\N	PRESENT	0
702053	701642	20042V	PARTICIPANT	\N	PRESENT	0
702054	701992	11065P	PARTICIPANT	\N	PRESENT	0
702055	701992	14219Q	PARTICIPANT	\N	EXCUSE	0
702056	701992	19631V	PARTICIPANT	\N	EXCUSE	0
702057	699814	14331P	PARTICIPANT	\N	PRESENT	0
702058	699814	11048N	PARTICIPANT	\N	PRESENT	0
702059	699814	19647E	PARTICIPANT	\N	PRESENT	0
702060	699814	19711U	PARTICIPANT	\N	PRESENT	0
702061	699814	08034U	PARTICIPANT	\N	PRESENT	0
702062	699814	14189C	PARTICIPANT	\N	PRESENT	0
702063	699814	19545Y	PARTICIPANT	\N	PRESENT	0
702064	699814	01057W	PARTICIPANT	\N	PRESENT	0
702065	699814	19687N	PARTICIPANT	\N	PRESENT	0
702066	699814	20080C	PARTICIPANT	\N	PRESENT	0
702067	699814	12016W	PARTICIPANT	\N	PRESENT	0
702068	699814	20044X	PARTICIPANT	\N	PRESENT	0
702069	699814	14225N	PRESIDENT	0	PRESENT	0
702070	699814	19671E	PARTICIPANT	\N	PRESENT	0
702071	699814	14173T	PARTICIPANT	\N	PRESENT	0
702072	699814	11012A	PARTICIPANT	\N	PRESENT	0
702073	699814	20252E	PARTICIPANT	\N	PRESENT	0
688738	688736	19533U	PARTICIPANT	\N	PRESENT	0
688740	688735	19533U	PARTICIPANT	\N	PRESENT	0
690434	688421	19701S	PARTICIPANT	\N	EXCUSE	0
690435	688421	20100N	PARTICIPANT	\N	PRESENT	0
690436	688421	04045F	PARTICIPANT	\N	EXCUSE	0
690671	690670	14133K	PARTICIPANT	\N	PRESENT	0
690672	690670	11066Q	PARTICIPANT	\N	PRESENT	0
691206	691189	14026U	PARTICIPANT	\N	PRESENT	0
691207	691205	14026U	PARTICIPANT	\N	PRESENT	0
691208	691205	20130U	PARTICIPANT	\N	PRESENT	0
691209	691205	11097X	PARTICIPANT	\N	PRESENT	0
691352	691351	20024T	PARTICIPANT	\N	PRESENT	0
691353	691351	14255U	PARTICIPANT	\N	PRESENT	0
691354	691351	11026G	PARTICIPANT	\N	PRESENT	0
691355	691351	10015M	PARTICIPANT	\N	PRESENT	0
691356	691351	20084G	PARTICIPANT	\N	PRESENT	0
692415	692388	20066E	PARTICIPANT	\N	PRESENT	0
692419	692418	11045K	PARTICIPANT	\N	PRESENT	0
692420	692418	20130U	PARTICIPANT	\N	PRESENT	0
692421	692418	17965H	PARTICIPANT	\N	PRESENT	0
692436	692435	11090Q	PARTICIPANT	\N	PRESENT	0
692437	692435	19711U	PARTICIPANT	\N	PRESENT	0
692438	692435	14097Y	PARTICIPANT	\N	PRESENT	0
692451	692450	19711U	PARTICIPANT	\N	PRESENT	0
692452	692450	20050V	PARTICIPANT	\N	PRESENT	0
692455	692453	19533U	PARTICIPANT	\N	PRESENT	0
692461	692460	20086J	PARTICIPANT	\N	PRESENT	1
696559	696008	14189C	PARTICIPANT	\N	PRESENT	0
696560	696008	14327T	PARTICIPANT	\N	PRESENT	0
696561	696008	11074Q	PARTICIPANT	\N	PRESENT	0
696562	696008	01048V	PARTICIPANT	\N	PRESENT	0
696563	696008	19762G	PARTICIPANT	\N	PRESENT	0
705877	703673	14257W	PARTICIPANT	\N	PRESENT	0
706175	706167	20114U	PARTICIPANT	\N	PRESENT	0
706177	706167	20090E	PARTICIPANT	\N	PRESENT	0
706178	706167	19721W	PARTICIPANT	\N	PRESENT	0
706180	706167	19826F	PARTICIPANT	\N	PRESENT	0
706181	706167	20076G	PARTICIPANT	\N	PRESENT	0
706182	706167	14205J	PARTICIPANT	\N	PRESENT	0
706183	706167	19725B	PARTICIPANT	\N	PRESENT	0
706184	706167	20026V	PARTICIPANT	\N	PRESENT	0
706185	706167	19719D	PARTICIPANT	\N	PRESENT	0
706186	706167	19723Y	PARTICIPANT	\N	PRESENT	0
706187	706167	16685X	PARTICIPANT	\N	PRESENT	0
706188	706167	20142Y	PARTICIPANT	\N	PRESENT	0
706189	706167	04045F	PARTICIPANT	\N	PRESENT	0
706190	706167	14097Y	PARTICIPANT	\N	PRESENT	0
706191	706167	20054A	PARTICIPANT	\N	PRESENT	0
706198	706193	20248J	PARTICIPANT	\N	PRESENT	0
706199	706193	20072C	PARTICIPANT	\N	PRESENT	0
706200	706193	20090E	PARTICIPANT	\N	PRESENT	0
706201	706193	19721W	PARTICIPANT	\N	PRESENT	0
706202	706193	19826F	PARTICIPANT	\N	PRESENT	0
706203	706193	20076G	PARTICIPANT	\N	PRESENT	0
706204	706193	14205J	PARTICIPANT	\N	PRESENT	0
706205	706193	19725B	PARTICIPANT	\N	PRESENT	0
706206	706193	19723Y	PARTICIPANT	\N	PRESENT	0
706207	706193	20142Y	PARTICIPANT	\N	PRESENT	0
706209	706193	04045F	PARTICIPANT	\N	PRESENT	0
706210	706193	14097Y	PARTICIPANT	\N	PRESENT	0
706211	706193	20054A	PARTICIPANT	\N	PRESENT	0
706215	706212	20094J	PARTICIPANT	\N	PRESENT	0
706216	706212	20090E	PARTICIPANT	\N	PRESENT	0
706217	706212	19826F	PARTICIPANT	\N	PRESENT	0
706218	706212	20076G	PARTICIPANT	\N	PRESENT	0
706219	706212	14205J	PARTICIPANT	\N	PRESENT	0
706220	706212	14097Y	PARTICIPANT	\N	PRESENT	0
706222	706212	20054A	PARTICIPANT	\N	PRESENT	0
706265	706238	19760E	PARTICIPANT	\N	PRESENT	0
706266	706238	17965H	PARTICIPANT	\N	PRESENT	0
706267	706238	19697Q	PARTICIPANT	\N	PRESENT	0
706268	706238	14223L	PARTICIPANT	\N	PRESENT	0
706269	706238	14217N	PARTICIPANT	\N	PRESENT	0
706270	706238	19798U	PARTICIPANT	\N	PRESENT	0
706271	706238	14071N	PARTICIPANT	\N	PRESENT	0
706272	706238	14042U	PARTICIPANT	\N	PRESENT	0
706273	706238	17779H	PARTICIPANT	\N	PRESENT	0
706274	706238	20148F	PARTICIPANT	\N	PRESENT	0
706275	706238	04057K	PARTICIPANT	\N	EXCUSE	0
706276	706238	19295A	PARTICIPANT	\N	EXCUSE	0
706277	706238	20090E	PARTICIPANT	\N	EXCUSE	0
706278	706238	20248J	PARTICIPANT	\N	EXCUSE	0
706279	706238	14281W	PARTICIPANT	\N	PRESENT	0
706280	706238	19569H	PARTICIPANT	\N	PRESENT	0
706281	706238	08045X	PARTICIPANT	\N	PRESENT	0
706282	706238	19715Y	PARTICIPANT	\N	PRESENT	0
706283	706238	11031D	PARTICIPANT	\N	PRESENT	0
706284	706238	14195A	PARTICIPANT	\N	PRESENT	0
706285	706238	20066E	PARTICIPANT	\N	PRESENT	0
706286	706238	04092N	PARTICIPANT	\N	PRESENT	0
706288	706238	19723Y	PARTICIPANT	\N	PRESENT	0
706289	706238	18193Q	PARTICIPANT	\N	PRESENT	0
706290	706238	10006L	PRESIDENT	0	PRESENT	0
706291	706238	11097X	PARTICIPANT	\N	PRESENT	0
706369	706367	20086J	PARTICIPANT	\N	PRESENT	0
706370	706367	01043Q	PARTICIPANT	\N	PRESENT	0
706371	706367	20120S	PARTICIPANT	\N	PRESENT	0
706372	706367	19399H	PARTICIPANT	\N	PRESENT	0
706373	706367	11064N	PARTICIPANT	\N	PRESENT	0
706374	706367	20082E	PARTICIPANT	\N	PRESENT	0
706375	706367	14219Q	PARTICIPANT	\N	PRESENT	0
706376	706368	20086J	PARTICIPANT	\N	PRESENT	0
706377	706368	01043Q	PARTICIPANT	\N	PRESENT	0
706378	706368	20120S	PARTICIPANT	\N	PRESENT	0
706379	706368	20082E	PARTICIPANT	\N	PRESENT	0
706380	706368	14219Q	PARTICIPANT	\N	PRESENT	0
706465	706464	19711U	PARTICIPANT	\N	PRESENT	0
706466	706464	20050V	PARTICIPANT	\N	PRESENT	0
706468	706467	19503N	PARTICIPANT	\N	PRESENT	0
706471	706470	19503N	PARTICIPANT	\N	PRESENT	0
706474	706473	19533U	PARTICIPANT	\N	PRESENT	0
707088	704097	19697Q	PARTICIPANT	\N	PRESENT	0
707089	704097	20062A	PARTICIPANT	\N	PRESENT	0
707090	704097	10006L	PARTICIPANT	\N	PRESENT	0
707091	704097	14042U	PARTICIPANT	\N	PRESENT	0
707092	704097	19954N	PARTICIPANT	\N	PRESENT	0
707093	704097	11043H	PARTICIPANT	\N	PRESENT	0
707095	704097	20264J	PARTICIPANT	\N	PRESENT	0
707097	704097	14257W	PARTICIPANT	\N	PRESENT	0
707100	704097	19631V	PARTICIPANT	\N	PRESENT	0
707101	704097	19515S	PARTICIPANT	\N	PRESENT	0
707102	704097	19387D	PARTICIPANT	\N	PRESENT	0
707104	704097	20066E	PARTICIPANT	\N	PRESENT	0
707108	704097	20086J	PARTICIPANT	\N	PRESENT	0
707109	704097	20082E	PARTICIPANT	\N	PRESENT	0
707110	704097	19599P	PARTICIPANT	\N	PRESENT	0
707111	704097	14189C	PARTICIPANT	\N	PRESENT	0
707114	704097	19551W	PARTICIPANT	\N	PRESENT	0
707119	704097	20100N	PARTICIPANT	\N	PRESENT	0
707122	704097	01034P	PARTICIPANT	\N	PRESENT	0
707123	704097	08018U	PARTICIPANT	\N	PRESENT	0
707124	704097	11056N	PARTICIPANT	\N	PRESENT	0
707125	704097	14331P	PARTICIPANT	\N	PRESENT	0
710215	708155	20122U	PARTICIPANT	\N	PRESENT	0
710216	708155	20054A	PARTICIPANT	\N	PRESENT	0
710217	708155	20126Y	PARTICIPANT	\N	PRESENT	0
710218	708155	19631V	PARTICIPANT	\N	PRESENT	0
710219	708155	14059S	PARTICIPANT	\N	PRESENT	0
710220	708155	20094J	PARTICIPANT	\N	PRESENT	0
710221	708155	20062A	PARTICIPANT	\N	PRESENT	0
710222	708155	20114U	PARTICIPANT	\N	PRESENT	0
710223	708155	19768N	PARTICIPANT	\N	PRESENT	0
710224	708155	20080C	PARTICIPANT	\N	PRESENT	0
710225	708155	08015R	PARTICIPANT	\N	PRESENT	0
710226	708155	19729F	PARTICIPANT	\N	PRESENT	0
710227	708155	20060X	PARTICIPANT	\N	PRESENT	0
710228	708155	19657G	PARTICIPANT	\N	PRESENT	0
710229	708155	12028B	PARTICIPANT	\N	PRESENT	0
710239	708155	11074Q	PARTICIPANT	\N	PRESENT	0
710231	708155	07029T	PARTICIPANT	\N	PRESENT	0
710232	708155	08018U	PARTICIPANT	\N	PRESENT	0
710233	708155	19709B	PARTICIPANT	\N	PRESENT	0
710234	708155	18083K	PARTICIPANT	\N	PRESENT	0
710235	708155	20044X	PARTICIPANT	\N	PRESENT	0
710236	708155	20264J	PARTICIPANT	\N	PRESENT	0
710237	708155	19251M	PARTICIPANT	\N	PRESENT	0
710238	708155	20058E	PARTICIPANT	\N	PRESENT	0
710240	708155	19705W	PARTICIPANT	\N	PRESENT	0
710241	708155	01057W	PARTICIPANT	\N	PRESENT	0
710242	708155	08045X	PARTICIPANT	\N	PRESENT	0
710243	708155	19820Y	PARTICIPANT	\N	PRESENT	0
710244	708155	19725B	PARTICIPANT	\N	PRESENT	0
710245	708155	14121F	PARTICIPANT	\N	PRESENT	0
710246	708155	19531S	PARTICIPANT	\N	PRESENT	0
710247	708155	19683J	PARTICIPANT	\N	PRESENT	0
710248	708155	19489J	PARTICIPANT	\N	PRESENT	0
710249	708155	19649G	PARTICIPANT	\N	PRESENT	0
710250	708155	11026G	PARTICIPANT	\N	PRESENT	0
710251	708155	08012N	PARTICIPANT	\N	PRESENT	0
710252	708155	17779H	PARTICIPANT	\N	PRESENT	0
710253	708155	20028X	PARTICIPANT	\N	PRESENT	0
710254	708155	11067R	PARTICIPANT	\N	PRESENT	0
710255	708155	20018V	PARTICIPANT	\N	PRESENT	0
710256	708155	17965H	PARTICIPANT	\N	PRESENT	0
710257	708155	19503N	PARTICIPANT	\N	PRESENT	0
710258	708155	14225N	PARTICIPANT	\N	PRESENT	0
710259	708155	19766L	PARTICIPANT	\N	PRESENT	0
710260	708155	01028R	PARTICIPANT	\N	PRESENT	0
710261	708155	19669L	PARTICIPANT	\N	PRESENT	0
710262	708155	14187A	PARTICIPANT	\N	PRESENT	0
710263	708155	11097X	PARTICIPANT	\N	PRESENT	0
710264	708155	11110B	PARTICIPANT	\N	PRESENT	0
710265	708155	14189C	PARTICIPANT	\N	PRESENT	0
710266	708155	19543W	PARTICIPANT	\N	PRESENT	0
710267	708155	14030Q	PARTICIPANT	\N	PRESENT	0
710268	708155	20042V	PARTICIPANT	\N	PRESENT	0
710269	708155	01048V	PARTICIPANT	\N	PRESENT	0
710270	708155	14089Y	PARTICIPANT	\N	PRESENT	0
710271	708155	14255U	PARTICIPANT	\N	PRESENT	0
710272	708155	14083S	PARTICIPANT	\N	PRESENT	0
710273	708155	20084G	PARTICIPANT	\N	PRESENT	0
710274	708155	11053K	PARTICIPANT	\N	PRESENT	0
710275	708155	19721W	PARTICIPANT	\N	PRESENT	0
710276	708155	20144B	PARTICIPANT	\N	PRESENT	0
710277	708155	04043D	PARTICIPANT	\N	PRESENT	0
710278	708155	14267Y	PARTICIPANT	\N	PRESENT	0
710279	708155	11070L	PARTICIPANT	\N	PRESENT	0
710280	708155	14327T	PARTICIPANT	\N	PRESENT	0
710281	708155	17229F	PARTICIPANT	\N	PRESENT	0
710282	708155	01024M	PARTICIPANT	\N	PRESENT	0
710283	708155	14042U	PARTICIPANT	\N	PRESENT	0
710284	708155	20040T	PARTICIPANT	\N	PRESENT	0
710292	708155	20048C	PARTICIPANT	\N	PRESENT	0
710286	708155	07004J	PARTICIPANT	\N	PRESENT	0
710287	708155	19691J	PARTICIPANT	\N	PRESENT	0
710288	708155	20286Q	PARTICIPANT	\N	PRESENT	0
710289	708155	19611R	PARTICIPANT	\N	PRESENT	0
710290	708155	19569H	PARTICIPANT	\N	PRESENT	0
710291	708155	14231L	PARTICIPANT	\N	PRESENT	0
710297	708155	20066E	PARTICIPANT	\N	PRESENT	0
710294	708155	14073Q	PARTICIPANT	\N	PRESENT	0
710295	708155	19699S	PARTICIPANT	\N	PRESENT	0
710296	708155	19735D	PARTICIPANT	\N	PRESENT	0
710298	708155	01043Q	PARTICIPANT	\N	PRESENT	0
710299	708155	20052X	PARTICIPANT	\N	PRESENT	0
710300	708155	16685X	PARTICIPANT	\N	PRESENT	0
710301	708155	14205J	PARTICIPANT	\N	PRESENT	0
710302	708155	14219Q	PARTICIPANT	\N	PRESENT	0
710303	708155	11085T	PARTICIPANT	\N	PRESENT	0
710304	708155	19826F	PARTICIPANT	\N	PRESENT	0
710305	708155	08009T	PARTICIPANT	\N	PRESENT	0
710306	708155	19335Q	PARTICIPANT	\N	PRESENT	0
710307	708155	04070G	PARTICIPANT	\N	PRESENT	0
710308	708155	19745F	PARTICIPANT	\N	PRESENT	0
710309	708155	19739H	PARTICIPANT	\N	PRESENT	0
710310	708155	20298U	PARTICIPANT	\N	PRESENT	0
710311	708155	19619A	PARTICIPANT	\N	PRESENT	0
710312	708155	14257W	PARTICIPANT	\N	PRESENT	0
710313	708155	19713W	PARTICIPANT	\N	PRESENT	0
710314	708155	19749K	PARTICIPANT	\N	PRESENT	0
710315	708155	19479G	PARTICIPANT	\N	PRESENT	0
710316	708155	19707Y	PARTICIPANT	\N	PRESENT	0
710317	708155	20050V	PARTICIPANT	\N	PRESENT	0
710318	708155	20172F	PARTICIPANT	\N	PRESENT	0
710319	708155	11064N	PARTICIPANT	\N	PRESENT	0
710320	708155	19549D	PARTICIPANT	\N	PRESENT	0
710321	708155	20068G	PARTICIPANT	\N	PRESENT	0
710322	708155	20248J	PARTICIPANT	\N	PRESENT	0
710324	710323	19553Y	PARTICIPANT	\N	PRESENT	0
710325	710323	14083S	PARTICIPANT	\N	PRESENT	0
710326	708155	19369B	PARTICIPANT	\N	PRESENT	0
710327	708155	11090Q	PARTICIPANT	\N	PRESENT	0
710328	708155	04071H	PARTICIPANT	\N	PRESENT	0
710329	708155	20150Y	PARTICIPANT	\N	PRESENT	0
710330	708155	14179A	PARTICIPANT	\N	PRESENT	0
710331	708155	19717B	PARTICIPANT	\N	PRESENT	0
710332	708155	19413M	PARTICIPANT	\N	PRESENT	0
710336	708155	19551W	PARTICIPANT	\N	PRESENT	0
710337	708155	19565D	PARTICIPANT	\N	PRESENT	0
710338	708155	04059M	PARTICIPANT	\N	PRESENT	0
710636	710339	19251M	PARTICIPANT	\N	PRESENT	0
710637	708161	11070L	PARTICIPANT	\N	PRESENT	0
710638	708161	14195A	PARTICIPANT	\N	PRESENT	0
710639	708161	17589D	PARTICIPANT	\N	PRESENT	0
710640	708161	19782L	PARTICIPANT	\N	PRESENT	0
710641	708161	20130U	PARTICIPANT	\N	PRESENT	0
710642	708161	19347U	PARTICIPANT	\N	PRESENT	0
710643	708161	20142Y	PARTICIPANT	\N	PRESENT	0
710644	708161	20134Y	PARTICIPANT	\N	PRESENT	0
710645	708161	08060W	PARTICIPANT	\N	PRESENT	0
710646	708161	19820Y	PARTICIPANT	\N	PRESENT	0
710647	708161	19295A	PARTICIPANT	\N	PRESENT	0
710648	708161	19649G	PARTICIPANT	\N	PRESENT	0
710649	708161	19725B	PARTICIPANT	\N	PRESENT	0
710650	708161	04057K	PARTICIPANT	\N	PRESENT	0
710651	708161	19721W	PARTICIPANT	\N	PRESENT	0
710652	708161	19479G	PARTICIPANT	\N	PRESENT	0
710653	708161	14147R	PARTICIPANT	\N	PRESENT	0
710654	708161	20286Q	PARTICIPANT	\N	PRESENT	0
710655	708161	19707Y	PARTICIPANT	\N	PRESENT	0
710656	708161	19866P	PARTICIPANT	\N	PRESENT	0
710657	708161	19705W	PARTICIPANT	\N	PRESENT	0
710658	708161	19760E	PARTICIPANT	\N	PRESENT	0
710659	708161	14213J	PARTICIPANT	\N	PRESENT	0
710660	708161	20024T	PARTICIPANT	\N	PRESENT	0
710661	708161	20046A	PARTICIPANT	\N	PRESENT	0
710662	708161	20026V	PARTICIPANT	\N	PRESENT	0
710663	708161	20180F	PARTICIPANT	\N	PRESENT	0
710664	708161	19695N	PARTICIPANT	\N	PRESENT	0
710665	708161	20980G	PARTICIPANT	\N	PRESENT	0
710666	708161	20044X	PARTICIPANT	\N	PRESENT	0
710667	708161	19691J	PARTICIPANT	\N	PRESENT	0
710668	708161	19826F	PARTICIPANT	\N	PRESENT	0
710669	708161	14357A	PARTICIPANT	\N	PRESENT	0
710670	708161	14215L	PARTICIPANT	\N	PRESENT	0
710671	708161	14059S	PARTICIPANT	\N	PRESENT	0
710672	708161	14123H	PARTICIPANT	\N	PRESENT	0
710673	708161	20090E	PARTICIPANT	\N	PRESENT	0
710674	708161	20062A	PARTICIPANT	\N	PRESENT	0
710675	710339	19575F	PARTICIPANT	\N	PRESENT	0
710676	710339	11053K	PARTICIPANT	\N	PRESENT	0
710677	708161	14189C	PARTICIPANT	\N	PRESENT	0
710678	708161	19687N	PARTICIPANT	\N	PRESENT	0
710679	708161	20018V	PARTICIPANT	\N	PRESENT	0
688894	688644	12041X	PARTICIPANT	\N	PRESENT	0
688895	688644	19583F	PARTICIPANT	\N	PRESENT	0
688896	688644	20914V	PARTICIPANT	\N	PRESENT	0
688897	688644	18083K	PARTICIPANT	\N	PRESENT	0
688898	688644	14071N	PARTICIPANT	\N	PRESENT	0
688899	688644	20072C	PARTICIPANT	\N	PRESENT	0
688900	688644	19954N	PARTICIPANT	\N	PRESENT	0
688901	688644	20102Q	PARTICIPANT	\N	PRESENT	0
688902	688644	20046A	PARTICIPANT	\N	PRESENT	0
688903	688644	19565D	PARTICIPANT	\N	PRESENT	0
688904	688644	14207L	PARTICIPANT	\N	PRESENT	0
688905	688644	20026V	PARTICIPANT	\N	PRESENT	0
688906	688644	20062A	PARTICIPANT	\N	PRESENT	0
688907	688644	20106U	PARTICIPANT	\N	PRESENT	0
688908	688644	19637C	PARTICIPANT	\N	PRESENT	0
688909	688644	18193Q	PARTICIPANT	\N	PRESENT	0
688910	688644	20018V	PARTICIPANT	\N	PRESENT	0
688911	688644	19399H	PARTICIPANT	\N	PRESENT	0
688912	688644	20088L	PARTICIPANT	\N	PRESENT	0
688913	688644	14195A	PARTICIPANT	\N	PRESENT	0
688914	688644	19729F	PARTICIPANT	\N	PRESENT	0
688915	688644	19739H	PARTICIPANT	\N	PRESENT	0
688916	688644	14223L	PARTICIPANT	\N	PRESENT	0
688917	688644	08073C	PARTICIPANT	\N	PRESENT	0
688918	688644	20286Q	PARTICIPANT	\N	PRESENT	0
688919	688644	20090E	PARTICIPANT	\N	PRESENT	0
688920	688644	05012A	PARTICIPANT	\N	PRESENT	0
688921	688644	19703U	PARTICIPANT	\N	PRESENT	0
688922	688644	20098N	PARTICIPANT	\N	PRESENT	0
688923	688644	19507S	PARTICIPANT	\N	PRESENT	0
688924	688644	14038Y	PARTICIPANT	\N	PRESENT	0
688925	688644	19820Y	PARTICIPANT	\N	PRESENT	0
688926	688644	20030R	PARTICIPANT	\N	PRESENT	0
688927	688644	20032T	PARTICIPANT	\N	PRESENT	0
688928	688644	19745F	PARTICIPANT	\N	PRESENT	0
688929	688644	19383Y	PARTICIPANT	\N	PRESENT	0
688930	688644	14031R	PARTICIPANT	\N	PRESENT	0
688932	688644	95063L	PARTICIPANT	\N	PRESENT	0
688933	688644	20068G	PARTICIPANT	\N	PRESENT	0
688934	688644	19798U	PARTICIPANT	\N	PRESENT	0
688935	688644	14257W	PARTICIPANT	\N	PRESENT	0
688936	688644	19387D	PARTICIPANT	\N	PRESENT	0
688937	688644	20152B	PARTICIPANT	\N	PRESENT	0
688938	688644	99004R	PARTICIPANT	\N	PRESENT	0
688939	688644	20058E	PARTICIPANT	\N	PRESENT	0
688940	688644	11097X	PARTICIPANT	\N	PRESENT	0
688941	688644	19599P	PARTICIPANT	\N	PRESENT	0
688942	688644	19549D	PARTICIPANT	\N	PRESENT	0
688943	688644	14219Q	PARTICIPANT	\N	PRESENT	0
688944	688644	20248J	PARTICIPANT	\N	PRESENT	0
688945	688644	20078J	PARTICIPANT	\N	PRESENT	0
688946	688644	19503N	PARTICIPANT	\N	PRESENT	0
688947	688644	20104S	PARTICIPANT	\N	PRESENT	0
688948	688644	14069U	PARTICIPANT	\N	PRESENT	0
688949	688644	14033T	PARTICIPANT	\N	PRESENT	0
688950	688644	19782L	PARTICIPANT	\N	PRESENT	0
688951	688644	01024M	PARTICIPANT	\N	PRESENT	0
688952	688644	20066E	PARTICIPANT	\N	PRESENT	0
688953	688644	19467C	PARTICIPANT	\N	PRESENT	0
688958	688644	14147R	PARTICIPANT	\N	PRESENT	0
688959	688644	11067R	PARTICIPANT	\N	PRESENT	0
688960	688644	14107H	PARTICIPANT	\N	PRESENT	0
688961	688644	19685L	PARTICIPANT	\N	PRESENT	0
688962	688644	19367Y	PARTICIPANT	\N	PRESENT	0
688963	688644	14221J	PARTICIPANT	\N	PRESENT	0
688964	688644	14089Y	PARTICIPANT	\N	PRESENT	0
688965	688644	14237S	PARTICIPANT	\N	PRESENT	0
688966	688644	20056C	PARTICIPANT	\N	PRESENT	0
688967	688644	11064N	PARTICIPANT	\N	PRESENT	0
688968	688644	20136B	PARTICIPANT	\N	PRESENT	0
688969	688644	11104D	PARTICIPANT	\N	PRESENT	0
688970	688644	01025N	PARTICIPANT	\N	PRESENT	0
688971	688644	14189C	PARTICIPANT	\N	PRESENT	0
688972	688644	01057W	PARTICIPANT	\N	PRESENT	0
688973	688394	19701S	PARTICIPANT	\N	EXCUSE	0
688974	688394	17367Q	PARTICIPANT	\N	EXCUSE	0
688975	688644	08028W	PARTICIPANT	\N	PRESENT	0
688976	688644	08015R	PARTICIPANT	\N	PRESENT	0
688977	688644	19691J	PARTICIPANT	\N	PRESENT	0
688978	688644	19441R	PARTICIPANT	\N	PRESENT	0
688979	688644	19479G	PARTICIPANT	\N	PRESENT	0
688980	688644	20100N	PARTICIPANT	\N	PRESENT	0
688981	688644	19651A	PARTICIPANT	\N	PRESENT	0
688982	688644	20180F	PARTICIPANT	\N	PRESENT	0
688983	688644	08060W	PARTICIPANT	\N	PRESENT	0
688984	688645	12041X	PARTICIPANT	\N	PRESENT	0
688985	688645	20914V	PARTICIPANT	\N	PRESENT	0
688986	688645	18083K	PARTICIPANT	\N	PRESENT	0
688987	688645	20072C	PARTICIPANT	\N	PRESENT	0
688988	688645	19954N	PARTICIPANT	\N	PRESENT	0
688989	688645	20102Q	PARTICIPANT	\N	PRESENT	0
688990	688645	20046A	PARTICIPANT	\N	PRESENT	0
689068	688645	14033T	PARTICIPANT	\N	PRESENT	0
689049	688645	20076G	PARTICIPANT	\N	PRESENT	0
689060	688645	19251M	PARTICIPANT	\N	PRESENT	0
689048	688645	20062A	PARTICIPANT	\N	PRESENT	0
688995	688645	18193Q	PARTICIPANT	\N	PRESENT	0
688996	688645	20018V	PARTICIPANT	\N	PRESENT	0
689061	688645	20106U	PARTICIPANT	\N	PRESENT	0
689062	688645	14237S	PARTICIPANT	\N	PRESENT	0
689050	688645	11043H	PARTICIPANT	\N	PRESENT	0
689065	688645	19367Y	PARTICIPANT	\N	PRESENT	0
689001	688645	20090E	PARTICIPANT	\N	PRESENT	0
689051	688645	19693L	PARTICIPANT	\N	PRESENT	0
689003	688645	19703U	PARTICIPANT	\N	PRESENT	0
689004	688645	19507S	PARTICIPANT	\N	PRESENT	0
689067	688645	19782L	PARTICIPANT	\N	PRESENT	0
689052	688645	19747H	PARTICIPANT	\N	PRESENT	0
689066	688645	14223L	PARTICIPANT	\N	PRESENT	0
689008	688645	20032T	PARTICIPANT	\N	PRESENT	0
689009	688645	19745F	PARTICIPANT	\N	PRESENT	0
689010	688645	19383Y	PARTICIPANT	\N	PRESENT	0
689011	688645	14031R	PARTICIPANT	\N	PRESENT	0
689012	688645	20068G	PARTICIPANT	\N	PRESENT	0
689058	688645	19569H	PARTICIPANT	\N	PRESENT	0
689014	688645	19387D	PARTICIPANT	\N	PRESENT	0
689069	688645	19479G	PARTICIPANT	\N	PRESENT	0
689016	688645	19599P	PARTICIPANT	\N	PRESENT	0
689017	688645	19549D	PARTICIPANT	\N	PRESENT	0
689018	688645	14219Q	PARTICIPANT	\N	PRESENT	0
689070	688645	19581D	PARTICIPANT	\N	PRESENT	0
689020	688645	19503N	PARTICIPANT	\N	PRESENT	0
689071	688645	19719D	PARTICIPANT	\N	PRESENT	0
689053	688645	20098N	PARTICIPANT	\N	PRESENT	0
689054	688645	14069U	PARTICIPANT	\N	PRESENT	0
689024	688645	01024M	PARTICIPANT	\N	PRESENT	0
689025	688645	20066E	PARTICIPANT	\N	PRESENT	0
689072	688645	20020P	PARTICIPANT	\N	PRESENT	0
689027	688645	14147R	PARTICIPANT	\N	PRESENT	0
689073	688645	20026V	PARTICIPANT	\N	PRESENT	0
689029	688645	14107H	PARTICIPANT	\N	PRESENT	0
689030	688645	19685L	PARTICIPANT	\N	PRESENT	0
689074	688645	11104D	PARTICIPANT	\N	PRESENT	0
689075	688645	17965H	PARTICIPANT	\N	PRESENT	0
689033	688645	20056C	PARTICIPANT	\N	PRESENT	0
689034	688645	11064N	PARTICIPANT	\N	PRESENT	0
689035	688645	20136B	PARTICIPANT	\N	PRESENT	0
689036	688645	01025N	PARTICIPANT	\N	PRESENT	0
689037	688645	14189C	PARTICIPANT	\N	PRESENT	0
689057	688645	20108W	PARTICIPANT	\N	PRESENT	0
689039	688645	08028W	PARTICIPANT	\N	PRESENT	0
689055	688645	19711U	PARTICIPANT	\N	PRESENT	0
689041	688645	19691J	PARTICIPANT	\N	PRESENT	0
689042	688645	19441R	PARTICIPANT	\N	PRESENT	0
689076	688645	20088L	PARTICIPANT	\N	PRESENT	0
689044	688645	20100N	PARTICIPANT	\N	PRESENT	0
689045	688645	19651A	PARTICIPANT	\N	PRESENT	0
689046	688645	20180F	PARTICIPANT	\N	PRESENT	0
689047	688645	08060W	PARTICIPANT	\N	PRESENT	0
689056	688645	20172F	PARTICIPANT	\N	PRESENT	0
689077	688645	14073Q	PARTICIPANT	\N	PRESENT	0
689078	688645	14281W	PARTICIPANT	\N	PRESENT	0
689079	688645	11067R	PARTICIPANT	\N	PRESENT	0
689080	688645	20116W	PARTICIPANT	\N	PRESENT	0
689081	688645	97011G	PARTICIPANT	\N	PRESENT	0
689082	688645	14259Y	PARTICIPANT	\N	PRESENT	0
689083	688645	19533U	PARTICIPANT	\N	PRESENT	0
689088	688645	14026U	PARTICIPANT	\N	PRESENT	0
689089	688645	19563B	PARTICIPANT	\N	PRESENT	0
689090	688394	14237S	PARTICIPANT	\N	PRESENT	0
689091	688394	20076G	PARTICIPANT	\N	PRESENT	0
702074	699814	19349W	PARTICIPANT	\N	PRESENT	0
702075	699814	08010L	PARTICIPANT	\N	PRESENT	0
702076	699814	99004R	PARTICIPANT	\N	PRESENT	0
702077	699814	20116W	PARTICIPANT	\N	PRESENT	0
702078	699814	20914V	PARTICIPANT	\N	PRESENT	0
702079	701992	20058E	PARTICIPANT	\N	PRESENT	0
702080	701992	19573D	PARTICIPANT	\N	PRESENT	0
702081	699814	14327T	PARTICIPANT	\N	PRESENT	0
702082	699814	19479G	PARTICIPANT	\N	PRESENT	0
702083	699814	01048V	PARTICIPANT	\N	PRESENT	0
702084	699814	19335Q	PARTICIPANT	\N	PRESENT	0
702085	699814	07029T	PARTICIPANT	\N	PRESENT	0
702086	701992	20120S	PARTICIPANT	\N	PRESENT	0
702087	701642	20088L	PARTICIPANT	\N	PRESENT	0
702088	699814	20126Y	PARTICIPANT	\N	PRESENT	0
702089	699814	20070A	PARTICIPANT	\N	PRESENT	0
702227	692497	20150Y	PARTICIPANT	\N	EXCUSE	0
702228	692497	14219Q	PARTICIPANT	\N	EXCUSE	0
702229	692497	14331P	PARTICIPANT	\N	EXCUSE	0
702230	692497	19631V	PARTICIPANT	\N	EXCUSE	0
702234	692497	14053L	PARTICIPANT	\N	EXCUSE	0
702236	692497	14147R	PARTICIPANT	\N	EXCUSE	0
702238	692497	19295A	PARTICIPANT	\N	PRESENT	1
702241	692497	14259Y	PARTICIPANT	\N	EXCUSE	0
702242	692497	11043H	PARTICIPANT	\N	EXCUSE	0
702261	692497	05008E	PARTICIPANT	\N	EXCUSE	0
702262	692497	19717B	PRESIDENT	0	PRESENT	0
702263	692497	20034V	PARTICIPANT	\N	PRESENT	0
702280	702279	19503N	PARTICIPANT	\N	PRESENT	0
702298	701643	14173T	PARTICIPANT	\N	PRESENT	0
702299	701643	14331P	PARTICIPANT	\N	PRESENT	0
702300	701643	19599P	PARTICIPANT	\N	PRESENT	0
702301	701643	14083S	PARTICIPANT	\N	PRESENT	0
702311	701992	19349W	PARTICIPANT	\N	PRESENT	0
702312	701992	14205J	PARTICIPANT	\N	PRESENT	0
702313	701643	14281W	PARTICIPANT	\N	PRESENT	0
702314	701643	20038A	PARTICIPANT	\N	PRESENT	0
702315	701643	20100N	PARTICIPANT	\N	PRESENT	0
702316	701643	04047H	PARTICIPANT	\N	PRESENT	0
702317	701643	14205J	PARTICIPANT	\N	PRESENT	0
702323	701643	19479G	PARTICIPANT	\N	PRESENT	0
702334	702333	20120S	PARTICIPANT	\N	PRESENT	0
702335	701643	20032T	PARTICIPANT	\N	PRESENT	0
702336	701643	19349W	PARTICIPANT	\N	PRESENT	0
702337	701643	11110B	PARTICIPANT	\N	PRESENT	0
702338	701643	20298U	PARTICIPANT	\N	PRESENT	0
702403	701644	19683J	PARTICIPANT	\N	PRESENT	0
702404	701644	14213J	PARTICIPANT	\N	PRESENT	0
702405	701644	10006L	PARTICIPANT	\N	PRESENT	0
702431	701644	20038A	PARTICIPANT	\N	PRESENT	0
702407	701644	14195A	PARTICIPANT	\N	PRESENT	0
702408	701644	19591F	PARTICIPANT	\N	PRESENT	0
702433	701644	14042U	PARTICIPANT	\N	PRESENT	0
702410	701644	14030Q	PARTICIPANT	\N	PRESENT	0
702411	701644	17965H	PARTICIPANT	\N	PRESENT	0
702412	701644	11067R	PARTICIPANT	\N	PRESENT	0
702413	701644	18193Q	PARTICIPANT	\N	PRESENT	0
702414	701644	11031D	PARTICIPANT	\N	PRESENT	0
702415	701644	20130U	PARTICIPANT	\N	PRESENT	0
702416	701644	20054A	PARTICIPANT	\N	PRESENT	0
702417	701644	20124W	PARTICIPANT	\N	PRESENT	0
702418	701644	14215L	PARTICIPANT	\N	PRESENT	0
702419	701644	14071N	PARTICIPANT	\N	PRESENT	0
702420	701644	18083K	PARTICIPANT	\N	PRESENT	0
702421	701644	20180F	PARTICIPANT	\N	PRESENT	0
702422	701644	20044X	PARTICIPANT	\N	PRESENT	0
702423	701644	19679N	PARTICIPANT	\N	PRESENT	0
702424	701644	20076G	PARTICIPANT	\N	PRESENT	0
702425	701644	20074E	PARTICIPANT	\N	PRESENT	0
702426	701644	19703U	PARTICIPANT	\N	PRESENT	0
702427	701644	10015M	PARTICIPANT	\N	PRESENT	0
702428	701644	20086J	PARTICIPANT	\N	PRESENT	0
702429	701644	19798U	PARTICIPANT	\N	PRESENT	0
702430	701644	14053L	PARTICIPANT	\N	PRESENT	0
702432	701644	04092N	PARTICIPANT	\N	PRESENT	0
702434	701644	19760E	PARTICIPANT	\N	PRESENT	0
702435	701644	20126Y	PARTICIPANT	\N	PRESENT	0
702436	701644	20132W	PARTICIPANT	\N	PRESENT	0
702437	701644	19553Y	PARTICIPANT	\N	PRESENT	0
702438	701644	14217N	PARTICIPANT	\N	PRESENT	0
702439	701644	20062A	PARTICIPANT	\N	PRESENT	0
702440	701644	19723Y	PARTICIPANT	\N	PRESENT	0
702441	701644	17589D	PARTICIPANT	\N	PRESENT	0
702442	701644	20070A	PARTICIPANT	\N	PRESENT	0
702443	701644	20026V	PARTICIPANT	\N	PRESENT	0
702444	701644	20140W	PARTICIPANT	\N	PRESENT	0
702445	701644	20040T	PARTICIPANT	\N	PRESENT	0
702446	701644	14069U	PARTICIPANT	\N	PRESENT	0
702447	701644	19367Y	PARTICIPANT	\N	PRESENT	0
702448	701644	20032T	PARTICIPANT	\N	PRESENT	0
702449	701644	20056C	PARTICIPANT	\N	PRESENT	0
702450	701644	20266L	PARTICIPANT	\N	PRESENT	0
702451	701644	14357A	PARTICIPANT	\N	PRESENT	0
702452	701644	14147R	PARTICIPANT	\N	PRESENT	0
702453	701644	19713W	PARTICIPANT	\N	PRESENT	0
702454	701644	19575F	PARTICIPANT	\N	PRESENT	0
702455	701644	14026U	PARTICIPANT	\N	PRESENT	0
702456	701644	19387D	PARTICIPANT	\N	PRESENT	0
702457	701644	11097X	PARTICIPANT	\N	PRESENT	0
702458	701644	19741B	PARTICIPANT	\N	PRESENT	0
702459	701644	14033T	PARTICIPANT	\N	PRESENT	0
702659	701622	14179A	PARTICIPANT	\N	EXCUSE	0
702903	702460	14111D	PARTICIPANT	\N	PRESENT	0
702904	702460	14107H	PARTICIPANT	\N	PRESENT	0
702906	702905	14111D	PARTICIPANT	\N	PRESENT	0
702907	702463	20022R	PARTICIPANT	\N	PRESENT	0
702908	702463	14231L	PARTICIPANT	\N	PRESENT	0
702909	702463	20110Q	PARTICIPANT	\N	PRESENT	0
702401	701644	95063L	PARTICIPANT	\N	PRESENT	0
702402	701644	19569H	PARTICIPANT	\N	PRESENT	0
702910	702464	20022R	PARTICIPANT	\N	PRESENT	0
702923	702922	14189C	PARTICIPANT	\N	EXCUSE	0
702924	702922	20024T	PARTICIPANT	\N	EXCUSE	0
702925	702922	20080C	PARTICIPANT	\N	EXCUSE	0
702926	702922	20056C	PARTICIPANT	\N	EXCUSE	0
702927	702922	20118Y	PARTICIPANT	\N	EXCUSE	0
702928	702922	20098N	PARTICIPANT	\N	EXCUSE	0
703091	701645	19954N	PARTICIPANT	\N	PRESENT	0
703092	701645	14033T	PARTICIPANT	\N	PRESENT	0
703093	701645	19399H	PARTICIPANT	\N	PRESENT	0
703094	701645	20140W	PARTICIPANT	\N	PRESENT	0
703095	701645	08047A	PARTICIPANT	\N	PRESENT	0
703097	701645	04035D	PARTICIPANT	\N	PRESENT	0
703098	701645	11065P	PARTICIPANT	\N	PRESENT	0
703099	701645	20084G	PARTICIPANT	\N	PRESENT	0
703100	701645	19705W	PARTICIPANT	\N	PRESENT	0
703101	701645	19707Y	PARTICIPANT	\N	PRESENT	0
703102	701645	08015R	PARTICIPANT	\N	PRESENT	0
703103	701645	19723Y	PARTICIPANT	\N	PRESENT	0
703104	701645	14331P	PARTICIPANT	\N	PRESENT	0
703105	701645	01062T	PARTICIPANT	\N	PRESENT	0
703106	701645	14147R	PARTICIPANT	\N	PRESENT	0
703107	701645	14151M	PARTICIPANT	\N	PRESENT	0
703108	701645	19489J	PARTICIPANT	\N	PRESENT	0
703109	701645	20104S	PARTICIPANT	\N	PRESENT	0
703110	701645	14213J	PARTICIPANT	\N	PRESENT	0
703111	701645	14001X	PARTICIPANT	\N	PRESENT	0
703112	701645	19333N	PARTICIPANT	\N	PRESENT	0
703113	701645	19649G	PARTICIPANT	\N	PRESENT	0
703114	701645	14021P	PARTICIPANT	\N	PRESENT	0
703115	701645	14229S	PARTICIPANT	\N	PRESENT	0
703116	701645	17367Q	PARTICIPANT	\N	PRESENT	0
703117	701645	19647E	PARTICIPANT	\N	PRESENT	0
703118	701645	11067R	PARTICIPANT	\N	PRESENT	0
703119	701645	14133K	PARTICIPANT	\N	PRESENT	0
703120	701645	20114U	PARTICIPANT	\N	PRESENT	0
703121	701645	01048V	PARTICIPANT	\N	PRESENT	0
703122	701645	20070A	PARTICIPANT	\N	PRESENT	0
703123	701645	08012N	PARTICIPANT	\N	PRESENT	0
703124	701645	14109K	PARTICIPANT	\N	PRESENT	0
703125	701645	04042C	PARTICIPANT	\N	PRESENT	0
703126	701645	11066Q	PARTICIPANT	\N	PRESENT	0
703127	701645	11104D	PARTICIPANT	\N	PRESENT	0
703128	701645	08069G	PARTICIPANT	\N	PRESENT	0
703129	701645	04071H	PARTICIPANT	\N	PRESENT	0
703130	701645	19725B	PARTICIPANT	\N	PRESENT	0
703131	701645	11099A	PARTICIPANT	\N	PRESENT	0
703132	701645	18193Q	PARTICIPANT	\N	PRESENT	0
703133	701645	20060X	PARTICIPANT	\N	PRESENT	0
703134	701645	20018V	PARTICIPANT	\N	PRESENT	0
688596	688595	14033T	PARTICIPANT	\N	PRESENT	0
688597	688595	14257W	PARTICIPANT	\N	PRESENT	0
688599	688598	14033T	PARTICIPANT	\N	PRESENT	0
688600	688598	14257W	PARTICIPANT	\N	PRESENT	0
692206	690710	14001X	PARTICIPANT	\N	PRESENT	0
692207	690710	04047H	PRESIDENT	0	PRESENT	0
692208	690710	20074E	PARTICIPANT	\N	PRESENT	0
692209	690710	14147R	PARTICIPANT	\N	PRESENT	0
692217	690710	14089Y	PARTICIPANT	\N	PRESENT	0
692218	690710	14021P	PARTICIPANT	\N	EXCUSE	0
692219	690710	20100N	PARTICIPANT	\N	PRESENT	0
692220	690710	11083R	PARTICIPANT	\N	PRESENT	0
692221	690710	08034U	PARTICIPANT	\N	PRESENT	0
692222	690710	19441R	PARTICIPANT	\N	PRESENT	0
692223	690710	14331P	PARTICIPANT	\N	PRESENT	0
692226	690710	11041F	PARTICIPANT	\N	PRESENT	0
692227	690710	01062T	PARTICIPANT	\N	PRESENT	0
692228	690710	11064N	PARTICIPANT	\N	PRESENT	0
692229	690710	07033P	PARTICIPANT	\N	PRESENT	0
692230	690710	01024M	PARTICIPANT	\N	PRESENT	0
692231	690710	20042V	PARTICIPANT	\N	PRESENT	0
692232	690710	14059S	PARTICIPANT	\N	PRESENT	0
694961	692318	11109J	PARTICIPANT	\N	EXCUSE	0
694962	692318	19621T	PARTICIPANT	\N	EXCUSE	0
694963	691611	11109J	PARTICIPANT	\N	EXCUSE	0
694964	691611	19621T	PARTICIPANT	\N	EXCUSE	0
694965	691635	11109J	PARTICIPANT	\N	EXCUSE	0
694966	691635	19621T	PARTICIPANT	\N	EXCUSE	0
694967	691670	11109J	PARTICIPANT	\N	EXCUSE	0
694968	691670	19621T	PARTICIPANT	\N	EXCUSE	0
694969	691670	19758L	PARTICIPANT	\N	EXCUSE	0
694970	691670	19573D	PARTICIPANT	\N	PRESENT	0
701806	701788	14187A	PRESIDENT	0	PRESENT	0
701807	701788	19701S	PARTICIPANT	\N	EXCUSE	0
701808	701788	20124W	PARTICIPANT	\N	PRESENT	0
701809	701788	14257W	PARTICIPANT	\N	PRESENT	0
701810	701788	19525U	PARTICIPANT	\N	PRESENT	0
701811	701788	20286Q	PARTICIPANT	\N	PRESENT	0
701812	701788	20062A	PARTICIPANT	\N	PRESENT	0
701813	701788	19347U	PARTICIPANT	\N	PRESENT	0
701814	701788	20298U	PARTICIPANT	\N	PRESENT	0
701815	701788	20018V	PARTICIPANT	\N	PRESENT	0
701816	701788	19681G	PARTICIPANT	\N	EXCUSE	0
701820	701788	17023S	PARTICIPANT	\N	PRESENT	0
701821	701788	11101A	PARTICIPANT	\N	PRESENT	0
702466	701622	11033F	PARTICIPANT	\N	PRESENT	0
702467	701622	19649G	PARTICIPANT	\N	PRESENT	0
702468	701622	14111D	PARTICIPANT	\N	PRESENT	0
702469	701622	20074E	PARTICIPANT	\N	PRESENT	0
702470	701622	10015M	PARTICIPANT	\N	PRESENT	0
702471	701622	04047H	PRESIDENT	0	PRESENT	0
702472	701622	19675J	PARTICIPANT	\N	PRESENT	0
702473	701622	19954N	PARTICIPANT	\N	PRESENT	0
702474	701622	14107H	PARTICIPANT	\N	PRESENT	0
702475	701622	20110Q	PARTICIPANT	\N	PRESENT	0
702476	701622	11085T	PARTICIPANT	\N	PRESENT	0
702477	701622	08018U	PARTICIPANT	\N	PRESENT	0
702478	701622	20022R	PARTICIPANT	\N	PRESENT	0
702479	701622	19729F	PARTICIPANT	\N	EXCUSE	0
702480	701622	19701S	PARTICIPANT	\N	PRESENT	0
702481	701622	19673G	PARTICIPANT	\N	PRESENT	0
702482	701622	19447X	PARTICIPANT	\N	PRESENT	0
702483	701622	14231L	PARTICIPANT	\N	PRESENT	0
702484	701622	07004J	PARTICIPANT	\N	PRESENT	0
702485	701622	14147R	PARTICIPANT	\N	PRESENT	0
702486	701622	14151M	PARTICIPANT	\N	PRESENT	0
702487	701622	14215L	PARTICIPANT	\N	PRESENT	0
702488	701622	11072N	PARTICIPANT	\N	PRESENT	0
702489	701622	11026G	PARTICIPANT	\N	PRESENT	0
702490	701622	95063L	PARTICIPANT	\N	PRESENT	0
702491	701622	19629C	PARTICIPANT	\N	PRESENT	0
702492	701622	14001X	PARTICIPANT	\N	PRESENT	0
702493	701622	05008E	PARTICIPANT	\N	PRESENT	0
702494	701622	19489J	PARTICIPANT	\N	PRESENT	0
702495	701622	19725B	PARTICIPANT	\N	PRESENT	0
702496	701622	14069U	PARTICIPANT	\N	PRESENT	0
702497	701622	04008A	PARTICIPANT	\N	PRESENT	0
702498	701622	11056N	PARTICIPANT	\N	PRESENT	0
702500	701622	14053L	PARTICIPANT	\N	PRESENT	0
702501	701622	17737W	PARTICIPANT	\N	PRESENT	0
702502	701536	20130U	PARTICIPANT	\N	PRESENT	0
702503	701536	19479G	PARTICIPANT	\N	PRESENT	0
702504	701536	11067R	PARTICIPANT	\N	PRESENT	0
702505	701536	19798U	PARTICIPANT	\N	PRESENT	0
702506	701536	11097X	PARTICIPANT	\N	PRESENT	0
702507	701536	20040T	PARTICIPANT	\N	PRESENT	0
702508	701536	17965H	PARTICIPANT	\N	PRESENT	0
702509	701536	19691J	PARTICIPANT	\N	PRESENT	0
702510	701536	19715Y	PARTICIPANT	\N	PRESENT	0
702511	701536	19717B	PARTICIPANT	\N	PRESENT	0
702512	701536	17779H	PARTICIPANT	\N	PRESENT	0
702513	701536	19553Y	PARTICIPANT	\N	PRESENT	0
702514	701536	14281W	PARTICIPANT	\N	PRESENT	0
702515	701536	19679N	PARTICIPANT	\N	PRESENT	0
702516	701536	14042U	PARTICIPANT	\N	PRESENT	0
702517	701536	14195A	PARTICIPANT	\N	PRESENT	0
702518	701536	14213J	PARTICIPANT	\N	PRESENT	0
702519	701536	19367Y	PARTICIPANT	\N	PRESENT	0
702520	701536	14071N	PARTICIPANT	\N	PRESENT	0
702521	701536	14217N	PRESIDENT	1	PRESENT	0
702522	701536	19511N	PARTICIPANT	\N	PRESENT	0
702523	701536	19760E	PARTICIPANT	\N	PRESENT	0
702565	698972	20102Q	PARTICIPANT	\N	PRESENT	0
702566	698972	19637C	PARTICIPANT	\N	EXCUSE	0
702567	701623	20074E	PARTICIPANT	\N	PRESENT	0
702568	701623	14001X	PARTICIPANT	\N	PRESENT	0
702569	701623	19581D	PARTICIPANT	\N	PRESENT	0
702570	701623	04047H	PRESIDENT	0	PRESENT	0
702571	701623	19673G	PARTICIPANT	\N	PRESENT	0
702572	701623	19675J	PARTICIPANT	\N	PRESENT	0
702573	701623	19447X	PARTICIPANT	\N	PRESENT	0
702574	701623	05008E	PARTICIPANT	\N	PRESENT	0
702575	701623	19954N	PARTICIPANT	\N	PRESENT	0
702576	701623	19489J	PARTICIPANT	\N	PRESENT	0
702577	701623	17737W	PARTICIPANT	\N	PRESENT	0
702578	701623	20110Q	PARTICIPANT	\N	PRESENT	0
702579	701623	14147R	PARTICIPANT	\N	PRESENT	0
702580	701623	20114U	PARTICIPANT	\N	PRESENT	0
702581	701623	14215L	PARTICIPANT	\N	PRESENT	0
702582	701623	20022R	PARTICIPANT	\N	PRESENT	0
702583	701623	11072N	PARTICIPANT	\N	PRESENT	0
702584	701623	14053L	PARTICIPANT	\N	PRESENT	0
702585	701623	14111D	PARTICIPANT	\N	PRESENT	0
702586	701623	19649G	PARTICIPANT	\N	PRESENT	0
702587	701623	11010L	PARTICIPANT	\N	PRESENT	0
702588	701623	10015M	PARTICIPANT	\N	PRESENT	0
702589	701623	11033F	PARTICIPANT	\N	PRESENT	0
702590	701623	19725B	PARTICIPANT	\N	PRESENT	0
702591	701623	11056N	PARTICIPANT	\N	PRESENT	0
702592	701623	95063L	PARTICIPANT	\N	PRESENT	0
702593	701623	19629C	PARTICIPANT	\N	PRESENT	0
702594	701623	14069U	PARTICIPANT	\N	PRESENT	0
702595	701623	04008A	PARTICIPANT	\N	PRESENT	0
702596	701623	14021P	PARTICIPANT	\N	PRESENT	0
702597	701623	19301E	PARTICIPANT	\N	EXCUSE	0
702598	701623	19585H	PARTICIPANT	\N	EXCUSE	0
702599	701623	14259Y	PARTICIPANT	\N	EXCUSE	0
702600	698972	18083K	PARTICIPANT	\N	PRESENT	0
702601	698972	11101A	PARTICIPANT	\N	PRESENT	0
702602	698972	19599P	PARTICIPANT	\N	PRESENT	0
702603	698972	17229F	PARTICIPANT	\N	PRESENT	0
702604	700257	19699S	PARTICIPANT	\N	PRESENT	0
702605	700257	19573D	PARTICIPANT	\N	PRESENT	0
702606	700257	19527W	PARTICIPANT	\N	PRESENT	0
702607	700257	14109K	PARTICIPANT	\N	PRESENT	0
702608	698972	19333N	PARTICIPANT	\N	PRESENT	0
702609	698972	19701S	PARTICIPANT	\N	PRESENT	0
702610	698972	20136B	PARTICIPANT	\N	PRESENT	0
702611	698972	20140W	PARTICIPANT	\N	PRESENT	0
702612	698972	19826F	PARTICIPANT	\N	PRESENT	0
702613	698972	14221J	PARTICIPANT	\N	PRESENT	0
702614	698972	14169X	PARTICIPANT	\N	PRESENT	0
702615	698972	08060W	PARTICIPANT	\N	PRESENT	0
702617	698972	14031R	PARTICIPANT	\N	PRESENT	0
702618	698972	19387D	PARTICIPANT	\N	PRESENT	0
702619	698972	20096L	PARTICIPANT	\N	PRESENT	0
702621	698972	20032T	PARTICIPANT	\N	PRESENT	0
702622	698972	20020P	PARTICIPANT	\N	PRESENT	0
702623	701623	14231L	PARTICIPANT	\N	PRESENT	0
702624	701623	14107H	PARTICIPANT	\N	PRESENT	0
702625	701623	08018U	PARTICIPANT	\N	PRESENT	0
710334	710333	19553Y	PARTICIPANT	\N	PRESENT	0
710335	710333	14083S	PARTICIPANT	\N	PRESENT	0
710340	706234	19583F	PARTICIPANT	\N	EXCUSE	0
710680	708161	19675J	PARTICIPANT	\N	PRESENT	0
710681	708161	14267Y	PARTICIPANT	\N	PRESENT	0
710682	708161	20252E	PARTICIPANT	\N	PRESENT	0
710683	708161	20152B	PARTICIPANT	\N	PRESENT	0
710684	708161	20020P	PARTICIPANT	\N	PRESENT	0
710685	708161	07029T	PARTICIPANT	\N	PRESENT	0
710686	708161	14071N	PARTICIPANT	\N	PRESENT	0
710687	708161	18193Q	PARTICIPANT	\N	PRESENT	0
710688	708161	19747H	PARTICIPANT	\N	PRESENT	0
710689	708161	11077T	PARTICIPANT	\N	PRESENT	0
710690	708161	19766L	PARTICIPANT	\N	PRESENT	0
710691	708161	20144B	PARTICIPANT	\N	PRESENT	0
710692	708161	20076G	PARTICIPANT	\N	PRESENT	0
710693	708161	18083K	PARTICIPANT	\N	PRESENT	0
710694	708161	14225N	PARTICIPANT	\N	PRESENT	0
710695	708161	20028X	PARTICIPANT	\N	PRESENT	0
710696	708161	11097X	PARTICIPANT	\N	PRESENT	0
710697	708161	14223L	PARTICIPANT	\N	PRESENT	0
710698	708161	20914V	PARTICIPANT	\N	PRESENT	0
710699	708161	10015M	PARTICIPANT	\N	PRESENT	0
710700	708161	11043H	PARTICIPANT	\N	PRESENT	0
710701	708161	20092G	PARTICIPANT	\N	PRESENT	0
710702	708161	20100N	PARTICIPANT	\N	PRESENT	0
710703	708161	08010L	PARTICIPANT	\N	PRESENT	0
710704	708161	04092N	PARTICIPANT	\N	PRESENT	0
710705	708161	08045X	PARTICIPANT	\N	PRESENT	0
710706	708161	04059M	PARTICIPANT	\N	PRESENT	0
710707	708161	04085P	PARTICIPANT	\N	PRESENT	0
710708	708161	01024M	PARTICIPANT	\N	PRESENT	0
710709	708161	19798U	PARTICIPANT	\N	PRESENT	0
710710	708161	19333N	PARTICIPANT	\N	PRESENT	0
710711	708161	14151M	PARTICIPANT	\N	PRESENT	0
710712	708161	01057W	PARTICIPANT	\N	PRESENT	0
710713	708161	19758L	PARTICIPANT	\N	PRESENT	0
710714	708161	19515S	PARTICIPANT	\N	PRESENT	0
710715	708161	20096L	PARTICIPANT	\N	PRESENT	0
710716	708161	10006L	PARTICIPANT	\N	PRESENT	0
710717	708161	14042U	PARTICIPANT	\N	PRESENT	0
710718	708161	20136B	PARTICIPANT	\N	PRESENT	0
710719	708161	20088L	PARTICIPANT	\N	PRESENT	0
710720	708161	14031R	PARTICIPANT	\N	PRESENT	0
710721	708161	14257W	PARTICIPANT	\N	PRESENT	0
710722	708161	20120S	PARTICIPANT	\N	PRESENT	0
710723	708161	17965H	PARTICIPANT	\N	PRESENT	0
710724	708161	19551W	PARTICIPANT	\N	PRESENT	0
710725	708161	19527W	PARTICIPANT	\N	PRESENT	0
710726	708161	17367Q	PARTICIPANT	\N	PRESENT	0
710727	708161	20064C	PARTICIPANT	\N	PRESENT	0
710728	708161	20056C	PARTICIPANT	\N	PRESENT	0
710729	708161	20108W	PARTICIPANT	\N	PRESENT	0
710730	708161	20110Q	PARTICIPANT	\N	PRESENT	0
710731	708161	14259Y	PARTICIPANT	\N	PRESENT	0
710732	708161	11099A	PARTICIPANT	\N	PRESENT	0
710733	708161	20084G	PARTICIPANT	\N	PRESENT	0
710734	708161	04047H	PARTICIPANT	\N	PRESENT	0
710735	708161	08034U	PARTICIPANT	\N	PRESENT	0
710736	708161	20128B	PARTICIPANT	\N	PRESENT	0
710737	708161	14281W	PARTICIPANT	\N	PRESENT	0
710738	708161	19669L	PARTICIPANT	\N	PRESENT	0
710739	708161	14187A	PARTICIPANT	\N	PRESENT	0
710740	708161	19683J	PARTICIPANT	\N	PRESENT	0
710741	708161	14021P	PARTICIPANT	\N	PRESENT	0
710742	708161	20172F	PARTICIPANT	\N	PRESENT	0
710743	708161	99004R	PARTICIPANT	\N	PRESENT	0
710744	708161	17779H	PARTICIPANT	\N	PRESENT	0
710745	708161	20072C	PARTICIPANT	\N	PRESENT	0
710746	708161	19681G	PARTICIPANT	\N	PRESENT	0
710747	708161	08015R	PARTICIPANT	\N	PRESENT	0
710748	708161	11031D	PARTICIPANT	\N	PRESENT	0
710749	708161	19768N	PARTICIPANT	\N	PRESENT	0
710750	708161	14211G	PARTICIPANT	\N	PRESENT	0
710751	708161	20038A	PARTICIPANT	\N	PRESENT	0
710752	708161	19573D	PARTICIPANT	\N	PRESENT	0
710753	708161	11104D	PARTICIPANT	\N	PRESENT	0
710754	708161	19467C	PARTICIPANT	\N	PRESENT	0
710755	708161	19745F	PARTICIPANT	\N	PRESENT	0
710756	708161	14327T	PARTICIPANT	\N	PRESENT	0
710757	708161	19739H	PARTICIPANT	\N	PRESENT	0
710758	708161	19762G	PARTICIPANT	\N	PRESENT	0
710759	708161	19415P	PARTICIPANT	\N	PRESENT	0
710760	708161	19629C	PARTICIPANT	\N	PRESENT	0
710761	708161	12028B	PARTICIPANT	\N	PRESENT	0
710762	708161	14207L	PARTICIPANT	\N	PRESENT	0
710763	708161	14217N	PARTICIPANT	\N	PRESENT	0
710764	708161	08009T	PARTICIPANT	\N	PRESENT	0
710765	708161	14026U	PARTICIPANT	\N	PRESENT	0
710766	708161	14073Q	PARTICIPANT	\N	PRESENT	0
710839	705810	11031D	PARTICIPANT	\N	EXCUSE	0
710768	708161	95041E	PARTICIPANT	\N	PRESENT	0
710769	708161	19619A	PARTICIPANT	\N	PRESENT	0
710770	708161	19569H	PARTICIPANT	\N	PRESENT	0
710771	708161	19621T	PARTICIPANT	\N	PRESENT	0
710772	708161	04070G	PARTICIPANT	\N	PRESENT	0
710773	708161	11033F	PARTICIPANT	\N	PRESENT	0
710774	708161	20126Y	PARTICIPANT	\N	PRESENT	0
710775	708161	04045F	PARTICIPANT	\N	PRESENT	0
710776	708161	11072N	PARTICIPANT	\N	PRESENT	0
710777	708161	14089Y	PARTICIPANT	\N	PRESENT	0
710778	708161	14109K	PARTICIPANT	\N	PRESENT	0
710779	708161	19697Q	PARTICIPANT	\N	PRESENT	0
710780	708161	12016W	PARTICIPANT	\N	PRESENT	0
710781	708161	14053L	PARTICIPANT	\N	PRESENT	0
710782	708161	20060X	PARTICIPANT	\N	PRESENT	0
710783	708161	19701S	PARTICIPANT	\N	PRESENT	0
710784	708161	01028R	PARTICIPANT	\N	PRESENT	0
710785	708161	19329S	PARTICIPANT	\N	PRESENT	0
710786	708161	19657G	PARTICIPANT	\N	PRESENT	0
710787	708161	14037X	PARTICIPANT	\N	PRESENT	0
710788	708161	19659J	PARTICIPANT	\N	PRESENT	0
710789	708161	19703U	PARTICIPANT	\N	PRESENT	0
710790	708161	11012A	PARTICIPANT	\N	PRESENT	0
710791	710339	20052X	PARTICIPANT	\N	PRESENT	0
710792	708161	08018U	PARTICIPANT	\N	PRESENT	0
710793	708161	14033T	PARTICIPANT	\N	PRESENT	0
710794	708161	01062T	PARTICIPANT	\N	PRESENT	0
710795	708161	19543W	PARTICIPANT	\N	PRESENT	0
710796	708161	20102Q	PARTICIPANT	\N	PRESENT	0
710797	708161	04033B	PARTICIPANT	\N	PRESENT	0
710798	708161	19699S	PARTICIPANT	\N	PRESENT	0
710799	708161	12041X	PARTICIPANT	\N	PRESENT	0
710800	708161	20040T	PARTICIPANT	\N	PRESENT	0
710810	708161	20264J	PARTICIPANT	\N	PRESENT	0
710802	708161	20132W	PARTICIPANT	\N	PRESENT	0
710803	708161	20122U	PARTICIPANT	\N	PRESENT	0
710804	708161	20054A	PARTICIPANT	\N	PRESENT	0
710805	708161	11110B	PARTICIPANT	\N	PRESENT	0
710807	708161	19533U	PARTICIPANT	\N	PRESENT	0
710808	710339	19713W	PARTICIPANT	\N	PRESENT	0
710809	708161	14133K	PARTICIPANT	\N	PRESENT	0
710811	708161	14229S	PARTICIPANT	\N	PRESENT	0
710812	708161	11045K	PARTICIPANT	\N	PRESENT	0
710813	708161	19729F	PARTICIPANT	\N	PRESENT	0
710814	708161	11054L	PARTICIPANT	\N	PRESENT	0
710815	708161	19413M	PARTICIPANT	\N	PRESENT	0
710816	708161	08069G	PARTICIPANT	\N	PRESENT	0
710817	708161	20106U	PARTICIPANT	\N	PRESENT	0
710818	708161	19591F	PARTICIPANT	\N	PRESENT	0
710819	708161	01048V	PARTICIPANT	\N	PRESENT	0
710820	706384	19593H	PARTICIPANT	\N	PRESENT	0
710821	706384	19643A	PARTICIPANT	\N	PRESENT	0
710822	706384	04070G	PARTICIPANT	\N	PRESENT	0
710823	706384	20134Y	PARTICIPANT	\N	PRESENT	0
710824	706384	20064C	PARTICIPANT	\N	PRESENT	0
710825	706384	14251Q	PRESIDENT	0	PRESENT	0
710826	706384	20068G	PARTICIPANT	\N	PRESENT	0
710827	706384	11083R	PARTICIPANT	\N	PRESENT	0
710828	706384	11090Q	PARTICIPANT	\N	PRESENT	0
710829	706384	19717B	PARTICIPANT	\N	PRESENT	0
710830	706384	20152B	PARTICIPANT	\N	PRESENT	0
710831	706384	19711U	PARTICIPANT	\N	EXCUSE	0
710832	706384	14193X	PARTICIPANT	\N	EXCUSE	0
710833	708161	19367Y	PARTICIPANT	\N	PRESENT	0
710834	708161	04043D	PARTICIPANT	\N	PRESENT	0
710835	708161	97011G	PARTICIPANT	\N	PRESENT	0
710836	708161	19563B	PARTICIPANT	\N	PRESENT	0
710837	708161	20070A	PARTICIPANT	\N	PRESENT	0
710838	708161	14083S	PARTICIPANT	\N	PRESENT	0
710840	705810	20080C	PARTICIPANT	\N	EXCUSE	0
689092	688394	19251M	PARTICIPANT	\N	PRESENT	0
689093	688394	20020P	PARTICIPANT	\N	PRESENT	0
689094	688394	19826F	PARTICIPANT	\N	PRESENT	0
689095	688394	20046A	PARTICIPANT	\N	PRESENT	0
689096	688394	20102Q	PARTICIPANT	\N	PRESENT	0
689097	688394	19525U	PARTICIPANT	\N	PRESENT	0
689098	688645	19467C	PARTICIPANT	\N	PRESENT	0
689099	688645	20130U	PARTICIPANT	\N	PRESENT	0
689100	688645	11012A	PARTICIPANT	\N	PRESENT	0
689101	688394	18083K	PARTICIPANT	\N	PRESENT	0
689102	688394	19333N	PARTICIPANT	\N	PRESENT	0
689103	688394	20032T	PARTICIPANT	\N	PRESENT	0
689104	688394	14219Q	PRESIDENT	0	PRESENT	0
689105	688394	14031R	PARTICIPANT	\N	PRESENT	0
689106	688394	19820Y	PARTICIPANT	\N	PRESENT	0
689107	688394	17229F	PARTICIPANT	\N	PRESENT	0
689108	688394	20118Y	PARTICIPANT	\N	PRESENT	0
689109	688394	19503N	PARTICIPANT	\N	PRESENT	0
689110	688394	20024T	PARTICIPANT	\N	PRESENT	0
689185	688646	20030R	PARTICIPANT	\N	PRESENT	0
691358	690826	14038Y	PARTICIPANT	\N	PRESENT	0
691359	690826	14257W	PARTICIPANT	\N	PRESENT	0
691360	690826	19333N	PARTICIPANT	\N	PRESENT	0
691361	690826	11090Q	PARTICIPANT	\N	PRESENT	0
691362	690826	14033T	PARTICIPANT	\N	PRESENT	0
691363	690826	19563B	PARTICIPANT	\N	PRESENT	0
691364	690826	19533U	PARTICIPANT	\N	PRESENT	0
691365	690826	19369B	PARTICIPANT	\N	PRESENT	0
691366	690826	20092G	PARTICIPANT	\N	PRESENT	0
691367	690826	19629C	PARTICIPANT	\N	PRESENT	0
691368	690826	20124W	PARTICIPANT	\N	PRESENT	0
691369	690826	19798U	PARTICIPANT	\N	PRESENT	0
691370	690826	19866P	PARTICIPANT	\N	PRESENT	0
691371	690826	19695N	PARTICIPANT	\N	PRESENT	0
691372	690826	20062A	PARTICIPANT	\N	PRESENT	0
691373	690826	19413M	PARTICIPANT	\N	PRESENT	0
691374	690826	20018V	PARTICIPANT	\N	PRESENT	0
691375	690826	20116W	PARTICIPANT	\N	PRESENT	0
691376	690826	19826F	PARTICIPANT	\N	PRESENT	0
691377	690826	19954N	PARTICIPANT	\N	PRESENT	0
691378	690826	20180F	PARTICIPANT	\N	PRESENT	0
691379	690826	20026V	PARTICIPANT	\N	PRESENT	0
691380	690826	19447X	PARTICIPANT	\N	PRESENT	0
691381	690826	20034V	PARTICIPANT	\N	PRESENT	0
691382	690826	19782L	PARTICIPANT	\N	PRESENT	0
691383	690826	20142Y	PARTICIPANT	\N	PRESENT	0
691384	690826	20046A	PARTICIPANT	\N	PRESENT	0
691385	690826	19503N	PARTICIPANT	\N	PRESENT	0
691386	690826	19467C	PARTICIPANT	\N	PRESENT	0
691387	690826	08015R	PARTICIPANT	\N	PRESENT	0
691388	690826	19703U	PARTICIPANT	\N	PRESENT	0
691389	690826	19820Y	PARTICIPANT	\N	PRESENT	0
691390	690826	11065P	PARTICIPANT	\N	PRESENT	0
691391	690826	20914V	PARTICIPANT	\N	PRESENT	0
691392	690826	11056N	PARTICIPANT	\N	PRESENT	0
691393	690826	19758L	PARTICIPANT	\N	PRESENT	0
691394	690826	20126Y	PARTICIPANT	\N	PRESENT	0
691395	690826	14069U	PARTICIPANT	\N	PRESENT	0
691396	690826	19575F	PARTICIPANT	\N	PRESENT	0
691397	690826	14193X	PARTICIPANT	\N	PRESENT	0
691398	690826	20064C	PARTICIPANT	\N	PRESENT	0
691399	690826	14147R	PARTICIPANT	\N	PRESENT	0
691400	690826	07029T	PARTICIPANT	\N	PRESENT	0
691401	690826	20100N	PARTICIPANT	\N	PRESENT	0
691402	690826	20038A	PARTICIPANT	\N	PRESENT	0
691403	690826	14215L	PARTICIPANT	\N	PRESENT	0
691404	690826	20104S	PARTICIPANT	\N	PRESENT	0
691405	690826	14219Q	PARTICIPANT	\N	PRESENT	0
691406	690826	14231L	PARTICIPANT	\N	PRESENT	0
691407	690826	20134Y	PARTICIPANT	\N	PRESENT	0
691350	690826	11070L	PARTICIPANT	\N	PRESENT	0
691357	690826	19251M	PARTICIPANT	\N	PRESENT	0
691408	690826	14179A	PARTICIPANT	\N	PRESENT	0
691409	690826	20298U	PARTICIPANT	\N	PRESENT	0
691410	690826	20070A	PARTICIPANT	\N	PRESENT	0
691411	690826	08061X	PARTICIPANT	\N	PRESENT	0
691412	690826	19679N	PARTICIPANT	\N	PRESENT	0
691413	690826	14071N	PARTICIPANT	\N	PRESENT	0
691414	690826	19701S	PARTICIPANT	\N	PRESENT	0
691415	690826	19565D	PARTICIPANT	\N	PRESENT	0
691416	690826	19762G	PARTICIPANT	\N	PRESENT	0
691417	690826	19383Y	PARTICIPANT	\N	PRESENT	0
691418	690826	14187A	PARTICIPANT	\N	PRESENT	0
691419	690826	14133K	PARTICIPANT	\N	PRESENT	0
691420	690826	19507S	PARTICIPANT	\N	PRESENT	0
691421	690826	11097X	PARTICIPANT	\N	PRESENT	0
691422	690826	20086J	PARTICIPANT	\N	PRESENT	0
691423	690826	20110Q	PARTICIPANT	\N	PRESENT	0
691424	690826	20032T	PARTICIPANT	\N	PRESENT	0
691425	690826	14213J	PARTICIPANT	\N	PRESENT	0
691426	690826	19479G	PARTICIPANT	\N	PRESENT	0
691427	690826	19347U	PARTICIPANT	\N	PRESENT	0
691428	690826	20094J	PARTICIPANT	\N	PRESENT	0
691429	690826	19441R	PARTICIPANT	\N	PRESENT	0
691430	690826	20144B	PARTICIPANT	\N	PRESENT	0
691431	690826	20066E	PARTICIPANT	\N	PRESENT	0
691432	690826	14083S	PARTICIPANT	\N	PRESENT	0
691433	690826	20042V	PARTICIPANT	\N	PRESENT	0
691434	690826	20082E	PARTICIPANT	\N	PRESENT	0
691435	690826	20252E	PARTICIPANT	\N	PRESENT	0
691436	690826	20172F	PARTICIPANT	\N	PRESENT	0
691437	690826	14109K	PARTICIPANT	\N	PRESENT	0
691442	688931	20032T	PARTICIPANT	\N	PRESENT	0
691443	688931	19387D	PARTICIPANT	\N	PRESENT	0
691444	688931	14219Q	PRESIDENT	0	PRESENT	0
691445	688931	19820Y	PARTICIPANT	\N	PRESENT	0
691446	688931	19826F	PARTICIPANT	\N	PRESENT	0
691447	688931	20046A	PARTICIPANT	\N	PRESENT	0
691448	688931	20102Q	PARTICIPANT	\N	PRESENT	0
691449	688931	17229F	PARTICIPANT	\N	PRESENT	0
691450	688931	19637C	PARTICIPANT	\N	PRESENT	0
691451	688931	14237S	PARTICIPANT	\N	PRESENT	0
691452	688931	11056N	PARTICIPANT	\N	PRESENT	0
691453	688931	19954N	PARTICIPANT	\N	PRESENT	0
691454	688931	95063L	PARTICIPANT	\N	PRESENT	0
691455	688931	19745F	PARTICIPANT	\N	PRESENT	0
691456	688931	17367Q	PARTICIPANT	\N	PRESENT	0
691457	688931	19619A	PARTICIPANT	\N	PRESENT	0
691481	688931	14221J	PARTICIPANT	\N	PRESENT	0
691482	688931	18083K	PARTICIPANT	\N	PRESENT	0
691483	688931	20118Y	PARTICIPANT	\N	PRESENT	0
691484	688931	19503N	PARTICIPANT	\N	PRESENT	0
691485	688931	20020P	PARTICIPANT	\N	PRESENT	0
691486	688931	20024T	PARTICIPANT	\N	PRESENT	0
691487	688931	19525U	PARTICIPANT	\N	PRESENT	0
691488	688931	20038A	PARTICIPANT	\N	PRESENT	0
691489	688931	14031R	PARTICIPANT	\N	PRESENT	0
691490	688931	19659J	PARTICIPANT	\N	PRESENT	0
691492	688931	19701S	PARTICIPANT	\N	PRESENT	0
691493	688931	08060W	PARTICIPANT	\N	PRESENT	0
691494	688931	19333N	PARTICIPANT	\N	PRESENT	0
691495	688931	05012A	PARTICIPANT	\N	PRESENT	0
691496	688931	19739H	PARTICIPANT	\N	PRESENT	0
691511	688931	20076G	PARTICIPANT	\N	PRESENT	0
691513	688931	19681G	PARTICIPANT	\N	PRESENT	0
691516	688931	11065P	PARTICIPANT	\N	PRESENT	0
691518	688931	11101A	PARTICIPANT	\N	PRESENT	0
691519	690386	19699S	PARTICIPANT	\N	PRESENT	0
691520	690386	19533U	PARTICIPANT	\N	PRESENT	0
691521	690386	04033B	PARTICIPANT	\N	PRESENT	0
691522	690386	20098N	PARTICIPANT	\N	PRESENT	0
691523	690386	19573D	PARTICIPANT	\N	PRESENT	0
691524	690386	08012N	PARTICIPANT	\N	PRESENT	0
691525	690386	20124W	PARTICIPANT	\N	PRESENT	0
691526	690386	20026V	PARTICIPANT	\N	PRESENT	0
691527	690386	19593H	PARTICIPANT	\N	PRESENT	0
691528	690386	19643A	PARTICIPANT	\N	PRESENT	0
691529	690386	20132W	PARTICIPANT	\N	PRESENT	0
691530	690386	14073Q	PARTICIPANT	\N	PRESENT	0
691531	690386	20138D	PARTICIPANT	\N	PRESENT	0
691532	690386	19611R	PRESIDENT	0	PRESENT	0
691533	690386	20142Y	PARTICIPANT	\N	PRESENT	0
691534	690386	19399H	PARTICIPANT	\N	PRESENT	0
691535	690386	20152B	PARTICIPANT	\N	PRESENT	0
691536	690386	20052X	PARTICIPANT	\N	PRESENT	0
691537	690386	14030Q	PARTICIPANT	\N	PRESENT	0
691538	690386	20056C	PARTICIPANT	\N	PRESENT	0
691539	690386	20180F	PARTICIPANT	\N	PRESENT	0
691540	690386	04059M	PARTICIPANT	\N	PRESENT	0
691541	690386	14109K	PARTICIPANT	\N	PRESENT	0
691542	690386	14123H	PARTICIPANT	\N	PRESENT	0
703135	701645	20082E	PARTICIPANT	\N	PRESENT	0
704048	704047	17023S	PARTICIPANT	\N	PRESENT	0
704152	704145	20090E	PARTICIPANT	\N	PRESENT	1
704153	704145	14281W	PARTICIPANT	\N	PRESENT	1
704154	704145	19798U	PARTICIPANT	\N	PRESENT	1
704155	704145	19691J	PARTICIPANT	\N	PRESENT	0
704157	704156	14133K	PARTICIPANT	\N	PRESENT	0
704159	704158	11064N	PARTICIPANT	\N	PRESENT	0
704160	704158	12028B	PARTICIPANT	\N	PRESENT	0
704162	704161	12028B	PARTICIPANT	\N	PRESENT	0
704163	704161	11064N	PARTICIPANT	\N	PRESENT	0
704191	704186	14195A	PARTICIPANT	\N	PRESENT	0
704192	704186	20090E	PARTICIPANT	\N	PRESENT	0
704193	704186	18193Q	PARTICIPANT	\N	PRESENT	0
704194	704187	14195A	PARTICIPANT	\N	PRESENT	0
704195	704187	18193Q	PARTICIPANT	\N	PRESENT	0
704196	704188	14195A	PARTICIPANT	\N	PRESENT	0
704197	704188	20090E	PARTICIPANT	\N	PRESENT	0
704198	704188	18193Q	PARTICIPANT	\N	PRESENT	0
704199	704189	20090E	PARTICIPANT	\N	PRESENT	0
704200	704189	14195A	PARTICIPANT	\N	PRESENT	0
704202	704201	20034V	PARTICIPANT	\N	PRESENT	0
704204	704203	20034V	PARTICIPANT	\N	PRESENT	0
704206	704205	20034V	PARTICIPANT	\N	PRESENT	0
704208	704207	19447X	PARTICIPANT	\N	PRESENT	0
704209	704207	14089Y	PARTICIPANT	\N	PRESENT	0
704210	704207	11026G	PARTICIPANT	\N	PRESENT	0
704230	704229	05008E	PARTICIPANT	\N	PRESENT	0
704231	704229	11053K	PARTICIPANT	\N	PRESENT	0
704234	704232	14179A	PARTICIPANT	\N	PRESENT	0
704235	704233	14179A	PARTICIPANT	\N	PRESENT	0
704237	704236	11027H	PARTICIPANT	\N	PRESENT	0
704242	704241	14121F	PARTICIPANT	\N	PRESENT	0
704244	704243	14121F	PARTICIPANT	\N	PRESENT	0
704246	704245	14329V	PARTICIPANT	\N	EXCUSE	0
704256	704255	19479G	PARTICIPANT	\N	PRESENT	0
704270	704269	19479G	PARTICIPANT	\N	PRESENT	0
704272	704271	19479G	PARTICIPANT	\N	PRESENT	0
704274	704273	19479G	PARTICIPANT	\N	PRESENT	0
704276	704275	19479G	PARTICIPANT	\N	PRESENT	0
704278	704277	19711U	PARTICIPANT	\N	PRESENT	0
704280	704279	14327T	PARTICIPANT	\N	PRESENT	0
704281	699132	05008E	PARTICIPANT	\N	EXCUSE	0
704305	699132	11010L	PARTICIPANT	\N	EXCUSE	0
704306	699132	14331P	PARTICIPANT	\N	EXCUSE	0
704307	699132	11043H	PARTICIPANT	\N	EXCUSE	0
704315	699132	14147R	PARTICIPANT	\N	EXCUSE	0
704328	704316	19565D	PARTICIPANT	\N	EXCUSE	0
704333	704214	19725B	PARTICIPANT	\N	PRESENT	0
704334	704214	11031D	PARTICIPANT	\N	PRESENT	0
704335	704214	20138D	PARTICIPANT	\N	PRESENT	0
704336	704214	20066E	PARTICIPANT	\N	PRESENT	0
704337	704214	19735D	PRESIDENT	0	PRESENT	0
704338	704214	17965H	PARTICIPANT	\N	PRESENT	0
704339	704214	20024T	PARTICIPANT	\N	PRESENT	0
704342	704214	14213J	PARTICIPANT	\N	PRESENT	0
704343	704214	04045F	PARTICIPANT	\N	PRESENT	0
704344	704214	19369B	PARTICIPANT	\N	EXCUSE	0
704346	704345	19691J	PARTICIPANT	\N	PRESENT	1
704347	704345	20090E	PARTICIPANT	\N	PRESENT	0
704376	704216	19697Q	PARTICIPANT	\N	PRESENT	0
704377	704216	11067R	PARTICIPANT	\N	PRESENT	0
704378	704216	14355X	PARTICIPANT	\N	PRESENT	0
704379	704216	19569H	PARTICIPANT	\N	PRESENT	0
704380	704216	19798U	PARTICIPANT	\N	PRESENT	0
704381	704216	11097X	PARTICIPANT	\N	PRESENT	0
704382	704216	19415P	PARTICIPANT	\N	PRESENT	0
704383	704216	18193Q	PARTICIPANT	\N	PRESENT	0
704384	704216	14223L	PARTICIPANT	\N	PRESENT	0
704385	704216	17779H	PARTICIPANT	\N	PRESENT	0
704386	704216	19703U	PARTICIPANT	\N	PRESENT	0
704387	704216	19553Y	PARTICIPANT	\N	PRESENT	0
704388	704216	19679N	PARTICIPANT	\N	PRESENT	0
704389	704216	14042U	PARTICIPANT	\N	PRESENT	0
704390	704216	14195A	PARTICIPANT	\N	PRESENT	0
704391	704216	14213J	PARTICIPANT	\N	PRESENT	0
704392	704216	19511N	PARTICIPANT	\N	PRESENT	0
704393	704216	19683J	PARTICIPANT	\N	PRESENT	0
704394	704216	10006L	PRESIDENT	0	PRESENT	0
704395	704216	19591F	PARTICIPANT	\N	PRESENT	0
704396	704216	20130U	PARTICIPANT	\N	PRESENT	0
704397	704216	01034P	PARTICIPANT	\N	PRESENT	0
704398	704216	04092N	PARTICIPANT	\N	PRESENT	0
704399	704216	11045K	PARTICIPANT	\N	PRESENT	0
704400	704216	20040T	PARTICIPANT	\N	PRESENT	0
704401	704216	19691J	PARTICIPANT	\N	PRESENT	0
704402	704216	19717B	PARTICIPANT	\N	PRESENT	0
704403	704216	20148F	PARTICIPANT	\N	PRESENT	0
704404	704216	20248J	PARTICIPANT	\N	PRESENT	0
704405	704216	20066E	PARTICIPANT	\N	PRESENT	0
704406	704216	19760E	PARTICIPANT	\N	PRESENT	0
704438	704216	08045X	PARTICIPANT	\N	PRESENT	0
704439	704216	19723Y	PARTICIPANT	\N	PRESENT	0
704440	704216	20266L	PARTICIPANT	\N	PRESENT	0
704443	704329	11048N	PARTICIPANT	\N	PRESENT	0
704444	704329	14225N	PRESIDENT	0	PRESENT	0
704446	704216	17965H	PARTICIPANT	\N	PRESENT	0
704447	704329	14327T	PARTICIPANT	\N	PRESENT	0
704448	704329	14331P	PARTICIPANT	\N	PRESENT	0
704449	704329	11053K	PARTICIPANT	\N	PRESENT	0
704450	704329	20080C	PARTICIPANT	\N	PRESENT	0
704451	704329	11074Q	PARTICIPANT	\N	PRESENT	0
704452	704329	19667J	PARTICIPANT	\N	PRESENT	0
704453	704329	19671E	PARTICIPANT	\N	PRESENT	0
704454	704329	11070L	PARTICIPANT	\N	PRESENT	0
704455	704329	07029T	PARTICIPANT	\N	PRESENT	0
704456	704329	19349W	PARTICIPANT	\N	PRESENT	0
704457	704329	19335Q	PARTICIPANT	\N	PRESENT	0
704458	704329	20126Y	PARTICIPANT	\N	PRESENT	0
704459	704329	19479G	PARTICIPANT	\N	PRESENT	0
704460	704329	19647E	PARTICIPANT	\N	PRESENT	0
704461	704329	08034U	PARTICIPANT	\N	PRESENT	0
704462	704329	19531S	PARTICIPANT	\N	PRESENT	0
704463	704329	20044X	PARTICIPANT	\N	PRESENT	0
704464	704329	11040E	PARTICIPANT	\N	PRESENT	0
704465	704329	14083S	PARTICIPANT	\N	PRESENT	0
704466	704329	11012A	PARTICIPANT	\N	PRESENT	0
704467	704329	08009T	PARTICIPANT	\N	PRESENT	0
704468	704329	20914V	PARTICIPANT	\N	PRESENT	0
704469	704329	99004R	PARTICIPANT	\N	PRESENT	0
704470	704216	11031D	PARTICIPANT	\N	PRESENT	0
704472	704329	08010L	PARTICIPANT	\N	PRESENT	0
704474	704329	20086J	PARTICIPANT	\N	PRESENT	0
704475	704363	19383Y	PARTICIPANT	\N	PRESENT	0
704476	704363	20032T	PARTICIPANT	\N	PRESENT	0
704477	704363	01043Q	PRESIDENT	0	PRESENT	0
704478	704363	20298U	PARTICIPANT	\N	PRESENT	0
704479	704363	20046A	PARTICIPANT	\N	PRESENT	0
704481	704363	19631V	PARTICIPANT	\N	PRESENT	0
704482	704363	14231L	PARTICIPANT	\N	PRESENT	0
704485	704216	04057K	PARTICIPANT	\N	EXCUSE	0
704486	704216	19295A	PARTICIPANT	\N	EXCUSE	0
704488	704363	19531S	PARTICIPANT	\N	PRESENT	0
704489	704363	20044X	PARTICIPANT	\N	PRESENT	0
704490	704363	19399H	PARTICIPANT	\N	PRESENT	0
704491	704363	20098N	PARTICIPANT	\N	PRESENT	0
704492	704363	11056N	PARTICIPANT	\N	PRESENT	0
704493	704363	19735D	PARTICIPANT	\N	PRESENT	0
704494	704363	19503N	PARTICIPANT	\N	PRESENT	0
704495	704363	19349W	PARTICIPANT	\N	PRESENT	0
704496	704363	20120S	PARTICIPANT	\N	PRESENT	0
704499	704363	20086J	PARTICIPANT	\N	PRESENT	0
704500	704363	20020P	PARTICIPANT	\N	PRESENT	0
704501	704363	19525U	PARTICIPANT	\N	PRESENT	0
704502	704363	20058E	PARTICIPANT	\N	PRESENT	0
704503	704363	19387D	PARTICIPANT	\N	PRESENT	0
704504	704363	20082E	PARTICIPANT	\N	PRESENT	0
704505	704329	20252E	PARTICIPANT	\N	EXCUSE	0
704506	704329	01057W	PARTICIPANT	\N	EXCUSE	0
704507	704363	19549D	PARTICIPANT	\N	PRESENT	0
704508	704471	20180F	PARTICIPANT	\N	PRESENT	0
704509	704471	14357A	PARTICIPANT	\N	PRESENT	0
704510	704471	20140W	PARTICIPANT	\N	PRESENT	0
704511	704471	19251M	PRESIDENT	0	PRESENT	0
704512	704471	17367Q	PARTICIPANT	\N	PRESENT	0
704513	704471	14207L	PARTICIPANT	\N	PRESENT	0
704514	704471	20084G	PARTICIPANT	\N	PRESENT	0
704515	704471	19782L	PARTICIPANT	\N	EXCUSE	0
704516	704471	20102Q	PARTICIPANT	\N	EXCUSE	0
688393	687362	11109J	PARTICIPANT	\N	EXCUSE	0
688808	688745	11090Q	PARTICIPANT	\N	EXCUSE	0
688809	688745	17023S	PARTICIPANT	\N	EXCUSE	0
688810	688745	04085P	PARTICIPANT	\N	EXCUSE	0
688811	688745	14147R	PARTICIPANT	\N	PRESENT	0
688812	688692	20024T	PARTICIPANT	\N	EXCUSE	0
690677	690676	14231L	PARTICIPANT	\N	PRESENT	0
690678	690676	14259Y	PARTICIPANT	\N	PRESENT	0
690679	690676	11048N	PARTICIPANT	\N	PRESENT	0
690680	690676	19711U	PARTICIPANT	\N	PRESENT	0
690682	690681	14231L	PARTICIPANT	\N	PRESENT	0
690683	690681	14259Y	PARTICIPANT	\N	PRESENT	0
690684	690681	19711U	PARTICIPANT	\N	PRESENT	0
692357	691220	11097X	PRESIDENT	0	PRESENT	0
692359	691220	19479G	PARTICIPANT	\N	EXCUSE	0
692360	691220	19954N	PARTICIPANT	\N	EXCUSE	0
692363	691220	14259Y	PARTICIPANT	\N	EXCUSE	0
692392	692388	19723Y	PARTICIPANT	\N	PRESENT	0
692396	692388	19663E	PARTICIPANT	\N	EXCUSE	0
701727	701726	86034E	PARTICIPANT	\N	PRESENT	0
701728	701726	04085P	PARTICIPANT	\N	PRESENT	0
701729	701726	05008E	PARTICIPANT	\N	PRESENT	0
701730	701726	04047H	PARTICIPANT	\N	PRESENT	0
701731	701726	19719D	PARTICIPANT	\N	PRESENT	0
701732	701726	10006L	PARTICIPANT	\N	PRESENT	0
701733	701726	14042U	PARTICIPANT	\N	PRESENT	0
701734	701726	14187A	PARTICIPANT	\N	PRESENT	0
701735	701726	19347U	PARTICIPANT	\N	PRESENT	0
701736	701726	14026U	PARTICIPANT	\N	PRESENT	0
701737	701726	11048N	PARTICIPANT	\N	PRESENT	0
701738	701726	99004R	PARTICIPANT	\N	PRESENT	0
701739	701726	19611R	PARTICIPANT	\N	PRESENT	0
701740	701726	12041X	PARTICIPANT	\N	PRESENT	0
701741	701726	14219Q	PARTICIPANT	\N	PRESENT	0
701742	701726	19563B	PARTICIPANT	\N	PRESENT	0
701743	701726	08061X	PARTICIPANT	\N	PRESENT	0
701744	701726	08047A	PARTICIPANT	\N	PRESENT	0
701745	701726	11090Q	PARTICIPANT	\N	PRESENT	0
701746	701726	14331P	PARTICIPANT	\N	PRESENT	0
701747	701726	14225N	PARTICIPANT	\N	PRESENT	0
701748	701726	11012A	PARTICIPANT	\N	PRESENT	0
701749	701726	95063L	PARTICIPANT	\N	PRESENT	0
701750	701726	14229S	PARTICIPANT	\N	PRESENT	0
701753	701752	14213J	PARTICIPANT	\N	PRESENT	0
701754	701752	19663E	PARTICIPANT	\N	PRESENT	0
701755	701752	19367Y	PARTICIPANT	\N	PRESENT	0
701756	701752	04092N	PARTICIPANT	\N	PRESENT	0
701757	701752	11067R	PARTICIPANT	\N	PRESENT	0
701758	701752	19798U	PARTICIPANT	\N	PRESENT	0
701759	701751	10006L	PARTICIPANT	\N	PRESENT	0
702629	698972	20076G	PARTICIPANT	\N	PRESENT	0
701761	701751	18193Q	PARTICIPANT	\N	PRESENT	0
701762	701751	19691J	PARTICIPANT	\N	PRESENT	0
701763	701751	11031D	PARTICIPANT	\N	PRESENT	0
702649	698972	19681G	PARTICIPANT	\N	PRESENT	0
701765	701751	14071N	PARTICIPANT	\N	PRESENT	0
702630	698972	19820Y	PARTICIPANT	\N	PRESENT	0
702631	698972	14219Q	PRESIDENT	0	PRESENT	0
702632	698972	20100N	PARTICIPANT	\N	PRESENT	0
702633	698972	05012A	PARTICIPANT	\N	PRESENT	0
702634	698972	19503N	PARTICIPANT	\N	PRESENT	0
702635	698972	17367Q	PARTICIPANT	\N	PRESENT	0
702636	698972	19525U	PARTICIPANT	\N	PRESENT	0
702637	698972	20120S	PARTICIPANT	\N	PRESENT	0
702638	698972	20038A	PARTICIPANT	\N	PRESENT	0
702639	698972	20046A	PARTICIPANT	\N	PRESENT	0
702640	698972	19745F	PARTICIPANT	\N	PRESENT	0
702646	698972	19549D	PARTICIPANT	\N	PRESENT	0
702650	698972	19619A	PARTICIPANT	\N	PRESENT	0
702656	701622	19581D	PARTICIPANT	\N	PRESENT	0
702657	701622	11010L	PARTICIPANT	\N	PRESENT	0
702658	701622	14021P	PARTICIPANT	\N	PRESENT	0
702660	698972	20122U	PARTICIPANT	\N	PRESENT	0
702662	698972	19251M	PARTICIPANT	\N	PRESENT	0
702663	701623	14179A	PARTICIPANT	\N	PRESENT	0
702664	702661	14331P	PARTICIPANT	\N	PRESENT	0
702665	702661	11048N	PARTICIPANT	\N	PRESENT	0
702666	702661	19647E	PARTICIPANT	\N	PRESENT	0
702667	702661	19711U	PARTICIPANT	\N	PRESENT	0
702668	702661	20036X	PARTICIPANT	\N	PRESENT	0
702669	702661	08034U	PARTICIPANT	\N	PRESENT	0
702670	702661	01057W	PARTICIPANT	\N	PRESENT	0
702671	702661	11053K	PARTICIPANT	\N	PRESENT	0
702672	702661	20080C	PARTICIPANT	\N	PRESENT	0
702673	702661	19667J	PARTICIPANT	\N	PRESENT	0
702674	702661	11074Q	PARTICIPANT	\N	PRESENT	0
702675	702661	20044X	PARTICIPANT	\N	PRESENT	0
702676	702661	14173T	PARTICIPANT	\N	PRESENT	0
702677	702661	11040E	PARTICIPANT	\N	PRESENT	0
702678	702661	14083S	PARTICIPANT	\N	PRESENT	0
702679	702661	11012A	PARTICIPANT	\N	PRESENT	0
702698	698972	11065P	PARTICIPANT	\N	PRESENT	0
702681	702661	20070A	PARTICIPANT	\N	PRESENT	0
702682	702661	19349W	PARTICIPANT	\N	PRESENT	0
702683	702661	19741B	PARTICIPANT	\N	PRESENT	0
702684	702661	08010L	PARTICIPANT	\N	PRESENT	0
702685	702661	14121F	PARTICIPANT	\N	PRESENT	0
702686	702661	99004R	PARTICIPANT	\N	PRESENT	0
702687	702661	20116W	PARTICIPANT	\N	PRESENT	0
702688	698972	20068G	PARTICIPANT	\N	PRESENT	0
702689	698972	20106U	PARTICIPANT	\N	PRESENT	0
702690	702661	04071H	PARTICIPANT	\N	PRESENT	0
702691	702661	14225N	PRESIDENT	0	PRESENT	0
702692	702661	20126Y	PARTICIPANT	\N	PRESENT	0
702693	702661	08011M	PARTICIPANT	\N	PRESENT	0
702694	702661	20050V	PARTICIPANT	\N	EXCUSE	0
702695	702661	19762G	PARTICIPANT	\N	EXCUSE	0
702697	702661	19671E	PARTICIPANT	\N	PRESENT	0
702699	702661	01048V	PARTICIPANT	\N	PRESENT	0
702700	702661	14189C	PARTICIPANT	\N	PRESENT	0
702860	701688	95041E	PARTICIPANT	\N	PRESENT	0
702861	701688	12041X	PARTICIPANT	\N	PRESENT	0
702862	701688	11080N	PARTICIPANT	\N	PRESENT	0
702863	701688	19565D	PARTICIPANT	\N	PRESENT	0
702864	701688	20072C	PARTICIPANT	\N	PRESENT	0
702865	701688	01058X	PARTICIPANT	\N	PRESENT	0
702866	701688	16685X	PARTICIPANT	\N	PRESENT	0
702867	701688	11027H	PARTICIPANT	\N	PRESENT	0
702868	701688	04042C	PRESIDENT	0	PRESENT	0
702869	701688	11054L	PARTICIPANT	\N	PRESENT	0
702870	701688	19669L	PARTICIPANT	\N	PRESENT	0
702871	701688	11066Q	PARTICIPANT	\N	PRESENT	0
702872	701688	12028B	PARTICIPANT	\N	PRESENT	0
702873	701688	14055N	PARTICIPANT	\N	PRESENT	0
702874	701688	19421M	PARTICIPANT	\N	PRESENT	0
702875	701688	19347U	PARTICIPANT	\N	PRESENT	0
702876	701688	07033P	PARTICIPANT	\N	PRESENT	0
702877	701688	08061X	PARTICIPANT	\N	PRESENT	0
702878	701688	97011G	PARTICIPANT	\N	PRESENT	0
702879	701688	14249W	PARTICIPANT	\N	PRESENT	0
702880	701688	08047A	PARTICIPANT	\N	PRESENT	0
702881	701688	20128B	PARTICIPANT	\N	PRESENT	0
702882	701688	14059S	PARTICIPANT	\N	PRESENT	0
702883	701688	14133K	PARTICIPANT	\N	PRESENT	0
702884	701688	01062T	PARTICIPANT	\N	PRESENT	0
702885	701688	11041F	PARTICIPANT	\N	PRESENT	0
702886	701688	20042V	PARTICIPANT	\N	PRESENT	0
702887	701688	01024M	PARTICIPANT	\N	PRESENT	0
702888	701688	19721W	PARTICIPANT	\N	PRESENT	0
702889	701688	14191V	PARTICIPANT	\N	PRESENT	0
702890	701688	19319Q	PARTICIPANT	\N	PRESENT	0
702891	701688	14105F	PARTICIPANT	\N	PRESENT	0
702892	701688	20064C	PARTICIPANT	\N	PRESENT	0
702893	701688	98022P	PARTICIPANT	\N	PRESENT	0
702894	701688	14267Y	PARTICIPANT	\N	PRESENT	0
702895	701688	11064N	PARTICIPANT	\N	PRESENT	0
702896	701688	11083R	PARTICIPANT	\N	PRESENT	0
702897	701688	14211G	PARTICIPANT	\N	PRESENT	0
702898	701688	14255U	PARTICIPANT	\N	PRESENT	0
702899	701688	17023S	PARTICIPANT	\N	PRESENT	0
702900	701688	19443T	PARTICIPANT	\N	EXCUSE	0
703136	701645	12028B	PARTICIPANT	\N	PRESENT	0
703137	701645	08010L	PARTICIPANT	\N	PRESENT	0
703138	701645	19669L	PARTICIPANT	\N	PRESENT	0
703139	701645	19703U	PARTICIPANT	\N	PRESENT	0
703140	701645	20088L	PARTICIPANT	\N	PRESENT	0
703141	701645	14026U	PARTICIPANT	\N	PRESENT	0
703142	701645	04047H	PARTICIPANT	\N	PRESENT	0
703143	701645	20264J	PARTICIPANT	\N	PRESENT	0
703144	701645	11110B	PARTICIPANT	\N	PRESENT	0
703145	701645	14121F	PARTICIPANT	\N	PRESENT	0
710843	705810	07029T	PARTICIPANT	\N	EXCUSE	0
710844	705810	86034E	PARTICIPANT	\N	PRESENT	0
710845	708161	20094J	PARTICIPANT	\N	PRESENT	0
710846	708161	19369B	PARTICIPANT	\N	PRESENT	0
710847	708161	20104S	PARTICIPANT	\N	PRESENT	0
710848	708161	05008E	PARTICIPANT	\N	PRESENT	0
710849	708161	14169X	PARTICIPANT	\N	PRESENT	0
710850	708161	14111D	PARTICIPANT	\N	PRESENT	0
710851	708161	11064N	PARTICIPANT	\N	PRESENT	0
710852	708161	19553Y	PARTICIPANT	\N	PRESENT	0
710853	708161	17737W	PARTICIPANT	\N	PRESENT	0
710854	708161	11067R	PARTICIPANT	\N	PRESENT	0
710855	708161	19531S	PARTICIPANT	\N	PRESENT	0
710856	708161	08061X	PARTICIPANT	\N	PRESENT	0
710857	708161	19575F	PARTICIPANT	\N	PRESENT	0
710858	708161	11027H	PARTICIPANT	\N	PRESENT	0
710859	708161	17023S	PARTICIPANT	\N	PRESENT	0
710860	708161	01058X	PARTICIPANT	\N	PRESENT	0
710861	706384	14030Q	PARTICIPANT	\N	PRESENT	0
710862	706384	14179A	PARTICIPANT	\N	PRESENT	0
710863	706384	11045K	PARTICIPANT	\N	EXCUSE	0
710864	708161	19335Q	PARTICIPANT	\N	PRESENT	0
710865	708161	19713W	PARTICIPANT	\N	PRESENT	0
710866	708161	19719D	PARTICIPANT	\N	PRESENT	0
710867	708161	11041F	PARTICIPANT	\N	PRESENT	0
710868	708161	19647E	PARTICIPANT	\N	PRESENT	0
710869	708161	19251M	PARTICIPANT	\N	PRESENT	0
710871	706152	19643A	PARTICIPANT	\N	PRESENT	1
710872	706152	19735D	PARTICIPANT	\N	PRESENT	1
710873	708161	14251Q	PARTICIPANT	\N	PRESENT	0
710875	708161	20042V	PARTICIPANT	\N	PRESENT	0
710876	706153	20112S	PARTICIPANT	\N	PRESENT	0
710877	706153	19643A	PARTICIPANT	\N	PRESENT	0
710878	706156	19693L	PARTICIPANT	\N	PRESENT	0
710879	706156	20112S	PARTICIPANT	\N	PRESENT	0
710880	708161	19643A	PARTICIPANT	\N	PRESENT	0
710881	708161	20078J	PARTICIPANT	\N	PRESENT	0
710883	710882	19643A	PARTICIPANT	\N	PRESENT	0
710884	710882	20112S	PARTICIPANT	\N	PRESENT	0
710886	710885	95063L	PARTICIPANT	\N	PRESENT	0
710887	706098	20032T	PARTICIPANT	\N	PRESENT	0
710888	706098	19631V	PARTICIPANT	\N	PRESENT	0
710889	706098	05008E	PARTICIPANT	\N	PRESENT	0
710890	706098	19549D	PARTICIPANT	\N	PRESENT	0
710891	706098	20086J	PARTICIPANT	\N	PRESENT	0
710892	706098	19545Y	PARTICIPANT	\N	PRESENT	0
710893	706098	11056N	PARTICIPANT	\N	PRESENT	0
710894	706098	19525U	PARTICIPANT	\N	PRESENT	0
710895	706098	11065P	PARTICIPANT	\N	PRESENT	0
710896	706098	14231L	PARTICIPANT	\N	PRESENT	0
710897	706098	20120S	PARTICIPANT	\N	PRESENT	0
710898	706098	19387D	PARTICIPANT	\N	PRESENT	0
710899	706098	20068G	PARTICIPANT	\N	PRESENT	0
710900	706098	19399H	PARTICIPANT	\N	PRESENT	0
710901	706098	11064N	PARTICIPANT	\N	PRESENT	0
710902	706098	19489J	PARTICIPANT	\N	PRESENT	0
710903	706098	19735D	PARTICIPANT	\N	PRESENT	0
710904	706098	01043Q	PRESIDENT	0	PRESENT	0
710905	706098	14205J	PARTICIPANT	\N	PRESENT	0
710906	706098	19503N	PARTICIPANT	\N	PRESENT	0
710907	706098	20298U	PARTICIPANT	\N	PRESENT	0
710908	706098	20082E	PARTICIPANT	\N	PRESENT	0
710909	706098	20098N	PARTICIPANT	\N	PRESENT	0
710910	706098	20046A	PARTICIPANT	\N	PRESENT	0
710911	706098	20058E	PARTICIPANT	\N	PRESENT	0
710912	706098	19637C	PARTICIPANT	\N	EXCUSE	0
710913	708161	20112S	PARTICIPANT	\N	PRESENT	0
710914	708161	20266L	PARTICIPANT	\N	PRESENT	0
710915	708161	20032T	PARTICIPANT	\N	PRESENT	0
710916	708161	19489J	PARTICIPANT	\N	PRESENT	0
710917	708161	19525U	PARTICIPANT	\N	PRESENT	0
710918	708161	20248J	PARTICIPANT	\N	PRESENT	0
710919	708161	20030R	PARTICIPANT	\N	PRESENT	0
710920	708161	14255U	PARTICIPANT	\N	PRESENT	0
710921	708161	14205J	PARTICIPANT	\N	PRESENT	0
710922	708161	11090Q	PARTICIPANT	\N	PRESENT	0
711040	708187	86034E	PARTICIPANT	\N	PRESENT	0
711041	708187	10006L	PARTICIPANT	\N	PRESENT	0
711042	708187	11097X	PARTICIPANT	\N	PRESENT	0
711043	708187	14042U	PARTICIPANT	\N	PRESENT	0
711044	708187	20130U	PARTICIPANT	\N	PRESENT	0
711045	708187	19347U	PARTICIPANT	\N	PRESENT	0
711099	708187	19387D	PARTICIPANT	\N	PRESENT	0
711047	708187	14195A	PARTICIPANT	\N	PRESENT	0
711048	708187	04085P	PARTICIPANT	\N	PRESENT	0
711049	708187	19687N	PARTICIPANT	\N	PRESENT	0
711100	708187	20046A	PARTICIPANT	\N	PRESENT	0
711051	708187	11067R	PARTICIPANT	\N	PRESENT	0
711101	708187	19593H	PARTICIPANT	\N	PRESENT	0
711102	708187	19591F	PARTICIPANT	\N	PRESENT	0
711103	708187	04047H	PARTICIPANT	\N	PRESENT	0
711055	708187	20062A	PARTICIPANT	\N	PRESENT	0
710841	705810	20130U	PARTICIPANT	\N	EXCUSE	0
710842	705810	19715Y	PARTICIPANT	\N	EXCUSE	0
711056	708187	19629C	PARTICIPANT	\N	PRESENT	0
711057	708187	19719D	PARTICIPANT	\N	PRESENT	0
711058	708187	12028B	PARTICIPANT	\N	PRESENT	0
711059	708187	20090E	PARTICIPANT	\N	PRESENT	0
711060	708187	19798U	PARTICIPANT	\N	PRESENT	0
711061	708187	14213J	PARTICIPANT	\N	PRESENT	0
711062	708187	19413M	PARTICIPANT	\N	PRESENT	0
711063	708187	11031D	PARTICIPANT	\N	PRESENT	0
711064	708187	08060W	PARTICIPANT	\N	PRESENT	0
711065	708187	08028W	PARTICIPANT	\N	PRESENT	0
711066	708187	20040T	PARTICIPANT	\N	PRESENT	0
711067	708187	20078J	PARTICIPANT	\N	PRESENT	0
711068	708187	11104D	PARTICIPANT	\N	PRESENT	0
711069	708187	20044X	PARTICIPANT	\N	PRESENT	0
711070	708187	08034U	PARTICIPANT	\N	PRESENT	0
711104	708187	19675J	PARTICIPANT	\N	PRESENT	0
711072	708187	20264J	PARTICIPANT	\N	PRESENT	0
711073	708187	19503N	PARTICIPANT	\N	PRESENT	0
711074	708187	19782L	PARTICIPANT	\N	PRESENT	0
711075	708187	19866P	PARTICIPANT	\N	PRESENT	0
711076	708187	20060X	PARTICIPANT	\N	PRESENT	0
711077	708187	19333N	PARTICIPANT	\N	PRESENT	0
711078	708187	11099A	PARTICIPANT	\N	PRESENT	0
711079	708187	11077T	PARTICIPANT	\N	PRESENT	0
711080	708187	14225N	PARTICIPANT	\N	PRESENT	0
711081	708187	20112S	PARTICIPANT	\N	PRESENT	0
711082	708187	11045K	PARTICIPANT	\N	PRESENT	0
711083	708187	19531S	PARTICIPANT	\N	PRESENT	0
711084	708187	20064C	PARTICIPANT	\N	PRESENT	0
711085	708187	01062T	PARTICIPANT	\N	PRESENT	0
711086	708187	14229S	PARTICIPANT	\N	PRESENT	0
711087	708187	08045X	PARTICIPANT	\N	PRESENT	0
711088	708187	11012A	PARTICIPANT	\N	PRESENT	0
711089	708187	20132W	PARTICIPANT	\N	PRESENT	0
711090	708187	19295A	PARTICIPANT	\N	PRESENT	0
711091	708187	95063L	PARTICIPANT	\N	PRESENT	0
711092	708187	08061X	PARTICIPANT	\N	PRESENT	0
711093	708187	04045F	PARTICIPANT	\N	PRESENT	0
711094	708187	19697Q	PARTICIPANT	\N	PRESENT	0
711095	708187	14327T	PARTICIPANT	\N	PRESENT	0
711096	708187	20144B	PARTICIPANT	\N	PRESENT	0
711097	708187	01024M	PARTICIPANT	\N	PRESENT	0
711098	708187	14073Q	PARTICIPANT	\N	PRESENT	0
711105	708187	19569H	PARTICIPANT	\N	PRESENT	0
711106	708187	20122U	PARTICIPANT	\N	PRESENT	0
711107	708187	14215L	PARTICIPANT	\N	PRESENT	0
711108	708187	14187A	PARTICIPANT	\N	PRESENT	0
711109	708187	04092N	PARTICIPANT	\N	PRESENT	0
711110	708187	18083K	PARTICIPANT	\N	PRESENT	0
711111	708187	05008E	PARTICIPANT	\N	PRESENT	0
711112	708187	97011G	PARTICIPANT	\N	PRESENT	0
711113	708187	14207L	PARTICIPANT	\N	PRESENT	0
711114	708187	20072C	PARTICIPANT	\N	PRESENT	0
711115	708187	08010L	PARTICIPANT	\N	PRESENT	0
711116	708187	20038A	PARTICIPANT	\N	PRESENT	0
711117	708187	19649G	PARTICIPANT	\N	PRESENT	0
711118	708187	19820Y	PARTICIPANT	\N	PRESENT	0
711119	708187	11065P	PARTICIPANT	\N	PRESENT	0
711120	708187	20100N	PARTICIPANT	\N	PRESENT	0
711121	708187	20180F	PARTICIPANT	\N	PRESENT	0
711122	708187	17367Q	PARTICIPANT	\N	PRESENT	0
711123	708187	20034V	PARTICIPANT	\N	PRESENT	0
711124	708187	20092G	PARTICIPANT	\N	PRESENT	0
711125	708187	11026G	PARTICIPANT	\N	PRESENT	0
711126	708187	19527W	PARTICIPANT	\N	PRESENT	0
711127	708187	14030Q	PARTICIPANT	\N	PRESENT	0
691543	690386	20980G	PARTICIPANT	\N	PRESENT	0
691544	690386	11104D	PARTICIPANT	\N	PRESENT	0
691545	690386	19758L	PARTICIPANT	\N	PRESENT	0
691547	690386	14229S	PARTICIPANT	\N	PRESENT	0
691548	690386	20134Y	PARTICIPANT	\N	PRESENT	0
691549	690386	19651A	PARTICIPANT	\N	PRESENT	0
691550	690386	19693L	PARTICIPANT	\N	PRESENT	0
691551	690386	19719D	PARTICIPANT	\N	PRESENT	0
691552	690386	20172F	PARTICIPANT	\N	PRESENT	0
691553	690386	20058E	PARTICIPANT	\N	PRESENT	0
691554	690386	20264J	PARTICIPANT	\N	PRESENT	0
691555	690386	19735D	PARTICIPANT	\N	PRESENT	0
691556	690386	19621T	PARTICIPANT	\N	PRESENT	0
691557	690709	14053L	PARTICIPANT	\N	PRESENT	0
691558	690709	14111D	PARTICIPANT	\N	PRESENT	0
691559	690709	14073Q	PARTICIPANT	\N	PRESENT	0
691560	690709	20074E	PARTICIPANT	\N	PRESENT	0
691561	690709	19585H	PARTICIPANT	\N	PRESENT	0
691562	690709	19673G	PARTICIPANT	\N	PRESENT	0
691563	690709	11033F	PARTICIPANT	\N	PRESENT	0
691564	690709	19723Y	PARTICIPANT	\N	PRESENT	0
691565	690709	19729F	PARTICIPANT	\N	PRESENT	0
691566	690709	19629C	PARTICIPANT	\N	PRESENT	0
691567	690709	07004J	PARTICIPANT	\N	PRESENT	0
691568	690709	20110Q	PARTICIPANT	\N	PRESENT	0
691569	690709	14215L	PARTICIPANT	\N	PRESENT	0
691573	690709	04047H	PRESIDENT	0	PRESENT	0
691574	690709	19447X	PARTICIPANT	\N	PRESENT	0
691575	690709	14107H	PARTICIPANT	\N	PRESENT	0
691576	690709	14147R	PARTICIPANT	\N	PRESENT	0
691577	690709	14151M	PARTICIPANT	\N	PRESENT	0
691578	690709	04008A	PARTICIPANT	\N	PRESENT	0
691579	690709	11072N	PARTICIPANT	\N	PRESENT	0
691601	690709	20108W	PARTICIPANT	\N	PRESENT	0
691602	690709	10015M	PARTICIPANT	\N	PRESENT	0
691603	690709	11026G	PARTICIPANT	\N	PRESENT	0
691604	690709	19301E	PARTICIPANT	\N	PRESENT	0
691605	690709	19725B	PARTICIPANT	\N	PRESENT	0
691606	690709	14089Y	PARTICIPANT	\N	PRESENT	0
691624	690709	14001X	PARTICIPANT	\N	PRESENT	0
691625	690709	19543W	PARTICIPANT	\N	PRESENT	0
691626	690709	14179A	PARTICIPANT	\N	PRESENT	0
691631	690709	04085P	PARTICIPANT	\N	PRESENT	0
691636	690709	19954N	PARTICIPANT	\N	PRESENT	0
691637	690709	14259Y	PARTICIPANT	\N	PRESENT	0
691638	690709	20022R	PARTICIPANT	\N	PRESENT	0
691639	690709	19649G	PARTICIPANT	\N	PRESENT	0
691640	690709	14069U	PARTICIPANT	\N	PRESENT	0
691641	690709	14231L	PARTICIPANT	\N	PRESENT	0
691642	690709	19489J	PARTICIPANT	\N	PRESENT	0
691643	690709	17737W	PARTICIPANT	\N	PRESENT	0
691644	690709	95063L	PARTICIPANT	\N	PRESENT	0
691645	690709	19749K	PARTICIPANT	\N	PRESENT	0
691646	690789	14059S	PARTICIPANT	\N	PRESENT	0
691647	690789	14097Y	PARTICIPANT	\N	PRESENT	0
691648	690789	12041X	PARTICIPANT	\N	PRESENT	0
691649	690789	14133K	PARTICIPANT	\N	PRESENT	0
691650	690789	20072C	PARTICIPANT	\N	PRESENT	0
691651	690789	19565D	PARTICIPANT	\N	PRESENT	0
691652	690789	08069G	PARTICIPANT	\N	PRESENT	0
691653	690789	11041F	PARTICIPANT	\N	PRESENT	0
691654	690789	11027H	PARTICIPANT	\N	PRESENT	0
691655	690789	04042C	PRESIDENT	0	PRESENT	0
691656	690789	11054L	PARTICIPANT	\N	PRESENT	0
691657	690789	01024M	PARTICIPANT	\N	PRESENT	0
691658	690789	11066Q	PARTICIPANT	\N	PRESENT	0
691659	690789	19669L	PARTICIPANT	\N	PRESENT	0
691660	690789	08056B	PARTICIPANT	\N	PRESENT	0
691661	690789	19319Q	PARTICIPANT	\N	PRESENT	0
691662	690789	14105F	PARTICIPANT	\N	PRESENT	0
691663	690789	19421M	PARTICIPANT	\N	PRESENT	0
691664	690789	19709B	PARTICIPANT	\N	PRESENT	0
691665	690789	11064N	PARTICIPANT	\N	PRESENT	0
691666	690789	14267Y	PARTICIPANT	\N	PRESENT	0
691667	690789	07033P	PARTICIPANT	\N	PRESENT	0
691668	690789	97011G	PARTICIPANT	\N	PRESENT	0
691669	690789	14249W	PARTICIPANT	\N	PRESENT	0
691671	690789	11080N	PARTICIPANT	\N	PRESENT	0
691672	690789	19721W	PARTICIPANT	\N	PRESENT	0
691673	690789	14211G	PARTICIPANT	\N	PRESENT	0
691674	690789	01058X	PARTICIPANT	\N	PRESENT	0
691675	690789	19347U	PARTICIPANT	\N	PRESENT	0
691676	690789	08061X	PARTICIPANT	\N	PRESENT	0
691677	690789	98022P	PARTICIPANT	\N	PRESENT	0
691678	690709	08018U	PARTICIPANT	\N	PRESENT	0
691679	690709	11056N	PARTICIPANT	\N	PRESENT	0
691680	690709	19581D	PARTICIPANT	\N	PRESENT	0
691681	690709	14021P	PARTICIPANT	\N	PRESENT	0
691689	690386	20048C	PARTICIPANT	\N	PRESENT	0
691690	690386	11043H	PARTICIPANT	\N	PRESENT	0
691691	690789	14055N	PARTICIPANT	\N	PRESENT	0
691692	690789	20128B	PARTICIPANT	\N	PRESENT	0
691693	690789	14255U	PARTICIPANT	\N	PRESENT	0
691694	688931	20086J	PARTICIPANT	\N	PRESENT	0
691695	688931	01043Q	PARTICIPANT	\N	PRESENT	0
691696	688931	19599P	PARTICIPANT	\N	PRESENT	0
691697	688931	20096L	PARTICIPANT	\N	PRESENT	0
691698	688931	20120S	PARTICIPANT	\N	PRESENT	0
691699	688931	20136B	PARTICIPANT	\N	PRESENT	0
691700	690709	11085T	PARTICIPANT	\N	PRESENT	0
691701	690786	14331P	PARTICIPANT	\N	PRESENT	0
691702	690786	99004R	PARTICIPANT	\N	PRESENT	0
691703	690786	14225N	PRESIDENT	0	PRESENT	0
691704	690786	01057W	PARTICIPANT	\N	PRESENT	0
691705	690786	14253S	PARTICIPANT	\N	PRESENT	0
691706	690786	20116W	PARTICIPANT	\N	PRESENT	0
691709	690786	20044X	PARTICIPANT	\N	PRESENT	0
691711	690786	08034U	PARTICIPANT	\N	PRESENT	0
691712	690789	95041E	PARTICIPANT	\N	PRESENT	0
691713	690786	11048N	PARTICIPANT	\N	PRESENT	0
691714	690786	19349W	PARTICIPANT	\N	PRESENT	0
691715	690786	01048V	PARTICIPANT	\N	PRESENT	0
691716	690786	14121F	PARTICIPANT	\N	PRESENT	0
691717	690786	19741B	PARTICIPANT	\N	PRESENT	0
691718	690786	20914V	PARTICIPANT	\N	PRESENT	0
691719	690786	19335Q	PARTICIPANT	\N	PRESENT	0
691720	690786	19479G	PARTICIPANT	\N	PRESENT	0
691721	690786	11040E	PARTICIPANT	\N	PRESENT	0
691722	690786	14327T	PARTICIPANT	\N	PRESENT	0
691723	690786	08010L	PARTICIPANT	\N	PRESENT	0
691724	690786	19671E	PARTICIPANT	\N	PRESENT	0
691725	690786	20050V	PARTICIPANT	\N	PRESENT	0
691726	690786	14189C	PARTICIPANT	\N	PRESENT	0
691727	690789	20042V	PARTICIPANT	\N	PRESENT	0
691728	690786	11053K	PARTICIPANT	\N	PRESENT	0
691729	690786	20126Y	PARTICIPANT	\N	PRESENT	0
691730	690786	19687N	PARTICIPANT	\N	PRESENT	0
691731	690786	19711U	PARTICIPANT	\N	PRESENT	0
691732	690709	20114U	PARTICIPANT	\N	PRESENT	0
691733	690786	19762G	PARTICIPANT	\N	PRESENT	0
691734	688931	20100N	PARTICIPANT	\N	PRESENT	0
691735	690786	14173T	PARTICIPANT	\N	PRESENT	0
691736	690786	20070A	PARTICIPANT	\N	PRESENT	0
691737	690786	19647E	PARTICIPANT	\N	PRESENT	0
691738	690786	11074Q	PARTICIPANT	\N	PRESENT	0
691739	690786	20036X	PARTICIPANT	\N	PRESENT	0
691741	690786	11012A	PARTICIPANT	\N	PRESENT	0
691742	690786	07029T	PARTICIPANT	\N	PRESENT	0
691743	690786	12016W	PARTICIPANT	\N	PRESENT	0
691744	690786	20252E	PARTICIPANT	\N	PRESENT	0
691745	690786	19531S	PARTICIPANT	\N	PRESENT	0
691746	690786	20080C	PARTICIPANT	\N	PRESENT	0
691747	688931	20140W	PARTICIPANT	\N	PRESENT	0
691748	691502	19383Y	PARTICIPANT	\N	PRESENT	0
691749	691502	19768N	PARTICIPANT	\N	PRESENT	0
691750	691502	20088L	PARTICIPANT	\N	PRESENT	0
691751	691502	19515S	PARTICIPANT	\N	PRESENT	0
691752	691502	19782L	PARTICIPANT	\N	PRESENT	0
691753	691502	20092G	PARTICIPANT	\N	PRESENT	0
691754	691502	01043Q	PARTICIPANT	\N	PRESENT	0
691755	691502	14357A	PARTICIPANT	\N	PRESENT	0
691756	691502	19441R	PARTICIPANT	\N	PRESENT	0
691757	691502	20078J	PARTICIPANT	\N	PRESENT	0
691758	691502	19413M	PARTICIPANT	\N	PRESENT	0
691759	691502	20082E	PARTICIPANT	\N	PRESENT	0
691760	691502	20094J	PARTICIPANT	\N	PRESENT	0
691761	691502	19866P	PARTICIPANT	\N	PRESENT	0
691762	691502	04045F	PARTICIPANT	\N	PRESENT	0
691763	691502	19631V	PARTICIPANT	\N	PRESENT	0
691764	691502	20104S	PARTICIPANT	\N	PRESENT	0
691765	691502	11099A	PARTICIPANT	\N	PRESENT	0
704517	704471	19563B	PARTICIPANT	\N	EXCUSE	0
704518	704471	11053K	PARTICIPANT	\N	PRESENT	0
704519	704471	20092G	PARTICIPANT	\N	PRESENT	0
704528	704471	19575F	PARTICIPANT	\N	PRESENT	0
704529	704363	11064N	PARTICIPANT	\N	PRESENT	0
704530	704363	19545Y	PARTICIPANT	\N	PRESENT	0
704531	704363	19637C	PARTICIPANT	\N	EXCUSE	0
704532	703787	14053L	PARTICIPANT	\N	PRESENT	0
704533	703787	17737W	PARTICIPANT	\N	PRESENT	0
704534	703787	04047H	PRESIDENT	0	PRESENT	0
704535	703787	04008A	PARTICIPANT	\N	PRESENT	0
704536	703787	19447X	PARTICIPANT	\N	PRESENT	0
704537	703787	19954N	PARTICIPANT	\N	PRESENT	0
704538	703787	19581D	PARTICIPANT	\N	PRESENT	0
704539	703787	19301E	PARTICIPANT	\N	PRESENT	0
704540	703787	19585H	PARTICIPANT	\N	PRESENT	0
704541	703787	14089Y	PARTICIPANT	\N	PRESENT	0
704542	703787	10015M	PARTICIPANT	\N	PRESENT	0
704543	703787	20108W	PARTICIPANT	\N	PRESENT	0
704602	703790	19629C	PARTICIPANT	\N	PRESENT	0
704545	703787	19673G	PARTICIPANT	\N	PRESENT	0
704546	704316	14097Y	PARTICIPANT	\N	PRESENT	0
704547	704316	04035D	PARTICIPANT	\N	PRESENT	0
704548	704316	01062T	PARTICIPANT	\N	PRESENT	0
704549	704316	20072C	PARTICIPANT	\N	PRESENT	0
704550	704316	14133K	PARTICIPANT	\N	PRESENT	0
704551	704316	11041F	PARTICIPANT	\N	PRESENT	0
704552	704316	01058X	PARTICIPANT	\N	PRESENT	0
704553	704316	16685X	PARTICIPANT	\N	PRESENT	0
704554	704316	04042C	PRESIDENT	0	PRESENT	0
704555	704316	11054L	PARTICIPANT	\N	PRESENT	0
704556	704316	19669L	PARTICIPANT	\N	PRESENT	0
704557	704316	11066Q	PARTICIPANT	\N	PRESENT	0
704558	704316	19721W	PARTICIPANT	\N	PRESENT	0
704559	704316	20064C	PARTICIPANT	\N	PRESENT	0
704560	704316	14267Y	PARTICIPANT	\N	PRESENT	0
704561	704316	14193X	PARTICIPANT	\N	PRESENT	0
704562	704316	11064N	PARTICIPANT	\N	PRESENT	0
704563	704316	07033P	PARTICIPANT	\N	PRESENT	0
704564	704316	97011G	PARTICIPANT	\N	PRESENT	0
704565	704316	14211G	PARTICIPANT	\N	PRESENT	0
704566	704316	14249W	PARTICIPANT	\N	PRESENT	0
704567	704316	08047A	PARTICIPANT	\N	PRESENT	0
704568	704316	19443T	PARTICIPANT	\N	EXCUSE	0
704569	703787	20022R	PARTICIPANT	\N	PRESENT	0
704570	703787	14215L	PARTICIPANT	\N	PRESENT	0
704571	703787	04085P	PARTICIPANT	\N	PRESENT	0
704572	703787	19489J	PARTICIPANT	\N	PRESENT	0
704573	703787	95063L	PARTICIPANT	\N	PRESENT	0
704603	703790	19675J	PARTICIPANT	\N	PRESENT	0
704575	704316	19347U	PARTICIPANT	\N	PRESENT	0
704576	704316	14059S	PARTICIPANT	\N	PRESENT	0
704577	704316	17023S	PARTICIPANT	\N	PRESENT	0
704578	703787	14231L	PARTICIPANT	\N	PRESENT	0
704579	703787	19729F	PARTICIPANT	\N	PRESENT	0
704580	703787	20110Q	PARTICIPANT	\N	PRESENT	0
704581	703787	19649G	PARTICIPANT	\N	PRESENT	0
704596	703787	14147R	PARTICIPANT	\N	PRESENT	0
704597	703787	11026G	PARTICIPANT	\N	PRESENT	0
704598	703787	11056N	PARTICIPANT	\N	PRESENT	0
704604	703790	14053L	PARTICIPANT	\N	PRESENT	0
704605	703790	07004J	PARTICIPANT	\N	PRESENT	0
704606	703790	19725B	PARTICIPANT	\N	PRESENT	0
704607	703790	14179A	PARTICIPANT	\N	PRESENT	0
704608	703790	10015M	PARTICIPANT	\N	PRESENT	0
704609	703790	11026G	PARTICIPANT	\N	PRESENT	0
704610	703790	19301E	PARTICIPANT	\N	PRESENT	0
704611	703790	04047H	PARTICIPANT	\N	PRESENT	0
704612	703790	14231L	PARTICIPANT	\N	PRESENT	0
704613	703790	19954N	PARTICIPANT	\N	PRESENT	0
704614	703790	19489J	PARTICIPANT	\N	PRESENT	0
704615	703790	14107H	PARTICIPANT	\N	PRESENT	0
704616	703790	14147R	PARTICIPANT	\N	PRESENT	0
704617	703790	14215L	PARTICIPANT	\N	PRESENT	0
704618	703790	08018U	PARTICIPANT	\N	PRESENT	0
704619	703790	20022R	PARTICIPANT	\N	PRESENT	0
704620	703790	14259Y	PARTICIPANT	\N	PRESENT	0
704621	703790	19749K	PARTICIPANT	\N	PRESENT	0
704623	703790	05008E	PARTICIPANT	\N	PRESENT	0
704624	703790	11056N	PARTICIPANT	\N	PRESENT	0
704625	703790	95063L	PARTICIPANT	\N	PRESENT	0
704626	703790	14069U	PARTICIPANT	\N	PRESENT	0
704634	703790	19581D	PARTICIPANT	\N	PRESENT	0
704635	703790	20110Q	PARTICIPANT	\N	PRESENT	0
704636	704329	14189C	PARTICIPANT	\N	PRESENT	0
704655	703790	01028R	PARTICIPANT	\N	PRESENT	0
704656	703790	20114U	PARTICIPANT	\N	PRESENT	0
704657	701853	19593H	PARTICIPANT	\N	PRESENT	0
704658	701853	19527W	PARTICIPANT	\N	PRESENT	0
704659	701853	20132W	PARTICIPANT	\N	PRESENT	0
704660	701853	19699S	PARTICIPANT	\N	PRESENT	0
704661	701853	14073Q	PARTICIPANT	\N	PRESENT	0
704662	701853	19611R	PRESIDENT	0	PRESENT	0
704663	701853	20142Y	PARTICIPANT	\N	PRESENT	0
704664	701853	14229S	PARTICIPANT	\N	PRESENT	0
704665	701853	20172F	PARTICIPANT	\N	PRESENT	0
704666	701853	14030Q	PARTICIPANT	\N	PRESENT	0
704667	701853	04059M	PARTICIPANT	\N	PRESENT	0
704668	701853	20264J	PARTICIPANT	\N	PRESENT	0
704669	701853	19735D	PARTICIPANT	\N	PRESENT	0
704670	701853	20112S	PARTICIPANT	\N	PRESENT	0
704671	701853	08012N	PARTICIPANT	\N	PRESENT	0
704672	701853	11043H	PARTICIPANT	\N	PRESENT	0
704673	701853	20980G	PARTICIPANT	\N	PRESENT	0
704674	701853	20124W	PARTICIPANT	\N	PRESENT	0
704675	701853	19758L	PARTICIPANT	\N	PRESENT	0
704676	701853	20026V	PARTICIPANT	\N	PRESENT	0
704677	701853	20084G	PARTICIPANT	\N	PRESENT	0
704678	701853	11109J	PARTICIPANT	\N	EXCUSE	0
704679	701853	20048C	PARTICIPANT	\N	EXCUSE	0
704680	704331	14331P	PARTICIPANT	\N	PRESENT	0
704681	704331	11048N	PARTICIPANT	\N	PRESENT	0
704682	704331	19531S	PARTICIPANT	\N	PRESENT	0
704683	704331	01048V	PARTICIPANT	\N	PRESENT	0
704684	704331	01057W	PARTICIPANT	\N	PRESENT	0
704685	704331	11053K	PARTICIPANT	\N	PRESENT	0
704686	704331	20080C	PARTICIPANT	\N	PRESENT	0
704687	704331	14225N	PRESIDENT	0	PRESENT	0
704688	704331	19671E	PARTICIPANT	\N	PRESENT	0
704689	704331	11040E	PARTICIPANT	\N	PRESENT	0
704690	704331	11012A	PARTICIPANT	\N	PRESENT	0
704711	704331	19647E	PARTICIPANT	\N	PRESENT	0
704692	704331	20070A	PARTICIPANT	\N	PRESENT	0
704693	704331	19349W	PARTICIPANT	\N	PRESENT	0
704694	704331	99004R	PARTICIPANT	\N	PRESENT	0
704695	704331	20116W	PARTICIPANT	\N	PRESENT	0
704696	704331	14253S	PARTICIPANT	\N	PRESENT	0
704697	703790	20074E	PARTICIPANT	\N	PRESENT	0
704698	703790	14001X	PARTICIPANT	\N	PRESENT	0
704699	703790	19447X	PARTICIPANT	\N	PRESENT	0
704700	703790	11033F	PARTICIPANT	\N	PRESENT	0
704701	703790	04085P	PARTICIPANT	\N	PRESENT	0
704702	703790	14021P	PARTICIPANT	\N	PRESENT	0
704703	704331	19479G	PARTICIPANT	\N	PRESENT	0
704704	704331	04071H	PARTICIPANT	\N	PRESENT	0
704705	704331	20036X	PARTICIPANT	\N	PRESENT	0
704706	704331	14083S	PARTICIPANT	\N	PRESENT	0
704707	704331	20126Y	PARTICIPANT	\N	PRESENT	0
704708	701853	19533U	PARTICIPANT	\N	PRESENT	0
704709	701853	19573D	PARTICIPANT	\N	PRESENT	0
704710	701853	19621T	PARTICIPANT	\N	PRESENT	0
704712	704331	20044X	PARTICIPANT	\N	PRESENT	0
704713	704331	08009T	PARTICIPANT	\N	PRESENT	0
704714	704331	19741B	PARTICIPANT	\N	PRESENT	0
704715	701853	20138D	PARTICIPANT	\N	PRESENT	0
704716	701853	20056C	PARTICIPANT	\N	PRESENT	0
704717	704331	20050V	PARTICIPANT	\N	EXCUSE	0
704718	704331	07029T	PARTICIPANT	\N	EXCUSE	0
704719	704331	20252E	PARTICIPANT	\N	EXCUSE	0
704720	703790	17737W	PARTICIPANT	\N	PRESENT	0
704722	703790	20108W	PARTICIPANT	\N	PRESENT	0
704723	703790	14111D	PARTICIPANT	\N	PRESENT	0
704725	703790	14089Y	PARTICIPANT	\N	PRESENT	0
704727	703790	04008A	PARTICIPANT	\N	PRESENT	0
704753	704752	14001X	PARTICIPANT	\N	PRESENT	0
704754	704752	20074E	PARTICIPANT	\N	PRESENT	0
704755	704752	20088L	PARTICIPANT	\N	PRESENT	0
704756	704752	20042V	PARTICIPANT	\N	PRESENT	0
704757	704752	20038A	PARTICIPANT	\N	PRESENT	0
704758	704752	20120S	PARTICIPANT	\N	PRESENT	0
704799	704798	19631V	PARTICIPANT	\N	PRESENT	0
686861	686748	14331P	PARTICIPANT	\N	PRESENT	0
686863	686748	14097Y	PARTICIPANT	\N	PRESENT	0
686864	686748	14073Q	PARTICIPANT	\N	PRESENT	0
686865	686748	14001X	PARTICIPANT	\N	PRESENT	0
686866	686748	14255U	PARTICIPANT	\N	PRESENT	0
703146	701645	19551W	PARTICIPANT	\N	PRESENT	0
703147	701645	17737W	PARTICIPANT	\N	PRESENT	0
703148	701645	19251M	PARTICIPANT	\N	PRESENT	0
703149	701645	20064C	PARTICIPANT	\N	PRESENT	0
703150	701645	04092N	PARTICIPANT	\N	PRESENT	0
703151	701645	20030R	PARTICIPANT	\N	PRESENT	0
703152	701645	11048N	PARTICIPANT	\N	PRESENT	0
703153	701645	04033B	PARTICIPANT	\N	PRESENT	0
703154	701645	17779H	PARTICIPANT	\N	PRESENT	0
703155	701645	14187A	PARTICIPANT	\N	PRESENT	0
703156	701645	20266L	PARTICIPANT	\N	PRESENT	0
703157	701645	14071N	PARTICIPANT	\N	PRESENT	0
703158	701645	05008E	PARTICIPANT	\N	PRESENT	0
703159	701645	11097X	PARTICIPANT	\N	PRESENT	0
703160	701645	19758L	PARTICIPANT	\N	PRESENT	0
703161	701645	11083R	PARTICIPANT	\N	PRESENT	0
703162	701645	19447X	PARTICIPANT	\N	PRESENT	0
703163	701645	14215L	PARTICIPANT	\N	PRESENT	0
703164	701645	19421M	PARTICIPANT	\N	PRESENT	0
703165	701645	14053L	PARTICIPANT	\N	PRESENT	0
703166	701645	19701S	PARTICIPANT	\N	PRESENT	0
703167	701645	14069U	PARTICIPANT	\N	PRESENT	0
703168	701645	11064N	PARTICIPANT	\N	PRESENT	0
703169	701645	19798U	PARTICIPANT	\N	PRESENT	0
703170	701645	20122U	PARTICIPANT	\N	PRESENT	0
703171	701645	20252E	PARTICIPANT	\N	PRESENT	0
703172	701645	19671E	PARTICIPANT	\N	PRESENT	0
703173	701645	04057K	PARTICIPANT	\N	PRESENT	0
703174	701645	19367Y	PARTICIPANT	\N	PRESENT	0
703175	701645	14251Q	PARTICIPANT	\N	PRESENT	0
703176	701645	19581D	PARTICIPANT	\N	PRESENT	0
703177	701645	20054A	PARTICIPANT	\N	PRESENT	0
703178	701645	19563B	PARTICIPANT	\N	PRESENT	0
703179	701645	20126Y	PARTICIPANT	\N	PRESENT	0
703180	701645	19543W	PARTICIPANT	\N	PRESENT	0
703181	701645	20124W	PARTICIPANT	\N	PRESENT	0
703182	701645	14059S	PARTICIPANT	\N	PRESENT	0
703183	701645	20062A	PARTICIPANT	\N	PRESENT	0
703184	701645	20042V	PARTICIPANT	\N	PRESENT	0
703185	701645	14329V	PARTICIPANT	\N	PRESENT	0
703186	701645	20048C	PARTICIPANT	\N	PRESENT	0
703187	701645	20052X	PARTICIPANT	\N	PRESENT	0
703188	701645	14357A	PARTICIPANT	\N	PRESENT	0
703189	701645	19675J	PARTICIPANT	\N	PRESENT	0
703190	701645	19713W	PARTICIPANT	\N	PRESENT	0
703191	701645	14089Y	PARTICIPANT	\N	PRESENT	0
703192	701645	19619A	PARTICIPANT	\N	PRESENT	0
703193	701645	19721W	PARTICIPANT	\N	PRESENT	0
703194	701645	19383Y	PARTICIPANT	\N	PRESENT	0
703195	701645	19441R	PARTICIPANT	\N	PRESENT	0
703196	701645	19762G	PARTICIPANT	\N	PRESENT	0
703197	701645	19479G	PARTICIPANT	\N	PRESENT	0
703198	701645	20020P	PARTICIPANT	\N	PRESENT	0
703199	701645	20152B	PARTICIPANT	\N	PRESENT	0
703200	701645	14042U	PARTICIPANT	\N	PRESENT	0
703201	701645	20120S	PARTICIPANT	\N	PRESENT	0
703202	701645	16685X	PARTICIPANT	\N	PRESENT	0
703203	701645	14217N	PARTICIPANT	\N	PRESENT	0
703204	701645	07033P	PARTICIPANT	\N	PRESENT	0
703205	701645	19585H	PARTICIPANT	\N	PRESENT	0
703206	701645	97011G	PARTICIPANT	\N	PRESENT	0
703207	701645	19569H	PARTICIPANT	\N	PRESENT	0
703208	701645	14205J	PARTICIPANT	\N	PRESENT	0
703209	701645	20144B	PARTICIPANT	\N	PRESENT	0
703210	701645	14189C	PARTICIPANT	\N	PRESENT	0
703211	701645	11053K	PARTICIPANT	\N	PRESENT	0
703212	701645	01034P	PARTICIPANT	\N	PRESENT	0
703213	701645	19369B	PARTICIPANT	\N	PRESENT	0
703214	701645	20298U	PARTICIPANT	\N	PRESENT	0
703215	701645	19611R	PARTICIPANT	\N	PRESENT	0
703216	701645	19691J	PARTICIPANT	\N	PRESENT	0
703217	701645	14179A	PARTICIPANT	\N	PRESENT	0
703218	701645	11026G	PARTICIPANT	\N	PRESENT	0
703219	701645	17229F	PARTICIPANT	\N	PRESENT	0
703220	701645	14267Y	PARTICIPANT	\N	PRESENT	0
703221	701645	17023S	PARTICIPANT	\N	PRESENT	0
703222	701645	19335Q	PARTICIPANT	\N	PRESENT	0
703223	701645	20098N	PARTICIPANT	\N	PRESENT	0
703224	701645	19699S	PARTICIPANT	\N	PRESENT	0
703225	701645	14083S	PARTICIPANT	\N	PRESENT	0
703226	701645	11070L	PARTICIPANT	\N	PRESENT	0
703227	701645	20040T	PARTICIPANT	\N	PRESENT	0
703228	701645	19826F	PARTICIPANT	\N	PRESENT	0
703229	701645	07004J	PARTICIPANT	\N	PRESENT	0
703230	701645	14255U	PARTICIPANT	\N	PRESENT	0
703231	701645	11085T	PARTICIPANT	\N	PRESENT	0
703232	701645	20066E	PARTICIPANT	\N	PRESENT	0
703233	701645	04070G	PARTICIPANT	\N	PRESENT	0
703234	701645	20094J	PARTICIPANT	\N	PRESENT	0
703235	701645	19553Y	PARTICIPANT	\N	PRESENT	0
703236	701645	01025N	PARTICIPANT	\N	PRESENT	0
703237	701645	01024M	PARTICIPANT	\N	PRESENT	0
703238	701645	14030Q	PARTICIPANT	\N	PRESENT	0
703239	701645	14327T	PARTICIPANT	\N	PRESENT	0
703240	701645	07029T	PARTICIPANT	\N	PRESENT	0
703241	701645	01043Q	PARTICIPANT	\N	PRESENT	0
703242	701645	20286Q	PARTICIPANT	\N	PRESENT	0
703243	701645	14123H	PARTICIPANT	\N	PRESENT	0
703244	701645	19679N	PARTICIPANT	\N	PRESENT	0
703245	701645	14111D	PARTICIPANT	\N	PRESENT	0
703246	701645	20136B	PARTICIPANT	\N	PRESENT	0
703247	701645	04043D	PARTICIPANT	\N	PRESENT	0
703248	701645	19717B	PARTICIPANT	\N	PRESENT	0
703249	701645	11074Q	PARTICIPANT	\N	PRESENT	0
703252	701645	95041E	PARTICIPANT	\N	PRESENT	0
703253	701645	19057M	PARTICIPANT	\N	PRESENT	0
703563	701647	19719D	PARTICIPANT	\N	PRESENT	0
703564	701647	14205J	PARTICIPANT	\N	PRESENT	0
703567	701647	14121F	PARTICIPANT	\N	PRESENT	0
703568	701647	14037X	PARTICIPANT	\N	PRESENT	0
703569	701647	20286Q	PARTICIPANT	\N	PRESENT	0
703570	701647	14089Y	PARTICIPANT	\N	PRESENT	0
703571	701647	19866P	PARTICIPANT	\N	PRESENT	0
703572	701647	19695N	PARTICIPANT	\N	PRESENT	0
703573	701647	20128B	PARTICIPANT	\N	PRESENT	0
703574	701647	19758L	PARTICIPANT	\N	PRESENT	0
703575	701647	19563B	PARTICIPANT	\N	PRESENT	0
703576	701647	20072C	PARTICIPANT	\N	PRESENT	0
703577	701647	14207L	PARTICIPANT	\N	PRESENT	0
703578	701647	11090Q	PARTICIPANT	\N	PRESENT	0
703579	701647	19507S	PARTICIPANT	\N	PRESENT	0
703580	701647	14191V	PARTICIPANT	\N	PRESENT	0
703581	701647	14033T	PARTICIPANT	\N	PRESENT	0
703582	701647	20068G	PARTICIPANT	\N	PRESENT	0
703583	701647	14069U	PARTICIPANT	\N	PRESENT	0
703584	701647	19798U	PARTICIPANT	\N	PRESENT	0
703585	701647	14147R	PARTICIPANT	\N	PRESENT	0
703586	701647	97011G	PARTICIPANT	\N	PRESENT	0
703587	701647	20030R	PARTICIPANT	\N	PRESENT	0
703588	701647	19251M	PARTICIPANT	\N	PRESENT	0
703589	701647	01058X	PARTICIPANT	\N	PRESENT	0
703590	701647	11099A	PARTICIPANT	\N	PRESENT	0
703591	701647	11083R	PARTICIPANT	\N	PRESENT	0
703592	701647	17023S	PARTICIPANT	\N	PRESENT	0
703597	701647	18083K	PARTICIPANT	\N	PRESENT	0
703594	701647	20032T	PARTICIPANT	\N	PRESENT	0
703595	701647	19782L	PARTICIPANT	\N	PRESENT	0
703596	701647	20062A	PARTICIPANT	\N	PRESENT	0
703598	701647	08061X	PARTICIPANT	\N	PRESENT	0
703599	701647	14257W	PARTICIPANT	\N	PRESENT	0
703600	701647	20098N	PARTICIPANT	\N	PRESENT	0
703601	701647	14073Q	PARTICIPANT	\N	PRESENT	0
703602	701647	20028X	PARTICIPANT	\N	PRESENT	0
703603	701647	14219Q	PARTICIPANT	\N	PRESENT	0
703604	701647	20180F	PARTICIPANT	\N	PRESENT	0
703605	701647	19954N	PARTICIPANT	\N	PRESENT	0
703606	701647	19387D	PARTICIPANT	\N	PRESENT	0
703607	701647	20042V	PARTICIPANT	\N	PRESENT	0
703608	701647	12016W	PARTICIPANT	\N	PRESENT	0
703612	701647	19441R	PARTICIPANT	\N	PRESENT	0
703610	701647	20018V	PARTICIPANT	\N	PRESENT	0
703611	701647	20092G	PARTICIPANT	\N	PRESENT	0
703613	701647	14083S	PARTICIPANT	\N	PRESENT	0
703614	701647	19515S	PARTICIPANT	\N	PRESENT	0
703615	701647	19651A	PARTICIPANT	\N	PRESENT	0
703616	701647	19691J	PARTICIPANT	\N	PRESENT	0
711130	708187	19467C	PARTICIPANT	\N	PRESENT	0
711131	708187	11090Q	PARTICIPANT	\N	PRESENT	0
711132	708187	14217N	PARTICIPANT	\N	PRESENT	0
711133	708187	20084G	PARTICIPANT	\N	PRESENT	0
711134	708187	14281W	PARTICIPANT	\N	PRESENT	0
711135	708187	17965H	PARTICIPANT	\N	PRESENT	0
711136	708187	20094J	PARTICIPANT	\N	PRESENT	0
711137	708187	11064N	PARTICIPANT	\N	PRESENT	0
711138	708187	19703U	PARTICIPANT	\N	PRESENT	0
711139	708187	10015M	PARTICIPANT	\N	PRESENT	0
711140	708187	17779H	PARTICIPANT	\N	PRESENT	0
711141	708187	14357A	PARTICIPANT	\N	PRESENT	0
711142	708187	04033B	PARTICIPANT	\N	PRESENT	0
711143	708187	14071N	PARTICIPANT	\N	PRESENT	0
711144	708187	19701S	PARTICIPANT	\N	PRESENT	0
711145	708187	19647E	PARTICIPANT	\N	PRESENT	0
711146	708187	19489J	PARTICIPANT	\N	PRESENT	0
711147	708187	19725B	PARTICIPANT	\N	PRESENT	0
711148	708187	20134Y	PARTICIPANT	\N	PRESENT	0
711149	708187	20266L	PARTICIPANT	\N	PRESENT	0
711150	708187	19631V	PARTICIPANT	\N	PRESENT	0
711151	708187	14249W	PARTICIPANT	\N	PRESENT	0
711152	708187	20026V	PARTICIPANT	\N	PRESENT	0
711153	708187	20096L	PARTICIPANT	\N	PRESENT	0
711154	708187	14033T	PARTICIPANT	\N	PRESENT	0
711155	708187	19657G	PARTICIPANT	\N	PRESENT	0
711156	708187	14059S	PARTICIPANT	\N	PRESENT	0
711157	708187	08012N	PARTICIPANT	\N	PRESENT	0
711158	708187	20030R	PARTICIPANT	\N	PRESENT	0
711159	708187	01057W	PARTICIPANT	\N	PRESENT	0
711160	708187	20076G	PARTICIPANT	\N	PRESENT	0
711161	708187	19643A	PARTICIPANT	\N	PRESENT	0
711162	708187	19673G	PARTICIPANT	\N	PRESENT	0
711163	708187	20086J	PARTICIPANT	\N	PRESENT	0
711164	708187	19575F	PARTICIPANT	\N	PRESENT	0
711128	708187	20980G	PARTICIPANT	\N	PRESENT	0
711129	708187	19573D	PARTICIPANT	\N	PRESENT	0
711165	708187	14231L	PARTICIPANT	\N	PRESENT	0
711166	708187	14205J	PARTICIPANT	\N	PRESENT	0
711167	708187	19826F	PARTICIPANT	\N	PRESENT	0
711168	708187	14267Y	PARTICIPANT	\N	PRESENT	0
711169	708187	20048C	PARTICIPANT	\N	PRESENT	0
711170	708187	20052X	PARTICIPANT	\N	PRESENT	0
711171	708187	01043Q	PARTICIPANT	\N	PRESENT	0
711172	708187	19543W	PARTICIPANT	\N	PRESENT	0
711173	708187	20106U	PARTICIPANT	\N	PRESENT	0
711174	708187	20018V	PARTICIPANT	\N	PRESENT	0
711175	708187	20082E	PARTICIPANT	\N	PRESENT	0
711176	708187	08018U	PARTICIPANT	\N	PRESENT	0
711177	708187	19549D	PARTICIPANT	\N	PRESENT	0
711178	708187	19758L	PARTICIPANT	\N	PRESENT	0
711179	708187	19695N	PARTICIPANT	\N	PRESENT	0
711180	708187	04070G	PARTICIPANT	\N	PRESENT	0
711181	708187	19565D	PARTICIPANT	\N	PRESENT	0
711182	708187	14259Y	PARTICIPANT	\N	PRESENT	0
711183	708187	14069U	PARTICIPANT	\N	PRESENT	0
711184	708187	20104S	PARTICIPANT	\N	PRESENT	0
711185	708187	19709B	PARTICIPANT	\N	PRESENT	0
711186	708187	20070A	PARTICIPANT	\N	PRESENT	0
711187	708187	14021P	PARTICIPANT	\N	PRESENT	0
711188	708187	20152B	PARTICIPANT	\N	PRESENT	0
711189	708187	14026U	PARTICIPANT	\N	PRESENT	0
711190	708187	20098N	PARTICIPANT	\N	PRESENT	0
711191	708187	20042V	PARTICIPANT	\N	PRESENT	0
711192	708187	14109K	PARTICIPANT	\N	PRESENT	0
711193	708187	20028X	PARTICIPANT	\N	PRESENT	0
711194	708187	14089Y	PARTICIPANT	\N	PRESENT	0
711195	708187	20286Q	PARTICIPANT	\N	PRESENT	0
711196	708187	20298U	PARTICIPANT	\N	PRESENT	0
711197	708187	19691J	PARTICIPANT	\N	PRESENT	0
711198	708187	19713W	PARTICIPANT	\N	PRESENT	0
711199	708187	19739H	PARTICIPANT	\N	PRESENT	0
711200	708187	19563B	PARTICIPANT	\N	PRESENT	0
711201	708187	19479G	PARTICIPANT	\N	PRESENT	0
711202	708187	19721W	PARTICIPANT	\N	PRESENT	0
711203	708187	19057M	PARTICIPANT	\N	PRESENT	0
711204	708187	01028R	PARTICIPANT	\N	PRESENT	0
711205	708187	19659J	PARTICIPANT	\N	PRESENT	0
711206	708187	20118Y	PARTICIPANT	\N	PRESENT	0
711207	708187	17637T	PARTICIPANT	\N	PRESENT	0
711208	708187	19621T	PARTICIPANT	\N	PRESENT	0
711209	708187	20058E	PARTICIPANT	\N	PRESENT	0
711210	708187	19693L	PARTICIPANT	\N	PRESENT	0
711211	708187	14257W	PARTICIPANT	\N	PRESENT	0
711212	708187	19369B	PARTICIPANT	\N	PRESENT	0
711213	708187	14083S	PARTICIPANT	\N	PRESENT	0
711214	708187	11048N	PARTICIPANT	\N	PRESENT	0
711215	708187	20120S	PARTICIPANT	\N	PRESENT	0
711216	708187	95041E	PARTICIPANT	\N	PRESENT	0
711217	708187	14151M	PARTICIPANT	\N	PRESENT	0
711218	708187	08015R	PARTICIPANT	\N	PRESENT	0
711219	708187	19729F	PARTICIPANT	\N	PRESENT	0
711220	708187	01048V	PARTICIPANT	\N	PRESENT	0
711221	708187	14179A	PARTICIPANT	\N	PRESENT	0
711222	708187	04059M	PARTICIPANT	\N	PRESENT	0
711223	708187	19723Y	PARTICIPANT	\N	PRESENT	0
711224	708187	05012A	PARTICIPANT	\N	PRESENT	0
711225	708187	11085T	PARTICIPANT	\N	PRESENT	0
711226	708187	20054A	PARTICIPANT	\N	PRESENT	0
711227	708187	20126Y	PARTICIPANT	\N	PRESENT	0
711228	708187	19415P	PARTICIPANT	\N	PRESENT	0
711229	708187	07004J	PARTICIPANT	\N	PRESENT	0
711245	706234	19659J	PARTICIPANT	\N	EXCUSE	0
711246	706234	19657G	PARTICIPANT	\N	EXCUSE	0
711247	706234	19717B	PRESIDENT	0	PRESENT	0
711248	706234	20146D	PARTICIPANT	\N	PRESENT	0
711249	706234	19295A	PARTICIPANT	\N	PRESENT	1
711250	706234	18083K	PARTICIPANT	\N	PRESENT	0
711252	705810	14189C	PARTICIPANT	\N	PRESENT	0
711253	705810	14030Q	PRESIDENT	0	PRESENT	0
711254	705810	17737W	PARTICIPANT	\N	PRESENT	0
711255	705810	20034V	PARTICIPANT	\N	PRESENT	0
711256	705810	20056C	PARTICIPANT	\N	PRESENT	0
711257	705810	14109K	PARTICIPANT	\N	PRESENT	0
711258	705810	20118Y	PARTICIPANT	\N	PRESENT	0
711259	705810	19798U	PARTICIPANT	\N	PRESENT	0
711260	705810	20024T	PARTICIPANT	\N	PRESENT	0
711261	705810	20248J	PARTICIPANT	\N	PRESENT	0
711262	708188	95063L	PARTICIPANT	\N	PRESENT	0
711263	705810	01043Q	PARTICIPANT	\N	PRESENT	0
711264	708188	19683J	PARTICIPANT	\N	PRESENT	0
711265	708188	19549D	PARTICIPANT	\N	PRESENT	0
711266	708188	08060W	PARTICIPANT	\N	PRESENT	0
711267	708188	14021P	PARTICIPANT	\N	PRESENT	0
711268	708188	20264J	PARTICIPANT	\N	PRESENT	0
711269	708188	20030R	PARTICIPANT	\N	PRESENT	0
711270	708188	11074Q	PARTICIPANT	\N	PRESENT	0
711271	708188	19760E	PARTICIPANT	\N	PRESENT	0
711272	708188	19565D	PARTICIPANT	\N	PRESENT	0
711273	708188	20076G	PARTICIPANT	\N	PRESENT	0
711274	708188	19575F	PARTICIPANT	\N	PRESENT	0
711275	708188	19693L	PARTICIPANT	\N	PRESENT	0
711276	708188	19333N	PARTICIPANT	\N	PRESENT	0
711277	708188	14225N	PARTICIPANT	\N	PRESENT	0
711278	708188	14259Y	PARTICIPANT	\N	PRESENT	0
711279	708188	19667J	PARTICIPANT	\N	PRESENT	0
711280	708188	19573D	PARTICIPANT	\N	PRESENT	0
711281	708188	11045K	PARTICIPANT	\N	PRESENT	0
711282	708188	01062T	PARTICIPANT	\N	PRESENT	0
711283	708188	08045X	PARTICIPANT	\N	PRESENT	0
711284	708188	20134Y	PARTICIPANT	\N	PRESENT	0
711285	708188	14071N	PARTICIPANT	\N	PRESENT	0
711286	708188	19782L	PARTICIPANT	\N	PRESENT	0
711287	708188	19525U	PARTICIPANT	\N	PRESENT	0
711288	708188	14187A	PARTICIPANT	\N	PRESENT	0
711289	708188	20130U	PARTICIPANT	\N	PRESENT	0
711290	708188	04033B	PARTICIPANT	\N	PRESENT	0
711291	708188	19413M	PARTICIPANT	\N	PRESENT	0
711292	708188	19701S	PARTICIPANT	\N	PRESENT	0
711293	708188	12028B	PARTICIPANT	\N	PRESENT	0
711294	708188	19820Y	PARTICIPANT	\N	PRESENT	0
711295	708188	11104D	PARTICIPANT	\N	PRESENT	0
711296	708188	20122U	PARTICIPANT	\N	PRESENT	0
711297	708188	14195A	PARTICIPANT	\N	PRESENT	0
711298	708188	10006L	PARTICIPANT	\N	PRESENT	0
711299	708188	11097X	PARTICIPANT	\N	PRESENT	0
711300	708188	14042U	PARTICIPANT	\N	PRESENT	0
711301	708188	19758L	PARTICIPANT	\N	PRESENT	0
711302	708188	20028X	PARTICIPANT	\N	PRESENT	0
711303	708188	14217N	PARTICIPANT	\N	PRESENT	0
711304	708188	11067R	PARTICIPANT	\N	PRESENT	0
687373	686130	11067R	PARTICIPANT	\N	PRESENT	0
687374	686130	18193Q	PARTICIPANT	\N	PRESENT	0
687375	686130	19683J	PARTICIPANT	\N	PRESENT	0
687376	686130	14281W	PARTICIPANT	\N	PRESENT	0
687377	686130	11031D	PARTICIPANT	\N	PRESENT	0
687378	686130	14195A	PARTICIPANT	\N	PRESENT	0
687379	686130	19691J	PARTICIPANT	\N	PRESENT	0
687380	686130	19367Y	PARTICIPANT	\N	PRESENT	0
687381	686130	19798U	PARTICIPANT	\N	PRESENT	0
687382	686130	19679N	PARTICIPANT	\N	PRESENT	0
687383	686130	20090E	PARTICIPANT	\N	PRESENT	0
687384	686130	14217N	PARTICIPANT	\N	PRESENT	0
687385	686130	11097X	PARTICIPANT	\N	PRESENT	0
687386	686130	14213J	PARTICIPANT	\N	PRESENT	0
687387	686130	19703U	PARTICIPANT	\N	PRESENT	0
687388	686130	19511N	PARTICIPANT	\N	PRESENT	0
687389	686130	14071N	PRESIDENT	1	PRESENT	0
687390	686130	14042U	PARTICIPANT	\N	PRESENT	0
687391	686130	10006L	PRESIDENT	0	PRESENT	0
687392	686130	19553Y	PARTICIPANT	\N	PRESENT	0
687393	686130	20130U	PARTICIPANT	\N	EXCUSE	0
687394	686130	19723Y	PARTICIPANT	\N	PRESENT	0
687397	686130	14026U	PARTICIPANT	\N	PRESENT	0
687398	686130	19715Y	PARTICIPANT	\N	PRESENT	0
687411	686130	19569H	PARTICIPANT	\N	PRESENT	0
687413	686130	20040T	PARTICIPANT	\N	PRESENT	0
687415	686130	19415P	PARTICIPANT	\N	PRESENT	0
687416	686130	17779H	PARTICIPANT	\N	EXCUSE	0
687417	686130	19713W	PARTICIPANT	\N	PRESENT	0
687426	687425	14193X	PARTICIPANT	\N	PRESENT	0
687427	687425	01062T	PARTICIPANT	\N	PRESENT	0
687437	687436	20042V	PARTICIPANT	\N	PRESENT	0
687438	687436	01062T	PARTICIPANT	\N	PRESENT	0
687439	687436	14193X	PARTICIPANT	\N	PRESENT	0
687440	687436	19421M	PARTICIPANT	\N	PRESENT	0
687442	687441	20042V	PARTICIPANT	\N	PRESENT	0
687443	687441	14059S	PARTICIPANT	\N	PRESENT	0
687444	687441	01062T	PARTICIPANT	\N	PRESENT	0
687445	687441	14193X	PARTICIPANT	\N	PRESENT	0
691766	691502	19705W	PARTICIPANT	\N	PRESENT	0
691767	691502	08015R	PARTICIPANT	\N	PRESENT	0
691768	691502	19575F	PARTICIPANT	\N	PRESENT	0
691769	691502	20018V	PARTICIPANT	\N	PRESENT	0
691770	691502	08028W	PARTICIPANT	\N	PRESENT	0
691771	691502	19563B	PARTICIPANT	\N	PRESENT	0
691772	691502	14329V	PARTICIPANT	\N	PRESENT	0
691773	691502	20028X	PARTICIPANT	\N	PRESENT	0
691774	691502	19467C	PARTICIPANT	\N	PRESENT	0
691775	691502	20034V	PARTICIPANT	\N	PRESENT	0
691776	691502	14187A	PARTICIPANT	\N	PRESENT	0
691777	691502	20144B	PARTICIPANT	\N	PRESENT	0
691778	691502	19695N	PARTICIPANT	\N	PRESENT	0
691779	691502	11090Q	PRESIDENT	0	PRESENT	0
691780	691502	14033T	PARTICIPANT	\N	PRESENT	0
691781	691502	01025N	PARTICIPANT	\N	PRESENT	0
691782	691502	20054A	PARTICIPANT	\N	PRESENT	0
691783	691502	14205J	PARTICIPANT	\N	PRESENT	0
691784	691502	20060X	PARTICIPANT	\N	PRESENT	0
691785	691502	20062A	PARTICIPANT	\N	PRESENT	0
691786	691502	19507S	PARTICIPANT	\N	PRESENT	0
691787	691502	20286Q	PARTICIPANT	\N	PRESENT	0
691788	691502	20298U	PARTICIPANT	\N	PRESENT	0
691789	691502	14207L	PARTICIPANT	\N	PRESENT	0
691790	691502	19747H	PARTICIPANT	\N	PRESENT	0
691791	691502	14257W	PARTICIPANT	\N	PRESENT	0
691792	690786	20150Y	PARTICIPANT	\N	PRESENT	0
691793	690789	19583F	PARTICIPANT	\N	PRESENT	0
691794	690789	17023S	PARTICIPANT	\N	PRESENT	0
691795	690790	12041X	PARTICIPANT	\N	PRESENT	0
691796	690790	95041E	PARTICIPANT	\N	PRESENT	0
691797	690790	20072C	PARTICIPANT	\N	PRESENT	0
691798	690790	19565D	PARTICIPANT	\N	PRESENT	0
691799	690790	11080N	PARTICIPANT	\N	PRESENT	0
691800	690790	01058X	PARTICIPANT	\N	PRESENT	0
691801	690790	11027H	PARTICIPANT	\N	PRESENT	0
691802	690790	16685X	PARTICIPANT	\N	PRESENT	0
691803	690790	04042C	PRESIDENT	0	PRESENT	0
691804	690790	11054L	PARTICIPANT	\N	PRESENT	0
691805	690790	11066Q	PARTICIPANT	\N	PRESENT	0
691806	690790	19669L	PARTICIPANT	\N	PRESENT	0
691807	690790	08056B	PARTICIPANT	\N	PRESENT	0
691808	690790	12028B	PARTICIPANT	\N	PRESENT	0
691809	690790	14055N	PARTICIPANT	\N	PRESENT	0
691810	690790	19421M	PARTICIPANT	\N	PRESENT	0
691811	690790	19709B	PARTICIPANT	\N	PRESENT	0
691812	690790	19347U	PARTICIPANT	\N	PRESENT	0
691813	690790	14193X	PARTICIPANT	\N	PRESENT	0
691814	690790	07033P	PARTICIPANT	\N	PRESENT	0
691815	690790	97011G	PARTICIPANT	\N	PRESENT	0
691816	690790	08061X	PARTICIPANT	\N	PRESENT	0
691817	690790	14249W	PARTICIPANT	\N	PRESENT	0
691818	690790	08047A	PARTICIPANT	\N	PRESENT	0
691819	690790	20128B	PARTICIPANT	\N	PRESENT	0
691820	690790	14059S	PARTICIPANT	\N	PRESENT	0
691821	690790	14097Y	PARTICIPANT	\N	PRESENT	0
691822	690790	14133K	PARTICIPANT	\N	PRESENT	0
691823	690790	01062T	PARTICIPANT	\N	PRESENT	0
691824	690790	08069G	PARTICIPANT	\N	PRESENT	0
691825	690790	11041F	PARTICIPANT	\N	PRESENT	0
691826	690790	20042V	PARTICIPANT	\N	PRESENT	0
691827	690790	01024M	PARTICIPANT	\N	PRESENT	0
691828	690790	19721W	PARTICIPANT	\N	PRESENT	0
691829	690790	19319Q	PARTICIPANT	\N	PRESENT	0
691830	690790	14105F	PARTICIPANT	\N	PRESENT	0
691831	690790	98022P	PARTICIPANT	\N	PRESENT	0
691832	690790	11064N	PARTICIPANT	\N	PRESENT	0
691833	690790	14267Y	PARTICIPANT	\N	PRESENT	0
691834	690790	11083R	PARTICIPANT	\N	PRESENT	0
691835	690790	14211G	PARTICIPANT	\N	PRESENT	0
691836	690790	19583F	PARTICIPANT	\N	PRESENT	0
691837	690790	14255U	PARTICIPANT	\N	PRESENT	0
691838	690790	17023S	PARTICIPANT	\N	PRESENT	0
691839	690790	19443T	PARTICIPANT	\N	EXCUSE	0
691840	690786	19545Y	PARTICIPANT	\N	PRESENT	0
691841	690709	01028R	PARTICIPANT	\N	PRESENT	0
691843	690827	86034E	PARTICIPANT	\N	PRESENT	0
691862	690827	19760E	PARTICIPANT	\N	PRESENT	0
691863	690827	11040E	PARTICIPANT	\N	PRESENT	0
691864	690827	19758L	PARTICIPANT	\N	PRESENT	0
691865	690827	04085P	PARTICIPANT	\N	PRESENT	0
691866	690827	19565D	PARTICIPANT	\N	PRESENT	0
691867	690827	11056N	PARTICIPANT	\N	PRESENT	0
691868	690827	20046A	PARTICIPANT	\N	PRESENT	0
691869	690827	20102Q	PARTICIPANT	\N	PRESENT	0
691870	690827	19593H	PARTICIPANT	\N	PRESENT	0
691871	690827	11033F	PARTICIPANT	\N	PRESENT	0
691872	690827	17589D	PARTICIPANT	\N	PRESENT	0
691873	690827	19545Y	PARTICIPANT	\N	PRESENT	0
691874	690827	11064N	PARTICIPANT	\N	PRESENT	0
691875	690827	19583F	PARTICIPANT	\N	PRESENT	0
691876	690827	20050V	PARTICIPANT	\N	PRESENT	0
691877	690827	14195A	PARTICIPANT	\N	PRESENT	0
691878	690827	19651A	PARTICIPANT	\N	PRESENT	0
691879	690827	19329S	PARTICIPANT	\N	PRESENT	0
691880	690827	19301E	PARTICIPANT	\N	PRESENT	0
691881	690827	08073C	PARTICIPANT	\N	PRESENT	0
691882	690827	20110Q	PARTICIPANT	\N	PRESENT	0
691883	690827	20100N	PARTICIPANT	\N	PRESENT	0
691884	690827	19347U	PARTICIPANT	\N	PRESENT	0
691885	690827	20142Y	PARTICIPANT	\N	PRESENT	0
691886	690827	20036X	PARTICIPANT	\N	PRESENT	0
691887	690827	20130U	PARTICIPANT	\N	PRESENT	0
691888	690827	20266L	PARTICIPANT	\N	PRESENT	0
691889	690827	20092G	PARTICIPANT	\N	PRESENT	0
691890	690827	08061X	PARTICIPANT	\N	PRESENT	0
691891	690827	20128B	PARTICIPANT	\N	PRESENT	0
691892	690827	14207L	PARTICIPANT	\N	PRESENT	0
691894	690827	19629C	PARTICIPANT	\N	PRESENT	0
691895	690827	19719D	PARTICIPANT	\N	PRESENT	0
691896	690827	98022P	PARTICIPANT	\N	PRESENT	0
691897	690827	19553Y	PARTICIPANT	\N	PRESENT	0
691898	690827	19866P	PARTICIPANT	\N	PRESENT	0
691900	690827	19681G	PARTICIPANT	\N	PRESENT	0
691901	690827	14107H	PARTICIPANT	\N	PRESENT	0
691902	690827	19697Q	PARTICIPANT	\N	PRESENT	0
691903	690827	20134Y	PARTICIPANT	\N	PRESENT	0
691904	690827	19637C	PARTICIPANT	\N	PRESENT	0
691905	690827	11072N	PARTICIPANT	\N	PRESENT	0
691906	690827	20116W	PARTICIPANT	\N	PRESENT	0
691907	690827	19543W	PARTICIPANT	\N	PRESENT	0
691908	690827	14030Q	PARTICIPANT	\N	PRESENT	0
704800	704798	19349W	PARTICIPANT	\N	PRESENT	0
704801	704798	11056N	PARTICIPANT	\N	PRESENT	0
704802	704798	19525U	PARTICIPANT	\N	PRESENT	0
704805	704798	01043Q	PARTICIPANT	\N	PRESENT	0
704806	704798	20086J	PARTICIPANT	\N	PRESENT	0
704809	704808	19631V	PARTICIPANT	\N	PRESENT	0
704811	704808	19349W	PARTICIPANT	\N	PRESENT	0
704812	704808	11056N	PARTICIPANT	\N	PRESENT	0
704813	704808	19525U	PARTICIPANT	\N	PRESENT	0
704814	704808	01043Q	PARTICIPANT	\N	PRESENT	0
704815	704808	20086J	PARTICIPANT	\N	PRESENT	0
704816	704808	19531S	PARTICIPANT	\N	PRESENT	0
704823	704822	19820Y	PARTICIPANT	\N	PRESENT	0
704824	704822	05012A	PARTICIPANT	\N	PRESENT	0
704825	704822	20914V	PARTICIPANT	\N	PRESENT	0
704826	704822	19745F	PARTICIPANT	\N	PRESENT	0
704830	703792	05008E	PARTICIPANT	\N	PRESENT	0
704831	704078	14267Y	PARTICIPANT	\N	PRESENT	0
704832	704822	20104S	PARTICIPANT	\N	PRESENT	0
704833	704078	19511N	PARTICIPANT	\N	PRESENT	0
704834	704078	19565D	PARTICIPANT	\N	PRESENT	0
704835	704078	19593H	PARTICIPANT	\N	PRESENT	0
704836	704078	11054L	PARTICIPANT	\N	PRESENT	0
704837	704078	20034V	PARTICIPANT	\N	PRESENT	0
704838	704078	19766L	PARTICIPANT	\N	PRESENT	0
704839	704078	86034E	PARTICIPANT	\N	PRESENT	0
704840	704078	14259Y	PARTICIPANT	\N	PRESENT	0
704841	704078	14237S	PARTICIPANT	\N	PRESENT	0
704842	704078	20136B	PARTICIPANT	\N	PRESENT	0
704843	704078	17589D	PARTICIPANT	\N	PRESENT	0
704844	704078	20046A	PARTICIPANT	\N	PRESENT	0
704845	704078	20068G	PARTICIPANT	\N	PRESENT	0
704846	704078	14073Q	PARTICIPANT	\N	PRESENT	0
704847	704078	98022P	PARTICIPANT	\N	PRESENT	0
704848	704078	19629C	PARTICIPANT	\N	PRESENT	0
704849	704078	14331P	PARTICIPANT	\N	PRESENT	0
704850	704078	20074E	PARTICIPANT	\N	PRESENT	0
704851	704078	19621T	PARTICIPANT	\N	PRESENT	0
704852	704078	11099A	PARTICIPANT	\N	PRESENT	0
704853	704078	18193Q	PARTICIPANT	\N	PRESENT	0
704854	704078	19057M	PARTICIPANT	\N	PRESENT	0
704855	704078	14207L	PARTICIPANT	\N	PRESENT	0
704856	704078	14107H	PARTICIPANT	\N	PRESENT	0
704857	704078	19866P	PARTICIPANT	\N	PRESENT	0
704858	704078	19683J	PARTICIPANT	\N	PRESENT	0
704859	704078	19649G	PARTICIPANT	\N	PRESENT	0
704860	704078	19527W	PARTICIPANT	\N	PRESENT	0
704861	704078	14109K	PARTICIPANT	\N	PRESENT	0
704862	704078	11033F	PARTICIPANT	\N	PRESENT	0
704863	704078	20264J	PARTICIPANT	\N	PRESENT	0
704864	704078	04059M	PARTICIPANT	\N	PRESENT	0
704865	704078	04045F	PARTICIPANT	\N	PRESENT	0
704866	704078	20088L	PARTICIPANT	\N	PRESENT	0
704867	704078	08009T	PARTICIPANT	\N	PRESENT	0
704868	704078	19349W	PARTICIPANT	\N	PRESENT	0
704869	704078	20036X	PARTICIPANT	\N	PRESENT	0
704873	704078	04008A	PARTICIPANT	\N	PRESENT	0
704874	704078	01058X	PARTICIPANT	\N	PRESENT	0
704875	704078	20076G	PARTICIPANT	\N	PRESENT	0
704876	704078	11101A	PARTICIPANT	\N	PRESENT	0
704877	704078	19703U	PARTICIPANT	\N	PRESENT	0
704878	704078	04047H	PARTICIPANT	\N	PRESENT	0
704879	704078	99004R	PARTICIPANT	\N	PRESENT	0
704880	704078	08010L	PARTICIPANT	\N	PRESENT	0
704881	704078	20078J	PARTICIPANT	\N	PRESENT	0
704882	704078	04042C	PARTICIPANT	\N	PRESENT	0
704883	704078	11048N	PARTICIPANT	\N	PRESENT	0
704884	704078	14133K	PARTICIPANT	\N	PRESENT	0
704885	704078	19747H	PARTICIPANT	\N	PRESENT	0
704886	704078	19415P	PARTICIPANT	\N	PRESENT	0
704887	704078	05008E	PARTICIPANT	\N	PRESENT	0
704888	704078	14071N	PARTICIPANT	\N	PRESENT	0
704889	704078	14187A	PARTICIPANT	\N	PRESENT	0
704890	704078	19679N	PARTICIPANT	\N	PRESENT	0
704891	704078	08034U	PARTICIPANT	\N	PRESENT	0
704892	704078	04033B	PARTICIPANT	\N	PRESENT	0
704893	704078	08028W	PARTICIPANT	\N	PRESENT	0
704894	704078	11043H	PARTICIPANT	\N	PRESENT	0
704895	704078	14223L	PARTICIPANT	\N	PRESENT	0
704896	704078	14169X	PARTICIPANT	\N	PRESENT	0
704897	704078	04071H	PARTICIPANT	\N	PRESENT	0
704898	704078	19643A	PARTICIPANT	\N	PRESENT	0
704899	704078	17367Q	PARTICIPANT	\N	PRESENT	0
704900	704078	19515S	PARTICIPANT	\N	PRESENT	0
704901	704078	19741B	PARTICIPANT	\N	PRESENT	0
704902	704078	11080N	PARTICIPANT	\N	PRESENT	0
704903	704078	11031D	PARTICIPANT	\N	PRESENT	0
704904	704078	19758L	PARTICIPANT	\N	PRESENT	0
704905	704078	01057W	PARTICIPANT	\N	PRESENT	0
704906	704078	19760E	PARTICIPANT	\N	PRESENT	0
704907	704078	20022R	PARTICIPANT	\N	PRESENT	0
704908	704078	04043D	PARTICIPANT	\N	PRESENT	0
704909	704078	14069U	PARTICIPANT	\N	PRESENT	0
704910	704078	20102Q	PARTICIPANT	\N	PRESENT	0
704911	704078	19701S	PARTICIPANT	\N	PRESENT	0
704912	704078	11097X	PARTICIPANT	\N	PRESENT	0
704913	704078	20110Q	PARTICIPANT	\N	PRESENT	0
704914	704078	20914V	PARTICIPANT	\N	PRESENT	0
704915	704078	14215L	PARTICIPANT	\N	PRESENT	0
704916	704078	14193X	PARTICIPANT	\N	PRESENT	0
704917	704078	19798U	PARTICIPANT	\N	PRESENT	0
704918	704078	20100N	PARTICIPANT	\N	PRESENT	0
704919	704078	10006L	PARTICIPANT	\N	PRESENT	0
704920	704078	19533U	PARTICIPANT	\N	PRESENT	0
704921	704078	20084G	PARTICIPANT	\N	PRESENT	0
704922	704078	20118Y	PARTICIPANT	\N	PRESENT	0
704923	704078	20142Y	PARTICIPANT	\N	PRESENT	0
704924	704078	20032T	PARTICIPANT	\N	PRESENT	0
704925	704078	19525U	PARTICIPANT	\N	PRESENT	0
704926	704078	14249W	PARTICIPANT	\N	PRESENT	0
704927	704078	14253S	PARTICIPANT	\N	PRESENT	0
704928	704078	11115U	PARTICIPANT	\N	PRESENT	0
704929	704078	14031R	PARTICIPANT	\N	PRESENT	0
704931	704078	19673G	PARTICIPANT	\N	PRESENT	0
704932	704078	08061X	PARTICIPANT	\N	PRESENT	0
704933	704078	20038A	PARTICIPANT	\N	PRESENT	0
704934	704078	95063L	PARTICIPANT	\N	PRESENT	0
704935	704078	14173T	PARTICIPANT	\N	PRESENT	0
704936	704078	20128B	PARTICIPANT	\N	PRESENT	0
704937	704078	20106U	PARTICIPANT	\N	PRESENT	0
704938	704078	19705W	PARTICIPANT	\N	PRESENT	0
704939	704078	11083R	PARTICIPANT	\N	PRESENT	0
704940	704078	19637C	PARTICIPANT	\N	PRESENT	0
704941	704078	19697Q	PARTICIPANT	\N	PRESENT	0
704942	704078	19447X	PARTICIPANT	\N	PRESENT	0
704943	704078	14037X	PARTICIPANT	\N	PRESENT	0
704944	704078	05012A	PARTICIPANT	\N	PRESENT	0
704945	704078	20086J	PARTICIPANT	\N	PRESENT	0
704946	704078	14055N	PARTICIPANT	\N	PRESENT	0
704947	704078	20096L	PARTICIPANT	\N	PRESENT	0
704948	704078	19717B	PARTICIPANT	\N	PRESENT	0
704949	704078	20180F	PARTICIPANT	\N	PRESENT	0
704950	704078	20026V	PARTICIPANT	\N	PRESENT	0
704951	704078	20116W	PARTICIPANT	\N	PRESENT	0
704952	704078	19954N	PARTICIPANT	\N	PRESENT	0
704953	704078	20132W	PARTICIPANT	\N	PRESENT	0
704954	704078	19387D	PARTICIPANT	\N	PRESENT	0
704955	704078	20140W	PARTICIPANT	\N	PRESENT	0
704956	704078	19681G	PARTICIPANT	\N	PRESENT	0
704957	704078	14147R	PARTICIPANT	\N	PRESENT	0
704958	704078	20072C	PARTICIPANT	\N	PRESENT	0
704959	704078	11012A	PARTICIPANT	\N	PRESENT	0
704960	704078	97011G	PARTICIPANT	\N	PRESENT	0
704961	704078	20134Y	PARTICIPANT	\N	PRESENT	0
704962	704078	07033P	PARTICIPANT	\N	PRESENT	0
704963	704078	19545Y	PARTICIPANT	\N	PRESENT	0
704964	704078	14195A	PARTICIPANT	\N	PRESENT	0
704965	704078	14217N	PARTICIPANT	\N	PRESENT	0
704966	704078	14211G	PARTICIPANT	\N	PRESENT	0
704967	704078	11064N	PARTICIPANT	\N	PRESENT	0
704968	704078	95041E	PARTICIPANT	\N	PRESENT	0
704969	704078	19671E	PARTICIPANT	\N	PRESENT	0
704970	704078	14251Q	PARTICIPANT	\N	PRESENT	0
704971	704078	01060R	PARTICIPANT	\N	PRESENT	0
704972	704078	19581D	PARTICIPANT	\N	PRESENT	0
704973	704078	20122U	PARTICIPANT	\N	PRESENT	0
704974	704078	14221J	PARTICIPANT	\N	PRESENT	0
704975	704078	20050V	PARTICIPANT	\N	PRESENT	0
704976	704078	20152B	PARTICIPANT	\N	PRESENT	0
704977	704078	20020P	PARTICIPANT	\N	PRESENT	0
696432	694876	19649G	PARTICIPANT	\N	PRESENT	0
696433	694876	11010L	PARTICIPANT	\N	PRESENT	0
696434	694876	11026G	PARTICIPANT	\N	PRESENT	0
696435	694876	10015M	PARTICIPANT	\N	PRESENT	0
696436	694876	04085P	PARTICIPANT	\N	PRESENT	0
696437	694876	14089Y	PARTICIPANT	\N	PRESENT	0
696438	694876	19725B	PARTICIPANT	\N	PRESENT	0
696439	694876	11056N	PARTICIPANT	\N	PRESENT	0
696440	694876	95063L	PARTICIPANT	\N	PRESENT	0
696441	694876	14069U	PARTICIPANT	\N	PRESENT	0
696442	694876	14021P	PARTICIPANT	\N	PRESENT	0
696443	694876	19729F	PARTICIPANT	\N	EXCUSE	0
696444	693394	20106U	PARTICIPANT	\N	PRESENT	0
696445	693394	19251M	PARTICIPANT	\N	PRESENT	0
696447	695107	95041E	PARTICIPANT	\N	PRESENT	0
696448	695107	12041X	PARTICIPANT	\N	PRESENT	0
696449	695107	19565D	PARTICIPANT	\N	PRESENT	0
696450	695107	20072C	PARTICIPANT	\N	PRESENT	0
696451	695107	01058X	PARTICIPANT	\N	PRESENT	0
696452	695107	16685X	PARTICIPANT	\N	PRESENT	0
696453	695107	11054L	PARTICIPANT	\N	PRESENT	0
696454	695107	19669L	PARTICIPANT	\N	PRESENT	0
696455	695107	11066Q	PARTICIPANT	\N	PRESENT	0
696456	695107	08056B	PARTICIPANT	\N	PRESENT	0
696457	695107	12028B	PARTICIPANT	\N	PRESENT	0
696458	695107	19421M	PARTICIPANT	\N	PRESENT	0
696459	695107	14193X	PARTICIPANT	\N	PRESENT	0
696460	695107	19347U	PARTICIPANT	\N	PRESENT	0
696461	695107	07033P	PARTICIPANT	\N	PRESENT	0
696462	695107	97011G	PARTICIPANT	\N	PRESENT	0
696463	695107	08061X	PARTICIPANT	\N	PRESENT	0
696464	695107	08047A	PRESIDENT	0	PRESENT	0
696465	695107	20128B	PARTICIPANT	\N	PRESENT	0
696466	695107	14059S	PARTICIPANT	\N	PRESENT	0
696467	695107	14097Y	PARTICIPANT	\N	PRESENT	0
696468	695107	14133K	PARTICIPANT	\N	PRESENT	0
696469	695107	08069G	PARTICIPANT	\N	PRESENT	0
696470	695107	11041F	PARTICIPANT	\N	PRESENT	0
696471	695107	19319Q	PARTICIPANT	\N	PRESENT	0
696472	695107	20064C	PARTICIPANT	\N	PRESENT	0
696473	695107	98022P	PARTICIPANT	\N	PRESENT	0
696474	695107	14267Y	PARTICIPANT	\N	PRESENT	0
696475	695107	11064N	PARTICIPANT	\N	PRESENT	0
696476	695107	11083R	PARTICIPANT	\N	PRESENT	0
696477	695107	14255U	PARTICIPANT	\N	PRESENT	0
696478	695107	19443T	PARTICIPANT	\N	EXCUSE	0
696479	695107	04042C	PARTICIPANT	\N	EXCUSE	0
696553	695107	11080N	PARTICIPANT	\N	PRESENT	0
696554	695107	11115U	PARTICIPANT	\N	PRESENT	0
696555	695107	20042V	PARTICIPANT	\N	PRESENT	0
696556	695107	19721W	PARTICIPANT	\N	PRESENT	0
696558	694949	19651A	PARTICIPANT	\N	PRESENT	0
696576	694949	14109K	PARTICIPANT	\N	PRESENT	0
696577	693394	20046A	PARTICIPANT	\N	EXCUSE	0
696578	693394	17367Q	PARTICIPANT	\N	EXCUSE	0
696579	694876	14231L	PARTICIPANT	\N	PRESENT	0
696583	696275	95041E	PARTICIPANT	\N	PRESENT	0
696635	696631	19349W	PARTICIPANT	\N	PRESENT	0
696585	696275	19565D	PARTICIPANT	\N	PRESENT	0
696586	696275	20072C	PARTICIPANT	\N	PRESENT	0
696587	696275	11080N	PARTICIPANT	\N	PRESENT	0
696588	696275	01058X	PARTICIPANT	\N	PRESENT	0
696589	696275	16685X	PARTICIPANT	\N	PRESENT	0
696590	696275	11027H	PARTICIPANT	\N	PRESENT	0
696591	696275	11054L	PARTICIPANT	\N	PRESENT	0
696592	696275	19669L	PARTICIPANT	\N	PRESENT	0
696593	696275	11066Q	PARTICIPANT	\N	PRESENT	0
696594	696275	08056B	PARTICIPANT	\N	PRESENT	0
696595	696275	12028B	PARTICIPANT	\N	PRESENT	0
696596	696275	11115U	PARTICIPANT	\N	PRESENT	0
696597	696275	19421M	PARTICIPANT	\N	PRESENT	0
696598	696275	14193X	PARTICIPANT	\N	PRESENT	0
696599	696275	19347U	PARTICIPANT	\N	PRESENT	0
696600	696275	07033P	PARTICIPANT	\N	PRESENT	0
696601	696275	97011G	PARTICIPANT	\N	PRESENT	0
696602	696275	08061X	PARTICIPANT	\N	PRESENT	0
696603	696275	14249W	PARTICIPANT	\N	PRESENT	0
696604	696275	08047A	PRESIDENT	0	PRESENT	0
696605	696275	20128B	PARTICIPANT	\N	PRESENT	0
696606	696275	14059S	PARTICIPANT	\N	PRESENT	0
696607	696275	14097Y	PARTICIPANT	\N	PRESENT	0
696636	696631	19820Y	PARTICIPANT	\N	PRESENT	0
696609	696275	08069G	PARTICIPANT	\N	PRESENT	0
696610	696275	11041F	PARTICIPANT	\N	PRESENT	0
696611	696275	20042V	PARTICIPANT	\N	PRESENT	0
696612	696275	19721W	PARTICIPANT	\N	PRESENT	0
696613	696275	19319Q	PARTICIPANT	\N	PRESENT	0
696614	696275	20064C	PARTICIPANT	\N	PRESENT	0
696615	696275	98022P	PARTICIPANT	\N	PRESENT	0
696616	696275	14267Y	PARTICIPANT	\N	PRESENT	0
696617	696275	11064N	PARTICIPANT	\N	PRESENT	0
696618	696275	11083R	PARTICIPANT	\N	PRESENT	0
696619	696275	14255U	PARTICIPANT	\N	PRESENT	0
696620	696275	14105F	PARTICIPANT	\N	EXCUSE	0
696621	696275	19443T	PARTICIPANT	\N	EXCUSE	0
696622	696275	01062T	PARTICIPANT	\N	EXCUSE	0
696623	696275	19709B	PARTICIPANT	\N	EXCUSE	0
696624	696275	04042C	PARTICIPANT	\N	EXCUSE	0
696633	696631	14231L	PARTICIPANT	\N	PRESENT	0
696634	696631	14259Y	PARTICIPANT	\N	PRESENT	0
696637	696631	14229S	PARTICIPANT	\N	PRESENT	0
696638	696631	20044X	PARTICIPANT	\N	PRESENT	0
696639	696630	14231L	PARTICIPANT	\N	PRESENT	0
696640	696630	14259Y	PARTICIPANT	\N	PRESENT	0
696641	696630	19349W	PARTICIPANT	\N	PRESENT	0
696642	696630	19820Y	PARTICIPANT	\N	PRESENT	0
696643	696630	14229S	PARTICIPANT	\N	PRESENT	0
696644	696630	20044X	PARTICIPANT	\N	PRESENT	0
696645	696629	20024T	PARTICIPANT	\N	PRESENT	0
696646	696629	19954N	PARTICIPANT	\N	PRESENT	0
696647	696629	14255U	PARTICIPANT	\N	PRESENT	0
696648	696629	14026U	PARTICIPANT	\N	PRESENT	0
696649	696629	19553Y	PARTICIPANT	\N	PRESENT	0
696650	696629	11048N	PARTICIPANT	\N	PRESENT	0
696651	696629	19551W	PARTICIPANT	\N	PRESENT	0
696652	696629	19335Q	PARTICIPANT	\N	PRESENT	0
696653	696629	14331P	PARTICIPANT	\N	PRESENT	0
696654	696629	20122U	PARTICIPANT	\N	PRESENT	0
696655	696629	04045F	PARTICIPANT	\N	PRESENT	0
696656	695155	86034E	PARTICIPANT	\N	PRESENT	0
696657	695155	98022P	PARTICIPANT	\N	PRESENT	0
696658	695155	19593H	PARTICIPANT	\N	PRESENT	0
696659	695155	14073Q	PARTICIPANT	\N	PRESENT	0
696660	695155	20068G	PARTICIPANT	\N	PRESENT	0
696661	695155	14275Y	PARTICIPANT	\N	PRESENT	0
696662	695155	18083K	PARTICIPANT	\N	PRESENT	0
696663	695155	14211G	PARTICIPANT	\N	PRESENT	0
696664	695155	19681G	PARTICIPANT	\N	PRESENT	0
696665	695155	17229F	PARTICIPANT	\N	PRESENT	0
696666	695155	14225N	PARTICIPANT	\N	PRESENT	0
696667	695155	20094J	PARTICIPANT	\N	PRESENT	0
696668	695155	14223L	PARTICIPANT	\N	PRESENT	0
696669	695155	12041X	PARTICIPANT	\N	PRESENT	0
696670	695155	19565D	PARTICIPANT	\N	PRESENT	0
696671	695155	11054L	PARTICIPANT	\N	PRESENT	0
696672	695155	11083R	PARTICIPANT	\N	PRESENT	0
696673	695155	14195A	PARTICIPANT	\N	PRESENT	0
696674	695155	19563B	PARTICIPANT	\N	PRESENT	0
696675	695155	20052X	PARTICIPANT	\N	PRESENT	0
696676	695155	19707Y	PARTICIPANT	\N	PRESENT	0
696677	695155	19705W	PARTICIPANT	\N	PRESENT	0
696678	695155	14053L	PARTICIPANT	\N	PRESENT	0
696679	695155	11090Q	PARTICIPANT	\N	PRESENT	0
696680	695155	20074E	PARTICIPANT	\N	PRESENT	0
696681	695155	01048V	PARTICIPANT	\N	PRESENT	0
696682	695155	20038A	PARTICIPANT	\N	PRESENT	0
696683	695155	20980G	PARTICIPANT	\N	PRESENT	0
696684	695155	20180F	PARTICIPANT	\N	PRESENT	0
696685	695155	20020P	PARTICIPANT	\N	PRESENT	0
696686	695155	20090E	PARTICIPANT	\N	PRESENT	0
696687	695155	04070G	PARTICIPANT	\N	PRESENT	0
696688	695155	11074Q	PARTICIPANT	\N	PRESENT	0
696689	695155	19333N	PARTICIPANT	\N	PRESENT	0
696690	695155	19683J	PARTICIPANT	\N	PRESENT	0
696691	695155	14281W	PARTICIPANT	\N	PRESENT	0
696692	695155	11066Q	PARTICIPANT	\N	PRESENT	0
696693	695155	19649G	PARTICIPANT	\N	PRESENT	0
696694	695155	08012N	PARTICIPANT	\N	PRESENT	0
696695	695155	14253S	PARTICIPANT	\N	PRESENT	0
696696	695155	14033T	PARTICIPANT	\N	PRESENT	0
696697	695155	08047A	PARTICIPANT	\N	PRESENT	0
686956	686364	20022R	PARTICIPANT	\N	EXCUSE	0
686957	686364	14151M	PARTICIPANT	\N	EXCUSE	0
686958	686364	19729F	PARTICIPANT	\N	EXCUSE	0
687019	687018	19611R	PARTICIPANT	\N	PRESENT	0
687020	687018	19699S	PARTICIPANT	\N	PRESENT	0
687021	687018	19651A	PARTICIPANT	\N	PRESENT	0
687083	687018	19621T	PARTICIPANT	\N	PRESENT	0
690876	690872	11045K	PARTICIPANT	\N	PRESENT	0
690877	690872	17965H	PARTICIPANT	\N	PRESENT	0
690878	690872	19715Y	PARTICIPANT	\N	PRESENT	0
692488	692388	19709B	PARTICIPANT	\N	EXCUSE	0
692489	691842	11045K	PARTICIPANT	\N	PRESENT	0
692490	692401	11045K	PARTICIPANT	\N	PRESENT	0
692491	692401	17965H	PARTICIPANT	\N	PRESENT	1
692492	692402	11045K	PARTICIPANT	\N	PRESENT	0
692493	692403	11045K	PARTICIPANT	\N	PRESENT	0
692494	692403	17965H	PARTICIPANT	\N	PRESENT	0
692495	692409	11045K	PARTICIPANT	\N	PRESENT	0
694903	692316	14059S	PARTICIPANT	\N	PRESENT	0
698946	698945	19954N	PARTICIPANT	\N	PRESENT	0
698948	698947	19954N	PARTICIPANT	\N	PRESENT	0
701626	701624	14231L	PARTICIPANT	\N	PRESENT	0
701627	701624	14259Y	PARTICIPANT	\N	PRESENT	0
701628	701624	20044X	PARTICIPANT	\N	PRESENT	0
701629	701624	19820Y	PARTICIPANT	\N	PRESENT	0
704308	704245	01025N	PARTICIPANT	\N	EXCUSE	0
704314	704245	20172F	PARTICIPANT	\N	EXCUSE	0
706601	704340	20248J	PARTICIPANT	\N	EXCUSE	0
708459	708051	14249W	PARTICIPANT	\N	PRESENT	0
708460	708051	20142Y	PARTICIPANT	\N	PRESENT	0
708461	708051	19725B	PARTICIPANT	\N	PRESENT	0
708462	708051	19703U	PARTICIPANT	\N	PRESENT	0
708463	708051	08061X	PARTICIPANT	\N	PRESENT	0
708464	708051	08010L	PARTICIPANT	\N	PRESENT	0
708465	708051	14217N	PARTICIPANT	\N	PRESENT	0
708466	708051	08069G	PARTICIPANT	\N	PRESENT	0
708467	708051	19421M	PARTICIPANT	\N	PRESENT	0
708468	708051	19673G	PARTICIPANT	\N	PRESENT	0
708469	708051	20134Y	PARTICIPANT	\N	PRESENT	0
708470	708051	14205J	PARTICIPANT	\N	PRESENT	0
708471	708051	19415P	PARTICIPANT	\N	PRESENT	0
708477	708051	19295A	PARTICIPANT	\N	PRESENT	0
708474	708051	19643A	PARTICIPANT	\N	PRESENT	0
708475	708051	14211G	PARTICIPANT	\N	PRESENT	0
708476	708051	19369B	PARTICIPANT	\N	PRESENT	0
708478	708051	14259Y	PARTICIPANT	\N	PRESENT	0
708479	708051	14255U	PARTICIPANT	\N	PRESENT	0
708480	708051	20136B	PARTICIPANT	\N	PRESENT	0
708481	708051	17367Q	PARTICIPANT	\N	PRESENT	0
708482	708051	19699S	PARTICIPANT	\N	PRESENT	0
708483	708051	11054L	PARTICIPANT	\N	PRESENT	0
708484	708051	14257W	PARTICIPANT	\N	PRESENT	0
708485	708051	20092G	PARTICIPANT	\N	PRESENT	0
708486	708051	04057K	PARTICIPANT	\N	PRESENT	0
708487	708051	01024M	PARTICIPANT	\N	PRESENT	0
708488	708051	20026V	PARTICIPANT	\N	PRESENT	0
708489	708051	01028R	PARTICIPANT	\N	PRESENT	0
708490	708051	04047H	PARTICIPANT	\N	PRESENT	0
708491	708051	14147R	PARTICIPANT	\N	PRESENT	0
708492	708051	17965H	PARTICIPANT	\N	PRESENT	0
708493	708051	19399H	PARTICIPANT	\N	PRESENT	0
708494	708051	14267Y	PARTICIPANT	\N	PRESENT	0
708495	708051	20018V	PARTICIPANT	\N	PRESENT	0
708496	708051	20052X	PARTICIPANT	\N	PRESENT	0
708497	708051	20024T	PARTICIPANT	\N	PRESENT	0
708498	708051	20286Q	PARTICIPANT	\N	PRESENT	0
708499	708051	20266L	PARTICIPANT	\N	PRESENT	0
708500	708051	14069U	PARTICIPANT	\N	PRESENT	0
708501	708051	01057W	PARTICIPANT	\N	PRESENT	0
708610	708052	11045K	PARTICIPANT	\N	PRESENT	0
708611	708052	14229S	PARTICIPANT	\N	PRESENT	0
708612	708052	11054L	PARTICIPANT	\N	PRESENT	0
708613	708052	20914V	PARTICIPANT	\N	PRESENT	0
708614	708052	20100N	PARTICIPANT	\N	PRESENT	0
708615	708052	20092G	PARTICIPANT	\N	PRESENT	0
708616	708052	12041X	PARTICIPANT	\N	PRESENT	0
708617	708052	19695N	PARTICIPANT	\N	PRESENT	0
708618	708052	19758L	PARTICIPANT	\N	PRESENT	0
708619	708052	19659J	PARTICIPANT	\N	PRESENT	0
708620	708052	19387D	PARTICIPANT	\N	PRESENT	0
708621	708052	19629C	PARTICIPANT	\N	PRESENT	0
708622	708052	14107H	PARTICIPANT	\N	PRESENT	0
708623	708052	19798U	PARTICIPANT	\N	PRESENT	0
708624	708052	19413M	PARTICIPANT	\N	PRESENT	0
708625	708052	19553Y	PARTICIPANT	\N	PRESENT	0
708626	708052	08045X	PARTICIPANT	\N	PRESENT	0
708627	708052	19525U	PARTICIPANT	\N	PRESENT	0
708628	708052	14069U	PARTICIPANT	\N	PRESENT	0
708629	708052	14038Y	PARTICIPANT	\N	PRESENT	0
708630	708052	14151M	PARTICIPANT	\N	PRESENT	0
708631	708052	18083K	PARTICIPANT	\N	PRESENT	0
708632	708052	19421M	PARTICIPANT	\N	PRESENT	0
708633	708052	19611R	PARTICIPANT	\N	PRESENT	0
708634	708052	11041F	PARTICIPANT	\N	PRESENT	0
708635	708052	20024T	PARTICIPANT	\N	PRESENT	0
708636	708052	08028W	PARTICIPANT	\N	PRESENT	0
708637	708052	14223L	PARTICIPANT	\N	PRESENT	0
708638	708052	19399H	PARTICIPANT	\N	PRESENT	0
708639	708052	20072C	PARTICIPANT	\N	PRESENT	0
708640	708052	19703U	PARTICIPANT	\N	PRESENT	0
708641	708052	08060W	PARTICIPANT	\N	PRESENT	0
708642	708052	99004R	PARTICIPANT	\N	PRESENT	0
708643	708052	20130U	PARTICIPANT	\N	PRESENT	0
708644	708052	20084G	PARTICIPANT	\N	PRESENT	0
708645	708052	19527W	PARTICIPANT	\N	PRESENT	0
708646	708052	11027H	PARTICIPANT	\N	PRESENT	0
708647	708052	12028B	PARTICIPANT	\N	PRESENT	0
708648	708052	11040E	PARTICIPANT	\N	PRESENT	0
708649	708052	11056N	PARTICIPANT	\N	PRESENT	0
708650	708052	11066Q	PARTICIPANT	\N	PRESENT	0
708651	708052	20102Q	PARTICIPANT	\N	PRESENT	0
708652	708052	14281W	PARTICIPANT	\N	PRESENT	0
708653	708052	18193Q	PARTICIPANT	\N	PRESENT	0
708654	708052	20080C	PARTICIPANT	\N	PRESENT	0
708655	708052	12016W	PARTICIPANT	\N	PRESENT	0
708656	708052	20046A	PARTICIPANT	\N	PRESENT	0
708657	708052	20018V	PARTICIPANT	\N	PRESENT	0
708658	708052	20028X	PARTICIPANT	\N	PRESENT	0
708659	708052	19503N	PARTICIPANT	\N	PRESENT	0
708660	708052	20180F	PARTICIPANT	\N	PRESENT	0
708661	708052	20026V	PARTICIPANT	\N	PRESENT	0
708662	708052	19347U	PARTICIPANT	\N	PRESENT	0
708663	708052	14211G	PARTICIPANT	\N	PRESENT	0
708664	708052	20096L	PARTICIPANT	\N	PRESENT	0
708665	708052	20140W	PARTICIPANT	\N	PRESENT	0
708666	708052	20056C	PARTICIPANT	\N	PRESENT	0
708667	708052	19866P	PARTICIPANT	\N	PRESENT	0
708668	708052	14207L	PARTICIPANT	\N	PRESENT	0
708669	708052	19719D	PARTICIPANT	\N	PRESENT	0
708670	708052	20040T	PARTICIPANT	\N	PRESENT	0
708671	708052	08015R	PARTICIPANT	\N	PRESENT	0
708672	708052	20144B	PARTICIPANT	\N	PRESENT	0
708673	708052	19631V	PARTICIPANT	\N	PRESENT	0
708674	708052	14071N	PARTICIPANT	\N	PRESENT	0
708675	708052	04092N	PARTICIPANT	\N	PRESENT	0
708676	708052	04047H	PARTICIPANT	\N	PRESENT	0
708677	708052	14030Q	PARTICIPANT	\N	PRESENT	0
708678	708052	20054A	PARTICIPANT	\N	PRESENT	0
708679	708052	20298U	PARTICIPANT	\N	PRESENT	0
708680	708052	10015M	PARTICIPANT	\N	PRESENT	0
708681	708052	14189C	PARTICIPANT	\N	PRESENT	0
708682	708052	05008E	PARTICIPANT	\N	PRESENT	0
708683	708052	19415P	PARTICIPANT	\N	PRESENT	0
708684	708052	14327T	PARTICIPANT	\N	PRESENT	0
708685	708052	14173T	PARTICIPANT	\N	PRESENT	0
708686	708052	19569H	PARTICIPANT	\N	PRESENT	0
708687	708052	11067R	PARTICIPANT	\N	PRESENT	0
708688	708052	11104D	PARTICIPANT	\N	PRESENT	0
708689	708052	20126Y	PARTICIPANT	\N	PRESENT	0
708690	708052	19531S	PARTICIPANT	\N	PRESENT	0
708691	708052	19715Y	PARTICIPANT	\N	PRESENT	0
708692	708052	01024M	PARTICIPANT	\N	PRESENT	0
708693	708052	17779H	PARTICIPANT	\N	PRESENT	0
708694	708052	17965H	PARTICIPANT	\N	PRESENT	0
708695	708052	19649G	PARTICIPANT	\N	PRESENT	0
708696	708052	20266L	PARTICIPANT	\N	PRESENT	0
708697	708052	19489J	PARTICIPANT	\N	PRESENT	0
708698	708052	20114U	PARTICIPANT	\N	PRESENT	0
708699	708052	20142Y	PARTICIPANT	\N	PRESENT	0
708700	708052	19545Y	PARTICIPANT	\N	PRESENT	0
708701	708052	08061X	PARTICIPANT	\N	PRESENT	0
685369	683642	20144B	PARTICIPANT	\N	PRESENT	0
685370	683642	19695N	PARTICIPANT	\N	PRESENT	0
685371	683642	11090Q	PRESIDENT	0	PRESENT	0
685372	683642	14033T	PARTICIPANT	\N	PRESENT	0
685373	683642	01025N	PARTICIPANT	\N	PRESENT	0
685374	683642	20054A	PARTICIPANT	\N	PRESENT	0
685375	683642	14205J	PARTICIPANT	\N	PRESENT	0
685376	683642	20060X	PARTICIPANT	\N	PRESENT	0
685377	683642	20062A	PARTICIPANT	\N	PRESENT	0
685378	683642	19507S	PARTICIPANT	\N	PRESENT	0
685379	683642	20286Q	PARTICIPANT	\N	PRESENT	0
685380	683642	20298U	PARTICIPANT	\N	PRESENT	0
685381	683642	14207L	PARTICIPANT	\N	PRESENT	0
685382	683642	19747H	PARTICIPANT	\N	PRESENT	0
685383	683642	14257W	PARTICIPANT	\N	PRESENT	0
687401	687400	19621T	PARTICIPANT	\N	PRESENT	0
687402	687400	11027H	PARTICIPANT	\N	PRESENT	0
687403	687400	14026U	PARTICIPANT	\N	PRESENT	0
687404	687400	20128B	PARTICIPANT	\N	PRESENT	0
687405	687400	20056C	PARTICIPANT	\N	PRESENT	0
687406	687400	20052X	PARTICIPANT	\N	PRESENT	0
687407	687400	14147R	PARTICIPANT	\N	PRESENT	0
687408	687400	95063L	PARTICIPANT	\N	PRESENT	0
687409	687400	19585H	PARTICIPANT	\N	PRESENT	0
687527	686707	14133K	PARTICIPANT	\N	PRESENT	0
687528	686707	11101A	PARTICIPANT	\N	EXCUSE	0
687529	686707	19701S	PARTICIPANT	\N	PRESENT	0
687530	686707	08018U	PARTICIPANT	\N	EXCUSE	0
687531	686707	04035D	PARTICIPANT	\N	PRESENT	0
687532	686707	19333N	PARTICIPANT	\N	EXCUSE	0
687533	686707	14097Y	PARTICIPANT	\N	EXCUSE	0
687534	686707	14073Q	PARTICIPANT	\N	EXCUSE	0
687535	686707	19711U	PARTICIPANT	\N	EXCUSE	0
687536	686707	19441R	PARTICIPANT	\N	EXCUSE	0
687537	686707	12016W	PARTICIPANT	\N	EXCUSE	0
687538	686707	04070G	PARTICIPANT	\N	EXCUSE	0
687539	686707	14169X	PARTICIPANT	\N	EXCUSE	0
687540	686707	19593H	PARTICIPANT	\N	EXCUSE	0
687541	686707	04045F	PARTICIPANT	\N	PRESENT	0
687605	686707	14331P	PRESIDENT	0	PRESENT	0
687606	686707	20098N	PARTICIPANT	\N	PRESENT	0
687611	686707	14001X	PARTICIPANT	\N	PRESENT	0
687613	686707	20100N	PARTICIPANT	\N	PRESENT	0
687616	686707	11026G	PARTICIPANT	\N	PRESENT	0
687619	686707	19954N	PARTICIPANT	\N	PRESENT	0
687620	686707	04047H	PARTICIPANT	\N	PRESENT	0
687621	686707	14215L	PARTICIPANT	\N	PRESENT	0
687623	686707	14151M	PARTICIPANT	\N	PRESENT	0
687627	686707	14357A	PARTICIPANT	\N	PRESENT	0
687628	686707	19725B	PARTICIPANT	\N	PRESENT	0
687630	686707	14147R	PARTICIPANT	\N	PRESENT	0
687631	686707	19649G	PARTICIPANT	\N	PRESENT	0
687634	686707	08034U	PARTICIPANT	\N	PRESENT	0
687635	686707	14033T	PARTICIPANT	\N	PRESENT	0
687639	686707	14026U	PARTICIPANT	\N	PRESENT	0
687640	686707	10015M	PARTICIPANT	\N	PRESENT	0
687642	686707	19673G	PARTICIPANT	\N	PRESENT	0
687644	686707	14089Y	PARTICIPANT	\N	PRESENT	0
687646	686707	20022R	PARTICIPANT	\N	PRESENT	0
687647	686707	14189C	PARTICIPANT	\N	EXCUSE	0
687650	686707	01028R	PARTICIPANT	\N	PRESENT	0
687651	686707	19543W	PARTICIPANT	\N	PRESENT	0
687654	686707	20128B	PARTICIPANT	\N	PRESENT	0
687656	686707	20286Q	PARTICIPANT	\N	PRESENT	0
687658	686707	20104S	PARTICIPANT	\N	PRESENT	0
687661	686707	14179A	PARTICIPANT	\N	PRESENT	0
687680	686707	19507S	PARTICIPANT	\N	PRESENT	0
690766	690765	14231L	PARTICIPANT	\N	PRESENT	0
690767	690765	20110Q	PARTICIPANT	\N	PRESENT	0
690768	690765	19349W	PARTICIPANT	\N	PRESENT	0
690769	690765	11048N	PARTICIPANT	\N	PRESENT	0
690771	690770	14231L	PARTICIPANT	\N	PRESENT	0
690772	690770	14259Y	PARTICIPANT	\N	PRESENT	0
690773	690770	20110Q	PARTICIPANT	\N	PRESENT	0
690774	690770	04047H	PARTICIPANT	\N	PRESENT	0
690775	690770	14179A	PARTICIPANT	\N	PRESENT	0
690776	690770	11048N	PARTICIPANT	\N	PRESENT	0
690777	690770	19349W	PARTICIPANT	\N	PRESENT	0
690779	690778	14231L	PARTICIPANT	\N	PRESENT	0
690780	690778	14259Y	PARTICIPANT	\N	PRESENT	0
690781	690778	14179A	PARTICIPANT	\N	PRESENT	0
690782	690778	04047H	PARTICIPANT	\N	PRESENT	0
690783	690778	11048N	PARTICIPANT	\N	PRESENT	0
692464	692463	20112S	PARTICIPANT	\N	PRESENT	1
692465	692463	19735D	PARTICIPANT	\N	PRESENT	1
692466	692463	19643A	PARTICIPANT	\N	PRESENT	1
692468	692467	20112S	PARTICIPANT	\N	PRESENT	1
692469	692467	19643A	PARTICIPANT	\N	PRESENT	1
692470	692467	19735D	PARTICIPANT	\N	PRESENT	1
692471	692467	14229S	PARTICIPANT	\N	PRESENT	1
693355	692427	20090E	PARTICIPANT	\N	PRESENT	0
693356	692427	14173T	PARTICIPANT	\N	PRESENT	0
693357	692427	19747H	PARTICIPANT	\N	PRESENT	0
693358	692427	20136B	PARTICIPANT	\N	PRESENT	0
693359	692427	20084G	PARTICIPANT	\N	PRESENT	0
693360	692427	14217N	PARTICIPANT	\N	PRESENT	0
693361	692427	19593H	PARTICIPANT	\N	PRESENT	0
693362	692427	14038Y	PARTICIPANT	\N	PRESENT	0
693363	692427	19691J	PARTICIPANT	\N	PRESENT	0
693364	692427	20142Y	PARTICIPANT	\N	PRESENT	0
693365	692427	17023S	PARTICIPANT	\N	PRESENT	0
693366	692427	14089Y	PARTICIPANT	\N	PRESENT	0
693367	692427	19760E	PARTICIPANT	\N	PRESENT	0
693368	692427	19643A	PARTICIPANT	\N	PRESENT	0
693369	692427	08061X	PARTICIPANT	\N	PRESENT	0
693370	692427	20088L	PARTICIPANT	\N	PRESENT	0
693371	692427	11067R	PARTICIPANT	\N	PRESENT	0
693372	692427	19347U	PARTICIPANT	\N	PRESENT	0
693373	692427	19527W	PARTICIPANT	\N	PRESENT	0
693374	692427	19798U	PARTICIPANT	\N	PRESENT	0
693375	692427	10006L	PARTICIPANT	\N	PRESENT	0
693381	692427	20018V	PARTICIPANT	\N	PRESENT	0
693382	692427	19647E	PARTICIPANT	\N	PRESENT	0
693383	692427	19758L	PARTICIPANT	\N	PRESENT	0
693384	692427	14071N	PARTICIPANT	\N	PRESENT	0
693385	692427	20052X	PARTICIPANT	\N	PRESENT	0
693386	692427	01062T	PARTICIPANT	\N	PRESENT	0
693387	692427	17779H	PARTICIPANT	\N	PRESENT	0
693396	692427	19673G	PARTICIPANT	\N	PRESENT	0
693389	692427	20104S	PARTICIPANT	\N	PRESENT	0
693390	692427	20048C	PARTICIPANT	\N	PRESENT	0
693391	692427	20122U	PARTICIPANT	\N	PRESENT	0
693392	692427	14169X	PARTICIPANT	\N	PRESENT	0
693395	692427	20058E	PARTICIPANT	\N	PRESENT	0
693397	692427	19715Y	PARTICIPANT	\N	PRESENT	0
693398	692427	20082E	PARTICIPANT	\N	PRESENT	0
693399	692427	20264J	PARTICIPANT	\N	PRESENT	0
693400	692427	01057W	PARTICIPANT	\N	PRESENT	0
693401	692427	14133K	PARTICIPANT	\N	PRESENT	0
693402	692427	04045F	PARTICIPANT	\N	PRESENT	0
693403	692427	11012A	PARTICIPANT	\N	PRESENT	0
693404	692427	19545Y	PARTICIPANT	\N	PRESENT	0
693450	692428	01043Q	PARTICIPANT	\N	PRESENT	0
693451	692428	14151M	PARTICIPANT	\N	PRESENT	0
693452	692428	19649G	PARTICIPANT	\N	PRESENT	0
693453	692428	20082E	PARTICIPANT	\N	PRESENT	0
693454	692428	19673G	PARTICIPANT	\N	PRESENT	0
693455	692428	19531S	PARTICIPANT	\N	PRESENT	0
693456	692428	20076G	PARTICIPANT	\N	PRESENT	0
693457	692428	19798U	PARTICIPANT	\N	PRESENT	0
693458	692428	20092G	PARTICIPANT	\N	PRESENT	0
693459	692428	14191V	PARTICIPANT	\N	PRESENT	0
693460	692428	20110Q	PARTICIPANT	\N	PRESENT	0
693461	692428	20134Y	PARTICIPANT	\N	PRESENT	0
693462	692428	14229S	PARTICIPANT	\N	PRESENT	0
693463	692428	20034V	PARTICIPANT	\N	PRESENT	0
693464	692428	20264J	PARTICIPANT	\N	PRESENT	0
693465	692428	20980G	PARTICIPANT	\N	PRESENT	0
693466	692428	19719D	PARTICIPANT	\N	PRESENT	0
693467	692428	14195A	PARTICIPANT	\N	PRESENT	0
693468	692428	14275Y	PARTICIPANT	\N	PRESENT	0
693469	692428	14147R	PARTICIPANT	\N	PRESENT	0
693470	692428	19593H	PARTICIPANT	\N	PRESENT	0
693471	692428	14073Q	PARTICIPANT	\N	PRESENT	0
693472	692428	20112S	PARTICIPANT	\N	PRESENT	0
693473	692428	19611R	PARTICIPANT	\N	PRESENT	0
693474	692428	20100N	PARTICIPANT	\N	PRESENT	0
693475	692428	19543W	PARTICIPANT	\N	PRESENT	0
693476	692428	19631V	PARTICIPANT	\N	PRESENT	0
693477	692428	17589D	PARTICIPANT	\N	PRESENT	0
693478	692428	14021P	PARTICIPANT	\N	PRESENT	0
685043	683057	14001X	PARTICIPANT	\N	PRESENT	0
685044	683057	14215L	PARTICIPANT	\N	PRESENT	0
685045	683057	19675J	PARTICIPANT	\N	PRESENT	0
685046	683057	14231L	PARTICIPANT	\N	PRESENT	0
685047	683057	11056N	PARTICIPANT	\N	PRESENT	0
685048	683057	19729F	PARTICIPANT	\N	PRESENT	0
685049	683057	04008A	PARTICIPANT	\N	PRESENT	0
685051	683338	14327T	PARTICIPANT	\N	PRESENT	0
685052	683338	14331P	PARTICIPANT	\N	PRESENT	0
685053	683338	19479G	PARTICIPANT	\N	PRESENT	0
685054	683338	19531S	PARTICIPANT	\N	PRESENT	0
685055	683338	01057W	PARTICIPANT	\N	PRESENT	0
685056	683338	11074Q	PARTICIPANT	\N	PRESENT	0
685057	683338	19667J	PARTICIPANT	\N	PRESENT	0
685058	683338	14225N	PRESIDENT	0	PRESENT	0
685059	683338	20252E	PARTICIPANT	\N	PRESENT	0
685060	683338	20070A	PARTICIPANT	\N	PRESENT	0
685061	683338	19349W	PARTICIPANT	\N	PRESENT	0
685062	683338	14121F	PARTICIPANT	\N	PRESENT	0
685063	683338	99004R	PARTICIPANT	\N	PRESENT	0
685064	683057	14111D	PARTICIPANT	\N	PRESENT	0
685065	683057	20074E	PARTICIPANT	\N	PRESENT	0
685066	683057	19301E	PARTICIPANT	\N	PRESENT	0
685067	683057	04047H	PRESIDENT	0	PRESENT	0
685068	683057	11033F	PARTICIPANT	\N	PRESENT	0
685069	683057	14089Y	PARTICIPANT	\N	PRESENT	0
685070	683057	19954N	PARTICIPANT	\N	PRESENT	0
685071	683057	20110Q	PARTICIPANT	\N	PRESENT	0
685072	683057	14147R	PARTICIPANT	\N	PRESENT	0
685073	683057	14069U	PARTICIPANT	\N	PRESENT	0
685074	683057	08018U	PARTICIPANT	\N	PRESENT	0
685075	683338	11048N	PARTICIPANT	\N	PRESENT	0
685076	683338	20036X	PARTICIPANT	\N	PRESENT	0
685077	683338	20044X	PARTICIPANT	\N	PRESENT	0
685078	683338	19671E	PARTICIPANT	\N	PRESENT	0
685079	683338	14253S	PARTICIPANT	\N	PRESENT	0
685080	683338	20080C	PARTICIPANT	\N	PRESENT	0
685081	683338	11040E	PARTICIPANT	\N	PRESENT	0
685082	683338	20116W	PARTICIPANT	\N	PRESENT	0
685083	683338	20126Y	PARTICIPANT	\N	PRESENT	0
685084	683338	19741B	PARTICIPANT	\N	PRESENT	0
685085	683057	19673G	PARTICIPANT	\N	PRESENT	0
685086	683057	01028R	PARTICIPANT	\N	PRESENT	0
685087	683057	19447X	PARTICIPANT	\N	PRESENT	0
685088	683057	05008E	PARTICIPANT	\N	PRESENT	0
685089	683057	19489J	PARTICIPANT	\N	PRESENT	0
685090	683057	20108W	PARTICIPANT	\N	PRESENT	0
685091	683057	14107H	PARTICIPANT	\N	PRESENT	0
685092	683057	14259Y	PARTICIPANT	\N	PRESENT	0
685093	683057	11072N	PARTICIPANT	\N	PRESENT	0
685094	683057	14053L	PARTICIPANT	\N	PRESENT	0
685095	683057	10015M	PARTICIPANT	\N	PRESENT	0
685096	683057	19725B	PARTICIPANT	\N	PRESENT	0
685097	683057	95063L	PARTICIPANT	\N	PRESENT	0
685098	683057	19629C	PARTICIPANT	\N	PRESENT	0
685099	683057	11085T	PARTICIPANT	\N	PRESENT	0
685100	683057	14021P	PARTICIPANT	\N	PRESENT	0
685274	680943	19685L	PARTICIPANT	\N	EXCUSE	0
685275	680943	20038A	PARTICIPANT	\N	EXCUSE	0
685276	681308	19333N	PARTICIPANT	\N	PRESENT	0
685277	681308	20032T	PARTICIPANT	\N	PRESENT	0
685278	681308	20136B	PARTICIPANT	\N	EXCUSE	0
685279	681308	19685L	PARTICIPANT	\N	EXCUSE	0
685280	683338	08010L	PARTICIPANT	\N	PRESENT	0
685281	683057	17737W	PARTICIPANT	\N	PRESENT	0
685286	683057	14179A	PARTICIPANT	\N	PRESENT	0
685288	683228	19719D	PARTICIPANT	\N	PRESENT	0
685430	682962	19565D	PARTICIPANT	\N	PRESENT	0
685431	682962	20072C	PARTICIPANT	\N	PRESENT	0
685432	682962	01058X	PARTICIPANT	\N	PRESENT	0
685433	682962	11027H	PARTICIPANT	\N	PRESENT	0
685434	682962	16685X	PARTICIPANT	\N	PRESENT	0
685435	682962	11066Q	PARTICIPANT	\N	PRESENT	0
685436	682962	08056B	PARTICIPANT	\N	PRESENT	0
685437	682962	19421M	PARTICIPANT	\N	PRESENT	0
685438	682962	14193X	PARTICIPANT	\N	PRESENT	0
685439	682962	19347U	PARTICIPANT	\N	PRESENT	0
685440	682962	08061X	PARTICIPANT	\N	PRESENT	0
685441	682962	08047A	PARTICIPANT	\N	PRESENT	0
685442	682962	20128B	PARTICIPANT	\N	PRESENT	0
685443	682962	14097Y	PARTICIPANT	\N	PRESENT	0
685444	682962	14133K	PRESIDENT	0	PRESENT	0
685445	682962	01062T	PARTICIPANT	\N	PRESENT	0
685446	682962	08069G	PARTICIPANT	\N	PRESENT	0
685447	682962	11041F	PARTICIPANT	\N	PRESENT	0
685448	682962	20042V	PARTICIPANT	\N	PRESENT	0
685449	682962	01024M	PARTICIPANT	\N	PRESENT	0
685450	682962	14191V	PARTICIPANT	\N	PRESENT	0
685451	682962	14105F	PARTICIPANT	\N	PRESENT	0
685452	682962	20064C	PARTICIPANT	\N	PRESENT	0
685453	682962	98022P	PARTICIPANT	\N	PRESENT	0
685454	682962	14267Y	PARTICIPANT	\N	PRESENT	0
685455	682962	11064N	PARTICIPANT	\N	PRESENT	0
685456	682962	11083R	PARTICIPANT	\N	PRESENT	0
685457	682962	14255U	PARTICIPANT	\N	PRESENT	0
685458	682962	04035D	PARTICIPANT	\N	EXCUSE	0
685459	682962	04042C	PARTICIPANT	\N	EXCUSE	0
685460	682962	07033P	PARTICIPANT	\N	EXCUSE	0
685461	682962	17023S	PARTICIPANT	\N	EXCUSE	0
685464	683228	14331P	PARTICIPANT	\N	PRESENT	0
685465	683228	08028W	PARTICIPANT	\N	PRESENT	0
685466	683228	20034V	PARTICIPANT	\N	PRESENT	0
685467	683228	19581D	PARTICIPANT	\N	PRESENT	0
685468	683228	14191V	PARTICIPANT	\N	PRESENT	0
685469	683228	98022P	PARTICIPANT	\N	PRESENT	0
685470	683228	20068G	PARTICIPANT	\N	PRESENT	0
685471	683228	19701S	PARTICIPANT	\N	PRESENT	0
685472	683228	19683J	PARTICIPANT	\N	PRESENT	0
685473	683228	14097Y	PARTICIPANT	\N	PRESENT	0
685474	683228	20116W	PARTICIPANT	\N	PRESENT	0
685475	683228	20088L	PARTICIPANT	\N	PRESENT	0
685476	683228	14107H	PARTICIPANT	\N	PRESENT	0
685477	683228	20084G	PARTICIPANT	\N	PRESENT	0
685478	683228	19697Q	PARTICIPANT	\N	PRESENT	0
685479	683228	19349W	PARTICIPANT	\N	PRESENT	0
685480	683228	19565D	PARTICIPANT	\N	PRESENT	0
685481	683228	17779H	PARTICIPANT	\N	PRESENT	0
685482	683228	19593H	PARTICIPANT	\N	PRESENT	0
685483	683228	20102Q	PARTICIPANT	\N	PRESENT	0
685484	683228	20046A	PARTICIPANT	\N	PRESENT	0
685485	683228	19760E	PARTICIPANT	\N	PRESENT	0
685486	683228	19711U	PARTICIPANT	\N	PRESENT	0
685487	683228	04008A	PARTICIPANT	\N	PRESENT	0
685488	683228	19693L	PARTICIPANT	\N	PRESENT	0
685489	683228	19575F	PARTICIPANT	\N	PRESENT	0
685490	683228	01058X	PARTICIPANT	\N	PRESENT	0
685491	683228	99004R	PARTICIPANT	\N	PRESENT	0
685492	683228	19679N	PARTICIPANT	\N	PRESENT	0
685493	683228	20076G	PARTICIPANT	\N	PRESENT	0
685494	683228	20058E	PARTICIPANT	\N	PRESENT	0
685495	683228	20086J	PARTICIPANT	\N	PRESENT	0
685496	683228	20044X	PARTICIPANT	\N	PRESENT	0
685497	683228	19573D	PARTICIPANT	\N	PRESENT	0
685498	683228	19467C	PARTICIPANT	\N	PRESENT	0
685499	683228	20038A	PARTICIPANT	\N	PRESENT	0
685500	683228	19447X	PARTICIPANT	\N	PRESENT	0
685501	683228	18083K	PARTICIPANT	\N	PRESENT	0
685502	683228	19673G	PARTICIPANT	\N	PRESENT	0
685503	683228	20026V	PARTICIPANT	\N	PRESENT	0
685504	683228	20180F	PARTICIPANT	\N	PRESENT	0
685505	683228	14033T	PARTICIPANT	\N	PRESENT	0
685506	683228	20098N	PARTICIPANT	\N	PRESENT	0
685507	683228	14259Y	PARTICIPANT	\N	PRESENT	0
685508	683228	19515S	PARTICIPANT	\N	PRESENT	0
685509	683228	14031R	PARTICIPANT	\N	PRESENT	0
685510	683228	92040Q	PARTICIPANT	\N	PRESENT	0
685511	683228	01057W	PARTICIPANT	\N	PRESENT	0
685512	683228	14253S	PARTICIPANT	\N	PRESENT	0
685513	683228	11080N	PARTICIPANT	\N	PRESENT	0
685514	683228	11115U	PARTICIPANT	\N	PRESENT	0
685515	683228	19643A	PARTICIPANT	\N	PRESENT	0
685516	683228	14223L	PARTICIPANT	\N	PRESENT	0
685517	683228	11043H	PARTICIPANT	\N	PRESENT	0
685518	683228	01048V	PARTICIPANT	\N	PRESENT	0
685519	683228	14169X	PARTICIPANT	\N	PRESENT	0
685520	683228	19729F	PARTICIPANT	\N	PRESENT	0
685521	683228	08015R	PARTICIPANT	\N	PRESENT	0
685522	683228	19657G	PARTICIPANT	\N	PRESENT	0
685523	683228	07029T	PARTICIPANT	\N	PRESENT	0
685524	683228	20024T	PARTICIPANT	\N	PRESENT	0
685525	683228	12041X	PARTICIPANT	\N	PRESENT	0
696698	695155	11010L	PARTICIPANT	\N	PRESENT	0
697510	695156	95041E	PARTICIPANT	\N	PRESENT	0
697511	695156	19782L	PARTICIPANT	\N	PRESENT	0
697512	695156	19511N	PARTICIPANT	\N	PRESENT	0
697513	695156	17637T	PARTICIPANT	\N	PRESENT	0
697514	695156	19553Y	PARTICIPANT	\N	PRESENT	0
697515	695156	19703U	PARTICIPANT	\N	PRESENT	0
697516	695156	20058E	PARTICIPANT	\N	PRESENT	0
697517	695156	19768N	PARTICIPANT	\N	PRESENT	0
697518	695156	14275Y	PARTICIPANT	\N	PRESENT	0
697519	695156	08011M	PARTICIPANT	\N	PRESENT	0
697520	695156	14211G	PARTICIPANT	\N	PRESENT	0
697521	695156	17589D	PARTICIPANT	\N	PRESENT	0
697522	695156	08009T	PARTICIPANT	\N	PRESENT	0
697523	695156	11045K	PARTICIPANT	\N	PRESENT	0
697524	695156	19669L	PARTICIPANT	\N	PRESENT	0
697525	695156	14229S	PARTICIPANT	\N	PRESENT	0
697526	695156	11070L	PARTICIPANT	\N	PRESENT	0
697909	697897	14237S	PARTICIPANT	\N	PRESENT	0
697911	697897	20032T	PARTICIPANT	\N	PRESENT	0
697912	697897	19575F	PARTICIPANT	\N	PRESENT	0
697915	697897	19383Y	PARTICIPANT	\N	PRESENT	0
697916	697897	20066E	PARTICIPANT	\N	PRESENT	0
697917	697897	19768N	PARTICIPANT	\N	PRESENT	0
697925	697897	19503N	PARTICIPANT	\N	PRESENT	0
697927	697897	14107H	PARTICIPANT	\N	PRESENT	0
697947	697897	19629C	PARTICIPANT	\N	PRESENT	0
697955	697954	19467C	PARTICIPANT	\N	PRESENT	0
697956	697954	19575F	PARTICIPANT	\N	PRESENT	0
697957	697954	20032T	PARTICIPANT	\N	PRESENT	0
697958	697954	19383Y	PARTICIPANT	\N	PRESENT	0
697959	697954	20090E	PARTICIPANT	\N	PRESENT	0
697960	697954	20038A	PARTICIPANT	\N	PRESENT	0
697961	697954	20120S	PARTICIPANT	\N	PRESENT	0
697962	697954	20066E	PARTICIPANT	\N	PRESENT	0
697963	697954	05012A	PARTICIPANT	\N	PRESENT	0
697964	697954	20092G	PARTICIPANT	\N	PRESENT	0
697965	697954	19413M	PARTICIPANT	\N	PRESENT	0
698213	694877	14021P	PARTICIPANT	\N	EXCUSE	0
698214	694877	19729F	PARTICIPANT	\N	EXCUSE	0
698445	690950	14030Q	PRESIDENT	0	PRESENT	0
698446	690950	20098N	PARTICIPANT	\N	PRESENT	0
698447	690950	19715Y	PARTICIPANT	\N	PRESENT	0
698448	690950	20034V	PARTICIPANT	\N	PRESENT	0
698449	690950	19657G	PARTICIPANT	\N	PRESENT	0
698450	690950	19693L	PARTICIPANT	\N	PRESENT	0
698462	690950	20024T	PARTICIPANT	\N	PRESENT	0
698465	690950	19717B	PARTICIPANT	\N	PRESENT	0
698466	690950	18083K	PARTICIPANT	\N	PRESENT	0
698467	690950	14059S	PARTICIPANT	\N	PRESENT	0
698468	690950	20146D	PARTICIPANT	\N	PRESENT	0
698469	690950	19319Q	PARTICIPANT	\N	PRESENT	0
698470	690950	14147R	PARTICIPANT	\N	PRESENT	0
698473	690950	19577H	PARTICIPANT	\N	PRESENT	0
698902	698369	14073Q	PARTICIPANT	\N	PRESENT	0
699028	699019	14213J	PARTICIPANT	\N	PRESENT	0
699026	699018	14213J	PARTICIPANT	\N	PRESENT	0
699027	699018	17965H	PARTICIPANT	\N	PRESENT	0
699029	699019	17965H	PARTICIPANT	\N	PRESENT	0
699030	699020	14213J	PARTICIPANT	\N	PRESENT	0
699031	699020	17965H	PARTICIPANT	\N	PRESENT	0
699032	699023	14042U	PARTICIPANT	\N	PRESENT	0
699033	699023	14213J	PARTICIPANT	\N	PRESENT	0
699034	699024	14042U	PARTICIPANT	\N	PRESENT	0
699035	699024	14213J	PARTICIPANT	\N	PRESENT	0
699036	699015	14213J	PARTICIPANT	\N	PRESENT	0
699037	699015	14042U	PARTICIPANT	\N	PRESENT	0
699038	699015	19553Y	PARTICIPANT	\N	PRESENT	0
699039	699016	19367Y	PARTICIPANT	\N	PRESENT	0
699040	699016	19553Y	PARTICIPANT	\N	PRESENT	0
699041	699016	14213J	PARTICIPANT	\N	PRESENT	0
699042	699016	14223L	PARTICIPANT	\N	PRESENT	0
699043	699016	17965H	PARTICIPANT	\N	PRESENT	0
699049	699048	20054A	PARTICIPANT	\N	PRESENT	0
699050	699048	14207L	PARTICIPANT	\N	PRESENT	0
699059	699058	20054A	PARTICIPANT	\N	PRESENT	0
699060	699058	14207L	PARTICIPANT	\N	PRESENT	0
699069	699061	19717B	PARTICIPANT	\N	PRESENT	0
699071	699061	86034E	PARTICIPANT	\N	PRESENT	0
699072	699061	04085P	PARTICIPANT	\N	PRESENT	0
699073	699061	04047H	PARTICIPANT	\N	PRESENT	0
699074	699061	04042C	PARTICIPANT	\N	PRESENT	0
699075	699061	14259Y	PARTICIPANT	\N	PRESENT	0
699076	699061	11070L	PARTICIPANT	\N	PRESENT	0
699077	699061	19719D	PARTICIPANT	\N	PRESENT	0
699078	699061	10006L	PARTICIPANT	\N	PRESENT	0
699079	699061	14231L	PARTICIPANT	\N	PRESENT	0
699080	699061	14026U	PARTICIPANT	\N	PRESENT	0
699081	699061	11048N	PARTICIPANT	\N	PRESENT	0
699082	699061	14021P	PARTICIPANT	\N	PRESENT	0
699083	699061	99004R	PARTICIPANT	\N	PRESENT	0
699084	699061	19735D	PARTICIPANT	\N	PRESENT	0
699085	699061	01043Q	PARTICIPANT	\N	PRESENT	0
699086	699061	14219Q	PARTICIPANT	\N	PRESENT	0
699087	699061	14251Q	PARTICIPANT	\N	PRESENT	0
699088	699061	08061X	PARTICIPANT	\N	PRESENT	0
699089	699061	11090Q	PARTICIPANT	\N	PRESENT	0
699090	699061	14331P	PARTICIPANT	\N	PRESENT	0
699091	699061	14225N	PARTICIPANT	\N	PRESENT	0
699092	699061	11012A	PARTICIPANT	\N	PRESENT	0
699093	699061	04033B	PARTICIPANT	\N	PRESENT	0
699094	699061	95063L	PARTICIPANT	\N	PRESENT	0
699095	699061	11045K	PARTICIPANT	\N	PRESENT	0
699096	699061	20266L	PARTICIPANT	\N	PRESENT	0
699103	698964	20032T	PARTICIPANT	\N	PRESENT	0
699104	698964	19387D	PARTICIPANT	\N	PRESENT	0
699105	698964	14219Q	PRESIDENT	0	PRESENT	0
699106	698964	20046A	PARTICIPANT	\N	PRESENT	0
699107	698964	19745F	PARTICIPANT	\N	PRESENT	0
699108	698964	17367Q	PARTICIPANT	\N	PRESENT	0
699109	698964	20102Q	PARTICIPANT	\N	PRESENT	0
699110	698964	20020P	PARTICIPANT	\N	PRESENT	0
699111	698964	19251M	PARTICIPANT	\N	PRESENT	0
699112	698964	19826F	PARTICIPANT	\N	PRESENT	0
699113	698964	19525U	PARTICIPANT	\N	PRESENT	0
699114	698964	19333N	PARTICIPANT	\N	PRESENT	0
699115	698964	20038A	PARTICIPANT	\N	PRESENT	0
699116	698964	14031R	PARTICIPANT	\N	PRESENT	0
699117	698964	19549D	PARTICIPANT	\N	PRESENT	0
699118	698964	19820Y	PARTICIPANT	\N	PRESENT	0
699119	698964	20106U	PARTICIPANT	\N	PRESENT	0
699120	698964	19619A	PARTICIPANT	\N	PRESENT	0
699121	698964	20140W	PARTICIPANT	\N	PRESENT	0
699122	698964	19599P	PARTICIPANT	\N	PRESENT	0
699123	698964	18083K	PARTICIPANT	\N	PRESENT	0
699124	698964	19685L	PARTICIPANT	\N	PRESENT	0
699471	699468	05008E	PARTICIPANT	\N	EXCUSE	0
699469	699468	20032T	PARTICIPANT	\N	PRESENT	0
699470	699468	19631V	PARTICIPANT	\N	PRESENT	0
699472	699468	19549D	PARTICIPANT	\N	PRESENT	0
699473	699468	20086J	PARTICIPANT	\N	PRESENT	0
699474	699468	19545Y	PARTICIPANT	\N	EXCUSE	0
699475	699468	19525U	PARTICIPANT	\N	PRESENT	0
699476	699468	11110B	PARTICIPANT	\N	PRESENT	0
699477	699468	14231L	PARTICIPANT	\N	PRESENT	0
699478	699468	20120S	PARTICIPANT	\N	PRESENT	0
699479	699468	19387D	PARTICIPANT	\N	PRESENT	0
699480	699468	19399H	PARTICIPANT	\N	PRESENT	0
699481	699468	19531S	PARTICIPANT	\N	PRESENT	0
699482	699468	19489J	PARTICIPANT	\N	PRESENT	0
699483	699468	19735D	PARTICIPANT	\N	PRESENT	0
699484	699468	20108W	PARTICIPANT	\N	PRESENT	0
699485	699468	01043Q	PRESIDENT	0	PRESENT	0
699486	699468	14205J	PARTICIPANT	\N	PRESENT	0
699487	699468	17637T	PARTICIPANT	\N	PRESENT	0
699488	699468	19503N	PARTICIPANT	\N	PRESENT	0
699489	699468	20298U	PARTICIPANT	\N	PRESENT	0
699490	699468	19349W	PARTICIPANT	\N	PRESENT	0
699491	699468	20082E	PARTICIPANT	\N	PRESENT	0
699492	699468	20020P	PARTICIPANT	\N	PRESENT	0
699493	699468	20044X	PARTICIPANT	\N	PRESENT	0
699494	699468	20098N	PARTICIPANT	\N	PRESENT	0
699495	699468	20046A	PARTICIPANT	\N	PRESENT	0
699604	697922	20106U	PARTICIPANT	\N	EXCUSE	0
699605	697922	20066E	PARTICIPANT	\N	EXCUSE	0
699607	697922	20118Y	PARTICIPANT	\N	EXCUSE	0
699609	697922	20024T	PARTICIPANT	\N	EXCUSE	0
699611	697922	20080C	PARTICIPANT	\N	EXCUSE	0
699634	698943	11067R	PARTICIPANT	\N	EXCUSE	0
699858	699857	17737W	PARTICIPANT	\N	PRESENT	0
699976	698940	20074E	PARTICIPANT	\N	PRESENT	0
683958	683954	14237S	PARTICIPANT	\N	PRESENT	0
683962	683961	14237S	PARTICIPANT	\N	PRESENT	0
683970	683969	14237S	PARTICIPANT	\N	PRESENT	0
683980	683979	14237S	PARTICIPANT	\N	PRESENT	0
688266	688265	11027H	PARTICIPANT	\N	PRESENT	0
688267	688265	20034V	PARTICIPANT	\N	PRESENT	0
688268	688265	11040E	PARTICIPANT	\N	PRESENT	0
688269	688265	20064C	PARTICIPANT	\N	PRESENT	0
689115	689113	14026U	PARTICIPANT	\N	PRESENT	0
689117	689113	11097X	PARTICIPANT	\N	PRESENT	0
693827	692457	14237S	PARTICIPANT	\N	PRESENT	0
693859	692457	20144B	PARTICIPANT	\N	EXCUSE	0
693860	692457	14251Q	PARTICIPANT	\N	EXCUSE	0
693861	692457	20030R	PARTICIPANT	\N	EXCUSE	0
694043	692457	14257W	PARTICIPANT	\N	PRESENT	0
694044	692457	01043Q	PARTICIPANT	\N	PRESENT	0
694045	692457	14033T	PARTICIPANT	\N	PRESENT	0
694046	692457	01025N	PARTICIPANT	\N	PRESENT	0
694047	692457	08028W	PARTICIPANT	\N	PRESENT	0
694943	694942	19543W	PARTICIPANT	\N	PRESENT	0
694944	694942	11026G	PARTICIPANT	\N	PRESENT	0
694945	694942	11033F	PARTICIPANT	\N	PRESENT	0
694946	694942	20110Q	PARTICIPANT	\N	PRESENT	0
695558	695557	20112S	PARTICIPANT	\N	PRESENT	1
695559	695557	19643A	PARTICIPANT	\N	PRESENT	1
695561	695557	19735D	PARTICIPANT	\N	PRESENT	1
695564	695563	20112S	PARTICIPANT	\N	PRESENT	1
695565	695563	19643A	PARTICIPANT	\N	PRESENT	1
695566	695563	19735D	PARTICIPANT	\N	PRESENT	1
695567	695563	20980G	PARTICIPANT	\N	PRESENT	1
699965	699964	19593H	PARTICIPANT	\N	PRESENT	0
699966	699964	14189C	PARTICIPANT	\N	PRESENT	0
699967	699964	20132W	PARTICIPANT	\N	PRESENT	0
699968	699964	14059S	PARTICIPANT	\N	PRESENT	0
699969	699964	20180F	PARTICIPANT	\N	PRESENT	0
699970	699964	19713W	PARTICIPANT	\N	PRESENT	0
703833	692497	11072N	PARTICIPANT	\N	PRESENT	0
703834	692497	12016W	PARTICIPANT	\N	PRESENT	0
703852	701600	19693L	PARTICIPANT	\N	PRESENT	0
703859	701600	01048V	PARTICIPANT	\N	PRESENT	0
703860	701600	19503N	PARTICIPANT	\N	PRESENT	0
703861	701600	04043D	PARTICIPANT	\N	PRESENT	0
704077	704076	14147R	PARTICIPANT	\N	PRESENT	0
704348	704214	20126Y	PARTICIPANT	\N	EXCUSE	0
704349	704214	20050V	PARTICIPANT	\N	EXCUSE	0
708137	708136	04035D	PARTICIPANT	\N	PRESENT	0
708138	708136	11041F	PARTICIPANT	\N	PRESENT	0
708139	708136	07033P	PARTICIPANT	\N	PRESENT	0
708140	708136	17023S	PARTICIPANT	\N	PRESENT	0
708141	708136	14249W	PARTICIPANT	\N	PRESENT	0
708704	708052	14089Y	PARTICIPANT	\N	PRESENT	0
708705	708052	19826F	PARTICIPANT	\N	PRESENT	0
708706	708052	11072N	PARTICIPANT	\N	PRESENT	0
708707	708052	20252E	PARTICIPANT	\N	PRESENT	0
708708	708052	19713W	PARTICIPANT	\N	PRESENT	0
708709	708052	19735D	PARTICIPANT	\N	PRESENT	0
708710	708052	19766L	PARTICIPANT	\N	PRESENT	0
708711	708052	01057W	PARTICIPANT	\N	PRESENT	0
708712	708052	14217N	PARTICIPANT	\N	PRESENT	0
708713	708052	14213J	PARTICIPANT	\N	PRESENT	0
708714	708052	14026U	PARTICIPANT	\N	PRESENT	0
708715	708052	20062A	PARTICIPANT	\N	PRESENT	0
708716	708052	14329V	PARTICIPANT	\N	PRESENT	0
708717	708052	08010L	PARTICIPANT	\N	PRESENT	0
708718	708052	14187A	PARTICIPANT	\N	PRESENT	0
708719	708052	11048N	PARTICIPANT	\N	PRESENT	0
708702	708052	20122U	PARTICIPANT	\N	PRESENT	0
708703	708052	19725B	PARTICIPANT	\N	PRESENT	0
708720	708052	20044X	PARTICIPANT	\N	PRESENT	0
708721	708052	20134Y	PARTICIPANT	\N	PRESENT	0
708722	708052	17367Q	PARTICIPANT	\N	PRESENT	0
708723	708052	19739H	PARTICIPANT	\N	PRESENT	0
708724	708052	19699S	PARTICIPANT	\N	PRESENT	0
708725	708052	20058E	PARTICIPANT	\N	PRESENT	0
708726	708052	20086J	PARTICIPANT	\N	PRESENT	0
708727	708052	08018U	PARTICIPANT	\N	PRESENT	0
708728	708052	11026G	PARTICIPANT	\N	PRESENT	0
708729	708052	20286Q	PARTICIPANT	\N	PRESENT	0
708730	708052	14205J	PARTICIPANT	\N	PRESENT	0
708731	708052	20064C	PARTICIPANT	\N	PRESENT	0
708732	708052	20070A	PARTICIPANT	\N	PRESENT	0
708733	708052	17637T	PARTICIPANT	\N	PRESENT	0
708734	708052	20052X	PARTICIPANT	\N	PRESENT	0
708735	708052	14249W	PARTICIPANT	\N	PRESENT	0
708736	708052	16685X	PARTICIPANT	\N	PRESENT	0
708737	708052	19479G	PARTICIPANT	\N	PRESENT	0
708738	708052	14073Q	PARTICIPANT	\N	PRESENT	0
708739	708052	01048V	PARTICIPANT	\N	PRESENT	0
708740	708052	19723Y	PARTICIPANT	\N	PRESENT	0
708741	708052	14215L	PARTICIPANT	\N	PRESENT	0
708742	708052	95063L	PARTICIPANT	\N	PRESENT	0
708743	708052	14231L	PARTICIPANT	\N	PRESENT	0
708744	708052	19591F	PARTICIPANT	\N	PRESENT	0
708745	708052	01034P	PARTICIPANT	\N	PRESENT	0
708746	708052	19691J	PARTICIPANT	\N	PRESENT	0
708747	708052	04045F	PARTICIPANT	\N	PRESENT	0
708748	708052	20106U	PARTICIPANT	\N	PRESENT	0
708749	708052	19349W	PARTICIPANT	\N	PRESENT	0
708750	708052	14219Q	PARTICIPANT	\N	PRESENT	0
708751	708052	17737W	PARTICIPANT	\N	PRESENT	0
708752	708052	20112S	PARTICIPANT	\N	PRESENT	0
708753	708052	04059M	PARTICIPANT	\N	PRESENT	0
708754	708052	14042U	PARTICIPANT	\N	PRESENT	0
708755	708052	11097X	PARTICIPANT	\N	PRESENT	0
708756	708052	10006L	PARTICIPANT	\N	PRESENT	0
708757	708052	19551W	PARTICIPANT	\N	PRESENT	0
708758	708052	19782L	PARTICIPANT	\N	PRESENT	0
708759	708052	19057M	PARTICIPANT	\N	PRESENT	0
708760	708052	19820Y	PARTICIPANT	\N	PRESENT	0
708761	708052	19729F	PARTICIPANT	\N	PRESENT	0
708762	708052	19577H	PARTICIPANT	\N	PRESENT	0
708763	708052	14031R	PARTICIPANT	\N	PRESENT	0
708764	708052	19565D	PARTICIPANT	\N	PRESENT	0
708765	708052	19295A	PARTICIPANT	\N	PRESENT	0
708766	708052	20032T	PARTICIPANT	\N	PRESENT	0
708767	708052	14083S	PARTICIPANT	\N	PRESENT	0
708768	708052	19637C	PARTICIPANT	\N	PRESENT	0
708769	708052	20066E	PARTICIPANT	\N	PRESENT	0
708770	708052	19573D	PARTICIPANT	\N	PRESENT	0
708771	708052	04085P	PARTICIPANT	\N	PRESENT	0
708772	708052	19599P	PARTICIPANT	\N	PRESENT	0
708773	708052	20980G	PARTICIPANT	\N	PRESENT	0
708774	708052	01028R	PARTICIPANT	\N	PRESENT	0
708775	708052	14147R	PARTICIPANT	\N	PRESENT	0
708776	708052	08034U	PARTICIPANT	\N	PRESENT	0
708777	708052	20088L	PARTICIPANT	\N	PRESENT	0
708778	708052	11012A	PARTICIPANT	\N	PRESENT	0
708779	708052	07029T	PARTICIPANT	\N	PRESENT	0
708780	708052	20248J	PARTICIPANT	\N	PRESENT	0
708781	708052	20128B	PARTICIPANT	\N	PRESENT	0
708782	708052	20098N	PARTICIPANT	\N	PRESENT	0
708791	708052	20090E	PARTICIPANT	\N	PRESENT	0
708784	708052	19621T	PARTICIPANT	\N	PRESENT	0
708785	708052	14357A	PARTICIPANT	\N	PRESENT	0
708786	708052	95041E	PARTICIPANT	\N	PRESENT	0
708787	708052	20136B	PARTICIPANT	\N	PRESENT	0
708788	708052	14259Y	PARTICIPANT	\N	PRESENT	0
708789	708052	20110Q	PARTICIPANT	\N	PRESENT	0
708790	708052	14053L	PARTICIPANT	\N	PRESENT	0
708792	708052	19671E	PARTICIPANT	\N	PRESENT	0
708793	708052	14225N	PARTICIPANT	\N	PRESENT	0
708794	708052	14021P	PARTICIPANT	\N	PRESENT	0
708795	708052	11077T	PARTICIPANT	\N	PRESENT	0
708796	708052	14179A	PARTICIPANT	\N	PRESENT	0
708797	708052	14257W	PARTICIPANT	\N	PRESENT	0
708798	708052	19711U	PARTICIPANT	\N	PRESENT	0
708799	708052	86034E	PARTICIPANT	\N	PRESENT	0
708800	708052	14123H	PARTICIPANT	\N	PRESENT	0
708801	708052	19369B	PARTICIPANT	\N	PRESENT	0
708802	708052	14037X	PARTICIPANT	\N	PRESENT	0
708804	708803	20054A	PARTICIPANT	\N	PRESENT	0
708805	708803	20076G	PARTICIPANT	\N	PRESENT	0
693479	692428	14053L	PARTICIPANT	\N	PRESENT	0
693480	692428	04047H	PARTICIPANT	\N	PRESENT	0
693481	692428	19301E	PARTICIPANT	\N	PRESENT	0
693486	692428	19569H	PARTICIPANT	\N	PRESENT	0
693483	692428	19747H	PARTICIPANT	\N	PRESENT	0
693484	692428	14179A	PARTICIPANT	\N	PRESENT	0
693485	692428	04059M	PARTICIPANT	\N	PRESENT	0
693487	692428	11043H	PARTICIPANT	\N	PRESENT	0
693488	692428	07029T	PARTICIPANT	\N	PRESENT	0
693489	692428	08012N	PARTICIPANT	\N	PRESENT	0
693490	692428	20086J	PARTICIPANT	\N	PRESENT	0
693491	692428	20142Y	PARTICIPANT	\N	PRESENT	0
693492	692428	19725B	PARTICIPANT	\N	PRESENT	0
693493	692428	20084G	PARTICIPANT	\N	PRESENT	0
693494	692428	20124W	PARTICIPANT	\N	PRESENT	0
693495	692428	19723Y	PARTICIPANT	\N	PRESENT	0
693499	692428	14213J	PARTICIPANT	\N	PRESENT	0
693497	692428	14026U	PARTICIPANT	\N	PRESENT	0
693498	692428	20136B	PARTICIPANT	\N	PRESENT	0
693500	692428	08010L	PARTICIPANT	\N	PRESENT	0
693501	692428	20026V	PARTICIPANT	\N	PRESENT	0
693502	692428	20140W	PARTICIPANT	\N	PRESENT	0
693503	692428	20056C	PARTICIPANT	\N	PRESENT	0
693504	692428	19545Y	PARTICIPANT	\N	PRESENT	0
693505	692428	20132W	PARTICIPANT	\N	PRESENT	0
693506	692428	08061X	PARTICIPANT	\N	PRESENT	0
693507	692428	19447X	PARTICIPANT	\N	PRESENT	0
693508	692428	14187A	PARTICIPANT	\N	PRESENT	0
693509	692428	14069U	PARTICIPANT	\N	PRESENT	0
693510	692428	20022R	PARTICIPANT	\N	PRESENT	0
693511	692428	14071N	PARTICIPANT	\N	PRESENT	0
693512	692428	17023S	PARTICIPANT	\N	PRESENT	0
693513	692428	04033B	PARTICIPANT	\N	PRESENT	0
693514	692428	04085P	PARTICIPANT	\N	PRESENT	0
693515	692428	19695N	PARTICIPANT	\N	PRESENT	0
693516	692428	14033T	PARTICIPANT	\N	PRESENT	0
693517	692428	20298U	PARTICIPANT	\N	PRESENT	0
693518	692428	20128B	PARTICIPANT	\N	PRESENT	0
693519	692428	14249W	PARTICIPANT	\N	PRESENT	0
693520	692428	19349W	PARTICIPANT	\N	PRESENT	0
693521	692428	19647E	PARTICIPANT	\N	PRESENT	0
693522	692428	14083S	PARTICIPANT	\N	PRESENT	0
693523	692428	20058E	PARTICIPANT	\N	PRESENT	0
693524	692428	14105F	PARTICIPANT	\N	PRESENT	0
693589	693561	05008E	PARTICIPANT	\N	EXCUSE	0
693590	693561	14331P	PARTICIPANT	\N	EXCUSE	0
693600	693586	05008E	PARTICIPANT	\N	EXCUSE	0
693601	693586	14331P	PARTICIPANT	\N	EXCUSE	0
693602	693587	05008E	PARTICIPANT	\N	EXCUSE	0
693603	693587	14331P	PARTICIPANT	\N	EXCUSE	0
693605	692532	10006L	PRESIDENT	0	PRESENT	0
693606	692532	20130U	PARTICIPANT	\N	PRESENT	0
693607	692532	14281W	PARTICIPANT	\N	PRESENT	0
693608	692532	17779H	PARTICIPANT	\N	PRESENT	0
693609	692532	19553Y	PARTICIPANT	\N	PRESENT	0
693610	692532	19683J	PARTICIPANT	\N	PRESENT	0
693611	692532	11045K	PARTICIPANT	\N	PRESENT	0
693612	692532	19415P	PARTICIPANT	\N	PRESENT	0
693613	692532	14223L	PARTICIPANT	\N	PRESENT	0
693614	692532	20090E	PARTICIPANT	\N	PRESENT	0
693615	692532	19511N	PARTICIPANT	\N	PRESENT	0
693616	692532	19798U	PARTICIPANT	\N	PRESENT	0
693617	692532	14195A	PARTICIPANT	\N	PRESENT	0
693618	692532	17965H	PARTICIPANT	\N	PRESENT	0
693619	692532	14042U	PARTICIPANT	\N	PRESENT	0
693630	692532	19691J	PARTICIPANT	\N	PRESENT	0
693631	692532	14217N	PARTICIPANT	\N	PRESENT	0
693632	692532	14213J	PARTICIPANT	\N	PRESENT	0
693645	692532	19591F	PARTICIPANT	\N	PRESENT	0
693646	692532	14071N	PARTICIPANT	\N	PRESENT	0
693647	692532	20248J	PARTICIPANT	\N	PRESENT	0
693648	692532	11097X	PARTICIPANT	\N	PRESENT	0
693652	692532	19679N	PARTICIPANT	\N	PRESENT	0
693655	692532	19723Y	PARTICIPANT	\N	PRESENT	0
693659	692532	19569H	PARTICIPANT	\N	PRESENT	0
693661	692532	20040T	PARTICIPANT	\N	PRESENT	0
693662	692532	14026U	PARTICIPANT	\N	PRESENT	0
693663	692532	08045X	PARTICIPANT	\N	PRESENT	0
693666	692532	11067R	PARTICIPANT	\N	PRESENT	0
693670	692532	04043D	PARTICIPANT	\N	PRESENT	0
693671	692532	19367Y	PARTICIPANT	\N	PRESENT	0
693674	692532	18193Q	PARTICIPANT	\N	PRESENT	0
693754	690706	14237S	PARTICIPANT	\N	PRESENT	0
693756	690706	19685L	PARTICIPANT	\N	PRESENT	0
693798	692321	19649G	PARTICIPANT	\N	PRESENT	0
693801	692321	10015M	PARTICIPANT	\N	PRESENT	0
693803	692321	19301E	PARTICIPANT	\N	PRESENT	0
693805	692321	19581D	PARTICIPANT	\N	PRESENT	0
693806	692321	04047H	PRESIDENT	0	PRESENT	0
693808	692321	05008E	PARTICIPANT	\N	PRESENT	0
693811	692321	19447X	PARTICIPANT	\N	PRESENT	0
693814	692321	14089Y	PARTICIPANT	\N	PRESENT	0
693816	692321	14275Y	PARTICIPANT	\N	PRESENT	0
693817	692321	14147R	PARTICIPANT	\N	PRESENT	0
693818	692321	14069U	PARTICIPANT	\N	PRESENT	0
693819	692321	20022R	PARTICIPANT	\N	PRESENT	0
693820	692321	19749K	PARTICIPANT	\N	PRESENT	0
693821	692321	14021P	PARTICIPANT	\N	PRESENT	0
693822	692321	19675J	PARTICIPANT	\N	PRESENT	0
693823	691220	19399H	PARTICIPANT	\N	PRESENT	0
693824	692321	19673G	PARTICIPANT	\N	PRESENT	0
693825	692321	11033F	PARTICIPANT	\N	PRESENT	0
693826	692321	20114U	PARTICIPANT	\N	PRESENT	0
693828	691635	19766L	PARTICIPANT	\N	PRESENT	0
693829	691635	19699S	PARTICIPANT	\N	PRESENT	0
693830	691635	19533U	PARTICIPANT	\N	PRESENT	0
693831	691635	04033B	PARTICIPANT	\N	PRESENT	0
693832	691635	14229S	PARTICIPANT	\N	PRESENT	0
693833	691635	19573D	PARTICIPANT	\N	PRESENT	0
693834	691635	20112S	PARTICIPANT	\N	PRESENT	0
693835	691635	08012N	PARTICIPANT	\N	PRESENT	0
693836	691635	20124W	PARTICIPANT	\N	PRESENT	0
693837	691635	19593H	PARTICIPANT	\N	PRESENT	0
693838	691635	19643A	PARTICIPANT	\N	PRESENT	0
693839	691635	20132W	PARTICIPANT	\N	PRESENT	0
693840	691635	14073Q	PARTICIPANT	\N	PRESENT	0
693841	691635	19651A	PARTICIPANT	\N	PRESENT	0
693842	691635	19611R	PRESIDENT	0	PRESENT	0
693843	691635	20142Y	PARTICIPANT	\N	PRESENT	0
693844	691635	19693L	PARTICIPANT	\N	PRESENT	0
693845	691635	19399H	PARTICIPANT	\N	PRESENT	0
693846	691635	20152B	PARTICIPANT	\N	PRESENT	0
693847	691635	20172F	PARTICIPANT	\N	PRESENT	0
693848	691635	20058E	PARTICIPANT	\N	PRESENT	0
693849	691635	20056C	PARTICIPANT	\N	PRESENT	0
693850	691635	04059M	PARTICIPANT	\N	PRESENT	0
693851	691635	20264J	PARTICIPANT	\N	PRESENT	0
693852	691635	19735D	PARTICIPANT	\N	PRESENT	0
693853	691635	14109K	PARTICIPANT	\N	PRESENT	0
693854	691635	11043H	PARTICIPANT	\N	PRESENT	0
693855	691635	20980G	PARTICIPANT	\N	PRESENT	0
693856	691635	11104D	PARTICIPANT	\N	PRESENT	0
693857	691635	19758L	PARTICIPANT	\N	PRESENT	0
693858	691635	20084G	PARTICIPANT	\N	PRESENT	0
693862	691635	04070G	PARTICIPANT	\N	PRESENT	0
693863	691635	19527W	PARTICIPANT	\N	PRESENT	0
693864	690706	20106U	PARTICIPANT	\N	PRESENT	0
693865	692321	01028R	PARTICIPANT	\N	PRESENT	0
693866	692321	14179A	PARTICIPANT	\N	PRESENT	0
693867	692321	19725B	PARTICIPANT	\N	PRESENT	0
693868	692321	17737W	PARTICIPANT	\N	EXCUSE	0
693869	692429	86034E	PARTICIPANT	\N	PRESENT	0
693870	692966	19545Y	PARTICIPANT	\N	PRESENT	0
693871	691635	20026V	PARTICIPANT	\N	PRESENT	0
693872	692532	19717B	PARTICIPANT	\N	PRESENT	0
693873	692532	20266L	PARTICIPANT	\N	PRESENT	0
693874	692532	20066E	PARTICIPANT	\N	PRESENT	0
693875	692533	19717B	PARTICIPANT	\N	PRESENT	0
693876	692533	19367Y	PARTICIPANT	\N	PRESENT	0
693877	692533	19415P	PARTICIPANT	\N	PRESENT	0
693878	692533	20090E	PARTICIPANT	\N	PRESENT	0
693879	692533	14195A	PARTICIPANT	\N	PRESENT	0
693880	692533	10006L	PARTICIPANT	\N	PRESENT	0
693881	692533	14217N	PARTICIPANT	\N	PRESENT	0
693882	692533	20248J	PARTICIPANT	\N	PRESENT	0
693883	692533	14042U	PARTICIPANT	\N	PRESENT	0
693884	692533	20040T	PARTICIPANT	\N	PRESENT	0
693885	692533	14281W	PARTICIPANT	\N	PRESENT	0
693886	692533	08045X	PARTICIPANT	\N	PRESENT	0
693887	692533	14026U	PARTICIPANT	\N	PRESENT	0
693888	692533	19691J	PARTICIPANT	\N	PRESENT	0
685526	683228	20074E	PARTICIPANT	\N	PRESENT	0
685527	683228	20078J	PARTICIPANT	\N	PRESENT	0
685528	683228	14123H	PARTICIPANT	\N	PRESENT	0
685529	683228	20112S	PARTICIPANT	\N	PRESENT	0
685530	683228	19758L	PARTICIPANT	\N	PRESENT	0
685531	683228	08069G	PARTICIPANT	\N	PRESENT	0
685532	683228	11077T	PARTICIPANT	\N	PRESENT	0
685533	683228	04035D	PARTICIPANT	\N	PRESENT	0
685534	683228	17637T	PARTICIPANT	\N	PRESENT	0
685535	683228	20110Q	PARTICIPANT	\N	PRESENT	0
685536	683228	19703U	PARTICIPANT	\N	PRESENT	0
685537	683228	20914V	PARTICIPANT	\N	PRESENT	0
685538	683228	11065P	PARTICIPANT	\N	PRESENT	0
685539	683228	11101A	PARTICIPANT	\N	PRESENT	0
685540	683228	08010L	PARTICIPANT	\N	PRESENT	0
685541	683228	20100N	PARTICIPANT	\N	PRESENT	0
685542	683228	04047H	PARTICIPANT	\N	PRESENT	0
685543	683228	20130U	PARTICIPANT	\N	PRESENT	0
685544	683228	14026U	PARTICIPANT	\N	PRESENT	0
685545	683228	20142Y	PARTICIPANT	\N	PRESENT	0
685546	683228	14133K	PARTICIPANT	\N	PRESENT	0
685547	683228	20092G	PARTICIPANT	\N	PRESENT	0
685548	683228	08034U	PARTICIPANT	\N	PRESENT	0
685549	683228	20266L	PARTICIPANT	\N	PRESENT	0
685550	683228	11099A	PARTICIPANT	\N	PRESENT	0
685551	683228	04092N	PARTICIPANT	\N	PRESENT	0
685552	683228	19747H	PARTICIPANT	\N	PRESENT	0
685553	683228	19651A	PARTICIPANT	\N	PRESENT	0
685554	683228	19782L	PARTICIPANT	\N	PRESENT	0
685555	683228	04033B	PARTICIPANT	\N	PRESENT	0
685556	683228	19525U	PARTICIPANT	\N	PRESENT	0
685557	683228	14187A	PARTICIPANT	\N	PRESENT	0
685558	683228	11097X	PARTICIPANT	\N	PRESENT	0
685559	683228	19659J	PARTICIPANT	\N	PRESENT	0
685560	683228	14249W	PARTICIPANT	\N	PRESENT	0
685561	683228	19415P	PARTICIPANT	\N	PRESENT	0
685562	683228	11083R	PARTICIPANT	\N	PRESENT	0
685563	683228	14215L	PARTICIPANT	\N	PRESENT	0
685564	683228	19329S	PARTICIPANT	\N	PRESENT	0
685565	683228	19421M	PARTICIPANT	\N	PRESENT	0
685566	683228	20106U	PARTICIPANT	\N	PRESENT	0
685567	683228	14053L	PARTICIPANT	\N	PRESENT	0
685568	683228	19591F	PARTICIPANT	\N	PRESENT	0
685569	683228	20016T	PARTICIPANT	\N	PRESENT	0
685570	683228	14069U	PARTICIPANT	\N	PRESENT	0
685571	683228	04043D	PARTICIPANT	\N	PRESENT	0
685572	683228	11072N	PARTICIPANT	\N	PRESENT	0
685573	683228	11090Q	PARTICIPANT	\N	PRESENT	0
685574	683228	14105F	PARTICIPANT	\N	PRESENT	0
685575	683228	20118Y	PARTICIPANT	\N	PRESENT	0
685576	683228	08061X	PARTICIPANT	\N	PRESENT	0
685577	683228	20146D	PARTICIPANT	\N	PRESENT	0
685578	683228	19533U	PARTICIPANT	\N	PRESENT	0
685579	683228	04045F	PARTICIPANT	\N	PRESENT	0
685580	683228	19798U	PARTICIPANT	\N	PRESENT	0
685581	683228	11033F	PARTICIPANT	\N	PRESENT	0
685582	683228	01060R	PARTICIPANT	\N	PRESENT	0
685583	683228	20252E	PARTICIPANT	\N	PRESENT	0
685584	683228	19367Y	PARTICIPANT	\N	PRESENT	0
685585	683228	14207L	PARTICIPANT	\N	PRESENT	0
685586	683228	19629C	PARTICIPANT	\N	PRESENT	0
685587	683228	20132W	PARTICIPANT	\N	PRESENT	0
685588	683228	19387D	PARTICIPANT	\N	PRESENT	0
685589	683228	20120S	PARTICIPANT	\N	PRESENT	0
685590	683228	19553Y	PARTICIPANT	\N	PRESENT	0
685591	683228	20072C	PARTICIPANT	\N	PRESENT	0
685592	683228	20152B	PARTICIPANT	\N	PRESENT	0
685593	683228	19866P	PARTICIPANT	\N	PRESENT	0
685594	683228	11012A	PARTICIPANT	\N	PRESENT	0
685595	683228	20054A	PARTICIPANT	\N	PRESENT	0
685596	683228	19545Y	PARTICIPANT	\N	PRESENT	0
685597	683228	20126Y	PARTICIPANT	\N	PRESENT	0
685598	683228	20124W	PARTICIPANT	\N	PRESENT	0
685599	683228	08056B	PARTICIPANT	\N	PRESENT	0
685600	683228	14059S	PARTICIPANT	\N	PRESENT	0
685604	683228	19583F	PARTICIPANT	\N	PRESENT	0
685602	683228	14211G	PARTICIPANT	\N	PRESENT	0
685603	683228	20090E	PARTICIPANT	\N	PRESENT	0
685605	683228	20062A	PARTICIPANT	\N	PRESENT	0
685606	683228	14111D	PARTICIPANT	\N	PRESENT	0
685607	683228	14221J	PARTICIPANT	\N	PRESENT	0
685608	683228	04057K	PARTICIPANT	\N	PRESENT	0
685609	683228	14147R	PARTICIPANT	\N	PRESENT	0
685610	683228	17737W	PARTICIPANT	\N	PRESENT	0
685611	683228	20122U	PARTICIPANT	\N	PRESENT	0
685612	683228	19585H	PARTICIPANT	\N	PRESENT	0
685613	683228	20136B	PARTICIPANT	\N	PRESENT	0
685614	683228	20032T	PARTICIPANT	\N	PRESENT	0
685615	683228	20148F	PARTICIPANT	\N	PRESENT	0
685616	683228	20172F	PARTICIPANT	\N	PRESENT	0
685617	683228	20138D	PARTICIPANT	\N	PRESENT	0
685618	683228	08047A	PARTICIPANT	\N	PRESENT	0
685619	683228	19768N	PARTICIPANT	\N	PRESENT	0
685620	683228	19705W	PARTICIPANT	\N	PRESENT	0
685621	683228	19741B	PARTICIPANT	\N	PRESENT	0
685622	683228	14329V	PARTICIPANT	\N	PRESENT	0
685623	683228	11103C	PARTICIPANT	\N	PRESENT	0
685624	683228	14357A	PARTICIPANT	\N	PRESENT	0
685625	683228	14217N	PARTICIPANT	\N	PRESENT	0
685626	683228	19762G	PARTICIPANT	\N	PRESENT	0
685627	683228	20020P	PARTICIPANT	\N	PRESENT	0
685628	683228	20056C	PARTICIPANT	\N	PRESENT	0
685629	683228	14213J	PARTICIPANT	\N	PRESENT	0
685630	683228	19399H	PARTICIPANT	\N	PRESENT	0
685631	683228	19631V	PARTICIPANT	\N	PRESENT	0
685632	683228	04059M	PARTICIPANT	\N	PRESENT	0
685634	683228	19549D	PARTICIPANT	\N	PRESENT	0
685635	683228	08018U	PARTICIPANT	\N	PRESENT	0
685636	683228	20114U	PARTICIPANT	\N	PRESENT	0
685637	683228	19503N	PARTICIPANT	\N	PRESENT	0
685638	683228	14225N	PARTICIPANT	\N	PRESENT	0
685639	683228	01028R	PARTICIPANT	\N	PRESENT	0
685640	683228	11045K	PARTICIPANT	\N	PRESENT	0
685641	683228	01062T	PARTICIPANT	\N	PRESENT	0
685642	683228	20060X	PARTICIPANT	\N	PRESENT	0
685643	683228	20264J	PARTICIPANT	\N	PRESENT	0
685644	683228	20104S	PARTICIPANT	\N	PRESENT	0
685645	683228	20070A	PARTICIPANT	\N	PRESENT	0
685646	683228	11027H	PARTICIPANT	\N	PRESENT	0
685647	683228	19695N	PARTICIPANT	\N	PRESENT	0
685648	683228	19669L	PARTICIPANT	\N	PRESENT	0
685649	683228	11026G	PARTICIPANT	\N	PRESENT	0
685650	683228	19489J	PARTICIPANT	\N	PRESENT	0
685651	683228	14021P	PARTICIPANT	\N	PRESENT	0
685652	683228	14121F	PARTICIPANT	\N	PRESENT	0
685653	683228	08045X	PARTICIPANT	\N	PRESENT	0
685654	683228	20128B	PARTICIPANT	\N	PRESENT	0
685655	683228	19675J	PARTICIPANT	\N	PRESENT	0
685656	683228	11104D	PARTICIPANT	\N	PRESENT	0
685657	683228	19333N	PARTICIPANT	\N	PRESENT	0
685658	683228	19820Y	PARTICIPANT	\N	PRESENT	0
685659	683228	14109K	PARTICIPANT	\N	PRESENT	0
685660	683228	20030R	PARTICIPANT	\N	PRESENT	0
685661	683228	20028X	PARTICIPANT	\N	PRESENT	0
685662	683228	20018V	PARTICIPANT	\N	PRESENT	0
685663	683228	18193Q	PARTICIPANT	\N	PRESENT	0
685664	683228	08012N	PARTICIPANT	\N	PRESENT	0
685665	683228	20050V	PARTICIPANT	\N	PRESENT	0
685666	683228	11048N	PARTICIPANT	\N	PRESENT	0
685667	683228	14193X	PARTICIPANT	\N	PRESENT	0
685668	683228	11074Q	PARTICIPANT	\N	PRESENT	0
685669	683228	14229S	PARTICIPANT	\N	PRESENT	0
685670	683228	10015M	PARTICIPANT	\N	PRESENT	0
685671	683228	20082E	PARTICIPANT	\N	PRESENT	0
685672	683228	11066Q	PARTICIPANT	\N	PRESENT	0
685673	683228	19527W	PARTICIPANT	\N	PRESENT	0
685674	683228	17589D	PARTICIPANT	\N	PRESENT	0
685675	683228	11041F	PARTICIPANT	\N	PRESENT	0
685676	683228	20064C	PARTICIPANT	\N	PRESENT	0
685677	683228	20080C	PARTICIPANT	\N	PRESENT	0
685678	683228	19413M	PARTICIPANT	\N	PRESENT	0
685679	683228	19251M	PARTICIPANT	\N	PRESENT	0
685680	683228	19649G	PARTICIPANT	\N	PRESENT	0
685681	683228	19531S	PARTICIPANT	\N	PRESENT	0
685682	683228	11067R	PARTICIPANT	\N	PRESENT	0
685683	683228	14001X	PARTICIPANT	\N	PRESENT	0
685684	683228	14257W	PARTICIPANT	\N	PRESENT	0
685685	683228	17965H	PARTICIPANT	\N	PRESENT	0
685686	683228	19569H	PARTICIPANT	\N	PRESENT	0
685687	683228	19319Q	PARTICIPANT	\N	PRESENT	0
685688	683228	20042V	PARTICIPANT	\N	PRESENT	0
699977	698940	14001X	PARTICIPANT	\N	PRESENT	0
699978	698940	19543W	PARTICIPANT	\N	PRESENT	0
699979	698940	19581D	PARTICIPANT	\N	PRESENT	0
699980	698940	04047H	PRESIDENT	0	PRESENT	0
699981	698940	19673G	PARTICIPANT	\N	PRESENT	0
699982	698940	01028R	PARTICIPANT	\N	PRESENT	0
699983	698940	19447X	PARTICIPANT	\N	PRESENT	0
699984	698940	05008E	PARTICIPANT	\N	PRESENT	0
699985	698940	19954N	PARTICIPANT	\N	PRESENT	0
699986	698940	19489J	PARTICIPANT	\N	PRESENT	0
699987	698940	07004J	PARTICIPANT	\N	PRESENT	0
699988	698940	14107H	PARTICIPANT	\N	PRESENT	0
699989	698940	20108W	PARTICIPANT	\N	PRESENT	0
699990	698940	14147R	PARTICIPANT	\N	PRESENT	0
699991	698940	14151M	PARTICIPANT	\N	PRESENT	0
699992	698940	14215L	PARTICIPANT	\N	PRESENT	0
699993	698940	08018U	PARTICIPANT	\N	PRESENT	0
699994	698940	20022R	PARTICIPANT	\N	PRESENT	0
699995	698940	14259Y	PARTICIPANT	\N	PRESENT	0
699996	698940	11072N	PARTICIPANT	\N	PRESENT	0
699997	698940	14111D	PARTICIPANT	\N	PRESENT	0
699998	698940	11010L	PARTICIPANT	\N	PRESENT	0
699999	698940	11026G	PARTICIPANT	\N	PRESENT	0
700000	698940	04085P	PARTICIPANT	\N	PRESENT	0
700001	698940	19725B	PARTICIPANT	\N	PRESENT	0
700002	698940	19629C	PARTICIPANT	\N	PRESENT	0
700003	698940	14069U	PARTICIPANT	\N	PRESENT	0
700004	698940	04008A	PARTICIPANT	\N	PRESENT	0
700007	698938	20074E	PARTICIPANT	\N	PRESENT	0
700008	698938	14001X	PARTICIPANT	\N	PRESENT	0
700009	698938	19543W	PARTICIPANT	\N	PRESENT	0
700010	698938	19581D	PARTICIPANT	\N	PRESENT	0
700011	698938	04047H	PRESIDENT	0	PRESENT	0
700012	698938	19673G	PARTICIPANT	\N	PRESENT	0
700013	698938	01028R	PARTICIPANT	\N	PRESENT	0
700014	698938	19447X	PARTICIPANT	\N	PRESENT	0
700015	698938	05008E	PARTICIPANT	\N	PRESENT	0
700016	698938	19954N	PARTICIPANT	\N	PRESENT	0
700017	698938	19489J	PARTICIPANT	\N	PRESENT	0
700018	698938	07004J	PARTICIPANT	\N	PRESENT	0
700019	698938	14107H	PARTICIPANT	\N	PRESENT	0
700020	698938	20108W	PARTICIPANT	\N	PRESENT	0
700021	698938	14147R	PARTICIPANT	\N	PRESENT	0
700022	698938	14151M	PARTICIPANT	\N	PRESENT	0
700023	698938	20114U	PARTICIPANT	\N	PRESENT	0
700024	698938	14215L	PARTICIPANT	\N	PRESENT	0
700025	698938	08018U	PARTICIPANT	\N	PRESENT	0
700026	698938	20022R	PARTICIPANT	\N	PRESENT	0
700027	698938	14259Y	PARTICIPANT	\N	PRESENT	0
700028	698938	11072N	PARTICIPANT	\N	PRESENT	0
700029	698938	14053L	PARTICIPANT	\N	PRESENT	0
700030	698938	14111D	PARTICIPANT	\N	PRESENT	0
700031	698938	11010L	PARTICIPANT	\N	PRESENT	0
700032	698938	10015M	PARTICIPANT	\N	PRESENT	0
700033	698938	11033F	PARTICIPANT	\N	PRESENT	0
700034	698938	04085P	PARTICIPANT	\N	PRESENT	0
700035	698938	19725B	PARTICIPANT	\N	PRESENT	0
700036	698938	14089Y	PARTICIPANT	\N	PRESENT	0
700037	698938	11056N	PARTICIPANT	\N	PRESENT	0
700038	698938	19729F	PARTICIPANT	\N	PRESENT	0
700039	698938	95063L	PARTICIPANT	\N	PRESENT	0
700040	698938	19629C	PARTICIPANT	\N	PRESENT	0
700041	698938	14069U	PARTICIPANT	\N	PRESENT	0
700042	698938	04008A	PARTICIPANT	\N	PRESENT	0
700043	698938	14021P	PARTICIPANT	\N	PRESENT	0
700044	698938	11026G	PARTICIPANT	\N	PRESENT	0
700045	698938	17737W	PARTICIPANT	\N	EXCUSE	0
700095	698941	12041X	PARTICIPANT	\N	PRESENT	0
700096	698941	11080N	PARTICIPANT	\N	PRESENT	0
700097	698941	20072C	PARTICIPANT	\N	PRESENT	0
700098	698941	01058X	PARTICIPANT	\N	PRESENT	0
700099	698941	16685X	PARTICIPANT	\N	PRESENT	0
700100	698941	04042C	PRESIDENT	0	PRESENT	0
700101	698941	11054L	PARTICIPANT	\N	PRESENT	0
700102	698941	11066Q	PARTICIPANT	\N	PRESENT	0
700103	698941	08056B	PARTICIPANT	\N	PRESENT	0
700104	698941	12028B	PARTICIPANT	\N	PRESENT	0
700105	698941	11115U	PARTICIPANT	\N	PRESENT	0
700106	698941	19421M	PARTICIPANT	\N	PRESENT	0
700107	698941	19347U	PARTICIPANT	\N	PRESENT	0
700108	698941	07033P	PARTICIPANT	\N	PRESENT	0
700109	698941	97011G	PARTICIPANT	\N	PRESENT	0
700110	698941	08061X	PARTICIPANT	\N	PRESENT	0
700111	698941	14249W	PARTICIPANT	\N	PRESENT	0
700112	698941	08047A	PARTICIPANT	\N	PRESENT	0
700113	698941	20128B	PARTICIPANT	\N	PRESENT	0
700114	698941	14059S	PARTICIPANT	\N	PRESENT	0
700115	698941	14097Y	PARTICIPANT	\N	PRESENT	0
700116	698941	04035D	PARTICIPANT	\N	PRESENT	0
700117	698941	14133K	PARTICIPANT	\N	PRESENT	0
700118	698941	01062T	PARTICIPANT	\N	PRESENT	0
700119	698941	08069G	PARTICIPANT	\N	PRESENT	0
700120	698941	11041F	PARTICIPANT	\N	PRESENT	0
700121	698941	20042V	PARTICIPANT	\N	PRESENT	0
700122	698941	01024M	PARTICIPANT	\N	PRESENT	0
700123	698941	14191V	PARTICIPANT	\N	PRESENT	0
700124	698941	19319Q	PARTICIPANT	\N	PRESENT	0
700125	698941	20064C	PARTICIPANT	\N	PRESENT	0
700126	698941	98022P	PARTICIPANT	\N	PRESENT	0
700127	698941	14267Y	PARTICIPANT	\N	PRESENT	0
700128	698941	11064N	PARTICIPANT	\N	PRESENT	0
700129	698941	11083R	PARTICIPANT	\N	PRESENT	0
700130	698941	14211G	PARTICIPANT	\N	PRESENT	0
700131	698942	12041X	PARTICIPANT	\N	PRESENT	0
700132	698942	11080N	PARTICIPANT	\N	PRESENT	0
700133	698942	20072C	PARTICIPANT	\N	PRESENT	0
700134	698942	01058X	PARTICIPANT	\N	PRESENT	0
700135	698942	16685X	PARTICIPANT	\N	PRESENT	0
700136	698942	04042C	PRESIDENT	0	PRESENT	0
700137	698942	11054L	PARTICIPANT	\N	PRESENT	0
700138	698942	11066Q	PARTICIPANT	\N	PRESENT	0
700139	698942	08056B	PARTICIPANT	\N	PRESENT	0
700140	698942	12028B	PARTICIPANT	\N	PRESENT	0
700141	698942	11115U	PARTICIPANT	\N	PRESENT	0
700142	698942	19421M	PARTICIPANT	\N	PRESENT	0
700143	698942	19709B	PARTICIPANT	\N	PRESENT	0
700144	698942	19347U	PARTICIPANT	\N	PRESENT	0
700145	698942	14193X	PARTICIPANT	\N	PRESENT	0
700146	698942	07033P	PARTICIPANT	\N	PRESENT	0
700147	698942	97011G	PARTICIPANT	\N	PRESENT	0
700148	698942	08061X	PARTICIPANT	\N	PRESENT	0
700149	698942	14249W	PARTICIPANT	\N	PRESENT	0
700150	698942	08047A	PARTICIPANT	\N	PRESENT	0
700151	698942	20128B	PARTICIPANT	\N	PRESENT	0
700152	698942	14059S	PARTICIPANT	\N	PRESENT	0
700153	698942	14097Y	PARTICIPANT	\N	PRESENT	0
700154	698942	04035D	PARTICIPANT	\N	PRESENT	0
700155	698942	14133K	PARTICIPANT	\N	PRESENT	0
700156	698942	01062T	PARTICIPANT	\N	PRESENT	0
700157	698942	08069G	PARTICIPANT	\N	PRESENT	0
700158	698942	11041F	PARTICIPANT	\N	PRESENT	0
700159	698942	20042V	PARTICIPANT	\N	PRESENT	0
700160	698942	01024M	PARTICIPANT	\N	PRESENT	0
700161	698942	14191V	PARTICIPANT	\N	PRESENT	0
700162	698942	19319Q	PARTICIPANT	\N	PRESENT	0
700163	698942	20064C	PARTICIPANT	\N	PRESENT	0
700164	698942	98022P	PARTICIPANT	\N	PRESENT	0
700165	698942	14267Y	PARTICIPANT	\N	PRESENT	0
700166	698942	11064N	PARTICIPANT	\N	PRESENT	0
700167	698942	11083R	PARTICIPANT	\N	PRESENT	0
700168	698942	14211G	PARTICIPANT	\N	PRESENT	0
700169	698942	14255U	PARTICIPANT	\N	PRESENT	0
700170	698942	17023S	PARTICIPANT	\N	PRESENT	0
700171	698938	19585H	PARTICIPANT	\N	PRESENT	0
700172	698938	14231L	PARTICIPANT	\N	PRESENT	0
700173	698938	14179A	PARTICIPANT	\N	PRESENT	0
700174	698938	11085T	PARTICIPANT	\N	PRESENT	0
700175	695332	19333N	PARTICIPANT	\N	PRESENT	0
700176	695332	19701S	PARTICIPANT	\N	PRESENT	0
700177	695332	19549D	PARTICIPANT	\N	PRESENT	0
700178	695332	20076G	PARTICIPANT	\N	PRESENT	0
700179	695332	19387D	PARTICIPANT	\N	PRESENT	0
700180	695332	19820Y	PARTICIPANT	\N	PRESENT	0
700181	695332	14219Q	PRESIDENT	0	PRESENT	0
700182	695332	19826F	PARTICIPANT	\N	PRESENT	0
700183	695332	20102Q	PARTICIPANT	\N	PRESENT	0
700184	695332	20096L	PARTICIPANT	\N	PRESENT	0
700185	695332	20100N	PARTICIPANT	\N	PRESENT	0
700186	695332	18083K	PARTICIPANT	\N	PRESENT	0
700187	695332	05012A	PARTICIPANT	\N	PRESENT	0
700188	695332	08060W	PARTICIPANT	\N	PRESENT	0
688827	688826	14053L	PARTICIPANT	\N	PRESENT	0
688828	688826	04085P	PARTICIPANT	\N	PRESENT	0
688829	688826	14151M	PARTICIPANT	\N	PRESENT	0
688830	688826	19543W	PARTICIPANT	\N	PRESENT	0
688832	688831	14053L	PARTICIPANT	\N	PRESENT	0
688833	688831	04085P	PARTICIPANT	\N	PRESENT	0
688834	688831	14151M	PARTICIPANT	\N	PRESENT	0
688835	688831	19543W	PARTICIPANT	\N	PRESENT	0
688836	688831	11033F	PARTICIPANT	\N	PRESENT	0
688838	688837	14053L	PARTICIPANT	\N	PRESENT	0
688839	688837	04085P	PARTICIPANT	\N	PRESENT	0
688840	688837	19543W	PARTICIPANT	\N	PRESENT	0
689193	689192	14151M	PARTICIPANT	\N	PRESENT	0
689194	689192	20022R	PARTICIPANT	\N	PRESENT	0
690799	690798	20128B	PARTICIPANT	\N	PRESENT	0
692241	692239	14205J	PARTICIPANT	\N	PRESENT	0
692242	692240	14205J	PARTICIPANT	\N	PRESENT	0
692243	690791	04042C	PRESIDENT	0	PRESENT	0
692244	690791	01062T	PARTICIPANT	\N	PRESENT	0
692245	690791	11041F	PARTICIPANT	\N	PRESENT	0
692246	690791	11064N	PARTICIPANT	\N	PRESENT	0
692247	690791	07033P	PARTICIPANT	\N	PRESENT	0
692248	690791	01024M	PARTICIPANT	\N	PRESENT	0
692249	690791	20042V	PARTICIPANT	\N	PRESENT	0
692250	690791	11083R	PARTICIPANT	\N	PRESENT	0
692251	690791	14059S	PARTICIPANT	\N	PRESENT	0
692252	690791	14089Y	PARTICIPANT	\N	PRESENT	0
692253	690791	04047H	PARTICIPANT	\N	PRESENT	0
692254	690791	20074E	PARTICIPANT	\N	PRESENT	0
692255	690791	14001X	PARTICIPANT	\N	PRESENT	0
692256	690791	14147R	PARTICIPANT	\N	PRESENT	0
692257	690791	20100N	PARTICIPANT	\N	PRESENT	0
692258	690791	08034U	PARTICIPANT	\N	PRESENT	0
692259	690791	19441R	PARTICIPANT	\N	PRESENT	0
692260	690791	14331P	PARTICIPANT	\N	PRESENT	0
692261	691860	11045K	PARTICIPANT	\N	PRESENT	0
692422	690785	04042C	PARTICIPANT	\N	PRESENT	0
692656	691220	11056N	PARTICIPANT	\N	EXCUSE	0
692675	691220	01028R	PARTICIPANT	\N	EXCUSE	0
692676	691220	04070G	PARTICIPANT	\N	EXCUSE	0
696226	694042	20082E	PARTICIPANT	\N	EXCUSE	0
698441	697954	20026V	PARTICIPANT	\N	PRESENT	0
698443	693586	14059S	PARTICIPANT	\N	EXCUSE	0
701786	701785	20132W	PARTICIPANT	\N	PRESENT	1
701787	701785	14229S	PARTICIPANT	\N	PRESENT	1
701793	701792	19631V	PARTICIPANT	\N	PRESENT	0
701794	701792	19515S	PARTICIPANT	\N	PRESENT	0
701795	701792	20078J	PARTICIPANT	\N	PRESENT	0
701799	701792	19768N	PARTICIPANT	\N	PRESENT	0
701797	701792	19467C	PARTICIPANT	\N	PRESENT	0
701798	701792	14187A	PARTICIPANT	\N	PRESENT	0
701800	701792	20030R	PARTICIPANT	\N	PRESENT	0
701801	701792	19705W	PARTICIPANT	\N	PRESENT	0
701802	701792	11090Q	PARTICIPANT	\N	PRESENT	0
701803	701792	19621T	PARTICIPANT	\N	PRESENT	0
701804	701792	20138D	PARTICIPANT	\N	PRESENT	0
701819	701817	19503N	PARTICIPANT	\N	PRESENT	0
703766	702922	19798U	PARTICIPANT	\N	PRESENT	0
703767	702922	14030Q	PRESIDENT	0	PRESENT	0
703768	702922	20066E	PARTICIPANT	\N	PRESENT	0
703769	702922	14109K	PARTICIPANT	\N	PRESENT	0
703770	702922	11031D	PARTICIPANT	\N	PRESENT	0
703771	702922	11045K	PARTICIPANT	\N	PRESENT	0
703772	702922	19715Y	PARTICIPANT	\N	PRESENT	0
708806	708803	20248J	PARTICIPANT	\N	PRESENT	0
708807	708803	20114U	PARTICIPANT	\N	PRESENT	0
708808	708803	19826F	PARTICIPANT	\N	PRESENT	0
708809	708803	14205J	PARTICIPANT	\N	PRESENT	0
708810	708803	19503N	PARTICIPANT	\N	PRESENT	0
708811	708803	19725B	PARTICIPANT	\N	PRESENT	0
708812	708803	20026V	PARTICIPANT	\N	PRESENT	0
708813	708803	19723Y	PARTICIPANT	\N	PRESENT	0
708814	708803	16685X	PARTICIPANT	\N	PRESENT	0
708815	708803	19820Y	PARTICIPANT	\N	PRESENT	0
708817	708816	20054A	PARTICIPANT	\N	PRESENT	0
708818	708816	20076G	PARTICIPANT	\N	PRESENT	0
708819	708816	20248J	PARTICIPANT	\N	PRESENT	0
708820	708816	20114U	PARTICIPANT	\N	PRESENT	0
708821	708816	19826F	PARTICIPANT	\N	PRESENT	0
708822	708816	14205J	PARTICIPANT	\N	PRESENT	0
708823	708816	19503N	PARTICIPANT	\N	PRESENT	0
708824	708816	19725B	PARTICIPANT	\N	PRESENT	0
708825	708816	19723Y	PARTICIPANT	\N	PRESENT	0
708826	708816	16685X	PARTICIPANT	\N	PRESENT	0
708827	708816	19820Y	PARTICIPANT	\N	PRESENT	0
708828	708816	19719D	PARTICIPANT	\N	PRESENT	0
708830	708829	20054A	PARTICIPANT	\N	PRESENT	0
708831	708829	20076G	PARTICIPANT	\N	PRESENT	0
708832	708829	20142Y	PARTICIPANT	\N	PRESENT	0
708833	708829	20248J	PARTICIPANT	\N	PRESENT	0
708834	708829	20114U	PARTICIPANT	\N	PRESENT	0
708835	708829	19826F	PARTICIPANT	\N	PRESENT	0
708836	708829	14205J	PARTICIPANT	\N	PRESENT	0
708837	708829	19503N	PARTICIPANT	\N	PRESENT	0
708838	708829	19725B	PARTICIPANT	\N	PRESENT	0
708839	708829	19723Y	PARTICIPANT	\N	PRESENT	0
708840	708829	16685X	PARTICIPANT	\N	PRESENT	0
708841	708829	19820Y	PARTICIPANT	\N	PRESENT	0
708842	708829	19719D	PARTICIPANT	\N	PRESENT	0
708843	706234	11010L	PARTICIPANT	\N	EXCUSE	0
708896	706245	20248J	PARTICIPANT	\N	PRESENT	0
709115	708148	19533U	PARTICIPANT	\N	PRESENT	0
709116	708148	04085P	PARTICIPANT	\N	PRESENT	0
709117	708148	14089Y	PARTICIPANT	\N	PRESENT	0
709118	708148	07033P	PARTICIPANT	\N	PRESENT	0
709119	708148	20042V	PARTICIPANT	\N	PRESENT	0
709120	708148	04070G	PARTICIPANT	\N	PRESENT	0
709121	708148	11043H	PARTICIPANT	\N	PRESENT	0
709575	708473	19711U	PARTICIPANT	\N	PRESENT	0
709581	708473	19335Q	PARTICIPANT	\N	PRESENT	0
709566	708473	11074Q	PARTICIPANT	\N	PRESENT	0
709582	709564	11031D	PARTICIPANT	\N	PRESENT	0
709568	708473	14225N	PRESIDENT	0	PRESENT	0
709583	709564	19760E	PARTICIPANT	\N	PRESENT	0
709571	708473	14327T	PARTICIPANT	\N	PRESENT	0
709572	708473	11040E	PARTICIPANT	\N	PRESENT	0
709573	708473	11048N	PARTICIPANT	\N	PRESENT	0
709574	708473	11070L	PARTICIPANT	\N	PRESENT	0
709576	708473	20050V	PARTICIPANT	\N	PRESENT	0
709577	708473	14253S	PARTICIPANT	\N	PRESENT	0
709578	708473	19671E	PARTICIPANT	\N	PRESENT	0
709579	708473	19349W	PARTICIPANT	\N	PRESENT	0
709584	709564	11045K	PARTICIPANT	\N	PRESENT	0
709585	709564	18193Q	PARTICIPANT	\N	PRESENT	0
709586	709564	11067R	PARTICIPANT	\N	PRESENT	0
709587	709564	17779H	PARTICIPANT	\N	PRESENT	0
709588	709564	11097X	PARTICIPANT	\N	PRESENT	0
709589	709564	14042U	PARTICIPANT	\N	PRESENT	0
709590	709564	04092N	PARTICIPANT	\N	PRESENT	0
709591	709564	19723Y	PARTICIPANT	\N	PRESENT	0
709592	709564	19553Y	PARTICIPANT	\N	PRESENT	0
709593	709564	19713W	PARTICIPANT	\N	PRESENT	0
709594	709564	19569H	PARTICIPANT	\N	PRESENT	0
709595	709564	19657G	PARTICIPANT	\N	PRESENT	0
709596	709564	20066E	PARTICIPANT	\N	PRESENT	0
709597	709564	19691J	PARTICIPANT	\N	PRESENT	0
709598	709564	19415P	PARTICIPANT	\N	PRESENT	0
709599	709564	14223L	PARTICIPANT	\N	PRESENT	0
709600	709564	14071N	PARTICIPANT	\N	PRESENT	0
709601	709564	19703U	PARTICIPANT	\N	PRESENT	0
709602	709564	19367Y	PARTICIPANT	\N	PRESENT	0
709603	709564	19798U	PARTICIPANT	\N	PRESENT	0
709604	709564	14026U	PARTICIPANT	\N	PRESENT	0
709605	709564	14213J	PARTICIPANT	\N	PRESENT	0
709606	709564	14217N	PARTICIPANT	\N	PRESENT	0
709607	709564	20090E	PARTICIPANT	\N	PRESENT	0
709608	709564	10006L	PRESIDENT	0	PRESENT	0
709609	709564	17965H	PARTICIPANT	\N	PRESENT	0
709610	706166	19593H	PARTICIPANT	\N	PRESENT	0
709611	706166	19766L	PARTICIPANT	\N	PRESENT	0
709612	706166	20132W	PARTICIPANT	\N	PRESENT	0
709613	706166	19699S	PARTICIPANT	\N	PRESENT	0
709614	706166	19651A	PARTICIPANT	\N	PRESENT	0
709615	706166	19611R	PRESIDENT	0	PRESENT	0
709616	706166	04033B	PARTICIPANT	\N	PRESENT	0
709617	706166	20142Y	PARTICIPANT	\N	PRESENT	0
709618	706166	01060R	PARTICIPANT	\N	PRESENT	0
709619	706166	19399H	PARTICIPANT	\N	PRESENT	0
709620	706166	20052X	PARTICIPANT	\N	PRESENT	0
693889	692533	19553Y	PARTICIPANT	\N	PRESENT	0
693890	692533	19591F	PARTICIPANT	\N	PRESENT	0
693891	692533	14213J	PARTICIPANT	\N	PRESENT	0
693892	692533	20066E	PARTICIPANT	\N	PRESENT	0
693893	692533	19511N	PARTICIPANT	\N	PRESENT	0
693894	692533	19569H	PARTICIPANT	\N	PRESENT	0
693895	692533	19683J	PARTICIPANT	\N	PRESENT	0
693896	692533	19723Y	PARTICIPANT	\N	PRESENT	0
693897	692533	18193Q	PARTICIPANT	\N	PRESENT	0
693898	692533	17779H	PARTICIPANT	\N	PRESENT	0
693899	692533	14223L	PARTICIPANT	\N	PRESENT	0
693900	692533	04043D	PARTICIPANT	\N	PRESENT	0
693901	692533	17965H	PARTICIPANT	\N	PRESENT	0
693902	692533	19679N	PARTICIPANT	\N	PRESENT	0
693903	692533	19798U	PARTICIPANT	\N	PRESENT	0
693904	692533	11097X	PARTICIPANT	\N	PRESENT	0
693905	692533	11045K	PARTICIPANT	\N	PRESENT	0
693906	692533	20130U	PARTICIPANT	\N	PRESENT	0
693907	692533	14071N	PARTICIPANT	\N	PRESENT	0
693908	692533	11067R	PARTICIPANT	\N	PRESENT	0
693909	692533	20266L	PARTICIPANT	\N	PRESENT	0
693910	692323	04035D	PARTICIPANT	\N	PRESENT	0
693911	692321	19489J	PARTICIPANT	\N	PRESENT	0
693912	692321	20110Q	PARTICIPANT	\N	PRESENT	0
693913	692321	14215L	PARTICIPANT	\N	PRESENT	0
693914	692321	08018U	PARTICIPANT	\N	PRESENT	0
693915	692321	14259Y	PARTICIPANT	\N	PRESENT	0
693916	692321	11026G	PARTICIPANT	\N	PRESENT	0
693917	692321	04085P	PARTICIPANT	\N	PRESENT	0
693918	692321	04008A	PARTICIPANT	\N	PRESENT	0
693919	692321	11085T	PARTICIPANT	\N	PRESENT	0
693920	692321	14231L	PARTICIPANT	\N	PRESENT	0
693925	692533	19697Q	PARTICIPANT	\N	PRESENT	0
693926	692533	11031D	PARTICIPANT	\N	PRESENT	0
693954	693928	19671E	PARTICIPANT	\N	PRESENT	0
693955	693928	20126Y	PARTICIPANT	\N	PRESENT	0
694049	691635	20098N	PARTICIPANT	\N	PRESENT	0
694050	693928	08011M	PARTICIPANT	\N	PRESENT	0
694052	692429	14275Y	PARTICIPANT	\N	PRESENT	0
694053	692429	20136B	PARTICIPANT	\N	PRESENT	0
694054	692429	20100N	PARTICIPANT	\N	PRESENT	0
694055	692429	11115U	PARTICIPANT	\N	PRESENT	0
694056	692429	19527W	PARTICIPANT	\N	PRESENT	0
694062	692429	98022P	PARTICIPANT	\N	PRESENT	0
694063	692429	14207L	PARTICIPANT	\N	PRESENT	0
694064	692429	17229F	PARTICIPANT	\N	PRESENT	0
694065	692429	11012A	PARTICIPANT	\N	PRESENT	0
694066	692429	19583F	PARTICIPANT	\N	PRESENT	0
694067	692429	14073Q	PARTICIPANT	\N	PRESENT	0
694069	692429	11104D	PARTICIPANT	\N	PRESENT	0
694070	692429	17779H	PARTICIPANT	\N	PRESENT	0
694071	692429	19619A	PARTICIPANT	\N	PRESENT	0
694072	692429	19721W	PARTICIPANT	\N	PRESENT	0
694073	692429	20042V	PARTICIPANT	\N	PRESENT	0
694074	692429	14195A	PARTICIPANT	\N	PRESENT	0
694075	692429	19565D	PARTICIPANT	\N	PRESENT	0
694076	692429	07004J	PARTICIPANT	\N	PRESENT	0
694077	692429	04057K	PARTICIPANT	\N	PRESENT	0
694078	692429	17737W	PARTICIPANT	\N	PRESENT	0
694079	692429	20020P	PARTICIPANT	\N	PRESENT	0
694080	692429	14191V	PARTICIPANT	\N	PRESENT	0
694081	692429	20980G	PARTICIPANT	\N	PRESENT	0
694082	692429	19251M	PARTICIPANT	\N	PRESENT	0
694083	692429	19573D	PARTICIPANT	\N	PRESENT	0
694084	692429	11067R	PARTICIPANT	\N	PRESENT	0
694086	692429	19782L	PARTICIPANT	\N	PRESENT	0
694087	692429	20130U	PARTICIPANT	\N	PRESENT	0
694088	692429	19629C	PARTICIPANT	\N	PRESENT	0
694089	692429	19866P	PARTICIPANT	\N	PRESENT	0
694090	692429	20072C	PARTICIPANT	\N	PRESENT	0
694091	692429	11066Q	PARTICIPANT	\N	PRESENT	0
694092	692429	11054L	PARTICIPANT	\N	PRESENT	0
694093	692429	99004R	PARTICIPANT	\N	PRESENT	0
694094	692429	04008A	PARTICIPANT	\N	PRESENT	0
694095	692429	19711U	PARTICIPANT	\N	PRESENT	0
694096	692429	12041X	PARTICIPANT	\N	PRESENT	0
694097	692429	04035D	PARTICIPANT	\N	PRESENT	0
694098	692429	19693L	PARTICIPANT	\N	PRESENT	0
694099	692429	19760E	PARTICIPANT	\N	PRESENT	0
694100	692429	19758L	PARTICIPANT	\N	PRESENT	0
694101	692429	08011M	PARTICIPANT	\N	PRESENT	0
694102	692429	19575F	PARTICIPANT	\N	PRESENT	0
694103	692429	04085P	PARTICIPANT	\N	PRESENT	0
694104	692429	19593H	PARTICIPANT	\N	PRESENT	0
694105	692429	08010L	PARTICIPANT	\N	PRESENT	0
694106	692429	20110Q	PARTICIPANT	\N	PRESENT	0
694107	692429	20914V	PARTICIPANT	\N	PRESENT	0
694108	692429	19679N	PARTICIPANT	\N	PRESENT	0
694109	692429	11065P	PARTICIPANT	\N	PRESENT	0
694110	692429	20142Y	PARTICIPANT	\N	PRESENT	0
694111	692429	20078J	PARTICIPANT	\N	PRESENT	0
694112	692429	20076G	PARTICIPANT	\N	PRESENT	0
694113	692429	20102Q	PARTICIPANT	\N	PRESENT	0
694114	692429	14038Y	PARTICIPANT	\N	PRESENT	0
694115	692429	20046A	PARTICIPANT	\N	PRESENT	0
694116	692429	20112S	PARTICIPANT	\N	PRESENT	0
694117	692429	20086J	PARTICIPANT	\N	PRESENT	0
694118	692429	20044X	PARTICIPANT	\N	PRESENT	0
694119	692429	11040E	PARTICIPANT	\N	PRESENT	0
694120	692429	20058E	PARTICIPANT	\N	PRESENT	0
694121	692429	19467C	PARTICIPANT	\N	PRESENT	0
694122	692429	20092G	PARTICIPANT	\N	PRESENT	0
694123	692429	20056C	PARTICIPANT	\N	PRESENT	0
694124	692429	20098N	PARTICIPANT	\N	PRESENT	0
694125	692429	11031D	PARTICIPANT	\N	PRESENT	0
694126	692429	19525U	PARTICIPANT	\N	PRESENT	0
694127	692429	11083R	PARTICIPANT	\N	PRESENT	0
694128	692429	08018U	PARTICIPANT	\N	PRESENT	0
694129	692429	20128B	PARTICIPANT	\N	PRESENT	0
694130	692429	07029T	PARTICIPANT	\N	PRESENT	0
694131	692429	14037X	PARTICIPANT	\N	PRESENT	0
694132	692429	19697Q	PARTICIPANT	\N	PRESENT	0
694133	692429	20038A	PARTICIPANT	\N	PRESENT	0
694134	692429	14173T	PARTICIPANT	\N	PRESENT	0
694135	692429	08061X	PARTICIPANT	\N	PRESENT	0
694136	692429	11080N	PARTICIPANT	\N	PRESENT	0
694137	692429	19349W	PARTICIPANT	\N	PRESENT	0
694138	692429	14031R	PARTICIPANT	\N	PRESENT	0
694139	692429	19667J	PARTICIPANT	\N	PRESENT	0
694140	692429	19399H	PARTICIPANT	\N	PRESENT	0
694141	692429	20096L	PARTICIPANT	\N	PRESENT	0
694142	692429	20026V	PARTICIPANT	\N	PRESENT	0
694143	692429	19347U	PARTICIPANT	\N	PRESENT	0
694144	692429	08073C	PARTICIPANT	\N	PRESENT	0
694145	692429	14259Y	PARTICIPANT	\N	PRESENT	0
694146	692429	95063L	PARTICIPANT	\N	PRESENT	0
694147	692429	19766L	PARTICIPANT	\N	PRESENT	0
694148	692429	04045F	PARTICIPANT	\N	PRESENT	0
694149	692429	19301E	PARTICIPANT	\N	PRESENT	0
694150	692429	01057W	PARTICIPANT	\N	PRESENT	0
694151	692429	19515S	PARTICIPANT	\N	PRESENT	0
694152	692429	17637T	PARTICIPANT	\N	PRESENT	0
694153	692429	19768N	PARTICIPANT	\N	PRESENT	0
694154	692429	20104S	PARTICIPANT	\N	PRESENT	0
694155	692429	08015R	PARTICIPANT	\N	PRESENT	0
694156	692429	19729F	PARTICIPANT	\N	PRESENT	0
694157	692429	19591F	PARTICIPANT	\N	PRESENT	0
694158	692429	20108W	PARTICIPANT	\N	PRESENT	0
694159	692429	20148F	PARTICIPANT	\N	PRESENT	0
694160	692429	20024T	PARTICIPANT	\N	PRESENT	0
694161	692429	14213J	PARTICIPANT	\N	PRESENT	0
694162	692429	19707Y	PARTICIPANT	\N	PRESENT	0
694163	692429	20116W	PARTICIPANT	\N	PRESENT	0
694164	692429	19723Y	PARTICIPANT	\N	PRESENT	0
694165	692429	19719D	PARTICIPANT	\N	PRESENT	0
694166	692429	19705W	PARTICIPANT	\N	PRESENT	0
694167	692429	19387D	PARTICIPANT	\N	PRESENT	0
694168	692429	10015M	PARTICIPANT	\N	PRESENT	0
694169	692429	19553Y	PARTICIPANT	\N	PRESENT	0
694170	692429	19545Y	PARTICIPANT	\N	PRESENT	0
694171	692429	14253S	PARTICIPANT	\N	PRESENT	0
694172	692429	14251Q	PARTICIPANT	\N	PRESENT	0
694173	692429	20032T	PARTICIPANT	\N	PRESENT	0
694174	692429	14331P	PARTICIPANT	\N	PRESENT	0
694175	692429	14221J	PARTICIPANT	\N	PRESENT	0
694176	692429	04043D	PARTICIPANT	\N	PRESENT	0
694177	692429	20050V	PARTICIPANT	\N	PRESENT	0
694178	692429	14059S	PARTICIPANT	\N	PRESENT	0
694179	692429	19673G	PARTICIPANT	\N	PRESENT	0
694180	692429	20022R	PARTICIPANT	\N	PRESENT	0
694181	692429	20068G	PARTICIPANT	\N	PRESENT	0
684275	682296	18193Q	PARTICIPANT	\N	PRESENT	0
684276	682296	17779H	PARTICIPANT	\N	PRESENT	0
684277	682296	20130U	PARTICIPANT	\N	PRESENT	0
684278	682296	01034P	PARTICIPANT	\N	PRESENT	0
684279	682296	11097X	PRESIDENT	0	PRESENT	0
684280	682296	04092N	PARTICIPANT	\N	PRESENT	0
684281	682296	14213J	PARTICIPANT	\N	EXCUSE	0
684282	682296	14195A	PARTICIPANT	\N	EXCUSE	0
684283	682296	14042U	PARTICIPANT	\N	PRESENT	0
684284	682296	19569H	PARTICIPANT	\N	PRESENT	0
684291	682296	14071N	PARTICIPANT	\N	PRESENT	0
685689	683228	20052X	PARTICIPANT	\N	PRESENT	0
685690	683228	19619A	PARTICIPANT	\N	PRESENT	0
685691	683228	19647E	PARTICIPANT	\N	PRESENT	0
685692	683228	19721W	PARTICIPANT	\N	PRESENT	0
685693	683228	19479G	PARTICIPANT	\N	PRESENT	0
685694	683228	14219Q	PARTICIPANT	\N	PRESENT	0
685695	683228	20286Q	PARTICIPANT	\N	PRESENT	0
685696	683228	19577H	PARTICIPANT	\N	PRESENT	0
685697	683228	19739H	PARTICIPANT	\N	PRESENT	0
685698	683228	16685X	PARTICIPANT	\N	PRESENT	0
685699	683228	14205J	PARTICIPANT	\N	PRESENT	0
685700	683228	20144B	PARTICIPANT	\N	PRESENT	0
685701	683228	11053K	PARTICIPANT	\N	PRESENT	0
685702	683228	19369B	PARTICIPANT	\N	PRESENT	0
685703	683228	19611R	PARTICIPANT	\N	PRESENT	0
685704	683228	19691J	PARTICIPANT	\N	PRESENT	0
685705	683228	19745F	PARTICIPANT	\N	PRESENT	0
685706	683228	17229F	PARTICIPANT	\N	PRESENT	0
685707	683228	14231L	PARTICIPANT	\N	PRESENT	0
685708	683228	14267Y	PARTICIPANT	\N	PRESENT	0
685709	683228	19699S	PARTICIPANT	\N	PRESENT	0
685710	683228	14089Y	PARTICIPANT	\N	PRESENT	0
685711	683228	14083S	PARTICIPANT	\N	PRESENT	0
685712	683228	14073Q	PARTICIPANT	\N	PRESENT	0
685713	683228	20248J	PARTICIPANT	\N	PRESENT	0
685714	683228	19826F	PARTICIPANT	\N	PRESENT	0
685715	683228	11070L	PARTICIPANT	\N	PRESENT	0
685716	683228	20040T	PARTICIPANT	\N	PRESENT	0
685717	683228	14255U	PARTICIPANT	\N	PRESENT	0
685718	683228	14189C	PARTICIPANT	\N	PRESENT	0
685719	683228	11085T	PARTICIPANT	\N	PRESENT	0
685720	683228	20066E	PARTICIPANT	\N	PRESENT	0
685721	683228	04070G	PARTICIPANT	\N	PRESENT	0
685722	683228	14151M	PARTICIPANT	\N	PRESENT	0
685723	683228	01025N	PARTICIPANT	\N	PRESENT	0
685724	683228	01024M	PARTICIPANT	\N	PRESENT	0
685725	683228	14327T	PARTICIPANT	\N	PRESENT	0
685726	683228	14030Q	PARTICIPANT	\N	PRESENT	0
685727	683228	08073C	PARTICIPANT	\N	PRESENT	0
685728	683228	19717B	PARTICIPANT	\N	PRESENT	0
685729	683228	14055N	PARTICIPANT	\N	PRESENT	0
685730	683228	08060W	PARTICIPANT	\N	PRESENT	0
685731	683228	08011M	PARTICIPANT	\N	PRESENT	0
685732	683228	20094J	PARTICIPANT	\N	PRESENT	0
685733	683228	19715Y	PARTICIPANT	\N	PRESENT	0
685739	683228	19671E	PARTICIPANT	\N	PRESENT	0
685735	683228	11056N	PARTICIPANT	\N	PRESENT	0
685736	683228	04071H	PARTICIPANT	\N	PRESENT	0
685737	683228	20108W	PARTICIPANT	\N	PRESENT	0
685738	683228	14179A	PARTICIPANT	\N	PRESENT	0
685740	683228	19347U	PARTICIPANT	\N	PRESENT	0
685742	683228	11040E	PARTICIPANT	\N	PRESENT	0
685743	683228	19687N	PARTICIPANT	\N	PRESENT	0
685744	683228	14195A	PARTICIPANT	\N	PRESENT	0
685745	683228	14251Q	PARTICIPANT	\N	PRESENT	0
685746	683228	11064N	PARTICIPANT	\N	PRESENT	0
685747	683228	19511N	PARTICIPANT	\N	PRESENT	0
685748	683228	14237S	PARTICIPANT	\N	PRESENT	0
685749	683228	19295A	PARTICIPANT	\N	PRESENT	0
685750	683228	19599P	PARTICIPANT	\N	PRESENT	0
685751	683228	19725B	PARTICIPANT	\N	PRESENT	0
685752	683228	11110B	PARTICIPANT	\N	PRESENT	0
685753	683228	20048C	PARTICIPANT	\N	PRESENT	0
685754	683228	19667J	PARTICIPANT	\N	PRESENT	0
685755	683228	20022R	PARTICIPANT	\N	PRESENT	0
685756	683228	14038Y	PARTICIPANT	\N	PRESENT	0
686049	683229	19719D	PARTICIPANT	\N	PRESENT	0
686050	683229	19691J	PARTICIPANT	\N	PRESENT	0
686051	683229	14327T	PARTICIPANT	\N	PRESENT	0
686052	683229	19479G	PARTICIPANT	\N	PRESENT	0
686053	683229	20020P	PARTICIPANT	\N	PRESENT	0
686054	683229	20090E	PARTICIPANT	\N	PRESENT	0
686055	683229	17737W	PARTICIPANT	\N	PRESENT	0
686056	683229	20136B	PARTICIPANT	\N	PRESENT	0
686057	683229	19467C	PARTICIPANT	\N	PRESENT	0
686058	683229	20092G	PARTICIPANT	\N	PRESENT	0
686059	683229	14121F	PARTICIPANT	\N	PRESENT	0
686060	683229	19695N	PARTICIPANT	\N	PRESENT	0
686061	683229	19251M	PARTICIPANT	\N	PRESENT	0
686062	683229	20120S	PARTICIPANT	\N	PRESENT	0
686063	683229	14191V	PARTICIPANT	\N	PRESENT	0
686064	683229	20252E	PARTICIPANT	\N	PRESENT	0
686065	683229	19619A	PARTICIPANT	\N	PRESENT	0
686066	683229	19369B	PARTICIPANT	\N	PRESENT	0
686067	683229	20298U	PARTICIPANT	\N	PRESENT	0
686068	683229	19758L	PARTICIPANT	\N	PRESENT	0
686069	683229	20046A	PARTICIPANT	\N	PRESENT	0
686070	683229	20102Q	PARTICIPANT	\N	PRESENT	0
686071	683229	14211G	PARTICIPANT	\N	PRESENT	0
686072	683229	14207L	PARTICIPANT	\N	PRESENT	0
686073	683229	19629C	PARTICIPANT	\N	PRESENT	0
686074	683229	19866P	PARTICIPANT	\N	PRESENT	0
686075	683229	14187A	PARTICIPANT	\N	PRESENT	0
686076	683229	20024T	PARTICIPANT	\N	PRESENT	0
686077	683229	14069U	PARTICIPANT	\N	PRESENT	0
686078	683229	10015M	PARTICIPANT	\N	PRESENT	0
686079	683229	19515S	PARTICIPANT	\N	PRESENT	0
686080	683229	14038Y	PARTICIPANT	\N	PRESENT	0
686081	683229	20034V	PARTICIPANT	\N	PRESENT	0
686082	683229	19747H	PARTICIPANT	\N	PRESENT	0
686083	683229	19333N	PARTICIPANT	\N	PRESENT	0
686084	683229	19413M	PARTICIPANT	\N	PRESENT	0
686085	683229	01024M	PARTICIPANT	\N	PRESENT	0
686086	683229	08056B	PARTICIPANT	\N	PRESENT	0
686087	683229	19798U	PARTICIPANT	\N	PRESENT	0
686088	683229	11056N	PARTICIPANT	\N	PRESENT	0
686089	683229	11077T	PARTICIPANT	\N	PRESENT	0
686090	683229	20062A	PARTICIPANT	\N	PRESENT	0
686091	683229	11090Q	PARTICIPANT	\N	PRESENT	0
686092	683229	19599P	PARTICIPANT	\N	PRESENT	0
686093	683229	14147R	PARTICIPANT	\N	PRESENT	0
686094	683229	20048C	PARTICIPANT	\N	PRESENT	0
686095	683229	18193Q	PARTICIPANT	\N	PRESENT	0
686096	681118	19593H	PARTICIPANT	\N	PRESENT	0
686097	681118	20132W	PARTICIPANT	\N	PRESENT	0
686098	681118	19611R	PRESIDENT	0	PRESENT	0
686099	681118	20138D	PARTICIPANT	\N	PRESENT	0
686100	681118	20142Y	PARTICIPANT	\N	PRESENT	0
686101	681118	19693L	PARTICIPANT	\N	PRESENT	0
686102	681118	19399H	PARTICIPANT	\N	PRESENT	0
686103	681118	14229S	PARTICIPANT	\N	PRESENT	0
686104	681118	20180F	PARTICIPANT	\N	PRESENT	0
686105	681118	04059M	PARTICIPANT	\N	PRESENT	0
686106	681118	20264J	PARTICIPANT	\N	PRESENT	0
686107	681118	20112S	PARTICIPANT	\N	PRESENT	0
686108	681118	08012N	PARTICIPANT	\N	PRESENT	0
686109	681118	20016T	PARTICIPANT	\N	PRESENT	0
686110	681118	20084G	PARTICIPANT	\N	PRESENT	0
686111	681118	11109J	PARTICIPANT	\N	EXCUSE	0
686112	683229	20030R	PARTICIPANT	\N	PRESENT	0
686113	683229	19687N	PARTICIPANT	\N	PRESENT	0
686114	683229	12041X	PARTICIPANT	\N	PRESENT	0
686115	683229	18083K	PARTICIPANT	\N	PRESENT	0
686116	683229	19591F	PARTICIPANT	\N	PRESENT	0
686117	683229	14089Y	PARTICIPANT	\N	PRESENT	0
686118	683229	19533U	PARTICIPANT	\N	PRESENT	0
686119	683229	19782L	PARTICIPANT	\N	PRESENT	0
686120	683229	20128B	PARTICIPANT	\N	PRESENT	0
686121	683229	20126Y	PARTICIPANT	\N	PRESENT	0
686122	683229	01058X	PARTICIPANT	\N	PRESENT	0
686123	683229	14073Q	PARTICIPANT	\N	PRESENT	0
686124	683229	14031R	PARTICIPANT	\N	PRESENT	0
686125	683229	19631V	PARTICIPANT	\N	PRESENT	0
686126	683229	20172F	PARTICIPANT	\N	PRESENT	0
686127	683229	14021P	PARTICIPANT	\N	PRESENT	0
686128	683229	08015R	PARTICIPANT	\N	PRESENT	0
686129	683229	20098N	PARTICIPANT	\N	PRESENT	0
686131	683229	20042V	PARTICIPANT	\N	PRESENT	0
686132	683229	11031D	PARTICIPANT	\N	PRESENT	0
686133	683229	07029T	PARTICIPANT	\N	PRESENT	0
698773	698772	20090E	PARTICIPANT	\N	PRESENT	0
698774	698772	19691J	PARTICIPANT	\N	PRESENT	0
698775	698772	14281W	PARTICIPANT	\N	PRESENT	0
698777	698776	20090E	PARTICIPANT	\N	PRESENT	0
698778	698776	19691J	PARTICIPANT	\N	PRESENT	0
698779	698776	14281W	PARTICIPANT	\N	PRESENT	0
700092	700091	20094J	PARTICIPANT	\N	PRESENT	0
700093	700091	19549D	PARTICIPANT	\N	PRESENT	0
700094	700091	20092G	PARTICIPANT	\N	PRESENT	0
700189	695332	20106U	PARTICIPANT	\N	PRESENT	0
700190	695332	20118Y	PARTICIPANT	\N	PRESENT	0
700191	695332	19503N	PARTICIPANT	\N	PRESENT	0
700192	695332	20020P	PARTICIPANT	\N	PRESENT	0
700193	695332	19685L	PARTICIPANT	\N	PRESENT	0
700194	695332	17367Q	PARTICIPANT	\N	PRESENT	0
700195	695332	19681G	PARTICIPANT	\N	PRESENT	0
700196	695332	17637T	PARTICIPANT	\N	PRESENT	0
700197	695332	19525U	PARTICIPANT	\N	PRESENT	0
700198	695332	20120S	PARTICIPANT	\N	PRESENT	0
700199	695332	20136B	PARTICIPANT	\N	PRESENT	0
700200	695332	14031R	PARTICIPANT	\N	PRESENT	0
700201	695332	20038A	PARTICIPANT	\N	PRESENT	0
700202	695332	20140W	PARTICIPANT	\N	PRESENT	0
700203	695332	19251M	PARTICIPANT	\N	PRESENT	0
700204	695332	20146D	PARTICIPANT	\N	PRESENT	0
700205	695332	20046A	PARTICIPANT	\N	PRESENT	0
700206	695332	17229F	PARTICIPANT	\N	PRESENT	0
700207	695332	14169X	PARTICIPANT	\N	PRESENT	0
700208	695332	20068G	PARTICIPANT	\N	PRESENT	0
700209	695332	11101A	PARTICIPANT	\N	PRESENT	0
700210	695332	19739H	PARTICIPANT	\N	PRESENT	0
700211	695332	19745F	PARTICIPANT	\N	PRESENT	0
700212	695332	19619A	PARTICIPANT	\N	PRESENT	0
700213	695332	14038Y	PARTICIPANT	\N	PRESENT	0
700214	699097	19383Y	PARTICIPANT	\N	PRESENT	0
700215	699097	19768N	PARTICIPANT	\N	PRESENT	0
700216	699097	19515S	PARTICIPANT	\N	PRESENT	0
700217	699097	20092G	PARTICIPANT	\N	PRESENT	0
700218	699097	19782L	PARTICIPANT	\N	PRESENT	0
700219	699097	11077T	PARTICIPANT	\N	PRESENT	0
700220	699097	14357A	PARTICIPANT	\N	PRESENT	0
700221	699097	20078J	PARTICIPANT	\N	PRESENT	0
700222	699097	20094J	PARTICIPANT	\N	PRESENT	0
700223	699097	19667J	PARTICIPANT	\N	PRESENT	0
700224	699097	04045F	PARTICIPANT	\N	PRESENT	0
700225	699097	20104S	PARTICIPANT	\N	PRESENT	0
700226	699097	19705W	PARTICIPANT	\N	PRESENT	0
700227	699097	08015R	PARTICIPANT	\N	PRESENT	0
700228	699097	19369B	PARTICIPANT	\N	PRESENT	0
700229	699097	20018V	PARTICIPANT	\N	PRESENT	0
700230	699097	08028W	PARTICIPANT	\N	PRESENT	0
700231	699097	19563B	PARTICIPANT	\N	PRESENT	0
700232	699097	20028X	PARTICIPANT	\N	PRESENT	0
700233	699097	20030R	PARTICIPANT	\N	PRESENT	0
700234	699097	14038Y	PARTICIPANT	\N	PRESENT	0
700235	699097	19467C	PARTICIPANT	\N	PRESENT	0
700236	699097	20034V	PARTICIPANT	\N	PRESENT	0
700237	699097	14187A	PARTICIPANT	\N	PRESENT	0
700238	699097	20144B	PARTICIPANT	\N	PRESENT	0
700239	699097	19695N	PARTICIPANT	\N	PRESENT	0
700240	699097	14033T	PARTICIPANT	\N	PRESENT	0
700241	699097	11090Q	PRESIDENT	0	PRESENT	0
700242	699097	20054A	PARTICIPANT	\N	PRESENT	0
700243	699097	14205J	PARTICIPANT	\N	PRESENT	0
700244	699097	20060X	PARTICIPANT	\N	PRESENT	0
700245	699097	20062A	PARTICIPANT	\N	PRESENT	0
700246	699097	19507S	PARTICIPANT	\N	PRESENT	0
700247	699097	20286Q	PARTICIPANT	\N	PRESENT	0
700248	699097	19747H	PARTICIPANT	\N	PRESENT	0
700249	699097	14207L	PARTICIPANT	\N	PRESENT	0
700250	699097	14257W	PARTICIPANT	\N	PRESENT	0
700251	699097	19413M	PARTICIPANT	\N	EXCUSE	0
700252	699097	20082E	PARTICIPANT	\N	EXCUSE	0
700253	699097	01025N	PARTICIPANT	\N	EXCUSE	0
700255	698940	11033F	PARTICIPANT	\N	PRESENT	0
700256	698940	14089Y	PARTICIPANT	\N	PRESENT	0
700258	698940	20114U	PARTICIPANT	\N	PRESENT	0
700259	698940	17737W	PARTICIPANT	\N	EXCUSE	0
700260	698940	14053L	PARTICIPANT	\N	PRESENT	0
700261	698940	11056N	PARTICIPANT	\N	PRESENT	0
700262	698940	14021P	PARTICIPANT	\N	PRESENT	0
700263	698940	11085T	PARTICIPANT	\N	PRESENT	0
700264	698940	95063L	PARTICIPANT	\N	PRESENT	0
700265	698940	14179A	PARTICIPANT	\N	PRESENT	0
700266	698940	19729F	PARTICIPANT	\N	PRESENT	0
700267	698940	19585H	PARTICIPANT	\N	PRESENT	0
700268	695332	14221J	PARTICIPANT	\N	PRESENT	0
700272	695332	20024T	PARTICIPANT	\N	PRESENT	0
700286	698744	19679N	PARTICIPANT	\N	PRESENT	0
700287	698744	19663E	PARTICIPANT	\N	PRESENT	0
700392	699017	19745F	PARTICIPANT	\N	PRESENT	0
700289	698744	14355X	PARTICIPANT	\N	PRESENT	0
700290	698744	19415P	PARTICIPANT	\N	PRESENT	0
700291	698744	14026U	PARTICIPANT	\N	PRESENT	0
700292	695332	20032T	PARTICIPANT	\N	PRESENT	0
700293	695332	11065P	PARTICIPANT	\N	PRESENT	0
700294	696398	19766L	PARTICIPANT	\N	PRESENT	0
700295	696398	19699S	PARTICIPANT	\N	PRESENT	0
700296	696398	04033B	PARTICIPANT	\N	PRESENT	0
700297	696398	14229S	PARTICIPANT	\N	PRESENT	0
700298	696398	20112S	PARTICIPANT	\N	PRESENT	0
700299	696398	20124W	PARTICIPANT	\N	PRESENT	0
700300	696398	19527W	PARTICIPANT	\N	PRESENT	0
700301	696398	19643A	PARTICIPANT	\N	PRESENT	0
700302	696398	20132W	PARTICIPANT	\N	PRESENT	0
700303	696398	14073Q	PARTICIPANT	\N	PRESENT	0
700304	696398	19651A	PARTICIPANT	\N	PRESENT	0
700305	696398	19611R	PRESIDENT	0	PRESENT	0
700306	696398	20142Y	PARTICIPANT	\N	PRESENT	0
700307	696398	20048C	PARTICIPANT	\N	PRESENT	0
700308	696398	19399H	PARTICIPANT	\N	PRESENT	0
700309	696398	20052X	PARTICIPANT	\N	PRESENT	0
700310	696398	19719D	PARTICIPANT	\N	PRESENT	0
700311	696398	14030Q	PARTICIPANT	\N	PRESENT	0
700312	696398	20058E	PARTICIPANT	\N	PRESENT	0
700313	696398	20180F	PARTICIPANT	\N	PRESENT	0
700314	696398	20264J	PARTICIPANT	\N	PRESENT	0
700315	696398	14123H	PARTICIPANT	\N	PRESENT	0
700316	696398	11104D	PARTICIPANT	\N	PRESENT	0
700317	696398	20980G	PARTICIPANT	\N	PRESENT	0
700318	696398	19758L	PARTICIPANT	\N	PRESENT	0
700319	696398	19621T	PARTICIPANT	\N	PRESENT	0
700320	696398	20084G	PARTICIPANT	\N	PRESENT	0
700321	696398	20056C	PARTICIPANT	\N	EXCUSE	0
700322	696398	11109J	PARTICIPANT	\N	EXCUSE	0
700351	699128	20086J	PARTICIPANT	\N	PRESENT	0
700352	699128	04071H	PARTICIPANT	\N	PRESENT	0
700353	699128	01048V	PARTICIPANT	\N	PRESENT	0
700354	699128	01057W	PARTICIPANT	\N	PRESENT	0
700355	699128	11053K	PARTICIPANT	\N	PRESENT	0
700356	699128	19667J	PARTICIPANT	\N	PRESENT	0
700357	699128	14225N	PARTICIPANT	\N	PRESENT	0
700358	699128	11110B	PARTICIPANT	\N	PRESENT	0
700359	699128	19349W	PARTICIPANT	\N	PRESENT	0
700360	699128	08010L	PARTICIPANT	\N	PRESENT	0
700361	699128	20116W	PARTICIPANT	\N	PRESENT	0
700362	699128	19335Q	PARTICIPANT	\N	PRESENT	0
700363	699128	19479G	PARTICIPANT	\N	PRESENT	0
700364	699128	11048N	PARTICIPANT	\N	PRESENT	0
700365	699128	19711U	PARTICIPANT	\N	PRESENT	0
700366	699128	14189C	PARTICIPANT	\N	PRESENT	0
700367	699128	19531S	PARTICIPANT	\N	PRESENT	0
700368	699128	19687N	PARTICIPANT	\N	PRESENT	0
700369	699128	20050V	PARTICIPANT	\N	PRESENT	0
700370	699128	20044X	PARTICIPANT	\N	PRESENT	0
700372	699128	11040E	PARTICIPANT	\N	PRESENT	0
700373	699128	14083S	PARTICIPANT	\N	PRESENT	0
700374	699128	11012A	PARTICIPANT	\N	PRESENT	0
700375	699128	20252E	PARTICIPANT	\N	PRESENT	0
700376	699128	20070A	PARTICIPANT	\N	PRESENT	0
700377	699128	19741B	PARTICIPANT	\N	PRESENT	0
700378	699128	99004R	PARTICIPANT	\N	PRESENT	0
700379	699128	20914V	PARTICIPANT	\N	PRESENT	0
700380	699128	07029T	PARTICIPANT	\N	EXCUSE	0
700381	699128	14331P	PARTICIPANT	\N	EXCUSE	0
700387	699017	05012A	PRESIDENT	1	PRESENT	0
700388	699017	20070A	PARTICIPANT	\N	PRESENT	0
700389	699017	20078J	PARTICIPANT	\N	PRESENT	0
700390	699017	19820Y	PARTICIPANT	\N	PRESENT	0
700391	699017	14219Q	PARTICIPANT	\N	PRESENT	0
683465	682944	08009T	PARTICIPANT	\N	PRESENT	0
683467	683466	14255U	PARTICIPANT	\N	PRESENT	0
683468	683466	95063L	PARTICIPANT	\N	PRESENT	0
689283	689279	19383Y	PARTICIPANT	\N	PRESENT	0
689284	689279	19768N	PARTICIPANT	\N	PRESENT	0
689285	689279	19515S	PARTICIPANT	\N	PRESENT	0
689286	689279	20092G	PARTICIPANT	\N	PRESENT	0
689287	689279	19782L	PARTICIPANT	\N	PRESENT	0
689288	689279	01043Q	PARTICIPANT	\N	PRESENT	0
689289	689279	19441R	PARTICIPANT	\N	PRESENT	0
689290	689279	20094J	PARTICIPANT	\N	PRESENT	0
689291	689279	19705W	PARTICIPANT	\N	PRESENT	0
689292	689279	08015R	PARTICIPANT	\N	PRESENT	0
689293	689279	19575F	PARTICIPANT	\N	PRESENT	0
689294	689279	19369B	PARTICIPANT	\N	PRESENT	0
689295	689279	19563B	PARTICIPANT	\N	PRESENT	0
689296	689279	08028W	PARTICIPANT	\N	PRESENT	0
689297	689279	14038Y	PARTICIPANT	\N	PRESENT	0
689298	689279	19467C	PARTICIPANT	\N	PRESENT	0
689299	689279	20034V	PARTICIPANT	\N	PRESENT	0
689300	689279	14187A	PARTICIPANT	\N	PRESENT	0
689301	689279	20144B	PARTICIPANT	\N	PRESENT	0
689302	689279	19695N	PARTICIPANT	\N	PRESENT	0
689303	689279	11090Q	PRESIDENT	0	PRESENT	0
689304	689279	14033T	PARTICIPANT	\N	PRESENT	0
689305	689279	20054A	PARTICIPANT	\N	PRESENT	0
689306	689279	14205J	PARTICIPANT	\N	PRESENT	0
689307	689279	20060X	PARTICIPANT	\N	PRESENT	0
689308	689279	20062A	PARTICIPANT	\N	PRESENT	0
689309	689279	20286Q	PARTICIPANT	\N	PRESENT	0
689310	689279	20298U	PARTICIPANT	\N	PRESENT	0
689311	689279	19747H	PARTICIPANT	\N	PRESENT	0
689312	689279	14257W	PARTICIPANT	\N	PRESENT	0
689392	688395	14221J	PARTICIPANT	\N	PRESENT	0
689394	688395	20140W	PARTICIPANT	\N	PRESENT	0
689396	689280	14205J	PARTICIPANT	\N	PRESENT	0
689397	689280	19467C	PARTICIPANT	\N	PRESENT	0
689398	689280	19768N	PARTICIPANT	\N	PRESENT	0
689399	689280	19782L	PARTICIPANT	\N	PRESENT	0
689400	689280	19705W	PARTICIPANT	\N	PRESENT	0
689401	689280	19707Y	PARTICIPANT	\N	PRESENT	0
689402	689280	08015R	PARTICIPANT	\N	PRESENT	0
689403	689280	19575F	PARTICIPANT	\N	PRESENT	0
689404	689280	19695N	PARTICIPANT	\N	PRESENT	0
689405	689280	20094J	PARTICIPANT	\N	PRESENT	0
689406	689280	11090Q	PRESIDENT	0	PRESENT	0
689407	689280	04045F	PARTICIPANT	\N	PRESENT	0
689408	689280	20034V	PARTICIPANT	\N	PRESENT	0
689409	689280	19515S	PARTICIPANT	\N	PRESENT	0
689410	689280	19441R	PARTICIPANT	\N	PRESENT	0
689411	689280	14033T	PARTICIPANT	\N	PRESENT	0
689412	689280	20060X	PARTICIPANT	\N	PRESENT	0
689413	689280	20054A	PARTICIPANT	\N	PRESENT	0
689414	689280	19747H	PARTICIPANT	\N	PRESENT	0
689415	689280	08028W	PARTICIPANT	\N	PRESENT	0
689416	689280	01043Q	PARTICIPANT	\N	PRESENT	0
689417	689280	14187A	PARTICIPANT	\N	PRESENT	0
689418	689280	20082E	PARTICIPANT	\N	PRESENT	0
689419	689280	14257W	PARTICIPANT	\N	PRESENT	0
689420	689280	19631V	PARTICIPANT	\N	PRESENT	0
689424	689280	20018V	PARTICIPANT	\N	PRESENT	0
689425	689280	20030R	PARTICIPANT	\N	PRESENT	0
689426	689280	20062A	PARTICIPANT	\N	PRESENT	0
689427	689280	19826F	PARTICIPANT	\N	PRESENT	0
689428	689280	14207L	PARTICIPANT	\N	PRESENT	0
689429	689280	19383Y	PARTICIPANT	\N	PRESENT	0
689430	689280	20092G	PARTICIPANT	\N	PRESENT	0
689431	689280	11077T	PARTICIPANT	\N	PRESENT	0
689432	689280	14357A	PARTICIPANT	\N	PRESENT	0
689433	689280	19369B	PARTICIPANT	\N	PRESENT	0
689434	689280	14329V	PARTICIPANT	\N	PRESENT	0
689435	689280	20028X	PARTICIPANT	\N	PRESENT	0
689436	689280	01025N	PARTICIPANT	\N	PRESENT	0
689437	689280	20286Q	PARTICIPANT	\N	PRESENT	0
689438	689280	20298U	PARTICIPANT	\N	PRESENT	0
689439	689280	19563B	PARTICIPANT	\N	PRESENT	0
689440	689280	14038Y	PARTICIPANT	\N	PRESENT	0
689441	689280	19507S	PARTICIPANT	\N	PRESENT	0
689442	689280	14251Q	PARTICIPANT	\N	PRESENT	0
689443	689280	20144B	PARTICIPANT	\N	PRESENT	0
689444	688706	14151M	PARTICIPANT	\N	PRESENT	0
689445	688706	19581D	PARTICIPANT	\N	PRESENT	0
689446	688706	11033F	PARTICIPANT	\N	PRESENT	0
689449	688706	10015M	PARTICIPANT	\N	PRESENT	0
689450	688706	19729F	PARTICIPANT	\N	PRESENT	0
689451	688706	19489J	PARTICIPANT	\N	PRESENT	0
689452	688706	07004J	PARTICIPANT	\N	PRESENT	0
689453	688706	04047H	PRESIDENT	0	PRESENT	0
689454	688706	14001X	PARTICIPANT	\N	PRESENT	0
689455	688706	14215L	PARTICIPANT	\N	PRESENT	0
689456	688706	14111D	PARTICIPANT	\N	PRESENT	0
689457	688706	14089Y	PARTICIPANT	\N	PRESENT	0
689458	688706	19954N	PARTICIPANT	\N	PRESENT	0
689459	688706	95063L	PARTICIPANT	\N	PRESENT	0
689460	688706	20022R	PARTICIPANT	\N	PRESENT	0
689461	688706	14053L	PARTICIPANT	\N	PRESENT	0
689462	688706	14231L	PARTICIPANT	\N	PRESENT	0
689463	688706	11026G	PARTICIPANT	\N	PRESENT	0
689464	688706	17737W	PARTICIPANT	\N	PRESENT	0
689465	688706	14107H	PARTICIPANT	\N	PRESENT	0
689466	688706	20110Q	PARTICIPANT	\N	PRESENT	0
689467	688706	11072N	PARTICIPANT	\N	PRESENT	0
689468	688706	20074E	PARTICIPANT	\N	PRESENT	0
689469	688706	14021P	PARTICIPANT	\N	PRESENT	0
689470	689282	19333N	PARTICIPANT	\N	PRESENT	0
689471	689282	20076G	PARTICIPANT	\N	PRESENT	0
689472	689282	19549D	PARTICIPANT	\N	PRESENT	0
689473	689282	19387D	PARTICIPANT	\N	PRESENT	0
689474	689282	19820Y	PARTICIPANT	\N	PRESENT	0
689475	689282	14219Q	PRESIDENT	0	PRESENT	0
689476	689282	19826F	PARTICIPANT	\N	PRESENT	0
689477	689282	19599P	PARTICIPANT	\N	PRESENT	0
689478	689282	20102Q	PARTICIPANT	\N	PRESENT	0
689479	689282	19637C	PARTICIPANT	\N	PRESENT	0
689480	689282	18083K	PARTICIPANT	\N	PRESENT	0
689481	689282	14237S	PARTICIPANT	\N	PRESENT	0
689482	689282	05012A	PARTICIPANT	\N	PRESENT	0
689483	689282	20118Y	PARTICIPANT	\N	PRESENT	0
689484	689282	19503N	PARTICIPANT	\N	PRESENT	0
689485	689282	19685L	PARTICIPANT	\N	PRESENT	0
689486	689282	17367Q	PARTICIPANT	\N	PRESENT	0
689487	689282	19681G	PARTICIPANT	\N	PRESENT	0
689488	689282	20024T	PARTICIPANT	\N	PRESENT	0
689489	689282	19525U	PARTICIPANT	\N	PRESENT	0
689490	689282	20032T	PARTICIPANT	\N	PRESENT	0
689491	689282	20136B	PARTICIPANT	\N	PRESENT	0
689492	689282	14031R	PARTICIPANT	\N	PRESENT	0
689493	689282	19251M	PARTICIPANT	\N	PRESENT	0
689494	689282	20046A	PARTICIPANT	\N	PRESENT	0
689495	689282	20068G	PARTICIPANT	\N	PRESENT	0
689496	689282	19739H	PARTICIPANT	\N	PRESENT	0
689497	689282	19745F	PARTICIPANT	\N	PRESENT	0
689498	688796	14331P	PARTICIPANT	\N	PRESENT	0
689499	688796	19479G	PARTICIPANT	\N	PRESENT	0
689500	688796	08073C	PARTICIPANT	\N	PRESENT	0
689501	688796	19349W	PARTICIPANT	\N	PRESENT	0
689502	688796	20914V	PARTICIPANT	\N	PRESENT	0
689503	688796	14253S	PARTICIPANT	\N	PRESENT	0
689504	688796	99004R	PARTICIPANT	\N	PRESENT	0
689505	688796	19671E	PARTICIPANT	\N	PRESENT	0
689506	688796	14173T	PARTICIPANT	\N	PRESENT	0
689507	688706	14147R	PARTICIPANT	\N	PRESENT	0
689508	689282	14221J	PARTICIPANT	\N	PRESENT	0
689509	689282	20100N	PARTICIPANT	\N	PRESENT	0
689510	689282	11065P	PARTICIPANT	\N	PRESENT	0
689511	689282	20122U	PARTICIPANT	\N	PRESENT	0
689512	688706	11085T	PARTICIPANT	\N	PRESENT	0
689513	688796	19741B	PARTICIPANT	\N	PRESENT	0
689514	688796	11048N	PARTICIPANT	\N	PRESENT	0
689515	688796	01048V	PARTICIPANT	\N	PRESENT	0
689516	688796	01057W	PARTICIPANT	\N	PRESENT	0
689517	688796	19711U	PARTICIPANT	\N	PRESENT	0
689518	688796	14225N	PRESIDENT	0	PRESENT	0
689519	688706	04008A	PARTICIPANT	\N	PRESENT	0
689520	688706	19649G	PARTICIPANT	\N	PRESENT	0
689521	689282	19768N	PARTICIPANT	\N	PRESENT	0
689522	689282	19515S	PARTICIPANT	\N	PRESENT	0
689523	689282	20092G	PARTICIPANT	\N	PRESENT	0
689524	689282	19782L	PARTICIPANT	\N	PRESENT	0
689525	689282	01043Q	PARTICIPANT	\N	PRESENT	0
689526	689282	20094J	PARTICIPANT	\N	PRESENT	0
694182	692429	05012A	PARTICIPANT	\N	PRESENT	0
694183	692429	11090Q	PARTICIPANT	\N	PRESENT	0
694184	692429	08028W	PARTICIPANT	\N	PRESENT	0
694185	692429	19631V	PARTICIPANT	\N	PRESENT	0
694186	692429	01048V	PARTICIPANT	\N	PRESENT	0
694187	692429	11043H	PARTICIPANT	\N	PRESENT	0
694188	692429	19549D	PARTICIPANT	\N	PRESENT	0
694189	692429	20094J	PARTICIPANT	\N	PRESENT	0
694190	692429	14223L	PARTICIPANT	\N	PRESENT	0
694191	692429	14169X	PARTICIPANT	\N	PRESENT	0
694192	692429	08060W	PARTICIPANT	\N	PRESENT	0
694193	692429	20088L	PARTICIPANT	\N	PRESENT	0
694194	692429	20114U	PARTICIPANT	\N	PRESENT	0
694195	692429	19643A	PARTICIPANT	\N	PRESENT	0
694196	692429	20034V	PARTICIPANT	\N	PRESENT	0
694197	692429	17367Q	PARTICIPANT	\N	PRESENT	0
694198	692429	20172F	PARTICIPANT	\N	PRESENT	0
694199	692429	18083K	PARTICIPANT	\N	PRESENT	0
694200	692429	11027H	PARTICIPANT	\N	PRESENT	0
694201	692429	20074E	PARTICIPANT	\N	PRESENT	0
694202	692429	19447X	PARTICIPANT	\N	PRESENT	0
694203	692429	14281W	PARTICIPANT	\N	PRESENT	0
694204	692429	14249W	PARTICIPANT	\N	PRESENT	0
694205	692429	08045X	PARTICIPANT	\N	PRESENT	0
694206	692429	19585H	PARTICIPANT	\N	PRESENT	0
694207	692429	01058X	PARTICIPANT	\N	PRESENT	0
694208	692429	19820Y	PARTICIPANT	\N	PRESENT	0
694209	692429	19725B	PARTICIPANT	\N	PRESENT	0
694210	692429	19333N	PARTICIPANT	\N	PRESENT	0
694211	692429	04047H	PARTICIPANT	\N	PRESENT	0
694212	692429	14026U	PARTICIPANT	\N	PRESENT	0
694213	692429	14121F	PARTICIPANT	\N	PRESENT	0
694214	692429	19531S	PARTICIPANT	\N	PRESENT	0
694215	692429	19747H	PARTICIPANT	\N	PRESENT	0
694216	692429	14133K	PARTICIPANT	\N	PRESENT	0
694217	692429	19683J	PARTICIPANT	\N	PRESENT	0
694218	692429	08034U	PARTICIPANT	\N	PRESENT	0
694219	692429	12028B	PARTICIPANT	\N	PRESENT	0
694220	692429	04042C	PARTICIPANT	\N	PRESENT	0
694221	692429	04033B	PARTICIPANT	\N	PRESENT	0
694222	692429	14021P	PARTICIPANT	\N	PRESENT	0
694223	692429	14187A	PARTICIPANT	\N	PRESENT	0
694224	692429	19649G	PARTICIPANT	\N	PRESENT	0
694225	692429	14071N	PARTICIPANT	\N	PRESENT	0
694226	692429	18193Q	PARTICIPANT	\N	PRESENT	0
694227	692429	08012N	PARTICIPANT	\N	PRESENT	0
694228	692429	14001X	PARTICIPANT	\N	PRESENT	0
694229	692429	20028X	PARTICIPANT	\N	PRESENT	0
694230	692429	14257W	PARTICIPANT	\N	PRESENT	0
694231	692429	17965H	PARTICIPANT	\N	PRESENT	0
694232	692429	19503N	PARTICIPANT	\N	PRESENT	0
694233	692429	11097X	PARTICIPANT	\N	PRESENT	0
694234	692429	14225N	PARTICIPANT	\N	PRESENT	0
694235	692429	20082E	PARTICIPANT	\N	PRESENT	0
694236	692429	14229S	PARTICIPANT	\N	PRESENT	0
694237	692429	11045K	PARTICIPANT	\N	PRESENT	0
694238	692429	19415P	PARTICIPANT	\N	PRESENT	0
694239	692429	20084G	PARTICIPANT	\N	PRESENT	0
694240	692429	14215L	PARTICIPANT	\N	PRESENT	0
694241	692429	19421M	PARTICIPANT	\N	PRESENT	0
694242	692429	19669L	PARTICIPANT	\N	PRESENT	0
694243	692429	14053L	PARTICIPANT	\N	PRESENT	0
694244	692429	19701S	PARTICIPANT	\N	PRESENT	0
694245	692429	14069U	PARTICIPANT	\N	PRESENT	0
694246	692429	20118Y	PARTICIPANT	\N	PRESENT	0
694247	692429	20064C	PARTICIPANT	\N	PRESENT	0
694248	692429	19533U	PARTICIPANT	\N	PRESENT	0
694249	692429	10006L	PARTICIPANT	\N	PRESENT	0
694250	692429	11026G	PARTICIPANT	\N	PRESENT	0
694280	692429	19762G	PARTICIPANT	\N	PRESENT	0
694252	692429	04071H	PARTICIPANT	\N	PRESENT	0
694253	692429	19798U	PARTICIPANT	\N	PRESENT	0
694254	692429	14193X	PARTICIPANT	\N	PRESENT	0
694255	692429	20060X	PARTICIPANT	\N	PRESENT	0
694256	692429	20080C	PARTICIPANT	\N	PRESENT	0
694257	692429	19671E	PARTICIPANT	\N	PRESENT	0
694258	692429	20070A	PARTICIPANT	\N	PRESENT	0
694259	692429	11033F	PARTICIPANT	\N	PRESENT	0
694260	692429	19367Y	PARTICIPANT	\N	PRESENT	0
694261	692429	19581D	PARTICIPANT	\N	PRESENT	0
694262	692429	20252E	PARTICIPANT	\N	PRESENT	0
694263	692429	11064N	PARTICIPANT	\N	PRESENT	0
694264	692429	20120S	PARTICIPANT	\N	PRESENT	0
694265	692429	14211G	PARTICIPANT	\N	PRESENT	0
694266	692429	14217N	PARTICIPANT	\N	PRESENT	0
694267	692429	07033P	PARTICIPANT	\N	PRESENT	0
694268	692429	14329V	PARTICIPANT	\N	PRESENT	0
694269	692429	19675J	PARTICIPANT	\N	PRESENT	0
694270	692429	01062T	PARTICIPANT	\N	PRESENT	0
694271	692429	20124W	PARTICIPANT	\N	PRESENT	0
694272	692429	20126Y	PARTICIPANT	\N	PRESENT	0
694273	692429	20054A	PARTICIPANT	\N	PRESENT	0
694274	692429	19647E	PARTICIPANT	\N	PRESENT	0
694275	692429	20090E	PARTICIPANT	\N	PRESENT	0
694276	692429	11074Q	PARTICIPANT	\N	PRESENT	0
694277	692429	20062A	PARTICIPANT	\N	PRESENT	0
694278	692429	19741B	PARTICIPANT	\N	PRESENT	0
694279	692429	14030Q	PARTICIPANT	\N	PRESENT	0
694281	692429	14255U	PARTICIPANT	\N	PRESENT	0
694282	692429	14083S	PARTICIPANT	\N	PRESENT	0
694283	692429	11053K	PARTICIPANT	\N	PRESENT	0
694284	692429	19383Y	PARTICIPANT	\N	PRESENT	0
694285	692429	20140W	PARTICIPANT	\N	PRESENT	0
694286	692429	14267Y	PARTICIPANT	\N	PRESENT	0
694287	692429	11070L	PARTICIPANT	\N	PRESENT	0
694288	692429	14327T	PARTICIPANT	\N	PRESENT	0
694289	692429	01024M	PARTICIPANT	\N	PRESENT	0
694290	692429	19717B	PARTICIPANT	\N	PRESENT	0
694291	692429	14042U	PARTICIPANT	\N	PRESENT	0
694292	692429	20152B	PARTICIPANT	\N	PRESENT	0
694293	692429	19685L	PARTICIPANT	\N	PRESENT	0
694294	692429	20048C	PARTICIPANT	\N	PRESENT	0
694295	692429	20066E	PARTICIPANT	\N	PRESENT	0
694296	692429	19569H	PARTICIPANT	\N	PRESENT	0
694297	692429	20286Q	PARTICIPANT	\N	PRESENT	0
694298	692429	19691J	PARTICIPANT	\N	PRESENT	0
694299	692429	14179A	PARTICIPANT	\N	PRESENT	0
694300	692429	19745F	PARTICIPANT	\N	PRESENT	0
694301	692429	19319Q	PARTICIPANT	\N	PRESENT	0
694302	692429	11085T	PARTICIPANT	\N	PRESENT	0
694303	692429	14219Q	PARTICIPANT	\N	PRESENT	0
694304	692429	16685X	PARTICIPANT	\N	PRESENT	0
694305	692429	20052X	PARTICIPANT	\N	PRESENT	0
694306	692429	01043Q	PARTICIPANT	\N	PRESENT	0
694307	692429	14357A	PARTICIPANT	\N	PRESENT	0
694308	692429	19699S	PARTICIPANT	\N	PRESENT	0
694309	692429	19611R	PARTICIPANT	\N	PRESENT	0
694310	692429	19735D	PARTICIPANT	\N	PRESENT	0
694311	692429	08009T	PARTICIPANT	\N	PRESENT	0
694312	692429	19826F	PARTICIPANT	\N	PRESENT	0
694313	692429	04070G	PARTICIPANT	\N	PRESENT	0
694314	692429	20248J	PARTICIPANT	\N	PRESENT	0
694315	692429	14055N	PARTICIPANT	\N	PRESENT	0
694316	692429	01060R	PARTICIPANT	\N	PRESENT	0
694317	692429	01034P	PARTICIPANT	\N	PRESENT	0
694318	692429	19479G	PARTICIPANT	\N	PRESENT	0
694319	692429	19749K	PARTICIPANT	\N	PRESENT	0
694320	692429	14147R	PARTICIPANT	\N	PRESENT	0
694321	692429	19563B	PARTICIPANT	\N	PRESENT	0
694322	692429	14231L	PARTICIPANT	\N	PRESENT	0
694323	692429	08069G	PARTICIPANT	\N	PRESENT	0
694324	692429	01025N	PARTICIPANT	\N	PRESENT	0
694325	692429	20040T	PARTICIPANT	\N	PRESENT	0
694326	692429	20132W	PARTICIPANT	\N	PRESENT	0
694327	692429	19687N	PARTICIPANT	\N	PRESENT	0
694328	692429	20134Y	PARTICIPANT	\N	PRESENT	0
694329	692429	20106U	PARTICIPANT	\N	PRESENT	0
694330	692429	19681G	PARTICIPANT	\N	PRESENT	0
694331	692429	04059M	PARTICIPANT	\N	PRESENT	0
694332	692429	20264J	PARTICIPANT	\N	PRESENT	0
694333	692429	14097Y	PARTICIPANT	\N	PRESENT	0
694334	692429	14109K	PARTICIPANT	\N	PRESENT	0
694335	692429	20018V	PARTICIPANT	\N	PRESENT	0
694336	692429	20266L	PARTICIPANT	\N	PRESENT	0
694337	692429	11077T	PARTICIPANT	\N	PRESENT	0
694338	692429	20016T	PARTICIPANT	\N	PRESENT	0
694339	692429	14033T	PARTICIPANT	\N	PRESENT	0
694340	692429	19507S	PARTICIPANT	\N	PRESENT	0
694341	692429	20298U	PARTICIPANT	\N	PRESENT	0
694342	692429	19543W	PARTICIPANT	\N	PRESENT	0
694343	692429	17023S	PARTICIPANT	\N	PRESENT	0
686136	683229	14083S	PARTICIPANT	\N	PRESENT	0
686137	683229	20106U	PARTICIPANT	\N	PRESENT	0
686138	683229	19349W	PARTICIPANT	\N	PRESENT	0
686139	683229	19525U	PARTICIPANT	\N	PRESENT	0
686140	683229	20100N	PARTICIPANT	\N	PRESENT	0
686141	683229	19715Y	PARTICIPANT	\N	PRESENT	0
686142	683229	19565D	PARTICIPANT	\N	PRESENT	0
686196	683230	19333N	PARTICIPANT	\N	PRESENT	0
686197	683230	08015R	PARTICIPANT	\N	PRESENT	0
686198	683230	19565D	PARTICIPANT	\N	PRESENT	0
686199	683230	20030R	PARTICIPANT	\N	PRESENT	0
686200	683230	19503N	PARTICIPANT	\N	PRESENT	0
686201	683230	19715Y	PARTICIPANT	\N	PRESENT	0
686202	683230	20092G	PARTICIPANT	\N	PRESENT	0
686203	683230	14211G	PARTICIPANT	\N	PRESENT	0
686204	683230	14031R	PARTICIPANT	\N	PRESENT	0
686205	683230	20034V	PARTICIPANT	\N	PRESENT	0
686206	683230	19467C	PARTICIPANT	\N	PRESENT	0
686207	683230	20136B	PARTICIPANT	\N	PRESENT	0
686208	683230	07029T	PARTICIPANT	\N	PRESENT	0
686215	683230	20100N	PARTICIPANT	\N	PRESENT	0
686210	683230	01024M	PARTICIPANT	\N	PRESENT	0
686211	683230	19369B	PARTICIPANT	\N	PRESENT	0
686212	683230	20298U	PARTICIPANT	\N	PRESENT	0
686213	683230	19747H	PARTICIPANT	\N	PRESENT	0
686214	683230	19525U	PARTICIPANT	\N	PRESENT	0
686216	683230	19866P	PARTICIPANT	\N	PRESENT	0
686217	683230	19629C	PARTICIPANT	\N	PRESENT	0
686218	683230	14207L	PARTICIPANT	\N	PRESENT	0
686219	683230	20046A	PARTICIPANT	\N	PRESENT	0
686220	683230	14038Y	PARTICIPANT	\N	PRESENT	0
686221	683230	11077T	PARTICIPANT	\N	PRESENT	0
686225	683230	19575F	PARTICIPANT	\N	PRESENT	0
686223	683230	11031D	PARTICIPANT	\N	PRESENT	0
686224	683230	19758L	PARTICIPANT	\N	PRESENT	0
686226	683230	19349W	PARTICIPANT	\N	PRESENT	0
686227	683230	20032T	PARTICIPANT	\N	PRESENT	0
686234	683230	14083S	PARTICIPANT	\N	PRESENT	0
686241	683230	20028X	PARTICIPANT	\N	PRESENT	0
686242	683230	04045F	PARTICIPANT	\N	PRESENT	0
686243	683230	19687N	PARTICIPANT	\N	PRESENT	0
686244	683230	14021P	PARTICIPANT	\N	PRESENT	0
686245	683230	14219Q	PARTICIPANT	\N	PRESENT	0
686246	683230	19549D	PARTICIPANT	\N	PRESENT	0
686247	683230	19798U	PARTICIPANT	\N	PRESENT	0
686248	683230	19413M	PARTICIPANT	\N	PRESENT	0
686249	683230	20062A	PARTICIPANT	\N	PRESENT	0
686250	683230	19695N	PARTICIPANT	\N	PRESENT	0
686251	683230	11056N	PARTICIPANT	\N	PRESENT	0
686252	683230	20142Y	PARTICIPANT	\N	PRESENT	0
686803	686799	20066E	PARTICIPANT	\N	PRESENT	0
686836	685294	20024T	PARTICIPANT	\N	PRESENT	0
686837	685294	19549D	PARTICIPANT	\N	PRESENT	0
686838	685294	18083K	PARTICIPANT	\N	EXCUSE	0
686839	685294	19525U	PARTICIPANT	\N	PRESENT	0
686840	685294	20140W	PARTICIPANT	\N	PRESENT	0
686841	685294	19251M	PARTICIPANT	\N	PRESENT	0
686842	685294	20038A	PARTICIPANT	\N	PRESENT	0
686194	683230	19719D	PARTICIPANT	\N	PRESENT	0
686195	683230	19599P	PARTICIPANT	\N	PRESENT	0
686843	685294	19599P	PARTICIPANT	\N	PRESENT	0
686844	685294	20120S	PARTICIPANT	\N	PRESENT	0
686845	685294	19820Y	PARTICIPANT	\N	PRESENT	0
686846	685294	20068G	PARTICIPANT	\N	EXCUSE	0
686847	685294	19333N	PARTICIPANT	\N	EXCUSE	0
686848	685294	20102Q	PARTICIPANT	\N	PRESENT	0
686849	685294	14219Q	PRESIDENT	0	PRESENT	0
686850	685294	14031R	PARTICIPANT	\N	PRESENT	0
686851	685294	14221J	PARTICIPANT	\N	PRESENT	0
686852	685294	14237S	PARTICIPANT	\N	EXCUSE	0
686853	685294	19503N	PARTICIPANT	\N	EXCUSE	0
686854	685294	20020P	PARTICIPANT	\N	PRESENT	0
686855	685294	19619A	PARTICIPANT	\N	EXCUSE	0
686856	685294	20136B	PARTICIPANT	\N	EXCUSE	0
686857	685294	19745F	PARTICIPANT	\N	PRESENT	0
687419	687418	10015M	PARTICIPANT	\N	PRESENT	0
687420	687418	20082E	PARTICIPANT	\N	PRESENT	0
687421	687418	19723Y	PARTICIPANT	\N	PRESENT	0
687422	687418	19569H	PARTICIPANT	\N	PRESENT	0
687423	687418	11026G	PARTICIPANT	\N	PRESENT	0
688217	686135	10006L	PRESIDENT	0	PRESENT	0
688219	686135	11031D	PARTICIPANT	\N	PRESENT	0
688220	686135	19760E	PARTICIPANT	\N	PRESENT	0
688222	686135	11067R	PARTICIPANT	\N	PRESENT	0
688223	686135	04057K	PARTICIPANT	\N	PRESENT	0
688225	686135	14071N	PARTICIPANT	\N	PRESENT	0
688227	686135	14195A	PARTICIPANT	\N	PRESENT	0
688228	686135	14213J	PARTICIPANT	\N	PRESENT	0
688230	686135	11097X	PARTICIPANT	\N	PRESENT	0
688231	686135	19415P	PARTICIPANT	\N	PRESENT	0
688256	686135	11045K	PARTICIPANT	\N	PRESENT	0
688258	686135	19703U	PARTICIPANT	\N	PRESENT	0
688259	686135	14042U	PARTICIPANT	\N	PRESENT	0
688260	686135	14026U	PARTICIPANT	\N	PRESENT	0
688261	686135	17779H	PARTICIPANT	\N	EXCUSE	0
688262	686135	19691J	PARTICIPANT	\N	PRESENT	0
688263	686135	20130U	PARTICIPANT	\N	PRESENT	0
688513	688512	08009T	PARTICIPANT	\N	PRESENT	0
688514	688512	19543W	PARTICIPANT	\N	PRESENT	0
688515	688512	10015M	PARTICIPANT	\N	PRESENT	0
688516	688512	11026G	PARTICIPANT	\N	PRESENT	0
688517	688512	19739H	PARTICIPANT	\N	PRESENT	0
688518	688512	20064C	PARTICIPANT	\N	PRESENT	0
688519	688512	18083K	PARTICIPANT	\N	PRESENT	0
688521	688520	17229F	PARTICIPANT	\N	PRESENT	0
688522	688520	14151M	PARTICIPANT	\N	PRESENT	0
688523	688520	20252E	PARTICIPANT	\N	PRESENT	0
688524	688520	14037X	PARTICIPANT	\N	PRESENT	0
688525	688520	08010L	PARTICIPANT	\N	PRESENT	0
688583	688582	20132W	PARTICIPANT	\N	PRESENT	0
688584	688582	19553Y	PARTICIPANT	\N	PRESENT	0
688588	688587	14083S	PARTICIPANT	\N	PRESENT	0
688589	688587	19553Y	PARTICIPANT	\N	PRESENT	0
688633	688632	19575F	PARTICIPANT	\N	PRESENT	0
688635	688634	19575F	PARTICIPANT	\N	PRESENT	0
688637	688636	19575F	PARTICIPANT	\N	PRESENT	0
688639	688638	19575F	PARTICIPANT	\N	PRESENT	0
688641	688640	19575F	PARTICIPANT	\N	PRESENT	0
688643	688642	19575F	PARTICIPANT	\N	PRESENT	0
688757	688756	14033T	PARTICIPANT	\N	PRESENT	0
688758	688756	20018V	PARTICIPANT	\N	PRESENT	0
688759	688756	20092G	PARTICIPANT	\N	PRESENT	0
688760	688756	19575F	PARTICIPANT	\N	PRESENT	0
688761	688756	20144B	PARTICIPANT	\N	PRESENT	0
688762	688756	20062A	PARTICIPANT	\N	PRESENT	0
688846	688779	14331P	PARTICIPANT	\N	PRESENT	0
688847	688779	01048V	PARTICIPANT	\N	PRESENT	0
688848	688779	12016W	PARTICIPANT	\N	PRESENT	0
688849	688779	20050V	PARTICIPANT	\N	PRESENT	0
688850	688779	99004R	PARTICIPANT	\N	PRESENT	0
688851	688779	20080C	PARTICIPANT	\N	EXCUSE	0
688852	688779	11048N	PARTICIPANT	\N	PRESENT	0
688853	688779	08073C	PARTICIPANT	\N	PRESENT	0
688854	688779	20914V	PARTICIPANT	\N	PRESENT	0
688855	688779	08009T	PARTICIPANT	\N	PRESENT	0
688856	688779	08011M	PARTICIPANT	\N	PRESENT	0
688857	688779	19667J	PARTICIPANT	\N	PRESENT	0
688858	688779	20070A	PARTICIPANT	\N	PRESENT	0
688859	688779	19479G	PARTICIPANT	\N	PRESENT	0
688860	688779	19687N	PARTICIPANT	\N	PRESENT	0
688861	688779	19741B	PARTICIPANT	\N	PRESENT	0
688862	688779	14189C	PARTICIPANT	\N	PRESENT	0
689111	688645	20028X	PARTICIPANT	\N	PRESENT	0
688867	688779	11074Q	PARTICIPANT	\N	PRESENT	0
688865	688779	14083S	PARTICIPANT	\N	PRESENT	0
688866	688779	14225N	PRESIDENT	0	PRESENT	0
688868	688779	19631V	PARTICIPANT	\N	PRESENT	0
688869	688779	19647E	PARTICIPANT	\N	PRESENT	0
688870	688779	11040E	PARTICIPANT	\N	PRESENT	0
688871	688779	20116W	PARTICIPANT	\N	PRESENT	0
688872	688779	20044X	PARTICIPANT	\N	PRESENT	0
688873	688779	08010L	PARTICIPANT	\N	PRESENT	0
689114	688645	20082E	PARTICIPANT	\N	PRESENT	0
689112	688645	14257W	PARTICIPANT	\N	PRESENT	0
689116	688645	20080C	PARTICIPANT	\N	PRESENT	0
689118	688645	19631V	PARTICIPANT	\N	PRESENT	0
689119	688645	20092G	PARTICIPANT	\N	PRESENT	0
689120	688645	14133K	PARTICIPANT	\N	PRESENT	0
689121	688645	20104S	PARTICIPANT	\N	PRESENT	0
689122	688394	19549D	PARTICIPANT	\N	PRESENT	0
689123	688394	14221J	PARTICIPANT	\N	PRESENT	0
700393	699017	20914V	PARTICIPANT	\N	PRESENT	0
700394	699017	20046A	PARTICIPANT	\N	PRESENT	0
700395	699017	20094J	PARTICIPANT	\N	PRESENT	0
700396	699017	20104S	PARTICIPANT	\N	PRESENT	0
700397	699017	14229S	PARTICIPANT	\N	PRESENT	0
700398	699017	14169X	PRESIDENT	0	PRESENT	0
700399	699128	19647E	PARTICIPANT	\N	PRESENT	0
700446	698768	14189C	PARTICIPANT	\N	PRESENT	0
700447	698768	14089Y	PARTICIPANT	\N	PRESENT	0
700448	698768	11101A	PARTICIPANT	\N	PRESENT	0
700449	698768	19701S	PARTICIPANT	\N	PRESENT	0
700450	698768	19507S	PARTICIPANT	\N	PRESENT	0
700451	698768	20100N	PARTICIPANT	\N	PRESENT	0
700452	698768	20286Q	PARTICIPANT	\N	PRESENT	0
700453	698768	11083R	PARTICIPANT	\N	PRESENT	0
700454	698768	14033T	PARTICIPANT	\N	PRESENT	0
700455	698768	19725B	PARTICIPANT	\N	PRESENT	0
700456	698768	14073Q	PARTICIPANT	\N	PRESENT	0
700457	698768	19711U	PARTICIPANT	\N	PRESENT	0
700458	698768	14001X	PARTICIPANT	\N	PRESENT	0
700459	698768	04057K	PARTICIPANT	\N	EXCUSE	0
700460	698768	14169X	PARTICIPANT	\N	PRESENT	0
700461	698768	14331P	PARTICIPANT	\N	PRESENT	0
700462	698768	20098N	PARTICIPANT	\N	PRESENT	0
700463	698768	04045F	PARTICIPANT	\N	PRESENT	0
700470	699017	19387D	PARTICIPANT	\N	PRESENT	0
700471	699017	14221J	PARTICIPANT	\N	PRESENT	0
700472	699017	14205J	PARTICIPANT	\N	PRESENT	0
700473	698941	14105F	PARTICIPANT	\N	EXCUSE	0
700474	698941	19443T	PARTICIPANT	\N	EXCUSE	0
700475	698941	11027H	PARTICIPANT	\N	EXCUSE	0
700476	698970	14107H	PARTICIPANT	\N	PRESENT	0
700477	698970	14249W	PARTICIPANT	\N	PRESENT	0
700478	698970	20024T	PARTICIPANT	\N	PRESENT	0
700479	698970	19369B	PARTICIPANT	\N	PRESENT	0
700480	698970	08028W	PARTICIPANT	\N	PRESENT	0
700481	698970	20108W	PARTICIPANT	\N	PRESENT	0
700482	698970	19399H	PARTICIPANT	\N	PRESENT	0
700483	698970	98022P	PARTICIPANT	\N	PRESENT	0
700484	698970	14225N	PARTICIPANT	\N	PRESENT	0
700485	698970	19553Y	PARTICIPANT	\N	PRESENT	0
700486	698970	11040E	PARTICIPANT	\N	PRESENT	0
700487	698970	14221J	PARTICIPANT	\N	PRESENT	0
700488	698970	14195A	PARTICIPANT	\N	PRESENT	0
700489	698970	20090E	PARTICIPANT	\N	PRESENT	0
700490	698970	19719D	PARTICIPANT	\N	PRESENT	0
700491	698970	19585H	PARTICIPANT	\N	PRESENT	0
700492	698970	19511N	PARTICIPANT	\N	PRESENT	0
700493	698970	19619A	PARTICIPANT	\N	PRESENT	0
700494	698970	19741B	PARTICIPANT	\N	PRESENT	0
700495	698970	19723Y	PARTICIPANT	\N	PRESENT	0
700496	698970	20046A	PARTICIPANT	\N	PRESENT	0
700497	698970	14031R	PARTICIPANT	\N	PRESENT	0
700498	698970	14191V	PARTICIPANT	\N	PRESENT	0
700499	698970	20068G	PARTICIPANT	\N	PRESENT	0
700500	698970	20136B	PARTICIPANT	\N	PRESENT	0
700501	698970	14267Y	PARTICIPANT	\N	PRESENT	0
700502	698970	14357A	PARTICIPANT	\N	PRESENT	0
700503	698970	19593H	PARTICIPANT	\N	PRESENT	0
700504	698970	19563B	PARTICIPANT	\N	PRESENT	0
700505	698970	19745F	PARTICIPANT	\N	PRESENT	0
700506	698970	12028B	PARTICIPANT	\N	PRESENT	0
700507	698970	11070L	PARTICIPANT	\N	PRESENT	0
700508	698970	19681G	PARTICIPANT	\N	PRESENT	0
700509	698970	14327T	PARTICIPANT	\N	PRESENT	0
700510	698970	19629C	PARTICIPANT	\N	PRESENT	0
700512	698970	20072C	PARTICIPANT	\N	PRESENT	0
700513	698970	20914V	PARTICIPANT	\N	PRESENT	0
700518	698970	11041F	PARTICIPANT	\N	PRESENT	0
700520	698970	19319Q	PARTICIPANT	\N	PRESENT	0
700522	698970	11104D	PARTICIPANT	\N	PRESENT	0
700523	698970	19675J	PARTICIPANT	\N	PRESENT	0
700524	698970	20100N	PARTICIPANT	\N	PRESENT	0
700525	698970	11074Q	PARTICIPANT	\N	PRESENT	0
700527	698970	20102Q	PARTICIPANT	\N	PRESENT	0
700532	698970	19657G	PARTICIPANT	\N	PRESENT	0
700534	698970	19697Q	PARTICIPANT	\N	PRESENT	0
700535	698970	14001X	PARTICIPANT	\N	PRESENT	0
700536	698970	20018V	PARTICIPANT	\N	PRESENT	0
700537	698970	11054L	PARTICIPANT	\N	PRESENT	0
700538	698970	11085T	PARTICIPANT	\N	PRESENT	0
700540	698970	19621T	PARTICIPANT	\N	PRESENT	0
700541	698970	19711U	PARTICIPANT	\N	PRESENT	0
700542	698970	04035D	PARTICIPANT	\N	PRESENT	0
700543	698970	14038Y	PARTICIPANT	\N	PRESENT	0
700544	698970	20034V	PARTICIPANT	\N	PRESENT	0
700545	698970	19467C	PARTICIPANT	\N	PRESENT	0
700546	698970	19709B	PARTICIPANT	\N	PRESENT	0
700547	698970	08018U	PARTICIPANT	\N	PRESENT	0
700548	698970	19507S	PARTICIPANT	\N	PRESENT	0
700549	698970	20038A	PARTICIPANT	\N	PRESENT	0
700550	698970	20980G	PARTICIPANT	\N	PRESENT	0
700551	698970	20056C	PARTICIPANT	\N	PRESENT	0
700552	698970	20096L	PARTICIPANT	\N	PRESENT	0
700553	698970	14033T	PARTICIPANT	\N	PRESENT	0
700556	698970	19954N	PARTICIPANT	\N	PRESENT	0
700557	698970	20086J	PARTICIPANT	\N	PRESENT	0
700558	698970	20026V	PARTICIPANT	\N	PRESENT	0
700559	698970	11097X	PARTICIPANT	\N	PRESENT	0
700560	698970	19667J	PARTICIPANT	\N	PRESENT	0
700561	698970	20180F	PARTICIPANT	\N	PRESENT	0
700562	698970	20104S	PARTICIPANT	\N	PRESENT	0
700563	698970	08015R	PARTICIPANT	\N	PRESENT	0
700564	698970	19729F	PARTICIPANT	\N	PRESENT	0
700565	698970	19768N	PARTICIPANT	\N	PRESENT	0
700566	698970	20148F	PARTICIPANT	\N	PRESENT	0
700567	698970	04042C	PARTICIPANT	\N	PRESENT	0
700568	698970	20022R	PARTICIPANT	\N	PRESENT	0
700569	698970	08047A	PARTICIPANT	\N	PRESENT	0
700570	698970	14259Y	PARTICIPANT	\N	PRESENT	0
700572	698970	01057W	PARTICIPANT	\N	PRESENT	0
700576	698970	17367Q	PARTICIPANT	\N	PRESENT	0
700577	698970	19643A	PARTICIPANT	\N	PRESENT	0
700579	698970	14169X	PARTICIPANT	\N	PRESENT	0
700580	698970	14187A	PARTICIPANT	\N	PRESENT	0
700581	698970	04033B	PARTICIPANT	\N	PRESENT	0
700582	698970	05012A	PARTICIPANT	\N	PRESENT	0
700583	698970	11090Q	PARTICIPANT	\N	PRESENT	0
700584	698970	11048N	PARTICIPANT	\N	PRESENT	0
700585	698970	14329V	PARTICIPANT	\N	PRESENT	0
700586	698970	08056B	PARTICIPANT	\N	PRESENT	0
700587	698970	01058X	PARTICIPANT	\N	PRESENT	0
700588	698970	19762G	PARTICIPANT	\N	PRESENT	0
700589	698970	19701S	PARTICIPANT	\N	PRESENT	0
700590	698970	20126Y	PARTICIPANT	\N	PRESENT	0
700591	698970	20054A	PARTICIPANT	\N	PRESENT	0
700592	698970	20124W	PARTICIPANT	\N	PRESENT	0
700593	698970	19383Y	PARTICIPANT	\N	PRESENT	0
700594	698970	20020P	PARTICIPANT	\N	PRESENT	0
700595	698970	20152B	PARTICIPANT	\N	PRESENT	0
700596	698970	19581D	PARTICIPANT	\N	PRESENT	0
700597	698970	10006L	PARTICIPANT	\N	PRESENT	0
700598	698970	19798U	PARTICIPANT	\N	PRESENT	0
700599	698970	20252E	PARTICIPANT	\N	PRESENT	0
700600	698970	19671E	PARTICIPANT	\N	PRESENT	0
700601	698970	14193X	PARTICIPANT	\N	PRESENT	0
700602	698970	19760E	PARTICIPANT	\N	PRESENT	0
700603	698970	04085P	PARTICIPANT	\N	PRESENT	0
700604	698970	20112S	PARTICIPANT	\N	PRESENT	0
700605	698970	14071N	PARTICIPANT	\N	PRESENT	0
700606	698970	19758L	PARTICIPANT	\N	PRESENT	0
700607	698970	11056N	PARTICIPANT	\N	PRESENT	0
700608	698970	12041X	PARTICIPANT	\N	PRESENT	0
700609	698970	14217N	PARTICIPANT	\N	PRESENT	0
700610	698970	11077T	PARTICIPANT	\N	PRESENT	0
700611	698970	19687N	PARTICIPANT	\N	PRESENT	0
700612	698970	20120S	PARTICIPANT	\N	PRESENT	0
683485	683336	11048N	PARTICIPANT	\N	PRESENT	0
683486	683336	19711U	PARTICIPANT	\N	PRESENT	0
683487	683336	11012A	PARTICIPANT	\N	PRESENT	0
683488	683336	08034U	PARTICIPANT	\N	PRESENT	0
683489	683336	99004R	PARTICIPANT	\N	PRESENT	0
683490	683336	19667J	PARTICIPANT	\N	PRESENT	0
683491	683336	20044X	PARTICIPANT	\N	PRESENT	0
683492	683336	14225N	PRESIDENT	0	PRESENT	0
683493	683336	20050V	PARTICIPANT	\N	EXCUSE	0
683494	683336	19647E	PARTICIPANT	\N	PRESENT	0
683495	683336	14083S	PARTICIPANT	\N	PRESENT	0
683496	683336	20252E	PARTICIPANT	\N	PRESENT	0
683497	683336	07029T	PARTICIPANT	\N	PRESENT	0
683498	683220	95063L	PARTICIPANT	\N	PRESENT	0
683499	683220	19583F	PARTICIPANT	\N	PRESENT	0
683507	683220	12041X	PARTICIPANT	\N	PRESENT	0
683508	683220	19711U	PARTICIPANT	\N	PRESENT	0
683513	683220	19669L	PARTICIPANT	\N	PRESENT	0
683510	683220	08047A	PARTICIPANT	\N	PRESENT	0
683511	683220	07029T	PARTICIPANT	\N	PRESENT	0
683512	683220	19565D	PARTICIPANT	\N	PRESENT	0
683514	683220	01058X	PARTICIPANT	\N	PRESENT	0
683515	683220	11027H	PARTICIPANT	\N	PRESENT	0
683516	683220	14267Y	PARTICIPANT	\N	PRESENT	0
683517	683220	14225N	PARTICIPANT	\N	PRESENT	0
683518	683220	08034U	PARTICIPANT	\N	PRESENT	0
683519	683220	19421M	PARTICIPANT	\N	PRESENT	0
683520	683220	11012A	PARTICIPANT	\N	PRESENT	0
683521	683220	14193X	PARTICIPANT	\N	PRESENT	0
683522	683220	20072C	PARTICIPANT	\N	PRESENT	0
683523	683220	11083R	PARTICIPANT	\N	PRESENT	0
683524	683220	14133K	PARTICIPANT	\N	PRESENT	0
683525	683220	19347U	PARTICIPANT	\N	PRESENT	0
683526	683220	14249W	PARTICIPANT	\N	PRESENT	0
683527	683220	04042C	PARTICIPANT	\N	PRESENT	0
683528	683220	19651A	PARTICIPANT	\N	PRESENT	0
683529	683220	11064N	PARTICIPANT	\N	PRESENT	0
683530	683220	20100N	PARTICIPANT	\N	PRESENT	0
683531	683220	14255U	PARTICIPANT	\N	PRESENT	0
683532	683220	20252E	PARTICIPANT	\N	PRESENT	0
683533	683220	11026G	PARTICIPANT	\N	PRESENT	0
683534	683220	19667J	PARTICIPANT	\N	PRESENT	0
683535	683220	01024M	PARTICIPANT	\N	PRESENT	0
683536	683220	19709B	PARTICIPANT	\N	PRESENT	0
683538	683220	14211G	PARTICIPANT	\N	PRESENT	0
683539	683220	01062T	PARTICIPANT	\N	PRESENT	0
683540	683220	19591F	PARTICIPANT	\N	PRESENT	0
683544	683220	16685X	PARTICIPANT	\N	PRESENT	0
683542	683220	19319Q	PARTICIPANT	\N	PRESENT	0
683543	683220	14083S	PARTICIPANT	\N	PRESENT	0
683545	683220	20016T	PARTICIPANT	\N	PRESENT	0
683546	683220	95041E	PARTICIPANT	\N	PRESENT	0
683547	683220	19647E	PARTICIPANT	\N	PRESENT	0
683559	683220	20044X	PARTICIPANT	\N	PRESENT	0
683560	683220	14055N	PARTICIPANT	\N	PRESENT	0
683561	683220	20150Y	PARTICIPANT	\N	PRESENT	0
683562	683220	20078J	PARTICIPANT	\N	PRESENT	0
683563	683220	11048N	PARTICIPANT	\N	PRESENT	0
683602	683221	14133K	PARTICIPANT	\N	PRESENT	0
683603	683221	20264J	PARTICIPANT	\N	PRESENT	0
683604	683221	11027H	PARTICIPANT	\N	PRESENT	0
683605	683221	19347U	PARTICIPANT	\N	PRESENT	0
683645	683221	11080N	PARTICIPANT	\N	PRESENT	0
683607	683221	95041E	PARTICIPANT	\N	PRESENT	0
683608	683221	11041F	PARTICIPANT	\N	PRESENT	0
683609	683221	14073Q	PARTICIPANT	\N	PRESENT	0
683610	683221	11070L	PARTICIPANT	\N	PRESENT	0
683611	683221	19647E	PARTICIPANT	\N	PRESENT	0
683612	683221	20052X	PARTICIPANT	\N	PRESENT	0
683613	683221	11026G	PARTICIPANT	\N	PRESENT	0
683614	683221	19611R	PARTICIPANT	\N	PRESENT	0
683615	683221	20044X	PARTICIPANT	\N	PRESENT	0
683616	683221	01062T	PARTICIPANT	\N	PRESENT	0
683617	683221	20914V	PARTICIPANT	\N	PRESENT	0
683618	683221	19709B	PARTICIPANT	\N	PRESENT	0
683619	683221	20034V	PARTICIPANT	\N	PRESENT	0
683620	683221	14211G	PARTICIPANT	\N	PRESENT	0
683621	683221	19583F	PARTICIPANT	\N	PRESENT	0
683622	683221	20266L	PARTICIPANT	\N	PRESENT	0
683623	683221	08047A	PARTICIPANT	\N	PRESENT	0
683624	683221	19735D	PARTICIPANT	\N	PRESENT	0
683625	683221	20072C	PARTICIPANT	\N	PRESENT	0
683626	683221	11083R	PARTICIPANT	\N	PRESENT	0
683627	683221	19057M	PARTICIPANT	\N	PRESENT	0
683628	683221	12041X	PARTICIPANT	\N	PRESENT	0
683629	683221	14038Y	PARTICIPANT	\N	PRESENT	0
683630	683221	14083S	PARTICIPANT	\N	PRESENT	0
683631	683221	14225N	PARTICIPANT	\N	PRESENT	0
683632	683221	04042C	PARTICIPANT	\N	PRESENT	0
683633	683221	14267Y	PARTICIPANT	\N	PRESENT	0
683634	683221	19421M	PARTICIPANT	\N	PRESENT	0
683636	683221	14255U	PARTICIPANT	\N	PRESENT	0
683638	683221	20100N	PARTICIPANT	\N	PRESENT	0
683639	683221	07033P	PARTICIPANT	\N	PRESENT	0
683600	683221	99004R	PARTICIPANT	\N	PRESENT	0
683601	683221	01058X	PARTICIPANT	\N	PRESENT	0
683641	683221	11085T	PARTICIPANT	\N	PRESENT	0
683643	683221	11064N	PARTICIPANT	\N	PRESENT	0
683644	683221	19669L	PARTICIPANT	\N	PRESENT	0
683646	683221	19349W	PARTICIPANT	\N	PRESENT	0
683647	683221	14215L	PARTICIPANT	\N	PRESENT	0
683648	683221	16685X	PARTICIPANT	\N	PRESENT	0
683649	683221	20016T	PARTICIPANT	\N	PRESENT	0
683650	683221	20042V	PARTICIPANT	\N	PRESENT	0
683651	683221	19651A	PARTICIPANT	\N	PRESENT	0
683652	683221	95063L	PARTICIPANT	\N	PRESENT	0
683653	683221	14193X	PARTICIPANT	\N	PRESENT	0
683654	683221	19657G	PARTICIPANT	\N	PRESENT	0
683656	683221	20070A	PARTICIPANT	\N	PRESENT	0
683657	683221	11012A	PARTICIPANT	\N	PRESENT	0
683658	683221	07029T	PARTICIPANT	\N	PRESENT	0
683659	683221	19705W	PARTICIPANT	\N	PRESENT	0
683660	683221	08034U	PARTICIPANT	\N	PRESENT	0
683661	683221	11048N	PARTICIPANT	\N	PRESENT	0
683662	683221	14331P	PARTICIPANT	\N	PRESENT	0
683663	683221	19762G	PARTICIPANT	\N	PRESENT	0
683664	683221	14037X	PARTICIPANT	\N	PRESENT	0
683665	683221	19479G	PARTICIPANT	\N	PRESENT	0
683666	683221	01024M	PARTICIPANT	\N	PRESENT	0
686747	686746	08018U	PARTICIPANT	\N	PRESENT	0
689353	688395	19333N	PARTICIPANT	\N	PRESENT	0
689354	688395	19549D	PARTICIPANT	\N	PRESENT	0
689355	688395	20076G	PARTICIPANT	\N	PRESENT	0
689356	688395	19387D	PARTICIPANT	\N	PRESENT	0
689357	688395	19820Y	PARTICIPANT	\N	PRESENT	0
689358	688395	14219Q	PRESIDENT	0	PRESENT	0
689359	688395	19826F	PARTICIPANT	\N	PRESENT	0
689360	688395	20102Q	PARTICIPANT	\N	PRESENT	0
689361	688395	19599P	PARTICIPANT	\N	PRESENT	0
689362	688395	19637C	PARTICIPANT	\N	PRESENT	0
689363	688395	14237S	PARTICIPANT	\N	PRESENT	0
689364	688395	20100N	PARTICIPANT	\N	PRESENT	0
689365	688395	18083K	PARTICIPANT	\N	PRESENT	0
689366	688395	05012A	PARTICIPANT	\N	PRESENT	0
689367	688395	08060W	PARTICIPANT	\N	PRESENT	0
689368	688395	20020P	PARTICIPANT	\N	PRESENT	0
689369	688395	19685L	PARTICIPANT	\N	PRESENT	0
689370	688395	17367Q	PARTICIPANT	\N	PRESENT	0
689371	688395	19681G	PARTICIPANT	\N	PRESENT	0
689372	688395	19525U	PARTICIPANT	\N	PRESENT	0
689373	688395	20032T	PARTICIPANT	\N	PRESENT	0
689374	688395	20136B	PARTICIPANT	\N	PRESENT	0
689375	688395	14031R	PARTICIPANT	\N	PRESENT	0
689376	688395	19251M	PARTICIPANT	\N	PRESENT	0
689377	688395	20068G	PARTICIPANT	\N	PRESENT	0
689378	688395	19739H	PARTICIPANT	\N	PRESENT	0
689379	688395	19745F	PARTICIPANT	\N	PRESENT	0
689380	688395	20024T	PARTICIPANT	\N	PRESENT	0
689381	688395	17229F	PARTICIPANT	\N	PRESENT	0
689382	688395	19701S	PARTICIPANT	\N	EXCUSE	0
689383	688395	19503N	PARTICIPANT	\N	PRESENT	0
689384	688395	20046A	PARTICIPANT	\N	PRESENT	0
689387	688395	11101A	PARTICIPANT	\N	PRESENT	0
689388	688395	20038A	PARTICIPANT	\N	EXCUSE	0
689389	688395	20118Y	PARTICIPANT	\N	PRESENT	0
689390	688395	11065P	PARTICIPANT	\N	PRESENT	0
689391	688395	20096L	PARTICIPANT	\N	PRESENT	0
689527	689282	04045F	PARTICIPANT	\N	PRESENT	0
689528	689282	19954N	PARTICIPANT	\N	PRESENT	0
689529	689282	19563B	PARTICIPANT	\N	PRESENT	0
689530	689282	14038Y	PARTICIPANT	\N	PRESENT	0
694344	692429	19441R	PARTICIPANT	\N	PRESENT	0
694647	692431	08015R	PARTICIPANT	\N	PRESENT	0
694829	692487	19515S	PARTICIPANT	\N	PRESENT	0
694830	692487	19575F	PRESIDENT	0	PRESENT	0
694831	692487	20094J	PARTICIPANT	\N	PRESENT	0
694832	692487	20092G	PARTICIPANT	\N	PRESENT	0
694833	692487	14083S	PARTICIPANT	\N	PRESENT	0
694842	692487	19762G	PARTICIPANT	\N	PRESENT	0
694845	692487	14030Q	PARTICIPANT	\N	PRESENT	0
694848	694847	14231L	PRESIDENT	0	PRESENT	0
694849	694847	05012A	PARTICIPANT	\N	PRESENT	0
694850	694847	08010L	PARTICIPANT	\N	PRESENT	0
694851	694847	14215L	PARTICIPANT	\N	PRESENT	0
694852	694847	01057W	PARTICIPANT	\N	PRESENT	0
694853	694847	14229S	PARTICIPANT	\N	PRESENT	0
694854	694847	14257W	PARTICIPANT	\N	PRESENT	0
694855	694847	04045F	PARTICIPANT	\N	PRESENT	0
694856	694847	14071N	PARTICIPANT	\N	PRESENT	0
694857	694847	19447X	PARTICIPANT	\N	PRESENT	0
694858	694847	14217N	PARTICIPANT	\N	PRESENT	0
694859	694847	20090E	PARTICIPANT	\N	PRESENT	0
694860	694847	20062A	PARTICIPANT	\N	PRESENT	0
694861	694847	14187A	PARTICIPANT	\N	PRESENT	0
694862	694847	19782L	PARTICIPANT	\N	EXCUSE	0
694863	694847	20070A	PARTICIPANT	\N	EXCUSE	0
694864	694847	14327T	PARTICIPANT	\N	EXCUSE	0
694865	694847	19735D	PARTICIPANT	\N	EXCUSE	0
694866	694847	19565D	PARTICIPANT	\N	EXCUSE	0
694867	694847	19489J	PARTICIPANT	\N	EXCUSE	0
694868	694847	19826F	PARTICIPANT	\N	EXCUSE	0
694869	694847	19563B	PARTICIPANT	\N	EXCUSE	0
694870	694847	20122U	PARTICIPANT	\N	EXCUSE	0
694871	694847	20058E	PARTICIPANT	\N	EXCUSE	0
694878	694847	19573D	PARTICIPANT	\N	PRESENT	0
694879	694847	14053L	PARTICIPANT	\N	PRESENT	0
694891	692487	20054A	PARTICIPANT	\N	PRESENT	0
694893	694847	20022R	PARTICIPANT	\N	PRESENT	0
694895	694894	14133K	PARTICIPANT	\N	EXCUSE	0
694896	694894	14189C	PARTICIPANT	\N	EXCUSE	0
694897	694894	20104S	PARTICIPANT	\N	EXCUSE	0
694898	694894	20100N	PARTICIPANT	\N	PRESENT	0
694899	694894	14033T	PARTICIPANT	\N	PRESENT	0
694900	694894	14026U	PARTICIPANT	\N	EXCUSE	0
694901	694894	19725B	PARTICIPANT	\N	EXCUSE	0
694902	694894	19333N	PARTICIPANT	\N	PRESENT	0
694904	694894	14073Q	PARTICIPANT	\N	PRESENT	0
694905	694894	11026G	PARTICIPANT	\N	PRESENT	0
694906	694894	04070G	PARTICIPANT	\N	EXCUSE	0
694907	694894	14237S	PARTICIPANT	\N	EXCUSE	0
694908	694894	14331P	PRESIDENT	0	PRESENT	0
694909	694894	10015M	PARTICIPANT	\N	PRESENT	0
694910	694894	20098N	PARTICIPANT	\N	EXCUSE	0
694911	694894	19593H	PARTICIPANT	\N	PRESENT	0
694912	694894	20286Q	PARTICIPANT	\N	EXCUSE	0
694913	692486	14030Q	PARTICIPANT	\N	PRESENT	0
694914	692486	14083S	PARTICIPANT	\N	PRESENT	0
694915	692486	19762G	PARTICIPANT	\N	PRESENT	0
694916	692486	20092G	PARTICIPANT	\N	PRESENT	0
694917	692486	19575F	PARTICIPANT	\N	PRESENT	0
694918	692486	20054A	PARTICIPANT	\N	PRESENT	0
694919	692486	19515S	PRESIDENT	0	PRESENT	0
694920	692486	19251M	PARTICIPANT	\N	PRESENT	0
694955	694953	19703U	PARTICIPANT	\N	PRESENT	1
694956	694953	11031D	PARTICIPANT	\N	PRESENT	1
694957	694954	19703U	PARTICIPANT	\N	PRESENT	1
695036	695035	19709B	PARTICIPANT	\N	PRESENT	0
695037	695035	20264J	PARTICIPANT	\N	PRESENT	0
695038	695035	14147R	PARTICIPANT	\N	PRESENT	0
695039	695035	01058X	PARTICIPANT	\N	PRESENT	0
695040	695035	04043D	PARTICIPANT	\N	PRESENT	0
695041	695035	14331P	PARTICIPANT	\N	PRESENT	0
695042	695035	14255U	PARTICIPANT	\N	PRESENT	0
695043	695035	11027H	PARTICIPANT	\N	PRESENT	0
695044	695035	11026G	PARTICIPANT	\N	PRESENT	0
695045	695035	20266L	PARTICIPANT	\N	PRESENT	0
695046	695035	19671E	PARTICIPANT	\N	PRESENT	0
695048	695047	04033B	PARTICIPANT	\N	PRESENT	0
695049	695047	19251M	PARTICIPANT	\N	PRESENT	0
695050	695047	20248J	PARTICIPANT	\N	PRESENT	0
695051	695047	14055N	PARTICIPANT	\N	PRESENT	0
695052	695047	17737W	PARTICIPANT	\N	PRESENT	0
695053	695047	14037X	PARTICIPANT	\N	PRESENT	0
695054	695047	19593H	PARTICIPANT	\N	PRESENT	0
695055	695047	14021P	PARTICIPANT	\N	PRESENT	0
695056	695047	04059M	PARTICIPANT	\N	PRESENT	0
695057	695047	04042C	PARTICIPANT	\N	PRESENT	0
695060	695058	14097Y	PARTICIPANT	\N	PRESENT	0
695061	695058	14259Y	PARTICIPANT	\N	PRESENT	0
695147	695146	19711U	PARTICIPANT	\N	PRESENT	0
695148	695146	20050V	PARTICIPANT	\N	PRESENT	0
695186	695185	14133K	PARTICIPANT	\N	PRESENT	0
695187	695185	11066Q	PARTICIPANT	\N	PRESENT	0
695189	695188	17023S	PARTICIPANT	\N	PRESENT	0
695190	695188	11083R	PARTICIPANT	\N	PRESENT	0
695216	695213	86034E	PARTICIPANT	\N	PRESENT	0
695259	695193	08009T	PARTICIPANT	\N	PRESENT	0
695260	695193	01048V	PARTICIPANT	\N	PRESENT	0
695261	695213	19577H	PARTICIPANT	\N	PRESENT	0
695262	695193	11053K	PARTICIPANT	\N	PRESENT	0
695263	695213	19593H	PARTICIPANT	\N	PRESENT	0
695264	695213	20102Q	PARTICIPANT	\N	PRESENT	0
695265	695213	14231L	PARTICIPANT	\N	PRESENT	0
695266	695213	19745F	PARTICIPANT	\N	PRESENT	0
695267	695213	19675J	PARTICIPANT	\N	PRESENT	0
695268	694941	20130U	PARTICIPANT	\N	PRESENT	0
695269	694941	20090E	PARTICIPANT	\N	PRESENT	0
695270	694941	20066E	PARTICIPANT	\N	PRESENT	0
695271	694941	20040T	PARTICIPANT	\N	PRESENT	0
695272	694941	19657G	PARTICIPANT	\N	PRESENT	0
695273	694941	14217N	PARTICIPANT	\N	PRESENT	0
695274	694941	14223L	PARTICIPANT	\N	PRESENT	0
695275	694941	10006L	PRESIDENT	0	PRESENT	0
695276	694941	17779H	PARTICIPANT	\N	PRESENT	0
695277	695193	14189C	PARTICIPANT	\N	EXCUSE	0
695278	695193	19671E	PARTICIPANT	\N	EXCUSE	0
695281	694941	11097X	PARTICIPANT	\N	PRESENT	0
695282	694941	14026U	PARTICIPANT	\N	PRESENT	0
695283	694941	19553Y	PARTICIPANT	\N	PRESENT	0
695284	694941	14213J	PARTICIPANT	\N	PRESENT	0
695285	694941	19591F	PARTICIPANT	\N	PRESENT	0
695286	695213	14151M	PARTICIPANT	\N	PRESENT	0
695287	695213	19333N	PARTICIPANT	\N	PRESENT	0
695288	695213	20180F	PARTICIPANT	\N	PRESENT	0
695289	695213	20252E	PARTICIPANT	\N	PRESENT	0
695290	695213	14053L	PARTICIPANT	\N	PRESENT	0
695291	694941	14042U	PARTICIPANT	\N	PRESENT	0
695300	695215	14038Y	PARTICIPANT	\N	PRESENT	0
695301	695215	19467C	PARTICIPANT	\N	PRESENT	0
695302	695215	19768N	PARTICIPANT	\N	PRESENT	0
695303	695215	19515S	PARTICIPANT	\N	PRESENT	0
695304	695215	19782L	PARTICIPANT	\N	PRESENT	0
695305	695215	20092G	PARTICIPANT	\N	PRESENT	0
695306	695215	14357A	PARTICIPANT	\N	PRESENT	0
695307	695215	19413M	PARTICIPANT	\N	PRESENT	0
695308	695215	14033T	PARTICIPANT	\N	PRESENT	0
695309	695215	01025N	PARTICIPANT	\N	PRESENT	0
695310	695215	11090Q	PARTICIPANT	\N	PRESENT	0
695311	695215	20094J	PARTICIPANT	\N	PRESENT	0
695312	695215	04045F	PARTICIPANT	\N	PRESENT	0
695313	695215	20104S	PARTICIPANT	\N	PRESENT	0
695314	695215	14205J	PARTICIPANT	\N	PRESENT	0
695315	695215	19705W	PARTICIPANT	\N	PRESENT	0
695316	695215	19507S	PARTICIPANT	\N	PRESENT	0
695317	695215	08015R	PARTICIPANT	\N	PRESENT	0
695318	695215	19575F	PARTICIPANT	\N	PRESENT	0
695319	695215	19369B	PARTICIPANT	\N	PRESENT	0
695320	695215	19747H	PARTICIPANT	\N	PRESENT	0
695321	695213	14331P	PARTICIPANT	\N	PRESENT	0
695322	695213	19954N	PARTICIPANT	\N	PRESENT	0
695323	695213	14215L	PARTICIPANT	\N	PRESENT	0
695324	695213	01048V	PARTICIPANT	\N	PRESENT	0
695325	695213	20080C	PARTICIPANT	\N	PRESENT	0
695326	695213	19629C	PARTICIPANT	\N	PRESENT	0
695327	695213	14073Q	PARTICIPANT	\N	PRESENT	0
695328	695213	19747H	PARTICIPANT	\N	PRESENT	0
695329	695213	14225N	PARTICIPANT	\N	PRESENT	0
695330	695213	14107H	PARTICIPANT	\N	PRESENT	0
695331	695213	14033T	PARTICIPANT	\N	PRESENT	0
695333	695213	19782L	PARTICIPANT	\N	PRESENT	0
695334	695213	18193Q	PARTICIPANT	\N	PRESENT	0
695335	695215	20082E	PARTICIPANT	\N	EXCUSE	0
683900	683337	14331P	PARTICIPANT	\N	PRESENT	0
683901	683337	14253S	PARTICIPANT	\N	PRESENT	0
683902	683337	14225N	PRESIDENT	0	PRESENT	0
683903	683337	11012A	PARTICIPANT	\N	EXCUSE	0
683904	683337	20050V	PARTICIPANT	\N	EXCUSE	0
683905	683337	20044X	PARTICIPANT	\N	PRESENT	0
683906	683337	08009T	PARTICIPANT	\N	PRESENT	0
683907	683337	14327T	PARTICIPANT	\N	PRESENT	0
683908	683337	11048N	PARTICIPANT	\N	PRESENT	0
683909	683337	20080C	PARTICIPANT	\N	PRESENT	0
683910	683337	99004R	PARTICIPANT	\N	PRESENT	0
683911	683337	20070A	PARTICIPANT	\N	PRESENT	0
683912	683337	19349W	PARTICIPANT	\N	PRESENT	0
683913	683337	19531S	PARTICIPANT	\N	PRESENT	0
683914	683337	19335Q	PARTICIPANT	\N	PRESENT	0
683915	683337	08010L	PARTICIPANT	\N	PRESENT	0
683916	683337	19671E	PARTICIPANT	\N	PRESENT	0
683917	683337	20126Y	PARTICIPANT	\N	PRESENT	0
683918	683337	20116W	PARTICIPANT	\N	PRESENT	0
683919	683337	19479G	PARTICIPANT	\N	PRESENT	0
683920	683337	14083S	PARTICIPANT	\N	PRESENT	0
683921	683337	01048V	PARTICIPANT	\N	PRESENT	0
683922	683337	19762G	PARTICIPANT	\N	PRESENT	0
683923	683055	14053L	PARTICIPANT	\N	PRESENT	0
683924	683055	14111D	PARTICIPANT	\N	PRESENT	0
683925	683055	20074E	PARTICIPANT	\N	PRESENT	0
683926	683055	14001X	PARTICIPANT	\N	PRESENT	0
683927	683055	19585H	PARTICIPANT	\N	PRESENT	0
683928	683055	04047H	PARTICIPANT	\N	PRESENT	0
683929	683055	19447X	PARTICIPANT	\N	PRESENT	0
683930	683055	05008E	PARTICIPANT	\N	PRESENT	0
683931	683055	14089Y	PARTICIPANT	\N	PRESENT	0
683932	683055	19489J	PARTICIPANT	\N	PRESENT	0
683933	683055	17737W	PARTICIPANT	\N	PRESENT	0
683934	683055	95063L	PARTICIPANT	\N	PRESENT	0
683935	683055	20108W	PARTICIPANT	\N	PRESENT	0
683936	683055	14151M	PARTICIPANT	\N	PRESENT	0
683937	683055	14069U	PARTICIPANT	\N	PRESENT	0
683938	683055	14215L	PARTICIPANT	\N	PRESENT	0
683939	683055	11072N	PARTICIPANT	\N	PRESENT	0
683940	683055	20022R	PARTICIPANT	\N	EXCUSE	0
683941	683337	20086J	PARTICIPANT	\N	PRESENT	0
683942	683337	11053K	PARTICIPANT	\N	PRESENT	0
683943	683337	07029T	PARTICIPANT	\N	PRESENT	0
683944	683337	14173T	PARTICIPANT	\N	PRESENT	0
683945	683337	20252E	PARTICIPANT	\N	PRESENT	0
683946	683337	19711U	PARTICIPANT	\N	PRESENT	0
683949	683947	19511N	PARTICIPANT	\N	PRESENT	0
683950	683947	19569H	PARTICIPANT	\N	PRESENT	0
683951	683947	14225N	PARTICIPANT	\N	PRESENT	0
683952	683947	14083S	PARTICIPANT	\N	PRESENT	0
683953	683947	95041E	PARTICIPANT	\N	PRESENT	0
683955	683947	14105F	PARTICIPANT	\N	PRESENT	0
683956	683947	20028X	PARTICIPANT	\N	PRESENT	0
683957	683947	20084G	PARTICIPANT	\N	PRESENT	0
683959	683947	19745F	PARTICIPANT	\N	PRESENT	0
683960	683947	14231L	PARTICIPANT	\N	PRESENT	0
683963	683947	92040Q	PARTICIPANT	\N	PRESENT	0
683964	683947	14107H	PARTICIPANT	\N	PRESENT	0
683965	683947	19583F	PARTICIPANT	\N	PRESENT	0
683966	683947	11041F	PARTICIPANT	\N	PRESENT	0
683967	683947	20068G	PARTICIPANT	\N	PRESENT	0
683968	683947	19741B	PARTICIPANT	\N	PRESENT	0
683972	683947	19721W	PARTICIPANT	\N	PRESENT	0
683974	683947	20062A	PARTICIPANT	\N	PRESENT	0
683975	683947	14053L	PARTICIPANT	\N	PRESENT	0
683976	683947	20072C	PARTICIPANT	\N	PRESENT	0
683977	683947	19581D	PARTICIPANT	\N	PRESENT	0
683978	683947	01058X	PARTICIPANT	\N	PRESENT	0
683981	683947	19683J	PARTICIPANT	\N	PRESENT	0
683982	683947	19647E	PARTICIPANT	\N	PRESENT	0
683983	683947	20074E	PARTICIPANT	\N	PRESENT	0
683984	683947	19593H	PARTICIPANT	\N	PRESENT	0
683985	683947	19729F	PARTICIPANT	\N	PRESENT	0
683986	683947	19413M	PARTICIPANT	\N	PRESENT	0
683987	683947	20042V	PARTICIPANT	\N	PRESENT	0
683988	683947	19631V	PARTICIPANT	\N	PRESENT	0
683989	683947	19629C	PARTICIPANT	\N	PRESENT	0
683990	683947	14111D	PARTICIPANT	\N	PRESENT	0
683991	683947	20122U	PARTICIPANT	\N	PRESENT	0
683992	683947	19758L	PARTICIPANT	\N	PRESENT	0
683993	683947	11012A	PARTICIPANT	\N	PRESENT	0
683994	683947	19527W	PARTICIPANT	\N	PRESENT	0
683995	683947	11103C	PARTICIPANT	\N	PRESENT	0
683996	683947	19369B	PARTICIPANT	\N	PRESENT	0
683997	683947	19585H	PARTICIPANT	\N	PRESENT	0
683998	683947	19782L	PARTICIPANT	\N	PRESENT	0
683999	683947	19691J	PARTICIPANT	\N	PRESENT	0
684000	683947	08009T	PARTICIPANT	\N	PRESENT	0
684001	683947	19739H	PARTICIPANT	\N	PRESENT	0
684002	683947	20018V	PARTICIPANT	\N	PRESENT	0
684003	683947	11048N	PARTICIPANT	\N	PRESENT	0
684004	683947	04057K	PARTICIPANT	\N	PRESENT	0
684005	683947	19319Q	PARTICIPANT	\N	PRESENT	0
684006	683947	19695N	PARTICIPANT	\N	PRESENT	0
684007	683947	19762G	PARTICIPANT	\N	PRESENT	0
684008	683947	20120S	PARTICIPANT	\N	PRESENT	0
684009	683947	14327T	PARTICIPANT	\N	PRESENT	0
684010	683947	11070L	PARTICIPANT	\N	PRESENT	0
684011	683947	14267Y	PARTICIPANT	\N	PRESENT	0
684012	683947	11085T	PARTICIPANT	\N	PRESENT	0
684013	683947	01025N	PARTICIPANT	\N	PRESENT	0
684014	683947	04085P	PARTICIPANT	\N	PRESENT	0
684015	683947	19760E	PARTICIPANT	\N	PRESENT	0
684016	683947	11040E	PARTICIPANT	\N	PRESENT	0
684017	683947	20102Q	PARTICIPANT	\N	PRESENT	0
684018	683947	20046A	PARTICIPANT	\N	PRESENT	0
684019	683947	20112S	PARTICIPANT	\N	PRESENT	0
684020	683947	20100N	PARTICIPANT	\N	PRESENT	0
684021	683947	20110Q	PARTICIPANT	\N	PRESENT	0
684022	683947	19347U	PARTICIPANT	\N	PRESENT	0
684023	683947	20914V	PARTICIPANT	\N	PRESENT	0
684024	683947	11033F	PARTICIPANT	\N	PRESENT	0
684025	683947	19659J	PARTICIPANT	\N	PRESENT	0
684026	683947	19637C	PARTICIPANT	\N	PRESENT	0
684027	683947	20146D	PARTICIPANT	\N	PRESENT	0
684028	683947	04045F	PARTICIPANT	\N	PRESENT	0
684029	683947	19301E	PARTICIPANT	\N	PRESENT	0
684030	683947	11072N	PARTICIPANT	\N	PRESENT	0
684031	683947	19329S	PARTICIPANT	\N	PRESENT	0
684032	683947	08061X	PARTICIPANT	\N	PRESENT	0
684033	683947	11065P	PARTICIPANT	\N	PRESENT	0
684034	683947	14251Q	PARTICIPANT	\N	PRESENT	0
684035	683947	14211G	PARTICIPANT	\N	PRESENT	0
684036	683947	19545Y	PARTICIPANT	\N	PRESENT	0
684037	683947	14221J	PARTICIPANT	\N	PRESENT	0
684038	683947	19553Y	PARTICIPANT	\N	PRESENT	0
684039	683947	19387D	PARTICIPANT	\N	PRESENT	0
684040	683947	14207L	PARTICIPANT	\N	PRESENT	0
684041	683947	20116W	PARTICIPANT	\N	PRESENT	0
684042	683947	14249W	PARTICIPANT	\N	PRESENT	0
684043	683947	19525U	PARTICIPANT	\N	PRESENT	0
684044	683947	08073C	PARTICIPANT	\N	PRESENT	0
684045	683947	19717B	PARTICIPANT	\N	PRESENT	0
684046	683947	19866P	PARTICIPANT	\N	PRESENT	0
684047	683947	20132W	PARTICIPANT	\N	PRESENT	0
684048	683947	98022P	PARTICIPANT	\N	PRESENT	0
684049	683947	20128B	PARTICIPANT	\N	PRESENT	0
684050	683947	20266L	PARTICIPANT	\N	PRESENT	0
684051	683947	20130U	PARTICIPANT	\N	PRESENT	0
684052	683947	19349W	PARTICIPANT	\N	PRESENT	0
684053	683947	19651A	PARTICIPANT	\N	PRESENT	0
684054	683947	20092G	PARTICIPANT	\N	PRESENT	0
684055	683947	14055N	PARTICIPANT	\N	PRESENT	0
684056	683947	01028R	PARTICIPANT	\N	PRESENT	0
684057	683947	04059M	PARTICIPANT	\N	PRESENT	0
684058	683947	14021P	PARTICIPANT	\N	PRESENT	0
684059	683947	01062T	PARTICIPANT	\N	PRESENT	0
684060	683947	11045K	PARTICIPANT	\N	PRESENT	0
684061	683947	11066Q	PARTICIPANT	\N	PRESENT	0
684062	683947	19333N	PARTICIPANT	\N	PRESENT	0
684063	683947	11104D	PARTICIPANT	\N	PRESENT	0
684064	683947	19649G	PARTICIPANT	\N	PRESENT	0
684065	683947	14001X	PARTICIPANT	\N	PRESENT	0
684066	683947	14151M	PARTICIPANT	\N	PRESENT	0
684067	683947	19687N	PARTICIPANT	\N	PRESENT	0
700613	698970	04043D	PARTICIPANT	\N	PRESENT	0
700614	698970	20134Y	PARTICIPANT	\N	PRESENT	0
700615	698970	20110Q	PARTICIPANT	\N	PRESENT	0
700616	698970	11065P	PARTICIPANT	\N	PRESENT	0
700617	698970	14069U	PARTICIPANT	\N	PRESENT	0
700618	698970	11031D	PARTICIPANT	\N	PRESENT	0
700619	698970	14053L	PARTICIPANT	\N	PRESENT	0
700620	698970	20130U	PARTICIPANT	\N	PRESENT	0
700621	698970	19347U	PARTICIPANT	\N	PRESENT	0
700622	698970	20142Y	PARTICIPANT	\N	PRESENT	0
700623	698970	04092N	PARTICIPANT	\N	PRESENT	0
700624	698970	20266L	PARTICIPANT	\N	PRESENT	0
700625	698970	19651A	PARTICIPANT	\N	PRESENT	0
700626	698970	19747H	PARTICIPANT	\N	PRESENT	0
700627	698970	19782L	PARTICIPANT	\N	PRESENT	0
700628	698970	08010L	PARTICIPANT	\N	PRESENT	0
700629	698970	04047H	PARTICIPANT	\N	PRESENT	0
700630	698970	19525U	PARTICIPANT	\N	PRESENT	0
700631	698970	11083R	PARTICIPANT	\N	PRESENT	0
700632	698970	17737W	PARTICIPANT	\N	PRESENT	0
700633	698970	14026U	PARTICIPANT	\N	PRESENT	0
700634	698970	19703U	PARTICIPANT	\N	PRESENT	0
700635	698970	19329S	PARTICIPANT	\N	PRESENT	0
700636	698970	11101A	PARTICIPANT	\N	PRESENT	0
700637	698970	20106U	PARTICIPANT	\N	PRESENT	0
700638	698970	14037X	PARTICIPANT	\N	PRESENT	0
700639	698970	19591F	PARTICIPANT	\N	PRESENT	0
700640	698970	19575F	PARTICIPANT	\N	PRESENT	0
700641	698970	99004R	PARTICIPANT	\N	PRESENT	0
700642	698970	20078J	PARTICIPANT	\N	PRESENT	0
700643	698970	04045F	PARTICIPANT	\N	PRESENT	0
700644	698970	95063L	PARTICIPANT	\N	PRESENT	0
700645	698970	19349W	PARTICIPANT	\N	PRESENT	0
700646	698970	20076G	PARTICIPANT	\N	PRESENT	0
700647	698970	08061X	PARTICIPANT	\N	PRESENT	0
700648	698970	20146D	PARTICIPANT	\N	PRESENT	0
700649	698970	11072N	PARTICIPANT	\N	PRESENT	0
700650	698970	19679N	PARTICIPANT	\N	PRESENT	0
700651	698970	11033F	PARTICIPANT	\N	PRESENT	0
700652	698970	01060R	PARTICIPANT	\N	PRESENT	0
700653	698970	20128B	PARTICIPANT	\N	PRESENT	0
700654	698970	01048V	PARTICIPANT	\N	PRESENT	0
700665	698970	20116W	PARTICIPANT	\N	PRESENT	0
700656	698970	14207L	PARTICIPANT	\N	PRESENT	0
700657	698970	14223L	PARTICIPANT	\N	PRESENT	0
700658	698970	11012A	PARTICIPANT	\N	PRESENT	0
700659	698970	14331P	PARTICIPANT	\N	PRESENT	0
700660	698970	19866P	PARTICIPANT	\N	PRESENT	0
700661	698970	97011G	PARTICIPANT	\N	PRESENT	0
700662	698970	19387D	PARTICIPANT	\N	PRESENT	0
700663	698970	20032T	PARTICIPANT	\N	PRESENT	0
700664	698970	14147R	PARTICIPANT	\N	PRESENT	0
700666	698970	20132W	PARTICIPANT	\N	PRESENT	0
700667	698970	14211G	PARTICIPANT	\N	PRESENT	0
700668	698970	11064N	PARTICIPANT	\N	PRESENT	0
700669	698970	14111D	PARTICIPANT	\N	PRESENT	0
700670	698970	20050V	PARTICIPANT	\N	PRESENT	0
700671	698970	19415P	PARTICIPANT	\N	PRESENT	0
700672	698970	01028R	PARTICIPANT	\N	PRESENT	0
700673	698970	19715Y	PARTICIPANT	\N	PRESENT	0
700674	698970	11045K	PARTICIPANT	\N	PRESENT	0
700676	698970	19693L	PARTICIPANT	\N	PRESENT	0
700677	698970	17779H	PARTICIPANT	\N	PRESENT	0
700679	698970	19673G	PARTICIPANT	\N	PRESENT	0
700680	698970	05008E	PARTICIPANT	\N	PRESENT	0
700682	698970	14021P	PARTICIPANT	\N	PRESENT	0
700684	698970	19647E	PARTICIPANT	\N	PRESENT	0
700685	698970	14229S	PARTICIPANT	\N	PRESENT	0
700686	698970	14215L	PARTICIPANT	\N	PRESENT	0
700687	698970	19421M	PARTICIPANT	\N	PRESENT	0
700688	698970	19649G	PARTICIPANT	\N	PRESENT	0
700689	698970	19333N	PARTICIPANT	\N	PRESENT	0
700690	698970	19489J	PARTICIPANT	\N	PRESENT	0
700691	698970	20172F	PARTICIPANT	\N	PRESENT	0
700692	698970	20114U	PARTICIPANT	\N	PRESENT	0
700693	698970	14355X	PARTICIPANT	\N	PRESENT	0
700694	698970	11067R	PARTICIPANT	\N	PRESENT	0
700695	698970	14097Y	PARTICIPANT	\N	PRESENT	0
700696	698970	19683J	PARTICIPANT	\N	PRESENT	0
700697	698970	19820Y	PARTICIPANT	\N	PRESENT	0
700698	698970	01062T	PARTICIPANT	\N	PRESENT	0
700699	698970	19549D	PARTICIPANT	\N	PRESENT	0
700700	698970	11066Q	PARTICIPANT	\N	PRESENT	0
700701	698970	14281W	PARTICIPANT	\N	PRESENT	0
700702	698970	20070A	PARTICIPANT	\N	PRESENT	0
700703	698970	20060X	PARTICIPANT	\N	PRESENT	0
700704	698970	14257W	PARTICIPANT	\N	PRESENT	0
700705	698970	18193Q	PARTICIPANT	\N	PRESENT	0
700706	698970	20264J	PARTICIPANT	\N	PRESENT	0
700707	698970	19725B	PARTICIPANT	\N	PRESENT	0
700708	698970	20084G	PARTICIPANT	\N	PRESENT	0
700709	698970	20082E	PARTICIPANT	\N	PRESENT	0
700710	698970	19503N	PARTICIPANT	\N	PRESENT	0
700711	698970	14121F	PARTICIPANT	\N	PRESENT	0
700712	698970	11110B	PARTICIPANT	\N	PRESENT	0
700713	698970	19631V	PARTICIPANT	\N	PRESENT	0
700714	698970	20094J	PARTICIPANT	\N	PRESENT	0
700715	698970	19251M	PARTICIPANT	\N	PRESENT	0
700716	698970	20044X	PARTICIPANT	\N	PRESENT	0
700717	698970	19527W	PARTICIPANT	\N	PRESENT	0
700718	698970	11026G	PARTICIPANT	\N	PRESENT	0
700720	698970	20030R	PARTICIPANT	\N	PRESENT	0
700721	698970	20064C	PARTICIPANT	\N	PRESENT	0
700722	698970	20028X	PARTICIPANT	\N	PRESENT	0
700723	698970	14189C	PARTICIPANT	\N	PRESENT	0
700724	698970	20042V	PARTICIPANT	\N	PRESENT	0
700725	700719	19954N	PARTICIPANT	\N	PRESENT	0
700726	698970	07004J	PARTICIPANT	\N	PRESENT	0
700727	698970	19699S	PARTICIPANT	\N	PRESENT	0
700728	700719	19649G	PARTICIPANT	\N	PRESENT	0
700729	698970	11080N	PARTICIPANT	\N	PRESENT	0
700730	698970	14255U	PARTICIPANT	\N	PRESENT	0
700731	698970	11053K	PARTICIPANT	\N	PRESENT	0
700732	698970	20052X	PARTICIPANT	\N	PRESENT	0
700733	698970	01043Q	PARTICIPANT	\N	PRESENT	0
700734	698970	20286Q	PARTICIPANT	\N	PRESENT	0
700735	698970	17229F	PARTICIPANT	\N	PRESENT	0
700736	698970	14231L	PARTICIPANT	\N	PRESENT	0
700737	698970	19611R	PARTICIPANT	\N	PRESENT	0
700738	698970	20298U	PARTICIPANT	\N	PRESENT	0
700786	698970	19531S	PARTICIPANT	\N	PRESENT	0
700740	698970	14030Q	PARTICIPANT	\N	PRESENT	0
700741	698970	08011M	PARTICIPANT	\N	PRESENT	0
700742	698970	07033P	PARTICIPANT	\N	PRESENT	0
700743	698970	20074E	PARTICIPANT	\N	PRESENT	0
700744	698970	04008A	PARTICIPANT	\N	PRESENT	0
700745	698970	19515S	PARTICIPANT	\N	PRESENT	0
700746	698970	19447X	PARTICIPANT	\N	PRESENT	0
700748	698970	08034U	PARTICIPANT	\N	PRESENT	0
700749	698970	19766L	PARTICIPANT	\N	PRESENT	0
700750	698970	19533U	PARTICIPANT	\N	PRESENT	0
700751	698970	20098N	PARTICIPANT	\N	PRESENT	0
700752	698970	20062A	PARTICIPANT	\N	PRESENT	0
700753	698970	14173T	PARTICIPANT	\N	PRESENT	0
700754	698970	14205J	PARTICIPANT	\N	PRESENT	0
700755	698970	19441R	PARTICIPANT	\N	PRESENT	0
700756	698970	19826F	PARTICIPANT	\N	PRESENT	0
700757	698970	20040T	PARTICIPANT	\N	PRESENT	0
700758	698970	20248J	PARTICIPANT	\N	PRESENT	0
700759	698970	14073Q	PARTICIPANT	\N	PRESENT	0
700760	698970	14219Q	PARTICIPANT	\N	PRESENT	0
700761	698970	08009T	PARTICIPANT	\N	PRESENT	0
700762	698970	08069G	PARTICIPANT	\N	PRESENT	0
700763	698970	19691J	PARTICIPANT	\N	PRESENT	0
700764	698970	16685X	PARTICIPANT	\N	PRESENT	0
700765	698970	19335Q	PARTICIPANT	\N	PRESENT	0
700766	698970	19685L	PARTICIPANT	\N	PRESENT	0
700768	698970	19569H	PARTICIPANT	\N	PRESENT	0
700772	698970	19713W	PARTICIPANT	\N	PRESENT	0
700773	698970	01034P	PARTICIPANT	\N	PRESENT	0
700774	698970	19479G	PARTICIPANT	\N	PRESENT	0
700775	698970	19739H	PARTICIPANT	\N	PRESENT	0
700776	698970	11010L	PARTICIPANT	\N	PRESENT	0
700777	698970	20144B	PARTICIPANT	\N	PRESENT	0
700778	698970	20066E	PARTICIPANT	\N	PRESENT	0
700780	698970	14251Q	PARTICIPANT	\N	PRESENT	0
700781	698970	01024M	PARTICIPANT	\N	PRESENT	0
700785	698970	14109K	PARTICIPANT	\N	PRESENT	0
700787	698970	14083S	PARTICIPANT	\N	PRESENT	0
700788	698970	11109J	PARTICIPANT	\N	PRESENT	0
700789	698970	14151M	PARTICIPANT	\N	PRESENT	0
683667	683221	20024T	PARTICIPANT	\N	PRESENT	0
683668	683221	14231L	PARTICIPANT	\N	PRESENT	0
683669	683221	14069U	PARTICIPANT	\N	PRESENT	0
683670	683221	20030R	PARTICIPANT	\N	PRESENT	0
683725	683222	99004R	PARTICIPANT	\N	PRESENT	0
683726	683222	01058X	PARTICIPANT	\N	PRESENT	0
683727	683222	14133K	PARTICIPANT	\N	PRESENT	0
683781	683222	14249W	PARTICIPANT	\N	PRESENT	0
683779	683222	14083S	PARTICIPANT	\N	PRESENT	0
683730	683222	19347U	PARTICIPANT	\N	PRESENT	0
683731	683222	95041E	PARTICIPANT	\N	PRESENT	0
683732	683222	11041F	PARTICIPANT	\N	PRESENT	0
683733	683222	14073Q	PARTICIPANT	\N	PRESENT	0
683734	683222	11070L	PARTICIPANT	\N	PRESENT	0
683782	683222	04047H	PARTICIPANT	\N	PRESENT	0
683780	683222	11064N	PARTICIPANT	\N	PRESENT	0
683737	683222	20044X	PARTICIPANT	\N	PRESENT	0
683738	683222	01062T	PARTICIPANT	\N	PRESENT	0
683739	683222	19709B	PARTICIPANT	\N	PRESENT	0
683740	683222	20034V	PARTICIPANT	\N	PRESENT	0
683783	683222	19747H	PARTICIPANT	\N	PRESENT	0
683742	683222	08047A	PARTICIPANT	\N	PRESENT	0
683785	683222	14055N	PARTICIPANT	\N	PRESENT	0
683744	683222	20072C	PARTICIPANT	\N	PRESENT	0
683745	683222	11083R	PARTICIPANT	\N	PRESENT	0
683784	683222	11027H	PARTICIPANT	\N	PRESENT	0
683747	683222	12041X	PARTICIPANT	\N	PRESENT	0
683748	683222	14038Y	PARTICIPANT	\N	PRESENT	0
683786	683222	04042C	PARTICIPANT	\N	PRESENT	0
683750	683222	19421M	PARTICIPANT	\N	PRESENT	0
683751	683222	14255U	PARTICIPANT	\N	PRESENT	0
683752	683222	20100N	PARTICIPANT	\N	PRESENT	0
683787	683222	14225N	PARTICIPANT	\N	PRESENT	0
683788	683222	07004J	PARTICIPANT	\N	PRESENT	0
683755	683222	19669L	PARTICIPANT	\N	PRESENT	0
683756	683222	19349W	PARTICIPANT	\N	PRESENT	0
683757	683222	14215L	PARTICIPANT	\N	PRESENT	0
683758	683222	16685X	PARTICIPANT	\N	PRESENT	0
683759	683222	20016T	PARTICIPANT	\N	PRESENT	0
683789	683222	08061X	PARTICIPANT	\N	PRESENT	0
683761	683222	19651A	PARTICIPANT	\N	PRESENT	0
683762	683222	14193X	PARTICIPANT	\N	PRESENT	0
683790	683222	20026V	PARTICIPANT	\N	PRESENT	0
683764	683222	20070A	PARTICIPANT	\N	PRESENT	0
683765	683222	11012A	PARTICIPANT	\N	PRESENT	0
683766	683222	07029T	PARTICIPANT	\N	PRESENT	0
683791	683222	19687N	PARTICIPANT	\N	PRESENT	0
683768	683222	08034U	PARTICIPANT	\N	PRESENT	0
683792	683222	11048N	PARTICIPANT	\N	PRESENT	0
683770	683222	14331P	PARTICIPANT	\N	PRESENT	0
683771	683222	19762G	PARTICIPANT	\N	PRESENT	0
683772	683222	14037X	PARTICIPANT	\N	PRESENT	0
683773	683222	19479G	PARTICIPANT	\N	PRESENT	0
683793	683222	20092G	PARTICIPANT	\N	PRESENT	0
683775	683222	20024T	PARTICIPANT	\N	PRESENT	0
683776	683222	14231L	PARTICIPANT	\N	PRESENT	0
683777	683222	14069U	PARTICIPANT	\N	PRESENT	0
683778	683222	20030R	PARTICIPANT	\N	PRESENT	0
683794	683222	20108W	PARTICIPANT	\N	PRESENT	0
683795	683222	20080C	PARTICIPANT	\N	PRESENT	0
683796	683222	20110Q	PARTICIPANT	\N	PRESENT	0
683797	683222	14021P	PARTICIPANT	\N	PRESENT	0
683798	683222	14030Q	PARTICIPANT	\N	PRESENT	0
683844	683224	11045K	PARTICIPANT	\N	PRESENT	0
683845	683224	19687N	PARTICIPANT	\N	PRESENT	0
683846	683224	19251M	PARTICIPANT	\N	PRESENT	0
683847	683224	19647E	PARTICIPANT	\N	PRESENT	0
683848	683224	20110Q	PARTICIPANT	\N	PRESENT	0
683849	683224	20914V	PARTICIPANT	\N	PRESENT	0
683850	683224	20100N	PARTICIPANT	\N	PRESENT	0
683851	683224	11012A	PARTICIPANT	\N	PRESENT	0
683852	683224	11064N	PARTICIPANT	\N	PRESENT	0
683853	683224	11048N	PARTICIPANT	\N	PRESENT	0
683854	683224	07029T	PARTICIPANT	\N	PRESENT	0
683860	683224	19711U	PARTICIPANT	\N	PRESENT	0
683856	683224	14021P	PARTICIPANT	\N	PRESENT	0
683857	683224	14187A	PARTICIPANT	\N	PRESENT	0
683858	683224	14331P	PARTICIPANT	\N	PRESENT	0
683859	683224	19703U	PARTICIPANT	\N	PRESENT	0
683861	683224	20034V	PARTICIPANT	\N	PRESENT	0
683862	683224	20044X	PARTICIPANT	\N	PRESENT	0
683863	683224	19349W	PARTICIPANT	\N	PRESENT	0
683864	683224	14038Y	PARTICIPANT	\N	PRESENT	0
683865	683224	20054A	PARTICIPANT	\N	PRESENT	0
683866	683224	14030Q	PARTICIPANT	\N	PRESENT	0
683867	683224	14215L	PARTICIPANT	\N	PRESENT	0
683868	683224	19347U	PARTICIPANT	\N	PRESENT	0
683869	683224	19479G	PARTICIPANT	\N	PRESENT	0
683873	683224	14221J	PARTICIPANT	\N	PRESENT	0
683871	683224	01024M	PARTICIPANT	\N	PRESENT	0
683872	683224	20092G	PARTICIPANT	\N	PRESENT	0
683874	683224	19713W	PARTICIPANT	\N	PRESENT	0
683875	683224	20080C	PARTICIPANT	\N	PRESENT	0
683876	683224	20026V	PARTICIPANT	\N	PRESENT	0
683877	683224	20070A	PARTICIPANT	\N	PRESENT	0
683878	683224	19768N	PARTICIPANT	\N	PRESENT	0
683879	683224	20066E	PARTICIPANT	\N	PRESENT	0
683880	683224	14225N	PARTICIPANT	\N	PRESENT	0
683881	683224	14193X	PARTICIPANT	\N	PRESENT	0
683882	683224	19709B	PARTICIPANT	\N	PRESENT	0
683883	683224	20108W	PARTICIPANT	\N	PRESENT	0
683884	683224	08061X	PARTICIPANT	\N	PRESENT	0
683885	683224	19741B	PARTICIPANT	\N	PRESENT	0
683886	683224	04085P	PARTICIPANT	\N	PRESENT	0
683887	683224	19421M	PARTICIPANT	\N	PRESENT	0
683888	683224	20124W	PARTICIPANT	\N	PRESENT	0
683889	683224	14083S	PARTICIPANT	\N	PRESENT	0
695338	695215	20144B	PARTICIPANT	\N	EXCUSE	0
695339	695213	19631V	PARTICIPANT	\N	PRESENT	0
695340	695213	20072C	PARTICIPANT	\N	PRESENT	0
695341	695215	08028W	PARTICIPANT	\N	EXCUSE	0
695342	695213	19515S	PARTICIPANT	\N	PRESENT	0
695343	695213	14038Y	PARTICIPANT	\N	PRESENT	0
695344	695213	19413M	PARTICIPANT	\N	PRESENT	0
695345	695213	14267Y	PARTICIPANT	\N	PRESENT	0
695346	695213	19511N	PARTICIPANT	\N	PRESENT	0
695347	695213	19649G	PARTICIPANT	\N	PRESENT	0
695348	695213	14195A	PARTICIPANT	\N	PRESENT	0
695349	695213	19369B	PARTICIPANT	\N	PRESENT	0
695350	695213	20068G	PARTICIPANT	\N	PRESENT	0
695351	695213	08060W	PARTICIPANT	\N	PRESENT	0
695352	695213	04045F	PARTICIPANT	\N	PRESENT	0
695353	695213	19651A	PARTICIPANT	\N	PRESENT	0
695354	695213	20128B	PARTICIPANT	\N	PRESENT	0
695355	695213	14179A	PARTICIPANT	\N	PRESENT	0
695356	695213	08009T	PARTICIPANT	\N	PRESENT	0
695357	695213	19725B	PARTICIPANT	\N	PRESENT	0
695358	695213	20110Q	PARTICIPANT	\N	PRESENT	0
695359	695213	20036X	PARTICIPANT	\N	PRESENT	0
695360	695213	19569H	PARTICIPANT	\N	PRESENT	0
695361	695213	98022P	PARTICIPANT	\N	PRESENT	0
695362	695213	19349W	PARTICIPANT	\N	PRESENT	0
695363	695213	19705W	PARTICIPANT	\N	PRESENT	0
695364	695213	19707Y	PARTICIPANT	\N	PRESENT	0
695365	695213	04085P	PARTICIPANT	\N	PRESENT	0
695366	695213	19585H	PARTICIPANT	\N	PRESENT	0
695367	695213	11054L	PARTICIPANT	\N	PRESENT	0
695368	695213	08069G	PARTICIPANT	\N	PRESENT	0
695369	695213	04043D	PARTICIPANT	\N	PRESENT	0
695370	695213	20092G	PARTICIPANT	\N	PRESENT	0
695371	695213	11012A	PARTICIPANT	\N	PRESENT	0
695372	695213	01025N	PARTICIPANT	\N	PRESENT	0
695373	695213	20146D	PARTICIPANT	\N	PRESENT	0
695374	695213	19687N	PARTICIPANT	\N	PRESENT	0
695375	695193	20116W	PARTICIPANT	\N	EXCUSE	0
695376	695213	12041X	PARTICIPANT	\N	PRESENT	0
695377	695213	11077T	PARTICIPANT	\N	PRESENT	0
695378	695213	11031D	PARTICIPANT	\N	PRESENT	0
695379	695213	20142Y	PARTICIPANT	\N	PRESENT	0
695380	695213	20130U	PARTICIPANT	\N	PRESENT	0
695381	695213	19329S	PARTICIPANT	\N	PRESENT	0
695382	695213	20106U	PARTICIPANT	\N	PRESENT	0
695383	695213	19621T	PARTICIPANT	\N	PRESENT	0
695384	695213	14037X	PARTICIPANT	\N	PRESENT	0
695497	695213	19619A	PARTICIPANT	\N	PRESENT	0
695498	695213	19713W	PARTICIPANT	\N	PRESENT	0
695499	695213	14275Y	PARTICIPANT	\N	PRESENT	0
695500	695213	11115U	PARTICIPANT	\N	PRESENT	0
695501	695213	20126Y	PARTICIPANT	\N	PRESENT	0
695502	695213	20124W	PARTICIPANT	\N	PRESENT	0
695503	695213	01058X	PARTICIPANT	\N	PRESENT	0
695504	695213	08056B	PARTICIPANT	\N	PRESENT	0
695505	695213	14059S	PARTICIPANT	\N	PRESENT	0
695506	695213	20062A	PARTICIPANT	\N	PRESENT	0
695507	695213	20090E	PARTICIPANT	\N	PRESENT	0
695508	695213	19768N	PARTICIPANT	\N	PRESENT	0
695509	695213	08015R	PARTICIPANT	\N	PRESENT	0
695510	695213	19657G	PARTICIPANT	\N	PRESENT	0
695511	695213	07029T	PARTICIPANT	\N	PRESENT	0
695512	695213	20058E	PARTICIPANT	\N	PRESENT	0
695513	695213	19489J	PARTICIPANT	\N	PRESENT	0
695514	695213	19701S	PARTICIPANT	\N	PRESENT	0
695515	695213	20152B	PARTICIPANT	\N	PRESENT	0
695519	695213	04047H	PARTICIPANT	\N	PRESENT	0
695517	695213	19507S	PARTICIPANT	\N	PRESENT	0
695518	695213	11070L	PARTICIPANT	\N	PRESENT	0
695520	695213	04035D	PARTICIPANT	\N	PRESENT	0
695521	695213	11090Q	PARTICIPANT	\N	PRESENT	0
695525	695213	20064C	PARTICIPANT	\N	PRESENT	0
695523	695213	07004J	PARTICIPANT	\N	PRESENT	0
695524	695213	14030Q	PARTICIPANT	\N	PRESENT	0
695526	695213	14249W	PARTICIPANT	\N	PRESENT	0
695527	695213	20108W	PARTICIPANT	\N	PRESENT	0
695528	695213	20248J	PARTICIPANT	\N	PRESENT	0
695529	695213	19691J	PARTICIPANT	\N	PRESENT	0
695530	695213	19693L	PARTICIPANT	\N	PRESENT	0
695531	695213	19383Y	PARTICIPANT	\N	PRESENT	0
695532	695213	20286Q	PARTICIPANT	\N	PRESENT	0
695533	695213	01060R	PARTICIPANT	\N	PRESENT	0
695534	695213	08034U	PARTICIPANT	\N	PRESENT	0
695535	695213	20120S	PARTICIPANT	\N	PRESENT	0
695544	695213	14255U	PARTICIPANT	\N	PRESENT	0
695539	695213	04071H	PARTICIPANT	\N	PRESENT	0
695540	695213	14083S	PARTICIPANT	\N	PRESENT	0
695541	695213	14123H	PARTICIPANT	\N	PRESENT	0
695542	695213	20032T	PARTICIPANT	\N	PRESENT	0
695549	695213	20076G	PARTICIPANT	\N	PRESENT	0
695545	695213	95041E	PARTICIPANT	\N	PRESENT	0
695546	695213	20050V	PARTICIPANT	\N	PRESENT	0
695547	695213	14237S	PARTICIPANT	\N	PRESENT	0
695548	695213	19762G	PARTICIPANT	\N	PRESENT	0
695560	695213	19057M	PARTICIPANT	\N	PRESENT	0
695552	695213	19699S	PARTICIPANT	\N	PRESENT	0
695553	695213	11048N	PARTICIPANT	\N	PRESENT	0
695556	695213	20104S	PARTICIPANT	\N	PRESENT	0
695562	695213	20100N	PARTICIPANT	\N	PRESENT	0
695568	695213	11026G	PARTICIPANT	\N	PRESENT	0
695569	695213	11066Q	PARTICIPANT	\N	PRESENT	0
695572	695213	20054A	PARTICIPANT	\N	PRESENT	0
695574	695213	20266L	PARTICIPANT	\N	PRESENT	0
695573	695213	19575F	PARTICIPANT	\N	PRESENT	0
695822	695149	95063L	PARTICIPANT	\N	PRESENT	0
695823	695149	18193Q	PARTICIPANT	\N	PRESENT	0
695824	695149	20102Q	PARTICIPANT	\N	PRESENT	0
695825	695149	19725B	PARTICIPANT	\N	PRESENT	0
695826	695149	20134Y	PARTICIPANT	\N	PRESENT	0
695827	695149	20100N	PARTICIPANT	\N	PRESENT	0
695828	695149	19647E	PARTICIPANT	\N	PRESENT	0
695829	695149	20266L	PARTICIPANT	\N	PRESENT	0
695830	695149	19649G	PARTICIPANT	\N	PRESENT	0
695831	695149	01028R	PARTICIPANT	\N	PRESENT	0
695832	695149	14097Y	PARTICIPANT	\N	PRESENT	0
695833	695149	19447X	PARTICIPANT	\N	PRESENT	0
695834	695149	19413M	PARTICIPANT	\N	PRESENT	0
695835	695149	11056N	PARTICIPANT	\N	PRESENT	0
695836	695149	19599P	PARTICIPANT	\N	PRESENT	0
695837	695149	20122U	PARTICIPANT	\N	PRESENT	0
695838	695149	19545Y	PARTICIPANT	\N	PRESENT	0
695839	695149	19782L	PARTICIPANT	\N	PRESENT	0
695840	695149	14251Q	PARTICIPANT	\N	PRESENT	0
695841	695149	04045F	PARTICIPANT	\N	PRESENT	0
695845	695149	14107H	PARTICIPANT	\N	PRESENT	0
695847	695149	20092G	PARTICIPANT	\N	PRESENT	0
695336	695213	19611R	PARTICIPANT	\N	PRESENT	0
695337	695213	20044X	PARTICIPANT	\N	PRESENT	0
695848	695149	20036X	PARTICIPANT	\N	PRESENT	0
695849	695149	20072C	PARTICIPANT	\N	PRESENT	0
695850	695149	98022P	PARTICIPANT	\N	PRESENT	0
695851	695149	19479G	PARTICIPANT	\N	PRESENT	0
695852	695149	14179A	PARTICIPANT	\N	PRESENT	0
695853	695149	11012A	PARTICIPANT	\N	PRESENT	0
695854	695149	19711U	PARTICIPANT	\N	PRESENT	0
695855	695149	14083S	PARTICIPANT	\N	PRESENT	0
695856	695149	14055N	PARTICIPANT	\N	PRESENT	0
695857	695149	20252E	PARTICIPANT	\N	PRESENT	0
695858	695149	19515S	PARTICIPANT	\N	PRESENT	0
695859	695149	20090E	PARTICIPANT	\N	PRESENT	0
695860	695149	20062A	PARTICIPANT	\N	PRESENT	0
695861	695149	97011G	PARTICIPANT	\N	PRESENT	0
695862	695149	14147R	PARTICIPANT	\N	PRESENT	0
695863	695149	20980G	PARTICIPANT	\N	PRESENT	0
695882	695149	08015R	PARTICIPANT	\N	PRESENT	0
695865	695149	08010L	PARTICIPANT	\N	PRESENT	0
695866	695149	04043D	PARTICIPANT	\N	PRESENT	0
695867	695149	20096L	PARTICIPANT	\N	PRESENT	0
695869	695149	20056C	PARTICIPANT	\N	PRESENT	0
695870	695149	11090Q	PARTICIPANT	\N	PRESENT	0
695871	695149	20034V	PARTICIPANT	\N	PRESENT	0
695874	695149	01024M	PARTICIPANT	\N	PRESENT	0
695875	695149	14189C	PARTICIPANT	\N	PRESENT	0
695876	695149	19693L	PARTICIPANT	\N	PRESENT	0
695877	695149	19768N	PARTICIPANT	\N	PRESENT	0
695881	695149	14059S	PARTICIPANT	\N	PRESENT	0
695883	695149	14237S	PARTICIPANT	\N	PRESENT	0
695884	695149	20286Q	PARTICIPANT	\N	PRESENT	0
695887	695149	19747H	PARTICIPANT	\N	PRESENT	0
695888	695149	19543W	PARTICIPANT	\N	PRESENT	0
695889	695149	20298U	PARTICIPANT	\N	PRESENT	0
684068	683947	08012N	PARTICIPANT	\N	PRESENT	0
684069	683947	08045X	PARTICIPANT	\N	PRESENT	0
684070	683947	14097Y	PARTICIPANT	\N	PRESENT	0
684071	683947	19820Y	PARTICIPANT	\N	PRESENT	0
684072	683947	19531S	PARTICIPANT	\N	PRESENT	0
684073	683947	20070A	PARTICIPANT	\N	PRESENT	0
684074	683947	14109K	PARTICIPANT	\N	PRESENT	0
684075	683947	18193Q	PARTICIPANT	\N	PRESENT	0
684076	683947	20060X	PARTICIPANT	\N	PRESENT	0
684077	683947	19295A	PARTICIPANT	\N	PRESENT	0
684078	683947	19725B	PARTICIPANT	\N	PRESENT	0
684079	683947	11110B	PARTICIPANT	\N	PRESENT	0
684080	683947	14121F	PARTICIPANT	\N	PRESENT	0
684081	683947	19669L	PARTICIPANT	\N	PRESENT	0
684082	683947	11027H	PARTICIPANT	\N	PRESENT	0
684083	683947	20264J	PARTICIPANT	\N	PRESENT	0
684084	683947	19489J	PARTICIPANT	\N	PRESENT	0
684085	683947	19251M	PARTICIPANT	\N	PRESENT	0
684086	683947	20030R	PARTICIPANT	\N	PRESENT	0
684087	683947	20088L	PARTICIPANT	\N	PRESENT	0
684088	683947	17965H	PARTICIPANT	\N	PRESENT	0
684089	683947	20036X	PARTICIPANT	\N	PRESENT	0
684090	683947	19591F	PARTICIPANT	\N	PRESENT	0
684091	683947	11077T	PARTICIPANT	\N	PRESENT	0
684092	683947	11074Q	PARTICIPANT	\N	PRESENT	0
684093	683947	08060W	PARTICIPANT	\N	PRESENT	0
684094	683947	19599P	PARTICIPANT	\N	PRESENT	0
684095	683947	11031D	PARTICIPANT	\N	PRESENT	0
684096	683947	11064N	PARTICIPANT	\N	PRESENT	0
684097	683947	19697Q	PARTICIPANT	\N	PRESENT	0
684098	683947	17779H	PARTICIPANT	\N	PRESENT	0
684099	683947	19503N	PARTICIPANT	\N	PRESENT	0
684100	683947	19699S	PARTICIPANT	\N	PRESENT	0
684101	683947	19549D	PARTICIPANT	\N	PRESENT	0
684102	683947	19479G	PARTICIPANT	\N	PRESENT	0
684103	683947	14257W	PARTICIPANT	\N	PRESENT	0
684104	683947	19563B	PARTICIPANT	\N	PRESENT	0
684105	683947	19619A	PARTICIPANT	\N	PRESENT	0
684106	683947	04070G	PARTICIPANT	\N	PRESENT	0
684107	683947	16685X	PARTICIPANT	\N	PRESENT	0
684108	683947	19735D	PARTICIPANT	\N	PRESENT	0
684109	683947	11099A	PARTICIPANT	\N	PRESENT	0
684110	683947	14229S	PARTICIPANT	\N	PRESENT	0
684111	683947	11067R	PARTICIPANT	\N	PRESENT	0
684112	683947	14189C	PARTICIPANT	\N	PRESENT	0
684113	683947	07004J	PARTICIPANT	\N	PRESENT	0
684114	683947	11053K	PARTICIPANT	\N	PRESENT	0
684115	683947	14205J	PARTICIPANT	\N	PRESENT	0
684116	683947	14255U	PARTICIPANT	\N	PRESENT	0
684117	683947	20040T	PARTICIPANT	\N	PRESENT	0
684118	683947	19826F	PARTICIPANT	\N	PRESENT	0
684119	683947	14089Y	PARTICIPANT	\N	PRESENT	0
684120	683947	01034P	PARTICIPANT	\N	PRESENT	0
684121	683947	20286Q	PARTICIPANT	\N	PRESENT	0
684122	683947	20066E	PARTICIPANT	\N	PRESENT	0
684123	683947	19715Y	PARTICIPANT	\N	PRESENT	0
684124	683947	20052X	PARTICIPANT	\N	PRESENT	0
684125	683947	14073Q	PARTICIPANT	\N	PRESENT	0
684126	683947	01024M	PARTICIPANT	\N	PRESENT	0
684127	683947	14030Q	PARTICIPANT	\N	PRESENT	0
684128	683947	17229F	PARTICIPANT	\N	PRESENT	0
684129	683947	20298U	PARTICIPANT	\N	PRESENT	0
684130	683947	19335Q	PARTICIPANT	\N	PRESENT	0
684131	683947	01060R	PARTICIPANT	\N	PRESENT	0
684132	683947	12041X	PARTICIPANT	\N	PRESENT	0
684133	683947	19707Y	PARTICIPANT	\N	PRESENT	0
684134	683947	19705W	PARTICIPANT	\N	PRESENT	0
684135	683947	14357A	PARTICIPANT	\N	PRESENT	0
684136	683947	20148F	PARTICIPANT	\N	PRESENT	0
684137	683947	14253S	PARTICIPANT	\N	PRESENT	0
684138	683947	20024T	PARTICIPANT	\N	PRESENT	0
684139	683947	14133K	PARTICIPANT	\N	PRESENT	0
684140	683947	20172F	PARTICIPANT	\N	PRESENT	0
684141	683947	20138D	PARTICIPANT	\N	PRESENT	0
684142	683947	14147R	PARTICIPANT	\N	PRESENT	0
684143	683947	08015R	PARTICIPANT	\N	PRESENT	0
684144	683947	19573D	PARTICIPANT	\N	PRESENT	0
684145	683947	19657G	PARTICIPANT	\N	PRESENT	0
684146	683947	07029T	PARTICIPANT	\N	PRESENT	0
684147	683947	19954N	PARTICIPANT	\N	PRESENT	0
684148	683947	19399H	PARTICIPANT	\N	PRESENT	0
684149	683947	08047A	PARTICIPANT	\N	PRESENT	0
684150	683947	20022R	PARTICIPANT	\N	PRESENT	0
684151	683947	19667J	PARTICIPANT	\N	PRESENT	0
684152	683947	05012A	PARTICIPANT	\N	PRESENT	0
684153	683947	19421M	PARTICIPANT	\N	PRESENT	0
684154	683947	11090Q	PARTICIPANT	\N	PRESENT	0
684155	683947	08028W	PARTICIPANT	\N	PRESENT	0
684156	683947	20134Y	PARTICIPANT	\N	PRESENT	0
684157	683947	11043H	PARTICIPANT	\N	PRESENT	0
684158	683947	14223L	PARTICIPANT	\N	PRESENT	0
684159	683947	14169X	PARTICIPANT	\N	PRESENT	0
684160	683947	19643A	PARTICIPANT	\N	PRESENT	0
684161	683947	20076G	PARTICIPANT	\N	PRESENT	0
684162	683947	20078J	PARTICIPANT	\N	PRESENT	0
684163	683947	19693L	PARTICIPANT	\N	PRESENT	0
684164	683947	08011M	PARTICIPANT	\N	PRESENT	0
684165	683947	19575F	PARTICIPANT	\N	PRESENT	0
684166	683947	99004R	PARTICIPANT	\N	PRESENT	0
684167	683947	86034E	PARTICIPANT	\N	PRESENT	0
684168	683947	19711U	PARTICIPANT	\N	PRESENT	0
684169	683947	04008A	PARTICIPANT	\N	PRESENT	0
684170	683947	19621T	PARTICIPANT	\N	PRESENT	0
684171	683947	11101A	PARTICIPANT	\N	PRESENT	0
684172	683947	19703U	PARTICIPANT	\N	PRESENT	0
684173	683947	04047H	PARTICIPANT	\N	PRESENT	0
684174	683947	19515S	PARTICIPANT	\N	PRESENT	0
684175	683947	14191V	PARTICIPANT	\N	PRESENT	0
684176	683947	11080N	PARTICIPANT	\N	PRESENT	0
684177	683947	14259Y	PARTICIPANT	\N	PRESENT	0
684178	683947	19663E	PARTICIPANT	\N	PRESENT	0
684179	683947	19673G	PARTICIPANT	\N	PRESENT	0
684180	683947	11115U	PARTICIPANT	\N	PRESENT	0
684181	683947	20180F	PARTICIPANT	\N	PRESENT	0
684182	683947	19675J	PARTICIPANT	\N	PRESENT	0
684183	683947	20026V	PARTICIPANT	\N	PRESENT	0
684184	683947	20098N	PARTICIPANT	\N	PRESENT	0
684185	683947	20044X	PARTICIPANT	\N	PRESENT	0
684186	683947	11097X	PARTICIPANT	\N	PRESENT	0
684187	683947	20054A	PARTICIPANT	\N	PRESENT	0
684188	683947	20020P	PARTICIPANT	\N	PRESENT	0
684189	683947	14038Y	PARTICIPANT	\N	PRESENT	0
684190	683947	14033T	PARTICIPANT	\N	PRESENT	0
684191	683947	20058E	PARTICIPANT	\N	PRESENT	0
684192	683947	14173T	PARTICIPANT	\N	PRESENT	0
684193	683947	19467C	PARTICIPANT	\N	PRESENT	0
684194	683947	20056C	PARTICIPANT	\N	PRESENT	0
684195	683947	20034V	PARTICIPANT	\N	PRESENT	0
684196	683947	19443T	PARTICIPANT	\N	PRESENT	0
684197	683947	08018U	PARTICIPANT	\N	PRESENT	0
684198	683947	17367Q	PARTICIPANT	\N	PRESENT	0
684199	683947	18083K	PARTICIPANT	\N	PRESENT	0
684200	683947	19057M	PARTICIPANT	\N	PRESENT	0
684201	683947	19447X	PARTICIPANT	\N	PRESENT	0
684202	683947	11083R	PARTICIPANT	\N	PRESENT	0
684203	683947	19611R	PARTICIPANT	\N	PRESENT	0
684204	683947	04042C	PARTICIPANT	\N	PRESENT	0
684205	683947	19543W	PARTICIPANT	\N	PRESENT	0
684206	683947	20016T	PARTICIPANT	\N	PRESENT	0
684207	683947	01057W	PARTICIPANT	\N	PRESENT	0
684208	683947	19367Y	PARTICIPANT	\N	PRESENT	0
684209	683947	19798U	PARTICIPANT	\N	PRESENT	0
684210	683947	20032T	PARTICIPANT	\N	PRESENT	0
684211	683947	14237S	PARTICIPANT	\N	PRESENT	0
684212	683947	14215L	PARTICIPANT	\N	PRESENT	0
684213	683947	14193X	PARTICIPANT	\N	PRESENT	0
684214	683947	05008E	PARTICIPANT	\N	PRESENT	0
684215	683947	14071N	PARTICIPANT	\N	PRESENT	0
684216	683947	19747H	PARTICIPANT	\N	PRESENT	0
684217	683947	20142Y	PARTICIPANT	\N	PRESENT	0
684218	683947	10006L	PARTICIPANT	\N	PRESENT	0
684219	683947	08034U	PARTICIPANT	\N	PRESENT	0
684220	683947	04092N	PARTICIPANT	\N	PRESENT	0
684221	683947	19671E	PARTICIPANT	\N	PRESENT	0
684222	683947	04033B	PARTICIPANT	\N	PRESENT	0
684223	683947	14187A	PARTICIPANT	\N	PRESENT	0
684224	683947	14069U	PARTICIPANT	\N	PRESENT	0
684225	683947	20090E	PARTICIPANT	\N	PRESENT	0
684226	683947	20118Y	PARTICIPANT	\N	PRESENT	0
684227	683947	04043D	PARTICIPANT	\N	PRESENT	0
684228	683947	14059S	PARTICIPANT	\N	PRESENT	0
700790	698970	20092G	PARTICIPANT	\N	PRESENT	0
700791	698970	04071H	PARTICIPANT	\N	PRESENT	0
700792	698970	18083K	PARTICIPANT	\N	PRESENT	0
700793	698970	14133K	PARTICIPANT	\N	PRESENT	0
700794	698970	14123H	PARTICIPANT	\N	PRESENT	0
700795	698970	19695N	PARTICIPANT	\N	PRESENT	0
700796	698970	14213J	PARTICIPANT	\N	PRESENT	0
700797	698970	14089Y	PARTICIPANT	\N	PRESENT	0
700798	698970	14179A	PARTICIPANT	\N	PRESENT	0
700799	698970	20058E	PARTICIPANT	\N	PRESENT	0
700803	698970	19543W	PARTICIPANT	\N	PRESENT	0
700801	698970	14059S	PARTICIPANT	\N	PRESENT	0
700802	698970	20048C	PARTICIPANT	\N	PRESENT	0
700804	698970	14042U	PARTICIPANT	\N	PRESENT	0
700805	698970	17023S	PARTICIPANT	\N	PRESENT	0
701102	698975	86034E	PARTICIPANT	\N	PRESENT	0
700807	698970	19637C	PARTICIPANT	\N	PRESENT	0
700808	698970	17637T	PARTICIPANT	\N	PRESENT	0
701115	698975	14033T	PARTICIPANT	\N	PRESENT	0
701124	698975	20034V	PARTICIPANT	\N	PRESENT	0
701108	698975	20072C	PARTICIPANT	\N	PRESENT	0
701109	698975	19820Y	PARTICIPANT	\N	PRESENT	0
701110	698975	14001X	PARTICIPANT	\N	PRESENT	0
701111	698975	20070A	PARTICIPANT	\N	PRESENT	0
701112	698975	20062A	PARTICIPANT	\N	PRESENT	0
701126	698975	20100N	PARTICIPANT	\N	PRESENT	0
701127	698975	14257W	PARTICIPANT	\N	PRESENT	0
701116	698975	19954N	PARTICIPANT	\N	PRESENT	0
701117	698975	20104S	PARTICIPANT	\N	PRESENT	0
701118	698975	20108W	PARTICIPANT	\N	PRESENT	0
701133	698975	19611R	PARTICIPANT	\N	PRESENT	0
701120	698975	20124W	PARTICIPANT	\N	PRESENT	0
701121	698975	14189C	PARTICIPANT	\N	PRESENT	0
701122	698975	11064N	PARTICIPANT	\N	PRESENT	0
701123	698975	14097Y	PARTICIPANT	\N	PRESENT	0
701125	698975	20914V	PARTICIPANT	\N	PRESENT	0
701128	698975	20106U	PARTICIPANT	\N	PRESENT	0
701129	698975	20032T	PARTICIPANT	\N	PRESENT	0
701130	698975	17737W	PARTICIPANT	\N	PRESENT	0
701131	698975	19695N	PARTICIPANT	\N	PRESENT	0
701132	698975	19681G	PARTICIPANT	\N	PRESENT	0
701134	698975	19441R	PARTICIPANT	\N	PRESENT	0
701142	698975	04045F	PARTICIPANT	\N	PRESENT	0
701151	698975	19747H	PARTICIPANT	\N	PRESENT	0
701152	698975	20048C	PARTICIPANT	\N	PRESENT	0
701153	698975	20252E	PARTICIPANT	\N	PRESENT	0
701154	698975	01058X	PARTICIPANT	\N	PRESENT	0
701155	698975	14069U	PARTICIPANT	\N	PRESENT	0
701156	698975	95063L	PARTICIPANT	\N	PRESENT	0
701157	698975	18083K	PARTICIPANT	\N	PRESENT	0
701158	698975	20024T	PARTICIPANT	\N	PRESENT	0
701159	698975	14331P	PARTICIPANT	\N	PRESENT	0
701160	698975	20116W	PARTICIPANT	\N	PRESENT	0
701161	698975	20068G	PARTICIPANT	\N	PRESENT	0
701162	698975	19782L	PARTICIPANT	\N	PRESENT	0
701163	698975	19631V	PARTICIPANT	\N	PRESENT	0
701164	698975	01024M	PARTICIPANT	\N	PRESENT	0
701165	698975	97011G	PARTICIPANT	\N	PRESENT	0
701167	698975	19593H	PARTICIPANT	\N	PRESENT	0
701168	698975	17023S	PARTICIPANT	\N	PRESENT	0
701169	698975	20138D	PARTICIPANT	\N	PRESENT	0
701170	698975	19563B	PARTICIPANT	\N	PRESENT	0
701171	698975	20030R	PARTICIPANT	\N	PRESENT	0
701172	698975	19766L	PARTICIPANT	\N	PRESENT	0
701173	698975	19673G	PARTICIPANT	\N	PRESENT	0
701174	698975	20082E	PARTICIPANT	\N	PRESENT	0
701175	698975	19649G	PARTICIPANT	\N	PRESENT	0
701176	698975	12028B	PARTICIPANT	\N	PRESENT	0
701177	698975	20084G	PARTICIPANT	\N	PRESENT	0
701178	698975	19669L	PARTICIPANT	\N	PRESENT	0
701181	698975	08034U	PARTICIPANT	\N	PRESENT	0
701183	698975	19503N	PARTICIPANT	\N	PRESENT	0
701222	698975	19671E	PARTICIPANT	\N	PRESENT	0
701223	698975	20018V	PARTICIPANT	\N	PRESENT	0
701224	698975	19349W	PARTICIPANT	\N	PRESENT	0
701225	698975	19798U	PARTICIPANT	\N	PRESENT	0
701265	698971	19347U	PARTICIPANT	\N	PRESENT	0
701227	698971	20072C	PARTICIPANT	\N	PRESENT	0
701261	698971	19549D	PARTICIPANT	\N	PRESENT	0
701229	698971	20070A	PARTICIPANT	\N	PRESENT	0
701230	698971	20062A	PARTICIPANT	\N	PRESENT	0
701231	698971	11064N	PARTICIPANT	\N	PRESENT	0
701232	698971	14097Y	PARTICIPANT	\N	PRESENT	0
701263	698971	20030R	PARTICIPANT	\N	PRESENT	0
701266	698971	14249W	PARTICIPANT	\N	PRESENT	0
701235	698971	20032T	PARTICIPANT	\N	PRESENT	0
701236	698971	17737W	PARTICIPANT	\N	PRESENT	0
701267	698971	19671E	PARTICIPANT	\N	PRESENT	0
701268	698971	04033B	PARTICIPANT	\N	PRESENT	0
701239	698971	19747H	PARTICIPANT	\N	PRESENT	0
701240	698971	18083K	PARTICIPANT	\N	PRESENT	0
701241	698971	14331P	PARTICIPANT	\N	PRESENT	0
701242	698971	20116W	PARTICIPANT	\N	PRESENT	0
701276	698971	14069U	PARTICIPANT	\N	PRESENT	0
701269	698971	20042V	PARTICIPANT	\N	PRESENT	0
701245	698971	97011G	PARTICIPANT	\N	PRESENT	0
701246	698971	19593H	PARTICIPANT	\N	PRESENT	0
701247	698971	19766L	PARTICIPANT	\N	PRESENT	0
701248	698971	19673G	PARTICIPANT	\N	PRESENT	0
701249	698971	20082E	PARTICIPANT	\N	PRESENT	0
701250	698971	19649G	PARTICIPANT	\N	PRESENT	0
701251	698971	12028B	PARTICIPANT	\N	PRESENT	0
701252	698971	20084G	PARTICIPANT	\N	PRESENT	0
701253	698971	19669L	PARTICIPANT	\N	PRESENT	0
701254	698971	08034U	PARTICIPANT	\N	PRESENT	0
701255	698971	19503N	PARTICIPANT	\N	PRESENT	0
701270	698971	20056C	PARTICIPANT	\N	PRESENT	0
701257	698971	20018V	PARTICIPANT	\N	PRESENT	0
701258	698971	19349W	PARTICIPANT	\N	PRESENT	0
701259	698971	19647E	PARTICIPANT	\N	PRESENT	0
701260	698971	20138D	PARTICIPANT	\N	PRESENT	0
701264	698971	01043Q	PARTICIPANT	\N	PRESENT	0
701271	698971	08061X	PARTICIPANT	\N	PRESENT	0
701272	698971	14053L	PARTICIPANT	\N	PRESENT	0
701273	698971	19798U	PARTICIPANT	\N	PRESENT	0
701274	698971	14215L	PARTICIPANT	\N	PRESENT	0
701275	698971	19758L	PARTICIPANT	\N	PRESENT	0
701277	698971	11012A	PARTICIPANT	\N	PRESENT	0
701278	698971	20136B	PARTICIPANT	\N	PRESENT	0
701279	698971	14031R	PARTICIPANT	\N	PRESENT	0
701280	698971	19691J	PARTICIPANT	\N	PRESENT	0
701281	698971	14030Q	PARTICIPANT	\N	PRESENT	0
701282	698971	14073Q	PARTICIPANT	\N	PRESENT	0
701283	698971	20052X	PARTICIPANT	\N	PRESENT	0
701284	698971	11026G	PARTICIPANT	\N	PRESENT	0
701286	701285	19691J	PARTICIPANT	\N	PRESENT	0
701287	698971	20100N	PARTICIPANT	\N	PRESENT	0
701289	698971	19415P	PARTICIPANT	\N	PRESENT	0
701292	698971	20086J	PARTICIPANT	\N	PRESENT	0
701293	698971	19543W	PARTICIPANT	\N	PRESENT	0
701294	698971	19383Y	PARTICIPANT	\N	PRESENT	0
701295	698971	20110Q	PARTICIPANT	\N	PRESENT	0
701296	698971	04045F	PARTICIPANT	\N	PRESENT	0
701297	698971	14147R	PARTICIPANT	\N	PRESENT	0
683892	683224	08010L	PARTICIPANT	\N	PRESENT	0
683890	683224	14069U	PARTICIPANT	\N	PRESENT	0
683891	683224	20042V	PARTICIPANT	\N	PRESENT	0
683893	683224	11065P	PARTICIPANT	\N	PRESENT	0
683894	683224	04047H	PARTICIPANT	\N	PRESENT	0
683895	683224	14211G	PARTICIPANT	\N	PRESENT	0
683896	683224	11056N	PARTICIPANT	\N	PRESENT	0
683897	683224	11070L	PARTICIPANT	\N	PRESENT	0
683898	683224	14231L	PARTICIPANT	\N	PRESENT	0
683899	683224	11026G	PARTICIPANT	\N	PRESENT	0
687601	687357	19782L	PARTICIPANT	\N	EXCUSE	0
687602	687357	14207L	PARTICIPANT	\N	EXCUSE	0
687603	687357	19441R	PARTICIPANT	\N	EXCUSE	0
687604	687357	19826F	PARTICIPANT	\N	PRESENT	0
687607	686745	14331P	PARTICIPANT	\N	PRESENT	0
687608	686745	20098N	PARTICIPANT	\N	PRESENT	0
687609	686745	04045F	PARTICIPANT	\N	PRESENT	0
687610	686745	04047H	PRESIDENT	0	PRESENT	0
687612	686745	14001X	PARTICIPANT	\N	PRESENT	0
687614	686745	20100N	PARTICIPANT	\N	PRESENT	0
687615	686745	11026G	PARTICIPANT	\N	PRESENT	0
687617	686745	14215L	PARTICIPANT	\N	PRESENT	0
687618	686745	19954N	PARTICIPANT	\N	PRESENT	0
687622	686745	19729F	PARTICIPANT	\N	EXCUSE	0
687624	686745	14151M	PARTICIPANT	\N	PRESENT	0
687625	686745	19725B	PARTICIPANT	\N	PRESENT	0
687626	686745	14357A	PARTICIPANT	\N	PRESENT	0
687629	686745	14147R	PARTICIPANT	\N	PRESENT	0
687632	686745	19649G	PARTICIPANT	\N	PRESENT	0
687633	686745	08034U	PARTICIPANT	\N	PRESENT	0
687636	686745	14033T	PARTICIPANT	\N	PRESENT	0
687637	686745	14026U	PARTICIPANT	\N	PRESENT	0
687638	686745	10015M	PARTICIPANT	\N	PRESENT	0
687641	686745	19673G	PARTICIPANT	\N	PRESENT	0
687643	686745	14089Y	PARTICIPANT	\N	PRESENT	0
687645	686745	20022R	PARTICIPANT	\N	PRESENT	0
687648	686745	14133K	PARTICIPANT	\N	PRESENT	0
687649	686745	01028R	PARTICIPANT	\N	PRESENT	0
687652	686745	19543W	PARTICIPANT	\N	PRESENT	0
687653	686745	20128B	PARTICIPANT	\N	PRESENT	0
687655	686745	20286Q	PARTICIPANT	\N	PRESENT	0
687657	686745	04035D	PARTICIPANT	\N	PRESENT	0
687659	686745	20104S	PARTICIPANT	\N	PRESENT	0
687660	686745	14179A	PARTICIPANT	\N	PRESENT	0
687921	686745	19701S	PARTICIPANT	\N	PRESENT	0
688423	688422	05008E	PARTICIPANT	\N	PRESENT	0
688424	688422	11053K	PARTICIPANT	\N	PRESENT	0
688425	688422	01028R	PARTICIPANT	\N	PRESENT	0
688429	688428	10006L	PARTICIPANT	\N	PRESENT	0
688430	688428	19683J	PARTICIPANT	\N	PRESENT	0
688431	688428	14071N	PARTICIPANT	\N	PRESENT	0
688432	688428	11031D	PARTICIPANT	\N	PRESENT	0
689531	689282	14187A	PARTICIPANT	\N	PRESENT	0
689532	689282	19695N	PARTICIPANT	\N	PRESENT	0
689533	689282	14033T	PARTICIPANT	\N	PRESENT	0
689534	689282	20060X	PARTICIPANT	\N	PRESENT	0
689535	689282	20062A	PARTICIPANT	\N	PRESENT	0
689536	689282	19747H	PARTICIPANT	\N	PRESENT	0
689537	689282	17229F	PARTICIPANT	\N	PRESENT	0
689538	688706	20108W	PARTICIPANT	\N	PRESENT	0
689539	688796	19687N	PARTICIPANT	\N	PRESENT	0
689540	688796	11040E	PARTICIPANT	\N	PRESENT	0
689541	688796	11012A	PARTICIPANT	\N	PRESENT	0
689542	688796	08010L	PARTICIPANT	\N	PRESENT	0
689543	688796	20126Y	PARTICIPANT	\N	PRESENT	0
689544	688706	19725B	PARTICIPANT	\N	PRESENT	0
689545	688796	20080C	PARTICIPANT	\N	PRESENT	0
689546	688796	11053K	PARTICIPANT	\N	PRESENT	0
689547	688796	14083S	PARTICIPANT	\N	PRESENT	0
689548	688796	08009T	PARTICIPANT	\N	PRESENT	0
689549	688796	20070A	PARTICIPANT	\N	PRESENT	0
689550	688796	14189C	PARTICIPANT	\N	PRESENT	0
689551	688796	19335Q	PARTICIPANT	\N	PRESENT	0
689552	688796	19667J	PARTICIPANT	\N	PRESENT	0
689553	688796	20116W	PARTICIPANT	\N	PRESENT	0
689554	688796	20050V	PARTICIPANT	\N	PRESENT	0
689555	689282	19441R	PARTICIPANT	\N	PRESENT	0
689556	689282	20034V	PARTICIPANT	\N	PRESENT	0
689557	689282	11090Q	PARTICIPANT	\N	PRESENT	0
689558	689282	20054A	PARTICIPANT	\N	PRESENT	0
689559	689282	14257W	PARTICIPANT	\N	PRESENT	0
689560	689282	17737W	PARTICIPANT	\N	PRESENT	0
689561	689282	19705W	PARTICIPANT	\N	PRESENT	0
689562	689282	08015R	PARTICIPANT	\N	PRESENT	0
689563	689282	19575F	PARTICIPANT	\N	PRESENT	0
689564	689282	19369B	PARTICIPANT	\N	PRESENT	0
689565	689282	08028W	PARTICIPANT	\N	PRESENT	0
689566	689282	19467C	PARTICIPANT	\N	PRESENT	0
689567	689282	20144B	PARTICIPANT	\N	PRESENT	0
689568	689282	14205J	PARTICIPANT	\N	PRESENT	0
689569	689282	20286Q	PARTICIPANT	\N	PRESENT	0
689570	689282	20298U	PARTICIPANT	\N	PRESENT	0
689571	688706	01028R	PARTICIPANT	\N	PRESENT	0
689572	688796	19647E	PARTICIPANT	\N	PRESENT	0
689573	688796	19531S	PARTICIPANT	\N	PRESENT	0
689574	688796	12016W	PARTICIPANT	\N	PRESENT	0
689575	688395	20106U	PARTICIPANT	\N	PRESENT	0
689576	689279	19333N	PARTICIPANT	\N	PRESENT	0
689577	689279	19549D	PARTICIPANT	\N	PRESENT	0
689578	689279	19820Y	PARTICIPANT	\N	PRESENT	0
689579	689279	19826F	PARTICIPANT	\N	PRESENT	0
689580	689279	19954N	PARTICIPANT	\N	PRESENT	0
689581	689279	19685L	PARTICIPANT	\N	PRESENT	0
689582	689279	19681G	PARTICIPANT	\N	PRESENT	0
689583	689279	20024T	PARTICIPANT	\N	PRESENT	0
689584	689279	11065P	PARTICIPANT	\N	PRESENT	0
689585	689279	19525U	PARTICIPANT	\N	PRESENT	0
689586	689279	20032T	PARTICIPANT	\N	PRESENT	0
689587	689279	20046A	PARTICIPANT	\N	PRESENT	0
689588	689279	17229F	PARTICIPANT	\N	PRESENT	0
689589	689279	20068G	PARTICIPANT	\N	PRESENT	0
689590	689279	20076G	PARTICIPANT	\N	PRESENT	0
689591	689279	19387D	PARTICIPANT	\N	PRESENT	0
689592	689279	14219Q	PARTICIPANT	\N	PRESENT	0
689593	689279	14221J	PARTICIPANT	\N	PRESENT	0
689594	689279	19599P	PARTICIPANT	\N	PRESENT	0
689595	689279	20102Q	PARTICIPANT	\N	PRESENT	0
689596	689279	20100N	PARTICIPANT	\N	PRESENT	0
689597	689279	18083K	PARTICIPANT	\N	PRESENT	0
689598	689279	14237S	PARTICIPANT	\N	PRESENT	0
689599	689279	05012A	PARTICIPANT	\N	PRESENT	0
689600	689279	20118Y	PARTICIPANT	\N	PRESENT	0
689601	689279	19503N	PARTICIPANT	\N	PRESENT	0
689602	689279	17367Q	PARTICIPANT	\N	PRESENT	0
689603	689279	20122U	PARTICIPANT	\N	PRESENT	0
689604	689279	20136B	PARTICIPANT	\N	PRESENT	0
689605	689279	14031R	PARTICIPANT	\N	PRESENT	0
689606	689279	19251M	PARTICIPANT	\N	PRESENT	0
689607	689279	19739H	PARTICIPANT	\N	PRESENT	0
689608	689279	19745F	PARTICIPANT	\N	PRESENT	0
689610	688796	11070L	PARTICIPANT	\N	PRESENT	0
689611	688796	20044X	PARTICIPANT	\N	PRESENT	0
689612	688796	20252E	PARTICIPANT	\N	PRESENT	0
689613	688706	11056N	PARTICIPANT	\N	PRESENT	0
689614	688706	14259Y	PARTICIPANT	\N	PRESENT	0
689615	688796	19545Y	PARTICIPANT	\N	PRESENT	0
689616	688796	08034U	PARTICIPANT	\N	PRESENT	0
689617	688706	14179A	PARTICIPANT	\N	PRESENT	0
689618	688796	04071H	PARTICIPANT	\N	PRESENT	0
689619	688796	14121F	PARTICIPANT	\N	PRESENT	0
689620	688706	08018U	PARTICIPANT	\N	PRESENT	0
689621	688706	14069U	PARTICIPANT	\N	PRESENT	0
689622	689279	04045F	PARTICIPANT	\N	PRESENT	0
689623	689279	19637C	PARTICIPANT	\N	PRESENT	0
689663	688648	86034E	PARTICIPANT	\N	PRESENT	0
689664	688648	19507S	PARTICIPANT	\N	PRESENT	0
689665	688648	14331P	PARTICIPANT	\N	PRESENT	0
689666	688648	19565D	PARTICIPANT	\N	PRESENT	0
689667	688648	11054L	PARTICIPANT	\N	PRESENT	0
689668	688648	20068G	PARTICIPANT	\N	PRESENT	0
689669	688648	20046A	PARTICIPANT	\N	PRESENT	0
689670	688648	14105F	PARTICIPANT	\N	PRESENT	0
689671	688648	20090E	PARTICIPANT	\N	PRESENT	0
689672	688648	19383Y	PARTICIPANT	\N	PRESENT	0
689673	688648	14107H	PARTICIPANT	\N	PRESENT	0
689674	688648	19583F	PARTICIPANT	\N	PRESENT	0
689675	688648	20152B	PARTICIPANT	\N	PRESENT	0
689676	688648	98022P	PARTICIPANT	\N	PRESENT	0
689677	688648	08060W	PARTICIPANT	\N	PRESENT	0
689678	688648	20034V	PARTICIPANT	\N	PRESENT	0
689679	688648	19798U	PARTICIPANT	\N	PRESENT	0
695891	695149	14207L	PARTICIPANT	\N	PRESENT	0
695893	695149	20048C	PARTICIPANT	\N	PRESENT	0
695894	695149	19319Q	PARTICIPANT	\N	PRESENT	0
695896	695149	11043H	PARTICIPANT	\N	PRESENT	0
695897	695149	19575F	PARTICIPANT	\N	PRESENT	0
695898	695149	11104D	PARTICIPANT	\N	PRESENT	0
695899	695149	01043Q	PARTICIPANT	\N	PRESENT	0
695900	695149	14275Y	PARTICIPANT	\N	PRESENT	0
695901	695149	14357A	PARTICIPANT	\N	PRESENT	0
695902	695149	20128B	PARTICIPANT	\N	PRESENT	0
695903	693561	19673G	PARTICIPANT	\N	EXCUSE	0
695904	693561	20034V	PARTICIPANT	\N	PRESENT	0
695905	693561	19717B	PRESIDENT	0	PRESENT	1
695906	693586	19673G	PARTICIPANT	\N	EXCUSE	0
695907	693587	19673G	PARTICIPANT	\N	EXCUSE	0
695908	695149	14219Q	PARTICIPANT	\N	PRESENT	0
695909	695149	14030Q	PARTICIPANT	\N	PRESENT	0
695910	695149	19349W	PARTICIPANT	\N	PRESENT	0
695911	695149	20058E	PARTICIPANT	\N	PRESENT	0
695912	695149	14089Y	PARTICIPANT	\N	PRESENT	0
695913	695149	20088L	PARTICIPANT	\N	PRESENT	0
695914	695149	14231L	PARTICIPANT	\N	PRESENT	0
695915	695149	20040T	PARTICIPANT	\N	PRESENT	0
695916	695149	18083K	PARTICIPANT	\N	PRESENT	0
695917	695149	19741B	PARTICIPANT	\N	PRESENT	0
695918	695149	20052X	PARTICIPANT	\N	PRESENT	0
695919	695149	20032T	PARTICIPANT	\N	PRESENT	0
695920	695149	20914V	PARTICIPANT	\N	PRESENT	0
695921	695149	08073C	PARTICIPANT	\N	PRESENT	0
695922	695149	11048N	PARTICIPANT	\N	PRESENT	0
696192	694875	14111D	PARTICIPANT	\N	PRESENT	0
696193	694875	19729F	PARTICIPANT	\N	EXCUSE	0
696194	694875	14053L	PARTICIPANT	\N	PRESENT	0
696195	694875	19649G	PARTICIPANT	\N	PRESENT	0
696196	694875	07004J	PARTICIPANT	\N	PRESENT	0
696197	694875	04047H	PRESIDENT	0	PRESENT	0
696198	694875	19673G	PARTICIPANT	\N	PRESENT	0
696199	694875	19675J	PARTICIPANT	\N	PRESENT	0
696200	694875	05008E	PARTICIPANT	\N	PRESENT	0
696201	694875	20074E	PARTICIPANT	\N	PRESENT	0
696202	694875	19543W	PARTICIPANT	\N	PRESENT	0
696203	694875	19585H	PARTICIPANT	\N	PRESENT	0
696204	694875	14231L	PARTICIPANT	\N	PRESENT	0
696205	694875	19447X	PARTICIPANT	\N	PRESENT	0
696206	694875	17737W	PARTICIPANT	\N	PRESENT	0
696207	694875	20108W	PARTICIPANT	\N	PRESENT	0
696208	694875	14107H	PARTICIPANT	\N	PRESENT	0
696209	694875	20110Q	PARTICIPANT	\N	PRESENT	0
696210	694875	14179A	PARTICIPANT	\N	PRESENT	0
696211	694875	14151M	PARTICIPANT	\N	PRESENT	0
696212	694875	14215L	PARTICIPANT	\N	PRESENT	0
696213	694875	20022R	PARTICIPANT	\N	PRESENT	0
696214	694875	11026G	PARTICIPANT	\N	PRESENT	0
696215	694875	14089Y	PARTICIPANT	\N	PRESENT	0
696216	694875	14069U	PARTICIPANT	\N	PRESENT	0
696217	694875	11085T	PARTICIPANT	\N	PRESENT	0
696218	694875	19749K	PARTICIPANT	\N	PRESENT	0
696219	694875	14021P	PARTICIPANT	\N	PRESENT	0
696220	694875	14275Y	PARTICIPANT	\N	PRESENT	0
696221	694875	14147R	PARTICIPANT	\N	PRESENT	0
696222	694875	14001X	PARTICIPANT	\N	PRESENT	0
696223	694875	01028R	PARTICIPANT	\N	PRESENT	0
696224	694875	19489J	PARTICIPANT	\N	PRESENT	0
696225	694875	19725B	PARTICIPANT	\N	PRESENT	0
696227	694947	10006L	PRESIDENT	0	PRESENT	0
696228	694947	19683J	PARTICIPANT	\N	PRESENT	0
696229	694947	11045K	PARTICIPANT	\N	PRESENT	0
696230	694947	18193Q	PARTICIPANT	\N	PRESENT	0
696231	694947	19657G	PARTICIPANT	\N	PRESENT	0
696232	694947	14223L	PARTICIPANT	\N	PRESENT	0
696233	694947	20040T	PARTICIPANT	\N	PRESENT	0
696234	694947	19691J	PARTICIPANT	\N	PRESENT	0
696235	694947	14217N	PRESIDENT	1	PRESENT	0
696236	694947	19415P	PARTICIPANT	\N	PRESENT	0
696237	694947	14213J	PARTICIPANT	\N	PRESENT	0
696238	694947	20090E	PARTICIPANT	\N	PRESENT	0
696239	694947	20248J	PARTICIPANT	\N	PRESENT	0
696240	694875	11010L	PARTICIPANT	\N	PRESENT	0
696241	694875	11056N	PARTICIPANT	\N	PRESENT	0
696242	694947	14042U	PARTICIPANT	\N	PRESENT	0
696243	693394	20032T	PARTICIPANT	\N	PRESENT	0
696244	693394	20068G	PARTICIPANT	\N	PRESENT	0
696245	693394	20066E	PARTICIPANT	\N	PRESENT	0
696246	693394	14219Q	PRESIDENT	0	PRESENT	0
696247	693394	19745F	PARTICIPANT	\N	PRESENT	0
696248	693394	19826F	PARTICIPANT	\N	PRESENT	0
696249	693394	20102Q	PARTICIPANT	\N	PRESENT	0
696250	693394	19619A	PARTICIPANT	\N	PRESENT	0
696251	694947	19295A	PARTICIPANT	\N	EXCUSE	0
696252	694947	19329S	PARTICIPANT	\N	PRESENT	0
696253	694875	20114U	PARTICIPANT	\N	PRESENT	0
696254	694875	95063L	PARTICIPANT	\N	PRESENT	0
696255	694947	04092N	PARTICIPANT	\N	PRESENT	0
696256	694947	17965H	PARTICIPANT	\N	PRESENT	0
696257	693394	18083K	PARTICIPANT	\N	PRESENT	0
696258	693394	19503N	PARTICIPANT	\N	PRESENT	0
696259	693394	19599P	PARTICIPANT	\N	PRESENT	0
696260	694947	14281W	PARTICIPANT	\N	PRESENT	0
696261	693394	20140W	PARTICIPANT	\N	PRESENT	0
696262	693394	05012A	PARTICIPANT	\N	PRESENT	0
696263	694947	19367Y	PARTICIPANT	\N	PRESENT	0
696264	694875	19954N	PARTICIPANT	\N	PRESENT	0
696265	693394	19333N	PARTICIPANT	\N	PRESENT	0
696266	693394	14031R	PARTICIPANT	\N	PRESENT	0
696267	693394	20100N	PARTICIPANT	\N	PRESENT	0
696268	693394	19681G	PARTICIPANT	\N	PRESENT	0
696269	694875	10015M	PARTICIPANT	\N	PRESENT	0
696270	694875	14259Y	PARTICIPANT	\N	PRESENT	0
696276	694947	19713W	PARTICIPANT	\N	PRESENT	0
696277	694947	19760E	PARTICIPANT	\N	EXCUSE	0
696278	694947	11031D	PARTICIPANT	\N	PRESENT	0
696302	694947	20130U	PARTICIPANT	\N	PRESENT	0
696303	694947	20266L	PARTICIPANT	\N	PRESENT	0
696304	694947	11097X	PARTICIPANT	\N	PRESENT	0
696305	694947	19703U	PARTICIPANT	\N	PRESENT	0
696349	694947	14026U	PARTICIPANT	\N	PRESENT	0
696446	694947	17779H	PARTICIPANT	\N	PRESENT	0
696480	695195	19762G	PARTICIPANT	\N	PRESENT	0
696481	694949	20048C	PARTICIPANT	\N	PRESENT	0
696482	694949	14123H	PARTICIPANT	\N	PRESENT	0
696483	694947	01034P	PARTICIPANT	\N	PRESENT	0
696513	695217	19383Y	PARTICIPANT	\N	PRESENT	0
696514	695217	19768N	PARTICIPANT	\N	PRESENT	0
696515	695217	20088L	PARTICIPANT	\N	PRESENT	0
696516	695217	19515S	PARTICIPANT	\N	PRESENT	0
696517	695217	19782L	PARTICIPANT	\N	PRESENT	0
696518	695217	20092G	PARTICIPANT	\N	PRESENT	0
696519	695217	11077T	PARTICIPANT	\N	PRESENT	0
696520	695217	01043Q	PARTICIPANT	\N	PRESENT	0
696521	695217	19413M	PARTICIPANT	\N	PRESENT	0
696522	695217	20094J	PARTICIPANT	\N	PRESENT	0
696523	695217	04045F	PARTICIPANT	\N	PRESENT	0
684229	683947	19383Y	PARTICIPANT	\N	PRESENT	0
684230	683947	17737W	PARTICIPANT	\N	PRESENT	0
684231	683947	19533U	PARTICIPANT	\N	PRESENT	0
684232	683947	14217N	PARTICIPANT	\N	PRESENT	0
684233	683947	07033P	PARTICIPANT	\N	PRESENT	0
684234	683947	20152B	PARTICIPANT	\N	PRESENT	0
684235	683947	08056B	PARTICIPANT	\N	PRESENT	0
684236	683947	20094J	PARTICIPANT	\N	PRESENT	0
684237	683947	20082E	PARTICIPANT	\N	PRESENT	0
684238	683947	14123H	PARTICIPANT	\N	PRESENT	0
684239	683947	20080C	PARTICIPANT	\N	PRESENT	0
684240	683947	19701S	PARTICIPANT	\N	PRESENT	0
684241	683947	95063L	PARTICIPANT	\N	PRESENT	0
684242	683947	14331P	PARTICIPANT	\N	PRESENT	0
684243	683947	14219Q	PARTICIPANT	\N	PRESENT	0
684244	683947	20106U	PARTICIPANT	\N	PRESENT	0
684245	683947	19577H	PARTICIPANT	\N	PRESENT	0
684246	683947	20248J	PARTICIPANT	\N	PRESENT	0
684247	683947	17637T	PARTICIPANT	\N	PRESENT	0
684248	683947	11026G	PARTICIPANT	\N	PRESENT	0
684249	683947	19507S	PARTICIPANT	\N	PRESENT	0
684250	683947	19679N	PARTICIPANT	\N	PRESENT	0
684251	683947	14037X	PARTICIPANT	\N	PRESENT	0
684252	683947	08069G	PARTICIPANT	\N	PRESENT	0
684257	683947	01048V	PARTICIPANT	\N	PRESENT	0
684254	683947	19713W	PARTICIPANT	\N	PRESENT	0
684255	683947	14329V	PARTICIPANT	\N	PRESENT	0
684256	683947	10015M	PARTICIPANT	\N	PRESENT	0
684287	683947	20104S	PARTICIPANT	\N	PRESENT	0
684259	683947	04071H	PARTICIPANT	\N	PRESENT	0
684266	683947	11056N	PARTICIPANT	\N	PRESENT	0
684264	683947	20124W	PARTICIPANT	\N	PRESENT	0
684262	683947	20126Y	PARTICIPANT	\N	PRESENT	0
684265	683947	19768N	PARTICIPANT	\N	PRESENT	0
684267	683947	19415P	PARTICIPANT	\N	PRESENT	0
684268	683947	14179A	PARTICIPANT	\N	PRESENT	0
684269	683947	20136B	PARTICIPANT	\N	PRESENT	0
684270	683947	20144B	PARTICIPANT	\N	PRESENT	0
684271	683947	20086J	PARTICIPANT	\N	PRESENT	0
684272	683947	20038A	PARTICIPANT	\N	PRESENT	0
684273	683947	20050V	PARTICIPANT	\N	PRESENT	0
684274	683947	14026U	PARTICIPANT	\N	PRESENT	0
684285	683947	20108W	PARTICIPANT	\N	PRESENT	0
684286	683947	20252E	PARTICIPANT	\N	PRESENT	0
684288	683947	19441R	PARTICIPANT	\N	PRESENT	0
684289	683947	20048C	PARTICIPANT	\N	PRESENT	0
684290	683947	14042U	PARTICIPANT	\N	PRESENT	0
684609	683273	14026U	PARTICIPANT	\N	PRESENT	0
684610	680943	14237S	PARTICIPANT	\N	PRESENT	0
684611	680943	08060W	PARTICIPANT	\N	PRESENT	0
684612	680943	20068G	PARTICIPANT	\N	PRESENT	0
684613	680943	20076G	PARTICIPANT	\N	PRESENT	0
684614	680943	20046A	PARTICIPANT	\N	PRESENT	0
684615	680943	20106U	PARTICIPANT	\N	PRESENT	0
684616	680943	19251M	PARTICIPANT	\N	PRESENT	0
684617	680943	20102Q	PARTICIPANT	\N	PRESENT	0
684618	680943	20146D	PARTICIPANT	\N	PRESENT	0
684619	680943	19826F	PARTICIPANT	\N	PRESENT	0
684620	683273	08061X	PARTICIPANT	\N	PRESENT	0
684621	683273	04045F	PARTICIPANT	\N	PRESENT	0
684622	683273	14073Q	PARTICIPANT	\N	PRESENT	0
684623	683273	19569H	PARTICIPANT	\N	PRESENT	0
684624	683273	14327T	PARTICIPANT	\N	PRESENT	0
684625	683273	19479G	PARTICIPANT	\N	PRESENT	0
684626	683273	19739H	PARTICIPANT	\N	PRESENT	0
684627	683273	20016T	PARTICIPANT	\N	PRESENT	0
684628	683273	20092G	PARTICIPANT	\N	PRESENT	0
684629	683273	19631V	PARTICIPANT	\N	PRESENT	0
684630	680943	19525U	PARTICIPANT	\N	PRESENT	0
684631	683273	14121F	PARTICIPANT	\N	PRESENT	0
684632	683273	18193Q	PARTICIPANT	\N	PRESENT	0
684633	683273	20082E	PARTICIPANT	\N	PRESENT	0
684634	683273	11012A	PARTICIPANT	\N	PRESENT	0
684635	683273	19629C	PARTICIPANT	\N	PRESENT	0
684636	683273	14207L	PARTICIPANT	\N	PRESENT	0
684637	683273	19563B	PARTICIPANT	\N	PRESENT	0
684638	683273	20116W	PARTICIPANT	\N	PRESENT	0
684639	683273	19745F	PARTICIPANT	\N	PRESENT	0
684640	683273	14189C	PARTICIPANT	\N	PRESENT	0
684641	683273	20124W	PARTICIPANT	\N	PRESENT	0
684642	683273	20152B	PARTICIPANT	\N	PRESENT	0
684643	683273	19798U	PARTICIPANT	\N	PRESENT	0
684644	683273	14215L	PARTICIPANT	\N	PRESENT	0
684645	683273	20090E	PARTICIPANT	\N	PRESENT	0
684646	683273	19768N	PARTICIPANT	\N	PRESENT	0
684673	680943	19333N	PARTICIPANT	\N	PRESENT	0
684648	683273	07029T	PARTICIPANT	\N	PRESENT	0
684649	683273	20180F	PARTICIPANT	\N	PRESENT	0
684650	683273	20038A	PARTICIPANT	\N	PRESENT	0
684651	680943	14219Q	PRESIDENT	0	PRESENT	0
684652	680943	20020P	PARTICIPANT	\N	PRESENT	0
684653	680943	20024T	PARTICIPANT	\N	PRESENT	0
684654	683273	19515S	PARTICIPANT	\N	PRESENT	0
684655	683273	20078J	PARTICIPANT	\N	PRESENT	0
684656	683273	20108W	PARTICIPANT	\N	PRESENT	0
684657	683273	10015M	PARTICIPANT	\N	PRESENT	0
684658	683273	11043H	PARTICIPANT	\N	PRESENT	0
684659	683273	14069U	PARTICIPANT	\N	PRESENT	0
684663	680943	19619A	PARTICIPANT	\N	PRESENT	0
684661	683273	19691J	PARTICIPANT	\N	PRESENT	0
684662	683273	14042U	PARTICIPANT	\N	PRESENT	0
684664	683273	14147R	PARTICIPANT	\N	PRESENT	0
684665	683273	01058X	PARTICIPANT	\N	PRESENT	0
684666	683273	19729F	PARTICIPANT	\N	PRESENT	0
684667	680943	19503N	PARTICIPANT	\N	PRESENT	0
684668	680943	20136B	PARTICIPANT	\N	PRESENT	0
684669	680943	18083K	PARTICIPANT	\N	PRESENT	0
684670	683273	14357A	PARTICIPANT	\N	PRESENT	0
684671	683273	14329V	PARTICIPANT	\N	PRESENT	0
684672	683273	08045X	PARTICIPANT	\N	PRESENT	0
684674	680943	19701S	PARTICIPANT	\N	PRESENT	0
684675	680943	20100N	PARTICIPANT	\N	PRESENT	0
684676	683273	14033T	PARTICIPANT	\N	PRESENT	0
684677	683273	14111D	PARTICIPANT	\N	PRESENT	0
684678	683273	19782L	PARTICIPANT	\N	PRESENT	0
684679	683273	11056N	PARTICIPANT	\N	PRESENT	0
684680	683273	11090Q	PARTICIPANT	\N	PRESENT	0
684681	683273	14151M	PARTICIPANT	\N	PRESENT	0
684682	680943	19549D	PARTICIPANT	\N	PRESENT	0
684683	680943	19820Y	PARTICIPANT	\N	PRESENT	0
684684	680943	19637C	PARTICIPANT	\N	PRESENT	0
684685	680943	20118Y	PARTICIPANT	\N	PRESENT	0
684686	680943	17229F	PARTICIPANT	\N	PRESENT	0
684687	683273	20062A	PARTICIPANT	\N	PRESENT	0
684688	683273	01024M	PARTICIPANT	\N	PRESENT	0
684689	683273	19575F	PARTICIPANT	\N	PRESENT	0
684690	683273	20026V	PARTICIPANT	\N	PRESENT	0
684691	683273	20066E	PARTICIPANT	\N	PRESENT	0
684692	683273	11103C	PARTICIPANT	\N	PRESENT	0
684693	683273	20056C	PARTICIPANT	\N	PRESENT	0
684694	683273	19443T	PARTICIPANT	\N	PRESENT	0
684695	683273	11064N	PARTICIPANT	\N	PRESENT	0
684697	683273	19507S	PARTICIPANT	\N	PRESENT	0
684698	683273	20034V	PARTICIPANT	\N	PRESENT	0
684704	683273	14169X	PARTICIPANT	\N	PRESENT	0
684712	680943	11065P	PARTICIPANT	\N	PRESENT	0
684713	680943	20032T	PARTICIPANT	\N	PRESENT	0
684721	683273	01060R	PARTICIPANT	\N	PRESENT	0
684722	680943	14221J	PARTICIPANT	\N	PRESENT	0
684723	683273	01025N	PARTICIPANT	\N	PRESENT	0
684724	680943	19745F	PARTICIPANT	\N	PRESENT	0
684725	683273	14105F	PARTICIPANT	\N	PRESENT	0
684726	683273	05012A	PARTICIPANT	\N	PRESENT	0
684727	680943	20120S	PARTICIPANT	\N	PRESENT	0
684728	683273	20048C	PARTICIPANT	\N	PRESENT	0
684729	683273	20298U	PARTICIPANT	\N	PRESENT	0
684730	683273	19741B	PARTICIPANT	\N	PRESENT	0
684731	683273	19489J	PARTICIPANT	\N	PRESENT	0
684732	683273	20068G	PARTICIPANT	\N	PRESENT	0
684733	683273	20076G	PARTICIPANT	\N	PRESENT	0
684734	683273	11072N	PARTICIPANT	\N	PRESENT	0
684735	683273	20024T	PARTICIPANT	\N	PRESENT	0
684736	683273	19413M	PARTICIPANT	\N	PRESENT	0
684737	683273	19251M	PARTICIPANT	\N	PRESENT	0
684738	683273	20110Q	PARTICIPANT	\N	PRESENT	0
684739	683273	20088L	PARTICIPANT	\N	PRESENT	0
684740	683273	14021P	PARTICIPANT	\N	PRESENT	0
684741	683273	14053L	PARTICIPANT	\N	PRESENT	0
684742	683273	08015R	PARTICIPANT	\N	PRESENT	0
684743	683273	20054A	PARTICIPANT	\N	PRESENT	0
684744	683273	14089Y	PARTICIPANT	\N	PRESENT	0
701342	701340	20058E	PARTICIPANT	\N	PRESENT	0
701343	701340	11048N	PARTICIPANT	\N	PRESENT	0
701344	701340	14059S	PARTICIPANT	\N	PRESENT	0
701345	698976	14331P	PARTICIPANT	\N	PRESENT	0
701346	698976	04047H	PARTICIPANT	\N	PRESENT	0
701347	698976	19543W	PARTICIPANT	\N	PRESENT	0
701348	698976	14073Q	PARTICIPANT	\N	PRESENT	0
701349	698976	19719D	PARTICIPANT	\N	PRESENT	0
701350	698976	20108W	PARTICIPANT	\N	PRESENT	0
701351	698976	19563B	PARTICIPANT	\N	PRESENT	0
701352	698976	04045F	PARTICIPANT	\N	PRESENT	0
701353	698976	11026G	PARTICIPANT	\N	PRESENT	0
701354	698976	12041X	PARTICIPANT	\N	PRESENT	0
701355	698976	14189C	PARTICIPANT	\N	PRESENT	0
701339	698976	95063L	PARTICIPANT	\N	PRESENT	0
701341	701340	20118Y	PARTICIPANT	\N	PRESENT	0
701356	698976	11033F	PARTICIPANT	\N	PRESENT	0
701357	698976	19954N	PARTICIPANT	\N	PRESENT	0
701358	698976	14001X	PARTICIPANT	\N	PRESENT	0
701359	698976	04085P	PARTICIPANT	\N	PRESENT	0
701360	698976	19441R	PARTICIPANT	\N	PRESENT	0
701361	698976	17023S	PARTICIPANT	\N	PRESENT	0
701362	698976	14147R	PARTICIPANT	\N	PRESENT	0
701363	698976	14071N	PARTICIPANT	\N	PRESENT	0
701364	698976	20034V	PARTICIPANT	\N	PRESENT	0
701365	698976	20180F	PARTICIPANT	\N	PRESENT	0
701366	698976	14033T	PARTICIPANT	\N	PRESENT	0
701367	698976	19447X	PARTICIPANT	\N	PRESENT	0
701368	698976	14215L	PARTICIPANT	\N	PRESENT	0
701396	701395	14073Q	PARTICIPANT	\N	PRESENT	0
701435	701425	19735D	PARTICIPANT	\N	PRESENT	0
701436	701425	20098N	PARTICIPANT	\N	PRESENT	0
701437	701425	11110B	PARTICIPANT	\N	PRESENT	0
701438	698977	99004R	PARTICIPANT	\N	PRESENT	0
701439	701425	11065P	PARTICIPANT	\N	PRESENT	0
701440	701425	19631V	PARTICIPANT	\N	PRESENT	0
701441	701425	20082E	PARTICIPANT	\N	PRESENT	0
701442	701425	20032T	PARTICIPANT	\N	PRESENT	0
701443	701425	01043Q	PARTICIPANT	\N	PRESENT	0
701444	701425	20086J	PARTICIPANT	\N	PRESENT	0
701445	701425	19503N	PARTICIPANT	\N	PRESENT	0
701446	701425	20046A	PARTICIPANT	\N	PRESENT	0
701454	701453	08009T	PARTICIPANT	\N	PRESENT	0
701455	701453	08015R	PARTICIPANT	\N	PRESENT	0
701456	701453	19713W	PARTICIPANT	\N	PRESENT	0
701457	701453	18083K	PARTICIPANT	\N	PRESENT	0
701458	701453	14169X	PARTICIPANT	\N	PRESENT	0
701459	701453	11026G	PARTICIPANT	\N	PRESENT	0
701460	701453	19739H	PARTICIPANT	\N	PRESENT	0
701461	701453	10015M	PARTICIPANT	\N	PRESENT	0
701463	698977	19335Q	PARTICIPANT	\N	PRESENT	0
701464	698977	20052X	PARTICIPANT	\N	PRESENT	0
701465	698977	19575F	PARTICIPANT	\N	PRESENT	0
701466	701462	14259Y	PARTICIPANT	\N	PRESENT	0
701467	698977	20096L	PARTICIPANT	\N	PRESENT	0
701468	701462	19333N	PARTICIPANT	\N	PRESENT	0
701469	698977	19715Y	PARTICIPANT	\N	PRESENT	0
701470	698977	14267Y	PARTICIPANT	\N	PRESENT	0
701473	701472	11026G	PARTICIPANT	\N	PRESENT	0
701474	701472	04070G	PARTICIPANT	\N	PRESENT	0
701475	701472	19333N	PARTICIPANT	\N	PRESENT	0
701476	701472	14255U	PARTICIPANT	\N	PRESENT	0
701477	701472	19766L	PARTICIPANT	\N	PRESENT	0
701478	701472	14357A	PARTICIPANT	\N	PRESENT	0
701479	698977	19637C	PARTICIPANT	\N	PRESENT	0
701480	698977	19479G	PARTICIPANT	\N	PRESENT	0
701481	698977	20126Y	PARTICIPANT	\N	PRESENT	0
701482	698977	19768N	PARTICIPANT	\N	PRESENT	0
701484	701483	19766L	PARTICIPANT	\N	PRESENT	0
701485	701483	14255U	PARTICIPANT	\N	PRESENT	0
701486	701483	04070G	PARTICIPANT	\N	PRESENT	0
701487	701483	11026G	PARTICIPANT	\N	PRESENT	0
701488	701483	19333N	PARTICIPANT	\N	PRESENT	0
701489	701483	14357A	PARTICIPANT	\N	PRESENT	0
701491	701490	19709B	PARTICIPANT	\N	PRESENT	0
701492	701490	20264J	PARTICIPANT	\N	PRESENT	0
701493	701490	20266L	PARTICIPANT	\N	PRESENT	0
701494	701490	08018U	PARTICIPANT	\N	PRESENT	0
701495	701490	14255U	PARTICIPANT	\N	PRESENT	0
701497	701496	14147R	PARTICIPANT	\N	PRESENT	0
701498	701496	04043D	PARTICIPANT	\N	PRESENT	0
701499	701496	14255U	PARTICIPANT	\N	PRESENT	0
701500	701496	04035D	PARTICIPANT	\N	PRESENT	0
701501	701496	08018U	PARTICIPANT	\N	PRESENT	0
701502	701496	11026G	PARTICIPANT	\N	PRESENT	0
701503	701496	20264J	PARTICIPANT	\N	PRESENT	0
701504	701496	19709B	PARTICIPANT	\N	PRESENT	0
701505	698977	19369B	PARTICIPANT	\N	PRESENT	0
701506	698977	19735D	PARTICIPANT	\N	PRESENT	0
701507	698977	14030Q	PARTICIPANT	\N	PRESENT	0
701508	698977	01024M	PARTICIPANT	\N	PRESENT	0
701509	698977	20046A	PARTICIPANT	\N	PRESENT	0
701510	698977	17779H	PARTICIPANT	\N	PRESENT	0
701511	698977	14205J	PARTICIPANT	\N	PRESENT	0
701513	698977	19531S	PARTICIPANT	\N	PRESENT	0
701514	698977	04043D	PARTICIPANT	\N	PRESENT	0
701515	698977	19691J	PARTICIPANT	\N	PRESENT	0
701525	698977	14001X	PARTICIPANT	\N	PRESENT	0
701526	698977	14207L	PARTICIPANT	\N	PRESENT	0
701528	698977	19681G	PARTICIPANT	\N	PRESENT	0
701529	698977	19685L	PARTICIPANT	\N	PRESENT	0
701545	698978	19565D	PARTICIPANT	\N	PRESENT	0
701546	698978	20134Y	PARTICIPANT	\N	PRESENT	0
701547	698978	14231L	PARTICIPANT	\N	PRESENT	0
701543	698978	12041X	PARTICIPANT	\N	PRESENT	0
701544	698978	19489J	PARTICIPANT	\N	PRESENT	0
701548	698978	19782L	PARTICIPANT	\N	PRESENT	0
701549	698978	11012A	PARTICIPANT	\N	PRESENT	0
701550	698978	04057K	PARTICIPANT	\N	PRESENT	0
701551	698978	20070A	PARTICIPANT	\N	PRESENT	0
701552	698978	20030R	PARTICIPANT	\N	PRESENT	0
701553	698978	20090E	PARTICIPANT	\N	PRESENT	0
701554	698978	20032T	PARTICIPANT	\N	PRESENT	0
701555	698978	14259Y	PARTICIPANT	\N	PRESENT	0
701556	698978	14053L	PARTICIPANT	\N	PRESENT	0
701557	698978	20084G	PARTICIPANT	\N	PRESENT	0
701558	698978	20098N	PARTICIPANT	\N	PRESENT	0
701559	698978	14189C	PARTICIPANT	\N	PRESENT	0
701560	698978	20130U	PARTICIPANT	\N	PRESENT	0
701561	698978	19758L	PARTICIPANT	\N	PRESENT	0
701564	698978	14001X	PARTICIPANT	\N	PRESENT	0
701565	698978	19671E	PARTICIPANT	\N	PRESENT	0
701568	698978	19687N	PARTICIPANT	\N	PRESENT	0
701571	698978	20068G	PARTICIPANT	\N	PRESENT	0
701572	698978	19525U	PARTICIPANT	\N	PRESENT	0
701573	698978	19441R	PARTICIPANT	\N	PRESENT	0
701574	698978	14237S	PARTICIPANT	\N	PRESENT	0
701578	698978	19681G	PARTICIPANT	\N	PRESENT	0
701589	698978	97011G	PARTICIPANT	\N	PRESENT	0
701590	698978	14217N	PARTICIPANT	\N	PRESENT	0
701592	698978	99004R	PARTICIPANT	\N	PRESENT	0
701594	701580	19533U	PARTICIPANT	\N	PRESENT	0
701595	698978	20132W	PARTICIPANT	\N	PRESENT	0
701596	698978	01024M	PARTICIPANT	\N	PRESENT	0
701598	701597	19479G	PARTICIPANT	\N	PRESENT	0
701604	701602	19479G	PARTICIPANT	\N	PRESENT	0
701608	701607	99004R	PARTICIPANT	\N	PRESENT	0
701822	701641	14026U	PARTICIPANT	\N	PRESENT	0
701823	701641	20044X	PARTICIPANT	\N	PRESENT	0
701824	701641	18083K	PARTICIPANT	\N	PRESENT	0
701825	701641	14187A	PARTICIPANT	\N	PRESENT	0
701826	701641	19441R	PARTICIPANT	\N	PRESENT	0
701827	701641	07029T	PARTICIPANT	\N	PRESENT	0
701828	701641	20092G	PARTICIPANT	\N	PRESENT	0
701829	701641	20136B	PARTICIPANT	\N	PRESENT	0
701830	701641	14189C	PARTICIPANT	\N	PRESENT	0
701831	701641	04042C	PARTICIPANT	\N	PRESENT	0
701290	701285	20090E	PARTICIPANT	\N	PRESENT	0
701291	701285	04057K	PARTICIPANT	\N	PRESENT	0
701832	701641	19367Y	PARTICIPANT	\N	PRESENT	0
701833	701641	04092N	PARTICIPANT	\N	PRESENT	0
701834	701641	20030R	PARTICIPANT	\N	PRESENT	0
701835	701641	14217N	PARTICIPANT	\N	PRESENT	0
701836	701641	19713W	PARTICIPANT	\N	PRESENT	0
701837	701641	08015R	PARTICIPANT	\N	PRESENT	0
701838	701641	20066E	PARTICIPANT	\N	PRESENT	0
701839	701641	19954N	PARTICIPANT	\N	PRESENT	0
701840	701641	20140W	PARTICIPANT	\N	PRESENT	0
701841	701641	19723Y	PARTICIPANT	\N	PRESENT	0
685287	683227	14147R	PARTICIPANT	\N	PRESENT	0
688397	688396	19826F	PARTICIPANT	\N	PRESENT	0
688398	688396	14033T	PARTICIPANT	\N	PRESENT	0
688400	688399	19826F	PARTICIPANT	\N	PRESENT	0
688401	688399	14033T	PARTICIPANT	\N	PRESENT	0
688403	688402	19826F	PARTICIPANT	\N	PRESENT	0
688405	688404	19826F	PARTICIPANT	\N	PRESENT	0
688406	688404	14033T	PARTICIPANT	\N	PRESENT	0
688408	688407	19826F	PARTICIPANT	\N	PRESENT	0
688410	688409	19826F	PARTICIPANT	\N	PRESENT	0
688411	688409	14033T	PARTICIPANT	\N	PRESENT	0
688413	688412	19826F	PARTICIPANT	\N	PRESENT	0
688414	688412	14033T	PARTICIPANT	\N	PRESENT	0
688416	688415	19826F	PARTICIPANT	\N	PRESENT	0
688418	688417	19826F	PARTICIPANT	\N	PRESENT	0
688466	688465	19719D	PARTICIPANT	\N	PRESENT	0
688467	688465	20106U	PARTICIPANT	\N	PRESENT	0
689680	688648	20914V	PARTICIPANT	\N	PRESENT	0
689681	688648	20040T	PARTICIPANT	\N	PRESENT	0
689682	688648	14223L	PARTICIPANT	\N	PRESENT	0
689683	688648	04070G	PARTICIPANT	\N	PRESENT	0
689684	688648	14173T	PARTICIPANT	\N	PRESENT	0
689685	688648	20028X	PARTICIPANT	\N	PRESENT	0
689686	688648	20980G	PARTICIPANT	\N	PRESENT	0
689687	688648	20078J	PARTICIPANT	\N	PRESENT	0
689688	688648	19585H	PARTICIPANT	\N	PRESENT	0
689689	688648	04092N	PARTICIPANT	\N	PRESENT	0
689690	688648	19533U	PARTICIPANT	\N	PRESENT	0
689691	688648	19525U	PARTICIPANT	\N	PRESENT	0
689692	688648	14215L	PARTICIPANT	\N	PRESENT	0
689693	688648	19515S	PARTICIPANT	\N	PRESENT	0
689694	688648	14033T	PARTICIPANT	\N	PRESENT	0
689695	688648	20144B	PARTICIPANT	\N	PRESENT	0
689696	688648	20060X	PARTICIPANT	\N	PRESENT	0
689697	688648	20076G	PARTICIPANT	\N	PRESENT	0
689698	688648	20054A	PARTICIPANT	\N	PRESENT	0
689699	688648	11101A	PARTICIPANT	\N	PRESENT	0
689700	688648	11104D	PARTICIPANT	\N	PRESENT	0
689701	688648	08045X	PARTICIPANT	\N	PRESENT	0
689702	688648	19671E	PARTICIPANT	\N	PRESENT	0
689703	688648	11067R	PARTICIPANT	\N	PRESENT	0
689704	688648	19826F	PARTICIPANT	\N	PRESENT	0
689705	688648	20062A	PARTICIPANT	\N	PRESENT	0
689706	688648	19745F	PARTICIPANT	\N	PRESENT	0
689707	688648	20116W	PARTICIPANT	\N	PRESENT	0
689708	688648	19593H	PARTICIPANT	\N	PRESENT	0
689709	688648	19367Y	PARTICIPANT	\N	PRESENT	0
689710	688648	20056C	PARTICIPANT	\N	PRESENT	0
689711	688648	10015M	PARTICIPANT	\N	PRESENT	0
689712	688648	14267Y	PARTICIPANT	\N	PRESENT	0
689713	688648	19553Y	PARTICIPANT	\N	PRESENT	0
689714	688648	07004J	PARTICIPANT	\N	PRESENT	0
689715	688648	20072C	PARTICIPANT	\N	PRESENT	0
689716	688648	19747H	PARTICIPANT	\N	PRESENT	0
689717	688648	19647E	PARTICIPANT	\N	PRESENT	0
689718	688648	14109K	PARTICIPANT	\N	PRESENT	0
689719	688648	19683J	PARTICIPANT	\N	PRESENT	0
689720	688648	17779H	PARTICIPANT	\N	PRESENT	0
689721	688648	01062T	PARTICIPANT	\N	PRESENT	0
689722	688648	12016W	PARTICIPANT	\N	PRESENT	0
689723	688648	11033F	PARTICIPANT	\N	PRESENT	0
689724	688648	20084G	PARTICIPANT	\N	PRESENT	0
689725	688648	11066Q	PARTICIPANT	\N	PRESENT	0
689726	688648	19760E	PARTICIPANT	\N	PRESENT	0
689727	688648	19599P	PARTICIPANT	\N	PRESENT	0
689728	688648	04008A	PARTICIPANT	\N	PRESENT	0
689729	688648	17637T	PARTICIPANT	\N	PRESENT	0
689730	688648	19711U	PARTICIPANT	\N	PRESENT	0
689731	688648	19621T	PARTICIPANT	\N	PRESENT	0
689732	688648	08011M	PARTICIPANT	\N	PRESENT	0
689733	688648	19693L	PARTICIPANT	\N	PRESENT	0
689734	688648	19575F	PARTICIPANT	\N	PRESENT	0
689735	688648	01058X	PARTICIPANT	\N	PRESENT	0
689736	688648	99004R	PARTICIPANT	\N	PRESENT	0
689737	688648	14026U	PARTICIPANT	\N	PRESENT	0
689738	688648	04047H	PARTICIPANT	\N	PRESENT	0
689739	688648	08010L	PARTICIPANT	\N	PRESENT	0
689740	688648	11048N	PARTICIPANT	\N	PRESENT	0
689741	688648	18083K	PARTICIPANT	\N	PRESENT	0
689742	688648	08069G	PARTICIPANT	\N	PRESENT	0
689743	688648	14123H	PARTICIPANT	\N	PRESENT	0
689744	688648	20074E	PARTICIPANT	\N	PRESENT	0
689745	688648	19679N	PARTICIPANT	\N	PRESENT	0
689746	688648	19643A	PARTICIPANT	\N	PRESENT	0
689747	688648	04071H	PARTICIPANT	\N	PRESENT	0
689748	688648	11043H	PARTICIPANT	\N	PRESENT	0
689749	688648	01048V	PARTICIPANT	\N	PRESENT	0
689750	688648	08028W	PARTICIPANT	\N	PRESENT	0
689751	688648	04033B	PARTICIPANT	\N	PRESENT	0
689752	688648	14187A	PARTICIPANT	\N	PRESENT	0
689753	688648	04085P	PARTICIPANT	\N	PRESENT	0
689754	688648	14071N	PARTICIPANT	\N	PRESENT	0
689755	688648	20112S	PARTICIPANT	\N	PRESENT	0
689756	688648	11097X	PARTICIPANT	\N	PRESENT	0
689757	688648	19415P	PARTICIPANT	\N	PRESENT	0
689758	688648	11040E	PARTICIPANT	\N	PRESENT	0
689759	688648	19695N	PARTICIPANT	\N	PRESENT	0
689760	688648	19421M	PARTICIPANT	\N	PRESENT	0
689761	688648	12041X	PARTICIPANT	\N	PRESENT	0
689762	688648	14053L	PARTICIPANT	\N	PRESENT	0
689763	688648	19758L	PARTICIPANT	\N	PRESENT	0
689765	688648	19687N	PARTICIPANT	\N	PRESENT	0
689766	688648	11031D	PARTICIPANT	\N	PRESENT	0
689767	688648	14069U	PARTICIPANT	\N	PRESENT	0
689768	688648	11090Q	PARTICIPANT	\N	PRESENT	0
689769	688648	05012A	PARTICIPANT	\N	PRESENT	0
689770	688648	20022R	PARTICIPANT	\N	PRESENT	0
689771	688648	01057W	PARTICIPANT	\N	PRESENT	0
689772	688648	14259Y	PARTICIPANT	\N	PRESENT	0
689773	688648	20102Q	PARTICIPANT	\N	PRESENT	0
689774	688648	11080N	PARTICIPANT	\N	PRESENT	0
689775	688648	19673G	PARTICIPANT	\N	PRESENT	0
689776	688648	14031R	PARTICIPANT	\N	PRESENT	0
689777	688648	19667J	PARTICIPANT	\N	PRESENT	0
689778	688648	14253S	PARTICIPANT	\N	PRESENT	0
689779	688648	20032T	PARTICIPANT	\N	PRESENT	0
689780	688648	20136B	PARTICIPANT	\N	PRESENT	0
689781	688648	20118Y	PARTICIPANT	\N	PRESENT	0
689782	688648	10006L	PARTICIPANT	\N	PRESENT	0
689783	688648	20252E	PARTICIPANT	\N	PRESENT	0
689784	688648	20120S	PARTICIPANT	\N	PRESENT	0
689785	688648	14217N	PARTICIPANT	\N	PRESENT	0
689786	688648	07033P	PARTICIPANT	\N	PRESENT	0
689787	688648	97011G	PARTICIPANT	\N	PRESENT	0
689788	688648	14147R	PARTICIPANT	\N	PRESENT	0
689789	688648	11065P	PARTICIPANT	\N	PRESENT	0
689790	688648	20134Y	PARTICIPANT	\N	PRESENT	0
689791	688648	20172F	PARTICIPANT	\N	PRESENT	0
689792	688648	20138D	PARTICIPANT	\N	PRESENT	0
689793	688648	20100N	PARTICIPANT	\N	PRESENT	0
689794	688648	08047A	PARTICIPANT	\N	PRESENT	0
689795	688648	20142Y	PARTICIPANT	\N	PRESENT	0
689796	688648	20130U	PARTICIPANT	\N	PRESENT	0
689797	688648	20140W	PARTICIPANT	\N	PRESENT	0
689798	688648	20092G	PARTICIPANT	\N	PRESENT	0
689799	688648	20266L	PARTICIPANT	\N	PRESENT	0
689800	688648	19954N	PARTICIPANT	\N	PRESENT	0
689801	688648	20110Q	PARTICIPANT	\N	PRESENT	0
689802	688648	20026V	PARTICIPANT	\N	PRESENT	0
689803	688648	19651A	PARTICIPANT	\N	PRESENT	0
689804	688648	20180F	PARTICIPANT	\N	PRESENT	0
689805	688648	19782L	PARTICIPANT	\N	PRESENT	0
689806	688648	19057M	PARTICIPANT	\N	PRESENT	0
689807	688648	11083R	PARTICIPANT	\N	PRESENT	0
689808	688648	19329S	PARTICIPANT	\N	PRESENT	0
689809	688648	20106U	PARTICIPANT	\N	PRESENT	0
689810	688648	20128B	PARTICIPANT	\N	PRESENT	0
689811	688648	19591F	PARTICIPANT	\N	PRESENT	0
689812	688648	19573D	PARTICIPANT	\N	PRESENT	0
689813	688648	14038Y	PARTICIPANT	\N	PRESENT	0
689814	688648	14249W	PARTICIPANT	\N	PRESENT	0
689815	688648	14037X	PARTICIPANT	\N	PRESENT	0
689816	688648	19637C	PARTICIPANT	\N	PRESENT	0
689817	688648	19723Y	PARTICIPANT	\N	PRESENT	0
689818	688648	08073C	PARTICIPANT	\N	PRESENT	0
689819	688648	08061X	PARTICIPANT	\N	PRESENT	0
689820	688648	20146D	PARTICIPANT	\N	PRESENT	0
689821	688648	19349W	PARTICIPANT	\N	PRESENT	0
689822	688648	19467C	PARTICIPANT	\N	PRESENT	0
689823	688648	95063L	PARTICIPANT	\N	PRESENT	0
696569	694947	19591F	PARTICIPANT	\N	PRESENT	0
696570	694947	04057K	PARTICIPANT	\N	PRESENT	0
696571	694947	11067R	PARTICIPANT	\N	PRESENT	0
696572	694947	04043D	PARTICIPANT	\N	PRESENT	0
696573	694947	20066E	PARTICIPANT	\N	PRESENT	0
696574	694947	19569H	PARTICIPANT	\N	PRESENT	0
696625	695107	11027H	PARTICIPANT	\N	PRESENT	0
696626	695107	14249W	PARTICIPANT	\N	PRESENT	0
696627	695107	14105F	PARTICIPANT	\N	EXCUSE	0
696628	695107	01062T	PARTICIPANT	\N	EXCUSE	0
696699	695155	14229S	PARTICIPANT	\N	PRESENT	0
696700	695155	20070A	PARTICIPANT	\N	PRESENT	0
696701	695155	19631V	PARTICIPANT	\N	PRESENT	0
696702	695155	20080C	PARTICIPANT	\N	PRESENT	0
696703	695155	19637C	PARTICIPANT	\N	PRESENT	0
696704	695155	11072N	PARTICIPANT	\N	PRESENT	0
696705	695155	20132W	PARTICIPANT	\N	PRESENT	0
696706	695155	19479G	PARTICIPANT	\N	PRESENT	0
696707	695155	19415P	PARTICIPANT	\N	PRESENT	0
696708	695155	20108W	PARTICIPANT	\N	PRESENT	0
696709	695155	08034U	PARTICIPANT	\N	PRESENT	0
696710	695155	19675J	PARTICIPANT	\N	PRESENT	0
696524	695217	19631V	PARTICIPANT	\N	PRESENT	0
696525	695217	20104S	PARTICIPANT	\N	PRESENT	0
696526	695217	08015R	PARTICIPANT	\N	PRESENT	0
696527	695217	19575F	PARTICIPANT	\N	PRESENT	0
696528	695217	19369B	PARTICIPANT	\N	PRESENT	0
696529	695217	20018V	PARTICIPANT	\N	PRESENT	0
696530	695217	19563B	PARTICIPANT	\N	PRESENT	0
696531	695217	20028X	PARTICIPANT	\N	PRESENT	0
696532	695217	14329V	PARTICIPANT	\N	PRESENT	0
696533	695217	20030R	PARTICIPANT	\N	PRESENT	0
696534	695217	14038Y	PARTICIPANT	\N	PRESENT	0
696535	695217	19467C	PARTICIPANT	\N	PRESENT	0
696536	695217	20034V	PARTICIPANT	\N	PRESENT	0
696537	695217	14187A	PARTICIPANT	\N	PRESENT	0
696538	695217	19695N	PARTICIPANT	\N	PRESENT	0
696539	695217	01025N	PARTICIPANT	\N	PRESENT	0
696540	695217	11090Q	PRESIDENT	0	PRESENT	0
696541	695217	14033T	PARTICIPANT	\N	PRESENT	0
696542	695217	20054A	PARTICIPANT	\N	PRESENT	0
696543	695217	14205J	PARTICIPANT	\N	PRESENT	0
696544	695217	20060X	PARTICIPANT	\N	PRESENT	0
696545	695217	20062A	PARTICIPANT	\N	PRESENT	0
696546	695217	20286Q	PARTICIPANT	\N	PRESENT	0
696547	695217	14207L	PARTICIPANT	\N	PRESENT	0
696548	695217	19747H	PARTICIPANT	\N	PRESENT	0
696549	695217	14257W	PARTICIPANT	\N	PRESENT	0
696550	695217	20144B	PARTICIPANT	\N	EXCUSE	0
696551	695217	20082E	PARTICIPANT	\N	EXCUSE	0
696552	695217	08028W	PARTICIPANT	\N	EXCUSE	0
696711	695155	19673G	PARTICIPANT	\N	PRESENT	0
696712	695155	14259Y	PARTICIPANT	\N	PRESENT	0
696713	695155	14133K	PARTICIPANT	\N	PRESENT	0
696714	695155	19543W	PARTICIPANT	\N	PRESENT	0
696715	695155	19611R	PARTICIPANT	\N	PRESENT	0
696716	695155	19619A	PARTICIPANT	\N	PRESENT	0
696717	695155	19820Y	PARTICIPANT	\N	PRESENT	0
696718	695155	20100N	PARTICIPANT	\N	PRESENT	0
696719	695155	19503N	PARTICIPANT	\N	PRESENT	0
696720	695155	14107H	PARTICIPANT	\N	PRESENT	0
696721	695155	20072C	PARTICIPANT	\N	PRESENT	0
696722	695155	14331P	PARTICIPANT	\N	PRESENT	0
696723	695155	20104S	PARTICIPANT	\N	PRESENT	0
696724	695155	20044X	PARTICIPANT	\N	PRESENT	0
696725	695155	20086J	PARTICIPANT	\N	PRESENT	0
696726	695155	10015M	PARTICIPANT	\N	PRESENT	0
696727	695155	20032T	PARTICIPANT	\N	PRESENT	0
696728	695155	07033P	PARTICIPANT	\N	PRESENT	0
696729	695155	14217N	PARTICIPANT	\N	PRESENT	0
696730	695155	20120S	PARTICIPANT	\N	PRESENT	0
696731	695155	14030Q	PARTICIPANT	\N	PRESENT	0
696732	695155	14327T	PARTICIPANT	\N	PRESENT	0
696733	695155	14207L	PARTICIPANT	\N	PRESENT	0
696734	695155	19347U	PARTICIPANT	\N	PRESENT	0
696735	695155	20058E	PARTICIPANT	\N	PRESENT	0
696736	695155	14038Y	PARTICIPANT	\N	PRESENT	0
696737	695155	20034V	PARTICIPANT	\N	PRESENT	0
696738	695155	19467C	PARTICIPANT	\N	PRESENT	0
696739	695155	14173T	PARTICIPANT	\N	PRESENT	0
696740	695155	19447X	PARTICIPANT	\N	PRESENT	0
696741	695155	19573D	PARTICIPANT	\N	PRESENT	0
696742	695155	14187A	PARTICIPANT	\N	PRESENT	0
696743	695155	20056C	PARTICIPANT	\N	PRESENT	0
696744	695155	20098N	PARTICIPANT	\N	PRESENT	0
696745	695155	07029T	PARTICIPANT	\N	PRESENT	0
696746	695155	20026V	PARTICIPANT	\N	PRESENT	0
696747	695155	20096L	PARTICIPANT	\N	PRESENT	0
696748	695155	14031R	PARTICIPANT	\N	PRESENT	0
696749	695155	19667J	PARTICIPANT	\N	PRESENT	0
696750	695155	01057W	PARTICIPANT	\N	PRESENT	0
696751	695155	19766L	PARTICIPANT	\N	PRESENT	0
696752	695155	19643A	PARTICIPANT	\N	PRESENT	0
696753	695155	04071H	PARTICIPANT	\N	PRESENT	0
696754	695155	14169X	PARTICIPANT	\N	PRESENT	0
696755	695155	11043H	PARTICIPANT	\N	PRESENT	0
696756	695155	20076G	PARTICIPANT	\N	PRESENT	0
696757	695155	01058X	PARTICIPANT	\N	PRESENT	0
696758	695155	19575F	PARTICIPANT	\N	PRESENT	0
696759	695155	04035D	PARTICIPANT	\N	PRESENT	0
696760	695155	19621T	PARTICIPANT	\N	PRESENT	0
696761	695155	19711U	PARTICIPANT	\N	PRESENT	0
696762	695155	11101A	PARTICIPANT	\N	PRESENT	0
696763	695155	19703U	PARTICIPANT	\N	PRESENT	0
696764	695155	14026U	PARTICIPANT	\N	PRESENT	0
696765	695155	04047H	PARTICIPANT	\N	PRESENT	0
696766	695155	08010L	PARTICIPANT	\N	PRESENT	0
696767	695155	19747H	PARTICIPANT	\N	PRESENT	0
696768	695155	11048N	PARTICIPANT	\N	PRESENT	0
696769	695155	04092N	PARTICIPANT	\N	PRESENT	0
696770	695155	11097X	PARTICIPANT	\N	PRESENT	0
696771	695155	05008E	PARTICIPANT	\N	PRESENT	0
696772	695155	04033B	PARTICIPANT	\N	PRESENT	0
696773	695155	04043D	PARTICIPANT	\N	PRESENT	0
696774	695155	14069U	PARTICIPANT	\N	PRESENT	0
696775	695155	19701S	PARTICIPANT	\N	PRESENT	0
696776	695155	19421M	PARTICIPANT	\N	PRESENT	0
696777	695155	14215L	PARTICIPANT	\N	PRESENT	0
696778	695155	14193X	PARTICIPANT	\N	PRESENT	0
696779	695155	10006L	PARTICIPANT	\N	PRESENT	0
696780	695155	19533U	PARTICIPANT	\N	PRESENT	0
696781	695155	20118Y	PARTICIPANT	\N	PRESENT	0
696782	695155	97011G	PARTICIPANT	\N	PRESENT	0
696783	695155	19729F	PARTICIPANT	\N	PRESENT	0
696784	695155	20252E	PARTICIPANT	\N	PRESENT	0
696785	695155	95041E	PARTICIPANT	\N	PRESENT	0
696786	695155	19671E	PARTICIPANT	\N	PRESENT	0
696787	695155	19367Y	PARTICIPANT	\N	PRESENT	0
696788	695155	19693L	PARTICIPANT	\N	PRESENT	0
696789	695155	20152B	PARTICIPANT	\N	PRESENT	0
696790	695155	19383Y	PARTICIPANT	\N	PRESENT	0
696791	695155	14357A	PARTICIPANT	\N	PRESENT	0
696792	695155	19695N	PARTICIPANT	\N	PRESENT	0
696793	695155	19687N	PARTICIPANT	\N	PRESENT	0
696794	695155	14329V	PARTICIPANT	\N	PRESENT	0
696795	695155	20046A	PARTICIPANT	\N	PRESENT	0
696796	695155	20062A	PARTICIPANT	\N	PRESENT	0
696797	695155	20110Q	PARTICIPANT	\N	PRESENT	0
696798	695155	20914V	PARTICIPANT	\N	PRESENT	0
696799	695155	20134Y	PARTICIPANT	\N	PRESENT	0
696800	695155	20142Y	PARTICIPANT	\N	PRESENT	0
696801	695155	20130U	PARTICIPANT	\N	PRESENT	0
696802	695155	20092G	PARTICIPANT	\N	PRESENT	0
696803	695155	19651A	PARTICIPANT	\N	PRESENT	0
696804	695155	14059S	PARTICIPANT	\N	PRESENT	0
696805	695155	19782L	PARTICIPANT	\N	PRESENT	0
696806	695155	20124W	PARTICIPANT	\N	PRESENT	0
696807	695155	19525U	PARTICIPANT	\N	PRESENT	0
696808	695155	20126Y	PARTICIPANT	\N	PRESENT	0
696809	695155	19659J	PARTICIPANT	\N	PRESENT	0
696810	695155	14249W	PARTICIPANT	\N	PRESENT	0
684806	683276	20092G	PARTICIPANT	\N	PRESENT	0
684807	683276	18193Q	PARTICIPANT	\N	PRESENT	0
684808	683276	19489J	PARTICIPANT	\N	PRESENT	0
684809	683276	11012A	PARTICIPANT	\N	PRESENT	0
684810	683276	20116W	PARTICIPANT	\N	PRESENT	0
684811	683276	19629C	PARTICIPANT	\N	PRESENT	0
684812	683276	19563B	PARTICIPANT	\N	PRESENT	0
684813	683276	14111D	PARTICIPANT	\N	PRESENT	0
684814	683276	11064N	PARTICIPANT	\N	PRESENT	0
684815	683276	14073Q	PARTICIPANT	\N	PRESENT	0
684816	683276	20298U	PARTICIPANT	\N	PRESENT	0
684817	683276	20054A	PARTICIPANT	\N	PRESENT	0
684818	683276	01024M	PARTICIPANT	\N	PRESENT	0
684819	683276	14215L	PARTICIPANT	\N	PRESENT	0
684820	683276	14105F	PARTICIPANT	\N	PRESENT	0
684821	683276	20090E	PARTICIPANT	\N	PRESENT	0
684822	683276	01058X	PARTICIPANT	\N	PRESENT	0
684823	683276	11072N	PARTICIPANT	\N	PRESENT	0
684824	683276	07029T	PARTICIPANT	\N	PRESENT	0
684825	683276	20068G	PARTICIPANT	\N	PRESENT	0
684826	683276	19443T	PARTICIPANT	\N	PRESENT	0
684827	683276	20026V	PARTICIPANT	\N	PRESENT	0
684828	683276	20180F	PARTICIPANT	\N	PRESENT	0
684829	683276	14107H	PARTICIPANT	\N	PRESENT	0
684830	683276	14151M	PARTICIPANT	\N	PRESENT	0
684831	683276	20070A	PARTICIPANT	\N	PRESENT	0
684832	683276	20088L	PARTICIPANT	\N	PRESENT	0
684833	683276	11085T	PARTICIPANT	\N	PRESENT	0
684834	683276	14053L	PARTICIPANT	\N	PRESENT	0
684835	683276	19798U	PARTICIPANT	\N	PRESENT	0
684836	683276	19713W	PARTICIPANT	\N	PRESENT	0
684837	683276	14030Q	PARTICIPANT	\N	PRESENT	0
684838	683276	19691J	PARTICIPANT	\N	PRESENT	0
684839	683276	14021P	PARTICIPANT	\N	PRESENT	0
684840	683640	19515S	PARTICIPANT	\N	PRESENT	0
684841	683640	20034V	PARTICIPANT	\N	PRESENT	0
684842	683640	19782L	PARTICIPANT	\N	PRESENT	0
684843	683640	20078J	PARTICIPANT	\N	PRESENT	0
684844	683640	19413M	PARTICIPANT	\N	PRESENT	0
684845	683640	19695N	PARTICIPANT	\N	PRESENT	0
684846	683640	11090Q	PRESIDENT	0	PRESENT	0
684847	683640	14033T	PARTICIPANT	\N	PRESENT	0
684848	683640	04045F	PARTICIPANT	\N	PRESENT	0
684849	683640	20054A	PARTICIPANT	\N	PRESENT	0
684850	683640	19631V	PARTICIPANT	\N	PRESENT	0
684851	683640	19507S	PARTICIPANT	\N	PRESENT	0
684852	683640	08015R	PARTICIPANT	\N	PRESENT	0
684853	683640	19575F	PARTICIPANT	\N	PRESENT	0
684854	683640	20298U	PARTICIPANT	\N	PRESENT	0
684855	683640	14207L	PARTICIPANT	\N	PRESENT	0
684856	683640	20018V	PARTICIPANT	\N	PRESENT	0
684857	683640	08028W	PARTICIPANT	\N	PRESENT	0
684858	683640	14037X	PARTICIPANT	\N	PRESENT	0
684859	683640	01025N	PARTICIPANT	\N	PRESENT	0
684860	683276	11097X	PARTICIPANT	\N	PRESENT	0
684861	683640	19768N	PARTICIPANT	\N	PRESENT	0
684862	683640	20104S	PARTICIPANT	\N	PRESENT	0
684863	683640	14251Q	PARTICIPANT	\N	PRESENT	0
684864	683640	14257W	PARTICIPANT	\N	PRESENT	0
684804	683276	14026U	PARTICIPANT	\N	PRESENT	0
684805	683276	20108W	PARTICIPANT	\N	PRESENT	0
684865	683276	20110Q	PARTICIPANT	\N	PRESENT	0
684866	683276	11033F	PARTICIPANT	\N	PRESENT	0
684867	683640	20286Q	PARTICIPANT	\N	PRESENT	0
684868	683640	19747H	PARTICIPANT	\N	PRESENT	0
684869	683276	14089Y	PARTICIPANT	\N	PRESENT	0
684870	683276	19745F	PARTICIPANT	\N	PRESENT	0
684871	683276	19739H	PARTICIPANT	\N	PRESENT	0
684872	683276	20076G	PARTICIPANT	\N	PRESENT	0
685292	685289	01028R	PARTICIPANT	\N	PRESENT	0
684874	683640	14187A	PARTICIPANT	\N	PRESENT	0
684875	683640	20062A	PARTICIPANT	\N	PRESENT	0
684876	683276	11067R	PARTICIPANT	\N	PRESENT	0
684877	683640	01043Q	PARTICIPANT	\N	EXCUSE	0
684878	683640	19369B	PARTICIPANT	\N	EXCUSE	0
684879	683276	19760E	PARTICIPANT	\N	PRESENT	0
684880	683276	04047H	PARTICIPANT	\N	PRESENT	0
684881	683640	14357A	PARTICIPANT	\N	PRESENT	0
684882	683276	20030R	PARTICIPANT	\N	PRESENT	0
684883	683276	14219Q	PARTICIPANT	\N	PRESENT	0
684884	683276	01034P	PARTICIPANT	\N	PRESENT	0
684885	683640	20094J	PARTICIPANT	\N	PRESENT	0
684886	683640	20028X	PARTICIPANT	\N	PRESENT	0
684887	683276	20022R	PARTICIPANT	\N	PRESENT	0
684888	683276	14223L	PARTICIPANT	\N	PRESENT	0
684889	683276	20052X	PARTICIPANT	\N	PRESENT	0
685290	685289	05008E	PARTICIPANT	\N	PRESENT	0
685291	685289	11053K	PARTICIPANT	\N	PRESENT	0
685295	682307	04092N	PARTICIPANT	\N	PRESENT	0
685296	682307	14223L	PARTICIPANT	\N	PRESENT	0
685297	682307	11067R	PARTICIPANT	\N	PRESENT	0
685298	682307	14071N	PARTICIPANT	\N	PRESENT	0
685299	682307	17965H	PARTICIPANT	\N	PRESENT	0
685300	682307	19679N	PARTICIPANT	\N	PRESENT	0
685301	682307	20130U	PARTICIPANT	\N	PRESENT	0
685302	682307	04043D	PARTICIPANT	\N	PRESENT	0
685303	682307	18193Q	PARTICIPANT	\N	PRESENT	0
685304	682307	19511N	PARTICIPANT	\N	PRESENT	0
685305	682307	19683J	PARTICIPANT	\N	PRESENT	0
685306	682307	19657G	PARTICIPANT	\N	PRESENT	0
685307	682307	04057K	PARTICIPANT	\N	PRESENT	0
685308	682307	19697Q	PARTICIPANT	\N	PRESENT	0
685309	682307	17779H	PARTICIPANT	\N	PRESENT	0
685310	682307	11045K	PARTICIPANT	\N	PRESENT	0
685311	682307	19295A	PARTICIPANT	\N	PRESENT	0
685312	682307	19703U	PARTICIPANT	\N	PRESENT	0
685313	682307	19713W	PARTICIPANT	\N	PRESENT	0
685314	682307	19798U	PARTICIPANT	\N	PRESENT	0
685315	682307	11097X	PARTICIPANT	\N	PRESENT	0
685316	682307	01034P	PARTICIPANT	\N	PRESENT	0
685317	682307	20266L	PARTICIPANT	\N	PRESENT	0
685318	682307	19717B	PARTICIPANT	\N	PRESENT	0
685319	682307	19415P	PARTICIPANT	\N	PRESENT	0
685320	682307	19760E	PARTICIPANT	\N	PRESENT	0
685321	682307	14042U	PARTICIPANT	\N	EXCUSE	0
685322	682307	19553Y	PARTICIPANT	\N	PRESENT	0
685323	682307	19329S	PARTICIPANT	\N	PRESENT	0
685324	682307	14355X	PARTICIPANT	\N	EXCUSE	0
685325	682307	14026U	PARTICIPANT	\N	PRESENT	0
685326	682307	14213J	PARTICIPANT	\N	PRESENT	0
685327	682307	20066E	PARTICIPANT	\N	PRESENT	0
685328	682307	19569H	PARTICIPANT	\N	PRESENT	0
685329	682307	19591F	PARTICIPANT	\N	PRESENT	0
685330	682307	11103C	PARTICIPANT	\N	PRESENT	0
685331	682307	11031D	PARTICIPANT	\N	EXCUSE	0
685332	682307	19367Y	PARTICIPANT	\N	PRESENT	0
685333	682307	20090E	PARTICIPANT	\N	PRESENT	0
685334	682307	20248J	PARTICIPANT	\N	PRESENT	0
685335	682307	08045X	PARTICIPANT	\N	PRESENT	0
685336	682307	10006L	PARTICIPANT	\N	PRESENT	0
685337	682307	14217N	PRESIDENT	\N	PRESENT	0
685338	682307	20040T	PARTICIPANT	\N	PRESENT	0
686721	686720	14193X	PARTICIPANT	\N	PRESENT	0
686723	686722	08010L	PARTICIPANT	\N	PRESENT	0
686725	686724	97011G	PARTICIPANT	\N	PRESENT	0
686760	686700	12041X	PARTICIPANT	\N	PRESENT	0
686761	686428	14225N	PRESIDENT	0	PRESENT	0
686762	686428	08009T	PARTICIPANT	\N	PRESENT	0
686763	686428	19671E	PARTICIPANT	\N	PRESENT	0
686764	686428	20050V	PARTICIPANT	\N	PRESENT	0
686765	686428	20044X	PARTICIPANT	\N	PRESENT	0
686766	686428	14083S	PARTICIPANT	\N	PRESENT	0
686767	686700	20914V	PARTICIPANT	\N	PRESENT	0
686768	686700	19441R	PARTICIPANT	\N	PRESENT	0
686769	686428	07029T	PARTICIPANT	\N	EXCUSE	0
686770	686428	11040E	PARTICIPANT	\N	PRESENT	0
686771	686428	11053K	PARTICIPANT	\N	PRESENT	0
686772	686700	19531S	PARTICIPANT	\N	PRESENT	0
686773	686700	19760E	PARTICIPANT	\N	PRESENT	0
686774	686700	19701S	PARTICIPANT	\N	PRESENT	0
686775	686428	19741B	PARTICIPANT	\N	PRESENT	0
686776	686428	20116W	PARTICIPANT	\N	PRESENT	0
686777	686428	08010L	PARTICIPANT	\N	PRESENT	0
686778	686700	19691J	PARTICIPANT	\N	PRESENT	0
686883	686756	14033T	PARTICIPANT	\N	PRESENT	0
686884	686756	19782L	PARTICIPANT	\N	EXCUSE	0
686885	686756	14329V	PARTICIPANT	\N	EXCUSE	0
686886	686364	20074E	PARTICIPANT	\N	PRESENT	0
686887	686364	14001X	PARTICIPANT	\N	PRESENT	0
686888	686364	04047H	PRESIDENT	0	PRESENT	0
686889	686364	19954N	PARTICIPANT	\N	PRESENT	0
701842	701641	14107H	PARTICIPANT	\N	PRESENT	0
701843	701641	08073C	PARTICIPANT	\N	PRESENT	0
701844	701641	11101A	PARTICIPANT	\N	PRESENT	0
701845	701641	11040E	PARTICIPANT	\N	PRESENT	0
701846	701641	10006L	PARTICIPANT	\N	PRESENT	0
701847	701641	14219Q	PARTICIPANT	\N	PRESENT	0
701863	701641	19503N	PARTICIPANT	\N	PRESENT	0
701849	701641	19621T	PARTICIPANT	\N	PRESENT	0
701850	701641	18193Q	PARTICIPANT	\N	PRESENT	0
701851	701641	11054L	PARTICIPANT	\N	PRESENT	0
701852	701641	12028B	PARTICIPANT	\N	PRESENT	0
701854	701641	14071N	PARTICIPANT	\N	PRESENT	0
701855	701641	19593H	PARTICIPANT	\N	PRESENT	0
701856	701641	20068G	PARTICIPANT	\N	PRESENT	0
701857	701641	19553Y	PARTICIPANT	\N	PRESENT	0
701858	701641	20098N	PARTICIPANT	\N	PRESENT	0
701859	701641	19515S	PARTICIPANT	\N	PRESENT	0
701860	701641	14031R	PARTICIPANT	\N	PRESENT	0
701861	701641	20248J	PARTICIPANT	\N	PRESENT	0
701862	701641	19711U	PARTICIPANT	\N	PRESENT	0
701864	701641	19599P	PARTICIPANT	\N	PRESENT	0
701866	701641	14147R	PARTICIPANT	\N	PRESENT	0
701870	701641	19527W	PARTICIPANT	\N	PRESENT	0
701871	701641	19758L	PARTICIPANT	\N	PRESENT	0
701872	701641	11072N	PARTICIPANT	\N	PRESENT	0
701873	701641	14237S	PARTICIPANT	\N	PRESENT	0
702090	699814	14083S	PARTICIPANT	\N	PRESENT	0
702091	701643	12041X	PARTICIPANT	\N	PRESENT	0
702184	701992	19503N	PARTICIPANT	\N	PRESENT	0
702093	701643	19760E	PARTICIPANT	\N	PRESENT	0
701878	701642	12041X	PARTICIPANT	\N	PRESENT	0
701879	701534	19703U	PARTICIPANT	\N	PRESENT	0
701880	701534	11067R	PARTICIPANT	\N	PRESENT	0
701881	701534	04092N	PARTICIPANT	\N	PRESENT	0
701882	701534	19798U	PARTICIPANT	\N	PRESENT	0
701883	701534	19679N	PARTICIPANT	\N	PRESENT	0
701884	701534	20040T	PARTICIPANT	\N	PRESENT	0
701885	701534	19367Y	PARTICIPANT	\N	PRESENT	0
701886	701534	14213J	PARTICIPANT	\N	PRESENT	0
701887	701534	17965H	PARTICIPANT	\N	PRESENT	0
701888	701534	14071N	PRESIDENT	0	PRESENT	0
701889	701534	14223L	PARTICIPANT	\N	PRESENT	0
701890	701534	18193Q	PARTICIPANT	\N	PRESENT	0
701891	701534	19295A	PARTICIPANT	\N	EXCUSE	0
702094	701643	11031D	PARTICIPANT	\N	PRESENT	0
702095	701643	20266L	PARTICIPANT	\N	PRESENT	0
702178	701643	19723Y	PARTICIPANT	\N	PRESENT	0
702097	701643	20066E	PARTICIPANT	\N	PRESENT	0
702176	701643	14221J	PARTICIPANT	\N	PRESENT	0
702175	701643	95063L	PARTICIPANT	\N	PRESENT	0
702100	701643	19683J	PARTICIPANT	\N	PRESENT	0
702177	700090	20084G	PARTICIPANT	\N	PRESENT	0
702102	701643	18193Q	PARTICIPANT	\N	PRESENT	0
702103	701643	20040T	PARTICIPANT	\N	PRESENT	0
702104	701643	19745F	PARTICIPANT	\N	PRESENT	0
702105	701643	08028W	PARTICIPANT	\N	PRESENT	0
702106	701643	18083K	PARTICIPANT	\N	PRESENT	0
702107	701643	20074E	PARTICIPANT	\N	PRESENT	0
702108	701643	20076G	PARTICIPANT	\N	PRESENT	0
702179	701643	11067R	PARTICIPANT	\N	PRESENT	0
702110	701643	20026V	PARTICIPANT	\N	PRESENT	0
702111	701643	14223L	PARTICIPANT	\N	PRESENT	0
702112	701643	19713W	PARTICIPANT	\N	PRESENT	0
702113	701643	19798U	PARTICIPANT	\N	PRESENT	0
702114	701643	19703U	PARTICIPANT	\N	PRESENT	0
702190	701643	17023S	PARTICIPANT	\N	PRESENT	0
702116	701643	19367Y	PARTICIPANT	\N	PRESENT	0
702117	701643	20130U	PARTICIPANT	\N	PRESENT	0
702118	701643	14071N	PARTICIPANT	\N	PRESENT	0
702119	701643	14213J	PARTICIPANT	\N	PRESENT	0
702180	700090	14237S	PARTICIPANT	\N	EXCUSE	0
702121	701643	20062A	PARTICIPANT	\N	PRESENT	0
702122	701643	04092N	PARTICIPANT	\N	PRESENT	0
702181	700090	14207L	PARTICIPANT	\N	EXCUSE	0
702124	701643	08045X	PARTICIPANT	\N	PRESENT	0
702191	701643	14107H	PARTICIPANT	\N	PRESENT	0
702126	701643	97011G	PARTICIPANT	\N	PRESENT	0
702127	701643	20144B	PARTICIPANT	\N	PRESENT	0
702128	701643	20052X	PARTICIPANT	\N	PRESENT	0
702182	701643	14109K	PARTICIPANT	\N	PRESENT	0
702130	701643	20034V	PARTICIPANT	\N	PRESENT	0
702183	701643	14169X	PARTICIPANT	\N	PRESENT	0
702132	701643	19629C	PARTICIPANT	\N	PRESENT	0
702133	701643	20068G	PARTICIPANT	\N	PRESENT	0
702192	701643	19954N	PARTICIPANT	\N	PRESENT	0
702185	701643	19447X	PARTICIPANT	\N	PRESENT	0
702187	701643	19569H	PARTICIPANT	\N	PRESENT	0
702186	701643	14042U	PARTICIPANT	\N	PRESENT	0
702138	701643	19758L	PARTICIPANT	\N	PRESENT	0
702188	700090	14357A	PARTICIPANT	\N	PRESENT	0
702140	701643	14187A	PARTICIPANT	\N	PRESENT	0
702189	700090	11053K	PARTICIPANT	\N	PRESENT	0
702142	701643	20078J	PARTICIPANT	\N	PRESENT	0
702143	701643	19826F	PARTICIPANT	\N	PRESENT	0
702144	701643	19333N	PARTICIPANT	\N	PRESENT	0
702145	701643	14073Q	PARTICIPANT	\N	PRESENT	0
702193	701643	01025N	PARTICIPANT	\N	PRESENT	0
702147	701643	19747H	PARTICIPANT	\N	PRESENT	0
702194	701643	08061X	PARTICIPANT	\N	PRESENT	0
702149	701643	01058X	PARTICIPANT	\N	PRESENT	0
702150	701643	04057K	PARTICIPANT	\N	PRESENT	0
702195	701643	04045F	PARTICIPANT	\N	PRESENT	0
702210	701643	20980G	PARTICIPANT	\N	PRESENT	0
702153	701643	98022P	PARTICIPANT	\N	PRESENT	0
702154	701643	04043D	PARTICIPANT	\N	PRESENT	0
702155	701643	20104S	PARTICIPANT	\N	PRESENT	0
702156	701643	14033T	PARTICIPANT	\N	PRESENT	0
702196	701643	19591F	PARTICIPANT	\N	PRESENT	0
702158	701643	20124W	PARTICIPANT	\N	PRESENT	0
702159	701643	20140W	PARTICIPANT	\N	PRESENT	0
702160	701643	19581D	PARTICIPANT	\N	PRESENT	0
702161	701643	14021P	PARTICIPANT	\N	PRESENT	0
702197	701643	11045K	PARTICIPANT	\N	PRESENT	0
702198	701643	19697Q	PARTICIPANT	\N	PRESENT	0
702174	701643	20134Y	PARTICIPANT	\N	PRESENT	0
702165	701643	19691J	PARTICIPANT	\N	PRESENT	0
702166	701643	14031R	PARTICIPANT	\N	PRESENT	0
702167	701643	20042V	PARTICIPANT	\N	PRESENT	0
702168	701643	20088L	PARTICIPANT	\N	PRESENT	0
702169	701643	19782L	PARTICIPANT	\N	PRESENT	0
702170	700090	20102Q	PARTICIPANT	\N	PRESENT	0
702171	700090	20028X	PARTICIPANT	\N	PRESENT	0
702172	699814	19762G	PARTICIPANT	\N	PRESENT	0
702173	699814	20036X	PARTICIPANT	\N	PRESENT	0
702199	701643	20180F	PARTICIPANT	\N	PRESENT	0
702200	701643	19715Y	PARTICIPANT	\N	PRESENT	0
702201	701643	14030Q	PARTICIPANT	\N	PRESENT	0
702202	701643	17965H	PARTICIPANT	\N	PRESENT	0
702203	701643	14217N	PARTICIPANT	\N	PRESENT	0
702204	701643	11104D	PARTICIPANT	\N	PRESENT	0
702205	701643	19699S	PARTICIPANT	\N	PRESENT	0
702206	701643	14195A	PARTICIPANT	\N	PRESENT	0
702207	700090	20180F	PARTICIPANT	\N	PRESENT	0
702209	700090	19713W	PARTICIPANT	\N	PRESENT	0
702211	701643	20056C	PARTICIPANT	\N	PRESENT	0
702212	701643	20054A	PARTICIPANT	\N	PRESENT	0
702213	700090	19575F	PARTICIPANT	\N	PRESENT	0
702214	700090	19251M	PRESIDENT	0	PRESENT	0
702215	700090	20092G	PARTICIPANT	\N	PRESENT	0
702216	701643	19553Y	PARTICIPANT	\N	PRESENT	0
702217	701643	14215L	PARTICIPANT	\N	PRESENT	0
702218	701643	10006L	PARTICIPANT	\N	PRESENT	0
702219	701643	17589D	PARTICIPANT	\N	PRESENT	0
702220	701643	14026U	PARTICIPANT	\N	PRESENT	0
702221	701643	19866P	PARTICIPANT	\N	PRESENT	0
702226	701643	14147R	PARTICIPANT	\N	PRESENT	0
702231	701643	01024M	PARTICIPANT	\N	PRESENT	0
702232	701992	17637T	PARTICIPANT	\N	PRESENT	0
702235	701643	14191V	PARTICIPANT	\N	PRESENT	0
702237	701643	19533U	PARTICIPANT	\N	PRESENT	0
702240	701992	20044X	PARTICIPANT	\N	PRESENT	0
702243	701620	14053L	PARTICIPANT	\N	PRESENT	0
702244	701620	19649G	PARTICIPANT	\N	PRESENT	0
702245	701620	11010L	PARTICIPANT	\N	PRESENT	0
702246	701620	20074E	PARTICIPANT	\N	PRESENT	0
702247	701620	10015M	PARTICIPANT	\N	PRESENT	0
702248	701620	19581D	PARTICIPANT	\N	PRESENT	0
702249	701620	19585H	PARTICIPANT	\N	PRESENT	0
702250	701620	04047H	PRESIDENT	0	PRESENT	0
702251	701620	19673G	PARTICIPANT	\N	PRESENT	0
688572	688571	08018U	PARTICIPANT	\N	PRESENT	0
688573	688571	04043D	PARTICIPANT	\N	PRESENT	0
688574	688571	08012N	PARTICIPANT	\N	PRESENT	0
688576	688575	14033T	PARTICIPANT	\N	PRESENT	0
688577	688575	14257W	PARTICIPANT	\N	PRESENT	0
689824	688648	04045F	PARTICIPANT	\N	PRESENT	0
689825	688648	19697Q	PARTICIPANT	\N	PRESENT	0
689826	688648	19741B	PARTICIPANT	\N	PRESENT	0
689827	688648	19399H	PARTICIPANT	\N	PRESENT	0
689828	688648	19701S	PARTICIPANT	\N	PRESENT	0
689829	688648	20104S	PARTICIPANT	\N	PRESENT	0
689830	688648	20108W	PARTICIPANT	\N	PRESENT	0
689831	688648	17737W	PARTICIPANT	\N	PRESENT	0
689832	688648	19717B	PARTICIPANT	\N	PRESENT	0
689833	688648	20148F	PARTICIPANT	\N	PRESENT	0
689834	688648	20024T	PARTICIPANT	\N	PRESENT	0
689835	688648	14329V	PARTICIPANT	\N	PRESENT	0
689836	688648	14357A	PARTICIPANT	\N	PRESENT	0
689837	688648	14207L	PARTICIPANT	\N	PRESENT	0
689838	688843	95041E	PARTICIPANT	\N	PRESENT	0
689839	688843	12041X	PARTICIPANT	\N	PRESENT	0
689840	688843	19565D	PARTICIPANT	\N	PRESENT	0
689841	688843	20072C	PARTICIPANT	\N	PRESENT	0
689842	688843	01058X	PARTICIPANT	\N	PRESENT	0
689843	688843	16685X	PARTICIPANT	\N	PRESENT	0
689844	688843	04042C	PRESIDENT	0	PRESENT	0
689845	688843	11054L	PARTICIPANT	\N	PRESENT	0
689846	688843	11066Q	PARTICIPANT	\N	PRESENT	0
689847	688843	19669L	PARTICIPANT	\N	PRESENT	0
689848	688843	08056B	PARTICIPANT	\N	PRESENT	0
689849	688843	12028B	PARTICIPANT	\N	PRESENT	0
689850	688843	19709B	PARTICIPANT	\N	PRESENT	0
689851	688843	19347U	PARTICIPANT	\N	PRESENT	0
689852	688843	07033P	PARTICIPANT	\N	PRESENT	0
689853	688843	97011G	PARTICIPANT	\N	PRESENT	0
689854	688843	08061X	PARTICIPANT	\N	PRESENT	0
689855	688843	14249W	PARTICIPANT	\N	PRESENT	0
689856	688843	08047A	PARTICIPANT	\N	PRESENT	0
689857	688843	20128B	PARTICIPANT	\N	PRESENT	0
689858	688843	14097Y	PARTICIPANT	\N	PRESENT	0
689859	688843	14059S	PARTICIPANT	\N	PRESENT	0
689860	688843	04035D	PARTICIPANT	\N	PRESENT	0
689861	688843	14133K	PARTICIPANT	\N	PRESENT	0
689862	688843	01062T	PARTICIPANT	\N	PRESENT	0
689863	688843	08069G	PARTICIPANT	\N	PRESENT	0
689864	688843	20042V	PARTICIPANT	\N	PRESENT	0
689865	688843	01024M	PARTICIPANT	\N	PRESENT	0
689866	688843	14105F	PARTICIPANT	\N	PRESENT	0
689867	688843	20064C	PARTICIPANT	\N	PRESENT	0
689868	688843	11064N	PARTICIPANT	\N	PRESENT	0
689869	688843	14267Y	PARTICIPANT	\N	PRESENT	0
689870	688843	11083R	PARTICIPANT	\N	PRESENT	0
689871	688843	19583F	PARTICIPANT	\N	PRESENT	0
689872	688843	14211G	PARTICIPANT	\N	EXCUSE	0
689873	688648	19681G	PARTICIPANT	\N	PRESENT	0
689874	688648	19719D	PARTICIPANT	\N	PRESENT	0
689875	688648	20132W	PARTICIPANT	\N	PRESENT	0
689876	688648	19675J	PARTICIPANT	\N	PRESENT	0
689877	688648	19387D	PARTICIPANT	\N	PRESENT	0
689878	688648	20020P	PARTICIPANT	\N	PRESENT	0
689879	688648	11012A	PARTICIPANT	\N	PRESENT	0
689880	688648	14111D	PARTICIPANT	\N	PRESENT	0
689881	688648	14251Q	PARTICIPANT	\N	PRESENT	0
689882	688648	19581D	PARTICIPANT	\N	PRESENT	0
689883	688648	14195A	PARTICIPANT	\N	PRESENT	0
689884	688648	19563B	PARTICIPANT	\N	PRESENT	0
689885	688648	14193X	PARTICIPANT	\N	PRESENT	0
689886	688648	20050V	PARTICIPANT	\N	PRESENT	0
689887	688648	14221J	PARTICIPANT	\N	PRESENT	0
689888	688648	04057K	PARTICIPANT	\N	PRESENT	0
689889	688648	20126Y	PARTICIPANT	\N	PRESENT	0
689890	688648	08056B	PARTICIPANT	\N	PRESENT	0
689891	688648	14059S	PARTICIPANT	\N	PRESENT	0
689892	688648	19631V	PARTICIPANT	\N	PRESENT	0
689893	688648	19707Y	PARTICIPANT	\N	PRESENT	0
689894	688648	19705W	PARTICIPANT	\N	PRESENT	0
689895	688648	19768N	PARTICIPANT	\N	PRESENT	0
689896	688648	08015R	PARTICIPANT	\N	PRESENT	0
689897	688648	19729F	PARTICIPANT	\N	PRESENT	0
689898	688648	20124W	PARTICIPANT	\N	PRESENT	0
689899	688648	20094J	PARTICIPANT	\N	PRESENT	0
689900	688648	19657G	PARTICIPANT	\N	PRESENT	0
689901	688648	20080C	PARTICIPANT	\N	PRESENT	0
689902	688648	20114U	PARTICIPANT	\N	PRESENT	0
689903	688648	12028B	PARTICIPANT	\N	PRESENT	0
689904	688648	19295A	PARTICIPANT	\N	PRESENT	0
689905	688648	14133K	PARTICIPANT	\N	PRESENT	0
689906	688648	20070A	PARTICIPANT	\N	PRESENT	0
689907	688648	20264J	PARTICIPANT	\N	PRESENT	0
689908	688648	19251M	PARTICIPANT	\N	PRESENT	0
689909	688648	19709B	PARTICIPANT	\N	PRESENT	0
689910	688648	14151M	PARTICIPANT	\N	PRESENT	0
689911	688648	08018U	PARTICIPANT	\N	PRESENT	0
689912	688648	20044X	PARTICIPANT	\N	PRESENT	0
689913	688648	20058E	PARTICIPANT	\N	PRESENT	0
689914	688648	19725B	PARTICIPANT	\N	PRESENT	0
689915	688648	19820Y	PARTICIPANT	\N	PRESENT	0
689916	688648	19333N	PARTICIPANT	\N	PRESENT	0
689917	688648	19715Y	PARTICIPANT	\N	PRESENT	0
689918	688648	14121F	PARTICIPANT	\N	PRESENT	0
689919	688648	19531S	PARTICIPANT	\N	PRESENT	0
689920	688648	14021P	PARTICIPANT	\N	PRESENT	0
689921	688648	14097Y	PARTICIPANT	\N	PRESENT	0
689922	688648	20096L	PARTICIPANT	\N	PRESENT	0
689923	688648	08012N	PARTICIPANT	\N	PRESENT	0
689924	688648	18193Q	PARTICIPANT	\N	PRESENT	0
689925	688648	20018V	PARTICIPANT	\N	PRESENT	0
689926	688648	14257W	PARTICIPANT	\N	PRESENT	0
689927	688648	14225N	PARTICIPANT	\N	PRESENT	0
689928	688648	19503N	PARTICIPANT	\N	PRESENT	0
689929	688648	04035D	PARTICIPANT	\N	PRESENT	0
689930	688648	17965H	PARTICIPANT	\N	PRESENT	0
689931	688648	20082E	PARTICIPANT	\N	PRESENT	0
689932	688648	01028R	PARTICIPANT	\N	PRESENT	0
689933	688648	19669L	PARTICIPANT	\N	PRESENT	0
689934	688648	20030R	PARTICIPANT	\N	PRESENT	0
689935	688648	19527W	PARTICIPANT	\N	PRESENT	0
689936	688648	19413M	PARTICIPANT	\N	PRESENT	0
689937	688648	11072N	PARTICIPANT	\N	PRESENT	0
689938	688648	14189C	PARTICIPANT	\N	PRESENT	0
689939	688648	19543W	PARTICIPANT	\N	PRESENT	0
689940	688648	14030Q	PARTICIPANT	\N	PRESENT	0
689941	688648	20042V	PARTICIPANT	\N	PRESENT	0
689942	688648	14089Y	PARTICIPANT	\N	PRESENT	0
689943	688648	14083S	PARTICIPANT	\N	PRESENT	0
689944	688648	11053K	PARTICIPANT	\N	PRESENT	0
689945	688648	11070L	PARTICIPANT	\N	PRESENT	0
689946	688648	17229F	PARTICIPANT	\N	PRESENT	0
689947	688648	01024M	PARTICIPANT	\N	PRESENT	0
689948	688648	19577H	PARTICIPANT	\N	PRESENT	0
689949	688648	20248J	PARTICIPANT	\N	PRESENT	0
689950	688648	01025N	PARTICIPANT	\N	PRESENT	0
689951	688648	14231L	PARTICIPANT	\N	PRESENT	0
689952	688648	19691J	PARTICIPANT	\N	PRESENT	0
689953	688648	20286Q	PARTICIPANT	\N	PRESENT	0
689954	688648	14179A	PARTICIPANT	\N	PRESENT	0
689955	688648	19569H	PARTICIPANT	\N	PRESENT	0
689956	688648	19685L	PARTICIPANT	\N	PRESENT	0
689957	688648	20048C	PARTICIPANT	\N	PRESENT	0
689958	688648	20066E	PARTICIPANT	\N	PRESENT	0
689959	688648	14073Q	PARTICIPANT	\N	PRESENT	0
689960	688648	19735D	PARTICIPANT	\N	PRESENT	0
689961	688648	19611R	PARTICIPANT	\N	PRESENT	0
689962	688648	19699S	PARTICIPANT	\N	PRESENT	0
689963	688648	01043Q	PARTICIPANT	\N	PRESENT	0
689964	688648	20052X	PARTICIPANT	\N	PRESENT	0
689965	688648	16685X	PARTICIPANT	\N	PRESENT	0
689966	688648	14205J	PARTICIPANT	\N	PRESENT	0
689967	688648	14219Q	PARTICIPANT	\N	PRESENT	0
689968	688648	19441R	PARTICIPANT	\N	PRESENT	0
689969	688648	08009T	PARTICIPANT	\N	PRESENT	0
689970	688648	19335Q	PARTICIPANT	\N	PRESENT	0
689971	688648	19369B	PARTICIPANT	\N	PRESENT	0
689972	688648	19739H	PARTICIPANT	\N	PRESENT	0
689973	688648	20298U	PARTICIPANT	\N	PRESENT	0
689974	688648	19713W	PARTICIPANT	\N	PRESENT	0
689975	688648	01034P	PARTICIPANT	\N	PRESENT	0
689976	688648	19479G	PARTICIPANT	\N	PRESENT	0
689977	688648	14055N	PARTICIPANT	\N	PRESENT	0
689978	688648	11056N	PARTICIPANT	\N	PRESENT	0
689980	688648	19489J	PARTICIPANT	\N	PRESENT	0
696811	695155	20054A	PARTICIPANT	\N	PRESENT	0
696812	695155	19329S	PARTICIPANT	\N	PRESENT	0
696813	695155	20106U	PARTICIPANT	\N	PRESENT	0
696814	695155	19591F	PARTICIPANT	\N	PRESENT	0
696815	695155	14037X	PARTICIPANT	\N	PRESENT	0
696816	695155	19697Q	PARTICIPANT	\N	PRESENT	0
696817	695155	08015R	PARTICIPANT	\N	PRESENT	0
696818	695155	19657G	PARTICIPANT	\N	PRESENT	0
696819	695155	08061X	PARTICIPANT	\N	PRESENT	0
696820	695155	01028R	PARTICIPANT	\N	PRESENT	0
696821	695155	19741B	PARTICIPANT	\N	PRESENT	0
696822	695155	19399H	PARTICIPANT	\N	PRESENT	0
696823	695155	11045K	PARTICIPANT	\N	PRESENT	0
696824	695155	19599P	PARTICIPANT	\N	PRESENT	0
696825	695155	04059M	PARTICIPANT	\N	PRESENT	0
696826	695155	17779H	PARTICIPANT	\N	PRESENT	0
696827	695155	14257W	PARTICIPANT	\N	PRESENT	0
696829	695155	20024T	PARTICIPANT	\N	PRESENT	0
696830	695155	14213J	PARTICIPANT	\N	PRESENT	0
696831	695155	11027H	PARTICIPANT	\N	PRESENT	0
696832	695155	14147R	PARTICIPANT	\N	PRESENT	0
696833	695155	12028B	PARTICIPANT	\N	PRESENT	0
696834	695155	14151M	PARTICIPANT	\N	PRESENT	0
696835	695155	20172F	PARTICIPANT	\N	PRESENT	0
696836	695155	19489J	PARTICIPANT	\N	PRESENT	0
696837	695155	20138D	PARTICIPANT	\N	PRESENT	0
696838	695155	14001X	PARTICIPANT	\N	PRESENT	0
696839	695155	20140W	PARTICIPANT	\N	PRESENT	0
696840	695155	19647E	PARTICIPANT	\N	PRESENT	0
696841	695155	11115U	PARTICIPANT	\N	PRESENT	0
696842	695155	14021P	PARTICIPANT	\N	PRESENT	0
696843	695155	01062T	PARTICIPANT	\N	PRESENT	0
696844	695155	08060W	PARTICIPANT	\N	PRESENT	0
696845	695155	19549D	PARTICIPANT	\N	PRESENT	0
696846	695155	19669L	PARTICIPANT	\N	PRESENT	0
696847	695155	14097Y	PARTICIPANT	\N	PRESENT	0
696848	695155	05012A	PARTICIPANT	\N	PRESENT	0
696849	695155	11067R	PARTICIPANT	\N	PRESENT	0
696850	695155	20022R	PARTICIPANT	\N	PRESENT	0
696851	695155	20114U	PARTICIPANT	\N	PRESENT	0
696852	695155	20028X	PARTICIPANT	\N	PRESENT	0
696853	695155	11104D	PARTICIPANT	\N	PRESENT	0
696854	695155	19515S	PARTICIPANT	\N	PRESENT	0
696855	695155	14109K	PARTICIPANT	\N	PRESENT	0
696856	695155	19531S	PARTICIPANT	\N	PRESENT	0
696857	695155	14121F	PARTICIPANT	\N	PRESENT	0
696858	695155	19413M	PARTICIPANT	\N	PRESENT	0
696859	695155	11041F	PARTICIPANT	\N	PRESENT	0
696860	695155	19527W	PARTICIPANT	\N	PRESENT	0
696861	695155	19725B	PARTICIPANT	\N	PRESENT	0
696862	695155	18193Q	PARTICIPANT	\N	PRESENT	0
696863	695155	20060X	PARTICIPANT	\N	PRESENT	0
696864	695155	20018V	PARTICIPANT	\N	PRESENT	0
696865	695155	11110B	PARTICIPANT	\N	PRESENT	0
696866	695155	20264J	PARTICIPANT	\N	PRESENT	0
696867	695155	19551W	PARTICIPANT	\N	PRESENT	0
696868	695155	19251M	PARTICIPANT	\N	PRESENT	0
696869	695155	11026G	PARTICIPANT	\N	PRESENT	0
696870	695155	20064C	PARTICIPANT	\N	PRESENT	0
696871	695155	17965H	PARTICIPANT	\N	PRESENT	0
696872	695155	20030R	PARTICIPANT	\N	PRESENT	0
696873	695155	99004R	PARTICIPANT	\N	PRESENT	0
696874	695155	20088L	PARTICIPANT	\N	PRESENT	0
696875	695155	19553Y	PARTICIPANT	\N	PRESENT	0
696876	695155	19629C	PARTICIPANT	\N	PRESENT	0
696877	695155	19719D	PARTICIPANT	\N	PRESENT	0
696878	695155	11012A	PARTICIPANT	\N	PRESENT	0
696879	695155	19545Y	PARTICIPANT	\N	PRESENT	0
696880	695155	11064N	PARTICIPANT	\N	PRESENT	0
696881	695155	14251Q	PARTICIPANT	\N	PRESENT	0
696882	695155	14111D	PARTICIPANT	\N	PRESENT	0
696883	695155	14221J	PARTICIPANT	\N	PRESENT	0
696884	695155	04057K	PARTICIPANT	\N	PRESENT	0
696885	695155	20050V	PARTICIPANT	\N	PRESENT	0
696886	695155	20122U	PARTICIPANT	\N	PRESENT	0
696887	695155	19585H	PARTICIPANT	\N	PRESENT	0
696888	695155	20128B	PARTICIPANT	\N	PRESENT	0
696889	695155	11080N	PARTICIPANT	\N	PRESENT	0
696890	695155	20146D	PARTICIPANT	\N	PRESENT	0
696891	695155	19349W	PARTICIPANT	\N	PRESENT	0
696892	695155	95063L	PARTICIPANT	\N	PRESENT	0
696893	695155	04045F	PARTICIPANT	\N	PRESENT	0
696894	695155	11033F	PARTICIPANT	\N	PRESENT	0
696895	695155	19758L	PARTICIPANT	\N	PRESENT	0
696896	695155	20102Q	PARTICIPANT	\N	PRESENT	0
696897	695155	11077T	PARTICIPANT	\N	PRESENT	0
696898	695155	04085P	PARTICIPANT	\N	PRESENT	0
696899	695155	11040E	PARTICIPANT	\N	PRESENT	0
696900	695155	11031D	PARTICIPANT	\N	PRESENT	0
696901	695155	14189C	PARTICIPANT	\N	PRESENT	0
696902	695155	20042V	PARTICIPANT	\N	PRESENT	0
696903	695155	14089Y	PARTICIPANT	\N	PRESENT	0
696904	695155	11053K	PARTICIPANT	\N	PRESENT	0
696905	695155	14255U	PARTICIPANT	\N	PRESENT	0
696906	695155	14083S	PARTICIPANT	\N	PRESENT	0
696907	695155	19721W	PARTICIPANT	\N	PRESENT	0
696908	695155	14267Y	PARTICIPANT	\N	PRESENT	0
696909	695155	01024M	PARTICIPANT	\N	PRESENT	0
696910	695155	19577H	PARTICIPANT	\N	PRESENT	0
696911	695155	14042U	PARTICIPANT	\N	PRESENT	0
696912	695155	20040T	PARTICIPANT	\N	PRESENT	0
696913	695155	20248J	PARTICIPANT	\N	PRESENT	0
696914	695155	01025N	PARTICIPANT	\N	PRESENT	0
696915	695155	14231L	PARTICIPANT	\N	PRESENT	0
696916	695155	07004J	PARTICIPANT	\N	PRESENT	0
696917	695155	19691J	PARTICIPANT	\N	PRESENT	0
696918	695155	20286Q	PARTICIPANT	\N	PRESENT	0
696919	695155	14179A	PARTICIPANT	\N	PRESENT	0
696920	695155	20048C	PARTICIPANT	\N	PRESENT	0
696921	695155	19319Q	PARTICIPANT	\N	PRESENT	0
696922	695155	20066E	PARTICIPANT	\N	PRESENT	0
696923	695155	19699S	PARTICIPANT	\N	PRESENT	0
696924	695155	01043Q	PARTICIPANT	\N	PRESENT	0
696925	695155	16685X	PARTICIPANT	\N	PRESENT	0
696926	695155	14205J	PARTICIPANT	\N	PRESENT	0
696927	695155	14219Q	PARTICIPANT	\N	PRESENT	0
696928	695155	11085T	PARTICIPANT	\N	PRESENT	0
696929	695155	19826F	PARTICIPANT	\N	PRESENT	0
696930	695155	08009T	PARTICIPANT	\N	PRESENT	0
696931	695155	19335Q	PARTICIPANT	\N	PRESENT	0
696932	695155	19369B	PARTICIPANT	\N	PRESENT	0
696933	695155	19745F	PARTICIPANT	\N	PRESENT	0
696934	695155	19739H	PARTICIPANT	\N	PRESENT	0
696935	695155	19713W	PARTICIPANT	\N	PRESENT	0
696936	695155	01034P	PARTICIPANT	\N	PRESENT	0
696937	695155	19749K	PARTICIPANT	\N	PRESENT	0
696938	695155	19735D	PARTICIPANT	\N	PRESENT	0
696939	695155	20266L	PARTICIPANT	\N	PRESENT	0
696940	695155	08045X	PARTICIPANT	\N	PRESENT	0
697225	695156	99004R	PARTICIPANT	\N	PRESENT	0
697226	695156	20076G	PARTICIPANT	\N	PRESENT	0
697227	695156	20114U	PARTICIPANT	\N	PRESENT	0
697228	695156	19758L	PARTICIPANT	\N	PRESENT	0
697229	695156	20080C	PARTICIPANT	\N	PRESENT	0
697230	695156	20092G	PARTICIPANT	\N	PRESENT	0
697231	695156	20266L	PARTICIPANT	\N	PRESENT	0
697232	695156	20142Y	PARTICIPANT	\N	PRESENT	0
697233	695156	20914V	PARTICIPANT	\N	PRESENT	0
697234	695156	08073C	PARTICIPANT	\N	PRESENT	0
697235	695156	20086J	PARTICIPANT	\N	PRESENT	0
697236	695156	11077T	PARTICIPANT	\N	PRESENT	0
697237	695156	11090Q	PARTICIPANT	\N	PRESENT	0
697238	695156	20102Q	PARTICIPANT	\N	PRESENT	0
697239	695156	12041X	PARTICIPANT	\N	PRESENT	0
697240	695156	20038A	PARTICIPANT	\N	PRESENT	0
697241	695156	19673G	PARTICIPANT	\N	PRESENT	0
697242	695156	14173T	PARTICIPANT	\N	PRESENT	0
697243	695156	14033T	PARTICIPANT	\N	PRESENT	0
697244	695156	20034V	PARTICIPANT	\N	PRESENT	0
697245	695156	20056C	PARTICIPANT	\N	PRESENT	0
697246	695156	19705W	PARTICIPANT	\N	PRESENT	0
697247	695156	19707Y	PARTICIPANT	\N	PRESENT	0
697248	695156	08047A	PARTICIPANT	\N	PRESENT	0
697249	695156	20098N	PARTICIPANT	\N	PRESENT	0
697250	695156	08010L	PARTICIPANT	\N	PRESENT	0
697251	695156	07029T	PARTICIPANT	\N	PRESENT	0
697252	695156	14038Y	PARTICIPANT	\N	PRESENT	0
697253	695156	19467C	PARTICIPANT	\N	PRESENT	0
697254	695156	20104S	PARTICIPANT	\N	PRESENT	0
697255	695156	14031R	PARTICIPANT	\N	PRESENT	0
697256	695156	11010L	PARTICIPANT	\N	PRESENT	0
684892	683276	11056N	PARTICIPANT	\N	PRESENT	0
684893	683276	20024T	PARTICIPANT	\N	PRESENT	0
684894	683276	19703U	PARTICIPANT	\N	PRESENT	0
684928	683227	14026U	PARTICIPANT	\N	PRESENT	0
684957	683227	19333N	PARTICIPANT	\N	PRESENT	0
684930	683227	08011M	PARTICIPANT	\N	PRESENT	0
684931	683227	14331P	PARTICIPANT	\N	PRESENT	0
684932	683227	19553Y	PARTICIPANT	\N	PRESENT	0
684933	683227	14133K	PARTICIPANT	\N	PRESENT	0
684934	683227	14221J	PARTICIPANT	\N	PRESENT	0
684935	683227	20100N	PARTICIPANT	\N	PRESENT	0
684936	683227	11083R	PARTICIPANT	\N	PRESENT	0
684937	683227	14001X	PARTICIPANT	\N	PRESENT	0
684938	683227	12041X	PARTICIPANT	\N	PRESENT	0
684939	683227	14073Q	PARTICIPANT	\N	PRESENT	0
684940	683227	14237S	PARTICIPANT	\N	PRESENT	0
684941	683227	14097Y	PARTICIPANT	\N	PRESENT	0
684942	683227	14189C	PARTICIPANT	\N	PRESENT	0
684943	683227	10015M	PARTICIPANT	\N	PRESENT	0
684944	683227	20104S	PARTICIPANT	\N	PRESENT	0
684955	683227	19725B	PARTICIPANT	\N	PRESENT	0
684956	683227	17965H	PARTICIPANT	\N	PRESENT	0
684958	683227	18193Q	PARTICIPANT	\N	PRESENT	0
684959	683227	08061X	PARTICIPANT	\N	PRESENT	0
684960	683227	20116W	PARTICIPANT	\N	PRESENT	0
684961	683227	19549D	PARTICIPANT	\N	PRESENT	0
684966	683227	19593H	PARTICIPANT	\N	PRESENT	0
684963	683227	19387D	PARTICIPANT	\N	PRESENT	0
684964	683227	18083K	PARTICIPANT	\N	PRESENT	0
684965	683227	20076G	PARTICIPANT	\N	PRESENT	0
684967	683227	14021P	PARTICIPANT	\N	PRESENT	0
684968	683227	20172F	PARTICIPANT	\N	PRESENT	0
684969	683227	11026G	PARTICIPANT	\N	PRESENT	0
684970	683227	20048C	PARTICIPANT	\N	PRESENT	0
684971	683227	14033T	PARTICIPANT	\N	PRESENT	0
684972	683227	14089Y	PARTICIPANT	\N	PRESENT	0
684973	683227	19415P	PARTICIPANT	\N	PRESENT	0
684974	683227	19479G	PARTICIPANT	\N	PRESENT	0
684975	683227	11097X	PARTICIPANT	\N	PRESENT	0
684976	683227	20086J	PARTICIPANT	\N	PRESENT	0
684977	683227	14069U	PARTICIPANT	\N	PRESENT	0
684978	683227	20032T	PARTICIPANT	\N	PRESENT	0
684890	683276	14147R	PARTICIPANT	\N	PRESENT	0
684891	683276	19741B	PARTICIPANT	\N	PRESENT	0
684983	683227	20094J	PARTICIPANT	\N	PRESENT	0
684980	683227	19503N	PARTICIPANT	\N	PRESENT	0
684981	683227	07029T	PARTICIPANT	\N	PRESENT	0
684982	683227	20252E	PARTICIPANT	\N	PRESENT	0
686893	686756	19768N	PARTICIPANT	\N	PRESENT	0
686894	686756	19467C	PARTICIPANT	\N	PRESENT	0
686895	686756	20034V	PARTICIPANT	\N	PRESENT	0
686896	686756	14357A	PARTICIPANT	\N	PRESENT	0
686897	686756	08015R	PARTICIPANT	\N	PRESENT	0
686898	686756	19441R	PARTICIPANT	\N	PRESENT	0
686899	686756	11090Q	PRESIDENT	0	PRESENT	0
686900	686756	04045F	PARTICIPANT	\N	PRESENT	0
686901	686756	19507S	PARTICIPANT	\N	PRESENT	0
686902	686756	20054A	PARTICIPANT	\N	PRESENT	0
686903	686756	14037X	PARTICIPANT	\N	PRESENT	0
686904	686756	14205J	PARTICIPANT	\N	PRESENT	0
686905	686756	19575F	PARTICIPANT	\N	PRESENT	0
686906	686756	20298U	PARTICIPANT	\N	PRESENT	0
686907	686701	20090E	PARTICIPANT	\N	PRESENT	0
686908	686701	14026U	PARTICIPANT	\N	PRESENT	0
686890	686364	20108W	PARTICIPANT	\N	PRESENT	0
686891	686364	05008E	PARTICIPANT	\N	PRESENT	0
686892	686364	11072N	PARTICIPANT	\N	PRESENT	0
686909	686701	19507S	PARTICIPANT	\N	PRESENT	0
686910	686701	14237S	PARTICIPANT	\N	PRESENT	0
686911	686701	08009T	PARTICIPANT	\N	PRESENT	0
686912	686701	14001X	PARTICIPANT	\N	PRESENT	0
686913	686701	19760E	PARTICIPANT	\N	PRESENT	0
686914	686701	01034P	PARTICIPANT	\N	PRESENT	0
686915	686701	19717B	PARTICIPANT	\N	PRESENT	0
686916	686701	20032T	PARTICIPANT	\N	PRESENT	0
686917	686701	04057K	PARTICIPANT	\N	PRESENT	0
686918	686701	20100N	PARTICIPANT	\N	PRESENT	0
686919	686701	19637C	PARTICIPANT	\N	PRESENT	0
686920	686701	11067R	PARTICIPANT	\N	PRESENT	0
686921	686701	14083S	PARTICIPANT	\N	PRESENT	0
686922	686701	19503N	PARTICIPANT	\N	PRESENT	0
686923	686701	04045F	PARTICIPANT	\N	PRESENT	0
686924	686701	14331P	PARTICIPANT	\N	PRESENT	0
686925	686701	20102Q	PARTICIPANT	\N	PRESENT	0
686926	686701	14259Y	PARTICIPANT	\N	PRESENT	0
686927	686701	11031D	PARTICIPANT	\N	PRESENT	0
686928	686701	19703U	PARTICIPANT	\N	PRESENT	0
686929	686701	14257W	PARTICIPANT	\N	PRESENT	0
686930	686701	20028X	PARTICIPANT	\N	PRESENT	0
686931	686701	14071N	PARTICIPANT	\N	PRESENT	0
686932	686701	19657G	PARTICIPANT	\N	PRESENT	0
686933	686701	14221J	PARTICIPANT	\N	PRESENT	0
686934	686701	14223L	PARTICIPANT	\N	PRESENT	0
686935	686701	04047H	PARTICIPANT	\N	PRESENT	0
686936	686701	14213J	PARTICIPANT	\N	PRESENT	0
686937	686701	19575F	PARTICIPANT	\N	PRESENT	0
686938	686701	19683J	PARTICIPANT	\N	PRESENT	0
686939	686701	20152B	PARTICIPANT	\N	PRESENT	0
686940	686701	19679N	PARTICIPANT	\N	PRESENT	0
686941	686701	11040E	PARTICIPANT	\N	PRESENT	0
686942	686701	14179A	PARTICIPANT	\N	PRESENT	0
686943	686701	14357A	PARTICIPANT	\N	PRESENT	0
686944	686701	20054A	PARTICIPANT	\N	PRESENT	0
686945	686701	20088L	PARTICIPANT	\N	PRESENT	0
686946	686701	14219Q	PARTICIPANT	\N	PRESENT	0
686947	686701	14207L	PARTICIPANT	\N	PRESENT	0
686948	686701	18193Q	PARTICIPANT	\N	PRESENT	0
686949	686701	19349W	PARTICIPANT	\N	PRESENT	0
686950	686701	14037X	PARTICIPANT	\N	PRESENT	0
686951	686701	19671E	PARTICIPANT	\N	PRESENT	0
686952	686701	20024T	PARTICIPANT	\N	PRESENT	0
686953	686701	19798U	PARTICIPANT	\N	PRESENT	0
686954	686701	19515S	PARTICIPANT	\N	PRESENT	0
686955	686701	14030Q	PARTICIPANT	\N	PRESENT	0
686959	686701	19367Y	PARTICIPANT	\N	PRESENT	0
686960	686701	20128B	PARTICIPANT	\N	PRESENT	0
686961	686701	14105F	PARTICIPANT	\N	PRESENT	0
686962	686701	19745F	PARTICIPANT	\N	PRESENT	0
686963	686701	11097X	PARTICIPANT	\N	PRESENT	0
686964	686701	20056C	PARTICIPANT	\N	PRESENT	0
686965	686701	19531S	PARTICIPANT	\N	PRESENT	0
686966	686701	19441R	PARTICIPANT	\N	PRESENT	0
686967	686701	20026V	PARTICIPANT	\N	PRESENT	0
686968	686701	11053K	PARTICIPANT	\N	PRESENT	0
686969	686701	14133K	PARTICIPANT	\N	PRESENT	0
686970	686701	19599P	PARTICIPANT	\N	PRESENT	0
686971	686701	20140W	PARTICIPANT	\N	PRESENT	0
686972	686701	19525U	PARTICIPANT	\N	PRESENT	0
686973	686701	19691J	PARTICIPANT	\N	PRESENT	0
686974	686701	20040T	PARTICIPANT	\N	PRESENT	0
686975	686701	11056N	PARTICIPANT	\N	PRESENT	0
686976	686701	08010L	PARTICIPANT	\N	PRESENT	0
686977	686701	08028W	PARTICIPANT	\N	PRESENT	0
686978	686701	04085P	PARTICIPANT	\N	PRESENT	0
686979	686701	14033T	PARTICIPANT	\N	PRESENT	0
686980	686701	20252E	PARTICIPANT	\N	PRESENT	0
686981	686701	08034U	PARTICIPANT	\N	PRESENT	0
686982	686701	20092G	PARTICIPANT	\N	PRESENT	0
686983	686701	19479G	PARTICIPANT	\N	PRESENT	0
686984	686701	20116W	PARTICIPANT	\N	PRESENT	0
686985	686701	19413M	PARTICIPANT	\N	PRESENT	0
686986	686701	01058X	PARTICIPANT	\N	PRESENT	0
686987	686701	19387D	PARTICIPANT	\N	PRESENT	0
686988	686701	19467C	PARTICIPANT	\N	PRESENT	0
686989	686701	19581D	PARTICIPANT	\N	PRESENT	0
686990	686701	19723Y	PARTICIPANT	\N	PRESENT	0
686991	686701	97011G	PARTICIPANT	\N	PRESENT	0
686992	686701	19820Y	PARTICIPANT	\N	PRESENT	0
686993	686701	14217N	PARTICIPANT	\N	PRESENT	0
686994	686701	14069U	PARTICIPANT	\N	PRESENT	0
686995	686701	20044X	PARTICIPANT	\N	PRESENT	0
686996	686701	20068G	PARTICIPANT	\N	PRESENT	0
686997	686701	20084G	PARTICIPANT	\N	PRESENT	0
686998	686701	08060W	PARTICIPANT	\N	PRESENT	0
686999	686701	19549D	PARTICIPANT	\N	PRESENT	0
687000	686701	19251M	PARTICIPANT	\N	PRESENT	0
687001	686701	20062A	PARTICIPANT	\N	PRESENT	0
687002	686701	20020P	PARTICIPANT	\N	PRESENT	0
687003	686701	20098N	PARTICIPANT	\N	PRESENT	0
687004	686701	19383Y	PARTICIPANT	\N	PRESENT	0
687005	686701	98022P	PARTICIPANT	\N	PRESENT	0
700271	700270	07033P	PARTICIPANT	\N	PRESENT	0
700445	699099	14038Y	PARTICIPANT	\N	PRESENT	0
700465	700464	20112S	PARTICIPANT	\N	PRESENT	0
700466	700464	19643A	PARTICIPANT	\N	PRESENT	0
700467	700464	19735D	PARTICIPANT	\N	PRESENT	0
700468	700464	20142Y	PARTICIPANT	\N	PRESENT	0
700469	700464	19693L	PARTICIPANT	\N	PRESENT	0
702252	701620	05008E	PARTICIPANT	\N	PRESENT	0
702253	701620	19954N	PARTICIPANT	\N	PRESENT	0
702254	701620	95063L	PARTICIPANT	\N	PRESENT	0
702255	701620	19629C	PARTICIPANT	\N	PRESENT	0
702256	701620	14107H	PARTICIPANT	\N	PRESENT	0
702257	701620	14151M	PARTICIPANT	\N	PRESENT	0
702258	701620	14215L	PARTICIPANT	\N	PRESENT	0
702259	701620	20022R	PARTICIPANT	\N	PRESENT	0
702260	701620	11072N	PARTICIPANT	\N	PRESENT	0
702265	701620	19725B	PARTICIPANT	\N	PRESENT	0
702266	701620	14021P	PARTICIPANT	\N	PRESENT	0
702267	701620	14147R	PARTICIPANT	\N	PRESENT	0
702268	701620	04008A	PARTICIPANT	\N	PRESENT	0
702269	701620	14001X	PARTICIPANT	\N	PRESENT	0
702270	701620	20110Q	PARTICIPANT	\N	PRESENT	0
702271	701643	11012A	PARTICIPANT	\N	PRESENT	0
702272	701643	14211G	PARTICIPANT	\N	PRESENT	0
702273	701643	19575F	PARTICIPANT	\N	PRESENT	0
702274	700090	17229F	PARTICIPANT	\N	PRESENT	0
702275	701643	14111D	PARTICIPANT	\N	PRESENT	0
702276	701643	19762G	PARTICIPANT	\N	PRESENT	0
702277	701643	19507S	PARTICIPANT	\N	PRESENT	0
702278	701643	19441R	PARTICIPANT	\N	PRESENT	0
702281	701643	20036X	PARTICIPANT	\N	PRESENT	0
702282	701643	20028X	PARTICIPANT	\N	PRESENT	0
702283	701643	14189C	PARTICIPANT	\N	PRESENT	0
702284	701643	07029T	PARTICIPANT	\N	PRESENT	0
702285	701643	19467C	PARTICIPANT	\N	PRESENT	0
702286	701643	14059S	PARTICIPANT	\N	PRESENT	0
702287	701620	20114U	PARTICIPANT	\N	PRESENT	0
702288	701643	19675J	PARTICIPANT	\N	PRESENT	0
702289	701643	19565D	PARTICIPANT	\N	PRESENT	0
702290	701643	11043H	PARTICIPANT	\N	PRESENT	0
702291	701643	14037X	PARTICIPANT	\N	PRESENT	0
702292	701643	19621T	PARTICIPANT	\N	PRESENT	0
702293	701643	20142Y	PARTICIPANT	\N	PRESENT	0
702294	701643	20126Y	PARTICIPANT	\N	PRESENT	0
702295	701620	19729F	PARTICIPANT	\N	EXCUSE	0
702296	701620	14231L	PARTICIPANT	\N	EXCUSE	0
702297	701643	20108W	PARTICIPANT	\N	PRESENT	0
702302	701643	19673G	PARTICIPANT	\N	PRESENT	0
702303	701643	17737W	PARTICIPANT	\N	PRESENT	0
702304	701643	08015R	PARTICIPANT	\N	PRESENT	0
702305	701643	20132W	PARTICIPANT	\N	PRESENT	0
702306	701643	16685X	PARTICIPANT	\N	PRESENT	0
702307	701643	14329V	PARTICIPANT	\N	PRESENT	0
702308	701643	14357A	PARTICIPANT	\N	PRESENT	0
702309	701643	19693L	PARTICIPANT	\N	PRESENT	0
702310	701643	19251M	PARTICIPANT	\N	PRESENT	0
702318	698849	14042U	PARTICIPANT	\N	PRESENT	0
702319	698849	11097X	PARTICIPANT	\N	PRESENT	0
702320	698849	19479G	PARTICIPANT	\N	PRESENT	0
702321	698850	11097X	PARTICIPANT	\N	PRESENT	0
702322	698850	19479G	PARTICIPANT	\N	PRESENT	0
702324	698854	11097X	PARTICIPANT	\N	PRESENT	0
702325	698857	14042U	PARTICIPANT	\N	PRESENT	0
702326	698857	11097X	PARTICIPANT	\N	PRESENT	0
702327	698864	14042U	PARTICIPANT	\N	PRESENT	0
702328	698864	20090E	PARTICIPANT	\N	PRESENT	0
702329	698864	14281W	PARTICIPANT	\N	PRESENT	0
702330	698864	20130U	PARTICIPANT	\N	PRESENT	0
702331	698864	11097X	PARTICIPANT	\N	PRESENT	0
702332	698864	19479G	PARTICIPANT	\N	PRESENT	0
702499	701536	10006L	PRESIDENT	0	PRESENT	0
702524	701536	19569H	PARTICIPANT	\N	PRESENT	0
702525	701536	14223L	PARTICIPANT	\N	PRESENT	0
702526	701536	19697Q	PARTICIPANT	\N	PRESENT	0
702527	701536	20266L	PARTICIPANT	\N	PRESENT	0
702562	701536	20248J	PARTICIPANT	\N	EXCUSE	0
702563	701536	19295A	PARTICIPANT	\N	EXCUSE	0
702564	701536	19591F	PARTICIPANT	\N	EXCUSE	0
702616	701536	14026U	PARTICIPANT	\N	PRESENT	0
702620	701536	18193Q	PARTICIPANT	\N	PRESENT	0
702627	701536	08045X	PARTICIPANT	\N	PRESENT	0
702651	701536	04043D	PARTICIPANT	\N	PRESENT	0
702652	701536	11031D	PARTICIPANT	\N	PRESENT	0
702653	701536	11045K	PARTICIPANT	\N	PRESENT	0
702654	701536	04092N	PARTICIPANT	\N	PRESENT	0
702655	701536	19703U	PARTICIPANT	\N	PRESENT	0
702696	701536	19683J	PARTICIPANT	\N	PRESENT	0
702701	701536	01034P	PARTICIPANT	\N	PRESENT	0
702703	702702	20116W	PARTICIPANT	\N	PRESENT	0
702704	702702	19383Y	PARTICIPANT	\N	PRESENT	0
702705	702702	19782L	PARTICIPANT	\N	PRESENT	0
702711	702702	14329V	PARTICIPANT	\N	PRESENT	0
702712	702702	14357A	PARTICIPANT	\N	PRESENT	0
702713	702702	17589D	PARTICIPANT	\N	PRESENT	0
702714	702702	19507S	PARTICIPANT	\N	PRESENT	0
702715	702702	14213J	PARTICIPANT	\N	PRESENT	0
702716	702702	05012A	PARTICIPANT	\N	PRESENT	0
702717	702702	19679N	PARTICIPANT	\N	PRESENT	0
702718	702702	20044X	PARTICIPANT	\N	PRESENT	0
702806	701536	19723Y	PARTICIPANT	\N	PRESENT	0
702811	702807	14231L	PARTICIPANT	\N	PRESENT	0
702812	702807	11048N	PARTICIPANT	\N	PRESENT	0
702939	701180	19735D	PARTICIPANT	\N	EXCUSE	0
702952	701724	14001X	PARTICIPANT	\N	PRESENT	0
703250	702461	14111D	PARTICIPANT	\N	PRESENT	0
703255	703254	14357A	PARTICIPANT	\N	PRESENT	0
703256	703254	97011G	PARTICIPANT	\N	PRESENT	0
703257	703254	14179A	PARTICIPANT	\N	PRESENT	0
703258	703254	08034U	PARTICIPANT	\N	PRESENT	0
703259	703254	14147R	PARTICIPANT	\N	PRESENT	0
703260	703254	04045F	PARTICIPANT	\N	PRESENT	0
703261	703254	11041F	PARTICIPANT	\N	PRESENT	0
703619	703618	14255U	PARTICIPANT	\N	PRESENT	0
703620	703618	05012A	PARTICIPANT	\N	PRESENT	0
703874	703873	14147R	PARTICIPANT	\N	PRESENT	0
703972	703967	20044X	PARTICIPANT	\N	PRESENT	0
703970	703967	01043Q	PARTICIPANT	\N	PRESENT	0
703971	703967	20086J	PARTICIPANT	\N	PRESENT	0
703973	703967	20058E	PARTICIPANT	\N	PRESENT	0
703974	703967	11064N	PARTICIPANT	\N	PRESENT	0
703975	703967	19573D	PARTICIPANT	\N	PRESENT	0
703976	703968	01043Q	PARTICIPANT	\N	PRESENT	0
703977	703968	20086J	PARTICIPANT	\N	PRESENT	0
703978	703968	20044X	PARTICIPANT	\N	PRESENT	0
703979	703968	20058E	PARTICIPANT	\N	PRESENT	0
703980	703968	11064N	PARTICIPANT	\N	PRESENT	0
703981	703968	19573D	PARTICIPANT	\N	PRESENT	0
703982	703968	20298U	PARTICIPANT	\N	PRESENT	0
703983	703968	19349W	PARTICIPANT	\N	PRESENT	0
703984	703968	20082E	PARTICIPANT	\N	PRESENT	0
703985	703968	19503N	PARTICIPANT	\N	PRESENT	0
703986	703968	19525U	PARTICIPANT	\N	PRESENT	0
703987	703969	01043Q	PARTICIPANT	\N	PRESENT	0
703988	703969	20086J	PARTICIPANT	\N	PRESENT	0
703989	703969	19503N	PARTICIPANT	\N	PRESENT	0
703990	703969	20298U	PARTICIPANT	\N	PRESENT	0
703991	703969	20082E	PARTICIPANT	\N	PRESENT	0
703993	701600	19533U	PARTICIPANT	\N	PRESENT	0
703995	701600	01058X	PARTICIPANT	\N	EXCUSE	0
703997	703996	19251M	PARTICIPANT	\N	PRESENT	0
703998	703996	04033B	PARTICIPANT	\N	PRESENT	0
703999	703996	19673G	PARTICIPANT	\N	PRESENT	0
704000	703996	10006L	PARTICIPANT	\N	PRESENT	0
704001	703996	19713W	PARTICIPANT	\N	PRESENT	0
704002	703996	14147R	PARTICIPANT	\N	PRESENT	0
704003	703996	19593H	PARTICIPANT	\N	PRESENT	0
704004	703996	14223L	PARTICIPANT	\N	PRESENT	0
704005	703996	97011G	PARTICIPANT	\N	PRESENT	0
704006	703996	19671E	PARTICIPANT	\N	PRESENT	0
704007	703996	20108W	PARTICIPANT	\N	PRESENT	0
704008	703996	19782L	PARTICIPANT	\N	PRESENT	0
704009	703996	17637T	PARTICIPANT	\N	PRESENT	0
704010	703996	19349W	PARTICIPANT	\N	PRESENT	0
704012	704011	19782L	PARTICIPANT	\N	PRESENT	0
704013	704011	10006L	PARTICIPANT	\N	PRESENT	0
704014	704011	19251M	PARTICIPANT	\N	PRESENT	0
704015	704011	19673G	PARTICIPANT	\N	PRESENT	0
704016	704011	97011G	PARTICIPANT	\N	PRESENT	0
689996	688648	19549D	PARTICIPANT	\N	PRESENT	0
686660	686659	20022R	PARTICIPANT	\N	PRESENT	0
686661	686659	14231L	PARTICIPANT	\N	PRESENT	0
686662	686659	11083R	PARTICIPANT	\N	PRESENT	0
686663	686659	14059S	PARTICIPANT	\N	PRESENT	0
686664	686659	19503N	PARTICIPANT	\N	PRESENT	0
686669	686668	04059M	PARTICIPANT	\N	PRESENT	0
686670	686668	11026G	PARTICIPANT	\N	PRESENT	0
686671	686668	20022R	PARTICIPANT	\N	PRESENT	0
686672	686668	19575F	PARTICIPANT	\N	PRESENT	0
686673	686668	14193X	PARTICIPANT	\N	PRESENT	0
686674	686668	14187A	PARTICIPANT	\N	PRESENT	0
686675	686668	18083K	PARTICIPANT	\N	PRESENT	0
686676	686668	20144B	PARTICIPANT	\N	PRESENT	0
686677	686668	19347U	PARTICIPANT	\N	PRESENT	0
686678	686668	20056C	PARTICIPANT	\N	PRESENT	0
686679	686668	19735D	PARTICIPANT	\N	PRESENT	0
686684	686683	04033B	PARTICIPANT	\N	PRESENT	0
686685	686683	14030Q	PARTICIPANT	\N	PRESENT	0
686686	686683	20056C	PARTICIPANT	\N	PRESENT	0
686687	686683	04035D	PARTICIPANT	\N	PRESENT	0
686688	686683	14215L	PARTICIPANT	\N	PRESENT	0
686689	686683	19545Y	PARTICIPANT	\N	PRESENT	0
686690	686683	10015M	PARTICIPANT	\N	PRESENT	0
686691	686683	19515S	PARTICIPANT	\N	PRESENT	0
686692	686683	17737W	PARTICIPANT	\N	PRESENT	0
686693	686683	99004R	PARTICIPANT	\N	PRESENT	0
686694	686683	97011G	PARTICIPANT	\N	PRESENT	0
686695	686683	14147R	PARTICIPANT	\N	PRESENT	0
686696	686683	20138D	PARTICIPANT	\N	PRESENT	0
686697	686683	20264J	PARTICIPANT	\N	PRESENT	0
686698	686683	19673G	PARTICIPANT	\N	PRESENT	0
686699	686683	07004J	PARTICIPANT	\N	PRESENT	0
689981	688648	20064C	PARTICIPANT	\N	PRESENT	0
689983	688648	14213J	PARTICIPANT	\N	PRESENT	0
689984	688648	20098N	PARTICIPANT	\N	PRESENT	0
690002	688648	19347U	PARTICIPANT	\N	PRESENT	0
690009	688648	01060R	PARTICIPANT	\N	PRESENT	0
690013	688648	14042U	PARTICIPANT	\N	PRESENT	0
690014	688648	19649G	PARTICIPANT	\N	PRESENT	0
690015	688648	11064N	PARTICIPANT	\N	PRESENT	0
690016	688648	14237S	PARTICIPANT	\N	PRESENT	0
690017	688648	11026G	PARTICIPANT	\N	PRESENT	0
690018	688648	14001X	PARTICIPANT	\N	PRESENT	0
690019	688648	19545Y	PARTICIPANT	\N	PRESENT	0
690020	688648	20122U	PARTICIPANT	\N	PRESENT	0
690318	688649	14026U	PARTICIPANT	\N	PRESENT	0
690319	688649	04045F	PARTICIPANT	\N	PRESENT	0
690320	688649	19683J	PARTICIPANT	\N	PRESENT	0
690321	688649	11031D	PARTICIPANT	\N	PRESENT	0
690322	688649	19691J	PARTICIPANT	\N	PRESENT	0
690323	688649	14055N	PARTICIPANT	\N	PRESENT	0
690324	688649	14107H	PARTICIPANT	\N	PRESENT	0
690325	688649	10006L	PARTICIPANT	\N	PRESENT	0
690326	688649	14195A	PARTICIPANT	\N	PRESENT	0
690327	688649	20266L	PARTICIPANT	\N	PRESENT	0
690328	688649	08045X	PARTICIPANT	\N	PRESENT	0
690329	688649	19713W	PARTICIPANT	\N	PRESENT	0
690330	688649	14213J	PARTICIPANT	\N	PRESENT	0
690331	688649	20062A	PARTICIPANT	\N	PRESENT	0
690332	688649	20066E	PARTICIPANT	\N	PRESENT	0
690333	688649	14205J	PARTICIPANT	\N	PRESENT	0
690334	688649	18193Q	PARTICIPANT	\N	PRESENT	0
690335	688649	19651A	PARTICIPANT	\N	PRESENT	0
690336	688649	20074E	PARTICIPANT	\N	PRESENT	0
690337	688649	17737W	PARTICIPANT	\N	PRESENT	0
690338	688649	20090E	PARTICIPANT	\N	PRESENT	0
690339	688649	19347U	PARTICIPANT	\N	PRESENT	0
690340	688649	20914V	PARTICIPANT	\N	PRESENT	0
690341	688649	14121F	PARTICIPANT	\N	PRESENT	0
690342	688649	08060W	PARTICIPANT	\N	PRESENT	0
690343	688649	04092N	PARTICIPANT	\N	PRESENT	0
690344	688649	19747H	PARTICIPANT	\N	PRESENT	0
690391	688649	14059S	PARTICIPANT	\N	PRESENT	0
690346	688649	20124W	PARTICIPANT	\N	PRESENT	0
690347	688649	18083K	PARTICIPANT	\N	PRESENT	0
690348	688649	05012A	PARTICIPANT	\N	PRESENT	0
690349	688649	01062T	PARTICIPANT	\N	PRESENT	0
690350	688649	86034E	PARTICIPANT	\N	PRESENT	0
690351	688649	20264J	PARTICIPANT	\N	PRESENT	0
690352	688649	17965H	PARTICIPANT	\N	PRESENT	0
690353	688649	20112S	PARTICIPANT	\N	PRESENT	0
690354	688649	11040E	PARTICIPANT	\N	PRESENT	0
690355	688649	20020P	PARTICIPANT	\N	PRESENT	0
690356	688649	20172F	PARTICIPANT	\N	PRESENT	0
690357	688649	20026V	PARTICIPANT	\N	PRESENT	0
690358	688649	20126Y	PARTICIPANT	\N	PRESENT	0
690359	688649	20152B	PARTICIPANT	\N	PRESENT	0
690360	688649	04057K	PARTICIPANT	\N	PRESENT	0
690361	688649	08012N	PARTICIPANT	\N	PRESENT	0
690362	688649	20018V	PARTICIPANT	\N	PRESENT	0
690364	688649	19673G	PARTICIPANT	\N	PRESENT	0
690365	688649	19657G	PARTICIPANT	\N	PRESENT	0
690366	688649	20056C	PARTICIPANT	\N	PRESENT	0
690367	688649	97011G	PARTICIPANT	\N	PRESENT	0
690368	688649	08034U	PARTICIPANT	\N	PRESENT	0
690369	688649	11048N	PARTICIPANT	\N	PRESENT	0
690370	688649	14069U	PARTICIPANT	\N	PRESENT	0
690371	688649	19798U	PARTICIPANT	\N	PRESENT	0
690372	688649	20138D	PARTICIPANT	\N	PRESENT	0
690373	688649	99004R	PARTICIPANT	\N	PRESENT	0
690390	688649	20054A	PARTICIPANT	\N	PRESENT	0
690375	688649	19621T	PARTICIPANT	\N	PRESENT	0
690376	688649	20044X	PARTICIPANT	\N	PRESENT	0
690377	688649	14207L	PARTICIPANT	\N	PRESENT	0
690378	688649	19735D	PARTICIPANT	\N	PRESENT	0
690379	688649	19349W	PARTICIPANT	\N	PRESENT	0
690380	688649	95063L	PARTICIPANT	\N	PRESENT	0
690381	688649	11067R	PARTICIPANT	\N	PRESENT	0
690382	688649	19758L	PARTICIPANT	\N	PRESENT	0
690383	688649	19687N	PARTICIPANT	\N	PRESENT	0
690384	688649	20102Q	PARTICIPANT	\N	PRESENT	0
690385	688649	19715Y	PARTICIPANT	\N	PRESENT	0
690387	688649	14053L	PARTICIPANT	\N	PRESENT	0
690388	688649	14071N	PARTICIPANT	\N	PRESENT	0
690389	688649	14357A	PARTICIPANT	\N	PRESENT	0
690392	688649	14217N	PARTICIPANT	\N	PRESENT	0
690414	688649	20068G	PARTICIPANT	\N	PRESENT	0
690401	688649	19413M	PARTICIPANT	\N	PRESENT	0
690404	688649	20032T	PARTICIPANT	\N	PRESENT	0
690405	688649	14231L	PARTICIPANT	\N	PRESENT	0
690406	688649	20046A	PARTICIPANT	\N	PRESENT	0
690408	688649	14225N	PARTICIPANT	\N	PRESENT	0
690409	688649	01058X	PARTICIPANT	\N	PRESENT	0
690410	688649	14031R	PARTICIPANT	\N	PRESENT	0
690411	688649	19693L	PARTICIPANT	\N	PRESENT	0
690412	688649	14147R	PARTICIPANT	\N	PRESENT	0
690413	688649	19569H	PARTICIPANT	\N	PRESENT	0
690415	688649	19631V	PARTICIPANT	\N	PRESENT	0
690417	688649	11012A	PARTICIPANT	\N	PRESENT	0
690418	688649	14030Q	PARTICIPANT	\N	PRESENT	0
690424	688649	19441R	PARTICIPANT	\N	PRESENT	0
690425	688649	20122U	PARTICIPANT	\N	PRESENT	0
690426	688649	20130U	PARTICIPANT	\N	PRESENT	0
690427	688649	14133K	PARTICIPANT	\N	PRESENT	0
690429	688649	14033T	PARTICIPANT	\N	PRESENT	0
690433	688649	14083S	PARTICIPANT	\N	PRESENT	0
690445	688649	01024M	PARTICIPANT	\N	PRESENT	0
690448	688649	19479G	PARTICIPANT	\N	PRESENT	0
690453	688649	20128B	PARTICIPANT	\N	PRESENT	0
690461	688649	19647E	PARTICIPANT	\N	PRESENT	0
690462	688649	20108W	PARTICIPANT	\N	PRESENT	0
697257	695156	20180F	PARTICIPANT	\N	PRESENT	0
697258	695156	19347U	PARTICIPANT	\N	PRESENT	0
697259	695156	20980G	PARTICIPANT	\N	PRESENT	0
697260	695156	19637C	PARTICIPANT	\N	PRESENT	0
697261	695156	20140W	PARTICIPANT	\N	PRESENT	0
697262	695156	20026V	PARTICIPANT	\N	PRESENT	0
697263	695156	14249W	PARTICIPANT	\N	PRESENT	0
697264	695156	20094J	PARTICIPANT	\N	PRESENT	0
697265	695156	11115U	PARTICIPANT	\N	PRESENT	0
697266	695156	19725B	PARTICIPANT	\N	PRESENT	0
697267	695156	19766L	PARTICIPANT	\N	PRESENT	0
697268	695156	14281W	PARTICIPANT	\N	PRESENT	0
697269	695156	11033F	PARTICIPANT	\N	PRESENT	0
697270	695156	19349W	PARTICIPANT	\N	PRESENT	0
697271	695156	11072N	PARTICIPANT	\N	PRESENT	0
697272	695156	19329S	PARTICIPANT	\N	PRESENT	0
697273	695156	20068G	PARTICIPANT	\N	PRESENT	0
697274	695156	19697Q	PARTICIPANT	\N	PRESENT	0
697275	695156	14169X	PARTICIPANT	\N	PRESENT	0
697276	695156	19057M	PARTICIPANT	\N	PRESENT	0
697277	695156	20074E	PARTICIPANT	\N	PRESENT	0
697278	695156	19651A	PARTICIPANT	\N	PRESENT	0
697279	695156	20146D	PARTICIPANT	\N	PRESENT	0
697280	695156	04071H	PARTICIPANT	\N	PRESENT	0
697281	695156	14259Y	PARTICIPANT	\N	PRESENT	0
697282	695156	01048V	PARTICIPANT	\N	PRESENT	0
697283	695156	14223L	PARTICIPANT	\N	PRESENT	0
697284	695156	14021P	PARTICIPANT	\N	PRESENT	0
697285	695156	20108W	PARTICIPANT	\N	PRESENT	0
697286	695156	11066Q	PARTICIPANT	\N	PRESENT	0
697287	695156	14253S	PARTICIPANT	\N	PRESENT	0
697288	695156	19631V	PARTICIPANT	\N	PRESENT	0
697289	695156	19693L	PARTICIPANT	\N	PRESENT	0
697290	695156	20264J	PARTICIPANT	\N	PRESENT	0
697291	695156	08015R	PARTICIPANT	\N	PRESENT	0
697292	695156	19820Y	PARTICIPANT	\N	PRESENT	0
697293	695156	20062A	PARTICIPANT	\N	PRESENT	0
697294	695156	14207L	PARTICIPANT	\N	PRESENT	0
697295	695156	20090E	PARTICIPANT	\N	PRESENT	0
697296	695156	19585H	PARTICIPANT	\N	PRESENT	0
697297	695156	14059S	PARTICIPANT	\N	PRESENT	0
697298	695156	14111D	PARTICIPANT	\N	PRESENT	0
697299	695156	97011G	PARTICIPANT	\N	PRESENT	0
697300	695156	14073Q	PARTICIPANT	\N	PRESENT	0
697301	695156	05012A	PARTICIPANT	\N	PRESENT	0
697302	695156	20088L	PARTICIPANT	\N	PRESENT	0
697303	695156	19383Y	PARTICIPANT	\N	PRESENT	0
697304	695156	19711U	PARTICIPANT	\N	PRESENT	0
697305	695156	19525U	PARTICIPANT	\N	PRESENT	0
697306	695156	20172F	PARTICIPANT	\N	PRESENT	0
697307	695156	14221J	PARTICIPANT	\N	PRESENT	0
697308	695156	19954N	PARTICIPANT	\N	PRESENT	0
697309	695156	01058X	PARTICIPANT	\N	PRESENT	0
697310	695156	14121F	PARTICIPANT	\N	PRESENT	0
697311	695156	11067R	PARTICIPANT	\N	PRESENT	0
697312	695156	14357A	PARTICIPANT	\N	PRESENT	0
697313	695156	20018V	PARTICIPANT	\N	PRESENT	0
697314	695156	14053L	PARTICIPANT	\N	PRESENT	0
697315	695156	10006L	PARTICIPANT	\N	PRESENT	0
697316	695156	19683J	PARTICIPANT	\N	PRESENT	0
697317	695156	14097Y	PARTICIPANT	\N	PRESENT	0
697318	695156	14329V	PARTICIPANT	\N	PRESENT	0
697319	695156	19649G	PARTICIPANT	\N	PRESENT	0
697320	695156	14213J	PARTICIPANT	\N	PRESENT	0
697321	695156	20252E	PARTICIPANT	\N	PRESENT	0
697322	695156	20152B	PARTICIPANT	\N	PRESENT	0
697323	695156	20044X	PARTICIPANT	\N	PRESENT	0
697324	695156	01057W	PARTICIPANT	\N	PRESENT	0
697325	695156	19533U	PARTICIPANT	\N	PRESENT	0
697326	695156	20020P	PARTICIPANT	\N	PRESENT	0
697327	695156	14109K	PARTICIPANT	\N	PRESENT	0
697328	695156	19399H	PARTICIPANT	\N	PRESENT	0
697329	695156	18193Q	PARTICIPANT	\N	PRESENT	0
697330	695156	10015M	PARTICIPANT	\N	PRESENT	0
697331	695156	19251M	PARTICIPANT	\N	PRESENT	0
697332	695156	04043D	PARTICIPANT	\N	PRESENT	0
697333	695156	14151M	PARTICIPANT	\N	PRESENT	0
697334	695156	19489J	PARTICIPANT	\N	PRESENT	0
697335	695156	19675J	PARTICIPANT	\N	PRESENT	0
697336	695156	20110Q	PARTICIPANT	\N	PRESENT	0
697337	695156	14193X	PARTICIPANT	\N	PRESENT	0
697338	695156	08069G	PARTICIPANT	\N	PRESENT	0
697339	695156	19599P	PARTICIPANT	\N	PRESENT	0
697340	695156	11041F	PARTICIPANT	\N	PRESENT	0
697341	695156	20054A	PARTICIPANT	\N	PRESENT	0
697342	695156	20028X	PARTICIPANT	\N	PRESENT	0
697343	695156	20138D	PARTICIPANT	\N	PRESENT	0
697344	695156	20126Y	PARTICIPANT	\N	PRESENT	0
697345	695156	20124W	PARTICIPANT	\N	PRESENT	0
697346	695156	11040E	PARTICIPANT	\N	PRESENT	0
697347	695156	19565D	PARTICIPANT	\N	PRESENT	0
697348	695156	19695N	PARTICIPANT	\N	PRESENT	0
697349	695156	14217N	PARTICIPANT	\N	PRESENT	0
697350	695156	11056N	PARTICIPANT	\N	PRESENT	0
697351	696632	20138D	PARTICIPANT	\N	PRESENT	0
697352	696632	17965H	PARTICIPANT	\N	PRESENT	0
697353	696632	20050V	PARTICIPANT	\N	PRESENT	0
697354	696632	04045F	PARTICIPANT	\N	PRESENT	0
697355	696632	14026U	PARTICIPANT	\N	PRESENT	0
697356	696632	20096L	PARTICIPANT	\N	PRESENT	0
697357	696632	19725B	PARTICIPANT	\N	PRESENT	0
697358	696632	11031D	PARTICIPANT	\N	PRESENT	0
697359	696632	19735D	PRESIDENT	1	PRESENT	0
697360	696632	20114U	PARTICIPANT	\N	PRESENT	0
697361	696632	14213J	PARTICIPANT	\N	PRESENT	0
697362	696632	19369B	PRESIDENT	0	PRESENT	0
697363	696632	20024T	PARTICIPANT	\N	PRESENT	0
697364	696632	20126Y	PARTICIPANT	\N	PRESENT	0
697365	695156	19593H	PARTICIPANT	\N	PRESENT	0
697366	695156	19687N	PARTICIPANT	\N	PRESENT	0
697367	695156	05008E	PARTICIPANT	\N	PRESENT	0
697368	695156	19747H	PARTICIPANT	\N	PRESENT	0
697369	695156	19415P	PARTICIPANT	\N	PRESENT	0
697370	695156	20070A	PARTICIPANT	\N	PRESENT	0
697371	695156	19621T	PARTICIPANT	\N	PRESENT	0
697372	695156	12028B	PARTICIPANT	\N	PRESENT	0
697373	695156	19421M	PARTICIPANT	\N	PRESENT	0
697374	695156	14215L	PARTICIPANT	\N	PRESENT	0
697375	695156	17779H	PARTICIPANT	\N	PRESENT	0
697376	695156	19701S	PARTICIPANT	\N	PRESENT	0
697377	695156	19549D	PARTICIPANT	\N	PRESENT	0
697378	695156	19573D	PARTICIPANT	\N	PRESENT	0
697379	695156	04059M	PARTICIPANT	\N	PRESENT	0
697380	695156	19741B	PARTICIPANT	\N	PRESENT	0
697381	695156	08060W	PARTICIPANT	\N	PRESENT	0
697382	695156	20064C	PARTICIPANT	\N	PRESENT	0
697383	695156	11097X	PARTICIPANT	\N	PRESENT	0
697384	695156	20134Y	PARTICIPANT	\N	PRESENT	0
697385	695156	20100N	PARTICIPANT	\N	PRESENT	0
697386	695156	95063L	PARTICIPANT	\N	PRESENT	0
697387	695156	08061X	PARTICIPANT	\N	PRESENT	0
697388	695156	04047H	PARTICIPANT	\N	PRESENT	0
697389	695156	14026U	PARTICIPANT	\N	PRESENT	0
697390	695156	08034U	PARTICIPANT	\N	PRESENT	0
697391	695156	11083R	PARTICIPANT	\N	PRESENT	0
697392	695156	19629C	PARTICIPANT	\N	PRESENT	0
697393	695156	11048N	PARTICIPANT	\N	PRESENT	0
697394	695156	04045F	PARTICIPANT	\N	PRESENT	0
697395	695156	20130U	PARTICIPANT	\N	PRESENT	0
697396	695156	01060R	PARTICIPANT	\N	PRESENT	0
697397	695156	11054L	PARTICIPANT	\N	PRESENT	0
697398	695156	19667J	PARTICIPANT	\N	PRESENT	0
697399	695156	20118Y	PARTICIPANT	\N	PRESENT	0
697400	695156	19333N	PARTICIPANT	\N	PRESENT	0
697401	695156	19647E	PARTICIPANT	\N	PRESENT	0
697402	695156	19527W	PARTICIPANT	\N	PRESENT	0
697403	695156	20096L	PARTICIPANT	\N	PRESENT	0
697404	695156	20022R	PARTICIPANT	\N	PRESENT	0
697405	695156	11026G	PARTICIPANT	\N	PRESENT	0
697406	695156	08012N	PARTICIPANT	\N	PRESENT	0
697407	695156	11043H	PARTICIPANT	\N	PRESENT	0
697408	695156	08045X	PARTICIPANT	\N	PRESENT	0
697409	695156	11074Q	PARTICIPANT	\N	PRESENT	0
697410	695156	11031D	PARTICIPANT	\N	PRESENT	0
697411	695156	01028R	PARTICIPANT	\N	PRESENT	0
697412	695156	11110B	PARTICIPANT	\N	PRESENT	0
697413	695156	20120S	PARTICIPANT	\N	PRESENT	0
697414	695156	01062T	PARTICIPANT	\N	PRESENT	0
697415	695156	07004J	PARTICIPANT	\N	PRESENT	0
697416	695156	19657G	PARTICIPANT	\N	PRESENT	0
697417	695156	14251Q	PARTICIPANT	\N	PRESENT	0
687006	686701	11012A	PARTICIPANT	\N	PRESENT	0
687007	686701	08018U	PARTICIPANT	\N	PRESENT	0
687008	686701	01043Q	PARTICIPANT	\N	PRESENT	0
687009	686701	99004R	PARTICIPANT	\N	PRESENT	0
687010	686701	20018V	PARTICIPANT	\N	PRESENT	0
687011	686701	14073Q	PARTICIPANT	\N	PRESENT	0
687012	686701	19573D	PARTICIPANT	\N	PRESENT	0
687013	686701	19747H	PARTICIPANT	\N	PRESENT	0
687014	686701	14189C	PARTICIPANT	\N	PRESENT	0
687015	686701	11026G	PARTICIPANT	\N	PRESENT	0
687016	686701	20172F	PARTICIPANT	\N	PRESENT	0
687017	686701	14109K	PARTICIPANT	\N	PRESENT	0
687086	686702	14031R	PARTICIPANT	\N	PRESENT	0
687087	686702	95063L	PARTICIPANT	\N	PRESENT	0
687088	686702	14109K	PARTICIPANT	\N	PRESENT	0
687089	686702	19649G	PARTICIPANT	\N	PRESENT	0
687090	686702	12041X	PARTICIPANT	\N	PRESENT	0
687091	686702	20102Q	PARTICIPANT	\N	PRESENT	0
687092	686702	20046A	PARTICIPANT	\N	PRESENT	0
687093	686702	20018V	PARTICIPANT	\N	PRESENT	0
687094	686702	19413M	PARTICIPANT	\N	PRESENT	0
687095	686702	19599P	PARTICIPANT	\N	PRESENT	0
687096	686702	11104D	PARTICIPANT	\N	PRESENT	0
687097	686702	11067R	PARTICIPANT	\N	PRESENT	0
687098	686702	14001X	PARTICIPANT	\N	PRESENT	0
687099	686702	11026G	PARTICIPANT	\N	PRESENT	0
687100	686702	14021P	PARTICIPANT	\N	PRESENT	0
687101	686702	20110Q	PARTICIPANT	\N	PRESENT	0
687102	686702	20100N	PARTICIPANT	\N	PRESENT	0
687103	686702	20134Y	PARTICIPANT	\N	PRESENT	0
687104	686702	08061X	PARTICIPANT	\N	PRESENT	0
687105	686702	19525U	PARTICIPANT	\N	PRESENT	0
687106	686702	19637C	PARTICIPANT	\N	PRESENT	0
687107	686702	14207L	PARTICIPANT	\N	PRESENT	0
687108	686702	19651A	PARTICIPANT	\N	PRESENT	0
687109	686702	20264J	PARTICIPANT	\N	PRESENT	0
687110	686702	19725B	PARTICIPANT	\N	PRESENT	0
687111	686702	14037X	PARTICIPANT	\N	PRESENT	0
687112	686702	04057K	PARTICIPANT	\N	PRESENT	0
687113	686702	19387D	PARTICIPANT	\N	PRESENT	0
687114	686702	19629C	PARTICIPANT	\N	PRESENT	0
687115	686702	98022P	PARTICIPANT	\N	PRESENT	0
687116	686702	14189C	PARTICIPANT	\N	PRESENT	0
687117	686702	11077T	PARTICIPANT	\N	PRESENT	0
687118	686702	20028X	PARTICIPANT	\N	PRESENT	0
687119	686702	18193Q	PARTICIPANT	\N	PRESENT	0
687120	686702	01028R	PARTICIPANT	\N	PRESENT	0
687121	686702	19611R	PARTICIPANT	\N	PRESENT	0
687122	686702	14089Y	PARTICIPANT	\N	PRESENT	0
687123	686702	19739H	PARTICIPANT	\N	PRESENT	0
687124	686702	14205J	PARTICIPANT	\N	PRESENT	0
687125	686702	20144B	PARTICIPANT	\N	PRESENT	0
687126	686702	19691J	PARTICIPANT	\N	PRESENT	0
687127	686702	14073Q	PARTICIPANT	\N	PRESENT	0
687128	686702	14083S	PARTICIPANT	\N	PRESENT	0
687129	686702	11053K	PARTICIPANT	\N	PRESENT	0
687130	686702	19581D	PARTICIPANT	\N	PRESENT	0
687131	686702	19671E	PARTICIPANT	\N	PRESENT	0
687132	686702	14215L	PARTICIPANT	\N	PRESENT	0
687133	686702	19415P	PARTICIPANT	\N	PRESENT	0
687134	686702	19747H	PARTICIPANT	\N	PRESENT	0
687135	686702	08034U	PARTICIPANT	\N	PRESENT	0
687136	686702	05008E	PARTICIPANT	\N	PRESENT	0
687137	686702	14071N	PARTICIPANT	\N	PRESENT	0
687138	686702	14133K	PARTICIPANT	\N	PRESENT	0
687139	686702	04047H	PARTICIPANT	\N	PRESENT	0
687140	686702	99004R	PARTICIPANT	\N	PRESENT	0
687141	686702	19798U	PARTICIPANT	\N	PRESENT	0
687142	686702	20252E	PARTICIPANT	\N	PRESENT	0
687143	686702	20020P	PARTICIPANT	\N	PRESENT	0
687144	686702	20126Y	PARTICIPANT	\N	PRESENT	0
687145	686702	20124W	PARTICIPANT	\N	PRESENT	0
687146	686702	20090E	PARTICIPANT	\N	PRESENT	0
687084	686702	86034E	PARTICIPANT	\N	PRESENT	0
687085	686702	19515S	PARTICIPANT	\N	PRESENT	0
687147	686702	19703U	PARTICIPANT	\N	PRESENT	0
687148	686702	01058X	PARTICIPANT	\N	PRESENT	0
687149	686702	19507S	PARTICIPANT	\N	PRESENT	0
687150	686702	20138D	PARTICIPANT	\N	PRESENT	0
687151	686702	14249W	PARTICIPANT	\N	PRESENT	0
687152	686702	19301E	PARTICIPANT	\N	PRESENT	0
687153	686702	11033F	PARTICIPANT	\N	PRESENT	0
687154	686702	20024T	PARTICIPANT	\N	PRESENT	0
687155	686702	20108W	PARTICIPANT	\N	PRESENT	0
687156	686702	19399H	PARTICIPANT	\N	PRESENT	0
687157	686702	20068G	PARTICIPANT	\N	PRESENT	0
687158	686702	20140W	PARTICIPANT	\N	PRESENT	0
687159	686702	20022R	PARTICIPANT	\N	PRESENT	0
687160	686702	14223L	PARTICIPANT	\N	PRESENT	0
687161	686702	08028W	PARTICIPANT	\N	PRESENT	0
687162	686702	11090Q	PARTICIPANT	\N	PRESENT	0
687163	686702	17637T	PARTICIPANT	\N	PRESENT	0
687164	686702	20076G	PARTICIPANT	\N	PRESENT	0
687165	686702	20026V	PARTICIPANT	\N	PRESENT	0
687166	686702	20098N	PARTICIPANT	\N	PRESENT	0
687167	686702	20056C	PARTICIPANT	\N	PRESENT	0
687168	686702	20044X	PARTICIPANT	\N	PRESENT	0
687169	686702	14331P	PARTICIPANT	\N	PRESENT	0
687170	686702	14187A	PARTICIPANT	\N	PRESENT	0
687171	686702	11097X	PARTICIPANT	\N	PRESENT	0
687172	686702	14151M	PARTICIPANT	\N	PRESENT	0
687173	686702	19549D	PARTICIPANT	\N	PRESENT	0
687174	686702	20058E	PARTICIPANT	\N	PRESENT	0
687175	686702	19467C	PARTICIPANT	\N	PRESENT	0
687176	686702	19723Y	PARTICIPANT	\N	PRESENT	0
687177	686702	19760E	PARTICIPANT	\N	PRESENT	0
687178	686702	97011G	PARTICIPANT	\N	PRESENT	0
687179	686702	14121F	PARTICIPANT	\N	PRESENT	0
687180	686702	19349W	PARTICIPANT	\N	PRESENT	0
687181	686702	19441R	PARTICIPANT	\N	PRESENT	0
687182	686702	11043H	PARTICIPANT	\N	PRESENT	0
687183	686702	20032T	PARTICIPANT	\N	PRESENT	0
687184	686702	19621T	PARTICIPANT	\N	PRESENT	0
687185	686702	20096L	PARTICIPANT	\N	PRESENT	0
687186	686702	20172F	PARTICIPANT	\N	PRESENT	0
687187	686702	20062A	PARTICIPANT	\N	PRESENT	0
687188	686702	19383Y	PARTICIPANT	\N	PRESENT	0
687189	686702	08010L	PARTICIPANT	\N	PRESENT	0
687190	686702	20034V	PARTICIPANT	\N	PRESENT	0
687191	686702	04033B	PARTICIPANT	\N	PRESENT	0
687192	686702	19479G	PARTICIPANT	\N	PRESENT	0
687193	686702	19687N	PARTICIPANT	\N	PRESENT	0
687194	686702	11056N	PARTICIPANT	\N	PRESENT	0
687195	686702	19347U	PARTICIPANT	\N	PRESENT	0
687196	686702	20114U	PARTICIPANT	\N	PRESENT	0
687197	686702	20052X	PARTICIPANT	\N	PRESENT	0
687198	686702	19673G	PARTICIPANT	\N	PRESENT	0
687199	686702	19679N	PARTICIPANT	\N	PRESENT	0
687200	686702	14069U	PARTICIPANT	\N	PRESENT	0
687201	686702	14053L	PARTICIPANT	\N	PRESENT	0
687202	686702	14225N	PARTICIPANT	\N	PRESENT	0
687203	686702	20180F	PARTICIPANT	\N	PRESENT	0
687204	686702	19443T	PARTICIPANT	\N	PRESENT	0
687205	686702	19762G	PARTICIPANT	\N	PRESENT	0
687206	686702	14221J	PARTICIPANT	\N	PRESENT	0
687207	686702	19503N	PARTICIPANT	\N	PRESENT	0
687208	686702	19820Y	PARTICIPANT	\N	PRESENT	0
687218	686702	19367Y	PARTICIPANT	\N	PRESENT	0
687221	686702	11012A	PARTICIPANT	\N	PRESENT	0
687222	686702	20048C	PARTICIPANT	\N	PRESENT	0
687223	686702	05012A	PARTICIPANT	\N	PRESENT	0
687224	686702	19569H	PARTICIPANT	\N	PRESENT	0
687225	686702	19954N	PARTICIPANT	\N	PRESENT	0
687226	686702	01024M	PARTICIPANT	\N	PRESENT	0
687227	686702	14217N	PARTICIPANT	\N	PRESENT	0
687228	686702	20104S	PARTICIPANT	\N	PRESENT	0
687229	686702	14193X	PARTICIPANT	\N	PRESENT	0
687230	686702	14147R	PARTICIPANT	\N	PRESENT	0
687231	686702	19369B	PARTICIPANT	\N	PRESENT	0
687232	686702	14097Y	PARTICIPANT	\N	PRESENT	0
687233	686702	04045F	PARTICIPANT	\N	PRESENT	0
687234	686702	20128B	PARTICIPANT	\N	PRESENT	0
687235	686702	14357A	PARTICIPANT	\N	PRESENT	0
687236	686702	20116W	PARTICIPANT	\N	PRESENT	0
687237	686702	01057W	PARTICIPANT	\N	PRESENT	0
687238	686702	19709B	PARTICIPANT	\N	PRESENT	0
687239	686702	14033T	PARTICIPANT	\N	PRESENT	0
704017	704011	20108W	PARTICIPANT	\N	PRESENT	0
704018	704011	14147R	PARTICIPANT	\N	PRESENT	0
704019	704011	19671E	PARTICIPANT	\N	PRESENT	0
704020	704011	14223L	PARTICIPANT	\N	PRESENT	0
704021	704011	19593H	PARTICIPANT	\N	PRESENT	0
704022	704011	04033B	PARTICIPANT	\N	PRESENT	0
704023	704011	19713W	PARTICIPANT	\N	PRESENT	0
704024	704011	19349W	PARTICIPANT	\N	PRESENT	0
704025	704011	17637T	PARTICIPANT	\N	PRESENT	0
704027	704026	04033B	PARTICIPANT	\N	PRESENT	0
704028	704026	17737W	PARTICIPANT	\N	PRESENT	0
704029	704026	14169X	PARTICIPANT	\N	PRESENT	0
704030	704026	19367Y	PARTICIPANT	\N	PRESENT	0
704031	704026	20042V	PARTICIPANT	\N	PRESENT	0
704032	704026	04042C	PARTICIPANT	\N	PRESENT	0
704033	704026	18083K	PARTICIPANT	\N	PRESENT	0
704034	704026	20140W	PARTICIPANT	\N	PRESENT	0
704035	704026	14097Y	PARTICIPANT	\N	PRESENT	0
704036	704026	97011G	PARTICIPANT	\N	PRESENT	0
704037	704026	14147R	PARTICIPANT	\N	PRESENT	0
704038	704026	08034U	PARTICIPANT	\N	PRESENT	0
704039	704026	19711U	PARTICIPANT	\N	PRESENT	0
704040	704026	08015R	PARTICIPANT	\N	PRESENT	0
704041	704026	19647E	PARTICIPANT	\N	PRESENT	0
704042	704026	16685X	PARTICIPANT	\N	PRESENT	0
704044	704043	20064C	PARTICIPANT	\N	PRESENT	0
704046	704045	11064N	PARTICIPANT	\N	PRESENT	0
704051	704049	19533U	PARTICIPANT	\N	PRESENT	0
704053	704052	19711U	PARTICIPANT	\N	PRESENT	0
704054	704052	20050V	PARTICIPANT	\N	PRESENT	0
704056	704055	19711U	PARTICIPANT	\N	PRESENT	0
704057	704055	20050V	PARTICIPANT	\N	PRESENT	0
704059	704058	20132W	PARTICIPANT	\N	PRESENT	0
704060	704058	14229S	PARTICIPANT	\N	PRESENT	0
704062	704061	20132W	PARTICIPANT	\N	PRESENT	0
704063	704061	14229S	PARTICIPANT	\N	PRESENT	0
704065	704064	04047H	PARTICIPANT	\N	PRESENT	0
704066	704064	04042C	PARTICIPANT	\N	PRESENT	0
704070	704064	11066Q	PARTICIPANT	\N	PRESENT	0
704072	704071	19503N	PARTICIPANT	\N	PRESENT	0
704087	698875	14042U	PARTICIPANT	\N	PRESENT	0
704089	698875	18193Q	PARTICIPANT	\N	PRESENT	0
704090	698875	11097X	PARTICIPANT	\N	PRESENT	0
704091	698875	19479G	PARTICIPANT	\N	PRESENT	0
704092	698878	14042U	PARTICIPANT	\N	PRESENT	0
704093	698878	11097X	PARTICIPANT	\N	PRESENT	0
704094	698878	19479G	PARTICIPANT	\N	PRESENT	0
704095	698878	18193Q	PARTICIPANT	\N	PRESENT	0
704102	702461	14069U	PARTICIPANT	\N	PRESENT	0
704104	704103	14111D	PARTICIPANT	\N	PRESENT	0
704105	704103	14259Y	PARTICIPANT	\N	PRESENT	0
704212	704211	19701S	PARTICIPANT	\N	PRESENT	0
704219	704217	14147R	PARTICIPANT	\N	PRESENT	0
704220	704217	19725B	PARTICIPANT	\N	PRESENT	0
704221	704217	19749K	PARTICIPANT	\N	PRESENT	0
704223	704222	14147R	PARTICIPANT	\N	PRESENT	0
704226	704225	14179A	PARTICIPANT	\N	PRESENT	0
704239	704238	19399H	PARTICIPANT	\N	EXCUSE	0
704240	704238	19479G	PARTICIPANT	\N	EXCUSE	0
704323	704313	19525U	PARTICIPANT	\N	PRESENT	0
704324	704313	20090E	PARTICIPANT	\N	EXCUSE	0
704325	704313	19701S	PARTICIPANT	\N	EXCUSE	0
704326	704313	20286Q	PARTICIPANT	\N	EXCUSE	0
704332	704313	17023S	PARTICIPANT	\N	PRESENT	0
704351	704350	04092N	PARTICIPANT	\N	PRESENT	0
704352	704350	19717B	PARTICIPANT	\N	PRESENT	0
704353	704213	14213J	PARTICIPANT	\N	PRESENT	0
704354	704213	20126Y	PARTICIPANT	\N	EXCUSE	0
704355	704213	20050V	PARTICIPANT	\N	EXCUSE	0
704356	704213	11031D	PARTICIPANT	\N	PRESENT	0
704357	704213	19735D	PRESIDENT	0	PRESENT	0
704358	704213	20138D	PARTICIPANT	\N	PRESENT	0
704359	704213	04045F	PARTICIPANT	\N	PRESENT	0
704360	704213	17965H	PARTICIPANT	\N	PRESENT	0
704361	704213	20066E	PARTICIPANT	\N	PRESENT	0
704362	704213	19725B	PARTICIPANT	\N	PRESENT	0
704521	704520	20106U	PARTICIPANT	\N	PRESENT	0
704522	704520	19335Q	PARTICIPANT	\N	PRESENT	0
704523	704520	20264J	PARTICIPANT	\N	PRESENT	1
704524	704520	20142Y	PARTICIPANT	\N	PRESENT	1
704525	704520	20026V	PARTICIPANT	\N	PRESENT	0
704526	704520	20980G	PARTICIPANT	\N	PRESENT	0
704527	704520	20056C	PARTICIPANT	\N	PRESENT	0
704583	704582	19725B	PARTICIPANT	\N	PRESENT	0
704584	704582	14147R	PARTICIPANT	\N	PRESENT	0
704586	704585	19725B	PARTICIPANT	\N	PRESENT	0
704588	704587	20094J	PARTICIPANT	\N	PRESENT	0
704589	704587	20914V	PARTICIPANT	\N	PRESENT	0
704590	704587	19387D	PARTICIPANT	\N	PRESENT	0
704591	704587	14169X	PARTICIPANT	\N	PRESENT	0
704592	704587	19820Y	PARTICIPANT	\N	PRESENT	0
704593	704587	20104S	PARTICIPANT	\N	PRESENT	0
704594	704587	14219Q	PARTICIPANT	\N	PRESENT	0
704595	704587	20070A	PARTICIPANT	\N	PRESENT	0
704627	704622	19447X	PARTICIPANT	\N	PRESENT	0
704628	704622	14089Y	PARTICIPANT	\N	PRESENT	0
704630	704629	19447X	PARTICIPANT	\N	PRESENT	0
704631	704629	14089Y	PARTICIPANT	\N	PRESENT	0
704632	704629	20110Q	PARTICIPANT	\N	PRESENT	0
704633	704629	11026G	PARTICIPANT	\N	PRESENT	0
704638	704637	19447X	PARTICIPANT	\N	PRESENT	0
704639	704637	14089Y	PARTICIPANT	\N	PRESENT	0
704640	704637	11026G	PARTICIPANT	\N	PRESENT	0
704641	704637	11033F	PARTICIPANT	\N	PRESENT	0
704643	704642	19447X	PARTICIPANT	\N	PRESENT	0
704644	704642	14089Y	PARTICIPANT	\N	PRESENT	0
704645	704642	11026G	PARTICIPANT	\N	PRESENT	0
704647	704646	19447X	PARTICIPANT	\N	PRESENT	0
704648	704646	14089Y	PARTICIPANT	\N	PRESENT	0
704649	704646	20110Q	PARTICIPANT	\N	PRESENT	0
704651	704650	19447X	PARTICIPANT	\N	PRESENT	0
704652	704650	14089Y	PARTICIPANT	\N	PRESENT	0
704653	704650	11026G	PARTICIPANT	\N	PRESENT	0
704654	704650	19649G	PARTICIPANT	\N	PRESENT	0
704721	704327	14059S	PARTICIPANT	\N	PRESENT	0
704724	704327	14097Y	PARTICIPANT	\N	PRESENT	0
704726	704327	19565D	PARTICIPANT	\N	EXCUSE	0
704728	704327	14133K	PARTICIPANT	\N	PRESENT	0
704729	704327	20042V	PARTICIPANT	\N	PRESENT	0
704730	704327	01058X	PARTICIPANT	\N	PRESENT	0
704731	704327	16685X	PARTICIPANT	\N	PRESENT	0
704732	704327	04042C	PRESIDENT	0	PRESENT	0
704733	704327	11066Q	PARTICIPANT	\N	PRESENT	0
704734	704327	19669L	PARTICIPANT	\N	PRESENT	0
704735	704327	19721W	PARTICIPANT	\N	PRESENT	0
704736	704327	98022P	PARTICIPANT	\N	PRESENT	0
704737	704327	97011G	PARTICIPANT	\N	PRESENT	0
704738	704327	14211G	PARTICIPANT	\N	PRESENT	0
704739	704327	08047A	PARTICIPANT	\N	PRESENT	0
704740	704331	19762G	PARTICIPANT	\N	PRESENT	0
704741	701853	14123H	PARTICIPANT	\N	PRESENT	0
704742	703790	19729F	PARTICIPANT	\N	PRESENT	0
704743	704327	01062T	PARTICIPANT	\N	PRESENT	0
704744	704327	08069G	PARTICIPANT	\N	PRESENT	0
704745	704327	11041F	PARTICIPANT	\N	PRESENT	0
704746	704327	11054L	PARTICIPANT	\N	PRESENT	0
704747	704327	01024M	PARTICIPANT	\N	PRESENT	0
704748	704327	19347U	PARTICIPANT	\N	PRESENT	0
704749	704327	17023S	PARTICIPANT	\N	PRESENT	0
704750	704327	19443T	PARTICIPANT	\N	EXCUSE	0
704751	704327	20072C	PARTICIPANT	\N	EXCUSE	0
704759	704327	11064N	PARTICIPANT	\N	PRESENT	0
704760	704327	20128B	PARTICIPANT	\N	PRESENT	0
704761	704331	08034U	PARTICIPANT	\N	PRESENT	0
704763	704762	19575F	PARTICIPANT	\N	PRESENT	0
704764	704762	14053L	PARTICIPANT	\N	PRESENT	0
704765	704762	20038A	PARTICIPANT	\N	PRESENT	0
704766	704762	19826F	PARTICIPANT	\N	PRESENT	0
704767	704762	14071N	PARTICIPANT	\N	PRESENT	0
704768	704762	19798U	PARTICIPANT	\N	PRESENT	0
704769	704762	20084G	PARTICIPANT	\N	PRESENT	0
704770	704762	20058E	PARTICIPANT	\N	PRESENT	0
704771	701853	04070G	PARTICIPANT	\N	PRESENT	0
704772	704331	19545Y	PARTICIPANT	\N	PRESENT	0
704773	704327	07033P	PARTICIPANT	\N	PRESENT	0
704774	704331	08010L	PARTICIPANT	\N	PRESENT	0
688666	688665	04059M	PARTICIPANT	\N	PRESENT	0
688667	688665	20024T	PARTICIPANT	\N	PRESENT	0
688668	688665	20094J	PARTICIPANT	\N	PRESENT	0
688669	688665	04042C	PARTICIPANT	\N	PRESENT	0
688670	688665	20264J	PARTICIPANT	\N	PRESENT	0
688671	688665	19525U	PARTICIPANT	\N	PRESENT	0
688672	688665	07033P	PARTICIPANT	\N	PRESENT	0
688673	688665	11074Q	PARTICIPANT	\N	PRESENT	0
688674	688665	19565D	PARTICIPANT	\N	PRESENT	0
688675	688665	19591F	PARTICIPANT	\N	PRESENT	0
688676	688665	14073Q	PARTICIPANT	\N	PRESENT	0
688677	688665	19709B	PARTICIPANT	\N	PRESENT	0
688678	688665	11026G	PARTICIPANT	\N	PRESENT	0
688679	688665	20018V	PARTICIPANT	\N	PRESENT	0
688680	688665	04070G	PARTICIPANT	\N	PRESENT	0
688681	688665	19503N	PARTICIPANT	\N	PRESENT	0
688682	688665	11041F	PARTICIPANT	\N	PRESENT	0
688683	688665	20046A	PARTICIPANT	\N	PRESENT	0
688684	688665	11027H	PARTICIPANT	\N	PRESENT	0
688685	688665	04035D	PARTICIPANT	\N	PRESENT	0
688686	688665	19443T	PARTICIPANT	\N	PRESENT	0
688687	688665	11064N	PARTICIPANT	\N	PRESENT	0
688688	688665	08047A	PARTICIPANT	\N	PRESENT	0
688689	688665	19421M	PARTICIPANT	\N	PRESENT	0
688691	688690	04042C	PARTICIPANT	\N	PRESENT	0
690509	688653	19349W	PARTICIPANT	\N	PRESENT	0
690510	688653	19651A	PARTICIPANT	\N	PRESENT	0
690511	688653	20108W	PARTICIPANT	\N	PRESENT	0
690512	688653	20032T	PARTICIPANT	\N	PRESENT	0
690513	688653	19621T	PARTICIPANT	\N	PRESENT	0
690514	688653	11012A	PARTICIPANT	\N	PRESENT	0
690515	688653	20914V	PARTICIPANT	\N	PRESENT	0
690516	688653	19549D	PARTICIPANT	\N	PRESENT	0
690526	688653	19479G	PARTICIPANT	\N	PRESENT	0
690518	688653	11040E	PARTICIPANT	\N	PRESENT	0
690519	688653	19758L	PARTICIPANT	\N	PRESENT	0
690520	688653	20102Q	PARTICIPANT	\N	PRESENT	0
690521	688653	14225N	PARTICIPANT	\N	PRESENT	0
690522	688653	11048N	PARTICIPANT	\N	PRESENT	0
690523	688653	19631V	PARTICIPANT	\N	PRESENT	0
690524	688653	14195A	PARTICIPANT	\N	PRESENT	0
690525	688653	20122U	PARTICIPANT	\N	PRESENT	0
690527	688653	19441R	PARTICIPANT	\N	PRESENT	0
690528	688653	14030Q	PARTICIPANT	\N	PRESENT	0
690529	688653	14083S	PARTICIPANT	\N	PRESENT	0
690530	688653	01024M	PARTICIPANT	\N	PRESENT	0
690531	688653	20054A	PARTICIPANT	\N	PRESENT	0
690532	688653	19798U	PARTICIPANT	\N	PRESENT	0
690533	688653	20062A	PARTICIPANT	\N	PRESENT	0
690534	688653	19693L	PARTICIPANT	\N	PRESENT	0
690507	688653	14026U	PARTICIPANT	\N	PRESENT	0
690508	688653	20128B	PARTICIPANT	\N	PRESENT	0
690535	688653	20080C	PARTICIPANT	\N	PRESENT	0
690536	688653	20126Y	PARTICIPANT	\N	PRESENT	0
690537	688653	08010L	PARTICIPANT	\N	PRESENT	0
690538	688653	18193Q	PARTICIPANT	\N	PRESENT	0
690539	688653	12016W	PARTICIPANT	\N	PRESENT	0
690543	688653	20040T	PARTICIPANT	\N	PRESENT	0
690544	688653	19715Y	PARTICIPANT	\N	PRESENT	0
690545	688653	14033T	PARTICIPANT	\N	PRESENT	0
690546	688653	20090E	PARTICIPANT	\N	PRESENT	0
690547	688653	19647E	PARTICIPANT	\N	PRESENT	0
690548	688653	19295A	PARTICIPANT	\N	PRESENT	0
690549	688653	19717B	PARTICIPANT	\N	PRESENT	0
690578	688650	19347U	PARTICIPANT	\N	PRESENT	0
690579	688650	20046A	PARTICIPANT	\N	PRESENT	0
690580	688650	19577H	PARTICIPANT	\N	PRESENT	0
690581	688650	20034V	PARTICIPANT	\N	PRESENT	0
690582	688650	20122U	PARTICIPANT	\N	PRESENT	0
690583	688650	20092G	PARTICIPANT	\N	PRESENT	0
690584	688650	20146D	PARTICIPANT	\N	PRESENT	0
690585	688650	19715Y	PARTICIPANT	\N	PRESENT	0
690586	688650	19657G	PARTICIPANT	\N	PRESENT	0
690587	688650	19295A	PARTICIPANT	\N	PRESENT	0
690588	688650	20148F	PARTICIPANT	\N	PRESENT	0
690589	688650	12016W	PARTICIPANT	\N	PRESENT	0
690590	688650	19631V	PARTICIPANT	\N	PRESENT	0
690591	688650	18083K	PARTICIPANT	\N	PRESENT	0
690592	688650	14033T	PARTICIPANT	\N	PRESENT	0
690593	688650	14147R	PARTICIPANT	\N	PRESENT	0
690594	688650	14069U	PARTICIPANT	\N	PRESENT	0
690867	690866	19711U	PARTICIPANT	\N	PRESENT	0
690868	690866	20050V	PARTICIPANT	\N	PRESENT	0
690869	690865	17965H	PARTICIPANT	\N	PRESENT	0
690870	690865	19715Y	PARTICIPANT	\N	PRESENT	0
690871	690865	11045K	PARTICIPANT	\N	PRESENT	0
692417	692416	12028B	PARTICIPANT	\N	PRESENT	0
692505	692423	95063L	PARTICIPANT	\N	PRESENT	0
692506	692318	19593H	PARTICIPANT	\N	PRESENT	0
692507	692318	19527W	PARTICIPANT	\N	PRESENT	0
690576	688650	11070L	PARTICIPANT	\N	PRESENT	0
690577	688650	19717B	PARTICIPANT	\N	PRESENT	0
692508	692318	19766L	PARTICIPANT	\N	PRESENT	0
692509	692318	20134Y	PARTICIPANT	\N	PRESENT	0
692510	692318	19699S	PARTICIPANT	\N	PRESENT	0
692511	692318	19611R	PRESIDENT	0	PRESENT	0
692512	692318	19693L	PARTICIPANT	\N	PRESENT	0
692513	692318	19399H	PARTICIPANT	\N	PRESENT	0
692514	692318	20052X	PARTICIPANT	\N	PRESENT	0
692515	692318	14229S	PARTICIPANT	\N	PRESENT	0
692516	692318	14030Q	PARTICIPANT	\N	PRESENT	0
692517	692318	20098N	PARTICIPANT	\N	PRESENT	0
692518	692318	20056C	PARTICIPANT	\N	PRESENT	0
692519	692318	19573D	PARTICIPANT	\N	PRESENT	0
692520	692318	20264J	PARTICIPANT	\N	PRESENT	0
692521	692318	19735D	PARTICIPANT	\N	PRESENT	0
692522	692318	08012N	PARTICIPANT	\N	PRESENT	0
692523	692318	11043H	PARTICIPANT	\N	PRESENT	0
692524	692318	20124W	PARTICIPANT	\N	PRESENT	0
692525	692318	20026V	PARTICIPANT	\N	PRESENT	0
692526	692318	20084G	PARTICIPANT	\N	PRESENT	0
692527	692318	14073Q	PARTICIPANT	\N	PRESENT	0
692528	692319	14053L	PARTICIPANT	\N	PRESENT	0
692530	692319	17737W	PARTICIPANT	\N	PRESENT	0
692531	692319	20110Q	PARTICIPANT	\N	PRESENT	0
692534	692423	20018V	PARTICIPANT	\N	PRESENT	0
692538	692319	04047H	PRESIDENT	0	PRESENT	0
692539	692423	12028B	PARTICIPANT	\N	PRESENT	0
692547	692319	19729F	PARTICIPANT	\N	PRESENT	0
692548	692319	05008E	PARTICIPANT	\N	PRESENT	0
692549	692423	19741B	PARTICIPANT	\N	PRESENT	0
692550	692319	20022R	PARTICIPANT	\N	PRESENT	0
692551	692423	20016T	PARTICIPANT	\N	PRESENT	0
692558	692423	04045F	PARTICIPANT	\N	PRESENT	0
692561	692319	19489J	PARTICIPANT	\N	PRESENT	0
692562	692423	20086J	PARTICIPANT	\N	PRESENT	0
692563	692423	14191V	PARTICIPANT	\N	PRESENT	0
692564	692423	19685L	PARTICIPANT	\N	PRESENT	0
692565	692319	14151M	PARTICIPANT	\N	PRESENT	0
692567	692319	19301E	PARTICIPANT	\N	PRESENT	0
692576	692456	14038Y	PARTICIPANT	\N	PRESENT	0
692577	692456	20088L	PARTICIPANT	\N	PRESENT	0
692578	692456	19768N	PARTICIPANT	\N	PRESENT	0
692579	692456	20034V	PARTICIPANT	\N	PRESENT	0
692580	692456	19515S	PARTICIPANT	\N	PRESENT	0
692581	692456	20092G	PARTICIPANT	\N	PRESENT	0
692582	692456	14187A	PARTICIPANT	\N	PRESENT	0
692583	692456	20078J	PARTICIPANT	\N	PRESENT	0
692584	692456	19441R	PARTICIPANT	\N	PRESENT	0
692585	692456	19695N	PARTICIPANT	\N	PRESENT	0
692586	692456	11090Q	PRESIDENT	0	PRESENT	0
692587	692456	19866P	PARTICIPANT	\N	PRESENT	0
692588	692456	20062A	PARTICIPANT	\N	PRESENT	0
692589	692456	19705W	PARTICIPANT	\N	PRESENT	0
692590	692456	19507S	PARTICIPANT	\N	PRESENT	0
692591	692456	08015R	PARTICIPANT	\N	PRESENT	0
692592	692456	19369B	PARTICIPANT	\N	PRESENT	0
692593	692456	08028W	PARTICIPANT	\N	PRESENT	0
692594	692456	14329V	PARTICIPANT	\N	PRESENT	0
692599	692319	14069U	PARTICIPANT	\N	PRESENT	0
692601	692423	14195A	PARTICIPANT	\N	PRESENT	0
692603	692456	19782L	PARTICIPANT	\N	PRESENT	0
692604	692456	20094J	PARTICIPANT	\N	PRESENT	0
692605	692456	20104S	PARTICIPANT	\N	PRESENT	0
692606	692456	19747H	PARTICIPANT	\N	PRESENT	0
692607	692456	20298U	PARTICIPANT	\N	PRESENT	0
692634	692456	04045F	PARTICIPANT	\N	PRESENT	0
692635	692423	20080C	PARTICIPANT	\N	PRESENT	0
692636	692423	11043H	PARTICIPANT	\N	PRESENT	0
692637	692423	17779H	PARTICIPANT	\N	PRESENT	0
692639	692423	14147R	PARTICIPANT	\N	PRESENT	0
697420	695156	19643A	PARTICIPANT	\N	PRESENT	0
697421	695156	20122U	PARTICIPANT	\N	PRESENT	0
697422	695156	11064N	PARTICIPANT	\N	PRESENT	0
697423	695156	19563B	PARTICIPANT	\N	PRESENT	0
697424	695156	19762G	PARTICIPANT	\N	PRESENT	0
697425	695156	14195A	PARTICIPANT	\N	PRESENT	0
697426	695156	19515S	PARTICIPANT	\N	PRESENT	0
697427	695156	20060X	PARTICIPANT	\N	PRESENT	0
697428	695156	14257W	PARTICIPANT	\N	PRESENT	0
697429	695156	20030R	PARTICIPANT	\N	PRESENT	0
697430	695156	17965H	PARTICIPANT	\N	PRESENT	0
697431	695156	19503N	PARTICIPANT	\N	PRESENT	0
697432	695156	14225N	PARTICIPANT	\N	PRESENT	0
697433	695156	19531S	PARTICIPANT	\N	PRESENT	0
697434	695156	20286Q	PARTICIPANT	\N	PRESENT	0
697435	695156	11065P	PARTICIPANT	\N	PRESENT	0
697436	695156	14331P	PARTICIPANT	\N	PRESENT	0
697437	695156	19671E	PARTICIPANT	\N	PRESENT	0
697438	695156	11027H	PARTICIPANT	\N	PRESENT	0
697439	695156	04033B	PARTICIPANT	\N	PRESENT	0
697440	695156	19543W	PARTICIPANT	\N	PRESENT	0
697441	695156	14030Q	PARTICIPANT	\N	PRESENT	0
697442	695156	20042V	PARTICIPANT	\N	PRESENT	0
697443	695156	19826F	PARTICIPANT	\N	PRESENT	0
697444	695156	11085T	PARTICIPANT	\N	PRESENT	0
697445	695156	19721W	PARTICIPANT	\N	PRESENT	0
697446	695156	19569H	PARTICIPANT	\N	PRESENT	0
697447	695156	19713W	PARTICIPANT	\N	PRESENT	0
697448	695156	16685X	PARTICIPANT	\N	PRESENT	0
697449	695156	14205J	PARTICIPANT	\N	PRESENT	0
697450	695156	20052X	PARTICIPANT	\N	PRESENT	0
697451	695156	01043Q	PARTICIPANT	\N	PRESENT	0
697452	695156	19699S	PARTICIPANT	\N	PRESENT	0
697453	695156	14042U	PARTICIPANT	\N	PRESENT	0
697454	695156	20040T	PARTICIPANT	\N	PRESENT	0
697455	695156	20248J	PARTICIPANT	\N	PRESENT	0
697456	695156	19749K	PARTICIPANT	\N	PRESENT	0
697457	695156	20032T	PARTICIPANT	\N	PRESENT	0
697458	695156	19745F	PARTICIPANT	\N	PRESENT	0
697459	695156	01025N	PARTICIPANT	\N	PRESENT	0
697460	695156	14231L	PARTICIPANT	\N	PRESENT	0
697461	695156	19691J	PARTICIPANT	\N	PRESENT	0
697462	695156	11080N	PARTICIPANT	\N	PRESENT	0
697463	695156	14179A	PARTICIPANT	\N	PRESENT	0
697464	695156	14001X	PARTICIPANT	\N	PRESENT	0
697465	695156	14255U	PARTICIPANT	\N	PRESENT	0
697466	695156	14083S	PARTICIPANT	\N	PRESENT	0
697467	695156	18083K	PARTICIPANT	\N	PRESENT	0
697468	695156	14189C	PARTICIPANT	\N	PRESENT	0
697469	695156	14267Y	PARTICIPANT	\N	PRESENT	0
697470	695156	11053K	PARTICIPANT	\N	PRESENT	0
697471	695156	17229F	PARTICIPANT	\N	PRESENT	0
697472	695156	14327T	PARTICIPANT	\N	PRESENT	0
697473	695156	19577H	PARTICIPANT	\N	PRESENT	0
697474	695156	01024M	PARTICIPANT	\N	PRESENT	0
697475	695156	19611R	PARTICIPANT	\N	PRESENT	0
697476	695156	20066E	PARTICIPANT	\N	PRESENT	0
697477	695156	14219Q	PARTICIPANT	\N	PRESENT	0
697478	695156	19735D	PARTICIPANT	\N	PRESENT	0
697479	695156	19335Q	PARTICIPANT	\N	PRESENT	0
697480	695156	19369B	PARTICIPANT	\N	PRESENT	0
697481	695156	04070G	PARTICIPANT	\N	PRESENT	0
697482	695156	04092N	PARTICIPANT	\N	PRESENT	0
697483	695156	19319Q	PARTICIPANT	\N	PRESENT	0
697484	695156	19739H	PARTICIPANT	\N	PRESENT	0
697485	695156	19479G	PARTICIPANT	\N	PRESENT	0
697486	695156	14133K	PARTICIPANT	\N	PRESENT	0
697487	695156	20024T	PARTICIPANT	\N	PRESENT	0
697488	695156	01034P	PARTICIPANT	\N	PRESENT	0
697489	695156	19575F	PARTICIPANT	\N	PRESENT	0
697929	695162	14097Y	PARTICIPANT	\N	PRESENT	0
697491	695156	19619A	PARTICIPANT	\N	PRESENT	0
697492	695156	19367Y	PARTICIPANT	\N	PRESENT	0
697493	695156	14069U	PARTICIPANT	\N	PRESENT	0
697494	695156	19681G	PARTICIPANT	\N	PRESENT	0
697495	695156	19719D	PARTICIPANT	\N	PRESENT	0
697496	695156	20132W	PARTICIPANT	\N	PRESENT	0
697497	695156	11101A	PARTICIPANT	\N	PRESENT	0
697498	695156	20072C	PARTICIPANT	\N	PRESENT	0
697499	695156	11012A	PARTICIPANT	\N	PRESENT	0
697500	695156	14107H	PARTICIPANT	\N	PRESENT	0
697501	695156	07033P	PARTICIPANT	\N	PRESENT	0
697502	695156	14055N	PARTICIPANT	\N	PRESENT	0
697503	695156	14037X	PARTICIPANT	\N	PRESENT	0
697504	695156	20106U	PARTICIPANT	\N	PRESENT	0
697505	695156	19659J	PARTICIPANT	\N	PRESENT	0
697506	695156	20128B	PARTICIPANT	\N	PRESENT	0
697507	695156	19591F	PARTICIPANT	\N	PRESENT	0
697508	695156	04085P	PARTICIPANT	\N	PRESENT	0
697509	695156	19447X	PARTICIPANT	\N	PRESENT	0
697928	695162	20286Q	PARTICIPANT	\N	PRESENT	0
697418	695156	04057K	PARTICIPANT	\N	PRESENT	0
697419	695156	20050V	PARTICIPANT	\N	PRESENT	0
697930	695162	12041X	PARTICIPANT	\N	PRESENT	0
697931	695162	08034U	PARTICIPANT	\N	PRESENT	0
697932	695162	04070G	PARTICIPANT	\N	PRESENT	0
697933	695162	14133K	PARTICIPANT	\N	PRESENT	0
697934	695162	10015M	PARTICIPANT	\N	PRESENT	0
697935	695162	14001X	PARTICIPANT	\N	PRESENT	0
697936	695162	20094J	PARTICIPANT	\N	PRESENT	0
697937	695162	11026G	PARTICIPANT	\N	PRESENT	0
697938	695162	14331P	PRESIDENT	0	PRESENT	0
697939	695162	14237S	PARTICIPANT	\N	PRESENT	0
697940	695162	04045F	PARTICIPANT	\N	PRESENT	0
697941	695162	14357A	PARTICIPANT	\N	PRESENT	0
697942	695162	14089Y	PARTICIPANT	\N	PRESENT	0
697943	695162	04047H	PARTICIPANT	\N	PRESENT	0
697944	695162	05008E	PARTICIPANT	\N	PRESENT	0
697945	695162	11072N	PARTICIPANT	\N	PRESENT	0
697946	695162	95063L	PARTICIPANT	\N	PRESENT	0
697948	695162	19681G	PARTICIPANT	\N	PRESENT	0
697949	695162	14053L	PARTICIPANT	\N	PRESENT	0
697950	695162	20110Q	PARTICIPANT	\N	PRESENT	0
697951	694947	08045X	PARTICIPANT	\N	PRESENT	0
697952	694947	14195A	PARTICIPANT	\N	PRESENT	0
697953	694947	19479G	PARTICIPANT	\N	PRESENT	0
697983	695156	14123H	PARTICIPANT	\N	PRESENT	0
697984	695156	20048C	PARTICIPANT	\N	PRESENT	0
697985	695156	19551W	PARTICIPANT	\N	PRESENT	0
697987	695156	14147R	PARTICIPANT	\N	PRESENT	0
697989	695156	14237S	PARTICIPANT	\N	PRESENT	0
697991	695156	19413M	PARTICIPANT	\N	PRESENT	0
698018	698017	05008E	PARTICIPANT	\N	PRESENT	0
698020	698017	11053K	PARTICIPANT	\N	PRESENT	0
698021	698017	01028R	PARTICIPANT	\N	PRESENT	0
698169	695156	14089Y	PARTICIPANT	\N	PRESENT	0
698215	695158	14231L	PARTICIPANT	\N	PRESENT	0
698216	695158	14069U	PARTICIPANT	\N	PRESENT	0
698217	695158	20180F	PARTICIPANT	\N	PRESENT	0
698218	695158	19599P	PARTICIPANT	\N	PRESENT	0
698219	695158	20132W	PARTICIPANT	\N	PRESENT	0
698220	695158	20056C	PARTICIPANT	\N	PRESENT	0
698221	695158	19719D	PARTICIPANT	\N	PRESENT	0
698222	695158	11097X	PARTICIPANT	\N	PRESENT	0
698223	695158	04043D	PARTICIPANT	\N	PRESENT	0
698224	695158	19701S	PARTICIPANT	\N	PRESENT	0
698225	695158	10006L	PARTICIPANT	\N	PRESENT	0
698226	695158	19563B	PARTICIPANT	\N	PRESENT	0
698231	695158	20052X	PARTICIPANT	\N	PRESENT	0
698232	695158	01057W	PARTICIPANT	\N	PRESENT	0
687283	686703	14237S	PARTICIPANT	\N	PRESENT	0
687284	686703	11067R	PARTICIPANT	\N	PRESENT	0
687285	686703	19503N	PARTICIPANT	\N	PRESENT	0
687286	686703	20082E	PARTICIPANT	\N	PRESENT	0
687287	686703	19413M	PARTICIPANT	\N	PRESENT	0
687288	686703	20024T	PARTICIPANT	\N	PRESENT	0
687289	686703	20100N	PARTICIPANT	\N	PRESENT	0
687290	686703	14071N	PARTICIPANT	\N	PRESENT	0
687291	686703	14195A	PARTICIPANT	\N	PRESENT	0
687292	686703	08010L	PARTICIPANT	\N	PRESENT	0
687293	686703	19760E	PARTICIPANT	\N	PRESENT	0
687294	686703	20046A	PARTICIPANT	\N	PRESENT	0
687295	686703	19691J	PARTICIPANT	\N	PRESENT	0
687296	686703	19679N	PARTICIPANT	\N	PRESENT	0
687300	686703	10006L	PARTICIPANT	\N	PRESENT	0
687298	686703	14147R	PARTICIPANT	\N	PRESENT	0
687299	686703	19637C	PARTICIPANT	\N	PRESENT	0
687301	686703	19701S	PARTICIPANT	\N	PRESENT	0
687302	686703	20090E	PARTICIPANT	\N	PRESENT	0
687303	686703	19531S	PARTICIPANT	\N	PRESENT	0
687304	686703	19507S	PARTICIPANT	\N	PRESENT	0
687305	686703	19798U	PARTICIPANT	\N	PRESENT	0
687306	686703	19347U	PARTICIPANT	\N	PRESENT	0
687353	687352	14193X	PARTICIPANT	\N	PRESENT	0
687354	687352	01062T	PARTICIPANT	\N	PRESENT	0
687355	687352	14097Y	PARTICIPANT	\N	PRESENT	0
689124	688394	20096L	PARTICIPANT	\N	PRESENT	0
689125	688394	20106U	PARTICIPANT	\N	PRESENT	0
689126	688394	08060W	PARTICIPANT	\N	PRESENT	0
689127	688394	19685L	PARTICIPANT	\N	PRESENT	0
689128	688394	20140W	PARTICIPANT	\N	PRESENT	0
689129	688394	19745F	PARTICIPANT	\N	PRESENT	0
689130	688646	12041X	PARTICIPANT	\N	PRESENT	0
689131	688646	19954N	PARTICIPANT	\N	PRESENT	0
689132	688646	20062A	PARTICIPANT	\N	PRESENT	0
689172	688646	19647E	PARTICIPANT	\N	PRESENT	0
689173	688394	20136B	PARTICIPANT	\N	PRESENT	0
687281	686703	11070L	PARTICIPANT	\N	PRESENT	0
687282	686703	14219Q	PARTICIPANT	\N	PRESENT	0
689174	688646	19563B	PARTICIPANT	\N	PRESENT	0
689175	688394	20100N	PARTICIPANT	\N	PRESENT	0
689176	688646	20070A	PARTICIPANT	\N	PRESENT	0
689177	688646	20066E	PARTICIPANT	\N	PRESENT	0
689139	688646	14147R	PARTICIPANT	\N	PRESENT	0
689179	688646	14031R	PARTICIPANT	\N	PRESENT	0
689180	689178	19723Y	PARTICIPANT	\N	PRESENT	0
689142	688646	19693L	PARTICIPANT	\N	PRESENT	0
689143	688646	19747H	PARTICIPANT	\N	PRESENT	0
689181	688646	11031D	PARTICIPANT	\N	PRESENT	0
689182	688646	17965H	PARTICIPANT	\N	PRESENT	0
689146	688646	19569H	PARTICIPANT	\N	PRESENT	0
689183	688394	19387D	PARTICIPANT	\N	PRESENT	0
689184	688394	14033T	PARTICIPANT	\N	PRESENT	0
689186	688646	11067R	PARTICIPANT	\N	PRESENT	0
689150	688646	19782L	PARTICIPANT	\N	PRESENT	0
689187	688646	14026U	PARTICIPANT	\N	PRESENT	0
689152	688646	19719D	PARTICIPANT	\N	PRESENT	0
689188	688646	14109K	PARTICIPANT	\N	PRESENT	0
689154	688646	20088L	PARTICIPANT	\N	PRESENT	0
689155	688646	14281W	PARTICIPANT	\N	PRESENT	0
689156	688646	20116W	PARTICIPANT	\N	PRESENT	0
689157	688646	97011G	PARTICIPANT	\N	PRESENT	0
689189	688646	19525U	PARTICIPANT	\N	PRESENT	0
689190	688394	19599P	PARTICIPANT	\N	PRESENT	0
689160	688646	19467C	PARTICIPANT	\N	PRESENT	0
689161	688646	20130U	PARTICIPANT	\N	PRESENT	0
689191	688646	18193Q	PARTICIPANT	\N	PRESENT	0
689163	688646	20028X	PARTICIPANT	\N	PRESENT	0
689164	688646	14257W	PARTICIPANT	\N	PRESENT	0
689165	688646	20082E	PARTICIPANT	\N	PRESENT	0
689166	688646	20080C	PARTICIPANT	\N	PRESENT	0
689167	688646	19631V	PARTICIPANT	\N	PRESENT	0
689168	688646	20092G	PARTICIPANT	\N	PRESENT	0
689169	688646	14133K	PARTICIPANT	\N	PRESENT	0
689170	688646	20104S	PARTICIPANT	\N	PRESENT	0
689171	688394	05012A	PARTICIPANT	\N	PRESENT	0
689195	688646	08045X	PARTICIPANT	\N	PRESENT	0
689196	688646	14225N	PARTICIPANT	\N	PRESENT	0
689197	688646	20094J	PARTICIPANT	\N	PRESENT	0
689198	688646	14069U	PARTICIPANT	\N	PRESENT	0
689199	688646	14073Q	PARTICIPANT	\N	PRESENT	0
689200	688394	11065P	PARTICIPANT	\N	PRESENT	0
689201	688646	14217N	PARTICIPANT	\N	PRESENT	0
689205	688646	14083S	PARTICIPANT	\N	PRESENT	0
689203	688646	19723Y	PARTICIPANT	\N	PRESENT	0
689204	688646	19533U	PARTICIPANT	\N	PRESENT	0
689206	688646	01024M	PARTICIPANT	\N	PRESENT	0
689207	688646	19515S	PARTICIPANT	\N	PRESENT	0
689208	688646	20128B	PARTICIPANT	\N	PRESENT	0
689209	688646	19251M	PARTICIPANT	\N	PRESENT	0
689210	688646	20052X	PARTICIPANT	\N	PRESENT	0
689211	688646	20024T	PARTICIPANT	\N	PRESENT	0
689212	688646	18083K	PARTICIPANT	\N	PRESENT	0
689213	688646	20140W	PARTICIPANT	\N	PRESENT	0
689214	688646	14231L	PARTICIPANT	\N	PRESENT	0
689215	688646	20060X	PARTICIPANT	\N	PRESENT	0
689216	688646	14033T	PARTICIPANT	\N	PRESENT	0
689217	688646	19383Y	PARTICIPANT	\N	PRESENT	0
689256	688647	19515S	PARTICIPANT	\N	PRESENT	0
689257	688647	20060X	PARTICIPANT	\N	PRESENT	0
689258	688647	20044X	PARTICIPANT	\N	PRESENT	0
689259	688647	14037X	PARTICIPANT	\N	PRESENT	0
689260	688647	18083K	PARTICIPANT	\N	PRESENT	0
689261	688647	01025N	PARTICIPANT	\N	PRESENT	0
689262	688647	19545Y	PARTICIPANT	\N	PRESENT	0
689263	688647	14089Y	PARTICIPANT	\N	PRESENT	0
689264	688647	14030Q	PARTICIPANT	\N	PRESENT	0
689265	688647	20094J	PARTICIPANT	\N	PRESENT	0
689266	688647	19575F	PARTICIPANT	\N	PRESENT	0
689267	688647	19415P	PARTICIPANT	\N	PRESENT	0
689268	688647	16685X	PARTICIPANT	\N	PRESENT	0
689269	688647	20030R	PARTICIPANT	\N	PRESENT	0
689270	688647	19758L	PARTICIPANT	\N	PRESENT	0
689271	688647	14207L	PARTICIPANT	\N	PRESENT	0
689272	688647	20018V	PARTICIPANT	\N	PRESENT	0
689273	688647	14069U	PARTICIPANT	\N	PRESENT	0
689274	688647	19369B	PARTICIPANT	\N	PRESENT	0
689275	688647	19479G	PARTICIPANT	\N	PRESENT	0
689276	688647	14147R	PARTICIPANT	\N	PRESENT	0
689277	688647	20082E	PARTICIPANT	\N	PRESENT	0
689278	688647	19387D	PARTICIPANT	\N	PRESENT	0
689313	688764	10006L	PRESIDENT	0	PRESENT	0
689314	688764	19683J	PARTICIPANT	\N	PRESENT	0
689315	688764	08045X	PARTICIPANT	\N	PRESENT	0
689316	688764	17965H	PARTICIPANT	\N	PRESENT	0
689317	688764	14223L	PARTICIPANT	\N	PRESENT	0
689318	688764	14213J	PARTICIPANT	\N	PRESENT	0
689319	688764	19713W	PARTICIPANT	\N	PRESENT	0
689320	688764	14071N	PARTICIPANT	\N	PRESENT	0
689321	688764	20248J	PARTICIPANT	\N	PRESENT	0
689322	688764	14217N	PARTICIPANT	\N	PRESENT	0
689323	688764	20090E	PARTICIPANT	\N	PRESENT	0
689324	688764	11097X	PARTICIPANT	\N	PRESENT	0
689325	688764	04092N	PARTICIPANT	\N	PRESENT	0
689254	688647	01043Q	PARTICIPANT	\N	PRESENT	0
689255	688647	20134Y	PARTICIPANT	\N	PRESENT	0
689326	688764	19415P	PARTICIPANT	\N	PRESENT	0
689327	688764	14195A	PARTICIPANT	\N	PRESENT	0
689328	688764	19367Y	PARTICIPANT	\N	PRESENT	0
689329	688764	19703U	PARTICIPANT	\N	PRESENT	0
689330	688764	19329S	PARTICIPANT	\N	PRESENT	0
689331	688764	14042U	PARTICIPANT	\N	PRESENT	0
689332	688764	11067R	PARTICIPANT	\N	PRESENT	0
689333	688764	14026U	PARTICIPANT	\N	PRESENT	0
689336	688764	11031D	PARTICIPANT	\N	PRESENT	0
689337	688764	19657G	PARTICIPANT	\N	PRESENT	0
689338	688764	19569H	PARTICIPANT	\N	PRESENT	0
689339	688764	19691J	PARTICIPANT	\N	PRESENT	0
689340	688764	20148F	PARTICIPANT	\N	PRESENT	0
689341	688764	17779H	PARTICIPANT	\N	PRESENT	0
689342	688764	19679N	PARTICIPANT	\N	PRESENT	0
689343	688842	14053L	PARTICIPANT	\N	PRESENT	0
689344	688842	19725B	PARTICIPANT	\N	PRESENT	0
689345	688842	14179A	PARTICIPANT	\N	PRESENT	0
689346	688842	19649G	PARTICIPANT	\N	PRESENT	0
689347	688842	20110Q	PARTICIPANT	\N	PRESENT	0
689349	689348	14053L	PARTICIPANT	\N	PRESENT	0
689350	689348	19725B	PARTICIPANT	\N	PRESENT	0
689351	689348	19649G	PARTICIPANT	\N	PRESENT	0
689352	689348	20110Q	PARTICIPANT	\N	PRESENT	0
689385	688764	20040T	PARTICIPANT	\N	PRESENT	0
704777	704776	17737W	PARTICIPANT	\N	PRESENT	0
704778	704776	19717B	PARTICIPANT	\N	PRESENT	0
704779	704776	04092N	PARTICIPANT	\N	PRESENT	0
704781	704780	17737W	PARTICIPANT	\N	PRESENT	0
704782	704780	04092N	PARTICIPANT	\N	PRESENT	0
704783	704780	19717B	PARTICIPANT	\N	PRESENT	0
704784	704215	11031D	PARTICIPANT	\N	PRESENT	0
704785	704215	19735D	PRESIDENT	0	PRESENT	0
704786	704215	17965H	PARTICIPANT	\N	PRESENT	0
704787	704215	14213J	PARTICIPANT	\N	PRESENT	0
704788	704215	20096L	PARTICIPANT	\N	PRESENT	0
704789	704215	20066E	PARTICIPANT	\N	PRESENT	0
704790	704215	20050V	PARTICIPANT	\N	EXCUSE	0
704791	704215	19369B	PARTICIPANT	\N	EXCUSE	0
704792	704215	20024T	PARTICIPANT	\N	EXCUSE	0
704793	704215	20126Y	PARTICIPANT	\N	EXCUSE	0
704794	704215	14026U	PARTICIPANT	\N	PRESENT	0
704795	704215	20138D	PRESIDENT	1	PRESENT	0
704796	703792	20022R	PARTICIPANT	\N	PRESENT	0
704797	703792	19673G	PARTICIPANT	\N	PRESENT	0
704803	703792	19729F	PARTICIPANT	\N	PRESENT	0
704804	703792	14151M	PARTICIPANT	\N	PRESENT	0
704807	703792	20074E	PARTICIPANT	\N	PRESENT	0
704810	703792	19581D	PARTICIPANT	\N	PRESENT	0
704817	703792	04047H	PRESIDENT	0	PRESENT	0
704818	703792	19489J	PARTICIPANT	\N	PRESENT	0
704819	703792	19649G	PARTICIPANT	\N	PRESENT	0
704820	703792	14147R	PARTICIPANT	\N	PRESENT	0
704821	703792	14215L	PARTICIPANT	\N	PRESENT	0
704827	703792	19447X	PARTICIPANT	\N	PRESENT	0
704828	703792	14001X	PARTICIPANT	\N	PRESENT	0
704872	704870	19533U	PARTICIPANT	\N	PRESENT	0
705027	704078	20130U	PARTICIPANT	\N	PRESENT	0
705028	704078	08047A	PARTICIPANT	\N	PRESENT	0
705029	704078	20048C	PARTICIPANT	\N	PRESENT	0
705030	704078	17779H	PARTICIPANT	\N	PRESENT	0
705031	704078	04035D	PARTICIPANT	\N	PRESENT	0
705032	704078	11056N	PARTICIPANT	\N	PRESENT	0
705033	704078	20028X	PARTICIPANT	\N	PRESENT	0
705034	704078	20126Y	PARTICIPANT	\N	PRESENT	0
705035	704078	19489J	PARTICIPANT	\N	PRESENT	0
705036	704078	14001X	PARTICIPANT	\N	PRESENT	0
705037	704078	19768N	PARTICIPANT	\N	PRESENT	0
705038	704078	11066Q	PARTICIPANT	\N	PRESENT	0
705039	704078	08018U	PARTICIPANT	\N	PRESENT	0
705040	704078	11041F	PARTICIPANT	\N	PRESENT	0
705041	704078	20064C	PARTICIPANT	\N	PRESENT	0
705042	704078	01062T	PARTICIPANT	\N	PRESENT	0
705043	704078	19413M	PARTICIPANT	\N	PRESENT	0
705044	704078	14053L	PARTICIPANT	\N	PRESENT	0
705045	704078	14111D	PARTICIPANT	\N	PRESENT	0
705046	704078	17023S	PARTICIPANT	\N	PRESENT	0
705047	704078	14083S	PARTICIPANT	\N	PRESENT	0
705048	704078	19685L	PARTICIPANT	\N	PRESENT	0
705049	704078	19335Q	PARTICIPANT	\N	PRESENT	0
705050	704078	11070L	PARTICIPANT	\N	PRESENT	0
705051	704078	19826F	PARTICIPANT	\N	PRESENT	0
705052	704078	20040T	PARTICIPANT	\N	PRESENT	0
705053	704078	14089Y	PARTICIPANT	\N	PRESENT	0
705054	704078	07004J	PARTICIPANT	\N	PRESENT	0
705055	704078	04085P	PARTICIPANT	\N	PRESENT	0
705056	704078	19735D	PARTICIPANT	\N	PRESENT	0
705057	704078	20080C	PARTICIPANT	\N	PRESENT	0
705058	704078	20980G	PARTICIPANT	\N	PRESENT	0
705059	704078	11026G	PARTICIPANT	\N	PRESENT	0
705060	704078	08012N	PARTICIPANT	\N	PRESENT	0
705061	704078	11067R	PARTICIPANT	\N	PRESENT	0
705062	704078	20018V	PARTICIPANT	\N	PRESENT	0
705063	704078	19503N	PARTICIPANT	\N	PRESENT	0
705067	704078	20052X	PARTICIPANT	\N	PRESENT	0
705065	704078	14225N	PARTICIPANT	\N	PRESENT	0
705066	704078	17965H	PARTICIPANT	\N	PRESENT	0
705068	704078	19699S	PARTICIPANT	\N	PRESENT	0
705069	704078	19347U	PARTICIPANT	\N	PRESENT	0
705070	704078	14042U	PARTICIPANT	\N	PRESENT	0
705071	704078	14123H	PARTICIPANT	\N	PRESENT	0
705072	704078	20266L	PARTICIPANT	\N	PRESENT	0
705073	704078	19619A	PARTICIPANT	\N	PRESENT	0
705074	704078	20042V	PARTICIPANT	\N	PRESENT	0
705075	704078	11072N	PARTICIPANT	\N	PRESENT	0
705076	704078	19301E	PARTICIPANT	\N	PRESENT	0
705077	704078	19657G	PARTICIPANT	\N	PRESENT	0
705078	704078	20248J	PARTICIPANT	\N	PRESENT	0
705079	704078	14219Q	PARTICIPANT	\N	PRESENT	0
705080	704078	19441R	PARTICIPANT	\N	PRESENT	0
705081	704078	19721W	PARTICIPANT	\N	PRESENT	0
705082	704078	20144B	PARTICIPANT	\N	PRESENT	0
705083	704078	14030Q	PARTICIPANT	\N	PRESENT	0
705084	704078	14189C	PARTICIPANT	\N	PRESENT	0
705085	704078	14327T	PARTICIPANT	\N	PRESENT	0
705086	704078	01024M	PARTICIPANT	\N	PRESENT	0
705087	704078	14231L	PARTICIPANT	\N	PRESENT	0
705088	704078	01025N	PARTICIPANT	\N	PRESENT	0
705089	704078	19691J	PARTICIPANT	\N	PRESENT	0
705090	704078	11053K	PARTICIPANT	\N	PRESENT	0
705091	704078	19369B	PARTICIPANT	\N	PRESENT	0
705092	704078	20066E	PARTICIPANT	\N	PRESENT	0
705093	704078	14179A	PARTICIPANT	\N	PRESENT	0
705094	704078	14205J	PARTICIPANT	\N	PRESENT	0
705095	704078	16685X	PARTICIPANT	\N	PRESENT	0
705096	704078	01043Q	PARTICIPANT	\N	PRESENT	0
705097	704078	19611R	PARTICIPANT	\N	PRESENT	0
705098	704078	11085T	PARTICIPANT	\N	PRESENT	0
705099	704078	04070G	PARTICIPANT	\N	PRESENT	0
705100	704078	19739H	PARTICIPANT	\N	PRESENT	0
705101	704078	19479G	PARTICIPANT	\N	PRESENT	0
705102	704078	19745F	PARTICIPANT	\N	PRESENT	0
705103	704078	19599P	PARTICIPANT	\N	PRESENT	0
705104	704078	20094J	PARTICIPANT	\N	PRESENT	0
705106	704078	19729F	PARTICIPANT	\N	PRESENT	0
705108	704078	20044X	PARTICIPANT	\N	PRESENT	0
705109	704078	20286Q	PARTICIPANT	\N	PRESENT	0
705110	704078	11040E	PARTICIPANT	\N	PRESENT	0
705111	704078	19553Y	PARTICIPANT	\N	PRESENT	0
705115	704078	19563B	PARTICIPANT	\N	PRESENT	0
705116	704078	20138D	PARTICIPANT	\N	PRESENT	0
705117	704078	20120S	PARTICIPANT	\N	PRESENT	0
705118	704078	10015M	PARTICIPANT	\N	PRESENT	0
705119	704078	19421M	PARTICIPANT	\N	PRESENT	0
705120	704078	19675J	PARTICIPANT	\N	PRESENT	0
705121	704078	19749K	PARTICIPANT	\N	PRESENT	0
705125	704078	08060W	PARTICIPANT	\N	PRESENT	0
705409	704079	99004R	PARTICIPANT	\N	PRESENT	0
705410	704079	11031D	PARTICIPANT	\N	PRESENT	0
705411	704079	20080C	PARTICIPANT	\N	PRESENT	0
705412	704079	19565D	PARTICIPANT	\N	PRESENT	0
705413	704079	11040E	PARTICIPANT	\N	PRESENT	0
705414	704079	19715Y	PARTICIPANT	\N	PRESENT	0
705415	704079	14121F	PARTICIPANT	\N	PRESENT	0
705416	704079	20036X	PARTICIPANT	\N	PRESENT	0
705417	704079	11012A	PARTICIPANT	\N	PRESENT	0
705418	704079	20128B	PARTICIPANT	\N	PRESENT	0
705419	704079	19553Y	PARTICIPANT	\N	PRESENT	0
705420	704079	14107H	PARTICIPANT	\N	PRESENT	0
705421	704079	19251M	PARTICIPANT	\N	PRESENT	0
705422	704079	20152B	PARTICIPANT	\N	PRESENT	0
705423	704079	14073Q	PARTICIPANT	\N	PRESENT	0
705424	704079	97011G	PARTICIPANT	\N	PRESENT	0
705425	704079	20108W	PARTICIPANT	\N	PRESENT	0
705426	704079	10015M	PARTICIPANT	\N	PRESENT	0
705427	704079	19515S	PARTICIPANT	\N	PRESENT	0
705428	704079	20038A	PARTICIPANT	\N	PRESENT	0
705429	704079	14173T	PARTICIPANT	\N	PRESENT	0
705430	704079	20100N	PARTICIPANT	\N	PRESENT	0
705431	704079	19413M	PARTICIPANT	\N	PRESENT	0
705432	704079	19745F	PARTICIPANT	\N	PRESENT	0
705433	704079	14055N	PARTICIPANT	\N	PRESENT	0
705434	704079	20050V	PARTICIPANT	\N	PRESENT	0
705435	704079	19631V	PARTICIPANT	\N	PRESENT	0
705436	704079	19629C	PARTICIPANT	\N	PRESENT	0
705437	704079	19599P	PARTICIPANT	\N	PRESENT	0
705438	704079	20082E	PARTICIPANT	\N	PRESENT	0
705439	704079	14257W	PARTICIPANT	\N	PRESENT	0
705440	704079	14069U	PARTICIPANT	\N	PRESENT	0
705441	704079	20124W	PARTICIPANT	\N	PRESENT	0
705442	704079	11053K	PARTICIPANT	\N	PRESENT	0
705443	704079	14189C	PARTICIPANT	\N	PRESENT	0
705444	704079	01024M	PARTICIPANT	\N	PRESENT	0
705445	704079	19383Y	PARTICIPANT	\N	PRESENT	0
705446	704245	19467C	PARTICIPANT	\N	EXCUSE	0
685031	683640	20082E	PARTICIPANT	\N	EXCUSE	0
685032	683640	14205J	PARTICIPANT	\N	EXCUSE	0
685033	683640	19383Y	PARTICIPANT	\N	EXCUSE	0
686261	686260	14231L	PRESIDENT	0	PRESENT	0
686262	686260	19826F	PARTICIPANT	\N	PRESENT	0
686263	686260	20022R	PARTICIPANT	\N	PRESENT	0
686264	686260	08010L	PARTICIPANT	\N	PRESENT	0
686265	686260	19333N	PARTICIPANT	\N	PRESENT	0
686266	686260	17637T	PARTICIPANT	\N	PRESENT	0
686267	686260	20058E	PARTICIPANT	\N	PRESENT	0
686268	686260	19573D	PARTICIPANT	\N	PRESENT	0
686269	686260	19565D	PARTICIPANT	\N	PRESENT	0
686270	686260	01057W	PARTICIPANT	\N	PRESENT	0
686271	686260	20062A	PARTICIPANT	\N	PRESENT	0
686272	686260	19758L	PARTICIPANT	\N	PRESENT	0
686273	686260	04045F	PARTICIPANT	\N	PRESENT	0
686274	686260	20110Q	PARTICIPANT	\N	PRESENT	0
686275	686260	20084G	PARTICIPANT	\N	PRESENT	0
686276	686260	19489J	PARTICIPANT	\N	PRESENT	0
686277	686260	20090E	PARTICIPANT	\N	EXCUSE	0
686278	686260	14053L	PARTICIPANT	\N	EXCUSE	0
686279	686260	19681G	PARTICIPANT	\N	EXCUSE	0
686280	686260	19735D	PARTICIPANT	\N	EXCUSE	0
686281	686260	14327T	PARTICIPANT	\N	EXCUSE	0
686282	686260	14217N	PARTICIPANT	\N	EXCUSE	0
686283	686260	14215L	PARTICIPANT	\N	EXCUSE	0
686284	686260	14281W	PARTICIPANT	\N	EXCUSE	0
686285	686260	19447X	PARTICIPANT	\N	EXCUSE	0
686286	686260	19563B	PARTICIPANT	\N	EXCUSE	0
686287	686260	14071N	PARTICIPANT	\N	EXCUSE	0
686288	686260	05012A	PARTICIPANT	\N	EXCUSE	0
686289	686260	20122U	PARTICIPANT	\N	EXCUSE	0
686303	686260	20070A	PARTICIPANT	\N	PRESENT	0
686304	686260	19349W	PARTICIPANT	\N	PRESENT	0
686332	686260	19820Y	PARTICIPANT	\N	PRESENT	0
688746	688745	19319Q	PARTICIPANT	\N	EXCUSE	0
688747	688745	19659J	PARTICIPANT	\N	EXCUSE	0
688748	688745	19717B	PRESIDENT	0	PRESENT	0
688749	688745	11010L	PARTICIPANT	\N	EXCUSE	0
688750	688745	19577H	PARTICIPANT	\N	EXCUSE	0
688751	688745	14275Y	PARTICIPANT	\N	EXCUSE	0
688752	688745	20034V	PARTICIPANT	\N	PRESENT	0
688753	688745	14259Y	PARTICIPANT	\N	EXCUSE	0
692641	692423	14169X	PARTICIPANT	\N	PRESENT	0
692642	692423	14089Y	PARTICIPANT	\N	PRESENT	0
692643	692423	19798U	PARTICIPANT	\N	PRESENT	0
692644	692423	20264J	PARTICIPANT	\N	PRESENT	0
692645	691220	20042V	PARTICIPANT	\N	EXCUSE	0
692646	691220	08012N	PARTICIPANT	\N	EXCUSE	0
692647	691220	11040E	PARTICIPANT	\N	EXCUSE	0
692648	691220	20144B	PARTICIPANT	\N	EXCUSE	0
692649	691220	20018V	PARTICIPANT	\N	PRESENT	0
692650	692388	19735D	PARTICIPANT	\N	EXCUSE	0
692651	692423	20172F	PARTICIPANT	\N	PRESENT	0
692652	692423	19399H	PARTICIPANT	\N	PRESENT	0
692653	692423	11066Q	PARTICIPANT	\N	PRESENT	0
692654	692423	19479G	PARTICIPANT	\N	PRESENT	0
692655	692423	14042U	PARTICIPANT	\N	PRESENT	0
692657	692423	19725B	PARTICIPANT	\N	PRESENT	0
692658	692423	20096L	PARTICIPANT	\N	PRESENT	0
692659	692423	11054L	PARTICIPANT	\N	PRESENT	0
692660	692423	19691J	PARTICIPANT	\N	PRESENT	0
692661	692423	20044X	PARTICIPANT	\N	PRESENT	0
692662	692423	19758L	PARTICIPANT	\N	PRESENT	0
692663	692423	19593H	PARTICIPANT	\N	PRESENT	0
692664	692423	14053L	PARTICIPANT	\N	PRESENT	0
692679	692638	19593H	PARTICIPANT	\N	PRESENT	0
692680	692638	19649G	PARTICIPANT	\N	PRESENT	0
692681	692638	19583F	PARTICIPANT	\N	PRESENT	0
692682	692638	14331P	PARTICIPANT	\N	PRESENT	0
692683	692638	14105F	PARTICIPANT	\N	PRESENT	0
692684	692638	11043H	PARTICIPANT	\N	PRESENT	0
692677	692638	86034E	PARTICIPANT	\N	PRESENT	0
692678	692638	19629C	PARTICIPANT	\N	PRESENT	0
692685	692638	19766L	PARTICIPANT	\N	PRESENT	0
692686	692638	14191V	PARTICIPANT	\N	PRESENT	0
692687	692638	19683J	PARTICIPANT	\N	PRESENT	0
692688	692638	11077T	PARTICIPANT	\N	PRESENT	0
692689	692638	19569H	PARTICIPANT	\N	PRESENT	0
692690	692638	19619A	PARTICIPANT	\N	PRESENT	0
692691	692638	19511N	PARTICIPANT	\N	PRESENT	0
692692	692638	20102Q	PARTICIPANT	\N	PRESENT	0
692693	692638	20980G	PARTICIPANT	\N	PRESENT	0
692694	692638	01058X	PARTICIPANT	\N	PRESENT	0
692696	692638	99004R	PARTICIPANT	\N	PRESENT	0
692744	692638	19667J	PARTICIPANT	\N	PRESENT	0
692698	692638	11040E	PARTICIPANT	\N	PRESENT	0
692699	692638	20076G	PARTICIPANT	\N	PRESENT	0
692700	692638	18083K	PARTICIPANT	\N	PRESENT	0
692701	692638	20018V	PARTICIPANT	\N	PRESENT	0
692702	692638	14038Y	PARTICIPANT	\N	PRESENT	0
692703	692638	20046A	PARTICIPANT	\N	PRESENT	0
692704	692638	20044X	PARTICIPANT	\N	PRESENT	0
692705	692638	20034V	PARTICIPANT	\N	PRESENT	0
692706	692638	20070A	PARTICIPANT	\N	PRESENT	0
692707	692638	19701S	PARTICIPANT	\N	PRESENT	0
692708	692638	20074E	PARTICIPANT	\N	PRESENT	0
692709	692638	19758L	PARTICIPANT	\N	PRESENT	0
692710	692638	19760E	PARTICIPANT	\N	PRESENT	0
692711	692638	19467C	PARTICIPANT	\N	PRESENT	0
692712	692638	19573D	PARTICIPANT	\N	PRESENT	0
692713	692638	04085P	PARTICIPANT	\N	PRESENT	0
692714	692638	12041X	PARTICIPANT	\N	PRESENT	0
692715	692638	19695N	PARTICIPANT	\N	PRESENT	0
692716	692638	20060X	PARTICIPANT	\N	PRESENT	0
692717	692638	19251M	PARTICIPANT	\N	PRESENT	0
692718	692638	20088L	PARTICIPANT	\N	PRESENT	0
692719	692638	20112S	PARTICIPANT	\N	PRESENT	0
692720	692638	17965H	PARTICIPANT	\N	PRESENT	0
692721	692638	19673G	PARTICIPANT	\N	PRESENT	0
692722	692638	14031R	PARTICIPANT	\N	PRESENT	0
692723	692638	18193Q	PARTICIPANT	\N	PRESENT	0
692724	692638	14033T	PARTICIPANT	\N	PRESENT	0
692725	692638	14071N	PARTICIPANT	\N	PRESENT	0
692726	692638	19741B	PARTICIPANT	\N	PRESENT	0
692727	692638	14355X	PARTICIPANT	\N	PRESENT	0
692728	692638	17737W	PARTICIPANT	\N	PRESENT	0
692729	692638	19707Y	PARTICIPANT	\N	PRESENT	0
692730	692638	19705W	PARTICIPANT	\N	PRESENT	0
692731	692638	20024T	PARTICIPANT	\N	PRESENT	0
692732	692638	20172F	PARTICIPANT	\N	PRESENT	0
692733	692638	08047A	PARTICIPANT	\N	PRESENT	0
692734	692638	20140W	PARTICIPANT	\N	PRESENT	0
692735	692638	20082E	PARTICIPANT	\N	PRESENT	0
692736	692638	14259Y	PARTICIPANT	\N	PRESENT	0
692737	692638	19599P	PARTICIPANT	\N	PRESENT	0
692738	692638	14253S	PARTICIPANT	\N	PRESENT	0
692739	692638	12028B	PARTICIPANT	\N	PRESENT	0
692740	692638	01057W	PARTICIPANT	\N	PRESENT	0
692741	692638	20068G	PARTICIPANT	\N	PRESENT	0
692742	692638	11056N	PARTICIPANT	\N	PRESENT	0
692743	692638	05012A	PARTICIPANT	\N	PRESENT	0
692746	692638	11080N	PARTICIPANT	\N	PRESENT	0
692747	692638	11065P	PARTICIPANT	\N	PRESENT	0
692748	692638	20100N	PARTICIPANT	\N	PRESENT	0
692749	692638	19347U	PARTICIPANT	\N	PRESENT	0
692750	692638	20142Y	PARTICIPANT	\N	PRESENT	0
692751	692638	20130U	PARTICIPANT	\N	PRESENT	0
692752	692638	20092G	PARTICIPANT	\N	PRESENT	0
692753	692638	19515S	PARTICIPANT	\N	PRESENT	0
692754	692638	20266L	PARTICIPANT	\N	PRESENT	0
692755	692638	19651A	PARTICIPANT	\N	PRESENT	0
692756	692638	19782L	PARTICIPANT	\N	PRESENT	0
692757	692638	19525U	PARTICIPANT	\N	PRESENT	0
692758	692638	14169X	PARTICIPANT	\N	PRESENT	0
692759	692638	11083R	PARTICIPANT	\N	PRESENT	0
692760	692638	10015M	PARTICIPANT	\N	PRESENT	0
692761	692638	20022R	PARTICIPANT	\N	PRESENT	0
692762	692638	08028W	PARTICIPANT	\N	PRESENT	0
692763	692638	14187A	PARTICIPANT	\N	PRESENT	0
692764	692638	07033P	PARTICIPANT	\N	PRESENT	0
692765	692638	19591F	PARTICIPANT	\N	PRESENT	0
692766	692638	20016T	PARTICIPANT	\N	PRESENT	0
692767	692638	14053L	PARTICIPANT	\N	PRESENT	0
692768	692638	19697Q	PARTICIPANT	\N	PRESENT	0
692769	692638	19637C	PARTICIPANT	\N	PRESENT	0
692770	692638	11090Q	PARTICIPANT	\N	PRESENT	0
692771	692638	08073C	PARTICIPANT	\N	PRESENT	0
692772	692638	08061X	PARTICIPANT	\N	PRESENT	0
692773	692638	19798U	PARTICIPANT	\N	PRESENT	0
697968	697967	20088L	PARTICIPANT	\N	PRESENT	0
697969	697967	19369B	PARTICIPANT	\N	PRESENT	0
697970	697967	14169X	PARTICIPANT	\N	PRESENT	0
697971	697967	20062A	PARTICIPANT	\N	PRESENT	0
698381	695159	18083K	PARTICIPANT	\N	PRESENT	0
698382	695159	19657G	PARTICIPANT	\N	PRESENT	0
698383	695159	11056N	PARTICIPANT	\N	PRESENT	0
698384	695159	10006L	PARTICIPANT	\N	PRESENT	0
698385	695159	14026U	PARTICIPANT	\N	PRESENT	0
698386	695159	19349W	PARTICIPANT	\N	PRESENT	0
698387	695159	14207L	PARTICIPANT	\N	PRESENT	0
698388	695159	17779H	PARTICIPANT	\N	PRESENT	0
698389	695159	19413M	PARTICIPANT	\N	PRESENT	0
698390	695159	19531S	PARTICIPANT	\N	PRESENT	0
698391	695159	20102Q	PARTICIPANT	\N	PRESENT	0
698392	695159	20040T	PARTICIPANT	\N	PRESENT	0
698393	695159	20126Y	PARTICIPANT	\N	PRESENT	0
698394	695159	19782L	PARTICIPANT	\N	PRESENT	0
698395	695159	19347U	PARTICIPANT	\N	PRESENT	0
698396	695159	20122U	PARTICIPANT	\N	PRESENT	0
698397	695159	07029T	PARTICIPANT	\N	PRESENT	0
698398	695159	20032T	PARTICIPANT	\N	PRESENT	0
698399	695159	20090E	PARTICIPANT	\N	PRESENT	0
698400	695159	20118Y	PARTICIPANT	\N	PRESENT	0
698401	695159	17965H	PARTICIPANT	\N	PRESENT	0
698402	695159	20180F	PARTICIPANT	\N	PRESENT	0
698403	695159	20130U	PARTICIPANT	\N	PRESENT	0
698404	695159	19621T	PARTICIPANT	\N	PRESENT	0
698405	695159	14069U	PARTICIPANT	\N	PRESENT	0
698406	695159	20092G	PARTICIPANT	\N	PRESENT	0
698407	695159	11110B	PARTICIPANT	\N	PRESENT	0
698408	695159	95041E	PARTICIPANT	\N	PRESENT	0
698409	695159	20028X	PARTICIPANT	\N	PRESENT	0
698410	695159	11097X	PARTICIPANT	\N	PRESENT	0
698411	695159	19479G	PARTICIPANT	\N	PRESENT	0
698412	695159	14147R	PARTICIPANT	\N	PRESENT	0
698413	695159	14217N	PARTICIPANT	\N	PRESENT	0
698414	695159	20062A	PARTICIPANT	\N	PRESENT	0
698415	695159	14097Y	PARTICIPANT	\N	PRESENT	0
698416	695159	14213J	PARTICIPANT	\N	PRESENT	0
698417	695159	20134Y	PARTICIPANT	\N	PRESENT	0
698418	695159	14083S	PARTICIPANT	\N	PRESENT	0
698419	695159	20124W	PARTICIPANT	\N	PRESENT	0
698420	695159	01024M	PARTICIPANT	\N	PRESENT	0
698421	695159	19447X	PARTICIPANT	\N	PRESENT	0
698422	693586	19717B	PRESIDENT	0	PRESENT	0
698423	693586	18083K	PARTICIPANT	\N	PRESENT	0
698424	693586	20034V	PARTICIPANT	\N	PRESENT	0
698425	693586	19295A	PARTICIPANT	\N	EXCUSE	0
698426	693586	20146D	PARTICIPANT	\N	PRESENT	0
698427	693586	19319Q	PARTICIPANT	\N	PRESENT	0
698428	695163	14331P	PRESIDENT	0	PRESENT	0
698429	695163	19711U	PARTICIPANT	\N	PRESENT	0
698430	695163	04045F	PARTICIPANT	\N	PRESENT	0
698431	695163	20100N	PARTICIPANT	\N	PRESENT	0
698432	695163	19531S	PARTICIPANT	\N	PRESENT	0
698433	695163	19333N	PARTICIPANT	\N	PRESENT	0
698434	695163	14189C	PARTICIPANT	\N	PRESENT	0
698435	695163	14097Y	PARTICIPANT	\N	PRESENT	0
698436	695163	14169X	PARTICIPANT	\N	PRESENT	0
698437	695163	10015M	PARTICIPANT	\N	PRESENT	0
698438	695163	14073Q	PARTICIPANT	\N	PRESENT	0
698439	695163	14001X	PARTICIPANT	\N	PRESENT	0
698440	695163	14133K	PARTICIPANT	\N	PRESENT	0
698442	695163	19701S	PARTICIPANT	\N	PRESENT	0
698451	695163	14237S	PARTICIPANT	\N	PRESENT	0
698471	695163	12041X	PARTICIPANT	\N	PRESENT	0
698486	698485	19251M	PARTICIPANT	\N	PRESENT	0
698492	698490	19703U	PARTICIPANT	\N	PRESENT	1
698493	698490	18193Q	PARTICIPANT	\N	PRESENT	1
698513	698512	11026G	PARTICIPANT	\N	PRESENT	0
698550	695163	14026U	PARTICIPANT	\N	PRESENT	0
698551	695163	11083R	PARTICIPANT	\N	PRESENT	0
698561	698559	19703U	PARTICIPANT	\N	PRESENT	1
698562	698559	18193Q	PARTICIPANT	\N	PRESENT	1
698645	694940	20120S	PARTICIPANT	\N	EXCUSE	0
698646	694940	19735D	PARTICIPANT	\N	EXCUSE	0
698647	694940	19565D	PARTICIPANT	\N	EXCUSE	0
698648	694940	19563B	PARTICIPANT	\N	EXCUSE	0
698649	694940	14071N	PARTICIPANT	\N	EXCUSE	0
698650	694940	17637T	PARTICIPANT	\N	EXCUSE	0
698651	694940	20062A	PARTICIPANT	\N	EXCUSE	0
698652	694940	20084G	PARTICIPANT	\N	EXCUSE	0
698653	694940	20122U	PARTICIPANT	\N	EXCUSE	0
698654	694940	20058E	PARTICIPANT	\N	EXCUSE	0
698655	694940	14173T	PARTICIPANT	\N	EXCUSE	0
698754	698753	19673G	PARTICIPANT	\N	PRESENT	0
698756	698755	19673G	PARTICIPANT	\N	PRESENT	0
698759	698758	14237S	PARTICIPANT	\N	PRESENT	0
698760	698758	11101A	PARTICIPANT	\N	PRESENT	0
698761	698758	14189C	PARTICIPANT	\N	PRESENT	0
698762	698758	19349W	PARTICIPANT	\N	PRESENT	0
698763	698758	19575F	PARTICIPANT	\N	PRESENT	0
698764	698758	20138D	PARTICIPANT	\N	PRESENT	0
698765	698758	19643A	PARTICIPANT	\N	PRESENT	0
698903	692496	05008E	PARTICIPANT	\N	EXCUSE	0
698904	692496	19673G	PARTICIPANT	\N	EXCUSE	0
698905	692496	14331P	PARTICIPANT	\N	EXCUSE	0
698906	692496	11043H	PARTICIPANT	\N	EXCUSE	0
698907	692496	19301E	PARTICIPANT	\N	EXCUSE	0
698908	698900	05008E	PARTICIPANT	\N	EXCUSE	0
698909	698900	19673G	PARTICIPANT	\N	EXCUSE	0
698910	698900	14331P	PARTICIPANT	\N	EXCUSE	0
698911	698900	11043H	PARTICIPANT	\N	EXCUSE	0
698912	698900	19301E	PARTICIPANT	\N	EXCUSE	0
698974	698973	16685X	PARTICIPANT	\N	PRESENT	0
699126	698964	19739H	PARTICIPANT	\N	PRESENT	0
699127	698964	19701S	PARTICIPANT	\N	PRESENT	0
699131	699130	14329V	PARTICIPANT	\N	PRESENT	0
699135	699134	20076G	PRESIDENT	0	PRESENT	0
699136	699134	20140W	PARTICIPANT	\N	PRESENT	0
699137	699134	19503N	PARTICIPANT	\N	PRESENT	0
699138	699134	16685X	PARTICIPANT	\N	PRESENT	0
699139	699134	19820Y	PARTICIPANT	\N	PRESENT	0
699140	699134	20046A	PARTICIPANT	\N	PRESENT	0
699141	699134	14033T	PARTICIPANT	\N	PRESENT	0
699142	699134	19826F	PARTICIPANT	\N	PRESENT	0
699143	699134	19721W	PARTICIPANT	\N	EXCUSE	0
699144	699134	20026V	PARTICIPANT	\N	EXCUSE	0
698379	695159	11045K	PARTICIPANT	\N	PRESENT	0
698380	695159	19713W	PARTICIPANT	\N	PRESENT	0
699146	699134	19798U	PARTICIPANT	\N	PRESENT	0
699147	699134	20074E	PARTICIPANT	\N	PRESENT	0
699148	699134	04045F	PARTICIPANT	\N	PRESENT	0
699149	699134	20054A	PARTICIPANT	\N	PRESENT	0
699150	699134	19725B	PARTICIPANT	\N	PRESENT	0
699151	699134	14205J	PARTICIPANT	\N	PRESENT	0
699152	699134	20248J	PARTICIPANT	\N	PRESENT	0
699153	699134	20118Y	PARTICIPANT	\N	PRESENT	0
699154	699134	14267Y	PARTICIPANT	\N	PRESENT	0
699155	699134	20114U	PARTICIPANT	\N	PRESENT	0
699156	699134	08045X	PARTICIPANT	\N	EXCUSE	0
699157	699134	20056C	PARTICIPANT	\N	EXCUSE	0
699158	699134	19701S	PARTICIPANT	\N	PRESENT	0
699159	699134	20096L	PARTICIPANT	\N	PRESENT	0
699160	699134	20142Y	PARTICIPANT	\N	PRESENT	0
699161	699134	19782L	PARTICIPANT	\N	PRESENT	0
699162	699134	14173T	PARTICIPANT	\N	PRESENT	0
699163	699134	20106U	PARTICIPANT	\N	EXCUSE	0
699164	698965	14026U	PARTICIPANT	\N	PRESENT	0
699165	698965	14111D	PARTICIPANT	\N	PRESENT	0
699166	698965	19681G	PARTICIPANT	\N	PRESENT	0
699167	698965	08028W	PARTICIPANT	\N	PRESENT	0
699168	698965	12041X	PARTICIPANT	\N	PRESENT	0
699169	698965	19711U	PARTICIPANT	\N	PRESENT	0
699170	698965	14195A	PARTICIPANT	\N	PRESENT	0
699171	698965	11066Q	PARTICIPANT	\N	PRESENT	0
699172	698965	19525U	PARTICIPANT	\N	PRESENT	0
699173	698965	19349W	PARTICIPANT	\N	PRESENT	0
699174	698965	14211G	PARTICIPANT	\N	PRESENT	0
699175	698965	19713W	PARTICIPANT	\N	PRESENT	0
699176	698965	14030Q	PARTICIPANT	\N	PRESENT	0
699177	698965	11083R	PARTICIPANT	\N	PRESENT	0
699178	698965	19581D	PARTICIPANT	\N	PRESENT	0
699179	698965	98022P	PARTICIPANT	\N	PRESENT	0
699180	698965	04057K	PARTICIPANT	\N	PRESENT	0
699181	698965	01062T	PARTICIPANT	\N	PRESENT	0
699182	698965	20086J	PARTICIPANT	\N	PRESENT	0
699183	698965	14021P	PARTICIPANT	\N	PRESENT	0
699184	698965	11054L	PARTICIPANT	\N	PRESENT	0
699185	698965	20102Q	PARTICIPANT	\N	PRESENT	0
699186	698965	19643A	PARTICIPANT	\N	PRESENT	0
686493	681117	19621T	PARTICIPANT	\N	EXCUSE	0
686494	681117	08012N	PARTICIPANT	\N	PRESENT	0
686495	681116	19621T	PARTICIPANT	\N	EXCUSE	0
686572	681116	08012N	PARTICIPANT	\N	PRESENT	0
686574	681118	19621T	PARTICIPANT	\N	EXCUSE	0
686577	681118	19699S	PARTICIPANT	\N	PRESENT	0
688620	688619	19515S	PARTICIPANT	\N	PRESENT	0
688621	688619	19954N	PARTICIPANT	\N	PRESENT	0
688622	688619	19575F	PARTICIPANT	\N	PRESENT	0
688623	688619	19503N	PARTICIPANT	\N	PRESENT	0
688624	688619	14033T	PARTICIPANT	\N	PRESENT	0
688625	688619	14193X	PARTICIPANT	\N	PRESENT	0
688626	688619	19709B	PARTICIPANT	\N	PRESENT	0
688627	688619	19735D	PARTICIPANT	\N	PRESENT	0
688628	688619	19565D	PARTICIPANT	\N	PRESENT	0
688629	688619	14105F	PARTICIPANT	\N	PRESENT	0
688631	688630	01028R	PARTICIPANT	\N	PRESENT	0
688797	688745	08073C	PARTICIPANT	\N	EXCUSE	0
688798	688745	11043H	PARTICIPANT	\N	EXCUSE	0
689386	688764	19723Y	PARTICIPANT	\N	PRESENT	0
689393	688764	19697Q	PARTICIPANT	\N	PRESENT	0
689395	688764	19295A	PARTICIPANT	\N	PRESENT	0
689421	688764	19591F	PARTICIPANT	\N	PRESENT	0
689422	688764	18193Q	PARTICIPANT	\N	PRESENT	0
689423	688764	19760E	PARTICIPANT	\N	PRESENT	0
689609	689280	14037X	PARTICIPANT	\N	PRESENT	0
690423	688745	19329S	PARTICIPANT	\N	PRESENT	0
690458	690455	14026U	PARTICIPANT	\N	PRESENT	0
690459	690455	11097X	PARTICIPANT	\N	PRESENT	0
690460	690455	20130U	PARTICIPANT	\N	PRESENT	0
690541	690540	20022R	PARTICIPANT	\N	PRESENT	0
690542	690540	14151M	PARTICIPANT	\N	PRESENT	0
690595	688692	07029T	PARTICIPANT	\N	EXCUSE	0
690596	688692	20118Y	PARTICIPANT	\N	EXCUSE	0
690597	688692	11045K	PARTICIPANT	\N	EXCUSE	0
690598	688692	14109K	PARTICIPANT	\N	PRESENT	0
690599	688692	19798U	PARTICIPANT	\N	PRESENT	0
690600	688692	20066E	PARTICIPANT	\N	PRESENT	0
690601	688692	14030Q	PRESIDENT	0	PRESENT	0
690602	688692	14189C	PARTICIPANT	\N	PRESENT	0
690603	688692	19693L	PARTICIPANT	\N	PRESENT	0
690604	688692	11031D	PARTICIPANT	\N	PRESENT	0
690616	688692	14179A	PARTICIPANT	\N	PRESENT	0
690617	688734	19717B	PRESIDENT	0	PRESENT	0
690618	688734	18083K	PARTICIPANT	\N	PRESENT	0
690619	688734	19295A	PARTICIPANT	\N	PRESENT	0
690620	688734	97011G	PARTICIPANT	\N	PRESENT	0
690621	688734	20034V	PARTICIPANT	\N	PRESENT	0
690622	688734	14219Q	PARTICIPANT	\N	PRESENT	0
690623	688734	14059S	PARTICIPANT	\N	PRESENT	0
690624	688734	19657G	PARTICIPANT	\N	PRESENT	0
690625	688734	14147R	PARTICIPANT	\N	PRESENT	0
690626	688734	20146D	PARTICIPANT	\N	PRESENT	0
690627	688734	19577H	PARTICIPANT	\N	EXCUSE	0
690628	688734	19691J	PARTICIPANT	\N	EXCUSE	0
690629	688734	19329S	PARTICIPANT	\N	EXCUSE	0
690630	688734	19715Y	PARTICIPANT	\N	EXCUSE	0
690631	688734	14097Y	PARTICIPANT	\N	EXCUSE	0
690633	688734	12016W	PARTICIPANT	\N	EXCUSE	0
690634	688734	11072N	PARTICIPANT	\N	EXCUSE	0
690635	688734	08073C	PARTICIPANT	\N	EXCUSE	0
690636	688734	19301E	PARTICIPANT	\N	EXCUSE	0
690640	688734	19631V	PARTICIPANT	\N	EXCUSE	0
690641	688734	05008E	PARTICIPANT	\N	EXCUSE	0
690642	688734	04085P	PARTICIPANT	\N	EXCUSE	0
690643	688734	14053L	PARTICIPANT	\N	EXCUSE	0
690644	688734	14259Y	PARTICIPANT	\N	EXCUSE	0
690645	688734	19659J	PARTICIPANT	\N	EXCUSE	0
690646	688734	19673G	PARTICIPANT	\N	EXCUSE	0
690647	688734	17023S	PARTICIPANT	\N	EXCUSE	0
690648	688734	11010L	PARTICIPANT	\N	EXCUSE	0
690649	688734	14033T	PARTICIPANT	\N	EXCUSE	0
690650	688734	19583F	PARTICIPANT	\N	EXCUSE	0
690651	688734	08034U	PARTICIPANT	\N	EXCUSE	0
690652	688734	20028X	PARTICIPANT	\N	EXCUSE	0
690653	688734	20148F	PARTICIPANT	\N	EXCUSE	0
690654	688734	19319Q	PARTICIPANT	\N	EXCUSE	0
690655	688734	11090Q	PARTICIPANT	\N	EXCUSE	0
690656	688734	14331P	PARTICIPANT	\N	EXCUSE	0
690657	688734	20150Y	PARTICIPANT	\N	EXCUSE	0
690658	688734	11043H	PARTICIPANT	\N	EXCUSE	0
690659	688734	14275Y	PARTICIPANT	\N	EXCUSE	0
691238	691237	19693L	PARTICIPANT	\N	PRESENT	0
691222	691220	20050V	PARTICIPANT	\N	EXCUSE	0
691239	691237	20112S	PARTICIPANT	\N	PRESENT	0
691240	691237	19643A	PARTICIPANT	\N	PRESENT	0
691241	691237	19735D	PARTICIPANT	\N	PRESENT	0
691243	691242	20112S	PARTICIPANT	\N	PRESENT	0
691244	691242	19643A	PARTICIPANT	\N	PRESENT	0
691245	691242	19735D	PARTICIPANT	\N	PRESENT	0
691458	690893	11045K	PARTICIPANT	\N	PRESENT	0
691459	690893	19683J	PARTICIPANT	\N	PRESENT	0
691460	690893	20130U	PARTICIPANT	\N	PRESENT	0
691461	690893	17965H	PARTICIPANT	\N	PRESENT	0
691463	691462	19683J	PARTICIPANT	\N	PRESENT	0
691464	691462	17965H	PARTICIPANT	\N	PRESENT	0
691465	691462	19715Y	PARTICIPANT	\N	PRESENT	0
691546	688764	19798U	PARTICIPANT	\N	PRESENT	0
691580	691570	20054A	PARTICIPANT	\N	PRESENT	0
691682	690789	16685X	PARTICIPANT	\N	PRESENT	0
691683	690789	12028B	PARTICIPANT	\N	PRESENT	0
691684	690789	14193X	PARTICIPANT	\N	PRESENT	0
691685	690789	08047A	PARTICIPANT	\N	PRESENT	0
691686	690789	01062T	PARTICIPANT	\N	PRESENT	0
691687	690789	11083R	PARTICIPANT	\N	PRESENT	0
691688	690789	19443T	PARTICIPANT	\N	EXCUSE	0
692304	692303	11048N	PARTICIPANT	\N	PRESENT	0
692305	692303	08011M	PARTICIPANT	\N	PRESENT	0
692307	692306	11048N	PARTICIPANT	\N	PRESENT	0
692309	692308	20086J	PARTICIPANT	\N	PRESENT	0
692310	692308	11065P	PARTICIPANT	\N	PRESENT	0
692311	692308	20914V	PARTICIPANT	\N	PRESENT	0
692313	692312	19711U	PARTICIPANT	\N	PRESENT	0
692315	692314	19711U	PARTICIPANT	\N	PRESENT	0
692317	692316	05008E	PARTICIPANT	\N	EXCUSE	0
692445	692444	07033P	PARTICIPANT	\N	PRESENT	0
692446	692444	14187A	PARTICIPANT	\N	PRESENT	0
692447	692444	14073Q	PARTICIPANT	\N	PRESENT	0
692448	692444	19699S	PARTICIPANT	\N	PRESENT	0
692608	692423	19349W	PARTICIPANT	\N	PRESENT	0
692610	692423	20074E	PARTICIPANT	\N	PRESENT	0
692611	692423	20052X	PARTICIPANT	\N	PRESENT	0
692612	692423	08010L	PARTICIPANT	\N	PRESENT	0
692613	692423	20082E	PARTICIPANT	\N	PRESENT	0
692620	692423	20056C	PARTICIPANT	\N	PRESENT	0
692621	692423	19511N	PARTICIPANT	\N	PRESENT	0
692622	692423	14205J	PARTICIPANT	\N	PRESENT	0
692623	692423	20116W	PARTICIPANT	\N	PRESENT	0
692624	692423	19719D	PARTICIPANT	\N	PRESENT	0
692625	692423	20054A	PARTICIPANT	\N	PRESENT	0
692626	692423	20058E	PARTICIPANT	\N	PRESENT	0
692627	692423	19681G	PARTICIPANT	\N	PRESENT	0
692628	692423	14221J	PARTICIPANT	\N	PRESENT	0
692632	692423	20038A	PARTICIPANT	\N	PRESENT	0
692633	692423	17737W	PARTICIPANT	\N	PRESENT	0
692940	692638	05008E	PARTICIPANT	\N	PRESENT	0
692944	692638	14069U	PARTICIPANT	\N	PRESENT	0
692946	692638	20056C	PARTICIPANT	\N	PRESENT	0
692943	692638	19643A	PARTICIPANT	\N	PRESENT	0
692945	692638	20098N	PARTICIPANT	\N	PRESENT	0
692947	692638	95041E	PARTICIPANT	\N	PRESENT	0
692948	692638	20248J	PARTICIPANT	\N	PRESENT	0
692951	692638	11053K	PARTICIPANT	\N	PRESENT	0
692952	692638	19687N	PARTICIPANT	\N	PRESENT	0
692953	692638	20298U	PARTICIPANT	\N	PRESENT	0
693331	693326	20056C	PARTICIPANT	\N	PRESENT	0
693329	693326	04070G	PARTICIPANT	\N	PRESENT	0
693332	693326	20134Y	PARTICIPANT	\N	PRESENT	0
693333	693326	19593H	PARTICIPANT	\N	PRESENT	0
693377	693376	14033T	PARTICIPANT	\N	PRESENT	0
693378	693376	14205J	PARTICIPANT	\N	PRESENT	0
693380	693379	14205J	PARTICIPANT	\N	PRESENT	0
694060	693928	19479G	PARTICIPANT	\N	PRESENT	0
694061	693928	11012A	PARTICIPANT	\N	PRESENT	0
694761	692535	17779H	PARTICIPANT	\N	PRESENT	0
694762	692535	10006L	PRESIDENT	0	PRESENT	0
694763	692535	19760E	PARTICIPANT	\N	PRESENT	0
694764	692535	17965H	PARTICIPANT	\N	PRESENT	0
694765	692535	14281W	PARTICIPANT	\N	PRESENT	0
694766	692535	18193Q	PARTICIPANT	\N	PRESENT	0
705447	704079	20052X	PARTICIPANT	\N	PRESENT	0
705448	704079	20142Y	PARTICIPANT	\N	PRESENT	0
705449	704079	14021P	PARTICIPANT	\N	PRESENT	0
705450	704079	20106U	PARTICIPANT	\N	PRESENT	0
705451	704079	19479G	PARTICIPANT	\N	PRESENT	0
705452	704079	19954N	PARTICIPANT	\N	PRESENT	0
705453	704079	20032T	PARTICIPANT	\N	PRESENT	0
705454	704079	17965H	PARTICIPANT	\N	PRESENT	0
705455	704079	18193Q	PARTICIPANT	\N	PRESENT	0
705464	704079	20114U	PARTICIPANT	\N	PRESENT	0
705465	704079	19563B	PARTICIPANT	\N	PRESENT	0
705474	704079	20018V	PARTICIPANT	\N	PRESENT	0
705467	704079	14030Q	PARTICIPANT	\N	PRESENT	0
705468	704079	14221J	PARTICIPANT	\N	PRESENT	0
705470	704079	20098N	PARTICIPANT	\N	PRESENT	0
705471	704079	08045X	PARTICIPANT	\N	PRESENT	0
705472	704079	08060W	PARTICIPANT	\N	PRESENT	0
705473	704079	19549D	PARTICIPANT	\N	PRESENT	0
705475	704079	07029T	PARTICIPANT	\N	PRESENT	0
705476	704079	11045K	PARTICIPANT	\N	PRESENT	0
705477	704079	04059M	PARTICIPANT	\N	PRESENT	0
705478	704079	19669L	PARTICIPANT	\N	PRESENT	0
705479	704079	19057M	PARTICIPANT	\N	PRESENT	0
705480	704829	14053L	PARTICIPANT	\N	PRESENT	0
705481	704829	10015M	PRESIDENT	0	PRESENT	0
705482	704829	20080C	PARTICIPANT	\N	PRESENT	0
705483	704829	12016W	PARTICIPANT	\N	PRESENT	0
705484	704829	19866P	PARTICIPANT	\N	PRESENT	0
705485	704829	19631V	PARTICIPANT	\N	PRESENT	0
705486	704829	20108W	PARTICIPANT	\N	PRESENT	0
705487	704829	08010L	PARTICIPANT	\N	PRESENT	0
705488	704829	19741B	PRESIDENT	1	PRESENT	0
705489	704829	20914V	PARTICIPANT	\N	PRESENT	0
705490	704829	14249W	PARTICIPANT	\N	PRESENT	0
705491	704829	19619A	PARTICIPANT	\N	PRESENT	0
705492	704829	20084G	PARTICIPANT	\N	PRESENT	0
705493	704829	08073C	PARTICIPANT	\N	EXCUSE	0
705494	704829	19687N	PARTICIPANT	\N	EXCUSE	0
705495	704829	20042V	PARTICIPANT	\N	EXCUSE	0
705496	704829	19667J	PARTICIPANT	\N	EXCUSE	0
705497	704829	19585H	PARTICIPANT	\N	EXCUSE	0
705498	704829	20044X	PARTICIPANT	\N	EXCUSE	0
705499	704079	11056N	PARTICIPANT	\N	PRESENT	0
705500	704079	19649G	PARTICIPANT	\N	PRESENT	0
705501	704079	20138D	PARTICIPANT	\N	PRESENT	0
705502	704079	20046A	PARTICIPANT	\N	PRESENT	0
705503	704079	17737W	PARTICIPANT	\N	PRESENT	0
705504	704829	11070L	PARTICIPANT	\N	PRESENT	0
705505	704080	99004R	PARTICIPANT	\N	PRESENT	0
705506	704080	11031D	PARTICIPANT	\N	PRESENT	0
705507	704080	19565D	PARTICIPANT	\N	PRESENT	0
705508	704080	11040E	PARTICIPANT	\N	PRESENT	0
705509	704080	19715Y	PARTICIPANT	\N	PRESENT	0
705561	704080	14215L	PARTICIPANT	\N	PRESENT	0
705511	704080	11012A	PARTICIPANT	\N	PRESENT	0
705512	704080	19553Y	PARTICIPANT	\N	PRESENT	0
705557	704080	11053K	PARTICIPANT	\N	PRESENT	0
705514	704080	19251M	PARTICIPANT	\N	PRESENT	0
705555	704080	04070G	PARTICIPANT	\N	PRESENT	0
705556	704080	19749K	PARTICIPANT	\N	PRESENT	0
705551	704080	20142Y	PARTICIPANT	\N	PRESENT	0
705559	704080	01062T	PARTICIPANT	\N	PRESENT	0
705558	704080	19503N	PARTICIPANT	\N	PRESENT	0
705520	704080	19599P	PARTICIPANT	\N	PRESENT	0
705521	704080	20082E	PARTICIPANT	\N	PRESENT	0
705563	704080	20028X	PARTICIPANT	\N	PRESENT	0
705523	704080	20124W	PARTICIPANT	\N	PRESENT	0
705524	704080	14189C	PARTICIPANT	\N	PRESENT	0
705525	704080	01024M	PARTICIPANT	\N	PRESENT	0
705526	704080	14021P	PARTICIPANT	\N	PRESENT	0
705527	704080	20106U	PARTICIPANT	\N	PRESENT	0
705554	704080	19693L	PARTICIPANT	\N	PRESENT	0
705564	704080	20136B	PARTICIPANT	\N	PRESENT	0
705530	704080	18193Q	PARTICIPANT	\N	PRESENT	0
705531	704080	20114U	PARTICIPANT	\N	PRESENT	0
705532	704080	19563B	PARTICIPANT	\N	PRESENT	0
705533	704080	14030Q	PARTICIPANT	\N	PRESENT	0
705534	704080	14221J	PARTICIPANT	\N	PRESENT	0
705535	704080	20098N	PARTICIPANT	\N	PRESENT	0
705536	704080	08045X	PARTICIPANT	\N	PRESENT	0
705537	704080	08060W	PARTICIPANT	\N	PRESENT	0
705538	704080	19549D	PARTICIPANT	\N	PRESENT	0
705539	704080	20018V	PARTICIPANT	\N	PRESENT	0
705540	704080	07029T	PARTICIPANT	\N	PRESENT	0
705541	704080	11045K	PARTICIPANT	\N	PRESENT	0
705566	704080	08015R	PARTICIPANT	\N	PRESENT	0
705567	704080	14147R	PARTICIPANT	\N	PRESENT	0
705544	704080	19057M	PARTICIPANT	\N	PRESENT	0
705553	704080	20134Y	PARTICIPANT	\N	PRESENT	0
705546	704080	19649G	PARTICIPANT	\N	PRESENT	0
705547	704080	20138D	PARTICIPANT	\N	PRESENT	0
705548	704080	20046A	PARTICIPANT	\N	PRESENT	0
705549	704080	17737W	PARTICIPANT	\N	PRESENT	0
705550	704080	97011G	PARTICIPANT	\N	PRESENT	0
705552	704080	11033F	PARTICIPANT	\N	PRESENT	0
705568	704080	20062A	PARTICIPANT	\N	PRESENT	0
705569	704080	14179A	PARTICIPANT	\N	PRESENT	0
705570	704829	19569H	PARTICIPANT	\N	PRESENT	0
705571	704080	14213J	PARTICIPANT	\N	PRESENT	0
705572	704245	14231L	PARTICIPANT	\N	PRESENT	0
705573	704080	20108W	PARTICIPANT	\N	PRESENT	0
705574	704245	19421M	PARTICIPANT	\N	PRESENT	0
705575	704245	20110Q	PARTICIPANT	\N	PRESENT	0
705576	704245	11056N	PARTICIPANT	\N	PRESENT	0
705577	704245	19954N	PARTICIPANT	\N	PRESENT	0
705578	704245	19629C	PRESIDENT	0	PRESENT	0
705579	704245	14259Y	PARTICIPANT	\N	PRESENT	0
705580	704080	14038Y	PARTICIPANT	\N	PRESENT	0
705581	704080	20264J	PARTICIPANT	\N	PRESENT	0
705582	704245	19489J	PARTICIPANT	\N	PRESENT	0
705585	704245	19383Y	PARTICIPANT	\N	PRESENT	0
705591	704245	20082E	PARTICIPANT	\N	PRESENT	0
705593	704245	19703U	PARTICIPANT	\N	PRESENT	0
705596	704080	17965H	PARTICIPANT	\N	PRESENT	0
705603	704080	19741B	PARTICIPANT	\N	PRESENT	0
705611	704080	14053L	PARTICIPANT	\N	PRESENT	0
705612	704245	14001X	PARTICIPANT	\N	PRESENT	0
705613	704080	19533U	PARTICIPANT	\N	PRESENT	0
705614	704080	19631V	PARTICIPANT	\N	PRESENT	0
705615	704080	19479G	PARTICIPANT	\N	PRESENT	0
705616	704245	20248J	PARTICIPANT	\N	PRESENT	0
705617	704080	14107H	PARTICIPANT	\N	PRESENT	0
705620	704080	14109K	PARTICIPANT	\N	PRESENT	0
705621	704080	19691J	PARTICIPANT	\N	PRESENT	0
705622	704080	19569H	PARTICIPANT	\N	PRESENT	0
705623	704080	20070A	PARTICIPANT	\N	PRESENT	0
705624	704080	04045F	PARTICIPANT	\N	PRESENT	0
705625	704080	14357A	PARTICIPANT	\N	PRESENT	0
705626	704080	20064C	PARTICIPANT	\N	PRESENT	0
705627	704080	20100N	PARTICIPANT	\N	PRESENT	0
705628	704080	19760E	PARTICIPANT	\N	PRESENT	0
705629	704080	19611R	PARTICIPANT	\N	PRESENT	0
705630	704080	19701S	PARTICIPANT	\N	PRESENT	0
705631	704080	01048V	PARTICIPANT	\N	PRESENT	0
705632	704080	19798U	PARTICIPANT	\N	PRESENT	0
705633	704080	19413M	PARTICIPANT	\N	PRESENT	0
705634	704080	20080C	PARTICIPANT	\N	PRESENT	0
705635	704080	19758L	PARTICIPANT	\N	PRESENT	0
705636	704245	14331P	PARTICIPANT	\N	PRESENT	0
705638	704080	20980G	PARTICIPANT	\N	PRESENT	0
705639	704080	20180F	PARTICIPANT	\N	PRESENT	0
705640	704080	19573D	PARTICIPANT	\N	PRESENT	0
705641	704080	14026U	PARTICIPANT	\N	PRESENT	0
705642	704080	19954N	PARTICIPANT	\N	PRESENT	0
705643	704080	20022R	PARTICIPANT	\N	PRESENT	0
705644	704080	20914V	PARTICIPANT	\N	PRESENT	0
705646	704080	95063L	PARTICIPANT	\N	PRESENT	0
705648	704081	19715Y	PARTICIPANT	\N	PRESENT	0
705650	704081	19251M	PARTICIPANT	\N	PRESENT	0
705651	704081	97011G	PARTICIPANT	\N	PRESENT	0
705653	704081	20124W	PARTICIPANT	\N	PRESENT	0
705656	704081	20142Y	PARTICIPANT	\N	PRESENT	0
684984	682305	10006L	PRESIDENT	0	PRESENT	0
684985	682305	19760E	PARTICIPANT	\N	PRESENT	0
684986	682305	19683J	PARTICIPANT	\N	PRESENT	0
684987	682305	19329S	PARTICIPANT	\N	PRESENT	0
684988	682305	19553Y	PARTICIPANT	\N	PRESENT	0
684989	682305	19679N	PARTICIPANT	\N	PRESENT	0
684990	682305	19511N	PARTICIPANT	\N	PRESENT	0
684991	682305	19415P	PARTICIPANT	\N	PRESENT	0
684992	682305	19713W	PARTICIPANT	\N	PRESENT	0
684993	682305	19367Y	PARTICIPANT	\N	PRESENT	0
684994	682305	11097X	PARTICIPANT	\N	PRESENT	0
684995	682305	19798U	PARTICIPANT	\N	PRESENT	0
684996	682305	01034P	PARTICIPANT	\N	PRESENT	0
684997	682305	11067R	PARTICIPANT	\N	PRESENT	0
684998	682305	19657G	PARTICIPANT	\N	PRESENT	0
684999	682305	11103C	PARTICIPANT	\N	PRESENT	0
685000	682305	20090E	PARTICIPANT	\N	PRESENT	0
685001	682305	04092N	PARTICIPANT	\N	PRESENT	0
685002	682305	14071N	PARTICIPANT	\N	PRESENT	0
685003	682305	14217N	PRESIDENT	1	PRESENT	0
685004	682305	19703U	PARTICIPANT	\N	PRESENT	0
685005	682305	14213J	PARTICIPANT	\N	PRESENT	0
685006	682305	19507S	PARTICIPANT	\N	PRESENT	0
685007	682305	14237S	PARTICIPANT	\N	PRESENT	0
685008	682305	20248J	PARTICIPANT	\N	PRESENT	0
685009	682305	20066E	PARTICIPANT	\N	PRESENT	0
685010	682305	04057K	PARTICIPANT	\N	PRESENT	0
685011	682305	18193Q	PARTICIPANT	\N	PRESENT	0
685012	682305	14026U	PARTICIPANT	\N	PRESENT	0
685013	682305	14223L	PARTICIPANT	\N	PRESENT	0
685014	682305	20130U	PARTICIPANT	\N	PRESENT	0
685034	682305	14355X	PARTICIPANT	\N	EXCUSE	0
685035	682305	04043D	PARTICIPANT	\N	PRESENT	0
685036	682305	19697Q	PARTICIPANT	\N	PRESENT	0
685037	682305	17779H	PARTICIPANT	\N	PRESENT	0
685038	682305	17965H	PARTICIPANT	\N	PRESENT	0
685039	682305	20266L	PARTICIPANT	\N	PRESENT	0
685040	682305	19717B	PARTICIPANT	\N	PRESENT	0
685041	682305	19591F	PARTICIPANT	\N	PRESENT	0
685042	682305	08045X	PARTICIPANT	\N	PRESENT	0
685050	682305	19569H	PARTICIPANT	\N	PRESENT	0
685106	682306	19760E	PARTICIPANT	\N	PRESENT	0
685107	682306	19717B	PARTICIPANT	\N	PRESENT	0
685108	682306	19415P	PARTICIPANT	\N	PRESENT	0
685109	682306	19367Y	PARTICIPANT	\N	PRESENT	0
685110	682306	20090E	PARTICIPANT	\N	PRESENT	0
685111	682306	11103C	PARTICIPANT	\N	PRESENT	0
685112	682306	11031D	PARTICIPANT	\N	EXCUSE	0
685113	682306	10006L	PARTICIPANT	\N	PRESENT	0
685114	682306	14217N	PRESIDENT	0	PRESENT	0
685115	682306	20248J	PARTICIPANT	\N	PRESENT	0
685116	682306	08045X	PARTICIPANT	\N	PRESENT	0
685117	682306	14355X	PARTICIPANT	\N	EXCUSE	0
685118	682306	14026U	PARTICIPANT	\N	PRESENT	0
685119	682306	19553Y	PARTICIPANT	\N	PRESENT	0
685120	682306	19329S	PARTICIPANT	\N	PRESENT	0
685121	682306	19569H	PARTICIPANT	\N	PRESENT	0
685122	682306	19591F	PARTICIPANT	\N	PRESENT	0
685123	682306	14213J	PARTICIPANT	\N	PRESENT	0
685124	682306	20066E	PARTICIPANT	\N	PRESENT	0
685125	682306	19511N	PARTICIPANT	\N	PRESENT	0
685126	682306	19683J	PARTICIPANT	\N	PRESENT	0
685127	682306	18193Q	PARTICIPANT	\N	PRESENT	0
685129	682306	19697Q	PARTICIPANT	\N	PRESENT	0
685130	682306	17779H	PARTICIPANT	\N	PRESENT	0
685131	682306	19657G	PARTICIPANT	\N	PRESENT	0
685132	682306	04057K	PARTICIPANT	\N	PRESENT	0
685133	682306	11067R	PARTICIPANT	\N	PRESENT	0
685134	682306	14071N	PARTICIPANT	\N	PRESENT	0
685135	682306	04092N	PARTICIPANT	\N	PRESENT	0
685136	682306	14223L	PARTICIPANT	\N	PRESENT	0
685137	682306	20130U	PARTICIPANT	\N	PRESENT	0
685138	682306	04043D	PARTICIPANT	\N	PRESENT	0
685139	682306	17965H	PARTICIPANT	\N	PRESENT	0
685140	682306	19679N	PARTICIPANT	\N	PRESENT	0
685141	682306	19798U	PARTICIPANT	\N	PRESENT	0
685142	682306	11097X	PARTICIPANT	\N	PRESENT	0
685143	682306	19703U	PARTICIPANT	\N	PRESENT	0
685144	682306	19713W	PARTICIPANT	\N	PRESENT	0
685145	682306	01034P	PARTICIPANT	\N	PRESENT	0
685146	682306	20266L	PARTICIPANT	\N	PRESENT	0
685154	682306	11045K	PARTICIPANT	\N	PRESENT	0
685155	682305	11045K	PARTICIPANT	\N	PRESENT	0
685282	682306	19295A	PARTICIPANT	\N	PRESENT	0
685283	682305	19295A	PARTICIPANT	\N	PRESENT	0
685284	682305	14042U	PARTICIPANT	\N	EXCUSE	0
685285	682306	14042U	PARTICIPANT	\N	EXCUSE	0
685462	681308	19251M	PARTICIPANT	\N	PRESENT	0
685463	681308	19637C	PARTICIPANT	\N	EXCUSE	0
685633	674946	19673G	PARTICIPANT	\N	EXCUSE	0
688427	688426	19954N	PARTICIPANT	\N	PRESENT	0
688434	688433	14069U	PARTICIPANT	\N	PRESENT	0
688435	688433	14083S	PARTICIPANT	\N	PRESENT	0
688436	688433	07033P	PARTICIPANT	\N	PRESENT	0
688437	688433	14187A	PARTICIPANT	\N	PRESENT	0
688438	688433	20180F	PARTICIPANT	\N	PRESENT	0
688439	688433	14213J	PARTICIPANT	\N	PRESENT	0
688440	688433	14059S	PARTICIPANT	\N	PRESENT	0
688441	688433	08012N	PARTICIPANT	\N	PRESENT	0
688442	688433	14147R	PARTICIPANT	\N	PRESENT	0
688443	688433	19745F	PARTICIPANT	\N	PRESENT	0
688444	688433	19479G	PARTICIPANT	\N	PRESENT	0
688445	688433	19369B	PARTICIPANT	\N	PRESENT	0
692210	690785	14331P	PRESIDENT	0	PRESENT	0
692211	690785	14001X	PARTICIPANT	\N	PRESENT	0
692212	690785	20100N	PARTICIPANT	\N	PRESENT	0
692213	690785	11083R	PARTICIPANT	\N	PRESENT	0
692214	690785	19441R	PARTICIPANT	\N	PRESENT	0
692215	690785	08034U	PARTICIPANT	\N	PRESENT	0
692216	690785	14089Y	PARTICIPANT	\N	PRESENT	0
692224	690785	04047H	PARTICIPANT	\N	PRESENT	0
692225	690785	14147R	PARTICIPANT	\N	PRESENT	0
692500	692499	05008E	PARTICIPANT	\N	PRESENT	0
692501	692499	11053K	PARTICIPANT	\N	PRESENT	0
692502	692499	01028R	PARTICIPANT	\N	PRESENT	0
692774	692638	19301E	PARTICIPANT	\N	PRESENT	0
692775	692638	04045F	PARTICIPANT	\N	PRESENT	0
692776	692638	19349W	PARTICIPANT	\N	PRESENT	0
692777	692638	10006L	PARTICIPANT	\N	PRESENT	0
692778	692638	20914V	PARTICIPANT	\N	PRESENT	0
692779	692638	19533U	PARTICIPANT	\N	PRESENT	0
692780	692638	11033F	PARTICIPANT	\N	PRESENT	0
692781	692638	01060R	PARTICIPANT	\N	PRESENT	0
692782	692638	14055N	PARTICIPANT	\N	PRESENT	0
692783	692638	20118Y	PARTICIPANT	\N	PRESENT	0
692784	692638	19717B	PARTICIPANT	\N	PRESENT	0
692785	692638	19367Y	PARTICIPANT	\N	PRESENT	0
692786	692638	19681G	PARTICIPANT	\N	PRESENT	0
692787	692638	20132W	PARTICIPANT	\N	PRESENT	0
692788	692638	19387D	PARTICIPANT	\N	PRESENT	0
692789	692638	19762G	PARTICIPANT	\N	PRESENT	0
692790	692638	20126Y	PARTICIPANT	\N	PRESENT	0
692791	692638	20090E	PARTICIPANT	\N	PRESENT	0
692792	692638	20062A	PARTICIPANT	\N	PRESENT	0
692793	692638	20116W	PARTICIPANT	\N	PRESENT	0
692794	692638	19719D	PARTICIPANT	\N	PRESENT	0
692795	692638	98022P	PARTICIPANT	\N	PRESENT	0
692796	692638	19553Y	PARTICIPANT	\N	PRESENT	0
692797	692638	14329V	PARTICIPANT	\N	PRESENT	0
692798	692638	20072C	PARTICIPANT	\N	PRESENT	0
692799	692638	19866P	PARTICIPANT	\N	PRESENT	0
692800	692638	11012A	PARTICIPANT	\N	PRESENT	0
692801	692638	14357A	PARTICIPANT	\N	PRESENT	0
692802	692638	14251Q	PARTICIPANT	\N	PRESENT	0
692803	692638	20032T	PARTICIPANT	\N	PRESENT	0
692804	692638	19545Y	PARTICIPANT	\N	PRESENT	0
692805	692638	14111D	PARTICIPANT	\N	PRESENT	0
692806	692638	14195A	PARTICIPANT	\N	PRESENT	0
692807	692638	20054A	PARTICIPANT	\N	PRESENT	0
692808	692638	11064N	PARTICIPANT	\N	PRESENT	0
692809	692638	14221J	PARTICIPANT	\N	PRESENT	0
692810	692638	04057K	PARTICIPANT	\N	PRESENT	0
692811	692638	19563B	PARTICIPANT	\N	PRESENT	0
692812	692638	20050V	PARTICIPANT	\N	PRESENT	0
692813	692638	19585H	PARTICIPANT	\N	PRESENT	0
692814	692638	20152B	PARTICIPANT	\N	PRESENT	0
692815	692638	20020P	PARTICIPANT	\N	PRESENT	0
692816	692638	04059M	PARTICIPANT	\N	PRESENT	0
692817	692638	19549D	PARTICIPANT	\N	PRESENT	0
692820	692638	20080C	PARTICIPANT	\N	PRESENT	0
692819	692638	08060W	PARTICIPANT	\N	PRESENT	0
699187	698965	19515S	PARTICIPANT	\N	PRESENT	0
699188	698965	19631V	PARTICIPANT	\N	PRESENT	0
699189	698965	20980G	PARTICIPANT	\N	PRESENT	0
699190	698965	19347U	PARTICIPANT	\N	PRESENT	0
699191	698965	20030R	PARTICIPANT	\N	PRESENT	0
699192	698965	14031R	PARTICIPANT	\N	PRESENT	0
699193	698965	12028B	PARTICIPANT	\N	PRESENT	0
699194	698965	20050V	PARTICIPANT	\N	PRESENT	0
699195	698965	11010L	PARTICIPANT	\N	PRESENT	0
699196	698965	19585H	PARTICIPANT	\N	PRESENT	0
699197	698965	14147R	PARTICIPANT	\N	PRESENT	0
699198	698965	20122U	PARTICIPANT	\N	PRESENT	0
699199	698965	14217N	PARTICIPANT	\N	PRESENT	0
699200	698965	19637C	PARTICIPANT	\N	PRESENT	0
699201	698965	20062A	PARTICIPANT	\N	PRESENT	0
699202	698965	19387D	PARTICIPANT	\N	PRESENT	0
699203	698965	20132W	PARTICIPANT	\N	PRESENT	0
699204	698965	20044X	PARTICIPANT	\N	PRESENT	0
699205	698965	11012A	PARTICIPANT	\N	PRESENT	0
699206	698965	14133K	PARTICIPANT	\N	PRESENT	0
699207	698965	14207L	PARTICIPANT	\N	PRESENT	0
699208	698965	19621T	PARTICIPANT	\N	PRESENT	0
699209	698965	08061X	PARTICIPANT	\N	PRESENT	0
699210	698965	17229F	PARTICIPANT	\N	PRESENT	0
699211	699134	20090E	PARTICIPANT	\N	PRESENT	0
699212	699134	19719D	PARTICIPANT	\N	PRESENT	0
699213	699134	19723Y	PARTICIPANT	\N	PRESENT	0
699214	698965	17023S	PARTICIPANT	\N	PRESENT	0
699215	698965	19685L	PARTICIPANT	\N	PRESENT	0
699216	698965	97011G	PARTICIPANT	\N	PRESENT	0
699217	698965	14255U	PARTICIPANT	\N	PRESENT	0
699218	698965	95063L	PARTICIPANT	\N	PRESENT	0
699219	698965	20090E	PARTICIPANT	\N	PRESENT	0
699220	698965	19782L	PARTICIPANT	\N	PRESENT	0
699221	698965	19503N	PARTICIPANT	\N	PRESENT	0
699222	698965	19798U	PARTICIPANT	\N	PRESENT	0
699223	698965	04045F	PARTICIPANT	\N	PRESENT	0
699224	698965	20022R	PARTICIPANT	\N	PRESENT	0
699225	698965	16685X	PARTICIPANT	\N	PRESENT	0
699226	698965	20032T	PARTICIPANT	\N	PRESENT	0
699227	698965	14219Q	PARTICIPANT	\N	PRESENT	0
699228	698965	14107H	PARTICIPANT	\N	PRESENT	0
699229	698965	20140W	PARTICIPANT	\N	PRESENT	0
699230	698965	20046A	PARTICIPANT	\N	PRESENT	0
699231	698965	20074E	PARTICIPANT	\N	PRESENT	0
699232	698965	18083K	PARTICIPANT	\N	PRESENT	0
699233	698965	14033T	PARTICIPANT	\N	PRESENT	0
699234	698965	20096L	PARTICIPANT	\N	PRESENT	0
699235	698965	20072C	PARTICIPANT	\N	PRESENT	0
699236	698965	14038Y	PARTICIPANT	\N	PRESENT	0
699237	698965	04085P	PARTICIPANT	\N	PRESENT	0
699238	698965	19563B	PARTICIPANT	\N	PRESENT	0
699239	698965	11048N	PARTICIPANT	\N	PRESENT	0
699240	698965	20298U	PARTICIPANT	\N	PRESENT	0
699241	698965	14225N	PARTICIPANT	\N	PRESENT	0
699242	698965	20142Y	PARTICIPANT	\N	PRESENT	0
699243	698965	14191V	PARTICIPANT	\N	PRESENT	0
699244	698965	19826F	PARTICIPANT	\N	PRESENT	0
699245	698965	19671E	PARTICIPANT	\N	PRESENT	0
699246	698965	14251Q	PARTICIPANT	\N	PRESENT	0
699247	698965	08009T	PARTICIPANT	\N	PRESENT	0
699248	698965	20076G	PARTICIPANT	\N	PRESENT	0
699249	698965	20108W	PARTICIPANT	\N	PRESENT	0
699250	698965	19619A	PARTICIPANT	\N	PRESENT	0
699251	698965	20098N	PARTICIPANT	\N	PRESENT	0
699252	698965	01060R	PARTICIPANT	\N	PRESENT	0
699253	698965	20042V	PARTICIPANT	\N	PRESENT	0
699254	698965	20052X	PARTICIPANT	\N	PRESENT	0
699255	698965	14059S	PARTICIPANT	\N	PRESENT	0
699256	698965	19467C	PARTICIPANT	\N	PRESENT	0
699257	698965	01025N	PARTICIPANT	\N	PRESENT	0
699259	698965	20084G	PARTICIPANT	\N	PRESENT	0
699260	698965	14223L	PARTICIPANT	\N	PRESENT	0
699261	698965	20128B	PARTICIPANT	\N	PRESENT	0
699262	698965	01057W	PARTICIPANT	\N	PRESENT	0
699263	698965	19251M	PARTICIPANT	\N	PRESENT	0
699264	698965	19441R	PARTICIPANT	\N	PRESENT	0
699265	698965	20082E	PARTICIPANT	\N	PRESENT	0
699266	698965	20172F	PARTICIPANT	\N	PRESENT	0
699267	698965	04092N	PARTICIPANT	\N	PRESENT	0
699268	698965	19549D	PARTICIPANT	\N	PRESENT	0
699269	698965	17737W	PARTICIPANT	\N	PRESENT	0
699270	698965	19729F	PARTICIPANT	\N	PRESENT	0
699271	698965	01024M	PARTICIPANT	\N	PRESENT	0
699272	698965	14089Y	PARTICIPANT	\N	PRESENT	0
699273	698965	19762G	PARTICIPANT	\N	PRESENT	0
699274	698965	14083S	PARTICIPANT	\N	PRESENT	0
699275	698965	01058X	PARTICIPANT	\N	PRESENT	0
699276	698965	01048V	PARTICIPANT	\N	PRESENT	0
699277	698965	20038A	PARTICIPANT	\N	PRESENT	0
699278	698965	20028X	PARTICIPANT	\N	PRESENT	0
699279	698965	19745F	PARTICIPANT	\N	PRESENT	0
699281	698965	20252E	PARTICIPANT	\N	PRESENT	0
699282	698965	20144B	PARTICIPANT	\N	PRESENT	0
699283	698965	14189C	PARTICIPANT	\N	PRESENT	0
699285	698965	20064C	PARTICIPANT	\N	PRESENT	0
699286	698965	11104D	PARTICIPANT	\N	PRESENT	0
699287	698965	19820Y	PARTICIPANT	\N	PRESENT	0
699288	698965	19747H	PARTICIPANT	\N	PRESENT	0
699289	698965	19333N	PARTICIPANT	\N	PRESENT	0
699290	698965	99004R	PARTICIPANT	\N	PRESENT	0
699291	698965	19599P	PARTICIPANT	\N	PRESENT	0
699292	698965	07029T	PARTICIPANT	\N	PRESENT	0
699293	698965	20248J	PARTICIPANT	\N	PRESENT	0
699294	698943	20066E	PARTICIPANT	\N	EXCUSE	0
699295	698943	01048V	PARTICIPANT	\N	PRESENT	0
699390	698966	14026U	PARTICIPANT	\N	PRESENT	0
699391	698966	12041X	PARTICIPANT	\N	PRESENT	0
699392	698966	19820Y	PARTICIPANT	\N	PRESENT	0
699393	698966	11104D	PARTICIPANT	\N	PRESENT	0
699394	698966	19599P	PARTICIPANT	\N	PRESENT	0
699409	698966	19347U	PARTICIPANT	\N	PRESENT	0
699408	698966	14031R	PARTICIPANT	\N	PRESENT	0
699397	698966	20064C	PARTICIPANT	\N	PRESENT	0
699398	698966	20092G	PARTICIPANT	\N	PRESENT	0
699399	698966	19782L	PARTICIPANT	\N	PRESENT	0
699400	698966	01058X	PARTICIPANT	\N	PRESENT	0
699401	698966	20102Q	PARTICIPANT	\N	PRESENT	0
699402	698966	14223L	PARTICIPANT	\N	PRESENT	0
699403	698966	20128B	PARTICIPANT	\N	PRESENT	0
699404	698966	19703U	PARTICIPANT	\N	PRESENT	0
699405	698966	11048N	PARTICIPANT	\N	PRESENT	0
699406	698966	19333N	PARTICIPANT	\N	PRESENT	0
699407	698966	01057W	PARTICIPANT	\N	PRESENT	0
699410	698966	19467C	PARTICIPANT	\N	PRESENT	0
699411	698966	19637C	PARTICIPANT	\N	PRESENT	0
699412	698966	20072C	PARTICIPANT	\N	PRESENT	0
699413	698966	14107H	PARTICIPANT	\N	PRESENT	0
699414	698966	11012A	PARTICIPANT	\N	PRESENT	0
699415	698966	14207L	PARTICIPANT	\N	PRESENT	0
699416	698966	19681G	PARTICIPANT	\N	PRESENT	0
699417	698966	18083K	PARTICIPANT	\N	PRESENT	0
699418	698966	20122U	PARTICIPANT	\N	PRESENT	0
699419	698966	04057K	PARTICIPANT	\N	PRESENT	0
699420	698966	14123H	PARTICIPANT	\N	PRESENT	0
699421	698966	14083S	PARTICIPANT	\N	PRESENT	0
699422	698966	19745F	PARTICIPANT	\N	PRESENT	0
699423	698966	20144B	PARTICIPANT	\N	PRESENT	0
699424	698966	14189C	PARTICIPANT	\N	PRESENT	0
699425	698966	19685L	PARTICIPANT	\N	PRESENT	0
699426	698966	19747H	PARTICIPANT	\N	PRESENT	0
699427	698966	20252E	PARTICIPANT	\N	PRESENT	0
699428	698966	20074E	PARTICIPANT	\N	PRESENT	0
699429	698966	20076G	PARTICIPANT	\N	PRESENT	0
699430	698966	17737W	PARTICIPANT	\N	PRESENT	0
699431	698966	19762G	PARTICIPANT	\N	PRESENT	0
699432	698966	20062A	PARTICIPANT	\N	PRESENT	0
699433	698966	20090E	PARTICIPANT	\N	PRESENT	0
699434	698966	97011G	PARTICIPANT	\N	PRESENT	0
699435	698966	20980G	PARTICIPANT	\N	PRESENT	0
699437	699436	05008E	PARTICIPANT	\N	PRESENT	0
699438	699436	11053K	PARTICIPANT	\N	PRESENT	0
699439	699436	01028R	PARTICIPANT	\N	PRESENT	0
699440	698966	19619A	PARTICIPANT	\N	PRESENT	0
699441	698966	19515S	PARTICIPANT	\N	PRESENT	0
699442	698966	19507S	PARTICIPANT	\N	PRESENT	0
699443	698966	14221J	PARTICIPANT	\N	PRESENT	0
699444	698966	19701S	PARTICIPANT	\N	PRESENT	0
699445	698966	14357A	PARTICIPANT	\N	PRESENT	0
699446	698966	19711U	PARTICIPANT	\N	PRESENT	0
699447	698966	01048V	PARTICIPANT	\N	PRESENT	0
686779	686428	19335Q	PARTICIPANT	\N	PRESENT	0
686780	686700	14187A	PARTICIPANT	\N	PRESENT	0
686781	686428	08034U	PARTICIPANT	\N	PRESENT	0
686782	686428	11074Q	PARTICIPANT	\N	PRESENT	0
686783	686700	19515S	PARTICIPANT	\N	PRESENT	0
686784	686428	11048N	PARTICIPANT	\N	PRESENT	0
686785	686700	19581D	PARTICIPANT	\N	PRESENT	0
686786	686700	20038A	PARTICIPANT	\N	PRESENT	0
686787	686700	19679N	PARTICIPANT	\N	PRESENT	0
686788	686700	14331P	PARTICIPANT	\N	PRESENT	0
686789	686700	19826F	PARTICIPANT	\N	PRESENT	0
686790	686700	19319Q	PARTICIPANT	\N	PRESENT	0
686791	686700	08015R	PARTICIPANT	\N	PRESENT	0
686792	686700	14001X	PARTICIPANT	\N	PRESENT	0
686793	686700	19705W	PARTICIPANT	\N	PRESENT	0
686794	686700	20098N	PARTICIPANT	\N	PRESENT	0
686795	686700	20266L	PARTICIPANT	\N	PRESENT	0
686796	686700	20072C	PARTICIPANT	\N	PRESENT	0
686797	686700	20024T	PARTICIPANT	\N	PRESENT	0
686798	686700	19599P	PARTICIPANT	\N	PRESENT	0
686808	686700	14073Q	PARTICIPANT	\N	PRESENT	0
686818	686700	14105F	PARTICIPANT	\N	PRESENT	0
686820	686700	20126Y	PARTICIPANT	\N	PRESENT	0
686823	686700	20028X	PARTICIPANT	\N	PRESENT	0
686825	686700	18193Q	PARTICIPANT	\N	PRESENT	0
686826	686700	19715Y	PARTICIPANT	\N	PRESENT	0
686827	686700	10006L	PARTICIPANT	\N	PRESENT	0
686828	686700	14071N	PARTICIPANT	\N	PRESENT	0
686858	686700	04045F	PARTICIPANT	\N	PRESENT	0
686859	686700	20018V	PARTICIPANT	\N	PRESENT	0
686860	686700	19593H	PARTICIPANT	\N	PRESENT	0
686862	686700	11045K	PARTICIPANT	\N	PRESENT	0
686867	686700	14189C	PARTICIPANT	\N	PRESENT	0
686868	686700	19563B	PARTICIPANT	\N	PRESENT	0
686869	686700	08012N	PARTICIPANT	\N	PRESENT	0
686870	686700	20052X	PARTICIPANT	\N	PRESENT	0
686871	686700	14267Y	PARTICIPANT	\N	PRESENT	0
686872	686700	14123H	PARTICIPANT	\N	PRESENT	0
686873	686700	14213J	PARTICIPANT	\N	PRESENT	0
686874	686700	14207L	PARTICIPANT	\N	PRESENT	0
686875	686700	19693L	PARTICIPANT	\N	PRESENT	0
686876	686700	04057K	PARTICIPANT	\N	PRESENT	0
687361	687358	14133K	PARTICIPANT	\N	PRESENT	0
687363	687358	14097Y	PARTICIPANT	\N	PRESENT	0
687365	687364	14133K	PARTICIPANT	\N	PRESENT	0
687366	687364	14217N	PARTICIPANT	\N	PRESENT	0
686882	686701	12041X	PARTICIPANT	\N	PRESENT	0
687360	687358	14217N	PARTICIPANT	\N	PRESENT	0
694767	692535	20130U	PARTICIPANT	\N	PRESENT	0
694768	692535	11067R	PARTICIPANT	\N	PRESENT	0
694769	692535	11031D	PARTICIPANT	\N	PRESENT	0
694770	692535	20066E	PARTICIPANT	\N	PRESENT	0
694771	692535	01034P	PARTICIPANT	\N	PRESENT	0
694772	692535	14195A	PARTICIPANT	\N	PRESENT	0
694773	692535	20266L	PARTICIPANT	\N	PRESENT	0
694774	692535	14213J	PARTICIPANT	\N	PRESENT	0
694775	692535	14026U	PARTICIPANT	\N	PRESENT	0
694776	692535	20040T	PARTICIPANT	\N	PRESENT	0
694777	692535	19415P	PARTICIPANT	\N	PRESENT	0
694778	692535	20090E	PARTICIPANT	\N	PRESENT	0
694779	692535	11097X	PARTICIPANT	\N	PRESENT	0
694780	692535	14071N	PARTICIPANT	\N	PRESENT	0
694781	692535	19569H	PARTICIPANT	\N	PRESENT	0
694782	692535	19691J	PARTICIPANT	\N	PRESENT	0
694783	692535	14042U	PARTICIPANT	\N	PRESENT	0
694784	692535	19479G	PARTICIPANT	\N	PRESENT	0
694793	692535	19591F	PARTICIPANT	\N	PRESENT	0
694794	692535	19697Q	PARTICIPANT	\N	PRESENT	0
694795	692535	14217N	PARTICIPANT	\N	PRESENT	0
694921	691670	19593H	PARTICIPANT	\N	PRESENT	0
694922	691670	20132W	PARTICIPANT	\N	PRESENT	0
694923	691670	20134Y	PARTICIPANT	\N	PRESENT	0
694924	691670	19699S	PARTICIPANT	\N	PRESENT	0
694925	691670	19533U	PARTICIPANT	\N	PRESENT	0
694926	691670	14073Q	PARTICIPANT	\N	PRESENT	0
694927	691670	19611R	PRESIDENT	0	PRESENT	0
694928	691670	20142Y	PARTICIPANT	\N	PRESENT	0
694929	691670	20048C	PARTICIPANT	\N	PRESENT	0
694930	691670	19693L	PARTICIPANT	\N	PRESENT	0
694931	691670	20152B	PARTICIPANT	\N	PRESENT	0
694932	691670	20052X	PARTICIPANT	\N	PRESENT	0
694933	691670	14229S	PARTICIPANT	\N	PRESENT	0
694934	691670	14030Q	PARTICIPANT	\N	PRESENT	0
694935	691670	20264J	PARTICIPANT	\N	PRESENT	0
694936	691670	19735D	PARTICIPANT	\N	PRESENT	0
694938	694354	14193X	PARTICIPANT	\N	PRESENT	0
695015	694958	14042U	PARTICIPANT	\N	PRESENT	0
695003	695001	20056C	PARTICIPANT	\N	PRESENT	0
695004	695001	95063L	PARTICIPANT	\N	PRESENT	0
695014	695006	19703U	PARTICIPANT	\N	PRESENT	1
695016	694958	11097X	PARTICIPANT	\N	PRESENT	0
695017	694958	11067R	PARTICIPANT	\N	PRESENT	0
695018	694958	20130U	PARTICIPANT	\N	PRESENT	0
695019	694958	18193Q	PARTICIPANT	\N	PRESENT	0
695020	694959	14042U	PARTICIPANT	\N	PRESENT	0
695021	694959	11097X	PARTICIPANT	\N	PRESENT	0
695022	694959	20130U	PARTICIPANT	\N	PRESENT	0
695023	694959	11067R	PARTICIPANT	\N	PRESENT	0
695024	694959	18193Q	PARTICIPANT	\N	PRESENT	0
695025	694960	14042U	PARTICIPANT	\N	PRESENT	0
695026	694960	18193Q	PARTICIPANT	\N	PRESENT	0
695027	694960	11097X	PARTICIPANT	\N	PRESENT	0
695028	695005	14053L	PARTICIPANT	\N	PRESENT	0
695029	695005	14331P	PARTICIPANT	\N	PRESENT	0
695030	695005	20116W	PARTICIPANT	\N	PRESENT	0
695031	695005	14083S	PARTICIPANT	\N	PRESENT	0
695032	695005	14031R	PARTICIPANT	\N	PRESENT	0
695075	695059	14213J	PARTICIPANT	\N	PRESENT	0
695076	695059	14042U	PARTICIPANT	\N	PRESENT	0
695077	695062	14213J	PARTICIPANT	\N	PRESENT	0
695078	695063	14217N	PARTICIPANT	\N	PRESENT	0
695079	695063	14213J	PARTICIPANT	\N	PRESENT	0
695080	695063	11097X	PARTICIPANT	\N	PRESENT	0
695081	695064	11031D	PARTICIPANT	\N	PRESENT	0
695082	695064	14042U	PARTICIPANT	\N	PRESENT	0
695083	695064	14213J	PARTICIPANT	\N	PRESENT	0
695084	695064	17965H	PARTICIPANT	\N	PRESENT	0
695085	695065	14042U	PARTICIPANT	\N	PRESENT	0
695086	695065	14213J	PARTICIPANT	\N	PRESENT	0
695087	695065	17965H	PARTICIPANT	\N	PRESENT	0
695088	695066	14213J	PARTICIPANT	\N	PRESENT	0
695089	695066	19553Y	PARTICIPANT	\N	PRESENT	0
695090	695066	18193Q	PARTICIPANT	\N	PRESENT	0
695091	695066	17965H	PARTICIPANT	\N	PRESENT	0
695092	695067	19553Y	PARTICIPANT	\N	PRESENT	0
695093	695067	14213J	PARTICIPANT	\N	PRESENT	0
695094	695067	18193Q	PARTICIPANT	\N	PRESENT	0
695095	695067	17965H	PARTICIPANT	\N	PRESENT	0
695096	695068	14042U	PARTICIPANT	\N	PRESENT	0
695097	695068	14213J	PARTICIPANT	\N	PRESENT	0
695098	695068	18193Q	PARTICIPANT	\N	PRESENT	0
695099	695068	17965H	PARTICIPANT	\N	PRESENT	0
695100	695074	14213J	PARTICIPANT	\N	PRESENT	0
695101	695074	18193Q	PARTICIPANT	\N	PRESENT	0
695102	695074	17965H	PARTICIPANT	\N	PRESENT	0
695103	695069	14213J	PARTICIPANT	\N	PRESENT	0
695104	695069	17965H	PARTICIPANT	\N	PRESENT	0
695105	695073	14213J	PARTICIPANT	\N	PRESENT	0
695106	695073	17965H	PARTICIPANT	\N	PRESENT	0
695197	693561	14147R	PARTICIPANT	\N	PRESENT	0
695114	695112	19643A	PARTICIPANT	\N	PRESENT	0
695115	695112	19735D	PARTICIPANT	\N	PRESENT	0
695116	695112	19693L	PARTICIPANT	\N	PRESENT	0
695118	695117	14259Y	PARTICIPANT	\N	PRESENT	0
695119	695117	14097Y	PARTICIPANT	\N	PRESENT	0
695121	695120	19251M	PARTICIPANT	\N	PRESENT	0
695192	695191	14205J	PARTICIPANT	\N	PRESENT	0
695196	693561	14219Q	PARTICIPANT	\N	EXCUSE	0
695198	693586	14147R	PARTICIPANT	\N	PRESENT	0
695199	693586	14219Q	PARTICIPANT	\N	EXCUSE	0
695200	693587	14219Q	PARTICIPANT	\N	EXCUSE	0
695201	693587	14147R	PARTICIPANT	\N	PRESENT	0
695203	695202	14187A	PARTICIPANT	\N	PRESENT	0
695205	695204	14187A	PARTICIPANT	\N	PRESENT	0
695207	695206	14187A	PARTICIPANT	\N	PRESENT	0
695209	695208	14187A	PARTICIPANT	\N	PRESENT	0
696271	693394	19549D	PARTICIPANT	\N	PRESENT	0
696272	693394	20076G	PARTICIPANT	\N	PRESENT	0
696273	693394	14237S	PARTICIPANT	\N	PRESENT	0
696274	693394	08060W	PARTICIPANT	\N	PRESENT	0
696279	693394	19820Y	PARTICIPANT	\N	PRESENT	0
705711	704081	14038Y	PARTICIPANT	\N	PRESENT	0
705712	704081	19565D	PARTICIPANT	\N	PRESENT	0
705718	704081	19611R	PARTICIPANT	\N	PRESENT	0
705716	704081	14147R	PARTICIPANT	\N	PRESENT	0
705719	704081	19563B	PARTICIPANT	\N	PRESENT	0
705720	704081	11045K	PARTICIPANT	\N	PRESENT	0
705721	704081	11031D	PARTICIPANT	\N	PRESENT	0
705722	704081	04047H	PARTICIPANT	\N	PRESENT	0
705723	704081	14357A	PARTICIPANT	\N	PRESENT	0
705724	704081	19691J	PARTICIPANT	\N	PRESENT	0
705725	704081	19599P	PARTICIPANT	\N	PRESENT	0
705726	704081	14179A	PARTICIPANT	\N	PRESENT	0
705727	704081	19057M	PARTICIPANT	\N	PRESENT	0
705728	704081	19349W	PARTICIPANT	\N	PRESENT	0
705729	704081	14213J	PARTICIPANT	\N	PRESENT	0
705730	704081	20128B	PARTICIPANT	\N	PRESENT	0
705731	704081	19758L	PARTICIPANT	\N	PRESENT	0
705755	704082	14229S	PARTICIPANT	\N	PRESENT	0
705756	704082	19621T	PARTICIPANT	\N	PRESENT	0
705757	704082	20132W	PARTICIPANT	\N	PRESENT	0
705758	704082	14073Q	PARTICIPANT	\N	PRESENT	0
705759	704082	08012N	PARTICIPANT	\N	PRESENT	0
705760	704082	20134Y	PARTICIPANT	\N	PRESENT	0
705761	704082	19629C	PARTICIPANT	\N	PRESENT	0
705762	704082	14109K	PARTICIPANT	\N	PRESENT	0
705763	704082	20122U	PARTICIPANT	\N	PRESENT	0
705764	704082	14069U	PARTICIPANT	\N	PRESENT	0
705765	704082	19573D	PARTICIPANT	\N	PRESENT	0
705766	704082	20124W	PARTICIPANT	\N	PRESENT	0
705767	704082	19820Y	PARTICIPANT	\N	PRESENT	0
705768	704082	17965H	PARTICIPANT	\N	PRESENT	0
705769	704082	19503N	PARTICIPANT	\N	PRESENT	0
705770	704082	19593H	PARTICIPANT	\N	PRESENT	0
705771	704082	19758L	PARTICIPANT	\N	PRESENT	0
705772	704082	19057M	PARTICIPANT	\N	PRESENT	0
705773	704082	20100N	PARTICIPANT	\N	PRESENT	0
705774	704082	20180F	PARTICIPANT	\N	PRESENT	0
705775	704082	20080C	PARTICIPANT	\N	PRESENT	0
705753	704082	11070L	PARTICIPANT	\N	PRESENT	0
705754	704082	20152B	PARTICIPANT	\N	PRESENT	0
705776	704082	18193Q	PARTICIPANT	\N	PRESENT	0
705777	704082	20264J	PARTICIPANT	\N	PRESENT	0
705778	704082	19715Y	PARTICIPANT	\N	PRESENT	0
705779	704082	20032T	PARTICIPANT	\N	PRESENT	0
705780	704082	14021P	PARTICIPANT	\N	PRESENT	0
705781	704082	20980G	PARTICIPANT	\N	PRESENT	0
705782	704082	14030Q	PARTICIPANT	\N	PRESENT	0
705783	704082	20082E	PARTICIPANT	\N	PRESENT	0
705784	704082	14123H	PARTICIPANT	\N	PRESENT	0
705785	704082	19347U	PARTICIPANT	\N	PRESENT	0
705786	704082	20062A	PARTICIPANT	\N	PRESENT	0
705787	704082	14213J	PARTICIPANT	\N	PRESENT	0
705788	704082	14033T	PARTICIPANT	\N	PRESENT	0
705789	704082	14083S	PARTICIPANT	\N	PRESENT	0
705812	703672	14189C	PARTICIPANT	\N	PRESENT	0
705813	703672	11101A	PARTICIPANT	\N	PRESENT	0
705814	703672	20100N	PARTICIPANT	\N	PRESENT	0
705815	703672	20286Q	PARTICIPANT	\N	PRESENT	0
705816	703672	19531S	PARTICIPANT	\N	PRESENT	0
705817	703672	14073Q	PARTICIPANT	\N	PRESENT	0
705818	703672	14001X	PARTICIPANT	\N	PRESENT	0
705821	703672	19593H	PARTICIPANT	\N	PRESENT	0
705823	703672	14331P	PARTICIPANT	\N	PRESENT	0
705825	703672	10015M	PARTICIPANT	\N	PRESENT	0
705833	703672	11026G	PARTICIPANT	\N	PRESENT	0
705834	704330	14331P	PARTICIPANT	\N	PRESENT	0
705835	704330	14073Q	PARTICIPANT	\N	PRESENT	0
705836	704330	14001X	PARTICIPANT	\N	PRESENT	0
705856	703672	14026U	PARTICIPANT	\N	PRESENT	0
705858	699132	19295A	PARTICIPANT	\N	EXCUSE	0
705859	699132	18083K	PARTICIPANT	\N	EXCUSE	0
705860	699132	12016W	PARTICIPANT	\N	PRESENT	0
705883	705882	19503N	PARTICIPANT	\N	PRESENT	0
706103	704075	19760E	PARTICIPANT	\N	PRESENT	0
706104	704075	05008E	PARTICIPANT	\N	PRESENT	0
706105	704075	14030Q	PARTICIPANT	\N	PRESENT	0
706106	704075	17737W	PARTICIPANT	\N	PRESENT	0
706107	704075	14053L	PARTICIPANT	\N	PRESENT	0
706108	704075	14083S	PARTICIPANT	\N	PRESENT	0
706109	704075	19693L	PARTICIPANT	\N	PRESENT	0
706110	704075	14215L	PARTICIPANT	\N	PRESENT	0
706111	704075	20120S	PARTICIPANT	\N	PRESENT	0
706112	704075	20066E	PARTICIPANT	\N	PRESENT	0
706113	704075	20034V	PARTICIPANT	\N	PRESENT	0
706114	704075	14059S	PARTICIPANT	\N	PRESENT	0
705665	704081	19649G	PARTICIPANT	\N	PRESENT	0
706115	704075	19657G	PARTICIPANT	\N	PRESENT	0
706116	704075	14147R	PARTICIPANT	\N	PRESENT	0
706117	704075	11067R	PARTICIPANT	\N	PRESENT	0
706118	704075	14223L	PARTICIPANT	\N	PRESENT	0
706119	704075	14071N	PARTICIPANT	\N	PRESENT	0
705671	704081	19749K	PARTICIPANT	\N	PRESENT	0
706120	704075	14331P	PARTICIPANT	\N	PRESENT	0
705673	704081	14215L	PARTICIPANT	\N	PRESENT	0
706121	704075	19766L	PARTICIPANT	\N	PRESENT	0
706122	704075	19798U	PARTICIPANT	\N	PRESENT	0
706123	704075	19703U	PARTICIPANT	\N	PRESENT	0
705677	704081	20062A	PARTICIPANT	\N	PRESENT	0
706124	704075	20062A	PARTICIPANT	\N	PRESENT	0
706125	704075	20058E	PARTICIPANT	\N	PRESENT	0
706130	706128	20264J	PARTICIPANT	\N	PRESENT	0
705681	704081	20264J	PARTICIPANT	\N	PRESENT	0
706131	706128	19691J	PARTICIPANT	\N	PRESENT	0
705683	704081	14053L	PARTICIPANT	\N	PRESENT	0
706132	706128	20980G	PARTICIPANT	\N	PRESENT	0
706133	706128	19335Q	PARTICIPANT	\N	PRESENT	0
705686	704081	14107H	PARTICIPANT	\N	PRESENT	0
705687	704081	14109K	PARTICIPANT	\N	PRESENT	0
706134	706128	20106U	PARTICIPANT	\N	PRESENT	0
706142	706135	19643A	PARTICIPANT	\N	PRESENT	0
705690	704081	20070A	PARTICIPANT	\N	PRESENT	0
706143	706135	19735D	PARTICIPANT	\N	PRESENT	0
706144	706136	20112S	PARTICIPANT	\N	PRESENT	0
705693	704081	20100N	PARTICIPANT	\N	PRESENT	0
706145	706137	19643A	PARTICIPANT	\N	PRESENT	0
706146	706137	20112S	PARTICIPANT	\N	PRESENT	0
705696	704081	19701S	PARTICIPANT	\N	PRESENT	0
706147	706137	19735D	PARTICIPANT	\N	PRESENT	0
706148	706141	20112S	PARTICIPANT	\N	PRESENT	0
705699	704081	20980G	PARTICIPANT	\N	PRESENT	0
705700	704081	20180F	PARTICIPANT	\N	PRESENT	0
706149	706141	19643A	PARTICIPANT	\N	PRESENT	0
705702	704081	14026U	PARTICIPANT	\N	PRESENT	0
705703	704081	19954N	PARTICIPANT	\N	PRESENT	0
705704	704081	20022R	PARTICIPANT	\N	PRESENT	0
705705	704081	20914V	PARTICIPANT	\N	PRESENT	0
705706	704081	95063L	PARTICIPANT	\N	PRESENT	0
706150	706141	19735D	PARTICIPANT	\N	PRESENT	0
706158	705637	11074Q	PARTICIPANT	\N	PRESENT	0
706159	705637	08045X	PARTICIPANT	\N	PRESENT	0
706168	706151	19515S	PRESIDENT	0	PRESENT	0
706169	706151	20094J	PARTICIPANT	\N	PRESENT	0
706170	706151	19575F	PARTICIPANT	\N	PRESENT	0
706171	706151	14083S	PARTICIPANT	\N	PRESENT	0
706172	706151	14026U	PARTICIPANT	\N	PRESENT	0
706173	706151	19467C	PARTICIPANT	\N	PRESENT	0
706174	706151	14357A	PARTICIPANT	\N	PRESENT	0
706176	706151	08015R	PARTICIPANT	\N	PRESENT	0
706179	706151	19762G	PARTICIPANT	\N	PRESENT	0
706192	706151	20054A	PARTICIPANT	\N	EXCUSE	0
706194	706151	20092G	PARTICIPANT	\N	EXCUSE	0
706195	706151	19369B	PARTICIPANT	\N	EXCUSE	0
706196	706151	14253S	PARTICIPANT	\N	EXCUSE	0
706197	706151	19866P	PARTICIPANT	\N	EXCUSE	0
706208	706151	14031R	PARTICIPANT	\N	EXCUSE	0
706213	706151	16685X	PARTICIPANT	\N	EXCUSE	0
706214	706151	20126Y	PARTICIPANT	\N	EXCUSE	0
706221	706151	20048C	PARTICIPANT	\N	EXCUSE	0
706223	706151	19251M	PARTICIPANT	\N	EXCUSE	0
706224	706151	08028W	PARTICIPANT	\N	EXCUSE	0
706225	706151	14329V	PARTICIPANT	\N	EXCUSE	0
706227	706151	20060X	PARTICIPANT	\N	EXCUSE	0
706228	706151	19545Y	PARTICIPANT	\N	EXCUSE	0
706229	706151	14105F	PARTICIPANT	\N	EXCUSE	0
706230	706151	08060W	PARTICIPANT	\N	EXCUSE	0
706231	706151	14030Q	PARTICIPANT	\N	EXCUSE	0
706236	706234	05008E	PARTICIPANT	\N	EXCUSE	0
706241	706240	19673G	PARTICIPANT	\N	PRESENT	0
706243	706242	20056C	PARTICIPANT	\N	PRESENT	0
708053	708050	86034E	PARTICIPANT	\N	PRESENT	0
686346	686343	04047H	PARTICIPANT	\N	PRESENT	0
686347	686343	14231L	PARTICIPANT	\N	PRESENT	0
686348	686343	14259Y	PARTICIPANT	\N	PRESENT	0
686349	686343	11048N	PARTICIPANT	\N	PRESENT	0
692821	692638	11027H	PARTICIPANT	\N	PRESENT	0
692822	692638	20264J	PARTICIPANT	\N	PRESENT	0
692823	692638	14151M	PARTICIPANT	\N	PRESENT	0
692824	692638	11074Q	PARTICIPANT	\N	PRESENT	0
692825	692638	19647E	PARTICIPANT	\N	PRESENT	0
692826	692638	04033B	PARTICIPANT	\N	PRESENT	0
692827	692638	08034U	PARTICIPANT	\N	PRESENT	0
692828	692638	08045X	PARTICIPANT	\N	PRESENT	0
692829	692638	19709B	PARTICIPANT	\N	PRESENT	0
692830	692638	19820Y	PARTICIPANT	\N	PRESENT	0
692831	692638	14193X	PARTICIPANT	\N	PRESENT	0
692832	692638	19725B	PARTICIPANT	\N	PRESENT	0
692833	692638	19747H	PARTICIPANT	\N	PRESENT	0
692834	692638	04047H	PARTICIPANT	\N	PRESENT	0
692835	692638	08010L	PARTICIPANT	\N	PRESENT	0
692836	692638	14026U	PARTICIPANT	\N	PRESENT	0
692837	692638	14097Y	PARTICIPANT	\N	PRESENT	0
692838	692638	19679N	PARTICIPANT	\N	PRESENT	0
692839	692638	14021P	PARTICIPANT	\N	PRESENT	0
692840	692638	19489J	PARTICIPANT	\N	PRESENT	0
692841	692638	19693L	PARTICIPANT	\N	PRESENT	0
692842	692638	95063L	PARTICIPANT	\N	PRESENT	0
692843	692638	14123H	PARTICIPANT	\N	PRESENT	0
692844	692638	04035D	PARTICIPANT	\N	PRESENT	0
692845	692638	20122U	PARTICIPANT	\N	PRESENT	0
692846	692638	11067R	PARTICIPANT	\N	PRESENT	0
692847	692638	04008A	PARTICIPANT	\N	PRESENT	0
692848	692638	19711U	PARTICIPANT	\N	PRESENT	0
692849	692638	04071H	PARTICIPANT	\N	PRESENT	0
692850	692638	07029T	PARTICIPANT	\N	PRESENT	0
692851	692638	14109K	PARTICIPANT	\N	PRESENT	0
692852	692638	14257W	PARTICIPANT	\N	PRESENT	0
692853	692638	19729F	PARTICIPANT	\N	PRESENT	0
692854	692638	12016W	PARTICIPANT	\N	PRESENT	0
692855	692638	19503N	PARTICIPANT	\N	PRESENT	0
692856	692638	04043D	PARTICIPANT	\N	PRESENT	0
692857	692638	19333N	PARTICIPANT	\N	PRESENT	0
692858	692638	19715Y	PARTICIPANT	\N	PRESENT	0
692859	692638	17779H	PARTICIPANT	\N	PRESENT	0
692860	692638	14217N	PARTICIPANT	\N	PRESENT	0
692861	692638	19383Y	PARTICIPANT	\N	PRESENT	0
692862	692638	14225N	PARTICIPANT	\N	PRESENT	0
692863	692638	14229S	PARTICIPANT	\N	PRESENT	0
692864	692638	11054L	PARTICIPANT	\N	PRESENT	0
692865	692638	11045K	PARTICIPANT	\N	PRESENT	0
692866	692638	20120S	PARTICIPANT	\N	PRESENT	0
692867	692638	20084G	PARTICIPANT	\N	PRESENT	0
692868	692638	20252E	PARTICIPANT	\N	PRESENT	0
692869	692638	11097X	PARTICIPANT	\N	PRESENT	0
692870	692638	20134Y	PARTICIPANT	\N	PRESENT	0
692871	692638	20096L	PARTICIPANT	\N	PRESENT	0
692872	692638	01062T	PARTICIPANT	\N	PRESENT	0
692873	692638	20064C	PARTICIPANT	\N	PRESENT	0
692874	692638	19527W	PARTICIPANT	\N	PRESENT	0
692875	692638	14223L	PARTICIPANT	\N	PRESENT	0
692876	692638	11066Q	PARTICIPANT	\N	PRESENT	0
692877	692638	19399H	PARTICIPANT	\N	PRESENT	0
692878	692638	08015R	PARTICIPANT	\N	PRESENT	0
692879	692638	19543W	PARTICIPANT	\N	PRESENT	0
692880	692638	04042C	PARTICIPANT	\N	PRESENT	0
692881	692638	14030Q	PARTICIPANT	\N	PRESENT	0
692882	692638	01048V	PARTICIPANT	\N	PRESENT	0
692883	692638	14255U	PARTICIPANT	\N	PRESENT	0
692884	692638	14083S	PARTICIPANT	\N	PRESENT	0
692885	692638	19415P	PARTICIPANT	\N	PRESENT	0
692886	692638	14267Y	PARTICIPANT	\N	PRESENT	0
692887	692638	14147R	PARTICIPANT	\N	PRESENT	0
692888	692638	11070L	PARTICIPANT	\N	PRESENT	0
692889	692638	17229F	PARTICIPANT	\N	PRESENT	0
692890	692638	20108W	PARTICIPANT	\N	PRESENT	0
692891	692638	20040T	PARTICIPANT	\N	PRESENT	0
692892	692638	20110Q	PARTICIPANT	\N	PRESENT	0
692893	692638	07004J	PARTICIPANT	\N	PRESENT	0
692894	692638	20058E	PARTICIPANT	\N	PRESENT	0
692895	692638	01024M	PARTICIPANT	\N	PRESENT	0
692896	692638	20286Q	PARTICIPANT	\N	PRESENT	0
692897	692638	14179A	PARTICIPANT	\N	PRESENT	0
692898	692638	19685L	PARTICIPANT	\N	PRESENT	0
692899	692638	20048C	PARTICIPANT	\N	PRESENT	0
692900	692638	14073Q	PARTICIPANT	\N	PRESENT	0
692901	692638	19735D	PARTICIPANT	\N	PRESENT	0
692902	692638	20052X	PARTICIPANT	\N	PRESENT	0
692903	692638	14205J	PARTICIPANT	\N	PRESENT	0
692904	692638	14219Q	PARTICIPANT	\N	PRESENT	0
692905	692638	19826F	PARTICIPANT	\N	PRESENT	0
692906	692638	19581D	PARTICIPANT	\N	PRESENT	0
692907	692638	17589D	PARTICIPANT	\N	PRESENT	0
692908	692638	14249W	PARTICIPANT	\N	PRESENT	0
692909	692638	20026V	PARTICIPANT	\N	PRESENT	0
692910	692638	08009T	PARTICIPANT	\N	PRESENT	0
692911	692638	19335Q	PARTICIPANT	\N	PRESENT	0
692912	692638	19369B	PARTICIPANT	\N	PRESENT	0
692913	692638	04070G	PARTICIPANT	\N	PRESENT	0
692914	692638	19745F	PARTICIPANT	\N	PRESENT	0
692915	692638	19319Q	PARTICIPANT	\N	PRESENT	0
692916	692638	19441R	PARTICIPANT	\N	PRESENT	0
692917	692638	19699S	PARTICIPANT	\N	PRESENT	0
692918	692638	14275Y	PARTICIPANT	\N	PRESENT	0
692919	692638	19479G	PARTICIPANT	\N	PRESENT	0
692920	692638	19749K	PARTICIPANT	\N	PRESENT	0
692921	692638	20066E	PARTICIPANT	\N	PRESENT	0
692922	692638	19691J	PARTICIPANT	\N	PRESENT	0
692923	692638	01043Q	PARTICIPANT	\N	PRESENT	0
692924	692638	19721W	PARTICIPANT	\N	PRESENT	0
692925	692638	19565D	PARTICIPANT	\N	PRESENT	0
692926	692638	14327T	PARTICIPANT	\N	PRESENT	0
692927	692638	20094J	PARTICIPANT	\N	PRESENT	0
692928	692638	08069G	PARTICIPANT	\N	PRESENT	0
692929	692638	19723Y	PARTICIPANT	\N	PRESENT	0
692930	692638	14281W	PARTICIPANT	\N	PRESENT	0
692931	692638	20106U	PARTICIPANT	\N	PRESENT	0
692932	692638	20042V	PARTICIPANT	\N	PRESENT	0
692933	692638	19611R	PARTICIPANT	\N	PRESENT	0
692934	692638	19507S	PARTICIPANT	\N	PRESENT	0
692935	692638	17367Q	PARTICIPANT	\N	PRESENT	0
692936	692638	20086J	PARTICIPANT	\N	PRESENT	0
692937	692638	14133K	PARTICIPANT	\N	PRESENT	0
692938	692638	14173T	PARTICIPANT	\N	PRESENT	0
692939	692638	14207L	PARTICIPANT	\N	PRESENT	0
692955	692638	20148F	PARTICIPANT	\N	PRESENT	0
692956	692638	20104S	PARTICIPANT	\N	PRESENT	0
692957	692638	14121F	PARTICIPANT	\N	PRESENT	0
692958	692638	01028R	PARTICIPANT	\N	PRESENT	0
692959	692638	19669L	PARTICIPANT	\N	PRESENT	0
692960	692638	11104D	PARTICIPANT	\N	PRESENT	0
692961	692638	19421M	PARTICIPANT	\N	PRESENT	0
692962	692638	19768N	PARTICIPANT	\N	PRESENT	0
692963	692638	17023S	PARTICIPANT	\N	PRESENT	0
692964	692638	20136B	PARTICIPANT	\N	PRESENT	0
692965	692638	11026G	PARTICIPANT	\N	PRESENT	0
699450	698966	08028W	PARTICIPANT	\N	PRESENT	0
699451	698966	19563B	PARTICIPANT	\N	PRESENT	0
699452	698966	04045F	PARTICIPANT	\N	PRESENT	0
699453	698966	14169X	PARTICIPANT	\N	PRESENT	0
699454	698966	08015R	PARTICIPANT	\N	PRESENT	0
699455	698966	20138D	PARTICIPANT	\N	PRESENT	0
699456	698966	19549D	PARTICIPANT	\N	PRESENT	0
699457	698966	19525U	PARTICIPANT	\N	PRESENT	0
699458	698966	19387D	PARTICIPANT	\N	PRESENT	0
699459	698966	11074Q	PARTICIPANT	\N	PRESENT	0
699460	698966	20136B	PARTICIPANT	\N	PRESENT	0
699461	698966	19349W	PARTICIPANT	\N	PRESENT	0
699462	698966	20106U	PARTICIPANT	\N	PRESENT	0
699463	698966	20046A	PARTICIPANT	\N	PRESENT	0
699464	698966	20028X	PARTICIPANT	\N	PRESENT	0
699465	698966	11077T	PARTICIPANT	\N	PRESENT	0
699466	698966	98022P	PARTICIPANT	\N	PRESENT	0
699467	698966	20116W	PARTICIPANT	\N	PRESENT	0
699496	698966	20044X	PARTICIPANT	\N	PRESENT	0
699497	698966	20100N	PARTICIPANT	\N	PRESENT	0
699503	698966	20086J	PARTICIPANT	\N	PRESENT	0
699504	698966	14030Q	PARTICIPANT	\N	PRESENT	0
699505	698966	20298U	PARTICIPANT	\N	PRESENT	0
699506	698966	01025N	PARTICIPANT	\N	PRESENT	0
699507	698966	14121F	PARTICIPANT	\N	PRESENT	0
699508	698966	20066E	PARTICIPANT	\N	PRESENT	0
699509	698966	11090Q	PARTICIPANT	\N	PRESENT	0
699510	698966	14219Q	PARTICIPANT	\N	PRESENT	0
699511	698966	20032T	PARTICIPANT	\N	PRESENT	0
699512	698966	19687N	PARTICIPANT	\N	PRESENT	0
699513	698966	19503N	PARTICIPANT	\N	PRESENT	0
699514	698966	19699S	PARTICIPANT	\N	PRESENT	0
699515	698966	20172F	PARTICIPANT	\N	PRESENT	0
699516	698966	20052X	PARTICIPANT	\N	PRESENT	0
699517	698966	08056B	PARTICIPANT	\N	PRESENT	0
699518	698966	20096L	PARTICIPANT	\N	PRESENT	0
699519	698966	20050V	PARTICIPANT	\N	PRESENT	0
699520	698966	14038Y	PARTICIPANT	\N	PRESENT	0
699521	698966	20142Y	PARTICIPANT	\N	PRESENT	0
699448	698966	14147R	PARTICIPANT	\N	PRESENT	0
699449	698966	01024M	PARTICIPANT	\N	PRESENT	0
699579	698967	14121F	PARTICIPANT	\N	PRESENT	0
699580	698967	19549D	PARTICIPANT	\N	PRESENT	0
699581	698967	19820Y	PARTICIPANT	\N	PRESENT	0
699582	698967	11065P	PARTICIPANT	\N	PRESENT	0
699583	698967	20142Y	PARTICIPANT	\N	PRESENT	0
699584	698967	19251M	PARTICIPANT	\N	PRESENT	0
699585	698967	19333N	PARTICIPANT	\N	PRESENT	0
699586	698967	20106U	PARTICIPANT	\N	PRESENT	0
699587	698967	04045F	PARTICIPANT	\N	PRESENT	0
699588	698967	20128B	PARTICIPANT	\N	PRESENT	0
699589	698967	20050V	PARTICIPANT	\N	PRESENT	0
699590	698967	11012A	PARTICIPANT	\N	PRESENT	0
699591	698967	19745F	PARTICIPANT	\N	PRESENT	0
699592	698967	19619A	PARTICIPANT	\N	PRESENT	0
699593	698967	20144B	PARTICIPANT	\N	PRESENT	0
699594	698967	19681G	PARTICIPANT	\N	PRESENT	0
699595	698967	20298U	PARTICIPANT	\N	PRESENT	0
699596	698967	01024M	PARTICIPANT	\N	PRESENT	0
699597	698967	20052X	PARTICIPANT	\N	PRESENT	0
699598	698967	14219Q	PARTICIPANT	\N	PRESENT	0
699599	698967	19695N	PARTICIPANT	\N	PRESENT	0
699600	698967	11077T	PARTICIPANT	\N	PRESENT	0
699601	698967	20102Q	PARTICIPANT	\N	PRESENT	0
699602	698967	20046A	PARTICIPANT	\N	PRESENT	0
699603	698967	19699S	PARTICIPANT	\N	PRESENT	0
699606	698967	20090E	PARTICIPANT	\N	PRESENT	0
699608	698967	97011G	PARTICIPANT	\N	PRESENT	0
699610	698967	01058X	PARTICIPANT	\N	PRESENT	0
699612	698967	19729F	PARTICIPANT	\N	PRESENT	0
699613	698967	20086J	PARTICIPANT	\N	PRESENT	0
699614	698967	18083K	PARTICIPANT	\N	PRESENT	0
699615	698967	14169X	PARTICIPANT	\N	PRESENT	0
699616	698967	20032T	PARTICIPANT	\N	PRESENT	0
699617	698967	11090Q	PARTICIPANT	\N	PRESENT	0
699618	698967	14133K	PARTICIPANT	\N	PRESENT	0
699619	698967	19703U	PARTICIPANT	\N	PRESENT	0
699620	698967	19701S	PARTICIPANT	\N	PRESENT	0
699621	698967	19798U	PARTICIPANT	\N	PRESENT	0
699622	698967	20062A	PARTICIPANT	\N	PRESENT	0
699623	698967	19685L	PARTICIPANT	\N	PRESENT	0
699624	698967	19335Q	PARTICIPANT	\N	PRESENT	0
699625	698967	08056B	PARTICIPANT	\N	PRESENT	0
699626	698967	19782L	PARTICIPANT	\N	PRESENT	0
699627	698967	14030Q	PARTICIPANT	\N	PRESENT	0
699628	698967	20100N	PARTICIPANT	\N	PRESENT	0
699629	698967	14031R	PARTICIPANT	\N	PRESENT	0
699630	698967	14221J	PARTICIPANT	\N	PRESENT	0
699631	698967	19747H	PARTICIPANT	\N	PRESENT	0
699632	698967	14211G	PARTICIPANT	\N	PRESENT	0
699633	698967	14191V	PARTICIPANT	\N	PRESENT	0
699635	698967	19515S	PARTICIPANT	\N	PRESENT	0
699636	698967	19467C	PARTICIPANT	\N	PRESENT	0
699637	698967	19369B	PARTICIPANT	\N	PRESENT	0
699638	698967	01025N	PARTICIPANT	\N	PRESENT	0
699639	698967	14217N	PARTICIPANT	\N	PRESENT	0
699577	698967	14026U	PARTICIPANT	\N	PRESENT	0
699578	698967	19503N	PARTICIPANT	\N	PRESENT	0
699640	698967	14083S	PARTICIPANT	\N	PRESENT	0
699643	698967	14053L	PARTICIPANT	\N	PRESENT	0
699646	698967	14329V	PARTICIPANT	\N	PRESENT	0
699650	698967	20044X	PARTICIPANT	\N	PRESENT	0
699651	698967	19760E	PARTICIPANT	\N	PRESENT	0
699655	698967	11085T	PARTICIPANT	\N	PRESENT	0
699656	698967	14205J	PARTICIPANT	\N	PRESENT	0
699657	698967	14033T	PARTICIPANT	\N	PRESENT	0
699658	698967	20118Y	PARTICIPANT	\N	PRESENT	0
699659	698967	01043Q	PARTICIPANT	\N	PRESENT	0
699660	698967	19563B	PARTICIPANT	\N	PRESENT	0
699661	698967	14038Y	PARTICIPANT	\N	PRESENT	0
699662	698967	14073Q	PARTICIPANT	\N	PRESENT	0
699663	698967	19866P	PARTICIPANT	\N	PRESENT	0
699664	698967	11048N	PARTICIPANT	\N	PRESENT	0
699665	698967	20042V	PARTICIPANT	\N	PRESENT	0
699666	698967	14267Y	PARTICIPANT	\N	PRESENT	0
699667	698967	20092G	PARTICIPANT	\N	PRESENT	0
699668	698967	20172F	PARTICIPANT	\N	PRESENT	0
699669	698967	19762G	PARTICIPANT	\N	PRESENT	0
699670	698967	07029T	PARTICIPANT	\N	PRESENT	0
699671	698967	20070A	PARTICIPANT	\N	PRESENT	0
699672	698967	11097X	PARTICIPANT	\N	PRESENT	0
699673	698967	20094J	PARTICIPANT	\N	PRESENT	0
699733	698968	14026U	PARTICIPANT	\N	PRESENT	0
699734	698968	19760E	PARTICIPANT	\N	PRESENT	0
699735	698968	20094J	PARTICIPANT	\N	PRESENT	0
699736	698968	14121F	PARTICIPANT	\N	PRESENT	0
699737	698968	19703U	PARTICIPANT	\N	PRESENT	0
699738	698968	14038Y	PARTICIPANT	\N	PRESENT	0
699739	698968	20100N	PARTICIPANT	\N	PRESENT	0
699740	698968	11012A	PARTICIPANT	\N	PRESENT	0
699741	698968	20032T	PARTICIPANT	\N	PRESENT	0
699742	698968	14037X	PARTICIPANT	\N	PRESENT	0
699743	698968	20172F	PARTICIPANT	\N	PRESENT	0
699744	698968	19747H	PARTICIPANT	\N	PRESENT	0
699745	698968	19695N	PARTICIPANT	\N	PRESENT	0
699746	698968	14191V	PARTICIPANT	\N	PRESENT	0
699747	698968	11077T	PARTICIPANT	\N	PRESENT	0
699748	698968	07029T	PARTICIPANT	\N	PRESENT	0
699749	698968	20046A	PARTICIPANT	\N	PRESENT	0
699750	698968	20102Q	PARTICIPANT	\N	PRESENT	0
699751	698968	19685L	PARTICIPANT	\N	PRESENT	0
699752	698968	19866P	PARTICIPANT	\N	PRESENT	0
699753	698968	20044X	PARTICIPANT	\N	PRESENT	0
699754	698968	20092G	PARTICIPANT	\N	PRESENT	0
699755	698968	19467C	PARTICIPANT	\N	PRESENT	0
699756	698968	11048N	PARTICIPANT	\N	PRESENT	0
699757	698968	20070A	PARTICIPANT	\N	PRESENT	0
699758	698968	14211G	PARTICIPANT	\N	PRESENT	0
699759	698968	19335Q	PARTICIPANT	\N	PRESENT	0
699760	698968	14221J	PARTICIPANT	\N	PRESENT	0
699761	698968	01024M	PARTICIPANT	\N	PRESENT	0
699762	698968	19563B	PARTICIPANT	\N	PRESENT	0
699763	698968	14083S	PARTICIPANT	\N	PRESENT	0
699764	698968	20050V	PARTICIPANT	\N	PRESENT	0
699765	698968	19745F	PARTICIPANT	\N	PRESENT	0
699766	698968	19515S	PARTICIPANT	\N	PRESENT	0
699767	698968	20298U	PARTICIPANT	\N	PRESENT	0
699768	698968	19619A	PARTICIPANT	\N	PRESENT	0
699769	698968	20144B	PARTICIPANT	\N	PRESENT	0
699770	698968	20048C	PARTICIPANT	\N	PRESENT	0
699771	698968	19762G	PARTICIPANT	\N	PRESENT	0
686727	686726	19701S	PARTICIPANT	\N	PRESENT	0
686728	686726	20106U	PARTICIPANT	\N	PRESENT	0
686729	686726	14083S	PARTICIPANT	\N	PRESENT	0
686730	686726	19820Y	PARTICIPANT	\N	PRESENT	0
686731	686726	20038A	PARTICIPANT	\N	PRESENT	0
691893	691861	11048N	PARTICIPANT	\N	PRESENT	0
691899	691861	08011M	PARTICIPANT	\N	PRESENT	0
692600	692529	14217N	PARTICIPANT	\N	PRESENT	0
692602	692529	20040T	PARTICIPANT	\N	PRESENT	0
692609	692529	11031D	PARTICIPANT	\N	PRESENT	0
692629	692319	14107H	PARTICIPANT	\N	EXCUSE	0
692630	692319	14001X	PARTICIPANT	\N	EXCUSE	0
692631	692319	14021P	PARTICIPANT	\N	EXCUSE	0
695070	693561	19301E	PARTICIPANT	\N	EXCUSE	0
695071	693586	19301E	PARTICIPANT	\N	EXCUSE	0
695072	693587	19301E	PARTICIPANT	\N	EXCUSE	0
696280	693394	20024T	PARTICIPANT	\N	PRESENT	0
696281	693394	20136B	PARTICIPANT	\N	EXCUSE	0
696282	694949	19593H	PARTICIPANT	\N	PRESENT	0
696283	694949	14073Q	PARTICIPANT	\N	PRESENT	0
696284	694949	19611R	PRESIDENT	0	PRESENT	0
696285	694949	20138D	PARTICIPANT	\N	PRESENT	0
696286	694949	20142Y	PARTICIPANT	\N	PRESENT	0
696287	694949	19399H	PARTICIPANT	\N	PRESENT	0
696288	694949	20052X	PARTICIPANT	\N	PRESENT	0
696289	694949	14229S	PARTICIPANT	\N	PRESENT	0
696290	694949	14030Q	PARTICIPANT	\N	PRESENT	0
696291	694949	20056C	PARTICIPANT	\N	PRESENT	0
696292	694949	20264J	PARTICIPANT	\N	PRESENT	0
696293	694949	20980G	PARTICIPANT	\N	PRESENT	0
696294	694949	11104D	PARTICIPANT	\N	PRESENT	0
696295	694949	11043H	PARTICIPANT	\N	PRESENT	0
696296	694949	20124W	PARTICIPANT	\N	PRESENT	0
696297	694949	19758L	PARTICIPANT	\N	PRESENT	0
696298	694949	20026V	PARTICIPANT	\N	PRESENT	0
696299	694949	19621T	PARTICIPANT	\N	PRESENT	0
696300	694949	11109J	PARTICIPANT	\N	EXCUSE	0
696301	694949	20084G	PARTICIPANT	\N	PRESENT	0
696306	694949	19643A	PARTICIPANT	\N	PRESENT	0
696307	694949	19693L	PARTICIPANT	\N	PRESENT	0
696308	694949	20152B	PARTICIPANT	\N	PRESENT	0
696309	694949	20180F	PARTICIPANT	\N	PRESENT	0
696310	694949	19735D	PARTICIPANT	\N	PRESENT	0
696311	696008	14331P	PARTICIPANT	\N	PRESENT	0
696312	696008	04071H	PARTICIPANT	\N	PRESENT	0
696313	696008	19479G	PARTICIPANT	\N	PRESENT	0
696314	696008	11012A	PARTICIPANT	\N	PRESENT	0
696315	696008	01057W	PARTICIPANT	\N	PRESENT	0
696316	696008	99004R	PARTICIPANT	\N	PRESENT	0
696317	696008	14225N	PRESIDENT	0	PRESENT	0
696318	696008	20116W	PARTICIPANT	\N	EXCUSE	0
696319	693394	20118Y	PARTICIPANT	\N	PRESENT	0
696320	694949	20172F	PARTICIPANT	\N	PRESENT	0
696321	696008	19711U	PARTICIPANT	\N	PRESENT	0
696322	696008	20080C	PARTICIPANT	\N	PRESENT	0
696323	696008	20044X	PARTICIPANT	\N	PRESENT	0
696324	696008	14173T	PARTICIPANT	\N	PRESENT	0
696325	696008	11040E	PARTICIPANT	\N	PRESENT	0
696326	696008	07029T	PARTICIPANT	\N	PRESENT	0
696327	696008	19349W	PARTICIPANT	\N	PRESENT	0
696328	696008	20914V	PARTICIPANT	\N	PRESENT	0
696329	696008	20050V	PARTICIPANT	\N	PRESENT	0
696330	696008	19741B	PARTICIPANT	\N	PRESENT	0
696331	696008	14253S	PARTICIPANT	\N	PRESENT	0
696332	696008	19671E	PARTICIPANT	\N	PRESENT	0
696333	696008	20070A	PARTICIPANT	\N	PRESENT	0
696334	696008	20252E	PARTICIPANT	\N	PRESENT	0
696335	693394	11101A	PARTICIPANT	\N	PRESENT	0
696336	696008	20036X	PARTICIPANT	\N	PRESENT	0
696337	696008	11110B	PARTICIPANT	\N	PRESENT	0
696338	696008	19531S	PARTICIPANT	\N	PRESENT	0
696351	696008	19647E	PARTICIPANT	\N	PRESENT	0
696340	696008	19667J	PARTICIPANT	\N	PRESENT	0
696341	696008	08010L	PARTICIPANT	\N	PRESENT	0
696342	696008	11048N	PARTICIPANT	\N	PRESENT	0
696343	696008	11070L	PARTICIPANT	\N	PRESENT	0
696344	696008	20126Y	PARTICIPANT	\N	PRESENT	0
696345	696008	08009T	PARTICIPANT	\N	PRESENT	0
696346	696008	11053K	PARTICIPANT	\N	PRESENT	0
696347	696008	08073C	PARTICIPANT	\N	PRESENT	0
696348	696008	19545Y	PARTICIPANT	\N	PRESENT	0
696350	696008	08034U	PARTICIPANT	\N	PRESENT	0
696352	693394	19701S	PARTICIPANT	\N	PRESENT	0
696353	693394	20122U	PARTICIPANT	\N	PRESENT	0
696354	693394	14169X	PARTICIPANT	\N	PRESENT	0
696355	696008	19335Q	PARTICIPANT	\N	PRESENT	0
696356	696008	14083S	PARTICIPANT	\N	PRESENT	0
696357	695195	14327T	PARTICIPANT	\N	PRESENT	0
696358	695195	14331P	PARTICIPANT	\N	PRESENT	0
696359	695195	04071H	PARTICIPANT	\N	PRESENT	0
696360	695195	19545Y	PARTICIPANT	\N	PRESENT	0
696361	695195	01057W	PARTICIPANT	\N	PRESENT	0
696362	695195	20080C	PARTICIPANT	\N	PRESENT	0
696363	695195	11053K	PARTICIPANT	\N	PRESENT	0
696364	695195	19667J	PARTICIPANT	\N	PRESENT	0
696365	695195	14225N	PRESIDENT	0	PRESENT	0
696366	695195	19671E	PARTICIPANT	\N	PRESENT	0
696367	695195	11070L	PARTICIPANT	\N	PRESENT	0
696368	695195	11110B	PARTICIPANT	\N	PRESENT	0
696369	695195	07029T	PARTICIPANT	\N	PRESENT	0
696370	695195	19349W	PARTICIPANT	\N	PRESENT	0
696371	695195	08010L	PARTICIPANT	\N	PRESENT	0
696372	695195	14253S	PARTICIPANT	\N	PRESENT	0
696373	695195	19335Q	PARTICIPANT	\N	PRESENT	0
696374	695195	20126Y	PARTICIPANT	\N	PRESENT	0
696375	695195	19479G	PARTICIPANT	\N	PRESENT	0
696376	695195	11048N	PARTICIPANT	\N	PRESENT	0
696377	695195	19647E	PARTICIPANT	\N	PRESENT	0
696378	695195	19711U	PARTICIPANT	\N	PRESENT	0
696379	695195	20036X	PARTICIPANT	\N	PRESENT	0
696380	695195	19531S	PARTICIPANT	\N	PRESENT	0
696381	695195	08034U	PARTICIPANT	\N	PRESENT	0
696382	695195	14189C	PARTICIPANT	\N	PRESENT	0
696383	695195	20050V	PARTICIPANT	\N	PRESENT	0
696384	695195	20044X	PARTICIPANT	\N	PRESENT	0
696385	695195	14173T	PARTICIPANT	\N	PRESENT	0
696386	695195	11040E	PARTICIPANT	\N	PRESENT	0
696387	695195	14083S	PARTICIPANT	\N	PRESENT	0
696388	695195	11012A	PARTICIPANT	\N	PRESENT	0
696389	695195	20252E	PARTICIPANT	\N	PRESENT	0
696390	695195	08073C	PARTICIPANT	\N	PRESENT	0
696391	695195	20070A	PARTICIPANT	\N	PRESENT	0
696392	695195	08009T	PARTICIPANT	\N	PRESENT	0
696393	695195	19741B	PARTICIPANT	\N	PRESENT	0
696394	695195	99004R	PARTICIPANT	\N	PRESENT	0
696395	695195	20914V	PARTICIPANT	\N	PRESENT	0
696396	695195	20116W	PARTICIPANT	\N	EXCUSE	0
696397	695195	11074Q	PARTICIPANT	\N	PRESENT	0
696399	694949	19533U	PARTICIPANT	\N	PRESENT	0
696400	694949	04033B	PARTICIPANT	\N	PRESENT	0
696401	694949	20098N	PARTICIPANT	\N	PRESENT	0
696402	694949	19573D	PARTICIPANT	\N	PRESENT	0
696403	694949	08012N	PARTICIPANT	\N	PRESENT	0
696404	694949	19527W	PARTICIPANT	\N	PRESENT	0
696405	694949	20134Y	PARTICIPANT	\N	PRESENT	0
696406	695195	01048V	PARTICIPANT	\N	PRESENT	0
696407	694949	20132W	PARTICIPANT	\N	PRESENT	0
696408	694876	20074E	PARTICIPANT	\N	PRESENT	0
696409	694876	14001X	PARTICIPANT	\N	PRESENT	0
696410	694876	19543W	PARTICIPANT	\N	PRESENT	0
696411	694876	19585H	PARTICIPANT	\N	PRESENT	0
696412	694876	04047H	PRESIDENT	0	PRESENT	0
696413	694876	19673G	PARTICIPANT	\N	PRESENT	0
696414	694876	19675J	PARTICIPANT	\N	PRESENT	0
696415	694876	01028R	PARTICIPANT	\N	PRESENT	0
696416	694876	19447X	PARTICIPANT	\N	PRESENT	0
696417	694876	05008E	PARTICIPANT	\N	PRESENT	0
696418	694876	19954N	PARTICIPANT	\N	PRESENT	0
696419	694876	19489J	PARTICIPANT	\N	PRESENT	0
696420	694876	17737W	PARTICIPANT	\N	PRESENT	0
696421	694876	20108W	PARTICIPANT	\N	PRESENT	0
696422	694876	14147R	PARTICIPANT	\N	PRESENT	0
696423	694876	14179A	PARTICIPANT	\N	PRESENT	0
696424	694876	20114U	PARTICIPANT	\N	PRESENT	0
696425	694876	14151M	PARTICIPANT	\N	PRESENT	0
696426	694876	14215L	PARTICIPANT	\N	PRESENT	0
696427	694876	20022R	PARTICIPANT	\N	PRESENT	0
696428	694876	14259Y	PARTICIPANT	\N	PRESENT	0
696429	694876	11072N	PARTICIPANT	\N	PRESENT	0
696430	694876	14053L	PARTICIPANT	\N	PRESENT	0
696431	694876	14111D	PARTICIPANT	\N	PRESENT	0
700285	698744	01034P	PARTICIPANT	\N	PRESENT	0
700323	698943	20072C	PARTICIPANT	\N	EXCUSE	0
700350	698744	04043D	PARTICIPANT	\N	PRESENT	0
700386	698744	20148F	PARTICIPANT	\N	PRESENT	0
702707	702706	04047H	PARTICIPANT	\N	PRESENT	0
702708	702706	14231L	PARTICIPANT	\N	PRESENT	0
702709	702706	14001X	PARTICIPANT	\N	PRESENT	0
702710	702706	20110Q	PARTICIPANT	\N	PRESENT	0
704775	699132	19583F	PARTICIPANT	\N	EXCUSE	0
708054	708050	11045K	PARTICIPANT	\N	PRESENT	0
708055	708050	20130U	PARTICIPANT	\N	PRESENT	0
708056	708050	20100N	PARTICIPANT	\N	PRESENT	0
708057	708050	20914V	PARTICIPANT	\N	PRESENT	0
708058	708050	08045X	PARTICIPANT	\N	PRESENT	0
708059	708050	17779H	PARTICIPANT	\N	PRESENT	0
708060	708050	20264J	PARTICIPANT	\N	PRESENT	0
708061	708050	19413M	PARTICIPANT	\N	PRESENT	0
708062	708050	12016W	PARTICIPANT	\N	PRESENT	0
708063	708050	18193Q	PARTICIPANT	\N	PRESENT	0
708064	708050	11067R	PARTICIPANT	\N	PRESENT	0
708065	708050	14281W	PARTICIPANT	\N	PRESENT	0
708066	708050	19683J	PARTICIPANT	\N	PRESENT	0
708067	708050	11040E	PARTICIPANT	\N	PRESENT	0
708068	708050	20028X	PARTICIPANT	\N	PRESENT	0
708069	708050	12028B	PARTICIPANT	\N	PRESENT	0
708070	708050	19760E	PARTICIPANT	\N	PRESENT	0
708071	708050	19695N	PARTICIPANT	\N	PRESENT	0
708072	708050	20080C	PARTICIPANT	\N	PRESENT	0
708073	708050	20122U	PARTICIPANT	\N	PRESENT	0
708074	708050	19553Y	PARTICIPANT	\N	PRESENT	0
708075	708050	19766L	PARTICIPANT	\N	PRESENT	0
708076	708050	01048V	PARTICIPANT	\N	PRESENT	0
708077	708050	20074E	PARTICIPANT	\N	PRESENT	0
708078	708050	14223L	PARTICIPANT	\N	PRESENT	0
708079	708050	04092N	PARTICIPANT	\N	PRESENT	0
708080	708050	11053K	PARTICIPANT	\N	PRESENT	0
708081	708050	14071N	PARTICIPANT	\N	PRESENT	0
708082	708050	14030Q	PARTICIPANT	\N	PRESENT	0
708083	708050	14187A	PARTICIPANT	\N	PRESENT	0
708084	708050	19691J	PARTICIPANT	\N	PRESENT	0
708085	708050	19745F	PARTICIPANT	\N	PRESENT	0
708086	708050	14217N	PARTICIPANT	\N	PRESENT	0
708087	708050	19369B	PARTICIPANT	\N	PRESENT	0
708088	708050	14213J	PARTICIPANT	\N	PRESENT	0
708089	708050	20040T	PARTICIPANT	\N	PRESENT	0
708090	708050	20062A	PARTICIPANT	\N	PRESENT	0
708091	708050	19569H	PARTICIPANT	\N	PRESENT	0
708092	708050	20020P	PARTICIPANT	\N	PRESENT	0
708093	708050	20066E	PARTICIPANT	\N	PRESENT	0
708094	708050	19581D	PARTICIPANT	\N	PRESENT	0
708095	708050	20142Y	PARTICIPANT	\N	PRESENT	0
708096	708050	19383Y	PARTICIPANT	\N	PRESENT	0
708097	708050	01034P	PARTICIPANT	\N	PRESENT	0
708098	708050	19798U	PARTICIPANT	\N	PRESENT	0
708099	708050	19301E	PARTICIPANT	\N	PRESENT	0
708100	708050	19667J	PARTICIPANT	\N	PRESENT	0
708101	708050	11097X	PARTICIPANT	\N	PRESENT	0
708102	708050	20044X	PARTICIPANT	\N	PRESENT	0
708103	708050	10006L	PARTICIPANT	\N	PRESENT	0
708104	708050	14042U	PARTICIPANT	\N	PRESENT	0
708105	708050	17367Q	PARTICIPANT	\N	PRESENT	0
708106	708050	14225N	PARTICIPANT	\N	PRESENT	0
708107	708050	19657G	PARTICIPANT	\N	PRESENT	0
708108	708050	20064C	PARTICIPANT	\N	PRESENT	0
708109	708050	14026U	PARTICIPANT	\N	PRESENT	0
708110	708050	20056C	PARTICIPANT	\N	PRESENT	0
708111	708050	19711U	PARTICIPANT	\N	PRESENT	0
708112	708050	99004R	PARTICIPANT	\N	PRESENT	0
708113	708050	19723Y	PARTICIPANT	\N	PRESENT	0
708114	708050	08069G	PARTICIPANT	\N	PRESENT	0
708115	708050	14169X	PARTICIPANT	\N	PRESENT	0
708116	708050	17965H	PARTICIPANT	\N	PRESENT	0
708117	708050	14151M	PARTICIPANT	\N	PRESENT	0
708118	708050	19549D	PARTICIPANT	\N	PRESENT	0
708119	708050	19758L	PARTICIPANT	\N	PRESENT	0
708123	708050	14257W	PARTICIPANT	\N	PRESENT	0
708121	708050	11054L	PARTICIPANT	\N	PRESENT	0
708122	708050	14229S	PARTICIPANT	\N	PRESENT	0
708124	708050	19629C	PARTICIPANT	\N	PRESENT	0
708125	708050	14037X	PARTICIPANT	\N	PRESENT	0
708126	708050	19349W	PARTICIPANT	\N	PRESENT	0
708127	708050	95063L	PARTICIPANT	\N	PRESENT	0
708128	708050	19525U	PARTICIPANT	\N	PRESENT	0
708129	708050	08061X	PARTICIPANT	\N	PRESENT	0
708130	708050	11074Q	PARTICIPANT	\N	PRESENT	0
708131	708050	19367Y	PARTICIPANT	\N	PRESENT	0
708132	708050	14073Q	PARTICIPANT	\N	PRESENT	0
708133	708050	11048N	PARTICIPANT	\N	PRESENT	0
708134	708050	14189C	PARTICIPANT	\N	PRESENT	0
708135	708050	19715Y	PARTICIPANT	\N	PRESENT	0
708142	708050	04033B	PARTICIPANT	\N	PRESENT	0
708143	708050	19659J	PARTICIPANT	\N	PRESENT	0
708144	708050	14211G	PARTICIPANT	\N	PRESENT	0
708145	708050	19701S	PARTICIPANT	\N	PRESENT	0
708146	708050	19507S	PARTICIPANT	\N	PRESENT	0
708147	708050	20032T	PARTICIPANT	\N	PRESENT	0
708150	708149	14133K	PARTICIPANT	\N	PRESENT	0
708151	708050	14111D	PARTICIPANT	\N	PRESENT	0
708153	708152	14133K	PARTICIPANT	\N	PRESENT	0
708154	708152	14097Y	PARTICIPANT	\N	PRESENT	0
708156	708050	14249W	PARTICIPANT	\N	PRESENT	0
708157	708050	19347U	PARTICIPANT	\N	PRESENT	0
708158	708050	14107H	PARTICIPANT	\N	PRESENT	0
708159	708050	20252E	PARTICIPANT	\N	PRESENT	0
708162	708050	20058E	PARTICIPANT	\N	PRESENT	0
708163	708050	20084G	PARTICIPANT	\N	PRESENT	0
708165	708164	14133K	PARTICIPANT	\N	PRESENT	0
708166	708050	17737W	PARTICIPANT	\N	PRESENT	0
708167	708050	08015R	PARTICIPANT	\N	PRESENT	0
708168	708050	14215L	PARTICIPANT	\N	PRESENT	0
708169	708050	19673G	PARTICIPANT	\N	PRESENT	0
708170	708050	14231L	PARTICIPANT	\N	PRESENT	0
708171	708050	19503N	PARTICIPANT	\N	PRESENT	0
708172	708050	08010L	PARTICIPANT	\N	PRESENT	0
708173	708050	20266L	PARTICIPANT	\N	PRESENT	0
708174	708050	19489J	PARTICIPANT	\N	PRESENT	0
708175	708050	14083S	PARTICIPANT	\N	PRESENT	0
708176	708050	19735D	PARTICIPANT	\N	PRESENT	0
708177	708050	11077T	PARTICIPANT	\N	PRESENT	0
708178	708050	20108W	PARTICIPANT	\N	PRESENT	0
708180	708179	07004J	PARTICIPANT	\N	PRESENT	0
708181	708179	19329S	PARTICIPANT	\N	PRESENT	0
708182	708179	19531S	PARTICIPANT	\N	PRESENT	0
708183	708179	10015M	PARTICIPANT	\N	PRESENT	0
708184	708050	20094J	PARTICIPANT	\N	PRESENT	0
708185	708050	19820Y	PARTICIPANT	\N	PRESENT	0
708186	708050	14109K	PARTICIPANT	\N	PRESENT	0
708189	708050	08018U	PARTICIPANT	\N	PRESENT	0
708190	708050	19643A	PARTICIPANT	\N	PRESENT	0
708193	708050	11031D	PARTICIPANT	\N	PRESENT	0
708196	706244	04057K	PARTICIPANT	\N	EXCUSE	0
708197	708050	19479G	PARTICIPANT	\N	PRESENT	0
708198	708050	11026G	PARTICIPANT	\N	PRESENT	0
708200	706244	20248J	PARTICIPANT	\N	EXCUSE	0
708207	708050	16685X	PARTICIPANT	\N	PRESENT	0
708208	708050	14089Y	PARTICIPANT	\N	PRESENT	0
708209	708050	19591F	PARTICIPANT	\N	PRESENT	0
708210	708050	08073C	PARTICIPANT	\N	PRESENT	0
708211	708050	14255U	PARTICIPANT	\N	PRESENT	0
708212	708050	04035D	PARTICIPANT	\N	PRESENT	0
708213	708050	14329V	PARTICIPANT	\N	PRESENT	0
689624	688706	05008E	PARTICIPANT	\N	EXCUSE	0
689625	688707	11056N	PARTICIPANT	\N	PRESENT	0
689626	688707	14259Y	PARTICIPANT	\N	PRESENT	0
689627	688707	08018U	PARTICIPANT	\N	PRESENT	0
689628	688707	14179A	PARTICIPANT	\N	PRESENT	0
689629	688707	19725B	PARTICIPANT	\N	PRESENT	0
689630	688707	14147R	PARTICIPANT	\N	PRESENT	0
689631	688707	01028R	PARTICIPANT	\N	PRESENT	0
689632	688707	14151M	PARTICIPANT	\N	PRESENT	0
689633	688707	05008E	PARTICIPANT	\N	EXCUSE	0
689634	688707	14069U	PARTICIPANT	\N	PRESENT	0
689635	688707	14215L	PARTICIPANT	\N	PRESENT	0
689636	688707	04008A	PARTICIPANT	\N	PRESENT	0
689637	688707	14111D	PARTICIPANT	\N	PRESENT	0
689638	688707	19649G	PARTICIPANT	\N	PRESENT	0
689639	688707	04047H	PRESIDENT	\N	PRESENT	0
689640	688707	14001X	PARTICIPANT	\N	PRESENT	0
689641	688707	95063L	PARTICIPANT	\N	PRESENT	0
689642	688707	20022R	PARTICIPANT	\N	PRESENT	0
689643	688707	14089Y	PARTICIPANT	\N	PRESENT	0
689644	688707	19954N	PARTICIPANT	\N	PRESENT	0
689645	688707	11085T	PARTICIPANT	\N	PRESENT	0
689646	688707	19581D	PARTICIPANT	\N	PRESENT	0
689647	688707	11033F	PARTICIPANT	\N	PRESENT	0
689648	688707	19489J	PARTICIPANT	\N	PRESENT	0
689649	688707	07004J	PARTICIPANT	\N	PRESENT	0
689650	688707	10015M	PARTICIPANT	\N	PRESENT	0
689651	688707	19729F	PARTICIPANT	\N	PRESENT	0
689652	688707	14021P	PARTICIPANT	\N	PRESENT	0
689653	688707	20108W	PARTICIPANT	\N	PRESENT	0
689654	688707	11026G	PARTICIPANT	\N	PRESENT	0
689655	688707	17737W	PARTICIPANT	\N	PRESENT	0
689656	688707	14053L	PARTICIPANT	\N	PRESENT	0
689657	688707	14231L	PARTICIPANT	\N	PRESENT	0
689658	688707	11072N	PARTICIPANT	\N	PRESENT	0
689659	688707	20074E	PARTICIPANT	\N	PRESENT	0
689660	688707	14107H	PARTICIPANT	\N	PRESENT	0
689661	688707	20110Q	PARTICIPANT	\N	PRESENT	0
689662	688708	14021P	PARTICIPANT	\N	EXCUSE	0
689979	688708	05008E	PARTICIPANT	\N	EXCUSE	0
690437	688708	04047H	PRESIDENT	0	PRESENT	0
690438	688708	19649G	PARTICIPANT	\N	PRESENT	0
690439	688708	19725B	PARTICIPANT	\N	PRESENT	0
690440	688708	19749K	PARTICIPANT	\N	PRESENT	0
690441	688708	14107H	PARTICIPANT	\N	PRESENT	0
690442	688708	11056N	PARTICIPANT	\N	PRESENT	0
690443	688708	20074E	PARTICIPANT	\N	PRESENT	0
690444	688708	20022R	PARTICIPANT	\N	PRESENT	0
690447	688708	11026G	PARTICIPANT	\N	PRESENT	0
690449	688708	14053L	PARTICIPANT	\N	PRESENT	0
690450	688708	14151M	PARTICIPANT	\N	PRESENT	0
690451	688708	95063L	PARTICIPANT	\N	PRESENT	0
690452	688708	14147R	PARTICIPANT	\N	PRESENT	0
690454	688708	14231L	PARTICIPANT	\N	PRESENT	0
690456	688708	20110Q	PARTICIPANT	\N	PRESENT	0
690457	688708	11033F	PARTICIPANT	\N	PRESENT	0
690800	690797	11026G	PARTICIPANT	\N	PRESENT	0
690801	690797	14089Y	PARTICIPANT	\N	PRESENT	0
690802	690797	20104S	PARTICIPANT	\N	PRESENT	0
690803	690797	14097Y	PARTICIPANT	\N	PRESENT	0
693248	692427	11045K	PARTICIPANT	\N	PRESENT	0
693249	692427	14053L	PARTICIPANT	\N	PRESENT	0
693250	692427	19723Y	PARTICIPANT	\N	PRESENT	0
693251	692427	19301E	PARTICIPANT	\N	PRESENT	0
693252	692427	20114U	PARTICIPANT	\N	PRESENT	0
693253	692427	14073Q	PARTICIPANT	\N	PRESENT	0
693254	692427	14195A	PARTICIPANT	\N	PRESENT	0
693255	692427	17589D	PARTICIPANT	\N	PRESENT	0
693256	692427	19583F	PARTICIPANT	\N	PRESENT	0
693257	692427	19441R	PARTICIPANT	\N	PRESENT	0
693258	692427	19479G	PARTICIPANT	\N	PRESENT	0
693259	692427	19745F	PARTICIPANT	\N	PRESENT	0
693260	692427	14042U	PARTICIPANT	\N	PRESENT	0
693261	692427	19553Y	PARTICIPANT	\N	PRESENT	0
693262	692427	20132W	PARTICIPANT	\N	PRESENT	0
693263	692427	98022P	PARTICIPANT	\N	PRESENT	0
693264	692427	20134Y	PARTICIPANT	\N	PRESENT	0
693265	692427	19543W	PARTICIPANT	\N	PRESENT	0
693266	692427	11064N	PARTICIPANT	\N	PRESENT	0
693267	692427	14179A	PARTICIPANT	\N	PRESENT	0
693268	692427	18083K	PARTICIPANT	\N	PRESENT	0
693269	692427	20040T	PARTICIPANT	\N	PRESENT	0
693270	692427	19367Y	PARTICIPANT	\N	PRESENT	0
693271	692427	19581D	PARTICIPANT	\N	PRESENT	0
693272	692427	19826F	PARTICIPANT	\N	PRESENT	0
693273	692427	14030Q	PARTICIPANT	\N	PRESENT	0
693274	692427	14255U	PARTICIPANT	\N	PRESENT	0
693275	692427	19611R	PARTICIPANT	\N	PRESENT	0
693276	692427	20914V	PARTICIPANT	\N	PRESENT	0
693277	692427	19637C	PARTICIPANT	\N	PRESENT	0
693278	692427	19651A	PARTICIPANT	\N	PRESENT	0
693279	692427	19629C	PARTICIPANT	\N	PRESENT	0
693280	692427	14021P	PARTICIPANT	\N	PRESENT	0
693281	692427	14229S	PARTICIPANT	\N	PRESENT	0
693282	692427	08012N	PARTICIPANT	\N	PRESENT	0
693283	692427	11104D	PARTICIPANT	\N	PRESENT	0
693284	692427	14281W	PARTICIPANT	\N	PRESENT	0
693285	692427	14109K	PARTICIPANT	\N	PRESENT	0
693286	692427	19387D	PARTICIPANT	\N	PRESENT	0
693287	692427	19531S	PARTICIPANT	\N	PRESENT	0
693288	692427	14151M	PARTICIPANT	\N	PRESENT	0
693289	692427	19649G	PARTICIPANT	\N	PRESENT	0
693290	692427	08045X	PARTICIPANT	\N	PRESENT	0
693291	692427	18193Q	PARTICIPANT	\N	PRESENT	0
693292	692427	19695N	PARTICIPANT	\N	PRESENT	0
693293	692427	04085P	PARTICIPANT	\N	PRESENT	0
693294	692427	11077T	PARTICIPANT	\N	PRESENT	0
693295	692427	20064C	PARTICIPANT	\N	PRESENT	0
693296	692427	20102Q	PARTICIPANT	\N	PRESENT	0
693297	692427	20046A	PARTICIPANT	\N	PRESENT	0
693298	692427	20112S	PARTICIPANT	\N	PRESENT	0
693299	692427	19349W	PARTICIPANT	\N	PRESENT	0
693300	692427	04047H	PARTICIPANT	\N	PRESENT	0
693301	692427	19549D	PARTICIPANT	\N	PRESENT	0
693302	692427	19725B	PARTICIPANT	\N	PRESENT	0
693303	692427	20252E	PARTICIPANT	\N	PRESENT	0
693304	692427	19383Y	PARTICIPANT	\N	PRESENT	0
693305	692427	20062A	PARTICIPANT	\N	PRESENT	0
693306	692427	20024T	PARTICIPANT	\N	PRESENT	0
693307	692427	14147R	PARTICIPANT	\N	PRESENT	0
693308	692427	20172F	PARTICIPANT	\N	PRESENT	0
693309	692427	20032T	PARTICIPANT	\N	PRESENT	0
693310	692427	17737W	PARTICIPANT	\N	PRESENT	0
693311	692427	14069U	PARTICIPANT	\N	PRESENT	0
693312	692427	19533U	PARTICIPANT	\N	PRESENT	0
693313	692427	14031R	PARTICIPANT	\N	PRESENT	0
693314	692427	20026V	PARTICIPANT	\N	PRESENT	0
693315	692427	20152B	PARTICIPANT	\N	PRESENT	0
693316	692427	20056C	PARTICIPANT	\N	PRESENT	0
693317	692427	19399H	PARTICIPANT	\N	PRESENT	0
693318	692427	07029T	PARTICIPANT	\N	PRESENT	0
693319	692427	20022R	PARTICIPANT	\N	PRESENT	0
693320	692427	20068G	PARTICIPANT	\N	PRESENT	0
693321	692427	08028W	PARTICIPANT	\N	PRESENT	0
693322	692427	14223L	PARTICIPANT	\N	PRESENT	0
693323	692427	19693L	PARTICIPANT	\N	PRESENT	0
693324	692427	04008A	PARTICIPANT	\N	PRESENT	0
693325	692427	20074E	PARTICIPANT	\N	PRESENT	0
693327	692427	20076G	PARTICIPANT	\N	PRESENT	0
693328	692427	11043H	PARTICIPANT	\N	PRESENT	0
693330	692427	19679N	PARTICIPANT	\N	PRESENT	0
693334	692427	20140W	PARTICIPANT	\N	PRESENT	0
693335	692427	20034V	PARTICIPANT	\N	PRESENT	0
693336	692427	20086J	PARTICIPANT	\N	PRESENT	0
693337	692427	20980G	PARTICIPANT	\N	PRESENT	0
693338	692427	20038A	PARTICIPANT	\N	PRESENT	0
693339	692427	20110Q	PARTICIPANT	\N	PRESENT	0
693340	692427	20130U	PARTICIPANT	\N	PRESENT	0
693341	692427	19782L	PARTICIPANT	\N	PRESENT	0
693342	692427	11065P	PARTICIPANT	\N	PRESENT	0
693343	692427	20092G	PARTICIPANT	\N	PRESENT	0
693344	692427	01048V	PARTICIPANT	\N	PRESENT	0
693345	692427	14275Y	PARTICIPANT	\N	PRESENT	0
693346	692427	14083S	PARTICIPANT	\N	PRESENT	0
693347	692427	08010L	PARTICIPANT	\N	PRESENT	0
693349	692427	01024M	PARTICIPANT	\N	PRESENT	0
693350	692427	14331P	PARTICIPANT	\N	PRESENT	0
693351	692427	14191V	PARTICIPANT	\N	PRESENT	0
693352	692427	20098N	PARTICIPANT	\N	PRESENT	0
693353	692427	11033F	PARTICIPANT	\N	PRESENT	0
693354	692427	14105F	PARTICIPANT	\N	PRESENT	0
699774	698968	20140W	PARTICIPANT	\N	PRESENT	0
699775	698968	14033T	PARTICIPANT	\N	PRESENT	0
699776	698968	14071N	PARTICIPANT	\N	PRESENT	0
699777	698968	19705W	PARTICIPANT	\N	PRESENT	0
699778	698968	20108W	PARTICIPANT	\N	PRESENT	0
699779	698968	19671E	PARTICIPANT	\N	PRESENT	0
699780	698968	14147R	PARTICIPANT	\N	PRESENT	0
699781	698968	19701S	PARTICIPANT	\N	PRESENT	0
699782	698968	14042U	PARTICIPANT	\N	PRESENT	0
699783	698968	20104S	PARTICIPANT	\N	PRESENT	0
699784	698968	14205J	PARTICIPANT	\N	PRESENT	0
699785	698968	11065P	PARTICIPANT	\N	PRESENT	0
699786	698968	20106U	PARTICIPANT	\N	PRESENT	0
699787	698968	11090Q	PARTICIPANT	\N	PRESENT	0
699788	698968	20110Q	PARTICIPANT	\N	PRESENT	0
699789	698968	04045F	PARTICIPANT	\N	PRESENT	0
699790	698968	18083K	PARTICIPANT	\N	PRESENT	0
699791	698968	01028R	PARTICIPANT	\N	PRESENT	0
699792	698968	19729F	PARTICIPANT	\N	PRESENT	0
699793	698968	20028X	PARTICIPANT	\N	PRESENT	0
699772	698968	19441R	PARTICIPANT	\N	PRESENT	0
699773	698968	14030Q	PARTICIPANT	\N	PRESENT	0
699794	698968	11110B	PARTICIPANT	\N	PRESENT	0
699817	698969	20028X	PARTICIPANT	\N	PRESENT	0
699818	698969	19441R	PARTICIPANT	\N	PRESENT	0
699819	698969	20106U	PARTICIPANT	\N	PRESENT	0
699820	698969	20092G	PARTICIPANT	\N	PRESENT	0
699821	698969	04045F	PARTICIPANT	\N	PRESENT	0
699822	698969	14207L	PARTICIPANT	\N	PRESENT	0
699823	698969	19760E	PARTICIPANT	\N	PRESENT	0
699824	698969	19695N	PARTICIPANT	\N	PRESENT	0
699825	698969	11077T	PARTICIPANT	\N	PRESENT	0
699826	698969	20102Q	PARTICIPANT	\N	PRESENT	0
699827	698969	20048C	PARTICIPANT	\N	PRESENT	0
699828	698969	20286Q	PARTICIPANT	\N	PRESENT	0
699829	698969	01025N	PARTICIPANT	\N	PRESENT	0
699830	698969	19563B	PARTICIPANT	\N	PRESENT	0
699831	698969	18083K	PARTICIPANT	\N	PRESENT	0
699832	698969	19507S	PARTICIPANT	\N	PRESENT	0
699833	698969	14191V	PARTICIPANT	\N	PRESENT	0
699834	698969	14033T	PARTICIPANT	\N	PRESENT	0
699835	698969	19447X	PARTICIPANT	\N	PRESENT	0
699815	698969	11070L	PARTICIPANT	\N	PRESENT	0
699816	698969	11090Q	PARTICIPANT	\N	PRESENT	0
699836	698969	19347U	PARTICIPANT	\N	PRESENT	0
699837	698969	20100N	PARTICIPANT	\N	PRESENT	0
699838	698969	14147R	PARTICIPANT	\N	PRESENT	0
699839	698969	20062A	PARTICIPANT	\N	PRESENT	0
699840	698969	20024T	PARTICIPANT	\N	PRESENT	0
699841	698969	20126Y	PARTICIPANT	\N	PRESENT	0
699842	698969	20124W	PARTICIPANT	\N	PRESENT	0
699843	698969	20180F	PARTICIPANT	\N	PRESENT	0
699844	698969	07029T	PARTICIPANT	\N	PRESENT	0
699845	698969	20086J	PARTICIPANT	\N	PRESENT	0
699846	698969	20052X	PARTICIPANT	\N	PRESENT	0
699847	698969	14073Q	PARTICIPANT	\N	PRESENT	0
699848	698969	17023S	PARTICIPANT	\N	PRESENT	0
699849	698969	19782L	PARTICIPANT	\N	PRESENT	0
699850	698969	20172F	PARTICIPANT	\N	PRESENT	0
699851	698969	11065P	PARTICIPANT	\N	PRESENT	0
699852	698969	20298U	PARTICIPANT	\N	PRESENT	0
699853	698969	20032T	PARTICIPANT	\N	PRESENT	0
699854	698969	14213J	PARTICIPANT	\N	PRESENT	0
699855	698969	14083S	PARTICIPANT	\N	PRESENT	0
699856	698969	19569H	PARTICIPANT	\N	PRESENT	0
700273	696828	19575F	PARTICIPANT	\N	PRESENT	0
700274	696828	19782L	PARTICIPANT	\N	PRESENT	0
700275	696828	11053K	PARTICIPANT	\N	PRESENT	0
700276	696828	14357A	PARTICIPANT	\N	PRESENT	0
700277	696828	20140W	PARTICIPANT	\N	PRESENT	0
700278	696828	19251M	PRESIDENT	0	PRESENT	0
700279	696828	20180F	PARTICIPANT	\N	PRESENT	0
700280	696828	20102Q	PARTICIPANT	\N	PRESENT	0
700281	696828	20052X	PARTICIPANT	\N	PRESENT	0
700282	696828	20028X	PARTICIPANT	\N	PRESENT	0
700283	696828	14237S	PARTICIPANT	\N	PRESENT	0
700284	696828	20030R	PARTICIPANT	\N	PRESENT	0
701187	701186	20042V	PARTICIPANT	\N	PRESENT	0
701188	701186	19782L	PARTICIPANT	\N	PRESENT	0
701189	701186	20090E	PARTICIPANT	\N	PRESENT	0
701191	701186	11101A	PARTICIPANT	\N	PRESENT	0
701193	701186	14357A	PARTICIPANT	\N	PRESENT	0
701195	701186	19719D	PARTICIPANT	\N	PRESENT	0
701196	701186	01024M	PARTICIPANT	\N	PRESENT	0
701198	701186	20128B	PARTICIPANT	\N	PRESENT	0
701200	701186	14213J	PARTICIPANT	\N	PRESENT	0
701202	701186	20126Y	PARTICIPANT	\N	PRESENT	0
701205	701186	19723Y	PARTICIPANT	\N	PRESENT	0
701207	701186	08015R	PARTICIPANT	\N	PRESENT	0
701209	701186	20028X	PARTICIPANT	\N	PRESENT	0
701210	701186	08061X	PARTICIPANT	\N	PRESENT	0
701212	701186	19745F	PARTICIPANT	\N	PRESENT	0
701214	701186	19798U	PARTICIPANT	\N	PRESENT	0
701216	701186	11097X	PARTICIPANT	\N	PRESENT	0
701217	701186	20058E	PARTICIPANT	\N	PRESENT	0
701376	692496	19577H	PARTICIPANT	\N	PRESENT	1
701377	697922	19715Y	PARTICIPANT	\N	PRESENT	0
701378	692496	14147R	PARTICIPANT	\N	PRESENT	0
701379	697922	14147R	PARTICIPANT	\N	PRESENT	0
701380	692496	20098N	PARTICIPANT	\N	PRESENT	0
701381	692496	14030Q	PARTICIPANT	\N	PRESENT	0
701382	697922	14030Q	PRESIDENT	0	PRESENT	0
701383	697922	19717B	PARTICIPANT	\N	PRESENT	0
701384	697922	20098N	PARTICIPANT	\N	PRESENT	0
701385	697922	19577H	PARTICIPANT	\N	PRESENT	0
701386	697922	20146D	PARTICIPANT	\N	PRESENT	0
701387	692496	20146D	PARTICIPANT	\N	PRESENT	0
701390	701389	19667J	PARTICIPANT	\N	PRESENT	0
701391	701389	20024T	PARTICIPANT	\N	PRESENT	0
701392	701389	11033F	PARTICIPANT	\N	PRESENT	0
701393	701389	20054A	PARTICIPANT	\N	PRESENT	0
701394	701389	20062A	PARTICIPANT	\N	PRESENT	0
701398	701397	14231L	PRESIDENT	0	PRESENT	0
701399	701397	14229S	PARTICIPANT	\N	PRESENT	0
701400	701397	14151M	PARTICIPANT	\N	PRESENT	0
701401	701397	19489J	PARTICIPANT	\N	PRESENT	0
701402	701397	19820Y	PARTICIPANT	\N	PRESENT	0
701403	701397	14257W	PARTICIPANT	\N	PRESENT	0
701404	701397	20084G	PARTICIPANT	\N	PRESENT	0
701405	701397	19782L	PARTICIPANT	\N	PRESENT	0
701406	701397	19565D	PARTICIPANT	\N	PRESENT	0
701407	701397	20134Y	PARTICIPANT	\N	PRESENT	0
701408	701397	19758L	PARTICIPANT	\N	PRESENT	0
701409	701397	14281W	PARTICIPANT	\N	PRESENT	0
701410	701397	20110Q	PARTICIPANT	\N	PRESENT	0
701411	701397	04045F	PARTICIPANT	\N	PRESENT	0
701412	701397	19735D	PARTICIPANT	\N	PRESENT	0
701413	701397	14327T	PARTICIPANT	\N	PRESENT	0
701414	701397	19681G	PARTICIPANT	\N	PRESENT	0
701415	701397	19335Q	PARTICIPANT	\N	PRESENT	0
701416	701397	20022R	PARTICIPANT	\N	EXCUSE	0
701417	701397	14217N	PARTICIPANT	\N	EXCUSE	0
701418	701397	14215L	PARTICIPANT	\N	EXCUSE	0
701419	701397	14187A	PARTICIPANT	\N	EXCUSE	0
701420	701397	01057W	PARTICIPANT	\N	EXCUSE	0
701421	701397	19447X	PARTICIPANT	\N	EXCUSE	0
701422	701397	08010L	PARTICIPANT	\N	EXCUSE	0
701423	701397	19826F	PARTICIPANT	\N	EXCUSE	0
701424	701397	19563B	PARTICIPANT	\N	EXCUSE	0
701426	701397	14071N	PARTICIPANT	\N	EXCUSE	0
701427	701397	19349W	PARTICIPANT	\N	EXCUSE	0
701428	701397	14107H	PARTICIPANT	\N	EXCUSE	0
701429	701397	20062A	PARTICIPANT	\N	EXCUSE	0
701430	701397	20058E	PARTICIPANT	\N	EXCUSE	0
701431	698933	14042U	PARTICIPANT	\N	PRESENT	0
701432	698933	11097X	PARTICIPANT	\N	PRESENT	0
701433	698933	01034P	PARTICIPANT	\N	PRESENT	0
701434	698933	19479G	PARTICIPANT	\N	PRESENT	0
701447	698934	14042U	PARTICIPANT	\N	PRESENT	0
701448	698934	11097X	PARTICIPANT	\N	PRESENT	0
701449	698934	19479G	PARTICIPANT	\N	PRESENT	0
701450	698935	11097X	PARTICIPANT	\N	PRESENT	0
701451	698935	19479G	PARTICIPANT	\N	PRESENT	0
701452	701397	20070A	PARTICIPANT	\N	PRESENT	0
701471	701397	14205J	PARTICIPANT	\N	PRESENT	0
701530	698900	17023S	PARTICIPANT	\N	PRESENT	0
701570	701566	11115U	PARTICIPANT	\N	PRESENT	0
701576	701575	19711U	PARTICIPANT	\N	PRESENT	0
701577	701575	20050V	PARTICIPANT	\N	PRESENT	0
701581	701579	20138D	PARTICIPANT	\N	PRESENT	0
701582	701579	11031D	PARTICIPANT	\N	PRESENT	0
684699	684696	04059M	PARTICIPANT	\N	PRESENT	0
684700	684696	19643A	PARTICIPANT	\N	PRESENT	0
684701	684696	20134Y	PARTICIPANT	\N	PRESENT	0
684702	684696	20180F	PARTICIPANT	\N	PRESENT	0
684703	684696	20056C	PARTICIPANT	\N	PRESENT	0
684705	684696	14123H	PARTICIPANT	\N	PRESENT	0
684706	684696	20052X	PARTICIPANT	\N	PRESENT	0
684707	684696	08012N	PARTICIPANT	\N	PRESENT	0
684708	684696	19611R	PARTICIPANT	\N	PRESENT	0
684709	684696	14073Q	PARTICIPANT	\N	PRESENT	0
684710	684696	20142Y	PARTICIPANT	\N	PRESENT	0
684711	684696	14109K	PARTICIPANT	\N	PRESENT	0
684714	684696	19533U	PARTICIPANT	\N	PRESENT	0
684715	684696	14229S	PARTICIPANT	\N	PRESENT	0
684716	684696	11043H	PARTICIPANT	\N	PRESENT	0
684720	684696	20058E	PARTICIPANT	\N	PRESENT	0
684718	684696	19527W	PARTICIPANT	\N	PRESENT	0
684719	684696	20026V	PARTICIPANT	\N	PRESENT	0
686352	683655	20024T	PARTICIPANT	\N	EXCUSE	0
686353	683655	20080C	PARTICIPANT	\N	EXCUSE	0
686354	683655	19681G	PARTICIPANT	\N	EXCUSE	0
686355	683655	07029T	PARTICIPANT	\N	EXCUSE	0
686356	683655	20118Y	PARTICIPANT	\N	EXCUSE	0
686357	683655	20098N	PARTICIPANT	\N	PRESENT	0
686360	683655	19798U	PARTICIPANT	\N	PRESENT	0
686710	686709	19585H	PARTICIPANT	\N	PRESENT	0
686711	686709	19631V	PARTICIPANT	\N	PRESENT	0
686712	686709	19533U	PARTICIPANT	\N	PRESENT	0
686713	686709	20140W	PARTICIPANT	\N	PRESENT	1
686714	686709	19798U	PARTICIPANT	\N	PRESENT	1
686715	686709	14257W	PARTICIPANT	\N	PRESENT	1
686716	686709	14038Y	PARTICIPANT	\N	PRESENT	0
686719	686718	19711U	PARTICIPANT	\N	PRESENT	0
688795	688794	19709B	PARTICIPANT	\N	PRESENT	0
690713	690712	14073Q	PARTICIPANT	\N	PRESENT	0
689086	689084	19723Y	PARTICIPANT	\N	PRESENT	0
689087	689085	19723Y	PARTICIPANT	\N	PRESENT	0
690714	690712	08012N	PARTICIPANT	\N	PRESENT	0
690715	690712	20132W	PARTICIPANT	\N	PRESENT	1
690716	690712	20134Y	PARTICIPANT	\N	PRESENT	1
690717	690712	20052X	PARTICIPANT	\N	PRESENT	1
690719	690718	14073Q	PARTICIPANT	\N	PRESENT	0
690720	690718	11043H	PARTICIPANT	\N	PRESENT	0
690721	690718	20052X	PARTICIPANT	\N	PRESENT	0
690728	690727	20066E	PARTICIPANT	\N	PRESENT	0
690805	690804	20094J	PARTICIPANT	\N	PRESENT	0
690806	690804	19575F	PARTICIPANT	\N	PRESENT	0
690807	690804	20110Q	PARTICIPANT	\N	PRESENT	0
690809	690808	11043H	PARTICIPANT	\N	PRESENT	0
690810	690808	20138D	PARTICIPANT	\N	PRESENT	0
690811	690808	20134Y	PARTICIPANT	\N	PRESENT	0
690812	690808	19399H	PARTICIPANT	\N	PRESENT	0
690813	690808	19699S	PARTICIPANT	\N	PRESENT	0
690814	690808	20052X	PARTICIPANT	\N	PRESENT	0
690815	690808	08012N	PARTICIPANT	\N	PRESENT	0
690816	690808	19533U	PARTICIPANT	\N	PRESENT	0
690817	690808	19611R	PARTICIPANT	\N	PRESENT	0
690818	690718	20134Y	PARTICIPANT	\N	PRESENT	0
690819	690718	08012N	PARTICIPANT	\N	PRESENT	0
690829	690828	14053L	PARTICIPANT	\N	PRESENT	0
690835	690696	10015M	PARTICIPANT	\N	PRESENT	0
690842	690836	14042U	PARTICIPANT	\N	PRESENT	0
690843	690836	14217N	PARTICIPANT	\N	PRESENT	0
690844	690836	11067R	PARTICIPANT	\N	PRESENT	0
690845	690836	20130U	PARTICIPANT	\N	PRESENT	0
690846	690836	04092N	PARTICIPANT	\N	PRESENT	0
690847	690836	11097X	PARTICIPANT	\N	PRESENT	0
690848	690837	14042U	PARTICIPANT	\N	PRESENT	0
690849	690837	14217N	PARTICIPANT	\N	PRESENT	0
690850	690837	11067R	PARTICIPANT	\N	PRESENT	0
690851	690837	20130U	PARTICIPANT	\N	PRESENT	0
690852	690837	04092N	PARTICIPANT	\N	PRESENT	0
690853	690837	11097X	PARTICIPANT	\N	PRESENT	0
690854	690838	14217N	PARTICIPANT	\N	PRESENT	0
690855	690838	14042U	PARTICIPANT	\N	PRESENT	0
690856	690838	11067R	PARTICIPANT	\N	PRESENT	0
690857	690838	20130U	PARTICIPANT	\N	PRESENT	0
690858	690838	11097X	PARTICIPANT	\N	PRESENT	0
690859	690839	14042U	PARTICIPANT	\N	PRESENT	0
690860	690839	20130U	PARTICIPANT	\N	PRESENT	0
690861	690839	11097X	PARTICIPANT	\N	PRESENT	0
690862	690840	11097X	PARTICIPANT	\N	PRESENT	0
690863	690841	11097X	PARTICIPANT	\N	PRESENT	0
690880	690879	17965H	PARTICIPANT	\N	PRESENT	0
690881	690879	19715Y	PARTICIPANT	\N	PRESENT	0
690882	690879	19683J	PARTICIPANT	\N	PRESENT	0
690883	690879	11045K	PARTICIPANT	\N	PRESENT	0
691438	690432	14281W	PARTICIPANT	\N	PRESENT	0
691439	690432	10006L	PRESIDENT	0	PRESENT	0
691440	690432	19798U	PARTICIPANT	\N	PRESENT	0
691441	690432	19511N	PARTICIPANT	\N	PRESENT	0
691466	690432	19295A	PARTICIPANT	\N	PRESENT	0
691467	690432	11067R	PARTICIPANT	\N	PRESENT	0
691468	690432	20130U	PARTICIPANT	\N	PRESENT	0
691469	690432	19717B	PARTICIPANT	\N	PRESENT	0
691470	690432	19691J	PARTICIPANT	\N	PRESENT	0
691471	690432	19697Q	PARTICIPANT	\N	PRESENT	0
691472	690432	20040T	PARTICIPANT	\N	PRESENT	0
691473	690432	19657G	PARTICIPANT	\N	PRESENT	0
691474	690432	20066E	PARTICIPANT	\N	PRESENT	0
691475	690432	19679N	PARTICIPANT	\N	PRESENT	0
691476	690432	14223L	PARTICIPANT	\N	PRESENT	0
691477	690432	14071N	PARTICIPANT	\N	PRESENT	0
691478	690432	19703U	PARTICIPANT	\N	PRESENT	0
691479	690432	14213J	PARTICIPANT	\N	PRESENT	0
691480	690432	19723Y	PARTICIPANT	\N	PRESENT	0
691491	690432	19329S	PARTICIPANT	\N	PRESENT	0
691497	690432	19760E	PARTICIPANT	\N	PRESENT	0
691498	690432	19367Y	PARTICIPANT	\N	PRESENT	0
691499	690432	19415P	PARTICIPANT	\N	PRESENT	0
691500	690432	20090E	PARTICIPANT	\N	EXCUSE	0
691501	690432	19569H	PARTICIPANT	\N	PRESENT	0
691503	690432	08045X	PARTICIPANT	\N	PRESENT	0
691504	690432	14026U	PARTICIPANT	\N	PRESENT	0
691505	690432	17965H	PARTICIPANT	\N	PRESENT	0
691506	690432	17779H	PARTICIPANT	\N	PRESENT	0
691507	690432	14042U	PARTICIPANT	\N	PRESENT	0
691508	690432	04043D	PARTICIPANT	\N	PRESENT	0
691509	690432	14217N	PARTICIPANT	\N	PRESENT	0
691510	690432	11097X	PARTICIPANT	\N	PRESENT	0
691512	690432	04057K	PARTICIPANT	\N	PRESENT	0
691514	690432	14195A	PARTICIPANT	\N	PRESENT	0
691515	690432	04092N	PARTICIPANT	\N	PRESENT	0
691517	690432	11031D	PARTICIPANT	\N	PRESENT	0
691571	690432	11045K	PARTICIPANT	\N	PRESENT	0
691572	690432	19683J	PARTICIPANT	\N	PRESENT	0
691582	690446	19760E	PARTICIPANT	\N	PRESENT	0
691583	690446	19717B	PARTICIPANT	\N	PRESENT	0
691584	690446	19367Y	PARTICIPANT	\N	PRESENT	0
691585	690446	19415P	PARTICIPANT	\N	PRESENT	0
691586	690446	20090E	PARTICIPANT	\N	EXCUSE	0
691587	690446	14195A	PARTICIPANT	\N	PRESENT	0
691588	690446	11031D	PARTICIPANT	\N	PRESENT	0
691589	690446	19295A	PARTICIPANT	\N	PRESENT	0
691590	690446	10006L	PRESIDENT	0	PRESENT	0
691591	690446	14217N	PARTICIPANT	\N	PRESENT	0
691592	690446	14042U	PARTICIPANT	\N	PRESENT	0
691593	690446	20040T	PARTICIPANT	\N	PRESENT	0
691594	690446	14281W	PARTICIPANT	\N	PRESENT	0
691595	690446	08045X	PARTICIPANT	\N	PRESENT	0
691596	690446	14026U	PARTICIPANT	\N	PRESENT	0
691597	690446	19691J	PARTICIPANT	\N	PRESENT	0
691598	690446	19569H	PARTICIPANT	\N	PRESENT	0
691599	690446	19553Y	PARTICIPANT	\N	PRESENT	0
691600	690446	19329S	PARTICIPANT	\N	PRESENT	0
691607	690446	19591F	PARTICIPANT	\N	PRESENT	0
691608	690446	14213J	PARTICIPANT	\N	PRESENT	0
691609	690446	20066E	PARTICIPANT	\N	PRESENT	0
691610	690446	19511N	PARTICIPANT	\N	PRESENT	0
691612	690446	19683J	PARTICIPANT	\N	PRESENT	0
691613	690446	19723Y	PARTICIPANT	\N	PRESENT	0
691614	690446	19697Q	PARTICIPANT	\N	PRESENT	0
691615	690446	17779H	PARTICIPANT	\N	EXCUSE	0
691616	690446	19657G	PARTICIPANT	\N	PRESENT	0
691617	690446	04057K	PARTICIPANT	\N	PRESENT	0
691618	690446	11067R	PARTICIPANT	\N	PRESENT	0
691619	690446	04092N	PARTICIPANT	\N	PRESENT	0
691620	690446	14071N	PARTICIPANT	\N	PRESENT	0
691621	690446	20130U	PARTICIPANT	\N	PRESENT	0
691622	690446	17965H	PARTICIPANT	\N	PRESENT	0
698491	698489	04043D	PARTICIPANT	\N	PRESENT	0
698498	698496	04043D	PARTICIPANT	\N	PRESENT	0
698735	698733	20092G	PARTICIPANT	\N	PRESENT	0
699045	699044	99004R	PARTICIPANT	\N	PRESENT	0
699047	699046	99004R	PARTICIPANT	\N	PRESENT	0
703656	703654	19631V	PARTICIPANT	\N	PRESENT	0
703657	703654	19383Y	PARTICIPANT	\N	PRESENT	0
703658	703654	11065P	PARTICIPANT	\N	PRESENT	0
703659	703654	20082E	PARTICIPANT	\N	PRESENT	0
703660	703654	19503N	PARTICIPANT	\N	PRESENT	0
703661	703654	19735D	PARTICIPANT	\N	PRESENT	0
703662	703654	20098N	PARTICIPANT	\N	PRESENT	0
703663	703654	19573D	PARTICIPANT	\N	PRESENT	0
703664	703654	20298U	PARTICIPANT	\N	PRESENT	0
703665	703654	20058E	PARTICIPANT	\N	PRESENT	0
703666	703654	19349W	PARTICIPANT	\N	PRESENT	0
703667	703654	11056N	PARTICIPANT	\N	PRESENT	0
703669	703654	20032T	PARTICIPANT	\N	PRESENT	0
703670	703654	19399H	PARTICIPANT	\N	PRESENT	0
703676	703675	19631V	PARTICIPANT	\N	PRESENT	0
703677	703675	20082E	PARTICIPANT	\N	PRESENT	0
703678	703675	19503N	PARTICIPANT	\N	PRESENT	0
703679	703675	19573D	PARTICIPANT	\N	PRESENT	0
703680	703675	20298U	PARTICIPANT	\N	PRESENT	0
703681	703675	20032T	PARTICIPANT	\N	PRESENT	0
703682	703675	19399H	PARTICIPANT	\N	PRESENT	0
703683	703675	19383Y	PARTICIPANT	\N	PRESENT	0
703684	703675	11056N	PARTICIPANT	\N	PRESENT	0
703685	703675	20046A	PARTICIPANT	\N	PRESENT	0
704147	704146	19713W	PARTICIPANT	\N	PRESENT	0
704148	704146	19525U	PARTICIPANT	\N	PRESENT	0
704149	704146	01024M	PARTICIPANT	\N	PRESENT	0
704150	704146	11066Q	PARTICIPANT	\N	PRESENT	0
704151	704146	19782L	PARTICIPANT	\N	PRESENT	0
708318	708051	19347U	PARTICIPANT	\N	PRESENT	0
708319	708051	20130U	PARTICIPANT	\N	PRESENT	0
708320	708051	19758L	PARTICIPANT	\N	PRESENT	0
708321	708051	19760E	PARTICIPANT	\N	PRESENT	0
708322	708051	11031D	PARTICIPANT	\N	PRESENT	0
708323	708051	11077T	PARTICIPANT	\N	PRESENT	0
708324	708051	19503N	PARTICIPANT	\N	PRESENT	0
708325	708051	20094J	PARTICIPANT	\N	PRESENT	0
708326	708051	14281W	PARTICIPANT	\N	PRESENT	0
708327	708051	14109K	PARTICIPANT	\N	PRESENT	0
708328	708051	19715Y	PARTICIPANT	\N	PRESENT	0
708329	708051	19553Y	PARTICIPANT	\N	PRESENT	0
708330	708051	01034P	PARTICIPANT	\N	PRESENT	0
708331	708051	14042U	PARTICIPANT	\N	PRESENT	0
708332	708051	11097X	PARTICIPANT	\N	PRESENT	0
708333	708051	10006L	PARTICIPANT	\N	PRESENT	0
708334	708051	19591F	PARTICIPANT	\N	PRESENT	0
708335	708051	19569H	PARTICIPANT	\N	PRESENT	0
708336	708051	20032T	PARTICIPANT	\N	PRESENT	0
708337	708051	20074E	PARTICIPANT	\N	PRESENT	0
708338	708051	14187A	PARTICIPANT	\N	PRESENT	0
708339	708051	04092N	PARTICIPANT	\N	PRESENT	0
708340	708051	19657G	PARTICIPANT	\N	PRESENT	0
708341	708051	19581D	PARTICIPANT	\N	PRESENT	0
708342	708051	19711U	PARTICIPANT	\N	PRESENT	0
708343	708051	08015R	PARTICIPANT	\N	PRESENT	0
708344	708051	14213J	PARTICIPANT	\N	PRESENT	0
708345	708051	14026U	PARTICIPANT	\N	PRESENT	0
708346	708051	04033B	PARTICIPANT	\N	PRESENT	0
708347	708051	20062A	PARTICIPANT	\N	PRESENT	0
708348	708051	11040E	PARTICIPANT	\N	PRESENT	0
708349	708051	19629C	PARTICIPANT	\N	PRESENT	0
708350	708051	11012A	PARTICIPANT	\N	PRESENT	0
708351	708051	11074Q	PARTICIPANT	\N	PRESENT	0
708352	708051	19798U	PARTICIPANT	\N	PRESENT	0
708353	708051	14030Q	PARTICIPANT	\N	PRESENT	0
708354	708051	14107H	PARTICIPANT	\N	PRESENT	0
708355	708051	20068G	PARTICIPANT	\N	PRESENT	0
708356	708051	19515S	PARTICIPANT	\N	PRESENT	0
708357	708051	14215L	PARTICIPANT	\N	PRESENT	0
708358	708051	20064C	PARTICIPANT	\N	PRESENT	0
708359	708051	19525U	PARTICIPANT	\N	PRESENT	0
708360	708051	19683J	PARTICIPANT	\N	PRESENT	0
708361	708051	14223L	PARTICIPANT	\N	PRESENT	0
708362	708051	20914V	PARTICIPANT	\N	PRESENT	0
708363	708051	08045X	PARTICIPANT	\N	PRESENT	0
708364	708051	08018U	PARTICIPANT	\N	PRESENT	0
708365	708051	20084G	PARTICIPANT	\N	PRESENT	0
708366	708051	20264J	PARTICIPANT	\N	PRESENT	0
708367	708051	19413M	PARTICIPANT	\N	PRESENT	0
708368	708051	18193Q	PARTICIPANT	\N	PRESENT	0
708369	708051	11067R	PARTICIPANT	\N	PRESENT	0
708370	708051	11066Q	PARTICIPANT	\N	PRESENT	0
708371	708051	19667J	PARTICIPANT	\N	PRESENT	0
708372	708051	14231L	PARTICIPANT	\N	PRESENT	0
708373	708051	14071N	PARTICIPANT	\N	PRESENT	0
708374	708051	04085P	PARTICIPANT	\N	PRESENT	0
708375	708051	20122U	PARTICIPANT	\N	PRESENT	0
708376	708051	20046A	PARTICIPANT	\N	PRESENT	0
708377	708051	19695N	PARTICIPANT	\N	PRESENT	0
708378	708051	19659J	PARTICIPANT	\N	PRESENT	0
708379	708051	20056C	PARTICIPANT	\N	PRESENT	0
708380	708051	20080C	PARTICIPANT	\N	PRESENT	0
708382	708051	20248J	PARTICIPANT	\N	PRESENT	0
708383	708051	20040T	PARTICIPANT	\N	PRESENT	0
708384	708051	20088L	PARTICIPANT	\N	PRESENT	0
708385	708051	20108W	PARTICIPANT	\N	PRESENT	0
708386	708051	19766L	PARTICIPANT	\N	PRESENT	0
708387	708051	14229S	PARTICIPANT	\N	PRESENT	0
708388	708051	14225N	PARTICIPANT	\N	PRESENT	0
708389	708051	12028B	PARTICIPANT	\N	PRESENT	0
708390	708051	19251M	PARTICIPANT	\N	PRESENT	0
708391	708051	17737W	PARTICIPANT	\N	PRESENT	0
708392	708051	19507S	PARTICIPANT	\N	PRESENT	0
708393	708051	20044X	PARTICIPANT	\N	PRESENT	0
708394	708051	04059M	PARTICIPANT	\N	PRESENT	0
708395	708051	19649G	PARTICIPANT	\N	PRESENT	0
708396	708051	19701S	PARTICIPANT	\N	PRESENT	0
708397	708051	19367Y	PARTICIPANT	\N	PRESENT	0
708398	708051	19383Y	PARTICIPANT	\N	PRESENT	0
708316	708051	12041X	PARTICIPANT	\N	PRESENT	0
708317	708051	17779H	PARTICIPANT	\N	PRESENT	0
708400	708051	19349W	PARTICIPANT	\N	PRESENT	0
708401	708051	01048V	PARTICIPANT	\N	PRESENT	0
708402	708051	11045K	PARTICIPANT	\N	PRESENT	0
708403	708051	14173T	PARTICIPANT	\N	PRESENT	0
708404	708051	19820Y	PARTICIPANT	\N	PRESENT	0
708405	708051	14329V	PARTICIPANT	\N	PRESENT	0
708406	708051	20086J	PARTICIPANT	\N	PRESENT	0
708407	708051	20028X	PARTICIPANT	\N	PRESENT	0
708408	708051	19479G	PARTICIPANT	\N	PRESENT	0
708409	708051	14083S	PARTICIPANT	\N	PRESENT	0
708410	708051	14189C	PARTICIPANT	\N	PRESENT	0
708411	708051	19747H	PARTICIPANT	\N	PRESENT	0
708412	708051	11048N	PARTICIPANT	\N	PRESENT	0
708413	708051	20058E	PARTICIPANT	\N	PRESENT	0
708414	708051	19531S	PARTICIPANT	\N	PRESENT	0
708415	708051	11056N	PARTICIPANT	\N	PRESENT	0
708416	708051	95063L	PARTICIPANT	\N	PRESENT	0
708417	708051	19735D	PARTICIPANT	\N	PRESENT	0
708418	708051	12016W	PARTICIPANT	\N	PRESENT	0
708419	708051	20114U	PARTICIPANT	\N	PRESENT	0
708420	708051	20066E	PARTICIPANT	\N	PRESENT	0
708421	708051	19723Y	PARTICIPANT	\N	PRESENT	0
708422	708051	19745F	PARTICIPANT	\N	PRESENT	0
708423	708051	19593H	PARTICIPANT	\N	PRESENT	0
708424	708051	17229F	PARTICIPANT	\N	PRESENT	0
708425	708051	14089Y	PARTICIPANT	\N	PRESENT	0
708426	708051	04035D	PARTICIPANT	\N	PRESENT	0
708427	708051	20112S	PARTICIPANT	\N	PRESENT	0
708428	708051	19489J	PARTICIPANT	\N	PRESENT	0
708429	708051	20100N	PARTICIPANT	\N	PRESENT	0
708430	708051	20070A	PARTICIPANT	\N	PRESENT	0
708431	708051	20054A	PARTICIPANT	\N	PRESENT	0
708432	708051	14073Q	PARTICIPANT	\N	PRESENT	0
708433	708051	20252E	PARTICIPANT	\N	PRESENT	0
708446	708051	14221J	PARTICIPANT	\N	PRESENT	0
708447	708051	14038Y	PARTICIPANT	\N	PRESENT	0
708448	708051	04045F	PARTICIPANT	\N	PRESENT	0
708449	708051	11027H	PARTICIPANT	\N	PRESENT	0
708450	708051	19329S	PARTICIPANT	\N	PRESENT	0
708451	708051	08034U	PARTICIPANT	\N	PRESENT	0
708452	708051	16685X	PARTICIPANT	\N	PRESENT	0
708453	708051	14151M	PARTICIPANT	\N	PRESENT	0
708454	708051	14037X	PARTICIPANT	\N	PRESENT	0
685101	683338	11053K	PARTICIPANT	\N	PRESENT	0
685102	683338	14189C	PARTICIPANT	\N	PRESENT	0
685103	683057	14151M	PARTICIPANT	\N	PRESENT	0
685104	683338	11110B	PARTICIPANT	\N	PRESENT	0
685105	683057	20022R	PARTICIPANT	\N	PRESENT	0
685128	683338	20086J	PARTICIPANT	\N	PRESENT	0
685147	683338	08034U	PARTICIPANT	\N	PRESENT	0
685148	683338	20914V	PARTICIPANT	\N	PRESENT	0
685149	683057	19585H	PARTICIPANT	\N	PRESENT	0
685150	683057	20114U	PARTICIPANT	\N	PRESENT	0
685151	683338	01048V	PARTICIPANT	\N	PRESENT	0
685152	683338	19762G	PARTICIPANT	\N	PRESENT	0
685153	683338	19545Y	PARTICIPANT	\N	PRESENT	0
685156	683057	19581D	PARTICIPANT	\N	PRESENT	0
685157	683057	19649G	PARTICIPANT	\N	PRESENT	0
685158	681116	04070G	PARTICIPANT	\N	PRESENT	0
685159	681116	19699S	PARTICIPANT	\N	PRESENT	0
685160	681116	19533U	PARTICIPANT	\N	PRESENT	0
685161	681116	04033B	PARTICIPANT	\N	PRESENT	0
685162	681116	01060R	PARTICIPANT	\N	PRESENT	0
685163	681116	14229S	PARTICIPANT	\N	PRESENT	0
685164	681116	20098N	PARTICIPANT	\N	PRESENT	0
685165	681116	19573D	PARTICIPANT	\N	PRESENT	0
685166	681116	92040Q	PARTICIPANT	\N	PRESENT	0
685167	681116	20112S	PARTICIPANT	\N	PRESENT	0
685168	681116	20124W	PARTICIPANT	\N	PRESENT	0
685169	681116	20026V	PARTICIPANT	\N	PRESENT	0
685170	681116	19593H	PARTICIPANT	\N	PRESENT	0
685171	681116	19527W	PARTICIPANT	\N	PRESENT	0
685172	681116	14073Q	PARTICIPANT	\N	PRESENT	0
685173	681116	19651A	PARTICIPANT	\N	PRESENT	0
685174	681116	19611R	PRESIDENT	0	PRESENT	0
685175	681116	20138D	PARTICIPANT	\N	PRESENT	0
685176	681116	20142Y	PARTICIPANT	\N	PRESENT	0
685177	681116	19399H	PARTICIPANT	\N	PRESENT	0
685178	681116	20152B	PARTICIPANT	\N	PRESENT	0
685179	681116	20052X	PARTICIPANT	\N	PRESENT	0
685180	681116	20172F	PARTICIPANT	\N	PRESENT	0
685181	681116	20058E	PARTICIPANT	\N	PRESENT	0
685182	681116	14030Q	PARTICIPANT	\N	PRESENT	0
685183	681116	20056C	PARTICIPANT	\N	PRESENT	0
685184	681116	20264J	PARTICIPANT	\N	PRESENT	0
685185	681116	19735D	PARTICIPANT	\N	PRESENT	0
685186	681116	19057M	PARTICIPANT	\N	PRESENT	0
685187	681116	14109K	PARTICIPANT	\N	PRESENT	0
685188	681116	14123H	PARTICIPANT	\N	PRESENT	0
685189	681116	11043H	PARTICIPANT	\N	PRESENT	0
685190	681116	11104D	PARTICIPANT	\N	PRESENT	0
685191	681116	19758L	PARTICIPANT	\N	PRESENT	0
685192	681116	17589D	PARTICIPANT	\N	PRESENT	0
685193	681116	19643A	PARTICIPANT	\N	PRESENT	0
685194	681116	20132W	PARTICIPANT	\N	PRESENT	0
685195	681116	20134Y	PARTICIPANT	\N	PRESENT	0
685196	681116	20048C	PARTICIPANT	\N	PRESENT	0
685197	681116	20084G	PARTICIPANT	\N	PRESENT	0
685198	681116	04059M	PARTICIPANT	\N	PRESENT	0
685199	683057	11026G	PARTICIPANT	\N	PRESENT	0
685200	683338	14083S	PARTICIPANT	\N	PRESENT	0
685201	683338	07029T	PARTICIPANT	\N	PRESENT	0
685202	681308	19701S	PARTICIPANT	\N	PRESENT	0
685203	681308	19549D	PARTICIPANT	\N	PRESENT	0
685204	681308	20076G	PARTICIPANT	\N	PRESENT	0
685205	681308	19387D	PARTICIPANT	\N	PRESENT	0
685206	681308	19820Y	PARTICIPANT	\N	PRESENT	0
685207	681308	14219Q	PRESIDENT	0	PRESENT	0
685208	681308	19826F	PARTICIPANT	\N	PRESENT	0
685209	681308	14221J	PARTICIPANT	\N	PRESENT	0
685210	681308	20102Q	PARTICIPANT	\N	PRESENT	0
685211	681308	19599P	PARTICIPANT	\N	PRESENT	0
685212	681308	14237S	PARTICIPANT	\N	PRESENT	0
685213	681308	18083K	PARTICIPANT	\N	PRESENT	0
685214	681308	05012A	PARTICIPANT	\N	PRESENT	0
685215	681308	20106U	PARTICIPANT	\N	PRESENT	0
685216	681308	08060W	PARTICIPANT	\N	PRESENT	0
685217	681308	19503N	PARTICIPANT	\N	PRESENT	0
685218	681308	20020P	PARTICIPANT	\N	PRESENT	0
685219	681308	20024T	PARTICIPANT	\N	PRESENT	0
685220	681308	20120S	PARTICIPANT	\N	PRESENT	0
685221	681308	14031R	PARTICIPANT	\N	PRESENT	0
685222	681308	20038A	PARTICIPANT	\N	PRESENT	0
685223	681308	20046A	PARTICIPANT	\N	PRESENT	0
685224	681308	17229F	PARTICIPANT	\N	PRESENT	0
685225	681308	20068G	PARTICIPANT	\N	PRESENT	0
685226	681308	19739H	PARTICIPANT	\N	PRESENT	0
685227	681308	19745F	PARTICIPANT	\N	PRESENT	0
685228	681308	19619A	PARTICIPANT	\N	PRESENT	0
685229	681116	20180F	PARTICIPANT	\N	PRESENT	0
685230	681116	11109J	PARTICIPANT	\N	EXCUSE	0
685231	681117	04070G	PARTICIPANT	\N	PRESENT	0
685232	681117	19699S	PARTICIPANT	\N	PRESENT	0
685233	681117	19533U	PARTICIPANT	\N	PRESENT	0
685234	681117	04033B	PARTICIPANT	\N	PRESENT	0
685235	681117	01060R	PARTICIPANT	\N	PRESENT	0
685236	681117	14229S	PARTICIPANT	\N	PRESENT	0
685237	681117	20098N	PARTICIPANT	\N	PRESENT	0
685238	681117	19573D	PARTICIPANT	\N	PRESENT	0
685239	681117	92040Q	PARTICIPANT	\N	PRESENT	0
685240	681117	20112S	PARTICIPANT	\N	PRESENT	0
685241	681117	20124W	PARTICIPANT	\N	PRESENT	0
685242	681117	20026V	PARTICIPANT	\N	PRESENT	0
685243	681117	19593H	PARTICIPANT	\N	PRESENT	0
685244	681117	19527W	PARTICIPANT	\N	PRESENT	0
685245	681117	19643A	PARTICIPANT	\N	PRESENT	0
685246	681117	20132W	PARTICIPANT	\N	PRESENT	0
685247	681117	20134Y	PARTICIPANT	\N	PRESENT	0
685248	681117	14073Q	PARTICIPANT	\N	PRESENT	0
685249	681117	19651A	PARTICIPANT	\N	PRESENT	0
685250	681117	19611R	PRESIDENT	0	PRESENT	0
685251	681117	20138D	PARTICIPANT	\N	PRESENT	0
685252	681117	20142Y	PARTICIPANT	\N	PRESENT	0
685253	681117	20048C	PARTICIPANT	\N	PRESENT	0
685254	681117	19399H	PARTICIPANT	\N	PRESENT	0
685255	681117	20152B	PARTICIPANT	\N	PRESENT	0
685256	681117	20052X	PARTICIPANT	\N	PRESENT	0
685257	681117	20172F	PARTICIPANT	\N	PRESENT	0
685258	681117	20058E	PARTICIPANT	\N	PRESENT	0
685259	681117	14030Q	PARTICIPANT	\N	PRESENT	0
685260	681117	20056C	PARTICIPANT	\N	PRESENT	0
685261	681117	20180F	PARTICIPANT	\N	PRESENT	0
685262	681117	20264J	PARTICIPANT	\N	PRESENT	0
685263	681117	04059M	PARTICIPANT	\N	PRESENT	0
685264	681117	19735D	PARTICIPANT	\N	PRESENT	0
685265	681117	19057M	PARTICIPANT	\N	PRESENT	0
685266	681117	14109K	PARTICIPANT	\N	PRESENT	0
685267	681117	14123H	PARTICIPANT	\N	PRESENT	0
685268	681117	11043H	PARTICIPANT	\N	PRESENT	0
685269	681117	11104D	PARTICIPANT	\N	PRESENT	0
685270	681117	19758L	PARTICIPANT	\N	PRESENT	0
685271	681117	17589D	PARTICIPANT	\N	PRESENT	0
685272	681117	20084G	PARTICIPANT	\N	PRESENT	0
685273	681117	11109J	PARTICIPANT	\N	EXCUSE	0
685339	683642	19768N	PARTICIPANT	\N	PRESENT	0
685340	683642	20088L	PARTICIPANT	\N	PRESENT	0
685341	683642	19515S	PARTICIPANT	\N	PRESENT	0
685342	683642	20092G	PARTICIPANT	\N	PRESENT	0
685343	683642	19782L	PARTICIPANT	\N	PRESENT	0
685344	683642	11077T	PARTICIPANT	\N	PRESENT	0
685345	683642	14357A	PARTICIPANT	\N	PRESENT	0
685346	683642	20078J	PARTICIPANT	\N	PRESENT	0
685347	683642	19413M	PARTICIPANT	\N	PRESENT	0
685348	683642	20082E	PARTICIPANT	\N	PRESENT	0
685349	683642	20094J	PARTICIPANT	\N	PRESENT	0
685350	683642	04045F	PARTICIPANT	\N	PRESENT	0
685351	683642	19866P	PARTICIPANT	\N	PRESENT	0
685352	683642	19631V	PARTICIPANT	\N	PRESENT	0
685353	683642	20104S	PARTICIPANT	\N	PRESENT	0
685354	683642	11099A	PARTICIPANT	\N	PRESENT	0
685355	683642	19705W	PARTICIPANT	\N	PRESENT	0
685356	683642	08015R	PARTICIPANT	\N	PRESENT	0
685357	683642	19575F	PARTICIPANT	\N	PRESENT	0
685358	683642	19369B	PARTICIPANT	\N	PRESENT	0
685359	683642	20018V	PARTICIPANT	\N	PRESENT	0
685360	683642	08028W	PARTICIPANT	\N	PRESENT	0
685361	683642	19563B	PARTICIPANT	\N	PRESENT	0
685362	683642	20028X	PARTICIPANT	\N	PRESENT	0
685363	683642	14329V	PARTICIPANT	\N	PRESENT	0
685364	683642	14038Y	PARTICIPANT	\N	PRESENT	0
685365	683642	20030R	PARTICIPANT	\N	PRESENT	0
685366	683642	19467C	PARTICIPANT	\N	PRESENT	0
685367	683642	20034V	PARTICIPANT	\N	PRESENT	0
685368	683642	14187A	PARTICIPANT	\N	PRESENT	0
699006	699005	19367Y	PARTICIPANT	\N	PRESENT	0
699007	699005	14213J	PARTICIPANT	\N	PRESENT	0
699008	699005	19798U	PARTICIPANT	\N	PRESENT	0
699009	699005	11067R	PARTICIPANT	\N	PRESENT	0
699010	699005	14223L	PARTICIPANT	\N	PRESENT	0
699012	699011	10006L	PARTICIPANT	\N	PRESENT	0
699013	699011	18193Q	PARTICIPANT	\N	PRESENT	0
699014	699011	19697Q	PARTICIPANT	\N	PRESENT	0
701583	701579	19725B	PARTICIPANT	\N	PRESENT	0
701584	701579	19735D	PRESIDENT	0	PRESENT	0
701585	701579	04092N	PARTICIPANT	\N	PRESENT	0
701586	701579	14026U	PARTICIPANT	\N	PRESENT	0
701587	701579	14213J	PARTICIPANT	\N	PRESENT	0
701588	701579	19369B	PARTICIPANT	\N	PRESENT	0
701591	701579	20096L	PARTICIPANT	\N	PRESENT	0
701639	701599	19735D	PARTICIPANT	\N	EXCUSE	0
701640	701600	19735D	PARTICIPANT	\N	EXCUSE	0
701670	701669	14026U	PARTICIPANT	\N	PRESENT	0
701671	701669	19725B	PARTICIPANT	\N	PRESENT	0
701673	701672	05008E	PARTICIPANT	\N	PRESENT	0
701674	701672	11053K	PARTICIPANT	\N	PRESENT	0
701675	701672	01028R	PARTICIPANT	\N	PRESENT	0
701677	701676	20024T	PARTICIPANT	\N	PRESENT	0
701678	701676	14083S	PARTICIPANT	\N	PRESENT	0
701679	701676	11053K	PARTICIPANT	\N	PRESENT	0
701680	701676	19251M	PARTICIPANT	\N	PRESENT	0
701681	701676	20052X	PARTICIPANT	\N	PRESENT	0
701682	701676	19671E	PARTICIPANT	\N	PRESENT	0
701683	701676	20044X	PARTICIPANT	\N	PRESENT	0
701685	701684	14331P	PARTICIPANT	\N	PRESENT	0
702023	702022	14111D	PARTICIPANT	\N	PRESENT	0
702026	701892	19691J	PARTICIPANT	\N	PRESENT	0
702027	701892	20090E	PARTICIPANT	\N	PRESENT	1
702028	701892	14281W	PARTICIPANT	\N	PRESENT	0
702628	702626	08015R	PARTICIPANT	\N	PRESENT	0
702641	702626	14211G	PARTICIPANT	\N	PRESENT	0
702642	702626	01024M	PARTICIPANT	\N	PRESENT	0
702643	702626	19467C	PARTICIPANT	\N	PRESENT	0
702644	702626	19441R	PARTICIPANT	\N	PRESENT	0
702645	702626	20126Y	PARTICIPANT	\N	PRESENT	0
702647	702626	20114U	PARTICIPANT	\N	PRESENT	0
702648	702626	20030R	PARTICIPANT	\N	PRESENT	0
702911	701180	20066E	PARTICIPANT	\N	PRESENT	0
702912	701180	19725B	PRESIDENT	0	PRESENT	0
702913	701180	14026U	PARTICIPANT	\N	PRESENT	0
702914	701180	20126Y	PARTICIPANT	\N	PRESENT	0
702915	701180	17965H	PARTICIPANT	\N	PRESENT	0
702916	701180	20050V	PARTICIPANT	\N	PRESENT	0
702917	701180	11031D	PARTICIPANT	\N	PRESENT	0
702918	701180	20096L	PARTICIPANT	\N	PRESENT	0
702919	701180	08069G	PARTICIPANT	\N	PRESENT	0
702920	701180	20024T	PARTICIPANT	\N	EXCUSE	0
702921	701180	20138D	PARTICIPANT	\N	EXCUSE	0
702929	701180	19369B	PARTICIPANT	\N	PRESENT	0
702947	702946	19667J	PARTICIPANT	\N	PRESENT	0
702948	702946	19701S	PARTICIPANT	\N	PRESENT	0
702949	702946	11027H	PARTICIPANT	\N	PRESENT	0
702950	702946	19693L	PARTICIPANT	\N	PRESENT	0
702951	702946	14179A	PARTICIPANT	\N	PRESENT	0
702955	701724	19441R	PARTICIPANT	\N	PRESENT	0
702956	701724	04057K	PARTICIPANT	\N	PRESENT	0
703264	703263	19553Y	PARTICIPANT	\N	PRESENT	0
703265	703263	19387D	PARTICIPANT	\N	PRESENT	0
703266	703263	11065P	PARTICIPANT	\N	PRESENT	0
703565	692497	11010L	PARTICIPANT	\N	PRESENT	0
703687	703668	17737W	PARTICIPANT	\N	PRESENT	0
703689	703688	17737W	PARTICIPANT	\N	PRESENT	0
703745	703744	11101A	PARTICIPANT	\N	PRESENT	0
703746	703744	08028W	PARTICIPANT	\N	PRESENT	0
703747	703744	20052X	PARTICIPANT	\N	PRESENT	0
703748	703744	14221J	PARTICIPANT	\N	PRESENT	0
703749	703744	20018V	PARTICIPANT	\N	PRESENT	0
703750	703744	14223L	PARTICIPANT	\N	PRESENT	0
703751	703744	19703U	PARTICIPANT	\N	PRESENT	0
703775	701599	01048V	PARTICIPANT	\N	PRESENT	0
703777	701599	19503N	PARTICIPANT	\N	PRESENT	0
703778	701599	04043D	PARTICIPANT	\N	PRESENT	0
703779	701599	01058X	PARTICIPANT	\N	EXCUSE	0
703783	703782	11040E	PARTICIPANT	\N	PRESENT	0
703784	703782	14083S	PARTICIPANT	\N	PRESENT	0
703785	703782	19467C	PARTICIPANT	\N	PRESENT	0
703786	703782	19691J	PARTICIPANT	\N	PRESENT	0
703788	703782	19591F	PARTICIPANT	\N	PRESENT	0
703795	703782	11067R	PARTICIPANT	\N	PRESENT	0
703793	703782	18193Q	PARTICIPANT	\N	PRESENT	0
703794	703782	14059S	PARTICIPANT	\N	PRESENT	0
703796	703782	14147R	PARTICIPANT	\N	PRESENT	0
703797	703782	14223L	PARTICIPANT	\N	PRESENT	0
703798	703782	08047A	PARTICIPANT	\N	PRESENT	0
703799	703782	19798U	PARTICIPANT	\N	PRESENT	0
703800	703782	19703U	PARTICIPANT	\N	PRESENT	0
703801	703782	20062A	PARTICIPANT	\N	PRESENT	0
703802	703782	14071N	PARTICIPANT	\N	PRESENT	0
703806	692497	97011G	PARTICIPANT	\N	PRESENT	0
703809	692497	14059S	PARTICIPANT	\N	PRESENT	0
703811	692497	20146D	PARTICIPANT	\N	PRESENT	0
703814	692497	18083K	PARTICIPANT	\N	PRESENT	0
703818	703817	14133K	PARTICIPANT	\N	PRESENT	0
703819	703817	16685X	PARTICIPANT	\N	PRESENT	0
703821	703820	14089Y	PARTICIPANT	\N	PRESENT	0
703822	703820	19447X	PARTICIPANT	\N	PRESENT	0
703824	703823	19447X	PARTICIPANT	\N	PRESENT	0
703825	703823	14089Y	PARTICIPANT	\N	PRESENT	0
703826	703823	20110Q	PARTICIPANT	\N	PRESENT	0
703828	703827	19447X	PARTICIPANT	\N	PRESENT	0
703829	703827	14089Y	PARTICIPANT	\N	PRESENT	0
703830	703827	20110Q	PARTICIPANT	\N	PRESENT	0
703831	703827	11026G	PARTICIPANT	\N	PRESENT	0
703870	692497	08034U	PARTICIPANT	\N	PRESENT	0
703876	692497	08073C	PARTICIPANT	\N	PRESENT	0
703885	692497	19715Y	PARTICIPANT	\N	PRESENT	0
703886	692497	20148F	PARTICIPANT	\N	EXCUSE	0
703887	692497	19657G	PARTICIPANT	\N	EXCUSE	0
703919	701649	19691J	PARTICIPANT	\N	PRESENT	0
703920	701649	14071N	PARTICIPANT	\N	PRESENT	0
703921	701649	11031D	PARTICIPANT	\N	PRESENT	0
704109	704106	11074Q	PARTICIPANT	\N	PRESENT	0
704108	704106	11080N	PRESIDENT	0	PRESENT	0
704110	704106	14121F	PARTICIPANT	\N	PRESENT	0
704111	704106	19711U	PARTICIPANT	\N	PRESENT	0
704112	704106	05012A	PARTICIPANT	\N	PRESENT	0
704115	704114	20112S	PARTICIPANT	\N	PRESENT	0
704116	704114	19643A	PARTICIPANT	\N	PRESENT	0
704117	704114	19735D	PARTICIPANT	\N	PRESENT	1
704118	704114	20142Y	PARTICIPANT	\N	PRESENT	0
704119	704113	19643A	PARTICIPANT	\N	PRESENT	1
704120	704113	20112S	PARTICIPANT	\N	PRESENT	1
704121	704113	19693L	PARTICIPANT	\N	PRESENT	1
704122	704106	20042V	PARTICIPANT	\N	PRESENT	0
704123	704106	01057W	PARTICIPANT	\N	PRESENT	0
704124	704106	19687N	PARTICIPANT	\N	PRESENT	0
704127	704125	11031D	PARTICIPANT	\N	PRESENT	0
704128	704125	19725B	PARTICIPANT	\N	PRESENT	0
704129	704125	20138D	PARTICIPANT	\N	PRESENT	0
704130	704125	20024T	PARTICIPANT	\N	PRESENT	0
704131	704125	14213J	PARTICIPANT	\N	PRESENT	0
704132	704125	20126Y	PARTICIPANT	\N	PRESENT	0
704133	704125	04045F	PARTICIPANT	\N	PRESENT	0
704134	704125	17965H	PARTICIPANT	\N	PRESENT	0
704136	704126	11031D	PARTICIPANT	\N	PRESENT	0
704137	704126	14213J	PARTICIPANT	\N	PRESENT	0
704138	704126	20126Y	PARTICIPANT	\N	PRESENT	0
704139	704126	04045F	PARTICIPANT	\N	PRESENT	0
704259	704238	20050V	PARTICIPANT	\N	EXCUSE	0
704260	704238	14193X	PARTICIPANT	\N	EXCUSE	0
704261	704238	19954N	PARTICIPANT	\N	PRESENT	0
704262	704257	20066E	PARTICIPANT	\N	EXCUSE	0
704263	704258	20066E	PARTICIPANT	\N	EXCUSE	0
704264	704190	18193Q	PARTICIPANT	\N	PRESENT	1
704265	704190	14213J	PARTICIPANT	\N	PRESENT	1
704266	704190	20090E	PARTICIPANT	\N	PRESENT	1
704267	704190	14195A	PARTICIPANT	\N	PRESENT	1
704317	704313	11077T	PARTICIPANT	\N	PRESENT	0
704318	704313	14187A	PRESIDENT	0	PRESENT	0
704319	704313	19347U	PARTICIPANT	\N	PRESENT	0
704320	704313	20018V	PARTICIPANT	\N	PRESENT	0
704321	704313	20124W	PARTICIPANT	\N	PRESENT	0
704322	704313	14257W	PARTICIPANT	\N	PRESENT	0
686497	686496	19515S	PRESIDENT	0	PRESENT	0
686502	686496	19251M	PARTICIPANT	\N	PRESENT	0
686506	686496	19525U	PARTICIPANT	\N	PRESENT	0
686507	686496	14083S	PARTICIPANT	\N	PRESENT	0
686508	686496	19467C	PARTICIPANT	\N	PRESENT	0
686509	686496	19575F	PARTICIPANT	\N	PRESENT	0
686510	686496	08015R	PARTICIPANT	\N	PRESENT	0
686511	686496	19369B	PARTICIPANT	\N	PRESENT	0
686512	686496	14031R	PARTICIPANT	\N	PRESENT	0
686513	686496	14357A	PARTICIPANT	\N	PRESENT	0
686515	686496	20092G	PARTICIPANT	\N	PRESENT	0
686519	686496	19762G	PARTICIPANT	\N	PRESENT	0
686521	686496	20094J	PARTICIPANT	\N	PRESENT	0
686523	686496	20048C	PARTICIPANT	\N	PRESENT	0
686524	686496	16685X	PARTICIPANT	\N	PRESENT	0
686525	686496	20082E	PARTICIPANT	\N	PRESENT	0
686532	686496	19760E	PARTICIPANT	\N	EXCUSE	0
686536	686496	14105F	PARTICIPANT	\N	EXCUSE	0
686534	686496	14030Q	PARTICIPANT	\N	EXCUSE	0
686535	686496	08060W	PARTICIPANT	\N	EXCUSE	0
686537	686496	19545Y	PARTICIPANT	\N	EXCUSE	0
686539	686496	14329V	PARTICIPANT	\N	EXCUSE	0
686540	686496	14195A	PARTICIPANT	\N	EXCUSE	0
686541	686496	08028W	PARTICIPANT	\N	EXCUSE	0
686543	686496	20134Y	PARTICIPANT	\N	EXCUSE	0
686544	686496	20040T	PARTICIPANT	\N	EXCUSE	0
686545	686496	19695N	PARTICIPANT	\N	EXCUSE	0
686546	686496	14026U	PARTICIPANT	\N	EXCUSE	0
686547	686496	20126Y	PARTICIPANT	\N	EXCUSE	0
686548	686496	19697Q	PARTICIPANT	\N	EXCUSE	0
686549	686496	19671E	PARTICIPANT	\N	EXCUSE	0
686550	686496	19866P	PARTICIPANT	\N	EXCUSE	0
686551	686496	20030R	PARTICIPANT	\N	EXCUSE	0
686552	686496	17965H	PARTICIPANT	\N	EXCUSE	0
686554	686496	20054A	PARTICIPANT	\N	EXCUSE	0
686555	686496	19301E	PARTICIPANT	\N	EXCUSE	0
688198	686134	14213J	PARTICIPANT	\N	PRESENT	0
688199	686134	14026U	PARTICIPANT	\N	PRESENT	0
688201	686134	11097X	PARTICIPANT	\N	PRESENT	0
688202	686134	19798U	PARTICIPANT	\N	PRESENT	0
688203	686134	19679N	PARTICIPANT	\N	PRESENT	0
688204	686134	14071N	PRESIDENT	0	PRESENT	0
688205	686134	11067R	PARTICIPANT	\N	PRESENT	0
688206	686134	04057K	PARTICIPANT	\N	PRESENT	0
688212	686134	19715Y	PARTICIPANT	\N	EXCUSE	0
688232	686134	20090E	PARTICIPANT	\N	PRESENT	0
691623	690446	04043D	PARTICIPANT	\N	PRESENT	0
691627	690446	19679N	PARTICIPANT	\N	PRESENT	0
691628	690446	19798U	PARTICIPANT	\N	PRESENT	0
691629	690446	11045K	PARTICIPANT	\N	PRESENT	0
691630	690446	11097X	PARTICIPANT	\N	PRESENT	0
691632	690446	19703U	PARTICIPANT	\N	PRESENT	0
691633	690446	01034P	PARTICIPANT	\N	PRESENT	0
691634	690446	14223L	PARTICIPANT	\N	PRESENT	0
691740	691242	19693L	PARTICIPANT	\N	PRESENT	0
692263	692262	11045K	PARTICIPANT	\N	PRESENT	0
692264	690785	20074E	PARTICIPANT	\N	PRESENT	0
692265	690785	11041F	PARTICIPANT	\N	PRESENT	0
692266	690785	01062T	PARTICIPANT	\N	PRESENT	0
692267	690785	11064N	PARTICIPANT	\N	PRESENT	0
692268	690785	07033P	PARTICIPANT	\N	PRESENT	0
692269	690785	01024M	PARTICIPANT	\N	PRESENT	0
692270	690785	20042V	PARTICIPANT	\N	PRESENT	0
692271	690785	14059S	PARTICIPANT	\N	PRESENT	0
692273	692272	14231L	PARTICIPANT	\N	PRESENT	0
692274	692272	14259Y	PARTICIPANT	\N	PRESENT	0
692275	692272	20110Q	PARTICIPANT	\N	PRESENT	0
692276	692272	14179A	PARTICIPANT	\N	PRESENT	0
692277	692272	19820Y	PARTICIPANT	\N	PRESENT	0
692278	692272	14229S	PARTICIPANT	\N	PRESENT	0
692280	692279	20098N	PARTICIPANT	\N	PRESENT	0
692281	692279	14331P	PRESIDENT	0	PRESENT	0
692282	692279	14026U	PARTICIPANT	\N	PRESENT	0
692283	692279	19701S	PARTICIPANT	\N	PRESENT	0
692284	692279	11083R	PARTICIPANT	\N	PRESENT	0
692285	692279	14001X	PARTICIPANT	\N	PRESENT	0
692286	692279	14189C	PARTICIPANT	\N	EXCUSE	0
692287	692279	04045F	PARTICIPANT	\N	EXCUSE	0
692289	692288	10015M	PARTICIPANT	\N	PRESENT	0
692290	692288	14187A	PARTICIPANT	\N	PRESENT	0
692326	692325	20054A	PARTICIPANT	\N	PRESENT	0
692327	692325	14207L	PARTICIPANT	\N	PRESENT	0
692328	692325	14033T	PARTICIPANT	\N	PRESENT	0
692330	692329	20112S	PARTICIPANT	\N	PRESENT	0
692331	692329	19643A	PARTICIPANT	\N	PRESENT	0
692332	692329	19735D	PARTICIPANT	\N	PRESENT	0
692336	692335	14213J	PARTICIPANT	\N	PRESENT	0
692337	692335	19367Y	PARTICIPANT	\N	PRESENT	0
692338	692335	11067R	PARTICIPANT	\N	PRESENT	0
692339	692335	14217N	PARTICIPANT	\N	PRESENT	0
692340	692335	14223L	PARTICIPANT	\N	PRESENT	0
692341	692335	19798U	PARTICIPANT	\N	PRESENT	0
692342	692335	04092N	PARTICIPANT	\N	PRESENT	0
692343	692335	19553Y	PARTICIPANT	\N	PRESENT	0
692344	692333	10006L	PARTICIPANT	\N	PRESENT	0
692345	692333	19553Y	PARTICIPANT	\N	PRESENT	0
692346	692333	18193Q	PARTICIPANT	\N	PRESENT	0
692347	692333	19697Q	PARTICIPANT	\N	PRESENT	0
692348	692333	11097X	PARTICIPANT	\N	PRESENT	0
692349	692333	04092N	PARTICIPANT	\N	PRESENT	0
692350	692333	14071N	PARTICIPANT	\N	PRESENT	0
692351	692334	10006L	PARTICIPANT	\N	PRESENT	0
692352	692334	18193Q	PARTICIPANT	\N	PRESENT	0
692353	692334	14071N	PARTICIPANT	\N	PRESENT	0
692354	692334	11097X	PARTICIPANT	\N	PRESENT	0
692355	692316	14331P	PARTICIPANT	\N	EXCUSE	0
692361	692356	14189C	PARTICIPANT	\N	PRESENT	0
692362	692356	19631V	PARTICIPANT	\N	PRESENT	0
692364	692356	20112S	PARTICIPANT	\N	PRESENT	0
692365	692356	20024T	PARTICIPANT	\N	PRESENT	0
692366	692356	19954N	PARTICIPANT	\N	PRESENT	0
692367	692356	19575F	PARTICIPANT	\N	PRESENT	0
692368	692356	20042V	PARTICIPANT	\N	PRESENT	0
692369	692356	20138D	PARTICIPANT	\N	PRESENT	0
692370	692356	14105F	PARTICIPANT	\N	PRESENT	0
692371	692356	19643A	PARTICIPANT	\N	PRESENT	0
692372	692356	19782L	PARTICIPANT	\N	PRESENT	0
692373	692356	19629C	PARTICIPANT	\N	PRESENT	0
692374	692356	08028W	PARTICIPANT	\N	PRESENT	0
692375	692356	19467C	PARTICIPANT	\N	PRESENT	0
692376	692356	19251M	PARTICIPANT	\N	PRESENT	0
692377	692356	20132W	PARTICIPANT	\N	PRESENT	0
692378	692356	17023S	PARTICIPANT	\N	PRESENT	0
692379	692356	20120S	PARTICIPANT	\N	PRESENT	0
692380	692356	19725B	PARTICIPANT	\N	PRESENT	0
692381	692356	19399H	PARTICIPANT	\N	PRESENT	0
692382	692356	14213J	PARTICIPANT	\N	PRESENT	0
692383	692356	20056C	PARTICIPANT	\N	PRESENT	0
692384	692356	14073Q	PARTICIPANT	\N	PRESENT	0
692385	692356	19723Y	PARTICIPANT	\N	PRESENT	0
692386	692356	19699S	PARTICIPANT	\N	PRESENT	0
692387	692356	08012N	PARTICIPANT	\N	PRESENT	0
692389	692356	14221J	PARTICIPANT	\N	PRESENT	0
692390	692356	14147R	PARTICIPANT	\N	PRESENT	0
692391	692356	20096L	PARTICIPANT	\N	PRESENT	0
692393	692356	14237S	PARTICIPANT	\N	PRESENT	0
692394	692356	19533U	PARTICIPANT	\N	PRESENT	0
692395	692356	17965H	PARTICIPANT	\N	PRESENT	0
692397	692356	19349W	PARTICIPANT	\N	PRESENT	0
692398	692356	11043H	PARTICIPANT	\N	PRESENT	0
692399	692356	20098N	PARTICIPANT	\N	PRESENT	0
692400	692356	20058E	PARTICIPANT	\N	PRESENT	0
692485	692316	19295A	PARTICIPANT	\N	PRESENT	1
692949	692456	20030R	PARTICIPANT	\N	EXCUSE	0
692950	692456	14357A	PARTICIPANT	\N	EXCUSE	0
694735	694085	19549D	PARTICIPANT	\N	PRESENT	0
694736	694085	20090E	PARTICIPANT	\N	PRESENT	0
694737	694085	18083K	PARTICIPANT	\N	PRESENT	0
694738	694085	19701S	PARTICIPANT	\N	PRESENT	0
694739	694085	20124W	PARTICIPANT	\N	PRESENT	0
694740	694085	14187A	PRESIDENT	0	PRESENT	0
694741	694085	17023S	PARTICIPANT	\N	PRESENT	0
694743	694085	19347U	PARTICIPANT	\N	PRESENT	0
694744	694085	20286Q	PARTICIPANT	\N	PRESENT	0
694745	694085	14221J	PARTICIPANT	\N	PRESENT	0
694746	694085	20018V	PARTICIPANT	\N	PRESENT	0
694747	694085	14257W	PARTICIPANT	\N	PRESENT	0
694748	694085	20298U	PARTICIPANT	\N	PRESENT	0
694749	694085	20062A	PARTICIPANT	\N	PRESENT	0
695211	695210	19503N	PARTICIPANT	\N	PRESENT	0
712105	708194	19719D	PARTICIPANT	\N	PRESENT	0
712106	708194	14042U	PARTICIPANT	\N	PRESENT	0
712107	708194	11097X	PARTICIPANT	\N	PRESENT	0
712108	708194	10006L	PARTICIPANT	\N	PRESENT	0
712110	708194	14207L	PARTICIPANT	\N	PRESENT	0
712111	708194	17779H	PARTICIPANT	\N	PRESENT	0
712112	708194	20252E	PARTICIPANT	\N	PRESENT	0
712113	708194	20026V	PARTICIPANT	\N	PRESENT	0
712114	708194	18193Q	PARTICIPANT	\N	PRESENT	0
712115	708194	20130U	PARTICIPANT	\N	PRESENT	0
712116	708194	20180F	PARTICIPANT	\N	PRESENT	0
712117	708194	19697Q	PARTICIPANT	\N	PRESENT	0
712118	708194	08028W	PARTICIPANT	\N	PRESENT	0
712119	708194	18083K	PARTICIPANT	\N	PRESENT	0
712120	708194	07033P	PARTICIPANT	\N	PRESENT	0
712121	708194	20090E	PARTICIPANT	\N	PRESENT	0
712122	708194	14059S	PARTICIPANT	\N	PRESENT	0
712123	708194	19657G	PARTICIPANT	\N	PRESENT	0
712124	708194	20264J	PARTICIPANT	\N	PRESENT	0
712125	708194	19527W	PARTICIPANT	\N	PRESENT	0
712126	708194	20084G	PARTICIPANT	\N	PRESENT	0
712127	708194	19643A	PARTICIPANT	\N	PRESENT	0
712128	708194	19693L	PARTICIPANT	\N	PRESENT	0
712129	708194	99004R	PARTICIPANT	\N	PRESENT	0
712130	708194	14069U	PARTICIPANT	\N	PRESENT	0
712131	708194	19782L	PARTICIPANT	\N	PRESENT	0
712132	708194	14259Y	PARTICIPANT	\N	PRESENT	0
712133	708194	14031R	PARTICIPANT	\N	PRESENT	0
712134	708194	14281W	PARTICIPANT	\N	PRESENT	0
712135	708194	14253S	PARTICIPANT	\N	PRESENT	0
712136	708194	20100N	PARTICIPANT	\N	PRESENT	0
712137	708194	14195A	PARTICIPANT	\N	PRESENT	0
712138	708194	14211G	PARTICIPANT	\N	PRESENT	0
712139	708194	20132W	PARTICIPANT	\N	PRESENT	0
712140	708194	14213J	PARTICIPANT	\N	PRESENT	0
712141	708194	14225N	PARTICIPANT	\N	PRESENT	0
712142	708194	11054L	PARTICIPANT	\N	PRESENT	0
712143	708194	11101A	PARTICIPANT	\N	PRESENT	0
712144	708194	19347U	PARTICIPANT	\N	PRESENT	0
712145	708194	14071N	PARTICIPANT	\N	PRESENT	0
712146	708194	17965H	PARTICIPANT	\N	PRESENT	0
712147	708194	11045K	PARTICIPANT	\N	PRESENT	0
712148	708194	19683J	PARTICIPANT	\N	PRESENT	0
712149	708194	19826F	PARTICIPANT	\N	PRESENT	0
712150	708194	19333N	PARTICIPANT	\N	PRESENT	0
712151	708194	11031D	PARTICIPANT	\N	PRESENT	0
712152	708194	20152B	PARTICIPANT	\N	PRESENT	0
712153	708194	11074Q	PARTICIPANT	\N	PRESENT	0
712154	708194	19593H	PARTICIPANT	\N	PRESENT	0
712155	708194	20054A	PARTICIPANT	\N	PRESENT	0
712156	708194	11067R	PARTICIPANT	\N	PRESENT	0
712157	708194	19703U	PARTICIPANT	\N	PRESENT	0
712158	708194	19349W	PARTICIPANT	\N	PRESENT	0
712159	708194	20104S	PARTICIPANT	\N	PRESENT	0
712160	708194	11053K	PARTICIPANT	\N	PRESENT	0
712161	708194	20042V	PARTICIPANT	\N	PRESENT	0
712162	708194	07004J	PARTICIPANT	\N	PRESENT	0
712163	708194	20098N	PARTICIPANT	\N	PRESENT	0
712164	708194	19569H	PARTICIPANT	\N	PRESENT	0
712168	708194	20038A	PARTICIPANT	\N	PRESENT	0
712166	708194	20062A	PARTICIPANT	\N	PRESENT	0
712167	708194	14215L	PARTICIPANT	\N	PRESENT	0
712169	708194	14217N	PARTICIPANT	\N	PRESENT	0
712170	708194	14038Y	PARTICIPANT	\N	PRESENT	0
712171	708194	97011G	PARTICIPANT	\N	PRESENT	0
712172	708194	19525U	PARTICIPANT	\N	PRESENT	0
712173	708194	04092N	PARTICIPANT	\N	PRESENT	0
712174	708194	19591F	PARTICIPANT	\N	PRESENT	0
712175	708194	08045X	PARTICIPANT	\N	PRESENT	0
712176	708194	20040T	PARTICIPANT	\N	PRESENT	0
712177	708194	20914V	PARTICIPANT	\N	PRESENT	0
712178	708194	19573D	PARTICIPANT	\N	PRESENT	0
712179	708194	19758L	PARTICIPANT	\N	PRESENT	0
712180	708194	19760E	PARTICIPANT	\N	PRESENT	0
712181	708194	19695N	PARTICIPANT	\N	PRESENT	0
712182	708194	20102Q	PARTICIPANT	\N	PRESENT	0
712183	708194	20046A	PARTICIPANT	\N	PRESENT	0
712184	708194	19691J	PARTICIPANT	\N	PRESENT	0
712185	708194	11090Q	PARTICIPANT	\N	PRESENT	0
712186	708194	19369B	PARTICIPANT	\N	PRESENT	0
712187	708194	19745F	PARTICIPANT	\N	PRESENT	0
712188	708194	14187A	PARTICIPANT	\N	PRESENT	0
712189	708194	14229S	PARTICIPANT	\N	PRESENT	0
712190	708194	20030R	PARTICIPANT	\N	PRESENT	0
712191	708194	11040E	PARTICIPANT	\N	PRESENT	0
712192	708194	14073Q	PARTICIPANT	\N	PRESENT	0
712194	708194	01048V	PARTICIPANT	\N	PRESENT	0
712195	708194	20078J	PARTICIPANT	\N	PRESENT	0
712196	708194	19479G	PARTICIPANT	\N	PRESENT	0
712197	708194	19515S	PARTICIPANT	\N	PRESENT	0
712199	708194	19545Y	PARTICIPANT	\N	PRESENT	0
712200	708194	20172F	PARTICIPANT	\N	PRESENT	0
712201	708194	19675J	PARTICIPANT	\N	PRESENT	0
712202	708194	14021P	PARTICIPANT	\N	PRESENT	0
712203	708194	20034V	PARTICIPANT	\N	PRESENT	0
712205	708194	12041X	PARTICIPANT	\N	PRESENT	0
712206	708194	19503N	PARTICIPANT	\N	PRESENT	0
712210	708194	14030Q	PARTICIPANT	\N	PRESENT	0
712208	708194	12016W	PARTICIPANT	\N	PRESENT	0
712209	708194	14053L	PARTICIPANT	\N	PRESENT	0
712211	708194	04035D	PARTICIPANT	\N	PRESENT	0
712212	708194	19717B	PARTICIPANT	\N	PRESENT	0
712213	708194	20112S	PARTICIPANT	\N	PRESENT	0
712214	708194	08060W	PARTICIPANT	\N	PRESENT	0
712215	708194	19699S	PARTICIPANT	\N	PRESENT	0
712216	708194	20060X	PARTICIPANT	\N	PRESENT	0
712218	708194	19866P	PARTICIPANT	\N	PRESENT	0
712220	708194	19549D	PARTICIPANT	\N	PRESENT	0
712221	708194	19489J	PARTICIPANT	\N	PRESENT	0
712222	708194	19741B	PARTICIPANT	\N	PRESENT	0
712223	708194	20044X	PARTICIPANT	\N	PRESENT	0
712224	708194	14147R	PARTICIPANT	\N	PRESENT	0
712225	708194	20110Q	PARTICIPANT	\N	PRESENT	0
712226	708194	19415P	PARTICIPANT	\N	PRESENT	0
712227	708194	08034U	PARTICIPANT	\N	PRESENT	0
712237	708194	14231L	PARTICIPANT	\N	PRESENT	0
712238	708194	11072N	PARTICIPANT	\N	PRESENT	0
712239	708194	05012A	PARTICIPANT	\N	PRESENT	0
712240	708194	11085T	PARTICIPANT	\N	PRESENT	0
712241	708194	14257W	PARTICIPANT	\N	PRESENT	0
712242	708194	07029T	PARTICIPANT	\N	PRESENT	0
712243	708194	19687N	PARTICIPANT	\N	PRESENT	0
712244	708194	17367Q	PARTICIPANT	\N	PRESENT	0
712251	708194	11027H	PARTICIPANT	\N	PRESENT	0
712252	708194	16685X	PARTICIPANT	\N	PRESENT	0
712253	708194	20028X	PARTICIPANT	\N	PRESENT	0
712254	708194	11012A	PARTICIPANT	\N	PRESENT	0
712255	708194	01034P	PARTICIPANT	\N	PRESENT	0
712256	708194	19611R	PARTICIPANT	\N	PRESENT	0
712257	708194	04033B	PARTICIPANT	\N	PRESENT	0
712258	708194	20092G	PARTICIPANT	\N	PRESENT	0
712260	708194	04057K	PARTICIPANT	\N	PRESENT	0
712263	708194	19413M	PARTICIPANT	\N	PRESENT	0
712264	708194	11065P	PARTICIPANT	\N	PRESENT	0
712265	708194	20150Y	PARTICIPANT	\N	PRESENT	0
712266	708194	11026G	PARTICIPANT	\N	PRESENT	0
712267	708194	12028B	PARTICIPANT	\N	PRESENT	0
712268	708194	14251Q	PARTICIPANT	\N	PRESENT	0
712269	708194	20134Y	PARTICIPANT	\N	PRESENT	0
712270	708194	20298U	PARTICIPANT	\N	PRESENT	0
712271	708194	19295A	PARTICIPANT	\N	PRESENT	0
712273	708194	20980G	PARTICIPANT	\N	PRESENT	0
712274	708194	04059M	PARTICIPANT	\N	PRESENT	0
712275	708194	04042C	PARTICIPANT	\N	PRESENT	0
712276	708194	19711U	PARTICIPANT	\N	PRESENT	0
712277	708194	20076G	PARTICIPANT	\N	PRESENT	0
712279	708194	20094J	PARTICIPANT	\N	PRESENT	0
716783	716560	19820Y	PARTICIPANT	\N	PRESENT	0
716784	716560	20094J	PARTICIPANT	\N	PRESENT	0
716815	716560	05012A	PARTICIPANT	\N	PRESENT	0
716829	716560	14229S	PARTICIPANT	\N	PRESENT	0
716845	716560	14169X	PARTICIPANT	\N	PRESENT	0
716857	716560	20128B	PARTICIPANT	\N	PRESENT	0
716977	716562	20094J	PARTICIPANT	\N	PRESENT	0
716978	716562	19768N	PARTICIPANT	\N	PRESENT	0
716979	716562	14169X	PARTICIPANT	\N	PRESENT	0
716980	716562	19820Y	PARTICIPANT	\N	PRESENT	0
716981	716562	05012A	PARTICIPANT	\N	PRESENT	0
716982	716562	20128B	PARTICIPANT	\N	PRESENT	0
717064	716562	20914V	PARTICIPANT	\N	PRESENT	0
717519	717516	19593H	PARTICIPANT	\N	PRESENT	1
717520	717516	14123H	PARTICIPANT	\N	PRESENT	1
717521	717517	14123H	PARTICIPANT	\N	PRESENT	1
717522	717517	19593H	PARTICIPANT	\N	PRESENT	1
717523	717518	14123H	PARTICIPANT	\N	PRESENT	1
717524	717518	19593H	PARTICIPANT	\N	PRESENT	1
717528	717527	11077T	PARTICIPANT	\N	PRESENT	0
717529	717527	14037X	PARTICIPANT	\N	PRESENT	0
717530	717527	19515S	PARTICIPANT	\N	PRESENT	0
717531	717527	14257W	PARTICIPANT	\N	PRESENT	0
717534	717533	11077T	PARTICIPANT	\N	PRESENT	0
717535	717533	14037X	PARTICIPANT	\N	PRESENT	0
717536	717533	19515S	PARTICIPANT	\N	PRESENT	0
717537	717533	14257W	PARTICIPANT	\N	PRESENT	0
717538	717532	11077T	PARTICIPANT	\N	PRESENT	0
717539	717532	19515S	PARTICIPANT	\N	PRESENT	0
717540	717532	14037X	PARTICIPANT	\N	PRESENT	0
717541	717532	14257W	PARTICIPANT	\N	PRESENT	0
717543	717542	11077T	PARTICIPANT	\N	PRESENT	0
717544	717542	14037X	PARTICIPANT	\N	PRESENT	0
717545	717542	19515S	PARTICIPANT	\N	PRESENT	0
717546	717542	14257W	PARTICIPANT	\N	PRESENT	0
717548	717547	11077T	PARTICIPANT	\N	PRESENT	0
717549	717547	14037X	PARTICIPANT	\N	PRESENT	0
717550	717547	19515S	PARTICIPANT	\N	PRESENT	0
717552	717551	14053L	PARTICIPANT	\N	PRESENT	0
725465	722810	20100N	PARTICIPANT	\N	PRESENT	0
717555	717554	14053L	PARTICIPANT	\N	PRESENT	0
717556	717554	19489J	PARTICIPANT	\N	PRESENT	0
717557	717554	11056N	PARTICIPANT	\N	PRESENT	0
717571	717570	14053L	PARTICIPANT	\N	PRESENT	0
717572	717570	19489J	PARTICIPANT	\N	PRESENT	0
725466	722810	14001X	PARTICIPANT	\N	PRESENT	0
725467	722810	19441R	PARTICIPANT	\N	PRESENT	0
725468	722810	14033T	PARTICIPANT	\N	PRESENT	0
725469	722810	14073Q	PARTICIPANT	\N	PRESENT	0
725470	722810	08034U	PARTICIPANT	\N	PRESENT	0
725471	722810	19701S	PARTICIPANT	\N	PRESENT	0
725472	722810	14237S	PARTICIPANT	\N	PRESENT	0
725473	722810	14169X	PARTICIPANT	\N	PRESENT	0
725474	722810	20286Q	PARTICIPANT	\N	PRESENT	0
725475	722810	14026U	PARTICIPANT	\N	PRESENT	0
725476	722810	11101A	PARTICIPANT	\N	PRESENT	0
725477	722810	14357A	PARTICIPANT	\N	PRESENT	0
725478	722810	19711U	PARTICIPANT	\N	PRESENT	0
729303	728206	12041X	PARTICIPANT	\N	PRESENT	0
729304	728206	19443T	PARTICIPANT	\N	PRESENT	0
729305	728206	19565D	PARTICIPANT	\N	PRESENT	0
729306	728206	01058X	PARTICIPANT	\N	PRESENT	0
729307	728206	16685X	PARTICIPANT	\N	PRESENT	0
729308	728206	11027H	PARTICIPANT	\N	PRESENT	0
729309	728206	11054L	PARTICIPANT	\N	PRESENT	0
729310	728206	11066Q	PARTICIPANT	\N	PRESENT	0
729311	728206	19669L	PARTICIPANT	\N	PRESENT	0
729312	728206	08056B	PARTICIPANT	\N	PRESENT	0
729313	728206	12028B	PARTICIPANT	\N	PRESENT	0
729314	728206	19709B	PARTICIPANT	\N	PRESENT	0
729315	728206	19347U	PARTICIPANT	\N	PRESENT	0
729316	728206	14193X	PARTICIPANT	\N	PRESENT	0
729317	728206	97011G	PARTICIPANT	\N	PRESENT	0
729318	728206	14249W	PARTICIPANT	\N	PRESENT	0
729319	728206	08047A	PARTICIPANT	\N	PRESENT	0
729320	728206	14097Y	PARTICIPANT	\N	PRESENT	0
729321	728206	14059S	PARTICIPANT	\N	PRESENT	0
729322	728206	04035D	PARTICIPANT	\N	PRESENT	0
729323	728206	14133K	PRESIDENT	0	PRESENT	0
729324	728206	01062T	PARTICIPANT	\N	PRESENT	0
729325	728206	11041F	PARTICIPANT	\N	PRESENT	0
729326	728206	20042V	PARTICIPANT	\N	PRESENT	0
729327	728206	01024M	PARTICIPANT	\N	PRESENT	0
729328	728206	14105F	PARTICIPANT	\N	PRESENT	0
729329	728206	20064C	PARTICIPANT	\N	PRESENT	0
729330	728206	98022P	PARTICIPANT	\N	PRESENT	0
729331	728206	14267Y	PARTICIPANT	\N	PRESENT	0
729332	728206	11083R	PARTICIPANT	\N	PRESENT	0
729333	728206	14211G	PARTICIPANT	\N	PRESENT	0
729334	728206	14255U	PARTICIPANT	\N	PRESENT	0
729335	728206	04042C	PRESIDENT	1	PRESENT	0
729336	728205	12041X	PARTICIPANT	\N	PRESENT	0
729337	728205	19443T	PARTICIPANT	\N	PRESENT	0
729338	728205	19565D	PARTICIPANT	\N	PRESENT	0
729339	728205	01058X	PARTICIPANT	\N	PRESENT	0
729340	728205	16685X	PARTICIPANT	\N	PRESENT	0
729341	728205	11027H	PARTICIPANT	\N	PRESENT	0
729342	728205	04042C	PRESIDENT	0	PRESENT	0
729343	728205	11054L	PARTICIPANT	\N	PRESENT	0
729344	728205	11066Q	PARTICIPANT	\N	PRESENT	0
729345	728205	19669L	PARTICIPANT	\N	PRESENT	0
729346	728205	08056B	PARTICIPANT	\N	PRESENT	0
729347	728205	12028B	PARTICIPANT	\N	PRESENT	0
729348	728205	19709B	PARTICIPANT	\N	PRESENT	0
729349	728205	19347U	PARTICIPANT	\N	PRESENT	0
729350	728205	14193X	PARTICIPANT	\N	PRESENT	0
729351	728205	97011G	PARTICIPANT	\N	PRESENT	0
729352	728205	14249W	PARTICIPANT	\N	PRESENT	0
729353	728205	08047A	PARTICIPANT	\N	PRESENT	0
729354	728205	14097Y	PARTICIPANT	\N	PRESENT	0
729355	728205	14059S	PARTICIPANT	\N	PRESENT	0
729356	728205	04035D	PARTICIPANT	\N	PRESENT	0
729357	728205	14133K	PRESIDENT	1	PRESENT	0
729358	728205	01062T	PARTICIPANT	\N	PRESENT	0
729359	728205	11041F	PARTICIPANT	\N	PRESENT	0
729360	728205	20042V	PARTICIPANT	\N	PRESENT	0
729361	728205	01024M	PARTICIPANT	\N	PRESENT	0
729362	728205	14105F	PARTICIPANT	\N	PRESENT	0
729363	728205	20064C	PARTICIPANT	\N	PRESENT	0
729364	728205	98022P	PARTICIPANT	\N	PRESENT	0
729365	728205	14267Y	PARTICIPANT	\N	PRESENT	0
729366	728205	11083R	PARTICIPANT	\N	PRESENT	0
729367	728205	14211G	PARTICIPANT	\N	PRESENT	0
729368	728205	14255U	PARTICIPANT	\N	PRESENT	0
729377	728206	11064N	PARTICIPANT	\N	PRESENT	0
730342	730341	19621T	PARTICIPANT	\N	PRESENT	0
730343	730341	14030Q	PARTICIPANT	\N	PRESENT	0
730346	730340	20124W	PARTICIPANT	\N	PRESENT	1
730345	730341	14109K	PARTICIPANT	\N	PRESENT	0
730347	730340	14109K	PARTICIPANT	\N	PRESENT	1
730351	730350	20152B	PARTICIPANT	\N	PRESENT	0
730368	730266	20124W	PARTICIPANT	\N	PRESENT	0
730458	728188	14331P	PRESIDENT	0	PRESENT	0
730459	728188	04070G	PARTICIPANT	\N	PRESENT	0
730460	728188	20094J	PARTICIPANT	\N	PRESENT	0
730461	728188	19593H	PARTICIPANT	\N	PRESENT	0
730462	728188	20104S	PARTICIPANT	\N	PRESENT	0
730463	728188	10015M	PARTICIPANT	\N	PRESENT	0
730464	728188	08034U	PARTICIPANT	\N	PRESENT	0
730465	728188	11083R	PARTICIPANT	\N	PRESENT	0
730466	728188	14026U	PARTICIPANT	\N	PRESENT	0
730468	728188	14089Y	PARTICIPANT	\N	PRESENT	0
730470	728188	17737W	PARTICIPANT	\N	PRESENT	0
730472	728139	14213J	PARTICIPANT	\N	EXCUSE	0
730473	728188	19701S	PARTICIPANT	\N	EXCUSE	0
730474	728188	04045F	PARTICIPANT	\N	EXCUSE	0
730475	728188	20100N	PARTICIPANT	\N	EXCUSE	0
730478	730476	19503N	PARTICIPANT	\N	PRESENT	0
730481	730479	19503N	PARTICIPANT	\N	PRESENT	0
730482	728140	14213J	PARTICIPANT	\N	EXCUSE	0
730808	730682	95063L	PARTICIPANT	\N	PRESENT	0
730813	730682	20060X	PARTICIPANT	\N	PRESENT	0
730814	730682	20040T	PARTICIPANT	\N	PRESENT	0
730815	730682	20120S	PARTICIPANT	\N	PRESENT	0
730816	730682	20086J	PARTICIPANT	\N	PRESENT	0
730817	730682	07033P	PARTICIPANT	\N	PRESENT	0
730818	730682	14111D	PARTICIPANT	\N	PRESENT	0
730819	730682	11027H	PARTICIPANT	\N	PRESENT	0
730820	730682	19685L	PARTICIPANT	\N	PRESENT	0
712413	708195	86034E	PARTICIPANT	\N	PRESENT	0
712414	708195	14042U	PARTICIPANT	\N	PRESENT	0
712415	708195	11097X	PARTICIPANT	\N	PRESENT	0
712416	708195	10006L	PARTICIPANT	\N	PRESENT	0
712417	708195	20092G	PARTICIPANT	\N	PRESENT	0
712418	708195	20130U	PARTICIPANT	\N	PRESENT	0
712419	708195	11045K	PARTICIPANT	\N	PRESENT	0
712420	708195	14229S	PARTICIPANT	\N	PRESENT	0
712421	708195	14195A	PARTICIPANT	\N	PRESENT	0
712422	708195	20076G	PARTICIPANT	\N	PRESENT	0
712423	708195	20042V	PARTICIPANT	\N	PRESENT	0
712424	708195	19745F	PARTICIPANT	\N	PRESENT	0
712425	708195	19479G	PARTICIPANT	\N	PRESENT	0
712426	708195	18083K	PARTICIPANT	\N	PRESENT	0
712427	708195	11033F	PARTICIPANT	\N	PRESENT	0
712428	708195	20152B	PARTICIPANT	\N	PRESENT	0
712429	708195	14213J	PARTICIPANT	\N	PRESENT	0
712430	708195	08028W	PARTICIPANT	\N	PRESENT	0
712431	708195	14207L	PARTICIPANT	\N	PRESENT	0
712432	708195	07033P	PARTICIPANT	\N	PRESENT	0
712433	708195	11080N	PARTICIPANT	\N	PRESENT	0
712434	708195	04057K	PARTICIPANT	\N	PRESENT	0
712435	708195	14257W	PARTICIPANT	\N	PRESENT	0
712436	708195	20060X	PARTICIPANT	\N	PRESENT	0
712437	708195	08060W	PARTICIPANT	\N	PRESENT	0
712438	708195	20134Y	PARTICIPANT	\N	PRESENT	0
712439	708195	20132W	PARTICIPANT	\N	PRESENT	0
712440	708195	14211G	PARTICIPANT	\N	PRESENT	0
712441	708195	12016W	PARTICIPANT	\N	PRESENT	0
712442	708195	17779H	PARTICIPANT	\N	PRESENT	0
712443	708195	19691J	PARTICIPANT	\N	PRESENT	0
712444	708195	14215L	PARTICIPANT	\N	PRESENT	0
712445	708195	20252E	PARTICIPANT	\N	PRESENT	0
712446	708195	19699S	PARTICIPANT	\N	PRESENT	0
712447	708195	19866P	PARTICIPANT	\N	PRESENT	0
712448	708195	14031R	PARTICIPANT	\N	PRESENT	0
712449	708195	19515S	PARTICIPANT	\N	PRESENT	0
712450	708195	19575F	PARTICIPANT	\N	PRESENT	0
712451	708195	14071N	PARTICIPANT	\N	PRESENT	0
712452	708195	19415P	PARTICIPANT	\N	PRESENT	0
712459	708195	20100N	PARTICIPANT	\N	PRESENT	0
712454	708195	20090E	PARTICIPANT	\N	PRESENT	0
712455	708195	14030Q	PARTICIPANT	\N	PRESENT	0
712456	708195	19569H	PARTICIPANT	\N	PRESENT	0
712457	708195	19703U	PARTICIPANT	\N	PRESENT	0
712458	708195	08034U	PARTICIPANT	\N	PRESENT	0
712460	708195	14187A	PARTICIPANT	\N	PRESENT	0
712461	708195	19711U	PARTICIPANT	\N	PRESENT	0
712462	708195	08045X	PARTICIPANT	\N	PRESENT	0
712463	708195	11054L	PARTICIPANT	\N	PRESENT	0
712464	708195	20040T	PARTICIPANT	\N	PRESENT	0
712465	708195	20044X	PARTICIPANT	\N	PRESENT	0
712466	708195	20046A	PARTICIPANT	\N	PRESENT	0
712467	708195	14217N	PARTICIPANT	\N	PRESENT	0
712468	708195	18193Q	PARTICIPANT	\N	PRESENT	0
712469	708195	19782L	PARTICIPANT	\N	PRESENT	0
712470	708195	14281W	PARTICIPANT	\N	PRESENT	0
712471	708195	20062A	PARTICIPANT	\N	PRESENT	0
712472	708195	20084G	PARTICIPANT	\N	PRESENT	0
712473	708195	19527W	PARTICIPANT	\N	PRESENT	0
712474	708195	11031D	PARTICIPANT	\N	PRESENT	0
712475	708195	19760E	PARTICIPANT	\N	PRESENT	0
712476	708195	19695N	PARTICIPANT	\N	PRESENT	0
712477	708195	20112S	PARTICIPANT	\N	PRESENT	0
712478	708195	19413M	PARTICIPANT	\N	PRESENT	0
712479	708195	19295A	PARTICIPANT	\N	PRESENT	0
712480	708195	19503N	PARTICIPANT	\N	PRESENT	0
712481	708195	17965H	PARTICIPANT	\N	PRESENT	0
712482	708195	19333N	PARTICIPANT	\N	PRESENT	0
712483	708195	14021P	PARTICIPANT	\N	PRESENT	0
712484	708195	19349W	PARTICIPANT	\N	PRESENT	0
712485	708195	19697Q	PARTICIPANT	\N	PRESENT	0
712486	708195	14038Y	PARTICIPANT	\N	PRESENT	0
712487	708195	19525U	PARTICIPANT	\N	PRESENT	0
712488	708195	19573D	PARTICIPANT	\N	PRESENT	0
712489	708195	11067R	PARTICIPANT	\N	PRESENT	0
712490	708195	14259Y	PARTICIPANT	\N	PRESENT	0
712491	708195	04059M	PARTICIPANT	\N	PRESENT	0
712492	708195	20034V	PARTICIPANT	\N	PRESENT	0
712493	708195	20914V	PARTICIPANT	\N	PRESENT	0
712494	708195	19347U	PARTICIPANT	\N	PRESENT	0
712495	708195	07029T	PARTICIPANT	\N	PRESENT	0
712496	708195	20110Q	PARTICIPANT	\N	PRESENT	0
712497	708195	20172F	PARTICIPANT	\N	PRESENT	0
712583	708195	95063L	PARTICIPANT	\N	PRESENT	0
712499	708195	12028B	PARTICIPANT	\N	PRESENT	0
712500	708195	11074Q	PARTICIPANT	\N	PRESENT	0
712501	708195	19826F	PARTICIPANT	\N	PRESENT	0
712502	708195	19549D	PARTICIPANT	\N	PRESENT	0
712503	708195	04085P	PARTICIPANT	\N	PRESENT	0
712504	708195	11090Q	PARTICIPANT	\N	PRESENT	0
712505	708195	05012A	PARTICIPANT	\N	PRESENT	0
712506	708195	14147R	PARTICIPANT	\N	PRESENT	0
712507	708195	11040E	PARTICIPANT	\N	PRESENT	0
712508	708195	19758L	PARTICIPANT	\N	PRESENT	0
712509	708195	11101A	PARTICIPANT	\N	PRESENT	0
712510	708195	19719D	PARTICIPANT	\N	PRESENT	0
712511	708195	11012A	PARTICIPANT	\N	PRESENT	0
712512	708195	97011G	PARTICIPANT	\N	PRESENT	0
712513	708195	19717B	PARTICIPANT	\N	PRESENT	0
712514	708195	04033B	PARTICIPANT	\N	PRESENT	0
712515	708195	17023S	PARTICIPANT	\N	PRESENT	0
712516	708195	14231L	PARTICIPANT	\N	PRESENT	0
712517	708195	20030R	PARTICIPANT	\N	PRESENT	0
712518	708195	01034P	PARTICIPANT	\N	PRESENT	0
712519	708195	19593H	PARTICIPANT	\N	PRESENT	0
712520	708195	19649G	PARTICIPANT	\N	PRESENT	0
712521	708195	20102Q	PARTICIPANT	\N	PRESENT	0
712522	708195	19591F	PARTICIPANT	\N	PRESENT	0
712523	708195	11065P	PARTICIPANT	\N	PRESENT	0
712524	708195	19369B	PARTICIPANT	\N	PRESENT	0
712525	708195	20098N	PARTICIPANT	\N	PRESENT	0
712526	708195	20104S	PARTICIPANT	\N	PRESENT	0
712527	708195	19687N	PARTICIPANT	\N	PRESENT	0
712528	708195	19657G	PARTICIPANT	\N	PRESENT	0
712529	708195	20026V	PARTICIPANT	\N	PRESENT	0
712530	708195	16685X	PARTICIPANT	\N	PRESENT	0
712531	708195	20094J	PARTICIPANT	\N	PRESENT	0
712532	708195	19489J	PARTICIPANT	\N	PRESENT	0
712533	708195	99004R	PARTICIPANT	\N	PRESENT	0
712534	708195	11027H	PARTICIPANT	\N	PRESENT	0
712535	708195	19693L	PARTICIPANT	\N	PRESENT	0
712536	708195	14073Q	PARTICIPANT	\N	PRESENT	0
712537	708195	14053L	PARTICIPANT	\N	PRESENT	0
712538	708195	14253S	PARTICIPANT	\N	PRESENT	0
712539	708195	20980G	PARTICIPANT	\N	PRESENT	0
712540	708195	20028X	PARTICIPANT	\N	PRESENT	0
712541	708195	11072N	PARTICIPANT	\N	PRESENT	0
712548	708195	20264J	PARTICIPANT	\N	PRESENT	0
712555	708195	20180F	PARTICIPANT	\N	PRESENT	0
712558	708195	20070A	PARTICIPANT	\N	PRESENT	0
712559	708195	20114U	PARTICIPANT	\N	PRESENT	0
712560	708195	14059S	PARTICIPANT	\N	PRESENT	0
712562	708195	19643A	PARTICIPANT	\N	PRESENT	0
712563	708195	20078J	PARTICIPANT	\N	PRESENT	0
712564	708195	19647E	PARTICIPANT	\N	PRESENT	0
712565	708195	19675J	PARTICIPANT	\N	PRESENT	0
712566	708195	20038A	PARTICIPANT	\N	PRESENT	0
712567	708195	20054A	PARTICIPANT	\N	PRESENT	0
712568	708195	04035D	PARTICIPANT	\N	PRESENT	0
712569	708195	17637T	PARTICIPANT	\N	PRESENT	0
712572	708195	01057W	PARTICIPANT	\N	PRESENT	0
712573	708195	20108W	PARTICIPANT	\N	PRESENT	0
712574	708195	19329S	PARTICIPANT	\N	PRESENT	0
712575	708195	19669L	PARTICIPANT	\N	PRESENT	0
712576	708195	04042C	PARTICIPANT	\N	PRESENT	0
712577	708195	17367Q	PARTICIPANT	\N	PRESENT	0
712582	708195	04092N	PARTICIPANT	\N	PRESENT	0
712579	708195	14037X	PARTICIPANT	\N	PRESENT	0
712580	708195	19543W	PARTICIPANT	\N	PRESENT	0
712586	708195	14026U	PARTICIPANT	\N	PRESENT	0
712598	708195	19611R	PARTICIPANT	\N	PRESENT	0
712599	708195	14251Q	PARTICIPANT	\N	PRESENT	0
712600	708195	08061X	PARTICIPANT	\N	PRESENT	0
712601	708195	08069G	PARTICIPANT	\N	PRESENT	0
712602	708195	20140W	PARTICIPANT	\N	PRESENT	0
730561	730530	14053L	PARTICIPANT	\N	PRESENT	0
730562	730530	19749K	PARTICIPANT	\N	PRESENT	0
730563	730530	19649G	PARTICIPANT	\N	PRESENT	0
730564	730531	14053L	PARTICIPANT	\N	PRESENT	0
730565	730531	19749K	PARTICIPANT	\N	PRESENT	0
730566	730531	19649G	PARTICIPANT	\N	PRESENT	0
730726	730725	14255U	PARTICIPANT	\N	PRESENT	0
730727	730725	04035D	PARTICIPANT	\N	PRESENT	0
730728	730725	86034E	PARTICIPANT	\N	PRESENT	0
730729	730725	99004R	PARTICIPANT	\N	PRESENT	0
730730	730725	04042C	PARTICIPANT	\N	PRESENT	0
730754	730753	14187A	PRESIDENT	0	PRESENT	0
730755	730753	19347U	PARTICIPANT	\N	PRESENT	0
730756	730753	14257W	PARTICIPANT	\N	PRESENT	0
730758	730753	20124W	PARTICIPANT	\N	PRESENT	0
730767	730753	20018V	PARTICIPANT	\N	PRESENT	0
730772	730753	19525U	PARTICIPANT	\N	PRESENT	0
730773	730560	20064C	PRESIDENT	0	PRESENT	0
730774	730560	14251Q	PARTICIPANT	\N	PRESENT	0
730775	730560	11083R	PARTICIPANT	\N	PRESENT	0
730776	730560	14030Q	PARTICIPANT	\N	PRESENT	0
730790	730753	19701S	PARTICIPANT	\N	EXCUSE	0
730796	729876	19741B	PRESIDENT	0	PRESENT	0
730797	729876	19866P	PARTICIPANT	\N	PRESENT	0
730802	729876	20080C	PARTICIPANT	\N	PRESENT	0
730803	729876	19631V	PARTICIPANT	\N	PRESENT	0
730938	730683	14195A	PARTICIPANT	\N	PRESENT	0
730939	730683	10006L	PARTICIPANT	\N	PRESENT	0
730940	730683	14253S	PARTICIPANT	\N	PRESENT	0
730941	730683	14033T	PARTICIPANT	\N	PRESENT	0
730942	730683	19533U	PARTICIPANT	\N	PRESENT	0
730943	730683	19747H	PARTICIPANT	\N	PRESENT	0
730944	730683	20062A	PARTICIPANT	\N	PRESENT	0
730945	730787	11048N	PARTICIPANT	\N	PRESENT	0
730946	730787	20080C	PARTICIPANT	\N	PRESENT	0
730947	730787	14225N	PRESIDENT	0	PRESENT	0
730948	730787	19647E	PARTICIPANT	\N	PRESENT	0
730949	730787	01057W	PARTICIPANT	\N	PRESENT	0
730950	730683	11056N	PARTICIPANT	\N	PRESENT	0
730951	730787	14327T	PARTICIPANT	\N	PRESENT	0
730952	730683	14111D	PARTICIPANT	\N	PRESENT	0
730953	730683	14089Y	PARTICIPANT	\N	PRESENT	0
730954	730683	19545Y	PARTICIPANT	\N	PRESENT	0
730955	730683	07004J	PARTICIPANT	\N	PRESENT	0
730956	730683	14215L	PARTICIPANT	\N	PRESENT	0
730957	730683	20114U	PARTICIPANT	\N	PRESENT	0
730958	730683	14069U	PARTICIPANT	\N	PRESENT	0
730959	730787	20070A	PARTICIPANT	\N	PRESENT	0
730960	730683	04047H	PARTICIPANT	\N	PRESENT	0
730961	730683	20054A	PARTICIPANT	\N	PRESENT	0
730979	730683	19549D	PARTICIPANT	\N	PRESENT	0
730963	730683	20022R	PARTICIPANT	\N	PRESENT	0
730964	730683	19507S	PARTICIPANT	\N	PRESENT	0
730966	730683	20034V	PARTICIPANT	\N	PRESENT	0
730967	730683	20098N	PARTICIPANT	\N	PRESENT	0
730968	730683	18083K	PARTICIPANT	\N	PRESENT	0
730969	730683	14249W	PARTICIPANT	\N	PRESENT	0
730970	730683	97011G	PARTICIPANT	\N	PRESENT	0
730971	730683	20036X	PARTICIPANT	\N	PRESENT	0
730972	730683	19782L	PARTICIPANT	\N	PRESENT	0
730973	730787	19349W	PARTICIPANT	\N	PRESENT	0
730974	730683	20056C	PARTICIPANT	\N	PRESENT	0
730975	730787	20252E	PARTICIPANT	\N	PRESENT	0
730976	730787	19741B	PARTICIPANT	\N	PRESENT	0
731320	729877	19866P	PARTICIPANT	\N	PRESENT	0
730978	730787	19671E	PARTICIPANT	\N	PRESENT	0
730980	730683	14231L	PARTICIPANT	\N	PRESENT	0
730986	730683	20142Y	PARTICIPANT	\N	PRESENT	0
730989	730683	20032T	PARTICIPANT	\N	PRESENT	0
730990	730787	08034U	PARTICIPANT	\N	PRESENT	0
730991	730787	11074Q	PARTICIPANT	\N	PRESENT	0
731321	729877	20084G	PARTICIPANT	\N	PRESENT	0
730993	730683	14205J	PARTICIPANT	\N	PRESENT	0
730994	730683	04045F	PARTICIPANT	\N	PRESENT	0
730998	730683	14259Y	PARTICIPANT	\N	PRESENT	0
731003	730683	20038A	PARTICIPANT	\N	PRESENT	0
731004	730683	19954N	PARTICIPANT	\N	PRESENT	0
731005	730683	19563B	PARTICIPANT	\N	PRESENT	0
731006	730683	19719D	PARTICIPANT	\N	PRESENT	0
731007	730683	11040E	PARTICIPANT	\N	PRESENT	0
731008	730683	11012A	PARTICIPANT	\N	PRESENT	0
731009	730683	08028W	PARTICIPANT	\N	PRESENT	0
731010	730683	20026V	PARTICIPANT	\N	PRESENT	0
731036	730683	19565D	PARTICIPANT	\N	PRESENT	0
731037	730683	12041X	PARTICIPANT	\N	PRESENT	0
731038	730683	11085T	PARTICIPANT	\N	PRESENT	0
731039	730683	14021P	PARTICIPANT	\N	PRESENT	0
731040	730683	17637T	PARTICIPANT	\N	PRESENT	0
731041	730683	07029T	PARTICIPANT	\N	PRESENT	0
731043	730683	20066E	PARTICIPANT	\N	PRESENT	0
731044	730683	20088L	PARTICIPANT	\N	PRESENT	0
731045	730787	20050V	PARTICIPANT	\N	EXCUSE	0
731046	730683	20248J	PARTICIPANT	\N	PRESENT	0
731047	730683	19663E	PARTICIPANT	\N	PRESENT	0
731048	730683	19703U	PARTICIPANT	\N	PRESENT	0
731049	730683	19367Y	PARTICIPANT	\N	PRESENT	0
731050	730683	08060W	PARTICIPANT	\N	PRESENT	0
731051	730683	05008E	PARTICIPANT	\N	PRESENT	0
731052	730683	19413M	PARTICIPANT	\N	PRESENT	0
731053	730683	20140W	PARTICIPANT	\N	PRESENT	0
731054	730683	01058X	PARTICIPANT	\N	PRESENT	0
731055	730683	20046A	PARTICIPANT	\N	PRESENT	0
731132	730684	11070L	PARTICIPANT	\N	PRESENT	0
731136	730684	20114U	PARTICIPANT	\N	PRESENT	0
731309	730642	14001X	PARTICIPANT	\N	EXCUSE	0
731319	729877	19741B	PRESIDENT	0	PRESENT	0
731322	729877	20108W	PARTICIPANT	\N	PRESENT	0
731323	729877	10015M	PARTICIPANT	\N	PRESENT	0
731571	730319	20056C	PARTICIPANT	\N	PRESENT	0
731572	730319	19593H	PARTICIPANT	\N	PRESENT	0
731573	730319	20180F	PARTICIPANT	\N	PRESENT	0
731574	730319	19611R	PRESIDENT	0	PRESENT	0
731575	730319	04059M	PARTICIPANT	\N	PRESENT	0
731576	730319	20142Y	PARTICIPANT	\N	PRESENT	0
731577	730319	01060R	PARTICIPANT	\N	PRESENT	0
731578	730319	11104D	PARTICIPANT	\N	PRESENT	0
731579	730319	20124W	PARTICIPANT	\N	PRESENT	0
731580	730319	19399H	PARTICIPANT	\N	PRESENT	0
731581	730319	20152B	PARTICIPANT	\N	PRESENT	0
731721	731720	19741B	PARTICIPANT	\N	PRESENT	0
718630	716725	14030Q	PARTICIPANT	\N	PRESENT	0
718631	716725	20152B	PARTICIPANT	\N	PRESENT	0
718632	716725	20058E	PARTICIPANT	\N	PRESENT	0
718633	716725	14109K	PARTICIPANT	\N	PRESENT	0
718634	716725	14229S	PARTICIPANT	\N	PRESENT	0
718635	716725	14123H	PARTICIPANT	\N	PRESENT	0
718641	718636	14030Q	PARTICIPANT	\N	PRESENT	0
718643	718636	14123H	PARTICIPANT	\N	PRESENT	0
718644	718636	20058E	PARTICIPANT	\N	PRESENT	0
718645	718636	14229S	PARTICIPANT	\N	PRESENT	0
718646	718636	14109K	PARTICIPANT	\N	PRESENT	0
718649	718647	14123H	PARTICIPANT	\N	PRESENT	0
718650	718647	20152B	PARTICIPANT	\N	PRESENT	0
718651	718647	19643A	PARTICIPANT	\N	PRESENT	0
718652	718647	14030Q	PARTICIPANT	\N	PRESENT	0
718653	718647	14229S	PARTICIPANT	\N	PRESENT	0
730761	730760	11053K	PARTICIPANT	\N	PRESENT	0
730763	730762	11053K	PARTICIPANT	\N	PRESENT	0
730765	730764	19711U	PARTICIPANT	\N	PRESENT	0
730768	730766	14225N	PARTICIPANT	\N	PRESENT	0
730778	730777	08011M	PARTICIPANT	\N	PRESENT	0
730780	730779	08010L	PARTICIPANT	\N	PRESENT	0
730782	730781	08010L	PARTICIPANT	\N	PRESENT	0
730784	730783	08010L	PARTICIPANT	\N	PRESENT	0
730786	730785	08010L	PARTICIPANT	\N	PRESENT	0
734155	734154	05008E	PARTICIPANT	\N	PRESENT	0
734156	734154	11053K	PARTICIPANT	\N	PRESENT	0
734157	734154	01028R	PARTICIPANT	\N	PRESENT	0
735000	732768	01043Q	PARTICIPANT	\N	PRESENT	0
735008	732768	20128B	PARTICIPANT	\N	PRESENT	0
735033	732768	20108W	PARTICIPANT	\N	PRESENT	0
735013	732768	20914V	PARTICIPANT	\N	PRESENT	0
735014	732768	19565D	PARTICIPANT	\N	PRESENT	0
735016	732768	11040E	PARTICIPANT	\N	PRESENT	0
735018	732768	12041X	PARTICIPANT	\N	PRESENT	0
735019	732768	20070A	PARTICIPANT	\N	PRESENT	0
735020	732768	14083S	PARTICIPANT	\N	PRESENT	0
735021	732768	17737W	PARTICIPANT	\N	PRESENT	0
735022	732768	01058X	PARTICIPANT	\N	PRESENT	0
735034	732768	20062A	PARTICIPANT	\N	PRESENT	0
735024	732768	14191V	PARTICIPANT	\N	PRESENT	0
735025	732768	12028B	PARTICIPANT	\N	PRESENT	0
735026	732768	11026G	PARTICIPANT	\N	PRESENT	0
735027	732768	19687N	PARTICIPANT	\N	PRESENT	0
735028	732768	20064C	PARTICIPANT	\N	PRESENT	0
735029	732768	11083R	PARTICIPANT	\N	PRESENT	0
735030	732768	95063L	PARTICIPANT	\N	PRESENT	0
735031	732768	19301E	PARTICIPANT	\N	PRESENT	0
735032	732768	07029T	PARTICIPANT	\N	PRESENT	0
735035	732768	20022R	PARTICIPANT	\N	PRESENT	0
735036	732768	19954N	PARTICIPANT	\N	PRESENT	0
735037	732768	10015M	PARTICIPANT	\N	PRESENT	0
735038	732768	08011M	PARTICIPANT	\N	PRESENT	0
735039	732768	19479G	PARTICIPANT	\N	PRESENT	0
735040	732768	97011G	PARTICIPANT	\N	PRESENT	0
735041	732770	01043Q	PARTICIPANT	\N	PRESENT	0
735042	732770	20128B	PARTICIPANT	\N	PRESENT	0
735043	732770	20914V	PARTICIPANT	\N	PRESENT	0
735044	732770	19565D	PARTICIPANT	\N	PRESENT	0
735045	732770	11040E	PARTICIPANT	\N	PRESENT	0
735046	732770	12041X	PARTICIPANT	\N	PRESENT	0
735047	732770	20070A	PARTICIPANT	\N	PRESENT	0
735048	732770	14083S	PARTICIPANT	\N	PRESENT	0
735049	732770	17737W	PARTICIPANT	\N	PRESENT	0
735050	732770	01058X	PARTICIPANT	\N	PRESENT	0
735051	732770	14191V	PARTICIPANT	\N	PRESENT	0
735052	732770	12028B	PARTICIPANT	\N	PRESENT	0
735053	732770	11026G	PARTICIPANT	\N	PRESENT	0
735054	732770	19687N	PARTICIPANT	\N	PRESENT	0
735055	732770	20064C	PARTICIPANT	\N	PRESENT	0
735056	732770	11083R	PARTICIPANT	\N	PRESENT	0
735057	732770	95063L	PARTICIPANT	\N	PRESENT	0
735058	732770	19301E	PARTICIPANT	\N	PRESENT	0
735059	732770	07029T	PARTICIPANT	\N	PRESENT	0
735060	732770	20108W	PARTICIPANT	\N	PRESENT	0
735061	732770	20062A	PARTICIPANT	\N	PRESENT	0
735062	732770	20022R	PARTICIPANT	\N	PRESENT	0
735063	732770	19954N	PARTICIPANT	\N	PRESENT	0
735064	732770	10015M	PARTICIPANT	\N	PRESENT	0
735065	732770	08011M	PARTICIPANT	\N	PRESENT	0
735066	732770	19479G	PARTICIPANT	\N	PRESENT	0
735067	732770	97011G	PARTICIPANT	\N	PRESENT	0
735068	732770	14109K	PARTICIPANT	\N	PRESENT	0
735069	732770	11012A	PARTICIPANT	\N	PRESENT	0
735070	732770	19681G	PARTICIPANT	\N	PRESENT	0
735071	732770	20032T	PARTICIPANT	\N	PRESENT	0
735084	732770	20126Y	PARTICIPANT	\N	PRESENT	0
735082	732770	11056N	PARTICIPANT	\N	PRESENT	0
735083	732770	20142Y	PARTICIPANT	\N	PRESENT	0
735095	732770	11048N	PARTICIPANT	\N	PRESENT	0
735105	732770	19441R	PARTICIPANT	\N	PRESENT	0
735106	732770	01057W	PARTICIPANT	\N	PRESENT	0
735107	732770	14069U	PARTICIPANT	\N	PRESENT	0
735108	732770	20100N	PARTICIPANT	\N	PRESENT	0
735110	732770	20098N	PARTICIPANT	\N	PRESENT	0
735111	732770	08061X	PARTICIPANT	\N	PRESENT	0
735112	732770	19553Y	PARTICIPANT	\N	PRESENT	0
735113	732770	01024M	PARTICIPANT	\N	PRESENT	0
735115	735114	20124W	PARTICIPANT	\N	PRESENT	0
735116	732770	11074Q	PARTICIPANT	\N	PRESENT	0
735117	732770	20042V	PARTICIPANT	\N	PRESENT	0
735118	732653	11054L	PARTICIPANT	\N	PRESENT	0
735119	732653	17023S	PARTICIPANT	\N	PRESENT	0
735125	732770	11110B	PARTICIPANT	\N	PRESENT	0
735126	732770	20080C	PARTICIPANT	\N	PRESENT	0
735127	732770	14055N	PARTICIPANT	\N	PRESENT	0
735129	732770	19719D	PARTICIPANT	\N	PRESENT	0
735130	732770	20050V	PARTICIPANT	\N	PRESENT	0
735131	732770	14053L	PARTICIPANT	\N	PRESENT	0
735132	732770	14147R	PARTICIPANT	\N	PRESENT	0
735133	732770	19347U	PARTICIPANT	\N	PRESENT	0
735134	732770	20038A	PARTICIPANT	\N	PRESENT	0
735135	732770	14193X	PARTICIPANT	\N	PRESENT	0
735136	732770	19747H	PARTICIPANT	\N	PRESENT	0
735137	732770	14121F	PARTICIPANT	\N	PRESENT	0
735139	732770	20066E	PARTICIPANT	\N	PRESENT	0
735140	732770	11097X	PARTICIPANT	\N	PRESENT	0
735141	732770	14217N	PARTICIPANT	\N	PRESENT	0
735142	732770	19533U	PARTICIPANT	\N	PRESENT	0
718628	718627	14097Y	PARTICIPANT	\N	PRESENT	0
718629	718627	14059S	PARTICIPANT	\N	PRESENT	0
735143	732770	14042U	PARTICIPANT	\N	PRESENT	0
735144	732770	20104S	PARTICIPANT	\N	PRESENT	0
735145	732770	20090E	PARTICIPANT	\N	PRESENT	0
735146	732770	14033T	PARTICIPANT	\N	PRESENT	0
735147	732770	11064N	PARTICIPANT	\N	PRESENT	0
735149	732770	14107H	PARTICIPANT	\N	PRESENT	0
735150	732770	14251Q	PARTICIPANT	\N	PRESENT	0
735151	732770	20124W	PARTICIPANT	\N	PRESENT	0
735152	732770	01048V	PARTICIPANT	\N	PRESENT	0
735153	732770	14231L	PARTICIPANT	\N	PRESENT	0
735154	732770	19369B	PARTICIPANT	\N	PRESENT	0
735155	732770	19711U	PARTICIPANT	\N	PRESENT	0
735156	732770	14073Q	PARTICIPANT	\N	PRESENT	0
735157	732770	04045F	PARTICIPANT	\N	PRESENT	0
735158	732770	19673G	PARTICIPANT	\N	PRESENT	0
735160	735159	19667J	PARTICIPANT	\N	PRESENT	0
735161	735159	19663E	PARTICIPANT	\N	PRESENT	0
735162	735159	20022R	PARTICIPANT	\N	PRESENT	0
719821	717743	20914V	PARTICIPANT	\N	PRESENT	0
719822	717743	19820Y	PARTICIPANT	\N	PRESENT	0
719823	717743	05012A	PARTICIPANT	\N	PRESENT	0
719831	717743	20094J	PARTICIPANT	\N	PRESENT	0
719860	717743	20070A	PARTICIPANT	\N	PRESENT	0
719861	717742	20094J	PARTICIPANT	\N	PRESENT	0
719862	717742	20914V	PARTICIPANT	\N	PRESENT	0
719863	717742	19820Y	PARTICIPANT	\N	PRESENT	0
719864	717742	05012A	PARTICIPANT	\N	PRESENT	0
719865	717742	20070A	PARTICIPANT	\N	PRESENT	0
720224	720223	14187A	PARTICIPANT	\N	PRESENT	0
720225	720223	20124W	PARTICIPANT	\N	PRESENT	0
720226	720223	19347U	PARTICIPANT	\N	PRESENT	0
721228	720199	20062A	PARTICIPANT	\N	PRESENT	0
721229	720199	04045F	PARTICIPANT	\N	EXCUSE	0
723262	723257	19695N	PARTICIPANT	\N	PRESENT	0
723263	723257	14187A	PARTICIPANT	\N	PRESENT	0
723343	723207	20124W	PARTICIPANT	\N	PRESENT	0
723433	722682	19673G	PARTICIPANT	\N	EXCUSE	0
730822	730682	19581D	PARTICIPANT	\N	PRESENT	0
730888	730574	20024T	PARTICIPANT	\N	PRESENT	0
730889	730574	20126Y	PARTICIPANT	\N	EXCUSE	0
730890	730574	11031D	PARTICIPANT	\N	PRESENT	0
730891	730574	19735D	PRESIDENT	0	PRESENT	0
730892	730574	17965H	PARTICIPANT	\N	PRESENT	0
730893	730574	14213J	PARTICIPANT	\N	PRESENT	0
730894	730574	04092N	PARTICIPANT	\N	PRESENT	0
730895	730574	14026U	PARTICIPANT	\N	PRESENT	0
730896	730574	19725B	PARTICIPANT	\N	PRESENT	0
731259	730684	19725B	PARTICIPANT	\N	PRESENT	0
731260	730684	17965H	PARTICIPANT	\N	PRESENT	0
731261	730684	01057W	PARTICIPANT	\N	PRESENT	0
731263	730684	19782L	PARTICIPANT	\N	PRESENT	0
731269	730684	11045K	PARTICIPANT	\N	PRESENT	0
731270	730684	01025N	PARTICIPANT	\N	PRESENT	0
731275	730684	14357A	PARTICIPANT	\N	PRESENT	0
731288	731266	20152B	PARTICIPANT	\N	PRESENT	1
731289	731266	19527W	PARTICIPANT	\N	PRESENT	1
731290	731262	04070G	PARTICIPANT	\N	PRESENT	0
731291	731262	20056C	PARTICIPANT	\N	PRESENT	0
731292	731262	20134Y	PARTICIPANT	\N	PRESENT	1
731294	731268	14030Q	PARTICIPANT	\N	PRESENT	0
731295	731268	19621T	PARTICIPANT	\N	PRESENT	0
731296	731268	14109K	PARTICIPANT	\N	PRESENT	0
731304	731256	20070A	PARTICIPANT	\N	PRESENT	0
731305	731256	19820Y	PARTICIPANT	\N	PRESENT	0
731306	731256	05012A	PARTICIPANT	\N	PRESENT	0
731308	731307	19820Y	PARTICIPANT	\N	PRESENT	0
731310	731307	05012A	PRESIDENT	0	PRESENT	0
731311	731307	14237S	PARTICIPANT	\N	PRESENT	0
731312	731307	19717B	PARTICIPANT	\N	PRESENT	0
731313	731307	20034V	PARTICIPANT	\N	PRESENT	0
731315	731307	14147R	PARTICIPANT	\N	PRESENT	0
731324	731307	20128B	PARTICIPANT	\N	PRESENT	0
731723	731720	04042C	PARTICIPANT	\N	PRESENT	0
731724	731720	19545Y	PARTICIPANT	\N	PRESENT	0
731725	731720	14357A	PARTICIPANT	\N	PRESENT	0
731726	731720	20248J	PARTICIPANT	\N	PRESENT	0
731728	731720	97011G	PARTICIPANT	\N	PRESENT	0
731729	731720	14179A	PARTICIPANT	\N	PRESENT	0
731731	731720	19333N	PARTICIPANT	\N	PRESENT	0
731733	731720	08034U	PARTICIPANT	\N	PRESENT	0
731735	731720	14147R	PARTICIPANT	\N	PRESENT	0
731736	731720	20062A	PARTICIPANT	\N	PRESENT	0
731737	731720	20064C	PARTICIPANT	\N	PRESENT	0
731738	731720	11041F	PARTICIPANT	\N	PRESENT	0
731739	731720	98022P	PARTICIPANT	\N	PRESENT	0
731740	731720	12028B	PARTICIPANT	\N	PRESENT	0
731915	730697	11097X	PARTICIPANT	\N	PRESENT	0
731916	730697	20130U	PARTICIPANT	\N	PRESENT	0
731917	730697	19760E	PARTICIPANT	\N	PRESENT	0
731918	730698	11097X	PARTICIPANT	\N	PRESENT	0
731919	730698	20130U	PARTICIPANT	\N	PRESENT	0
731925	730644	08018U	PARTICIPANT	\N	EXCUSE	0
731938	730645	11110B	PARTICIPANT	\N	PRESENT	0
731951	730645	20022R	PARTICIPANT	\N	PRESENT	0
731955	730645	14069U	PARTICIPANT	\N	PRESENT	0
731956	730645	17737W	PARTICIPANT	\N	PRESENT	0
731958	730645	04047H	PARTICIPANT	\N	PRESENT	0
731959	730645	14053L	PARTICIPANT	\N	PRESENT	0
731960	730645	14215L	PARTICIPANT	\N	PRESENT	0
731962	730645	20074E	PARTICIPANT	\N	PRESENT	0
731963	730645	19673G	PARTICIPANT	\N	PRESENT	0
731964	730645	19447X	PARTICIPANT	\N	PRESENT	0
731965	730686	86034E	PARTICIPANT	\N	PRESENT	0
731966	730645	19729F	PARTICIPANT	\N	PRESENT	0
731967	730645	20108W	PARTICIPANT	\N	PRESENT	0
731968	730645	19581D	PARTICIPANT	\N	PRESENT	0
731970	730645	14147R	PARTICIPANT	\N	PRESENT	0
731971	730645	10015M	PARTICIPANT	\N	PRESENT	0
731972	730645	20114U	PARTICIPANT	\N	PRESENT	0
731974	730645	14151M	PARTICIPANT	\N	PRESENT	0
731976	730645	19725B	PARTICIPANT	\N	PRESENT	0
731978	730645	14021P	PARTICIPANT	\N	PRESENT	0
731979	730645	19649G	PARTICIPANT	\N	PRESENT	0
731981	730645	11026G	PARTICIPANT	\N	PRESENT	0
731985	730645	01028R	PARTICIPANT	\N	PRESENT	0
731987	730645	14231L	PARTICIPANT	\N	PRESENT	0
731989	730645	14179A	PARTICIPANT	\N	PRESENT	0
731991	730645	11033F	PARTICIPANT	\N	PRESENT	0
731993	730645	11085T	PARTICIPANT	\N	PRESENT	0
731994	730645	05008E	PARTICIPANT	\N	PRESENT	0
731995	730645	04085P	PARTICIPANT	\N	PRESENT	0
731997	730645	19489J	PARTICIPANT	\N	PRESENT	0
731998	730646	04085P	PARTICIPANT	\N	PRESENT	0
731999	730646	05008E	PARTICIPANT	\N	PRESENT	0
732000	730646	19489J	PARTICIPANT	\N	PRESENT	0
732001	730646	11085T	PARTICIPANT	\N	PRESENT	0
732002	730646	08018U	PARTICIPANT	\N	EXCUSE	0
732005	730646	14189C	PARTICIPANT	\N	PRESENT	0
732007	730646	11110B	PARTICIPANT	\N	PRESENT	0
732009	730646	20172F	PARTICIPANT	\N	PRESENT	0
732010	730646	11064N	PARTICIPANT	\N	PRESENT	0
732011	730646	14331P	PARTICIPANT	\N	PRESENT	0
732012	730646	20082E	PARTICIPANT	\N	PRESENT	0
732019	730686	19511N	PARTICIPANT	\N	PRESENT	0
732020	730686	98022P	PARTICIPANT	\N	PRESENT	0
732021	730686	11027H	PARTICIPANT	\N	PRESENT	0
732022	730686	14030Q	PARTICIPANT	\N	PRESENT	0
732023	730686	14275Y	PARTICIPANT	\N	PRESENT	0
732024	730686	20090E	PARTICIPANT	\N	PRESENT	0
732025	730686	20068G	PARTICIPANT	\N	PRESENT	0
732026	730686	20054A	PARTICIPANT	\N	PRESENT	0
732027	730686	14223L	PARTICIPANT	\N	PRESENT	0
732028	730686	19621T	PARTICIPANT	\N	PRESENT	0
732029	730686	19866P	PARTICIPANT	\N	PRESENT	0
732030	730686	20248J	PARTICIPANT	\N	PRESENT	0
732031	730686	20024T	PARTICIPANT	\N	PRESENT	0
732032	730686	19691J	PARTICIPANT	\N	PRESENT	0
732033	730686	14021P	PARTICIPANT	\N	PRESENT	0
732034	730686	20298U	PARTICIPANT	\N	PRESENT	0
732035	730686	12028B	PARTICIPANT	\N	PRESENT	0
732036	730686	20032T	PARTICIPANT	\N	PRESENT	0
732037	730686	14221J	PARTICIPANT	\N	PRESENT	0
732038	730686	11104D	PARTICIPANT	\N	PRESENT	0
732039	730686	11056N	PARTICIPANT	\N	PRESENT	0
732040	730686	19719D	PARTICIPANT	\N	PRESENT	0
732041	730686	14195A	PARTICIPANT	\N	PRESENT	0
732042	730686	19479G	PARTICIPANT	\N	PRESENT	0
732043	730686	20102Q	PARTICIPANT	\N	PRESENT	0
732044	730686	11040E	PARTICIPANT	\N	PRESENT	0
732045	730686	19671E	PARTICIPANT	\N	PRESENT	0
732046	730686	19581D	PARTICIPANT	\N	PRESENT	0
732047	730686	20086J	PARTICIPANT	\N	PRESENT	0
732048	730686	20142Y	PARTICIPANT	\N	PRESENT	0
732049	730686	20028X	PARTICIPANT	\N	PRESENT	0
732050	730686	04047H	PARTICIPANT	\N	PRESENT	0
732051	730686	19399H	PARTICIPANT	\N	PRESENT	0
732052	731727	19691J	PARTICIPANT	\N	PRESENT	0
732053	731727	14281W	PARTICIPANT	\N	PRESENT	0
732061	730686	14121F	PARTICIPANT	\N	PRESENT	0
732070	730686	19760E	PARTICIPANT	\N	PRESENT	0
732071	730686	04085P	PARTICIPANT	\N	PRESENT	0
732072	730686	19758L	PARTICIPANT	\N	PRESENT	0
732073	730686	12041X	PARTICIPANT	\N	PRESENT	0
732074	730686	19593H	PARTICIPANT	\N	PRESENT	0
732075	730686	20046A	PARTICIPANT	\N	PRESENT	0
732076	730686	19687N	PARTICIPANT	\N	PRESENT	0
732077	730686	20914V	PARTICIPANT	\N	PRESENT	0
732078	730686	11065P	PARTICIPANT	\N	PRESENT	0
732079	730686	19693L	PARTICIPANT	\N	PRESENT	0
712699	708199	10006L	PARTICIPANT	\N	PRESENT	0
712700	708199	11097X	PARTICIPANT	\N	PRESENT	0
712701	708199	20130U	PARTICIPANT	\N	PRESENT	0
712702	708199	11067R	PARTICIPANT	\N	PRESENT	0
712750	708199	11065P	PARTICIPANT	\N	PRESENT	0
712704	708199	11045K	PARTICIPANT	\N	PRESENT	0
712705	708199	20090E	PARTICIPANT	\N	PRESENT	0
712706	708199	20062A	PARTICIPANT	\N	PRESENT	0
712707	708199	19347U	PARTICIPANT	\N	PRESENT	0
712708	708199	11031D	PARTICIPANT	\N	PRESENT	0
712709	708199	19569H	PARTICIPANT	\N	PRESENT	0
712710	708199	99004R	PARTICIPANT	\N	PRESENT	0
712711	708199	17779H	PARTICIPANT	\N	PRESENT	0
712712	708199	20134Y	PARTICIPANT	\N	PRESENT	0
712713	708199	20084G	PARTICIPANT	\N	PRESENT	0
712714	708199	12016W	PARTICIPANT	\N	PRESENT	0
712715	708199	19687N	PARTICIPANT	\N	PRESENT	0
712716	708199	12041X	PARTICIPANT	\N	PRESENT	0
712717	708199	19295A	PARTICIPANT	\N	PRESENT	0
712718	708199	20030R	PARTICIPANT	\N	PRESENT	0
712719	708199	20028X	PARTICIPANT	\N	PRESENT	0
712720	708199	14109K	PARTICIPANT	\N	PRESENT	0
712721	708199	14031R	PARTICIPANT	\N	PRESENT	0
712722	708199	18193Q	PARTICIPANT	\N	PRESENT	0
712723	708199	20044X	PARTICIPANT	\N	PRESENT	0
712724	708199	19717B	PARTICIPANT	\N	PRESENT	0
712725	708199	14207L	PARTICIPANT	\N	PRESENT	0
712726	708199	14253S	PARTICIPANT	\N	PRESENT	0
712727	708199	14281W	PARTICIPANT	\N	PRESENT	0
712728	708199	19657G	PARTICIPANT	\N	PRESENT	0
712729	708199	11072N	PARTICIPANT	\N	PRESENT	0
712730	708199	20034V	PARTICIPANT	\N	PRESENT	0
712731	708199	14030Q	PARTICIPANT	\N	PRESENT	0
712732	708199	19611R	PARTICIPANT	\N	PRESENT	0
712733	708199	19749K	PARTICIPANT	\N	PRESENT	0
712734	708199	14215L	PARTICIPANT	\N	PRESENT	0
712735	708199	19415P	PARTICIPANT	\N	PRESENT	0
712736	708199	19573D	PARTICIPANT	\N	PRESENT	0
712737	708199	14187A	PARTICIPANT	\N	PRESENT	0
712738	708199	19699S	PARTICIPANT	\N	PRESENT	0
712739	708199	20092G	PARTICIPANT	\N	PRESENT	0
712740	708199	20112S	PARTICIPANT	\N	PRESENT	0
712741	708199	20046A	PARTICIPANT	\N	PRESENT	0
712742	708199	20102Q	PARTICIPANT	\N	PRESENT	0
712747	708199	19760E	PARTICIPANT	\N	PRESENT	0
712744	708199	19593H	PARTICIPANT	\N	PRESENT	0
712745	708199	11077T	PARTICIPANT	\N	PRESENT	0
712746	708199	04085P	PARTICIPANT	\N	PRESENT	0
712748	708199	17965H	PARTICIPANT	\N	PRESENT	0
712749	708199	20914V	PARTICIPANT	\N	PRESENT	0
712751	708199	19782L	PARTICIPANT	\N	PRESENT	0
712752	708199	19413M	PARTICIPANT	\N	PRESENT	0
712753	708199	19649G	PARTICIPANT	\N	PRESENT	0
712754	708199	08045X	PARTICIPANT	\N	PRESENT	0
712755	708199	19647E	PARTICIPANT	\N	PRESENT	0
712756	708199	20124W	PARTICIPANT	\N	PRESENT	0
712757	708199	14059S	PARTICIPANT	\N	PRESENT	0
712758	708199	97011G	PARTICIPANT	\N	PRESENT	0
712759	708199	18083K	PARTICIPANT	\N	PRESENT	0
712760	708199	19711U	PARTICIPANT	\N	PRESENT	0
712761	708199	20098N	PARTICIPANT	\N	PRESENT	0
712762	708199	01057W	PARTICIPANT	\N	PRESENT	0
712763	708199	14259Y	PARTICIPANT	\N	PRESENT	0
712764	708199	20180F	PARTICIPANT	\N	PRESENT	0
712765	708199	17367Q	PARTICIPANT	\N	PRESENT	0
712766	708199	20076G	PARTICIPANT	\N	PRESENT	0
712767	708199	19575F	PARTICIPANT	\N	PRESENT	0
712768	708199	11090Q	PARTICIPANT	\N	PRESENT	0
712769	708199	08028W	PARTICIPANT	\N	PRESENT	0
712770	708199	14213J	PARTICIPANT	\N	PRESENT	0
712771	708199	20038A	PARTICIPANT	\N	PRESENT	0
712772	708199	08061X	PARTICIPANT	\N	PRESENT	0
712773	708199	19697Q	PARTICIPANT	\N	PRESENT	0
712774	708199	12028B	PARTICIPANT	\N	PRESENT	0
712775	708199	19709B	PARTICIPANT	\N	PRESENT	0
712776	708199	20110Q	PARTICIPANT	\N	PRESENT	0
712777	708199	20060X	PARTICIPANT	\N	PRESENT	0
712778	708199	14217N	PARTICIPANT	\N	PRESENT	0
712779	708199	20100N	PARTICIPANT	\N	PRESENT	0
712780	708199	20122U	PARTICIPANT	\N	PRESENT	0
712781	708199	19719D	PARTICIPANT	\N	PRESENT	0
712782	708199	19691J	PARTICIPANT	\N	PRESENT	0
712783	708199	20172F	PARTICIPANT	\N	PRESENT	0
712784	708199	07029T	PARTICIPANT	\N	PRESENT	0
712785	708199	20054A	PARTICIPANT	\N	PRESENT	0
712786	708199	20980G	PARTICIPANT	\N	PRESENT	0
712787	708199	19693L	PARTICIPANT	\N	PRESENT	0
712788	708199	20026V	PARTICIPANT	\N	PRESENT	0
712789	708199	08010L	PARTICIPANT	\N	PRESENT	0
712790	708199	04092N	PARTICIPANT	\N	PRESENT	0
712698	708199	14042U	PARTICIPANT	\N	PRESENT	0
712791	708199	20140W	PARTICIPANT	\N	PRESENT	0
712792	708199	14147R	PARTICIPANT	\N	PRESENT	0
712793	708199	14026U	PARTICIPANT	\N	PRESENT	0
712794	708199	20252E	PARTICIPANT	\N	PRESENT	0
712795	708199	19866P	PARTICIPANT	\N	PRESENT	0
712796	708199	19591F	PARTICIPANT	\N	PRESENT	0
712797	708199	19349W	PARTICIPANT	\N	PRESENT	0
712798	708199	14038Y	PARTICIPANT	\N	PRESENT	0
712799	708199	14257W	PARTICIPANT	\N	PRESENT	0
712800	708199	19479G	PARTICIPANT	\N	PRESENT	0
712801	708199	11040E	PARTICIPANT	\N	PRESENT	0
712802	708199	04047H	PARTICIPANT	\N	PRESENT	0
712803	708199	08069G	PARTICIPANT	\N	PRESENT	0
712804	708199	17637T	PARTICIPANT	\N	PRESENT	0
712805	708199	08018U	PARTICIPANT	\N	PRESENT	0
712806	708199	20094J	PARTICIPANT	\N	PRESENT	0
712807	708199	19489J	PARTICIPANT	\N	PRESENT	0
712808	708199	14021P	PARTICIPANT	\N	PRESENT	0
712809	708199	19527W	PARTICIPANT	\N	PRESENT	0
712810	708199	08034U	PARTICIPANT	\N	PRESENT	0
712811	708199	01028R	PARTICIPANT	\N	PRESENT	0
712812	708199	14255U	PARTICIPANT	\N	PRESENT	0
712813	708199	14211G	PARTICIPANT	\N	PRESENT	0
712814	708199	19713W	PARTICIPANT	\N	PRESENT	0
712815	708199	19703U	PARTICIPANT	\N	PRESENT	0
712816	708199	19553Y	PARTICIPANT	\N	PRESENT	0
714505	711835	14089Y	PARTICIPANT	\N	PRESENT	0
714506	711835	20286Q	PARTICIPANT	\N	PRESENT	0
714507	711835	14097Y	PARTICIPANT	\N	PRESENT	0
714508	711835	19711U	PARTICIPANT	\N	PRESENT	0
714509	711835	08034U	PARTICIPANT	\N	PRESENT	0
714510	711835	12016W	PARTICIPANT	\N	PRESENT	0
714511	711835	11026G	PARTICIPANT	\N	PRESENT	0
714512	711835	20098N	PARTICIPANT	\N	PRESENT	0
714513	711835	10015M	PARTICIPANT	\N	EXCUSE	0
714514	711835	14331P	PRESIDENT	0	PRESENT	0
714515	711835	14237S	PARTICIPANT	\N	PRESENT	0
714516	711835	14073Q	PARTICIPANT	\N	PRESENT	0
715376	715374	11066Q	PARTICIPANT	\N	PRESENT	0
715526	692638	20124W	PARTICIPANT	\N	PRESENT	0
716620	716619	14031R	PARTICIPANT	\N	PRESENT	0
716621	716619	20180F	PARTICIPANT	\N	PRESENT	0
716622	716619	20172F	PARTICIPANT	\N	PRESENT	0
716623	716619	14083S	PARTICIPANT	\N	PRESENT	0
716625	716619	19826F	PARTICIPANT	\N	PRESENT	0
716637	716525	19691J	PARTICIPANT	\N	PRESENT	0
716638	716525	14281W	PARTICIPANT	\N	PRESENT	0
716639	716525	11031D	PARTICIPANT	\N	PRESENT	0
716641	716640	05008E	PARTICIPANT	\N	PRESENT	0
716642	716640	11053K	PARTICIPANT	\N	PRESENT	0
716643	716640	01028R	PARTICIPANT	\N	PRESENT	0
717003	717002	20032T	PARTICIPANT	\N	PRESENT	0
717004	717002	20024T	PARTICIPANT	\N	PRESENT	0
717005	717002	19549D	PARTICIPANT	\N	PRESENT	0
717006	717002	17367Q	PARTICIPANT	\N	PRESENT	0
717007	717002	08060W	PARTICIPANT	\N	PRESENT	0
717008	717002	11101A	PARTICIPANT	\N	PRESENT	0
717009	717002	18083K	PARTICIPANT	\N	PRESENT	0
717010	717002	19701S	PARTICIPANT	\N	PRESENT	0
717011	717002	19525U	PARTICIPANT	\N	PRESENT	0
717012	717002	11065P	PARTICIPANT	\N	PRESENT	0
717013	717002	20140W	PARTICIPANT	\N	PRESENT	0
717014	717002	17229F	PARTICIPANT	\N	PRESENT	0
717015	717002	19659J	PARTICIPANT	\N	PRESENT	0
717016	717002	19251M	PARTICIPANT	\N	PRESENT	0
717017	717002	19577H	PARTICIPANT	\N	PRESENT	0
717018	717002	20038A	PARTICIPANT	\N	PRESENT	0
717019	717002	20100N	PARTICIPANT	\N	PRESENT	0
717020	717002	19599P	PARTICIPANT	\N	PRESENT	0
716566	716257	14147R	PARTICIPANT	\N	PRESENT	0
716568	716567	19711U	PARTICIPANT	\N	PRESENT	0
716569	716567	20050V	PARTICIPANT	\N	PRESENT	0
716570	713466	20090E	PARTICIPANT	\N	PRESENT	1
716571	713466	19691J	PARTICIPANT	\N	PRESENT	0
716572	715369	20090E	PARTICIPANT	\N	PRESENT	1
716573	715369	19691J	PARTICIPANT	\N	PRESENT	0
718778	718623	19593H	PARTICIPANT	\N	PRESENT	0
718779	718623	04070G	PARTICIPANT	\N	PRESENT	0
718780	718623	20064C	PRESIDENT	0	PRESENT	0
718781	718623	14251Q	PARTICIPANT	\N	PRESENT	0
718782	718623	14193X	PARTICIPANT	\N	PRESENT	0
718783	718623	11083R	PARTICIPANT	\N	PRESENT	0
718784	718623	20152B	PARTICIPANT	\N	PRESENT	0
718785	718623	14030Q	PARTICIPANT	\N	PRESENT	0
718786	718623	17737W	PARTICIPANT	\N	EXCUSE	0
718787	718623	14147R	PARTICIPANT	\N	EXCUSE	0
723210	723209	97011G	PARTICIPANT	\N	PRESENT	0
723212	723209	20024T	PARTICIPANT	\N	PRESENT	0
723213	723209	20252E	PARTICIPANT	\N	PRESENT	0
730827	730682	14229S	PARTICIPANT	\N	PRESENT	0
730828	730682	19719D	PARTICIPANT	\N	PRESENT	0
730829	730682	20118Y	PARTICIPANT	\N	PRESENT	0
730830	730682	19599P	PARTICIPANT	\N	PRESENT	0
730831	730682	17229F	PARTICIPANT	\N	PRESENT	0
730832	730682	20286Q	PARTICIPANT	\N	PRESENT	0
730833	730682	11054L	PARTICIPANT	\N	PRESENT	0
730834	730682	19525U	PARTICIPANT	\N	PRESENT	0
730835	730682	19621T	PARTICIPANT	\N	PRESENT	0
730836	730682	19760E	PARTICIPANT	\N	PRESENT	0
730837	730682	19569H	PARTICIPANT	\N	PRESENT	0
730840	730682	14053L	PARTICIPANT	\N	PRESENT	0
730841	730682	01028R	PARTICIPANT	\N	PRESENT	0
730842	730682	19251M	PARTICIPANT	\N	PRESENT	0
730843	730682	04070G	PARTICIPANT	\N	PRESENT	0
730844	730682	19691J	PARTICIPANT	\N	PRESENT	0
730845	730682	19758L	PARTICIPANT	\N	PRESENT	0
730846	730682	20106U	PARTICIPANT	\N	PRESENT	0
730847	730682	19515S	PARTICIPANT	\N	PRESENT	0
730848	730682	17737W	PARTICIPANT	\N	PRESENT	0
730849	730682	20054A	PARTICIPANT	\N	PRESENT	0
730858	730682	20062A	PARTICIPANT	\N	PRESENT	0
730859	730682	04057K	PARTICIPANT	\N	PRESENT	0
730860	730682	20070A	PARTICIPANT	\N	PRESENT	0
730861	730682	20056C	PARTICIPANT	\N	PRESENT	0
730824	730682	20122U	PARTICIPANT	\N	PRESENT	0
730825	730682	19335Q	PARTICIPANT	\N	PRESENT	0
730867	730682	14071N	PARTICIPANT	\N	PRESENT	0
730868	730682	20026V	PARTICIPANT	\N	PRESENT	0
730869	730682	01058X	PARTICIPANT	\N	PRESENT	0
730870	730682	19782L	PARTICIPANT	\N	PRESENT	0
730872	730682	14147R	PARTICIPANT	\N	PRESENT	0
730873	730682	10006L	PARTICIPANT	\N	PRESENT	0
730876	730682	19347U	PARTICIPANT	\N	PRESENT	0
730877	730682	20108W	PARTICIPANT	\N	PRESENT	0
730878	730682	14033T	PARTICIPANT	\N	PRESENT	0
730900	730641	04047H	PRESIDENT	0	PRESENT	0
730901	730641	14111D	PARTICIPANT	\N	PRESENT	0
730902	730641	14147R	PARTICIPANT	\N	PRESENT	0
730903	730641	14179A	PARTICIPANT	\N	PRESENT	0
730904	730641	14089Y	PARTICIPANT	\N	PRESENT	0
730905	730641	10015M	PARTICIPANT	\N	PRESENT	0
730906	730641	14069U	PARTICIPANT	\N	PRESENT	0
730886	730683	11070L	PARTICIPANT	\N	PRESENT	0
730898	730641	20074E	PARTICIPANT	\N	PRESENT	0
730899	730641	05008E	PARTICIPANT	\N	PRESENT	0
730907	730641	14215L	PARTICIPANT	\N	PRESENT	0
730908	730757	19515S	PARTICIPANT	\N	PRESENT	0
730909	730757	19782L	PARTICIPANT	\N	PRESENT	0
730910	730757	20092G	PARTICIPANT	\N	PRESENT	0
730911	730757	14357A	PARTICIPANT	\N	PRESENT	0
730912	730757	19441R	PARTICIPANT	\N	PRESENT	0
730913	730757	19413M	PARTICIPANT	\N	PRESENT	0
730914	730757	20082E	PARTICIPANT	\N	PRESENT	0
730915	730757	04045F	PARTICIPANT	\N	PRESENT	0
730916	730757	11099A	PARTICIPANT	\N	PRESENT	0
730917	730757	19705W	PARTICIPANT	\N	PRESENT	0
730918	730757	08015R	PARTICIPANT	\N	PRESENT	0
730919	730757	19575F	PARTICIPANT	\N	PRESENT	0
730920	730757	20018V	PARTICIPANT	\N	PRESENT	0
730921	730757	20028X	PARTICIPANT	\N	PRESENT	0
730922	730757	14329V	PARTICIPANT	\N	PRESENT	0
730923	730757	19467C	PARTICIPANT	\N	PRESENT	0
730924	730757	14187A	PARTICIPANT	\N	PRESENT	0
730925	730757	14033T	PARTICIPANT	\N	PRESENT	0
730926	730757	11090Q	PRESIDENT	0	PRESENT	0
730927	730757	20054A	PARTICIPANT	\N	PRESENT	0
730928	730757	20062A	PARTICIPANT	\N	PRESENT	0
730929	730757	19507S	PARTICIPANT	\N	PRESENT	0
730930	730757	20286Q	PARTICIPANT	\N	PRESENT	0
730931	730757	20298U	PARTICIPANT	\N	PRESENT	0
730932	730757	19747H	PARTICIPANT	\N	PRESENT	0
730933	730757	14257W	PARTICIPANT	\N	PRESENT	0
730934	730641	20022R	PARTICIPANT	\N	PRESENT	0
730936	730641	19729F	PARTICIPANT	\N	PRESENT	0
731012	731011	19741B	PRESIDENT	0	PRESENT	0
731013	731011	19866P	PARTICIPANT	\N	PRESENT	0
731014	730683	19599P	PARTICIPANT	\N	PRESENT	0
731015	730683	10015M	PARTICIPANT	\N	PRESENT	0
731016	730683	19713W	PARTICIPANT	\N	PRESENT	0
731017	730683	20980G	PARTICIPANT	\N	PRESENT	0
731018	730683	11115U	PARTICIPANT	\N	PRESENT	0
731019	730683	14031R	PARTICIPANT	\N	PRESENT	0
731020	730683	19515S	PARTICIPANT	\N	PRESENT	0
731021	730683	20040T	PARTICIPANT	\N	PRESENT	0
731022	730683	14223L	PARTICIPANT	\N	PRESENT	0
731023	730683	19673G	PARTICIPANT	\N	PRESENT	0
731024	730683	14257W	PARTICIPANT	\N	PRESENT	0
731025	730683	19695N	PARTICIPANT	\N	PRESENT	0
731026	730683	14237S	PARTICIPANT	\N	PRESENT	0
731027	730683	19333N	PARTICIPANT	\N	PRESENT	0
731028	730683	19683J	PARTICIPANT	\N	PRESENT	0
731029	730683	19383Y	PARTICIPANT	\N	PRESENT	0
731030	730683	19399H	PARTICIPANT	\N	PRESENT	0
731031	730683	19729F	PARTICIPANT	\N	PRESENT	0
731032	730683	20024T	PARTICIPANT	\N	PRESENT	0
731033	730683	14147R	PARTICIPANT	\N	PRESENT	0
731034	730683	14267Y	PARTICIPANT	\N	PRESENT	0
731035	730683	20044X	PARTICIPANT	\N	PRESENT	0
731139	730684	08061X	PARTICIPANT	\N	PRESENT	0
731140	730684	19413M	PARTICIPANT	\N	PRESENT	0
731141	730684	20088L	PARTICIPANT	\N	PRESENT	0
731142	730684	20028X	PARTICIPANT	\N	PRESENT	0
731143	730684	11056N	PARTICIPANT	\N	PRESENT	0
731144	730684	19695N	PARTICIPANT	\N	PRESENT	0
731145	730684	19525U	PARTICIPANT	\N	PRESENT	0
731146	730684	20092G	PARTICIPANT	\N	PRESENT	0
731147	730684	19719D	PARTICIPANT	\N	PRESENT	0
731148	730684	11012A	PARTICIPANT	\N	PRESENT	0
731149	730684	01058X	PARTICIPANT	\N	PRESENT	0
731150	730684	04057K	PARTICIPANT	\N	PRESENT	0
731151	730684	19563B	PARTICIPANT	\N	PRESENT	0
731152	730684	19713W	PARTICIPANT	\N	PRESENT	0
731153	730684	19369B	PARTICIPANT	\N	PRESENT	0
731154	730684	20036X	PARTICIPANT	\N	PRESENT	0
731155	730684	20040T	PARTICIPANT	\N	PRESENT	0
731137	730684	11090Q	PARTICIPANT	\N	PRESENT	0
731138	730684	04045F	PARTICIPANT	\N	PRESENT	0
731156	730684	11099A	PARTICIPANT	\N	PRESENT	0
731157	730684	14205J	PARTICIPANT	\N	PRESENT	0
731158	730684	14215L	PARTICIPANT	\N	PRESENT	0
731159	730684	20248J	PARTICIPANT	\N	PRESENT	0
731160	730684	19367Y	PARTICIPANT	\N	PRESENT	0
731161	730684	19629C	PARTICIPANT	\N	PRESENT	0
731163	730684	14069U	PARTICIPANT	\N	PRESENT	0
731164	730684	19415P	PARTICIPANT	\N	PRESENT	0
731165	730684	20062A	PARTICIPANT	\N	PRESENT	0
731166	730684	20022R	PARTICIPANT	\N	PRESENT	0
731167	730684	19762G	PARTICIPANT	\N	PRESENT	0
731168	730684	20032T	PARTICIPANT	\N	PRESENT	0
731169	730684	14257W	PARTICIPANT	\N	PRESENT	0
731170	730684	20024T	PARTICIPANT	\N	PRESENT	0
731171	730684	19729F	PARTICIPANT	\N	PRESENT	0
731172	730684	07029T	PARTICIPANT	\N	PRESENT	0
731173	730684	14033T	PARTICIPANT	\N	PRESENT	0
731174	730684	19507S	PARTICIPANT	\N	PRESENT	0
731175	730684	19663E	PARTICIPANT	\N	PRESENT	0
731176	730684	20980G	PARTICIPANT	\N	PRESENT	0
731177	730684	20144B	PARTICIPANT	\N	PRESENT	0
731178	730684	19467C	PARTICIPANT	\N	PRESENT	0
718819	718817	19503N	PARTICIPANT	\N	PRESENT	0
718821	718820	19525U	PARTICIPANT	\N	PRESENT	0
718822	718820	04035D	PARTICIPANT	\N	PRESENT	0
718823	718820	14030Q	PARTICIPANT	\N	PRESENT	0
718824	718820	11064N	PARTICIPANT	\N	PRESENT	0
720802	720743	19663E	PARTICIPANT	\N	PRESENT	0
725038	725037	14205J	PARTICIPANT	\N	PRESENT	0
725039	725037	20092G	PARTICIPANT	\N	PRESENT	0
725040	725037	19745F	PARTICIPANT	\N	PRESENT	0
725041	725037	11097X	PARTICIPANT	\N	PRESENT	0
725042	725037	20082E	PARTICIPANT	\N	PRESENT	0
725043	725037	14033T	PARTICIPANT	\N	PRESENT	0
725044	725037	16685X	PARTICIPANT	\N	PRESENT	0
725045	725037	20054A	PARTICIPANT	\N	PRESENT	0
727843	727842	14231L	PRESIDENT	0	PRESENT	0
727844	727842	01057W	PARTICIPANT	\N	PRESENT	0
727845	727842	19820Y	PARTICIPANT	\N	PRESENT	0
727846	727842	19333N	PARTICIPANT	\N	PRESENT	0
727847	727842	14215L	PARTICIPANT	\N	PRESENT	0
727848	727842	19758L	PARTICIPANT	\N	PRESENT	0
727849	727842	14281W	PARTICIPANT	\N	PRESENT	0
727850	727842	20084G	PARTICIPANT	\N	PRESENT	0
727851	727842	19782L	PARTICIPANT	\N	PRESENT	0
727852	727842	19717B	PARTICIPANT	\N	PRESENT	0
727854	727842	14151M	PARTICIPANT	\N	PRESENT	0
727855	727842	20090E	PARTICIPANT	\N	PRESENT	0
727905	727842	14257W	PARTICIPANT	\N	PRESENT	0
727906	727842	14327T	PARTICIPANT	\N	PRESENT	0
727908	727842	08010L	PARTICIPANT	\N	PRESENT	0
727909	727842	19735D	PARTICIPANT	\N	PRESENT	0
727910	727842	19619A	PARTICIPANT	\N	PRESENT	0
727911	727842	20080C	PARTICIPANT	\N	PRESENT	0
727913	727842	19866P	PARTICIPANT	\N	PRESENT	0
727915	727842	19741B	PARTICIPANT	\N	PRESENT	0
727929	727842	04045F	PARTICIPANT	\N	PRESENT	0
727935	727842	14033T	PARTICIPANT	\N	PRESENT	0
727951	727842	20022R	PARTICIPANT	\N	EXCUSE	0
727952	727842	19681G	PARTICIPANT	\N	EXCUSE	0
727953	727842	14217N	PARTICIPANT	\N	EXCUSE	0
727954	727842	19565D	PARTICIPANT	\N	EXCUSE	0
727955	727842	19447X	PARTICIPANT	\N	EXCUSE	0
727956	727842	19711U	PARTICIPANT	\N	EXCUSE	0
727957	727842	19826F	PARTICIPANT	\N	EXCUSE	0
727958	727842	19563B	PARTICIPANT	\N	EXCUSE	0
727959	727842	14071N	PARTICIPANT	\N	EXCUSE	0
727960	727842	20062A	PARTICIPANT	\N	EXCUSE	0
727961	727842	20058E	PARTICIPANT	\N	EXCUSE	0
729492	728187	11101A	PARTICIPANT	\N	PRESENT	0
729493	728187	14089Y	PARTICIPANT	\N	PRESENT	0
729494	728187	08034U	PARTICIPANT	\N	PRESENT	0
729495	728187	14237S	PARTICIPANT	\N	PRESENT	0
729496	728187	04035D	PARTICIPANT	\N	PRESENT	0
729497	728187	19701S	PARTICIPANT	\N	PRESENT	0
729498	728187	12016W	PARTICIPANT	\N	PRESENT	0
729499	728187	14331P	PRESIDENT	0	PRESENT	0
729500	728187	19717B	PARTICIPANT	\N	PRESENT	0
729501	728187	19577H	PARTICIPANT	\N	PRESENT	0
729502	728187	20034V	PARTICIPANT	\N	PRESENT	0
729503	728187	19715Y	PARTICIPANT	\N	PRESENT	1
729504	728187	11072N	PARTICIPANT	\N	PRESENT	0
729507	728187	17737W	PARTICIPANT	\N	EXCUSE	0
729508	728187	20094J	PARTICIPANT	\N	EXCUSE	0
729509	728187	20100N	PARTICIPANT	\N	EXCUSE	0
729512	728187	20148F	PARTICIPANT	\N	PRESENT	0
729513	728187	14147R	PARTICIPANT	\N	PRESENT	0
729570	728187	11026G	PARTICIPANT	\N	PRESENT	0
729576	728187	20098N	PARTICIPANT	\N	PRESENT	0
729577	728187	18083K	PARTICIPANT	\N	PRESENT	0
735195	732771	95063L	PARTICIPANT	\N	PRESENT	0
735196	732771	20080C	PARTICIPANT	\N	PRESENT	0
735197	732771	11040E	PARTICIPANT	\N	PRESENT	0
735198	732771	20050V	PARTICIPANT	\N	PRESENT	0
735199	732771	20914V	PARTICIPANT	\N	PRESENT	0
735200	732771	19719D	PARTICIPANT	\N	PRESENT	0
735201	732771	20090E	PARTICIPANT	\N	PRESENT	0
735202	732771	14193X	PARTICIPANT	\N	PRESENT	0
735193	732771	11070L	PARTICIPANT	\N	PRESENT	0
735194	732771	20070A	PARTICIPANT	\N	PRESENT	0
735203	732771	20062A	PARTICIPANT	\N	PRESENT	0
735204	732771	07029T	PARTICIPANT	\N	PRESENT	0
735205	732771	11048N	PARTICIPANT	\N	PRESENT	0
735206	732771	19479G	PARTICIPANT	\N	PRESENT	0
735207	732771	19301E	PARTICIPANT	\N	PRESENT	0
735208	732771	20038A	PARTICIPANT	\N	PRESENT	0
735209	732771	08011M	PARTICIPANT	\N	PRESENT	0
735210	732771	20100N	PARTICIPANT	\N	PRESENT	0
735211	732771	14073Q	PARTICIPANT	\N	PRESENT	0
735424	735423	19745F	PARTICIPANT	\N	PRESENT	0
735213	732771	14147R	PARTICIPANT	\N	PRESENT	0
735214	732771	14215L	PARTICIPANT	\N	PRESENT	0
735215	732771	04047H	PARTICIPANT	\N	PRESENT	0
735477	735476	20120S	PARTICIPANT	\N	PRESENT	0
735478	735476	20106U	PARTICIPANT	\N	PRESENT	0
735480	735479	20120S	PARTICIPANT	\N	PRESENT	0
735481	735479	20106U	PARTICIPANT	\N	PRESENT	0
735483	735482	20120S	PARTICIPANT	\N	PRESENT	0
735484	735482	20106U	PARTICIPANT	\N	PRESENT	0
735486	735485	20120S	PARTICIPANT	\N	PRESENT	0
735488	735487	20120S	PARTICIPANT	\N	PRESENT	0
735490	735489	20120S	PARTICIPANT	\N	PRESENT	0
735496	735495	20120S	PARTICIPANT	\N	PRESENT	0
735498	735497	20120S	PARTICIPANT	\N	PRESENT	0
735503	735501	14107H	PARTICIPANT	\N	PRESENT	0
735500	735497	14107H	PARTICIPANT	\N	PRESENT	0
735502	735501	20120S	PARTICIPANT	\N	PRESENT	0
735505	735504	20120S	PARTICIPANT	\N	PRESENT	0
735506	735504	14107H	PARTICIPANT	\N	PRESENT	0
735508	735507	20120S	PARTICIPANT	\N	PRESENT	0
735513	735512	19399H	PARTICIPANT	\N	PRESENT	0
735514	735512	20142Y	PARTICIPANT	\N	PRESENT	0
735515	735512	14229S	PARTICIPANT	\N	PRESENT	0
735517	735516	19399H	PARTICIPANT	\N	PRESENT	0
735518	735516	20142Y	PARTICIPANT	\N	PRESENT	0
735519	735516	14229S	PARTICIPANT	\N	PRESENT	0
735520	735516	08012N	PARTICIPANT	\N	PRESENT	0
735521	735516	20134Y	PARTICIPANT	\N	PRESENT	0
735523	735522	19399H	PARTICIPANT	\N	PRESENT	0
735524	735522	14229S	PARTICIPANT	\N	PRESENT	0
735525	735522	20134Y	PARTICIPANT	\N	PRESENT	0
735526	735522	20142Y	PARTICIPANT	\N	PRESENT	0
735528	735527	19399H	PARTICIPANT	\N	PRESENT	0
735529	735527	20142Y	PARTICIPANT	\N	PRESENT	0
735599	735597	19711U	PARTICIPANT	\N	PRESENT	0
735601	735600	19711U	PARTICIPANT	\N	PRESENT	0
735611	735610	14038Y	PARTICIPANT	\N	PRESENT	0
735612	735610	19768N	PARTICIPANT	\N	PRESENT	0
735613	735610	20034V	PARTICIPANT	\N	PRESENT	0
735614	735610	19515S	PARTICIPANT	\N	PRESENT	0
735615	735610	19441R	PARTICIPANT	\N	PRESENT	0
735616	735610	20144B	PARTICIPANT	\N	PRESENT	0
735617	735610	14033T	PARTICIPANT	\N	PRESENT	0
735618	735610	01025N	PARTICIPANT	\N	PRESENT	0
735619	735610	11090Q	PRESIDENT	0	PRESENT	0
735620	735610	04045F	PARTICIPANT	\N	PRESENT	0
735621	735610	20054A	PARTICIPANT	\N	PRESENT	0
735622	735610	19631V	PARTICIPANT	\N	PRESENT	0
735623	735610	19705W	PARTICIPANT	\N	PRESENT	0
735624	735610	14251Q	PARTICIPANT	\N	PRESENT	0
735625	735610	19575F	PARTICIPANT	\N	PRESENT	0
735626	735610	20298U	PARTICIPANT	\N	PRESENT	0
735627	735610	19369B	PARTICIPANT	\N	PRESENT	0
735628	735610	19747H	PARTICIPANT	\N	PRESENT	0
735629	735610	14257W	PARTICIPANT	\N	PRESENT	0
735630	735610	14037X	PARTICIPANT	\N	PRESENT	0
735631	735610	20028X	PARTICIPANT	\N	PRESENT	0
736282	735535	19739H	PARTICIPANT	\N	PRESENT	0
736283	735535	19563B	PARTICIPANT	\N	PRESENT	0
736284	735535	20054A	PARTICIPANT	\N	PRESENT	0
736285	735913	19647E	PARTICIPANT	\N	PRESENT	0
736286	735913	14189C	PARTICIPANT	\N	PRESENT	0
736287	735913	01057W	PARTICIPANT	\N	PRESENT	0
736288	735913	19741B	PARTICIPANT	\N	PRESENT	0
736289	735913	14121F	PARTICIPANT	\N	PRESENT	0
736290	735913	20914V	PARTICIPANT	\N	PRESENT	0
736291	735913	99004R	PARTICIPANT	\N	PRESENT	0
736292	735913	20126Y	PARTICIPANT	\N	PRESENT	0
736294	735535	20040T	PARTICIPANT	\N	PRESENT	0
736295	735913	20086J	PARTICIPANT	\N	PRESENT	0
736296	735913	19531S	PARTICIPANT	\N	PRESENT	0
718974	718924	14053L	PARTICIPANT	\N	PRESENT	0
718975	718924	19533U	PARTICIPANT	\N	PRESENT	1
718976	718924	20080C	PARTICIPANT	\N	PRESENT	0
718977	718924	19741B	PARTICIPANT	\N	PRESENT	0
718978	718924	08010L	PARTICIPANT	\N	PRESENT	0
718979	718924	19866P	PARTICIPANT	\N	PRESENT	0
718980	718924	20044X	PARTICIPANT	\N	PRESENT	0
718981	718924	19631V	PARTICIPANT	\N	PRESENT	1
718982	718924	20042V	PARTICIPANT	\N	EXCUSE	0
718983	718325	19713W	PARTICIPANT	\N	PRESENT	0
718984	718325	19782L	PARTICIPANT	\N	PRESENT	0
724430	723233	14225N	PARTICIPANT	\N	EXCUSE	0
724431	723233	19531S	PARTICIPANT	\N	EXCUSE	0
726721	725826	19631V	PARTICIPANT	\N	PRESENT	0
726722	725826	19515S	PARTICIPANT	\N	PRESENT	0
726723	725826	19707Y	PARTICIPANT	\N	PRESENT	0
726724	725826	19575F	PARTICIPANT	\N	PRESENT	0
726725	725826	20088L	PARTICIPANT	\N	PRESENT	0
726726	725826	19747H	PARTICIPANT	\N	PRESENT	0
726727	725826	19383Y	PARTICIPANT	\N	PRESENT	0
726728	725826	19782L	PARTICIPANT	\N	PRESENT	0
726729	725826	14207L	PARTICIPANT	\N	PRESENT	0
726730	725826	20104S	PARTICIPANT	\N	PRESENT	0
726731	725826	20060X	PARTICIPANT	\N	PRESENT	0
726732	725826	14329V	PARTICIPANT	\N	PRESENT	0
726733	725826	14038Y	PARTICIPANT	\N	PRESENT	0
726734	725826	08028W	PARTICIPANT	\N	PRESENT	0
726735	725826	20144B	PARTICIPANT	\N	PRESENT	0
726736	725826	19467C	PARTICIPANT	\N	PRESENT	0
726737	725826	14357A	PARTICIPANT	\N	PRESENT	0
726738	725826	19507S	PARTICIPANT	\N	PRESENT	0
726739	725826	14187A	PARTICIPANT	\N	PRESENT	0
726740	725826	01025N	PARTICIPANT	\N	PRESENT	0
726741	725826	20286Q	PARTICIPANT	\N	PRESENT	0
726742	725826	19695N	PARTICIPANT	\N	PRESENT	0
726743	725826	14033T	PARTICIPANT	\N	PRESENT	0
726744	725826	08015R	PARTICIPANT	\N	PRESENT	0
726745	725826	14037X	PARTICIPANT	\N	PRESENT	0
726746	725826	01043Q	PARTICIPANT	\N	PRESENT	0
726747	725826	11077T	PARTICIPANT	\N	PRESENT	0
726748	725826	14205J	PARTICIPANT	\N	PRESENT	0
726749	725826	19441R	PARTICIPANT	\N	PRESENT	0
726750	725826	19563B	PARTICIPANT	\N	PRESENT	0
726751	725826	20028X	PARTICIPANT	\N	PRESENT	0
726752	725826	20018V	PARTICIPANT	\N	PRESENT	0
726753	725826	19369B	PARTICIPANT	\N	PRESENT	0
726754	725826	14257W	PARTICIPANT	\N	PRESENT	0
726755	725826	19768N	PARTICIPANT	\N	PRESENT	0
726756	725826	19866P	PARTICIPANT	\N	PRESENT	0
726757	725826	20030R	PARTICIPANT	\N	PRESENT	0
726758	725826	11090Q	PRESIDENT	0	PRESENT	0
726759	725826	20298U	PARTICIPANT	\N	PRESENT	0
726760	725826	20082E	PARTICIPANT	\N	PRESENT	0
726761	725826	20054A	PARTICIPANT	\N	PRESENT	0
726762	725826	20092G	PARTICIPANT	\N	PRESENT	0
726763	725826	04045F	PARTICIPANT	\N	PRESENT	0
726764	725826	20062A	PARTICIPANT	\N	PRESENT	0
726765	725826	19413M	PARTICIPANT	\N	PRESENT	0
732080	730686	20100N	PARTICIPANT	\N	PRESENT	0
732081	730686	08011M	PARTICIPANT	\N	PRESENT	0
732082	730686	19575F	PARTICIPANT	\N	PRESENT	0
732083	730686	20036X	PARTICIPANT	\N	PRESENT	0
732084	730686	20130U	PARTICIPANT	\N	PRESENT	0
732085	730686	01058X	PARTICIPANT	\N	PRESENT	0
732086	730686	99004R	PARTICIPANT	\N	PRESENT	0
732087	730686	19782L	PARTICIPANT	\N	PRESENT	0
732088	730686	19525U	PARTICIPANT	\N	PRESENT	0
732334	732326	19367Y	PARTICIPANT	\N	PRESENT	0
732090	730686	20266L	PARTICIPANT	\N	PRESENT	0
732091	730686	20076G	PARTICIPANT	\N	PRESENT	0
732092	730686	20092G	PARTICIPANT	\N	PRESENT	0
732093	730686	14249W	PARTICIPANT	\N	PRESENT	0
732094	730686	08069G	PARTICIPANT	\N	PRESENT	0
732095	730686	04042C	PARTICIPANT	\N	PRESENT	0
732096	730686	20106U	PARTICIPANT	\N	PRESENT	0
732097	730686	19591F	PARTICIPANT	\N	PRESENT	0
732098	730686	17367Q	PARTICIPANT	\N	PRESENT	0
732099	730686	14037X	PARTICIPANT	\N	PRESENT	0
732100	730686	19643A	PARTICIPANT	\N	PRESENT	0
732101	730686	20128B	PARTICIPANT	\N	PRESENT	0
732102	730686	14169X	PARTICIPANT	\N	PRESENT	0
732103	730686	08061X	PARTICIPANT	\N	PRESENT	0
732104	730686	10015M	PARTICIPANT	\N	PRESENT	0
732105	730686	19349W	PARTICIPANT	\N	PRESENT	0
732106	730686	20150Y	PARTICIPANT	\N	PRESENT	0
732107	730686	19515S	PARTICIPANT	\N	PRESENT	0
732108	730686	04045F	PARTICIPANT	\N	PRESENT	0
732109	730686	19301E	PARTICIPANT	\N	PRESENT	0
732110	730686	11033F	PARTICIPANT	\N	PRESENT	0
732111	730686	19766L	PARTICIPANT	\N	PRESENT	0
732113	730686	11080N	PARTICIPANT	\N	PRESENT	0
732114	730686	19717B	PARTICIPANT	\N	PRESENT	0
732115	730686	20116W	PARTICIPANT	\N	PRESENT	0
732116	730686	05012A	PARTICIPANT	\N	PRESENT	0
732117	730686	14259Y	PARTICIPANT	\N	PRESENT	0
732118	730686	19629C	PARTICIPANT	\N	PRESENT	0
732119	730686	20098N	PARTICIPANT	\N	PRESENT	0
732120	730686	20132W	PARTICIPANT	\N	PRESENT	0
732121	730686	19553Y	PARTICIPANT	\N	PRESENT	0
732122	730686	20034V	PARTICIPANT	\N	PRESENT	0
732123	730686	19447X	PARTICIPANT	\N	PRESENT	0
732124	730686	11012A	PARTICIPANT	\N	PRESENT	0
732125	730686	19573D	PARTICIPANT	\N	PRESENT	0
732126	730686	19545Y	PARTICIPANT	\N	PRESENT	0
732127	730686	14355X	PARTICIPANT	\N	PRESENT	0
732128	730686	19467C	PARTICIPANT	\N	PRESENT	0
732129	730686	95063L	PARTICIPANT	\N	PRESENT	0
732130	730686	20058E	PARTICIPANT	\N	PRESENT	0
732131	730686	20038A	PARTICIPANT	\N	PRESENT	0
732336	732333	10006L	PARTICIPANT	\N	PRESENT	0
732133	730686	11064N	PARTICIPANT	\N	PRESENT	0
732134	730686	19673G	PARTICIPANT	\N	PRESENT	0
732135	730686	14031R	PARTICIPANT	\N	PRESENT	0
732136	730686	19667J	PARTICIPANT	\N	PRESENT	0
732137	730686	11083R	PARTICIPANT	\N	PRESENT	0
732138	730686	04057K	PARTICIPANT	\N	PRESENT	0
732335	732326	14213J	PARTICIPANT	\N	PRESENT	0
732337	732333	14071N	PARTICIPANT	\N	PRESENT	0
732338	732329	19760E	PARTICIPANT	\N	PRESENT	0
732339	732329	19415P	PARTICIPANT	\N	PRESENT	0
732340	732332	19415P	PARTICIPANT	\N	PRESENT	0
732341	732332	19591F	PARTICIPANT	\N	PRESENT	0
732342	732330	19415P	PARTICIPANT	\N	PRESENT	0
732661	732659	14225N	PRESIDENT	0	PRESENT	0
732662	732659	14189C	PARTICIPANT	\N	PRESENT	0
732663	732659	19741B	PARTICIPANT	\N	PRESENT	0
732665	732659	19667J	PARTICIPANT	\N	PRESENT	0
732666	732659	20116W	PARTICIPANT	\N	PRESENT	0
732667	732659	20086J	PARTICIPANT	\N	PRESENT	0
732668	732659	20914V	PARTICIPANT	\N	PRESENT	0
732669	732659	20080C	PARTICIPANT	\N	PRESENT	0
732670	732659	14083S	PARTICIPANT	\N	PRESENT	0
732671	732659	19545Y	PARTICIPANT	\N	PRESENT	0
732672	732659	20070A	PARTICIPANT	\N	PRESENT	0
732673	732659	11070L	PARTICIPANT	\N	PRESENT	0
732674	732659	14327T	PARTICIPANT	\N	PRESENT	0
732675	732659	04071H	PARTICIPANT	\N	PRESENT	0
732677	732659	11074Q	PARTICIPANT	\N	PRESENT	0
732678	732659	11110B	PARTICIPANT	\N	PRESENT	0
732679	732659	19647E	PARTICIPANT	\N	PRESENT	0
732680	732659	01057W	PARTICIPANT	\N	PRESENT	0
732681	732659	11048N	PARTICIPANT	\N	PRESENT	0
732682	732659	14121F	PARTICIPANT	\N	PRESENT	0
732683	732659	99004R	PARTICIPANT	\N	PRESENT	0
732684	732659	20126Y	PARTICIPANT	\N	PRESENT	0
732685	732659	07029T	PARTICIPANT	\N	PRESENT	0
732686	732659	19711U	PARTICIPANT	\N	PRESENT	0
732687	732659	08010L	PARTICIPANT	\N	PRESENT	0
732688	732659	08034U	PARTICIPANT	\N	PRESENT	0
732689	732659	08009T	PARTICIPANT	\N	PRESENT	0
732690	732659	20252E	PARTICIPANT	\N	PRESENT	0
732691	732659	19671E	PARTICIPANT	\N	PRESENT	0
732692	732659	19335Q	PARTICIPANT	\N	PRESENT	0
732693	732659	08011M	PARTICIPANT	\N	PRESENT	0
732694	732659	20050V	PARTICIPANT	\N	PRESENT	0
732695	732659	20036X	PARTICIPANT	\N	PRESENT	0
732696	732659	19349W	PARTICIPANT	\N	PRESENT	0
732697	732659	14331P	PARTICIPANT	\N	PRESENT	0
732698	732659	11012A	PARTICIPANT	\N	PRESENT	0
732699	732659	20150Y	PARTICIPANT	\N	PRESENT	0
732700	732659	20044X	PARTICIPANT	\N	PRESENT	0
717021	717002	20120S	PARTICIPANT	\N	PRESENT	0
717022	717002	19820Y	PARTICIPANT	\N	PRESENT	0
717023	717002	19387D	PARTICIPANT	\N	PRESENT	0
717024	717002	20068G	PARTICIPANT	\N	PRESENT	0
717025	717002	20106U	PARTICIPANT	\N	PRESENT	0
717026	717002	19685L	PARTICIPANT	\N	PRESENT	0
717027	717002	19333N	PARTICIPANT	\N	PRESENT	0
717028	717002	20102Q	PARTICIPANT	\N	PRESENT	0
717029	717002	14219Q	PRESIDENT	0	PRESENT	0
717030	717002	14031R	PARTICIPANT	\N	PRESENT	0
717031	717002	19826F	PARTICIPANT	\N	PRESENT	0
717032	717002	14221J	PARTICIPANT	\N	PRESENT	0
717033	717002	20096L	PARTICIPANT	\N	PRESENT	0
717034	717002	14237S	PARTICIPANT	\N	PRESENT	0
717035	717002	19745F	PARTICIPANT	\N	PRESENT	0
717036	717002	20118Y	PARTICIPANT	\N	PRESENT	0
717037	717002	05012A	PARTICIPANT	\N	PRESENT	0
717038	717002	19503N	PARTICIPANT	\N	PRESENT	0
717039	717002	19739H	PARTICIPANT	\N	PRESENT	0
717040	717002	19619A	PARTICIPANT	\N	PRESENT	0
717041	717002	20136B	PARTICIPANT	\N	PRESENT	0
717042	717002	20046A	PARTICIPANT	\N	PRESENT	0
717043	717002	20122U	PARTICIPANT	\N	PRESENT	0
717044	717002	19637C	PARTICIPANT	\N	EXCUSE	0
719483	718666	17737W	PARTICIPANT	\N	PRESENT	0
719484	718666	11101A	PARTICIPANT	\N	PRESENT	0
719485	718666	14357A	PARTICIPANT	\N	PRESENT	0
719486	718666	20100N	PARTICIPANT	\N	PRESENT	0
719487	718666	20286Q	PARTICIPANT	\N	PRESENT	0
719488	718666	11083R	PARTICIPANT	\N	PRESENT	0
719489	718666	14033T	PARTICIPANT	\N	PRESENT	0
719490	718666	11026G	PARTICIPANT	\N	PRESENT	0
719491	718666	19441R	PARTICIPANT	\N	PRESENT	0
719492	718666	14001X	PARTICIPANT	\N	PRESENT	0
719493	718666	14237S	PARTICIPANT	\N	PRESENT	0
719494	718666	14331P	PARTICIPANT	\N	PRESENT	0
719495	718666	10015M	PARTICIPANT	\N	PRESENT	0
719497	718666	19711U	PARTICIPANT	\N	PRESENT	0
719498	718666	19531S	PARTICIPANT	\N	PRESENT	0
719499	718666	20128B	PARTICIPANT	\N	PRESENT	0
719501	718666	04070G	PARTICIPANT	\N	PRESENT	0
719502	718666	19725B	PARTICIPANT	\N	PRESENT	0
719504	718666	14133K	PARTICIPANT	\N	PRESENT	0
722846	722845	14179A	PARTICIPANT	\N	PRESENT	0
724094	722794	20086J	PARTICIPANT	\N	PRESENT	0
724095	722794	19663E	PARTICIPANT	\N	PRESENT	0
724096	722794	20044X	PARTICIPANT	\N	PRESENT	0
724097	722794	20038A	PARTICIPANT	\N	PRESENT	0
724098	722794	19760E	PARTICIPANT	\N	PRESENT	0
724099	722794	19687N	PARTICIPANT	\N	PRESENT	0
724100	722794	11031D	PARTICIPANT	\N	PRESENT	0
724101	722794	19741B	PARTICIPANT	\N	PRESENT	0
724102	722794	19673G	PARTICIPANT	\N	PRESENT	0
724103	722794	19573D	PARTICIPANT	\N	PRESENT	0
724104	722794	20026V	PARTICIPANT	\N	PRESENT	0
724105	722794	20980G	PARTICIPANT	\N	PRESENT	0
724106	722794	19507S	PARTICIPANT	\N	PRESENT	0
724107	722794	20102Q	PARTICIPANT	\N	PRESENT	0
724108	722794	20096L	PARTICIPANT	\N	PRESENT	0
724109	722794	11010L	PARTICIPANT	\N	PRESENT	0
724110	722794	20046A	PARTICIPANT	\N	PRESENT	0
724111	722794	19593H	PARTICIPANT	\N	PRESENT	0
724112	722794	14031R	PARTICIPANT	\N	PRESENT	0
724113	722794	11077T	PARTICIPANT	\N	PRESENT	0
724114	722794	19695N	PARTICIPANT	\N	PRESENT	0
724115	722794	14033T	PARTICIPANT	\N	PRESENT	0
724116	722794	19667J	PARTICIPANT	\N	PRESENT	0
724117	722794	20112S	PARTICIPANT	\N	PRESENT	0
724118	722794	19565D	PARTICIPANT	\N	PRESENT	0
724119	722794	20056C	PARTICIPANT	\N	PRESENT	0
724120	722794	19399H	PARTICIPANT	\N	PRESENT	0
724121	722794	20110Q	PARTICIPANT	\N	PRESENT	0
724122	722794	19954N	PARTICIPANT	\N	PRESENT	0
724123	722794	20914V	PARTICIPANT	\N	PRESENT	0
724124	722794	20134Y	PARTICIPANT	\N	PRESENT	0
724125	722794	14253S	PARTICIPANT	\N	PRESENT	0
724126	722794	11065P	PARTICIPANT	\N	PRESENT	0
724127	722794	19515S	PARTICIPANT	\N	PRESENT	0
724128	722794	20092G	PARTICIPANT	\N	PRESENT	0
724129	722794	20130U	PARTICIPANT	\N	PRESENT	0
724130	722794	14191V	PARTICIPANT	\N	PRESENT	0
724131	722794	11080N	PARTICIPANT	\N	PRESENT	0
724132	722794	14259Y	PARTICIPANT	\N	PRESENT	0
724133	722794	08061X	PARTICIPANT	\N	PRESENT	0
724134	722794	11072N	PARTICIPANT	\N	PRESENT	0
724135	722794	01057W	PARTICIPANT	\N	PRESENT	0
724136	722794	95063L	PARTICIPANT	\N	PRESENT	0
724137	722794	20136B	PARTICIPANT	\N	PRESENT	0
724138	722794	19301E	PARTICIPANT	\N	PRESENT	0
724139	722794	08047A	PARTICIPANT	\N	PRESENT	0
724140	722794	20128B	PARTICIPANT	\N	PRESENT	0
724141	722794	20140W	PARTICIPANT	\N	PRESENT	0
724142	722794	11083R	PARTICIPANT	\N	PRESENT	0
724143	722794	14173T	PARTICIPANT	\N	PRESENT	0
724144	722794	19591F	PARTICIPANT	\N	PRESENT	0
724145	722794	20024T	PARTICIPANT	\N	PRESENT	0
724146	722794	19697Q	PARTICIPANT	\N	PRESENT	0
724147	722794	20148F	PARTICIPANT	\N	PRESENT	0
724148	722794	19782L	PARTICIPANT	\N	PRESENT	0
724149	722794	20108W	PARTICIPANT	\N	PRESENT	0
724150	722794	20142Y	PARTICIPANT	\N	PRESENT	0
724151	722794	19707Y	PARTICIPANT	\N	PRESENT	0
724152	722794	19705W	PARTICIPANT	\N	PRESENT	0
724153	722794	11033F	PARTICIPANT	\N	PRESENT	0
724154	722794	19768N	PARTICIPANT	\N	PRESENT	0
724155	722794	14055N	PARTICIPANT	\N	PRESENT	0
724156	722794	08015R	PARTICIPANT	\N	PRESENT	0
724157	722794	20116W	PARTICIPANT	\N	PRESENT	0
724158	722794	20138D	PARTICIPANT	\N	PRESENT	0
724159	722794	20172F	PARTICIPANT	\N	PRESENT	0
724160	722794	20132W	PARTICIPANT	\N	PRESENT	0
724161	722794	14147R	PARTICIPANT	\N	PRESENT	0
724162	722794	19387D	PARTICIPANT	\N	PRESENT	0
724163	722794	19553Y	PARTICIPANT	\N	PRESENT	0
724164	722794	14213J	PARTICIPANT	\N	PRESENT	0
724166	722794	20050V	PARTICIPANT	\N	PRESENT	0
724167	722794	08018U	PARTICIPANT	\N	PRESENT	0
724168	722794	14211G	PARTICIPANT	\N	PRESENT	0
724169	722794	19709B	PARTICIPANT	\N	PRESENT	0
724170	722794	17589D	PARTICIPANT	\N	PRESENT	0
724171	722794	20058E	PARTICIPANT	\N	PRESENT	0
724172	722794	20068G	PARTICIPANT	\N	PRESENT	0
724173	722794	17367Q	PARTICIPANT	\N	PRESENT	0
724174	722794	19643A	PARTICIPANT	\N	PRESENT	0
724176	722794	04071H	PARTICIPANT	\N	PRESENT	0
724177	722794	14169X	PARTICIPANT	\N	PRESENT	0
724180	722794	14221J	PARTICIPANT	\N	PRESENT	0
724181	722794	19679N	PARTICIPANT	\N	PRESENT	0
724182	722794	20078J	PARTICIPANT	\N	PRESENT	0
724183	722794	18083K	PARTICIPANT	\N	PRESENT	0
724184	722794	08069G	PARTICIPANT	\N	PRESENT	0
724185	722794	20150Y	PARTICIPANT	\N	PRESENT	0
724186	722794	08028W	PARTICIPANT	\N	PRESENT	0
724187	722794	11043H	PARTICIPANT	\N	PRESENT	0
724188	722794	04059M	PARTICIPANT	\N	PRESENT	0
724189	722794	19631V	PARTICIPANT	\N	PRESENT	0
724190	722794	11090Q	PARTICIPANT	\N	PRESENT	0
724191	722794	05012A	PARTICIPANT	\N	PRESENT	0
724192	722794	11064N	PARTICIPANT	\N	PRESENT	0
724193	722794	20022R	PARTICIPANT	\N	PRESENT	0
724194	722794	19549D	PARTICIPANT	\N	PRESENT	0
724195	722794	20032T	PARTICIPANT	\N	PRESENT	0
724196	722794	97011G	PARTICIPANT	\N	PRESENT	0
724198	722794	01028R	PARTICIPANT	\N	PRESENT	0
724199	722794	17779H	PARTICIPANT	\N	PRESENT	0
724200	722794	14357A	PARTICIPANT	\N	PRESENT	0
724201	722794	11074Q	PARTICIPANT	\N	PRESENT	0
724202	722794	20090E	PARTICIPANT	\N	PRESENT	0
724203	722794	19599P	PARTICIPANT	\N	PRESENT	0
724205	722794	17637T	PARTICIPANT	\N	PRESENT	0
724207	722794	20028X	PARTICIPANT	\N	PRESENT	0
724208	722794	20124W	PARTICIPANT	\N	PRESENT	0
724209	722794	20126Y	PARTICIPANT	\N	PRESENT	0
724210	722794	20054A	PARTICIPANT	\N	PRESENT	0
724211	722794	19683J	PARTICIPANT	\N	PRESENT	0
724212	722794	19647E	PARTICIPANT	\N	PRESENT	0
724213	722794	19581D	PARTICIPANT	\N	PRESENT	0
724214	722794	20152B	PARTICIPANT	\N	PRESENT	0
724215	722794	14229S	PARTICIPANT	\N	PRESENT	0
724216	722794	20020P	PARTICIPANT	\N	PRESENT	0
724219	722794	19762G	PARTICIPANT	\N	PRESENT	0
719336	718554	04047H	PRESIDENT	0	PRESENT	0
719337	718554	20074E	PARTICIPANT	\N	PRESENT	0
719338	718554	14147R	PARTICIPANT	\N	PRESENT	0
719339	718554	14053L	PARTICIPANT	\N	PRESENT	0
719340	718554	19749K	PARTICIPANT	\N	PRESENT	0
719342	718554	11072N	PARTICIPANT	\N	PRESENT	0
719343	718554	11056N	PARTICIPANT	\N	PRESENT	0
719344	718554	20114U	PARTICIPANT	\N	PRESENT	0
719348	718554	19729F	PARTICIPANT	\N	PRESENT	0
719349	718554	14215L	PARTICIPANT	\N	PRESENT	0
719350	718554	95063L	PARTICIPANT	\N	PRESENT	0
719806	719805	19954N	PARTICIPANT	\N	PRESENT	0
719807	719805	08010L	PARTICIPANT	\N	PRESENT	0
719808	719805	20074E	PARTICIPANT	\N	PRESENT	0
719809	719805	19503N	PARTICIPANT	\N	PRESENT	0
719810	719805	19709B	PARTICIPANT	\N	PRESENT	0
719812	719811	14259Y	PARTICIPANT	\N	PRESENT	0
719814	719813	17737W	PARTICIPANT	\N	PRESENT	0
719815	719813	20248J	PARTICIPANT	\N	PRESENT	0
719816	719813	14179A	PARTICIPANT	\N	PRESENT	0
719817	719813	19349W	PARTICIPANT	\N	PRESENT	0
721265	719054	19711U	PARTICIPANT	\N	PRESENT	0
721272	719054	20024T	PARTICIPANT	\N	PRESENT	0
721273	719054	20058E	PARTICIPANT	\N	PRESENT	0
721274	719054	14215L	PARTICIPANT	\N	PRESENT	0
721275	719054	19699S	PARTICIPANT	\N	PRESENT	0
725918	725810	14147R	PARTICIPANT	\N	EXCUSE	0
726619	726616	19569H	PARTICIPANT	\N	PRESENT	0
725942	725940	14173T	PARTICIPANT	\N	PRESENT	0
725944	725943	14173T	PARTICIPANT	\N	PRESENT	0
726620	726616	14042U	PARTICIPANT	\N	PRESENT	0
726621	726616	18193Q	PARTICIPANT	\N	PRESENT	0
726622	726618	14042U	PARTICIPANT	\N	PRESENT	0
726623	726618	19569H	PARTICIPANT	\N	PRESENT	0
726624	726618	18193Q	PARTICIPANT	\N	PRESENT	0
731179	730684	20098N	PARTICIPANT	\N	PRESENT	0
731180	730684	20038A	PARTICIPANT	\N	PRESENT	0
731181	730684	19515S	PARTICIPANT	\N	PRESENT	0
731182	730684	20076G	PARTICIPANT	\N	PRESENT	0
731183	730684	17637T	PARTICIPANT	\N	PRESENT	0
731184	730684	11085T	PARTICIPANT	\N	PRESENT	0
731185	730684	14223L	PARTICIPANT	\N	PRESENT	0
731186	730684	19703U	PARTICIPANT	\N	PRESENT	0
731187	730684	18083K	PARTICIPANT	\N	PRESENT	0
731188	730684	14071N	PARTICIPANT	\N	PRESENT	0
731189	730684	20140W	PARTICIPANT	\N	PRESENT	0
731190	730684	20026V	PARTICIPANT	\N	PRESENT	0
731191	730684	14259Y	PARTICIPANT	\N	PRESENT	0
731192	730684	20018V	PARTICIPANT	\N	PRESENT	0
731193	730684	19565D	PARTICIPANT	\N	PRESENT	0
731194	730684	20046A	PARTICIPANT	\N	PRESENT	0
731195	730684	19333N	PARTICIPANT	\N	PRESENT	0
731196	730684	19573D	PARTICIPANT	\N	PRESENT	0
731197	730684	19581D	PARTICIPANT	\N	PRESENT	0
731198	730684	20074E	PARTICIPANT	\N	PRESENT	0
731199	730684	08028W	PARTICIPANT	\N	PRESENT	0
731200	730684	05012A	PARTICIPANT	\N	PRESENT	0
731201	730684	14021P	PARTICIPANT	\N	PRESENT	0
731202	730684	19383Y	PARTICIPANT	\N	PRESENT	0
731203	730684	19447X	PARTICIPANT	\N	PRESENT	0
731204	730684	08060W	PARTICIPANT	\N	PRESENT	0
731205	730684	20142Y	PARTICIPANT	\N	PRESENT	0
731206	730684	20066E	PARTICIPANT	\N	PRESENT	0
731207	730684	20054A	PARTICIPANT	\N	PRESENT	0
731208	730684	19575F	PARTICIPANT	\N	PRESENT	0
731209	730684	19441R	PARTICIPANT	\N	PRESENT	0
731210	730787	14121F	PARTICIPANT	\N	PRESENT	0
731211	730787	20914V	PARTICIPANT	\N	PRESENT	0
731212	730684	19549D	PARTICIPANT	\N	PRESENT	0
731213	730684	19760E	PARTICIPANT	\N	PRESENT	0
731214	730684	19599P	PARTICIPANT	\N	PRESENT	0
731215	730684	20108W	PARTICIPANT	\N	PRESENT	0
731216	730684	19399H	PARTICIPANT	\N	PRESENT	0
731217	730684	14195A	PARTICIPANT	\N	PRESENT	0
731218	730684	97011G	PARTICIPANT	\N	PRESENT	0
731219	730684	04033B	PARTICIPANT	\N	PRESENT	0
731220	730684	19545Y	PARTICIPANT	\N	PRESENT	0
731221	730684	14111D	PARTICIPANT	\N	PRESENT	0
731730	730639	19367Y	PARTICIPANT	\N	PRESENT	0
731223	730684	14221J	PARTICIPANT	\N	PRESENT	0
731224	730787	14189C	PARTICIPANT	\N	PRESENT	0
731225	730787	19545Y	PARTICIPANT	\N	PRESENT	0
731226	730684	20082E	PARTICIPANT	\N	PRESENT	0
731227	730684	01024M	PARTICIPANT	\N	PRESENT	0
731230	730935	20090E	PARTICIPANT	\N	PRESENT	0
731231	730935	14187A	PRESIDENT	0	PRESENT	0
731232	730935	19347U	PARTICIPANT	\N	PRESENT	0
731233	730935	20018V	PARTICIPANT	\N	PRESENT	0
731234	730935	20124W	PARTICIPANT	\N	PRESENT	0
731235	730935	17023S	PARTICIPANT	\N	PRESENT	0
731236	730935	19701S	PARTICIPANT	\N	EXCUSE	0
731237	730684	19691J	PARTICIPANT	\N	PRESENT	0
731238	730684	20090E	PARTICIPANT	\N	PRESENT	0
731239	730684	14042U	PARTICIPANT	\N	PRESENT	0
731240	730684	14187A	PARTICIPANT	\N	PRESENT	0
731241	730684	20030R	PARTICIPANT	\N	PRESENT	0
731242	730684	19251M	PARTICIPANT	\N	PRESENT	0
731246	730684	14229S	PARTICIPANT	\N	PRESENT	0
731248	730684	14026U	PARTICIPANT	\N	PRESENT	0
731249	730684	20124W	PARTICIPANT	\N	PRESENT	0
731250	730684	08015R	PARTICIPANT	\N	PRESENT	0
731255	730684	01043Q	PARTICIPANT	\N	PRESENT	0
731257	730684	19798U	PARTICIPANT	\N	PRESENT	0
731722	731720	17737W	PARTICIPANT	\N	PRESENT	0
731732	730639	04057K	PARTICIPANT	\N	PRESENT	0
731734	730639	19713W	PARTICIPANT	\N	PRESENT	0
731794	730639	08045X	PARTICIPANT	\N	EXCUSE	0
731804	730639	14195A	PARTICIPANT	\N	PRESENT	0
731904	731903	14215L	PARTICIPANT	\N	PRESENT	0
731905	731902	20128B	PARTICIPANT	\N	PRESENT	0
731906	731902	14237S	PARTICIPANT	\N	PRESENT	0
731907	731902	20076G	PARTICIPANT	\N	PRESENT	0
731908	731902	19745F	PARTICIPANT	\N	PRESENT	0
731909	731902	20046A	PARTICIPANT	\N	PRESENT	0
731910	731902	20914V	PARTICIPANT	\N	PRESENT	0
731911	731902	05012A	PARTICIPANT	\N	PRESENT	0
731912	731902	19820Y	PRESIDENT	0	PRESENT	0
731920	730674	20042V	PARTICIPANT	\N	PRESENT	0
731921	730674	14255U	PARTICIPANT	\N	PRESENT	0
731922	730674	14105F	PARTICIPANT	\N	EXCUSE	0
731923	730674	04042C	PRESIDENT	0	PRESENT	0
731924	730674	12028B	PARTICIPANT	\N	PRESENT	0
731926	730674	14267Y	PARTICIPANT	\N	PRESENT	0
731927	730674	11027H	PARTICIPANT	\N	PRESENT	0
731928	730674	01024M	PARTICIPANT	\N	PRESENT	0
731929	731903	20114U	PARTICIPANT	\N	PRESENT	0
731930	730674	14249W	PARTICIPANT	\N	PRESENT	0
731931	730674	17023S	PARTICIPANT	\N	PRESENT	0
731932	730674	97011G	PARTICIPANT	\N	PRESENT	0
731933	730674	04035D	PARTICIPANT	\N	PRESENT	0
731934	730674	11083R	PARTICIPANT	\N	PRESENT	0
731935	730674	19347U	PARTICIPANT	\N	PRESENT	0
731936	730674	08056B	PARTICIPANT	\N	EXCUSE	0
731937	730674	14211G	PARTICIPANT	\N	EXCUSE	0
731939	730674	19565D	PARTICIPANT	\N	PRESENT	0
731940	730674	98022P	PARTICIPANT	\N	PRESENT	0
731941	730674	11064N	PARTICIPANT	\N	PRESENT	0
731942	730674	20072C	PARTICIPANT	\N	EXCUSE	0
731943	730674	08069G	PARTICIPANT	\N	PRESENT	0
731944	730674	14097Y	PARTICIPANT	\N	EXCUSE	0
731946	731945	14215L	PARTICIPANT	\N	PRESENT	0
731947	731945	20114U	PARTICIPANT	\N	PRESENT	0
731948	731945	95063L	PARTICIPANT	\N	PRESENT	0
731949	730674	12041X	PARTICIPANT	\N	PRESENT	0
731950	730674	19709B	PARTICIPANT	\N	EXCUSE	0
731952	730674	16685X	PARTICIPANT	\N	EXCUSE	0
731953	730674	14059S	PARTICIPANT	\N	EXCUSE	0
731954	730674	14191V	PARTICIPANT	\N	PRESENT	0
731957	730674	08061X	PARTICIPANT	\N	PRESENT	0
731961	730674	14193X	PARTICIPANT	\N	PRESENT	0
731969	730674	11054L	PARTICIPANT	\N	PRESENT	0
731973	730674	19421M	PARTICIPANT	\N	EXCUSE	0
731975	730674	01058X	PARTICIPANT	\N	PRESENT	0
731977	730674	19669L	PARTICIPANT	\N	PRESENT	0
731980	730674	01062T	PARTICIPANT	\N	PRESENT	0
731982	730674	20064C	PARTICIPANT	\N	PRESENT	0
731983	730674	11041F	PARTICIPANT	\N	PRESENT	0
731984	730674	11066Q	PARTICIPANT	\N	PRESENT	0
731986	730674	95041E	PARTICIPANT	\N	PRESENT	0
731988	730674	11080N	PARTICIPANT	\N	PRESENT	0
731990	730674	11115U	PARTICIPANT	\N	PRESENT	0
711847	708187	20024T	PARTICIPANT	\N	PRESENT	0
722368	720102	99004R	PARTICIPANT	\N	PRESENT	0
722417	720102	14215L	PARTICIPANT	\N	PRESENT	0
722418	720102	11056N	PARTICIPANT	\N	PRESENT	0
722419	720102	19758L	PARTICIPANT	\N	PRESENT	0
722420	720102	04085P	PARTICIPANT	\N	PRESENT	0
722421	720102	19760E	PARTICIPANT	\N	PRESENT	0
722422	720102	19695N	PARTICIPANT	\N	PRESENT	0
722442	720102	20098N	PARTICIPANT	\N	PRESENT	0
722424	720102	07004J	PARTICIPANT	\N	PRESENT	0
722425	720102	20040T	PARTICIPANT	\N	PRESENT	0
722426	720102	14231L	PARTICIPANT	\N	PRESENT	0
722427	720102	19629C	PARTICIPANT	\N	PRESENT	0
722428	720102	19681G	PARTICIPANT	\N	PRESENT	0
722429	720102	14037X	PARTICIPANT	\N	PRESENT	0
722430	720102	95063L	PARTICIPANT	\N	PRESENT	0
722431	720102	20114U	PARTICIPANT	\N	PRESENT	0
722437	720102	04047H	PARTICIPANT	\N	PRESENT	0
722433	720102	20110Q	PARTICIPANT	\N	PRESENT	0
722434	720102	20980G	PARTICIPANT	\N	PRESENT	0
722435	720102	20180F	PARTICIPANT	\N	PRESENT	0
722436	720102	20058E	PARTICIPANT	\N	PRESENT	0
722438	720102	19741B	PARTICIPANT	\N	PRESENT	0
722439	720102	14053L	PARTICIPANT	\N	PRESENT	0
722440	720102	19687N	PARTICIPANT	\N	PRESENT	0
722441	720102	20046A	PARTICIPANT	\N	PRESENT	0
722443	720102	10015M	PARTICIPANT	\N	PRESENT	0
722444	720102	04057K	PARTICIPANT	\N	PRESENT	0
722445	720102	14219Q	PARTICIPANT	\N	PRESENT	0
722446	720102	19691J	PARTICIPANT	\N	PRESENT	0
722447	720102	17023S	PARTICIPANT	\N	PRESENT	0
722448	720102	01057W	PARTICIPANT	\N	PRESENT	0
722449	720102	19693L	PARTICIPANT	\N	PRESENT	0
722450	720102	19798U	PARTICIPANT	\N	PRESENT	0
722451	720102	20060X	PARTICIPANT	\N	PRESENT	0
722452	720102	20082E	PARTICIPANT	\N	PRESENT	0
722453	720102	19747H	PARTICIPANT	\N	PRESENT	0
722454	720102	20066E	PARTICIPANT	\N	PRESENT	0
722455	720102	14071N	PARTICIPANT	\N	PRESENT	0
722456	720102	20128B	PARTICIPANT	\N	PRESENT	0
722460	720102	20116W	PARTICIPANT	\N	PRESENT	0
722461	720102	19657G	PARTICIPANT	\N	PRESENT	0
722462	720102	11048N	PARTICIPANT	\N	PRESENT	0
722463	720102	14083S	PARTICIPANT	\N	PRESENT	0
722464	720102	14281W	PARTICIPANT	\N	PRESENT	0
722465	720102	14259Y	PARTICIPANT	\N	PRESENT	0
722466	720102	19593H	PARTICIPANT	\N	PRESENT	0
722467	720102	08010L	PARTICIPANT	\N	PRESENT	0
722468	720102	20126Y	PARTICIPANT	\N	PRESENT	0
722472	720102	19551W	PARTICIPANT	\N	PRESENT	0
722478	720102	20266L	PARTICIPANT	\N	PRESENT	0
722479	720102	19719D	PARTICIPANT	\N	PRESENT	0
722516	720103	14215L	PARTICIPANT	\N	PRESENT	0
722517	720103	20128B	PARTICIPANT	\N	PRESENT	0
722518	720103	20266L	PARTICIPANT	\N	PRESENT	0
722519	720103	14281W	PARTICIPANT	\N	PRESENT	0
722520	720103	11056N	PARTICIPANT	\N	PRESENT	0
722521	720103	19687N	PARTICIPANT	\N	PRESENT	0
722522	720103	14071N	PARTICIPANT	\N	PRESENT	0
722523	720103	19760E	PARTICIPANT	\N	PRESENT	0
722524	720103	99004R	PARTICIPANT	\N	PRESENT	0
722525	720103	04057K	PARTICIPANT	\N	PRESENT	0
722526	720103	19758L	PARTICIPANT	\N	PRESENT	0
722527	720103	19695N	PARTICIPANT	\N	PRESENT	0
722528	720103	19593H	PARTICIPANT	\N	PRESENT	0
722529	720103	20046A	PARTICIPANT	\N	PRESENT	0
722530	720103	08010L	PARTICIPANT	\N	PRESENT	0
722531	720103	19551W	PARTICIPANT	\N	PRESENT	0
722532	720103	19515S	PARTICIPANT	\N	PRESENT	0
722533	720103	20116W	PARTICIPANT	\N	PRESENT	0
722534	720103	20130U	PARTICIPANT	\N	PRESENT	0
722545	720103	11045K	PARTICIPANT	\N	PRESENT	0
722548	720103	19681G	PARTICIPANT	\N	PRESENT	0
722549	720103	20090E	PARTICIPANT	\N	PRESENT	0
722557	722547	19691J	PARTICIPANT	\N	PRESENT	0
722558	722547	11056N	PARTICIPANT	\N	PRESENT	0
722588	722547	17965H	PARTICIPANT	\N	PRESENT	0
722560	722547	19760E	PARTICIPANT	\N	PRESENT	0
722561	722547	04057K	PARTICIPANT	\N	PRESENT	0
722562	722547	19758L	PARTICIPANT	\N	PRESENT	0
722563	722547	19593H	PARTICIPANT	\N	PRESENT	0
722564	722547	20046A	PARTICIPANT	\N	PRESENT	0
722565	722547	19515S	PARTICIPANT	\N	PRESENT	0
722566	722547	20116W	PARTICIPANT	\N	PRESENT	0
722567	722547	20130U	PARTICIPANT	\N	PRESENT	0
722568	722547	11045K	PARTICIPANT	\N	PRESENT	0
722514	720103	19691J	PARTICIPANT	\N	PRESENT	0
722515	720103	20040T	PARTICIPANT	\N	PRESENT	0
722569	722547	20090E	PARTICIPANT	\N	PRESENT	0
722570	722547	19687N	PARTICIPANT	\N	PRESENT	0
722571	722547	14281W	PARTICIPANT	\N	PRESENT	0
722572	722547	19657G	PARTICIPANT	\N	PRESENT	0
722573	722547	19695N	PARTICIPANT	\N	PRESENT	0
722574	722547	14231L	PARTICIPANT	\N	PRESENT	0
722575	722547	01048V	PARTICIPANT	\N	PRESENT	0
722576	722547	20128B	PARTICIPANT	\N	PRESENT	0
722577	722547	19747H	PARTICIPANT	\N	PRESENT	0
722578	722547	04085P	PARTICIPANT	\N	PRESENT	0
722580	722547	19681G	PARTICIPANT	\N	PRESENT	0
722586	722547	14071N	PARTICIPANT	\N	PRESENT	0
722587	722547	19441R	PARTICIPANT	\N	PRESENT	0
722600	722547	19551W	PARTICIPANT	\N	PRESENT	0
722601	722547	19631V	PARTICIPANT	\N	PRESENT	0
722602	722547	20098N	PARTICIPANT	\N	PRESENT	0
722603	722547	19693L	PARTICIPANT	\N	PRESENT	0
722604	722547	17023S	PARTICIPANT	\N	PRESENT	0
722606	722547	14257W	PARTICIPANT	\N	PRESENT	0
722638	720104	20116W	PARTICIPANT	\N	PRESENT	0
722639	720104	19711U	PARTICIPANT	\N	PRESENT	0
722640	720104	19545Y	PARTICIPANT	\N	PRESENT	0
722641	720104	20914V	PARTICIPANT	\N	PRESENT	0
722642	720104	19651A	PARTICIPANT	\N	PRESENT	0
722643	720104	12016W	PARTICIPANT	\N	PRESENT	0
722644	720104	19695N	PARTICIPANT	\N	PRESENT	0
722645	720104	14083S	PARTICIPANT	\N	PRESENT	0
722646	720104	11056N	PARTICIPANT	\N	PRESENT	0
722647	720104	20130U	PARTICIPANT	\N	PRESENT	0
722648	720104	19631V	PARTICIPANT	\N	PRESENT	0
722649	720104	14257W	PARTICIPANT	\N	PRESENT	0
722650	720104	19619A	PARTICIPANT	\N	PRESENT	0
722651	720104	14021P	PARTICIPANT	\N	PRESENT	0
722652	720104	99004R	PARTICIPANT	\N	PRESENT	0
722653	720104	19691J	PARTICIPANT	\N	PRESENT	0
722655	720104	17965H	PARTICIPANT	\N	PRESENT	0
722656	720104	01057W	PARTICIPANT	\N	PRESENT	0
722657	720104	20080C	PARTICIPANT	\N	PRESENT	0
722658	720104	20126Y	PARTICIPANT	\N	PRESENT	0
722659	720104	19441R	PARTICIPANT	\N	PRESENT	0
722660	720104	19693L	PARTICIPANT	\N	PRESENT	0
722664	720104	19649G	PARTICIPANT	\N	PRESENT	0
722665	720104	14231L	PARTICIPANT	\N	PRESENT	0
722666	720104	11048N	PARTICIPANT	\N	PRESENT	0
722667	720104	19489J	PARTICIPANT	\N	PRESENT	0
722668	720104	14225N	PARTICIPANT	\N	PRESENT	0
722636	720104	11045K	PARTICIPANT	\N	PRESENT	0
722637	720104	01048V	PARTICIPANT	\N	PRESENT	0
722670	720104	19866P	PARTICIPANT	\N	PRESENT	0
722671	720104	17023S	PARTICIPANT	\N	PRESENT	0
722672	720104	08010L	PARTICIPANT	\N	PRESENT	0
722673	720104	19647E	PARTICIPANT	\N	PRESENT	0
722677	720104	14215L	PARTICIPANT	\N	PRESENT	0
722678	720104	20060X	PARTICIPANT	\N	PRESENT	0
722679	720104	14001X	PARTICIPANT	\N	PRESENT	0
722680	720104	17779H	PARTICIPANT	\N	PRESENT	0
722681	720104	19741B	PARTICIPANT	\N	PRESENT	0
722683	720104	20110Q	PARTICIPANT	\N	PRESENT	0
722684	720104	01028R	PARTICIPANT	\N	PRESENT	0
722705	720105	11045K	PARTICIPANT	\N	PRESENT	0
722709	720105	19545Y	PARTICIPANT	\N	PRESENT	0
722711	720105	19651A	PARTICIPANT	\N	PRESENT	0
722712	720105	12016W	PARTICIPANT	\N	PRESENT	0
722715	720105	11056N	PARTICIPANT	\N	PRESENT	0
722716	720105	19631V	PARTICIPANT	\N	PRESENT	0
718693	718691	01057W	PARTICIPANT	\N	PRESENT	0
718694	718691	19489J	PARTICIPANT	\N	PRESENT	0
718707	718706	01057W	PARTICIPANT	\N	PRESENT	0
718709	718708	01057W	PARTICIPANT	\N	PRESENT	0
718711	718710	01057W	PARTICIPANT	\N	PRESENT	0
718713	718712	20058E	PARTICIPANT	\N	PRESENT	1
718714	718712	19693L	PARTICIPANT	\N	PRESENT	1
718715	718712	19758L	PARTICIPANT	\N	PRESENT	1
718717	718716	20058E	PARTICIPANT	\N	PRESENT	1
718718	718716	20180F	PARTICIPANT	\N	PRESENT	1
718719	718716	19758L	PARTICIPANT	\N	PRESENT	1
718720	718716	19693L	PARTICIPANT	\N	PRESENT	1
718721	718716	14030Q	PARTICIPANT	\N	PRESENT	1
718723	718722	20058E	PARTICIPANT	\N	PRESENT	1
718724	718722	19693L	PARTICIPANT	\N	PRESENT	1
718725	718722	20180F	PARTICIPANT	\N	PRESENT	1
718811	718810	19565D	PARTICIPANT	\N	PRESENT	0
718813	718812	19565D	PARTICIPANT	\N	PRESENT	0
718815	718814	99004R	PARTICIPANT	\N	PRESENT	0
718816	718814	11085T	PARTICIPANT	\N	PRESENT	0
718825	718543	14059S	PARTICIPANT	\N	PRESENT	0
718826	718768	20124W	PARTICIPANT	\N	PRESENT	0
718930	717722	19820Y	PARTICIPANT	\N	PRESENT	0
718931	717722	14229S	PARTICIPANT	\N	PRESENT	0
718932	717722	19768N	PARTICIPANT	\N	PRESENT	0
718933	717722	14237S	PARTICIPANT	\N	PRESENT	0
718934	717722	20118Y	PARTICIPANT	\N	PRESENT	0
720204	716539	19691J	PARTICIPANT	\N	PRESENT	0
720205	716539	19798U	PARTICIPANT	\N	PRESENT	0
720206	720139	19691J	PARTICIPANT	\N	PRESENT	0
720207	720139	19798U	PARTICIPANT	\N	PRESENT	0
720208	720192	20124W	PARTICIPANT	\N	PRESENT	0
720209	720192	20090E	PARTICIPANT	\N	PRESENT	0
720211	720210	04047H	PARTICIPANT	\N	PRESENT	0
720212	720210	14089Y	PARTICIPANT	\N	PRESENT	0
720213	720210	11056N	PARTICIPANT	\N	PRESENT	0
720214	720210	19729F	PARTICIPANT	\N	PRESENT	0
720215	720210	19649G	PARTICIPANT	\N	PRESENT	0
729381	729283	04059M	PARTICIPANT	\N	PRESENT	0
729382	729283	14073Q	PARTICIPANT	\N	PRESENT	0
729383	729283	20052X	PARTICIPANT	\N	PRESENT	0
729384	729284	04059M	PARTICIPANT	\N	PRESENT	0
729385	729284	14073Q	PARTICIPANT	\N	PRESENT	0
729386	729284	20052X	PARTICIPANT	\N	PRESENT	0
729387	729284	08012N	PARTICIPANT	\N	PRESENT	0
732703	732659	11053K	PARTICIPANT	\N	PRESENT	0
732701	732659	19479G	PARTICIPANT	\N	PRESENT	0
732702	732659	11040E	PARTICIPANT	\N	PRESENT	0
732704	732659	95063L	PARTICIPANT	\N	PRESENT	0
732719	732718	19760E	PARTICIPANT	\N	PRESENT	0
732720	732718	05008E	PARTICIPANT	\N	PRESENT	0
732721	732718	14215L	PARTICIPANT	\N	PRESENT	0
732722	732718	14042U	PARTICIPANT	\N	PRESENT	0
732723	732718	20034V	PARTICIPANT	\N	PRESENT	0
732724	732718	19447X	PARTICIPANT	\N	PRESENT	0
732725	732718	14147R	PARTICIPANT	\N	PRESENT	0
732726	732718	19798U	PARTICIPANT	\N	PRESENT	0
732727	732718	19713W	PARTICIPANT	\N	PRESENT	0
732728	732718	20058E	PARTICIPANT	\N	PRESENT	0
732738	732718	14071N	PARTICIPANT	\N	PRESENT	0
732849	732848	01057W	PARTICIPANT	\N	PRESENT	0
732851	732850	01057W	PARTICIPANT	\N	PRESENT	0
732853	732852	11074Q	PARTICIPANT	\N	PRESENT	0
732854	732852	19349W	PARTICIPANT	\N	PRESENT	0
732856	732855	19741B	PARTICIPANT	\N	PRESENT	0
732858	732857	19515S	PARTICIPANT	\N	PRESENT	0
732859	732754	14189C	PARTICIPANT	\N	EXCUSE	0
732860	732754	19467C	PARTICIPANT	\N	EXCUSE	0
732861	732754	20082E	PARTICIPANT	\N	EXCUSE	0
732862	732755	14189C	PARTICIPANT	\N	EXCUSE	0
732863	732755	19467C	PARTICIPANT	\N	EXCUSE	0
732864	732755	20082E	PARTICIPANT	\N	EXCUSE	0
732875	732865	14187A	PRESIDENT	0	PRESENT	0
732876	732865	19347U	PARTICIPANT	\N	PRESENT	0
732877	732865	20018V	PARTICIPANT	\N	PRESENT	0
732878	732865	14257W	PARTICIPANT	\N	PRESENT	0
732879	732865	20286Q	PARTICIPANT	\N	EXCUSE	0
732880	730572	19749K	PARTICIPANT	\N	PRESENT	0
732881	730875	14331P	PARTICIPANT	\N	EXCUSE	0
732882	732628	14331P	PARTICIPANT	\N	EXCUSE	0
732883	728445	14331P	PARTICIPANT	\N	EXCUSE	0
732884	730875	14147R	PARTICIPANT	\N	PRESENT	0
732885	732628	14147R	PARTICIPANT	\N	EXCUSE	0
732886	728445	14147R	PARTICIPANT	\N	EXCUSE	0
732887	730875	14053L	PARTICIPANT	\N	EXCUSE	0
732888	732628	14053L	PARTICIPANT	\N	EXCUSE	0
732889	728445	14053L	PARTICIPANT	\N	EXCUSE	0
732890	732865	20124W	PARTICIPANT	\N	PRESENT	0
732895	732894	08010L	PARTICIPANT	\N	PRESENT	0
732897	732896	14189C	PARTICIPANT	\N	PRESENT	0
732898	732896	14069U	PARTICIPANT	\N	PRESENT	0
732899	732896	20090E	PARTICIPANT	\N	PRESENT	0
732900	732896	14083S	PARTICIPANT	\N	PRESENT	0
732901	732896	11053K	PARTICIPANT	\N	PRESENT	0
732902	732896	19611R	PARTICIPANT	\N	PRESENT	0
732903	732896	20056C	PARTICIPANT	\N	PRESENT	0
732904	732896	19671E	PARTICIPANT	\N	PRESENT	0
732905	732896	19745F	PARTICIPANT	\N	PRESENT	0
732906	732896	11097X	PARTICIPANT	\N	PRESENT	0
732908	732907	20116W	PARTICIPANT	\N	PRESENT	0
732910	732909	20086J	PARTICIPANT	\N	PRESENT	0
732912	732911	20086J	PARTICIPANT	\N	PRESENT	0
732914	732913	01048V	PARTICIPANT	\N	PRESENT	0
733346	732893	20248J	PARTICIPANT	\N	PRESENT	0
733750	732013	19643A	PARTICIPANT	\N	EXCUSE	0
733751	732013	11056N	PARTICIPANT	\N	EXCUSE	0
733752	732013	20018V	PARTICIPANT	\N	EXCUSE	0
733753	732013	20042V	PARTICIPANT	\N	PRESENT	0
733754	732013	11097X	PARTICIPANT	\N	PRESENT	0
733767	733765	20128B	PARTICIPANT	\N	PRESENT	0
733768	733765	20070A	PARTICIPANT	\N	PRESENT	0
733769	733765	20094J	PARTICIPANT	\N	PRESENT	0
733770	733765	19820Y	PARTICIPANT	\N	PRESENT	0
718747	718543	14053L	PARTICIPANT	\N	EXCUSE	0
724220	722794	19669L	PARTICIPANT	\N	PRESENT	0
724221	722794	19383Y	PARTICIPANT	\N	PRESENT	0
724222	722794	04042C	PARTICIPANT	\N	PRESENT	0
724223	722794	19333N	PARTICIPANT	\N	PRESENT	0
724224	722794	20120S	PARTICIPANT	\N	PRESENT	0
724226	722794	14257W	PARTICIPANT	\N	PRESENT	0
724228	722794	20252E	PARTICIPANT	\N	PRESENT	0
724231	722794	95041E	PARTICIPANT	\N	PRESENT	0
724232	722794	20084G	PARTICIPANT	\N	PRESENT	0
724234	722794	11067R	PARTICIPANT	\N	PRESENT	0
724235	722794	14237S	PARTICIPANT	\N	PRESENT	0
724236	722794	14193X	PARTICIPANT	\N	PRESENT	0
724238	722794	14217N	PARTICIPANT	\N	PRESENT	0
724239	722794	19820Y	PARTICIPANT	\N	PRESENT	0
724240	722794	14281W	PARTICIPANT	\N	PRESENT	0
724242	722794	86034E	PARTICIPANT	\N	PRESENT	0
724244	722794	19798U	PARTICIPANT	\N	PRESENT	0
724245	722794	19725B	PARTICIPANT	\N	PRESENT	0
724246	722794	19533U	PARTICIPANT	\N	PRESENT	0
724247	722794	20070A	PARTICIPANT	\N	PRESENT	0
724248	722794	01048V	PARTICIPANT	\N	PRESENT	0
724249	722794	20080C	PARTICIPANT	\N	PRESENT	0
724250	722794	20118Y	PARTICIPANT	\N	PRESENT	0
724251	722794	19701S	PARTICIPANT	\N	PRESENT	0
724252	722794	20060X	PARTICIPANT	\N	PRESENT	0
724253	722794	19413M	PARTICIPANT	\N	PRESENT	0
724254	722794	14071N	PARTICIPANT	\N	PRESENT	0
724255	722794	14053L	PARTICIPANT	\N	PRESENT	0
724256	722794	20018V	PARTICIPANT	\N	PRESENT	0
724257	722794	14215L	PARTICIPANT	\N	PRESENT	0
724258	722794	17965H	PARTICIPANT	\N	PRESENT	0
724259	722794	19251M	PARTICIPANT	\N	PRESENT	0
724260	722794	11097X	PARTICIPANT	\N	PRESENT	0
724261	722794	19527W	PARTICIPANT	\N	PRESENT	0
724262	722794	05008E	PARTICIPANT	\N	PRESENT	0
724263	722794	20264J	PARTICIPANT	\N	PRESENT	0
724264	722794	14187A	PARTICIPANT	\N	PRESENT	0
724265	722794	04033B	PARTICIPANT	\N	PRESENT	0
724266	722794	19489J	PARTICIPANT	\N	PRESENT	0
724267	722794	11048N	PARTICIPANT	\N	PRESENT	0
724269	722794	19671E	PARTICIPANT	\N	PRESENT	0
724270	722794	14121F	PARTICIPANT	\N	PRESENT	0
724272	722794	14133K	PARTICIPANT	\N	PRESENT	0
724274	722794	08034U	PARTICIPANT	\N	PRESENT	0
724275	722794	11054L	PARTICIPANT	\N	PRESENT	0
724276	722794	19747H	PARTICIPANT	\N	PRESENT	0
724277	722794	20094J	PARTICIPANT	\N	PRESENT	0
724278	722794	14026U	PARTICIPANT	\N	PRESENT	0
724279	722794	18193Q	PARTICIPANT	\N	PRESENT	0
724280	722794	14231L	PARTICIPANT	\N	PRESENT	0
724281	722794	19347U	PARTICIPANT	\N	PRESENT	0
724282	722794	11101A	PARTICIPANT	\N	PRESENT	0
724283	722794	19703U	PARTICIPANT	\N	PRESENT	0
724284	722794	19745F	PARTICIPANT	\N	PRESENT	0
724285	722794	19691J	PARTICIPANT	\N	PRESENT	0
724286	722794	11115U	PARTICIPANT	\N	PRESENT	0
724287	722794	19611R	PARTICIPANT	\N	PRESENT	0
724288	722794	20298U	PARTICIPANT	\N	PRESENT	0
724289	722794	20180F	PARTICIPANT	\N	PRESENT	0
724290	722794	19369B	PARTICIPANT	\N	PRESENT	0
724291	722794	01034P	PARTICIPANT	\N	PRESENT	0
724292	722794	08009T	PARTICIPANT	\N	PRESENT	0
724293	722794	19335Q	PARTICIPANT	\N	PRESENT	0
724294	722794	19563B	PARTICIPANT	\N	PRESENT	0
724295	722794	19569H	PARTICIPANT	\N	PRESENT	0
724296	722794	14219Q	PARTICIPANT	\N	PRESENT	0
724297	722794	14042U	PARTICIPANT	\N	PRESENT	0
724298	722794	04043D	PARTICIPANT	\N	PRESENT	0
724299	722794	19479G	PARTICIPANT	\N	PRESENT	0
724323	722794	16685X	PARTICIPANT	\N	PRESENT	0
724301	722794	19441R	PARTICIPANT	\N	PRESENT	0
724302	722794	11085T	PARTICIPANT	\N	PRESENT	0
724303	722794	19826F	PARTICIPANT	\N	PRESENT	0
724304	722794	20052X	PARTICIPANT	\N	PRESENT	0
724305	722794	19619A	PARTICIPANT	\N	PRESENT	0
724306	722794	14073Q	PARTICIPANT	\N	PRESENT	0
724307	722794	19699S	PARTICIPANT	\N	PRESENT	0
724308	722794	14083S	PARTICIPANT	\N	PRESENT	0
724309	722794	20040T	PARTICIPANT	\N	PRESENT	0
724310	722794	11070L	PARTICIPANT	\N	PRESENT	0
724311	722794	14255U	PARTICIPANT	\N	PRESENT	0
724312	722794	14205J	PARTICIPANT	\N	PRESENT	0
724313	722794	14189C	PARTICIPANT	\N	PRESENT	0
724314	722794	04070G	PARTICIPANT	\N	PRESENT	0
724315	722794	20066E	PARTICIPANT	\N	PRESENT	0
724316	722794	01024M	PARTICIPANT	\N	PRESENT	0
724317	722794	01025N	PARTICIPANT	\N	PRESENT	0
724319	722794	14327T	PARTICIPANT	\N	PRESENT	0
724320	722794	01043Q	PARTICIPANT	\N	PRESENT	0
724321	722794	19651A	PARTICIPANT	\N	PRESENT	0
724322	722794	14030Q	PARTICIPANT	\N	PRESENT	0
724324	722794	14179A	PARTICIPANT	\N	PRESENT	0
724326	722794	19685L	PARTICIPANT	\N	PRESENT	0
724327	722794	11110B	PARTICIPANT	\N	PRESENT	0
724328	722794	19735D	PARTICIPANT	\N	PRESENT	0
724329	722794	14251Q	PARTICIPANT	\N	PRESENT	0
724331	722794	20248J	PARTICIPANT	\N	PRESENT	0
724332	722794	19749K	PARTICIPANT	\N	PRESENT	0
724333	722794	20144B	PARTICIPANT	\N	PRESENT	0
724336	722794	19551W	PARTICIPANT	\N	PRESENT	0
724353	722794	19467C	PARTICIPANT	\N	PRESENT	0
724357	722794	19421M	PARTICIPANT	\N	PRESENT	0
724395	722794	01060R	PARTICIPANT	\N	PRESENT	0
724396	722794	20048C	PARTICIPANT	\N	PRESENT	0
724401	722794	20098N	PARTICIPANT	\N	PRESENT	0
724403	722794	14069U	PARTICIPANT	\N	PRESENT	0
724770	722654	19820Y	PARTICIPANT	\N	PRESENT	0
724433	722794	14123H	PARTICIPANT	\N	PRESENT	0
724771	722654	20914V	PARTICIPANT	\N	PRESENT	0
724782	722654	19768N	PARTICIPANT	\N	PRESENT	0
725012	725011	20042V	PARTICIPANT	\N	PRESENT	0
724987	724983	14187A	PRESIDENT	0	PRESENT	0
725013	725011	11080N	PRESIDENT	0	PRESENT	0
725014	725011	11074Q	PARTICIPANT	\N	PRESENT	0
725015	725011	01057W	PARTICIPANT	\N	PRESENT	0
725017	725011	14121F	PARTICIPANT	\N	PRESENT	0
725018	725011	19711U	PARTICIPANT	\N	PRESENT	0
725019	725011	05012A	PARTICIPANT	\N	PRESENT	0
725480	725479	17737W	PARTICIPANT	\N	PRESENT	0
725026	721823	04045F	PARTICIPANT	\N	EXCUSE	0
725027	721823	20050V	PARTICIPANT	\N	EXCUSE	0
725482	725481	17737W	PARTICIPANT	\N	PRESENT	0
725619	725618	20024T	PARTICIPANT	\N	PRESENT	0
725621	725620	20266L	PARTICIPANT	\N	PRESENT	0
725622	725620	19347U	PARTICIPANT	\N	PRESENT	0
725623	725620	14083S	PARTICIPANT	\N	PRESENT	0
725625	725624	19347U	PARTICIPANT	\N	PRESENT	0
725626	725624	20080C	PARTICIPANT	\N	PRESENT	0
725630	725629	20094J	PARTICIPANT	\N	PRESENT	0
725631	725629	04070G	PARTICIPANT	\N	PRESENT	0
725632	725629	11083R	PARTICIPANT	\N	PRESENT	0
725636	719278	14357A	PARTICIPANT	\N	PRESENT	0
725637	719328	20180F	PARTICIPANT	\N	PRESENT	0
728409	728189	14189C	PARTICIPANT	\N	EXCUSE	0
728410	728189	14001X	PARTICIPANT	\N	EXCUSE	0
728413	728411	04047H	PARTICIPANT	\N	PRESENT	0
728414	728411	14215L	PARTICIPANT	\N	PRESENT	0
728415	728411	19749K	PARTICIPANT	\N	PRESENT	0
728416	728411	14053L	PARTICIPANT	\N	PRESENT	0
728417	728412	04047H	PARTICIPANT	\N	PRESENT	0
728418	728412	19629C	PARTICIPANT	\N	PRESENT	0
728419	728412	11072N	PARTICIPANT	\N	PRESENT	0
728420	728412	14053L	PARTICIPANT	\N	PRESENT	0
728421	728412	19749K	PARTICIPANT	\N	PRESENT	0
728422	728412	19725B	PARTICIPANT	\N	PRESENT	0
728424	728423	14259Y	PARTICIPANT	\N	PRESENT	0
728425	728423	19629C	PARTICIPANT	\N	PRESENT	0
728446	728189	20036X	PARTICIPANT	\N	EXCUSE	0
729241	729236	19515S	PARTICIPANT	\N	PRESENT	0
729242	729236	20042V	PARTICIPANT	\N	PRESENT	0
729247	729236	20132W	PARTICIPANT	\N	PRESENT	0
729245	729236	14255U	PARTICIPANT	\N	PRESENT	0
729246	729236	20264J	PARTICIPANT	\N	PRESENT	0
729248	729236	04035D	PARTICIPANT	\N	PRESENT	0
729249	729236	19611R	PARTICIPANT	\N	PRESENT	0
729250	729236	04070G	PARTICIPANT	\N	PRESENT	0
729252	729236	20098N	PARTICIPANT	\N	PRESENT	0
729253	729236	20084G	PARTICIPANT	\N	PRESENT	0
729596	728221	19383Y	PARTICIPANT	\N	PRESENT	0
729597	728221	14042U	PARTICIPANT	\N	PRESENT	0
720277	720276	14225N	PARTICIPANT	\N	PRESENT	0
720278	720276	01057W	PARTICIPANT	\N	PRESENT	0
720291	720289	11053K	PARTICIPANT	\N	PRESENT	0
731331	730787	20116W	PARTICIPANT	\N	PRESENT	0
731593	730639	10006L	PRESIDENT	0	PRESENT	0
731597	730639	14213J	PARTICIPANT	\N	PRESENT	0
731598	730639	20248J	PARTICIPANT	\N	PRESENT	0
731599	730639	19691J	PARTICIPANT	\N	PRESENT	0
731600	730639	19569H	PARTICIPANT	\N	PRESENT	0
731601	730639	14223L	PARTICIPANT	\N	PRESENT	0
731602	730639	20090E	PARTICIPANT	\N	PRESENT	0
731603	730639	14281W	PARTICIPANT	\N	PRESENT	0
731604	730639	04092N	PARTICIPANT	\N	PRESENT	0
731605	730639	11097X	PARTICIPANT	\N	PRESENT	0
731606	730639	19415P	PARTICIPANT	\N	PRESENT	0
731607	730639	19798U	PARTICIPANT	\N	PRESENT	0
731608	730639	17965H	PARTICIPANT	\N	PRESENT	0
731609	730639	11045K	PARTICIPANT	\N	PRESENT	0
731635	730639	20066E	PARTICIPANT	\N	PRESENT	0
731649	730639	19760E	PARTICIPANT	\N	PRESENT	0
731650	730639	17779H	PARTICIPANT	\N	PRESENT	0
731651	730639	20040T	PARTICIPANT	\N	PRESENT	0
731652	730639	14071N	PARTICIPANT	\N	PRESENT	0
731653	730639	11031D	PARTICIPANT	\N	PRESENT	0
731654	730639	19591F	PARTICIPANT	\N	PRESENT	0
731671	730639	14042U	PARTICIPANT	\N	PRESENT	0
731672	730639	04043D	PARTICIPANT	\N	PRESENT	0
731992	730674	14055N	PARTICIPANT	\N	PRESENT	0
731996	730674	20128B	PARTICIPANT	\N	PRESENT	0
732014	732013	19399H	PARTICIPANT	\N	EXCUSE	0
732015	732013	11040E	PARTICIPANT	\N	EXCUSE	0
732016	732013	19479G	PARTICIPANT	\N	PRESENT	0
732018	732013	20044X	PARTICIPANT	\N	EXCUSE	0
732055	732054	20024T	PARTICIPANT	\N	PRESENT	0
732056	732054	14030Q	PARTICIPANT	\N	PRESENT	0
732057	732054	19782L	PARTICIPANT	\N	PRESENT	0
732058	732054	19525U	PARTICIPANT	\N	PRESENT	0
732059	732054	17229F	PARTICIPANT	\N	PRESENT	0
732060	732054	14213J	PARTICIPANT	\N	PRESENT	0
732062	732054	14147R	PARTICIPANT	\N	PRESENT	0
732063	732054	19369B	PARTICIPANT	\N	PRESENT	0
732064	732054	19745F	PARTICIPANT	\N	PRESENT	0
732065	732054	19798U	PARTICIPANT	\N	PRESENT	0
732066	732054	19713W	PARTICIPANT	\N	PRESENT	0
732067	732054	19503N	PARTICIPANT	\N	PRESENT	0
732068	732054	01024M	PARTICIPANT	\N	PRESENT	0
732069	732054	14021P	PARTICIPANT	\N	PRESENT	0
732274	730639	19663E	PARTICIPANT	\N	PRESENT	0
732275	730639	14026U	PARTICIPANT	\N	PRESENT	0
732635	730576	11031D	PARTICIPANT	\N	PRESENT	0
732636	730576	19735D	PRESIDENT	0	PRESENT	0
732637	730576	20066E	PARTICIPANT	\N	EXCUSE	0
732639	730576	20126Y	PARTICIPANT	\N	PRESENT	0
732647	730576	14026U	PARTICIPANT	\N	PRESENT	0
732654	730576	19369B	PARTICIPANT	\N	PRESENT	0
732655	730576	14213J	PARTICIPANT	\N	PRESENT	0
732756	732642	14357A	PRESIDENT	0	PRESENT	0
732757	732642	11053K	PARTICIPANT	\N	PRESENT	0
732758	732642	20180F	PARTICIPANT	\N	PRESENT	0
732761	732760	19553Y	PARTICIPANT	\N	PRESENT	0
732762	732760	14205J	PARTICIPANT	\N	PRESENT	0
732779	732778	20084G	PARTICIPANT	\N	PRESENT	0
732780	732778	17023S	PARTICIPANT	\N	PRESENT	0
732806	732805	86034E	PARTICIPANT	\N	PRESENT	0
732807	732805	04085P	PARTICIPANT	\N	PRESENT	0
732808	732805	14133K	PARTICIPANT	\N	PRESENT	0
732809	732805	04047H	PARTICIPANT	\N	PRESENT	0
732810	732805	11053K	PARTICIPANT	\N	PRESENT	0
732811	732805	19719D	PARTICIPANT	\N	PRESENT	0
732812	732805	10006L	PARTICIPANT	\N	PRESENT	0
732813	732805	14026U	PARTICIPANT	\N	PRESENT	0
732814	732805	11048N	PARTICIPANT	\N	PRESENT	0
732815	732805	14021P	PARTICIPANT	\N	PRESENT	0
732816	732805	99004R	PARTICIPANT	\N	PRESENT	0
732817	732805	19611R	PARTICIPANT	\N	PRESENT	0
732818	732805	12041X	PARTICIPANT	\N	PRESENT	0
732819	732805	01043Q	PARTICIPANT	\N	PRESENT	0
732820	732805	14251Q	PARTICIPANT	\N	PRESENT	0
732821	732805	14031R	PARTICIPANT	\N	PRESENT	0
732822	732805	11085T	PARTICIPANT	\N	PRESENT	0
732823	732805	08061X	PARTICIPANT	\N	PRESENT	0
732824	732805	11090Q	PARTICIPANT	\N	PRESENT	0
732825	732805	14331P	PARTICIPANT	\N	PRESENT	0
732826	732805	14225N	PARTICIPANT	\N	PRESENT	0
732827	732805	11012A	PARTICIPANT	\N	PRESENT	0
732828	732805	04033B	PARTICIPANT	\N	PRESENT	0
732829	732805	95063L	PARTICIPANT	\N	PRESENT	0
732830	732805	20266L	PARTICIPANT	\N	PRESENT	0
732929	732923	19399H	PARTICIPANT	\N	PRESENT	0
732921	732893	19719D	PARTICIPANT	\N	PRESENT	0
732928	732922	19399H	PARTICIPANT	\N	PRESENT	0
732930	732923	19611R	PARTICIPANT	\N	PRESENT	0
732931	732923	14229S	PARTICIPANT	\N	PRESENT	0
732932	732923	19699S	PARTICIPANT	\N	PRESENT	0
732933	732924	19399H	PARTICIPANT	\N	PRESENT	0
732934	732924	19611R	PARTICIPANT	\N	PRESENT	0
732935	732924	14229S	PARTICIPANT	\N	PRESENT	0
732936	732924	04059M	PARTICIPANT	\N	PRESENT	0
732940	732939	14189C	PARTICIPANT	\N	PRESENT	0
732941	732939	19741B	PARTICIPANT	\N	PRESENT	0
732942	732939	19667J	PARTICIPANT	\N	PRESENT	0
732943	732939	20116W	PARTICIPANT	\N	PRESENT	0
732944	732939	20086J	PARTICIPANT	\N	PRESENT	0
732945	732939	11040E	PARTICIPANT	\N	PRESENT	0
732946	732939	20914V	PARTICIPANT	\N	PRESENT	0
732947	732939	20080C	PARTICIPANT	\N	PRESENT	0
732948	732939	14083S	PARTICIPANT	\N	PRESENT	0
732949	732939	11053K	PARTICIPANT	\N	PRESENT	0
732950	732939	19545Y	PARTICIPANT	\N	PRESENT	0
732951	732939	20070A	PARTICIPANT	\N	PRESENT	0
732952	732939	11070L	PARTICIPANT	\N	PRESENT	0
732953	732939	14327T	PARTICIPANT	\N	PRESENT	0
732954	732939	04071H	PARTICIPANT	\N	PRESENT	0
732955	732939	11074Q	PARTICIPANT	\N	PRESENT	0
732956	732939	11110B	PARTICIPANT	\N	PRESENT	0
732957	732939	19647E	PARTICIPANT	\N	PRESENT	0
732958	732939	01057W	PARTICIPANT	\N	PRESENT	0
732959	732939	11048N	PARTICIPANT	\N	PRESENT	0
732960	732939	14121F	PARTICIPANT	\N	PRESENT	0
732961	732939	99004R	PARTICIPANT	\N	PRESENT	0
732962	732939	20126Y	PARTICIPANT	\N	PRESENT	0
732963	732939	07029T	PARTICIPANT	\N	PRESENT	0
732964	732939	19711U	PARTICIPANT	\N	PRESENT	0
732965	732939	08010L	PARTICIPANT	\N	PRESENT	0
732966	732939	08034U	PARTICIPANT	\N	PRESENT	0
732967	732939	08009T	PARTICIPANT	\N	PRESENT	0
732968	732939	20252E	PARTICIPANT	\N	PRESENT	0
732969	732939	19671E	PARTICIPANT	\N	PRESENT	0
732970	732939	19335Q	PARTICIPANT	\N	PRESENT	0
732971	732939	08011M	PARTICIPANT	\N	PRESENT	0
732972	732939	20050V	PARTICIPANT	\N	PRESENT	0
732973	732939	20036X	PARTICIPANT	\N	PRESENT	0
732974	732893	20068G	PARTICIPANT	\N	PRESENT	0
732975	732893	19507S	PARTICIPANT	\N	PRESENT	0
732976	732939	19349W	PARTICIPANT	\N	PRESENT	0
732977	732939	14331P	PARTICIPANT	\N	PRESENT	0
732978	732939	14225N	PRESIDENT	0	PRESENT	0
732979	732939	11012A	PARTICIPANT	\N	PRESENT	0
732980	732939	20150Y	PARTICIPANT	\N	PRESENT	0
732981	732939	20044X	PARTICIPANT	\N	PRESENT	0
732982	732939	19479G	PARTICIPANT	\N	PRESENT	0
732983	732939	95063L	PARTICIPANT	\N	PRESENT	0
732984	732893	17589D	PARTICIPANT	\N	PRESENT	0
732985	732893	20028X	PARTICIPANT	\N	PRESENT	0
732986	732893	14221J	PARTICIPANT	\N	PRESENT	0
732987	732893	14191V	PARTICIPANT	\N	PRESENT	0
732988	732893	04045F	PARTICIPANT	\N	PRESENT	0
732989	732893	11099A	PARTICIPANT	\N	PRESENT	0
732990	732893	14223L	PARTICIPANT	\N	PRESENT	0
732991	732893	20090E	PARTICIPANT	\N	PRESENT	0
732992	732893	20114U	PARTICIPANT	\N	PRESENT	0
732993	732893	19747H	PARTICIPANT	\N	PRESENT	0
732994	732893	20080C	PARTICIPANT	\N	PRESENT	0
732995	732893	19954N	PARTICIPANT	\N	PRESENT	0
732996	732893	01034P	PARTICIPANT	\N	PRESENT	0
732997	732893	14059S	PARTICIPANT	\N	PRESENT	0
732998	732893	04033B	PARTICIPANT	\N	PRESENT	0
732999	732893	19301E	PARTICIPANT	\N	PRESENT	0
733000	732893	19798U	PARTICIPANT	\N	PRESENT	0
733001	732893	14001X	PARTICIPANT	\N	PRESENT	0
733002	732893	20118Y	PARTICIPANT	\N	PRESENT	0
711795	711794	20042V	PARTICIPANT	\N	PRESENT	0
711796	711794	11080N	PARTICIPANT	\N	PRESENT	0
711797	711794	11074Q	PARTICIPANT	\N	PRESENT	0
711798	711794	14121F	PARTICIPANT	\N	PRESENT	0
711799	711794	19335Q	PARTICIPANT	\N	PRESENT	0
711800	711794	05012A	PARTICIPANT	\N	PRESENT	0
711813	705127	11083R	PARTICIPANT	\N	PRESENT	0
711814	705127	14073Q	PARTICIPANT	\N	PRESENT	0
711815	705127	19593H	PARTICIPANT	\N	PRESENT	0
711816	705127	20100N	PARTICIPANT	\N	PRESENT	0
711817	705127	10015M	PARTICIPANT	\N	PRESENT	0
711818	705127	04035D	PARTICIPANT	\N	PRESENT	0
711819	705127	11026G	PARTICIPANT	\N	PRESENT	0
711820	705127	04045F	PARTICIPANT	\N	PRESENT	0
711821	705127	19333N	PARTICIPANT	\N	PRESENT	0
711822	705127	14331P	PARTICIPANT	\N	PRESENT	0
711824	705127	20286Q	PARTICIPANT	\N	PRESENT	0
711825	705127	20104S	PARTICIPANT	\N	PRESENT	0
711826	705127	14357A	PARTICIPANT	\N	PRESENT	0
711827	705127	14033T	PARTICIPANT	\N	PRESENT	0
711828	705127	04057K	PARTICIPANT	\N	PRESENT	0
711829	705127	14189C	PARTICIPANT	\N	EXCUSE	0
711830	705127	19701S	PARTICIPANT	\N	EXCUSE	0
711831	705127	14169X	PARTICIPANT	\N	EXCUSE	0
722719	720105	14021P	PARTICIPANT	\N	PRESENT	0
722720	720105	99004R	PARTICIPANT	\N	PRESENT	0
722743	720105	19866P	PARTICIPANT	\N	PRESENT	0
722739	720105	04047H	PARTICIPANT	\N	PRESENT	0
722723	720105	20080C	PARTICIPANT	\N	PRESENT	0
722740	720105	01057W	PARTICIPANT	\N	PRESENT	0
722725	720105	14231L	PARTICIPANT	\N	PRESENT	0
722741	720105	14053L	PARTICIPANT	\N	PRESENT	0
722727	720105	19489J	PARTICIPANT	\N	PRESENT	0
722742	720105	14225N	PARTICIPANT	\N	PRESENT	0
722745	720105	14215L	PARTICIPANT	\N	PRESENT	0
722730	720105	08010L	PARTICIPANT	\N	PRESENT	0
722731	720105	19647E	PARTICIPANT	\N	PRESENT	0
722744	720105	20116W	PARTICIPANT	\N	PRESENT	0
722733	720105	20060X	PARTICIPANT	\N	PRESENT	0
722734	720105	14001X	PARTICIPANT	\N	PRESENT	0
722735	720105	17779H	PARTICIPANT	\N	PRESENT	0
722746	720105	19760E	PARTICIPANT	\N	PRESENT	0
722737	720105	20110Q	PARTICIPANT	\N	PRESENT	0
722747	720105	20058E	PARTICIPANT	\N	PRESENT	0
732831	730569	19749K	PARTICIPANT	\N	PRESENT	0
732832	730570	19749K	PARTICIPANT	\N	PRESENT	0
732833	730570	19649G	PARTICIPANT	\N	PRESENT	0
732835	732834	19749K	PARTICIPANT	\N	PRESENT	0
732836	732834	14053L	PARTICIPANT	\N	PRESENT	0
732837	732834	19649G	PARTICIPANT	\N	PRESENT	0
732869	730571	14053L	PARTICIPANT	\N	PRESENT	0
732870	730571	19749K	PARTICIPANT	\N	PRESENT	0
732872	732871	14053L	PARTICIPANT	\N	PRESENT	0
732873	732871	19749K	PARTICIPANT	\N	PRESENT	0
732874	732871	20110Q	PARTICIPANT	\N	PRESENT	0
735657	735596	86034E	PARTICIPANT	\N	PRESENT	0
735658	735596	20076G	PARTICIPANT	\N	PRESENT	0
735659	735596	05008E	PARTICIPANT	\N	PRESENT	0
735660	735596	19741B	PARTICIPANT	\N	PRESENT	0
735661	735596	19667J	PARTICIPANT	\N	PRESENT	0
735662	735596	20024T	PARTICIPANT	\N	PRESENT	0
735663	735596	19954N	PARTICIPANT	\N	PRESENT	0
735664	735596	19760E	PARTICIPANT	\N	PRESENT	0
735665	735596	19575F	PARTICIPANT	\N	PRESENT	0
735666	735596	04085P	PARTICIPANT	\N	PRESENT	0
735667	735596	17367Q	PARTICIPANT	\N	PRESENT	0
735668	735596	20112S	PARTICIPANT	\N	PRESENT	0
735669	735596	20086J	PARTICIPANT	\N	PRESENT	0
735670	735596	11040E	PARTICIPANT	\N	PRESENT	0
735671	735596	19758L	PARTICIPANT	\N	PRESENT	0
735672	735596	19415P	PARTICIPANT	\N	PRESENT	0
735673	735596	11031D	PARTICIPANT	\N	PRESENT	0
735674	735596	20078J	PARTICIPANT	\N	PRESENT	0
735675	735596	20138D	PARTICIPANT	\N	PRESENT	0
735676	735596	11056N	PARTICIPANT	\N	PRESENT	0
735677	735596	19747H	PARTICIPANT	\N	PRESENT	0
735678	735596	19565D	PARTICIPANT	\N	PRESENT	0
735679	735596	20152B	PARTICIPANT	\N	PRESENT	0
735680	735596	20102Q	PARTICIPANT	\N	PRESENT	0
735681	735596	19383Y	PARTICIPANT	\N	PRESENT	0
735682	735596	11077T	PARTICIPANT	\N	PRESENT	0
735683	735596	19687N	PARTICIPANT	\N	PRESENT	0
735684	735596	20046A	PARTICIPANT	\N	PRESENT	0
735685	735596	19621T	PARTICIPANT	\N	PRESENT	0
735686	735596	20110Q	PARTICIPANT	\N	PRESENT	0
735687	735596	04047H	PARTICIPANT	\N	PRESENT	0
735688	735596	20090E	PARTICIPANT	\N	PRESENT	0
735689	735596	20142Y	PARTICIPANT	\N	PRESENT	0
735690	735596	11101A	PARTICIPANT	\N	PRESENT	0
735691	735596	20036X	PARTICIPANT	\N	PRESENT	0
735692	735596	04042C	PARTICIPANT	\N	PRESENT	0
735693	735596	20100N	PARTICIPANT	\N	PRESENT	0
735694	735596	19347U	PARTICIPANT	\N	PRESENT	0
735695	735596	14053L	PARTICIPANT	\N	PRESENT	0
735696	735596	11103C	PARTICIPANT	\N	PRESENT	0
735697	735596	20130U	PARTICIPANT	\N	PRESENT	0
735698	735596	20092G	PARTICIPANT	\N	PRESENT	0
735699	735596	20266L	PARTICIPANT	\N	PRESENT	0
735700	735596	20126Y	PARTICIPANT	\N	PRESENT	0
735701	735596	19651A	PARTICIPANT	\N	PRESENT	0
735702	735596	14329V	PARTICIPANT	\N	PRESENT	0
735655	735596	14133K	PARTICIPANT	\N	PRESENT	0
735656	735596	19515S	PARTICIPANT	\N	PRESENT	0
735703	735596	19782L	PARTICIPANT	\N	PRESENT	0
735704	735596	14038Y	PARTICIPANT	\N	PRESENT	0
735705	735596	11080N	PARTICIPANT	\N	PRESENT	0
735706	735596	19659J	PARTICIPANT	\N	PRESENT	0
735707	735596	08028W	PARTICIPANT	\N	PRESENT	0
735708	735596	19467C	PARTICIPANT	\N	PRESENT	0
735709	735596	11083R	PARTICIPANT	\N	PRESENT	0
735710	735596	18083K	PARTICIPANT	\N	PRESENT	0
735711	735596	14259Y	PARTICIPANT	\N	PRESENT	0
735712	735596	04008A	PARTICIPANT	\N	PRESENT	0
735713	735596	20128B	PARTICIPANT	\N	PRESENT	0
735714	735596	19643A	PARTICIPANT	\N	PRESENT	0
735715	735596	14037X	PARTICIPANT	\N	PRESENT	0
735716	735596	19697Q	PARTICIPANT	\N	PRESENT	0
735717	735596	19637C	PARTICIPANT	\N	PRESENT	0
735718	735596	20108W	PARTICIPANT	\N	PRESENT	0
735719	735596	08073C	PARTICIPANT	\N	PRESENT	0
735720	735596	08061X	PARTICIPANT	\N	PRESENT	0
735721	735596	19349W	PARTICIPANT	\N	PRESENT	0
735722	735596	04045F	PARTICIPANT	\N	PRESENT	0
735723	735596	20140W	PARTICIPANT	\N	PRESENT	0
735724	735596	10006L	PARTICIPANT	\N	PRESENT	0
735725	735596	14215L	PARTICIPANT	\N	PRESENT	0
735726	735596	01060R	PARTICIPANT	\N	PRESENT	0
735727	735596	14055N	PARTICIPANT	\N	PRESENT	0
735728	735596	19717B	PARTICIPANT	\N	PRESENT	0
735729	735596	20116W	PARTICIPANT	\N	PRESENT	0
735730	735596	14207L	PARTICIPANT	\N	PRESENT	0
735731	735596	19629C	PARTICIPANT	\N	PRESENT	0
735732	735596	19681G	PARTICIPANT	\N	PRESENT	0
735733	735596	19719D	PARTICIPANT	\N	PRESENT	0
735734	735596	20132W	PARTICIPANT	\N	PRESENT	0
735735	735596	04071H	PARTICIPANT	\N	PRESENT	0
735736	735596	19387D	PARTICIPANT	\N	PRESENT	0
735737	735596	20074E	PARTICIPANT	\N	PRESENT	0
735738	735596	98022P	PARTICIPANT	\N	PRESENT	0
735739	735596	19507S	PARTICIPANT	\N	PRESENT	0
735740	735596	19553Y	PARTICIPANT	\N	PRESENT	0
735741	735596	20072C	PARTICIPANT	\N	PRESENT	0
735742	735596	14187A	PARTICIPANT	\N	PRESENT	0
735743	735596	19866P	PARTICIPANT	\N	PRESENT	0
735744	735596	20038A	PARTICIPANT	\N	PRESENT	0
735745	735596	11012A	PARTICIPANT	\N	PRESENT	0
735746	735596	97011G	PARTICIPANT	\N	PRESENT	0
735747	735596	08018U	PARTICIPANT	\N	PRESENT	0
735748	735596	14107H	PARTICIPANT	\N	PRESENT	0
735749	735596	20172F	PARTICIPANT	\N	PRESENT	0
735750	735596	04035D	PARTICIPANT	\N	PRESENT	0
735751	735596	19545Y	PARTICIPANT	\N	PRESENT	0
735752	735596	14195A	PARTICIPANT	\N	PRESENT	0
735753	735596	14355X	PARTICIPANT	\N	PRESENT	0
735754	735596	14211G	PARTICIPANT	\N	PRESENT	0
735755	735596	11064N	PARTICIPANT	\N	PRESENT	0
735756	735596	08056B	PARTICIPANT	\N	PRESENT	0
735757	735596	19583F	PARTICIPANT	\N	PRESENT	0
735758	735596	14033T	PARTICIPANT	\N	PRESENT	0
735759	735596	14251Q	PARTICIPANT	\N	PRESENT	0
735760	735596	14111D	PARTICIPANT	\N	PRESENT	0
713830	713829	20074E	PARTICIPANT	\N	PRESENT	0
715965	709156	19329S	PARTICIPANT	\N	EXCUSE	0
715975	715973	20112S	PARTICIPANT	\N	PRESENT	0
715976	715973	19643A	PARTICIPANT	\N	PRESENT	0
715978	715977	19643A	PARTICIPANT	\N	PRESENT	1
715979	715977	20112S	PARTICIPANT	\N	PRESENT	0
715980	715977	19693L	PARTICIPANT	\N	PRESENT	0
715982	715981	19643A	PARTICIPANT	\N	PRESENT	0
715983	715981	19735D	PARTICIPANT	\N	PRESENT	0
728208	728207	19421M	PARTICIPANT	\N	PRESENT	0
728209	728207	14059S	PARTICIPANT	\N	PRESENT	0
728210	728207	14097Y	PARTICIPANT	\N	PRESENT	0
728212	728211	20072C	PARTICIPANT	\N	PRESENT	0
728213	728211	19421M	PARTICIPANT	\N	PRESENT	0
728214	728211	14059S	PARTICIPANT	\N	PRESENT	0
728215	728211	14097Y	PARTICIPANT	\N	PRESENT	0
728241	728234	19515S	PARTICIPANT	\N	PRESENT	0
728242	728234	19705W	PARTICIPANT	\N	PRESENT	0
730804	730640	19629C	PRESIDENT	0	PRESENT	0
730805	730640	14259Y	PARTICIPANT	\N	PRESENT	0
730806	730640	14329V	PARTICIPANT	\N	PRESENT	0
730809	730640	11056N	PARTICIPANT	\N	PRESENT	0
730810	730640	14189C	PARTICIPANT	\N	PRESENT	0
730811	730640	19383Y	PARTICIPANT	\N	PRESENT	0
730812	730640	19703U	PARTICIPANT	\N	PRESENT	0
733823	732765	19719D	PARTICIPANT	\N	PRESENT	0
733824	732765	19593H	PARTICIPANT	\N	PRESENT	0
733825	732765	20112S	PARTICIPANT	\N	PRESENT	0
733826	732765	14109K	PARTICIPANT	\N	PRESENT	0
733827	732765	11104D	PARTICIPANT	\N	PRESENT	0
733828	732765	20134Y	PARTICIPANT	\N	PRESENT	0
733829	732765	14229S	PARTICIPANT	\N	PRESENT	0
733831	732765	04059M	PARTICIPANT	\N	PRESENT	0
733833	732765	14037X	PARTICIPANT	\N	PRESENT	0
733834	732765	20914V	PARTICIPANT	\N	PRESENT	0
733835	732765	20116W	PARTICIPANT	\N	PRESENT	0
733836	732765	14030Q	PARTICIPANT	\N	PRESENT	0
733837	732765	20132W	PARTICIPANT	\N	PRESENT	0
733838	732765	17589D	PARTICIPANT	\N	PRESENT	0
733839	732765	19479G	PARTICIPANT	\N	PRESENT	0
733840	732765	19747H	PARTICIPANT	\N	PRESENT	0
733841	732765	20152B	PARTICIPANT	\N	PRESENT	0
733842	732765	20056C	PARTICIPANT	\N	PRESENT	0
733843	732765	20054A	PARTICIPANT	\N	PRESENT	0
733844	732765	01025N	PARTICIPANT	\N	PRESENT	0
733845	732765	18083K	PARTICIPANT	\N	PRESENT	0
733846	732765	20032T	PARTICIPANT	\N	PRESENT	0
733847	732765	14147R	PARTICIPANT	\N	PRESENT	0
733848	732765	19533U	PARTICIPANT	\N	PRESENT	0
733849	732765	14223L	PARTICIPANT	\N	PRESENT	0
733850	732765	19703U	PARTICIPANT	\N	PRESENT	0
733851	732765	19693L	PARTICIPANT	\N	PRESENT	0
733853	732765	19679N	PARTICIPANT	\N	PRESENT	0
733854	732765	19643A	PARTICIPANT	\N	PRESENT	0
733855	732765	20076G	PARTICIPANT	\N	PRESENT	0
733856	732765	14191V	PARTICIPANT	\N	PRESENT	0
733857	732765	20038A	PARTICIPANT	\N	PRESENT	0
733858	732765	19621T	PARTICIPANT	\N	PRESENT	0
733859	732765	20138D	PARTICIPANT	\N	PRESENT	0
733860	732765	11056N	PARTICIPANT	\N	PRESENT	0
733861	732765	20062A	PARTICIPANT	\N	PRESENT	0
733862	732765	97011G	PARTICIPANT	\N	PRESENT	0
733863	732765	20140W	PARTICIPANT	\N	PRESENT	0
733864	732765	19387D	PARTICIPANT	\N	PRESENT	0
733869	733695	20180F	PARTICIPANT	\N	PRESENT	0
733870	733695	14357A	PARTICIPANT	\N	PRESENT	0
733871	733695	11097X	PARTICIPANT	\N	PRESENT	0
733872	733695	11053K	PARTICIPANT	\N	PRESENT	0
733873	733695	19251M	PRESIDENT	0	PRESENT	0
733874	733695	20102Q	PARTICIPANT	\N	PRESENT	0
733875	733695	19762G	PARTICIPANT	\N	PRESENT	0
733876	732765	20142Y	PARTICIPANT	\N	PRESENT	0
733877	733695	20084G	PARTICIPANT	\N	PRESENT	0
733878	732765	20090E	PARTICIPANT	\N	PRESENT	0
733887	732765	11012A	PARTICIPANT	\N	PRESENT	0
733888	732765	08061X	PARTICIPANT	\N	PRESENT	0
733889	732765	19669L	PARTICIPANT	\N	PRESENT	0
733890	732765	19383Y	PARTICIPANT	\N	PRESENT	0
733891	732777	05008E	PARTICIPANT	\N	PRESENT	0
733892	732777	04085P	PARTICIPANT	\N	PRESENT	0
733893	732765	20018V	PARTICIPANT	\N	PRESENT	0
733894	732777	95063L	PARTICIPANT	\N	PRESENT	0
733895	732765	19599P	PARTICIPANT	\N	PRESENT	0
733896	732765	20034V	PARTICIPANT	\N	PRESENT	0
733897	732777	14147R	PARTICIPANT	\N	PRESENT	0
733898	732776	14021P	PARTICIPANT	\N	EXCUSE	0
733899	732776	20074E	PARTICIPANT	\N	EXCUSE	0
733900	732777	20074E	PARTICIPANT	\N	EXCUSE	0
733901	732777	14021P	PARTICIPANT	\N	EXCUSE	0
733904	732765	19651A	PARTICIPANT	\N	PRESENT	0
733905	732765	14205J	PARTICIPANT	\N	PRESENT	0
733906	732765	20048C	PARTICIPANT	\N	PRESENT	0
733907	732765	19701S	PARTICIPANT	\N	PRESENT	0
733908	732765	14055N	PARTICIPANT	\N	PRESENT	0
733909	732765	14033T	PARTICIPANT	\N	PRESENT	0
733910	732765	07029T	PARTICIPANT	\N	PRESENT	0
733912	732765	14193X	PARTICIPANT	\N	PRESENT	0
733913	732765	14237S	PARTICIPANT	\N	PRESENT	0
733914	732765	19563B	PARTICIPANT	\N	PRESENT	0
733915	732765	11043H	PARTICIPANT	\N	PRESENT	0
733916	732765	19611R	PARTICIPANT	\N	PRESENT	0
733917	732765	14251Q	PARTICIPANT	\N	PRESENT	0
733918	732765	20104S	PARTICIPANT	\N	PRESENT	0
733919	732765	14215L	PARTICIPANT	\N	PRESENT	0
733920	732765	20110Q	PARTICIPANT	\N	PRESENT	0
733921	732765	20058E	PARTICIPANT	\N	PRESENT	0
734026	732649	14355X	PARTICIPANT	\N	PRESENT	0
734027	732649	19591F	PARTICIPANT	\N	PRESENT	0
734028	732649	19569H	PARTICIPANT	\N	PRESENT	0
734029	732649	14281W	PARTICIPANT	\N	PRESENT	0
734120	732649	17965H	PARTICIPANT	\N	PRESENT	0
734125	732649	19295A	PARTICIPANT	\N	EXCUSE	0
734146	732649	04057K	PARTICIPANT	\N	PRESENT	0
734172	732649	14026U	PARTICIPANT	\N	PRESENT	0
735120	732653	19583F	PARTICIPANT	\N	EXCUSE	0
735121	732653	19443T	PARTICIPANT	\N	EXCUSE	0
735122	732653	20072C	PARTICIPANT	\N	EXCUSE	0
735123	732755	14259Y	PARTICIPANT	\N	PRESENT	0
735124	732755	19629C	PRESIDENT	0	PRESENT	0
735128	732755	14329V	PARTICIPANT	\N	PRESENT	0
735138	732755	11064N	PARTICIPANT	\N	PRESENT	0
735216	732013	20068G	PARTICIPANT	\N	EXCUSE	0
735217	732013	19711U	PARTICIPANT	\N	PRESENT	0
735218	732013	20050V	PARTICIPANT	\N	PRESENT	0
735219	732013	14259Y	PARTICIPANT	\N	PRESENT	0
735244	732628	19717B	PRESIDENT	0	PRESENT	0
735245	732628	19715Y	PARTICIPANT	\N	PRESENT	0
735246	732628	19657G	PARTICIPANT	\N	PRESENT	0
735247	732628	11072N	PARTICIPANT	\N	PRESENT	0
735248	732628	07029T	PARTICIPANT	\N	PRESENT	0
735249	732628	20098N	PARTICIPANT	\N	PRESENT	0
735250	732628	14030Q	PARTICIPANT	\N	PRESENT	0
735255	732628	20146D	PARTICIPANT	\N	PRESENT	0
735268	732628	08073C	PARTICIPANT	\N	PRESENT	0
735269	731901	08073C	PARTICIPANT	\N	PRESENT	0
735306	728445	19717B	PRESIDENT	0	PRESENT	0
735307	728445	19715Y	PARTICIPANT	\N	PRESENT	0
735308	728445	14059S	PARTICIPANT	\N	PRESENT	0
735309	728445	11072N	PARTICIPANT	\N	PRESENT	0
735310	728445	08073C	PARTICIPANT	\N	PRESENT	0
735311	728445	20146D	PARTICIPANT	\N	PRESENT	0
735319	732740	20050V	PARTICIPANT	\N	PRESENT	0
735336	732740	04045F	PARTICIPANT	\N	PRESENT	0
735353	733757	19533U	PARTICIPANT	\N	PRESENT	0
735354	733757	19503N	PARTICIPANT	\N	PRESENT	0
735357	733757	01048V	PARTICIPANT	\N	PRESENT	0
735358	733757	20066E	PARTICIPANT	\N	EXCUSE	0
735359	733757	11067R	PARTICIPANT	\N	EXCUSE	0
735360	733757	20072C	PARTICIPANT	\N	EXCUSE	0
735361	733757	19735D	PARTICIPANT	\N	EXCUSE	0
735364	733756	19503N	PARTICIPANT	\N	PRESENT	0
735365	733756	01048V	PARTICIPANT	\N	EXCUSE	0
735366	733756	20072C	PARTICIPANT	\N	EXCUSE	0
735367	733756	11067R	PARTICIPANT	\N	EXCUSE	0
735368	733756	20066E	PARTICIPANT	\N	EXCUSE	0
735369	733756	19735D	PARTICIPANT	\N	EXCUSE	0
715140	714821	20914V	PARTICIPANT	\N	PRESENT	0
715142	714821	19820Y	PARTICIPANT	\N	PRESENT	0
715143	714821	05012A	PARTICIPANT	\N	PRESENT	0
718760	718759	11026G	PARTICIPANT	\N	PRESENT	0
715178	714821	20094J	PARTICIPANT	\N	PRESENT	0
715214	714821	20070A	PARTICIPANT	\N	PRESENT	0
718761	718759	08018U	PARTICIPANT	\N	PRESENT	0
718764	718762	20058E	PARTICIPANT	\N	PRESENT	1
718765	718762	19758L	PARTICIPANT	\N	PRESENT	1
718766	718763	19758L	PARTICIPANT	\N	PRESENT	1
718767	718763	20058E	PARTICIPANT	\N	PRESENT	1
718789	718788	14123H	PARTICIPANT	\N	PRESENT	1
718790	718788	19643A	PARTICIPANT	\N	PRESENT	1
718791	718788	14030Q	PARTICIPANT	\N	PRESENT	1
718792	718788	14109K	PARTICIPANT	\N	PRESENT	1
718793	718788	20980G	PARTICIPANT	\N	PRESENT	1
718794	718788	14229S	PARTICIPANT	\N	PRESENT	1
718796	718795	14123H	PARTICIPANT	\N	PRESENT	1
718797	718795	14030Q	PARTICIPANT	\N	PRESENT	1
718798	718795	14229S	PARTICIPANT	\N	PRESENT	1
718799	718795	20980G	PARTICIPANT	\N	PRESENT	1
718800	716529	14281W	PARTICIPANT	\N	PRESENT	0
719361	719351	11053K	PARTICIPANT	\N	PRESENT	0
719365	719351	20180F	PARTICIPANT	\N	PRESENT	0
719363	719351	14357A	PARTICIPANT	\N	PRESENT	0
719364	719351	20084G	PARTICIPANT	\N	PRESENT	0
719366	719351	20092G	PARTICIPANT	\N	PRESENT	0
719368	719367	11053K	PARTICIPANT	\N	PRESENT	0
719369	719367	14357A	PARTICIPANT	\N	PRESENT	0
719370	719367	20084G	PARTICIPANT	\N	PRESENT	0
719371	719367	20180F	PARTICIPANT	\N	PRESENT	0
719382	719380	11053K	PARTICIPANT	\N	PRESENT	0
719393	719392	11053K	PARTICIPANT	\N	PRESENT	0
719394	719392	19251M	PARTICIPANT	\N	PRESENT	1
719395	719392	11097X	PARTICIPANT	\N	PRESENT	1
719396	719392	19782L	PARTICIPANT	\N	PRESENT	1
719397	719392	20180F	PARTICIPANT	\N	PRESENT	1
719479	717744	19387D	PARTICIPANT	\N	PRESENT	0
719480	717744	20046A	PARTICIPANT	\N	PRESENT	0
719481	717744	19820Y	PARTICIPANT	\N	PRESENT	0
719482	717744	05012A	PRESIDENT	0	PRESENT	0
719496	717744	20914V	PARTICIPANT	\N	PRESENT	0
719505	717744	20094J	PARTICIPANT	\N	PRESENT	0
719506	717744	20070A	PARTICIPANT	\N	PRESENT	0
720245	718758	14030Q	PRESIDENT	0	PRESENT	0
720246	718758	19715Y	PARTICIPANT	\N	PRESENT	0
720247	718758	20024T	PARTICIPANT	\N	PRESENT	0
720248	718758	14189C	PARTICIPANT	\N	PRESENT	0
720249	718758	20098N	PARTICIPANT	\N	PRESENT	0
720250	718758	19319Q	PARTICIPANT	\N	PRESENT	0
720251	718758	20016T	PARTICIPANT	\N	PRESENT	0
720252	718758	19717B	PARTICIPANT	\N	PRESENT	1
720261	718758	19798U	PARTICIPANT	\N	EXCUSE	0
720262	718758	20118Y	PARTICIPANT	\N	EXCUSE	0
720263	718758	07029T	PARTICIPANT	\N	EXCUSE	0
721121	721120	19575F	PARTICIPANT	\N	PRESENT	0
721122	721120	17367Q	PARTICIPANT	\N	PRESENT	0
721123	721120	14083S	PARTICIPANT	\N	PRESENT	0
721124	721120	19721W	PARTICIPANT	\N	PRESENT	0
721125	721120	20144B	PARTICIPANT	\N	PRESENT	0
721126	721120	19681G	PARTICIPANT	\N	PRESENT	0
721127	721120	01024M	PARTICIPANT	\N	PRESENT	0
721128	721120	19820Y	PARTICIPANT	\N	PRESENT	0
721129	721120	14033T	PARTICIPANT	\N	PRESENT	0
721130	721120	19333N	PARTICIPANT	\N	PRESENT	0
721131	721120	20126Y	PARTICIPANT	\N	PRESENT	0
721132	721120	14031R	PARTICIPANT	\N	PRESENT	0
721133	721120	19563B	PARTICIPANT	\N	PRESENT	0
721134	721120	20018V	PARTICIPANT	\N	PRESENT	0
721135	721120	19369B	PARTICIPANT	\N	PRESENT	0
721142	721120	14071N	PARTICIPANT	\N	PRESENT	0
721143	721120	19619A	PARTICIPANT	\N	PRESENT	0
721144	721120	20092G	PARTICIPANT	\N	PRESENT	0
724706	722795	95063L	PARTICIPANT	\N	PRESENT	0
725197	722800	99004R	PARTICIPANT	\N	PRESENT	0
725198	722800	19713W	PARTICIPANT	\N	PRESENT	0
725199	722800	20092G	PARTICIPANT	\N	PRESENT	0
725200	722800	11110B	PARTICIPANT	\N	PRESENT	0
725244	722800	20024T	PARTICIPANT	\N	PRESENT	0
725245	722800	14191V	PARTICIPANT	\N	PRESENT	0
725247	722800	20090E	PARTICIPANT	\N	PRESENT	0
725248	725246	18083K	PARTICIPANT	\N	PRESENT	0
725249	725246	14187A	PRESIDENT	0	PRESENT	0
725250	725246	19347U	PARTICIPANT	\N	PRESENT	0
725251	725246	19525U	PARTICIPANT	\N	PRESENT	0
725252	725246	19701S	PARTICIPANT	\N	EXCUSE	0
725253	725246	20286Q	PARTICIPANT	\N	EXCUSE	0
725254	725246	19681G	PARTICIPANT	\N	EXCUSE	0
725255	725246	17023S	PARTICIPANT	\N	EXCUSE	0
725256	722800	14083S	PARTICIPANT	\N	PRESENT	0
725257	722800	19301E	PARTICIPANT	\N	PRESENT	0
725258	722800	19768N	PARTICIPANT	\N	PRESENT	0
725259	725246	20124W	PARTICIPANT	\N	PRESENT	0
725260	722800	19479G	PARTICIPANT	\N	PRESENT	0
725261	725246	20298U	PARTICIPANT	\N	PRESENT	0
725262	722800	14071N	PARTICIPANT	\N	PRESENT	0
725263	722800	19820Y	PARTICIPANT	\N	PRESENT	0
725264	722800	20080C	PARTICIPANT	\N	PRESENT	0
725265	722800	19693L	PARTICIPANT	\N	PRESENT	0
725266	722800	19954N	PARTICIPANT	\N	PRESENT	0
725267	722800	18083K	PARTICIPANT	\N	PRESENT	0
725268	725246	20090E	PARTICIPANT	\N	PRESENT	0
725274	722800	04045F	PARTICIPANT	\N	PRESENT	0
725275	722800	20098N	PARTICIPANT	\N	PRESENT	0
725276	722800	19525U	PARTICIPANT	\N	PRESENT	0
725277	722800	14030Q	PARTICIPANT	\N	PRESENT	0
725278	722800	08073C	PARTICIPANT	\N	PRESENT	0
725279	722800	20108W	PARTICIPANT	\N	PRESENT	0
725280	722800	19441R	PARTICIPANT	\N	PRESENT	0
725281	722800	20298U	PARTICIPANT	\N	PRESENT	0
725282	722768	04070G	PARTICIPANT	\N	PRESENT	0
725283	722768	20060X	PARTICIPANT	\N	PRESENT	0
725284	722768	19711U	PARTICIPANT	\N	PRESENT	0
725285	722768	11083R	PARTICIPANT	\N	PRESENT	0
725319	722800	14073Q	PARTICIPANT	\N	PRESENT	0
725287	722768	20152B	PARTICIPANT	\N	PRESENT	0
725288	722768	20064C	PARTICIPANT	\N	EXCUSE	0
725289	722800	01058X	PARTICIPANT	\N	PRESENT	0
725290	722800	14237S	PARTICIPANT	\N	PRESENT	0
725291	722800	14205J	PARTICIPANT	\N	PRESENT	0
725292	725233	14331P	PARTICIPANT	\N	PRESENT	0
725293	725233	04070G	PARTICIPANT	\N	PRESENT	0
725294	725233	14133K	PARTICIPANT	\N	PRESENT	0
725295	725233	14073Q	PARTICIPANT	\N	PRESENT	0
725296	725233	01058X	PARTICIPANT	\N	PRESENT	0
725297	725233	19441R	PARTICIPANT	\N	PRESENT	0
725298	725233	14001X	PARTICIPANT	\N	PRESENT	0
725299	725233	04042C	PRESIDENT	0	PRESENT	0
725300	725233	14169X	PARTICIPANT	\N	PRESENT	0
725301	725233	20100N	PARTICIPANT	\N	PRESENT	0
725302	725233	14237S	PARTICIPANT	\N	PRESENT	0
725303	725233	11083R	PARTICIPANT	\N	PRESENT	0
725304	725233	97011G	PARTICIPANT	\N	PRESENT	0
725305	725233	04035D	PARTICIPANT	\N	EXCUSE	0
725306	725233	01062T	PARTICIPANT	\N	EXCUSE	0
725307	725233	11041F	PARTICIPANT	\N	EXCUSE	0
725308	725233	19421M	PARTICIPANT	\N	EXCUSE	0
725309	725233	07033P	PARTICIPANT	\N	EXCUSE	0
725310	725233	14249W	PARTICIPANT	\N	EXCUSE	0
725311	725233	17023S	PARTICIPANT	\N	EXCUSE	0
725312	722800	20124W	PARTICIPANT	\N	PRESENT	0
725313	722800	14169X	PARTICIPANT	\N	PRESENT	0
725314	722768	20068G	PARTICIPANT	\N	PRESENT	0
725315	722768	14030Q	PARTICIPANT	\N	PRESENT	0
725316	722768	17737W	PARTICIPANT	\N	EXCUSE	0
725317	722768	14147R	PARTICIPANT	\N	EXCUSE	0
725318	722768	14251Q	PARTICIPANT	\N	PRESENT	0
729096	728176	10006L	PRESIDENT	0	PRESENT	0
729097	728176	19683J	PARTICIPANT	\N	PRESENT	0
729098	728176	11067R	PARTICIPANT	\N	PRESENT	0
729099	728176	14195A	PARTICIPANT	\N	PRESENT	0
729100	728176	19760E	PARTICIPANT	\N	PRESENT	0
729101	728176	19691J	PARTICIPANT	\N	PRESENT	0
729102	728176	19798U	PARTICIPANT	\N	PRESENT	0
729103	728176	14355X	PARTICIPANT	\N	PRESENT	0
729104	728176	14223L	PARTICIPANT	\N	PRESENT	0
729105	728176	19415P	PARTICIPANT	\N	PRESENT	0
729106	728176	14071N	PARTICIPANT	\N	PRESENT	0
729107	728176	14217N	PARTICIPANT	\N	PRESENT	0
729108	728176	19511N	PARTICIPANT	\N	PRESENT	0
729109	728176	04092N	PARTICIPANT	\N	PRESENT	0
729110	728176	19703U	PARTICIPANT	\N	PRESENT	0
714414	714413	86034E	PARTICIPANT	\N	PRESENT	0
714415	714413	04085P	PARTICIPANT	\N	PRESENT	0
714416	714413	20076G	PARTICIPANT	\N	PRESENT	0
714417	714413	05008E	PARTICIPANT	\N	PRESENT	0
714418	714413	04047H	PARTICIPANT	\N	PRESENT	0
714419	714413	04042C	PARTICIPANT	\N	PRESENT	0
714421	714413	11070L	PARTICIPANT	\N	PRESENT	0
714422	714413	19719D	PARTICIPANT	\N	PRESENT	0
714423	714413	10006L	PARTICIPANT	\N	PRESENT	0
714424	714413	14042U	PARTICIPANT	\N	PRESENT	0
714425	714413	19347U	PARTICIPANT	\N	PRESENT	0
714426	714413	14026U	PARTICIPANT	\N	PRESENT	0
714427	714413	14021P	PARTICIPANT	\N	PRESENT	0
714428	714413	99004R	PARTICIPANT	\N	PRESENT	0
714429	714413	19611R	PARTICIPANT	\N	PRESENT	0
714430	714413	12041X	PARTICIPANT	\N	PRESENT	0
714431	714413	14219Q	PARTICIPANT	\N	PRESENT	0
714432	714413	14251Q	PARTICIPANT	\N	PRESENT	0
714434	714413	11085T	PARTICIPANT	\N	PRESENT	0
714436	714413	01060R	PARTICIPANT	\N	PRESENT	0
714437	714413	08061X	PARTICIPANT	\N	PRESENT	0
714438	714413	11090Q	PARTICIPANT	\N	PRESENT	0
714439	714413	14331P	PARTICIPANT	\N	PRESENT	0
714442	714413	14225N	PARTICIPANT	\N	PRESENT	0
714443	714413	11012A	PARTICIPANT	\N	PRESENT	0
714444	714413	04033B	PARTICIPANT	\N	PRESENT	0
714447	714413	95063L	PARTICIPANT	\N	PRESENT	0
714448	714413	11045K	PARTICIPANT	\N	PRESENT	0
717167	716730	08010L	PARTICIPANT	\N	PRESENT	0
719472	718393	19295A	PARTICIPANT	\N	EXCUSE	0
719473	718395	19295A	PARTICIPANT	\N	EXCUSE	0
719474	718374	11031D	PARTICIPANT	\N	PRESENT	0
719475	718374	20126Y	PARTICIPANT	\N	PRESENT	0
719476	718374	19735D	PRESIDENT	0	PRESENT	0
719477	718374	20066E	PARTICIPANT	\N	PRESENT	0
719478	718374	20096L	PARTICIPANT	\N	PRESENT	0
719788	718374	20050V	PARTICIPANT	\N	EXCUSE	0
719789	718374	04045F	PARTICIPANT	\N	EXCUSE	0
719790	718374	20138D	PARTICIPANT	\N	EXCUSE	0
719798	718374	14026U	PARTICIPANT	\N	PRESENT	0
725919	722794	11066Q	PARTICIPANT	\N	PRESENT	0
733003	732893	20042V	PARTICIPANT	\N	PRESENT	0
733004	732893	20146D	PARTICIPANT	\N	PRESENT	0
733005	732893	04092N	PARTICIPANT	\N	PRESENT	0
733006	732893	19637C	PARTICIPANT	\N	PRESENT	0
733007	732893	19563B	PARTICIPANT	\N	PRESENT	0
733008	732893	20132W	PARTICIPANT	\N	PRESENT	0
733009	732893	20092G	PARTICIPANT	\N	PRESENT	0
733010	732893	14331P	PARTICIPANT	\N	PRESENT	0
733011	732893	11090Q	PARTICIPANT	\N	PRESENT	0
733012	732893	19569H	PARTICIPANT	\N	PRESENT	0
733013	732893	20020P	PARTICIPANT	\N	PRESENT	0
733014	732893	19687N	PARTICIPANT	\N	PRESENT	0
733015	732893	11043H	PARTICIPANT	\N	PRESENT	0
733016	732893	11031D	PARTICIPANT	\N	PRESENT	0
733017	732893	19760E	PARTICIPANT	\N	PRESENT	0
733018	732893	19679N	PARTICIPANT	\N	PRESENT	0
733019	732893	11077T	PARTICIPANT	\N	PRESENT	0
733020	732893	19593H	PARTICIPANT	\N	PRESENT	0
733021	732893	19621T	PARTICIPANT	\N	PRESENT	0
733022	732893	20046A	PARTICIPANT	\N	PRESENT	0
733023	732893	20102Q	PARTICIPANT	\N	PRESENT	0
733024	732893	19489J	PARTICIPANT	\N	PRESENT	0
733025	732893	19599P	PARTICIPANT	\N	PRESENT	0
733026	732893	19715Y	PARTICIPANT	\N	PRESENT	0
733027	732893	20034V	PARTICIPANT	\N	PRESENT	0
733028	732893	11074Q	PARTICIPANT	\N	PRESENT	0
733029	732893	12016W	PARTICIPANT	\N	PRESENT	0
733030	732893	20060X	PARTICIPANT	\N	PRESENT	0
733031	732893	11027H	PARTICIPANT	\N	PRESENT	0
733032	732893	19549D	PARTICIPANT	\N	PRESENT	0
733033	732893	20264J	PARTICIPANT	\N	PRESENT	0
733034	732893	19251M	PARTICIPANT	\N	PRESENT	0
733035	732893	17367Q	PARTICIPANT	\N	PRESENT	0
733036	732893	20078J	PARTICIPANT	\N	PRESENT	0
733037	732893	20076G	PARTICIPANT	\N	PRESENT	0
733038	732893	18083K	PARTICIPANT	\N	PRESENT	0
733039	732893	01048V	PARTICIPANT	\N	PRESENT	0
733040	732893	20070A	PARTICIPANT	\N	PRESENT	0
733041	732893	14123H	PARTICIPANT	\N	PRESENT	0
733042	732893	14133K	PARTICIPANT	\N	PRESENT	0
733043	732893	04047H	PARTICIPANT	\N	PRESENT	0
733044	732893	19703U	PARTICIPANT	\N	PRESENT	0
733045	732893	11110B	PARTICIPANT	\N	PRESENT	0
733046	732893	14215L	PARTICIPANT	\N	PRESENT	0
733047	732893	19820Y	PARTICIPANT	\N	PRESENT	0
733048	732893	04043D	PARTICIPANT	\N	PRESENT	0
733049	732893	19725B	PARTICIPANT	\N	PRESENT	0
733050	732893	10015M	PARTICIPANT	\N	PRESENT	0
733051	732893	19333N	PARTICIPANT	\N	PRESENT	0
733052	732893	14021P	PARTICIPANT	\N	PRESENT	0
733053	732893	19515S	PARTICIPANT	\N	PRESENT	0
733054	732893	19649G	PARTICIPANT	\N	PRESENT	0
733055	732893	04035D	PARTICIPANT	\N	PRESENT	0
733056	732893	19575F	PARTICIPANT	\N	PRESENT	0
733057	732893	08012N	PARTICIPANT	\N	PRESENT	0
733058	732893	99004R	PARTICIPANT	\N	PRESENT	0
733059	732893	17779H	PARTICIPANT	\N	PRESENT	0
733060	732893	11104D	PARTICIPANT	\N	PRESENT	0
733061	732893	04059M	PARTICIPANT	\N	PRESENT	0
733062	732893	11067R	PARTICIPANT	\N	PRESENT	0
733063	732893	20018V	PARTICIPANT	\N	PRESENT	0
733064	732893	14109K	PARTICIPANT	\N	PRESENT	0
733065	732893	20030R	PARTICIPANT	\N	PRESENT	0
733066	732893	17965H	PARTICIPANT	\N	PRESENT	0
733067	732893	19503N	PARTICIPANT	\N	PRESENT	0
733068	732893	20082E	PARTICIPANT	\N	PRESENT	0
733069	732893	11054L	PARTICIPANT	\N	PRESENT	0
733070	732893	11097X	PARTICIPANT	\N	PRESENT	0
733071	732893	14237S	PARTICIPANT	\N	PRESENT	0
733072	732893	19413M	PARTICIPANT	\N	PRESENT	0
733073	732893	01062T	PARTICIPANT	\N	PRESENT	0
733074	732893	20064C	PARTICIPANT	\N	PRESENT	0
733075	732893	05012A	PARTICIPANT	\N	PRESENT	0
733076	732893	19527W	PARTICIPANT	\N	PRESENT	0
733077	732893	01057W	PARTICIPANT	\N	PRESENT	0
733078	732893	08060W	PARTICIPANT	\N	PRESENT	0
733079	732893	19421M	PARTICIPANT	\N	PRESENT	0
733080	732893	19766L	PARTICIPANT	\N	PRESENT	0
733081	732893	20134Y	PARTICIPANT	\N	PRESENT	0
733082	732893	20100N	PARTICIPANT	\N	PRESENT	0
733083	732893	19347U	PARTICIPANT	\N	PRESENT	0
733084	732893	20038A	PARTICIPANT	\N	PRESENT	0
733085	732893	19673G	PARTICIPANT	\N	PRESENT	0
733086	732893	19667J	PARTICIPANT	\N	PRESENT	0
733087	732893	20032T	PARTICIPANT	\N	PRESENT	0
733088	732893	20130U	PARTICIPANT	\N	PRESENT	0
733089	732893	19533U	PARTICIPANT	\N	PRESENT	0
733090	732893	20054A	PARTICIPANT	\N	PRESENT	0
733091	732893	20142Y	PARTICIPANT	\N	PRESENT	0
733092	732893	20252E	PARTICIPANT	\N	PRESENT	0
733093	732893	20126Y	PARTICIPANT	\N	PRESENT	0
733094	732893	20120S	PARTICIPANT	\N	PRESENT	0
733095	732893	19659J	PARTICIPANT	\N	PRESENT	0
733096	732893	14193X	PARTICIPANT	\N	PRESENT	0
733097	732893	07033P	PARTICIPANT	\N	PRESENT	0
733098	732893	19329S	PARTICIPANT	\N	PRESENT	0
733099	732893	97011G	PARTICIPANT	\N	PRESENT	0
733100	732893	08061X	PARTICIPANT	\N	PRESENT	0
733101	732893	19349W	PARTICIPANT	\N	PRESENT	0
733102	732893	95063L	PARTICIPANT	\N	PRESENT	0
733103	732893	20138D	PARTICIPANT	\N	PRESENT	0
733104	732893	20150Y	PARTICIPANT	\N	PRESENT	0
733105	732893	11072N	PARTICIPANT	\N	PRESENT	0
733106	732893	08011M	PARTICIPANT	\N	PRESENT	0
733107	732893	14187A	PARTICIPANT	\N	PRESENT	0
733108	732893	14055N	PARTICIPANT	\N	PRESENT	0
733109	732893	20140W	PARTICIPANT	\N	PRESENT	0
733110	732893	20094J	PARTICIPANT	\N	PRESENT	0
733111	732893	20084G	PARTICIPANT	\N	PRESENT	0
733112	732893	11080N	PARTICIPANT	\N	PRESENT	0
733113	732893	20980G	PARTICIPANT	\N	PRESENT	0
733114	732893	19531S	PARTICIPANT	\N	PRESENT	0
733115	732893	19683J	PARTICIPANT	\N	PRESENT	0
733116	732893	14038Y	PARTICIPANT	\N	PRESENT	0
733117	732893	19723Y	PARTICIPANT	\N	PRESENT	0
733118	732893	20056C	PARTICIPANT	\N	PRESENT	0
733119	732893	20106U	PARTICIPANT	\N	PRESENT	0
733120	732893	20128B	PARTICIPANT	\N	PRESENT	0
733121	732893	19591F	PARTICIPANT	\N	PRESENT	0
733122	732893	19399H	PARTICIPANT	\N	PRESENT	0
719885	719383	14030Q	PRESIDENT	0	PRESENT	0
719886	719383	19749K	PARTICIPANT	\N	PRESENT	0
719887	719383	19798U	PARTICIPANT	\N	PRESENT	0
719889	719383	11045K	PARTICIPANT	\N	PRESENT	0
719892	719383	19715Y	PARTICIPANT	\N	PRESENT	0
719893	719383	20066E	PARTICIPANT	\N	PRESENT	0
720407	720095	19741B	PARTICIPANT	\N	PRESENT	0
720408	720095	14121F	PARTICIPANT	\N	PRESENT	0
720409	720095	19479G	PARTICIPANT	\N	PRESENT	0
720410	720095	19709B	PARTICIPANT	\N	PRESENT	0
720411	720095	07004J	PARTICIPANT	\N	PRESENT	0
720412	720095	08018U	PARTICIPANT	\N	PRESENT	0
720415	720095	14225N	PARTICIPANT	\N	PRESENT	0
720416	720095	01060R	PARTICIPANT	\N	PRESENT	0
720417	701182	20090E	PARTICIPANT	\N	PRESENT	0
720418	701182	16685X	PARTICIPANT	\N	PRESENT	0
720419	720095	19766L	PARTICIPANT	\N	PRESENT	0
720420	720095	20040T	PARTICIPANT	\N	PRESENT	0
720421	720095	19583F	PARTICIPANT	\N	PRESENT	0
720422	720095	14037X	PARTICIPANT	\N	PRESENT	0
720423	720095	19057M	PARTICIPANT	\N	PRESENT	0
720424	720095	11026G	PARTICIPANT	\N	PRESENT	0
720425	720095	19647E	PARTICIPANT	\N	PRESENT	0
720426	720095	20266L	PARTICIPANT	\N	PRESENT	0
720427	720095	08028W	PARTICIPANT	\N	PRESENT	0
720428	701182	14097Y	PARTICIPANT	\N	PRESENT	0
720431	720095	14207L	PARTICIPANT	\N	PRESENT	0
720432	720095	19687N	PARTICIPANT	\N	PRESENT	0
720433	720095	20172F	PARTICIPANT	\N	PRESENT	0
720435	720095	08056B	PARTICIPANT	\N	PRESENT	0
720437	720095	19507S	PARTICIPANT	\N	PRESENT	0
720438	720095	20062A	PARTICIPANT	\N	PRESENT	0
720439	720095	20914V	PARTICIPANT	\N	PRESENT	0
720440	720095	14038Y	PARTICIPANT	\N	PRESENT	0
720441	720095	20080C	PARTICIPANT	\N	PRESENT	0
720442	720095	20090E	PARTICIPANT	\N	PRESENT	0
720443	720095	19383Y	PARTICIPANT	\N	PRESENT	0
720444	720095	20032T	PARTICIPANT	\N	PRESENT	0
720445	720095	19705W	PARTICIPANT	\N	PRESENT	0
720446	720095	19691J	PARTICIPANT	\N	PRESENT	0
720447	720095	19798U	PARTICIPANT	\N	PRESENT	0
720448	720095	08010L	PARTICIPANT	\N	PRESENT	0
720449	720095	14223L	PARTICIPANT	\N	PRESENT	0
720450	720095	20026V	PARTICIPANT	\N	PRESENT	0
720451	720095	01024M	PARTICIPANT	\N	PRESENT	0
720452	720095	04043D	PARTICIPANT	\N	PRESENT	0
720453	720095	14251Q	PARTICIPANT	\N	PRESENT	0
720454	720095	14133K	PARTICIPANT	\N	PRESENT	0
720455	720095	19747H	PARTICIPANT	\N	PRESENT	0
720456	720095	20076G	PARTICIPANT	\N	PRESENT	0
720457	720095	20252E	PARTICIPANT	\N	PRESENT	0
720459	720095	14147R	PARTICIPANT	\N	PRESENT	0
720461	720095	14259Y	PARTICIPANT	\N	PRESENT	0
720465	720095	19447X	PARTICIPANT	\N	PRESENT	0
720463	720095	20022R	PARTICIPANT	\N	PRESENT	0
720464	720095	20044X	PARTICIPANT	\N	PRESENT	0
720466	720095	11048N	PARTICIPANT	\N	PRESENT	0
720467	720095	11012A	PARTICIPANT	\N	PRESENT	0
720469	720095	08045X	PARTICIPANT	\N	PRESENT	0
720471	720095	19782L	PARTICIPANT	\N	PRESENT	0
720472	720095	20264J	PARTICIPANT	\N	PRESENT	0
720473	720095	14205J	PARTICIPANT	\N	PRESENT	0
720474	720095	20054A	PARTICIPANT	\N	PRESENT	0
720475	720095	14189C	PARTICIPANT	\N	PRESENT	0
720476	720095	14107H	PARTICIPANT	\N	PRESENT	0
720477	720095	19826F	PARTICIPANT	\N	PRESENT	0
720482	720095	19745F	PARTICIPANT	\N	PRESENT	0
720479	720095	19367Y	PARTICIPANT	\N	PRESENT	0
720480	720095	19349W	PARTICIPANT	\N	PRESENT	0
720481	720095	20112S	PARTICIPANT	\N	PRESENT	0
720483	720095	14069U	PARTICIPANT	\N	PRESENT	0
720484	720095	19525U	PARTICIPANT	\N	PRESENT	0
720485	720095	99004R	PARTICIPANT	\N	PRESENT	0
720486	720095	14053L	PARTICIPANT	\N	PRESENT	0
720487	720095	14030Q	PARTICIPANT	\N	PRESENT	0
720489	720095	14215L	PARTICIPANT	\N	PRESENT	0
720490	720095	19762G	PARTICIPANT	\N	PRESENT	0
720491	720095	20048C	PARTICIPANT	\N	PRESENT	0
720492	720095	20036X	PARTICIPANT	\N	PRESENT	0
720493	720095	18083K	PARTICIPANT	\N	PRESENT	0
720494	720095	04057K	PARTICIPANT	\N	PRESENT	0
720495	720095	20024T	PARTICIPANT	\N	PRESENT	0
720496	720095	14031R	PARTICIPANT	\N	PRESENT	0
720497	720095	20098N	PARTICIPANT	\N	PRESENT	0
720498	720095	19683J	PARTICIPANT	\N	PRESENT	0
720499	720095	19549D	PARTICIPANT	\N	PRESENT	0
720500	720095	14059S	PARTICIPANT	\N	PRESENT	0
720501	720095	19719D	PARTICIPANT	\N	PRESENT	0
720511	720095	19467C	PARTICIPANT	\N	PRESENT	0
720514	720095	98022P	PARTICIPANT	\N	PRESENT	0
720516	720095	14217N	PARTICIPANT	\N	PRESENT	0
720517	720095	20020P	PARTICIPANT	\N	PRESENT	0
720518	720095	19631V	PARTICIPANT	\N	PRESENT	0
720519	720095	19711U	PARTICIPANT	\N	PRESENT	0
720520	720095	11090Q	PARTICIPANT	\N	PRESENT	0
720523	720095	14169X	PARTICIPANT	\N	PRESENT	0
720524	720095	14097Y	PARTICIPANT	\N	PRESENT	0
720528	720095	20088L	PARTICIPANT	\N	PRESENT	0
720533	720095	20050V	PARTICIPANT	\N	PRESENT	0
720534	720095	05012A	PARTICIPANT	\N	PRESENT	0
720535	720095	19369B	PARTICIPANT	\N	PRESENT	0
720536	720095	20072C	PARTICIPANT	\N	PRESENT	0
720537	720095	14111D	PARTICIPANT	\N	PRESENT	0
720538	720095	14179A	PARTICIPANT	\N	PRESENT	0
720539	720095	14219Q	PARTICIPANT	\N	PRESENT	0
720540	720095	01058X	PARTICIPANT	\N	PRESENT	0
720541	720095	20056C	PARTICIPANT	\N	PRESENT	0
720542	720095	20078J	PARTICIPANT	\N	PRESENT	0
720543	720095	20138D	PARTICIPANT	\N	PRESENT	0
720544	720095	17737W	PARTICIPANT	\N	PRESENT	0
720549	720095	19387D	PARTICIPANT	\N	PRESENT	0
720550	720095	19713W	PARTICIPANT	\N	PRESENT	0
720551	720095	19563B	PARTICIPANT	\N	PRESENT	0
720552	720522	11097X	PARTICIPANT	\N	PRESENT	0
720553	720095	01057W	PARTICIPANT	\N	PRESENT	0
720554	720522	19251M	PRESIDENT	0	PRESENT	0
720555	720522	17229F	PARTICIPANT	\N	PRESENT	0
720556	720522	20084G	PARTICIPANT	\N	PRESENT	0
720557	720095	20064C	PARTICIPANT	\N	PRESENT	0
720558	720095	20142Y	PARTICIPANT	\N	PRESENT	0
720559	720522	14357A	PRESIDENT	1	PRESENT	0
720560	720095	14213J	PARTICIPANT	\N	PRESENT	0
720561	720095	19347U	PARTICIPANT	\N	PRESENT	0
720562	719950	20132W	PARTICIPANT	\N	PRESENT	0
720563	719950	20038A	PARTICIPANT	\N	PRESENT	0
720564	719950	20980G	PARTICIPANT	\N	PRESENT	0
720565	719950	19758L	PARTICIPANT	\N	PRESENT	0
720566	720095	20046A	PARTICIPANT	\N	PRESENT	0
720567	720095	20030R	PARTICIPANT	\N	PRESENT	0
720568	720522	20102Q	PARTICIPANT	\N	PRESENT	0
720569	720522	19762G	PARTICIPANT	\N	PRESENT	0
720570	720522	20052X	PARTICIPANT	\N	PRESENT	0
720571	720522	19713W	PARTICIPANT	\N	PRESENT	0
720572	720095	16685X	PARTICIPANT	\N	PRESENT	0
720573	720095	19725B	PARTICIPANT	\N	PRESENT	0
720574	720095	14221J	PARTICIPANT	\N	PRESENT	0
720575	720095	20124W	PARTICIPANT	\N	PRESENT	0
720576	720095	14109K	PARTICIPANT	\N	PRESENT	0
720577	720095	19703U	PARTICIPANT	\N	PRESENT	0
712543	712542	14205J	PARTICIPANT	\N	PRESENT	1
712544	712542	20026V	PARTICIPANT	\N	PRESENT	0
712545	712542	20090E	PARTICIPANT	\N	PRESENT	0
712546	712542	20046A	PARTICIPANT	\N	PRESENT	0
712547	712542	14097Y	PARTICIPANT	\N	PRESENT	0
712550	712549	14205J	PARTICIPANT	\N	PRESENT	1
712551	712549	20026V	PARTICIPANT	\N	PRESENT	0
712552	712549	20090E	PARTICIPANT	\N	PRESENT	0
712553	712549	20046A	PARTICIPANT	\N	PRESENT	0
712554	712549	14097Y	PARTICIPANT	\N	PRESENT	0
720377	720374	20050V	PARTICIPANT	\N	PRESENT	0
720391	720390	14331P	PARTICIPANT	\N	PRESENT	0
720402	720401	14331P	PARTICIPANT	\N	PRESENT	0
720404	720403	14331P	PARTICIPANT	\N	PRESENT	0
720406	720405	20050V	PARTICIPANT	\N	PRESENT	0
720414	720413	01048V	PARTICIPANT	\N	PRESENT	0
720525	720521	14030Q	PARTICIPANT	\N	PRESENT	0
720526	720521	19715Y	PARTICIPANT	\N	PRESENT	0
720527	720521	20098N	PARTICIPANT	\N	PRESENT	0
725960	725810	14331P	PARTICIPANT	\N	EXCUSE	0
725962	725810	05008E	PARTICIPANT	\N	EXCUSE	0
725963	725810	11043H	PARTICIPANT	\N	EXCUSE	0
725964	725810	19673G	PARTICIPANT	\N	EXCUSE	0
725966	725965	20138D	PARTICIPANT	\N	PRESENT	1
725967	725965	19693L	PARTICIPANT	\N	PRESENT	1
725968	725965	20152B	PARTICIPANT	\N	PRESENT	1
730484	728178	19643A	PARTICIPANT	\N	PRESENT	0
730485	728178	04070G	PARTICIPANT	\N	PRESENT	0
730486	728178	17737W	PARTICIPANT	\N	PRESENT	0
730487	728178	14251Q	PARTICIPANT	\N	PRESENT	0
730488	728178	11045K	PARTICIPANT	\N	PRESENT	0
730489	728178	14147R	PARTICIPANT	\N	PRESENT	0
730490	728178	14030Q	PARTICIPANT	\N	PRESENT	0
730587	730546	20090E	PARTICIPANT	\N	PRESENT	0
730588	730546	14187A	PRESIDENT	0	PRESENT	0
730589	730546	19347U	PARTICIPANT	\N	PRESENT	0
730590	730546	20018V	PARTICIPANT	\N	PRESENT	0
730591	730546	20124W	PARTICIPANT	\N	PRESENT	0
730592	730546	14257W	PARTICIPANT	\N	PRESENT	0
735376	735375	19820Y	PARTICIPANT	\N	PRESENT	0
735377	735375	20914V	PARTICIPANT	\N	PRESENT	0
735379	735378	19820Y	PARTICIPANT	\N	PRESENT	0
735380	735378	20914V	PARTICIPANT	\N	PRESENT	0
735382	735381	14255U	PARTICIPANT	\N	PRESENT	0
735383	735381	11027H	PARTICIPANT	\N	PRESENT	0
735384	735381	19329S	PARTICIPANT	\N	PRESENT	0
735453	735452	05008E	PARTICIPANT	\N	PRESENT	0
735454	735452	11053K	PARTICIPANT	\N	PRESENT	0
735455	735452	11033F	PARTICIPANT	\N	PRESENT	0
735456	735452	14357A	PARTICIPANT	\N	PRESENT	0
735457	735452	11070L	PARTICIPANT	\N	PRESENT	0
735458	735452	19719D	PARTICIPANT	\N	PRESENT	0
735459	735452	19673G	PARTICIPANT	\N	PRESENT	0
735460	735452	14123H	PARTICIPANT	\N	PRESENT	0
735461	735452	14179A	PARTICIPANT	\N	PRESENT	0
735462	735452	14213J	PARTICIPANT	\N	PRESENT	0
735463	735452	14147R	PARTICIPANT	\N	PRESENT	0
735464	735452	99004R	PARTICIPANT	\N	PRESENT	0
735465	735452	86034E	PARTICIPANT	\N	PRESENT	0
735466	735452	12041X	PARTICIPANT	\N	PRESENT	0
735467	735452	95063L	PARTICIPANT	\N	PRESENT	0
735468	735452	11045K	PARTICIPANT	\N	PRESENT	0
735469	735452	01028R	PARTICIPANT	\N	PRESENT	0
735470	735452	14026U	PARTICIPANT	\N	PRESENT	0
735549	735548	19711U	PARTICIPANT	\N	PRESENT	0
735550	735548	20024T	PARTICIPANT	\N	PRESENT	0
735551	735548	14026U	PARTICIPANT	\N	PRESENT	0
735553	735552	14255U	PARTICIPANT	\N	PRESENT	0
735575	735574	20024T	PARTICIPANT	\N	PRESENT	0
735576	735574	20114U	PARTICIPANT	\N	PRESENT	0
735577	735574	01024M	PARTICIPANT	\N	PRESENT	0
735578	735574	14026U	PARTICIPANT	\N	PRESENT	0
735579	735574	19691J	PARTICIPANT	\N	PRESENT	0
735580	735574	19333N	PARTICIPANT	\N	PRESENT	0
735581	735574	14097Y	PARTICIPANT	\N	PRESENT	0
735582	735574	19798U	PARTICIPANT	\N	PRESENT	0
735583	735574	04045F	PARTICIPANT	\N	PRESENT	0
735586	735373	19369B	PARTICIPANT	\N	EXCUSE	0
735587	735373	11031D	PARTICIPANT	\N	PRESENT	0
735588	735373	20126Y	PARTICIPANT	\N	EXCUSE	0
735589	735373	17965H	PARTICIPANT	\N	PRESENT	0
735590	735373	14213J	PARTICIPANT	\N	PRESENT	0
735591	735373	19735D	PRESIDENT	1	PRESENT	0
735592	735373	20138D	PRESIDENT	0	PRESENT	0
735593	735373	20024T	PARTICIPANT	\N	PRESENT	0
735594	735373	20266L	PARTICIPANT	\N	PRESENT	0
735598	735373	14026U	PARTICIPANT	\N	PRESENT	0
735602	735373	20066E	PARTICIPANT	\N	PRESENT	0
735761	735596	14026U	PARTICIPANT	\N	PRESENT	0
735762	735596	14221J	PARTICIPANT	\N	PRESENT	0
735763	735596	04057K	PARTICIPANT	\N	PRESENT	0
735764	735596	01057W	PARTICIPANT	\N	PRESENT	0
735765	735596	19563B	PARTICIPANT	\N	PRESENT	0
735766	735596	20050V	PARTICIPANT	\N	PRESENT	0
735767	735596	20068G	PARTICIPANT	\N	PRESENT	0
735768	735596	19585H	PARTICIPANT	\N	PRESENT	0
735769	735596	20034V	PARTICIPANT	\N	PRESENT	0
735770	735596	20056C	PARTICIPANT	\N	PRESENT	0
735771	735596	19631V	PARTICIPANT	\N	PRESENT	0
735772	735596	04059M	PARTICIPANT	\N	PRESENT	0
735773	735596	99004R	PARTICIPANT	\N	PRESENT	0
735774	735596	19549D	PARTICIPANT	\N	PRESENT	0
735775	735596	20094J	PARTICIPANT	\N	PRESENT	0
735776	735596	08060W	PARTICIPANT	\N	PRESENT	0
735777	735596	07029T	PARTICIPANT	\N	PRESENT	0
735778	735596	20088L	PARTICIPANT	\N	PRESENT	0
735779	735596	19723Y	PARTICIPANT	\N	PRESENT	0
735780	735596	20080C	PARTICIPANT	\N	PRESENT	0
735781	735596	08015R	PARTICIPANT	\N	PRESENT	0
735782	735596	12028B	PARTICIPANT	\N	PRESENT	0
735783	735596	19711U	PARTICIPANT	\N	PRESENT	0
735784	735596	20060X	PARTICIPANT	\N	PRESENT	0
735785	735596	08010L	PARTICIPANT	\N	PRESENT	0
735786	735596	20070A	PARTICIPANT	\N	PRESENT	0
735787	735596	08069G	PARTICIPANT	\N	PRESENT	0
735788	735596	20264J	PARTICIPANT	\N	PRESENT	0
735789	735596	19251M	PARTICIPANT	\N	PRESENT	0
735790	735596	14151M	PARTICIPANT	\N	PRESENT	0
735791	735596	11074Q	PARTICIPANT	\N	PRESENT	0
735792	735596	11110B	PARTICIPANT	\N	PRESENT	0
735793	735596	19647E	PARTICIPANT	\N	PRESENT	0
735794	735596	14281W	PARTICIPANT	\N	PRESENT	0
735795	735596	08045X	PARTICIPANT	\N	PRESENT	0
735796	735596	19709B	PARTICIPANT	\N	PRESENT	0
735797	735596	19599P	PARTICIPANT	\N	PRESENT	0
735798	735596	19820Y	PARTICIPANT	\N	PRESENT	0
735799	735596	19725B	PARTICIPANT	\N	PRESENT	0
735800	735596	08034U	PARTICIPANT	\N	PRESENT	0
735801	735596	19333N	PARTICIPANT	\N	PRESENT	0
735802	735596	14121F	PARTICIPANT	\N	PRESENT	0
735803	735596	19729F	PARTICIPANT	\N	PRESENT	0
735804	735596	19531S	PARTICIPANT	\N	PRESENT	0
735805	735596	19683J	PARTICIPANT	\N	PRESENT	0
735806	735596	19581D	PARTICIPANT	\N	PRESENT	0
735807	735596	14097Y	PARTICIPANT	\N	PRESENT	0
735808	735596	14021P	PARTICIPANT	\N	PRESENT	0
735809	735596	14147R	PARTICIPANT	\N	PRESENT	0
735810	735596	19489J	PARTICIPANT	\N	PRESENT	0
735811	735596	19649G	PARTICIPANT	\N	PRESENT	0
735812	735596	14059S	PARTICIPANT	\N	PRESENT	0
735813	735596	19657G	PARTICIPANT	\N	PRESENT	0
735814	735596	18193Q	PARTICIPANT	\N	PRESENT	0
735815	735596	14031R	PARTICIPANT	\N	PRESENT	0
735816	735596	19671E	PARTICIPANT	\N	PRESENT	0
735817	735596	08012N	PARTICIPANT	\N	PRESENT	0
735818	735596	14223L	PARTICIPANT	\N	PRESENT	0
735819	735596	14071N	PARTICIPANT	\N	PRESENT	0
735820	735596	11104D	PARTICIPANT	\N	PRESENT	0
735821	735596	14169X	PARTICIPANT	\N	PRESENT	0
735822	735596	14001X	PARTICIPANT	\N	PRESENT	0
735823	735596	20028X	PARTICIPANT	\N	PRESENT	0
735824	735596	11067R	PARTICIPANT	\N	PRESENT	0
735825	735596	19768N	PARTICIPANT	\N	PRESENT	0
735826	735596	14253S	PARTICIPANT	\N	PRESENT	0
735827	735596	19573D	PARTICIPANT	\N	PRESENT	0
735828	735596	14109K	PARTICIPANT	\N	PRESENT	0
735829	735596	08047A	PARTICIPANT	\N	PRESENT	0
735830	735596	12041X	PARTICIPANT	\N	PRESENT	0
729113	728176	20090E	PARTICIPANT	\N	PRESENT	0
729114	728176	19553Y	PARTICIPANT	\N	PRESENT	0
729115	728176	14042U	PARTICIPANT	\N	PRESENT	0
729116	728176	20248J	PARTICIPANT	\N	PRESENT	0
729117	728176	20066E	PARTICIPANT	\N	PRESENT	0
729134	728176	11097X	PARTICIPANT	\N	PRESENT	0
729137	728176	14281W	PARTICIPANT	\N	PRESENT	0
729138	728176	11031D	PARTICIPANT	\N	PRESENT	0
729139	728176	19679N	PARTICIPANT	\N	PRESENT	0
729140	728176	04043D	PARTICIPANT	\N	PRESENT	0
729141	728176	19569H	PARTICIPANT	\N	PRESENT	0
729173	728176	17779H	PARTICIPANT	\N	PRESENT	0
729174	728176	19591F	PARTICIPANT	\N	PRESENT	0
729175	728176	14213J	PARTICIPANT	\N	PRESENT	0
729264	728176	19713W	PARTICIPANT	\N	PRESENT	0
729265	728176	01034P	PARTICIPANT	\N	PRESENT	0
729266	728176	14026U	PARTICIPANT	\N	PRESENT	0
729285	728176	04057K	PARTICIPANT	\N	PRESENT	0
729598	728221	20052X	PARTICIPANT	\N	PRESENT	0
729599	728221	19675J	PARTICIPANT	\N	PRESENT	0
729605	728221	19569H	PARTICIPANT	\N	PRESENT	0
729610	728221	20068G	PARTICIPANT	\N	PRESENT	0
729602	728221	14219Q	PARTICIPANT	\N	PRESENT	0
729603	728221	20066E	PARTICIPANT	\N	PRESENT	0
729604	728221	14259Y	PARTICIPANT	\N	PRESENT	0
729606	728221	04059M	PARTICIPANT	\N	PRESENT	0
729607	728221	14207L	PARTICIPANT	\N	PRESENT	0
729608	728221	14223L	PARTICIPANT	\N	PRESENT	0
729609	728221	11043H	PARTICIPANT	\N	PRESENT	0
729611	728221	19387D	PARTICIPANT	\N	PRESENT	0
729612	728221	20102Q	PARTICIPANT	\N	PRESENT	0
729613	728221	14107H	PARTICIPANT	\N	PRESENT	0
729614	728221	19703U	PARTICIPANT	\N	PRESENT	0
729615	728221	11040E	PARTICIPANT	\N	PRESENT	0
729616	728221	11027H	PARTICIPANT	\N	PRESENT	0
729617	728221	19739H	PARTICIPANT	\N	PRESENT	0
729618	728221	14355X	PARTICIPANT	\N	PRESENT	0
729619	728221	19762G	PARTICIPANT	\N	PRESENT	0
729620	728221	18083K	PARTICIPANT	\N	PRESENT	0
729621	728221	20252E	PARTICIPANT	\N	PRESENT	0
729622	728221	19467C	PARTICIPANT	\N	PRESENT	0
729623	728221	14033T	PARTICIPANT	\N	PRESENT	0
729624	728221	20140W	PARTICIPANT	\N	PRESENT	0
729625	728221	11080N	PARTICIPANT	\N	PRESENT	0
729626	728221	19747H	PARTICIPANT	\N	PRESENT	0
729627	728221	20034V	PARTICIPANT	\N	PRESENT	0
729628	728221	14257W	PARTICIPANT	\N	PRESENT	0
729629	728221	14267Y	PARTICIPANT	\N	PRESENT	0
729630	728221	19721W	PARTICIPANT	\N	PRESENT	0
729631	728221	16685X	PARTICIPANT	\N	PRESENT	0
729632	728221	14097Y	PARTICIPANT	\N	PRESENT	0
729635	728221	19719D	PARTICIPANT	\N	PRESENT	0
729641	728221	20266L	PARTICIPANT	\N	PRESENT	0
729642	728221	99004R	PARTICIPANT	\N	PRESENT	0
729643	728221	14001X	PARTICIPANT	\N	PRESENT	0
729644	728221	19489J	PARTICIPANT	\N	PRESENT	0
729645	728221	04092N	PARTICIPANT	\N	PRESENT	0
729646	728221	08060W	PARTICIPANT	\N	PRESENT	0
729647	728221	14059S	PARTICIPANT	\N	PRESENT	0
729648	728221	20074E	PARTICIPANT	\N	PRESENT	0
729649	728221	20064C	PARTICIPANT	\N	PRESENT	0
729650	728221	14133K	PARTICIPANT	\N	PRESENT	0
729651	728221	14229S	PARTICIPANT	\N	PRESENT	0
729652	728221	11099A	PARTICIPANT	\N	PRESENT	0
729653	728221	20142Y	PARTICIPANT	\N	PRESENT	0
729654	728221	11026G	PARTICIPANT	\N	PRESENT	0
729655	728221	12016W	PARTICIPANT	\N	PRESENT	0
729656	728221	19669L	PARTICIPANT	\N	PRESENT	0
729657	728221	20132W	PARTICIPANT	\N	PRESENT	0
729658	728221	19619A	PARTICIPANT	\N	PRESENT	0
729659	728221	19527W	PARTICIPANT	\N	PRESENT	0
729660	728221	12028B	PARTICIPANT	\N	PRESENT	0
729661	728221	20122U	PARTICIPANT	\N	PRESENT	0
729662	728221	20264J	PARTICIPANT	\N	PRESENT	0
729663	728221	19683J	PARTICIPANT	\N	PRESENT	0
729664	728221	19349W	PARTICIPANT	\N	PRESENT	0
729665	728221	19591F	PARTICIPANT	\N	PRESENT	0
729666	728221	20082E	PARTICIPANT	\N	PRESENT	0
729667	728221	14109K	PARTICIPANT	\N	PRESENT	0
729668	728221	20080C	PARTICIPANT	\N	PRESENT	0
729669	728221	19782L	PARTICIPANT	\N	PRESENT	0
729670	728221	11083R	PARTICIPANT	\N	PRESENT	0
729671	728221	08012N	PARTICIPANT	\N	PRESENT	0
729672	728221	14205J	PARTICIPANT	\N	PRESENT	0
729673	728221	19693L	PARTICIPANT	\N	PRESENT	0
729674	728221	01058X	PARTICIPANT	\N	PRESENT	0
729675	728221	04008A	PARTICIPANT	\N	PRESENT	0
729676	728221	19711U	PARTICIPANT	\N	PRESENT	0
729677	728221	19565D	PARTICIPANT	\N	PRESENT	0
729678	728221	11056N	PARTICIPANT	\N	PRESENT	0
729679	728221	19621T	PARTICIPANT	\N	PRESENT	0
729680	728221	19687N	PARTICIPANT	\N	PRESENT	0
729681	728221	20046A	PARTICIPANT	\N	PRESENT	0
729682	728221	11077T	PARTICIPANT	\N	PRESENT	0
729683	728221	12041X	PARTICIPANT	\N	PRESENT	0
729684	728221	19593H	PARTICIPANT	\N	PRESENT	0
729685	728221	04042C	PARTICIPANT	\N	PRESENT	0
729686	728221	19758L	PARTICIPANT	\N	PRESENT	0
729687	728221	14123H	PARTICIPANT	\N	PRESENT	0
729688	728221	20092G	PARTICIPANT	\N	PRESENT	0
729689	728221	20078J	PARTICIPANT	\N	PRESENT	0
729690	728221	14055N	PARTICIPANT	\N	PRESENT	0
729691	728221	19679N	PARTICIPANT	\N	PRESENT	0
729692	728221	19651A	PARTICIPANT	\N	PRESENT	0
729693	728221	17367Q	PARTICIPANT	\N	PRESENT	0
729694	728221	19525U	PARTICIPANT	\N	PRESENT	0
729695	728221	04071H	PARTICIPANT	\N	PRESENT	0
729696	728221	14249W	PARTICIPANT	\N	PRESENT	0
729697	728221	10015M	PARTICIPANT	\N	PRESENT	0
729698	728221	20106U	PARTICIPANT	\N	PRESENT	0
729699	728221	20076G	PARTICIPANT	\N	PRESENT	0
729700	728221	20128B	PARTICIPANT	\N	PRESENT	0
729701	728221	01048V	PARTICIPANT	\N	PRESENT	0
729702	728221	14037X	PARTICIPANT	\N	PRESENT	0
729703	728221	19515S	PARTICIPANT	\N	PRESENT	0
729704	728221	19697Q	PARTICIPANT	\N	PRESENT	0
729705	728221	19637C	PARTICIPANT	\N	PRESENT	0
729706	728221	11072N	PARTICIPANT	\N	PRESENT	0
729707	728221	20146D	PARTICIPANT	\N	PRESENT	0
729708	728221	95063L	PARTICIPANT	\N	PRESENT	0
729709	728221	04045F	PARTICIPANT	\N	PRESENT	0
729710	728221	01057W	PARTICIPANT	\N	PRESENT	0
729711	728221	20022R	PARTICIPANT	\N	PRESENT	0
729712	728221	05012A	PARTICIPANT	\N	PRESENT	0
729713	728221	19545Y	PARTICIPANT	\N	PRESENT	0
729714	728221	11090Q	PARTICIPANT	\N	PRESENT	0
729715	728221	20038A	PARTICIPANT	\N	PRESENT	0
729716	728221	19673G	PARTICIPANT	\N	PRESENT	0
729717	728221	19667J	PARTICIPANT	\N	PRESENT	0
729718	728221	20136B	PARTICIPANT	\N	PRESENT	0
729111	728176	20148F	PARTICIPANT	\N	PRESENT	0
729112	728176	20040T	PARTICIPANT	\N	PRESENT	0
729719	728221	14253S	PARTICIPANT	\N	PRESENT	0
729720	728221	14211G	PARTICIPANT	\N	PRESENT	0
729721	728221	04057K	PARTICIPANT	\N	PRESENT	0
729722	728221	17737W	PARTICIPANT	\N	PRESENT	0
729723	728221	14221J	PARTICIPANT	\N	PRESENT	0
729724	728221	11064N	PARTICIPANT	\N	PRESENT	0
729725	728221	14331P	PARTICIPANT	\N	PRESENT	0
729726	728221	14195A	PARTICIPANT	\N	PRESENT	0
729727	728221	20090E	PARTICIPANT	\N	PRESENT	0
729728	728221	14111D	PARTICIPANT	\N	PRESENT	0
729729	728221	20118Y	PARTICIPANT	\N	PRESENT	0
729730	728221	19563B	PARTICIPANT	\N	PRESENT	0
729731	728221	19533U	PARTICIPANT	\N	PRESENT	0
729732	728221	10006L	PARTICIPANT	\N	PRESENT	0
729733	728221	01060R	PARTICIPANT	\N	PRESENT	0
729734	728221	14173T	PARTICIPANT	\N	PRESENT	0
729735	728221	19447X	PARTICIPANT	\N	PRESENT	0
729736	728221	20980G	PARTICIPANT	\N	PRESENT	0
729737	728221	08069G	PARTICIPANT	\N	PRESENT	0
729738	728221	19629C	PARTICIPANT	\N	PRESENT	0
729739	728221	20180F	PARTICIPANT	\N	PRESENT	0
729740	728221	11012A	PARTICIPANT	\N	PRESENT	0
729741	728221	20130U	PARTICIPANT	\N	PRESENT	0
729742	728221	20138D	PARTICIPANT	\N	PRESENT	0
729743	728221	19329S	PARTICIPANT	\N	PRESENT	0
729744	728221	20172F	PARTICIPANT	\N	PRESENT	0
729745	728221	08011M	PARTICIPANT	\N	PRESENT	0
729746	728221	14147R	PARTICIPANT	\N	PRESENT	0
716223	716222	14069U	PARTICIPANT	\N	PRESENT	0
716150	714405	20152B	PARTICIPANT	\N	PRESENT	0
716151	714405	20134Y	PARTICIPANT	\N	PRESENT	0
716152	714405	11083R	PARTICIPANT	\N	PRESENT	0
716153	714405	20068G	PARTICIPANT	\N	PRESENT	0
716154	714405	19711U	PARTICIPANT	\N	PRESENT	0
716156	714405	14251Q	PARTICIPANT	\N	PRESENT	0
716224	716222	19643A	PARTICIPANT	\N	PRESENT	0
716161	714405	20064C	PRESIDENT	0	PRESENT	0
716225	716222	17737W	PARTICIPANT	\N	PRESENT	0
716226	716222	20248J	PARTICIPANT	\N	PRESENT	0
716227	716222	19713W	PARTICIPANT	\N	PRESENT	0
716228	716222	20122U	PARTICIPANT	\N	PRESENT	0
716229	716222	11026G	PARTICIPANT	\N	PRESENT	0
716262	716261	14133K	PARTICIPANT	\N	PRESENT	0
716263	716261	11083R	PARTICIPANT	\N	PRESENT	0
716264	716261	14059S	PARTICIPANT	\N	PRESENT	0
716424	716422	86034E	PARTICIPANT	\N	PRESENT	0
716425	716422	99004R	PARTICIPANT	\N	PRESENT	0
716426	716422	11045K	PARTICIPANT	\N	PRESENT	0
716427	716422	01043Q	PARTICIPANT	\N	PRESENT	0
716428	716422	95063L	PARTICIPANT	\N	PRESENT	0
716432	716422	11070L	PARTICIPANT	\N	PRESENT	0
716430	716422	19719D	PARTICIPANT	\N	PRESENT	0
716431	716422	14026U	PARTICIPANT	\N	PRESENT	0
716433	716422	05008E	PARTICIPANT	\N	PRESENT	0
716434	716422	01028R	PARTICIPANT	\N	PRESENT	0
716435	716422	11053K	PARTICIPANT	\N	PRESENT	0
716436	716422	11033F	PARTICIPANT	\N	PRESENT	0
716437	716422	14357A	PARTICIPANT	\N	PRESENT	0
716438	716422	01025N	PARTICIPANT	\N	PRESENT	0
716439	716422	14033T	PARTICIPANT	\N	PRESENT	0
716440	716422	14123H	PARTICIPANT	\N	PRESENT	0
716441	716422	14179A	PARTICIPANT	\N	PRESENT	0
716442	716422	14213J	PARTICIPANT	\N	PRESENT	0
716443	716422	19715Y	PARTICIPANT	\N	PRESENT	0
716444	716422	14147R	PARTICIPANT	\N	PRESENT	0
716445	716422	19301E	PARTICIPANT	\N	PRESENT	0
722221	722217	17737W	PARTICIPANT	\N	PRESENT	0
722222	722217	19467C	PARTICIPANT	\N	PRESENT	0
722224	722217	19719D	PARTICIPANT	\N	PRESENT	0
722225	722217	14217N	PARTICIPANT	\N	PRESENT	0
722226	722217	14042U	PARTICIPANT	\N	PRESENT	0
722229	722217	19591F	PARTICIPANT	\N	PRESENT	0
722231	722217	19447X	PARTICIPANT	\N	PRESENT	0
722232	722217	14059S	PARTICIPANT	\N	PRESENT	0
722233	722217	04057K	PARTICIPANT	\N	PRESENT	0
722234	722217	14147R	PARTICIPANT	\N	PRESENT	0
722235	722217	11067R	PARTICIPANT	\N	PRESENT	0
722236	722217	14223L	PARTICIPANT	\N	PRESENT	0
722237	722217	14071N	PARTICIPANT	\N	PRESENT	0
722238	722217	14055N	PARTICIPANT	\N	PRESENT	0
722239	722217	19766L	PARTICIPANT	\N	PRESENT	0
722240	722217	19798U	PARTICIPANT	\N	PRESENT	0
722241	722217	19713W	PARTICIPANT	\N	PRESENT	0
722242	722217	19703U	PARTICIPANT	\N	PRESENT	0
722244	722217	20062A	PARTICIPANT	\N	PRESENT	0
722245	722217	19415P	PARTICIPANT	\N	PRESENT	0
728092	725544	14030Q	PARTICIPANT	\N	PRESENT	0
728093	725544	20106U	PARTICIPANT	\N	EXCUSE	0
728094	725544	20024T	PARTICIPANT	\N	EXCUSE	0
728095	725544	20080C	PARTICIPANT	\N	EXCUSE	0
728096	725544	20098N	PARTICIPANT	\N	EXCUSE	0
728097	725544	20118Y	PARTICIPANT	\N	EXCUSE	0
728098	725544	07029T	PARTICIPANT	\N	EXCUSE	0
728099	725544	19717B	PARTICIPANT	\N	PRESENT	0
728100	725544	20146D	PARTICIPANT	\N	PRESENT	1
728101	725544	97011G	PARTICIPANT	\N	PRESENT	0
728104	725544	19715Y	PARTICIPANT	\N	PRESENT	1
728143	728142	86034E	PARTICIPANT	\N	PRESENT	0
728144	728142	04085P	PARTICIPANT	\N	PRESENT	0
728145	728142	14133K	PARTICIPANT	\N	PRESENT	0
728146	728142	04047H	PARTICIPANT	\N	PRESENT	0
728147	728142	20104S	PARTICIPANT	\N	PRESENT	0
728148	728142	11070L	PARTICIPANT	\N	PRESENT	0
728149	728142	10006L	PARTICIPANT	\N	PRESENT	0
728150	728142	14042U	PARTICIPANT	\N	PRESENT	0
728151	728142	19347U	PARTICIPANT	\N	PRESENT	0
728152	728142	11048N	PARTICIPANT	\N	PRESENT	0
728153	728142	14021P	PARTICIPANT	\N	PRESENT	0
728154	728142	99004R	PARTICIPANT	\N	PRESENT	0
728155	728142	19611R	PARTICIPANT	\N	PRESENT	0
728156	728142	12041X	PARTICIPANT	\N	PRESENT	0
728157	728142	01043Q	PARTICIPANT	\N	PRESENT	0
728158	728142	14219Q	PARTICIPANT	\N	PRESENT	0
728159	728142	14251Q	PARTICIPANT	\N	PRESENT	0
728160	728142	11085T	PARTICIPANT	\N	PRESENT	0
728161	728142	08061X	PARTICIPANT	\N	PRESENT	0
728162	728142	11090Q	PARTICIPANT	\N	PRESENT	0
728163	728142	14225N	PARTICIPANT	\N	PRESENT	0
728164	728142	11012A	PARTICIPANT	\N	PRESENT	0
728165	728142	04033B	PARTICIPANT	\N	PRESENT	0
728166	728142	01028R	PARTICIPANT	\N	PRESENT	0
730600	729230	19515S	PRESIDENT	0	PRESENT	0
730601	729230	14083S	PARTICIPANT	\N	PRESENT	0
730602	729230	19467C	PARTICIPANT	\N	PRESENT	0
730603	729230	19369B	PARTICIPANT	\N	PRESENT	0
730605	729230	19717B	PARTICIPANT	\N	PRESENT	0
730607	729230	18083K	PARTICIPANT	\N	PRESENT	0
730608	729230	19691J	PARTICIPANT	\N	PRESENT	0
730609	729230	20034V	PARTICIPANT	\N	PRESENT	0
730610	729230	14059S	PARTICIPANT	\N	PRESENT	0
730611	729230	14147R	PARTICIPANT	\N	PRESENT	0
730612	729230	20146D	PARTICIPANT	\N	PRESENT	0
730613	729230	19760E	PARTICIPANT	\N	EXCUSE	0
730614	729230	14030Q	PARTICIPANT	\N	EXCUSE	0
730615	729230	08060W	PARTICIPANT	\N	EXCUSE	0
730616	729230	19545Y	PARTICIPANT	\N	EXCUSE	0
730617	729230	14329V	PARTICIPANT	\N	EXCUSE	0
730619	729230	08028W	PARTICIPANT	\N	EXCUSE	0
730620	729230	19251M	PARTICIPANT	\N	EXCUSE	0
730622	729230	19866P	PARTICIPANT	\N	EXCUSE	0
730623	729230	20030R	PARTICIPANT	\N	EXCUSE	0
730624	729230	20082E	PARTICIPANT	\N	EXCUSE	0
730625	729230	20054A	PARTICIPANT	\N	EXCUSE	0
730626	729230	20092G	PARTICIPANT	\N	EXCUSE	0
730627	729230	19762G	PARTICIPANT	\N	EXCUSE	0
730629	729230	19715Y	PARTICIPANT	\N	PRESENT	1
730630	729230	20148F	PARTICIPANT	\N	PRESENT	1
733123	732893	20148F	PARTICIPANT	\N	PRESENT	0
733124	732893	14037X	PARTICIPANT	\N	PRESENT	0
733125	732893	14329V	PARTICIPANT	\N	PRESENT	0
733126	732893	19525U	PARTICIPANT	\N	PRESENT	0
733127	732893	14357A	PARTICIPANT	\N	PRESENT	0
733128	732893	19383Y	PARTICIPANT	\N	PRESENT	0
733129	732893	19717B	PARTICIPANT	\N	PRESENT	0
733130	732893	20116W	PARTICIPANT	\N	PRESENT	0
733131	732893	14207L	PARTICIPANT	\N	PRESENT	0
733132	732893	20152B	PARTICIPANT	\N	PRESENT	0
733133	732893	19629C	PARTICIPANT	\N	PRESENT	0
733134	732893	19387D	PARTICIPANT	\N	PRESENT	0
733135	732893	19367Y	PARTICIPANT	\N	PRESENT	0
733136	732893	98022P	PARTICIPANT	\N	PRESENT	0
733137	732893	20124W	PARTICIPANT	\N	PRESENT	0
733138	732893	08069G	PARTICIPANT	\N	PRESENT	0
733139	732893	11012A	PARTICIPANT	\N	PRESENT	0
733140	732893	08056B	PARTICIPANT	\N	PRESENT	0
733141	732893	19545Y	PARTICIPANT	\N	PRESENT	0
733142	732893	20062A	PARTICIPANT	\N	PRESENT	0
733143	732893	14195A	PARTICIPANT	\N	PRESENT	0
733144	732893	01058X	PARTICIPANT	\N	PRESENT	0
733145	732893	19707Y	PARTICIPANT	\N	PRESENT	0
733146	732893	14251Q	PARTICIPANT	\N	PRESENT	0
733147	732893	19705W	PARTICIPANT	\N	PRESENT	0
733148	732893	19768N	PARTICIPANT	\N	PRESENT	0
733149	732893	19729F	PARTICIPANT	\N	PRESENT	0
733150	732893	07029T	PARTICIPANT	\N	PRESENT	0
733151	732893	20016T	PARTICIPANT	\N	PRESENT	0
733152	732893	20050V	PARTICIPANT	\N	PRESENT	0
733153	732893	19585H	PARTICIPANT	\N	PRESENT	0
733154	732893	11045K	PARTICIPANT	\N	PRESENT	0
733155	732893	08018U	PARTICIPANT	\N	PRESENT	0
733156	732893	19709B	PARTICIPANT	\N	PRESENT	0
733157	732893	20086J	PARTICIPANT	\N	PRESENT	0
733158	732893	19663E	PARTICIPANT	\N	PRESENT	0
733159	732893	14033T	PARTICIPANT	\N	PRESENT	0
733160	732893	11115U	PARTICIPANT	\N	PRESENT	0
733161	732893	17737W	PARTICIPANT	\N	PRESENT	0
733162	732893	11066Q	PARTICIPANT	\N	PRESENT	0
733163	732893	19721W	PARTICIPANT	\N	PRESENT	0
733164	732893	14259Y	PARTICIPANT	\N	PRESENT	0
714236	709156	19717B	PARTICIPANT	\N	EXCUSE	0
714237	709156	20034V	PARTICIPANT	\N	PRESENT	0
718463	718455	19593H	PARTICIPANT	\N	PRESENT	0
718464	718455	20132W	PARTICIPANT	\N	PRESENT	0
718465	718455	04070G	PARTICIPANT	\N	PRESENT	0
718466	718455	19699S	PARTICIPANT	\N	PRESENT	0
718467	718455	19611R	PRESIDENT	0	PRESENT	0
718468	718455	20016T	PARTICIPANT	\N	PRESENT	0
720662	720097	95063L	PARTICIPANT	\N	PRESENT	0
718474	718455	19399H	PARTICIPANT	\N	PRESENT	0
720664	720097	11067R	PARTICIPANT	\N	PRESENT	0
720665	720097	19725B	PARTICIPANT	\N	PRESENT	0
720666	720097	19599P	PARTICIPANT	\N	PRESENT	0
720667	720097	14109K	PARTICIPANT	\N	PRESENT	0
720668	720097	19503N	PARTICIPANT	\N	PRESENT	0
720669	720097	20088L	PARTICIPANT	\N	PRESENT	0
720670	720097	19549D	PARTICIPANT	\N	PRESENT	0
720671	720097	20030R	PARTICIPANT	\N	PRESENT	0
720672	720097	14219Q	PARTICIPANT	\N	PRESENT	0
720673	720097	14073Q	PARTICIPANT	\N	PRESENT	0
720674	720097	20142Y	PARTICIPANT	\N	PRESENT	0
720675	720097	14097Y	PARTICIPANT	\N	PRESENT	0
720676	720097	20112S	PARTICIPANT	\N	PRESENT	0
720677	720097	14205J	PARTICIPANT	\N	PRESENT	0
720678	720097	19826F	PARTICIPANT	\N	PRESENT	0
720679	720097	20050V	PARTICIPANT	\N	PRESENT	0
720680	720097	14221J	PARTICIPANT	\N	PRESENT	0
720681	720097	19719D	PARTICIPANT	\N	PRESENT	0
720682	720097	20072C	PARTICIPANT	\N	PRESENT	0
720683	720097	14107H	PARTICIPANT	\N	PRESENT	0
720684	720097	19563B	PARTICIPANT	\N	PRESENT	0
720685	720097	14251Q	PARTICIPANT	\N	PRESENT	0
720686	720097	19745F	PARTICIPANT	\N	PRESENT	0
720687	720097	20078J	PARTICIPANT	\N	PRESENT	0
720688	720097	14169X	PARTICIPANT	\N	PRESENT	0
720689	720097	14031R	PARTICIPANT	\N	PRESENT	0
720690	720097	20022R	PARTICIPANT	\N	PRESENT	0
720691	720097	17737W	PARTICIPANT	\N	PRESENT	0
720692	720097	20026V	PARTICIPANT	\N	PRESENT	0
720693	720097	20032T	PARTICIPANT	\N	PRESENT	0
720694	720097	14147R	PARTICIPANT	\N	PRESENT	0
720695	720097	14213J	PARTICIPANT	\N	PRESENT	0
720696	720097	14217N	PARTICIPANT	\N	PRESENT	0
720697	720097	20090E	PARTICIPANT	\N	PRESENT	0
720698	720097	19383Y	PARTICIPANT	\N	PRESENT	0
720699	720097	19711U	PARTICIPANT	\N	PRESENT	0
720700	720097	19703U	PARTICIPANT	\N	PRESENT	0
720701	720097	11090Q	PARTICIPANT	\N	PRESENT	0
720702	720097	11048N	PARTICIPANT	\N	PRESENT	0
720703	720097	19747H	PARTICIPANT	\N	PRESENT	0
720704	720097	19447X	PARTICIPANT	\N	PRESENT	0
720705	720097	20046A	PARTICIPANT	\N	PRESENT	0
720706	720097	20054A	PARTICIPANT	\N	PRESENT	0
720707	720097	19782L	PARTICIPANT	\N	PRESENT	0
720708	720522	19575F	PARTICIPANT	\N	PRESENT	0
720709	720097	08028W	PARTICIPANT	\N	PRESENT	0
720710	720089	12041X	PARTICIPANT	\N	PRESENT	0
720711	720089	14133K	PARTICIPANT	\N	PRESENT	0
720712	720089	01062T	PARTICIPANT	\N	PRESENT	0
720713	720089	11041F	PARTICIPANT	\N	PRESENT	0
720714	720089	20042V	PARTICIPANT	\N	PRESENT	0
720715	720089	01058X	PARTICIPANT	\N	PRESENT	0
720716	720089	16685X	PARTICIPANT	\N	PRESENT	0
720717	720089	01024M	PARTICIPANT	\N	PRESENT	0
720718	720089	11066Q	PARTICIPANT	\N	PRESENT	0
720719	720089	19669L	PARTICIPANT	\N	PRESENT	0
720720	720089	08056B	PARTICIPANT	\N	PRESENT	0
720721	720089	19319Q	PARTICIPANT	\N	PRESENT	0
720722	720089	20064C	PARTICIPANT	\N	PRESENT	0
720723	720089	19421M	PARTICIPANT	\N	PRESENT	0
720724	720089	98022P	PARTICIPANT	\N	PRESENT	0
720725	720089	19347U	PARTICIPANT	\N	PRESENT	0
720663	720097	20076G	PARTICIPANT	\N	PRESENT	0
720726	720089	11064N	PARTICIPANT	\N	PRESENT	0
720727	720089	14249W	PARTICIPANT	\N	PRESENT	0
720728	720089	14211G	PARTICIPANT	\N	PRESENT	0
720729	720089	19583F	PARTICIPANT	\N	PRESENT	0
720730	720089	08047A	PRESIDENT	0	PRESENT	0
720731	720089	19443T	PARTICIPANT	\N	EXCUSE	0
720732	720089	19565D	PARTICIPANT	\N	EXCUSE	0
720733	720089	20072C	PARTICIPANT	\N	EXCUSE	0
720734	720089	14267Y	PARTICIPANT	\N	EXCUSE	0
720735	720089	04042C	PARTICIPANT	\N	EXCUSE	0
720736	720089	97011G	PARTICIPANT	\N	EXCUSE	0
720737	720097	19507S	PARTICIPANT	\N	PRESENT	0
720738	720097	01025N	PARTICIPANT	\N	PRESENT	0
720739	720097	14281W	PARTICIPANT	\N	PRESENT	0
720740	720097	19798U	PARTICIPANT	\N	PRESENT	0
720741	720097	14215L	PARTICIPANT	\N	PRESENT	0
720742	720097	20036X	PARTICIPANT	\N	PRESENT	0
720744	720097	20018V	PARTICIPANT	\N	PRESENT	0
720745	720097	11065P	PARTICIPANT	\N	PRESENT	0
720746	720097	19349W	PARTICIPANT	\N	PRESENT	0
720747	720097	20066E	PARTICIPANT	\N	PRESENT	0
720748	720097	17965H	PARTICIPANT	\N	PRESENT	0
720749	720097	16685X	PARTICIPANT	\N	PRESENT	0
720750	720097	20024T	PARTICIPANT	\N	PRESENT	0
720751	720089	12028B	PARTICIPANT	\N	PRESENT	0
720752	720097	14071N	PARTICIPANT	\N	PRESENT	0
720753	720097	19413M	PARTICIPANT	\N	PRESENT	0
720754	720097	20140W	PARTICIPANT	\N	PRESENT	0
720755	720097	14173T	PARTICIPANT	\N	PRESENT	0
720756	720097	14038Y	PARTICIPANT	\N	PRESENT	0
720757	720097	20074E	PARTICIPANT	\N	PRESENT	0
720758	720097	11064N	PARTICIPANT	\N	PRESENT	0
720759	720089	20128B	PARTICIPANT	\N	PRESENT	0
720767	720097	18083K	PARTICIPANT	\N	PRESENT	0
720768	720097	08061X	PARTICIPANT	\N	PRESENT	0
720769	720097	08045X	PARTICIPANT	\N	PRESENT	0
720770	720097	14042U	PARTICIPANT	\N	PRESENT	0
720771	720097	20114U	PARTICIPANT	\N	PRESENT	0
720772	720097	19387D	PARTICIPANT	\N	PRESENT	0
720782	720097	19681G	PARTICIPANT	\N	PRESENT	0
720783	720097	20248J	PARTICIPANT	\N	PRESENT	0
720784	720097	19367Y	PARTICIPANT	\N	PRESENT	0
720785	720097	08010L	PARTICIPANT	\N	PRESENT	0
720786	720097	20118Y	PARTICIPANT	\N	PRESENT	0
720787	720097	14259Y	PARTICIPANT	\N	PRESENT	0
720788	720097	20062A	PARTICIPANT	\N	PRESENT	0
720789	720097	11012A	PARTICIPANT	\N	PRESENT	0
720790	720097	14231L	PARTICIPANT	\N	PRESENT	0
720791	720097	20136B	PARTICIPANT	\N	PRESENT	0
720793	720097	19758L	PARTICIPANT	\N	PRESENT	0
720794	720097	14033T	PARTICIPANT	\N	PRESENT	0
720795	719950	19691J	PARTICIPANT	\N	PRESENT	0
720796	720097	20040T	PARTICIPANT	\N	PRESENT	0
720797	720097	19347U	PARTICIPANT	\N	PRESENT	0
720798	720097	11099A	PARTICIPANT	\N	PRESENT	0
720799	720097	19629C	PARTICIPANT	\N	PRESENT	0
720800	720097	19721W	PARTICIPANT	\N	PRESENT	0
720801	720097	20128B	PARTICIPANT	\N	PRESENT	0
720803	720097	19723Y	PARTICIPANT	\N	PRESENT	0
720804	720097	19441R	PARTICIPANT	\N	PRESENT	0
720805	720097	19820Y	PARTICIPANT	\N	PRESENT	0
720806	720097	14083S	PARTICIPANT	\N	PRESENT	0
720807	720097	20082E	PARTICIPANT	\N	PRESENT	0
720808	720097	01024M	PARTICIPANT	\N	PRESENT	0
720809	720097	20116W	PARTICIPANT	\N	PRESENT	0
720810	720097	20132W	PARTICIPANT	\N	PRESENT	0
720811	720097	20914V	PARTICIPANT	\N	PRESENT	0
720812	720097	14257W	PARTICIPANT	\N	PRESENT	0
720813	720097	20092G	PARTICIPANT	\N	PRESENT	0
720814	720097	19479G	PARTICIPANT	\N	PRESENT	0
720815	720097	19573D	PARTICIPANT	\N	PRESENT	0
720816	720097	14053L	PARTICIPANT	\N	PRESENT	0
720817	720097	19673G	PARTICIPANT	\N	PRESENT	0
720818	720097	11097X	PARTICIPANT	\N	PRESENT	0
720819	720097	20056C	PARTICIPANT	\N	PRESENT	0
720820	720097	14207L	PARTICIPANT	\N	PRESENT	0
720821	720097	20100N	PARTICIPANT	\N	PRESENT	0
720822	720097	19569H	PARTICIPANT	\N	PRESENT	0
713484	713483	14133K	PARTICIPANT	\N	PRESENT	0
713485	713483	14059S	PARTICIPANT	\N	PRESENT	0
713486	712571	14030Q	PARTICIPANT	\N	PRESENT	0
713487	712571	19643A	PARTICIPANT	\N	PRESENT	0
713488	712571	20152B	PARTICIPANT	\N	PRESENT	0
713489	712571	20134Y	PARTICIPANT	\N	PRESENT	0
713490	712571	14179A	PARTICIPANT	\N	PRESENT	0
713491	712571	14251Q	PARTICIPANT	\N	PRESENT	0
713492	712571	19593H	PARTICIPANT	\N	PRESENT	0
713493	712571	14193X	PARTICIPANT	\N	PRESENT	0
713494	712571	11045K	PARTICIPANT	\N	PRESENT	0
713495	712571	20064C	PRESIDENT	0	PRESENT	0
713860	713859	20024T	PARTICIPANT	\N	PRESENT	0
713861	713859	20042V	PARTICIPANT	\N	PRESENT	0
713862	713859	20070A	PARTICIPANT	\N	PRESENT	0
713863	713859	10015M	PARTICIPANT	\N	PRESENT	0
713864	713859	20084G	PARTICIPANT	\N	PRESENT	0
714822	714820	19621T	PARTICIPANT	\N	PRESENT	0
714823	714820	20980G	PARTICIPANT	\N	PRESENT	0
714824	714820	20026V	PARTICIPANT	\N	PRESENT	0
714825	714820	20264J	PARTICIPANT	\N	PRESENT	1
714826	714820	19739H	PARTICIPANT	\N	PRESENT	1
714827	714820	20106U	PARTICIPANT	\N	PRESENT	0
714828	714820	19335Q	PARTICIPANT	\N	PRESENT	0
714830	714829	20980G	PARTICIPANT	\N	PRESENT	0
714831	714829	19335Q	PARTICIPANT	\N	PRESENT	0
714832	714829	20106U	PARTICIPANT	\N	PRESENT	0
714833	714829	20264J	PARTICIPANT	\N	PRESENT	1
714836	714835	20980G	PARTICIPANT	\N	PRESENT	0
714837	714835	20038A	PARTICIPANT	\N	PRESENT	0
714838	714835	20106U	PARTICIPANT	\N	PRESENT	0
714839	714835	19335Q	PARTICIPANT	\N	PRESENT	0
715119	713517	19387D	PARTICIPANT	\N	PRESENT	0
715133	713517	19637C	PARTICIPANT	\N	EXCUSE	0
715716	715715	20032T	PARTICIPANT	\N	PRESENT	0
715717	715715	20024T	PARTICIPANT	\N	PRESENT	0
715718	715715	19383Y	PARTICIPANT	\N	PRESENT	0
715719	715715	20090E	PARTICIPANT	\N	PRESENT	0
715720	715715	19467C	PARTICIPANT	\N	PRESENT	0
715721	715715	14327T	PARTICIPANT	\N	PRESENT	0
715722	715715	14059S	PARTICIPANT	\N	PRESENT	0
715723	715715	20092G	PARTICIPANT	\N	PRESENT	0
715724	715715	20062A	PARTICIPANT	\N	PRESENT	0
715725	715715	19713W	PARTICIPANT	\N	PRESENT	0
715726	715715	20044X	PARTICIPANT	\N	PRESENT	0
717068	717067	14133K	PARTICIPANT	\N	PRESENT	0
717069	717067	14217N	PARTICIPANT	\N	PRESENT	0
717070	717067	10006L	PARTICIPANT	\N	PRESENT	0
720773	720140	19691J	PARTICIPANT	\N	PRESENT	0
721790	721783	20106U	PARTICIPANT	\N	PRESENT	1
721791	721783	19335Q	PARTICIPANT	\N	PRESENT	0
721792	721783	19329S	PARTICIPANT	\N	PRESENT	1
721793	721783	11072N	PARTICIPANT	\N	PRESENT	0
721794	721783	19717B	PARTICIPANT	\N	PRESENT	1
735831	735596	14237S	PARTICIPANT	\N	PRESENT	0
735832	735596	14257W	PARTICIPANT	\N	PRESENT	0
735833	735596	14193X	PARTICIPANT	\N	PRESENT	0
735834	735596	20030R	PARTICIPANT	\N	PRESENT	0
735835	735596	17965H	PARTICIPANT	\N	PRESENT	0
735836	735596	19533U	PARTICIPANT	\N	PRESENT	0
735837	735596	19503N	PARTICIPANT	\N	PRESENT	0
735838	735596	14225N	PARTICIPANT	\N	PRESENT	0
735839	735596	20082E	PARTICIPANT	\N	PRESENT	0
735840	735596	05012A	PARTICIPANT	\N	PRESENT	0
735841	735596	14229S	PARTICIPANT	\N	PRESENT	0
735842	735596	11090Q	PARTICIPANT	\N	PRESENT	0
735843	735596	11054L	PARTICIPANT	\N	PRESENT	0
735844	735596	04043D	PARTICIPANT	\N	PRESENT	0
735845	735596	11045K	PARTICIPANT	\N	PRESENT	0
735846	735596	20084G	PARTICIPANT	\N	PRESENT	0
735847	735596	14331P	PARTICIPANT	\N	PRESENT	0
735848	735596	01028R	PARTICIPANT	\N	PRESENT	0
735849	735596	19669L	PARTICIPANT	\N	PRESENT	0
735850	735596	19766L	PARTICIPANT	\N	PRESENT	0
735851	735596	10015M	PARTICIPANT	\N	PRESENT	0
735852	735596	01062T	PARTICIPANT	\N	PRESENT	0
735853	735596	19705W	PARTICIPANT	\N	PRESENT	0
735854	735596	04033B	PARTICIPANT	\N	PRESENT	0
735855	735596	19798U	PARTICIPANT	\N	PRESENT	0
735856	735596	20054A	PARTICIPANT	\N	PRESENT	0
735857	735596	19421M	PARTICIPANT	\N	PRESENT	0
735858	735596	11041F	PARTICIPANT	\N	PRESENT	0
735859	735596	20044X	PARTICIPANT	\N	PRESENT	0
735860	735596	19527W	PARTICIPANT	\N	PRESENT	0
735861	735596	11066Q	PARTICIPANT	\N	PRESENT	0
735862	735596	11097X	PARTICIPANT	\N	PRESENT	0
735863	735596	20098N	PARTICIPANT	\N	PRESENT	0
735864	735596	19762G	PARTICIPANT	\N	PRESENT	0
735865	735596	19543W	PARTICIPANT	\N	PRESENT	0
735866	735596	01058X	PARTICIPANT	\N	PRESENT	0
735867	735596	19703U	PARTICIPANT	\N	PRESENT	0
735868	735596	20062A	PARTICIPANT	\N	PRESENT	0
735869	735596	14030Q	PARTICIPANT	\N	PRESENT	0
735870	735596	14089Y	PARTICIPANT	\N	PRESENT	0
735871	735596	14255U	PARTICIPANT	\N	PRESENT	0
735872	735596	14083S	PARTICIPANT	\N	PRESENT	0
735873	735596	20144B	PARTICIPANT	\N	PRESENT	0
735874	735596	14267Y	PARTICIPANT	\N	PRESENT	0
735875	735596	11070L	PARTICIPANT	\N	PRESENT	0
735876	735596	17229F	PARTICIPANT	\N	PRESENT	0
735877	735596	01024M	PARTICIPANT	\N	PRESENT	0
735878	735596	20040T	PARTICIPANT	\N	PRESENT	0
735879	735596	01025N	PARTICIPANT	\N	PRESENT	0
735880	735596	14231L	PARTICIPANT	\N	PRESENT	0
735881	735596	07004J	PARTICIPANT	\N	PRESENT	0
735882	735596	19691J	PARTICIPANT	\N	PRESENT	0
735883	735596	19569H	PARTICIPANT	\N	PRESENT	0
735884	735596	20048C	PARTICIPANT	\N	PRESENT	0
735885	735596	20066E	PARTICIPANT	\N	PRESENT	0
735886	735596	19511N	PARTICIPANT	\N	PRESENT	0
735887	735596	14073Q	PARTICIPANT	\N	PRESENT	0
735888	735596	19735D	PARTICIPANT	\N	PRESENT	0
735889	735596	19611R	PARTICIPANT	\N	PRESENT	0
735890	735596	19699S	PARTICIPANT	\N	PRESENT	0
735891	735596	20016T	PARTICIPANT	\N	PRESENT	0
735892	735596	01043Q	PARTICIPANT	\N	PRESENT	0
735893	735596	20052X	PARTICIPANT	\N	PRESENT	0
735894	735596	16685X	PARTICIPANT	\N	PRESENT	0
735895	735596	14205J	PARTICIPANT	\N	PRESENT	0
735896	735596	14219Q	PARTICIPANT	\N	PRESENT	0
735897	735596	19441R	PARTICIPANT	\N	PRESENT	0
735898	735596	19826F	PARTICIPANT	\N	PRESENT	0
735899	735596	08009T	PARTICIPANT	\N	PRESENT	0
735900	735596	19335Q	PARTICIPANT	\N	PRESENT	0
735901	735596	19369B	PARTICIPANT	\N	PRESENT	0
735902	735596	04070G	PARTICIPANT	\N	PRESENT	0
735903	735596	19745F	PARTICIPANT	\N	PRESENT	0
735904	735596	19739H	PARTICIPANT	\N	PRESENT	0
735905	735596	20298U	PARTICIPANT	\N	PRESENT	0
735906	735596	19619A	PARTICIPANT	\N	PRESENT	0
735907	735596	14275Y	PARTICIPANT	\N	PRESENT	0
735908	735596	19749K	PARTICIPANT	\N	PRESENT	0
735909	735596	19479G	PARTICIPANT	\N	PRESENT	0
735910	735596	14249W	PARTICIPANT	\N	PRESENT	0
735911	735596	20064C	PARTICIPANT	\N	PRESENT	0
735912	735596	08011M	PARTICIPANT	\N	PRESENT	0
735914	735596	11048N	PARTICIPANT	\N	PRESENT	0
735915	735596	14213J	PARTICIPANT	\N	PRESENT	0
735916	735596	20106U	PARTICIPANT	\N	PRESENT	0
735917	735596	19525U	PARTICIPANT	\N	PRESENT	0
735918	735596	14217N	PARTICIPANT	\N	PRESENT	0
735919	735596	14189C	PARTICIPANT	\N	PRESENT	0
735920	735596	11085T	PARTICIPANT	\N	PRESENT	0
735921	735596	20032T	PARTICIPANT	\N	PRESENT	0
735922	735596	11053K	PARTICIPANT	\N	PRESENT	0
735923	735596	20058E	PARTICIPANT	\N	PRESENT	0
735925	735596	19663E	PARTICIPANT	\N	PRESENT	0
735926	735596	19673G	PARTICIPANT	\N	PRESENT	0
735927	735596	20180F	PARTICIPANT	\N	PRESENT	0
735928	735596	20114U	PARTICIPANT	\N	PRESENT	0
735929	735596	14123H	PARTICIPANT	\N	PRESENT	0
735930	735596	11027H	PARTICIPANT	\N	PRESENT	0
735931	735596	11026G	PARTICIPANT	\N	PRESENT	0
735932	735596	20104S	PARTICIPANT	\N	PRESENT	0
735933	735596	20980G	PARTICIPANT	\N	PRESENT	0
735935	735596	20136B	PARTICIPANT	\N	PRESENT	0
735936	735596	01048V	PARTICIPANT	\N	PRESENT	0
735937	735596	04092N	PARTICIPANT	\N	PRESENT	0
735938	735596	20022R	PARTICIPANT	\N	PRESENT	0
735939	735596	19399H	PARTICIPANT	\N	PRESENT	0
735940	735596	20042V	PARTICIPANT	\N	PRESENT	0
711476	705810	19749K	PARTICIPANT	\N	PRESENT	0
713481	712571	14147R	PARTICIPANT	\N	EXCUSE	0
713482	712571	04070G	PARTICIPANT	\N	EXCUSE	0
713753	709564	14281W	PARTICIPANT	\N	PRESENT	0
714495	714494	20094J	PARTICIPANT	\N	PRESENT	0
714496	714494	19820Y	PARTICIPANT	\N	PRESENT	0
714497	714494	20128B	PARTICIPANT	\N	PRESENT	0
714498	714494	19745F	PRESIDENT	0	PRESENT	0
714499	714494	14229S	PARTICIPANT	\N	PRESENT	0
714500	714494	20118Y	PARTICIPANT	\N	PRESENT	0
714501	714494	20104S	PARTICIPANT	\N	EXCUSE	0
714502	714494	05012A	PARTICIPANT	\N	EXCUSE	0
714503	714494	20070A	PARTICIPANT	\N	PRESENT	0
714504	714494	19387D	PARTICIPANT	\N	PRESENT	0
720013	719934	20058E	PARTICIPANT	\N	PRESENT	1
720014	719934	14030Q	PARTICIPANT	\N	PRESENT	1
720253	718399	19717B	PRESIDENT	0	PRESENT	1
720254	718399	20016T	PARTICIPANT	\N	PRESENT	0
720255	718399	19319Q	PARTICIPANT	\N	PRESENT	0
720256	718399	19715Y	PARTICIPANT	\N	PRESENT	0
720257	718399	20098N	PARTICIPANT	\N	PRESENT	0
720258	718399	14030Q	PARTICIPANT	\N	PRESENT	0
720259	718399	20024T	PARTICIPANT	\N	PRESENT	0
720260	718399	14189C	PARTICIPANT	\N	PRESENT	0
724032	722794	14107H	PARTICIPANT	\N	PRESENT	0
724030	722794	19719D	PARTICIPANT	\N	PRESENT	0
724031	722794	98022P	PARTICIPANT	\N	PRESENT	0
724033	722794	19866P	PARTICIPANT	\N	PRESENT	0
724034	722794	19525U	PARTICIPANT	\N	PRESENT	0
724035	722794	19349W	PARTICIPANT	\N	PRESENT	0
724036	722794	11027H	PARTICIPANT	\N	PRESENT	0
724037	722794	20082E	PARTICIPANT	\N	PRESENT	0
724039	722794	19629C	PARTICIPANT	\N	PRESENT	0
724040	722794	14267Y	PARTICIPANT	\N	PRESENT	0
724041	722794	19319Q	PARTICIPANT	\N	PRESENT	0
724042	722794	19511N	PARTICIPANT	\N	PRESENT	0
724043	722794	19721W	PARTICIPANT	\N	PRESENT	0
724045	722794	11012A	PARTICIPANT	\N	PRESENT	0
724047	722794	12028B	PARTICIPANT	\N	PRESENT	0
724049	722794	17229F	PARTICIPANT	\N	PRESENT	0
724050	722794	14207L	PARTICIPANT	\N	PRESENT	0
724051	722794	20100N	PARTICIPANT	\N	PRESENT	0
724052	723223	14327T	PARTICIPANT	\N	PRESENT	0
724053	723223	20086J	PARTICIPANT	\N	PRESENT	0
724054	723223	04071H	PARTICIPANT	\N	PRESENT	0
724055	723223	01048V	PARTICIPANT	\N	PRESENT	0
724056	723223	19545Y	PARTICIPANT	\N	PRESENT	0
724057	723223	01057W	PARTICIPANT	\N	PRESENT	0
724058	723223	20080C	PARTICIPANT	\N	PRESENT	0
724059	723223	11053K	PARTICIPANT	\N	PRESENT	0
724060	723223	11074Q	PARTICIPANT	\N	PRESENT	0
724061	723223	19667J	PARTICIPANT	\N	PRESENT	0
724062	723223	19671E	PARTICIPANT	\N	PRESENT	0
724063	723223	11070L	PARTICIPANT	\N	PRESENT	0
724064	723223	11110B	PARTICIPANT	\N	PRESENT	0
724065	723223	07029T	PARTICIPANT	\N	PRESENT	0
724066	723223	19349W	PARTICIPANT	\N	PRESENT	0
724067	723223	08010L	PARTICIPANT	\N	PRESENT	0
724068	723223	14253S	PARTICIPANT	\N	PRESENT	0
724069	723223	20116W	PARTICIPANT	\N	PRESENT	0
724070	723223	19335Q	PARTICIPANT	\N	PRESENT	0
724071	723223	20126Y	PARTICIPANT	\N	PRESENT	0
724072	723223	19479G	PRESIDENT	0	PRESENT	0
724073	723223	19647E	PARTICIPANT	\N	PRESENT	0
724074	723223	11048N	PARTICIPANT	\N	PRESENT	0
724075	723223	20036X	PARTICIPANT	\N	PRESENT	0
724076	723223	19711U	PARTICIPANT	\N	PRESENT	0
724077	723223	19687N	PARTICIPANT	\N	PRESENT	0
724078	723223	20050V	PARTICIPANT	\N	PRESENT	0
724079	723223	08011M	PARTICIPANT	\N	PRESENT	0
724080	723223	20044X	PARTICIPANT	\N	PRESENT	0
724081	723223	14173T	PARTICIPANT	\N	PRESENT	0
724082	723223	14083S	PARTICIPANT	\N	PRESENT	0
724083	723223	11012A	PARTICIPANT	\N	PRESENT	0
724084	723223	08073C	PARTICIPANT	\N	PRESENT	0
724085	723223	08009T	PARTICIPANT	\N	PRESENT	0
724086	723223	20070A	PARTICIPANT	\N	PRESENT	0
724087	723223	14121F	PARTICIPANT	\N	PRESENT	0
724088	723223	20914V	PARTICIPANT	\N	PRESENT	0
724089	723223	99004R	PARTICIPANT	\N	PRESENT	0
724090	723223	19762G	PARTICIPANT	\N	PRESENT	0
724091	723223	19741B	PARTICIPANT	\N	PRESENT	0
724092	723223	14225N	PARTICIPANT	\N	EXCUSE	0
725828	722477	20032T	PARTICIPANT	\N	PRESENT	0
725829	722477	20024T	PARTICIPANT	\N	PRESENT	0
725830	722477	19549D	PARTICIPANT	\N	PRESENT	0
725831	722477	17367Q	PARTICIPANT	\N	PRESENT	0
725832	722477	11101A	PARTICIPANT	\N	PRESENT	0
725833	722477	18083K	PARTICIPANT	\N	PRESENT	0
725834	722477	19701S	PARTICIPANT	\N	PRESENT	0
725835	722477	19525U	PARTICIPANT	\N	PRESENT	0
725836	722477	11065P	PARTICIPANT	\N	PRESENT	0
725837	722477	20140W	PARTICIPANT	\N	PRESENT	0
725838	722477	17229F	PARTICIPANT	\N	PRESENT	0
725839	722477	19659J	PARTICIPANT	\N	PRESENT	0
725840	722477	19251M	PARTICIPANT	\N	PRESENT	0
725841	722477	19577H	PARTICIPANT	\N	PRESENT	0
725842	722477	20038A	PARTICIPANT	\N	PRESENT	0
725843	722477	20100N	PARTICIPANT	\N	PRESENT	0
725844	722477	19599P	PARTICIPANT	\N	PRESENT	0
725845	722477	20120S	PARTICIPANT	\N	PRESENT	0
725846	722477	19820Y	PARTICIPANT	\N	PRESENT	0
725847	722477	19387D	PARTICIPANT	\N	PRESENT	0
725848	722477	20068G	PARTICIPANT	\N	PRESENT	0
725849	722477	20106U	PARTICIPANT	\N	PRESENT	0
725850	722477	19685L	PARTICIPANT	\N	PRESENT	0
725851	722477	19333N	PARTICIPANT	\N	PRESENT	0
725852	722477	14219Q	PRESIDENT	0	PRESENT	0
725853	722477	14031R	PARTICIPANT	\N	PRESENT	0
725854	722477	19637C	PARTICIPANT	\N	PRESENT	0
725855	722477	19826F	PARTICIPANT	\N	PRESENT	0
725856	722477	14221J	PARTICIPANT	\N	PRESENT	0
725857	722477	20096L	PARTICIPANT	\N	PRESENT	0
725858	722477	14169X	PARTICIPANT	\N	PRESENT	0
725859	722477	14237S	PARTICIPANT	\N	PRESENT	0
725860	722477	19745F	PARTICIPANT	\N	PRESENT	0
725861	722477	20118Y	PARTICIPANT	\N	PRESENT	0
725862	722477	05012A	PARTICIPANT	\N	PRESENT	0
725863	722477	20020P	PARTICIPANT	\N	PRESENT	0
725864	722477	19619A	PARTICIPANT	\N	PRESENT	0
725865	722477	20136B	PARTICIPANT	\N	PRESENT	0
725866	722477	20046A	PARTICIPANT	\N	PRESENT	0
729747	728221	19347U	PARTICIPANT	\N	PRESENT	0
729748	728221	97011G	PARTICIPANT	\N	PRESENT	0
729749	728221	14329V	PARTICIPANT	\N	PRESENT	0
729750	728221	19631V	PARTICIPANT	\N	PRESENT	0
729751	728221	14213J	PARTICIPANT	\N	PRESENT	0
729752	728221	20024T	PARTICIPANT	\N	PRESENT	0
729753	728221	20148F	PARTICIPANT	\N	PRESENT	0
729754	728221	19549D	PARTICIPANT	\N	PRESENT	0
729755	728221	20108W	PARTICIPANT	\N	PRESENT	0
729756	728221	20094J	PARTICIPANT	\N	PRESENT	0
729757	728221	20104S	PARTICIPANT	\N	PRESENT	0
729758	728221	20088L	PARTICIPANT	\N	PRESENT	0
729759	728221	19399H	PARTICIPANT	\N	PRESENT	0
729760	728221	20114U	PARTICIPANT	\N	PRESENT	0
729761	728221	20060X	PARTICIPANT	\N	PRESENT	0
729762	728221	20056C	PARTICIPANT	\N	PRESENT	0
729763	728221	20070A	PARTICIPANT	\N	PRESENT	0
729764	728221	19251M	PARTICIPANT	\N	PRESENT	0
729765	728221	14151M	PARTICIPANT	\N	PRESENT	0
729766	728221	14038Y	PARTICIPANT	\N	PRESENT	0
729767	728221	11110B	PARTICIPANT	\N	PRESENT	0
729768	728221	20058E	PARTICIPANT	\N	PRESENT	0
729769	728221	20044X	PARTICIPANT	\N	PRESENT	0
729770	728221	14281W	PARTICIPANT	\N	PRESENT	0
729771	728221	08045X	PARTICIPANT	\N	PRESENT	0
729772	728221	19663E	PARTICIPANT	\N	PRESENT	0
729773	728221	19599P	PARTICIPANT	\N	PRESENT	0
729774	728221	19820Y	PARTICIPANT	\N	PRESENT	0
729775	728221	19709B	PARTICIPANT	\N	PRESENT	0
729776	728221	19725B	PARTICIPANT	\N	PRESENT	0
729777	728221	19333N	PARTICIPANT	\N	PRESENT	0
729778	728221	08018U	PARTICIPANT	\N	PRESENT	0
729779	728221	14121F	PARTICIPANT	\N	PRESENT	0
729780	728221	04033B	PARTICIPANT	\N	PRESENT	0
729781	728221	19531S	PARTICIPANT	\N	PRESENT	0
729782	728221	08047A	PARTICIPANT	\N	PRESENT	0
729783	728221	14021P	PARTICIPANT	\N	PRESENT	0
729784	728221	19643A	PARTICIPANT	\N	PRESENT	0
729785	728221	19649G	PARTICIPANT	\N	PRESENT	0
713795	712584	19545Y	PARTICIPANT	\N	PRESENT	0
717059	715267	11072N	PARTICIPANT	\N	PRESENT	0
717061	715267	19489J	PARTICIPANT	\N	PRESENT	0
726660	725546	20096L	PARTICIPANT	\N	PRESENT	0
726661	725546	14237S	PARTICIPANT	\N	PRESENT	0
726662	725546	19685L	PARTICIPANT	\N	PRESENT	0
726663	725546	20122U	PARTICIPANT	\N	PRESENT	0
726664	725546	20136B	PARTICIPANT	\N	PRESENT	0
726665	725546	11101A	PARTICIPANT	\N	PRESENT	0
726666	725546	19739H	PARTICIPANT	\N	PRESENT	0
726669	725666	14021P	PARTICIPANT	\N	PRESENT	0
726670	725666	20074E	PARTICIPANT	\N	EXCUSE	0
726671	726448	19667J	PARTICIPANT	\N	PRESENT	0
726707	726448	11053K	PARTICIPANT	\N	PRESENT	0
726718	725546	20100N	PARTICIPANT	\N	EXCUSE	0
726719	725546	19251M	PARTICIPANT	\N	EXCUSE	0
726720	725546	20068G	PARTICIPANT	\N	PRESENT	0
726766	723710	19699S	PARTICIPANT	\N	PRESENT	0
726767	723710	20084G	PARTICIPANT	\N	PRESENT	0
726768	723710	11109J	PARTICIPANT	\N	EXCUSE	0
726769	725546	20120S	PARTICIPANT	\N	PRESENT	0
726779	725638	04070G	PARTICIPANT	\N	PRESENT	0
726780	725638	20064C	PRESIDENT	0	PRESENT	0
726781	725638	14251Q	PARTICIPANT	\N	PRESENT	0
726782	725638	20068G	PARTICIPANT	\N	PRESENT	0
726783	725638	14147R	PARTICIPANT	\N	PRESENT	0
726784	725638	20152B	PARTICIPANT	\N	PRESENT	0
726785	725638	17737W	PARTICIPANT	\N	EXCUSE	0
726788	725638	14030Q	PARTICIPANT	\N	PRESENT	0
726804	725874	08028W	PARTICIPANT	\N	PRESENT	0
726805	725874	14193X	PARTICIPANT	\N	PRESENT	0
726806	725874	20090E	PARTICIPANT	\N	PRESENT	0
726807	725874	20062A	PARTICIPANT	\N	PRESENT	0
726808	725874	14331P	PARTICIPANT	\N	PRESENT	0
726809	725874	14059S	PARTICIPANT	\N	PRESENT	0
726810	725874	14133K	PARTICIPANT	\N	PRESENT	0
726811	725874	14107H	PARTICIPANT	\N	PRESENT	0
726812	725874	11041F	PARTICIPANT	\N	PRESENT	0
726813	725874	20036X	PARTICIPANT	\N	PRESENT	0
726814	725874	19647E	PARTICIPANT	\N	PRESENT	0
726815	725874	19798U	PARTICIPANT	\N	PRESENT	0
726816	725874	08056B	PARTICIPANT	\N	PRESENT	0
726817	725874	17229F	PARTICIPANT	\N	PRESENT	0
726818	725874	19387D	PARTICIPANT	\N	PRESENT	0
726819	725874	11033F	PARTICIPANT	\N	PRESENT	0
726820	725874	11104D	PARTICIPANT	\N	PRESENT	0
726821	725874	19479G	PARTICIPANT	\N	PRESENT	0
726822	725874	14038Y	PARTICIPANT	\N	PRESENT	0
726823	725874	14259Y	PARTICIPANT	\N	PRESENT	0
726825	725874	19693L	PARTICIPANT	\N	PRESENT	0
726826	725874	01043Q	PARTICIPANT	\N	PRESENT	0
726827	725874	19295A	PARTICIPANT	\N	PRESENT	0
726828	725874	20132W	PARTICIPANT	\N	PRESENT	0
726829	725874	19333N	PARTICIPANT	\N	PRESENT	0
726830	725874	19415P	PARTICIPANT	\N	PRESENT	0
726831	725874	14223L	PARTICIPANT	\N	PRESENT	0
726832	725874	08010L	PARTICIPANT	\N	PRESENT	0
726834	725874	19511N	PARTICIPANT	\N	PRESENT	0
726835	725874	14055N	PARTICIPANT	\N	PRESENT	0
726836	725874	20248J	PARTICIPANT	\N	PRESENT	0
726837	725874	04008A	PARTICIPANT	\N	PRESENT	0
726838	725874	20144B	PARTICIPANT	\N	PRESENT	0
726839	725874	14215L	PARTICIPANT	\N	PRESENT	0
726840	725874	20124W	PARTICIPANT	\N	PRESENT	0
726841	725874	14217N	PARTICIPANT	\N	PRESENT	0
726842	725874	19675J	PARTICIPANT	\N	PRESENT	0
726843	725874	95041E	PARTICIPANT	\N	PRESENT	0
726844	725874	20080C	PARTICIPANT	\N	PRESENT	0
726845	725874	11040E	PARTICIPANT	\N	PRESENT	0
726846	725874	19593H	PARTICIPANT	\N	PRESENT	0
726847	725874	20112S	PARTICIPANT	\N	PRESENT	0
726848	725874	19447X	PARTICIPANT	\N	PRESENT	0
726849	725874	19637C	PARTICIPANT	\N	PRESENT	0
726850	725874	08060W	PARTICIPANT	\N	PRESENT	0
726851	725874	14097Y	PARTICIPANT	\N	PRESENT	0
726852	725874	19691J	PARTICIPANT	\N	PRESENT	0
726853	725874	20056C	PARTICIPANT	\N	PRESENT	0
726854	725874	11101A	PARTICIPANT	\N	PRESENT	0
726855	725874	19703U	PARTICIPANT	\N	PRESENT	0
726856	725874	20138D	PARTICIPANT	\N	PRESENT	0
726857	725874	19762G	PARTICIPANT	\N	PRESENT	0
726858	725874	20140W	PARTICIPANT	\N	PRESENT	0
726859	725874	20032T	PARTICIPANT	\N	PRESENT	0
726860	725874	20126Y	PARTICIPANT	\N	PRESENT	0
726861	725874	19758L	PARTICIPANT	\N	PRESENT	0
726862	725874	11031D	PARTICIPANT	\N	PRESENT	0
726863	725874	04047H	PARTICIPANT	\N	PRESENT	0
726864	725874	14205J	PARTICIPANT	\N	PRESENT	0
726865	725874	19739H	PARTICIPANT	\N	PRESENT	0
726866	725874	99004R	PARTICIPANT	\N	PRESENT	0
726867	725874	14033T	PARTICIPANT	\N	PRESENT	0
726868	725874	11027H	PARTICIPANT	\N	PRESENT	0
726869	725874	14031R	PARTICIPANT	\N	PRESENT	0
726870	725874	19651A	PARTICIPANT	\N	PRESENT	0
726871	725874	20180F	PARTICIPANT	\N	PRESENT	0
726872	725874	20148F	PARTICIPANT	\N	PRESENT	0
726873	725874	20054A	PARTICIPANT	\N	PRESENT	0
726874	725874	11048N	PARTICIPANT	\N	PRESENT	0
726875	725874	19766L	PARTICIPANT	\N	PRESENT	0
726876	725874	11080N	PARTICIPANT	\N	PRESENT	0
726877	725874	17637T	PARTICIPANT	\N	PRESENT	0
726878	725874	01058X	PARTICIPANT	\N	PRESENT	0
726879	725874	19575F	PARTICIPANT	\N	PRESENT	0
726880	725874	18083K	PARTICIPANT	\N	PRESENT	0
726881	725874	20152B	PARTICIPANT	\N	PRESENT	0
726882	725874	14030Q	PARTICIPANT	\N	PRESENT	0
726883	725874	14327T	PARTICIPANT	\N	PRESENT	0
726884	725874	19611R	PARTICIPANT	\N	PRESENT	0
726885	725874	01024M	PARTICIPANT	\N	PRESENT	0
726886	725874	01025N	PARTICIPANT	\N	PRESENT	0
726887	725874	19643A	PARTICIPANT	\N	PRESENT	0
726888	725874	19421M	PARTICIPANT	\N	PRESENT	0
726889	725874	19533U	PARTICIPANT	\N	PRESENT	0
726890	725874	14357A	PARTICIPANT	\N	PRESENT	0
726891	725874	14147R	PARTICIPANT	\N	PRESENT	0
726892	725874	14187A	PARTICIPANT	\N	PRESENT	0
726893	725874	04085P	PARTICIPANT	\N	PRESENT	0
726894	725874	19760E	PARTICIPANT	\N	PRESENT	0
726895	725874	20102Q	PARTICIPANT	\N	PRESENT	0
726896	725874	12041X	PARTICIPANT	\N	PRESENT	0
726897	725874	19687N	PARTICIPANT	\N	PRESENT	0
726898	725874	20046A	PARTICIPANT	\N	PRESENT	0
726899	725874	20110Q	PARTICIPANT	\N	PRESENT	0
726900	725874	20914V	PARTICIPANT	\N	PRESENT	0
726901	725874	11065P	PARTICIPANT	\N	PRESENT	0
726902	725874	08034U	PARTICIPANT	\N	PRESENT	0
726903	725874	20134Y	PARTICIPANT	\N	PRESENT	0
726904	725874	20142Y	PARTICIPANT	\N	PRESENT	0
726905	725874	20130U	PARTICIPANT	\N	PRESENT	0
726906	725874	20092G	PARTICIPANT	\N	PRESENT	0
726907	725874	11097X	PARTICIPANT	\N	PRESENT	0
726908	725874	19782L	PARTICIPANT	\N	PRESENT	0
726909	725874	01048V	PARTICIPANT	\N	PRESENT	0
726910	725874	05008E	PARTICIPANT	\N	PRESENT	0
726911	725874	14249W	PARTICIPANT	\N	PRESENT	0
726912	725874	11043H	PARTICIPANT	\N	PRESENT	0
726913	725874	04033B	PARTICIPANT	\N	PRESENT	0
726914	725874	10015M	PARTICIPANT	\N	PRESENT	0
726915	725874	20128B	PARTICIPANT	\N	PRESENT	0
726916	725874	04042C	PARTICIPANT	\N	PRESENT	0
726917	725874	14037X	PARTICIPANT	\N	PRESENT	0
726918	725874	19747H	PARTICIPANT	\N	PRESENT	0
726919	725874	11072N	PARTICIPANT	\N	PRESENT	0
726920	725874	08061X	PARTICIPANT	\N	PRESENT	0
726921	725874	17367Q	PARTICIPANT	\N	PRESENT	0
726922	725874	19349W	PARTICIPANT	\N	PRESENT	0
726923	725874	95063L	PARTICIPANT	\N	PRESENT	0
726924	725874	19515S	PARTICIPANT	\N	PRESENT	0
726925	725874	04045F	PARTICIPANT	\N	PRESENT	0
726926	725874	01057W	PARTICIPANT	\N	PRESENT	0
726927	725874	20068G	PARTICIPANT	\N	PRESENT	0
726928	725874	19659J	PARTICIPANT	\N	PRESENT	0
726929	725874	20022R	PARTICIPANT	\N	PRESENT	0
726930	725874	11090Q	PARTICIPANT	\N	PRESENT	0
726931	725874	04043D	PARTICIPANT	\N	PRESENT	0
726932	725874	14207L	PARTICIPANT	\N	PRESENT	0
726933	725874	19629C	PARTICIPANT	\N	PRESENT	0
726934	725874	19671E	PARTICIPANT	\N	PRESENT	0
726935	725874	19553Y	PARTICIPANT	\N	PRESENT	0
726936	725874	19679N	PARTICIPANT	\N	PRESENT	0
720892	720823	19447X	PARTICIPANT	\N	PRESENT	0
720893	720823	19826F	PARTICIPANT	\N	PRESENT	0
720894	720823	20076G	PARTICIPANT	\N	PRESENT	0
720895	720823	20054A	PARTICIPANT	\N	PRESENT	0
720896	720823	19820Y	PARTICIPANT	\N	PRESENT	0
720897	720823	20046A	PARTICIPANT	\N	PRESENT	0
720898	720823	19782L	PARTICIPANT	\N	PRESENT	0
720899	720823	20142Y	PARTICIPANT	\N	PRESENT	0
720900	720823	19503N	PARTICIPANT	\N	PRESENT	0
720901	720823	14231L	PARTICIPANT	\N	PRESENT	0
720902	720823	14205J	PARTICIPANT	\N	PRESENT	0
720903	720823	19866P	PARTICIPANT	\N	PRESENT	0
720904	720823	14169X	PARTICIPANT	\N	PRESENT	0
720905	720823	20078J	PARTICIPANT	\N	PRESENT	0
720906	720823	20090E	PARTICIPANT	\N	PRESENT	0
720907	720823	19467C	PARTICIPANT	\N	PRESENT	0
720908	720823	19507S	PARTICIPANT	\N	PRESENT	0
720909	720823	19798U	PARTICIPANT	\N	PRESENT	0
720910	720823	20914V	PARTICIPANT	\N	PRESENT	0
720911	720823	14031R	PARTICIPANT	\N	PRESENT	0
720912	720823	14053L	PARTICIPANT	\N	PRESENT	0
720913	720823	19725B	PARTICIPANT	\N	PRESENT	0
720914	720823	20100N	PARTICIPANT	\N	PRESENT	0
720915	720823	18083K	PARTICIPANT	\N	PRESENT	0
720916	720823	20056C	PARTICIPANT	\N	PRESENT	0
720917	720823	20044X	PARTICIPANT	\N	PRESENT	0
720918	720823	20140W	PARTICIPANT	\N	PRESENT	0
720919	720823	14033T	PARTICIPANT	\N	PRESENT	0
720920	720823	20026V	PARTICIPANT	\N	PRESENT	0
720921	720823	19723Y	PARTICIPANT	\N	PRESENT	0
720922	720823	20048C	PARTICIPANT	\N	PRESENT	0
720923	720823	20052X	PARTICIPANT	\N	PRESENT	0
720924	720823	20072C	PARTICIPANT	\N	PRESENT	0
720925	720823	14207L	PARTICIPANT	\N	PRESENT	0
720926	720823	19695N	PARTICIPANT	\N	PRESENT	0
720927	720823	14147R	PARTICIPANT	\N	PRESENT	0
720928	720823	16685X	PARTICIPANT	\N	PRESENT	0
720929	720823	14073Q	PARTICIPANT	\N	PRESENT	0
720930	720823	19347U	PARTICIPANT	\N	PRESENT	0
720931	720823	19573D	PARTICIPANT	\N	PRESENT	0
720932	720823	20092G	PARTICIPANT	\N	PRESENT	0
720933	720823	14215L	PARTICIPANT	\N	PRESENT	0
720934	720823	20248J	PARTICIPANT	\N	PRESENT	0
720935	720823	19719D	PARTICIPANT	\N	PRESENT	0
720936	720823	07029T	PARTICIPANT	\N	PRESENT	0
720937	720823	19729F	PARTICIPANT	\N	PRESENT	0
720938	720823	19533U	PARTICIPANT	\N	PRESENT	0
720939	720823	08010L	PARTICIPANT	\N	PRESENT	0
720940	720823	11064N	PARTICIPANT	\N	PRESENT	0
720941	720823	20124W	PARTICIPANT	\N	PRESENT	0
720942	720823	14219Q	PARTICIPANT	\N	PRESENT	0
720943	720823	20104S	PARTICIPANT	\N	PRESENT	0
720944	720823	20180F	PARTICIPANT	\N	PRESENT	0
720945	720823	20094J	PARTICIPANT	\N	PRESENT	0
720946	720823	20126Y	PARTICIPANT	\N	PRESENT	0
720947	720823	19569H	PARTICIPANT	\N	PRESENT	0
720890	720823	11045K	PARTICIPANT	\N	PRESENT	0
720891	720823	14097Y	PARTICIPANT	\N	PRESENT	0
720948	720823	19383Y	PARTICIPANT	\N	PRESENT	0
720949	720823	14042U	PARTICIPANT	\N	PRESENT	0
720950	720823	20032T	PARTICIPANT	\N	PRESENT	0
720951	720823	20128B	PARTICIPANT	\N	PRESENT	0
720952	720823	20096L	PARTICIPANT	\N	PRESENT	0
720953	720823	20114U	PARTICIPANT	\N	PRESENT	0
720954	720823	19563B	PARTICIPANT	\N	PRESENT	0
720955	720823	11056N	PARTICIPANT	\N	PRESENT	0
720966	720965	14133K	PARTICIPANT	\N	PRESENT	0
720967	720965	20086J	PARTICIPANT	\N	PRESENT	0
720968	720965	20104S	PARTICIPANT	\N	PRESENT	0
720969	720965	18083K	PARTICIPANT	\N	PRESENT	0
720970	720965	11056N	PARTICIPANT	\N	PRESENT	0
720971	720965	07033P	PARTICIPANT	\N	PRESENT	0
720972	720965	04035D	PARTICIPANT	\N	PRESENT	0
720973	720965	14097Y	PARTICIPANT	\N	PRESENT	0
720974	720965	19611R	PARTICIPANT	\N	PRESENT	0
720975	720965	11026G	PARTICIPANT	\N	PRESENT	0
720976	720965	01048V	PARTICIPANT	\N	PRESENT	0
720977	720965	14059S	PARTICIPANT	\N	PRESENT	0
720978	720965	05012A	PARTICIPANT	\N	PRESENT	0
720979	720965	19503N	PARTICIPANT	\N	PRESENT	0
720980	720965	19349W	PARTICIPANT	\N	PRESENT	0
720981	720965	20054A	PARTICIPANT	\N	PRESENT	0
720982	720965	19713W	PARTICIPANT	\N	PRESENT	0
720983	720965	20064C	PARTICIPANT	\N	PRESENT	0
721000	720107	19760E	PARTICIPANT	\N	PRESENT	0
721007	720107	18193Q	PARTICIPANT	\N	PRESENT	0
721008	720107	19683J	PARTICIPANT	\N	PRESENT	0
721009	720107	11067R	PARTICIPANT	\N	PRESENT	0
721010	720107	14281W	PARTICIPANT	\N	PRESENT	0
721011	720107	19569H	PARTICIPANT	\N	PRESENT	0
721012	720107	19691J	PARTICIPANT	\N	PRESENT	0
721013	720107	20090E	PARTICIPANT	\N	PRESENT	0
721014	720107	10006L	PRESIDENT	0	PRESENT	0
721015	720107	14213J	PARTICIPANT	\N	PRESENT	0
721016	720107	20066E	PARTICIPANT	\N	PRESENT	0
721017	720107	14217N	PARTICIPANT	\N	PRESENT	0
721018	720107	19367Y	PARTICIPANT	\N	PRESENT	0
721019	720107	04092N	PARTICIPANT	\N	PRESENT	0
721023	720107	19703U	PARTICIPANT	\N	PRESENT	0
721024	720107	20148F	PARTICIPANT	\N	PRESENT	0
721025	720107	20130U	PARTICIPANT	\N	PRESENT	0
721026	720107	19657G	PARTICIPANT	\N	PRESENT	0
721027	720107	19798U	PARTICIPANT	\N	PRESENT	0
721028	720107	17965H	PARTICIPANT	\N	PRESENT	0
721029	720107	19679N	PARTICIPANT	\N	PRESENT	0
721031	720107	19723Y	PARTICIPANT	\N	PRESENT	0
721032	720107	19415P	PARTICIPANT	\N	PRESENT	0
721033	720107	14042U	PARTICIPANT	\N	PRESENT	0
721034	720107	20040T	PARTICIPANT	\N	PRESENT	0
721035	720107	14071N	PARTICIPANT	\N	PRESENT	0
721039	720107	19715Y	PARTICIPANT	\N	PRESENT	0
721040	720107	19697Q	PARTICIPANT	\N	PRESENT	0
721041	720107	04043D	PARTICIPANT	\N	PRESENT	0
721115	720107	04057K	PARTICIPANT	\N	PRESENT	0
721116	720107	19713W	PARTICIPANT	\N	PRESENT	0
721117	720107	19329S	PARTICIPANT	\N	PRESENT	0
721118	720107	14026U	PARTICIPANT	\N	PRESENT	0
721119	720107	20248J	PARTICIPANT	\N	PRESENT	0
721146	720107	19663E	PARTICIPANT	\N	PRESENT	0
721194	720107	14223L	PARTICIPANT	\N	PRESENT	0
721227	720107	20266L	PARTICIPANT	\N	PRESENT	0
721237	720107	17779H	PARTICIPANT	\N	PRESENT	0
725435	722809	01058X	PARTICIPANT	\N	PRESENT	0
725590	725589	20124W	PARTICIPANT	\N	PRESENT	1
725605	725587	20094J	PARTICIPANT	\N	PRESENT	0
725706	725705	19711U	PARTICIPANT	\N	PRESENT	0
725708	725707	11053K	PARTICIPANT	\N	PRESENT	0
725710	725709	11053K	PARTICIPANT	\N	PRESENT	0
725712	725711	19741B	PARTICIPANT	\N	PRESENT	0
725715	725714	08034U	PARTICIPANT	\N	PRESENT	0
725717	725716	08034U	PARTICIPANT	\N	PRESENT	0
725719	725718	08034U	PARTICIPANT	\N	PRESENT	0
725721	725720	08073C	PARTICIPANT	\N	PRESENT	0
725722	725720	20150Y	PARTICIPANT	\N	PRESENT	0
725724	725723	08073C	PARTICIPANT	\N	PRESENT	0
725725	725723	20150Y	PARTICIPANT	\N	PRESENT	0
725727	725726	08073C	PARTICIPANT	\N	PRESENT	0
725728	725726	20150Y	PARTICIPANT	\N	PRESENT	0
725730	725729	08073C	PARTICIPANT	\N	PRESENT	0
725731	725729	20150Y	PARTICIPANT	\N	PRESENT	0
725733	725732	08073C	PARTICIPANT	\N	PRESENT	0
725734	725732	20150Y	PARTICIPANT	\N	PRESENT	0
725736	725735	08073C	PARTICIPANT	\N	PRESENT	0
725737	725735	20150Y	PARTICIPANT	\N	PRESENT	0
725739	725738	08073C	PARTICIPANT	\N	PRESENT	0
725740	725738	20150Y	PARTICIPANT	\N	PRESENT	0
725742	725741	08073C	PARTICIPANT	\N	PRESENT	0
725743	725741	20150Y	PARTICIPANT	\N	PRESENT	0
725745	725744	08073C	PARTICIPANT	\N	PRESENT	0
725746	725744	20150Y	PARTICIPANT	\N	PRESENT	0
725748	725747	11077T	PARTICIPANT	\N	PRESENT	0
725749	725747	14037X	PARTICIPANT	\N	PRESENT	0
725751	725750	11077T	PARTICIPANT	\N	PRESENT	0
725752	725750	14037X	PARTICIPANT	\N	PRESENT	0
725755	725754	14037X	PARTICIPANT	\N	PRESENT	0
725756	725753	20070A	PARTICIPANT	\N	PRESENT	0
725757	725754	11077T	PARTICIPANT	\N	PRESENT	0
725758	725753	11110B	PARTICIPANT	\N	PRESENT	0
725760	725759	11077T	PARTICIPANT	\N	PRESENT	0
725761	725759	14037X	PARTICIPANT	\N	PRESENT	0
725763	725762	14037X	PARTICIPANT	\N	PRESENT	0
718544	715224	19735D	PRESIDENT	0	PRESENT	0
718545	715224	20024T	PARTICIPANT	\N	PRESENT	0
718546	715224	14213J	PARTICIPANT	\N	PRESENT	0
718547	715224	11031D	PARTICIPANT	\N	PRESENT	0
718548	715224	20096L	PARTICIPANT	\N	PRESENT	0
718549	715224	17965H	PARTICIPANT	\N	PRESENT	0
718550	715224	20050V	PARTICIPANT	\N	EXCUSE	0
718551	715224	20138D	PARTICIPANT	\N	EXCUSE	0
718552	715224	04045F	PARTICIPANT	\N	PRESENT	0
718553	715224	14026U	PARTICIPANT	\N	PRESENT	0
718607	718606	14038Y	PARTICIPANT	\N	PRESENT	0
718608	718606	14357A	PARTICIPANT	\N	PRESENT	0
718609	718606	01024M	PARTICIPANT	\N	PRESENT	0
718610	718606	20038A	PARTICIPANT	\N	PRESENT	0
718611	718606	14033T	PARTICIPANT	\N	PRESENT	0
718612	718606	20018V	PARTICIPANT	\N	PRESENT	0
718613	718606	19369B	PARTICIPANT	\N	PRESENT	0
718614	718606	14257W	PARTICIPANT	\N	PRESENT	0
718615	718606	20092G	PARTICIPANT	\N	PRESENT	0
718616	718606	20062A	PARTICIPANT	\N	PRESENT	0
718617	718606	08028W	PARTICIPANT	\N	PRESENT	0
718619	718618	14237S	PARTICIPANT	\N	PRESENT	0
718620	718618	20058E	PARTICIPANT	\N	PRESENT	0
718802	718801	08012N	PARTICIPANT	\N	PRESENT	0
718803	718801	19525U	PARTICIPANT	\N	PRESENT	0
718804	718801	20056C	PARTICIPANT	\N	PRESENT	0
718805	718801	04057K	PARTICIPANT	\N	PRESENT	0
718806	718801	20180F	PARTICIPANT	\N	PRESENT	0
718807	718801	19333N	PARTICIPANT	\N	PRESENT	0
718808	718801	20026V	PARTICIPANT	\N	PRESENT	0
719039	719038	19711U	PARTICIPANT	\N	PRESENT	0
719040	719038	04033B	PARTICIPANT	\N	PRESENT	0
719041	719038	14187A	PARTICIPANT	\N	PRESENT	0
719042	719038	20024T	PARTICIPANT	\N	PRESENT	0
719043	719038	14189C	PARTICIPANT	\N	PRESENT	0
719044	719038	14215L	PARTICIPANT	\N	PRESENT	0
719045	719038	19647E	PARTICIPANT	\N	PRESENT	0
719046	719038	19593H	PARTICIPANT	\N	PRESENT	0
719047	719038	14331P	PARTICIPANT	\N	PRESENT	0
719049	719048	19711U	PARTICIPANT	\N	PRESENT	0
719050	719048	14255U	PARTICIPANT	\N	PRESENT	0
719051	719048	20132W	PARTICIPANT	\N	PRESENT	0
719053	719052	19711U	PARTICIPANT	\N	PRESENT	0
720460	720458	20086J	PARTICIPANT	\N	PRESENT	0
720470	720468	20086J	PARTICIPANT	\N	PRESENT	0
721385	719035	20106U	PARTICIPANT	\N	EXCUSE	0
722333	722332	20116W	PARTICIPANT	\N	PRESENT	0
722334	722332	19545Y	PARTICIPANT	\N	PRESENT	0
722335	722332	11080N	PRESIDENT	0	PRESENT	0
722336	722332	01057W	PARTICIPANT	\N	PRESENT	0
722337	722332	14121F	PARTICIPANT	\N	PRESENT	0
722338	722332	19687N	PARTICIPANT	\N	PRESENT	0
722551	722550	04035D	PARTICIPANT	\N	PRESENT	0
722552	722550	14249W	PARTICIPANT	\N	PRESENT	0
722553	722550	17023S	PARTICIPANT	\N	PRESENT	0
722554	722550	07033P	PARTICIPANT	\N	PRESENT	0
722555	722550	11041F	PARTICIPANT	\N	PRESENT	0
722581	722579	04035D	PARTICIPANT	\N	PRESENT	0
722582	722579	07033P	PARTICIPANT	\N	PRESENT	0
722583	722579	14249W	PARTICIPANT	\N	PRESENT	0
722584	722579	17023S	PARTICIPANT	\N	PRESENT	0
722585	722579	11041F	PARTICIPANT	\N	PRESENT	0
722590	722589	07033P	PARTICIPANT	\N	PRESENT	0
722596	722595	07033P	PARTICIPANT	\N	PRESENT	0
722592	722589	04035D	PARTICIPANT	\N	PRESENT	0
722593	722589	11041F	PARTICIPANT	\N	PRESENT	0
722594	722589	14249W	PARTICIPANT	\N	PRESENT	0
722597	722595	04035D	PARTICIPANT	\N	PRESENT	0
722598	722595	11041F	PARTICIPANT	\N	PRESENT	0
728567	728406	14187A	PRESIDENT	0	PRESENT	0
726668	726667	14097Y	PARTICIPANT	\N	PRESENT	0
728568	728406	19711U	PARTICIPANT	\N	PRESENT	0
728569	728406	20298U	PARTICIPANT	\N	PRESENT	0
728570	728406	19347U	PARTICIPANT	\N	PRESENT	0
728571	728406	20124W	PARTICIPANT	\N	PRESENT	0
728576	728406	20018V	PARTICIPANT	\N	PRESENT	0
728689	728406	14257W	PARTICIPANT	\N	PRESENT	0
728702	728406	18083K	PARTICIPANT	\N	PRESENT	0
731042	731011	20084G	PARTICIPANT	\N	PRESENT	0
735941	735596	19695N	PARTICIPANT	\N	PRESENT	0
735942	735596	19593H	PARTICIPANT	\N	PRESENT	0
736215	735535	11045K	PARTICIPANT	\N	PRESENT	0
736216	735913	14225N	PRESIDENT	0	PRESENT	0
736217	735535	19599P	PARTICIPANT	\N	PRESENT	0
736218	735535	19593H	PARTICIPANT	\N	PRESENT	0
736219	735535	11056N	PARTICIPANT	\N	PRESENT	0
736220	735535	19251M	PARTICIPANT	\N	PRESENT	0
736221	735535	19631V	PARTICIPANT	\N	PRESENT	0
736222	735535	14121F	PARTICIPANT	\N	PRESENT	0
736223	735535	20084G	PARTICIPANT	\N	PRESENT	0
736224	735535	01058X	PARTICIPANT	\N	PRESENT	0
736225	735535	19575F	PARTICIPANT	\N	PRESENT	0
736226	735535	20082E	PARTICIPANT	\N	PRESENT	0
736227	735535	20298U	PARTICIPANT	\N	PRESENT	0
736228	735535	20078J	PARTICIPANT	\N	PRESENT	0
736229	735535	19749K	PARTICIPANT	\N	PRESENT	0
736230	735535	10015M	PARTICIPANT	\N	PRESENT	0
736231	735535	20140W	PARTICIPANT	\N	PRESENT	0
736232	735535	19782L	PARTICIPANT	\N	PRESENT	0
736233	735535	20056C	PARTICIPANT	\N	PRESENT	0
736234	735535	19349W	PARTICIPANT	\N	PRESENT	0
736235	735535	19383Y	PARTICIPANT	\N	PRESENT	0
736236	735535	08061X	PARTICIPANT	\N	PRESENT	0
736237	735535	19954N	PARTICIPANT	\N	PRESENT	0
736238	735535	11064N	PARTICIPANT	\N	PRESENT	0
736239	735535	20180F	PARTICIPANT	\N	PRESENT	0
736240	735535	20132W	PARTICIPANT	\N	PRESENT	0
736241	735535	19866P	PARTICIPANT	\N	PRESENT	0
736242	735535	19629C	PARTICIPANT	\N	PRESENT	0
736243	735535	98022P	PARTICIPANT	\N	PRESENT	0
736244	735535	20072C	PARTICIPANT	\N	PRESENT	0
736245	735535	20980G	PARTICIPANT	\N	PRESENT	0
736246	735535	14107H	PARTICIPANT	\N	PRESENT	0
736247	735535	20034V	PARTICIPANT	\N	PRESENT	0
736248	735535	14189C	PARTICIPANT	\N	PRESENT	0
736249	735535	20044X	PARTICIPANT	\N	PRESENT	0
736250	735535	14123H	PARTICIPANT	\N	PRESENT	0
736251	735535	14089Y	PARTICIPANT	\N	PRESENT	0
736252	735535	20086J	PARTICIPANT	\N	PRESENT	0
736253	735535	14038Y	PARTICIPANT	\N	PRESENT	0
736254	735535	19467C	PARTICIPANT	\N	PRESENT	0
736255	735535	19507S	PARTICIPANT	\N	PRESENT	0
736256	735535	19565D	PARTICIPANT	\N	PRESENT	0
736257	735535	97011G	PARTICIPANT	\N	PRESENT	0
736258	735535	19581D	PARTICIPANT	\N	PRESENT	0
736259	735535	20062A	PARTICIPANT	\N	PRESENT	0
736260	735535	19762G	PARTICIPANT	\N	PRESENT	0
736261	735535	14237S	PARTICIPANT	\N	PRESENT	0
736262	735535	20022R	PARTICIPANT	\N	PRESENT	0
736263	735535	20152B	PARTICIPANT	\N	PRESENT	0
736264	735535	19387D	PARTICIPANT	\N	PRESENT	0
736265	735535	14026U	PARTICIPANT	\N	PRESENT	0
736266	735535	14213J	PARTICIPANT	\N	PRESENT	0
736267	735535	20024T	PARTICIPANT	\N	PRESENT	0
736268	735535	08028W	PARTICIPANT	\N	PRESENT	0
736269	735535	14205J	PARTICIPANT	\N	PRESENT	0
736270	735535	19479G	PARTICIPANT	\N	PRESENT	0
736271	735535	19745F	PARTICIPANT	\N	PRESENT	0
736272	735535	19747H	PARTICIPANT	\N	PRESENT	0
736273	735535	19691J	PARTICIPANT	\N	PRESENT	0
736274	735535	01025N	PARTICIPANT	\N	PRESENT	0
736275	735535	14033T	PARTICIPANT	\N	PRESENT	0
736276	735535	18083K	PARTICIPANT	\N	PRESENT	0
736277	735535	19583F	PARTICIPANT	\N	PRESENT	0
736278	735913	11048N	PARTICIPANT	\N	PRESENT	0
736279	735913	20080C	PARTICIPANT	\N	PRESENT	0
736280	735535	19333N	PARTICIPANT	\N	PRESENT	0
736281	735535	14147R	PARTICIPANT	\N	PRESENT	0
736297	735913	19671E	PARTICIPANT	\N	PRESENT	0
736298	735913	07029T	PARTICIPANT	\N	PRESENT	0
736845	736843	17367Q	PARTICIPANT	\N	PRESENT	0
736846	736843	14069U	PARTICIPANT	\N	PRESENT	0
736847	736843	14083S	PARTICIPANT	\N	PRESENT	0
736848	736843	19681G	PARTICIPANT	\N	PRESENT	0
736849	736843	19719D	PARTICIPANT	\N	PRESENT	0
736850	736843	11070L	PARTICIPANT	\N	PRESENT	0
736851	736843	01024M	PARTICIPANT	\N	PRESENT	0
736852	736843	20038A	PARTICIPANT	\N	PRESENT	0
736853	736843	19820Y	PARTICIPANT	\N	PRESENT	0
736854	736843	14033T	PARTICIPANT	\N	PRESENT	0
736855	736843	20126Y	PARTICIPANT	\N	PRESENT	0
713472	704309	14030Q	PARTICIPANT	\N	PRESENT	0
713473	704309	19749K	PARTICIPANT	\N	PRESENT	0
713474	704309	19798U	PARTICIPANT	\N	PRESENT	0
713478	712272	14331P	PARTICIPANT	\N	EXCUSE	0
713479	712272	19467C	PARTICIPANT	\N	EXCUSE	0
713480	712272	20172F	PARTICIPANT	\N	EXCUSE	0
714249	714162	14327T	PARTICIPANT	\N	PRESENT	0
714250	714162	20086J	PARTICIPANT	\N	PRESENT	0
714251	714162	01048V	PARTICIPANT	\N	PRESENT	0
714252	714162	01057W	PARTICIPANT	\N	PRESENT	0
714253	714162	20080C	PARTICIPANT	\N	PRESENT	0
714254	714162	11053K	PARTICIPANT	\N	PRESENT	0
714255	714162	11074Q	PARTICIPANT	\N	PRESENT	0
714256	714162	19667J	PARTICIPANT	\N	PRESENT	0
714257	714162	19671E	PARTICIPANT	\N	PRESENT	0
714258	714162	14225N	PARTICIPANT	\N	PRESENT	0
714259	714162	19349W	PARTICIPANT	\N	PRESENT	0
714260	714162	20116W	PARTICIPANT	\N	PRESENT	0
714261	714162	19335Q	PARTICIPANT	\N	PRESENT	0
714262	714162	20126Y	PARTICIPANT	\N	PRESENT	0
714263	714162	11048N	PARTICIPANT	\N	PRESENT	0
714264	714162	19711U	PARTICIPANT	\N	PRESENT	0
714265	714162	20044X	PARTICIPANT	\N	PRESENT	0
714266	714162	14173T	PARTICIPANT	\N	PRESENT	0
714267	714162	14083S	PARTICIPANT	\N	PRESENT	0
714268	714162	20070A	PARTICIPANT	\N	PRESENT	0
714269	714162	08009T	PARTICIPANT	\N	PRESENT	0
714270	714162	14121F	PARTICIPANT	\N	PRESENT	0
714271	714162	19741B	PARTICIPANT	\N	PRESENT	0
714272	714162	20914V	PARTICIPANT	\N	PRESENT	0
714273	714162	99004R	PARTICIPANT	\N	PRESENT	0
714274	714162	20050V	PARTICIPANT	\N	EXCUSE	0
714275	714163	20086J	PARTICIPANT	\N	PRESENT	0
714276	714163	04071H	PARTICIPANT	\N	PRESENT	0
714277	714163	11012A	PARTICIPANT	\N	PRESENT	0
714278	712198	95041E	PARTICIPANT	\N	PRESENT	0
714279	712198	08056B	PARTICIPANT	\N	PRESENT	0
714280	712198	11115U	PARTICIPANT	\N	PRESENT	0
714281	712198	14193X	PARTICIPANT	\N	PRESENT	0
714282	712198	08061X	PARTICIPANT	\N	PRESENT	0
714283	712198	97011G	PARTICIPANT	\N	PRESENT	0
714284	712198	14249W	PARTICIPANT	\N	PRESENT	0
714285	711614	08018U	PARTICIPANT	\N	PRESENT	0
714286	714163	11048N	PARTICIPANT	\N	PRESENT	0
714287	714163	19711U	PARTICIPANT	\N	PRESENT	0
714288	714163	01057W	PARTICIPANT	\N	PRESENT	0
714289	714163	11074Q	PARTICIPANT	\N	PRESENT	0
714290	714163	20044X	PARTICIPANT	\N	PRESENT	0
714291	714163	19671E	PARTICIPANT	\N	PRESENT	0
714292	714163	14083S	PARTICIPANT	\N	PRESENT	0
714293	714163	20070A	PARTICIPANT	\N	PRESENT	0
714294	714163	08009T	PARTICIPANT	\N	PRESENT	0
714295	714163	19349W	PARTICIPANT	\N	PRESENT	0
714296	714163	14121F	PARTICIPANT	\N	PRESENT	0
714297	714163	19741B	PARTICIPANT	\N	PRESENT	0
714298	714163	20914V	PARTICIPANT	\N	PRESENT	0
714299	714163	19335Q	PARTICIPANT	\N	PRESENT	0
714300	714163	14189C	PARTICIPANT	\N	PRESENT	0
714301	714163	19531S	PARTICIPANT	\N	PRESENT	0
714620	712588	20134Y	PARTICIPANT	\N	PRESENT	0
714621	712588	10015M	PARTICIPANT	\N	PRESENT	0
714622	712588	20142Y	PARTICIPANT	\N	PRESENT	0
714623	712588	11033F	PARTICIPANT	\N	PRESENT	0
714624	712588	04071H	PARTICIPANT	\N	PRESENT	0
714625	712588	19651A	PARTICIPANT	\N	PRESENT	0
714626	712588	17367Q	PARTICIPANT	\N	PRESENT	0
714627	712588	19717B	PARTICIPANT	\N	PRESENT	0
714628	712588	14223L	PARTICIPANT	\N	PRESENT	0
714629	712588	08028W	PARTICIPANT	\N	PRESENT	0
714630	712588	20116W	PARTICIPANT	\N	PRESENT	0
714631	712588	14207L	PARTICIPANT	\N	PRESENT	0
714632	712588	19866P	PARTICIPANT	\N	PRESENT	0
714633	712588	11012A	PARTICIPANT	\N	PRESENT	0
714634	712588	20074E	PARTICIPANT	\N	PRESENT	0
714635	712588	19387D	PARTICIPANT	\N	PRESENT	0
714636	712588	19719D	PARTICIPANT	\N	PRESENT	0
714637	712588	20122U	PARTICIPANT	\N	PRESENT	0
714638	712588	18083K	PARTICIPANT	\N	PRESENT	0
714639	712588	14123H	PARTICIPANT	\N	PRESENT	0
714640	712588	08069G	PARTICIPANT	\N	PRESENT	0
714641	712588	19629C	PARTICIPANT	\N	PRESENT	0
714642	712588	04042C	PARTICIPANT	\N	PRESENT	0
714643	712588	20132W	PARTICIPANT	\N	PRESENT	0
714644	712588	11048N	PARTICIPANT	\N	PRESENT	0
714645	712588	14107H	PARTICIPANT	\N	PRESENT	0
714646	712588	19693L	PARTICIPANT	\N	PRESENT	0
714647	712588	19553Y	PARTICIPANT	\N	PRESENT	0
714648	712588	14195A	PARTICIPANT	\N	PRESENT	0
714649	712588	04047H	PARTICIPANT	\N	PRESENT	0
714650	712588	17589D	PARTICIPANT	\N	PRESENT	0
714651	712588	08010L	PARTICIPANT	\N	PRESENT	0
714652	712588	19585H	PARTICIPANT	\N	PRESENT	0
714653	712588	19747H	PARTICIPANT	\N	PRESENT	0
714654	712588	20050V	PARTICIPANT	\N	PRESENT	0
714655	712588	08034U	PARTICIPANT	\N	PRESENT	0
714656	712588	19563B	PARTICIPANT	\N	PRESENT	0
714657	712588	14215L	PARTICIPANT	\N	PRESENT	0
714658	712588	04057K	PARTICIPANT	\N	PRESENT	0
714659	712588	14221J	PARTICIPANT	\N	PRESENT	0
714660	712588	19421M	PARTICIPANT	\N	PRESENT	0
714661	712588	14187A	PARTICIPANT	\N	PRESENT	0
714662	712588	19545Y	PARTICIPANT	\N	PRESENT	0
714663	712588	04033B	PARTICIPANT	\N	PRESENT	0
714664	712588	14053L	PARTICIPANT	\N	PRESENT	0
714665	712588	19701S	PARTICIPANT	\N	PRESENT	0
714666	712588	19533U	PARTICIPANT	\N	PRESENT	0
714667	712588	20118Y	PARTICIPANT	\N	PRESENT	0
714668	712588	14193X	PARTICIPANT	\N	PRESENT	0
714669	712588	14237S	PARTICIPANT	\N	PRESENT	0
714670	712588	19671E	PARTICIPANT	\N	PRESENT	0
714671	712588	19367Y	PARTICIPANT	\N	PRESENT	0
714672	712588	19581D	PARTICIPANT	\N	PRESENT	0
714673	712588	20054A	PARTICIPANT	\N	PRESENT	0
714674	712588	20126Y	PARTICIPANT	\N	PRESENT	0
714675	712588	19383Y	PARTICIPANT	\N	PRESENT	0
714676	712588	19762G	PARTICIPANT	\N	PRESENT	0
714677	712588	04059M	PARTICIPANT	\N	PRESENT	0
714678	712588	07033P	PARTICIPANT	\N	PRESENT	0
714679	712588	14329V	PARTICIPANT	\N	PRESENT	0
714680	712588	19631V	PARTICIPANT	\N	PRESENT	0
714681	712588	97011G	PARTICIPANT	\N	PRESENT	0
714682	712588	14357A	PARTICIPANT	\N	PRESENT	0
714683	712588	19527W	PARTICIPANT	\N	PRESENT	0
714684	712588	19413M	PARTICIPANT	\N	PRESENT	0
714685	712588	08056B	PARTICIPANT	\N	PRESENT	0
714686	712588	19531S	PARTICIPANT	\N	PRESENT	0
714687	712588	11026G	PARTICIPANT	\N	PRESENT	0
714688	712588	20082E	PARTICIPANT	\N	PRESENT	0
714689	712588	14059S	PARTICIPANT	\N	PRESENT	0
714690	712588	20030R	PARTICIPANT	\N	PRESENT	0
714691	712588	19251M	PARTICIPANT	\N	PRESENT	0
714692	712588	20090E	PARTICIPANT	\N	PRESENT	0
714693	712588	12028B	PARTICIPANT	\N	PRESENT	0
714694	712588	20062A	PARTICIPANT	\N	PRESENT	0
714695	712588	19503N	PARTICIPANT	\N	PRESENT	0
714696	712588	19295A	PARTICIPANT	\N	PRESENT	0
714697	712588	20094J	PARTICIPANT	\N	PRESENT	0
714698	712588	20080C	PARTICIPANT	\N	PRESENT	0
714699	712588	19705W	PARTICIPANT	\N	PRESENT	0
714700	712588	19820Y	PARTICIPANT	\N	PRESENT	0
714701	712588	18193Q	PARTICIPANT	\N	PRESENT	0
714702	712588	14109K	PARTICIPANT	\N	PRESENT	0
714703	712588	11067R	PARTICIPANT	\N	PRESENT	0
714704	712588	20028X	PARTICIPANT	\N	PRESENT	0
714705	712588	20114U	PARTICIPANT	\N	PRESENT	0
714706	712588	14031R	PARTICIPANT	\N	PRESENT	0
714707	712588	14151M	PARTICIPANT	\N	PRESENT	0
714708	712588	19333N	PARTICIPANT	\N	PRESENT	0
714709	712588	19329S	PARTICIPANT	\N	PRESENT	0
714710	712588	08018U	PARTICIPANT	\N	PRESENT	0
714711	712588	20070A	PARTICIPANT	\N	PRESENT	0
714712	712588	19489J	PARTICIPANT	\N	PRESENT	0
714713	712588	14021P	PARTICIPANT	\N	PRESENT	0
714714	712588	12016W	PARTICIPANT	\N	PRESENT	0
714715	712588	11074Q	PARTICIPANT	\N	PRESENT	0
714716	712588	14331P	PARTICIPANT	\N	PRESENT	0
714717	712588	19715Y	PARTICIPANT	\N	PRESENT	0
714718	712588	14257W	PARTICIPANT	\N	PRESENT	0
714719	712588	14225N	PARTICIPANT	\N	PRESENT	0
714720	712588	01028R	PARTICIPANT	\N	PRESENT	0
714721	712588	11027H	PARTICIPANT	\N	PRESENT	0
715239	702239	14189C	PARTICIPANT	\N	PRESENT	0
715240	702239	19741B	PARTICIPANT	\N	PRESENT	0
715241	702239	19667J	PARTICIPANT	\N	PRESENT	0
715242	702239	20086J	PARTICIPANT	\N	PRESENT	0
715243	702239	20914V	PARTICIPANT	\N	PRESENT	0
715244	702239	20080C	PARTICIPANT	\N	PRESENT	0
715246	702239	14083S	PARTICIPANT	\N	PRESENT	0
715247	702239	11053K	PARTICIPANT	\N	PRESENT	0
715248	702239	19545Y	PARTICIPANT	\N	PRESENT	0
715249	702239	20070A	PARTICIPANT	\N	PRESENT	0
715250	702239	04071H	PARTICIPANT	\N	PRESENT	0
715251	702239	11074Q	PARTICIPANT	\N	PRESENT	0
715253	702239	01057W	PARTICIPANT	\N	PRESENT	0
715254	702239	11048N	PARTICIPANT	\N	PRESENT	0
715255	702239	14121F	PARTICIPANT	\N	PRESENT	0
715256	702239	19531S	PARTICIPANT	\N	PRESENT	0
715257	702239	20126Y	PARTICIPANT	\N	PRESENT	0
715258	702239	19711U	PARTICIPANT	\N	PRESENT	0
715259	702239	12016W	PARTICIPANT	\N	PRESENT	0
715260	702239	08009T	PARTICIPANT	\N	PRESENT	0
715261	702239	19671E	PARTICIPANT	\N	PRESENT	0
715262	702239	19335Q	PARTICIPANT	\N	PRESENT	0
715263	702239	19349W	PARTICIPANT	\N	PRESENT	0
715264	702239	14225N	PARTICIPANT	\N	PRESENT	0
715265	702239	11012A	PARTICIPANT	\N	PRESENT	0
715266	702239	20044X	PARTICIPANT	\N	PRESENT	0
715274	715272	05008E	PARTICIPANT	\N	PRESENT	0
715275	715272	01028R	PARTICIPANT	\N	PRESENT	0
715276	715272	11053K	PARTICIPANT	\N	PRESENT	0
715926	715733	19697Q	PARTICIPANT	\N	PRESENT	0
715927	715733	11067R	PARTICIPANT	\N	PRESENT	0
715928	715733	04057K	PARTICIPANT	\N	PRESENT	0
715929	715733	19713W	PARTICIPANT	\N	PRESENT	0
715930	715733	19569H	PARTICIPANT	\N	PRESENT	0
715931	715733	11097X	PARTICIPANT	\N	PRESENT	0
715932	715733	19415P	PARTICIPANT	\N	PRESENT	0
715933	715733	18193Q	PARTICIPANT	\N	PRESENT	0
715934	715733	20148F	PARTICIPANT	\N	PRESENT	0
715935	715733	19553Y	PARTICIPANT	\N	PRESENT	0
715936	715733	14042U	PARTICIPANT	\N	PRESENT	0
715937	715733	14195A	PARTICIPANT	\N	PRESENT	0
715938	715733	19657G	PARTICIPANT	\N	PRESENT	0
715939	715733	14071N	PARTICIPANT	\N	PRESENT	0
715940	715733	14217N	PARTICIPANT	\N	PRESENT	0
715941	715733	19683J	PARTICIPANT	\N	PRESENT	0
715942	715733	10006L	PRESIDENT	0	PRESENT	0
715943	712593	20086J	PARTICIPANT	\N	PRESENT	0
715944	712593	14107H	PARTICIPANT	\N	PRESENT	0
715945	712593	20032T	PARTICIPANT	\N	PRESENT	0
715946	712593	14195A	PARTICIPANT	\N	PRESENT	0
715947	712593	04057K	PARTICIPANT	\N	PRESENT	0
715948	712593	10015M	PARTICIPANT	\N	PRESENT	0
715949	712593	11090Q	PARTICIPANT	\N	PRESENT	0
715950	712593	14071N	PARTICIPANT	\N	PRESENT	0
715951	715733	19367Y	PARTICIPANT	\N	EXCUSE	0
715952	715733	19295A	PARTICIPANT	\N	EXCUSE	0
715953	712593	14191V	PARTICIPANT	\N	PRESENT	0
715954	712593	19629C	PARTICIPANT	\N	PRESENT	0
715955	712593	19713W	PARTICIPANT	\N	PRESENT	0
715956	712593	19553Y	PARTICIPANT	\N	PRESENT	0
715957	712593	19693L	PARTICIPANT	\N	PRESENT	0
715962	712593	14189C	PARTICIPANT	\N	PRESENT	0
715964	712593	20024T	PARTICIPANT	\N	PRESENT	0
715966	712593	19399H	PARTICIPANT	\N	PRESENT	0
715967	712593	97011G	PARTICIPANT	\N	PRESENT	0
715968	712593	20980G	PARTICIPANT	\N	PRESENT	0
715969	712593	18193Q	PARTICIPANT	\N	PRESENT	0
715970	712593	19447X	PARTICIPANT	\N	PRESENT	0
715971	712593	20058E	PARTICIPANT	\N	PRESENT	0
715972	712593	20022R	PARTICIPANT	\N	PRESENT	0
715974	712593	11048N	PARTICIPANT	\N	PRESENT	0
715984	712593	07029T	PARTICIPANT	\N	PRESENT	0
715985	712593	19762G	PARTICIPANT	\N	PRESENT	0
715986	712593	19621T	PARTICIPANT	\N	PRESENT	0
715987	712593	14069U	PARTICIPANT	\N	PRESENT	0
715988	712593	19691J	PARTICIPANT	\N	PRESENT	0
715989	712593	11053K	PARTICIPANT	\N	PRESENT	0
715990	712593	14083S	PARTICIPANT	\N	PRESENT	0
715991	712593	08010L	PARTICIPANT	\N	PRESENT	0
715993	712593	04043D	PARTICIPANT	\N	PRESENT	0
715994	712593	14073Q	PARTICIPANT	\N	PRESENT	0
715995	712593	20070A	PARTICIPANT	\N	PRESENT	0
716042	712594	14195A	PARTICIPANT	\N	PRESENT	0
716043	712594	19683J	PARTICIPANT	\N	PRESENT	0
716044	712594	19631V	PARTICIPANT	\N	PRESENT	0
716045	712594	11067R	PARTICIPANT	\N	PRESENT	0
716046	712594	20070A	PARTICIPANT	\N	PRESENT	0
716047	712594	11031D	PARTICIPANT	\N	PRESENT	0
716048	712594	11012A	PARTICIPANT	\N	PRESENT	0
716049	712594	14111D	PARTICIPANT	\N	PRESENT	0
716050	712594	17589D	PARTICIPANT	\N	PRESENT	0
716051	712594	19713W	PARTICIPANT	\N	PRESENT	0
716052	712594	19691J	PARTICIPANT	\N	PRESENT	0
716053	712594	14073Q	PARTICIPANT	\N	PRESENT	0
716054	712594	14083S	PARTICIPANT	\N	PRESENT	0
716055	712594	19583F	PARTICIPANT	\N	PRESENT	0
716056	712594	04057K	PARTICIPANT	\N	PRESENT	0
716057	712594	14071N	PARTICIPANT	\N	PRESENT	0
716058	712594	19553Y	PARTICIPANT	\N	PRESENT	0
716059	712594	04043D	PARTICIPANT	\N	PRESENT	0
716060	712594	11090Q	PARTICIPANT	\N	PRESENT	0
716061	712594	18193Q	PARTICIPANT	\N	PRESENT	0
716062	712594	19399H	PARTICIPANT	\N	PRESENT	0
716063	712594	20032T	PARTICIPANT	\N	PRESENT	0
716064	712594	07029T	PARTICIPANT	\N	PRESENT	0
716065	712594	97011G	PARTICIPANT	\N	PRESENT	0
716066	712594	14069U	PARTICIPANT	\N	PRESENT	0
716067	712594	14191V	PARTICIPANT	\N	PRESENT	0
716068	712594	19447X	PARTICIPANT	\N	PRESENT	0
716069	712594	19467C	PARTICIPANT	\N	PRESENT	0
717726	716750	19367Y	PARTICIPANT	\N	PRESENT	0
717727	716750	20090E	PARTICIPANT	\N	PRESENT	0
717729	716750	10006L	PARTICIPANT	\N	PRESENT	0
717730	716750	14217N	PARTICIPANT	\N	PRESENT	0
717731	716750	14042U	PARTICIPANT	\N	PRESENT	0
717732	716750	20040T	PARTICIPANT	\N	PRESENT	0
717733	716750	19569H	PARTICIPANT	\N	PRESENT	0
717734	716750	19723Y	PARTICIPANT	\N	PRESENT	0
717735	716750	04092N	PARTICIPANT	\N	PRESENT	0
717736	716750	19679N	PARTICIPANT	\N	PRESENT	0
717737	716750	19798U	PARTICIPANT	\N	PRESENT	0
717738	716750	11097X	PARTICIPANT	\N	PRESENT	0
720430	720429	14331P	PARTICIPANT	\N	PRESENT	0
720436	720434	20050V	PARTICIPANT	\N	PRESENT	0
720502	719953	11031D	PARTICIPANT	\N	PRESENT	0
720503	719953	19735D	PRESIDENT	0	PRESENT	0
716040	712594	95063L	PARTICIPANT	\N	PRESENT	0
716041	712594	19585H	PARTICIPANT	\N	PRESENT	0
720504	719953	17965H	PARTICIPANT	\N	PRESENT	0
720505	719953	14026U	PARTICIPANT	\N	PRESENT	0
720506	719953	14213J	PARTICIPANT	\N	PRESENT	0
720507	719953	20024T	PARTICIPANT	\N	PRESENT	0
720508	719953	20066E	PARTICIPANT	\N	PRESENT	0
720509	719953	20050V	PARTICIPANT	\N	PRESENT	0
720510	719953	20126Y	PARTICIPANT	\N	PRESENT	0
720512	719953	20096L	PARTICIPANT	\N	PRESENT	0
720513	719953	04045F	PARTICIPANT	\N	EXCUSE	0
720515	719953	04092N	PARTICIPANT	\N	EXCUSE	0
720546	720545	14123H	PARTICIPANT	\N	PRESENT	1
720547	720545	19533U	PARTICIPANT	\N	PRESENT	1
720548	720545	19593H	PARTICIPANT	\N	PRESENT	1
720760	720145	20094J	PARTICIPANT	\N	PRESENT	0
720761	720145	20914V	PARTICIPANT	\N	PRESENT	0
720762	720145	19820Y	PARTICIPANT	\N	PRESENT	0
720763	720145	20128B	PARTICIPANT	\N	PRESENT	0
720764	720145	19768N	PARTICIPANT	\N	PRESENT	0
720765	720145	05012A	PARTICIPANT	\N	PRESENT	0
720766	720145	19369B	PARTICIPANT	\N	PRESENT	0
722771	722682	11043H	PARTICIPANT	\N	EXCUSE	0
722772	722682	20148F	PRESIDENT	0	PRESENT	0
722773	722682	14147R	PARTICIPANT	\N	EXCUSE	0
724957	724948	20180F	PARTICIPANT	\N	PRESENT	0
724959	724948	20132W	PARTICIPANT	\N	PRESENT	0
724961	724948	19593H	PARTICIPANT	\N	PRESENT	0
724962	724948	20084G	PARTICIPANT	\N	PRESENT	0
726937	725874	20072C	PARTICIPANT	\N	PRESENT	0
726938	725874	11012A	PARTICIPANT	\N	PRESENT	0
726939	725874	10006L	PARTICIPANT	\N	PRESENT	0
726940	725874	19383Y	PARTICIPANT	\N	PRESENT	0
726941	725874	20118Y	PARTICIPANT	\N	PRESENT	0
726942	725874	05012A	PARTICIPANT	\N	PRESENT	0
718435	718434	19741B	PARTICIPANT	\N	PRESENT	0
718436	718434	20024T	PARTICIPANT	\N	PRESENT	0
718437	718434	11101A	PARTICIPANT	\N	PRESENT	0
718438	718434	14357A	PARTICIPANT	\N	PRESENT	0
718439	718434	97011G	PARTICIPANT	\N	PRESENT	0
718440	718434	14179A	PARTICIPANT	\N	PRESENT	0
718441	718434	08015R	PARTICIPANT	\N	PRESENT	0
718442	718434	08034U	PARTICIPANT	\N	PRESENT	0
718443	718434	14169X	PARTICIPANT	\N	PRESENT	0
718444	718434	20062A	PARTICIPANT	\N	PRESENT	0
718445	718434	14030Q	PARTICIPANT	\N	PRESENT	0
718446	718434	14275Y	PARTICIPANT	\N	PRESENT	0
718447	713475	14231L	PRESIDENT	0	PRESENT	0
718448	713475	05012A	PARTICIPANT	\N	PRESENT	0
718449	713475	08010L	PARTICIPANT	\N	PRESENT	0
718450	713475	19333N	PARTICIPANT	\N	PRESENT	0
718451	713475	14217N	PARTICIPANT	\N	PRESENT	0
718452	713475	19820Y	PARTICIPANT	\N	PRESENT	0
718453	713475	20022R	PARTICIPANT	\N	PRESENT	0
718454	713475	17637T	PARTICIPANT	\N	PRESENT	0
718456	713475	19782L	PARTICIPANT	\N	EXCUSE	0
718457	713475	20090E	PARTICIPANT	\N	EXCUSE	0
718458	713475	14053L	PARTICIPANT	\N	EXCUSE	0
718459	713475	14327T	PARTICIPANT	\N	EXCUSE	0
718460	713475	14215L	PARTICIPANT	\N	EXCUSE	0
718461	713475	14187A	PARTICIPANT	\N	EXCUSE	0
718462	713475	19565D	PARTICIPANT	\N	EXCUSE	0
718470	713475	19447X	PARTICIPANT	\N	EXCUSE	0
718471	713475	19489J	PARTICIPANT	\N	EXCUSE	0
718472	713475	19735D	PARTICIPANT	\N	EXCUSE	0
718473	713475	19826F	PARTICIPANT	\N	EXCUSE	0
718475	713475	14257W	PARTICIPANT	\N	EXCUSE	0
718476	713475	14071N	PARTICIPANT	\N	EXCUSE	0
718477	713475	14107H	PARTICIPANT	\N	EXCUSE	0
718478	713475	04045F	PARTICIPANT	\N	EXCUSE	0
718479	713475	20062A	PARTICIPANT	\N	EXCUSE	0
718480	713475	20058E	PARTICIPANT	\N	EXCUSE	0
718541	718540	20042V	PARTICIPANT	\N	EXCUSE	0
718542	718540	19479G	PARTICIPANT	\N	EXCUSE	0
718559	713475	14229S	PARTICIPANT	\N	EXCUSE	0
723046	723045	20286Q	PARTICIPANT	\N	PRESENT	0
723058	723057	20044X	PARTICIPANT	\N	PRESENT	0
723193	723192	20116W	PARTICIPANT	\N	PRESENT	0
723200	723199	20116W	PARTICIPANT	\N	PRESENT	0
724206	721821	20138D	PARTICIPANT	\N	PRESENT	0
724227	721821	17965H	PARTICIPANT	\N	PRESENT	0
724229	721821	20096L	PARTICIPANT	\N	PRESENT	0
724230	721821	19735D	PRESIDENT	0	PRESENT	0
724233	721821	20126Y	PARTICIPANT	\N	PRESENT	0
724237	721821	19725B	PARTICIPANT	\N	PRESENT	0
724241	721821	14026U	PARTICIPANT	\N	PRESENT	0
724243	721821	11031D	PARTICIPANT	\N	PRESENT	0
724268	721821	04045F	PARTICIPANT	\N	EXCUSE	0
724271	721821	20024T	PARTICIPANT	\N	EXCUSE	0
724273	721821	20050V	PARTICIPANT	\N	EXCUSE	0
724406	724038	19629C	PARTICIPANT	\N	PRESENT	0
724407	724038	14259Y	PARTICIPANT	\N	PRESENT	0
724411	724404	19629C	PARTICIPANT	\N	PRESENT	0
724409	724038	14231L	PARTICIPANT	\N	PRESENT	0
724410	724038	08034U	PARTICIPANT	\N	PRESENT	0
724412	724404	14259Y	PARTICIPANT	\N	PRESENT	0
724413	724404	19703U	PARTICIPANT	\N	PRESENT	0
724415	724405	19629C	PARTICIPANT	\N	PRESENT	0
724417	724405	14259Y	PARTICIPANT	\N	PRESENT	0
724419	724405	14189C	PARTICIPANT	\N	PRESENT	0
725764	725762	11077T	PARTICIPANT	\N	PRESENT	0
725766	725765	11077T	PARTICIPANT	\N	PRESENT	0
725767	725765	14037X	PARTICIPANT	\N	PRESENT	0
725769	725768	14037X	PARTICIPANT	\N	PRESENT	0
725770	725768	11077T	PARTICIPANT	\N	PRESENT	0
725772	725771	08009T	PARTICIPANT	\N	PRESENT	0
725774	725773	08009T	PARTICIPANT	\N	PRESENT	0
725776	725775	19667J	PARTICIPANT	\N	PRESENT	0
725777	725775	11040E	PARTICIPANT	\N	PRESENT	0
725779	725778	19667J	PARTICIPANT	\N	PRESENT	0
725780	725778	11040E	PARTICIPANT	\N	PRESENT	0
725782	725781	19667J	PARTICIPANT	\N	PRESENT	0
725783	725781	11040E	PARTICIPANT	\N	PRESENT	0
725785	725784	11053K	PARTICIPANT	\N	PRESENT	0
725788	725493	14069U	PARTICIPANT	\N	PRESENT	0
725789	725493	14083S	PARTICIPANT	\N	PRESENT	0
725790	725493	20056C	PARTICIPANT	\N	PRESENT	0
725791	725493	11097X	PARTICIPANT	\N	PRESENT	0
725793	725792	19762G	PARTICIPANT	\N	PRESENT	0
725794	725792	19531S	PARTICIPANT	\N	PRESENT	0
725872	725867	14042U	PARTICIPANT	\N	PRESENT	0
725873	725867	18193Q	PARTICIPANT	\N	PRESENT	0
725876	725868	14042U	PARTICIPANT	\N	PRESENT	0
725877	725868	18193Q	PARTICIPANT	\N	PRESENT	0
727866	727813	20050V	PARTICIPANT	\N	EXCUSE	0
730653	730652	20024T	PARTICIPANT	\N	PRESENT	0
730654	730652	01024M	PARTICIPANT	\N	PRESENT	0
730655	730652	14281W	PARTICIPANT	\N	PRESENT	0
730656	730652	14026U	PARTICIPANT	\N	PRESENT	0
730657	730652	19691J	PARTICIPANT	\N	PRESENT	0
730658	730652	08047A	PARTICIPANT	\N	PRESENT	0
730659	730652	19798U	PARTICIPANT	\N	PRESENT	0
730660	730652	04045F	PARTICIPANT	\N	PRESENT	0
730661	730647	19415P	PARTICIPANT	\N	PRESENT	0
730662	730647	20130U	PARTICIPANT	\N	PRESENT	0
730663	730648	14213J	PARTICIPANT	\N	PRESENT	0
730664	730648	11067R	PARTICIPANT	\N	PRESENT	0
730665	730649	11031D	PARTICIPANT	\N	PRESENT	0
730666	730649	14213J	PARTICIPANT	\N	PRESENT	0
730667	730649	11067R	PARTICIPANT	\N	PRESENT	0
730668	730650	19367Y	PARTICIPANT	\N	PRESENT	0
730669	730650	14213J	PARTICIPANT	\N	PRESENT	0
730670	730650	11067R	PARTICIPANT	\N	PRESENT	0
730671	730651	14213J	PARTICIPANT	\N	PRESENT	0
730672	730651	11067R	PARTICIPANT	\N	PRESENT	0
730677	730676	14255U	PARTICIPANT	\N	PRESENT	0
730678	730676	11083R	PARTICIPANT	\N	PRESENT	0
730679	730676	20064C	PARTICIPANT	\N	PRESENT	0
730681	730680	20064C	PARTICIPANT	\N	PRESENT	0
731742	730320	19621T	PARTICIPANT	\N	PRESENT	0
731744	730319	14030Q	PARTICIPANT	\N	PRESENT	0
731745	730319	19643A	PARTICIPANT	\N	PRESENT	0
731746	730319	19621T	PARTICIPANT	\N	PRESENT	0
731747	730319	19758L	PARTICIPANT	\N	PRESENT	0
731748	730319	19057M	PARTICIPANT	\N	PRESENT	0
731749	730319	20264J	PARTICIPANT	\N	PRESENT	0
731750	730319	20980G	PARTICIPANT	\N	PRESENT	0
731751	730319	19719D	PARTICIPANT	\N	PRESENT	0
731752	730319	20132W	PARTICIPANT	\N	PRESENT	0
731753	730319	20172F	PARTICIPANT	\N	PRESENT	0
731754	730319	14123H	PARTICIPANT	\N	PRESENT	0
731755	730319	20048C	PARTICIPANT	\N	PRESENT	0
731756	730319	14073Q	PARTICIPANT	\N	PRESENT	0
731757	730319	19735D	PARTICIPANT	\N	PRESENT	0
731758	730319	19699S	PARTICIPANT	\N	PRESENT	0
731759	730319	14109K	PARTICIPANT	\N	PRESENT	0
731760	730319	04070G	PARTICIPANT	\N	PRESENT	0
731761	730319	19573D	PARTICIPANT	\N	PRESENT	0
731762	730319	04033B	PARTICIPANT	\N	PRESENT	0
731763	730319	14229S	PARTICIPANT	\N	PRESENT	0
731764	730319	11043H	PARTICIPANT	\N	PRESENT	0
731765	730319	20098N	PARTICIPANT	\N	PRESENT	0
731766	730319	20084G	PARTICIPANT	\N	PRESENT	0
731767	730319	19527W	PARTICIPANT	\N	PRESENT	0
731768	730319	20026V	PARTICIPANT	\N	PRESENT	0
731769	730319	20058E	PARTICIPANT	\N	PRESENT	0
731770	730319	19533U	PARTICIPANT	\N	PRESENT	0
731772	730646	17737W	PARTICIPANT	\N	PRESENT	0
731773	730646	19629C	PARTICIPANT	\N	PRESENT	0
731774	730646	20074E	PARTICIPANT	\N	PRESENT	0
731775	730646	20114U	PARTICIPANT	\N	PRESENT	0
731776	730646	14215L	PARTICIPANT	\N	PRESENT	0
731777	730646	19649G	PARTICIPANT	\N	PRESENT	0
731778	730646	19581D	PARTICIPANT	\N	PRESENT	0
731779	730673	12041X	PARTICIPANT	\N	PRESENT	0
731781	730673	11054L	PARTICIPANT	\N	PRESENT	0
731782	730673	19347U	PARTICIPANT	\N	PRESENT	0
731783	730673	04035D	PARTICIPANT	\N	PRESENT	0
731784	730673	01062T	PARTICIPANT	\N	PRESENT	0
731785	730673	08069G	PARTICIPANT	\N	PRESENT	0
731786	730673	01024M	PARTICIPANT	\N	PRESENT	0
731787	730673	11064N	PARTICIPANT	\N	PRESENT	0
731788	730673	17023S	PARTICIPANT	\N	PRESENT	0
731789	730673	14105F	PARTICIPANT	\N	EXCUSE	0
731790	730646	14053L	PARTICIPANT	\N	PRESENT	0
713855	712585	10015M	PARTICIPANT	\N	PRESENT	0
713856	712585	20112S	PARTICIPANT	\N	PRESENT	0
720073	720071	19503N	PARTICIPANT	\N	PRESENT	0
722691	722690	14083S	PARTICIPANT	\N	PRESENT	0
722692	722690	14038Y	PARTICIPANT	\N	PRESENT	0
722693	722690	19577H	PARTICIPANT	\N	PRESENT	0
722694	722690	20038A	PARTICIPANT	\N	PRESENT	0
722695	722690	20100N	PARTICIPANT	\N	PRESENT	0
722696	722690	19699S	PARTICIPANT	\N	PRESENT	0
722697	722690	18193Q	PARTICIPANT	\N	PRESENT	0
722698	722690	16685X	PARTICIPANT	\N	PRESENT	0
722699	722690	14059S	PARTICIPANT	\N	PRESENT	0
722700	722690	19657G	PARTICIPANT	\N	PRESENT	0
722701	722690	11072N	PARTICIPANT	\N	PRESENT	0
722702	722682	05008E	PARTICIPANT	\N	EXCUSE	0
725438	725437	05008E	PARTICIPANT	\N	PRESENT	0
725439	725437	11053K	PARTICIPANT	\N	PRESENT	0
725440	725437	01028R	PARTICIPANT	\N	PRESENT	0
725444	721813	11097X	PARTICIPANT	\N	PRESENT	0
725445	721813	20130U	PARTICIPANT	\N	PRESENT	0
725446	721815	20130U	PARTICIPANT	\N	PRESENT	0
725453	725451	14213J	PARTICIPANT	\N	PRESENT	0
725454	725451	19367Y	PARTICIPANT	\N	PRESENT	0
725455	725451	11067R	PARTICIPANT	\N	PRESENT	0
725456	725448	19415P	PARTICIPANT	\N	PRESENT	0
725457	725448	19591F	PARTICIPANT	\N	PRESENT	0
725458	725448	19798U	PARTICIPANT	\N	PRESENT	0
725459	725449	19415P	PARTICIPANT	\N	PRESENT	0
725460	725449	19798U	PARTICIPANT	\N	PRESENT	0
725461	725450	19415P	PARTICIPANT	\N	PRESENT	0
725462	725450	11067R	PARTICIPANT	\N	PRESENT	0
725463	725450	19798U	PARTICIPANT	\N	PRESENT	0
730851	730850	04047H	PARTICIPANT	\N	PRESENT	0
730852	730850	04042C	PARTICIPANT	\N	PRESENT	0
730853	730850	14053L	PARTICIPANT	\N	PRESENT	0
730857	730850	11066Q	PARTICIPANT	\N	PRESENT	0
730863	730862	19693L	PARTICIPANT	\N	PRESENT	0
736430	736372	11031D	PARTICIPANT	\N	PRESENT	0
736431	736372	19725B	PRESIDENT	0	PRESENT	0
736432	736372	14213J	PARTICIPANT	\N	PRESENT	0
736433	736372	20066E	PARTICIPANT	\N	PRESENT	0
736434	736372	19735D	PRESIDENT	1	PRESENT	0
736435	736372	04045F	PARTICIPANT	\N	PRESENT	0
736436	736372	17965H	PARTICIPANT	\N	PRESENT	0
736448	736372	20126Y	PARTICIPANT	\N	EXCUSE	0
736449	736372	20050V	PARTICIPANT	\N	EXCUSE	0
736761	736759	95063L	PARTICIPANT	\N	PRESENT	0
736763	736759	11054L	PARTICIPANT	\N	PRESENT	0
736764	736759	14219Q	PARTICIPANT	\N	PRESENT	0
736766	736759	20056C	PARTICIPANT	\N	PRESENT	0
736767	736759	20128B	PARTICIPANT	\N	PRESENT	0
736768	736759	11064N	PARTICIPANT	\N	PRESENT	0
736769	736759	11083R	PARTICIPANT	\N	PRESENT	0
736772	736759	20138D	PARTICIPANT	\N	PRESENT	0
736773	736759	14147R	PARTICIPANT	\N	PRESENT	0
736886	733710	11043H	PARTICIPANT	\N	EXCUSE	0
736887	733710	11010L	PARTICIPANT	\N	EXCUSE	0
736888	733710	19715Y	PARTICIPANT	\N	EXCUSE	1
736889	733710	14219Q	PARTICIPANT	\N	EXCUSE	0
736892	733710	19673G	PARTICIPANT	\N	EXCUSE	0
736893	733712	11043H	PARTICIPANT	\N	EXCUSE	0
736894	733712	14219Q	PARTICIPANT	\N	EXCUSE	0
736895	733712	19673G	PARTICIPANT	\N	EXCUSE	0
736896	733712	19715Y	PARTICIPANT	\N	PRESENT	1
737845	737844	11066Q	PARTICIPANT	\N	PRESENT	0
738085	738084	19533U	PARTICIPANT	\N	PRESENT	0
738099	738098	19711U	PARTICIPANT	\N	PRESENT	0
738100	738098	20050V	PARTICIPANT	\N	PRESENT	0
738190	738189	19515S	PRESIDENT	0	PRESENT	0
738193	738189	14083S	PARTICIPANT	\N	PRESENT	0
738198	738189	20054A	PARTICIPANT	\N	PRESENT	0
738207	738189	19251M	PARTICIPANT	\N	PRESENT	0
738213	738189	19369B	PARTICIPANT	\N	PRESENT	0
738245	738243	20120S	PARTICIPANT	\N	PRESENT	0
738247	738246	20120S	PARTICIPANT	\N	PRESENT	0
738250	738249	20120S	PARTICIPANT	\N	PRESENT	0
738259	738252	20120S	PARTICIPANT	\N	PRESENT	0
738265	738264	11053K	PARTICIPANT	\N	PRESENT	0
738267	738266	11053K	PARTICIPANT	\N	PRESENT	0
738269	738268	19711U	PARTICIPANT	\N	PRESENT	0
738271	738270	14225N	PARTICIPANT	\N	PRESENT	0
738274	738273	14042U	PARTICIPANT	\N	PRESENT	1
738275	738273	18193Q	PARTICIPANT	\N	PRESENT	1
738277	738276	11074Q	PARTICIPANT	\N	PRESENT	0
738278	738276	19349W	PARTICIPANT	\N	PRESENT	0
738280	738279	14083S	PARTICIPANT	\N	PRESENT	0
738282	738281	14083S	PARTICIPANT	\N	PRESENT	0
738284	738283	01048V	PARTICIPANT	\N	PRESENT	0
738294	738293	05008E	PARTICIPANT	\N	PRESENT	0
738295	738293	11053K	PARTICIPANT	\N	PRESENT	0
738296	738293	01028R	PARTICIPANT	\N	PRESENT	0
738298	738272	10006L	PARTICIPANT	\N	PRESENT	0
738299	738272	18193Q	PARTICIPANT	\N	PRESENT	0
738300	738272	14071N	PARTICIPANT	\N	PRESENT	0
738301	738272	14026U	PARTICIPANT	\N	PRESENT	0
738302	738285	10006L	PARTICIPANT	\N	PRESENT	0
738303	738285	18193Q	PARTICIPANT	\N	PRESENT	0
738304	738285	14026U	PARTICIPANT	\N	PRESENT	0
738305	738285	14071N	PARTICIPANT	\N	PRESENT	0
738306	738285	19725B	PARTICIPANT	\N	PRESENT	0
738307	738290	19663E	PARTICIPANT	\N	PRESENT	0
738308	738290	19713W	PARTICIPANT	\N	PRESENT	0
738309	738291	20130U	PARTICIPANT	\N	PRESENT	0
738310	738291	19713W	PARTICIPANT	\N	PRESENT	0
738311	738289	14213J	PARTICIPANT	\N	PRESENT	0
738312	738289	19367Y	PARTICIPANT	\N	PRESENT	0
738313	738289	20054A	PARTICIPANT	\N	PRESENT	0
738314	738286	19415P	PARTICIPANT	\N	PRESENT	0
738315	738286	14217N	PARTICIPANT	\N	PRESENT	0
738316	738286	11067R	PARTICIPANT	\N	PRESENT	0
738317	738286	19798U	PARTICIPANT	\N	PRESENT	0
738318	738287	19415P	PARTICIPANT	\N	PRESENT	0
738319	738287	14217N	PARTICIPANT	\N	PRESENT	0
738320	738287	19798U	PARTICIPANT	\N	PRESENT	0
738321	738288	19415P	PARTICIPANT	\N	PRESENT	0
738322	738288	14217N	PARTICIPANT	\N	PRESENT	0
738323	738288	11067R	PARTICIPANT	\N	PRESENT	0
738324	738288	19798U	PARTICIPANT	\N	PRESENT	0
738325	738288	17965H	PARTICIPANT	\N	PRESENT	0
738326	738288	20130U	PARTICIPANT	\N	PRESENT	0
738346	738260	11043H	PARTICIPANT	\N	EXCUSE	0
738347	738260	14331P	PARTICIPANT	\N	EXCUSE	0
738348	738260	05008E	PARTICIPANT	\N	EXCUSE	0
738349	733724	20034V	PARTICIPANT	\N	PRESENT	0
738350	733724	05008E	PARTICIPANT	\N	EXCUSE	0
738351	733724	11043H	PARTICIPANT	\N	EXCUSE	0
738352	733724	14331P	PARTICIPANT	\N	EXCUSE	0
738355	738354	12028B	PARTICIPANT	\N	PRESENT	0
738357	738356	12028B	PARTICIPANT	\N	PRESENT	0
738358	738356	11064N	PARTICIPANT	\N	PRESENT	0
738380	738260	14219Q	PARTICIPANT	\N	EXCUSE	0
738381	733724	14219Q	PARTICIPANT	\N	EXCUSE	0
738385	738003	14026U	PARTICIPANT	\N	PRESENT	0
738393	738003	08045X	PARTICIPANT	\N	PRESENT	0
738394	738003	14187A	PARTICIPANT	\N	PRESENT	0
714722	712588	19543W	PARTICIPANT	\N	PRESENT	0
714723	712588	19683J	PARTICIPANT	\N	PRESENT	0
714724	712588	19649G	PARTICIPANT	\N	PRESENT	0
714725	712588	14267Y	PARTICIPANT	\N	PRESENT	0
714726	712588	11045K	PARTICIPANT	\N	PRESENT	0
714727	712588	01062T	PARTICIPANT	\N	PRESENT	0
714728	712588	08060W	PARTICIPANT	\N	PRESENT	0
714729	712588	19335Q	PARTICIPANT	\N	PRESENT	0
714730	712588	19685L	PARTICIPANT	\N	PRESENT	0
714731	712588	20248J	PARTICIPANT	\N	PRESENT	0
714732	712588	19549D	PARTICIPANT	\N	PRESENT	0
714733	712588	14089Y	PARTICIPANT	\N	PRESENT	0
714734	712588	14083S	PARTICIPANT	\N	PRESENT	0
714735	712588	14073Q	PARTICIPANT	\N	PRESENT	0
714736	712588	19599P	PARTICIPANT	\N	PRESENT	0
714737	712588	20040T	PARTICIPANT	\N	PRESENT	0
714738	712588	19826F	PARTICIPANT	\N	PRESENT	0
714739	712588	20060X	PARTICIPANT	\N	PRESENT	0
714740	712588	14255U	PARTICIPANT	\N	PRESENT	0
714741	712588	07004J	PARTICIPANT	\N	PRESENT	0
714742	712588	19577H	PARTICIPANT	\N	PRESENT	0
714743	712588	19725B	PARTICIPANT	\N	PRESENT	0
714744	712588	01025N	PARTICIPANT	\N	PRESENT	0
714745	712588	14097Y	PARTICIPANT	\N	PRESENT	0
714746	712588	01024M	PARTICIPANT	\N	PRESENT	0
714747	712588	14030Q	PARTICIPANT	\N	PRESENT	0
714748	712588	14327T	PARTICIPANT	\N	PRESENT	0
714749	712588	14229S	PARTICIPANT	\N	PRESENT	0
714750	712588	01043Q	PARTICIPANT	\N	PRESENT	0
714751	712588	11066Q	PARTICIPANT	\N	PRESENT	0
714752	712588	20064C	PARTICIPANT	\N	PRESENT	0
714753	712588	14189C	PARTICIPANT	\N	PRESENT	0
714754	712588	08012N	PARTICIPANT	\N	PRESENT	0
714755	712588	19569H	PARTICIPANT	\N	PRESENT	0
714782	712588	20052X	PARTICIPANT	\N	PRESENT	0
714780	712588	19691J	PARTICIPANT	\N	PRESENT	0
714777	712588	14275Y	PARTICIPANT	\N	PRESENT	0
714776	712588	19749K	PARTICIPANT	\N	PRESENT	0
714784	712588	17229F	PARTICIPANT	\N	PRESENT	0
714785	712588	19441R	PARTICIPANT	\N	PRESENT	0
714762	712588	19699S	PARTICIPANT	\N	PRESENT	0
714779	712588	19713W	PARTICIPANT	\N	PRESENT	0
714764	712588	20042V	PARTICIPANT	\N	PRESENT	0
714765	712588	19619A	PARTICIPANT	\N	PRESENT	0
714766	712588	14219Q	PARTICIPANT	\N	PRESENT	0
714767	712588	16685X	PARTICIPANT	\N	PRESENT	0
714768	712588	19739H	PARTICIPANT	\N	PRESENT	0
714769	712588	19735D	PARTICIPANT	\N	PRESENT	0
714770	712588	14205J	PARTICIPANT	\N	PRESENT	0
714771	712588	20144B	PARTICIPANT	\N	PRESENT	0
714772	712588	08009T	PARTICIPANT	\N	PRESENT	0
714773	712588	19369B	PARTICIPANT	\N	PRESENT	0
714774	712588	19479G	PARTICIPANT	\N	PRESENT	0
714775	712588	20298U	PARTICIPANT	\N	PRESENT	0
714781	712588	19319Q	PARTICIPANT	\N	PRESENT	0
714783	712588	14231L	PARTICIPANT	\N	PRESENT	0
714786	712588	11090Q	PARTICIPANT	\N	PRESENT	0
714787	712588	17023S	PARTICIPANT	\N	PRESENT	0
714788	712588	19798U	PARTICIPANT	\N	PRESENT	0
714790	712588	20056C	PARTICIPANT	\N	PRESENT	0
714792	712588	19611R	PARTICIPANT	\N	PRESENT	0
714794	712588	19707Y	PARTICIPANT	\N	PRESENT	0
714798	712588	20286Q	PARTICIPANT	\N	PRESENT	0
714799	712588	14179A	PARTICIPANT	\N	PRESENT	0
714800	712588	20140W	PARTICIPANT	\N	PRESENT	0
714801	712588	04035D	PARTICIPANT	\N	PRESENT	0
714802	712588	86034E	PARTICIPANT	\N	PRESENT	0
714803	712588	19573D	PARTICIPANT	\N	PRESENT	0
714804	712588	08047A	PARTICIPANT	\N	PRESENT	0
714805	712588	20102Q	PARTICIPANT	\N	PRESENT	0
714806	712588	14055N	PARTICIPANT	\N	PRESENT	0
714807	712588	20110Q	PARTICIPANT	\N	PRESENT	0
714808	712588	19447X	PARTICIPANT	\N	PRESENT	0
714809	712588	20058E	PARTICIPANT	\N	PRESENT	0
714810	712588	20084G	PARTICIPANT	\N	PRESENT	0
714811	712588	19758L	PARTICIPANT	\N	PRESENT	0
714812	712588	19745F	PARTICIPANT	\N	PRESENT	0
714813	712588	11072N	PARTICIPANT	\N	PRESENT	0
714814	712588	20120S	PARTICIPANT	\N	PRESENT	0
714815	712588	19669L	PARTICIPANT	\N	PRESENT	0
714816	712588	11104D	PARTICIPANT	\N	PRESENT	0
715203	710027	19569H	PARTICIPANT	\N	PRESENT	0
715204	710027	12016W	PARTICIPANT	\N	PRESENT	0
715205	710027	19741B	PRESIDENT	0	PRESENT	0
715206	710027	19866P	PARTICIPANT	\N	PRESENT	0
715207	710027	19585H	PARTICIPANT	\N	PRESENT	0
715208	710027	19631V	PARTICIPANT	\N	PRESENT	0
715209	710027	20084G	PARTICIPANT	\N	PRESENT	0
715212	710027	10015M	PARTICIPANT	\N	PRESENT	0
715213	712589	20024T	PARTICIPANT	\N	PRESENT	0
715215	712589	19507S	PARTICIPANT	\N	PRESENT	0
715218	712589	20144B	PARTICIPANT	\N	PRESENT	0
715219	712589	11115U	PARTICIPANT	\N	PRESENT	0
715220	712589	07029T	PARTICIPANT	\N	PRESENT	0
715221	712589	19599P	PARTICIPANT	\N	PRESENT	0
715222	712589	11056N	PARTICIPANT	\N	PRESENT	0
715225	712589	19367Y	PARTICIPANT	\N	PRESENT	0
715226	712589	14121F	PARTICIPANT	\N	PRESENT	0
715227	712589	20098N	PARTICIPANT	\N	PRESENT	0
715228	712589	19447X	PARTICIPANT	\N	PRESENT	0
715229	712589	20114U	PARTICIPANT	\N	PRESENT	0
715230	712589	14215L	PARTICIPANT	\N	PRESENT	0
715231	712589	18083K	PARTICIPANT	\N	PRESENT	0
715232	712589	19441R	PARTICIPANT	\N	PRESENT	0
715233	712589	19693L	PARTICIPANT	\N	PRESENT	0
715234	712589	14179A	PARTICIPANT	\N	PRESENT	0
715235	712589	19611R	PARTICIPANT	\N	PRESENT	0
715236	710027	08010L	PARTICIPANT	\N	PRESENT	0
719138	719055	07029T	PARTICIPANT	\N	PRESENT	0
719059	719037	20036X	PARTICIPANT	\N	PRESENT	0
719060	719037	14253S	PARTICIPANT	\N	PRESENT	0
719061	719037	14225N	PRESIDENT	0	PRESENT	0
719062	719037	14173T	PARTICIPANT	\N	PRESENT	0
719133	719055	11040E	PARTICIPANT	\N	PRESENT	0
719134	718556	04085P	PARTICIPANT	\N	PRESENT	0
719135	718556	05008E	PARTICIPANT	\N	PRESENT	0
719136	718556	19725B	PARTICIPANT	\N	PRESENT	0
719137	718556	19749K	PARTICIPANT	\N	PRESENT	0
719139	719055	19647E	PARTICIPANT	\N	PRESENT	0
719141	719055	19545Y	PARTICIPANT	\N	PRESENT	0
719142	719055	20080C	PARTICIPANT	\N	PRESENT	0
719143	719055	14189C	PARTICIPANT	\N	PRESENT	0
719144	719055	11074Q	PARTICIPANT	\N	PRESENT	0
719145	718556	20110Q	PARTICIPANT	\N	PRESENT	0
719146	718556	11056N	PARTICIPANT	\N	PRESENT	0
719147	718556	04008A	PARTICIPANT	\N	PRESENT	0
719148	718556	14231L	PARTICIPANT	\N	PRESENT	0
719149	718556	07004J	PARTICIPANT	\N	PRESENT	0
719150	718393	20090E	PARTICIPANT	\N	PRESENT	0
719151	718393	19798U	PARTICIPANT	\N	PRESENT	0
719152	718393	19415P	PARTICIPANT	\N	PRESENT	0
719153	718393	14223L	PARTICIPANT	\N	PRESENT	0
719154	718393	17779H	PARTICIPANT	\N	PRESENT	0
719155	718393	19703U	PARTICIPANT	\N	PRESENT	0
719156	718393	11031D	PARTICIPANT	\N	PRESENT	0
719157	718393	14281W	PARTICIPANT	\N	PRESENT	0
719158	718393	19679N	PARTICIPANT	\N	PRESENT	0
719159	718393	14042U	PARTICIPANT	\N	PRESENT	0
719160	718393	19367Y	PARTICIPANT	\N	PRESENT	0
719161	718393	14213J	PARTICIPANT	\N	PRESENT	0
719162	718393	14217N	PARTICIPANT	\N	PRESENT	0
719163	718393	19511N	PARTICIPANT	\N	PRESENT	0
719164	718393	10006L	PRESIDENT	0	PRESENT	0
719165	718393	20130U	PARTICIPANT	\N	PRESENT	0
719166	718393	04092N	PARTICIPANT	\N	PRESENT	0
719167	718393	19713W	PARTICIPANT	\N	PRESENT	0
719168	718393	20040T	PARTICIPANT	\N	PRESENT	0
719169	718393	19691J	PARTICIPANT	\N	PRESENT	0
719170	718393	19715Y	PARTICIPANT	\N	PRESENT	0
719171	718393	19717B	PARTICIPANT	\N	PRESENT	0
719172	718393	20248J	PARTICIPANT	\N	PRESENT	0
719173	718393	14071N	PARTICIPANT	\N	PRESENT	0
719174	718393	19760E	PARTICIPANT	\N	PRESENT	0
719175	718556	17737W	PARTICIPANT	\N	PRESENT	0
719176	718556	14259Y	PARTICIPANT	\N	PRESENT	0
719177	718556	19649G	PARTICIPANT	\N	PRESENT	0
719178	718556	11033F	PARTICIPANT	\N	PRESENT	0
719179	718556	14021P	PARTICIPANT	\N	PRESENT	0
719180	718668	14097Y	PARTICIPANT	\N	PRESENT	0
719181	718668	12041X	PARTICIPANT	\N	PRESENT	0
723863	723862	14026U	PARTICIPANT	\N	PRESENT	0
723864	723862	19725B	PARTICIPANT	\N	PRESENT	0
723941	723660	19527W	PARTICIPANT	\N	PRESENT	0
723942	723660	20052X	PARTICIPANT	\N	PRESENT	0
723943	723660	11109J	PARTICIPANT	\N	EXCUSE	0
723944	723660	20152B	PARTICIPANT	\N	PRESENT	0
725342	725340	20286Q	PARTICIPANT	\N	PRESENT	0
726943	725874	20076G	PARTICIPANT	\N	PRESENT	0
726944	725874	14195A	PARTICIPANT	\N	PRESENT	0
726945	725874	14211G	PARTICIPANT	\N	PRESENT	0
726946	725874	19367Y	PARTICIPANT	\N	PRESENT	0
726947	725874	14026U	PARTICIPANT	\N	PRESENT	0
726948	725874	11064N	PARTICIPANT	\N	PRESENT	0
726949	725874	19583F	PARTICIPANT	\N	PRESENT	0
726950	725874	19329S	PARTICIPANT	\N	PRESENT	0
726951	725874	20120S	PARTICIPANT	\N	PRESENT	0
726952	725874	14111D	PARTICIPANT	\N	PRESENT	0
726953	725874	14221J	PARTICIPANT	\N	PRESENT	0
726954	725874	20252E	PARTICIPANT	\N	PRESENT	0
726955	725874	04057K	PARTICIPANT	\N	PRESENT	0
726956	725874	19563B	PARTICIPANT	\N	PRESENT	0
726957	725874	20050V	PARTICIPANT	\N	PRESENT	0
726958	725874	20122U	PARTICIPANT	\N	PRESENT	0
726959	725874	14237S	PARTICIPANT	\N	PRESENT	0
726960	725874	19585H	PARTICIPANT	\N	PRESENT	0
726961	725874	20020P	PARTICIPANT	\N	PRESENT	0
726962	725874	19631V	PARTICIPANT	\N	PRESENT	0
726963	725874	04059M	PARTICIPANT	\N	PRESENT	0
726964	725874	19707Y	PARTICIPANT	\N	PRESENT	0
726965	725874	19705W	PARTICIPANT	\N	PRESENT	0
726966	725874	19549D	PARTICIPANT	\N	PRESENT	0
726967	725874	08015R	PARTICIPANT	\N	PRESENT	0
726968	725874	19729F	PARTICIPANT	\N	PRESENT	0
726969	725874	07029T	PARTICIPANT	\N	PRESENT	0
726970	725874	19768N	PARTICIPANT	\N	PRESENT	0
726971	725874	19657G	PARTICIPANT	\N	PRESENT	0
726972	725874	19709B	PARTICIPANT	\N	PRESENT	0
726973	725874	14355X	PARTICIPANT	\N	PRESENT	0
726974	725874	20088L	PARTICIPANT	\N	PRESENT	0
726975	725874	20060X	PARTICIPANT	\N	PRESENT	0
726976	725874	19663E	PARTICIPANT	\N	PRESENT	0
726977	725874	20070A	PARTICIPANT	\N	PRESENT	0
726978	725874	14169X	PARTICIPANT	\N	PRESENT	0
726979	725874	08047A	PARTICIPANT	\N	PRESENT	0
726980	725874	14123H	PARTICIPANT	\N	PRESENT	0
726981	725874	20172F	PARTICIPANT	\N	PRESENT	0
726982	725874	19954N	PARTICIPANT	\N	PRESENT	0
726983	725874	20086J	PARTICIPANT	\N	PRESENT	0
726984	725874	19251M	PARTICIPANT	\N	PRESENT	0
726985	725874	14151M	PARTICIPANT	\N	PRESENT	0
726986	725874	19723Y	PARTICIPANT	\N	PRESENT	0
726987	725874	20264J	PARTICIPANT	\N	PRESENT	0
726988	725874	11074Q	PARTICIPANT	\N	PRESENT	0
726989	725874	20034V	PARTICIPANT	\N	PRESENT	0
726990	725874	11110B	PARTICIPANT	\N	PRESENT	0
726991	725874	14281W	PARTICIPANT	\N	PRESENT	0
726992	725874	08045X	PARTICIPANT	\N	PRESENT	0
726993	725874	19599P	PARTICIPANT	\N	PRESENT	0
726994	725874	19467C	PARTICIPANT	\N	PRESENT	0
726995	725874	19820Y	PARTICIPANT	\N	PRESENT	0
726996	725874	19725B	PARTICIPANT	\N	PRESENT	0
726997	725874	20058E	PARTICIPANT	\N	PRESENT	0
726998	725874	20026V	PARTICIPANT	\N	PRESENT	0
726999	725874	20096L	PARTICIPANT	\N	PRESENT	0
727000	725874	14121F	PARTICIPANT	\N	PRESENT	0
727001	725874	20980G	PARTICIPANT	\N	PRESENT	0
727002	725874	19573D	PARTICIPANT	\N	PRESENT	0
727003	725874	19531S	PARTICIPANT	\N	PRESENT	0
727004	725874	19683J	PARTICIPANT	\N	PRESENT	0
727005	725874	14173T	PARTICIPANT	\N	PRESENT	0
727006	725874	14021P	PARTICIPANT	\N	PRESENT	0
727007	725874	20038A	PARTICIPANT	\N	PRESENT	0
727008	725874	19489J	PARTICIPANT	\N	PRESENT	0
727009	725874	20136B	PARTICIPANT	\N	PRESENT	0
727010	725874	19649G	PARTICIPANT	\N	PRESENT	0
727011	725874	14253S	PARTICIPANT	\N	PRESENT	0
727012	725874	18193Q	PARTICIPANT	\N	PRESENT	0
727013	725874	08018U	PARTICIPANT	\N	PRESENT	0
727014	725874	08012N	PARTICIPANT	\N	PRESENT	0
727015	725874	19741B	PARTICIPANT	\N	PRESENT	0
727016	725874	19399H	PARTICIPANT	\N	PRESENT	0
727017	725874	19507S	PARTICIPANT	\N	PRESENT	0
727018	725874	20104S	PARTICIPANT	\N	PRESENT	0
727019	725874	11056N	PARTICIPANT	\N	PRESENT	0
727020	725874	14069U	PARTICIPANT	\N	PRESENT	0
727021	725874	19695N	PARTICIPANT	\N	PRESENT	0
727022	725874	14213J	PARTICIPANT	\N	PRESENT	0
727023	725874	19565D	PARTICIPANT	\N	PRESENT	0
727024	725874	20024T	PARTICIPANT	\N	PRESENT	0
727025	725874	19347U	PARTICIPANT	\N	PRESENT	0
727026	725874	08011M	PARTICIPANT	\N	PRESENT	0
727027	725874	20044X	PARTICIPANT	\N	PRESENT	0
727028	725874	11099A	PARTICIPANT	\N	PRESENT	0
727029	725874	19697Q	PARTICIPANT	\N	PRESENT	0
727030	725874	01060R	PARTICIPANT	\N	PRESENT	0
727031	725874	20116W	PARTICIPANT	\N	PRESENT	0
727032	725874	19681G	PARTICIPANT	\N	PRESENT	0
727033	725874	19866P	PARTICIPANT	\N	PRESENT	0
727099	725874	14071N	PARTICIPANT	\N	PRESENT	0
727035	725874	20028X	PARTICIPANT	\N	PRESENT	0
727036	725874	11067R	PARTICIPANT	\N	PRESENT	0
727037	725874	20018V	PARTICIPANT	\N	PRESENT	0
727038	725874	14257W	PARTICIPANT	\N	PRESENT	0
727039	725874	20030R	PARTICIPANT	\N	PRESENT	0
727040	725874	17965H	PARTICIPANT	\N	PRESENT	0
727041	725874	19503N	PARTICIPANT	\N	PRESENT	0
727042	725874	14225N	PARTICIPANT	\N	PRESENT	0
727043	725874	20082E	PARTICIPANT	\N	PRESENT	0
727044	725874	14229S	PARTICIPANT	\N	PRESENT	0
727045	725874	11054L	PARTICIPANT	\N	PRESENT	0
727046	725874	11045K	PARTICIPANT	\N	PRESENT	0
727047	725874	20084G	PARTICIPANT	\N	PRESENT	0
727048	725874	19413M	PARTICIPANT	\N	PRESENT	0
727049	725874	01062T	PARTICIPANT	\N	PRESENT	0
727050	725874	20064C	PARTICIPANT	\N	PRESENT	0
727097	725874	86034E	PARTICIPANT	\N	PRESENT	0
727052	725874	19527W	PARTICIPANT	\N	PRESENT	0
727053	725874	11066Q	PARTICIPANT	\N	PRESENT	0
727054	725874	14189C	PARTICIPANT	\N	PRESENT	0
727055	725874	14089Y	PARTICIPANT	\N	PRESENT	0
727098	725874	14053L	PARTICIPANT	\N	PRESENT	0
727096	725874	97011G	PARTICIPANT	\N	PRESENT	0
727058	725874	11053K	PARTICIPANT	\N	PRESENT	0
727059	725874	19721W	PARTICIPANT	\N	PRESENT	0
727060	725874	14267Y	PARTICIPANT	\N	PRESENT	0
727061	725874	11070L	PARTICIPANT	\N	PRESENT	0
727095	725874	20108W	PARTICIPANT	\N	PRESENT	0
727104	725874	19717B	PARTICIPANT	\N	PRESENT	0
727064	725874	14042U	PARTICIPANT	\N	PRESENT	0
727065	725874	20266L	PARTICIPANT	\N	PRESENT	0
727066	725874	14231L	PARTICIPANT	\N	PRESENT	0
727067	725874	07004J	PARTICIPANT	\N	PRESENT	0
727068	725874	20286Q	PARTICIPANT	\N	PRESENT	0
727069	725874	19569H	PARTICIPANT	\N	PRESENT	0
727070	725874	14179A	PARTICIPANT	\N	PRESENT	0
727071	725874	20048C	PARTICIPANT	\N	PRESENT	0
727072	725874	20066E	PARTICIPANT	\N	PRESENT	0
727073	725874	14073Q	PARTICIPANT	\N	PRESENT	0
727074	725874	14251Q	PARTICIPANT	\N	PRESENT	0
727075	725874	19735D	PARTICIPANT	\N	PRESENT	0
727076	725874	19699S	PARTICIPANT	\N	PRESENT	0
727077	725874	20052X	PARTICIPANT	\N	PRESENT	0
727078	725874	16685X	PARTICIPANT	\N	PRESENT	0
727079	725874	14219Q	PARTICIPANT	\N	PRESENT	0
727080	725874	19441R	PARTICIPANT	\N	PRESENT	0
727081	725874	11085T	PARTICIPANT	\N	PRESENT	0
727082	725874	19826F	PARTICIPANT	\N	PRESENT	0
727083	725874	19335Q	PARTICIPANT	\N	PRESENT	0
727084	725874	19369B	PARTICIPANT	\N	PRESENT	0
727085	725874	04070G	PARTICIPANT	\N	PRESENT	0
727086	725874	19745F	PARTICIPANT	\N	PRESENT	0
727087	725874	20298U	PARTICIPANT	\N	PRESENT	0
727088	725874	19619A	PARTICIPANT	\N	PRESENT	0
727089	725874	11083R	PARTICIPANT	\N	PRESENT	0
727090	725874	19749K	PARTICIPANT	\N	PRESENT	0
727091	725874	17779H	PARTICIPANT	\N	PRESENT	0
727092	725874	19713W	PARTICIPANT	\N	PRESENT	0
727093	725874	20040T	PARTICIPANT	\N	PRESENT	0
727094	725874	07033P	PARTICIPANT	\N	PRESENT	0
727100	725874	19685L	PARTICIPANT	\N	PRESENT	0
727125	725874	11026G	PARTICIPANT	\N	PRESENT	0
725330	722799	20132W	PARTICIPANT	\N	PRESENT	0
725331	722799	18083K	PARTICIPANT	\N	PRESENT	0
725371	722799	19741B	PARTICIPANT	\N	PRESENT	0
725333	722799	20100N	PARTICIPANT	\N	PRESENT	0
725334	722799	19525U	PARTICIPANT	\N	PRESENT	0
725328	722799	11045K	PARTICIPANT	\N	PRESENT	0
725329	722799	19701S	PARTICIPANT	\N	PRESENT	0
725335	722799	19549D	PARTICIPANT	\N	PRESENT	0
725336	722799	04085P	PARTICIPANT	\N	PRESENT	0
725337	722799	19699S	PARTICIPANT	\N	PRESENT	0
725338	722799	20090E	PARTICIPANT	\N	PRESENT	0
725339	722799	19715Y	PARTICIPANT	\N	PRESENT	0
725341	722799	11012A	PARTICIPANT	\N	PRESENT	0
725349	722799	14219Q	PARTICIPANT	\N	PRESENT	0
725360	722799	19333N	PARTICIPANT	\N	PRESENT	0
725361	722799	14073Q	PARTICIPANT	\N	PRESENT	0
725362	722799	20038A	PARTICIPANT	\N	PRESENT	0
725369	722799	14251Q	PARTICIPANT	\N	PRESENT	0
725370	722799	11010L	PARTICIPANT	\N	PRESENT	0
725372	722799	19711U	PARTICIPANT	\N	PRESENT	0
725373	722799	19319Q	PARTICIPANT	\N	PRESENT	0
725374	722799	17965H	PARTICIPANT	\N	PRESENT	0
725380	722799	19563B	PARTICIPANT	\N	PRESENT	0
725381	722799	19683J	PARTICIPANT	\N	PRESENT	0
725382	722799	19691J	PARTICIPANT	\N	PRESENT	0
725383	722799	20098N	PARTICIPANT	\N	PRESENT	0
725384	722799	19631V	PARTICIPANT	\N	PRESENT	0
725412	722801	04085P	PARTICIPANT	\N	PRESENT	0
725413	722801	19631V	PARTICIPANT	\N	PRESENT	0
725414	722801	20100N	PARTICIPANT	\N	PRESENT	0
725415	722801	14021P	PARTICIPANT	\N	PRESENT	0
725416	722801	19683J	PARTICIPANT	\N	PRESENT	0
725417	722801	19549D	PARTICIPANT	\N	PRESENT	0
725418	722801	17965H	PARTICIPANT	\N	PRESENT	0
725419	722801	11012A	PARTICIPANT	\N	PRESENT	0
725420	722801	19319Q	PARTICIPANT	\N	PRESENT	0
725421	722801	19691J	PARTICIPANT	\N	PRESENT	0
725422	722801	20108W	PARTICIPANT	\N	PRESENT	0
725423	722801	20098N	PARTICIPANT	\N	PRESENT	0
725424	722801	11010L	PARTICIPANT	\N	PRESENT	0
725425	722801	20132W	PARTICIPANT	\N	PRESENT	0
725426	722801	14251Q	PARTICIPANT	\N	PRESENT	0
725427	722801	14071N	PARTICIPANT	\N	PRESENT	0
725429	722801	19563B	PARTICIPANT	\N	PRESENT	0
725430	722801	14133K	PARTICIPANT	\N	PRESENT	0
725431	722801	11072N	PARTICIPANT	\N	PRESENT	0
725432	722801	20148F	PARTICIPANT	\N	PRESENT	0
725433	722801	01028R	PARTICIPANT	\N	PRESENT	0
725434	722801	19741B	PARTICIPANT	\N	PRESENT	0
725436	722801	18193Q	PARTICIPANT	\N	PRESENT	0
731771	730645	19629C	PRESIDENT	0	PRESENT	0
731792	730646	14259Y	PARTICIPANT	\N	PRESENT	0
725410	722801	11045K	PARTICIPANT	\N	PRESENT	0
725411	722801	19715Y	PARTICIPANT	\N	PRESENT	0
731793	730646	14231L	PARTICIPANT	\N	PRESENT	0
731795	730646	10015M	PARTICIPANT	\N	PRESENT	0
731796	730646	19447X	PARTICIPANT	\N	PRESENT	0
731797	730646	19954N	PARTICIPANT	\N	PRESENT	0
731798	730646	19729F	PARTICIPANT	\N	PRESENT	0
731799	730645	14259Y	PARTICIPANT	\N	PRESENT	0
731803	730645	20172F	PARTICIPANT	\N	PRESENT	0
731805	730646	14001X	PARTICIPANT	\N	PRESENT	0
731806	730646	19673G	PARTICIPANT	\N	PRESENT	0
731807	730646	11033F	PARTICIPANT	\N	PRESENT	0
731808	730646	11056N	PARTICIPANT	\N	PRESENT	0
731809	730646	20108W	PARTICIPANT	\N	PRESENT	0
731810	730646	14147R	PARTICIPANT	\N	PRESENT	0
731811	730646	20022R	PARTICIPANT	\N	PRESENT	0
731812	730645	14189C	PARTICIPANT	\N	PRESENT	0
731813	730645	11064N	PARTICIPANT	\N	PRESENT	0
731815	730645	11056N	PARTICIPANT	\N	PRESENT	0
731814	730646	19725B	PARTICIPANT	\N	PRESENT	0
731816	730646	14151M	PARTICIPANT	\N	PRESENT	0
731817	731537	19768N	PARTICIPANT	\N	PRESENT	0
731818	731537	19515S	PARTICIPANT	\N	PRESENT	0
731819	731537	20092G	PARTICIPANT	\N	PRESENT	0
731820	731537	19782L	PARTICIPANT	\N	PRESENT	0
731821	731537	01043Q	PARTICIPANT	\N	PRESENT	0
731822	731537	14357A	PARTICIPANT	\N	PRESENT	0
731823	731537	19441R	PARTICIPANT	\N	PRESENT	0
731824	731537	19413M	PARTICIPANT	\N	PRESENT	0
731825	731537	20094J	PARTICIPANT	\N	PRESENT	0
731826	731537	04045F	PARTICIPANT	\N	PRESENT	0
731827	731537	19866P	PARTICIPANT	\N	PRESENT	0
731828	731537	20104S	PARTICIPANT	\N	PRESENT	0
731829	731537	19705W	PARTICIPANT	\N	PRESENT	0
731830	731537	08015R	PARTICIPANT	\N	PRESENT	0
731831	731537	19575F	PARTICIPANT	\N	PRESENT	0
731832	731537	19369B	PARTICIPANT	\N	PRESENT	0
731833	731537	20018V	PARTICIPANT	\N	PRESENT	0
731834	731537	08028W	PARTICIPANT	\N	PRESENT	0
731835	731537	19563B	PARTICIPANT	\N	PRESENT	0
731836	731537	20030R	PARTICIPANT	\N	PRESENT	0
731837	731537	19467C	PARTICIPANT	\N	PRESENT	0
731838	731537	20034V	PARTICIPANT	\N	PRESENT	0
731839	731537	14187A	PARTICIPANT	\N	PRESENT	0
731840	731537	20144B	PARTICIPANT	\N	PRESENT	0
731841	731537	11090Q	PRESIDENT	0	PRESENT	0
731842	731537	01025N	PARTICIPANT	\N	PRESENT	0
731843	731537	14033T	PARTICIPANT	\N	PRESENT	0
731844	731537	20054A	PARTICIPANT	\N	PRESENT	0
731845	731537	14205J	PARTICIPANT	\N	PRESENT	0
731846	731537	20062A	PARTICIPANT	\N	PRESENT	0
731847	731537	20286Q	PARTICIPANT	\N	PRESENT	0
731848	731537	14257W	PARTICIPANT	\N	PRESENT	0
731849	730645	14001X	PARTICIPANT	\N	PRESENT	0
731850	730646	14179A	PARTICIPANT	\N	PRESENT	0
731851	730545	19333N	PARTICIPANT	\N	PRESENT	0
731852	730545	19701S	PARTICIPANT	\N	PRESENT	0
731853	730545	19549D	PARTICIPANT	\N	PRESENT	0
731854	730545	20076G	PARTICIPANT	\N	PRESENT	0
731855	730545	01057W	PARTICIPANT	\N	PRESENT	0
731856	730545	19820Y	PARTICIPANT	\N	PRESENT	0
731857	730545	14219Q	PRESIDENT	0	PRESENT	0
731858	730545	19826F	PARTICIPANT	\N	PRESENT	0
731859	730545	14221J	PARTICIPANT	\N	PRESENT	0
731860	730545	19599P	PARTICIPANT	\N	PRESENT	0
731861	730545	20102Q	PARTICIPANT	\N	PRESENT	0
731862	730545	18083K	PARTICIPANT	\N	PRESENT	0
731863	730545	20100N	PARTICIPANT	\N	PRESENT	0
731864	730545	14237S	PARTICIPANT	\N	PRESENT	0
731865	730545	05012A	PARTICIPANT	\N	PRESENT	0
731866	730545	08060W	PARTICIPANT	\N	PRESENT	0
731867	730545	20106U	PARTICIPANT	\N	PRESENT	0
731868	730545	19503N	PARTICIPANT	\N	PRESENT	0
731869	730545	20020P	PARTICIPANT	\N	PRESENT	0
731870	730545	19685L	PARTICIPANT	\N	PRESENT	0
731871	730545	17367Q	PARTICIPANT	\N	PRESENT	0
731872	730545	14259Y	PARTICIPANT	\N	PRESENT	0
731873	730545	20024T	PARTICIPANT	\N	PRESENT	0
731874	730545	11065P	PARTICIPANT	\N	PRESENT	0
731875	730545	19525U	PARTICIPANT	\N	PRESENT	0
731876	730545	20032T	PARTICIPANT	\N	PRESENT	0
731877	730545	20136B	PARTICIPANT	\N	PRESENT	0
731878	730545	20038A	PARTICIPANT	\N	PRESENT	0
731879	730545	14031R	PARTICIPANT	\N	PRESENT	0
731880	730545	20140W	PARTICIPANT	\N	PRESENT	0
731881	730545	19251M	PARTICIPANT	\N	PRESENT	0
731882	730545	17229F	PARTICIPANT	\N	PRESENT	0
731883	730545	14169X	PARTICIPANT	\N	PRESENT	0
731884	730545	20068G	PARTICIPANT	\N	PRESENT	0
731885	730545	11101A	PARTICIPANT	\N	PRESENT	0
731886	730545	19745F	PARTICIPANT	\N	PRESENT	0
731887	730545	19758L	PARTICIPANT	\N	PRESENT	0
731888	730545	19619A	PARTICIPANT	\N	PRESENT	0
731889	730545	19637C	PARTICIPANT	\N	EXCUSE	0
731890	730646	04047H	PRESIDENT	0	PRESENT	0
731891	730645	14331P	PARTICIPANT	\N	PRESENT	0
731892	730646	11026G	PARTICIPANT	\N	PRESENT	0
731893	730646	14021P	PARTICIPANT	\N	PRESENT	0
731894	730646	14069U	PARTICIPANT	\N	PRESENT	0
731895	730646	01028R	PARTICIPANT	\N	PRESENT	0
731896	730645	20082E	PARTICIPANT	\N	PRESENT	0
731897	730673	14191V	PARTICIPANT	\N	PRESENT	0
731899	730645	19954N	PARTICIPANT	\N	PRESENT	0
731913	730695	11097X	PARTICIPANT	\N	PRESENT	0
731914	730695	20130U	PARTICIPANT	\N	PRESENT	0
720150	720147	19667J	PARTICIPANT	\N	PRESENT	0
720151	720147	11040E	PARTICIPANT	\N	PRESENT	0
720167	720166	11048N	PARTICIPANT	\N	PRESENT	0
720169	720168	99004R	PARTICIPANT	\N	PRESENT	0
720171	720170	99004R	PARTICIPANT	\N	PRESENT	0
720179	720174	11074Q	PARTICIPANT	\N	PRESENT	0
720180	720174	19349W	PARTICIPANT	\N	PRESENT	0
720182	720181	99004R	PARTICIPANT	\N	PRESENT	0
722848	721817	19735D	PRESIDENT	0	PRESENT	0
722849	721817	11031D	PARTICIPANT	\N	PRESENT	0
722850	721817	20138D	PARTICIPANT	\N	PRESENT	0
722851	721817	04045F	PARTICIPANT	\N	EXCUSE	0
722852	721817	17965H	PARTICIPANT	\N	PRESENT	0
722853	721817	20066E	PARTICIPANT	\N	PRESENT	0
722854	721817	14213J	PARTICIPANT	\N	PRESENT	0
722855	721817	20050V	PARTICIPANT	\N	EXCUSE	0
722856	721817	19369B	PARTICIPANT	\N	EXCUSE	0
722857	721817	20024T	PARTICIPANT	\N	EXCUSE	0
722862	722861	20086J	PARTICIPANT	\N	PRESENT	0
722864	722863	20086J	PARTICIPANT	\N	PRESENT	0
722878	722844	11048N	PARTICIPANT	\N	PRESENT	0
722890	722825	11053K	PARTICIPANT	\N	PRESENT	0
722891	722826	01048V	PARTICIPANT	\N	PRESENT	0
722893	722827	11053K	PARTICIPANT	\N	PRESENT	0
722894	722839	11053K	PARTICIPANT	\N	PRESENT	0
722896	722840	19711U	PARTICIPANT	\N	PRESENT	0
722900	722841	19711U	PARTICIPANT	\N	PRESENT	0
722907	722904	11074Q	PARTICIPANT	\N	PRESENT	0
722908	722904	99004R	PARTICIPANT	\N	PRESENT	0
722909	722904	19349W	PARTICIPANT	\N	PRESENT	0
722910	722837	11074Q	PARTICIPANT	\N	PRESENT	0
722911	722837	19349W	PARTICIPANT	\N	PRESENT	0
722913	722838	99004R	PARTICIPANT	\N	PRESENT	0
722918	722828	19741B	PARTICIPANT	\N	PRESENT	0
722921	722829	20044X	PARTICIPANT	\N	PRESENT	0
722922	722830	20044X	PARTICIPANT	\N	PRESENT	0
722923	722831	20044X	PARTICIPANT	\N	PRESENT	0
722924	722832	20044X	PARTICIPANT	\N	PRESENT	0
722925	722833	19741B	PARTICIPANT	\N	PRESENT	0
722927	722834	19741B	PARTICIPANT	\N	PRESENT	0
722971	722970	04071H	PARTICIPANT	\N	PRESENT	0
723013	723012	20070A	PARTICIPANT	\N	PRESENT	0
723014	723012	11110B	PARTICIPANT	\N	PRESENT	0
723016	722828	19647E	PARTICIPANT	\N	PRESENT	0
723017	722828	19413M	PARTICIPANT	\N	PRESENT	0
723029	723028	08034U	PARTICIPANT	\N	PRESENT	0
723041	723037	01048V	PARTICIPANT	\N	PRESENT	0
723044	723043	01048V	PARTICIPANT	\N	PRESENT	0
723946	723945	08034U	PARTICIPANT	\N	PRESENT	0
723947	723945	19333N	PARTICIPANT	\N	PRESENT	0
724707	723382	19631V	PARTICIPANT	\N	PRESENT	0
724708	723382	19515S	PARTICIPANT	\N	PRESENT	0
724709	723382	19707Y	PARTICIPANT	\N	PRESENT	0
724710	723382	19575F	PARTICIPANT	\N	PRESENT	0
724711	723382	20094J	PARTICIPANT	\N	PRESENT	0
724712	723382	20078J	PARTICIPANT	\N	PRESENT	0
724713	723382	19747H	PARTICIPANT	\N	PRESENT	0
724714	723382	19383Y	PARTICIPANT	\N	PRESENT	0
724715	723382	19782L	PARTICIPANT	\N	PRESENT	0
724716	723382	14207L	PARTICIPANT	\N	PRESENT	0
724717	723382	20060X	PARTICIPANT	\N	PRESENT	0
724718	723382	14038Y	PARTICIPANT	\N	PRESENT	0
724719	723382	08028W	PARTICIPANT	\N	PRESENT	0
724720	723382	20144B	PARTICIPANT	\N	PRESENT	0
724722	723382	19467C	PARTICIPANT	\N	PRESENT	0
724723	723382	14357A	PARTICIPANT	\N	PRESENT	0
724725	723382	19507S	PARTICIPANT	\N	PRESENT	0
724726	723382	14187A	PARTICIPANT	\N	PRESENT	0
724727	723382	01025N	PARTICIPANT	\N	PRESENT	0
724728	723382	20286Q	PARTICIPANT	\N	PRESENT	0
724729	723382	19695N	PARTICIPANT	\N	PRESENT	0
724730	723382	14033T	PARTICIPANT	\N	PRESENT	0
724731	723382	08015R	PARTICIPANT	\N	PRESENT	0
724732	723382	14037X	PARTICIPANT	\N	PRESENT	0
724733	723382	01043Q	PARTICIPANT	\N	PRESENT	0
724734	723382	11077T	PARTICIPANT	\N	PRESENT	0
724735	723382	14205J	PARTICIPANT	\N	PRESENT	0
724736	723382	19441R	PARTICIPANT	\N	PRESENT	0
724737	723382	14251Q	PARTICIPANT	\N	PRESENT	0
724738	723382	19563B	PARTICIPANT	\N	PRESENT	0
724739	723382	20028X	PARTICIPANT	\N	PRESENT	0
724740	723382	20018V	PARTICIPANT	\N	PRESENT	0
724741	723382	19369B	PARTICIPANT	\N	PRESENT	0
724742	723382	14257W	PARTICIPANT	\N	PRESENT	0
724743	723382	19768N	PARTICIPANT	\N	PRESENT	0
724744	723382	19866P	PARTICIPANT	\N	PRESENT	0
724745	723382	20030R	PARTICIPANT	\N	EXCUSE	0
724746	723382	11090Q	PRESIDENT	0	PRESENT	0
724747	723382	20298U	PARTICIPANT	\N	PRESENT	0
724748	723382	20082E	PARTICIPANT	\N	PRESENT	0
724749	723382	19705W	PARTICIPANT	\N	PRESENT	0
724750	723382	20054A	PARTICIPANT	\N	PRESENT	0
724751	723382	20092G	PARTICIPANT	\N	PRESENT	0
724752	723382	04045F	PARTICIPANT	\N	EXCUSE	0
724753	723382	19413M	PARTICIPANT	\N	PRESENT	0
736299	735535	19525U	PARTICIPANT	\N	PRESENT	0
736300	735535	19768N	PARTICIPANT	\N	PRESENT	0
736301	735535	14109K	PARTICIPANT	\N	PRESENT	0
736306	735535	14223L	PARTICIPANT	\N	PRESENT	0
736303	735535	19699S	PARTICIPANT	\N	PRESENT	0
736305	735535	20032T	PARTICIPANT	\N	PRESENT	0
736307	735535	19729F	PARTICIPANT	\N	PRESENT	0
736309	735535	20030R	PARTICIPANT	\N	PRESENT	0
736310	735535	20088L	PARTICIPANT	\N	PRESENT	0
736311	736308	19575F	PARTICIPANT	\N	PRESENT	0
736312	736308	11053K	PARTICIPANT	\N	PRESENT	0
736313	736308	19251M	PRESIDENT	0	PRESENT	0
736314	736308	20102Q	PARTICIPANT	\N	PRESENT	0
736315	736308	17229F	PARTICIPANT	\N	PRESENT	0
736320	735535	19657G	PARTICIPANT	\N	PRESENT	0
736317	736308	11097X	PARTICIPANT	\N	PRESENT	0
736318	736308	14237S	PARTICIPANT	\N	PRESENT	0
736319	735535	14169X	PARTICIPANT	\N	PRESENT	0
736321	735535	14331P	PARTICIPANT	\N	PRESENT	0
736322	735535	14083S	PARTICIPANT	\N	PRESENT	0
736323	736308	20084G	PARTICIPANT	\N	PRESENT	0
736324	735913	08034U	PARTICIPANT	\N	PRESENT	0
736325	735913	01048V	PARTICIPANT	\N	PRESENT	0
736326	735913	20070A	PARTICIPANT	\N	PRESENT	0
736327	735913	11012A	PARTICIPANT	\N	EXCUSE	0
736328	736308	19762G	PARTICIPANT	\N	PRESENT	0
736334	735535	19758L	PARTICIPANT	\N	PRESENT	0
736335	735535	19489J	PARTICIPANT	\N	PRESENT	0
736336	735535	08045X	PARTICIPANT	\N	PRESENT	0
736337	735420	12041X	PARTICIPANT	\N	PRESENT	0
736338	735420	19565D	PARTICIPANT	\N	PRESENT	0
736339	735420	20072C	PARTICIPANT	\N	PRESENT	0
736340	735420	16685X	PARTICIPANT	\N	PRESENT	0
736341	735420	11027H	PARTICIPANT	\N	PRESENT	0
736342	735420	04042C	PRESIDENT	0	PRESENT	0
736343	735420	11054L	PARTICIPANT	\N	PRESENT	0
736344	735420	11066Q	PARTICIPANT	\N	EXCUSE	0
736345	735420	19669L	PARTICIPANT	\N	PRESENT	0
736346	735420	19421M	PARTICIPANT	\N	PRESENT	0
736347	735420	14193X	PARTICIPANT	\N	PRESENT	0
736348	735420	97011G	PARTICIPANT	\N	PRESENT	0
736349	735420	14249W	PARTICIPANT	\N	PRESENT	0
736350	735420	08047A	PARTICIPANT	\N	PRESENT	0
736351	735420	20128B	PARTICIPANT	\N	PRESENT	0
736352	735420	14097Y	PARTICIPANT	\N	PRESENT	0
736353	735420	04035D	PARTICIPANT	\N	PRESENT	0
736354	735420	14133K	PARTICIPANT	\N	PRESENT	0
736355	735420	01062T	PARTICIPANT	\N	PRESENT	0
736356	735420	20042V	PARTICIPANT	\N	PRESENT	0
736357	735420	01024M	PARTICIPANT	\N	PRESENT	0
736358	735420	20064C	PARTICIPANT	\N	PRESENT	0
736359	735420	98022P	PARTICIPANT	\N	PRESENT	0
736360	735420	14267Y	PARTICIPANT	\N	PRESENT	0
736361	735420	11064N	PARTICIPANT	\N	PRESENT	0
736362	735420	11083R	PARTICIPANT	\N	PRESENT	0
736363	735420	14211G	PARTICIPANT	\N	PRESENT	0
736364	735535	19703U	PARTICIPANT	\N	PRESENT	0
736365	735535	19705W	PARTICIPANT	\N	PRESENT	0
736366	735913	20044X	PARTICIPANT	\N	PRESENT	0
736367	735420	08061X	PARTICIPANT	\N	PRESENT	0
736368	735535	20046A	PARTICIPANT	\N	PRESENT	0
736369	735535	19760E	PARTICIPANT	\N	PRESENT	0
736370	735535	20048C	PARTICIPANT	\N	PRESENT	0
736371	735535	14073Q	PARTICIPANT	\N	PRESENT	0
736373	735535	20052X	PARTICIPANT	\N	PRESENT	0
736374	735535	19707Y	PARTICIPANT	\N	PRESENT	0
717405	716750	19741B	PARTICIPANT	\N	PRESENT	0
717406	716750	14225N	PRESIDENT	0	PRESENT	0
717407	716750	07029T	PARTICIPANT	\N	EXCUSE	0
717413	716750	14327T	PARTICIPANT	\N	PRESENT	0
717414	716750	01048V	PARTICIPANT	\N	PRESENT	0
717417	716750	20086J	PARTICIPANT	\N	PRESENT	0
717418	716750	14331P	PARTICIPANT	\N	PRESENT	0
717419	716750	19531S	PARTICIPANT	\N	PRESENT	0
717420	716750	14121F	PARTICIPANT	\N	PRESENT	0
717427	716750	01057W	PARTICIPANT	\N	PRESENT	0
717428	716750	19671E	PARTICIPANT	\N	PRESENT	0
717434	716750	19479G	PARTICIPANT	\N	PRESENT	0
717741	716502	86034E	PARTICIPANT	\N	PRESENT	0
717436	716750	11074Q	PARTICIPANT	\N	PRESENT	0
717745	716502	19413M	PARTICIPANT	\N	PRESENT	0
717453	716750	11048N	PARTICIPANT	\N	EXCUSE	0
717746	716502	14111D	PARTICIPANT	\N	PRESENT	0
717747	716502	19866P	PARTICIPANT	\N	PRESENT	0
717748	716502	19511N	PARTICIPANT	\N	PRESENT	0
717749	716502	14275Y	PARTICIPANT	\N	PRESENT	0
717750	716502	19798U	PARTICIPANT	\N	PRESENT	0
717751	716502	20252E	PARTICIPANT	\N	PRESENT	0
717752	716502	19543W	PARTICIPANT	\N	PRESENT	0
717753	716502	19581D	PARTICIPANT	\N	PRESENT	0
717754	716502	14173T	PARTICIPANT	\N	PRESENT	0
717755	716502	20108W	PARTICIPANT	\N	PRESENT	0
717756	716502	20298U	PARTICIPANT	\N	PRESENT	0
717757	716502	20086J	PARTICIPANT	\N	PRESENT	0
717758	716502	19415P	PARTICIPANT	\N	PRESENT	0
717483	715210	95041E	PARTICIPANT	\N	PRESENT	0
717484	715210	12041X	PARTICIPANT	\N	PRESENT	0
717485	715210	19565D	PARTICIPANT	\N	PRESENT	0
717486	715210	20072C	PARTICIPANT	\N	PRESENT	0
717487	715210	01058X	PARTICIPANT	\N	PRESENT	0
717488	715210	16685X	PARTICIPANT	\N	PRESENT	0
717489	715210	04042C	PRESIDENT	0	PRESENT	0
717490	715210	11054L	PARTICIPANT	\N	PRESENT	0
717491	715210	11066Q	PARTICIPANT	\N	PRESENT	0
717492	715210	12028B	PARTICIPANT	\N	PRESENT	0
717493	715210	19421M	PARTICIPANT	\N	PRESENT	0
717494	715210	19709B	PARTICIPANT	\N	PRESENT	0
717495	715210	14193X	PARTICIPANT	\N	PRESENT	0
717496	715210	19347U	PARTICIPANT	\N	PRESENT	0
717497	715210	97011G	PARTICIPANT	\N	PRESENT	0
717498	715210	08047A	PARTICIPANT	\N	PRESENT	0
717499	715210	20128B	PARTICIPANT	\N	PRESENT	0
717500	715210	14059S	PARTICIPANT	\N	PRESENT	0
717501	715210	14097Y	PARTICIPANT	\N	PRESENT	0
717502	715210	14133K	PARTICIPANT	\N	PRESENT	0
717503	715210	01062T	PARTICIPANT	\N	PRESENT	0
717504	715210	08069G	PARTICIPANT	\N	PRESENT	0
717505	715210	01024M	PARTICIPANT	\N	PRESENT	0
717506	715210	14191V	PARTICIPANT	\N	PRESENT	0
717507	715210	19319Q	PARTICIPANT	\N	PRESENT	0
717508	715210	14267Y	PARTICIPANT	\N	PRESENT	0
717509	715210	11064N	PARTICIPANT	\N	PRESENT	0
717759	716502	19583F	PARTICIPANT	\N	PRESENT	0
717760	716502	14133K	PARTICIPANT	\N	PRESENT	0
717588	715211	95041E	PARTICIPANT	\N	PRESENT	0
717589	715211	12041X	PARTICIPANT	\N	PRESENT	0
717590	715211	19565D	PARTICIPANT	\N	PRESENT	0
717591	715211	20072C	PARTICIPANT	\N	PRESENT	0
717592	715211	01058X	PARTICIPANT	\N	PRESENT	0
717593	715211	16685X	PARTICIPANT	\N	PRESENT	0
717594	715211	11027H	PARTICIPANT	\N	PRESENT	0
717595	715211	04042C	PRESIDENT	0	PRESENT	0
717596	715211	11054L	PARTICIPANT	\N	PRESENT	0
717597	715211	11066Q	PARTICIPANT	\N	PRESENT	0
717598	715211	19669L	PARTICIPANT	\N	PRESENT	0
717599	715211	12028B	PARTICIPANT	\N	PRESENT	0
717600	715211	19421M	PARTICIPANT	\N	PRESENT	0
717601	715211	19709B	PARTICIPANT	\N	PRESENT	0
717602	715211	14193X	PARTICIPANT	\N	PRESENT	0
717603	715211	19347U	PARTICIPANT	\N	PRESENT	0
717604	715211	97011G	PARTICIPANT	\N	PRESENT	0
717605	715211	08047A	PARTICIPANT	\N	PRESENT	0
717606	715211	20128B	PARTICIPANT	\N	PRESENT	0
717607	715211	14059S	PARTICIPANT	\N	PRESENT	0
717608	715211	14097Y	PARTICIPANT	\N	PRESENT	0
717609	715211	14133K	PARTICIPANT	\N	PRESENT	0
717610	715211	01062T	PARTICIPANT	\N	PRESENT	0
717611	715211	08069G	PARTICIPANT	\N	PRESENT	0
717612	715211	20042V	PARTICIPANT	\N	PRESENT	0
717613	715211	01024M	PARTICIPANT	\N	PRESENT	0
717614	715211	14191V	PARTICIPANT	\N	PRESENT	0
717615	715211	19319Q	PARTICIPANT	\N	PRESENT	0
717616	715211	14267Y	PARTICIPANT	\N	PRESENT	0
717617	715211	11064N	PARTICIPANT	\N	PRESENT	0
717618	715211	14211G	PARTICIPANT	\N	PRESENT	0
717619	716610	20088L	PARTICIPANT	\N	PRESENT	0
717620	716610	19768N	PARTICIPANT	\N	PRESENT	0
717621	716610	19515S	PARTICIPANT	\N	PRESENT	0
717622	716610	20092G	PARTICIPANT	\N	PRESENT	0
717623	716610	19782L	PARTICIPANT	\N	PRESENT	0
717624	716610	01043Q	PARTICIPANT	\N	PRESENT	0
717625	716610	14357A	PARTICIPANT	\N	PRESENT	0
717626	716610	20078J	PARTICIPANT	\N	PRESENT	0
717627	716610	19441R	PARTICIPANT	\N	PRESENT	0
717628	716610	19413M	PARTICIPANT	\N	PRESENT	0
717629	716610	20094J	PARTICIPANT	\N	PRESENT	0
717630	716610	19866P	PARTICIPANT	\N	PRESENT	0
717631	716610	04045F	PARTICIPANT	\N	PRESENT	0
717632	716610	19631V	PARTICIPANT	\N	PRESENT	0
717633	716610	20104S	PARTICIPANT	\N	PRESENT	0
717634	716610	11099A	PARTICIPANT	\N	PRESENT	0
717635	716610	08015R	PARTICIPANT	\N	PRESENT	0
717636	716610	19369B	PARTICIPANT	\N	PRESENT	0
717637	716610	20018V	PARTICIPANT	\N	PRESENT	0
717638	716610	08028W	PARTICIPANT	\N	PRESENT	0
717639	716610	20028X	PARTICIPANT	\N	PRESENT	0
717640	716610	14038Y	PARTICIPANT	\N	PRESENT	0
717641	716610	19467C	PARTICIPANT	\N	PRESENT	0
717642	716610	20034V	PARTICIPANT	\N	PRESENT	0
717643	716610	14187A	PARTICIPANT	\N	PRESENT	0
717644	716610	20144B	PARTICIPANT	\N	PRESENT	0
717645	716610	19695N	PARTICIPANT	\N	PRESENT	0
717646	716610	14033T	PARTICIPANT	\N	PRESENT	0
717647	716610	01025N	PARTICIPANT	\N	PRESENT	0
717648	716610	11090Q	PRESIDENT	0	PRESENT	0
717649	716610	20054A	PARTICIPANT	\N	PRESENT	0
717650	716610	14205J	PARTICIPANT	\N	PRESENT	0
717651	716610	20060X	PARTICIPANT	\N	PRESENT	0
717652	716610	20062A	PARTICIPANT	\N	PRESENT	0
717653	716610	19507S	PARTICIPANT	\N	PRESENT	0
717654	716610	20286Q	PARTICIPANT	\N	PRESENT	0
717655	716610	20298U	PARTICIPANT	\N	PRESENT	0
717656	716610	14207L	PARTICIPANT	\N	PRESENT	0
717657	716610	19747H	PARTICIPANT	\N	PRESENT	0
717658	716610	14257W	PARTICIPANT	\N	PRESENT	0
717659	716610	20082E	PARTICIPANT	\N	EXCUSE	0
717660	716610	19563B	PARTICIPANT	\N	EXCUSE	0
717661	716610	14329V	PARTICIPANT	\N	EXCUSE	0
717664	715210	11041F	PARTICIPANT	\N	EXCUSE	0
717665	715211	11041F	PARTICIPANT	\N	EXCUSE	0
717761	716502	20024T	PARTICIPANT	\N	PRESENT	0
717762	716502	19954N	PARTICIPANT	\N	PRESENT	0
717763	716502	95041E	PARTICIPANT	\N	PRESENT	0
717764	716502	19826F	PARTICIPANT	\N	PRESENT	0
717765	716502	19745F	PARTICIPANT	\N	PRESENT	0
717766	716502	19766L	PARTICIPANT	\N	PRESENT	0
717767	716502	19629C	PARTICIPANT	\N	PRESENT	0
717768	716502	14221J	PARTICIPANT	\N	PRESENT	0
717769	716502	20102Q	PARTICIPANT	\N	PRESENT	0
717770	716502	08028W	PARTICIPANT	\N	PRESENT	0
717771	716502	11054L	PARTICIPANT	\N	PRESENT	0
717772	716502	17229F	PARTICIPANT	\N	PRESENT	0
717773	716502	08060W	PARTICIPANT	\N	PRESENT	0
717774	716502	01024M	PARTICIPANT	\N	PRESENT	0
717775	716502	16685X	PARTICIPANT	\N	PRESENT	0
717776	716502	17023S	PARTICIPANT	\N	PRESENT	0
717777	716502	20144B	PARTICIPANT	\N	PRESENT	0
717778	716502	08010L	PARTICIPANT	\N	PRESENT	0
717779	716502	18083K	PARTICIPANT	\N	PRESENT	0
717780	716502	20076G	PARTICIPANT	\N	PRESENT	0
717781	716502	20044X	PARTICIPANT	\N	PRESENT	0
717782	716502	11045K	PARTICIPANT	\N	PRESENT	0
717783	716502	20026V	PARTICIPANT	\N	PRESENT	0
717784	716502	20028X	PARTICIPANT	\N	PRESENT	0
717785	716502	19699S	PARTICIPANT	\N	PRESENT	0
717786	716502	12028B	PARTICIPANT	\N	PRESENT	0
717787	716502	14281W	PARTICIPANT	\N	PRESENT	0
723008	721224	11109J	PARTICIPANT	\N	EXCUSE	0
723033	722682	19583F	PARTICIPANT	\N	EXCUSE	0
723034	722682	14331P	PARTICIPANT	\N	EXCUSE	0
727417	725875	14026U	PARTICIPANT	\N	PRESENT	0
727418	725875	19647E	PARTICIPANT	\N	PRESENT	0
727419	725875	20044X	PARTICIPANT	\N	PRESENT	0
727422	725875	07033P	PARTICIPANT	\N	PRESENT	0
727423	725875	20152B	PARTICIPANT	\N	PRESENT	0
727424	725875	20124W	PARTICIPANT	\N	PRESENT	0
727426	725875	14033T	PARTICIPANT	\N	PRESENT	0
727427	725875	19479G	PARTICIPANT	\N	PRESENT	0
727428	725875	14089Y	PARTICIPANT	\N	PRESENT	0
727429	725875	20036X	PARTICIPANT	\N	PRESENT	0
727430	725875	14257W	PARTICIPANT	\N	PRESENT	0
727431	725875	20082E	PARTICIPANT	\N	PRESENT	0
727432	725875	11012A	PARTICIPANT	\N	PRESENT	0
727433	725875	19585H	PARTICIPANT	\N	PRESENT	0
727434	725875	19631V	PARTICIPANT	\N	PRESENT	0
727435	725875	20116W	PARTICIPANT	\N	PRESENT	0
727436	725875	20088L	PARTICIPANT	\N	PRESENT	0
727437	725875	11040E	PARTICIPANT	\N	PRESENT	0
727438	725875	20252E	PARTICIPANT	\N	PRESENT	0
727439	725875	14253S	PARTICIPANT	\N	PRESENT	0
727440	725875	11048N	PARTICIPANT	\N	PRESENT	0
727441	725875	14225N	PARTICIPANT	\N	PRESENT	0
727442	725875	19782L	PARTICIPANT	\N	PRESENT	0
727443	725875	20980G	PARTICIPANT	\N	PRESENT	0
727444	725875	19413M	PARTICIPANT	\N	PRESENT	0
727445	725875	18193Q	PARTICIPANT	\N	PRESENT	0
727446	725875	20080C	PARTICIPANT	\N	PRESENT	0
727447	725875	19687N	PARTICIPANT	\N	PRESENT	0
727448	725875	11067R	PARTICIPANT	\N	PRESENT	0
727449	725875	19619A	PARTICIPANT	\N	PRESENT	0
727450	725875	20032T	PARTICIPANT	\N	PRESENT	0
727451	725875	07029T	PARTICIPANT	\N	PRESENT	0
727644	725878	14026U	PARTICIPANT	\N	PRESENT	0
727453	725875	20030R	PARTICIPANT	\N	PRESENT	0
727458	725696	12041X	PARTICIPANT	\N	PRESENT	0
727459	725696	19565D	PARTICIPANT	\N	PRESENT	0
727460	725696	20072C	PARTICIPANT	\N	PRESENT	0
727461	725696	01058X	PARTICIPANT	\N	PRESENT	0
727462	725696	11027H	PARTICIPANT	\N	PRESENT	0
727463	725696	04042C	PRESIDENT	0	PRESENT	0
727464	725696	11066Q	PARTICIPANT	\N	PRESENT	0
727465	725696	19669L	PARTICIPANT	\N	PRESENT	0
727466	725696	19421M	PARTICIPANT	\N	PRESENT	0
727467	725696	14193X	PARTICIPANT	\N	PRESENT	0
727468	725696	19347U	PARTICIPANT	\N	PRESENT	0
727469	725696	08061X	PARTICIPANT	\N	PRESENT	0
727470	725696	14249W	PARTICIPANT	\N	PRESENT	0
727471	725696	08047A	PARTICIPANT	\N	PRESENT	0
727472	725696	20128B	PARTICIPANT	\N	PRESENT	0
727473	725696	14097Y	PARTICIPANT	\N	PRESENT	0
727474	725696	08034U	PARTICIPANT	\N	PRESENT	0
727475	725696	14133K	PARTICIPANT	\N	PRESENT	0
727476	725696	01062T	PARTICIPANT	\N	PRESENT	0
727477	725696	11041F	PARTICIPANT	\N	PRESENT	0
727478	725696	19721W	PARTICIPANT	\N	PRESENT	0
727479	725696	11064N	PARTICIPANT	\N	PRESENT	0
727480	725696	11083R	PARTICIPANT	\N	PRESENT	0
727481	725696	14211G	PARTICIPANT	\N	PRESENT	0
727482	725696	19583F	PARTICIPANT	\N	PRESENT	0
727488	725875	17779H	PARTICIPANT	\N	PRESENT	0
727490	725875	20026V	PARTICIPANT	\N	PRESENT	0
727491	725875	20298U	PARTICIPANT	\N	PRESENT	0
727492	725875	19489J	PARTICIPANT	\N	PRESENT	0
727493	725875	19683J	PARTICIPANT	\N	PRESENT	0
727494	725875	11045K	PARTICIPANT	\N	PRESENT	0
727496	725875	19649G	PARTICIPANT	\N	PRESENT	0
727497	727425	18083K	PARTICIPANT	\N	PRESENT	0
727498	727425	20062A	PARTICIPANT	\N	PRESENT	0
727499	727425	20090E	PARTICIPANT	\N	PRESENT	0
727500	727425	14187A	PRESIDENT	0	PRESENT	0
727501	727425	19347U	PARTICIPANT	\N	PRESENT	0
727502	727425	20018V	PARTICIPANT	\N	PRESENT	0
727503	727425	20124W	PARTICIPANT	\N	PRESENT	0
727504	727425	19701S	PARTICIPANT	\N	EXCUSE	0
727505	727425	20286Q	PARTICIPANT	\N	EXCUSE	0
727506	727425	17023S	PARTICIPANT	\N	EXCUSE	0
727507	725875	11074Q	PARTICIPANT	\N	PRESENT	0
727508	725875	20024T	PARTICIPANT	\N	PRESENT	0
727509	725875	20126Y	PARTICIPANT	\N	PRESENT	0
727510	725875	14217N	PARTICIPANT	\N	PRESENT	0
727511	725875	20264J	PARTICIPANT	\N	PRESENT	0
727512	725875	20052X	PARTICIPANT	\N	PRESENT	0
727513	725875	14147R	PARTICIPANT	\N	PRESENT	0
727514	725875	14151M	PARTICIPANT	\N	PRESENT	0
727518	725875	20104S	PARTICIPANT	\N	PRESENT	0
727521	725875	20034V	PARTICIPANT	\N	PRESENT	0
727523	725875	14037X	PARTICIPANT	\N	PRESENT	0
727524	725875	19798U	PARTICIPANT	\N	PRESENT	0
727525	725875	14038Y	PARTICIPANT	\N	PRESENT	0
727527	725875	19758L	PARTICIPANT	\N	PRESENT	0
727528	725875	19531S	PARTICIPANT	\N	PRESENT	0
727529	725566	04070G	PARTICIPANT	\N	PRESENT	0
727530	725566	20064C	PRESIDENT	0	PRESENT	0
727531	725566	14147R	PARTICIPANT	\N	PRESENT	0
727532	725566	11083R	PARTICIPANT	\N	PRESENT	0
727533	725566	20152B	PARTICIPANT	\N	PRESENT	0
727534	725566	14030Q	PARTICIPANT	\N	PRESENT	0
727535	725566	17737W	PARTICIPANT	\N	EXCUSE	0
727536	725875	20018V	PARTICIPANT	\N	PRESENT	0
727645	725878	20060X	PARTICIPANT	\N	PRESENT	0
727646	725878	14187A	PARTICIPANT	\N	PRESENT	0
727647	725878	19631V	PARTICIPANT	\N	PRESENT	0
727648	725878	11077T	PARTICIPANT	\N	PRESENT	0
727649	725878	20030R	PARTICIPANT	\N	PRESENT	0
727650	725878	20088L	PARTICIPANT	\N	PRESENT	0
727651	725878	20082E	PARTICIPANT	\N	PRESENT	0
727652	725878	20264J	PARTICIPANT	\N	PRESENT	0
727653	725878	20092G	PARTICIPANT	\N	PRESENT	0
727654	725878	20036X	PARTICIPANT	\N	PRESENT	0
727655	725878	19347U	PARTICIPANT	\N	PRESENT	0
727656	725878	14037X	PARTICIPANT	\N	PRESENT	0
727657	725878	11012A	PARTICIPANT	\N	PRESENT	0
727658	725878	19866P	PARTICIPANT	\N	PRESENT	0
727659	725878	19479G	PARTICIPANT	\N	PRESENT	0
727660	725878	20090E	PARTICIPANT	\N	PRESENT	0
727661	725878	20062A	PARTICIPANT	\N	PRESENT	0
727662	725878	14147R	PARTICIPANT	\N	PRESENT	0
727663	725878	14217N	PARTICIPANT	\N	PRESENT	0
727664	725878	97011G	PARTICIPANT	\N	PRESENT	0
727665	725878	20022R	PARTICIPANT	\N	PRESENT	0
727666	725878	08010L	PARTICIPANT	\N	PRESENT	0
727667	725878	20018V	PARTICIPANT	\N	PRESENT	0
727668	725878	14021P	PARTICIPANT	\N	PRESENT	0
727669	725878	19647E	PARTICIPANT	\N	PRESENT	0
727670	725878	11067R	PARTICIPANT	\N	PRESENT	0
727671	725878	20080C	PARTICIPANT	\N	PRESENT	0
727672	725878	19527W	PARTICIPANT	\N	PRESENT	0
727673	725878	18193Q	PARTICIPANT	\N	PRESENT	0
727674	725878	11090Q	PARTICIPANT	\N	PRESENT	0
727675	725878	19629C	PARTICIPANT	\N	PRESENT	0
727676	725878	20120S	PARTICIPANT	\N	PRESENT	0
727677	725878	07029T	PARTICIPANT	\N	PRESENT	0
727678	725878	19954N	PARTICIPANT	\N	PRESENT	0
727679	725878	20140W	PARTICIPANT	\N	PRESENT	0
727683	725878	20252E	PARTICIPANT	\N	PRESENT	0
727708	727707	20138D	PARTICIPANT	\N	PRESENT	0
727712	727711	20138D	PARTICIPANT	\N	PRESENT	0
727713	727710	20138D	PARTICIPANT	\N	PRESENT	0
727714	727709	20138D	PARTICIPANT	\N	PRESENT	0
728262	728261	14069U	PARTICIPANT	\N	PRESENT	0
728266	728265	14069U	PARTICIPANT	\N	PRESENT	0
728268	728267	14069U	PARTICIPANT	\N	PRESENT	0
728272	728271	08018U	PARTICIPANT	\N	PRESENT	0
728273	728271	11026G	PARTICIPANT	\N	PRESENT	0
728274	728130	05008E	PARTICIPANT	\N	EXCUSE	0
728275	728190	05008E	PARTICIPANT	\N	EXCUSE	0
728276	728190	14331P	PARTICIPANT	\N	EXCUSE	0
728277	728130	19715Y	PARTICIPANT	\N	PRESENT	1
728278	728190	19715Y	PARTICIPANT	\N	PRESENT	1
728282	728281	14225N	PARTICIPANT	\N	PRESENT	0
728283	728281	11048N	PARTICIPANT	\N	PRESENT	0
728284	728281	08034U	PARTICIPANT	\N	PRESENT	0
728285	728281	14327T	PARTICIPANT	\N	PRESENT	0
728286	728281	19647E	PARTICIPANT	\N	PRESENT	0
728288	728287	14225N	PARTICIPANT	\N	PRESENT	0
728289	728287	11048N	PARTICIPANT	\N	PRESENT	0
728290	728287	08034U	PARTICIPANT	\N	PRESENT	0
728291	728287	14327T	PARTICIPANT	\N	PRESENT	0
719793	719791	19691J	PARTICIPANT	\N	PRESENT	0
719794	719792	19691J	PARTICIPANT	\N	PRESENT	0
719795	719792	20090E	PARTICIPANT	\N	PRESENT	0
719796	719792	14281W	PARTICIPANT	\N	PRESENT	0
719804	718543	19583F	PARTICIPANT	\N	EXCUSE	0
719818	718375	11031D	PARTICIPANT	\N	PRESENT	0
719819	718375	19735D	PRESIDENT	0	PRESENT	0
719820	718375	20096L	PARTICIPANT	\N	PRESENT	0
719824	718375	20066E	PARTICIPANT	\N	PRESENT	0
719825	718375	14026U	PARTICIPANT	\N	PRESENT	0
719826	718375	19369B	PARTICIPANT	\N	PRESENT	0
719827	718375	20050V	PARTICIPANT	\N	EXCUSE	0
719828	718375	04045F	PARTICIPANT	\N	EXCUSE	0
719829	718375	20138D	PARTICIPANT	\N	EXCUSE	0
719830	718375	20126Y	PARTICIPANT	\N	PRESENT	0
720200	720192	14257W	PARTICIPANT	\N	PRESENT	0
720984	719035	20032T	PARTICIPANT	\N	PRESENT	0
720194	720192	14187A	PRESIDENT	0	PRESENT	0
720195	720192	19347U	PARTICIPANT	\N	PRESENT	0
720196	720192	20298U	PARTICIPANT	\N	PRESENT	0
720197	720192	20018V	PARTICIPANT	\N	PRESENT	0
720198	720192	19701S	PARTICIPANT	\N	EXCUSE	0
720985	719035	20136B	PARTICIPANT	\N	PRESENT	0
720986	719035	20076G	PARTICIPANT	\N	PRESENT	0
720987	719035	19387D	PARTICIPANT	\N	PRESENT	0
720988	719035	19503N	PARTICIPANT	\N	PRESENT	0
720989	719035	14219Q	PRESIDENT	0	PRESENT	0
720990	719035	19826F	PARTICIPANT	\N	PRESENT	0
720991	719035	20102Q	PARTICIPANT	\N	PRESENT	0
720992	719035	20024T	PARTICIPANT	\N	PRESENT	0
720993	719035	20038A	PARTICIPANT	\N	PRESENT	0
720994	719035	19599P	PARTICIPANT	\N	PRESENT	0
720995	719035	18083K	PARTICIPANT	\N	PRESENT	0
720996	719035	05012A	PARTICIPANT	\N	PRESENT	0
720997	719035	20020P	PARTICIPANT	\N	PRESENT	0
720998	719035	17367Q	PARTICIPANT	\N	PRESENT	0
720999	719035	19525U	PARTICIPANT	\N	PRESENT	0
721001	719035	19333N	PARTICIPANT	\N	PRESENT	0
721002	719035	14031R	PARTICIPANT	\N	PRESENT	0
721003	719035	19820Y	PARTICIPANT	\N	PRESENT	0
721004	719035	17229F	PARTICIPANT	\N	PRESENT	0
721005	719035	20100N	PARTICIPANT	\N	PRESENT	0
721006	719035	19681G	PARTICIPANT	\N	PRESENT	0
721020	719035	19551W	PARTICIPANT	\N	PRESENT	0
721021	719035	14237S	PARTICIPANT	\N	PRESENT	0
721022	719035	20122U	PARTICIPANT	\N	EXCUSE	0
721030	719035	19549D	PARTICIPANT	\N	PRESENT	0
721036	719035	19745F	PARTICIPANT	\N	PRESENT	0
721037	719035	19619A	PARTICIPANT	\N	PRESENT	0
721233	720090	12041X	PARTICIPANT	\N	PRESENT	0
721234	720090	11115U	PARTICIPANT	\N	PRESENT	0
721235	720090	01062T	PARTICIPANT	\N	PRESENT	0
721238	721236	14327T	PARTICIPANT	\N	PRESENT	0
721239	721236	01048V	PARTICIPANT	\N	PRESENT	0
721240	721236	01057W	PARTICIPANT	\N	PRESENT	0
721241	721236	20080C	PARTICIPANT	\N	PRESENT	0
721242	721236	11070L	PARTICIPANT	\N	PRESENT	0
721243	721236	14225N	PRESIDENT	0	PRESENT	0
721244	721236	07029T	PARTICIPANT	\N	PRESENT	0
721245	721236	19349W	PARTICIPANT	\N	PRESENT	0
721246	721236	14253S	PARTICIPANT	\N	PRESENT	0
721247	721236	19335Q	PARTICIPANT	\N	PRESENT	0
721248	721236	20126Y	PARTICIPANT	\N	PRESENT	0
721249	721236	19479G	PARTICIPANT	\N	PRESENT	0
721250	721236	11048N	PARTICIPANT	\N	PRESENT	0
721251	721236	20036X	PARTICIPANT	\N	PRESENT	0
721252	721236	08034U	PARTICIPANT	\N	PRESENT	0
721253	721236	12016W	PARTICIPANT	\N	PRESENT	0
721254	721236	20050V	PARTICIPANT	\N	PRESENT	0
721255	721236	14173T	PARTICIPANT	\N	PRESENT	0
721256	721236	14083S	PARTICIPANT	\N	PRESENT	0
721257	721236	11012A	PARTICIPANT	\N	PRESENT	0
721258	721236	20252E	PARTICIPANT	\N	PRESENT	0
721259	721236	20070A	PARTICIPANT	\N	PRESENT	0
721260	721236	14121F	PARTICIPANT	\N	PRESENT	0
721261	721236	99004R	PARTICIPANT	\N	PRESENT	0
721262	721236	20914V	PARTICIPANT	\N	PRESENT	0
721263	721236	19762G	PARTICIPANT	\N	PRESENT	0
721266	721236	04071H	PARTICIPANT	\N	PRESENT	0
721267	721236	19545Y	PARTICIPANT	\N	PRESENT	0
721268	721236	19667J	PARTICIPANT	\N	PRESENT	0
721269	721236	20116W	PARTICIPANT	\N	PRESENT	0
721270	721236	14189C	PARTICIPANT	\N	PRESENT	0
721271	721236	19687N	PARTICIPANT	\N	PRESENT	0
721276	721236	14331P	PARTICIPANT	\N	PRESENT	0
721277	721236	08011M	PARTICIPANT	\N	PRESENT	0
721278	721236	20044X	PARTICIPANT	\N	PRESENT	0
721279	721236	11074Q	PARTICIPANT	\N	PRESENT	0
721280	721236	08010L	PARTICIPANT	\N	PRESENT	0
721281	721236	08009T	PARTICIPANT	\N	PRESENT	0
721282	721236	19647E	PARTICIPANT	\N	PRESENT	0
721283	721236	19671E	PARTICIPANT	\N	PRESENT	0
721301	721236	11053K	PARTICIPANT	\N	PRESENT	0
721324	721264	14327T	PARTICIPANT	\N	PRESENT	0
721325	721264	14331P	PARTICIPANT	\N	PRESENT	0
721326	721264	04071H	PARTICIPANT	\N	PRESENT	0
721327	721264	01048V	PARTICIPANT	\N	PRESENT	0
721328	721264	01057W	PARTICIPANT	\N	PRESENT	0
721329	721264	11053K	PARTICIPANT	\N	PRESENT	0
721330	721264	20080C	PARTICIPANT	\N	PRESENT	0
721331	721264	19667J	PARTICIPANT	\N	PRESENT	0
721332	721264	11074Q	PARTICIPANT	\N	PRESENT	0
721333	721264	19671E	PARTICIPANT	\N	PRESENT	0
721334	721264	11070L	PARTICIPANT	\N	PRESENT	0
721335	721264	14225N	PRESIDENT	0	PRESENT	0
721336	721264	07029T	PARTICIPANT	\N	PRESENT	0
721337	721264	19349W	PARTICIPANT	\N	PRESENT	0
721338	721264	08010L	PARTICIPANT	\N	PRESENT	0
721339	721264	14253S	PARTICIPANT	\N	PRESENT	0
721340	721264	20116W	PARTICIPANT	\N	PRESENT	0
721341	721264	19335Q	PARTICIPANT	\N	PRESENT	0
721342	721264	19479G	PARTICIPANT	\N	PRESENT	0
721343	721264	11048N	PARTICIPANT	\N	PRESENT	0
721344	721264	20036X	PARTICIPANT	\N	PRESENT	0
721345	721264	14189C	PARTICIPANT	\N	PRESENT	0
721346	721264	08034U	PARTICIPANT	\N	PRESENT	0
721347	721264	12016W	PARTICIPANT	\N	PRESENT	0
721348	721264	20050V	PARTICIPANT	\N	PRESENT	0
721349	721264	08011M	PARTICIPANT	\N	PRESENT	0
721350	721264	20044X	PARTICIPANT	\N	PRESENT	0
721351	721264	14173T	PARTICIPANT	\N	PRESENT	0
721352	721264	14083S	PARTICIPANT	\N	PRESENT	0
721353	721264	20252E	PARTICIPANT	\N	PRESENT	0
721354	721264	08009T	PARTICIPANT	\N	PRESENT	0
721355	721264	20070A	PARTICIPANT	\N	PRESENT	0
721356	721264	19741B	PARTICIPANT	\N	PRESENT	0
721357	721264	14121F	PARTICIPANT	\N	PRESENT	0
721358	721264	99004R	PARTICIPANT	\N	PRESENT	0
721359	721264	20914V	PARTICIPANT	\N	PRESENT	0
721360	721264	19762G	PARTICIPANT	\N	PRESENT	0
721375	719035	20120S	PARTICIPANT	\N	PRESENT	0
721376	719035	19251M	PARTICIPANT	\N	PRESENT	0
721377	719035	19739H	PARTICIPANT	\N	PRESENT	0
721824	720098	14251Q	PARTICIPANT	\N	PRESENT	0
721797	720098	19543W	PARTICIPANT	\N	PRESENT	0
721799	720098	11115U	PARTICIPANT	\N	PRESENT	0
721800	720098	19527W	PARTICIPANT	\N	PRESENT	0
721809	720098	17023S	PARTICIPANT	\N	PRESENT	0
721810	720098	20298U	PARTICIPANT	\N	PRESENT	0
721822	720098	19621T	PARTICIPANT	\N	PRESENT	0
721812	720098	19057M	PARTICIPANT	\N	PRESENT	0
721819	720098	01048V	PARTICIPANT	\N	PRESENT	0
721820	720098	08011M	PARTICIPANT	\N	PRESENT	0
715269	715268	19367Y	PARTICIPANT	\N	PRESENT	0
715271	715268	14213J	PARTICIPANT	\N	PRESENT	0
715273	715268	11067R	PARTICIPANT	\N	PRESENT	0
715284	715282	20024T	PARTICIPANT	\N	PRESENT	0
715285	715282	11031D	PARTICIPANT	\N	PRESENT	0
715286	715282	14213J	PARTICIPANT	\N	PRESENT	0
715287	715282	20096L	PARTICIPANT	\N	PRESENT	0
728042	728041	19515S	PRESIDENT	0	PRESENT	0
728043	728041	19575F	PARTICIPANT	\N	PRESENT	0
728044	728041	20094J	PARTICIPANT	\N	PRESENT	0
728045	728041	19671E	PARTICIPANT	\N	EXCUSE	0
728046	728041	20082E	PARTICIPANT	\N	EXCUSE	0
728047	728041	19762G	PARTICIPANT	\N	EXCUSE	0
728048	728041	19760E	PARTICIPANT	\N	EXCUSE	0
728049	728041	14105F	PARTICIPANT	\N	EXCUSE	0
728050	728041	14083S	PARTICIPANT	\N	PRESENT	0
728051	728041	20060X	PARTICIPANT	\N	EXCUSE	0
737777	737720	20024T	PRESIDENT	0	PRESENT	0
737778	737720	20266L	PARTICIPANT	\N	PRESENT	0
728054	728041	08028W	PARTICIPANT	\N	EXCUSE	0
728055	728041	19467C	PARTICIPANT	\N	EXCUSE	0
728056	728041	14026U	PARTICIPANT	\N	EXCUSE	0
728057	728041	20048C	PARTICIPANT	\N	EXCUSE	0
728058	728041	20126Y	PARTICIPANT	\N	EXCUSE	0
728059	728041	08015R	PARTICIPANT	\N	EXCUSE	0
728060	728041	16685X	PARTICIPANT	\N	EXCUSE	0
728061	728041	14031R	PARTICIPANT	\N	EXCUSE	0
728079	728041	19369B	PARTICIPANT	\N	PRESENT	0
737780	737720	19735D	PRESIDENT	1	PRESENT	0
728081	728041	19866P	PARTICIPANT	\N	EXCUSE	0
728177	728041	04045F	PARTICIPANT	\N	PRESENT	0
737781	737720	11031D	PARTICIPANT	\N	PRESENT	0
737783	737720	17965H	PARTICIPANT	\N	PRESENT	0
737784	737720	20126Y	PARTICIPANT	\N	PRESENT	0
737821	737720	20050V	PARTICIPANT	\N	EXCUSE	0
736856	736843	14031R	PARTICIPANT	\N	PRESENT	0
737776	737720	14213J	PARTICIPANT	\N	PRESENT	0
737823	737720	04045F	PARTICIPANT	\N	EXCUSE	0
738388	738386	14259Y	PARTICIPANT	\N	PRESENT	0
738389	738386	19629C	PARTICIPANT	\N	PRESENT	0
738390	738386	14329V	PARTICIPANT	\N	PRESENT	0
738391	738386	19954N	PARTICIPANT	\N	PRESENT	0
738392	738386	19489J	PARTICIPANT	\N	PRESENT	0
738395	738003	20124W	PARTICIPANT	\N	PRESENT	0
738396	738003	18083K	PARTICIPANT	\N	PRESENT	0
738397	738003	14042U	PARTICIPANT	\N	PRESENT	0
738398	738003	20106U	PARTICIPANT	\N	PRESENT	0
738399	738003	19621T	PARTICIPANT	\N	PRESENT	0
738400	738333	14038Y	PARTICIPANT	\N	PRESENT	0
738401	738333	04070G	PRESIDENT	1	PRESENT	0
738402	738333	20134Y	PARTICIPANT	\N	PRESENT	0
738403	738333	20062A	PARTICIPANT	\N	PRESENT	0
738404	738333	11077T	PRESIDENT	0	PRESENT	0
738405	738333	14189C	PARTICIPANT	\N	PRESENT	0
738406	738333	14179A	PARTICIPANT	\N	PRESENT	0
738407	738333	14151M	PARTICIPANT	\N	PRESENT	0
738408	738333	20082E	PARTICIPANT	\N	PRESENT	0
738409	738333	20022R	PARTICIPANT	\N	PRESENT	0
738410	738333	14030Q	PARTICIPANT	\N	PRESENT	0
738411	738333	14237S	PARTICIPANT	\N	PRESENT	0
738412	738003	95063L	PARTICIPANT	\N	PRESENT	0
738413	738333	20034V	PARTICIPANT	\N	PRESENT	0
738414	738333	19651A	PARTICIPANT	\N	PRESENT	0
738415	738333	20140W	PARTICIPANT	\N	PRESENT	0
738416	738333	20052X	PARTICIPANT	\N	PRESENT	0
738417	738333	20098N	PARTICIPANT	\N	PRESENT	0
738418	738333	11045K	PARTICIPANT	\N	PRESENT	0
738419	738333	14229S	PARTICIPANT	\N	PRESENT	0
738420	738333	20060X	PARTICIPANT	\N	PRESENT	0
738421	738333	20128B	PARTICIPANT	\N	PRESENT	0
738422	738333	20096L	PARTICIPANT	\N	PRESENT	0
738423	738333	20122U	PARTICIPANT	\N	PRESENT	0
738424	738003	14195A	PARTICIPANT	\N	PRESENT	0
738425	738003	08060W	PARTICIPANT	\N	PRESENT	0
738430	738003	14267Y	PARTICIPANT	\N	PRESENT	0
738431	738333	20138D	PARTICIPANT	\N	PRESENT	0
738432	738003	20086J	PARTICIPANT	\N	PRESENT	0
738434	738003	14191V	PARTICIPANT	\N	PRESENT	0
738435	738333	20132W	PARTICIPANT	\N	EXCUSE	0
738436	738003	14189C	PARTICIPANT	\N	PRESENT	0
738437	738003	19713W	PARTICIPANT	\N	PRESENT	0
738438	738003	14193X	PARTICIPANT	\N	PRESENT	0
738439	738003	20140W	PARTICIPANT	\N	PRESENT	0
738444	738003	14169X	PARTICIPANT	\N	PRESENT	0
738445	738003	19531S	PARTICIPANT	\N	PRESENT	0
738446	738003	19503N	PARTICIPANT	\N	PRESENT	0
738447	738003	19637C	PARTICIPANT	\N	PRESENT	0
738448	738003	20136B	PARTICIPANT	\N	PRESENT	0
738449	738003	20146D	PARTICIPANT	\N	PRESENT	0
738450	738003	14001X	PARTICIPANT	\N	PRESENT	0
738503	738502	20064C	PARTICIPANT	\N	PRESENT	0
738504	738502	14030Q	PARTICIPANT	\N	PRESENT	0
738505	738502	11045K	PARTICIPANT	\N	PRESENT	0
738506	738502	14251Q	PARTICIPANT	\N	PRESENT	0
738507	738502	11083R	PARTICIPANT	\N	PRESENT	0
738509	738508	20064C	PARTICIPANT	\N	PRESENT	0
738510	738508	14251Q	PARTICIPANT	\N	PRESENT	0
738511	738508	14030Q	PARTICIPANT	\N	PRESENT	0
738512	738508	20152B	PARTICIPANT	\N	PRESENT	0
738513	738508	20068G	PARTICIPANT	\N	PRESENT	0
738514	738508	14147R	PARTICIPANT	\N	PRESENT	0
738527	738519	19711U	PARTICIPANT	\N	PRESENT	0
738529	738528	19711U	PARTICIPANT	\N	PRESENT	0
738531	738530	19711U	PARTICIPANT	\N	PRESENT	0
738533	738532	19711U	PARTICIPANT	\N	PRESENT	0
738535	738534	19711U	PARTICIPANT	\N	PRESENT	0
738537	738536	19711U	PARTICIPANT	\N	PRESENT	0
738539	738538	19711U	PARTICIPANT	\N	PRESENT	0
738541	738540	19711U	PARTICIPANT	\N	PRESENT	0
738543	738542	19711U	PARTICIPANT	\N	PRESENT	0
738549	738548	08034U	PARTICIPANT	\N	PRESENT	0
738563	738561	14030Q	PARTICIPANT	\N	PRESENT	0
738564	738561	20066E	PARTICIPANT	\N	PRESENT	0
738566	738561	14109K	PARTICIPANT	\N	PRESENT	1
738567	738015	01028R	PARTICIPANT	\N	PRESENT	0
738568	738015	17737W	PARTICIPANT	\N	PRESENT	0
738569	738015	20022R	PARTICIPANT	\N	PRESENT	0
738570	738015	14259Y	PARTICIPANT	\N	PRESENT	0
738572	738004	14053L	PARTICIPANT	\N	PRESENT	0
738573	738004	19749K	PARTICIPANT	\N	PRESENT	0
738574	738004	19725B	PARTICIPANT	\N	PRESENT	0
738575	738004	11056N	PARTICIPANT	\N	PRESENT	0
738576	738004	14089Y	PARTICIPANT	\N	PRESENT	0
738577	738004	14055N	PARTICIPANT	\N	PRESENT	0
738578	738004	14107H	PARTICIPANT	\N	PRESENT	0
738579	738004	20108W	PARTICIPANT	\N	PRESENT	0
738580	738004	20122U	PARTICIPANT	\N	PRESENT	0
738581	738004	20110Q	PARTICIPANT	\N	PRESENT	0
738582	738004	11072N	PARTICIPANT	\N	PRESENT	0
738583	738004	01028R	PARTICIPANT	\N	PRESENT	0
738584	738004	20038A	PARTICIPANT	\N	PRESENT	0
738585	738004	11045K	PARTICIPANT	\N	PRESENT	0
738586	738004	19954N	PARTICIPANT	\N	PRESENT	0
738587	738004	14215L	PARTICIPANT	\N	PRESENT	0
738588	738004	20074E	PARTICIPANT	\N	PRESENT	0
738589	738004	14169X	PARTICIPANT	\N	PRESENT	0
738590	738004	19515S	PARTICIPANT	\N	PRESENT	0
738591	738004	14069U	PARTICIPANT	\N	PRESENT	0
738592	738004	11033F	PARTICIPANT	\N	PRESENT	0
738593	738004	20022R	PARTICIPANT	\N	PRESENT	0
738594	738004	19649G	PARTICIPANT	\N	PRESENT	0
738595	738004	14147R	PARTICIPANT	\N	PRESENT	0
738596	738004	14151M	PARTICIPANT	\N	PRESENT	0
738597	738004	20088L	PARTICIPANT	\N	PRESENT	0
738598	738004	99004R	PARTICIPANT	\N	PRESENT	0
738599	738004	20030R	PARTICIPANT	\N	PRESENT	0
738600	738004	19295A	PARTICIPANT	\N	PRESENT	0
738601	738004	18083K	PARTICIPANT	\N	PRESENT	0
738602	738004	95063L	PARTICIPANT	\N	PRESENT	0
738603	738004	19826F	PARTICIPANT	\N	PRESENT	0
738604	738004	19387D	PARTICIPANT	\N	PRESENT	0
738605	738004	14073Q	PARTICIPANT	\N	PRESENT	0
738606	738004	14231L	PARTICIPANT	\N	PRESENT	0
738607	738004	14211G	PARTICIPANT	\N	PRESENT	0
738608	738004	08010L	PARTICIPANT	\N	PRESENT	0
738609	738004	98022P	PARTICIPANT	\N	PRESENT	0
738610	738004	19553Y	PARTICIPANT	\N	PRESENT	0
738611	738004	19447X	PARTICIPANT	\N	PRESENT	0
738612	738004	20116W	PARTICIPANT	\N	PRESENT	0
738613	738004	20034V	PARTICIPANT	\N	PRESENT	0
738614	738004	19441R	PARTICIPANT	\N	PRESENT	0
717788	716502	20110Q	PARTICIPANT	\N	PRESENT	0
717789	716502	11040E	PARTICIPANT	\N	PRESENT	0
717790	716502	14217N	PARTICIPANT	\N	PRESENT	0
717791	716502	19525U	PARTICIPANT	\N	PRESENT	0
717792	716502	14207L	PARTICIPANT	\N	PRESENT	0
717793	716502	19565D	PARTICIPANT	\N	PRESENT	0
717794	716502	14211G	PARTICIPANT	\N	PRESENT	0
717795	716502	20142Y	PARTICIPANT	\N	PRESENT	0
717796	716502	04008A	PARTICIPANT	\N	PRESENT	0
717797	716502	20068G	PARTICIPANT	\N	PRESENT	0
717798	716502	01048V	PARTICIPANT	\N	PRESENT	0
717799	716502	04047H	PARTICIPANT	\N	PRESENT	0
717800	716502	04033B	PARTICIPANT	\N	PRESENT	0
717801	716502	14071N	PARTICIPANT	\N	PRESENT	0
717802	716502	08034U	PARTICIPANT	\N	PRESENT	0
717803	716502	19747H	PARTICIPANT	\N	PRESENT	0
717804	716502	20034V	PARTICIPANT	\N	PRESENT	0
717805	716502	17637T	PARTICIPANT	\N	PRESENT	0
717806	716502	19447X	PARTICIPANT	\N	PRESENT	0
717807	716502	20038A	PARTICIPANT	\N	PRESENT	0
717808	716502	20056C	PARTICIPANT	\N	PRESENT	0
717809	716502	20098N	PARTICIPANT	\N	PRESENT	0
717810	716502	14033T	PARTICIPANT	\N	PRESENT	0
717811	716502	20180F	PARTICIPANT	\N	PRESENT	0
717812	716502	19515S	PARTICIPANT	\N	PRESENT	0
717813	716502	19673G	PARTICIPANT	\N	PRESENT	0
717814	716502	20980G	PARTICIPANT	\N	PRESENT	0
717815	716502	19709B	PARTICIPANT	\N	PRESENT	0
717816	716502	19741B	PARTICIPANT	\N	PRESENT	0
717817	716502	14031R	PARTICIPANT	\N	PRESENT	0
717818	716502	19667J	PARTICIPANT	\N	PRESENT	0
717819	716502	14191V	PARTICIPANT	\N	PRESENT	0
717820	716502	11080N	PARTICIPANT	\N	PRESENT	0
717821	716502	01057W	PARTICIPANT	\N	PRESENT	0
717822	716502	14253S	PARTICIPANT	\N	PRESENT	0
717823	716502	20136B	PARTICIPANT	\N	PRESENT	0
717824	716502	14169X	PARTICIPANT	\N	PRESENT	0
717825	716502	08015R	PARTICIPANT	\N	PRESENT	0
717826	716502	20104S	PARTICIPANT	\N	PRESENT	0
717827	716502	19399H	PARTICIPANT	\N	PRESENT	0
717828	716502	19768N	PARTICIPANT	\N	PRESENT	0
717829	716502	19707Y	PARTICIPANT	\N	PRESENT	0
717830	716502	20138D	PARTICIPANT	\N	PRESENT	0
717831	716502	20172F	PARTICIPANT	\N	PRESENT	0
717832	716502	05008E	PARTICIPANT	\N	PRESENT	0
717833	716502	14147R	PARTICIPANT	\N	PRESENT	0
717834	716502	20062A	PARTICIPANT	\N	PRESENT	0
717835	716502	20090E	PARTICIPANT	\N	PRESENT	0
717836	716502	19760E	PARTICIPANT	\N	PRESENT	0
717837	716502	04085P	PARTICIPANT	\N	PRESENT	0
717838	716502	14329V	PARTICIPANT	\N	PRESENT	0
717839	716502	19758L	PARTICIPANT	\N	PRESENT	0
717840	716502	14059S	PARTICIPANT	\N	PRESENT	0
717841	716502	11056N	PARTICIPANT	\N	PRESENT	0
717842	716502	12041X	PARTICIPANT	\N	PRESENT	0
717843	716502	14357A	PARTICIPANT	\N	PRESENT	0
717844	716502	11077T	PARTICIPANT	\N	PRESENT	0
717845	716502	19687N	PARTICIPANT	\N	PRESENT	0
717846	716502	97011G	PARTICIPANT	\N	PRESENT	0
717847	716502	14259Y	PARTICIPANT	\N	PRESENT	0
717848	716502	20032T	PARTICIPANT	\N	PRESENT	0
717849	716502	20036X	PARTICIPANT	\N	PRESENT	0
717850	716502	20022R	PARTICIPANT	\N	PRESENT	0
717851	716502	05012A	PARTICIPANT	\N	PRESENT	0
717852	716502	11090Q	PARTICIPANT	\N	PRESENT	0
717853	716502	19695N	PARTICIPANT	\N	PRESENT	0
717854	716502	19643A	PARTICIPANT	\N	PRESENT	0
717855	716502	20078J	PARTICIPANT	\N	PRESENT	0
717856	716502	20914V	PARTICIPANT	\N	PRESENT	0
717857	716502	20100N	PARTICIPANT	\N	PRESENT	0
717858	716502	20074E	PARTICIPANT	\N	PRESENT	0
717859	716502	19347U	PARTICIPANT	\N	PRESENT	0
717860	716502	11099A	PARTICIPANT	\N	PRESENT	0
717861	716502	20130U	PARTICIPANT	\N	PRESENT	0
717862	716502	08069G	PARTICIPANT	\N	PRESENT	0
717863	716502	20092G	PARTICIPANT	\N	PRESENT	0
717864	716502	20266L	PARTICIPANT	\N	PRESENT	0
717865	716502	04042C	PARTICIPANT	\N	PRESENT	0
717866	716502	19693L	PARTICIPANT	\N	PRESENT	0
717867	716502	19651A	PARTICIPANT	\N	PRESENT	0
717868	716502	04035D	PARTICIPANT	\N	PRESENT	0
717869	716502	19782L	PARTICIPANT	\N	PRESENT	0
717870	716502	20016T	PARTICIPANT	\N	PRESENT	0
717871	716502	14037X	PARTICIPANT	\N	PRESENT	0
717872	716502	14026U	PARTICIPANT	\N	PRESENT	0
717873	716502	20106U	PARTICIPANT	\N	PRESENT	0
717874	716502	19697Q	PARTICIPANT	\N	PRESENT	0
717875	716502	19591F	PARTICIPANT	\N	PRESENT	0
717876	716502	14249W	PARTICIPANT	\N	PRESENT	0
717877	716502	19637C	PARTICIPANT	\N	PRESENT	0
717878	716502	11048N	PARTICIPANT	\N	PRESENT	0
717879	716502	19507S	PARTICIPANT	\N	PRESENT	0
717880	716502	11097X	PARTICIPANT	\N	PRESENT	0
717881	716502	19421M	PARTICIPANT	\N	PRESENT	0
717882	716502	08073C	PARTICIPANT	\N	PRESENT	0
717883	716502	11072N	PARTICIPANT	\N	PRESENT	0
717884	716502	08061X	PARTICIPANT	\N	PRESENT	0
717885	716502	14053L	PARTICIPANT	\N	PRESENT	0
717886	716502	14187A	PARTICIPANT	\N	PRESENT	0
717887	716502	04045F	PARTICIPANT	\N	PRESENT	0
717888	716502	95063L	PARTICIPANT	\N	PRESENT	0
717889	716502	19701S	PARTICIPANT	\N	PRESENT	0
717890	716502	14069U	PARTICIPANT	\N	PRESENT	0
717891	716502	11033F	PARTICIPANT	\N	PRESENT	0
717892	716502	10006L	PARTICIPANT	\N	PRESENT	0
717893	716502	14193X	PARTICIPANT	\N	PRESENT	0
717894	716502	19681G	PARTICIPANT	\N	PRESENT	0
717895	716502	14237S	PARTICIPANT	\N	PRESENT	0
717896	716502	19719D	PARTICIPANT	\N	PRESENT	0
717897	716502	20132W	PARTICIPANT	\N	PRESENT	0
717898	716502	19671E	PARTICIPANT	\N	PRESENT	0
717899	716502	19387D	PARTICIPANT	\N	PRESENT	0
717900	716502	19367Y	PARTICIPANT	\N	PRESENT	0
717901	716502	20116W	PARTICIPANT	\N	PRESENT	0
717902	716502	19553Y	PARTICIPANT	\N	PRESENT	0
717903	716502	20072C	PARTICIPANT	\N	PRESENT	0
717904	716502	20054A	PARTICIPANT	\N	PRESENT	0
717905	716502	11012A	PARTICIPANT	\N	PRESENT	0
717906	716502	20126Y	PARTICIPANT	\N	PRESENT	0
717907	716502	20118Y	PARTICIPANT	\N	PRESENT	0
717908	716502	11064N	PARTICIPANT	\N	PRESENT	0
717909	716502	19762G	PARTICIPANT	\N	PRESENT	0
717910	716502	14251Q	PARTICIPANT	\N	PRESENT	0
717911	716502	04057K	PARTICIPANT	\N	PRESENT	0
717912	716502	14331P	PARTICIPANT	\N	PRESENT	0
717913	716502	04092N	PARTICIPANT	\N	PRESENT	0
717914	716502	20122U	PARTICIPANT	\N	PRESENT	0
717915	716502	19585H	PARTICIPANT	\N	PRESENT	0
717916	716502	20120S	PARTICIPANT	\N	PRESENT	0
717917	716502	20042V	PARTICIPANT	\N	PRESENT	0
717918	716502	20096L	PARTICIPANT	\N	PRESENT	0
717919	716502	19679N	PARTICIPANT	\N	PRESENT	0
717920	716502	19467C	PARTICIPANT	\N	PRESENT	0
717921	716502	20264J	PARTICIPANT	\N	PRESENT	0
717922	716502	19333N	PARTICIPANT	\N	PRESENT	0
717923	716502	11067R	PARTICIPANT	\N	PRESENT	0
717924	716502	14001X	PARTICIPANT	\N	PRESENT	0
717925	716502	07029T	PARTICIPANT	\N	PRESENT	0
717926	716502	14121F	PARTICIPANT	\N	PRESENT	0
717927	716502	19683J	PARTICIPANT	\N	PRESENT	0
717928	716502	20030R	PARTICIPANT	\N	PRESENT	0
717929	716502	08012N	PARTICIPANT	\N	PRESENT	0
717930	716502	14229S	PARTICIPANT	\N	PRESENT	0
717932	716502	08047A	PARTICIPANT	\N	PRESENT	0
717933	716502	20094J	PARTICIPANT	\N	PRESENT	0
717934	716502	19549D	PARTICIPANT	\N	PRESENT	0
717935	716502	04059M	PARTICIPANT	\N	PRESENT	0
717936	716502	19705W	PARTICIPANT	\N	PRESENT	0
717937	716502	01028R	PARTICIPANT	\N	PRESENT	0
717938	716502	14225N	PARTICIPANT	\N	PRESENT	0
717939	716502	19503N	PARTICIPANT	\N	PRESENT	0
717940	716502	19725B	PARTICIPANT	\N	PRESENT	0
717941	716502	11066Q	PARTICIPANT	\N	PRESENT	0
717942	716502	19527W	PARTICIPANT	\N	PRESENT	0
717943	716502	11041F	PARTICIPANT	\N	PRESENT	0
717944	716502	17965H	PARTICIPANT	\N	PRESENT	0
717945	716502	19593H	PARTICIPANT	\N	PRESENT	0
717946	716502	20018V	PARTICIPANT	\N	PRESENT	0
717947	716502	20088L	PARTICIPANT	\N	PRESENT	0
717948	716502	19723Y	PARTICIPANT	\N	PRESENT	0
728292	728287	19647E	PARTICIPANT	\N	PRESENT	0
728294	728293	14225N	PARTICIPANT	\N	PRESENT	0
728295	728293	11048N	PARTICIPANT	\N	PRESENT	0
728296	728293	08034U	PARTICIPANT	\N	PRESENT	0
728297	728293	14327T	PARTICIPANT	\N	PRESENT	0
728298	728293	19647E	PARTICIPANT	\N	PRESENT	0
729375	729374	05012A	PARTICIPANT	\N	PRESENT	0
729376	729374	20032T	PARTICIPANT	\N	PRESENT	0
729379	729378	05012A	PARTICIPANT	\N	PRESENT	0
729380	729378	20032T	PARTICIPANT	\N	PRESENT	0
729574	725628	11097X	PARTICIPANT	\N	PRESENT	0
729882	729881	20076G	PARTICIPANT	\N	PRESENT	0
729883	729881	20024T	PARTICIPANT	\N	PRESENT	0
729884	729881	17367Q	PARTICIPANT	\N	PRESENT	0
729885	729881	20090E	PARTICIPANT	\N	PRESENT	0
729886	729881	11103C	PARTICIPANT	\N	PRESENT	0
729887	729881	14329V	PARTICIPANT	\N	PRESENT	0
729888	729881	19467C	PARTICIPANT	\N	PRESENT	0
729890	729881	18083K	PARTICIPANT	\N	PRESENT	0
729891	729881	19681G	PARTICIPANT	\N	PRESENT	0
729892	729881	17589D	PARTICIPANT	\N	PRESENT	0
729893	729881	14187A	PARTICIPANT	\N	PRESENT	0
729894	729881	20038A	PARTICIPANT	\N	PRESENT	0
729895	729881	14213J	PARTICIPANT	\N	PRESENT	0
729896	729881	20126Y	PARTICIPANT	\N	PRESENT	0
729897	729881	14221J	PARTICIPANT	\N	PRESENT	0
729898	729881	20018V	PARTICIPANT	\N	PRESENT	0
729899	729881	05012A	PARTICIPANT	\N	PRESENT	0
729900	729881	19619A	PARTICIPANT	\N	PRESENT	0
729901	729881	20092G	PARTICIPANT	\N	PRESENT	0
729902	729881	20044X	PARTICIPANT	\N	PRESENT	0
730245	730244	14030Q	PARTICIPANT	\N	PRESENT	0
730246	730244	20114U	PARTICIPANT	\N	PRESENT	0
730247	730244	19621T	PARTICIPANT	\N	PRESENT	0
730248	730244	14211G	PARTICIPANT	\N	PRESENT	0
730249	730244	19591F	PARTICIPANT	\N	PRESENT	0
730250	730244	99004R	PARTICIPANT	\N	PRESENT	0
730251	730244	08015R	PARTICIPANT	\N	PRESENT	0
730252	730244	11026G	PARTICIPANT	\N	PRESENT	0
730253	730244	20052X	PARTICIPANT	\N	PRESENT	0
730254	730244	11085T	PARTICIPANT	\N	PRESENT	0
730255	730244	10015M	PARTICIPANT	\N	PRESENT	0
730256	730244	11012A	PARTICIPANT	\N	PRESENT	0
730257	730244	04045F	PARTICIPANT	\N	PRESENT	0
730982	730981	19741B	PARTICIPANT	\N	PRESENT	0
730983	730981	14255U	PARTICIPANT	\N	PRESENT	0
730984	730981	10006L	PARTICIPANT	\N	PRESENT	0
730985	730981	20066E	PARTICIPANT	\N	PRESENT	0
730987	730981	12041X	PARTICIPANT	\N	PRESENT	0
730988	730981	19745F	PARTICIPANT	\N	PRESENT	0
730996	730995	10006L	PARTICIPANT	\N	PRESENT	0
730999	730997	19782L	PARTICIPANT	\N	PRESENT	0
731000	730997	10006L	PARTICIPANT	\N	PRESENT	0
731001	730997	20066E	PARTICIPANT	\N	PRESENT	0
731002	730997	14073Q	PARTICIPANT	\N	PRESENT	0
733167	732893	11070L	PARTICIPANT	\N	PRESENT	0
733165	732893	20144B	PARTICIPANT	\N	PRESENT	0
733166	732893	14213J	PARTICIPANT	\N	PRESENT	0
733168	732893	08015R	PARTICIPANT	\N	PRESENT	0
733169	732893	14327T	PARTICIPANT	\N	PRESENT	0
733170	732893	20108W	PARTICIPANT	\N	PRESENT	0
733171	732893	17229F	PARTICIPANT	\N	PRESENT	0
733172	732893	14042U	PARTICIPANT	\N	PRESENT	0
733173	732893	08010L	PARTICIPANT	\N	PRESENT	0
733174	732893	14147R	PARTICIPANT	\N	PRESENT	0
733175	732893	19695N	PARTICIPANT	\N	PRESENT	0
733176	732893	14030Q	PARTICIPANT	\N	PRESENT	0
733177	732893	08009T	PARTICIPANT	\N	PRESENT	0
733178	732893	07004J	PARTICIPANT	\N	PRESENT	0
733179	732893	14231L	PARTICIPANT	\N	PRESENT	0
733180	732893	19691J	PARTICIPANT	\N	PRESENT	0
733181	732893	14073Q	PARTICIPANT	\N	PRESENT	0
733182	732893	19611R	PARTICIPANT	\N	PRESENT	0
733183	732893	19699S	PARTICIPANT	\N	PRESENT	0
733184	732893	16685X	PARTICIPANT	\N	PRESENT	0
733185	732893	14219Q	PARTICIPANT	\N	PRESENT	0
733186	732893	11085T	PARTICIPANT	\N	PRESENT	0
733187	732893	19369B	PARTICIPANT	\N	PRESENT	0
733188	732893	19745F	PARTICIPANT	\N	PRESENT	0
733189	732893	19713W	PARTICIPANT	\N	PRESENT	0
733190	732893	14275Y	PARTICIPANT	\N	PRESENT	0
733191	732893	01025N	PARTICIPANT	\N	PRESENT	0
733192	732893	19057M	PARTICIPANT	\N	PRESENT	0
733193	732893	20112S	PARTICIPANT	\N	PRESENT	0
733194	732893	19782L	PARTICIPANT	\N	PRESENT	0
733195	732893	14026U	PARTICIPANT	\N	PRESENT	0
733196	732893	14229S	PARTICIPANT	\N	PRESENT	0
733206	732893	19693L	PARTICIPANT	\N	PRESENT	0
733198	732893	20180F	PARTICIPANT	\N	PRESENT	0
733199	732893	19581D	PARTICIPANT	\N	PRESENT	0
733200	732893	20914V	PARTICIPANT	\N	PRESENT	0
733201	732893	17637T	PARTICIPANT	\N	PRESENT	0
733202	732893	14281W	PARTICIPANT	\N	PRESENT	0
733203	732893	05008E	PARTICIPANT	\N	PRESENT	0
733204	732893	01060R	PARTICIPANT	\N	PRESENT	0
733205	732893	19643A	PARTICIPANT	\N	PRESENT	0
733207	732893	14205J	PARTICIPANT	\N	PRESENT	0
733208	732893	19441R	PARTICIPANT	\N	PRESENT	0
733209	732893	20052X	PARTICIPANT	\N	PRESENT	0
733210	732893	14111D	PARTICIPANT	\N	PRESENT	0
733211	732893	01024M	PARTICIPANT	\N	PRESENT	0
733212	732893	11056N	PARTICIPANT	\N	PRESENT	0
733213	732893	04085P	PARTICIPANT	\N	PRESENT	0
733214	732893	17023S	PARTICIPANT	\N	PRESENT	0
733215	732893	11053K	PARTICIPANT	\N	PRESENT	0
733216	732893	14249W	PARTICIPANT	\N	PRESENT	0
733217	732893	04042C	PARTICIPANT	\N	PRESENT	0
733218	732893	20022R	PARTICIPANT	\N	PRESENT	0
733219	732893	20058E	PARTICIPANT	\N	PRESENT	0
733220	732893	14031R	PARTICIPANT	\N	PRESENT	0
733221	732893	19447X	PARTICIPANT	\N	PRESENT	0
733222	732893	19573D	PARTICIPANT	\N	PRESENT	0
733223	732893	20024T	PARTICIPANT	\N	PRESENT	0
733224	732893	11101A	PARTICIPANT	\N	PRESENT	0
733225	732893	19735D	PARTICIPANT	\N	PRESENT	0
733226	732893	04071H	PARTICIPANT	\N	PRESENT	0
733227	732893	20172F	PARTICIPANT	\N	PRESENT	0
733228	732893	20096L	PARTICIPANT	\N	PRESENT	0
733229	732893	14169X	PARTICIPANT	\N	PRESENT	0
733230	732893	20104S	PARTICIPANT	\N	PRESENT	0
733231	732893	19741B	PARTICIPANT	\N	PRESENT	0
733232	732893	19647E	PARTICIPANT	\N	PRESENT	0
733233	732893	11065P	PARTICIPANT	\N	PRESENT	0
733234	732893	19711U	PARTICIPANT	\N	PRESENT	0
733239	732893	14151M	PARTICIPANT	\N	PRESENT	0
733236	732893	14089Y	PARTICIPANT	\N	PRESENT	0
733237	732893	14071N	PARTICIPANT	\N	PRESENT	0
733238	732893	19762G	PARTICIPANT	\N	PRESENT	0
733240	732893	19701S	PARTICIPANT	\N	PRESENT	0
733241	732893	11048N	PARTICIPANT	\N	PRESENT	0
733242	732893	14257W	PARTICIPANT	\N	PRESENT	0
733243	732893	19669L	PARTICIPANT	\N	PRESENT	0
733244	732893	01028R	PARTICIPANT	\N	PRESENT	0
733245	732893	19651A	PARTICIPANT	\N	PRESENT	0
733246	732893	14069U	PARTICIPANT	\N	PRESENT	0
733247	732893	14179A	PARTICIPANT	\N	PRESENT	0
733248	732893	11026G	PARTICIPANT	\N	PRESENT	0
733249	732893	14053L	PARTICIPANT	\N	PRESENT	0
733250	730865	19699S	PARTICIPANT	\N	PRESENT	0
733251	730865	19533U	PARTICIPANT	\N	PRESENT	0
733252	730865	04033B	PARTICIPANT	\N	PRESENT	0
733253	730865	14229S	PARTICIPANT	\N	PRESENT	0
733254	730865	19573D	PARTICIPANT	\N	PRESENT	0
733255	730865	20112S	PARTICIPANT	\N	PRESENT	0
733256	730865	08012N	PARTICIPANT	\N	PRESENT	0
733257	730865	20124W	PARTICIPANT	\N	PRESENT	0
733258	730865	19593H	PARTICIPANT	\N	PRESENT	0
733259	730865	19527W	PARTICIPANT	\N	PRESENT	0
733260	730865	19643A	PARTICIPANT	\N	PRESENT	0
733261	730865	20132W	PARTICIPANT	\N	PRESENT	0
733262	730865	20134Y	PARTICIPANT	\N	PRESENT	0
733263	730865	14073Q	PARTICIPANT	\N	PRESENT	0
733264	730865	19611R	PRESIDENT	0	PRESENT	0
733265	730865	20138D	PARTICIPANT	\N	PRESENT	0
733266	730865	20142Y	PARTICIPANT	\N	PRESENT	0
733268	730865	20048C	PARTICIPANT	\N	PRESENT	0
733270	730865	19693L	PARTICIPANT	\N	PRESENT	0
733272	730865	20152B	PARTICIPANT	\N	PRESENT	0
733273	730865	20052X	PARTICIPANT	\N	PRESENT	0
733275	730865	20172F	PARTICIPANT	\N	PRESENT	0
733276	730865	14030Q	PARTICIPANT	\N	PRESENT	0
711642	711641	04047H	PARTICIPANT	\N	PRESENT	0
711643	711641	14053L	PARTICIPANT	\N	PRESENT	0
716365	716362	20058E	PARTICIPANT	\N	PRESENT	1
716366	716363	14109K	PARTICIPANT	\N	PRESENT	1
716367	716363	20058E	PARTICIPANT	\N	PRESENT	1
720202	720201	20058E	PARTICIPANT	\N	PRESENT	1
720203	720201	14030Q	PARTICIPANT	\N	PRESENT	1
722124	720099	14026U	PARTICIPANT	\N	PRESENT	0
722125	720099	01024M	PARTICIPANT	\N	PRESENT	0
722126	720099	14215L	PARTICIPANT	\N	PRESENT	0
722159	720099	20052X	PARTICIPANT	\N	PRESENT	0
722128	720099	20090E	PARTICIPANT	\N	PRESENT	0
722129	720099	20180F	PARTICIPANT	\N	PRESENT	0
722130	720099	19507S	PARTICIPANT	\N	PRESENT	0
722150	722144	14357A	PARTICIPANT	\N	PRESENT	0
722132	720099	19593H	PARTICIPANT	\N	PRESENT	0
722133	720099	20114U	PARTICIPANT	\N	PRESENT	0
722134	720099	19651A	PARTICIPANT	\N	PRESENT	0
722194	720099	20074E	PARTICIPANT	\N	PRESENT	0
722181	721826	19533U	PARTICIPANT	\N	PRESENT	0
722157	720099	19699S	PARTICIPANT	\N	PRESENT	0
722138	720099	19479G	PARTICIPANT	\N	PRESENT	0
722139	720099	14097Y	PARTICIPANT	\N	PRESENT	0
722166	720099	14042U	PARTICIPANT	\N	PRESENT	0
722167	720099	19611R	PARTICIPANT	\N	PRESENT	0
722142	720099	20066E	PARTICIPANT	\N	PRESENT	0
722143	720099	19713W	PARTICIPANT	\N	PRESENT	0
722155	722144	17229F	PARTICIPANT	\N	PRESENT	0
722168	720099	19527W	PARTICIPANT	\N	PRESENT	0
722148	720099	20142Y	PARTICIPANT	\N	PRESENT	0
722151	722144	11097X	PARTICIPANT	\N	PRESENT	0
722152	722144	11053K	PARTICIPANT	\N	PRESENT	0
722153	722144	19251M	PARTICIPANT	\N	PRESENT	0
722154	720099	19599P	PARTICIPANT	\N	PRESENT	0
722156	720099	20132W	PARTICIPANT	\N	PRESENT	0
722158	720099	14147R	PARTICIPANT	\N	PRESENT	0
722160	720099	14069U	PARTICIPANT	\N	PRESENT	0
722195	720099	20172F	PARTICIPANT	\N	PRESENT	0
722162	720099	20024T	PARTICIPANT	\N	PRESENT	0
722163	720099	11033F	PARTICIPANT	\N	PRESENT	0
722164	720099	14033T	PARTICIPANT	\N	PRESENT	0
722165	722144	20102Q	PARTICIPANT	\N	PRESENT	0
722169	720099	19798U	PARTICIPANT	\N	PRESENT	0
722170	722144	20092G	PARTICIPANT	\N	PRESENT	0
722171	720099	20048C	PARTICIPANT	\N	PRESENT	0
722172	722144	19575F	PARTICIPANT	\N	PRESENT	0
722173	720099	14030Q	PARTICIPANT	\N	PRESENT	0
722180	720099	04057K	PARTICIPANT	\N	PRESENT	0
722175	720099	20082E	PARTICIPANT	\N	PRESENT	0
722176	720099	19749K	PARTICIPANT	\N	PRESENT	0
722311	720100	14030Q	PARTICIPANT	\N	PRESENT	0
722183	721826	20080C	PARTICIPANT	\N	PRESENT	0
722184	721826	19741B	PARTICIPANT	\N	PRESENT	0
722185	721826	08010L	PARTICIPANT	\N	PRESENT	0
722186	721826	19667J	PARTICIPANT	\N	PRESENT	0
722187	721826	19866P	PARTICIPANT	\N	PRESENT	0
722188	721826	11070L	PARTICIPANT	\N	PRESENT	0
722189	721826	19631V	PARTICIPANT	\N	PRESENT	0
722197	720099	19673G	PARTICIPANT	\N	PRESENT	0
722200	720099	14073Q	PARTICIPANT	\N	PRESENT	0
722209	720099	20022R	PARTICIPANT	\N	PRESENT	0
722210	720099	19747H	PARTICIPANT	\N	PRESENT	0
722211	720099	19703U	PARTICIPANT	\N	PRESENT	0
722213	720099	19637C	PARTICIPANT	\N	PRESENT	0
722214	720099	19543W	PARTICIPANT	\N	PRESENT	0
722215	720099	20144B	PARTICIPANT	\N	PRESENT	0
722223	720099	20042V	PARTICIPANT	\N	PRESENT	0
722227	720099	11012A	PARTICIPANT	\N	PRESENT	0
722228	720099	17965H	PARTICIPANT	\N	PRESENT	0
722230	720099	19715Y	PARTICIPANT	\N	PRESENT	0
722243	720099	14053L	PARTICIPANT	\N	PRESENT	0
722286	720100	20046A	PARTICIPANT	\N	PRESENT	0
722288	720100	20114U	PARTICIPANT	\N	PRESENT	0
722290	720100	14097Y	PARTICIPANT	\N	PRESENT	0
722291	720100	17965H	PARTICIPANT	\N	PRESENT	0
722292	720100	20082E	PARTICIPANT	\N	PRESENT	0
722293	720100	19715Y	PARTICIPANT	\N	PRESENT	0
722294	720100	19599P	PARTICIPANT	\N	PRESENT	0
722295	720100	11012A	PARTICIPANT	\N	PRESENT	0
722296	720100	19749K	PARTICIPANT	\N	PRESENT	0
722297	720100	01024M	PARTICIPANT	\N	PRESENT	0
722298	720100	19543W	PARTICIPANT	\N	PRESENT	0
722299	720100	19703U	PARTICIPANT	\N	PRESENT	0
722300	720100	19747H	PARTICIPANT	\N	PRESENT	0
722301	720100	20022R	PARTICIPANT	\N	PRESENT	0
722302	720100	19798U	PARTICIPANT	\N	PRESENT	0
722303	720100	19651A	PARTICIPANT	\N	PRESENT	0
722304	720100	20098N	PARTICIPANT	\N	PRESENT	0
722305	720100	19693L	PARTICIPANT	\N	PRESENT	0
722306	720100	19673G	PARTICIPANT	\N	PRESENT	0
722307	720100	19719D	PARTICIPANT	\N	PRESENT	0
722308	721826	10015M	PARTICIPANT	\N	PRESENT	0
722309	720100	14133K	PARTICIPANT	\N	PRESENT	0
722310	720100	20266L	PARTICIPANT	\N	PRESENT	0
722312	720100	14001X	PARTICIPANT	\N	PRESENT	0
722313	720100	14053L	PARTICIPANT	\N	PRESENT	0
722314	720100	14259Y	PARTICIPANT	\N	PRESENT	0
722315	720100	14221J	PARTICIPANT	\N	PRESENT	0
722316	720100	14215L	PARTICIPANT	\N	PRESENT	0
722317	720100	19533U	PARTICIPANT	\N	PRESENT	0
722318	720100	10015M	PARTICIPANT	\N	PRESENT	0
722319	720100	20116W	PARTICIPANT	\N	PRESENT	0
722320	720100	14217N	PARTICIPANT	\N	PRESENT	0
722323	720100	14249W	PARTICIPANT	\N	PRESENT	0
722324	722147	20180F	PARTICIPANT	\N	PRESENT	0
722325	722147	20092G	PARTICIPANT	\N	PRESENT	0
722326	722147	14357A	PARTICIPANT	\N	PRESENT	0
722327	722147	11097X	PARTICIPANT	\N	PRESENT	0
722328	722147	11053K	PARTICIPANT	\N	PRESENT	0
722284	720100	14026U	PARTICIPANT	\N	PRESENT	0
722285	720100	20074E	PARTICIPANT	\N	PRESENT	0
722329	722147	19251M	PRESIDENT	0	PRESENT	0
722330	722147	20102Q	PARTICIPANT	\N	PRESENT	0
722331	722147	17229F	PARTICIPANT	\N	PRESENT	0
722339	720100	14231L	PARTICIPANT	\N	PRESENT	0
722340	720100	20980G	PARTICIPANT	\N	PRESENT	0
722341	722147	19713W	PARTICIPANT	\N	PRESENT	0
722342	720100	14147R	PARTICIPANT	\N	PRESENT	0
722343	720100	20124W	PARTICIPANT	\N	PRESENT	0
722344	720100	19741B	PARTICIPANT	\N	PRESENT	0
722345	720100	07029T	PARTICIPANT	\N	PRESENT	0
722346	720100	14042U	PARTICIPANT	\N	PRESENT	0
722347	720100	20100N	PARTICIPANT	\N	PRESENT	0
722348	720100	04047H	PARTICIPANT	\N	PRESENT	0
722349	720100	18193Q	PARTICIPANT	\N	PRESENT	0
722350	720100	20142Y	PARTICIPANT	\N	PRESENT	0
722351	720100	14213J	PARTICIPANT	\N	PRESENT	0
722608	722607	17023S	PARTICIPANT	\N	PRESENT	0
724027	722416	10015M	PARTICIPANT	\N	EXCUSE	0
725980	725555	14038Y	PARTICIPANT	\N	PRESENT	0
725981	725555	14219Q	PRESIDENT	0	PRESENT	0
725982	725555	20102Q	PARTICIPANT	\N	PRESENT	0
725983	725555	20024T	PARTICIPANT	\N	PRESENT	0
725984	725555	17229F	PARTICIPANT	\N	PRESENT	0
725985	725555	20032T	PARTICIPANT	\N	PRESENT	0
725986	725555	17367Q	PARTICIPANT	\N	PRESENT	0
725987	725555	19333N	PARTICIPANT	\N	PRESENT	0
725988	725555	14169X	PARTICIPANT	\N	PRESENT	0
725989	725555	20140W	PARTICIPANT	\N	PRESENT	0
725990	725555	19826F	PARTICIPANT	\N	PRESENT	0
725991	725555	19820Y	PARTICIPANT	\N	PRESENT	0
725992	725555	20076G	PARTICIPANT	\N	PRESENT	0
725993	725555	20020P	PARTICIPANT	\N	PRESENT	0
725994	725555	20046A	PARTICIPANT	\N	PRESENT	0
725995	725555	05012A	PARTICIPANT	\N	PRESENT	0
725996	725869	99004R	PARTICIPANT	\N	PRESENT	0
725997	725555	20038A	PARTICIPANT	\N	PRESENT	0
725998	725555	19637C	PARTICIPANT	\N	PRESENT	0
725999	725555	18083K	PARTICIPANT	\N	PRESENT	0
726000	725555	14237S	PARTICIPANT	\N	PRESENT	0
726001	725555	19503N	PARTICIPANT	\N	PRESENT	0
726002	725555	19745F	PARTICIPANT	\N	PRESENT	0
726003	725555	11065P	PARTICIPANT	\N	PRESENT	0
726013	725869	19681G	PARTICIPANT	\N	PRESENT	0
726014	725869	14237S	PARTICIPANT	\N	PRESENT	0
726015	725869	17229F	PARTICIPANT	\N	PRESENT	0
726016	725869	19745F	PARTICIPANT	\N	PRESENT	0
726017	725869	20144B	PARTICIPANT	\N	PRESENT	0
726019	725869	20076G	PARTICIPANT	\N	PRESENT	0
718850	718849	19637C	PARTICIPANT	\N	PRESENT	0
718851	718849	19826F	PARTICIPANT	\N	PRESENT	0
718852	718849	14219Q	PARTICIPANT	\N	PRESENT	0
718853	718849	19333N	PARTICIPANT	\N	PRESENT	0
718854	718849	19503N	PARTICIPANT	\N	PRESENT	0
718855	718849	19619A	PARTICIPANT	\N	PRESENT	0
718856	718849	20120S	PARTICIPANT	\N	PRESENT	0
718857	718849	14033T	PARTICIPANT	\N	PRESENT	0
718859	718858	19637C	PARTICIPANT	\N	PRESENT	0
718860	718858	19826F	PARTICIPANT	\N	PRESENT	0
718861	718858	14219Q	PARTICIPANT	\N	PRESENT	0
718862	718858	19503N	PARTICIPANT	\N	PRESENT	0
718863	718858	20120S	PARTICIPANT	\N	PRESENT	0
718864	718858	14033T	PARTICIPANT	\N	PRESENT	0
718883	718882	05008E	PARTICIPANT	\N	PRESENT	0
718884	718882	11053K	PARTICIPANT	\N	PRESENT	0
718885	718882	01028R	PARTICIPANT	\N	PRESENT	0
718886	718540	20144B	PARTICIPANT	\N	EXCUSE	0
718887	718540	14193X	PARTICIPANT	\N	EXCUSE	0
719334	717060	20056C	PARTICIPANT	\N	PRESENT	0
723066	723065	19569H	PARTICIPANT	\N	PRESENT	1
723067	723065	18193Q	PARTICIPANT	\N	PRESENT	0
726786	725633	19745F	PRESIDENT	0	PRESENT	0
726787	725633	20076G	PARTICIPANT	\N	PRESENT	0
726789	725633	20104S	PARTICIPANT	\N	PRESENT	0
726790	725633	20046A	PARTICIPANT	\N	PRESENT	0
726791	725633	20914V	PARTICIPANT	\N	PRESENT	0
726792	725633	20070A	PARTICIPANT	\N	PRESENT	0
726793	725633	20118Y	PARTICIPANT	\N	PRESENT	0
726794	725633	20094J	PARTICIPANT	\N	PRESENT	0
726795	725633	20128B	PARTICIPANT	\N	PRESENT	0
726796	725633	14237S	PARTICIPANT	\N	PRESENT	0
726797	725633	19768N	PARTICIPANT	\N	PRESENT	0
726824	725633	19820Y	PARTICIPANT	\N	PRESENT	0
737999	733710	14059S	PRESIDENT	0	PRESENT	0
736330	735374	19735D	PRESIDENT	0	PRESENT	0
736331	735374	11031D	PARTICIPANT	\N	PRESENT	0
738000	733710	19659J	PARTICIPANT	\N	PRESENT	0
738001	733710	11072N	PARTICIPANT	\N	PRESENT	1
736685	728009	20074E	PARTICIPANT	\N	PRESENT	0
738002	733710	19657G	PARTICIPANT	\N	PRESENT	1
738261	735596	07033P	PARTICIPANT	\N	PRESENT	0
738327	735639	19399H	PARTICIPANT	\N	PRESENT	0
738328	735639	19643A	PARTICIPANT	\N	PRESENT	0
738329	735639	04059M	PARTICIPANT	\N	PRESENT	0
738330	735639	20142Y	PARTICIPANT	\N	PRESENT	0
738331	735641	19643A	PARTICIPANT	\N	PRESENT	0
738332	735641	19399H	PARTICIPANT	\N	PRESENT	0
738336	738335	04047H	PARTICIPANT	\N	PRESENT	0
738338	738337	04047H	PARTICIPANT	\N	PRESENT	0
738615	738004	19683J	PARTICIPANT	\N	PRESENT	0
738616	738004	20046A	PARTICIPANT	\N	PRESENT	0
738620	738004	01058X	PARTICIPANT	\N	PRESENT	0
738618	738004	20076G	PARTICIPANT	\N	PRESENT	0
738619	738004	20062A	PARTICIPANT	\N	PRESENT	0
738621	738004	04085P	PARTICIPANT	\N	PRESENT	0
738622	738004	01057W	PARTICIPANT	\N	PRESENT	0
738623	738004	20040T	PARTICIPANT	\N	PRESENT	0
738624	738004	14111D	PARTICIPANT	\N	PRESENT	0
738625	738004	14259Y	PARTICIPANT	\N	PRESENT	0
738626	738004	19565D	PARTICIPANT	\N	PRESENT	0
738627	738004	14195A	PARTICIPANT	\N	PRESENT	0
738628	738004	19629C	PARTICIPANT	\N	PRESENT	0
738629	738004	08028W	PARTICIPANT	\N	PRESENT	0
738630	738004	20044X	PARTICIPANT	\N	PRESENT	0
738631	738004	14223L	PARTICIPANT	\N	PRESENT	0
738632	738004	19525U	PARTICIPANT	\N	PRESENT	0
738633	738565	14030Q	PARTICIPANT	\N	PRESENT	0
738634	738565	20066E	PARTICIPANT	\N	PRESENT	0
738635	738565	11031D	PARTICIPANT	\N	PRESENT	0
738636	738004	08061X	PARTICIPANT	\N	PRESENT	0
738637	738004	20136B	PARTICIPANT	\N	PRESENT	0
738638	738004	19467C	PARTICIPANT	\N	PRESENT	0
738639	738004	20016T	PARTICIPANT	\N	PRESENT	0
738640	738004	14179A	PARTICIPANT	\N	PRESENT	0
738641	738004	19703U	PARTICIPANT	\N	PRESENT	0
738642	738004	19637C	PARTICIPANT	\N	PRESENT	0
738643	738004	11067R	PARTICIPANT	\N	PRESENT	0
738644	738004	19569H	PARTICIPANT	\N	PRESENT	0
738645	738004	14038Y	PARTICIPANT	\N	PRESENT	0
738646	738004	14033T	PARTICIPANT	\N	PRESENT	0
738647	738004	97011G	PARTICIPANT	\N	PRESENT	0
738648	738004	20144B	PARTICIPANT	\N	PRESENT	0
738649	738004	20128B	PARTICIPANT	\N	PRESENT	0
738650	738004	19747H	PARTICIPANT	\N	PRESENT	0
738651	738004	19367Y	PARTICIPANT	\N	PRESENT	0
738652	738004	20152B	PARTICIPANT	\N	PRESENT	0
738653	738004	19507S	PARTICIPANT	\N	PRESENT	0
738654	738004	20082E	PARTICIPANT	\N	PRESENT	0
738655	738004	11043H	PARTICIPANT	\N	PRESENT	0
738656	738004	19581D	PARTICIPANT	\N	PRESENT	0
738657	738004	14042U	PARTICIPANT	\N	PRESENT	0
738658	738004	20020P	PARTICIPANT	\N	PRESENT	0
738659	738004	14217N	PARTICIPANT	\N	PRESENT	0
738660	738004	14133K	PARTICIPANT	\N	PRESENT	0
738661	738004	20056C	PARTICIPANT	\N	PRESENT	0
738662	738004	14189C	PARTICIPANT	\N	PRESENT	0
738663	738004	20042V	PARTICIPANT	\N	PRESENT	0
738664	738004	14267Y	PARTICIPANT	\N	PRESENT	0
738665	738004	11085T	PARTICIPANT	\N	PRESENT	0
738666	738004	11026G	PARTICIPANT	\N	PRESENT	0
738667	738004	19723Y	PARTICIPANT	\N	PRESENT	0
738668	738004	19679N	PARTICIPANT	\N	PRESENT	0
738669	738004	08015R	PARTICIPANT	\N	PRESENT	0
738670	738004	19563B	PARTICIPANT	\N	PRESENT	0
738677	738004	14237S	PARTICIPANT	\N	PRESENT	0
738678	738004	20058E	PARTICIPANT	\N	PRESENT	0
738679	738004	20098N	PARTICIPANT	\N	PRESENT	0
738680	738004	20024T	PARTICIPANT	\N	PRESENT	0
738681	738004	14071N	PARTICIPANT	\N	PRESENT	0
738682	738004	20086J	PARTICIPANT	\N	PRESENT	0
738683	738004	20078J	PARTICIPANT	\N	PRESENT	0
738684	738004	20130U	PARTICIPANT	\N	PRESENT	0
738685	738004	14021P	PARTICIPANT	\N	PRESENT	0
738686	738360	14097Y	PARTICIPANT	\N	PRESENT	0
738687	738360	20090E	PARTICIPANT	\N	PRESENT	0
738688	738360	20072C	PARTICIPANT	\N	PRESENT	0
738689	738360	20140W	PARTICIPANT	\N	PRESENT	0
738690	738360	20076G	PRESIDENT	0	PRESENT	0
738691	738360	16685X	PARTICIPANT	\N	PRESENT	0
738692	738360	20046A	PARTICIPANT	\N	PRESENT	0
738693	738360	19826F	PARTICIPANT	\N	PRESENT	0
738694	738360	20094J	PARTICIPANT	\N	PRESENT	0
738695	738360	20096L	PARTICIPANT	\N	PRESENT	0
738696	738360	19723Y	PARTICIPANT	\N	PRESENT	0
738697	738360	14205J	PARTICIPANT	\N	PRESENT	0
738698	738360	19725B	PARTICIPANT	\N	PRESENT	0
738699	738360	20056C	PARTICIPANT	\N	PRESENT	0
738700	738360	20118Y	PARTICIPANT	\N	PRESENT	0
738701	738360	19503N	PARTICIPANT	\N	PRESENT	0
738702	738360	20114U	PARTICIPANT	\N	PRESENT	0
738703	738360	20026V	PARTICIPANT	\N	PRESENT	0
738704	738360	19798U	PARTICIPANT	\N	EXCUSE	0
738705	738360	20074E	PARTICIPANT	\N	EXCUSE	0
738706	738360	20050V	PARTICIPANT	\N	EXCUSE	0
738707	738360	19719D	PARTICIPANT	\N	EXCUSE	0
738708	738360	20024T	PARTICIPANT	\N	EXCUSE	0
738709	738360	19721W	PARTICIPANT	\N	EXCUSE	0
738710	738004	20028X	PARTICIPANT	\N	PRESENT	0
738711	738004	19782L	PARTICIPANT	\N	PRESENT	0
738712	738004	20248J	PARTICIPANT	\N	PRESENT	0
738723	738004	19745F	PARTICIPANT	\N	PRESENT	0
738724	738004	19479G	PARTICIPANT	\N	PRESENT	0
738725	738004	14205J	PARTICIPANT	\N	PRESENT	0
738727	738004	19611R	PARTICIPANT	\N	PRESENT	0
738730	738004	19575F	PARTICIPANT	\N	PRESENT	0
738731	738004	19251M	PARTICIPANT	\N	PRESENT	0
738732	738004	11101A	PARTICIPANT	\N	PRESENT	0
738733	738004	08045X	PARTICIPANT	\N	PRESENT	0
738734	738004	20266L	PARTICIPANT	\N	PRESENT	0
738735	738004	19415P	PARTICIPANT	\N	PRESENT	0
738736	738004	20060X	PARTICIPANT	\N	PRESENT	0
738737	738004	19549D	PARTICIPANT	\N	PRESENT	0
738739	738004	19741B	PARTICIPANT	\N	PRESENT	0
738740	738004	20140W	PARTICIPANT	\N	PRESENT	0
738741	738004	20114U	PARTICIPANT	\N	PRESENT	0
738742	738004	20026V	PARTICIPANT	\N	PRESENT	0
738748	737724	19415P	PARTICIPANT	\N	PRESENT	0
738749	737724	14223L	PARTICIPANT	\N	PRESENT	0
738750	738571	14257W	PARTICIPANT	\N	PRESENT	0
738751	738004	19413M	PARTICIPANT	\N	PRESENT	0
711834	711833	19647E	PARTICIPANT	\N	PRESENT	0
717949	716502	20114U	PARTICIPANT	\N	PRESENT	0
717950	716502	14151M	PARTICIPANT	\N	PRESENT	0
717951	716502	18193Q	PARTICIPANT	\N	PRESENT	0
717952	716502	11027H	PARTICIPANT	\N	PRESENT	0
717953	716502	11026G	PARTICIPANT	\N	PRESENT	0
717954	716502	01062T	PARTICIPANT	\N	PRESENT	0
717955	716502	20048C	PARTICIPANT	\N	PRESENT	0
717956	716502	19713W	PARTICIPANT	\N	PRESENT	0
717957	716502	19319Q	PARTICIPANT	\N	PRESENT	0
717958	716502	01043Q	PARTICIPANT	\N	PRESENT	0
717959	716502	20052X	PARTICIPANT	\N	PRESENT	0
717960	716502	19735D	PARTICIPANT	\N	PRESENT	0
717961	716502	07004J	PARTICIPANT	\N	PRESENT	0
717962	716502	14219Q	PARTICIPANT	\N	PRESENT	0
717980	716502	20040T	PARTICIPANT	\N	PRESENT	0
717964	716502	14205J	PARTICIPANT	\N	PRESENT	0
717965	716502	20286Q	PARTICIPANT	\N	PRESENT	0
717966	716502	19335Q	PARTICIPANT	\N	PRESENT	0
717967	716502	19369B	PARTICIPANT	\N	PRESENT	0
717968	716502	19721W	PARTICIPANT	\N	PRESENT	0
717969	716502	14030Q	PARTICIPANT	\N	PRESENT	0
717970	716502	08009T	PARTICIPANT	\N	PRESENT	0
717971	716502	19691J	PARTICIPANT	\N	PRESENT	0
717972	716502	04070G	PARTICIPANT	\N	PRESENT	0
717973	716502	14179A	PARTICIPANT	\N	PRESENT	0
717974	716502	20248J	PARTICIPANT	\N	PRESENT	0
717975	716502	01034P	PARTICIPANT	\N	PRESENT	0
717976	716502	01025N	PARTICIPANT	\N	PRESENT	0
717977	716502	14231L	PARTICIPANT	\N	PRESENT	0
717978	716502	14083S	PARTICIPANT	\N	PRESENT	0
717979	716502	14042U	PARTICIPANT	\N	PRESENT	0
717981	716502	11053K	PARTICIPANT	\N	PRESENT	0
717982	716502	11085T	PARTICIPANT	\N	PRESENT	0
717983	716502	19611R	PARTICIPANT	\N	PRESENT	0
717984	716502	14327T	PARTICIPANT	\N	PRESENT	0
717985	716502	19479G	PARTICIPANT	\N	PRESENT	0
717986	716502	14109K	PARTICIPANT	\N	PRESENT	0
717987	716502	20084G	PARTICIPANT	\N	PRESENT	0
717988	716502	19647E	PARTICIPANT	\N	PRESENT	0
717989	716502	19631V	PARTICIPANT	\N	PRESENT	0
717990	716502	20080C	PARTICIPANT	\N	PRESENT	0
717991	716502	20060X	PARTICIPANT	\N	PRESENT	0
717992	716502	19820Y	PARTICIPANT	\N	PRESENT	0
717993	716502	11074Q	PARTICIPANT	\N	PRESENT	0
717994	716502	19599P	PARTICIPANT	\N	PRESENT	0
717995	716502	11110B	PARTICIPANT	\N	PRESENT	0
717996	716502	14021P	PARTICIPANT	\N	PRESENT	0
717997	716502	11065P	PARTICIPANT	\N	PRESENT	0
717998	716502	20128B	PARTICIPANT	\N	PRESENT	0
717999	716502	19569H	PARTICIPANT	\N	PRESENT	0
718000	716502	14257W	PARTICIPANT	\N	PRESENT	0
718001	716502	04071H	PARTICIPANT	\N	PRESENT	0
718002	716502	20134Y	PARTICIPANT	\N	PRESENT	0
718003	716502	19251M	PARTICIPANT	\N	PRESENT	0
718004	716502	14097Y	PARTICIPANT	\N	PRESENT	0
718005	716502	19669L	PARTICIPANT	\N	PRESENT	0
718006	716502	20070A	PARTICIPANT	\N	PRESENT	0
718268	716503	86034E	PARTICIPANT	\N	PRESENT	0
718279	716503	14225N	PARTICIPANT	\N	PRESENT	0
718280	716503	10006L	PARTICIPANT	\N	PRESENT	0
718281	716503	20044X	PARTICIPANT	\N	PRESENT	0
718282	716503	19583F	PARTICIPANT	\N	PRESENT	0
718283	716503	20914V	PARTICIPANT	\N	PRESENT	0
718284	716503	08073C	PARTICIPANT	\N	PRESENT	0
718285	716503	20070A	PARTICIPANT	\N	PRESENT	0
718286	716503	19687N	PARTICIPANT	\N	PRESENT	0
718287	716503	14083S	PARTICIPANT	\N	PRESENT	0
718288	716503	20116W	PARTICIPANT	\N	PRESENT	0
718312	716503	19798U	PARTICIPANT	\N	PRESENT	0
718290	716503	20080C	PARTICIPANT	\N	PRESENT	0
718291	716503	19335Q	PARTICIPANT	\N	PRESENT	0
718292	716503	19421M	PARTICIPANT	\N	PRESENT	0
718293	716503	14237S	PARTICIPANT	\N	PRESENT	0
718294	716503	19671E	PARTICIPANT	\N	PRESENT	0
718295	716503	19479G	PARTICIPANT	\N	PRESENT	0
718296	716503	18193Q	PARTICIPANT	\N	PRESENT	0
718297	716503	14121F	PARTICIPANT	\N	PRESENT	0
718298	716503	20030R	PARTICIPANT	\N	PRESENT	0
718299	716503	20048C	PARTICIPANT	\N	PRESENT	0
718300	716503	20042V	PARTICIPANT	\N	PRESENT	0
718301	716503	20132W	PARTICIPANT	\N	PRESENT	0
718302	716503	11040E	PARTICIPANT	\N	PRESENT	0
718303	716503	11053K	PARTICIPANT	\N	PRESENT	0
718304	716503	20074E	PARTICIPANT	\N	PRESENT	0
718305	716503	20018V	PARTICIPANT	\N	PRESENT	0
718306	716503	20126Y	PARTICIPANT	\N	PRESENT	0
718307	716503	14059S	PARTICIPANT	\N	PRESENT	0
718308	716503	19333N	PARTICIPANT	\N	PRESENT	0
718309	716503	04042C	PARTICIPANT	\N	PRESENT	0
718310	716503	05012A	PARTICIPANT	\N	PRESENT	0
718311	716503	20062A	PARTICIPANT	\N	PRESENT	0
718313	716503	14217N	PARTICIPANT	\N	PRESENT	0
718314	716503	97011G	PARTICIPANT	\N	PRESENT	0
718315	716503	11097X	PARTICIPANT	\N	PRESENT	0
718316	716503	19399H	PARTICIPANT	\N	PRESENT	0
718317	716503	19667J	PARTICIPANT	\N	PRESENT	0
718318	716503	14031R	PARTICIPANT	\N	PRESENT	0
718319	716503	20180F	PARTICIPANT	\N	PRESENT	0
718320	716503	04047H	PARTICIPANT	\N	PRESENT	0
718321	716503	20086J	PARTICIPANT	\N	PRESENT	0
718322	716503	14147R	PARTICIPANT	\N	PRESENT	0
718323	716503	14193X	PARTICIPANT	\N	PRESENT	0
718324	716503	19507S	PARTICIPANT	\N	PRESENT	0
718326	716503	14259Y	PARTICIPANT	\N	PRESENT	0
718327	716503	14191V	PARTICIPANT	\N	PRESENT	0
718328	716503	14169X	PARTICIPANT	\N	PRESENT	0
718329	716503	08011M	PARTICIPANT	\N	PRESENT	0
718330	716503	19693L	PARTICIPANT	\N	PRESENT	0
718331	716503	18083K	PARTICIPANT	\N	PRESENT	0
718332	716503	14133K	PARTICIPANT	\N	PRESENT	0
718333	716503	14069U	PARTICIPANT	\N	PRESENT	0
718334	716503	08034U	PARTICIPANT	\N	PRESENT	0
718335	716503	11048N	PARTICIPANT	\N	PRESENT	0
718336	716503	14253S	PARTICIPANT	\N	PRESENT	0
718337	716503	20252E	PARTICIPANT	\N	PRESENT	0
718338	716503	19762G	PARTICIPANT	\N	PRESENT	0
718339	716503	14042U	PARTICIPANT	\N	PRESENT	0
718341	716503	01034P	PARTICIPANT	\N	PRESENT	0
718342	716503	19629C	PARTICIPANT	\N	PRESENT	0
718343	716503	14021P	PARTICIPANT	\N	PRESENT	0
718344	716503	19782L	PARTICIPANT	\N	PRESENT	0
718345	716503	20032T	PARTICIPANT	\N	PRESENT	0
718346	716503	07029T	PARTICIPANT	\N	PRESENT	0
718347	716503	17023S	PARTICIPANT	\N	PRESENT	0
718348	716503	08010L	PARTICIPANT	\N	PRESENT	0
718349	716503	95063L	PARTICIPANT	\N	PRESENT	0
718350	716503	05008E	PARTICIPANT	\N	PRESENT	0
718351	716503	14037X	PARTICIPANT	\N	PRESENT	0
718356	716503	01057W	PARTICIPANT	\N	PRESENT	0
718360	716503	14231L	PARTICIPANT	\N	PRESENT	0
718362	718340	14357A	PRESIDENT	0	PRESENT	0
718363	718340	20102Q	PARTICIPANT	\N	PRESENT	0
718364	716503	20098N	PARTICIPANT	\N	PRESENT	0
718365	716503	19713W	PARTICIPANT	\N	PRESENT	0
718366	718340	11097X	PARTICIPANT	\N	PRESENT	0
718367	718340	14237S	PARTICIPANT	\N	PRESENT	0
718592	718587	14123H	PARTICIPANT	\N	PRESENT	1
718593	718587	14109K	PARTICIPANT	\N	PRESENT	1
718595	718587	14229S	PARTICIPANT	\N	PRESENT	1
718596	718587	20152B	PARTICIPANT	\N	PRESENT	1
718597	718587	20980G	PARTICIPANT	\N	PRESENT	1
718598	718587	19643A	PARTICIPANT	\N	PRESENT	1
718938	718881	19820Y	PARTICIPANT	\N	PRESENT	0
718939	718881	05012A	PRESIDENT	0	PRESENT	0
718945	718942	17023S	PARTICIPANT	\N	PRESENT	0
718943	718942	07033P	PARTICIPANT	\N	PRESENT	0
718944	718942	14249W	PARTICIPANT	\N	PRESENT	0
718946	718942	04035D	PARTICIPANT	\N	PRESENT	0
718947	718942	11041F	PARTICIPANT	\N	PRESENT	0
718992	718990	14123H	PARTICIPANT	\N	PRESENT	0
718993	718991	14123H	PARTICIPANT	\N	PRESENT	1
719182	718668	01062T	PARTICIPANT	\N	PRESENT	0
719183	718668	11041F	PARTICIPANT	\N	PRESENT	0
719184	718668	01058X	PARTICIPANT	\N	PRESENT	0
719185	718668	16685X	PARTICIPANT	\N	PRESENT	0
719186	718668	04042C	PRESIDENT	0	PRESENT	0
719187	718668	11054L	PARTICIPANT	\N	PRESENT	0
719188	718668	11066Q	PARTICIPANT	\N	PRESENT	0
719189	718668	08056B	PARTICIPANT	\N	PRESENT	0
719190	718668	20064C	PARTICIPANT	\N	PRESENT	0
721802	721801	19695N	PARTICIPANT	\N	PRESENT	0
721803	721801	14187A	PARTICIPANT	\N	PRESENT	0
721804	721801	14257W	PARTICIPANT	\N	PRESENT	0
721805	721801	14033T	PARTICIPANT	\N	PRESENT	0
723201	722605	19820Y	PARTICIPANT	\N	PRESENT	0
723202	722605	05012A	PARTICIPANT	\N	PRESENT	0
723243	723239	11083R	PARTICIPANT	\N	PRESENT	0
723241	723239	14255U	PARTICIPANT	\N	PRESENT	0
723242	723239	20248J	PARTICIPANT	\N	PRESENT	0
723244	723239	98022P	PARTICIPANT	\N	PRESENT	0
723245	723239	11026G	PARTICIPANT	\N	PRESENT	0
723248	722836	14038Y	PARTICIPANT	\N	PRESENT	0
723249	722836	20056C	PARTICIPANT	\N	PRESENT	0
723250	722836	14189C	PARTICIPANT	\N	PRESENT	0
723251	722836	20042V	PARTICIPANT	\N	PRESENT	0
723252	722836	19798U	PARTICIPANT	\N	PRESENT	1
723253	722836	19723Y	PARTICIPANT	\N	PRESENT	1
733281	730865	20058E	PARTICIPANT	\N	PRESENT	0
733283	730865	20056C	PARTICIPANT	\N	PRESENT	0
733286	730865	20180F	PARTICIPANT	\N	PRESENT	0
733288	730865	20264J	PARTICIPANT	\N	PRESENT	0
733290	730865	14109K	PARTICIPANT	\N	PRESENT	0
733293	730865	14123H	PARTICIPANT	\N	PRESENT	0
733297	730865	11104D	PARTICIPANT	\N	PRESENT	0
733301	730865	20084G	PARTICIPANT	\N	PRESENT	0
733303	730865	19621T	PARTICIPANT	\N	PRESENT	0
733623	730865	11109J	PARTICIPANT	\N	EXCUSE	0
733624	730865	19735D	PARTICIPANT	\N	EXCUSE	0
733625	730865	20026V	PARTICIPANT	\N	EXCUSE	0
733641	733637	20090E	PARTICIPANT	\N	PRESENT	0
733642	733637	14187A	PRESIDENT	0	PRESENT	0
733643	733637	19347U	PARTICIPANT	\N	PRESENT	0
733645	733637	20286Q	PARTICIPANT	\N	EXCUSE	0
733925	732649	10006L	PRESIDENT	0	PRESENT	0
733926	732649	14213J	PARTICIPANT	\N	PRESENT	0
733685	733637	18083K	PARTICIPANT	\N	PRESENT	0
733691	733637	17023S	PARTICIPANT	\N	PRESENT	0
733927	732649	20090E	PARTICIPANT	\N	PRESENT	0
733713	733694	19782L	PARTICIPANT	\N	PRESENT	0
733714	733694	11053K	PARTICIPANT	\N	PRESENT	0
733715	733694	19251M	PRESIDENT	0	PRESENT	0
733716	733694	20102Q	PARTICIPANT	\N	PRESENT	0
733717	733694	19762G	PARTICIPANT	\N	PRESENT	0
733718	732776	14111D	PARTICIPANT	\N	PRESENT	0
733721	732776	20022R	PARTICIPANT	\N	PRESENT	0
733722	732776	05008E	PARTICIPANT	\N	PRESENT	0
733725	732776	14151M	PARTICIPANT	\N	PRESENT	0
733726	732776	20108W	PARTICIPANT	\N	PRESENT	0
733928	732649	19715Y	PARTICIPANT	\N	PRESENT	0
733729	732776	04047H	PRESIDENT	0	PRESENT	0
733736	732776	19954N	PARTICIPANT	\N	PRESENT	0
733740	732776	01028R	PARTICIPANT	\N	PRESENT	0
733741	732776	14215L	PARTICIPANT	\N	PRESENT	0
733742	732776	14259Y	PARTICIPANT	\N	PRESENT	0
733743	732776	14231L	PARTICIPANT	\N	PRESENT	0
733746	732776	14147R	PARTICIPANT	\N	PRESENT	0
733929	732649	14223L	PARTICIPANT	\N	PRESENT	0
733930	732649	20148F	PARTICIPANT	\N	PRESENT	0
733931	732649	19713W	PARTICIPANT	\N	PRESENT	0
733932	732649	19798U	PARTICIPANT	\N	PRESENT	0
733933	732649	19683J	PARTICIPANT	\N	PRESENT	0
733934	732649	11097X	PARTICIPANT	\N	PRESENT	0
733935	732649	11067R	PARTICIPANT	\N	PRESENT	0
733936	732649	20130U	PARTICIPANT	\N	PRESENT	0
733937	732649	19760E	PARTICIPANT	\N	PRESENT	0
733938	732649	14217N	PARTICIPANT	\N	PRESENT	0
733939	732649	19679N	PARTICIPANT	\N	PRESENT	0
733940	732649	14042U	PARTICIPANT	\N	PRESENT	0
733941	732649	20066E	PARTICIPANT	\N	PRESENT	0
733942	732649	20040T	PARTICIPANT	\N	PRESENT	0
733943	732649	19703U	PARTICIPANT	\N	PRESENT	0
733944	732649	19367Y	PARTICIPANT	\N	PRESENT	0
733945	732649	19415P	PARTICIPANT	\N	PRESENT	0
733946	732649	04092N	PARTICIPANT	\N	PRESENT	0
733947	732649	14071N	PARTICIPANT	\N	PRESENT	0
733948	732649	19511N	PARTICIPANT	\N	PRESENT	0
733949	732649	14195A	PARTICIPANT	\N	PRESENT	0
733950	732915	14331P	PARTICIPANT	\N	PRESENT	0
733951	732915	11048N	PARTICIPANT	\N	PRESENT	0
733952	732915	11012A	PARTICIPANT	\N	PRESENT	0
733953	732915	08073C	PARTICIPANT	\N	PRESENT	0
733954	732915	20252E	PARTICIPANT	\N	PRESENT	0
733955	732915	12016W	PARTICIPANT	\N	PRESENT	0
733956	732915	11074Q	PRESIDENT	0	PRESENT	0
733957	732915	14253S	PARTICIPANT	\N	PRESENT	0
733958	732915	20116W	PARTICIPANT	\N	PRESENT	0
733959	732915	20150Y	PARTICIPANT	\N	PRESENT	0
733960	732915	01057W	PARTICIPANT	\N	PRESENT	0
733961	732915	19667J	PARTICIPANT	\N	PRESENT	0
734045	732628	19673G	PARTICIPANT	\N	EXCUSE	0
734046	728445	19673G	PARTICIPANT	\N	EXCUSE	0
734047	732916	14331P	PARTICIPANT	\N	PRESENT	0
734048	732916	04071H	PARTICIPANT	\N	PRESENT	0
734049	732916	01048V	PARTICIPANT	\N	PRESENT	0
734050	732916	19545Y	PARTICIPANT	\N	PRESENT	0
734051	732916	01057W	PARTICIPANT	\N	PRESENT	0
734052	732916	11053K	PARTICIPANT	\N	PRESENT	0
734053	732916	20080C	PARTICIPANT	\N	PRESENT	0
734054	732916	11074Q	PRESIDENT	0	PRESENT	0
734055	732916	19667J	PARTICIPANT	\N	PRESENT	0
719057	719056	20062A	PARTICIPANT	\N	PRESENT	0
726022	725869	14111D	PARTICIPANT	\N	PRESENT	0
726023	725869	20090E	PARTICIPANT	\N	PRESENT	0
726024	725869	19637C	PARTICIPANT	\N	PRESENT	0
726025	725869	19826F	PARTICIPANT	\N	PRESENT	0
726026	725869	19575F	PARTICIPANT	\N	PRESENT	0
726027	725869	19533U	PARTICIPANT	\N	PRESENT	0
726028	725869	14257W	PARTICIPANT	\N	PRESENT	0
726029	725869	20082E	PARTICIPANT	\N	PRESENT	0
726030	725869	20062A	PARTICIPANT	\N	PRESENT	0
726031	725869	19651A	PARTICIPANT	\N	PRESENT	0
726032	725869	19333N	PARTICIPANT	\N	PRESENT	0
726033	725869	19695N	PARTICIPANT	\N	PRESENT	0
726034	725869	19563B	PARTICIPANT	\N	PRESENT	0
726035	725869	20056C	PARTICIPANT	\N	PRESENT	0
726036	725869	14189C	PARTICIPANT	\N	PRESENT	0
726037	725869	08028W	PARTICIPANT	\N	PRESENT	0
726038	725869	11101A	PARTICIPANT	\N	PRESENT	0
726039	725869	14031R	PARTICIPANT	\N	PRESENT	0
726040	725869	20136B	PARTICIPANT	\N	PRESENT	0
726041	725869	19573D	PARTICIPANT	\N	PRESENT	0
726042	725565	19593H	PARTICIPANT	\N	PRESENT	0
726043	725565	20064C	PRESIDENT	0	PRESENT	0
726044	725565	14251Q	PARTICIPANT	\N	PRESENT	0
726045	725565	14193X	PARTICIPANT	\N	PRESENT	0
726046	725565	11083R	PARTICIPANT	\N	PRESENT	0
726047	725869	20038A	PARTICIPANT	\N	PRESENT	0
726048	725869	20092G	PARTICIPANT	\N	PRESENT	0
726049	725869	20252E	PARTICIPANT	\N	PRESENT	0
726050	725869	20124W	PARTICIPANT	\N	PRESENT	0
726051	725869	20054A	PARTICIPANT	\N	PRESENT	0
726052	725565	14179A	PARTICIPANT	\N	PRESENT	0
726053	725565	14147R	PARTICIPANT	\N	PRESENT	0
726054	725869	19383Y	PARTICIPANT	\N	PRESENT	0
726055	725869	19629C	PARTICIPANT	\N	PRESENT	0
726056	725869	19631V	PARTICIPANT	\N	PRESENT	0
726057	725869	97011G	PARTICIPANT	\N	PRESENT	0
726058	725869	19507S	PARTICIPANT	\N	PRESENT	0
726059	725869	14207L	PARTICIPANT	\N	PRESENT	0
726060	725869	20108W	PARTICIPANT	\N	PRESENT	0
726061	725869	08015R	PARTICIPANT	\N	PRESENT	0
726062	725869	19760E	PARTICIPANT	\N	PRESENT	0
726063	725869	20026V	PARTICIPANT	\N	PRESENT	0
726064	725869	14038Y	PARTICIPANT	\N	PRESENT	0
726065	725869	19413M	PARTICIPANT	\N	PRESENT	0
726069	725869	20140W	PARTICIPANT	\N	PRESENT	0
726070	725869	01058X	PARTICIPANT	\N	PRESENT	0
726071	725869	14193X	PARTICIPANT	\N	PRESENT	0
726072	725869	19729F	PARTICIPANT	\N	PRESENT	0
726075	725869	01062T	PARTICIPANT	\N	PRESENT	0
726076	725869	20098N	PARTICIPANT	\N	PRESENT	0
726077	725869	20180F	PARTICIPANT	\N	PRESENT	0
726078	725869	14169X	PARTICIPANT	\N	PRESENT	0
726079	725869	20040T	PARTICIPANT	\N	PRESENT	0
726080	725869	11070L	PARTICIPANT	\N	PRESENT	0
726081	725869	01024M	PARTICIPANT	\N	PRESENT	0
726082	725869	19741B	PARTICIPANT	\N	PRESENT	0
726083	725869	08060W	PARTICIPANT	\N	PRESENT	0
726084	725869	17737W	PARTICIPANT	\N	PRESENT	0
726085	725869	20104S	PARTICIPANT	\N	PRESENT	0
726086	725869	19782L	PARTICIPANT	\N	PRESENT	0
726087	725869	11104D	PARTICIPANT	\N	PRESENT	0
726088	725869	14219Q	PARTICIPANT	\N	PRESENT	0
726089	725869	20036X	PARTICIPANT	\N	PRESENT	0
726090	725565	20068G	PARTICIPANT	\N	PRESENT	0
726091	725565	04070G	PARTICIPANT	\N	EXCUSE	0
726092	725565	17737W	PARTICIPANT	\N	EXCUSE	0
726093	725565	14030Q	PARTICIPANT	\N	EXCUSE	0
726094	725869	19467C	PARTICIPANT	\N	PRESENT	0
726095	725869	19479G	PARTICIPANT	\N	PRESENT	0
726096	725869	14205J	PARTICIPANT	\N	PRESENT	0
726097	725869	19503N	PARTICIPANT	\N	PRESENT	0
726098	725869	19758L	PARTICIPANT	\N	PRESENT	0
726105	725869	14069U	PARTICIPANT	\N	PRESENT	0
726106	725869	19747H	PARTICIPANT	\N	PRESENT	0
726108	725869	11040E	PARTICIPANT	\N	PRESENT	0
726378	725871	07004J	PARTICIPANT	\N	PRESENT	0
726379	725871	11056N	PARTICIPANT	\N	PRESENT	0
726380	725871	20044X	PARTICIPANT	\N	PRESENT	0
726381	725871	19647E	PARTICIPANT	\N	PRESENT	0
726382	725871	01025N	PARTICIPANT	\N	PRESENT	0
726383	725871	14225N	PARTICIPANT	\N	PRESENT	0
726384	725871	04085P	PARTICIPANT	\N	PRESENT	0
726385	725871	19747H	PARTICIPANT	\N	PRESENT	0
726386	725871	18083K	PARTICIPANT	\N	PRESENT	0
726387	725871	20122U	PARTICIPANT	\N	PRESENT	0
726388	725871	19651A	PARTICIPANT	\N	PRESENT	0
726389	725871	19349W	PARTICIPANT	\N	PRESENT	0
726390	725871	01057W	PARTICIPANT	\N	PRESENT	0
726391	725871	19758L	PARTICIPANT	\N	PRESENT	0
726392	725871	11074Q	PARTICIPANT	\N	PRESENT	0
726393	725871	20080C	PARTICIPANT	\N	PRESENT	0
726394	725871	18193Q	PARTICIPANT	\N	PRESENT	0
726395	725871	20046A	PARTICIPANT	\N	PRESENT	0
726396	725871	19687N	PARTICIPANT	\N	PRESENT	0
726397	725871	14030Q	PARTICIPANT	\N	PRESENT	0
726398	725871	19762G	PARTICIPANT	\N	PRESENT	0
726399	725871	11012A	PARTICIPANT	\N	PRESENT	0
726400	725871	14213J	PARTICIPANT	\N	PRESENT	0
726401	725871	19347U	PARTICIPANT	\N	PRESENT	0
726402	725871	19563B	PARTICIPANT	\N	PRESENT	0
726403	725871	19723Y	PARTICIPANT	\N	PRESENT	0
726404	725871	19782L	PARTICIPANT	\N	PRESENT	0
726405	725871	14033T	PARTICIPANT	\N	PRESENT	0
727811	727806	20180F	PARTICIPANT	\N	PRESENT	1
727812	727806	20084G	PARTICIPANT	\N	PRESENT	1
727821	727813	20252E	PARTICIPANT	\N	PRESENT	0
727822	727813	14225N	PRESIDENT	0	PRESENT	0
727823	727813	08009T	PARTICIPANT	\N	PRESENT	0
727867	727825	20286Q	PARTICIPANT	\N	EXCUSE	0
727826	727813	11048N	PARTICIPANT	\N	PRESENT	0
727827	727813	08010L	PARTICIPANT	\N	PRESENT	0
727828	727813	99004R	PARTICIPANT	\N	PRESENT	0
727829	727813	20914V	PARTICIPANT	\N	PRESENT	0
727830	727813	20126Y	PARTICIPANT	\N	PRESENT	0
727831	727813	20080C	PARTICIPANT	\N	PRESENT	0
727832	727813	19741B	PARTICIPANT	\N	PRESENT	0
727834	727813	19647E	PARTICIPANT	\N	PRESENT	0
727835	727833	14281W	PARTICIPANT	\N	PRESENT	0
727836	727833	19691J	PARTICIPANT	\N	PRESENT	0
727838	727837	19569H	PARTICIPANT	\N	PRESENT	0
727839	727837	18193Q	PARTICIPANT	\N	PRESENT	0
727840	727813	07029T	PARTICIPANT	\N	PRESENT	0
727841	727813	20086J	PARTICIPANT	\N	PRESENT	0
727853	727813	19441R	PARTICIPANT	\N	PRESENT	0
727856	725880	11045K	PARTICIPANT	\N	PRESENT	0
727857	727825	20090E	PARTICIPANT	\N	PRESENT	0
727858	727825	19711U	PARTICIPANT	\N	PRESENT	0
726020	725869	18083K	PARTICIPANT	\N	PRESENT	0
726021	725869	14033T	PARTICIPANT	\N	PRESENT	0
727859	727825	14187A	PARTICIPANT	\N	PRESENT	0
727860	727825	19347U	PARTICIPANT	\N	PRESENT	0
727861	727825	20298U	PARTICIPANT	\N	PRESENT	0
727862	727825	14257W	PARTICIPANT	\N	PRESENT	0
727863	727825	20062A	PARTICIPANT	\N	EXCUSE	0
727864	727825	19701S	PARTICIPANT	\N	EXCUSE	0
727865	727825	17023S	PARTICIPANT	\N	EXCUSE	0
727868	725880	19782L	PARTICIPANT	\N	PRESENT	0
727869	725880	11033F	PARTICIPANT	\N	PRESENT	0
727870	725880	11083R	PARTICIPANT	\N	PRESENT	0
727871	725880	08061X	PARTICIPANT	\N	PRESENT	0
727872	725880	20072C	PARTICIPANT	\N	PRESENT	0
727873	725880	16685X	PARTICIPANT	\N	PRESENT	0
727874	725880	08015R	PARTICIPANT	\N	PRESENT	0
727875	725880	20252E	PARTICIPANT	\N	PRESENT	0
727876	725880	19347U	PARTICIPANT	\N	PRESENT	0
727877	725827	20080C	PARTICIPANT	\N	PRESENT	0
727878	725827	19741B	PRESIDENT	0	PRESENT	0
727879	725827	19866P	PARTICIPANT	\N	PRESENT	0
727880	725827	19619A	PARTICIPANT	\N	PRESENT	0
727881	725827	14231L	PARTICIPANT	\N	PRESENT	0
727882	725827	14053L	PARTICIPANT	\N	EXCUSE	0
727883	725827	20042V	PARTICIPANT	\N	EXCUSE	0
727884	725827	20108W	PARTICIPANT	\N	EXCUSE	0
727885	725827	12016W	PARTICIPANT	\N	EXCUSE	0
727886	725827	14249W	PARTICIPANT	\N	EXCUSE	0
727887	725880	14026U	PARTICIPANT	\N	PRESENT	0
727888	725880	11026G	PARTICIPANT	\N	PRESENT	0
727889	725880	04057K	PARTICIPANT	\N	PRESENT	0
727890	725827	08010L	PARTICIPANT	\N	PRESENT	0
727891	725880	20248J	PARTICIPANT	\N	PRESENT	0
718584	718582	20094J	PARTICIPANT	\N	PRESENT	0
718585	718582	04070G	PARTICIPANT	\N	PRESENT	0
718586	716557	20094J	PARTICIPANT	\N	PRESENT	0
718588	716557	14331P	PRESIDENT	0	PRESENT	0
718589	716557	19593H	PARTICIPANT	\N	PRESENT	0
718590	716557	04070G	PARTICIPANT	\N	PRESENT	0
718599	716557	19611R	PARTICIPANT	\N	PRESENT	0
718594	716557	11083R	PARTICIPANT	\N	PRESENT	0
718600	716557	19699S	PARTICIPANT	\N	PRESENT	0
718601	716557	20132W	PARTICIPANT	\N	PRESENT	0
718602	716557	19399H	PARTICIPANT	\N	PRESENT	0
718603	716557	20016T	PARTICIPANT	\N	PRESENT	0
718665	718543	11043H	PARTICIPANT	\N	EXCUSE	0
718670	718669	14053L	PARTICIPANT	\N	PRESENT	0
718671	718669	20110Q	PARTICIPANT	\N	PRESENT	0
718672	716561	20128B	PARTICIPANT	\N	PRESENT	0
718674	718673	20116W	PARTICIPANT	\N	PRESENT	0
718676	718675	19741B	PARTICIPANT	\N	PRESENT	0
718678	718677	19741B	PARTICIPANT	\N	PRESENT	0
718680	718679	20086J	PARTICIPANT	\N	PRESENT	0
718682	718681	20086J	PARTICIPANT	\N	PRESENT	0
718684	718683	20086J	PARTICIPANT	\N	PRESENT	0
718686	718685	01048V	PARTICIPANT	\N	PRESENT	0
718688	718687	01048V	PARTICIPANT	\N	PRESENT	0
718690	718689	01048V	PARTICIPANT	\N	PRESENT	0
724754	722795	11012A	PARTICIPANT	\N	PRESENT	0
736375	735913	11074Q	PARTICIPANT	\N	PRESENT	0
736376	735913	19349W	PARTICIPANT	\N	PRESENT	0
736377	735536	11045K	PARTICIPANT	\N	PRESENT	0
736378	735536	19599P	PARTICIPANT	\N	PRESENT	0
736379	735536	19631V	PARTICIPANT	\N	PRESENT	0
736415	735536	14331P	PARTICIPANT	\N	PRESENT	0
736381	735536	20082E	PARTICIPANT	\N	PRESENT	0
736416	735536	20024T	PARTICIPANT	\N	PRESENT	0
736417	735536	20054A	PARTICIPANT	\N	PRESENT	0
736384	735536	19782L	PARTICIPANT	\N	PRESENT	0
736385	735536	19954N	PARTICIPANT	\N	PRESENT	0
736386	735536	20180F	PARTICIPANT	\N	PRESENT	0
736387	735536	20132W	PARTICIPANT	\N	PRESENT	0
736388	735536	19507S	PARTICIPANT	\N	PRESENT	0
736412	735536	19593H	PARTICIPANT	\N	PRESENT	0
736390	735536	20152B	PARTICIPANT	\N	PRESENT	0
736418	735536	14207L	PARTICIPANT	\N	PRESENT	0
736419	735536	20142Y	PARTICIPANT	\N	PRESENT	0
736393	735536	19479G	PARTICIPANT	\N	PRESENT	0
736394	735536	19747H	PARTICIPANT	\N	PRESENT	0
736395	735536	01025N	PARTICIPANT	\N	PRESENT	0
736396	735536	18083K	PARTICIPANT	\N	PRESENT	0
736397	735536	19333N	PARTICIPANT	\N	PRESENT	0
736398	735536	19699S	PARTICIPANT	\N	PRESENT	0
736420	735536	19758L	PARTICIPANT	\N	PRESENT	0
736400	735536	14223L	PARTICIPANT	\N	PRESENT	0
736401	735536	19657G	PARTICIPANT	\N	PRESENT	0
736402	735536	19703U	PARTICIPANT	\N	PRESENT	0
736403	735536	19705W	PARTICIPANT	\N	PRESENT	0
736404	735536	20046A	PARTICIPANT	\N	PRESENT	0
736405	735536	19760E	PARTICIPANT	\N	PRESENT	0
736406	735536	20048C	PARTICIPANT	\N	PRESENT	0
736407	735536	14073Q	PARTICIPANT	\N	PRESENT	0
736421	735536	19527W	PARTICIPANT	\N	PRESENT	0
736409	735536	19707Y	PARTICIPANT	\N	PRESENT	0
736410	735536	20030R	PARTICIPANT	\N	PRESENT	0
736411	735536	20088L	PARTICIPANT	\N	PRESENT	0
736413	735536	20298U	PARTICIPANT	\N	PRESENT	0
736414	735536	20052X	PARTICIPANT	\N	PRESENT	0
736422	735536	08028W	PARTICIPANT	\N	PRESENT	0
736423	735536	04057K	PARTICIPANT	\N	PRESENT	0
736424	735536	19369B	PARTICIPANT	\N	PRESENT	0
736425	735536	20090E	PARTICIPANT	\N	PRESENT	0
736426	735536	20032T	PARTICIPANT	\N	PRESENT	0
736427	735536	20140W	PARTICIPANT	\N	PRESENT	0
736428	735536	19611R	PARTICIPANT	\N	PRESENT	0
736429	735536	11012A	PARTICIPANT	\N	PRESENT	0
736437	735536	19467C	PARTICIPANT	\N	PRESENT	0
736438	735536	20044X	PARTICIPANT	\N	PRESENT	0
736439	735536	07029T	PARTICIPANT	\N	PRESENT	0
736440	735536	19745F	PARTICIPANT	\N	PRESENT	0
736441	735536	14033T	PARTICIPANT	\N	PRESENT	0
736442	735536	20080C	PARTICIPANT	\N	PRESENT	0
736443	735536	20070A	PARTICIPANT	\N	PRESENT	0
736444	735536	19515S	PARTICIPANT	\N	PRESENT	0
736445	735536	20092G	PARTICIPANT	\N	PRESENT	0
736446	735536	14147R	PARTICIPANT	\N	PRESENT	0
736447	735536	14069U	PARTICIPANT	\N	PRESENT	0
736497	735537	19593H	PARTICIPANT	\N	PRESENT	0
736498	735537	20082E	PARTICIPANT	\N	PRESENT	0
736499	735537	20264J	PARTICIPANT	\N	PRESENT	0
736500	735537	19515S	PARTICIPANT	\N	PRESENT	0
736501	735537	20080C	PARTICIPANT	\N	PRESENT	0
736502	735537	11027H	PARTICIPANT	\N	PRESENT	0
736503	735537	20092G	PARTICIPANT	\N	PRESENT	0
736504	735537	20142Y	PARTICIPANT	\N	PRESENT	0
736505	735537	19782L	PARTICIPANT	\N	PRESENT	0
736506	735537	19387D	PARTICIPANT	\N	PRESENT	0
736507	735537	11012A	PARTICIPANT	\N	PRESENT	0
736508	735537	14207L	PARTICIPANT	\N	PRESENT	0
736509	735420	01058X	PARTICIPANT	\N	PRESENT	0
736510	735420	14255U	PARTICIPANT	\N	PRESENT	0
736511	735537	19745F	PARTICIPANT	\N	PRESENT	0
736512	735537	01025N	PARTICIPANT	\N	PRESENT	0
736513	735537	14037X	PARTICIPANT	\N	PRESENT	0
736514	735537	14073Q	PARTICIPANT	\N	PRESENT	0
736515	735537	14033T	PARTICIPANT	\N	PRESENT	0
736516	735537	14255U	PARTICIPANT	\N	PRESENT	0
736517	735537	19369B	PARTICIPANT	\N	PRESENT	0
736518	735537	11026G	PARTICIPANT	\N	PRESENT	0
736519	735537	20094J	PARTICIPANT	\N	PRESENT	0
736520	735537	11090Q	PARTICIPANT	\N	PRESENT	0
736521	735537	19467C	PARTICIPANT	\N	PRESENT	0
736522	735537	20054A	PARTICIPANT	\N	PRESENT	0
736523	735537	19707Y	PARTICIPANT	\N	PRESENT	0
736524	735537	19705W	PARTICIPANT	\N	PRESENT	0
736525	735537	20024T	PARTICIPANT	\N	PRESENT	0
736526	735537	14147R	PARTICIPANT	\N	PRESENT	0
736527	735537	14069U	PARTICIPANT	\N	PRESENT	0
736528	735537	20032T	PARTICIPANT	\N	PRESENT	0
736529	735537	20180F	PARTICIPANT	\N	PRESENT	0
736530	735537	14223L	PARTICIPANT	\N	PRESENT	0
736531	735537	08028W	PARTICIPANT	\N	PRESENT	0
736532	735537	20090E	PARTICIPANT	\N	PRESENT	0
736533	735537	19703U	PARTICIPANT	\N	PRESENT	0
736534	735537	19747H	PARTICIPANT	\N	PRESENT	0
736535	735537	19760E	PARTICIPANT	\N	PRESENT	0
736536	735537	14257W	PARTICIPANT	\N	PRESENT	0
736537	735537	20140W	PARTICIPANT	\N	PRESENT	0
736538	735537	07029T	PARTICIPANT	\N	PRESENT	0
736539	735537	08015R	PARTICIPANT	\N	PRESENT	0
736540	735537	14329V	PARTICIPANT	\N	PRESENT	0
736541	735537	14111D	PARTICIPANT	\N	PRESENT	0
736495	735537	11045K	PARTICIPANT	\N	PRESENT	0
736496	735537	19758L	PARTICIPANT	\N	PRESENT	0
736542	735537	19695N	PARTICIPANT	\N	PRESENT	0
736543	735537	14213J	PARTICIPANT	\N	PRESENT	0
736544	735537	19687N	PARTICIPANT	\N	PRESENT	0
736545	735537	01024M	PARTICIPANT	\N	PRESENT	0
736546	735537	20042V	PARTICIPANT	\N	PRESENT	0
736547	735537	20072C	PARTICIPANT	\N	PRESENT	0
736548	735537	14053L	PARTICIPANT	\N	PRESENT	0
736549	735537	19441R	PARTICIPANT	\N	PRESENT	0
736550	735537	20266L	PARTICIPANT	\N	PRESENT	0
736551	735537	11056N	PARTICIPANT	\N	PRESENT	0
736552	735537	11115U	PARTICIPANT	\N	PRESENT	0
736553	735537	12041X	PARTICIPANT	\N	PRESENT	0
736554	735537	19479G	PARTICIPANT	\N	PRESENT	0
736555	735537	14083S	PARTICIPANT	\N	PRESENT	0
736556	735537	20116W	PARTICIPANT	\N	PRESENT	0
736557	735537	19565D	PARTICIPANT	\N	PRESENT	0
736558	735537	14215L	PARTICIPANT	\N	PRESENT	0
736559	735537	19575F	PARTICIPANT	\N	PRESENT	0
736562	735537	20132W	PARTICIPANT	\N	PRESENT	0
736563	735537	18083K	PARTICIPANT	\N	PRESENT	0
736565	735537	20104S	PARTICIPANT	\N	PRESENT	0
736588	735537	20128B	PARTICIPANT	\N	PRESENT	0
736589	735537	19768N	PARTICIPANT	\N	PRESENT	0
736590	735537	20098N	PARTICIPANT	\N	PRESENT	0
736591	735537	14193X	PARTICIPANT	\N	PRESENT	0
736592	735537	20100N	PARTICIPANT	\N	PRESENT	0
736803	735642	19399H	PARTICIPANT	\N	PRESENT	1
736804	735642	20142Y	PARTICIPANT	\N	PRESENT	1
736805	735642	19643A	PARTICIPANT	\N	PRESENT	1
736844	736843	19575F	PARTICIPANT	\N	PRESENT	0
718697	718692	20018V	PARTICIPANT	\N	PRESENT	0
718699	718698	20018V	PARTICIPANT	\N	PRESENT	0
718701	718700	20018V	PARTICIPANT	\N	PRESENT	0
718702	718700	14033T	PARTICIPANT	\N	PRESENT	0
718704	718703	20018V	PARTICIPANT	\N	PRESENT	0
718705	718703	14033T	PARTICIPANT	\N	PRESENT	0
719191	718668	98022P	PARTICIPANT	\N	PRESENT	0
719192	718668	19347U	PARTICIPANT	\N	PRESENT	0
719193	718668	11083R	PARTICIPANT	\N	PRESENT	0
719194	718668	97011G	PARTICIPANT	\N	PRESENT	0
719195	718668	08061X	PARTICIPANT	\N	PRESENT	0
719196	718668	19583F	PARTICIPANT	\N	PRESENT	0
719352	718668	19443T	PARTICIPANT	\N	PRESENT	0
719353	718668	19669L	PARTICIPANT	\N	PRESENT	0
719354	718668	14055N	PARTICIPANT	\N	PRESENT	0
719355	718668	19421M	PARTICIPANT	\N	PRESENT	0
719356	718668	14193X	PARTICIPANT	\N	PRESENT	0
719357	718668	08047A	PARTICIPANT	\N	EXCUSE	0
719358	718668	04035D	PARTICIPANT	\N	PRESENT	0
719359	718668	14105F	PARTICIPANT	\N	PRESENT	0
719360	718668	14211G	PARTICIPANT	\N	PRESENT	0
719372	718668	19319Q	PARTICIPANT	\N	EXCUSE	0
719373	718668	12028B	PARTICIPANT	\N	EXCUSE	0
719374	718668	19565D	PARTICIPANT	\N	EXCUSE	0
719375	718668	20072C	PARTICIPANT	\N	EXCUSE	0
719376	718668	14267Y	PARTICIPANT	\N	EXCUSE	0
719377	718668	07033P	PARTICIPANT	\N	EXCUSE	0
719378	718668	14249W	PARTICIPANT	\N	EXCUSE	0
719379	718668	20128B	PARTICIPANT	\N	EXCUSE	0
719433	718395	19697Q	PARTICIPANT	\N	PRESENT	0
719434	718395	20090E	PARTICIPANT	\N	PRESENT	0
719435	718395	11067R	PARTICIPANT	\N	PRESENT	0
719436	718395	19798U	PARTICIPANT	\N	PRESENT	0
719437	718395	19569H	PARTICIPANT	\N	PRESENT	0
719438	718395	19329S	PARTICIPANT	\N	PRESENT	0
719439	718395	11097X	PARTICIPANT	\N	PRESENT	0
719440	718395	19415P	PARTICIPANT	\N	PRESENT	0
719441	718395	14223L	PARTICIPANT	\N	PRESENT	0
719442	718395	18193Q	PARTICIPANT	\N	PRESENT	0
719443	718395	14026U	PARTICIPANT	\N	PRESENT	0
719444	718395	17779H	PARTICIPANT	\N	PRESENT	0
719445	718395	19703U	PARTICIPANT	\N	PRESENT	0
719446	718395	11031D	PARTICIPANT	\N	PRESENT	0
719447	718395	19553Y	PARTICIPANT	\N	PRESENT	0
719448	718395	14281W	PARTICIPANT	\N	PRESENT	0
719449	718395	19679N	PARTICIPANT	\N	PRESENT	0
719450	718395	14042U	PARTICIPANT	\N	PRESENT	0
719451	718395	19367Y	PARTICIPANT	\N	PRESENT	0
719452	718395	14213J	PARTICIPANT	\N	PRESENT	0
719453	718395	14217N	PARTICIPANT	\N	PRESENT	0
719454	718395	19511N	PARTICIPANT	\N	PRESENT	0
719455	718395	10006L	PRESIDENT	0	PRESENT	0
719456	718395	20130U	PARTICIPANT	\N	PRESENT	0
719457	718395	01034P	PARTICIPANT	\N	PRESENT	0
719458	718395	04057K	PARTICIPANT	\N	PRESENT	0
719459	718395	04092N	PARTICIPANT	\N	PRESENT	0
719460	718395	19713W	PARTICIPANT	\N	PRESENT	0
719461	718395	20040T	PARTICIPANT	\N	PRESENT	0
719462	718395	19663E	PARTICIPANT	\N	PRESENT	0
719463	718395	19691J	PARTICIPANT	\N	PRESENT	0
719464	718395	19715Y	PARTICIPANT	\N	PRESENT	0
719465	718395	19717B	PARTICIPANT	\N	PRESENT	0
719466	718395	19723Y	PARTICIPANT	\N	PRESENT	0
719467	718395	20248J	PARTICIPANT	\N	PRESENT	0
719468	718395	20066E	PARTICIPANT	\N	PRESENT	0
719469	718395	14071N	PARTICIPANT	\N	PRESENT	0
719470	718395	04043D	PARTICIPANT	\N	PRESENT	0
719471	718395	19760E	PARTICIPANT	\N	PRESENT	0
719503	718605	86034E	PARTICIPANT	\N	PRESENT	0
719508	718605	04047H	PARTICIPANT	\N	PRESENT	0
719509	718605	20062A	PARTICIPANT	\N	PRESENT	0
719510	718605	19866P	PARTICIPANT	\N	PRESENT	0
719511	718605	19629C	PARTICIPANT	\N	PRESENT	0
719512	718605	19511N	PARTICIPANT	\N	PRESENT	0
719513	718605	11043H	PARTICIPANT	\N	PRESENT	0
719514	718605	19583F	PARTICIPANT	\N	PRESENT	0
719515	718605	20180F	PARTICIPANT	\N	PRESENT	0
719516	718605	19679N	PARTICIPANT	\N	PRESENT	0
719517	718605	19533U	PARTICIPANT	\N	PRESENT	0
719518	718605	20068G	PARTICIPANT	\N	PRESENT	0
719519	718605	17589D	PARTICIPANT	\N	PRESENT	0
719520	718605	14221J	PARTICIPANT	\N	PRESENT	0
719521	718605	14107H	PARTICIPANT	\N	PRESENT	0
719522	718605	98022P	PARTICIPANT	\N	PRESENT	0
719523	718605	20298U	PARTICIPANT	\N	PRESENT	0
719524	718605	19585H	PARTICIPANT	\N	PRESENT	0
719525	718605	11080N	PARTICIPANT	\N	PRESENT	0
719526	718605	14033T	PARTICIPANT	\N	PRESENT	0
719527	718605	20026V	PARTICIPANT	\N	PRESENT	0
719528	718605	19507S	PARTICIPANT	\N	PRESENT	0
719529	718605	19515S	PARTICIPANT	\N	PRESENT	0
719530	718605	20140W	PARTICIPANT	\N	PRESENT	0
719531	718605	14213J	PARTICIPANT	\N	PRESENT	0
719532	718605	19599P	PARTICIPANT	\N	PRESENT	0
719533	718605	19715Y	PARTICIPANT	\N	PRESENT	0
719534	718605	20050V	PARTICIPANT	\N	PRESENT	0
719535	718605	19798U	PARTICIPANT	\N	PRESENT	0
719536	718605	14217N	PARTICIPANT	\N	PRESENT	0
719537	718605	19565D	PARTICIPANT	\N	PRESENT	0
719538	718605	08069G	PARTICIPANT	\N	PRESENT	0
719539	718605	20074E	PARTICIPANT	\N	PRESENT	0
719540	718605	11010L	PARTICIPANT	\N	PRESENT	0
719541	718605	19697Q	PARTICIPANT	\N	PRESENT	0
719542	718605	07004J	PARTICIPANT	\N	PRESENT	0
719543	718605	01025N	PARTICIPANT	\N	PRESENT	0
719544	718605	14267Y	PARTICIPANT	\N	PRESENT	0
719545	718605	04059M	PARTICIPANT	\N	PRESENT	0
719546	718605	19683J	PARTICIPANT	\N	PRESENT	0
719547	718605	11067R	PARTICIPANT	\N	PRESENT	0
719548	718605	19725B	PARTICIPANT	\N	PRESENT	0
719549	718605	19503N	PARTICIPANT	\N	PRESENT	0
719550	718605	19593H	PARTICIPANT	\N	PRESENT	0
719551	718605	19695N	PARTICIPANT	\N	PRESENT	0
719552	718605	20102Q	PARTICIPANT	\N	PRESENT	0
719553	718605	11104D	PARTICIPANT	\N	PRESENT	0
719554	718605	20100N	PARTICIPANT	\N	PRESENT	0
719555	718605	19489J	PARTICIPANT	\N	PRESENT	0
719556	718605	19719D	PARTICIPANT	\N	PRESENT	0
719557	718605	19545Y	PARTICIPANT	\N	PRESENT	0
719558	718605	14211G	PARTICIPANT	\N	PRESENT	0
719559	718605	08061X	PARTICIPANT	\N	PRESENT	0
719560	718605	19525U	PARTICIPANT	\N	PRESENT	0
719561	718605	11027H	PARTICIPANT	\N	PRESENT	0
719562	718605	20114U	PARTICIPANT	\N	PRESENT	0
719563	718605	11054L	PARTICIPANT	\N	PRESENT	0
719564	718605	11040E	PARTICIPANT	\N	PRESENT	0
719565	718605	19760E	PARTICIPANT	\N	PRESENT	0
719566	718605	19758L	PARTICIPANT	\N	PRESENT	0
719567	718605	12041X	PARTICIPANT	\N	PRESENT	0
719568	718605	11077T	PARTICIPANT	\N	PRESENT	0
719569	718605	20046A	PARTICIPANT	\N	PRESENT	0
719570	718605	20112S	PARTICIPANT	\N	PRESENT	0
719571	718605	20036X	PARTICIPANT	\N	PRESENT	0
719572	718605	20134Y	PARTICIPANT	\N	PRESENT	0
719573	718605	19347U	PARTICIPANT	\N	PRESENT	0
719838	719835	14205J	PARTICIPANT	\N	PRESENT	0
719575	718605	19621T	PARTICIPANT	\N	PRESENT	0
719576	718605	20110Q	PARTICIPANT	\N	PRESENT	0
719836	719835	20092G	PARTICIPANT	\N	PRESENT	0
719837	719835	20076G	PARTICIPANT	\N	PRESENT	0
719839	719835	19713W	PARTICIPANT	\N	PRESENT	0
719840	719835	14189C	PARTICIPANT	\N	PRESENT	0
719841	719835	20082E	PARTICIPANT	\N	PRESENT	0
719842	719835	19563B	PARTICIPANT	\N	PRESENT	0
719843	719835	20050V	PARTICIPANT	\N	PRESENT	0
719844	719835	19723Y	PARTICIPANT	\N	PRESENT	0
719888	718540	11056N	PARTICIPANT	\N	PRESENT	0
719890	718540	14259Y	PARTICIPANT	\N	PRESENT	0
719891	718540	11097X	PARTICIPANT	\N	PRESENT	0
719894	718667	14331P	PRESIDENT	0	PRESENT	0
719895	718667	14169X	PARTICIPANT	\N	PRESENT	0
719896	718667	19701S	PARTICIPANT	\N	PRESENT	0
719897	718667	14237S	PARTICIPANT	\N	PRESENT	0
719898	718667	20100N	PARTICIPANT	\N	PRESENT	0
719899	718667	17737W	PARTICIPANT	\N	PRESENT	0
719900	718667	19531S	PARTICIPANT	\N	PRESENT	0
719901	718667	20098N	PARTICIPANT	\N	PRESENT	0
719902	718667	11083R	PARTICIPANT	\N	PRESENT	0
718695	718692	14187A	PARTICIPANT	\N	PRESENT	0
718696	718692	19695N	PARTICIPANT	\N	PRESENT	0
719903	718667	04070G	PARTICIPANT	\N	PRESENT	0
716626	716624	14030Q	PARTICIPANT	\N	PRESENT	1
716627	716624	20058E	PARTICIPANT	\N	PRESENT	1
734056	732916	19671E	PARTICIPANT	\N	PRESENT	0
734057	732916	11110B	PARTICIPANT	\N	PRESENT	0
734058	732916	07029T	PARTICIPANT	\N	PRESENT	0
734059	732916	19349W	PARTICIPANT	\N	PRESENT	0
734060	732916	14253S	PARTICIPANT	\N	PRESENT	0
734061	732916	20116W	PARTICIPANT	\N	PRESENT	0
734063	732916	19335Q	PARTICIPANT	\N	PRESENT	0
734064	732916	20126Y	PARTICIPANT	\N	PRESENT	0
734065	732916	11048N	PARTICIPANT	\N	PRESENT	0
734066	732916	19479G	PARTICIPANT	\N	PRESENT	0
734067	732916	19711U	PARTICIPANT	\N	PRESENT	0
734068	732916	19531S	PARTICIPANT	\N	PRESENT	0
734069	732916	08034U	PARTICIPANT	\N	PRESENT	0
734070	732916	19687N	PARTICIPANT	\N	PRESENT	0
734071	732916	12016W	PARTICIPANT	\N	PRESENT	0
734072	732916	20050V	PARTICIPANT	\N	PRESENT	0
734073	732916	20044X	PARTICIPANT	\N	PRESENT	0
734074	732916	20150Y	PARTICIPANT	\N	PRESENT	0
734075	732916	14083S	PARTICIPANT	\N	PRESENT	0
734076	732916	11012A	PARTICIPANT	\N	PRESENT	0
734077	732916	08073C	PARTICIPANT	\N	PRESENT	0
734078	732916	20252E	PARTICIPANT	\N	PRESENT	0
734079	732916	20070A	PARTICIPANT	\N	PRESENT	0
734080	732916	19741B	PARTICIPANT	\N	PRESENT	0
734081	732916	14121F	PARTICIPANT	\N	PRESENT	0
734082	732916	20914V	PARTICIPANT	\N	PRESENT	0
734083	732916	99004R	PARTICIPANT	\N	PRESENT	0
734084	732916	19762G	PARTICIPANT	\N	PRESENT	0
734085	732916	08011M	PARTICIPANT	\N	PRESENT	0
734086	732916	14225N	PARTICIPANT	\N	EXCUSE	0
734087	732653	12041X	PARTICIPANT	\N	PRESENT	0
734088	732653	19565D	PARTICIPANT	\N	PRESENT	0
734089	732653	01058X	PARTICIPANT	\N	PRESENT	0
734090	732653	11027H	PARTICIPANT	\N	PRESENT	0
734091	732653	16685X	PARTICIPANT	\N	PRESENT	0
734092	732653	04042C	PRESIDENT	0	PRESENT	0
734093	732653	11066Q	PARTICIPANT	\N	PRESENT	0
734094	732653	19669L	PARTICIPANT	\N	PRESENT	0
734095	732653	08056B	PARTICIPANT	\N	PRESENT	0
734096	732653	12028B	PARTICIPANT	\N	PRESENT	0
734097	732653	19421M	PARTICIPANT	\N	PRESENT	0
734098	732653	19709B	PARTICIPANT	\N	PRESENT	0
734099	732653	14193X	PARTICIPANT	\N	PRESENT	0
734100	732653	19347U	PARTICIPANT	\N	PRESENT	0
734101	732653	07033P	PARTICIPANT	\N	PRESENT	0
734102	732653	97011G	PARTICIPANT	\N	PRESENT	0
734103	732653	08061X	PARTICIPANT	\N	PRESENT	0
734104	732653	08047A	PARTICIPANT	\N	PRESENT	0
734105	732653	20128B	PARTICIPANT	\N	PRESENT	0
734106	732653	14097Y	PARTICIPANT	\N	PRESENT	0
734107	732653	14059S	PARTICIPANT	\N	PRESENT	0
734108	732653	14133K	PARTICIPANT	\N	PRESENT	0
734109	732653	01062T	PARTICIPANT	\N	PRESENT	0
734110	732653	11041F	PARTICIPANT	\N	PRESENT	0
734111	732653	20042V	PARTICIPANT	\N	PRESENT	0
734112	732653	01024M	PARTICIPANT	\N	PRESENT	0
734113	732653	14191V	PARTICIPANT	\N	PRESENT	0
734114	732653	19721W	PARTICIPANT	\N	PRESENT	0
734115	732653	20064C	PARTICIPANT	\N	PRESENT	0
734116	732653	98022P	PARTICIPANT	\N	PRESENT	0
734117	732653	11083R	PARTICIPANT	\N	PRESENT	0
734118	732653	14211G	PARTICIPANT	\N	PRESENT	0
734119	732653	14255U	PARTICIPANT	\N	PRESENT	0
734121	732653	08069G	PARTICIPANT	\N	PRESENT	0
734122	732653	14105F	PARTICIPANT	\N	PRESENT	0
734123	732916	08010L	PARTICIPANT	\N	PRESENT	0
734124	732916	20036X	PARTICIPANT	\N	EXCUSE	0
734266	732868	19383Y	PARTICIPANT	\N	PRESENT	0
734267	732868	19768N	PARTICIPANT	\N	PRESENT	0
734268	732868	20088L	PARTICIPANT	\N	PRESENT	0
734269	732868	19515S	PARTICIPANT	\N	PRESENT	0
734270	732868	19782L	PARTICIPANT	\N	PRESENT	0
734271	732868	20092G	PARTICIPANT	\N	PRESENT	0
734272	732868	11077T	PARTICIPANT	\N	PRESENT	0
734273	732868	01043Q	PARTICIPANT	\N	PRESENT	0
734274	732868	14357A	PARTICIPANT	\N	PRESENT	0
734275	732868	20078J	PARTICIPANT	\N	PRESENT	0
734276	732868	19413M	PARTICIPANT	\N	PRESENT	0
734277	732868	20094J	PARTICIPANT	\N	PRESENT	0
734278	732868	04045F	PARTICIPANT	\N	PRESENT	0
734279	732868	20104S	PARTICIPANT	\N	PRESENT	0
734280	732868	11099A	PARTICIPANT	\N	PRESENT	0
734281	732868	19705W	PARTICIPANT	\N	PRESENT	0
734282	732868	19707Y	PARTICIPANT	\N	PRESENT	0
734283	732868	08015R	PARTICIPANT	\N	PRESENT	0
734284	732868	19575F	PARTICIPANT	\N	PRESENT	0
734285	732868	19369B	PARTICIPANT	\N	PRESENT	0
734286	732868	20018V	PARTICIPANT	\N	PRESENT	0
734287	732868	19563B	PARTICIPANT	\N	PRESENT	0
734288	732868	14329V	PARTICIPANT	\N	PRESENT	0
734289	732868	20028X	PARTICIPANT	\N	PRESENT	0
734290	732868	14037X	PARTICIPANT	\N	PRESENT	0
734291	732868	14038Y	PARTICIPANT	\N	PRESENT	0
734292	732868	20030R	PARTICIPANT	\N	PRESENT	0
734293	732868	14187A	PARTICIPANT	\N	PRESENT	0
734294	732868	20144B	PARTICIPANT	\N	PRESENT	0
734295	732868	19695N	PARTICIPANT	\N	PRESENT	0
734296	732868	11090Q	PRESIDENT	0	PRESENT	0
734297	732868	01025N	PARTICIPANT	\N	PRESENT	0
734298	732868	14033T	PARTICIPANT	\N	PRESENT	0
734299	732868	20054A	PARTICIPANT	\N	PRESENT	0
734300	732868	14205J	PARTICIPANT	\N	PRESENT	0
734301	732868	20060X	PARTICIPANT	\N	PRESENT	0
734302	732868	20062A	PARTICIPANT	\N	PRESENT	0
734303	732868	14251Q	PARTICIPANT	\N	PRESENT	0
734304	732868	20286Q	PARTICIPANT	\N	PRESENT	0
734305	732868	19747H	PARTICIPANT	\N	PRESENT	0
734306	732868	14207L	PARTICIPANT	\N	PRESENT	0
734307	732868	14257W	PARTICIPANT	\N	PRESENT	0
734308	732868	19467C	PARTICIPANT	\N	EXCUSE	0
734309	732868	20082E	PARTICIPANT	\N	EXCUSE	0
734310	734162	11048N	PARTICIPANT	\N	PRESENT	0
734311	734162	19647E	PARTICIPANT	\N	PRESENT	0
734312	734162	19479G	PARTICIPANT	\N	PRESENT	0
734313	734162	19711U	PARTICIPANT	\N	PRESENT	0
734314	734162	01048V	PARTICIPANT	\N	PRESENT	0
734315	734162	01057W	PARTICIPANT	\N	PRESENT	0
734316	734162	20080C	PARTICIPANT	\N	PRESENT	0
734317	734162	11074Q	PRESIDENT	0	PRESENT	0
734318	734162	19667J	PARTICIPANT	\N	PRESENT	0
734319	734162	20044X	PARTICIPANT	\N	PRESENT	0
734320	734162	19671E	PARTICIPANT	\N	PRESENT	0
734321	734162	07029T	PARTICIPANT	\N	PRESENT	0
734322	734162	14083S	PARTICIPANT	\N	PRESENT	0
734323	734162	20252E	PARTICIPANT	\N	PRESENT	0
734324	734162	20070A	PARTICIPANT	\N	PRESENT	0
734325	734162	19349W	PARTICIPANT	\N	PRESENT	0
734326	734162	19741B	PARTICIPANT	\N	PRESENT	0
734327	734162	20116W	PARTICIPANT	\N	PRESENT	0
734328	734162	20914V	PARTICIPANT	\N	PRESENT	0
734329	734162	20086J	PARTICIPANT	\N	PRESENT	0
734330	734162	12016W	PARTICIPANT	\N	PRESENT	0
734348	733755	01048V	PARTICIPANT	\N	PRESENT	0
734349	733755	19593H	PARTICIPANT	\N	PRESENT	0
734350	733755	19533U	PARTICIPANT	\N	PRESENT	0
734351	733755	04043D	PARTICIPANT	\N	PRESENT	0
734390	732767	86034E	PARTICIPANT	\N	PRESENT	0
734397	732767	08060W	PARTICIPANT	\N	PRESENT	0
734398	732767	19333N	PARTICIPANT	\N	PRESENT	0
734399	732767	19531S	PARTICIPANT	\N	PRESENT	0
734400	732767	19782L	PARTICIPANT	\N	PRESENT	0
734401	732767	19525U	PARTICIPANT	\N	PRESENT	0
734402	732767	04045F	PARTICIPANT	\N	PRESENT	0
734403	732767	11041F	PARTICIPANT	\N	PRESENT	0
734404	732767	11104D	PARTICIPANT	\N	PRESENT	0
734405	732767	14107H	PARTICIPANT	\N	PRESENT	0
734406	732767	14231L	PARTICIPANT	\N	PRESENT	0
734407	732767	14037X	PARTICIPANT	\N	PRESENT	0
734408	732767	19599P	PARTICIPANT	\N	PRESENT	0
734409	732767	20032T	PARTICIPANT	\N	PRESENT	0
734410	732767	14038Y	PARTICIPANT	\N	PRESENT	0
734411	732767	20098N	PARTICIPANT	\N	PRESENT	0
734412	732767	20056C	PARTICIPANT	\N	PRESENT	0
734413	732767	20180F	PARTICIPANT	\N	PRESENT	0
722860	722790	19719D	PARTICIPANT	\N	PRESENT	0
722871	722790	19703U	PARTICIPANT	\N	PRESENT	0
722875	722790	95041E	PARTICIPANT	\N	PRESENT	0
722876	722790	20050V	PARTICIPANT	\N	PRESENT	0
722880	722790	20914V	PARTICIPANT	\N	PRESENT	0
722881	722790	20106U	PARTICIPANT	\N	PRESENT	0
722882	722790	19820Y	PARTICIPANT	\N	PRESENT	0
722883	722790	20046A	PARTICIPANT	\N	PRESENT	0
722884	722790	14219Q	PARTICIPANT	\N	PRESENT	0
722885	722790	19387D	PARTICIPANT	\N	PRESENT	0
722886	722790	11048N	PARTICIPANT	\N	PRESENT	0
722887	722790	19701S	PARTICIPANT	\N	PRESENT	0
722888	722790	20094J	PARTICIPANT	\N	PRESENT	0
722889	722790	19441R	PARTICIPANT	\N	PRESENT	0
722892	722790	19691J	PARTICIPANT	\N	PRESENT	0
722895	722790	14259Y	PARTICIPANT	\N	PRESENT	0
722897	722790	20024T	PARTICIPANT	\N	PRESENT	0
722898	722790	20038A	PARTICIPANT	\N	PRESENT	0
722899	722790	18083K	PARTICIPANT	\N	PRESENT	0
722901	722790	08028W	PARTICIPANT	\N	PRESENT	0
722905	722790	20098N	PARTICIPANT	\N	PRESENT	0
722912	722790	19543W	PARTICIPANT	\N	PRESENT	0
722917	722790	20252E	PARTICIPANT	\N	PRESENT	0
722915	722790	19711U	PARTICIPANT	\N	PRESENT	0
722916	722790	20286Q	PARTICIPANT	\N	PRESENT	0
722919	722790	20066E	PARTICIPANT	\N	PRESENT	0
722920	722790	14169X	PARTICIPANT	\N	PRESENT	0
722926	722790	11065P	PARTICIPANT	\N	PRESENT	0
722928	721224	19699S	PARTICIPANT	\N	PRESENT	0
722929	721224	19533U	PARTICIPANT	\N	PRESENT	0
722930	721224	14229S	PARTICIPANT	\N	PRESENT	0
722931	721224	19573D	PARTICIPANT	\N	PRESENT	0
722932	721224	20124W	PARTICIPANT	\N	PRESENT	0
722933	721224	20026V	PARTICIPANT	\N	PRESENT	0
722934	721224	19527W	PARTICIPANT	\N	PRESENT	0
722935	721224	20132W	PARTICIPANT	\N	PRESENT	0
722936	721224	19643A	PARTICIPANT	\N	PRESENT	0
722937	721224	14073Q	PARTICIPANT	\N	PRESENT	0
722938	721224	19651A	PARTICIPANT	\N	PRESENT	0
722939	721224	20138D	PARTICIPANT	\N	PRESENT	0
722940	721224	20142Y	PARTICIPANT	\N	PRESENT	0
722941	721224	19693L	PRESIDENT	0	PRESENT	0
722942	721224	14030Q	PARTICIPANT	\N	PRESENT	0
722943	721224	20058E	PARTICIPANT	\N	PRESENT	0
722944	721224	20056C	PARTICIPANT	\N	PRESENT	0
722945	721224	20264J	PARTICIPANT	\N	PRESENT	0
722946	721224	04059M	PARTICIPANT	\N	PRESENT	0
722947	721224	19735D	PARTICIPANT	\N	PRESENT	0
722948	721224	14109K	PARTICIPANT	\N	PRESENT	0
722949	721224	14123H	PARTICIPANT	\N	PRESENT	0
722950	721224	11104D	PARTICIPANT	\N	PRESENT	0
722951	721224	11043H	PARTICIPANT	\N	PRESENT	0
722952	721224	20980G	PARTICIPANT	\N	PRESENT	0
722953	721224	19621T	PARTICIPANT	\N	PRESENT	0
722954	721224	20098N	PARTICIPANT	\N	PRESENT	0
722956	722790	14069U	PARTICIPANT	\N	PRESENT	0
722957	722790	20032T	PARTICIPANT	\N	PRESENT	0
722959	721224	20152B	PARTICIPANT	\N	PRESENT	0
722966	722790	19507S	PARTICIPANT	\N	PRESENT	0
722963	722790	20036X	PARTICIPANT	\N	PRESENT	0
722964	722790	14107H	PARTICIPANT	\N	PRESENT	0
722965	722790	19333N	PARTICIPANT	\N	PRESENT	0
722967	722790	20090E	PARTICIPANT	\N	PRESENT	0
722968	722790	14207L	PARTICIPANT	\N	PRESENT	0
722969	722790	20128B	PARTICIPANT	\N	PRESENT	0
722972	722790	01058X	PARTICIPANT	\N	PRESENT	0
722973	721224	19593H	PARTICIPANT	\N	PRESENT	0
722974	721224	19399H	PARTICIPANT	\N	PRESENT	0
722975	721224	20180F	PARTICIPANT	\N	PRESENT	0
722976	722790	19631V	PARTICIPANT	\N	PRESENT	0
722977	722790	14151M	PARTICIPANT	\N	PRESENT	0
722978	722790	20034V	PARTICIPANT	\N	PRESENT	0
722979	722790	14147R	PARTICIPANT	\N	PRESENT	0
722980	722790	20058E	PARTICIPANT	\N	PRESENT	0
722981	722790	19747H	PARTICIPANT	\N	PRESENT	0
722982	722790	20132W	PARTICIPANT	\N	PRESENT	0
722983	722790	20026V	PARTICIPANT	\N	PRESENT	0
722984	722790	95063L	PARTICIPANT	\N	PRESENT	0
722985	722790	19713W	PARTICIPANT	\N	PRESENT	0
722986	722790	19399H	PARTICIPANT	\N	PRESENT	0
722987	722790	19741B	PARTICIPANT	\N	PRESENT	0
722988	722790	14073Q	PARTICIPANT	\N	PRESENT	0
722989	722790	11104D	PARTICIPANT	\N	PRESENT	0
722990	722790	20028X	PARTICIPANT	\N	PRESENT	0
722991	722790	14030Q	PARTICIPANT	\N	PRESENT	0
722992	722790	19723Y	PARTICIPANT	\N	PRESENT	0
722993	722790	19575F	PARTICIPANT	\N	PRESENT	0
722994	722790	14083S	PARTICIPANT	\N	PRESENT	0
722995	722790	19798U	PARTICIPANT	\N	PRESENT	0
722996	722790	20134Y	PARTICIPANT	\N	PRESENT	0
722997	722790	20980G	PARTICIPANT	\N	PRESENT	0
722998	722790	14033T	PARTICIPANT	\N	PRESENT	0
722999	722790	14123H	PARTICIPANT	\N	PRESENT	0
723000	722790	19533U	PARTICIPANT	\N	PRESENT	0
723001	722790	19745F	PARTICIPANT	\N	PRESENT	0
723002	722790	14121F	PARTICIPANT	\N	PRESENT	0
723003	722790	20092G	PARTICIPANT	\N	PRESENT	0
723004	722790	14217N	PARTICIPANT	\N	PRESENT	0
723005	722790	14189C	PARTICIPANT	\N	PRESENT	0
723006	722790	19735D	PARTICIPANT	\N	PRESENT	0
723007	722790	19467C	PARTICIPANT	\N	PRESENT	0
723009	722790	01024M	PARTICIPANT	\N	PRESENT	0
723010	722790	19699S	PARTICIPANT	\N	PRESENT	0
723011	722790	19826F	PARTICIPANT	\N	PRESENT	0
723015	722790	08015R	PARTICIPANT	\N	PRESENT	0
723018	722790	20044X	PARTICIPANT	\N	PRESENT	0
723019	722790	19651A	PARTICIPANT	\N	PRESENT	0
723020	722790	01025N	PARTICIPANT	\N	PRESENT	0
723021	722790	20124W	PARTICIPANT	\N	PRESENT	0
723022	722790	20108W	PARTICIPANT	\N	PRESENT	0
723023	722790	14179A	PARTICIPANT	\N	PRESENT	0
723024	722790	19762G	PARTICIPANT	\N	PRESENT	0
723025	722790	97011G	PARTICIPANT	\N	PRESENT	0
723026	722790	20140W	PARTICIPANT	\N	PRESENT	0
723027	722790	14038Y	PARTICIPANT	\N	PRESENT	0
723030	722790	01057W	PARTICIPANT	\N	PRESENT	0
723031	722790	14042U	PARTICIPANT	\N	PRESENT	0
723032	722790	14031R	PARTICIPANT	\N	PRESENT	0
723035	722790	14267Y	PARTICIPANT	\N	PRESENT	0
723036	722790	14205J	PARTICIPANT	\N	PRESENT	0
723038	722790	20114U	PARTICIPANT	\N	PRESENT	0
723039	722790	19369B	PARTICIPANT	\N	PRESENT	0
723040	722790	14237S	PARTICIPANT	\N	PRESENT	0
723042	722790	20152B	PARTICIPANT	\N	PRESENT	0
723047	722790	20056C	PARTICIPANT	\N	PRESENT	0
723048	722790	20022R	PARTICIPANT	\N	PRESENT	0
723049	722790	19383Y	PARTICIPANT	\N	PRESENT	0
723050	722790	19621T	PARTICIPANT	\N	PRESENT	0
723051	722790	20138D	PARTICIPANT	\N	PRESENT	0
723052	722790	20264J	PARTICIPANT	\N	PRESENT	0
723053	722790	19527W	PARTICIPANT	\N	PRESENT	0
723054	722790	20062A	PARTICIPANT	\N	PRESENT	0
723055	722790	19760E	PARTICIPANT	\N	PRESENT	0
723056	722790	19758L	PARTICIPANT	\N	PRESENT	0
723060	722790	11033F	PARTICIPANT	\N	PRESENT	0
723061	723059	19713W	PARTICIPANT	\N	PRESENT	0
723062	723059	19251M	PRESIDENT	0	PRESENT	0
723063	723059	14237S	PARTICIPANT	\N	PRESENT	0
723064	722790	14053L	PARTICIPANT	\N	PRESENT	0
718749	718748	20118Y	PARTICIPANT	\N	PRESENT	0
718750	718748	20058E	PARTICIPANT	\N	PRESENT	0
718751	718748	20022R	PARTICIPANT	\N	PRESENT	0
718752	718748	14059S	PARTICIPANT	\N	PRESENT	0
718753	718748	19713W	PARTICIPANT	\N	PRESENT	0
718755	718754	14071N	PARTICIPANT	\N	PRESENT	0
718756	718754	19826F	PARTICIPANT	\N	PRESENT	0
718757	718754	19575F	PARTICIPANT	\N	PRESENT	0
718770	718768	14187A	PRESIDENT	0	PRESENT	0
718771	718768	19347U	PARTICIPANT	\N	PRESENT	0
718772	718768	20298U	PARTICIPANT	\N	PRESENT	0
718773	718768	20018V	PARTICIPANT	\N	PRESENT	0
720088	720087	18083K	PARTICIPANT	\N	PRESENT	0
718775	718768	20090E	PARTICIPANT	\N	EXCUSE	0
718776	718768	19701S	PARTICIPANT	\N	EXCUSE	0
718777	718768	14257W	PARTICIPANT	\N	PRESENT	0
720085	718399	11043H	PARTICIPANT	\N	EXCUSE	0
720086	719776	11043H	PARTICIPANT	\N	EXCUSE	0
725926	725805	19735D	PRESIDENT	0	PRESENT	0
722867	722865	14030Q	PARTICIPANT	\N	PRESENT	0
722868	722865	20114U	PARTICIPANT	\N	PRESENT	0
722869	722865	19782L	PARTICIPANT	\N	PRESENT	0
722870	722865	14042U	PARTICIPANT	\N	PRESENT	0
722872	722865	11083R	PARTICIPANT	\N	PRESENT	0
722873	722865	19723Y	PARTICIPANT	\N	PRESENT	0
725925	725805	11031D	PARTICIPANT	\N	PRESENT	0
722877	722865	19503N	PARTICIPANT	\N	PRESENT	0
722879	722865	20098N	PARTICIPANT	\N	PRESENT	0
725927	725805	14213J	PARTICIPANT	\N	PRESENT	0
725928	725805	20096L	PARTICIPANT	\N	PRESENT	0
725929	725805	20024T	PARTICIPANT	\N	PRESENT	0
725930	725805	17965H	PARTICIPANT	\N	PRESENT	0
725931	725805	14026U	PARTICIPANT	\N	PRESENT	0
725946	725945	14173T	PARTICIPANT	\N	PRESENT	0
725948	725947	14173T	PARTICIPANT	\N	PRESENT	0
725951	725950	14173T	PARTICIPANT	\N	PRESENT	0
725953	725952	14173T	PARTICIPANT	\N	PRESENT	0
725955	725954	14173T	PARTICIPANT	\N	PRESENT	0
736857	736843	19369B	PARTICIPANT	\N	PRESENT	0
736858	736843	14071N	PARTICIPANT	\N	PRESENT	0
736859	736843	19533U	PARTICIPANT	\N	PRESENT	0
736860	736843	19619A	PARTICIPANT	\N	PRESENT	0
736861	736843	20092G	PARTICIPANT	\N	PRESENT	0
736862	736843	19413M	PARTICIPANT	\N	PRESENT	0
736867	736866	04070G	PARTICIPANT	\N	EXCUSE	0
736868	736866	19479G	PARTICIPANT	\N	EXCUSE	0
736869	736866	11040E	PARTICIPANT	\N	EXCUSE	0
736870	736866	14193X	PARTICIPANT	\N	EXCUSE	0
736871	736866	20144B	PARTICIPANT	\N	EXCUSE	0
736872	736866	20018V	PARTICIPANT	\N	EXCUSE	0
736873	736866	20044X	PARTICIPANT	\N	EXCUSE	0
737951	736866	20068G	PARTICIPANT	\N	PRESENT	0
737952	736866	20050V	PARTICIPANT	\N	PRESENT	0
737953	736866	19711U	PARTICIPANT	\N	PRESENT	0
737954	736866	20042V	PARTICIPANT	\N	PRESENT	0
737955	736866	11097X	PARTICIPANT	\N	PRESENT	0
737956	735305	14331P	PRESIDENT	0	PRESENT	0
737957	735305	14073Q	PARTICIPANT	\N	PRESENT	0
737958	735305	14033T	PARTICIPANT	\N	PRESENT	0
737959	736866	14259Y	PARTICIPANT	\N	PRESENT	0
737960	735305	19701S	PARTICIPANT	\N	PRESENT	0
737961	735305	14237S	PARTICIPANT	\N	PRESENT	0
737962	735305	10015M	PARTICIPANT	\N	PRESENT	0
737963	735305	08034U	PARTICIPANT	\N	PRESENT	0
737964	735305	14357A	PARTICIPANT	\N	PRESENT	0
737965	735305	20100N	PARTICIPANT	\N	PRESENT	0
737966	735305	14001X	PARTICIPANT	\N	PRESENT	0
737967	735305	19333N	PARTICIPANT	\N	PRESENT	0
737968	735305	20098N	PARTICIPANT	\N	PRESENT	0
737969	735305	20286Q	PARTICIPANT	\N	PRESENT	0
737970	736866	11056N	PARTICIPANT	\N	PRESENT	0
737971	736866	20132W	PARTICIPANT	\N	PRESENT	0
737996	735305	14097Y	PARTICIPANT	\N	PRESENT	0
738027	738026	04033B	PARTICIPANT	\N	PRESENT	0
738063	733710	20034V	PARTICIPANT	\N	EXCUSE	0
738223	738221	19333N	PARTICIPANT	\N	PRESENT	0
738225	738224	19709B	PARTICIPANT	\N	PRESENT	0
738220	738217	04033B	PARTICIPANT	\N	PRESENT	0
738222	738221	14259Y	PARTICIPANT	\N	PRESENT	0
738226	738224	99004R	PARTICIPANT	\N	PRESENT	0
738228	738227	11027H	PARTICIPANT	\N	PRESENT	0
738230	738229	11031D	PARTICIPANT	\N	PRESENT	0
738232	738231	20024T	PARTICIPANT	\N	PRESENT	0
738233	738231	20106U	PARTICIPANT	\N	PRESENT	0
738234	738231	12016W	PARTICIPANT	\N	PRESENT	0
738236	738235	08015R	PARTICIPANT	\N	PRESENT	0
738238	738237	20120S	PARTICIPANT	\N	PRESENT	0
738239	738237	04045F	PARTICIPANT	\N	PRESENT	0
738240	738022	14229S	PARTICIPANT	\N	PRESENT	0
738241	738023	14229S	PARTICIPANT	\N	PRESENT	0
738248	738020	08012N	PARTICIPANT	\N	PRESENT	0
738251	738242	08012N	PARTICIPANT	\N	PRESENT	0
738253	738024	19621T	PARTICIPANT	\N	PRESENT	0
738254	738024	14030Q	PARTICIPANT	\N	PRESENT	0
738255	738024	14109K	PARTICIPANT	\N	PRESENT	0
738256	738024	20180F	PARTICIPANT	\N	PRESENT	0
738258	738257	04070G	PARTICIPANT	\N	PRESENT	0
738340	738339	20136B	PARTICIPANT	\N	PRESENT	0
738342	738341	19503N	PARTICIPANT	\N	PRESENT	0
738376	738375	14225N	PARTICIPANT	\N	PRESENT	0
738377	738375	11026G	PARTICIPANT	\N	PRESENT	0
738378	738375	12041X	PARTICIPANT	\N	PRESENT	0
738379	738375	19647E	PARTICIPANT	\N	PRESENT	0
738756	737724	14213J	PARTICIPANT	\N	PRESENT	0
738758	738571	19701S	PARTICIPANT	\N	EXCUSE	0
738761	737724	14195A	PARTICIPANT	\N	PRESENT	0
738762	737724	04092N	PARTICIPANT	\N	PRESENT	0
738765	737724	20130U	PARTICIPANT	\N	PRESENT	0
738766	737724	19683J	PARTICIPANT	\N	PRESENT	0
738767	737724	11031D	PARTICIPANT	\N	PRESENT	0
738768	737724	19691J	PARTICIPANT	\N	PRESENT	0
738770	737724	19679N	PARTICIPANT	\N	PRESENT	0
738771	737724	19553Y	PARTICIPANT	\N	PRESENT	0
738772	737724	10006L	PRESIDENT	0	PRESENT	0
738773	737724	20090E	PARTICIPANT	\N	PRESENT	0
738774	737724	19569H	PARTICIPANT	\N	PRESENT	0
738775	737724	14026U	PARTICIPANT	\N	PRESENT	0
738776	737724	19703U	PARTICIPANT	\N	PRESENT	0
738777	737724	19723Y	PARTICIPANT	\N	PRESENT	0
738778	737724	14217N	PARTICIPANT	\N	PRESENT	0
738779	737724	19367Y	PARTICIPANT	\N	PRESENT	0
738781	737724	11103C	PARTICIPANT	\N	EXCUSE	0
738783	737724	11067R	PARTICIPANT	\N	PRESENT	0
738786	738729	19768N	PARTICIPANT	\N	PRESENT	0
738787	738729	20078J	PARTICIPANT	\N	PRESENT	0
738788	737724	11097X	PARTICIPANT	\N	PRESENT	0
738957	738956	19701S	PARTICIPANT	\N	PRESENT	0
739045	738361	19531S	PARTICIPANT	\N	PRESENT	0
739046	738361	19687N	PARTICIPANT	\N	PRESENT	0
739047	738361	11040E	PARTICIPANT	\N	PRESENT	0
739048	738361	08073C	PARTICIPANT	\N	PRESENT	0
739049	738361	20070A	PARTICIPANT	\N	PRESENT	0
739050	738361	14121F	PARTICIPANT	\N	PRESENT	0
739051	738361	19762G	PARTICIPANT	\N	PRESENT	0
739052	738361	11053K	PARTICIPANT	\N	PRESENT	0
739053	737731	19713W	PARTICIPANT	\N	PRESENT	0
739054	737731	19723Y	PARTICIPANT	\N	PRESENT	0
739055	737731	20266L	PARTICIPANT	\N	PRESENT	0
739056	737731	19553Y	PARTICIPANT	\N	PRESENT	0
739057	737731	20040T	PARTICIPANT	\N	PRESENT	0
739058	737731	19691J	PARTICIPANT	\N	PRESENT	0
739059	738361	08009T	PARTICIPANT	\N	PRESENT	0
739060	738361	20036X	PARTICIPANT	\N	EXCUSE	0
739061	738361	20050V	PARTICIPANT	\N	EXCUSE	0
739062	737731	20066E	PARTICIPANT	\N	PRESENT	0
739063	738361	08034U	PARTICIPANT	\N	PRESENT	0
739064	738361	19741B	PARTICIPANT	\N	PRESENT	0
739065	738017	19543W	PARTICIPANT	\N	PRESENT	0
739066	738017	14259Y	PARTICIPANT	\N	PRESENT	0
739067	737731	14026U	PARTICIPANT	\N	PRESENT	0
739068	737731	19683J	PARTICIPANT	\N	PRESENT	0
739069	735924	19766L	PARTICIPANT	\N	PRESENT	0
739070	735924	04070G	PARTICIPANT	\N	PRESENT	0
739071	735924	19699S	PARTICIPANT	\N	PRESENT	0
739072	735924	19533U	PARTICIPANT	\N	PRESENT	0
739073	735924	04033B	PARTICIPANT	\N	PRESENT	0
739074	735924	20098N	PARTICIPANT	\N	PRESENT	0
739075	735924	19573D	PARTICIPANT	\N	PRESENT	0
739076	735924	20112S	PARTICIPANT	\N	PRESENT	0
739077	735924	08012N	PARTICIPANT	\N	PRESENT	0
716645	702225	18083K	PARTICIPANT	\N	PRESENT	0
716646	702225	20032T	PARTICIPANT	\N	PRESENT	0
716647	702225	14031R	PARTICIPANT	\N	PRESENT	0
716648	702225	19251M	PARTICIPANT	\N	PRESENT	0
716649	702225	14219Q	PRESIDENT	0	PRESENT	0
716650	702225	19745F	PARTICIPANT	\N	PRESENT	0
716651	702225	17367Q	PARTICIPANT	\N	PRESENT	0
716652	702225	19333N	PARTICIPANT	\N	PRESENT	0
716653	702225	19701S	PARTICIPANT	\N	PRESENT	0
716654	702225	19503N	PARTICIPANT	\N	PRESENT	0
716655	702225	19525U	PARTICIPANT	\N	PRESENT	0
716656	702225	19599P	PARTICIPANT	\N	PRESENT	0
716657	702225	20100N	PARTICIPANT	\N	PRESENT	0
716658	702225	20024T	PARTICIPANT	\N	PRESENT	0
716659	702225	20102Q	PARTICIPANT	\N	PRESENT	0
716660	702225	11101A	PARTICIPANT	\N	PRESENT	0
716661	702225	19820Y	PARTICIPANT	\N	PRESENT	0
718566	718557	19760E	PARTICIPANT	\N	PRESENT	0
718567	718558	19760E	PARTICIPANT	\N	PRESENT	0
718568	718560	19760E	PARTICIPANT	\N	PRESENT	0
718569	718561	19760E	PARTICIPANT	\N	PRESENT	0
718571	718562	19760E	PARTICIPANT	\N	PRESENT	0
718572	718563	19760E	PARTICIPANT	\N	PRESENT	0
718575	718564	19367Y	PARTICIPANT	\N	PRESENT	0
718576	718564	14213J	PARTICIPANT	\N	PRESENT	0
718577	718564	11067R	PARTICIPANT	\N	PRESENT	0
718578	718564	19798U	PARTICIPANT	\N	PRESENT	0
718580	718565	19367Y	PARTICIPANT	\N	PRESENT	0
718581	718565	14213J	PARTICIPANT	\N	PRESENT	0
718583	718565	11067R	PARTICIPANT	\N	PRESENT	0
718604	718540	19643A	PARTICIPANT	\N	EXCUSE	0
718638	718618	19631V	PARTICIPANT	\N	PRESENT	0
718639	718618	19768N	PARTICIPANT	\N	PRESENT	0
718640	718618	19349W	PARTICIPANT	\N	PRESENT	0
719904	718667	19593H	PARTICIPANT	\N	PRESENT	0
719905	718667	10015M	PARTICIPANT	\N	PRESENT	0
719906	718667	19681G	PARTICIPANT	\N	EXCUSE	0
719907	718667	20104S	PARTICIPANT	\N	EXCUSE	0
719908	718667	14073Q	PARTICIPANT	\N	EXCUSE	0
719923	719922	20100N	PARTICIPANT	\N	PRESENT	0
719924	719922	14331P	PARTICIPANT	\N	PRESENT	0
719925	719922	11083R	PARTICIPANT	\N	PRESENT	0
719931	719929	14123H	PARTICIPANT	\N	PRESENT	1
719932	719930	14123H	PARTICIPANT	\N	PRESENT	0
719943	718888	20094J	PARTICIPANT	\N	PRESENT	0
719944	718888	19820Y	PARTICIPANT	\N	PRESENT	0
719945	718888	14169X	PRESIDENT	1	PRESENT	0
719946	718888	14237S	PARTICIPANT	\N	PRESENT	0
719948	718888	05012A	PRESIDENT	0	PRESENT	0
719949	718888	20914V	PARTICIPANT	\N	PRESENT	0
720113	720110	19691J	PARTICIPANT	\N	PRESENT	0
720114	720110	14281W	PARTICIPANT	\N	PRESENT	0
720115	720109	20090E	PARTICIPANT	\N	PRESENT	0
720116	720109	19691J	PARTICIPANT	\N	PRESENT	0
720117	720109	14281W	PARTICIPANT	\N	PRESENT	0
720118	720109	19798U	PARTICIPANT	\N	PRESENT	0
720119	720111	19691J	PARTICIPANT	\N	PRESENT	0
720120	720111	20090E	PARTICIPANT	\N	PRESENT	0
720121	720111	14281W	PARTICIPANT	\N	PRESENT	0
720122	720112	19691J	PARTICIPANT	\N	PRESENT	0
720123	720112	20090E	PARTICIPANT	\N	PRESENT	0
720124	720112	14281W	PARTICIPANT	\N	PRESENT	0
720125	720112	19798U	PARTICIPANT	\N	PRESENT	0
720153	720152	20136B	PARTICIPANT	\N	PRESENT	0
720156	720155	20136B	PARTICIPANT	\N	PRESENT	0
720158	720157	20136B	PARTICIPANT	\N	PRESENT	0
720159	720157	20100N	PARTICIPANT	\N	PRESENT	0
720161	720160	20136B	PARTICIPANT	\N	PRESENT	0
720162	720160	20100N	PARTICIPANT	\N	PRESENT	0
720164	720163	20136B	PARTICIPANT	\N	PRESENT	0
720165	720163	20100N	PARTICIPANT	\N	PRESENT	0
720173	720172	08018U	PARTICIPANT	\N	PRESENT	0
720175	720172	14231L	PARTICIPANT	\N	PRESENT	0
720176	720172	19631V	PARTICIPANT	\N	PRESENT	0
720177	720172	14059S	PARTICIPANT	\N	PRESENT	0
720178	720172	20024T	PARTICIPANT	\N	PRESENT	0
720183	718399	05008E	PARTICIPANT	\N	EXCUSE	0
720184	719776	05008E	PARTICIPANT	\N	EXCUSE	0
720186	720185	19741B	PARTICIPANT	\N	PRESENT	0
720188	720187	19741B	PARTICIPANT	\N	PRESENT	0
720190	720189	19741B	PARTICIPANT	\N	PRESENT	0
720299	720296	14030Q	PARTICIPANT	\N	PRESENT	0
720300	720296	19643A	PARTICIPANT	\N	PRESENT	0
720301	720296	20152B	PARTICIPANT	\N	PRESENT	0
720302	720296	17737W	PARTICIPANT	\N	EXCUSE	0
720303	720296	20134Y	PARTICIPANT	\N	PRESENT	0
720305	720296	11083R	PARTICIPANT	\N	PRESENT	0
720306	720296	20068G	PARTICIPANT	\N	EXCUSE	0
720307	720296	14179A	PARTICIPANT	\N	PRESENT	0
720308	720296	14251Q	PARTICIPANT	\N	PRESENT	0
720309	720296	04070G	PARTICIPANT	\N	PRESENT	0
720311	720296	19593H	PARTICIPANT	\N	PRESENT	0
720312	720296	14147R	PARTICIPANT	\N	EXCUSE	0
720314	720296	20064C	PRESIDENT	0	PRESENT	0
721428	721427	20058E	PARTICIPANT	\N	PRESENT	1
721429	721427	14109K	PARTICIPANT	\N	PRESENT	1
724823	723232	19531S	PARTICIPANT	\N	EXCUSE	0
724835	723223	14189C	PARTICIPANT	\N	PRESENT	0
724838	723223	08034U	PARTICIPANT	\N	PRESENT	0
724839	723223	19531S	PARTICIPANT	\N	EXCUSE	0
725442	725441	19711U	PARTICIPANT	\N	PRESENT	0
725443	725441	20050V	PARTICIPANT	\N	PRESENT	0
728102	725567	19711U	PARTICIPANT	\N	PRESENT	0
728103	725567	14251Q	PARTICIPANT	\N	PRESENT	0
728110	728040	20248J	PARTICIPANT	\N	PRESENT	0
728111	728040	11031D	PARTICIPANT	\N	PRESENT	0
728112	728040	10006L	PARTICIPANT	\N	PRESENT	0
728113	728040	19697Q	PARTICIPANT	\N	PRESENT	0
728114	728040	17965H	PARTICIPANT	\N	PRESENT	0
728115	728040	04045F	PARTICIPANT	\N	PRESENT	0
728116	728040	20130U	PARTICIPANT	\N	PRESENT	0
728117	728040	14030Q	PARTICIPANT	\N	PRESENT	0
728118	728040	19553Y	PARTICIPANT	\N	PRESENT	0
728119	728040	20090E	PARTICIPANT	\N	PRESENT	0
728120	728040	19657G	PARTICIPANT	\N	PRESENT	0
728121	728040	04057K	PARTICIPANT	\N	PRESENT	0
728123	728040	11012A	PARTICIPANT	\N	PRESENT	0
728124	728040	20266L	PARTICIPANT	\N	PRESENT	0
728125	728040	04043D	PARTICIPANT	\N	PRESENT	0
728126	728040	14215L	PARTICIPANT	\N	PRESENT	0
728127	728040	19741B	PARTICIPANT	\N	PRESENT	0
728128	728040	14169X	PARTICIPANT	\N	PRESENT	0
728129	728040	08010L	PARTICIPANT	\N	PRESENT	0
728132	728040	11083R	PARTICIPANT	\N	PRESENT	0
729786	728221	08015R	PARTICIPANT	\N	PRESENT	0
729787	728221	19768N	PARTICIPANT	\N	PRESENT	0
729788	728221	04043D	PARTICIPANT	\N	PRESENT	0
729789	728221	05008E	PARTICIPANT	\N	PRESENT	0
729790	728221	20028X	PARTICIPANT	\N	PRESENT	0
729791	728221	11067R	PARTICIPANT	\N	PRESENT	0
729792	728221	11033F	PARTICIPANT	\N	PRESENT	0
729793	728221	20018V	PARTICIPANT	\N	PRESENT	0
729794	728221	17965H	PARTICIPANT	\N	PRESENT	0
729795	728221	19503N	PARTICIPANT	\N	PRESENT	0
729796	728221	08056B	PARTICIPANT	\N	PRESENT	0
729797	728221	14251Q	PARTICIPANT	\N	PRESENT	0
729798	728221	14357A	PARTICIPANT	\N	PRESENT	0
729799	728221	11054L	PARTICIPANT	\N	PRESENT	0
729800	728221	20152B	PARTICIPANT	\N	PRESENT	0
729801	728221	11045K	PARTICIPANT	\N	PRESENT	0
729802	728221	20084G	PARTICIPANT	\N	PRESENT	0
729803	728221	20126Y	PARTICIPANT	\N	PRESENT	0
729804	728221	01062T	PARTICIPANT	\N	PRESENT	0
729805	728221	20054A	PARTICIPANT	\N	PRESENT	0
729806	728221	11041F	PARTICIPANT	\N	PRESENT	0
729807	728221	11066Q	PARTICIPANT	\N	PRESENT	0
729808	728221	20020P	PARTICIPANT	\N	PRESENT	0
729809	728221	19543W	PARTICIPANT	\N	PRESENT	0
729810	728221	14030Q	PARTICIPANT	\N	PRESENT	0
729811	728221	07033P	PARTICIPANT	\N	PRESENT	0
729812	728221	20042V	PARTICIPANT	\N	PRESENT	0
729813	728221	14217N	PARTICIPANT	\N	PRESENT	0
729814	728221	14089Y	PARTICIPANT	\N	PRESENT	0
729815	728221	14255U	PARTICIPANT	\N	PRESENT	0
729816	728221	11053K	PARTICIPANT	\N	PRESENT	0
729817	728221	19367Y	PARTICIPANT	\N	PRESENT	0
729818	728221	14237S	PARTICIPANT	\N	PRESENT	0
729819	728221	20144B	PARTICIPANT	\N	PRESENT	0
729820	728221	19701S	PARTICIPANT	\N	PRESENT	0
729821	728221	14327T	PARTICIPANT	\N	PRESENT	0
729822	728221	17229F	PARTICIPANT	\N	PRESENT	0
716696	716609	11101A	PARTICIPANT	\N	PRESENT	0
716704	716703	14038Y	PARTICIPANT	\N	PRESENT	0
716705	716703	20026V	PARTICIPANT	\N	PRESENT	1
716709	716703	20044X	PARTICIPANT	\N	PRESENT	0
716707	716703	14179A	PARTICIPANT	\N	PRESENT	0
716708	716703	08028W	PARTICIPANT	\N	PRESENT	0
716710	716703	14169X	PARTICIPANT	\N	PRESENT	0
716711	716703	20128B	PARTICIPANT	\N	PRESENT	0
716712	716703	19798U	PARTICIPANT	\N	PRESENT	0
716713	716703	20042V	PARTICIPANT	\N	PRESENT	0
717238	717237	20056C	PARTICIPANT	\N	PRESENT	0
717239	717237	04070G	PARTICIPANT	\N	PRESENT	0
717240	717237	19593H	PARTICIPANT	\N	PRESENT	0
717244	717243	20112S	PARTICIPANT	\N	PRESENT	1
717245	717243	19643A	PARTICIPANT	\N	PRESENT	0
717246	717243	19735D	PARTICIPANT	\N	PRESENT	0
718403	718340	11053K	PARTICIPANT	\N	PRESENT	0
718405	718404	95063L	PARTICIPANT	\N	PRESENT	0
718406	718404	19669L	PARTICIPANT	\N	PRESENT	0
734414	732767	19766L	PARTICIPANT	\N	PRESENT	0
734415	732767	20020P	PARTICIPANT	\N	PRESENT	0
734416	732767	17229F	PARTICIPANT	\N	PRESENT	0
734417	732767	19669L	PARTICIPANT	\N	PRESENT	0
734418	732767	01062T	PARTICIPANT	\N	PRESENT	0
734419	732767	19647E	PARTICIPANT	\N	PRESENT	0
734421	732767	11054L	PARTICIPANT	\N	PRESENT	0
734422	732767	19413M	PARTICIPANT	\N	PRESENT	0
734423	732767	19649G	PARTICIPANT	\N	PRESENT	0
734424	732767	04059M	PARTICIPANT	\N	PRESENT	0
734425	732767	19683J	PARTICIPANT	\N	PRESENT	0
734426	732767	14207L	PARTICIPANT	\N	PRESENT	0
734427	732767	01025N	PARTICIPANT	\N	PRESENT	0
734428	732767	20088L	PARTICIPANT	\N	PRESENT	0
734429	732767	11033F	PARTICIPANT	\N	PRESENT	0
734430	732767	20084G	PARTICIPANT	\N	PRESENT	0
734431	732767	19739H	PARTICIPANT	\N	PRESENT	0
734432	732767	20144B	PARTICIPANT	\N	PRESENT	0
734433	732767	98022P	PARTICIPANT	\N	PRESENT	0
734434	732767	19717B	PARTICIPANT	\N	PRESENT	0
734435	732767	11012A	PARTICIPANT	\N	PRESENT	0
734444	734443	08012N	PARTICIPANT	\N	PRESENT	0
734445	734443	19527W	PARTICIPANT	\N	PRESENT	1
734446	732767	19715Y	PARTICIPANT	\N	PRESENT	0
734447	732767	04085P	PARTICIPANT	\N	PRESENT	0
734448	732767	19687N	PARTICIPANT	\N	PRESENT	0
734449	732767	19760E	PARTICIPANT	\N	PRESENT	0
734450	732767	19695N	PARTICIPANT	\N	PRESENT	0
734451	732767	19565D	PARTICIPANT	\N	PRESENT	0
734452	732767	11040E	PARTICIPANT	\N	PRESENT	0
734453	732767	19711U	PARTICIPANT	\N	PRESENT	0
734454	732767	11077T	PARTICIPANT	\N	PRESENT	0
734455	732767	20102Q	PARTICIPANT	\N	PRESENT	0
734456	732767	20046A	PARTICIPANT	\N	PRESENT	0
734457	732767	19679N	PARTICIPANT	\N	PRESENT	0
734458	732767	20076G	PARTICIPANT	\N	PRESENT	0
734459	732767	11074Q	PARTICIPANT	\N	PRESENT	0
734460	732767	12016W	PARTICIPANT	\N	PRESENT	0
734461	732767	20078J	PARTICIPANT	\N	PRESENT	0
734462	732767	14257W	PARTICIPANT	\N	PRESENT	0
734463	732767	01058X	PARTICIPANT	\N	PRESENT	0
734464	732767	17779H	PARTICIPANT	\N	PRESENT	0
734465	732767	14021P	PARTICIPANT	\N	PRESENT	0
734466	732767	20044X	PARTICIPANT	\N	PRESENT	0
734467	732767	19489J	PARTICIPANT	\N	PRESENT	0
734468	732767	19723Y	PARTICIPANT	\N	PRESENT	0
734469	732767	14001X	PARTICIPANT	\N	PRESENT	0
734470	732767	20038A	PARTICIPANT	\N	PRESENT	0
734471	732767	20058E	PARTICIPANT	\N	PRESENT	0
734472	732767	17367Q	PARTICIPANT	\N	PRESENT	0
734473	732767	20086J	PARTICIPANT	\N	PRESENT	0
734474	732767	20114U	PARTICIPANT	\N	PRESENT	0
734475	732767	19573D	PARTICIPANT	\N	PRESENT	0
734476	732767	11067R	PARTICIPANT	\N	PRESENT	0
734477	732767	14097Y	PARTICIPANT	\N	PRESENT	0
734478	732767	19515S	PARTICIPANT	\N	PRESENT	0
734479	732767	14031R	PARTICIPANT	\N	PRESENT	0
734480	732767	19399H	PARTICIPANT	\N	PRESENT	0
734481	732767	19741B	PARTICIPANT	\N	PRESENT	0
734482	732767	11066Q	PARTICIPANT	\N	PRESENT	0
734483	732767	19673G	PARTICIPANT	\N	PRESENT	0
734484	732767	14281W	PARTICIPANT	\N	PRESENT	0
734485	732767	20980G	PARTICIPANT	\N	PRESENT	0
734486	732767	08012N	PARTICIPANT	\N	PRESENT	0
734487	732767	07029T	PARTICIPANT	\N	PRESENT	0
734488	732767	11115U	PARTICIPANT	\N	PRESENT	0
734489	732767	19820Y	PARTICIPANT	\N	PRESENT	0
734490	732767	20096L	PARTICIPANT	\N	PRESENT	0
734491	732767	20080C	PARTICIPANT	\N	PRESENT	0
734492	732767	19729F	PARTICIPANT	\N	PRESENT	0
734493	732767	19725B	PARTICIPANT	\N	PRESENT	0
734494	732767	08015R	PARTICIPANT	\N	PRESENT	0
734495	732767	20108W	PARTICIPANT	\N	PRESENT	0
734496	732767	19503N	PARTICIPANT	\N	PRESENT	0
734497	732767	19768N	PARTICIPANT	\N	PRESENT	0
734498	732767	20018V	PARTICIPANT	\N	PRESENT	0
734499	732767	20140W	PARTICIPANT	\N	PRESENT	0
734500	732767	11110B	PARTICIPANT	\N	PRESENT	0
734501	732767	08047A	PARTICIPANT	\N	PRESENT	0
734502	732767	20138D	PARTICIPANT	\N	PRESENT	0
734503	732767	14121F	PARTICIPANT	\N	PRESENT	0
734504	732767	19954N	PARTICIPANT	\N	PRESENT	0
734505	732767	14191V	PARTICIPANT	\N	PRESENT	0
734506	732767	20030R	PARTICIPANT	\N	PRESENT	0
734507	732767	01057W	PARTICIPANT	\N	PRESENT	0
734508	732767	20064C	PARTICIPANT	\N	PRESENT	0
734509	732767	20094J	PARTICIPANT	\N	PRESENT	0
734510	732767	14253S	PARTICIPANT	\N	PRESENT	0
734511	732767	19251M	PARTICIPANT	\N	PRESENT	0
734512	732767	19709B	PARTICIPANT	\N	PRESENT	0
734513	732767	05008E	PARTICIPANT	\N	PRESENT	0
734514	732767	20024T	PARTICIPANT	\N	PRESENT	0
734515	732767	20028X	PARTICIPANT	\N	PRESENT	0
734516	732767	99004R	PARTICIPANT	\N	PRESENT	0
734517	732767	20264J	PARTICIPANT	\N	PRESENT	0
734518	732767	20068G	PARTICIPANT	\N	PRESENT	0
734519	732767	10015M	PARTICIPANT	\N	PRESENT	0
734520	732767	19643A	PARTICIPANT	\N	PRESENT	0
734521	732767	17965H	PARTICIPANT	\N	PRESENT	0
734522	732767	14151M	PARTICIPANT	\N	PRESENT	0
734523	732767	11043H	PARTICIPANT	\N	PRESENT	0
734524	732767	12041X	PARTICIPANT	\N	PRESENT	0
734525	732767	14123H	PARTICIPANT	\N	PRESENT	0
734526	732767	11090Q	PARTICIPANT	\N	PRESENT	0
734527	732767	11056N	PARTICIPANT	\N	PRESENT	0
734528	732767	20914V	PARTICIPANT	\N	PRESENT	0
734529	732767	20130U	PARTICIPANT	\N	PRESENT	0
734530	732767	08069G	PARTICIPANT	\N	PRESENT	0
734531	732767	19347U	PARTICIPANT	\N	PRESENT	0
734532	732767	18083K	PARTICIPANT	\N	PRESENT	0
734533	732767	20100N	PARTICIPANT	\N	PRESENT	0
734534	732767	04042C	PARTICIPANT	\N	PRESENT	0
734535	732767	20142Y	PARTICIPANT	\N	PRESENT	0
734536	732767	20134Y	PARTICIPANT	\N	PRESENT	0
734537	732767	19575F	PARTICIPANT	\N	PRESENT	0
734538	732767	08061X	PARTICIPANT	\N	PRESENT	0
734539	732767	14026U	PARTICIPANT	\N	PRESENT	0
734540	732767	11072N	PARTICIPANT	\N	PRESENT	0
734541	732767	19747H	PARTICIPANT	\N	PRESENT	0
734542	732767	19301E	PARTICIPANT	\N	PRESENT	0
734543	732767	19415P	PARTICIPANT	\N	PRESENT	0
734544	732767	95063L	PARTICIPANT	\N	PRESENT	0
734545	732767	04033B	PARTICIPANT	\N	PRESENT	0
734546	732767	08010L	PARTICIPANT	\N	PRESENT	0
734547	732767	19591F	PARTICIPANT	\N	PRESENT	0
734548	732767	11048N	PARTICIPANT	\N	PRESENT	0
734549	732767	11083R	PARTICIPANT	\N	PRESENT	0
734550	732767	04047H	PARTICIPANT	\N	PRESENT	0
734551	732767	20106U	PARTICIPANT	\N	PRESENT	0
734552	732767	04092N	PARTICIPANT	\N	PRESENT	0
734553	732767	14133K	PARTICIPANT	\N	PRESENT	0
734554	732767	14187A	PARTICIPANT	\N	PRESENT	0
734555	732767	14071N	PARTICIPANT	\N	PRESENT	0
734556	732767	14069U	PARTICIPANT	\N	PRESENT	0
734557	732767	19637C	PARTICIPANT	\N	PRESENT	0
734558	732767	14053L	PARTICIPANT	\N	PRESENT	0
734559	732767	19697Q	PARTICIPANT	\N	PRESENT	0
734560	732767	19421M	PARTICIPANT	\N	PRESENT	0
734561	732767	20146D	PARTICIPANT	\N	PRESENT	0
734562	732767	19349W	PARTICIPANT	\N	PRESENT	0
734563	732767	14215L	PARTICIPANT	\N	PRESENT	0
734564	732767	20150Y	PARTICIPANT	\N	PRESENT	0
722177	720148	05012A	PARTICIPANT	\N	PRESENT	0
722178	720148	19820Y	PARTICIPANT	\N	PRESENT	0
722179	720148	20070A	PARTICIPANT	\N	PRESENT	0
722287	720148	20094J	PARTICIPANT	\N	PRESENT	0
722289	720148	20914V	PARTICIPANT	\N	PRESENT	0
725937	725936	08010L	PARTICIPANT	\N	PRESENT	0
723144	722791	20134Y	PARTICIPANT	\N	PRESENT	0
723145	722791	11033F	PARTICIPANT	\N	PRESENT	0
723146	722791	14229S	PARTICIPANT	\N	PRESENT	0
723147	722791	20036X	PARTICIPANT	\N	PRESENT	0
725939	725938	14173T	PARTICIPANT	\N	PRESENT	0
723149	722791	20082E	PARTICIPANT	\N	PRESENT	0
723150	722791	20264J	PARTICIPANT	\N	PRESENT	0
723151	722791	19527W	PARTICIPANT	\N	PRESENT	0
723152	722791	19621T	PARTICIPANT	\N	PRESENT	0
723153	722791	19651A	PARTICIPANT	\N	PRESENT	0
727892	725880	97011G	PARTICIPANT	\N	PRESENT	0
727893	725827	19333N	PARTICIPANT	\N	PRESENT	0
723156	722791	19703U	PARTICIPANT	\N	PRESENT	0
723157	722791	19758L	PARTICIPANT	\N	PRESENT	0
723158	722791	14069U	PARTICIPANT	\N	PRESENT	0
727894	725827	14327T	PARTICIPANT	\N	PRESENT	0
723160	722791	20132W	PARTICIPANT	\N	PRESENT	0
723161	722791	19711U	PARTICIPANT	\N	PRESENT	0
723162	722791	19699S	PARTICIPANT	\N	PRESENT	0
727895	725827	20090E	PARTICIPANT	\N	PRESENT	0
723164	722791	01024M	PARTICIPANT	\N	PRESENT	0
727896	725827	19735D	PARTICIPANT	\N	PRESENT	0
727897	725827	14151M	PARTICIPANT	\N	PRESENT	0
723167	722791	20056C	PARTICIPANT	\N	PRESENT	0
727898	725827	14215L	PARTICIPANT	\N	PRESENT	0
727899	725827	19758L	PARTICIPANT	\N	PRESENT	0
723170	722791	20026V	PARTICIPANT	\N	PRESENT	0
723171	722791	20062A	PARTICIPANT	\N	PRESENT	0
723172	722791	19399H	PARTICIPANT	\N	PRESENT	0
727900	725827	14257W	PARTICIPANT	\N	PRESENT	0
723174	722791	14053L	PARTICIPANT	\N	PRESENT	0
727901	725827	20084G	PARTICIPANT	\N	PRESENT	0
727902	725880	11067R	PARTICIPANT	\N	PRESENT	0
723186	722791	20044X	PARTICIPANT	\N	PRESENT	0
727903	725880	14071N	PARTICIPANT	\N	PRESENT	0
727904	725827	14281W	PARTICIPANT	\N	PRESENT	0
727907	725880	14207L	PARTICIPANT	\N	PRESENT	0
723181	722791	20034V	PARTICIPANT	\N	PRESENT	0
727912	725811	20104S	PARTICIPANT	\N	PRESENT	0
723183	722791	19383Y	PARTICIPANT	\N	PRESENT	0
723184	722791	19507S	PARTICIPANT	\N	PRESENT	0
723190	723059	17229F	PARTICIPANT	\N	PRESENT	0
727914	725811	20100N	PARTICIPANT	\N	EXCUSE	0
727916	725811	14026U	PARTICIPANT	\N	PRESENT	0
723189	723059	11053K	PARTICIPANT	\N	PRESENT	0
723191	723059	20102Q	PARTICIPANT	\N	EXCUSE	0
723194	722791	19747H	PARTICIPANT	\N	PRESENT	0
727917	725811	19725B	PARTICIPANT	\N	PRESENT	0
727918	725811	12041X	PARTICIPANT	\N	PRESENT	0
723198	722791	19593H	PARTICIPANT	\N	PRESENT	0
723141	722791	19719D	PARTICIPANT	\N	PRESENT	0
723142	722791	20138D	PARTICIPANT	\N	PRESENT	0
727919	725811	19441R	PARTICIPANT	\N	PRESENT	0
727920	725811	04045F	PARTICIPANT	\N	PRESENT	0
727921	725811	14331P	PARTICIPANT	\N	PRESENT	0
723206	722791	19611R	PARTICIPANT	\N	PRESENT	0
725933	725932	08010L	PARTICIPANT	\N	PRESENT	0
725935	725934	08010L	PARTICIPANT	\N	PRESENT	0
727922	725811	14169X	PARTICIPANT	\N	PRESENT	0
727923	725811	04070G	PARTICIPANT	\N	PRESENT	0
727924	725811	10015M	PARTICIPANT	\N	EXCUSE	0
727925	725811	19563B	PARTICIPANT	\N	EXCUSE	0
727926	725811	14033T	PARTICIPANT	\N	PRESENT	0
727927	725811	20286Q	PARTICIPANT	\N	EXCUSE	0
727928	725880	04047H	PARTICIPANT	\N	PRESENT	0
727930	725880	19511N	PARTICIPANT	\N	PRESENT	0
727931	725827	04045F	PARTICIPANT	\N	PRESENT	0
727932	725880	20082E	PARTICIPANT	\N	PRESENT	0
727933	725880	19651A	PARTICIPANT	\N	PRESENT	0
727934	725880	19441R	PARTICIPANT	\N	PRESENT	0
727936	725827	14033T	PARTICIPANT	\N	PRESENT	0
727937	725880	19697Q	PARTICIPANT	\N	PRESENT	0
727940	725880	11012A	PARTICIPANT	\N	PRESENT	0
727941	725880	19515S	PARTICIPANT	\N	PRESENT	0
727942	725880	04085P	PARTICIPANT	\N	PRESENT	0
727943	725809	19735D	PRESIDENT	0	PRESENT	0
727944	725809	17965H	PARTICIPANT	\N	PRESENT	0
727945	725809	11031D	PARTICIPANT	\N	PRESENT	0
727946	725880	20104S	PARTICIPANT	\N	PRESENT	0
727947	725880	20090E	PARTICIPANT	\N	PRESENT	0
727948	725880	19553Y	PARTICIPANT	\N	PRESENT	0
727949	725880	14021P	PARTICIPANT	\N	PRESENT	0
727950	725880	20130U	PARTICIPANT	\N	PRESENT	0
727962	725880	20266L	PARTICIPANT	\N	PRESENT	0
727963	725880	11027H	PARTICIPANT	\N	PRESENT	0
728011	725881	10006L	PARTICIPANT	\N	PRESENT	0
728013	725881	12041X	PARTICIPANT	\N	PRESENT	0
728014	725881	20266L	PARTICIPANT	\N	PRESENT	0
728015	725881	20130U	PARTICIPANT	\N	PRESENT	0
728016	725881	11012A	PARTICIPANT	\N	PRESENT	0
728017	725881	04057K	PARTICIPANT	\N	PRESENT	0
728018	725881	19553Y	PARTICIPANT	\N	PRESENT	0
728019	725881	20090E	PARTICIPANT	\N	PRESENT	0
728020	725881	20104S	PARTICIPANT	\N	PRESENT	0
728021	725881	97011G	PARTICIPANT	\N	PRESENT	0
728022	725881	19651A	PARTICIPANT	\N	PRESENT	0
728023	725881	11067R	PARTICIPANT	\N	PRESENT	0
728024	725881	04085P	PARTICIPANT	\N	PRESENT	0
728025	725881	04045F	PARTICIPANT	\N	PRESENT	0
728026	725881	20248J	PARTICIPANT	\N	PRESENT	0
728027	725881	17965H	PARTICIPANT	\N	PRESENT	0
728029	725881	14026U	PARTICIPANT	\N	PRESENT	0
728038	725881	11031D	PARTICIPANT	\N	PRESENT	0
728039	725881	19782L	PARTICIPANT	\N	PRESENT	0
728087	725567	20064C	PRESIDENT	0	PRESENT	0
728088	725567	20152B	PRESIDENT	1	PRESENT	0
728089	725567	17737W	PARTICIPANT	\N	EXCUSE	0
728090	725567	14147R	PARTICIPANT	\N	EXCUSE	0
728091	725809	20024T	PARTICIPANT	\N	EXCUSE	0
728360	728359	14225N	PARTICIPANT	\N	PRESENT	0
728361	728359	11048N	PARTICIPANT	\N	PRESENT	0
728362	728359	08034U	PARTICIPANT	\N	PRESENT	0
728363	728359	14327T	PARTICIPANT	\N	PRESENT	0
728364	728359	19647E	PARTICIPANT	\N	PRESENT	0
728007	725881	11045K	PARTICIPANT	\N	PRESENT	0
728010	725881	19697Q	PARTICIPANT	\N	PRESENT	0
728366	728365	14225N	PARTICIPANT	\N	PRESENT	0
728367	728365	11048N	PARTICIPANT	\N	PRESENT	0
728368	728365	08034U	PARTICIPANT	\N	PRESENT	0
728369	728365	14327T	PARTICIPANT	\N	PRESENT	0
728370	728365	19647E	PARTICIPANT	\N	PRESENT	0
728374	728371	14225N	PARTICIPANT	\N	PRESENT	0
728375	728371	11048N	PARTICIPANT	\N	PRESENT	0
728082	728040	12041X	PARTICIPANT	\N	PRESENT	0
728083	725567	19593H	PARTICIPANT	\N	PRESENT	0
728084	725567	04070G	PARTICIPANT	\N	PRESENT	0
728376	728371	08034U	PARTICIPANT	\N	PRESENT	0
728086	725567	14030Q	PARTICIPANT	\N	PRESENT	0
728377	728371	14327T	PARTICIPANT	\N	PRESENT	0
728378	728371	19647E	PARTICIPANT	\N	PRESENT	0
728380	728379	14225N	PARTICIPANT	\N	PRESENT	0
728381	728379	11048N	PARTICIPANT	\N	PRESENT	0
728382	728379	08034U	PARTICIPANT	\N	PRESENT	0
728383	728379	14327T	PARTICIPANT	\N	PRESENT	0
728384	728379	19647E	PARTICIPANT	\N	PRESENT	0
728386	728385	08010L	PARTICIPANT	\N	PRESENT	0
728388	728387	08010L	PARTICIPANT	\N	PRESENT	0
728390	728389	08010L	PARTICIPANT	\N	PRESENT	0
728392	728391	11074Q	PARTICIPANT	\N	PRESENT	0
728393	728391	19349W	PARTICIPANT	\N	PRESENT	0
728449	728448	19693L	PARTICIPANT	\N	PRESENT	0
728450	728448	01048V	PARTICIPANT	\N	PRESENT	0
728451	728448	19533U	PARTICIPANT	\N	PRESENT	0
728452	728448	04043D	PARTICIPANT	\N	EXCUSE	0
728453	728448	19735D	PARTICIPANT	\N	EXCUSE	0
728454	728448	20066E	PARTICIPANT	\N	EXCUSE	0
738426	738292	19725B	PRESIDENT	0	PRESENT	0
738427	738292	11031D	PARTICIPANT	\N	PRESENT	0
738428	738292	20066E	PRESIDENT	1	PRESENT	0
738429	738292	14213J	PARTICIPANT	\N	PRESENT	0
738442	738441	20056C	PARTICIPANT	\N	PRESENT	0
738443	738441	19593H	PARTICIPANT	\N	PRESENT	0
738764	738004	14121F	PARTICIPANT	\N	PRESENT	0
738769	738004	14001X	PARTICIPANT	\N	PRESENT	0
738790	738004	20052X	PARTICIPANT	\N	PRESENT	0
738782	738004	14123H	PARTICIPANT	\N	PRESENT	0
738784	738004	01024M	PARTICIPANT	\N	PRESENT	0
738785	738004	20048C	PARTICIPANT	\N	PRESENT	0
738843	738004	11097X	PARTICIPANT	\N	PRESENT	0
738791	738004	14031R	PARTICIPANT	\N	PRESENT	0
738792	738004	20102Q	PARTICIPANT	\N	PRESENT	0
738840	738004	20090E	PARTICIPANT	\N	PRESENT	0
738841	738004	11012A	PARTICIPANT	\N	PRESENT	0
738844	738004	20032T	PARTICIPANT	\N	PRESENT	0
738845	738004	19619A	PARTICIPANT	\N	PRESENT	0
738846	738004	14213J	PARTICIPANT	\N	PRESENT	0
738848	738004	19673G	PARTICIPANT	\N	PRESENT	0
738849	738004	14207L	PARTICIPANT	\N	PRESENT	0
738850	738004	19399H	PARTICIPANT	\N	PRESENT	0
738851	738004	20092G	PARTICIPANT	\N	PRESENT	0
738852	738004	14030Q	PARTICIPANT	\N	PRESENT	0
738853	738004	20298U	PARTICIPANT	\N	PRESENT	0
738909	738006	12028B	PARTICIPANT	\N	PRESENT	0
738910	738006	14255U	PARTICIPANT	\N	PRESENT	0
738911	738006	14249W	PARTICIPANT	\N	PRESENT	0
738912	738006	12041X	PARTICIPANT	\N	PRESENT	0
738913	738006	11064N	PARTICIPANT	\N	PRESENT	0
738914	738006	20072C	PARTICIPANT	\N	PRESENT	0
738915	738006	19347U	PARTICIPANT	\N	PRESENT	0
738916	738006	14055N	PARTICIPANT	\N	PRESENT	0
738917	738006	19669L	PARTICIPANT	\N	PRESENT	0
738918	738006	01062T	PARTICIPANT	\N	PRESENT	0
738919	738006	11054L	PARTICIPANT	\N	PRESENT	0
738920	738006	20064C	PARTICIPANT	\N	PRESENT	0
738921	738006	19503N	PARTICIPANT	\N	PRESENT	0
738922	738006	19565D	PARTICIPANT	\N	PRESENT	0
738923	738006	20100N	PARTICIPANT	\N	PRESENT	0
738924	738006	11066Q	PARTICIPANT	\N	PRESENT	0
738925	738006	14097Y	PARTICIPANT	\N	PRESENT	0
738926	738006	08061X	PARTICIPANT	\N	PRESENT	0
738927	738006	19349W	PARTICIPANT	\N	PRESENT	0
738928	738006	20038A	PARTICIPANT	\N	PRESENT	0
738929	738006	08047A	PARTICIPANT	\N	PRESENT	0
738930	738006	20090E	PARTICIPANT	\N	PRESENT	0
738931	738006	14187A	PARTICIPANT	\N	PRESENT	0
738932	738006	14193X	PARTICIPANT	\N	PRESENT	0
738933	738006	14021P	PARTICIPANT	\N	PRESENT	0
738934	738006	19415P	PARTICIPANT	\N	PRESENT	0
738935	738006	14147R	PARTICIPANT	\N	PRESENT	0
738936	738006	14205J	PARTICIPANT	\N	PRESENT	0
738937	738006	19441R	PARTICIPANT	\N	PRESENT	0
738938	738006	20042V	PARTICIPANT	\N	PRESENT	0
738939	738006	19387D	PARTICIPANT	\N	PRESENT	0
738940	738006	20104S	PARTICIPANT	\N	PRESENT	0
738941	738006	04033B	PARTICIPANT	\N	PRESENT	0
738942	738006	19713W	PARTICIPANT	\N	PRESENT	0
738943	738006	18083K	PARTICIPANT	\N	PRESENT	0
738944	738006	17023S	PARTICIPANT	\N	PRESENT	0
738945	738006	20034V	PARTICIPANT	\N	PRESENT	0
738946	738006	14073Q	PARTICIPANT	\N	PRESENT	0
738947	738006	11026G	PARTICIPANT	\N	PRESENT	0
738948	738006	14213J	PARTICIPANT	\N	PRESENT	0
738949	738006	19575F	PARTICIPANT	\N	PRESENT	0
738950	738006	20092G	PARTICIPANT	\N	PRESENT	0
738951	738006	20032T	PARTICIPANT	\N	PRESENT	0
738952	738006	19479G	PARTICIPANT	\N	PRESENT	0
738953	738006	14189C	PARTICIPANT	\N	PRESENT	0
738954	738006	20086J	PARTICIPANT	\N	PRESENT	0
738955	738006	19545Y	PARTICIPANT	\N	PRESENT	0
738958	738017	19725B	PARTICIPANT	\N	PRESENT	0
738959	738017	14053L	PARTICIPANT	\N	PRESENT	0
738960	738017	11056N	PARTICIPANT	\N	PRESENT	0
738961	738017	14111D	PARTICIPANT	\N	PRESENT	0
738962	738017	14069U	PARTICIPANT	\N	PRESENT	0
738963	738017	14215L	PRESIDENT	0	PRESENT	0
738907	738006	86034E	PARTICIPANT	\N	PRESENT	0
738908	738006	04042C	PARTICIPANT	\N	PRESENT	0
738964	738017	19581D	PARTICIPANT	\N	PRESENT	0
738965	738017	19673G	PARTICIPANT	\N	PRESENT	0
738966	738017	19729F	PARTICIPANT	\N	EXCUSE	0
738967	738017	04047H	PARTICIPANT	\N	EXCUSE	0
738968	738017	20074E	PARTICIPANT	\N	PRESENT	0
738969	738017	14001X	PARTICIPANT	\N	PRESENT	0
738970	738017	19447X	PARTICIPANT	\N	PRESENT	0
738971	738017	14231L	PARTICIPANT	\N	PRESENT	0
738972	738017	14089Y	PRESIDENT	1	PRESENT	0
738973	738017	19954N	PARTICIPANT	\N	PRESENT	0
738974	738017	95063L	PARTICIPANT	\N	PRESENT	0
738975	738017	19629C	PARTICIPANT	\N	PRESENT	0
738976	738017	14107H	PARTICIPANT	\N	PRESENT	0
738977	738017	14147R	PARTICIPANT	\N	PRESENT	0
738978	738017	20114U	PARTICIPANT	\N	PRESENT	0
738979	738017	14151M	PARTICIPANT	\N	PRESENT	0
738980	738017	11085T	PARTICIPANT	\N	PRESENT	0
738981	738017	19749K	PARTICIPANT	\N	PRESENT	0
738982	738017	11072N	PARTICIPANT	\N	PRESENT	0
738983	738017	19585H	PARTICIPANT	\N	PRESENT	0
738984	738017	07004J	PARTICIPANT	\N	PRESENT	0
738985	738017	04085P	PARTICIPANT	\N	PRESENT	0
738986	738361	11012A	PARTICIPANT	\N	PRESENT	0
738987	738361	20252E	PARTICIPANT	\N	PRESENT	0
738988	738361	99004R	PARTICIPANT	\N	PRESENT	0
738989	738361	20914V	PARTICIPANT	\N	PRESENT	0
738990	738361	14225N	PRESIDENT	0	PRESENT	0
738991	738361	19671E	PARTICIPANT	\N	PRESENT	0
738992	738361	14083S	PARTICIPANT	\N	PRESENT	0
738993	738361	11048N	PARTICIPANT	\N	PRESENT	0
738994	738361	20044X	PARTICIPANT	\N	PRESENT	0
738995	738017	05008E	PARTICIPANT	\N	PRESENT	0
738996	738017	20022R	PARTICIPANT	\N	PRESENT	0
738997	738017	11033F	PARTICIPANT	\N	PRESENT	0
738999	738017	19489J	PARTICIPANT	\N	PRESENT	0
739000	738017	20110Q	PARTICIPANT	\N	PRESENT	0
739001	738017	14021P	PARTICIPANT	\N	PRESENT	0
739002	737731	20090E	PARTICIPANT	\N	PRESENT	0
739003	737731	19367Y	PARTICIPANT	\N	PRESENT	0
739004	737731	19415P	PARTICIPANT	\N	PRESENT	0
739005	737731	14071N	PARTICIPANT	\N	PRESENT	0
739006	737731	14217N	PARTICIPANT	\N	PRESENT	0
739007	737731	14223L	PARTICIPANT	\N	PRESENT	0
739008	737731	20148F	PARTICIPANT	\N	PRESENT	0
739009	737731	10006L	PRESIDENT	0	PRESENT	0
739010	737731	20130U	PARTICIPANT	\N	PRESENT	0
739011	737731	19697Q	PARTICIPANT	\N	PRESENT	0
739012	737731	11067R	PARTICIPANT	\N	PRESENT	0
739013	737731	19798U	PARTICIPANT	\N	PRESENT	0
739014	737731	11097X	PARTICIPANT	\N	PRESENT	0
739015	737731	18193Q	PARTICIPANT	\N	PRESENT	0
739016	737731	19703U	PARTICIPANT	\N	PRESENT	0
739017	737731	11031D	PARTICIPANT	\N	PRESENT	0
739018	737731	20248J	PARTICIPANT	\N	PRESENT	0
739019	737731	19679N	PARTICIPANT	\N	PRESENT	0
739020	737731	14042U	PARTICIPANT	\N	PRESENT	0
739021	737731	14195A	PARTICIPANT	\N	PRESENT	0
739022	737731	14213J	PARTICIPANT	\N	PRESENT	0
739023	737731	19760E	PARTICIPANT	\N	PRESENT	0
739024	737731	19591F	PARTICIPANT	\N	PRESENT	0
739025	738017	17737W	PARTICIPANT	\N	PRESENT	0
739026	738361	14327T	PARTICIPANT	\N	PRESENT	0
739027	738361	20086J	PARTICIPANT	\N	PRESENT	0
739028	738361	14331P	PARTICIPANT	\N	PRESENT	0
739029	738361	01048V	PARTICIPANT	\N	PRESENT	0
739030	738361	19545Y	PARTICIPANT	\N	PRESENT	0
739031	738361	01057W	PARTICIPANT	\N	PRESENT	0
739032	738361	20080C	PARTICIPANT	\N	PRESENT	0
739033	738361	19667J	PARTICIPANT	\N	PRESENT	0
739034	738361	11074Q	PARTICIPANT	\N	PRESENT	0
739035	738361	11070L	PARTICIPANT	\N	PRESENT	0
739036	738361	14229S	PARTICIPANT	\N	PRESENT	0
739037	738361	07029T	PARTICIPANT	\N	PRESENT	0
739038	738361	19349W	PARTICIPANT	\N	PRESENT	0
739039	738361	08010L	PARTICIPANT	\N	PRESENT	0
739040	738361	20116W	PARTICIPANT	\N	PRESENT	0
739041	738361	19335Q	PARTICIPANT	\N	PRESENT	0
739042	738361	20126Y	PARTICIPANT	\N	PRESENT	0
739043	738361	19479G	PARTICIPANT	\N	PRESENT	0
739044	738361	19711U	PARTICIPANT	\N	PRESENT	0
729823	728221	19421M	PARTICIPANT	\N	PRESENT	0
729824	728221	14215L	PARTICIPANT	\N	PRESENT	0
729825	728221	14187A	PARTICIPANT	\N	PRESENT	0
729826	728221	14071N	PARTICIPANT	\N	PRESENT	0
729827	728221	14193X	PARTICIPANT	\N	PRESENT	0
729828	728221	19577H	PARTICIPANT	\N	PRESENT	0
729829	728221	11097X	PARTICIPANT	\N	PRESENT	0
729830	728221	07029T	PARTICIPANT	\N	PRESENT	0
729831	728221	19415P	PARTICIPANT	\N	PRESENT	0
729832	728221	20248J	PARTICIPANT	\N	PRESENT	0
729833	728221	01025N	PARTICIPANT	\N	PRESENT	0
729834	728221	08034U	PARTICIPANT	\N	PRESENT	0
729835	728221	17023S	PARTICIPANT	\N	PRESENT	0
729836	728221	11048N	PARTICIPANT	\N	PRESENT	0
729837	728221	14031R	PARTICIPANT	\N	PRESENT	0
729838	728221	08010L	PARTICIPANT	\N	PRESENT	0
729839	728221	04047H	PARTICIPANT	\N	PRESENT	0
729840	728221	20048C	PARTICIPANT	\N	PRESENT	0
729841	728221	20040T	PARTICIPANT	\N	PRESENT	0
729842	728221	19647E	PARTICIPANT	\N	PRESENT	0
729843	728221	19611R	PARTICIPANT	\N	PRESENT	0
729844	728221	19691J	PARTICIPANT	\N	PRESENT	0
729845	728221	19699S	PARTICIPANT	\N	PRESENT	0
729846	728221	11085T	PARTICIPANT	\N	PRESENT	0
729847	728221	19441R	PARTICIPANT	\N	PRESENT	0
729848	728221	04035D	PARTICIPANT	\N	PRESENT	0
729849	728221	19335Q	PARTICIPANT	\N	PRESENT	0
729850	728221	19369B	PARTICIPANT	\N	PRESENT	0
729851	728221	04070G	PARTICIPANT	\N	PRESENT	0
729852	728221	19745F	PARTICIPANT	\N	PRESENT	0
729853	728221	20298U	PARTICIPANT	\N	PRESENT	0
729854	728221	20134Y	PARTICIPANT	\N	PRESENT	0
729855	728221	19713W	PARTICIPANT	\N	PRESENT	0
729856	728221	20914V	PARTICIPANT	\N	PRESENT	0
729857	728221	19553Y	PARTICIPANT	\N	PRESENT	0
729858	728221	01034P	PARTICIPANT	\N	PRESENT	0
729859	728221	19479G	PARTICIPANT	\N	PRESENT	0
729860	728221	07004J	PARTICIPANT	\N	PRESENT	0
729861	728221	11031D	PARTICIPANT	\N	PRESENT	0
729862	728221	04085P	PARTICIPANT	\N	PRESENT	0
729863	728221	20032T	PARTICIPANT	\N	PRESENT	0
729864	728221	20026V	PARTICIPANT	\N	PRESENT	0
729865	728221	01028R	PARTICIPANT	\N	PRESENT	0
729866	728221	14083S	PARTICIPANT	\N	PRESENT	0
729867	728221	20286Q	PARTICIPANT	\N	PRESENT	0
729868	728221	20120S	PARTICIPANT	\N	PRESENT	0
729869	728221	17589D	PARTICIPANT	\N	PRESENT	0
729874	728221	17637T	PARTICIPANT	\N	PRESENT	0
729871	728221	14053L	PARTICIPANT	\N	PRESENT	0
729872	728221	19749K	PARTICIPANT	\N	PRESENT	0
729873	728221	11074Q	PARTICIPANT	\N	PRESENT	0
729875	728221	17779H	PARTICIPANT	\N	PRESENT	0
729878	728221	14179A	PARTICIPANT	\N	PRESENT	0
729879	728221	19413M	PARTICIPANT	\N	PRESENT	0
729880	728221	19551W	PARTICIPANT	\N	PRESENT	0
729889	728221	20086J	PARTICIPANT	\N	PRESENT	0
729903	728221	19507S	PARTICIPANT	\N	PRESENT	0
729904	728221	14069U	PARTICIPANT	\N	PRESENT	0
730195	728222	12041X	PARTICIPANT	\N	PRESENT	0
729906	728221	01043Q	PARTICIPANT	\N	PRESENT	0
730196	725883	10015M	PARTICIPANT	\N	PRESENT	0
730197	725883	19866P	PARTICIPANT	\N	PRESENT	0
730198	725883	19631V	PARTICIPANT	\N	PRESENT	0
730199	725883	19619A	PRESIDENT	0	PRESENT	0
730200	728222	11040E	PARTICIPANT	\N	PRESENT	0
730201	728222	20114U	PARTICIPANT	\N	PRESENT	0
730202	728222	14225N	PARTICIPANT	\N	PRESENT	0
730203	728222	20080C	PARTICIPANT	\N	PRESENT	0
730204	728222	19649G	PARTICIPANT	\N	PRESENT	0
730205	725883	20108W	PARTICIPANT	\N	PRESENT	0
730206	728222	19647E	PARTICIPANT	\N	PRESENT	0
730207	728222	04059M	PARTICIPANT	\N	PRESENT	0
730208	728222	12016W	PARTICIPANT	\N	PRESENT	0
730209	728222	20128B	PARTICIPANT	\N	PRESENT	0
730210	728222	11072N	PARTICIPANT	\N	PRESENT	0
730211	728222	11048N	PARTICIPANT	\N	PRESENT	0
730212	728222	17589D	PARTICIPANT	\N	PRESENT	0
730213	728222	19713W	PARTICIPANT	\N	PRESENT	0
730214	728222	14267Y	PARTICIPANT	\N	PRESENT	0
730215	728222	14089Y	PARTICIPANT	\N	PRESENT	0
730216	728222	20048C	PARTICIPANT	\N	PRESENT	0
730217	728222	14189C	PARTICIPANT	\N	PRESENT	0
730218	728222	19479G	PARTICIPANT	\N	PRESENT	0
730219	728222	20022R	PARTICIPANT	\N	PRESENT	0
730220	728222	19533U	PARTICIPANT	\N	PRESENT	0
730221	725883	20042V	PARTICIPANT	\N	EXCUSE	0
730222	725883	20080C	PARTICIPANT	\N	EXCUSE	0
730223	728222	19545Y	PARTICIPANT	\N	PRESENT	0
730224	728222	19553Y	PARTICIPANT	\N	PRESENT	0
730225	728222	97011G	PARTICIPANT	\N	PRESENT	0
730226	728222	20090E	PARTICIPANT	\N	PRESENT	0
730227	728222	19507S	PARTICIPANT	\N	PRESENT	0
730228	728222	19467C	PARTICIPANT	\N	PRESENT	0
730229	728222	20180F	PARTICIPANT	\N	PRESENT	0
730230	728222	01060R	PARTICIPANT	\N	PRESENT	0
730231	728222	19599P	PARTICIPANT	\N	PRESENT	0
730232	728222	19413M	PARTICIPANT	\N	PRESENT	0
730233	728222	20914V	PARTICIPANT	\N	PRESENT	0
730234	728222	20172F	PARTICIPANT	\N	PRESENT	0
730235	728222	19762G	PARTICIPANT	\N	PRESENT	0
730242	728222	11056N	PARTICIPANT	\N	PRESENT	0
730243	728222	19747H	PARTICIPANT	\N	PRESENT	0
730258	728222	20032T	PARTICIPANT	\N	PRESENT	0
730259	728222	08010L	PARTICIPANT	\N	PRESENT	0
730265	728222	11012A	PARTICIPANT	\N	PRESENT	0
730263	728222	20026V	PARTICIPANT	\N	PRESENT	0
730264	728222	14231L	PARTICIPANT	\N	PRESENT	0
730352	728224	14179A	PARTICIPANT	\N	PRESENT	0
730353	728224	19651A	PARTICIPANT	\N	PRESENT	0
730355	728224	14083S	PARTICIPANT	\N	PRESENT	0
730356	728224	11064N	PARTICIPANT	\N	PRESENT	0
730358	725883	19741B	PARTICIPANT	\N	EXCUSE	0
730359	728224	20248J	PARTICIPANT	\N	PRESENT	0
730360	728224	20090E	PARTICIPANT	\N	PRESENT	0
730361	728224	19349W	PARTICIPANT	\N	PRESENT	0
730362	728224	19591F	PARTICIPANT	\N	PRESENT	0
730369	728224	19631V	PARTICIPANT	\N	PRESENT	0
730370	728224	20134Y	PARTICIPANT	\N	PRESENT	0
730371	728224	14147R	PARTICIPANT	\N	PRESENT	0
730372	728224	19533U	PARTICIPANT	\N	PRESENT	0
730373	728224	20024T	PARTICIPANT	\N	PRESENT	0
730374	728224	01034P	PARTICIPANT	\N	PRESENT	0
730409	728227	20134Y	PARTICIPANT	\N	PRESENT	0
730410	728227	20266L	PARTICIPANT	\N	PRESENT	0
730411	728227	11064N	PARTICIPANT	\N	PRESENT	0
730412	728227	17589D	PARTICIPANT	\N	PRESENT	0
730413	728227	14231L	PARTICIPANT	\N	PRESENT	0
730414	728227	19699S	PARTICIPANT	\N	PRESENT	0
730415	728227	20090E	PARTICIPANT	\N	PRESENT	0
730416	728227	08010L	PARTICIPANT	\N	PRESENT	0
730417	728227	19749K	PARTICIPANT	\N	PRESENT	0
730418	728227	11056N	PARTICIPANT	\N	PRESENT	0
730419	728227	04047H	PARTICIPANT	\N	PRESENT	0
730420	728227	14179A	PARTICIPANT	\N	PRESENT	0
730421	728227	20056C	PARTICIPANT	\N	PRESENT	0
730422	728227	20248J	PARTICIPANT	\N	PRESENT	0
730423	728227	19629C	PARTICIPANT	\N	PRESENT	0
730424	728227	01034P	PARTICIPANT	\N	PRESENT	0
730425	728227	19591F	PARTICIPANT	\N	PRESENT	0
730426	728227	14147R	PARTICIPANT	\N	PRESENT	0
730427	728227	19533U	PARTICIPANT	\N	PRESENT	0
730428	728227	19413M	PARTICIPANT	\N	PRESENT	0
730429	728227	19565D	PARTICIPANT	\N	PRESENT	0
730430	728227	19479G	PARTICIPANT	\N	PRESENT	0
730431	728227	14215L	PARTICIPANT	\N	PRESENT	0
730432	728227	20024T	PARTICIPANT	\N	PRESENT	0
730433	728227	19551W	PARTICIPANT	\N	PRESENT	0
730434	728227	19441R	PARTICIPANT	\N	PRESENT	0
730435	728227	19347U	PARTICIPANT	\N	PRESENT	0
730436	728227	11012A	PARTICIPANT	\N	PRESENT	0
730437	728227	20026V	PARTICIPANT	\N	PRESENT	0
730438	728227	20034V	PARTICIPANT	\N	PRESENT	0
730439	728227	20180F	PARTICIPANT	\N	PRESENT	0
730440	728227	20104S	PARTICIPANT	\N	PRESENT	0
730407	728227	12041X	PARTICIPANT	\N	PRESENT	0
730408	728227	20114U	PARTICIPANT	\N	PRESENT	0
730555	730554	04047H	PARTICIPANT	\N	PRESENT	0
730556	730554	04042C	PARTICIPANT	\N	PRESENT	0
730559	730554	11066Q	PARTICIPANT	\N	PRESENT	0
734565	732767	08073C	PARTICIPANT	\N	PRESENT	0
734566	732767	11097X	PARTICIPANT	\N	PRESENT	0
734567	732767	12028B	PARTICIPANT	\N	PRESENT	0
734568	732767	14193X	PARTICIPANT	\N	PRESENT	0
734569	732767	14237S	PARTICIPANT	\N	PRESENT	0
734570	732767	19057M	PARTICIPANT	\N	PRESENT	0
734571	732767	19671E	PARTICIPANT	\N	PRESENT	0
734572	732767	19659J	PARTICIPANT	\N	PRESENT	0
734573	732767	19329S	PARTICIPANT	\N	PRESENT	0
734574	732767	19367Y	PARTICIPANT	\N	PRESENT	0
734575	732767	19581D	PARTICIPANT	\N	PRESENT	0
734576	732767	14055N	PARTICIPANT	\N	PRESENT	0
734577	732767	20152B	PARTICIPANT	\N	PRESENT	0
734578	732767	19629C	PARTICIPANT	\N	PRESENT	0
734579	732767	20054A	PARTICIPANT	\N	PRESENT	0
734580	732767	20116W	PARTICIPANT	\N	PRESENT	0
734581	732767	20128B	PARTICIPANT	\N	PRESENT	0
734582	732767	19675J	PARTICIPANT	\N	PRESENT	0
734583	732767	20070A	PARTICIPANT	\N	PRESENT	0
734584	732767	14357A	PARTICIPANT	\N	PRESENT	0
734585	732767	14329V	PARTICIPANT	\N	PRESENT	0
734586	732767	19719D	PARTICIPANT	\N	PRESENT	0
734587	732767	14217N	PARTICIPANT	\N	PRESENT	0
734588	732767	19681G	PARTICIPANT	\N	PRESENT	0
734589	732767	20132W	PARTICIPANT	\N	PRESENT	0
734590	732767	20120S	PARTICIPANT	\N	PRESENT	0
734591	732767	19387D	PARTICIPANT	\N	PRESENT	0
734592	732767	10006L	PARTICIPANT	\N	PRESENT	0
734593	732767	19553Y	PARTICIPANT	\N	PRESENT	0
734594	732767	19798U	PARTICIPANT	\N	PRESENT	0
734595	732767	20090E	PARTICIPANT	\N	PRESENT	0
734596	732767	20118Y	PARTICIPANT	\N	PRESENT	0
734597	732767	20062A	PARTICIPANT	\N	PRESENT	0
734598	732767	14059S	PARTICIPANT	\N	PRESENT	0
734599	732767	08056B	PARTICIPANT	\N	PRESENT	0
734600	732767	20124W	PARTICIPANT	\N	PRESENT	0
734601	732767	20148F	PARTICIPANT	\N	PRESENT	0
734602	732767	07004J	PARTICIPANT	\N	PRESENT	0
734603	732767	17737W	PARTICIPANT	\N	PRESENT	0
734604	732767	20110Q	PARTICIPANT	\N	PRESENT	0
734605	732767	20104S	PARTICIPANT	\N	PRESENT	0
734606	732767	14169X	PARTICIPANT	\N	PRESENT	0
734607	732767	19545Y	PARTICIPANT	\N	PRESENT	0
734608	732767	17637T	PARTICIPANT	\N	PRESENT	0
734609	732767	20050V	PARTICIPANT	\N	PRESENT	0
734610	732767	14211G	PARTICIPANT	\N	PRESENT	0
734611	732767	11064N	PARTICIPANT	\N	PRESENT	0
734612	732767	04071H	PARTICIPANT	\N	PRESENT	0
734613	732767	14355X	PARTICIPANT	\N	PRESENT	0
734614	732767	01028R	PARTICIPANT	\N	PRESENT	0
734615	732767	19703U	PARTICIPANT	\N	PRESENT	0
734616	732767	14251Q	PARTICIPANT	\N	PRESENT	0
734617	732767	14111D	PARTICIPANT	\N	PRESENT	0
734618	732767	11101A	PARTICIPANT	\N	PRESENT	0
734619	732767	14221J	PARTICIPANT	\N	PRESENT	0
734620	732767	04057K	PARTICIPANT	\N	PRESENT	0
734621	732767	20022R	PARTICIPANT	\N	PRESENT	0
734622	732767	19533U	PARTICIPANT	\N	PRESENT	0
734623	732767	20122U	PARTICIPANT	\N	PRESENT	0
734624	732767	19585H	PARTICIPANT	\N	PRESENT	0
734625	732767	17589D	PARTICIPANT	\N	PRESENT	0
734626	732767	14195A	PARTICIPANT	\N	PRESENT	0
734627	732767	11027H	PARTICIPANT	\N	PRESENT	0
734628	732767	14259Y	PARTICIPANT	\N	PRESENT	0
734629	732767	19543W	PARTICIPANT	\N	PRESENT	0
734630	732767	11031D	PARTICIPANT	\N	PRESENT	0
734631	732767	14089Y	PARTICIPANT	\N	PRESENT	0
734695	732767	20016T	PARTICIPANT	\N	PRESENT	0
734633	732767	19335Q	PARTICIPANT	\N	PRESENT	0
734634	732767	14147R	PARTICIPANT	\N	PRESENT	0
734635	732767	19699S	PARTICIPANT	\N	PRESENT	0
734636	732767	19721W	PARTICIPANT	\N	PRESENT	0
734637	732767	14083S	PARTICIPANT	\N	PRESENT	0
734638	732767	19713W	PARTICIPANT	\N	PRESENT	0
734639	732767	19749K	PARTICIPANT	\N	PRESENT	0
734640	732767	19383Y	PARTICIPANT	\N	PRESENT	0
734641	732767	20040T	PARTICIPANT	\N	PRESENT	0
734642	732767	20248J	PARTICIPANT	\N	PRESENT	0
734643	732767	19826F	PARTICIPANT	\N	PRESENT	0
734644	732767	19735D	PARTICIPANT	\N	PRESENT	0
734645	732767	97011G	PARTICIPANT	\N	PRESENT	0
734646	732767	14255U	PARTICIPANT	\N	PRESENT	0
734647	732767	14331P	PARTICIPANT	\N	PRESENT	0
734648	732767	11085T	PARTICIPANT	\N	PRESENT	0
734649	732767	01048V	PARTICIPANT	\N	PRESENT	0
734650	732767	20066E	PARTICIPANT	\N	PRESENT	0
734651	732767	01024M	PARTICIPANT	\N	PRESENT	0
734652	732767	14030Q	PARTICIPANT	\N	PRESENT	0
734653	732767	01043Q	PARTICIPANT	\N	PRESENT	0
734654	732767	20286Q	PARTICIPANT	\N	PRESENT	0
734655	732767	14179A	PARTICIPANT	\N	PRESENT	0
734656	732767	19745F	PARTICIPANT	\N	PRESENT	0
734657	732767	19611R	PARTICIPANT	\N	PRESENT	0
734658	732767	19369B	PARTICIPANT	\N	PRESENT	0
734659	732767	19667J	PARTICIPANT	\N	PRESENT	0
734660	732767	11053K	PARTICIPANT	\N	PRESENT	0
734661	732767	08009T	PARTICIPANT	\N	PRESENT	0
734662	732767	17023S	PARTICIPANT	\N	PRESENT	0
734663	732767	14205J	PARTICIPANT	\N	PRESENT	0
734664	732767	19563B	PARTICIPANT	\N	PRESENT	0
734665	732767	16685X	PARTICIPANT	\N	PRESENT	0
734666	732767	04035D	PARTICIPANT	\N	PRESENT	0
734667	732767	14033T	PARTICIPANT	\N	PRESENT	0
734668	732767	19569H	PARTICIPANT	\N	PRESENT	0
734669	732767	20112S	PARTICIPANT	\N	PRESENT	0
734670	732767	14042U	PARTICIPANT	\N	PRESENT	0
734671	732767	14219Q	PARTICIPANT	\N	PRESENT	0
734672	732767	11099A	PARTICIPANT	\N	PRESENT	0
734673	732767	20092G	PARTICIPANT	\N	PRESENT	0
734674	732767	14073Q	PARTICIPANT	\N	PRESENT	0
734675	732767	14275Y	PARTICIPANT	\N	PRESENT	0
734676	732767	20042V	PARTICIPANT	\N	PRESENT	0
734677	732767	20052X	PARTICIPANT	\N	PRESENT	0
734678	732767	20252E	PARTICIPANT	\N	PRESENT	0
734679	732767	19551W	PARTICIPANT	\N	PRESENT	0
734680	732767	11026G	PARTICIPANT	\N	PRESENT	0
734681	732767	19479G	PARTICIPANT	\N	PRESENT	0
734682	732767	11080N	PARTICIPANT	\N	PRESENT	0
734683	732767	19441R	PARTICIPANT	\N	PRESENT	0
734684	732767	19593H	PARTICIPANT	\N	PRESENT	0
734685	732767	19707Y	PARTICIPANT	\N	PRESENT	0
734686	732767	19705W	PARTICIPANT	\N	PRESENT	0
734687	732767	14213J	PARTICIPANT	\N	PRESENT	0
734688	732767	14109K	PARTICIPANT	\N	PRESENT	0
734689	732767	20136B	PARTICIPANT	\N	PRESENT	0
734690	732767	08018U	PARTICIPANT	\N	PRESENT	0
734691	732767	19663E	PARTICIPANT	\N	PRESENT	0
734692	732767	07033P	PARTICIPANT	\N	PRESENT	0
734693	732767	20126Y	PARTICIPANT	\N	PRESENT	0
734697	732767	20048C	PARTICIPANT	\N	PRESENT	0
734698	734696	10006L	PARTICIPANT	\N	PRESENT	0
734699	734696	19663E	PARTICIPANT	\N	PRESENT	0
734700	734696	14213J	PARTICIPANT	\N	PRESENT	0
734701	734696	11097X	PARTICIPANT	\N	PRESENT	0
734704	734696	14223L	PARTICIPANT	\N	PRESENT	0
734705	734694	10006L	PARTICIPANT	\N	PRESENT	0
734706	734694	14071N	PARTICIPANT	\N	PRESENT	0
734707	734694	14223L	PARTICIPANT	\N	PRESENT	0
734708	734694	11097X	PARTICIPANT	\N	PRESENT	0
734709	734694	19663E	PARTICIPANT	\N	PRESENT	0
734710	734694	14213J	PARTICIPANT	\N	PRESENT	0
734711	734694	19713W	PARTICIPANT	\N	PRESENT	0
728475	728447	20128B	PARTICIPANT	\N	PRESENT	0
728502	728447	01048V	PARTICIPANT	\N	EXCUSE	0
728504	728447	11067R	PARTICIPANT	\N	EXCUSE	0
728505	728447	20066E	PARTICIPANT	\N	EXCUSE	0
728506	728447	19723Y	PARTICIPANT	\N	EXCUSE	0
728903	728891	19820Y	PARTICIPANT	\N	PRESENT	0
728778	728777	05008E	PARTICIPANT	\N	PRESENT	0
728779	728777	11053K	PARTICIPANT	\N	PRESENT	0
728904	728891	20094J	PARTICIPANT	\N	PRESENT	0
728905	728891	20070A	PARTICIPANT	\N	PRESENT	0
728906	728891	14229S	PARTICIPANT	\N	PRESENT	0
728907	728891	19768N	PARTICIPANT	\N	PRESENT	0
728911	728895	20128B	PARTICIPANT	\N	PRESENT	0
728912	728895	20094J	PARTICIPANT	\N	PRESENT	0
728913	728895	14229S	PARTICIPANT	\N	PRESENT	0
728914	728895	19820Y	PARTICIPANT	\N	PRESENT	0
728915	728895	20070A	PARTICIPANT	\N	PRESENT	0
729085	728009	07004J	PARTICIPANT	\N	PRESENT	0
729086	728009	20108W	PARTICIPANT	\N	PRESENT	0
729087	728009	14147R	PARTICIPANT	\N	PRESENT	0
729088	728009	14069U	PARTICIPANT	\N	PRESENT	0
729089	728009	14215L	PARTICIPANT	\N	PRESENT	0
729090	728009	19749K	PARTICIPANT	\N	PRESENT	0
729091	728009	04047H	PRESIDENT	0	PRESENT	0
729092	728009	19673G	PARTICIPANT	\N	PRESENT	0
729093	728009	19675J	PARTICIPANT	\N	PRESENT	0
729094	728009	19649G	PARTICIPANT	\N	PRESENT	0
729095	728009	05008E	PARTICIPANT	\N	PRESENT	0
729118	728009	10015M	PARTICIPANT	\N	PRESENT	0
729119	728009	14001X	PARTICIPANT	\N	PRESENT	0
729120	728009	19543W	PARTICIPANT	\N	PRESENT	0
729121	728009	19581D	PARTICIPANT	\N	PRESENT	0
729122	728009	14089Y	PARTICIPANT	\N	PRESENT	0
729123	728009	19725B	PARTICIPANT	\N	PRESENT	0
729124	728009	11056N	PARTICIPANT	\N	PRESENT	0
729125	728009	95063L	PARTICIPANT	\N	PRESENT	0
729126	728009	14107H	PARTICIPANT	\N	PRESENT	0
729127	728009	14179A	PARTICIPANT	\N	PRESENT	0
729128	728009	08018U	PARTICIPANT	\N	PRESENT	0
729129	728009	14021P	PARTICIPANT	\N	PRESENT	0
729130	728009	14231L	PARTICIPANT	\N	PRESENT	0
729131	728009	14053L	PARTICIPANT	\N	PRESENT	0
729132	728009	14111D	PARTICIPANT	\N	PRESENT	0
729133	728009	19729F	PARTICIPANT	\N	EXCUSE	0
729135	728009	17737W	PARTICIPANT	\N	PRESENT	0
729136	728009	04008A	PARTICIPANT	\N	PRESENT	0
729142	728009	19489J	PARTICIPANT	\N	PRESENT	0
729268	729267	20110Q	PARTICIPANT	\N	PRESENT	0
729144	728009	20114U	PARTICIPANT	\N	PRESENT	0
729145	728009	20022R	PARTICIPANT	\N	PRESENT	0
729146	728009	14259Y	PARTICIPANT	\N	PRESENT	0
729147	728009	11026G	PARTICIPANT	\N	PRESENT	0
729148	726276	19527W	PARTICIPANT	\N	PRESENT	0
729149	726276	20132W	PARTICIPANT	\N	PRESENT	0
729150	726276	04070G	PARTICIPANT	\N	PRESENT	0
729151	726276	19651A	PARTICIPANT	\N	PRESENT	0
729152	726276	19611R	PRESIDENT	0	PRESENT	0
729153	726276	20138D	PARTICIPANT	\N	PRESENT	0
729154	726276	04033B	PARTICIPANT	\N	PRESENT	0
729155	726276	20142Y	PARTICIPANT	\N	PRESENT	0
729156	726276	01060R	PARTICIPANT	\N	PRESENT	0
729157	726276	19399H	PARTICIPANT	\N	PRESENT	0
729158	726276	20172F	PARTICIPANT	\N	PRESENT	0
729159	726276	20098N	PARTICIPANT	\N	PRESENT	0
729160	726276	20056C	PARTICIPANT	\N	PRESENT	0
729161	726276	20180F	PARTICIPANT	\N	PRESENT	0
729162	726276	20264J	PARTICIPANT	\N	PRESENT	0
729163	726276	08012N	PARTICIPANT	\N	PRESENT	0
729164	726276	20980G	PARTICIPANT	\N	PRESENT	0
729165	726276	11043H	PARTICIPANT	\N	PRESENT	0
729166	726276	19758L	PARTICIPANT	\N	PRESENT	0
729167	726276	17589D	PARTICIPANT	\N	PRESENT	0
729168	726276	20026V	PARTICIPANT	\N	PRESENT	0
729169	726276	20084G	PARTICIPANT	\N	PRESENT	0
729170	726276	19621T	PARTICIPANT	\N	PRESENT	0
729171	728582	14225N	PRESIDENT	0	PRESENT	0
729172	728582	19671E	PARTICIPANT	\N	EXCUSE	0
729176	728009	11072N	PARTICIPANT	\N	PRESENT	0
729177	728582	14331P	PARTICIPANT	\N	PRESENT	0
729178	728582	11048N	PARTICIPANT	\N	PRESENT	0
729179	728582	19479G	PARTICIPANT	\N	PRESENT	0
729180	728582	01057W	PARTICIPANT	\N	PRESENT	0
729181	728582	11040E	PARTICIPANT	\N	PRESENT	0
729182	728582	14083S	PARTICIPANT	\N	PRESENT	0
729183	728582	11012A	PARTICIPANT	\N	PRESENT	0
729184	728582	20070A	PARTICIPANT	\N	PRESENT	0
729185	728582	08010L	PARTICIPANT	\N	PRESENT	0
729186	728582	19741B	PARTICIPANT	\N	PRESENT	0
729187	728582	20914V	PARTICIPANT	\N	PRESENT	0
729188	728582	99004R	PARTICIPANT	\N	PRESENT	0
729189	728582	19711U	PARTICIPANT	\N	PRESENT	0
729190	728582	14121F	PARTICIPANT	\N	PRESENT	0
729191	728012	20074E	PARTICIPANT	\N	PRESENT	0
729192	728012	19581D	PARTICIPANT	\N	PRESENT	0
729193	728012	04047H	PRESIDENT	0	PRESENT	0
729194	728012	19673G	PARTICIPANT	\N	PRESENT	0
729195	728012	19675J	PARTICIPANT	\N	PRESENT	0
729196	728012	05008E	PARTICIPANT	\N	PRESENT	0
729197	728012	14231L	PARTICIPANT	\N	PRESENT	0
729198	728012	17737W	PARTICIPANT	\N	PRESENT	0
729199	728012	19489J	PARTICIPANT	\N	PRESENT	0
729200	728012	20108W	PARTICIPANT	\N	PRESENT	0
729201	728012	14147R	PARTICIPANT	\N	PRESENT	0
729202	728012	14179A	PARTICIPANT	\N	PRESENT	0
729203	728012	14151M	PARTICIPANT	\N	PRESENT	0
729204	728012	20114U	PARTICIPANT	\N	PRESENT	0
729205	728012	14215L	PARTICIPANT	\N	PRESENT	0
729206	728012	08018U	PARTICIPANT	\N	PRESENT	0
729207	728012	20022R	PARTICIPANT	\N	PRESENT	0
729208	728012	11072N	PARTICIPANT	\N	PRESENT	0
729209	728012	14053L	PARTICIPANT	\N	PRESENT	0
729210	728012	19649G	PARTICIPANT	\N	PRESENT	0
729211	728012	10015M	PARTICIPANT	\N	PRESENT	0
729212	728012	11026G	PARTICIPANT	\N	PRESENT	0
729213	728012	04085P	PARTICIPANT	\N	PRESENT	0
729214	728012	19725B	PARTICIPANT	\N	PRESENT	0
729215	728012	95063L	PARTICIPANT	\N	PRESENT	0
729216	728012	14069U	PARTICIPANT	\N	PRESENT	0
729217	728012	19749K	PARTICIPANT	\N	PRESENT	0
729218	728012	04008A	PARTICIPANT	\N	PRESENT	0
729219	728012	14021P	PARTICIPANT	\N	PRESENT	0
729220	728012	19729F	PARTICIPANT	\N	EXCUSE	0
729221	728582	20086J	PARTICIPANT	\N	PRESENT	0
729222	728582	01048V	PARTICIPANT	\N	PRESENT	0
729223	728582	14189C	PARTICIPANT	\N	PRESENT	0
729224	728582	08011M	PARTICIPANT	\N	PRESENT	0
729225	728582	20044X	PARTICIPANT	\N	PRESENT	0
729226	728582	20126Y	PARTICIPANT	\N	PRESENT	0
729227	728582	19687N	PARTICIPANT	\N	PRESENT	0
729228	728582	19349W	PARTICIPANT	\N	PRESENT	0
729229	728582	19531S	PARTICIPANT	\N	PRESENT	0
729231	728582	19762G	PARTICIPANT	\N	PRESENT	0
729232	728582	20080C	PARTICIPANT	\N	PRESENT	0
729233	728582	19335Q	PARTICIPANT	\N	PRESENT	0
729234	728582	08034U	PARTICIPANT	\N	PRESENT	0
729235	728582	19545Y	PARTICIPANT	\N	PRESENT	0
729262	729261	11066Q	PARTICIPANT	\N	PRESENT	0
729269	729267	19649G	PARTICIPANT	\N	PRESENT	0
729270	729267	19725B	PARTICIPANT	\N	PRESENT	0
729271	729267	14053L	PARTICIPANT	\N	PRESENT	0
729272	729267	19749K	PARTICIPANT	\N	PRESENT	0
729273	728582	04071H	PARTICIPANT	\N	PRESENT	0
729277	728582	11053K	PARTICIPANT	\N	PRESENT	0
729278	729276	20110Q	PARTICIPANT	\N	PRESENT	0
729279	729276	19649G	PARTICIPANT	\N	PRESENT	0
729280	729276	19725B	PARTICIPANT	\N	PRESENT	0
729281	729276	14053L	PARTICIPANT	\N	PRESENT	0
729282	729276	19749K	PARTICIPANT	\N	PRESENT	0
729287	729286	19649G	PARTICIPANT	\N	PRESENT	0
729288	729286	14053L	PARTICIPANT	\N	PRESENT	0
729289	729286	19749K	PARTICIPANT	\N	PRESENT	0
729292	729291	08018U	PARTICIPANT	\N	PRESENT	0
729293	729291	11026G	PARTICIPANT	\N	PRESENT	0
729297	729295	20136B	PARTICIPANT	\N	PRESENT	0
729298	728582	07029T	PARTICIPANT	\N	EXCUSE	0
729300	729299	11031D	PARTICIPANT	\N	PRESENT	0
729301	729299	04035D	PARTICIPANT	\N	PRESENT	0
729302	729299	11026G	PARTICIPANT	\N	PRESENT	0
712581	712571	17737W	PARTICIPANT	\N	EXCUSE	0
714406	714405	14147R	PARTICIPANT	\N	EXCUSE	0
714407	714405	17737W	PARTICIPANT	\N	PRESENT	0
714408	714405	04070G	PARTICIPANT	\N	EXCUSE	0
715626	715623	20248J	PARTICIPANT	\N	PRESENT	0
715628	715623	95063L	PARTICIPANT	\N	PRESENT	0
715629	715623	19669L	PARTICIPANT	\N	PRESENT	0
717408	716361	10006L	PRESIDENT	0	PRESENT	0
717409	716361	11097X	PARTICIPANT	\N	PRESENT	0
717410	716361	14042U	PARTICIPANT	\N	PRESENT	0
717411	716361	20090E	PARTICIPANT	\N	PRESENT	0
717412	716361	19798U	PARTICIPANT	\N	PRESENT	0
717415	716361	04092N	PARTICIPANT	\N	PRESENT	0
717416	716361	14217N	PARTICIPANT	\N	PRESENT	0
717421	716361	01048V	PARTICIPANT	\N	PRESENT	0
717422	716361	14121F	PARTICIPANT	\N	PRESENT	0
717423	716361	14331P	PARTICIPANT	\N	PRESENT	0
717424	716361	14225N	PARTICIPANT	\N	PRESENT	0
717425	716361	19367Y	PARTICIPANT	\N	PRESENT	0
717426	716361	20040T	PARTICIPANT	\N	PRESENT	0
717429	716361	19569H	PARTICIPANT	\N	PRESENT	0
717430	716361	19723Y	PARTICIPANT	\N	PRESENT	0
717431	716361	19679N	PARTICIPANT	\N	PRESENT	0
717432	716361	19741B	PARTICIPANT	\N	PRESENT	0
717433	716361	19531S	PARTICIPANT	\N	PRESENT	0
717438	716361	20116W	PARTICIPANT	\N	PRESENT	0
717439	716361	20086J	PARTICIPANT	\N	PRESENT	0
717440	716361	14327T	PARTICIPANT	\N	PRESENT	0
717441	716361	11074Q	PARTICIPANT	\N	PRESENT	0
717442	716361	01057W	PARTICIPANT	\N	PRESENT	0
717443	716361	19671E	PARTICIPANT	\N	PRESENT	0
717444	716361	19479G	PARTICIPANT	\N	PRESENT	0
717445	716364	10006L	PRESIDENT	0	PRESENT	0
717446	716364	11067R	PARTICIPANT	\N	PRESENT	0
717447	716364	19683J	PARTICIPANT	\N	PRESENT	0
717448	716364	18193Q	PARTICIPANT	\N	PRESENT	0
717449	716364	19367Y	PARTICIPANT	\N	PRESENT	0
717450	716364	20090E	PARTICIPANT	\N	PRESENT	0
717451	716364	04092N	PARTICIPANT	\N	PRESENT	0
717452	716364	20248J	PARTICIPANT	\N	PRESENT	0
717461	716364	19691J	PARTICIPANT	\N	PRESENT	0
717462	716364	19723Y	PARTICIPANT	\N	PRESENT	0
717463	716364	20040T	PARTICIPANT	\N	PRESENT	0
717464	716364	11097X	PARTICIPANT	\N	PRESENT	0
717465	716364	14217N	PARTICIPANT	\N	PRESENT	0
717466	716364	19663E	PARTICIPANT	\N	PRESENT	0
717467	716364	19511N	PARTICIPANT	\N	PRESENT	0
717468	716364	11031D	PARTICIPANT	\N	EXCUSE	0
717469	716364	19295A	PARTICIPANT	\N	EXCUSE	0
717470	716364	17779H	PARTICIPANT	\N	EXCUSE	0
717471	716361	11031D	PARTICIPANT	\N	EXCUSE	0
717472	716361	19295A	PARTICIPANT	\N	EXCUSE	0
717473	716361	17779H	PARTICIPANT	\N	EXCUSE	0
717474	716364	14042U	PARTICIPANT	\N	PRESENT	0
717475	716364	19679N	PARTICIPANT	\N	PRESENT	0
717476	716364	19798U	PARTICIPANT	\N	PRESENT	0
717510	716364	19760E	PARTICIPANT	\N	PRESENT	0
717511	716364	17965H	PARTICIPANT	\N	PRESENT	0
717512	716364	19591F	PARTICIPANT	\N	PRESENT	0
717513	716364	19415P	PARTICIPANT	\N	PRESENT	0
717514	716364	19713W	PARTICIPANT	\N	PRESENT	0
717525	716364	19697Q	PARTICIPANT	\N	PRESENT	0
729369	728206	11080N	PARTICIPANT	\N	PRESENT	0
729370	728206	14055N	PARTICIPANT	\N	PRESENT	0
729371	728206	07033P	PARTICIPANT	\N	PRESENT	0
729372	728206	19721W	PARTICIPANT	\N	PRESENT	0
729388	728520	19383Y	PARTICIPANT	\N	PRESENT	0
729389	728520	20088L	PARTICIPANT	\N	PRESENT	0
729390	728520	19768N	PARTICIPANT	\N	PRESENT	0
729391	728520	19515S	PARTICIPANT	\N	PRESENT	0
729392	728520	20092G	PARTICIPANT	\N	PRESENT	0
729393	728520	11077T	PARTICIPANT	\N	PRESENT	0
729394	728520	19782L	PARTICIPANT	\N	PRESENT	0
729395	728520	01043Q	PARTICIPANT	\N	PRESENT	0
729396	728520	14357A	PARTICIPANT	\N	PRESENT	0
729397	728520	20078J	PARTICIPANT	\N	PRESENT	0
729398	728520	19441R	PARTICIPANT	\N	PRESENT	0
729399	728520	19413M	PARTICIPANT	\N	PRESENT	0
729400	728520	20082E	PARTICIPANT	\N	PRESENT	0
729401	728520	20094J	PARTICIPANT	\N	PRESENT	0
729402	728520	19866P	PARTICIPANT	\N	PRESENT	0
729403	728520	04045F	PARTICIPANT	\N	PRESENT	0
729404	728520	20104S	PARTICIPANT	\N	PRESENT	0
729405	728520	19631V	PARTICIPANT	\N	PRESENT	0
729406	728520	11099A	PARTICIPANT	\N	PRESENT	0
729407	728520	08015R	PARTICIPANT	\N	PRESENT	0
729408	728520	19369B	PARTICIPANT	\N	PRESENT	0
729409	728520	20018V	PARTICIPANT	\N	PRESENT	0
729410	728520	08028W	PARTICIPANT	\N	PRESENT	0
729411	728520	19563B	PARTICIPANT	\N	PRESENT	0
729412	728520	14329V	PARTICIPANT	\N	PRESENT	0
729413	728520	20028X	PARTICIPANT	\N	PRESENT	0
729414	728520	14037X	PARTICIPANT	\N	PRESENT	0
729415	728520	14038Y	PRESIDENT	0	PRESENT	0
729416	728520	19467C	PARTICIPANT	\N	PRESENT	0
729417	728520	20034V	PARTICIPANT	\N	PRESENT	0
729418	728520	14187A	PARTICIPANT	\N	PRESENT	0
729419	728520	20144B	PARTICIPANT	\N	PRESENT	0
729420	728520	11090Q	PARTICIPANT	\N	PRESENT	0
729421	728520	14033T	PARTICIPANT	\N	PRESENT	0
729422	728520	01025N	PARTICIPANT	\N	PRESENT	0
729423	728520	20054A	PARTICIPANT	\N	PRESENT	0
729424	728520	14205J	PARTICIPANT	\N	PRESENT	0
729425	728520	20060X	PARTICIPANT	\N	PRESENT	0
729426	728520	20062A	PARTICIPANT	\N	PRESENT	0
729427	728520	14251Q	PARTICIPANT	\N	PRESENT	0
729428	728520	19507S	PARTICIPANT	\N	PRESENT	0
729429	728520	20286Q	PARTICIPANT	\N	PRESENT	0
729430	728520	20298U	PARTICIPANT	\N	PRESENT	0
729431	728520	19747H	PARTICIPANT	\N	PRESENT	0
729432	728520	14207L	PARTICIPANT	\N	PRESENT	0
729433	728520	14257W	PARTICIPANT	\N	PRESENT	0
729447	728141	19701S	PARTICIPANT	\N	PRESENT	0
729448	728141	20076G	PARTICIPANT	\N	PRESENT	0
729449	728141	19549D	PARTICIPANT	\N	PRESENT	0
729450	728141	14219Q	PRESIDENT	0	PRESENT	0
729451	728141	19820Y	PARTICIPANT	\N	PRESENT	0
729452	728141	14221J	PARTICIPANT	\N	PRESENT	0
729453	728141	20102Q	PARTICIPANT	\N	PRESENT	0
729454	728141	14237S	PARTICIPANT	\N	PRESENT	0
729455	728141	18083K	PARTICIPANT	\N	PRESENT	0
729456	728141	19551W	PARTICIPANT	\N	PRESENT	0
729457	728141	05012A	PARTICIPANT	\N	PRESENT	0
729458	728141	19503N	PARTICIPANT	\N	PRESENT	0
729459	728141	20020P	PARTICIPANT	\N	PRESENT	0
729460	728141	17367Q	PARTICIPANT	\N	PRESENT	0
729461	728141	20024T	PARTICIPANT	\N	PRESENT	0
729462	728141	20032T	PARTICIPANT	\N	PRESENT	0
729463	728141	20122U	PARTICIPANT	\N	PRESENT	0
729464	728141	20136B	PARTICIPANT	\N	PRESENT	0
729465	728141	14031R	PARTICIPANT	\N	PRESENT	0
729466	728141	20038A	PARTICIPANT	\N	PRESENT	0
729467	728141	20140W	PARTICIPANT	\N	PRESENT	0
729468	728141	19251M	PARTICIPANT	\N	PRESENT	0
729469	728141	20046A	PARTICIPANT	\N	PRESENT	0
729470	728141	17229F	PARTICIPANT	\N	PRESENT	0
729471	728141	14169X	PARTICIPANT	\N	EXCUSE	0
729472	728141	19739H	PARTICIPANT	\N	PRESENT	0
729473	728141	19745F	PARTICIPANT	\N	PRESENT	0
729474	728141	19619A	PARTICIPANT	\N	PRESENT	0
729475	728141	20100N	PARTICIPANT	\N	EXCUSE	0
729523	729506	12028B	PARTICIPANT	\N	PRESENT	0
729524	729506	20106U	PARTICIPANT	\N	PRESENT	0
729525	729506	20264J	PARTICIPANT	\N	PRESENT	0
729526	729506	20142Y	PARTICIPANT	\N	PRESENT	0
729527	729506	19739H	PARTICIPANT	\N	PRESENT	0
729528	729506	19335Q	PRESIDENT	0	PRESENT	0
729529	729506	20980G	PARTICIPANT	\N	PRESENT	0
729530	729506	19758L	PARTICIPANT	\N	PRESENT	0
729563	729506	20026V	PARTICIPANT	\N	PRESENT	0
729575	728221	86034E	PARTICIPANT	\N	PRESENT	0
729585	728221	14105F	PARTICIPANT	\N	PRESENT	0
729586	728221	20062A	PARTICIPANT	\N	PRESENT	0
729588	728221	98022P	PARTICIPANT	\N	PRESENT	0
729589	728221	19511N	PARTICIPANT	\N	PRESENT	0
729590	728221	14189C	PARTICIPANT	\N	PRESENT	0
729591	728221	19866P	PARTICIPANT	\N	PRESENT	0
729592	728221	20098N	PARTICIPANT	\N	PRESENT	0
729593	728221	19798U	PARTICIPANT	\N	PRESENT	0
729594	728221	08028W	PARTICIPANT	\N	PRESENT	0
729595	728221	11101A	PARTICIPANT	\N	PRESENT	0
723768	723631	16685X	PARTICIPANT	\N	PRESENT	0
723769	723631	01024M	PARTICIPANT	\N	PRESENT	0
723770	723631	19669L	PARTICIPANT	\N	PRESENT	0
723771	723631	11066Q	PARTICIPANT	\N	PRESENT	0
723772	723631	12028B	PARTICIPANT	\N	PRESENT	0
723773	723631	19421M	PARTICIPANT	\N	PRESENT	0
723774	723631	98022P	PARTICIPANT	\N	PRESENT	0
723775	723631	19709B	PARTICIPANT	\N	PRESENT	0
723776	723631	14193X	PRESIDENT	0	PRESENT	0
723777	723631	14267Y	PARTICIPANT	\N	PRESENT	0
723778	723631	11083R	PARTICIPANT	\N	PRESENT	0
723779	723631	08061X	PARTICIPANT	\N	PRESENT	0
723780	723631	97011G	PARTICIPANT	\N	PRESENT	0
723781	723631	14255U	PARTICIPANT	\N	PRESENT	0
723782	723631	08047A	PARTICIPANT	\N	PRESENT	0
723783	723631	20128B	PARTICIPANT	\N	PRESENT	0
723784	723631	04042C	PARTICIPANT	\N	EXCUSE	0
723785	723233	19711U	PARTICIPANT	\N	PRESENT	0
723786	723233	14189C	PARTICIPANT	\N	PRESENT	0
723787	723233	20044X	PARTICIPANT	\N	PRESENT	0
723788	723233	11070L	PARTICIPANT	\N	PRESENT	0
723789	723233	08010L	PARTICIPANT	\N	PRESENT	0
723790	723233	14253S	PARTICIPANT	\N	PRESENT	0
723791	723233	14083S	PARTICIPANT	\N	PRESENT	0
723792	723233	20086J	PARTICIPANT	\N	PRESENT	0
723793	723233	08034U	PARTICIPANT	\N	PRESENT	0
723794	723233	11053K	PARTICIPANT	\N	PRESENT	0
723795	723233	19349W	PARTICIPANT	\N	PRESENT	0
723796	723233	99004R	PARTICIPANT	\N	PRESENT	0
723797	723233	19762G	PARTICIPANT	\N	PRESENT	0
723798	723233	19479G	PARTICIPANT	\N	PRESENT	0
723799	723233	11048N	PARTICIPANT	\N	PRESENT	0
723800	723233	01057W	PARTICIPANT	\N	PRESENT	0
723801	723233	19671E	PARTICIPANT	\N	PRESENT	0
723802	723233	19545Y	PARTICIPANT	\N	PRESENT	0
723803	723233	19667J	PARTICIPANT	\N	PRESENT	0
723804	723233	20126Y	PARTICIPANT	\N	PRESENT	0
723806	723233	07029T	PARTICIPANT	\N	PRESENT	0
723807	723660	20058E	PARTICIPANT	\N	PRESENT	0
723808	723631	04035D	PARTICIPANT	\N	EXCUSE	0
723809	723631	19443T	PARTICIPANT	\N	EXCUSE	0
723810	723631	01062T	PARTICIPANT	\N	EXCUSE	0
723811	723631	11041F	PARTICIPANT	\N	EXCUSE	0
723812	723631	07033P	PARTICIPANT	\N	EXCUSE	0
723813	723631	14249W	PARTICIPANT	\N	EXCUSE	0
723814	723631	19583F	PARTICIPANT	\N	EXCUSE	0
723815	723631	17023S	PARTICIPANT	\N	EXCUSE	0
723817	723816	12041X	PARTICIPANT	\N	PRESENT	0
723818	723816	95041E	PARTICIPANT	\N	PRESENT	0
723819	723816	19565D	PARTICIPANT	\N	PRESENT	0
723820	723816	20072C	PARTICIPANT	\N	PRESENT	0
723821	723816	01058X	PARTICIPANT	\N	PRESENT	0
723822	723816	11027H	PARTICIPANT	\N	PRESENT	0
723823	723816	16685X	PARTICIPANT	\N	PRESENT	0
723824	723816	04042C	PRESIDENT	0	PRESENT	0
723825	723816	19669L	PARTICIPANT	\N	PRESENT	0
723826	723816	11066Q	PARTICIPANT	\N	PRESENT	0
723827	723816	12028B	PARTICIPANT	\N	PRESENT	0
723828	723816	19421M	PARTICIPANT	\N	PRESENT	0
723829	723816	19709B	PARTICIPANT	\N	PRESENT	0
723830	723816	14193X	PARTICIPANT	\N	PRESENT	0
723831	723816	08061X	PARTICIPANT	\N	PRESENT	0
723832	723816	97011G	PARTICIPANT	\N	PRESENT	0
723833	723816	08047A	PARTICIPANT	\N	PRESENT	0
723834	723816	20128B	PARTICIPANT	\N	PRESENT	0
723835	723816	14133K	PARTICIPANT	\N	PRESENT	0
723836	723816	20042V	PARTICIPANT	\N	PRESENT	0
723837	723816	01024M	PARTICIPANT	\N	PRESENT	0
723838	723816	98022P	PARTICIPANT	\N	PRESENT	0
723839	723816	14267Y	PARTICIPANT	\N	PRESENT	0
723840	723816	11083R	PARTICIPANT	\N	PRESENT	0
723841	723816	14255U	PARTICIPANT	\N	PRESENT	0
723842	723816	04035D	PARTICIPANT	\N	EXCUSE	0
723843	723816	19443T	PARTICIPANT	\N	EXCUSE	0
723844	723816	01062T	PARTICIPANT	\N	EXCUSE	0
723845	723816	11041F	PARTICIPANT	\N	EXCUSE	0
723846	723816	07033P	PARTICIPANT	\N	EXCUSE	0
723847	723816	14249W	PARTICIPANT	\N	EXCUSE	0
723848	723816	19583F	PARTICIPANT	\N	EXCUSE	0
723849	723816	17023S	PARTICIPANT	\N	EXCUSE	0
723851	723816	08069G	PARTICIPANT	\N	PRESENT	0
723852	723816	14191V	PARTICIPANT	\N	PRESENT	0
723853	723233	19335Q	PARTICIPANT	\N	PRESENT	0
723854	723233	19413M	PARTICIPANT	\N	PRESENT	0
723855	722416	14053L	PARTICIPANT	\N	PRESENT	0
723856	722416	14231L	PARTICIPANT	\N	PRESENT	0
723857	722416	19489J	PARTICIPANT	\N	PRESENT	0
723858	722416	14147R	PARTICIPANT	\N	PRESENT	0
723859	722416	14179A	PARTICIPANT	\N	PRESENT	0
723860	722416	08018U	PARTICIPANT	\N	PRESENT	0
723861	723233	14173T	PARTICIPANT	\N	PRESENT	0
723865	723631	01048V	PARTICIPANT	\N	PRESENT	0
723866	723631	19545Y	PARTICIPANT	\N	PRESENT	0
723867	723631	01057W	PARTICIPANT	\N	PRESENT	0
723868	723631	11053K	PARTICIPANT	\N	PRESENT	0
723869	723631	19667J	PARTICIPANT	\N	PRESENT	0
723870	723631	11070L	PARTICIPANT	\N	PRESENT	0
723871	723631	19671E	PARTICIPANT	\N	PRESENT	0
723872	723631	07029T	PARTICIPANT	\N	PRESENT	0
723874	723631	19349W	PARTICIPANT	\N	PRESENT	0
723875	723631	19335Q	PARTICIPANT	\N	PRESENT	0
723876	723631	19647E	PARTICIPANT	\N	PRESENT	0
723877	723631	11048N	PARTICIPANT	\N	PRESENT	0
723878	723631	20036X	PARTICIPANT	\N	PRESENT	0
723879	723631	14189C	PARTICIPANT	\N	PRESENT	0
723880	723631	19687N	PARTICIPANT	\N	PRESENT	0
723881	723631	20044X	PARTICIPANT	\N	PRESENT	0
723882	723631	14083S	PARTICIPANT	\N	PRESENT	0
723883	723631	20070A	PARTICIPANT	\N	PRESENT	0
723884	723631	14121F	PARTICIPANT	\N	PRESENT	0
723885	723631	99004R	PARTICIPANT	\N	PRESENT	0
723886	723631	20080C	PARTICIPANT	\N	PRESENT	0
723887	723631	08010L	PARTICIPANT	\N	PRESENT	0
723888	723631	20116W	PARTICIPANT	\N	PRESENT	0
723889	723631	14253S	PARTICIPANT	\N	PRESENT	0
723890	723631	17367Q	PARTICIPANT	\N	PRESENT	0
723891	723631	20126Y	PARTICIPANT	\N	PRESENT	0
723892	723631	19479G	PARTICIPANT	\N	PRESENT	0
723893	723631	19711U	PARTICIPANT	\N	PRESENT	0
723894	723631	08034U	PARTICIPANT	\N	PRESENT	0
723895	723631	19741B	PARTICIPANT	\N	PRESENT	0
723896	723631	20914V	PARTICIPANT	\N	PRESENT	0
723897	723631	19762G	PARTICIPANT	\N	PRESENT	0
723898	723233	08073C	PARTICIPANT	\N	PRESENT	0
723938	723233	11012A	PARTICIPANT	\N	PRESENT	0
723939	723233	14327T	PARTICIPANT	\N	PRESENT	0
723948	723232	95041E	PARTICIPANT	\N	PRESENT	0
723949	723232	01058X	PARTICIPANT	\N	PRESENT	0
723950	723232	11027H	PARTICIPANT	\N	PRESENT	0
723951	723232	16685X	PARTICIPANT	\N	PRESENT	0
723952	723232	19669L	PARTICIPANT	\N	PRESENT	0
723953	723232	11066Q	PARTICIPANT	\N	PRESENT	0
723954	723232	19421M	PARTICIPANT	\N	PRESENT	0
723955	723232	19347U	PARTICIPANT	\N	PRESENT	0
723956	723232	97011G	PARTICIPANT	\N	PRESENT	0
723957	723232	08061X	PARTICIPANT	\N	PRESENT	0
723958	723232	08047A	PARTICIPANT	\N	PRESENT	0
723959	723232	20042V	PARTICIPANT	\N	PRESENT	0
723960	723232	01024M	PARTICIPANT	\N	PRESENT	0
723961	723232	98022P	PARTICIPANT	\N	PRESENT	0
723962	723232	14255U	PARTICIPANT	\N	PRESENT	0
723963	723232	12041X	PARTICIPANT	\N	PRESENT	0
723964	723232	19565D	PARTICIPANT	\N	PRESENT	0
723965	723232	20072C	PARTICIPANT	\N	PRESENT	0
723966	723232	12028B	PARTICIPANT	\N	PRESENT	0
723967	723232	19709B	PARTICIPANT	\N	PRESENT	0
723968	723232	14193X	PARTICIPANT	\N	PRESENT	0
723969	723232	20128B	PARTICIPANT	\N	PRESENT	0
723970	723232	14133K	PARTICIPANT	\N	PRESENT	0
723971	723232	14267Y	PARTICIPANT	\N	PRESENT	0
723972	723232	11064N	PARTICIPANT	\N	PRESENT	0
723973	723232	11083R	PARTICIPANT	\N	PRESENT	0
723974	720141	14221J	PARTICIPANT	\N	PRESENT	0
723975	720141	11065P	PARTICIPANT	\N	PRESENT	0
723976	720141	19659J	PARTICIPANT	\N	PRESENT	0
723977	720141	19577H	PARTICIPANT	\N	PRESENT	0
723978	723232	14225N	PARTICIPANT	\N	EXCUSE	0
723979	723381	19383Y	PARTICIPANT	\N	PRESENT	0
723980	723381	19768N	PARTICIPANT	\N	PRESENT	0
723981	723381	19515S	PARTICIPANT	\N	PRESENT	0
713469	713467	19533U	PARTICIPANT	\N	PRESENT	0
713471	713470	20128B	PARTICIPANT	\N	PRESENT	0
718917	718916	20024T	PARTICIPANT	\N	PRESENT	0
718918	718916	14213J	PARTICIPANT	\N	PRESENT	0
718919	718916	20050V	PARTICIPANT	\N	PRESENT	0
718920	718916	20096L	PARTICIPANT	\N	PRESENT	0
718921	718916	20066E	PARTICIPANT	\N	PRESENT	0
718922	718916	11031D	PARTICIPANT	\N	PRESENT	0
718923	718916	14026U	PARTICIPANT	\N	PRESENT	0
718995	718994	11074Q	PARTICIPANT	\N	PRESENT	0
718996	718994	19349W	PARTICIPANT	\N	PRESENT	0
719009	719008	01048V	PARTICIPANT	\N	PRESENT	0
719011	719010	01048V	PARTICIPANT	\N	PRESENT	0
719013	719012	01048V	PARTICIPANT	\N	PRESENT	0
719015	719014	01048V	PARTICIPANT	\N	PRESENT	0
719017	719016	01048V	PARTICIPANT	\N	PRESENT	0
719019	719018	01048V	PARTICIPANT	\N	PRESENT	0
719021	719020	01048V	PARTICIPANT	\N	PRESENT	0
719023	719022	01048V	PARTICIPANT	\N	PRESENT	0
719063	718556	19729F	PARTICIPANT	\N	PRESENT	0
719064	718556	14111D	PARTICIPANT	\N	PRESENT	0
719065	718556	19629C	PARTICIPANT	\N	PRESENT	0
719066	718556	20074E	PARTICIPANT	\N	PRESENT	0
719199	718556	14179A	PARTICIPANT	\N	PRESENT	0
719068	718556	14001X	PARTICIPANT	\N	PRESENT	0
719069	718556	20114U	PARTICIPANT	\N	PRESENT	0
719070	718556	14069U	PARTICIPANT	\N	PRESENT	0
719071	718556	19301E	PARTICIPANT	\N	PRESENT	0
719200	718556	14151M	PARTICIPANT	\N	PRESENT	0
719073	718556	04047H	PRESIDENT	0	PRESENT	0
719074	718556	19673G	PARTICIPANT	\N	PRESENT	0
719075	719037	14327T	PARTICIPANT	\N	PRESENT	0
719076	719037	20086J	PARTICIPANT	\N	PRESENT	0
719077	719037	11048N	PARTICIPANT	\N	PRESENT	0
719078	719037	19479G	PARTICIPANT	\N	PRESENT	0
719079	719037	01048V	PARTICIPANT	\N	PRESENT	0
719080	719037	08034U	PARTICIPANT	\N	PRESENT	0
719081	719037	01057W	PARTICIPANT	\N	PRESENT	0
719082	719037	12016W	PARTICIPANT	\N	PRESENT	0
719083	719037	20050V	PARTICIPANT	\N	PRESENT	0
719084	719037	19667J	PARTICIPANT	\N	PRESENT	0
719085	719037	20044X	PARTICIPANT	\N	PRESENT	0
719086	719037	19671E	PARTICIPANT	\N	PRESENT	0
719087	719037	14083S	PARTICIPANT	\N	PRESENT	0
719088	719037	08009T	PARTICIPANT	\N	PRESENT	0
719089	719037	20070A	PARTICIPANT	\N	PRESENT	0
719090	719037	19349W	PARTICIPANT	\N	PRESENT	0
719091	719037	08010L	PARTICIPANT	\N	PRESENT	0
719092	719037	19741B	PARTICIPANT	\N	PRESENT	0
719093	719037	19335Q	PARTICIPANT	\N	PRESENT	0
719094	719037	20914V	PARTICIPANT	\N	PRESENT	0
719095	719037	19531S	PARTICIPANT	\N	PRESENT	0
719096	719037	19687N	PARTICIPANT	\N	PRESENT	0
719097	719055	14327T	PARTICIPANT	\N	PRESENT	0
719098	719055	20086J	PARTICIPANT	\N	PRESENT	0
719099	719055	01048V	PARTICIPANT	\N	PRESENT	0
719100	719055	01057W	PARTICIPANT	\N	PRESENT	0
719101	719055	19667J	PARTICIPANT	\N	PRESENT	0
719102	719055	14225N	PRESIDENT	0	PRESENT	0
719103	719055	19671E	PARTICIPANT	\N	PRESENT	0
719104	719055	19349W	PARTICIPANT	\N	PRESENT	0
719105	719055	08010L	PARTICIPANT	\N	PRESENT	0
719106	719055	14253S	PARTICIPANT	\N	PRESENT	0
719107	719055	19335Q	PARTICIPANT	\N	PRESENT	0
719108	719055	11048N	PARTICIPANT	\N	PRESENT	0
719109	719055	19479G	PARTICIPANT	\N	PRESENT	0
719110	719055	20036X	PARTICIPANT	\N	PRESENT	0
719111	719055	08034U	PARTICIPANT	\N	PRESENT	0
719112	719055	19531S	PARTICIPANT	\N	PRESENT	0
719113	719055	19687N	PARTICIPANT	\N	PRESENT	0
719114	719055	12016W	PARTICIPANT	\N	PRESENT	0
719115	719055	20050V	PARTICIPANT	\N	PRESENT	0
719116	719055	20044X	PARTICIPANT	\N	PRESENT	0
719117	719055	14173T	PARTICIPANT	\N	PRESENT	0
719118	719055	14083S	PARTICIPANT	\N	PRESENT	0
719119	719055	08009T	PARTICIPANT	\N	PRESENT	0
719120	719055	20070A	PARTICIPANT	\N	PRESENT	0
719121	719055	19741B	PARTICIPANT	\N	PRESENT	0
719122	719055	20914V	PARTICIPANT	\N	PRESENT	0
719123	718556	14053L	PARTICIPANT	\N	PRESENT	0
719124	718556	10015M	PARTICIPANT	\N	PRESENT	0
719125	718556	19447X	PARTICIPANT	\N	PRESENT	0
719126	718556	19954N	PARTICIPANT	\N	PRESENT	0
719127	718556	19489J	PARTICIPANT	\N	PRESENT	0
719128	718556	95063L	PARTICIPANT	\N	PRESENT	0
719129	718556	14147R	PARTICIPANT	\N	PRESENT	0
719130	718556	14215L	PARTICIPANT	\N	PRESENT	0
719131	718556	20022R	PARTICIPANT	\N	PRESENT	0
719132	718556	11072N	PARTICIPANT	\N	PRESENT	0
719198	718556	14107H	PARTICIPANT	\N	PRESENT	0
719201	718556	01028R	PARTICIPANT	\N	EXCUSE	0
719202	718393	19329S	PARTICIPANT	\N	PRESENT	0
719203	718393	18193Q	PARTICIPANT	\N	PRESENT	0
719204	718393	19723Y	PARTICIPANT	\N	PRESENT	0
719205	718393	20066E	PARTICIPANT	\N	PRESENT	0
719206	718393	04043D	PARTICIPANT	\N	PRESENT	0
719207	718393	19663E	PARTICIPANT	\N	PRESENT	0
719209	718556	08018U	PARTICIPANT	\N	PRESENT	0
719214	718556	11026G	PARTICIPANT	\N	PRESENT	0
719217	718393	19569H	PARTICIPANT	\N	PRESENT	0
719218	718393	19553Y	PARTICIPANT	\N	PRESENT	0
719219	718769	19383Y	PARTICIPANT	\N	PRESENT	0
719220	718769	19768N	PARTICIPANT	\N	PRESENT	0
719221	718769	20088L	PARTICIPANT	\N	PRESENT	0
719222	718769	19515S	PARTICIPANT	\N	PRESENT	0
719223	718769	20092G	PARTICIPANT	\N	PRESENT	0
719224	718769	19782L	PARTICIPANT	\N	PRESENT	0
719225	718769	01043Q	PARTICIPANT	\N	PRESENT	0
719226	718769	14357A	PARTICIPANT	\N	PRESENT	0
719227	718769	19441R	PARTICIPANT	\N	PRESENT	0
719228	718769	19413M	PARTICIPANT	\N	PRESENT	0
719229	718769	20082E	PARTICIPANT	\N	PRESENT	0
719230	718769	04045F	PARTICIPANT	\N	PRESENT	0
719231	718769	19866P	PARTICIPANT	\N	PRESENT	0
719232	718769	19631V	PARTICIPANT	\N	PRESENT	0
719233	718769	20104S	PARTICIPANT	\N	PRESENT	0
719234	718769	19705W	PARTICIPANT	\N	PRESENT	0
719235	718769	19369B	PARTICIPANT	\N	PRESENT	0
719236	718769	20018V	PARTICIPANT	\N	PRESENT	0
719237	718769	19563B	PARTICIPANT	\N	PRESENT	0
719238	718769	14329V	PARTICIPANT	\N	PRESENT	0
719239	718769	14187A	PARTICIPANT	\N	PRESENT	0
719240	718769	20144B	PARTICIPANT	\N	PRESENT	0
719241	718769	14033T	PARTICIPANT	\N	PRESENT	0
719242	718769	11090Q	PRESIDENT	0	PRESENT	0
719243	718769	01025N	PARTICIPANT	\N	PRESENT	0
719244	718769	20054A	PARTICIPANT	\N	PRESENT	0
719245	718769	14205J	PARTICIPANT	\N	PRESENT	0
719246	718769	20060X	PARTICIPANT	\N	PRESENT	0
719247	718769	20062A	PARTICIPANT	\N	PRESENT	0
719248	718769	19507S	PARTICIPANT	\N	PRESENT	0
719249	718769	20286Q	PARTICIPANT	\N	PRESENT	0
719250	718769	20298U	PARTICIPANT	\N	PRESENT	0
719251	718769	19747H	PARTICIPANT	\N	PRESENT	0
719252	718769	14207L	PARTICIPANT	\N	PRESENT	0
719253	718769	14257W	PARTICIPANT	\N	PRESENT	0
719254	718769	20030R	PARTICIPANT	\N	EXCUSE	0
719255	718769	08028W	PARTICIPANT	\N	EXCUSE	0
719256	718769	20028X	PARTICIPANT	\N	EXCUSE	0
719257	719055	14331P	PARTICIPANT	\N	PRESENT	0
719258	719055	11070L	PARTICIPANT	\N	PRESENT	0
719259	719055	11110B	PARTICIPANT	\N	PRESENT	0
719261	719055	20126Y	PARTICIPANT	\N	PRESENT	0
719262	719055	19711U	PARTICIPANT	\N	PRESENT	0
719263	719055	08011M	PARTICIPANT	\N	PRESENT	0
719264	719055	20252E	PARTICIPANT	\N	PRESENT	0
719265	719055	14121F	PARTICIPANT	\N	PRESENT	0
719266	719055	99004R	PARTICIPANT	\N	PRESENT	0
719267	719055	11053K	PARTICIPANT	\N	PRESENT	0
719269	719055	11012A	PARTICIPANT	\N	EXCUSE	0
719270	718393	01034P	PARTICIPANT	\N	PRESENT	0
719271	718668	14059S	PARTICIPANT	\N	PRESENT	0
719272	718668	08069G	PARTICIPANT	\N	PRESENT	0
719273	718668	19709B	PARTICIPANT	\N	PRESENT	0
719274	718668	17023S	PARTICIPANT	\N	PRESENT	0
719275	718668	14255U	PARTICIPANT	\N	PRESENT	0
719276	718668	14133K	PARTICIPANT	\N	EXCUSE	0
719277	718668	20042V	PARTICIPANT	\N	EXCUSE	0
714619	712588	20032T	PARTICIPANT	\N	PRESENT	0
714818	712588	11070L	PARTICIPANT	\N	PRESENT	0
714579	712588	11080N	PARTICIPANT	\N	PRESENT	0
714819	712588	19643A	PARTICIPANT	\N	PRESENT	0
714581	712588	19515S	PARTICIPANT	\N	PRESENT	0
714582	712588	20914V	PARTICIPANT	\N	PRESENT	0
714583	712588	19667J	PARTICIPANT	\N	PRESENT	0
714584	712588	11115U	PARTICIPANT	\N	PRESENT	0
714585	712588	19729F	PARTICIPANT	\N	PRESENT	0
714586	712588	19399H	PARTICIPANT	\N	PRESENT	0
714587	712588	19782L	PARTICIPANT	\N	PRESENT	0
714588	712588	19057M	PARTICIPANT	\N	PRESENT	0
714589	712588	20104S	PARTICIPANT	\N	PRESENT	0
714590	712588	19525U	PARTICIPANT	\N	PRESENT	0
714591	712588	19659J	PARTICIPANT	\N	PRESENT	0
714592	712588	20108W	PARTICIPANT	\N	PRESENT	0
714593	712588	14249W	PARTICIPANT	\N	PRESENT	0
714594	712588	20148F	PARTICIPANT	\N	PRESENT	0
714595	712588	11083R	PARTICIPANT	\N	PRESENT	0
714596	712588	14147R	PARTICIPANT	\N	PRESENT	0
714597	712588	19768N	PARTICIPANT	\N	PRESENT	0
714598	712588	20128B	PARTICIPANT	\N	PRESENT	0
714599	712588	20024T	PARTICIPANT	\N	PRESENT	0
714600	712588	14213J	PARTICIPANT	\N	PRESENT	0
714601	712588	19591F	PARTICIPANT	\N	PRESENT	0
714602	712588	14037X	PARTICIPANT	\N	PRESENT	0
714603	712588	20172F	PARTICIPANT	\N	PRESENT	0
714604	712588	19697Q	PARTICIPANT	\N	PRESENT	0
714605	712588	17737W	PARTICIPANT	\N	PRESENT	0
714606	712588	19301E	PARTICIPANT	\N	PRESENT	0
714607	712588	04045F	PARTICIPANT	\N	PRESENT	0
714608	712588	20136B	PARTICIPANT	\N	PRESENT	0
714609	712588	95063L	PARTICIPANT	\N	PRESENT	0
714610	712588	08061X	PARTICIPANT	\N	PRESENT	0
714611	712588	08073C	PARTICIPANT	\N	PRESENT	0
714612	712588	19349W	PARTICIPANT	\N	PRESENT	0
714613	712588	01057W	PARTICIPANT	\N	PRESENT	0
714614	712588	20106U	PARTICIPANT	\N	PRESENT	0
714615	712588	20068G	PARTICIPANT	\N	PRESENT	0
714616	712588	05012A	PARTICIPANT	\N	PRESENT	0
714617	712588	20022R	PARTICIPANT	\N	PRESENT	0
714618	712588	11065P	PARTICIPANT	\N	PRESENT	0
714834	712588	14251Q	PARTICIPANT	\N	PRESENT	0
714840	714163	14219Q	PARTICIPANT	\N	PRESENT	0
714841	714163	20118Y	PARTICIPANT	\N	PRESENT	0
714842	714163	19659J	PARTICIPANT	\N	PRESENT	0
714843	714163	19577H	PARTICIPANT	\N	PRESENT	0
714844	714163	19619A	PARTICIPANT	\N	PRESENT	0
714845	714163	14331P	PARTICIPANT	\N	EXCUSE	0
715118	712589	11070L	PARTICIPANT	\N	PRESENT	0
715120	712589	14097Y	PARTICIPANT	\N	PRESENT	0
715121	712589	19715Y	PARTICIPANT	\N	PRESENT	0
715122	712589	19782L	PARTICIPANT	\N	PRESENT	0
715123	712589	20036X	PARTICIPANT	\N	PRESENT	0
715124	712589	19301E	PARTICIPANT	\N	PRESENT	0
715125	712589	19719D	PARTICIPANT	\N	PRESENT	0
715126	712589	04057K	PARTICIPANT	\N	PRESENT	0
715127	712589	14257W	PARTICIPANT	\N	PRESENT	0
715128	712589	19758L	PARTICIPANT	\N	PRESENT	0
715129	712589	20102Q	PARTICIPANT	\N	PRESENT	0
715130	712589	20046A	PARTICIPANT	\N	PRESENT	0
715131	712589	14021P	PARTICIPANT	\N	PRESENT	0
715132	712589	20142Y	PARTICIPANT	\N	PRESENT	0
715134	712589	17589D	PARTICIPANT	\N	PRESENT	0
715135	712589	19585H	PARTICIPANT	\N	PRESENT	0
715136	712589	19629C	PARTICIPANT	\N	PRESENT	0
715137	712589	14107H	PARTICIPANT	\N	PRESENT	0
715138	712589	20080C	PARTICIPANT	\N	PRESENT	0
715139	712589	11012A	PARTICIPANT	\N	PRESENT	0
715141	712589	14205J	PARTICIPANT	\N	PRESENT	0
715144	712589	19333N	PARTICIPANT	\N	PRESENT	0
715145	712589	20084G	PARTICIPANT	\N	PRESENT	0
715146	712589	14037X	PARTICIPANT	\N	PRESENT	0
715147	712589	14030Q	PARTICIPANT	\N	PRESENT	0
715148	712589	14219Q	PARTICIPANT	\N	PRESENT	0
715149	712589	20064C	PARTICIPANT	\N	PRESENT	0
715150	712589	20082E	PARTICIPANT	\N	PRESENT	0
715151	712589	01024M	PARTICIPANT	\N	PRESENT	0
715152	712589	14231L	PARTICIPANT	\N	PRESENT	0
715153	712589	19713W	PARTICIPANT	\N	PRESENT	0
715154	712589	20122U	PARTICIPANT	\N	PRESENT	0
715155	712589	14189C	PARTICIPANT	\N	PRESENT	0
715156	712589	07004J	PARTICIPANT	\N	PRESENT	0
715158	712589	01025N	PARTICIPANT	\N	PRESENT	0
715159	712589	19335Q	PARTICIPANT	\N	PRESENT	0
715160	712589	14073Q	PARTICIPANT	\N	PRESENT	0
715161	712589	19826F	PARTICIPANT	\N	PRESENT	0
715162	712589	14053L	PARTICIPANT	\N	PRESENT	0
715163	712589	20118Y	PARTICIPANT	\N	PRESENT	0
715164	712589	97011G	PARTICIPANT	\N	PRESENT	0
715165	712589	19762G	PARTICIPANT	\N	PRESENT	0
715166	712589	20062A	PARTICIPANT	\N	PRESENT	0
715167	712589	20090E	PARTICIPANT	\N	PRESENT	0
715168	712589	14173T	PARTICIPANT	\N	PRESENT	0
715169	712589	14038Y	PARTICIPANT	\N	PRESENT	0
715170	712589	14147R	PARTICIPANT	\N	PRESENT	0
715171	712589	20056C	PARTICIPANT	\N	PRESENT	0
715172	712589	19467C	PARTICIPANT	\N	PRESENT	0
715173	712589	20086J	PARTICIPANT	\N	PRESENT	0
715174	712589	19679N	PARTICIPANT	\N	PRESENT	0
715175	712589	19691J	PARTICIPANT	\N	PRESENT	0
715176	712589	20042V	PARTICIPANT	\N	PRESENT	0
715177	712589	14083S	PARTICIPANT	\N	PRESENT	0
715179	712589	08009T	PARTICIPANT	\N	PRESENT	0
715180	712589	14033T	PARTICIPANT	\N	PRESENT	0
715181	712589	19725B	PARTICIPANT	\N	PRESENT	0
715182	712589	20030R	PARTICIPANT	\N	PRESENT	0
715183	712589	19631V	PARTICIPANT	\N	PRESENT	0
715184	712589	14069U	PARTICIPANT	\N	PRESENT	0
715185	712589	04047H	PARTICIPANT	\N	PRESENT	0
715186	712589	19563B	PARTICIPANT	\N	PRESENT	0
715187	712589	20172F	PARTICIPANT	\N	PRESENT	0
715188	712589	14357A	PARTICIPANT	\N	PRESENT	0
715189	712589	20180F	PARTICIPANT	\N	PRESENT	0
715190	712589	19399H	PARTICIPANT	\N	PRESENT	0
715191	712589	14223L	PARTICIPANT	\N	PRESENT	0
715192	712589	17023S	PARTICIPANT	\N	PRESENT	0
715193	712589	20034V	PARTICIPANT	\N	PRESENT	0
715194	712589	20032T	PARTICIPANT	\N	PRESENT	0
715195	712589	19798U	PARTICIPANT	\N	PRESENT	0
715196	712589	19383Y	PARTICIPANT	\N	PRESENT	0
715245	712589	19489J	PARTICIPANT	\N	PRESENT	0
715198	712589	14191V	PARTICIPANT	\N	PRESENT	0
715199	712589	20248J	PARTICIPANT	\N	PRESENT	0
715200	712589	14109K	PARTICIPANT	\N	PRESENT	0
715201	712589	19503N	PARTICIPANT	\N	PRESENT	0
715202	712589	19533U	PARTICIPANT	\N	PRESENT	0
715237	712589	20110Q	PARTICIPANT	\N	PRESENT	0
715238	712589	19749K	PARTICIPANT	\N	PRESENT	0
715252	712589	19415P	PARTICIPANT	\N	PRESENT	0
715277	712589	01057W	PARTICIPANT	\N	PRESENT	0
715278	712589	10015M	PARTICIPANT	\N	PRESENT	0
715280	712589	20120S	PARTICIPANT	\N	PRESENT	0
715281	712589	19553Y	PARTICIPANT	\N	PRESENT	0
716531	716530	04042C	PARTICIPANT	\N	PRESENT	0
716532	716530	14267Y	PARTICIPANT	\N	PRESENT	0
716534	716533	14331P	PARTICIPANT	\N	PRESENT	0
716537	716535	14331P	PARTICIPANT	\N	PRESENT	0
717669	717667	19741B	PARTICIPANT	\N	PRESENT	0
717666	704312	07029T	PARTICIPANT	\N	EXCUSE	0
717668	717667	14225N	PRESIDENT	0	PRESENT	0
717670	717667	19667J	PARTICIPANT	\N	PRESENT	0
717671	717667	20116W	PARTICIPANT	\N	PRESENT	0
717672	717667	20086J	PARTICIPANT	\N	PRESENT	0
717673	717667	11040E	PARTICIPANT	\N	PRESENT	0
717674	717667	20080C	PARTICIPANT	\N	PRESENT	0
717675	717667	14083S	PARTICIPANT	\N	PRESENT	0
717676	717667	11053K	PARTICIPANT	\N	PRESENT	0
717677	717667	14327T	PARTICIPANT	\N	PRESENT	0
717678	717667	11074Q	PARTICIPANT	\N	PRESENT	0
717679	717667	19647E	PARTICIPANT	\N	PRESENT	0
717680	717667	01057W	PARTICIPANT	\N	PRESENT	0
717681	717667	11048N	PARTICIPANT	\N	PRESENT	0
717682	717667	14121F	PARTICIPANT	\N	PRESENT	0
717683	717667	20126Y	PARTICIPANT	\N	PRESENT	0
717684	717667	19711U	PARTICIPANT	\N	PRESENT	0
717685	717667	08010L	PARTICIPANT	\N	PRESENT	0
717686	717667	01048V	PARTICIPANT	\N	PRESENT	0
717687	717667	19671E	PARTICIPANT	\N	PRESENT	0
717688	717667	14253S	PARTICIPANT	\N	PRESENT	0
717689	717667	20036X	PARTICIPANT	\N	PRESENT	0
717690	717667	19349W	PARTICIPANT	\N	PRESENT	0
717691	717667	14331P	PARTICIPANT	\N	PRESENT	0
717692	717667	11012A	PARTICIPANT	\N	PRESENT	0
717693	717667	20044X	PARTICIPANT	\N	PRESENT	0
717694	717667	19762G	PARTICIPANT	\N	PRESENT	0
717695	717667	19479G	PARTICIPANT	\N	PRESENT	0
717696	717667	14173T	PARTICIPANT	\N	PRESENT	0
717699	716556	20286Q	PARTICIPANT	\N	PRESENT	0
717700	716556	04070G	PARTICIPANT	\N	PRESENT	0
717701	716556	14169X	PARTICIPANT	\N	PRESENT	0
717702	716556	20104S	PARTICIPANT	\N	PRESENT	0
717703	716556	14026U	PARTICIPANT	\N	PRESENT	0
717704	716556	14331P	PRESIDENT	0	PRESENT	0
717705	716556	08034U	PARTICIPANT	\N	PRESENT	0
717706	716556	14357A	PARTICIPANT	\N	PRESENT	0
717707	716556	04035D	PARTICIPANT	\N	PRESENT	0
717708	716556	20100N	PARTICIPANT	\N	PRESENT	0
717709	716556	19553Y	PARTICIPANT	\N	PRESENT	0
717710	716556	04045F	PARTICIPANT	\N	PRESENT	0
717711	716556	04057K	PARTICIPANT	\N	PRESENT	0
717713	716556	11026G	PARTICIPANT	\N	PRESENT	0
717714	716556	19531S	PARTICIPANT	\N	PRESENT	0
717715	716556	14189C	PARTICIPANT	\N	EXCUSE	0
717716	716556	20094J	PARTICIPANT	\N	PRESENT	0
717717	716556	14073Q	PARTICIPANT	\N	EXCUSE	0
717718	716556	14237S	PARTICIPANT	\N	PRESENT	0
717720	716556	14033T	PARTICIPANT	\N	PRESENT	0
717721	716556	20128B	PARTICIPANT	\N	PRESENT	0
717723	716556	14001X	PARTICIPANT	\N	PRESENT	0
718269	715963	20086J	PARTICIPANT	\N	PRESENT	0
718270	715963	20264J	PARTICIPANT	\N	PRESENT	0
718271	715963	20980G	PARTICIPANT	\N	PRESENT	0
718272	715963	20106U	PARTICIPANT	\N	PRESENT	0
718273	715963	19335Q	PRESIDENT	0	PRESENT	0
718274	715963	20026V	PARTICIPANT	\N	PRESENT	0
718275	715963	14109K	PARTICIPANT	\N	PRESENT	0
718276	715963	11027H	PARTICIPANT	\N	PRESENT	0
718277	715963	14147R	PARTICIPANT	\N	PRESENT	0
718278	715963	19709B	PARTICIPANT	\N	PRESENT	0
718353	718352	20112S	PARTICIPANT	\N	PRESENT	1
718354	718352	19643A	PARTICIPANT	\N	PRESENT	0
718355	718352	19735D	PARTICIPANT	\N	PRESENT	0
718358	718357	20106U	PARTICIPANT	\N	PRESENT	0
718359	718357	19335Q	PARTICIPANT	\N	PRESENT	1
718361	718357	20142Y	PARTICIPANT	\N	PRESENT	1
718382	718381	04042C	PARTICIPANT	\N	PRESENT	0
718383	718381	19709B	PARTICIPANT	\N	PRESENT	0
718384	718381	04059M	PARTICIPANT	\N	PRESENT	0
718385	718381	19503N	PARTICIPANT	\N	PRESENT	0
718386	718381	19565D	PARTICIPANT	\N	PRESENT	0
718387	718381	14187A	PARTICIPANT	\N	PRESENT	0
718388	718381	19699S	PARTICIPANT	\N	PRESENT	0
718390	718381	14281W	PARTICIPANT	\N	PRESENT	0
718624	718455	14331P	PARTICIPANT	\N	PRESENT	0
718625	718455	20094J	PARTICIPANT	\N	PRESENT	0
718626	718455	11083R	PARTICIPANT	\N	PRESENT	0
718732	716528	19691J	PARTICIPANT	\N	PRESENT	0
718733	716528	20090E	PARTICIPANT	\N	PRESENT	0
718734	716528	14281W	PARTICIPANT	\N	PRESENT	0
718735	716529	19691J	PARTICIPANT	\N	PRESENT	0
718926	718925	19367Y	PARTICIPANT	\N	PRESENT	0
718927	718925	14213J	PARTICIPANT	\N	PRESENT	0
718928	718925	10006L	PARTICIPANT	\N	PRESENT	0
718929	718925	11067R	PARTICIPANT	\N	PRESENT	0
718941	718881	19768N	PARTICIPANT	0	PRESENT	0
718954	717722	20094J	PARTICIPANT	\N	EXCUSE	0
718955	717722	19745F	PARTICIPANT	\N	EXCUSE	0
718956	717722	05012A	PARTICIPANT	\N	EXCUSE	0
718957	718881	20094J	PARTICIPANT	\N	EXCUSE	0
718958	718881	19745F	PARTICIPANT	\N	EXCUSE	0
719025	719024	19621T	PARTICIPANT	\N	PRESENT	0
719026	719024	14030Q	PARTICIPANT	\N	PRESENT	0
719027	719024	14109K	PARTICIPANT	\N	PRESENT	0
719028	719024	20180F	PARTICIPANT	\N	PRESENT	1
719030	719029	20112S	PARTICIPANT	\N	PRESENT	1
719031	719029	19735D	PARTICIPANT	\N	PRESENT	0
719032	719029	19643A	PARTICIPANT	\N	PRESENT	0
719936	719935	20024T	PARTICIPANT	\N	PRESENT	0
719937	719935	14255U	PARTICIPANT	\N	PRESENT	0
719938	719935	14083S	PARTICIPANT	\N	PRESENT	0
719939	719935	11027H	PARTICIPANT	\N	PRESENT	0
719940	719935	20106U	PARTICIPANT	\N	PRESENT	0
719941	719935	05012A	PARTICIPANT	\N	PRESENT	0
719942	719935	12016W	PARTICIPANT	\N	PRESENT	0
719955	719954	19709B	PARTICIPANT	\N	PRESENT	0
719956	719954	11026G	PARTICIPANT	\N	PRESENT	0
719957	719954	11027H	PARTICIPANT	\N	PRESENT	0
719958	719954	20038A	PARTICIPANT	\N	PRESENT	0
719959	719954	01058X	PARTICIPANT	\N	PRESENT	0
719960	719954	08018U	PARTICIPANT	\N	PRESENT	0
719961	719954	14255U	PARTICIPANT	\N	PRESENT	0
719962	719954	04035D	PARTICIPANT	\N	PRESENT	0
719963	719954	10006L	PARTICIPANT	\N	PRESENT	0
719964	719954	19766L	PARTICIPANT	\N	PRESENT	0
719965	719954	19057M	PARTICIPANT	\N	PRESENT	0
719966	719954	14147R	PARTICIPANT	\N	PRESENT	0
719967	719954	20264J	PARTICIPANT	\N	PRESENT	0
719968	718509	04042C	PARTICIPANT	\N	PRESENT	0
719970	719969	14030Q	PARTICIPANT	\N	PRESENT	0
719971	719969	20152B	PARTICIPANT	\N	PRESENT	0
719972	719969	17737W	PARTICIPANT	\N	PRESENT	0
719973	719969	20134Y	PARTICIPANT	\N	PRESENT	0
719974	719969	11083R	PARTICIPANT	\N	PRESENT	0
719975	719969	14251Q	PARTICIPANT	\N	PRESENT	0
719976	719969	04070G	PARTICIPANT	\N	PRESENT	0
719977	719969	20064C	PARTICIPANT	\N	PRESENT	0
719982	717725	04070G	PARTICIPANT	\N	PRESENT	0
719983	717073	20980G	PARTICIPANT	\N	PRESENT	0
719984	717073	20106U	PARTICIPANT	\N	PRESENT	0
719985	717073	19685L	PARTICIPANT	\N	PRESENT	0
719986	717073	20056C	PARTICIPANT	\N	PRESENT	0
719987	717073	19335Q	PARTICIPANT	\N	PRESENT	0
719988	717073	20026V	PARTICIPANT	\N	PRESENT	0
719989	717073	19739H	PARTICIPANT	\N	PRESENT	0
719990	717073	14109K	PARTICIPANT	\N	PRESENT	0
719991	717073	20038A	PARTICIPANT	\N	PRESENT	0
719992	717078	19335Q	PRESIDENT	0	PRESENT	0
719993	717078	20106U	PARTICIPANT	\N	PRESENT	0
720019	720018	11109J	PARTICIPANT	\N	EXCUSE	0
720020	720018	04059M	PARTICIPANT	\N	PRESENT	0
720021	720018	20112S	PARTICIPANT	\N	PRESENT	0
720022	720018	19651A	PARTICIPANT	\N	PRESENT	0
720023	720018	14030Q	PARTICIPANT	\N	PRESENT	0
720024	720018	19643A	PARTICIPANT	\N	PRESENT	0
720025	720018	19621T	PARTICIPANT	\N	PRESENT	0
720026	720018	19057M	PARTICIPANT	\N	PRESENT	0
720027	720018	19758L	PARTICIPANT	\N	PRESENT	0
720028	720018	20264J	PARTICIPANT	\N	PRESENT	0
720029	720018	19693L	PARTICIPANT	\N	PRESENT	0
720030	720018	20152B	PARTICIPANT	\N	PRESENT	0
720031	720018	20980G	PARTICIPANT	\N	PRESENT	0
720032	720018	20134Y	PARTICIPANT	\N	PRESENT	0
720033	720018	20124W	PARTICIPANT	\N	PRESENT	0
723982	723381	19782L	PARTICIPANT	\N	PRESENT	0
723983	723381	11077T	PARTICIPANT	\N	PRESENT	0
723984	723381	20092G	PARTICIPANT	\N	PRESENT	0
723985	723381	01043Q	PARTICIPANT	\N	PRESENT	0
723986	723381	14357A	PARTICIPANT	\N	PRESENT	0
723987	723381	19441R	PARTICIPANT	\N	PRESENT	0
723988	723381	20078J	PARTICIPANT	\N	PRESENT	0
723989	723381	19413M	PARTICIPANT	\N	PRESENT	0
723990	723381	20082E	PARTICIPANT	\N	PRESENT	0
723991	723381	20094J	PARTICIPANT	\N	PRESENT	0
723992	723381	19866P	PARTICIPANT	\N	PRESENT	0
723993	723381	19631V	PARTICIPANT	\N	PRESENT	0
723994	723381	19705W	PARTICIPANT	\N	PRESENT	0
723995	723381	19707Y	PARTICIPANT	\N	PRESENT	0
723996	723381	08015R	PARTICIPANT	\N	PRESENT	0
723997	723381	19575F	PARTICIPANT	\N	PRESENT	0
723998	723381	19369B	PARTICIPANT	\N	PRESENT	0
723999	723381	20018V	PARTICIPANT	\N	PRESENT	0
724000	723381	19563B	PARTICIPANT	\N	PRESENT	0
724001	723381	08028W	PARTICIPANT	\N	PRESENT	0
724002	723381	20028X	PARTICIPANT	\N	PRESENT	0
724003	723381	14037X	PARTICIPANT	\N	PRESENT	0
724004	723381	14038Y	PARTICIPANT	\N	PRESENT	0
724005	723381	19467C	PARTICIPANT	\N	PRESENT	0
724006	723381	14187A	PARTICIPANT	\N	PRESENT	0
724007	723381	20144B	PARTICIPANT	\N	PRESENT	0
724008	723381	19695N	PARTICIPANT	\N	PRESENT	0
724009	723381	14033T	PARTICIPANT	\N	PRESENT	0
724010	723381	11090Q	PARTICIPANT	\N	PRESENT	0
724011	723381	01025N	PARTICIPANT	\N	PRESENT	0
724012	723381	20054A	PARTICIPANT	\N	PRESENT	0
724013	723381	14205J	PARTICIPANT	\N	PRESENT	0
724014	723381	20060X	PARTICIPANT	\N	PRESENT	0
724015	723381	14251Q	PARTICIPANT	\N	PRESENT	0
724016	723381	19507S	PARTICIPANT	\N	PRESENT	0
724017	723381	20286Q	PARTICIPANT	\N	PRESENT	0
724018	723381	20298U	PARTICIPANT	\N	PRESENT	0
724019	723381	19747H	PARTICIPANT	\N	PRESENT	0
724020	723381	14207L	PARTICIPANT	\N	PRESENT	0
724021	723381	14257W	PARTICIPANT	\N	PRESENT	0
724022	723381	20030R	PARTICIPANT	\N	EXCUSE	0
724023	723381	04045F	PARTICIPANT	\N	EXCUSE	0
724325	724318	14331P	PARTICIPANT	\N	PRESENT	0
724330	724318	04047H	PARTICIPANT	\N	PRESENT	0
724335	724334	14033T	PARTICIPANT	\N	PRESENT	0
724337	724334	12041X	PARTICIPANT	\N	PRESENT	0
724338	724334	14073Q	PARTICIPANT	\N	PRESENT	0
724340	724339	14033T	PARTICIPANT	\N	PRESENT	0
724341	724339	12041X	PARTICIPANT	\N	PRESENT	0
724342	724339	14073Q	PARTICIPANT	\N	PRESENT	0
724344	724343	14073Q	PARTICIPANT	\N	PRESENT	0
724345	724343	12041X	PARTICIPANT	\N	PRESENT	0
724347	724346	14033T	PARTICIPANT	\N	PRESENT	0
724348	724346	12041X	PARTICIPANT	\N	PRESENT	0
724350	724349	14033T	PARTICIPANT	\N	PRESENT	0
724351	724349	14073Q	PARTICIPANT	\N	PRESENT	0
724352	724349	12041X	PARTICIPANT	\N	PRESENT	0
724355	724354	14033T	PARTICIPANT	\N	PRESENT	0
724356	724354	12041X	PARTICIPANT	\N	PRESENT	0
724358	724024	08034U	PARTICIPANT	\N	PRESENT	0
724359	724024	19333N	PARTICIPANT	\N	PRESENT	0
724361	724360	14026U	PARTICIPANT	\N	PRESENT	0
724363	724362	14026U	PARTICIPANT	\N	PRESENT	0
724365	724364	14026U	PARTICIPANT	\N	PRESENT	0
724367	724366	14026U	PARTICIPANT	\N	PRESENT	0
724369	724368	19333N	PARTICIPANT	\N	PRESENT	0
724378	724376	14033T	PARTICIPANT	\N	PRESENT	0
724379	724376	14073Q	PARTICIPANT	\N	PRESENT	0
724380	724376	12041X	PARTICIPANT	\N	PRESENT	0
724382	724381	14033T	PARTICIPANT	\N	PRESENT	0
724383	724381	14073Q	PARTICIPANT	\N	PRESENT	0
724384	724381	12041X	PARTICIPANT	\N	PRESENT	0
724386	724385	19333N	PARTICIPANT	\N	PRESENT	0
724387	724385	08034U	PARTICIPANT	\N	PRESENT	0
724389	724388	14033T	PARTICIPANT	\N	PRESENT	0
724390	724388	14073Q	PARTICIPANT	\N	PRESENT	0
724391	724388	12041X	PARTICIPANT	\N	PRESENT	0
724393	724392	19701S	PARTICIPANT	\N	PRESENT	0
724402	724400	08034U	PARTICIPANT	\N	PRESENT	0
724802	721823	17965H	PARTICIPANT	\N	PRESENT	0
724803	721823	20138D	PARTICIPANT	\N	PRESENT	0
724808	721823	11031D	PARTICIPANT	\N	PRESENT	0
724814	721823	19735D	PRESIDENT	0	PRESENT	0
724815	721823	19369B	PARTICIPANT	\N	PRESENT	0
724820	721823	20024T	PARTICIPANT	\N	PRESENT	0
724821	721823	14213J	PARTICIPANT	\N	PRESENT	0
725222	722809	14331P	PRESIDENT	0	PRESENT	0
725223	722809	19441R	PARTICIPANT	\N	PRESENT	0
725224	722809	20100N	PARTICIPANT	\N	PRESENT	0
725225	722809	14237S	PARTICIPANT	\N	PRESENT	0
725226	722809	11083R	PARTICIPANT	\N	PRESENT	0
725227	722809	14169X	PARTICIPANT	\N	PRESENT	0
725228	722809	14073Q	PARTICIPANT	\N	PRESENT	0
725229	722809	14001X	PARTICIPANT	\N	PRESENT	0
725234	722809	14133K	PARTICIPANT	\N	PRESENT	0
725235	722809	04070G	PARTICIPANT	\N	PRESENT	0
725236	722809	04042C	PARTICIPANT	\N	PRESENT	0
725237	722809	19347U	PARTICIPANT	\N	PRESENT	0
725238	722809	97011G	PARTICIPANT	\N	PRESENT	0
725240	725219	14331P	PARTICIPANT	\N	PRESENT	0
725241	725219	14073Q	PARTICIPANT	\N	PRESENT	0
725242	725219	11083R	PARTICIPANT	\N	PRESENT	0
725243	725219	20100N	PARTICIPANT	\N	PRESENT	0
725375	722682	08073C	PARTICIPANT	\N	PRESENT	0
725376	722682	08034U	PARTICIPANT	\N	PRESENT	0
725377	722682	19715Y	PARTICIPANT	\N	PRESENT	0
725378	722682	11072N	PARTICIPANT	\N	PRESENT	0
725379	722682	20146D	PARTICIPANT	\N	PRESENT	1
725428	722682	18083K	PARTICIPANT	\N	PRESENT	0
725484	725483	19349W	PARTICIPANT	\N	PRESENT	0
725486	725485	99004R	PARTICIPANT	\N	PRESENT	0
725488	725487	99004R	PARTICIPANT	\N	PRESENT	0
725490	725489	01048V	PARTICIPANT	\N	PRESENT	0
725492	725491	14331P	PARTICIPANT	\N	PRESENT	0
725494	725493	11053K	PARTICIPANT	\N	PRESENT	0
725495	725493	20024T	PARTICIPANT	\N	PRESENT	0
725496	725493	20116W	PARTICIPANT	\N	PRESENT	0
725497	725493	17229F	PARTICIPANT	\N	PRESENT	0
725498	725493	19251M	PARTICIPANT	\N	PRESENT	0
725499	725493	14211G	PARTICIPANT	\N	PRESENT	0
725500	725493	19611R	PARTICIPANT	\N	PRESENT	0
725501	725493	20052X	PARTICIPANT	\N	PRESENT	0
725502	725493	19671E	PARTICIPANT	\N	PRESENT	0
725503	725493	19745F	PARTICIPANT	\N	PRESENT	0
725504	725493	19349W	PARTICIPANT	\N	PRESENT	0
725509	725508	11053K	PARTICIPANT	\N	PRESENT	0
725511	725510	11053K	PARTICIPANT	\N	PRESENT	0
725569	725568	19693L	PARTICIPANT	\N	PRESENT	0
725572	725571	20286Q	PARTICIPANT	\N	PRESENT	0
725574	725573	20286Q	PARTICIPANT	\N	PRESENT	0
725575	725573	14251Q	PARTICIPANT	\N	PRESENT	0
725577	725576	20286Q	PARTICIPANT	\N	PRESENT	0
725578	725452	10006L	PARTICIPANT	\N	PRESENT	0
725579	725452	18193Q	PARTICIPANT	\N	PRESENT	0
725580	725452	14071N	PARTICIPANT	\N	PRESENT	0
725582	725581	19820Y	PARTICIPANT	\N	PRESENT	0
725592	725591	20106U	PARTICIPANT	\N	PRESENT	0
725599	725587	19820Y	PARTICIPANT	\N	PRESENT	0
725921	725920	08010L	PARTICIPANT	\N	PRESENT	0
725923	725922	08010L	PARTICIPANT	\N	PRESENT	0
726010	725555	20136B	PARTICIPANT	\N	PRESENT	0
726011	725555	19251M	PARTICIPANT	\N	EXCUSE	0
726012	725555	17637T	PARTICIPANT	\N	PRESENT	0
712570	709156	19673G	PARTICIPANT	\N	EXCUSE	0
715958	715223	20070A	PARTICIPANT	\N	PRESENT	0
715959	715223	19745F	PRESIDENT	0	PRESENT	0
715960	715223	14229S	PARTICIPANT	\N	PRESENT	0
715961	715223	19820Y	PARTICIPANT	\N	PRESENT	0
716373	716257	11043H	PARTICIPANT	\N	EXCUSE	0
716374	716257	14331P	PARTICIPANT	\N	EXCUSE	0
719283	717725	19766L	PARTICIPANT	\N	PRESENT	0
719284	717725	19699S	PARTICIPANT	\N	PRESENT	0
719285	717725	19533U	PARTICIPANT	\N	PRESENT	0
719286	717725	04033B	PARTICIPANT	\N	PRESENT	0
719287	717725	01060R	PARTICIPANT	\N	PRESENT	0
719288	717725	14229S	PARTICIPANT	\N	PRESENT	0
719289	717725	19573D	PARTICIPANT	\N	PRESENT	0
719290	717725	20112S	PARTICIPANT	\N	PRESENT	0
719291	717725	08012N	PARTICIPANT	\N	PRESENT	0
719292	717725	20124W	PARTICIPANT	\N	PRESENT	0
719293	717725	20026V	PARTICIPANT	\N	PRESENT	0
719294	717725	19593H	PARTICIPANT	\N	PRESENT	0
719295	717725	19527W	PARTICIPANT	\N	PRESENT	0
719296	717725	20132W	PARTICIPANT	\N	PRESENT	0
719297	717725	19643A	PARTICIPANT	\N	PRESENT	0
719298	717725	20134Y	PARTICIPANT	\N	PRESENT	0
719299	717725	19651A	PARTICIPANT	\N	PRESENT	0
719300	717725	19611R	PRESIDENT	0	PRESENT	0
719301	717725	20142Y	PARTICIPANT	\N	PRESENT	0
719302	717725	20048C	PARTICIPANT	\N	PRESENT	0
719303	717725	19693L	PARTICIPANT	\N	PRESENT	0
719304	717725	19399H	PARTICIPANT	\N	PRESENT	0
719305	717725	20152B	PARTICIPANT	\N	PRESENT	0
719306	717725	20052X	PARTICIPANT	\N	PRESENT	0
719307	717725	19719D	PARTICIPANT	\N	PRESENT	0
719308	717725	20172F	PARTICIPANT	\N	PRESENT	0
719309	717725	20058E	PARTICIPANT	\N	PRESENT	0
719310	717725	14030Q	PARTICIPANT	\N	PRESENT	0
719311	717725	20056C	PARTICIPANT	\N	PRESENT	0
719312	717725	20180F	PARTICIPANT	\N	PRESENT	0
719313	717725	20264J	PARTICIPANT	\N	PRESENT	0
719314	717725	04059M	PARTICIPANT	\N	PRESENT	0
719315	717725	19735D	PARTICIPANT	\N	PRESENT	0
719316	717725	19057M	PARTICIPANT	\N	PRESENT	0
719317	717725	14109K	PARTICIPANT	\N	PRESENT	0
719318	717725	14123H	PARTICIPANT	\N	PRESENT	0
719319	717725	11043H	PARTICIPANT	\N	PRESENT	0
719320	717725	11104D	PARTICIPANT	\N	PRESENT	0
719321	717725	20980G	PARTICIPANT	\N	PRESENT	0
719322	717725	19758L	PARTICIPANT	\N	PRESENT	0
719323	717725	19621T	PARTICIPANT	\N	PRESENT	0
719324	717725	20084G	PARTICIPANT	\N	PRESENT	0
719325	717725	11109J	PARTICIPANT	\N	EXCUSE	0
719326	717725	20098N	PARTICIPANT	\N	EXCUSE	0
719331	718393	19697Q	PARTICIPANT	\N	PRESENT	0
719332	718393	11067R	PARTICIPANT	\N	PRESENT	0
719333	718393	14026U	PARTICIPANT	\N	PRESENT	0
719335	719055	19709B	PARTICIPANT	\N	PRESENT	0
719347	718393	04057K	PARTICIPANT	\N	PRESENT	0
719381	718393	11097X	PARTICIPANT	\N	PRESENT	0
719398	717526	19333N	PARTICIPANT	\N	PRESENT	0
719399	717526	20076G	PARTICIPANT	\N	PRESENT	0
719400	717526	19387D	PARTICIPANT	\N	PRESENT	0
719401	717526	19820Y	PARTICIPANT	\N	PRESENT	0
719402	717526	14219Q	PRESIDENT	0	PRESENT	0
719403	717526	19826F	PARTICIPANT	\N	PRESENT	0
719404	717526	14221J	PARTICIPANT	\N	PRESENT	0
719405	717526	19599P	PARTICIPANT	\N	PRESENT	0
719406	717526	20102Q	PARTICIPANT	\N	PRESENT	0
719407	717526	11070L	PARTICIPANT	\N	PRESENT	0
719408	717526	20096L	PARTICIPANT	\N	PRESENT	0
719409	717526	19637C	PARTICIPANT	\N	PRESENT	0
719410	717526	18083K	PARTICIPANT	\N	PRESENT	0
719411	717526	19551W	PARTICIPANT	\N	PRESENT	0
719412	717526	20100N	PARTICIPANT	\N	PRESENT	0
719413	717526	05012A	PARTICIPANT	\N	PRESENT	0
719414	717526	08060W	PARTICIPANT	\N	PRESENT	0
719415	717526	20106U	PARTICIPANT	\N	PRESENT	0
719416	717526	20118Y	PARTICIPANT	\N	PRESENT	0
719417	717526	19503N	PARTICIPANT	\N	PRESENT	0
719418	717526	19685L	PARTICIPANT	\N	PRESENT	0
719419	717526	17367Q	PARTICIPANT	\N	PRESENT	0
719420	717526	20024T	PARTICIPANT	\N	PRESENT	0
719421	717526	19525U	PARTICIPANT	\N	PRESENT	0
719422	717526	20032T	PARTICIPANT	\N	PRESENT	0
719423	717526	20122U	PARTICIPANT	\N	PRESENT	0
719424	717526	20136B	PARTICIPANT	\N	PRESENT	0
719425	717526	20038A	PARTICIPANT	\N	PRESENT	0
719426	717526	14031R	PARTICIPANT	\N	PRESENT	0
719427	717526	14169X	PARTICIPANT	\N	PRESENT	0
719428	717526	20068G	PARTICIPANT	\N	PRESENT	0
719429	717526	11101A	PARTICIPANT	\N	PRESENT	0
719430	717526	19739H	PARTICIPANT	\N	PRESENT	0
719431	717526	14121F	PARTICIPANT	\N	PRESENT	0
719432	717526	14237S	PARTICIPANT	\N	PRESENT	0
719577	718605	20092G	PARTICIPANT	\N	PRESENT	0
719578	718605	08011M	PARTICIPANT	\N	PRESENT	0
719579	718605	20142Y	PARTICIPANT	\N	PRESENT	0
719580	718605	19711U	PARTICIPANT	\N	PRESENT	0
719581	718605	11033F	PARTICIPANT	\N	PRESENT	0
719582	718605	19651A	PARTICIPANT	\N	PRESENT	0
719583	718605	20914V	PARTICIPANT	\N	PRESENT	0
719584	718605	04008A	PARTICIPANT	\N	PRESENT	0
719585	718605	19782L	PARTICIPANT	\N	PRESENT	0
719586	718605	19693L	PARTICIPANT	\N	PRESENT	0
719587	718605	14037X	PARTICIPANT	\N	PRESENT	0
719588	718605	99004R	PARTICIPANT	\N	PRESENT	0
719589	718605	20016T	PARTICIPANT	\N	PRESENT	0
719590	718605	11072N	PARTICIPANT	\N	PRESENT	0
719591	718605	20076G	PARTICIPANT	\N	PRESENT	0
719592	718605	95063L	PARTICIPANT	\N	PRESENT	0
719593	718605	19591F	PARTICIPANT	\N	PRESENT	0
719594	718605	04045F	PARTICIPANT	\N	PRESENT	0
719595	718605	08073C	PARTICIPANT	\N	PRESENT	0
719596	718605	19637C	PARTICIPANT	\N	PRESENT	0
719597	718605	19349W	PARTICIPANT	\N	PRESENT	0
719598	718605	20146D	PARTICIPANT	\N	PRESENT	0
719599	718605	19301E	PARTICIPANT	\N	PRESENT	0
719600	718605	20086J	PARTICIPANT	\N	PRESENT	0
719601	718605	20106U	PARTICIPANT	\N	PRESENT	0
719602	718605	20128B	PARTICIPANT	\N	PRESENT	0
719603	718605	14038Y	PARTICIPANT	\N	PRESENT	0
719604	718605	14173T	PARTICIPANT	\N	PRESENT	0
719605	718605	14055N	PARTICIPANT	\N	PRESENT	0
719606	718605	19723Y	PARTICIPANT	\N	PRESENT	0
719607	718605	19717B	PARTICIPANT	\N	PRESENT	0
719608	718605	14207L	PARTICIPANT	\N	PRESENT	0
719609	718605	20044X	PARTICIPANT	\N	PRESENT	0
719610	718605	20038A	PARTICIPANT	\N	PRESENT	0
719611	718605	20132W	PARTICIPANT	\N	PRESENT	0
719612	718605	19387D	PARTICIPANT	\N	PRESENT	0
719613	718605	19573D	PARTICIPANT	\N	PRESENT	0
719614	718605	20980G	PARTICIPANT	\N	PRESENT	0
719615	718605	11083R	PARTICIPANT	\N	PRESENT	0
719616	718605	20096L	PARTICIPANT	\N	PRESENT	0
719617	718605	20056C	PARTICIPANT	\N	PRESENT	0
719618	718605	19709B	PARTICIPANT	\N	PRESENT	0
719619	718605	14251Q	PARTICIPANT	\N	PRESENT	0
719620	718605	08018U	PARTICIPANT	\N	PRESENT	0
719621	718605	20122U	PARTICIPANT	\N	PRESENT	0
719622	718605	04057K	PARTICIPANT	\N	PRESENT	0
719623	718605	19563B	PARTICIPANT	\N	PRESENT	0
719624	718605	14031R	PARTICIPANT	\N	PRESENT	0
719625	718605	19329S	PARTICIPANT	\N	PRESENT	0
719626	718605	14259Y	PARTICIPANT	\N	PRESENT	0
719627	718605	14249W	PARTICIPANT	\N	PRESENT	0
719628	718605	11045K	PARTICIPANT	\N	PRESENT	0
719629	718605	14225N	PARTICIPANT	\N	PRESENT	0
719630	718605	11074Q	PARTICIPANT	\N	PRESENT	0
719631	718605	14151M	PARTICIPANT	\N	PRESENT	0
719632	718605	11099A	PARTICIPANT	\N	PRESENT	0
719633	718605	20130U	PARTICIPANT	\N	PRESENT	0
719634	718605	11041F	PARTICIPANT	\N	PRESENT	0
719635	718605	11066Q	PARTICIPANT	\N	PRESENT	0
719636	718605	19667J	PARTICIPANT	\N	PRESENT	0
719637	718605	19527W	PARTICIPANT	\N	PRESENT	0
719638	718605	20064C	PARTICIPANT	\N	PRESENT	0
719639	718605	01057W	PARTICIPANT	\N	PRESENT	0
719640	718605	01062T	PARTICIPANT	\N	PRESENT	0
719641	718605	19399H	PARTICIPANT	\N	PRESENT	0
719642	718605	20084G	PARTICIPANT	\N	PRESENT	0
719643	718605	19729F	PARTICIPANT	\N	PRESENT	0
719644	718605	14229S	PARTICIPANT	\N	PRESENT	0
719645	718605	20082E	PARTICIPANT	\N	PRESENT	0
715367	712590	14179A	PARTICIPANT	\N	PRESENT	0
715368	712590	19715Y	PARTICIPANT	\N	PRESENT	0
715370	712590	19489J	PARTICIPANT	\N	PRESENT	0
715371	712590	20080C	PARTICIPANT	\N	PRESENT	0
715372	712590	19599P	PARTICIPANT	\N	PRESENT	0
715373	712590	14121F	PARTICIPANT	\N	PRESENT	0
715377	712590	20110Q	PARTICIPANT	\N	PRESENT	0
715378	712590	20036X	PARTICIPANT	\N	PRESENT	0
715379	712590	95063L	PARTICIPANT	\N	PRESENT	0
715380	712590	11056N	PARTICIPANT	\N	PRESENT	0
715381	712590	19585H	PARTICIPANT	\N	PRESENT	0
715382	712590	20122U	PARTICIPANT	\N	PRESENT	0
715383	712590	14107H	PARTICIPANT	\N	PRESENT	0
715384	712590	19713W	PARTICIPANT	\N	PRESENT	0
715385	712590	16685X	PARTICIPANT	\N	PRESENT	0
715386	712590	14083S	PARTICIPANT	\N	PRESENT	0
715387	712590	07004J	PARTICIPANT	\N	PRESENT	0
715388	712590	19749K	PARTICIPANT	\N	PRESENT	0
715389	712590	08009T	PARTICIPANT	\N	PRESENT	0
715390	712590	01024M	PARTICIPANT	\N	PRESENT	0
715391	712590	19611R	PARTICIPANT	\N	PRESENT	0
715392	712590	14231L	PARTICIPANT	\N	PRESENT	0
715393	712590	14223L	PARTICIPANT	\N	PRESENT	0
715394	712590	14215L	PARTICIPANT	\N	PRESENT	0
715395	712590	19798U	PARTICIPANT	\N	PRESENT	0
715396	712590	14053L	PARTICIPANT	\N	PRESENT	0
715397	712590	20090E	PARTICIPANT	\N	PRESENT	0
715398	712590	20062A	PARTICIPANT	\N	PRESENT	0
715399	712590	19399H	PARTICIPANT	\N	PRESENT	0
715400	712590	20180F	PARTICIPANT	\N	PRESENT	0
715401	712590	01057W	PARTICIPANT	\N	PRESENT	0
715402	712590	19693L	PARTICIPANT	\N	PRESENT	0
715403	712590	14191V	PARTICIPANT	\N	PRESENT	0
715404	712590	19673G	PARTICIPANT	\N	PRESENT	0
715405	712590	20034V	PARTICIPANT	\N	PRESENT	0
715406	712590	14038Y	PARTICIPANT	\N	PRESENT	0
715407	712590	19820Y	PARTICIPANT	\N	PRESENT	0
715408	712590	19441R	PARTICIPANT	\N	PRESENT	0
715409	712590	19691J	PARTICIPANT	\N	PRESENT	0
715410	712590	19447X	PARTICIPANT	\N	PRESENT	0
715411	712590	14217N	PARTICIPANT	\N	PRESENT	0
715412	712590	19762G	PARTICIPANT	\N	PRESENT	0
715413	712590	19415P	PARTICIPANT	\N	PRESENT	0
715414	712590	20142Y	PARTICIPANT	\N	PRESENT	0
715415	712590	14195A	PARTICIPANT	\N	PRESENT	0
715416	712590	20100N	PARTICIPANT	\N	PRESENT	0
715417	712590	04047H	PARTICIPANT	\N	PRESENT	0
715365	712590	99004R	PARTICIPANT	\N	PRESENT	0
715366	712590	20022R	PARTICIPANT	\N	PRESENT	0
715418	712590	19758L	PARTICIPANT	\N	PRESENT	0
715419	712590	19569H	PARTICIPANT	\N	PRESENT	0
715420	712590	01028R	PARTICIPANT	\N	PRESENT	0
715421	712590	14147R	PARTICIPANT	\N	PRESENT	0
715422	712590	20024T	PARTICIPANT	\N	PRESENT	0
715423	712590	14033T	PARTICIPANT	\N	PRESENT	0
715424	712590	20126Y	PARTICIPANT	\N	PRESENT	0
715425	712590	20298U	PARTICIPANT	\N	PRESENT	0
715426	712590	01025N	PARTICIPANT	\N	PRESENT	0
715427	712590	20028X	PARTICIPANT	\N	PRESENT	0
715428	712590	14031R	PARTICIPANT	\N	PRESENT	0
715477	712591	20100N	PARTICIPANT	\N	PRESENT	0
715478	712591	04057K	PARTICIPANT	\N	PRESENT	0
715479	712591	19553Y	PARTICIPANT	\N	PRESENT	0
715480	712591	14026U	PARTICIPANT	\N	PRESENT	0
715481	712591	19687N	PARTICIPANT	\N	PRESENT	0
715482	712591	11026G	PARTICIPANT	\N	PRESENT	0
715483	712591	14189C	PARTICIPANT	\N	PRESENT	0
715484	712591	14021P	PARTICIPANT	\N	PRESENT	0
715485	712591	14331P	PARTICIPANT	\N	PRESENT	0
715486	712591	14255U	PARTICIPANT	\N	PRESENT	0
715487	712591	11048N	PARTICIPANT	\N	PRESENT	0
715488	712591	19593H	PARTICIPANT	\N	PRESENT	0
715489	712591	20086J	PARTICIPANT	\N	PRESENT	0
715490	712591	11083R	PARTICIPANT	\N	PRESENT	0
715491	712591	95063L	PARTICIPANT	\N	PRESENT	0
715492	712591	14097Y	PARTICIPANT	\N	PRESENT	0
715493	712591	20122U	PARTICIPANT	\N	PRESENT	0
715494	712591	19701S	PARTICIPANT	\N	PRESENT	0
715495	712591	20134Y	PARTICIPANT	\N	PRESENT	0
715496	712591	14147R	PARTICIPANT	\N	PRESENT	0
715497	712591	18083K	PARTICIPANT	\N	PRESENT	0
715498	712591	19575F	PARTICIPANT	\N	PRESENT	0
715499	712591	20126Y	PARTICIPANT	\N	PRESENT	0
715500	712591	20092G	PARTICIPANT	\N	PRESENT	0
715501	712591	14033T	PARTICIPANT	\N	PRESENT	0
715502	712591	14069U	PARTICIPANT	\N	PRESENT	0
715503	712591	14179A	PARTICIPANT	\N	PRESENT	0
715504	712591	20070A	PARTICIPANT	\N	PRESENT	0
715505	712591	19563B	PARTICIPANT	\N	PRESENT	0
715727	709156	19715Y	PARTICIPANT	\N	PRESENT	0
715729	709156	11072N	PARTICIPANT	\N	PRESENT	0
715731	713477	19715Y	PRESIDENT	0	PRESENT	0
715732	713477	20034V	PARTICIPANT	\N	PRESENT	0
715734	713477	20098N	PARTICIPANT	\N	PRESENT	0
715735	713477	11072N	PARTICIPANT	\N	PRESENT	0
715892	713477	14030Q	PRESIDENT	1	PRESENT	0
715893	713477	97011G	PARTICIPANT	\N	PRESENT	0
715923	713477	18083K	PARTICIPANT	\N	PRESENT	0
716538	716257	19295A	PARTICIPANT	\N	EXCUSE	0
716540	716369	04059M	PARTICIPANT	\N	PRESENT	0
716541	716369	14073Q	PARTICIPANT	\N	PRESENT	0
716542	716369	19611R	PARTICIPANT	\N	PRESENT	0
716543	716369	08012N	PARTICIPANT	\N	PRESENT	0
716544	716369	20052X	PARTICIPANT	\N	PRESENT	0
716545	716369	19057M	PARTICIPANT	\N	PRESENT	0
716546	716368	14073Q	PARTICIPANT	\N	PRESENT	0
715475	712591	19719D	PARTICIPANT	\N	PRESENT	0
715476	712591	19531S	PARTICIPANT	\N	PRESENT	0
717697	716563	19820Y	PARTICIPANT	\N	PRESENT	0
717698	716563	14229S	PARTICIPANT	\N	PRESENT	0
717712	716563	05012A	PARTICIPANT	\N	PRESENT	0
718376	716564	19820Y	PARTICIPANT	\N	PRESENT	0
718377	716564	05012A	PARTICIPANT	\N	PRESENT	0
718397	716564	14169X	PARTICIPANT	\N	PRESENT	0
718398	716565	19820Y	PARTICIPANT	\N	PRESENT	0
718400	716565	14169X	PARTICIPANT	\N	PRESENT	0
718401	716565	14229S	PARTICIPANT	\N	PRESENT	0
718431	716257	20016T	PARTICIPANT	\N	PRESENT	0
718432	716257	19717B	PARTICIPANT	\N	PRESENT	1
718433	716257	19329S	PARTICIPANT	\N	PRESENT	1
718482	718481	14069U	PARTICIPANT	\N	PRESENT	0
718483	718481	14259Y	PARTICIPANT	\N	PRESENT	0
718484	718481	10006L	PARTICIPANT	\N	PRESENT	0
718485	718481	14215L	PARTICIPANT	\N	PRESENT	0
718486	718481	14151M	PARTICIPANT	\N	PRESENT	0
718487	718481	14187A	PARTICIPANT	\N	PRESENT	0
718488	718481	19673G	PARTICIPANT	\N	PRESENT	0
718489	718481	20098N	PARTICIPANT	\N	PRESENT	0
718490	718481	14225N	PARTICIPANT	\N	PRESENT	0
718491	718481	14071N	PARTICIPANT	\N	PRESENT	0
718492	718481	20052X	PARTICIPANT	\N	PRESENT	0
718493	718481	20126Y	PARTICIPANT	\N	PRESENT	0
718494	718481	14097Y	PARTICIPANT	\N	PRESENT	0
718495	718481	19531S	PARTICIPANT	\N	PRESENT	0
718496	718481	19333N	PARTICIPANT	\N	PRESENT	0
718497	718481	20120S	PARTICIPANT	\N	PRESENT	0
718498	718481	14147R	PARTICIPANT	\N	PRESENT	0
718499	718481	14357A	PARTICIPANT	\N	PRESENT	0
718501	718500	04033B	PARTICIPANT	\N	PRESENT	0
718502	718500	19251M	PARTICIPANT	\N	PRESENT	0
718503	718500	17737W	PARTICIPANT	\N	PRESENT	0
718504	718500	19643A	PARTICIPANT	\N	PRESENT	0
718506	718500	07033P	PARTICIPANT	\N	PRESENT	0
718507	718500	19593H	PARTICIPANT	\N	PRESENT	0
718508	718500	19713W	PARTICIPANT	\N	PRESENT	0
718510	718509	17737W	PARTICIPANT	\N	PRESENT	0
718511	718509	19251M	PARTICIPANT	\N	PRESENT	0
718512	718509	04033B	PARTICIPANT	\N	PRESENT	0
718513	718509	19593H	PARTICIPANT	\N	PRESENT	0
718514	718509	19643A	PARTICIPANT	\N	PRESENT	0
718519	718518	20024T	PARTICIPANT	\N	PRESENT	0
718516	718509	19713W	PARTICIPANT	\N	PRESENT	0
718517	718509	07033P	PARTICIPANT	\N	PRESENT	0
718520	718518	11074Q	PARTICIPANT	\N	PRESENT	0
718521	718518	04035D	PARTICIPANT	\N	PRESENT	0
718522	718518	14026U	PARTICIPANT	\N	PRESENT	0
718523	718518	01057W	PARTICIPANT	\N	PRESENT	0
718524	718518	14147R	PARTICIPANT	\N	PRESENT	0
718525	718518	20064C	PARTICIPANT	\N	PRESENT	0
718526	718518	14225N	PARTICIPANT	\N	PRESENT	0
718425	716257	20034V	PRESIDENT	0	PRESENT	0
718426	716257	14059S	PARTICIPANT	\N	PRESENT	0
718427	716257	11072N	PARTICIPANT	\N	PRESENT	0
718428	704312	19798U	PARTICIPANT	\N	PRESENT	0
718429	704312	20066E	PARTICIPANT	\N	PRESENT	0
718430	704312	14030Q	PRESIDENT	0	PRESENT	0
719197	718543	14331P	PARTICIPANT	\N	EXCUSE	0
719279	719278	11053K	PARTICIPANT	\N	PRESENT	0
719213	719211	20140W	PARTICIPANT	\N	PRESENT	0
719216	719215	20140W	PARTICIPANT	\N	PRESENT	0
719280	719278	19251M	PARTICIPANT	\N	PRESENT	0
719281	719278	20180F	PARTICIPANT	\N	PRESENT	0
719282	719278	19762G	PARTICIPANT	\N	PRESENT	0
719327	719278	20052X	PARTICIPANT	\N	PRESENT	0
719329	719328	11053K	PARTICIPANT	\N	PRESENT	0
719330	719328	19251M	PARTICIPANT	\N	PRESENT	0
719345	719341	11053K	PARTICIPANT	\N	PRESENT	0
719346	719341	19251M	PARTICIPANT	\N	PRESENT	0
720034	720018	19719D	PARTICIPANT	\N	PRESENT	0
720035	720018	20132W	PARTICIPANT	\N	PRESENT	0
720036	720018	20172F	PARTICIPANT	\N	PRESENT	0
720037	720018	20180F	PARTICIPANT	\N	PRESENT	0
720038	720018	20048C	PARTICIPANT	\N	PRESENT	0
720039	720018	14123H	PARTICIPANT	\N	PRESENT	0
720040	720018	19399H	PARTICIPANT	\N	PRESENT	0
720041	720018	20056C	PARTICIPANT	\N	PRESENT	0
720042	720018	19611R	PRESIDENT	0	PRESENT	0
720043	720018	19735D	PARTICIPANT	\N	PRESENT	0
720044	720018	20052X	PARTICIPANT	\N	PRESENT	0
720045	720018	19699S	PARTICIPANT	\N	PRESENT	0
720046	720018	08012N	PARTICIPANT	\N	PRESENT	0
720047	720018	11104D	PARTICIPANT	\N	PRESENT	0
720048	720018	20142Y	PARTICIPANT	\N	PRESENT	0
720049	720018	01060R	PARTICIPANT	\N	PRESENT	0
720050	720018	14109K	PARTICIPANT	\N	PRESENT	0
720051	720018	04070G	PARTICIPANT	\N	PRESENT	0
720052	720018	19593H	PARTICIPANT	\N	PRESENT	0
720053	720018	19573D	PARTICIPANT	\N	PRESENT	0
720054	720018	19533U	PARTICIPANT	\N	PRESENT	0
720055	720018	19766L	PARTICIPANT	\N	PRESENT	0
720056	720018	04033B	PARTICIPANT	\N	PRESENT	0
720057	720018	14229S	PARTICIPANT	\N	PRESENT	0
720058	720018	11043H	PARTICIPANT	\N	PRESENT	0
720059	720018	20098N	PARTICIPANT	\N	EXCUSE	0
720060	720018	20084G	PARTICIPANT	\N	PRESENT	0
720061	720018	19527W	PARTICIPANT	\N	PRESENT	0
720062	720018	20058E	PARTICIPANT	\N	PRESENT	0
720063	720018	20026V	PARTICIPANT	\N	PRESENT	0
720093	718399	19295A	PARTICIPANT	\N	EXCUSE	0
720094	719776	19295A	PARTICIPANT	\N	EXCUSE	0
720217	720216	08073C	PARTICIPANT	\N	PRESENT	0
720218	720216	20150Y	PARTICIPANT	\N	PRESENT	0
720220	720219	08073C	PARTICIPANT	\N	PRESENT	0
720221	720219	20150Y	PARTICIPANT	\N	PRESENT	0
721361	719208	19057M	PARTICIPANT	\N	PRESENT	0
721362	719208	17589D	PARTICIPANT	\N	PRESENT	0
721363	719208	20016T	PARTICIPANT	\N	PRESENT	0
721364	719208	01060R	PARTICIPANT	\N	PRESENT	0
721365	719208	04033B	PARTICIPANT	\N	PRESENT	0
721366	719208	11109J	PARTICIPANT	\N	EXCUSE	0
721397	721396	86034E	PARTICIPANT	\N	PRESENT	0
721398	721396	14133K	PARTICIPANT	\N	PRESENT	0
721399	721396	04047H	PARTICIPANT	\N	PRESENT	0
721400	721396	19782L	PARTICIPANT	\N	PRESENT	0
721401	721396	19629C	PARTICIPANT	\N	PRESENT	0
721402	721396	14217N	PARTICIPANT	\N	PRESENT	0
721403	721396	14187A	PARTICIPANT	\N	PRESENT	0
721404	721396	19347U	PARTICIPANT	\N	PRESENT	0
721405	721396	11048N	PARTICIPANT	\N	PRESENT	0
721406	721396	14021P	PARTICIPANT	\N	PRESENT	0
721407	721396	12041X	PARTICIPANT	\N	PRESENT	0
721408	721396	14251Q	PARTICIPANT	\N	PRESENT	0
721409	721396	11085T	PARTICIPANT	\N	PRESENT	0
721410	721396	14331P	PARTICIPANT	\N	PRESENT	0
721411	721396	14225N	PARTICIPANT	\N	PRESENT	0
721412	721396	04033B	PARTICIPANT	\N	PRESENT	0
721413	721396	11045K	PARTICIPANT	\N	PRESENT	0
721414	721396	01028R	PARTICIPANT	\N	PRESENT	0
721814	719776	19715Y	PARTICIPANT	\N	PRESENT	1
722190	722149	20076G	PARTICIPANT	\N	PRESENT	0
722191	722149	20024T	PARTICIPANT	\N	PRESENT	0
722192	722149	19383Y	PARTICIPANT	\N	PRESENT	0
722193	722149	20090E	PARTICIPANT	\N	PRESENT	0
722196	722149	11103C	PARTICIPANT	\N	PRESENT	0
722198	722149	14329V	PARTICIPANT	\N	PRESENT	0
722199	722149	14357A	PARTICIPANT	\N	PRESENT	0
722201	722149	14187A	PARTICIPANT	\N	PRESENT	0
722202	722149	20038A	PARTICIPANT	\N	PRESENT	0
722203	722149	14213J	PARTICIPANT	\N	PRESENT	0
722204	722149	19723Y	PARTICIPANT	\N	PRESENT	0
722205	722149	14221J	PARTICIPANT	\N	PRESENT	0
722206	722149	20030R	PARTICIPANT	\N	PRESENT	0
722207	722149	14331P	PARTICIPANT	\N	PRESENT	0
722208	722149	14173T	PARTICIPANT	\N	PRESENT	0
722544	722543	14193X	PARTICIPANT	\N	PRESENT	0
724397	724394	20136B	PARTICIPANT	\N	PRESENT	0
724399	724398	20136B	PARTICIPANT	\N	PRESENT	0
724422	724421	14173T	PARTICIPANT	\N	PRESENT	0
724423	724421	11090Q	PARTICIPANT	\N	PRESENT	0
724424	724421	14133K	PARTICIPANT	\N	PRESENT	0
724425	724421	19545Y	PARTICIPANT	\N	PRESENT	0
724426	724421	18083K	PARTICIPANT	\N	PRESENT	0
724427	724421	08034U	PARTICIPANT	\N	PRESENT	0
724428	724421	14205J	PARTICIPANT	\N	PRESENT	0
724429	724421	11097X	PARTICIPANT	\N	PRESENT	0
725185	719507	19798U	PARTICIPANT	\N	PRESENT	0
725186	719507	20118Y	PARTICIPANT	\N	EXCUSE	0
725187	719507	19866P	PARTICIPANT	\N	EXCUSE	0
725188	719507	20080C	PARTICIPANT	\N	EXCUSE	0
725189	719507	20024T	PARTICIPANT	\N	PRESENT	0
725190	719507	19599P	PARTICIPANT	\N	PRESENT	0
725191	719507	14030Q	PRESIDENT	0	PRESENT	0
725192	719507	19749K	PARTICIPANT	\N	PRESENT	0
725193	719507	20066E	PARTICIPANT	\N	PRESENT	0
725194	719507	19693L	PARTICIPANT	\N	PRESENT	0
725195	719507	11031D	PARTICIPANT	\N	PRESENT	0
725196	719507	19715Y	PARTICIPANT	\N	PRESENT	0
725232	719507	07029T	PARTICIPANT	\N	EXCUSE	0
725239	719507	20098N	PARTICIPANT	\N	PRESENT	0
725352	725350	20180F	PARTICIPANT	\N	PRESENT	1
725353	725350	20142Y	PARTICIPANT	\N	PRESENT	1
725354	725350	20084G	PARTICIPANT	\N	PRESENT	1
725355	725350	20132W	PARTICIPANT	\N	PRESENT	1
725356	725351	20180F	PARTICIPANT	\N	PRESENT	1
725357	725351	20132W	PARTICIPANT	\N	PRESENT	1
725358	725351	20084G	PARTICIPANT	\N	PRESENT	1
725359	725351	20142Y	PARTICIPANT	\N	PRESENT	1
725601	725600	07033P	PARTICIPANT	\N	PRESENT	0
725602	725600	19551W	PARTICIPANT	\N	PRESENT	0
725604	725603	14255U	PARTICIPANT	\N	PRESENT	0
725613	725612	19335Q	PARTICIPANT	\N	PRESENT	0
725614	725612	20106U	PARTICIPANT	\N	PRESENT	0
725615	725230	20106U	PARTICIPANT	\N	PRESENT	0
725616	725230	19335Q	PARTICIPANT	\N	PRESENT	0
725617	725230	14147R	PARTICIPANT	\N	PRESENT	0
725640	725639	19701S	PARTICIPANT	\N	PRESENT	0
725642	725641	19701S	PARTICIPANT	\N	PRESENT	0
725644	725643	19701S	PARTICIPANT	\N	PRESENT	0
725646	725645	19701S	PARTICIPANT	\N	PRESENT	0
725655	725654	19701S	PARTICIPANT	\N	PRESENT	0
725657	725656	19701S	PARTICIPANT	\N	PRESENT	0
726425	725627	14281W	PARTICIPANT	\N	PRESENT	0
726426	725627	14195A	PARTICIPANT	\N	PRESENT	0
726427	725627	14217N	PARTICIPANT	\N	PRESENT	0
726428	725627	19683J	PARTICIPANT	\N	PRESENT	0
726429	725627	14223L	PARTICIPANT	\N	PRESENT	0
726430	725627	20090E	PARTICIPANT	\N	PRESENT	0
726431	725627	14042U	PARTICIPANT	\N	PRESENT	0
726432	725627	19703U	PARTICIPANT	\N	PRESENT	0
726433	725627	14213J	PARTICIPANT	\N	PRESENT	0
726434	725627	04092N	PARTICIPANT	\N	PRESENT	0
726435	725627	19415P	PARTICIPANT	\N	PRESENT	0
726436	725627	20148F	PARTICIPANT	\N	PRESENT	0
726437	725627	19657G	PARTICIPANT	\N	PRESENT	0
726438	725627	11103C	PARTICIPANT	\N	PRESENT	0
726439	725627	11067R	PARTICIPANT	\N	PRESENT	0
726440	725627	20066E	PARTICIPANT	\N	PRESENT	0
726441	725627	14071N	PARTICIPANT	\N	PRESENT	0
726442	725627	10006L	PRESIDENT	0	PRESENT	0
726443	725627	18193Q	PARTICIPANT	\N	PRESENT	0
726444	725627	19367Y	PARTICIPANT	\N	PRESENT	0
726568	726447	11053K	PARTICIPANT	\N	PRESENT	0
726569	726447	11074Q	PARTICIPANT	\N	PRESENT	0
726582	725627	19663E	PARTICIPANT	\N	PRESENT	0
726617	725627	04057K	PARTICIPANT	\N	PRESENT	0
726625	725627	19295A	PARTICIPANT	\N	PRESENT	0
726626	725627	04043D	PARTICIPANT	\N	PRESENT	0
726642	725627	01034P	PARTICIPANT	\N	PRESENT	0
726659	725627	20266L	PARTICIPANT	\N	PRESENT	0
726672	725628	19760E	PARTICIPANT	\N	PRESENT	0
726673	725628	19717B	PARTICIPANT	\N	PRESENT	0
726674	725628	19367Y	PARTICIPANT	\N	PRESENT	0
726675	725628	19415P	PARTICIPANT	\N	PRESENT	0
726676	725628	20090E	PARTICIPANT	\N	PRESENT	0
726677	725628	11103C	PARTICIPANT	\N	PRESENT	0
726678	725628	14195A	PARTICIPANT	\N	PRESENT	0
726679	725628	11031D	PARTICIPANT	\N	PRESENT	0
726680	725628	19663E	PARTICIPANT	\N	PRESENT	0
726681	725628	19295A	PARTICIPANT	\N	PRESENT	0
726682	725628	14217N	PARTICIPANT	\N	PRESENT	0
726683	725628	10006L	PARTICIPANT	\N	PRESENT	0
726684	725628	20248J	PARTICIPANT	\N	PRESENT	0
726685	725628	14042U	PARTICIPANT	\N	PRESENT	0
726686	725628	20040T	PARTICIPANT	\N	PRESENT	0
726687	725628	14281W	PARTICIPANT	\N	PRESENT	0
726688	725628	08045X	PARTICIPANT	\N	PRESENT	0
726689	725628	14355X	PARTICIPANT	\N	PRESENT	0
726690	725628	14026U	PARTICIPANT	\N	PRESENT	0
726691	725628	19691J	PARTICIPANT	\N	PRESENT	0
726692	725628	19329S	PARTICIPANT	\N	PRESENT	0
726693	725628	19569H	PARTICIPANT	\N	PRESENT	0
726694	725628	14213J	PARTICIPANT	\N	PRESENT	0
726695	725628	20066E	PARTICIPANT	\N	PRESENT	0
726696	725628	19683J	PARTICIPANT	\N	PRESENT	0
726697	725628	19723Y	PARTICIPANT	\N	PRESENT	0
726698	725628	18193Q	PARTICIPANT	\N	PRESENT	0
726699	725628	19697Q	PARTICIPANT	\N	PRESENT	0
726700	725628	17779H	PARTICIPANT	\N	EXCUSE	0
726701	725628	19657G	PARTICIPANT	\N	PRESENT	0
726702	725628	04057K	PARTICIPANT	\N	PRESENT	0
726703	725628	11067R	PARTICIPANT	\N	PRESENT	0
726704	725628	04092N	PARTICIPANT	\N	PRESENT	0
726705	725628	14071N	PARTICIPANT	\N	PRESENT	0
726706	725628	14223L	PARTICIPANT	\N	PRESENT	0
726708	725628	20148F	PARTICIPANT	\N	PRESENT	0
726709	725628	20130U	PARTICIPANT	\N	PRESENT	0
726710	725628	17965H	PARTICIPANT	\N	PRESENT	0
726711	725628	04043D	PARTICIPANT	\N	PRESENT	0
726712	725628	19798U	PARTICIPANT	\N	PRESENT	0
726261	725806	19725B	PARTICIPANT	\N	PRESENT	0
726713	725628	19679N	PARTICIPANT	\N	PRESENT	0
726714	725628	19703U	PARTICIPANT	\N	PRESENT	0
726715	725628	19713W	PARTICIPANT	\N	PRESENT	0
726716	725628	01034P	PARTICIPANT	\N	PRESENT	0
726717	725628	20266L	PARTICIPANT	\N	PRESENT	0
728235	728230	19415P	PARTICIPANT	\N	PRESENT	0
728236	728230	14217N	PARTICIPANT	\N	PRESENT	0
728237	728230	19798U	PARTICIPANT	\N	PRESENT	0
728238	728231	19415P	PARTICIPANT	\N	PRESENT	0
728239	728231	14217N	PARTICIPANT	\N	PRESENT	0
728240	728231	19798U	PARTICIPANT	\N	PRESENT	0
728243	728232	19415P	PARTICIPANT	\N	PRESENT	0
728244	728232	11067R	PARTICIPANT	\N	PRESENT	0
728245	728232	20130U	PARTICIPANT	\N	PRESENT	0
728247	728246	19367Y	PARTICIPANT	\N	PRESENT	0
728248	728246	14213J	PARTICIPANT	\N	PRESENT	0
728249	728246	19691J	PARTICIPANT	\N	PRESENT	0
728250	728246	14223L	PARTICIPANT	\N	PRESENT	0
728251	728246	20130U	PARTICIPANT	\N	PRESENT	0
728252	728246	11067R	PARTICIPANT	\N	PRESENT	0
728253	728233	10006L	PARTICIPANT	\N	PRESENT	0
728254	728233	14026U	PARTICIPANT	\N	PRESENT	0
728255	728233	14071N	PARTICIPANT	\N	PRESENT	0
728256	728233	11097X	PARTICIPANT	\N	PRESENT	0
728945	728944	04070G	PARTICIPANT	\N	PRESENT	0
728946	728944	20056C	PARTICIPANT	\N	PRESENT	0
730492	730483	20090E	PARTICIPANT	\N	PRESENT	0
730493	730483	14187A	PRESIDENT	0	PRESENT	0
730494	730483	19347U	PARTICIPANT	\N	PRESENT	0
730495	730483	20286Q	PARTICIPANT	\N	PRESENT	0
730496	730483	20124W	PARTICIPANT	\N	PRESENT	0
730497	730483	19525U	PARTICIPANT	\N	PRESENT	0
730691	730689	19503N	PARTICIPANT	\N	PRESENT	0
730693	730692	19693L	PARTICIPANT	\N	PRESENT	0
730701	730699	19693L	PARTICIPANT	\N	PRESENT	0
730704	730702	19693L	PARTICIPANT	\N	PRESENT	0
730706	730705	01057W	PARTICIPANT	\N	PRESENT	0
731229	731228	05008E	PARTICIPANT	\N	PRESENT	0
732327	730575	11031D	PARTICIPANT	\N	PRESENT	0
732744	730575	19735D	PRESIDENT	0	PRESENT	0
732745	730575	04045F	PARTICIPANT	\N	PRESENT	0
732746	730575	20266L	PARTICIPANT	\N	PRESENT	0
732747	730575	20066E	PARTICIPANT	\N	PRESENT	0
732748	730575	20126Y	PARTICIPANT	\N	PRESENT	0
732749	730575	19725B	PARTICIPANT	\N	PRESENT	0
732750	730575	17965H	PARTICIPANT	\N	PRESENT	0
732751	730575	04092N	PARTICIPANT	\N	PRESENT	0
732752	730575	14213J	PARTICIPANT	\N	PRESENT	0
732753	730575	20024T	PARTICIPANT	\N	PRESENT	0
732787	730576	20024T	PARTICIPANT	\N	EXCUSE	0
733690	733686	19768N	PARTICIPANT	\N	PRESENT	0
733706	733686	20094J	PARTICIPANT	\N	PRESENT	0
733723	733686	20070A	PARTICIPANT	\N	PRESENT	0
733730	733728	20070A	PARTICIPANT	\N	PRESENT	0
733731	733728	20094J	PARTICIPANT	\N	PRESENT	0
733732	733728	19768N	PARTICIPANT	\N	PRESENT	0
733733	733728	19820Y	PARTICIPANT	\N	PRESENT	0
733749	733728	20128B	PARTICIPANT	\N	PRESENT	0
733962	732775	19954N	PARTICIPANT	\N	PRESENT	0
733963	732775	14275Y	PARTICIPANT	\N	PRESENT	0
733964	732775	14111D	PARTICIPANT	\N	PRESENT	0
733965	732775	19629C	PARTICIPANT	\N	PRESENT	0
733966	732775	07004J	PARTICIPANT	\N	PRESENT	0
733967	732775	11026G	PARTICIPANT	\N	PRESENT	0
733968	732775	14179A	PARTICIPANT	\N	PRESENT	0
733969	732775	14215L	PRESIDENT	0	PRESENT	0
733970	732775	08018U	PARTICIPANT	\N	PRESENT	0
733971	732775	14259Y	PARTICIPANT	\N	PRESENT	0
733972	732775	19673G	PARTICIPANT	\N	PRESENT	0
733973	732775	14231L	PARTICIPANT	\N	PRESENT	0
733974	732915	19531S	PARTICIPANT	\N	PRESENT	0
733975	732915	19687N	PARTICIPANT	\N	PRESENT	0
733976	732915	20050V	PARTICIPANT	\N	PRESENT	0
733977	732915	07029T	PARTICIPANT	\N	PRESENT	0
733978	732915	14083S	PARTICIPANT	\N	PRESENT	0
733979	732915	19741B	PARTICIPANT	\N	PRESENT	0
733980	732915	20914V	PARTICIPANT	\N	PRESENT	0
733982	732775	14053L	PARTICIPANT	\N	PRESENT	0
733983	732775	19301E	PARTICIPANT	\N	PRESENT	0
733984	732775	95063L	PARTICIPANT	\N	PRESENT	0
733985	732775	14107H	PARTICIPANT	\N	PRESENT	0
733986	732775	20108W	PARTICIPANT	\N	PRESENT	0
733987	732775	14151M	PARTICIPANT	\N	PRESENT	0
733988	732775	11072N	PARTICIPANT	\N	PRESENT	0
733989	730866	19593H	PARTICIPANT	\N	PRESENT	0
733990	730866	19643A	PARTICIPANT	\N	PRESENT	0
733991	730866	20132W	PARTICIPANT	\N	PRESENT	0
733992	730866	19699S	PARTICIPANT	\N	PRESENT	0
733993	730866	20134Y	PARTICIPANT	\N	PRESENT	0
733994	730866	19611R	PRESIDENT	0	PRESENT	0
733995	730866	20142Y	PARTICIPANT	\N	PRESENT	0
733996	730866	20052X	PARTICIPANT	\N	PRESENT	0
733997	730866	14229S	PARTICIPANT	\N	PRESENT	0
733998	730866	20056C	PARTICIPANT	\N	PRESENT	0
733999	730866	19573D	PARTICIPANT	\N	PRESENT	0
734000	730866	20264J	PARTICIPANT	\N	PRESENT	0
734001	730866	19735D	PARTICIPANT	\N	PRESENT	0
734002	730866	14109K	PARTICIPANT	\N	PRESENT	0
734003	730866	20112S	PARTICIPANT	\N	PRESENT	0
734004	730866	08012N	PARTICIPANT	\N	PRESENT	0
734005	730866	14123H	PARTICIPANT	\N	PRESENT	0
734006	730866	11104D	PARTICIPANT	\N	PRESENT	0
734007	730866	11043H	PARTICIPANT	\N	PRESENT	0
734008	730866	20124W	PARTICIPANT	\N	PRESENT	0
734009	732915	11053K	PARTICIPANT	\N	PRESENT	0
734010	732915	08011M	PARTICIPANT	\N	PRESENT	0
734011	732915	14121F	PARTICIPANT	\N	PRESENT	0
716305	716257	05008E	PARTICIPANT	\N	EXCUSE	0
716550	716549	20114U	PARTICIPANT	\N	PRESENT	1
716551	716549	14215L	PARTICIPANT	\N	PRESENT	0
716553	716552	14053L	PARTICIPANT	\N	PRESENT	0
717192	716526	14281W	PARTICIPANT	\N	PRESENT	0
717193	716526	19691J	PARTICIPANT	\N	PRESENT	0
717194	716526	20090E	PARTICIPANT	\N	PRESENT	0
717196	716527	19691J	PARTICIPANT	\N	PRESENT	0
717198	716527	14281W	PARTICIPANT	\N	PRESENT	0
717199	716527	20090E	PARTICIPANT	\N	PRESENT	0
719646	718605	07029T	PARTICIPANT	\N	PRESENT	0
719647	718605	20070A	PARTICIPANT	\N	PRESENT	0
719648	718605	19741B	PARTICIPANT	\N	PRESENT	0
719649	718605	20060X	PARTICIPANT	\N	PRESENT	0
719650	718605	19669L	PARTICIPANT	\N	PRESENT	0
719651	718605	19413M	PARTICIPANT	\N	PRESENT	0
719652	718605	18193Q	PARTICIPANT	\N	PRESENT	0
719653	718605	08012N	PARTICIPANT	\N	PRESENT	0
719654	718605	19707Y	PARTICIPANT	\N	PRESENT	0
719655	718605	20018V	PARTICIPANT	\N	PRESENT	0
719656	718605	19705W	PARTICIPANT	\N	PRESENT	0
719657	718605	14109K	PARTICIPANT	\N	PRESENT	0
719658	718605	14257W	PARTICIPANT	\N	PRESENT	0
719659	718605	20108W	PARTICIPANT	\N	PRESENT	0
719660	718605	17779H	PARTICIPANT	\N	PRESENT	0
719661	718605	19954N	PARTICIPANT	\N	PRESENT	0
719662	718605	19649G	PARTICIPANT	\N	PRESENT	0
719663	718605	20104S	PARTICIPANT	\N	PRESENT	0
719664	718605	14001X	PARTICIPANT	\N	PRESENT	0
719665	718605	20172F	PARTICIPANT	\N	PRESENT	0
719666	718605	14253S	PARTICIPANT	\N	PRESENT	0
719667	718605	08047A	PARTICIPANT	\N	PRESENT	0
719668	718605	20080C	PARTICIPANT	\N	PRESENT	0
719669	718605	20024T	PARTICIPANT	\N	PRESENT	0
719670	718605	19820Y	PARTICIPANT	\N	PRESENT	0
719671	718605	20022R	PARTICIPANT	\N	PRESENT	0
719672	718605	14281W	PARTICIPANT	\N	PRESENT	0
719673	718605	05012A	PARTICIPANT	\N	PRESENT	0
719674	718605	10015M	PARTICIPANT	\N	PRESENT	0
719675	718605	14021P	PARTICIPANT	\N	PRESENT	0
719676	718605	14097Y	PARTICIPANT	\N	PRESENT	0
719677	718605	19531S	PARTICIPANT	\N	PRESENT	0
719678	718605	17367Q	PARTICIPANT	\N	PRESENT	0
719679	718605	19333N	PARTICIPANT	\N	PRESENT	0
719680	718605	18083K	PARTICIPANT	\N	PRESENT	0
719681	718605	14123H	PARTICIPANT	\N	PRESENT	0
719682	718605	20264J	PARTICIPANT	\N	PRESENT	0
719683	718605	04042C	PARTICIPANT	\N	PRESENT	0
719684	718605	19551W	PARTICIPANT	\N	PRESENT	0
719685	718605	14223L	PARTICIPANT	\N	PRESENT	0
719686	718605	19631V	PARTICIPANT	\N	PRESENT	0
719687	718605	11110B	PARTICIPANT	\N	PRESENT	0
719688	718605	11090Q	PARTICIPANT	\N	PRESENT	0
719689	718605	14121F	PARTICIPANT	\N	PRESENT	0
719690	718605	11056N	PARTICIPANT	\N	PRESENT	0
719691	718605	17637T	PARTICIPANT	\N	PRESENT	0
719692	718605	11026G	PARTICIPANT	\N	PRESENT	0
719693	718605	01058X	PARTICIPANT	\N	PRESENT	0
719694	718605	20088L	PARTICIPANT	\N	PRESENT	0
719695	718605	11101A	PARTICIPANT	\N	PRESENT	0
719696	718605	19703U	PARTICIPANT	\N	PRESENT	0
719697	718605	08010L	PARTICIPANT	\N	PRESENT	0
719698	718605	19713W	PARTICIPANT	\N	PRESENT	0
719699	718605	19699S	PARTICIPANT	\N	PRESENT	0
719700	718605	14026U	PARTICIPANT	\N	PRESENT	0
719701	718605	19319Q	PARTICIPANT	\N	PRESENT	0
719702	718605	19747H	PARTICIPANT	\N	PRESENT	0
719703	718605	14111D	PARTICIPANT	\N	PRESENT	0
719704	718605	14133K	PARTICIPANT	\N	PRESENT	0
719705	718605	19057M	PARTICIPANT	\N	PRESENT	0
719706	718605	11031D	PARTICIPANT	\N	PRESENT	0
719707	718605	04092N	PARTICIPANT	\N	PRESENT	0
719708	718605	20286Q	PARTICIPANT	\N	PRESENT	0
719709	718605	11097X	PARTICIPANT	\N	PRESENT	0
719710	718605	19441R	PARTICIPANT	\N	PRESENT	0
719711	718605	19479G	PARTICIPANT	\N	PRESENT	0
719712	718605	14219Q	PARTICIPANT	\N	PRESENT	0
719713	718605	19415P	PARTICIPANT	\N	PRESENT	0
719714	718605	14042U	PARTICIPANT	\N	PRESENT	0
719715	718605	05008E	PARTICIPANT	\N	PRESENT	0
719716	718605	14071N	PARTICIPANT	\N	PRESENT	0
719717	718605	19569H	PARTICIPANT	\N	PRESENT	0
719718	718605	19739H	PARTICIPANT	\N	PRESENT	0
719719	718605	14187A	PARTICIPANT	\N	PRESENT	0
719720	718605	16685X	PARTICIPANT	\N	PRESENT	0
719721	718605	14205J	PARTICIPANT	\N	PRESENT	0
719722	718605	04033B	PARTICIPANT	\N	PRESENT	0
719723	718605	20144B	PARTICIPANT	\N	PRESENT	0
719724	718605	14069U	PARTICIPANT	\N	PRESENT	0
719725	718605	04043D	PARTICIPANT	\N	PRESENT	0
719726	718605	08009T	PARTICIPANT	\N	PRESENT	0
719727	718605	14053L	PARTICIPANT	\N	PRESENT	0
719728	718605	11053K	PARTICIPANT	\N	PRESENT	0
719729	718605	14237S	PARTICIPANT	\N	PRESENT	0
719730	718605	19671E	PARTICIPANT	\N	PRESENT	0
719731	718605	19369B	PARTICIPANT	\N	PRESENT	0
719732	718605	19367Y	PARTICIPANT	\N	PRESENT	0
719733	718605	14189C	PARTICIPANT	\N	PRESENT	0
719734	718605	19611R	PARTICIPANT	\N	PRESENT	0
719735	718605	20054A	PARTICIPANT	\N	PRESENT	0
719736	718605	20126Y	PARTICIPANT	\N	PRESENT	0
719737	718605	14179A	PARTICIPANT	\N	PRESENT	0
719738	718605	08056B	PARTICIPANT	\N	PRESENT	0
719739	718605	20124W	PARTICIPANT	\N	PRESENT	0
719740	718605	14231L	PARTICIPANT	\N	PRESENT	0
719741	718605	19691J	PARTICIPANT	\N	PRESENT	0
719742	718605	19383Y	PARTICIPANT	\N	PRESENT	0
719743	718605	20048C	PARTICIPANT	\N	PRESENT	0
719744	718605	20152B	PARTICIPANT	\N	PRESENT	0
719745	718605	20252E	PARTICIPANT	\N	PRESENT	0
719746	718605	20120S	PARTICIPANT	\N	PRESENT	0
719747	718605	19543W	PARTICIPANT	\N	PRESENT	0
719748	718605	17023S	PARTICIPANT	\N	PRESENT	0
719749	718605	10006L	PARTICIPANT	\N	PRESENT	0
719750	718605	19335Q	PARTICIPANT	\N	PRESENT	0
719751	718605	19685L	PARTICIPANT	\N	PRESENT	0
719752	718605	20118Y	PARTICIPANT	\N	PRESENT	0
719753	718605	20052X	PARTICIPANT	\N	PRESENT	0
719754	718605	14083S	PARTICIPANT	\N	PRESENT	0
719755	718605	14331P	PARTICIPANT	\N	PRESENT	0
719756	718605	20040T	PARTICIPANT	\N	PRESENT	0
719757	718605	20032T	PARTICIPANT	\N	PRESENT	0
719758	718605	19826F	PARTICIPANT	\N	PRESENT	0
719759	718605	17737W	PARTICIPANT	\N	PRESENT	0
719760	718605	19749K	PARTICIPANT	\N	PRESENT	0
719761	718605	14255U	PARTICIPANT	\N	PRESENT	0
719762	718605	20066E	PARTICIPANT	\N	PRESENT	0
719763	718605	11085T	PARTICIPANT	\N	PRESENT	0
719764	718605	14059S	PARTICIPANT	\N	PRESENT	0
719765	718605	04070G	PARTICIPANT	\N	PRESENT	0
719766	718605	20090E	PARTICIPANT	\N	PRESENT	0
719767	718605	14030Q	PARTICIPANT	\N	PRESENT	0
719768	718605	14327T	PARTICIPANT	\N	PRESENT	0
719769	718605	19701S	PARTICIPANT	\N	PRESENT	0
719770	718605	19643A	PARTICIPANT	\N	PRESENT	0
719771	718605	14329V	PARTICIPANT	\N	PRESENT	0
719772	718605	14357A	PARTICIPANT	\N	PRESENT	0
719773	718605	14147R	PARTICIPANT	\N	PRESENT	0
719774	718605	97011G	PARTICIPANT	\N	PRESENT	0
719775	718605	04035D	PARTICIPANT	\N	PRESENT	0
719777	718605	19553Y	PARTICIPANT	\N	PRESENT	0
719778	718605	11048N	PARTICIPANT	\N	PRESENT	0
719779	718605	19766L	PARTICIPANT	\N	PRESENT	0
719780	718605	11115U	PARTICIPANT	\N	PRESENT	0
719781	718605	19735D	PARTICIPANT	\N	PRESENT	0
719782	718605	20058E	PARTICIPANT	\N	PRESENT	0
719783	718605	14215L	PARTICIPANT	\N	PRESENT	0
719799	718605	20094J	PARTICIPANT	\N	PRESENT	0
719787	718605	19447X	PARTICIPANT	\N	PRESENT	0
719786	718605	20098N	PARTICIPANT	\N	PRESENT	0
719797	718605	19647E	PARTICIPANT	\N	PRESENT	0
719800	718605	19681G	PARTICIPANT	\N	PRESENT	0
719801	718605	20136B	PARTICIPANT	\N	PRESENT	0
719802	718605	20248J	PARTICIPANT	\N	PRESENT	0
719803	718605	01043Q	PARTICIPANT	\N	PRESENT	0
719832	718622	19629C	PRESIDENT	0	PRESENT	0
719833	718622	14331P	PARTICIPANT	\N	PRESENT	0
719834	718622	14001X	PARTICIPANT	\N	PRESENT	0
719845	718622	14259Y	PARTICIPANT	\N	PRESENT	0
719846	718622	19954N	PARTICIPANT	\N	PRESENT	0
719848	718622	14189C	PARTICIPANT	\N	PRESENT	0
718527	718518	10006L	PARTICIPANT	\N	PRESENT	0
718528	718518	11026G	PARTICIPANT	\N	PRESENT	0
718529	718518	20248J	PARTICIPANT	\N	PRESENT	0
718530	718518	14217N	PARTICIPANT	\N	PRESENT	0
718531	718518	19525U	PARTICIPANT	\N	PRESENT	0
718532	718518	01024M	PARTICIPANT	\N	PRESENT	0
718533	718518	19713W	PARTICIPANT	\N	PRESENT	0
718534	716257	97011G	PARTICIPANT	\N	PRESENT	0
718535	718518	14097Y	PARTICIPANT	\N	PRESENT	0
718536	718518	20062A	PARTICIPANT	\N	PRESENT	0
718537	718518	20118Y	PARTICIPANT	\N	PRESENT	0
718539	718538	20248J	PARTICIPANT	\N	PRESENT	0
718727	718726	08018U	PARTICIPANT	\N	PRESENT	0
718728	718726	11026G	PARTICIPANT	\N	PRESENT	0
718730	718729	11026G	PARTICIPANT	\N	PRESENT	0
718731	718729	08018U	PARTICIPANT	\N	PRESENT	0
718746	718745	11026G	PARTICIPANT	\N	PRESENT	0
718889	718372	11031D	PARTICIPANT	\N	PRESENT	0
718890	718372	19735D	PRESIDENT	0	PRESENT	0
718891	718372	14213J	PARTICIPANT	\N	PRESENT	0
718892	718372	14026U	PARTICIPANT	\N	PRESENT	0
718893	718372	20138D	PARTICIPANT	\N	EXCUSE	0
718894	718372	20050V	PARTICIPANT	\N	EXCUSE	0
718895	718372	04045F	PARTICIPANT	\N	EXCUSE	0
718896	701179	19725B	PARTICIPANT	\N	PRESENT	0
718897	701179	14205J	PARTICIPANT	\N	PRESENT	0
718898	701179	14097Y	PARTICIPANT	\N	PRESENT	0
718899	701179	20076G	PRESIDENT	0	PRESENT	0
718900	701179	19820Y	PARTICIPANT	\N	PRESENT	0
718901	701179	19826F	PARTICIPANT	\N	PRESENT	0
718902	701179	20054A	PARTICIPANT	\N	PRESENT	0
718903	701179	19719D	PARTICIPANT	\N	PRESENT	0
718904	701179	19701S	PARTICIPANT	\N	EXCUSE	0
718905	701179	20072C	PARTICIPANT	\N	EXCUSE	0
718906	701179	14033T	PARTICIPANT	\N	PRESENT	0
718907	701179	20074E	PARTICIPANT	\N	PRESENT	0
718908	701179	20046A	PARTICIPANT	\N	PRESENT	0
718909	701179	19723Y	PARTICIPANT	\N	PRESENT	0
718910	701179	19798U	PARTICIPANT	\N	PRESENT	0
718911	701179	20142Y	PARTICIPANT	\N	PRESENT	0
718912	701179	14173T	PARTICIPANT	\N	PRESENT	0
718913	701179	20056C	PARTICIPANT	\N	PRESENT	0
718914	701179	20026V	PARTICIPANT	\N	PRESENT	0
718915	701179	19782L	PARTICIPANT	\N	PRESENT	0
718935	718372	04092N	PARTICIPANT	\N	PRESENT	0
718936	718372	20066E	PARTICIPANT	\N	PRESENT	0
718937	718372	20126Y	PARTICIPANT	\N	EXCUSE	0
718948	717060	20106U	PARTICIPANT	\N	PRESENT	0
718949	717060	19739H	PARTICIPANT	\N	PRESENT	0
718950	717060	14109K	PARTICIPANT	\N	PRESENT	0
718951	717060	19335Q	PRESIDENT	0	PRESENT	0
718952	717060	20980G	PARTICIPANT	\N	PRESENT	0
718953	717060	20026V	PARTICIPANT	\N	PRESENT	0
718965	718325	14357A	PRESIDENT	0	PRESENT	0
718966	718325	11097X	PARTICIPANT	\N	PRESENT	0
718967	718325	11053K	PARTICIPANT	\N	PRESENT	0
718968	718325	20102Q	PARTICIPANT	\N	PRESENT	0
718969	718325	14237S	PARTICIPANT	\N	PRESENT	0
718971	718325	20180F	PARTICIPANT	\N	PRESENT	0
718972	718325	19575F	PARTICIPANT	\N	PRESENT	0
718973	718325	20052X	PARTICIPANT	\N	PRESENT	0
718985	701179	20090E	PARTICIPANT	\N	PRESENT	0
718986	701179	04045F	PARTICIPANT	\N	PRESENT	0
718987	701179	16685X	PARTICIPANT	\N	PRESENT	0
718988	701179	20050V	PARTICIPANT	\N	PRESENT	0
718989	717060	20038A	PARTICIPANT	\N	PRESENT	0
718997	718970	19593H	PARTICIPANT	\N	PRESENT	0
718998	718970	04070G	PARTICIPANT	\N	PRESENT	0
718999	718970	17737W	PARTICIPANT	\N	PRESENT	0
719000	718970	20064C	PRESIDENT	0	PRESENT	0
719001	718970	20068G	PARTICIPANT	\N	PRESENT	0
719002	718970	14251Q	PARTICIPANT	\N	PRESENT	0
719003	718970	14193X	PARTICIPANT	\N	PRESENT	0
719004	718970	14179A	PARTICIPANT	\N	PRESENT	0
719005	718970	11083R	PARTICIPANT	\N	PRESENT	0
719006	718970	20152B	PARTICIPANT	\N	PRESENT	0
719007	718970	14030Q	PARTICIPANT	\N	PRESENT	0
719910	719909	19673G	PARTICIPANT	\N	PRESENT	0
719911	719909	20056C	PARTICIPANT	\N	PRESENT	0
719912	719909	20054A	PARTICIPANT	\N	PRESENT	0
719913	718543	19319Q	PARTICIPANT	\N	EXCUSE	0
719914	718543	19301E	PARTICIPANT	\N	PRESENT	0
719915	718543	19717B	PRESIDENT	0	PRESENT	0
719916	718543	05008E	PARTICIPANT	\N	PRESENT	0
719917	718543	18083K	PARTICIPANT	\N	PRESENT	0
719918	718543	19295A	PARTICIPANT	\N	PRESENT	0
719919	718543	20034V	PARTICIPANT	\N	PRESENT	1
719920	718543	14147R	PARTICIPANT	\N	PRESENT	0
719921	718543	04043D	PARTICIPANT	\N	PRESENT	0
719926	718543	19715Y	PARTICIPANT	\N	PRESENT	0
719927	718543	20146D	PARTICIPANT	\N	PRESENT	0
719928	718543	12016W	PARTICIPANT	\N	PRESENT	0
720074	719933	14030Q	PARTICIPANT	\N	PRESENT	1
720283	720281	19697Q	PARTICIPANT	\N	PRESENT	0
720284	720281	20090E	PARTICIPANT	\N	PRESENT	1
720285	720281	20130U	PARTICIPANT	\N	PRESENT	1
720286	720282	20090E	PARTICIPANT	\N	PRESENT	1
720287	720282	19697Q	PARTICIPANT	\N	PRESENT	0
720288	720282	20130U	PARTICIPANT	\N	PRESENT	1
720304	720298	19711U	PARTICIPANT	\N	PRESENT	0
720353	720352	11048N	PARTICIPANT	\N	PRESENT	0
720340	720339	01057W	PARTICIPANT	\N	PRESENT	0
720341	720339	19489J	PARTICIPANT	\N	PRESENT	0
721038	719035	14221J	PARTICIPANT	\N	PRESENT	0
721042	719208	19766L	PARTICIPANT	\N	PRESENT	0
721043	719208	19699S	PARTICIPANT	0	PRESENT	0
721044	719208	19533U	PARTICIPANT	\N	PRESENT	0
721045	719208	14229S	PARTICIPANT	\N	PRESENT	0
721046	719208	20098N	PARTICIPANT	\N	PRESENT	0
721047	719208	19573D	PARTICIPANT	\N	PRESENT	0
721048	719208	20112S	PARTICIPANT	\N	PRESENT	0
721049	719208	08012N	PARTICIPANT	\N	PRESENT	0
721050	719208	20124W	PARTICIPANT	\N	PRESENT	0
721051	719208	20026V	PARTICIPANT	\N	PRESENT	0
721052	719208	19593H	PARTICIPANT	\N	PRESENT	0
721053	719208	19527W	PARTICIPANT	\N	PRESENT	0
721054	719208	19643A	PARTICIPANT	\N	PRESENT	0
721055	719208	20132W	PARTICIPANT	\N	PRESENT	0
721056	719208	20134Y	PARTICIPANT	\N	PRESENT	0
721057	719208	14073Q	PARTICIPANT	\N	PRESENT	0
721058	719208	19651A	PARTICIPANT	\N	PRESENT	0
721059	719208	19611R	PRESIDENT	0	PRESENT	0
721060	719208	20138D	PARTICIPANT	\N	PRESENT	0
721061	719208	20142Y	PARTICIPANT	\N	PRESENT	0
721062	719208	20048C	PARTICIPANT	\N	PRESENT	0
721063	719208	19693L	PARTICIPANT	\N	PRESENT	0
721064	719208	19399H	PARTICIPANT	\N	PRESENT	0
721065	719208	20052X	PARTICIPANT	\N	PRESENT	0
721066	719208	20152B	PARTICIPANT	\N	PRESENT	0
721067	719208	19719D	PARTICIPANT	\N	PRESENT	0
721068	719208	20172F	PARTICIPANT	\N	PRESENT	0
721069	719208	14030Q	PARTICIPANT	\N	PRESENT	0
721070	719208	20058E	PARTICIPANT	\N	PRESENT	0
721071	719208	20056C	PARTICIPANT	\N	PRESENT	0
721072	719208	20180F	PARTICIPANT	\N	PRESENT	0
721073	719208	20264J	PARTICIPANT	\N	PRESENT	0
721074	719208	04059M	PARTICIPANT	\N	PRESENT	0
721075	719208	19735D	PARTICIPANT	\N	PRESENT	0
721076	719208	14109K	PARTICIPANT	\N	PRESENT	0
721077	719208	14123H	PARTICIPANT	\N	PRESENT	0
721078	719208	11104D	PARTICIPANT	\N	PRESENT	0
721079	719208	11043H	PARTICIPANT	\N	PRESENT	0
721080	719208	20980G	PARTICIPANT	\N	PRESENT	0
721081	719208	19758L	PARTICIPANT	\N	PRESENT	0
721082	719208	20084G	PARTICIPANT	\N	PRESENT	0
721083	719208	19621T	PARTICIPANT	\N	PRESENT	0
721084	720090	14097Y	PARTICIPANT	\N	PRESENT	0
721085	720090	14059S	PARTICIPANT	\N	PRESENT	0
721086	720090	04035D	PARTICIPANT	\N	PRESENT	0
721087	720090	95041E	PARTICIPANT	\N	PRESENT	0
721088	720090	14133K	PRESIDENT	0	PRESENT	0
721089	720090	08069G	PARTICIPANT	\N	PRESENT	0
721090	720090	11041F	PARTICIPANT	\N	PRESENT	0
721091	720090	20042V	PARTICIPANT	\N	PRESENT	0
721092	720090	01058X	PARTICIPANT	\N	PRESENT	0
721093	720090	16685X	PARTICIPANT	\N	PRESENT	0
721094	720090	01024M	PARTICIPANT	\N	PRESENT	0
721095	720090	11066Q	PARTICIPANT	\N	PRESENT	0
721096	720090	19721W	PARTICIPANT	\N	PRESENT	0
721097	720090	12028B	PARTICIPANT	\N	PRESENT	0
721098	720090	19421M	PARTICIPANT	\N	PRESENT	0
711617	711616	14037X	PARTICIPANT	\N	PRESENT	0
711618	711616	14257W	PARTICIPANT	\N	PRESENT	0
711619	711616	11077T	PARTICIPANT	\N	PRESENT	0
712021	708191	19760E	PARTICIPANT	\N	PRESENT	0
712023	708191	19631V	PARTICIPANT	\N	PRESENT	0
719384	719383	14189C	PARTICIPANT	\N	EXCUSE	0
719385	719383	11031D	PARTICIPANT	\N	EXCUSE	0
719386	719383	20024T	PARTICIPANT	\N	EXCUSE	0
719387	719383	20118Y	PARTICIPANT	\N	EXCUSE	0
719388	719383	20098N	PARTICIPANT	\N	EXCUSE	0
719389	719383	19681G	PARTICIPANT	\N	EXCUSE	0
719390	719383	20080C	PARTICIPANT	\N	EXCUSE	0
719391	719383	07029T	PARTICIPANT	\N	EXCUSE	0
719947	718667	20094J	PARTICIPANT	\N	PRESENT	0
724026	722689	04057K	PARTICIPANT	\N	EXCUSE	0
724028	722685	04057K	PARTICIPANT	\N	EXCUSE	0
725526	725525	14133K	PARTICIPANT	\N	PRESENT	0
725527	725525	16685X	PARTICIPANT	\N	PRESENT	0
725529	725528	14133K	PARTICIPANT	\N	PRESENT	0
725530	725528	11066Q	PARTICIPANT	\N	PRESENT	0
725532	725531	14133K	PARTICIPANT	\N	PRESENT	0
725533	725531	11066Q	PARTICIPANT	\N	PRESENT	0
725535	725534	14133K	PARTICIPANT	\N	PRESENT	0
725537	725536	14133K	PARTICIPANT	\N	PRESENT	0
725539	725538	14255U	PARTICIPANT	\N	PRESENT	0
725540	725538	11083R	PARTICIPANT	\N	PRESENT	0
725542	725541	14255U	PARTICIPANT	\N	PRESENT	0
725543	725541	11083R	PARTICIPANT	\N	PRESENT	0
725548	725547	20286Q	PARTICIPANT	\N	PRESENT	0
725550	725549	20286Q	PARTICIPANT	\N	PRESENT	0
725552	725551	20286Q	PARTICIPANT	\N	PRESENT	0
725553	725551	20060X	PARTICIPANT	\N	PRESENT	0
725554	725551	20092G	PARTICIPANT	\N	PRESENT	0
725557	725556	14031R	PARTICIPANT	\N	PRESENT	0
725558	725556	20136B	PARTICIPANT	\N	PRESENT	0
725559	725556	19599P	PARTICIPANT	\N	PRESENT	0
725560	725556	20180F	PARTICIPANT	\N	PRESENT	0
725561	725556	14053L	PARTICIPANT	\N	PRESENT	0
725562	725556	14083S	PARTICIPANT	\N	PRESENT	0
725659	725658	14187A	PARTICIPANT	\N	PRESENT	0
725660	725658	19347U	PARTICIPANT	\N	PRESENT	0
725661	725658	20090E	PARTICIPANT	\N	PRESENT	0
725662	725658	20062A	PARTICIPANT	\N	PRESENT	0
725663	725658	20018V	PARTICIPANT	\N	PRESENT	0
725664	725658	18083K	PARTICIPANT	\N	PRESENT	0
726445	725627	20130U	PARTICIPANT	\N	PRESENT	0
730897	730731	19798U	PARTICIPANT	\N	PRESENT	0
730965	730731	20066E	PARTICIPANT	\N	PRESENT	0
731134	731133	14221J	PARTICIPANT	\N	PRESENT	0
734196	732866	19707Y	PARTICIPANT	\N	PRESENT	0
734197	732866	08015R	PARTICIPANT	\N	PRESENT	0
734198	732866	19575F	PARTICIPANT	\N	PRESENT	0
734199	732866	19369B	PARTICIPANT	\N	PRESENT	0
734200	732866	20018V	PARTICIPANT	\N	PRESENT	0
734201	732866	19563B	PARTICIPANT	\N	PRESENT	0
734202	732866	14329V	PARTICIPANT	\N	PRESENT	0
734203	732866	20028X	PARTICIPANT	\N	PRESENT	0
734204	732866	14037X	PARTICIPANT	\N	PRESENT	0
734205	732866	14038Y	PARTICIPANT	\N	PRESENT	0
734206	732866	20030R	PARTICIPANT	\N	PRESENT	0
734207	732866	14187A	PARTICIPANT	\N	PRESENT	0
734208	732866	20144B	PARTICIPANT	\N	PRESENT	0
734209	732866	19695N	PARTICIPANT	\N	PRESENT	0
734210	732866	11090Q	PRESIDENT	0	PRESENT	0
734211	732866	01025N	PARTICIPANT	\N	PRESENT	0
734212	732866	14033T	PARTICIPANT	\N	PRESENT	0
734213	732866	20054A	PARTICIPANT	\N	PRESENT	0
734214	732866	14205J	PARTICIPANT	\N	PRESENT	0
734215	732866	20060X	PARTICIPANT	\N	PRESENT	0
734216	732866	20062A	PARTICIPANT	\N	PRESENT	0
734217	732866	20286Q	PARTICIPANT	\N	PRESENT	0
734218	732866	19747H	PARTICIPANT	\N	PRESENT	0
734219	732866	14207L	PARTICIPANT	\N	PRESENT	0
734220	732866	14257W	PARTICIPANT	\N	PRESENT	0
734221	732866	19467C	PARTICIPANT	\N	EXCUSE	0
734222	732866	20082E	PARTICIPANT	\N	EXCUSE	0
734224	730887	20076G	PARTICIPANT	\N	PRESENT	0
734225	730887	19549D	PARTICIPANT	\N	PRESENT	0
734226	730887	19387D	PARTICIPANT	\N	PRESENT	0
734227	730887	14219Q	PRESIDENT	0	PRESENT	0
734228	730887	19820Y	PARTICIPANT	\N	PRESENT	0
734229	730887	14221J	PARTICIPANT	\N	PRESENT	0
734230	730887	19826F	PARTICIPANT	\N	PRESENT	0
734231	730887	20102Q	PARTICIPANT	\N	PRESENT	0
734232	730887	19599P	PARTICIPANT	\N	PRESENT	0
734233	730887	19637C	PARTICIPANT	\N	PRESENT	0
734234	730887	20096L	PARTICIPANT	\N	PRESENT	0
734235	730887	18083K	PARTICIPANT	\N	PRESENT	0
734236	730887	14237S	PARTICIPANT	\N	PRESENT	0
734237	730887	20100N	PARTICIPANT	\N	PRESENT	0
734238	730887	08060W	PARTICIPANT	\N	PRESENT	0
734239	730887	20106U	PARTICIPANT	\N	PRESENT	0
734240	730887	20118Y	PARTICIPANT	\N	PRESENT	0
734241	730887	19503N	PARTICIPANT	\N	PRESENT	0
734242	730887	20020P	PARTICIPANT	\N	PRESENT	0
734243	730887	17367Q	PARTICIPANT	\N	PRESENT	0
734244	730887	19681G	PARTICIPANT	\N	PRESENT	0
734245	730887	20024T	PARTICIPANT	\N	PRESENT	0
734246	730887	19525U	PARTICIPANT	\N	PRESENT	0
734247	730887	20120S	PARTICIPANT	\N	PRESENT	0
734248	730887	20032T	PARTICIPANT	\N	PRESENT	0
734249	730887	20136B	PARTICIPANT	\N	PRESENT	0
734250	730887	14031R	PARTICIPANT	\N	PRESENT	0
734251	730887	20038A	PARTICIPANT	\N	PRESENT	0
734252	730887	20140W	PARTICIPANT	\N	PRESENT	0
734253	730887	19251M	PARTICIPANT	\N	PRESENT	0
734254	730887	20046A	PARTICIPANT	\N	PRESENT	0
734255	730887	20146D	PARTICIPANT	\N	PRESENT	0
734256	730887	17229F	PARTICIPANT	\N	PRESENT	0
734257	730887	14169X	PARTICIPANT	\N	PRESENT	0
734258	730887	20068G	PARTICIPANT	\N	PRESENT	0
734259	730887	11101A	PARTICIPANT	\N	PRESENT	0
734260	730887	19739H	PARTICIPANT	\N	PRESENT	0
734261	730887	19745F	PARTICIPANT	\N	PRESENT	0
734262	730887	05012A	PARTICIPANT	\N	EXCUSE	0
734263	730887	19619A	PARTICIPANT	\N	EXCUSE	0
734331	732739	20024T	PARTICIPANT	\N	PRESENT	0
734332	732739	20126Y	PARTICIPANT	\N	EXCUSE	0
734333	732739	19735D	PRESIDENT	0	PRESENT	0
734334	732739	11031D	PARTICIPANT	\N	PRESENT	0
734335	732739	17965H	PARTICIPANT	\N	PRESENT	0
734336	732740	20024T	PARTICIPANT	\N	EXCUSE	0
734337	732740	11031D	PARTICIPANT	\N	PRESENT	0
734338	732740	20126Y	PARTICIPANT	\N	EXCUSE	0
734339	732740	19735D	PRESIDENT	0	PRESENT	0
734340	732741	20024T	PARTICIPANT	\N	EXCUSE	0
734341	732741	11031D	PARTICIPANT	\N	PRESENT	0
734342	732741	20126Y	PARTICIPANT	\N	EXCUSE	0
734343	732741	19735D	PRESIDENT	0	PRESENT	0
734370	732739	20138D	PARTICIPANT	\N	PRESENT	0
734371	732739	20096L	PARTICIPANT	\N	PRESENT	0
734372	732754	14259Y	PARTICIPANT	\N	PRESENT	0
734373	732754	19954N	PARTICIPANT	\N	PRESENT	0
734374	732754	14329V	PARTICIPANT	\N	PRESENT	0
734380	732754	19383Y	PARTICIPANT	\N	PRESENT	0
734381	732754	19629C	PRESIDENT	0	PRESENT	0
734385	732754	14001X	PARTICIPANT	\N	PRESENT	0
734387	732754	11056N	PARTICIPANT	\N	PRESENT	0
734391	732754	20110Q	PARTICIPANT	\N	PRESENT	0
734392	732915	20086J	PARTICIPANT	\N	PRESENT	0
734393	732915	19647E	PARTICIPANT	\N	PRESENT	0
734394	732915	08010L	PARTICIPANT	\N	PRESENT	0
734395	732915	01048V	PARTICIPANT	\N	PRESENT	0
734396	732915	20036X	PARTICIPANT	\N	EXCUSE	0
734420	732916	19369B	PARTICIPANT	\N	PRESENT	0
734436	734162	20036X	PARTICIPANT	\N	EXCUSE	0
734437	734162	14225N	PARTICIPANT	\N	EXCUSE	0
735003	735001	10006L	PARTICIPANT	\N	PRESENT	0
735004	735001	14213J	PARTICIPANT	\N	PRESENT	0
735005	735001	19367Y	PARTICIPANT	\N	PRESENT	0
735006	735001	11067R	PARTICIPANT	\N	PRESENT	0
735007	735001	11097X	PARTICIPANT	\N	PRESENT	0
735009	735001	19415P	PARTICIPANT	\N	PRESENT	0
735011	735001	19798U	PARTICIPANT	\N	PRESENT	0
735012	735001	19703U	PARTICIPANT	\N	PRESENT	0
735015	735001	19723Y	PARTICIPANT	\N	PRESENT	0
735017	735001	14195A	PARTICIPANT	\N	PRESENT	0
735109	732650	19715Y	PARTICIPANT	\N	PRESENT	0
735276	735272	19711U	PARTICIPANT	\N	PRESENT	0
735278	735272	20050V	PARTICIPANT	\N	PRESENT	0
735341	735340	14255U	PARTICIPANT	\N	PRESENT	0
726285	725806	04092N	PARTICIPANT	\N	PRESENT	0
734265	732755	19703U	PARTICIPANT	\N	EXCUSE	0
734382	732628	20034V	PARTICIPANT	\N	EXCUSE	0
734383	728445	20034V	PARTICIPANT	\N	EXCUSE	0
734384	730875	20034V	PARTICIPANT	\N	EXCUSE	0
734389	732739	19725B	PARTICIPANT	\N	PRESENT	0
735220	730874	19593H	PARTICIPANT	\N	PRESENT	0
735221	730874	20132W	PARTICIPANT	\N	PRESENT	0
735222	730874	19699S	PARTICIPANT	\N	PRESENT	0
735223	730874	20134Y	PARTICIPANT	\N	PRESENT	0
735224	730874	19533U	PARTICIPANT	\N	PRESENT	0
735225	730874	19611R	PRESIDENT	0	PRESENT	0
735226	730874	20142Y	PARTICIPANT	\N	PRESENT	0
735227	730874	19693L	PARTICIPANT	\N	PRESENT	0
735228	730874	20152B	PARTICIPANT	\N	PRESENT	0
735229	730874	14229S	PARTICIPANT	\N	PRESENT	0
735230	730874	14073Q	PARTICIPANT	\N	PRESENT	0
735231	730874	20180F	PARTICIPANT	\N	PRESENT	0
735232	730874	14109K	PARTICIPANT	\N	PRESENT	0
735233	730874	08012N	PARTICIPANT	\N	PRESENT	0
735234	730874	20084G	PARTICIPANT	\N	PRESENT	0
735235	731901	14030Q	PRESIDENT	0	PRESENT	0
735236	731901	19715Y	PARTICIPANT	\N	PRESENT	0
735237	731901	19717B	PARTICIPANT	\N	PRESENT	0
735238	731901	20098N	PARTICIPANT	\N	PRESENT	0
735239	731901	20118Y	PARTICIPANT	\N	EXCUSE	0
735240	731901	19866P	PARTICIPANT	\N	EXCUSE	0
735241	731901	20024T	PARTICIPANT	\N	EXCUSE	0
735242	731901	20080C	PARTICIPANT	\N	EXCUSE	0
735243	731901	11072N	PARTICIPANT	\N	PRESENT	0
735253	731901	07029T	PARTICIPANT	\N	PRESENT	0
735252	731901	19657G	PARTICIPANT	\N	PRESENT	1
735254	731901	20146D	PARTICIPANT	\N	PRESENT	0
735257	735256	14073Q	PARTICIPANT	\N	PRESENT	0
735258	735256	20180F	PARTICIPANT	\N	PRESENT	0
735259	735256	08012N	PARTICIPANT	\N	PRESENT	0
735260	730874	11109J	PARTICIPANT	\N	EXCUSE	0
735261	730874	19735D	PARTICIPANT	\N	EXCUSE	0
735262	730874	20098N	PARTICIPANT	\N	EXCUSE	0
735263	730874	20026V	PARTICIPANT	\N	EXCUSE	0
735264	730874	14030Q	PARTICIPANT	\N	EXCUSE	0
735274	730826	14231L	PRESIDENT	0	PRESENT	0
735275	730826	19489J	PARTICIPANT	\N	PRESENT	0
735277	730826	20058E	PARTICIPANT	\N	PRESENT	0
735279	730826	14281W	PARTICIPANT	\N	PRESENT	0
735280	730826	04045F	PARTICIPANT	\N	PRESENT	0
735281	730826	01057W	PARTICIPANT	\N	PRESENT	0
735282	730826	19735D	PARTICIPANT	\N	PRESENT	0
735283	730826	20070A	PARTICIPANT	\N	PRESENT	0
735284	730826	14107H	PARTICIPANT	\N	PRESENT	0
735285	730826	20022R	PARTICIPANT	\N	PRESENT	0
735286	730826	08010L	PARTICIPANT	\N	PRESENT	0
735287	730826	14215L	PARTICIPANT	\N	PRESENT	0
735288	730826	14217N	PARTICIPANT	\N	PRESENT	0
735289	730826	19826F	PARTICIPANT	\N	PRESENT	0
735290	730826	20062A	PARTICIPANT	\N	PRESENT	0
735291	730826	20084G	PARTICIPANT	\N	PRESENT	0
735292	730826	14229S	PARTICIPANT	\N	PRESENT	0
735296	730826	19758L	PARTICIPANT	\N	EXCUSE	0
735297	730826	19782L	PARTICIPANT	\N	EXCUSE	0
735298	730826	20090E	PARTICIPANT	\N	EXCUSE	0
735299	730826	14327T	PARTICIPANT	\N	EXCUSE	0
735300	730826	14187A	PARTICIPANT	\N	EXCUSE	0
735301	730826	19565D	PARTICIPANT	\N	EXCUSE	0
735302	730826	19447X	PARTICIPANT	\N	EXCUSE	0
735303	730826	05012A	PARTICIPANT	\N	EXCUSE	0
735304	730826	14173T	PARTICIPANT	\N	EXCUSE	0
735312	735273	14231L	PRESIDENT	0	PRESENT	0
735313	735273	19489J	PARTICIPANT	\N	PRESENT	0
735314	735273	20058E	PARTICIPANT	\N	PRESENT	0
735315	735273	14281W	PARTICIPANT	\N	PRESENT	0
735316	735273	04045F	PARTICIPANT	\N	PRESENT	0
735317	735273	01057W	PARTICIPANT	\N	PRESENT	0
735318	735273	19735D	PARTICIPANT	\N	PRESENT	0
735320	735273	20070A	PARTICIPANT	\N	PRESENT	0
735321	735273	14107H	PARTICIPANT	\N	PRESENT	0
735322	735273	20022R	PARTICIPANT	\N	PRESENT	0
735323	735273	08010L	PARTICIPANT	\N	PRESENT	0
735324	735273	14215L	PARTICIPANT	\N	PRESENT	0
735325	735273	14217N	PARTICIPANT	\N	PRESENT	0
735326	735273	19826F	PARTICIPANT	\N	PRESENT	0
735327	735273	20062A	PARTICIPANT	\N	PRESENT	0
735328	735273	20084G	PARTICIPANT	\N	PRESENT	0
735329	735273	14229S	PARTICIPANT	\N	PRESENT	0
735330	735273	19758L	PARTICIPANT	\N	EXCUSE	0
735331	735273	19782L	PARTICIPANT	\N	EXCUSE	0
735332	735273	20090E	PARTICIPANT	\N	EXCUSE	0
735333	735273	14327T	PARTICIPANT	\N	EXCUSE	0
735334	735273	14187A	PARTICIPANT	\N	EXCUSE	0
735335	735273	19565D	PARTICIPANT	\N	EXCUSE	0
735337	735273	19447X	PARTICIPANT	\N	EXCUSE	0
735338	735273	05012A	PARTICIPANT	\N	EXCUSE	0
735339	735273	14173T	PARTICIPANT	\N	EXCUSE	0
735342	735340	01024M	PARTICIPANT	\N	PRESENT	0
735343	735340	04035D	PARTICIPANT	\N	PRESENT	0
735344	735340	11083R	PARTICIPANT	\N	PRESENT	0
735345	735340	20120S	PARTICIPANT	\N	PRESENT	0
735346	735340	11026G	PARTICIPANT	\N	PRESENT	0
735347	735340	08009T	PARTICIPANT	\N	PRESENT	0
735348	735340	14147R	PARTICIPANT	\N	PRESENT	0
735349	735340	19745F	PARTICIPANT	\N	PRESENT	0
735350	735340	19713W	PARTICIPANT	\N	PRESENT	0
735386	735385	01048V	PARTICIPANT	\N	PRESENT	0
735388	735387	01048V	PARTICIPANT	\N	PRESENT	0
735390	735389	20050V	PARTICIPANT	\N	PRESENT	0
735392	735391	20050V	PARTICIPANT	\N	PRESENT	0
735394	735393	08073C	PARTICIPANT	\N	PRESENT	0
735395	735393	20150Y	PARTICIPANT	\N	PRESENT	0
735397	735396	20086J	PARTICIPANT	\N	PRESENT	0
735399	735398	20086J	PARTICIPANT	\N	PRESENT	0
735401	735400	20086J	PARTICIPANT	\N	PRESENT	0
735403	735402	20116W	PARTICIPANT	\N	PRESENT	0
735405	735404	19711U	PARTICIPANT	\N	PRESENT	0
735407	735406	19711U	PARTICIPANT	\N	PRESENT	0
734012	732915	14225N	PARTICIPANT	\N	EXCUSE	0
734264	732754	19703U	PARTICIPANT	\N	EXCUSE	0
735409	735408	19711U	PARTICIPANT	\N	PRESENT	0
735410	732741	14026U	PARTICIPANT	\N	PRESENT	0
735412	735411	19711U	PARTICIPANT	\N	PRESENT	0
735414	735413	19711U	PARTICIPANT	\N	PRESENT	0
735416	735415	14083S	PARTICIPANT	\N	PRESENT	0
735418	735417	11074Q	PARTICIPANT	\N	PRESENT	0
735419	735417	19349W	PARTICIPANT	\N	PRESENT	0
735425	728041	14030Q	PARTICIPANT	\N	EXCUSE	0
735426	728041	19545Y	PARTICIPANT	\N	EXCUSE	0
735427	728041	19251M	PARTICIPANT	\N	EXCUSE	0
735428	728041	20054A	PARTICIPANT	\N	EXCUSE	0
735430	735429	19515S	PRESIDENT	0	PRESENT	0
735431	735429	19575F	PARTICIPANT	\N	PRESENT	0
735432	735429	20094J	PARTICIPANT	\N	PRESENT	0
735433	735429	14083S	PARTICIPANT	\N	PRESENT	0
735434	735429	19369B	PARTICIPANT	\N	PRESENT	0
735435	735429	19760E	PARTICIPANT	\N	EXCUSE	0
735436	735429	14030Q	PARTICIPANT	\N	EXCUSE	0
735437	735429	19545Y	PARTICIPANT	\N	EXCUSE	0
735438	735429	20060X	PARTICIPANT	\N	EXCUSE	0
735439	735429	08028W	PARTICIPANT	\N	EXCUSE	0
735440	735429	19467C	PARTICIPANT	\N	EXCUSE	0
735441	735429	19251M	PARTICIPANT	\N	EXCUSE	0
735442	735429	14026U	PARTICIPANT	\N	EXCUSE	0
735443	735429	20048C	PARTICIPANT	\N	EXCUSE	0
735444	735429	20126Y	PARTICIPANT	\N	EXCUSE	0
735445	735429	08015R	PARTICIPANT	\N	EXCUSE	0
735446	735429	14031R	PARTICIPANT	\N	EXCUSE	0
735447	735429	19671E	PARTICIPANT	\N	EXCUSE	0
735448	735429	19866P	PARTICIPANT	\N	EXCUSE	0
735449	735429	20082E	PARTICIPANT	\N	EXCUSE	0
735450	735429	20054A	PARTICIPANT	\N	EXCUSE	0
735451	735429	19762G	PARTICIPANT	\N	EXCUSE	0
735472	735471	11027H	PARTICIPANT	\N	PRESENT	0
735473	735471	14193X	PARTICIPANT	\N	PRESENT	0
735474	733710	14147R	PARTICIPANT	\N	EXCUSE	0
735475	733712	14147R	PARTICIPANT	\N	EXCUSE	0
735492	735491	14107H	PARTICIPANT	\N	PRESENT	0
735493	733710	05008E	PARTICIPANT	\N	EXCUSE	0
735494	733712	05008E	PARTICIPANT	\N	EXCUSE	0
735531	735530	12028B	PARTICIPANT	\N	PRESENT	0
735532	735530	11064N	PARTICIPANT	\N	PRESENT	0
735534	735533	11064N	PARTICIPANT	\N	PRESENT	0
735540	735511	19667J	PARTICIPANT	\N	PRESENT	0
735541	735511	19663E	PARTICIPANT	\N	PRESENT	0
735544	735511	20022R	PARTICIPANT	\N	PRESENT	0
711472	711470	19533U	PARTICIPANT	\N	PRESENT	0
716662	716494	12041X	PARTICIPANT	\N	PRESENT	0
716663	716494	11054L	PARTICIPANT	\N	PRESENT	0
716664	716494	19760E	PARTICIPANT	\N	PRESENT	0
716665	716494	19251M	PARTICIPANT	\N	PRESENT	0
716666	716494	14267Y	PARTICIPANT	\N	PRESENT	0
716667	716494	14069U	PARTICIPANT	\N	PRESENT	0
716668	716494	19319Q	PARTICIPANT	\N	PRESENT	0
716669	716494	20090E	PARTICIPANT	\N	PRESENT	0
716670	716494	08010L	PARTICIPANT	\N	PRESENT	0
716671	716494	19507S	PARTICIPANT	\N	PRESENT	0
716672	716494	14037X	PARTICIPANT	\N	PRESENT	0
716673	716494	20024T	PARTICIPANT	\N	PRESENT	0
716674	716494	14173T	PARTICIPANT	\N	PRESENT	0
716675	716494	14281W	PARTICIPANT	\N	PRESENT	0
716676	716494	14107H	PARTICIPANT	\N	PRESENT	0
716677	716494	20058E	PARTICIPANT	\N	PRESENT	0
716678	716494	19762G	PARTICIPANT	\N	PRESENT	0
716679	716494	19599P	PARTICIPANT	\N	PRESENT	0
716680	716494	14053L	PARTICIPANT	\N	PRESENT	0
716681	716494	20034V	PARTICIPANT	\N	PRESENT	0
716682	716494	14327T	PARTICIPANT	\N	PRESENT	0
716683	716494	14259Y	PARTICIPANT	\N	PRESENT	0
716684	716494	20086J	PARTICIPANT	\N	PRESENT	0
716685	716494	14026U	PARTICIPANT	\N	PRESENT	0
716687	716494	19399H	PARTICIPANT	\N	PRESENT	0
716688	716494	19725B	PARTICIPANT	\N	PRESENT	0
716689	716494	20042V	PARTICIPANT	\N	PRESENT	0
716693	716494	19709B	PARTICIPANT	\N	PRESENT	0
716691	716494	20110Q	PARTICIPANT	\N	PRESENT	0
716692	716494	20108W	PARTICIPANT	\N	PRESENT	0
716694	716494	19679N	PARTICIPANT	\N	PRESENT	0
716695	716494	20088L	PARTICIPANT	\N	PRESENT	0
716697	716494	14179A	PARTICIPANT	\N	PRESENT	0
716698	716494	14033T	PARTICIPANT	\N	PRESENT	0
716699	716494	14071N	PARTICIPANT	\N	PRESENT	0
716700	716494	20056C	PARTICIPANT	\N	PRESENT	0
716701	716494	14147R	PARTICIPANT	\N	PRESENT	0
716702	716494	20096L	PARTICIPANT	\N	PRESENT	0
716714	716494	14195A	PARTICIPANT	\N	PRESENT	0
716715	716494	19782L	PARTICIPANT	\N	PRESENT	0
716716	716494	20126Y	PARTICIPANT	\N	PRESENT	0
716717	716494	20264J	PARTICIPANT	\N	PRESENT	0
716718	716494	20122U	PARTICIPANT	\N	PRESENT	0
716719	716494	01024M	PARTICIPANT	\N	PRESENT	0
716720	716494	14193X	PARTICIPANT	\N	PRESENT	0
716721	716494	19637C	PARTICIPANT	\N	PRESENT	0
716722	716494	19758L	PARTICIPANT	\N	PRESENT	0
716723	716494	20052X	PARTICIPANT	\N	PRESENT	0
716724	716494	14089Y	PARTICIPANT	\N	PRESENT	0
716726	716494	19581D	PARTICIPANT	\N	PRESENT	0
716727	716494	20064C	PARTICIPANT	\N	PRESENT	0
716743	715267	14179A	PARTICIPANT	\N	PRESENT	0
716744	715267	14151M	PARTICIPANT	\N	PRESENT	0
716731	715267	14089Y	PARTICIPANT	\N	PRESENT	0
716732	715267	19725B	PARTICIPANT	\N	PRESENT	0
716733	715267	14275Y	PARTICIPANT	\N	PRESENT	0
716734	715267	20108W	PARTICIPANT	\N	PRESENT	0
716735	715267	14147R	PARTICIPANT	\N	PRESENT	0
716736	715267	04047H	PRESIDENT	0	PRESENT	0
716737	715267	19673G	PARTICIPANT	\N	PRESENT	0
716738	715267	05008E	PARTICIPANT	\N	PRESENT	0
716739	715267	19447X	PARTICIPANT	\N	PRESENT	0
716740	715267	19729F	PARTICIPANT	\N	EXCUSE	0
716741	715267	20022R	PARTICIPANT	\N	EXCUSE	0
716742	716496	95063L	PARTICIPANT	\N	PRESENT	0
716745	715267	14215L	PARTICIPANT	\N	PRESENT	0
716746	715267	19749K	PARTICIPANT	\N	PRESENT	0
716747	716730	14225N	PRESIDENT	0	PRESENT	0
716748	716730	20050V	PARTICIPANT	\N	PRESENT	0
716749	716730	07029T	PARTICIPANT	\N	EXCUSE	0
716751	716686	19782L	PARTICIPANT	\N	PRESENT	0
716752	716686	01043Q	PARTICIPANT	\N	PRESENT	0
716753	716686	14357A	PARTICIPANT	\N	PRESENT	0
716754	716686	19413M	PARTICIPANT	\N	PRESENT	0
716755	716686	04045F	PARTICIPANT	\N	PRESENT	0
716756	716686	19631V	PARTICIPANT	\N	PRESENT	0
716757	716686	20104S	PARTICIPANT	\N	PRESENT	0
716758	716686	08015R	PARTICIPANT	\N	PRESENT	0
716759	716686	19575F	PARTICIPANT	\N	PRESENT	0
716760	716686	19369B	PARTICIPANT	\N	PRESENT	0
716761	716686	20028X	PARTICIPANT	\N	PRESENT	0
716762	716686	14329V	PARTICIPANT	\N	PRESENT	0
716763	716686	14038Y	PARTICIPANT	\N	PRESENT	0
716764	716686	19467C	PARTICIPANT	\N	PRESENT	0
716765	716686	20034V	PARTICIPANT	\N	PRESENT	0
716766	716686	20144B	PARTICIPANT	\N	PRESENT	0
716767	716686	19695N	PARTICIPANT	\N	PRESENT	0
716768	716686	14033T	PARTICIPANT	\N	PRESENT	0
716769	716686	01025N	PARTICIPANT	\N	PRESENT	0
716770	716686	11090Q	PRESIDENT	0	PRESENT	0
716771	716686	20054A	PARTICIPANT	\N	PRESENT	0
716772	716686	14205J	PARTICIPANT	\N	PRESENT	0
716773	716686	20062A	PARTICIPANT	\N	PRESENT	0
716774	716686	14251Q	PARTICIPANT	\N	PRESENT	0
716775	716686	19507S	PARTICIPANT	\N	PRESENT	0
716776	716686	20298U	PARTICIPANT	\N	PRESENT	0
716777	716686	19747H	PARTICIPANT	\N	PRESENT	0
716781	716730	14327T	PRESIDENT	1	PRESENT	0
716831	716496	20110Q	PARTICIPANT	\N	PRESENT	0
716785	716730	20044X	PARTICIPANT	\N	PRESENT	0
716786	716730	20914V	PARTICIPANT	\N	PRESENT	0
716787	716496	11033F	PARTICIPANT	\N	PRESENT	0
716788	716496	04047H	PARTICIPANT	\N	PRESENT	0
716789	716496	19673G	PARTICIPANT	\N	PRESENT	0
716790	716496	20102Q	PARTICIPANT	\N	PRESENT	0
716791	716496	11040E	PARTICIPANT	\N	PRESENT	0
716792	716496	11083R	PARTICIPANT	\N	PRESENT	0
716793	716496	14207L	PARTICIPANT	\N	PRESENT	0
716794	716496	20072C	PARTICIPANT	\N	PRESENT	0
716795	716496	19583F	PARTICIPANT	\N	PRESENT	0
716796	716730	14083S	PARTICIPANT	\N	PRESENT	0
716797	716730	20126Y	PARTICIPANT	\N	PRESENT	0
716798	716730	19671E	PARTICIPANT	\N	PRESENT	0
716799	716496	19387D	PARTICIPANT	\N	PRESENT	0
716800	716496	19413M	PARTICIPANT	\N	PRESENT	0
716801	716496	14089Y	PARTICIPANT	\N	PRESENT	0
716802	716496	14275Y	PARTICIPANT	\N	PRESENT	0
716803	716496	14215L	PARTICIPANT	\N	PRESENT	0
716804	716496	19701S	PARTICIPANT	\N	PRESENT	0
716805	716496	20062A	PARTICIPANT	\N	PRESENT	0
716806	716730	19667J	PARTICIPANT	\N	PRESENT	0
716807	716496	97011G	PARTICIPANT	\N	PRESENT	0
716808	716496	20108W	PARTICIPANT	\N	PRESENT	0
716809	716730	19711U	PARTICIPANT	\N	PRESENT	0
716810	716496	20056C	PARTICIPANT	\N	PRESENT	0
716811	716730	19479G	PARTICIPANT	\N	PRESENT	0
716812	716496	20034V	PARTICIPANT	\N	PRESENT	0
716813	716730	20252E	PARTICIPANT	\N	PRESENT	0
716814	716496	19507S	PARTICIPANT	\N	PRESENT	0
716816	716496	18083K	PARTICIPANT	\N	PRESENT	0
716817	716496	19575F	PARTICIPANT	\N	PRESENT	0
716818	716730	14033T	PARTICIPANT	\N	PRESENT	0
716819	716496	11026G	PARTICIPANT	\N	PRESENT	0
716820	716496	19467C	PARTICIPANT	\N	PRESENT	0
716821	716496	14038Y	PARTICIPANT	\N	PRESENT	0
716822	716496	20026V	PARTICIPANT	\N	PRESENT	0
716823	716496	14193X	PARTICIPANT	\N	PRESENT	0
716824	716730	20116W	PARTICIPANT	\N	PRESENT	0
716825	716730	20080C	PARTICIPANT	\N	PRESENT	0
716826	716496	20106U	PARTICIPANT	\N	PRESENT	0
716827	716496	19782L	PARTICIPANT	\N	PRESENT	0
716828	716496	19631V	PARTICIPANT	\N	PRESENT	0
716830	716496	19629C	PARTICIPANT	\N	PRESENT	0
716832	716730	11048N	PARTICIPANT	\N	PRESENT	0
716833	716496	11072N	PARTICIPANT	\N	PRESENT	0
716834	716730	08034U	PARTICIPANT	\N	PRESENT	0
716835	716730	19741B	PARTICIPANT	\N	PRESENT	0
716836	716496	19691J	PARTICIPANT	\N	PRESENT	0
716837	716496	14107H	PARTICIPANT	\N	PRESENT	0
716838	716496	01025N	PARTICIPANT	\N	PRESENT	0
716839	716730	19762G	PARTICIPANT	\N	PRESENT	0
716840	716496	20054A	PARTICIPANT	\N	PRESENT	0
716841	716496	14205J	PARTICIPANT	\N	PRESENT	0
716842	716496	20058E	PARTICIPANT	\N	PRESENT	0
716843	716496	19747H	PARTICIPANT	\N	PRESENT	0
716844	716496	20032T	PARTICIPANT	\N	PRESENT	0
716846	716496	20028X	PARTICIPANT	\N	PRESENT	0
716847	716496	20024T	PARTICIPANT	\N	PRESENT	0
716848	716496	19585H	PARTICIPANT	\N	PRESENT	0
721099	720090	98022P	PARTICIPANT	\N	PRESENT	0
721100	720090	11064N	PARTICIPANT	\N	PRESENT	0
721101	720090	11083R	PARTICIPANT	\N	PRESENT	0
721102	720090	07033P	PARTICIPANT	\N	PRESENT	0
721103	720090	08061X	PARTICIPANT	\N	PRESENT	0
721104	720090	14211G	PARTICIPANT	\N	PRESENT	0
721105	720090	08047A	PARTICIPANT	\N	PRESENT	0
721106	720090	20128B	PARTICIPANT	\N	PRESENT	0
721107	720090	19443T	PARTICIPANT	\N	EXCUSE	0
721108	720090	19565D	PARTICIPANT	\N	EXCUSE	0
721109	720090	14267Y	PARTICIPANT	\N	EXCUSE	0
721110	720090	11027H	PARTICIPANT	\N	EXCUSE	0
721111	720090	04042C	PARTICIPANT	\N	EXCUSE	0
721112	720090	97011G	PARTICIPANT	\N	EXCUSE	0
721113	719035	19637C	PARTICIPANT	\N	EXCUSE	0
721114	719035	20068G	PARTICIPANT	\N	PRESENT	0
721136	720076	11056N	PARTICIPANT	\N	PRESENT	0
721137	720076	17737W	PARTICIPANT	\N	PRESENT	0
721138	720076	20074E	PARTICIPANT	\N	PRESENT	0
721139	720076	19543W	PARTICIPANT	\N	PRESENT	0
721140	720076	19581D	PARTICIPANT	\N	PRESENT	0
721141	720076	14215L	PARTICIPANT	\N	PRESENT	0
721145	720076	04047H	PRESIDENT	0	PRESENT	0
721147	720199	19383Y	PARTICIPANT	\N	PRESENT	0
721148	720199	20088L	PARTICIPANT	\N	PRESENT	0
721149	720199	19768N	PARTICIPANT	\N	PRESENT	0
721150	720199	19515S	PARTICIPANT	\N	PRESENT	0
721151	720199	19782L	PARTICIPANT	\N	PRESENT	0
721152	720199	20092G	PARTICIPANT	\N	PRESENT	0
721153	720199	01043Q	PARTICIPANT	\N	PRESENT	0
721154	720199	14357A	PARTICIPANT	\N	PRESENT	0
721155	720199	20078J	PARTICIPANT	\N	PRESENT	0
721156	720199	19441R	PARTICIPANT	\N	PRESENT	0
721157	720199	19413M	PARTICIPANT	\N	PRESENT	0
721158	720199	19866P	PARTICIPANT	\N	PRESENT	0
721159	720199	19631V	PARTICIPANT	\N	PRESENT	0
721160	720199	20104S	PARTICIPANT	\N	PRESENT	0
721161	720199	11099A	PARTICIPANT	\N	PRESENT	0
721162	720199	19705W	PARTICIPANT	\N	PRESENT	0
721163	720199	08015R	PARTICIPANT	\N	PRESENT	0
721164	720199	19575F	PARTICIPANT	\N	PRESENT	0
721165	720199	19369B	PARTICIPANT	\N	PRESENT	0
721166	720199	20018V	PARTICIPANT	\N	PRESENT	0
721167	720199	08028W	PARTICIPANT	\N	PRESENT	0
721168	720199	19563B	PARTICIPANT	\N	PRESENT	0
721169	720199	14329V	PARTICIPANT	\N	PRESENT	0
721170	720199	14037X	PARTICIPANT	\N	PRESENT	0
721171	720199	20028X	PARTICIPANT	\N	PRESENT	0
721172	720199	20030R	PARTICIPANT	\N	PRESENT	0
721173	720199	14038Y	PARTICIPANT	\N	PRESENT	0
721174	720199	19467C	PARTICIPANT	\N	PRESENT	0
721175	720199	14187A	PARTICIPANT	\N	PRESENT	0
721176	720199	20144B	PARTICIPANT	\N	PRESENT	0
721177	720199	19695N	PARTICIPANT	\N	PRESENT	0
721178	720199	11090Q	PRESIDENT	0	PRESENT	0
721179	720199	01025N	PARTICIPANT	\N	PRESENT	0
721180	720199	14033T	PARTICIPANT	\N	PRESENT	0
721181	720199	20054A	PARTICIPANT	\N	PRESENT	0
721182	720199	14205J	PARTICIPANT	\N	PRESENT	0
721183	720199	20060X	PARTICIPANT	\N	PRESENT	0
721184	720199	19507S	PARTICIPANT	\N	PRESENT	0
721185	720199	20286Q	PARTICIPANT	\N	PRESENT	0
721186	720199	20298U	PARTICIPANT	\N	PRESENT	0
721187	720199	14207L	PARTICIPANT	\N	PRESENT	0
721188	720199	19747H	PARTICIPANT	\N	PRESENT	0
721189	720199	14257W	PARTICIPANT	\N	PRESENT	0
721190	720090	19669L	PARTICIPANT	\N	PRESENT	0
721191	720090	08056B	PARTICIPANT	\N	PRESENT	0
721192	720090	19347U	PARTICIPANT	\N	PRESENT	0
721193	720090	20064C	PARTICIPANT	\N	PRESENT	0
721195	719035	20140W	PARTICIPANT	\N	PRESENT	0
721196	720098	86034E	PARTICIPANT	\N	PRESENT	0
721197	720076	14001X	PARTICIPANT	\N	PRESENT	0
721198	720076	19585H	PARTICIPANT	\N	PRESENT	0
721199	720076	19673G	PARTICIPANT	\N	PRESENT	0
721200	720076	19447X	PARTICIPANT	\N	PRESENT	0
721201	720076	05008E	PARTICIPANT	\N	PRESENT	0
721202	720076	19489J	PARTICIPANT	\N	PRESENT	0
721203	720076	14107H	PARTICIPANT	\N	PRESENT	0
721204	720076	20108W	PARTICIPANT	\N	PRESENT	0
721205	720076	20110Q	PARTICIPANT	\N	PRESENT	0
721206	720076	14147R	PARTICIPANT	\N	PRESENT	0
721207	720076	14179A	PARTICIPANT	\N	PRESENT	0
721208	720076	14151M	PARTICIPANT	\N	PRESENT	0
721209	720076	08018U	PARTICIPANT	\N	PRESENT	0
721210	720076	14259Y	PARTICIPANT	\N	PRESENT	0
721211	720076	20022R	PARTICIPANT	\N	PRESENT	0
721212	720076	11072N	PARTICIPANT	\N	PRESENT	0
721213	720076	14053L	PARTICIPANT	\N	PRESENT	0
721214	720076	11026G	PARTICIPANT	\N	PRESENT	0
721215	720076	10015M	PARTICIPANT	\N	PRESENT	0
721216	720076	04085P	PARTICIPANT	\N	PRESENT	0
721217	720076	14089Y	PARTICIPANT	\N	PRESENT	0
721218	720076	19725B	PARTICIPANT	\N	PRESENT	0
721219	720076	19729F	PARTICIPANT	\N	PRESENT	0
721220	720076	14069U	PARTICIPANT	\N	PRESENT	0
721221	720076	19749K	PARTICIPANT	\N	PRESENT	0
721222	720076	04008A	PARTICIPANT	\N	PRESENT	0
721223	719035	19701S	PARTICIPANT	\N	PRESENT	0
721225	720076	20114U	PARTICIPANT	\N	PRESENT	0
721226	720076	14111D	PARTICIPANT	\N	PRESENT	0
721230	720076	14231L	PARTICIPANT	\N	PRESENT	0
721231	720076	19649G	PARTICIPANT	\N	PRESENT	0
721232	720076	11010L	PARTICIPANT	\N	PRESENT	0
721395	721264	19647E	PARTICIPANT	\N	PRESENT	0
721438	720098	14179A	PARTICIPANT	\N	PRESENT	0
721442	720098	20068G	PARTICIPANT	\N	PRESENT	0
721444	720098	11077T	PARTICIPANT	\N	PRESENT	0
721450	720098	08028W	PARTICIPANT	\N	PRESENT	0
721451	720098	19507S	PARTICIPANT	\N	PRESENT	0
721452	720098	14259Y	PARTICIPANT	\N	PRESENT	0
721453	720098	14107H	PARTICIPANT	\N	PRESENT	0
721454	720098	19721W	PARTICIPANT	\N	PRESENT	0
721455	720098	19593H	PARTICIPANT	\N	PRESENT	0
721456	720098	19629C	PARTICIPANT	\N	PRESENT	0
721457	720098	20100N	PARTICIPANT	\N	PRESENT	0
721461	720091	95041E	PARTICIPANT	\N	PRESENT	0
721462	720091	12041X	PARTICIPANT	\N	PRESENT	0
721463	720091	11080N	PARTICIPANT	\N	PRESENT	0
721464	720091	20072C	PARTICIPANT	\N	PRESENT	0
721465	720091	01058X	PARTICIPANT	\N	PRESENT	0
721466	720091	16685X	PARTICIPANT	\N	PRESENT	0
721467	720091	11066Q	PARTICIPANT	\N	PRESENT	0
721468	720091	19669L	PARTICIPANT	\N	PRESENT	0
721469	720091	08056B	PARTICIPANT	\N	PRESENT	0
721470	720091	12028B	PARTICIPANT	\N	PRESENT	0
721471	720091	11115U	PARTICIPANT	\N	PRESENT	0
721472	720091	14055N	PARTICIPANT	\N	PRESENT	0
721473	720091	19421M	PARTICIPANT	\N	PRESENT	0
721474	720091	19347U	PARTICIPANT	\N	PRESENT	0
721475	720091	07033P	PARTICIPANT	\N	PRESENT	0
721476	720091	08061X	PARTICIPANT	\N	PRESENT	0
721477	720091	14249W	PARTICIPANT	\N	PRESENT	0
721478	720091	08047A	PARTICIPANT	\N	PRESENT	0
721479	720091	20128B	PARTICIPANT	\N	PRESENT	0
721480	720091	14097Y	PARTICIPANT	\N	PRESENT	0
721481	720091	14059S	PARTICIPANT	\N	PRESENT	0
721482	720091	04035D	PARTICIPANT	\N	PRESENT	0
721483	720091	14133K	PRESIDENT	0	PRESENT	0
721484	720091	01062T	PARTICIPANT	\N	PRESENT	0
721485	720091	08069G	PARTICIPANT	\N	PRESENT	0
721486	720091	11041F	PARTICIPANT	\N	PRESENT	0
721487	720091	20042V	PARTICIPANT	\N	PRESENT	0
721488	720091	01024M	PARTICIPANT	\N	PRESENT	0
721489	720091	19721W	PARTICIPANT	\N	PRESENT	0
721490	720091	20064C	PARTICIPANT	\N	PRESENT	0
721491	720091	98022P	PARTICIPANT	\N	PRESENT	0
721492	720091	11064N	PARTICIPANT	\N	PRESENT	0
721493	720091	11083R	PARTICIPANT	\N	PRESENT	0
721494	720091	14211G	PARTICIPANT	\N	PRESENT	0
721495	720091	19443T	PARTICIPANT	\N	EXCUSE	0
721496	720091	19565D	PARTICIPANT	\N	EXCUSE	0
721497	720091	14267Y	PARTICIPANT	\N	EXCUSE	0
721498	720091	11027H	PARTICIPANT	\N	EXCUSE	0
721499	720091	04042C	PARTICIPANT	\N	EXCUSE	0
721500	720091	97011G	PARTICIPANT	\N	EXCUSE	0
721504	720098	20252E	PARTICIPANT	\N	PRESENT	0
721505	720098	14331P	PARTICIPANT	\N	PRESENT	0
721506	720098	20086J	PARTICIPANT	\N	PRESENT	0
721507	720098	19577H	PARTICIPANT	\N	PRESENT	0
721508	720098	20088L	PARTICIPANT	\N	PRESENT	0
715525	712592	86034E	PARTICIPANT	\N	PRESENT	0
715527	712592	14042U	PARTICIPANT	\N	PRESENT	0
715528	712592	10006L	PARTICIPANT	\N	PRESENT	0
715529	712592	11097X	PARTICIPANT	\N	PRESENT	0
715530	712592	14195A	PARTICIPANT	\N	PRESENT	0
715531	712592	20068G	PARTICIPANT	\N	PRESENT	0
715532	712592	19766L	PARTICIPANT	\N	PRESENT	0
715533	712592	20148F	PARTICIPANT	\N	PRESENT	0
715534	712592	20130U	PARTICIPANT	\N	PRESENT	0
715535	712592	04057K	PARTICIPANT	\N	PRESENT	0
715536	712592	19591F	PARTICIPANT	\N	PRESENT	0
715537	712592	19760E	PARTICIPANT	\N	PRESENT	0
715538	712592	19569H	PARTICIPANT	\N	PRESENT	0
715539	712592	14055N	PARTICIPANT	\N	PRESENT	0
715540	712592	11012A	PARTICIPANT	\N	PRESENT	0
715541	712592	20102Q	PARTICIPANT	\N	PRESENT	0
715542	712592	19367Y	PARTICIPANT	\N	PRESENT	0
715543	712592	19681G	PARTICIPANT	\N	PRESENT	0
715544	712592	19745F	PARTICIPANT	\N	PRESENT	0
715545	712592	19798U	PARTICIPANT	\N	PRESENT	0
715546	712592	14275Y	PARTICIPANT	\N	PRESENT	0
715547	712592	11067R	PARTICIPANT	\N	PRESENT	0
715548	712592	19525U	PARTICIPANT	\N	PRESENT	0
715549	712592	14215L	PARTICIPANT	\N	PRESENT	0
715550	712592	20056C	PARTICIPANT	\N	PRESENT	0
715551	712592	19657G	PARTICIPANT	\N	PRESENT	0
715552	712592	14223L	PARTICIPANT	\N	PRESENT	0
715553	712592	19581D	PARTICIPANT	\N	PRESENT	0
715554	712592	19599P	PARTICIPANT	\N	PRESENT	0
715555	712592	14030Q	PARTICIPANT	\N	PRESENT	0
715556	712592	20100N	PARTICIPANT	\N	PRESENT	0
715557	712592	14097Y	PARTICIPANT	\N	PRESENT	0
715558	712592	19693L	PARTICIPANT	\N	PRESENT	0
715559	712592	19467C	PARTICIPANT	\N	PRESENT	0
715560	712592	19747H	PARTICIPANT	\N	PRESENT	0
715561	712592	20052X	PARTICIPANT	\N	PRESENT	0
715562	712592	14107H	PARTICIPANT	\N	PRESENT	0
715563	712592	14073Q	PARTICIPANT	\N	PRESENT	0
715564	712592	20142Y	PARTICIPANT	\N	PRESENT	0
715565	712592	20092G	PARTICIPANT	\N	PRESENT	0
715566	712592	19347U	PARTICIPANT	\N	PRESENT	0
715567	712592	17779H	PARTICIPANT	\N	PRESENT	0
715568	712592	14021P	PARTICIPANT	\N	PRESENT	0
715569	712592	04059M	PARTICIPANT	\N	PRESENT	0
715570	712592	11045K	PARTICIPANT	\N	PRESENT	0
715571	712592	10015M	PARTICIPANT	\N	PRESENT	0
715572	712592	14229S	PARTICIPANT	\N	PRESENT	0
715573	712592	19683J	PARTICIPANT	\N	PRESENT	0
715574	712592	01057W	PARTICIPANT	\N	PRESENT	0
715575	712592	19333N	PARTICIPANT	\N	PRESENT	0
715576	712592	11080N	PARTICIPANT	\N	PRESENT	0
715577	712592	14151M	PARTICIPANT	\N	PRESENT	0
715578	712592	14123H	PARTICIPANT	\N	PRESENT	0
715579	712592	20028X	PARTICIPANT	\N	PRESENT	0
715580	712592	18083K	PARTICIPANT	\N	PRESENT	0
715581	712592	14109K	PARTICIPANT	\N	PRESENT	0
715582	712592	08012N	PARTICIPANT	\N	PRESENT	0
715583	712592	08010L	PARTICIPANT	\N	PRESENT	0
715584	712592	19820Y	PARTICIPANT	\N	PRESENT	0
715585	712592	04047H	PARTICIPANT	\N	PRESENT	0
715586	712592	18193Q	PARTICIPANT	\N	PRESENT	0
715587	712592	20032T	PARTICIPANT	\N	PRESENT	0
715588	712592	11090Q	PARTICIPANT	\N	PRESENT	0
715589	712592	20080C	PARTICIPANT	\N	PRESENT	0
715590	712592	19503N	PARTICIPANT	\N	PRESENT	0
715591	712592	12028B	PARTICIPANT	\N	PRESENT	0
715592	712592	19489J	PARTICIPANT	\N	PRESENT	0
715593	712592	99004R	PARTICIPANT	\N	PRESENT	0
715594	712592	20060X	PARTICIPANT	\N	PRESENT	0
715595	712592	08034U	PARTICIPANT	\N	PRESENT	0
715596	712592	20030R	PARTICIPANT	\N	PRESENT	0
715597	712592	19527W	PARTICIPANT	\N	PRESENT	0
715598	712592	19631V	PARTICIPANT	\N	PRESENT	0
715599	712592	19415P	PARTICIPANT	\N	PRESENT	0
715600	712592	20084G	PARTICIPANT	\N	PRESENT	0
715601	712592	14071N	PARTICIPANT	\N	PRESENT	0
715602	712592	14281W	PARTICIPANT	\N	PRESENT	0
715603	712592	19711U	PARTICIPANT	\N	PRESENT	0
715604	712592	14257W	PARTICIPANT	\N	PRESENT	0
715605	712592	19649G	PARTICIPANT	\N	PRESENT	0
715606	712592	08073C	PARTICIPANT	\N	PRESENT	0
715607	712592	14053L	PARTICIPANT	\N	PRESENT	0
715608	712592	11033F	PARTICIPANT	\N	PRESENT	0
715609	712592	20036X	PARTICIPANT	\N	PRESENT	0
715610	712592	19782L	PARTICIPANT	\N	PRESENT	0
715611	712592	14237S	PARTICIPANT	\N	PRESENT	0
715612	712592	20110Q	PARTICIPANT	\N	PRESENT	0
715613	712592	20022R	PARTICIPANT	\N	PRESENT	0
715614	712592	20070A	PARTICIPANT	\N	PRESENT	0
715615	712592	12016W	PARTICIPANT	\N	PRESENT	0
715616	712592	14331P	PARTICIPANT	\N	PRESENT	0
715617	712592	14147R	PARTICIPANT	\N	PRESENT	0
715618	712592	19715Y	PARTICIPANT	\N	PRESENT	0
715619	712592	01028R	PARTICIPANT	\N	PRESENT	0
715620	712592	14213J	PARTICIPANT	\N	PRESENT	0
715621	712592	20266L	PARTICIPANT	\N	PRESENT	0
715622	712592	20134Y	PARTICIPANT	\N	PRESENT	0
715624	712592	20024T	PARTICIPANT	\N	PRESENT	0
715625	712592	20180F	PARTICIPANT	\N	PRESENT	0
715627	712592	14111D	PARTICIPANT	\N	PRESENT	0
715630	712592	20122U	PARTICIPANT	\N	PRESENT	0
715631	712592	19399H	PARTICIPANT	\N	PRESENT	0
715632	712592	14033T	PARTICIPANT	\N	PRESENT	0
715633	712592	19583F	PARTICIPANT	\N	PRESENT	0
715634	712592	20086J	PARTICIPANT	\N	PRESENT	0
715635	712592	14221J	PARTICIPANT	\N	PRESENT	0
715636	712592	19573D	PARTICIPANT	\N	PRESENT	0
715637	712592	20042V	PARTICIPANT	\N	PRESENT	0
715638	712592	19447X	PARTICIPANT	\N	PRESENT	0
715639	712592	14219Q	PARTICIPANT	\N	PRESENT	0
715640	712592	20038A	PARTICIPANT	\N	PRESENT	0
715641	712592	19441R	PARTICIPANT	\N	PRESENT	0
715642	712592	19739H	PARTICIPANT	\N	PRESENT	0
715643	712592	14038Y	PARTICIPANT	\N	PRESENT	0
715644	712592	11053K	PARTICIPANT	\N	PRESENT	0
715645	712592	20058E	PARTICIPANT	\N	PRESENT	0
715646	712592	20132W	PARTICIPANT	\N	PRESENT	0
715647	712592	20034V	PARTICIPANT	\N	PRESENT	0
715648	712592	19553Y	PARTICIPANT	\N	PRESENT	0
715649	712592	19629C	PARTICIPANT	\N	PRESENT	0
715650	712592	14031R	PARTICIPANT	\N	PRESENT	0
715651	712592	19866P	PARTICIPANT	\N	PRESENT	0
715652	712592	20298U	PARTICIPANT	\N	PRESENT	0
715653	712592	14191V	PARTICIPANT	\N	PRESENT	0
715654	712592	95063L	PARTICIPANT	\N	PRESENT	0
715655	712592	01025N	PARTICIPANT	\N	PRESENT	0
715656	712592	19349W	PARTICIPANT	\N	PRESENT	0
715657	712592	19621T	PARTICIPANT	\N	PRESENT	0
715658	712592	14179A	PARTICIPANT	\N	PRESENT	0
715659	712592	19758L	PARTICIPANT	\N	PRESENT	0
715660	712592	11040E	PARTICIPANT	\N	PRESENT	0
715661	712592	19687N	PARTICIPANT	\N	PRESENT	0
715662	712592	19335Q	PARTICIPANT	\N	PRESENT	0
715663	712592	11031D	PARTICIPANT	\N	PRESENT	0
715664	712592	04085P	PARTICIPANT	\N	PRESENT	0
715665	712592	19695N	PARTICIPANT	\N	PRESENT	0
715666	712592	11056N	PARTICIPANT	\N	PRESENT	0
715667	712592	14189C	PARTICIPANT	\N	PRESENT	0
715668	712592	14255U	PARTICIPANT	\N	PRESENT	0
715669	712592	20126Y	PARTICIPANT	\N	PRESENT	0
715670	712592	20062A	PARTICIPANT	\N	PRESENT	0
715671	712592	14357A	PARTICIPANT	\N	PRESENT	0
715672	712592	20046A	PARTICIPANT	\N	PRESENT	0
715673	712592	05008E	PARTICIPANT	\N	PRESENT	0
715674	712592	11083R	PARTICIPANT	\N	PRESENT	0
715675	712592	01043Q	PARTICIPANT	\N	PRESENT	0
715676	712592	14205J	PARTICIPANT	\N	PRESENT	0
715677	712592	11027H	PARTICIPANT	\N	PRESENT	0
715678	712592	20064C	PARTICIPANT	\N	PRESENT	0
715679	712592	19611R	PARTICIPANT	\N	PRESENT	0
715680	712592	01058X	PARTICIPANT	\N	PRESENT	0
715681	712592	14187A	PARTICIPANT	\N	PRESENT	0
715682	712592	14037X	PARTICIPANT	\N	PRESENT	0
715683	712592	19697Q	PARTICIPANT	\N	PRESENT	0
715684	712592	11110B	PARTICIPANT	\N	PRESENT	0
715685	712592	07029T	PARTICIPANT	\N	PRESENT	0
715686	712592	20044X	PARTICIPANT	\N	PRESENT	0
715687	712592	97011G	PARTICIPANT	\N	PRESENT	0
715688	712592	11070L	PARTICIPANT	\N	PRESENT	0
715689	712592	11048N	PARTICIPANT	\N	PRESENT	0
715690	712592	14026U	PARTICIPANT	\N	PRESENT	0
735558	735554	17965H	PARTICIPANT	\N	PRESENT	0
735647	735646	19507S	PARTICIPANT	\N	PRESENT	0
735648	735646	14030Q	PARTICIPANT	\N	PRESENT	0
735649	735646	01024M	PARTICIPANT	\N	PRESENT	0
735650	735646	01025N	PARTICIPANT	\N	PRESENT	0
735651	735646	20180F	PARTICIPANT	\N	PRESENT	0
735652	735646	08015R	PARTICIPANT	\N	PRESENT	0
735653	735646	04045F	PARTICIPANT	\N	PRESENT	0
739154	738998	19383Y	PARTICIPANT	\N	PRESENT	0
739155	738998	19768N	PARTICIPANT	\N	PRESENT	0
739156	738998	20088L	PARTICIPANT	\N	PRESENT	0
739157	738998	19515S	PARTICIPANT	\N	PRESENT	0
739158	738998	19782L	PARTICIPANT	\N	PRESENT	0
739159	738998	20092G	PARTICIPANT	\N	PRESENT	0
739160	738998	11077T	PARTICIPANT	\N	PRESENT	0
739161	738998	01043Q	PARTICIPANT	\N	PRESENT	0
739162	738998	19441R	PARTICIPANT	\N	PRESENT	0
739163	738998	20078J	PARTICIPANT	\N	PRESENT	0
739164	738998	19413M	PARTICIPANT	\N	PRESENT	0
739165	738998	20082E	PARTICIPANT	\N	PRESENT	0
739166	738998	20094J	PARTICIPANT	\N	PRESENT	0
739167	738998	19866P	PARTICIPANT	\N	PRESENT	0
739168	738998	19631V	PARTICIPANT	\N	PRESENT	0
739169	738998	20104S	PARTICIPANT	\N	PRESENT	0
739170	738998	11099A	PARTICIPANT	\N	PRESENT	0
739171	738998	19705W	PARTICIPANT	\N	PRESENT	0
739172	738998	19707Y	PARTICIPANT	\N	PRESENT	0
739173	738998	08015R	PARTICIPANT	\N	PRESENT	0
739174	738998	19575F	PARTICIPANT	\N	PRESENT	0
739175	738998	19369B	PARTICIPANT	\N	PRESENT	0
739176	738998	20018V	PARTICIPANT	\N	PRESENT	0
739177	738998	08028W	PARTICIPANT	\N	PRESENT	0
739178	738998	14329V	PARTICIPANT	\N	PRESENT	0
739179	738998	20028X	PARTICIPANT	\N	PRESENT	0
739180	738998	20030R	PARTICIPANT	\N	PRESENT	0
739181	738998	14038Y	PARTICIPANT	\N	PRESENT	0
739182	738998	19467C	PARTICIPANT	\N	PRESENT	0
739183	738998	20034V	PARTICIPANT	\N	PRESENT	0
739184	738998	14187A	PARTICIPANT	\N	PRESENT	0
739185	738998	20144B	PARTICIPANT	\N	PRESENT	0
739186	738998	19695N	PARTICIPANT	\N	PRESENT	0
739187	738998	11090Q	PARTICIPANT	\N	PRESENT	0
739188	738998	14033T	PARTICIPANT	\N	PRESENT	0
739189	738998	01025N	PARTICIPANT	\N	PRESENT	0
739190	738998	14205J	PARTICIPANT	\N	PRESENT	0
739191	738998	20060X	PARTICIPANT	\N	PRESENT	0
739192	738998	20062A	PARTICIPANT	\N	PRESENT	0
739193	738998	14251Q	PARTICIPANT	\N	PRESENT	0
739194	738998	19507S	PARTICIPANT	\N	PRESENT	0
739195	738998	20286Q	PARTICIPANT	\N	PRESENT	0
739196	738998	20298U	PARTICIPANT	\N	PRESENT	0
739197	738998	19747H	PARTICIPANT	\N	PRESENT	0
739198	738998	14207L	PARTICIPANT	\N	PRESENT	0
739199	738998	14257W	PARTICIPANT	\N	PRESENT	0
739200	738998	14357A	PARTICIPANT	\N	EXCUSE	0
739201	738998	04045F	PARTICIPANT	\N	EXCUSE	0
739202	738998	19563B	PARTICIPANT	\N	EXCUSE	0
739204	737730	11067R	PARTICIPANT	\N	PRESENT	0
739205	737730	20090E	PARTICIPANT	\N	PRESENT	0
739206	737730	19798U	PARTICIPANT	\N	PRESENT	0
739207	737730	11097X	PARTICIPANT	\N	PRESENT	0
739208	737730	19415P	PARTICIPANT	\N	PRESENT	0
739209	737730	14223L	PARTICIPANT	\N	PRESENT	0
739210	737730	18193Q	PARTICIPANT	\N	PRESENT	0
739211	737730	14026U	PARTICIPANT	\N	PRESENT	0
739212	737730	17779H	PARTICIPANT	\N	PRESENT	0
739213	737730	19703U	PARTICIPANT	\N	PRESENT	0
739214	737730	11031D	PARTICIPANT	\N	PRESENT	0
739215	737730	19553Y	PARTICIPANT	\N	PRESENT	0
739216	737730	14195A	PARTICIPANT	\N	PRESENT	0
739217	737730	19367Y	PARTICIPANT	\N	PRESENT	0
739218	737730	14213J	PARTICIPANT	\N	PRESENT	0
739219	737730	14217N	PARTICIPANT	\N	PRESENT	0
739221	737730	10006L	PRESIDENT	0	PRESENT	0
739224	737730	19683J	PARTICIPANT	\N	PRESENT	0
739226	737730	20130U	PARTICIPANT	\N	PRESENT	0
739227	737730	01034P	PARTICIPANT	\N	PRESENT	0
739229	737730	04057K	PARTICIPANT	\N	PRESENT	0
739231	737730	04092N	PARTICIPANT	\N	PRESENT	0
739234	737730	19713W	PARTICIPANT	\N	PRESENT	0
739235	737730	11045K	PARTICIPANT	\N	PRESENT	0
739237	737730	20040T	PARTICIPANT	\N	PRESENT	0
739239	737730	19663E	PARTICIPANT	\N	PRESENT	0
739240	737730	19691J	PARTICIPANT	\N	PRESENT	0
739242	737730	20148F	PARTICIPANT	\N	PRESENT	0
739243	737730	19723Y	PARTICIPANT	\N	PRESENT	0
739245	737730	20248J	PARTICIPANT	\N	PRESENT	0
739247	737730	20066E	PARTICIPANT	\N	PRESENT	0
739248	737730	20266L	PARTICIPANT	\N	PRESENT	0
739249	737730	14071N	PARTICIPANT	\N	PRESENT	0
739252	737730	04043D	PARTICIPANT	\N	PRESENT	0
739254	737730	19760E	PARTICIPANT	\N	PRESENT	0
739274	737730	19735D	PARTICIPANT	\N	PRESENT	0
739275	738362	20086J	PARTICIPANT	\N	PRESENT	0
739276	738362	14331P	PARTICIPANT	\N	PRESENT	0
739277	738362	11053K	PARTICIPANT	\N	PRESENT	0
739278	738362	19479G	PARTICIPANT	\N	PRESENT	0
739279	738362	11012A	PARTICIPANT	\N	PRESENT	0
739280	736883	19333N	PARTICIPANT	\N	PRESENT	0
739281	736883	19701S	PARTICIPANT	\N	PRESENT	0
739282	736883	19549D	PARTICIPANT	\N	PRESENT	0
739283	736883	20076G	PARTICIPANT	\N	PRESENT	0
739284	736883	19387D	PARTICIPANT	\N	PRESENT	0
739285	736883	11053K	PARTICIPANT	\N	PRESENT	0
739286	736883	14219Q	PRESIDENT	0	PRESENT	0
739287	736883	19820Y	PARTICIPANT	\N	PRESENT	0
739288	736883	19826F	PARTICIPANT	\N	PRESENT	0
739289	736883	20102Q	PARTICIPANT	\N	PRESENT	0
739290	736883	19599P	PARTICIPANT	\N	PRESENT	0
739291	736883	19637C	PARTICIPANT	\N	PRESENT	0
739292	736883	20096L	PARTICIPANT	\N	PRESENT	0
739293	736883	18083K	PARTICIPANT	\N	PRESENT	0
739294	736883	14237S	PARTICIPANT	\N	PRESENT	0
739295	736883	20100N	PARTICIPANT	\N	PRESENT	0
739296	736883	05012A	PARTICIPANT	\N	PRESENT	0
739297	736883	08060W	PARTICIPANT	\N	PRESENT	0
739298	736883	20106U	PARTICIPANT	\N	PRESENT	0
739299	736883	20118Y	PARTICIPANT	\N	PRESENT	0
739300	736883	19503N	PARTICIPANT	\N	PRESENT	0
739301	736883	20020P	PARTICIPANT	\N	PRESENT	0
739302	736883	17367Q	PARTICIPANT	\N	PRESENT	0
739303	736883	19681G	PARTICIPANT	\N	PRESENT	0
739304	736883	20024T	PARTICIPANT	\N	PRESENT	0
739305	736883	19525U	PARTICIPANT	\N	PRESENT	0
739306	736883	20120S	PARTICIPANT	\N	PRESENT	0
739307	736883	20032T	PARTICIPANT	\N	PRESENT	0
739308	736883	20122U	PARTICIPANT	\N	PRESENT	0
739309	736883	20136B	PARTICIPANT	\N	PRESENT	0
739310	736883	20038A	PARTICIPANT	\N	PRESENT	0
739311	736883	14031R	PARTICIPANT	\N	PRESENT	0
739312	736883	20140W	PARTICIPANT	\N	PRESENT	0
739313	736883	19251M	PARTICIPANT	\N	PRESENT	0
739314	736883	20046A	PARTICIPANT	\N	PRESENT	0
739315	736883	20146D	PARTICIPANT	\N	PRESENT	0
739316	736883	17229F	PARTICIPANT	\N	PRESENT	0
739317	736883	14169X	PARTICIPANT	\N	PRESENT	0
739318	736883	20068G	PARTICIPANT	\N	PRESENT	0
739319	736883	11101A	PARTICIPANT	\N	PRESENT	0
739320	736883	19745F	PARTICIPANT	\N	PRESENT	0
739321	736883	19619A	PARTICIPANT	\N	PRESENT	0
739322	737730	19679N	PARTICIPANT	\N	PRESENT	0
739323	737972	19681G	PARTICIPANT	\N	EXCUSE	0
739324	737972	19735D	PARTICIPANT	\N	EXCUSE	0
739325	737972	14327T	PARTICIPANT	\N	PRESENT	0
739326	737972	19563B	PARTICIPANT	\N	EXCUSE	0
739327	737972	19349W	PARTICIPANT	\N	EXCUSE	0
739328	737972	14229S	PARTICIPANT	\N	EXCUSE	0
739329	737972	20062A	PARTICIPANT	\N	EXCUSE	0
739331	739330	20090E	PARTICIPANT	\N	PRESENT	0
739332	739330	20124W	PARTICIPANT	\N	PRESENT	0
739333	739330	14187A	PRESIDENT	0	PRESENT	0
739334	739330	19347U	PARTICIPANT	\N	PRESENT	0
739335	739330	14257W	PARTICIPANT	\N	PRESENT	0
739336	739330	20018V	PARTICIPANT	\N	EXCUSE	0
739337	739330	20062A	PARTICIPANT	\N	EXCUSE	0
739338	737730	14042U	PARTICIPANT	\N	PRESENT	0
739339	738516	19383Y	PARTICIPANT	\N	PRESENT	0
739340	738516	19768N	PARTICIPANT	\N	PRESENT	0
739341	738516	20088L	PARTICIPANT	\N	PRESENT	0
739342	738516	19515S	PARTICIPANT	\N	PRESENT	0
739343	738516	19782L	PARTICIPANT	\N	PRESENT	0
712557	712556	04042C	PARTICIPANT	\N	PRESENT	0
712561	709156	11043H	PARTICIPANT	\N	EXCUSE	0
714518	714517	14249W	PARTICIPANT	\N	PRESENT	0
714519	714517	19421M	PARTICIPANT	\N	PRESENT	0
714520	714517	14133K	PARTICIPANT	\N	PRESENT	0
714521	714517	14193X	PARTICIPANT	\N	PRESENT	0
714522	714517	19565D	PARTICIPANT	\N	PRESENT	0
714523	714517	14267Y	PARTICIPANT	\N	PRESENT	0
714524	714517	20128B	PARTICIPANT	\N	PRESENT	0
714525	714517	19319Q	PARTICIPANT	\N	PRESENT	0
714526	714517	12041X	PARTICIPANT	\N	PRESENT	0
714527	714517	08047A	PARTICIPANT	\N	PRESENT	0
714528	714517	04035D	PARTICIPANT	\N	PRESENT	0
714529	714517	19669L	PARTICIPANT	\N	PRESENT	0
714530	714517	14059S	PARTICIPANT	\N	PRESENT	0
714791	714789	20024T	PARTICIPANT	\N	PRESENT	0
714793	714789	18083K	PARTICIPANT	\N	PRESENT	0
714795	714789	10015M	PARTICIPANT	\N	PRESENT	0
714796	714789	19703U	PARTICIPANT	\N	PRESENT	0
714797	714789	20084G	PARTICIPANT	\N	PRESENT	0
716849	716496	11065P	PARTICIPANT	\N	PRESENT	0
716850	716496	20016T	PARTICIPANT	\N	PRESENT	0
716851	716496	11043H	PARTICIPANT	\N	PRESENT	0
716852	716496	20052X	PARTICIPANT	\N	PRESENT	0
716853	716496	14211G	PARTICIPANT	\N	PRESENT	0
716854	716496	01058X	PARTICIPANT	\N	PRESENT	0
716855	716496	19758L	PARTICIPANT	\N	PRESENT	0
716856	716496	08069G	PARTICIPANT	\N	PRESENT	0
716858	716496	20068G	PARTICIPANT	\N	PRESENT	0
716859	716496	19798U	PARTICIPANT	\N	PRESENT	0
716924	716497	14205J	PARTICIPANT	\N	PRESENT	0
716861	716496	08028W	PARTICIPANT	\N	PRESENT	0
716862	716496	01024M	PARTICIPANT	\N	PRESENT	0
716864	716730	20086J	PARTICIPANT	\N	PRESENT	0
716865	716496	19768N	PARTICIPANT	\N	PRESENT	0
716925	716497	14207L	PARTICIPANT	\N	PRESENT	0
716926	716497	20072C	PARTICIPANT	\N	PRESENT	0
716927	716497	19629C	PARTICIPANT	\N	PRESENT	0
716928	716497	19631V	PARTICIPANT	\N	PRESENT	0
716929	716497	19413M	PARTICIPANT	\N	PRESENT	0
716930	716497	20088L	PARTICIPANT	\N	PRESENT	0
716931	716497	20028X	PARTICIPANT	\N	PRESENT	0
716932	716497	19387D	PARTICIPANT	\N	PRESENT	0
716933	716497	14107H	PARTICIPANT	\N	PRESENT	0
716934	716497	20122U	PARTICIPANT	\N	PRESENT	0
716935	716497	19583F	PARTICIPANT	\N	PRESENT	0
716936	716497	11033F	PARTICIPANT	\N	PRESENT	0
716937	716497	01024M	PARTICIPANT	\N	PRESENT	0
716938	716497	20016T	PARTICIPANT	\N	PRESENT	0
716939	716497	19747H	PARTICIPANT	\N	PRESENT	0
716940	716497	19798U	PARTICIPANT	\N	PRESENT	0
716941	716497	19701S	PARTICIPANT	\N	PRESENT	0
716942	716497	97011G	PARTICIPANT	\N	PRESENT	0
716943	716497	20024T	PARTICIPANT	\N	PRESENT	0
716944	716497	01058X	PARTICIPANT	\N	PRESENT	0
716945	716497	20032T	PARTICIPANT	\N	PRESENT	0
716946	716497	08028W	PARTICIPANT	\N	PRESENT	0
716947	716497	20068G	PARTICIPANT	\N	PRESENT	0
716948	716497	20108W	PARTICIPANT	\N	PRESENT	0
716949	716497	20062A	PARTICIPANT	\N	PRESENT	0
716950	716497	19467C	PARTICIPANT	\N	PRESENT	0
716951	716497	14033T	PARTICIPANT	\N	PRESENT	0
716952	716497	18083K	PARTICIPANT	\N	PRESENT	0
716953	716497	19768N	PARTICIPANT	\N	PRESENT	0
716954	716497	08069G	PARTICIPANT	\N	PRESENT	0
716955	716497	20034V	PARTICIPANT	\N	PRESENT	0
716956	716497	19673G	PARTICIPANT	\N	PRESENT	0
716957	716497	14038Y	PARTICIPANT	\N	PRESENT	0
716958	716497	19575F	PARTICIPANT	\N	PRESENT	0
716959	716497	20144B	PARTICIPANT	\N	PRESENT	0
716960	716497	20058E	PARTICIPANT	\N	PRESENT	0
716961	716497	11072N	PARTICIPANT	\N	PRESENT	0
716962	716497	19758L	PARTICIPANT	\N	PRESENT	0
716963	716497	20102Q	PARTICIPANT	\N	PRESENT	0
716964	716497	08015R	PARTICIPANT	\N	PRESENT	0
716965	716497	11043H	PARTICIPANT	\N	PRESENT	0
716966	716497	20180F	PARTICIPANT	\N	PRESENT	0
716967	716497	19782L	PARTICIPANT	\N	PRESENT	0
716968	716497	20286Q	PARTICIPANT	\N	PRESENT	0
716969	716497	11099A	PARTICIPANT	\N	PRESENT	0
716970	716497	20054A	PARTICIPANT	\N	PRESENT	0
716974	716497	14275Y	PARTICIPANT	\N	PRESENT	0
716972	716497	19745F	PARTICIPANT	\N	PRESENT	0
716973	716613	19741B	PRESIDENT	0	PRESENT	0
716975	716497	19679N	PARTICIPANT	\N	PRESENT	0
716976	716497	19581D	PARTICIPANT	\N	PRESENT	0
716983	716497	19599P	PARTICIPANT	\N	PRESENT	0
716984	716497	11085T	PARTICIPANT	\N	PRESENT	0
716985	716497	01043Q	PARTICIPANT	\N	PRESENT	0
716986	716497	01025N	PARTICIPANT	\N	PRESENT	0
716922	716497	95063L	PARTICIPANT	\N	PRESENT	0
716923	716497	11090Q	PARTICIPANT	\N	PRESENT	0
716987	716497	20104S	PARTICIPANT	\N	PRESENT	0
716988	713635	20056C	PARTICIPANT	\N	PRESENT	0
716989	713635	20132W	PARTICIPANT	\N	PRESENT	0
716990	713635	20106U	PARTICIPANT	\N	PRESENT	0
716991	713635	20038A	PARTICIPANT	\N	PRESENT	0
716992	713635	14109K	PARTICIPANT	\N	PRESENT	0
716993	713635	19758L	PARTICIPANT	\N	PRESENT	0
716994	713635	20026V	PRESIDENT	0	PRESENT	0
716995	716497	11097X	PARTICIPANT	\N	PRESENT	0
716996	716497	19507S	PARTICIPANT	\N	PRESENT	0
716997	716497	14267Y	PARTICIPANT	\N	PRESENT	0
716998	716730	11053K	PARTICIPANT	\N	PRESENT	0
716999	716497	20092G	PARTICIPANT	\N	PRESENT	0
717000	716497	14147R	PARTICIPANT	\N	PRESENT	0
717001	716497	14037X	PARTICIPANT	\N	PRESENT	0
717045	716497	19699S	PARTICIPANT	\N	PRESENT	0
717046	716497	14089Y	PARTICIPANT	\N	PRESENT	0
717047	716497	11101A	PARTICIPANT	\N	PRESENT	0
717048	713635	20980G	PARTICIPANT	\N	PRESENT	0
717049	716613	19569H	PARTICIPANT	\N	PRESENT	0
717050	716613	20108W	PARTICIPANT	\N	PRESENT	0
717051	716613	20042V	PARTICIPANT	\N	PRESENT	0
717052	716613	20080C	PARTICIPANT	\N	PRESENT	0
717053	716613	08010L	PARTICIPANT	\N	PRESENT	0
717054	716613	19667J	PARTICIPANT	\N	PRESENT	0
717055	716613	20044X	PARTICIPANT	\N	PRESENT	0
717056	716613	19866P	PARTICIPANT	\N	PRESENT	0
717057	716613	19631V	PARTICIPANT	\N	PRESENT	0
717058	716613	20084G	PARTICIPANT	\N	PRESENT	0
717062	716497	14111D	PARTICIPANT	\N	PRESENT	0
717063	716497	20138D	PARTICIPANT	\N	PRESENT	0
717065	716497	20128B	PARTICIPANT	\N	PRESENT	0
717066	716497	11056N	PARTICIPANT	\N	PRESENT	0
717071	716497	19725B	PARTICIPANT	\N	PRESENT	0
717072	716497	14173T	PARTICIPANT	\N	PRESENT	0
717074	716497	14069U	PARTICIPANT	\N	PRESENT	0
717075	716497	14357A	PARTICIPANT	\N	PRESENT	0
717076	716497	07029T	PARTICIPANT	\N	PRESENT	0
717077	716497	11031D	PARTICIPANT	\N	PRESENT	0
717079	716497	19760E	PARTICIPANT	\N	PRESENT	0
717080	716498	95063L	PARTICIPANT	\N	PRESENT	0
717085	716498	19629C	PARTICIPANT	\N	PRESENT	0
717087	716498	19413M	PARTICIPANT	\N	PRESENT	0
717088	716498	20088L	PARTICIPANT	\N	PRESENT	0
717089	716498	20028X	PARTICIPANT	\N	PRESENT	0
717090	716498	19387D	PARTICIPANT	\N	PRESENT	0
717092	716498	20122U	PARTICIPANT	\N	PRESENT	0
717094	716498	11033F	PARTICIPANT	\N	PRESENT	0
717096	716498	20016T	PARTICIPANT	\N	PRESENT	0
717097	716498	19747H	PARTICIPANT	\N	PRESENT	0
717099	716498	19701S	PARTICIPANT	\N	PRESENT	0
717100	716498	97011G	PARTICIPANT	\N	PRESENT	0
717101	716498	01058X	PARTICIPANT	\N	PRESENT	0
717102	716498	20032T	PARTICIPANT	\N	PRESENT	0
717103	716498	08028W	PARTICIPANT	\N	PRESENT	0
717104	716498	20068G	PARTICIPANT	\N	PRESENT	0
717106	716498	14033T	PARTICIPANT	\N	PRESENT	0
717107	716498	18083K	PARTICIPANT	\N	PRESENT	0
717108	716498	20034V	PARTICIPANT	\N	PRESENT	0
721509	720098	14281W	PARTICIPANT	\N	PRESENT	0
721510	720098	11043H	PARTICIPANT	\N	PRESENT	0
721511	720098	20026V	PARTICIPANT	\N	PRESENT	0
721512	720098	20032T	PARTICIPANT	\N	PRESENT	0
721513	720098	19741B	PARTICIPANT	\N	PRESENT	0
721514	720098	20152B	PARTICIPANT	\N	PRESENT	0
721515	720098	19421M	PARTICIPANT	\N	PRESENT	0
721516	720098	19525U	PARTICIPANT	\N	PRESENT	0
721517	720098	19683J	PARTICIPANT	\N	PRESENT	0
721519	720098	17229F	PARTICIPANT	\N	PRESENT	0
721520	720098	20090E	PARTICIPANT	\N	PRESENT	0
721521	720098	19479G	PARTICIPANT	\N	PRESENT	0
721522	720098	19747H	PARTICIPANT	\N	PRESENT	0
721523	720098	07033P	PARTICIPANT	\N	PRESENT	0
721524	720098	19671E	PARTICIPANT	\N	PRESENT	0
721525	720098	14053L	PARTICIPANT	\N	PRESENT	0
721526	720098	95041E	PARTICIPANT	\N	PRESENT	0
721527	720098	19701S	PARTICIPANT	\N	PRESENT	0
721528	720098	14073Q	PARTICIPANT	\N	PRESENT	0
721532	720098	19333N	PARTICIPANT	\N	PRESENT	0
721533	720098	14089Y	PARTICIPANT	\N	PRESENT	0
721534	720098	19691J	PARTICIPANT	\N	PRESENT	0
721536	720098	20132W	PARTICIPANT	\N	PRESENT	0
721538	720098	20036X	PARTICIPANT	\N	PRESENT	0
721540	720098	20104S	PARTICIPANT	\N	PRESENT	0
721541	720098	20024T	PARTICIPANT	\N	PRESENT	0
721542	720098	20028X	PARTICIPANT	\N	PRESENT	0
721543	720098	08069G	PARTICIPANT	\N	PRESENT	0
721544	720098	14215L	PARTICIPANT	\N	PRESENT	0
721545	720098	20022R	PARTICIPANT	\N	PRESENT	0
721546	720098	19581D	PARTICIPANT	\N	PRESENT	0
721547	720098	19651A	PARTICIPANT	\N	PRESENT	0
721548	720098	11033F	PARTICIPANT	\N	PRESENT	0
721549	720098	14111D	PARTICIPANT	\N	PRESENT	0
721550	720098	19681G	PARTICIPANT	\N	PRESENT	0
721551	720098	19413M	PARTICIPANT	\N	PRESENT	0
721552	720098	20094J	PARTICIPANT	\N	PRESENT	0
721553	720098	19866P	PARTICIPANT	\N	PRESENT	0
721554	720098	14207L	PARTICIPANT	\N	PRESENT	0
721555	720098	11066Q	PARTICIPANT	\N	PRESENT	0
721556	720098	08060W	PARTICIPANT	\N	PRESENT	0
721557	720098	19782L	PARTICIPANT	\N	PRESENT	0
721558	720098	19649G	PARTICIPANT	\N	PRESENT	0
721559	720098	19599P	PARTICIPANT	\N	PRESENT	0
721560	720098	01062T	PARTICIPANT	\N	PRESENT	0
721561	720098	17637T	PARTICIPANT	\N	PRESENT	0
721562	720098	14249W	PARTICIPANT	\N	PRESENT	0
721563	720098	19329S	PARTICIPANT	\N	PRESENT	0
721564	720098	20128B	PARTICIPANT	\N	PRESENT	0
721565	720098	19591F	PARTICIPANT	\N	PRESENT	0
721566	720098	19703U	PARTICIPANT	\N	PRESENT	0
721567	720098	20016T	PARTICIPANT	\N	PRESENT	0
721568	720098	04008A	PARTICIPANT	\N	PRESENT	0
721569	720098	14037X	PARTICIPANT	\N	PRESENT	0
721570	720098	19637C	PARTICIPANT	\N	PRESENT	0
721571	720098	19697Q	PARTICIPANT	\N	PRESENT	0
721572	720098	08061X	PARTICIPANT	\N	PRESENT	0
721573	720098	20146D	PARTICIPANT	\N	PRESENT	0
721574	720098	19349W	PARTICIPANT	\N	PRESENT	0
721575	720098	04035D	PARTICIPANT	\N	PRESENT	0
721576	720098	01060R	PARTICIPANT	\N	PRESENT	0
721577	720098	19575F	PARTICIPANT	\N	PRESENT	0
721578	720098	01058X	PARTICIPANT	\N	PRESENT	0
721579	720098	99004R	PARTICIPANT	\N	PRESENT	0
721580	720098	08010L	PARTICIPANT	\N	PRESENT	0
721581	720098	04047H	PARTICIPANT	\N	PRESENT	0
721582	720098	20134Y	PARTICIPANT	\N	PRESENT	0
721583	720098	11099A	PARTICIPANT	\N	PRESENT	0
721584	720098	20142Y	PARTICIPANT	\N	PRESENT	0
721585	720098	14026U	PARTICIPANT	\N	PRESENT	0
721586	720098	20092G	PARTICIPANT	\N	PRESENT	0
721587	720098	19347U	PARTICIPANT	\N	PRESENT	0
721588	720098	08034U	PARTICIPANT	\N	PRESENT	0
721589	720098	19760E	PARTICIPANT	\N	PRESENT	0
721590	720098	14133K	PARTICIPANT	\N	PRESENT	0
721591	720098	19515S	PARTICIPANT	\N	PRESENT	0
721592	720098	19679N	PARTICIPANT	\N	PRESENT	0
721593	720098	04092N	PARTICIPANT	\N	PRESENT	0
721594	720098	11048N	PARTICIPANT	\N	PRESENT	0
721595	720098	04085P	PARTICIPANT	\N	PRESENT	0
721596	720098	14123H	PARTICIPANT	\N	PRESENT	0
721597	720098	20112S	PARTICIPANT	\N	PRESENT	0
721598	720098	19758L	PARTICIPANT	\N	PRESENT	0
721599	720098	11031D	PARTICIPANT	\N	PRESENT	0
721600	720098	11056N	PARTICIPANT	\N	PRESENT	0
721601	720098	19695N	PARTICIPANT	\N	PRESENT	0
721602	720098	20078J	PARTICIPANT	\N	PRESENT	0
721603	720098	20102Q	PARTICIPANT	\N	PRESENT	0
721604	720098	18083K	PARTICIPANT	\N	PRESENT	0
721605	720098	20046A	PARTICIPANT	\N	PRESENT	0
721606	720098	20074E	PARTICIPANT	\N	PRESENT	0
721607	720098	19719D	PARTICIPANT	\N	PRESENT	0
721608	720098	19387D	PARTICIPANT	\N	PRESENT	0
721609	720098	17367Q	PARTICIPANT	\N	PRESENT	0
721610	720098	20914V	PARTICIPANT	\N	PRESENT	0
721611	720098	11065P	PARTICIPANT	\N	PRESENT	0
721612	720098	19643A	PARTICIPANT	\N	PRESENT	0
721613	720098	98022P	PARTICIPANT	\N	PRESENT	0
721614	720098	14223L	PARTICIPANT	\N	PRESENT	0
721615	720098	20072C	PARTICIPANT	\N	PRESENT	0
721616	720098	11012A	PARTICIPANT	\N	PRESENT	0
721617	720098	04033B	PARTICIPANT	\N	PRESENT	0
721618	720098	14187A	PARTICIPANT	\N	PRESENT	0
721619	720098	19545Y	PARTICIPANT	\N	PRESENT	0
721626	720098	19415P	PARTICIPANT	\N	PRESENT	0
721621	720098	17589D	PARTICIPANT	\N	PRESENT	0
721622	720098	14071N	PARTICIPANT	\N	PRESENT	0
721623	720098	05008E	PARTICIPANT	\N	PRESENT	0
721624	720098	14211G	PARTICIPANT	\N	PRESENT	0
721625	720098	11097X	PARTICIPANT	\N	PRESENT	0
721627	720098	11064N	PARTICIPANT	\N	PRESENT	0
721628	720098	14221J	PARTICIPANT	\N	PRESENT	0
721629	720098	04057K	PARTICIPANT	\N	PRESENT	0
721630	720098	14069U	PARTICIPANT	\N	PRESENT	0
721631	720098	19563B	PARTICIPANT	\N	PRESENT	0
721632	720098	04043D	PARTICIPANT	\N	PRESENT	0
721633	720098	20050V	PARTICIPANT	\N	PRESENT	0
721634	720098	19585H	PARTICIPANT	\N	PRESENT	0
721635	720098	11090Q	PARTICIPANT	\N	PRESENT	0
721636	720098	19631V	PARTICIPANT	\N	PRESENT	0
721637	720098	05012A	PARTICIPANT	\N	PRESENT	0
721638	720098	04059M	PARTICIPANT	\N	PRESENT	0
721639	720098	19549D	PARTICIPANT	\N	PRESENT	0
721640	720098	20114U	PARTICIPANT	\N	PRESENT	0
721641	720098	01057W	PARTICIPANT	\N	PRESENT	0
721642	720098	20110Q	PARTICIPANT	\N	PRESENT	0
721643	720098	19766L	PARTICIPANT	\N	PRESENT	0
721644	720098	20060X	PARTICIPANT	\N	PRESENT	0
721645	720098	11080N	PARTICIPANT	\N	PRESENT	0
721646	720098	10015M	PARTICIPANT	\N	PRESENT	0
721647	720098	20038A	PARTICIPANT	\N	PRESENT	0
721648	720098	20070A	PARTICIPANT	\N	PRESENT	0
721649	720098	20264J	PARTICIPANT	\N	PRESENT	0
721650	720098	19673G	PARTICIPANT	\N	PRESENT	0
721651	720098	19251M	PARTICIPANT	\N	PRESENT	0
721652	720098	11010L	PARTICIPANT	\N	PRESENT	0
721653	720098	14151M	PARTICIPANT	\N	PRESENT	0
721654	720098	19667J	PARTICIPANT	\N	PRESENT	0
721655	720098	11074Q	PARTICIPANT	\N	PRESENT	0
721656	720098	20136B	PARTICIPANT	\N	PRESENT	0
721657	720098	19647E	PARTICIPANT	\N	PRESENT	0
721658	720098	08045X	PARTICIPANT	\N	PRESENT	0
721659	720098	14253S	PARTICIPANT	\N	PRESENT	0
721660	720098	19820Y	PARTICIPANT	\N	PRESENT	0
721661	720098	19725B	PARTICIPANT	\N	PRESENT	0
721662	720098	17737W	PARTICIPANT	\N	PRESENT	0
721663	720098	19533U	PARTICIPANT	\N	PRESENT	0
721664	720098	20118Y	PARTICIPANT	\N	PRESENT	0
721665	720098	19687N	PARTICIPANT	\N	PRESENT	0
721666	720098	12041X	PARTICIPANT	\N	PRESENT	0
721667	720098	10006L	PARTICIPANT	\N	PRESENT	0
721668	720098	19798U	PARTICIPANT	\N	PRESENT	0
721669	720098	20130U	PARTICIPANT	\N	PRESENT	0
721670	720098	14237S	PARTICIPANT	\N	PRESENT	0
721671	720098	14147R	PARTICIPANT	\N	PRESENT	0
721672	720098	14257W	PARTICIPANT	\N	PRESENT	0
721673	720098	20030R	PARTICIPANT	\N	PRESENT	0
721674	720098	17965H	PARTICIPANT	\N	PRESENT	0
721675	720098	19503N	PARTICIPANT	\N	PRESENT	0
721676	720098	20120S	PARTICIPANT	\N	PRESENT	0
721677	720098	19715Y	PARTICIPANT	\N	PRESENT	0
715691	712592	14251Q	PARTICIPANT	\N	PRESENT	0
715692	712592	20040T	PARTICIPANT	\N	PRESENT	0
715693	712592	19826F	PARTICIPANT	\N	PRESENT	0
715694	712592	20094J	PARTICIPANT	\N	PRESENT	0
715695	712592	20980G	PARTICIPANT	\N	PRESENT	0
715696	712592	19647E	PARTICIPANT	\N	PRESENT	0
715697	712592	19719D	PARTICIPANT	\N	PRESENT	0
715698	712592	04033B	PARTICIPANT	\N	PRESENT	0
715699	712592	19643A	PARTICIPANT	\N	PRESENT	0
715700	712592	07033P	PARTICIPANT	\N	PRESENT	0
715701	712592	04071H	PARTICIPANT	\N	PRESENT	0
715702	712592	20098N	PARTICIPANT	\N	PRESENT	0
715704	712592	19713W	PARTICIPANT	\N	PRESENT	0
715705	712592	19741B	PARTICIPANT	\N	PRESENT	0
715706	712592	04042C	PARTICIPANT	\N	PRESENT	0
715707	712592	19329S	PARTICIPANT	\N	PRESENT	0
715708	712592	20136B	PARTICIPANT	\N	PRESENT	0
715709	712592	17589D	PARTICIPANT	\N	PRESENT	0
715710	712592	14217N	PARTICIPANT	\N	PRESENT	0
715711	712592	14069U	PARTICIPANT	\N	PRESENT	0
715712	712592	20082E	PARTICIPANT	\N	PRESENT	0
715713	712592	14121F	PARTICIPANT	\N	PRESENT	0
715714	712592	14173T	PARTICIPANT	\N	PRESENT	0
715728	712592	11077T	PARTICIPANT	\N	PRESENT	0
715730	712592	19057M	PARTICIPANT	\N	PRESENT	0
715891	712593	95063L	PARTICIPANT	\N	PRESENT	0
715897	712593	19583F	PARTICIPANT	\N	PRESENT	0
715898	712593	20034V	PARTICIPANT	\N	PRESENT	0
715899	712593	20092G	PARTICIPANT	\N	PRESENT	0
715900	712593	19527W	PARTICIPANT	\N	PRESENT	0
715901	712593	20082E	PARTICIPANT	\N	PRESENT	0
715902	712593	14121F	PARTICIPANT	\N	PRESENT	0
715903	712593	14111D	PARTICIPANT	\N	PRESENT	0
715904	712593	17589D	PARTICIPANT	\N	PRESENT	0
716072	712594	20034V	PARTICIPANT	\N	PRESENT	0
715906	712593	19711U	PARTICIPANT	\N	PRESENT	0
715907	712593	14187A	PARTICIPANT	\N	PRESENT	0
715908	712593	20298U	PARTICIPANT	\N	PRESENT	0
715909	712593	20136B	PARTICIPANT	\N	PRESENT	0
715910	712593	18083K	PARTICIPANT	\N	PRESENT	0
715911	712593	19467C	PARTICIPANT	\N	PRESENT	0
715912	712593	19701S	PARTICIPANT	\N	PRESENT	0
715913	712593	19631V	PARTICIPANT	\N	PRESENT	0
715914	712593	20030R	PARTICIPANT	\N	PRESENT	0
715915	712593	11031D	PARTICIPANT	\N	PRESENT	0
715916	712593	11056N	PARTICIPANT	\N	PRESENT	0
715917	712593	19695N	PARTICIPANT	\N	PRESENT	0
715918	712593	14205J	PARTICIPANT	\N	PRESENT	0
715919	712593	11012A	PARTICIPANT	\N	PRESENT	0
715920	712593	19581D	PARTICIPANT	\N	PRESENT	0
715921	712593	19747H	PARTICIPANT	\N	PRESENT	0
715922	712593	19782L	PARTICIPANT	\N	PRESENT	0
715925	712593	19585H	PARTICIPANT	\N	PRESENT	0
716070	712594	19693L	PARTICIPANT	\N	PRESENT	0
716071	712594	10006L	PARTICIPANT	\N	PRESENT	0
716073	712594	20098N	PARTICIPANT	\N	PRESENT	0
716074	712594	19715Y	PARTICIPANT	\N	PRESENT	0
716075	712594	11097X	PARTICIPANT	\N	PRESENT	0
716076	712594	20142Y	PARTICIPANT	\N	PRESENT	0
716077	712594	19629C	PARTICIPANT	\N	PRESENT	0
716078	712594	14037X	PARTICIPANT	\N	PRESENT	0
716079	712594	14251Q	PARTICIPANT	\N	PRESENT	0
716080	712594	14259Y	PARTICIPANT	\N	PRESENT	0
716081	712594	19301E	PARTICIPANT	\N	PRESENT	0
716114	712595	19683J	PARTICIPANT	\N	PRESENT	0
716115	712595	18193Q	PARTICIPANT	\N	PRESENT	0
716116	712595	17589D	PARTICIPANT	\N	PRESENT	0
716117	712595	14213J	PARTICIPANT	\N	PRESENT	0
716118	712595	19585H	PARTICIPANT	\N	PRESENT	0
716119	712595	14195A	PARTICIPANT	\N	PRESENT	0
716120	712595	19553Y	PARTICIPANT	\N	PRESENT	0
716121	712595	14237S	PARTICIPANT	\N	PRESENT	0
716122	712595	19301E	PARTICIPANT	\N	PRESENT	0
716123	712595	20032T	PARTICIPANT	\N	PRESENT	0
716124	712595	01057W	PARTICIPANT	\N	PRESENT	0
716125	712595	20062A	PARTICIPANT	\N	PRESENT	0
716126	712595	11031D	PARTICIPANT	\N	PRESENT	0
716127	712595	11067R	PARTICIPANT	\N	PRESENT	0
716128	712595	14071N	PARTICIPANT	\N	PRESENT	0
716129	712595	20142Y	PARTICIPANT	\N	PRESENT	0
716130	712595	20052X	PARTICIPANT	\N	PRESENT	0
716131	712595	19715Y	PARTICIPANT	\N	PRESENT	0
716132	712595	97011G	PARTICIPANT	\N	PRESENT	0
716133	712595	20022R	PARTICIPANT	\N	PRESENT	0
716134	712595	19467C	PARTICIPANT	\N	PRESENT	0
716135	712595	19713W	PARTICIPANT	\N	PRESENT	0
716136	712595	19693L	PARTICIPANT	\N	PRESENT	0
716137	712595	19573D	PARTICIPANT	\N	PRESENT	0
716139	712595	19583F	PARTICIPANT	\N	PRESENT	0
716140	712595	14251Q	PARTICIPANT	\N	PRESENT	0
716141	712595	14111D	PARTICIPANT	\N	PRESENT	0
716142	712595	14191V	PARTICIPANT	\N	PRESENT	0
716143	712595	99004R	PARTICIPANT	\N	PRESENT	0
716144	712595	14259Y	PARTICIPANT	\N	PRESENT	0
716112	712595	14026U	PARTICIPANT	\N	PRESENT	0
716113	712595	19629C	PARTICIPANT	\N	PRESENT	0
716145	712595	20034V	PARTICIPANT	\N	PRESENT	0
716146	712595	04057K	PARTICIPANT	\N	PRESENT	0
716147	712595	19447X	PARTICIPANT	\N	PRESENT	0
716148	716138	14215L	PARTICIPANT	\N	PRESENT	0
716155	712595	14033T	PARTICIPANT	\N	PRESENT	0
716158	716157	14215L	PARTICIPANT	\N	PRESENT	0
716159	716157	20114U	PARTICIPANT	\N	PRESENT	0
716162	712595	19798U	PARTICIPANT	\N	PRESENT	0
716163	712595	11048N	PARTICIPANT	\N	PRESENT	0
716164	712595	19563B	PARTICIPANT	\N	PRESENT	0
716204	712596	19629C	PARTICIPANT	\N	PRESENT	0
716233	712596	14219Q	PARTICIPANT	\N	PRESENT	0
716206	712596	04057K	PARTICIPANT	\N	PRESENT	0
716207	712596	17589D	PARTICIPANT	\N	PRESENT	0
716208	712596	19583F	PARTICIPANT	\N	PRESENT	0
716209	712596	19585H	PARTICIPANT	\N	PRESENT	0
716210	712596	14251Q	PARTICIPANT	\N	PRESENT	0
716211	712596	14195A	PARTICIPANT	\N	PRESENT	0
716212	712596	14191V	PARTICIPANT	\N	PRESENT	0
716213	712596	14111D	PARTICIPANT	\N	PRESENT	0
716214	712596	19301E	PARTICIPANT	\N	PRESENT	0
716215	712596	01028R	PARTICIPANT	\N	PRESENT	0
716216	712596	11056N	PARTICIPANT	\N	PRESENT	0
716217	712596	14189C	PARTICIPANT	\N	PRESENT	0
716218	712596	14259Y	PARTICIPANT	\N	PRESENT	0
716219	712596	19563B	PARTICIPANT	\N	PRESENT	0
716220	712596	20914V	PARTICIPANT	\N	PRESENT	0
716221	712596	19399H	PARTICIPANT	\N	PRESENT	0
716230	712596	20062A	PARTICIPANT	\N	PRESENT	0
716231	712596	19713W	PARTICIPANT	\N	PRESENT	0
716232	712596	20980G	PARTICIPANT	\N	PRESENT	0
716234	712596	04085P	PARTICIPANT	\N	PRESENT	0
716235	712596	20032T	PARTICIPANT	\N	PRESENT	0
716236	712596	19447X	PARTICIPANT	\N	PRESENT	0
716237	712596	04047H	PARTICIPANT	\N	PRESENT	0
716238	712596	19643A	PARTICIPANT	\N	PRESENT	0
716239	712596	20044X	PARTICIPANT	\N	PRESENT	0
716240	712596	20030R	PARTICIPANT	\N	PRESENT	0
716241	712596	11012A	PARTICIPANT	\N	PRESENT	0
716242	712596	20098N	PARTICIPANT	\N	PRESENT	0
716243	712596	20132W	PARTICIPANT	\N	PRESENT	0
716244	712596	19631V	PARTICIPANT	\N	PRESENT	0
716245	712596	19503N	PARTICIPANT	\N	PRESENT	0
716246	712596	20152B	PARTICIPANT	\N	PRESENT	0
716247	712596	20086J	PARTICIPANT	\N	PRESENT	0
716248	712596	19749K	PARTICIPANT	\N	PRESENT	0
716249	712596	14033T	PARTICIPANT	\N	PRESENT	0
716202	712596	14026U	PARTICIPANT	\N	PRESENT	0
716203	712596	14107H	PARTICIPANT	\N	PRESENT	0
716250	712596	19693L	PARTICIPANT	\N	PRESENT	0
716251	712596	14083S	PARTICIPANT	\N	PRESENT	0
716252	712596	14109K	PARTICIPANT	\N	PRESENT	0
716253	712596	14069U	PARTICIPANT	\N	PRESENT	0
716254	712596	20052X	PARTICIPANT	\N	PRESENT	0
716255	712596	14213J	PARTICIPANT	\N	PRESENT	0
716256	712596	19593H	PARTICIPANT	\N	PRESENT	0
716258	712596	20058E	PARTICIPANT	\N	PRESENT	0
716259	712596	14179A	PARTICIPANT	\N	PRESENT	0
716260	712596	19711U	PARTICIPANT	\N	PRESENT	0
716265	712596	19611R	PARTICIPANT	\N	PRESENT	0
716266	712596	20082E	PARTICIPANT	\N	PRESENT	0
716267	712596	20180F	PARTICIPANT	\N	PRESENT	0
716268	712596	14215L	PARTICIPANT	\N	PRESENT	0
716269	712596	08010L	PARTICIPANT	\N	PRESENT	0
716284	712596	01058X	PARTICIPANT	\N	PRESENT	0
735266	735265	04047H	PARTICIPANT	\N	PRESENT	0
735267	735265	11056N	PARTICIPANT	\N	PRESENT	0
735271	735270	05008E	PARTICIPANT	\N	PRESENT	0
736594	736593	14327T	PARTICIPANT	\N	PRESENT	0
736595	736593	14331P	PARTICIPANT	\N	PRESENT	0
736596	736593	11048N	PARTICIPANT	\N	PRESENT	0
736597	736593	19479G	PARTICIPANT	\N	PRESENT	0
736598	736593	19687N	PARTICIPANT	\N	PRESENT	0
736599	736593	20080C	PARTICIPANT	\N	PRESENT	0
736600	736593	11074Q	PARTICIPANT	\N	PRESENT	0
736601	736593	19671E	PARTICIPANT	\N	PRESENT	0
736602	736593	14225N	PRESIDENT	0	PRESENT	0
736603	736593	20070A	PARTICIPANT	\N	PRESENT	0
736604	736593	14121F	PARTICIPANT	\N	PRESENT	0
736605	736593	20914V	PARTICIPANT	\N	PRESENT	0
736606	736593	20116W	PARTICIPANT	\N	PRESENT	0
736609	736593	19647E	PARTICIPANT	\N	PRESENT	0
736610	736593	07029T	PARTICIPANT	\N	PRESENT	0
736611	736593	19531S	PARTICIPANT	\N	PRESENT	0
736612	736593	01057W	PARTICIPANT	\N	PRESENT	0
736613	736593	20126Y	PARTICIPANT	\N	PRESENT	0
736614	736593	19349W	PARTICIPANT	\N	PRESENT	0
736615	734147	20056C	PARTICIPANT	\N	PRESENT	0
736616	734147	11104D	PARTICIPANT	\N	PRESENT	0
736617	736593	19741B	PARTICIPANT	\N	PRESENT	0
736618	736593	19762G	PARTICIPANT	\N	PRESENT	0
736619	736593	11053K	PARTICIPANT	\N	PRESENT	0
736620	734147	04070G	PARTICIPANT	\N	PRESENT	0
736621	734147	19699S	PARTICIPANT	\N	PRESENT	0
736622	734147	19533U	PARTICIPANT	\N	PRESENT	0
736623	734147	14229S	PARTICIPANT	\N	PRESENT	0
736624	734147	19573D	PARTICIPANT	\N	PRESENT	0
736625	734147	20112S	PARTICIPANT	\N	PRESENT	0
736626	734147	08012N	PARTICIPANT	\N	PRESENT	0
736627	734147	20124W	PARTICIPANT	\N	PRESENT	0
736628	734147	19593H	PARTICIPANT	\N	PRESENT	0
736629	734147	19643A	PARTICIPANT	\N	PRESENT	0
736630	734147	20132W	PARTICIPANT	\N	PRESENT	0
736631	734147	14073Q	PARTICIPANT	\N	PRESENT	0
736632	734147	19611R	PRESIDENT	0	PRESENT	0
736633	734147	20142Y	PARTICIPANT	\N	PRESENT	0
736634	734147	20052X	PARTICIPANT	\N	PRESENT	0
736635	734147	20172F	PARTICIPANT	\N	PRESENT	0
736636	734147	20058E	PARTICIPANT	\N	PRESENT	0
736637	734147	14030Q	PARTICIPANT	\N	PRESENT	0
736638	734147	20180F	PARTICIPANT	\N	PRESENT	0
736639	734147	20264J	PARTICIPANT	\N	PRESENT	0
736640	734147	14109K	PARTICIPANT	\N	PRESENT	0
736641	734147	14123H	PARTICIPANT	\N	PRESENT	0
736642	734147	11043H	PARTICIPANT	\N	PRESENT	0
736643	734147	19758L	PARTICIPANT	\N	PRESENT	0
736644	734147	20084G	PARTICIPANT	\N	PRESENT	0
736645	734147	19621T	PARTICIPANT	\N	PRESENT	0
736646	734147	19735D	PARTICIPANT	\N	EXCUSE	0
736647	734147	11109J	PARTICIPANT	\N	EXCUSE	0
736648	735293	14053L	PARTICIPANT	\N	PRESENT	0
736649	735293	19954N	PARTICIPANT	\N	PRESENT	0
736650	735293	11056N	PARTICIPANT	\N	PRESENT	0
736651	735293	19629C	PARTICIPANT	\N	PRESENT	0
736652	735293	20074E	PARTICIPANT	\N	PRESENT	0
736653	735293	14069U	PARTICIPANT	\N	PRESENT	0
736654	735293	14215L	PARTICIPANT	\N	PRESENT	0
736655	735293	19581D	PARTICIPANT	\N	PRESENT	0
736656	735293	19673G	PARTICIPANT	\N	PRESENT	0
736657	735293	14111D	PARTICIPANT	\N	PRESENT	0
736658	735293	19649G	PARTICIPANT	\N	PRESENT	0
736659	735293	10015M	PARTICIPANT	\N	PRESENT	0
736660	735293	19725B	PARTICIPANT	\N	PRESENT	0
736661	735293	14107H	PARTICIPANT	\N	PRESENT	0
736662	735293	20110Q	PARTICIPANT	\N	PRESENT	0
736663	735293	14147R	PARTICIPANT	\N	PRESENT	0
736664	735293	14151M	PARTICIPANT	\N	PRESENT	0
736665	735293	04008A	PARTICIPANT	\N	PRESENT	0
736666	735293	19749K	PARTICIPANT	\N	PRESENT	0
736667	735293	14001X	PARTICIPANT	\N	PRESENT	0
736668	735293	04047H	PRESIDENT	0	PRESENT	0
736669	735293	19447X	PARTICIPANT	\N	PRESENT	0
736670	735293	14275Y	PARTICIPANT	\N	PRESENT	0
736671	735293	20108W	PARTICIPANT	\N	PRESENT	0
736672	735293	20022R	PARTICIPANT	\N	PRESENT	0
736673	735293	14089Y	PARTICIPANT	\N	PRESENT	0
736675	735293	19585H	PARTICIPANT	\N	PRESENT	0
736676	735293	07004J	PARTICIPANT	\N	PRESENT	0
736677	735293	11026G	PARTICIPANT	\N	PRESENT	0
736678	735293	95063L	PARTICIPANT	\N	PRESENT	0
736681	735293	01028R	PARTICIPANT	\N	PRESENT	0
736682	735293	14231L	PARTICIPANT	\N	PRESENT	0
736683	735293	14259Y	PARTICIPANT	\N	PRESENT	0
736684	735293	04085P	PARTICIPANT	\N	PRESENT	0
736686	736593	14189C	PARTICIPANT	\N	PRESENT	0
736687	736593	14083S	PARTICIPANT	\N	PRESENT	0
736688	735293	19489J	PARTICIPANT	\N	PRESENT	0
736689	735293	05008E	PARTICIPANT	\N	PRESENT	0
736801	736800	14215L	PARTICIPANT	\N	PRESENT	0
736802	736800	20114U	PARTICIPANT	\N	PRESENT	0
736809	736808	14215L	PARTICIPANT	\N	PRESENT	0
736906	735510	19333N	PARTICIPANT	\N	PRESENT	0
736907	735510	20088L	PARTICIPANT	\N	PRESENT	0
736908	735510	20090E	PARTICIPANT	\N	PRESENT	0
736909	735510	19549D	PARTICIPANT	\N	PRESENT	0
736910	735510	20076G	PARTICIPANT	\N	PRESENT	0
736911	735510	19387D	PARTICIPANT	\N	PRESENT	0
736912	735510	14219Q	PRESIDENT	0	PRESENT	0
736913	735510	19820Y	PARTICIPANT	\N	PRESENT	0
736914	735510	19826F	PARTICIPANT	\N	PRESENT	0
736915	735510	14221J	PARTICIPANT	\N	PRESENT	0
736916	735510	20102Q	PARTICIPANT	\N	PRESENT	0
736917	735510	18083K	PARTICIPANT	\N	PRESENT	0
736918	735510	20100N	PARTICIPANT	\N	PRESENT	0
736919	735510	05012A	PARTICIPANT	\N	PRESENT	0
736920	735510	20106U	PARTICIPANT	\N	PRESENT	0
736921	735510	20118Y	PARTICIPANT	\N	PRESENT	0
736922	735510	19503N	PARTICIPANT	\N	PRESENT	0
736923	735510	17367Q	PARTICIPANT	\N	PRESENT	0
736924	735510	19681G	PARTICIPANT	\N	PRESENT	0
736925	735510	20024T	PARTICIPANT	\N	PRESENT	0
736926	735510	20032T	PARTICIPANT	\N	PRESENT	0
736927	735510	14059S	PARTICIPANT	\N	PRESENT	0
736928	735510	14031R	PARTICIPANT	\N	PRESENT	0
736929	735510	20038A	PARTICIPANT	\N	PRESENT	0
736930	735510	20046A	PARTICIPANT	\N	PRESENT	0
736931	735510	17229F	PARTICIPANT	\N	PRESENT	0
736932	735510	20068G	PARTICIPANT	\N	PRESENT	0
736933	735510	11101A	PARTICIPANT	\N	PRESENT	0
736934	735510	19739H	PARTICIPANT	\N	PRESENT	0
736935	735510	19745F	PARTICIPANT	\N	PRESENT	0
736936	735510	14237S	PARTICIPANT	\N	EXCUSE	0
736937	735510	19701S	PARTICIPANT	\N	EXCUSE	0
736938	735510	20136B	PARTICIPANT	\N	EXCUSE	0
736939	735510	19251M	PARTICIPANT	\N	EXCUSE	0
736940	735510	20120S	PARTICIPANT	\N	EXCUSE	0
736990	736989	11066Q	PARTICIPANT	\N	PRESENT	0
737086	735539	20132W	PARTICIPANT	\N	PRESENT	0
737087	735539	20092G	PARTICIPANT	\N	PRESENT	0
737089	735539	20266L	PARTICIPANT	\N	PRESENT	0
737090	735539	14097Y	PARTICIPANT	\N	PRESENT	0
737091	735539	08045X	PARTICIPANT	\N	PRESENT	0
737092	735539	14151M	PARTICIPANT	\N	PRESENT	0
737093	735539	20134Y	PARTICIPANT	\N	PRESENT	0
737094	735539	20264J	PARTICIPANT	\N	PRESENT	0
737095	735539	14121F	PARTICIPANT	\N	PRESENT	0
737096	735539	11031D	PARTICIPANT	\N	PRESENT	0
737097	735539	19760E	PARTICIPANT	\N	PRESENT	0
737098	735539	04008A	PARTICIPANT	\N	PRESENT	0
737099	735539	19693L	PARTICIPANT	\N	PRESENT	0
737101	735539	19575F	PARTICIPANT	\N	PRESENT	0
737102	735539	08010L	PARTICIPANT	\N	PRESENT	0
737103	735539	20130U	PARTICIPANT	\N	PRESENT	0
737104	735539	01058X	PARTICIPANT	\N	PRESENT	0
737105	735539	04047H	PARTICIPANT	\N	PRESENT	0
737106	735539	14038Y	PARTICIPANT	\N	PRESENT	0
737107	735539	11083R	PARTICIPANT	\N	PRESENT	0
737108	735539	19447X	PARTICIPANT	\N	PRESENT	0
737109	735539	20098N	PARTICIPANT	\N	PRESENT	0
737110	735539	20106U	PARTICIPANT	\N	PRESENT	0
737114	735539	14355X	PARTICIPANT	\N	PRESENT	0
737112	735539	20056C	PARTICIPANT	\N	PRESENT	0
737113	735539	19591F	PARTICIPANT	\N	PRESENT	0
737115	735539	14037X	PARTICIPANT	\N	PRESENT	0
714348	714306	20074E	PARTICIPANT	\N	PRESENT	0
714349	714306	19749K	PARTICIPANT	\N	PRESENT	0
714435	714433	11090Q	PARTICIPANT	\N	PRESENT	0
714440	714433	14097Y	PARTICIPANT	\N	PRESENT	0
714441	714433	19711U	PARTICIPANT	\N	PRESENT	0
714445	714433	14331P	PARTICIPANT	\N	PRESENT	0
714446	714433	14225N	PARTICIPANT	\N	PRESENT	0
715216	713477	20118Y	PARTICIPANT	\N	EXCUSE	0
715217	713477	19798U	PARTICIPANT	\N	EXCUSE	0
715364	715363	11066Q	PARTICIPANT	\N	PRESENT	0
716288	716286	14357A	PARTICIPANT	\N	PRESENT	0
716292	716290	14357A	PARTICIPANT	\N	PRESENT	0
716294	716293	14357A	PARTICIPANT	\N	PRESENT	0
716296	716295	14357A	PARTICIPANT	\N	PRESENT	0
716298	716297	14357A	PARTICIPANT	\N	PRESENT	0
716303	716302	14357A	PARTICIPANT	\N	PRESENT	0
716307	716306	14357A	PARTICIPANT	\N	PRESENT	0
717109	716498	14038Y	PARTICIPANT	\N	PRESENT	0
717157	716498	14071N	PARTICIPANT	\N	PRESENT	0
717111	716498	20144B	PARTICIPANT	\N	PRESENT	0
717112	716498	20058E	PARTICIPANT	\N	PRESENT	0
717113	716498	11072N	PARTICIPANT	\N	PRESENT	0
717114	716498	20102Q	PARTICIPANT	\N	PRESENT	0
717162	716498	18193Q	PARTICIPANT	\N	PRESENT	0
717116	716498	11043H	PARTICIPANT	\N	PRESENT	0
717117	716498	20180F	PARTICIPANT	\N	PRESENT	0
717118	716498	19782L	PARTICIPANT	\N	PRESENT	0
717155	716498	19649G	PARTICIPANT	\N	PRESENT	0
717120	716498	11099A	PARTICIPANT	\N	PRESENT	0
717121	716498	20054A	PARTICIPANT	\N	PRESENT	0
717122	716498	19745F	PARTICIPANT	\N	PRESENT	0
717123	716498	14275Y	PARTICIPANT	\N	PRESENT	0
717124	716498	19679N	PARTICIPANT	\N	PRESENT	0
717125	716498	19581D	PARTICIPANT	\N	PRESENT	0
717126	716498	19599P	PARTICIPANT	\N	PRESENT	0
717153	716498	14042U	PARTICIPANT	\N	PRESENT	0
717128	716498	01025N	PARTICIPANT	\N	PRESENT	0
717150	716498	11101A	PARTICIPANT	\N	PRESENT	0
717151	716498	11053K	PARTICIPANT	\N	PRESENT	0
717131	716498	19507S	PARTICIPANT	\N	PRESENT	0
717154	716498	19467C	PARTICIPANT	\N	PRESENT	0
717152	716498	19479G	PARTICIPANT	\N	PRESENT	0
717134	716498	14147R	PARTICIPANT	\N	PRESENT	0
717156	716498	98022P	PARTICIPANT	\N	PRESENT	0
717136	716498	19699S	PARTICIPANT	\N	PRESENT	0
717158	716498	20022R	PARTICIPANT	\N	PRESENT	0
717159	716498	14030Q	PARTICIPANT	\N	PRESENT	0
717139	716498	14111D	PARTICIPANT	\N	PRESENT	0
717160	716498	14215L	PARTICIPANT	\N	PRESENT	0
717141	716498	20128B	PARTICIPANT	\N	PRESENT	0
717142	716498	11056N	PARTICIPANT	\N	PRESENT	0
717143	716498	19725B	PARTICIPANT	\N	PRESENT	0
717144	716498	14173T	PARTICIPANT	\N	PRESENT	0
717145	716498	14069U	PARTICIPANT	\N	PRESENT	0
717146	716498	14357A	PARTICIPANT	\N	PRESENT	0
717161	716498	04047H	PARTICIPANT	\N	PRESENT	0
717148	716498	11031D	PARTICIPANT	\N	PRESENT	0
717149	716498	19760E	PARTICIPANT	\N	PRESENT	0
717163	716498	11045K	PARTICIPANT	\N	PRESENT	0
717164	716498	19693L	PARTICIPANT	\N	PRESENT	0
717165	716498	14231L	PARTICIPANT	\N	PRESENT	0
717166	716498	01024M	PARTICIPANT	\N	PRESENT	0
717168	716498	20072C	PARTICIPANT	\N	PRESENT	0
717169	716498	14207L	PARTICIPANT	\N	PRESENT	0
717170	716498	14249W	PARTICIPANT	\N	PRESENT	0
717171	716498	19447X	PARTICIPANT	\N	PRESENT	0
717172	716498	14031R	PARTICIPANT	\N	PRESENT	0
717173	716498	14109K	PARTICIPANT	\N	PRESENT	0
717174	716498	19369B	PARTICIPANT	\N	PRESENT	0
717175	716498	20042V	PARTICIPANT	\N	PRESENT	0
717176	716498	12028B	PARTICIPANT	\N	PRESENT	0
717177	716498	19749K	PARTICIPANT	\N	PRESENT	0
717178	716498	17965H	PARTICIPANT	\N	PRESENT	0
717179	716498	19713W	PARTICIPANT	\N	PRESENT	0
717180	716498	19399H	PARTICIPANT	\N	PRESENT	0
717181	716498	14151M	PARTICIPANT	\N	PRESENT	0
717182	716498	04042C	PARTICIPANT	\N	PRESENT	0
717183	716498	19798U	PARTICIPANT	\N	PRESENT	0
717184	716498	11067R	PARTICIPANT	\N	PRESENT	0
717185	716498	20980G	PARTICIPANT	\N	PRESENT	0
717186	716498	19367Y	PARTICIPANT	\N	PRESENT	0
717187	716498	01043Q	PARTICIPANT	\N	PRESENT	0
717188	716498	19691J	PARTICIPANT	\N	PRESENT	0
717189	716498	20038A	PARTICIPANT	\N	PRESENT	0
717190	716498	14133K	PARTICIPANT	\N	PRESENT	0
717191	716498	19611R	PARTICIPANT	\N	PRESENT	0
717195	716498	20056C	PARTICIPANT	\N	PRESENT	0
717197	716498	20026V	PARTICIPANT	\N	PRESENT	0
717200	716498	14193X	PARTICIPANT	\N	PRESENT	0
717201	716498	20024T	PARTICIPANT	\N	PRESENT	0
717208	716498	17023S	PARTICIPANT	\N	PRESENT	0
717209	716498	20052X	PARTICIPANT	\N	PRESENT	0
717210	716498	04057K	PARTICIPANT	\N	PRESENT	0
717211	716498	20266L	PARTICIPANT	\N	PRESENT	0
717212	716498	20142Y	PARTICIPANT	\N	PRESENT	0
717213	716498	20104S	PARTICIPANT	\N	PRESENT	0
717214	716498	19703U	PARTICIPANT	\N	PRESENT	0
717215	716498	20078J	PARTICIPANT	\N	PRESENT	0
717216	716498	19673G	PARTICIPANT	\N	PRESENT	0
717217	716498	04033B	PARTICIPANT	\N	PRESENT	0
717218	716498	20040T	PARTICIPANT	\N	PRESENT	0
717219	716498	14205J	PARTICIPANT	\N	PRESENT	0
717220	716498	19687N	PARTICIPANT	\N	PRESENT	0
717221	716498	20090E	PARTICIPANT	\N	PRESENT	0
717222	716498	11012A	PARTICIPANT	\N	PRESENT	0
717223	716498	20132W	PARTICIPANT	\N	PRESENT	0
717224	716498	20076G	PARTICIPANT	\N	PRESENT	0
717225	716498	20048C	PARTICIPANT	\N	PRESENT	0
717226	716498	20118Y	PARTICIPANT	\N	PRESENT	0
717227	716498	19349W	PARTICIPANT	\N	PRESENT	0
717228	716498	20086J	PARTICIPANT	\N	PRESENT	0
717229	716498	04070G	PARTICIPANT	\N	PRESENT	0
717230	716498	14257W	PARTICIPANT	\N	PRESENT	0
717231	716498	20030R	PARTICIPANT	\N	PRESENT	0
717241	716498	14213J	PARTICIPANT	\N	PRESENT	0
717242	716498	20092G	PARTICIPANT	\N	PRESENT	0
717247	716498	19758L	PARTICIPANT	\N	PRESENT	0
717248	716498	14021P	PARTICIPANT	\N	PRESENT	0
717249	716498	14195A	PARTICIPANT	\N	PRESENT	0
717250	716498	20100N	PARTICIPANT	\N	PRESENT	0
717295	716499	95063L	PARTICIPANT	\N	PRESENT	0
717296	716499	14219Q	PARTICIPANT	\N	PRESENT	0
717297	716499	20142Y	PARTICIPANT	\N	PRESENT	0
717298	716499	20100N	PARTICIPANT	\N	PRESENT	0
717299	716499	20092G	PARTICIPANT	\N	PRESENT	0
717300	716499	19503N	PARTICIPANT	\N	PRESENT	0
717301	716499	20022R	PARTICIPANT	\N	PRESENT	0
717302	716499	20102Q	PARTICIPANT	\N	PRESENT	0
717303	716499	11043H	PARTICIPANT	\N	PRESENT	0
717304	716499	19701S	PARTICIPANT	\N	PRESENT	0
717305	716499	20076G	PARTICIPANT	\N	PRESENT	0
717306	716499	14031R	PARTICIPANT	\N	PRESENT	0
717307	716499	19699S	PARTICIPANT	\N	PRESENT	0
717308	716499	14147R	PARTICIPANT	\N	PRESENT	0
717309	716499	19447X	PARTICIPANT	\N	PRESENT	0
717310	716499	19467C	PARTICIPANT	\N	PRESENT	0
717311	716499	14215L	PARTICIPANT	\N	PRESENT	0
717312	716499	14195A	PARTICIPANT	\N	PRESENT	0
717313	716499	19747H	PARTICIPANT	\N	PRESENT	0
717314	716499	17229F	PARTICIPANT	\N	PRESENT	0
717315	716499	19629C	PARTICIPANT	\N	PRESENT	0
717316	716499	19693L	PARTICIPANT	\N	PRESENT	0
717317	716499	20030R	PARTICIPANT	\N	PRESENT	0
717318	716499	14033T	PARTICIPANT	\N	PRESENT	0
721678	720098	14121F	PARTICIPANT	\N	PRESENT	0
721679	720098	14217N	PARTICIPANT	\N	PRESENT	0
721680	720098	14097Y	PARTICIPANT	\N	PRESENT	0
721681	720098	14021P	PARTICIPANT	\N	PRESENT	0
721682	720098	19489J	PARTICIPANT	\N	PRESENT	0
721683	720098	20172F	PARTICIPANT	\N	PRESENT	0
721684	720098	20138D	PARTICIPANT	\N	PRESENT	0
721685	720098	18193Q	PARTICIPANT	\N	PRESENT	0
721686	720098	08012N	PARTICIPANT	\N	PRESENT	0
721687	720098	08047A	PARTICIPANT	\N	PRESENT	0
721688	720098	20140W	PARTICIPANT	\N	PRESENT	0
721689	720098	20056C	PARTICIPANT	\N	PRESENT	0
721690	720098	20096L	PARTICIPANT	\N	PRESENT	0
721691	720098	20180F	PARTICIPANT	\N	PRESENT	0
721692	720098	14001X	PARTICIPANT	\N	PRESENT	0
721693	720098	20980G	PARTICIPANT	\N	PRESENT	0
721694	720098	11067R	PARTICIPANT	\N	PRESENT	0
721695	720098	20018V	PARTICIPANT	\N	PRESENT	0
721696	720098	19573D	PARTICIPANT	\N	PRESENT	0
721697	720098	19447X	PARTICIPANT	\N	PRESENT	0
721698	720098	17779H	PARTICIPANT	\N	PRESENT	0
721699	720098	14173T	PARTICIPANT	\N	PRESENT	0
721700	720098	14225N	PARTICIPANT	\N	PRESENT	0
721701	720098	20082E	PARTICIPANT	\N	PRESENT	0
721702	720098	14038Y	PARTICIPANT	\N	PRESENT	0
721703	720098	14229S	PARTICIPANT	\N	PRESENT	0
721704	720098	19723Y	PARTICIPANT	\N	PRESENT	0
721705	720098	11045K	PARTICIPANT	\N	PRESENT	0
721706	720098	19467C	PARTICIPANT	\N	PRESENT	0
721707	720098	20098N	PARTICIPANT	\N	PRESENT	0
721708	720098	14033T	PARTICIPANT	\N	PRESENT	0
721709	720098	12016W	PARTICIPANT	\N	PRESENT	0
721710	720098	01028R	PARTICIPANT	\N	PRESENT	0
721711	720098	19399H	PARTICIPANT	\N	PRESENT	0
721712	720098	20108W	PARTICIPANT	\N	PRESENT	0
721713	720098	12028B	PARTICIPANT	\N	PRESENT	0
721714	720098	20148F	PARTICIPANT	\N	PRESENT	0
721715	720098	14357A	PARTICIPANT	\N	PRESENT	0
721716	720098	14213J	PARTICIPANT	\N	PRESENT	0
721717	720098	19699S	PARTICIPANT	\N	PRESENT	0
721718	720098	14329V	PARTICIPANT	\N	PRESENT	0
721719	720098	20052X	PARTICIPANT	\N	PRESENT	0
721720	720098	19383Y	PARTICIPANT	\N	PRESENT	0
721721	720098	20042V	PARTICIPANT	\N	PRESENT	0
721722	720098	19762G	PARTICIPANT	\N	PRESENT	0
721723	720098	19749K	PARTICIPANT	\N	PRESENT	0
721724	720098	19713W	PARTICIPANT	\N	PRESENT	0
721725	720098	14042U	PARTICIPANT	\N	PRESENT	0
721726	720098	14219Q	PARTICIPANT	\N	PRESENT	0
721727	720098	20124W	PARTICIPANT	\N	PRESENT	0
721728	720098	08056B	PARTICIPANT	\N	PRESENT	0
721729	720098	14059S	PARTICIPANT	\N	PRESENT	0
721730	720098	14169X	PARTICIPANT	\N	PRESENT	0
721731	720098	19739H	PARTICIPANT	\N	PRESENT	0
721732	720098	20062A	PARTICIPANT	\N	PRESENT	0
721733	720098	19369B	PARTICIPANT	\N	PRESENT	0
721734	720098	16685X	PARTICIPANT	\N	PRESENT	0
721735	720098	19707Y	PARTICIPANT	\N	PRESENT	0
721736	720098	14205J	PARTICIPANT	\N	PRESENT	0
721737	720098	19705W	PARTICIPANT	\N	PRESENT	0
721738	720098	19768N	PARTICIPANT	\N	PRESENT	0
721739	720098	14189C	PARTICIPANT	\N	PRESENT	0
721740	720098	08015R	PARTICIPANT	\N	PRESENT	0
721741	720098	19729F	PARTICIPANT	\N	PRESENT	0
721742	720098	19657G	PARTICIPANT	\N	PRESENT	0
721743	720098	07029T	PARTICIPANT	\N	PRESENT	0
721744	720098	14030Q	PARTICIPANT	\N	PRESENT	0
721745	720098	08018U	PARTICIPANT	\N	PRESENT	0
721746	720098	11053K	PARTICIPANT	\N	PRESENT	0
721747	720098	19663E	PARTICIPANT	\N	PRESENT	0
721748	720098	20058E	PARTICIPANT	\N	PRESENT	0
721749	720098	11070L	PARTICIPANT	\N	PRESENT	0
721750	720098	14327T	PARTICIPANT	\N	PRESENT	0
721751	720098	01024M	PARTICIPANT	\N	PRESENT	0
721752	720098	20040T	PARTICIPANT	\N	PRESENT	0
721753	720098	20248J	PARTICIPANT	\N	PRESENT	0
721786	720098	20054A	PARTICIPANT	\N	PRESENT	0
721755	720098	01025N	PARTICIPANT	\N	PRESENT	0
721756	720098	14231L	PARTICIPANT	\N	PRESENT	0
721757	720098	19611R	PARTICIPANT	\N	PRESENT	0
721758	720098	01043Q	PARTICIPANT	\N	PRESENT	0
721759	720098	19735D	PARTICIPANT	\N	PRESENT	0
721760	720098	20066E	PARTICIPANT	\N	PRESENT	0
721761	720098	19685L	PARTICIPANT	\N	PRESENT	0
721762	720098	20286Q	PARTICIPANT	\N	PRESENT	0
721763	720098	20020P	PARTICIPANT	\N	PRESENT	0
722365	705811	19798U	PARTICIPANT	\N	PRESENT	0
721765	720098	11085T	PARTICIPANT	\N	PRESENT	0
721766	720098	19826F	PARTICIPANT	\N	PRESENT	0
721767	720098	08009T	PARTICIPANT	\N	PRESENT	0
721768	720098	19335Q	PARTICIPANT	\N	PRESENT	0
721769	720098	04070G	PARTICIPANT	\N	PRESENT	0
721770	720098	19745F	PARTICIPANT	\N	PRESENT	0
721771	720098	19619A	PARTICIPANT	\N	PRESENT	0
721772	720098	20144B	PARTICIPANT	\N	PRESENT	0
721773	720098	19441R	PARTICIPANT	\N	PRESENT	0
721774	720098	20266L	PARTICIPANT	\N	PRESENT	0
721775	720098	11072N	PARTICIPANT	\N	PRESENT	0
721776	720098	04071H	PARTICIPANT	\N	PRESENT	0
721777	720098	11041F	PARTICIPANT	\N	PRESENT	0
721778	720098	20048C	PARTICIPANT	\N	PRESENT	0
721779	720098	14055N	PARTICIPANT	\N	PRESENT	0
721780	720098	14083S	PARTICIPANT	\N	PRESENT	0
721781	720098	20116W	PARTICIPANT	\N	PRESENT	0
721782	720098	19659J	PARTICIPANT	\N	PRESENT	0
721784	720098	20080C	PARTICIPANT	\N	PRESENT	0
721785	720098	19693L	PARTICIPANT	\N	PRESENT	0
721787	720098	20126Y	PARTICIPANT	\N	PRESENT	0
721789	720098	19569H	PARTICIPANT	\N	PRESENT	0
721795	720098	14109K	PARTICIPANT	\N	PRESENT	0
722366	705811	14030Q	PRESIDENT	0	PRESENT	0
722367	705811	20066E	PARTICIPANT	\N	PRESENT	0
722369	705811	11045K	PARTICIPANT	\N	PRESENT	0
722415	705811	07029T	PARTICIPANT	\N	EXCUSE	0
722457	720154	19820Y	PARTICIPANT	\N	PRESENT	0
722458	720154	20104S	PRESIDENT	0	PRESENT	0
722459	720154	20094J	PARTICIPANT	\N	PRESENT	0
722469	720154	19745F	PARTICIPANT	\N	EXCUSE	0
722470	720154	05012A	PARTICIPANT	\N	EXCUSE	0
722474	722473	19593H	PARTICIPANT	\N	PRESENT	1
722475	722473	14123H	PARTICIPANT	\N	PRESENT	1
722536	722535	20118Y	PARTICIPANT	\N	PRESENT	0
722537	722535	11048N	PARTICIPANT	\N	PRESENT	0
722538	722535	19575F	PARTICIPANT	\N	PRESENT	0
722539	722535	20096L	PARTICIPANT	\N	PRESENT	0
722540	722535	14059S	PARTICIPANT	\N	PRESENT	0
722541	722535	04057K	PARTICIPANT	\N	PRESENT	0
722542	722535	20022R	PARTICIPANT	\N	PRESENT	0
722669	720143	19691J	PARTICIPANT	\N	PRESENT	0
722675	722674	19335Q	PARTICIPANT	\N	PRESENT	0
722676	722674	20106U	PARTICIPANT	\N	PRESENT	1
722777	722776	20180F	PARTICIPANT	\N	PRESENT	1
722778	722776	20124W	PARTICIPANT	\N	PRESENT	1
722779	722776	19593H	PARTICIPANT	\N	PRESENT	1
722780	722775	20180F	PARTICIPANT	\N	PRESENT	1
722781	722775	20124W	PARTICIPANT	\N	PRESENT	1
722782	722775	19593H	PARTICIPANT	\N	PRESENT	1
722785	722783	19697Q	PARTICIPANT	\N	PRESENT	1
722786	722783	20130U	PARTICIPANT	\N	PRESENT	0
722787	722784	19697Q	PARTICIPANT	\N	PRESENT	1
722788	722784	17965H	PARTICIPANT	\N	PRESENT	1
722789	722784	20130U	PARTICIPANT	\N	PRESENT	0
723576	722793	95041E	PARTICIPANT	\N	PRESENT	0
723574	722793	18083K	PARTICIPANT	\N	PRESENT	0
723575	722793	04033B	PARTICIPANT	\N	PRESENT	0
723577	722793	11043H	PARTICIPANT	\N	PRESENT	0
723578	722793	07029T	PARTICIPANT	\N	PRESENT	0
723585	722685	19760E	PARTICIPANT	\N	PRESENT	0
723586	722685	20130U	PARTICIPANT	\N	PRESENT	0
723587	722685	19683J	PARTICIPANT	\N	PRESENT	0
723588	722685	18193Q	PARTICIPANT	\N	PRESENT	0
723589	722685	11045K	PARTICIPANT	\N	PRESENT	0
723590	722685	14195A	PARTICIPANT	\N	PRESENT	0
723591	722685	10006L	PRESIDENT	0	PRESENT	0
723592	720141	19745F	PARTICIPANT	\N	PRESENT	0
723593	722685	19723Y	PARTICIPANT	\N	PRESENT	0
723594	722685	14281W	PARTICIPANT	\N	PRESENT	0
723595	722685	19691J	PARTICIPANT	\N	PRESENT	0
723596	722685	19569H	PARTICIPANT	\N	PRESENT	0
723597	722685	14042U	PARTICIPANT	\N	PRESENT	0
716289	712596	20142Y	PARTICIPANT	\N	PRESENT	0
716299	712596	20136B	PARTICIPANT	\N	PRESENT	0
716300	712596	14037X	PARTICIPANT	\N	PRESENT	0
716301	712596	11110B	PARTICIPANT	\N	PRESENT	0
716304	712596	20034V	PARTICIPANT	\N	PRESENT	0
716308	712597	14026U	PARTICIPANT	\N	PRESENT	0
716309	712597	14107H	PARTICIPANT	\N	PRESENT	0
716354	712597	19651A	PARTICIPANT	\N	PRESENT	0
716311	712597	14251Q	PARTICIPANT	\N	PRESENT	0
716312	712597	14195A	PARTICIPANT	\N	PRESENT	0
716355	712597	14111D	PARTICIPANT	\N	PRESENT	0
716356	712597	11056N	PARTICIPANT	\N	PRESENT	0
716357	712597	20080C	PARTICIPANT	\N	PRESENT	0
716358	712597	19629C	PARTICIPANT	\N	PRESENT	0
716359	712597	11065P	PARTICIPANT	\N	PRESENT	0
716318	712597	14189C	PARTICIPANT	\N	PRESENT	0
716360	712597	11110B	PARTICIPANT	\N	PRESENT	0
716320	712597	20914V	PARTICIPANT	\N	PRESENT	0
716321	712597	20062A	PARTICIPANT	\N	PRESENT	0
716285	712596	19621T	PARTICIPANT	\N	PRESENT	0
716287	712596	14229S	PARTICIPANT	\N	PRESENT	0
716371	712597	20120S	PARTICIPANT	\N	PRESENT	0
716323	712597	20980G	PARTICIPANT	\N	PRESENT	0
716372	712597	20034V	PARTICIPANT	\N	PRESENT	0
716325	712597	19447X	PARTICIPANT	\N	PRESENT	0
716375	712597	19741B	PARTICIPANT	\N	PRESENT	0
716376	712597	11090Q	PARTICIPANT	\N	PRESENT	0
716328	712597	20030R	PARTICIPANT	\N	PRESENT	0
716329	712597	11012A	PARTICIPANT	\N	PRESENT	0
716330	712597	20132W	PARTICIPANT	\N	PRESENT	0
716377	712597	20298U	PARTICIPANT	\N	PRESENT	0
716332	712597	19503N	PARTICIPANT	\N	PRESENT	0
716333	712597	20152B	PARTICIPANT	\N	PRESENT	0
716334	712597	20086J	PARTICIPANT	\N	PRESENT	0
716335	712597	19693L	PARTICIPANT	\N	PRESENT	0
716336	712597	14083S	PARTICIPANT	\N	PRESENT	0
716337	712597	14069U	PARTICIPANT	\N	PRESENT	0
716338	712597	20052X	PARTICIPANT	\N	PRESENT	0
716339	712597	19593H	PARTICIPANT	\N	PRESENT	0
716340	712597	20058E	PARTICIPANT	\N	PRESENT	0
716378	712597	01043Q	PARTICIPANT	\N	PRESENT	0
716342	712597	19711U	PARTICIPANT	\N	PRESENT	0
716343	712597	19611R	PARTICIPANT	\N	PRESENT	0
716344	712597	20082E	PARTICIPANT	\N	PRESENT	0
716345	712597	20180F	PARTICIPANT	\N	PRESENT	0
716379	712597	20032T	PARTICIPANT	\N	PRESENT	0
716380	712597	20044X	PARTICIPANT	\N	PRESENT	0
716348	712597	19621T	PARTICIPANT	\N	PRESENT	0
716349	712597	14229S	PARTICIPANT	\N	PRESENT	0
716350	712597	20142Y	PARTICIPANT	\N	PRESENT	0
716381	713870	14026U	PARTICIPANT	\N	PRESENT	0
716382	713870	14107H	PARTICIPANT	\N	PRESENT	0
716383	713870	14251Q	PARTICIPANT	\N	PRESENT	0
716384	713870	14195A	PARTICIPANT	\N	PRESENT	0
716385	713870	14189C	PARTICIPANT	\N	PRESENT	0
716386	713870	20062A	PARTICIPANT	\N	PRESENT	0
716419	713870	14215L	PARTICIPANT	\N	PRESENT	0
716388	713870	19447X	PARTICIPANT	\N	PRESENT	0
716389	713870	11012A	PARTICIPANT	\N	PRESENT	0
716418	713870	19503N	PARTICIPANT	\N	PRESENT	0
716391	713870	20086J	PARTICIPANT	\N	PRESENT	0
716392	713870	19693L	PARTICIPANT	\N	PRESENT	0
716393	713870	20052X	PARTICIPANT	\N	PRESENT	0
716420	713870	04047H	PARTICIPANT	\N	PRESENT	0
716395	713870	20058E	PARTICIPANT	\N	PRESENT	0
716421	713870	20132W	PARTICIPANT	\N	PRESENT	0
716397	713870	20082E	PARTICIPANT	\N	PRESENT	0
716398	713870	20180F	PARTICIPANT	\N	PRESENT	0
716423	713870	20030R	PARTICIPANT	\N	PRESENT	0
716446	713870	19631V	PARTICIPANT	\N	PRESENT	0
716415	713870	11090Q	PARTICIPANT	\N	PRESENT	0
716416	713870	20136B	PARTICIPANT	\N	PRESENT	0
716403	713870	11056N	PARTICIPANT	\N	PRESENT	0
716404	713870	20080C	PARTICIPANT	\N	PRESENT	0
716405	713870	19629C	PARTICIPANT	\N	PRESENT	0
716406	713870	11065P	PARTICIPANT	\N	PRESENT	0
716407	713870	20120S	PARTICIPANT	\N	PRESENT	0
716408	713870	20034V	PARTICIPANT	\N	PRESENT	0
716409	713870	19741B	PARTICIPANT	\N	PRESENT	0
716410	713870	20298U	PARTICIPANT	\N	PRESENT	0
716417	713870	01043Q	PARTICIPANT	\N	PRESENT	0
716412	713870	20032T	PARTICIPANT	\N	PRESENT	0
716413	713870	20044X	PARTICIPANT	\N	PRESENT	0
716414	713870	14219Q	PARTICIPANT	\N	PRESENT	0
716447	713870	14229S	PARTICIPANT	\N	PRESENT	0
716448	713870	19525U	PARTICIPANT	\N	PRESENT	0
716450	713870	07004J	PARTICIPANT	\N	PRESENT	0
716451	713870	14059S	PARTICIPANT	\N	PRESENT	0
716452	713870	19711U	PARTICIPANT	\N	PRESENT	0
716453	713870	19747H	PARTICIPANT	\N	PRESENT	0
716454	713870	11077T	PARTICIPANT	\N	PRESENT	0
716455	716449	14026U	PARTICIPANT	\N	PRESENT	0
716456	716449	14107H	PARTICIPANT	\N	PRESENT	0
716457	716449	14251Q	PARTICIPANT	\N	PRESENT	0
716458	716449	14195A	PARTICIPANT	\N	PRESENT	0
716459	716449	14189C	PARTICIPANT	\N	PRESENT	0
716460	716449	19447X	PARTICIPANT	\N	PRESENT	0
716461	716449	11012A	PARTICIPANT	\N	PRESENT	0
716462	716449	20086J	PARTICIPANT	\N	PRESENT	0
716463	716449	19693L	PARTICIPANT	\N	PRESENT	0
716464	716449	20052X	PARTICIPANT	\N	PRESENT	0
716465	716449	20082E	PARTICIPANT	\N	PRESENT	0
716466	716449	19629C	PARTICIPANT	\N	PRESENT	0
716467	716449	11065P	PARTICIPANT	\N	PRESENT	0
716468	716449	20120S	PARTICIPANT	\N	PRESENT	0
716469	716449	20298U	PARTICIPANT	\N	PRESENT	0
716470	716449	20032T	PARTICIPANT	\N	PRESENT	0
716471	716449	20044X	PARTICIPANT	\N	PRESENT	0
716472	716449	14219Q	PARTICIPANT	\N	PRESENT	0
716473	716449	11090Q	PARTICIPANT	\N	PRESENT	0
716474	716449	01043Q	PARTICIPANT	\N	PRESENT	0
716475	716449	19503N	PARTICIPANT	\N	PRESENT	0
716476	716449	04047H	PARTICIPANT	\N	PRESENT	0
716477	716449	20132W	PARTICIPANT	\N	PRESENT	0
716478	716449	19631V	PARTICIPANT	\N	PRESENT	0
716479	716449	14229S	PARTICIPANT	\N	PRESENT	0
716480	716449	19525U	PARTICIPANT	\N	PRESENT	0
716481	716449	07004J	PARTICIPANT	\N	PRESENT	0
716482	716449	14059S	PARTICIPANT	\N	PRESENT	0
716483	716449	19711U	PARTICIPANT	\N	PRESENT	0
716484	716449	19747H	PARTICIPANT	\N	PRESENT	0
716485	716449	11077T	PARTICIPANT	\N	PRESENT	0
716486	716449	20060X	PARTICIPANT	\N	PRESENT	0
716487	716449	20030R	PARTICIPANT	\N	PRESENT	0
716488	716449	14215L	PARTICIPANT	\N	PRESENT	0
716489	716449	19621T	PARTICIPANT	\N	PRESENT	0
716490	716449	20180F	PARTICIPANT	\N	PRESENT	0
716491	716449	20034V	PARTICIPANT	\N	PRESENT	0
716492	716449	20062A	PARTICIPANT	\N	PRESENT	0
716493	716449	11056N	PARTICIPANT	\N	PRESENT	0
716495	716449	14069U	PARTICIPANT	\N	PRESENT	0
718642	718540	04070G	PARTICIPANT	\N	EXCUSE	0
716507	716449	01058X	PARTICIPANT	\N	PRESENT	0
716508	716449	20058E	PARTICIPANT	\N	PRESENT	0
716509	716449	20136B	PARTICIPANT	\N	PRESENT	0
716510	716449	19741B	PARTICIPANT	\N	PRESENT	0
718637	718540	19399H	PARTICIPANT	\N	EXCUSE	0
718654	718540	19954N	PARTICIPANT	\N	EXCUSE	0
719867	718622	20146D	PARTICIPANT	\N	PRESENT	0
719868	718622	20082E	PARTICIPANT	\N	PRESENT	0
721430	720146	19820Y	PARTICIPANT	\N	PRESENT	0
721431	720146	14205J	PARTICIPANT	\N	PRESENT	0
721432	720146	20914V	PARTICIPANT	\N	PRESENT	0
721433	720146	20070A	PARTICIPANT	\N	PRESENT	0
721434	720146	19768N	PARTICIPANT	\N	PRESENT	0
721435	720146	20128B	PARTICIPANT	\N	PRESENT	0
721436	720146	20094J	PARTICIPANT	\N	PRESENT	0
721445	720146	05012A	PARTICIPANT	\N	PRESENT	0
722961	722955	19569H	PARTICIPANT	\N	PRESENT	1
722962	722955	18193Q	PARTICIPANT	\N	PRESENT	0
725698	725697	14026U	PARTICIPANT	\N	PRESENT	0
725699	725697	19725B	PARTICIPANT	\N	PRESENT	0
725713	722791	14147R	PARTICIPANT	\N	PRESENT	0
725787	725786	19415P	PARTICIPANT	\N	PRESENT	0
725958	725957	20050V	PARTICIPANT	\N	PRESENT	0
725961	725959	11053K	PARTICIPANT	\N	PRESENT	0
726799	726447	19667J	PARTICIPANT	\N	PRESENT	0
726802	726447	99004R	PARTICIPANT	\N	PRESENT	0
726803	726447	11070L	PARTICIPANT	\N	PRESENT	0
727421	727420	19820Y	PARTICIPANT	\N	PRESENT	0
727545	725808	04045F	PARTICIPANT	\N	EXCUSE	0
737342	737341	19820Y	PARTICIPANT	\N	PRESENT	0
737343	737341	20128B	PARTICIPANT	\N	PRESENT	0
737344	737341	14205J	PARTICIPANT	\N	PRESENT	0
737345	737341	05012A	PARTICIPANT	\N	PRESENT	0
737668	734153	10015M	PARTICIPANT	\N	PRESENT	0
737669	735542	14215L	PARTICIPANT	\N	PRESENT	0
737670	735542	19629C	PARTICIPANT	\N	PRESENT	0
737671	735542	14259Y	PARTICIPANT	\N	PRESENT	0
737672	735542	14073Q	PARTICIPANT	\N	PRESENT	0
737673	735542	19657G	PARTICIPANT	\N	PRESENT	0
737674	734153	14069U	PARTICIPANT	\N	PRESENT	0
737675	734153	14257W	PARTICIPANT	\N	PRESENT	0
737676	735542	20102Q	PARTICIPANT	\N	PRESENT	0
737677	735542	18083K	PARTICIPANT	\N	PRESENT	0
737678	735542	19507S	PARTICIPANT	\N	PRESENT	0
737679	735542	20024T	PARTICIPANT	\N	PRESENT	0
737680	734153	14231L	PARTICIPANT	\N	PRESENT	0
737681	735542	19701S	PARTICIPANT	\N	PRESENT	0
737682	735542	20054A	PARTICIPANT	\N	PRESENT	0
737683	735542	19762G	PARTICIPANT	\N	PRESENT	0
737684	735542	14038Y	PARTICIPANT	\N	PRESENT	0
737685	735422	14133K	PARTICIPANT	\N	PRESENT	0
737686	735422	19565D	PARTICIPANT	\N	PRESENT	0
737687	735422	20072C	PARTICIPANT	\N	PRESENT	0
737688	735422	20042V	PARTICIPANT	\N	PRESENT	0
737689	735422	01058X	PARTICIPANT	\N	PRESENT	0
737690	735422	11027H	PARTICIPANT	\N	PRESENT	0
737691	735422	12028B	PARTICIPANT	\N	PRESENT	0
737692	735422	19421M	PARTICIPANT	\N	PRESENT	0
737693	735422	14267Y	PARTICIPANT	\N	PRESENT	0
737694	735422	11064N	PARTICIPANT	\N	PRESENT	0
737695	735422	07033P	PARTICIPANT	\N	PRESENT	0
737696	735422	97011G	PARTICIPANT	\N	PRESENT	0
737697	735422	08047A	PRESIDENT	0	PRESENT	0
737698	735422	14255U	PARTICIPANT	\N	PRESENT	0
737699	735422	14193X	PARTICIPANT	\N	PRESENT	0
737700	735422	04042C	PRESIDENT	1	PRESENT	0
737701	735422	11066Q	PARTICIPANT	\N	EXCUSE	0
737702	734153	19565D	PARTICIPANT	\N	PRESENT	0
737703	734153	20058E	PARTICIPANT	\N	PRESENT	0
737704	734153	19349W	PARTICIPANT	\N	PRESENT	0
737705	735542	10015M	PARTICIPANT	\N	PRESENT	0
737706	735542	14275Y	PARTICIPANT	\N	PRESENT	0
737707	735422	16685X	PARTICIPANT	\N	PRESENT	0
737708	735422	17023S	PARTICIPANT	\N	PRESENT	0
737709	735422	20128B	PARTICIPANT	\N	PRESENT	0
737711	737710	19820Y	PARTICIPANT	\N	PRESENT	0
737712	737710	20914V	PARTICIPANT	\N	PRESENT	0
737713	737710	19768N	PARTICIPANT	\N	PRESENT	0
737714	734153	20914V	PARTICIPANT	\N	PRESENT	0
737715	735542	07029T	PARTICIPANT	\N	PRESENT	0
737716	734153	01057W	PARTICIPANT	\N	PRESENT	0
737717	734153	14033T	PARTICIPANT	\N	PRESENT	0
737718	735542	20114U	PARTICIPANT	\N	PRESENT	0
737719	735542	14089Y	PARTICIPANT	\N	PRESENT	0
737721	735542	08061X	PARTICIPANT	\N	PRESENT	0
737722	735542	20152B	PARTICIPANT	\N	PRESENT	0
737723	735542	20172F	PARTICIPANT	\N	PRESENT	0
737725	735542	14147R	PARTICIPANT	\N	PRESENT	0
737726	735542	14097Y	PARTICIPANT	\N	PRESENT	0
737727	735542	19467C	PARTICIPANT	\N	PRESENT	0
737728	735542	20098N	PARTICIPANT	\N	PRESENT	0
737729	735542	19717B	PARTICIPANT	\N	PRESENT	0
737732	735542	14033T	PARTICIPANT	\N	PRESENT	0
737733	735542	20034V	PARTICIPANT	\N	PRESENT	0
737761	735543	20034V	PARTICIPANT	\N	PRESENT	0
737762	735543	20098N	PARTICIPANT	\N	PRESENT	0
737763	735543	14033T	PARTICIPANT	\N	PRESENT	0
737764	735543	19467C	PARTICIPANT	\N	PRESENT	0
737774	735543	14069U	PARTICIPANT	\N	PRESENT	0
737766	735543	14097Y	PARTICIPANT	\N	PRESENT	0
737767	735543	19583F	PARTICIPANT	\N	PRESENT	0
737768	735543	14107H	PARTICIPANT	\N	PRESENT	0
737769	735543	11012A	PARTICIPANT	\N	PRESENT	0
737770	735543	14215L	PARTICIPANT	\N	PRESENT	0
737771	735543	19798U	PARTICIPANT	\N	PRESENT	0
737772	735543	14059S	PARTICIPANT	\N	PRESENT	0
737773	735543	20172F	PARTICIPANT	\N	PRESENT	0
737775	735543	19657G	PARTICIPANT	\N	PRESENT	0
737779	735543	20102Q	PARTICIPANT	\N	PRESENT	0
737782	735543	20152B	PARTICIPANT	\N	PRESENT	0
737786	735543	08073C	PARTICIPANT	\N	PRESENT	0
737788	735543	20100N	PARTICIPANT	\N	PRESENT	0
737791	735543	14030Q	PARTICIPANT	\N	PRESENT	0
737792	735543	14275Y	PARTICIPANT	\N	PRESENT	0
737793	735295	14053L	PARTICIPANT	\N	PRESENT	0
737794	735295	19629C	PARTICIPANT	\N	PRESENT	0
737795	735295	14215L	PARTICIPANT	\N	PRESENT	0
737796	735295	19649G	PARTICIPANT	\N	PRESENT	0
737759	735543	99004R	PARTICIPANT	\N	PRESENT	0
737760	735543	19717B	PARTICIPANT	\N	PRESENT	0
737801	735295	20114U	PARTICIPANT	\N	PRESENT	0
737803	737800	14357A	PARTICIPANT	\N	PRESENT	0
737804	737800	11097X	PARTICIPANT	\N	PRESENT	0
737805	737800	11053K	PARTICIPANT	\N	PRESENT	0
737807	737800	19251M	PRESIDENT	0	PRESENT	0
737808	737800	20084G	PARTICIPANT	\N	PRESENT	0
737809	737800	20180F	PARTICIPANT	\N	PRESENT	0
737822	735295	14147R	PARTICIPANT	\N	PRESENT	0
737824	735295	14259Y	PARTICIPANT	\N	PRESENT	0
737825	735295	11064N	PARTICIPANT	\N	PRESENT	0
737826	735295	14231L	PARTICIPANT	\N	PRESENT	0
737827	735295	20022R	PARTICIPANT	\N	PRESENT	0
737828	735295	10015M	PARTICIPANT	\N	PRESENT	0
737829	735295	14069U	PARTICIPANT	\N	PRESENT	0
737830	735295	19489J	PARTICIPANT	\N	PRESENT	0
737831	735422	14059S	PARTICIPANT	\N	PRESENT	0
737832	735295	14001X	PARTICIPANT	\N	PRESENT	0
737833	735295	04047H	PRESIDENT	0	PRESENT	0
737834	735295	14089Y	PARTICIPANT	\N	PRESENT	0
737835	735295	19749K	PARTICIPANT	\N	PRESENT	0
737836	735543	97011G	PARTICIPANT	\N	PRESENT	0
737837	735543	19549D	PARTICIPANT	\N	PRESENT	0
737838	735543	14071N	PARTICIPANT	\N	PRESENT	0
737839	735543	19701S	PARTICIPANT	\N	PRESENT	0
737840	735543	14195A	PARTICIPANT	\N	PRESENT	0
737841	735543	20024T	PARTICIPANT	\N	PRESENT	0
737842	735543	20036X	PARTICIPANT	\N	PRESENT	0
737843	735543	19335Q	PARTICIPANT	\N	PRESENT	0
737846	735543	19619A	PARTICIPANT	\N	PRESENT	0
737847	735543	14217N	PARTICIPANT	\N	PRESENT	0
737848	735543	19565D	PARTICIPANT	\N	PRESENT	0
737849	735543	19599P	PARTICIPANT	\N	PRESENT	0
737850	735543	19575F	PARTICIPANT	\N	PRESENT	0
737851	735545	99004R	PARTICIPANT	\N	PRESENT	0
737872	735545	20180F	PARTICIPANT	\N	PRESENT	0
737873	735545	20072C	PARTICIPANT	\N	PRESENT	0
737874	735545	19701S	PARTICIPANT	\N	PRESENT	0
737855	735545	11012A	PARTICIPANT	\N	PRESENT	0
737875	735545	19349W	PARTICIPANT	\N	PRESENT	0
737876	735545	20098N	PARTICIPANT	\N	PRESENT	0
737858	735545	20102Q	PARTICIPANT	\N	PRESENT	0
737877	735545	20024T	PARTICIPANT	\N	PRESENT	0
737878	735545	19629C	PARTICIPANT	\N	PRESENT	0
737861	735545	19549D	PARTICIPANT	\N	PRESENT	0
737879	735545	19531S	PARTICIPANT	\N	PRESENT	0
737863	735545	14195A	PARTICIPANT	\N	PRESENT	0
737880	735545	18083K	PARTICIPANT	\N	PRESENT	0
737865	735545	20036X	PARTICIPANT	\N	PRESENT	0
737866	735545	19335Q	PARTICIPANT	\N	PRESENT	0
737867	735545	19619A	PARTICIPANT	\N	PRESENT	0
737881	735545	20042V	PARTICIPANT	\N	PRESENT	0
737869	735545	19565D	PARTICIPANT	\N	PRESENT	0
737870	735545	19599P	PARTICIPANT	\N	PRESENT	0
737871	735545	19575F	PARTICIPANT	\N	PRESENT	0
737882	735545	08010L	PARTICIPANT	\N	PRESENT	0
737883	735545	14033T	PARTICIPANT	\N	PRESENT	0
737884	735545	14083S	PARTICIPANT	\N	PRESENT	0
737885	735545	14107H	PARTICIPANT	\N	PRESENT	0
737886	735545	11064N	PARTICIPANT	\N	PRESENT	0
737887	735545	20152B	PARTICIPANT	\N	PRESENT	0
737888	735545	20126Y	PARTICIPANT	\N	PRESENT	0
737889	735545	14097Y	PARTICIPANT	\N	PRESENT	0
737890	735545	20082E	PARTICIPANT	\N	PRESENT	0
737891	737785	19333N	PARTICIPANT	\N	PRESENT	0
737892	737785	19768N	PARTICIPANT	\N	PRESENT	0
737893	737785	14331P	PARTICIPANT	\N	PRESENT	0
737894	737785	19515S	PARTICIPANT	\N	PRESENT	0
737895	737785	19782L	PARTICIPANT	\N	PRESENT	0
737896	737785	01057W	PARTICIPANT	\N	PRESENT	0
737897	737785	19441R	PARTICIPANT	\N	PRESENT	0
717343	716500	01043Q	PARTICIPANT	\N	PRESENT	0
717344	716500	14219Q	PARTICIPANT	\N	PRESENT	0
717345	716500	14031R	PARTICIPANT	\N	PRESENT	0
717346	716500	19701S	PARTICIPANT	\N	PRESENT	0
717347	716500	19693L	PARTICIPANT	\N	PRESENT	0
717348	716500	20132W	PARTICIPANT	\N	PRESENT	0
717349	716500	19333N	PARTICIPANT	\N	PRESENT	0
717350	716500	19503N	PARTICIPANT	\N	PRESENT	0
717351	716500	20102Q	PARTICIPANT	\N	PRESENT	0
717352	716500	20100N	PARTICIPANT	\N	PRESENT	0
717353	716500	08060W	PARTICIPANT	\N	PRESENT	0
717354	716500	19699S	PARTICIPANT	\N	PRESENT	0
717355	716500	14229S	PARTICIPANT	\N	PRESENT	0
717356	716500	14195A	PARTICIPANT	\N	PRESENT	0
717357	716500	19441R	PARTICIPANT	\N	PRESENT	0
717358	716500	19479G	PARTICIPANT	\N	PRESENT	0
717359	716500	20040T	PARTICIPANT	\N	PRESENT	0
717360	716500	17229F	PARTICIPANT	\N	PRESENT	0
717361	716500	19611R	PARTICIPANT	\N	PRESENT	0
717362	716500	20106U	PARTICIPANT	\N	PRESENT	0
717363	716500	20090E	PARTICIPANT	\N	PRESENT	0
717364	716500	14033T	PARTICIPANT	\N	PRESENT	0
717365	716500	14147R	PARTICIPANT	\N	PRESENT	0
717366	716500	20096L	PARTICIPANT	\N	PRESENT	0
717367	716500	19637C	PARTICIPANT	\N	PRESENT	0
717368	716500	19549D	PARTICIPANT	\N	PRESENT	0
717369	716500	19723Y	PARTICIPANT	\N	PRESENT	0
717370	716500	20076G	PARTICIPANT	\N	PRESENT	0
717371	716500	20030R	PARTICIPANT	\N	PRESENT	0
717372	716500	14069U	PARTICIPANT	\N	PRESENT	0
717373	716500	20086J	PARTICIPANT	\N	PRESENT	0
717374	716500	20142Y	PARTICIPANT	\N	PRESENT	0
717375	716500	19349W	PARTICIPANT	\N	PRESENT	0
717376	716500	20120S	PARTICIPANT	\N	PRESENT	0
717377	716500	17367Q	PARTICIPANT	\N	PRESENT	0
717378	716500	20058E	PARTICIPANT	\N	PRESENT	0
717379	716500	20054A	PARTICIPANT	\N	PRESENT	0
717380	716500	20092G	PARTICIPANT	\N	PRESENT	0
717381	716500	19741B	PARTICIPANT	\N	PRESENT	0
717382	716500	19251M	PARTICIPANT	\N	PRESENT	0
717383	716500	19447X	PARTICIPANT	\N	PRESENT	0
717384	716500	19369B	PARTICIPANT	\N	PRESENT	0
717385	716500	20126Y	PARTICIPANT	\N	PRESENT	0
717584	715210	11027H	PARTICIPANT	\N	PRESENT	0
717585	715210	19669L	PARTICIPANT	\N	PRESENT	0
717586	715210	20042V	PARTICIPANT	\N	PRESENT	0
717587	715210	14211G	PARTICIPANT	\N	PRESENT	0
718368	716503	14053L	PARTICIPANT	\N	PRESENT	0
718369	716503	08069G	PARTICIPANT	\N	PRESENT	0
718370	716503	14033T	PARTICIPANT	\N	PRESENT	0
718371	716503	20172F	PARTICIPANT	\N	PRESENT	0
718373	716503	01024M	PARTICIPANT	\N	PRESENT	0
718378	716503	19525U	PARTICIPANT	\N	PRESENT	0
718380	716503	11045K	PARTICIPANT	\N	PRESENT	0
718389	716503	20136B	PARTICIPANT	\N	PRESENT	0
718391	716503	19709B	PARTICIPANT	\N	PRESENT	0
718392	716503	19647E	PARTICIPANT	\N	PRESENT	0
718396	718340	19782L	PARTICIPANT	\N	PRESENT	0
718402	716503	20022R	PARTICIPANT	\N	PRESENT	0
718846	718845	86034E	PARTICIPANT	\N	PRESENT	0
718847	718845	04085P	PARTICIPANT	\N	PRESENT	0
718848	718845	19719D	PARTICIPANT	\N	PRESENT	0
718865	718845	10006L	PARTICIPANT	\N	PRESENT	0
718866	718845	14215L	PARTICIPANT	\N	PRESENT	0
718867	718845	14042U	PARTICIPANT	\N	PRESENT	0
718868	718845	19347U	PARTICIPANT	\N	PRESENT	0
718869	718845	14021P	PARTICIPANT	\N	PRESENT	0
718870	718845	99004R	PARTICIPANT	\N	PRESENT	0
718871	718845	19611R	PARTICIPANT	\N	PRESENT	0
718872	718845	12041X	PARTICIPANT	\N	PRESENT	0
718873	718845	19697Q	PARTICIPANT	\N	PRESENT	0
718874	718845	14251Q	PARTICIPANT	\N	PRESENT	0
718875	718845	11085T	PARTICIPANT	\N	PRESENT	0
718876	718845	11090Q	PARTICIPANT	\N	PRESENT	0
718877	718845	14225N	PARTICIPANT	\N	PRESENT	0
718878	718845	11012A	PARTICIPANT	\N	PRESENT	0
718879	718845	04033B	PARTICIPANT	\N	PRESENT	0
718880	718845	11045K	PARTICIPANT	\N	PRESENT	0
718960	718959	14133K	PARTICIPANT	\N	PRESENT	0
718961	718959	14097Y	PARTICIPANT	\N	PRESENT	0
718962	718959	11066Q	PARTICIPANT	\N	PRESENT	0
718964	718963	11083R	PARTICIPANT	\N	PRESENT	0
719855	718622	20172F	PARTICIPANT	\N	PRESENT	0
719856	718622	11056N	PARTICIPANT	\N	PRESENT	0
719858	718622	19703U	PARTICIPANT	\N	EXCUSE	0
719859	718622	20248J	PARTICIPANT	\N	EXCUSE	0
719866	718622	08073C	PARTICIPANT	\N	PRESENT	0
719978	719929	19533U	PARTICIPANT	\N	PRESENT	1
719979	719930	19593H	PARTICIPANT	\N	PRESENT	0
719980	719933	20058E	PARTICIPANT	\N	PRESENT	1
719981	719933	19758L	PARTICIPANT	\N	PRESENT	1
719995	719994	14257W	PARTICIPANT	\N	PRESENT	0
719996	719994	20018V	PARTICIPANT	\N	PRESENT	0
719997	719994	20092G	PARTICIPANT	\N	PRESENT	0
720000	719998	14257W	PARTICIPANT	\N	PRESENT	0
720001	719998	20018V	PARTICIPANT	\N	PRESENT	0
720002	719998	20092G	PARTICIPANT	\N	PRESENT	0
720004	720003	19695N	PARTICIPANT	\N	PRESENT	0
720005	720003	14187A	PARTICIPANT	\N	PRESENT	0
720006	720003	14257W	PARTICIPANT	\N	PRESENT	0
720007	720003	20018V	PARTICIPANT	\N	PRESENT	0
720008	720003	20092G	PARTICIPANT	\N	PRESENT	0
720009	719994	19695N	PARTICIPANT	\N	PRESENT	0
720010	719994	14187A	PARTICIPANT	\N	PRESENT	0
720011	719998	19695N	PARTICIPANT	\N	PRESENT	0
720012	719998	14187A	PARTICIPANT	\N	PRESENT	0
720065	720064	20090E	PARTICIPANT	\N	PRESENT	0
720066	720064	14213J	PARTICIPANT	\N	PRESENT	0
720128	720126	19399H	PARTICIPANT	\N	PRESENT	0
720068	720064	19569H	PARTICIPANT	\N	PRESENT	0
720069	720064	11067R	PARTICIPANT	\N	PRESENT	0
720070	720064	11097X	PARTICIPANT	\N	PRESENT	0
720127	720126	11043H	PARTICIPANT	\N	PRESENT	0
720129	720126	08012N	PARTICIPANT	\N	PRESENT	0
720133	720132	14267Y	PARTICIPANT	\N	PRESENT	0
720134	720132	11027H	PARTICIPANT	\N	PRESENT	0
720135	720132	19565D	PARTICIPANT	\N	PRESENT	0
720137	720136	14267Y	PARTICIPANT	\N	PRESENT	0
720138	720136	19565D	PARTICIPANT	\N	PRESENT	0
720488	701182	19695N	PARTICIPANT	\N	EXCUSE	0
720774	720743	10006L	PARTICIPANT	\N	PRESENT	0
720775	720743	14026U	PARTICIPANT	\N	PRESENT	0
720776	720743	14213J	PARTICIPANT	\N	PRESENT	0
720777	720743	18193Q	PARTICIPANT	\N	PRESENT	0
720778	720743	14223L	PARTICIPANT	\N	PRESENT	0
720779	720743	19798U	PARTICIPANT	\N	PRESENT	0
720780	720743	14071N	PARTICIPANT	\N	PRESENT	0
720781	720743	11097X	PARTICIPANT	\N	PRESENT	0
720792	701182	19721W	PARTICIPANT	\N	EXCUSE	0
721284	720092	04047H	PRESIDENT	0	PRESENT	0
721285	720092	14021P	PARTICIPANT	\N	PRESENT	0
721286	720092	11033F	PARTICIPANT	\N	PRESENT	0
721287	720092	11056N	PARTICIPANT	\N	PRESENT	0
721288	720092	20114U	PARTICIPANT	\N	PRESENT	0
721289	720092	08018U	PARTICIPANT	\N	PRESENT	0
721290	720092	11072N	PARTICIPANT	\N	PRESENT	0
721291	720092	14107H	PARTICIPANT	\N	PRESENT	0
721292	720092	19629C	PARTICIPANT	\N	PRESENT	0
721293	720092	11026G	PARTICIPANT	\N	PRESENT	0
721294	720092	20108W	PARTICIPANT	\N	PRESENT	0
721295	720092	19729F	PARTICIPANT	\N	PRESENT	0
721296	720092	14089Y	PARTICIPANT	\N	PRESENT	0
721297	720092	14231L	PARTICIPANT	\N	PRESENT	0
721298	720092	14259Y	PARTICIPANT	\N	PRESENT	0
721299	720092	14053L	PARTICIPANT	\N	PRESENT	0
721300	720092	04008A	PARTICIPANT	\N	PRESENT	0
721302	720092	14179A	PARTICIPANT	\N	PRESENT	0
721303	720092	20022R	PARTICIPANT	\N	PRESENT	0
721304	720092	19581D	PARTICIPANT	\N	PRESENT	0
721305	720092	19585H	PARTICIPANT	\N	PRESENT	0
721306	720092	19649G	PARTICIPANT	\N	PRESENT	0
721307	720092	14151M	PARTICIPANT	\N	PRESENT	0
721308	720092	20074E	PARTICIPANT	\N	PRESENT	0
721309	720092	10015M	PARTICIPANT	\N	PRESENT	0
721310	720092	14069U	PARTICIPANT	\N	PRESENT	0
721311	720092	19673G	PARTICIPANT	\N	PRESENT	0
721312	720092	14147R	PARTICIPANT	\N	PRESENT	0
721313	720092	19543W	PARTICIPANT	\N	PRESENT	0
721314	720092	19749K	PARTICIPANT	\N	PRESENT	0
721315	720092	14111D	PARTICIPANT	\N	PRESENT	0
721316	720092	19447X	PARTICIPANT	\N	PRESENT	0
721317	720092	11010L	PARTICIPANT	\N	PRESENT	0
723598	722685	14071N	PARTICIPANT	0	PRESENT	0
723599	722685	19679N	PARTICIPANT	\N	PRESENT	0
723600	722685	19798U	PARTICIPANT	\N	PRESENT	0
723601	722685	19511N	PARTICIPANT	\N	PRESENT	0
723602	722685	19415P	PARTICIPANT	\N	PRESENT	0
723603	722685	11097X	PARTICIPANT	\N	PRESENT	0
723604	722685	14217N	PRESIDENT	1	PRESENT	0
723605	722685	14213J	PARTICIPANT	\N	PRESENT	0
723610	722685	19295A	PARTICIPANT	\N	EXCUSE	0
723607	722685	19703U	PARTICIPANT	\N	PRESENT	0
723608	722685	20148F	PARTICIPANT	\N	PRESENT	0
723609	722685	20248J	PARTICIPANT	\N	PRESENT	0
723611	722685	04043D	PARTICIPANT	\N	PRESENT	0
723612	722685	20090E	PARTICIPANT	\N	PRESENT	0
723613	723232	19479G	PRESIDENT	0	PRESENT	0
723614	723232	01048V	PARTICIPANT	\N	PRESENT	0
723615	723232	14189C	PARTICIPANT	\N	PRESENT	0
723616	723232	19545Y	PARTICIPANT	\N	PRESENT	0
723617	723232	19349W	PARTICIPANT	\N	PRESENT	0
723618	723232	08010L	PARTICIPANT	\N	PRESENT	0
723619	723232	19741B	PARTICIPANT	\N	PRESENT	0
723620	723232	14121F	PARTICIPANT	\N	PRESENT	0
723621	723232	20116W	PARTICIPANT	\N	PRESENT	0
723622	723232	14253S	PARTICIPANT	\N	PRESENT	0
723623	723232	19335Q	PARTICIPANT	\N	PRESENT	0
723624	723232	20070A	PARTICIPANT	\N	PRESENT	0
723625	723232	19687N	PARTICIPANT	\N	PRESENT	0
723626	723232	20086J	PARTICIPANT	\N	PRESENT	0
723627	723232	11048N	PARTICIPANT	\N	PRESENT	0
723628	723232	01057W	PARTICIPANT	\N	PRESENT	0
723629	723232	20044X	PARTICIPANT	\N	PRESENT	0
723630	723232	99004R	PARTICIPANT	\N	PRESENT	0
723632	720141	19333N	PARTICIPANT	\N	PRESENT	0
723633	720141	20068G	PARTICIPANT	\N	PRESENT	0
723634	720141	19549D	PARTICIPANT	\N	PRESENT	0
723635	720141	14219Q	PRESIDENT	0	PRESENT	0
723636	720141	20020P	PARTICIPANT	\N	PRESENT	0
723637	720141	19619A	PARTICIPANT	\N	PRESENT	0
723638	720141	17229F	PARTICIPANT	\N	PRESENT	0
723639	720141	20096L	PARTICIPANT	\N	PRESENT	0
723640	722685	19663E	PARTICIPANT	\N	PRESENT	0
723641	720141	20032T	PARTICIPANT	\N	PRESENT	0
723642	720141	19826F	PARTICIPANT	\N	PRESENT	0
723643	720141	19637C	PARTICIPANT	\N	PRESENT	0
723644	720141	14237S	PARTICIPANT	\N	PRESENT	0
723645	720141	17367Q	PARTICIPANT	\N	PRESENT	0
723646	720141	20120S	PARTICIPANT	\N	PRESENT	0
723647	723232	19667J	PARTICIPANT	\N	PRESENT	0
723648	723232	14083S	PARTICIPANT	\N	PRESENT	0
723649	723232	19671E	PARTICIPANT	\N	PRESENT	0
723650	720141	20140W	PARTICIPANT	\N	PRESENT	0
723651	720141	20100N	PARTICIPANT	\N	PRESENT	0
723652	720141	18083K	PARTICIPANT	\N	PRESENT	0
723653	720141	20024T	PARTICIPANT	\N	PRESENT	0
723670	720141	05012A	PARTICIPANT	\N	PRESENT	0
723655	720141	19701S	PARTICIPANT	\N	PRESENT	0
723656	720141	14031R	PARTICIPANT	\N	PRESENT	0
723657	720141	19251M	PARTICIPANT	\N	PRESENT	0
723658	720141	19599P	PARTICIPANT	\N	PRESENT	0
723659	720141	11101A	PARTICIPANT	\N	PRESENT	0
723661	720141	19820Y	PARTICIPANT	\N	PRESENT	0
723662	720141	20106U	PARTICIPANT	\N	PRESENT	0
723663	720141	19525U	PARTICIPANT	\N	PRESENT	0
723664	720141	20136B	PARTICIPANT	\N	PRESENT	0
723665	720141	14169X	PARTICIPANT	\N	PRESENT	0
723666	722685	19697Q	PARTICIPANT	\N	PRESENT	0
723667	723232	19647E	PARTICIPANT	\N	PRESENT	0
723668	723232	20080C	PARTICIPANT	\N	PRESENT	0
723669	723232	11070L	PARTICIPANT	\N	PRESENT	0
723671	720141	19685L	PARTICIPANT	\N	PRESENT	0
723672	720141	20038A	PARTICIPANT	\N	PRESENT	0
723673	720141	20118Y	PARTICIPANT	\N	PRESENT	0
723674	720141	19387D	PARTICIPANT	\N	PRESENT	0
723675	720141	20046A	PARTICIPANT	\N	PRESENT	0
723704	722685	14026U	PARTICIPANT	\N	PRESENT	0
723705	722685	20066E	PARTICIPANT	\N	PRESENT	0
723706	722685	19553Y	PARTICIPANT	\N	PRESENT	0
723707	722685	19591F	PARTICIPANT	\N	PRESENT	0
723708	722685	20040T	PARTICIPANT	\N	PRESENT	0
723709	722685	11067R	PARTICIPANT	\N	PRESENT	0
723713	723712	11085T	PARTICIPANT	\N	PRESENT	0
723714	723712	19545Y	PARTICIPANT	\N	PRESENT	0
723715	723712	14179A	PARTICIPANT	\N	PRESENT	0
723716	723712	20138D	PARTICIPANT	\N	PRESENT	0
723717	723712	14187A	PARTICIPANT	\N	PRESENT	0
723718	723712	14069U	PARTICIPANT	\N	PRESENT	0
723728	722685	20266L	PARTICIPANT	\N	PRESENT	0
723729	722685	11031D	PARTICIPANT	\N	PRESENT	0
723739	722685	17779H	PARTICIPANT	\N	PRESENT	0
723742	721806	11097X	PARTICIPANT	\N	PRESENT	0
723743	721806	20130U	PARTICIPANT	\N	PRESENT	0
723744	721807	11097X	PARTICIPANT	\N	PRESENT	0
723745	721807	20130U	PARTICIPANT	\N	PRESENT	0
723746	721807	14213J	PARTICIPANT	\N	PRESENT	0
723747	721808	11097X	PARTICIPANT	\N	PRESENT	0
723748	721808	14213J	PARTICIPANT	\N	PRESENT	0
723749	721808	20130U	PARTICIPANT	\N	PRESENT	0
723805	722685	17965H	PARTICIPANT	\N	PRESENT	0
723850	722685	01034P	PARTICIPANT	\N	PRESENT	0
723873	723233	08011M	PARTICIPANT	\N	PRESENT	0
723899	722689	19760E	PARTICIPANT	\N	PRESENT	0
723900	722689	20090E	PARTICIPANT	\N	PRESENT	0
723901	722689	14195A	PARTICIPANT	\N	PRESENT	0
723902	722689	11031D	PARTICIPANT	\N	PRESENT	0
723903	722689	19295A	PARTICIPANT	\N	EXCUSE	0
723904	722689	19663E	PARTICIPANT	\N	PRESENT	0
723905	722689	10006L	PRESIDENT	0	PRESENT	0
723906	722689	14217N	PRESIDENT	1	PRESENT	0
723907	722689	20248J	PARTICIPANT	\N	PRESENT	0
723908	722689	20040T	PARTICIPANT	\N	PRESENT	0
723909	722689	14042U	PARTICIPANT	\N	PRESENT	0
723910	722689	14281W	PARTICIPANT	\N	PRESENT	0
723911	722689	14026U	PARTICIPANT	\N	PRESENT	0
723912	722689	19691J	PARTICIPANT	\N	PRESENT	0
723913	722689	19553Y	PARTICIPANT	\N	PRESENT	0
723914	722689	19591F	PARTICIPANT	\N	PRESENT	0
723915	722689	14213J	PARTICIPANT	\N	PRESENT	0
723916	722689	20066E	PARTICIPANT	\N	PRESENT	0
723917	722689	19511N	PARTICIPANT	\N	PRESENT	0
723918	722689	19683J	PARTICIPANT	\N	PRESENT	0
723919	722689	19723Y	PARTICIPANT	\N	PRESENT	0
723920	722689	18193Q	PARTICIPANT	\N	PRESENT	0
723921	722689	19697Q	PARTICIPANT	\N	PRESENT	0
723922	722689	17779H	PARTICIPANT	\N	PRESENT	0
723923	722689	11067R	PARTICIPANT	\N	PRESENT	0
723924	722689	14071N	PARTICIPANT	\N	PRESENT	0
723925	722689	17965H	PARTICIPANT	\N	PRESENT	0
723926	722689	20130U	PARTICIPANT	\N	PRESENT	0
723927	722689	20148F	PARTICIPANT	\N	PRESENT	0
723928	722689	04043D	PARTICIPANT	\N	PRESENT	0
723929	722689	19679N	PARTICIPANT	\N	PRESENT	0
723930	722689	11045K	PARTICIPANT	\N	PRESENT	0
723931	722689	19798U	PARTICIPANT	\N	PRESENT	0
723932	722689	19703U	PARTICIPANT	\N	PRESENT	0
723933	722689	01034P	PARTICIPANT	\N	PRESENT	0
723934	722689	20266L	PARTICIPANT	\N	PRESENT	0
723935	722689	04092N	PARTICIPANT	\N	PRESENT	0
723936	722689	19569H	PARTICIPANT	\N	PRESENT	0
723937	722689	19415P	PARTICIPANT	\N	PRESENT	0
724044	720191	19691J	PARTICIPANT	\N	PRESENT	0
724046	720191	14281W	PARTICIPANT	\N	PRESENT	0
724048	720191	20090E	PARTICIPANT	\N	PRESENT	0
724093	722794	14038Y	PARTICIPANT	\N	PRESENT	0
724175	724165	20090E	PARTICIPANT	\N	PRESENT	0
724178	724165	14281W	PARTICIPANT	\N	PRESENT	0
724179	724165	19691J	PARTICIPANT	\N	PRESENT	0
724217	724197	19691J	PARTICIPANT	\N	PRESENT	0
724218	724197	20090E	PARTICIPANT	\N	PRESENT	0
724225	724197	14281W	PARTICIPANT	\N	PRESENT	0
724370	722661	20914V	PARTICIPANT	\N	PRESENT	0
724371	722661	19820Y	PARTICIPANT	\N	PRESENT	0
724372	722661	19387D	PARTICIPANT	\N	PRESENT	0
724373	722661	20128B	PARTICIPANT	\N	PRESENT	0
724374	722661	19745F	PRESIDENT	0	PRESENT	0
724375	722661	05012A	PARTICIPANT	\N	PRESENT	0
716271	716270	11077T	PARTICIPANT	\N	PRESENT	0
716272	716270	14037X	PARTICIPANT	\N	PRESENT	0
716273	716270	19515S	PARTICIPANT	\N	PRESENT	0
716274	716270	14257W	PARTICIPANT	\N	PRESENT	0
716276	716275	11077T	PARTICIPANT	\N	PRESENT	0
716277	716275	14037X	PARTICIPANT	\N	PRESENT	0
716278	716275	19515S	PARTICIPANT	\N	PRESENT	0
716279	716275	14257W	PARTICIPANT	\N	PRESENT	0
716281	716280	11077T	PARTICIPANT	\N	PRESENT	0
716282	716280	14037X	PARTICIPANT	\N	PRESENT	0
716283	716280	14257W	PARTICIPANT	\N	PRESENT	0
716558	716548	14147R	PARTICIPANT	\N	EXCUSE	0
716559	716547	20058E	PARTICIPANT	\N	PRESENT	1
724755	722795	20142Y	PARTICIPANT	\N	PRESENT	0
724756	722795	20082E	PARTICIPANT	\N	PRESENT	0
724757	722795	19489J	PARTICIPANT	\N	PRESENT	0
724758	722795	14229S	PARTICIPANT	\N	PRESENT	0
724759	722795	19479G	PARTICIPANT	\N	PRESENT	0
724760	722795	14083S	PARTICIPANT	\N	PRESENT	0
724761	722795	04070G	PARTICIPANT	\N	PRESENT	0
724762	722795	14055N	PARTICIPANT	\N	PRESENT	0
724763	722795	14237S	PARTICIPANT	\N	PRESENT	0
724764	722795	20108W	PARTICIPANT	\N	PRESENT	0
724765	722795	14259Y	PARTICIPANT	\N	PRESENT	0
724766	722795	19507S	PARTICIPANT	\N	PRESENT	0
724767	722795	19747H	PARTICIPANT	\N	PRESENT	0
724768	722795	19687N	PARTICIPANT	\N	PRESENT	0
724769	722795	19563B	PARTICIPANT	\N	PRESENT	0
724772	722795	20172F	PARTICIPANT	\N	PRESENT	0
724773	722795	14147R	PARTICIPANT	\N	PRESENT	0
724774	722795	20026V	PARTICIPANT	\N	PRESENT	0
724775	722795	19631V	PARTICIPANT	\N	PRESENT	0
724776	722795	11083R	PARTICIPANT	\N	PRESENT	0
724777	722795	14191V	PARTICIPANT	\N	PRESENT	0
724778	722795	19798U	PARTICIPANT	\N	PRESENT	0
724779	722795	20080C	PARTICIPANT	\N	PRESENT	0
724780	722795	20090E	PARTICIPANT	\N	PRESENT	0
724781	722795	20032T	PARTICIPANT	\N	PRESENT	0
724787	722795	19549D	PARTICIPANT	\N	PRESENT	0
724788	722795	14207L	PARTICIPANT	\N	PRESENT	0
724789	722795	14151M	PARTICIPANT	\N	PRESENT	0
724790	722795	20052X	PARTICIPANT	\N	PRESENT	0
724791	722795	19699S	PARTICIPANT	\N	PRESENT	0
724792	722795	20914V	PARTICIPANT	\N	PRESENT	0
724793	722795	20022R	PARTICIPANT	\N	PRESENT	0
724795	722795	19533U	PARTICIPANT	\N	PRESENT	0
724799	722795	20024T	PARTICIPANT	\N	PRESENT	0
724801	722795	20018V	PARTICIPANT	\N	PRESENT	0
724804	722795	20050V	PARTICIPANT	\N	PRESENT	0
724805	722795	19703U	PARTICIPANT	\N	PRESENT	0
724806	722795	19954N	PARTICIPANT	\N	PRESENT	0
724807	722795	19441R	PARTICIPANT	\N	PRESENT	0
724813	722795	14033T	PARTICIPANT	\N	PRESENT	0
724822	722795	20252E	PARTICIPANT	\N	PRESENT	0
724825	722795	14133K	PARTICIPANT	\N	PRESENT	0
724826	722795	19826F	PARTICIPANT	\N	PRESENT	0
724828	722795	14030Q	PARTICIPANT	\N	PRESENT	0
724829	722795	18193Q	PARTICIPANT	\N	PRESENT	0
724830	722795	19719D	PARTICIPANT	\N	PRESENT	0
724831	722795	19383Y	PARTICIPANT	\N	PRESENT	0
724832	724824	14357A	PARTICIPANT	\N	PRESENT	0
724833	724824	19251M	PRESIDENT	0	PRESENT	0
724834	724824	20102Q	PARTICIPANT	\N	PRESENT	0
724836	722795	19673G	PARTICIPANT	\N	PRESENT	0
724837	722795	19591F	PARTICIPANT	\N	PRESENT	0
724840	724824	19575F	PARTICIPANT	\N	PRESENT	0
724887	722795	11043H	PARTICIPANT	\N	PRESENT	0
724888	722795	20110Q	PARTICIPANT	\N	PRESENT	0
724889	724824	11053K	PARTICIPANT	\N	PRESENT	0
724933	722796	14151M	PARTICIPANT	\N	PRESENT	0
724934	722796	14229S	PARTICIPANT	\N	PRESENT	0
724935	722796	20082E	PARTICIPANT	\N	PRESENT	0
724936	722796	20264J	PARTICIPANT	\N	PRESENT	0
724937	722796	19599P	PARTICIPANT	\N	PRESENT	0
724938	722796	20130U	PARTICIPANT	\N	PRESENT	0
724939	722796	20142Y	PARTICIPANT	\N	PRESENT	0
724940	722796	20110Q	PARTICIPANT	\N	PRESENT	0
724941	722796	20914V	PARTICIPANT	\N	PRESENT	0
724942	722796	19591F	PARTICIPANT	\N	PRESENT	0
724943	722796	11012A	PARTICIPANT	\N	PRESENT	0
724944	722796	19441R	PARTICIPANT	\N	PRESENT	0
724945	722796	20092G	PARTICIPANT	\N	PRESENT	0
724946	722796	19489J	PARTICIPANT	\N	PRESENT	0
724947	722796	19563B	PARTICIPANT	\N	PRESENT	0
724949	722796	20144B	PARTICIPANT	\N	PRESENT	0
724950	722796	19699S	PARTICIPANT	\N	PRESENT	0
724951	722796	14021P	PARTICIPANT	\N	PRESENT	0
724952	722796	19826F	PARTICIPANT	\N	PRESENT	0
724953	722796	14055N	PARTICIPANT	\N	PRESENT	0
724954	722796	19798U	PARTICIPANT	\N	PRESENT	0
724955	722796	19621T	PARTICIPANT	\N	PRESENT	0
724956	722796	04033B	PARTICIPANT	\N	PRESENT	0
724958	722796	04070G	PARTICIPANT	\N	PRESENT	0
724960	722796	18083K	PARTICIPANT	\N	PRESENT	0
724963	722796	97011G	PARTICIPANT	\N	PRESENT	0
724964	722796	20090E	PARTICIPANT	\N	PRESENT	0
724965	722796	20032T	PARTICIPANT	\N	PRESENT	0
724966	722796	19741B	PARTICIPANT	\N	PRESENT	0
724967	722796	99004R	PARTICIPANT	\N	PRESENT	0
724968	722796	11043H	PARTICIPANT	\N	PRESENT	0
724969	722796	19954N	PARTICIPANT	\N	PRESENT	0
724970	722796	20026V	PARTICIPANT	\N	PRESENT	0
724984	722796	20056C	PARTICIPANT	\N	PRESENT	0
724972	722796	19573D	PARTICIPANT	\N	PRESENT	0
724973	722796	19673G	PARTICIPANT	\N	PRESENT	0
724974	722796	20038A	PARTICIPANT	\N	PRESENT	0
724975	722796	14133K	PARTICIPANT	\N	PRESENT	0
724976	724824	14237S	PARTICIPANT	\N	PRESENT	0
724977	722796	12041X	PARTICIPANT	\N	PRESENT	0
724978	722796	19719D	PARTICIPANT	\N	PRESENT	0
724931	722796	95063L	PARTICIPANT	\N	PRESENT	0
724932	722796	04085P	PARTICIPANT	\N	PRESENT	0
724979	722796	20022R	PARTICIPANT	\N	PRESENT	0
724980	722796	19383Y	PARTICIPANT	\N	PRESENT	0
724981	722796	20098N	PARTICIPANT	\N	PRESENT	0
724982	722796	19693L	PARTICIPANT	\N	PRESENT	0
724985	722796	05008E	PARTICIPANT	\N	PRESENT	0
724986	722796	20126Y	PARTICIPANT	\N	PRESENT	0
724988	722796	19747H	PARTICIPANT	\N	PRESENT	0
724989	724983	19347U	PARTICIPANT	\N	PRESENT	0
724990	724983	20018V	PARTICIPANT	\N	PRESENT	0
724991	724983	20124W	PARTICIPANT	\N	PRESENT	0
724992	724983	14257W	PARTICIPANT	\N	PRESENT	0
724993	724983	19701S	PARTICIPANT	\N	EXCUSE	0
724994	724983	20286Q	PARTICIPANT	\N	EXCUSE	0
724995	724983	19681G	PARTICIPANT	\N	EXCUSE	0
724996	724983	17023S	PARTICIPANT	\N	EXCUSE	0
724997	722796	14069U	PARTICIPANT	\N	PRESENT	0
724998	722796	01028R	PARTICIPANT	\N	PRESENT	0
724999	722796	19581D	PARTICIPANT	\N	PRESENT	0
725000	722796	14033T	PARTICIPANT	\N	PRESENT	0
725001	722796	14191V	PARTICIPANT	\N	PRESENT	0
725002	722796	19413M	PARTICIPANT	\N	PRESENT	0
725003	722796	17779H	PARTICIPANT	\N	PRESENT	0
725004	722796	20138D	PARTICIPANT	\N	PRESENT	0
725005	722796	14053L	PARTICIPANT	\N	PRESENT	0
725006	724824	20084G	PARTICIPANT	\N	PRESENT	0
725007	722796	14217N	PARTICIPANT	\N	PRESENT	0
725008	722796	01048V	PARTICIPANT	\N	PRESENT	0
725009	724824	20180F	PARTICIPANT	\N	PRESENT	0
725010	722796	19695N	PARTICIPANT	\N	PRESENT	0
725020	722796	20066E	PARTICIPANT	\N	PRESENT	0
725021	722796	14031R	PARTICIPANT	\N	PRESENT	0
725022	722796	20024T	PARTICIPANT	\N	PRESENT	0
725023	722796	14071N	PARTICIPANT	\N	PRESENT	0
725024	722796	18193Q	PARTICIPANT	\N	PRESENT	0
725028	722796	01058X	PARTICIPANT	\N	PRESENT	0
725029	722796	20132W	PARTICIPANT	\N	PRESENT	0
725030	722796	19399H	PARTICIPANT	\N	PRESENT	0
725031	722796	01043Q	PARTICIPANT	\N	PRESENT	0
725032	722796	14073Q	PARTICIPANT	\N	PRESENT	0
725033	722796	14215L	PARTICIPANT	\N	PRESENT	0
725034	722796	19691J	PARTICIPANT	\N	PRESENT	0
725035	722796	08061X	PARTICIPANT	\N	PRESENT	0
725036	722796	19301E	PARTICIPANT	\N	PRESENT	0
734158	733755	11067R	PARTICIPANT	\N	EXCUSE	0
734159	733755	19735D	PARTICIPANT	\N	EXCUSE	0
734160	733755	20072C	PARTICIPANT	\N	EXCUSE	0
734161	733755	20066E	PARTICIPANT	\N	EXCUSE	0
734353	732759	14133K	PARTICIPANT	\N	PRESENT	0
734354	732759	20104S	PARTICIPANT	\N	PRESENT	0
734355	732759	11101A	PARTICIPANT	\N	PRESENT	0
734356	732759	14357A	PARTICIPANT	\N	PRESENT	0
734357	732759	20100N	PARTICIPANT	\N	PRESENT	0
734358	732759	11083R	PARTICIPANT	\N	PRESENT	0
734359	732759	19333N	PARTICIPANT	\N	PRESENT	0
734360	732759	08034U	PARTICIPANT	\N	PRESENT	0
734361	732759	19441R	PARTICIPANT	\N	PRESENT	0
734362	732759	14001X	PARTICIPANT	\N	PRESENT	0
734363	732759	19563B	PARTICIPANT	\N	PRESENT	0
734364	732759	14331P	PARTICIPANT	\N	PRESENT	0
734365	732759	10015M	PARTICIPANT	\N	PRESENT	0
734366	732759	14033T	PARTICIPANT	\N	PRESENT	0
734367	732759	14026U	PARTICIPANT	\N	PRESENT	0
734368	732759	14083S	PARTICIPANT	\N	PRESENT	0
734369	732759	20098N	PARTICIPANT	\N	PRESENT	0
738796	738795	20062A	PARTICIPANT	\N	PRESENT	0
738798	738797	20062A	PARTICIPANT	\N	PRESENT	0
738799	738797	14257W	PARTICIPANT	\N	PRESENT	0
738801	738800	20062A	PARTICIPANT	\N	PRESENT	0
738803	738802	20062A	PARTICIPANT	\N	PRESENT	0
738805	738804	20062A	PARTICIPANT	\N	PRESENT	0
738806	738804	14257W	PARTICIPANT	\N	PRESENT	1
738808	738807	20062A	PARTICIPANT	\N	PRESENT	0
738811	738810	20062A	PARTICIPANT	\N	PRESENT	0
738813	738812	20062A	PARTICIPANT	\N	PRESENT	0
738815	738814	20062A	PARTICIPANT	\N	PRESENT	0
738818	738817	20062A	PARTICIPANT	\N	PRESENT	0
738821	738819	20062A	PARTICIPANT	\N	PRESENT	0
738829	738827	20062A	PARTICIPANT	\N	PRESENT	0
738831	738830	20062A	PARTICIPANT	\N	PRESENT	0
739344	738516	20092G	PARTICIPANT	\N	PRESENT	0
739345	738516	11077T	PARTICIPANT	\N	PRESENT	0
739346	738516	01043Q	PARTICIPANT	\N	PRESENT	0
739347	738516	19441R	PARTICIPANT	\N	PRESENT	0
739348	738516	20078J	PARTICIPANT	\N	PRESENT	0
739349	738516	19413M	PARTICIPANT	\N	PRESENT	0
739350	738516	20082E	PARTICIPANT	\N	PRESENT	0
739351	738516	20094J	PARTICIPANT	\N	PRESENT	0
739352	738516	19866P	PARTICIPANT	\N	PRESENT	0
739353	738516	19631V	PARTICIPANT	\N	PRESENT	0
739354	738516	20104S	PARTICIPANT	\N	PRESENT	0
739355	738516	11099A	PARTICIPANT	\N	PRESENT	0
739356	738516	19705W	PARTICIPANT	\N	PRESENT	0
739357	738516	19707Y	PARTICIPANT	\N	PRESENT	0
739358	738516	08015R	PARTICIPANT	\N	PRESENT	0
739359	738516	19575F	PARTICIPANT	\N	PRESENT	0
739360	738516	19369B	PARTICIPANT	\N	PRESENT	0
739361	738516	20018V	PARTICIPANT	\N	PRESENT	0
739362	738516	08028W	PARTICIPANT	\N	PRESENT	0
739363	738516	14329V	PARTICIPANT	\N	PRESENT	0
739364	738516	20028X	PARTICIPANT	\N	PRESENT	0
739365	738516	20030R	PARTICIPANT	\N	PRESENT	0
739366	738516	14038Y	PARTICIPANT	\N	PRESENT	0
739367	738516	19467C	PARTICIPANT	\N	PRESENT	0
739368	738516	20034V	PARTICIPANT	\N	PRESENT	0
739369	738516	14187A	PARTICIPANT	\N	PRESENT	0
739370	738516	20144B	PARTICIPANT	\N	PRESENT	0
739371	738516	19695N	PARTICIPANT	\N	PRESENT	0
739372	738516	11090Q	PRESIDENT	0	PRESENT	0
739373	738516	14033T	PARTICIPANT	\N	PRESENT	0
739374	738516	01025N	PARTICIPANT	\N	PRESENT	0
739375	738516	14205J	PARTICIPANT	\N	PRESENT	0
739376	738516	20060X	PARTICIPANT	\N	PRESENT	0
739377	738516	20062A	PARTICIPANT	\N	PRESENT	0
739378	738516	14251Q	PARTICIPANT	\N	PRESENT	0
739379	738516	19507S	PARTICIPANT	\N	PRESENT	0
739380	738516	20286Q	PARTICIPANT	\N	PRESENT	0
739381	738516	20298U	PARTICIPANT	\N	PRESENT	0
739382	738516	19747H	PARTICIPANT	\N	PRESENT	0
739383	738516	14207L	PARTICIPANT	\N	PRESENT	0
739384	738516	14257W	PARTICIPANT	\N	PRESENT	0
739385	738516	14357A	PARTICIPANT	\N	EXCUSE	0
739386	738516	04045F	PARTICIPANT	\N	EXCUSE	0
739387	738516	19563B	PARTICIPANT	\N	EXCUSE	0
739426	735924	11109J	PARTICIPANT	\N	EXCUSE	0
739427	735924	19735D	PARTICIPANT	\N	EXCUSE	0
739428	735924	14229S	PARTICIPANT	\N	PRESENT	0
739453	725786	19575F	PARTICIPANT	\N	PRESENT	0
739454	725786	20094J	PARTICIPANT	\N	PRESENT	0
739455	725786	11012A	PARTICIPANT	\N	PRESENT	0
739456	725786	19251M	PARTICIPANT	\N	PRESENT	0
739457	725786	20124W	PARTICIPANT	\N	PRESENT	0
739458	725786	20126Y	PARTICIPANT	\N	PRESENT	0
739459	725786	14237S	PARTICIPANT	\N	PRESENT	0
739460	725786	14193X	PARTICIPANT	\N	PRESENT	0
739475	739474	04047H	PARTICIPANT	\N	PRESENT	0
739678	738007	20052X	PARTICIPANT	\N	PRESENT	0
739679	738007	20062A	PARTICIPANT	\N	PRESENT	0
739680	738007	19721W	PARTICIPANT	\N	PRESENT	0
739681	738007	14329V	PARTICIPANT	\N	PRESENT	0
739682	738007	19619A	PARTICIPANT	\N	PRESENT	0
739683	738007	20048C	PARTICIPANT	\N	PRESENT	0
739684	738007	19479G	PARTICIPANT	\N	PRESENT	0
739685	738007	19383Y	PARTICIPANT	\N	PRESENT	0
739686	738007	14219Q	PARTICIPANT	\N	PRESENT	0
739687	738007	17737W	PARTICIPANT	\N	PRESENT	0
739688	738007	14042U	PARTICIPANT	\N	PRESENT	0
739689	738007	20118Y	PARTICIPANT	\N	PRESENT	0
739690	738007	14205J	PARTICIPANT	\N	PRESENT	0
739691	738007	20144B	PARTICIPANT	\N	PRESENT	0
739692	738007	20090E	PARTICIPANT	\N	PRESENT	0
739693	738007	19798U	PARTICIPANT	\N	PRESENT	0
739694	738007	11053K	PARTICIPANT	\N	PRESENT	0
739695	738007	08009T	PARTICIPANT	\N	PRESENT	0
739696	738007	20096L	PARTICIPANT	\N	PRESENT	0
739697	738007	19369B	PARTICIPANT	\N	PRESENT	0
739698	738007	01034P	PARTICIPANT	\N	PRESENT	0
739699	738007	01043Q	PARTICIPANT	\N	PRESENT	0
739700	738007	11056N	PARTICIPANT	\N	PRESENT	0
739701	738007	19723Y	PARTICIPANT	\N	PRESENT	0
739702	738007	19691J	PARTICIPANT	\N	PRESENT	0
739703	738007	20058E	PARTICIPANT	\N	PRESENT	0
739704	738007	14179A	PARTICIPANT	\N	PRESENT	0
739705	738007	20148F	PARTICIPANT	\N	PRESENT	0
739706	738007	19745F	PARTICIPANT	\N	PRESENT	0
739707	738007	11026G	PARTICIPANT	\N	PRESENT	0
739708	738007	14033T	PARTICIPANT	\N	PRESENT	0
739709	738007	17229F	PARTICIPANT	\N	PRESENT	0
739710	738007	14259Y	PARTICIPANT	\N	PRESENT	0
739711	738007	14231L	PARTICIPANT	\N	PRESENT	0
739719	738007	17023S	PARTICIPANT	\N	PRESENT	0
739713	738007	20298U	PARTICIPANT	\N	PRESENT	0
739714	738007	19543W	PARTICIPANT	\N	PRESENT	0
739715	738007	19533U	PARTICIPANT	\N	PRESENT	0
739716	738007	19335Q	PARTICIPANT	\N	PRESENT	0
739717	738007	10006L	PARTICIPANT	\N	PRESENT	0
739718	738007	14331P	PARTICIPANT	\N	PRESENT	0
739720	738007	19611R	PARTICIPANT	\N	PRESENT	0
739721	738007	14073Q	PARTICIPANT	\N	PRESENT	0
739722	738007	14083S	PARTICIPANT	\N	PRESENT	0
739723	738007	19749K	PARTICIPANT	\N	PRESENT	0
739724	738007	14089Y	PARTICIPANT	\N	PRESENT	0
739725	738007	20248J	PARTICIPANT	\N	PRESENT	0
739726	738007	20132W	PARTICIPANT	\N	PRESENT	0
739727	738007	11070L	PARTICIPANT	\N	PRESENT	0
739728	738007	20040T	PARTICIPANT	\N	PRESENT	0
739729	738007	14026U	PARTICIPANT	\N	PRESENT	0
739730	738007	19826F	PARTICIPANT	\N	PRESENT	0
739731	738007	20070A	PARTICIPANT	\N	PRESENT	0
739732	738007	07004J	PARTICIPANT	\N	PRESENT	0
739733	738007	19762G	PARTICIPANT	\N	PRESENT	0
739734	738007	14217N	PARTICIPANT	\N	PRESENT	0
739735	738007	14255U	PARTICIPANT	\N	PRESENT	0
739736	738007	11085T	PARTICIPANT	\N	PRESENT	0
739737	738007	19679N	PARTICIPANT	\N	PRESENT	0
739738	738007	01025N	PARTICIPANT	\N	PRESENT	0
739739	738007	01024M	PARTICIPANT	\N	PRESENT	0
739740	738007	04070G	PARTICIPANT	\N	PRESENT	0
739741	738007	14030Q	PARTICIPANT	\N	PRESENT	0
739742	738007	14327T	PARTICIPANT	\N	PRESENT	0
739743	738007	20252E	PARTICIPANT	\N	PRESENT	0
739744	738007	19643A	PARTICIPANT	\N	PRESENT	0
739746	738007	19399H	PARTICIPANT	\N	PRESENT	0
720530	720529	14073Q	PARTICIPANT	\N	PRESENT	0
720531	720529	19647E	PARTICIPANT	\N	PRESENT	0
720532	720529	20056C	PARTICIPANT	\N	PRESENT	0
721318	720092	20110Q	PARTICIPANT	\N	PRESENT	0
721319	720092	14215L	PARTICIPANT	\N	PRESENT	0
721320	720092	14001X	PARTICIPANT	\N	PRESENT	0
721321	720092	01028R	PARTICIPANT	\N	PRESENT	0
721322	720092	19725B	PARTICIPANT	\N	PRESENT	0
721323	720092	19489J	PARTICIPANT	\N	PRESENT	0
721370	720092	05008E	PARTICIPANT	\N	PRESENT	0
721415	719952	11031D	PARTICIPANT	\N	PRESENT	0
721416	719952	20024T	PARTICIPANT	\N	PRESENT	0
721417	719952	20126Y	PARTICIPANT	\N	EXCUSE	0
721418	719952	04045F	PARTICIPANT	\N	EXCUSE	0
721419	719952	04092N	PARTICIPANT	\N	EXCUSE	0
721420	719952	20050V	PARTICIPANT	\N	EXCUSE	0
721421	719952	19725B	PARTICIPANT	\N	PRESENT	0
721422	719952	19735D	PRESIDENT	0	PRESENT	0
721423	719952	17965H	PARTICIPANT	\N	PRESENT	0
721424	719952	14026U	PARTICIPANT	\N	PRESENT	0
721425	719952	20138D	PARTICIPANT	\N	PRESENT	0
721426	719952	20066E	PARTICIPANT	\N	PRESENT	0
721437	705811	14189C	PARTICIPANT	\N	EXCUSE	0
721439	705811	20024T	PARTICIPANT	\N	EXCUSE	0
721440	705811	19715Y	PARTICIPANT	\N	EXCUSE	0
721441	705811	11031D	PARTICIPANT	\N	EXCUSE	0
721443	705811	20118Y	PARTICIPANT	\N	EXCUSE	0
721447	721446	20136B	PARTICIPANT	\N	PRESENT	0
721448	721446	20100N	PARTICIPANT	\N	PRESENT	0
721449	721446	19551W	PARTICIPANT	\N	PRESENT	0
721459	721458	20136B	PARTICIPANT	\N	PRESENT	0
721460	721458	20100N	PARTICIPANT	\N	PRESENT	0
721502	721501	20136B	PARTICIPANT	\N	PRESENT	0
721529	721518	20136B	PARTICIPANT	\N	PRESENT	0
721530	721518	20100N	PARTICIPANT	\N	PRESENT	0
721531	721518	19551W	PARTICIPANT	\N	PRESENT	0
721537	721535	20136B	PARTICIPANT	\N	PRESENT	0
721539	721535	20100N	PARTICIPANT	\N	PRESENT	0
722216	719776	19673G	PARTICIPANT	\N	EXCUSE	0
722322	722321	20124W	PARTICIPANT	\N	PRESENT	0
722353	722352	19663E	PARTICIPANT	\N	PRESENT	0
722354	722352	19693L	PARTICIPANT	\N	PRESENT	0
722355	722352	10006L	PARTICIPANT	\N	PRESENT	0
722356	722352	19723Y	PARTICIPANT	\N	PRESENT	0
722357	722352	11097X	PARTICIPANT	\N	PRESENT	0
722373	722371	14231L	PRESIDENT	0	PRESENT	0
722374	722371	08010L	PARTICIPANT	\N	PRESENT	0
722376	722371	14151M	PARTICIPANT	\N	PRESENT	0
722378	722371	19681G	PARTICIPANT	\N	PRESENT	0
722380	722371	14327T	PARTICIPANT	\N	PRESENT	0
722381	722371	20058E	PARTICIPANT	\N	PRESENT	0
722383	722371	14215L	PARTICIPANT	\N	PRESENT	0
722384	722371	01057W	PARTICIPANT	\N	PRESENT	0
722385	722371	14053L	PARTICIPANT	\N	PRESENT	0
722386	722371	14071N	PARTICIPANT	\N	PRESENT	0
722387	722371	20090E	PARTICIPANT	\N	PRESENT	0
722388	722371	20022R	PARTICIPANT	\N	EXCUSE	0
722389	722371	14069U	PARTICIPANT	\N	EXCUSE	0
722390	722371	19782L	PARTICIPANT	\N	EXCUSE	0
722391	722371	14217N	PARTICIPANT	\N	EXCUSE	0
722392	722371	19565D	PARTICIPANT	\N	EXCUSE	0
722393	722371	19447X	PARTICIPANT	\N	EXCUSE	0
722394	722371	19735D	PARTICIPANT	\N	EXCUSE	0
722395	722371	19489J	PARTICIPANT	\N	EXCUSE	0
722396	722371	19711U	PARTICIPANT	\N	EXCUSE	0
722397	722371	14205J	PARTICIPANT	\N	EXCUSE	0
722398	722371	19826F	PARTICIPANT	\N	EXCUSE	0
722399	722371	17637T	PARTICIPANT	\N	EXCUSE	0
722400	722371	05012A	PARTICIPANT	\N	EXCUSE	0
722401	722371	14229S	PARTICIPANT	\N	EXCUSE	0
722402	722371	04045F	PARTICIPANT	\N	EXCUSE	0
722403	722371	20062A	PARTICIPANT	\N	EXCUSE	0
722404	722371	20084G	PARTICIPANT	\N	EXCUSE	0
722471	721236	19741B	PARTICIPANT	\N	PRESENT	0
722556	705811	20130U	PARTICIPANT	\N	EXCUSE	0
722687	722686	20058E	PARTICIPANT	\N	PRESENT	1
722688	722686	14123H	PARTICIPANT	\N	PRESENT	1
722703	719951	20038A	PARTICIPANT	\N	PRESENT	0
722704	719951	19335Q	PRESIDENT	0	PRESENT	0
722769	722768	11045K	PRESIDENT	0	PRESENT	0
722858	722847	19569H	PARTICIPANT	\N	PRESENT	1
722859	722847	18193Q	PARTICIPANT	\N	PRESENT	0
722903	722902	14329V	PARTICIPANT	\N	PRESENT	0
722906	722902	14259Y	PARTICIPANT	\N	PRESENT	0
722958	722902	19629C	PARTICIPANT	\N	PRESENT	0
723211	722791	20024T	PARTICIPANT	\N	PRESENT	0
723215	722791	20180F	PARTICIPANT	\N	PRESENT	0
723216	722791	20980G	PARTICIPANT	\N	PRESENT	0
723218	722791	20042V	PARTICIPANT	\N	PRESENT	0
723227	722791	14205J	PARTICIPANT	\N	PRESENT	0
723228	722791	14030Q	PARTICIPANT	\N	PRESENT	0
723234	722791	14173T	PARTICIPANT	\N	PRESENT	0
723235	722791	20116W	PARTICIPANT	\N	PRESENT	0
723236	722791	20142Y	PARTICIPANT	\N	PRESENT	0
723237	722791	14207L	PARTICIPANT	\N	PRESENT	0
723254	722791	18193Q	PARTICIPANT	\N	PRESENT	0
723255	722791	19421M	PARTICIPANT	\N	PRESENT	0
723256	722791	14073Q	PARTICIPANT	\N	PRESENT	0
723258	723207	18083K	PARTICIPANT	\N	PRESENT	0
723259	723207	20090E	PARTICIPANT	\N	PRESENT	0
723260	723207	14187A	PRESIDENT	0	PRESENT	0
723261	723207	19347U	PARTICIPANT	\N	PRESENT	0
723264	722791	11104D	PARTICIPANT	\N	PRESENT	0
723267	722791	20054A	PARTICIPANT	\N	PRESENT	0
723268	722791	17965H	PARTICIPANT	\N	PRESENT	0
723323	722792	19719D	PARTICIPANT	\N	PRESENT	0
723324	722792	20036X	PARTICIPANT	\N	PRESENT	0
723325	722792	20142Y	PARTICIPANT	\N	PRESENT	0
723326	722792	20134Y	PARTICIPANT	\N	PRESENT	0
723327	722792	20024T	PARTICIPANT	\N	PRESENT	0
723328	722792	11033F	PARTICIPANT	\N	PRESENT	0
723329	722792	14030Q	PARTICIPANT	\N	PRESENT	0
723331	722792	19758L	PARTICIPANT	\N	PRESENT	0
723332	722792	19621T	PARTICIPANT	\N	PRESENT	0
723333	722792	19593H	PARTICIPANT	\N	PRESENT	0
723334	723207	19701S	PARTICIPANT	\N	EXCUSE	0
723335	723207	20286Q	PARTICIPANT	\N	EXCUSE	0
723336	723207	19681G	PARTICIPANT	\N	EXCUSE	0
723337	723207	17023S	PARTICIPANT	\N	EXCUSE	0
723338	722792	19647E	PARTICIPANT	\N	PRESENT	0
723339	722792	18193Q	PARTICIPANT	\N	PRESENT	0
723340	722792	17965H	PARTICIPANT	\N	PRESENT	0
723341	722792	14109K	PARTICIPANT	\N	PRESENT	0
723342	722792	20264J	PARTICIPANT	\N	PRESENT	0
723344	722792	11104D	PARTICIPANT	\N	PRESENT	0
723346	722792	20044X	PARTICIPANT	\N	PRESENT	0
723348	722792	19651A	PARTICIPANT	\N	PRESENT	0
723349	722792	20132W	PARTICIPANT	\N	PRESENT	0
723350	722792	20116W	PARTICIPANT	\N	PRESENT	0
723351	722792	11012A	PARTICIPANT	\N	PRESENT	0
723352	722792	98022P	PARTICIPANT	\N	PRESENT	0
723353	722792	14207L	PARTICIPANT	\N	PRESENT	0
723354	722792	14053L	PARTICIPANT	\N	PRESENT	0
723355	722792	19479G	PARTICIPANT	\N	PRESENT	0
723357	722792	14073Q	PARTICIPANT	\N	PRESENT	0
723358	722792	20042V	PARTICIPANT	\N	PRESENT	0
723359	722792	01024M	PARTICIPANT	\N	PRESENT	0
723360	722792	19699S	PARTICIPANT	\N	PRESENT	0
724377	722661	20094J	PARTICIPANT	\N	PRESENT	0
724416	724414	04070G	PARTICIPANT	\N	PRESENT	0
724418	724414	20128B	PARTICIPANT	\N	PRESENT	0
724420	724414	10015M	PARTICIPANT	\N	PRESENT	0
724784	724783	04070G	PARTICIPANT	\N	PRESENT	0
724785	724783	20128B	PARTICIPANT	\N	PRESENT	0
724786	724783	10015M	PARTICIPANT	\N	PRESENT	0
724797	724796	04070G	PARTICIPANT	\N	PRESENT	0
724798	724796	20128B	PARTICIPANT	\N	PRESENT	0
724800	724796	10015M	PARTICIPANT	\N	PRESENT	0
724810	724809	04070G	PARTICIPANT	\N	PRESENT	0
724811	724809	20128B	PARTICIPANT	\N	PRESENT	0
724812	724809	10015M	PARTICIPANT	\N	PRESENT	0
724817	724816	04070G	PARTICIPANT	\N	PRESENT	0
724818	724816	20128B	PARTICIPANT	\N	PRESENT	0
724819	724816	10015M	PARTICIPANT	\N	PRESENT	0
725203	725201	19333N	PARTICIPANT	\N	PRESENT	0
724842	724841	04045F	PARTICIPANT	\N	EXCUSE	0
724843	724841	20092G	PARTICIPANT	\N	PRESENT	0
724844	724841	20054A	PARTICIPANT	\N	PRESENT	0
724845	724841	19705W	PARTICIPANT	\N	PRESENT	0
724846	724841	19413M	PARTICIPANT	\N	PRESENT	0
724847	724841	19866P	PARTICIPANT	\N	PRESENT	0
724848	724841	19768N	PARTICIPANT	\N	PRESENT	0
724849	724841	14257W	PARTICIPANT	\N	PRESENT	0
724850	724841	19369B	PARTICIPANT	\N	PRESENT	0
724851	724841	20082E	PARTICIPANT	\N	PRESENT	0
724852	724841	20298U	PARTICIPANT	\N	PRESENT	0
724853	724841	11090Q	PRESIDENT	\N	PRESENT	0
724854	724841	20030R	PARTICIPANT	\N	EXCUSE	0
724855	724841	19515S	PARTICIPANT	\N	PRESENT	0
724856	724841	19631V	PARTICIPANT	\N	PRESENT	0
724857	724841	20144B	PARTICIPANT	\N	PRESENT	0
724858	724841	08028W	PARTICIPANT	\N	PRESENT	0
724859	724841	14038Y	PARTICIPANT	\N	PRESENT	0
724860	724841	20060X	PARTICIPANT	\N	PRESENT	0
724861	724841	14357A	PARTICIPANT	\N	PRESENT	0
724862	724841	19467C	PARTICIPANT	\N	PRESENT	0
724863	724841	20078J	PARTICIPANT	\N	PRESENT	0
724864	724841	20094J	PARTICIPANT	\N	PRESENT	0
724865	724841	19575F	PARTICIPANT	\N	PRESENT	0
724866	724841	19707Y	PARTICIPANT	\N	PRESENT	0
724867	724841	14207L	PARTICIPANT	\N	PRESENT	0
724868	724841	19782L	PARTICIPANT	\N	PRESENT	0
724869	724841	19383Y	PARTICIPANT	\N	PRESENT	0
724870	724841	19747H	PARTICIPANT	\N	PRESENT	0
724871	724841	19441R	PARTICIPANT	\N	PRESENT	0
724872	724841	14205J	PARTICIPANT	\N	PRESENT	0
724873	724841	11077T	PARTICIPANT	\N	PRESENT	0
724874	724841	01043Q	PARTICIPANT	\N	PRESENT	0
724875	724841	20018V	PARTICIPANT	\N	PRESENT	0
724876	724841	20028X	PARTICIPANT	\N	PRESENT	0
724877	724841	19563B	PARTICIPANT	\N	PRESENT	0
724878	724841	14251Q	PARTICIPANT	\N	PRESENT	0
724879	724841	20286Q	PARTICIPANT	\N	PRESENT	0
724880	724841	01025N	PARTICIPANT	\N	PRESENT	0
724881	724841	14187A	PARTICIPANT	\N	PRESENT	0
724882	724841	19507S	PARTICIPANT	\N	PRESENT	0
724883	724841	14037X	PARTICIPANT	\N	PRESENT	0
724884	724841	08015R	PARTICIPANT	\N	PRESENT	0
724885	724841	14033T	PARTICIPANT	\N	PRESENT	0
724886	724841	19695N	PARTICIPANT	\N	PRESENT	0
725202	725201	14231L	PRESIDENT	0	PRESENT	0
725204	725201	20084G	PARTICIPANT	\N	PRESENT	0
725205	725201	14151M	PARTICIPANT	\N	PRESENT	0
725206	725201	19782L	PARTICIPANT	\N	PRESENT	0
725207	725201	14187A	PARTICIPANT	\N	PRESENT	0
725208	725201	19735D	PARTICIPANT	\N	PRESENT	0
725209	725201	19826F	PARTICIPANT	\N	PRESENT	0
725210	725201	20090E	PARTICIPANT	\N	PRESENT	0
725211	725201	14215L	PARTICIPANT	\N	PRESENT	0
725212	725201	20022R	PARTICIPANT	\N	EXCUSE	0
725213	725201	19565D	PARTICIPANT	\N	EXCUSE	0
725214	725201	19447X	PARTICIPANT	\N	EXCUSE	0
725215	725201	19489J	PARTICIPANT	\N	EXCUSE	0
725216	725201	04045F	PARTICIPANT	\N	EXCUSE	0
725217	725201	20058E	PARTICIPANT	\N	EXCUSE	0
725220	725201	19711U	PARTICIPANT	\N	PRESENT	0
725221	725201	20062A	PARTICIPANT	\N	EXCUSE	0
725269	721825	20024T	PARTICIPANT	\N	PRESENT	0
725270	721825	20066E	PARTICIPANT	\N	PRESENT	0
725271	721825	17965H	PARTICIPANT	\N	PRESENT	0
725272	721825	19735D	PRESIDENT	0	PRESENT	0
725273	721825	11031D	PARTICIPANT	\N	PRESENT	0
725320	721825	04045F	PARTICIPANT	\N	EXCUSE	0
725321	721825	20050V	PARTICIPANT	\N	EXCUSE	0
725322	721825	14213J	PARTICIPANT	\N	EXCUSE	0
725344	725343	20286Q	PARTICIPANT	\N	PRESENT	0
725346	725345	20286Q	PARTICIPANT	\N	PRESENT	0
725347	725345	01025N	PARTICIPANT	\N	PRESENT	0
725348	725345	20092G	PARTICIPANT	\N	PRESENT	0
725365	725363	14053L	PARTICIPANT	\N	PRESENT	0
725447	725233	19347U	PARTICIPANT	\N	PRESENT	0
725506	725505	19693L	PARTICIPANT	\N	PRESENT	0
725513	725512	20106U	PARTICIPANT	\N	PRESENT	0
725514	725512	19335Q	PARTICIPANT	\N	PRESENT	0
725515	725512	19715Y	PARTICIPANT	\N	PRESENT	1
725516	725512	20148F	PARTICIPANT	\N	PRESENT	1
725584	725583	19820Y	PARTICIPANT	\N	PRESENT	0
725588	725585	19820Y	PARTICIPANT	\N	PRESENT	0
725594	725593	14179A	PARTICIPANT	\N	PRESENT	0
725596	725595	14179A	PARTICIPANT	\N	PRESENT	0
725597	725586	19820Y	PARTICIPANT	\N	PRESENT	0
725607	725606	95063L	PARTICIPANT	\N	PRESENT	0
725609	725608	95063L	PARTICIPANT	\N	PRESENT	0
725611	725610	17737W	PARTICIPANT	\N	PRESENT	0
725885	725884	11090Q	PARTICIPANT	\N	PRESENT	0
725887	725886	11090Q	PARTICIPANT	\N	PRESENT	0
725889	725888	11090Q	PARTICIPANT	\N	PRESENT	0
725891	725890	11090Q	PARTICIPANT	\N	PRESENT	0
725893	725892	11090Q	PARTICIPANT	\N	PRESENT	0
725894	725892	19507S	PARTICIPANT	\N	PRESENT	0
725896	725895	11090Q	PARTICIPANT	\N	PRESENT	0
725897	725895	19507S	PARTICIPANT	\N	PRESENT	0
725899	725898	11090Q	PARTICIPANT	\N	PRESENT	0
725901	725900	11090Q	PARTICIPANT	\N	PRESENT	0
725902	725810	20034V	PARTICIPANT	\N	PRESENT	0
725903	725810	11010L	PARTICIPANT	\N	EXCUSE	0
725907	725904	14042U	PARTICIPANT	\N	PRESENT	0
725908	725904	18193Q	PARTICIPANT	\N	PRESENT	0
725909	725905	14042U	PARTICIPANT	\N	PRESENT	0
725910	725905	18193Q	PARTICIPANT	\N	PRESENT	0
725911	725906	14042U	PARTICIPANT	\N	PRESENT	0
725912	725906	18193Q	PARTICIPANT	\N	PRESENT	0
725913	725810	19295A	PARTICIPANT	\N	EXCUSE	0
725915	725914	05008E	PARTICIPANT	\N	PRESENT	0
725916	725914	11053K	PARTICIPANT	\N	PRESENT	0
725917	725914	01028R	PARTICIPANT	\N	PRESENT	0
725970	725806	20126Y	PARTICIPANT	\N	PRESENT	0
725971	725806	19735D	PRESIDENT	0	PRESENT	0
725972	725806	14026U	PARTICIPANT	\N	PRESENT	0
725973	725806	11031D	PARTICIPANT	\N	PRESENT	0
725974	725806	20138D	PARTICIPANT	\N	PRESENT	0
725975	725806	14213J	PARTICIPANT	\N	PRESENT	0
725976	725806	17965H	PARTICIPANT	\N	PRESENT	0
725977	725806	04045F	PARTICIPANT	\N	PRESENT	0
725978	725806	20066E	PARTICIPANT	\N	PRESENT	0
725979	725806	20096L	PARTICIPANT	\N	PRESENT	0
726005	726004	14030Q	PARTICIPANT	\N	PRESENT	0
726006	726004	20066E	PARTICIPANT	\N	PRESENT	0
726007	726004	19798U	PARTICIPANT	\N	PRESENT	0
726008	726004	11045K	PARTICIPANT	\N	PRESENT	0
726009	725806	20024T	PARTICIPANT	\N	PRESENT	0
726068	726067	20136B	PARTICIPANT	\N	PRESENT	0
726074	726073	20136B	PARTICIPANT	\N	PRESENT	0
726100	726099	14225N	PARTICIPANT	\N	PRESENT	0
726101	726099	11048N	PARTICIPANT	\N	PRESENT	0
726102	726099	08034U	PARTICIPANT	\N	PRESENT	0
726103	726099	19647E	PARTICIPANT	\N	PRESENT	0
726104	726099	14327T	PARTICIPANT	\N	PRESENT	0
726236	726235	19820Y	PARTICIPANT	\N	PRESENT	0
726238	726235	05012A	PARTICIPANT	\N	PRESENT	0
726239	726235	19768N	PARTICIPANT	\N	PRESENT	0
726241	726235	20914V	PARTICIPANT	\N	PRESENT	0
726242	726235	20094J	PARTICIPANT	\N	PRESENT	0
726243	726235	20128B	PARTICIPANT	\N	PRESENT	0
726246	726235	20070A	PARTICIPANT	\N	PRESENT	0
712259	709156	19319Q	PARTICIPANT	\N	EXCUSE	0
712262	712261	19711U	PARTICIPANT	\N	PRESENT	0
716778	716686	19768N	PARTICIPANT	\N	EXCUSE	0
716779	716686	20082E	PARTICIPANT	\N	EXCUSE	0
716780	716686	19563B	PARTICIPANT	\N	EXCUSE	0
718573	716561	19820Y	PARTICIPANT	\N	PRESENT	0
718574	716561	20914V	PARTICIPANT	\N	PRESENT	0
718579	716561	14229S	PARTICIPANT	\N	PRESENT	0
718621	716561	05012A	PARTICIPANT	\N	PRESENT	0
725092	722797	20100N	PARTICIPANT	\N	PRESENT	0
725093	722797	12041X	PARTICIPANT	\N	PRESENT	0
725094	722797	14151M	PARTICIPANT	\N	PRESENT	0
725095	722797	19599P	PARTICIPANT	\N	PRESENT	0
725096	722797	14215L	PARTICIPANT	\N	PRESENT	0
725097	722797	14053L	PARTICIPANT	\N	PRESENT	0
725098	722797	20110Q	PARTICIPANT	\N	PRESENT	0
725099	722797	20066E	PARTICIPANT	\N	PRESENT	0
725100	722797	19699S	PARTICIPANT	\N	PRESENT	0
725101	722797	14073Q	PARTICIPANT	\N	PRESENT	0
725102	722797	19826F	PARTICIPANT	\N	PRESENT	0
725103	722797	19563B	PARTICIPANT	\N	PRESENT	0
725104	722797	20090E	PARTICIPANT	\N	PRESENT	0
725105	722797	20032T	PARTICIPANT	\N	PRESENT	0
725106	722797	11043H	PARTICIPANT	\N	PRESENT	0
725107	722797	19399H	PARTICIPANT	\N	PRESENT	0
725108	722797	14191V	PARTICIPANT	\N	PRESENT	0
725109	722797	20026V	PARTICIPANT	\N	PRESENT	0
725110	722797	19693L	PARTICIPANT	\N	PRESENT	0
725111	722797	20056C	PARTICIPANT	\N	PRESENT	0
725112	722797	19798U	PARTICIPANT	\N	PRESENT	0
725113	722797	19747H	PARTICIPANT	\N	PRESENT	0
725114	722797	08061X	PARTICIPANT	\N	PRESENT	0
725115	722797	19301E	PARTICIPANT	\N	PRESENT	0
725116	722797	20132W	PARTICIPANT	\N	PRESENT	0
725117	722797	11012A	PARTICIPANT	\N	PRESENT	0
725118	722797	20024T	PARTICIPANT	\N	PRESENT	0
725119	722797	14030Q	PARTICIPANT	\N	PRESENT	0
725120	722797	19569H	PARTICIPANT	\N	PRESENT	0
725121	722797	14231L	PARTICIPANT	\N	PRESENT	0
725122	722797	19335Q	PARTICIPANT	\N	PRESENT	0
725123	722797	19741B	PARTICIPANT	\N	PRESENT	0
725124	722797	19479G	PARTICIPANT	\N	PRESENT	0
725125	722797	14021P	PARTICIPANT	\N	PRESENT	0
725126	722797	20124W	PARTICIPANT	\N	PRESENT	0
725156	722798	19599P	PARTICIPANT	\N	PRESENT	0
725157	722798	19866P	PARTICIPANT	\N	PRESENT	0
725158	722798	20106U	PARTICIPANT	\N	PRESENT	0
725090	722797	95063L	PARTICIPANT	\N	PRESENT	0
725091	722797	20264J	PARTICIPANT	\N	PRESENT	0
725159	722798	14030Q	PARTICIPANT	\N	PRESENT	0
725160	722798	19798U	PARTICIPANT	\N	PRESENT	0
725161	722798	20056C	PARTICIPANT	\N	PRESENT	0
725162	722798	20026V	PARTICIPANT	\N	PRESENT	0
725163	722798	20066E	PARTICIPANT	\N	PRESENT	0
725164	722798	20032T	PARTICIPANT	\N	PRESENT	0
725165	722798	19954N	PARTICIPANT	\N	PRESENT	0
725166	722798	07029T	PARTICIPANT	\N	PRESENT	0
725167	722798	18083K	PARTICIPANT	\N	PRESENT	0
725168	722798	20180F	PARTICIPANT	\N	PRESENT	0
725169	722798	20096L	PARTICIPANT	\N	PRESENT	0
725170	722798	20092G	PARTICIPANT	\N	PRESENT	0
725171	722798	19563B	PARTICIPANT	\N	PRESENT	0
725172	722798	01028R	PARTICIPANT	\N	PRESENT	0
725173	722798	19347U	PARTICIPANT	\N	PRESENT	0
725174	722798	19549D	PARTICIPANT	\N	PRESENT	0
725175	722798	14219Q	PARTICIPANT	\N	PRESENT	0
727805	725545	20106U	PARTICIPANT	\N	EXCUSE	0
727807	725545	20024T	PARTICIPANT	\N	EXCUSE	0
727808	725545	20080C	PARTICIPANT	\N	EXCUSE	0
727809	725545	20118Y	PARTICIPANT	\N	EXCUSE	0
727810	725545	20098N	PARTICIPANT	\N	EXCUSE	0
727814	725545	19599P	PARTICIPANT	\N	PRESENT	0
727815	725545	19798U	PARTICIPANT	\N	PRESENT	0
725154	722798	11070L	PARTICIPANT	\N	PRESENT	0
725155	722798	20100N	PARTICIPANT	\N	PRESENT	0
727816	725545	20066E	PARTICIPANT	\N	PRESENT	0
727817	725545	11031D	PARTICIPANT	\N	PRESENT	0
727818	725545	14030Q	PARTICIPANT	\N	PRESENT	0
727819	725545	11045K	PARTICIPANT	\N	PRESENT	0
727820	725545	07029T	PARTICIPANT	\N	EXCUSE	0
727939	727938	14097Y	PARTICIPANT	\N	PRESENT	0
728030	725634	19820Y	PARTICIPANT	\N	PRESENT	0
728031	725634	20914V	PARTICIPANT	\N	PRESENT	0
728032	725634	14229S	PARTICIPANT	\N	PRESENT	0
728033	725634	20094J	PARTICIPANT	\N	PRESENT	0
728034	725634	19745F	PARTICIPANT	\N	EXCUSE	0
728035	725634	05012A	PARTICIPANT	\N	EXCUSE	0
728036	725635	19820Y	PARTICIPANT	\N	PRESENT	0
728037	725635	20094J	PARTICIPANT	\N	PRESENT	0
728105	725810	19717B	PRESIDENT	0	PRESENT	0
728106	725810	97011G	PARTICIPANT	\N	PRESENT	0
728107	725810	19715Y	PARTICIPANT	\N	PRESENT	1
728108	725810	20146D	PARTICIPANT	\N	PRESENT	1
728109	725810	14030Q	PARTICIPANT	\N	PRESENT	0
728122	725809	04045F	PARTICIPANT	\N	EXCUSE	0
728131	725544	20034V	PARTICIPANT	\N	PRESENT	0
728134	728133	19569H	PARTICIPANT	\N	PRESENT	1
728135	728133	18193Q	PARTICIPANT	\N	PRESENT	1
728137	728136	18193Q	PARTICIPANT	\N	PRESENT	1
728138	728136	19569H	PARTICIPANT	\N	PRESENT	1
728179	728178	20064C	PRESIDENT	0	PRESENT	0
728181	728180	18193Q	PARTICIPANT	\N	PRESENT	1
728182	728180	19569H	PARTICIPANT	\N	PRESENT	1
729476	728141	20106U	PARTICIPANT	\N	PRESENT	0
729561	728901	19820Y	PARTICIPANT	\N	PRESENT	0
729562	728901	20104S	PARTICIPANT	\N	PRESENT	0
729564	728901	20076G	PARTICIPANT	\N	PRESENT	0
729565	728901	20078J	PARTICIPANT	\N	PRESENT	0
729566	728901	20046A	PARTICIPANT	\N	PRESENT	0
729567	728901	19387D	PARTICIPANT	\N	PRESENT	0
729568	728901	14237S	PARTICIPANT	\N	PRESENT	0
729569	728901	19745F	PARTICIPANT	\N	PRESENT	0
729573	728901	20094J	PARTICIPANT	\N	PRESENT	0
730236	728139	20024T	PRESIDENT	0	PRESENT	0
730237	728139	19369B	PARTICIPANT	\N	EXCUSE	0
730238	728139	20126Y	PARTICIPANT	\N	EXCUSE	0
730239	728139	20050V	PARTICIPANT	\N	EXCUSE	0
730240	728139	04045F	PARTICIPANT	\N	PRESENT	0
730241	728139	14026U	PARTICIPANT	\N	EXCUSE	0
730261	728139	17965H	PRESIDENT	1	PRESENT	0
730262	728139	11031D	PARTICIPANT	\N	PRESENT	0
730500	730498	20116W	PARTICIPANT	\N	PRESENT	0
730502	730498	11080N	PRESIDENT	0	PRESENT	0
730505	730498	01057W	PARTICIPANT	\N	PRESENT	0
730506	730498	14121F	PARTICIPANT	\N	PRESENT	0
730508	730507	19545Y	PARTICIPANT	\N	PRESENT	0
730509	730507	11080N	PRESIDENT	0	PRESENT	0
730510	730507	11074Q	PARTICIPANT	\N	PRESENT	0
730511	730507	01057W	PARTICIPANT	\N	PRESENT	0
730512	730507	14121F	PARTICIPANT	\N	PRESENT	0
730513	730507	19711U	PARTICIPANT	\N	PRESENT	0
730514	730507	05012A	PARTICIPANT	\N	PRESENT	0
730515	730507	19687N	PARTICIPANT	\N	PRESENT	0
730517	730516	20042V	PARTICIPANT	\N	PRESENT	0
730518	730516	19545Y	PARTICIPANT	\N	PRESENT	0
730519	730516	11080N	PRESIDENT	0	PRESENT	0
730520	730516	11074Q	PARTICIPANT	\N	PRESENT	0
730521	730516	01057W	PARTICIPANT	\N	PRESENT	0
730522	730516	14121F	PARTICIPANT	\N	PRESENT	0
730523	730516	19711U	PARTICIPANT	\N	PRESENT	0
730524	730516	05012A	PARTICIPANT	\N	PRESENT	0
730526	730525	14053L	PARTICIPANT	\N	PRESENT	0
730527	730525	19749K	PARTICIPANT	\N	PRESENT	0
730528	730525	19725B	PARTICIPANT	\N	PRESENT	0
730529	730525	19649G	PARTICIPANT	\N	PRESENT	0
730734	730733	11077T	PARTICIPANT	\N	PRESENT	0
730735	730733	14037X	PARTICIPANT	\N	PRESENT	0
730737	730736	11077T	PARTICIPANT	\N	PRESENT	0
730738	730736	14037X	PARTICIPANT	\N	PRESENT	0
730740	730739	11077T	PARTICIPANT	\N	PRESENT	0
730741	730739	14037X	PARTICIPANT	\N	PRESENT	0
730742	730739	14257W	PARTICIPANT	\N	PRESENT	0
730744	730743	95063L	PARTICIPANT	\N	PRESENT	0
730745	730743	19669L	PARTICIPANT	\N	PRESENT	0
730746	730743	11083R	PARTICIPANT	\N	PRESENT	0
730747	730743	14255U	PARTICIPANT	\N	PRESENT	0
730749	730748	19335Q	PARTICIPANT	\N	PRESENT	0
730750	730748	20106U	PARTICIPANT	\N	PRESENT	0
730751	730748	20980G	PARTICIPANT	\N	PRESENT	0
730752	730748	20038A	PARTICIPANT	\N	PRESENT	0
730798	730573	19725B	PARTICIPANT	\N	PRESENT	0
736690	736607	19383Y	PARTICIPANT	\N	PRESENT	0
736691	736607	19768N	PARTICIPANT	\N	PRESENT	0
736692	736607	19515S	PARTICIPANT	\N	PRESENT	0
736693	736607	19782L	PARTICIPANT	\N	PRESENT	0
736694	736607	20092G	PARTICIPANT	\N	PRESENT	0
736695	736607	11077T	PARTICIPANT	\N	PRESENT	0
736696	736607	01043Q	PARTICIPANT	\N	PRESENT	0
736697	736607	14357A	PARTICIPANT	\N	PRESENT	0
736698	736607	20078J	PARTICIPANT	\N	PRESENT	0
736699	736607	19441R	PARTICIPANT	\N	PRESENT	0
736700	736607	19413M	PARTICIPANT	\N	PRESENT	0
736701	736607	20094J	PARTICIPANT	\N	PRESENT	0
736702	736607	19866P	PARTICIPANT	\N	PRESENT	0
736703	736607	04045F	PARTICIPANT	\N	PRESENT	0
736704	736607	20104S	PARTICIPANT	\N	PRESENT	0
736705	736607	19631V	PARTICIPANT	\N	PRESENT	0
736706	736607	11099A	PARTICIPANT	\N	PRESENT	0
736707	736607	19705W	PARTICIPANT	\N	PRESENT	0
736708	736607	19707Y	PARTICIPANT	\N	PRESENT	0
736709	736607	08015R	PARTICIPANT	\N	PRESENT	0
736710	736607	19575F	PARTICIPANT	\N	PRESENT	0
736711	736607	19369B	PARTICIPANT	\N	PRESENT	0
736712	736607	19563B	PARTICIPANT	\N	PRESENT	0
736713	736607	14037X	PARTICIPANT	\N	PRESENT	0
736714	736607	20028X	PARTICIPANT	\N	PRESENT	0
736715	736607	20030R	PARTICIPANT	\N	PRESENT	0
736716	736607	14038Y	PARTICIPANT	\N	PRESENT	0
736717	736607	19467C	PARTICIPANT	\N	PRESENT	0
736718	736607	20034V	PARTICIPANT	\N	PRESENT	0
736719	736607	14187A	PARTICIPANT	\N	PRESENT	0
736720	736607	19695N	PARTICIPANT	\N	PRESENT	0
736721	736607	01025N	PARTICIPANT	\N	PRESENT	0
736722	736607	11090Q	PRESIDENT	0	PRESENT	0
736723	736607	14033T	PARTICIPANT	\N	PRESENT	0
736724	736607	20054A	PARTICIPANT	\N	PRESENT	0
736725	736607	14205J	PARTICIPANT	\N	PRESENT	0
736726	736607	20060X	PARTICIPANT	\N	PRESENT	0
736727	736607	14251Q	PARTICIPANT	\N	PRESENT	0
736728	736607	19507S	PARTICIPANT	\N	PRESENT	0
736729	736607	20286Q	PARTICIPANT	\N	PRESENT	0
736730	736607	20298U	PARTICIPANT	\N	PRESENT	0
736731	736607	19747H	PARTICIPANT	\N	PRESENT	0
736732	736607	14257W	PARTICIPANT	\N	PRESENT	0
736733	736607	14207L	PARTICIPANT	\N	EXCUSE	0
736734	736607	20018V	PARTICIPANT	\N	EXCUSE	0
736740	735293	20114U	PARTICIPANT	\N	PRESENT	0
736741	736593	14253S	PARTICIPANT	\N	PRESENT	0
736742	736593	19335Q	PARTICIPANT	\N	PRESENT	0
736774	736593	08034U	PARTICIPANT	\N	PRESENT	0
736781	735293	08018U	PARTICIPANT	\N	PRESENT	0
736782	736593	99004R	PARTICIPANT	\N	PRESENT	0
736791	735293	11033F	PARTICIPANT	\N	PRESENT	0
736792	735293	11085T	PARTICIPANT	\N	PRESENT	0
736793	735293	14021P	PARTICIPANT	\N	PRESENT	0
736795	736593	19667J	PARTICIPANT	\N	PRESENT	0
736796	736593	11012A	PARTICIPANT	\N	PRESENT	0
736797	736593	20044X	PARTICIPANT	\N	PRESENT	0
736810	735421	12041X	PARTICIPANT	\N	PRESENT	0
736811	735421	19565D	PARTICIPANT	\N	PRESENT	0
736812	735421	20072C	PARTICIPANT	\N	PRESENT	0
736813	735421	01058X	PARTICIPANT	\N	PRESENT	0
736814	735421	11027H	PARTICIPANT	\N	PRESENT	0
736815	735421	16685X	PARTICIPANT	\N	PRESENT	0
736816	735421	04042C	PRESIDENT	0	PRESENT	0
736817	735421	11054L	PARTICIPANT	\N	PRESENT	0
736818	735421	11066Q	PARTICIPANT	\N	PRESENT	0
736819	735421	08056B	PARTICIPANT	\N	PRESENT	0
736820	735421	12028B	PARTICIPANT	\N	PRESENT	0
736821	735421	14193X	PARTICIPANT	\N	PRESENT	0
736822	735421	19347U	PARTICIPANT	\N	PRESENT	0
736823	735421	97011G	PARTICIPANT	\N	PRESENT	0
736824	735421	08061X	PARTICIPANT	\N	PRESENT	0
736825	735421	14249W	PARTICIPANT	\N	PRESENT	0
736826	735421	08047A	PARTICIPANT	\N	PRESENT	0
736827	735421	20128B	PARTICIPANT	\N	PRESENT	0
736828	735421	14059S	PARTICIPANT	\N	PRESENT	0
736829	735421	14097Y	PARTICIPANT	\N	PRESENT	0
736830	735421	14133K	PARTICIPANT	\N	PRESENT	0
736831	735421	08069G	PARTICIPANT	\N	PRESENT	0
736832	735421	11041F	PARTICIPANT	\N	PRESENT	0
736833	735421	20042V	PARTICIPANT	\N	PRESENT	0
736834	735421	01024M	PARTICIPANT	\N	PRESENT	0
736835	735421	14191V	PARTICIPANT	\N	PRESENT	0
736836	735421	20064C	PARTICIPANT	\N	PRESENT	0
736837	735421	14267Y	PARTICIPANT	\N	PRESENT	0
736838	735421	11064N	PARTICIPANT	\N	PRESENT	0
736839	735421	11083R	PARTICIPANT	\N	PRESENT	0
736840	735421	19583F	PARTICIPANT	\N	PRESENT	0
736841	735421	14255U	PARTICIPANT	\N	PRESENT	0
736842	735421	17023S	PARTICIPANT	\N	PRESENT	0
736941	736608	19383Y	PARTICIPANT	\N	PRESENT	0
736942	736608	19768N	PARTICIPANT	\N	PRESENT	0
736943	736608	20088L	PARTICIPANT	\N	PRESENT	0
736944	736608	19515S	PARTICIPANT	\N	PRESENT	0
736945	736608	19782L	PARTICIPANT	\N	PRESENT	0
736946	736608	20092G	PARTICIPANT	\N	PRESENT	0
736947	736608	11077T	PARTICIPANT	\N	PRESENT	0
736948	736608	01043Q	PARTICIPANT	\N	PRESENT	0
736949	736608	14357A	PARTICIPANT	\N	PRESENT	0
736950	736608	20078J	PARTICIPANT	\N	PRESENT	0
736951	736608	19441R	PARTICIPANT	\N	PRESENT	0
736952	736608	19413M	PARTICIPANT	\N	PRESENT	0
736953	736608	20082E	PARTICIPANT	\N	PRESENT	0
736954	736608	20094J	PARTICIPANT	\N	PRESENT	0
736955	736608	19866P	PARTICIPANT	\N	PRESENT	0
736956	736608	04045F	PARTICIPANT	\N	PRESENT	0
736957	736608	20104S	PARTICIPANT	\N	PRESENT	0
736958	736608	19631V	PARTICIPANT	\N	PRESENT	0
736959	736608	11099A	PARTICIPANT	\N	PRESENT	0
736960	736608	19705W	PARTICIPANT	\N	PRESENT	0
736961	736608	19707Y	PARTICIPANT	\N	PRESENT	0
736962	736608	08015R	PARTICIPANT	\N	PRESENT	0
736963	736608	19575F	PARTICIPANT	\N	PRESENT	0
736964	736608	19369B	PARTICIPANT	\N	PRESENT	0
736965	736608	19563B	PARTICIPANT	\N	PRESENT	0
736966	736608	14037X	PARTICIPANT	\N	PRESENT	0
736967	736608	20028X	PARTICIPANT	\N	PRESENT	0
736968	736608	14329V	PARTICIPANT	\N	PRESENT	0
736969	736608	20030R	PARTICIPANT	\N	PRESENT	0
736970	736608	14038Y	PARTICIPANT	\N	PRESENT	0
736971	736608	19467C	PARTICIPANT	\N	PRESENT	0
736972	736608	20034V	PARTICIPANT	\N	PRESENT	0
736973	736608	14187A	PARTICIPANT	\N	PRESENT	0
736974	736608	19695N	PARTICIPANT	\N	PRESENT	0
736975	736608	01025N	PARTICIPANT	\N	PRESENT	0
736976	736608	11090Q	PRESIDENT	0	PRESENT	0
736977	736608	14033T	PARTICIPANT	\N	PRESENT	0
736978	736608	20054A	PARTICIPANT	\N	PRESENT	0
736979	736608	14205J	PARTICIPANT	\N	PRESENT	0
736980	736608	20060X	PARTICIPANT	\N	PRESENT	0
736981	736608	14251Q	PARTICIPANT	\N	PRESENT	0
736982	736608	19507S	PARTICIPANT	\N	PRESENT	0
736983	736608	20286Q	PARTICIPANT	\N	PRESENT	0
736984	736608	20298U	PARTICIPANT	\N	PRESENT	0
736985	736608	19747H	PARTICIPANT	\N	PRESENT	0
736986	736608	14257W	PARTICIPANT	\N	PRESENT	0
736987	736608	14207L	PARTICIPANT	\N	EXCUSE	0
736988	736608	20018V	PARTICIPANT	\N	EXCUSE	0
736994	735294	14089Y	PARTICIPANT	\N	PRESENT	0
736995	735294	14053L	PARTICIPANT	\N	PRESENT	0
736996	735294	19954N	PARTICIPANT	\N	PRESENT	0
736997	735294	20074E	PARTICIPANT	\N	PRESENT	0
736998	735294	20108W	PARTICIPANT	\N	PRESENT	0
736999	735294	10015M	PARTICIPANT	\N	PRESENT	0
737000	735294	20022R	PARTICIPANT	\N	PRESENT	0
737001	735294	04047H	PRESIDENT	0	PRESENT	0
737002	735294	19447X	PARTICIPANT	\N	PRESENT	0
737003	735294	05008E	PARTICIPANT	\N	PRESENT	0
737004	735294	19543W	PARTICIPANT	\N	PRESENT	0
737005	735294	14147R	PARTICIPANT	\N	PRESENT	0
737006	735294	04008A	PARTICIPANT	\N	PRESENT	0
737010	735294	14151M	PARTICIPANT	\N	PRESENT	0
737014	735294	11033F	PARTICIPANT	\N	PRESENT	0
737017	735294	14259Y	PARTICIPANT	\N	PRESENT	0
737018	735294	95063L	PARTICIPANT	\N	PRESENT	0
737019	735294	14215L	PARTICIPANT	\N	PRESENT	0
737020	735539	99004R	PARTICIPANT	\N	PRESENT	0
737024	735539	20068G	PARTICIPANT	\N	PRESENT	0
737025	735539	14259Y	PARTICIPANT	\N	PRESENT	0
737026	735539	20090E	PARTICIPANT	\N	PRESENT	0
737027	735539	20074E	PARTICIPANT	\N	PRESENT	0
712219	712217	20116W	PARTICIPANT	\N	PRESENT	0
712228	703566	20024T	PARTICIPANT	\N	PRESENT	0
712229	703566	20042V	PARTICIPANT	\N	PRESENT	0
712230	703566	20090E	PARTICIPANT	\N	PRESENT	0
712231	703566	14083S	PARTICIPANT	\N	PRESENT	0
712232	703566	11053K	PARTICIPANT	\N	PRESENT	0
712233	703566	14211G	PARTICIPANT	\N	PRESENT	0
712234	703566	19671E	PARTICIPANT	\N	PRESENT	0
712235	703566	19745F	PARTICIPANT	\N	PRESENT	0
712236	703566	14225N	PARTICIPANT	\N	PRESENT	0
712249	712248	14225N	PARTICIPANT	\N	PRESENT	0
712250	712248	11048N	PARTICIPANT	\N	PRESENT	0
717719	716257	20146D	PARTICIPANT	\N	EXCUSE	0
717728	715210	98022P	PARTICIPANT	\N	EXCUSE	0
717740	715211	98022P	PARTICIPANT	\N	EXCUSE	0
723364	722792	14205J	PARTICIPANT	\N	PRESENT	0
723365	722792	14231L	PARTICIPANT	\N	PRESENT	0
723366	722792	20062A	PARTICIPANT	\N	PRESENT	0
723367	722792	19703U	PARTICIPANT	\N	PRESENT	0
723368	722792	19711U	PARTICIPANT	\N	PRESENT	0
723426	722792	19735D	PARTICIPANT	\N	PRESENT	0
723370	722792	19747H	PARTICIPANT	\N	PRESENT	0
723371	722792	19643A	PARTICIPANT	\N	PRESENT	0
723372	722792	20138D	PARTICIPANT	\N	PRESENT	0
723373	722792	20034V	PARTICIPANT	\N	PRESENT	0
723427	722792	14217N	PARTICIPANT	\N	PRESENT	0
723375	722792	19399H	PARTICIPANT	\N	PRESENT	0
723376	722792	19673G	PARTICIPANT	\N	PRESENT	0
723377	722792	14173T	PARTICIPANT	\N	PRESENT	0
723378	722792	20140W	PARTICIPANT	\N	PRESENT	0
723379	722792	20980G	PARTICIPANT	\N	PRESENT	0
723362	722792	20054A	PARTICIPANT	\N	PRESENT	0
723363	722792	19421M	PARTICIPANT	\N	PRESENT	0
723380	722792	14229S	PARTICIPANT	\N	PRESENT	0
723383	722792	14257W	PARTICIPANT	\N	PRESENT	0
723384	722792	19749K	PARTICIPANT	\N	PRESENT	0
723385	722792	19611R	PARTICIPANT	\N	PRESENT	0
723386	722792	14133K	PARTICIPANT	\N	PRESENT	0
723387	722792	19741B	PARTICIPANT	\N	PRESENT	0
723388	722792	14069U	PARTICIPANT	\N	PRESENT	0
723389	722792	19349W	PARTICIPANT	\N	PRESENT	0
723390	722792	20052X	PARTICIPANT	\N	PRESENT	0
723428	722792	20090E	PARTICIPANT	\N	PRESENT	0
723392	722792	20082E	PARTICIPANT	\N	PRESENT	0
723393	722792	20026V	PARTICIPANT	\N	PRESENT	0
723394	722792	20180F	PARTICIPANT	\N	PRESENT	0
723429	722792	19563B	PARTICIPANT	\N	PRESENT	0
723396	722792	14123H	PARTICIPANT	\N	PRESENT	0
723397	722792	20136B	PARTICIPANT	\N	PRESENT	0
723398	722792	19507S	PARTICIPANT	\N	PRESENT	0
723399	722792	20086J	PARTICIPANT	\N	PRESENT	0
723400	722792	19527W	PARTICIPANT	\N	PRESENT	0
723401	722792	19383Y	PARTICIPANT	\N	PRESENT	0
723402	722792	11097X	PARTICIPANT	\N	PRESENT	0
723403	722792	20056C	PARTICIPANT	\N	PRESENT	0
723404	722792	14083S	PARTICIPANT	\N	PRESENT	0
723405	722791	19647E	PARTICIPANT	\N	PRESENT	0
723406	722791	14109K	PARTICIPANT	\N	PRESENT	0
723407	722791	11012A	PARTICIPANT	\N	PRESENT	0
723408	722791	98022P	PARTICIPANT	\N	PRESENT	0
723409	722791	19479G	PARTICIPANT	\N	PRESENT	0
723410	722791	14231L	PARTICIPANT	\N	PRESENT	0
723411	722791	19643A	PARTICIPANT	\N	PRESENT	0
723412	722791	19673G	PARTICIPANT	\N	PRESENT	0
723413	722791	20140W	PARTICIPANT	\N	PRESENT	0
723414	722791	14257W	PARTICIPANT	\N	PRESENT	0
723415	722791	19749K	PARTICIPANT	\N	PRESENT	0
723416	722791	14133K	PARTICIPANT	\N	PRESENT	0
723417	722791	19741B	PARTICIPANT	\N	PRESENT	0
723418	722791	19349W	PARTICIPANT	\N	PRESENT	0
723419	722791	20052X	PARTICIPANT	\N	PRESENT	0
723420	722791	14123H	PARTICIPANT	\N	PRESENT	0
723421	722791	20136B	PARTICIPANT	\N	PRESENT	0
723422	722791	20086J	PARTICIPANT	\N	PRESENT	0
723423	722791	11097X	PARTICIPANT	\N	PRESENT	0
723424	722791	14083S	PARTICIPANT	\N	PRESENT	0
723425	722792	19533U	PARTICIPANT	\N	PRESENT	0
723430	722792	14021P	PARTICIPANT	\N	PRESENT	0
723431	722792	14213J	PARTICIPANT	\N	PRESENT	0
723432	722792	19573D	PARTICIPANT	\N	PRESENT	0
723434	722792	01025N	PARTICIPANT	\N	PRESENT	0
723435	722792	20112S	PARTICIPANT	\N	PRESENT	0
723436	722792	19413M	PARTICIPANT	\N	PRESENT	0
723437	722792	19723Y	PARTICIPANT	\N	PRESENT	0
723438	722792	14071N	PARTICIPANT	\N	PRESENT	0
723439	722792	20058E	PARTICIPANT	\N	PRESENT	0
723440	722792	20038A	PARTICIPANT	\N	PRESENT	0
723441	722792	14147R	PARTICIPANT	\N	PRESENT	0
723442	722792	14033T	PARTICIPANT	\N	PRESENT	0
723443	722792	20098N	PARTICIPANT	\N	PRESENT	0
723505	722793	19647E	PARTICIPANT	\N	PRESENT	0
723506	722793	14109K	PARTICIPANT	\N	PRESENT	0
723507	722793	14229S	PARTICIPANT	\N	PRESENT	0
723508	722793	14021P	PARTICIPANT	\N	PRESENT	0
723509	722793	20142Y	PARTICIPANT	\N	PRESENT	0
723510	722793	14030Q	PARTICIPANT	\N	PRESENT	0
723511	722793	20090E	PARTICIPANT	\N	PRESENT	0
723512	722793	19798U	PARTICIPANT	\N	PRESENT	0
723513	722793	19533U	PARTICIPANT	\N	PRESENT	0
723514	722793	19651A	PARTICIPANT	\N	PRESENT	0
723515	722793	19611R	PARTICIPANT	\N	PRESENT	0
723516	722793	17367Q	PARTICIPANT	\N	PRESENT	0
723517	722793	20098N	PARTICIPANT	\N	PRESENT	0
723518	722793	20980G	PARTICIPANT	\N	PRESENT	0
723519	722793	19573D	PARTICIPANT	\N	PRESENT	0
723520	722793	20180F	PARTICIPANT	\N	PRESENT	0
723521	722793	19673G	PARTICIPANT	\N	PRESENT	0
723522	722793	20056C	PARTICIPANT	\N	PRESENT	0
723523	722793	19679N	PARTICIPANT	\N	PRESENT	0
723524	722793	20264J	PARTICIPANT	\N	PRESENT	0
723525	722793	19758L	PARTICIPANT	\N	PRESENT	0
723526	722793	20112S	PARTICIPANT	\N	PRESENT	0
723527	722793	19593H	PARTICIPANT	\N	PRESENT	0
723528	722793	14207L	PARTICIPANT	\N	PRESENT	0
723529	722793	20034V	PARTICIPANT	\N	PRESENT	0
723530	722793	20058E	PARTICIPANT	\N	PRESENT	0
723531	722793	20138D	PARTICIPANT	\N	PRESENT	0
723532	722793	20026V	PARTICIPANT	\N	PRESENT	0
723533	722793	14147R	PARTICIPANT	\N	PRESENT	0
723534	722793	20132W	PARTICIPANT	\N	PRESENT	0
723535	722793	01024M	PARTICIPANT	\N	PRESENT	0
723536	722793	01060R	PARTICIPANT	\N	PRESENT	0
723537	722793	20252E	PARTICIPANT	\N	PRESENT	0
723538	722793	20044X	PARTICIPANT	\N	PRESENT	0
723539	722793	19621T	PARTICIPANT	\N	PRESENT	0
723540	722793	19693L	PARTICIPANT	\N	PRESENT	0
723541	722793	14259Y	PARTICIPANT	\N	PRESENT	0
723542	722793	20124W	PARTICIPANT	\N	PRESENT	0
723543	722793	19415P	PARTICIPANT	\N	PRESENT	0
723544	722793	14215L	PARTICIPANT	\N	PRESENT	0
723545	722793	14083S	PARTICIPANT	\N	PRESENT	0
723546	722793	20086J	PARTICIPANT	\N	PRESENT	0
723547	722793	20022R	PARTICIPANT	\N	PRESENT	0
723548	722793	20024T	PARTICIPANT	\N	PRESENT	0
723549	722793	20116W	PARTICIPANT	\N	PRESENT	0
723550	722793	19563B	PARTICIPANT	\N	PRESENT	0
723551	722793	05012A	PARTICIPANT	\N	PRESENT	0
723552	722793	11104D	PARTICIPANT	\N	PRESENT	0
723553	722793	08061X	PARTICIPANT	\N	PRESENT	0
723554	722793	20038A	PARTICIPANT	\N	PRESENT	0
723555	722793	19399H	PARTICIPANT	\N	PRESENT	0
723556	722793	19735D	PARTICIPANT	\N	PRESENT	0
723557	722793	11097X	PARTICIPANT	\N	PRESENT	0
723558	722793	19643A	PARTICIPANT	\N	PRESENT	0
723559	722793	14213J	PARTICIPANT	\N	PRESENT	0
723560	722793	14187A	PARTICIPANT	\N	PRESENT	0
723561	722793	19507S	PARTICIPANT	\N	PRESENT	0
723562	722793	19553Y	PARTICIPANT	\N	PRESENT	0
723563	722793	19719D	PARTICIPANT	\N	PRESENT	0
723503	722793	14026U	PARTICIPANT	\N	PRESENT	0
723504	722793	14123H	PARTICIPANT	\N	PRESENT	0
723564	722793	19383Y	PARTICIPANT	\N	PRESENT	0
723565	722793	14071N	PARTICIPANT	\N	PRESENT	0
723566	722793	14133K	PARTICIPANT	\N	PRESENT	0
723567	722793	20048C	PARTICIPANT	\N	PRESENT	0
723568	722793	14073Q	PARTICIPANT	\N	PRESENT	0
723569	722793	20084G	PARTICIPANT	\N	PRESENT	0
723570	722793	19479G	PARTICIPANT	\N	PRESENT	0
723571	722793	20052X	PARTICIPANT	\N	PRESENT	0
723572	722793	20136B	PARTICIPANT	\N	PRESENT	0
723573	722793	20134Y	PARTICIPANT	\N	PRESENT	0
726268	726267	19515S	PARTICIPANT	\N	PRESENT	0
726446	725627	19798U	PARTICIPANT	\N	PRESENT	0
726449	725627	11031D	PARTICIPANT	\N	PRESENT	0
726450	725627	19329S	PARTICIPANT	\N	PRESENT	0
726451	725627	17965H	PARTICIPANT	\N	PRESENT	0
726452	725627	14026U	PARTICIPANT	\N	PRESENT	0
726453	725627	19569H	PARTICIPANT	\N	PRESENT	0
726454	725627	20248J	PARTICIPANT	\N	PRESENT	0
726455	725627	19713W	PARTICIPANT	\N	PRESENT	0
726456	725627	19760E	PARTICIPANT	\N	PRESENT	0
726457	726447	14331P	PARTICIPANT	\N	PRESENT	0
726458	726447	20252E	PARTICIPANT	\N	PRESENT	0
726459	725627	19723Y	PARTICIPANT	\N	PRESENT	0
726460	725627	19691J	PARTICIPANT	\N	PRESENT	0
726461	726447	11012A	PARTICIPANT	\N	PRESENT	0
726462	725627	11097X	PARTICIPANT	\N	PRESENT	0
726463	726447	08010L	PARTICIPANT	\N	PRESENT	0
726464	726447	19671E	PARTICIPANT	\N	PRESENT	0
726465	726447	20044X	PARTICIPANT	\N	PRESENT	0
726466	725627	14355X	PARTICIPANT	\N	PRESENT	0
726467	725627	17779H	PARTICIPANT	\N	EXCUSE	0
726468	726447	11040E	PARTICIPANT	\N	PRESENT	0
726469	726447	14327T	PARTICIPANT	\N	PRESENT	0
726470	726447	20070A	PARTICIPANT	\N	PRESENT	0
726471	726447	20116W	PARTICIPANT	\N	PRESENT	0
726472	726447	14173T	PARTICIPANT	\N	PRESENT	0
726473	726447	11048N	PARTICIPANT	\N	PRESENT	0
726474	723710	19593H	PARTICIPANT	\N	PRESENT	0
726475	723710	20138D	PARTICIPANT	\N	PRESENT	0
726476	723710	19611R	PRESIDENT	0	PRESENT	0
726477	723710	14123H	PARTICIPANT	\N	PRESENT	0
726478	723710	19693L	PARTICIPANT	\N	PRESENT	0
726479	723710	11104D	PARTICIPANT	\N	PRESENT	0
726480	723710	11043H	PARTICIPANT	\N	PRESENT	0
726481	723710	20124W	PARTICIPANT	\N	PRESENT	0
726482	723710	20152B	PARTICIPANT	\N	PRESENT	0
726483	723710	19758L	PARTICIPANT	\N	PRESENT	0
726484	723710	20026V	PARTICIPANT	\N	PRESENT	0
726485	723710	20058E	PARTICIPANT	\N	PRESENT	0
726486	725627	19679N	PARTICIPANT	\N	PRESENT	0
726487	726447	20080C	PARTICIPANT	\N	PRESENT	0
726488	726447	20050V	PARTICIPANT	\N	PRESENT	0
726489	726447	19349W	PARTICIPANT	\N	PRESENT	0
726490	726447	14121F	PARTICIPANT	\N	PRESENT	0
726491	726447	19687N	PARTICIPANT	\N	PRESENT	0
726492	726447	07029T	PARTICIPANT	\N	PRESENT	0
726493	726447	19647E	PARTICIPANT	\N	PRESENT	0
726494	726447	19479G	PARTICIPANT	\N	PRESENT	0
726495	726447	20036X	PARTICIPANT	\N	PRESENT	0
726496	726447	14225N	PARTICIPANT	\N	PRESENT	0
726497	726447	20914V	PARTICIPANT	\N	PRESENT	0
726498	723710	20132W	PARTICIPANT	\N	PRESENT	0
726499	723710	19651A	PARTICIPANT	\N	PRESENT	0
726500	723710	20142Y	PARTICIPANT	\N	PRESENT	0
726501	723710	20052X	PARTICIPANT	\N	PRESENT	0
726502	723710	14030Q	PARTICIPANT	\N	PRESENT	0
726503	723710	20056C	PARTICIPANT	\N	PRESENT	0
726504	723710	20180F	PARTICIPANT	\N	PRESENT	0
726505	723710	20264J	PARTICIPANT	\N	PRESENT	0
726506	723710	20112S	PARTICIPANT	\N	PRESENT	0
726507	726447	01057W	PARTICIPANT	\N	PRESENT	0
726508	726447	14189C	PARTICIPANT	\N	PRESENT	0
726509	726447	19531S	PARTICIPANT	\N	PRESENT	0
726510	723710	08012N	PARTICIPANT	\N	PRESENT	0
726511	723710	20980G	PARTICIPANT	\N	PRESENT	0
726512	726447	20126Y	PARTICIPANT	\N	PRESENT	0
726513	726447	08011M	PARTICIPANT	\N	PRESENT	0
726514	726447	19545Y	PARTICIPANT	\N	PRESENT	0
726515	726447	14253S	PARTICIPANT	\N	PRESENT	0
726516	726447	19335Q	PARTICIPANT	\N	PRESENT	0
726517	726447	19741B	PARTICIPANT	\N	PRESENT	0
726518	726447	11110B	PARTICIPANT	\N	PRESENT	0
726519	726447	08034U	PARTICIPANT	\N	PRESENT	0
726520	723710	04070G	PARTICIPANT	\N	PRESENT	0
726521	723710	20098N	PARTICIPANT	\N	PRESENT	0
726522	723710	20048C	PARTICIPANT	\N	PRESENT	0
726523	726447	20086J	PARTICIPANT	\N	PRESENT	0
726524	725627	19717B	PARTICIPANT	\N	PRESENT	0
726525	725627	20040T	PARTICIPANT	\N	PRESENT	0
726526	725627	08045X	PARTICIPANT	\N	PRESENT	0
726527	726447	19762G	PARTICIPANT	\N	PRESENT	0
726528	726448	14327T	PARTICIPANT	\N	PRESENT	0
726529	726448	20086J	PARTICIPANT	\N	PRESENT	0
726530	726448	14331P	PARTICIPANT	\N	PRESENT	0
726531	726448	19545Y	PARTICIPANT	\N	PRESENT	0
726532	726448	01057W	PARTICIPANT	\N	PRESENT	0
726533	726448	20080C	PARTICIPANT	\N	PRESENT	0
726534	726448	19671E	PARTICIPANT	\N	PRESENT	0
726535	726448	14225N	PRESIDENT	0	PRESENT	0
726581	726448	11074Q	PARTICIPANT	\N	PRESENT	0
726537	726448	07029T	PARTICIPANT	\N	PRESENT	0
726538	726448	19349W	PARTICIPANT	\N	PRESENT	0
726539	726448	08010L	PARTICIPANT	\N	PRESENT	0
726540	726448	20116W	PARTICIPANT	\N	PRESENT	0
726541	726448	14253S	PARTICIPANT	\N	PRESENT	0
726542	726448	19335Q	PARTICIPANT	\N	PRESENT	0
726543	726448	20126Y	PARTICIPANT	\N	PRESENT	0
726544	726448	11048N	PARTICIPANT	\N	PRESENT	0
726545	726448	19647E	PARTICIPANT	\N	PRESENT	0
726546	726448	19479G	PARTICIPANT	\N	PRESENT	0
726547	726448	20036X	PARTICIPANT	\N	PRESENT	0
726548	726448	14189C	PARTICIPANT	\N	PRESENT	0
726549	726448	19531S	PARTICIPANT	\N	PRESENT	0
726550	726448	08034U	PARTICIPANT	\N	PRESENT	0
726551	726448	19687N	PARTICIPANT	\N	PRESENT	0
726552	726448	20050V	PARTICIPANT	\N	PRESENT	0
726553	726448	08011M	PARTICIPANT	\N	PRESENT	0
726554	726448	20044X	PARTICIPANT	\N	PRESENT	0
726555	726448	14173T	PARTICIPANT	\N	PRESENT	0
726556	726448	11040E	PARTICIPANT	\N	PRESENT	0
726557	726448	11012A	PARTICIPANT	\N	PRESENT	0
726558	726448	20252E	PARTICIPANT	\N	PRESENT	0
726559	726448	20070A	PARTICIPANT	\N	PRESENT	0
726560	726448	14121F	PARTICIPANT	\N	PRESENT	0
726561	726448	19741B	PARTICIPANT	\N	PRESENT	0
726562	726448	20914V	PARTICIPANT	\N	PRESENT	0
726563	726448	99004R	PARTICIPANT	\N	PRESENT	0
726564	726448	19762G	PARTICIPANT	\N	PRESENT	0
726565	726448	11070L	PARTICIPANT	\N	PRESENT	0
726566	725627	19697Q	PARTICIPANT	\N	PRESENT	0
726570	725666	17737W	PARTICIPANT	\N	PRESENT	0
726571	725666	19629C	PARTICIPANT	\N	PRESENT	0
726572	725666	07004J	PARTICIPANT	\N	PRESENT	0
726573	725666	20108W	PARTICIPANT	\N	PRESENT	0
726574	725666	14107H	PARTICIPANT	\N	PRESENT	0
726575	725666	14179A	PARTICIPANT	\N	PRESENT	0
726576	725666	14259Y	PARTICIPANT	\N	PRESENT	0
726577	725666	11033F	PARTICIPANT	\N	PRESENT	0
726578	725666	19675J	PARTICIPANT	\N	PRESENT	0
726579	725666	14001X	PARTICIPANT	\N	EXCUSE	0
726580	725666	19581D	PARTICIPANT	\N	EXCUSE	0
726583	725666	19585H	PARTICIPANT	\N	PRESENT	0
726584	725666	04047H	PRESIDENT	0	PRESENT	0
726585	725666	14231L	PARTICIPANT	\N	PRESENT	0
726586	725666	05008E	PARTICIPANT	\N	PRESENT	0
726587	725666	19447X	PARTICIPANT	\N	PRESENT	0
726588	725666	19954N	PARTICIPANT	\N	PRESENT	0
726589	725666	19489J	PARTICIPANT	\N	PRESENT	0
726590	725666	20110Q	PARTICIPANT	\N	PRESENT	0
726591	725666	14147R	PARTICIPANT	\N	PRESENT	0
726592	725666	14215L	PARTICIPANT	\N	PRESENT	0
726593	725666	08018U	PARTICIPANT	\N	PRESENT	0
726594	725666	20022R	PARTICIPANT	\N	PRESENT	0
726595	725666	14053L	PARTICIPANT	\N	PRESENT	0
726596	725666	19649G	PARTICIPANT	\N	PRESENT	0
726597	725666	14111D	PARTICIPANT	\N	PRESENT	0
726598	725666	10015M	PARTICIPANT	\N	PRESENT	0
726599	725666	11026G	PARTICIPANT	\N	PRESENT	0
726600	725666	04085P	PARTICIPANT	\N	PRESENT	0
726601	725666	19725B	PARTICIPANT	\N	PRESENT	0
726602	725666	14089Y	PARTICIPANT	\N	PRESENT	0
726603	725666	19729F	PARTICIPANT	\N	PRESENT	0
726604	725666	95063L	PARTICIPANT	\N	PRESENT	0
726605	725666	14069U	PARTICIPANT	\N	PRESENT	0
726606	725666	04008A	PARTICIPANT	\N	PRESENT	0
726607	725666	19749K	PARTICIPANT	\N	PRESENT	0
726608	725666	11056N	PARTICIPANT	\N	PRESENT	0
726610	723710	14229S	PARTICIPANT	\N	PRESENT	0
726611	723710	19573D	PARTICIPANT	\N	PRESENT	0
726612	723710	19527W	PARTICIPANT	\N	PRESENT	0
712193	709156	20016T	PARTICIPANT	\N	EXCUSE	0
724724	724721	11085T	PARTICIPANT	\N	PRESENT	0
727107	727106	19515S	PARTICIPANT	\N	PRESENT	0
727108	727106	19575F	PARTICIPANT	\N	PRESENT	0
727109	727106	19782L	PARTICIPANT	\N	PRESENT	0
727110	727106	20090E	PARTICIPANT	\N	PRESENT	0
727111	727106	11101A	PARTICIPANT	\N	PRESENT	0
727112	727106	19467C	PARTICIPANT	\N	PRESENT	0
727113	727106	14357A	PARTICIPANT	\N	PRESENT	0
727114	727106	01024M	PARTICIPANT	\N	PRESENT	0
727115	727106	01025N	PARTICIPANT	\N	PRESENT	0
727116	727106	20128B	PARTICIPANT	\N	PRESENT	0
727117	727106	20126Y	PARTICIPANT	\N	PRESENT	0
727118	727106	08015R	PARTICIPANT	\N	PRESENT	0
727119	727106	19441R	PARTICIPANT	\N	PRESENT	0
727120	727106	20030R	PARTICIPANT	\N	PRESENT	0
727121	727106	19503N	PARTICIPANT	\N	PRESENT	0
727122	727106	11097X	PARTICIPANT	\N	PRESENT	0
727123	727106	04045F	PARTICIPANT	\N	PRESENT	0
727124	727106	95041E	PARTICIPANT	\N	PRESENT	0
728184	728183	11031D	PARTICIPANT	\N	PRESENT	0
728185	728183	20266L	PARTICIPANT	\N	PRESENT	0
728186	728183	17965H	PARTICIPANT	\N	PRESENT	0
728510	728189	01025N	PARTICIPANT	\N	PRESENT	0
728513	728189	19703U	PARTICIPANT	\N	PRESENT	0
728514	728189	19629C	PRESIDENT	0	PRESENT	0
728515	728189	14331P	PARTICIPANT	\N	PRESENT	0
728517	728189	14329V	PARTICIPANT	\N	PRESENT	0
728521	728189	11056N	PARTICIPANT	\N	PRESENT	0
728536	728189	14259Y	PARTICIPANT	\N	PRESENT	0
728537	728189	11110B	PARTICIPANT	\N	PRESENT	0
728538	728189	19489J	PARTICIPANT	\N	PRESENT	0
729434	726276	04059M	PARTICIPANT	\N	PRESENT	0
729435	726276	14030Q	PARTICIPANT	\N	PRESENT	0
729436	726276	19643A	PARTICIPANT	\N	PRESENT	0
729437	726276	19693L	PARTICIPANT	\N	PRESENT	0
729438	726276	19719D	PARTICIPANT	\N	PRESENT	0
729439	726276	20134Y	PARTICIPANT	\N	PRESENT	0
729440	726276	14123H	PARTICIPANT	\N	PRESENT	0
729441	726276	20048C	PARTICIPANT	\N	PRESENT	0
729442	726276	14109K	PARTICIPANT	\N	PRESENT	0
729443	726276	19593H	PARTICIPANT	\N	PRESENT	0
729444	726276	19533U	PARTICIPANT	\N	PRESENT	0
729445	726276	14229S	PARTICIPANT	\N	PRESENT	0
729446	726276	20058E	PARTICIPANT	\N	PRESENT	0
729477	728140	20138D	PRESIDENT	0	PRESENT	0
729478	728140	11031D	PARTICIPANT	\N	PRESENT	0
729479	728140	17965H	PARTICIPANT	\N	PRESENT	0
729480	728130	19717B	PRESIDENT	0	PRESENT	0
729481	728130	12016W	PARTICIPANT	\N	PRESENT	0
729482	728130	11072N	PARTICIPANT	\N	PRESENT	0
729483	728130	20034V	PARTICIPANT	\N	PRESENT	0
729484	728130	19577H	PARTICIPANT	\N	PRESENT	0
729485	728130	04035D	PARTICIPANT	\N	PRESENT	0
729486	728130	14237S	PARTICIPANT	\N	PRESENT	0
729487	728130	19701S	PARTICIPANT	\N	PRESENT	0
729488	728130	14089Y	PARTICIPANT	\N	PRESENT	0
729489	728130	08034U	PARTICIPANT	\N	PRESENT	0
729490	728130	11101A	PARTICIPANT	\N	PRESENT	0
729491	728130	14331P	PRESIDENT	1	PRESENT	0
729505	728140	20066E	PARTICIPANT	\N	PRESENT	0
729510	728130	20148F	PARTICIPANT	\N	PRESENT	0
729511	728130	14147R	PARTICIPANT	\N	PRESENT	0
729560	728130	20098N	PARTICIPANT	\N	PRESENT	0
729571	728130	11026G	PARTICIPANT	\N	PRESENT	0
729572	728130	18083K	PARTICIPANT	\N	PRESENT	0
729579	729578	11026G	PARTICIPANT	\N	PRESENT	0
729580	729578	19766L	PARTICIPANT	\N	PRESENT	0
729582	729581	04008A	PARTICIPANT	\N	PRESENT	0
729583	729581	11026G	PARTICIPANT	\N	PRESENT	0
729584	729581	19954N	PARTICIPANT	\N	PRESENT	0
729633	728140	20024T	PARTICIPANT	\N	EXCUSE	0
729634	728140	19369B	PARTICIPANT	\N	EXCUSE	0
729636	728140	20126Y	PARTICIPANT	\N	EXCUSE	0
729637	728140	20050V	PARTICIPANT	\N	EXCUSE	0
729639	728140	04045F	PARTICIPANT	\N	EXCUSE	0
729640	728140	14026U	PARTICIPANT	\N	EXCUSE	0
730442	728028	14109K	PARTICIPANT	\N	PRESENT	0
730445	728028	19798U	PARTICIPANT	\N	EXCUSE	0
730447	728028	14030Q	PARTICIPANT	\N	PRESENT	0
730449	728028	11045K	PARTICIPANT	\N	PRESENT	0
730450	728028	11031D	PARTICIPANT	\N	PRESENT	0
730451	728190	20148F	PARTICIPANT	\N	PRESENT	1
730452	728190	20146D	PARTICIPANT	\N	PRESENT	0
730453	728190	19717B	PRESIDENT	0	PRESENT	0
730454	728190	19515S	PARTICIPANT	\N	PRESENT	0
730455	728190	14083S	PARTICIPANT	\N	PRESENT	0
730456	728190	14059S	PARTICIPANT	\N	PRESENT	0
730457	728190	20034V	PARTICIPANT	\N	PRESENT	0
730467	728190	19691J	PARTICIPANT	\N	PRESENT	0
730469	728190	18083K	PARTICIPANT	\N	PRESENT	0
730471	728190	14147R	PARTICIPANT	\N	PRESENT	0
730533	725650	11097X	PARTICIPANT	\N	PRESENT	0
730534	725650	20130U	PARTICIPANT	\N	PRESENT	0
730535	725651	11097X	PARTICIPANT	\N	PRESENT	0
730536	725651	20130U	PARTICIPANT	\N	PRESENT	0
730537	725652	11097X	PARTICIPANT	\N	PRESENT	0
730538	725652	20130U	PARTICIPANT	\N	PRESENT	0
730539	725653	11097X	PARTICIPANT	\N	PRESENT	0
730540	725653	20130U	PARTICIPANT	\N	PRESENT	0
730593	729238	19735D	PARTICIPANT	\N	EXCUSE	0
730799	730573	19735D	PARTICIPANT	\N	PRESENT	0
730800	730573	17965H	PARTICIPANT	\N	PRESENT	0
730801	730573	11031D	PARTICIPANT	\N	PRESENT	0
730807	730573	14026U	PARTICIPANT	\N	PRESENT	0
730821	730573	20050V	PARTICIPANT	\N	PRESENT	0
730823	730573	14213J	PARTICIPANT	\N	PRESENT	0
730838	730573	20126Y	PARTICIPANT	\N	EXCUSE	0
730839	730573	20024T	PARTICIPANT	\N	EXCUSE	0
730871	730640	14001X	PARTICIPANT	\N	EXCUSE	0
730937	730757	20034V	PARTICIPANT	\N	PRESENT	0
731243	730732	14030Q	PARTICIPANT	\N	PRESENT	0
731244	730732	19693L	PARTICIPANT	\N	PRESENT	0
731245	730732	11045K	PARTICIPANT	\N	PRESENT	0
731247	730732	19599P	PARTICIPANT	\N	PRESENT	0
731278	730684	14169X	PARTICIPANT	\N	PRESENT	0
731279	730684	19768N	PARTICIPANT	\N	PRESENT	0
731282	730787	99004R	PARTICIPANT	\N	PRESENT	0
731329	730684	19479G	PARTICIPANT	\N	PRESENT	0
731285	730787	19479G	PARTICIPANT	\N	PRESENT	0
731286	730787	08010L	PARTICIPANT	\N	PRESENT	0
731287	730684	20058E	PARTICIPANT	\N	PRESENT	0
731293	730684	19533U	PARTICIPANT	\N	PRESENT	0
731297	730684	20120S	PARTICIPANT	\N	PRESENT	0
731303	730684	10015M	PARTICIPANT	\N	PRESENT	0
731314	730684	19954N	PARTICIPANT	\N	PRESENT	0
731316	730684	19866P	PARTICIPANT	\N	PRESENT	0
731317	730684	20116W	PARTICIPANT	\N	PRESENT	0
731318	730684	19349W	PARTICIPANT	\N	PRESENT	0
731325	730684	14219Q	PARTICIPANT	\N	PRESENT	0
731326	730684	11097X	PARTICIPANT	\N	PRESENT	0
731327	730684	20104S	PARTICIPANT	\N	PRESENT	0
731328	730684	20914V	PARTICIPANT	\N	PRESENT	0
731330	730684	14231L	PARTICIPANT	\N	PRESENT	0
731332	730684	19687N	PARTICIPANT	\N	PRESENT	0
731333	730684	11048N	PARTICIPANT	\N	PRESENT	0
731334	730684	14225N	PARTICIPANT	\N	PRESENT	0
731335	730684	04092N	PARTICIPANT	\N	PRESENT	0
731336	730684	14213J	PARTICIPANT	\N	PRESENT	0
731337	730684	19347U	PARTICIPANT	\N	PRESENT	0
734376	734375	19745F	PARTICIPANT	\N	PRESENT	0
734377	734375	20076G	PARTICIPANT	\N	PRESENT	0
734378	734375	20046A	PARTICIPANT	\N	PRESENT	0
734379	734375	05012A	PARTICIPANT	\N	EXCUSE	0
734386	734375	19387D	PARTICIPANT	\N	PRESENT	0
734438	734375	14237S	PARTICIPANT	\N	PRESENT	0
734439	734375	19768N	PARTICIPANT	\N	PRESENT	0
734440	734375	20094J	PARTICIPANT	\N	PRESENT	0
734441	734375	20914V	PARTICIPANT	\N	PRESENT	0
734442	734375	19820Y	PARTICIPANT	\N	PRESENT	0
735635	735632	19399H	PARTICIPANT	\N	PRESENT	0
735636	735632	04059M	PARTICIPANT	\N	PRESENT	0
735637	735633	19399H	PARTICIPANT	\N	PRESENT	0
735638	735634	19399H	PARTICIPANT	\N	PRESENT	0
736735	736674	04043D	PARTICIPANT	\N	PRESENT	0
736736	736679	04043D	PARTICIPANT	\N	PRESENT	0
736737	736680	04043D	PARTICIPANT	\N	PRESENT	0
737196	737121	04047H	PARTICIPANT	\N	PRESENT	0
737200	737121	14089Y	PARTICIPANT	\N	PRESENT	0
737202	737121	11056N	PARTICIPANT	\N	PRESENT	0
737946	737785	19762G	PARTICIPANT	\N	PRESENT	0
737947	737785	20018V	PARTICIPANT	\N	EXCUSE	0
737948	735545	20034V	PARTICIPANT	\N	PRESENT	0
737949	735545	19467C	PARTICIPANT	\N	PRESENT	0
737950	735546	95063L	PARTICIPANT	\N	PRESENT	0
738005	733710	97011G	PARTICIPANT	\N	PRESENT	0
738105	735546	20082E	PARTICIPANT	\N	PRESENT	0
738115	738112	14259Y	PARTICIPANT	\N	PRESENT	0
738116	738112	01028R	PARTICIPANT	\N	PRESENT	0
738117	738113	14259Y	PARTICIPANT	\N	PRESENT	0
738118	736304	20286Q	PARTICIPANT	\N	PRESENT	0
738110	736304	11070L	PARTICIPANT	\N	PRESENT	0
738114	738111	14259Y	PARTICIPANT	\N	PRESENT	0
738119	736304	19782L	PARTICIPANT	\N	PRESENT	0
738120	736304	20060X	PARTICIPANT	\N	PRESENT	0
738121	736304	19695N	PARTICIPANT	\N	PRESENT	0
738122	736304	14083S	PARTICIPANT	\N	PRESENT	0
738123	736304	20072C	PARTICIPANT	\N	PRESENT	0
738124	736304	11090Q	PARTICIPANT	\N	PRESENT	0
738125	736304	19583F	PARTICIPANT	\N	PRESENT	0
738126	736304	20092G	PARTICIPANT	\N	PRESENT	0
738128	738103	04043D	PARTICIPANT	\N	PRESENT	0
738129	738102	04043D	PARTICIPANT	\N	PRESENT	0
738048	738045	19782L	PARTICIPANT	\N	PRESENT	0
738049	738045	14357A	PRESIDENT	0	PRESENT	0
738050	738045	11053K	PARTICIPANT	\N	PRESENT	0
738051	738045	14207L	PARTICIPANT	\N	PRESENT	0
738052	738045	20084G	PARTICIPANT	\N	PRESENT	0
738053	738045	11097X	PARTICIPANT	\N	PRESENT	0
738054	738045	19575F	PARTICIPANT	\N	PRESENT	0
738130	738104	04043D	PARTICIPANT	\N	PRESENT	0
738056	738045	14237S	PARTICIPANT	\N	PRESENT	0
738057	738045	20092G	PARTICIPANT	\N	PRESENT	0
738131	738104	01034P	PARTICIPANT	\N	PRESENT	0
738132	738102	01034P	PARTICIPANT	\N	PRESENT	0
738133	738127	04043D	PARTICIPANT	\N	PRESENT	0
738134	738127	01034P	PARTICIPANT	\N	PRESENT	0
738135	736304	19711U	PARTICIPANT	\N	PRESENT	0
738064	735546	20052X	PARTICIPANT	\N	PRESENT	0
738065	735546	20034V	PARTICIPANT	\N	PRESENT	0
738066	735546	20024T	PARTICIPANT	\N	PRESENT	0
738067	735546	97011G	PARTICIPANT	\N	PRESENT	0
738068	735546	20100N	PARTICIPANT	\N	PRESENT	0
738069	735546	14327T	PARTICIPANT	\N	PRESENT	0
738070	735546	08073C	PARTICIPANT	\N	PRESENT	0
738071	735546	05012A	PARTICIPANT	\N	PRESENT	0
738072	735546	20080C	PARTICIPANT	\N	PRESENT	0
738073	735546	20042V	PARTICIPANT	\N	PRESENT	0
738074	735546	19669L	PARTICIPANT	\N	PRESENT	0
738075	735546	20030R	PARTICIPANT	\N	PRESENT	0
738076	735546	20066E	PARTICIPANT	\N	PRESENT	0
738077	735546	20126Y	PARTICIPANT	\N	PRESENT	0
738078	735546	20914V	PARTICIPANT	\N	PRESENT	0
738079	735546	14097Y	PARTICIPANT	\N	PRESENT	0
738080	735546	19467C	PARTICIPANT	\N	PRESENT	0
738081	735546	20980G	PARTICIPANT	\N	PRESENT	0
738082	735546	14237S	PARTICIPANT	\N	PRESENT	0
738083	735546	14107H	PARTICIPANT	\N	PRESENT	0
738087	735546	20022R	PARTICIPANT	\N	PRESENT	0
738088	735546	19553Y	PARTICIPANT	\N	PRESENT	0
738089	735546	14069U	PARTICIPANT	\N	PRESENT	0
738090	735546	20068G	PARTICIPANT	\N	PRESENT	0
738091	735546	07004J	PARTICIPANT	\N	PRESENT	0
738092	735546	14073Q	PARTICIPANT	\N	PRESENT	0
738093	735546	14031R	PARTICIPANT	\N	PRESENT	0
738094	735546	04070G	PARTICIPANT	\N	PRESENT	0
738095	735546	19768N	PARTICIPANT	\N	PRESENT	0
738096	735546	20098N	PARTICIPANT	\N	PRESENT	0
738097	735546	04043D	PARTICIPANT	\N	PRESENT	0
738101	735546	14089Y	PARTICIPANT	\N	PRESENT	0
738136	733712	14059S	PRESIDENT	0	PRESENT	0
738137	733712	97011G	PARTICIPANT	\N	PRESENT	0
738138	733712	08034U	PARTICIPANT	\N	PRESENT	0
738139	733712	20034V	PARTICIPANT	\N	PRESENT	0
738140	736304	19515S	PARTICIPANT	\N	PRESENT	0
738141	736304	20134Y	PARTICIPANT	\N	PRESENT	0
738142	733712	11072N	PARTICIPANT	\N	PRESENT	1
738143	736304	20100N	PARTICIPANT	\N	PRESENT	0
738144	736304	11083R	PARTICIPANT	\N	PRESENT	0
738145	736304	14026U	PARTICIPANT	\N	PRESENT	0
738148	736304	20130U	PARTICIPANT	\N	PRESENT	0
738149	736304	20264J	PARTICIPANT	\N	PRESENT	0
738150	736304	19669L	PARTICIPANT	\N	PRESENT	0
737898	737785	19820Y	PARTICIPANT	\N	PRESENT	0
737899	737785	01028R	PARTICIPANT	\N	PRESENT	0
737900	737785	20024T	PARTICIPANT	\N	PRESENT	0
737901	737785	14038Y	PARTICIPANT	\N	PRESENT	0
737902	737785	20030R	PARTICIPANT	\N	PRESENT	0
737903	737785	20034V	PARTICIPANT	\N	PRESENT	0
737904	737785	20038A	PARTICIPANT	\N	PRESENT	0
737905	737785	20050V	PARTICIPANT	\N	PRESENT	0
737906	737785	11090Q	PRESIDENT	0	PRESENT	0
737907	737785	20046A	PARTICIPANT	\N	PRESENT	0
737908	737785	20054A	PARTICIPANT	\N	PRESENT	0
737909	737785	14083S	PARTICIPANT	\N	PRESENT	0
737910	737785	20062A	PARTICIPANT	\N	PRESENT	0
737911	737785	11012A	PARTICIPANT	\N	PRESENT	0
737912	737785	20068G	PARTICIPANT	\N	PRESENT	0
737913	737785	14207L	PARTICIPANT	\N	PRESENT	0
737914	737785	14257W	PARTICIPANT	\N	PRESENT	0
737915	737785	20086J	PARTICIPANT	\N	PRESENT	0
737916	737785	20092G	PARTICIPANT	\N	PRESENT	0
737917	737785	19701S	PARTICIPANT	\N	PRESENT	0
737918	737785	01043Q	PARTICIPANT	\N	PRESENT	0
737919	737785	14357A	PARTICIPANT	\N	PRESENT	0
737920	737785	19413M	PARTICIPANT	\N	PRESENT	0
737921	737785	20080C	PARTICIPANT	\N	PRESENT	0
737922	737785	20082E	PARTICIPANT	\N	PRESENT	0
737923	737785	20094J	PARTICIPANT	\N	PRESENT	0
737924	737785	04045F	PARTICIPANT	\N	PRESENT	0
737925	737785	19599P	PARTICIPANT	\N	PRESENT	0
737926	737785	14225N	PARTICIPANT	\N	PRESENT	0
737927	737785	18083K	PARTICIPANT	\N	PRESENT	0
737928	737785	14107H	PARTICIPANT	\N	PRESENT	0
737929	737785	19503N	PARTICIPANT	\N	PRESENT	0
737930	737785	19575F	PARTICIPANT	\N	PRESENT	0
737931	737785	08010L	PARTICIPANT	\N	PRESENT	0
737932	737785	19369B	PARTICIPANT	\N	PRESENT	0
737933	737785	20126Y	PARTICIPANT	\N	PRESENT	0
737934	737785	19467C	PARTICIPANT	\N	PRESENT	0
737935	737785	19711U	PARTICIPANT	\N	PRESENT	0
737936	737785	14031R	PARTICIPANT	\N	PRESENT	0
737937	737785	20140W	PARTICIPANT	\N	PRESENT	0
737938	737785	14033T	PARTICIPANT	\N	PRESENT	0
737939	737785	14205J	PARTICIPANT	\N	PRESENT	0
737940	737785	11056N	PARTICIPANT	\N	PRESENT	0
737941	737785	20286Q	PARTICIPANT	\N	PRESENT	0
737942	737785	20298U	PARTICIPANT	\N	PRESENT	0
737943	737785	19745F	PARTICIPANT	\N	PRESENT	0
737944	737785	19747H	PARTICIPANT	\N	PRESENT	0
737945	737785	19619A	PARTICIPANT	\N	PRESENT	0
711452	708188	20066E	PARTICIPANT	\N	PRESENT	0
711453	708188	11090Q	PARTICIPANT	\N	PRESENT	0
711454	708188	17637T	PARTICIPANT	\N	PRESENT	0
711455	708188	04043D	PARTICIPANT	\N	PRESENT	0
711456	708188	19699S	PARTICIPANT	\N	PRESENT	0
711457	708188	14331P	PARTICIPANT	\N	PRESENT	0
711458	708188	14038Y	PARTICIPANT	\N	PRESENT	0
711459	708188	20286Q	PARTICIPANT	\N	PRESENT	0
711460	708188	19611R	PARTICIPANT	\N	PRESENT	0
711461	708188	20068G	PARTICIPANT	\N	PRESENT	0
711462	708188	20092G	PARTICIPANT	\N	PRESENT	0
711463	708188	20070A	PARTICIPANT	\N	PRESENT	0
711464	708188	19599P	PARTICIPANT	\N	PRESENT	0
711465	708188	11065P	PARTICIPANT	\N	PRESENT	0
711466	708188	11054L	PARTICIPANT	\N	PRESENT	0
711467	708188	19489J	PARTICIPANT	\N	PRESENT	0
711468	708188	20052X	PARTICIPANT	\N	PRESENT	0
711469	708188	20018V	PARTICIPANT	\N	PRESENT	0
711473	708188	20104S	PARTICIPANT	\N	PRESENT	0
711474	708188	14251Q	PARTICIPANT	\N	PRESENT	0
711475	708188	01048V	PARTICIPANT	\N	PRESENT	0
711477	708188	20914V	PARTICIPANT	\N	PRESENT	0
711478	708188	14257W	PARTICIPANT	\N	PRESENT	0
711479	708188	20108W	PARTICIPANT	\N	PRESENT	0
711480	708188	11012A	PARTICIPANT	\N	PRESENT	0
711481	708188	14249W	PARTICIPANT	\N	PRESENT	0
711482	708188	14111D	PARTICIPANT	\N	PRESENT	0
711483	708188	19669L	PARTICIPANT	\N	PRESENT	0
711484	708188	19719D	PARTICIPANT	\N	PRESENT	0
711485	708188	20114U	PARTICIPANT	\N	PRESENT	0
711486	708188	14033T	PARTICIPANT	\N	PRESENT	0
711487	708188	08034U	PARTICIPANT	\N	PRESENT	0
711488	708188	05008E	PARTICIPANT	\N	PRESENT	0
711489	708188	14189C	PARTICIPANT	\N	PRESENT	0
711490	708188	19553Y	PARTICIPANT	\N	PRESENT	0
711491	708188	19591F	PARTICIPANT	\N	PRESENT	0
711492	708188	14109K	PARTICIPANT	\N	PRESENT	0
711493	708188	14357A	PARTICIPANT	\N	PRESENT	0
711627	708191	14042U	PARTICIPANT	\N	PRESENT	0
711629	708191	10006L	PARTICIPANT	\N	PRESENT	0
711635	708191	11097X	PARTICIPANT	\N	PRESENT	0
711640	708191	14026U	PARTICIPANT	\N	PRESENT	0
711646	708191	11090Q	PARTICIPANT	\N	PRESENT	0
711647	708191	20054A	PARTICIPANT	\N	PRESENT	0
711648	708191	19798U	PARTICIPANT	\N	PRESENT	0
711649	708191	19701S	PARTICIPANT	\N	PRESENT	0
711650	708191	10015M	PARTICIPANT	\N	PRESENT	0
711651	708191	20078J	PARTICIPANT	\N	PRESENT	0
711652	708191	08045X	PARTICIPANT	\N	PRESENT	0
711653	708191	11054L	PARTICIPANT	\N	PRESENT	0
711654	708191	19745F	PARTICIPANT	\N	PRESENT	0
711655	708191	19713W	PARTICIPANT	\N	PRESENT	0
711656	708191	99004R	PARTICIPANT	\N	PRESENT	0
711657	708191	19569H	PARTICIPANT	\N	PRESENT	0
711658	708191	20064C	PARTICIPANT	\N	PRESENT	0
711659	708191	19413M	PARTICIPANT	\N	PRESENT	0
711660	708191	19593H	PARTICIPANT	\N	PRESENT	0
711661	708191	19866P	PARTICIPANT	\N	PRESENT	0
711662	708191	14207L	PARTICIPANT	\N	PRESENT	0
711663	708191	04057K	PARTICIPANT	\N	PRESENT	0
711664	708191	14231L	PARTICIPANT	\N	PRESENT	0
711665	708191	08034U	PARTICIPANT	\N	PRESENT	0
711666	708191	20024T	PARTICIPANT	\N	PRESENT	0
711667	708191	19251M	PARTICIPANT	\N	PRESENT	0
711669	708191	11031D	PARTICIPANT	\N	PRESENT	0
711670	708191	11067R	PARTICIPANT	\N	PRESENT	0
711671	708191	19333N	PARTICIPANT	\N	PRESENT	0
711672	708191	20060X	PARTICIPANT	\N	PRESENT	0
711673	708191	19599P	PARTICIPANT	\N	PRESENT	0
711674	708191	11045K	PARTICIPANT	\N	PRESENT	0
711675	708191	19683J	PARTICIPANT	\N	PRESENT	0
711676	708191	17965H	PARTICIPANT	\N	PRESENT	0
711677	708191	14259Y	PARTICIPANT	\N	PRESENT	0
711678	708191	11110B	PARTICIPANT	\N	PRESENT	0
711679	708191	20130U	PARTICIPANT	\N	PRESENT	0
711680	708191	18083K	PARTICIPANT	\N	PRESENT	0
711681	708191	19667J	PARTICIPANT	\N	PRESENT	0
711682	708191	19611R	PARTICIPANT	\N	PRESENT	0
711683	708191	20034V	PARTICIPANT	\N	PRESENT	0
711684	708191	18193Q	PARTICIPANT	\N	PRESENT	0
711685	708191	14281W	PARTICIPANT	\N	PRESENT	0
711686	708191	20062A	PARTICIPANT	\N	PRESENT	0
711687	708191	19527W	PARTICIPANT	\N	PRESENT	0
711688	708191	19826F	PARTICIPANT	\N	PRESENT	0
711689	708191	20046A	PARTICIPANT	\N	PRESENT	0
711690	708191	14071N	PARTICIPANT	\N	PRESENT	0
711692	708191	04043D	PARTICIPANT	\N	PRESENT	0
711693	708191	04092N	PARTICIPANT	\N	PRESENT	0
711694	708191	14030Q	PARTICIPANT	\N	PRESENT	0
711695	708191	17779H	PARTICIPANT	\N	PRESENT	0
711696	708191	19621T	PARTICIPANT	\N	PRESENT	0
711697	708191	11101A	PARTICIPANT	\N	PRESENT	0
711698	708191	14097Y	PARTICIPANT	\N	PRESENT	0
711699	708191	19515S	PARTICIPANT	\N	PRESENT	0
711700	708191	20914V	PARTICIPANT	\N	PRESENT	0
711701	708191	19747H	PARTICIPANT	\N	PRESENT	0
711702	708191	14251Q	PARTICIPANT	\N	PRESENT	0
711703	708191	19729F	PARTICIPANT	\N	PRESENT	0
711704	708191	19675J	PARTICIPANT	\N	PRESENT	0
711705	708191	19657G	PARTICIPANT	\N	PRESENT	0
711706	708191	19347U	PARTICIPANT	\N	PRESENT	0
711707	708191	19711U	PARTICIPANT	\N	PRESENT	0
711708	708191	11012A	PARTICIPANT	\N	PRESENT	0
711709	708191	14253S	PARTICIPANT	\N	PRESENT	0
711710	708191	14211G	PARTICIPANT	\N	PRESENT	0
711711	708191	19553Y	PARTICIPANT	\N	PRESENT	0
711712	708191	20100N	PARTICIPANT	\N	PRESENT	0
711713	708191	08028W	PARTICIPANT	\N	PRESENT	0
711714	708191	20122U	PARTICIPANT	\N	PRESENT	0
711715	708191	19573D	PARTICIPANT	\N	PRESENT	0
711716	708191	05008E	PARTICIPANT	\N	PRESENT	0
711717	708191	19367Y	PARTICIPANT	\N	PRESENT	0
711718	708191	14213J	PARTICIPANT	\N	PRESENT	0
711719	708191	14123H	PARTICIPANT	\N	PRESENT	0
711720	708191	19687N	PARTICIPANT	\N	PRESENT	0
711721	708191	01034P	PARTICIPANT	\N	PRESENT	0
711722	708191	19489J	PARTICIPANT	\N	PRESENT	0
711723	708191	14217N	PARTICIPANT	\N	PRESENT	0
711724	708191	20104S	PARTICIPANT	\N	PRESENT	0
711725	708191	20136B	PARTICIPANT	\N	PRESENT	0
711726	708191	20026V	PARTICIPANT	\N	PRESENT	0
711727	708191	14033T	PARTICIPANT	\N	PRESENT	0
711728	708191	14151M	PARTICIPANT	\N	PRESENT	0
711729	708191	19467C	PARTICIPANT	\N	PRESENT	0
711730	708191	20038A	PARTICIPANT	\N	PRESENT	0
711731	708191	05012A	PARTICIPANT	\N	PRESENT	0
711732	708191	14357A	PARTICIPANT	\N	PRESENT	0
711733	708191	97011G	PARTICIPANT	\N	PRESENT	0
711734	708191	14083S	PARTICIPANT	\N	PRESENT	0
711735	708191	20266L	PARTICIPANT	\N	PRESENT	0
711736	708191	01024M	PARTICIPANT	\N	PRESENT	0
711737	708191	20092G	PARTICIPANT	\N	PRESENT	0
711738	708191	19575F	PARTICIPANT	\N	PRESENT	0
711740	708191	16685X	PARTICIPANT	\N	PRESENT	0
711741	708191	04033B	PARTICIPANT	\N	PRESENT	0
711742	708191	14187A	PARTICIPANT	\N	PRESENT	0
711743	708191	01048V	PARTICIPANT	\N	PRESENT	0
711744	708191	19693L	PARTICIPANT	\N	PRESENT	0
711745	708191	20084G	PARTICIPANT	\N	PRESENT	0
711746	708191	20102Q	PARTICIPANT	\N	PRESENT	0
711747	708191	20076G	PARTICIPANT	\N	PRESENT	0
711748	708191	20094J	PARTICIPANT	\N	PRESENT	0
711749	708191	20030R	PARTICIPANT	\N	PRESENT	0
711750	708191	20040T	PARTICIPANT	\N	PRESENT	0
711751	708191	14069U	PARTICIPANT	\N	PRESENT	0
711752	708191	20052X	PARTICIPANT	\N	PRESENT	0
711753	708191	19479G	PARTICIPANT	\N	PRESENT	0
711754	708191	12041X	PARTICIPANT	\N	PRESENT	0
711755	708191	20286Q	PARTICIPANT	\N	PRESENT	0
711756	708191	20042V	PARTICIPANT	\N	PRESENT	0
711757	708191	12028B	PARTICIPANT	\N	PRESENT	0
711758	708191	20132W	PARTICIPANT	\N	PRESENT	0
711759	708191	19699S	PARTICIPANT	\N	PRESENT	0
711760	708191	19669L	PARTICIPANT	\N	PRESENT	0
711761	708191	14031R	PARTICIPANT	\N	PRESENT	0
711621	708191	20090E	PARTICIPANT	\N	PRESENT	0
711762	708191	20252E	PARTICIPANT	\N	PRESENT	0
711763	708191	20108W	PARTICIPANT	\N	PRESENT	0
726251	726250	08034U	PARTICIPANT	\N	PRESENT	0
726613	723710	14073Q	PARTICIPANT	\N	PRESENT	0
726614	723710	20172F	PARTICIPANT	\N	PRESENT	0
726615	723710	19735D	PARTICIPANT	\N	PRESENT	0
726627	725546	18083K	PARTICIPANT	\N	PRESENT	0
726628	725546	08060W	PARTICIPANT	\N	PRESENT	0
726629	725546	20076G	PARTICIPANT	\N	PRESENT	0
726630	725546	20140W	PARTICIPANT	\N	PRESENT	0
726631	725546	20020P	PARTICIPANT	\N	PRESENT	0
726632	725546	14219Q	PARTICIPANT	\N	PRESENT	0
726633	725546	20046A	PARTICIPANT	\N	PRESENT	0
726634	725546	19826F	PARTICIPANT	\N	PRESENT	0
726635	725546	20102Q	PARTICIPANT	\N	PRESENT	0
726636	725546	19637C	PARTICIPANT	\N	PRESENT	0
726637	725546	14169X	PARTICIPANT	\N	PRESENT	0
726638	725546	19333N	PARTICIPANT	\N	PRESENT	0
726639	725546	20038A	PARTICIPANT	\N	PRESENT	0
726640	723710	20134Y	PARTICIPANT	\N	PRESENT	0
726641	723710	04059M	PARTICIPANT	\N	PRESENT	0
726643	725546	20032T	PARTICIPANT	\N	PRESENT	0
726644	725546	19549D	PARTICIPANT	\N	PRESENT	0
726645	725546	19820Y	PARTICIPANT	\N	PRESENT	0
726646	725546	19599P	PARTICIPANT	\N	PRESENT	0
726647	725546	17229F	PARTICIPANT	\N	PRESENT	0
726648	725546	19503N	PARTICIPANT	\N	PRESENT	0
726649	725546	19745F	PARTICIPANT	\N	PRESENT	0
726650	725546	14031R	PARTICIPANT	\N	PRESENT	0
726651	725546	05012A	PARTICIPANT	\N	PRESENT	0
726652	725546	19681G	PARTICIPANT	\N	PRESENT	0
726653	725546	17367Q	PARTICIPANT	\N	PRESENT	0
726654	725546	20024T	PARTICIPANT	\N	PRESENT	0
726655	725546	11065P	PARTICIPANT	\N	PRESENT	0
726656	725546	19619A	PARTICIPANT	\N	PRESENT	0
726658	725546	20118Y	PARTICIPANT	\N	PRESENT	0
727537	725875	20140W	PARTICIPANT	\N	PRESENT	0
727538	725875	01057W	PARTICIPANT	\N	PRESENT	0
727539	725875	20066E	PARTICIPANT	\N	PRESENT	0
727540	725875	19369B	PARTICIPANT	\N	PRESENT	0
727541	725875	20022R	PARTICIPANT	\N	PRESENT	0
727542	725875	20090E	PARTICIPANT	\N	PRESENT	0
727543	725875	08010L	PARTICIPANT	\N	PRESENT	0
727544	725875	14331P	PARTICIPANT	\N	PRESENT	0
727546	725875	20060X	PARTICIPANT	\N	PRESENT	0
727547	725875	19741B	PARTICIPANT	\N	PRESENT	0
727548	725875	20120S	PARTICIPANT	\N	PRESENT	0
727549	725875	14021P	PARTICIPANT	\N	PRESENT	0
727550	725875	11090Q	PARTICIPANT	\N	PRESENT	0
727551	725875	19333N	PARTICIPANT	\N	PRESENT	0
727552	725875	97011G	PARTICIPANT	\N	PRESENT	0
727553	725875	20062A	PARTICIPANT	\N	PRESENT	0
727554	726284	14357A	PARTICIPANT	\N	PRESENT	0
727555	726284	19713W	PARTICIPANT	\N	PRESENT	0
727556	726284	11097X	PARTICIPANT	\N	PRESENT	0
727557	726284	19575F	PARTICIPANT	\N	PRESENT	0
727558	726284	11053K	PARTICIPANT	\N	PRESENT	0
727559	726284	19251M	PRESIDENT	0	PRESENT	0
727560	726284	20102Q	PARTICIPANT	\N	PRESENT	0
727561	726284	20052X	PARTICIPANT	\N	PRESENT	0
727562	726284	17229F	PARTICIPANT	\N	PRESENT	0
727563	726284	19762G	PARTICIPANT	\N	PRESENT	0
727564	726284	20084G	PARTICIPANT	\N	PRESENT	0
727565	726284	20092G	PARTICIPANT	\N	PRESENT	0
727568	727566	20132W	PARTICIPANT	\N	PRESENT	1
727569	727566	20180F	PARTICIPANT	\N	PRESENT	1
727570	727566	19593H	PARTICIPANT	\N	PRESENT	1
727571	727566	20084G	PARTICIPANT	\N	PRESENT	1
727572	727566	20142Y	PARTICIPANT	\N	PRESENT	1
727573	725875	11064N	PARTICIPANT	\N	PRESENT	0
727574	725875	14187A	PARTICIPANT	\N	PRESENT	0
727575	725875	19527W	PARTICIPANT	\N	PRESENT	0
727576	725875	19533U	PARTICIPANT	\N	PRESENT	0
727577	725875	19954N	PARTICIPANT	\N	PRESENT	0
727578	725875	19681G	PARTICIPANT	\N	PRESENT	0
727579	725875	17965H	PARTICIPANT	\N	PRESENT	0
727580	725875	14231L	PARTICIPANT	\N	PRESENT	0
727680	727567	20132W	PARTICIPANT	\N	PRESENT	1
727681	727567	20180F	PARTICIPANT	\N	PRESENT	1
727682	727567	19593H	PARTICIPANT	\N	PRESENT	1
727684	725878	14033T	PARTICIPANT	\N	PRESENT	0
727685	725696	16685X	PARTICIPANT	\N	PRESENT	0
727686	725696	97011G	PARTICIPANT	\N	PRESENT	0
727687	725696	14059S	PARTICIPANT	\N	PRESENT	0
727688	725696	01024M	PARTICIPANT	\N	PRESENT	0
727689	725696	12028B	PARTICIPANT	\N	EXCUSE	0
727690	725696	19443T	PARTICIPANT	\N	EXCUSE	0
727691	725696	98022P	PARTICIPANT	\N	EXCUSE	0
727692	725696	11054L	PARTICIPANT	\N	EXCUSE	0
727693	725878	17965H	PARTICIPANT	\N	PRESENT	0
727694	725878	19413M	PARTICIPANT	\N	PRESENT	0
727695	725878	14257W	PARTICIPANT	\N	PRESENT	0
727696	725878	14053L	PARTICIPANT	\N	PRESENT	0
727697	725878	19333N	PARTICIPANT	\N	PRESENT	0
727698	725878	19585H	PARTICIPANT	\N	PRESENT	0
727699	725878	20298U	PARTICIPANT	\N	PRESENT	0
727700	725878	19782L	PARTICIPANT	\N	PRESENT	0
727701	725878	11056N	PARTICIPANT	\N	PRESENT	0
727702	725878	19758L	PARTICIPANT	\N	PRESENT	0
727703	725878	14042U	PARTICIPANT	\N	PRESENT	0
727704	725878	04092N	PARTICIPANT	\N	PRESENT	0
727705	725878	04045F	PARTICIPANT	\N	PRESENT	0
727706	725878	19762G	PARTICIPANT	\N	PRESENT	0
727715	725878	19713W	PARTICIPANT	\N	PRESENT	0
727716	725878	14357A	PARTICIPANT	\N	PRESENT	0
727717	725878	11040E	PARTICIPANT	\N	PRESENT	0
727718	725878	20180F	PARTICIPANT	\N	PRESENT	0
727719	725878	20034V	PARTICIPANT	\N	PRESENT	0
727720	725878	14215L	PARTICIPANT	\N	PRESENT	0
727721	725878	20114U	PARTICIPANT	\N	PRESENT	0
727722	725878	19599P	PARTICIPANT	\N	PRESENT	0
727723	725878	19503N	PARTICIPANT	\N	PRESENT	0
727724	725878	19820Y	PARTICIPANT	\N	PRESENT	0
727725	725878	17779H	PARTICIPANT	\N	PRESENT	0
727726	725878	20100N	PARTICIPANT	\N	PRESENT	0
727770	725879	18193Q	PARTICIPANT	\N	PRESENT	0
727771	725879	11040E	PARTICIPANT	\N	PRESENT	0
727772	725879	20092G	PARTICIPANT	\N	PRESENT	0
727773	725879	20914V	PARTICIPANT	\N	PRESENT	0
727774	725879	14042U	PARTICIPANT	\N	PRESENT	0
727775	725879	11053K	PARTICIPANT	\N	PRESENT	0
727776	725879	14327T	PARTICIPANT	\N	PRESENT	0
727777	725879	14253S	PARTICIPANT	\N	PRESENT	0
727778	725879	01057W	PARTICIPANT	\N	PRESENT	0
727779	725879	19741B	PARTICIPANT	\N	PRESENT	0
727780	725879	20044X	PARTICIPANT	\N	PRESENT	0
727781	725879	19687N	PARTICIPANT	\N	PRESENT	0
727782	725879	19531S	PARTICIPANT	\N	PRESENT	0
727783	725879	14249W	PARTICIPANT	\N	PRESENT	0
727784	725879	14225N	PARTICIPANT	\N	PRESENT	0
727785	725879	11048N	PARTICIPANT	\N	PRESENT	0
727786	725879	20116W	PARTICIPANT	\N	PRESENT	0
727787	725879	19647E	PARTICIPANT	\N	PRESENT	0
727788	725879	20050V	PARTICIPANT	\N	PRESENT	0
727789	725879	17779H	PARTICIPANT	\N	PRESENT	0
727790	725879	10006L	PARTICIPANT	\N	PRESENT	0
727791	725879	07029T	PARTICIPANT	\N	PRESENT	0
727792	725879	20126Y	PARTICIPANT	\N	PRESENT	0
727793	725879	19553Y	PARTICIPANT	\N	PRESENT	0
727794	725879	14033T	PARTICIPANT	\N	PRESENT	0
727795	725879	20298U	PARTICIPANT	\N	PRESENT	0
727964	725016	19760E	PARTICIPANT	\N	PRESENT	0
727965	725016	14207L	PARTICIPANT	\N	PRESENT	0
727966	725016	14217N	PARTICIPANT	\N	PRESENT	0
727967	725016	19479G	PARTICIPANT	\N	PRESENT	0
727968	725016	11097X	PARTICIPANT	\N	PRESENT	0
727969	725016	20130U	PARTICIPANT	\N	PRESENT	0
727970	725016	14071N	PARTICIPANT	\N	PRESENT	0
727971	725016	04092N	PARTICIPANT	\N	PRESENT	0
727972	725016	17779H	PARTICIPANT	\N	PRESENT	0
727973	725016	19591F	PARTICIPANT	\N	PRESENT	0
727974	725016	14026U	PARTICIPANT	\N	PRESENT	0
727975	725016	14281W	PARTICIPANT	\N	PRESENT	0
727976	725016	14042U	PARTICIPANT	\N	PRESENT	0
727977	725016	10006L	PARTICIPANT	\N	PRESENT	0
728258	728257	14173T	PARTICIPANT	\N	PRESENT	0
727768	725879	95063L	PARTICIPANT	\N	PRESENT	0
727769	725879	20080C	PARTICIPANT	\N	PRESENT	0
728260	728259	14331P	PARTICIPANT	\N	PRESENT	0
728264	728263	20050V	PARTICIPANT	\N	PRESENT	0
728270	728269	20116W	PARTICIPANT	\N	PRESENT	0
728280	728279	20080C	PARTICIPANT	\N	PRESENT	0
728300	728299	14225N	PARTICIPANT	\N	PRESENT	0
721369	719215	19333N	PARTICIPANT	\N	PRESENT	0
721372	721371	20140W	PARTICIPANT	\N	PRESENT	0
721374	721373	20140W	PARTICIPANT	\N	PRESENT	0
721378	721373	14038Y	PARTICIPANT	\N	PRESENT	0
721380	721379	20140W	PARTICIPANT	\N	PRESENT	0
721381	721379	14038Y	PARTICIPANT	\N	PRESENT	0
721383	721382	20140W	PARTICIPANT	\N	PRESENT	0
721384	721382	14038Y	PARTICIPANT	\N	PRESENT	0
721387	721386	20140W	PARTICIPANT	\N	PRESENT	0
721388	721386	14038Y	PARTICIPANT	\N	PRESENT	0
721390	721389	20140W	PARTICIPANT	\N	PRESENT	0
721391	721389	14038Y	PARTICIPANT	\N	PRESENT	0
721393	721392	20140W	PARTICIPANT	\N	PRESENT	0
721394	721367	20140W	PARTICIPANT	\N	PRESENT	0
726657	725555	14031R	PARTICIPANT	\N	PRESENT	0
727454	725808	20024T	PARTICIPANT	\N	PRESENT	0
727455	725808	20138D	PARTICIPANT	\N	PRESENT	0
727456	725808	11031D	PARTICIPANT	\N	PRESENT	0
727457	725808	14213J	PARTICIPANT	\N	PRESENT	0
727483	725808	19725B	PARTICIPANT	\N	PRESENT	0
727484	725808	20126Y	PARTICIPANT	\N	PRESENT	0
727485	725808	19735D	PRESIDENT	0	PRESENT	0
727486	725808	20066E	PARTICIPANT	\N	PRESENT	0
727487	725808	17965H	PARTICIPANT	\N	PRESENT	0
727489	725808	19369B	PARTICIPANT	\N	PRESENT	0
727495	725808	20096L	PARTICIPANT	\N	PRESENT	0
728923	725647	11097X	PARTICIPANT	\N	PRESENT	0
728924	725647	20130U	PARTICIPANT	\N	PRESENT	0
728925	725648	11097X	PARTICIPANT	\N	PRESENT	0
728926	725648	20130U	PARTICIPANT	\N	PRESENT	0
728927	728564	11097X	PARTICIPANT	\N	PRESENT	0
728928	728564	20130U	PARTICIPANT	\N	PRESENT	0
729239	728012	01028R	PARTICIPANT	\N	PRESENT	0
729514	726277	04059M	PARTICIPANT	\N	PRESENT	0
729515	726277	19651A	PARTICIPANT	\N	PRESENT	0
729516	726277	14030Q	PARTICIPANT	\N	PRESENT	0
729517	726277	20138D	PARTICIPANT	\N	PRESENT	0
729518	726277	19643A	PARTICIPANT	\N	PRESENT	0
731420	730685	14026U	PARTICIPANT	\N	PRESENT	0
729520	726277	19621T	PARTICIPANT	\N	PRESENT	0
729521	726277	19758L	PARTICIPANT	\N	PRESENT	0
729522	726277	20264J	PARTICIPANT	\N	PRESENT	0
729531	726277	19693L	PARTICIPANT	\N	PRESENT	0
729532	726277	17589D	PARTICIPANT	\N	PRESENT	0
729533	726277	20980G	PARTICIPANT	\N	PRESENT	0
729534	726277	19719D	PARTICIPANT	\N	PRESENT	0
729535	726277	20134Y	PARTICIPANT	\N	PRESENT	0
729536	726277	20132W	PARTICIPANT	\N	PRESENT	0
729537	726277	20172F	PARTICIPANT	\N	PRESENT	0
729538	726277	20180F	PARTICIPANT	\N	PRESENT	0
729539	726277	14123H	PARTICIPANT	\N	PRESENT	0
729540	726277	20048C	PARTICIPANT	\N	PRESENT	0
729541	726277	19399H	PARTICIPANT	\N	PRESENT	0
729542	726277	20056C	PARTICIPANT	\N	PRESENT	0
729543	726277	19611R	PRESIDENT	0	PRESENT	0
729546	726277	20142Y	PARTICIPANT	\N	PRESENT	0
729545	726277	08012N	PARTICIPANT	\N	PRESENT	0
729547	726277	20058E	PARTICIPANT	\N	PRESENT	0
729548	726277	20026V	PARTICIPANT	\N	PRESENT	0
729549	726277	19527W	PARTICIPANT	\N	PRESENT	0
729550	726277	20084G	PARTICIPANT	\N	PRESENT	0
729551	726277	20098N	PARTICIPANT	\N	PRESENT	0
729552	726277	11043H	PARTICIPANT	\N	PRESENT	0
729553	726277	14229S	PARTICIPANT	\N	PRESENT	0
729554	726277	04033B	PARTICIPANT	\N	PRESENT	0
729555	726277	19533U	PARTICIPANT	\N	PRESENT	0
729556	726277	19593H	PARTICIPANT	\N	PRESENT	0
729557	726277	04070G	PARTICIPANT	\N	PRESENT	0
729558	726277	14109K	PARTICIPANT	\N	PRESENT	0
729559	726277	01060R	PARTICIPANT	\N	PRESENT	0
731421	730685	20046A	PARTICIPANT	\N	PRESENT	0
731422	730685	20028X	PARTICIPANT	\N	PRESENT	0
731423	730685	08060W	PARTICIPANT	\N	PRESENT	0
731424	730685	19413M	PARTICIPANT	\N	PRESENT	0
731425	730685	11099A	PARTICIPANT	\N	PRESENT	0
731426	730685	19347U	PARTICIPANT	\N	PRESENT	0
731427	730685	20092G	PARTICIPANT	\N	PRESENT	0
731428	730685	19782L	PARTICIPANT	\N	PRESENT	0
731429	730685	19349W	PARTICIPANT	\N	PRESENT	0
731430	730685	19565D	PARTICIPANT	\N	PRESENT	0
731431	730685	19713W	PARTICIPANT	\N	PRESENT	0
731432	730685	14215L	PARTICIPANT	\N	PRESENT	0
731433	730685	20090E	PARTICIPANT	\N	PRESENT	0
731434	730685	20034V	PARTICIPANT	\N	PRESENT	0
731435	730685	20054A	PARTICIPANT	\N	PRESENT	0
731436	730685	19467C	PARTICIPANT	\N	PRESENT	0
731437	730685	19507S	PARTICIPANT	\N	PRESENT	0
731438	730685	07029T	PARTICIPANT	\N	PRESENT	0
731439	730685	19447X	PARTICIPANT	\N	PRESENT	0
731440	730685	19575F	PARTICIPANT	\N	PRESENT	0
731441	730685	08028W	PARTICIPANT	\N	PRESENT	0
731442	730685	14187A	PARTICIPANT	\N	PRESENT	0
731443	730685	11090Q	PARTICIPANT	\N	PRESENT	0
731444	730685	14205J	PARTICIPANT	\N	PRESENT	0
731445	730685	19441R	PARTICIPANT	\N	PRESENT	0
731446	730685	20018V	PARTICIPANT	\N	PRESENT	0
731447	730685	19758L	PARTICIPANT	\N	PRESENT	0
731448	730685	20914V	PARTICIPANT	\N	PRESENT	0
731449	730685	20076G	PARTICIPANT	\N	PRESENT	0
731450	730685	04045F	PARTICIPANT	\N	PRESENT	0
731451	730685	19629C	PARTICIPANT	\N	PRESENT	0
731452	730685	20082E	PARTICIPANT	\N	PRESENT	0
731453	730685	20044X	PARTICIPANT	\N	PRESENT	0
731454	730685	20056C	PARTICIPANT	\N	PRESENT	0
731455	730685	20118Y	PARTICIPANT	\N	PRESENT	0
731456	730685	14033T	PARTICIPANT	\N	PRESENT	0
731457	730685	20144B	PARTICIPANT	\N	PRESENT	0
731458	730685	20040T	PARTICIPANT	\N	PRESENT	0
731459	730685	14257W	PARTICIPANT	\N	PRESENT	0
731460	730685	14329V	PARTICIPANT	\N	PRESENT	0
731461	730685	19705W	PARTICIPANT	\N	PRESENT	0
731462	730685	19798U	PARTICIPANT	\N	PRESENT	0
731463	730685	20116W	PARTICIPANT	\N	PRESENT	0
731464	730685	20142Y	PARTICIPANT	\N	PRESENT	0
731465	730685	05008E	PARTICIPANT	\N	PRESENT	0
731466	730685	08061X	PARTICIPANT	\N	PRESENT	0
731467	730685	19768N	PARTICIPANT	\N	PRESENT	0
731468	730685	14259Y	PARTICIPANT	\N	PRESENT	0
731469	730685	20098N	PARTICIPANT	\N	PRESENT	0
731470	730685	19383Y	PARTICIPANT	\N	PRESENT	0
731471	730685	08010L	PARTICIPANT	\N	PRESENT	0
731472	730685	14195A	PARTICIPANT	\N	PRESENT	0
731473	730685	20062A	PARTICIPANT	\N	PRESENT	0
731474	730685	20032T	PARTICIPANT	\N	PRESENT	0
731475	730685	14147R	PARTICIPANT	\N	PRESENT	0
731476	730685	14219Q	PARTICIPANT	\N	PRESENT	0
731477	730685	19954N	PARTICIPANT	\N	PRESENT	0
731478	730685	18083K	PARTICIPANT	\N	PRESENT	0
731479	730685	19741B	PARTICIPANT	\N	PRESENT	0
731480	730685	20130U	PARTICIPANT	\N	PRESENT	0
731481	730685	20980G	PARTICIPANT	\N	PRESENT	0
731482	730685	17367Q	PARTICIPANT	\N	PRESENT	0
731483	730685	19695N	PARTICIPANT	\N	PRESENT	0
731484	730685	14357A	PARTICIPANT	\N	PRESENT	0
731485	730685	20086J	PARTICIPANT	\N	PRESENT	0
731486	730685	04033B	PARTICIPANT	\N	PRESENT	0
731487	730685	08015R	PARTICIPANT	\N	PRESENT	0
731488	730685	14213J	PARTICIPANT	\N	PRESENT	0
731489	730685	14071N	PARTICIPANT	\N	PRESENT	0
731493	730685	14231L	PARTICIPANT	\N	PRESENT	0
731491	730685	20180F	PARTICIPANT	\N	PRESENT	0
731492	730685	14069U	PARTICIPANT	\N	PRESENT	0
731494	730685	20042V	PARTICIPANT	\N	PRESENT	0
731495	730685	19762G	PARTICIPANT	\N	PRESENT	0
731496	730685	20070A	PARTICIPANT	\N	PRESENT	0
731499	730685	20124W	PARTICIPANT	\N	PRESENT	0
731500	730685	19719D	PARTICIPANT	\N	PRESENT	0
731501	730685	20038A	PARTICIPANT	\N	PRESENT	0
731502	730685	17023S	PARTICIPANT	\N	PRESENT	0
731503	730685	14083S	PARTICIPANT	\N	PRESENT	0
731504	730685	20128B	PARTICIPANT	\N	PRESENT	0
731505	730685	20298U	PARTICIPANT	\N	PRESENT	0
731506	730685	19563B	PARTICIPANT	\N	PRESENT	0
731507	730685	14221J	PARTICIPANT	\N	PRESENT	0
731508	730685	19701S	PARTICIPANT	\N	PRESENT	0
731509	730685	20058E	PARTICIPANT	\N	PRESENT	0
732139	730686	19563B	PARTICIPANT	\N	PRESENT	0
732140	730686	20180F	PARTICIPANT	\N	PRESENT	0
732141	730686	20050V	PARTICIPANT	\N	PRESENT	0
732142	730686	20026V	PARTICIPANT	\N	PRESENT	0
736783	736780	08034U	PARTICIPANT	\N	PRESENT	0
736785	736784	08034U	PARTICIPANT	\N	PRESENT	0
736787	736786	08034U	PARTICIPANT	\N	PRESENT	0
736799	736798	08034U	PARTICIPANT	\N	PRESENT	0
736875	736874	08034U	PARTICIPANT	\N	PRESENT	0
736885	736884	08034U	PARTICIPANT	\N	PRESENT	0
736891	736890	08034U	PARTICIPANT	\N	PRESENT	0
736898	736897	08034U	PARTICIPANT	\N	PRESENT	0
736900	736899	08034U	PARTICIPANT	\N	PRESENT	0
736902	736901	08034U	PARTICIPANT	\N	PRESENT	0
736904	736903	11074Q	PARTICIPANT	\N	PRESENT	0
736905	736903	19349W	PARTICIPANT	\N	PRESENT	0
736991	736738	11026G	PARTICIPANT	\N	PRESENT	0
736992	736739	19729F	PARTICIPANT	\N	PRESENT	0
736993	736739	20074E	PARTICIPANT	\N	PRESENT	0
737007	735374	20066E	PARTICIPANT	\N	PRESENT	0
737008	735374	14026U	PARTICIPANT	\N	PRESENT	0
737009	735374	20266L	PARTICIPANT	\N	PRESENT	0
737011	735374	20024T	PARTICIPANT	\N	PRESENT	0
737012	735374	14213J	PARTICIPANT	\N	PRESENT	0
737013	735374	20126Y	PARTICIPANT	\N	PRESENT	0
737015	735374	20050V	PARTICIPANT	\N	EXCUSE	0
737016	735374	17965H	PARTICIPANT	\N	PRESENT	0
739388	738262	95041E	PARTICIPANT	\N	PRESENT	0
739389	738262	12041X	PARTICIPANT	\N	PRESENT	0
739390	738262	19565D	PARTICIPANT	\N	PRESENT	0
739391	738262	20072C	PARTICIPANT	\N	PRESENT	0
739392	738262	01058X	PARTICIPANT	\N	PRESENT	0
739393	738262	11027H	PARTICIPANT	\N	PRESENT	0
739394	738262	16685X	PARTICIPANT	\N	PRESENT	0
739395	738262	04042C	PRESIDENT	0	PRESENT	0
739396	738262	11054L	PARTICIPANT	\N	PRESENT	0
739397	738262	11066Q	PARTICIPANT	\N	PRESENT	0
739398	738262	19669L	PARTICIPANT	\N	PRESENT	0
739399	738262	08056B	PARTICIPANT	\N	PRESENT	0
739400	738262	12028B	PARTICIPANT	\N	PRESENT	0
739401	738262	19421M	PARTICIPANT	\N	PRESENT	0
739402	738262	19709B	PARTICIPANT	\N	PRESENT	0
739403	738262	14193X	PARTICIPANT	\N	PRESENT	0
739404	738262	97011G	PARTICIPANT	\N	PRESENT	0
739405	738262	08061X	PARTICIPANT	\N	PRESENT	0
739406	738262	08047A	PARTICIPANT	\N	PRESENT	0
739407	738262	20128B	PARTICIPANT	\N	PRESENT	0
739408	738262	14059S	PARTICIPANT	\N	PRESENT	0
739409	738262	14097Y	PARTICIPANT	\N	PRESENT	0
739410	738262	04035D	PARTICIPANT	\N	PRESENT	0
739411	738262	14133K	PARTICIPANT	\N	PRESENT	0
739412	738262	01062T	PARTICIPANT	\N	PRESENT	0
739413	738262	11041F	PARTICIPANT	\N	PRESENT	0
739414	738262	20042V	PARTICIPANT	\N	PRESENT	0
739415	738262	01024M	PARTICIPANT	\N	PRESENT	0
739416	738262	19721W	PARTICIPANT	\N	PRESENT	0
739417	738262	20064C	PARTICIPANT	\N	PRESENT	0
739418	738262	98022P	PARTICIPANT	\N	PRESENT	0
739419	738262	14267Y	PARTICIPANT	\N	PRESENT	0
739420	738262	11064N	PARTICIPANT	\N	PRESENT	0
739421	738262	11083R	PARTICIPANT	\N	PRESENT	0
739422	738262	14211G	PARTICIPANT	\N	PRESENT	0
739423	738262	19583F	PARTICIPANT	\N	PRESENT	0
739424	738262	14255U	PARTICIPANT	\N	PRESENT	0
739425	738262	17023S	PARTICIPANT	\N	PRESENT	0
739430	738297	19725B	PRESIDENT	0	PRESENT	0
739431	738297	20024T	PARTICIPANT	\N	PRESENT	0
739432	738297	20114U	PARTICIPANT	\N	PRESENT	0
739433	738297	11031D	PARTICIPANT	\N	PRESENT	0
739434	738297	20266L	PARTICIPANT	\N	PRESENT	0
739435	738363	11048N	PARTICIPANT	\N	PRESENT	0
739436	738363	19741B	PARTICIPANT	\N	PRESENT	0
739437	738363	99004R	PARTICIPANT	\N	PRESENT	0
739438	738363	19667J	PARTICIPANT	\N	PRESENT	0
739439	738363	19671E	PARTICIPANT	\N	PRESENT	0
739440	738363	19711U	PARTICIPANT	\N	PRESENT	0
739441	738363	20044X	PARTICIPANT	\N	PRESENT	0
739442	738363	19687N	PARTICIPANT	\N	PRESENT	0
739443	738363	11053K	PARTICIPANT	\N	PRESENT	0
739444	738363	07029T	PARTICIPANT	\N	PRESENT	0
739445	738363	20080C	PARTICIPANT	\N	PRESENT	0
739446	738363	14225N	PRESIDENT	0	PRESENT	0
739448	739447	19585H	PARTICIPANT	\N	PRESENT	0
739449	739447	20066E	PARTICIPANT	\N	PRESENT	0
739450	739447	11064N	PARTICIPANT	\N	PRESENT	0
739451	739447	14219Q	PARTICIPANT	\N	PRESENT	0
739452	739447	08056B	PARTICIPANT	\N	PRESENT	0
739463	738363	19762G	PARTICIPANT	\N	PRESENT	0
739464	738363	14083S	PARTICIPANT	\N	PRESENT	0
739465	738363	20126Y	PARTICIPANT	\N	PRESENT	0
739466	738007	86034E	PARTICIPANT	\N	PRESENT	0
739467	738363	20070A	PARTICIPANT	\N	PRESENT	0
739468	738363	20086J	PARTICIPANT	\N	PRESENT	0
739469	738007	98022P	PARTICIPANT	\N	PRESENT	0
739470	738007	19511N	PARTICIPANT	\N	PRESENT	0
739471	738007	20108W	PARTICIPANT	\N	PRESENT	0
739472	738007	14223L	PARTICIPANT	\N	PRESENT	0
739473	738007	08028W	PARTICIPANT	\N	PRESENT	0
739476	738007	14109K	PARTICIPANT	\N	PRESENT	0
739477	738007	14121F	PARTICIPANT	\N	PRESENT	0
739478	738007	20016T	PARTICIPANT	\N	PRESENT	0
739479	738007	14111D	PARTICIPANT	\N	PRESENT	0
739480	738007	14195A	PARTICIPANT	\N	PRESENT	0
739481	738007	19387D	PARTICIPANT	\N	PRESENT	0
739482	738007	14267Y	PARTICIPANT	\N	PRESENT	0
739483	738007	20130U	PARTICIPANT	\N	PRESENT	0
739484	738007	20102Q	PARTICIPANT	\N	PRESENT	0
739485	738007	19333N	PARTICIPANT	\N	PRESENT	0
739486	738007	11067R	PARTICIPANT	\N	PRESENT	0
739487	738007	18193Q	PARTICIPANT	\N	PRESENT	0
739488	738007	19651A	PARTICIPANT	\N	PRESENT	0
739489	738007	19413M	PARTICIPANT	\N	PRESENT	0
739490	738007	11045K	PARTICIPANT	\N	PRESENT	0
739491	738007	11012A	PARTICIPANT	\N	PRESENT	0
739492	738007	20914V	PARTICIPANT	\N	PRESENT	0
739493	738007	20110Q	PARTICIPANT	\N	PRESENT	0
739494	738007	01062T	PARTICIPANT	\N	PRESENT	0
739495	738007	11054L	PARTICIPANT	\N	PRESENT	0
739496	738007	11066Q	PARTICIPANT	\N	PRESENT	0
739497	738007	11099A	PARTICIPANT	\N	PRESENT	0
739498	738007	19631V	PARTICIPANT	\N	PRESENT	0
739499	738007	11040E	PARTICIPANT	\N	PRESENT	0
739500	738007	19565D	PARTICIPANT	\N	PRESENT	0
739501	738007	11033F	PARTICIPANT	\N	PRESENT	0
739502	738007	19669L	PARTICIPANT	\N	PRESENT	0
739503	738007	20082E	PARTICIPANT	\N	PRESENT	0
739504	738007	19531S	PARTICIPANT	\N	PRESENT	0
739505	738007	19527W	PARTICIPANT	\N	PRESENT	0
739506	738007	19585H	PARTICIPANT	\N	PRESENT	0
739507	738007	11041F	PARTICIPANT	\N	PRESENT	0
739508	738007	19820Y	PARTICIPANT	\N	PRESENT	0
739509	738007	12028B	PARTICIPANT	\N	PRESENT	0
739510	738007	11077T	PARTICIPANT	\N	PRESENT	0
739511	738007	20264J	PARTICIPANT	\N	PRESENT	0
739512	738007	11031D	PARTICIPANT	\N	PRESENT	0
739513	738007	19725B	PARTICIPANT	\N	PRESENT	0
739514	738007	01028R	PARTICIPANT	\N	PRESENT	0
739515	738007	20098N	PARTICIPANT	\N	PRESENT	0
739516	738007	14225N	PARTICIPANT	\N	PRESENT	0
739517	738007	19507S	PARTICIPANT	\N	PRESENT	0
739518	738007	17367Q	PARTICIPANT	\N	PRESENT	0
739519	738007	20086J	PARTICIPANT	\N	PRESENT	0
739520	738007	19663E	PARTICIPANT	\N	PRESENT	0
739521	738007	14038Y	PARTICIPANT	\N	PRESENT	0
739522	738007	20044X	PARTICIPANT	\N	PRESENT	0
739523	738007	11074Q	PARTICIPANT	\N	PRESENT	0
739524	738007	19447X	PARTICIPANT	\N	PRESENT	0
739525	738007	04059M	PARTICIPANT	\N	PRESENT	0
739526	738007	20038A	PARTICIPANT	\N	PRESENT	0
739527	738007	19573D	PARTICIPANT	\N	PRESENT	0
739528	738007	14257W	PARTICIPANT	\N	PRESENT	0
739529	738007	17779H	PARTICIPANT	\N	PRESENT	0
739530	738007	14151M	PARTICIPANT	\N	PRESENT	0
739531	738007	19467C	PARTICIPANT	\N	PRESENT	0
739532	738007	19709B	PARTICIPANT	\N	PRESENT	0
739533	738007	19683J	PARTICIPANT	\N	PRESENT	0
739534	738007	20056C	PARTICIPANT	\N	PRESENT	0
739535	738007	11027H	PARTICIPANT	\N	PRESENT	0
739536	738007	14021P	PARTICIPANT	\N	PRESENT	0
739537	738007	20180F	PARTICIPANT	\N	PRESENT	0
739538	738007	20980G	PARTICIPANT	\N	PRESENT	0
739539	738007	17637T	PARTICIPANT	\N	PRESENT	0
739540	738007	07029T	PARTICIPANT	\N	PRESENT	0
739541	738007	08060W	PARTICIPANT	\N	PRESENT	0
711764	708191	17023S	PARTICIPANT	\N	PRESENT	0
711838	708191	14255U	PARTICIPANT	\N	PRESENT	0
711766	708191	20152B	PARTICIPANT	\N	PRESENT	0
711767	708191	01028R	PARTICIPANT	\N	PRESENT	0
711768	708191	04085P	PARTICIPANT	\N	PRESENT	0
711769	708191	19525U	PARTICIPANT	\N	PRESENT	0
711770	708191	19549D	PARTICIPANT	\N	PRESENT	0
711771	708191	08060W	PARTICIPANT	\N	PRESENT	0
711772	708191	14021P	PARTICIPANT	\N	PRESENT	0
711773	708191	20098N	PARTICIPANT	\N	PRESENT	0
711774	708191	11048N	PARTICIPANT	\N	PRESENT	0
711775	708191	19329S	PARTICIPANT	\N	PRESENT	0
711776	708191	19531S	PARTICIPANT	\N	PRESENT	0
711777	708191	14225N	PARTICIPANT	\N	PRESENT	0
711778	708191	20056C	PARTICIPANT	\N	PRESENT	0
711779	708191	14053L	PARTICIPANT	\N	PRESENT	0
711780	708191	11065P	PARTICIPANT	\N	PRESENT	0
711781	708191	11033F	PARTICIPANT	\N	PRESENT	0
711782	708191	20150Y	PARTICIPANT	\N	PRESENT	0
711783	708191	19782L	PARTICIPANT	\N	PRESENT	0
711784	708191	19695N	PARTICIPANT	\N	PRESENT	0
711785	708191	04059M	PARTICIPANT	\N	PRESENT	0
711786	708191	19703U	PARTICIPANT	\N	PRESENT	0
711787	708191	14038Y	PARTICIPANT	\N	PRESENT	0
711788	708191	20112S	PARTICIPANT	\N	PRESENT	0
711789	708191	20066E	PARTICIPANT	\N	PRESENT	0
711790	708191	20050V	PARTICIPANT	\N	PRESENT	0
711791	708191	20082E	PARTICIPANT	\N	PRESENT	0
711792	708191	19649G	PARTICIPANT	\N	PRESENT	0
711793	708191	08018U	PARTICIPANT	\N	PRESENT	0
711801	708191	14073Q	PARTICIPANT	\N	PRESENT	0
711802	708191	14229S	PARTICIPANT	\N	PRESENT	0
711803	708191	19691J	PARTICIPANT	\N	PRESENT	0
711804	708191	20110Q	PARTICIPANT	\N	PRESENT	0
711808	708191	17367Q	PARTICIPANT	\N	PRESENT	0
711806	708191	20180F	PARTICIPANT	\N	PRESENT	0
711807	708191	11080N	PARTICIPANT	\N	PRESENT	0
711809	708191	20086J	PARTICIPANT	\N	PRESENT	0
711810	708191	11072N	PARTICIPANT	\N	PRESENT	0
711811	708191	11099A	PARTICIPANT	\N	PRESENT	0
711812	708191	11085T	PARTICIPANT	\N	PRESENT	0
711823	708191	14109K	PARTICIPANT	\N	PRESENT	0
711832	708191	20028X	PARTICIPANT	\N	PRESENT	0
711836	708191	19697Q	PARTICIPANT	\N	PRESENT	0
711837	708191	19591F	PARTICIPANT	\N	PRESENT	0
711839	708191	19369B	PARTICIPANT	\N	PRESENT	0
711840	708191	20072C	PARTICIPANT	\N	PRESENT	0
711841	708191	11070L	PARTICIPANT	\N	PRESENT	0
711842	708191	14037X	PARTICIPANT	\N	PRESENT	0
711843	708191	19349W	PARTICIPANT	\N	PRESENT	0
711844	708191	07004J	PARTICIPANT	\N	PRESENT	0
711845	708191	04035D	PARTICIPANT	\N	PRESENT	0
711850	708191	20134Y	PARTICIPANT	\N	PRESENT	0
711848	708191	14059S	PARTICIPANT	\N	PRESENT	0
711849	708191	19545Y	PARTICIPANT	\N	PRESENT	0
711851	708191	19503N	PARTICIPANT	\N	PRESENT	0
711852	708191	19758L	PARTICIPANT	\N	PRESENT	0
711853	708191	14215L	PARTICIPANT	\N	PRESENT	0
711854	708191	95063L	PARTICIPANT	\N	PRESENT	0
711855	708191	19719D	PARTICIPANT	\N	PRESENT	0
711963	708192	11070L	PARTICIPANT	\N	PRESENT	0
711966	708192	11099A	PARTICIPANT	\N	PRESENT	0
711967	708192	19467C	PARTICIPANT	\N	PRESENT	0
711968	708192	14253S	PARTICIPANT	\N	PRESENT	0
711969	708192	19657G	PARTICIPANT	\N	PRESENT	0
711970	708192	20264J	PARTICIPANT	\N	PRESENT	0
711971	708192	19631V	PARTICIPANT	\N	PRESENT	0
711972	708192	19782L	PARTICIPANT	\N	PRESENT	0
711973	708192	19545Y	PARTICIPANT	\N	PRESENT	0
711974	708192	14195A	PARTICIPANT	\N	PRESENT	0
711975	708192	17779H	PARTICIPANT	\N	PRESENT	0
711976	708192	14151M	PARTICIPANT	\N	PRESENT	0
711977	708192	19349W	PARTICIPANT	\N	PRESENT	0
711978	708192	19866P	PARTICIPANT	\N	PRESENT	0
711979	708192	20072C	PARTICIPANT	\N	PRESENT	0
711980	708192	19525U	PARTICIPANT	\N	PRESENT	0
711981	708192	19333N	PARTICIPANT	\N	PRESENT	0
711982	708192	11067R	PARTICIPANT	\N	PRESENT	0
711983	708192	11031D	PARTICIPANT	\N	PRESENT	0
711984	708192	19760E	PARTICIPANT	\N	PRESENT	0
711985	708192	18193Q	PARTICIPANT	\N	PRESENT	0
711986	708192	20084G	PARTICIPANT	\N	PRESENT	0
711987	708192	14225N	PARTICIPANT	\N	PRESENT	0
711988	708192	19527W	PARTICIPANT	\N	PRESENT	0
711989	708192	20130U	PARTICIPANT	\N	PRESENT	0
711990	708192	20132W	PARTICIPANT	\N	PRESENT	0
711991	708192	14030Q	PARTICIPANT	\N	PRESENT	0
711992	708192	14207L	PARTICIPANT	\N	PRESENT	0
711993	708192	19553Y	PARTICIPANT	\N	PRESENT	0
711994	708192	11074Q	PARTICIPANT	\N	PRESENT	0
711995	708192	19593H	PARTICIPANT	\N	PRESENT	0
711996	708192	19758L	PARTICIPANT	\N	PRESENT	0
711997	708192	08060W	PARTICIPANT	\N	PRESENT	0
711998	708192	08045X	PARTICIPANT	\N	PRESENT	0
711999	708192	12028B	PARTICIPANT	\N	PRESENT	0
712000	708192	20060X	PARTICIPANT	\N	PRESENT	0
712001	708192	14281W	PARTICIPANT	\N	PRESENT	0
712002	708192	08028W	PARTICIPANT	\N	PRESENT	0
712003	708192	11097X	PARTICIPANT	\N	PRESENT	0
712004	708192	11072N	PARTICIPANT	\N	PRESENT	0
712005	708192	14109K	PARTICIPANT	\N	PRESENT	0
712006	708192	14042U	PARTICIPANT	\N	PRESENT	0
712007	708192	14257W	PARTICIPANT	\N	PRESENT	0
712008	708192	19503N	PARTICIPANT	\N	PRESENT	0
712009	708192	19591F	PARTICIPANT	\N	PRESENT	0
712010	708192	19347U	PARTICIPANT	\N	PRESENT	0
712011	708192	08034U	PARTICIPANT	\N	PRESENT	0
712012	708192	14215L	PARTICIPANT	\N	PRESENT	0
712013	708192	20028X	PARTICIPANT	\N	PRESENT	0
712014	708192	17965H	PARTICIPANT	\N	PRESENT	0
712015	708192	04092N	PARTICIPANT	\N	PRESENT	0
712016	708192	14071N	PARTICIPANT	\N	PRESENT	0
712017	708192	10006L	PARTICIPANT	\N	PRESENT	0
712018	708192	14053L	PARTICIPANT	\N	PRESENT	0
712019	708192	20914V	PARTICIPANT	\N	PRESENT	0
712020	708192	20030R	PARTICIPANT	\N	PRESENT	0
712022	708192	12041X	PARTICIPANT	\N	PRESENT	0
712024	708192	20102Q	PARTICIPANT	\N	PRESENT	0
712025	708192	20046A	PARTICIPANT	\N	PRESENT	0
712026	708192	07004J	PARTICIPANT	\N	PRESENT	0
712027	708192	20126Y	PARTICIPANT	\N	PRESENT	0
712028	708192	20152B	PARTICIPANT	\N	PRESENT	0
712029	708192	20034V	PARTICIPANT	\N	PRESENT	0
712030	708192	20090E	PARTICIPANT	\N	PRESENT	0
712031	708192	11045K	PARTICIPANT	\N	PRESENT	0
712032	708192	99004R	PARTICIPANT	\N	PRESENT	0
712033	708192	14123H	PARTICIPANT	\N	PRESENT	0
712034	708192	20980G	PARTICIPANT	\N	PRESENT	0
712035	708192	20086J	PARTICIPANT	\N	PRESENT	0
712036	708192	20092G	PARTICIPANT	\N	PRESENT	0
712037	708192	19611R	PARTICIPANT	\N	PRESENT	0
712038	708192	19711U	PARTICIPANT	\N	PRESENT	0
712039	708192	14069U	PARTICIPANT	\N	PRESENT	0
712040	708192	97011G	PARTICIPANT	\N	PRESENT	0
712041	708192	11090Q	PARTICIPANT	\N	PRESENT	0
712042	708192	14213J	PARTICIPANT	\N	PRESENT	0
712043	708192	20024T	PARTICIPANT	\N	PRESENT	0
712044	708192	19573D	PARTICIPANT	\N	PRESENT	0
712045	708192	05012A	PARTICIPANT	\N	PRESENT	0
712046	708192	20026V	PARTICIPANT	\N	PRESENT	0
712047	708192	14031R	PARTICIPANT	\N	PRESENT	0
712048	708192	20076G	PARTICIPANT	\N	PRESENT	0
712049	708192	19693L	PARTICIPANT	\N	PRESENT	0
712050	708192	20180F	PARTICIPANT	\N	PRESENT	0
712051	708192	20038A	PARTICIPANT	\N	PRESENT	0
712052	708192	20078J	PARTICIPANT	\N	PRESENT	0
712053	708192	14073Q	PARTICIPANT	\N	PRESENT	0
712054	708192	19369B	PARTICIPANT	\N	PRESENT	0
712055	708192	20064C	PARTICIPANT	\N	PRESENT	0
712056	708192	16685X	PARTICIPANT	\N	PRESENT	0
712057	708192	19699S	PARTICIPANT	\N	PRESENT	0
712058	708192	19569H	PARTICIPANT	\N	PRESENT	0
712059	708192	14187A	PARTICIPANT	\N	PRESENT	0
712060	708192	04085P	PARTICIPANT	\N	PRESENT	0
712061	708192	04059M	PARTICIPANT	\N	PRESENT	0
712062	708192	95063L	PARTICIPANT	\N	PRESENT	0
712063	708192	19413M	PARTICIPANT	\N	PRESENT	0
712064	708192	20104S	PARTICIPANT	\N	PRESENT	0
712065	708192	19697Q	PARTICIPANT	\N	PRESENT	0
712066	708192	20040T	PARTICIPANT	\N	PRESENT	0
712067	708192	14021P	PARTICIPANT	\N	PRESENT	0
726273	726272	20136B	PARTICIPANT	\N	PRESENT	0
726274	726272	18083K	PARTICIPANT	\N	PRESENT	0
728301	728299	11048N	PARTICIPANT	\N	PRESENT	0
728302	728299	08034U	PARTICIPANT	\N	PRESENT	0
728303	728299	14327T	PARTICIPANT	\N	PRESENT	0
728304	728299	19647E	PARTICIPANT	\N	PRESENT	0
728306	728305	14225N	PARTICIPANT	\N	PRESENT	0
728307	728305	11048N	PARTICIPANT	\N	PRESENT	0
728308	728305	08034U	PARTICIPANT	\N	PRESENT	0
728309	728305	14327T	PARTICIPANT	\N	PRESENT	0
728310	728305	19647E	PARTICIPANT	\N	PRESENT	0
728312	728311	14225N	PARTICIPANT	\N	PRESENT	0
728313	728311	11048N	PARTICIPANT	\N	PRESENT	0
728314	728311	08034U	PARTICIPANT	\N	PRESENT	0
728315	728311	14327T	PARTICIPANT	\N	PRESENT	0
728316	728311	19647E	PARTICIPANT	\N	PRESENT	0
728318	728317	14225N	PARTICIPANT	\N	PRESENT	0
728319	728317	11048N	PARTICIPANT	\N	PRESENT	0
728320	728317	08034U	PARTICIPANT	\N	PRESENT	0
728321	728317	14327T	PARTICIPANT	\N	PRESENT	0
728322	728317	19647E	PARTICIPANT	\N	PRESENT	0
728324	728323	14225N	PARTICIPANT	\N	PRESENT	0
728325	728323	11048N	PARTICIPANT	\N	PRESENT	0
728326	728323	08034U	PARTICIPANT	\N	PRESENT	0
728327	728323	11070L	PARTICIPANT	\N	PRESENT	0
728328	728323	19647E	PARTICIPANT	\N	PRESENT	0
728330	728329	14225N	PARTICIPANT	\N	PRESENT	0
728331	728329	11048N	PARTICIPANT	\N	PRESENT	0
728332	728329	08034U	PARTICIPANT	\N	PRESENT	0
728333	728329	14327T	PARTICIPANT	\N	PRESENT	0
728334	728329	19647E	PARTICIPANT	\N	PRESENT	0
728336	728335	14225N	PARTICIPANT	\N	PRESENT	0
728337	728335	11048N	PARTICIPANT	\N	PRESENT	0
728338	728335	08034U	PARTICIPANT	\N	PRESENT	0
728339	728335	14327T	PARTICIPANT	\N	PRESENT	0
728340	728335	19647E	PARTICIPANT	\N	PRESENT	0
728342	728341	14225N	PARTICIPANT	\N	PRESENT	0
728343	728341	11048N	PARTICIPANT	\N	PRESENT	0
728344	728341	08034U	PARTICIPANT	\N	PRESENT	0
728345	728341	14327T	PARTICIPANT	\N	PRESENT	0
728346	728341	19647E	PARTICIPANT	\N	PRESENT	0
728348	728347	14225N	PARTICIPANT	\N	PRESENT	0
728349	728347	11048N	PARTICIPANT	\N	PRESENT	0
728350	728347	08034U	PARTICIPANT	\N	PRESENT	0
728351	728347	14327T	PARTICIPANT	\N	PRESENT	0
728352	728347	19647E	PARTICIPANT	\N	PRESENT	0
728354	728353	14225N	PARTICIPANT	\N	PRESENT	0
728355	728353	11048N	PARTICIPANT	\N	PRESENT	0
728356	728353	08034U	PARTICIPANT	\N	PRESENT	0
728357	728353	14327T	PARTICIPANT	\N	PRESENT	0
728358	728353	19647E	PARTICIPANT	\N	PRESENT	0
728372	728130	11043H	PARTICIPANT	\N	EXCUSE	0
728373	728190	11043H	PARTICIPANT	\N	EXCUSE	0
728407	728130	19295A	PARTICIPANT	\N	EXCUSE	0
728408	728190	19295A	PARTICIPANT	\N	EXCUSE	0
728427	728426	14267Y	PARTICIPANT	\N	PRESENT	0
728428	728426	19565D	PARTICIPANT	\N	PRESENT	0
728430	728429	04042C	PARTICIPANT	\N	PRESENT	0
728431	728429	14249W	PARTICIPANT	\N	PRESENT	0
728432	728429	14133K	PARTICIPANT	\N	PRESENT	0
728433	728429	01024M	PARTICIPANT	\N	PRESENT	0
728434	728429	14193X	PARTICIPANT	\N	PRESENT	0
728435	728429	14267Y	PARTICIPANT	\N	PRESENT	0
728436	728429	20128B	PARTICIPANT	\N	PRESENT	0
728437	728429	08047A	PARTICIPANT	\N	PRESENT	0
728438	728429	19669L	PARTICIPANT	\N	PRESENT	0
728440	728439	19503N	PARTICIPANT	\N	PRESENT	0
728443	728442	19503N	PARTICIPANT	\N	PRESENT	0
728464	728218	11045K	PARTICIPANT	\N	PRESENT	0
728465	728218	14033T	PARTICIPANT	\N	PRESENT	0
728466	728218	19681G	PARTICIPANT	\N	PRESENT	0
728467	728218	11090Q	PARTICIPANT	\N	PRESENT	0
728468	728218	14221J	PARTICIPANT	\N	PRESENT	0
728469	728218	20092G	PARTICIPANT	\N	PRESENT	0
728470	728218	19782L	PARTICIPANT	\N	PRESENT	0
728471	728218	14257W	PARTICIPANT	\N	PRESENT	0
728472	728218	19695N	PARTICIPANT	\N	PRESENT	0
728473	728218	19369B	PARTICIPANT	\N	PRESENT	0
728476	728405	19383Y	PARTICIPANT	\N	PRESENT	0
728477	728405	19515S	PARTICIPANT	\N	PRESENT	0
728478	728405	19782L	PARTICIPANT	\N	PRESENT	0
728479	728405	20078J	PARTICIPANT	\N	PRESENT	0
728480	728405	04045F	PARTICIPANT	\N	PRESENT	0
728481	728405	19631V	PARTICIPANT	\N	PRESENT	0
728482	728405	08015R	PARTICIPANT	\N	PRESENT	0
728483	728405	19369B	PARTICIPANT	\N	PRESENT	0
728484	728405	14037X	PARTICIPANT	\N	PRESENT	0
728485	728405	14038Y	PARTICIPANT	\N	PRESENT	0
728486	728405	19467C	PARTICIPANT	\N	PRESENT	0
728487	728405	20034V	PARTICIPANT	\N	PRESENT	0
728488	728405	20144B	PARTICIPANT	\N	PRESENT	0
728489	728405	19695N	PARTICIPANT	\N	PRESENT	0
728490	728405	14033T	PARTICIPANT	\N	PRESENT	0
728491	728405	11090Q	PRESIDENT	0	PRESENT	0
728492	728405	01025N	PARTICIPANT	\N	PRESENT	0
728493	728405	20054A	PARTICIPANT	\N	PRESENT	0
728494	728405	14205J	PARTICIPANT	\N	PRESENT	0
728495	728405	20062A	PARTICIPANT	\N	PRESENT	0
728496	728405	14251Q	PARTICIPANT	\N	PRESENT	0
728497	728405	19507S	PARTICIPANT	\N	PRESENT	0
728498	728405	20286Q	PARTICIPANT	\N	PRESENT	0
728499	728405	20298U	PARTICIPANT	\N	PRESENT	0
728500	728405	19747H	PARTICIPANT	\N	PRESENT	0
728508	728218	19467C	PARTICIPANT	\N	PRESENT	0
728509	728218	20034V	PARTICIPANT	\N	PRESENT	0
728511	728218	19507S	PARTICIPANT	\N	PRESENT	0
728512	728218	20076G	PARTICIPANT	\N	PRESENT	0
728516	728218	20078J	PARTICIPANT	\N	PRESENT	0
728518	728218	20062A	PARTICIPANT	\N	PRESENT	0
728519	728218	14213J	PARTICIPANT	\N	PRESENT	0
728522	728218	20914V	PARTICIPANT	\N	PRESENT	0
728523	728218	20144B	PARTICIPANT	\N	PRESENT	0
728524	728218	19760E	PARTICIPANT	\N	PRESENT	0
728525	728218	19525U	PARTICIPANT	\N	PRESENT	0
728526	728218	20074E	PARTICIPANT	\N	PRESENT	0
728527	728218	14147R	PARTICIPANT	\N	PRESENT	0
728528	728218	20018V	PARTICIPANT	\N	PRESENT	0
728529	728218	18083K	PARTICIPANT	\N	PRESENT	0
728530	728218	19631V	PARTICIPANT	\N	PRESENT	0
728531	728218	08028W	PARTICIPANT	\N	PRESENT	0
728532	728218	20022R	PARTICIPANT	\N	PRESENT	0
728533	728218	19747H	PARTICIPANT	\N	PRESENT	0
728534	728218	20090E	PARTICIPANT	\N	PRESENT	0
728535	728218	14038Y	PARTICIPANT	\N	PRESENT	0
728539	728218	19758L	PARTICIPANT	\N	PRESENT	0
728540	728218	20026V	PARTICIPANT	\N	PRESENT	0
728541	728218	20054A	PARTICIPANT	\N	PRESENT	0
728542	728218	19719D	PARTICIPANT	\N	PRESENT	0
728543	728218	20142Y	PARTICIPANT	\N	PRESENT	0
728544	728218	20088L	PARTICIPANT	\N	PRESENT	0
728545	728218	14207L	PARTICIPANT	\N	PRESENT	0
728546	728218	14231L	PARTICIPANT	\N	PRESENT	0
728547	728218	14107H	PARTICIPANT	\N	PRESENT	0
728548	728218	99004R	PARTICIPANT	\N	PRESENT	0
728549	728218	14205J	PARTICIPANT	\N	PRESENT	0
728550	728218	14069U	PARTICIPANT	\N	PRESENT	0
728551	728218	20086J	PARTICIPANT	\N	PRESENT	0
728552	728218	12041X	PARTICIPANT	\N	PRESENT	0
728554	728218	19383Y	PARTICIPANT	\N	PRESENT	0
728555	728553	19762G	PARTICIPANT	\N	PRESENT	0
728557	728553	19531S	PARTICIPANT	\N	PRESENT	0
728556	728218	19479G	PARTICIPANT	\N	PRESENT	0
728558	728218	14030Q	PARTICIPANT	\N	PRESENT	0
728560	728218	19683J	PARTICIPANT	\N	PRESENT	0
728561	728218	19549D	PARTICIPANT	\N	PRESENT	0
728562	728559	19762G	PARTICIPANT	\N	PRESENT	0
728563	728559	19531S	PARTICIPANT	\N	PRESENT	0
728565	728218	14223L	PARTICIPANT	\N	PRESENT	0
728566	728218	11031D	PARTICIPANT	\N	PRESENT	0
728572	728218	20082E	PARTICIPANT	\N	PRESENT	0
728573	728218	14237S	PARTICIPANT	\N	PRESENT	0
728574	728218	14179A	PARTICIPANT	\N	PRESENT	0
728575	728218	19739H	PARTICIPANT	\N	PRESENT	0
728577	728218	19569H	PARTICIPANT	\N	PRESENT	0
728578	728218	20068G	PARTICIPANT	\N	PRESENT	0
728579	728218	20066E	PARTICIPANT	\N	PRESENT	0
728580	728218	20286Q	PARTICIPANT	\N	PRESENT	0
728581	728218	19575F	PARTICIPANT	\N	PRESENT	0
725687	725685	19503N	PARTICIPANT	\N	PRESENT	0
725690	725688	19503N	PARTICIPANT	\N	PRESENT	0
725692	725691	05008E	PARTICIPANT	\N	PRESENT	0
725693	725691	11053K	PARTICIPANT	\N	PRESENT	0
725694	725691	01028R	PARTICIPANT	\N	PRESENT	0
726345	725870	14026U	PARTICIPANT	\N	PRESENT	0
726770	725807	19725B	PARTICIPANT	\N	PRESENT	0
726771	725807	17965H	PARTICIPANT	\N	PRESENT	0
726772	725807	20096L	PARTICIPANT	\N	PRESENT	0
726773	725807	19735D	PARTICIPANT	\N	PRESENT	0
726774	725807	19369B	PARTICIPANT	\N	PRESENT	0
726775	725807	14026U	PARTICIPANT	\N	PRESENT	0
726776	725807	14213J	PARTICIPANT	\N	PRESENT	0
726777	725807	11031D	PARTICIPANT	\N	PRESENT	0
726778	725807	20066E	PARTICIPANT	\N	PRESENT	0
728692	728691	20180F	PARTICIPANT	\N	PRESENT	1
728693	728691	20132W	PARTICIPANT	\N	PRESENT	1
728694	728691	19593H	PARTICIPANT	\N	PRESENT	1
728695	728691	20084G	PARTICIPANT	\N	PRESENT	1
728788	728787	20180F	PARTICIPANT	\N	PRESENT	1
728789	728787	19593H	PARTICIPANT	\N	PRESENT	1
728790	728787	20132W	PARTICIPANT	\N	PRESENT	1
728791	728787	20084G	PARTICIPANT	\N	PRESENT	1
728857	728796	20132W	PARTICIPANT	\N	PRESENT	1
728858	728796	19593H	PARTICIPANT	\N	PRESENT	1
728859	728796	20180F	PARTICIPANT	\N	PRESENT	1
728860	728796	20084G	PARTICIPANT	\N	PRESENT	1
731646	731643	11027H	PARTICIPANT	\N	PRESENT	0
731647	731643	14193X	PARTICIPANT	\N	PRESENT	0
732143	730686	19057M	PARTICIPANT	\N	PRESENT	0
732144	730686	20980G	PARTICIPANT	\N	PRESENT	0
732145	730686	08018U	PARTICIPANT	\N	PRESENT	0
732146	730686	11099A	PARTICIPANT	\N	PRESENT	0
732147	730686	04071H	PARTICIPANT	\N	PRESENT	0
732148	730686	14033T	PARTICIPANT	\N	PRESENT	0
732149	730686	20056C	PARTICIPANT	\N	PRESENT	0
732150	730686	07029T	PARTICIPANT	\N	PRESENT	0
732151	730686	19729F	PARTICIPANT	\N	PRESENT	0
732153	730686	08015R	PARTICIPANT	\N	PRESENT	0
732154	730686	20104S	PARTICIPANT	\N	PRESENT	0
732156	730686	19954N	PARTICIPANT	\N	PRESENT	0
732157	730686	11115U	PARTICIPANT	\N	PRESENT	0
732158	730686	20074E	PARTICIPANT	\N	PRESENT	0
732159	730686	14253S	PARTICIPANT	\N	PRESENT	0
732160	730686	11101A	PARTICIPANT	\N	PRESENT	0
732161	730686	08010L	PARTICIPANT	\N	PRESENT	0
732162	730686	04059M	PARTICIPANT	\N	PRESENT	0
732163	730686	04092N	PARTICIPANT	\N	PRESENT	0
732164	730686	19747H	PARTICIPANT	\N	PRESENT	0
732165	730686	11097X	PARTICIPANT	\N	PRESENT	0
732166	730686	19415P	PARTICIPANT	\N	PRESENT	0
732167	730686	20094J	PARTICIPANT	\N	PRESENT	0
732168	730686	14071N	PARTICIPANT	\N	PRESENT	0
732169	730686	05008E	PARTICIPANT	\N	PRESENT	0
732170	730686	11077T	PARTICIPANT	\N	PRESENT	0
732171	730686	17637T	PARTICIPANT	\N	PRESENT	0
732172	730686	19695N	PARTICIPANT	\N	PRESENT	0
732173	730686	14187A	PARTICIPANT	\N	PRESENT	0
732174	730686	20114U	PARTICIPANT	\N	PRESENT	0
732175	730686	14026U	PARTICIPANT	\N	PRESENT	0
732176	730686	04033B	PARTICIPANT	\N	PRESENT	0
732177	730686	19701S	PARTICIPANT	\N	PRESENT	0
732178	730686	04043D	PARTICIPANT	\N	PRESENT	0
732179	730686	19798U	PARTICIPANT	\N	PRESENT	0
732180	730686	14237S	PARTICIPANT	\N	PRESENT	0
732181	730686	19367Y	PARTICIPANT	\N	PRESENT	0
732182	730686	20126Y	PARTICIPANT	\N	PRESENT	0
732183	730686	20124W	PARTICIPANT	\N	PRESENT	0
732184	730686	14357A	PARTICIPANT	\N	PRESENT	0
732185	730686	20020P	PARTICIPANT	\N	PRESENT	0
732186	730686	95041E	PARTICIPANT	\N	PRESENT	0
732187	730686	20120S	PARTICIPANT	\N	PRESENT	0
732188	730686	19533U	PARTICIPANT	\N	PRESENT	0
732189	730686	20118Y	PARTICIPANT	\N	PRESENT	0
732190	730686	97011G	PARTICIPANT	\N	PRESENT	0
732191	730686	14331P	PARTICIPANT	\N	PRESENT	0
732192	730686	14147R	PARTICIPANT	\N	PRESENT	0
732193	730686	20172F	PARTICIPANT	\N	PRESENT	0
732194	730686	14213J	PARTICIPANT	\N	PRESENT	0
732195	730686	19705W	PARTICIPANT	\N	PRESENT	0
732196	730686	19768N	PARTICIPANT	\N	PRESENT	0
732197	730686	20140W	PARTICIPANT	\N	PRESENT	0
732198	730686	11090Q	PARTICIPANT	\N	PRESENT	0
732199	730686	19663E	PARTICIPANT	\N	PRESENT	0
732200	730686	14053L	PARTICIPANT	\N	PRESENT	0
732201	730686	20108W	PARTICIPANT	\N	PRESENT	0
732202	730686	20080C	PARTICIPANT	\N	PRESENT	0
732203	730686	20152B	PARTICIPANT	\N	PRESENT	0
732204	730686	14055N	PARTICIPANT	\N	PRESENT	0
732205	730686	11074Q	PARTICIPANT	\N	PRESENT	0
732206	730686	11031D	PARTICIPANT	\N	PRESENT	0
732207	730686	11110B	PARTICIPANT	\N	PRESENT	0
732208	730686	19647E	PARTICIPANT	\N	PRESENT	0
732209	730686	14215L	PARTICIPANT	\N	PRESENT	0
732213	730686	14281W	PARTICIPANT	\N	PRESENT	0
732214	730686	19599P	PARTICIPANT	\N	PRESENT	0
732217	730686	19820Y	PARTICIPANT	\N	PRESENT	0
732218	730686	19725B	PARTICIPANT	\N	PRESENT	0
732219	730686	19333N	PARTICIPANT	\N	PRESENT	0
732221	730686	14133K	PARTICIPANT	\N	PRESENT	0
732224	730686	19683J	PARTICIPANT	\N	PRESENT	0
732225	730686	01060R	PARTICIPANT	\N	PRESENT	0
732227	730686	11048N	PARTICIPANT	\N	PRESENT	0
732229	730686	19489J	PARTICIPANT	\N	PRESENT	0
732231	730686	20070A	PARTICIPANT	\N	PRESENT	0
732232	730686	11026G	PARTICIPANT	\N	PRESENT	0
732235	730686	17779H	PARTICIPANT	\N	PRESENT	0
732236	730686	14001X	PARTICIPANT	\N	PRESENT	0
732238	730686	19565D	PARTICIPANT	\N	PRESENT	0
732240	730686	20018V	PARTICIPANT	\N	PRESENT	0
732241	730686	14193X	PARTICIPANT	\N	PRESENT	0
732243	730686	20030R	PARTICIPANT	\N	PRESENT	0
732245	730686	19503N	PARTICIPANT	\N	PRESENT	0
732246	730686	14225N	PARTICIPANT	\N	PRESENT	0
732247	730686	20082E	PARTICIPANT	\N	PRESENT	0
732249	730686	14229S	PARTICIPANT	\N	PRESENT	0
732250	730686	11054L	PARTICIPANT	\N	PRESENT	0
732251	730686	20084G	PARTICIPANT	\N	PRESENT	0
732254	730686	01028R	PARTICIPANT	\N	PRESENT	0
732255	730686	11045K	PARTICIPANT	\N	PRESENT	0
732256	730686	19669L	PARTICIPANT	\N	PRESENT	0
732257	730686	19413M	PARTICIPANT	\N	PRESENT	0
732258	730686	01062T	PARTICIPANT	\N	PRESENT	0
732259	730686	20064C	PARTICIPANT	\N	PRESENT	0
732260	730686	19347U	PARTICIPANT	\N	PRESENT	0
732261	730686	11041F	PARTICIPANT	\N	PRESENT	0
732262	730686	19527W	PARTICIPANT	\N	PRESENT	0
732263	730686	14189C	PARTICIPANT	\N	PRESENT	0
732264	730686	20042V	PARTICIPANT	\N	PRESENT	0
732267	730686	04035D	PARTICIPANT	\N	PRESENT	0
732269	730686	14251Q	PARTICIPANT	\N	PRESENT	0
732270	730686	19711U	PARTICIPANT	\N	PRESENT	0
732271	730686	14111D	PARTICIPANT	\N	PRESENT	0
732272	730686	12016W	PARTICIPANT	\N	PRESENT	0
732273	730686	11053K	PARTICIPANT	\N	PRESENT	0
732276	730686	20144B	PARTICIPANT	\N	PRESENT	0
732278	730686	14267Y	PARTICIPANT	\N	PRESENT	0
732279	730686	11070L	PARTICIPANT	\N	PRESENT	0
732280	730686	14327T	PARTICIPANT	\N	PRESENT	0
732281	730686	17229F	PARTICIPANT	\N	PRESENT	0
732283	730686	01024M	PARTICIPANT	\N	PRESENT	0
732285	730686	14042U	PARTICIPANT	\N	PRESENT	0
732286	730686	20040T	PARTICIPANT	\N	PRESENT	0
732288	730686	01025N	PARTICIPANT	\N	PRESENT	0
732292	730686	14231L	PARTICIPANT	\N	PRESENT	0
732293	730686	07004J	PARTICIPANT	\N	PRESENT	0
732295	730686	19569H	PARTICIPANT	\N	PRESENT	0
732296	730686	20286Q	PARTICIPANT	\N	PRESENT	0
732298	730686	14179A	PARTICIPANT	\N	PRESENT	0
732299	730686	19685L	PARTICIPANT	\N	PRESENT	0
732300	730686	20048C	PARTICIPANT	\N	PRESENT	0
732302	730686	20066E	PARTICIPANT	\N	PRESENT	0
732303	730686	14073Q	PARTICIPANT	\N	PRESENT	0
732304	730686	19735D	PARTICIPANT	\N	PRESENT	0
732305	730686	19611R	PARTICIPANT	\N	PRESENT	0
732306	730686	19699S	PARTICIPANT	\N	PRESENT	0
732307	730686	14205J	PARTICIPANT	\N	PRESENT	0
732308	730686	14219Q	PARTICIPANT	\N	PRESENT	0
732309	730686	19441R	PARTICIPANT	\N	PRESENT	0
737028	735539	14191V	PARTICIPANT	\N	PRESENT	0
737031	735539	19782L	PARTICIPANT	\N	PRESENT	0
737032	735539	19583F	PARTICIPANT	\N	PRESENT	0
737033	735539	19721W	PARTICIPANT	\N	PRESENT	0
737034	735539	14107H	PARTICIPANT	\N	PRESENT	0
737035	735539	01025N	PARTICIPANT	\N	PRESENT	0
737037	735539	04045F	PARTICIPANT	\N	PRESENT	0
737041	735539	17229F	PARTICIPANT	\N	PRESENT	0
737042	735539	04059M	PARTICIPANT	\N	PRESENT	0
737043	735539	19347U	PARTICIPANT	\N	PRESENT	0
737044	735539	16685X	PARTICIPANT	\N	PRESENT	0
737045	735539	19697Q	PARTICIPANT	\N	PRESENT	0
737046	735539	19629C	PARTICIPANT	\N	PRESENT	0
737047	735539	19659J	PARTICIPANT	\N	PRESENT	0
737048	735539	14195A	PARTICIPANT	\N	PRESENT	0
737049	735539	11054L	PARTICIPANT	\N	PRESENT	0
737050	735539	19549D	PARTICIPANT	\N	PRESENT	0
737051	735539	11104D	PARTICIPANT	\N	PRESENT	0
737052	735539	14001X	PARTICIPANT	\N	PRESENT	0
737053	735539	11074Q	PARTICIPANT	\N	PRESENT	0
737054	735539	11045K	PARTICIPANT	\N	PRESENT	0
737055	735539	19683J	PARTICIPANT	\N	PRESENT	0
737056	735539	19565D	PARTICIPANT	\N	PRESENT	0
737057	735539	08012N	PARTICIPANT	\N	PRESENT	0
737060	735539	19581D	PARTICIPANT	\N	PRESENT	0
737062	735539	04085P	PARTICIPANT	\N	PRESENT	0
737063	735539	11040E	PARTICIPANT	\N	PRESENT	0
737064	735539	20046A	PARTICIPANT	\N	PRESENT	0
737065	735539	20102Q	PARTICIPANT	\N	PRESENT	0
737066	735539	19593H	PARTICIPANT	\N	PRESENT	0
737067	735539	20084G	PARTICIPANT	\N	PRESENT	0
737068	735539	19349W	PARTICIPANT	\N	PRESENT	0
737069	735539	08060W	PARTICIPANT	\N	PRESENT	0
737071	735539	01034P	PARTICIPANT	\N	PRESENT	0
737072	735539	14255U	PARTICIPANT	\N	PRESENT	0
737073	735539	19713W	PARTICIPANT	\N	PRESENT	0
737074	735539	14267Y	PARTICIPANT	\N	PRESENT	0
737075	735539	19699S	PARTICIPANT	\N	PRESENT	0
737076	735539	20252E	PARTICIPANT	\N	PRESENT	0
737080	735539	19415P	PARTICIPANT	\N	PRESENT	0
737084	735539	19333N	PARTICIPANT	\N	PRESENT	0
737085	735539	11066Q	PARTICIPANT	\N	PRESENT	0
737116	735539	19573D	PARTICIPANT	\N	PRESENT	0
737117	735539	19637C	PARTICIPANT	\N	PRESENT	0
737118	735539	20980G	PARTICIPANT	\N	PRESENT	0
737119	735539	08018U	PARTICIPANT	\N	PRESENT	0
737120	735539	11033F	PARTICIPANT	\N	PRESENT	0
737122	735539	20180F	PARTICIPANT	\N	PRESENT	0
737123	735539	19717B	PARTICIPANT	\N	PRESENT	0
737124	735539	19954N	PARTICIPANT	\N	PRESENT	0
737125	735539	19673G	PARTICIPANT	\N	PRESENT	0
737126	735539	20116W	PARTICIPANT	\N	PRESENT	0
737127	735539	14207L	PARTICIPANT	\N	PRESENT	0
737128	735539	19741B	PARTICIPANT	\N	PRESENT	0
737129	735539	20036X	PARTICIPANT	\N	PRESENT	0
737130	735539	19681G	PARTICIPANT	\N	PRESENT	0
737131	735539	11080N	PARTICIPANT	\N	PRESENT	0
737132	735539	14031R	PARTICIPANT	\N	PRESENT	0
737133	735539	19553Y	PARTICIPANT	\N	PRESENT	0
737134	735539	19667J	PARTICIPANT	\N	PRESENT	0
737135	735539	19719D	PARTICIPANT	\N	PRESENT	0
737136	735539	14253S	PARTICIPANT	\N	PRESENT	0
737137	735539	19866P	PARTICIPANT	\N	PRESENT	0
737138	735539	11012A	PARTICIPANT	\N	PRESENT	0
737139	735539	19711U	PARTICIPANT	\N	PRESENT	0
737140	735539	20128B	PARTICIPANT	\N	PRESENT	0
737141	735539	04071H	PARTICIPANT	\N	PRESENT	0
737142	735539	11064N	PARTICIPANT	\N	PRESENT	0
737143	735539	14211G	PARTICIPANT	\N	PRESENT	0
737144	735539	19663E	PARTICIPANT	\N	PRESENT	0
737145	735539	14251Q	PARTICIPANT	\N	PRESENT	0
737146	735539	14111D	PARTICIPANT	\N	PRESENT	0
737147	735539	14221J	PARTICIPANT	\N	PRESENT	0
737148	735539	04057K	PARTICIPANT	\N	PRESENT	0
737150	735539	19563B	PARTICIPANT	\N	PRESENT	0
737151	735539	01057W	PARTICIPANT	\N	PRESENT	0
737152	735539	20122U	PARTICIPANT	\N	PRESENT	0
737153	735539	20172F	PARTICIPANT	\N	PRESENT	0
737154	735539	19585H	PARTICIPANT	\N	PRESENT	0
737155	735539	14033T	PARTICIPANT	\N	PRESENT	0
737156	735539	17367Q	PARTICIPANT	\N	PRESENT	0
737157	735539	20086J	PARTICIPANT	\N	PRESENT	0
737158	735539	20108W	PARTICIPANT	\N	PRESENT	0
737159	735539	19631V	PARTICIPANT	\N	PRESENT	0
737160	735539	20094J	PARTICIPANT	\N	PRESENT	0
737161	735539	20104S	PARTICIPANT	\N	PRESENT	0
737162	735539	11099A	PARTICIPANT	\N	PRESENT	0
737163	735539	08015R	PARTICIPANT	\N	PRESENT	0
737164	735539	20114U	PARTICIPANT	\N	PRESENT	0
737165	735539	19399H	PARTICIPANT	\N	PRESENT	0
737166	735539	20016T	PARTICIPANT	\N	PRESENT	0
737167	735539	19507S	PARTICIPANT	\N	PRESENT	0
737168	735539	20060X	PARTICIPANT	\N	PRESENT	0
737169	735539	14169X	PARTICIPANT	\N	PRESENT	0
737170	735539	12028B	PARTICIPANT	\N	PRESENT	0
737171	735539	14069U	PARTICIPANT	\N	PRESENT	0
737172	735539	19251M	PARTICIPANT	\N	PRESENT	0
737173	735539	14281W	PARTICIPANT	\N	PRESENT	0
737174	735539	19599P	PARTICIPANT	\N	PRESENT	0
737175	735539	04043D	PARTICIPANT	\N	PRESENT	0
737176	735539	19820Y	PARTICIPANT	\N	PRESENT	0
737177	735539	19725B	PARTICIPANT	\N	PRESENT	0
737178	735539	05012A	PARTICIPANT	\N	PRESENT	0
737179	735539	19387D	PARTICIPANT	\N	PRESENT	0
737180	735539	20022R	PARTICIPANT	\N	PRESENT	0
737181	735539	19647E	PARTICIPANT	\N	PRESENT	0
737182	735539	14213J	PARTICIPANT	\N	PRESENT	0
737183	735539	14021P	PARTICIPANT	\N	PRESENT	0
737184	735539	14331P	PARTICIPANT	\N	PRESENT	0
737185	735539	19525U	PARTICIPANT	\N	PRESENT	0
737186	735539	11090Q	PARTICIPANT	\N	PRESENT	0
737187	735539	20050V	PARTICIPANT	\N	PRESENT	0
737188	735539	19649G	PARTICIPANT	\N	PRESENT	0
737189	735539	10015M	PARTICIPANT	\N	PRESENT	0
737190	735539	18193Q	PARTICIPANT	\N	PRESENT	0
737191	735539	11026G	PARTICIPANT	\N	PRESENT	0
737192	735539	20028X	PARTICIPANT	\N	PRESENT	0
737193	735539	17965H	PARTICIPANT	\N	PRESENT	0
737194	735539	20030R	PARTICIPANT	\N	PRESENT	0
737195	735539	14123H	PARTICIPANT	\N	PRESENT	0
737197	735539	14109K	PARTICIPANT	\N	PRESENT	0
737198	735539	11067R	PARTICIPANT	\N	PRESENT	0
737199	735539	11048N	PARTICIPANT	\N	PRESENT	0
737201	735539	19503N	PARTICIPANT	\N	PRESENT	0
737203	735539	14225N	PARTICIPANT	\N	PRESENT	0
737204	735539	19621T	PARTICIPANT	\N	PRESENT	0
737205	735539	11027H	PARTICIPANT	\N	PRESENT	0
737206	735539	19489J	PARTICIPANT	\N	PRESENT	0
737207	735539	19413M	PARTICIPANT	\N	PRESENT	0
737208	735539	19703U	PARTICIPANT	\N	PRESENT	0
737209	735539	01062T	PARTICIPANT	\N	PRESENT	0
737210	735539	20064C	PARTICIPANT	\N	PRESENT	0
737211	735539	11041F	PARTICIPANT	\N	PRESENT	0
737212	735539	19527W	PARTICIPANT	\N	PRESENT	0
737213	735539	01028R	PARTICIPANT	\N	PRESENT	0
737214	735539	11056N	PARTICIPANT	\N	PRESENT	0
737215	735539	19695N	PARTICIPANT	\N	PRESENT	0
737216	735539	14133K	PARTICIPANT	\N	PRESENT	0
737217	735539	19687N	PARTICIPANT	\N	PRESENT	0
737218	735539	12041X	PARTICIPANT	\N	PRESENT	0
737219	735539	11097X	PARTICIPANT	\N	PRESENT	0
737220	735539	20110Q	PARTICIPANT	\N	PRESENT	0
737221	735539	20044X	PARTICIPANT	\N	PRESENT	0
737222	735539	19768N	PARTICIPANT	\N	PRESENT	0
737223	735539	20142Y	PARTICIPANT	\N	PRESENT	0
737224	735539	14053L	PARTICIPANT	\N	PRESENT	0
737225	735539	05008E	PARTICIPANT	\N	PRESENT	0
712070	708192	04042C	PARTICIPANT	\N	PRESENT	0
712071	708192	20042V	PARTICIPANT	\N	PRESENT	0
712072	708192	19489J	PARTICIPANT	\N	PRESENT	0
712073	708192	19647E	PARTICIPANT	\N	PRESENT	0
712074	708192	14231L	PARTICIPANT	\N	PRESENT	0
712075	708192	04070G	PARTICIPANT	\N	PRESENT	0
712068	708192	19826F	PARTICIPANT	\N	PRESENT	0
712069	708192	19649G	PARTICIPANT	\N	PRESENT	0
712076	708192	14059S	PARTICIPANT	\N	PRESENT	0
712077	708192	04033B	PARTICIPANT	\N	PRESENT	0
712078	708192	10015M	PARTICIPANT	\N	PRESENT	0
712079	708192	20298U	PARTICIPANT	\N	PRESENT	0
712080	708192	07029T	PARTICIPANT	\N	PRESENT	0
712081	708192	20066E	PARTICIPANT	\N	PRESENT	0
712082	708192	20094J	PARTICIPANT	\N	PRESENT	0
712083	708192	20062A	PARTICIPANT	\N	PRESENT	0
712084	708192	14038Y	PARTICIPANT	\N	PRESENT	0
712085	708192	20110Q	PARTICIPANT	\N	PRESENT	0
712086	708192	18083K	PARTICIPANT	\N	PRESENT	0
712087	708192	19479G	PARTICIPANT	\N	PRESENT	0
712088	708192	11065P	PARTICIPANT	\N	PRESENT	0
712089	708192	20114U	PARTICIPANT	\N	PRESENT	0
712090	708192	14026U	PARTICIPANT	\N	PRESENT	0
712091	708192	20134Y	PARTICIPANT	\N	PRESENT	0
712092	708192	19703U	PARTICIPANT	\N	PRESENT	0
712093	708192	20252E	PARTICIPANT	\N	PRESENT	0
712094	708192	20136B	PARTICIPANT	\N	PRESENT	0
712095	708192	20054A	PARTICIPANT	\N	PRESENT	0
712096	708192	19295A	PARTICIPANT	\N	PRESENT	0
712097	708192	11026G	PARTICIPANT	\N	PRESENT	0
712098	708192	14179A	PARTICIPANT	\N	PRESENT	0
712099	708192	11012A	PARTICIPANT	\N	PRESENT	0
712100	708192	17637T	PARTICIPANT	\N	PRESENT	0
712101	708192	19575F	PARTICIPANT	\N	PRESENT	0
713515	712584	11045K	PARTICIPANT	\N	PRESENT	0
713531	712584	20034V	PARTICIPANT	\N	PRESENT	0
713532	712584	17737W	PARTICIPANT	\N	PRESENT	0
713533	712584	04092N	PARTICIPANT	\N	PRESENT	0
713534	712584	12016W	PARTICIPANT	\N	PRESENT	0
713535	712584	04085P	PARTICIPANT	\N	PRESENT	0
713536	712584	17023S	PARTICIPANT	\N	PRESENT	0
713537	712584	19717B	PARTICIPANT	\N	PRESENT	0
713538	712584	14259Y	PARTICIPANT	\N	PRESENT	0
713539	712584	19585H	PARTICIPANT	\N	PRESENT	0
713540	712584	20110Q	PARTICIPANT	\N	PRESENT	0
713541	712584	20106U	PARTICIPANT	\N	PRESENT	0
713544	712584	18083K	PARTICIPANT	\N	PRESENT	0
713545	712584	14237S	PARTICIPANT	\N	PRESENT	0
713546	712584	04047H	PARTICIPANT	\N	PRESENT	0
713547	712584	14071N	PARTICIPANT	\N	PRESENT	0
713548	712584	97011G	PARTICIPANT	\N	PRESENT	0
713549	712584	19649G	PARTICIPANT	\N	PRESENT	0
713550	712584	19295A	PARTICIPANT	\N	PRESENT	0
713551	712584	14111D	PARTICIPANT	\N	PRESENT	0
713552	712584	19333N	PARTICIPANT	\N	PRESENT	0
713553	712584	19715Y	PARTICIPANT	\N	PRESENT	0
713554	712584	19301E	PARTICIPANT	\N	PRESENT	0
713555	712584	08073C	PARTICIPANT	\N	PRESENT	0
713556	712584	20026V	PARTICIPANT	\N	PRESENT	0
713557	712584	19629C	PARTICIPANT	\N	PRESENT	0
713558	712584	20052X	PARTICIPANT	\N	PRESENT	0
713559	712584	14031R	PARTICIPANT	\N	PRESENT	0
713560	712584	14053L	PARTICIPANT	\N	PRESENT	0
713561	712584	14249W	PARTICIPANT	\N	PRESENT	0
713562	712584	20062A	PARTICIPANT	\N	PRESENT	0
713563	712584	20098N	PARTICIPANT	\N	PRESENT	0
713564	712584	11072N	PARTICIPANT	\N	PRESENT	0
713565	712584	14069U	PARTICIPANT	\N	PRESENT	0
713566	712584	08028W	PARTICIPANT	\N	PRESENT	0
713567	712584	19467C	PARTICIPANT	\N	PRESENT	0
713568	712584	14033T	PARTICIPANT	\N	PRESENT	0
713569	712584	14021P	PARTICIPANT	\N	PRESENT	0
713570	712584	19387D	PARTICIPANT	\N	PRESENT	0
713571	712584	20020P	PARTICIPANT	\N	PRESENT	0
713572	712584	08015R	PARTICIPANT	\N	PRESENT	0
713573	712584	20124W	PARTICIPANT	\N	PRESENT	0
713574	712584	19525U	PARTICIPANT	\N	PRESENT	0
713575	712584	01024M	PARTICIPANT	\N	PRESENT	0
713576	712584	01028R	PARTICIPANT	\N	PRESENT	0
713577	712584	20248J	PARTICIPANT	\N	PRESENT	0
713578	712584	14205J	PARTICIPANT	\N	PRESENT	0
713579	712584	95041E	PARTICIPANT	\N	PRESENT	0
713580	712584	19798U	PARTICIPANT	\N	PRESENT	0
713581	712584	20148F	PARTICIPANT	\N	PRESENT	0
713582	712584	18193Q	PARTICIPANT	\N	PRESENT	0
713583	713517	20086J	PARTICIPANT	\N	PRESENT	0
713584	713517	20032T	PARTICIPANT	\N	PRESENT	0
713585	713517	19531S	PARTICIPANT	\N	PRESENT	0
713586	713517	01043Q	PRESIDENT	0	PRESENT	0
713587	713517	19545Y	PARTICIPANT	\N	PRESENT	0
713588	713517	20082E	PARTICIPANT	\N	PRESENT	0
713589	713517	20046A	PARTICIPANT	\N	PRESENT	0
713590	713517	20044X	PARTICIPANT	\N	PRESENT	0
713591	713517	19399H	PARTICIPANT	\N	PRESENT	0
713592	713517	19631V	PARTICIPANT	\N	PRESENT	0
713593	713517	11110B	PARTICIPANT	\N	PRESENT	0
713594	713517	05008E	PARTICIPANT	\N	PRESENT	0
713595	713517	14231L	PARTICIPANT	\N	PRESENT	0
713596	713517	20098N	PARTICIPANT	\N	PRESENT	0
713597	713517	20058E	PARTICIPANT	\N	PRESENT	0
713598	713517	14205J	PARTICIPANT	\N	PRESENT	0
713599	713517	19489J	PARTICIPANT	\N	PRESENT	0
713600	713517	19573D	PARTICIPANT	\N	PRESENT	0
713601	713517	19503N	PARTICIPANT	\N	PRESENT	0
713602	713517	14069U	PARTICIPANT	\N	PRESENT	0
713603	713517	20298U	PARTICIPANT	\N	PRESENT	0
713604	713517	11065P	PARTICIPANT	\N	PRESENT	0
713605	713517	19525U	PARTICIPANT	\N	PRESENT	0
713606	713517	20120S	PARTICIPANT	\N	PRESENT	0
713607	712584	01025N	PARTICIPANT	\N	PRESENT	0
713608	712584	19747H	PARTICIPANT	\N	PRESENT	0
713609	712584	19866P	PARTICIPANT	\N	PRESENT	0
713610	712584	11056N	PARTICIPANT	\N	PRESENT	0
713611	712584	14179A	PARTICIPANT	\N	PRESENT	0
713612	712584	19681G	PARTICIPANT	\N	PRESENT	0
713613	712584	14121F	PARTICIPANT	\N	PRESENT	0
713614	712584	14107H	PARTICIPANT	\N	PRESENT	0
713615	712584	14275Y	PARTICIPANT	\N	PRESENT	0
713616	712584	20044X	PARTICIPANT	\N	PRESENT	0
713617	712584	19782L	PARTICIPANT	\N	PRESENT	0
713618	712584	20116W	PARTICIPANT	\N	PRESENT	0
713619	712584	19563B	PARTICIPANT	\N	PRESENT	0
713620	712584	20108W	PARTICIPANT	\N	PRESENT	0
713621	712584	20036X	PARTICIPANT	\N	PRESENT	0
713622	712584	14073Q	PARTICIPANT	\N	PRESENT	0
713623	712584	20032T	PARTICIPANT	\N	PRESENT	0
713624	712584	14147R	PARTICIPANT	\N	PRESENT	0
713625	712584	19349W	PARTICIPANT	\N	PRESENT	0
713626	712584	20058E	PARTICIPANT	\N	PRESENT	0
713627	712584	19657G	PARTICIPANT	\N	PRESENT	0
713628	712584	17367Q	PARTICIPANT	\N	PRESENT	0
713629	712584	14037X	PARTICIPANT	\N	PRESENT	0
713630	712584	14059S	PARTICIPANT	\N	PRESENT	0
713631	712584	19577H	PARTICIPANT	\N	PRESENT	0
713632	712584	14223L	PARTICIPANT	\N	PRESENT	0
713633	712584	14257W	PARTICIPANT	\N	PRESENT	0
713634	712584	14151M	PARTICIPANT	\N	PRESENT	0
713636	712584	20024T	PARTICIPANT	\N	PRESENT	0
713637	712584	19575F	PARTICIPANT	\N	PRESENT	0
713638	712584	19479G	PARTICIPANT	\N	PRESENT	0
713639	712584	01043Q	PARTICIPANT	\N	PRESENT	0
713640	712584	11065P	PARTICIPANT	\N	PRESENT	0
713641	712584	07004J	PARTICIPANT	\N	PRESENT	0
713642	712584	08060W	PARTICIPANT	\N	PRESENT	0
713643	712584	01048V	PARTICIPANT	\N	PRESENT	0
713644	712584	19703U	PARTICIPANT	\N	PRESENT	0
713645	712584	14231L	PARTICIPANT	\N	PRESENT	0
713646	712584	20298U	PARTICIPANT	\N	PRESENT	0
713647	712584	20144B	PARTICIPANT	\N	PRESENT	0
713648	712584	20040T	PARTICIPANT	\N	PRESENT	0
713649	712584	11110B	PARTICIPANT	\N	PRESENT	0
713650	712584	19631V	PARTICIPANT	\N	PRESENT	0
713651	712584	20082E	PARTICIPANT	\N	PRESENT	0
713652	712584	14207L	PARTICIPANT	\N	PRESENT	0
713653	712584	98022P	PARTICIPANT	\N	PRESENT	0
713654	712584	19758L	PARTICIPANT	\N	PRESENT	0
713655	712584	14030Q	PARTICIPANT	\N	PRESENT	0
713656	712584	14219Q	PARTICIPANT	\N	PRESENT	0
713657	712584	05008E	PARTICIPANT	\N	PRESENT	0
713658	712584	19383Y	PARTICIPANT	\N	PRESENT	0
713659	712585	11045K	PARTICIPANT	\N	PRESENT	0
728637	728217	19760E	PARTICIPANT	\N	PRESENT	0
728638	728217	19758L	PARTICIPANT	\N	PRESENT	0
728639	728217	20914V	PARTICIPANT	\N	PRESENT	0
728640	728217	14213J	PARTICIPANT	\N	PRESENT	0
728641	728217	10006L	PARTICIPANT	\N	PRESENT	0
728642	728217	04045F	PARTICIPANT	\N	PRESENT	0
728643	728217	20088L	PARTICIPANT	\N	PRESENT	0
728644	728217	20082E	PARTICIPANT	\N	PRESENT	0
728645	728217	19333N	PARTICIPANT	\N	PRESENT	0
728646	728217	20070A	PARTICIPANT	\N	PRESENT	0
728647	728217	08045X	PARTICIPANT	\N	PRESENT	0
728648	728217	19683J	PARTICIPANT	\N	PRESENT	0
728649	728217	20266L	PARTICIPANT	\N	PRESENT	0
728650	728217	14195A	PARTICIPANT	\N	PRESENT	0
728651	728217	14107H	PARTICIPANT	\N	PRESENT	0
728652	728217	19681G	PARTICIPANT	\N	PRESENT	0
728653	728217	14207L	PARTICIPANT	\N	PRESENT	0
728654	728217	19637C	PARTICIPANT	\N	PRESENT	0
728655	728217	19569H	PARTICIPANT	\N	PRESENT	0
728656	728217	19329S	PARTICIPANT	\N	PRESENT	0
728657	728217	19719D	PARTICIPANT	\N	PRESENT	0
728658	728217	20066E	PARTICIPANT	\N	PRESENT	0
728659	728217	20034V	PARTICIPANT	\N	PRESENT	0
728660	728217	20078J	PARTICIPANT	\N	PRESENT	0
728661	728217	19369B	PARTICIPANT	\N	PRESENT	0
728662	728217	19479G	PARTICIPANT	\N	PRESENT	0
728663	728217	19739H	PARTICIPANT	\N	PRESENT	0
728664	728217	20286Q	PARTICIPANT	\N	PRESENT	0
728665	728217	14030Q	PARTICIPANT	\N	PRESENT	0
728666	728217	19575F	PARTICIPANT	\N	PRESENT	0
728667	728217	14083S	PARTICIPANT	\N	PRESENT	0
728668	728217	14038Y	PARTICIPANT	\N	PRESENT	0
728669	728217	14237S	PARTICIPANT	\N	PRESENT	0
728670	728217	20054A	PARTICIPANT	\N	PRESENT	0
728671	728217	14031R	PARTICIPANT	\N	PRESENT	0
728672	728217	14059S	PARTICIPANT	\N	PRESENT	0
728673	728217	20076G	PARTICIPANT	\N	PRESENT	0
728674	728217	20062A	PARTICIPANT	\N	PRESENT	0
728675	728217	19383Y	PARTICIPANT	\N	PRESENT	0
728676	728217	20068G	PARTICIPANT	\N	PRESENT	0
728677	728217	20026V	PARTICIPANT	\N	PRESENT	0
728678	728217	19747H	PARTICIPANT	\N	PRESENT	0
728679	728217	19507S	PARTICIPANT	\N	PRESENT	0
728680	728217	19467C	PARTICIPANT	\N	PRESENT	0
728681	728217	18083K	PARTICIPANT	\N	PRESENT	0
728682	728217	01058X	PARTICIPANT	\N	PRESENT	0
728683	728217	20022R	PARTICIPANT	\N	PRESENT	0
728684	728217	14223L	PARTICIPANT	\N	PRESENT	0
728685	728217	19525U	PARTICIPANT	\N	PRESENT	0
728686	728217	19782L	PARTICIPANT	\N	PRESENT	0
728687	728217	20038A	PARTICIPANT	\N	PRESENT	0
728635	728217	11045K	PARTICIPANT	\N	PRESENT	0
728636	728217	11031D	PARTICIPANT	\N	PRESENT	0
728688	728217	19631V	PARTICIPANT	\N	PRESENT	0
728690	728217	17779H	PARTICIPANT	\N	PRESENT	0
728696	728217	14071N	PARTICIPANT	\N	PRESENT	0
728697	728217	17965H	PARTICIPANT	\N	PRESENT	0
728698	728217	11012A	PARTICIPANT	\N	PRESENT	0
728699	728217	19441R	PARTICIPANT	\N	PRESENT	0
728700	728217	04043D	PARTICIPANT	\N	PRESENT	0
728701	728217	01024M	PARTICIPANT	\N	PRESENT	0
728703	728217	97011G	PARTICIPANT	\N	PRESENT	0
728704	728217	20024T	PARTICIPANT	\N	PRESENT	0
728705	728028	14189C	PARTICIPANT	\N	EXCUSE	0
728706	728028	20024T	PARTICIPANT	\N	EXCUSE	0
728707	728028	20130U	PARTICIPANT	\N	EXCUSE	0
728708	728028	20118Y	PARTICIPANT	\N	EXCUSE	0
728709	728217	04092N	PARTICIPANT	\N	PRESENT	0
728710	728217	19798U	PARTICIPANT	\N	PRESENT	0
728711	728217	14281W	PARTICIPANT	\N	PRESENT	0
728712	728217	08010L	PARTICIPANT	\N	PRESENT	0
728713	728217	11067R	PARTICIPANT	\N	PRESENT	0
728714	728217	19649G	PARTICIPANT	\N	PRESENT	0
728715	728217	14033T	PARTICIPANT	\N	PRESENT	0
728716	728217	19703U	PARTICIPANT	\N	PRESENT	0
728717	728217	04057K	PARTICIPANT	\N	PRESENT	0
728718	728217	14147R	PARTICIPANT	\N	PRESENT	0
728719	728217	08028W	PARTICIPANT	\N	PRESENT	0
728720	728217	14259Y	PARTICIPANT	\N	PRESENT	0
728721	728217	14026U	PARTICIPANT	\N	PRESENT	0
728722	728217	98022P	PARTICIPANT	\N	PRESENT	0
728723	728217	11040E	PARTICIPANT	\N	PRESENT	0
728724	728219	11045K	PARTICIPANT	\N	PRESENT	0
728725	728219	11031D	PARTICIPANT	\N	PRESENT	0
728726	728219	19760E	PARTICIPANT	\N	PRESENT	0
728727	728219	19758L	PARTICIPANT	\N	PRESENT	0
728728	728219	14213J	PARTICIPANT	\N	PRESENT	0
728729	728219	10006L	PARTICIPANT	\N	PRESENT	0
728730	728219	04045F	PARTICIPANT	\N	PRESENT	0
728731	728219	20088L	PARTICIPANT	\N	PRESENT	0
728732	728219	19333N	PARTICIPANT	\N	PRESENT	0
728733	728219	20070A	PARTICIPANT	\N	PRESENT	0
728734	728219	08045X	PARTICIPANT	\N	PRESENT	0
728735	728219	19683J	PARTICIPANT	\N	PRESENT	0
728736	728219	20266L	PARTICIPANT	\N	PRESENT	0
728737	728219	14195A	PARTICIPANT	\N	PRESENT	0
728738	728219	14107H	PARTICIPANT	\N	PRESENT	0
728739	728219	14207L	PARTICIPANT	\N	PRESENT	0
728740	728219	19329S	PARTICIPANT	\N	PRESENT	0
728741	728219	20066E	PARTICIPANT	\N	PRESENT	0
728742	728219	20034V	PARTICIPANT	\N	PRESENT	0
728743	728219	20078J	PARTICIPANT	\N	PRESENT	0
728744	728219	19739H	PARTICIPANT	\N	PRESENT	0
728745	728219	14038Y	PARTICIPANT	\N	PRESENT	0
728746	728219	20054A	PARTICIPANT	\N	PRESENT	0
728747	728219	14059S	PARTICIPANT	\N	PRESENT	0
728748	728219	20076G	PARTICIPANT	\N	PRESENT	0
728749	728219	20062A	PARTICIPANT	\N	PRESENT	0
728750	728219	19383Y	PARTICIPANT	\N	PRESENT	0
728751	728219	20026V	PARTICIPANT	\N	PRESENT	0
728752	728219	19747H	PARTICIPANT	\N	PRESENT	0
728753	728219	01058X	PARTICIPANT	\N	PRESENT	0
728754	728219	14223L	PARTICIPANT	\N	PRESENT	0
728755	728219	17779H	PARTICIPANT	\N	PRESENT	0
728756	728219	17965H	PARTICIPANT	\N	PRESENT	0
728757	728219	11012A	PARTICIPANT	\N	PRESENT	0
728758	728219	19441R	PARTICIPANT	\N	PRESENT	0
728759	728219	04043D	PARTICIPANT	\N	PRESENT	0
728760	728219	01024M	PARTICIPANT	\N	PRESENT	0
728761	728219	20024T	PARTICIPANT	\N	PRESENT	0
728762	728219	04092N	PARTICIPANT	\N	PRESENT	0
728763	728219	19798U	PARTICIPANT	\N	PRESENT	0
728764	728219	14281W	PARTICIPANT	\N	PRESENT	0
728765	728219	11067R	PARTICIPANT	\N	PRESENT	0
728766	728219	14033T	PARTICIPANT	\N	PRESENT	0
728767	728219	19703U	PARTICIPANT	\N	PRESENT	0
728768	728219	04057K	PARTICIPANT	\N	PRESENT	0
728769	728219	14147R	PARTICIPANT	\N	PRESENT	0
728770	728219	08028W	PARTICIPANT	\N	PRESENT	0
728771	728219	14026U	PARTICIPANT	\N	PRESENT	0
728772	728219	98022P	PARTICIPANT	\N	PRESENT	0
728773	728219	11040E	PARTICIPANT	\N	PRESENT	0
728774	728219	97011G	PARTICIPANT	\N	PRESENT	0
728775	728219	01025N	PARTICIPANT	\N	PRESENT	0
728776	728219	08010L	PARTICIPANT	\N	PRESENT	0
728780	728219	20090E	PARTICIPANT	\N	PRESENT	0
728781	728219	19569H	PARTICIPANT	\N	PRESENT	0
728782	728219	20130U	PARTICIPANT	\N	PRESENT	0
728783	728219	19467C	PARTICIPANT	\N	PRESENT	0
728784	728219	20018V	PARTICIPANT	\N	PRESENT	0
728785	728028	20080C	PARTICIPANT	\N	EXCUSE	0
728786	728219	11056N	PARTICIPANT	\N	PRESENT	0
728792	728219	20140W	PARTICIPANT	\N	PRESENT	0
728793	728219	14111D	PARTICIPANT	\N	PRESENT	0
728794	728219	20032T	PARTICIPANT	\N	PRESENT	0
728795	728219	14267Y	PARTICIPANT	\N	PRESENT	0
728797	728219	20048C	PARTICIPANT	\N	PRESENT	0
728798	728219	14189C	PARTICIPANT	\N	PRESENT	0
728799	728219	14030Q	PARTICIPANT	\N	PRESENT	0
728800	728219	20098N	PARTICIPANT	\N	PRESENT	0
728801	728219	14042U	PARTICIPANT	\N	PRESENT	0
728802	728219	20022R	PARTICIPANT	\N	PRESENT	0
728803	728219	14259Y	PARTICIPANT	\N	PRESENT	0
728804	728219	14109K	PARTICIPANT	\N	PRESENT	0
728805	728219	20142Y	PARTICIPANT	\N	PRESENT	0
728806	728219	19479G	PARTICIPANT	\N	PRESENT	0
728807	728219	19691J	PARTICIPANT	\N	PRESENT	0
728808	728219	20108W	PARTICIPANT	\N	PRESENT	0
728809	728219	14037X	PARTICIPANT	\N	PRESENT	0
728810	728216	11045K	PARTICIPANT	\N	PRESENT	0
728811	728216	11031D	PARTICIPANT	\N	PRESENT	0
716614	716609	14187A	PRESIDENT	0	PRESENT	0
716615	716609	19347U	PARTICIPANT	\N	PRESENT	0
716616	716609	11077T	PARTICIPANT	\N	PRESENT	0
716617	716609	14257W	PARTICIPANT	\N	PRESENT	0
716618	716609	19701S	PARTICIPANT	\N	PRESENT	0
716628	716609	17023S	PARTICIPANT	\N	PRESENT	0
716629	716548	04070G	PARTICIPANT	\N	PRESENT	0
716630	716548	20064C	PRESIDENT	0	PRESENT	0
716631	716548	14251Q	PARTICIPANT	\N	PRESENT	0
716632	716548	11083R	PARTICIPANT	\N	PRESENT	0
716633	716548	14030Q	PARTICIPANT	\N	PRESENT	0
716634	716548	19643A	PARTICIPANT	\N	EXCUSE	0
716635	716548	17737W	PARTICIPANT	\N	EXCUSE	0
716636	716548	20068G	PARTICIPANT	\N	EXCUSE	0
716644	716548	20134Y	PARTICIPANT	\N	PRESENT	0
718379	690827	17023S	PARTICIPANT	\N	PRESENT	0
726800	726798	14059S	PARTICIPANT	\N	PRESENT	0
726801	726798	14193X	PARTICIPANT	\N	PRESENT	0
727101	725949	14001X	PARTICIPANT	\N	EXCUSE	0
727102	725949	14331P	PARTICIPANT	\N	EXCUSE	0
727103	725949	20110Q	PARTICIPANT	\N	EXCUSE	0
727105	725949	19703U	PARTICIPANT	\N	EXCUSE	0
727515	725949	19629C	PRESIDENT	0	PRESENT	0
727516	725949	19954N	PARTICIPANT	\N	PRESENT	0
727517	725949	19489J	PARTICIPANT	\N	PRESENT	0
727519	725949	14259Y	PARTICIPANT	\N	PRESENT	0
727520	725949	11056N	PARTICIPANT	\N	PRESENT	0
727522	725949	11110B	PARTICIPANT	\N	PRESENT	0
727526	725949	14329V	PARTICIPANT	\N	PRESENT	0
730267	730266	20090E	PARTICIPANT	\N	PRESENT	0
730268	730266	14187A	PRESIDENT	0	PRESENT	0
730269	730266	19347U	PARTICIPANT	\N	PRESENT	0
730270	730266	20286Q	PARTICIPANT	\N	PRESENT	0
730271	730266	20018V	PARTICIPANT	\N	PRESENT	0
730272	730266	14257W	PARTICIPANT	\N	PRESENT	0
730273	728222	20044X	PARTICIPANT	\N	PRESENT	0
730274	730266	17023S	PARTICIPANT	\N	PRESENT	0
730275	728222	01024M	PARTICIPANT	\N	PRESENT	0
730276	728222	19699S	PARTICIPANT	\N	PRESENT	0
730277	728222	14069U	PARTICIPANT	\N	PRESENT	0
730278	728222	14147R	PARTICIPANT	\N	PRESENT	0
730279	728222	11033F	PARTICIPANT	\N	PRESENT	0
730280	728222	19565D	PARTICIPANT	\N	PRESENT	0
730281	728222	19629C	PARTICIPANT	\N	PRESENT	0
730282	725883	08010L	PARTICIPANT	\N	PRESENT	0
730283	725883	20084G	PARTICIPANT	\N	PRESENT	0
730312	728224	11012A	PARTICIPANT	\N	PRESENT	0
730313	728224	19629C	PARTICIPANT	\N	PRESENT	0
730314	728224	11033F	PARTICIPANT	\N	PRESENT	0
730315	728224	14231L	PARTICIPANT	\N	PRESENT	0
730316	728224	19479G	PARTICIPANT	\N	PRESENT	0
730317	728224	19713W	PARTICIPANT	\N	PRESENT	0
730321	728224	01024M	PARTICIPANT	\N	PRESENT	0
730322	728224	19699S	PARTICIPANT	\N	PRESENT	0
730323	728224	08010L	PARTICIPANT	\N	PRESENT	0
730324	728224	20180F	PARTICIPANT	\N	PRESENT	0
730325	728224	20026V	PARTICIPANT	\N	PRESENT	0
730326	728224	20108W	PARTICIPANT	\N	PRESENT	0
730327	728224	17737W	PARTICIPANT	\N	PRESENT	0
730328	728224	19565D	PARTICIPANT	\N	PRESENT	0
730329	728224	19749K	PARTICIPANT	\N	PRESENT	0
730330	728224	97011G	PARTICIPANT	\N	PRESENT	0
730331	728224	17589D	PARTICIPANT	\N	PRESENT	0
730332	728224	20082E	PARTICIPANT	\N	PRESENT	0
730333	728224	11056N	PARTICIPANT	\N	PRESENT	0
730334	728224	04047H	PARTICIPANT	\N	PRESENT	0
730335	728224	20114U	PARTICIPANT	\N	PRESENT	0
730336	728224	20098N	PARTICIPANT	\N	PRESENT	0
730337	728224	20022R	PARTICIPANT	\N	PRESENT	0
730338	728224	20056C	PARTICIPANT	\N	PRESENT	0
730339	728224	19691J	PARTICIPANT	\N	PRESENT	0
730348	728224	20052X	PARTICIPANT	\N	PRESENT	0
730310	728224	12041X	PARTICIPANT	\N	PRESENT	0
730311	728224	11072N	PARTICIPANT	\N	PRESENT	0
730349	728224	20266L	PARTICIPANT	\N	PRESENT	0
731298	730642	19629C	PRESIDENT	0	PRESENT	0
731299	730642	14259Y	PARTICIPANT	\N	PRESENT	0
731300	730642	19383Y	PARTICIPANT	\N	PRESENT	0
731301	730642	11056N	PARTICIPANT	\N	PRESENT	0
731302	730642	19954N	PARTICIPANT	\N	PRESENT	0
732310	730686	11085T	PARTICIPANT	\N	PRESENT	0
732311	730686	19826F	PARTICIPANT	\N	PRESENT	0
732312	730686	08009T	PARTICIPANT	\N	PRESENT	0
732313	730686	19369B	PARTICIPANT	\N	PRESENT	0
732314	730686	04070G	PARTICIPANT	\N	PRESENT	0
732315	730686	19745F	PARTICIPANT	\N	PRESENT	0
732319	730686	19649G	PARTICIPANT	\N	PRESENT	0
732317	730686	19619A	PARTICIPANT	\N	PRESENT	0
732318	730686	19713W	PARTICIPANT	\N	PRESENT	0
732321	730686	14083S	PARTICIPANT	\N	PRESENT	0
732325	730686	14069U	PARTICIPANT	\N	PRESENT	0
732323	730686	14255U	PARTICIPANT	\N	PRESENT	0
732324	730686	17023S	PARTICIPANT	\N	PRESENT	0
732328	730686	14151M	PARTICIPANT	\N	PRESENT	0
732592	730687	11070L	PARTICIPANT	\N	PRESENT	0
732622	730687	14147R	PARTICIPANT	\N	PRESENT	0
732594	730687	04035D	PARTICIPANT	\N	PRESENT	0
732627	730687	19563B	PARTICIPANT	\N	PRESENT	0
732596	730687	20116W	PARTICIPANT	\N	PRESENT	0
732623	730687	19798U	PARTICIPANT	\N	PRESENT	0
732621	730687	20152B	PARTICIPANT	\N	PRESENT	0
732620	730687	20098N	PARTICIPANT	\N	PRESENT	0
732600	730687	19347U	PARTICIPANT	\N	PRESENT	0
732601	730687	20106U	PARTICIPANT	\N	PRESENT	0
732624	730687	20032T	PARTICIPANT	\N	PRESENT	0
732603	730687	14033T	PARTICIPANT	\N	PRESENT	0
732604	730687	12041X	PARTICIPANT	\N	PRESENT	0
732625	730687	14069U	PARTICIPANT	\N	PRESENT	0
732606	730687	01060R	PARTICIPANT	\N	PRESENT	0
732607	730687	20024T	PARTICIPANT	\N	PRESENT	0
732629	730687	19573D	PARTICIPANT	\N	PRESENT	0
732609	730687	19713W	PARTICIPANT	\N	PRESENT	0
732630	730687	11012A	PARTICIPANT	\N	PRESENT	0
732611	730687	19057M	PARTICIPANT	\N	PRESENT	0
732612	730687	19479G	PARTICIPANT	\N	PRESENT	0
732626	730687	14251Q	PARTICIPANT	\N	PRESENT	0
732631	730687	19553Y	PARTICIPANT	\N	PRESENT	0
732616	730687	19515S	PARTICIPANT	\N	PRESENT	0
732632	730687	20054A	PARTICIPANT	\N	PRESENT	0
732633	730687	11027H	PARTICIPANT	\N	PRESENT	0
732634	730687	14021P	PARTICIPANT	\N	PRESENT	0
732638	730687	20082E	PARTICIPANT	\N	PRESENT	0
732640	730687	20108W	PARTICIPANT	\N	PRESENT	0
732643	732641	14357A	PARTICIPANT	\N	PRESENT	0
732644	732641	11097X	PARTICIPANT	\N	PRESENT	0
732645	732641	11053K	PARTICIPANT	\N	PRESENT	0
732646	732641	20102Q	PARTICIPANT	\N	PRESENT	0
732648	730687	19441R	PARTICIPANT	\N	PRESENT	0
732651	730687	19741B	PARTICIPANT	\N	PRESENT	0
732652	732641	20180F	PARTICIPANT	\N	PRESENT	0
732656	730687	20048C	PARTICIPANT	\N	PRESENT	0
732660	730687	20042V	PARTICIPANT	\N	PRESENT	0
732664	730687	11115U	PARTICIPANT	\N	PRESENT	0
732676	730687	04085P	PARTICIPANT	\N	PRESENT	0
732705	730675	01062T	PARTICIPANT	\N	PRESENT	0
732706	730675	19565D	PARTICIPANT	\N	PRESENT	0
732707	730675	01058X	PARTICIPANT	\N	PRESENT	0
732708	730675	04042C	PRESIDENT	0	PRESENT	0
732709	730675	11054L	PARTICIPANT	\N	PRESENT	0
732710	730675	12028B	PARTICIPANT	\N	PRESENT	0
732711	730675	20064C	PARTICIPANT	\N	PRESENT	0
732712	730675	11064N	PARTICIPANT	\N	PRESENT	0
732713	730675	11083R	PARTICIPANT	\N	PRESENT	0
732714	730675	08061X	PARTICIPANT	\N	PRESENT	0
732715	730675	17023S	PARTICIPANT	\N	PRESENT	0
732716	730675	20128B	PARTICIPANT	\N	PRESENT	0
732717	730675	14255U	PARTICIPANT	\N	PRESENT	0
732729	730675	08056B	PARTICIPANT	\N	EXCUSE	0
732730	730675	14097Y	PARTICIPANT	\N	EXCUSE	0
732731	730675	14059S	PARTICIPANT	\N	EXCUSE	0
732732	730675	14105F	PARTICIPANT	\N	EXCUSE	0
732733	730675	20072C	PARTICIPANT	\N	EXCUSE	0
732734	730675	19421M	PARTICIPANT	\N	EXCUSE	0
732735	730675	19709B	PARTICIPANT	\N	EXCUSE	0
732736	730675	16685X	PARTICIPANT	\N	EXCUSE	0
732737	730675	14211G	PARTICIPANT	\N	EXCUSE	0
732742	730687	07029T	PARTICIPANT	\N	PRESENT	0
732743	730675	19347U	PARTICIPANT	\N	PRESENT	0
733689	733686	19820Y	PARTICIPANT	\N	PRESENT	0
732847	732845	19671E	PARTICIPANT	\N	PRESENT	0
733688	733686	05012A	PARTICIPANT	\N	PRESENT	0
735074	735072	14030Q	PARTICIPANT	\N	PRESENT	0
735075	735072	14217N	PARTICIPANT	\N	PRESENT	0
735076	735072	14215L	PARTICIPANT	\N	PRESENT	0
735077	735072	14059S	PARTICIPANT	\N	PRESENT	0
735078	735072	04057K	PARTICIPANT	\N	PRESENT	0
735079	735072	14147R	PARTICIPANT	\N	PRESENT	0
735080	735072	14071N	PARTICIPANT	\N	PRESENT	0
735081	735072	20058E	PARTICIPANT	\N	PRESENT	0
735085	732650	10006L	PRESIDENT	0	PRESENT	0
735086	732650	17779H	PARTICIPANT	\N	PRESENT	0
735087	732650	11031D	PARTICIPANT	\N	PRESENT	0
735088	732650	14281W	PARTICIPANT	\N	PRESENT	0
735089	732650	11067R	PARTICIPANT	\N	PRESENT	0
735090	732650	14195A	PARTICIPANT	\N	PRESENT	0
735091	732650	20090E	PARTICIPANT	\N	PRESENT	0
735092	732650	14071N	PARTICIPANT	\N	PRESENT	0
735093	732650	14042U	PARTICIPANT	\N	PRESENT	0
735094	732650	19798U	PARTICIPANT	\N	PRESENT	0
735096	732650	14217N	PARTICIPANT	\N	PRESENT	0
735097	732650	19415P	PARTICIPANT	\N	PRESENT	0
735098	732650	11097X	PARTICIPANT	\N	PRESENT	0
735099	732650	14213J	PARTICIPANT	\N	PRESENT	0
735100	732650	19713W	PARTICIPANT	\N	PRESENT	0
735101	732650	20066E	PARTICIPANT	\N	PRESENT	0
735102	732650	20130U	PARTICIPANT	\N	PRESENT	0
735103	732650	19295A	PARTICIPANT	\N	PRESENT	0
735104	732650	17965H	PARTICIPANT	\N	PRESENT	0
736568	736567	04070G	PARTICIPANT	\N	PRESENT	0
736569	736567	19593H	PARTICIPANT	\N	PRESENT	0
736570	736561	04070G	PARTICIPANT	\N	PRESENT	0
736571	736560	19621T	PARTICIPANT	\N	PRESENT	0
736572	736560	14109K	PARTICIPANT	\N	PRESENT	0
736573	736564	14229S	PARTICIPANT	\N	PRESENT	0
736574	736566	08012N	PARTICIPANT	\N	PRESENT	0
736575	736566	19527W	PARTICIPANT	\N	PRESENT	1
736577	736576	08012N	PARTICIPANT	\N	PRESENT	0
736579	736578	14038Y	PARTICIPANT	\N	PRESENT	0
736580	736578	20128B	PARTICIPANT	\N	PRESENT	0
736581	736578	20022R	PARTICIPANT	\N	PRESENT	0
736582	736578	20064C	PARTICIPANT	\N	PRESENT	0
736583	736578	19631V	PARTICIPANT	\N	PRESENT	0
736584	736578	14169X	PARTICIPANT	\N	PRESENT	0
736585	736578	19701S	PARTICIPANT	\N	PRESENT	0
736586	736578	19723Y	PARTICIPANT	\N	PRESENT	0
736587	736578	14083S	PARTICIPANT	\N	PRESENT	0
738172	735547	19669L	PARTICIPANT	\N	PRESENT	0
738173	735547	20264J	PARTICIPANT	\N	PRESENT	0
738174	735547	20060X	PARTICIPANT	\N	PRESENT	0
738175	735547	20100N	PARTICIPANT	\N	PRESENT	0
738176	735547	20134Y	PARTICIPANT	\N	PRESENT	0
738177	735547	20130U	PARTICIPANT	\N	PRESENT	0
738178	735547	11033F	PARTICIPANT	\N	PRESENT	0
738179	735547	11083R	PARTICIPANT	\N	PRESENT	0
738180	735547	19583F	PARTICIPANT	\N	PRESENT	0
738170	735547	11070L	PARTICIPANT	\N	PRESENT	0
738171	735547	19695N	PARTICIPANT	\N	PRESENT	0
738181	735547	20286Q	PARTICIPANT	\N	PRESENT	0
738182	735547	14083S	PARTICIPANT	\N	PRESENT	0
738183	735547	19515S	PARTICIPANT	\N	PRESENT	0
738184	735547	14026U	PARTICIPANT	\N	PRESENT	0
738185	735547	19711U	PARTICIPANT	\N	PRESENT	0
738186	735547	20072C	PARTICIPANT	\N	PRESENT	0
738187	735547	19347U	PARTICIPANT	\N	PRESENT	0
738188	735547	14069U	PARTICIPANT	\N	PRESENT	0
738370	738369	20072C	PARTICIPANT	\N	EXCUSE	0
738371	738369	19693L	PARTICIPANT	\N	EXCUSE	0
738372	738369	20066E	PARTICIPANT	\N	EXCUSE	0
738373	738369	19723Y	PARTICIPANT	\N	EXCUSE	0
738374	738369	19663E	PARTICIPANT	\N	EXCUSE	0
738451	738387	20088L	PARTICIPANT	\N	PRESENT	0
738452	738387	19515S	PARTICIPANT	\N	PRESENT	0
738453	738387	20092G	PARTICIPANT	\N	PRESENT	0
738454	738387	11077T	PARTICIPANT	\N	PRESENT	0
738455	738387	20078J	PARTICIPANT	\N	PRESENT	0
738456	738387	19413M	PARTICIPANT	\N	PRESENT	0
738457	738387	20094J	PARTICIPANT	\N	PRESENT	0
738458	738387	19631V	PARTICIPANT	\N	PRESENT	0
738459	738387	08015R	PARTICIPANT	\N	PRESENT	0
738460	738387	19575F	PARTICIPANT	\N	PRESENT	0
738461	738387	19369B	PARTICIPANT	\N	PRESENT	0
738462	738387	20018V	PARTICIPANT	\N	PRESENT	0
738463	738387	19563B	PARTICIPANT	\N	PRESENT	0
738464	738387	20028X	PARTICIPANT	\N	PRESENT	0
738465	738387	14329V	PARTICIPANT	\N	PRESENT	0
738466	738387	20034V	PARTICIPANT	\N	PRESENT	0
738467	738387	14187A	PARTICIPANT	\N	PRESENT	0
738468	738387	20144B	PARTICIPANT	\N	PRESENT	0
738469	738387	19695N	PARTICIPANT	\N	PRESENT	0
738470	738387	11090Q	PRESIDENT	0	PRESENT	0
738471	738387	14033T	PARTICIPANT	\N	PRESENT	0
738472	738387	20062A	PARTICIPANT	\N	PRESENT	0
738473	738387	14251Q	PARTICIPANT	\N	PRESENT	0
738474	738387	19507S	PARTICIPANT	\N	PRESENT	0
738475	738387	20286Q	PARTICIPANT	\N	PRESENT	0
738476	738387	20298U	PARTICIPANT	\N	PRESENT	0
738477	738387	14207L	PARTICIPANT	\N	PRESENT	0
738478	738387	14257W	PARTICIPANT	\N	PRESENT	0
738479	738387	19768N	PARTICIPANT	\N	EXCUSE	0
738480	738387	14357A	PARTICIPANT	\N	EXCUSE	0
738481	738387	04045F	PARTICIPANT	\N	EXCUSE	0
738482	738387	08028W	PARTICIPANT	\N	EXCUSE	0
738484	738003	20130U	PARTICIPANT	\N	PRESENT	0
738485	738003	20090E	PARTICIPANT	\N	PRESENT	0
738486	738003	19695N	PARTICIPANT	\N	PRESENT	0
738487	738003	20020P	PARTICIPANT	\N	PRESENT	0
738488	738003	14147R	PARTICIPANT	\N	PRESENT	0
738493	738003	08009T	PARTICIPANT	\N	PRESENT	0
738494	738003	20108W	PARTICIPANT	\N	PRESENT	0
738495	738003	19709B	PARTICIPANT	\N	PRESENT	0
738496	738003	18193Q	PARTICIPANT	\N	PRESENT	0
738497	738003	14219Q	PARTICIPANT	\N	PRESENT	0
738498	738003	20028X	PARTICIPANT	\N	PRESENT	0
738499	738003	14030Q	PARTICIPANT	\N	PRESENT	0
738500	738003	19954N	PARTICIPANT	\N	PRESENT	0
738501	738003	20070A	PARTICIPANT	\N	PRESENT	0
738515	738003	20044X	PARTICIPANT	\N	PRESENT	0
738517	738003	19533U	PARTICIPANT	\N	PRESENT	0
738518	738003	19820Y	PARTICIPANT	\N	PRESENT	0
738550	738015	14053L	PARTICIPANT	\N	PRESENT	0
738551	738015	14111D	PARTICIPANT	\N	PRESENT	0
738552	738015	19649G	PARTICIPANT	\N	PRESENT	0
738553	738015	14147R	PARTICIPANT	\N	PRESENT	0
738554	738015	14069U	PARTICIPANT	\N	PRESENT	0
738555	738015	11085T	PARTICIPANT	\N	PRESENT	0
738526	738004	12041X	PARTICIPANT	\N	PRESENT	0
738544	738015	20074E	PARTICIPANT	\N	PRESENT	0
738545	738015	14215L	PRESIDENT	0	PRESENT	0
738546	738015	19729F	PARTICIPANT	\N	EXCUSE	0
738547	738015	04047H	PARTICIPANT	\N	EXCUSE	0
738556	738015	19749K	PARTICIPANT	\N	PRESENT	0
738557	738015	19447X	PARTICIPANT	\N	PRESENT	0
738558	738015	19725B	PARTICIPANT	\N	PRESENT	0
738559	738015	20110Q	PARTICIPANT	\N	PRESENT	0
738560	738015	95063L	PARTICIPANT	\N	PRESENT	0
738713	738571	14187A	PRESIDENT	0	PRESENT	0
738714	738571	20124W	PARTICIPANT	\N	PRESENT	0
738715	738571	20286Q	PARTICIPANT	\N	PRESENT	0
738716	738571	20018V	PARTICIPANT	\N	PRESENT	0
738717	738571	20298U	PARTICIPANT	\N	PRESENT	0
738718	738571	14221J	PARTICIPANT	\N	PRESENT	0
738719	738571	19347U	PARTICIPANT	\N	PRESENT	0
738720	738571	19525U	PARTICIPANT	\N	PRESENT	0
738721	738571	20090E	PARTICIPANT	\N	PRESENT	0
738722	738571	19681G	PARTICIPANT	\N	PRESENT	0
738728	738726	04071H	PARTICIPANT	\N	PRESENT	0
738760	738759	08012N	PARTICIPANT	\N	PRESENT	0
738763	738759	20030R	PARTICIPANT	\N	PRESENT	0
738820	738816	19701S	PARTICIPANT	\N	PRESENT	0
738822	738738	19629C	PRESIDENT	0	PRESENT	0
738823	738738	14259Y	PARTICIPANT	\N	PRESENT	0
738824	738738	19421M	PARTICIPANT	\N	PRESENT	0
738825	738738	19954N	PARTICIPANT	\N	PRESENT	0
738826	738738	14329V	PARTICIPANT	\N	PRESENT	0
738828	738738	14231L	PARTICIPANT	\N	PRESENT	0
738832	738738	19383Y	PARTICIPANT	\N	PRESENT	0
738833	738738	14001X	PARTICIPANT	\N	PRESENT	0
738834	738738	11056N	PARTICIPANT	\N	PRESENT	0
738835	738738	20248J	PARTICIPANT	\N	PRESENT	0
738836	735609	19335Q	PARTICIPANT	\N	PRESENT	0
738837	735609	20106U	PARTICIPANT	\N	PRESENT	0
738839	735609	14109K	PARTICIPANT	\N	PRESENT	0
712246	712245	14215L	PARTICIPANT	\N	PRESENT	0
712247	712245	20114U	PARTICIPANT	\N	PRESENT	0
713660	712585	20034V	PARTICIPANT	\N	PRESENT	0
713661	712585	17737W	PARTICIPANT	\N	PRESENT	0
713662	712585	04092N	PARTICIPANT	\N	PRESENT	0
713759	712585	14151M	PARTICIPANT	\N	PRESENT	0
713761	712585	20090E	PARTICIPANT	\N	PRESENT	0
713665	712585	17023S	PARTICIPANT	\N	PRESENT	0
713777	712585	19693L	PARTICIPANT	\N	PRESENT	0
713667	712585	14259Y	PARTICIPANT	\N	PRESENT	0
713751	712585	19549D	PARTICIPANT	\N	PRESENT	0
713746	712585	95063L	PARTICIPANT	\N	PRESENT	0
713747	712585	19569H	PARTICIPANT	\N	PRESENT	0
713671	712585	18083K	PARTICIPANT	\N	PRESENT	0
713762	712585	14069U	PARTICIPANT	\N	PRESENT	0
713768	712585	19399H	PARTICIPANT	\N	PRESENT	0
713674	712585	97011G	PARTICIPANT	\N	PRESENT	0
713760	712585	01058X	PARTICIPANT	\N	PRESENT	0
713752	712585	19503N	PARTICIPANT	\N	PRESENT	0
713677	712585	19715Y	PARTICIPANT	\N	PRESENT	0
713748	712585	20042V	PARTICIPANT	\N	PRESENT	0
713749	712585	19735D	PARTICIPANT	\N	PRESENT	0
713770	712585	19515S	PARTICIPANT	\N	PRESENT	0
713763	712585	11090Q	PARTICIPANT	\N	PRESENT	0
713682	712585	14031R	PARTICIPANT	\N	PRESENT	0
713683	712585	14053L	PARTICIPANT	\N	PRESENT	0
713684	712585	20062A	PARTICIPANT	\N	PRESENT	0
713685	712585	20098N	PARTICIPANT	\N	PRESENT	0
713750	712585	19527W	PARTICIPANT	\N	PRESENT	0
713687	712585	19387D	PARTICIPANT	\N	PRESENT	0
713688	712585	20020P	PARTICIPANT	\N	PRESENT	0
713689	712585	01024M	PARTICIPANT	\N	PRESENT	0
713764	712585	08028W	PARTICIPANT	\N	PRESENT	0
713691	712585	19798U	PARTICIPANT	\N	PRESENT	0
713765	712585	20086J	PARTICIPANT	\N	PRESENT	0
713693	712585	18193Q	PARTICIPANT	\N	PRESENT	0
713754	712585	19525U	PARTICIPANT	\N	PRESENT	0
713695	712585	19747H	PARTICIPANT	\N	PRESENT	0
713696	712585	19866P	PARTICIPANT	\N	PRESENT	0
713697	712585	11056N	PARTICIPANT	\N	PRESENT	0
713755	712585	14111D	PARTICIPANT	\N	PRESENT	0
713779	712585	19629C	PARTICIPANT	\N	PRESENT	0
713758	712585	20046A	PARTICIPANT	\N	PRESENT	0
713701	712585	14275Y	PARTICIPANT	\N	PRESENT	0
713702	712585	20044X	PARTICIPANT	\N	PRESENT	0
713703	712585	19782L	PARTICIPANT	\N	PRESENT	0
713704	712585	20116W	PARTICIPANT	\N	PRESENT	0
713705	712585	19563B	PARTICIPANT	\N	PRESENT	0
713706	712585	20108W	PARTICIPANT	\N	PRESENT	0
713707	712585	20036X	PARTICIPANT	\N	PRESENT	0
713708	712585	20032T	PARTICIPANT	\N	PRESENT	0
713778	712585	20070A	PARTICIPANT	\N	PRESENT	0
713710	712585	19349W	PARTICIPANT	\N	PRESENT	0
713711	712585	20058E	PARTICIPANT	\N	PRESENT	0
713769	712585	01057W	PARTICIPANT	\N	PRESENT	0
713713	712585	17367Q	PARTICIPANT	\N	PRESENT	0
713714	712585	14037X	PARTICIPANT	\N	PRESENT	0
713766	712585	19489J	PARTICIPANT	\N	PRESENT	0
713788	712585	19599P	PARTICIPANT	\N	PRESENT	0
713767	712585	20028X	PARTICIPANT	\N	PRESENT	0
713756	712585	19545Y	PARTICIPANT	\N	PRESENT	0
713757	712585	14257W	PARTICIPANT	\N	PRESENT	0
713771	712585	19719D	PARTICIPANT	\N	PRESENT	0
713721	712585	19575F	PARTICIPANT	\N	PRESENT	0
713772	712585	19573D	PARTICIPANT	\N	PRESENT	0
713723	712585	01043Q	PARTICIPANT	\N	PRESENT	0
713724	712585	11065P	PARTICIPANT	\N	PRESENT	0
713725	712585	07004J	PARTICIPANT	\N	PRESENT	0
713726	712585	08060W	PARTICIPANT	\N	PRESENT	0
713727	712585	01048V	PARTICIPANT	\N	PRESENT	0
713728	712585	19703U	PARTICIPANT	\N	PRESENT	0
713729	712585	14231L	PARTICIPANT	\N	PRESENT	0
713730	712585	20298U	PARTICIPANT	\N	PRESENT	0
713731	712585	20144B	PARTICIPANT	\N	PRESENT	0
713732	712585	20040T	PARTICIPANT	\N	PRESENT	0
713733	712585	11110B	PARTICIPANT	\N	PRESENT	0
713734	712585	19631V	PARTICIPANT	\N	PRESENT	0
713735	712585	20082E	PARTICIPANT	\N	PRESENT	0
713736	712585	14207L	PARTICIPANT	\N	PRESENT	0
713737	712585	98022P	PARTICIPANT	\N	PRESENT	0
713738	712585	19758L	PARTICIPANT	\N	PRESENT	0
713739	712585	14030Q	PARTICIPANT	\N	PRESENT	0
713740	712585	14219Q	PARTICIPANT	\N	PRESENT	0
713741	712585	05008E	PARTICIPANT	\N	PRESENT	0
713742	712585	19383Y	PARTICIPANT	\N	PRESENT	0
713743	712585	19333N	PARTICIPANT	\N	PRESENT	0
713744	712585	11104D	PARTICIPANT	\N	PRESENT	0
713745	712585	20914V	PARTICIPANT	\N	PRESENT	0
713773	712585	20056C	PARTICIPANT	\N	PRESENT	0
713774	712585	19685L	PARTICIPANT	\N	PRESENT	0
713775	712585	19826F	PARTICIPANT	\N	PRESENT	0
713776	712585	20286Q	PARTICIPANT	\N	PRESENT	0
713780	712585	14107H	PARTICIPANT	\N	PRESENT	0
713781	712585	14223L	PARTICIPANT	\N	PRESENT	0
713782	712585	20120S	PARTICIPANT	\N	PRESENT	0
713783	712585	14267Y	PARTICIPANT	\N	PRESENT	0
713784	712585	14327T	PARTICIPANT	\N	PRESENT	0
713785	712585	14042U	PARTICIPANT	\N	PRESENT	0
713786	712585	01025N	PARTICIPANT	\N	PRESENT	0
713787	712585	20084G	PARTICIPANT	\N	PRESENT	0
713789	712585	14237S	PARTICIPANT	\N	PRESENT	0
713790	712585	95041E	PARTICIPANT	\N	PRESENT	0
713791	712585	01034P	PARTICIPANT	\N	PRESENT	0
713792	712585	20092G	PARTICIPANT	\N	PRESENT	0
713793	712585	17229F	PARTICIPANT	\N	PRESENT	0
713794	712585	14059S	PARTICIPANT	\N	PRESENT	0
713796	712585	19621T	PARTICIPANT	\N	PRESENT	0
713797	712585	14038Y	PARTICIPANT	\N	PRESENT	0
713798	712585	20180F	PARTICIPANT	\N	PRESENT	0
713799	712585	16685X	PARTICIPANT	\N	PRESENT	0
713800	712585	11054L	PARTICIPANT	\N	PRESENT	0
713801	712585	19681G	PARTICIPANT	\N	PRESENT	0
713802	712585	19467C	PARTICIPANT	\N	PRESENT	0
713803	712585	19533U	PARTICIPANT	\N	PRESENT	0
713804	712585	14205J	PARTICIPANT	\N	PRESENT	0
713805	712585	20140W	PARTICIPANT	\N	PRESENT	0
713806	712585	14189C	PARTICIPANT	\N	PRESENT	0
713807	712585	20026V	PARTICIPANT	\N	PRESENT	0
713808	712585	08015R	PARTICIPANT	\N	PRESENT	0
713809	712585	20248J	PARTICIPANT	\N	PRESENT	0
713810	712585	19479G	PARTICIPANT	\N	PRESENT	0
713811	712585	19749K	PARTICIPANT	\N	PRESENT	0
713812	712585	04057K	PARTICIPANT	\N	PRESENT	0
713813	712585	20024T	PARTICIPANT	\N	PRESENT	0
713814	712585	19691J	PARTICIPANT	\N	PRESENT	0
713815	712585	19760E	PARTICIPANT	\N	PRESENT	0
713816	712585	20052X	PARTICIPANT	\N	PRESENT	0
713817	712585	14026U	PARTICIPANT	\N	PRESENT	0
713818	712585	20100N	PARTICIPANT	\N	PRESENT	0
713819	712585	11072N	PARTICIPANT	\N	PRESENT	0
713820	712585	08012N	PARTICIPANT	\N	PRESENT	0
713821	712585	01028R	PARTICIPANT	\N	PRESENT	0
713822	712585	19673G	PARTICIPANT	\N	PRESENT	0
713823	712585	19713W	PARTICIPANT	\N	PRESENT	0
713824	712585	14073Q	PARTICIPANT	\N	PRESENT	0
713825	709057	14237S	PARTICIPANT	\N	PRESENT	0
713826	709057	19251M	PRESIDENT	0	PRESENT	0
713827	712585	14217N	PARTICIPANT	\N	PRESENT	0
713828	709057	11053K	PARTICIPANT	\N	PRESENT	0
713831	712585	19369B	PARTICIPANT	\N	PRESENT	0
713832	712585	14187A	PARTICIPANT	\N	PRESENT	0
713833	712585	08010L	PARTICIPANT	\N	PRESENT	0
713836	712585	14089Y	PARTICIPANT	\N	PRESENT	0
713837	709057	14357A	PARTICIPANT	\N	PRESENT	0
713838	709057	20052X	PARTICIPANT	\N	PRESENT	0
713839	712585	05012A	PARTICIPANT	\N	PRESENT	0
713840	709057	19575F	PARTICIPANT	\N	EXCUSE	0
713841	712585	19447X	PARTICIPANT	\N	PRESENT	0
713842	712585	14021P	PARTICIPANT	\N	PRESENT	0
713843	712585	19413M	PARTICIPANT	\N	PRESENT	0
713844	712585	14147R	PARTICIPANT	\N	PRESENT	0
713845	712585	19335Q	PARTICIPANT	\N	PRESENT	0
713846	712585	19367Y	PARTICIPANT	\N	PRESENT	0
713847	712585	11012A	PARTICIPANT	\N	PRESENT	0
713848	712585	14033T	PARTICIPANT	\N	PRESENT	0
713849	712585	19531S	PARTICIPANT	\N	PRESENT	0
713850	712585	20080C	PARTICIPANT	\N	PRESENT	0
713851	712585	14083S	PARTICIPANT	\N	PRESENT	0
713852	712585	19768N	PARTICIPANT	\N	PRESENT	0
713853	712585	19347U	PARTICIPANT	\N	PRESENT	0
713854	712585	19421M	PARTICIPANT	\N	PRESENT	0
728866	728216	20142Y	PARTICIPANT	\N	PRESENT	0
728813	728216	04045F	PARTICIPANT	\N	PRESENT	0
728886	728216	14071N	PARTICIPANT	\N	PRESENT	0
728815	728216	14207L	PARTICIPANT	\N	PRESENT	0
728868	728216	14205J	PARTICIPANT	\N	PRESENT	0
728817	728216	14038Y	PARTICIPANT	\N	PRESENT	0
728818	728216	20054A	PARTICIPANT	\N	PRESENT	0
728819	728216	14059S	PARTICIPANT	\N	PRESENT	0
728869	728216	11033F	PARTICIPANT	\N	PRESENT	0
728870	728216	20104S	PARTICIPANT	\N	PRESENT	0
728888	728216	20062A	PARTICIPANT	\N	PRESENT	0
728823	728216	19747H	PARTICIPANT	\N	PRESENT	0
728824	728216	14223L	PARTICIPANT	\N	PRESENT	0
728825	728216	17965H	PARTICIPANT	\N	PRESENT	0
728887	728216	20026V	PARTICIPANT	\N	PRESENT	0
728827	728216	04043D	PARTICIPANT	\N	PRESENT	0
728828	728216	01024M	PARTICIPANT	\N	PRESENT	0
728829	728216	97011G	PARTICIPANT	\N	PRESENT	0
728889	728216	20090E	PARTICIPANT	\N	PRESENT	0
728831	728216	19798U	PARTICIPANT	\N	PRESENT	0
728890	728216	20044X	PARTICIPANT	\N	PRESENT	0
728833	728216	19703U	PARTICIPANT	\N	PRESENT	0
728871	728216	20060X	PARTICIPANT	\N	PRESENT	0
728892	728216	19383Y	PARTICIPANT	\N	PRESENT	0
728872	728216	20034V	PARTICIPANT	\N	PRESENT	0
728837	728216	98022P	PARTICIPANT	\N	PRESENT	0
728882	728216	19479G	PARTICIPANT	\N	PRESENT	0
728893	728216	10015M	PARTICIPANT	\N	PRESENT	0
728864	728216	20078J	PARTICIPANT	\N	PRESENT	0
728841	728216	19467C	PARTICIPANT	\N	PRESENT	0
728865	728216	01025N	PARTICIPANT	\N	PRESENT	0
728843	728216	20140W	PARTICIPANT	\N	PRESENT	0
728873	728216	20042V	PARTICIPANT	\N	PRESENT	0
728845	728216	14189C	PARTICIPANT	\N	PRESENT	0
728846	728216	14030Q	PARTICIPANT	\N	PRESENT	0
728894	728216	19507S	PARTICIPANT	\N	PRESENT	0
728896	728216	14231L	PARTICIPANT	\N	PRESENT	0
728849	728216	20022R	PARTICIPANT	\N	PRESENT	0
728897	728216	20018V	PARTICIPANT	\N	PRESENT	0
728874	728216	19782L	PARTICIPANT	\N	PRESENT	0
728875	728216	20122U	PARTICIPANT	\N	PRESENT	0
728876	728216	08045X	PARTICIPANT	\N	PRESENT	0
728854	728216	19691J	PARTICIPANT	\N	PRESENT	0
728898	728216	11040E	PARTICIPANT	\N	PRESENT	0
728856	728216	14037X	PARTICIPANT	\N	PRESENT	0
728861	728216	11090Q	PARTICIPANT	\N	PRESENT	0
728862	728216	20286Q	PARTICIPANT	\N	PRESENT	0
728863	728216	19695N	PARTICIPANT	\N	PRESENT	0
728877	728216	20056C	PARTICIPANT	\N	PRESENT	0
728878	728216	19673G	PARTICIPANT	\N	PRESENT	0
728879	728216	19667J	PARTICIPANT	\N	PRESENT	0
728880	728216	20032T	PARTICIPANT	\N	PRESENT	0
728881	728216	04070G	PARTICIPANT	\N	PRESENT	0
728883	728216	14151M	PARTICIPANT	\N	PRESENT	0
728884	728216	19631V	PARTICIPANT	\N	PRESENT	0
728899	728216	11115U	PARTICIPANT	\N	PRESENT	0
728900	728216	20070A	PARTICIPANT	\N	PRESENT	0
728916	728216	19569H	PARTICIPANT	\N	PRESENT	0
728917	728216	18083K	PARTICIPANT	\N	PRESENT	0
728920	728216	19768N	PARTICIPANT	\N	PRESENT	0
728921	728216	20052X	PARTICIPANT	\N	PRESENT	0
728922	728216	14073Q	PARTICIPANT	\N	PRESENT	0
728929	728216	19713W	PARTICIPANT	\N	PRESENT	0
728930	728216	19503N	PARTICIPANT	\N	PRESENT	0
728931	728216	11048N	PARTICIPANT	\N	PRESENT	0
728932	728919	19251M	PRESIDENT	0	PRESENT	0
728933	728919	20102Q	PARTICIPANT	\N	PRESENT	0
728934	728216	20092G	PARTICIPANT	\N	PRESENT	0
728935	728919	11097X	PARTICIPANT	\N	PRESENT	0
728936	728919	11053K	PARTICIPANT	\N	PRESENT	0
728937	728216	14069U	PARTICIPANT	\N	PRESENT	0
728938	728216	19347U	PARTICIPANT	\N	PRESENT	0
728939	728216	20088L	PARTICIPANT	\N	PRESENT	0
728940	728919	19762G	PARTICIPANT	\N	PRESENT	0
728941	728919	14357A	PARTICIPANT	\N	PRESENT	0
728942	728919	20180F	PARTICIPANT	\N	PRESENT	0
728943	728216	14033T	PARTICIPANT	\N	PRESENT	0
728947	728216	20914V	PARTICIPANT	\N	PRESENT	0
728948	728919	19713W	PARTICIPANT	\N	PRESENT	0
728949	728216	14147R	PARTICIPANT	\N	PRESENT	0
728950	728919	20084G	PARTICIPANT	\N	PRESENT	0
728951	728216	14215L	PARTICIPANT	\N	PRESENT	0
728952	728216	20058E	PARTICIPANT	\N	PRESENT	0
728953	728216	19643A	PARTICIPANT	\N	PRESENT	0
728954	728216	11067R	PARTICIPANT	\N	PRESENT	0
728955	728216	20082E	PARTICIPANT	\N	PRESENT	0
728956	728216	11012A	PARTICIPANT	\N	PRESENT	0
728957	728216	20980G	PARTICIPANT	\N	PRESENT	0
728958	728216	14213J	PARTICIPANT	\N	PRESENT	0
728959	728216	01043Q	PARTICIPANT	\N	PRESENT	0
728960	728216	20120S	PARTICIPANT	\N	PRESENT	0
728961	728216	20134Y	PARTICIPANT	\N	PRESENT	0
728962	728216	19415P	PARTICIPANT	\N	PRESENT	0
728963	728216	08010L	PARTICIPANT	\N	PRESENT	0
728964	728216	20132W	PARTICIPANT	\N	PRESENT	0
729010	728220	11090Q	PARTICIPANT	\N	PRESENT	0
729011	728220	20060X	PARTICIPANT	\N	PRESENT	0
729012	728220	19695N	PARTICIPANT	\N	PRESENT	0
729013	728220	14147R	PARTICIPANT	\N	PRESENT	0
729014	728220	20078J	PARTICIPANT	\N	PRESENT	0
729015	728220	19673G	PARTICIPANT	\N	PRESENT	0
729028	728220	14037X	PARTICIPANT	\N	PRESENT	0
729017	728220	14207L	PARTICIPANT	\N	PRESENT	0
729018	728220	20092G	PARTICIPANT	\N	PRESENT	0
729019	728220	20142Y	PARTICIPANT	\N	PRESENT	0
729030	728220	14187A	PARTICIPANT	\N	PRESENT	0
729050	728220	14193X	PARTICIPANT	\N	PRESENT	0
729052	728220	14257W	PARTICIPANT	\N	PRESENT	0
729023	728220	19747H	PARTICIPANT	\N	PRESENT	0
729024	728220	19347U	PARTICIPANT	\N	PRESENT	0
729025	728220	19503N	PARTICIPANT	\N	PRESENT	0
729026	728220	11067R	PARTICIPANT	\N	PRESENT	0
729027	728220	14151M	PARTICIPANT	\N	PRESENT	0
729029	728220	04045F	PARTICIPANT	\N	PRESENT	0
729031	728220	01025N	PARTICIPANT	\N	PRESENT	0
729032	728220	20134Y	PARTICIPANT	\N	PRESENT	0
729033	728220	19447X	PARTICIPANT	\N	PRESENT	0
729034	728220	20122U	PARTICIPANT	\N	PRESENT	0
729035	728220	14205J	PARTICIPANT	\N	PRESENT	0
729036	728220	20090E	PARTICIPANT	\N	PRESENT	0
729037	728220	14215L	PARTICIPANT	\N	PRESENT	0
729038	728220	14069U	PARTICIPANT	\N	PRESENT	0
729039	728220	20032T	PARTICIPANT	\N	PRESENT	0
729040	728220	14038Y	PARTICIPANT	\N	PRESENT	0
729041	728220	19507S	PARTICIPANT	\N	PRESENT	0
729042	728220	08010L	PARTICIPANT	\N	PRESENT	0
729043	728220	19621T	PARTICIPANT	\N	PRESENT	0
729044	728220	20022R	PARTICIPANT	\N	PRESENT	0
729045	728220	08015R	PARTICIPANT	\N	PRESENT	0
729046	728220	14033T	PARTICIPANT	\N	PRESENT	0
729047	728220	19383Y	PARTICIPANT	\N	PRESENT	0
729048	728220	19798U	PARTICIPANT	\N	PRESENT	0
729049	728220	19553Y	PARTICIPANT	\N	PRESENT	0
729051	728220	14026U	PARTICIPANT	\N	PRESENT	0
729053	728220	20098N	PARTICIPANT	\N	PRESENT	0
729054	728220	20024T	PARTICIPANT	\N	PRESENT	0
729055	728220	20048C	PARTICIPANT	\N	PRESENT	0
729056	728220	20062A	PARTICIPANT	\N	PRESENT	0
729008	728220	19719D	PARTICIPANT	\N	PRESENT	0
729009	728220	20286Q	PARTICIPANT	\N	PRESENT	0
729057	728220	20054A	PARTICIPANT	\N	PRESENT	0
729058	728220	14357A	PARTICIPANT	\N	PRESENT	0
729059	728220	20180F	PARTICIPANT	\N	PRESENT	0
729060	728220	20034V	PARTICIPANT	\N	PRESENT	0
729061	728220	14259Y	PARTICIPANT	\N	PRESENT	0
729062	728220	14089Y	PARTICIPANT	\N	PRESENT	0
729063	728220	19413M	PARTICIPANT	\N	PRESENT	0
729064	728220	20082E	PARTICIPANT	\N	PRESENT	0
729065	728220	17367Q	PARTICIPANT	\N	PRESENT	0
729066	728220	19782L	PARTICIPANT	\N	PRESENT	0
729067	728220	14219Q	PARTICIPANT	\N	PRESENT	0
729068	728220	11056N	PARTICIPANT	\N	PRESENT	0
729240	729238	11067R	PARTICIPANT	\N	EXCUSE	0
729243	729238	20066E	PARTICIPANT	\N	EXCUSE	0
729251	729238	19723Y	PARTICIPANT	\N	EXCUSE	0
729254	729237	20042V	PARTICIPANT	\N	PRESENT	0
729255	729237	11040E	PARTICIPANT	\N	EXCUSE	0
729256	729237	20050V	PARTICIPANT	\N	EXCUSE	0
729257	729237	19399H	PARTICIPANT	\N	EXCUSE	0
729258	729237	20018V	PARTICIPANT	\N	EXCUSE	0
729259	729237	04070G	PARTICIPANT	\N	EXCUSE	0
711964	709156	05008E	PARTICIPANT	\N	EXCUSE	0
711965	709156	14059S	PARTICIPANT	\N	EXCUSE	0
712825	708201	86034E	PARTICIPANT	\N	PRESENT	0
712826	708201	11067R	PARTICIPANT	\N	PRESENT	0
712827	708201	14021P	PARTICIPANT	\N	PRESENT	0
712828	708201	20914V	PARTICIPANT	\N	PRESENT	0
712829	708201	14211G	PARTICIPANT	\N	PRESENT	0
712830	708201	14207L	PARTICIPANT	\N	PRESENT	0
712831	708201	20076G	PARTICIPANT	\N	PRESENT	0
712832	708201	20130U	PARTICIPANT	\N	PRESENT	0
712833	708201	14031R	PARTICIPANT	\N	PRESENT	0
712834	708201	14151M	PARTICIPANT	\N	PRESENT	0
712835	708201	11040E	PARTICIPANT	\N	PRESENT	0
712836	708201	14253S	PARTICIPANT	\N	PRESENT	0
712837	708201	20046A	PARTICIPANT	\N	PRESENT	0
712838	708201	18083K	PARTICIPANT	\N	PRESENT	0
712839	708201	11077T	PARTICIPANT	\N	PRESENT	0
712840	708201	19760E	PARTICIPANT	\N	PRESENT	0
712841	708201	10006L	PARTICIPANT	\N	PRESENT	0
712842	708201	14357A	PARTICIPANT	\N	PRESENT	0
712843	708201	14042U	PARTICIPANT	\N	PRESENT	0
712844	708201	11097X	PARTICIPANT	\N	PRESENT	0
712845	708201	14147R	PARTICIPANT	\N	PRESENT	0
712846	708201	20090E	PARTICIPANT	\N	PRESENT	0
712847	708201	19479G	PARTICIPANT	\N	PRESENT	0
712848	708201	14030Q	PARTICIPANT	\N	PRESENT	0
712849	708201	20040T	PARTICIPANT	\N	PRESENT	0
712850	708201	14217N	PARTICIPANT	\N	PRESENT	0
712851	708201	19713W	PARTICIPANT	\N	PRESENT	0
712852	708201	19749K	PARTICIPANT	\N	PRESENT	0
712853	708201	14215L	PARTICIPANT	\N	PRESENT	0
712854	708201	11072N	PARTICIPANT	\N	PRESENT	0
712855	708201	19415P	PARTICIPANT	\N	PRESENT	0
712856	708201	08061X	PARTICIPANT	\N	PRESENT	0
712857	708201	19591F	PARTICIPANT	\N	PRESENT	0
712858	708201	99004R	PARTICIPANT	\N	PRESENT	0
712859	708201	20100N	PARTICIPANT	\N	PRESENT	0
712860	708201	14187A	PARTICIPANT	\N	PRESENT	0
712861	708201	18193Q	PARTICIPANT	\N	PRESENT	0
712862	708201	14281W	PARTICIPANT	\N	PRESENT	0
712863	708201	20044X	PARTICIPANT	\N	PRESENT	0
712864	708201	14038Y	PARTICIPANT	\N	PRESENT	0
712865	708201	19593H	PARTICIPANT	\N	PRESENT	0
712866	708201	20124W	PARTICIPANT	\N	PRESENT	0
712867	708201	11090Q	PARTICIPANT	\N	PRESENT	0
712868	708201	19782L	PARTICIPANT	\N	PRESENT	0
712869	708201	20134Y	PARTICIPANT	\N	PRESENT	0
712870	708201	20034V	PARTICIPANT	\N	PRESENT	0
712871	708201	11045K	PARTICIPANT	\N	PRESENT	0
712872	708201	20038A	PARTICIPANT	\N	PRESENT	0
712873	708201	11031D	PARTICIPANT	\N	PRESENT	0
712874	708201	19691J	PARTICIPANT	\N	PRESENT	0
712875	708201	14213J	PARTICIPANT	\N	PRESENT	0
712876	708201	04092N	PARTICIPANT	\N	PRESENT	0
712877	708201	20980G	PARTICIPANT	\N	PRESENT	0
712887	708201	08028W	PARTICIPANT	\N	PRESENT	0
712879	708201	19413M	PARTICIPANT	\N	PRESENT	0
712880	708201	01028R	PARTICIPANT	\N	PRESENT	0
712881	708201	20102Q	PARTICIPANT	\N	PRESENT	0
712882	708201	19758L	PARTICIPANT	\N	PRESENT	0
712883	708201	19347U	PARTICIPANT	\N	PRESENT	0
712884	708201	14059S	PARTICIPANT	\N	PRESENT	0
712885	708201	20026V	PARTICIPANT	\N	PRESENT	0
712886	708201	08010L	PARTICIPANT	\N	PRESENT	0
712888	708201	20092G	PARTICIPANT	\N	PRESENT	0
712889	708201	19657G	PARTICIPANT	\N	PRESENT	0
712890	708201	11054L	PARTICIPANT	\N	PRESENT	0
712891	708201	04047H	PARTICIPANT	\N	PRESENT	0
712892	708201	08011M	PARTICIPANT	\N	PRESENT	0
712893	708201	19719D	PARTICIPANT	\N	PRESENT	0
712894	708201	19745F	PARTICIPANT	\N	PRESENT	0
712895	708201	20180F	PARTICIPANT	\N	PRESENT	0
712896	708201	19515S	PARTICIPANT	\N	PRESENT	0
712897	708201	19527W	PARTICIPANT	\N	PRESENT	0
712898	708201	14257W	PARTICIPANT	\N	PRESENT	0
712899	708201	14053L	PARTICIPANT	\N	PRESENT	0
712900	708201	20054A	PARTICIPANT	\N	PRESENT	0
712901	708201	20122U	PARTICIPANT	\N	PRESENT	0
712902	708201	14229S	PARTICIPANT	\N	PRESENT	0
712903	708201	20140W	PARTICIPANT	\N	PRESENT	0
712904	708201	19709B	PARTICIPANT	\N	PRESENT	0
712905	708201	20028X	PARTICIPANT	\N	PRESENT	0
712906	708201	01057W	PARTICIPANT	\N	PRESENT	0
712907	708201	19866P	PARTICIPANT	\N	PRESENT	0
712908	708201	17965H	PARTICIPANT	\N	PRESENT	0
712909	708201	20152B	PARTICIPANT	\N	PRESENT	0
712910	708201	07029T	PARTICIPANT	\N	PRESENT	0
712911	708201	08069G	PARTICIPANT	\N	PRESENT	0
712912	708201	19349W	PARTICIPANT	\N	PRESENT	0
712913	708201	14259Y	PARTICIPANT	\N	PRESENT	0
712914	708201	19569H	PARTICIPANT	\N	PRESENT	0
712915	708201	11101A	PARTICIPANT	\N	PRESENT	0
712916	708201	19647E	PARTICIPANT	\N	PRESENT	0
712917	708201	20094J	PARTICIPANT	\N	PRESENT	0
712918	708201	19565D	PARTICIPANT	\N	PRESENT	0
712919	708201	19703U	PARTICIPANT	\N	PRESENT	0
712920	708201	20112S	PARTICIPANT	\N	PRESENT	0
712921	708201	14026U	PARTICIPANT	\N	PRESENT	0
712922	708201	08034U	PARTICIPANT	\N	PRESENT	0
712923	708201	14255U	PARTICIPANT	\N	PRESENT	0
712924	708201	19681G	PARTICIPANT	\N	PRESENT	0
712925	708201	08018U	PARTICIPANT	\N	PRESENT	0
712926	708201	17367Q	PARTICIPANT	\N	PRESENT	0
712927	708201	19675J	PARTICIPANT	\N	PRESENT	0
712928	708201	11085T	PARTICIPANT	\N	PRESENT	0
712929	708201	04057K	PARTICIPANT	\N	PRESENT	0
712930	708201	20066E	PARTICIPANT	\N	PRESENT	0
712931	708201	20098N	PARTICIPANT	\N	PRESENT	0
712932	708201	20110Q	PARTICIPANT	\N	PRESENT	0
712933	708201	20252E	PARTICIPANT	\N	PRESENT	0
712934	708201	17779H	PARTICIPANT	\N	PRESENT	0
712935	708201	19575F	PARTICIPANT	\N	PRESENT	0
712936	708201	14109K	PARTICIPANT	\N	PRESENT	0
712937	708201	11065P	PARTICIPANT	\N	PRESENT	0
712938	708201	19467C	PARTICIPANT	\N	PRESENT	0
712939	708201	95063L	PARTICIPANT	\N	PRESENT	0
712940	708201	05012A	PARTICIPANT	\N	PRESENT	0
712941	708201	17637T	PARTICIPANT	\N	PRESENT	0
712942	708201	20120S	PARTICIPANT	\N	PRESENT	0
712943	708201	19643A	PARTICIPANT	\N	PRESENT	0
712944	708201	04085P	PARTICIPANT	\N	PRESENT	0
713050	708202	99004R	PARTICIPANT	\N	PRESENT	0
713051	708202	10006L	PARTICIPANT	\N	PRESENT	0
713052	708202	11097X	PARTICIPANT	\N	PRESENT	0
713053	708202	14042U	PARTICIPANT	\N	PRESENT	0
713054	708202	19565D	PARTICIPANT	\N	PRESENT	0
713055	708202	18193Q	PARTICIPANT	\N	PRESENT	0
713056	708202	11067R	PARTICIPANT	\N	PRESENT	0
713057	708202	14281W	PARTICIPANT	\N	PRESENT	0
713058	708202	14151M	PARTICIPANT	\N	PRESENT	0
713059	708202	17779H	PARTICIPANT	\N	PRESENT	0
713060	708202	19651A	PARTICIPANT	\N	PRESENT	0
713061	708202	20130U	PARTICIPANT	\N	PRESENT	0
713062	708202	20264J	PARTICIPANT	\N	PRESENT	0
713063	708202	11065P	PARTICIPANT	\N	PRESENT	0
713064	708202	19782L	PARTICIPANT	\N	PRESENT	0
713065	708202	14207L	PARTICIPANT	\N	PRESENT	0
713066	708202	19681G	PARTICIPANT	\N	PRESENT	0
713067	708202	20092G	PARTICIPANT	\N	PRESENT	0
713068	708202	20028X	PARTICIPANT	\N	PRESENT	0
713069	708202	20102Q	PARTICIPANT	\N	PRESENT	0
713070	708202	19695N	PARTICIPANT	\N	PRESENT	0
713071	708202	04085P	PARTICIPANT	\N	PRESENT	0
713072	708202	19760E	PARTICIPANT	\N	PRESENT	0
713073	708202	11031D	PARTICIPANT	\N	PRESENT	0
713074	708202	20066E	PARTICIPANT	\N	PRESENT	0
713075	708202	20040T	PARTICIPANT	\N	PRESENT	0
713076	708202	07004J	PARTICIPANT	\N	PRESENT	0
713077	708202	14030Q	PARTICIPANT	\N	PRESENT	0
713078	708202	19749K	PARTICIPANT	\N	PRESENT	0
713079	708202	14215L	PARTICIPANT	\N	PRESENT	0
713080	708202	19647E	PARTICIPANT	\N	PRESENT	0
713081	708202	20054A	PARTICIPANT	\N	PRESENT	0
713082	708202	14053L	PARTICIPANT	\N	PRESENT	0
713083	708202	14217N	PARTICIPANT	\N	PRESENT	0
713084	708202	20090E	PARTICIPANT	\N	PRESENT	0
713085	708202	14357A	PARTICIPANT	\N	PRESENT	0
713086	708202	14026U	PARTICIPANT	\N	PRESENT	0
713087	708202	14213J	PARTICIPANT	\N	PRESENT	0
713088	708202	11090Q	PARTICIPANT	\N	PRESENT	0
713089	708202	08028W	PARTICIPANT	\N	PRESENT	0
735572	735571	19503N	PARTICIPANT	\N	PRESENT	0
735604	735603	04070G	PARTICIPANT	\N	PRESENT	0
735605	735603	20134Y	PARTICIPANT	\N	PRESENT	0
735606	735603	20056C	PARTICIPANT	\N	PRESENT	0
735607	735603	19593H	PARTICIPANT	\N	PRESENT	0
735608	735373	20050V	PARTICIPANT	\N	EXCUSE	0
738672	738671	05012A	PARTICIPANT	\N	PRESENT	0
738673	738671	19820Y	PARTICIPANT	\N	PRESENT	0
738674	738671	20094J	PARTICIPANT	\N	PRESENT	0
738675	738671	20128B	PARTICIPANT	\N	PRESENT	0
738676	738671	20914V	PARTICIPANT	\N	PRESENT	0
738743	738729	20914V	PARTICIPANT	\N	PRESENT	0
738744	738729	20046A	PARTICIPANT	\N	PRESENT	0
738745	738729	19745F	PARTICIPANT	\N	PRESENT	0
738746	738729	20094J	PARTICIPANT	\N	PRESENT	0
738747	738729	14169X	PARTICIPANT	\N	PRESENT	0
738752	738729	14237S	PARTICIPANT	\N	PRESENT	0
738753	738729	19387D	PARTICIPANT	\N	PRESENT	0
738754	738729	19820Y	PARTICIPANT	\N	PRESENT	0
738755	738729	05012A	PRESIDENT	0	PRESENT	0
739122	739117	14042U	PARTICIPANT	\N	PRESENT	0
739123	739117	18193Q	PARTICIPANT	\N	PRESENT	0
739124	739119	14042U	PARTICIPANT	\N	PRESENT	0
739125	739119	18193Q	PARTICIPANT	\N	PRESENT	0
739127	739120	14042U	PARTICIPANT	\N	PRESENT	0
739128	739120	18193Q	PARTICIPANT	\N	PRESENT	0
739542	738007	14213J	PARTICIPANT	\N	PRESENT	0
739543	738007	19549D	PARTICIPANT	\N	PRESENT	0
739563	738007	19503N	PARTICIPANT	\N	PRESENT	0
739545	738007	14097Y	PARTICIPANT	\N	PRESENT	0
739546	738007	04071H	PARTICIPANT	\N	PRESENT	0
739547	738007	19741B	PARTICIPANT	\N	PRESENT	0
739548	738007	19515S	PARTICIPANT	\N	PRESENT	0
739549	738007	20114U	PARTICIPANT	\N	PRESENT	0
739550	738007	08015R	PARTICIPANT	\N	PRESENT	0
739551	738007	20104S	PARTICIPANT	\N	PRESENT	0
739552	738007	19954N	PARTICIPANT	\N	PRESENT	0
739553	738007	20026V	PARTICIPANT	\N	PRESENT	0
739554	738007	20140W	PARTICIPANT	\N	PRESENT	0
739555	738007	08047A	PARTICIPANT	\N	PRESENT	0
739556	738007	20080C	PARTICIPANT	\N	PRESENT	0
739557	738007	14253S	PARTICIPANT	\N	PRESENT	0
739558	738007	20060X	PARTICIPANT	\N	PRESENT	0
739559	738007	20024T	PARTICIPANT	\N	PRESENT	0
739560	738007	19489J	PARTICIPANT	\N	PRESENT	0
739561	738007	19667J	PARTICIPANT	\N	PRESENT	0
739562	738007	20138D	PARTICIPANT	\N	PRESENT	0
739564	738007	14147R	PARTICIPANT	\N	PRESENT	0
739565	738007	20084G	PARTICIPANT	\N	PRESENT	0
739566	738007	20028X	PARTICIPANT	\N	PRESENT	0
739567	738007	19251M	PARTICIPANT	\N	PRESENT	0
739568	738007	20088L	PARTICIPANT	\N	PRESENT	0
739569	738007	01057W	PARTICIPANT	\N	PRESENT	0
739570	738007	20064C	PARTICIPANT	\N	PRESENT	0
739571	738007	19766L	PARTICIPANT	\N	PRESENT	0
739572	738007	20030R	PARTICIPANT	\N	PRESENT	0
739573	738007	11080N	PARTICIPANT	\N	PRESENT	0
739574	738007	19593H	PARTICIPANT	\N	PRESENT	0
739575	738007	19687N	PARTICIPANT	\N	PRESENT	0
739576	738007	11043H	PARTICIPANT	\N	PRESENT	0
739577	738007	20046A	PARTICIPANT	\N	PRESENT	0
739584	738007	11090Q	PARTICIPANT	\N	PRESENT	0
739579	738007	20172F	PARTICIPANT	\N	PRESENT	0
739580	738007	19760E	PARTICIPANT	\N	PRESENT	0
739581	738007	04033B	PARTICIPANT	\N	PRESENT	0
739582	738007	97011G	PARTICIPANT	\N	PRESENT	0
739583	738007	12041X	PARTICIPANT	\N	PRESENT	0
739585	738007	19673G	PARTICIPANT	\N	PRESENT	0
739586	738007	20134Y	PARTICIPANT	\N	PRESENT	0
739587	738007	20100N	PARTICIPANT	\N	PRESENT	0
739588	738007	05012A	PARTICIPANT	\N	PRESENT	0
739589	738007	20036X	PARTICIPANT	\N	PRESENT	0
739590	738007	20022R	PARTICIPANT	\N	PRESENT	0
739591	738007	20032T	PARTICIPANT	\N	PRESENT	0
739592	738007	20266L	PARTICIPANT	\N	PRESENT	0
739593	738007	19782L	PARTICIPANT	\N	PRESENT	0
739594	738007	19525U	PARTICIPANT	\N	PRESENT	0
739595	738007	20068G	PARTICIPANT	\N	PRESENT	0
739596	738007	19057M	PARTICIPANT	\N	PRESENT	0
739597	738007	14169X	PARTICIPANT	\N	PRESENT	0
739598	738007	14249W	PARTICIPANT	\N	PRESENT	0
739599	738007	20146D	PARTICIPANT	\N	PRESENT	0
739600	738007	01048V	PARTICIPANT	\N	PRESENT	0
739601	738007	19349W	PARTICIPANT	\N	PRESENT	0
739602	738007	20078J	PARTICIPANT	\N	PRESENT	0
739603	738007	19637C	PARTICIPANT	\N	PRESENT	0
739604	738007	18083K	PARTICIPANT	\N	PRESENT	0
739605	738007	11083R	PARTICIPANT	\N	PRESENT	0
739606	738007	20106U	PARTICIPANT	\N	PRESENT	0
739607	738007	04042C	PARTICIPANT	\N	PRESENT	0
739608	738007	20128B	PARTICIPANT	\N	PRESENT	0
739609	738007	08069G	PARTICIPANT	\N	PRESENT	0
739610	738007	20074E	PARTICIPANT	\N	PRESENT	0
739611	738007	20076G	PARTICIPANT	\N	PRESENT	0
739612	738007	04035D	PARTICIPANT	\N	PRESENT	0
739613	738007	19575F	PARTICIPANT	\N	PRESENT	0
739614	738007	99004R	PARTICIPANT	\N	PRESENT	0
739615	738007	01058X	PARTICIPANT	\N	PRESENT	0
739616	738007	08073C	PARTICIPANT	\N	PRESENT	0
739617	738007	19693L	PARTICIPANT	\N	PRESENT	0
739618	738007	11072N	PARTICIPANT	\N	PRESENT	0
739619	738007	19621T	PARTICIPANT	\N	PRESENT	0
739620	738007	19711U	PARTICIPANT	\N	PRESENT	0
739621	738007	95063L	PARTICIPANT	\N	PRESENT	0
739622	738007	19591F	PARTICIPANT	\N	PRESENT	0
739623	738007	11101A	PARTICIPANT	\N	PRESENT	0
739624	738007	08061X	PARTICIPANT	\N	PRESENT	0
739625	738007	19703U	PARTICIPANT	\N	PRESENT	0
739626	738007	08010L	PARTICIPANT	\N	PRESENT	0
739627	738007	14055N	PARTICIPANT	\N	PRESENT	0
739628	738007	11048N	PARTICIPANT	\N	PRESENT	0
739629	738007	04092N	PARTICIPANT	\N	PRESENT	0
739630	738007	19719D	PARTICIPANT	\N	PRESENT	0
739631	738007	14133K	PARTICIPANT	\N	PRESENT	0
739632	738007	08034U	PARTICIPANT	\N	PRESENT	0
739633	738007	19347U	PARTICIPANT	\N	PRESENT	0
739634	738007	19747H	PARTICIPANT	\N	PRESENT	0
739635	738007	19415P	PARTICIPANT	\N	PRESENT	0
739636	738007	19866P	PARTICIPANT	\N	PRESENT	0
739637	738007	05008E	PARTICIPANT	\N	PRESENT	0
739638	738007	20116W	PARTICIPANT	\N	PRESENT	0
739639	738007	11097X	PARTICIPANT	\N	PRESENT	0
739640	738007	20072C	PARTICIPANT	\N	PRESENT	0
739641	738007	14071N	PARTICIPANT	\N	PRESENT	0
739642	738007	20092G	PARTICIPANT	\N	PRESENT	0
739643	738007	14187A	PARTICIPANT	\N	PRESENT	0
739644	738007	14069U	PARTICIPANT	\N	PRESENT	0
739645	738007	14107H	PARTICIPANT	\N	PRESENT	0
739646	738007	04043D	PARTICIPANT	\N	PRESENT	0
739647	738007	19553Y	PARTICIPANT	\N	PRESENT	0
739648	738007	19681G	PARTICIPANT	\N	PRESENT	0
739649	738007	19701S	PARTICIPANT	\N	PRESENT	0
739650	738007	14207L	PARTICIPANT	\N	PRESENT	0
739651	738007	14053L	PARTICIPANT	\N	PRESENT	0
739652	738007	19421M	PARTICIPANT	\N	PRESENT	0
739653	738007	14215L	PARTICIPANT	\N	PRESENT	0
739654	738007	19545Y	PARTICIPANT	\N	PRESENT	0
739655	738007	17589D	PARTICIPANT	\N	PRESENT	0
739656	738007	14193X	PARTICIPANT	\N	PRESENT	0
739657	738007	14237S	PARTICIPANT	\N	PRESENT	0
739658	738007	14221J	PARTICIPANT	\N	PRESENT	0
739659	738007	19671E	PARTICIPANT	\N	PRESENT	0
739660	738007	95041E	PARTICIPANT	\N	PRESENT	0
739661	738007	20050V	PARTICIPANT	\N	PRESENT	0
739662	738007	19581D	PARTICIPANT	\N	PRESENT	0
739663	738007	20122U	PARTICIPANT	\N	PRESENT	0
739664	738007	19367Y	PARTICIPANT	\N	PRESENT	0
739665	738007	19583F	PARTICIPANT	\N	PRESENT	0
739666	738007	04057K	PARTICIPANT	\N	PRESENT	0
739667	738007	14251Q	PARTICIPANT	\N	PRESENT	0
739668	738007	11064N	PARTICIPANT	\N	PRESENT	0
739669	738007	14211G	PARTICIPANT	\N	PRESENT	0
739670	738007	20126Y	PARTICIPANT	\N	PRESENT	0
739671	738007	20020P	PARTICIPANT	\N	PRESENT	0
739672	738007	20152B	PARTICIPANT	\N	PRESENT	0
739673	738007	19713W	PARTICIPANT	\N	PRESENT	0
739674	738007	19699S	PARTICIPANT	\N	PRESENT	0
739675	738007	08056B	PARTICIPANT	\N	PRESENT	0
739676	738007	20042V	PARTICIPANT	\N	PRESENT	0
739677	738007	14059S	PARTICIPANT	\N	PRESENT	0
713505	712272	19629C	PRESIDENT	0	PRESENT	0
713506	712272	14259Y	PARTICIPANT	\N	PRESENT	0
713507	712272	20110Q	PARTICIPANT	\N	PRESENT	0
713508	712272	08073C	PARTICIPANT	\N	PRESENT	0
713509	712272	20082E	PARTICIPANT	\N	PRESENT	0
713510	712272	11110B	PARTICIPANT	\N	PRESENT	0
713511	712272	19703U	PARTICIPANT	\N	PRESENT	0
713512	712272	14329V	PARTICIPANT	\N	PRESENT	0
713513	712272	14189C	PARTICIPANT	\N	PRESENT	0
713514	712272	11056N	PARTICIPANT	\N	PRESENT	0
713516	712272	19383Y	PARTICIPANT	\N	PRESENT	0
713518	712272	14001X	PARTICIPANT	\N	EXCUSE	0
713521	713519	19503N	PARTICIPANT	\N	PRESENT	0
713522	710874	11031D	PARTICIPANT	\N	PRESENT	0
713523	710874	20096L	PARTICIPANT	\N	PRESENT	0
713524	710874	14026U	PARTICIPANT	\N	PRESENT	0
713525	710874	19735D	PRESIDENT	0	PRESENT	0
713526	710874	19725B	PARTICIPANT	\N	PRESENT	0
713527	710874	14213J	PARTICIPANT	\N	PRESENT	0
713528	710874	20066E	PARTICIPANT	\N	EXCUSE	0
713529	710874	20138D	PARTICIPANT	\N	EXCUSE	0
713530	710874	19369B	PARTICIPANT	\N	PRESENT	0
713542	710874	04045F	PARTICIPANT	\N	PRESENT	0
713543	710874	20024T	PARTICIPANT	\N	PRESENT	0
713857	712585	14173T	PARTICIPANT	\N	PRESENT	0
713858	712585	14133K	PARTICIPANT	\N	PRESENT	0
713865	712585	14329V	PARTICIPANT	\N	PRESENT	0
713866	712585	20096L	PARTICIPANT	\N	PRESENT	0
713867	712585	19577H	PARTICIPANT	\N	PRESENT	0
713868	712585	08056B	PARTICIPANT	\N	PRESENT	0
713869	712585	20060X	PARTICIPANT	\N	PRESENT	0
713871	712585	19741B	PARTICIPANT	\N	PRESENT	0
713872	712585	19441R	PARTICIPANT	\N	PRESENT	0
713875	712585	20104S	PARTICIPANT	\N	PRESENT	0
713876	712585	11048N	PARTICIPANT	\N	PRESENT	0
713967	712587	01043Q	PARTICIPANT	\N	PRESENT	0
714042	712587	19531S	PARTICIPANT	\N	PRESENT	0
714043	712587	14037X	PARTICIPANT	\N	PRESENT	0
714044	712587	14147R	PARTICIPANT	\N	PRESENT	0
713971	712587	11065P	PARTICIPANT	\N	PRESENT	0
713972	712587	20914V	PARTICIPANT	\N	PRESENT	0
713973	712587	20092G	PARTICIPANT	\N	PRESENT	0
713974	712587	20100N	PARTICIPANT	\N	PRESENT	0
714045	712587	20052X	PARTICIPANT	\N	PRESENT	0
714046	712587	20032T	PARTICIPANT	\N	PRESENT	0
713977	712587	11056N	PARTICIPANT	\N	PRESENT	0
714047	712587	05008E	PARTICIPANT	\N	PRESENT	0
714048	712587	14089Y	PARTICIPANT	\N	PRESENT	0
714049	712587	19335Q	PARTICIPANT	\N	PRESENT	0
714050	712587	19545Y	PARTICIPANT	\N	PRESENT	0
714051	712587	14331P	PARTICIPANT	\N	PRESENT	0
713983	712587	20090E	PARTICIPANT	\N	PRESENT	0
713984	712587	20062A	PARTICIPANT	\N	PRESENT	0
713985	712587	20120S	PARTICIPANT	\N	PRESENT	0
714052	712587	11090Q	PARTICIPANT	\N	PRESENT	0
714053	712587	19719D	PARTICIPANT	\N	PRESENT	0
714054	712587	14071N	PARTICIPANT	\N	PRESENT	0
714055	712587	20060X	PARTICIPANT	\N	PRESENT	0
714056	712587	20098N	PARTICIPANT	\N	PRESENT	0
714057	712587	14215L	PARTICIPANT	\N	PRESENT	0
714058	712587	20096L	PARTICIPANT	\N	PRESENT	0
714059	712587	19503N	PARTICIPANT	\N	PRESENT	0
713994	712587	11110B	PARTICIPANT	\N	PRESENT	0
714060	712587	19349W	PARTICIPANT	\N	PRESENT	0
713996	712587	19782L	PARTICIPANT	\N	PRESENT	0
714061	712587	14259Y	PARTICIPANT	\N	PRESENT	0
713998	712587	19599P	PARTICIPANT	\N	PRESENT	0
713999	712587	19489J	PARTICIPANT	\N	PRESENT	0
714000	712587	20082E	PARTICIPANT	\N	PRESENT	0
714001	712587	20058E	PARTICIPANT	\N	PRESENT	0
714002	712587	20044X	PARTICIPANT	\N	PRESENT	0
714062	712587	20980G	PARTICIPANT	\N	PRESENT	0
714004	712587	19735D	PARTICIPANT	\N	PRESENT	0
714005	712587	19681G	PARTICIPANT	\N	PRESENT	0
714063	712587	19383Y	PARTICIPANT	\N	PRESENT	0
714007	712587	19631V	PARTICIPANT	\N	PRESENT	0
714008	712587	14069U	PARTICIPANT	\N	PRESENT	0
714009	712587	19573D	PARTICIPANT	\N	PRESENT	0
714010	712587	19768N	PARTICIPANT	\N	PRESENT	0
714011	712587	19575F	PARTICIPANT	\N	PRESENT	0
714064	712587	19549D	PARTICIPANT	\N	PRESENT	0
714065	712587	20126Y	PARTICIPANT	\N	PRESENT	0
714014	712587	14327T	PARTICIPANT	\N	PRESENT	0
714066	712587	18083K	PARTICIPANT	\N	PRESENT	0
714067	712587	19533U	PARTICIPANT	\N	PRESENT	0
714017	712587	14031R	PARTICIPANT	\N	PRESENT	0
714068	712587	14329V	PARTICIPANT	\N	PRESENT	0
714019	712587	20180F	PARTICIPANT	\N	PRESENT	0
714020	712587	14223L	PARTICIPANT	\N	PRESENT	0
714021	712587	20104S	PARTICIPANT	\N	PRESENT	0
714069	712587	08015R	PARTICIPANT	\N	PRESENT	0
714023	712587	17023S	PARTICIPANT	\N	PRESENT	0
714024	712587	08060W	PARTICIPANT	\N	PRESENT	0
714025	712587	17229F	PARTICIPANT	\N	PRESENT	0
714026	712587	19685L	PARTICIPANT	\N	PRESENT	0
714027	712587	19798U	PARTICIPANT	\N	PRESENT	0
714028	712587	14187A	PARTICIPANT	\N	PRESENT	0
714029	712587	19621T	PARTICIPANT	\N	PRESENT	0
714030	712587	20036X	PARTICIPANT	\N	PRESENT	0
714031	712587	19758L	PARTICIPANT	\N	PRESENT	0
714032	712587	11077T	PARTICIPANT	\N	PRESENT	0
714033	712587	20298U	PARTICIPANT	\N	PRESENT	0
714034	712587	19441R	PARTICIPANT	\N	PRESENT	0
714035	712587	14189C	PARTICIPANT	\N	PRESENT	0
714036	712587	20136B	PARTICIPANT	\N	PRESENT	0
714037	712587	14191V	PARTICIPANT	\N	PRESENT	0
714038	712587	19447X	PARTICIPANT	\N	PRESENT	0
714039	712587	17367Q	PARTICIPANT	\N	PRESENT	0
714040	712587	20046A	PARTICIPANT	\N	PRESENT	0
714041	712587	05012A	PARTICIPANT	\N	PRESENT	0
714070	712587	14205J	PARTICIPANT	\N	PRESENT	0
714071	712587	20116W	PARTICIPANT	\N	PRESENT	0
714072	712587	07004J	PARTICIPANT	\N	PRESENT	0
714073	712587	20026V	PARTICIPANT	\N	PRESENT	0
714074	712587	20140W	PARTICIPANT	\N	PRESENT	0
714075	712587	20056C	PARTICIPANT	\N	PRESENT	0
714076	712587	01024M	PARTICIPANT	\N	PRESENT	0
714077	712587	14021P	PARTICIPANT	\N	PRESENT	0
714078	712587	14213J	PARTICIPANT	\N	PRESENT	0
714079	712587	20286Q	PARTICIPANT	\N	PRESENT	0
714080	712587	14053L	PARTICIPANT	\N	PRESENT	0
714081	712587	19479G	PARTICIPANT	\N	PRESENT	0
714082	712587	10015M	PARTICIPANT	\N	PRESENT	0
713965	712587	12041X	PARTICIPANT	\N	PRESENT	0
713966	712587	20086J	PARTICIPANT	\N	PRESENT	0
714083	712587	14179A	PARTICIPANT	\N	PRESENT	0
714084	712587	14231L	PARTICIPANT	\N	PRESENT	0
714085	712587	19563B	PARTICIPANT	\N	PRESENT	0
714086	712587	14033T	PARTICIPANT	\N	PRESENT	0
714087	712587	19703U	PARTICIPANT	\N	PRESENT	0
714088	712587	14073Q	PARTICIPANT	\N	PRESENT	0
714089	712587	16685X	PARTICIPANT	\N	PRESENT	0
714090	712587	14030Q	PARTICIPANT	\N	PRESENT	0
714091	712587	19565D	PARTICIPANT	\N	PRESENT	0
714092	712587	19826F	PARTICIPANT	\N	PRESENT	0
714093	712587	11048N	PARTICIPANT	\N	PRESENT	0
714094	712587	14357A	PARTICIPANT	\N	PRESENT	0
714095	712587	14083S	PARTICIPANT	\N	PRESENT	0
714096	712587	20034V	PARTICIPANT	\N	PRESENT	0
714097	712587	14219Q	PARTICIPANT	\N	PRESENT	0
714098	712587	19553Y	PARTICIPANT	\N	PRESENT	0
714099	712587	19387D	PARTICIPANT	\N	PRESENT	0
714100	712587	14107H	PARTICIPANT	\N	PRESENT	0
714101	712587	20118Y	PARTICIPANT	\N	PRESENT	0
714102	712587	19741B	PARTICIPANT	\N	PRESENT	0
714103	712587	08010L	PARTICIPANT	\N	PRESENT	0
714104	712587	19713W	PARTICIPANT	\N	PRESENT	0
714105	712587	20094J	PARTICIPANT	\N	PRESENT	0
714106	712587	19569H	PARTICIPANT	\N	PRESENT	0
714107	712587	14111D	PARTICIPANT	\N	PRESENT	0
714125	711614	14053L	PARTICIPANT	\N	PRESENT	0
714126	711614	14275Y	PARTICIPANT	\N	PRESENT	0
714127	711614	20074E	PARTICIPANT	\N	PRESENT	0
714128	711614	10015M	PARTICIPANT	\N	PRESENT	0
714129	711614	14179A	PARTICIPANT	\N	PRESENT	0
714130	711614	04047H	PRESIDENT	0	PRESENT	0
714131	711614	19673G	PARTICIPANT	\N	PRESENT	0
714132	711614	19447X	PARTICIPANT	\N	PRESENT	0
714133	711614	14231L	PARTICIPANT	\N	PRESENT	0
714134	711614	14111D	PARTICIPANT	\N	PRESENT	0
729260	729237	19954N	PARTICIPANT	\N	EXCUSE	0
729263	729238	20072C	PARTICIPANT	\N	EXCUSE	0
729275	729274	14097Y	PARTICIPANT	\N	PRESENT	0
729294	729290	20136B	PARTICIPANT	\N	PRESENT	0
730354	728028	20066E	PARTICIPANT	\N	PRESENT	0
730363	728902	20070A	PARTICIPANT	\N	PRESENT	0
730364	728902	20094J	PARTICIPANT	\N	PRESENT	0
730365	728902	20914V	PARTICIPANT	\N	PRESENT	0
730366	728902	20046A	PARTICIPANT	\N	PRESENT	0
730367	728902	19820Y	PARTICIPANT	\N	PRESENT	0
730441	729237	14259Y	PARTICIPANT	\N	PRESENT	0
730443	729237	20132W	PARTICIPANT	\N	PRESENT	0
730444	729237	20044X	PARTICIPANT	\N	PRESENT	0
730446	729237	95063L	PARTICIPANT	\N	PRESENT	0
730448	729237	11056N	PARTICIPANT	\N	PRESENT	0
730501	730499	14053L	PARTICIPANT	\N	PRESENT	0
730503	730499	14089Y	PARTICIPANT	\N	PRESENT	0
730504	730499	11026G	PARTICIPANT	\N	PRESENT	0
730541	730532	14331P	PARTICIPANT	\N	PRESENT	0
730542	730532	12041X	PARTICIPANT	\N	PRESENT	0
730543	728190	19467C	PARTICIPANT	\N	PRESENT	0
730544	728190	19369B	PARTICIPANT	\N	PRESENT	0
730550	729238	01048V	PARTICIPANT	\N	EXCUSE	0
730551	729238	19533U	PARTICIPANT	\N	PRESENT	0
730552	729238	04043D	PARTICIPANT	\N	PRESENT	0
730553	729238	19503N	PARTICIPANT	\N	PRESENT	0
730578	730577	20086J	PARTICIPANT	\N	PRESENT	0
730580	730579	20086J	PARTICIPANT	\N	PRESENT	0
730582	730581	11053K	PARTICIPANT	\N	PRESENT	0
730584	730583	11053K	PARTICIPANT	\N	PRESENT	0
730586	730585	11053K	PARTICIPANT	\N	PRESENT	0
730597	730596	14331P	PARTICIPANT	\N	PRESENT	0
730599	730598	14331P	PARTICIPANT	\N	PRESENT	0
730606	730604	20050V	PARTICIPANT	\N	PRESENT	0
730621	730618	20050V	PARTICIPANT	\N	PRESENT	0
730628	730350	19527W	PARTICIPANT	\N	PRESENT	0
730631	730560	17737W	PARTICIPANT	\N	EXCUSE	0
730633	730632	19820Y	PARTICIPANT	\N	PRESENT	0
730634	730632	20914V	PARTICIPANT	\N	PRESENT	0
730635	730632	19745F	PRESIDENT	0	PRESENT	0
730636	730632	20046A	PARTICIPANT	\N	PRESENT	0
730637	730632	20094J	PARTICIPANT	\N	PRESENT	0
730638	730632	05012A	PARTICIPANT	\N	EXCUSE	0
730769	730759	19701S	PARTICIPANT	\N	PRESENT	0
730792	730791	19515S	PARTICIPANT	\N	PRESENT	0
730794	730793	19553Y	PARTICIPANT	\N	PRESENT	0
731254	731251	20094J	PARTICIPANT	\N	PRESENT	0
731252	731251	05012A	PARTICIPANT	\N	PRESENT	0
731253	731251	19820Y	PARTICIPANT	\N	PRESENT	0
731258	730684	08010L	PARTICIPANT	\N	PRESENT	0
731264	730567	14053L	PARTICIPANT	\N	PRESENT	0
731265	730567	19749K	PARTICIPANT	\N	PRESENT	0
731267	730567	19649G	PARTICIPANT	\N	PRESENT	0
731273	731272	14053L	PARTICIPANT	\N	PRESENT	0
731274	731272	19749K	PARTICIPANT	\N	PRESENT	0
731276	731272	19649G	PARTICIPANT	\N	PRESENT	0
731277	731272	20114U	PARTICIPANT	\N	PRESENT	0
731280	731271	05008E	PARTICIPANT	\N	PRESENT	0
731281	731271	01028R	PARTICIPANT	\N	PRESENT	0
731284	731271	11053K	PARTICIPANT	\N	PRESENT	0
731510	730644	19725B	PARTICIPANT	\N	PRESENT	0
731511	730644	19954N	PARTICIPANT	\N	PRESENT	0
731512	730644	95063L	PARTICIPANT	\N	PRESENT	0
731513	730644	07004J	PARTICIPANT	\N	PRESENT	0
731514	730644	10015M	PARTICIPANT	\N	PRESENT	0
731515	730644	14001X	PARTICIPANT	\N	PRESENT	0
731516	730644	11085T	PARTICIPANT	\N	PRESENT	0
731517	730644	04047H	PRESIDENT	0	PRESENT	0
731518	730644	20022R	PARTICIPANT	\N	PRESENT	0
731519	730644	19543W	PARTICIPANT	\N	PRESENT	0
731520	730644	19581D	PARTICIPANT	\N	PRESENT	0
731521	730644	05008E	PARTICIPANT	\N	PRESENT	0
731522	730644	14231L	PARTICIPANT	\N	PRESENT	0
731523	730644	14275Y	PARTICIPANT	\N	PRESENT	0
731524	730644	20108W	PARTICIPANT	\N	PRESENT	0
731525	730644	14179A	PARTICIPANT	\N	PRESENT	0
731526	730644	14147R	PARTICIPANT	\N	PRESENT	0
731527	730644	14151M	PARTICIPANT	\N	PRESENT	0
731528	730644	20114U	PARTICIPANT	\N	PRESENT	0
731529	730644	14215L	PARTICIPANT	\N	PRESENT	0
731530	730644	14053L	PARTICIPANT	\N	PRESENT	0
731531	730644	11026G	PARTICIPANT	\N	PRESENT	0
731532	730644	14089Y	PARTICIPANT	\N	PRESENT	0
731533	730644	19729F	PARTICIPANT	\N	PRESENT	0
731534	730644	19629C	PARTICIPANT	\N	PRESENT	0
731535	730644	14069U	PARTICIPANT	\N	PRESENT	0
731536	730644	14021P	PARTICIPANT	\N	PRESENT	0
731538	730673	19565D	PARTICIPANT	\N	PRESENT	0
731539	730673	11041F	PARTICIPANT	\N	PRESENT	0
731540	730673	20042V	PARTICIPANT	\N	PRESENT	0
731541	730673	01058X	PARTICIPANT	\N	PRESENT	0
731542	730673	11027H	PARTICIPANT	\N	PRESENT	0
731543	730673	04042C	PRESIDENT	0	PRESENT	0
731544	730673	11066Q	PARTICIPANT	\N	PRESENT	0
731545	730673	19669L	PARTICIPANT	\N	PRESENT	0
731546	730673	12028B	PARTICIPANT	\N	PRESENT	0
731547	730673	20064C	PARTICIPANT	\N	PRESENT	0
731548	730673	98022P	PARTICIPANT	\N	PRESENT	0
731549	730673	14193X	PARTICIPANT	\N	PRESENT	0
731550	730673	14267Y	PARTICIPANT	\N	PRESENT	0
731551	730673	11083R	PARTICIPANT	\N	PRESENT	0
731552	730673	97011G	PARTICIPANT	\N	PRESENT	0
731553	730673	08061X	PARTICIPANT	\N	PRESENT	0
731554	730673	14249W	PARTICIPANT	\N	PRESENT	0
731555	730673	14255U	PARTICIPANT	\N	PRESENT	0
731556	730673	08056B	PARTICIPANT	\N	EXCUSE	0
731557	730673	14097Y	PARTICIPANT	\N	EXCUSE	0
731558	730673	14059S	PARTICIPANT	\N	EXCUSE	0
731559	730673	20072C	PARTICIPANT	\N	EXCUSE	0
731560	730673	19421M	PARTICIPANT	\N	EXCUSE	0
731561	730673	19709B	PARTICIPANT	\N	EXCUSE	0
731562	730673	16685X	PARTICIPANT	\N	EXCUSE	0
731563	730673	14211G	PARTICIPANT	\N	EXCUSE	0
731610	730320	04070G	PARTICIPANT	\N	PRESENT	0
731611	730320	19699S	PARTICIPANT	\N	PRESENT	0
731612	730320	19533U	PARTICIPANT	\N	PRESENT	0
731613	730320	01060R	PARTICIPANT	\N	PRESENT	0
731614	730320	14229S	PARTICIPANT	\N	PRESENT	0
731615	730320	19573D	PARTICIPANT	\N	PRESENT	0
731616	730320	20124W	PARTICIPANT	\N	PRESENT	0
731617	730320	20026V	PARTICIPANT	\N	PRESENT	0
731618	730320	19593H	PARTICIPANT	\N	PRESENT	0
731619	730320	19527W	PARTICIPANT	\N	PRESENT	0
731620	730320	19643A	PARTICIPANT	\N	PRESENT	0
731621	730320	14073Q	PARTICIPANT	\N	PRESENT	0
731622	730320	19611R	PRESIDENT	0	PRESENT	0
731623	730320	20142Y	PARTICIPANT	\N	PRESENT	0
731624	730320	19399H	PARTICIPANT	\N	PRESENT	0
731625	730320	20152B	PARTICIPANT	\N	PRESENT	0
731626	730320	20172F	PARTICIPANT	\N	PRESENT	0
731627	730320	20056C	PARTICIPANT	\N	PRESENT	0
731628	730320	20180F	PARTICIPANT	\N	PRESENT	0
731629	730320	20264J	PARTICIPANT	\N	PRESENT	0
731630	730320	04059M	PARTICIPANT	\N	PRESENT	0
731631	730320	14109K	PARTICIPANT	\N	PRESENT	0
731632	730320	14123H	PARTICIPANT	\N	PRESENT	0
731633	730320	11104D	PARTICIPANT	\N	PRESENT	0
731634	730320	19758L	PARTICIPANT	\N	PRESENT	0
713092	708202	14211G	PARTICIPANT	\N	PRESENT	0
713093	708202	11045K	PARTICIPANT	\N	PRESENT	0
713094	708202	11072N	PARTICIPANT	\N	PRESENT	0
713095	708202	19697Q	PARTICIPANT	\N	PRESENT	0
713096	708202	19675J	PARTICIPANT	\N	PRESENT	0
713097	708202	14253S	PARTICIPANT	\N	PRESENT	0
713098	708202	20026V	PARTICIPANT	\N	PRESENT	0
713099	708202	20044X	PARTICIPANT	\N	PRESENT	0
713100	708202	19347U	PARTICIPANT	\N	PRESENT	0
713101	708202	19489J	PARTICIPANT	\N	PRESENT	0
713102	708202	08011M	PARTICIPANT	\N	PRESENT	0
713103	708202	19415P	PARTICIPANT	\N	PRESENT	0
713104	708202	08034U	PARTICIPANT	\N	PRESENT	0
713105	708202	08010L	PARTICIPANT	\N	PRESENT	0
713106	708202	19413M	PARTICIPANT	\N	PRESENT	0
713107	708202	14259Y	PARTICIPANT	\N	PRESENT	0
713108	708202	19467C	PARTICIPANT	\N	PRESENT	0
713109	708202	20034V	PARTICIPANT	\N	PRESENT	0
713110	708202	19693L	PARTICIPANT	\N	PRESENT	0
713111	708202	19657G	PARTICIPANT	\N	PRESENT	0
713112	708202	14038Y	PARTICIPANT	\N	PRESENT	0
713113	708202	14109K	PARTICIPANT	\N	PRESENT	0
713114	708202	19479G	PARTICIPANT	\N	PRESENT	0
713115	708202	20076G	PARTICIPANT	\N	PRESENT	0
713116	708202	19758L	PARTICIPANT	\N	PRESENT	0
713117	708202	20098N	PARTICIPANT	\N	PRESENT	0
713118	708202	20140W	PARTICIPANT	\N	PRESENT	0
713119	708202	04057K	PARTICIPANT	\N	PRESENT	0
713120	708202	19711U	PARTICIPANT	\N	PRESENT	0
713121	708202	19515S	PARTICIPANT	\N	PRESENT	0
713122	708202	14031R	PARTICIPANT	\N	PRESENT	0
713123	708202	07033P	PARTICIPANT	\N	PRESENT	0
713124	708202	20038A	PARTICIPANT	\N	PRESENT	0
713125	708202	20180F	PARTICIPANT	\N	PRESENT	0
713126	708202	20084G	PARTICIPANT	\N	PRESENT	0
713127	708202	20070A	PARTICIPANT	\N	PRESENT	0
713128	708202	20152B	PARTICIPANT	\N	PRESENT	0
713129	708202	14037X	PARTICIPANT	\N	PRESENT	0
713130	708202	20980G	PARTICIPANT	\N	PRESENT	0
713131	708202	04092N	PARTICIPANT	\N	PRESENT	0
713132	708202	19553Y	PARTICIPANT	\N	PRESENT	0
713133	708202	14187A	PARTICIPANT	\N	PRESENT	0
713134	708202	04047H	PARTICIPANT	\N	PRESENT	0
713135	708202	14147R	PARTICIPANT	\N	PRESENT	0
713136	708202	19709B	PARTICIPANT	\N	PRESENT	0
713137	708202	08061X	PARTICIPANT	\N	PRESENT	0
713138	708202	20124W	PARTICIPANT	\N	PRESENT	0
713139	708202	14021P	PARTICIPANT	\N	PRESENT	0
713140	708202	11054L	PARTICIPANT	\N	PRESENT	0
713141	708202	05012A	PARTICIPANT	\N	PRESENT	0
713142	708202	01057W	PARTICIPANT	\N	PRESENT	0
713143	708202	19573D	PARTICIPANT	\N	PRESENT	0
713144	708202	14251Q	PARTICIPANT	\N	PRESENT	0
713145	708202	95063L	PARTICIPANT	\N	PRESENT	0
713146	708202	19575F	PARTICIPANT	\N	PRESENT	0
713147	708202	14257W	PARTICIPANT	\N	PRESENT	0
713148	708202	19527W	PARTICIPANT	\N	PRESENT	0
713149	708202	19649G	PARTICIPANT	\N	PRESENT	0
713150	708202	04059M	PARTICIPANT	\N	PRESENT	0
713151	708202	12028B	PARTICIPANT	\N	PRESENT	0
713152	708202	20120S	PARTICIPANT	\N	PRESENT	0
713153	708202	19866P	PARTICIPANT	\N	PRESENT	0
713154	708202	19669L	PARTICIPANT	\N	PRESENT	0
713155	708202	19531S	PARTICIPANT	\N	PRESENT	0
713156	708202	19703U	PARTICIPANT	\N	PRESENT	0
713090	708202	14123H	PARTICIPANT	\N	PRESENT	0
713091	708202	18083K	PARTICIPANT	\N	PRESENT	0
713157	708202	19719D	PARTICIPANT	\N	PRESENT	0
713158	708202	11027H	PARTICIPANT	\N	PRESENT	0
713159	708202	11053K	PARTICIPANT	\N	PRESENT	0
713160	708202	16685X	PARTICIPANT	\N	PRESENT	0
713161	708202	19569H	PARTICIPANT	\N	PRESENT	0
713162	708202	12041X	PARTICIPANT	\N	PRESENT	0
713163	708202	01058X	PARTICIPANT	\N	PRESENT	0
713164	708202	08018U	PARTICIPANT	\N	PRESENT	0
713165	708202	17965H	PARTICIPANT	\N	PRESENT	0
713166	708202	11099A	PARTICIPANT	\N	PRESENT	0
713167	708202	20266L	PARTICIPANT	\N	PRESENT	0
713168	708202	20110Q	PARTICIPANT	\N	PRESENT	0
713169	708202	20060X	PARTICIPANT	\N	PRESENT	0
713170	708202	19713W	PARTICIPANT	\N	PRESENT	0
713171	708202	19691J	PARTICIPANT	\N	PRESENT	0
713172	708202	19295A	PARTICIPANT	\N	PRESENT	0
713173	708202	14059S	PARTICIPANT	\N	PRESENT	0
713174	708202	20914V	PARTICIPANT	\N	PRESENT	0
713175	708202	20094J	PARTICIPANT	\N	PRESENT	0
713176	708202	14255U	PARTICIPANT	\N	PRESENT	0
713177	708202	20138D	PARTICIPANT	\N	PRESENT	0
713178	708202	11101A	PARTICIPANT	\N	PRESENT	0
713179	708202	19820Y	PARTICIPANT	\N	PRESENT	0
713180	708202	19369B	PARTICIPANT	\N	PRESENT	0
713181	708202	20100N	PARTICIPANT	\N	PRESENT	0
713182	708202	20046A	PARTICIPANT	\N	PRESENT	0
713183	708202	20112S	PARTICIPANT	\N	PRESENT	0
713184	708202	17367Q	PARTICIPANT	\N	PRESENT	0
713185	708202	19643A	PARTICIPANT	\N	PRESENT	0
713186	708202	20126Y	PARTICIPANT	\N	PRESENT	0
713187	708202	20062A	PARTICIPANT	\N	PRESENT	0
713188	708202	20252E	PARTICIPANT	\N	PRESENT	0
713189	708202	19591F	PARTICIPANT	\N	PRESENT	0
713190	708202	04033B	PARTICIPANT	\N	PRESENT	0
713315	708203	11045K	PARTICIPANT	\N	PRESENT	0
713316	708203	04033B	PARTICIPANT	\N	PRESENT	0
713317	708203	14123H	PARTICIPANT	\N	PRESENT	0
713318	708203	12041X	PARTICIPANT	\N	PRESENT	0
713319	708203	10006L	PARTICIPANT	\N	PRESENT	0
713320	708203	14042U	PARTICIPANT	\N	PRESENT	0
713321	708203	08011M	PARTICIPANT	\N	PRESENT	0
713322	708203	11097X	PARTICIPANT	\N	PRESENT	0
713323	708203	19575F	PARTICIPANT	\N	PRESENT	0
713324	708203	14021P	PARTICIPANT	\N	PRESENT	0
713325	708203	08061X	PARTICIPANT	\N	PRESENT	0
713326	708203	99004R	PARTICIPANT	\N	PRESENT	0
713327	708203	19669L	PARTICIPANT	\N	PRESENT	0
713328	708203	04047H	PARTICIPANT	\N	PRESENT	0
713329	708203	20134Y	PARTICIPANT	\N	PRESENT	0
713330	708203	08034U	PARTICIPANT	\N	PRESENT	0
713331	708203	20060X	PARTICIPANT	\N	PRESENT	0
713332	708203	14187A	PARTICIPANT	\N	PRESENT	0
713333	708203	18193Q	PARTICIPANT	\N	PRESENT	0
713334	708203	17965H	PARTICIPANT	\N	PRESENT	0
713335	708203	11067R	PARTICIPANT	\N	PRESENT	0
713336	708203	19415P	PARTICIPANT	\N	PRESENT	0
713337	708203	14257W	PARTICIPANT	\N	PRESENT	0
713338	708203	14053L	PARTICIPANT	\N	PRESENT	0
713339	708203	19531S	PARTICIPANT	\N	PRESENT	0
713340	708203	18083K	PARTICIPANT	\N	PRESENT	0
713341	708203	05012A	PARTICIPANT	\N	PRESENT	0
713342	708203	20152B	PARTICIPANT	\N	PRESENT	0
713343	708203	19703U	PARTICIPANT	\N	PRESENT	0
713344	708203	14217N	PARTICIPANT	\N	PRESENT	0
713345	708203	20120S	PARTICIPANT	\N	PRESENT	0
713346	708203	19413M	PARTICIPANT	\N	PRESENT	0
713347	708203	14357A	PARTICIPANT	\N	PRESENT	0
713348	708203	20124W	PARTICIPANT	\N	PRESENT	0
713349	708203	14059S	PARTICIPANT	\N	PRESENT	0
713350	708203	20090E	PARTICIPANT	\N	PRESENT	0
713351	708203	14281W	PARTICIPANT	\N	PRESENT	0
713352	708203	14109K	PARTICIPANT	\N	PRESENT	0
713353	708203	11101A	PARTICIPANT	\N	PRESENT	0
713354	708203	20264J	PARTICIPANT	\N	PRESENT	0
713355	708203	07033P	PARTICIPANT	\N	PRESENT	0
713356	708203	20092G	PARTICIPANT	\N	PRESENT	0
713357	708203	20062A	PARTICIPANT	\N	PRESENT	0
713358	708203	14147R	PARTICIPANT	\N	PRESENT	0
713359	708203	20138D	PARTICIPANT	\N	PRESENT	0
713360	708203	14253S	PARTICIPANT	\N	PRESENT	0
713361	708203	20044X	PARTICIPANT	\N	PRESENT	0
713362	708203	19329S	PARTICIPANT	\N	PRESENT	0
713363	708203	17367Q	PARTICIPANT	\N	PRESENT	0
713364	708203	19782L	PARTICIPANT	\N	PRESENT	0
713365	708203	20266L	PARTICIPANT	\N	PRESENT	0
713366	708203	17779H	PARTICIPANT	\N	PRESENT	0
713367	708203	14038Y	PARTICIPANT	\N	PRESENT	0
713368	708203	19573D	PARTICIPANT	\N	PRESENT	0
713369	708203	20980G	PARTICIPANT	\N	PRESENT	0
713370	708203	20038A	PARTICIPANT	\N	PRESENT	0
713371	708203	20034V	PARTICIPANT	\N	PRESENT	0
713372	708203	19515S	PARTICIPANT	\N	PRESENT	0
713373	708203	11080N	PARTICIPANT	\N	PRESENT	0
713374	708203	14037X	PARTICIPANT	\N	PRESENT	0
735559	735554	19713W	PARTICIPANT	\N	PRESENT	0
735560	735555	20130U	PARTICIPANT	\N	PRESENT	0
735561	735555	19713W	PARTICIPANT	\N	PRESENT	0
735562	735556	17965H	PARTICIPANT	\N	PRESENT	0
735563	735556	19713W	PARTICIPANT	\N	PRESENT	0
735564	735557	17965H	PARTICIPANT	\N	PRESENT	0
735565	735557	19713W	PARTICIPANT	\N	PRESENT	0
735568	735566	19415P	PARTICIPANT	\N	PRESENT	0
735569	735566	14217N	PARTICIPANT	\N	PRESENT	0
736877	736876	14189C	PARTICIPANT	\N	PRESENT	0
736878	736876	20076G	PARTICIPANT	\N	PRESENT	0
736879	736876	16685X	PARTICIPANT	\N	PRESENT	0
736880	736876	14205J	PARTICIPANT	\N	PRESENT	0
736881	736876	20082E	PARTICIPANT	\N	PRESENT	0
736882	736876	11097X	PARTICIPANT	\N	PRESENT	0
737021	736607	20088L	PARTICIPANT	\N	PRESENT	0
737022	736607	20082E	PARTICIPANT	\N	PRESENT	0
737023	736607	14329V	PARTICIPANT	\N	PRESENT	0
737061	735420	19443T	PARTICIPANT	\N	EXCUSE	0
737070	735421	19443T	PARTICIPANT	\N	EXCUSE	0
737226	735539	20100N	PARTICIPANT	\N	PRESENT	0
737227	735539	14215L	PARTICIPANT	\N	PRESENT	0
737228	735539	10006L	PARTICIPANT	\N	PRESENT	0
737229	735539	08061X	PARTICIPANT	\N	PRESENT	0
737230	735539	20118Y	PARTICIPANT	\N	PRESENT	0
737231	735539	19798U	PARTICIPANT	\N	PRESENT	0
737232	735539	95063L	PARTICIPANT	\N	PRESENT	0
737233	735539	14193X	PARTICIPANT	\N	PRESENT	0
737234	735539	19651A	PARTICIPANT	\N	PRESENT	0
737235	735539	20152B	PARTICIPANT	\N	PRESENT	0
737236	735539	20054A	PARTICIPANT	\N	PRESENT	0
737237	735539	20126Y	PARTICIPANT	\N	PRESENT	0
737238	735539	20124W	PARTICIPANT	\N	PRESENT	0
737239	735539	14217N	PARTICIPANT	\N	PRESENT	0
737240	735539	07033P	PARTICIPANT	\N	PRESENT	0
737241	735539	14189C	PARTICIPANT	\N	PRESENT	0
737242	735539	19543W	PARTICIPANT	\N	PRESENT	0
737243	735539	14026U	PARTICIPANT	\N	PRESENT	0
737244	735539	14030Q	PARTICIPANT	\N	PRESENT	0
737245	735539	20042V	PARTICIPANT	\N	PRESENT	0
737246	735539	14083S	PARTICIPANT	\N	PRESENT	0
737247	735539	11053K	PARTICIPANT	\N	PRESENT	0
737248	735539	11070L	PARTICIPANT	\N	PRESENT	0
737249	735539	14327T	PARTICIPANT	\N	PRESENT	0
737250	735539	01024M	PARTICIPANT	\N	PRESENT	0
737251	735539	97011G	PARTICIPANT	\N	PRESENT	0
737252	735539	14042U	PARTICIPANT	\N	PRESENT	0
737253	735539	20040T	PARTICIPANT	\N	PRESENT	0
737254	735539	14329V	PARTICIPANT	\N	PRESENT	0
737255	735539	14231L	PARTICIPANT	\N	PRESENT	0
737256	735539	04035D	PARTICIPANT	\N	PRESENT	0
737257	735539	07004J	PARTICIPANT	\N	PRESENT	0
737258	735539	19691J	PARTICIPANT	\N	PRESENT	0
737259	735539	20286Q	PARTICIPANT	\N	PRESENT	0
737263	735539	20048C	PARTICIPANT	\N	PRESENT	0
737261	735539	19758L	PARTICIPANT	\N	PRESENT	0
737262	735539	19685L	PARTICIPANT	\N	PRESENT	0
737264	735539	20066E	PARTICIPANT	\N	PRESENT	0
737265	735539	14357A	PARTICIPANT	\N	PRESENT	0
737266	735539	14073Q	PARTICIPANT	\N	PRESENT	0
737267	735539	19735D	PARTICIPANT	\N	PRESENT	0
737268	735539	01043Q	PARTICIPANT	\N	PRESENT	0
737269	735539	19657G	PARTICIPANT	\N	PRESENT	0
737270	735539	20052X	PARTICIPANT	\N	PRESENT	0
737271	735539	14205J	PARTICIPANT	\N	PRESENT	0
737272	735539	14219Q	PARTICIPANT	\N	PRESENT	0
737273	735539	19441R	PARTICIPANT	\N	PRESENT	0
737274	735539	11085T	PARTICIPANT	\N	PRESENT	0
737275	735539	08009T	PARTICIPANT	\N	PRESENT	0
737276	735539	19335Q	PARTICIPANT	\N	PRESENT	0
737277	735539	19369B	PARTICIPANT	\N	PRESENT	0
737278	735539	04070G	PARTICIPANT	\N	PRESENT	0
737279	735539	19723Y	PARTICIPANT	\N	PRESENT	0
737280	735539	19745F	PARTICIPANT	\N	PRESENT	0
737281	735539	19739H	PARTICIPANT	\N	PRESENT	0
737282	735539	20298U	PARTICIPANT	\N	PRESENT	0
737283	735539	19619A	PARTICIPANT	\N	PRESENT	0
737284	735539	14275Y	PARTICIPANT	\N	PRESENT	0
737285	735539	19749K	PARTICIPANT	\N	PRESENT	0
737286	735539	08073C	PARTICIPANT	\N	PRESENT	0
737287	735539	19679N	PARTICIPANT	\N	PRESENT	0
737288	735539	20076G	PARTICIPANT	\N	PRESENT	0
737289	735539	20072C	PARTICIPANT	\N	PRESENT	0
737290	735539	20078J	PARTICIPANT	\N	PRESENT	0
737291	735539	08034U	PARTICIPANT	\N	PRESENT	0
737292	735539	19707Y	PARTICIPANT	\N	PRESENT	0
737293	735539	19705W	PARTICIPANT	\N	PRESENT	0
737300	735539	11101A	PARTICIPANT	\N	PRESENT	0
737295	735539	20020P	PARTICIPANT	\N	PRESENT	0
737296	735539	19515S	PARTICIPANT	\N	PRESENT	0
737297	735539	20024T	PARTICIPANT	\N	PRESENT	0
737298	735539	19762G	PARTICIPANT	\N	PRESENT	0
737302	735539	19383Y	PARTICIPANT	\N	PRESENT	0
737301	735539	20032T	PARTICIPANT	\N	PRESENT	0
737303	735539	19747H	PARTICIPANT	\N	PRESENT	0
737304	735539	19467C	PARTICIPANT	\N	PRESENT	0
737305	735539	20038A	PARTICIPANT	\N	PRESENT	0
737306	735539	14229S	PARTICIPANT	\N	PRESENT	0
737307	735539	19709B	PARTICIPANT	\N	PRESENT	0
737308	735539	04092N	PARTICIPANT	\N	PRESENT	0
737309	735539	14223L	PARTICIPANT	\N	PRESENT	0
737317	735539	07029T	PARTICIPANT	\N	PRESENT	0
737311	735539	11043H	PARTICIPANT	\N	PRESENT	0
737312	735539	04033B	PARTICIPANT	\N	PRESENT	0
737313	735539	20058E	PARTICIPANT	\N	PRESENT	0
737314	735539	19766L	PARTICIPANT	\N	PRESENT	0
737315	735539	20136B	PARTICIPANT	\N	PRESENT	0
737316	735539	20034V	PARTICIPANT	\N	PRESENT	0
737318	735539	14147R	PARTICIPANT	\N	PRESENT	0
737319	735539	08011M	PARTICIPANT	\N	PRESENT	0
737320	735539	14059S	PARTICIPANT	\N	PRESENT	0
737321	735539	08056B	PARTICIPANT	\N	PRESENT	0
737325	735539	19826F	PARTICIPANT	\N	PRESENT	0
737323	735539	18083K	PARTICIPANT	\N	PRESENT	0
737324	735539	20080C	PARTICIPANT	\N	PRESENT	0
737329	735539	19643A	PARTICIPANT	\N	PRESENT	0
737327	735539	19421M	PARTICIPANT	\N	PRESENT	0
737328	735539	14089Y	PARTICIPANT	\N	PRESENT	0
737330	735539	20914V	PARTICIPANT	\N	PRESENT	0
737331	735539	20082E	PARTICIPANT	\N	PRESENT	0
737332	735539	20062A	PARTICIPANT	\N	PRESENT	0
737333	735539	14257W	PARTICIPANT	\N	PRESENT	0
737338	737337	11027H	PARTICIPANT	\N	PRESENT	0
737335	735539	17637T	PARTICIPANT	\N	PRESENT	0
737336	735539	19531S	PARTICIPANT	\N	PRESENT	0
737339	737337	14193X	PARTICIPANT	\N	PRESENT	0
737340	735539	17023S	PARTICIPANT	\N	PRESENT	0
737630	735542	99004R	PARTICIPANT	\N	PRESENT	0
737631	735542	11090Q	PARTICIPANT	\N	PRESENT	0
737655	735542	04042C	PARTICIPANT	\N	PRESENT	0
737657	735542	19745F	PARTICIPANT	\N	PRESENT	0
737634	735542	19583F	PARTICIPANT	\N	PRESENT	0
737635	735542	14107H	PARTICIPANT	\N	PRESENT	0
737636	735542	14121F	PARTICIPANT	\N	PRESENT	0
737653	735542	19782L	PARTICIPANT	\N	PRESENT	0
737638	734153	20080C	PARTICIPANT	\N	PRESENT	0
737639	734153	19741B	PRESIDENT	0	PRESENT	0
737640	734153	19866P	PARTICIPANT	\N	PRESENT	0
737641	735542	20134Y	PARTICIPANT	\N	PRESENT	0
737642	735542	20914V	PARTICIPANT	\N	PRESENT	0
737643	735542	11012A	PARTICIPANT	\N	PRESENT	0
737644	735542	14026U	PARTICIPANT	\N	PRESENT	0
737645	735542	14331P	PARTICIPANT	\N	PRESENT	0
737646	735542	19798U	PARTICIPANT	\N	PRESENT	0
737647	735542	20286Q	PARTICIPANT	\N	PRESENT	0
737648	734153	19333N	PARTICIPANT	\N	PRESENT	0
737649	734153	14281W	PARTICIPANT	\N	PRESENT	0
737650	734153	20044X	PARTICIPANT	\N	PRESENT	0
737651	734153	19619A	PARTICIPANT	\N	PRESENT	0
737652	735542	14069U	PARTICIPANT	\N	PRESENT	0
737654	735542	14225N	PARTICIPANT	\N	PRESENT	0
737656	735542	20110Q	PARTICIPANT	\N	PRESENT	0
737658	735542	14111D	PARTICIPANT	\N	PRESENT	0
737659	735542	04085P	PARTICIPANT	\N	PRESENT	0
737660	735542	20032T	PARTICIPANT	\N	PRESENT	0
737667	735542	10006L	PARTICIPANT	\N	PRESENT	0
737662	735542	19611R	PARTICIPANT	\N	PRESENT	0
737663	734153	05012A	PARTICIPANT	\N	PRESENT	0
737664	734153	20022R	PARTICIPANT	\N	PRESENT	0
737665	734153	19758L	PARTICIPANT	\N	PRESENT	0
737666	734153	19631V	PARTICIPANT	\N	PRESENT	0
714135	711614	11026G	PARTICIPANT	\N	PRESENT	0
714136	711614	19301E	PARTICIPANT	\N	PRESENT	0
714137	711614	11033F	PARTICIPANT	\N	PRESENT	0
714138	711614	19629C	PARTICIPANT	\N	PRESENT	0
714139	711614	07004J	PARTICIPANT	\N	PRESENT	0
714140	711614	14107H	PARTICIPANT	\N	PRESENT	0
714141	711614	20110Q	PARTICIPANT	\N	PRESENT	0
714142	711614	14147R	PARTICIPANT	\N	PRESENT	0
714143	711614	20022R	PARTICIPANT	\N	PRESENT	0
714144	711614	11072N	PARTICIPANT	\N	PRESENT	0
714145	711614	14001X	PARTICIPANT	\N	EXCUSE	0
714146	711614	19585H	PARTICIPANT	\N	PRESENT	0
714147	711614	05008E	PARTICIPANT	\N	PRESENT	0
714148	711614	17737W	PARTICIPANT	\N	PRESENT	0
714149	711614	20108W	PARTICIPANT	\N	PRESENT	0
714150	711614	14215L	PARTICIPANT	\N	PRESENT	0
714151	711614	14089Y	PARTICIPANT	\N	PRESENT	0
714152	711614	19729F	PARTICIPANT	\N	PRESENT	0
714153	711614	14021P	PARTICIPANT	\N	PRESENT	0
714154	711614	14151M	PARTICIPANT	\N	PRESENT	0
714155	711614	95063L	PARTICIPANT	\N	PRESENT	0
714156	711614	19749K	PARTICIPANT	\N	PRESENT	0
714157	711614	04085P	PARTICIPANT	\N	PRESENT	0
714158	711614	01028R	PARTICIPANT	\N	PRESENT	0
714159	711614	20114U	PARTICIPANT	\N	PRESENT	0
714160	711614	14259Y	PARTICIPANT	\N	PRESENT	0
714161	711614	19725B	PARTICIPANT	\N	PRESENT	0
714164	714162	07029T	PARTICIPANT	\N	EXCUSE	0
714165	714162	19479G	PARTICIPANT	\N	EXCUSE	0
714166	711614	19543W	PARTICIPANT	\N	PRESENT	0
714167	711614	19581D	PARTICIPANT	\N	PRESENT	0
714168	711614	14069U	PARTICIPANT	\N	PRESENT	0
714169	702239	20100N	PARTICIPANT	\N	PRESENT	0
714170	702239	19701S	PARTICIPANT	\N	PRESENT	0
714171	702239	20068G	PARTICIPANT	\N	PRESENT	0
714172	702239	20038A	PARTICIPANT	\N	PRESENT	0
714173	702239	14237S	PARTICIPANT	\N	PRESENT	0
714174	702239	19251M	PARTICIPANT	\N	PRESENT	0
714175	702239	20024T	PARTICIPANT	\N	PRESENT	0
714176	702239	19525U	PARTICIPANT	\N	PRESENT	0
714177	702239	14219Q	PRESIDENT	0	PRESENT	0
714178	702239	19826F	PARTICIPANT	\N	PRESENT	0
714179	702239	17229F	PARTICIPANT	\N	PRESENT	0
714180	702239	18083K	PARTICIPANT	\N	PRESENT	0
714181	702239	17367Q	PARTICIPANT	\N	PRESENT	0
714182	702239	19619A	PARTICIPANT	\N	PRESENT	0
714183	702239	19333N	PARTICIPANT	\N	PRESENT	0
714184	702239	20032T	PARTICIPANT	\N	PRESENT	0
714185	702239	20140W	PARTICIPANT	\N	PRESENT	0
714186	702239	19820Y	PARTICIPANT	\N	PRESENT	0
714187	702239	20046A	PARTICIPANT	\N	PRESENT	0
714188	702239	19599P	PARTICIPANT	\N	PRESENT	0
714189	702239	19503N	PARTICIPANT	\N	PRESENT	0
714190	702239	19739H	PARTICIPANT	\N	PRESENT	0
714191	702239	19745F	PARTICIPANT	\N	PRESENT	0
714192	702239	19659J	PARTICIPANT	\N	PRESENT	0
714193	711614	19489J	PARTICIPANT	\N	PRESENT	0
714195	702239	19387D	PARTICIPANT	\N	PRESENT	0
714197	702239	19637C	PARTICIPANT	\N	EXCUSE	0
714198	702239	14221J	PARTICIPANT	\N	PRESENT	0
714199	702239	20118Y	PARTICIPANT	\N	PRESENT	0
714200	702239	14031R	PARTICIPANT	\N	PRESENT	0
714201	702239	19577H	PARTICIPANT	\N	PRESENT	0
714202	702239	20122U	PARTICIPANT	\N	PRESENT	0
714203	702239	19549D	PARTICIPANT	\N	PRESENT	0
714204	712198	14059S	PARTICIPANT	\N	PRESENT	0
714205	712198	04035D	PARTICIPANT	\N	PRESENT	0
714206	712198	12041X	PARTICIPANT	\N	PRESENT	0
714207	712198	14133K	PARTICIPANT	\N	PRESENT	0
714208	712198	19565D	PARTICIPANT	\N	PRESENT	0
714209	712198	01062T	PARTICIPANT	\N	PRESENT	0
714210	712198	11041F	PARTICIPANT	\N	PRESENT	0
714211	712198	01058X	PARTICIPANT	\N	PRESENT	0
714212	712198	16685X	PARTICIPANT	\N	PRESENT	0
714213	712198	11027H	PARTICIPANT	\N	PRESENT	0
714214	712198	04042C	PRESIDENT	0	PRESENT	0
714215	712198	01024M	PARTICIPANT	\N	PRESENT	0
714216	712198	11054L	PARTICIPANT	\N	PRESENT	0
714217	712198	11066Q	PARTICIPANT	\N	PRESENT	0
714218	712198	19669L	PARTICIPANT	\N	PRESENT	0
714219	712198	14191V	PARTICIPANT	\N	PRESENT	0
714220	712198	12028B	PARTICIPANT	\N	PRESENT	0
714221	712198	20064C	PARTICIPANT	\N	PRESENT	0
714222	712198	19421M	PARTICIPANT	\N	PRESENT	0
714223	712198	14267Y	PARTICIPANT	\N	PRESENT	0
714224	712198	19347U	PARTICIPANT	\N	PRESENT	0
714225	712198	11083R	PARTICIPANT	\N	PRESENT	0
714226	712198	08047A	PARTICIPANT	\N	PRESENT	0
714227	712198	14255U	PARTICIPANT	\N	PRESENT	0
714228	712198	19443T	PARTICIPANT	\N	EXCUSE	0
714229	712198	08069G	PARTICIPANT	\N	EXCUSE	0
714230	712198	20128B	PARTICIPANT	\N	PRESENT	0
714231	702239	05012A	PARTICIPANT	\N	PRESENT	0
714232	702239	20120S	PARTICIPANT	\N	PRESENT	0
714233	712198	19319Q	PARTICIPANT	\N	PRESENT	0
714234	702239	20106U	PARTICIPANT	\N	PRESENT	0
714235	712198	14097Y	PARTICIPANT	\N	PRESENT	0
714238	712198	17023S	PARTICIPANT	\N	PRESENT	0
714239	712198	20072C	PARTICIPANT	\N	EXCUSE	0
714240	702239	11101A	PARTICIPANT	\N	PRESENT	0
714241	712198	11080N	PARTICIPANT	\N	PRESENT	0
714242	712198	19709B	PARTICIPANT	\N	PRESENT	0
714243	702239	20136B	PARTICIPANT	\N	PRESENT	0
714244	711614	19649G	PARTICIPANT	\N	PRESENT	0
714245	711614	11056N	PARTICIPANT	\N	PRESENT	0
714246	711614	04008A	PARTICIPANT	\N	PRESENT	0
714247	702239	08060W	PARTICIPANT	\N	PRESENT	0
714248	702239	19685L	PARTICIPANT	\N	PRESENT	0
714302	714163	12016W	PARTICIPANT	\N	PRESENT	0
714303	714163	19545Y	PARTICIPANT	\N	PRESENT	0
714304	714163	20126Y	PARTICIPANT	\N	PRESENT	0
714305	714163	11053K	PARTICIPANT	\N	PRESENT	0
714307	708936	19766L	PARTICIPANT	\N	PRESENT	0
714308	708936	19699S	PARTICIPANT	\N	PRESENT	0
714309	708936	04033B	PARTICIPANT	\N	PRESENT	0
714310	708936	14229S	PARTICIPANT	\N	PRESENT	0
714311	708936	20098N	PARTICIPANT	\N	PRESENT	0
714312	708936	19573D	PARTICIPANT	\N	PRESENT	0
714313	708936	20112S	PARTICIPANT	\N	PRESENT	0
714314	708936	08012N	PARTICIPANT	\N	PRESENT	0
714315	708936	20026V	PARTICIPANT	\N	PRESENT	0
714316	708936	19593H	PARTICIPANT	\N	PRESENT	0
714317	708936	19527W	PARTICIPANT	\N	PRESENT	0
714318	708936	19643A	PARTICIPANT	\N	PRESENT	0
714319	708936	20132W	PARTICIPANT	\N	PRESENT	0
714320	708936	20134Y	PARTICIPANT	\N	PRESENT	0
714321	708936	19651A	PARTICIPANT	\N	PRESENT	0
714322	708936	14073Q	PARTICIPANT	\N	PRESENT	0
714323	708936	19611R	PRESIDENT	0	PRESENT	0
714324	708936	20142Y	PARTICIPANT	\N	PRESENT	0
714325	708936	19693L	PARTICIPANT	\N	PRESENT	0
714326	708936	19399H	PARTICIPANT	\N	PRESENT	0
714327	708936	20052X	PARTICIPANT	\N	PRESENT	0
714328	708936	19719D	PARTICIPANT	\N	PRESENT	0
714329	708936	20152B	PARTICIPANT	\N	PRESENT	0
714330	708936	20172F	PARTICIPANT	\N	PRESENT	0
714331	708936	14030Q	PARTICIPANT	\N	PRESENT	0
714332	708936	20058E	PARTICIPANT	\N	PRESENT	0
714333	708936	20056C	PARTICIPANT	\N	PRESENT	0
714334	708936	20180F	PARTICIPANT	\N	PRESENT	0
714335	708936	20264J	PARTICIPANT	\N	PRESENT	0
714336	708936	04059M	PARTICIPANT	\N	PRESENT	0
714337	708936	19735D	PARTICIPANT	\N	PRESENT	0
714338	708936	19057M	PARTICIPANT	\N	PRESENT	0
714339	708936	14109K	PARTICIPANT	\N	PRESENT	0
714340	708936	14123H	PARTICIPANT	\N	PRESENT	0
714341	708936	20980G	PARTICIPANT	\N	PRESENT	0
714342	708936	11104D	PARTICIPANT	\N	PRESENT	0
714343	708936	19758L	PARTICIPANT	\N	PRESENT	0
714344	708936	17589D	PARTICIPANT	\N	PRESENT	0
714345	708936	20084G	PARTICIPANT	\N	PRESENT	0
714346	708936	19621T	PARTICIPANT	\N	PRESENT	0
714347	708936	11109J	PARTICIPANT	\N	EXCUSE	0
714350	714163	19667J	PARTICIPANT	\N	PRESENT	0
714351	714163	19333N	PARTICIPANT	\N	PRESENT	0
714352	714163	19820Y	PARTICIPANT	\N	PRESENT	0
714353	714163	19826F	PARTICIPANT	\N	PRESENT	0
714354	714163	08060W	PARTICIPANT	\N	PRESENT	0
714355	714163	19685L	PARTICIPANT	\N	PRESENT	0
714356	714163	20024T	PARTICIPANT	\N	PRESENT	0
714357	714163	11065P	PARTICIPANT	\N	PRESENT	0
726175	725870	99004R	PARTICIPANT	\N	PRESENT	0
726176	725870	11040E	PARTICIPANT	\N	PRESENT	0
726177	725870	19758L	PARTICIPANT	\N	PRESENT	0
726178	725870	19760E	PARTICIPANT	\N	PRESENT	0
726179	725870	19503N	PARTICIPANT	\N	PRESENT	0
726180	725870	14257W	PARTICIPANT	\N	PRESENT	0
726218	725870	14237S	PARTICIPANT	\N	PRESENT	0
726182	725870	20082E	PARTICIPANT	\N	PRESENT	0
726183	725870	20036X	PARTICIPANT	\N	PRESENT	0
726184	725870	19651A	PARTICIPANT	\N	PRESENT	0
726185	725870	19637C	PARTICIPANT	\N	PRESENT	0
726186	725870	19782L	PARTICIPANT	\N	PRESENT	0
726187	725870	19681G	PARTICIPANT	\N	PRESENT	0
726188	725870	19387D	PARTICIPANT	\N	PRESENT	0
726189	725870	19479G	PARTICIPANT	\N	PRESENT	0
726190	725870	19745F	PARTICIPANT	\N	PRESENT	0
726191	725870	17229F	PARTICIPANT	\N	PRESENT	0
726192	725870	01024M	PARTICIPANT	\N	PRESENT	0
726193	725870	19826F	PARTICIPANT	\N	PRESENT	0
726194	725870	11065P	PARTICIPANT	\N	PRESENT	0
726195	725870	19383Y	PARTICIPANT	\N	PRESENT	0
726196	725870	11104D	PARTICIPANT	\N	PRESENT	0
726197	725870	20062A	PARTICIPANT	\N	PRESENT	0
726198	725870	20090E	PARTICIPANT	\N	PRESENT	0
726199	725870	01058X	PARTICIPANT	\N	PRESENT	0
726200	725870	19507S	PARTICIPANT	\N	PRESENT	0
726201	725870	20026V	PARTICIPANT	\N	PRESENT	0
726202	725870	19467C	PARTICIPANT	\N	PRESENT	0
726203	725870	20056C	PARTICIPANT	\N	PRESENT	0
726204	725870	20180F	PARTICIPANT	\N	PRESENT	0
726205	725870	14169X	PARTICIPANT	\N	PRESENT	0
726207	725870	14031R	PARTICIPANT	\N	PRESENT	0
726208	725870	20038A	PARTICIPANT	\N	PRESENT	0
726209	725870	20068G	PARTICIPANT	\N	PRESENT	0
726210	725870	20032T	PARTICIPANT	\N	PRESENT	0
726211	725870	14193X	PARTICIPANT	\N	PRESENT	0
726212	725870	14069U	PARTICIPANT	\N	PRESENT	0
726213	725870	20076G	PARTICIPANT	\N	PRESENT	0
726214	725870	20104S	PARTICIPANT	\N	PRESENT	0
726215	725870	19333N	PARTICIPANT	\N	PRESENT	0
726216	725870	19599P	PARTICIPANT	\N	PRESENT	0
726217	725870	19747H	PARTICIPANT	\N	PRESENT	0
726219	725870	14038Y	PARTICIPANT	\N	PRESENT	0
726220	725870	14219Q	PARTICIPANT	\N	PRESENT	0
726221	725870	20140W	PARTICIPANT	\N	PRESENT	0
726222	725870	19741B	PARTICIPANT	\N	PRESENT	0
726223	725870	11056N	PARTICIPANT	\N	PRESENT	0
726224	725870	20046A	PARTICIPANT	\N	PRESENT	0
726225	725870	20102Q	PARTICIPANT	\N	PRESENT	0
726226	725870	20020P	PARTICIPANT	\N	PRESENT	0
726227	725870	19553Y	PARTICIPANT	\N	PRESENT	0
726228	725870	20122U	PARTICIPANT	\N	PRESENT	0
726229	725870	20066E	PARTICIPANT	\N	PRESENT	0
726230	725870	11070L	PARTICIPANT	\N	PRESENT	0
726231	725870	97011G	PARTICIPANT	\N	PRESENT	0
726232	725870	19798U	PARTICIPANT	\N	PRESENT	0
726233	725870	19691J	PARTICIPANT	\N	PRESENT	0
726234	725870	19549D	PARTICIPANT	\N	PRESENT	0
726240	725870	20024T	PARTICIPANT	\N	PRESENT	0
726244	725870	11097X	PARTICIPANT	\N	PRESENT	0
726245	725870	14223L	PARTICIPANT	\N	PRESENT	0
726247	725870	20128B	PARTICIPANT	\N	PRESENT	0
726249	725870	19367Y	PARTICIPANT	\N	PRESENT	0
726252	725870	04092N	PARTICIPANT	\N	PRESENT	0
726253	725870	01025N	PARTICIPANT	\N	PRESENT	0
726254	725870	19349W	PARTICIPANT	\N	PRESENT	0
726255	725870	18083K	PARTICIPANT	\N	PRESENT	0
726256	725870	20136B	PARTICIPANT	\N	PRESENT	0
726257	725870	14211G	PARTICIPANT	\N	PRESENT	0
726258	725870	20172F	PARTICIPANT	\N	PRESENT	0
726259	725870	14123H	PARTICIPANT	\N	PRESENT	0
726260	725870	14073Q	PARTICIPANT	\N	PRESENT	0
726262	725870	14173T	PARTICIPANT	\N	PRESENT	0
726263	725870	19631V	PARTICIPANT	\N	PRESENT	0
726264	725870	18193Q	PARTICIPANT	\N	PRESENT	0
726265	725870	14147R	PARTICIPANT	\N	PRESENT	0
726266	725870	11074Q	PARTICIPANT	\N	PRESENT	0
726269	725870	14055N	PARTICIPANT	\N	PRESENT	0
726271	725870	04033B	PARTICIPANT	\N	PRESENT	0
726278	725870	08028W	PARTICIPANT	\N	PRESENT	0
726279	725870	14133K	PARTICIPANT	\N	PRESENT	0
726280	725870	20048C	PARTICIPANT	\N	PRESENT	0
726281	725870	14357A	PARTICIPANT	\N	PRESENT	0
726282	725870	14033T	PARTICIPANT	\N	PRESENT	0
726286	726283	20180F	PARTICIPANT	\N	PRESENT	0
726287	726283	14357A	PRESIDENT	0	PRESENT	0
726288	726283	20102Q	PARTICIPANT	\N	PRESENT	0
726289	726283	11053K	PARTICIPANT	\N	PRESENT	0
726290	726283	19782L	PARTICIPANT	\N	PRESENT	0
726291	726283	11097X	PARTICIPANT	\N	PRESENT	0
726344	726283	17229F	PARTICIPANT	\N	PRESENT	0
726346	725871	20116W	PARTICIPANT	\N	PRESENT	0
726347	725871	20036X	PARTICIPANT	\N	PRESENT	0
726348	725969	20086J	PARTICIPANT	\N	PRESENT	0
726349	725969	14331P	PARTICIPANT	\N	PRESENT	0
726350	725969	11048N	PARTICIPANT	\N	PRESENT	0
726351	725969	14189C	PARTICIPANT	\N	PRESENT	0
726352	725969	08034U	PARTICIPANT	\N	PRESENT	0
726353	725969	19545Y	PARTICIPANT	\N	PRESENT	0
726354	725969	01057W	PARTICIPANT	\N	PRESENT	0
726355	725969	19687N	PARTICIPANT	\N	PRESENT	0
726356	725969	20080C	PARTICIPANT	\N	PRESENT	0
726357	725969	11053K	PARTICIPANT	\N	PRESENT	0
726358	725969	11074Q	PARTICIPANT	\N	PRESENT	0
726359	725969	20044X	PARTICIPANT	\N	PRESENT	0
726360	725969	14225N	PARTICIPANT	\N	PRESENT	0
726361	725969	14173T	PARTICIPANT	\N	PRESENT	0
726362	725969	11040E	PARTICIPANT	\N	PRESENT	0
726363	725969	11012A	PARTICIPANT	\N	PRESENT	0
726364	725969	20252E	PARTICIPANT	\N	PRESENT	0
726365	725969	19349W	PARTICIPANT	\N	PRESENT	0
726366	725969	14121F	PARTICIPANT	\N	PRESENT	0
726367	725969	19741B	PARTICIPANT	\N	PRESENT	0
726368	725969	08010L	PARTICIPANT	\N	PRESENT	0
726369	725969	20116W	PARTICIPANT	\N	PRESENT	0
726370	725969	20914V	PARTICIPANT	\N	PRESENT	0
726371	725969	19762G	PARTICIPANT	\N	PRESENT	0
726372	725871	11040E	PARTICIPANT	\N	PRESENT	0
726373	725871	14147R	PARTICIPANT	\N	PRESENT	0
726374	725871	20086J	PARTICIPANT	\N	PRESENT	0
726375	725871	14173T	PARTICIPANT	\N	PRESENT	0
726376	725871	19479G	PARTICIPANT	\N	PRESENT	0
726377	725871	11048N	PARTICIPANT	\N	PRESENT	0
731659	730320	04033B	PARTICIPANT	\N	PRESENT	0
731660	730320	20098N	PARTICIPANT	\N	PRESENT	0
731661	730320	20132W	PARTICIPANT	\N	PRESENT	0
731662	730320	20048C	PARTICIPANT	\N	PRESENT	0
731663	730320	19719D	PARTICIPANT	\N	PRESENT	0
731664	730320	14030Q	PARTICIPANT	\N	PRESENT	0
726342	725871	14026U	PARTICIPANT	\N	PRESENT	0
726343	726283	19251M	PARTICIPANT	\N	EXCUSE	0
731665	730320	20058E	PARTICIPANT	\N	PRESENT	0
731666	730320	19735D	PARTICIPANT	\N	PRESENT	0
731667	730320	20980G	PARTICIPANT	\N	PRESENT	0
731668	730320	11043H	PARTICIPANT	\N	PRESENT	0
731669	730320	20084G	PARTICIPANT	\N	PRESENT	0
731670	730320	19057M	PARTICIPANT	\N	PRESENT	0
732003	730320	19651A	PARTICIPANT	\N	PRESENT	0
732004	730320	19693L	PARTICIPANT	\N	PRESENT	0
732006	730319	19693L	PARTICIPANT	\N	PRESENT	0
732008	730319	19651A	PARTICIPANT	\N	PRESENT	0
732017	730684	14147R	PARTICIPANT	\N	PRESENT	0
732152	732112	19399H	PARTICIPANT	\N	PRESENT	0
713377	708203	20054A	PARTICIPANT	\N	PRESENT	0
713378	708203	11090Q	PARTICIPANT	\N	PRESENT	0
713379	708203	19565D	PARTICIPANT	\N	PRESENT	0
713380	708203	11031D	PARTICIPANT	\N	PRESENT	0
713381	708203	20140W	PARTICIPANT	\N	PRESENT	0
713382	708203	19687N	PARTICIPANT	\N	PRESENT	0
713383	708203	20180F	PARTICIPANT	\N	PRESENT	0
713384	708203	19758L	PARTICIPANT	\N	PRESENT	0
713385	708203	19643A	PARTICIPANT	\N	PRESENT	0
713386	708203	20102Q	PARTICIPANT	\N	PRESENT	0
713387	708203	19693L	PARTICIPANT	\N	PRESENT	0
713388	708203	20046A	PARTICIPANT	\N	PRESENT	0
713389	708203	14151M	PARTICIPANT	\N	PRESENT	0
713390	708203	20112S	PARTICIPANT	\N	PRESENT	0
713391	708203	19593H	PARTICIPANT	\N	PRESENT	0
713392	708203	19591F	PARTICIPANT	\N	PRESENT	0
713393	708203	19866P	PARTICIPANT	\N	PRESENT	0
713394	708203	20076G	PARTICIPANT	\N	PRESENT	0
713395	708203	19719D	PARTICIPANT	\N	PRESENT	0
713396	708203	01058X	PARTICIPANT	\N	PRESENT	0
713397	708203	14207L	PARTICIPANT	\N	PRESENT	0
713398	708203	19681G	PARTICIPANT	\N	PRESENT	0
713399	708203	19711U	PARTICIPANT	\N	PRESENT	0
713400	708203	16685X	PARTICIPANT	\N	PRESENT	0
713401	708203	19369B	PARTICIPANT	\N	PRESENT	0
713402	708203	08010L	PARTICIPANT	\N	PRESENT	0
713403	708203	19713W	PARTICIPANT	\N	PRESENT	0
713404	708203	08069G	PARTICIPANT	\N	PRESENT	0
713405	708203	19543W	PARTICIPANT	\N	PRESENT	0
713406	708203	14255U	PARTICIPANT	\N	PRESENT	0
713407	708203	19709B	PARTICIPANT	\N	PRESENT	0
713408	708203	08018U	PARTICIPANT	\N	PRESENT	0
713409	708203	19705W	PARTICIPANT	\N	PRESENT	0
713410	708203	19467C	PARTICIPANT	\N	PRESENT	0
713411	708203	20110Q	PARTICIPANT	\N	PRESENT	0
713412	708203	20914V	PARTICIPANT	\N	PRESENT	0
713413	708203	20252E	PARTICIPANT	\N	PRESENT	0
713414	708203	04059M	PARTICIPANT	\N	PRESENT	0
713415	708203	19649G	PARTICIPANT	\N	PRESENT	0
713416	708203	20040T	PARTICIPANT	\N	PRESENT	0
713417	708203	07004J	PARTICIPANT	\N	PRESENT	0
713418	708203	19527W	PARTICIPANT	\N	PRESENT	0
713419	708203	14215L	PARTICIPANT	\N	PRESENT	0
713420	708203	11072N	PARTICIPANT	\N	PRESENT	0
713421	708203	14026U	PARTICIPANT	\N	PRESENT	0
713422	708203	19479G	PARTICIPANT	\N	PRESENT	0
713423	708203	19569H	PARTICIPANT	\N	PRESENT	0
713424	708203	19657G	PARTICIPANT	\N	PRESENT	0
713425	708203	14231L	PARTICIPANT	\N	PRESENT	0
713426	708203	20026V	PARTICIPANT	\N	PRESENT	0
713427	708203	19647E	PARTICIPANT	\N	PRESENT	0
713428	708203	20100N	PARTICIPANT	\N	PRESENT	0
713429	708203	20084G	PARTICIPANT	\N	PRESENT	0
713430	708203	11083R	PARTICIPANT	\N	PRESENT	0
713431	708203	19347U	PARTICIPANT	\N	PRESENT	0
713432	708203	20130U	PARTICIPANT	\N	PRESENT	0
713433	708203	20094J	PARTICIPANT	\N	PRESENT	0
713434	708203	19611R	PARTICIPANT	\N	PRESENT	0
713435	708203	11065P	PARTICIPANT	\N	PRESENT	0
713436	708203	95041E	PARTICIPANT	\N	PRESENT	0
713437	708203	95063L	PARTICIPANT	\N	PRESENT	0
713438	708203	20066E	PARTICIPANT	\N	PRESENT	0
713439	708203	19760E	PARTICIPANT	\N	PRESENT	0
713440	708203	11027H	PARTICIPANT	\N	PRESENT	0
713375	708203	01057W	PARTICIPANT	\N	PRESENT	0
713376	708203	19820Y	PARTICIPANT	\N	PRESENT	0
713441	708203	19697Q	PARTICIPANT	\N	PRESENT	0
713442	708203	19553Y	PARTICIPANT	\N	PRESENT	0
713443	708203	08009T	PARTICIPANT	\N	PRESENT	0
713444	708203	14211G	PARTICIPANT	\N	PRESENT	0
713445	708203	14251Q	PARTICIPANT	\N	PRESENT	0
713446	708203	20150Y	PARTICIPANT	\N	PRESENT	0
713447	708203	19749K	PARTICIPANT	\N	PRESENT	0
713448	708203	86034E	PARTICIPANT	\N	PRESENT	0
713449	708203	19766L	PARTICIPANT	\N	PRESENT	0
713450	708203	20126Y	PARTICIPANT	\N	PRESENT	0
713451	708203	11085T	PARTICIPANT	\N	PRESENT	0
713452	708203	11070L	PARTICIPANT	\N	PRESENT	0
713453	708203	04085P	PARTICIPANT	\N	PRESENT	0
715894	709156	97011G	PARTICIPANT	\N	PRESENT	0
715895	709156	14030Q	PARTICIPANT	\N	PRESENT	0
715896	709156	20098N	PARTICIPANT	\N	PRESENT	0
715924	709156	18083K	PARTICIPANT	\N	PRESENT	0
716586	716585	19768N	PARTICIPANT	\N	PRESENT	0
716587	716585	20034V	PARTICIPANT	\N	PRESENT	0
716590	716589	19695N	PARTICIPANT	\N	PRESENT	0
716591	716589	14187A	PARTICIPANT	\N	PRESENT	0
716592	716589	14033T	PARTICIPANT	\N	PRESENT	0
716593	716589	20018V	PARTICIPANT	\N	PRESENT	0
716594	716589	19575F	PARTICIPANT	\N	PRESENT	0
716596	716595	19695N	PARTICIPANT	\N	PRESENT	0
716597	716595	14187A	PARTICIPANT	\N	PRESENT	0
716598	716595	14033T	PARTICIPANT	\N	PRESENT	0
716599	716595	20018V	PARTICIPANT	\N	PRESENT	0
716601	716600	19695N	PARTICIPANT	\N	PRESENT	0
716602	716600	14187A	PARTICIPANT	\N	PRESENT	0
716603	716600	14033T	PARTICIPANT	\N	PRESENT	0
716604	716600	20018V	PARTICIPANT	\N	PRESENT	0
716606	716605	01057W	PARTICIPANT	\N	PRESENT	0
716608	716607	19741B	PARTICIPANT	\N	PRESENT	0
716612	716611	19741B	PARTICIPANT	\N	PRESENT	0
717202	704312	14189C	PARTICIPANT	\N	EXCUSE	0
717203	704312	20056C	PARTICIPANT	\N	EXCUSE	0
717204	704312	11031D	PARTICIPANT	\N	EXCUSE	0
717205	704312	20024T	PARTICIPANT	\N	EXCUSE	0
717206	704312	19866P	PARTICIPANT	\N	EXCUSE	0
717207	704312	20098N	PARTICIPANT	\N	EXCUSE	0
717233	717232	20074E	PARTICIPANT	\N	PRESENT	0
717234	717232	19749K	PARTICIPANT	\N	PRESENT	0
717236	717235	20074E	PARTICIPANT	\N	PRESENT	0
717559	715270	04047H	PRESIDENT	0	PRESENT	0
717560	715270	14215L	PRESIDENT	1	PRESENT	0
717561	715270	20074E	PARTICIPANT	\N	PRESENT	0
717562	715270	14111D	PARTICIPANT	\N	PRESENT	0
717563	715270	14231L	PARTICIPANT	\N	PRESENT	0
717564	715270	95063L	PARTICIPANT	\N	PRESENT	0
717565	715270	11072N	PARTICIPANT	\N	PRESENT	0
717566	715270	19725B	PARTICIPANT	\N	PRESENT	0
717567	715270	19489J	PARTICIPANT	\N	PRESENT	0
717568	715270	14147R	PARTICIPANT	\N	PRESENT	0
717569	715270	19729F	PARTICIPANT	\N	EXCUSE	0
717573	715270	01028R	PARTICIPANT	\N	PRESENT	0
717574	715270	11033F	PARTICIPANT	\N	PRESENT	0
717575	715270	14053L	PARTICIPANT	\N	PRESENT	0
717576	715270	14069U	PARTICIPANT	\N	PRESENT	0
717577	715270	04008A	PARTICIPANT	\N	PRESENT	0
717578	715270	19543W	PARTICIPANT	\N	PRESENT	0
717579	715270	11056N	PARTICIPANT	\N	PRESENT	0
717580	715270	20022R	PARTICIPANT	\N	PRESENT	0
717581	715270	14151M	PARTICIPANT	\N	PRESENT	0
717582	715270	20108W	PARTICIPANT	\N	PRESENT	0
717583	715270	14259Y	PARTICIPANT	\N	PRESENT	0
719847	719500	20044X	PARTICIPANT	\N	PRESENT	0
719849	719500	19569H	PARTICIPANT	\N	PRESENT	0
719850	719500	10015M	PARTICIPANT	\N	PRESENT	0
719851	719500	19866P	PARTICIPANT	\N	PRESENT	0
719852	719500	19741B	PARTICIPANT	\N	PRESENT	0
719853	719500	20084G	PARTICIPANT	\N	PRESENT	0
719854	719500	19631V	PARTICIPANT	\N	PRESENT	0
719857	719500	08010L	PARTICIPANT	\N	PRESENT	0
720264	720096	19719D	PARTICIPANT	\N	PRESENT	0
720265	720096	14231L	PARTICIPANT	\N	PRESENT	0
720266	720096	19611R	PARTICIPANT	\N	PRESENT	0
720267	720096	19735D	PARTICIPANT	\N	PRESENT	0
720268	720096	12028B	PARTICIPANT	\N	PRESENT	0
720269	720096	18083K	PARTICIPANT	\N	PRESENT	0
720270	720096	19367Y	PARTICIPANT	\N	PRESENT	0
720271	720096	14109K	PARTICIPANT	\N	PRESENT	0
720272	720096	04059M	PARTICIPANT	\N	PRESENT	0
720273	720096	08015R	PARTICIPANT	\N	PRESENT	0
720274	720096	20140W	PARTICIPANT	\N	PRESENT	0
720275	720096	20026V	PARTICIPANT	\N	PRESENT	0
720279	720096	14217N	PARTICIPANT	\N	PRESENT	0
720280	720096	08009T	PARTICIPANT	\N	PRESENT	0
720290	720096	11066Q	PARTICIPANT	\N	PRESENT	0
720292	720096	14042U	PARTICIPANT	\N	PRESENT	0
720293	720096	19758L	PARTICIPANT	\N	PRESENT	0
720294	720096	14329V	PARTICIPANT	\N	PRESENT	0
720295	720096	14219Q	PARTICIPANT	\N	PRESENT	0
720310	720096	14259Y	PARTICIPANT	\N	PRESENT	0
720313	720096	07004J	PARTICIPANT	\N	PRESENT	0
736743	735351	11067R	PARTICIPANT	\N	PRESENT	0
736744	735351	18193Q	PARTICIPANT	\N	PRESENT	0
736745	735351	14195A	PARTICIPANT	\N	PRESENT	0
736746	735351	19569H	PARTICIPANT	\N	PRESENT	0
736747	735351	19657G	PARTICIPANT	\N	PRESENT	0
736748	735351	19798U	PARTICIPANT	\N	PRESENT	0
736749	735351	20040T	PARTICIPANT	\N	PRESENT	0
736750	735351	19415P	PARTICIPANT	\N	PRESENT	0
736751	735351	10006L	PRESIDENT	0	PRESENT	0
736752	735351	19679N	PARTICIPANT	\N	PRESENT	0
736753	735351	19691J	PARTICIPANT	\N	PRESENT	0
736754	735351	14071N	PARTICIPANT	\N	PRESENT	0
736755	735351	14217N	PARTICIPANT	\N	PRESENT	0
736756	735351	14223L	PARTICIPANT	\N	PRESENT	0
736757	735351	04092N	PARTICIPANT	\N	PRESENT	0
736758	735351	14213J	PARTICIPANT	\N	PRESENT	0
736760	735351	19511N	PARTICIPANT	\N	PRESENT	0
736762	735351	11097X	PARTICIPANT	\N	PRESENT	0
736765	735351	14281W	PARTICIPANT	\N	PRESENT	0
736770	735351	19703U	PARTICIPANT	\N	PRESENT	0
736771	735351	04057K	PARTICIPANT	\N	PRESENT	0
736775	735351	19295A	PARTICIPANT	\N	EXCUSE	0
736776	735351	20248J	PARTICIPANT	\N	EXCUSE	0
736777	735351	19723Y	PARTICIPANT	\N	PRESENT	0
736778	735351	14042U	PARTICIPANT	\N	PRESENT	0
736779	735351	20130U	PARTICIPANT	\N	PRESENT	0
736788	735351	19713W	PARTICIPANT	\N	PRESENT	0
736789	735351	14026U	PARTICIPANT	\N	PRESENT	0
736790	735351	20090E	PARTICIPANT	\N	PRESENT	0
736794	735351	20066E	PARTICIPANT	\N	PRESENT	0
736806	735351	01034P	PARTICIPANT	\N	PRESENT	0
736807	735351	19663E	PARTICIPANT	\N	PRESENT	0
736863	735351	19760E	PARTICIPANT	\N	PRESENT	0
736864	735351	11031D	PARTICIPANT	\N	EXCUSE	0
736865	735351	17965H	PARTICIPANT	\N	PRESENT	0
737787	737734	19760E	PARTICIPANT	\N	PRESENT	0
737789	737734	14189C	PARTICIPANT	\N	PRESENT	0
737790	737734	19954N	PARTICIPANT	\N	PRESENT	0
737797	737734	10006L	PARTICIPANT	\N	PRESENT	0
737798	737734	14217N	PARTICIPANT	\N	PRESENT	0
737799	737734	14042U	PARTICIPANT	\N	PRESENT	0
737802	737734	19691J	PARTICIPANT	\N	PRESENT	0
737806	737734	20066E	PARTICIPANT	\N	PRESENT	0
737810	737734	19447X	PARTICIPANT	\N	PRESENT	0
737811	737734	14059S	PARTICIPANT	\N	PRESENT	0
737812	737734	19657G	PARTICIPANT	\N	PRESENT	0
737813	737734	14147R	PARTICIPANT	\N	PRESENT	0
737814	737734	11067R	PARTICIPANT	\N	PRESENT	0
737815	737734	14223L	PARTICIPANT	\N	PRESENT	0
737816	737734	14071N	PARTICIPANT	\N	PRESENT	0
737817	737734	14331P	PARTICIPANT	\N	PRESENT	0
737818	737734	19798U	PARTICIPANT	\N	PRESENT	0
737819	737734	19703U	PARTICIPANT	\N	PRESENT	0
737820	737734	20058E	PARTICIPANT	\N	PRESENT	0
737973	737972	14231L	PRESIDENT	0	PRESENT	0
737974	737972	14215L	PARTICIPANT	\N	PRESENT	0
737975	737972	20058E	PARTICIPANT	\N	EXCUSE	0
737979	737972	08010L	PARTICIPANT	\N	EXCUSE	0
737980	737972	19782L	PARTICIPANT	\N	EXCUSE	0
737981	737972	04045F	PARTICIPANT	\N	EXCUSE	0
737985	737972	20022R	PARTICIPANT	\N	PRESENT	0
737987	737972	20090E	PARTICIPANT	\N	EXCUSE	0
737988	737972	14217N	PARTICIPANT	\N	PRESENT	0
737989	737972	14187A	PARTICIPANT	\N	PRESENT	0
737991	737972	19565D	PARTICIPANT	\N	EXCUSE	0
737992	737972	19447X	PARTICIPANT	\N	PRESENT	0
737993	737972	19489J	PARTICIPANT	\N	EXCUSE	0
737995	737972	14071N	PARTICIPANT	\N	EXCUSE	0
738044	734147	20048C	PARTICIPANT	\N	PRESENT	0
738046	734147	20098N	PARTICIPANT	\N	PRESENT	0
738047	734147	19527W	PARTICIPANT	\N	PRESENT	0
738483	738387	19747H	PARTICIPANT	\N	PRESENT	0
738489	738292	19369B	PARTICIPANT	\N	EXCUSE	0
738490	738292	20024T	PARTICIPANT	\N	EXCUSE	0
738491	738292	20126Y	PARTICIPANT	\N	EXCUSE	0
738492	738292	04045F	PARTICIPANT	\N	EXCUSE	0
738842	738738	19703U	PARTICIPANT	\N	PRESENT	0
739078	735924	20016T	PARTICIPANT	\N	PRESENT	0
739079	735924	20124W	PARTICIPANT	\N	PRESENT	0
739080	735924	20026V	PARTICIPANT	\N	PRESENT	0
739081	735924	19593H	PARTICIPANT	\N	PRESENT	0
739082	735924	19527W	PARTICIPANT	\N	PRESENT	0
739083	735924	20132W	PARTICIPANT	\N	PRESENT	0
739084	735924	19643A	PARTICIPANT	\N	PRESENT	0
739085	735924	20134Y	PARTICIPANT	\N	PRESENT	0
739086	735924	14073Q	PARTICIPANT	\N	PRESENT	0
739087	735924	19651A	PARTICIPANT	\N	PRESENT	0
739088	735924	19611R	PRESIDENT	0	PRESENT	0
739089	735924	20138D	PARTICIPANT	\N	PRESENT	0
739090	735924	20142Y	PARTICIPANT	\N	PRESENT	0
739091	735924	20048C	PARTICIPANT	\N	PRESENT	0
739092	735924	19693L	PARTICIPANT	\N	PRESENT	0
739093	735924	19399H	PARTICIPANT	\N	PRESENT	0
739094	735924	20152B	PARTICIPANT	\N	PRESENT	0
739095	735924	20052X	PARTICIPANT	\N	PRESENT	0
739096	735924	19719D	PARTICIPANT	\N	PRESENT	0
739097	735924	20172F	PARTICIPANT	\N	PRESENT	0
739098	735924	14030Q	PARTICIPANT	\N	PRESENT	0
739099	735924	20058E	PARTICIPANT	\N	PRESENT	0
739100	735924	20056C	PARTICIPANT	\N	PRESENT	0
739101	735924	04059M	PARTICIPANT	\N	PRESENT	0
739102	735924	20264J	PARTICIPANT	\N	PRESENT	0
739103	735924	19057M	PARTICIPANT	\N	PRESENT	0
739104	735924	14123H	PARTICIPANT	\N	PRESENT	0
739105	735924	11043H	PARTICIPANT	\N	PRESENT	0
739106	735924	19758L	PARTICIPANT	\N	PRESENT	0
739107	735924	17589D	PARTICIPANT	\N	PRESENT	0
739108	735924	20084G	PARTICIPANT	\N	PRESENT	0
739109	735924	19621T	PARTICIPANT	\N	PRESENT	0
739110	738361	04071H	PARTICIPANT	\N	PRESENT	0
739111	737731	04092N	PARTICIPANT	\N	PRESENT	0
739112	738017	14179A	PARTICIPANT	\N	PRESENT	0
739113	737731	04057K	PARTICIPANT	\N	PRESENT	0
739114	735610	20018V	PARTICIPANT	\N	EXCUSE	0
739115	737731	17779H	PARTICIPANT	\N	PRESENT	0
739116	737731	04043D	PARTICIPANT	\N	PRESENT	0
739118	737731	11045K	PARTICIPANT	\N	PRESENT	0
739121	737731	19663E	PARTICIPANT	\N	PRESENT	0
739129	738362	04071H	PARTICIPANT	\N	PRESENT	0
739130	738362	11048N	PARTICIPANT	\N	PRESENT	0
739131	738362	19711U	PARTICIPANT	\N	PRESENT	0
739132	738362	01048V	PARTICIPANT	\N	PRESENT	0
739133	738362	08034U	PARTICIPANT	\N	PRESENT	0
739134	738362	01057W	PARTICIPANT	\N	PRESENT	0
739135	738362	20080C	PARTICIPANT	\N	PRESENT	0
739136	738362	11074Q	PARTICIPANT	\N	PRESENT	0
739137	738362	19667J	PARTICIPANT	\N	PRESENT	0
739138	738362	20044X	PARTICIPANT	\N	PRESENT	0
739139	738362	14225N	PRESIDENT	0	PRESENT	0
739140	738362	19671E	PARTICIPANT	\N	PRESENT	0
739141	738362	07029T	PARTICIPANT	\N	PRESENT	0
739142	738362	14083S	PARTICIPANT	\N	PRESENT	0
739143	738362	20252E	PARTICIPANT	\N	PRESENT	0
739144	738362	20070A	PARTICIPANT	\N	PRESENT	0
739145	738362	19349W	PARTICIPANT	\N	PRESENT	0
739146	738362	14121F	PARTICIPANT	\N	PRESENT	0
739147	738362	08010L	PARTICIPANT	\N	PRESENT	0
739148	738362	19741B	PARTICIPANT	\N	PRESENT	0
739149	738362	20914V	PARTICIPANT	\N	PRESENT	0
739150	738362	99004R	PARTICIPANT	\N	PRESENT	0
739151	738362	20126Y	PARTICIPANT	\N	PRESENT	0
739152	738362	19762G	PARTICIPANT	\N	PRESENT	0
739153	738362	20050V	PARTICIPANT	\N	EXCUSE	0
739203	737731	01034P	PARTICIPANT	\N	PRESENT	0
711435	711251	19251M	PARTICIPANT	\N	PRESENT	0
711436	711251	19575F	PARTICIPANT	\N	PRESENT	0
711437	711251	14083S	PARTICIPANT	\N	PRESENT	0
711438	711251	20054A	PARTICIPANT	\N	PRESENT	0
711439	711251	19762G	PARTICIPANT	\N	EXCUSE	0
711440	711251	14031R	PARTICIPANT	\N	EXCUSE	0
711441	711251	16685X	PARTICIPANT	\N	EXCUSE	0
711442	711251	08015R	PARTICIPANT	\N	EXCUSE	0
711443	711251	20126Y	PARTICIPANT	\N	EXCUSE	0
711444	711251	20048C	PARTICIPANT	\N	EXCUSE	0
711445	711251	08028W	PARTICIPANT	\N	EXCUSE	0
711446	711251	14195A	PARTICIPANT	\N	EXCUSE	0
711447	711251	14329V	PARTICIPANT	\N	EXCUSE	0
711448	711251	20060X	PARTICIPANT	\N	EXCUSE	0
711449	711251	19545Y	PARTICIPANT	\N	EXCUSE	0
711450	711251	14030Q	PARTICIPANT	\N	EXCUSE	0
711451	711251	08060W	PARTICIPANT	\N	EXCUSE	0
711623	711622	19826F	PARTICIPANT	\N	PRESENT	0
711624	711622	14205J	PARTICIPANT	\N	PRESENT	0
711625	711622	20054A	PARTICIPANT	\N	PRESENT	0
711626	711622	20076G	PARTICIPANT	\N	PRESENT	0
711628	711622	20026V	PARTICIPANT	\N	PRESENT	0
711630	711622	19723Y	PARTICIPANT	\N	PRESENT	0
711631	711622	19798U	PARTICIPANT	\N	PRESENT	0
711632	711622	20046A	PARTICIPANT	\N	PRESENT	0
711633	711622	20142Y	PARTICIPANT	\N	PRESENT	0
711634	711622	19721W	PARTICIPANT	\N	PRESENT	0
711636	711622	04045F	PARTICIPANT	\N	PRESENT	0
711637	711622	20090E	PARTICIPANT	\N	PRESENT	0
711638	711622	14033T	PARTICIPANT	\N	PRESENT	0
711639	711622	19782L	PARTICIPANT	\N	PRESENT	0
712109	709156	14331P	PARTICIPANT	\N	EXCUSE	0
712204	709156	19295A	PARTICIPANT	\N	EXCUSE	0
713835	713834	20074E	PARTICIPANT	\N	PRESENT	0
714358	714163	19525U	PARTICIPANT	\N	PRESENT	0
714359	714163	20032T	PARTICIPANT	\N	PRESENT	0
714360	714163	20038A	PARTICIPANT	\N	PRESENT	0
714361	714163	20046A	PARTICIPANT	\N	PRESENT	0
714362	714163	17229F	PARTICIPANT	\N	PRESENT	0
714363	714163	20068G	PARTICIPANT	\N	PRESENT	0
714364	714163	19701S	PARTICIPANT	\N	PRESENT	0
714365	714163	19387D	PARTICIPANT	\N	PRESENT	0
714366	714163	14221J	PARTICIPANT	\N	PRESENT	0
714367	714163	20102Q	PARTICIPANT	\N	PRESENT	0
714368	714163	19599P	PARTICIPANT	\N	PRESENT	0
714369	714163	20096L	PARTICIPANT	\N	PRESENT	0
714370	714163	14237S	PARTICIPANT	\N	PRESENT	0
714371	714163	18083K	PARTICIPANT	\N	PRESENT	0
714372	714163	20100N	PARTICIPANT	\N	PRESENT	0
714373	714163	05012A	PARTICIPANT	\N	PRESENT	0
714374	714163	20106U	PARTICIPANT	\N	PRESENT	0
714375	714163	19503N	PARTICIPANT	\N	PRESENT	0
714376	714163	17367Q	PARTICIPANT	\N	PRESENT	0
714377	714163	20120S	PARTICIPANT	\N	PRESENT	0
714378	714163	20122U	PARTICIPANT	\N	PRESENT	0
714379	714163	20136B	PARTICIPANT	\N	PRESENT	0
714380	714163	14031R	PARTICIPANT	\N	PRESENT	0
714381	714163	20140W	PARTICIPANT	\N	PRESENT	0
714382	714163	19251M	PARTICIPANT	\N	PRESENT	0
714383	714163	19739H	PARTICIPANT	\N	PRESENT	0
714384	714163	19745F	PARTICIPANT	\N	PRESENT	0
714388	702239	20096L	PARTICIPANT	\N	PRESENT	0
714389	714163	20080C	PARTICIPANT	\N	PRESENT	0
714391	714163	07029T	PARTICIPANT	\N	EXCUSE	0
714392	714163	19479G	PARTICIPANT	\N	EXCUSE	0
714393	714163	20050V	PARTICIPANT	\N	EXCUSE	0
714402	714163	19549D	PARTICIPANT	\N	PRESENT	0
714410	702239	20102Q	PARTICIPANT	\N	PRESENT	0
714411	702239	11065P	PARTICIPANT	\N	PRESENT	0
714412	714163	14225N	PRESIDENT	0	PRESENT	0
714449	713873	19768N	PARTICIPANT	\N	PRESENT	0
714450	713873	19515S	PARTICIPANT	\N	PRESENT	0
714451	713873	11077T	PARTICIPANT	\N	PRESENT	0
714452	713873	19782L	PARTICIPANT	\N	PRESENT	0
714453	713873	20092G	PARTICIPANT	\N	PRESENT	0
714454	713873	01043Q	PARTICIPANT	\N	PRESENT	0
714455	713873	14357A	PARTICIPANT	\N	PRESENT	0
714456	713873	19441R	PARTICIPANT	\N	PRESENT	0
714457	713873	19413M	PARTICIPANT	\N	PRESENT	0
714458	713873	20082E	PARTICIPANT	\N	PRESENT	0
714459	713873	20094J	PARTICIPANT	\N	PRESENT	0
714460	713873	19866P	PARTICIPANT	\N	PRESENT	0
714461	713873	04045F	PARTICIPANT	\N	PRESENT	0
714462	713873	20104S	PARTICIPANT	\N	PRESENT	0
714463	713873	19631V	PARTICIPANT	\N	PRESENT	0
714464	713873	11099A	PARTICIPANT	\N	PRESENT	0
714465	713873	19705W	PARTICIPANT	\N	PRESENT	0
714466	713873	19575F	PARTICIPANT	\N	PRESENT	0
714467	713873	19369B	PARTICIPANT	\N	PRESENT	0
714468	713873	08028W	PARTICIPANT	\N	PRESENT	0
714469	713873	19563B	PARTICIPANT	\N	PRESENT	0
714470	713873	20028X	PARTICIPANT	\N	PRESENT	0
714471	713873	14037X	PARTICIPANT	\N	PRESENT	0
714472	713873	14329V	PARTICIPANT	\N	PRESENT	0
714473	713873	20030R	PARTICIPANT	\N	PRESENT	0
714474	713873	14038Y	PARTICIPANT	\N	PRESENT	0
714475	713873	19467C	PARTICIPANT	\N	PRESENT	0
714476	713873	20034V	PARTICIPANT	\N	PRESENT	0
714477	713873	14187A	PARTICIPANT	\N	PRESENT	0
714478	713873	20144B	PARTICIPANT	\N	PRESENT	0
714479	713873	19695N	PARTICIPANT	\N	PRESENT	0
714480	713873	14033T	PARTICIPANT	\N	PRESENT	0
714481	713873	11090Q	PRESIDENT	0	PRESENT	0
714482	713873	01025N	PARTICIPANT	\N	PRESENT	0
714483	713873	20054A	PARTICIPANT	\N	PRESENT	0
714484	713873	14205J	PARTICIPANT	\N	PRESENT	0
714485	713873	20060X	PARTICIPANT	\N	PRESENT	0
714486	713873	20062A	PARTICIPANT	\N	PRESENT	0
714487	713873	19507S	PARTICIPANT	\N	PRESENT	0
714488	713873	20286Q	PARTICIPANT	\N	PRESENT	0
714489	713873	20298U	PARTICIPANT	\N	PRESENT	0
714490	713873	19747H	PARTICIPANT	\N	PRESENT	0
714491	713873	14207L	PARTICIPANT	\N	PRESENT	0
714492	713873	14257W	PARTICIPANT	\N	PRESENT	0
714493	713873	20018V	PARTICIPANT	\N	EXCUSE	0
714531	712588	19621T	PARTICIPANT	\N	PRESENT	0
714532	712588	19711U	PARTICIPANT	\N	PRESENT	0
714533	712588	04008A	PARTICIPANT	\N	PRESENT	0
714534	712588	08011M	PARTICIPANT	\N	PRESENT	0
714535	712588	19575F	PARTICIPANT	\N	PRESENT	0
714536	712588	01058X	PARTICIPANT	\N	PRESENT	0
714537	712588	99004R	PARTICIPANT	\N	PRESENT	0
714538	712588	19703U	PARTICIPANT	\N	PRESENT	0
714539	712588	14038Y	PARTICIPANT	\N	PRESENT	0
714540	712588	20086J	PARTICIPANT	\N	PRESENT	0
714541	712588	20044X	PARTICIPANT	\N	PRESENT	0
714542	712588	14173T	PARTICIPANT	\N	PRESENT	0
714543	712588	19679N	PARTICIPANT	\N	PRESENT	0
714544	712588	19507S	PARTICIPANT	\N	PRESENT	0
714545	712588	20038A	PARTICIPANT	\N	PRESENT	0
714546	712588	19467C	PARTICIPANT	\N	PRESENT	0
714547	712588	19673G	PARTICIPANT	\N	PRESENT	0
714548	712588	19766L	PARTICIPANT	\N	PRESENT	0
714549	712588	11031D	PARTICIPANT	\N	PRESENT	0
714550	712588	19687N	PARTICIPANT	\N	PRESENT	0
714551	712588	20096L	PARTICIPANT	\N	PRESENT	0
714552	712588	11056N	PARTICIPANT	\N	PRESENT	0
714553	712588	12041X	PARTICIPANT	\N	PRESENT	0
714554	712588	20034V	PARTICIPANT	\N	PRESENT	0
714555	712588	19565D	PARTICIPANT	\N	PRESENT	0
714556	712588	19741B	PARTICIPANT	\N	PRESENT	0
714557	712588	19709B	PARTICIPANT	\N	PRESENT	0
714558	712588	20098N	PARTICIPANT	\N	PRESENT	0
714559	712588	20180F	PARTICIPANT	\N	PRESENT	0
714560	712588	04085P	PARTICIPANT	\N	PRESENT	0
714561	712588	20026V	PARTICIPANT	\N	PRESENT	0
714562	712588	11077T	PARTICIPANT	\N	PRESENT	0
714563	712588	19593H	PARTICIPANT	\N	PRESENT	0
714564	712588	20980G	PARTICIPANT	\N	PRESENT	0
714565	712588	20046A	PARTICIPANT	\N	PRESENT	0
714566	712588	14033T	PARTICIPANT	\N	PRESENT	0
714567	712588	20112S	PARTICIPANT	\N	PRESENT	0
714568	712588	07029T	PARTICIPANT	\N	PRESENT	0
714569	712588	20266L	PARTICIPANT	\N	PRESENT	0
714570	712588	20092G	PARTICIPANT	\N	PRESENT	0
714571	712588	19657G	PARTICIPANT	\N	PRESENT	0
714572	712588	11099A	PARTICIPANT	\N	PRESENT	0
714573	712588	19347U	PARTICIPANT	\N	PRESENT	0
714574	712588	20100N	PARTICIPANT	\N	PRESENT	0
714575	712588	14069U	PARTICIPANT	\N	PRESENT	0
714576	712588	14191V	PARTICIPANT	\N	PRESENT	0
732155	732112	20142Y	PARTICIPANT	\N	PRESENT	0
732210	730491	20104S	PRESIDENT	1	PRESENT	0
732211	730491	11101A	PARTICIPANT	\N	PRESENT	0
732212	730491	19701S	PARTICIPANT	\N	PRESENT	0
732215	730491	20100N	PARTICIPANT	\N	PRESENT	0
732216	730491	20286Q	PARTICIPANT	\N	PRESENT	0
732220	730491	11083R	PARTICIPANT	\N	PRESENT	0
732222	730491	14033T	PARTICIPANT	\N	PRESENT	0
732223	730491	14026U	PARTICIPANT	\N	PRESENT	0
732226	730491	19333N	PARTICIPANT	\N	PRESENT	0
732228	730491	14073Q	PARTICIPANT	\N	PRESENT	0
732230	730491	12041X	PARTICIPANT	\N	PRESENT	0
732233	730491	19711U	PARTICIPANT	\N	PRESENT	0
732234	730491	11026G	PARTICIPANT	\N	PRESENT	0
732237	730491	19441R	PARTICIPANT	\N	PRESENT	0
732239	730491	14001X	PARTICIPANT	\N	PRESENT	0
732242	730491	04057K	PARTICIPANT	\N	PRESENT	0
732244	730491	14169X	PARTICIPANT	\N	PRESENT	0
732248	730491	14237S	PARTICIPANT	\N	PRESENT	0
732252	730491	14331P	PRESIDENT	0	PRESENT	0
732253	730491	10015M	PARTICIPANT	\N	PRESENT	0
732265	730491	14249W	PARTICIPANT	\N	PRESENT	0
732266	730491	20126Y	PARTICIPANT	\N	PRESENT	0
732268	730491	11041F	PARTICIPANT	\N	PRESENT	0
732277	730491	14133K	PARTICIPANT	\N	EXCUSE	0
732282	730491	14189C	PARTICIPANT	\N	EXCUSE	0
732284	730491	20094J	PARTICIPANT	\N	EXCUSE	0
732287	730491	14089Y	PARTICIPANT	\N	EXCUSE	0
732289	730491	17737W	PARTICIPANT	\N	EXCUSE	0
732290	730491	08018U	PARTICIPANT	\N	EXCUSE	0
732291	730491	04035D	PARTICIPANT	\N	EXCUSE	0
732294	730491	19725B	PARTICIPANT	\N	EXCUSE	0
732297	730491	19531S	PARTICIPANT	\N	EXCUSE	0
732301	730491	04070G	PARTICIPANT	\N	EXCUSE	0
732320	730568	14053L	PARTICIPANT	\N	PRESENT	0
732781	730875	05008E	PARTICIPANT	\N	EXCUSE	0
732782	730875	11043H	PARTICIPANT	\N	EXCUSE	0
732783	732628	05008E	PARTICIPANT	\N	EXCUSE	0
732784	732628	11043H	PARTICIPANT	\N	EXCUSE	0
732785	728445	05008E	PARTICIPANT	\N	EXCUSE	0
732786	728445	11043H	PARTICIPANT	\N	EXCUSE	0
732891	730770	14053L	PARTICIPANT	\N	PRESENT	0
732917	730771	14053L	PARTICIPANT	\N	PRESENT	0
732918	730771	19749K	PARTICIPANT	\N	PRESENT	0
732919	730771	19725B	PARTICIPANT	\N	PRESENT	0
732938	732937	19954N	PARTICIPANT	\N	PRESENT	0
733674	730875	20148F	PARTICIPANT	\N	PRESENT	0
733675	730875	12016W	PARTICIPANT	\N	PRESENT	0
733676	730875	19301E	PARTICIPANT	\N	PRESENT	0
733677	730875	11072N	PARTICIPANT	\N	PRESENT	0
733678	730875	14059S	PARTICIPANT	\N	PRESENT	0
733679	730875	19717B	PRESIDENT	0	PRESENT	0
733687	730875	19715Y	PARTICIPANT	\N	PRESENT	0
733760	733759	14053L	PARTICIPANT	\N	PRESENT	0
733761	733759	14089Y	PARTICIPANT	\N	PRESENT	0
733762	733759	11026G	PARTICIPANT	\N	PRESENT	0
733771	732776	10015M	PARTICIPANT	\N	PRESENT	0
733772	732777	04047H	PRESIDENT	0	PRESENT	0
733911	733637	20124W	PARTICIPANT	\N	PRESENT	0
733774	732777	14179A	PARTICIPANT	\N	PRESENT	0
733775	732777	14231L	PARTICIPANT	\N	PRESENT	0
733776	732777	14215L	PRESIDENT	1	PRESENT	0
733830	732777	19629C	PARTICIPANT	\N	PRESENT	0
733832	732777	19749K	PARTICIPANT	\N	PRESENT	0
733852	732777	14053L	PARTICIPANT	\N	PRESENT	0
733865	732777	11056N	PARTICIPANT	\N	PRESENT	0
733866	732777	01028R	PARTICIPANT	\N	PRESENT	0
733867	732777	19673G	PARTICIPANT	\N	PRESENT	0
733868	732777	14107H	PARTICIPANT	\N	PRESENT	0
733879	732777	19954N	PARTICIPANT	\N	PRESENT	0
733880	732777	20022R	PARTICIPANT	\N	PRESENT	0
733881	732777	20110Q	PARTICIPANT	\N	PRESENT	0
733882	732777	10015M	PARTICIPANT	\N	PRESENT	0
733883	732777	14151M	PARTICIPANT	\N	PRESENT	0
733884	732777	14089Y	PARTICIPANT	\N	PRESENT	0
733885	732777	11026G	PARTICIPANT	\N	PRESENT	0
733886	732777	19725B	PARTICIPANT	\N	PRESENT	0
733903	733902	05008E	PARTICIPANT	\N	PRESENT	0
733923	733922	11066Q	PARTICIPANT	\N	PRESENT	0
734013	732775	20022R	PARTICIPANT	\N	PRESENT	0
734014	732915	19479G	PARTICIPANT	\N	PRESENT	0
734015	732915	20126Y	PARTICIPANT	\N	PRESENT	0
734016	732915	08034U	PARTICIPANT	\N	PRESENT	0
734017	732915	99004R	PARTICIPANT	\N	PRESENT	0
734018	732915	04071H	PARTICIPANT	\N	PRESENT	0
734019	732915	20080C	PARTICIPANT	\N	PRESENT	0
734020	732915	11110B	PARTICIPANT	\N	PRESENT	0
734021	732915	19545Y	PARTICIPANT	\N	PRESENT	0
734022	732915	19349W	PARTICIPANT	\N	PRESENT	0
734023	732915	19335Q	PARTICIPANT	\N	PRESENT	0
734024	732915	20044X	PARTICIPANT	\N	PRESENT	0
734025	732915	19711U	PARTICIPANT	\N	PRESENT	0
734030	732915	19671E	PARTICIPANT	\N	PRESENT	0
734031	732915	19762G	PARTICIPANT	\N	PRESENT	0
734032	732775	14001X	PARTICIPANT	\N	PRESENT	0
734033	732775	19543W	PARTICIPANT	\N	PRESENT	0
734034	732775	19585H	PARTICIPANT	\N	PRESENT	0
734035	732775	05008E	PARTICIPANT	\N	PRESENT	0
734036	732775	14147R	PARTICIPANT	\N	PRESENT	0
734037	732775	20114U	PARTICIPANT	\N	PRESENT	0
734038	732775	10015M	PARTICIPANT	\N	PRESENT	0
734039	732775	04085P	PARTICIPANT	\N	PRESENT	0
734040	732775	14089Y	PARTICIPANT	\N	PRESENT	0
734041	732775	19725B	PARTICIPANT	\N	PRESENT	0
734042	732775	19749K	PARTICIPANT	\N	PRESENT	0
734043	732775	14021P	PARTICIPANT	\N	PRESENT	0
734044	732915	20070A	PARTICIPANT	\N	PRESENT	0
734126	732916	20086J	PARTICIPANT	\N	PRESENT	0
734127	732775	17737W	PARTICIPANT	\N	PRESENT	0
734128	732775	20110Q	PARTICIPANT	\N	PRESENT	0
734129	732775	19729F	PARTICIPANT	\N	PRESENT	0
734130	732775	20074E	PARTICIPANT	\N	EXCUSE	0
734131	732775	19489J	PARTICIPANT	\N	PRESENT	0
734132	732775	04047H	PARTICIPANT	\N	EXCUSE	0
734133	732916	19647E	PARTICIPANT	\N	PRESENT	0
734134	730866	20098N	PARTICIPANT	\N	PRESENT	0
734135	730866	19527W	PARTICIPANT	\N	PRESENT	0
734136	730866	14073Q	PARTICIPANT	\N	PRESENT	0
734137	730866	19651A	PARTICIPANT	\N	PRESENT	0
734138	730866	20048C	PARTICIPANT	\N	PRESENT	0
734139	730866	14030Q	PARTICIPANT	\N	PRESENT	0
734140	730866	20058E	PARTICIPANT	\N	PRESENT	0
734141	730866	20180F	PARTICIPANT	\N	PRESENT	0
734142	730866	04059M	PARTICIPANT	\N	PRESENT	0
734143	730866	19057M	PARTICIPANT	\N	PRESENT	0
734144	730866	20980G	PARTICIPANT	\N	PRESENT	0
734145	730866	19621T	PARTICIPANT	\N	PRESENT	0
734149	734148	14133K	PARTICIPANT	\N	PRESENT	0
734150	734148	12028B	PARTICIPANT	\N	PRESENT	0
734151	734148	14267Y	PARTICIPANT	\N	PRESENT	0
734152	734148	20042V	PARTICIPANT	\N	PRESENT	0
734163	730866	20172F	PARTICIPANT	\N	EXCUSE	0
734164	730866	11109J	PARTICIPANT	\N	EXCUSE	0
734165	730866	19399H	PARTICIPANT	\N	EXCUSE	0
734166	730866	20026V	PARTICIPANT	\N	EXCUSE	0
734167	732925	19399H	PARTICIPANT	\N	PRESENT	0
734168	732925	14229S	PARTICIPANT	\N	PRESENT	0
734169	732925	19643A	PARTICIPANT	\N	PRESENT	0
734170	732927	19399H	PARTICIPANT	\N	PRESENT	0
734171	732927	14229S	PARTICIPANT	\N	PRESENT	0
734173	732926	19399H	PARTICIPANT	\N	PRESENT	0
734174	732649	20248J	PARTICIPANT	\N	PRESENT	0
734177	734176	04043D	PARTICIPANT	\N	PRESENT	0
734178	734176	08045X	PARTICIPANT	\N	PRESENT	1
734179	734175	04043D	PARTICIPANT	\N	PRESENT	0
734180	732866	19383Y	PARTICIPANT	\N	PRESENT	0
734181	732866	19768N	PARTICIPANT	\N	PRESENT	0
734182	732866	20088L	PARTICIPANT	\N	PRESENT	0
734183	732866	19515S	PARTICIPANT	\N	PRESENT	0
734184	732866	19782L	PARTICIPANT	\N	PRESENT	0
734185	732866	20092G	PARTICIPANT	\N	PRESENT	0
734186	732866	11077T	PARTICIPANT	\N	PRESENT	0
734187	732866	01043Q	PARTICIPANT	\N	PRESENT	0
734188	732866	14357A	PARTICIPANT	\N	PRESENT	0
734189	732866	20078J	PARTICIPANT	\N	PRESENT	0
734190	732866	19413M	PARTICIPANT	\N	PRESENT	0
734191	732866	20094J	PARTICIPANT	\N	PRESENT	0
734192	732866	04045F	PARTICIPANT	\N	PRESENT	0
734193	732866	20104S	PARTICIPANT	\N	PRESENT	0
734194	732866	11099A	PARTICIPANT	\N	PRESENT	0
734195	732866	19705W	PARTICIPANT	\N	PRESENT	0
714194	713465	20090E	PARTICIPANT	\N	PRESENT	0
714196	713465	19691J	PARTICIPANT	\N	PRESENT	0
714387	714385	14123H	PARTICIPANT	\N	PRESENT	0
714390	714385	19533U	PARTICIPANT	\N	PRESENT	0
714394	714386	14123H	PARTICIPANT	\N	PRESENT	0
714395	714386	19533U	PARTICIPANT	\N	PRESENT	0
714397	714396	04059M	PARTICIPANT	\N	PRESENT	0
714398	714396	14073Q	PARTICIPANT	\N	PRESENT	0
714399	714396	19611R	PARTICIPANT	\N	PRESENT	0
714400	714396	19593H	PARTICIPANT	\N	PRESENT	0
714401	714396	08012N	PARTICIPANT	\N	PRESENT	0
717662	704312	20080C	PARTICIPANT	\N	EXCUSE	0
720315	720096	11115U	PARTICIPANT	\N	PRESENT	0
720316	720096	01062T	PARTICIPANT	\N	PRESENT	0
720317	720096	20100N	PARTICIPANT	\N	PRESENT	0
720318	720096	01025N	PARTICIPANT	\N	PRESENT	0
720319	720096	20024T	PARTICIPANT	\N	PRESENT	0
720320	720096	20032T	PARTICIPANT	\N	PRESENT	0
720321	720096	14147R	PARTICIPANT	\N	PRESENT	0
720322	720096	10015M	PARTICIPANT	\N	PRESENT	0
720323	720096	20136B	PARTICIPANT	\N	PRESENT	0
720324	720096	14221J	PARTICIPANT	\N	PRESENT	0
720325	720096	01060R	PARTICIPANT	\N	PRESENT	0
720326	720096	20138D	PARTICIPANT	\N	PRESENT	0
720327	720096	14189C	PARTICIPANT	\N	PRESENT	0
720328	720096	08060W	PARTICIPANT	\N	PRESENT	0
720329	720096	19515S	PARTICIPANT	\N	PRESENT	0
720330	720096	14073Q	PARTICIPANT	\N	PRESENT	0
720331	720096	19782L	PARTICIPANT	\N	PRESENT	0
720332	720096	20092G	PARTICIPANT	\N	PRESENT	0
720333	720096	14107H	PARTICIPANT	\N	PRESENT	0
720334	720096	20082E	PARTICIPANT	\N	PRESENT	0
720335	720096	19531S	PARTICIPANT	\N	PRESENT	0
720336	720096	14001X	PARTICIPANT	\N	PRESENT	0
720337	720096	19768N	PARTICIPANT	\N	PRESENT	0
720342	720096	07033P	PARTICIPANT	\N	PRESENT	0
720343	720096	20044X	PARTICIPANT	\N	PRESENT	0
720344	720096	07029T	PARTICIPANT	\N	PRESENT	0
720345	720096	19741B	PARTICIPANT	\N	PRESENT	0
720346	720096	14033T	PARTICIPANT	\N	PRESENT	0
720347	720096	20030R	PARTICIPANT	\N	PRESENT	0
720368	701182	19820Y	PARTICIPANT	\N	PRESENT	0
720369	701182	20054A	PARTICIPANT	\N	PRESENT	0
720370	701182	19723Y	PARTICIPANT	\N	PRESENT	0
720371	701182	20026V	PARTICIPANT	\N	PRESENT	0
720354	701182	14205J	PARTICIPANT	\N	PRESENT	0
720355	701182	19725B	PARTICIPANT	\N	PRESENT	0
720356	701182	19798U	PARTICIPANT	\N	PRESENT	0
720357	701182	20074E	PARTICIPANT	\N	PRESENT	0
720358	701182	20076G	PRESIDENT	0	PRESENT	0
720359	701182	20140W	PARTICIPANT	\N	PRESENT	0
720360	701182	20142Y	PARTICIPANT	\N	PRESENT	0
720361	701182	20114U	PARTICIPANT	\N	PRESENT	0
720362	701182	19826F	PARTICIPANT	\N	PRESENT	0
720363	701182	20046A	PARTICIPANT	\N	PRESENT	0
720364	701182	14033T	PARTICIPANT	\N	PRESENT	0
720365	701182	14173T	PARTICIPANT	\N	PRESENT	0
720366	701182	20248J	PARTICIPANT	\N	PRESENT	0
720372	701182	20072C	PARTICIPANT	\N	PRESENT	0
720373	701182	19503N	PARTICIPANT	\N	PRESENT	0
720375	701182	19782L	PARTICIPANT	\N	PRESENT	0
720376	701182	19719D	PARTICIPANT	\N	PRESENT	0
720378	720367	14331P	PARTICIPANT	\N	PRESENT	0
720379	720367	11048N	PARTICIPANT	\N	PRESENT	0
720380	720367	20252E	PARTICIPANT	\N	PRESENT	0
720381	720367	19741B	PARTICIPANT	\N	PRESENT	0
720382	720367	20116W	PARTICIPANT	\N	PRESENT	0
720383	720367	14225N	PRESIDENT	0	PRESENT	0
720384	720367	20050V	PARTICIPANT	\N	EXCUSE	0
720385	720367	11074Q	PARTICIPANT	\N	PRESENT	0
720386	720367	19687N	PARTICIPANT	\N	PRESENT	0
720387	720367	01057W	PARTICIPANT	\N	PRESENT	0
720388	720367	07029T	PARTICIPANT	\N	PRESENT	0
720389	720367	19667J	PARTICIPANT	\N	PRESENT	0
720392	720367	20126Y	PARTICIPANT	\N	PRESENT	0
720393	720367	19479G	PARTICIPANT	\N	PRESENT	0
720394	720095	95063L	PARTICIPANT	\N	PRESENT	0
720395	720367	19647E	PARTICIPANT	\N	PRESENT	0
720396	720367	19531S	PARTICIPANT	\N	PRESENT	0
720397	720367	08011M	PARTICIPANT	\N	PRESENT	0
720398	720367	20044X	PARTICIPANT	\N	PRESENT	0
720399	720367	14121F	PARTICIPANT	\N	PRESENT	0
720400	720367	99004R	PARTICIPANT	\N	PRESENT	0
722370	719776	19717B	PARTICIPANT	\N	PRESENT	1
722372	719776	14059S	PRESIDENT	0	PRESENT	0
722375	719776	20148F	PARTICIPANT	\N	PRESENT	0
722377	719776	20146D	PARTICIPANT	\N	PRESENT	0
722379	719776	19319Q	PARTICIPANT	\N	PRESENT	0
722382	719776	11072N	PARTICIPANT	\N	PRESENT	0
722405	720193	20104S	PRESIDENT	0	PRESENT	0
722406	720193	20100N	PARTICIPANT	\N	PRESENT	0
722407	720193	11083R	PARTICIPANT	\N	PRESENT	0
722408	720193	14097Y	PARTICIPANT	\N	PRESENT	0
722409	720193	19441R	PARTICIPANT	\N	PRESENT	0
722410	720193	11026G	PARTICIPANT	\N	PRESENT	0
722411	720193	14001X	PARTICIPANT	\N	PRESENT	0
722412	720193	10015M	PARTICIPANT	\N	PRESENT	0
722413	720193	14331P	PARTICIPANT	\N	EXCUSE	0
722414	720193	04057K	PARTICIPANT	\N	PRESENT	0
722766	722765	11053K	PARTICIPANT	\N	PRESENT	0
722767	722765	05008E	PARTICIPANT	\N	PRESENT	0
723676	723232	08034U	PARTICIPANT	\N	PRESENT	0
723677	723660	19593H	PARTICIPANT	\N	PRESENT	0
723678	723660	20132W	PARTICIPANT	\N	PRESENT	0
723679	723660	19699S	PARTICIPANT	\N	PRESENT	0
723680	723660	19533U	PARTICIPANT	\N	PRESENT	0
723681	723660	14073Q	PARTICIPANT	\N	PRESENT	0
723682	723660	19611R	PRESIDENT	0	PRESENT	0
723683	723660	19399H	PARTICIPANT	\N	PRESENT	0
723684	723660	14229S	PARTICIPANT	\N	PRESENT	0
723685	723660	20172F	PARTICIPANT	\N	PRESENT	0
723686	723660	20056C	PARTICIPANT	\N	PRESENT	0
723687	723660	20180F	PARTICIPANT	\N	PRESENT	0
723688	723660	04059M	PARTICIPANT	\N	PRESENT	0
723689	723660	20112S	PARTICIPANT	\N	PRESENT	0
723690	723660	11104D	PARTICIPANT	\N	PRESENT	0
723691	723660	11043H	PARTICIPANT	\N	PRESENT	0
723692	723660	20980G	PARTICIPANT	\N	PRESENT	0
723693	723660	20124W	PARTICIPANT	\N	PRESENT	0
723694	723660	19758L	PARTICIPANT	\N	PRESENT	0
723695	723660	20026V	PARTICIPANT	\N	PRESENT	0
723696	723660	19621T	PARTICIPANT	\N	PRESENT	0
723697	723660	20084G	PARTICIPANT	\N	PRESENT	0
723698	723660	19573D	PARTICIPANT	\N	PRESENT	0
723699	723232	20036X	PARTICIPANT	\N	PRESENT	0
723700	723232	19711U	PARTICIPANT	\N	PRESENT	0
723701	723232	20126Y	PARTICIPANT	\N	PRESENT	0
723702	723660	20048C	PARTICIPANT	\N	PRESENT	0
723703	723660	14030Q	PARTICIPANT	\N	PRESENT	0
723711	723232	11053K	PARTICIPANT	\N	PRESENT	0
723726	723232	07029T	PARTICIPANT	\N	PRESENT	0
723727	723232	19762G	PARTICIPANT	\N	PRESENT	0
723730	723660	04070G	PARTICIPANT	\N	PRESENT	0
723731	723660	14123H	PARTICIPANT	\N	PRESENT	0
723732	722416	19954N	PARTICIPANT	\N	PRESENT	0
723733	722416	95063L	PARTICIPANT	\N	PRESENT	0
723734	722416	14151M	PARTICIPANT	\N	PRESENT	0
723735	722416	19301E	PARTICIPANT	\N	PRESENT	0
723736	722416	14215L	PRESIDENT	0	PRESENT	0
723737	722416	20022R	PARTICIPANT	\N	PRESENT	0
723738	722416	05008E	PARTICIPANT	\N	PRESENT	0
723740	723660	20098N	PARTICIPANT	\N	PRESENT	0
723741	723232	20914V	PARTICIPANT	\N	PRESENT	0
723750	723233	19647E	PARTICIPANT	\N	PRESENT	0
723751	723233	20036X	PARTICIPANT	\N	PRESENT	0
723752	723233	20070A	PARTICIPANT	\N	PRESENT	0
723753	723233	19687N	PARTICIPANT	\N	PRESENT	0
723754	723233	20080C	PARTICIPANT	\N	PRESENT	0
723755	723233	20914V	PARTICIPANT	\N	PRESENT	0
723756	723233	14121F	PARTICIPANT	\N	PRESENT	0
723757	723233	20116W	PARTICIPANT	\N	PRESENT	0
723758	723233	11074Q	PARTICIPANT	\N	PRESENT	0
723759	723233	19741B	PARTICIPANT	\N	PRESENT	0
723760	723631	12041X	PARTICIPANT	\N	PRESENT	0
723761	723631	95041E	PARTICIPANT	\N	PRESENT	0
723762	723631	14133K	PARTICIPANT	\N	PRESENT	0
723763	723631	19565D	PARTICIPANT	\N	PRESENT	0
723764	723631	20072C	PARTICIPANT	\N	PRESENT	0
723765	723631	20042V	PARTICIPANT	\N	PRESENT	0
723766	723631	01058X	PARTICIPANT	\N	PRESENT	0
723767	723631	11027H	PARTICIPANT	\N	PRESENT	0
741904	740308	14179A	PARTICIPANT	\N	PRESENT	0
741905	740308	11045K	PARTICIPANT	\N	PRESENT	0
741906	740308	20094J	PARTICIPANT	\N	PRESENT	0
741908	741907	14179A	PARTICIPANT	\N	PRESENT	0
741909	741907	11045K	PARTICIPANT	\N	PRESENT	0
748065	748064	08018U	PARTICIPANT	\N	PRESENT	0
748066	748064	20114U	PARTICIPANT	\N	PRESENT	0
748128	744519	14073Q	PARTICIPANT	\N	EXCUSE	0
748129	744519	20142Y	PARTICIPANT	\N	EXCUSE	0
749521	748445	19581D	PARTICIPANT	\N	PRESENT	0
749758	748445	04047H	PRESIDENT	0	PRESENT	0
749764	748445	14151M	PARTICIPANT	\N	PRESENT	0
750893	750892	14033T	PARTICIPANT	\N	PRESENT	0
749766	748445	19749K	PARTICIPANT	\N	PRESENT	0
749767	748445	14069U	PARTICIPANT	\N	PRESENT	0
749771	748445	14053L	PARTICIPANT	\N	PRESENT	0
750890	750888	14205J	PARTICIPANT	\N	PRESENT	0
750894	750892	14205J	PARTICIPANT	\N	PRESENT	0
750918	750910	14033T	PARTICIPANT	\N	PRESENT	0
750920	750910	14205J	PARTICIPANT	\N	PRESENT	0
750927	750926	14033T	PARTICIPANT	\N	PRESENT	0
750928	750926	14205J	PARTICIPANT	\N	PRESENT	0
751987	751986	14207L	PARTICIPANT	\N	PRESENT	0
751988	751986	19467C	PARTICIPANT	\N	PRESENT	0
751989	751986	01024M	PARTICIPANT	\N	PRESENT	0
751990	751986	01025N	PARTICIPANT	\N	PRESENT	0
751991	751986	20128B	PARTICIPANT	\N	PRESENT	0
751992	751986	19723Y	PARTICIPANT	\N	PRESENT	0
751993	751986	08015R	PARTICIPANT	\N	PRESENT	0
751994	751986	04092N	PARTICIPANT	\N	PRESENT	0
751995	751986	19745F	PARTICIPANT	\N	PRESENT	0
751996	751986	11097X	PARTICIPANT	\N	PRESENT	0
751998	751997	86034E	PARTICIPANT	\N	PRESENT	0
751999	751997	04085P	PARTICIPANT	\N	PRESENT	0
752000	751997	04047H	PARTICIPANT	\N	PRESENT	0
752001	751997	04042C	PARTICIPANT	\N	PRESENT	0
752002	751997	10006L	PARTICIPANT	\N	PRESENT	0
752003	751997	14042U	PARTICIPANT	\N	PRESENT	0
752004	751997	19347U	PARTICIPANT	\N	PRESENT	0
752005	751997	11048N	PARTICIPANT	\N	PRESENT	0
752006	751997	14021P	PARTICIPANT	\N	PRESENT	0
752007	751997	99004R	PARTICIPANT	\N	PRESENT	0
752008	751997	14219Q	PARTICIPANT	\N	PRESENT	0
752009	751997	11085T	PARTICIPANT	\N	PRESENT	0
752010	751997	04057K	PARTICIPANT	\N	PRESENT	0
752011	751997	08061X	PARTICIPANT	\N	PRESENT	0
752012	751997	11090Q	PARTICIPANT	\N	PRESENT	0
752013	751997	14331P	PARTICIPANT	\N	PRESENT	0
752014	751997	14225N	PARTICIPANT	\N	PRESENT	0
752015	751997	11012A	PARTICIPANT	\N	PRESENT	0
752016	751997	04033B	PARTICIPANT	\N	PRESENT	0
752017	751997	95063L	PARTICIPANT	\N	PRESENT	0
752018	751997	01028R	PARTICIPANT	\N	PRESENT	0
752217	752202	14215L	PARTICIPANT	\N	PRESENT	0
752218	752202	14231L	PARTICIPANT	\N	PRESENT	0
752220	752219	14215L	PARTICIPANT	\N	PRESENT	0
757851	757768	19551W	PARTICIPANT	\N	PRESENT	0
757852	757768	20100N	PARTICIPANT	\N	PRESENT	0
757853	757768	21084L	PARTICIPANT	\N	PRESENT	0
757854	757768	20136B	PARTICIPANT	\N	PRESENT	0
757855	757768	15197G	PARTICIPANT	\N	PRESENT	0
757856	757768	14031R	PARTICIPANT	\N	PRESENT	0
757857	757768	11053K	PARTICIPANT	\N	PRESENT	0
757858	757768	14219Q	PRESIDENT	0	PRESENT	0
757859	757768	19826F	PARTICIPANT	\N	PRESENT	0
757860	757768	21051B	PARTICIPANT	\N	PRESENT	0
757995	757790	07029T	PARTICIPANT	\N	PRESENT	0
757997	757790	20104S	PARTICIPANT	\N	PRESENT	0
757996	757790	14071N	PARTICIPANT	\N	PRESENT	0
757998	757790	14031R	PARTICIPANT	\N	PRESENT	0
757999	757790	20076G	PARTICIPANT	\N	PRESENT	0
758000	757790	19693L	PARTICIPANT	\N	PRESENT	0
758001	757790	21076L	PARTICIPANT	\N	PRESENT	0
758002	757790	21092L	PARTICIPANT	\N	PRESENT	0
758003	757790	19347U	PARTICIPANT	\N	PRESENT	0
758004	757790	20100N	PARTICIPANT	\N	PRESENT	0
758005	757790	21079P	PARTICIPANT	\N	PRESENT	0
758006	757790	17965H	PARTICIPANT	\N	PRESENT	0
758007	757790	19551W	PARTICIPANT	\N	PRESENT	0
758008	757790	19820Y	PARTICIPANT	\N	PRESENT	0
758009	757790	21051B	PARTICIPANT	\N	PRESENT	0
758010	757790	19553Y	PARTICIPANT	\N	PRESENT	0
758011	757790	11053K	PARTICIPANT	\N	PRESENT	0
758012	757790	19251M	PARTICIPANT	\N	PRESENT	0
758013	757790	11056N	PARTICIPANT	\N	PRESENT	0
758014	757790	20046A	PARTICIPANT	\N	PRESENT	0
758015	757790	21084L	PARTICIPANT	\N	PRESENT	0
758016	757790	21088Q	PARTICIPANT	\N	PRESENT	0
758017	757790	19695N	PARTICIPANT	\N	PRESENT	0
758018	757790	19687N	PARTICIPANT	\N	PRESENT	0
758019	757790	20102Q	PARTICIPANT	\N	PRESENT	0
758020	757790	20136B	PARTICIPANT	\N	PRESENT	0
758021	757790	14219Q	PARTICIPANT	\N	PRESENT	0
758022	757790	19619A	PARTICIPANT	\N	PRESENT	0
758023	757790	15197G	PARTICIPANT	\N	PRESENT	0
758024	757790	21069M	PARTICIPANT	\N	PRESENT	0
758025	757790	21085M	PARTICIPANT	\N	PRESENT	0
758026	757790	11090Q	PARTICIPANT	\N	PRESENT	0
758027	757790	21090J	PARTICIPANT	\N	PRESENT	0
758028	757790	20090E	PARTICIPANT	\N	PRESENT	0
758029	757790	19711U	PARTICIPANT	\N	PRESENT	0
758030	757790	20120S	PARTICIPANT	\N	PRESENT	0
758031	757790	20106U	PARTICIPANT	\N	PRESENT	0
758032	757790	14215L	PARTICIPANT	\N	PRESENT	0
758073	757793	21051B	PARTICIPANT	\N	PRESENT	0
758074	757793	19551W	PARTICIPANT	\N	PRESENT	0
758075	757793	14031R	PARTICIPANT	\N	PRESENT	0
758076	757793	21076L	PARTICIPANT	\N	PRESENT	0
758077	757793	19111A	PARTICIPANT	\N	PRESENT	0
758078	757793	20100N	PARTICIPANT	\N	PRESENT	0
758079	757793	21084L	PARTICIPANT	\N	PRESENT	0
758080	757793	19553Y	PARTICIPANT	\N	PRESENT	0
758081	757793	20106U	PARTICIPANT	\N	PRESENT	0
758082	757793	99004R	PARTICIPANT	\N	PRESENT	0
758083	757793	21085M	PARTICIPANT	\N	PRESENT	0
758084	757793	20136B	PARTICIPANT	\N	PRESENT	0
758085	757793	14219Q	PARTICIPANT	\N	PRESENT	0
758086	757793	21079P	PARTICIPANT	\N	PRESENT	0
758087	757793	19820Y	PARTICIPANT	\N	PRESENT	0
758088	757793	20046A	PARTICIPANT	\N	PRESENT	0
758089	757793	19693L	PARTICIPANT	\N	PRESENT	0
758090	757793	19687N	PARTICIPANT	\N	PRESENT	0
758091	757793	19695N	PARTICIPANT	\N	PRESENT	0
758092	757793	20102Q	PARTICIPANT	\N	PRESENT	0
758093	757793	19629C	PARTICIPANT	\N	PRESENT	0
758094	757793	21090J	PARTICIPANT	\N	PRESENT	0
758095	757793	20120S	PARTICIPANT	\N	PRESENT	0
758096	757793	19711U	PARTICIPANT	\N	PRESENT	0
758097	757793	21056G	PARTICIPANT	\N	PRESENT	0
758098	757793	21091K	PARTICIPANT	\N	PRESENT	0
758099	757793	14021P	PARTICIPANT	\N	PRESENT	0
758102	757793	11053K	PARTICIPANT	\N	PRESENT	0
758113	757793	21082J	PARTICIPANT	\N	PRESENT	0
758114	757793	21088Q	PARTICIPANT	\N	PRESENT	0
758115	757793	07029T	PARTICIPANT	\N	PRESENT	0
758116	757793	21092L	PARTICIPANT	\N	PRESENT	0
758117	757793	14069U	PARTICIPANT	\N	PRESENT	0
758118	757793	20076G	PARTICIPANT	\N	PRESENT	0
758119	757793	20058E	PARTICIPANT	\N	PRESENT	0
758120	757793	11056N	PARTICIPANT	\N	PRESENT	0
760194	760193	20124W	PARTICIPANT	\N	PRESENT	0
760195	760193	19593H	PARTICIPANT	\N	PRESENT	0
758071	757793	14259Y	PARTICIPANT	\N	PRESENT	0
758072	757793	15197G	PARTICIPANT	\N	PRESENT	0
760208	760199	21089R	PARTICIPANT	\N	PRESENT	0
760209	760199	21063F	PARTICIPANT	\N	PRESENT	0
760210	760199	19057M	PARTICIPANT	\N	PRESENT	0
760211	760199	18395Y	PARTICIPANT	\N	PRESENT	0
760212	760199	19693L	PARTICIPANT	\N	PRESENT	0
760213	760199	20124W	PARTICIPANT	\N	PRESENT	0
760214	760199	20264J	PARTICIPANT	\N	PRESENT	0
760215	760199	21091K	PARTICIPANT	\N	PRESENT	0
760216	760199	21074J	PARTICIPANT	\N	PRESENT	0
760217	760199	20132W	PARTICIPANT	\N	PRESENT	0
760218	760199	20172F	PARTICIPANT	\N	PRESENT	0
760219	760199	21032X	PARTICIPANT	\N	PRESENT	0
760220	760199	20180F	PARTICIPANT	\N	PRESENT	0
760221	760199	20048C	PARTICIPANT	\N	PRESENT	0
760222	760199	14123H	PARTICIPANT	\N	PRESENT	0
760223	760199	20056C	PARTICIPANT	\N	PRESENT	0
760224	760199	14021P	PARTICIPANT	\N	PRESENT	0
750909	750895	19685L	PARTICIPANT	\N	PRESENT	0
750912	750895	20066E	PARTICIPANT	\N	PRESENT	0
750913	750895	11099A	PARTICIPANT	\N	PRESENT	0
750914	750895	16685X	PARTICIPANT	\N	PRESENT	0
750915	750895	14205J	PARTICIPANT	\N	PRESENT	0
750916	750895	14059S	PARTICIPANT	\N	PRESENT	0
750917	750895	20018V	PARTICIPANT	\N	PRESENT	0
750919	750895	14257W	PARTICIPANT	\N	PRESENT	0
750921	750895	20082E	PARTICIPANT	\N	PRESENT	0
750922	750895	11097X	PARTICIPANT	\N	PRESENT	0
750923	750895	20062A	PARTICIPANT	\N	PRESENT	0
750924	750895	19413M	PARTICIPANT	\N	PRESENT	0
750925	750895	20064C	PARTICIPANT	\N	PRESENT	0
750940	749997	12041X	PARTICIPANT	\N	PRESENT	0
750941	749997	12028B	PARTICIPANT	\N	PRESENT	0
750942	749997	19347U	PARTICIPANT	\N	PRESENT	0
750943	749997	01062T	PARTICIPANT	\N	PRESENT	0
750944	749997	01024M	PARTICIPANT	\N	PRESENT	0
750945	749997	17023S	PARTICIPANT	\N	PRESENT	0
750956	749960	04047H	PRESIDENT	0	PRESENT	0
750957	749960	14215L	PARTICIPANT	\N	PRESENT	0
750958	749960	01028R	PARTICIPANT	\N	PRESENT	0
750959	749960	11056N	PARTICIPANT	\N	PRESENT	0
750960	749960	19729F	PARTICIPANT	\N	PRESENT	0
750961	749960	05008E	PARTICIPANT	\N	PRESENT	0
750962	749960	14089Y	PARTICIPANT	\N	PRESENT	0
750963	749960	19749K	PARTICIPANT	\N	PRESENT	0
750964	749960	17737W	PARTICIPANT	\N	PRESENT	0
750965	749960	14147R	PARTICIPANT	\N	PRESENT	0
750967	749960	14179A	PARTICIPANT	\N	PRESENT	0
750992	749975	86034E	PARTICIPANT	\N	PRESENT	0
750993	749975	14105F	PARTICIPANT	\N	PRESENT	0
750994	749975	20090E	PARTICIPANT	\N	PRESENT	0
750995	749960	14021P	PARTICIPANT	\N	PRESENT	0
750996	749975	14331P	PARTICIPANT	\N	PRESENT	0
750997	749975	19295A	PARTICIPANT	\N	PRESENT	0
750998	749975	14097Y	PARTICIPANT	\N	PRESENT	0
750999	749975	98022P	PARTICIPANT	\N	PRESENT	0
751000	749975	14259Y	PARTICIPANT	\N	PRESENT	0
751001	749975	19798U	PARTICIPANT	\N	PRESENT	0
751002	749975	20016T	PARTICIPANT	\N	PRESENT	0
751003	749975	17023S	PARTICIPANT	\N	PRESENT	0
751004	749975	18083K	PARTICIPANT	\N	PRESENT	0
751005	749975	20024T	PARTICIPANT	\N	PRESENT	0
751006	749975	11054L	PARTICIPANT	\N	PRESENT	0
751007	749975	20032T	PARTICIPANT	\N	PRESENT	0
751008	749975	14195A	PARTICIPANT	\N	PRESENT	0
751009	749975	11080N	PARTICIPANT	\N	PRESENT	0
751010	749975	08028W	PARTICIPANT	\N	PRESENT	0
751011	749975	20034V	PARTICIPANT	\N	PRESENT	0
751012	749975	19577H	PARTICIPANT	\N	PRESENT	0
751013	749975	11104D	PARTICIPANT	\N	PRESENT	0
751014	749975	19369B	PARTICIPANT	\N	PRESENT	0
751015	749975	20102Q	PARTICIPANT	\N	PRESENT	0
751016	749975	19745F	PARTICIPANT	\N	PRESENT	0
751017	749975	04045F	PARTICIPANT	\N	PRESENT	0
751018	749975	08009T	PARTICIPANT	\N	PRESENT	0
751019	749975	14281W	PARTICIPANT	\N	PRESENT	0
751020	749975	20084G	PARTICIPANT	\N	PRESENT	0
751021	749975	20132W	PARTICIPANT	\N	PRESENT	0
751022	749975	19782L	PARTICIPANT	\N	PRESENT	0
751023	749975	14111D	PARTICIPANT	\N	PRESENT	0
751024	749975	14207L	PARTICIPANT	\N	PRESENT	0
751025	749975	19683J	PARTICIPANT	\N	PRESENT	0
751026	749975	12028B	PARTICIPANT	\N	PRESENT	0
751027	749975	14211G	PARTICIPANT	\N	PRESENT	0
751036	749975	17589D	PARTICIPANT	\N	PRESENT	0
751037	749975	20050V	PARTICIPANT	\N	PRESENT	0
751038	749975	19637C	PARTICIPANT	\N	PRESENT	0
751039	749975	11027H	PARTICIPANT	\N	PRESENT	0
751040	749975	12016W	PARTICIPANT	\N	PRESENT	0
751041	749975	14257W	PARTICIPANT	\N	PRESENT	0
751042	749975	08061X	PARTICIPANT	\N	PRESENT	0
751043	749975	04059M	PARTICIPANT	\N	PRESENT	0
751044	749975	08045X	PARTICIPANT	\N	PRESENT	0
751045	749975	11067R	PARTICIPANT	\N	PRESENT	0
751046	749975	19333N	PARTICIPANT	\N	PRESENT	0
751047	749975	19647E	PARTICIPANT	\N	PRESENT	0
751048	749975	11012A	PARTICIPANT	\N	PRESENT	0
751049	749975	19621T	PARTICIPANT	\N	PRESENT	0
751050	749975	17637T	PARTICIPANT	\N	PRESENT	0
751051	749975	04085P	PARTICIPANT	\N	PRESENT	0
751052	749975	19758L	PARTICIPANT	\N	PRESENT	0
751053	749975	12041X	PARTICIPANT	\N	PRESENT	0
751054	749975	11031D	PARTICIPANT	\N	PRESENT	0
751055	749975	19565D	PARTICIPANT	\N	PRESENT	0
751056	749975	20092G	PARTICIPANT	\N	PRESENT	0
751057	749975	19347U	PARTICIPANT	\N	PRESENT	0
751058	749975	11101A	PARTICIPANT	\N	PRESENT	0
751059	749975	20142Y	PARTICIPANT	\N	PRESENT	0
751060	749975	20130U	PARTICIPANT	\N	PRESENT	0
751061	749975	19693L	PARTICIPANT	\N	PRESENT	0
751062	749975	99004R	PARTICIPANT	\N	PRESENT	0
751063	749975	19525U	PARTICIPANT	\N	PRESENT	0
751064	749975	08010L	PARTICIPANT	\N	PRESENT	0
751065	749975	14026U	PARTICIPANT	\N	PRESENT	0
751066	749975	11083R	PARTICIPANT	\N	PRESENT	0
751067	749975	04047H	PARTICIPANT	\N	PRESENT	0
750907	750895	20120S	PARTICIPANT	\N	PRESENT	0
750908	750895	14033T	PARTICIPANT	\N	PRESENT	0
751068	749975	08034U	PARTICIPANT	\N	PRESENT	0
751069	749975	04092N	PARTICIPANT	\N	PRESENT	0
751070	749975	11048N	PARTICIPANT	\N	PRESENT	0
751071	749975	14133K	PARTICIPANT	\N	PRESENT	0
751072	749975	04042C	PARTICIPANT	\N	PRESENT	0
751073	749975	20146D	PARTICIPANT	\N	PRESENT	0
751074	749975	08069G	PARTICIPANT	\N	PRESENT	0
751075	749975	95063L	PARTICIPANT	\N	PRESENT	0
751076	749975	20078J	PARTICIPANT	\N	PRESENT	0
751077	749975	20076G	PARTICIPANT	\N	PRESENT	0
751078	749975	11033F	PARTICIPANT	\N	PRESENT	0
751079	749975	17367Q	PARTICIPANT	\N	PRESENT	0
751080	749975	19643A	PARTICIPANT	\N	PRESENT	0
751081	749975	10015M	PARTICIPANT	\N	PRESENT	0
751082	749975	04033B	PARTICIPANT	\N	PRESENT	0
751083	749975	11097X	PARTICIPANT	\N	PRESENT	0
751085	749975	19415P	PARTICIPANT	\N	PRESENT	0
751086	749975	20036X	PARTICIPANT	\N	PRESENT	0
751087	749975	14187A	PARTICIPANT	\N	PRESENT	0
751089	749975	14071N	PARTICIPANT	\N	PRESENT	0
751090	749975	10006L	PARTICIPANT	\N	PRESENT	0
751091	749975	04071H	PARTICIPANT	\N	PRESENT	0
751092	749975	19701S	PARTICIPANT	\N	PRESENT	0
751093	749975	20116W	PARTICIPANT	\N	PRESENT	0
751094	749975	14069U	PARTICIPANT	\N	PRESENT	0
751095	749975	20072C	PARTICIPANT	\N	PRESENT	0
751096	749975	04043D	PARTICIPANT	\N	PRESENT	0
751097	749975	11090Q	PARTICIPANT	\N	PRESENT	0
751098	749975	19717B	PARTICIPANT	\N	PRESENT	0
751099	749975	19629C	PARTICIPANT	\N	PRESENT	0
751100	749975	19719D	PARTICIPANT	\N	PRESENT	0
751101	749975	20022R	PARTICIPANT	\N	PRESENT	0
751102	749975	04057K	PARTICIPANT	\N	PRESENT	0
751104	749975	19631V	PARTICIPANT	\N	PRESENT	0
751105	749975	19549D	PARTICIPANT	\N	PRESENT	0
751106	749975	20068G	PARTICIPANT	\N	PRESENT	0
751107	749975	01057W	PARTICIPANT	\N	PRESENT	0
751108	749975	20038A	PARTICIPANT	\N	PRESENT	0
751109	749975	19667J	PARTICIPANT	\N	PRESENT	0
751110	749975	19533U	PARTICIPANT	\N	PRESENT	0
751111	749975	14215L	PARTICIPANT	\N	PRESENT	0
751112	749975	20252E	PARTICIPANT	\N	PRESENT	0
751113	749975	20080C	PARTICIPANT	\N	PRESENT	0
751114	749975	20264J	PARTICIPANT	\N	PRESENT	0
751115	749975	14193X	PARTICIPANT	\N	PRESENT	0
751116	749975	14021P	PARTICIPANT	\N	PRESENT	0
751117	749975	08012N	PARTICIPANT	\N	PRESENT	0
751118	749975	20120S	PARTICIPANT	\N	PRESENT	0
751119	749975	20028X	PARTICIPANT	\N	PRESENT	0
751120	749975	14217N	PARTICIPANT	\N	PRESENT	0
751121	749975	97011G	PARTICIPANT	\N	PRESENT	0
751122	749975	14147R	PARTICIPANT	\N	PRESENT	0
751123	749975	17965H	PARTICIPANT	\N	PRESENT	0
751124	749975	19503N	PARTICIPANT	\N	PRESENT	0
751126	749975	14225N	PARTICIPANT	\N	PRESENT	0
751127	749975	20138D	PARTICIPANT	\N	PRESENT	0
751128	749975	20082E	PARTICIPANT	\N	PRESENT	0
751129	749975	11045K	PARTICIPANT	\N	PRESENT	0
751130	749975	01028R	PARTICIPANT	\N	PRESENT	0
751131	749975	20140W	PARTICIPANT	\N	PRESENT	0
740743	740742	08069G	PARTICIPANT	\N	PRESENT	0
740744	740742	20136B	PARTICIPANT	\N	PRESENT	0
740745	740742	14133K	PARTICIPANT	\N	PRESENT	0
740747	740746	08069G	PARTICIPANT	\N	PRESENT	0
740748	740746	20136B	PARTICIPANT	\N	PRESENT	0
740749	740746	14133K	PARTICIPANT	\N	PRESENT	0
740750	740746	04035D	PARTICIPANT	\N	PRESENT	0
746062	746061	19673G	PARTICIPANT	\N	PRESENT	0
746063	746061	19749K	PARTICIPANT	\N	PRESENT	0
746065	746064	08018U	PARTICIPANT	\N	PRESENT	0
746067	746066	08018U	PARTICIPANT	\N	PRESENT	0
746069	746068	08018U	PARTICIPANT	\N	PRESENT	0
750506	749973	19685L	PARTICIPANT	\N	PRESENT	0
750564	749974	20102Q	PARTICIPANT	\N	PRESENT	0
750505	749973	19711U	PARTICIPANT	\N	PRESENT	0
750507	749973	01043Q	PARTICIPANT	\N	PRESENT	0
750508	749973	14033T	PARTICIPANT	\N	PRESENT	0
750565	749974	19715Y	PARTICIPANT	\N	PRESENT	0
750566	749974	14281W	PARTICIPANT	\N	PRESENT	0
750567	749974	18193Q	PARTICIPANT	\N	PRESENT	0
750568	749974	14195A	PARTICIPANT	\N	PRESENT	0
750569	749974	20066E	PARTICIPANT	\N	PRESENT	0
750570	749974	11067R	PARTICIPANT	\N	PRESENT	0
750571	749974	19553Y	PARTICIPANT	\N	PRESENT	0
750572	749974	17737W	PARTICIPANT	\N	PRESENT	0
750573	749974	11090Q	PARTICIPANT	\N	PRESENT	0
750574	749974	20104S	PARTICIPANT	\N	PRESENT	0
750575	749974	20090E	PARTICIPANT	\N	PRESENT	0
750576	749974	20076G	PARTICIPANT	\N	PRESENT	0
750577	749974	19575F	PARTICIPANT	\N	PRESENT	0
750578	749974	20040T	PARTICIPANT	\N	PRESENT	0
750579	749974	11031D	PARTICIPANT	\N	PRESENT	0
750580	749974	10006L	PARTICIPANT	\N	PRESENT	0
750581	749974	14026U	PARTICIPANT	\N	PRESENT	0
750582	749974	17367Q	PARTICIPANT	\N	PRESENT	0
750583	749974	19798U	PARTICIPANT	\N	PRESENT	0
750584	749974	19782L	PARTICIPANT	\N	PRESENT	0
750585	749974	04047H	PARTICIPANT	\N	PRESENT	0
750586	749974	14071N	PARTICIPANT	\N	PRESENT	0
750587	749974	19447X	PARTICIPANT	\N	PRESENT	0
750588	749974	07029T	PARTICIPANT	\N	PRESENT	0
750589	749974	17965H	PARTICIPANT	\N	PRESENT	0
750590	749974	14215L	PARTICIPANT	\N	PRESENT	0
750591	749974	19711U	PARTICIPANT	\N	PRESENT	0
750592	749974	20058E	PARTICIPANT	\N	PRESENT	0
750593	749974	18083K	PARTICIPANT	\N	PRESENT	0
750594	749974	08010L	PARTICIPANT	\N	PRESENT	0
750595	749974	19760E	PARTICIPANT	\N	PRESENT	0
750596	749974	19758L	PARTICIPANT	\N	PRESENT	0
750597	749974	19347U	PARTICIPANT	\N	PRESENT	0
750598	749974	04033B	PARTICIPANT	\N	PRESENT	0
750599	749974	05012A	PARTICIPANT	\N	PRESENT	0
750600	749974	17779H	PARTICIPANT	\N	PRESENT	0
750601	749974	14231L	PARTICIPANT	\N	PRESENT	0
750602	749974	20026V	PARTICIPANT	\N	PRESENT	0
750603	749974	20044X	PARTICIPANT	\N	PRESENT	0
750604	749974	20062A	PARTICIPANT	\N	PRESENT	0
750605	749974	14193X	PARTICIPANT	\N	PRESENT	0
750606	749974	20086J	PARTICIPANT	\N	PRESENT	0
750607	749974	20140W	PARTICIPANT	\N	PRESENT	0
750608	749974	19723Y	PARTICIPANT	\N	PRESENT	0
750609	749974	20172F	PARTICIPANT	\N	PRESENT	0
750613	749974	20082E	PARTICIPANT	\N	PRESENT	0
750611	749974	20054A	PARTICIPANT	\N	PRESENT	0
750558	749974	11070L	PARTICIPANT	\N	PRESENT	0
750563	749974	20130U	PARTICIPANT	\N	PRESENT	0
750612	749974	14038Y	PARTICIPANT	\N	PRESENT	0
750614	749974	20252E	PARTICIPANT	\N	PRESENT	0
750630	749974	14083S	PARTICIPANT	\N	PRESENT	0
750616	749974	14213J	PARTICIPANT	\N	PRESENT	0
750617	749974	04092N	PARTICIPANT	\N	PRESENT	0
750618	749974	19415P	PARTICIPANT	\N	PRESENT	0
750619	749974	14217N	PARTICIPANT	\N	PRESENT	0
750620	749974	11097X	PARTICIPANT	\N	PRESENT	0
750621	749974	19762G	PARTICIPANT	\N	PRESENT	0
750622	749974	19467C	PARTICIPANT	\N	PRESENT	0
750623	749974	14187A	PARTICIPANT	\N	PRESENT	0
750624	749974	19820Y	PARTICIPANT	\N	PRESENT	0
750625	749974	14069U	PARTICIPANT	\N	PRESENT	0
750626	749974	20038A	PARTICIPANT	\N	PRESENT	0
750627	749974	11056N	PARTICIPANT	\N	PRESENT	0
750628	749974	17023S	PARTICIPANT	\N	PRESENT	0
750629	749974	14219Q	PARTICIPANT	\N	PRESENT	0
750631	749974	14033T	PARTICIPANT	\N	PRESENT	0
750632	749974	20034V	PARTICIPANT	\N	PRESENT	0
750633	749974	19295A	PARTICIPANT	\N	PRESENT	0
750634	749974	14147R	PARTICIPANT	\N	PRESENT	0
750636	749956	10006L	PRESIDENT	0	PRESENT	0
750637	749956	20248J	PARTICIPANT	\N	PRESENT	0
750638	749956	20040T	PARTICIPANT	\N	PRESENT	0
750639	749956	19553Y	PARTICIPANT	\N	PRESENT	0
750640	749956	14071N	PARTICIPANT	\N	PRESENT	0
750641	749956	20090E	PARTICIPANT	\N	PRESENT	0
750642	749956	18193Q	PARTICIPANT	\N	PRESENT	0
750643	749956	14217N	PARTICIPANT	\N	PRESENT	0
750644	749956	11097X	PARTICIPANT	\N	PRESENT	0
750645	749956	19798U	PARTICIPANT	\N	PRESENT	0
750646	749956	14042U	PARTICIPANT	\N	PRESENT	0
750647	749956	19723Y	PARTICIPANT	\N	PRESENT	0
750653	749956	19713W	PARTICIPANT	\N	PRESENT	0
750659	750559	10006L	PRESIDENT	0	PRESENT	0
750661	750559	14071N	PARTICIPANT	\N	PRESENT	0
750662	750559	19798U	PARTICIPANT	\N	PRESENT	0
750664	750559	20090E	PARTICIPANT	\N	PRESENT	0
750666	750559	14026U	PARTICIPANT	\N	PRESENT	0
750667	750559	20040T	PARTICIPANT	\N	PRESENT	0
750668	750559	17965H	PARTICIPANT	\N	PRESENT	0
750670	750559	14281W	PARTICIPANT	\N	PRESENT	0
750671	750559	11067R	PARTICIPANT	\N	PRESENT	0
750672	750559	18193Q	PARTICIPANT	\N	PRESENT	0
750674	750559	19760E	PARTICIPANT	\N	PRESENT	0
750675	750559	11031D	PARTICIPANT	\N	PRESENT	0
750680	749956	04092N	PARTICIPANT	\N	PRESENT	0
750701	749956	20066E	PARTICIPANT	\N	PRESENT	0
750707	749956	19415P	PARTICIPANT	\N	PRESENT	0
750709	749956	14281W	PARTICIPANT	\N	PRESENT	0
750724	749956	14026U	PARTICIPANT	\N	PRESENT	0
750725	749956	17965H	PARTICIPANT	\N	PRESENT	0
750726	749956	14195A	PARTICIPANT	\N	PRESENT	0
750749	749956	19760E	PARTICIPANT	\N	PRESENT	0
750751	749956	11067R	PARTICIPANT	\N	PRESENT	0
750761	749956	08045X	PARTICIPANT	\N	PRESENT	0
750762	749956	04043D	PARTICIPANT	\N	PRESENT	0
750764	749956	19683J	PARTICIPANT	\N	PRESENT	0
750765	749956	11031D	PARTICIPANT	\N	PRESENT	0
750771	749956	04057K	PARTICIPANT	\N	PRESENT	0
750823	749956	11045K	PARTICIPANT	\N	PRESENT	0
750825	749956	14213J	PARTICIPANT	\N	PRESENT	0
750841	749956	19663E	PARTICIPANT	\N	PRESENT	0
751594	749987	14133K	PARTICIPANT	\N	PRESENT	0
751595	749987	20286Q	PARTICIPANT	\N	PRESENT	0
751596	749987	14033T	PARTICIPANT	\N	PRESENT	0
751597	749987	19333N	PARTICIPANT	\N	PRESENT	0
751598	749987	14097Y	PARTICIPANT	\N	PRESENT	0
751599	749987	12041X	PARTICIPANT	\N	PRESENT	0
751600	749987	19711U	PARTICIPANT	\N	PRESENT	0
751602	749987	11026G	PARTICIPANT	\N	PRESENT	0
751603	749987	08034U	PARTICIPANT	\N	PRESENT	0
751604	749987	14001X	PARTICIPANT	\N	PRESENT	0
751605	749987	14331P	PRESIDENT	0	PRESENT	0
751606	749987	20098N	PARTICIPANT	\N	PRESENT	0
751607	749987	17737W	PARTICIPANT	\N	EXCUSE	0
751608	749987	20104S	PARTICIPANT	\N	EXCUSE	0
751609	749987	11101A	PARTICIPANT	\N	EXCUSE	0
751610	749987	19701S	PARTICIPANT	\N	EXCUSE	0
751611	749987	14357A	PARTICIPANT	\N	EXCUSE	0
751612	749987	08018U	PARTICIPANT	\N	EXCUSE	0
751613	749987	04035D	PARTICIPANT	\N	EXCUSE	0
751614	749987	19725B	PARTICIPANT	\N	EXCUSE	0
751615	749987	19441R	PARTICIPANT	\N	EXCUSE	0
751616	749987	04057K	PARTICIPANT	\N	EXCUSE	0
751617	749987	04070G	PARTICIPANT	\N	EXCUSE	0
751618	749987	14237S	PARTICIPANT	\N	EXCUSE	0
751619	749987	10015M	PARTICIPANT	\N	EXCUSE	0
751620	749987	04045F	PARTICIPANT	\N	EXCUSE	0
751622	749987	14169X	PARTICIPANT	\N	EXCUSE	0
751623	749987	20094J	PARTICIPANT	\N	EXCUSE	0
756755	756754	20108W	PARTICIPANT	\N	PRESENT	0
756790	756786	19649G	PARTICIPANT	\N	PRESENT	0
756793	756792	20108W	PARTICIPANT	\N	PRESENT	0
744545	744542	14111D	PARTICIPANT	\N	PRESENT	0
744549	744542	14219Q	PARTICIPANT	\N	PRESENT	0
744547	744542	04035D	PARTICIPANT	\N	PRESENT	0
744548	744542	14331P	PARTICIPANT	\N	PRESENT	0
746093	746014	14059S	PARTICIPANT	\N	PRESENT	0
746094	746014	12041X	PARTICIPANT	\N	PRESENT	0
746095	746014	01062T	PARTICIPANT	\N	PRESENT	0
746096	746014	20072C	PARTICIPANT	\N	PRESENT	0
746097	746014	20042V	PARTICIPANT	\N	PRESENT	0
746098	746014	04042C	PRESIDENT	0	PRESENT	0
746099	746014	11054L	PARTICIPANT	\N	PRESENT	0
746100	746014	11066Q	PARTICIPANT	\N	PRESENT	0
746101	746014	19669L	PARTICIPANT	\N	PRESENT	0
746102	746014	12028B	PARTICIPANT	\N	PRESENT	0
746103	746014	19319Q	PARTICIPANT	\N	PRESENT	0
746104	746014	20064C	PARTICIPANT	\N	PRESENT	0
746105	746014	19709B	PARTICIPANT	\N	PRESENT	0
746106	746014	98022P	PARTICIPANT	\N	PRESENT	0
746107	746014	19347U	PARTICIPANT	\N	PRESENT	0
746108	746014	14193X	PARTICIPANT	\N	PRESENT	0
746109	746014	11083R	PARTICIPANT	\N	PRESENT	0
746110	746014	97011G	PARTICIPANT	\N	PRESENT	0
746111	746014	14249W	PARTICIPANT	\N	PRESENT	0
746112	746014	08047A	PARTICIPANT	\N	PRESENT	0
746116	746014	14133K	PARTICIPANT	\N	PRESENT	0
746117	746014	19565D	PARTICIPANT	\N	PRESENT	0
746118	746014	01024M	PARTICIPANT	\N	PRESENT	0
746119	746014	14255U	PARTICIPANT	\N	PRESENT	0
746120	745791	14111D	PARTICIPANT	\N	PRESENT	0
746121	745791	11010L	PARTICIPANT	\N	PRESENT	0
746122	745791	14215L	PRESIDENT	0	PRESENT	0
746127	746014	20128B	PARTICIPANT	\N	PRESENT	0
746128	746014	14105F	PARTICIPANT	\N	EXCUSE	0
746129	746014	19443T	PARTICIPANT	\N	EXCUSE	0
746131	746014	04035D	PARTICIPANT	\N	PRESENT	0
746132	746014	14267Y	PARTICIPANT	\N	PRESENT	0
746133	746014	11027H	PARTICIPANT	\N	PRESENT	0
748134	748133	08018U	PARTICIPANT	\N	PRESENT	0
749897	748140	19441R	PARTICIPANT	\N	PRESENT	0
749895	749894	11066Q	PARTICIPANT	\N	PRESENT	0
749896	748140	14001X	PARTICIPANT	\N	PRESENT	0
759219	757734	19585H	PARTICIPANT	\N	PRESENT	0
759220	757734	04045F	PARTICIPANT	\N	PRESENT	0
759221	757734	04047H	PRESIDENT	0	PRESENT	0
759222	757734	05008E	PARTICIPANT	\N	PRESENT	0
759223	757734	19447X	PARTICIPANT	\N	PRESENT	0
759224	757734	19489J	PARTICIPANT	\N	PRESENT	0
759225	757734	21056G	PARTICIPANT	\N	PRESENT	0
759226	757734	20108W	PARTICIPANT	\N	PRESENT	0
759227	757734	18231D	PARTICIPANT	\N	PRESENT	0
759228	757734	20110Q	PARTICIPANT	\N	PRESENT	0
759229	757734	14147R	PARTICIPANT	\N	PRESENT	0
759230	757734	21088Q	PARTICIPANT	\N	PRESENT	0
759231	757734	14151M	PARTICIPANT	\N	PRESENT	0
759232	757734	20114U	PARTICIPANT	\N	PRESENT	0
759233	757734	19111A	PARTICIPANT	\N	PRESENT	0
759234	757734	14215L	PARTICIPANT	\N	PRESENT	0
759235	757734	08018U	PARTICIPANT	\N	PRESENT	0
759236	757734	21038E	PARTICIPANT	\N	PRESENT	0
759237	757734	21095P	PARTICIPANT	\N	PRESENT	0
759238	757734	11072N	PARTICIPANT	\N	PRESENT	0
759239	757734	14053L	PARTICIPANT	\N	PRESENT	0
759240	757734	20036X	PARTICIPANT	\N	PRESENT	0
759241	757734	14111D	PARTICIPANT	\N	PRESENT	0
759242	757734	19649G	PARTICIPANT	\N	PRESENT	0
759243	757734	14189C	PARTICIPANT	\N	PRESENT	0
759244	757734	21040X	PARTICIPANT	\N	PRESENT	0
759245	757734	19725B	PARTICIPANT	\N	PRESENT	0
759246	757734	21043B	PARTICIPANT	\N	PRESENT	0
759247	757734	21044C	PARTICIPANT	\N	PRESENT	0
759248	757734	11056N	PARTICIPANT	\N	PRESENT	0
759249	757734	19729F	PARTICIPANT	\N	PRESENT	0
759250	757734	19749K	PARTICIPANT	\N	PRESENT	0
759251	758135	21032X	PARTICIPANT	\N	PRESENT	0
759252	758135	18395Y	PARTICIPANT	\N	PRESENT	0
759253	758135	20132W	PARTICIPANT	\N	PRESENT	0
759254	758135	14073Q	PARTICIPANT	\N	PRESENT	0
759255	758135	20048C	PARTICIPANT	\N	PRESENT	0
759256	758135	20172F	PARTICIPANT	\N	PRESENT	0
759257	758135	14123H	PARTICIPANT	\N	PRESENT	0
759258	758135	21074J	PARTICIPANT	\N	PRESENT	0
759259	757734	20022R	PARTICIPANT	\N	PRESENT	0
759260	757734	19719D	PARTICIPANT	\N	PRESENT	0
759267	758747	20086J	PRESIDENT	1	PRESENT	0
759268	758747	19349W	PARTICIPANT	\N	PRESENT	0
759270	758135	19057M	PARTICIPANT	\N	PRESENT	0
759271	757734	14231L	PARTICIPANT	\N	PRESENT	0
759272	757734	20098N	PARTICIPANT	\N	PRESENT	0
759273	757734	18207D	PARTICIPANT	\N	PRESENT	0
759274	757734	14259Y	PARTICIPANT	\N	PRESENT	0
759275	757734	14069U	PARTICIPANT	\N	PRESENT	0
759279	757734	14089Y	PARTICIPANT	\N	PRESENT	0
759322	757774	17023S	PARTICIPANT	\N	PRESENT	0
759323	757861	19383Y	PARTICIPANT	\N	PRESENT	0
759324	757861	19768N	PARTICIPANT	\N	PRESENT	0
759325	757861	20088L	PARTICIPANT	\N	PRESENT	0
759326	757861	20092G	PARTICIPANT	\N	PRESENT	0
759327	757861	19782L	PARTICIPANT	\N	PRESENT	0
759328	757861	14357A	PARTICIPANT	\N	PRESENT	0
759329	757861	20078J	PARTICIPANT	\N	PRESENT	0
759330	757861	20082E	PARTICIPANT	\N	PRESENT	0
759331	757861	14221J	PARTICIPANT	\N	PRESENT	0
759332	757861	20104S	PARTICIPANT	\N	PRESENT	0
759333	757861	19705W	PARTICIPANT	\N	PRESENT	0
759334	757861	08015R	PARTICIPANT	\N	PRESENT	0
759335	757861	19575F	PARTICIPANT	\N	PRESENT	0
759336	757861	20018V	PARTICIPANT	\N	PRESENT	0
759337	757861	08028W	PARTICIPANT	\N	PRESENT	0
759338	757861	19563B	PARTICIPANT	\N	PRESENT	0
759339	757861	21050A	PARTICIPANT	\N	PRESENT	0
759340	757861	21096Q	PARTICIPANT	\N	PRESENT	0
759341	757861	20028X	PARTICIPANT	\N	PRESENT	0
759342	757861	14038Y	PARTICIPANT	\N	PRESENT	0
759343	757861	21054E	PARTICIPANT	\N	PRESENT	0
759344	757861	21075K	PARTICIPANT	\N	PRESENT	0
759345	757861	14187A	PRESIDENT	0	PRESENT	0
759346	757861	21083K	PARTICIPANT	\N	PRESENT	0
759347	757861	20144B	PARTICIPANT	\N	PRESENT	0
759348	757861	21086N	PARTICIPANT	\N	PRESENT	0
759349	757861	19695N	PARTICIPANT	\N	PRESENT	0
759350	757861	14033T	PARTICIPANT	\N	PRESENT	0
759351	757861	21093M	PARTICIPANT	\N	PRESENT	0
759352	757861	11090Q	PARTICIPANT	\N	PRESENT	0
759353	757861	20054A	PARTICIPANT	\N	PRESENT	0
759354	757861	14205J	PARTICIPANT	\N	PRESENT	0
759355	757861	20060X	PARTICIPANT	\N	PRESENT	0
759356	757861	19507S	PARTICIPANT	\N	PRESENT	0
759357	757861	21066J	PARTICIPANT	\N	PRESENT	0
759358	757861	14207L	PARTICIPANT	\N	PRESENT	0
759359	757861	14257W	PARTICIPANT	\N	PRESENT	0
759360	757861	20084G	PARTICIPANT	\N	PRESENT	0
759361	757861	21052C	PARTICIPANT	\N	EXCUSE	0
759362	757861	20066E	PARTICIPANT	\N	EXCUSE	0
759363	757861	14329V	PARTICIPANT	\N	EXCUSE	0
759369	757798	86034E	PARTICIPANT	\N	PRESENT	0
759384	757695	17965H	PARTICIPANT	\N	PRESENT	0
759413	757695	20140W	PARTICIPANT	\N	PRESENT	0
759386	757695	14223L	PARTICIPANT	\N	PRESENT	0
759414	757695	21045D	PARTICIPANT	\N	PRESENT	0
759388	757695	14213J	PARTICIPANT	\N	PRESENT	0
759389	757695	17779H	PARTICIPANT	\N	PRESENT	0
759390	757695	21039F	PARTICIPANT	\N	PRESENT	0
759391	757695	21049H	PARTICIPANT	\N	PRESENT	0
759392	757695	19758L	PARTICIPANT	\N	PRESENT	0
759393	757695	19760E	PARTICIPANT	\N	PRESENT	0
759394	757695	14217N	PARTICIPANT	\N	PRESENT	0
759395	757695	20248J	PARTICIPANT	\N	PRESENT	0
759415	757695	19866P	PARTICIPANT	\N	PRESENT	0
759397	757695	20130U	PARTICIPANT	\N	PRESENT	0
759398	757695	21064G	PARTICIPANT	\N	PRESENT	0
759399	757695	19703U	PARTICIPANT	\N	PRESENT	0
759416	757695	19723Y	PARTICIPANT	\N	PRESENT	0
759401	757695	14071N	PRESIDENT	\N	PRESENT	0
759402	757695	21087P	PARTICIPANT	\N	PRESENT	0
759403	757695	21046E	PARTICIPANT	\N	PRESENT	0
759404	757695	19367Y	PARTICIPANT	\N	PRESENT	0
759405	757695	20090E	PARTICIPANT	\N	PRESENT	0
759406	757695	14026U	PARTICIPANT	\N	PRESENT	0
759407	757695	19691J	PARTICIPANT	\N	PRESENT	0
759408	757695	19798U	PARTICIPANT	\N	PRESENT	0
759410	757695	01034P	PARTICIPANT	\N	PRESENT	0
739759	738838	19679N	PARTICIPANT	\N	PRESENT	0
739760	738838	11067R	PARTICIPANT	\N	PRESENT	0
739761	738838	20130U	PARTICIPANT	\N	PRESENT	0
739762	738838	14026U	PARTICIPANT	\N	PRESENT	0
741129	720098	11104D	PARTICIPANT	\N	PRESENT	0
741130	722794	11104D	PARTICIPANT	\N	PRESENT	0
742230	740161	08045X	PARTICIPANT	\N	PRESENT	0
742231	740161	19691J	PARTICIPANT	\N	PRESENT	0
742232	740161	19553Y	PARTICIPANT	\N	PRESENT	0
742233	740161	19713W	PARTICIPANT	\N	PRESENT	0
742234	740161	20130U	PARTICIPANT	\N	PRESENT	0
742235	740161	11067R	PARTICIPANT	\N	PRESENT	0
742236	740161	18193Q	PARTICIPANT	\N	PRESENT	0
742237	740161	17965H	PARTICIPANT	\N	PRESENT	0
742238	740161	14223L	PARTICIPANT	\N	PRESENT	0
742239	740161	19511N	PARTICIPANT	\N	PRESENT	0
742240	740161	14042U	PARTICIPANT	\N	PRESENT	0
742241	740161	14217N	PARTICIPANT	\N	PRESENT	0
742242	740161	04092N	PARTICIPANT	\N	PRESENT	0
742243	740161	19703U	PARTICIPANT	\N	PRESENT	0
742244	740161	14071N	PRESIDENT	0	PRESENT	0
742245	740161	20040T	PARTICIPANT	\N	PRESENT	0
742246	740161	14195A	PARTICIPANT	\N	PRESENT	0
742247	740161	14213J	PARTICIPANT	\N	PRESENT	0
742248	740161	19683J	PARTICIPANT	\N	PRESENT	0
742249	740161	14281W	PARTICIPANT	\N	PRESENT	0
742250	740161	19723Y	PARTICIPANT	\N	PRESENT	0
742251	740161	11097X	PARTICIPANT	\N	PRESENT	0
742252	740161	01034P	PARTICIPANT	\N	PRESENT	0
742253	740161	19329S	PARTICIPANT	\N	PRESENT	0
742255	740161	19295A	PARTICIPANT	\N	PRESENT	0
742256	740161	14355X	PARTICIPANT	\N	PRESENT	0
742257	740161	10006L	PRESIDENT	1	PRESENT	0
742258	740161	19715Y	PARTICIPANT	\N	PRESENT	0
742259	740161	17779H	PARTICIPANT	\N	PRESENT	0
742262	740161	20248J	PARTICIPANT	\N	PRESENT	0
742267	740161	19569H	PARTICIPANT	\N	PRESENT	0
742268	740161	20266L	PARTICIPANT	\N	PRESENT	0
742269	740161	19798U	PARTICIPANT	\N	PRESENT	0
742270	740161	04043D	PARTICIPANT	\N	PRESENT	0
742271	740161	20090E	PARTICIPANT	\N	PRESENT	0
742278	740161	14026U	PARTICIPANT	\N	PRESENT	0
742418	740161	04057K	PARTICIPANT	\N	PRESENT	0
742435	740161	19679N	PARTICIPANT	\N	PRESENT	0
742436	740161	19663E	PARTICIPANT	\N	PRESENT	0
742848	742823	14026U	PARTICIPANT	\N	PRESENT	0
742851	742823	19725B	PARTICIPANT	\N	PRESENT	0
760225	760199	14073Q	PARTICIPANT	\N	PRESENT	0
760680	760490	19575F	PARTICIPANT	\N	EXCUSE	0
760681	760490	20072C	PARTICIPANT	\N	EXCUSE	0
760682	760490	14038Y	PARTICIPANT	\N	EXCUSE	0
760683	760490	19569H	PARTICIPANT	\N	EXCUSE	0
760685	760490	19735D	PARTICIPANT	\N	EXCUSE	0
760686	760490	20138D	PARTICIPANT	\N	EXCUSE	0
767664	765403	20076G	PARTICIPANT	\N	PRESENT	0
767665	765403	21037D	PARTICIPANT	\N	PRESENT	0
767666	765403	21080G	PARTICIPANT	\N	PRESENT	0
767667	765403	21044C	PARTICIPANT	\N	PRESENT	0
767668	765403	19573D	PARTICIPANT	\N	PRESENT	0
767669	765403	10015M	PARTICIPANT	\N	PRESENT	0
767670	765403	19695N	PARTICIPANT	\N	PRESENT	0
767671	765403	11043H	PARTICIPANT	\N	PRESENT	0
767672	765403	14223L	PARTICIPANT	\N	PRESENT	0
767673	765403	14169X	PARTICIPANT	\N	PRESENT	0
767674	765403	20044X	PARTICIPANT	\N	PRESENT	0
767675	765403	20150Y	PARTICIPANT	\N	PRESENT	0
767676	765403	19349W	PARTICIPANT	\N	PRESENT	0
767677	765403	21072G	PARTICIPANT	\N	PRESENT	0
767678	765403	14037X	PARTICIPANT	\N	PRESENT	0
767679	765403	19591F	PARTICIPANT	\N	PRESENT	0
767680	765403	21055F	PARTICIPANT	\N	PRESENT	0
767681	765403	21074J	PARTICIPANT	\N	PRESENT	0
767682	765403	19673G	PARTICIPANT	\N	PRESENT	0
767683	765403	14031R	PARTICIPANT	\N	PRESENT	0
767684	765403	19667J	PARTICIPANT	\N	PRESENT	0
767685	765403	21046E	PARTICIPANT	\N	PRESENT	0
767686	765403	14253S	PARTICIPANT	\N	PRESENT	0
767687	765403	19545Y	PARTICIPANT	\N	PRESENT	0
767688	765403	20026V	PARTICIPANT	\N	PRESENT	0
767689	765403	21087P	PARTICIPANT	\N	PRESENT	0
767662	765403	20146D	PARTICIPANT	\N	PRESENT	0
767663	765403	20110Q	PARTICIPANT	\N	PRESENT	0
767690	765403	20180F	PARTICIPANT	\N	PRESENT	0
767691	765403	20096L	PARTICIPANT	\N	PRESENT	0
767692	765403	14111D	PARTICIPANT	\N	PRESENT	0
767693	765403	21058J	PARTICIPANT	\N	PRESENT	0
767694	765403	14173T	PARTICIPANT	\N	PRESENT	0
767695	765403	14251Q	PARTICIPANT	\N	PRESENT	0
767696	765403	19447X	PARTICIPANT	\N	PRESENT	0
767697	765403	21054E	PARTICIPANT	\N	PRESENT	0
767698	765403	19723Y	PARTICIPANT	\N	PRESENT	0
767699	765403	14038Y	PARTICIPANT	\N	PRESENT	0
767700	765403	20140W	PARTICIPANT	\N	PRESENT	0
767701	765403	21039F	PARTICIPANT	\N	PRESENT	0
767702	765403	20116W	PARTICIPANT	\N	PRESENT	0
767703	765403	21063F	PARTICIPANT	\N	PRESENT	0
767704	765403	19629C	PARTICIPANT	\N	PRESENT	0
767705	765403	17367Q	PARTICIPANT	\N	PRESENT	0
767706	765403	21066J	PARTICIPANT	\N	PRESENT	0
767707	765403	20072C	PARTICIPANT	\N	PRESENT	0
767708	765403	19709B	PARTICIPANT	\N	PRESENT	0
767709	765403	21078N	PARTICIPANT	\N	PRESENT	0
767710	765403	08018U	PARTICIPANT	\N	PRESENT	0
767712	765403	20050V	PARTICIPANT	\N	PRESENT	0
767713	765403	11090Q	PARTICIPANT	\N	PRESENT	0
767714	765403	21088Q	PARTICIPANT	\N	PRESENT	0
767715	765403	05012A	PARTICIPANT	\N	PRESENT	0
767716	765403	20032T	PARTICIPANT	\N	PRESENT	0
767717	765403	19565D	PARTICIPANT	\N	PRESENT	0
767718	765403	21081H	PARTICIPANT	\N	PRESENT	0
767719	765403	19954N	PARTICIPANT	\N	PRESENT	0
767720	765403	14147R	PARTICIPANT	\N	PRESENT	0
767722	765403	20138D	PARTICIPANT	\N	PRESENT	0
767723	765403	08047A	PARTICIPANT	\N	PRESENT	0
767724	765403	20056C	PARTICIPANT	\N	PRESENT	0
767725	765403	20104S	PARTICIPANT	\N	PRESENT	0
767726	765403	19399H	PARTICIPANT	\N	PRESENT	0
767729	765403	20148F	PARTICIPANT	\N	PRESENT	0
767730	765403	14123H	PARTICIPANT	\N	PRESENT	0
767731	765403	20172F	PARTICIPANT	\N	PRESENT	0
767732	765403	21036C	PARTICIPANT	\N	PRESENT	0
767733	765403	19657G	PARTICIPANT	\N	PRESENT	0
767734	765403	19768N	PARTICIPANT	\N	PRESENT	0
767735	765403	08015R	PARTICIPANT	\N	PRESENT	0
767736	765403	07029T	PARTICIPANT	\N	PRESENT	0
767737	765403	08056B	PARTICIPANT	\N	PRESENT	0
767738	765403	20126Y	PARTICIPANT	\N	PRESENT	0
767739	765403	20054A	PARTICIPANT	\N	PRESENT	0
767740	765403	20020P	PARTICIPANT	\N	PRESENT	0
767741	765403	20086J	PARTICIPANT	\N	PRESENT	0
767742	765403	20098N	PARTICIPANT	\N	PRESENT	0
767743	765403	19383Y	PARTICIPANT	\N	PRESENT	0
767744	765403	21095P	PARTICIPANT	\N	PRESENT	0
767745	765403	14217N	PARTICIPANT	\N	PRESENT	0
767746	765403	21090J	PARTICIPANT	\N	PRESENT	0
767747	765403	21071F	PARTICIPANT	\N	PRESENT	0
767748	765403	05008E	PARTICIPANT	\N	PRESENT	0
767749	765403	19331L	PARTICIPANT	\N	PRESENT	0
767750	765403	14329V	PARTICIPANT	\N	PRESENT	0
767751	765403	14357A	PARTICIPANT	\N	PRESENT	0
767752	765403	20252E	PARTICIPANT	\N	PRESENT	0
767753	765403	20100N	PARTICIPANT	\N	PRESENT	0
767754	765403	14069U	PARTICIPANT	\N	PRESENT	0
767755	765403	21092L	PARTICIPANT	\N	PRESENT	0
767756	765403	21079P	PARTICIPANT	\N	PRESENT	0
767757	765403	14071N	PARTICIPANT	\N	PRESENT	0
767758	765403	14053L	PARTICIPANT	\N	PRESENT	0
767759	765403	20266L	PARTICIPANT	\N	PRESENT	0
767760	765403	19701S	PARTICIPANT	\N	PRESENT	0
767761	765403	04033B	PARTICIPANT	\N	PRESENT	0
767762	765403	19679N	PARTICIPANT	\N	PRESENT	0
767763	765403	20062A	PARTICIPANT	\N	PRESENT	0
767764	765403	08034U	PARTICIPANT	\N	PRESENT	0
767765	765403	19301E	PARTICIPANT	\N	PRESENT	0
767766	765403	04092N	PARTICIPANT	\N	PRESENT	0
767767	765403	19697Q	PARTICIPANT	\N	PRESENT	0
767768	765403	21085M	PARTICIPANT	\N	PRESENT	0
767769	765403	21069M	PARTICIPANT	\N	PRESENT	0
767770	765403	21061D	PARTICIPANT	\N	PRESENT	0
767771	765403	14026U	PARTICIPANT	\N	PRESENT	0
767772	765403	19387D	PARTICIPANT	\N	PRESENT	0
751132	749975	08047A	PARTICIPANT	\N	PRESENT	0
751133	749975	19413M	PARTICIPANT	\N	PRESENT	0
751134	749975	20026V	PARTICIPANT	\N	PRESENT	0
751135	749975	19531S	PARTICIPANT	\N	PRESENT	0
751136	749975	20180F	PARTICIPANT	\N	PRESENT	0
751137	749975	20980G	PARTICIPANT	\N	PRESENT	0
751138	749975	14173T	PARTICIPANT	\N	PRESENT	0
751139	749975	11066Q	PARTICIPANT	\N	PRESENT	0
751140	749975	14038Y	PARTICIPANT	\N	PRESENT	0
751141	749975	19723Y	PARTICIPANT	\N	PRESENT	0
751142	749975	20070A	PARTICIPANT	\N	PRESENT	0
751143	749975	19467C	PARTICIPANT	\N	PRESENT	0
751144	749975	20098N	PARTICIPANT	\N	PRESENT	0
751145	749975	14033T	PARTICIPANT	\N	PRESENT	0
751146	749975	19741B	PARTICIPANT	\N	PRESENT	0
751147	749975	19057M	PARTICIPANT	\N	PRESENT	0
751148	749975	20104S	PARTICIPANT	\N	PRESENT	0
751149	749975	05008E	PARTICIPANT	\N	PRESENT	0
751150	749975	20172F	PARTICIPANT	\N	PRESENT	0
751151	749975	14329V	PARTICIPANT	\N	PRESENT	0
751152	749975	14251Q	PARTICIPANT	\N	PRESENT	0
751153	749975	14123H	PARTICIPANT	\N	PRESENT	0
751154	749975	14357A	PARTICIPANT	\N	PRESENT	0
751155	749975	17737W	PARTICIPANT	\N	PRESENT	0
751156	749975	11065P	PARTICIPANT	\N	PRESENT	0
751157	749975	19383Y	PARTICIPANT	\N	PRESENT	0
751158	749975	20020P	PARTICIPANT	\N	PRESENT	0
751159	749975	14030Q	PARTICIPANT	\N	PRESENT	0
751160	749975	20042V	PARTICIPANT	\N	PRESENT	0
751161	749975	20054A	PARTICIPANT	\N	PRESENT	0
751162	749975	20126Y	PARTICIPANT	\N	PRESENT	0
751163	749975	14255U	PARTICIPANT	\N	PRESENT	0
751164	749975	20124W	PARTICIPANT	\N	PRESENT	0
751165	749975	14083S	PARTICIPANT	\N	PRESENT	0
751166	749975	11053K	PARTICIPANT	\N	PRESENT	0
751167	749975	20062A	PARTICIPANT	\N	PRESENT	0
751233	749975	19695N	PARTICIPANT	\N	PRESENT	0
751169	749975	20144B	PARTICIPANT	\N	PRESENT	0
751170	749975	14267Y	PARTICIPANT	\N	PRESENT	0
751171	749975	11070L	PARTICIPANT	\N	PRESENT	0
751172	749975	14327T	PARTICIPANT	\N	PRESENT	0
751173	749975	05012A	PARTICIPANT	\N	PRESENT	0
751174	749975	08015R	PARTICIPANT	\N	PRESENT	0
751175	749975	19729F	PARTICIPANT	\N	PRESENT	0
751176	749975	20134Y	PARTICIPANT	\N	PRESENT	0
751177	749975	07029T	PARTICIPANT	\N	PRESENT	0
751178	749975	14042U	PARTICIPANT	\N	PRESENT	0
751179	749975	20086J	PARTICIPANT	\N	PRESENT	0
751180	749975	19709B	PARTICIPANT	\N	PRESENT	0
751181	749975	20248J	PARTICIPANT	\N	PRESENT	0
751182	749975	19663E	PARTICIPANT	\N	PRESENT	0
751183	749975	20044X	PARTICIPANT	\N	PRESENT	0
751184	749975	19820Y	PARTICIPANT	\N	PRESENT	0
751185	749975	20040T	PARTICIPANT	\N	PRESENT	0
751186	749975	01025N	PARTICIPANT	\N	PRESENT	0
751187	749975	19768N	PARTICIPANT	\N	PRESENT	0
751188	749975	17229F	PARTICIPANT	\N	PRESENT	0
751189	749975	14231L	PARTICIPANT	\N	PRESENT	0
751190	749975	01024M	PARTICIPANT	\N	PRESENT	0
751191	749975	20286Q	PARTICIPANT	\N	PRESENT	0
751192	749975	14179A	PARTICIPANT	\N	PRESENT	0
751193	749975	19685L	PARTICIPANT	\N	PRESENT	0
751194	749975	20048C	PARTICIPANT	\N	PRESENT	0
751195	749975	20066E	PARTICIPANT	\N	PRESENT	0
751196	749975	14073Q	PARTICIPANT	\N	PRESENT	0
751197	749975	19611R	PARTICIPANT	\N	PRESENT	0
751198	749975	01043Q	PARTICIPANT	\N	PRESENT	0
751199	749975	20052X	PARTICIPANT	\N	PRESENT	0
751200	749975	16685X	PARTICIPANT	\N	PRESENT	0
751201	749975	14205J	PARTICIPANT	\N	PRESENT	0
751202	749975	14219Q	PARTICIPANT	\N	PRESENT	0
751203	749975	19441R	PARTICIPANT	\N	PRESENT	0
751204	749975	11085T	PARTICIPANT	\N	PRESENT	0
751205	749975	19826F	PARTICIPANT	\N	PRESENT	0
751206	749975	19335Q	PARTICIPANT	\N	PRESENT	0
751207	749975	19739H	PARTICIPANT	\N	PRESENT	0
751208	749975	19713W	PARTICIPANT	\N	PRESENT	0
751209	749975	01034P	PARTICIPANT	\N	PRESENT	0
751210	749975	19749K	PARTICIPANT	\N	PRESENT	0
751211	749975	14213J	PARTICIPANT	\N	PRESENT	0
751212	749975	19711U	PARTICIPANT	\N	PRESENT	0
751213	749975	11099A	PARTICIPANT	\N	PRESENT	0
751214	749975	14249W	PARTICIPANT	\N	PRESENT	0
751215	749975	18193Q	PARTICIPANT	\N	PRESENT	0
751216	749975	11074Q	PARTICIPANT	\N	PRESENT	0
751217	749975	11056N	PARTICIPANT	\N	PRESENT	0
751218	749975	19760E	PARTICIPANT	\N	PRESENT	0
751219	749975	19591F	PARTICIPANT	\N	PRESENT	0
751220	749975	19687N	PARTICIPANT	\N	PRESENT	0
751221	749975	14121F	PARTICIPANT	\N	PRESENT	0
751226	749975	20018V	PARTICIPANT	\N	PRESENT	0
751223	749975	19553Y	PARTICIPANT	\N	PRESENT	0
751236	749975	11026G	PARTICIPANT	\N	PRESENT	0
751225	749975	14001X	PARTICIPANT	\N	PRESENT	0
751228	749975	11041F	PARTICIPANT	\N	PRESENT	0
751229	749975	19349W	PARTICIPANT	\N	PRESENT	0
751231	749975	14109K	PARTICIPANT	\N	PRESENT	0
751232	749975	19543W	PARTICIPANT	\N	PRESENT	0
751234	749975	14189C	PARTICIPANT	\N	PRESENT	0
751235	749975	20058E	PARTICIPANT	\N	PRESENT	0
751237	749975	14089Y	PARTICIPANT	\N	PRESENT	0
751466	749976	99004R	PARTICIPANT	\N	PRESENT	0
751467	749976	19798U	PARTICIPANT	\N	PRESENT	0
751468	749976	19553Y	PARTICIPANT	\N	PRESENT	0
751469	749976	14089Y	PARTICIPANT	\N	PRESENT	0
751470	749976	20024T	PARTICIPANT	\N	PRESENT	0
751471	749976	20090E	PARTICIPANT	\N	PRESENT	0
751472	749976	18193Q	PARTICIPANT	\N	PRESENT	0
751473	749976	20102Q	PARTICIPANT	\N	PRESENT	0
751474	749976	19565D	PARTICIPANT	\N	PRESENT	0
751475	749976	20062A	PARTICIPANT	\N	PRESENT	0
751476	749976	97011G	PARTICIPANT	\N	PRESENT	0
751477	749976	14213J	PARTICIPANT	\N	PRESENT	0
751478	749976	19591F	PARTICIPANT	\N	PRESENT	0
751479	749976	19760E	PARTICIPANT	\N	PRESENT	0
751480	749976	20248J	PARTICIPANT	\N	PRESENT	0
751481	749976	04057K	PARTICIPANT	\N	PRESENT	0
751482	749976	14069U	PARTICIPANT	\N	PRESENT	0
751483	749976	14147R	PARTICIPANT	\N	PRESENT	0
751484	749976	11031D	PARTICIPANT	\N	PRESENT	0
751485	749976	14217N	PARTICIPANT	\N	PRESENT	0
751486	749976	20048C	PARTICIPANT	\N	PRESENT	0
751487	749976	10006L	PARTICIPANT	\N	PRESENT	0
751488	749976	20266L	PARTICIPANT	\N	PRESENT	0
751489	749976	14083S	PARTICIPANT	\N	PRESENT	0
751490	749976	11012A	PARTICIPANT	\N	PRESENT	0
751510	749989	20034V	PARTICIPANT	\N	PRESENT	0
751511	749989	20092G	PARTICIPANT	\N	PRESENT	0
751512	749989	19782L	PARTICIPANT	\N	PRESENT	0
751513	749989	14187A	PARTICIPANT	\N	PRESENT	0
751514	749989	19441R	PARTICIPANT	\N	PRESENT	0
751515	749989	20144B	PARTICIPANT	\N	PRESENT	0
751516	749989	19413M	PARTICIPANT	\N	PRESENT	0
751517	749989	19695N	PARTICIPANT	\N	PRESENT	0
751518	749989	14033T	PARTICIPANT	\N	PRESENT	0
751519	749989	11090Q	PRESIDENT	0	PRESENT	0
751520	749989	14205J	PARTICIPANT	\N	PRESENT	0
751521	749989	08015R	PARTICIPANT	\N	PRESENT	0
751522	749989	20286Q	PARTICIPANT	\N	PRESENT	0
751523	749989	14207L	PARTICIPANT	\N	PRESENT	0
751524	749989	20018V	PARTICIPANT	\N	PRESENT	0
751525	749989	08028W	PARTICIPANT	\N	PRESENT	0
751526	749989	14257W	PARTICIPANT	\N	PRESENT	0
751527	749989	19575F	PARTICIPANT	\N	EXCUSE	0
751528	749989	20094J	PARTICIPANT	\N	EXCUSE	0
751539	751536	19533U	PARTICIPANT	\N	PRESENT	0
751540	751536	04043D	PARTICIPANT	\N	EXCUSE	0
751541	751536	01048V	PARTICIPANT	\N	EXCUSE	0
751542	751536	20072C	PARTICIPANT	\N	EXCUSE	0
751543	751536	20066E	PARTICIPANT	\N	EXCUSE	0
751544	751536	19693L	PARTICIPANT	\N	EXCUSE	0
751561	751536	20128B	PARTICIPANT	\N	PRESENT	0
751952	751951	19251M	PARTICIPANT	\N	PRESENT	0
751953	751951	19711U	PARTICIPANT	\N	PRESENT	0
751954	751951	97011G	PARTICIPANT	\N	PRESENT	0
751955	751951	19593H	PARTICIPANT	\N	PRESENT	0
751956	751951	19647E	PARTICIPANT	\N	PRESENT	0
751958	751957	14259Y	PARTICIPANT	\N	PRESENT	0
743789	743785	08018U	PARTICIPANT	\N	PRESENT	0
743792	743791	10006L	PARTICIPANT	\N	PRESENT	0
743793	743791	14213J	PARTICIPANT	\N	PRESENT	0
743794	743791	18193Q	PARTICIPANT	\N	PRESENT	0
743795	743791	04092N	PARTICIPANT	\N	PRESENT	0
743796	743791	11097X	PARTICIPANT	\N	PRESENT	0
743803	743802	10006L	PARTICIPANT	\N	PRESENT	0
743804	743802	19663E	PARTICIPANT	\N	PRESENT	0
748793	747231	19611R	PRESIDENT	0	PRESENT	0
748794	747231	19643A	PARTICIPANT	\N	PRESENT	0
748795	747231	20980G	PARTICIPANT	\N	PRESENT	0
748858	747231	20152B	PARTICIPANT	\N	PRESENT	0
748806	747231	19758L	PARTICIPANT	\N	PRESENT	0
748810	747231	20142Y	PARTICIPANT	\N	PRESENT	0
748812	747231	14229S	PARTICIPANT	\N	PRESENT	0
748817	747231	20180F	PARTICIPANT	\N	PRESENT	0
748818	747231	20026V	PARTICIPANT	\N	PRESENT	0
748820	747231	14123H	PARTICIPANT	\N	PRESENT	0
748821	747231	20052X	PARTICIPANT	\N	PRESENT	0
748825	747231	14073Q	PARTICIPANT	\N	PRESENT	0
748826	747231	20056C	PARTICIPANT	\N	PRESENT	0
748828	747231	19735D	PARTICIPANT	\N	PRESENT	0
748831	747231	19699S	PARTICIPANT	\N	PRESENT	0
748834	747231	20138D	PARTICIPANT	\N	PRESENT	0
748835	747231	20124W	PARTICIPANT	\N	PRESENT	0
748843	747231	14053L	PARTICIPANT	\N	PRESENT	0
748844	747231	20022R	PARTICIPANT	\N	PRESENT	0
748845	747231	14069U	PARTICIPANT	\N	PRESENT	0
748846	747231	04047H	PARTICIPANT	\N	PRESENT	0
748847	747231	19725B	PARTICIPANT	\N	PRESENT	0
748848	747231	19729F	PARTICIPANT	\N	PRESENT	0
748849	747231	14147R	PARTICIPANT	\N	PRESENT	0
748850	747231	10015M	PARTICIPANT	\N	PRESENT	0
748851	747231	01028R	PARTICIPANT	\N	PRESENT	0
748852	747231	19749K	PARTICIPANT	\N	PRESENT	0
748853	747231	20264J	PARTICIPANT	\N	PRESENT	0
748856	747231	19533U	PARTICIPANT	\N	PRESENT	0
748874	747231	11056N	PARTICIPANT	\N	PRESENT	0
749476	749471	05008E	PARTICIPANT	\N	PRESENT	0
749479	749471	11033F	PARTICIPANT	\N	PRESENT	0
749482	749471	11053K	PARTICIPANT	\N	PRESENT	0
749483	749471	14357A	PARTICIPANT	\N	PRESENT	0
749484	749471	11070L	PARTICIPANT	\N	PRESENT	0
749485	749471	19719D	PARTICIPANT	\N	PRESENT	0
749486	749471	19673G	PARTICIPANT	\N	PRESENT	0
749487	749471	01025N	PARTICIPANT	\N	PRESENT	0
749489	749471	14033T	PARTICIPANT	\N	PRESENT	0
749490	749471	14123H	PARTICIPANT	\N	PRESENT	0
749491	749471	14026U	PARTICIPANT	\N	PRESENT	0
749492	749471	11064N	PARTICIPANT	\N	PRESENT	0
749493	749471	14179A	PARTICIPANT	\N	PRESENT	0
749494	749471	14213J	PARTICIPANT	\N	PRESENT	0
749495	749471	99004R	PARTICIPANT	\N	PRESENT	0
749496	749471	86034E	PARTICIPANT	\N	PRESENT	0
749497	749471	12041X	PARTICIPANT	\N	PRESENT	0
749498	749471	14147R	PARTICIPANT	\N	PRESENT	0
749499	749471	95063L	PARTICIPANT	\N	PRESENT	0
749500	749471	01028R	PARTICIPANT	\N	PRESENT	0
749501	749471	19301E	PARTICIPANT	\N	PRESENT	0
749502	749471	19413M	PARTICIPANT	\N	PRESENT	0
756566	755515	19569H	PARTICIPANT	\N	PRESENT	0
756567	755515	19367Y	PARTICIPANT	\N	PRESENT	0
756568	755515	14071N	PRESIDENT	0	PRESENT	0
756569	755515	19657G	PARTICIPANT	\N	PRESENT	0
756570	755515	19691J	PARTICIPANT	\N	PRESENT	0
756571	755515	14223L	PARTICIPANT	\N	PRESENT	0
756572	755515	14217N	PARTICIPANT	\N	PRESENT	0
756573	755515	20148F	PARTICIPANT	\N	PRESENT	0
756574	755515	21039F	PARTICIPANT	\N	PRESENT	0
756575	755515	19760E	PARTICIPANT	\N	PRESENT	0
756576	755515	14213J	PARTICIPANT	\N	PRESENT	0
756577	755515	14026U	PARTICIPANT	\N	PRESENT	0
756578	755515	21045D	PARTICIPANT	\N	PRESENT	0
756579	755515	18193Q	PARTICIPANT	\N	PRESENT	0
756580	755515	21064G	PARTICIPANT	\N	PRESENT	0
756581	755515	21071F	PARTICIPANT	\N	PRESENT	0
756582	755515	21046E	PARTICIPANT	\N	EXCUSE	0
756583	755515	21087P	PARTICIPANT	\N	EXCUSE	0
756584	755515	17779H	PARTICIPANT	\N	EXCUSE	0
756585	755515	19703U	PARTICIPANT	\N	PRESENT	0
756586	755515	21049H	PARTICIPANT	\N	PRESENT	0
756587	755515	19713W	PARTICIPANT	\N	PRESENT	0
756588	755515	14042U	PARTICIPANT	\N	PRESENT	0
756589	755515	19679N	PARTICIPANT	\N	PRESENT	0
756612	755515	20140W	PARTICIPANT	\N	PRESENT	0
756613	755515	19723Y	PARTICIPANT	\N	PRESENT	0
756614	755515	20090E	PARTICIPANT	\N	PRESENT	0
756615	755515	14281W	PARTICIPANT	\N	PRESENT	0
756795	756792	19649G	PARTICIPANT	\N	PRESENT	0
756800	756799	20108W	PARTICIPANT	\N	PRESENT	0
756912	755865	11027H	PARTICIPANT	\N	PRESENT	0
756913	755865	07033P	PARTICIPANT	\N	PRESENT	0
756914	755865	08047A	PARTICIPANT	\N	PRESENT	0
756915	755865	17023S	PARTICIPANT	\N	PRESENT	0
756921	752397	04070G	PARTICIPANT	\N	PRESENT	0
756922	752397	21058J	PARTICIPANT	\N	PRESENT	0
756923	752397	14229S	PARTICIPANT	\N	PRESENT	0
756924	752397	18395Y	PARTICIPANT	\N	PRESENT	0
756925	752397	19611R	PRESIDENT	0	PRESENT	0
756926	752397	20138D	PARTICIPANT	\N	PRESENT	0
756927	752397	20048C	PARTICIPANT	\N	PRESENT	0
756928	752397	20172F	PARTICIPANT	\N	PRESENT	0
756929	752397	19735D	PARTICIPANT	\N	PRESENT	0
756930	752397	11043H	PARTICIPANT	\N	PRESENT	0
756931	752397	21074J	PARTICIPANT	\N	PRESENT	0
756933	755515	08061X	PARTICIPANT	\N	PRESENT	0
756934	755515	19591F	PARTICIPANT	\N	PRESENT	0
756937	756592	19768N	PARTICIPANT	\N	PRESENT	0
756938	756592	19782L	PARTICIPANT	\N	PRESENT	0
756939	756592	20018V	PARTICIPANT	\N	PRESENT	0
756940	756592	21050A	PARTICIPANT	\N	PRESENT	0
756941	756592	20028X	PARTICIPANT	\N	PRESENT	0
756942	756592	14038Y	PARTICIPANT	\N	PRESENT	0
756943	756592	20030R	PARTICIPANT	\N	PRESENT	0
756944	756592	21052C	PARTICIPANT	\N	PRESENT	0
756945	756592	21054E	PARTICIPANT	\N	PRESENT	0
756946	756592	20034V	PARTICIPANT	\N	PRESENT	0
756947	756592	14187A	PRESIDENT	0	PRESENT	0
756948	756592	20038A	PARTICIPANT	\N	PRESENT	0
756949	756592	21075K	PARTICIPANT	\N	PRESENT	0
756950	756592	21083K	PARTICIPANT	\N	PRESENT	0
756951	756592	21086N	PARTICIPANT	\N	PRESENT	0
756952	756592	21092L	PARTICIPANT	\N	PRESENT	0
756953	756592	19695N	PARTICIPANT	\N	PRESENT	0
756954	756592	21093M	PARTICIPANT	\N	PRESENT	0
756955	756592	11090Q	PARTICIPANT	\N	PRESENT	0
756956	756592	20054A	PARTICIPANT	\N	PRESENT	0
756957	756592	21034A	PARTICIPANT	\N	PRESENT	0
756958	756592	20060X	PARTICIPANT	\N	PRESENT	0
756959	756592	20066E	PARTICIPANT	\N	PRESENT	0
756960	756592	21066J	PARTICIPANT	\N	PRESENT	0
756961	756592	14207L	PARTICIPANT	\N	PRESENT	0
756962	756592	20084G	PARTICIPANT	\N	PRESENT	0
756963	756592	14257W	PARTICIPANT	\N	PRESENT	0
756964	756592	19383Y	PARTICIPANT	\N	PRESENT	0
756965	756592	20088L	PARTICIPANT	\N	PRESENT	0
756966	756592	20092G	PARTICIPANT	\N	PRESENT	0
756967	756592	14357A	PARTICIPANT	\N	PRESENT	0
756968	756592	20078J	PARTICIPANT	\N	PRESENT	0
756969	756592	19413M	PARTICIPANT	\N	PRESENT	0
756970	756592	20082E	PARTICIPANT	\N	PRESENT	0
756971	756592	14221J	PARTICIPANT	\N	PRESENT	0
756972	756592	20104S	PARTICIPANT	\N	PRESENT	0
756973	756592	19631V	PARTICIPANT	\N	PRESENT	0
756974	756592	19705W	PARTICIPANT	\N	PRESENT	0
756975	756592	19707Y	PARTICIPANT	\N	PRESENT	0
756976	756592	08015R	PARTICIPANT	\N	PRESENT	0
756977	756592	19575F	PARTICIPANT	\N	PRESENT	0
756978	756592	08028W	PARTICIPANT	\N	PRESENT	0
756979	756592	19563B	PARTICIPANT	\N	PRESENT	0
756980	756592	14329V	PARTICIPANT	\N	PRESENT	0
756981	756592	20144B	PARTICIPANT	\N	PRESENT	0
756982	756592	14033T	PARTICIPANT	\N	PRESENT	0
756983	756592	14205J	PARTICIPANT	\N	PRESENT	0
756984	756592	19507S	PARTICIPANT	\N	PRESENT	0
756985	756592	20286Q	PARTICIPANT	\N	PRESENT	0
757088	755537	19798U	PARTICIPANT	\N	PRESENT	0
757089	755537	19553Y	PARTICIPANT	\N	PRESENT	0
757090	755537	17965H	PARTICIPANT	\N	PRESENT	0
757168	754622	21071F	PARTICIPANT	\N	PRESENT	0
757169	754622	21042A	PARTICIPANT	\N	PRESENT	0
759417	757695	21081H	PARTICIPANT	\N	PRESENT	0
759420	758747	08009T	PARTICIPANT	\N	PRESENT	0
759421	757861	20038A	PARTICIPANT	\N	PRESENT	0
759422	757861	21092L	PARTICIPANT	\N	PRESENT	0
759425	757863	19383Y	PARTICIPANT	\N	PRESENT	0
759426	757863	19768N	PARTICIPANT	\N	PRESENT	0
759427	757863	20088L	PARTICIPANT	\N	PRESENT	0
759428	757863	20092G	PARTICIPANT	\N	PRESENT	0
759429	757863	19782L	PARTICIPANT	\N	PRESENT	0
759430	757863	14357A	PARTICIPANT	\N	PRESENT	0
759431	757863	20078J	PARTICIPANT	\N	PRESENT	0
759432	757863	20082E	PARTICIPANT	\N	PRESENT	0
759433	757863	14221J	PARTICIPANT	\N	PRESENT	0
759434	757863	20104S	PARTICIPANT	\N	PRESENT	0
759435	757863	19705W	PARTICIPANT	\N	PRESENT	0
759436	757863	08015R	PARTICIPANT	\N	PRESENT	0
759437	757863	19575F	PARTICIPANT	\N	PRESENT	0
759438	757863	20018V	PARTICIPANT	\N	PRESENT	0
759439	757863	08028W	PARTICIPANT	\N	PRESENT	0
759440	757863	19563B	PARTICIPANT	\N	PRESENT	0
759441	757863	21050A	PARTICIPANT	\N	PRESENT	0
759442	757863	21096Q	PARTICIPANT	\N	PRESENT	0
759443	757863	20028X	PARTICIPANT	\N	PRESENT	0
759444	757863	14038Y	PARTICIPANT	\N	PRESENT	0
759445	757863	21054E	PARTICIPANT	\N	PRESENT	0
759446	757863	21075K	PARTICIPANT	\N	PRESENT	0
759447	757863	14187A	PRESIDENT	0	PRESENT	0
759448	757863	20038A	PARTICIPANT	\N	PRESENT	0
759449	757863	21083K	PARTICIPANT	\N	PRESENT	0
759450	757863	20144B	PARTICIPANT	\N	PRESENT	0
759451	757863	21086N	PARTICIPANT	\N	PRESENT	0
759452	757863	19695N	PARTICIPANT	\N	PRESENT	0
759453	757863	21092L	PARTICIPANT	\N	PRESENT	0
759454	757863	14033T	PARTICIPANT	\N	PRESENT	0
759455	757863	21093M	PARTICIPANT	\N	PRESENT	0
759456	757863	11090Q	PARTICIPANT	\N	PRESENT	0
759457	757863	20054A	PARTICIPANT	\N	PRESENT	0
759458	757863	14205J	PARTICIPANT	\N	PRESENT	0
759459	757863	20060X	PARTICIPANT	\N	PRESENT	0
759460	757863	19507S	PARTICIPANT	\N	PRESENT	0
759461	757863	21066J	PARTICIPANT	\N	PRESENT	0
759462	757863	14207L	PARTICIPANT	\N	PRESENT	0
759463	757863	14257W	PARTICIPANT	\N	PRESENT	0
759464	757863	20084G	PARTICIPANT	\N	PRESENT	0
759465	757863	21052C	PARTICIPANT	\N	EXCUSE	0
759466	757863	20066E	PARTICIPANT	\N	EXCUSE	0
759467	757863	14329V	PARTICIPANT	\N	EXCUSE	0
759499	757861	19631V	PARTICIPANT	\N	EXCUSE	0
759500	757863	19631V	PARTICIPANT	\N	EXCUSE	0
759501	757798	21053D	PARTICIPANT	\N	PRESENT	0
759502	757798	98022P	PARTICIPANT	\N	PRESENT	0
759503	757798	20090E	PARTICIPANT	\N	PRESENT	0
759504	757798	21069M	PARTICIPANT	\N	PRESENT	0
759505	757798	04042C	PARTICIPANT	\N	PRESENT	0
759506	757798	19533U	PARTICIPANT	\N	PRESENT	0
759507	757798	21083K	PARTICIPANT	\N	PRESENT	0
759508	757798	20084G	PARTICIPANT	\N	PRESENT	0
759509	757798	21057H	PARTICIPANT	\N	PRESENT	0
759510	757798	20100N	PARTICIPANT	\N	PRESENT	0
759511	757798	21055F	PARTICIPANT	\N	PRESENT	0
759512	757798	20036X	PARTICIPANT	\N	PRESENT	0
759513	757798	20044X	PARTICIPANT	\N	PRESENT	0
759514	757798	21039F	PARTICIPANT	\N	PRESENT	0
759515	757798	21059K	PARTICIPANT	\N	PRESENT	0
759516	757798	21046E	PARTICIPANT	\N	PRESENT	0
759517	757798	19585H	PARTICIPANT	\N	PRESENT	0
759518	757798	21087P	PARTICIPANT	\N	PRESENT	0
759519	757798	14207L	PARTICIPANT	\N	PRESENT	0
759520	757798	99004R	PARTICIPANT	\N	PRESENT	0
759521	757798	08028W	PARTICIPANT	\N	PRESENT	0
759522	757798	17229F	PARTICIPANT	\N	PRESENT	0
759523	757798	20046A	PARTICIPANT	\N	PRESENT	0
759524	757798	20028X	PARTICIPANT	\N	PRESENT	0
759525	757798	20074E	PARTICIPANT	\N	PRESENT	0
759526	757798	21044C	PARTICIPANT	\N	PRESENT	0
759527	757798	20042V	PARTICIPANT	\N	PRESENT	0
759528	757798	20052X	PARTICIPANT	\N	PRESENT	0
759529	757798	19699S	PARTICIPANT	\N	PRESENT	0
759530	757798	14221J	PARTICIPANT	\N	PRESENT	0
759531	757798	14267Y	PARTICIPANT	\N	PRESENT	0
759532	757798	11040E	PARTICIPANT	\N	PRESENT	0
759533	757798	12028B	PARTICIPANT	\N	PRESENT	0
759534	757798	14151M	PARTICIPANT	\N	PRESENT	0
759535	757798	21089R	PARTICIPANT	\N	PRESENT	0
759536	757798	18193Q	PARTICIPANT	\N	PRESENT	0
759537	757798	19629C	PARTICIPANT	\N	PRESENT	0
759538	757798	21066J	PARTICIPANT	\N	PRESENT	0
759539	757798	19866P	PARTICIPANT	\N	PRESENT	0
759540	757798	21076L	PARTICIPANT	\N	PRESENT	0
759541	757798	08060W	PARTICIPANT	\N	PRESENT	0
759542	757798	19683J	PARTICIPANT	\N	PRESENT	0
759543	757798	21086N	PARTICIPANT	\N	PRESENT	0
759544	757798	11090Q	PARTICIPANT	\N	PRESENT	0
759545	757798	20064C	PARTICIPANT	\N	PRESENT	0
759546	757798	21082J	PARTICIPANT	\N	PRESENT	0
759547	757798	21062E	PARTICIPANT	\N	PRESENT	0
759548	757798	20086J	PARTICIPANT	\N	PRESENT	0
759549	757798	14059S	PARTICIPANT	\N	PRESENT	0
759550	757798	21061D	PARTICIPANT	\N	PRESENT	0
759551	757798	21095P	PARTICIPANT	\N	PRESENT	0
759552	757798	21088Q	PARTICIPANT	\N	PRESENT	0
759553	757798	21081H	PARTICIPANT	\N	PRESENT	0
759554	757798	21032X	PARTICIPANT	\N	PRESENT	0
759555	757798	14111D	PARTICIPANT	\N	PRESENT	0
759556	757798	14097Y	PARTICIPANT	\N	PRESENT	0
759557	757798	21045D	PARTICIPANT	\N	PRESENT	0
759558	757798	19111A	PARTICIPANT	\N	PRESENT	0
759559	757798	08009T	PARTICIPANT	\N	PRESENT	0
759560	757798	21054E	PARTICIPANT	\N	PRESENT	0
759561	757798	21070E	PARTICIPANT	\N	PRESENT	0
759562	757798	20132W	PARTICIPANT	\N	PRESENT	0
759563	757798	20088L	PARTICIPANT	\N	PRESENT	0
759566	757798	19760E	PARTICIPANT	\N	PRESENT	0
759567	757798	21084L	PARTICIPANT	\N	PRESENT	0
759568	757798	19758L	PARTICIPANT	\N	PRESENT	0
759569	757798	19621T	PARTICIPANT	\N	PRESENT	0
759570	757798	21049H	PARTICIPANT	\N	PRESENT	0
759571	757798	20076G	PARTICIPANT	\N	PRESENT	0
759572	757798	21071F	PARTICIPANT	\N	PRESENT	0
759573	757798	14026U	PARTICIPANT	\N	PRESENT	0
759574	757798	21040X	PARTICIPANT	\N	PRESENT	0
759575	757798	20102Q	PARTICIPANT	\N	PRESENT	0
759576	757798	21075K	PARTICIPANT	\N	PRESENT	0
759577	757798	04092N	PARTICIPANT	\N	PRESENT	0
759578	757798	20112S	PARTICIPANT	\N	PRESENT	0
759579	757798	19695N	PARTICIPANT	\N	PRESENT	0
759580	757798	19575F	PARTICIPANT	\N	PRESENT	0
759581	757798	21048G	PARTICIPANT	\N	PRESENT	0
759582	757798	20134Y	PARTICIPANT	\N	PRESENT	0
759583	757798	18083K	PARTICIPANT	\N	PRESENT	0
759584	757798	19347U	PARTICIPANT	\N	PRESENT	0
759585	757798	21092L	PARTICIPANT	\N	PRESENT	0
759586	757798	19711U	PARTICIPANT	\N	PRESENT	0
759587	757798	21093M	PARTICIPANT	\N	PRESENT	0
759588	757798	20142Y	PARTICIPANT	\N	PRESENT	0
759589	757798	19703U	PARTICIPANT	\N	PRESENT	0
759590	757798	21073H	PARTICIPANT	\N	PRESENT	0
759591	757798	21091K	PARTICIPANT	\N	PRESENT	0
759592	757798	21037D	PARTICIPANT	\N	PRESENT	0
759593	757798	19367Y	PARTICIPANT	\N	PRESENT	0
759594	757798	01058X	PARTICIPANT	\N	PRESENT	0
759595	757798	20092G	PARTICIPANT	\N	PRESENT	0
759596	757798	20130U	PARTICIPANT	\N	PRESENT	0
759597	757798	08010L	PARTICIPANT	\N	PRESENT	0
759598	757798	21079P	PARTICIPANT	\N	PRESENT	0
759599	757798	04047H	PARTICIPANT	\N	PRESENT	0
759601	757798	20266L	PARTICIPANT	\N	PRESENT	0
759602	757798	21043B	PARTICIPANT	\N	PRESENT	0
759603	757798	14123H	PARTICIPANT	\N	PRESENT	0
759604	757798	21096Q	PARTICIPANT	\N	PRESENT	0
759605	757798	14259Y	PARTICIPANT	\N	PRESENT	0
759606	757798	19057M	PARTICIPANT	\N	PRESENT	0
759607	757798	14249W	PARTICIPANT	\N	PRESENT	0
759609	757798	20078J	PARTICIPANT	\N	PRESENT	0
759610	757798	20106U	PARTICIPANT	\N	PRESENT	0
759611	757798	20128B	PARTICIPANT	\N	PRESENT	0
759612	757798	21080G	PARTICIPANT	\N	PRESENT	0
759613	757798	19782L	PARTICIPANT	\N	PRESENT	0
759614	757798	11072N	PARTICIPANT	\N	PRESENT	0
759615	757798	14223L	PARTICIPANT	\N	PRESENT	0
759616	757798	21097R	PARTICIPANT	\N	PRESENT	0
740518	740517	20264J	PARTICIPANT	\N	PRESENT	0
740519	740517	19525U	PARTICIPANT	\N	PRESENT	0
740520	740517	14133K	PARTICIPANT	\N	PRESENT	0
740521	740517	19749K	PARTICIPANT	\N	PRESENT	0
740523	740517	14255U	PARTICIPANT	\N	PRESENT	0
740847	740752	19729F	PARTICIPANT	\N	EXCUSE	0
741170	739429	14237S	PARTICIPANT	\N	PRESENT	0
741171	739429	19782L	PARTICIPANT	\N	PRESENT	0
741172	739429	11097X	PARTICIPANT	\N	PRESENT	0
741173	739429	19713W	PARTICIPANT	\N	PRESENT	0
746916	746915	05008E	PARTICIPANT	\N	PRESENT	0
746917	746915	11053K	PARTICIPANT	\N	PRESENT	0
746918	746915	01028R	PARTICIPANT	\N	PRESENT	0
748168	748094	99004R	PARTICIPANT	\N	PRESENT	0
748169	748162	11040E	PARTICIPANT	\N	PRESENT	0
748170	748162	14083S	PARTICIPANT	\N	PRESENT	0
748171	748162	11048N	PARTICIPANT	\N	PRESENT	0
748172	748162	20914V	PARTICIPANT	\N	PRESENT	0
748173	748162	99004R	PARTICIPANT	\N	PRESENT	0
748174	748162	14225N	PRESIDENT	0	PRESENT	0
748175	748162	07029T	PARTICIPANT	\N	PRESENT	0
748176	748162	19479G	PARTICIPANT	\N	EXCUSE	0
748177	748162	20050V	PARTICIPANT	\N	EXCUSE	0
748178	748162	19711U	PARTICIPANT	\N	PRESENT	0
748179	748162	20116W	PARTICIPANT	\N	PRESENT	0
748180	748162	19647E	PARTICIPANT	\N	PRESENT	0
748181	748094	11048N	PARTICIPANT	\N	PRESENT	0
748182	748094	11012A	PARTICIPANT	\N	PRESENT	0
748183	748094	19711U	PARTICIPANT	\N	PRESENT	0
748184	748094	14211G	PARTICIPANT	\N	PRESENT	0
748185	748162	04071H	PARTICIPANT	\N	PRESENT	0
748186	748162	11012A	PARTICIPANT	\N	PRESENT	0
748187	748094	20914V	PARTICIPANT	\N	PRESENT	0
748188	748094	95063L	PARTICIPANT	\N	PRESENT	0
748189	748094	20070A	PARTICIPANT	\N	PRESENT	0
748190	748094	11040E	PARTICIPANT	\N	PRESENT	0
748191	748094	14083S	PARTICIPANT	\N	PRESENT	0
748192	748094	19798U	PARTICIPANT	\N	PRESENT	0
748193	748094	11010L	PARTICIPANT	\N	PRESENT	0
748194	748094	20068G	PARTICIPANT	\N	PRESENT	0
748195	748094	19709B	PARTICIPANT	\N	PRESENT	0
748196	748094	08009T	PARTICIPANT	\N	PRESENT	0
748197	748094	20076G	PARTICIPANT	\N	PRESENT	0
748198	748094	14059S	PARTICIPANT	\N	PRESENT	0
748199	748094	20116W	PARTICIPANT	\N	PRESENT	0
748200	748094	07033P	PARTICIPANT	\N	PRESENT	0
748201	748094	14225N	PARTICIPANT	\N	PRESENT	0
748202	748094	14021P	PARTICIPANT	\N	PRESENT	0
748203	748094	07029T	PARTICIPANT	\N	PRESENT	0
748204	748094	20980G	PARTICIPANT	\N	PRESENT	0
748205	748094	19553Y	PARTICIPANT	\N	PRESENT	0
748206	748094	19723Y	PARTICIPANT	\N	PRESENT	0
748207	748094	19687N	PARTICIPANT	\N	PRESENT	0
748208	748094	20034V	PARTICIPANT	\N	PRESENT	0
748209	748094	19683J	PARTICIPANT	\N	PRESENT	0
748210	748094	04033B	PARTICIPANT	\N	PRESENT	0
748212	748094	20080C	PARTICIPANT	\N	PRESENT	0
748236	748094	19647E	PARTICIPANT	\N	PRESENT	0
748250	748094	14193X	PARTICIPANT	\N	PRESENT	0
748251	748095	99004R	PARTICIPANT	\N	PRESENT	0
748252	748095	11048N	PARTICIPANT	\N	PRESENT	0
748253	748095	19711U	PARTICIPANT	\N	PRESENT	0
748254	748095	14211G	PARTICIPANT	\N	PRESENT	0
748255	748095	20914V	PARTICIPANT	\N	PRESENT	0
748256	748095	95063L	PARTICIPANT	\N	PRESENT	0
748284	748095	20126Y	PARTICIPANT	\N	PRESENT	0
748258	748095	11040E	PARTICIPANT	\N	PRESENT	0
748259	748095	14083S	PARTICIPANT	\N	PRESENT	0
748260	748095	20068G	PARTICIPANT	\N	PRESENT	0
748261	748095	08009T	PARTICIPANT	\N	PRESENT	0
748308	748098	11048N	PARTICIPANT	\N	PRESENT	0
748263	748095	14225N	PARTICIPANT	\N	PRESENT	0
748264	748095	19553Y	PARTICIPANT	\N	PRESENT	0
748265	748095	19687N	PARTICIPANT	\N	PRESENT	0
748275	748095	19798U	PARTICIPANT	\N	PRESENT	0
748267	748095	20080C	PARTICIPANT	\N	PRESENT	0
748285	748095	14042U	PARTICIPANT	\N	PRESENT	0
748269	748095	14193X	PARTICIPANT	\N	PRESENT	0
748270	748095	07029T	PARTICIPANT	\N	PRESENT	0
748271	748095	20980G	PARTICIPANT	\N	PRESENT	0
748286	748098	99004R	PARTICIPANT	\N	PRESENT	0
748273	748095	20076G	PARTICIPANT	\N	PRESENT	0
748276	748095	19651A	PARTICIPANT	\N	PRESENT	0
748287	748098	19711U	PARTICIPANT	\N	PRESENT	0
748278	748095	20044X	PARTICIPANT	\N	PRESENT	0
748288	748098	20914V	PARTICIPANT	\N	PRESENT	0
748280	748095	20098N	PARTICIPANT	\N	PRESENT	0
748281	748095	20034V	PARTICIPANT	\N	PRESENT	0
748282	748095	20050V	PARTICIPANT	\N	PRESENT	0
748283	748095	14259Y	PARTICIPANT	\N	PRESENT	0
748309	748098	20116W	PARTICIPANT	\N	PRESENT	0
748290	748098	14083S	PARTICIPANT	\N	PRESENT	0
748291	748098	20068G	PARTICIPANT	\N	PRESENT	0
748310	748098	19553Y	PARTICIPANT	\N	PRESENT	0
748293	748098	20076G	PARTICIPANT	\N	PRESENT	0
748294	748098	14225N	PARTICIPANT	\N	PRESENT	0
748295	748098	07029T	PARTICIPANT	\N	PRESENT	0
748296	748098	20980G	PARTICIPANT	\N	PRESENT	0
748297	748098	19687N	PARTICIPANT	\N	PRESENT	0
748298	748098	20080C	PARTICIPANT	\N	PRESENT	0
748299	748098	19798U	PARTICIPANT	\N	PRESENT	0
748300	748098	19651A	PARTICIPANT	\N	PRESENT	0
748301	748098	20044X	PARTICIPANT	\N	PRESENT	0
748302	748098	20098N	PARTICIPANT	\N	PRESENT	0
748303	748098	20034V	PARTICIPANT	\N	PRESENT	0
748304	748098	20050V	PARTICIPANT	\N	PRESENT	0
748305	748098	14259Y	PARTICIPANT	\N	PRESENT	0
748306	748098	20126Y	PARTICIPANT	\N	PRESENT	0
748307	748098	14042U	PARTICIPANT	\N	PRESENT	0
748311	748098	20066E	PARTICIPANT	\N	PRESENT	0
748312	748163	20092G	PARTICIPANT	\N	PRESENT	0
748313	748163	11097X	PARTICIPANT	\N	PRESENT	0
748314	748163	11053K	PARTICIPANT	\N	PRESENT	0
748315	748163	19251M	PARTICIPANT	\N	PRESENT	0
748316	748163	20102Q	PARTICIPANT	\N	PRESENT	0
748319	748163	14357A	PARTICIPANT	\N	PRESENT	0
748320	748163	19713W	PARTICIPANT	\N	PRESENT	0
748321	748098	11040E	PARTICIPANT	\N	PRESENT	0
748322	748163	19782L	PARTICIPANT	\N	PRESENT	0
748323	748098	14213J	PARTICIPANT	\N	PRESENT	0
748324	748098	17965H	PARTICIPANT	\N	PRESENT	0
748325	748098	20058E	PARTICIPANT	\N	PRESENT	0
748326	748098	04033B	PARTICIPANT	\N	PRESENT	0
748327	748098	10006L	PARTICIPANT	\N	PRESENT	0
748328	748098	20048C	PARTICIPANT	\N	PRESENT	0
748329	748098	19683J	PARTICIPANT	\N	PRESENT	0
748330	748098	11045K	PARTICIPANT	\N	PRESENT	0
748331	748098	11085T	PARTICIPANT	\N	PRESENT	0
748332	748098	20130U	PARTICIPANT	\N	PRESENT	0
748333	748098	11072N	PARTICIPANT	\N	PRESENT	0
748334	748098	14217N	PARTICIPANT	\N	PRESENT	0
748335	748098	11031D	PARTICIPANT	\N	PRESENT	0
748338	748099	19711U	PARTICIPANT	\N	PRESENT	0
748340	748099	14083S	PARTICIPANT	\N	PRESENT	0
748341	748099	20068G	PARTICIPANT	\N	PRESENT	0
748342	748099	20076G	PARTICIPANT	\N	PRESENT	0
748344	748099	07029T	PARTICIPANT	\N	PRESENT	0
748345	748099	20980G	PARTICIPANT	\N	PRESENT	0
748347	748099	20080C	PARTICIPANT	\N	PRESENT	0
748348	748099	19798U	PARTICIPANT	\N	PRESENT	0
748349	748099	19651A	PARTICIPANT	\N	PRESENT	0
748351	748099	20050V	PARTICIPANT	\N	PRESENT	0
748352	748099	20126Y	PARTICIPANT	\N	PRESENT	0
748353	748099	14042U	PARTICIPANT	\N	PRESENT	0
748355	748099	19553Y	PARTICIPANT	\N	PRESENT	0
748357	748099	14213J	PARTICIPANT	\N	PRESENT	0
748359	748099	10006L	PARTICIPANT	\N	PRESENT	0
748361	748099	19683J	PARTICIPANT	\N	PRESENT	0
748362	748099	11045K	PARTICIPANT	\N	PRESENT	0
748364	748099	20130U	PARTICIPANT	\N	PRESENT	0
751959	751957	14071N	PARTICIPANT	\N	PRESENT	0
751960	751957	14357A	PARTICIPANT	\N	PRESENT	0
751961	751957	14147R	PARTICIPANT	\N	PRESENT	0
751962	751957	14133K	PARTICIPANT	\N	PRESENT	0
751963	751957	10006L	PARTICIPANT	\N	PRESENT	0
751964	751957	20098N	PARTICIPANT	\N	PRESENT	0
751965	751957	20126Y	PARTICIPANT	\N	PRESENT	0
751966	751957	20138D	PARTICIPANT	\N	PRESENT	0
751967	751957	20172F	PARTICIPANT	\N	PRESENT	0
751969	751968	04033B	PARTICIPANT	\N	PRESENT	0
751970	751968	19647E	PARTICIPANT	\N	PRESENT	0
751971	751968	08034U	PARTICIPANT	\N	PRESENT	0
752810	752410	20060X	PARTICIPANT	\N	PRESENT	0
751973	751968	11012A	PARTICIPANT	\N	PRESENT	0
751974	751968	19515S	PARTICIPANT	\N	PRESENT	0
751975	751968	14217N	PARTICIPANT	\N	PRESENT	0
752106	752105	17737W	PARTICIPANT	\N	PRESENT	0
752812	752410	14151M	PARTICIPANT	\N	PRESENT	0
752811	752410	20248J	PARTICIPANT	\N	PRESENT	0
752813	752410	11110B	PARTICIPANT	\N	PRESENT	0
752814	752410	14187A	PARTICIPANT	\N	PRESENT	0
752815	752410	21062E	PARTICIPANT	\N	PRESENT	0
752816	752410	20100N	PARTICIPANT	\N	PRESENT	0
752817	752410	20132W	PARTICIPANT	\N	PRESENT	0
752818	752410	08045X	PARTICIPANT	\N	PRESENT	0
752819	752410	21032X	PARTICIPANT	\N	PRESENT	0
752820	752410	19347U	PARTICIPANT	\N	PRESENT	0
752821	752410	14123H	PARTICIPANT	\N	PRESENT	0
752822	752410	21089R	PARTICIPANT	\N	PRESENT	0
752823	752410	21085M	PARTICIPANT	\N	PRESENT	0
752824	752410	14021P	PARTICIPANT	\N	PRESENT	0
752825	752410	99004R	PARTICIPANT	\N	PRESENT	0
752826	752410	17779H	PARTICIPANT	\N	PRESENT	0
752827	752410	14251Q	PARTICIPANT	\N	PRESENT	0
752828	752410	20142Y	PARTICIPANT	\N	PRESENT	0
752829	752410	21029D	PARTICIPANT	\N	PRESENT	0
752830	752410	21039F	PARTICIPANT	\N	PRESENT	0
752831	752410	21037D	PARTICIPANT	\N	PRESENT	0
752832	752410	19593H	PARTICIPANT	\N	PRESENT	0
752833	752410	08061X	PARTICIPANT	\N	PRESENT	0
752834	752410	08047A	PARTICIPANT	\N	PRESENT	0
752835	752410	21047F	PARTICIPANT	\N	PRESENT	0
752836	752410	14193X	PARTICIPANT	\N	PRESENT	0
752837	752410	21053D	PARTICIPANT	\N	PRESENT	0
752838	752410	14257W	PARTICIPANT	\N	PRESENT	0
752839	752410	14109K	PARTICIPANT	\N	PRESENT	0
752840	752410	20118Y	PARTICIPANT	\N	PRESENT	0
752841	752410	05012A	PARTICIPANT	\N	PRESENT	0
752842	752410	17965H	PARTICIPANT	\N	PRESENT	0
752843	752410	19679N	PARTICIPANT	\N	PRESENT	0
752844	752410	20148F	PARTICIPANT	\N	PRESENT	0
752845	752410	20082E	PARTICIPANT	\N	PRESENT	0
752846	752410	20054A	PARTICIPANT	\N	PRESENT	0
752847	752410	11045K	PARTICIPANT	\N	PRESENT	0
752848	752410	20044X	PARTICIPANT	\N	PRESENT	0
752849	752410	19687N	PARTICIPANT	\N	PRESENT	0
752850	752410	04045F	PARTICIPANT	\N	PRESENT	0
752851	752410	21051B	PARTICIPANT	\N	PRESENT	0
752852	752410	21061D	PARTICIPANT	\N	PRESENT	0
752853	752410	21031W	PARTICIPANT	\N	PRESENT	0
752854	752410	20026V	PARTICIPANT	\N	PRESENT	0
752855	752410	20064C	PARTICIPANT	\N	PRESENT	0
752856	752410	21069M	PARTICIPANT	\N	PRESENT	0
752857	752410	19713W	PARTICIPANT	\N	PRESENT	0
752858	752410	14031R	PARTICIPANT	\N	PRESENT	0
752859	752410	14223L	PARTICIPANT	\N	PRESENT	0
752860	752410	20120S	PARTICIPANT	\N	PRESENT	0
752861	752410	19820Y	PARTICIPANT	\N	PRESENT	0
752866	752410	05008E	PARTICIPANT	\N	PRESENT	0
752864	752410	14133K	PARTICIPANT	\N	PRESENT	0
752865	752410	21042A	PARTICIPANT	\N	PRESENT	0
752867	752410	20094J	PARTICIPANT	\N	PRESENT	0
752868	752410	11040E	PARTICIPANT	\N	PRESENT	0
752869	752862	04070G	PARTICIPANT	\N	PRESENT	0
752870	752862	20056C	PARTICIPANT	\N	PRESENT	0
752871	752410	14217N	PARTICIPANT	\N	PRESENT	0
752872	752862	20134Y	PARTICIPANT	\N	PRESENT	1
752873	752410	20116W	PARTICIPANT	\N	PRESENT	0
752875	752410	21050A	PARTICIPANT	\N	PRESENT	0
752876	752410	14069U	PARTICIPANT	\N	PRESENT	0
752877	752410	20078J	PARTICIPANT	\N	PRESENT	0
752878	752410	19747H	PARTICIPANT	\N	PRESENT	0
752879	752410	19621T	PARTICIPANT	\N	PRESENT	0
752880	752410	19758L	PARTICIPANT	\N	PRESENT	0
752881	752410	04047H	PARTICIPANT	\N	PRESENT	0
752882	752410	20090E	PARTICIPANT	\N	PRESENT	0
752883	752410	21045D	PARTICIPANT	\N	PRESENT	0
752884	752410	14053L	PARTICIPANT	\N	PRESENT	0
752886	752410	15197G	PARTICIPANT	\N	PRESENT	0
752887	752410	14215L	PARTICIPANT	\N	PRESENT	0
752888	752410	20124W	PARTICIPANT	\N	PRESENT	0
752889	752410	21086N	PARTICIPANT	\N	PRESENT	0
752890	752410	20038A	PARTICIPANT	\N	PRESENT	0
752891	752410	17023S	PARTICIPANT	\N	PRESENT	0
752892	752410	20286Q	PARTICIPANT	\N	PRESENT	0
752893	752410	20172F	PARTICIPANT	\N	PRESENT	0
752894	752410	08056B	PARTICIPANT	\N	PRESENT	0
752895	752410	14033T	PARTICIPANT	\N	PRESENT	0
752896	752410	14026U	PARTICIPANT	\N	PRESENT	0
752897	752410	20068G	PARTICIPANT	\N	PRESENT	0
752898	752410	19725B	PARTICIPANT	\N	PRESENT	0
752899	752410	20128B	PARTICIPANT	\N	PRESENT	0
752900	752410	14179A	PARTICIPANT	\N	PRESENT	0
752901	752410	20062A	PARTICIPANT	\N	PRESENT	0
752902	752410	21083K	PARTICIPANT	\N	PRESENT	0
752903	752410	19489J	PARTICIPANT	\N	PRESENT	0
752904	752410	20138D	PARTICIPANT	\N	PRESENT	0
752905	752410	20020P	PARTICIPANT	\N	PRESENT	0
752906	752410	19479G	PARTICIPANT	\N	PRESENT	0
752907	752410	21076L	PARTICIPANT	\N	PRESENT	0
752908	752410	21064G	PARTICIPANT	\N	PRESENT	0
752909	752410	21072G	PARTICIPANT	\N	PRESENT	0
752910	752410	21070E	PARTICIPANT	\N	PRESENT	0
752911	752410	18395Y	PARTICIPANT	\N	PRESENT	0
752912	752410	14357A	PARTICIPANT	\N	PRESENT	0
752913	752410	04033B	PARTICIPANT	\N	PRESENT	0
752914	752410	19798U	PARTICIPANT	\N	PRESENT	0
752915	752410	21041Y	PARTICIPANT	\N	PRESENT	0
752916	752410	19719D	PARTICIPANT	\N	PRESENT	0
752917	752410	14225N	PARTICIPANT	\N	PRESENT	0
752918	752410	17229F	PARTICIPANT	\N	PRESENT	0
752919	752410	19866P	PARTICIPANT	\N	PRESENT	0
752920	752410	19826F	PARTICIPANT	\N	PRESENT	0
752921	752410	19691J	PARTICIPANT	\N	PRESENT	0
752922	752410	19553Y	PARTICIPANT	\N	PRESENT	0
752923	752410	21092L	PARTICIPANT	\N	PRESENT	0
752924	752410	14001X	PARTICIPANT	\N	PRESENT	0
752925	752410	11085T	PARTICIPANT	\N	PRESENT	0
752926	752410	21058J	PARTICIPANT	\N	PRESENT	0
752927	752410	08010L	PARTICIPANT	\N	PRESENT	0
752928	752410	21087P	PARTICIPANT	\N	PRESENT	0
752929	752410	04092N	PARTICIPANT	\N	PRESENT	0
752930	752410	19729F	PARTICIPANT	\N	PRESENT	0
752931	752410	11048N	PARTICIPANT	\N	PRESENT	0
752932	752410	18207D	PARTICIPANT	\N	PRESENT	0
752933	752410	12016W	PARTICIPANT	\N	PRESENT	0
752934	752410	21054E	PARTICIPANT	\N	PRESENT	0
752935	752410	08012N	PARTICIPANT	\N	PRESENT	0
752936	752410	14059S	PARTICIPANT	\N	PRESENT	0
752937	752410	14111D	PARTICIPANT	\N	PRESENT	0
752938	752410	21044C	PARTICIPANT	\N	PRESENT	0
752939	752410	19649G	PARTICIPANT	\N	PRESENT	0
752940	752410	19735D	PARTICIPANT	\N	PRESENT	0
752941	752410	21056G	PARTICIPANT	\N	PRESENT	0
752942	752410	19611R	PARTICIPANT	\N	PRESENT	0
752943	752410	08015R	PARTICIPANT	\N	PRESENT	0
752944	752410	21082J	PARTICIPANT	\N	PRESENT	0
752945	752410	20052X	PARTICIPANT	\N	PRESENT	0
752946	752410	19531S	PARTICIPANT	\N	PRESENT	0
752947	752410	14255U	PARTICIPANT	\N	PRESENT	0
752948	752410	18193Q	PARTICIPANT	\N	PRESENT	0
752949	752410	14231L	PARTICIPANT	\N	PRESENT	0
752950	752410	21066J	PARTICIPANT	\N	PRESENT	0
752951	752410	07033P	PARTICIPANT	\N	PRESENT	0
752952	752410	19723Y	PARTICIPANT	\N	PRESENT	0
752953	752410	19569H	PARTICIPANT	\N	PRESENT	0
752954	752410	19619A	PARTICIPANT	\N	PRESENT	0
752955	752410	19749K	PARTICIPANT	\N	PRESENT	0
752956	752410	20056C	PARTICIPANT	\N	PRESENT	0
752957	752410	19683J	PARTICIPANT	\N	PRESENT	0
752958	752410	20084G	PARTICIPANT	\N	PRESENT	0
743478	738440	11109J	PARTICIPANT	\N	EXCUSE	0
750444	748426	19593H	PARTICIPANT	\N	PRESENT	0
750445	748426	20264J	PARTICIPANT	\N	PRESENT	0
750446	748426	19611R	PRESIDENT	0	PRESENT	0
750447	748426	20172F	PARTICIPANT	\N	PRESENT	0
750448	748426	19673G	PARTICIPANT	\N	PRESENT	0
750450	748426	14147R	PARTICIPANT	\N	PRESENT	0
750451	748426	20048C	PARTICIPANT	\N	PRESENT	0
750452	748426	14123H	PARTICIPANT	\N	PRESENT	0
750455	748426	19729F	PARTICIPANT	\N	PRESENT	0
750456	748426	19693L	PARTICIPANT	\N	PRESENT	0
750465	748426	19749K	PARTICIPANT	\N	PRESENT	0
750469	748426	14089Y	PARTICIPANT	\N	PRESENT	0
750470	748426	14109K	PARTICIPANT	\N	PRESENT	0
750471	748426	20114U	PARTICIPANT	\N	PRESENT	0
750473	748426	20134Y	PARTICIPANT	\N	PRESENT	0
750477	748426	14215L	PARTICIPANT	\N	PRESENT	0
750478	748426	20022R	PARTICIPANT	\N	PRESENT	0
750484	748426	19621T	PARTICIPANT	\N	PRESENT	0
750487	748426	14179A	PARTICIPANT	\N	PRESENT	0
750489	748426	20980G	PARTICIPANT	\N	PRESENT	0
750493	748426	14069U	PARTICIPANT	\N	PRESENT	0
752143	752121	20098N	PARTICIPANT	\N	EXCUSE	0
752141	752121	20056C	PARTICIPANT	\N	EXCUSE	0
752142	752121	14109K	PARTICIPANT	\N	EXCUSE	0
752144	752121	19681G	PARTICIPANT	\N	EXCUSE	0
757170	754622	14030Q	PARTICIPANT	\N	PRESENT	0
757171	754622	20114U	PARTICIPANT	\N	PRESENT	0
757172	754622	21034A	PARTICIPANT	\N	PRESENT	0
757173	754622	19693L	PARTICIPANT	\N	PRESENT	0
757174	754622	21089R	PARTICIPANT	\N	PRESENT	0
757175	754622	21091K	PARTICIPANT	\N	PRESENT	0
757176	754622	20180F	PARTICIPANT	\N	PRESENT	0
757177	754622	21044C	PARTICIPANT	\N	PRESENT	0
757178	754622	20056C	PARTICIPANT	\N	PRESENT	0
757179	754622	14147R	PARTICIPANT	\N	PRESENT	0
757180	754622	07029T	PARTICIPANT	\N	PRESENT	0
757181	754622	18193Q	PARTICIPANT	\N	PRESENT	0
757182	754622	14223L	PARTICIPANT	\N	PRESENT	0
757183	754622	19866P	PARTICIPANT	\N	PRESENT	0
757184	754622	20130U	PARTICIPANT	\N	PRESENT	0
757185	754622	21038E	PARTICIPANT	\N	PRESENT	0
757186	754622	11045K	PARTICIPANT	\N	PRESENT	0
757187	754622	20098N	PARTICIPANT	\N	PRESENT	0
757188	754622	20062A	PARTICIPANT	\N	PRESENT	0
757189	754622	21094N	PARTICIPANT	\N	PRESENT	0
757190	754622	21061D	PARTICIPANT	\N	PRESENT	0
757191	754622	20046A	PARTICIPANT	\N	PRESENT	0
757192	754622	19749K	PRESIDENT	1	PRESENT	0
758169	758168	14042U	PARTICIPANT	\N	PRESENT	0
758170	758168	14026U	PARTICIPANT	\N	PRESENT	0
758174	758172	19760E	PARTICIPANT	\N	PRESENT	0
758175	758172	14042U	PARTICIPANT	\N	PRESENT	0
758176	758172	14213J	PARTICIPANT	\N	PRESENT	0
758177	758172	21087P	PARTICIPANT	\N	PRESENT	0
758190	758173	14042U	PARTICIPANT	\N	PRESENT	0
758192	758173	14213J	PARTICIPANT	\N	PRESENT	0
758375	758373	19699S	PARTICIPANT	\N	PRESENT	0
758664	758660	19573D	PARTICIPANT	\N	PRESENT	0
758700	758699	19573D	PARTICIPANT	\N	PRESENT	0
758708	758705	19573D	PARTICIPANT	\N	PRESENT	0
759182	759181	14215L	PARTICIPANT	\N	PRESENT	0
760871	760870	14267Y	PARTICIPANT	\N	PRESENT	0
760872	760870	12028B	PARTICIPANT	\N	PRESENT	0
760873	760870	08010L	PARTICIPANT	\N	PRESENT	0
760920	760919	19399H	PARTICIPANT	\N	PRESENT	0
760926	760925	20050V	PARTICIPANT	\N	PRESENT	0
760927	760925	14331P	PARTICIPANT	\N	PRESENT	0
760930	760929	20050V	PARTICIPANT	\N	PRESENT	0
760933	760932	20050V	PARTICIPANT	\N	PRESENT	0
764551	757841	20146D	PARTICIPANT	\N	PRESENT	0
764552	757841	19749K	PRESIDENT	0	PRESENT	0
764553	757841	20046A	PARTICIPANT	\N	PRESENT	0
764554	757841	19866P	PARTICIPANT	\N	PRESENT	0
764555	757841	14147R	PARTICIPANT	\N	PRESENT	0
764556	757841	14109K	PARTICIPANT	\N	PRESENT	0
764557	757841	21034A	PARTICIPANT	\N	PRESENT	0
764558	757841	14030Q	PARTICIPANT	\N	PRESENT	0
764559	757841	21038E	PARTICIPANT	\N	PRESENT	0
764560	757841	21042A	PARTICIPANT	\N	PRESENT	0
764561	757841	07029T	PARTICIPANT	\N	PRESENT	0
764562	757841	20180F	PARTICIPANT	\N	PRESENT	0
764563	757841	19693L	PARTICIPANT	\N	PRESENT	0
764564	757841	21094N	PARTICIPANT	\N	PRESENT	0
764572	757841	21087P	PARTICIPANT	\N	PRESENT	0
764621	757841	21061D	PARTICIPANT	\N	PRESENT	0
764776	757842	21042A	PARTICIPANT	\N	PRESENT	0
764777	757842	14030Q	PARTICIPANT	\N	PRESENT	0
764778	757842	21089R	PARTICIPANT	\N	PRESENT	0
764779	757842	19693L	PARTICIPANT	\N	PRESENT	0
764780	757842	20180F	PARTICIPANT	\N	PRESENT	0
764781	757842	07029T	PARTICIPANT	\N	PRESENT	0
764782	757842	21087P	PARTICIPANT	\N	PRESENT	0
764783	757842	14147R	PARTICIPANT	\N	PRESENT	0
764784	757842	14109K	PARTICIPANT	\N	PRESENT	0
764785	757842	19866P	PARTICIPANT	\N	PRESENT	0
764786	757842	21038E	PARTICIPANT	\N	PRESENT	0
764787	757842	21094N	PARTICIPANT	\N	PRESENT	0
764788	757842	21061D	PARTICIPANT	\N	PRESENT	0
764789	757842	20046A	PARTICIPANT	\N	PRESENT	0
764790	757842	19749K	PRESIDENT	0	PRESENT	0
764792	757842	21077M	PARTICIPANT	\N	PRESENT	0
764819	757842	21044C	PARTICIPANT	\N	PRESENT	0
764864	757842	20146D	PARTICIPANT	\N	PRESENT	0
764865	757842	21034A	PARTICIPANT	\N	PRESENT	0
765757	765756	14327T	PARTICIPANT	\N	PRESENT	0
765760	765759	14327T	PARTICIPANT	\N	PRESENT	0
765850	765845	19735D	PARTICIPANT	\N	PRESENT	1
765852	765844	20132W	PARTICIPANT	\N	PRESENT	1
765861	765489	21032X	PARTICIPANT	\N	EXCUSE	0
765863	765862	19611R	PARTICIPANT	\N	PRESENT	0
765864	765862	14030Q	PARTICIPANT	\N	PRESENT	0
765865	765862	21089R	PARTICIPANT	\N	PRESENT	0
766042	766041	14229S	PARTICIPANT	\N	PRESENT	0
766043	766041	19699S	PARTICIPANT	\N	PRESENT	0
766051	765489	21096Q	PARTICIPANT	\N	EXCUSE	0
766053	765163	20132W	PARTICIPANT	\N	PRESENT	0
766055	766054	20058E	PARTICIPANT	\N	PRESENT	1
766058	764910	14195A	PARTICIPANT	\N	PRESENT	0
766059	764910	19683J	PARTICIPANT	\N	PRESENT	0
766060	764910	21045D	PARTICIPANT	\N	PRESENT	0
766061	764910	19723Y	PARTICIPANT	\N	PRESENT	0
766062	764910	19679N	PARTICIPANT	\N	PRESENT	0
766063	764910	21081H	PARTICIPANT	\N	PRESENT	0
766064	764910	14223L	PARTICIPANT	\N	PRESENT	0
766065	764910	19691J	PARTICIPANT	\N	PRESENT	0
766066	764910	20140W	PARTICIPANT	\N	PRESENT	0
766067	764910	19798U	PARTICIPANT	\N	PRESENT	0
766068	764910	14217N	PARTICIPANT	\N	PRESENT	0
766069	764910	14213J	PARTICIPANT	\N	PRESENT	0
766070	764910	14026U	PARTICIPANT	\N	PRESENT	0
766071	764910	20148F	PARTICIPANT	\N	PRESENT	0
766072	764910	20096L	PARTICIPANT	\N	PRESENT	0
766073	764910	21071F	PARTICIPANT	\N	PRESENT	0
766074	764910	14071N	PRESIDENT	0	PRESENT	0
766075	764910	19367Y	PARTICIPANT	\N	PRESENT	0
766076	764910	20248J	PARTICIPANT	\N	PRESENT	0
766077	764910	19657G	PARTICIPANT	\N	PRESENT	0
766078	764910	14355X	PARTICIPANT	\N	PRESENT	0
766079	764910	04092N	PARTICIPANT	\N	PRESENT	0
766080	764910	20090E	PARTICIPANT	\N	PRESENT	0
766081	764910	19713W	PARTICIPANT	\N	PRESENT	0
766082	764910	14042U	PARTICIPANT	\N	PRESENT	0
766083	764910	19569H	PARTICIPANT	\N	PRESENT	0
766084	765400	86034E	PARTICIPANT	\N	PRESENT	0
766085	764910	19703U	PARTICIPANT	\N	PRESENT	0
766086	765400	18207D	PARTICIPANT	\N	PRESENT	0
766087	765400	20060X	PARTICIPANT	\N	PRESENT	0
766088	765400	20018V	PARTICIPANT	\N	PRESENT	0
766089	765400	20128B	PARTICIPANT	\N	PRESENT	0
766090	765400	21087P	PARTICIPANT	\N	PRESENT	0
766091	765400	21052C	PARTICIPANT	\N	PRESENT	0
766092	765400	19619A	PARTICIPANT	\N	PRESENT	0
766093	765400	19707Y	PARTICIPANT	\N	PRESENT	0
766094	765400	21039F	PARTICIPANT	\N	PRESENT	0
766095	765400	21057H	PARTICIPANT	\N	PRESENT	0
766096	765400	20088L	PARTICIPANT	\N	PRESENT	0
766097	765400	20102Q	PARTICIPANT	\N	PRESENT	0
766098	765400	14107H	PARTICIPANT	\N	PRESENT	0
766099	765400	21070E	PARTICIPANT	\N	PRESENT	0
766100	765400	19749K	PARTICIPANT	\N	PRESENT	0
766101	765400	14275Y	PARTICIPANT	\N	PRESENT	0
759617	757798	11043H	PARTICIPANT	\N	PRESENT	0
759618	757798	19331L	PARTICIPANT	\N	PRESENT	0
759619	757798	08061X	PARTICIPANT	\N	PRESENT	0
759620	757798	04033B	PARTICIPANT	\N	PRESENT	0
759621	757798	20146D	PARTICIPANT	\N	PRESENT	0
759622	757798	19349W	PARTICIPANT	\N	PRESENT	0
759623	757798	19679N	PARTICIPANT	\N	PRESENT	0
759624	757798	04045F	PARTICIPANT	\N	PRESENT	0
759625	757798	20062A	PARTICIPANT	\N	PRESENT	0
759626	757798	08034U	PARTICIPANT	\N	PRESENT	0
759627	757798	20110Q	PARTICIPANT	\N	PRESENT	0
759628	757798	21074J	PARTICIPANT	\N	PRESENT	0
759629	757798	14055N	PARTICIPANT	\N	PRESENT	0
759630	757798	14053L	PARTICIPANT	\N	PRESENT	0
759631	757798	19701S	PARTICIPANT	\N	PRESENT	0
759632	757798	14187A	PARTICIPANT	\N	PRESENT	0
759633	757798	14071N	PARTICIPANT	\N	PRESENT	0
759635	757798	05012A	PARTICIPANT	\N	PRESENT	0
759636	757798	20116W	PARTICIPANT	\N	PRESENT	0
759637	757798	20022R	PARTICIPANT	\N	PRESENT	0
759638	757798	14215L	PARTICIPANT	\N	PRESENT	0
759639	757798	21041Y	PARTICIPANT	\N	PRESENT	0
759640	757798	14193X	PARTICIPANT	\N	PRESENT	0
759641	757798	21072G	PARTICIPANT	\N	PRESENT	0
759642	757798	19667J	PARTICIPANT	\N	PRESENT	0
759643	757798	19719D	PARTICIPANT	\N	PRESENT	0
759644	757798	14253S	PARTICIPANT	\N	PRESENT	0
759646	757798	20032T	PARTICIPANT	\N	PRESENT	0
759647	757798	19387D	PARTICIPANT	\N	PRESENT	0
759648	757798	19553Y	PARTICIPANT	\N	PRESENT	0
759649	757798	14331P	PARTICIPANT	\N	PRESENT	0
759650	757798	14031R	PARTICIPANT	\N	PRESENT	0
759651	757798	20072C	PARTICIPANT	\N	PRESENT	0
759653	757798	20118Y	PARTICIPANT	\N	PRESENT	0
759656	757798	14069U	PARTICIPANT	\N	PRESENT	0
759658	757798	19798U	PARTICIPANT	\N	PRESENT	0
759659	757798	14195A	PARTICIPANT	\N	PRESENT	0
759660	757798	20252E	PARTICIPANT	\N	PRESENT	0
759661	757798	20120S	PARTICIPANT	\N	PRESENT	0
759662	757798	14217N	PARTICIPANT	\N	PRESENT	0
759663	757798	21090J	PARTICIPANT	\N	PRESENT	0
759664	757798	21065H	PARTICIPANT	\N	PRESENT	0
759665	757798	14211G	PARTICIPANT	\N	PRESENT	0
759667	757798	14147R	PARTICIPANT	\N	PRESENT	0
759669	757798	20122U	PARTICIPANT	\N	PRESENT	0
759671	757798	19954N	PARTICIPANT	\N	PRESENT	0
759672	757798	20026V	PARTICIPANT	\N	PRESENT	0
759673	757798	20180F	PARTICIPANT	\N	PRESENT	0
759674	757798	20096L	PARTICIPANT	\N	PRESENT	0
759675	757798	21058J	PARTICIPANT	\N	PRESENT	0
759676	757798	11056N	PARTICIPANT	\N	PRESENT	0
759677	757798	21068L	PARTICIPANT	\N	PRESENT	0
759678	757798	19565D	PARTICIPANT	\N	PRESENT	0
759679	757798	19447X	PARTICIPANT	\N	PRESENT	0
759680	757798	14173T	PARTICIPANT	\N	PRESENT	0
759681	757798	19593H	PARTICIPANT	\N	PRESENT	0
759682	757798	14038Y	PARTICIPANT	\N	PRESENT	0
759683	757798	19723Y	PARTICIPANT	\N	PRESENT	0
759684	757798	19631V	PARTICIPANT	\N	PRESENT	0
759685	757798	20038A	PARTICIPANT	\N	PRESENT	0
759686	757798	20140W	PARTICIPANT	\N	PRESENT	0
759687	757798	20114U	PARTICIPANT	\N	PRESENT	0
759688	757798	20080C	PARTICIPANT	\N	PRESENT	0
759689	757798	14033T	PARTICIPANT	\N	PRESENT	0
759690	757798	20060X	PARTICIPANT	\N	PRESENT	0
759691	757798	11027H	PARTICIPANT	\N	PRESENT	0
759692	757798	19399H	PARTICIPANT	\N	PRESENT	0
759693	757798	20104S	PARTICIPANT	\N	PRESENT	0
759694	757798	20264J	PARTICIPANT	\N	PRESENT	0
759695	757798	20108W	PARTICIPANT	\N	PRESENT	0
759696	757798	19251M	PARTICIPANT	\N	PRESENT	0
759697	757798	21067K	PARTICIPANT	\N	PRESENT	0
759698	757798	18395Y	PARTICIPANT	\N	PRESENT	0
759699	757798	11074Q	PARTICIPANT	\N	PRESENT	0
759700	757798	20024T	PARTICIPANT	\N	PRESENT	0
759701	757798	19647E	PARTICIPANT	\N	PRESENT	0
759702	757798	14281W	PARTICIPANT	\N	PRESENT	0
759703	757798	14357A	PARTICIPANT	\N	PRESENT	0
759704	757798	19383Y	PARTICIPANT	\N	PRESENT	0
759705	757798	08045X	PARTICIPANT	\N	PRESENT	0
759706	757798	19820Y	PARTICIPANT	\N	PRESENT	0
759707	757798	20098N	PARTICIPANT	\N	PRESENT	0
759708	757798	19725B	PARTICIPANT	\N	PRESENT	0
759709	757798	20020P	PARTICIPANT	\N	PRESENT	0
759710	757798	20054A	PARTICIPANT	\N	PRESENT	0
759711	757798	19531S	PARTICIPANT	\N	PRESENT	0
759712	757798	14021P	PARTICIPANT	\N	PRESENT	0
759713	757798	19489J	PARTICIPANT	\N	PRESENT	0
759714	757798	19649G	PARTICIPANT	\N	PRESENT	0
759716	757798	08012N	PARTICIPANT	\N	PRESENT	0
759717	757798	18207D	PARTICIPANT	\N	PRESENT	0
759718	757798	20124W	PARTICIPANT	\N	PRESENT	0
759719	757798	12016W	PARTICIPANT	\N	PRESENT	0
759720	757798	14001X	PARTICIPANT	\N	PRESENT	0
759721	757798	21036C	PARTICIPANT	\N	PRESENT	0
759722	757798	20018V	PARTICIPANT	\N	PRESENT	0
759723	757798	14109K	PARTICIPANT	\N	PRESENT	0
759724	757798	14257W	PARTICIPANT	\N	PRESENT	0
759725	757798	18231D	PARTICIPANT	\N	PRESENT	0
759727	757798	17737W	PARTICIPANT	\N	PRESENT	0
759728	757798	19705W	PARTICIPANT	\N	PRESENT	0
759729	757798	19768N	PARTICIPANT	\N	PRESENT	0
759730	757798	08015R	PARTICIPANT	\N	PRESENT	0
759731	757798	19729F	PARTICIPANT	\N	PRESENT	0
759732	757798	07029T	PARTICIPANT	\N	PRESENT	0
759733	757798	19709B	PARTICIPANT	\N	PRESENT	0
759734	757798	17965H	PARTICIPANT	\N	PRESENT	0
759735	757798	20068G	PARTICIPANT	\N	PRESENT	0
759736	757798	20058E	PARTICIPANT	\N	PRESENT	0
759737	757798	20082E	PARTICIPANT	\N	PRESENT	0
759738	757798	14229S	PARTICIPANT	\N	PRESENT	0
759739	757798	17779H	PARTICIPANT	\N	PRESENT	0
759740	757798	21056G	PARTICIPANT	\N	PRESENT	0
759741	757798	21094N	PARTICIPANT	\N	PRESENT	0
759742	757798	11045K	PARTICIPANT	\N	PRESENT	0
759743	757798	19669L	PARTICIPANT	\N	PRESENT	0
759744	757798	21051B	PARTICIPANT	\N	PRESENT	0
759745	757798	21031W	PARTICIPANT	\N	PRESENT	0
759747	757798	21077M	PARTICIPANT	\N	PRESENT	0
759748	757798	05008E	PARTICIPANT	\N	PRESENT	0
759751	757798	20126Y	PARTICIPANT	\N	PRESENT	0
759753	757798	21042A	PARTICIPANT	\N	PRESENT	0
759754	757798	21050A	PARTICIPANT	\N	PRESENT	0
759755	757798	14255U	PARTICIPANT	\N	PRESENT	0
759756	757798	19721W	PARTICIPANT	\N	PRESENT	0
759757	757798	20144B	PARTICIPANT	\N	PRESENT	0
759758	757798	11070L	PARTICIPANT	\N	PRESENT	0
759759	757798	14327T	PARTICIPANT	\N	PRESENT	0
759760	757798	14042U	PARTICIPANT	\N	PRESENT	0
759761	757798	19691J	PARTICIPANT	\N	PRESENT	0
759762	757798	11053K	PARTICIPANT	\N	PRESENT	0
759763	757798	14073Q	PARTICIPANT	\N	PRESENT	0
759764	757798	19697Q	PARTICIPANT	\N	PRESENT	0
759765	757798	19826F	PARTICIPANT	\N	PRESENT	0
759766	757798	19563B	PARTICIPANT	\N	PRESENT	0
759767	757798	04070G	PARTICIPANT	\N	PRESENT	0
759768	757798	19749K	PARTICIPANT	\N	PRESENT	0
759769	757798	01034P	PARTICIPANT	\N	PRESENT	0
759787	757798	21035B	PARTICIPANT	\N	PRESENT	0
759771	757798	21064G	PARTICIPANT	\N	PRESENT	0
759772	757798	11115U	PARTICIPANT	\N	PRESENT	0
759773	757798	20248J	PARTICIPANT	\N	PRESENT	0
759774	757798	20048C	PARTICIPANT	\N	PRESENT	0
759775	757798	14205J	PARTICIPANT	\N	PRESENT	0
759776	757798	14219Q	PARTICIPANT	\N	PRESENT	0
759777	757798	11085T	PARTICIPANT	\N	PRESENT	0
759778	757798	19569H	PARTICIPANT	\N	PRESENT	0
759779	757798	14231L	PARTICIPANT	\N	PRESENT	0
759780	757798	15197G	PARTICIPANT	\N	PRESENT	0
759781	757798	21038E	PARTICIPANT	\N	PRESENT	0
759782	757798	14179A	PARTICIPANT	\N	PRESENT	0
759783	757798	21085M	PARTICIPANT	\N	PRESENT	0
759784	757798	14189C	PARTICIPANT	\N	PRESENT	0
759785	757798	07004J	PARTICIPANT	\N	PRESENT	0
759786	757798	19745F	PARTICIPANT	\N	PRESENT	0
759788	757798	19611R	PARTICIPANT	\N	PRESENT	0
759789	757798	20056C	PARTICIPANT	\N	PRESENT	0
759790	757798	20070A	PARTICIPANT	\N	PRESENT	0
759791	757798	14237S	PARTICIPANT	\N	PRESENT	0
759792	757798	20172F	PARTICIPANT	\N	PRESENT	0
740446	740445	14073Q	PARTICIPANT	\N	PRESENT	0
740458	740457	11041F	PARTICIPANT	\N	PRESENT	0
740459	740457	08034U	PARTICIPANT	\N	PRESENT	0
740460	740457	19367Y	PARTICIPANT	\N	PRESENT	0
740461	740457	11101A	PARTICIPANT	\N	PRESENT	0
740462	740457	14179A	PARTICIPANT	\N	PRESENT	0
740463	740457	11085T	PARTICIPANT	\N	PRESENT	0
740464	740457	14147R	PARTICIPANT	\N	PRESENT	0
740465	740457	14223L	PARTICIPANT	\N	PRESENT	0
740848	740727	14151M	PARTICIPANT	\N	PRESENT	0
740849	740727	19649G	PARTICIPANT	\N	PRESENT	0
740850	740727	20108W	PARTICIPANT	\N	PRESENT	0
740851	740727	04008A	PARTICIPANT	\N	PRESENT	0
740852	740727	20064C	PARTICIPANT	\N	PRESENT	0
740856	740727	04085P	PARTICIPANT	\N	PRESENT	0
740857	740727	19651A	PARTICIPANT	\N	PRESENT	0
740858	740727	19543W	PARTICIPANT	\N	PRESENT	0
740859	740727	20134Y	PARTICIPANT	\N	PRESENT	0
740860	740727	11012A	PARTICIPANT	\N	PRESENT	0
740861	740727	14259Y	PARTICIPANT	\N	PRESENT	0
740862	740727	05008E	PARTICIPANT	\N	PRESENT	0
740863	740727	04047H	PARTICIPANT	\N	PRESENT	0
740864	740727	19749K	PARTICIPANT	\N	PRESENT	0
740865	740727	20022R	PARTICIPANT	\N	PRESENT	0
740866	740727	20038A	PARTICIPANT	\N	PRESENT	0
740867	740727	14249W	PARTICIPANT	\N	PRESENT	0
740868	740727	20122U	PARTICIPANT	\N	PRESENT	0
740869	740727	07029T	PARTICIPANT	\N	PRESENT	0
740870	740727	19447X	PARTICIPANT	\N	PRESENT	0
740871	740727	20098N	PARTICIPANT	\N	PRESENT	0
740872	740727	20032T	PARTICIPANT	\N	PRESENT	0
740886	740727	19611R	PARTICIPANT	\N	PRESENT	0
740890	740727	14147R	PARTICIPANT	\N	PRESENT	0
740892	740727	20112S	PARTICIPANT	\N	PRESENT	0
740893	740891	04070G	PARTICIPANT	\N	PRESENT	0
740894	740891	20064C	PRESIDENT	0	PRESENT	0
740895	740891	14251Q	PARTICIPANT	\N	PRESENT	0
740896	740891	14147R	PARTICIPANT	\N	PRESENT	0
740897	740891	11083R	PARTICIPANT	\N	PRESENT	0
740912	740727	14215L	PARTICIPANT	\N	PRESENT	0
740916	738366	19735D	PARTICIPANT	\N	EXCUSE	0
740917	738366	11109J	PARTICIPANT	\N	PRESENT	0
740918	738366	11043H	PARTICIPANT	\N	EXCUSE	0
740919	738366	14030Q	PARTICIPANT	\N	EXCUSE	0
740920	740727	19399H	PARTICIPANT	\N	PRESENT	0
740921	740727	08061X	PARTICIPANT	\N	PRESENT	0
740922	740727	14187A	PARTICIPANT	\N	PRESENT	0
740923	740727	20034V	PARTICIPANT	\N	PRESENT	0
740924	740727	20058E	PARTICIPANT	\N	PRESENT	0
740925	740727	20132W	PARTICIPANT	\N	PRESENT	0
740958	740728	19399H	PARTICIPANT	\N	PRESENT	0
740959	740728	19651A	PARTICIPANT	\N	PRESENT	0
740960	740728	04059M	PARTICIPANT	\N	PRESENT	0
740961	740728	19649G	PARTICIPANT	\N	PRESENT	0
740962	740728	11012A	PARTICIPANT	\N	PRESENT	0
740963	740728	20142Y	PARTICIPANT	\N	PRESENT	0
740964	740728	20134Y	PARTICIPANT	\N	PRESENT	0
740965	740728	20122U	PARTICIPANT	\N	PRESENT	0
740966	740728	20132W	PARTICIPANT	\N	PRESENT	0
740967	740728	20022R	PARTICIPANT	\N	PRESENT	0
740968	740728	14215L	PARTICIPANT	\N	PRESENT	0
740969	740728	20032T	PARTICIPANT	\N	PRESENT	0
740970	740728	14147R	PARTICIPANT	\N	PRESENT	0
740971	740728	20112S	PARTICIPANT	\N	PRESENT	0
740972	740728	19543W	PARTICIPANT	\N	PRESENT	0
740973	740728	19766L	PARTICIPANT	\N	PRESENT	0
740974	740728	14187A	PARTICIPANT	\N	PRESENT	0
740975	740728	20038A	PARTICIPANT	\N	PRESENT	0
740976	740728	20058E	PARTICIPANT	\N	PRESENT	0
740977	740728	20098N	PARTICIPANT	\N	PRESENT	0
740978	740728	11045K	PARTICIPANT	\N	PRESENT	0
740979	740728	04070G	PARTICIPANT	\N	PRESENT	0
740980	740728	11109J	PARTICIPANT	\N	PRESENT	0
740981	740728	14229S	PARTICIPANT	\N	PRESENT	0
740982	740728	20124W	PARTICIPANT	\N	PRESENT	0
740983	740891	14179A	PARTICIPANT	\N	PRESENT	0
741071	740753	20022R	PARTICIPANT	\N	EXCUSE	0
741073	740753	14053L	PARTICIPANT	\N	PRESENT	0
741074	740753	14111D	PARTICIPANT	\N	PRESENT	0
741075	740753	14215L	PRESIDENT	1	PRESENT	0
740956	740728	99004R	PARTICIPANT	\N	PRESENT	0
740957	740728	19611R	PARTICIPANT	\N	PRESENT	0
741076	740753	04047H	PRESIDENT	0	PRESENT	0
741077	740753	19447X	PARTICIPANT	\N	PRESENT	0
741078	740753	14231L	PARTICIPANT	\N	PRESENT	0
741079	740753	11072N	PARTICIPANT	\N	PRESENT	0
741080	740753	20074E	PARTICIPANT	\N	PRESENT	0
741081	740753	14147R	PARTICIPANT	\N	PRESENT	0
741082	740753	19729F	PARTICIPANT	\N	EXCUSE	0
741107	740832	19741B	PARTICIPANT	\N	PRESENT	0
741109	741072	14038Y	PARTICIPANT	\N	PRESENT	0
741110	741072	19593H	PARTICIPANT	\N	PRESENT	0
741111	741072	04070G	PRESIDENT	0	PRESENT	0
741112	741072	20132W	PARTICIPANT	\N	PRESENT	0
741113	741072	20034V	PARTICIPANT	\N	PRESENT	0
741114	741072	20138D	PARTICIPANT	\N	PRESENT	0
741115	741072	20140W	PARTICIPANT	\N	PRESENT	0
741116	741072	11045K	PARTICIPANT	\N	PRESENT	0
741117	741072	20082E	PARTICIPANT	\N	PRESENT	0
741118	741072	20094J	PARTICIPANT	\N	PRESENT	0
741119	741072	20152B	PARTICIPANT	\N	PRESENT	0
741120	741072	20052X	PARTICIPANT	\N	PRESENT	0
741121	741072	20096L	PARTICIPANT	\N	PRESENT	0
741122	741072	14229S	PARTICIPANT	\N	PRESENT	0
741123	741072	14030Q	PARTICIPANT	\N	PRESENT	0
741124	741072	14147R	PARTICIPANT	\N	PRESENT	0
741125	741072	14179A	PARTICIPANT	\N	PRESENT	0
741126	741072	14151M	PARTICIPANT	\N	PRESENT	0
741127	741072	20128B	PARTICIPANT	\N	PRESENT	0
741128	741072	14189C	PARTICIPANT	\N	EXCUSE	0
741161	739429	20180F	PARTICIPANT	\N	PRESENT	0
741162	739429	19575F	PARTICIPANT	\N	PRESENT	0
741163	739429	11053K	PARTICIPANT	\N	PRESENT	0
741164	739429	19251M	PRESIDENT	0	PRESENT	0
741165	739429	20052X	PARTICIPANT	\N	PRESENT	0
741166	739429	14357A	PARTICIPANT	\N	PRESENT	0
741167	739429	20084G	PARTICIPANT	\N	PRESENT	0
741168	739429	19762G	PARTICIPANT	\N	PRESENT	0
741169	739429	20092G	PARTICIPANT	\N	PRESENT	0
741174	741106	14026U	PARTICIPANT	\N	PRESENT	0
741175	741106	19511N	PARTICIPANT	\N	PRESENT	0
741176	741106	20068G	PARTICIPANT	\N	PRESENT	0
741177	741106	14089Y	PARTICIPANT	\N	PRESENT	0
741178	741106	19649G	PARTICIPANT	\N	PRESENT	0
741179	741106	19671E	PARTICIPANT	\N	PRESENT	0
741180	741106	19629C	PARTICIPANT	\N	PRESENT	0
741181	741106	19866P	PARTICIPANT	\N	PRESENT	0
741182	741106	11041F	PARTICIPANT	\N	PRESENT	0
741183	741106	20090E	PARTICIPANT	\N	PRESENT	0
741184	741106	20102Q	PARTICIPANT	\N	PRESENT	0
741185	741106	19333N	PARTICIPANT	\N	PRESENT	0
741186	741106	14097Y	PARTICIPANT	\N	PRESENT	0
741187	741106	19413M	PARTICIPANT	\N	PRESENT	0
741188	741106	12028B	PARTICIPANT	\N	PRESENT	0
741189	741106	20082E	PARTICIPANT	\N	PRESENT	0
741190	741106	20030R	PARTICIPANT	\N	PRESENT	0
741191	741106	18193Q	PARTICIPANT	\N	PRESENT	0
741192	741106	19503N	PARTICIPANT	\N	PRESENT	0
741193	741106	11067R	PARTICIPANT	\N	PRESENT	0
741194	741106	04085P	PARTICIPANT	\N	PRESENT	0
741195	741106	19687N	PARTICIPANT	\N	PRESENT	0
741196	741106	19695N	PARTICIPANT	\N	PRESENT	0
741197	741106	11056N	PARTICIPANT	\N	PRESENT	0
741198	741106	19758L	PARTICIPANT	\N	PRESENT	0
741199	741106	11040E	PARTICIPANT	\N	PRESENT	0
741200	741106	11031D	PARTICIPANT	\N	PRESENT	0
741201	741106	19599P	PARTICIPANT	\N	PRESENT	0
741202	741106	19715Y	PARTICIPANT	\N	PRESENT	0
741203	741106	12016W	PARTICIPANT	\N	PRESENT	0
741204	741106	17779H	PARTICIPANT	\N	PRESENT	0
741205	741106	14225N	PARTICIPANT	\N	PRESENT	0
741206	741106	11074Q	PARTICIPANT	\N	PRESENT	0
741207	741106	19760E	PARTICIPANT	\N	PRESENT	0
741208	741106	11077T	PARTICIPANT	\N	PRESENT	0
741209	741106	19565D	PARTICIPANT	\N	PRESENT	0
741210	741106	14001X	PARTICIPANT	\N	PRESENT	0
741211	741106	20046A	PARTICIPANT	\N	PRESENT	0
741212	741106	20110Q	PARTICIPANT	\N	PRESENT	0
741213	741106	20914V	PARTICIPANT	\N	PRESENT	0
741214	741106	20100N	PARTICIPANT	\N	PRESENT	0
741215	741106	20130U	PARTICIPANT	\N	PRESENT	0
753151	753150	08034U	PARTICIPANT	\N	PRESENT	0
753155	752411	21044C	PARTICIPANT	\N	PRESENT	0
753153	752411	86034E	PARTICIPANT	\N	PRESENT	0
753154	752411	14179A	PARTICIPANT	\N	PRESENT	0
753156	752411	20024T	PARTICIPANT	\N	PRESENT	0
753160	752411	20286Q	PARTICIPANT	\N	PRESENT	0
753158	752411	21029D	PARTICIPANT	\N	PRESENT	0
753159	752411	21068L	PARTICIPANT	\N	PRESENT	0
753161	752411	19866P	PARTICIPANT	\N	PRESENT	0
753162	752411	14195A	PARTICIPANT	\N	PRESENT	0
753163	752411	20070A	PARTICIPANT	\N	PRESENT	0
753164	752411	21049H	PARTICIPANT	\N	PRESENT	0
753165	752411	21042A	PARTICIPANT	\N	PRESENT	0
753166	752411	20028X	PARTICIPANT	\N	PRESENT	0
753167	752411	21064G	PARTICIPANT	\N	PRESENT	0
753168	752411	20030R	PARTICIPANT	\N	PRESENT	0
753169	752411	21070E	PARTICIPANT	\N	PRESENT	0
753170	752411	20088L	PARTICIPANT	\N	PRESENT	0
753171	752411	21037D	PARTICIPANT	\N	PRESENT	0
753172	752411	19347U	PARTICIPANT	\N	PRESENT	0
753173	752411	19575F	PARTICIPANT	\N	PRESENT	0
753174	752411	01058X	PARTICIPANT	\N	PRESENT	0
753175	752411	14215L	PARTICIPANT	\N	PRESENT	0
753176	752411	18083K	PARTICIPANT	\N	PRESENT	0
753177	752411	20080C	PARTICIPANT	\N	PRESENT	0
753178	752411	08028W	PARTICIPANT	\N	PRESENT	0
753179	752411	19593H	PARTICIPANT	\N	PRESENT	0
753180	752411	10015M	PARTICIPANT	\N	PRESENT	0
753181	752411	14223L	PARTICIPANT	\N	PRESENT	0
753182	752411	11056N	PARTICIPANT	\N	PRESENT	0
753183	752411	14357A	PARTICIPANT	\N	PRESENT	0
753184	752411	05012A	PARTICIPANT	\N	PRESENT	0
753185	752411	18395Y	PARTICIPANT	\N	PRESENT	0
753186	752411	20032T	PARTICIPANT	\N	PRESENT	0
753187	752411	14169X	PARTICIPANT	\N	PRESENT	0
753188	752411	14229S	PARTICIPANT	\N	PRESENT	0
753189	752411	20054A	PARTICIPANT	\N	PRESENT	0
753190	752411	20038A	PARTICIPANT	\N	PRESENT	0
753191	752411	14187A	PARTICIPANT	\N	PRESENT	0
753192	752411	04092N	PARTICIPANT	\N	PRESENT	0
753193	752411	21058J	PARTICIPANT	\N	PRESENT	0
753194	752411	20172F	PARTICIPANT	\N	PRESENT	0
753195	752411	19954N	PARTICIPANT	\N	PRESENT	0
753196	752411	21039F	PARTICIPANT	\N	PRESENT	0
753197	752411	19621T	PARTICIPANT	\N	PRESENT	0
753198	752411	14217N	PARTICIPANT	\N	PRESENT	0
753199	752411	14213J	PARTICIPANT	\N	PRESENT	0
753200	752411	20180F	PARTICIPANT	\N	PRESENT	0
753201	752411	08056B	PARTICIPANT	\N	PRESENT	0
753202	752411	19798U	PARTICIPANT	\N	PRESENT	0
753203	752411	08015R	PARTICIPANT	\N	PRESENT	0
753204	752411	19723Y	PARTICIPANT	\N	PRESENT	0
753205	752411	14026U	PARTICIPANT	\N	PRESENT	0
753206	752411	21047F	PARTICIPANT	\N	PRESENT	0
753207	752411	20044X	PARTICIPANT	\N	PRESENT	0
753208	752411	07029T	PARTICIPANT	\N	PRESENT	0
753209	752411	19629C	PARTICIPANT	\N	PRESENT	0
753210	752411	20132W	PARTICIPANT	\N	PRESENT	0
753211	752411	19479G	PARTICIPANT	\N	PRESENT	0
753212	752411	19553Y	PARTICIPANT	\N	PRESENT	0
753213	752411	18193Q	PARTICIPANT	\N	PRESENT	0
753214	752411	21082J	PARTICIPANT	\N	PRESENT	0
753215	752411	14121F	PARTICIPANT	\N	PRESENT	0
753216	752411	19647E	PARTICIPANT	\N	PRESENT	0
753217	752411	19413M	PARTICIPANT	\N	PRESENT	0
753218	752411	19760E	PARTICIPANT	\N	PRESENT	0
753219	752411	21072G	PARTICIPANT	\N	PRESENT	0
753220	752411	20018V	PARTICIPANT	\N	PRESENT	0
753221	752411	14207L	PARTICIPANT	\N	PRESENT	0
753222	752411	20144B	PARTICIPANT	\N	PRESENT	0
753223	752411	14030Q	PARTICIPANT	\N	PRESENT	0
753224	752411	14189C	PARTICIPANT	\N	PRESENT	0
753225	752411	11085T	PARTICIPANT	\N	PRESENT	0
753226	752411	19691J	PARTICIPANT	\N	PRESENT	0
753227	752411	19569H	PARTICIPANT	\N	PRESENT	0
753228	752411	14042U	PARTICIPANT	\N	PRESENT	0
753229	752411	19745F	PARTICIPANT	\N	PRESENT	0
753230	752411	14111D	PARTICIPANT	\N	PRESENT	0
753231	752411	20142Y	PARTICIPANT	\N	PRESENT	0
753232	752411	21054E	PARTICIPANT	\N	PRESENT	0
753233	752411	20072C	PARTICIPANT	\N	PRESENT	0
753234	752411	21083K	PARTICIPANT	\N	PRESENT	0
753235	752411	14107H	PARTICIPANT	\N	PRESENT	0
753236	752411	21034A	PARTICIPANT	\N	PRESENT	0
753237	752411	20112S	PARTICIPANT	\N	PRESENT	0
753238	752411	21056G	PARTICIPANT	\N	PRESENT	0
753239	752411	20084G	PARTICIPANT	\N	PRESENT	0
753240	752411	18207D	PARTICIPANT	\N	PRESENT	0
753241	752411	19631V	PARTICIPANT	\N	PRESENT	0
753242	752411	19725B	PARTICIPANT	\N	PRESENT	0
753243	752411	21062E	PARTICIPANT	\N	PRESENT	0
753244	752411	20092G	PARTICIPANT	\N	PRESENT	0
753245	752411	21048G	PARTICIPANT	\N	PRESENT	0
753246	752411	14083S	PARTICIPANT	\N	PRESENT	0
753247	752411	19826F	PARTICIPANT	\N	PRESENT	0
753248	752411	20124W	PARTICIPANT	\N	PRESENT	0
753250	752411	14133K	PARTICIPANT	\N	PRESENT	0
753581	752387	14030Q	PARTICIPANT	\N	PRESENT	0
753582	752387	14147R	PARTICIPANT	\N	PRESENT	0
753583	752387	20140W	PARTICIPANT	\N	PRESENT	0
753584	752387	20034V	PARTICIPANT	\N	PRESENT	0
753585	752387	14038Y	PARTICIPANT	\N	PRESENT	0
753586	752387	10015M	PRESIDENT	0	PRESENT	0
753587	752387	04070G	PRESIDENT	1	PRESENT	0
753588	752387	11045K	PARTICIPANT	\N	PRESENT	0
753589	752387	14237S	PARTICIPANT	\N	PRESENT	0
753590	752387	20134Y	PARTICIPANT	\N	PRESENT	0
753591	752387	20128B	PARTICIPANT	\N	PRESENT	0
753592	752387	20094J	PARTICIPANT	\N	PRESENT	0
753593	752387	21037D	PARTICIPANT	\N	PRESENT	0
753677	753676	19545Y	PARTICIPANT	\N	PRESENT	0
753678	753676	21086N	PARTICIPANT	\N	PRESENT	0
753679	753676	99004R	PARTICIPANT	\N	PRESENT	0
753680	753676	08034U	PARTICIPANT	\N	PRESENT	0
753681	753676	05012A	PARTICIPANT	\N	PRESENT	0
753682	753676	14121F	PARTICIPANT	\N	PRESENT	0
753683	753676	20080C	PARTICIPANT	\N	PRESENT	0
753684	753676	19711U	PARTICIPANT	\N	PRESENT	0
753688	753252	20032T	PARTICIPANT	\N	PRESENT	0
753689	753252	21042A	PARTICIPANT	\N	PRESENT	0
753690	753252	20076G	PARTICIPANT	\N	PRESENT	0
753691	753252	21084L	PARTICIPANT	\N	PRESENT	0
753692	753252	21035B	PARTICIPANT	\N	PRESENT	0
753693	753252	08060W	PARTICIPANT	\N	PRESENT	0
753694	753252	21065H	PARTICIPANT	\N	PRESENT	0
753695	753252	18083K	PARTICIPANT	\N	PRESENT	0
753696	753252	19701S	PARTICIPANT	\N	PRESENT	0
753697	753252	19681G	PARTICIPANT	\N	PRESENT	0
753698	753252	11065P	PARTICIPANT	\N	PRESENT	0
753699	753252	17229F	PARTICIPANT	\N	EXCUSE	0
753700	753252	19251M	PARTICIPANT	\N	PRESENT	0
753701	753252	15197G	PARTICIPANT	\N	PRESENT	0
753702	753252	21062E	PARTICIPANT	\N	PRESENT	0
753703	753252	20100N	PARTICIPANT	\N	PRESENT	0
753704	753252	20120S	PARTICIPANT	\N	PRESENT	0
753705	753252	19820Y	PARTICIPANT	\N	PRESENT	0
753706	753252	19387D	PARTICIPANT	\N	PRESENT	0
753707	753252	20068G	PARTICIPANT	\N	PRESENT	0
753708	753252	20106U	PARTICIPANT	\N	PRESENT	0
753711	753252	19551W	PARTICIPANT	\N	PRESENT	0
753712	753252	14219Q	PRESIDENT	0	PRESENT	0
753713	753252	14031R	PARTICIPANT	\N	PRESENT	0
753714	753252	19826F	PARTICIPANT	\N	PRESENT	0
753715	753252	21080G	PARTICIPANT	\N	PRESENT	0
753716	753252	21029D	PARTICIPANT	\N	EXCUSE	0
753717	753252	21039F	PARTICIPANT	\N	PRESENT	0
753718	753252	14169X	PRESIDENT	1	PRESENT	0
753719	753252	19331L	PARTICIPANT	\N	PRESENT	0
753720	753252	21060C	PARTICIPANT	\N	PRESENT	0
753721	753252	14237S	PARTICIPANT	\N	PRESENT	0
753722	753252	21047F	PARTICIPANT	\N	PRESENT	0
753723	753252	20146D	PARTICIPANT	\N	PRESENT	0
753724	753252	21053D	PARTICIPANT	\N	PRESENT	0
753725	753252	20118Y	PARTICIPANT	\N	PRESENT	0
753726	753252	05012A	PARTICIPANT	\N	PRESENT	0
753727	753252	21068L	PARTICIPANT	\N	PRESENT	0
753728	753252	21070E	PARTICIPANT	\N	PRESENT	0
753729	753252	20020P	PARTICIPANT	\N	PRESENT	0
753730	753252	14107H	PARTICIPANT	\N	PRESENT	0
748165	748164	08015R	PARTICIPANT	\N	PRESENT	0
748166	748164	20104S	PARTICIPANT	\N	PRESENT	0
748384	748102	14026U	PARTICIPANT	\N	PRESENT	0
748385	748102	11067R	PARTICIPANT	\N	PRESENT	0
748386	748102	19649G	PARTICIPANT	\N	PRESENT	0
748387	748102	14281W	PARTICIPANT	\N	PRESENT	0
748388	748102	19319Q	PARTICIPANT	\N	PRESENT	0
748389	748102	19741B	PARTICIPANT	\N	PRESENT	0
748390	748102	19335Q	PARTICIPANT	\N	PRESENT	0
748391	748102	14355X	PARTICIPANT	\N	PRESENT	0
748392	748102	14111D	PARTICIPANT	\N	PRESENT	0
748394	748102	19768N	PARTICIPANT	\N	PRESENT	0
748395	748102	14033T	PARTICIPANT	\N	PRESENT	0
748396	748102	20024T	PARTICIPANT	\N	PRESENT	0
748397	748102	19679N	PARTICIPANT	\N	PRESENT	0
748398	748102	19565D	PARTICIPANT	\N	PRESENT	0
748399	748102	19719D	PARTICIPANT	\N	PRESENT	0
748400	748102	19553Y	PARTICIPANT	\N	PRESENT	0
748401	748102	19798U	PARTICIPANT	\N	PRESENT	0
748402	748102	20056C	PARTICIPANT	\N	PRESENT	0
748403	748102	20096L	PARTICIPANT	\N	PRESENT	0
748404	748102	20054A	PARTICIPANT	\N	PRESENT	0
748405	748102	08073C	PARTICIPANT	\N	PRESENT	0
748406	748102	10006L	PARTICIPANT	\N	PRESENT	0
748407	748102	20286Q	PARTICIPANT	\N	PRESENT	0
748408	748102	14083S	PARTICIPANT	\N	PRESENT	0
748409	748102	20058E	PARTICIPANT	\N	PRESENT	0
748410	748102	14191V	PARTICIPANT	\N	PRESENT	0
748411	748102	20172F	PARTICIPANT	\N	PRESENT	0
748412	748102	19527W	PARTICIPANT	\N	PRESENT	0
748413	748102	11115U	PARTICIPANT	\N	PRESENT	0
748414	748102	17589D	PARTICIPANT	\N	PRESENT	0
748415	748102	01024M	PARTICIPANT	\N	PRESENT	0
748416	748102	20122U	PARTICIPANT	\N	PRESENT	0
748417	748102	14147R	PARTICIPANT	\N	PRESENT	0
748418	748102	11040E	PARTICIPANT	\N	PRESENT	0
748419	748102	19693L	PARTICIPANT	\N	PRESENT	0
748420	748102	19441R	PARTICIPANT	\N	PRESENT	0
748421	748102	20088L	PARTICIPANT	\N	PRESENT	0
748422	748102	19782L	PARTICIPANT	\N	PRESENT	0
748423	748102	20126Y	PARTICIPANT	\N	PRESENT	0
748424	748102	19611R	PARTICIPANT	\N	PRESENT	0
748425	748102	20032T	PARTICIPANT	\N	PRESENT	0
748427	748102	11031D	PARTICIPANT	\N	PRESENT	0
748429	748102	20138D	PARTICIPANT	\N	PRESENT	0
748430	748102	20026V	PARTICIPANT	\N	PRESENT	0
748431	748102	01048V	PARTICIPANT	\N	PRESENT	0
748432	748102	20914V	PARTICIPANT	\N	PRESENT	0
748433	748102	14205J	PARTICIPANT	\N	PRESENT	0
748434	748102	11045K	PARTICIPANT	\N	PRESENT	0
748435	748102	14107H	PARTICIPANT	\N	PRESENT	0
748436	748102	19301E	PARTICIPANT	\N	PRESENT	0
748437	748102	20120S	PARTICIPANT	\N	PRESENT	0
748452	747871	19768N	PARTICIPANT	\N	PRESENT	0
748453	747871	10015M	PARTICIPANT	\N	PRESENT	0
748454	747871	14179A	PARTICIPANT	\N	PRESENT	0
748455	747871	20096L	PARTICIPANT	\N	PRESENT	0
748456	747871	20132W	PARTICIPANT	\N	PRESENT	0
748457	747871	20134Y	PARTICIPANT	\N	PRESENT	0
748458	747871	20034V	PARTICIPANT	\N	PRESENT	0
748446	747871	04070G	PRESIDENT	0	PRESENT	0
748447	747871	14237S	PARTICIPANT	\N	EXCUSE	0
748448	747871	14189C	PARTICIPANT	\N	EXCUSE	0
748449	747871	14038Y	PARTICIPANT	\N	PRESENT	0
748450	747871	20140W	PARTICIPANT	\N	PRESENT	0
748451	747871	20152B	PARTICIPANT	\N	PRESENT	0
748459	747871	19651A	PARTICIPANT	\N	PRESENT	0
748460	747871	11045K	PARTICIPANT	\N	PRESENT	0
748461	747871	20082E	PARTICIPANT	\N	PRESENT	0
748462	747871	20094J	PARTICIPANT	\N	PRESENT	0
748463	747871	19719D	PARTICIPANT	\N	PRESENT	0
748464	747871	14229S	PARTICIPANT	\N	PRESENT	0
748465	747871	14030Q	PARTICIPANT	\N	PRESENT	0
748466	747871	14205J	PARTICIPANT	\N	PRESENT	0
748467	747871	14147R	PARTICIPANT	\N	PRESENT	0
748468	747871	20060X	PARTICIPANT	\N	PRESENT	0
748477	748103	08015R	PARTICIPANT	\N	PRESENT	0
748490	748103	19798U	PARTICIPANT	\N	PRESENT	0
748491	748103	19591F	PARTICIPANT	\N	PRESENT	0
748492	748103	18193Q	PARTICIPANT	\N	PRESENT	0
748494	748103	19760E	PARTICIPANT	\N	PRESENT	0
748496	748103	19691J	PARTICIPANT	\N	PRESENT	0
748499	748103	19553Y	PARTICIPANT	\N	PRESENT	0
748500	748103	20138D	PARTICIPANT	\N	PRESENT	0
748501	748103	04057K	PARTICIPANT	\N	PRESENT	0
748503	748103	20266L	PARTICIPANT	\N	PRESENT	0
748504	748103	20180F	PARTICIPANT	\N	PRESENT	0
748506	748103	19507S	PARTICIPANT	\N	PRESENT	0
748507	748103	14223L	PARTICIPANT	\N	PRESENT	0
748508	748103	14179A	PARTICIPANT	\N	PRESENT	0
748510	748103	10006L	PARTICIPANT	\N	PRESENT	0
748527	748103	19479G	PARTICIPANT	\N	PRESENT	0
748512	748103	19651A	PARTICIPANT	\N	PRESENT	0
748513	748103	20062A	PARTICIPANT	\N	PRESENT	0
748514	748103	19729F	PARTICIPANT	\N	PRESENT	0
748515	748103	08045X	PARTICIPANT	\N	PRESENT	0
748516	748103	19683J	PARTICIPANT	\N	PRESENT	0
748517	748103	14281W	PARTICIPANT	\N	PRESENT	0
748518	748103	19333N	PARTICIPANT	\N	PRESENT	0
748519	748103	01062T	PARTICIPANT	\N	PRESENT	0
748520	748103	19782L	PARTICIPANT	\N	PRESENT	0
748521	748103	14073Q	PARTICIPANT	\N	PRESENT	0
748522	748103	19681G	PARTICIPANT	\N	PRESENT	0
748523	748103	18083K	PARTICIPANT	\N	PRESENT	0
748524	748103	97011G	PARTICIPANT	\N	PRESENT	0
748525	748103	20076G	PARTICIPANT	\N	PRESENT	0
748526	748103	01057W	PARTICIPANT	\N	PRESENT	0
748536	748103	20248J	PARTICIPANT	\N	PRESENT	0
748529	748103	14030Q	PARTICIPANT	\N	PRESENT	0
748530	748103	14038Y	PARTICIPANT	\N	PRESENT	0
748532	748103	14121F	PARTICIPANT	\N	PRESENT	0
748533	748103	19577H	PARTICIPANT	\N	PRESENT	0
748534	748103	19387D	PARTICIPANT	\N	PRESENT	0
748535	748103	20082E	PARTICIPANT	\N	PRESENT	0
748537	748103	20044X	PARTICIPANT	\N	PRESENT	0
748538	748103	19758L	PARTICIPANT	\N	PRESENT	0
748539	748103	19565D	PARTICIPANT	\N	PRESENT	0
748540	748103	12041X	PARTICIPANT	\N	PRESENT	0
748541	748103	20098N	PARTICIPANT	\N	PRESENT	0
748542	748103	14021P	PARTICIPANT	\N	PRESENT	0
748543	748103	14217N	PARTICIPANT	\N	PRESENT	0
748544	748103	14193X	PARTICIPANT	\N	PRESENT	0
748545	748103	19723Y	PARTICIPANT	\N	PRESENT	0
748546	748103	14189C	PARTICIPANT	\N	PRESENT	0
748547	748103	11097X	PARTICIPANT	\N	PRESENT	0
748548	748103	20022R	PARTICIPANT	\N	PRESENT	0
748549	748103	14147R	PARTICIPANT	\N	PRESENT	0
748552	748103	20032T	PARTICIPANT	\N	PRESENT	0
748553	748103	20066E	PARTICIPANT	\N	PRESENT	0
748554	748167	19479G	PARTICIPANT	\N	PRESENT	0
748555	748167	11048N	PARTICIPANT	\N	PRESENT	0
748556	748167	20252E	PARTICIPANT	\N	PRESENT	0
748557	748167	08009T	PARTICIPANT	\N	PRESENT	0
748558	748167	20914V	PRESIDENT	1	PRESENT	0
748559	748167	20044X	PARTICIPANT	\N	PRESENT	0
748560	748167	14225N	PRESIDENT	0	PRESENT	0
748561	748103	19415P	PARTICIPANT	\N	PRESENT	0
748562	748167	01057W	PARTICIPANT	\N	PRESENT	0
748563	748103	19563B	PARTICIPANT	\N	PRESENT	0
748564	748167	99004R	PARTICIPANT	\N	PRESENT	0
748565	748167	19671E	PARTICIPANT	\N	PRESENT	0
748566	748167	19762G	PARTICIPANT	\N	PRESENT	0
748567	748167	20080C	PARTICIPANT	\N	PRESENT	0
748568	748103	20034V	PARTICIPANT	\N	PRESENT	0
748569	748167	14331P	PARTICIPANT	\N	PRESENT	0
748570	748167	19647E	PARTICIPANT	\N	PRESENT	0
748571	748167	01048V	PARTICIPANT	\N	PRESENT	0
748572	748167	14189C	PARTICIPANT	\N	PRESENT	0
748573	748167	19687N	PARTICIPANT	\N	PRESENT	0
748574	748167	14083S	PARTICIPANT	\N	PRESENT	0
748575	748167	08073C	PARTICIPANT	\N	PRESENT	0
748576	748103	20026V	PARTICIPANT	\N	PRESENT	0
748577	748103	14259Y	PARTICIPANT	\N	PRESENT	0
748578	748103	14111D	PARTICIPANT	\N	PRESENT	0
748579	748103	14221J	PARTICIPANT	\N	PRESENT	0
748580	748167	19711U	PARTICIPANT	\N	PRESENT	0
748581	748167	11040E	PARTICIPANT	\N	PRESENT	0
748582	748167	14121F	PARTICIPANT	\N	PRESENT	0
748583	748167	08010L	PARTICIPANT	\N	PRESENT	0
748584	748103	14191V	PARTICIPANT	\N	PRESENT	0
748585	748167	11012A	PARTICIPANT	\N	PRESENT	0
759793	757798	14213J	PARTICIPANT	\N	PRESENT	0
759794	757798	19685L	PARTICIPANT	\N	PRESENT	0
759795	757798	20148F	PARTICIPANT	\N	PRESENT	0
759796	757798	17023S	PARTICIPANT	\N	PRESENT	0
759799	759797	14217N	PARTICIPANT	\N	PRESENT	0
759800	759797	19798U	PARTICIPANT	\N	PRESENT	0
759802	757798	19507S	PARTICIPANT	\N	PRESENT	0
759803	759801	14217N	PARTICIPANT	\N	PRESENT	0
759804	759801	19798U	PARTICIPANT	\N	PRESENT	0
759805	757798	19479G	PARTICIPANT	\N	PRESENT	0
759806	757798	20094J	PARTICIPANT	\N	PRESENT	0
759807	757798	19421M	PARTICIPANT	\N	PRESENT	0
759808	757798	14251Q	PARTICIPANT	\N	PRESENT	0
759809	757798	20030R	PARTICIPANT	\N	PRESENT	0
759810	757798	08047A	PARTICIPANT	\N	PRESENT	0
759811	757769	14107H	PARTICIPANT	\N	EXCUSE	0
759812	757769	14219Q	PRESIDENT	0	PRESENT	0
759813	757769	14031R	PARTICIPANT	\N	PRESENT	0
759814	757769	19826F	PARTICIPANT	\N	PRESENT	0
759815	757769	20032T	PARTICIPANT	\N	PRESENT	0
759816	757769	21042A	PARTICIPANT	\N	PRESENT	0
759817	757769	20076G	PARTICIPANT	\N	PRESENT	0
759818	757769	21084L	PARTICIPANT	\N	PRESENT	0
759819	757769	21035B	PARTICIPANT	\N	PRESENT	0
759820	757769	08060W	PARTICIPANT	\N	PRESENT	0
759821	757769	21065H	PARTICIPANT	\N	PRESENT	0
759822	757769	18083K	PARTICIPANT	\N	PRESENT	0
759823	757769	19701S	PARTICIPANT	\N	PRESENT	0
759824	757769	19681G	PARTICIPANT	\N	PRESENT	0
760144	757799	14179A	PARTICIPANT	\N	PRESENT	0
759826	757769	17229F	PARTICIPANT	\N	PRESENT	0
759827	757769	19251M	PARTICIPANT	\N	PRESENT	0
759828	757769	15197G	PARTICIPANT	\N	PRESENT	0
760169	757799	21081H	PARTICIPANT	\N	PRESENT	0
759830	757769	21062E	PARTICIPANT	\N	PRESENT	0
759831	757769	20100N	PARTICIPANT	\N	PRESENT	0
759832	757769	20120S	PARTICIPANT	\N	PRESENT	0
759833	757769	19820Y	PARTICIPANT	\N	PRESENT	0
760163	757799	21039F	PARTICIPANT	\N	PRESENT	0
759835	757769	20068G	PARTICIPANT	\N	PRESENT	0
759836	757769	20106U	PARTICIPANT	\N	PRESENT	0
759837	757769	19685L	PARTICIPANT	\N	PRESENT	0
760164	757799	21046E	PARTICIPANT	\N	PRESENT	0
760148	757799	20114U	PARTICIPANT	\N	PRESENT	0
759840	757769	21080G	PARTICIPANT	\N	PRESENT	0
760149	757799	14195A	PARTICIPANT	\N	PRESENT	0
759842	757769	14169X	PARTICIPANT	\N	EXCUSE	0
759843	757769	19331L	PARTICIPANT	\N	PRESENT	0
760150	757799	21094N	PARTICIPANT	\N	PRESENT	0
759845	757769	14237S	PARTICIPANT	\N	PRESENT	0
759846	757769	21047F	PARTICIPANT	\N	PRESENT	0
759847	757769	20146D	PARTICIPANT	\N	PRESENT	0
759848	757769	21053D	PARTICIPANT	\N	PRESENT	0
760151	757799	20090E	PARTICIPANT	\N	PRESENT	0
759850	757769	05012A	PARTICIPANT	\N	PRESENT	0
759851	757769	21068L	PARTICIPANT	\N	PRESENT	0
759852	757769	21070E	PARTICIPANT	\N	PRESENT	0
759853	757769	20020P	PARTICIPANT	\N	PRESENT	0
760152	757799	14033T	PARTICIPANT	\N	PRESENT	0
759855	757769	20136B	PARTICIPANT	\N	PRESENT	0
759856	757769	21051B	PARTICIPANT	\N	PRESENT	0
759857	757769	21061D	PARTICIPANT	\N	PRESENT	0
759858	757769	20046A	PARTICIPANT	\N	PRESENT	0
759859	757769	21082J	PARTICIPANT	\N	PRESENT	0
760153	757799	21087P	PARTICIPANT	\N	PRESENT	0
760167	757799	14189C	PARTICIPANT	\N	PRESENT	0
760155	757799	20140W	PARTICIPANT	\N	PRESENT	0
760156	757799	20134Y	PARTICIPANT	\N	PRESENT	0
760165	757799	21076L	PARTICIPANT	\N	PRESENT	0
760166	757799	19758L	PARTICIPANT	\N	PRESENT	0
760159	757799	04045F	PARTICIPANT	\N	PRESENT	0
760160	757799	21043B	PARTICIPANT	\N	PRESENT	0
760161	757799	19691J	PARTICIPANT	\N	PRESENT	0
760162	757799	19683J	PARTICIPANT	\N	PRESENT	0
760168	757799	20032T	PARTICIPANT	\N	PRESENT	0
760170	757799	18083K	PARTICIPANT	\N	PRESENT	0
760171	757799	19954N	PARTICIPANT	\N	PRESENT	0
760172	757799	20180F	PARTICIPANT	\N	PRESENT	0
760173	757799	20148F	PARTICIPANT	\N	PRESENT	0
760174	757799	19553Y	PARTICIPANT	\N	PRESENT	0
760175	757799	14213J	PARTICIPANT	\N	PRESENT	0
760176	757799	14071N	PARTICIPANT	\N	PRESENT	0
760177	757799	21090J	PARTICIPANT	\N	PRESENT	0
760178	757799	17965H	PARTICIPANT	\N	PRESENT	0
760179	757799	19703U	PARTICIPANT	\N	PRESENT	0
760180	757799	19760E	PARTICIPANT	\N	PRESENT	0
760181	757799	04092N	PARTICIPANT	\N	PRESENT	0
760182	757799	08045X	PARTICIPANT	\N	PRESENT	0
760183	757799	14205J	PARTICIPANT	\N	PRESENT	0
760184	757799	21064G	PARTICIPANT	\N	PRESENT	0
760185	757799	14215L	PARTICIPANT	\N	PRESENT	0
760187	757799	07029T	PARTICIPANT	\N	PRESENT	0
760188	757799	21097R	PARTICIPANT	\N	PRESENT	0
760189	757799	14281W	PARTICIPANT	\N	PRESENT	0
760190	757799	20024T	PARTICIPANT	\N	PRESENT	0
760191	757799	20248J	PARTICIPANT	\N	PRESENT	0
760192	757799	21049H	PARTICIPANT	\N	PRESENT	0
760196	757799	18193Q	PARTICIPANT	\N	PRESENT	0
760197	757799	19479G	PARTICIPANT	\N	PRESENT	0
760198	757799	21042A	PARTICIPANT	\N	PRESENT	0
760200	760199	20112S	PARTICIPANT	\N	PRESENT	0
760201	760199	19954N	PARTICIPANT	\N	PRESENT	0
760202	760199	14030Q	PARTICIPANT	\N	EXCUSE	0
760203	760199	19621T	PRESIDENT	0	PRESENT	0
760278	760204	14223L	PARTICIPANT	\N	EXCUSE	0
760279	760204	20034V	PARTICIPANT	\N	EXCUSE	0
760280	760204	21034A	PARTICIPANT	\N	EXCUSE	0
760281	760204	20056C	PARTICIPANT	\N	EXCUSE	0
760282	760204	20046A	PARTICIPANT	\N	EXCUSE	0
760286	760204	14030Q	PARTICIPANT	\N	EXCUSE	0
760287	760204	07029T	PARTICIPANT	\N	EXCUSE	0
760288	760204	14109K	PARTICIPANT	\N	EXCUSE	0
760509	760507	14042U	PARTICIPANT	\N	PRESENT	0
760510	760507	14026U	PARTICIPANT	\N	PRESENT	0
760511	760507	20130U	PARTICIPANT	\N	PRESENT	0
760512	760508	14026U	PARTICIPANT	\N	PRESENT	0
760513	760508	14042U	PARTICIPANT	\N	PRESENT	0
760514	760508	20130U	PARTICIPANT	\N	PRESENT	0
760555	757696	19703U	PARTICIPANT	\N	PRESENT	0
760556	757696	18193Q	PARTICIPANT	\N	PRESENT	0
760557	757696	20130U	PARTICIPANT	\N	PRESENT	0
760559	757696	19798U	PARTICIPANT	\N	PRESENT	0
760563	757696	21094N	PARTICIPANT	\N	PRESENT	0
760567	757696	21071F	PARTICIPANT	\N	PRESENT	0
760572	757696	19691J	PARTICIPANT	\N	PRESENT	0
760573	757696	04092N	PARTICIPANT	\N	PRESENT	0
760610	760609	14033T	PARTICIPANT	\N	PRESENT	0
760614	757801	14257W	PARTICIPANT	\N	PRESENT	0
760616	760615	14123H	PARTICIPANT	\N	PRESENT	1
760617	757801	21076L	PARTICIPANT	\N	PRESENT	0
760618	757801	14187A	PARTICIPANT	\N	PRESENT	0
760619	757801	19507S	PARTICIPANT	\N	PRESENT	0
760620	757801	14255U	PARTICIPANT	\N	PRESENT	0
760621	757801	20082E	PARTICIPANT	\N	PRESENT	0
760622	757801	14205J	PARTICIPANT	\N	PRESENT	0
760623	757801	19647E	PARTICIPANT	\N	PRESENT	0
760630	757801	20048C	PARTICIPANT	\N	PRESENT	0
760631	757801	21043B	PARTICIPANT	\N	PRESENT	0
760632	757802	14111D	PARTICIPANT	\N	PRESENT	0
760633	757802	20094J	PARTICIPANT	\N	PRESENT	0
760634	757802	11040E	PARTICIPANT	\N	PRESENT	0
760635	757802	20024T	PARTICIPANT	\N	PRESENT	0
760636	757802	21048G	PARTICIPANT	\N	PRESENT	0
760637	757802	14033T	PARTICIPANT	\N	PRESENT	0
760638	757802	21087P	PARTICIPANT	\N	PRESENT	0
760639	757802	19693L	PARTICIPANT	\N	PRESENT	0
760640	757802	21075K	PARTICIPANT	\N	PRESENT	0
760641	757802	98022P	PARTICIPANT	\N	PRESENT	0
760642	757802	19711U	PARTICIPANT	\N	PRESENT	0
760643	757802	07004J	PARTICIPANT	\N	PRESENT	0
760644	757802	20062A	PARTICIPANT	\N	PRESENT	0
760646	757802	19531S	PARTICIPANT	\N	PRESENT	0
760647	757802	21096Q	PARTICIPANT	\N	PRESENT	0
760649	757802	21053D	PARTICIPANT	\N	PRESENT	0
760650	757802	19563B	PARTICIPANT	\N	PRESENT	0
760651	757802	21042A	PARTICIPANT	\N	PRESENT	0
760652	757802	20070A	PARTICIPANT	\N	PRESENT	0
760653	757802	19057M	PARTICIPANT	\N	PRESENT	0
760654	757802	19705W	PARTICIPANT	\N	PRESENT	0
741216	741106	04035D	PARTICIPANT	\N	PRESENT	0
741217	741106	20036X	PARTICIPANT	\N	PRESENT	0
741218	741106	20266L	PARTICIPANT	\N	PRESENT	0
741219	741106	01058X	PARTICIPANT	\N	PRESENT	0
741220	741106	20134Y	PARTICIPANT	\N	PRESENT	0
741221	741106	19711U	PARTICIPANT	\N	PRESENT	0
741222	741106	08061X	PARTICIPANT	\N	PRESENT	0
741223	741106	11072N	PARTICIPANT	\N	PRESENT	0
741224	741106	04045F	PARTICIPANT	\N	PRESENT	0
741225	741106	99004R	PARTICIPANT	\N	PRESENT	0
741226	741106	08073C	PARTICIPANT	\N	PRESENT	0
741227	741106	19697Q	PARTICIPANT	\N	PRESENT	0
741228	741106	20106U	PARTICIPANT	\N	PRESENT	0
741229	741106	19349W	PARTICIPANT	\N	PRESENT	0
741230	741106	20076G	PARTICIPANT	\N	PRESENT	0
741231	741106	20146D	PARTICIPANT	\N	PRESENT	0
741232	741106	20150Y	PARTICIPANT	\N	PRESENT	0
741233	741106	20078J	PARTICIPANT	\N	PRESENT	0
741234	741106	19525U	PARTICIPANT	\N	PRESENT	0
741235	741106	14037X	PARTICIPANT	\N	PRESENT	0
741236	741106	11033F	PARTICIPANT	\N	PRESENT	0
741237	741106	17367Q	PARTICIPANT	\N	PRESENT	0
741238	741106	19387D	PARTICIPANT	\N	PRESENT	0
741239	741106	11012A	PARTICIPANT	\N	PRESENT	0
741240	741106	14169X	PARTICIPANT	\N	PRESENT	0
741241	741106	14207L	PARTICIPANT	\N	PRESENT	0
741242	741106	19719D	PARTICIPANT	\N	PRESENT	0
741243	741106	14107H	PARTICIPANT	\N	PRESENT	0
741244	741106	19703U	PARTICIPANT	\N	PRESENT	0
741245	741106	19681G	PARTICIPANT	\N	PRESENT	0
741246	741106	19553Y	PARTICIPANT	\N	PRESENT	0
741247	741106	10015M	PARTICIPANT	\N	PRESENT	0
741248	741106	19563B	PARTICIPANT	\N	PRESENT	0
741249	741106	19583F	PARTICIPANT	\N	PRESENT	0
741250	741106	05012A	PARTICIPANT	\N	PRESENT	0
741251	741106	14211G	PARTICIPANT	\N	PRESENT	0
741252	741106	14111D	PARTICIPANT	\N	PRESENT	0
741253	741106	14221J	PARTICIPANT	\N	PRESENT	0
741254	741106	19545Y	PARTICIPANT	\N	PRESENT	0
741255	741106	17589D	PARTICIPANT	\N	PRESENT	0
741256	741106	11099A	PARTICIPANT	\N	PRESENT	0
741257	741106	01057W	PARTICIPANT	\N	PRESENT	0
741258	741106	20122U	PARTICIPANT	\N	PRESENT	0
741259	741106	20050V	PARTICIPANT	\N	PRESENT	0
741260	741106	14195A	PARTICIPANT	\N	PRESENT	0
741261	741106	20074E	PARTICIPANT	\N	PRESENT	0
741262	741106	19766L	PARTICIPANT	\N	PRESENT	0
741263	741106	11080N	PARTICIPANT	\N	PRESENT	0
741264	741106	14021P	PARTICIPANT	\N	PRESENT	0
741265	741106	01062T	PARTICIPANT	\N	PRESENT	0
741266	741106	19515S	PARTICIPANT	\N	PRESENT	0
741267	741106	08060W	PARTICIPANT	\N	PRESENT	0
741268	741106	08045X	PARTICIPANT	\N	PRESENT	0
741269	741106	08028W	PARTICIPANT	\N	PRESENT	0
741270	741106	18083K	PARTICIPANT	\N	PRESENT	0
741271	741106	19820Y	PARTICIPANT	\N	PRESENT	0
741272	741106	14109K	PARTICIPANT	\N	PRESENT	0
741273	741106	11090Q	PARTICIPANT	\N	PRESENT	0
741274	741106	11066Q	PARTICIPANT	\N	PRESENT	0
741275	741106	20032T	PARTICIPANT	\N	PRESENT	0
741276	741106	19725B	PARTICIPANT	\N	PRESENT	0
741277	741106	17737W	PARTICIPANT	\N	PRESENT	0
741278	741106	14253S	PARTICIPANT	\N	PRESENT	0
741279	741106	20070A	PARTICIPANT	\N	PRESENT	0
741280	741106	20038A	PARTICIPANT	\N	PRESENT	0
741281	741106	19673G	PARTICIPANT	\N	PRESENT	0
741282	741106	14173T	PARTICIPANT	\N	PRESENT	0
741283	741106	19447X	PARTICIPANT	\N	PRESENT	0
741284	741106	14121F	PARTICIPANT	\N	PRESENT	0
741285	741106	20096L	PARTICIPANT	\N	PRESENT	0
741286	741106	19631V	PARTICIPANT	\N	PRESENT	0
741287	741106	14281W	PARTICIPANT	\N	PRESENT	0
741288	741106	14259Y	PARTICIPANT	\N	PRESENT	0
741289	741106	20264J	PARTICIPANT	\N	PRESENT	0
741290	741106	19527W	PARTICIPANT	\N	PRESENT	0
741291	741106	20026V	PARTICIPANT	\N	PRESENT	0
741292	741106	20088L	PARTICIPANT	\N	PRESENT	0
741293	741106	20140W	PARTICIPANT	\N	PRESENT	0
741294	741106	17965H	PARTICIPANT	\N	PRESENT	0
741295	741106	20064C	PARTICIPANT	\N	PRESENT	0
741296	741106	19593H	PARTICIPANT	\N	PRESENT	0
741297	741106	08047A	PARTICIPANT	\N	PRESENT	0
741298	741106	12041X	PARTICIPANT	\N	PRESENT	0
741299	741106	20028X	PARTICIPANT	\N	PRESENT	0
741300	741106	14038Y	PARTICIPANT	\N	PRESENT	0
741301	741106	19723Y	PARTICIPANT	\N	PRESENT	0
741302	741106	19651A	PARTICIPANT	\N	PRESENT	0
741303	741106	20034V	PARTICIPANT	\N	PRESENT	0
741304	741106	95063L	PARTICIPANT	\N	PRESENT	0
741305	741106	11065P	PARTICIPANT	\N	PRESENT	0
741306	741106	19347U	PARTICIPANT	\N	PRESENT	0
741307	741106	19467C	PARTICIPANT	\N	PRESENT	0
741308	741106	20056C	PARTICIPANT	\N	PRESENT	0
741309	741106	20042V	PARTICIPANT	\N	PRESENT	0
741310	741106	20052X	PARTICIPANT	\N	PRESENT	0
741311	741106	19319Q	PARTICIPANT	\N	PRESENT	0
741312	741106	20298U	PARTICIPANT	\N	PRESENT	0
741313	741106	14219Q	PARTICIPANT	\N	PRESENT	0
741314	741106	20098N	PARTICIPANT	\N	PRESENT	0
741315	741106	19479G	PARTICIPANT	\N	PRESENT	0
741316	741106	14033T	PARTICIPANT	\N	PRESENT	0
741317	741106	19441R	PARTICIPANT	\N	PRESENT	0
741318	741106	14213J	PARTICIPANT	\N	PRESENT	0
741319	741106	19619A	PARTICIPANT	\N	PRESENT	0
741320	741106	19569H	PARTICIPANT	\N	PRESENT	0
741321	741106	20024T	PARTICIPANT	\N	PRESENT	0
741322	741106	19735D	PARTICIPANT	\N	PRESENT	0
741323	741106	19489J	PARTICIPANT	\N	PRESENT	0
741324	741106	19699S	PARTICIPANT	\N	PRESENT	0
741325	741106	20144B	PARTICIPANT	\N	PRESENT	0
741326	741106	19369B	PARTICIPANT	\N	PRESENT	0
741327	741106	19611R	PARTICIPANT	\N	PRESENT	0
741328	741106	19745F	PARTICIPANT	\N	PRESENT	0
741329	741106	20108W	PARTICIPANT	\N	PRESENT	0
741330	741106	14179A	PARTICIPANT	\N	PRESENT	0
741331	741106	19691J	PARTICIPANT	\N	PRESENT	0
741332	741106	14231L	PARTICIPANT	\N	PRESENT	0
741333	741106	17229F	PARTICIPANT	\N	PRESENT	0
741334	741106	19705W	PARTICIPANT	\N	PRESENT	0
741335	741106	14267Y	PARTICIPANT	\N	PRESENT	0
741336	741106	14255U	PARTICIPANT	\N	PRESENT	0
741337	741106	19768N	PARTICIPANT	\N	PRESENT	0
741338	741106	20066E	PARTICIPANT	\N	PRESENT	0
741339	741106	14073Q	PARTICIPANT	\N	PRESENT	0
741340	741106	19621T	PARTICIPANT	\N	PRESENT	0
741341	741106	14083S	PARTICIPANT	\N	PRESENT	0
741342	741106	19335Q	PARTICIPANT	\N	PRESENT	0
741343	741106	19729F	PARTICIPANT	\N	PRESENT	0
741344	741106	19295A	PARTICIPANT	\N	PRESENT	0
741345	741106	07029T	PARTICIPANT	\N	PRESENT	0
741346	741106	19685L	PARTICIPANT	\N	PRESENT	0
741347	741106	19826F	PARTICIPANT	\N	PRESENT	0
741348	741106	08018U	PARTICIPANT	\N	PRESENT	0
741349	741106	20040T	PARTICIPANT	\N	PRESENT	0
741350	741106	07004J	PARTICIPANT	\N	PRESENT	0
741351	741106	19507S	PARTICIPANT	\N	PRESENT	0
741352	741106	01025N	PARTICIPANT	\N	PRESENT	0
741353	741106	01024M	PARTICIPANT	\N	PRESENT	0
741354	741106	19747H	PARTICIPANT	\N	PRESENT	0
741355	741106	19663E	PARTICIPANT	\N	PRESENT	0
741356	741106	14229S	PARTICIPANT	\N	PRESENT	0
741357	741106	01043Q	PARTICIPANT	\N	PRESENT	0
741358	741106	14030Q	PARTICIPANT	\N	PRESENT	0
741359	741106	20022R	PARTICIPANT	\N	PRESENT	0
741360	741106	19591F	PARTICIPANT	\N	PRESENT	0
741361	741106	04008A	PARTICIPANT	\N	PRESENT	0
741362	741106	14223L	PARTICIPANT	\N	PRESENT	0
741363	741106	17637T	PARTICIPANT	\N	PRESENT	0
741364	741106	20118Y	PARTICIPANT	\N	PRESENT	0
741365	741106	04057K	PARTICIPANT	\N	PRESENT	0
741366	741106	04042C	PARTICIPANT	\N	PRESENT	0
741367	741106	20980G	PARTICIPANT	\N	PRESENT	0
741368	741106	19707Y	PARTICIPANT	\N	PRESENT	0
741369	741106	20062A	PARTICIPANT	\N	PRESENT	0
741370	741106	14329V	PARTICIPANT	\N	PRESENT	0
741371	741106	04033B	PARTICIPANT	\N	PRESENT	0
741372	741106	97011G	PARTICIPANT	\N	PRESENT	0
741373	741106	14187A	PARTICIPANT	\N	PRESENT	0
741374	741106	14059S	PARTICIPANT	\N	PRESENT	0
741375	741106	08010L	PARTICIPANT	\N	PRESENT	0
741376	741106	08056B	PARTICIPANT	\N	PRESENT	0
753807	753745	19705W	PARTICIPANT	\N	EXCUSE	0
754081	753645	19719D	PARTICIPANT	\N	EXCUSE	0
754532	754136	14331P	PARTICIPANT	\N	PRESENT	0
754533	754136	20134Y	PARTICIPANT	\N	PRESENT	0
754534	754136	19711U	PARTICIPANT	\N	PRESENT	0
754535	754136	21090J	PARTICIPANT	\N	PRESENT	0
754536	754136	21048G	PARTICIPANT	\N	PRESENT	0
754537	754136	14173T	PARTICIPANT	\N	PRESENT	0
754538	754136	19479G	PARTICIPANT	\N	PRESENT	0
754539	754136	21079P	PARTICIPANT	\N	PRESENT	0
754540	754136	20094J	PARTICIPANT	\N	PRESENT	0
754541	754136	20116W	PARTICIPANT	\N	PRESENT	0
754542	754136	20024T	PARTICIPANT	\N	PRESENT	0
754543	754136	11040E	PARTICIPANT	\N	PRESENT	0
754544	754136	20080C	PARTICIPANT	\N	PRESENT	0
754545	754136	19667J	PARTICIPANT	\N	PRESENT	0
754546	754136	19573D	PARTICIPANT	\N	PRESENT	0
754547	754136	14121F	PARTICIPANT	\N	PRESENT	0
754548	754136	14253S	PARTICIPANT	\N	PRESENT	0
754550	754136	11053K	PARTICIPANT	\N	PRESENT	0
754551	754136	07004J	PARTICIPANT	\N	PRESENT	0
754552	754136	19349W	PARTICIPANT	\N	PRESENT	0
754553	754136	11048N	PARTICIPANT	\N	PRESENT	0
754554	754136	20044X	PARTICIPANT	\N	PRESENT	0
754555	754136	19399H	PARTICIPANT	\N	PRESENT	0
754556	754136	20062A	PARTICIPANT	\N	PRESENT	0
754557	754136	08073C	PARTICIPANT	\N	PRESENT	0
754559	754136	07029T	PARTICIPANT	\N	PRESENT	0
754560	754136	20126Y	PARTICIPANT	\N	PRESENT	0
754561	754136	20150Y	PARTICIPANT	\N	PRESENT	0
753731	753252	19619A	PARTICIPANT	\N	PRESENT	0
753732	753252	20136B	PARTICIPANT	\N	PRESENT	0
753733	753252	21051B	PARTICIPANT	\N	PRESENT	0
753734	753252	21061D	PARTICIPANT	\N	PRESENT	0
753735	753252	20046A	PARTICIPANT	\N	PRESENT	0
753736	753252	21082J	PARTICIPANT	\N	PRESENT	0
753806	753745	19707Y	PARTICIPANT	\N	EXCUSE	0
754563	754136	14225N	PRESIDENT	0	PRESENT	0
754564	754136	20070A	PARTICIPANT	\N	PRESENT	0
754565	754136	19647E	PARTICIPANT	\N	PRESENT	0
754566	754136	20050V	PARTICIPANT	\N	PRESENT	0
754567	754136	21072G	PARTICIPANT	\N	PRESENT	0
754568	754136	21041Y	PARTICIPANT	\N	PRESENT	0
754569	754136	14327T	PARTICIPANT	\N	PRESENT	0
754570	754136	11110B	PARTICIPANT	\N	PRESENT	0
754571	754136	19687N	PARTICIPANT	\N	PRESENT	0
754572	754136	08009T	PARTICIPANT	\N	PRESENT	0
754573	754136	11070L	PARTICIPANT	\N	PRESENT	0
754574	754136	08011M	PARTICIPANT	\N	PRESENT	0
754575	754136	21069M	PARTICIPANT	\N	PRESENT	0
754576	754136	14083S	PARTICIPANT	\N	PRESENT	0
754577	754136	19335Q	PARTICIPANT	\N	PRESENT	0
754578	754136	08034U	PARTICIPANT	\N	PRESENT	0
754579	752395	04070G	PARTICIPANT	\N	PRESENT	0
754580	752395	19533U	PARTICIPANT	\N	PRESENT	0
754581	752395	21058J	PARTICIPANT	\N	PRESENT	0
754582	752395	21059K	PARTICIPANT	\N	PRESENT	0
754583	752395	20102Q	PARTICIPANT	\N	PRESENT	0
754584	752395	14229S	PARTICIPANT	\N	PRESENT	0
754585	752395	21032X	PARTICIPANT	\N	PRESENT	0
754586	752395	18395Y	PARTICIPANT	\N	PRESENT	0
754587	752395	20112S	PARTICIPANT	\N	PRESENT	0
754588	752395	21037D	PARTICIPANT	\N	PRESENT	0
754589	752395	08012N	PARTICIPANT	\N	PRESENT	0
754590	752395	20124W	PARTICIPANT	\N	PRESENT	0
754591	752395	20026V	PARTICIPANT	\N	PRESENT	0
754592	752395	19593H	PARTICIPANT	\N	PRESENT	0
754593	752395	20132W	PARTICIPANT	\N	PRESENT	0
754594	752395	20138D	PARTICIPANT	\N	PRESENT	0
754595	752395	20142Y	PARTICIPANT	\N	PRESENT	0
754596	752395	20048C	PARTICIPANT	\N	PRESENT	0
754597	752395	19693L	PARTICIPANT	\N	PRESENT	0
754598	752395	20052X	PARTICIPANT	\N	PRESENT	0
754599	752395	20172F	PARTICIPANT	\N	PRESENT	0
754600	752395	20058E	PARTICIPANT	\N	PRESENT	0
754601	752395	20056C	PARTICIPANT	\N	PRESENT	0
754602	752395	20180F	PARTICIPANT	\N	PRESENT	0
754603	752395	21063F	PARTICIPANT	\N	PRESENT	0
754604	752395	19735D	PARTICIPANT	\N	PRESENT	0
754605	752395	14109K	PARTICIPANT	\N	PRESENT	0
754606	752395	21074J	PARTICIPANT	\N	PRESENT	0
754607	752395	21077M	PARTICIPANT	\N	PRESENT	0
754608	752395	21078N	PARTICIPANT	\N	PRESENT	0
754609	752395	19621T	PARTICIPANT	0	PRESENT	0
754610	754136	20086J	PARTICIPANT	\N	PRESENT	0
754612	754136	11074Q	PARTICIPANT	\N	PRESENT	0
754613	754136	08010L	PARTICIPANT	\N	PRESENT	0
754623	753674	21030V	PARTICIPANT	\N	PRESENT	0
754624	753674	20072C	PARTICIPANT	\N	PRESENT	0
754625	753674	21031W	PARTICIPANT	\N	PRESENT	0
754626	753674	01058X	PARTICIPANT	\N	PRESENT	0
754627	753674	11027H	PARTICIPANT	\N	PRESENT	0
754628	753674	04042C	PARTICIPANT	\N	PRESENT	0
754629	753674	19669L	PARTICIPANT	\N	PRESENT	0
754630	753674	08056B	PARTICIPANT	\N	PRESENT	0
754631	753674	12028B	PARTICIPANT	\N	PRESENT	0
754632	753674	17737W	PARTICIPANT	\N	PRESENT	0
754633	753674	19421M	PARTICIPANT	\N	PRESENT	0
754634	753674	21067K	PARTICIPANT	\N	PRESENT	0
754635	753674	19709B	PARTICIPANT	\N	PRESENT	0
754636	753674	14193X	PRESIDENT	0	PRESENT	0
754637	753674	19347U	PARTICIPANT	\N	PRESENT	0
754638	753674	14179A	PARTICIPANT	\N	PRESENT	0
754639	753674	07033P	PARTICIPANT	\N	PRESENT	0
754640	753674	17367Q	PARTICIPANT	\N	PRESENT	0
754641	753674	14249W	PARTICIPANT	\N	PRESENT	0
754642	753674	08047A	PARTICIPANT	\N	PRESENT	0
754643	753674	14037X	PARTICIPANT	\N	PRESENT	0
754644	753674	14059S	PARTICIPANT	\N	PRESENT	0
754645	753674	14097Y	PARTICIPANT	\N	PRESENT	0
754646	753674	21073H	PARTICIPANT	\N	PRESENT	0
754647	753674	14133K	PARTICIPANT	\N	PRESENT	0
754648	753674	08069G	PARTICIPANT	\N	PRESENT	0
754649	753674	20042V	PARTICIPANT	\N	PRESENT	0
754650	753674	20064C	PARTICIPANT	\N	PRESENT	0
754651	753674	20252E	PARTICIPANT	\N	PRESENT	0
754652	753674	14251Q	PARTICIPANT	\N	PRESENT	0
754653	753674	98022P	PARTICIPANT	\N	PRESENT	0
754654	753674	11064N	PARTICIPANT	\N	PRESENT	0
754655	753674	14267Y	PARTICIPANT	\N	PRESENT	0
754656	753674	19745F	PARTICIPANT	\N	PRESENT	0
754657	753674	99004R	PARTICIPANT	\N	PRESENT	0
754658	753674	14211G	PARTICIPANT	\N	PRESENT	0
754659	753674	17023S	PARTICIPANT	\N	PRESENT	0
754660	753674	14255U	PARTICIPANT	\N	PRESENT	0
754663	753674	19565D	PARTICIPANT	\N	PRESENT	0
754664	753674	20128B	PARTICIPANT	\N	PRESENT	0
754714	754527	19383Y	PARTICIPANT	\N	PRESENT	0
754715	754527	19768N	PARTICIPANT	\N	PRESENT	0
754716	754527	20088L	PARTICIPANT	\N	PRESENT	0
754717	754527	19782L	PARTICIPANT	\N	PRESENT	0
754718	754527	20092G	PARTICIPANT	\N	PRESENT	0
754719	754527	14357A	PARTICIPANT	\N	PRESENT	0
754720	754527	19413M	PARTICIPANT	\N	PRESENT	0
754721	754527	20082E	PARTICIPANT	\N	PRESENT	0
754722	754527	14221J	PARTICIPANT	\N	PRESENT	0
754723	754527	19631V	PARTICIPANT	\N	PRESENT	0
754724	754527	20104S	PARTICIPANT	\N	PRESENT	0
754725	754527	08015R	PARTICIPANT	\N	PRESENT	0
754726	754527	19575F	PARTICIPANT	\N	PRESENT	0
754727	754527	08028W	PARTICIPANT	\N	PRESENT	0
754728	754527	19563B	PARTICIPANT	\N	PRESENT	0
754729	754527	21050A	PARTICIPANT	\N	PRESENT	0
754730	754527	14329V	PARTICIPANT	\N	PRESENT	0
754731	754527	20028X	PARTICIPANT	\N	PRESENT	0
754732	754527	21052C	PARTICIPANT	\N	PRESENT	0
754733	754527	14038Y	PARTICIPANT	\N	PRESENT	0
754734	754527	20030R	PARTICIPANT	\N	PRESENT	0
754735	754527	21054E	PARTICIPANT	\N	PRESENT	0
754736	754527	20034V	PARTICIPANT	\N	PRESENT	0
754737	754527	21075K	PARTICIPANT	\N	PRESENT	0
754738	754527	20038A	PARTICIPANT	\N	PRESENT	0
754739	754527	14187A	PRESIDENT	0	PRESENT	0
754740	754527	21083K	PARTICIPANT	\N	PRESENT	0
754741	754527	19695N	PARTICIPANT	\N	PRESENT	0
754742	754527	21092L	PARTICIPANT	\N	PRESENT	0
754743	754527	14033T	PARTICIPANT	\N	PRESENT	0
754744	754527	21093M	PARTICIPANT	\N	PRESENT	0
754745	754527	20054A	PARTICIPANT	\N	PRESENT	0
754746	754527	21033Y	PARTICIPANT	\N	PRESENT	0
754747	754527	14205J	PARTICIPANT	\N	PRESENT	0
743745	743742	19693L	PARTICIPANT	\N	PRESENT	0
743747	743742	19723Y	PARTICIPANT	\N	PRESENT	0
743748	743742	01048V	PARTICIPANT	\N	PRESENT	0
743749	743742	11067R	PARTICIPANT	\N	PRESENT	0
743751	743742	20066E	PARTICIPANT	\N	EXCUSE	0
743752	743742	01058X	PARTICIPANT	\N	EXCUSE	0
743753	743742	19735D	PARTICIPANT	\N	EXCUSE	0
748586	748103	08061X	PARTICIPANT	\N	PRESENT	0
748587	748103	19713W	PARTICIPANT	\N	PRESENT	0
748588	748103	08028W	PARTICIPANT	\N	PRESENT	0
748589	748103	19383Y	PARTICIPANT	\N	PRESENT	0
748590	748103	14042U	PARTICIPANT	\N	PRESENT	0
748591	748167	20126Y	PARTICIPANT	\N	PRESENT	0
748592	748103	11101A	PARTICIPANT	\N	PRESENT	0
748593	748103	20024T	PARTICIPANT	\N	PRESENT	0
748594	748103	20072C	PARTICIPANT	\N	PRESENT	0
748595	748167	19349W	PARTICIPANT	\N	PRESENT	0
748596	748103	14059S	PARTICIPANT	\N	PRESENT	0
748597	748167	20070A	PARTICIPANT	\N	PRESENT	0
748598	748103	14213J	PARTICIPANT	\N	PRESENT	0
748599	748103	14069U	PARTICIPANT	\N	PRESENT	0
748600	748103	20132W	PARTICIPANT	\N	PRESENT	0
748601	748103	11074Q	PARTICIPANT	\N	PRESENT	0
748602	748103	14107H	PARTICIPANT	\N	PRESENT	0
748603	748103	19679N	PARTICIPANT	\N	PRESENT	0
748604	748103	19447X	PARTICIPANT	\N	PRESENT	0
748605	748103	20112S	PARTICIPANT	\N	PRESENT	0
748606	748103	04045F	PARTICIPANT	\N	PRESENT	0
748607	748167	07029T	PARTICIPANT	\N	PRESENT	0
748783	748428	20060X	PARTICIPANT	\N	PRESENT	0
748784	748104	20042V	PARTICIPANT	\N	PRESENT	0
748785	748104	97011G	PARTICIPANT	\N	PRESENT	0
748786	748104	14069U	PARTICIPANT	\N	PRESENT	0
748787	748104	11031D	PARTICIPANT	\N	PRESENT	0
748788	748104	19651A	PARTICIPANT	\N	PRESENT	0
748789	748104	20098N	PARTICIPANT	\N	PRESENT	0
748790	748104	14169X	PARTICIPANT	\N	PRESENT	0
748791	748104	08060W	PARTICIPANT	\N	PRESENT	0
748792	748104	19549D	PARTICIPANT	\N	PRESENT	0
748797	748104	19479G	PARTICIPANT	\N	PRESENT	0
748798	748104	19383Y	PARTICIPANT	\N	PRESENT	0
748809	748104	01024M	PARTICIPANT	\N	PRESENT	0
748819	748104	19695N	PARTICIPANT	\N	PRESENT	0
748836	748104	11090Q	PARTICIPANT	\N	PRESENT	0
748839	748104	08061X	PARTICIPANT	\N	PRESENT	0
748841	748104	19441R	PARTICIPANT	\N	PRESENT	0
748857	748104	14223L	PARTICIPANT	\N	PRESENT	0
748860	748104	08028W	PARTICIPANT	\N	PRESENT	0
748861	748104	20054A	PARTICIPANT	\N	PRESENT	0
748862	748104	19768N	PARTICIPANT	\N	PRESENT	0
748863	748104	14042U	PARTICIPANT	\N	PRESENT	0
748864	748104	18083K	PARTICIPANT	\N	PRESENT	0
748865	748104	19349W	PARTICIPANT	\N	PRESENT	0
748866	748104	14083S	PARTICIPANT	\N	PRESENT	0
748867	748104	99004R	PARTICIPANT	\N	PRESENT	0
748868	748104	20090E	PARTICIPANT	\N	PRESENT	0
748869	748104	20088L	PARTICIPANT	\N	PRESENT	0
748870	748104	04057K	PARTICIPANT	\N	PRESENT	0
748871	748104	20078J	PARTICIPANT	\N	PRESENT	0
748872	748104	19711U	PARTICIPANT	\N	PRESENT	0
748873	748104	10015M	PARTICIPANT	\N	PRESENT	0
748875	748104	08010L	PARTICIPANT	\N	PRESENT	0
748877	748104	14193X	PARTICIPANT	\N	PRESENT	0
748878	748104	20248J	PARTICIPANT	\N	PRESENT	0
748879	748104	11101A	PARTICIPANT	\N	PRESENT	0
748880	748104	14133K	PARTICIPANT	\N	PRESENT	0
748881	748104	19703U	PARTICIPANT	\N	PRESENT	0
748882	748104	17367Q	PARTICIPANT	\N	PRESENT	0
748935	748106	11031D	PARTICIPANT	\N	PRESENT	0
748936	748106	20124W	PARTICIPANT	\N	PRESENT	0
748937	748106	20090E	PARTICIPANT	\N	PRESENT	0
748938	748106	20076G	PARTICIPANT	\N	PRESENT	0
748939	748106	14030Q	PARTICIPANT	\N	PRESENT	0
748940	748106	04070G	PARTICIPANT	\N	PRESENT	0
748941	748106	11045K	PARTICIPANT	\N	PRESENT	0
748942	748106	20134Y	PARTICIPANT	\N	PRESENT	0
748943	748106	20094J	PARTICIPANT	\N	PRESENT	0
748944	748106	20132W	PARTICIPANT	\N	PRESENT	0
748945	748106	20122U	PARTICIPANT	\N	PRESENT	0
748946	748106	20152B	PARTICIPANT	\N	PRESENT	0
748947	748106	19768N	PARTICIPANT	\N	PRESENT	0
748948	748106	20034V	PARTICIPANT	\N	PRESENT	0
748949	748106	14147R	PARTICIPANT	\N	PRESENT	0
748950	748106	14031R	PARTICIPANT	\N	PRESENT	0
748951	748106	20066E	PARTICIPANT	\N	PRESENT	0
748952	748106	20082E	PARTICIPANT	\N	PRESENT	0
748953	748106	11090Q	PARTICIPANT	\N	PRESENT	0
748954	748106	14179A	PARTICIPANT	\N	PRESENT	0
748955	748106	14038Y	PARTICIPANT	\N	PRESENT	0
748956	748106	19749K	PARTICIPANT	\N	PRESENT	0
748957	748106	19782L	PARTICIPANT	\N	PRESENT	0
748958	748106	20048C	PARTICIPANT	\N	PRESENT	0
748959	748106	19651A	PARTICIPANT	\N	PRESENT	0
748960	748106	20138D	PARTICIPANT	\N	PRESENT	0
748961	748106	20172F	PARTICIPANT	\N	PRESENT	0
748962	748106	20052X	PARTICIPANT	\N	PRESENT	0
748963	748106	14215L	PARTICIPANT	\N	PRESENT	0
748964	748106	14083S	PARTICIPANT	\N	PRESENT	0
748965	748106	20128B	PARTICIPANT	\N	PRESENT	0
748966	748106	20112S	PARTICIPANT	\N	PRESENT	0
748967	748106	19479G	PARTICIPANT	\N	PRESENT	0
748968	748106	14069U	PARTICIPANT	\N	PRESENT	0
748969	748106	20022R	PARTICIPANT	\N	PRESENT	0
748970	748106	10015M	PARTICIPANT	\N	PRESENT	0
748971	748106	20054A	PARTICIPANT	\N	PRESENT	0
748972	748106	14193X	PARTICIPANT	\N	PRESENT	0
748973	748106	08010L	PARTICIPANT	\N	PRESENT	0
748974	748106	14213J	PARTICIPANT	\N	PRESENT	0
748975	748106	20058E	PARTICIPANT	\N	PRESENT	0
748976	748106	19383Y	PARTICIPANT	\N	PRESENT	0
748977	748106	14133K	PARTICIPANT	\N	PRESENT	0
748978	748106	18083K	PARTICIPANT	\N	PRESENT	0
748979	748106	14033T	PARTICIPANT	\N	PRESENT	0
748980	748106	19347U	PARTICIPANT	\N	PRESENT	0
748981	748106	05012A	PARTICIPANT	\N	PRESENT	0
748982	748106	19691J	PARTICIPANT	\N	PRESENT	0
751545	749959	14053L	PARTICIPANT	\N	EXCUSE	0
751546	749959	08018U	PARTICIPANT	\N	EXCUSE	0
748933	748106	14026U	PARTICIPANT	\N	PRESENT	0
748934	748106	19593H	PARTICIPANT	\N	PRESENT	0
751547	749959	20108W	PARTICIPANT	\N	EXCUSE	0
751551	749960	14053L	PARTICIPANT	\N	EXCUSE	0
751553	749960	08018U	PARTICIPANT	\N	EXCUSE	0
751554	749960	20108W	PARTICIPANT	\N	EXCUSE	0
751944	751943	14053L	PARTICIPANT	\N	PRESENT	1
751945	751943	14089Y	PARTICIPANT	\N	PRESENT	0
751946	751943	11026G	PARTICIPANT	\N	PRESENT	0
751948	751947	11026G	PARTICIPANT	\N	PRESENT	0
751949	751947	14089Y	PARTICIPANT	\N	PRESENT	0
751950	751947	14053L	PARTICIPANT	\N	PRESENT	1
751982	751981	10006L	PARTICIPANT	\N	PRESENT	0
751984	751983	10006L	PARTICIPANT	\N	PRESENT	0
752027	752026	04042C	PARTICIPANT	\N	PRESENT	0
752028	752026	14133K	PARTICIPANT	\N	PRESENT	0
752029	752026	14193X	PARTICIPANT	\N	PRESENT	0
752030	752026	14267Y	PARTICIPANT	\N	PRESENT	0
752031	752026	19669L	PARTICIPANT	\N	PRESENT	0
752032	752026	01062T	PARTICIPANT	\N	PRESENT	0
752033	752026	20128B	PARTICIPANT	\N	PRESENT	0
752299	752221	11067R	PARTICIPANT	\N	PRESENT	0
752035	752026	08034U	PARTICIPANT	\N	PRESENT	0
752038	752026	11066Q	PARTICIPANT	\N	PRESENT	0
759409	757695	21071F	PARTICIPANT	\N	PRESENT	0
759371	757695	14042U	PARTICIPANT	\N	PRESENT	0
759373	757695	21097R	PARTICIPANT	\N	PRESENT	0
759374	757695	14281W	PARTICIPANT	\N	PRESENT	0
759375	757695	14195A	PARTICIPANT	\N	PRESENT	0
759376	757695	18193Q	PARTICIPANT	\N	PRESENT	0
759380	757695	19569H	PARTICIPANT	\N	PRESENT	0
759381	757695	19679N	PARTICIPANT	\N	PRESENT	0
759382	757695	04092N	PARTICIPANT	\N	PRESENT	0
759383	757695	20148F	PARTICIPANT	\N	PRESENT	0
760655	757802	14257W	PARTICIPANT	\N	PRESENT	0
760667	757802	14207L	PARTICIPANT	\N	PRESENT	0
760665	757802	19749K	PARTICIPANT	\N	PRESENT	0
760658	757802	19507S	PARTICIPANT	\N	PRESENT	0
760668	757802	21049H	PARTICIPANT	\N	PRESENT	0
760660	757802	20082E	PARTICIPANT	\N	PRESENT	0
760661	757802	14205J	PARTICIPANT	\N	PRESENT	0
760662	757802	19647E	PARTICIPANT	\N	PRESENT	0
760666	757802	14187A	PARTICIPANT	\N	PRESENT	0
760664	757802	21043B	PARTICIPANT	\N	PRESENT	0
760669	757802	21050A	PARTICIPANT	\N	PRESENT	0
760670	757802	11090Q	PARTICIPANT	\N	PRESENT	0
760671	757802	21092L	PARTICIPANT	\N	PRESENT	0
760672	757802	21046E	PARTICIPANT	\N	PRESENT	0
760673	757802	14069U	PARTICIPANT	\N	PRESENT	0
760674	757802	12016W	PARTICIPANT	\N	PRESENT	0
760675	757802	20098N	PARTICIPANT	\N	PRESENT	0
760676	757802	20134Y	PARTICIPANT	\N	PRESENT	0
760677	757802	20110Q	PARTICIPANT	\N	PRESENT	0
760678	757802	14357A	PARTICIPANT	\N	PRESENT	0
760679	757802	21079P	PARTICIPANT	\N	PRESENT	0
760684	757802	21095P	PARTICIPANT	\N	PRESENT	0
760687	757802	20092G	PARTICIPANT	\N	PRESENT	0
760688	757802	19585H	PARTICIPANT	\N	PRESENT	0
760689	757802	14189C	PARTICIPANT	\N	PRESENT	0
760690	757802	21091K	PARTICIPANT	\N	PRESENT	0
760691	757802	14053L	PARTICIPANT	\N	PRESENT	0
760692	757802	19533U	PARTICIPANT	\N	PRESENT	0
760693	757802	21097R	PARTICIPANT	\N	PRESENT	0
760694	757802	21035B	PARTICIPANT	\N	PRESENT	0
760735	760734	11072N	PARTICIPANT	\N	PRESENT	0
760736	760733	11072N	PARTICIPANT	\N	PRESENT	0
760743	760741	19954N	PARTICIPANT	\N	PRESENT	0
760744	760741	20264J	PARTICIPANT	\N	PRESENT	0
760745	760742	20132W	PARTICIPANT	\N	PRESENT	0
760747	760426	14213J	PARTICIPANT	\N	PRESENT	0
760748	760426	20090E	PARTICIPANT	\N	PRESENT	0
760749	760426	19569H	PARTICIPANT	\N	PRESENT	0
760750	760426	19691J	PARTICIPANT	\N	PRESENT	0
760751	760426	04092N	PARTICIPANT	0	PRESENT	0
760752	760426	21097R	PARTICIPANT	\N	PRESENT	0
760753	760426	14195A	PARTICIPANT	\N	PRESENT	0
760754	760426	19703U	PARTICIPANT	\N	PRESENT	0
760755	760426	21081H	PARTICIPANT	\N	PRESENT	0
760756	760426	19758L	PARTICIPANT	\N	PRESENT	0
760757	760426	19760E	PARTICIPANT	\N	PRESENT	0
760758	760426	17965H	PARTICIPANT	\N	PRESENT	0
760759	760426	21049H	PARTICIPANT	\N	PRESENT	0
760760	760426	21045D	PARTICIPANT	\N	PRESENT	0
760761	760426	19553Y	PARTICIPANT	\N	PRESENT	0
760762	760426	21064G	PARTICIPANT	\N	PRESENT	0
760763	760426	19798U	PARTICIPANT	\N	PRESENT	0
760764	760426	21046E	PARTICIPANT	\N	PRESENT	0
760802	760801	19631V	PARTICIPANT	\N	PRESENT	0
760804	760803	19631V	PARTICIPANT	\N	PRESENT	0
760805	760800	19631V	PARTICIPANT	\N	PRESENT	0
760807	760806	19631V	PARTICIPANT	\N	PRESENT	0
760809	760808	14225N	PARTICIPANT	\N	PRESENT	0
760867	760823	21072G	PARTICIPANT	\N	PRESENT	0
760887	760737	19629C	PARTICIPANT	\N	PRESENT	0
760884	760737	07004J	PARTICIPANT	\N	PRESENT	0
760885	760737	20024T	PARTICIPANT	\N	PRESENT	0
760877	760823	20070A	PARTICIPANT	\N	PRESENT	0
760886	760737	19711U	PARTICIPANT	\N	PRESENT	0
760888	760737	21087P	PARTICIPANT	\N	PRESENT	0
760880	760737	14229S	PARTICIPANT	\N	PRESENT	0
760881	760737	20126Y	PARTICIPANT	\N	PRESENT	0
760889	760737	21041Y	PARTICIPANT	\N	PRESENT	0
760890	760737	11040E	PARTICIPANT	\N	PRESENT	0
760891	760737	20070A	PARTICIPANT	\N	PRESENT	0
760892	760737	20080C	PARTICIPANT	\N	PRESENT	0
760893	760737	18083K	PARTICIPANT	\N	PRESENT	0
760894	760737	20050V	PARTICIPANT	\N	PRESENT	0
760895	760737	21052C	PARTICIPANT	\N	PRESENT	0
760896	760737	21076L	PARTICIPANT	\N	PRESENT	0
760897	760737	20062A	PARTICIPANT	\N	PRESENT	0
760898	760737	21075K	PARTICIPANT	\N	PRESENT	0
760899	760737	19697Q	PARTICIPANT	\N	PRESENT	0
760900	760737	20092G	PARTICIPANT	\N	PRESENT	0
760901	760737	21086N	PARTICIPANT	\N	PRESENT	0
760902	760737	19479G	PARTICIPANT	\N	PRESENT	0
760903	760737	20036X	PARTICIPANT	\N	PRESENT	0
760904	760737	11065P	PARTICIPANT	\N	PRESENT	0
760905	760737	14251Q	PARTICIPANT	\N	PRESENT	0
760906	760737	19585H	PARTICIPANT	\N	PRESENT	0
760907	760737	14259Y	PARTICIPANT	\N	PRESENT	0
760908	760737	14225N	PARTICIPANT	\N	PRESENT	0
760909	760737	14331P	PARTICIPANT	\N	PRESENT	0
760910	760737	21072G	PARTICIPANT	\N	PRESENT	0
760911	760737	21044C	PARTICIPANT	\N	PRESENT	0
760912	760737	14083S	PARTICIPANT	\N	PRESENT	0
760913	760737	20134Y	PARTICIPANT	\N	PRESENT	0
760915	760737	11070L	PARTICIPANT	\N	PRESENT	0
760916	760737	20108W	PARTICIPANT	\N	PRESENT	0
760917	760737	21079P	PARTICIPANT	\N	PRESENT	0
760918	760737	21048G	PARTICIPANT	\N	PRESENT	0
760921	760737	07029T	PARTICIPANT	\N	PRESENT	0
760922	760737	20266L	PARTICIPANT	\N	PRESENT	0
760923	760737	21069M	PARTICIPANT	\N	PRESENT	0
760924	760737	21037D	PARTICIPANT	\N	PRESENT	0
760931	760737	99004R	PARTICIPANT	\N	PRESENT	0
760934	760737	14231L	PARTICIPANT	\N	PRESENT	0
760971	760928	19593H	PARTICIPANT	\N	PRESENT	0
760972	760928	19699S	PARTICIPANT	\N	PRESENT	0
760973	760928	21059K	PARTICIPANT	\N	PRESENT	0
760974	760928	20052X	PARTICIPANT	\N	PRESENT	0
760975	760928	14229S	PARTICIPANT	\N	PRESENT	0
760976	760928	20058E	PARTICIPANT	\N	PRESENT	0
760977	760928	20264J	PARTICIPANT	\N	PRESENT	0
760978	760928	19735D	PARTICIPANT	\N	PRESENT	0
760979	760928	18395Y	PARTICIPANT	\N	PRESENT	0
760980	760928	14109K	PARTICIPANT	\N	PRESENT	0
760981	760928	21089R	PARTICIPANT	\N	PRESENT	0
760982	760928	21077M	PARTICIPANT	\N	PRESENT	0
760983	760928	19621T	PRESIDENT	0	PRESENT	0
760984	760970	14253S	PARTICIPANT	\N	PRESENT	0
760986	760985	14253S	PARTICIPANT	\N	PRESENT	0
760992	760991	08010L	PARTICIPANT	\N	PRESENT	0
760994	760993	08010L	PARTICIPANT	\N	PRESENT	0
761104	761029	14331P	PARTICIPANT	\N	PRESENT	0
761105	761029	20062A	PARTICIPANT	\N	PRESENT	0
761106	761029	11048N	PARTICIPANT	\N	PRESENT	0
761107	761029	20080C	PARTICIPANT	\N	PRESENT	0
761108	761029	21090J	PARTICIPANT	\N	PRESENT	0
761109	761029	19335Q	PARTICIPANT	\N	PRESENT	0
761110	761029	20126Y	PARTICIPANT	\N	PRESENT	0
761111	761029	19711U	PARTICIPANT	\N	PRESENT	0
761112	761029	20094J	PARTICIPANT	\N	PRESENT	0
761113	761029	11070L	PARTICIPANT	\N	PRESENT	0
761114	761029	07029T	PARTICIPANT	\N	PRESENT	0
761115	761029	14083S	PARTICIPANT	\N	PRESENT	0
761116	761029	20070A	PARTICIPANT	\N	PRESENT	0
761117	761029	08010L	PARTICIPANT	\N	PRESENT	0
761118	761029	20116W	PARTICIPANT	\N	PRESENT	0
760968	760935	14253S	PARTICIPANT	\N	PRESENT	0
761129	761029	19349W	PARTICIPANT	\N	PRESENT	0
761119	761029	21048G	PARTICIPANT	\N	PRESENT	0
761120	761029	11053K	PARTICIPANT	\N	PRESENT	0
761121	761029	20044X	PARTICIPANT	\N	PRESENT	0
761122	761029	19479G	PARTICIPANT	\N	PRESENT	0
761124	761123	19593H	PARTICIPANT	\N	PRESENT	0
761125	761123	21092L	PARTICIPANT	\N	PRESENT	0
761134	761123	21043B	PARTICIPANT	\N	PRESENT	0
761135	761123	20054A	PARTICIPANT	\N	PRESENT	0
761136	761123	14237S	PARTICIPANT	\N	PRESENT	0
761137	761123	21088Q	PARTICIPANT	\N	PRESENT	0
761138	761123	19760E	PARTICIPANT	\N	PRESENT	0
761153	761123	20048C	PARTICIPANT	\N	PRESENT	0
761140	761123	21053D	PARTICIPANT	\N	PRESENT	0
761141	761123	19629C	PARTICIPANT	\N	PRESENT	0
761142	761123	19585H	PARTICIPANT	\N	PRESENT	0
761143	761123	20040T	PARTICIPANT	\N	PRESENT	0
761151	761123	19681G	PARTICIPANT	\N	PRESENT	0
761145	761123	19687N	PARTICIPANT	\N	PRESENT	0
761146	761123	18083K	PARTICIPANT	\N	PRESENT	0
761150	761123	21067K	PARTICIPANT	\N	PRESENT	0
761149	761123	17737W	PARTICIPANT	\N	PRESENT	0
761152	761123	14219Q	PARTICIPANT	\N	PRESENT	0
761154	761123	21087P	PARTICIPANT	\N	PRESENT	0
761155	761123	20066E	PARTICIPANT	\N	PRESENT	0
761156	761123	21072G	PARTICIPANT	\N	PRESENT	0
741379	741106	20126Y	PARTICIPANT	\N	PRESENT	0
740128	738364	20914V	PARTICIPANT	\N	PRESENT	0
740130	738364	11074Q	PARTICIPANT	\N	PRESENT	0
741380	741106	14151M	PARTICIPANT	\N	PRESENT	0
741377	741106	19543W	PARTICIPANT	\N	PRESENT	0
741378	741106	14133K	PARTICIPANT	\N	PRESENT	0
741381	741106	20054A	PARTICIPANT	\N	PRESENT	0
741382	741106	08034U	PARTICIPANT	\N	PRESENT	0
741383	741106	20020P	PARTICIPANT	\N	PRESENT	0
741384	741106	20120S	PARTICIPANT	\N	PRESENT	0
741385	741106	20252E	PARTICIPANT	\N	PRESENT	0
741386	741106	05008E	PARTICIPANT	\N	PRESENT	0
741387	741106	20152B	PARTICIPANT	\N	PRESENT	0
741388	741106	19415P	PARTICIPANT	\N	PRESENT	0
741389	741106	19798U	PARTICIPANT	\N	PRESENT	0
741390	741106	14193X	PARTICIPANT	\N	PRESENT	0
741394	741106	08069G	PARTICIPANT	\N	PRESENT	0
741392	741106	14215L	PARTICIPANT	\N	PRESENT	0
741393	741106	14217N	PARTICIPANT	\N	PRESENT	0
741407	741106	19643A	PARTICIPANT	\N	PRESENT	0
741396	741106	11045K	PARTICIPANT	\N	PRESENT	0
741398	741106	04047H	PARTICIPANT	\N	PRESENT	0
741399	741106	19782L	PARTICIPANT	\N	PRESENT	0
741400	741106	14053L	PARTICIPANT	\N	PRESENT	0
741409	741106	10006L	PARTICIPANT	\N	PRESENT	0
741404	741106	20180F	PARTICIPANT	\N	PRESENT	0
741405	741106	19762G	PARTICIPANT	\N	PRESENT	0
741406	741106	01048V	PARTICIPANT	\N	PRESENT	0
741408	741106	20094J	PARTICIPANT	\N	PRESENT	0
741410	741106	14237S	PARTICIPANT	\N	PRESENT	0
741412	741106	20138D	PARTICIPANT	\N	PRESENT	0
741414	741106	20058E	PARTICIPANT	\N	PRESENT	0
741420	741106	20124W	PARTICIPANT	\N	PRESENT	0
741416	741106	19251M	PARTICIPANT	\N	PRESENT	0
741417	741106	11053K	PARTICIPANT	\N	PRESENT	0
741421	741106	95041E	PARTICIPANT	\N	PRESENT	0
741419	741106	14357A	PARTICIPANT	\N	PRESENT	0
741431	741106	11097X	PARTICIPANT	\N	PRESENT	0
741424	741106	04043D	PARTICIPANT	\N	PRESENT	0
741425	741106	11110B	PARTICIPANT	\N	PRESENT	0
741432	741106	20092G	PARTICIPANT	\N	PRESENT	0
741428	741106	19701S	PARTICIPANT	\N	PRESENT	0
741434	741106	20112S	PARTICIPANT	\N	PRESENT	0
741430	741106	20044X	PARTICIPANT	\N	PRESENT	0
741433	741106	11027H	PARTICIPANT	\N	PRESENT	0
741435	741106	19057M	PARTICIPANT	\N	PRESENT	0
741436	741106	14257W	PARTICIPANT	\N	PRESENT	0
741437	741106	19329S	PARTICIPANT	\N	PRESENT	0
741438	741106	11083R	PARTICIPANT	\N	PRESENT	0
741439	741106	11026G	PARTICIPANT	\N	PRESENT	0
741440	741106	08012N	PARTICIPANT	\N	PRESENT	0
741447	741106	19713W	PARTICIPANT	\N	PRESENT	0
741442	741106	14251Q	PARTICIPANT	\N	PRESENT	0
741443	741106	11064N	PARTICIPANT	\N	PRESENT	0
741444	741106	19585H	PARTICIPANT	\N	PRESENT	0
741445	741106	14205J	PARTICIPANT	\N	PRESENT	0
741446	741106	04059M	PARTICIPANT	\N	PRESENT	0
741448	741106	14042U	PARTICIPANT	\N	PRESENT	0
741449	741106	20048C	PARTICIPANT	\N	PRESENT	0
741450	741106	14327T	PARTICIPANT	\N	PRESENT	0
741451	741106	11115U	PARTICIPANT	\N	PRESENT	0
741452	741106	98022P	PARTICIPANT	\N	PRESENT	0
741453	741106	20132W	PARTICIPANT	\N	PRESENT	0
741454	741106	20116W	PARTICIPANT	\N	PRESENT	0
741455	741106	04071H	PARTICIPANT	\N	PRESENT	0
741456	741106	19647E	PARTICIPANT	\N	PRESENT	0
741457	741106	14147R	PARTICIPANT	\N	PRESENT	0
741458	741106	20084G	PARTICIPANT	\N	PRESENT	0
741459	741106	19693L	PARTICIPANT	\N	PRESENT	0
741460	741106	19683J	PARTICIPANT	\N	PRESENT	0
741461	741106	16685X	PARTICIPANT	\N	PRESENT	0
741462	741106	19741B	PARTICIPANT	\N	PRESENT	0
741468	741106	04070G	PARTICIPANT	\N	PRESENT	0
741466	741106	14069U	PARTICIPANT	\N	PRESENT	0
741465	741106	14071N	PARTICIPANT	\N	PRESENT	0
741467	741106	14031R	PARTICIPANT	\N	PRESENT	0
741476	741106	20142Y	PARTICIPANT	\N	PRESENT	0
741470	741106	01034P	PARTICIPANT	\N	PRESENT	0
741471	741106	11070L	PARTICIPANT	\N	PRESENT	0
741475	741106	07033P	PARTICIPANT	\N	PRESENT	0
741479	741106	20136B	PARTICIPANT	\N	PRESENT	0
741480	741106	19575F	PARTICIPANT	\N	PRESENT	0
741481	741106	11104D	PARTICIPANT	\N	PRESENT	0
741483	741106	11048N	PARTICIPANT	\N	PRESENT	0
741484	741106	20060X	PARTICIPANT	\N	PRESENT	0
741485	741106	20104S	PARTICIPANT	\N	PRESENT	0
741486	741106	19531S	PARTICIPANT	\N	PRESENT	0
741487	741106	08015R	PARTICIPANT	\N	PRESENT	0
741488	741106	19749K	PARTICIPANT	\N	PRESENT	0
741489	741106	08009T	PARTICIPANT	\N	PRESENT	0
741493	741106	20286Q	PARTICIPANT	\N	PRESENT	0
741491	741106	19399H	PARTICIPANT	\N	PRESENT	0
741495	741106	14189C	PARTICIPANT	\N	PRESENT	0
741497	741106	14249W	PARTICIPANT	\N	PRESENT	0
741504	741106	19573D	PARTICIPANT	\N	PRESENT	0
741498	741106	20114U	PARTICIPANT	\N	PRESENT	0
741508	741106	19669L	PARTICIPANT	\N	PRESENT	0
741509	741106	19739H	PARTICIPANT	\N	PRESENT	0
741510	741106	20128B	PARTICIPANT	\N	PRESENT	0
741517	741106	11054L	PARTICIPANT	\N	PRESENT	0
741823	740612	14026U	PARTICIPANT	\N	PRESENT	0
741827	740612	20078J	PARTICIPANT	\N	PRESENT	0
741828	740612	14021P	PARTICIPANT	\N	PRESENT	0
741829	740612	19489J	PARTICIPANT	\N	PRESENT	0
741830	740612	19527W	PARTICIPANT	\N	PRESENT	0
741831	740612	20030R	PARTICIPANT	\N	PRESENT	0
741832	740612	19631V	PARTICIPANT	\N	PRESENT	0
741833	740612	20134Y	PARTICIPANT	\N	PRESENT	0
741835	740612	11110B	PARTICIPANT	\N	PRESENT	0
741836	740612	11031D	PARTICIPANT	\N	PRESENT	0
741837	740612	19565D	PARTICIPANT	\N	PRESENT	0
741838	740612	20046A	PARTICIPANT	\N	PRESENT	0
741839	740612	11065P	PARTICIPANT	\N	PRESENT	0
741840	740612	14037X	PARTICIPANT	\N	PRESENT	0
741841	740612	20084G	PARTICIPANT	\N	PRESENT	0
741843	740612	14225N	PARTICIPANT	\N	PRESENT	0
741844	740612	11012A	PARTICIPANT	\N	PRESENT	0
741846	740612	19563B	PARTICIPANT	\N	PRESENT	0
741847	740612	14207L	PARTICIPANT	\N	PRESENT	0
741848	740612	14107H	PARTICIPANT	\N	PRESENT	0
741850	740612	08073C	PARTICIPANT	\N	PRESENT	0
741851	740612	20102Q	PARTICIPANT	\N	PRESENT	0
741852	740612	98022P	PARTICIPANT	\N	PRESENT	0
741853	740612	14089Y	PARTICIPANT	\N	PRESENT	0
741854	740612	14189C	PARTICIPANT	\N	PRESENT	0
741855	740612	20066E	PARTICIPANT	\N	PRESENT	0
741856	740612	19685L	PARTICIPANT	\N	PRESENT	0
741857	740612	14357A	PARTICIPANT	\N	PRESENT	0
741858	740612	20126Y	PARTICIPANT	\N	PRESENT	0
741859	740612	20020P	PARTICIPANT	\N	PRESENT	0
741860	740612	20124W	PARTICIPANT	\N	PRESENT	0
741861	740612	19762G	PARTICIPANT	\N	PRESENT	0
741862	740612	20090E	PARTICIPANT	\N	PRESENT	0
741864	740612	20032T	PARTICIPANT	\N	PRESENT	0
741865	740612	17737W	PARTICIPANT	\N	PRESENT	0
741866	740612	05012A	PARTICIPANT	\N	PRESENT	0
741867	740612	20024T	PARTICIPANT	\N	PRESENT	0
741868	740612	20104S	PARTICIPANT	\N	PRESENT	0
741869	740612	19399H	PARTICIPANT	\N	PRESENT	0
741870	740612	14033T	PARTICIPANT	\N	PRESENT	0
741871	740612	18083K	PARTICIPANT	\N	PRESENT	0
741872	740612	19741B	PARTICIPANT	\N	PRESENT	0
741873	740612	19573D	PARTICIPANT	\N	PRESENT	0
741874	740612	20098N	PARTICIPANT	\N	PRESENT	0
741875	740612	19467C	PARTICIPANT	\N	PRESENT	0
741876	740612	20026V	PARTICIPANT	\N	PRESENT	0
741877	740612	20062A	PARTICIPANT	\N	PRESENT	0
741878	740612	01058X	PARTICIPANT	\N	PRESENT	0
741879	740612	19798U	PARTICIPANT	\N	PRESENT	0
741880	740612	20252E	PARTICIPANT	\N	PRESENT	0
741881	740612	97011G	PARTICIPANT	\N	PRESENT	0
741882	740612	20180F	PARTICIPANT	\N	PRESENT	0
741884	740612	20980G	PARTICIPANT	\N	PRESENT	0
741885	740612	14259Y	PARTICIPANT	\N	PRESENT	0
741886	740612	14031R	PARTICIPANT	\N	PRESENT	0
741887	740612	14169X	PARTICIPANT	\N	PRESENT	0
741888	740612	20022R	PARTICIPANT	\N	PRESENT	0
741889	740612	20076G	PARTICIPANT	\N	PRESENT	0
741890	740612	20068G	PARTICIPANT	\N	PRESENT	0
741891	740612	19693L	PARTICIPANT	\N	PRESENT	0
741892	740612	19629C	PARTICIPANT	\N	PRESENT	0
754748	754527	20060X	PARTICIPANT	\N	PRESENT	0
754749	754527	19507S	PARTICIPANT	\N	PRESENT	0
754750	754527	21066J	PARTICIPANT	\N	PRESENT	0
754751	754527	20286Q	PARTICIPANT	\N	PRESENT	0
754752	754527	14207L	PARTICIPANT	\N	PRESENT	0
754753	754527	20084G	PARTICIPANT	\N	PRESENT	0
754754	754527	19705W	PARTICIPANT	\N	EXCUSE	0
754755	754527	19707Y	PARTICIPANT	\N	EXCUSE	0
754757	754527	20066E	PARTICIPANT	\N	EXCUSE	0
754758	754527	20144B	PARTICIPANT	\N	PRESENT	0
754759	753747	21082J	PARTICIPANT	\N	PRESENT	0
754760	753747	20076G	PARTICIPANT	\N	PRESENT	0
754761	753747	21042A	PARTICIPANT	\N	PRESENT	0
754762	753747	19387D	PARTICIPANT	\N	PRESENT	0
754763	753747	14219Q	PRESIDENT	0	PRESENT	0
754764	753747	19820Y	PARTICIPANT	\N	PRESENT	0
754765	753747	19826F	PARTICIPANT	\N	PRESENT	0
754766	753747	21062E	PARTICIPANT	\N	PRESENT	0
754767	753747	21065H	PARTICIPANT	\N	PRESENT	0
754768	753747	14237S	PARTICIPANT	\N	PRESENT	0
754769	753747	19551W	PARTICIPANT	\N	PRESENT	0
754770	753747	20100N	PARTICIPANT	\N	PRESENT	0
754771	753747	18083K	PARTICIPANT	\N	PRESENT	0
754772	753747	21084L	PARTICIPANT	\N	PRESENT	0
754773	753747	05012A	PARTICIPANT	\N	PRESENT	0
754774	753747	20106U	PARTICIPANT	\N	PRESENT	0
754775	753747	20118Y	PARTICIPANT	\N	PRESENT	0
754776	753747	15197G	PARTICIPANT	\N	PRESENT	0
754777	753747	14107H	PARTICIPANT	\N	PRESENT	0
754778	753747	21080G	PARTICIPANT	\N	PRESENT	0
754779	753747	20020P	PARTICIPANT	\N	PRESENT	0
754780	753747	20120S	PARTICIPANT	\N	PRESENT	0
754781	753747	21051B	PARTICIPANT	\N	PRESENT	0
754782	753747	20032T	PARTICIPANT	\N	PRESENT	0
754783	753747	21053D	PARTICIPANT	\N	PRESENT	0
754784	753747	20136B	PARTICIPANT	\N	PRESENT	0
754785	753747	14031R	PARTICIPANT	\N	PRESENT	0
754786	753747	19251M	PARTICIPANT	\N	PRESENT	0
754787	753747	20046A	PARTICIPANT	\N	PRESENT	0
754788	753747	17229F	PARTICIPANT	\N	PRESENT	0
754789	753747	14169X	PARTICIPANT	\N	PRESENT	0
754790	753747	21047F	PARTICIPANT	\N	PRESENT	0
754791	753747	20068G	PARTICIPANT	\N	PRESENT	0
754792	753747	21070E	PARTICIPANT	\N	PRESENT	0
754793	753747	19619A	PARTICIPANT	\N	PRESENT	0
754796	753662	86034E	PARTICIPANT	\N	PRESENT	0
754797	753662	20086J	PARTICIPANT	\N	PRESENT	0
754798	753662	21087P	PARTICIPANT	\N	PRESENT	0
754799	753662	20062A	PARTICIPANT	\N	PRESENT	0
754800	753662	21059K	PARTICIPANT	\N	PRESENT	0
754801	753662	21052C	PARTICIPANT	\N	PRESENT	0
754802	753662	19782L	PARTICIPANT	\N	PRESENT	0
754803	753662	14223L	PARTICIPANT	\N	PRESENT	0
754804	753662	98022P	PARTICIPANT	\N	PRESENT	0
754805	753662	21091K	PARTICIPANT	\N	PRESENT	0
754806	753662	20150Y	PARTICIPANT	\N	PRESENT	0
754807	753662	19593H	PARTICIPANT	\N	PRESENT	0
754808	753662	20046A	PARTICIPANT	\N	PRESENT	0
754809	753662	21030V	PARTICIPANT	\N	PRESENT	0
754810	753662	21062E	PARTICIPANT	\N	PRESENT	0
754811	753662	17779H	PARTICIPANT	\N	PRESENT	0
754812	753662	21089R	PARTICIPANT	\N	PRESENT	0
754813	753662	18395Y	PARTICIPANT	\N	PRESENT	0
754814	753662	18207D	PARTICIPANT	\N	PRESENT	0
754815	753662	14097Y	PARTICIPANT	\N	PRESENT	0
754816	753662	19347U	PARTICIPANT	\N	PRESENT	0
754817	753662	08073C	PARTICIPANT	\N	PRESENT	0
754818	753662	19649G	PARTICIPANT	\N	PRESENT	0
754819	753662	21045D	PARTICIPANT	\N	PRESENT	0
754820	753662	21077M	PARTICIPANT	\N	PRESENT	0
754821	753662	14207L	PARTICIPANT	\N	PRESENT	0
754822	753662	21031W	PARTICIPANT	\N	PRESENT	0
754823	753662	20106U	PARTICIPANT	\N	PRESENT	0
754824	753662	19621T	PARTICIPANT	\N	PRESENT	0
754825	753662	18083K	PARTICIPANT	\N	PRESENT	0
754826	753662	04008A	PARTICIPANT	\N	PRESENT	0
754827	753662	19673G	PARTICIPANT	\N	PRESENT	0
754828	753662	08011M	PARTICIPANT	\N	PRESENT	0
754829	753662	19575F	PARTICIPANT	\N	PRESENT	0
754830	753662	01058X	PARTICIPANT	\N	PRESENT	0
754831	753662	19760E	PARTICIPANT	\N	PRESENT	0
754832	753662	19703U	PARTICIPANT	\N	PRESENT	0
754833	753662	21084L	PARTICIPANT	\N	PRESENT	0
754834	753662	11040E	PARTICIPANT	\N	PRESENT	0
754835	753662	19758L	PARTICIPANT	\N	PRESENT	0
754836	753662	11056N	PARTICIPANT	\N	PRESENT	0
754837	753662	20102Q	PARTICIPANT	\N	PRESENT	0
754838	753662	21075K	PARTICIPANT	\N	PRESENT	0
754839	753662	04033B	PARTICIPANT	\N	PRESENT	0
754840	753662	21049H	PARTICIPANT	\N	PRESENT	0
754841	753662	19679N	PARTICIPANT	\N	PRESENT	0
754842	753662	19687N	PARTICIPANT	\N	PRESENT	0
754843	753662	19681G	PARTICIPANT	\N	PRESENT	0
754844	753662	21088Q	PARTICIPANT	\N	PRESENT	0
754845	753662	21093M	PARTICIPANT	\N	PRESENT	0
754846	753662	20142Y	PARTICIPANT	\N	PRESENT	0
754847	753662	21094N	PARTICIPANT	\N	PRESENT	0
754848	753662	21079P	PARTICIPANT	\N	PRESENT	0
754849	753662	20266L	PARTICIPANT	\N	PRESENT	0
754850	753662	20130U	PARTICIPANT	\N	PRESENT	0
754851	753662	20092G	PARTICIPANT	\N	PRESENT	0
754852	753662	20076G	PARTICIPANT	\N	PRESENT	0
754853	753662	14259Y	PARTICIPANT	\N	PRESENT	0
754854	753662	14123H	PARTICIPANT	\N	PRESENT	0
754855	753662	08069G	PARTICIPANT	\N	PRESENT	0
754856	753662	04042C	PARTICIPANT	\N	PRESENT	0
754857	753662	21044C	PARTICIPANT	\N	PRESENT	0
754858	753662	14169X	PARTICIPANT	\N	PRESENT	0
754859	753662	19573D	PARTICIPANT	\N	PRESENT	0
754860	753662	21080G	PARTICIPANT	\N	PRESENT	0
754861	753662	10015M	PARTICIPANT	\N	PRESENT	0
754862	753662	08028W	PARTICIPANT	\N	PRESENT	0
754863	753662	21073H	PARTICIPANT	\N	PRESENT	0
754864	753662	21071F	PARTICIPANT	\N	PRESENT	0
754865	753662	21037D	PARTICIPANT	\N	PRESENT	0
754866	753662	21072G	PARTICIPANT	\N	PRESENT	0
754867	753662	20036X	PARTICIPANT	\N	PRESENT	0
754868	753662	14193X	PARTICIPANT	\N	PRESENT	0
754869	753662	14237S	PARTICIPANT	\N	PRESENT	0
754870	753662	20044X	PARTICIPANT	\N	PRESENT	0
754871	753662	20134Y	PARTICIPANT	\N	PRESENT	0
754872	753662	14215L	PARTICIPANT	\N	PRESENT	0
754873	753662	21048G	PARTICIPANT	\N	PRESENT	0
754874	753662	20022R	PARTICIPANT	\N	PRESENT	0
754875	753662	05012A	PARTICIPANT	\N	PRESENT	0
754876	753662	11090Q	PARTICIPANT	\N	PRESENT	0
754877	753662	21055F	PARTICIPANT	\N	PRESENT	0
754878	753662	14031R	PARTICIPANT	\N	PRESENT	0
754879	753662	19421M	PARTICIPANT	\N	PRESENT	0
754880	753662	14253S	PARTICIPANT	\N	PRESENT	0
754881	753662	20136B	PARTICIPANT	\N	PRESENT	0
754882	753662	21043B	PARTICIPANT	\N	PRESENT	0
754883	753662	19383Y	PARTICIPANT	\N	PRESENT	0
754884	753662	17737W	PARTICIPANT	\N	PRESENT	0
754885	753662	14331P	PARTICIPANT	\N	PRESENT	0
754886	753662	21092L	PARTICIPANT	\N	PRESENT	0
754887	753662	14173T	PARTICIPANT	\N	PRESENT	0
754888	753662	19447X	PARTICIPANT	\N	PRESENT	0
754889	753662	14249W	PARTICIPANT	\N	PRESENT	0
754890	753662	21068L	PARTICIPANT	\N	PRESENT	0
754891	753662	20096L	PARTICIPANT	\N	PRESENT	0
754892	753662	20180F	PARTICIPANT	\N	PRESENT	0
754893	753662	20026V	PARTICIPANT	\N	PRESENT	0
754894	753662	20128B	PARTICIPANT	\N	PRESENT	0
754895	753662	19591F	PARTICIPANT	\N	PRESENT	0
754896	753662	19954N	PARTICIPANT	\N	PRESENT	0
754897	753662	20138D	PARTICIPANT	\N	PRESENT	0
754898	753662	14147R	PARTICIPANT	\N	PRESENT	0
754899	753662	14037X	PARTICIPANT	\N	PRESENT	0
754900	753662	14038Y	PARTICIPANT	\N	PRESENT	0
754901	753662	21047F	PARTICIPANT	\N	PRESENT	0
754902	753662	21097R	PARTICIPANT	\N	PRESENT	0
754903	753662	20032T	PARTICIPANT	\N	PRESENT	0
754904	753662	08061X	PARTICIPANT	\N	PRESENT	0
754905	753662	20140W	PARTICIPANT	\N	PRESENT	0
754906	753662	19349W	PARTICIPANT	\N	PRESENT	0
754907	753662	20038A	PARTICIPANT	\N	PRESENT	0
754908	753662	04045F	PARTICIPANT	\N	PRESENT	0
754909	753662	19301E	PARTICIPANT	\N	PRESENT	0
754910	753662	14033T	PARTICIPANT	\N	PRESENT	0
754911	753662	21074J	PARTICIPANT	\N	PRESENT	0
740786	740785	19701S	PARTICIPANT	\N	PRESENT	0
740787	740785	14097Y	PARTICIPANT	\N	PRESENT	0
740789	740788	14097Y	PARTICIPANT	\N	PRESENT	0
740790	740788	19701S	PARTICIPANT	\N	PRESENT	0
740795	740793	14033T	PARTICIPANT	\N	PRESENT	0
740796	740793	14073Q	PARTICIPANT	\N	PRESENT	0
740797	740793	12041X	PARTICIPANT	\N	PRESENT	0
740798	740794	14033T	PARTICIPANT	\N	PRESENT	0
740799	740794	14073Q	PARTICIPANT	\N	PRESENT	0
740800	740794	12041X	PARTICIPANT	\N	PRESENT	0
740802	740801	19701S	PARTICIPANT	\N	PRESENT	0
740803	740801	20064C	PARTICIPANT	\N	PRESENT	0
740807	740806	01057W	PARTICIPANT	\N	PRESENT	0
747825	746028	19719D	PARTICIPANT	\N	PRESENT	0
747831	746028	04045F	PARTICIPANT	\N	PRESENT	0
747832	746028	20142Y	PARTICIPANT	\N	PRESENT	0
747833	746028	18193Q	PARTICIPANT	\N	PRESENT	0
747834	746028	19782L	PARTICIPANT	\N	PRESENT	0
747835	746028	20050V	PARTICIPANT	\N	PRESENT	0
747836	746028	20252E	PARTICIPANT	\N	PRESENT	0
747837	746028	20072C	PARTICIPANT	\N	PRESENT	0
747838	746028	20090E	PARTICIPANT	\N	PRESENT	0
747839	746028	04085P	PARTICIPANT	\N	PRESENT	0
747840	746028	14030Q	PARTICIPANT	\N	PRESENT	0
747841	746028	14205J	PARTICIPANT	\N	PRESENT	0
747842	746028	19467C	PARTICIPANT	\N	PRESENT	0
747843	746028	19826F	PARTICIPANT	\N	PRESENT	0
747844	746028	20076G	PARTICIPANT	\N	PRESENT	0
747845	746028	14069U	PARTICIPANT	\N	PRESENT	0
747846	746028	20248J	PARTICIPANT	\N	PRESENT	0
747847	746028	19651A	PARTICIPANT	\N	PRESENT	0
747848	746028	20152B	PARTICIPANT	\N	PRESENT	0
747849	746028	20138D	PARTICIPANT	\N	PRESENT	0
747850	746028	14179A	PARTICIPANT	\N	PRESENT	0
747851	746028	20980G	PARTICIPANT	\N	PRESENT	0
747852	746028	19611R	PARTICIPANT	\N	PRESENT	0
747853	746028	14053L	PARTICIPANT	\N	PRESENT	0
747855	746028	20132W	PARTICIPANT	\N	PRESENT	0
747856	746028	11067R	PARTICIPANT	\N	PRESENT	0
747857	746028	14259Y	PARTICIPANT	\N	PRESENT	0
747858	746028	20134Y	PARTICIPANT	\N	PRESENT	0
747860	746028	14217N	PARTICIPANT	\N	PRESENT	0
747870	746028	20092G	PARTICIPANT	\N	PRESENT	0
747873	746028	14083S	PARTICIPANT	\N	PRESENT	0
747874	746028	19725B	PARTICIPANT	\N	PRESENT	0
747906	746029	19467C	PARTICIPANT	\N	PRESENT	0
747907	746029	20134Y	PARTICIPANT	\N	PRESENT	0
747908	746029	19611R	PARTICIPANT	\N	PRESENT	0
747909	746029	20092G	PARTICIPANT	\N	PRESENT	0
747910	746029	14083S	PARTICIPANT	\N	PRESENT	0
747911	746029	14030Q	PARTICIPANT	\N	PRESENT	0
747912	746029	20248J	PARTICIPANT	\N	PRESENT	0
747913	746029	14217N	PARTICIPANT	\N	PRESENT	0
747914	746029	20090E	PARTICIPANT	\N	PRESENT	0
747915	746029	20138D	PARTICIPANT	\N	PRESENT	0
747916	746029	20152B	PARTICIPANT	\N	PRESENT	0
747917	746029	20252E	PARTICIPANT	\N	PRESENT	0
747918	746029	19651A	PARTICIPANT	\N	PRESENT	0
747919	746029	04045F	PARTICIPANT	\N	PRESENT	0
747920	746029	20132W	PARTICIPANT	\N	PRESENT	0
747921	746029	04085P	PARTICIPANT	\N	PRESENT	0
747937	746029	97011G	PARTICIPANT	\N	PRESENT	0
747923	747823	20090E	PARTICIPANT	\N	PRESENT	0
747924	747823	19711U	PARTICIPANT	\N	PRESENT	0
747925	747823	11077T	PARTICIPANT	\N	PRESENT	0
747926	747823	14187A	PARTICIPANT	\N	PRESENT	0
747927	747823	19347U	PARTICIPANT	\N	PRESENT	0
747928	747823	20286Q	PARTICIPANT	\N	PRESENT	0
747929	747823	20298U	PARTICIPANT	\N	PRESENT	0
747930	747823	20124W	PARTICIPANT	\N	PRESENT	0
747931	747823	14257W	PARTICIPANT	\N	PRESENT	0
747932	746029	14179A	PARTICIPANT	\N	PRESENT	0
747933	746029	14205J	PARTICIPANT	\N	PRESENT	0
747934	746029	14069U	PARTICIPANT	\N	PRESENT	0
747904	746029	19719D	PARTICIPANT	\N	PRESENT	0
747905	746029	20980G	PARTICIPANT	\N	PRESENT	0
747935	746029	14229S	PARTICIPANT	\N	PRESENT	0
747936	746029	20082E	PARTICIPANT	\N	PRESENT	0
747938	746029	20114U	PARTICIPANT	\N	PRESENT	0
747939	746029	20142Y	PARTICIPANT	\N	PRESENT	0
747949	746029	19441R	PARTICIPANT	\N	PRESENT	0
747950	746029	14251Q	PARTICIPANT	\N	PRESENT	0
747951	746029	19723Y	PARTICIPANT	\N	PRESENT	0
747952	746029	16685X	PARTICIPANT	\N	PRESENT	0
747953	746029	19782L	PARTICIPANT	\N	PRESENT	0
747954	746029	11031D	PARTICIPANT	\N	PRESENT	0
747955	746029	19697Q	PARTICIPANT	\N	PRESENT	0
747979	746030	19697Q	PARTICIPANT	\N	PRESENT	0
747980	746030	17965H	PARTICIPANT	\N	PRESENT	0
747981	746030	20134Y	PARTICIPANT	\N	PRESENT	0
747982	746030	20142Y	PARTICIPANT	\N	PRESENT	0
747983	746030	20132W	PARTICIPANT	\N	PRESENT	0
747984	746030	20980G	PARTICIPANT	\N	PRESENT	0
747985	746030	19723Y	PARTICIPANT	\N	PRESENT	0
747986	746030	04045F	PARTICIPANT	\N	PRESENT	0
747987	746030	20248J	PARTICIPANT	\N	PRESENT	0
747988	746030	14217N	PARTICIPANT	\N	PRESENT	0
747989	746030	20266L	PARTICIPANT	\N	PRESENT	0
747990	746030	14030Q	PARTICIPANT	\N	PRESENT	0
747991	746030	14251Q	PARTICIPANT	\N	PRESENT	0
748015	746033	12028B	PARTICIPANT	\N	PRESENT	0
748018	746033	11027H	PARTICIPANT	\N	PRESENT	0
748026	746033	01062T	PARTICIPANT	\N	PRESENT	0
748027	746033	11066Q	PARTICIPANT	\N	PRESENT	0
748028	746033	19347U	PARTICIPANT	\N	PRESENT	0
748029	746033	08015R	PARTICIPANT	\N	PRESENT	0
748030	746033	19565D	PARTICIPANT	\N	PRESENT	0
748031	746033	14249W	PARTICIPANT	\N	PRESENT	0
747977	746030	19719D	PARTICIPANT	\N	PRESENT	0
747978	746030	11031D	PARTICIPANT	\N	PRESENT	0
748032	746033	11054L	PARTICIPANT	\N	PRESENT	0
748033	746033	98022P	PARTICIPANT	\N	PRESENT	0
748034	746033	20072C	PARTICIPANT	\N	PRESENT	0
748013	746033	11045K	PARTICIPANT	\N	PRESENT	0
748014	746033	14267Y	PARTICIPANT	\N	PRESENT	0
748035	746033	20128B	PARTICIPANT	\N	PRESENT	0
748036	746033	16685X	PARTICIPANT	\N	PRESENT	0
748037	746033	20042V	PARTICIPANT	\N	PRESENT	0
748038	746033	14059S	PARTICIPANT	\N	PRESENT	0
748039	746033	19711U	PARTICIPANT	\N	PRESENT	0
748040	746033	14053L	PARTICIPANT	\N	PRESENT	0
748041	746033	19421M	PARTICIPANT	\N	PRESENT	0
748042	746033	99004R	PARTICIPANT	\N	PRESENT	0
748043	746033	97011G	PARTICIPANT	\N	PRESENT	0
748044	746033	14193X	PARTICIPANT	\N	PRESENT	0
748045	746033	20252E	PARTICIPANT	\N	PRESENT	0
748046	746033	08034U	PARTICIPANT	\N	PRESENT	0
748047	746033	08047A	PARTICIPANT	\N	PRESENT	0
748048	746033	19467C	PARTICIPANT	\N	PRESENT	0
748049	746033	14133K	PARTICIPANT	\N	PRESENT	0
748050	746033	04042C	PARTICIPANT	\N	PRESENT	0
748051	746033	04035D	PARTICIPANT	\N	PRESENT	0
748052	746033	14083S	PARTICIPANT	\N	PRESENT	0
748053	746033	19543W	PARTICIPANT	\N	PRESENT	0
748054	746033	17023S	PARTICIPANT	\N	PRESENT	0
748055	746033	14251Q	PARTICIPANT	\N	PRESENT	0
748076	746033	20980G	PARTICIPANT	\N	PRESENT	0
748084	746033	01048V	PARTICIPANT	\N	PRESENT	0
748088	746033	04085P	PARTICIPANT	\N	PRESENT	0
748089	746033	19669L	PARTICIPANT	\N	PRESENT	0
748090	746033	20092G	PARTICIPANT	\N	PRESENT	0
748091	746033	04047H	PARTICIPANT	\N	PRESENT	0
748093	746033	11083R	PARTICIPANT	\N	PRESENT	0
748097	746033	14255U	PARTICIPANT	\N	PRESENT	0
748116	746033	14030Q	PARTICIPANT	\N	PRESENT	0
748117	746033	14026U	PARTICIPANT	\N	PRESENT	0
748118	746033	11010L	PARTICIPANT	\N	PRESENT	0
748122	746033	20134Y	PARTICIPANT	\N	PRESENT	0
748124	746033	11026G	PARTICIPANT	\N	PRESENT	0
748127	746033	14205J	PARTICIPANT	\N	PRESENT	0
752418	752374	20032T	PARTICIPANT	\N	PRESENT	0
752419	752374	21042A	PARTICIPANT	\N	PRESENT	0
752420	752374	19760E	PARTICIPANT	\N	PRESENT	0
752421	752374	14189C	PARTICIPANT	\N	PRESENT	0
752422	752374	19631V	PARTICIPANT	\N	PRESENT	0
752423	752374	20112S	PARTICIPANT	\N	PRESENT	0
752424	752374	20076G	PARTICIPANT	\N	PRESENT	0
752425	752374	19707Y	PARTICIPANT	\N	PRESENT	0
752426	752374	21084L	PARTICIPANT	\N	PRESENT	0
761158	761123	08073C	PARTICIPANT	\N	PRESENT	0
761159	761123	19679N	PARTICIPANT	\N	PRESENT	0
761160	761123	20042V	PARTICIPANT	\N	PRESENT	0
761161	761123	08015R	PARTICIPANT	\N	PRESENT	0
761162	756371	19569H	PARTICIPANT	\N	PRESENT	0
761163	761123	20138D	PARTICIPANT	\N	PRESENT	0
761165	761123	20056C	PARTICIPANT	\N	PRESENT	0
761166	761123	20130U	PARTICIPANT	\N	PRESENT	0
761167	761123	21064G	PARTICIPANT	\N	PRESENT	0
761168	761123	19575F	PARTICIPANT	\N	PRESENT	0
761174	761123	19768N	PARTICIPANT	\N	PRESENT	0
761170	761123	14189C	PARTICIPANT	\N	PRESENT	0
761173	761123	14109K	PARTICIPANT	\N	PRESENT	0
761175	761123	20060X	PARTICIPANT	\N	PRESENT	0
761176	761123	14026U	PARTICIPANT	\N	PRESENT	0
761177	761123	14147R	PARTICIPANT	\N	PRESENT	0
761178	761123	20126Y	PARTICIPANT	\N	PRESENT	0
761157	761123	21080G	PARTICIPANT	\N	PRESENT	0
761188	761123	14357A	PARTICIPANT	\N	PRESENT	0
761193	761123	14037X	PARTICIPANT	\N	PRESENT	0
761196	761123	08045X	PARTICIPANT	\N	PRESENT	0
761203	761123	20092G	PARTICIPANT	\N	PRESENT	0
761204	761123	20122U	PARTICIPANT	\N	PRESENT	0
761215	761123	14111D	PARTICIPANT	\N	PRESENT	0
761216	761123	20044X	PARTICIPANT	\N	PRESENT	0
761217	761123	20120S	PARTICIPANT	\N	PRESENT	0
761218	761123	14107H	PARTICIPANT	\N	PRESENT	0
761219	761123	19798U	PARTICIPANT	\N	PRESENT	0
761220	761123	19691J	PARTICIPANT	\N	PRESENT	0
761221	761123	20024T	PARTICIPANT	\N	PRESENT	0
761222	761123	19479G	PARTICIPANT	\N	PRESENT	0
761227	761123	14231L	PARTICIPANT	\N	PRESENT	0
761228	761123	14073Q	PARTICIPANT	\N	PRESENT	0
761229	761123	19251M	PARTICIPANT	\N	PRESENT	0
761230	761123	14179A	PARTICIPANT	\N	PRESENT	0
761232	761231	14213J	PARTICIPANT	\N	PRESENT	0
761233	761231	21081H	PARTICIPANT	\N	PRESENT	0
761234	761231	20130U	PARTICIPANT	\N	PRESENT	0
761246	760765	04047H	PRESIDENT	0	PRESENT	0
761247	760765	21043B	PARTICIPANT	\N	PRESENT	0
761237	760765	20022R	PARTICIPANT	\N	EXCUSE	0
761238	760765	19719D	PARTICIPANT	\N	EXCUSE	0
761239	760765	14231L	PARTICIPANT	\N	EXCUSE	0
761240	760765	14089Y	PARTICIPANT	\N	PRESENT	0
761241	760765	14189C	PARTICIPANT	\N	PRESENT	0
761242	760765	20108W	PARTICIPANT	\N	PRESENT	0
761243	760765	21076L	PARTICIPANT	\N	PRESENT	0
761244	760765	21095P	PARTICIPANT	\N	PRESENT	0
761245	760765	19673G	PARTICIPANT	\N	PRESENT	0
761248	760765	20036X	PARTICIPANT	\N	PRESENT	0
761249	760765	10015M	PARTICIPANT	\N	PRESENT	0
761250	760765	14069U	PARTICIPANT	\N	PRESENT	0
761251	760765	14151M	PARTICIPANT	\N	PRESENT	0
761252	760765	20110Q	PARTICIPANT	\N	PRESENT	0
761253	760765	21088Q	PARTICIPANT	\N	PRESENT	0
761254	760765	04045F	PARTICIPANT	\N	PRESENT	0
761255	760765	14147R	PARTICIPANT	\N	PRESENT	0
761256	760765	19749K	PARTICIPANT	\N	PRESENT	0
761257	760739	14259Y	PARTICIPANT	\N	PRESENT	0
761258	760739	21049H	PARTICIPANT	\N	PRESENT	0
761259	760739	14189C	PARTICIPANT	\N	PRESENT	0
761260	760739	14151M	PARTICIPANT	\N	PRESENT	0
761261	760739	20108W	PARTICIPANT	\N	PRESENT	0
761262	760739	21069M	PARTICIPANT	\N	PRESENT	0
761263	760739	19585H	PARTICIPANT	\N	PRESENT	0
761264	760739	07004J	PARTICIPANT	\N	PRESENT	0
761265	760739	20266L	PARTICIPANT	\N	PRESENT	0
761266	760739	19760E	PARTICIPANT	\N	PRESENT	0
761267	760765	20098N	PARTICIPANT	\N	PRESENT	0
761268	760765	21044C	PARTICIPANT	\N	PRESENT	0
761326	760739	11056N	PARTICIPANT	\N	PRESENT	0
761327	760739	19758L	PARTICIPANT	\N	PRESENT	0
761328	761030	19335Q	PARTICIPANT	\N	PRESENT	0
761331	761030	19711U	PARTICIPANT	\N	PRESENT	0
761332	760739	19565D	PARTICIPANT	\N	PRESENT	0
761333	761030	21048G	PARTICIPANT	\N	PRESENT	0
761334	760739	18207D	PARTICIPANT	\N	PRESENT	0
761335	760739	21053D	PARTICIPANT	\N	PRESENT	0
761345	760739	14111D	PARTICIPANT	\N	PRESENT	0
761337	761030	07029T	PARTICIPANT	\N	PRESENT	0
761338	761030	11110B	PARTICIPANT	\N	PRESENT	0
761339	761030	19479G	PARTICIPANT	\N	PRESENT	0
761342	760739	20032T	PARTICIPANT	\N	PRESENT	0
761344	760739	19563B	PARTICIPANT	\N	PRESENT	0
761346	760739	21076L	PARTICIPANT	\N	PRESENT	0
761347	760739	18231D	PARTICIPANT	\N	PRESENT	0
761348	760739	19629C	PARTICIPANT	\N	PRESENT	0
761349	760739	21075K	PARTICIPANT	\N	PRESENT	0
761351	761030	21072G	PARTICIPANT	\N	PRESENT	0
761353	760739	20134Y	PARTICIPANT	\N	PRESENT	0
761354	760739	14147R	PARTICIPANT	\N	PRESENT	0
761356	760739	14021P	PARTICIPANT	\N	PRESENT	0
761357	760739	20082E	PARTICIPANT	\N	PRESENT	0
761358	760739	21062E	PARTICIPANT	\N	PRESENT	0
761361	760739	21043B	PARTICIPANT	\N	PRESENT	0
761362	760739	08061X	PARTICIPANT	\N	PRESENT	0
761363	760739	14123H	PARTICIPANT	\N	PRESENT	0
761364	760739	14237S	PARTICIPANT	\N	PRESENT	0
761365	760739	21085M	PARTICIPANT	\N	PRESENT	0
761366	760739	19387D	PARTICIPANT	\N	PRESENT	0
761367	760739	21052C	PARTICIPANT	\N	PRESENT	0
761368	760739	14083S	PARTICIPANT	\N	PRESENT	0
761370	761030	20050V	PARTICIPANT	\N	PRESENT	0
761385	761030	19545Y	PRESIDENT	1	PRESENT	0
761392	761030	21079P	PARTICIPANT	\N	PRESENT	0
761393	761030	14083S	PARTICIPANT	\N	PRESENT	0
761493	761030	21067K	PARTICIPANT	\N	PRESENT	0
761503	759474	19387D	PARTICIPANT	\N	PRESENT	0
761504	759474	14219Q	PRESIDENT	0	PRESENT	0
761505	759474	19820Y	PARTICIPANT	\N	PRESENT	0
761506	759474	19826F	PARTICIPANT	\N	PRESENT	0
761507	759474	21060C	PARTICIPANT	\N	PRESENT	0
761508	759474	21062E	PARTICIPANT	\N	PRESENT	0
761509	759474	21065H	PARTICIPANT	\N	PRESENT	0
761510	759474	14237S	PARTICIPANT	\N	PRESENT	0
761511	759474	18083K	PARTICIPANT	\N	PRESENT	0
761512	759474	20100N	PARTICIPANT	\N	PRESENT	0
761513	759474	21084L	PARTICIPANT	\N	PRESENT	0
761514	759474	15197G	PARTICIPANT	\N	PRESENT	0
761515	759474	14107H	PARTICIPANT	\N	PRESENT	0
761516	759474	21080G	PARTICIPANT	\N	PRESENT	0
761517	759474	19681G	PARTICIPANT	\N	PRESENT	0
761518	759474	11065P	PARTICIPANT	\N	PRESENT	0
761519	759474	20120S	PARTICIPANT	\N	PRESENT	0
761520	759474	20032T	PARTICIPANT	\N	PRESENT	0
761521	759474	21053D	PARTICIPANT	\N	PRESENT	0
761522	759474	20136B	PARTICIPANT	\N	PRESENT	0
761523	759474	20040T	PARTICIPANT	\N	PRESENT	0
761524	759474	19251M	PARTICIPANT	\N	PRESENT	0
761525	759474	20046A	PARTICIPANT	\N	PRESENT	0
761526	759474	17229F	PARTICIPANT	\N	PRESENT	0
761527	759474	20068G	PARTICIPANT	\N	PRESENT	0
761528	759474	21068L	PARTICIPANT	\N	PRESENT	0
761529	759474	08060W	PARTICIPANT	\N	EXCUSE	0
761530	759474	19701S	PARTICIPANT	\N	EXCUSE	0
761531	759474	21047F	PARTICIPANT	\N	EXCUSE	0
761532	759474	21051B	PARTICIPANT	\N	EXCUSE	0
761533	760740	21062E	PARTICIPANT	\N	PRESENT	0
761534	760740	18395Y	PARTICIPANT	\N	PRESENT	0
761535	760740	20062A	PARTICIPANT	\N	PRESENT	0
761536	760740	21060C	PARTICIPANT	\N	PRESENT	0
761580	761576	20264J	PARTICIPANT	\N	PRESENT	1
761581	761576	19533U	PARTICIPANT	\N	PRESENT	1
761582	761578	20264J	PARTICIPANT	\N	PRESENT	1
761583	761578	20142Y	PARTICIPANT	\N	PRESENT	1
761584	761578	19533U	PARTICIPANT	\N	PRESENT	1
761585	761577	20264J	PARTICIPANT	\N	PRESENT	1
761586	761577	19533U	PARTICIPANT	\N	PRESENT	1
761587	761579	19954N	PARTICIPANT	\N	PRESENT	1
761588	761579	19533U	PARTICIPANT	\N	PRESENT	1
761615	761614	08010L	PARTICIPANT	\N	PRESENT	0
761617	761616	14217N	PARTICIPANT	\N	PRESENT	0
761618	761616	14213J	PARTICIPANT	\N	PRESENT	0
761619	761616	19758L	PARTICIPANT	\N	PRESENT	0
761620	761616	20130U	PARTICIPANT	\N	PRESENT	0
761627	761621	14033T	PARTICIPANT	\N	PRESENT	0
761628	761622	14033T	PARTICIPANT	\N	PRESENT	0
761629	761623	14033T	PARTICIPANT	\N	PRESENT	0
761630	761624	14033T	PARTICIPANT	\N	PRESENT	0
761631	761624	14038Y	PARTICIPANT	\N	PRESENT	0
761632	761625	14033T	PARTICIPANT	\N	PRESENT	0
740316	738260	19673G	PARTICIPANT	\N	EXCUSE	0
740317	733724	19673G	PARTICIPANT	\N	EXCUSE	0
741893	740612	14053L	PARTICIPANT	\N	PRESENT	0
741894	740612	19703U	PARTICIPANT	\N	PRESENT	0
741895	740612	19621T	PARTICIPANT	\N	PRESENT	0
741896	740612	20070A	PARTICIPANT	\N	PRESENT	0
741897	740612	20108W	PARTICIPANT	\N	PRESENT	0
741899	740612	20088L	PARTICIPANT	\N	PRESENT	0
741900	740612	14083S	PARTICIPANT	\N	PRESENT	0
741901	740612	14231L	PARTICIPANT	\N	PRESENT	0
741902	740612	05008E	PARTICIPANT	\N	PRESENT	0
741903	740612	08028W	PARTICIPANT	\N	PRESENT	0
741910	740612	19349W	PARTICIPANT	\N	PRESENT	0
741911	740833	11048N	PARTICIPANT	\N	PRESENT	0
741912	740833	19711U	PARTICIPANT	\N	PRESENT	0
741913	740833	01048V	PARTICIPANT	\N	PRESENT	0
741914	740833	01057W	PARTICIPANT	\N	PRESENT	0
741915	740833	19687N	PARTICIPANT	\N	PRESENT	0
741916	740833	12016W	PARTICIPANT	\N	PRESENT	0
741917	740833	20044X	PARTICIPANT	\N	PRESENT	0
741918	740833	14225N	PRESIDENT	0	PRESENT	0
741919	740833	14173T	PARTICIPANT	\N	PRESENT	0
741920	740833	20070A	PARTICIPANT	\N	PRESENT	0
741921	740833	08010L	PARTICIPANT	\N	PRESENT	0
741922	740833	14253S	PARTICIPANT	\N	PRESENT	0
741923	740833	99004R	PARTICIPANT	\N	PRESENT	0
741924	740833	20116W	PARTICIPANT	\N	PRESENT	0
741925	740833	20914V	PARTICIPANT	\N	PRESENT	0
741926	740833	20126Y	PARTICIPANT	\N	PRESENT	0
741927	740833	19545Y	PARTICIPANT	\N	PRESENT	0
741928	740833	07029T	PARTICIPANT	\N	PRESENT	0
741929	740612	20056C	PARTICIPANT	\N	PRESENT	0
743070	743069	14030Q	PARTICIPANT	\N	PRESENT	0
743071	743069	19621T	PARTICIPANT	\N	PRESENT	0
743072	743069	14109K	PARTICIPANT	\N	PRESENT	0
743073	743068	14030Q	PARTICIPANT	\N	PRESENT	0
743074	743068	19621T	PARTICIPANT	\N	PRESENT	0
743075	743068	14109K	PARTICIPANT	\N	PRESENT	0
745979	745978	14225N	PARTICIPANT	\N	PRESENT	0
745980	745978	11048N	PARTICIPANT	\N	PRESENT	0
745981	745978	01057W	PARTICIPANT	\N	PRESENT	0
745982	745978	20116W	PARTICIPANT	\N	PRESENT	0
745983	745978	20070A	PARTICIPANT	\N	PRESENT	0
745984	745978	04071H	PARTICIPANT	\N	PRESENT	0
745985	745978	08034U	PARTICIPANT	\N	PRESENT	0
745986	745978	20150Y	PARTICIPANT	\N	PRESENT	0
748237	741501	20024T	PARTICIPANT	\N	EXCUSE	0
748238	741501	14189C	PARTICIPANT	\N	EXCUSE	0
748239	741501	20118Y	PARTICIPANT	\N	EXCUSE	0
748240	741501	20130U	PARTICIPANT	\N	EXCUSE	0
748241	741501	11031D	PARTICIPANT	\N	EXCUSE	0
748242	748092	14217N	PRESIDENT	0	PRESENT	0
748243	748092	20130U	PARTICIPANT	\N	PRESENT	0
748244	748092	11031D	PARTICIPANT	\N	PRESENT	0
748245	748092	19798U	PARTICIPANT	\N	PRESENT	0
748246	748092	11097X	PARTICIPANT	\N	PRESENT	0
748247	748092	14042U	PARTICIPANT	\N	PRESENT	0
748248	748092	19723Y	PARTICIPANT	\N	PRESENT	0
748249	748092	19683J	PARTICIPANT	\N	PRESENT	0
748274	748092	20066E	PARTICIPANT	\N	PRESENT	0
748317	748092	11067R	PARTICIPANT	\N	EXCUSE	0
748318	748092	04092N	PARTICIPANT	\N	EXCUSE	0
748365	748099	11072N	PARTICIPANT	\N	PRESENT	0
748366	748099	14217N	PARTICIPANT	\N	PRESENT	0
748367	748099	11031D	PARTICIPANT	\N	PRESENT	0
748368	748099	17965H	PARTICIPANT	\N	PRESENT	0
748369	748099	11048N	PARTICIPANT	\N	PRESENT	0
748370	748099	11012A	PARTICIPANT	\N	PRESENT	0
748371	748099	20058E	PARTICIPANT	\N	PRESENT	0
748372	748099	20116W	PARTICIPANT	\N	PRESENT	0
748373	748099	08061X	PARTICIPANT	\N	PRESENT	0
748374	748099	19723Y	PARTICIPANT	\N	PRESENT	0
748375	748099	11097X	PARTICIPANT	\N	PRESENT	0
748379	748099	20092G	PARTICIPANT	\N	PRESENT	0
748377	748099	19713W	PARTICIPANT	\N	PRESENT	0
748378	748099	19687N	PARTICIPANT	\N	PRESENT	0
748380	748099	19782L	PARTICIPANT	\N	PRESENT	0
748381	748099	14357A	PARTICIPANT	\N	PRESENT	0
748382	748099	20124W	PARTICIPANT	\N	PRESENT	0
748383	748099	14021P	PARTICIPANT	\N	PRESENT	0
748983	748004	19729F	PARTICIPANT	\N	PRESENT	0
748984	748004	14111D	PARTICIPANT	\N	PRESENT	0
748985	748004	14053L	PARTICIPANT	\N	PRESENT	0
748987	748986	19673G	PARTICIPANT	\N	PRESENT	0
748988	748986	19749K	PARTICIPANT	\N	PRESENT	0
748989	748004	14231L	PARTICIPANT	\N	PRESENT	0
748990	748004	04047H	PRESIDENT	0	PRESENT	0
748991	748004	10015M	PARTICIPANT	\N	PRESENT	0
748992	748004	19447X	PARTICIPANT	\N	PRESENT	0
748993	748004	14215L	PARTICIPANT	\N	PRESENT	0
748994	748004	20022R	PARTICIPANT	\N	PRESENT	0
748995	748004	19749K	PARTICIPANT	\N	PRESENT	0
748996	748004	20074E	PARTICIPANT	\N	PRESENT	0
748997	748004	14001X	PARTICIPANT	\N	PRESENT	0
748998	748004	14107H	PARTICIPANT	\N	PRESENT	0
748999	748004	11072N	PARTICIPANT	\N	PRESENT	0
749000	748004	14069U	PARTICIPANT	\N	PRESENT	0
749001	748004	19489J	PARTICIPANT	\N	PRESENT	0
749002	748004	14021P	PARTICIPANT	\N	PRESENT	0
749004	748004	14259Y	PARTICIPANT	\N	PRESENT	0
749005	748004	14151M	PARTICIPANT	\N	PRESENT	0
749006	748004	11056N	PARTICIPANT	\N	PRESENT	0
749017	748101	14281W	PARTICIPANT	\N	PRESENT	0
749018	748101	14042U	PARTICIPANT	\N	PRESENT	0
749020	748101	20040T	PARTICIPANT	\N	PRESENT	0
749021	748101	20090E	PARTICIPANT	\N	PRESENT	0
749022	748101	19691J	PARTICIPANT	\N	PRESENT	0
749023	748101	19511N	PARTICIPANT	\N	PRESENT	0
749024	748101	14223L	PARTICIPANT	\N	PRESENT	0
749025	748101	10006L	PRESIDENT	0	PRESENT	0
749026	748101	04092N	PARTICIPANT	\N	PRESENT	0
749027	748101	20130U	PARTICIPANT	\N	PRESENT	0
749028	748101	19415P	PARTICIPANT	\N	PRESENT	0
749029	748101	11097X	PARTICIPANT	\N	PRESENT	0
749030	748101	14217N	PARTICIPANT	\N	PRESENT	0
749033	748101	14213J	PARTICIPANT	\N	PRESENT	0
749034	748101	19798U	PARTICIPANT	\N	PRESENT	0
749035	748101	11067R	PARTICIPANT	\N	PRESENT	0
749036	748101	18193Q	PARTICIPANT	\N	PRESENT	0
749038	748101	19723Y	PARTICIPANT	\N	PRESENT	0
749041	748101	19679N	PARTICIPANT	\N	PRESENT	0
749068	748101	20248J	PARTICIPANT	\N	PRESENT	0
749069	748101	17965H	PARTICIPANT	\N	PRESENT	0
749072	748101	19760E	PARTICIPANT	\N	PRESENT	0
749093	748101	19683J	PARTICIPANT	\N	PRESENT	0
749094	748101	20066E	PARTICIPANT	\N	PRESENT	0
749099	748101	04043D	PARTICIPANT	\N	PRESENT	0
749105	748101	19713W	PARTICIPANT	\N	PRESENT	0
749135	748101	14026U	PARTICIPANT	\N	PRESENT	0
749773	748108	20152B	PARTICIPANT	\N	PRESENT	0
749774	748108	20044X	PARTICIPANT	\N	PRESENT	0
749775	748108	20052X	PARTICIPANT	\N	PRESENT	0
749776	748108	20056C	PARTICIPANT	\N	PRESENT	0
749777	748108	19577H	PARTICIPANT	\N	PRESENT	0
749778	748108	20048C	PARTICIPANT	\N	PRESENT	0
749792	748108	20138D	PARTICIPANT	\N	PRESENT	0
749779	747854	19383Y	PARTICIPANT	\N	PRESENT	0
749780	747854	19954N	PARTICIPANT	\N	PRESENT	0
749781	747854	11056N	PARTICIPANT	\N	PRESENT	0
749782	747854	14331P	PARTICIPANT	\N	PRESENT	0
749783	747854	19489J	PARTICIPANT	\N	PRESENT	0
749784	747854	20248J	PARTICIPANT	\N	PRESENT	0
749785	747854	19629C	PARTICIPANT	\N	PRESENT	0
749786	747854	14189C	PARTICIPANT	\N	PRESENT	0
749787	747854	14001X	PARTICIPANT	\N	PRESENT	0
749788	747854	20082E	PARTICIPANT	\N	PRESENT	0
749789	747854	14259Y	PRESIDENT	0	PRESENT	0
749790	747854	20172F	PARTICIPANT	\N	PRESENT	0
749791	747854	14329V	PARTICIPANT	\N	EXCUSE	0
749793	748108	20132W	PARTICIPANT	\N	PRESENT	0
749794	748108	20128B	PARTICIPANT	\N	PRESENT	0
749795	748108	08015R	PARTICIPANT	\N	PRESENT	0
749796	748108	20090E	PARTICIPANT	\N	PRESENT	0
749797	748108	11090Q	PARTICIPANT	\N	PRESENT	0
749801	748108	20066E	PARTICIPANT	\N	PRESENT	0
749799	748108	11083R	PARTICIPANT	\N	PRESENT	0
749800	748108	20058E	PARTICIPANT	\N	PRESENT	0
749811	748108	19565D	PARTICIPANT	\N	PRESENT	0
749814	748108	07029T	PARTICIPANT	\N	PRESENT	0
749817	748108	14030Q	PARTICIPANT	\N	PRESENT	0
749818	748108	19713W	PARTICIPANT	\N	PRESENT	0
754912	753662	21085M	PARTICIPANT	\N	PRESENT	0
754913	753662	21069M	PARTICIPANT	\N	PRESENT	0
754914	753662	20056C	PARTICIPANT	\N	PRESENT	0
754915	753662	14055N	PARTICIPANT	\N	PRESENT	0
754916	753662	19399H	PARTICIPANT	\N	PRESENT	0
754917	753662	20108W	PARTICIPANT	\N	PRESENT	0
754918	753662	20024T	PARTICIPANT	\N	PRESENT	0
754919	753662	14213J	PARTICIPANT	\N	PRESENT	0
754920	753662	20116W	PARTICIPANT	\N	PRESENT	0
754921	753662	20148F	PARTICIPANT	\N	PRESENT	0
754922	753662	19629C	PARTICIPANT	\N	PRESENT	0
754923	753662	20058E	PARTICIPANT	\N	PRESENT	0
754924	753662	21036C	PARTICIPANT	\N	PRESENT	0
754925	753662	21063F	PARTICIPANT	\N	PRESENT	0
754926	753662	21041Y	PARTICIPANT	\N	PRESENT	0
754927	753662	20068G	PARTICIPANT	\N	PRESENT	0
754928	753662	20132W	PARTICIPANT	\N	PRESENT	0
754929	753662	21066J	PARTICIPANT	\N	PRESENT	0
754930	753662	19553Y	PARTICIPANT	\N	PRESENT	0
754931	753662	17367Q	PARTICIPANT	\N	PRESENT	0
754932	753662	20072C	PARTICIPANT	\N	PRESENT	0
754933	753662	19709B	PARTICIPANT	\N	PRESENT	0
754934	753662	08018U	PARTICIPANT	\N	PRESENT	0
754935	753662	21078N	PARTICIPANT	\N	PRESENT	0
754936	753662	07029T	PARTICIPANT	\N	PRESENT	0
754937	753662	19657G	PARTICIPANT	\N	PRESENT	0
754938	753662	21040X	PARTICIPANT	\N	PRESENT	0
754939	753662	08015R	PARTICIPANT	\N	PRESENT	0
754940	753662	19768N	PARTICIPANT	\N	PRESENT	0
754941	753662	19866P	PARTICIPANT	\N	PRESENT	0
754942	753662	14107H	PARTICIPANT	\N	PRESENT	0
754943	753662	14059S	PARTICIPANT	\N	PRESENT	0
754944	753662	08056B	PARTICIPANT	\N	PRESENT	0
754945	753662	20124W	PARTICIPANT	\N	PRESENT	0
754946	753662	20126Y	PARTICIPANT	\N	PRESENT	0
754947	753662	19695N	PARTICIPANT	\N	PRESENT	0
754948	753662	20054A	PARTICIPANT	\N	PRESENT	0
754949	753662	19565D	PARTICIPANT	\N	PRESENT	0
754950	753662	20110Q	PARTICIPANT	\N	PRESENT	0
754951	753662	20100N	PARTICIPANT	\N	PRESENT	0
754952	753662	14329V	PARTICIPANT	\N	PRESENT	0
754953	753662	19057M	PARTICIPANT	\N	PRESENT	0
754954	753662	14357A	PARTICIPANT	\N	PRESENT	0
754955	753662	20098N	PARTICIPANT	\N	PRESENT	0
754956	753662	20020P	PARTICIPANT	\N	PRESENT	0
754957	753662	19719D	PARTICIPANT	\N	PRESENT	0
754958	753662	07033P	PARTICIPANT	\N	PRESENT	0
754959	753662	21090J	PARTICIPANT	\N	PRESENT	0
754960	753662	21032X	PARTICIPANT	\N	PRESENT	0
754961	753662	14217N	PARTICIPANT	\N	PRESENT	0
754962	753662	19387D	PARTICIPANT	\N	PRESENT	0
754963	753662	20120S	PARTICIPANT	\N	PRESENT	0
754964	753662	20252E	PARTICIPANT	\N	PRESENT	0
754965	753662	19545Y	PARTICIPANT	\N	PRESENT	0
754966	753662	21046E	PARTICIPANT	\N	PRESENT	0
754967	753662	14195A	PARTICIPANT	\N	PRESENT	0
754968	753662	20118Y	PARTICIPANT	\N	PRESENT	0
754969	753662	19533U	PARTICIPANT	\N	PRESENT	0
754970	753662	21065H	PARTICIPANT	\N	PRESENT	0
754971	753662	19693L	PARTICIPANT	\N	PRESENT	0
754972	753662	14069U	PARTICIPANT	\N	PRESENT	0
754973	753662	14211G	PARTICIPANT	\N	PRESENT	0
754974	753662	19798U	PARTICIPANT	\N	PRESENT	0
754975	753662	11064N	PARTICIPANT	\N	PRESENT	0
754976	753662	21054E	PARTICIPANT	\N	PRESENT	0
754977	753662	14251Q	PARTICIPANT	\N	PRESENT	0
754978	753662	14111D	PARTICIPANT	\N	PRESENT	0
754979	753662	14071N	PARTICIPANT	\N	PRESENT	0
754980	753662	14221J	PARTICIPANT	\N	PRESENT	0
754981	753662	20050V	PARTICIPANT	\N	PRESENT	0
754982	753662	14187A	PARTICIPANT	\N	PRESENT	0
754983	753662	14053L	PARTICIPANT	\N	PRESENT	0
754984	753662	21070E	PARTICIPANT	\N	PRESENT	0
754985	753662	20122U	PARTICIPANT	\N	PRESENT	0
754986	753662	21076L	PARTICIPANT	\N	PRESENT	0
754987	753662	05008E	PARTICIPANT	\N	PRESENT	0
754988	753662	19585H	PARTICIPANT	\N	PRESENT	0
754989	753662	19631V	PARTICIPANT	\N	PRESENT	0
754990	753662	11048N	PARTICIPANT	\N	PRESENT	0
754991	753662	20094J	PARTICIPANT	\N	PRESENT	0
754992	753662	08060W	PARTICIPANT	\N	PRESENT	0
754993	753662	04092N	PARTICIPANT	\N	PRESENT	0
754994	753662	20088L	PARTICIPANT	\N	PRESENT	0
754995	753662	14133K	PARTICIPANT	\N	PRESENT	0
754996	753662	14026U	PARTICIPANT	\N	PRESENT	0
754997	753662	20080C	PARTICIPANT	\N	PRESENT	0
754998	753662	20060X	PARTICIPANT	\N	PRESENT	0
754999	753662	12028B	PARTICIPANT	\N	PRESENT	0
755000	753662	21057H	PARTICIPANT	\N	PRESENT	0
755001	753662	11027H	PARTICIPANT	\N	PRESENT	0
755002	753662	20070A	PARTICIPANT	\N	PRESENT	0
755003	753662	20264J	PARTICIPANT	\N	PRESENT	0
755004	753662	21067K	PARTICIPANT	\N	PRESENT	0
755005	753662	19251M	PARTICIPANT	\N	PRESENT	0
755006	753662	14151M	PARTICIPANT	\N	PRESENT	0
755007	753662	11074Q	PARTICIPANT	\N	PRESENT	0
755008	753662	19367Y	PARTICIPANT	\N	PRESENT	0
755009	753662	11110B	PARTICIPANT	\N	PRESENT	0
755010	753662	14281W	PARTICIPANT	\N	PRESENT	0
755011	753662	19647E	PARTICIPANT	\N	PRESENT	0
755012	753662	04047H	PARTICIPANT	\N	PRESENT	0
755014	753662	19820Y	PARTICIPANT	\N	PRESENT	0
755015	753662	19507S	PARTICIPANT	\N	PRESENT	0
755016	753662	19725B	PARTICIPANT	\N	PRESENT	0
755017	753662	19551W	PARTICIPANT	\N	PRESENT	0
755018	753662	14121F	PARTICIPANT	\N	PRESENT	0
755019	753662	20172F	PARTICIPANT	\N	PRESENT	0
755020	753662	99004R	PARTICIPANT	\N	PRESENT	0
755021	753662	19683J	PARTICIPANT	\N	PRESENT	0
755022	753662	14021P	PARTICIPANT	\N	PRESENT	0
755023	753662	19489J	PARTICIPANT	\N	PRESENT	0
755024	753662	18193Q	PARTICIPANT	\N	PRESENT	0
755025	753662	08012N	PARTICIPANT	\N	PRESENT	0
755026	753662	19531S	PARTICIPANT	\N	PRESENT	0
755027	753662	19711U	PARTICIPANT	\N	PRESENT	0
755028	753662	08045X	PARTICIPANT	\N	PRESENT	0
755029	753662	08010L	PARTICIPANT	\N	PRESENT	0
755030	753662	08034U	PARTICIPANT	\N	PRESENT	0
755031	753662	14109K	PARTICIPANT	\N	PRESENT	0
755032	753662	14257W	PARTICIPANT	\N	PRESENT	0
755033	753662	21060C	PARTICIPANT	\N	PRESENT	0
755034	753662	20030R	PARTICIPANT	\N	PRESENT	0
755035	753662	14225N	PARTICIPANT	\N	PRESENT	0
755036	753662	17965H	PARTICIPANT	\N	PRESENT	0
755037	753662	14229S	PARTICIPANT	\N	PRESENT	0
755039	753662	21056G	PARTICIPANT	\N	PRESENT	0
755040	753662	11045K	PARTICIPANT	\N	PRESENT	0
755041	753662	20084G	PARTICIPANT	\N	PRESENT	0
755042	753662	19669L	PARTICIPANT	\N	PRESENT	0
755043	753662	20082E	PARTICIPANT	\N	PRESENT	0
755044	753662	19413M	PARTICIPANT	\N	PRESENT	0
755045	753662	21051B	PARTICIPANT	\N	PRESENT	0
755046	753662	20112S	PARTICIPANT	\N	PRESENT	0
755047	753662	20064C	PARTICIPANT	\N	PRESENT	0
755048	753662	21082J	PARTICIPANT	\N	PRESENT	0
755049	753662	18231D	PARTICIPANT	\N	PRESENT	0
755050	753662	20028X	PARTICIPANT	\N	PRESENT	0
755051	753662	20114U	PARTICIPANT	\N	PRESENT	0
755052	753662	21042A	PARTICIPANT	\N	PRESENT	0
755053	753662	14189C	PARTICIPANT	\N	PRESENT	0
755054	753662	21050A	PARTICIPANT	\N	PRESENT	0
755055	753662	21083K	PARTICIPANT	\N	PRESENT	0
755056	753662	14083S	PARTICIPANT	\N	PRESENT	0
755057	753662	11053K	PARTICIPANT	\N	PRESENT	0
755058	753662	14267Y	PARTICIPANT	\N	PRESENT	0
755059	753662	19721W	PARTICIPANT	\N	PRESENT	0
755060	753662	20144B	PARTICIPANT	\N	PRESENT	0
755061	753662	11070L	PARTICIPANT	\N	PRESENT	0
755062	753662	20040T	PARTICIPANT	\N	PRESENT	0
755063	753662	20248J	PARTICIPANT	\N	PRESENT	0
755064	753662	11085T	PARTICIPANT	\N	PRESENT	0
755065	753662	19563B	PARTICIPANT	\N	PRESENT	0
755066	753662	21086N	PARTICIPANT	\N	PRESENT	0
755067	753662	19111A	PARTICIPANT	\N	PRESENT	0
755068	753662	19745F	PARTICIPANT	\N	PRESENT	0
755069	753662	07004J	PARTICIPANT	\N	PRESENT	0
755070	753662	19691J	PARTICIPANT	\N	PRESENT	0
755071	753662	20286Q	PARTICIPANT	\N	PRESENT	0
755072	753662	19569H	PARTICIPANT	\N	PRESENT	0
755073	753662	14179A	PARTICIPANT	\N	PRESENT	0
755074	753662	19685L	PARTICIPANT	\N	PRESENT	0
752365	752364	04070G	PARTICIPANT	\N	PRESENT	0
752366	752364	20056C	PARTICIPANT	\N	PRESENT	0
752367	752364	19593H	PARTICIPANT	\N	PRESENT	0
752369	752368	04070G	PARTICIPANT	\N	PRESENT	0
752370	752368	20056C	PARTICIPANT	\N	PRESENT	0
752372	752371	04070G	PARTICIPANT	\N	PRESENT	0
752373	752371	20056C	PARTICIPANT	\N	PRESENT	0
752427	752374	05008E	PARTICIPANT	\N	PRESENT	0
752428	752374	19667J	PARTICIPANT	\N	PRESENT	0
752429	752374	21035B	PARTICIPANT	\N	PRESENT	0
752430	752374	20024T	PARTICIPANT	\N	PRESENT	0
752431	752374	20022R	PARTICIPANT	\N	PRESENT	0
752432	752374	19954N	PARTICIPANT	\N	PRESENT	0
752433	752374	20110Q	PARTICIPANT	\N	PRESENT	0
752434	752374	19575F	PARTICIPANT	\N	PRESENT	0
752435	752374	20116W	PARTICIPANT	\N	PRESENT	0
752436	752374	14030Q	PARTICIPANT	\N	PRESENT	0
752437	752374	21043B	PARTICIPANT	\N	PRESENT	0
752438	752374	17367Q	PARTICIPANT	\N	PRESENT	0
752439	752374	21048G	PARTICIPANT	\N	PRESENT	0
752440	752374	20086J	PARTICIPANT	\N	PRESENT	0
752441	752374	20094J	PARTICIPANT	\N	PRESENT	0
752442	752374	21050A	PARTICIPANT	\N	PRESENT	0
752443	752374	11040E	PARTICIPANT	\N	PRESENT	0
752444	752374	19367Y	PARTICIPANT	\N	PRESENT	0
752445	752374	14069U	PARTICIPANT	\N	PRESENT	0
752446	752374	20042V	PARTICIPANT	\N	PRESENT	0
752447	752374	14089Y	PARTICIPANT	\N	PRESENT	0
752448	752374	08060W	PARTICIPANT	\N	PRESENT	0
752449	752374	20078J	PARTICIPANT	\N	PRESENT	0
752450	752374	20138D	PARTICIPANT	\N	PRESENT	0
752451	752374	20088L	PARTICIPANT	\N	PRESENT	0
752452	752374	14105F	PARTICIPANT	\N	PRESENT	0
752454	752374	21046E	PARTICIPANT	\N	PRESENT	0
752455	752374	20114U	PARTICIPANT	\N	PRESENT	0
752456	752374	19383Y	PARTICIPANT	\N	PRESENT	0
752457	752374	17737W	PARTICIPANT	\N	PRESENT	0
752458	752374	21052C	PARTICIPANT	\N	PRESENT	0
752459	752374	20080C	PARTICIPANT	\N	PRESENT	0
752460	752374	19621T	PARTICIPANT	\N	PRESENT	0
752461	752374	21088Q	PARTICIPANT	\N	PRESENT	0
752462	752374	21089R	PARTICIPANT	\N	PRESENT	0
752463	752374	19758L	PARTICIPANT	\N	PRESENT	0
752464	752374	21063F	PARTICIPANT	\N	PRESENT	0
752465	752374	04047H	PARTICIPANT	\N	PRESENT	0
752466	752374	19782L	PARTICIPANT	\N	PRESENT	0
752467	752374	20090E	PARTICIPANT	\N	PRESENT	0
752468	752374	21096Q	PARTICIPANT	\N	PRESENT	0
752469	752374	14207L	PARTICIPANT	\N	PRESENT	0
752470	752374	20104S	PARTICIPANT	\N	PRESENT	0
752471	752374	14255U	PARTICIPANT	\N	PRESENT	0
752472	752374	21083K	PARTICIPANT	\N	PRESENT	0
752473	752374	04042C	PARTICIPANT	\N	PRESENT	0
752474	752374	21045D	PARTICIPANT	\N	PRESENT	0
752475	752374	14053L	PARTICIPANT	\N	PRESENT	0
752476	752374	14083S	PARTICIPANT	\N	PRESENT	0
752477	752374	11053K	PARTICIPANT	\N	PRESENT	0
752478	752374	19545Y	PARTICIPANT	\N	PRESENT	0
752479	752374	20060X	PARTICIPANT	\N	PRESENT	0
752480	752374	12028B	PARTICIPANT	\N	PRESENT	0
752481	752374	21090J	PARTICIPANT	\N	PRESENT	0
752482	752374	19629C	PARTICIPANT	\N	PRESENT	0
752483	752374	19721W	PARTICIPANT	\N	PRESENT	0
752484	752374	19057M	PARTICIPANT	\N	PRESENT	0
752485	752374	21057H	PARTICIPANT	\N	PRESENT	0
752486	752374	14329V	PARTICIPANT	\N	PRESENT	0
752487	752374	14038Y	PARTICIPANT	\N	PRESENT	0
752488	752374	20264J	PARTICIPANT	\N	PRESENT	0
752489	752374	14195A	PARTICIPANT	\N	PRESENT	0
752490	752374	08028W	PARTICIPANT	\N	PRESENT	0
752491	752374	20144B	PARTICIPANT	\N	PRESENT	0
752492	752374	21065H	PARTICIPANT	\N	PRESENT	0
752493	752374	18083K	PARTICIPANT	\N	PRESENT	0
752494	752374	19701S	PARTICIPANT	\N	PRESENT	0
752495	752374	14267Y	PARTICIPANT	\N	PRESENT	0
752496	752374	21072G	PARTICIPANT	\N	PRESENT	0
752497	752374	19295A	PARTICIPANT	\N	PRESENT	0
752498	752374	11027H	PARTICIPANT	\N	PRESENT	0
752499	752374	21034A	PARTICIPANT	\N	PRESENT	0
752500	752374	19681G	PARTICIPANT	\N	PRESENT	0
752502	752374	20070A	PARTICIPANT	\N	PRESENT	0
752503	752374	11056N	PARTICIPANT	\N	PRESENT	0
752504	752374	14357A	PARTICIPANT	\N	PRESENT	0
752505	752374	18395Y	PARTICIPANT	\N	PRESENT	0
752506	752374	11065P	PARTICIPANT	\N	PRESENT	0
752507	752374	19693L	PARTICIPANT	\N	PRESENT	0
752508	752374	14259Y	PARTICIPANT	\N	PRESENT	0
752509	752374	21067K	PARTICIPANT	\N	PRESENT	0
752510	752374	21041Y	PARTICIPANT	\N	PRESENT	0
752511	752374	04008A	PARTICIPANT	\N	PRESENT	0
752512	752374	11070L	PARTICIPANT	\N	PRESENT	0
752513	752374	19719D	PARTICIPANT	\N	PRESENT	0
752514	752374	14327T	PARTICIPANT	\N	PRESENT	0
752515	752374	20140W	PARTICIPANT	\N	PRESENT	0
752516	752374	17229F	PARTICIPANT	\N	PRESENT	0
752517	752374	14217N	PARTICIPANT	\N	PRESENT	0
752518	752374	20248J	PARTICIPANT	\N	PRESENT	0
752519	752374	19251M	PARTICIPANT	\N	PRESENT	0
752520	752374	15197G	PARTICIPANT	\N	PRESENT	0
752521	752374	14215L	PARTICIPANT	\N	PRESENT	0
752522	752374	14042U	PARTICIPANT	\N	PRESENT	0
752523	752374	20134Y	PARTICIPANT	\N	PRESENT	0
752524	752374	20124W	PARTICIPANT	\N	PRESENT	0
752525	752374	20040T	PARTICIPANT	\N	PRESENT	0
752526	752374	07033P	PARTICIPANT	\N	PRESENT	0
752527	752374	20074E	PARTICIPANT	\N	PRESENT	0
752528	752374	19507S	PARTICIPANT	\N	PRESENT	0
752529	752374	14151M	PARTICIPANT	\N	PRESENT	0
752530	752374	14249W	PARTICIPANT	\N	PRESENT	0
752531	752374	21074J	PARTICIPANT	\N	PRESENT	0
752532	752374	11074Q	PARTICIPANT	\N	PRESENT	0
752533	752374	11110B	PARTICIPANT	\N	PRESENT	0
752534	752374	14187A	PARTICIPANT	\N	PRESENT	0
752535	752374	19673G	PARTICIPANT	\N	PRESENT	0
752536	752374	21091K	PARTICIPANT	\N	PRESENT	0
752537	752374	21062E	PARTICIPANT	\N	PRESENT	0
752538	752374	21086N	PARTICIPANT	\N	PRESENT	0
752539	752374	20038A	PARTICIPANT	\N	PRESENT	0
752540	752374	19647E	PARTICIPANT	\N	PRESENT	0
752541	752374	14281W	PARTICIPANT	\N	PRESENT	0
752542	752374	20100N	PARTICIPANT	\N	PRESENT	0
752543	752374	20132W	PARTICIPANT	\N	PRESENT	0
752544	752374	08045X	PARTICIPANT	\N	PRESENT	0
752545	752374	19111A	PARTICIPANT	\N	PRESENT	0
752546	752374	17023S	PARTICIPANT	\N	PRESENT	0
752547	752374	21033Y	PARTICIPANT	\N	PRESENT	0
752548	752374	08018U	PARTICIPANT	\N	PRESENT	0
752549	752374	20286Q	PARTICIPANT	\N	PRESENT	0
752550	752374	20172F	PARTICIPANT	\N	PRESENT	0
752551	752374	14231L	PARTICIPANT	\N	PRESENT	0
752552	752374	19695N	PARTICIPANT	\N	PRESENT	0
752553	752374	20120S	PARTICIPANT	\N	PRESENT	0
752554	752374	14355X	PARTICIPANT	\N	PRESENT	0
752555	752374	19820Y	PARTICIPANT	\N	PRESENT	0
752556	752374	21032X	PARTICIPANT	\N	PRESENT	0
752557	752374	19387D	PARTICIPANT	\N	PRESENT	0
752558	752374	19347U	PARTICIPANT	\N	PRESENT	0
752559	752374	20180F	PARTICIPANT	\N	PRESENT	0
752560	752374	07004J	PARTICIPANT	\N	PRESENT	0
752561	752374	08056B	PARTICIPANT	\N	PRESENT	0
752562	752374	14211G	PARTICIPANT	\N	PRESENT	0
752563	752374	19565D	PARTICIPANT	\N	PRESENT	0
752564	752374	14033T	PARTICIPANT	\N	PRESENT	0
752565	752374	14123H	PARTICIPANT	\N	PRESENT	0
752566	752374	21066J	PARTICIPANT	\N	PRESENT	0
752567	752374	14026U	PARTICIPANT	\N	PRESENT	0
752568	752374	20068G	PARTICIPANT	\N	PRESENT	0
752569	752374	98022P	PARTICIPANT	\N	PRESENT	0
752570	752374	11064N	PARTICIPANT	\N	PRESENT	0
752571	752374	21092L	PARTICIPANT	\N	PRESENT	0
752572	752374	19691J	PARTICIPANT	\N	PRESENT	0
752573	752374	19553Y	PARTICIPANT	\N	PRESENT	0
752574	752374	20072C	PARTICIPANT	\N	PRESENT	0
752575	752374	19725B	PARTICIPANT	\N	PRESENT	0
752576	752374	20106U	PARTICIPANT	\N	PRESENT	0
752577	752374	20128B	PARTICIPANT	\N	PRESENT	0
752578	752374	19569H	PARTICIPANT	\N	PRESENT	0
752579	752374	14179A	PARTICIPANT	\N	PRESENT	0
761633	761625	14038Y	PARTICIPANT	\N	PRESENT	0
761634	761626	14033T	PARTICIPANT	\N	PRESENT	0
761636	761635	19719D	PARTICIPANT	\N	PRESENT	0
761638	761637	19719D	PARTICIPANT	\N	PRESENT	0
761639	760738	21071F	PARTICIPANT	\N	PRESENT	0
761641	760738	20116W	PARTICIPANT	\N	PRESENT	0
761642	760738	14030Q	PARTICIPANT	\N	PRESENT	0
761643	760738	17367Q	PARTICIPANT	\N	PRESENT	0
761644	760738	19621T	PARTICIPANT	\N	PRESENT	0
761645	760738	21089R	PARTICIPANT	\N	PRESENT	0
761646	760738	21063F	PARTICIPANT	\N	PRESENT	0
761647	760738	14053L	PARTICIPANT	\N	PRESENT	0
761648	760738	14083S	PARTICIPANT	\N	PRESENT	0
761649	760738	21090J	PARTICIPANT	\N	PRESENT	0
761650	760738	19629C	PARTICIPANT	\N	PRESENT	0
761651	760738	20264J	PARTICIPANT	\N	PRESENT	0
761652	760738	18083K	PARTICIPANT	\N	PRESENT	0
761653	760738	20070A	PARTICIPANT	\N	PRESENT	0
761654	760738	11056N	PARTICIPANT	\N	PRESENT	0
761655	760738	18395Y	PARTICIPANT	\N	PRESENT	0
761656	760738	20134Y	PARTICIPANT	\N	PRESENT	0
761657	760738	20124W	PARTICIPANT	\N	PRESENT	0
761658	760738	21074J	PARTICIPANT	\N	PRESENT	0
761659	760738	14187A	PARTICIPANT	\N	PRESENT	0
761660	760738	19647E	PARTICIPANT	\N	PRESENT	0
761661	760738	17023S	PARTICIPANT	\N	PRESENT	0
761662	760738	20172F	PARTICIPANT	\N	PRESENT	0
761663	760738	14231L	PARTICIPANT	\N	PRESENT	0
761664	760738	14026U	PARTICIPANT	\N	PRESENT	0
761665	760738	19691J	PARTICIPANT	\N	PRESENT	0
761666	760738	20048C	PARTICIPANT	\N	PRESENT	0
761667	760738	21085M	PARTICIPANT	\N	PRESENT	0
761668	760738	20066E	PARTICIPANT	\N	PRESENT	0
761669	760738	19531S	PARTICIPANT	\N	PRESENT	0
761670	760738	21044C	PARTICIPANT	\N	PRESENT	0
761671	760738	20056C	PARTICIPANT	\N	PRESENT	0
761672	760738	14021P	PARTICIPANT	\N	PRESENT	0
761673	760738	20126Y	PARTICIPANT	\N	PRESENT	0
761674	760738	19611R	PARTICIPANT	\N	PRESENT	0
761675	760738	20102Q	PARTICIPANT	\N	PRESENT	0
761676	760738	07029T	PARTICIPANT	\N	PRESENT	0
761677	760738	19699S	PARTICIPANT	\N	PRESENT	0
761678	760738	19711U	PARTICIPANT	\N	PRESENT	0
761679	760738	21087P	PARTICIPANT	\N	PRESENT	0
761680	760738	19697Q	PARTICIPANT	\N	PRESENT	0
761681	760738	21058J	PARTICIPANT	\N	PRESENT	0
761682	760738	19563B	PARTICIPANT	\N	PRESENT	0
761683	760738	21080G	PARTICIPANT	\N	PRESENT	0
761684	760738	14109K	PARTICIPANT	\N	PRESENT	0
761685	760738	21037D	PARTICIPANT	\N	PRESENT	0
761686	760738	19593H	PARTICIPANT	\N	PRESENT	0
761687	760738	20036X	PARTICIPANT	\N	PRESENT	0
761688	760738	19533U	PARTICIPANT	\N	PRESENT	0
761689	760738	19679N	PARTICIPANT	\N	PRESENT	0
761690	760738	20082E	PARTICIPANT	\N	PRESENT	0
761691	760738	04033B	PARTICIPANT	\N	PRESENT	0
761692	760738	21068L	PARTICIPANT	\N	PRESENT	0
761693	760738	20054A	PARTICIPANT	\N	PRESENT	0
761694	760738	14229S	PARTICIPANT	\N	PRESENT	0
761695	760738	21056G	PARTICIPANT	\N	PRESENT	0
761696	760738	11045K	PARTICIPANT	\N	PRESENT	0
761697	760738	20092G	PARTICIPANT	\N	PRESENT	0
761698	760738	20044X	PARTICIPANT	\N	PRESENT	0
761699	760738	20098N	PARTICIPANT	\N	PRESENT	0
761700	760738	21079P	PARTICIPANT	\N	PRESENT	0
761701	760738	20062A	PARTICIPANT	\N	PRESENT	0
761702	760738	21069M	PARTICIPANT	\N	PRESENT	0
761703	760738	21095P	PARTICIPANT	\N	PRESENT	0
761704	760738	20064C	PARTICIPANT	\N	PRESENT	0
761705	760738	19479G	PARTICIPANT	\N	PRESENT	0
761706	760738	20058E	PARTICIPANT	\N	PRESENT	0
761707	760738	20266L	PARTICIPANT	\N	PRESENT	0
761708	760738	21077M	PARTICIPANT	\N	PRESENT	0
761756	761563	14089Y	PARTICIPANT	\N	PRESENT	0
761757	761563	21043B	PARTICIPANT	\N	PRESENT	0
761758	761563	21044C	PARTICIPANT	\N	PRESENT	0
761759	761563	19649G	PARTICIPANT	\N	PRESENT	0
761760	761563	19111A	PARTICIPANT	\N	PRESENT	0
761761	761563	08018U	PRESIDENT	1	PRESENT	0
761762	761563	21095P	PARTICIPANT	\N	PRESENT	0
761763	761563	19673G	PARTICIPANT	\N	PRESENT	0
761764	761563	19447X	PARTICIPANT	\N	PRESENT	0
761765	761563	19729F	PARTICIPANT	\N	EXCUSE	0
761766	761563	19719D	PARTICIPANT	\N	EXCUSE	0
761767	761563	14111D	PARTICIPANT	\N	PRESENT	0
761768	761563	10015M	PARTICIPANT	\N	PRESENT	0
761769	761563	04047H	PRESIDENT	0	PRESENT	0
761770	761563	11056N	PARTICIPANT	\N	PRESENT	0
761771	761563	20114U	PARTICIPANT	\N	PRESENT	0
761772	761563	11085T	PARTICIPANT	\N	PRESENT	0
761773	761563	21038E	PARTICIPANT	\N	PRESENT	0
761774	761563	14259Y	PARTICIPANT	\N	PRESENT	0
761775	761563	21057H	PARTICIPANT	\N	PRESENT	0
761776	761563	19585H	PARTICIPANT	\N	PRESENT	0
761777	761563	18231D	PARTICIPANT	\N	PRESENT	0
761778	761563	18207D	PARTICIPANT	\N	EXCUSE	0
761779	761563	20266L	PARTICIPANT	\N	PRESENT	0
761780	761563	20110Q	PARTICIPANT	\N	PRESENT	0
761781	761563	21056G	PARTICIPANT	\N	PRESENT	0
761782	761563	20108W	PARTICIPANT	\N	EXCUSE	0
761783	761563	21076L	PARTICIPANT	\N	EXCUSE	0
761784	761563	14215L	PARTICIPANT	\N	EXCUSE	0
761785	761563	04045F	PARTICIPANT	\N	EXCUSE	0
761786	761563	20022R	PARTICIPANT	\N	EXCUSE	0
761787	761563	11072N	PARTICIPANT	\N	EXCUSE	0
761793	761709	14089Y	PARTICIPANT	\N	PRESENT	0
761791	761709	14111D	PARTICIPANT	\N	PRESENT	0
761792	761709	19447X	PARTICIPANT	\N	PRESENT	0
761794	761709	21090J	PARTICIPANT	\N	PRESENT	0
761795	761709	11056N	PARTICIPANT	\N	PRESENT	0
761796	761709	19649G	PARTICIPANT	\N	PRESENT	0
761797	761709	20134Y	PARTICIPANT	\N	PRESENT	0
761798	761709	14055N	PARTICIPANT	\N	PRESENT	0
761799	761709	19585H	PARTICIPANT	\N	PRESENT	0
761800	761709	19111A	PARTICIPANT	\N	PRESENT	0
761801	761709	20110Q	PARTICIPANT	\N	PRESENT	0
761802	761709	21088Q	PARTICIPANT	\N	PRESENT	0
761803	761709	21043B	PARTICIPANT	\N	PRESENT	0
761804	761709	18231D	PARTICIPANT	\N	PRESENT	0
761805	761709	04033B	PARTICIPANT	\N	PRESENT	0
761806	761709	08073C	PARTICIPANT	\N	PRESENT	0
761807	761709	20064C	PARTICIPANT	\N	PRESENT	0
761808	761709	04047H	PARTICIPANT	\N	PRESENT	0
761809	761709	99004R	PARTICIPANT	\N	PRESENT	0
761810	761709	21095P	PARTICIPANT	\N	PRESENT	0
761811	761709	21039F	PARTICIPANT	\N	PRESENT	0
761812	761709	21055F	PARTICIPANT	\N	PRESENT	0
761813	761709	21091K	PARTICIPANT	\N	PRESENT	0
761814	761709	21072G	PARTICIPANT	\N	PRESENT	0
761815	761709	14329V	PARTICIPANT	\N	PRESENT	0
761816	761709	20068G	PARTICIPANT	\N	PRESENT	0
761817	761709	14225N	PARTICIPANT	\N	PRESENT	0
761818	761709	19421M	PARTICIPANT	\N	PRESENT	0
761819	761709	19687N	PARTICIPANT	\N	PRESENT	0
761820	761709	19673G	PARTICIPANT	\N	PRESENT	0
761821	761709	21085M	PARTICIPANT	\N	PRESENT	0
761822	761709	21074J	PARTICIPANT	\N	PRESENT	0
761823	761709	10015M	PARTICIPANT	\N	PRESENT	0
761824	761709	21089R	PARTICIPANT	\N	PRESENT	0
761825	761709	18207D	PARTICIPANT	\N	PRESENT	0
761826	761709	12028B	PARTICIPANT	\N	PRESENT	0
761827	761709	21062E	PARTICIPANT	\N	PRESENT	0
761828	761709	21057H	PARTICIPANT	\N	PRESENT	0
761829	761709	21044C	PARTICIPANT	\N	PRESENT	0
761830	761709	21067K	PARTICIPANT	\N	PRESENT	0
761831	761709	21056G	PARTICIPANT	\N	PRESENT	0
761832	761709	14021P	PARTICIPANT	\N	PRESENT	0
761833	761709	11045K	PARTICIPANT	\N	PRESENT	0
761834	761709	21071F	PARTICIPANT	\N	PRESENT	0
761835	761709	20264J	PARTICIPANT	\N	PRESENT	0
761836	761709	14229S	PARTICIPANT	\N	PRESENT	0
761837	761709	11027H	PARTICIPANT	\N	PRESENT	0
761838	761709	19573D	PARTICIPANT	\N	PRESENT	0
761839	761709	20146D	PARTICIPANT	\N	PRESENT	0
761840	761709	21097R	PARTICIPANT	\N	PRESENT	0
761841	761709	19301E	PARTICIPANT	\N	PRESENT	0
761842	761709	19331L	PARTICIPANT	\N	PRESENT	0
761843	761709	20122U	PARTICIPANT	\N	PRESENT	0
761844	761709	14251Q	PARTICIPANT	\N	PRESENT	0
761845	761709	19667J	PARTICIPANT	\N	PRESENT	0
761846	761709	20048C	PARTICIPANT	\N	PRESENT	0
749821	748108	97011G	PARTICIPANT	\N	PRESENT	0
749822	748108	14083S	PARTICIPANT	\N	PRESENT	0
749824	748108	20024T	PARTICIPANT	\N	PRESENT	0
749841	748108	20032T	PARTICIPANT	\N	PRESENT	0
749826	748108	14038Y	PARTICIPANT	\N	PRESENT	0
749827	748108	19543W	PARTICIPANT	\N	PRESENT	0
749828	748108	20040T	PARTICIPANT	\N	PRESENT	0
749829	748108	17367Q	PARTICIPANT	\N	PRESENT	0
749830	748108	20120S	PARTICIPANT	\N	PRESENT	0
749837	748108	14147R	PARTICIPANT	\N	PRESENT	0
749838	748108	08034U	PARTICIPANT	\N	PRESENT	0
749839	748108	14237S	PARTICIPANT	\N	PRESENT	0
749840	748108	14073Q	PARTICIPANT	\N	PRESENT	0
749842	748108	14031R	PARTICIPANT	\N	PRESENT	0
749843	748108	19741B	PARTICIPANT	\N	PRESENT	0
749844	749769	19333N	PARTICIPANT	\N	PRESENT	0
749845	749769	20032T	PARTICIPANT	\N	PRESENT	0
749846	749769	20136B	PARTICIPANT	\N	PRESENT	0
749847	749769	14031R	PARTICIPANT	\N	PRESENT	0
749848	749769	20038A	PARTICIPANT	\N	PRESENT	0
749849	749769	19251M	PARTICIPANT	\N	PRESENT	0
749850	749769	14219Q	PRESIDENT	0	PRESENT	0
749851	749769	19820Y	PARTICIPANT	\N	PRESENT	0
749852	749769	19826F	PARTICIPANT	\N	PRESENT	0
749853	749769	20046A	PARTICIPANT	\N	PRESENT	0
749873	748108	20104S	PARTICIPANT	\N	PRESENT	0
749855	749769	20102Q	PARTICIPANT	\N	PRESENT	0
749856	749769	14237S	PARTICIPANT	\N	PRESENT	0
749857	749769	18083K	PARTICIPANT	\N	PRESENT	0
749858	749769	20100N	PARTICIPANT	\N	PRESENT	0
749859	749769	05012A	PARTICIPANT	\N	PRESENT	0
749860	749769	20068G	PARTICIPANT	\N	PRESENT	0
749861	749769	19745F	PARTICIPANT	\N	PRESENT	0
749862	749769	17367Q	PARTICIPANT	\N	PRESENT	0
749863	749769	20024T	PARTICIPANT	\N	PRESENT	0
749864	749769	19525U	PARTICIPANT	\N	PRESENT	0
749865	749769	20120S	PARTICIPANT	\N	PRESENT	0
749866	748108	20038A	PARTICIPANT	\N	PRESENT	0
749868	748108	18193Q	PARTICIPANT	\N	PRESENT	0
749869	748108	11012A	PARTICIPANT	\N	PRESENT	0
749878	748108	19533U	PARTICIPANT	\N	PRESENT	0
749879	748108	14179A	PARTICIPANT	\N	PRESENT	0
749880	748108	20022R	PARTICIPANT	\N	PRESENT	0
749881	748108	20980G	PARTICIPANT	\N	PRESENT	0
749882	748108	14217N	PARTICIPANT	\N	PRESENT	0
749883	748108	14053L	PARTICIPANT	\N	PRESENT	0
749884	748108	14331P	PARTICIPANT	\N	PRESENT	0
749885	748108	14259Y	PARTICIPANT	\N	PRESENT	0
749886	748108	10006L	PARTICIPANT	\N	PRESENT	0
749887	748108	08061X	PARTICIPANT	\N	PRESENT	0
749889	749888	20042V	PARTICIPANT	\N	PRESENT	0
749890	749888	10015M	PARTICIPANT	\N	PRESENT	0
749891	748108	20076G	PARTICIPANT	\N	PRESENT	0
749892	748108	14215L	PARTICIPANT	\N	PRESENT	0
749893	748108	20054A	PARTICIPANT	\N	PRESENT	0
750217	749973	11045K	PARTICIPANT	\N	PRESENT	0
750221	749973	14026U	PARTICIPANT	\N	PRESENT	0
750222	749973	17965H	PARTICIPANT	\N	PRESENT	0
750223	749973	14281W	PARTICIPANT	\N	PRESENT	0
750224	749973	20030R	PARTICIPANT	\N	PRESENT	0
750225	749973	11067R	PARTICIPANT	\N	PRESENT	0
750226	749973	18193Q	PARTICIPANT	\N	PRESENT	0
750227	749973	19715Y	PARTICIPANT	\N	PRESENT	0
750229	749973	19295A	PARTICIPANT	\N	PRESENT	0
750230	749973	20090E	PARTICIPANT	\N	PRESENT	0
750231	749973	19565D	PARTICIPANT	\N	PRESENT	0
750232	749973	19760E	PARTICIPANT	\N	PRESENT	0
750233	749973	11031D	PARTICIPANT	\N	PRESENT	0
750234	749973	19798U	PARTICIPANT	\N	PRESENT	0
750235	749973	20054A	PARTICIPANT	\N	PRESENT	0
750236	749973	20130U	PARTICIPANT	\N	PRESENT	0
750237	749973	14189C	PARTICIPANT	\N	PRESENT	0
750238	749973	14195A	PARTICIPANT	\N	PRESENT	0
750239	749973	14111D	PARTICIPANT	\N	PRESENT	0
750240	749973	01034P	PARTICIPANT	\N	PRESENT	0
750241	749973	20076G	PARTICIPANT	\N	PRESENT	0
750242	749973	20034V	PARTICIPANT	\N	PRESENT	0
750243	749973	20286Q	PARTICIPANT	\N	PRESENT	0
750244	749973	14213J	PARTICIPANT	\N	PRESENT	0
750245	749973	20040T	PARTICIPANT	\N	PRESENT	0
749819	748108	19798U	PARTICIPANT	\N	PRESENT	0
749820	748108	14213J	PARTICIPANT	\N	PRESENT	0
750246	749973	20066E	PARTICIPANT	\N	PRESENT	0
750247	749973	14059S	PARTICIPANT	\N	PRESENT	0
750248	749973	14217N	PARTICIPANT	\N	PRESENT	0
750249	749973	11097X	PARTICIPANT	\N	PRESENT	0
750250	749973	19758L	PARTICIPANT	\N	PRESENT	0
750251	749973	19591F	PARTICIPANT	\N	PRESENT	0
750252	749973	17367Q	PARTICIPANT	\N	PRESENT	0
750253	749973	95063L	PARTICIPANT	\N	PRESENT	0
750254	749973	14187A	PARTICIPANT	\N	PRESENT	0
750255	749973	19553Y	PARTICIPANT	\N	PRESENT	0
750256	749973	20082E	PARTICIPANT	\N	PRESENT	0
750257	749973	20152B	PARTICIPANT	\N	PRESENT	0
750258	749973	20098N	PARTICIPANT	\N	PRESENT	0
750259	749973	08045X	PARTICIPANT	\N	PRESENT	0
750260	749973	19683J	PARTICIPANT	\N	PRESENT	0
750261	749973	19687N	PARTICIPANT	\N	PRESENT	0
750262	749973	20062A	PARTICIPANT	\N	PRESENT	0
750263	749973	14147R	PARTICIPANT	\N	PRESENT	0
750264	749973	14021P	PARTICIPANT	\N	PRESENT	0
750265	749973	08028W	PARTICIPANT	\N	PRESENT	0
750266	749973	19575F	PARTICIPANT	\N	PRESENT	0
750267	749973	20144B	PARTICIPANT	\N	PRESENT	0
750268	749973	14069U	PARTICIPANT	\N	PRESENT	0
750269	749973	04092N	PARTICIPANT	\N	PRESENT	0
750270	749973	20058E	PARTICIPANT	\N	PRESENT	0
750272	749973	20914V	PARTICIPANT	\N	PRESENT	0
750273	749973	20266L	PARTICIPANT	\N	PRESENT	0
750274	749973	20026V	PARTICIPANT	\N	PRESENT	0
750275	749973	14207L	PARTICIPANT	\N	PRESENT	0
750276	749973	19739H	PARTICIPANT	\N	PRESENT	0
750282	749973	14042U	PARTICIPANT	\N	PRESENT	0
750278	749973	17779H	PARTICIPANT	\N	PRESENT	0
750279	749973	20036X	PARTICIPANT	\N	PRESENT	0
750280	749973	19749K	PARTICIPANT	\N	PRESENT	0
750281	749973	14073Q	PARTICIPANT	\N	PRESENT	0
750283	749973	20134Y	PARTICIPANT	\N	PRESENT	0
750284	749973	04043D	PARTICIPANT	\N	PRESENT	0
750285	749973	19782L	PARTICIPANT	\N	PRESENT	0
750286	749973	20136B	PARTICIPANT	\N	PRESENT	0
750287	749973	19681G	PARTICIPANT	\N	PRESENT	0
750288	749973	20024T	PARTICIPANT	\N	PRESENT	0
750289	749973	19415P	PARTICIPANT	\N	PRESENT	0
750290	749973	20018V	PARTICIPANT	\N	PRESENT	0
750291	749973	14107H	PARTICIPANT	\N	PRESENT	0
750292	749973	14231L	PARTICIPANT	\N	PRESENT	0
750293	749973	14071N	PARTICIPANT	\N	PRESENT	0
750294	749973	14259Y	PARTICIPANT	\N	PRESENT	0
750295	749973	14179A	PARTICIPANT	\N	PRESENT	0
750296	749973	08010L	PARTICIPANT	\N	PRESENT	0
750297	749973	11101A	PARTICIPANT	\N	PRESENT	0
750298	749973	10006L	PARTICIPANT	\N	PRESENT	0
750310	749973	19713W	PARTICIPANT	\N	PRESENT	0
750311	749973	20124W	PARTICIPANT	\N	PRESENT	0
750312	749973	20252E	PARTICIPANT	\N	PRESENT	0
750313	749973	20032T	PARTICIPANT	\N	PRESENT	0
750314	749973	05012A	PARTICIPANT	\N	PRESENT	0
750315	749973	19723Y	PARTICIPANT	\N	PRESENT	0
750316	749973	19729F	PARTICIPANT	\N	PRESENT	0
750317	750021	20086J	PARTICIPANT	\N	PRESENT	0
750318	750021	01048V	PARTICIPANT	\N	PRESENT	0
750319	750021	19545Y	PARTICIPANT	\N	PRESENT	0
750320	750021	01057W	PARTICIPANT	\N	PRESENT	0
750321	750021	11053K	PARTICIPANT	\N	PRESENT	0
750322	750021	11074Q	PARTICIPANT	\N	PRESENT	0
750323	750021	19667J	PARTICIPANT	\N	PRESENT	0
750324	750021	11070L	PARTICIPANT	\N	PRESENT	0
750325	750021	14225N	PARTICIPANT	\N	PRESENT	0
750326	750021	07029T	PARTICIPANT	\N	PRESENT	0
750327	750021	19349W	PARTICIPANT	\N	PRESENT	0
750328	750021	08010L	PARTICIPANT	\N	PRESENT	0
750329	750021	20116W	PARTICIPANT	\N	PRESENT	0
750330	750021	20126Y	PARTICIPANT	\N	PRESENT	0
750331	750021	11048N	PARTICIPANT	\N	PRESENT	0
750332	750021	19647E	PARTICIPANT	\N	PRESENT	0
750333	750021	20036X	PARTICIPANT	\N	PRESENT	0
750334	750021	08034U	PARTICIPANT	\N	PRESENT	0
750335	750021	14189C	PARTICIPANT	\N	PRESENT	0
750336	750021	20044X	PARTICIPANT	\N	PRESENT	0
755075	753662	19619A	PARTICIPANT	\N	PRESENT	0
755076	753662	20048C	PARTICIPANT	\N	PRESENT	0
755099	753662	21081H	PARTICIPANT	\N	PRESENT	0
755078	753662	14089Y	PARTICIPANT	\N	PRESENT	0
755079	753662	14327T	PARTICIPANT	\N	PRESENT	0
755080	753662	19735D	PARTICIPANT	\N	PRESENT	0
755081	753662	19611R	PARTICIPANT	\N	PRESENT	0
755082	753662	20052X	PARTICIPANT	\N	PRESENT	0
755083	753662	15197G	PARTICIPANT	\N	PRESENT	0
755084	753662	14205J	PARTICIPANT	\N	PRESENT	0
755085	753662	14219Q	PARTICIPANT	\N	PRESENT	0
755086	753662	19826F	PARTICIPANT	\N	PRESENT	0
755087	753662	08009T	PARTICIPANT	\N	PRESENT	0
755088	753662	04070G	PARTICIPANT	\N	PRESENT	0
755089	753662	21038E	PARTICIPANT	\N	PRESENT	0
755090	753662	21064G	PARTICIPANT	\N	PRESENT	0
755091	753662	14042U	PARTICIPANT	\N	PRESENT	0
755092	753662	19749K	PARTICIPANT	\N	PRESENT	0
755093	753662	19479G	PARTICIPANT	\N	PRESENT	0
755094	753662	17229F	PARTICIPANT	\N	PRESENT	0
755095	753662	21053D	PARTICIPANT	\N	PRESENT	0
755096	753662	14275Y	PARTICIPANT	\N	PRESENT	0
755097	753662	01034P	PARTICIPANT	\N	PRESENT	0
755098	753662	21039F	PARTICIPANT	\N	PRESENT	0
755100	753662	08047A	PARTICIPANT	\N	PRESENT	0
755101	753662	19699S	PARTICIPANT	\N	PRESENT	0
755102	753662	19713W	PARTICIPANT	\N	PRESENT	0
755423	753664	11090Q	PARTICIPANT	\N	PRESENT	0
755104	753662	21095P	PARTICIPANT	\N	PRESENT	0
755105	753662	19705W	PARTICIPANT	\N	PRESENT	0
755425	752396	20056C	PARTICIPANT	\N	PRESENT	0
755426	752396	20132W	PARTICIPANT	\N	PRESENT	0
755427	752396	20264J	PARTICIPANT	\N	PRESENT	0
755428	752396	19611R	PRESIDENT	0	PRESENT	0
755429	752396	14109K	PARTICIPANT	\N	PRESENT	0
755430	752396	21037D	PARTICIPANT	\N	PRESENT	0
755431	752396	21059K	PARTICIPANT	\N	PRESENT	0
755432	752396	14123H	PARTICIPANT	\N	PRESENT	0
755433	752396	21074J	PARTICIPANT	\N	PRESENT	0
755434	752396	21077M	PARTICIPANT	\N	PRESENT	0
755435	752396	21078N	PARTICIPANT	\N	PRESENT	0
755436	753664	14053L	PARTICIPANT	\N	PRESENT	0
755437	753664	04047H	PARTICIPANT	\N	PRESENT	0
755438	753664	14257W	PARTICIPANT	\N	PRESENT	0
755439	753664	20110Q	PARTICIPANT	\N	PRESENT	0
755440	753664	21079P	PARTICIPANT	\N	PRESENT	0
755441	753664	18207D	PARTICIPANT	\N	PRESENT	0
755442	753664	20114U	PARTICIPANT	\N	PRESENT	0
755443	753664	11040E	PARTICIPANT	\N	PRESENT	0
755444	753664	19367Y	PARTICIPANT	\N	PRESENT	0
755445	753664	04045F	PARTICIPANT	\N	PRESENT	0
755446	753664	20098N	PARTICIPANT	\N	PRESENT	0
755447	753664	19782L	PARTICIPANT	\N	PRESENT	0
755448	753664	19585H	PARTICIPANT	\N	PRESENT	0
755449	753664	21052C	PARTICIPANT	\N	PRESENT	0
755450	753664	20144B	PARTICIPANT	\N	PRESENT	0
755451	753664	14083S	PARTICIPANT	\N	PRESENT	0
755452	753664	19649G	PARTICIPANT	\N	PRESENT	0
755453	753675	21036C	PARTICIPANT	\N	PRESENT	0
755454	753675	21030V	PARTICIPANT	\N	PRESENT	0
755455	753675	21031W	PARTICIPANT	\N	PRESENT	0
755456	753675	19565D	PARTICIPANT	\N	PRESENT	0
755457	753675	20072C	PARTICIPANT	\N	PRESENT	0
755458	753675	11027H	PARTICIPANT	\N	PRESENT	0
755459	753675	04042C	PARTICIPANT	\N	PRESENT	0
755460	753675	19669L	PARTICIPANT	\N	PRESENT	0
755461	753675	08056B	PARTICIPANT	\N	PRESENT	0
755462	753675	12028B	PARTICIPANT	\N	PRESENT	0
755463	753675	17737W	PARTICIPANT	\N	PRESENT	0
755464	753675	19421M	PARTICIPANT	\N	PRESENT	0
755465	753675	21067K	PARTICIPANT	\N	PRESENT	0
755466	753675	14193X	PRESIDENT	0	PRESENT	0
755467	753675	07033P	PARTICIPANT	\N	PRESENT	0
755468	753675	17367Q	PARTICIPANT	\N	PRESENT	0
755469	753675	14249W	PARTICIPANT	\N	PRESENT	0
755470	753675	20128B	PARTICIPANT	\N	PRESENT	0
755471	753675	14037X	PARTICIPANT	\N	PRESENT	0
755472	753675	14059S	PARTICIPANT	\N	PRESENT	0
755473	753675	14133K	PARTICIPANT	\N	PRESENT	0
755474	753675	19531S	PARTICIPANT	\N	PRESENT	0
755475	753675	21073H	PARTICIPANT	\N	PRESENT	0
755476	753675	19721W	PARTICIPANT	\N	PRESENT	0
755477	753675	20064C	PARTICIPANT	\N	PRESENT	0
755478	753675	20252E	PARTICIPANT	\N	PRESENT	0
755479	753675	98022P	PARTICIPANT	\N	PRESENT	0
755480	753675	14267Y	PARTICIPANT	\N	PRESENT	0
755481	753675	11064N	PARTICIPANT	\N	PRESENT	0
755482	753675	19745F	PARTICIPANT	\N	PRESENT	0
755483	753675	99004R	PARTICIPANT	\N	PRESENT	0
755484	753675	17023S	PARTICIPANT	\N	PRESENT	0
755485	753675	20042V	PARTICIPANT	\N	EXCUSE	0
755486	753664	14089Y	PARTICIPANT	\N	PRESENT	0
755487	753664	21040X	PARTICIPANT	\N	PRESENT	0
755488	753664	21069M	PARTICIPANT	\N	PRESENT	0
755489	753664	20082E	PARTICIPANT	\N	PRESENT	0
755490	753664	19507S	PARTICIPANT	\N	PRESENT	0
755491	753664	20062A	PARTICIPANT	\N	PRESENT	0
755492	753664	14215L	PARTICIPANT	\N	PRESENT	0
755493	753664	21044C	PARTICIPANT	\N	PRESENT	0
755494	753664	14259Y	PARTICIPANT	\N	PRESENT	0
755495	753664	07029T	PARTICIPANT	\N	PRESENT	0
755496	753664	21054E	PARTICIPANT	\N	PRESENT	0
755497	752396	19533U	PARTICIPANT	\N	PRESENT	0
755498	752396	20102Q	PARTICIPANT	\N	PRESENT	0
755499	752396	14229S	PARTICIPANT	\N	PRESENT	0
755500	752396	19954N	PARTICIPANT	\N	PRESENT	0
755501	752396	18395Y	PARTICIPANT	\N	PRESENT	0
755502	752396	21089R	PARTICIPANT	\N	PRESENT	0
755503	752396	21091K	PARTICIPANT	\N	PRESENT	0
755504	752396	20124W	PARTICIPANT	\N	PRESENT	0
755505	752396	19593H	PARTICIPANT	\N	PRESENT	0
755506	752396	20138D	PARTICIPANT	\N	PRESENT	0
755507	752396	19693L	PARTICIPANT	\N	PRESENT	0
755508	752396	20052X	PARTICIPANT	\N	PRESENT	0
755509	752396	20058E	PARTICIPANT	\N	PRESENT	0
755510	752396	21063F	PARTICIPANT	\N	PRESENT	0
755511	752396	19735D	PARTICIPANT	\N	PRESENT	0
755512	752396	19057M	PARTICIPANT	\N	PRESENT	0
755513	752396	19621T	PARTICIPANT	\N	PRESENT	0
755514	753664	21064G	PARTICIPANT	\N	PRESENT	0
755516	752396	21055F	PARTICIPANT	\N	PRESENT	0
755517	753664	21038E	PARTICIPANT	\N	PRESENT	0
755518	752396	14030Q	PARTICIPANT	\N	EXCUSE	0
755519	753664	21041Y	PARTICIPANT	\N	PRESENT	0
755520	753664	19719D	PARTICIPANT	\N	PRESENT	0
755521	753664	21086N	PARTICIPANT	\N	PRESENT	0
755522	753664	19387D	PARTICIPANT	\N	PRESENT	0
755523	753664	19749K	PARTICIPANT	\N	PRESENT	0
755524	753664	11056N	PARTICIPANT	\N	PRESENT	0
755525	752396	20142Y	PARTICIPANT	\N	PRESENT	0
755526	753664	19695N	PARTICIPANT	\N	PRESENT	0
755527	753664	14069U	PARTICIPANT	\N	PRESENT	0
755528	753664	21095P	PARTICIPANT	\N	PRESENT	0
755529	753664	19711U	PARTICIPANT	\N	PRESENT	0
755530	752396	20048C	PARTICIPANT	\N	PRESENT	0
755531	753664	14151M	PARTICIPANT	\N	PRESENT	0
755532	753664	21085M	PARTICIPANT	\N	PRESENT	0
755533	753664	14042U	PARTICIPANT	\N	PRESENT	0
755534	753664	19349W	PARTICIPANT	\N	PRESENT	0
755535	753664	14187A	PARTICIPANT	\N	PRESENT	0
755538	753664	19399H	PARTICIPANT	\N	PRESENT	0
755539	753664	21094N	PARTICIPANT	\N	PRESENT	0
755540	753664	20120S	PARTICIPANT	\N	PRESENT	0
755541	753664	19479G	PARTICIPANT	\N	PRESENT	0
755542	753664	19545Y	PARTICIPANT	\N	PRESENT	0
755543	753664	21046E	PARTICIPANT	\N	PRESENT	0
755544	753664	21087P	PARTICIPANT	\N	PRESENT	0
755545	753664	21070E	PARTICIPANT	\N	PRESENT	0
755546	753664	21056G	PARTICIPANT	\N	PRESENT	0
755547	753664	19687N	PARTICIPANT	\N	PRESENT	0
755548	753664	14031R	PARTICIPANT	\N	PRESENT	0
755549	753664	18083K	PARTICIPANT	\N	PRESENT	0
744246	744201	19333N	PARTICIPANT	\N	PRESENT	0
744247	744201	19549D	PARTICIPANT	\N	PRESENT	0
744248	744201	20076G	PARTICIPANT	\N	PRESENT	0
744249	744201	14219Q	PRESIDENT	0	PRESENT	0
744250	744201	20102Q	PARTICIPANT	\N	PRESENT	0
744251	744201	20096L	PARTICIPANT	\N	PRESENT	0
744252	744201	14237S	PARTICIPANT	\N	PRESENT	0
744253	744201	18083K	PARTICIPANT	\N	PRESENT	0
744254	744201	20100N	PARTICIPANT	\N	PRESENT	0
744255	744201	05012A	PARTICIPANT	\N	PRESENT	0
744256	744201	08060W	PARTICIPANT	\N	PRESENT	0
744257	744201	19503N	PARTICIPANT	\N	PRESENT	0
744258	744201	17367Q	PARTICIPANT	\N	PRESENT	0
744259	744201	20024T	PARTICIPANT	\N	PRESENT	0
744260	744201	19525U	PARTICIPANT	\N	PRESENT	0
744261	744201	20120S	PARTICIPANT	\N	PRESENT	0
744262	744201	20136B	PARTICIPANT	\N	PRESENT	0
744263	744201	14031R	PARTICIPANT	\N	PRESENT	0
744264	744201	20038A	PARTICIPANT	\N	PRESENT	0
744265	744201	20140W	PARTICIPANT	\N	PRESENT	0
744266	744201	19251M	PARTICIPANT	\N	PRESENT	0
744267	744201	20046A	PARTICIPANT	\N	PRESENT	0
744268	744201	14033T	PARTICIPANT	\N	PRESENT	0
744269	744201	19739H	PARTICIPANT	\N	PRESENT	0
744270	744201	19745F	PARTICIPANT	\N	PRESENT	0
744271	744201	19701S	PARTICIPANT	\N	EXCUSE	0
744272	744201	19820Y	PARTICIPANT	\N	EXCUSE	0
744273	744201	19826F	PARTICIPANT	\N	EXCUSE	0
744274	744201	14169X	PARTICIPANT	\N	EXCUSE	0
744284	744092	04047H	PRESIDENT	0	PRESENT	0
744285	744092	14001X	PARTICIPANT	\N	EXCUSE	0
744286	744092	14231L	PARTICIPANT	\N	EXCUSE	0
744287	744092	19729F	PARTICIPANT	\N	PRESENT	0
744288	744092	14107H	PARTICIPANT	\N	PRESENT	0
744289	744203	14038Y	PARTICIPANT	\N	PRESENT	0
744290	744203	19467C	PARTICIPANT	\N	PRESENT	0
744291	744203	19515S	PARTICIPANT	\N	PRESENT	0
744292	744203	19782L	PARTICIPANT	\N	PRESENT	0
744293	744203	20092G	PARTICIPANT	\N	PRESENT	0
744294	744203	14357A	PARTICIPANT	\N	PRESENT	0
744295	744203	14187A	PARTICIPANT	\N	PRESENT	0
744296	744203	20144B	PARTICIPANT	\N	PRESENT	0
744297	744203	20082E	PARTICIPANT	\N	PRESENT	0
744298	744203	11090Q	PRESIDENT	0	PRESENT	0
744299	744203	14033T	PARTICIPANT	\N	PRESENT	0
744300	744203	01025N	PARTICIPANT	\N	PRESENT	0
744301	744203	04045F	PARTICIPANT	\N	PRESENT	0
744302	744203	20062A	PARTICIPANT	\N	PRESENT	0
744303	744203	19705W	PARTICIPANT	\N	PRESENT	0
744304	744203	08015R	PARTICIPANT	\N	PRESENT	0
744305	744203	19575F	PARTICIPANT	\N	PRESENT	0
744306	744203	20298U	PARTICIPANT	\N	PRESENT	0
744307	744203	19563B	PARTICIPANT	\N	PRESENT	0
744308	744203	14037X	PARTICIPANT	\N	PRESENT	0
744309	744203	14257W	PARTICIPANT	\N	PRESENT	0
744317	744092	10015M	PARTICIPANT	\N	PRESENT	0
744318	744092	14147R	PARTICIPANT	\N	PRESENT	0
744319	744092	14179A	PARTICIPANT	\N	PRESENT	0
744320	744092	14215L	PARTICIPANT	\N	PRESENT	0
744321	744092	20022R	PARTICIPANT	\N	PRESENT	0
744327	744168	11070L	PARTICIPANT	\N	PRESENT	0
744328	744168	14331P	PARTICIPANT	\N	PRESENT	0
744329	744168	14033T	PARTICIPANT	\N	PRESENT	0
744330	744168	20062A	PARTICIPANT	\N	PRESENT	0
744331	744168	20120S	PARTICIPANT	\N	PRESENT	0
744332	744168	19711U	PARTICIPANT	\N	PRESENT	0
744333	744168	14107H	PARTICIPANT	\N	PRESENT	0
744334	744168	20050V	PARTICIPANT	\N	PRESENT	0
744335	744168	19782L	PARTICIPANT	\N	PRESENT	0
744336	744168	14257W	PARTICIPANT	\N	PRESENT	0
744337	744168	19695N	PARTICIPANT	\N	PRESENT	0
744338	744168	14205J	PARTICIPANT	\N	PRESENT	0
744339	744168	20028X	PARTICIPANT	\N	PRESENT	0
744340	744168	14207L	PARTICIPANT	\N	PRESENT	0
744341	744168	20054A	PARTICIPANT	\N	PRESENT	0
744342	744168	19503N	PARTICIPANT	\N	PRESENT	0
744343	744168	14219Q	PARTICIPANT	\N	PRESENT	0
744384	744168	19565D	PARTICIPANT	\N	PRESENT	0
744345	744168	19747H	PARTICIPANT	\N	PRESENT	0
744346	744168	20024T	PARTICIPANT	\N	PRESENT	0
744347	744168	11090Q	PARTICIPANT	\N	PRESENT	0
744348	744168	14215L	PARTICIPANT	\N	PRESENT	0
744349	744168	19637C	PARTICIPANT	\N	PRESENT	0
744350	744168	20080C	PARTICIPANT	\N	PRESENT	0
744351	744168	20082E	PARTICIPANT	\N	PRESENT	0
744391	744168	11040E	PARTICIPANT	\N	PRESENT	0
744353	744168	04045F	PARTICIPANT	\N	PRESENT	0
744354	744168	08060W	PARTICIPANT	\N	PRESENT	0
744355	744168	20092G	PARTICIPANT	\N	PRESENT	0
744356	744168	11067R	PARTICIPANT	\N	PRESENT	0
744357	744168	11033F	PARTICIPANT	\N	PRESENT	0
744358	743960	14237S	PARTICIPANT	\N	PRESENT	0
744359	743960	14038Y	PARTICIPANT	\N	PRESENT	0
744360	743960	04070G	PRESIDENT	0	PRESENT	0
744361	743960	20034V	PARTICIPANT	\N	PRESENT	0
744363	743960	10015M	PARTICIPANT	\N	PRESENT	0
744364	743960	20140W	PARTICIPANT	\N	PRESENT	0
744365	743960	14179A	PARTICIPANT	\N	PRESENT	0
744366	744168	04057K	PARTICIPANT	\N	PRESENT	0
744367	744168	20914V	PARTICIPANT	\N	PRESENT	0
744368	744168	95063L	PARTICIPANT	\N	PRESENT	0
744369	743960	11045K	PARTICIPANT	\N	PRESENT	0
744370	744168	19826F	PARTICIPANT	\N	PRESENT	0
744371	744168	20076G	PARTICIPANT	\N	PRESENT	0
744372	744168	20090E	PARTICIPANT	\N	PRESENT	0
744373	744168	19515S	PARTICIPANT	\N	PRESENT	0
744374	744168	20038A	PARTICIPANT	\N	PRESENT	0
744375	744168	14147R	PARTICIPANT	\N	PRESENT	0
744376	744168	20044X	PARTICIPANT	\N	PRESENT	0
744377	744168	19575F	PARTICIPANT	\N	PRESENT	0
744378	744168	01048V	PARTICIPANT	\N	PRESENT	0
744379	743960	20022R	PARTICIPANT	\N	PRESENT	0
744380	744168	20100N	PARTICIPANT	\N	PRESENT	0
744381	744168	20086J	PARTICIPANT	\N	PRESENT	0
744382	744168	20102Q	PARTICIPANT	\N	PRESENT	0
744383	744168	20046A	PARTICIPANT	\N	PRESENT	0
744385	744168	11056N	PARTICIPANT	\N	PRESENT	0
744386	744168	19333N	PARTICIPANT	\N	PRESENT	0
744387	744168	08061X	PARTICIPANT	\N	PRESENT	0
744388	744168	20104S	PARTICIPANT	\N	PRESENT	0
744389	744168	19701S	PARTICIPANT	\N	PRESENT	0
744390	744168	19251M	PARTICIPANT	\N	PRESENT	0
744393	744168	19619A	PARTICIPANT	\N	PRESENT	0
744394	744168	20032T	PARTICIPANT	\N	PRESENT	0
744395	744168	05008E	PARTICIPANT	\N	PRESENT	0
744397	744168	19741B	PARTICIPANT	\N	PRESENT	0
744398	744168	99004R	PARTICIPANT	\N	PRESENT	0
744949	744160	14189C	PARTICIPANT	\N	PRESENT	0
744400	744168	19479G	PARTICIPANT	\N	PRESENT	0
744401	744396	19527W	PARTICIPANT	\N	PRESENT	0
744402	744396	19643A	PARTICIPANT	\N	PRESENT	0
744403	744396	20132W	PARTICIPANT	\N	PRESENT	0
744404	744396	19651A	PARTICIPANT	\N	PRESENT	0
744405	744396	20138D	PARTICIPANT	\N	PRESENT	0
744406	744396	19611R	PARTICIPANT	\N	PRESENT	0
744407	744396	20152B	PARTICIPANT	\N	PRESENT	0
744408	744396	20098N	PARTICIPANT	\N	PRESENT	0
744409	744396	20058E	PARTICIPANT	\N	PRESENT	0
744410	744396	14030Q	PARTICIPANT	\N	PRESENT	0
744411	744396	20180F	PARTICIPANT	\N	PRESENT	0
744412	744396	04059M	PARTICIPANT	\N	PRESENT	0
744413	744396	20112S	PARTICIPANT	\N	PRESENT	0
744414	744168	14133K	PARTICIPANT	\N	PRESENT	0
744415	744168	20298U	PARTICIPANT	\N	PRESENT	0
744416	744168	14071N	PARTICIPANT	\N	PRESENT	0
744417	744168	20980G	PARTICIPANT	\N	PRESENT	0
744948	744160	14133K	PARTICIPANT	\N	PRESENT	0
744950	744160	14089Y	PARTICIPANT	\N	EXCUSE	0
744951	744160	17737W	PARTICIPANT	\N	EXCUSE	0
744952	744160	11101A	PARTICIPANT	\N	PRESENT	0
744953	744160	19701S	PARTICIPANT	\N	PRESENT	0
744954	744160	20100N	PARTICIPANT	\N	PRESENT	0
744955	744160	08018U	PARTICIPANT	\N	EXCUSE	0
744956	744160	20286Q	PARTICIPANT	\N	EXCUSE	0
744957	744160	04035D	PARTICIPANT	\N	EXCUSE	0
744958	744160	14033T	PARTICIPANT	\N	PRESENT	0
744959	744160	14026U	PARTICIPANT	\N	EXCUSE	0
744960	744160	20128B	PARTICIPANT	\N	PRESENT	0
744961	744160	14097Y	PARTICIPANT	\N	PRESENT	0
744962	744160	14073Q	PARTICIPANT	\N	EXCUSE	0
744963	744160	19711U	PARTICIPANT	\N	PRESENT	0
761847	761709	14219Q	PARTICIPANT	\N	PRESENT	0
761848	761709	11070L	PARTICIPANT	\N	PRESENT	0
761849	761709	19629C	PARTICIPANT	\N	PRESENT	0
761850	761709	21094N	PARTICIPANT	\N	PRESENT	0
761851	761709	11085T	PARTICIPANT	\N	PRESENT	0
761852	761709	11053K	PARTICIPANT	\N	PRESENT	0
761853	761709	20040T	PARTICIPANT	\N	PRESENT	0
761854	761709	21053D	PARTICIPANT	\N	PRESENT	0
761855	761709	01058X	PARTICIPANT	\N	PRESENT	0
761856	761709	21038E	PARTICIPANT	\N	PRESENT	0
761857	761709	21052C	PARTICIPANT	\N	PRESENT	0
761858	761709	14257W	PARTICIPANT	\N	PRESENT	0
761859	761709	19347U	PARTICIPANT	\N	PRESENT	0
761860	761709	21093M	PARTICIPANT	\N	PRESENT	0
761861	761709	20266L	PARTICIPANT	\N	PRESENT	0
761862	761709	14217N	PARTICIPANT	\N	PRESENT	0
761863	761709	21051B	PARTICIPANT	\N	PRESENT	0
761864	761709	14069U	PARTICIPANT	\N	PRESENT	0
761865	761709	20080C	PARTICIPANT	\N	PRESENT	0
761866	761709	19669L	PARTICIPANT	\N	PRESENT	0
761867	761709	19563B	PARTICIPANT	\N	PRESENT	0
761868	761709	95041E	PARTICIPANT	\N	PRESENT	0
761869	761709	20252E	PARTICIPANT	\N	PRESENT	0
761870	761709	14053L	PARTICIPANT	\N	PRESENT	0
761871	761709	20062A	PARTICIPANT	\N	PRESENT	0
761873	761709	20148F	PARTICIPANT	\N	PRESENT	0
761874	761709	19697Q	PARTICIPANT	\N	PRESENT	0
761875	761709	14083S	PARTICIPANT	\N	PRESENT	0
761876	761709	20044X	PARTICIPANT	\N	PRESENT	0
761877	761709	21063F	PARTICIPANT	\N	PRESENT	0
761878	761709	08018U	PARTICIPANT	\N	PRESENT	0
761879	761709	21042A	PARTICIPANT	\N	PRESENT	0
761880	761709	19367Y	PARTICIPANT	\N	PRESENT	0
761881	761709	20018V	PARTICIPANT	\N	PRESENT	0
761882	761709	21054E	PARTICIPANT	\N	PRESENT	0
761883	761709	21073H	PARTICIPANT	\N	PRESENT	0
761884	761709	21049H	PARTICIPANT	\N	PRESENT	0
761885	761709	20060X	PARTICIPANT	\N	PRESENT	0
761886	761709	20022R	PARTICIPANT	\N	PRESENT	0
761887	761709	19591F	PARTICIPANT	\N	PRESENT	0
761888	761709	19489J	PARTICIPANT	\N	PRESENT	0
761889	761709	21096Q	PARTICIPANT	\N	PRESENT	0
761890	761709	21092L	PARTICIPANT	\N	PRESENT	0
761891	761709	20114U	PARTICIPANT	\N	PRESENT	0
761892	761709	14215L	PARTICIPANT	\N	PRESENT	0
761893	761709	14059S	PARTICIPANT	\N	PRESENT	0
761894	761709	86034E	PARTICIPANT	\N	PRESENT	0
761895	761709	14259Y	PARTICIPANT	\N	PRESENT	0
761896	761709	11074Q	PARTICIPANT	\N	PRESENT	0
761897	761709	11072N	PARTICIPANT	\N	PRESENT	0
761898	761709	08061X	PARTICIPANT	\N	PRESENT	0
761899	761709	04045F	PARTICIPANT	\N	PRESENT	0
761900	761709	19695N	PARTICIPANT	\N	PRESENT	0
761903	761709	20054A	PARTICIPANT	\N	PRESENT	0
761906	761709	21040X	PARTICIPANT	\N	PRESENT	0
761907	761709	18193Q	PARTICIPANT	\N	PRESENT	0
761908	761709	21078N	PARTICIPANT	\N	PRESENT	0
761909	761709	20082E	PARTICIPANT	\N	PRESENT	0
761910	761709	20038A	PARTICIPANT	\N	PRESENT	0
761917	761709	21060C	PARTICIPANT	\N	PRESENT	0
761921	761709	07033P	PARTICIPANT	\N	PRESENT	0
761924	761709	14357A	PARTICIPANT	\N	PRESENT	0
761939	761709	20108W	PARTICIPANT	\N	PRESENT	0
761948	761709	20124W	PARTICIPANT	\N	PRESENT	0
761958	761709	14211G	PARTICIPANT	\N	PRESENT	0
761959	761709	21083K	PARTICIPANT	\N	PRESENT	0
761960	761709	19709B	PARTICIPANT	\N	PRESENT	0
761961	761709	21037D	PARTICIPANT	\N	PRESENT	0
761962	761709	19725B	PARTICIPANT	\N	PRESENT	0
761963	761709	21059K	PARTICIPANT	\N	PRESENT	0
761965	761709	14147R	PARTICIPANT	\N	PRESENT	0
761966	761709	14151M	PARTICIPANT	\N	PRESENT	0
761967	761709	20092G	PARTICIPANT	\N	PRESENT	0
762080	761710	11090Q	PARTICIPANT	\N	PRESENT	0
761969	761709	21068L	PARTICIPANT	\N	PRESENT	0
761970	761709	21069M	PARTICIPANT	\N	PRESENT	0
761971	761709	04042C	PARTICIPANT	\N	PRESENT	0
761972	761709	19647E	PARTICIPANT	\N	PRESENT	0
761975	761709	20026V	PARTICIPANT	\N	PRESENT	0
761980	761709	14331P	PARTICIPANT	\N	PRESENT	0
761981	761709	08010L	PARTICIPANT	\N	PRESENT	0
761982	761709	14042U	PARTICIPANT	\N	PRESENT	0
761983	761709	11048N	PARTICIPANT	\N	PRESENT	0
761984	761709	19820Y	PARTICIPANT	\N	PRESENT	0
761985	761709	21087P	PARTICIPANT	\N	PRESENT	0
762081	761710	21063F	PARTICIPANT	\N	PRESENT	0
762082	761710	18207D	PARTICIPANT	\N	PRESENT	0
762114	761710	21054E	PARTICIPANT	\N	PRESENT	0
762084	761710	11045K	PARTICIPANT	\N	PRESENT	0
762085	761710	95041E	PARTICIPANT	\N	PRESENT	0
762086	761710	19649G	PARTICIPANT	\N	PRESENT	0
762087	761710	14151M	PARTICIPANT	\N	PRESENT	0
762088	761710	20060X	PARTICIPANT	\N	PRESENT	0
762089	761710	21059K	PARTICIPANT	\N	PRESENT	0
762090	761710	19621T	PARTICIPANT	\N	PRESENT	0
762091	761710	19691J	PARTICIPANT	\N	PRESENT	0
762092	761710	19826F	PARTICIPANT	\N	PRESENT	0
762093	761710	21053D	PARTICIPANT	\N	PRESENT	0
762094	761710	14055N	PARTICIPANT	\N	PRESENT	0
762095	761710	20040T	PARTICIPANT	\N	PRESENT	0
762096	761710	20034V	PARTICIPANT	\N	PRESENT	0
762097	761710	14053L	PARTICIPANT	\N	PRESENT	0
762098	761710	20062A	PARTICIPANT	\N	PRESENT	0
762099	761710	19669L	PARTICIPANT	\N	PRESENT	0
762100	761710	14021P	PARTICIPANT	\N	PRESENT	0
762101	761710	19725B	PARTICIPANT	\N	PRESENT	0
762102	761710	19820Y	PARTICIPANT	\N	PRESENT	0
762103	761710	14097Y	PARTICIPANT	\N	PRESENT	0
762104	761710	21089R	PARTICIPANT	\N	PRESENT	0
762105	761710	21062E	PARTICIPANT	\N	PRESENT	0
762106	761710	20018V	PARTICIPANT	\N	PRESENT	0
762107	761710	19489J	PARTICIPANT	\N	PRESENT	0
762108	761710	21060C	PARTICIPANT	\N	PRESENT	0
762109	761710	21031W	PARTICIPANT	\N	PRESENT	0
762110	761710	11027H	PARTICIPANT	\N	PRESENT	0
762111	761710	20110Q	PARTICIPANT	\N	PRESENT	0
762112	761710	21093M	PARTICIPANT	\N	PRESENT	0
762113	761710	18231D	PARTICIPANT	\N	PRESENT	0
762115	761710	21076L	PARTICIPANT	\N	PRESENT	0
762116	761710	21040X	PARTICIPANT	\N	PRESENT	0
762117	761710	19629C	PARTICIPANT	\N	PRESENT	0
762118	761710	14083S	PARTICIPANT	\N	PRESENT	0
762119	761710	14189C	PARTICIPANT	\N	PRESENT	0
762120	761710	21056G	PARTICIPANT	\N	PRESENT	0
762121	761710	21087P	PARTICIPANT	\N	PRESENT	0
762122	761710	19585H	PARTICIPANT	\N	PRESENT	0
762123	761710	14251Q	PARTICIPANT	\N	PRESENT	0
762124	761710	21085M	PARTICIPANT	\N	PRESENT	0
762125	761710	20124W	PARTICIPANT	\N	PRESENT	0
762126	761710	14187A	PARTICIPANT	\N	PRESENT	0
762127	761710	17737W	PARTICIPANT	\N	PRESENT	0
762128	761710	20032T	PARTICIPANT	\N	PRESENT	0
762129	761710	10015M	PARTICIPANT	\N	PRESENT	0
762130	761710	20026V	PARTICIPANT	\N	PRESENT	0
762131	761710	21039F	PARTICIPANT	\N	PRESENT	0
762132	761710	21055F	PARTICIPANT	\N	PRESENT	0
762133	761710	19673G	PARTICIPANT	\N	PRESENT	0
762134	761710	21044C	PARTICIPANT	\N	PRESENT	0
762135	761710	14259Y	PARTICIPANT	\N	PRESENT	0
762136	761710	20104S	PARTICIPANT	\N	PRESENT	0
762137	761710	20148F	PARTICIPANT	\N	PRESENT	0
762138	761710	14215L	PARTICIPANT	\N	PRESENT	0
762139	761710	08060W	PARTICIPANT	\N	PRESENT	0
762140	761710	21077M	PARTICIPANT	\N	PRESENT	0
762141	761710	18193Q	PARTICIPANT	\N	PRESENT	0
762142	761710	21088Q	PARTICIPANT	\N	PRESENT	0
762143	761710	11056N	PARTICIPANT	\N	PRESENT	0
762144	761710	19447X	PARTICIPANT	\N	PRESENT	0
762145	761710	14089Y	PARTICIPANT	\N	PRESENT	0
762146	761710	04047H	PARTICIPANT	\N	PRESENT	0
762147	761710	14217N	PARTICIPANT	\N	PRESENT	0
762148	761710	20252E	PARTICIPANT	\N	PRESENT	0
762149	761710	14069U	PARTICIPANT	\N	PRESENT	0
762150	761710	19573D	PARTICIPANT	\N	PRESENT	0
762151	761710	19575F	PARTICIPANT	\N	PRESENT	0
762152	761710	21091K	PARTICIPANT	\N	PRESENT	0
762153	761710	19111A	PARTICIPANT	\N	PRESENT	0
762154	761710	19631V	PARTICIPANT	\N	PRESENT	0
762155	761710	14257W	PARTICIPANT	\N	PRESENT	0
762156	761710	21052C	PARTICIPANT	\N	PRESENT	0
762157	761710	19782L	PARTICIPANT	\N	PRESENT	0
740480	736293	19593H	PARTICIPANT	\N	PRESENT	0
740481	736293	19766L	PARTICIPANT	\N	PRESENT	0
740482	736293	04070G	PARTICIPANT	\N	PRESENT	0
740483	736293	20132W	PARTICIPANT	\N	PRESENT	0
740484	736293	20134Y	PARTICIPANT	\N	PRESENT	0
740485	736293	19699S	PARTICIPANT	\N	PRESENT	0
740486	736293	14073Q	PARTICIPANT	\N	PRESENT	0
740487	736293	19611R	PRESIDENT	0	PRESENT	0
740488	736293	20142Y	PARTICIPANT	\N	PRESENT	0
740489	736293	20052X	PARTICIPANT	\N	PRESENT	0
740490	736293	20058E	PARTICIPANT	\N	PRESENT	0
740491	736293	20056C	PARTICIPANT	\N	PRESENT	0
740492	736293	20026V	PARTICIPANT	\N	PRESENT	0
740493	736293	20084G	PARTICIPANT	\N	PRESENT	0
740506	736293	19573D	PARTICIPANT	\N	PRESENT	0
740522	738012	99004R	PARTICIPANT	\N	PRESENT	0
740524	738012	19593H	PARTICIPANT	\N	PRESENT	0
740528	738012	14089Y	PARTICIPANT	\N	PRESENT	0
740529	738012	20110Q	PARTICIPANT	\N	PRESENT	0
740530	738012	20018V	PARTICIPANT	\N	PRESENT	0
740531	738012	19649G	PARTICIPANT	\N	PRESENT	0
740532	738012	11072N	PARTICIPANT	\N	PRESENT	0
740533	738012	19515S	PARTICIPANT	\N	PRESENT	0
740534	738012	20132W	PARTICIPANT	\N	PRESENT	0
740535	738012	14215L	PARTICIPANT	\N	PRESENT	0
740536	738012	14053L	PARTICIPANT	\N	PRESENT	0
740537	738012	19749K	PARTICIPANT	\N	PRESENT	0
740540	738012	95063L	PARTICIPANT	\N	PRESENT	0
740541	738146	04070G	PARTICIPANT	\N	PRESENT	0
740542	738146	19643A	PARTICIPANT	\N	PRESENT	0
740543	738146	20134Y	PARTICIPANT	\N	PRESENT	0
740544	738146	20064C	PRESIDENT	0	PRESENT	0
740545	738146	14251Q	PARTICIPANT	\N	PRESENT	0
740546	738146	11045K	PARTICIPANT	\N	PRESENT	0
740547	738146	11083R	PARTICIPANT	\N	PRESENT	0
740548	738146	14147R	PARTICIPANT	\N	PRESENT	0
740550	738012	14030Q	PARTICIPANT	\N	PRESENT	0
740551	738012	20022R	PARTICIPANT	\N	PRESENT	0
740552	738012	19447X	PARTICIPANT	\N	PRESENT	0
740553	738012	01028R	PARTICIPANT	\N	PRESENT	0
740554	738146	20060X	PARTICIPANT	\N	PRESENT	0
740555	738146	17737W	PARTICIPANT	\N	PRESENT	0
740556	738012	20266L	PARTICIPANT	\N	PRESENT	0
740561	738012	14001X	PARTICIPANT	\N	PRESENT	0
740563	738012	05008E	PARTICIPANT	\N	PRESENT	0
740564	738012	20032T	PARTICIPANT	\N	PRESENT	0
740565	738012	04057K	PARTICIPANT	\N	PRESENT	0
740566	738012	19441R	PARTICIPANT	\N	PRESENT	0
740570	738012	19711U	PARTICIPANT	\N	PRESENT	0
740568	738012	14073Q	PARTICIPANT	\N	PRESENT	0
740569	738012	20048C	PARTICIPANT	\N	PRESENT	0
740571	738012	97011G	PARTICIPANT	\N	PRESENT	0
740572	738146	20152B	PARTICIPANT	\N	PRESENT	0
740573	738012	20058E	PARTICIPANT	\N	PRESENT	0
740574	738012	19543W	PARTICIPANT	\N	PRESENT	0
740584	738012	17737W	PARTICIPANT	\N	PRESENT	0
740586	738012	20126Y	PARTICIPANT	\N	PRESENT	0
740603	738012	14207L	PARTICIPANT	\N	PRESENT	0
740604	738012	11056N	PARTICIPANT	\N	PRESENT	0
740605	738012	20130U	PARTICIPANT	\N	PRESENT	0
740606	738012	07029T	PARTICIPANT	\N	PRESENT	0
740608	738012	19583F	PARTICIPANT	\N	PRESENT	0
740609	738012	14259Y	PARTICIPANT	\N	PRESENT	0
740610	738012	14147R	PARTICIPANT	\N	PRESENT	0
740611	738012	11080N	PARTICIPANT	\N	PRESENT	0
740618	738012	14083S	PARTICIPANT	\N	PRESENT	0
740619	738012	14195A	PARTICIPANT	\N	PRESENT	0
740620	738012	14059S	PARTICIPANT	\N	PRESENT	0
740621	738012	20034V	PARTICIPANT	\N	PRESENT	0
740622	738012	11045K	PARTICIPANT	\N	PRESENT	0
740623	738012	19667J	PARTICIPANT	\N	PRESENT	0
740628	738012	11026G	PARTICIPANT	\N	PRESENT	0
740647	738012	20114U	PARTICIPANT	\N	PRESENT	0
740679	738013	19649G	PARTICIPANT	\N	PRESENT	0
740712	738013	11031D	PARTICIPANT	\N	PRESENT	0
740714	738013	14259Y	PARTICIPANT	\N	PRESENT	0
740715	738013	20034V	PARTICIPANT	\N	PRESENT	0
740711	738013	19447X	PARTICIPANT	\N	PRESENT	0
740716	738013	14089Y	PARTICIPANT	\N	PRESENT	0
740709	738013	14207L	PARTICIPANT	\N	PRESENT	0
740710	738013	19543W	PARTICIPANT	\N	PRESENT	0
740687	738013	19583F	PARTICIPANT	\N	PRESENT	0
740717	738013	20126Y	PARTICIPANT	\N	PRESENT	0
740689	738013	11072N	PARTICIPANT	\N	PRESENT	0
740718	738013	20058E	PARTICIPANT	\N	PRESENT	0
740695	738013	14053L	PARTICIPANT	\N	PRESENT	0
740696	738013	19749K	PARTICIPANT	\N	PRESENT	0
740699	738013	04085P	PARTICIPANT	\N	PRESENT	0
740707	738013	20110Q	PARTICIPANT	\N	PRESENT	0
740708	738013	14215L	PARTICIPANT	\N	PRESENT	0
740720	738013	14059S	PARTICIPANT	\N	PRESENT	0
740721	738013	20032T	PARTICIPANT	\N	PRESENT	0
740722	738013	97011G	PARTICIPANT	\N	PRESENT	0
740723	738013	19719D	PARTICIPANT	\N	PRESENT	0
740724	738013	19593H	PARTICIPANT	\N	PRESENT	0
740725	738013	95063L	PARTICIPANT	\N	PRESENT	0
740731	738013	20266L	PARTICIPANT	\N	PRESENT	0
740732	738013	17737W	PARTICIPANT	\N	PRESENT	0
740733	738013	08010L	PARTICIPANT	\N	PRESENT	0
740734	738013	20152B	PARTICIPANT	\N	PRESENT	0
740741	738013	11033F	PARTICIPANT	\N	PRESENT	0
750337	750021	14083S	PARTICIPANT	\N	PRESENT	0
740677	738013	11045K	PARTICIPANT	\N	PRESENT	0
750338	750021	20070A	PARTICIPANT	\N	PRESENT	0
750339	750021	14121F	PARTICIPANT	\N	PRESENT	0
750340	750021	99004R	PARTICIPANT	\N	PRESENT	0
750341	750021	19762G	PARTICIPANT	\N	PRESENT	0
750342	750021	19479G	PARTICIPANT	\N	EXCUSE	0
750343	750021	19671E	PARTICIPANT	\N	EXCUSE	0
750344	749973	11090Q	PARTICIPANT	\N	PRESENT	0
750345	749973	14193X	PARTICIPANT	\N	PRESENT	0
750346	749973	19467C	PARTICIPANT	\N	PRESENT	0
750347	749973	18083K	PARTICIPANT	\N	PRESENT	0
750348	749973	20072C	PARTICIPANT	\N	PRESENT	0
750352	749973	19701S	PARTICIPANT	\N	PRESENT	0
750353	749973	14133K	PARTICIPANT	\N	PRESENT	0
750354	749973	19820Y	PARTICIPANT	\N	PRESENT	0
750355	750218	20032T	PARTICIPANT	\N	PRESENT	0
750356	750218	20122U	PARTICIPANT	\N	PRESENT	0
750357	750218	19701S	PARTICIPANT	\N	PRESENT	0
750358	750218	20136B	PARTICIPANT	\N	PRESENT	0
750359	750218	14031R	PARTICIPANT	\N	PRESENT	0
750360	750218	20038A	PARTICIPANT	\N	PRESENT	0
750361	750218	14219Q	PRESIDENT	0	PRESENT	0
750362	750218	19820Y	PARTICIPANT	\N	PRESENT	0
750363	750218	20046A	PARTICIPANT	\N	PRESENT	0
750364	750218	19826F	PARTICIPANT	\N	PRESENT	0
750365	750218	20102Q	PARTICIPANT	\N	PRESENT	0
750366	750218	17229F	PARTICIPANT	\N	PRESENT	0
750367	750218	19637C	PARTICIPANT	\N	PRESENT	0
750368	750218	18083K	PARTICIPANT	\N	PRESENT	0
750369	750218	20100N	PARTICIPANT	\N	PRESENT	0
750370	750218	14237S	PARTICIPANT	\N	PRESENT	0
750371	750218	20068G	PARTICIPANT	\N	PRESENT	0
750372	750218	19685L	PARTICIPANT	\N	PRESENT	0
750373	750218	19745F	PARTICIPANT	\N	PRESENT	0
750374	750218	19577H	PARTICIPANT	\N	PRESENT	0
750375	750218	19681G	PARTICIPANT	\N	PRESENT	0
750376	750218	20024T	PARTICIPANT	\N	PRESENT	0
750377	750218	19525U	PARTICIPANT	\N	PRESENT	0
750380	749973	19507S	PARTICIPANT	\N	PRESENT	0
750390	749973	01024M	PARTICIPANT	\N	PRESENT	0
750393	749973	08061X	PARTICIPANT	\N	PRESENT	0
750394	749973	20102Q	PARTICIPANT	\N	PRESENT	0
750397	749973	20046A	PARTICIPANT	\N	PRESENT	0
750398	749973	20022R	PARTICIPANT	\N	PRESENT	0
750399	749973	20044X	PARTICIPANT	\N	PRESENT	0
750400	749973	14083S	PARTICIPANT	\N	PRESENT	0
750410	749973	20028X	PARTICIPANT	\N	PRESENT	0
750402	749973	20126Y	PARTICIPANT	\N	PRESENT	0
750404	749973	19745F	PARTICIPANT	\N	PRESENT	0
750412	749973	07029T	PARTICIPANT	\N	PRESENT	0
750413	749973	20086J	PARTICIPANT	\N	PRESENT	0
750414	749973	20104S	PARTICIPANT	\N	PRESENT	0
750415	749973	08034U	PARTICIPANT	\N	PRESENT	0
750417	749973	98022P	PARTICIPANT	\N	PRESENT	0
750418	749973	14215L	PARTICIPANT	\N	PRESENT	0
750419	749973	01048V	PARTICIPANT	\N	PRESENT	0
750420	749973	20078J	PARTICIPANT	\N	PRESENT	0
750421	749973	19762G	PARTICIPANT	\N	PRESENT	0
750424	749973	20096L	PARTICIPANT	\N	PRESENT	0
755586	753665	19387D	PARTICIPANT	\N	PRESENT	0
755587	753665	19349W	PARTICIPANT	\N	PRESENT	0
755588	753665	20092G	PARTICIPANT	\N	PRESENT	0
755589	753665	20080C	PARTICIPANT	\N	PRESENT	0
755590	753665	14257W	PARTICIPANT	\N	PRESENT	0
755591	753665	19687N	PARTICIPANT	\N	PRESENT	0
755592	753665	19695N	PARTICIPANT	\N	PRESENT	0
755593	753665	11056N	PARTICIPANT	\N	PRESENT	0
755594	753665	19479G	PARTICIPANT	\N	PRESENT	0
755595	753665	20050V	PARTICIPANT	\N	PRESENT	0
755596	753665	20144B	PARTICIPANT	\N	PRESENT	0
755597	753665	14083S	PARTICIPANT	\N	PRESENT	0
755598	753665	19719D	PARTICIPANT	\N	PRESENT	0
755599	753665	19711U	PARTICIPANT	\N	PRESENT	0
755600	753665	20120S	PARTICIPANT	\N	PRESENT	0
755601	753665	20062A	PARTICIPANT	\N	PRESENT	0
755602	753665	14215L	PARTICIPANT	\N	PRESENT	0
755603	753665	19399H	PARTICIPANT	\N	PRESENT	0
755604	753665	07029T	PARTICIPANT	\N	PRESENT	0
755605	753665	18083K	PARTICIPANT	\N	PRESENT	0
755606	753665	21050A	PARTICIPANT	\N	PRESENT	0
755607	753665	11040E	PARTICIPANT	\N	PRESENT	0
755608	753665	20136B	PARTICIPANT	\N	PRESENT	0
755609	752396	14021P	PARTICIPANT	\N	PRESENT	0
755610	753665	14031R	PARTICIPANT	\N	PRESENT	0
755584	753665	11090Q	PARTICIPANT	\N	PRESENT	0
755585	753665	14187A	PARTICIPANT	\N	PRESENT	0
755611	753665	20116W	PARTICIPANT	\N	PRESENT	0
755612	753665	21044C	PARTICIPANT	\N	PRESENT	0
755613	753665	21066J	PARTICIPANT	\N	PRESENT	0
755614	753665	21070E	PARTICIPANT	\N	PRESENT	0
755615	753665	20044X	PARTICIPANT	\N	PRESENT	0
755616	753748	20136B	PARTICIPANT	\N	PRESENT	0
755617	753748	14031R	PRESIDENT	1	PRESENT	0
755618	753748	11053K	PARTICIPANT	\N	PRESENT	0
755619	753748	14219Q	PRESIDENT	0	PRESENT	0
755620	753748	19820Y	PARTICIPANT	\N	PRESENT	0
755621	753748	20046A	PARTICIPANT	\N	PRESENT	0
755622	753748	19826F	PARTICIPANT	\N	PRESENT	0
755623	753748	14169X	PARTICIPANT	\N	PRESENT	0
755624	753748	21065H	PARTICIPANT	\N	PRESENT	0
755625	753748	21084L	PARTICIPANT	\N	PRESENT	0
755626	753748	18083K	PARTICIPANT	\N	PRESENT	0
755627	753748	14237S	PARTICIPANT	\N	PRESENT	0
755628	753748	19551W	PARTICIPANT	\N	PRESENT	0
755629	753748	05012A	PARTICIPANT	\N	PRESENT	0
755630	753748	20106U	PARTICIPANT	\N	PRESENT	0
755631	753748	20068G	PARTICIPANT	\N	PRESENT	0
755632	753748	15197G	PARTICIPANT	\N	PRESENT	0
755633	753748	21070E	PARTICIPANT	\N	PRESENT	0
755634	753748	19685L	PARTICIPANT	\N	PRESENT	0
755635	753748	20120S	PARTICIPANT	\N	PRESENT	0
755636	753748	21051B	PARTICIPANT	\N	PRESENT	0
755637	753675	14001X	PARTICIPANT	\N	PRESENT	0
755638	753675	08047A	PARTICIPANT	\N	PRESENT	0
755639	753665	19629C	PARTICIPANT	\N	PRESENT	0
755640	753665	20070A	PARTICIPANT	\N	PRESENT	0
755641	753665	14037X	PARTICIPANT	\N	PRESENT	0
755642	753665	21079P	PARTICIPANT	\N	PRESENT	0
755643	753665	17023S	PARTICIPANT	\N	PRESENT	0
755644	753665	21069M	PARTICIPANT	\N	PRESENT	0
755645	753665	14327T	PARTICIPANT	\N	PRESENT	0
755679	753666	20080C	PARTICIPANT	\N	PRESENT	0
755680	753666	20070A	PARTICIPANT	\N	PRESENT	0
755681	753666	20092G	PARTICIPANT	\N	PRESENT	0
755682	753666	21079P	PARTICIPANT	\N	PRESENT	0
755683	753666	21070E	PARTICIPANT	\N	PRESENT	0
755684	753666	17023S	PARTICIPANT	\N	PRESENT	0
755685	753666	19349W	PARTICIPANT	\N	PRESENT	0
755686	753666	19565D	PARTICIPANT	\N	PRESENT	0
755687	753666	14327T	PARTICIPANT	\N	PRESENT	0
755688	753666	19711U	PARTICIPANT	\N	PRESENT	0
755689	753666	07029T	PARTICIPANT	\N	PRESENT	0
755690	753666	20044X	PARTICIPANT	\N	PRESENT	0
755691	753666	19399H	PARTICIPANT	\N	PRESENT	0
755692	753666	14031R	PARTICIPANT	\N	PRESENT	0
755693	753666	19479G	PARTICIPANT	\N	PRESENT	0
755694	753666	20116W	PARTICIPANT	\N	PRESENT	0
755695	753666	11040E	PARTICIPANT	\N	PRESENT	0
755696	753666	11056N	PARTICIPANT	\N	PRESENT	0
755697	753666	21049H	PARTICIPANT	\N	PRESENT	0
755698	753666	14169X	PARTICIPANT	\N	PRESENT	0
755699	753666	19758L	PARTICIPANT	\N	PRESENT	0
755700	753666	14026U	PARTICIPANT	\N	PRESENT	0
755701	753666	20100N	PARTICIPANT	\N	PRESENT	0
755715	753666	21094N	PARTICIPANT	\N	PRESENT	0
755716	753666	20248J	PARTICIPANT	\N	PRESENT	0
755717	753666	21078N	PARTICIPANT	\N	PRESENT	0
755718	753666	14225N	PARTICIPANT	\N	PRESENT	0
755748	753667	14331P	PARTICIPANT	\N	PRESENT	0
755749	753667	11048N	PARTICIPANT	\N	PRESENT	0
755750	753667	08073C	PARTICIPANT	\N	PRESENT	0
755751	753667	20094J	PARTICIPANT	\N	PRESENT	0
755677	753666	11090Q	PARTICIPANT	\N	PRESENT	0
755678	753666	19687N	PARTICIPANT	\N	PRESENT	0
755752	753667	14133K	PARTICIPANT	\N	PRESENT	0
755753	753667	14221J	PARTICIPANT	\N	PRESENT	0
755754	753667	04070G	PARTICIPANT	\N	PRESENT	0
755755	753667	20100N	PARTICIPANT	\N	PRESENT	0
755756	753667	19760E	PARTICIPANT	\N	PRESENT	0
755757	753667	21078N	PARTICIPANT	\N	PRESENT	0
755758	753667	18395Y	PARTICIPANT	\N	PRESENT	0
755759	753667	10015M	PARTICIPANT	\N	PRESENT	0
755760	753667	20248J	PARTICIPANT	\N	PRESENT	0
755761	753667	14237S	PARTICIPANT	\N	PRESENT	0
755762	753667	21088Q	PARTICIPANT	\N	PRESENT	0
755763	753667	19565D	PARTICIPANT	\N	PRESENT	0
755764	753667	19479G	PARTICIPANT	\N	PRESENT	0
755765	753667	19709B	PARTICIPANT	\N	PRESENT	0
755766	753667	19629C	PARTICIPANT	\N	PRESENT	0
755767	753667	21049H	PARTICIPANT	\N	PRESENT	0
755768	753667	11056N	PARTICIPANT	\N	PRESENT	0
755769	753667	18083K	PARTICIPANT	\N	PRESENT	0
755770	753667	07029T	PARTICIPANT	\N	PRESENT	0
755771	753667	21037D	PARTICIPANT	\N	PRESENT	0
755772	753667	21057H	PARTICIPANT	\N	PRESENT	0
755773	753667	14021P	PARTICIPANT	\N	PRESENT	0
755774	753667	20080C	PARTICIPANT	\N	PRESENT	0
755746	753667	19593H	PARTICIPANT	\N	PRESENT	0
755747	753667	14193X	PARTICIPANT	\N	PRESENT	0
755775	753667	21045D	PARTICIPANT	\N	PRESENT	0
755776	753667	14179A	PARTICIPANT	\N	PRESENT	0
755846	755845	11048N	PARTICIPANT	\N	PRESENT	0
755848	755847	11048N	PARTICIPANT	\N	PRESENT	0
755907	755903	20136B	PARTICIPANT	\N	PRESENT	0
755908	755903	19551W	PARTICIPANT	\N	PRESENT	0
755909	755903	19820Y	PARTICIPANT	\N	PRESENT	0
755911	755903	19619A	PARTICIPANT	\N	PRESENT	0
755912	755904	20136B	PARTICIPANT	\N	PRESENT	0
755913	755904	19820Y	PARTICIPANT	\N	PRESENT	0
755914	755905	20136B	PARTICIPANT	\N	PRESENT	0
755915	755910	14225N	PARTICIPANT	\N	PRESENT	0
755916	755910	11048N	PARTICIPANT	\N	PRESENT	0
755918	755910	14083S	PARTICIPANT	\N	PRESENT	0
756139	755859	14111D	PARTICIPANT	\N	PRESENT	0
756140	755859	14195A	PARTICIPANT	\N	PRESENT	0
756138	755859	21042A	PARTICIPANT	\N	PRESENT	0
756141	755859	21046E	PARTICIPANT	\N	PRESENT	0
756142	755859	21076L	PARTICIPANT	\N	PRESENT	0
756144	755859	21054E	PARTICIPANT	\N	PRESENT	0
756145	755859	21081H	PARTICIPANT	\N	PRESENT	0
756146	755859	07029T	PARTICIPANT	\N	PRESENT	0
756147	755859	14207L	PARTICIPANT	\N	PRESENT	0
756149	755859	21058J	PARTICIPANT	\N	PRESENT	0
756150	755859	19866P	PARTICIPANT	\N	PRESENT	0
756151	755859	21068L	PARTICIPANT	\N	PRESENT	0
756152	755859	19798U	PARTICIPANT	\N	PRESENT	0
756153	755859	08056B	PARTICIPANT	\N	PRESENT	0
756154	755859	20036X	PARTICIPANT	\N	PRESENT	0
756155	755859	21070E	PARTICIPANT	\N	PRESENT	0
756156	755859	17779H	PARTICIPANT	\N	PRESENT	0
756157	755859	19565D	PARTICIPANT	\N	PRESENT	0
756158	755859	21088Q	PARTICIPANT	\N	PRESENT	0
756159	755859	19760E	PARTICIPANT	\N	PRESENT	0
756160	755859	19331L	PARTICIPANT	\N	PRESENT	0
756161	755859	08015R	PARTICIPANT	\N	PRESENT	0
756162	755859	19657G	PARTICIPANT	\N	PRESENT	0
756163	755859	04092N	PARTICIPANT	\N	PRESENT	0
756164	755859	18083K	PARTICIPANT	\N	PRESENT	0
756166	755859	20096L	PARTICIPANT	\N	PRESENT	0
740625	738369	11067R	PARTICIPANT	\N	PRESENT	0
740627	738369	19503N	PARTICIPANT	\N	PRESENT	0
740633	740632	14071N	PARTICIPANT	\N	PRESENT	0
740634	740632	20124W	PARTICIPANT	\N	PRESENT	0
740635	740632	19575F	PARTICIPANT	\N	PRESENT	0
740636	740632	19798U	PARTICIPANT	\N	PRESENT	0
740637	740632	19826F	PARTICIPANT	\N	PRESENT	0
740638	740632	20084G	PARTICIPANT	\N	PRESENT	0
740639	740632	14179A	PARTICIPANT	\N	PRESENT	0
743936	743935	14251Q	PARTICIPANT	\N	PRESENT	0
743937	743935	20064C	PARTICIPANT	\N	PRESENT	0
743938	743935	14030Q	PARTICIPANT	\N	PRESENT	0
743939	743935	20152B	PARTICIPANT	\N	PRESENT	0
743940	743935	17737W	PARTICIPANT	\N	PRESENT	0
743941	743935	20060X	PARTICIPANT	\N	PRESENT	0
743942	743935	20134Y	PARTICIPANT	\N	PRESENT	0
743943	743935	11083R	PARTICIPANT	\N	PRESENT	0
743944	743935	14179A	PARTICIPANT	\N	PRESENT	0
743945	743935	04070G	PARTICIPANT	\N	PRESENT	0
744541	744168	18083K	PARTICIPANT	\N	PRESENT	0
744550	744168	19347U	PARTICIPANT	\N	PRESENT	0
744551	744168	14237S	PARTICIPANT	\N	PRESENT	0
744552	744168	14089Y	PARTICIPANT	\N	PRESENT	0
744553	744168	14053L	PARTICIPANT	\N	PRESENT	0
744554	744168	11097X	PARTICIPANT	\N	PRESENT	0
744555	744168	07029T	PARTICIPANT	\N	PRESENT	0
744556	744168	14097Y	PARTICIPANT	\N	PRESENT	0
744605	744169	14225N	PARTICIPANT	\N	PRESENT	0
744606	744169	14331P	PARTICIPANT	\N	PRESENT	0
744607	744169	19531S	PARTICIPANT	\N	PRESENT	0
744608	744169	20100N	PARTICIPANT	\N	PRESENT	0
744609	744169	12041X	PARTICIPANT	\N	PRESENT	0
744610	744169	19565D	PARTICIPANT	\N	PRESENT	0
744611	744169	04057K	PARTICIPANT	\N	PRESENT	0
744612	744169	11083R	PARTICIPANT	\N	PRESENT	0
744613	744169	19553Y	PARTICIPANT	\N	PRESENT	0
744614	744169	10015M	PARTICIPANT	\N	PRESENT	0
744615	744169	18083K	PARTICIPANT	\N	PRESENT	0
744616	744169	19701S	PARTICIPANT	\N	PRESENT	0
744617	744169	20076G	PARTICIPANT	\N	PRESENT	0
744618	744169	14237S	PARTICIPANT	\N	PRESENT	0
744619	744169	11026G	PARTICIPANT	\N	PRESENT	0
744620	744169	04045F	PARTICIPANT	\N	PRESENT	0
744621	744169	14021P	PARTICIPANT	\N	PRESENT	0
744625	744169	19347U	PARTICIPANT	\N	PRESENT	0
744623	744169	08061X	PARTICIPANT	\N	PRESENT	0
744624	744169	19479G	PARTICIPANT	\N	PRESENT	0
744626	744169	04070G	PARTICIPANT	\N	PRESENT	0
744627	744169	01060R	PARTICIPANT	\N	PRESENT	0
744628	744169	14189C	PARTICIPANT	\N	PRESENT	0
744629	744169	14097Y	PARTICIPANT	\N	PRESENT	0
744630	744169	20134Y	PARTICIPANT	\N	PRESENT	0
744631	744169	14147R	PARTICIPANT	\N	PRESENT	0
744632	744169	14213J	PARTICIPANT	\N	PRESENT	0
744633	744169	20092G	PARTICIPANT	\N	PRESENT	0
744634	744169	20086J	PARTICIPANT	\N	PRESENT	0
744635	744169	20104S	PARTICIPANT	\N	PRESENT	0
744636	744169	14357A	PARTICIPANT	\N	PRESENT	0
744637	744169	14069U	PARTICIPANT	\N	PRESENT	0
744638	744169	19545Y	PARTICIPANT	\N	PRESENT	0
744639	744169	19383Y	PARTICIPANT	\N	PRESENT	0
744640	744169	19507S	PARTICIPANT	\N	PRESENT	0
744791	744225	14225N	PARTICIPANT	0	EXCUSE	0
744793	744705	14038Y	PARTICIPANT	\N	PRESENT	0
744794	744705	19467C	PARTICIPANT	\N	PRESENT	0
744795	744705	20034V	PARTICIPANT	\N	PRESENT	0
744796	744705	19515S	PARTICIPANT	\N	PRESENT	0
744797	744705	19782L	PARTICIPANT	\N	PRESENT	0
744798	744705	14187A	PARTICIPANT	\N	PRESENT	0
744799	744705	14357A	PARTICIPANT	\N	PRESENT	0
744800	744705	19413M	PARTICIPANT	\N	PRESENT	0
744801	744705	20144B	PARTICIPANT	\N	PRESENT	0
744802	744705	11090Q	PRESIDENT	0	PRESENT	0
744603	744169	01043Q	PARTICIPANT	\N	PRESENT	0
744604	744169	14133K	PARTICIPANT	\N	PRESENT	0
744803	744705	14033T	PARTICIPANT	\N	PRESENT	0
744804	744705	01025N	PARTICIPANT	\N	PRESENT	0
744805	744705	20054A	PARTICIPANT	\N	PRESENT	0
744806	744705	08015R	PARTICIPANT	\N	PRESENT	0
744807	744705	19575F	PARTICIPANT	\N	PRESENT	0
744808	744705	14207L	PARTICIPANT	\N	PRESENT	0
744809	744705	19563B	PARTICIPANT	\N	PRESENT	0
744810	744705	14257W	PARTICIPANT	\N	PRESENT	0
744811	744705	20028X	PARTICIPANT	\N	PRESENT	0
744812	744705	14329V	PARTICIPANT	\N	PRESENT	0
744813	744705	14037X	PARTICIPANT	\N	PRESENT	0
744814	744705	20062A	PARTICIPANT	\N	PRESENT	0
744815	744705	01043Q	PARTICIPANT	\N	PRESENT	0
744816	744705	20104S	PARTICIPANT	\N	PRESENT	0
744817	744705	14205J	PARTICIPANT	\N	PRESENT	0
744818	744705	20298U	PARTICIPANT	\N	PRESENT	0
744819	744705	20088L	PARTICIPANT	\N	EXCUSE	0
744820	744705	20286Q	PARTICIPANT	\N	EXCUSE	0
744821	744705	19866P	PARTICIPANT	\N	EXCUSE	0
744822	744705	19631V	PARTICIPANT	\N	EXCUSE	0
744864	744705	20092G	PARTICIPANT	\N	PRESENT	0
744865	744705	19441R	PARTICIPANT	\N	PRESENT	0
744866	744705	20082E	PARTICIPANT	\N	PRESENT	0
744867	744705	20094J	PARTICIPANT	\N	PRESENT	0
744868	744705	14251Q	PARTICIPANT	\N	PRESENT	0
744869	744705	04045F	PARTICIPANT	\N	PRESENT	0
744870	744705	19768N	PARTICIPANT	\N	PRESENT	0
744964	744160	08034U	PARTICIPANT	\N	EXCUSE	0
744965	744160	19441R	PARTICIPANT	\N	PRESENT	0
744966	744160	14001X	PARTICIPANT	\N	PRESENT	0
744967	744160	04057K	PARTICIPANT	\N	EXCUSE	0
744968	744160	14169X	PARTICIPANT	\N	PRESENT	0
744969	744160	14331P	PRESIDENT	0	PRESENT	0
744970	744160	10015M	PARTICIPANT	\N	EXCUSE	0
744971	744160	20098N	PARTICIPANT	\N	EXCUSE	0
744972	744160	19657G	PARTICIPANT	\N	PRESENT	0
746862	745858	20148F	PARTICIPANT	\N	PRESENT	0
746863	745858	18083K	PARTICIPANT	\N	PRESENT	0
746864	745858	14059S	PARTICIPANT	\N	PRESENT	0
746865	745858	19717B	PRESIDENT	0	PRESENT	0
746866	745858	11072N	PARTICIPANT	\N	PRESENT	0
746867	745858	20146D	PARTICIPANT	\N	PRESENT	0
746868	745858	20034V	PARTICIPANT	\N	PRESENT	0
746869	745858	17023S	PARTICIPANT	\N	PRESENT	0
747222	747221	20090E	PARTICIPANT	\N	PRESENT	0
747223	747221	14083S	PARTICIPANT	\N	PRESENT	0
747225	747221	19691J	PARTICIPANT	\N	PRESENT	0
747226	747221	20066E	PARTICIPANT	\N	PRESENT	0
747227	747221	20056C	PARTICIPANT	\N	PRESENT	0
747228	747221	19798U	PARTICIPANT	\N	PRESENT	0
747229	747221	20062A	PARTICIPANT	\N	PRESENT	0
747514	747512	14001X	PARTICIPANT	\N	PRESENT	0
747515	747512	19701S	PARTICIPANT	\N	PRESENT	0
747518	747517	19725B	PARTICIPANT	\N	PRESENT	0
747581	747532	19768N	PARTICIPANT	\N	PRESENT	0
747582	747532	20094J	PARTICIPANT	\N	PRESENT	0
747583	747532	14229S	PARTICIPANT	\N	PRESENT	0
747585	747532	20076G	PARTICIPANT	\N	PRESENT	0
747636	747532	20118Y	PARTICIPANT	\N	PRESENT	0
748131	748130	14001X	PARTICIPANT	\N	PRESENT	0
748132	748130	04057K	PARTICIPANT	\N	PRESENT	0
752357	752211	20130U	PARTICIPANT	\N	PRESENT	0
752581	752374	20048C	PARTICIPANT	\N	PRESENT	0
752582	752374	21085M	PARTICIPANT	\N	PRESENT	0
752583	752374	08069G	PARTICIPANT	\N	PRESENT	0
752584	752374	19399H	PARTICIPANT	\N	PRESENT	0
752585	752374	11048N	PARTICIPANT	\N	PRESENT	0
752586	752374	19591F	PARTICIPANT	\N	PRESENT	0
752587	752374	14213J	PARTICIPANT	\N	PRESENT	0
752588	752374	20066E	PARTICIPANT	\N	PRESENT	0
752589	752374	20034V	PARTICIPANT	\N	PRESENT	0
752590	752374	19551W	PARTICIPANT	\N	PRESENT	0
752591	752374	21093M	PARTICIPANT	\N	PRESENT	0
752592	752374	14121F	PARTICIPANT	\N	PRESENT	0
752593	752374	19531S	PARTICIPANT	\N	PRESENT	0
752594	752374	19683J	PARTICIPANT	\N	PRESENT	0
752595	752374	21044C	PARTICIPANT	\N	PRESENT	0
752596	752374	20056C	PARTICIPANT	\N	PRESENT	0
752597	752374	14097Y	PARTICIPANT	\N	PRESENT	0
752598	752374	19447X	PARTICIPANT	\N	PRESENT	0
752600	752374	14021P	PARTICIPANT	\N	PRESENT	0
762160	761710	20044X	PARTICIPANT	\N	PRESENT	0
762161	761710	21072G	PARTICIPANT	\N	PRESENT	0
762162	761710	20080C	PARTICIPANT	\N	PRESENT	0
762163	761710	21069M	PARTICIPANT	\N	PRESENT	0
762164	761710	20100N	PARTICIPANT	\N	PRESENT	0
762165	761710	20054A	PARTICIPANT	\N	PRESENT	0
762166	761710	14357A	PARTICIPANT	\N	PRESENT	0
762167	761710	14255U	PARTICIPANT	\N	PRESENT	0
762168	761710	20134Y	PARTICIPANT	\N	PRESENT	0
762169	761710	20264J	PARTICIPANT	\N	PRESENT	0
762170	761710	20048C	PARTICIPANT	\N	PRESENT	0
762171	761710	20092G	PARTICIPANT	\N	PRESENT	0
762172	761710	20130U	PARTICIPANT	\N	PRESENT	0
762173	761710	21095P	PARTICIPANT	\N	PRESENT	0
762174	761710	08018U	PARTICIPANT	\N	PRESENT	0
762175	761710	21067K	PARTICIPANT	\N	PRESENT	0
762176	761710	08010L	PARTICIPANT	\N	PRESENT	0
762158	761710	21043B	PARTICIPANT	\N	PRESENT	0
762159	761710	04045F	PARTICIPANT	\N	PRESENT	0
762177	761710	21057H	PARTICIPANT	\N	PRESENT	0
762178	761710	19367Y	PARTICIPANT	\N	PRESENT	0
762179	761710	19695N	PARTICIPANT	\N	PRESENT	0
762180	761710	20064C	PARTICIPANT	\N	PRESENT	0
762181	761710	17965H	PARTICIPANT	\N	PRESENT	0
762182	761710	17367Q	PARTICIPANT	\N	PRESENT	0
762183	761710	19563B	PARTICIPANT	\N	PRESENT	0
762184	761710	21045D	PARTICIPANT	\N	PRESENT	0
762185	761710	04033B	PARTICIPANT	\N	PRESENT	0
762186	761710	11048N	PARTICIPANT	\N	PRESENT	0
762187	761710	20082E	PARTICIPANT	\N	PRESENT	0
762188	761710	12028B	PARTICIPANT	\N	PRESENT	0
762189	761710	14219Q	PARTICIPANT	\N	PRESENT	0
762190	761710	21092L	PARTICIPANT	\N	PRESENT	0
762191	761710	19647E	PARTICIPANT	\N	PRESENT	0
762192	761710	04042C	PARTICIPANT	\N	PRESENT	0
762193	761710	20142Y	PARTICIPANT	\N	PRESENT	0
762194	761710	14147R	PARTICIPANT	\N	PRESENT	0
762195	761710	19347U	PARTICIPANT	\N	PRESENT	0
762196	761710	14107H	PARTICIPANT	\N	PRESENT	0
762197	761710	19479G	PARTICIPANT	\N	PRESENT	0
762198	761710	20072C	PARTICIPANT	\N	PRESENT	0
762199	761710	20266L	PARTICIPANT	\N	PRESENT	0
762200	761710	21071F	PARTICIPANT	\N	PRESENT	0
762201	761710	14193X	PARTICIPANT	\N	PRESENT	0
762202	761710	20052X	PARTICIPANT	\N	PRESENT	0
762203	761710	20066E	PARTICIPANT	\N	PRESENT	0
762204	761710	21047F	PARTICIPANT	\N	PRESENT	0
762205	761710	17779H	PARTICIPANT	\N	PRESENT	0
762206	761710	19591F	PARTICIPANT	\N	PRESENT	0
762207	761710	21038E	PARTICIPANT	\N	PRESENT	0
762208	761710	99004R	PARTICIPANT	\N	PRESENT	0
762209	761710	21068L	PARTICIPANT	\N	PRESENT	0
762210	761710	14179A	PARTICIPANT	\N	PRESENT	0
762211	761710	20114U	PARTICIPANT	\N	PRESENT	0
762212	761710	21051B	PARTICIPANT	\N	PRESENT	0
762213	761710	21094N	PARTICIPANT	\N	PRESENT	0
762214	761564	20074E	PARTICIPANT	\N	PRESENT	0
762215	761564	19673G	PARTICIPANT	\N	PRESENT	0
762216	761564	19447X	PARTICIPANT	\N	PRESENT	0
762217	761564	14089Y	PARTICIPANT	\N	PRESENT	0
762218	761564	14111D	PARTICIPANT	\N	PRESENT	0
762219	761564	08018U	PARTICIPANT	\N	PRESENT	0
762220	761564	21076L	PARTICIPANT	\N	EXCUSE	0
762221	761564	14215L	PARTICIPANT	\N	EXCUSE	0
762222	761564	04045F	PARTICIPANT	\N	EXCUSE	0
762223	761564	20022R	PARTICIPANT	\N	EXCUSE	0
762224	761564	11072N	PARTICIPANT	\N	EXCUSE	0
762225	761564	21043B	PARTICIPANT	\N	PRESENT	0
762226	761564	14189C	PARTICIPANT	\N	PRESENT	0
762227	761564	14147R	PARTICIPANT	\N	PRESENT	0
762228	761564	19111A	PARTICIPANT	\N	PRESENT	0
762229	761564	14053L	PARTICIPANT	\N	PRESENT	0
762230	761564	21044C	PARTICIPANT	\N	PRESENT	0
762231	761564	04047H	PRESIDENT	0	PRESENT	0
762232	761564	10015M	PARTICIPANT	\N	PRESENT	0
762233	761564	21038E	PARTICIPANT	\N	PRESENT	0
762234	761564	14259Y	PARTICIPANT	\N	PRESENT	0
762235	761564	20108W	PARTICIPANT	\N	EXCUSE	0
762236	761564	19719D	PARTICIPANT	\N	EXCUSE	0
762237	761564	21095P	PARTICIPANT	\N	PRESENT	0
762238	761564	19729F	PARTICIPANT	\N	EXCUSE	0
762239	761564	05008E	PARTICIPANT	\N	PRESENT	0
762240	761564	21057H	PARTICIPANT	\N	PRESENT	0
762241	761564	18231D	PARTICIPANT	\N	PRESENT	0
762242	761564	14151M	PARTICIPANT	\N	PRESENT	0
762255	761589	14059S	PARTICIPANT	\N	PRESENT	0
762408	761183	08010L	PARTICIPANT	\N	PRESENT	0
762409	761711	20142Y	PARTICIPANT	\N	PRESENT	0
762410	761711	04008A	PARTICIPANT	\N	PRESENT	0
762411	761183	12016W	PARTICIPANT	\N	PRESENT	0
762412	761711	20072C	PARTICIPANT	\N	PRESENT	0
762261	761589	01058X	PARTICIPANT	\N	PRESENT	0
762413	761711	19575F	PARTICIPANT	\N	PRESENT	0
762414	761711	20172F	PARTICIPANT	\N	PRESENT	0
762415	761711	20130U	PARTICIPANT	\N	PRESENT	0
762265	761589	19421M	PARTICIPANT	\N	PRESENT	0
762416	761711	19447X	PARTICIPANT	\N	PRESENT	0
762417	761711	14089Y	PARTICIPANT	\N	PRESENT	0
762268	761589	14193X	PARTICIPANT	\N	PRESENT	0
762418	761711	21089R	PARTICIPANT	\N	PRESENT	0
762270	761589	08047A	PARTICIPANT	\N	PRESENT	0
762419	761711	21072G	PARTICIPANT	\N	PRESENT	0
762420	761711	19758L	PARTICIPANT	\N	PRESENT	0
762421	761711	21074J	PARTICIPANT	\N	PRESENT	0
762274	761589	14105F	PARTICIPANT	\N	PRESENT	0
762275	761589	14133K	PARTICIPANT	\N	PRESENT	0
762276	761589	19745F	PARTICIPANT	\N	EXCUSE	0
762283	761589	19443T	PARTICIPANT	\N	PRESENT	0
762284	761589	04042C	PRESIDENT	0	PRESENT	0
762285	761589	14211G	PARTICIPANT	\N	PRESENT	0
762422	761711	19725B	PARTICIPANT	\N	PRESENT	0
762423	761711	14223L	PARTICIPANT	\N	PRESENT	0
762424	761711	11064N	PARTICIPANT	\N	PRESENT	0
762425	761711	21068L	PARTICIPANT	\N	PRESENT	0
762426	761711	20076G	PARTICIPANT	\N	PRESENT	0
762427	761711	21061D	PARTICIPANT	\N	PRESENT	0
762428	761711	21052C	PARTICIPANT	\N	PRESENT	0
762429	761711	21055F	PARTICIPANT	\N	PRESENT	0
762430	761711	21043B	PARTICIPANT	\N	PRESENT	0
762431	761711	01058X	PARTICIPANT	\N	PRESENT	0
762432	761711	04092N	PARTICIPANT	\N	PRESENT	0
762433	761711	19563B	PARTICIPANT	\N	PRESENT	0
762434	761183	20024T	PARTICIPANT	\N	PRESENT	0
762435	761711	11045K	PARTICIPANT	\N	PRESENT	0
762436	761711	18231D	PARTICIPANT	\N	PRESENT	0
762437	761711	11056N	PARTICIPANT	\N	PRESENT	0
762438	761711	21084L	PARTICIPANT	\N	PRESENT	0
762439	761711	14059S	PARTICIPANT	\N	PRESENT	0
762440	761711	08056B	PARTICIPANT	\N	PRESENT	0
762441	761711	21085M	PARTICIPANT	\N	PRESENT	0
762442	761711	21047F	PARTICIPANT	\N	PRESENT	0
762443	761711	14213J	PARTICIPANT	\N	PRESENT	0
762444	761711	14187A	PARTICIPANT	\N	PRESENT	0
762445	761711	20042V	PARTICIPANT	\N	PRESENT	0
762446	761711	21065H	PARTICIPANT	\N	PRESENT	0
762447	761711	98022P	PARTICIPANT	\N	PRESENT	0
762448	761183	08034U	PARTICIPANT	\N	PRESENT	0
762449	761711	14229S	PARTICIPANT	\N	PRESENT	0
762450	761711	20078J	PARTICIPANT	\N	PRESENT	0
762451	761711	21038E	PARTICIPANT	\N	PRESENT	0
762452	761183	19647E	PARTICIPANT	\N	PRESENT	0
762453	761711	19331L	PARTICIPANT	\N	PRESENT	0
762455	761711	19866P	PARTICIPANT	\N	PRESENT	0
762456	761183	14026U	PARTICIPANT	\N	PRESENT	0
762457	761711	01034P	PARTICIPANT	\N	PRESENT	0
762458	761711	19387D	PARTICIPANT	\N	PRESENT	0
762459	761711	20128B	PARTICIPANT	\N	PRESENT	0
762460	761711	14111D	PARTICIPANT	\N	PRESENT	0
762461	761711	14355X	PARTICIPANT	\N	PRESENT	0
762462	761711	14071N	PARTICIPANT	\N	PRESENT	0
762463	761711	20140W	PARTICIPANT	\N	PRESENT	0
762464	761711	20248J	PARTICIPANT	\N	PRESENT	0
762465	762243	19593H	PARTICIPANT	\N	PRESENT	0
762466	762243	20132W	PARTICIPANT	\N	PRESENT	0
762467	762243	19697Q	PARTICIPANT	\N	PRESENT	0
762468	762243	19699S	PARTICIPANT	\N	PRESENT	0
762469	762243	19533U	PARTICIPANT	\N	PRESENT	0
762470	762243	19611R	PRESIDENT	0	PRESENT	0
762471	762243	20138D	PARTICIPANT	\N	PRESENT	0
762472	762243	20142Y	PARTICIPANT	\N	PRESENT	0
762473	762243	20048C	PARTICIPANT	\N	PRESENT	0
750425	749973	99004R	PARTICIPANT	\N	PRESENT	0
750426	749973	14205J	PARTICIPANT	\N	PRESENT	0
750439	749973	19741B	PARTICIPANT	\N	PRESENT	0
750440	749973	19691J	PARTICIPANT	\N	PRESENT	0
750443	749973	01028R	PARTICIPANT	\N	PRESENT	0
750449	749958	19673G	PARTICIPANT	\N	PRESENT	0
750453	749958	19729F	PARTICIPANT	\N	PRESENT	0
750454	749958	14147R	PARTICIPANT	\N	PRESENT	0
750457	749958	20264J	PARTICIPANT	\N	PRESENT	0
750458	749958	19693L	PARTICIPANT	\N	PRESENT	0
750459	749958	20172F	PARTICIPANT	\N	PRESENT	0
750460	749958	14123H	PARTICIPANT	\N	PRESENT	0
750461	749958	20048C	PARTICIPANT	\N	PRESENT	0
750462	749958	19611R	PARTICIPANT	\N	PRESENT	0
750463	749958	19593H	PARTICIPANT	\N	PRESENT	0
750464	749958	19749K	PARTICIPANT	\N	PRESENT	0
750467	749973	04057K	PARTICIPANT	\N	PRESENT	0
750468	749973	97011G	PARTICIPANT	\N	PRESENT	0
750472	749958	20114U	PARTICIPANT	\N	PRESENT	0
750474	749958	20134Y	PARTICIPANT	\N	PRESENT	0
750475	749973	11012A	PARTICIPANT	\N	PRESENT	0
750476	749958	14215L	PRESIDENT	0	PRESENT	0
750479	749958	20022R	PARTICIPANT	\N	PRESENT	0
750480	749973	14219Q	PARTICIPANT	\N	PRESENT	0
750481	749973	19697Q	PARTICIPANT	\N	PRESENT	0
750482	749958	14109K	PARTICIPANT	\N	PRESENT	0
750483	749958	14089Y	PARTICIPANT	\N	PRESENT	0
750485	749958	19621T	PARTICIPANT	\N	PRESENT	0
750486	749973	20120S	PARTICIPANT	\N	PRESENT	0
750488	749958	14179A	PARTICIPANT	\N	PRESENT	0
750490	749958	20980G	PARTICIPANT	\N	PRESENT	0
750495	749958	14069U	PARTICIPANT	\N	PRESENT	0
750492	749973	01025N	PARTICIPANT	\N	PRESENT	0
750498	749973	19577H	PARTICIPANT	\N	PRESENT	0
750496	749973	19649G	PARTICIPANT	\N	PRESENT	0
750497	749973	17023S	PARTICIPANT	\N	PRESENT	0
750500	749973	14097Y	PARTICIPANT	\N	PRESENT	0
750501	749973	14151M	PARTICIPANT	\N	PRESENT	0
750502	749973	14211G	PARTICIPANT	\N	PRESENT	0
750648	750635	14331P	PARTICIPANT	\N	PRESENT	0
750649	750635	14225N	PRESIDENT	0	PRESENT	0
750650	750635	19479G	PARTICIPANT	\N	EXCUSE	0
750651	750635	20050V	PARTICIPANT	\N	EXCUSE	0
750652	750635	11048N	PARTICIPANT	\N	PRESENT	0
750656	750635	20070A	PARTICIPANT	\N	PRESENT	0
750657	750635	01057W	PARTICIPANT	\N	PRESENT	0
750665	750635	19349W	PARTICIPANT	\N	PRESENT	0
751491	749976	19533U	PARTICIPANT	\N	PRESENT	0
751492	749976	20020P	PARTICIPANT	\N	PRESENT	0
751505	749976	20180F	PARTICIPANT	\N	PRESENT	0
751506	749976	07029T	PARTICIPANT	\N	PRESENT	0
751507	749976	14071N	PARTICIPANT	\N	PRESENT	0
751508	749976	14193X	PARTICIPANT	\N	PRESENT	0
751509	749976	05012A	PARTICIPANT	\N	PRESENT	0
751724	749982	08010L	PARTICIPANT	\N	PRESENT	0
751725	749982	20052X	PARTICIPANT	\N	PRESENT	0
751726	749982	04071H	PARTICIPANT	\N	PRESENT	0
751941	751940	19673G	PARTICIPANT	\N	PRESENT	0
751942	751940	19749K	PARTICIPANT	\N	PRESENT	0
752045	752041	19798U	PARTICIPANT	\N	PRESENT	0
752047	752041	20248J	PARTICIPANT	\N	PRESENT	0
752044	752041	10006L	PARTICIPANT	\N	PRESENT	0
752046	752041	14213J	PARTICIPANT	\N	PRESENT	0
752048	752041	18193Q	PARTICIPANT	\N	PRESENT	0
752049	752041	17965H	PARTICIPANT	\N	PRESENT	0
752062	752061	19611R	PARTICIPANT	\N	PRESENT	0
752063	752061	20180F	PARTICIPANT	\N	PRESENT	0
752064	752061	20056C	PARTICIPANT	\N	PRESENT	0
752065	752061	20124W	PARTICIPANT	\N	PRESENT	0
752066	752061	20264J	PARTICIPANT	\N	PRESENT	0
752067	752061	19651A	PARTICIPANT	\N	PRESENT	0
752068	752061	04070G	PARTICIPANT	\N	PRESENT	0
752069	752061	20132W	PARTICIPANT	\N	PRESENT	0
752070	752061	19593H	PARTICIPANT	\N	PRESENT	0
752077	752072	04047H	PRESIDENT	0	PRESENT	0
752122	752121	14189C	PARTICIPANT	\N	EXCUSE	0
752078	752072	14215L	PARTICIPANT	\N	PRESENT	0
752079	752072	20074E	PARTICIPANT	\N	PRESENT	0
752080	752072	19599P	PARTICIPANT	\N	PRESENT	0
752124	752121	20080C	PARTICIPANT	\N	EXCUSE	0
752082	752072	11072N	PARTICIPANT	\N	PRESENT	0
752083	752072	19749K	PARTICIPANT	\N	PRESENT	0
752125	752121	20138D	PARTICIPANT	\N	EXCUSE	0
752126	752121	20106U	PARTICIPANT	\N	EXCUSE	0
752127	752121	20130U	PARTICIPANT	\N	EXCUSE	0
752128	752121	20118Y	PARTICIPANT	\N	EXCUSE	0
752129	752121	20024T	PARTICIPANT	\N	EXCUSE	0
752223	752221	01048V	PARTICIPANT	\N	PRESENT	0
752224	752221	04043D	PARTICIPANT	\N	PRESENT	0
752226	752221	20066E	PARTICIPANT	\N	EXCUSE	0
752227	752221	19723Y	PARTICIPANT	\N	PRESENT	0
752228	752221	19693L	PARTICIPANT	\N	PRESENT	0
752229	752221	19735D	PARTICIPANT	\N	PRESENT	0
752230	752221	20128B	PARTICIPANT	\N	PRESENT	0
752231	752221	19533U	PARTICIPANT	\N	PRESENT	0
752233	752232	04070G	PARTICIPANT	\N	PRESENT	0
752234	752232	20056C	PARTICIPANT	\N	PRESENT	0
752235	752232	19593H	PARTICIPANT	\N	PRESENT	0
752237	752236	04070G	PARTICIPANT	\N	PRESENT	0
752238	752236	20056C	PARTICIPANT	\N	PRESENT	0
752239	752236	19593H	PARTICIPANT	\N	PRESENT	0
752241	752240	04070G	PARTICIPANT	\N	PRESENT	0
752242	752240	20056C	PARTICIPANT	\N	PRESENT	0
752383	752382	14187A	PARTICIPANT	\N	PRESENT	1
752244	752204	19679N	PARTICIPANT	\N	PRESENT	0
752245	752204	20130U	PARTICIPANT	\N	PRESENT	0
752246	752205	19679N	PARTICIPANT	\N	PRESENT	0
752247	752205	20090E	PARTICIPANT	\N	PRESENT	0
752295	752203	14215L	PARTICIPANT	\N	PRESENT	0
752381	752380	14187A	PARTICIPANT	\N	PRESENT	1
752385	752384	14187A	PARTICIPANT	\N	PRESENT	1
752401	752400	14193X	PARTICIPANT	\N	PRESENT	0
752402	752400	14249W	PARTICIPANT	\N	PRESENT	0
752403	752400	17023S	PARTICIPANT	\N	PRESENT	0
752404	752400	04042C	PARTICIPANT	\N	PRESENT	0
752413	752410	86034E	PARTICIPANT	\N	PRESENT	0
752414	752410	20266L	PARTICIPANT	\N	PRESENT	0
752415	752410	18231D	PARTICIPANT	\N	PRESENT	0
752737	752410	14267Y	PARTICIPANT	\N	PRESENT	0
752765	752410	20264J	PARTICIPANT	\N	PRESENT	0
752766	752410	14195A	PARTICIPANT	\N	PRESENT	0
752767	752410	11056N	PARTICIPANT	\N	PRESENT	0
752768	752410	11065P	PARTICIPANT	\N	PRESENT	0
752769	752410	21067K	PARTICIPANT	\N	PRESENT	0
752770	752410	21055F	PARTICIPANT	\N	PRESENT	0
752771	752410	11090Q	PARTICIPANT	\N	PRESENT	0
752772	752410	19647E	PARTICIPANT	\N	PRESENT	0
752773	752410	21059K	PARTICIPANT	\N	PRESENT	0
752774	752410	14229S	PARTICIPANT	\N	PRESENT	0
752775	752410	21068L	PARTICIPANT	\N	PRESENT	0
752776	752410	21077M	PARTICIPANT	\N	PRESENT	0
752777	752410	20098N	PARTICIPANT	\N	PRESENT	0
752778	752410	19760E	PARTICIPANT	\N	PRESENT	0
752779	752410	14189C	PARTICIPANT	\N	PRESENT	0
752780	752410	19631V	PARTICIPANT	\N	PRESENT	0
752781	752410	20112S	PARTICIPANT	\N	PRESENT	0
752782	752410	21035B	PARTICIPANT	\N	PRESENT	0
752783	752410	20024T	PARTICIPANT	\N	PRESENT	0
752784	752410	20022R	PARTICIPANT	\N	PRESENT	0
752785	752410	19954N	PARTICIPANT	\N	PRESENT	0
752786	752410	20110Q	PARTICIPANT	\N	PRESENT	0
752787	752410	14030Q	PARTICIPANT	\N	PRESENT	0
752788	752410	19575F	PARTICIPANT	\N	PRESENT	0
752789	752410	17367Q	PARTICIPANT	\N	PRESENT	0
752790	752410	21048G	PARTICIPANT	\N	PRESENT	0
752791	752410	20086J	PARTICIPANT	\N	PRESENT	0
752792	752410	20114U	PARTICIPANT	\N	PRESENT	0
752793	752410	17737W	PARTICIPANT	\N	PRESENT	0
752794	752410	20080C	PARTICIPANT	\N	PRESENT	0
752795	752410	21088Q	PARTICIPANT	\N	PRESENT	0
752796	752410	19782L	PARTICIPANT	\N	PRESENT	0
752797	752410	19629C	PARTICIPANT	\N	PRESENT	0
752798	752410	21057H	PARTICIPANT	\N	PRESENT	0
752799	752410	14329V	PARTICIPANT	\N	PRESENT	0
752800	752410	19295A	PARTICIPANT	\N	PRESENT	0
752801	752410	11027H	PARTICIPANT	\N	PRESENT	0
752802	752410	21034A	PARTICIPANT	\N	PRESENT	0
752803	752410	19681G	PARTICIPANT	\N	PRESENT	0
752804	752410	20070A	PARTICIPANT	\N	PRESENT	0
756172	755859	20140W	PARTICIPANT	\N	PRESENT	0
756173	755859	20038A	PARTICIPANT	\N	PRESENT	0
756174	755859	19703U	PARTICIPANT	\N	PRESENT	0
756175	755859	14223L	PARTICIPANT	\N	PRESENT	0
756176	755859	14042U	PARTICIPANT	\N	PRESENT	0
756177	755859	14089Y	PARTICIPANT	\N	PRESENT	0
756178	755859	18193Q	PARTICIPANT	\N	PRESENT	0
756179	755859	19507S	PARTICIPANT	\N	PRESENT	0
756180	755859	19701S	PARTICIPANT	\N	PRESENT	0
756181	755859	21080G	PARTICIPANT	\N	PRESENT	0
756182	755859	04045F	PARTICIPANT	\N	PRESENT	0
756183	755859	19629C	PARTICIPANT	\N	PRESENT	0
756184	755859	21047F	PARTICIPANT	\N	PRESENT	0
756168	755859	20032T	PARTICIPANT	\N	PRESENT	0
756170	755859	19367Y	PARTICIPANT	\N	PRESENT	0
756185	755859	21045D	PARTICIPANT	\N	PRESENT	0
756186	755859	21060C	PARTICIPANT	\N	PRESENT	0
756187	755859	14281W	PARTICIPANT	\N	PRESENT	0
756188	755859	21082J	PARTICIPANT	\N	PRESENT	0
756191	755859	21035B	PARTICIPANT	\N	PRESENT	0
756192	755859	14147R	PARTICIPANT	\N	PRESENT	0
756196	755859	14026U	PARTICIPANT	\N	PRESENT	0
756198	755859	08045X	PARTICIPANT	\N	PRESENT	0
756208	755859	20062A	PARTICIPANT	\N	PRESENT	0
756209	755859	14038Y	PARTICIPANT	\N	PRESENT	0
756215	755859	19683J	PARTICIPANT	\N	PRESENT	0
756226	755859	14259Y	PARTICIPANT	\N	PRESENT	0
756227	755859	20136B	PARTICIPANT	\N	PRESENT	0
756238	755859	08061X	PARTICIPANT	\N	PRESENT	0
756242	755859	20044X	PARTICIPANT	\N	PRESENT	0
756244	755859	20098N	PARTICIPANT	\N	PRESENT	0
756246	756189	19593H	PARTICIPANT	\N	PRESENT	0
756247	756189	20132W	PARTICIPANT	\N	PRESENT	0
756248	756189	04070G	PARTICIPANT	\N	PRESENT	0
756249	756189	21055F	PARTICIPANT	\N	PRESENT	0
756250	756189	14073Q	PARTICIPANT	\N	PRESENT	0
756251	756189	19533U	PARTICIPANT	\N	PRESENT	0
756252	756189	19611R	PRESIDENT	0	PRESENT	0
756253	756189	20138D	PARTICIPANT	\N	PRESENT	0
756254	756189	20142Y	PARTICIPANT	\N	PRESENT	0
756255	756189	21059K	PARTICIPANT	\N	PRESENT	0
756256	756189	20052X	PARTICIPANT	\N	PRESENT	0
756257	756189	20056C	PARTICIPANT	\N	PRESENT	0
756258	756189	20180F	PARTICIPANT	\N	PRESENT	0
756259	756189	14109K	PARTICIPANT	\N	PRESENT	0
756260	756189	21089R	PARTICIPANT	\N	PRESENT	0
756261	756189	21037D	PARTICIPANT	\N	PRESENT	0
756262	756189	21091K	PARTICIPANT	\N	PRESENT	0
756263	756189	21074J	PARTICIPANT	\N	PRESENT	0
756264	756189	20026V	PARTICIPANT	\N	PRESENT	0
756265	756189	19621T	PARTICIPANT	\N	PRESENT	0
756267	755859	21067K	PARTICIPANT	\N	PRESENT	0
756271	756189	20264J	PARTICIPANT	\N	PRESENT	0
756272	755859	19563B	PARTICIPANT	\N	PRESENT	0
756273	755859	19383Y	PARTICIPANT	\N	PRESENT	0
756275	755859	19745F	PARTICIPANT	\N	PRESENT	0
756277	755859	19545Y	PARTICIPANT	\N	PRESENT	0
756281	755859	20076G	PARTICIPANT	\N	PRESENT	0
756282	755859	19387D	PARTICIPANT	\N	PRESENT	0
756283	755859	19695N	PARTICIPANT	\N	PRESENT	0
756285	755859	20030R	PARTICIPANT	\N	PRESENT	0
756287	755859	14033T	PARTICIPANT	\N	PRESENT	0
756290	755859	11040E	PARTICIPANT	\N	PRESENT	0
756291	755859	19575F	PARTICIPANT	\N	PRESENT	0
756292	755859	20042V	PARTICIPANT	\N	PRESENT	0
756300	755859	19479G	PARTICIPANT	\N	PRESENT	0
756302	756189	20102Q	PARTICIPANT	\N	PRESENT	0
756303	756189	14123H	PARTICIPANT	\N	PRESENT	0
756304	755859	14211G	PARTICIPANT	\N	PRESENT	0
756370	755859	21083K	PARTICIPANT	\N	PRESENT	0
756306	755859	20054A	PARTICIPANT	\N	PRESENT	0
756308	755943	14225N	PRESIDENT	0	PRESENT	0
756309	755943	14121F	PARTICIPANT	\N	PRESENT	0
756311	755943	19711U	PARTICIPANT	\N	PRESENT	0
756312	755943	21090J	PARTICIPANT	\N	PRESENT	0
756313	755859	14275Y	PARTICIPANT	\N	PRESENT	0
756315	755943	11040E	PARTICIPANT	\N	PRESENT	0
756316	755859	98022P	PARTICIPANT	\N	PRESENT	0
756317	755859	21095P	PARTICIPANT	\N	PRESENT	0
756374	755859	08069G	PARTICIPANT	\N	PRESENT	0
756319	755859	19826F	PARTICIPANT	\N	PRESENT	0
756320	755859	19723Y	PARTICIPANT	\N	PRESENT	0
756321	755859	17023S	PARTICIPANT	\N	PRESENT	0
756322	755859	99004R	PARTICIPANT	\N	PRESENT	0
756323	755859	21071F	PARTICIPANT	\N	PRESENT	0
756324	755859	14021P	PARTICIPANT	\N	PRESENT	0
756325	755859	21031W	PARTICIPANT	\N	PRESENT	0
756328	755859	20028X	PARTICIPANT	\N	PRESENT	0
756329	755859	08060W	PARTICIPANT	\N	PRESENT	0
756330	755943	20086J	PARTICIPANT	\N	PRESENT	0
756331	755943	14327T	PARTICIPANT	\N	PRESENT	0
756332	755943	14331P	PARTICIPANT	\N	PRESENT	0
756333	755943	19545Y	PARTICIPANT	\N	PRESENT	0
756334	755943	11053K	PARTICIPANT	\N	PRESENT	0
756335	755943	20080C	PARTICIPANT	\N	PRESENT	0
756336	755943	11110B	PARTICIPANT	\N	PRESENT	0
756337	755943	07029T	PARTICIPANT	\N	PRESENT	0
756338	755943	19573D	PARTICIPANT	\N	PRESENT	0
756339	755943	07004J	PARTICIPANT	\N	PRESENT	0
756340	755943	19349W	PARTICIPANT	\N	PRESENT	0
756341	755943	20116W	PARTICIPANT	\N	PRESENT	0
756342	755943	08012N	PARTICIPANT	\N	PRESENT	0
756343	755943	20126Y	PARTICIPANT	\N	PRESENT	0
756344	755943	20024T	PARTICIPANT	\N	PRESENT	0
756345	755943	21048G	PARTICIPANT	\N	PRESENT	0
756346	755943	11048N	PARTICIPANT	\N	PRESENT	0
756347	755943	19479G	PARTICIPANT	\N	PRESENT	0
756348	755943	19647E	PARTICIPANT	\N	PRESENT	0
756349	755943	08034U	PARTICIPANT	\N	PRESENT	0
756350	755943	20044X	PARTICIPANT	\N	PRESENT	0
756351	755943	19399H	PARTICIPANT	\N	PRESENT	0
756352	755943	21041Y	PARTICIPANT	\N	PRESENT	0
756353	755943	08073C	PARTICIPANT	\N	PRESENT	0
756354	755943	20070A	PARTICIPANT	\N	PRESENT	0
756355	755943	21072G	PARTICIPANT	\N	PRESENT	0
756356	755859	19782L	PARTICIPANT	\N	PRESENT	0
756357	755859	19631V	PARTICIPANT	\N	PRESENT	0
756358	755859	20108W	PARTICIPANT	\N	PRESENT	0
756359	755859	19413M	PARTICIPANT	\N	PRESENT	0
756361	756189	21063F	PARTICIPANT	\N	PRESENT	0
756362	755859	11064N	PARTICIPANT	\N	PRESENT	0
756363	755859	20048C	PARTICIPANT	\N	PRESENT	0
756364	755859	20286Q	PARTICIPANT	\N	PRESENT	0
756365	755859	11045K	PARTICIPANT	\N	PRESENT	0
756366	755859	14213J	PARTICIPANT	\N	PRESENT	0
756367	755859	05012A	PARTICIPANT	\N	PRESENT	0
756368	755859	20248J	PARTICIPANT	\N	PRESENT	0
756369	755859	11072N	PARTICIPANT	\N	PRESENT	0
756372	755859	21065H	PARTICIPANT	\N	PRESENT	0
756373	755859	11090Q	PARTICIPANT	\N	PRESENT	0
756375	755859	21034A	PARTICIPANT	\N	PRESENT	0
756376	755859	21094N	PARTICIPANT	\N	PRESENT	0
756378	755859	19335Q	PARTICIPANT	\N	PRESENT	0
756379	755859	21092L	PARTICIPANT	\N	PRESENT	0
756380	755859	19421M	PARTICIPANT	\N	PRESENT	0
756381	755859	05008E	PARTICIPANT	\N	PRESENT	0
756382	755859	20026V	PARTICIPANT	\N	PRESENT	0
756383	755859	04033B	PARTICIPANT	\N	PRESENT	0
756384	755859	19621T	PARTICIPANT	\N	PRESENT	0
756385	755859	20018V	PARTICIPANT	\N	PRESENT	0
756386	755859	20092G	PARTICIPANT	\N	PRESENT	0
756387	755859	20082E	PARTICIPANT	\N	PRESENT	0
756388	755859	14257W	PARTICIPANT	\N	PRESENT	0
756389	755859	01058X	PARTICIPANT	\N	PRESENT	0
756390	755943	20094J	PARTICIPANT	\N	PRESENT	0
756391	755943	19667J	PARTICIPANT	\N	PRESENT	0
756392	755943	20134Y	PARTICIPANT	\N	PRESENT	0
756393	755859	21059K	PARTICIPANT	\N	PRESENT	0
756394	755859	21079P	PARTICIPANT	\N	PRESENT	0
756395	755859	11053K	PARTICIPANT	\N	PRESENT	0
756396	755859	14109K	PARTICIPANT	\N	PRESENT	0
756397	755859	19533U	PARTICIPANT	\N	PRESENT	0
756398	755859	21089R	PARTICIPANT	\N	PRESENT	0
756399	755859	20264J	PARTICIPANT	\N	PRESENT	0
756400	755859	19685L	PARTICIPANT	\N	PRESENT	0
756401	755859	21063F	PARTICIPANT	\N	PRESENT	0
756402	755859	20148F	PARTICIPANT	\N	PRESENT	0
756403	756189	19954N	PARTICIPANT	\N	PRESENT	0
756404	756189	18395Y	PARTICIPANT	\N	PRESENT	0
756405	756189	20048C	PARTICIPANT	\N	PRESENT	0
740736	740735	17737W	PARTICIPANT	\N	PRESENT	0
740737	740735	04042C	PARTICIPANT	\N	PRESENT	0
740738	740735	11026G	PARTICIPANT	\N	PRESENT	0
740739	740735	19745F	PARTICIPANT	\N	PRESENT	0
740740	740735	19643A	PARTICIPANT	\N	PRESENT	0
740751	738013	14179A	PARTICIPANT	\N	PRESENT	0
740763	738147	20064C	PRESIDENT	0	PRESENT	0
740764	738147	14251Q	PARTICIPANT	\N	PRESENT	0
740765	738147	11083R	PARTICIPANT	\N	PRESENT	0
740771	740770	05008E	PARTICIPANT	\N	PRESENT	0
740772	740770	11053K	PARTICIPANT	\N	PRESENT	0
740773	740770	01028R	PARTICIPANT	\N	PRESENT	0
744008	743993	08018U	PARTICIPANT	\N	PRESENT	0
746154	746147	01048V	PARTICIPANT	\N	EXCUSE	0
746155	746147	19533U	PARTICIPANT	\N	PRESENT	0
746170	746147	20072C	PARTICIPANT	\N	EXCUSE	0
746171	746147	20128B	PARTICIPANT	\N	EXCUSE	0
746172	746147	11067R	PARTICIPANT	\N	EXCUSE	0
746173	746147	20066E	PARTICIPANT	\N	EXCUSE	0
748480	746773	11031D	PARTICIPANT	\N	PRESENT	0
748481	746773	14213J	PARTICIPANT	\N	PRESENT	0
748482	746773	20024T	PARTICIPANT	\N	PRESENT	0
748483	746773	04045F	PARTICIPANT	\N	PRESENT	0
748484	746773	19735D	PRESIDENT	0	PRESENT	0
748486	746773	19725B	PARTICIPANT	\N	PRESENT	0
748489	746773	20266L	PARTICIPANT	\N	PRESENT	0
748493	746773	14026U	PARTICIPANT	\N	PRESENT	0
748495	746773	20126Y	PARTICIPANT	\N	PRESENT	0
748497	746773	17965H	PARTICIPANT	\N	PRESENT	0
748498	746773	08069G	PARTICIPANT	\N	PRESENT	0
748502	746959	14229S	PARTICIPANT	\N	EXCUSE	0
749867	749769	19758L	PARTICIPANT	\N	PRESENT	0
750720	750663	20098N	PARTICIPANT	\N	PRESENT	0
750721	750663	20132W	PARTICIPANT	\N	PRESENT	0
750722	750663	20180F	PARTICIPANT	\N	PRESENT	0
750774	750773	11026G	PARTICIPANT	\N	PRESENT	0
750775	750773	14053L	PARTICIPANT	\N	PRESENT	0
750776	750773	14089Y	PARTICIPANT	\N	PRESENT	0
750792	749988	19631V	PARTICIPANT	\N	PRESENT	0
750793	749988	19575F	PARTICIPANT	\N	PRESENT	0
750794	749988	20078J	PARTICIPANT	\N	PRESENT	0
750795	749988	19383Y	PARTICIPANT	\N	PRESENT	0
750796	749988	19782L	PARTICIPANT	\N	PRESENT	0
750797	749988	14207L	PARTICIPANT	\N	PRESENT	0
750798	749988	20104S	PARTICIPANT	\N	PRESENT	0
750799	749988	14329V	PARTICIPANT	\N	PRESENT	0
750800	749988	14038Y	PARTICIPANT	\N	PRESENT	0
750801	749988	08028W	PARTICIPANT	\N	PRESENT	0
750802	749988	20144B	PARTICIPANT	\N	PRESENT	0
750803	749988	19467C	PARTICIPANT	\N	PRESENT	0
750804	749988	14187A	PARTICIPANT	\N	PRESENT	0
750805	749988	01025N	PARTICIPANT	\N	EXCUSE	0
750806	749988	20286Q	PARTICIPANT	\N	PRESENT	0
750807	749988	20034V	PARTICIPANT	\N	PRESENT	0
750808	749988	08015R	PARTICIPANT	\N	PRESENT	0
750809	749988	14037X	PARTICIPANT	\N	PRESENT	0
750810	749988	11077T	PARTICIPANT	\N	PRESENT	0
750811	749988	14205J	PARTICIPANT	\N	PRESENT	0
750812	749988	20028X	PARTICIPANT	\N	PRESENT	0
750813	749988	20018V	PARTICIPANT	\N	PRESENT	0
750814	749988	14257W	PARTICIPANT	\N	PRESENT	0
750815	749988	19768N	PARTICIPANT	\N	PRESENT	0
750816	749988	11090Q	PRESIDENT	0	PRESENT	0
750817	749988	20298U	PARTICIPANT	\N	PRESENT	0
750818	749988	20082E	PARTICIPANT	\N	PRESENT	0
750819	749988	20054A	PARTICIPANT	\N	PRESENT	0
750820	749988	20092G	PARTICIPANT	\N	PRESENT	0
750821	749988	20062A	PARTICIPANT	\N	PRESENT	0
750852	750849	14033T	PARTICIPANT	\N	PRESENT	0
750853	750849	14205J	PARTICIPANT	\N	PRESENT	0
750855	750854	14033T	PARTICIPANT	\N	PRESENT	0
750856	750854	14205J	PARTICIPANT	\N	PRESENT	0
750858	750857	14033T	PARTICIPANT	\N	PRESENT	0
750859	750857	14205J	PARTICIPANT	\N	PRESENT	0
750861	750860	14033T	PARTICIPANT	\N	PRESENT	0
750862	750860	14205J	PARTICIPANT	\N	PRESENT	0
750872	750871	14033T	PARTICIPANT	\N	PRESENT	0
750873	750871	14205J	PARTICIPANT	\N	PRESENT	0
750876	750875	14033T	PARTICIPANT	\N	PRESENT	0
750877	750875	14205J	PARTICIPANT	\N	PRESENT	0
750880	750878	14033T	PARTICIPANT	\N	PRESENT	0
750881	750878	14205J	PARTICIPANT	\N	PRESENT	0
750883	750882	14033T	PARTICIPANT	\N	PRESENT	0
750884	750882	14205J	PARTICIPANT	\N	PRESENT	0
750886	750885	14033T	PARTICIPANT	\N	PRESENT	0
750887	750885	14205J	PARTICIPANT	\N	PRESENT	0
750889	750888	14033T	PARTICIPANT	\N	PRESENT	0
750929	749985	11101A	PARTICIPANT	\N	PRESENT	0
750930	749985	19701S	PARTICIPANT	\N	PRESENT	0
750931	749985	20286Q	PARTICIPANT	\N	PRESENT	0
750932	749985	14097Y	PARTICIPANT	\N	PRESENT	0
750933	749985	14073Q	PARTICIPANT	\N	PRESENT	0
750934	749985	14331P	PRESIDENT	0	PRESENT	0
750935	749985	14001X	PARTICIPANT	\N	PRESENT	0
750936	749985	11026G	PARTICIPANT	\N	PRESENT	0
750937	749985	10015M	PARTICIPANT	\N	PRESENT	0
750938	749985	08034U	PARTICIPANT	\N	PRESENT	0
750939	749985	17737W	PARTICIPANT	\N	PRESENT	0
750946	749986	11026G	PARTICIPANT	\N	PRESENT	0
750947	749986	10015M	PARTICIPANT	\N	PRESENT	0
750948	749986	20286Q	PARTICIPANT	\N	PRESENT	0
750949	749986	14073Q	PARTICIPANT	\N	PRESENT	0
750950	749986	19701S	PARTICIPANT	\N	PRESENT	0
750951	749986	14001X	PARTICIPANT	\N	PRESENT	0
750952	749986	14331P	PRESIDENT	0	PRESENT	0
750953	749986	17737W	PARTICIPANT	\N	PRESENT	0
750954	749986	08034U	PARTICIPANT	\N	PRESENT	0
750955	749986	14089Y	PARTICIPANT	\N	PRESENT	0
750966	749986	14033T	PARTICIPANT	\N	PRESENT	0
752286	752285	14053L	PARTICIPANT	\N	PRESENT	0
752290	752287	14089Y	PARTICIPANT	\N	PRESENT	0
752304	752204	20090E	PARTICIPANT	\N	PRESENT	0
752305	752206	19679N	PARTICIPANT	\N	PRESENT	0
752306	752207	19679N	PARTICIPANT	\N	PRESENT	0
752307	752208	19679N	PARTICIPANT	\N	PRESENT	0
752308	752210	19679N	PARTICIPANT	\N	PRESENT	0
752309	752210	20090E	PARTICIPANT	\N	PRESENT	0
752310	752210	20130U	PARTICIPANT	\N	PRESENT	0
752601	752374	99004R	PARTICIPANT	\N	PRESENT	0
752602	752374	14073Q	PARTICIPANT	\N	PRESENT	0
752603	752374	19489J	PARTICIPANT	\N	PRESENT	0
752604	752374	21081H	PARTICIPANT	\N	PRESENT	0
752605	752374	20126Y	PARTICIPANT	\N	PRESENT	0
752606	752374	20016T	PARTICIPANT	\N	PRESENT	0
752607	752374	19611R	PARTICIPANT	\N	PRESENT	0
752608	752374	19649G	PARTICIPANT	\N	PRESENT	0
752609	752374	20102Q	PARTICIPANT	\N	PRESENT	0
752610	752374	07029T	PARTICIPANT	\N	PRESENT	0
752611	752374	21078N	PARTICIPANT	\N	PRESENT	0
752612	752374	19735D	PARTICIPANT	\N	PRESENT	0
752613	752374	86034E	PARTICIPANT	\N	PRESENT	0
752614	752374	19723Y	PARTICIPANT	\N	PRESENT	0
752615	752374	19699S	PARTICIPANT	\N	PRESENT	0
752616	752374	08015R	PARTICIPANT	\N	PRESENT	0
752617	752374	19711U	PARTICIPANT	\N	PRESENT	0
752618	752374	19709B	PARTICIPANT	\N	PRESENT	0
752619	752374	18193Q	PARTICIPANT	\N	PRESENT	0
752621	752374	08010L	PARTICIPANT	\N	PRESENT	0
752622	752374	08034U	PARTICIPANT	\N	PRESENT	0
752623	752374	14037X	PARTICIPANT	\N	PRESENT	0
752624	752374	21087P	PARTICIPANT	\N	PRESENT	0
752625	752374	19729F	PARTICIPANT	\N	PRESENT	0
752626	752374	20052X	PARTICIPANT	\N	PRESENT	0
752627	752374	19697Q	PARTICIPANT	\N	PRESENT	0
752628	752374	18207D	PARTICIPANT	\N	PRESENT	0
752630	752374	14219Q	PARTICIPANT	\N	PRESENT	0
752631	752374	14059S	PARTICIPANT	\N	PRESENT	0
752632	752374	21054E	PARTICIPANT	\N	PRESENT	0
752633	752374	08012N	PARTICIPANT	\N	PRESENT	0
752634	752374	17779H	PARTICIPANT	\N	PRESENT	0
752635	752374	12016W	PARTICIPANT	\N	PRESENT	0
752636	752374	19657G	PARTICIPANT	\N	PRESENT	0
752637	752374	14251Q	PARTICIPANT	\N	PRESENT	0
762474	762243	21059K	PARTICIPANT	\N	PRESENT	0
762475	762243	19693L	PARTICIPANT	\N	PRESENT	0
762476	762243	20052X	PARTICIPANT	\N	PRESENT	0
762477	762243	20172F	PARTICIPANT	\N	PRESENT	0
762478	762243	20056C	PARTICIPANT	\N	PRESENT	0
762479	762243	19954N	PARTICIPANT	\N	PRESENT	0
762480	762243	20180F	PARTICIPANT	\N	PRESENT	0
762481	762243	20264J	PARTICIPANT	\N	PRESENT	0
762482	762243	21063F	PARTICIPANT	\N	PRESENT	0
762483	762243	19735D	PARTICIPANT	\N	PRESENT	0
762484	762243	14109K	PARTICIPANT	\N	PRESENT	0
762485	762243	14123H	PARTICIPANT	\N	PRESENT	0
762486	762243	21077M	PARTICIPANT	\N	PRESENT	0
762487	762243	20026V	PARTICIPANT	\N	PRESENT	0
762488	761711	14069U	PARTICIPANT	\N	PRESENT	0
762489	761711	14207L	PARTICIPANT	\N	PRESENT	0
762490	761711	21082J	PARTICIPANT	\N	PRESENT	0
762491	761711	14031R	PARTICIPANT	\N	PRESENT	0
762492	761711	14357A	PARTICIPANT	\N	PRESENT	0
762493	761711	19687N	PARTICIPANT	\N	PRESENT	0
762494	761183	19563B	PARTICIPANT	\N	PRESENT	0
762495	761711	19631V	PARTICIPANT	\N	PRESENT	0
762499	761711	14151M	PARTICIPANT	\N	PRESENT	0
762501	761183	19507S	PARTICIPANT	\N	PRESENT	0
762502	761711	08060W	PARTICIPANT	\N	PRESENT	0
762503	761711	20034V	PARTICIPANT	\N	PRESENT	0
762504	761711	20066E	PARTICIPANT	\N	PRESENT	0
762508	761711	08009T	PARTICIPANT	\N	PRESENT	0
762510	761711	21086N	PARTICIPANT	\N	PRESENT	0
762513	761711	18207D	PARTICIPANT	\N	PRESENT	0
762514	761711	20114U	PARTICIPANT	\N	PRESENT	0
762518	761711	20106U	PARTICIPANT	\N	PRESENT	0
762519	761711	17737W	PARTICIPANT	\N	PRESENT	0
762520	761711	21045D	PARTICIPANT	\N	PRESENT	0
762524	761711	14205J	PARTICIPANT	\N	PRESENT	0
762525	761711	17367Q	PARTICIPANT	\N	PRESENT	0
762527	761711	19251M	PARTICIPANT	\N	PRESENT	0
762531	761711	21057H	PARTICIPANT	\N	PRESENT	0
762532	761711	14257W	PARTICIPANT	\N	PRESENT	0
762533	761711	20112S	PARTICIPANT	\N	PRESENT	0
762534	761711	21046E	PARTICIPANT	\N	PRESENT	0
762536	761711	20052X	PARTICIPANT	\N	PRESENT	0
762538	761711	20104S	PARTICIPANT	\N	PRESENT	0
762540	761711	20064C	PARTICIPANT	\N	PRESENT	0
762542	761711	21087P	PARTICIPANT	\N	PRESENT	0
762543	761711	14217N	PARTICIPANT	\N	PRESENT	0
762551	761711	20074E	PARTICIPANT	\N	PRESENT	0
762555	761711	20082E	PARTICIPANT	\N	PRESENT	0
762556	761711	19683J	PARTICIPANT	\N	PRESENT	0
762557	761711	14073Q	PARTICIPANT	\N	PRESENT	0
762558	761711	14042U	PARTICIPANT	\N	PRESENT	0
762559	761711	21064G	PARTICIPANT	\N	PRESENT	0
762560	761711	05008E	PARTICIPANT	\N	PRESENT	0
762561	761711	19723Y	PARTICIPANT	\N	PRESENT	0
762563	761711	21063F	PARTICIPANT	\N	PRESENT	0
762565	761711	19591F	PARTICIPANT	\N	PRESENT	0
762571	761711	20138D	PARTICIPANT	\N	PRESENT	0
762569	761711	11070L	PARTICIPANT	\N	PRESENT	0
762570	761711	08069G	PARTICIPANT	\N	PRESENT	0
762572	761711	19713W	PARTICIPANT	\N	PRESENT	0
762573	761711	21097R	PARTICIPANT	\N	PRESENT	0
762574	761711	19573D	PARTICIPANT	\N	PRESENT	0
762575	761711	14038Y	PARTICIPANT	\N	PRESENT	0
762578	761711	14179A	PARTICIPANT	\N	PRESENT	0
762579	761711	12016W	PARTICIPANT	\N	PRESENT	0
762582	761711	20124W	PARTICIPANT	\N	PRESENT	0
762585	761711	14123H	PARTICIPANT	\N	PRESENT	0
762586	761711	20264J	PARTICIPANT	\N	PRESENT	0
762587	761711	21056G	PARTICIPANT	\N	PRESENT	0
762588	761711	21037D	PARTICIPANT	\N	PRESENT	0
762590	761711	20044X	PARTICIPANT	\N	PRESENT	0
762591	761711	08034U	PARTICIPANT	\N	PRESENT	0
762592	761711	19711U	PARTICIPANT	\N	PRESENT	0
762593	761711	20116W	PARTICIPANT	\N	PRESENT	0
762594	761711	21077M	PARTICIPANT	\N	PRESENT	0
762595	761711	19479G	PARTICIPANT	\N	PRESENT	0
762596	761711	14331P	PARTICIPANT	\N	PRESENT	0
762597	761711	21059K	PARTICIPANT	\N	PRESENT	0
762598	761711	20126Y	PARTICIPANT	\N	PRESENT	0
762599	761711	11074Q	PARTICIPANT	\N	PRESENT	0
762600	761711	17965H	PARTICIPANT	\N	PRESENT	0
762601	761711	17779H	PARTICIPANT	\N	PRESENT	0
762602	761711	11085T	PARTICIPANT	\N	PRESENT	0
762603	761711	19489J	PARTICIPANT	\N	PRESENT	0
762604	761711	21049H	PARTICIPANT	\N	PRESENT	0
762606	762605	08011M	PARTICIPANT	\N	PRESENT	0
762607	761711	19301E	PARTICIPANT	\N	PRESENT	0
762608	761711	20080C	PARTICIPANT	\N	PRESENT	0
762610	762609	08011M	PARTICIPANT	\N	PRESENT	0
762611	761711	21079P	PARTICIPANT	\N	PRESENT	0
762612	761711	21048G	PARTICIPANT	\N	PRESENT	0
762614	761590	19565D	PARTICIPANT	\N	PRESENT	0
762615	761590	20072C	PARTICIPANT	\N	PRESENT	0
762616	761590	21031W	PARTICIPANT	\N	PRESENT	0
762617	761590	01058X	PARTICIPANT	\N	PRESENT	0
762618	761590	11027H	PARTICIPANT	\N	PRESENT	0
762619	761590	08056B	PARTICIPANT	\N	PRESENT	0
762620	761590	19421M	PARTICIPANT	\N	PRESENT	0
762621	761590	21067K	PARTICIPANT	\N	PRESENT	0
762622	761590	19709B	PARTICIPANT	\N	PRESENT	0
762623	761590	14193X	PRESIDENT	0	PRESENT	0
762624	761590	07033P	PARTICIPANT	\N	PRESENT	0
762625	761590	17367Q	PARTICIPANT	\N	PRESENT	0
762626	761590	14249W	PARTICIPANT	\N	PRESENT	0
762627	761590	20128B	PARTICIPANT	\N	PRESENT	0
762628	761590	08047A	PARTICIPANT	\N	PRESENT	0
762629	761590	14097Y	PARTICIPANT	\N	PRESENT	0
762630	761590	14059S	PARTICIPANT	\N	PRESENT	0
762631	761590	19531S	PARTICIPANT	\N	PRESENT	0
762632	761590	21073H	PARTICIPANT	\N	PRESENT	0
762633	761590	08069G	PARTICIPANT	\N	PRESENT	0
762634	761590	20042V	PARTICIPANT	\N	PRESENT	0
762635	761590	98022P	PARTICIPANT	\N	PRESENT	0
762636	761590	11064N	PARTICIPANT	\N	PRESENT	0
762637	761590	14255U	PARTICIPANT	\N	PRESENT	0
762638	761590	17023S	PARTICIPANT	\N	PRESENT	0
762639	761590	19745F	PARTICIPANT	\N	EXCUSE	0
762640	761590	14211G	PARTICIPANT	\N	EXCUSE	0
762641	761590	12028B	PARTICIPANT	\N	EXCUSE	0
762642	761590	14267Y	PARTICIPANT	\N	EXCUSE	0
762647	761711	20070A	PARTICIPANT	\N	PRESENT	0
762648	761711	14231L	PARTICIPANT	\N	PRESENT	0
762649	761711	19553Y	PARTICIPANT	\N	PRESENT	0
762650	761711	14109K	PARTICIPANT	\N	PRESENT	0
762651	761711	19709B	PARTICIPANT	\N	PRESENT	0
762652	761711	11048N	PARTICIPANT	\N	PRESENT	0
762653	761711	21080G	PARTICIPANT	\N	PRESENT	0
762654	761711	19693L	PARTICIPANT	\N	PRESENT	0
762656	762655	08011M	PARTICIPANT	\N	PRESENT	0
762657	761711	19735D	PARTICIPANT	\N	PRESENT	0
762660	762659	08011M	PARTICIPANT	\N	PRESENT	0
762661	761711	19569H	PARTICIPANT	\N	PRESENT	0
762662	761711	14219Q	PARTICIPANT	\N	PRESENT	0
762663	761711	14189C	PARTICIPANT	\N	PRESENT	0
762666	757755	08012N	PARTICIPANT	\N	PRESENT	0
762667	757755	11043H	PARTICIPANT	\N	PRESENT	0
762669	762668	20058E	PARTICIPANT	\N	PRESENT	0
762670	762668	19611R	PARTICIPANT	\N	PRESENT	0
762672	762671	07004J	PARTICIPANT	\N	PRESENT	0
762673	762671	19647E	PARTICIPANT	\N	PRESENT	0
762674	761711	14253S	PARTICIPANT	\N	PRESENT	0
762676	762675	07004J	PARTICIPANT	\N	PRESENT	0
762677	762675	19647E	PARTICIPANT	\N	PRESENT	0
762679	762678	07004J	PARTICIPANT	\N	PRESENT	0
762680	762678	19647E	PARTICIPANT	\N	PRESENT	0
762685	761711	19531S	PARTICIPANT	\N	PRESENT	0
762687	762686	07004J	PARTICIPANT	\N	PRESENT	0
762688	762686	19647E	PARTICIPANT	\N	PRESENT	0
762689	761711	19820Y	PARTICIPANT	\N	PRESENT	0
762726	761711	14026U	PARTICIPANT	\N	PRESENT	0
762727	761711	19685L	PARTICIPANT	\N	PRESENT	0
762728	761711	19691J	PARTICIPANT	\N	PRESENT	0
762729	761711	14083S	PARTICIPANT	\N	PRESENT	0
762730	761711	14249W	PARTICIPANT	\N	PRESENT	0
762731	761711	21092L	PARTICIPANT	\N	PRESENT	0
762735	761711	20022R	PARTICIPANT	\N	PRESENT	0
762733	761711	14215L	PARTICIPANT	\N	PRESENT	0
762734	761711	19760E	PARTICIPANT	\N	PRESENT	0
762736	761711	14195A	PARTICIPANT	\N	PRESENT	0
762737	761711	20084G	PARTICIPANT	\N	PRESENT	0
740808	722794	19693L	PARTICIPANT	\N	PRESENT	0
744505	743485	11097X	PRESIDENT	0	PRESENT	0
744506	743485	14042U	PARTICIPANT	\N	PRESENT	0
744507	743485	04092N	PARTICIPANT	\N	PRESENT	0
744508	743485	20130U	PARTICIPANT	\N	PRESENT	0
744509	743485	19760E	PARTICIPANT	\N	PRESENT	0
745905	745904	10015M	PARTICIPANT	\N	PRESENT	0
748471	748096	10006L	PRESIDENT	0	PRESENT	0
748472	748096	14223L	PARTICIPANT	\N	PRESENT	0
748473	748096	04057K	PARTICIPANT	\N	PRESENT	0
748474	748096	19798U	PARTICIPANT	\N	PRESENT	0
748475	748096	19511N	PARTICIPANT	\N	PRESENT	0
748476	748096	11097X	PARTICIPANT	\N	PRESENT	0
748478	748096	04092N	PARTICIPANT	\N	EXCUSE	0
748479	748096	20066E	PARTICIPANT	\N	EXCUSE	0
748485	748096	18193Q	PARTICIPANT	\N	PRESENT	0
748487	748096	19679N	PARTICIPANT	\N	PRESENT	0
748488	748096	19723Y	PARTICIPANT	\N	PRESENT	0
748509	746773	19369B	PARTICIPANT	\N	PRESENT	0
748550	746773	20114U	PARTICIPANT	\N	PRESENT	0
748551	746773	20096L	PARTICIPANT	\N	PRESENT	0
751770	751584	14215L	PARTICIPANT	\N	PRESENT	0
751771	751584	19749K	PARTICIPANT	\N	PRESENT	0
751772	751584	04047H	PRESIDENT	0	PRESENT	0
751773	751584	11033F	PARTICIPANT	\N	PRESENT	0
751774	751584	19649G	PARTICIPANT	\N	PRESENT	0
751775	751584	14147R	PARTICIPANT	\N	PRESENT	0
751776	751584	11085T	PARTICIPANT	\N	PRESENT	0
751777	751584	04085P	PARTICIPANT	\N	PRESENT	0
751778	751584	11026G	PARTICIPANT	\N	PRESENT	0
751779	751769	07029T	PARTICIPANT	\N	PRESENT	0
751780	751769	20252E	PARTICIPANT	\N	PRESENT	0
751781	751769	19687N	PARTICIPANT	\N	PRESENT	0
751782	751769	11053K	PARTICIPANT	\N	PRESENT	0
751783	751769	08010L	PARTICIPANT	\N	PRESENT	0
751784	751769	99004R	PARTICIPANT	\N	PRESENT	0
751785	751769	19667J	PARTICIPANT	\N	PRESENT	0
751786	751769	14225N	PRESIDENT	0	PRESENT	0
751787	751584	14021P	PARTICIPANT	\N	PRESENT	0
751788	751769	19647E	PARTICIPANT	\N	PRESENT	0
751789	751769	11070L	PARTICIPANT	\N	PRESENT	0
751790	751584	19729F	PARTICIPANT	\N	EXCUSE	0
751812	751567	99004R	PARTICIPANT	\N	PRESENT	0
751814	751587	14147R	PARTICIPANT	\N	PRESENT	0
751815	751587	14215L	PRESIDENT	0	PRESENT	0
751833	751567	20060X	PARTICIPANT	\N	PRESENT	0
751817	751587	19729F	PARTICIPANT	\N	EXCUSE	0
751818	751567	14089Y	PARTICIPANT	\N	PRESENT	0
751819	751567	20266L	PARTICIPANT	\N	PRESENT	0
751820	751567	07029T	PARTICIPANT	\N	PRESENT	0
751821	751567	20024T	PARTICIPANT	\N	PRESENT	0
751822	751567	19387D	PARTICIPANT	\N	PRESENT	0
751823	751567	19577H	PARTICIPANT	\N	PRESENT	0
751834	751567	19525U	PARTICIPANT	\N	PRESENT	0
751835	751567	19782L	PARTICIPANT	\N	PRESENT	0
751836	751567	14147R	PARTICIPANT	\N	PRESENT	0
751837	751567	20062A	PARTICIPANT	\N	PRESENT	0
751838	751567	20252E	PARTICIPANT	\N	PRESENT	0
751839	751567	11090Q	PARTICIPANT	\N	PRESENT	0
751840	751567	14219Q	PARTICIPANT	\N	PRESENT	0
751841	751567	14215L	PARTICIPANT	\N	PRESENT	0
751842	751567	11080N	PARTICIPANT	\N	PRESENT	0
751843	751567	20138D	PARTICIPANT	\N	PRESENT	0
751844	751567	14083S	PARTICIPANT	\N	PRESENT	0
751845	751567	18193Q	PARTICIPANT	\N	PRESENT	0
751846	751567	19826F	PARTICIPANT	\N	PRESENT	0
751847	751567	11070L	PARTICIPANT	\N	PRESENT	0
751848	751567	14037X	PARTICIPANT	\N	PRESENT	0
751849	751567	20298U	PARTICIPANT	\N	PRESENT	0
751850	751567	14217N	PARTICIPANT	\N	PRESENT	0
751851	751567	14169X	PARTICIPANT	\N	PRESENT	0
751852	751567	14071N	PARTICIPANT	\N	PRESENT	0
751853	751567	86034E	PARTICIPANT	\N	PRESENT	0
751854	751567	11085T	PARTICIPANT	\N	PRESENT	0
751855	751567	01025N	PARTICIPANT	\N	PRESENT	0
751856	751571	99004R	PARTICIPANT	\N	PRESENT	0
751857	751571	07029T	PARTICIPANT	\N	PRESENT	0
751858	751571	19577H	PARTICIPANT	\N	PRESENT	0
751859	751571	19695N	PARTICIPANT	\N	PRESENT	0
751860	751571	20060X	PARTICIPANT	\N	PRESENT	0
751861	751571	19525U	PARTICIPANT	\N	PRESENT	0
751862	751571	19782L	PARTICIPANT	\N	PRESENT	0
751863	751571	14147R	PARTICIPANT	\N	PRESENT	0
751864	751571	20062A	PARTICIPANT	\N	PRESENT	0
751865	751571	20252E	PARTICIPANT	\N	PRESENT	0
751866	751571	11090Q	PARTICIPANT	\N	PRESENT	0
751867	751571	14219Q	PARTICIPANT	\N	PRESENT	0
751868	751571	14215L	PARTICIPANT	\N	PRESENT	0
751869	751571	11080N	PARTICIPANT	\N	PRESENT	0
751870	751571	20138D	PARTICIPANT	\N	PRESENT	0
751871	751571	14083S	PARTICIPANT	\N	PRESENT	0
751872	751571	18193Q	PARTICIPANT	\N	PRESENT	0
751873	751571	19826F	PARTICIPANT	\N	PRESENT	0
751874	751571	11070L	PARTICIPANT	\N	PRESENT	0
751875	751571	14037X	PARTICIPANT	\N	PRESENT	0
751876	751571	20298U	PARTICIPANT	\N	PRESENT	0
751877	751571	14217N	PARTICIPANT	\N	PRESENT	0
751878	751571	14169X	PARTICIPANT	\N	PRESENT	0
751879	751571	14071N	PARTICIPANT	\N	PRESENT	0
751880	751571	86034E	PARTICIPANT	\N	PRESENT	0
751881	751571	11085T	PARTICIPANT	\N	PRESENT	0
751882	751571	01025N	PARTICIPANT	\N	PRESENT	0
751883	751571	20082E	PARTICIPANT	\N	PRESENT	0
751884	751571	20134Y	PARTICIPANT	\N	PRESENT	0
751885	751571	11053K	PARTICIPANT	\N	PRESENT	0
751886	751571	19649G	PARTICIPANT	\N	PRESENT	0
751887	751571	19683J	PARTICIPANT	\N	PRESENT	0
751888	751571	20024T	PARTICIPANT	\N	PRESENT	0
751889	751571	20018V	PARTICIPANT	\N	PRESENT	0
751890	751571	14281W	PARTICIPANT	\N	PRESENT	0
751891	751571	11012A	PARTICIPANT	\N	PRESENT	0
751892	751571	20040T	PARTICIPANT	\N	PRESENT	0
751893	751571	04085P	PARTICIPANT	\N	PRESENT	0
751894	751571	19687N	PARTICIPANT	\N	PRESENT	0
751895	751571	11097X	PARTICIPANT	\N	PRESENT	0
751896	751571	14213J	PARTICIPANT	\N	PRESENT	0
751897	751571	19667J	PARTICIPANT	\N	PRESENT	0
751932	751571	17023S	PARTICIPANT	\N	PRESENT	0
751899	751571	20038A	PARTICIPANT	\N	PRESENT	0
751900	751571	04033B	PARTICIPANT	\N	PRESENT	0
751901	751571	14225N	PARTICIPANT	\N	PRESENT	0
751902	751571	08061X	PARTICIPANT	\N	PRESENT	0
751903	751571	14026U	PARTICIPANT	\N	PRESENT	0
751904	751571	04043D	PARTICIPANT	\N	PRESENT	0
751905	751571	20126Y	PARTICIPANT	\N	PRESENT	0
751906	751571	04057K	PARTICIPANT	\N	PRESENT	0
751907	751571	20124W	PARTICIPANT	\N	PRESENT	0
751908	751571	20050V	PARTICIPANT	\N	PRESENT	0
751909	751571	01024M	PARTICIPANT	\N	PRESENT	0
751910	751571	07033P	PARTICIPANT	\N	PRESENT	0
751911	751571	20084G	PARTICIPANT	\N	PRESENT	0
751912	751571	20180F	PARTICIPANT	\N	PRESENT	0
751913	751571	20058E	PARTICIPANT	\N	PRESENT	0
751914	751571	20068G	PARTICIPANT	\N	PRESENT	0
751915	751571	11031D	PARTICIPANT	\N	PRESENT	0
751916	751571	19758L	PARTICIPANT	\N	PRESENT	0
751917	751571	19719D	PARTICIPANT	\N	PRESENT	0
751918	751571	20092G	PARTICIPANT	\N	PRESENT	0
751919	751571	20098N	PARTICIPANT	\N	PRESENT	0
751920	751571	19701S	PARTICIPANT	\N	PRESENT	0
751921	751571	14089Y	PARTICIPANT	\N	PRESENT	0
751922	751571	19387D	PARTICIPANT	\N	PRESENT	0
751923	751571	19693L	PARTICIPANT	\N	PRESENT	0
751924	751571	14259Y	PARTICIPANT	\N	PRESENT	0
751925	751571	20266L	PARTICIPANT	\N	PRESENT	0
751926	751571	20120S	PARTICIPANT	\N	PRESENT	0
751927	751571	19647E	PARTICIPANT	\N	PRESENT	0
751928	751571	14187A	PARTICIPANT	\N	PRESENT	0
751929	751571	97011G	PARTICIPANT	\N	PRESENT	0
751930	751571	19673G	PARTICIPANT	\N	PRESENT	0
751931	751571	20152B	PARTICIPANT	\N	PRESENT	0
751933	751571	95063L	PARTICIPANT	\N	PRESENT	0
751934	751571	01028R	PARTICIPANT	\N	PRESENT	0
751935	751571	95041E	PARTICIPANT	\N	PRESENT	0
752161	752121	07029T	PARTICIPANT	\N	EXCUSE	0
752162	752121	20046A	PARTICIPANT	\N	EXCUSE	0
752805	752410	21079P	PARTICIPANT	\N	PRESENT	0
752806	752410	01058X	PARTICIPANT	\N	PRESENT	0
752807	752410	14259Y	PARTICIPANT	\N	PRESENT	0
752808	752410	21090J	PARTICIPANT	\N	PRESENT	0
752809	752410	12028B	PARTICIPANT	\N	PRESENT	0
756406	756189	19735D	PARTICIPANT	\N	PRESENT	0
756407	756189	21077M	PARTICIPANT	\N	PRESENT	0
756408	755859	14215L	PARTICIPANT	\N	PRESENT	0
756413	755859	20034V	PARTICIPANT	\N	PRESENT	0
756410	755859	21057H	PARTICIPANT	\N	PRESENT	0
756411	755859	20022R	PARTICIPANT	\N	PRESENT	0
756412	755859	14217N	PARTICIPANT	\N	PRESENT	0
756414	755859	14031R	PARTICIPANT	\N	PRESENT	0
756415	755859	21050A	PARTICIPANT	\N	PRESENT	0
756416	755859	20052X	PARTICIPANT	\N	PRESENT	0
756417	755859	21044C	PARTICIPANT	\N	PRESENT	0
756418	755859	14187A	PARTICIPANT	\N	PRESENT	0
756419	755864	21031W	PARTICIPANT	\N	PRESENT	0
756420	755864	19565D	PARTICIPANT	\N	PRESENT	0
756421	755864	20072C	PARTICIPANT	\N	PRESENT	0
756422	755864	01058X	PARTICIPANT	\N	PRESENT	0
756423	755864	14001X	PARTICIPANT	\N	PRESENT	0
756424	755864	04042C	PARTICIPANT	\N	PRESENT	0
756425	755864	08056B	PARTICIPANT	\N	PRESENT	0
756426	755864	12028B	PARTICIPANT	\N	PRESENT	0
756427	755864	17737W	PARTICIPANT	\N	PRESENT	0
756428	755864	19421M	PARTICIPANT	\N	PRESENT	0
756429	755864	14193X	PRESIDENT	0	PRESENT	0
756430	755864	19347U	PARTICIPANT	\N	PRESENT	0
756431	755864	14179A	PARTICIPANT	\N	PRESENT	0
756432	755864	17367Q	PARTICIPANT	\N	PRESENT	0
756433	755864	14249W	PARTICIPANT	\N	PRESENT	0
756434	755864	08047A	PARTICIPANT	\N	PRESENT	0
756435	755864	20128B	PARTICIPANT	\N	PRESENT	0
756436	755864	14037X	PARTICIPANT	\N	PRESENT	0
756437	755864	14059S	PARTICIPANT	\N	PRESENT	0
756438	755864	14097Y	PARTICIPANT	\N	PRESENT	0
756439	755864	14133K	PARTICIPANT	\N	PRESENT	0
756440	755864	08069G	PARTICIPANT	\N	PRESENT	0
756441	755864	20042V	PARTICIPANT	\N	PRESENT	0
756442	755864	14191V	PARTICIPANT	\N	PRESENT	0
756443	755864	20064C	PARTICIPANT	\N	PRESENT	0
756444	755864	20252E	PARTICIPANT	\N	PRESENT	0
756445	755864	14251Q	PARTICIPANT	\N	PRESENT	0
756446	755864	14267Y	PARTICIPANT	\N	PRESENT	0
756447	755864	99004R	PARTICIPANT	\N	PRESENT	0
756448	755864	14255U	PARTICIPANT	\N	PRESENT	0
756451	755864	07033P	PARTICIPANT	\N	PRESENT	0
756452	755864	98022P	PARTICIPANT	\N	PRESENT	0
756458	755859	14173T	PARTICIPANT	\N	PRESENT	0
756459	755859	19681G	PARTICIPANT	\N	PRESENT	0
756464	755859	10015M	PARTICIPANT	\N	PRESENT	0
756465	755859	19954N	PARTICIPANT	\N	PRESENT	0
756476	755859	20104S	PARTICIPANT	\N	PRESENT	0
756512	755943	08010L	PARTICIPANT	\N	PRESENT	0
756513	755859	14073Q	PARTICIPANT	\N	PRESENT	0
756514	755859	20040T	PARTICIPANT	\N	PRESENT	0
756518	755859	17965H	PARTICIPANT	\N	PRESENT	0
756520	755859	20066E	PARTICIPANT	\N	PRESENT	0
756521	755859	20180F	PARTICIPANT	\N	PRESENT	0
756522	755859	20134Y	PARTICIPANT	\N	PRESENT	0
756523	755859	14249W	PARTICIPANT	\N	PRESENT	0
756524	755859	20266L	PARTICIPANT	\N	PRESENT	0
756530	756529	20110Q	PARTICIPANT	\N	PRESENT	0
756531	756529	17367Q	PARTICIPANT	\N	PRESENT	0
756532	756529	17737W	PARTICIPANT	\N	PRESENT	0
756533	756529	19782L	PARTICIPANT	\N	PRESENT	0
756534	756529	17229F	PARTICIPANT	\N	PRESENT	0
756535	756529	19251M	PARTICIPANT	\N	PRESENT	0
756536	756529	19647E	PARTICIPANT	\N	PRESENT	0
756540	756529	11085T	PARTICIPANT	\N	PRESENT	0
756538	756529	20064C	PARTICIPANT	\N	PRESENT	0
756539	756529	19349W	PARTICIPANT	\N	PRESENT	0
756541	756529	19711U	PARTICIPANT	\N	PRESENT	0
756542	756529	11045K	PARTICIPANT	\N	PRESENT	0
756543	756529	04033B	PARTICIPANT	\N	PRESENT	0
756544	756529	20180F	PARTICIPANT	\N	PRESENT	0
756545	756529	17023S	PARTICIPANT	\N	PRESENT	0
756546	756529	98022P	PARTICIPANT	\N	PRESENT	0
756547	755859	19347U	PARTICIPANT	\N	PRESENT	0
756549	755859	20100N	PARTICIPANT	\N	PRESENT	0
756550	756548	17367Q	PARTICIPANT	\N	PRESENT	0
756551	756548	17737W	PARTICIPANT	\N	PRESENT	0
756552	756548	19251M	PARTICIPANT	\N	PRESENT	0
756553	756548	19647E	PARTICIPANT	\N	PRESENT	0
756554	756548	19711U	PARTICIPANT	\N	PRESENT	0
756555	756548	11085T	PARTICIPANT	\N	PRESENT	0
756556	756548	20180F	PARTICIPANT	\N	PRESENT	0
756557	756548	04033B	PARTICIPANT	\N	PRESENT	0
756558	756548	11045K	PARTICIPANT	\N	PRESENT	0
756559	756548	98022P	PARTICIPANT	\N	PRESENT	0
756560	756548	20110Q	PARTICIPANT	\N	PRESENT	0
756561	756548	17229F	PARTICIPANT	\N	PRESENT	0
756562	756548	17023S	PARTICIPANT	\N	PRESENT	0
756563	756548	19349W	PARTICIPANT	\N	PRESENT	0
756564	756548	20064C	PARTICIPANT	\N	PRESENT	0
756565	756548	19782L	PARTICIPANT	\N	PRESENT	0
756624	756623	14217N	PARTICIPANT	\N	PRESENT	0
756625	756623	14281W	PARTICIPANT	\N	PRESENT	0
756626	756591	14042U	PARTICIPANT	\N	PRESENT	0
756627	756591	14213J	PARTICIPANT	\N	PRESENT	0
756628	756591	17965H	PARTICIPANT	\N	PRESENT	0
756756	756082	20084G	PRESIDENT	0	PRESENT	0
756757	756082	14231L	PRESIDENT	1	PRESENT	0
756758	756082	21065H	PARTICIPANT	\N	PRESENT	0
756759	756082	19349W	PARTICIPANT	\N	PRESENT	0
756760	756082	20090E	PARTICIPANT	\N	PRESENT	0
756761	756082	08012N	PARTICIPANT	\N	PRESENT	0
756762	756082	14257W	PARTICIPANT	\N	PRESENT	0
756763	756082	21070E	PARTICIPANT	\N	PRESENT	0
756764	756082	14151M	PARTICIPANT	\N	PRESENT	0
756765	756082	20070A	PARTICIPANT	\N	PRESENT	0
756766	756082	14281W	PARTICIPANT	\N	PRESENT	0
756767	756082	14327T	PARTICIPANT	\N	PRESENT	0
756768	756082	14173T	PARTICIPANT	\N	PRESENT	0
756769	756082	19531S	PARTICIPANT	\N	PRESENT	0
756770	756082	19489J	PARTICIPANT	\N	PRESENT	0
756771	756082	21068L	PARTICIPANT	\N	PRESENT	0
756772	756082	05012A	PARTICIPANT	\N	PRESENT	0
756773	756082	19573D	PARTICIPANT	\N	PRESENT	0
756774	756082	20022R	PARTICIPANT	\N	PRESENT	0
756777	756082	19782L	PARTICIPANT	\N	PRESENT	0
756778	756082	14053L	PARTICIPANT	\N	PRESENT	0
756779	756082	19826F	PARTICIPANT	\N	PRESENT	0
756780	756082	20058E	PARTICIPANT	\N	PRESENT	0
756781	756082	19866P	PARTICIPANT	\N	PRESENT	0
756782	756082	21085M	PARTICIPANT	\N	PRESENT	0
756783	756082	20120S	PARTICIPANT	\N	PRESENT	0
756784	756082	19447X	PARTICIPANT	\N	PRESENT	0
756785	756082	19673G	PARTICIPANT	\N	PRESENT	0
756787	756082	19758L	PARTICIPANT	\N	PRESENT	0
756789	756082	20102Q	PARTICIPANT	\N	PRESENT	0
756791	756082	20032T	PARTICIPANT	\N	PRESENT	0
756794	756082	14215L	PARTICIPANT	\N	EXCUSE	0
756796	756082	01034P	PARTICIPANT	\N	EXCUSE	0
756797	756082	19735D	PARTICIPANT	\N	EXCUSE	0
756798	756082	14205J	PARTICIPANT	\N	EXCUSE	0
756916	756082	14069U	PARTICIPANT	\N	EXCUSE	0
756917	756082	19621T	PARTICIPANT	\N	EXCUSE	0
756918	756082	14026U	PARTICIPANT	\N	EXCUSE	0
756919	756082	19768N	PARTICIPANT	\N	EXCUSE	0
757757	757756	08034U	PARTICIPANT	\N	PRESENT	0
757759	757758	11048N	PARTICIPANT	\N	PRESENT	0
757761	757760	11053K	PARTICIPANT	\N	PRESENT	0
757763	757762	11053K	PARTICIPANT	\N	PRESENT	0
757765	757764	11053K	PARTICIPANT	\N	PRESENT	0
757771	757770	08073C	PARTICIPANT	\N	PRESENT	0
757772	757770	20150Y	PARTICIPANT	\N	PRESENT	1
757776	757775	08073C	PARTICIPANT	\N	PRESENT	0
757777	757775	20150Y	PARTICIPANT	\N	PRESENT	1
757779	757778	14249W	PARTICIPANT	\N	PRESENT	0
757809	757808	14267Y	PARTICIPANT	\N	PRESENT	0
757810	757808	14249W	PARTICIPANT	\N	PRESENT	0
757811	757808	19565D	PARTICIPANT	\N	PRESENT	0
757812	757808	20072C	PARTICIPANT	\N	PRESENT	0
757813	757808	21073H	PARTICIPANT	\N	PRESENT	0
757814	757808	08047A	PARTICIPANT	\N	PRESENT	0
757815	757808	14193X	PARTICIPANT	\N	PRESENT	0
757816	757808	19745F	PARTICIPANT	\N	PRESENT	0
757817	757808	19421M	PARTICIPANT	\N	PRESENT	0
757818	757808	21031W	PARTICIPANT	\N	PRESENT	0
757820	757819	14249W	PARTICIPANT	\N	PRESENT	0
757821	757819	17023S	PARTICIPANT	\N	PRESENT	0
757822	757819	20128B	PARTICIPANT	\N	PRESENT	0
757823	757819	19531S	PARTICIPANT	\N	PRESENT	0
757824	757819	08047A	PARTICIPANT	\N	PRESENT	0
740831	740727	99004R	PARTICIPANT	\N	PRESENT	0
740837	740752	04047H	PRESIDENT	0	PRESENT	0
740838	740752	20108W	PARTICIPANT	\N	PRESENT	0
740839	740752	19543W	PARTICIPANT	\N	PRESENT	0
740840	740752	04008A	PARTICIPANT	\N	PRESENT	0
740841	740752	19673G	PARTICIPANT	\N	PRESENT	0
740842	740752	14215L	PARTICIPANT	\N	PRESENT	0
740843	740752	11072N	PARTICIPANT	\N	PRESENT	0
740844	740752	05008E	PARTICIPANT	\N	PRESENT	0
740845	740752	20022R	PARTICIPANT	\N	PRESENT	0
740846	740752	19749K	PARTICIPANT	\N	PRESENT	0
740984	740728	19447X	PARTICIPANT	\N	PRESENT	0
740985	740728	12041X	PARTICIPANT	\N	PRESENT	0
740986	740728	08061X	PARTICIPANT	\N	PRESENT	0
740987	740728	19643A	PARTICIPANT	\N	PRESENT	0
740988	740728	11083R	PARTICIPANT	\N	PRESENT	0
740989	740728	14073Q	PARTICIPANT	\N	PRESENT	0
740990	740728	19647E	PARTICIPANT	\N	PRESENT	0
740991	740728	20034V	PARTICIPANT	\N	PRESENT	0
740992	740728	20914V	PARTICIPANT	\N	PRESENT	0
740993	740728	11027H	PARTICIPANT	\N	PRESENT	0
740994	740728	20252E	PARTICIPANT	\N	PRESENT	0
740995	740728	20052X	PARTICIPANT	\N	PRESENT	0
741024	740729	19399H	PARTICIPANT	\N	PRESENT	0
741025	738366	19766L	PARTICIPANT	\N	PRESENT	0
741026	738366	20132W	PARTICIPANT	\N	PRESENT	0
741027	738366	04070G	PARTICIPANT	\N	PRESENT	0
741028	738366	19643A	PARTICIPANT	\N	PRESENT	0
741029	738366	20134Y	PARTICIPANT	\N	PRESENT	0
741030	738366	19651A	PARTICIPANT	\N	PRESENT	0
741031	738366	14073Q	PARTICIPANT	\N	PRESENT	0
741032	738366	19611R	PARTICIPANT	\N	PRESENT	0
741033	738366	20142Y	PARTICIPANT	\N	PRESENT	0
741034	738366	19399H	PARTICIPANT	\N	PRESENT	0
741035	738366	14229S	PARTICIPANT	\N	PRESENT	0
741036	738366	20098N	PARTICIPANT	\N	PRESENT	0
741037	738366	20058E	PARTICIPANT	\N	PRESENT	0
741038	738366	04059M	PARTICIPANT	\N	PRESENT	0
741039	738366	20112S	PARTICIPANT	\N	PRESENT	0
743480	743476	14026U	PARTICIPANT	\N	PRESENT	0
741041	738366	20124W	PARTICIPANT	\N	PRESENT	0
741042	738366	19758L	PARTICIPANT	\N	PRESENT	0
741043	738366	20052X	PARTICIPANT	\N	PRESENT	0
741044	740729	04059M	PARTICIPANT	\N	PRESENT	0
741045	740729	14229S	PARTICIPANT	\N	PRESENT	0
741046	740729	20142Y	PARTICIPANT	\N	PRESENT	0
741047	740729	04070G	PARTICIPANT	\N	PRESENT	0
741048	740729	20124W	PARTICIPANT	\N	PRESENT	0
741049	740729	20134Y	PARTICIPANT	\N	PRESENT	0
741022	740729	12041X	PARTICIPANT	\N	PRESENT	0
741023	740729	19611R	PARTICIPANT	\N	PRESENT	0
741050	740729	14187A	PARTICIPANT	\N	PRESENT	0
741051	740729	14147R	PARTICIPANT	\N	PRESENT	0
741052	740729	19447X	PARTICIPANT	\N	PRESENT	0
741053	740729	20034V	PARTICIPANT	\N	PRESENT	0
741054	740729	20112S	PARTICIPANT	\N	PRESENT	0
741055	740729	19651A	PARTICIPANT	\N	PRESENT	0
741056	740729	20132W	PARTICIPANT	\N	PRESENT	0
741057	740729	20052X	PARTICIPANT	\N	PRESENT	0
741058	740729	14215L	PARTICIPANT	\N	PRESENT	0
741059	740729	20252E	PARTICIPANT	\N	PRESENT	0
741060	740729	19621T	PARTICIPANT	\N	PRESENT	0
741061	740729	99004R	PARTICIPANT	\N	PRESENT	0
741062	740729	19758L	PARTICIPANT	\N	PRESENT	0
741063	740729	04033B	PARTICIPANT	\N	PRESENT	0
741064	740729	19643A	PARTICIPANT	\N	PRESENT	0
741065	740729	20122U	PARTICIPANT	\N	PRESENT	0
741066	740729	14073Q	PARTICIPANT	\N	PRESENT	0
741067	740729	11109J	PARTICIPANT	\N	PRESENT	0
741068	740729	11027H	PARTICIPANT	\N	PRESENT	0
741069	740729	11077T	PARTICIPANT	\N	PRESENT	0
741070	740729	20058E	PARTICIPANT	\N	PRESENT	0
743479	743476	19725B	PARTICIPANT	\N	PRESENT	0
744947	744944	11066Q	PARTICIPANT	\N	PRESENT	0
748213	748211	86034E	PARTICIPANT	\N	PRESENT	0
748214	748211	04085P	PARTICIPANT	\N	PRESENT	0
748215	748211	14133K	PARTICIPANT	\N	PRESENT	0
748216	748211	04047H	PARTICIPANT	\N	PRESENT	0
748217	748211	11053K	PARTICIPANT	\N	PRESENT	0
748218	748211	10006L	PARTICIPANT	\N	PRESENT	0
748219	748211	14042U	PARTICIPANT	\N	PRESENT	0
748220	748211	19347U	PARTICIPANT	\N	PRESENT	0
748221	748211	11048N	PARTICIPANT	\N	PRESENT	0
748222	748211	14021P	PARTICIPANT	\N	PRESENT	0
748223	748211	99004R	PARTICIPANT	\N	PRESENT	0
748224	748211	19611R	PARTICIPANT	\N	PRESENT	0
748225	748211	12041X	PARTICIPANT	\N	PRESENT	0
748226	748211	14219Q	PARTICIPANT	\N	PRESENT	0
748227	748211	11085T	PARTICIPANT	\N	PRESENT	0
748228	748211	04057K	PARTICIPANT	\N	PRESENT	0
748229	748211	11090Q	PARTICIPANT	\N	PRESENT	0
748230	748211	14331P	PARTICIPANT	\N	PRESENT	0
748231	748211	14225N	PARTICIPANT	\N	PRESENT	0
748232	748211	11012A	PARTICIPANT	\N	PRESENT	0
748233	748211	04033B	PARTICIPANT	\N	PRESENT	0
748234	748211	95063L	PARTICIPANT	\N	PRESENT	0
748235	748211	11045K	PARTICIPANT	\N	PRESENT	0
752359	752358	14053L	PARTICIPANT	\N	PRESENT	0
752360	752358	14089Y	PARTICIPANT	\N	PRESENT	0
752362	752361	20110Q	PARTICIPANT	\N	PRESENT	0
752363	752361	14059S	PARTICIPANT	\N	PRESENT	0
752638	752374	14031R	PARTICIPANT	\N	PRESENT	0
752640	752374	20142Y	PARTICIPANT	\N	PRESENT	0
752641	752374	21075K	PARTICIPANT	\N	PRESENT	0
752642	752374	14001X	PARTICIPANT	\N	PRESENT	0
752643	752374	11085T	PARTICIPANT	\N	PRESENT	0
752644	752374	19826F	PARTICIPANT	\N	PRESENT	0
752645	752374	21058J	PARTICIPANT	\N	PRESENT	0
752647	752374	08009T	PARTICIPANT	\N	PRESENT	0
752648	752374	14221J	PARTICIPANT	\N	PRESENT	0
752649	752374	20252E	PARTICIPANT	\N	PRESENT	0
752650	752374	21073H	PARTICIPANT	\N	PRESENT	0
752651	752374	19563B	PARTICIPANT	\N	PRESENT	0
752652	752374	14147R	PARTICIPANT	\N	PRESENT	0
752653	752374	20028X	PARTICIPANT	\N	PRESENT	0
752654	752374	21080G	PARTICIPANT	\N	PRESENT	0
752655	752374	20018V	PARTICIPANT	\N	PRESENT	0
752656	752374	14223L	PARTICIPANT	\N	PRESENT	0
752657	752374	04092N	PARTICIPANT	\N	PRESENT	0
752658	752374	19335Q	PARTICIPANT	\N	PRESENT	0
752659	752374	11072N	PARTICIPANT	\N	PRESENT	0
752660	752374	14109K	PARTICIPANT	\N	PRESENT	0
752661	752374	14257W	PARTICIPANT	\N	PRESENT	0
752662	752374	08011M	PARTICIPANT	\N	PRESENT	0
752663	752374	04070G	PARTICIPANT	\N	PRESENT	0
752664	752374	14071N	PARTICIPANT	\N	PRESENT	0
752665	752374	20096L	PARTICIPANT	\N	PRESENT	0
752666	752374	21097R	PARTICIPANT	\N	PRESENT	0
752667	752374	18231D	PARTICIPANT	\N	PRESENT	0
752668	752374	21029D	PARTICIPANT	\N	PRESENT	0
752669	752374	21039F	PARTICIPANT	\N	PRESENT	0
752670	752374	14169X	PARTICIPANT	\N	PRESENT	0
752672	752374	14253S	PARTICIPANT	\N	PRESENT	0
752673	752374	21037D	PARTICIPANT	\N	PRESENT	0
752674	752374	19331L	PARTICIPANT	\N	PRESENT	0
752675	752374	21060C	PARTICIPANT	\N	PRESENT	0
752676	752374	19593H	PARTICIPANT	\N	PRESENT	0
752677	752374	19573D	PARTICIPANT	\N	PRESENT	0
752678	752374	19866P	PARTICIPANT	\N	PRESENT	0
752679	752374	14191V	PARTICIPANT	\N	PRESENT	0
752680	752374	20050V	PARTICIPANT	\N	PRESENT	0
752681	752374	20036X	PARTICIPANT	\N	PRESENT	0
752682	752374	08073C	PARTICIPANT	\N	PRESENT	0
752683	752374	08061X	PARTICIPANT	\N	PRESENT	0
752684	752374	08047A	PARTICIPANT	\N	PRESENT	0
752685	752374	21055F	PARTICIPANT	\N	PRESENT	0
752686	752374	14237S	PARTICIPANT	\N	PRESENT	0
752687	752374	21047F	PARTICIPANT	\N	PRESENT	0
752688	752374	14193X	PARTICIPANT	\N	PRESENT	0
752689	752374	19745F	PARTICIPANT	\N	PRESENT	0
752690	752374	20148F	PARTICIPANT	\N	PRESENT	0
752691	752374	20146D	PARTICIPANT	\N	PRESENT	0
752692	752374	19533U	PARTICIPANT	\N	PRESENT	0
752693	752374	21053D	PARTICIPANT	\N	PRESENT	0
752694	752374	20030R	PARTICIPANT	\N	PRESENT	0
752695	752374	20118Y	PARTICIPANT	\N	PRESENT	0
762859	761712	21081H	PARTICIPANT	\N	PRESENT	0
762860	761712	14151M	PARTICIPANT	\N	PRESENT	0
762861	761712	17737W	PARTICIPANT	\N	PRESENT	0
762862	761712	19798U	PARTICIPANT	\N	PRESENT	0
762863	761712	21063F	PARTICIPANT	\N	PRESENT	0
762864	761712	19111A	PARTICIPANT	\N	PRESENT	0
762865	761712	14207L	PARTICIPANT	\N	PRESENT	0
762866	761712	19649G	PARTICIPANT	\N	PRESENT	0
762867	761712	17965H	PARTICIPANT	\N	PRESENT	0
762868	761712	20062A	PARTICIPANT	\N	PRESENT	0
762869	761712	19725B	PARTICIPANT	\N	PRESENT	0
762870	761712	18207D	PARTICIPANT	\N	PRESENT	0
762871	761712	21062E	PARTICIPANT	\N	PRESENT	0
762872	761712	14109K	PARTICIPANT	\N	PRESENT	0
762873	761712	19687N	PARTICIPANT	\N	PRESENT	0
762874	761712	21034A	PARTICIPANT	\N	PRESENT	0
762875	761712	21067K	PARTICIPANT	\N	PRESENT	0
762876	761712	18193Q	PARTICIPANT	\N	PRESENT	0
762877	761712	19565D	PARTICIPANT	\N	PRESENT	0
762878	761712	11074Q	PARTICIPANT	\N	PRESENT	0
762879	761712	20018V	PARTICIPANT	\N	PRESENT	0
762880	761712	11065P	PARTICIPANT	\N	PRESENT	0
762881	761712	21079P	PARTICIPANT	\N	PRESENT	0
762882	761712	20266L	PARTICIPANT	\N	PRESENT	0
762883	761712	04045F	PARTICIPANT	\N	PRESENT	0
762884	761712	14249W	PARTICIPANT	\N	PRESENT	0
762885	761712	19782L	PARTICIPANT	\N	PRESENT	0
762886	761712	20090E	PARTICIPANT	\N	PRESENT	0
762887	761712	04047H	PARTICIPANT	\N	PRESENT	0
762888	761712	14089Y	PARTICIPANT	\N	PRESENT	0
762889	761712	19367Y	PARTICIPANT	\N	PRESENT	0
762890	761712	19629C	PARTICIPANT	\N	PRESENT	0
762891	761712	19057M	PARTICIPANT	\N	PRESENT	0
762892	761712	21043B	PARTICIPANT	\N	PRESENT	0
762893	761712	21076L	PARTICIPANT	\N	PRESENT	0
762894	761712	20100N	PARTICIPANT	\N	PRESENT	0
762895	761712	21077M	PARTICIPANT	\N	PRESENT	0
762896	761712	19489J	PARTICIPANT	\N	PRESENT	0
762897	761712	19820Y	PARTICIPANT	\N	PRESENT	0
762898	761712	19647E	PARTICIPANT	\N	PRESENT	0
762899	761712	11045K	PARTICIPANT	\N	PRESENT	0
762900	761712	14189C	PARTICIPANT	\N	PRESENT	0
762901	761712	01034P	PARTICIPANT	\N	PRESENT	0
762902	761712	98022P	PARTICIPANT	\N	PRESENT	0
762903	761712	18395Y	PARTICIPANT	\N	PRESENT	0
762904	761712	21037D	PARTICIPANT	\N	PRESENT	0
762905	761712	20106U	PARTICIPANT	\N	PRESENT	0
762906	761712	20054A	PARTICIPANT	\N	PRESENT	0
762907	761712	14055N	PARTICIPANT	\N	PRESENT	0
762908	761712	19713W	PARTICIPANT	\N	PRESENT	0
762909	761712	21053D	PARTICIPANT	\N	PRESENT	0
762910	761712	95041E	PARTICIPANT	\N	PRESENT	0
762911	761712	20056C	PARTICIPANT	\N	PRESENT	0
762912	761712	21085M	PARTICIPANT	\N	PRESENT	0
762913	761712	14217N	PARTICIPANT	\N	PRESENT	0
762914	761712	20110Q	PARTICIPANT	\N	PRESENT	0
762915	761712	21093M	PARTICIPANT	\N	PRESENT	0
762916	761712	21056G	PARTICIPANT	\N	PRESENT	0
762917	761712	20088L	PARTICIPANT	\N	PRESENT	0
762918	761712	20080C	PARTICIPANT	\N	PRESENT	0
762919	761712	20076G	PARTICIPANT	\N	PRESENT	0
762920	761712	20074E	PARTICIPANT	\N	PRESENT	0
762921	761712	20078J	PARTICIPANT	\N	PRESENT	0
762922	761712	14069U	PARTICIPANT	\N	PRESENT	0
762923	761712	14187A	PARTICIPANT	\N	PRESENT	0
762924	761712	19679N	PARTICIPANT	\N	PRESENT	0
762925	761712	14053L	PARTICIPANT	\N	PRESENT	0
762926	761712	20124W	PARTICIPANT	\N	PRESENT	0
762927	761712	19533U	PARTICIPANT	\N	PRESENT	0
762928	761712	20108W	PARTICIPANT	\N	PRESENT	0
762929	761712	14357A	PARTICIPANT	\N	PRESENT	0
762930	761712	11090Q	PARTICIPANT	\N	PRESENT	0
762931	761712	05008E	PARTICIPANT	\N	PRESENT	0
762932	761712	14329V	PARTICIPANT	\N	PRESENT	0
762933	761712	08015R	PARTICIPANT	\N	PRESENT	0
762934	761712	20034V	PARTICIPANT	\N	PRESENT	0
762935	761712	14033T	PARTICIPANT	\N	PRESENT	0
762936	761712	20026V	PARTICIPANT	\N	PRESENT	0
762937	761712	20044X	PARTICIPANT	\N	PRESENT	0
762938	761712	19723Y	PARTICIPANT	\N	PRESENT	0
762939	761712	14147R	PARTICIPANT	\N	PRESENT	0
762940	761712	21055F	PARTICIPANT	\N	PRESENT	0
762941	761712	21072G	PARTICIPANT	\N	PRESENT	0
762942	761712	21080G	PARTICIPANT	\N	PRESENT	0
762943	761712	21071F	PARTICIPANT	\N	PRESENT	0
762944	761712	20180F	PARTICIPANT	\N	PRESENT	0
762945	761712	21058J	PARTICIPANT	\N	PRESENT	0
762946	761712	21068L	PARTICIPANT	\N	PRESENT	0
762947	761712	20140W	PARTICIPANT	\N	PRESENT	0
762948	761712	19954N	PARTICIPANT	\N	PRESENT	0
762949	761712	19421M	PARTICIPANT	\N	PRESENT	0
762950	761712	14215L	PARTICIPANT	\N	PRESENT	0
762951	761712	20022R	PARTICIPANT	\N	PRESENT	0
762952	761712	08018U	PARTICIPANT	\N	PRESENT	0
762953	761712	11043H	PARTICIPANT	\N	PRESENT	0
762954	761712	04033B	PARTICIPANT	\N	PRESENT	0
762955	761712	20126Y	PARTICIPANT	\N	PRESENT	0
762956	761712	14231L	PARTICIPANT	\N	PRESENT	0
762957	761712	19585H	PARTICIPANT	\N	PRESENT	0
762958	761712	21046E	PARTICIPANT	\N	PRESENT	0
762959	761712	11064N	PARTICIPANT	\N	PRESENT	0
762960	761712	20134Y	PARTICIPANT	\N	PRESENT	0
762961	761712	20128B	PARTICIPANT	\N	PRESENT	0
762962	761712	19349W	PARTICIPANT	\N	PRESENT	0
762963	761712	14021P	PARTICIPANT	\N	PRESENT	0
762964	761712	21088Q	PARTICIPANT	\N	PRESENT	0
762965	761712	19758L	PARTICIPANT	\N	PRESENT	0
762966	761712	21049H	PARTICIPANT	\N	PRESENT	0
762967	761712	19760E	PARTICIPANT	\N	PRESENT	0
762968	761712	19691J	PARTICIPANT	\N	PRESENT	0
762969	761712	20086J	PARTICIPANT	\N	PRESENT	0
762970	761712	21074J	PARTICIPANT	\N	PRESENT	0
762971	761712	19553Y	PARTICIPANT	\N	PRESENT	0
762972	761712	20072C	PARTICIPANT	\N	PRESENT	0
762973	761712	21038E	PARTICIPANT	\N	PRESENT	0
762974	761712	21064G	PARTICIPANT	\N	PRESENT	0
762975	761712	20066E	PARTICIPANT	\N	PRESENT	0
762976	761712	19673G	PARTICIPANT	\N	PRESENT	0
762857	761712	14229S	PARTICIPANT	\N	PRESENT	0
762858	761712	21044C	PARTICIPANT	\N	PRESENT	0
762977	761712	14026U	PARTICIPANT	\N	PRESENT	0
762978	761712	20092G	PARTICIPANT	\N	PRESENT	0
762979	761712	21082J	PARTICIPANT	\N	PRESENT	0
762980	761712	21097R	PARTICIPANT	\N	PRESENT	0
762981	761712	18231D	PARTICIPANT	\N	PRESENT	0
762982	761712	10015M	PARTICIPANT	\N	PRESENT	0
762983	761712	21066J	PARTICIPANT	\N	PRESENT	0
762984	761712	20138D	PARTICIPANT	\N	PRESENT	0
762985	761712	19507S	PARTICIPANT	\N	PRESENT	0
762986	761712	19383Y	PARTICIPANT	\N	PRESENT	0
762987	761712	19621T	PARTICIPANT	\N	PRESENT	0
762988	761712	19569H	PARTICIPANT	\N	PRESENT	0
762989	761712	20032T	PARTICIPANT	\N	PRESENT	0
762990	761712	20098N	PARTICIPANT	\N	PRESENT	0
762991	761712	18083K	PARTICIPANT	\N	PRESENT	0
762992	761712	21041Y	PARTICIPANT	\N	PRESENT	0
762993	761712	11048N	PARTICIPANT	\N	PRESENT	0
762994	761712	20028X	PARTICIPANT	\N	PRESENT	0
762995	761712	20058E	PARTICIPANT	\N	PRESENT	0
762996	761712	14213J	PARTICIPANT	\N	PRESENT	0
762997	761712	21031W	PARTICIPANT	\N	PRESENT	0
762998	761712	20084G	PARTICIPANT	\N	PRESENT	0
762999	761712	19531S	PARTICIPANT	\N	PRESENT	0
763000	761712	21057H	PARTICIPANT	\N	PRESENT	0
763001	761712	08010L	PARTICIPANT	\N	PRESENT	0
763002	761712	21039F	PARTICIPANT	\N	PRESENT	0
763003	761712	20064C	PARTICIPANT	\N	PRESENT	0
763004	761712	20082E	PARTICIPANT	\N	PRESENT	0
763005	761712	21045D	PARTICIPANT	\N	PRESENT	0
763006	761712	20172F	PARTICIPANT	\N	PRESENT	0
763007	761712	19447X	PARTICIPANT	\N	PRESENT	0
763008	761712	20142Y	PARTICIPANT	\N	PRESENT	0
763009	761712	20042V	PARTICIPANT	\N	PRESENT	0
763010	761712	17023S	PARTICIPANT	\N	PRESENT	0
763011	761712	14097Y	PARTICIPANT	\N	PRESENT	0
763012	761712	07029T	PARTICIPANT	\N	PRESENT	0
763013	761712	19563B	PARTICIPANT	\N	PRESENT	0
763014	761712	20114U	PARTICIPANT	\N	PRESENT	0
763015	761712	19387D	PARTICIPANT	\N	PRESENT	0
763016	761712	20120S	PARTICIPANT	\N	PRESENT	0
763017	761712	20052X	PARTICIPANT	\N	PRESENT	0
744941	741499	14179A	PARTICIPANT	\N	EXCUSE	0
744942	741499	20130U	PARTICIPANT	\N	EXCUSE	0
744943	741499	20024T	PARTICIPANT	\N	EXCUSE	0
745587	745585	14042U	PARTICIPANT	\N	PRESENT	0
745588	745585	11097X	PARTICIPANT	\N	PRESENT	0
745589	745585	14213J	PARTICIPANT	\N	PRESENT	0
745679	745677	11066Q	PARTICIPANT	\N	PRESENT	0
749187	749003	19333N	PARTICIPANT	\N	PRESENT	0
749188	749003	19701S	PARTICIPANT	\N	PRESENT	0
749189	749003	20076G	PARTICIPANT	\N	PRESENT	0
749190	749003	19387D	PARTICIPANT	\N	PRESENT	0
749191	749003	14219Q	PRESIDENT	0	PRESENT	0
749192	749003	19820Y	PARTICIPANT	\N	PRESENT	0
749193	749003	19826F	PARTICIPANT	\N	PRESENT	0
749194	749003	20102Q	PARTICIPANT	\N	PRESENT	0
749195	749003	19599P	PARTICIPANT	\N	PRESENT	0
749196	749003	20096L	PARTICIPANT	\N	PRESENT	0
749197	749003	19637C	PARTICIPANT	\N	PRESENT	0
749198	749003	18083K	PARTICIPANT	\N	PRESENT	0
749199	749003	20100N	PARTICIPANT	\N	PRESENT	0
749200	749003	19551W	PARTICIPANT	\N	PRESENT	0
749201	749003	14237S	PARTICIPANT	\N	PRESENT	0
749202	749003	05012A	PARTICIPANT	\N	PRESENT	0
749203	749003	08060W	PARTICIPANT	\N	PRESENT	0
749204	749003	20106U	PARTICIPANT	\N	PRESENT	0
749205	749003	19503N	PARTICIPANT	\N	PRESENT	0
749206	749003	20020P	PARTICIPANT	\N	PRESENT	0
749207	749003	17367Q	PARTICIPANT	\N	PRESENT	0
749208	749003	20024T	PARTICIPANT	\N	PRESENT	0
749209	749003	19525U	PARTICIPANT	\N	PRESENT	0
749210	749003	20120S	PARTICIPANT	\N	PRESENT	0
749211	749003	20032T	PARTICIPANT	\N	PRESENT	0
749212	749003	20122U	PARTICIPANT	\N	PRESENT	0
749213	749003	20136B	PARTICIPANT	\N	PRESENT	0
749214	749003	14031R	PARTICIPANT	\N	PRESENT	0
749215	749003	20038A	PARTICIPANT	\N	PRESENT	0
749216	749003	20140W	PARTICIPANT	\N	PRESENT	0
749217	749003	19251M	PARTICIPANT	\N	PRESENT	0
749218	749003	20046A	PARTICIPANT	\N	PRESENT	0
749219	749003	14169X	PARTICIPANT	\N	PRESENT	0
749220	749003	20068G	PARTICIPANT	\N	PRESENT	0
749221	749003	11101A	PARTICIPANT	\N	PRESENT	0
749222	749003	19739H	PARTICIPANT	\N	PRESENT	0
749223	749003	19745F	PARTICIPANT	\N	PRESENT	0
749224	749003	17229F	PARTICIPANT	\N	EXCUSE	0
749242	748107	86034E	PARTICIPANT	\N	PRESENT	0
749243	748107	11041F	PARTICIPANT	\N	PRESENT	0
749244	748107	19525U	PARTICIPANT	\N	PRESENT	0
749245	748107	20914V	PARTICIPANT	\N	PRESENT	0
749246	748107	14111D	PARTICIPANT	\N	PRESENT	0
749247	748107	19593H	PARTICIPANT	\N	PRESENT	0
749248	748107	20042V	PARTICIPANT	\N	PRESENT	0
749252	748107	14207L	PARTICIPANT	\N	PRESENT	0
749250	748107	14030Q	PARTICIPANT	\N	PRESENT	0
749251	748107	19511N	PARTICIPANT	\N	PRESENT	0
749253	748107	19739H	PARTICIPANT	\N	PRESENT	0
749254	748107	20052X	PARTICIPANT	\N	PRESENT	0
749255	748107	14073Q	PARTICIPANT	\N	PRESENT	0
749256	748107	19691J	PARTICIPANT	\N	PRESENT	0
749257	748107	20100N	PARTICIPANT	\N	PRESENT	0
749258	748107	20140W	PARTICIPANT	\N	PRESENT	0
749259	748107	19798U	PARTICIPANT	\N	PRESENT	0
749260	748107	20054A	PARTICIPANT	\N	PRESENT	0
749261	748107	20024T	PARTICIPANT	\N	PRESENT	0
749262	748107	20138D	PARTICIPANT	\N	PRESENT	0
749263	748107	14259Y	PARTICIPANT	\N	PRESENT	0
749264	748107	19711U	PARTICIPANT	\N	PRESENT	0
749265	748107	08028W	PARTICIPANT	\N	PRESENT	0
749266	748107	19479G	PARTICIPANT	\N	PRESENT	0
749267	748107	19319Q	PARTICIPANT	\N	PRESENT	0
749268	748107	14107H	PARTICIPANT	\N	PRESENT	0
749269	748107	98022P	PARTICIPANT	\N	PRESENT	0
749270	748107	19745F	PARTICIPANT	\N	PRESENT	0
749271	748107	19387D	PARTICIPANT	\N	PRESENT	0
749272	748107	11067R	PARTICIPANT	\N	PRESENT	0
749273	748107	20032T	PARTICIPANT	\N	PRESENT	0
749274	748107	12028B	PARTICIPANT	\N	PRESENT	0
749275	748107	11077T	PARTICIPANT	\N	PRESENT	0
749276	748107	08045X	PARTICIPANT	\N	PRESENT	0
749277	748107	14001X	PARTICIPANT	\N	PRESENT	0
749278	748107	14109K	PARTICIPANT	\N	PRESENT	0
749279	748107	11066Q	PARTICIPANT	\N	PRESENT	0
749280	748107	19649G	PARTICIPANT	\N	PRESENT	0
749281	748107	04059M	PARTICIPANT	\N	PRESENT	0
749282	748107	11074Q	PARTICIPANT	\N	PRESENT	0
749283	748107	11040E	PARTICIPANT	\N	PRESENT	0
749284	748107	19760E	PARTICIPANT	\N	PRESENT	0
749285	748107	17637T	PARTICIPANT	\N	PRESENT	0
749286	748107	19575F	PARTICIPANT	\N	PRESENT	0
749287	748107	14026U	PARTICIPANT	\N	PRESENT	0
749288	748107	08011M	PARTICIPANT	\N	PRESENT	0
749289	748107	99004R	PARTICIPANT	\N	PRESENT	0
749290	748107	19679N	PARTICIPANT	\N	PRESENT	0
749291	748107	20076G	PARTICIPANT	\N	PRESENT	0
749292	748107	08010L	PARTICIPANT	\N	PRESENT	0
749293	748107	20078J	PARTICIPANT	\N	PRESENT	0
749294	748107	17367Q	PARTICIPANT	\N	PRESENT	0
749295	748107	20074E	PARTICIPANT	\N	PRESENT	0
749296	748107	18083K	PARTICIPANT	\N	PRESENT	0
749297	748107	08069G	PARTICIPANT	\N	PRESENT	0
749298	748107	19643A	PARTICIPANT	\N	PRESENT	0
749299	748107	19515S	PARTICIPANT	\N	PRESENT	0
749300	748107	11080N	PARTICIPANT	\N	PRESENT	0
749301	748107	01057W	PARTICIPANT	\N	PRESENT	0
749302	748107	20068G	PARTICIPANT	\N	PRESENT	0
749303	748107	20022R	PARTICIPANT	\N	PRESENT	0
749304	748107	05012A	PARTICIPANT	\N	PRESENT	0
749305	748107	11090Q	PARTICIPANT	\N	PRESENT	0
749306	748107	19673G	PARTICIPANT	\N	PRESENT	0
749307	748107	11010L	PARTICIPANT	\N	PRESENT	0
749308	748107	20086J	PARTICIPANT	\N	PRESENT	0
749309	748107	14031R	PARTICIPANT	\N	PRESENT	0
749310	748107	19383Y	PARTICIPANT	\N	PRESENT	0
749311	748107	19667J	PARTICIPANT	\N	PRESENT	0
749312	748107	11115U	PARTICIPANT	\N	PRESENT	0
749313	748107	14253S	PARTICIPANT	\N	PRESENT	0
749314	748107	14331P	PARTICIPANT	\N	PRESENT	0
749315	748107	14173T	PARTICIPANT	\N	PRESENT	0
749316	748107	19447X	PARTICIPANT	\N	PRESENT	0
749317	748107	20980G	PARTICIPANT	\N	PRESENT	0
749318	748107	20096L	PARTICIPANT	\N	PRESENT	0
749319	748107	20026V	PARTICIPANT	\N	PRESENT	0
749320	748107	08047A	PARTICIPANT	\N	PRESENT	0
749321	748107	20172F	PARTICIPANT	\N	PRESENT	0
749322	748107	14147R	PARTICIPANT	\N	PRESENT	0
749323	748107	14038Y	PARTICIPANT	\N	PRESENT	0
749324	748107	19723Y	PARTICIPANT	\N	PRESENT	0
749325	748107	04035D	PARTICIPANT	\N	PRESENT	0
749326	748107	19741B	PARTICIPANT	\N	PRESENT	0
749327	748107	14033T	PARTICIPANT	\N	PRESENT	0
749328	748107	19467C	PARTICIPANT	\N	PRESENT	0
749329	748107	20104S	PARTICIPANT	\N	PRESENT	0
749330	748107	19507S	PARTICIPANT	\N	PRESENT	0
749331	748107	19729F	PARTICIPANT	\N	PRESENT	0
749332	748107	14213J	PARTICIPANT	\N	PRESENT	0
749333	748107	14059S	PARTICIPANT	\N	PRESENT	0
749334	748107	20124W	PARTICIPANT	\N	PRESENT	0
749335	748107	20126Y	PARTICIPANT	\N	PRESENT	0
749336	748107	04042C	PARTICIPANT	\N	PRESENT	0
749337	748107	14357A	PARTICIPANT	\N	PRESENT	0
749338	748107	20120S	PARTICIPANT	\N	PRESENT	0
749339	748107	20020P	PARTICIPANT	\N	PRESENT	0
749340	748107	19581D	PARTICIPANT	\N	PRESENT	0
749341	748107	20252E	PARTICIPANT	\N	PRESENT	0
749342	748107	14217N	PARTICIPANT	\N	PRESENT	0
749343	748107	97011G	PARTICIPANT	\N	PRESENT	0
749344	748107	11056N	PARTICIPANT	\N	PRESENT	0
749345	748107	10006L	PARTICIPANT	\N	PRESENT	0
749346	748107	12041X	PARTICIPANT	\N	PRESENT	0
749347	748107	19758L	PARTICIPANT	\N	PRESENT	0
749348	748107	20090E	PARTICIPANT	\N	PRESENT	0
749349	748107	19565D	PARTICIPANT	\N	PRESENT	0
749350	748107	14069U	PARTICIPANT	\N	PRESENT	0
749351	748107	19701S	PARTICIPANT	\N	PRESENT	0
749352	748107	14053L	PARTICIPANT	\N	PRESENT	0
749353	748107	01048V	PARTICIPANT	\N	PRESENT	0
749354	748107	04085P	PARTICIPANT	\N	PRESENT	0
749355	748107	19695N	PARTICIPANT	\N	PRESENT	0
749356	748107	04033B	PARTICIPANT	\N	PRESENT	0
749357	748107	05008E	PARTICIPANT	\N	PRESENT	0
757961	757959	12028B	PARTICIPANT	\N	PRESENT	0
757962	757959	14267Y	PARTICIPANT	\N	PRESENT	0
757963	757959	08010L	PARTICIPANT	\N	PRESENT	0
757965	757843	20124W	PARTICIPANT	\N	PRESENT	1
757966	757843	20056C	PARTICIPANT	\N	PRESENT	1
757967	757843	14109K	PARTICIPANT	\N	PRESENT	1
757968	757843	19735D	PARTICIPANT	\N	PRESENT	1
757969	757843	20026V	PARTICIPANT	\N	PRESENT	1
757970	757843	19954N	PARTICIPANT	\N	PRESENT	1
757972	757971	20124W	PARTICIPANT	\N	PRESENT	1
757973	757971	19735D	PARTICIPANT	\N	PRESENT	1
757974	757971	19954N	PARTICIPANT	\N	PRESENT	1
757975	757971	20056C	PARTICIPANT	\N	PRESENT	1
757976	757971	14109K	PARTICIPANT	\N	PRESENT	1
757985	757984	20058E	PARTICIPANT	\N	PRESENT	1
758132	757844	14030Q	PARTICIPANT	\N	EXCUSE	0
760205	757799	21071F	PARTICIPANT	\N	PRESENT	0
758139	758135	14030Q	PARTICIPANT	\N	EXCUSE	0
758137	752398	19735D	PARTICIPANT	\N	EXCUSE	0
758138	752398	14030Q	PARTICIPANT	\N	EXCUSE	0
758335	758334	20172F	PARTICIPANT	\N	PRESENT	0
758345	758344	20074E	PARTICIPANT	\N	PRESENT	0
758355	758354	14042U	PARTICIPANT	\N	PRESENT	0
758356	758354	20130U	PARTICIPANT	\N	PRESENT	0
758709	758704	20110Q	PARTICIPANT	\N	PRESENT	0
760186	757715	20286Q	PARTICIPANT	\N	EXCUSE	0
760206	757799	20078J	PARTICIPANT	\N	PRESENT	0
760207	757799	19701S	PARTICIPANT	\N	PRESENT	0
760226	760199	19611R	PARTICIPANT	\N	EXCUSE	0
760227	760199	20102Q	PARTICIPANT	\N	PRESENT	0
760228	760199	19735D	PARTICIPANT	\N	PRESENT	0
760229	760199	19699S	PARTICIPANT	\N	PRESENT	0
760230	760199	19697Q	PARTICIPANT	\N	PRESENT	0
760231	760199	20052X	PARTICIPANT	\N	PRESENT	0
760232	760199	08012N	PARTICIPANT	\N	PRESENT	0
760233	757799	21041Y	PARTICIPANT	\N	PRESENT	0
760234	760199	20142Y	PARTICIPANT	\N	PRESENT	0
760235	760199	21058J	PARTICIPANT	\N	PRESENT	0
760236	760199	14109K	PARTICIPANT	\N	PRESENT	0
760237	760199	21037D	PARTICIPANT	\N	PRESENT	0
760238	760199	21055F	PARTICIPANT	\N	PRESENT	0
760239	760199	19593H	PARTICIPANT	\N	PRESENT	0
760240	760199	04070G	PARTICIPANT	\N	PRESENT	0
760241	760199	19533U	PARTICIPANT	\N	PRESENT	0
760242	760199	14229S	PARTICIPANT	\N	PRESENT	0
760243	760199	04033B	PARTICIPANT	\N	PRESENT	0
760244	760199	21059K	PARTICIPANT	\N	PRESENT	0
760245	760199	11043H	PARTICIPANT	\N	PRESENT	0
760246	760199	20026V	PARTICIPANT	\N	PRESENT	0
760247	760199	20058E	PARTICIPANT	\N	PRESENT	0
760248	760199	21077M	PARTICIPANT	\N	PRESENT	0
760249	757799	19531S	PARTICIPANT	\N	PRESENT	0
760250	757799	20042V	PARTICIPANT	\N	PRESENT	0
760251	757799	19711U	PARTICIPANT	\N	PRESENT	0
760252	758135	20138D	PARTICIPANT	\N	EXCUSE	0
760253	752398	20112S	PARTICIPANT	\N	PRESENT	0
760254	752398	19954N	PARTICIPANT	\N	PRESENT	0
760255	752398	19621T	PARTICIPANT	\N	PRESENT	0
760256	752398	18395Y	PARTICIPANT	\N	PRESENT	0
760257	752398	20124W	PARTICIPANT	\N	PRESENT	0
760258	752398	21074J	PARTICIPANT	\N	PRESENT	0
760259	752398	21091K	PARTICIPANT	\N	PRESENT	0
760260	752398	20132W	PARTICIPANT	\N	PRESENT	0
760261	752398	20180F	PARTICIPANT	\N	PRESENT	0
760262	752398	20048C	PARTICIPANT	\N	PRESENT	0
760263	752398	20056C	PARTICIPANT	\N	PRESENT	0
760264	752398	14073Q	PARTICIPANT	\N	PRESENT	0
760265	752398	14021P	PARTICIPANT	\N	PRESENT	0
760266	752398	19611R	PARTICIPANT	\N	PRESENT	0
760267	752398	20102Q	PARTICIPANT	\N	PRESENT	0
760268	752398	19699S	PARTICIPANT	\N	PRESENT	0
760269	752398	19697Q	PARTICIPANT	\N	PRESENT	0
760270	752398	08012N	PARTICIPANT	\N	PRESENT	0
760271	752398	21058J	PARTICIPANT	\N	PRESENT	0
760272	752398	21037D	PARTICIPANT	\N	PRESENT	0
760273	752398	21055F	PARTICIPANT	\N	PRESENT	0
760274	752398	19533U	PARTICIPANT	\N	PRESENT	0
760275	752398	21059K	PARTICIPANT	\N	PRESENT	0
760276	752398	11043H	PARTICIPANT	\N	PRESENT	0
760277	752398	20026V	PARTICIPANT	\N	PRESENT	0
760283	757799	21066J	PARTICIPANT	\N	PRESENT	0
760284	757799	14217N	PARTICIPANT	\N	PRESENT	0
760285	757799	19575F	PARTICIPANT	\N	PRESENT	0
760289	757799	21058J	PARTICIPANT	\N	PRESENT	0
760290	757799	21032X	PARTICIPANT	\N	PRESENT	0
760291	757799	14059S	PARTICIPANT	\N	PRESENT	0
760292	757799	14257W	PARTICIPANT	\N	PRESENT	0
760293	757799	19798U	PARTICIPANT	\N	PRESENT	0
760294	757799	21079P	PARTICIPANT	\N	PRESENT	0
760295	757799	08061X	PARTICIPANT	\N	PRESENT	0
760296	757799	20082E	PARTICIPANT	\N	PRESENT	0
760297	757799	14053L	PARTICIPANT	\N	PRESENT	0
760298	757799	19621T	PARTICIPANT	\N	PRESENT	0
760299	757799	21092L	PARTICIPANT	\N	PRESENT	0
760300	757799	21082J	PARTICIPANT	\N	PRESENT	0
760301	757799	20070A	PARTICIPANT	\N	PRESENT	0
760302	757799	20104S	PARTICIPANT	\N	PRESENT	0
760303	757799	20058E	PARTICIPANT	\N	PRESENT	0
760304	757799	14231L	PARTICIPANT	\N	PRESENT	0
760305	757799	08034U	PARTICIPANT	\N	PRESENT	0
760306	757799	19569H	PARTICIPANT	\N	PRESENT	0
760307	757799	20048C	PARTICIPANT	\N	PRESENT	0
760308	757799	17779H	PARTICIPANT	\N	PRESENT	0
760309	757799	14073Q	PARTICIPANT	\N	PRESENT	0
760310	757799	21070E	PARTICIPANT	\N	PRESENT	0
760311	757799	14147R	PARTICIPANT	\N	PRESENT	0
760312	757799	19533U	PARTICIPANT	\N	PRESENT	0
760313	757799	20142Y	PARTICIPANT	\N	PRESENT	0
760314	757799	20062A	PARTICIPANT	\N	PRESENT	0
760355	757800	19760E	PARTICIPANT	\N	PRESENT	0
760356	757800	21049H	PARTICIPANT	\N	PRESENT	0
760357	757800	19683J	PARTICIPANT	\N	PRESENT	0
760394	757800	14147R	PARTICIPANT	\N	PRESENT	0
760359	757800	18193Q	PARTICIPANT	\N	PRESENT	0
760360	757800	21046E	PARTICIPANT	\N	PRESENT	0
760361	757800	14071N	PARTICIPANT	\N	PRESENT	0
760362	757800	14213J	PARTICIPANT	\N	PRESENT	0
760363	757800	21064G	PARTICIPANT	\N	PRESENT	0
760364	757800	17965H	PARTICIPANT	\N	PRESENT	0
760365	757800	19691J	PARTICIPANT	\N	PRESENT	0
760366	757800	19866P	PARTICIPANT	\N	PRESENT	0
760367	757800	19569H	PARTICIPANT	\N	PRESENT	0
760368	757800	21087P	PARTICIPANT	\N	PRESENT	0
760369	757800	14195A	PARTICIPANT	\N	PRESENT	0
760370	757800	21097R	PARTICIPANT	\N	PRESENT	0
760371	757800	21094N	PARTICIPANT	\N	PRESENT	0
760372	757800	21043B	PARTICIPANT	\N	PRESENT	0
760373	757800	20110Q	PARTICIPANT	\N	PRESENT	0
760374	757800	19553Y	PARTICIPANT	\N	PRESENT	0
760375	757800	14217N	PARTICIPANT	\N	PRESENT	0
760376	757800	20090E	PARTICIPANT	\N	PRESENT	0
760377	757800	19798U	PARTICIPANT	\N	PRESENT	0
760378	757800	20062A	PARTICIPANT	\N	PRESENT	0
760379	757800	04092N	PARTICIPANT	\N	PRESENT	0
760380	757800	20148F	PARTICIPANT	\N	PRESENT	0
760381	757800	21058J	PARTICIPANT	\N	PRESENT	0
760382	757800	14033T	PARTICIPANT	\N	PRESENT	0
760383	757800	21081H	PARTICIPANT	\N	PRESENT	0
760384	757800	20132W	PARTICIPANT	\N	PRESENT	0
760385	757800	14207L	PARTICIPANT	\N	PRESENT	0
760386	757800	04045F	PARTICIPANT	\N	PRESENT	0
760387	757800	20032T	PARTICIPANT	\N	PRESENT	0
760388	757800	19703U	PARTICIPANT	\N	PRESENT	0
760389	757800	20180F	PARTICIPANT	\N	PRESENT	0
760390	757800	14042U	PARTICIPANT	\N	PRESENT	0
760391	757800	20092G	PARTICIPANT	\N	PRESENT	0
760392	757800	14089Y	PARTICIPANT	\N	PRESENT	0
760353	757800	19593H	PARTICIPANT	\N	PRESENT	0
760354	757800	19758L	PARTICIPANT	\N	PRESENT	0
760393	757800	14026U	PARTICIPANT	\N	PRESENT	0
760395	757800	14021P	PARTICIPANT	\N	PRESENT	0
760396	757800	19563B	PARTICIPANT	\N	PRESENT	0
760397	757800	20120S	PARTICIPANT	\N	PRESENT	0
760398	757800	19575F	PARTICIPANT	\N	PRESENT	0
760399	757800	21045D	PARTICIPANT	\N	PRESENT	0
760400	757800	20040T	PARTICIPANT	\N	PRESENT	0
760401	757800	19701S	PARTICIPANT	\N	PRESENT	0
760402	757800	11070L	PARTICIPANT	\N	PRESENT	0
760403	757800	19507S	PARTICIPANT	\N	PRESENT	0
760404	757800	17023S	PARTICIPANT	\N	PRESENT	0
760405	757800	14069U	PARTICIPANT	\N	PRESENT	0
760406	757800	14179A	PARTICIPANT	\N	PRESENT	0
740309	740141	14026U	PARTICIPANT	\N	PRESENT	0
740310	740141	11067R	PARTICIPANT	\N	PRESENT	0
740311	740141	20130U	PARTICIPANT	\N	PRESENT	0
740312	740141	11031D	PARTICIPANT	\N	PRESENT	0
740313	740141	19760E	PARTICIPANT	\N	PRESENT	0
743822	740643	20088L	PARTICIPANT	\N	PRESENT	0
743823	740643	19758L	PARTICIPANT	\N	PRESENT	0
743824	740643	20090E	PARTICIPANT	\N	PRESENT	0
743825	740643	20104S	PARTICIPANT	\N	PRESENT	0
743826	740643	20264J	PARTICIPANT	\N	PRESENT	0
743827	740643	20070A	PARTICIPANT	\N	PRESENT	0
743828	740643	20134Y	PARTICIPANT	\N	PRESENT	0
743829	740643	20132W	PARTICIPANT	\N	PRESENT	0
743830	740643	14211G	PARTICIPANT	\N	PRESENT	0
743831	740643	14123H	PARTICIPANT	\N	PRESENT	0
743832	740643	14021P	PARTICIPANT	\N	PRESENT	0
743833	740643	99004R	PARTICIPANT	\N	PRESENT	0
743834	740643	19611R	PARTICIPANT	\N	PRESENT	0
743835	740643	19711U	PARTICIPANT	\N	PRESENT	0
743836	740643	08012N	PARTICIPANT	\N	PRESENT	0
743837	740643	20030R	PARTICIPANT	\N	PRESENT	0
743838	740643	17965H	PARTICIPANT	\N	PRESENT	0
743839	740643	19503N	PARTICIPANT	\N	PRESENT	0
743841	740643	11043H	PARTICIPANT	\N	PRESENT	0
743842	740643	20062A	PARTICIPANT	\N	PRESENT	0
743843	740643	19301E	PARTICIPANT	\N	PRESENT	0
743845	740643	20026V	PARTICIPANT	\N	PRESENT	0
745766	744236	14026U	PARTICIPANT	\N	PRESENT	0
745767	744236	20130U	PARTICIPANT	\N	PRESENT	0
745768	744236	11067R	PARTICIPANT	\N	PRESENT	0
745769	744236	14281W	PARTICIPANT	\N	PRESENT	0
745770	744236	17965H	PARTICIPANT	\N	PRESENT	0
745784	744245	14026U	PARTICIPANT	\N	PRESENT	0
745796	744245	17965H	PARTICIPANT	\N	PRESENT	0
745797	744245	14281W	PARTICIPANT	\N	PRESENT	0
745865	745864	14259Y	PARTICIPANT	\N	PRESENT	0
746775	745858	14147R	PARTICIPANT	\N	EXCUSE	0
746776	745858	14219Q	PARTICIPANT	\N	EXCUSE	0
746777	745858	14331P	PARTICIPANT	\N	EXCUSE	0
746778	745858	11043H	PARTICIPANT	\N	EXCUSE	0
746779	745858	05008E	PARTICIPANT	\N	EXCUSE	0
746781	746780	20120S	PARTICIPANT	\N	PRESENT	0
746782	746780	14151M	PARTICIPANT	\N	PRESENT	0
746783	746780	08010L	PARTICIPANT	\N	PRESENT	0
746785	746784	20120S	PARTICIPANT	\N	PRESENT	0
746786	746784	08010L	PARTICIPANT	\N	PRESENT	0
749074	746959	19611R	PRESIDENT	0	PRESENT	0
749075	746959	19593H	PARTICIPANT	\N	PRESENT	0
749076	746959	19758L	PARTICIPANT	\N	PRESENT	0
749077	746959	20264J	PARTICIPANT	\N	PRESENT	0
749078	746959	20132W	PARTICIPANT	\N	PRESENT	0
749079	746959	19533U	PARTICIPANT	\N	PRESENT	0
749080	746959	20172F	PARTICIPANT	\N	PRESENT	0
749081	746959	14030Q	PARTICIPANT	\N	PRESENT	0
749082	746959	14073Q	PARTICIPANT	\N	PRESENT	0
749083	746959	20052X	PARTICIPANT	\N	PRESENT	0
749084	746959	20026V	PARTICIPANT	\N	PRESENT	0
749085	746959	20980G	PARTICIPANT	\N	PRESENT	0
749086	746959	19699S	PARTICIPANT	\N	PRESENT	0
749087	746959	20142Y	PARTICIPANT	\N	PRESENT	0
749089	746959	11043H	PARTICIPANT	\N	PRESENT	0
749091	746959	20124W	PARTICIPANT	\N	PRESENT	0
749092	746959	19693L	PARTICIPANT	\N	EXCUSE	0
749096	746959	14123H	PARTICIPANT	\N	PRESENT	0
749100	746959	20048C	PARTICIPANT	\N	PRESENT	0
749101	746959	04059M	PARTICIPANT	\N	PRESENT	0
749103	746959	20058E	PARTICIPANT	\N	PRESENT	0
749104	746959	19643A	PARTICIPANT	\N	PRESENT	0
749109	746959	04070G	PARTICIPANT	\N	PRESENT	0
749177	749176	20286Q	PARTICIPANT	\N	PRESENT	0
749178	749176	14033T	PARTICIPANT	\N	PRESENT	0
749179	749176	14001X	PARTICIPANT	\N	PRESENT	0
752696	752374	05012A	PARTICIPANT	\N	PRESENT	0
752697	752374	20130U	PARTICIPANT	\N	PRESENT	0
752698	752374	17965H	PARTICIPANT	\N	PRESENT	0
752699	752374	11090Q	PARTICIPANT	\N	PRESENT	0
752700	752374	19679N	PARTICIPANT	\N	PRESENT	0
752701	752374	19349W	PARTICIPANT	\N	PRESENT	0
752702	752374	14331P	PARTICIPANT	\N	PRESENT	0
752703	752374	14055N	PARTICIPANT	\N	PRESENT	0
752704	752374	14225N	PARTICIPANT	\N	PRESENT	0
752705	752374	20082E	PARTICIPANT	\N	PRESENT	0
752706	752374	10015M	PARTICIPANT	\N	PRESENT	0
752707	752374	19705W	PARTICIPANT	\N	PRESENT	0
752708	752374	04033B	PARTICIPANT	\N	PRESENT	0
752709	752374	21068L	PARTICIPANT	\N	PRESENT	0
752710	752374	21038E	PARTICIPANT	\N	PRESENT	0
752711	752374	19798U	PARTICIPANT	\N	PRESENT	0
752712	752374	20054A	PARTICIPANT	\N	PRESENT	0
752713	752374	14229S	PARTICIPANT	\N	PRESENT	0
752714	752374	21070E	PARTICIPANT	\N	PRESENT	0
752715	752374	20150Y	PARTICIPANT	\N	PRESENT	0
752716	752374	21056G	PARTICIPANT	\N	PRESENT	0
752717	752374	20020P	PARTICIPANT	\N	PRESENT	0
752718	752374	21064G	PARTICIPANT	\N	PRESENT	0
752719	752374	21059K	PARTICIPANT	\N	PRESENT	0
752720	752374	11045K	PARTICIPANT	\N	PRESENT	0
752721	752374	14107H	PARTICIPANT	\N	PRESENT	0
752722	752374	21036C	PARTICIPANT	\N	PRESENT	0
752723	752374	19619A	PARTICIPANT	\N	PRESENT	0
752724	752374	20092G	PARTICIPANT	\N	PRESENT	0
752725	752374	19421M	PARTICIPANT	\N	PRESENT	0
752726	752374	20044X	PARTICIPANT	\N	PRESENT	0
752727	752374	11043H	PARTICIPANT	\N	PRESENT	0
752728	752374	19687N	PARTICIPANT	\N	PRESENT	0
752729	752374	20098N	PARTICIPANT	\N	PRESENT	0
752730	752374	04045F	PARTICIPANT	\N	PRESENT	0
752731	752374	21079P	PARTICIPANT	\N	PRESENT	0
753651	753648	14255U	PARTICIPANT	\N	PRESENT	0
752733	752374	21049H	PARTICIPANT	\N	PRESENT	0
752734	752374	19703U	PARTICIPANT	\N	PRESENT	0
752735	752374	19713W	PARTICIPANT	\N	PRESENT	0
752736	752374	20062A	PARTICIPANT	\N	PRESENT	0
752738	752374	21094N	PARTICIPANT	\N	PRESENT	0
752739	752374	20084G	PARTICIPANT	\N	PRESENT	0
752740	752374	21069M	PARTICIPANT	\N	PRESENT	0
752741	752374	21095P	PARTICIPANT	\N	PRESENT	0
752742	752374	20136B	PARTICIPANT	\N	PRESENT	0
752743	752374	19669L	PARTICIPANT	\N	PRESENT	0
752744	752374	14275Y	PARTICIPANT	\N	PRESENT	0
752745	752374	19301E	PARTICIPANT	\N	PRESENT	0
752746	752374	19413M	PARTICIPANT	\N	PRESENT	0
752747	752374	21051B	PARTICIPANT	\N	PRESENT	0
752748	752374	21061D	PARTICIPANT	\N	PRESENT	0
752749	752374	20064C	PARTICIPANT	\N	PRESENT	0
752750	752374	01034P	PARTICIPANT	\N	PRESENT	0
752751	752374	20046A	PARTICIPANT	\N	PRESENT	0
752752	752374	21031W	PARTICIPANT	\N	PRESENT	0
752753	752374	20026V	PARTICIPANT	\N	PRESENT	0
752754	752374	19749K	PARTICIPANT	\N	PRESENT	0
752755	752374	19479G	PARTICIPANT	\N	PRESENT	0
752756	752374	20122U	PARTICIPANT	\N	PRESENT	0
752757	752374	20058E	PARTICIPANT	\N	PRESENT	0
752758	752374	14173T	PARTICIPANT	\N	PRESENT	0
752759	752374	21076L	PARTICIPANT	\N	PRESENT	0
752760	752374	20266L	PARTICIPANT	\N	PRESENT	0
752761	752374	19585H	PARTICIPANT	\N	PRESENT	0
752762	752374	21082J	PARTICIPANT	\N	PRESENT	0
752763	752374	21030V	PARTICIPANT	\N	PRESENT	0
752764	752374	21077M	PARTICIPANT	\N	PRESENT	0
752874	752374	21071F	PARTICIPANT	\N	PRESENT	0
752885	752374	14133K	PARTICIPANT	\N	PRESENT	0
753652	753648	11064N	PARTICIPANT	\N	PRESENT	0
753653	753648	20248J	PARTICIPANT	\N	PRESENT	0
753654	753648	20110Q	PARTICIPANT	\N	PRESENT	0
753655	753648	14237S	PARTICIPANT	\N	PRESENT	0
753656	753648	20056C	PARTICIPANT	\N	PRESENT	0
753657	753648	20066E	PARTICIPANT	\N	PRESENT	0
753672	752410	14147R	PARTICIPANT	\N	PRESENT	0
753673	752411	14147R	PARTICIPANT	\N	PRESENT	0
755777	753687	14133K	PARTICIPANT	\N	PRESENT	0
755778	753687	20094J	PARTICIPANT	\N	PRESENT	0
755779	753687	18395Y	PARTICIPANT	\N	PRESENT	0
755780	753687	20248J	PARTICIPANT	\N	PRESENT	0
755781	753687	20286Q	PARTICIPANT	\N	PRESENT	0
755782	753687	21078N	PARTICIPANT	\N	PRESENT	0
755783	753687	19709B	PARTICIPANT	\N	PRESENT	0
755784	753687	08034U	PARTICIPANT	\N	PRESENT	0
755785	753687	21054E	PARTICIPANT	\N	PRESENT	0
755786	753687	21037D	PARTICIPANT	\N	PRESENT	0
755787	753687	14331P	PRESIDENT	0	PRESENT	0
763018	761712	11056N	PARTICIPANT	\N	PRESENT	0
763019	761712	19575F	PARTICIPANT	\N	PRESENT	0
763020	761712	19573D	PARTICIPANT	\N	PRESENT	0
763021	761712	21051B	PARTICIPANT	\N	PRESENT	0
763022	761712	19347U	PARTICIPANT	\N	PRESENT	0
763026	761712	21047F	PARTICIPANT	\N	PRESENT	0
763024	761712	19768N	PARTICIPANT	\N	PRESENT	0
763025	761712	20252E	PARTICIPANT	\N	PRESENT	0
763027	761712	14193X	PARTICIPANT	\N	PRESENT	0
763028	761712	20060X	PARTICIPANT	\N	PRESENT	0
763400	761182	19335Q	PARTICIPANT	\N	EXCUSE	0
763408	763407	19691J	PARTICIPANT	\N	PRESENT	0
763409	763406	19691J	PARTICIPANT	\N	PRESENT	0
763410	763406	17965H	PARTICIPANT	\N	PRESENT	0
763504	763497	20034V	PARTICIPANT	\N	PRESENT	0
763710	763707	20034V	PARTICIPANT	\N	PRESENT	0
764319	764243	18083K	PARTICIPANT	\N	PRESENT	0
764320	764243	17023S	PARTICIPANT	\N	EXCUSE	0
764321	764243	14219Q	PARTICIPANT	\N	EXCUSE	0
764322	764243	19657G	PARTICIPANT	\N	EXCUSE	0
764323	764243	21029D	PARTICIPANT	\N	EXCUSE	0
764324	764243	19745F	PARTICIPANT	\N	EXCUSE	0
764325	764243	11090Q	PARTICIPANT	\N	EXCUSE	0
764326	764243	14275Y	PARTICIPANT	\N	EXCUSE	0
764327	764243	21030V	PARTICIPANT	\N	EXCUSE	0
765104	765102	14257W	PARTICIPANT	\N	PRESENT	0
765178	765177	19719D	PARTICIPANT	\N	PRESENT	0
766056	761974	19713W	PARTICIPANT	\N	PRESENT	0
765200	765163	14109K	PARTICIPANT	\N	PRESENT	0
765207	765163	21063F	PARTICIPANT	\N	PRESENT	0
765208	765163	14030Q	PARTICIPANT	\N	PRESENT	0
765317	765314	20090E	PARTICIPANT	\N	PRESENT	0
765318	765315	20090E	PARTICIPANT	\N	PRESENT	0
765319	765315	14071N	PARTICIPANT	\N	PRESENT	0
765320	765315	19798U	PARTICIPANT	\N	PRESENT	0
765321	765316	20090E	PARTICIPANT	\N	PRESENT	0
765414	761720	14229S	PARTICIPANT	\N	PRESENT	0
765415	761720	14055N	PARTICIPANT	\N	PRESENT	0
765450	761720	18395Y	PARTICIPANT	\N	PRESENT	0
765448	761720	21053D	PARTICIPANT	\N	PRESENT	0
765418	761720	20110Q	PARTICIPANT	\N	PRESENT	0
765449	761720	21040X	PARTICIPANT	\N	PRESENT	0
765420	761720	19649G	PARTICIPANT	\N	PRESENT	0
765421	761720	11045K	PARTICIPANT	\N	PRESENT	0
765428	761720	19629C	PARTICIPANT	\N	PRESENT	0
765429	761720	21058J	PARTICIPANT	\N	PRESENT	0
765430	761720	19697Q	PARTICIPANT	\N	PRESENT	0
765431	761720	19673G	PARTICIPANT	\N	PRESENT	0
765432	761720	20100N	PARTICIPANT	\N	PRESENT	0
765433	761720	19711U	PARTICIPANT	\N	PRESENT	0
765434	761720	19687N	PARTICIPANT	\N	PRESENT	0
765435	761720	04033B	PARTICIPANT	\N	PRESENT	0
765436	761720	19447X	PARTICIPANT	\N	PRESENT	0
765437	761720	14089Y	PARTICIPANT	\N	PRESENT	0
765438	761720	04047H	PARTICIPANT	\N	PRESENT	0
765439	761720	20062A	PARTICIPANT	\N	PRESENT	0
765440	761720	20052X	PARTICIPANT	\N	PRESENT	0
765441	761720	19111A	PARTICIPANT	\N	PRESENT	0
765442	761720	21038E	PARTICIPANT	\N	PRESENT	0
765443	761720	21089R	PARTICIPANT	\N	PRESENT	0
765444	761720	14037X	PARTICIPANT	\N	PRESENT	0
765445	761720	19387D	PARTICIPANT	\N	PRESENT	0
765446	761720	19693L	PARTICIPANT	\N	PRESENT	0
765447	761720	21090J	PARTICIPANT	\N	PRESENT	0
765451	761720	21088Q	PARTICIPANT	\N	PRESENT	0
765452	761720	18231D	PARTICIPANT	\N	PRESENT	0
765453	761720	21069M	PARTICIPANT	\N	PRESENT	0
765454	761720	18207D	PARTICIPANT	\N	PRESENT	0
765618	765617	20086J	PARTICIPANT	\N	PRESENT	0
765612	765611	20086J	PARTICIPANT	\N	PRESENT	0
765614	765613	20086J	PARTICIPANT	\N	PRESENT	0
765620	765619	20086J	PARTICIPANT	\N	PRESENT	0
765622	765621	20086J	PARTICIPANT	\N	PRESENT	0
765624	765623	20086J	PARTICIPANT	\N	PRESENT	0
765629	765627	20086J	PARTICIPANT	\N	PRESENT	0
765654	765653	20136B	PARTICIPANT	\N	PRESENT	0
765655	765653	19685L	PARTICIPANT	\N	PRESENT	0
765657	765656	20136B	PARTICIPANT	\N	PRESENT	0
765658	765656	19685L	PARTICIPANT	\N	PRESENT	0
765660	765659	19820Y	PARTICIPANT	\N	PRESENT	0
765690	765689	19399H	PARTICIPANT	\N	PRESENT	0
765694	765693	11074Q	PARTICIPANT	\N	PRESENT	0
765695	765693	19349W	PARTICIPANT	\N	PRESENT	0
766047	766044	19611R	PARTICIPANT	\N	PRESENT	0
766048	766045	14030Q	PARTICIPANT	\N	PRESENT	1
766049	766045	21089R	PARTICIPANT	\N	PRESENT	1
766050	766045	19611R	PARTICIPANT	\N	PRESENT	0
766102	765400	19649G	PARTICIPANT	\N	PRESENT	0
766103	765400	19489J	PARTICIPANT	\N	PRESENT	0
766104	765400	20090E	PARTICIPANT	\N	PRESENT	0
766105	765400	08047A	PARTICIPANT	\N	PRESENT	0
766106	765400	99004R	PARTICIPANT	\N	PRESENT	0
766107	765400	14253S	PARTICIPANT	\N	PRESENT	0
766108	765400	14038Y	PARTICIPANT	\N	PRESENT	0
766109	765400	19447X	PARTICIPANT	\N	PRESENT	0
766110	765400	19479G	PARTICIPANT	\N	PRESENT	0
766111	765400	14257W	PARTICIPANT	\N	PRESENT	0
766112	765400	19683J	PARTICIPANT	\N	PRESENT	0
766118	765400	19760E	PARTICIPANT	\N	PRESENT	0
766119	765400	21044C	PARTICIPANT	\N	PRESENT	0
766120	765400	20074E	PARTICIPANT	\N	PRESENT	0
766121	765400	19725B	PARTICIPANT	\N	PRESENT	0
766122	765400	21089R	PARTICIPANT	\N	PRESENT	0
766123	765400	08060W	PARTICIPANT	\N	PRESENT	0
766124	765400	11040E	PARTICIPANT	\N	PRESENT	0
766125	765400	19758L	PARTICIPANT	\N	PRESENT	0
766126	765400	19695N	PARTICIPANT	\N	PRESENT	0
766127	765400	21075K	PARTICIPANT	\N	PRESENT	0
766128	765400	19687N	PARTICIPANT	\N	PRESENT	0
766129	765400	18083K	PARTICIPANT	\N	PRESENT	0
766130	765400	21049H	PARTICIPANT	\N	PRESENT	0
766131	765400	20046A	PARTICIPANT	\N	PRESENT	0
766132	765400	04008A	PARTICIPANT	\N	PRESENT	0
766133	765400	20036X	PARTICIPANT	\N	PRESENT	0
766134	765400	19367Y	PARTICIPANT	\N	PRESENT	0
766135	765400	20092G	PARTICIPANT	\N	PRESENT	0
766136	765400	21091K	PARTICIPANT	\N	PRESENT	0
766137	765400	21073H	PARTICIPANT	\N	PRESENT	0
766138	765400	19347U	PARTICIPANT	\N	PRESENT	0
766139	765400	19575F	PARTICIPANT	\N	PRESENT	0
766140	765400	21093M	PARTICIPANT	\N	PRESENT	0
766141	765400	21079P	PARTICIPANT	\N	PRESENT	0
766142	765400	21037D	PARTICIPANT	\N	PRESENT	0
766143	765400	20134Y	PARTICIPANT	\N	PRESENT	0
766144	765400	14259Y	PARTICIPANT	\N	PRESENT	0
766145	765400	20100N	PARTICIPANT	\N	PRESENT	0
766146	765400	20096L	PARTICIPANT	\N	PRESENT	0
766147	765400	21094N	PARTICIPANT	\N	PRESENT	0
766148	765400	20110Q	PARTICIPANT	\N	PRESENT	0
766149	765400	04042C	PARTICIPANT	\N	PRESENT	0
766150	765400	14169X	PARTICIPANT	\N	PRESENT	0
766151	765400	21092L	PARTICIPANT	\N	PRESENT	0
766152	765400	21061D	PARTICIPANT	\N	PRESENT	0
766153	765400	19573D	PARTICIPANT	\N	PRESENT	0
766154	765400	10015M	PARTICIPANT	\N	PRESENT	0
766155	765400	20146D	PARTICIPANT	\N	PRESENT	0
766156	765400	08028W	PARTICIPANT	\N	PRESENT	0
766169	765400	19591F	PARTICIPANT	\N	PRESENT	0
766158	765400	19349W	PARTICIPANT	\N	PRESENT	0
766159	765400	19331L	PARTICIPANT	\N	PRESENT	0
766160	765400	21071F	PARTICIPANT	\N	PRESENT	0
766161	765400	21072G	PARTICIPANT	\N	PRESENT	0
766162	765400	20106U	PARTICIPANT	\N	PRESENT	0
766163	765400	14037X	PARTICIPANT	\N	PRESENT	0
766164	765400	19782L	PARTICIPANT	\N	PRESENT	0
766165	765400	21055F	PARTICIPANT	\N	PRESENT	0
766166	765400	19673G	PARTICIPANT	\N	PRESENT	0
766167	765400	21096Q	PARTICIPANT	\N	PRESENT	0
766168	765400	21029D	PARTICIPANT	\N	PRESENT	0
766170	765400	19711U	PARTICIPANT	\N	PRESENT	0
766171	765400	05012A	PARTICIPANT	\N	PRESENT	0
766172	765400	20016T	PARTICIPANT	\N	PRESENT	0
766173	765400	11090Q	PARTICIPANT	\N	PRESENT	0
766174	765400	14223L	PARTICIPANT	\N	PRESENT	0
766175	765400	19387D	PARTICIPANT	\N	PRESENT	0
766176	765400	21043B	PARTICIPANT	\N	PRESENT	0
766177	765400	21068L	PARTICIPANT	\N	PRESENT	0
739748	738007	14001X	PARTICIPANT	\N	PRESENT	0
739749	738007	20124W	PARTICIPANT	\N	PRESENT	0
739750	738007	19768N	PARTICIPANT	\N	PRESENT	0
739751	738007	20286Q	PARTICIPANT	\N	PRESENT	0
739752	738007	08018U	PARTICIPANT	\N	PRESENT	0
739753	738007	11109J	PARTICIPANT	\N	PRESENT	0
739763	738007	20094J	PARTICIPANT	\N	PRESENT	0
739755	738007	20112S	PARTICIPANT	\N	PRESENT	0
739757	738007	19705W	PARTICIPANT	\N	PRESENT	0
739758	738007	19758L	PARTICIPANT	\N	PRESENT	0
739764	738007	20066E	PARTICIPANT	\N	PRESENT	0
739765	738007	19707Y	PARTICIPANT	\N	PRESENT	0
739769	738007	20018V	PARTICIPANT	\N	PRESENT	0
739770	738007	14123H	PARTICIPANT	\N	PRESENT	0
739771	738007	20142Y	PARTICIPANT	\N	PRESENT	0
739772	738007	20136B	PARTICIPANT	\N	PRESENT	0
739779	738007	19697Q	PARTICIPANT	\N	PRESENT	0
740467	738260	19717B	PRESIDENT	0	PRESENT	1
740468	738260	20148F	PARTICIPANT	\N	PRESENT	0
740469	738260	14030Q	PARTICIPANT	\N	PRESENT	0
740470	738260	14147R	PARTICIPANT	\N	PRESENT	0
740473	738216	14331P	PRESIDENT	0	PRESENT	0
740474	738216	11083R	PARTICIPANT	\N	PRESENT	0
740475	738216	19441R	PARTICIPANT	\N	PRESENT	0
740476	738216	14073Q	PARTICIPANT	\N	PRESENT	0
740477	738216	11026G	PARTICIPANT	\N	PRESENT	0
740478	738216	14097Y	PARTICIPANT	\N	PRESENT	0
740479	738216	19711U	PARTICIPANT	\N	PRESENT	0
740508	738216	14001X	PARTICIPANT	\N	PRESENT	0
740509	738216	17737W	PARTICIPANT	\N	PRESENT	0
740526	738216	14089Y	PARTICIPANT	\N	PRESENT	0
740527	738216	14357A	PARTICIPANT	\N	EXCUSE	0
742527	740754	14179A	PARTICIPANT	\N	PRESENT	0
742583	740755	20110Q	PARTICIPANT	\N	PRESENT	0
742584	740755	14089Y	PARTICIPANT	\N	PRESENT	0
742585	740755	20108W	PARTICIPANT	\N	PRESENT	0
742586	740755	11026G	PARTICIPANT	\N	PRESENT	0
742587	740755	07004J	PARTICIPANT	\N	PRESENT	0
742588	740755	20114U	PARTICIPANT	\N	PRESENT	0
742589	740755	19729F	PARTICIPANT	\N	PRESENT	0
742590	740755	14231L	PARTICIPANT	\N	PRESENT	0
742591	740755	20022R	PARTICIPANT	\N	PRESENT	0
742592	740755	14215L	PARTICIPANT	\N	PRESENT	0
742593	740755	14069U	PARTICIPANT	\N	PRESENT	0
742594	740755	14147R	PARTICIPANT	\N	PRESENT	0
742595	740755	19543W	PARTICIPANT	\N	PRESENT	0
742596	740755	19489J	PARTICIPANT	\N	PRESENT	0
742597	740755	19301E	PARTICIPANT	\N	PRESENT	0
742598	740755	17737W	PARTICIPANT	\N	PRESENT	0
742599	740755	20074E	PARTICIPANT	\N	PRESENT	0
742600	740755	14111D	PARTICIPANT	\N	PRESENT	0
742601	740755	05008E	PARTICIPANT	\N	PRESENT	0
742602	740755	19725B	PARTICIPANT	\N	PRESENT	0
742603	740755	01028R	PARTICIPANT	\N	PRESENT	0
742604	740755	19447X	PARTICIPANT	\N	PRESENT	0
742605	740755	11056N	PARTICIPANT	\N	PRESENT	0
742606	740755	19673G	PARTICIPANT	\N	PRESENT	0
742607	740755	14021P	PARTICIPANT	\N	PRESENT	0
742608	740755	04047H	PRESIDENT	0	PRESENT	0
742609	740755	11085T	PARTICIPANT	\N	PRESENT	0
742610	740755	14259Y	PARTICIPANT	\N	PRESENT	0
742611	740755	04008A	PARTICIPANT	\N	PRESENT	0
742612	740755	11072N	PARTICIPANT	\N	PRESENT	0
742613	740755	14179A	PARTICIPANT	\N	PRESENT	0
742614	740755	14151M	PARTICIPANT	\N	PRESENT	0
742615	740755	14053L	PARTICIPANT	\N	PRESENT	0
742616	740755	95063L	PARTICIPANT	\N	PRESENT	0
742617	740755	04085P	PARTICIPANT	\N	PRESENT	0
742618	740755	11033F	PARTICIPANT	\N	PRESENT	0
742619	740755	10015M	PARTICIPANT	\N	PRESENT	0
744237	744204	14026U	PARTICIPANT	\N	PRESENT	0
744238	744204	20130U	PARTICIPANT	\N	PRESENT	0
744239	744204	18193Q	PARTICIPANT	\N	PRESENT	0
744240	744204	14281W	PARTICIPANT	\N	PRESENT	0
744241	744205	14026U	PARTICIPANT	\N	PRESENT	0
744242	744205	18193Q	PARTICIPANT	\N	PRESENT	0
744243	744205	14281W	PARTICIPANT	\N	PRESENT	0
744244	744205	20130U	PARTICIPANT	\N	PRESENT	0
744871	743950	97011G	PARTICIPANT	\N	EXCUSE	0
746113	741500	17737W	PARTICIPANT	\N	EXCUSE	0
746114	741500	20130U	PARTICIPANT	\N	EXCUSE	0
746115	741500	20046A	PARTICIPANT	\N	EXCUSE	0
746123	745791	20022R	PARTICIPANT	\N	PRESENT	0
746124	745791	11026G	PARTICIPANT	\N	PRESENT	0
746125	745791	08018U	PARTICIPANT	\N	PRESENT	0
746126	745791	95063L	PARTICIPANT	\N	PRESENT	0
746130	745791	14179A	PARTICIPANT	\N	PRESENT	0
746136	741500	20106U	PARTICIPANT	\N	EXCUSE	0
746337	741500	19681G	PARTICIPANT	\N	PRESENT	0
746365	741500	19749K	PARTICIPANT	\N	PRESENT	0
746375	741500	20066E	PARTICIPANT	\N	PRESENT	0
746376	741500	11031D	PARTICIPANT	\N	PRESENT	0
746378	741500	14109K	PARTICIPANT	\N	PRESENT	0
746379	741500	07029T	PARTICIPANT	\N	PRESENT	0
746380	741500	19798U	PARTICIPANT	\N	PRESENT	0
746381	741500	14030Q	PRESIDENT	0	PRESENT	0
746383	741500	11045K	PARTICIPANT	\N	PRESENT	0
746384	741500	14179A	PARTICIPANT	\N	PRESENT	0
746386	741500	19693L	PARTICIPANT	\N	PRESENT	0
746389	741500	20114U	PARTICIPANT	\N	PRESENT	0
749358	748107	11031D	PARTICIPANT	\N	PRESENT	0
749367	748107	11101A	PARTICIPANT	\N	PRESENT	0
749360	748107	20046A	PARTICIPANT	\N	PRESENT	0
749361	748107	19415P	PARTICIPANT	\N	PRESENT	0
749362	748107	11097X	PARTICIPANT	\N	PRESENT	0
749363	748107	11048N	PARTICIPANT	\N	PRESENT	0
749364	748107	04092N	PARTICIPANT	\N	PRESENT	0
749365	748107	08034U	PARTICIPANT	\N	PRESENT	0
749366	748107	20102Q	PARTICIPANT	\N	PRESENT	0
749368	748107	04047H	PARTICIPANT	\N	PRESENT	0
749369	748107	08015R	PARTICIPANT	\N	PRESENT	0
749370	748107	20134Y	PARTICIPANT	\N	PRESENT	0
749371	748107	19347U	PARTICIPANT	\N	PRESENT	0
749372	748107	11099A	PARTICIPANT	\N	PRESENT	0
749373	748107	20142Y	PARTICIPANT	\N	PRESENT	0
749374	748107	14187A	PARTICIPANT	\N	PRESENT	0
749375	748107	20130U	PARTICIPANT	\N	PRESENT	0
749376	748107	20092G	PARTICIPANT	\N	PRESENT	0
749377	748107	20266L	PARTICIPANT	\N	PRESENT	0
749378	748107	14237S	PARTICIPANT	\N	PRESENT	0
749379	748107	14215L	PARTICIPANT	\N	PRESENT	0
749380	748107	19651A	PARTICIPANT	\N	PRESENT	0
749381	748107	20044X	PARTICIPANT	\N	PRESENT	0
749382	748107	20038A	PARTICIPANT	\N	PRESENT	0
749383	748107	19782L	PARTICIPANT	\N	PRESENT	0
749384	748107	20106U	PARTICIPANT	\N	PRESENT	0
749385	748107	20128B	PARTICIPANT	\N	PRESENT	0
749386	748107	19591F	PARTICIPANT	\N	PRESENT	0
749388	748107	14037X	PARTICIPANT	\N	PRESENT	0
749389	748107	19697Q	PARTICIPANT	\N	PRESENT	0
749390	748107	11083R	PARTICIPANT	\N	PRESENT	0
749400	748107	20132W	PARTICIPANT	\N	PRESENT	0
749395	748107	11072N	PARTICIPANT	\N	PRESENT	0
749396	748107	08061X	PARTICIPANT	\N	PRESENT	0
749397	748107	95063L	PARTICIPANT	\N	PRESENT	0
749398	748107	19301E	PARTICIPANT	\N	PRESENT	0
749399	748107	20116W	PARTICIPANT	\N	PRESENT	0
749401	748107	19553Y	PARTICIPANT	\N	PRESENT	0
749402	748107	20072C	PARTICIPANT	\N	PRESENT	0
749403	748107	20056C	PARTICIPANT	\N	PRESENT	0
749404	748107	11012A	PARTICIPANT	\N	PRESENT	0
749405	748107	14211G	PARTICIPANT	\N	PRESENT	0
749406	748107	04057K	PARTICIPANT	\N	PRESENT	0
749407	748107	20050V	PARTICIPANT	\N	PRESENT	0
749408	748107	14251Q	PARTICIPANT	\N	PRESENT	0
749409	748107	20122U	PARTICIPANT	\N	PRESENT	0
749410	748107	11033F	PARTICIPANT	\N	PRESENT	0
749411	748107	19549D	PARTICIPANT	\N	PRESENT	0
749412	748107	20094J	PARTICIPANT	\N	PRESENT	0
749413	748107	08060W	PARTICIPANT	\N	PRESENT	0
749414	748107	14133K	PARTICIPANT	\N	PRESENT	0
749415	748107	20088L	PARTICIPANT	\N	PRESENT	0
749416	748107	20080C	PARTICIPANT	\N	PRESENT	0
749417	748107	20060X	PARTICIPANT	\N	PRESENT	0
749418	748107	20070A	PARTICIPANT	\N	PRESENT	0
749419	748107	19251M	PARTICIPANT	\N	PRESENT	0
749420	748107	14151M	PARTICIPANT	\N	PRESENT	0
749424	748107	19820Y	PARTICIPANT	\N	PRESENT	0
749422	748107	20264J	PARTICIPANT	\N	PRESENT	0
749423	748107	14281W	PARTICIPANT	\N	PRESENT	0
749425	748107	19725B	PARTICIPANT	\N	PRESENT	0
749426	748107	19333N	PARTICIPANT	\N	PRESENT	0
760407	757800	20058E	PARTICIPANT	\N	PRESENT	0
760408	757800	19531S	PARTICIPANT	\N	PRESENT	0
760409	757800	20094J	PARTICIPANT	\N	PRESENT	0
760410	757716	14033T	PARTICIPANT	\N	PRESENT	0
760411	757716	18207D	PARTICIPANT	\N	PRESENT	0
760428	757716	21049H	PARTICIPANT	\N	PRESENT	0
760413	757716	20042V	PARTICIPANT	\N	PRESENT	0
760414	757716	19701S	PARTICIPANT	\N	PRESENT	0
760415	757716	19569H	PARTICIPANT	\N	PRESENT	0
760416	757716	20100N	PARTICIPANT	\N	PRESENT	0
760417	757716	14073Q	PARTICIPANT	\N	PRESENT	0
760418	757716	20104S	PARTICIPANT	\N	PRESENT	0
760419	757716	14001X	PARTICIPANT	\N	PRESENT	0
760420	757716	20094J	PARTICIPANT	\N	PRESENT	0
760421	757716	19760E	PARTICIPANT	\N	PRESENT	0
760427	757716	19711U	PARTICIPANT	\N	PRESENT	0
760434	757716	20150Y	PARTICIPANT	\N	EXCUSE	0
760437	757716	14189C	PARTICIPANT	\N	EXCUSE	0
760438	757716	20286Q	PARTICIPANT	\N	EXCUSE	0
760481	757716	14357A	PARTICIPANT	\N	PRESENT	0
760482	757716	21076L	PARTICIPANT	\N	PRESENT	0
760504	757716	20248J	PARTICIPANT	\N	PRESENT	0
760505	757716	18395Y	PARTICIPANT	\N	PRESENT	0
760506	757716	14331P	PRESIDENT	0	PRESENT	0
760697	760696	86034E	PARTICIPANT	\N	PRESENT	0
760698	760696	19629C	PARTICIPANT	\N	PRESENT	0
760699	760696	11056N	PARTICIPANT	\N	PRESENT	0
760700	760696	14259Y	PARTICIPANT	\N	PRESENT	0
760701	760696	14187A	PARTICIPANT	\N	PRESENT	0
760702	760696	08018U	PARTICIPANT	\N	PRESENT	0
760703	760696	19347U	PARTICIPANT	\N	PRESENT	0
760704	760696	14179A	PARTICIPANT	\N	PRESENT	0
760705	760696	11048N	PARTICIPANT	\N	PRESENT	0
760706	760696	14021P	PARTICIPANT	\N	PRESENT	0
760707	760696	19611R	PARTICIPANT	\N	PRESENT	0
760708	760696	08010L	PARTICIPANT	\N	PRESENT	0
760709	760696	14037X	PARTICIPANT	\N	PRESENT	0
760710	760696	14219Q	PARTICIPANT	\N	PRESENT	0
760711	760696	14251Q	PARTICIPANT	\N	PRESENT	0
760712	760696	14111D	PARTICIPANT	\N	PRESENT	0
760713	760696	11085T	PARTICIPANT	\N	PRESENT	0
760714	760696	04070G	PARTICIPANT	\N	PRESENT	0
760715	760696	14071N	PARTICIPANT	\N	PRESENT	0
760716	760696	19593H	PARTICIPANT	\N	PRESENT	0
760717	760696	14193X	PARTICIPANT	\N	PRESENT	0
760718	760696	11090Q	PARTICIPANT	\N	PRESENT	0
760719	760696	14331P	PARTICIPANT	\N	PRESENT	0
760720	760696	14225N	PARTICIPANT	\N	PRESENT	0
760721	760696	04033B	PARTICIPANT	\N	PRESENT	0
760722	760696	14229S	PARTICIPANT	\N	PRESENT	0
760723	760696	21069M	PARTICIPANT	\N	PRESENT	0
760724	760696	19301E	PARTICIPANT	\N	PRESENT	0
760725	760696	19479G	PARTICIPANT	\N	PRESENT	0
760769	760766	19533U	PARTICIPANT	\N	PRESENT	1
760770	760766	20264J	PARTICIPANT	\N	PRESENT	1
760771	760767	20264J	PARTICIPANT	\N	PRESENT	1
760772	760767	19533U	PARTICIPANT	\N	PRESENT	0
760773	760768	19533U	PARTICIPANT	\N	PRESENT	0
760774	760426	14071N	PRESIDENT	0	PRESENT	0
760777	760775	14213J	PARTICIPANT	\N	PRESENT	0
760778	760776	14213J	PARTICIPANT	\N	PRESENT	0
760839	760838	20050V	PARTICIPANT	\N	PRESENT	0
760841	760840	20050V	PARTICIPANT	\N	PRESENT	0
760869	760868	19798U	PARTICIPANT	\N	PRESENT	0
761209	756449	20038A	PARTICIPANT	\N	PRESENT	0
761210	756453	20038A	PARTICIPANT	\N	PRESENT	0
761211	756453	14071N	PARTICIPANT	\N	PRESENT	0
761213	756453	19575F	PARTICIPANT	\N	PRESENT	0
761340	760765	18207D	PARTICIPANT	\N	EXCUSE	0
761729	761726	21076L	PARTICIPANT	\N	PRESENT	0
761730	761728	21076L	PARTICIPANT	\N	PRESENT	0
761731	761727	21076L	PARTICIPANT	\N	PRESENT	0
761733	761732	11056N	PARTICIPANT	\N	PRESENT	0
761789	761788	19563B	PARTICIPANT	\N	PRESENT	0
762248	762247	14205J	PARTICIPANT	\N	PRESENT	0
762250	762249	14205J	PARTICIPANT	\N	PRESENT	0
762252	762251	14205J	PARTICIPANT	\N	PRESENT	0
762682	762681	18083K	PARTICIPANT	\N	PRESENT	0
762684	762683	18083K	PARTICIPANT	\N	PRESENT	0
763062	761593	17965H	PARTICIPANT	\N	PRESENT	0
763063	761593	18193Q	PARTICIPANT	\N	EXCUSE	0
763064	761593	08061X	PARTICIPANT	\N	PRESENT	0
763065	761593	21094N	PARTICIPANT	\N	PRESENT	0
763066	761593	21064G	PARTICIPANT	\N	PRESENT	0
763067	761593	21071F	PARTICIPANT	\N	PRESENT	0
763070	761593	21049H	PARTICIPANT	\N	PRESENT	0
763159	763155	19729F	PARTICIPANT	\N	PRESENT	0
763160	763156	14189C	PARTICIPANT	\N	PRESENT	0
763161	763156	21057H	PARTICIPANT	\N	PRESENT	0
763163	763162	14189C	PARTICIPANT	\N	PRESENT	0
763180	761591	21031W	PARTICIPANT	\N	PRESENT	0
763181	761591	19565D	PARTICIPANT	\N	PRESENT	0
763182	761591	20072C	PARTICIPANT	\N	PRESENT	0
763183	761591	01058X	PARTICIPANT	\N	PRESENT	0
763184	761591	14001X	PARTICIPANT	\N	PRESENT	0
763185	761591	04042C	PARTICIPANT	\N	PRESENT	0
763186	761591	08056B	PARTICIPANT	\N	PRESENT	0
763187	761591	12028B	PARTICIPANT	\N	PRESENT	0
763188	761591	11115U	PARTICIPANT	\N	PRESENT	0
763189	761591	17737W	PARTICIPANT	\N	PRESENT	0
763190	761591	19421M	PARTICIPANT	\N	PRESENT	0
763191	761591	21067K	PARTICIPANT	\N	PRESENT	0
763192	761591	14193X	PRESIDENT	0	PRESENT	0
763193	761591	07033P	PARTICIPANT	\N	PRESENT	0
763194	761591	14249W	PARTICIPANT	\N	PRESENT	0
763195	761591	08047A	PARTICIPANT	\N	PRESENT	0
763196	761591	14037X	PARTICIPANT	\N	PRESENT	0
763197	761591	14059S	PARTICIPANT	\N	PRESENT	0
763198	761591	14097Y	PARTICIPANT	\N	PRESENT	0
763199	761591	19531S	PARTICIPANT	\N	PRESENT	0
763200	761591	08069G	PARTICIPANT	\N	PRESENT	0
763201	761591	20064C	PARTICIPANT	\N	PRESENT	0
763202	761591	20252E	PARTICIPANT	\N	PRESENT	0
763203	761591	98022P	PARTICIPANT	\N	PRESENT	0
763204	761591	14267Y	PARTICIPANT	\N	PRESENT	0
763205	761591	99004R	PARTICIPANT	\N	PRESENT	0
763206	761591	14255U	PARTICIPANT	\N	PRESENT	0
763207	761591	17023S	PARTICIPANT	\N	PRESENT	0
763208	761591	19745F	PARTICIPANT	\N	EXCUSE	0
763209	761591	14211G	PARTICIPANT	\N	EXCUSE	0
763210	761566	20074E	PARTICIPANT	\N	PRESENT	0
763211	761566	21057H	PARTICIPANT	\N	PRESENT	0
763212	761566	19585H	PARTICIPANT	\N	PRESENT	0
763213	761566	04047H	PRESIDENT	0	PRESENT	0
763214	761566	19673G	PARTICIPANT	\N	PRESENT	0
763215	761566	19447X	PARTICIPANT	\N	PRESENT	0
763216	761566	14231L	PARTICIPANT	\N	PRESENT	0
763217	761566	19489J	PARTICIPANT	\N	PRESENT	0
763218	761566	18207D	PARTICIPANT	\N	PRESENT	0
763219	761566	18231D	PARTICIPANT	\N	PRESENT	0
763220	761566	20110Q	PARTICIPANT	\N	PRESENT	0
763221	761566	21088Q	PARTICIPANT	\N	PRESENT	0
763222	761566	14147R	PARTICIPANT	\N	PRESENT	0
763223	761566	14151M	PARTICIPANT	\N	PRESENT	0
763224	761566	19111A	PARTICIPANT	\N	PRESENT	0
763225	761566	08018U	PARTICIPANT	\N	PRESENT	0
763226	761566	21038E	PARTICIPANT	\N	PRESENT	0
763227	761566	21095P	PARTICIPANT	\N	PRESENT	0
763228	761566	14259Y	PARTICIPANT	\N	PRESENT	0
763229	761566	14053L	PARTICIPANT	\N	PRESENT	0
763230	761566	14111D	PARTICIPANT	\N	PRESENT	0
763231	761566	14189C	PARTICIPANT	\N	PRESENT	0
763232	761566	10015M	PARTICIPANT	\N	PRESENT	0
763233	761566	21040X	PARTICIPANT	\N	PRESENT	0
763234	761566	21043B	PARTICIPANT	\N	PRESENT	0
763235	761566	14089Y	PARTICIPANT	\N	PRESENT	0
763236	761566	19725B	PARTICIPANT	\N	PRESENT	0
763237	761566	11056N	PARTICIPANT	\N	PRESENT	0
763238	761566	21044C	PARTICIPANT	\N	PRESENT	0
763239	761566	20266L	PARTICIPANT	\N	PRESENT	0
763240	761566	14069U	PARTICIPANT	\N	PRESENT	0
763241	761566	11085T	PARTICIPANT	\N	PRESENT	0
763242	761566	04008A	PARTICIPANT	\N	PRESENT	0
763246	761566	05008E	PARTICIPANT	\N	PRESENT	0
763248	762589	21093M	PARTICIPANT	\N	PRESENT	0
763249	761566	21056G	PARTICIPANT	\N	PRESENT	0
763250	757841	20098N	PARTICIPANT	\N	EXCUSE	0
763251	757841	21089R	PARTICIPANT	\N	PRESENT	0
763252	757842	20098N	PARTICIPANT	\N	EXCUSE	0
763254	761747	20076G	PARTICIPANT	\N	PRESENT	0
763255	761747	21042A	PARTICIPANT	\N	PRESENT	0
740814	740813	19673G	PARTICIPANT	\N	PRESENT	0
740815	740813	20056C	PARTICIPANT	\N	PRESENT	0
740816	740813	20066E	PARTICIPANT	\N	PRESENT	0
740820	740818	10006L	PARTICIPANT	\N	PRESENT	0
740821	740818	11097X	PARTICIPANT	\N	PRESENT	0
740822	740819	10006L	PARTICIPANT	\N	PRESENT	0
740823	740819	11097X	PARTICIPANT	\N	PRESENT	0
740824	740817	19415P	PARTICIPANT	\N	PRESENT	0
740826	740825	14255U	PARTICIPANT	\N	PRESENT	0
744183	744178	14026U	PARTICIPANT	\N	PRESENT	0
744184	744178	14281W	PARTICIPANT	\N	PRESENT	0
744185	744178	20130U	PARTICIPANT	\N	PRESENT	0
744186	744178	18193Q	PARTICIPANT	\N	PRESENT	0
744187	744179	14026U	PARTICIPANT	\N	PRESENT	0
744188	744179	14281W	PARTICIPANT	\N	PRESENT	0
744189	744179	20130U	PARTICIPANT	\N	PRESENT	0
744190	744180	14026U	PARTICIPANT	\N	PRESENT	0
744191	744180	18193Q	PARTICIPANT	\N	PRESENT	0
744192	744181	14026U	PARTICIPANT	\N	PRESENT	0
744193	744181	18193Q	PARTICIPANT	\N	PRESENT	0
744194	744181	20130U	PARTICIPANT	\N	PRESENT	0
744195	744181	17965H	PARTICIPANT	\N	PRESENT	0
744196	744182	14026U	PARTICIPANT	\N	PRESENT	0
744197	744182	20130U	PARTICIPANT	\N	PRESENT	0
744198	744182	17965H	PARTICIPANT	\N	PRESENT	0
744199	744182	18193Q	PARTICIPANT	\N	PRESENT	0
744200	744182	14071N	PARTICIPANT	\N	PRESENT	0
746215	746195	19575F	PARTICIPANT	\N	PRESENT	0
746217	746195	14069U	PARTICIPANT	\N	PRESENT	0
746218	746195	19721W	PARTICIPANT	\N	PRESENT	0
746219	746195	20038A	PARTICIPANT	\N	PRESENT	0
746220	746195	14033T	PARTICIPANT	\N	PRESENT	0
746221	746195	14031R	PARTICIPANT	\N	PRESENT	0
746222	746195	14071N	PARTICIPANT	\N	PRESENT	0
746223	746195	19533U	PARTICIPANT	\N	PRESENT	0
746225	746195	19503N	PARTICIPANT	\N	PRESENT	0
746226	746195	20092G	PARTICIPANT	\N	PRESENT	0
746227	746195	20062A	PARTICIPANT	\N	PRESENT	0
755788	753687	10015M	PARTICIPANT	\N	PRESENT	0
755789	753687	20150Y	PARTICIPANT	\N	PRESENT	0
755790	753687	21076L	PARTICIPANT	\N	PRESENT	0
755791	753687	17737W	PARTICIPANT	\N	EXCUSE	0
755792	753687	20104S	PARTICIPANT	\N	EXCUSE	0
755793	753687	19701S	PARTICIPANT	\N	EXCUSE	0
755794	753687	14033T	PARTICIPANT	\N	EXCUSE	0
755795	753687	04070G	PARTICIPANT	\N	EXCUSE	0
755796	753687	14237S	PARTICIPANT	\N	EXCUSE	0
755797	753687	20100N	PARTICIPANT	\N	PRESENT	0
755961	755960	20058E	PARTICIPANT	\N	PRESENT	1
755962	755960	14229S	PARTICIPANT	\N	PRESENT	1
755963	755960	20264J	PARTICIPANT	\N	PRESENT	1
755964	755960	21037D	PARTICIPANT	\N	PRESENT	1
755966	755965	20058E	PARTICIPANT	\N	PRESENT	1
755967	755965	20264J	PARTICIPANT	\N	PRESENT	1
755968	755965	21037D	PARTICIPANT	\N	PRESENT	1
756022	756015	14213J	PARTICIPANT	\N	PRESENT	0
756023	756015	08045X	PARTICIPANT	\N	PRESENT	0
756024	756015	20096L	PARTICIPANT	\N	PRESENT	0
756025	756015	14071N	PARTICIPANT	\N	PRESENT	0
756026	756015	21094N	PARTICIPANT	\N	PRESENT	0
756027	756014	14213J	PARTICIPANT	\N	PRESENT	0
756028	756014	19553Y	PARTICIPANT	\N	PRESENT	0
756029	756014	21081H	PARTICIPANT	\N	PRESENT	0
756030	756014	18193Q	PARTICIPANT	\N	PRESENT	0
756031	756014	19683J	PARTICIPANT	\N	PRESENT	0
756032	756014	19703U	PARTICIPANT	\N	PRESENT	0
756033	756014	21094N	PARTICIPANT	\N	PRESENT	0
756034	756014	14223L	PARTICIPANT	\N	PRESENT	0
756035	756014	14071N	PARTICIPANT	\N	PRESENT	0
756036	756014	04092N	PARTICIPANT	\N	PRESENT	0
756037	756014	19758L	PARTICIPANT	\N	PRESENT	0
756038	756014	20130U	PARTICIPANT	\N	PRESENT	0
756039	756014	17965H	PARTICIPANT	\N	PRESENT	0
756040	756017	21081H	PARTICIPANT	\N	PRESENT	0
756041	756017	14213J	PARTICIPANT	\N	PRESENT	0
756042	756017	19553Y	PARTICIPANT	\N	PRESENT	0
756043	756017	20130U	PARTICIPANT	\N	PRESENT	0
756044	756017	17965H	PARTICIPANT	\N	PRESENT	0
756045	756017	19703U	PARTICIPANT	\N	PRESENT	0
756046	756017	04092N	PARTICIPANT	\N	PRESENT	0
756047	756021	14213J	PARTICIPANT	\N	PRESENT	0
756048	756021	18193Q	PARTICIPANT	\N	PRESENT	0
756049	756018	14213J	PARTICIPANT	\N	PRESENT	0
756050	756018	19553Y	PARTICIPANT	\N	PRESENT	0
756051	756018	14195A	PARTICIPANT	\N	PRESENT	0
756052	756018	20140W	PARTICIPANT	\N	PRESENT	0
756053	756018	19703U	PARTICIPANT	\N	PRESENT	0
756054	756018	20096L	PARTICIPANT	\N	PRESENT	0
756055	756018	14071N	PARTICIPANT	\N	PRESENT	0
756056	756018	20130U	PARTICIPANT	\N	PRESENT	0
756057	756018	21087P	PARTICIPANT	\N	PRESENT	0
756058	756019	19758L	PARTICIPANT	\N	PRESENT	0
756059	756019	14213J	PARTICIPANT	\N	PRESENT	0
756060	756019	19683J	PARTICIPANT	\N	PRESENT	0
756061	756019	14042U	PARTICIPANT	\N	PRESENT	0
756062	756019	21081H	PARTICIPANT	\N	PRESENT	0
756063	756019	14026U	PARTICIPANT	\N	PRESENT	0
756064	756019	21046E	PARTICIPANT	\N	PRESENT	0
756065	756019	18193Q	PARTICIPANT	\N	PRESENT	0
756066	756019	04092N	PARTICIPANT	\N	PRESENT	0
756067	756019	20130U	PARTICIPANT	\N	PRESENT	0
756068	756019	21094N	PARTICIPANT	\N	PRESENT	0
756167	756165	14189C	PARTICIPANT	\N	PRESENT	1
756207	755921	19573D	PARTICIPANT	\N	PRESENT	0
756171	756165	20266L	PARTICIPANT	\N	PRESENT	0
756206	755921	20134Y	PARTICIPANT	\N	PRESENT	0
756266	755424	19703U	PARTICIPANT	\N	EXCUSE	0
756456	756314	08012N	PARTICIPANT	\N	PRESENT	0
756457	756314	11043H	PARTICIPANT	\N	PRESENT	1
756461	756460	20172F	PARTICIPANT	\N	PRESENT	0
756462	756460	19593H	PARTICIPANT	\N	PRESENT	0
756467	756466	20058E	PARTICIPANT	\N	PRESENT	0
756485	756466	21037D	PARTICIPANT	\N	PRESENT	0
756469	756466	14030Q	PARTICIPANT	\N	PRESENT	1
756470	756466	20102Q	PARTICIPANT	\N	PRESENT	0
756519	756517	20058E	PARTICIPANT	\N	PRESENT	0
756526	756525	12028B	PARTICIPANT	\N	PRESENT	0
756527	756525	14267Y	PARTICIPANT	\N	PRESENT	0
756528	756525	08010L	PARTICIPANT	\N	PRESENT	0
757719	757717	14042U	PARTICIPANT	\N	PRESENT	0
757720	757717	14213J	PARTICIPANT	\N	PRESENT	0
757721	757717	19569H	PARTICIPANT	\N	PRESENT	0
757722	757718	14042U	PARTICIPANT	\N	PRESENT	0
757723	757718	19569H	PARTICIPANT	\N	PRESENT	0
757724	757718	14213J	PARTICIPANT	\N	PRESENT	0
757725	756326	19569H	PARTICIPANT	\N	PRESENT	0
757726	756327	19569H	PARTICIPANT	\N	PRESENT	0
757729	757727	20124W	PARTICIPANT	\N	PRESENT	0
757730	757728	20124W	PARTICIPANT	\N	PRESENT	0
757731	757728	14109K	PARTICIPANT	\N	PRESENT	0
757732	757728	19735D	PARTICIPANT	\N	PRESENT	0
757739	757736	19611R	PARTICIPANT	\N	PRESENT	0
757740	757737	19611R	PARTICIPANT	\N	PRESENT	0
757767	757766	08010L	PARTICIPANT	\N	PRESENT	0
757831	757736	19621T	PARTICIPANT	\N	PRESENT	1
757832	757737	19621T	PARTICIPANT	\N	PRESENT	1
758150	758149	14215L	PARTICIPANT	\N	PRESENT	0
758165	758164	05008E	PARTICIPANT	\N	PRESENT	0
758166	758164	11053K	PARTICIPANT	\N	PRESENT	0
758167	758164	01028R	PARTICIPANT	\N	PRESENT	0
758183	757692	21039F	PARTICIPANT	\N	PRESENT	0
758184	757692	19798U	PARTICIPANT	\N	PRESENT	0
758185	757692	14042U	PARTICIPANT	\N	PRESENT	0
758186	757692	19713W	PARTICIPANT	\N	PRESENT	0
758187	757692	20140W	PARTICIPANT	\N	PRESENT	0
758189	757692	14223L	PARTICIPANT	\N	PRESENT	0
758191	757692	14217N	PARTICIPANT	\N	PRESENT	0
758193	757692	21087P	PARTICIPANT	\N	PRESENT	0
758194	757692	21081H	PARTICIPANT	\N	PRESENT	0
758195	757692	21046E	PARTICIPANT	\N	PRESENT	0
758196	757692	14071N	PRESIDENT	0	PRESENT	0
758197	757692	21045D	PARTICIPANT	\N	EXCUSE	0
758198	757692	20248J	PARTICIPANT	\N	PRESENT	0
758199	757692	19703U	PARTICIPANT	\N	EXCUSE	0
758200	757692	19553Y	PARTICIPANT	\N	PRESENT	0
758201	757692	19683J	PARTICIPANT	\N	PRESENT	0
758202	757692	20096L	PARTICIPANT	\N	PRESENT	0
758203	757692	04092N	PARTICIPANT	\N	PRESENT	0
758204	757692	17965H	PARTICIPANT	\N	PRESENT	0
758205	757692	21071F	PARTICIPANT	\N	PRESENT	0
758206	757692	19758L	PARTICIPANT	\N	PRESENT	0
766178	765400	08061X	PARTICIPANT	\N	PRESENT	0
766179	765400	21058J	PARTICIPANT	\N	PRESENT	0
766180	765400	20122U	PARTICIPANT	\N	PRESENT	0
766181	765400	20180F	PARTICIPANT	\N	PRESENT	0
766182	765400	14195A	PARTICIPANT	\N	PRESENT	0
766183	765400	19667J	PARTICIPANT	\N	PRESENT	0
766184	765400	21046E	PARTICIPANT	\N	PRESENT	0
766185	765400	19421M	PARTICIPANT	\N	PRESENT	0
766186	765400	19545Y	PARTICIPANT	\N	PRESENT	0
766187	765400	14111D	PARTICIPANT	\N	PRESENT	0
766188	765400	20032T	PARTICIPANT	\N	PRESENT	0
766189	765400	19585H	PARTICIPANT	\N	PRESENT	0
766190	765400	19693L	PARTICIPANT	\N	PRESENT	0
766191	765400	19954N	PARTICIPANT	\N	PRESENT	0
766192	765400	21065H	PARTICIPANT	\N	PRESENT	0
766193	765400	21081H	PARTICIPANT	\N	PRESENT	0
766194	765400	20050V	PARTICIPANT	\N	PRESENT	0
766195	765400	14221J	PARTICIPANT	\N	PRESENT	0
766196	765400	20138D	PARTICIPANT	\N	PRESENT	0
766197	765400	20172F	PARTICIPANT	\N	PRESENT	0
766198	765400	21054E	PARTICIPANT	\N	PRESENT	0
766199	765400	20034V	PARTICIPANT	\N	PRESENT	0
766200	765400	14207L	PARTICIPANT	\N	PRESENT	0
766201	765400	19723Y	PARTICIPANT	\N	PRESENT	0
766202	765400	98022P	PARTICIPANT	\N	PRESENT	0
766203	765400	21047F	PARTICIPANT	\N	PRESENT	0
766204	765400	21066J	PARTICIPANT	\N	PRESENT	0
766205	765400	19533U	PARTICIPANT	\N	PRESENT	0
766206	765400	20072C	PARTICIPANT	\N	PRESENT	0
766207	765400	21078N	PARTICIPANT	\N	PRESENT	0
766208	765400	19866P	PARTICIPANT	\N	PRESENT	0
766209	765400	20140W	PARTICIPANT	\N	PRESENT	0
766210	765400	21040X	PARTICIPANT	\N	PRESENT	0
766211	765400	14033T	PARTICIPANT	\N	PRESENT	0
766212	765400	20132W	PARTICIPANT	\N	PRESENT	0
766213	765400	20056C	PARTICIPANT	\N	PRESENT	0
766214	765400	19719D	PARTICIPANT	\N	PRESENT	0
766215	765400	19399H	PARTICIPANT	\N	PRESENT	0
766216	765400	17737W	PARTICIPANT	\N	PRESENT	0
766217	765400	20068G	PARTICIPANT	\N	PRESENT	0
766218	765400	21063F	PARTICIPANT	\N	PRESENT	0
766219	765400	11043H	PARTICIPANT	\N	PRESENT	0
766220	765400	19647E	PARTICIPANT	\N	PRESENT	0
766221	765400	14026U	PARTICIPANT	\N	PRESENT	0
766222	765400	20116W	PARTICIPANT	\N	PRESENT	0
766223	765400	19709B	PARTICIPANT	\N	PRESENT	0
766224	765400	08018U	PARTICIPANT	\N	PRESENT	0
766225	765400	19657G	PARTICIPANT	\N	PRESENT	0
766226	765400	14251Q	PARTICIPANT	\N	PRESENT	0
766227	765400	07029T	PARTICIPANT	\N	PRESENT	0
766228	765400	19631V	PARTICIPANT	\N	PRESENT	0
766229	765400	20094J	PARTICIPANT	\N	PRESENT	0
766230	765400	20104S	PARTICIPANT	\N	PRESENT	0
766231	765400	20148F	PARTICIPANT	\N	PRESENT	0
766232	765400	20114U	PARTICIPANT	\N	PRESENT	0
766233	765400	21036C	PARTICIPANT	\N	PRESENT	0
766234	765400	19705W	PARTICIPANT	\N	PRESENT	0
766235	765400	21045D	PARTICIPANT	\N	PRESENT	0
766236	765400	12028B	PARTICIPANT	\N	PRESENT	0
766237	765400	20112S	PARTICIPANT	\N	PRESENT	0
766238	765400	21084L	PARTICIPANT	\N	PRESENT	0
766239	765400	21088Q	PARTICIPANT	\N	PRESENT	0
766240	765400	14213J	PARTICIPANT	\N	PRESENT	0
766241	765400	14059S	PARTICIPANT	\N	PRESENT	0
766242	765400	20054A	PARTICIPANT	\N	PRESENT	0
766243	765400	14329V	PARTICIPANT	\N	PRESENT	0
766244	765400	14357A	PARTICIPANT	\N	PRESENT	0
766245	765400	20070A	PARTICIPANT	\N	PRESENT	0
766246	765400	20264J	PARTICIPANT	\N	PRESENT	0
766247	765400	20086J	PARTICIPANT	\N	PRESENT	0
766248	765400	11027H	PARTICIPANT	\N	PRESENT	0
766249	765400	20020P	PARTICIPANT	\N	PRESENT	0
766250	765400	20098N	PARTICIPANT	\N	PRESENT	0
766251	765400	21095P	PARTICIPANT	\N	PRESENT	0
766252	765400	18395Y	PARTICIPANT	\N	PRESENT	0
766253	765400	19251M	PARTICIPANT	\N	PRESENT	0
766254	765400	14217N	PARTICIPANT	\N	PRESENT	0
766255	765400	20120S	PARTICIPANT	\N	PRESENT	0
766256	765400	14151M	PARTICIPANT	\N	PRESENT	0
766257	765400	20252E	PARTICIPANT	\N	PRESENT	0
766258	765400	11074Q	PARTICIPANT	\N	PRESENT	0
766259	765400	21062E	PARTICIPANT	\N	PRESENT	0
766260	765400	14281W	PARTICIPANT	\N	PRESENT	0
766261	765400	19820Y	PARTICIPANT	\N	PRESENT	0
766262	765400	20118Y	PARTICIPANT	\N	PRESENT	0
766263	765400	14069U	PARTICIPANT	\N	PRESENT	0
766264	765400	14121F	PARTICIPANT	\N	PRESENT	0
766265	765400	14071N	PARTICIPANT	\N	PRESENT	0
766266	765400	19701S	PARTICIPANT	\N	PRESENT	0
766267	765400	14097Y	PARTICIPANT	\N	PRESENT	0
766268	765400	14053L	PARTICIPANT	\N	PRESENT	0
766269	765400	19531S	PARTICIPANT	\N	PRESENT	0
766270	765400	19679N	PARTICIPANT	\N	PRESENT	0
766271	765400	04033B	PARTICIPANT	\N	PRESENT	0
766272	765400	08012N	PARTICIPANT	\N	PRESENT	0
766273	765400	20062A	PARTICIPANT	\N	PRESENT	0
766274	765400	17779H	PARTICIPANT	\N	PRESENT	0
766275	765400	05008E	PARTICIPANT	\N	PRESENT	0
766276	765400	04092N	PARTICIPANT	\N	PRESENT	0
766277	765400	14001X	PARTICIPANT	\N	PRESENT	0
766278	765400	14133K	PARTICIPANT	\N	PRESENT	0
766279	765400	20028X	PARTICIPANT	\N	PRESENT	0
766280	765400	01058X	PARTICIPANT	\N	PRESENT	0
766281	765400	19703U	PARTICIPANT	\N	PRESENT	0
766282	765400	21097R	PARTICIPANT	\N	PRESENT	0
766283	765400	14109K	PARTICIPANT	\N	PRESENT	0
766284	765400	18231D	PARTICIPANT	\N	PRESENT	0
766285	765400	17965H	PARTICIPANT	\N	PRESENT	0
766286	765400	21060C	PARTICIPANT	\N	PRESENT	0
766287	765400	14355X	PARTICIPANT	\N	PRESENT	0
766288	765400	20030R	PARTICIPANT	\N	PRESENT	0
766289	765400	20082E	PARTICIPANT	\N	PRESENT	0
766290	765400	20024T	PARTICIPANT	\N	PRESENT	0
766291	765400	14225N	PARTICIPANT	\N	PRESENT	0
766292	765400	14229S	PARTICIPANT	\N	PRESENT	0
766293	765400	11045K	PARTICIPANT	\N	PRESENT	0
766294	765400	21059K	PARTICIPANT	\N	PRESENT	0
766295	765400	08056B	PARTICIPANT	\N	PRESENT	0
766296	765400	19669L	PARTICIPANT	\N	PRESENT	0
766297	765400	20084G	PARTICIPANT	\N	PRESENT	0
766298	765400	21051B	PARTICIPANT	\N	PRESENT	0
766299	765400	21031W	PARTICIPANT	\N	PRESENT	0
766300	765400	04047H	PARTICIPANT	\N	PRESENT	0
766301	765400	21077M	PARTICIPANT	\N	PRESENT	0
766302	765400	21082J	PARTICIPANT	\N	PRESENT	0
766303	765400	08015R	PARTICIPANT	\N	PRESENT	0
766304	765400	14030Q	PARTICIPANT	\N	PRESENT	0
766305	765400	21042A	PARTICIPANT	\N	PRESENT	0
766306	765400	21050A	PARTICIPANT	\N	PRESENT	0
766307	765400	19553Y	PARTICIPANT	\N	PRESENT	0
766308	765400	20076G	PARTICIPANT	\N	PRESENT	0
766309	765400	21069M	PARTICIPANT	\N	PRESENT	0
766310	765400	14255U	PARTICIPANT	\N	PRESENT	0
766311	765400	21083K	PARTICIPANT	\N	PRESENT	0
766312	765400	11064N	PARTICIPANT	\N	PRESENT	0
766313	765400	20248J	PARTICIPANT	\N	PRESENT	0
766314	765400	20066E	PARTICIPANT	\N	PRESENT	0
766315	765400	19826F	PARTICIPANT	\N	PRESENT	0
766316	765400	21053D	PARTICIPANT	\N	PRESENT	0
766317	765400	21086N	PARTICIPANT	\N	PRESENT	0
766318	765400	21038E	PARTICIPANT	\N	PRESENT	0
766319	765400	08010L	PARTICIPANT	\N	PRESENT	0
766320	765400	07004J	PARTICIPANT	\N	PRESENT	0
766333	765400	19611R	PARTICIPANT	\N	PRESENT	0
766322	765400	15197G	PARTICIPANT	\N	PRESENT	0
766323	765400	14267Y	PARTICIPANT	\N	PRESENT	0
766324	765400	19685L	PARTICIPANT	\N	PRESENT	0
766325	765400	21064G	PARTICIPANT	\N	PRESENT	0
766326	765400	14327T	PARTICIPANT	\N	PRESENT	0
766327	765400	19691J	PARTICIPANT	\N	PRESENT	0
766328	765400	14083S	PARTICIPANT	\N	PRESENT	0
766329	765400	14205J	PARTICIPANT	\N	PRESENT	0
766330	765400	04070G	PARTICIPANT	\N	PRESENT	0
766331	765400	14179A	PARTICIPANT	\N	PRESENT	0
766332	765400	19699S	PARTICIPANT	\N	PRESENT	0
766334	765400	14237S	PARTICIPANT	\N	PRESENT	0
766335	765400	19569H	PARTICIPANT	\N	PRESENT	0
766336	765400	14189C	PARTICIPANT	\N	PRESENT	0
766337	765400	19111A	PARTICIPANT	\N	PRESENT	0
766338	765400	14231L	PARTICIPANT	\N	PRESENT	0
766339	765400	19798U	PARTICIPANT	\N	PRESENT	0
766340	765400	17229F	PARTICIPANT	\N	PRESENT	0
766341	765400	19721W	PARTICIPANT	\N	PRESENT	0
766342	765400	20126Y	PARTICIPANT	\N	PRESENT	0
766343	765400	20052X	PARTICIPANT	\N	PRESENT	0
739768	739766	11066Q	PARTICIPANT	\N	PRESENT	0
739782	738847	19629C	PRESIDENT	0	PRESENT	0
739783	738757	14237S	PARTICIPANT	\N	EXCUSE	0
740091	738847	11056N	PARTICIPANT	\N	PRESENT	0
740110	738847	14329V	PARTICIPANT	\N	PRESENT	0
740115	738847	20172F	PARTICIPANT	\N	PRESENT	0
740126	738847	19703U	PARTICIPANT	\N	PRESENT	0
740139	738847	20248J	PARTICIPANT	\N	PRESENT	0
742056	742055	20112S	PARTICIPANT	\N	PRESENT	0
742057	742055	10015M	PARTICIPANT	\N	PRESENT	0
742165	742164	08018U	PARTICIPANT	\N	PRESENT	0
742166	742164	20114U	PARTICIPANT	\N	PRESENT	0
744079	744078	14033T	PARTICIPANT	\N	PRESENT	0
744080	744078	14205J	PARTICIPANT	\N	PRESENT	0
744081	744078	20054A	PARTICIPANT	\N	PRESENT	0
744083	744082	14033T	PARTICIPANT	\N	PRESENT	0
744084	744082	14205J	PARTICIPANT	\N	PRESENT	0
744085	744082	20054A	PARTICIPANT	\N	PRESENT	0
744087	744086	05008E	PARTICIPANT	\N	PRESENT	0
744088	744086	11053K	PARTICIPANT	\N	PRESENT	0
744089	744086	01028R	PARTICIPANT	\N	PRESENT	0
744095	740804	04070G	PRESIDENT	0	PRESENT	0
744096	740804	14179A	PARTICIPANT	\N	PRESENT	0
744097	740804	14038Y	PARTICIPANT	\N	PRESENT	0
744098	740804	10015M	PARTICIPANT	\N	PRESENT	0
744099	740804	20094J	PARTICIPANT	\N	PRESENT	0
744100	740804	20152B	PARTICIPANT	\N	PRESENT	0
744101	740804	20062A	PARTICIPANT	\N	PRESENT	0
744642	743989	19760E	PARTICIPANT	\N	PRESENT	0
744643	743989	18193Q	PARTICIPANT	\N	PRESENT	0
744644	743989	19683J	PARTICIPANT	\N	PRESENT	0
744645	743989	11067R	PARTICIPANT	\N	PRESENT	0
744646	743989	20130U	PARTICIPANT	\N	PRESENT	0
744647	743989	19715Y	PARTICIPANT	\N	PRESENT	0
744648	743989	10006L	PRESIDENT	0	PRESENT	0
744649	743989	14281W	PARTICIPANT	\N	PRESENT	0
744650	743989	19329S	PARTICIPANT	\N	PRESENT	0
744651	743989	14195A	PARTICIPANT	\N	PRESENT	0
744652	743989	14042U	PARTICIPANT	\N	PRESENT	0
744653	743989	19569H	PARTICIPANT	\N	PRESENT	0
744654	743989	14223L	PARTICIPANT	\N	PRESENT	0
744655	743989	04092N	PARTICIPANT	\N	PRESENT	0
744656	743989	19798U	PARTICIPANT	\N	PRESENT	0
744657	743989	14217N	PARTICIPANT	\N	PRESENT	0
744658	743989	11097X	PARTICIPANT	\N	PRESENT	0
744659	743989	20040T	PARTICIPANT	\N	PRESENT	0
744660	743989	14213J	PARTICIPANT	\N	PRESENT	0
744661	743989	19367Y	PARTICIPANT	\N	PRESENT	0
744662	743989	19723Y	PARTICIPANT	\N	PRESENT	0
744663	743989	20090E	PARTICIPANT	\N	PRESENT	0
744664	743989	19657G	PARTICIPANT	\N	PRESENT	0
744665	743989	19703U	PARTICIPANT	\N	PRESENT	0
744666	743989	20066E	PARTICIPANT	\N	PRESENT	0
744667	743989	14071N	PARTICIPANT	\N	PRESENT	0
744668	743989	17779H	PARTICIPANT	\N	EXCUSE	0
744669	743989	19553Y	PARTICIPANT	\N	PRESENT	0
744670	743989	19691J	PARTICIPANT	\N	PRESENT	0
744671	743989	19679N	PARTICIPANT	\N	PRESENT	0
744672	743989	19713W	PARTICIPANT	\N	PRESENT	0
744673	743989	01034P	PARTICIPANT	\N	PRESENT	0
744702	743989	08045X	PARTICIPANT	\N	PRESENT	0
744703	743989	11045K	PARTICIPANT	\N	PRESENT	0
744704	743989	17965H	PARTICIPANT	\N	PRESENT	0
744710	743989	20248J	PARTICIPANT	\N	PRESENT	0
744752	743989	20266L	PARTICIPANT	\N	PRESENT	0
744780	743989	04043D	PARTICIPANT	\N	PRESENT	0
744782	743989	14026U	PARTICIPANT	\N	PRESENT	0
744789	743989	04057K	PARTICIPANT	\N	PRESENT	0
744792	743989	19717B	PARTICIPANT	\N	PRESENT	0
744823	743990	19798U	PARTICIPANT	\N	PRESENT	0
744824	743990	04092N	PARTICIPANT	\N	PRESENT	0
744825	743990	14223L	PARTICIPANT	\N	PRESENT	0
744875	743990	14213J	PARTICIPANT	\N	PRESENT	0
746083	746082	20070A	PARTICIPANT	\N	PRESENT	0
746084	746082	11110B	PARTICIPANT	\N	PRESENT	0
744829	743990	20040T	PARTICIPANT	\N	PRESENT	0
744830	743990	11097X	PARTICIPANT	\N	PRESENT	0
744831	743990	14217N	PARTICIPANT	\N	PRESENT	0
744832	743990	10006L	PRESIDENT	\N	PRESENT	0
744833	743990	19715Y	PARTICIPANT	\N	PRESENT	0
744834	743990	20130U	PARTICIPANT	\N	PRESENT	0
746086	746085	19671E	PARTICIPANT	\N	PRESENT	0
744836	743990	11067R	PARTICIPANT	\N	PRESENT	0
744837	743990	14042U	PARTICIPANT	\N	PRESENT	0
744838	743990	04043D	PARTICIPANT	\N	PRESENT	0
746088	746087	19671E	PARTICIPANT	\N	PRESENT	0
744840	743990	19329S	PARTICIPANT	\N	PRESENT	0
744841	743990	14281W	PARTICIPANT	\N	PRESENT	0
744842	743990	19713W	PARTICIPANT	\N	PRESENT	0
744843	743990	19679N	PARTICIPANT	\N	PRESENT	0
744844	743990	19691J	PARTICIPANT	\N	PRESENT	0
746090	746089	04071H	PARTICIPANT	\N	PRESENT	0
744846	743990	01034P	PARTICIPANT	\N	PRESENT	0
744847	743990	19657G	PARTICIPANT	\N	PRESENT	0
744848	743990	19717B	PARTICIPANT	\N	PRESENT	0
744849	743990	20090E	PARTICIPANT	\N	PRESENT	0
744850	743990	19723Y	PARTICIPANT	\N	PRESENT	0
744851	743990	19367Y	PARTICIPANT	\N	PRESENT	0
744852	743990	04057K	PARTICIPANT	\N	PRESENT	0
744853	743990	17779H	PARTICIPANT	\N	EXCUSE	0
744854	743990	14071N	PARTICIPANT	\N	PRESENT	0
749427	748107	14121F	PARTICIPANT	\N	PRESENT	0
744856	743990	19703U	PARTICIPANT	\N	PRESENT	0
744857	743990	20266L	PARTICIPANT	\N	PRESENT	0
744858	743990	17965H	PARTICIPANT	\N	PRESENT	0
744859	743990	11045K	PARTICIPANT	\N	PRESENT	0
744860	743990	08045X	PARTICIPANT	\N	PRESENT	0
749428	748107	14021P	PARTICIPANT	\N	PRESENT	0
744862	743990	18193Q	PARTICIPANT	\N	PRESENT	0
744863	743990	19760E	PARTICIPANT	\N	PRESENT	0
749429	748107	18193Q	PARTICIPANT	\N	PRESENT	0
749430	748107	08012N	PARTICIPANT	\N	PRESENT	0
749431	748107	20028X	PARTICIPANT	\N	PRESENT	0
749432	748107	20018V	PARTICIPANT	\N	PRESENT	0
749433	748107	14257W	PARTICIPANT	\N	PRESENT	0
749434	748107	20034V	PARTICIPANT	\N	PRESENT	0
749435	748107	19683J	PARTICIPANT	\N	PRESENT	0
749436	748107	20082E	PARTICIPANT	\N	PRESENT	0
749437	748107	14229S	PARTICIPANT	\N	PRESENT	0
749438	748107	11045K	PARTICIPANT	\N	PRESENT	0
749439	748107	11054L	PARTICIPANT	\N	PRESENT	0
749440	748107	19413M	PARTICIPANT	\N	PRESENT	0
749441	748107	01062T	PARTICIPANT	\N	PRESENT	0
749442	748107	10015M	PARTICIPANT	\N	PRESENT	0
749443	748107	20064C	PARTICIPANT	\N	PRESENT	0
749444	748107	19489J	PARTICIPANT	\N	PRESENT	0
749445	748107	14219Q	PARTICIPANT	\N	PRESENT	0
749446	748107	14042U	PARTICIPANT	\N	PRESENT	0
749447	748107	19543W	PARTICIPANT	\N	PRESENT	0
749448	748107	14189C	PARTICIPANT	\N	PRESENT	0
749452	748107	14179A	PARTICIPANT	\N	PRESENT	0
749450	748107	14083S	PARTICIPANT	\N	PRESENT	0
749451	748107	20286Q	PARTICIPANT	\N	PRESENT	0
749453	748107	20048C	PARTICIPANT	\N	PRESENT	0
749454	748107	20066E	PARTICIPANT	\N	PRESENT	0
749455	748107	19611R	PARTICIPANT	\N	PRESENT	0
749456	748107	16685X	PARTICIPANT	\N	PRESENT	0
749457	748107	19699S	PARTICIPANT	\N	PRESENT	0
749458	748107	14205J	PARTICIPANT	\N	PRESENT	0
749459	748107	19441R	PARTICIPANT	\N	PRESENT	0
749460	748107	11085T	PARTICIPANT	\N	PRESENT	0
749461	748107	20058E	PARTICIPANT	\N	PRESENT	0
749462	748107	19826F	PARTICIPANT	\N	PRESENT	0
749463	748107	19954N	PARTICIPANT	\N	PRESENT	0
749464	748107	19369B	PARTICIPANT	\N	PRESENT	0
749469	748107	19749K	PARTICIPANT	\N	PRESENT	0
749466	748107	20298U	PARTICIPANT	\N	PRESENT	0
749467	748107	04070G	PARTICIPANT	\N	PRESENT	0
749468	748107	19713W	PARTICIPANT	\N	PRESENT	0
749470	748107	19629C	PARTICIPANT	\N	PRESENT	0
740075	738847	14259Y	PARTICIPANT	\N	PRESENT	0
740090	738847	14001X	PARTICIPANT	\N	PRESENT	0
749472	748107	19577H	PARTICIPANT	\N	PRESENT	0
749473	748107	01028R	PARTICIPANT	\N	PRESENT	0
749474	748107	20144B	PARTICIPANT	\N	PRESENT	0
749475	748107	20248J	PARTICIPANT	\N	PRESENT	0
749477	748107	14327T	PARTICIPANT	\N	PRESENT	0
749478	748107	01024M	PARTICIPANT	\N	PRESENT	0
749480	748107	20040T	PARTICIPANT	\N	PRESENT	0
749481	748107	14231L	PARTICIPANT	\N	PRESENT	0
763256	761747	19387D	PARTICIPANT	\N	PRESENT	0
763257	761747	14219Q	PRESIDENT	0	PRESENT	0
763258	761747	19820Y	PARTICIPANT	\N	PRESENT	0
763259	761747	19826F	PARTICIPANT	\N	PRESENT	0
763260	761747	21061D	PARTICIPANT	\N	PRESENT	0
763261	761747	21065H	PARTICIPANT	\N	PRESENT	0
763262	761747	20100N	PARTICIPANT	\N	PRESENT	0
763263	761747	21084L	PARTICIPANT	\N	PRESENT	0
763264	761747	14237S	PARTICIPANT	\N	PRESENT	0
763265	761747	18083K	PARTICIPANT	\N	PRESENT	0
763266	761747	05012A	PARTICIPANT	\N	PRESENT	0
763267	761747	08060W	PARTICIPANT	\N	PRESENT	0
763268	761747	20106U	PARTICIPANT	\N	PRESENT	0
763269	761747	15197G	PARTICIPANT	\N	PRESENT	0
763270	761747	20118Y	PARTICIPANT	\N	PRESENT	0
763271	761747	14107H	PARTICIPANT	\N	PRESENT	0
763272	761747	21080G	PARTICIPANT	\N	PRESENT	0
763273	761747	19331L	PARTICIPANT	\N	PRESENT	0
763274	761747	20020P	PARTICIPANT	\N	PRESENT	0
763275	761747	19685L	PARTICIPANT	\N	PRESENT	0
763276	761747	19681G	PARTICIPANT	\N	PRESENT	0
763277	761747	11065P	PARTICIPANT	\N	PRESENT	0
763278	761747	21051B	PARTICIPANT	\N	PRESENT	0
763279	761747	21053D	PARTICIPANT	\N	PRESENT	0
763280	761747	20032T	PARTICIPANT	\N	PRESENT	0
763281	761747	20136B	PARTICIPANT	\N	PRESENT	0
763282	761747	14031R	PARTICIPANT	\N	PRESENT	0
763283	761747	20040T	PARTICIPANT	\N	PRESENT	0
763284	761747	19251M	PARTICIPANT	\N	PRESENT	0
763285	761747	20046A	PARTICIPANT	\N	PRESENT	0
763286	761747	20146D	PARTICIPANT	\N	PRESENT	0
763287	761747	19719D	PARTICIPANT	\N	PRESENT	0
763288	761747	17229F	PARTICIPANT	\N	PRESENT	0
763289	761747	20068G	PARTICIPANT	\N	PRESENT	0
763290	761747	21068L	PARTICIPANT	\N	PRESENT	0
763291	761747	21070E	PARTICIPANT	\N	PRESENT	0
763292	761747	19619A	PARTICIPANT	\N	PRESENT	0
763293	761747	19701S	PARTICIPANT	\N	EXCUSE	0
763294	761747	21035B	PARTICIPANT	\N	EXCUSE	0
763300	763072	21091K	PARTICIPANT	\N	PRESENT	0
763306	761591	19347U	PARTICIPANT	\N	PRESENT	0
763307	761591	14179A	PARTICIPANT	\N	PRESENT	0
763308	761591	21073H	PARTICIPANT	\N	PRESENT	0
763309	761591	11064N	PARTICIPANT	\N	PRESENT	0
763323	761182	14331P	PARTICIPANT	\N	PRESENT	0
763324	761182	19545Y	PARTICIPANT	\N	PRESENT	0
763325	761182	11053K	PARTICIPANT	\N	PRESENT	0
763326	761182	19667J	PARTICIPANT	\N	PRESENT	0
763327	761182	19671E	PARTICIPANT	\N	PRESENT	0
763328	761182	11070L	PARTICIPANT	\N	PRESENT	0
763329	761182	11110B	PARTICIPANT	\N	PRESENT	0
763330	761182	07029T	PARTICIPANT	\N	PRESENT	0
763331	761182	19573D	PARTICIPANT	\N	PRESENT	0
763332	761182	19349W	PARTICIPANT	\N	PRESENT	0
763333	761182	20024T	PARTICIPANT	\N	PRESENT	0
763334	761182	21048G	PARTICIPANT	\N	PRESENT	0
763404	761745	17737W	PARTICIPANT	\N	PRESENT	0
763336	761182	19687N	PARTICIPANT	\N	PRESENT	0
763337	761182	20044X	PARTICIPANT	\N	PRESENT	0
763338	761182	19399H	PARTICIPANT	\N	PRESENT	0
763339	761182	21041Y	PARTICIPANT	\N	PRESENT	0
763340	761182	11040E	PARTICIPANT	\N	PRESENT	0
763341	761182	14083S	PARTICIPANT	\N	PRESENT	0
763342	761182	20062A	PARTICIPANT	\N	PRESENT	0
763343	761182	08073C	PARTICIPANT	\N	PRESENT	0
763344	761182	20070A	PARTICIPANT	\N	PRESENT	0
763403	761745	19701S	PARTICIPANT	\N	EXCUSE	0
763346	761182	21072G	PARTICIPANT	\N	PRESENT	0
763347	761182	20094J	PARTICIPANT	\N	PRESENT	0
763348	761182	11074Q	PARTICIPANT	\N	PRESENT	0
763349	761182	21079P	PARTICIPANT	\N	PRESENT	0
763350	761182	08010L	PARTICIPANT	\N	PRESENT	0
763351	761182	20116W	PARTICIPANT	\N	PRESENT	0
763352	761182	20126Y	PARTICIPANT	\N	PRESENT	0
763353	761182	19479G	PARTICIPANT	\N	PRESENT	0
763354	761182	20134Y	PARTICIPANT	\N	PRESENT	0
763355	761182	19711U	PARTICIPANT	\N	PRESENT	0
763402	761745	08034U	PARTICIPANT	\N	PRESENT	0
763357	761182	08034U	PARTICIPANT	\N	PRESENT	0
763358	761182	12016W	PARTICIPANT	\N	PRESENT	0
763359	761182	08011M	PARTICIPANT	\N	PRESENT	0
763360	761182	20150Y	PARTICIPANT	\N	PRESENT	0
763361	761182	14173T	PARTICIPANT	\N	PRESENT	0
763405	761713	86034E	PARTICIPANT	\N	PRESENT	0
763363	761182	08009T	PARTICIPANT	\N	PRESENT	0
763364	761182	19741B	PARTICIPANT	\N	PRESENT	0
763365	761182	19762G	PARTICIPANT	\N	PRESENT	0
763411	761713	21082J	PARTICIPANT	\N	PRESENT	0
763367	761182	21069M	PARTICIPANT	\N	EXCUSE	0
763368	761182	20050V	PARTICIPANT	\N	EXCUSE	0
763412	761713	20100N	PARTICIPANT	\N	PRESENT	0
763371	763370	19699S	PARTICIPANT	\N	PRESENT	0
763374	763372	18395Y	PARTICIPANT	\N	PRESENT	0
763375	763372	21055F	PARTICIPANT	\N	PRESENT	0
763376	763372	19693L	PARTICIPANT	\N	PRESENT	0
763377	763372	19735D	PARTICIPANT	\N	PRESENT	0
763378	761182	19647E	PARTICIPANT	\N	PRESENT	0
763379	761591	11027H	PARTICIPANT	\N	PRESENT	0
763380	761591	17367Q	PARTICIPANT	\N	PRESENT	0
763381	761591	20128B	PARTICIPANT	\N	PRESENT	0
763383	761747	21047F	PARTICIPANT	\N	PRESENT	0
763384	761745	14331P	PRESIDENT	0	PRESENT	0
763385	761745	14237S	PARTICIPANT	\N	PRESENT	0
763386	761745	10015M	PARTICIPANT	\N	PRESENT	0
763387	761745	21037D	PARTICIPANT	\N	PRESENT	0
763388	761745	18395Y	PARTICIPANT	\N	PRESENT	0
763389	761745	14073Q	PARTICIPANT	\N	PRESENT	0
763390	761745	20100N	PARTICIPANT	\N	PRESENT	0
763391	761745	19711U	PARTICIPANT	\N	PRESENT	0
763392	761745	21054E	PARTICIPANT	\N	PRESENT	0
763393	761745	20094J	PARTICIPANT	\N	PRESENT	0
763394	761745	20106U	PARTICIPANT	\N	PRESENT	0
763395	761745	18207D	PARTICIPANT	\N	PRESENT	0
763396	761745	20286Q	PARTICIPANT	\N	PRESENT	0
763397	761745	20104S	PARTICIPANT	\N	PRESENT	0
763398	761745	14026U	PARTICIPANT	\N	PRESENT	0
763399	761745	14033T	PARTICIPANT	\N	PRESENT	0
763401	761745	20248J	PARTICIPANT	\N	PRESENT	0
763413	761713	19683J	PARTICIPANT	\N	PRESENT	0
763414	761713	21084L	PARTICIPANT	\N	PRESENT	0
763415	761713	21046E	PARTICIPANT	\N	PRESENT	0
763416	761713	21052C	PARTICIPANT	\N	PRESENT	0
763417	761713	14221J	PARTICIPANT	\N	PRESENT	0
763426	761713	14151M	PARTICIPANT	\N	PRESENT	0
763427	761713	14267Y	PARTICIPANT	\N	PRESENT	0
763428	761713	11056N	PARTICIPANT	\N	PRESENT	0
763432	761713	19057M	PARTICIPANT	\N	PRESENT	0
763435	761713	14107H	PARTICIPANT	\N	PRESENT	0
763437	761713	20116W	PARTICIPANT	\N	PRESENT	0
763439	761713	95041E	PARTICIPANT	\N	PRESENT	0
763440	761713	08056B	PARTICIPANT	\N	PRESENT	0
763441	761713	19387D	PARTICIPANT	\N	PRESENT	0
763442	761713	14327T	PARTICIPANT	\N	PRESENT	0
763443	761713	08028W	PARTICIPANT	\N	PRESENT	0
763444	761713	19954N	PARTICIPANT	\N	PRESENT	0
763445	761713	14033T	PARTICIPANT	\N	PRESENT	0
763446	761713	14173T	PARTICIPANT	\N	PRESENT	0
763448	761713	20148F	PARTICIPANT	\N	PRESENT	0
763478	763476	18395Y	PARTICIPANT	\N	PRESENT	0
763479	763476	19735D	PARTICIPANT	\N	PRESENT	0
763655	763653	14123H	PARTICIPANT	\N	PRESENT	0
763656	763653	14030Q	PARTICIPANT	\N	PRESENT	0
764574	761714	14189C	PARTICIPANT	\N	PRESENT	0
764301	764300	14257W	PARTICIPANT	\N	PRESENT	0
764573	761714	20032T	PARTICIPANT	\N	PRESENT	0
764575	761714	21042A	PARTICIPANT	\N	PRESENT	0
764576	761714	20076G	PARTICIPANT	\N	PRESENT	0
764577	761714	05008E	PARTICIPANT	\N	PRESENT	0
764578	761714	20024T	PARTICIPANT	\N	PRESENT	0
764579	761714	19954N	PARTICIPANT	\N	PRESENT	0
764580	761714	19575F	PARTICIPANT	\N	PRESENT	0
764581	761714	20116W	PARTICIPANT	\N	PRESENT	0
764582	761714	14030Q	PARTICIPANT	\N	PRESENT	0
764583	761714	21043B	PARTICIPANT	\N	PRESENT	0
764584	761714	20094J	PARTICIPANT	\N	PRESENT	0
764585	761714	21050A	PARTICIPANT	\N	PRESENT	0
764586	761714	14069U	PARTICIPANT	\N	PRESENT	0
764587	761714	20088L	PARTICIPANT	\N	PRESENT	0
764588	761714	20114U	PARTICIPANT	\N	PRESENT	0
764589	761714	17737W	PARTICIPANT	\N	PRESENT	0
764590	761714	19621T	PARTICIPANT	\N	PRESENT	0
743722	740809	20024T	PARTICIPANT	\N	EXCUSE	0
743724	740809	19735D	PRESIDENT	0	PRESENT	0
743725	740809	11031D	PARTICIPANT	0	PRESENT	0
743726	740809	04045F	PARTICIPANT	\N	PRESENT	0
743727	740809	20096L	PARTICIPANT	\N	PRESENT	0
743728	740809	17965H	PARTICIPANT	\N	PRESENT	0
743730	740809	19369B	PARTICIPANT	\N	EXCUSE	0
743741	740809	20066E	PARTICIPANT	\N	EXCUSE	0
746135	746134	08018U	PARTICIPANT	\N	PRESENT	0
746138	746137	08018U	PARTICIPANT	\N	PRESENT	0
746141	746140	20118Y	PARTICIPANT	\N	PRESENT	0
746143	746142	08018U	PARTICIPANT	\N	PRESENT	0
746144	745791	17737W	PARTICIPANT	\N	EXCUSE	0
746145	745791	19729F	PARTICIPANT	\N	EXCUSE	0
749120	748005	14179A	PARTICIPANT	\N	PRESENT	0
749121	748005	14111D	PARTICIPANT	\N	PRESENT	0
749122	748005	04047H	PRESIDENT	0	PRESENT	0
749123	748005	14053L	PARTICIPANT	\N	PRESENT	0
749124	748005	05008E	PARTICIPANT	\N	PRESENT	0
749125	748005	14107H	PARTICIPANT	\N	PRESENT	0
749126	748005	19301E	PARTICIPANT	\N	PRESENT	0
749127	748005	14215L	PARTICIPANT	\N	PRESENT	0
749128	748005	20022R	PARTICIPANT	\N	PRESENT	0
749129	748005	14147R	PARTICIPANT	\N	PRESENT	0
749130	748005	19729F	PARTICIPANT	\N	PRESENT	0
749131	748005	19749K	PARTICIPANT	\N	PRESENT	0
749132	748005	19649G	PARTICIPANT	\N	PRESENT	0
749133	748005	11056N	PARTICIPANT	\N	PRESENT	0
749134	748005	14069U	PARTICIPANT	\N	PRESENT	0
749136	748005	14021P	PARTICIPANT	\N	PRESENT	0
749172	748005	10015M	PARTICIPANT	\N	PRESENT	0
749173	748005	95063L	PARTICIPANT	\N	PRESENT	0
749174	748005	14151M	PARTICIPANT	\N	PRESENT	0
749180	748005	01028R	PARTICIPANT	\N	PRESENT	0
750654	749973	20116W	PARTICIPANT	\N	PRESENT	0
750655	749973	14030Q	PARTICIPANT	\N	PRESENT	0
750658	749973	14089Y	PARTICIPANT	\N	PRESENT	0
750660	749973	20070A	PARTICIPANT	\N	PRESENT	0
750669	749973	20038A	PARTICIPANT	\N	PRESENT	0
750673	749973	20100N	PARTICIPANT	\N	PRESENT	0
750682	749973	14257W	PARTICIPANT	\N	PRESENT	0
750683	749973	19768N	PARTICIPANT	\N	PRESENT	0
751532	751529	11083R	PARTICIPANT	\N	PRESENT	0
751530	751529	11074Q	PARTICIPANT	\N	PRESENT	0
751531	751529	08045X	PARTICIPANT	\N	PRESENT	0
751533	751529	08015R	PARTICIPANT	\N	PRESENT	0
751534	751529	19745F	PARTICIPANT	\N	PRESENT	0
751535	751529	20028X	PARTICIPANT	\N	PRESENT	0
751624	722794	20072C	PARTICIPANT	\N	PRESENT	0
758207	757692	21049H	PARTICIPANT	\N	PRESENT	0
758213	757692	19367Y	PARTICIPANT	\N	PRESENT	0
758223	757692	21094N	PARTICIPANT	\N	PRESENT	0
758224	757692	19723Y	PARTICIPANT	\N	PRESENT	0
758225	757692	21064G	PARTICIPANT	\N	PRESENT	0
758227	757692	20148F	PARTICIPANT	\N	PRESENT	0
758228	757692	18193Q	PARTICIPANT	\N	PRESENT	0
758231	757692	14026U	PARTICIPANT	\N	PRESENT	0
758296	757844	19621T	PRESIDENT	0	PRESENT	0
758297	757844	19611R	PARTICIPANT	\N	EXCUSE	0
758298	758135	19621T	PRESIDENT	0	PRESENT	0
758299	758135	19611R	PARTICIPANT	\N	EXCUSE	0
759083	758747	20062A	PARTICIPANT	\N	PRESENT	0
759084	758747	07004J	PARTICIPANT	\N	PRESENT	0
759085	758747	12016W	PARTICIPANT	\N	PRESENT	0
759086	758747	19667J	PARTICIPANT	\N	PRESENT	0
759087	758747	14253S	PARTICIPANT	\N	PRESENT	0
759088	758747	21090J	PARTICIPANT	\N	PRESENT	0
759089	758747	19399H	PARTICIPANT	\N	PRESENT	0
759090	758747	11070L	PARTICIPANT	\N	PRESENT	0
759091	758747	14225N	PRESIDENT	0	PRESENT	0
759092	758747	20126Y	PARTICIPANT	\N	PRESENT	0
759093	758747	20024T	PARTICIPANT	\N	PRESENT	0
759106	758747	14327T	PARTICIPANT	\N	PRESENT	0
759107	758747	14331P	PARTICIPANT	\N	PRESENT	0
759108	758747	11048N	PARTICIPANT	\N	PRESENT	0
759109	758747	19479G	PARTICIPANT	\N	PRESENT	0
759110	758747	19711U	PARTICIPANT	\N	PRESENT	0
759111	758747	08034U	PARTICIPANT	\N	PRESENT	0
759112	758747	20080C	PARTICIPANT	\N	PRESENT	0
759113	758747	20050V	PARTICIPANT	\N	PRESENT	0
759114	758747	11074Q	PARTICIPANT	\N	PRESENT	0
759115	758747	11040E	PARTICIPANT	\N	PRESENT	0
759116	758747	21079P	PARTICIPANT	\N	PRESENT	0
759117	758747	20116W	PARTICIPANT	\N	PRESENT	0
759118	758747	21048G	PARTICIPANT	\N	PRESENT	0
759125	758747	07029T	PARTICIPANT	\N	PRESENT	0
759126	758747	08010L	PARTICIPANT	\N	PRESENT	0
759127	758747	20134Y	PARTICIPANT	\N	PRESENT	0
759128	758747	19687N	PARTICIPANT	\N	PRESENT	0
759129	758747	21041Y	PARTICIPANT	\N	PRESENT	0
759130	758747	20070A	PARTICIPANT	\N	PRESENT	0
759135	758747	21072G	PARTICIPANT	\N	PRESENT	0
759136	758747	20044X	PARTICIPANT	\N	PRESENT	0
759137	758747	14083S	PARTICIPANT	\N	PRESENT	0
759138	758135	19697Q	PARTICIPANT	\N	PRESENT	0
759139	758135	04070G	PARTICIPANT	\N	PRESENT	0
759140	758135	19699S	PARTICIPANT	\N	PRESENT	0
759141	758135	19533U	PARTICIPANT	\N	PRESENT	0
759142	758135	21058J	PARTICIPANT	\N	PRESENT	0
759143	758135	21059K	PARTICIPANT	\N	PRESENT	0
759144	758135	20102Q	PARTICIPANT	\N	PRESENT	0
759145	758135	19954N	PARTICIPANT	\N	PRESENT	0
759146	758135	20112S	PARTICIPANT	\N	PRESENT	0
759147	758135	21089R	PARTICIPANT	\N	PRESENT	0
759148	758135	21037D	PARTICIPANT	\N	PRESENT	0
759149	758135	08012N	PARTICIPANT	\N	PRESENT	0
759150	758135	21091K	PARTICIPANT	\N	PRESENT	0
759151	758135	20124W	PARTICIPANT	\N	PRESENT	0
759152	758135	20026V	PARTICIPANT	\N	PRESENT	0
759153	758135	19593H	PARTICIPANT	\N	PRESENT	0
759154	758135	21055F	PARTICIPANT	\N	PRESENT	0
759155	758135	20142Y	PARTICIPANT	\N	PRESENT	0
759156	758135	19693L	PARTICIPANT	\N	PRESENT	0
759157	758135	20052X	PARTICIPANT	\N	PRESENT	0
759158	758135	20058E	PARTICIPANT	\N	PRESENT	0
759159	758135	20056C	PARTICIPANT	\N	PRESENT	0
759160	758135	20180F	PARTICIPANT	\N	PRESENT	0
759161	758135	20264J	PARTICIPANT	\N	PRESENT	0
759162	758135	21063F	PARTICIPANT	\N	PRESENT	0
759163	758135	19735D	PARTICIPANT	\N	PRESENT	0
759164	758135	14109K	PARTICIPANT	\N	PRESENT	0
759165	758135	11043H	PARTICIPANT	\N	PRESENT	0
759166	758135	21077M	PARTICIPANT	\N	PRESENT	0
759167	758135	14021P	PARTICIPANT	\N	PRESENT	0
759169	758747	20094J	PARTICIPANT	\N	PRESENT	0
759171	758135	04033B	PARTICIPANT	\N	PRESENT	0
759172	758135	14229S	PARTICIPANT	\N	PRESENT	0
759173	758747	14173T	PARTICIPANT	\N	PRESENT	0
759174	758747	21069M	PARTICIPANT	\N	PRESENT	0
759183	758747	11053K	PARTICIPANT	\N	PRESENT	0
759187	757774	21031W	PARTICIPANT	\N	PRESENT	0
759188	757774	19565D	PARTICIPANT	\N	PRESENT	0
759189	757774	20072C	PARTICIPANT	\N	PRESENT	0
759190	757774	01058X	PARTICIPANT	\N	PRESENT	0
759191	757774	11027H	PARTICIPANT	\N	PRESENT	0
759192	757774	14001X	PARTICIPANT	\N	PRESENT	0
759193	757774	12028B	PARTICIPANT	\N	PRESENT	0
759194	757774	17737W	PARTICIPANT	\N	PRESENT	0
759195	757774	21067K	PARTICIPANT	\N	PRESENT	0
759196	757774	14193X	PRESIDENT	0	PRESENT	0
759197	757774	19347U	PARTICIPANT	\N	PRESENT	0
759198	757774	14179A	PARTICIPANT	\N	PRESENT	0
759199	757774	14249W	PARTICIPANT	\N	PRESENT	0
759200	757774	08047A	PARTICIPANT	\N	PRESENT	0
759201	757774	20128B	PARTICIPANT	\N	PRESENT	0
759202	757774	14097Y	PARTICIPANT	\N	PRESENT	0
759203	757774	14059S	PARTICIPANT	\N	PRESENT	0
759204	757774	14133K	PARTICIPANT	\N	PRESENT	0
759205	757774	19531S	PARTICIPANT	\N	PRESENT	0
759206	757774	08069G	PARTICIPANT	\N	PRESENT	0
759207	757774	20042V	PARTICIPANT	\N	PRESENT	0
759208	757774	20064C	PARTICIPANT	\N	PRESENT	0
759209	757774	20252E	PARTICIPANT	\N	PRESENT	0
759210	757774	98022P	PARTICIPANT	\N	PRESENT	0
759211	757774	14267Y	PARTICIPANT	\N	PRESENT	0
759212	757774	19745F	PARTICIPANT	\N	PRESENT	0
759213	757774	99004R	PARTICIPANT	\N	PRESENT	0
759214	757774	14255U	PARTICIPANT	\N	PRESENT	0
759215	758747	19647E	PARTICIPANT	\N	PRESENT	0
759217	757734	20074E	PARTICIPANT	\N	PRESENT	0
759218	757734	21057H	PARTICIPANT	\N	PRESENT	0
766344	765400	14219Q	PARTICIPANT	\N	PRESENT	0
766345	765400	14089Y	PARTICIPANT	\N	PRESENT	0
766346	765400	11056N	PARTICIPANT	\N	PRESENT	0
766347	765400	19565D	PARTICIPANT	\N	PRESENT	0
766348	765400	19593H	PARTICIPANT	\N	PRESENT	0
766349	765400	14249W	PARTICIPANT	\N	PRESENT	0
766350	765400	11110B	PARTICIPANT	\N	PRESENT	0
766366	765400	14193X	PARTICIPANT	\N	PRESENT	0
766352	765400	14187A	PARTICIPANT	\N	PRESENT	0
766353	765400	19629C	PARTICIPANT	\N	PRESENT	0
766354	765400	20040T	PARTICIPANT	\N	PRESENT	0
766355	765400	19713W	PARTICIPANT	\N	PRESENT	0
766356	765400	19295A	PARTICIPANT	\N	PRESENT	0
766357	765400	14055N	PARTICIPANT	\N	PRESENT	0
766358	765400	20136B	PARTICIPANT	\N	PRESENT	0
766359	765400	11053K	PARTICIPANT	\N	PRESENT	0
766360	765400	21041Y	PARTICIPANT	\N	PRESENT	0
766361	765400	19697Q	PARTICIPANT	\N	PRESENT	0
766362	765400	20026V	PARTICIPANT	\N	PRESENT	0
766364	765400	19563B	PARTICIPANT	\N	PRESENT	0
766365	765400	14147R	PARTICIPANT	\N	PRESENT	0
766367	765400	19413M	PARTICIPANT	\N	PRESENT	0
766368	765400	20044X	PARTICIPANT	\N	PRESENT	0
766369	765400	11048N	PARTICIPANT	\N	PRESENT	0
766370	765400	20080C	PARTICIPANT	\N	PRESENT	0
766371	765400	14123H	PARTICIPANT	\N	PRESENT	0
766372	765400	20266L	PARTICIPANT	\N	PRESENT	0
766373	765400	19507S	PARTICIPANT	\N	PRESENT	0
766374	765400	14031R	PARTICIPANT	\N	PRESENT	0
766381	765400	08069G	PARTICIPANT	\N	PRESENT	0
766376	765400	11085T	PARTICIPANT	\N	PRESENT	0
766377	765400	19383Y	PARTICIPANT	\N	PRESENT	0
766378	765400	20124W	PARTICIPANT	\N	PRESENT	0
766379	765400	20078J	PARTICIPANT	\N	PRESENT	0
766380	765400	21085M	PARTICIPANT	\N	PRESENT	0
766382	765400	14042U	PARTICIPANT	\N	PRESENT	0
766383	765400	17367Q	PARTICIPANT	\N	PRESENT	0
766384	765400	19768N	PARTICIPANT	\N	PRESENT	0
766385	765400	19057M	PARTICIPANT	\N	PRESENT	0
766386	765400	14073Q	PARTICIPANT	\N	PRESENT	0
766387	765400	20142Y	PARTICIPANT	\N	PRESENT	0
766391	766388	19768N	PARTICIPANT	\N	PRESENT	0
766392	766389	19768N	PARTICIPANT	\N	PRESENT	0
766393	766390	19768N	PARTICIPANT	\N	PRESENT	0
766394	765400	08009T	PARTICIPANT	\N	PRESENT	0
766395	765400	20130U	PARTICIPANT	\N	PRESENT	0
766396	765400	20064C	PARTICIPANT	\N	PRESENT	0
766397	765400	11065P	PARTICIPANT	\N	PRESENT	0
766398	765400	21048G	PARTICIPANT	\N	PRESENT	0
766399	765400	19301E	PARTICIPANT	\N	PRESENT	0
766699	765401	19479G	PARTICIPANT	\N	PRESENT	0
766700	765401	19295A	PARTICIPANT	\N	PRESENT	0
766792	766791	14237S	PARTICIPANT	\N	PRESENT	0
766702	765401	21060C	PARTICIPANT	\N	PRESENT	0
766793	766791	19826F	PARTICIPANT	\N	PRESENT	0
766704	765401	20102Q	PARTICIPANT	\N	PRESENT	0
766705	763305	14253S	PARTICIPANT	\N	PRESENT	0
766706	765401	21097R	PARTICIPANT	\N	PRESENT	0
766707	765401	21087P	PARTICIPANT	\N	PRESENT	0
766708	765401	14195A	PARTICIPANT	\N	PRESENT	0
766784	765489	14259Y	PARTICIPANT	\N	EXCUSE	0
766795	766791	14111D	PARTICIPANT	\N	PRESENT	0
766798	766791	14151M	PARTICIPANT	\N	PRESENT	0
766802	766801	19295A	PARTICIPANT	\N	PRESENT	0
766809	763305	21090J	PARTICIPANT	\N	PRESENT	0
766906	764374	04042C	PARTICIPANT	\N	PRESENT	0
766954	766953	04047H	PARTICIPANT	\N	PRESENT	0
766956	766953	14097Y	PARTICIPANT	\N	PRESENT	0
766957	766953	14193X	PARTICIPANT	\N	PRESENT	0
767160	765855	20038A	PARTICIPANT	\N	EXCUSE	0
767161	765855	20030R	PARTICIPANT	\N	PRESENT	0
767162	765855	20092G	PARTICIPANT	\N	PRESENT	0
767163	765855	20126Y	PARTICIPANT	\N	PRESENT	0
767266	767261	11056N	PARTICIPANT	\N	PRESENT	0
767271	767269	14053L	PARTICIPANT	\N	PRESENT	0
767272	767269	19749K	PARTICIPANT	\N	PRESENT	0
767273	767269	19649G	PARTICIPANT	\N	PRESENT	0
767274	767269	20114U	PARTICIPANT	\N	PRESENT	0
767300	767299	11048N	PARTICIPANT	\N	PRESENT	0
767302	767301	11048N	PARTICIPANT	\N	PRESENT	0
767303	767301	19399H	PARTICIPANT	\N	PRESENT	0
767306	767304	11048N	PARTICIPANT	\N	PRESENT	0
767307	767304	19399H	PARTICIPANT	\N	PRESENT	0
767310	767309	19711U	PARTICIPANT	\N	PRESENT	0
767313	767312	19711U	PARTICIPANT	\N	PRESENT	0
767315	767314	19667J	PARTICIPANT	\N	PRESENT	0
767316	767314	11040E	PARTICIPANT	\N	PRESENT	0
767361	767360	19667J	PARTICIPANT	\N	PRESENT	0
767362	767360	11040E	PARTICIPANT	\N	PRESENT	0
767364	767363	19667J	PARTICIPANT	\N	PRESENT	0
767365	767363	11040E	PARTICIPANT	\N	PRESENT	0
767368	767367	19667J	PARTICIPANT	\N	PRESENT	0
767369	767367	11040E	PARTICIPANT	\N	PRESENT	0
767370	765836	14173T	PARTICIPANT	\N	PRESENT	0
767372	767371	14173T	PARTICIPANT	\N	PRESENT	0
767373	763071	21074J	PARTICIPANT	\N	PRESENT	0
767376	767375	14173T	PARTICIPANT	\N	PRESENT	0
767424	767377	19711U	PARTICIPANT	\N	PRESENT	0
767426	767425	19711U	PARTICIPANT	\N	PRESENT	0
767428	767427	19711U	PARTICIPANT	\N	PRESENT	0
767430	767429	19711U	PARTICIPANT	\N	PRESENT	0
767432	767431	19711U	PARTICIPANT	\N	PRESENT	0
767433	767291	21082J	PARTICIPANT	\N	PRESENT	0
767434	767291	21029D	PARTICIPANT	\N	PRESENT	0
767435	767291	19701S	PARTICIPANT	\N	PRESENT	0
767436	767291	21035B	PARTICIPANT	\N	PRESENT	0
767437	767291	21042A	PARTICIPANT	\N	PRESENT	0
767438	767291	20076G	PARTICIPANT	\N	PRESENT	0
767439	767291	19387D	PARTICIPANT	\N	PRESENT	0
767440	767291	19820Y	PARTICIPANT	\N	PRESENT	0
767441	767291	14219Q	PRESIDENT	0	PRESENT	0
767442	767291	19826F	PARTICIPANT	\N	PRESENT	0
767443	767291	21060C	PARTICIPANT	\N	PRESENT	0
767444	767291	21061D	PARTICIPANT	\N	PRESENT	0
767445	767291	21062E	PARTICIPANT	\N	PRESENT	0
767446	767291	21065H	PARTICIPANT	\N	PRESENT	0
767447	767291	21084L	PARTICIPANT	\N	PRESENT	0
767448	767291	20100N	PARTICIPANT	\N	PRESENT	0
767449	767291	18083K	PARTICIPANT	\N	PRESENT	0
767450	767291	08060W	PARTICIPANT	\N	PRESENT	0
767451	767291	14107H	PARTICIPANT	\N	PRESENT	0
767452	767291	21080G	PARTICIPANT	\N	PRESENT	0
767453	767291	19685L	PARTICIPANT	\N	PRESENT	0
767454	767291	11065P	PARTICIPANT	\N	PRESENT	0
767455	767291	21051B	PARTICIPANT	\N	PRESENT	0
767456	767291	20032T	PARTICIPANT	\N	PRESENT	0
767457	767291	21053D	PARTICIPANT	\N	PRESENT	0
767458	767291	20136B	PARTICIPANT	\N	PRESENT	0
767459	767291	14031R	PARTICIPANT	\N	PRESENT	0
767460	767291	20040T	PARTICIPANT	\N	PRESENT	0
767461	767291	19251M	PARTICIPANT	\N	PRESENT	0
767462	767291	20046A	PARTICIPANT	\N	PRESENT	0
767463	767291	20146D	PARTICIPANT	\N	PRESENT	0
767464	767291	14169X	PARTICIPANT	\N	PRESENT	0
767465	767291	17229F	PARTICIPANT	\N	PRESENT	0
767466	767291	20068G	PARTICIPANT	\N	PRESENT	0
767467	767291	21068L	PARTICIPANT	\N	PRESENT	0
767468	767291	21070E	PARTICIPANT	\N	PRESENT	0
767469	764866	21036C	PARTICIPANT	\N	PRESENT	0
767470	764866	21031W	PARTICIPANT	\N	PRESENT	0
767471	764866	19565D	PARTICIPANT	\N	PRESENT	0
767472	764866	20072C	PARTICIPANT	\N	PRESENT	0
767473	764866	01058X	PARTICIPANT	\N	PRESENT	0
767474	764866	11027H	PARTICIPANT	\N	PRESENT	0
767475	764866	14001X	PARTICIPANT	\N	PRESENT	0
767476	764866	04042C	PARTICIPANT	\N	PRESENT	0
767477	764866	19669L	PARTICIPANT	\N	PRESENT	0
767478	764866	08056B	PARTICIPANT	\N	PRESENT	0
767479	764866	12028B	PARTICIPANT	\N	PRESENT	0
767480	764866	17737W	PARTICIPANT	\N	PRESENT	0
767481	764866	11115U	PARTICIPANT	\N	PRESENT	0
767482	764866	14055N	PARTICIPANT	\N	PRESENT	0
767483	764866	19421M	PARTICIPANT	\N	PRESENT	0
767484	764866	19709B	PARTICIPANT	\N	PRESENT	0
767485	764866	21067K	PARTICIPANT	\N	PRESENT	0
767486	764866	19347U	PARTICIPANT	\N	PRESENT	0
767487	764866	14179A	PARTICIPANT	\N	PRESENT	0
767488	764866	17367Q	PARTICIPANT	\N	PRESENT	0
767489	764866	14249W	PARTICIPANT	\N	PRESENT	0
767490	764866	08047A	PRESIDENT	0	PRESENT	0
767491	764866	14037X	PARTICIPANT	\N	PRESENT	0
742665	742621	20032T	PARTICIPANT	\N	PRESENT	0
742666	742621	20076G	PARTICIPANT	\N	PRESENT	0
742667	742621	20024T	PARTICIPANT	\N	PRESENT	0
742668	742621	19549D	PARTICIPANT	\N	EXCUSE	0
742669	742621	17367Q	PARTICIPANT	\N	PRESENT	0
742670	742621	08060W	PARTICIPANT	\N	PRESENT	0
742671	742621	18083K	PARTICIPANT	\N	PRESENT	0
742672	742621	19701S	PARTICIPANT	\N	PRESENT	0
742673	742621	19681G	PARTICIPANT	\N	PRESENT	0
742674	742621	19525U	PARTICIPANT	\N	PRESENT	0
742675	742621	11065P	PARTICIPANT	\N	PRESENT	0
742676	742621	17229F	PARTICIPANT	\N	PRESENT	0
742677	742621	19251M	PARTICIPANT	\N	PRESENT	0
742678	742621	20038A	PARTICIPANT	\N	PRESENT	0
742679	742621	20100N	PARTICIPANT	\N	PRESENT	0
742680	742621	19599P	PARTICIPANT	\N	PRESENT	0
742681	742621	20120S	PARTICIPANT	\N	PRESENT	0
742682	742621	19820Y	PARTICIPANT	\N	PRESENT	0
742683	742621	19387D	PARTICIPANT	\N	PRESENT	0
742684	742621	20068G	PARTICIPANT	\N	PRESENT	0
742685	742621	20106U	PARTICIPANT	\N	EXCUSE	0
742686	742621	19685L	PARTICIPANT	\N	PRESENT	0
742687	742621	19333N	PARTICIPANT	\N	PRESENT	0
742688	742621	20102Q	PARTICIPANT	\N	PRESENT	0
742689	742621	14219Q	PRESIDENT	0	PRESENT	0
742690	742621	14031R	PARTICIPANT	\N	PRESENT	0
742691	742621	19637C	PARTICIPANT	\N	PRESENT	0
742692	742621	19826F	PARTICIPANT	\N	PRESENT	0
742693	742621	14221J	PARTICIPANT	\N	PRESENT	0
742694	742621	20096L	PARTICIPANT	\N	PRESENT	0
742695	742621	14169X	PARTICIPANT	\N	PRESENT	0
742696	742621	14237S	PARTICIPANT	\N	PRESENT	0
742697	742621	19745F	PARTICIPANT	\N	PRESENT	0
742698	742621	20146D	PARTICIPANT	\N	PRESENT	0
742699	742621	20118Y	PARTICIPANT	\N	PRESENT	0
742700	742621	05012A	PARTICIPANT	\N	PRESENT	0
742701	742621	19503N	PARTICIPANT	\N	PRESENT	0
742702	742621	19739H	PARTICIPANT	\N	PRESENT	0
742703	742621	20020P	PARTICIPANT	\N	PRESENT	0
742704	742621	20136B	PARTICIPANT	\N	PRESENT	0
742705	742621	20046A	PARTICIPANT	\N	PRESENT	0
742721	742229	19549D	PARTICIPANT	\N	EXCUSE	0
742722	742229	20106U	PARTICIPANT	\N	EXCUSE	0
742723	742229	19745F	PARTICIPANT	\N	PRESENT	0
742724	742229	19739H	PARTICIPANT	\N	PRESENT	0
742725	742229	20076G	PARTICIPANT	\N	PRESENT	0
742726	742229	19701S	PARTICIPANT	\N	PRESENT	0
742727	742229	19333N	PARTICIPANT	\N	PRESENT	0
742728	742229	19820Y	PARTICIPANT	\N	PRESENT	0
742729	742229	14219Q	PRESIDENT	\N	PRESENT	0
742803	742621	14033T	PARTICIPANT	\N	PRESENT	0
742731	742229	19387D	PARTICIPANT	\N	PRESENT	0
742732	742229	20118Y	PARTICIPANT	\N	PRESENT	0
742733	742229	08060W	PARTICIPANT	\N	PRESENT	0
742734	742229	05012A	PARTICIPANT	\N	PRESENT	0
742735	742229	14237S	PARTICIPANT	\N	PRESENT	0
742736	742229	17367Q	PARTICIPANT	\N	PRESENT	0
742737	742229	19685L	PARTICIPANT	\N	PRESENT	0
742738	742229	20020P	PARTICIPANT	\N	PRESENT	0
742739	742229	19503N	PARTICIPANT	\N	PRESENT	0
742740	742229	19599P	PARTICIPANT	\N	PRESENT	0
742741	742229	20102Q	PARTICIPANT	\N	PRESENT	0
742742	742229	14221J	PARTICIPANT	\N	PRESENT	0
742743	742229	19826F	PARTICIPANT	\N	PRESENT	0
742744	742229	18083K	PARTICIPANT	\N	PRESENT	0
742745	742229	20100N	PARTICIPANT	\N	PRESENT	0
742746	742229	20096L	PARTICIPANT	\N	PRESENT	0
742747	742229	19637C	PARTICIPANT	\N	PRESENT	0
744725	744711	19798U	PARTICIPANT	\N	PRESENT	0
742749	742229	20046A	PARTICIPANT	\N	PRESENT	0
742750	742229	19251M	PARTICIPANT	\N	PRESENT	0
742751	742229	14031R	PARTICIPANT	\N	PRESENT	0
742752	742229	20068G	PARTICIPANT	\N	PRESENT	0
742753	742229	17229F	PARTICIPANT	\N	PRESENT	0
742754	742229	14169X	PARTICIPANT	\N	PRESENT	0
742755	742229	20146D	PARTICIPANT	\N	PRESENT	0
742756	742229	20120S	PARTICIPANT	\N	PRESENT	0
742757	742229	11065P	PARTICIPANT	\N	PRESENT	0
742758	742229	20024T	PARTICIPANT	\N	PRESENT	0
742759	742229	19681G	PARTICIPANT	\N	PRESENT	0
742760	742229	20038A	PARTICIPANT	\N	PRESENT	0
742761	742229	20136B	PARTICIPANT	\N	PRESENT	0
742762	742229	20032T	PARTICIPANT	\N	PRESENT	0
742763	742229	19525U	PARTICIPANT	\N	PRESENT	0
742800	742621	11053K	PARTICIPANT	\N	PRESENT	0
744726	744711	19691J	PARTICIPANT	\N	PRESENT	0
744727	744711	14223L	PARTICIPANT	\N	PRESENT	0
744728	744712	19798U	PARTICIPANT	\N	PRESENT	0
744729	744712	14223L	PARTICIPANT	\N	PRESENT	0
744730	744712	19691J	PARTICIPANT	\N	PRESENT	0
744731	744713	19798U	PARTICIPANT	\N	PRESENT	0
744732	744713	18193Q	PARTICIPANT	\N	PRESENT	0
744733	744713	14223L	PARTICIPANT	\N	PRESENT	0
744783	744781	07033P	PARTICIPANT	\N	PRESENT	0
744784	744781	14059S	PARTICIPANT	\N	PRESENT	0
744785	744781	14147R	PARTICIPANT	\N	PRESENT	0
744786	744781	20084G	PARTICIPANT	\N	PRESENT	0
746653	745794	14215L	PARTICIPANT	\N	PRESENT	0
746654	745794	19749K	PARTICIPANT	\N	PRESENT	0
746655	745794	20074E	PARTICIPANT	\N	PRESENT	0
746656	745794	14053L	PARTICIPANT	\N	PRESENT	0
746657	745794	11033F	PARTICIPANT	\N	PRESENT	0
746658	745794	14179A	PARTICIPANT	\N	PRESENT	0
746671	745794	14259Y	PARTICIPANT	\N	PRESENT	0
746674	745794	19673G	PARTICIPANT	\N	PRESENT	0
746675	745794	11072N	PARTICIPANT	\N	PRESENT	0
746676	745794	19649G	PARTICIPANT	\N	PRESENT	0
746685	745794	14111D	PARTICIPANT	\N	PRESENT	0
746700	745794	19585H	PARTICIPANT	\N	PRESENT	0
746701	745794	14069U	PARTICIPANT	\N	PRESENT	0
746702	745794	20022R	PARTICIPANT	\N	PRESENT	0
746703	745794	14147R	PARTICIPANT	\N	PRESENT	0
746704	745794	14107H	PARTICIPANT	\N	PRESENT	0
746705	745794	20114U	PARTICIPANT	\N	PRESENT	0
746706	745794	04047H	PRESIDENT	0	PRESENT	0
746707	745794	95063L	PARTICIPANT	\N	PRESENT	0
746708	745794	19447X	PARTICIPANT	\N	PRESENT	0
746709	745794	19729F	PARTICIPANT	\N	EXCUSE	0
746710	745794	17737W	PARTICIPANT	\N	EXCUSE	0
746711	745794	11056N	PARTICIPANT	\N	PRESENT	0
746712	745794	14021P	PARTICIPANT	\N	PRESENT	0
746713	745794	11010L	PARTICIPANT	\N	PRESENT	0
746730	745794	14151M	PARTICIPANT	\N	PRESENT	0
746731	745794	08018U	PARTICIPANT	\N	PRESENT	0
746748	745794	14001X	PARTICIPANT	\N	PRESENT	0
746749	745794	19581D	PARTICIPANT	\N	PRESENT	0
746755	745794	14231L	PARTICIPANT	\N	PRESENT	0
746762	745795	04047H	PRESIDENT	0	PRESENT	0
746763	745795	08018U	PARTICIPANT	\N	PRESENT	0
746764	745795	11026G	PARTICIPANT	\N	PRESENT	0
746765	745795	11072N	PARTICIPANT	\N	PRESENT	0
746766	745795	20114U	PARTICIPANT	\N	PRESENT	0
746767	745795	11033F	PARTICIPANT	\N	PRESENT	0
746768	745795	19543W	PARTICIPANT	\N	PRESENT	0
746769	745795	14231L	PARTICIPANT	\N	PRESENT	0
746770	745795	14147R	PARTICIPANT	\N	PRESENT	0
746771	745795	20074E	PARTICIPANT	\N	PRESENT	0
746772	745795	14215L	PARTICIPANT	\N	PRESENT	0
746774	745795	05008E	PARTICIPANT	\N	PRESENT	0
747632	747630	97011G	PARTICIPANT	\N	PRESENT	0
747866	747859	19693L	PARTICIPANT	\N	PRESENT	0
747867	747859	19723Y	PARTICIPANT	\N	PRESENT	0
747868	747859	01048V	PARTICIPANT	\N	PRESENT	0
747869	747859	04043D	PARTICIPANT	\N	PRESENT	0
748007	747859	19503N	PARTICIPANT	\N	PRESENT	0
748008	747859	20072C	PARTICIPANT	\N	EXCUSE	0
748009	747859	20128B	PARTICIPANT	\N	EXCUSE	0
748010	747859	20066E	PARTICIPANT	\N	EXCUSE	0
748011	747859	19735D	PARTICIPANT	\N	EXCUSE	0
749175	746959	19735D	PARTICIPANT	\N	EXCUSE	0
749185	748004	17737W	PARTICIPANT	\N	EXCUSE	0
749186	748005	17737W	PARTICIPANT	\N	EXCUSE	0
749505	748107	19551W	PARTICIPANT	\N	PRESENT	0
749503	748107	04071H	PARTICIPANT	\N	PRESENT	0
764591	761714	21088Q	PARTICIPANT	\N	PRESENT	0
764592	761714	21089R	PARTICIPANT	\N	PRESENT	0
764593	761714	19758L	PARTICIPANT	\N	PRESENT	0
764594	761714	21063F	PARTICIPANT	\N	PRESENT	0
764595	761714	19782L	PARTICIPANT	\N	PRESENT	0
764596	761714	20090E	PARTICIPANT	\N	PRESENT	0
764597	761714	14207L	PARTICIPANT	\N	PRESENT	0
764598	761714	20104S	PARTICIPANT	\N	PRESENT	0
764599	761714	14255U	PARTICIPANT	\N	PRESENT	0
764600	761714	21083K	PARTICIPANT	\N	PRESENT	0
764601	761714	14053L	PARTICIPANT	\N	PRESENT	0
764602	761714	14083S	PARTICIPANT	\N	PRESENT	0
764603	761714	19545Y	PARTICIPANT	\N	PRESENT	0
764604	761714	20060X	PARTICIPANT	\N	PRESENT	0
764605	761714	12028B	PARTICIPANT	\N	PRESENT	0
764606	761714	19629C	PARTICIPANT	\N	PRESENT	0
764607	761714	21057H	PARTICIPANT	\N	PRESENT	0
764608	761714	14329V	PARTICIPANT	\N	PRESENT	0
764609	761714	14038Y	PARTICIPANT	\N	PRESENT	0
764610	761714	20264J	PARTICIPANT	\N	PRESENT	0
764611	761714	08028W	PARTICIPANT	\N	PRESENT	0
764612	761714	21065H	PARTICIPANT	\N	PRESENT	0
764613	761714	18083K	PARTICIPANT	\N	PRESENT	0
764614	761714	21072G	PARTICIPANT	\N	PRESENT	0
764615	761714	11027H	PARTICIPANT	\N	PRESENT	0
764616	761714	21034A	PARTICIPANT	\N	PRESENT	0
764617	761714	19681G	PARTICIPANT	\N	PRESENT	0
764618	761714	11056N	PARTICIPANT	\N	PRESENT	0
764619	761714	14357A	PARTICIPANT	\N	PRESENT	0
764620	761714	11065P	PARTICIPANT	\N	PRESENT	0
764622	761714	21067K	PARTICIPANT	\N	PRESENT	0
764623	761714	21041Y	PARTICIPANT	\N	PRESENT	0
764624	761714	20140W	PARTICIPANT	\N	PRESENT	0
764625	761714	14217N	PARTICIPANT	\N	PRESENT	0
764626	761714	20248J	PARTICIPANT	\N	PRESENT	0
764627	761714	15197G	PARTICIPANT	\N	PRESENT	0
764628	761714	14042U	PARTICIPANT	\N	PRESENT	0
764629	761714	20134Y	PARTICIPANT	\N	PRESENT	0
764630	761714	20040T	PARTICIPANT	\N	PRESENT	0
764631	761714	14151M	PARTICIPANT	\N	PRESENT	0
764632	761714	14249W	PARTICIPANT	\N	PRESENT	0
764633	761714	14187A	PARTICIPANT	\N	PRESENT	0
764635	761714	19673G	PARTICIPANT	\N	PRESENT	0
764636	761714	21091K	PARTICIPANT	\N	PRESENT	0
764639	761714	21062E	PARTICIPANT	\N	PRESENT	0
764640	761714	21086N	PARTICIPANT	\N	PRESENT	0
764641	761714	19647E	PARTICIPANT	\N	PRESENT	0
764642	761714	14281W	PARTICIPANT	\N	PRESENT	0
764643	761714	19111A	PARTICIPANT	\N	PRESENT	0
764644	761714	08018U	PARTICIPANT	\N	PRESENT	0
764645	761714	14231L	PARTICIPANT	\N	PRESENT	0
764646	761714	19695N	PARTICIPANT	\N	PRESENT	0
764649	761714	19347U	PARTICIPANT	\N	PRESENT	0
764651	761714	20180F	PARTICIPANT	\N	PRESENT	0
764653	761714	08056B	PARTICIPANT	\N	PRESENT	0
764655	761714	19565D	PARTICIPANT	\N	PRESENT	0
764658	761714	14033T	PARTICIPANT	\N	PRESENT	0
764659	761714	14123H	PARTICIPANT	\N	PRESENT	0
764662	761714	21066J	PARTICIPANT	\N	PRESENT	0
764663	761714	14026U	PARTICIPANT	\N	PRESENT	0
764665	761714	21092L	PARTICIPANT	\N	PRESENT	0
764668	761714	19553Y	PARTICIPANT	\N	PRESENT	0
764669	761714	20128B	PARTICIPANT	\N	PRESENT	0
764670	761714	19569H	PARTICIPANT	\N	PRESENT	0
764671	761714	19685L	PARTICIPANT	\N	PRESENT	0
764672	761714	20048C	PARTICIPANT	\N	PRESENT	0
764673	761714	21085M	PARTICIPANT	\N	PRESENT	0
764674	761714	14213J	PARTICIPANT	\N	PRESENT	0
764675	761714	20066E	PARTICIPANT	\N	PRESENT	0
764676	761714	21093M	PARTICIPANT	\N	PRESENT	0
764677	761714	14121F	PARTICIPANT	\N	PRESENT	0
764678	761714	19531S	PARTICIPANT	\N	PRESENT	0
764679	761714	21044C	PARTICIPANT	\N	PRESENT	0
764680	761714	20056C	PARTICIPANT	\N	PRESENT	0
764681	761714	14097Y	PARTICIPANT	\N	PRESENT	0
764682	761714	14021P	PARTICIPANT	\N	PRESENT	0
764684	761714	14073Q	PARTICIPANT	\N	PRESENT	0
764685	761714	19489J	PARTICIPANT	\N	PRESENT	0
764686	761714	21081H	PARTICIPANT	\N	PRESENT	0
764687	761714	20126Y	PARTICIPANT	\N	PRESENT	0
764688	761714	19735D	PARTICIPANT	\N	PRESENT	0
764689	761714	19611R	PARTICIPANT	\N	PRESENT	0
764690	761714	07029T	PARTICIPANT	\N	PRESENT	0
764691	761714	21078N	PARTICIPANT	\N	PRESENT	0
764692	761714	19723Y	PARTICIPANT	\N	PRESENT	0
764693	761714	19699S	PARTICIPANT	\N	PRESENT	0
764694	761714	08015R	PARTICIPANT	\N	PRESENT	0
764695	761714	19711U	PARTICIPANT	\N	PRESENT	0
764696	761714	08010L	PARTICIPANT	\N	PRESENT	0
764697	761714	08034U	PARTICIPANT	\N	PRESENT	0
764698	761714	21087P	PARTICIPANT	\N	PRESENT	0
764699	761714	20052X	PARTICIPANT	\N	PRESENT	0
764700	761714	18207D	PARTICIPANT	\N	PRESENT	0
764701	761714	14205J	PARTICIPANT	\N	PRESENT	0
764702	761714	14059S	PARTICIPANT	\N	PRESENT	0
764703	761714	21054E	PARTICIPANT	\N	PRESENT	0
764704	761714	12016W	PARTICIPANT	\N	PRESENT	0
764705	761714	14251Q	PARTICIPANT	\N	PRESENT	0
764706	761714	20142Y	PARTICIPANT	\N	PRESENT	0
764707	761714	21075K	PARTICIPANT	\N	PRESENT	0
764708	761714	21058J	PARTICIPANT	\N	PRESENT	0
764709	761714	21040X	PARTICIPANT	\N	PRESENT	0
764710	761714	21073H	PARTICIPANT	\N	PRESENT	0
764711	761714	19563B	PARTICIPANT	\N	PRESENT	0
764712	761714	14147R	PARTICIPANT	\N	PRESENT	0
764713	761714	20028X	PARTICIPANT	\N	PRESENT	0
764714	761714	20018V	PARTICIPANT	\N	PRESENT	0
764715	761714	14223L	PARTICIPANT	\N	PRESENT	0
764716	761714	14257W	PARTICIPANT	\N	PRESENT	0
764717	761714	14071N	PARTICIPANT	\N	PRESENT	0
764718	761714	18231D	PARTICIPANT	\N	PRESENT	0
764719	761714	21039F	PARTICIPANT	\N	PRESENT	0
764720	761714	21060C	PARTICIPANT	\N	PRESENT	0
764721	761714	08073C	PARTICIPANT	\N	PRESENT	0
764722	761714	08061X	PARTICIPANT	\N	PRESENT	0
764723	761714	21055F	PARTICIPANT	\N	PRESENT	0
764724	761714	20148F	PARTICIPANT	\N	PRESENT	0
764725	761714	19533U	PARTICIPANT	\N	PRESENT	0
764726	761714	21053D	PARTICIPANT	\N	PRESENT	0
764727	761714	05012A	PARTICIPANT	\N	PRESENT	0
764728	761714	20130U	PARTICIPANT	\N	PRESENT	0
764729	761714	17965H	PARTICIPANT	\N	PRESENT	0
764731	761714	11090Q	PARTICIPANT	\N	PRESENT	0
764732	761714	19679N	PARTICIPANT	\N	PRESENT	0
764733	761714	14331P	PARTICIPANT	\N	PRESENT	0
764734	761714	14055N	PARTICIPANT	\N	PRESENT	0
764735	761714	14225N	PARTICIPANT	\N	PRESENT	0
764736	761714	20082E	PARTICIPANT	\N	PRESENT	0
764737	761714	10015M	PARTICIPANT	\N	PRESENT	0
764738	761714	04033B	PARTICIPANT	\N	PRESENT	0
764739	761714	21068L	PARTICIPANT	\N	PRESENT	0
764740	761714	21038E	PARTICIPANT	\N	PRESENT	0
764741	761714	19798U	PARTICIPANT	\N	PRESENT	0
764742	761714	20054A	PARTICIPANT	\N	PRESENT	0
764743	761714	14229S	PARTICIPANT	\N	PRESENT	0
764744	761714	21070E	PARTICIPANT	\N	PRESENT	0
764745	761714	21056G	PARTICIPANT	\N	PRESENT	0
764746	761714	20020P	PARTICIPANT	\N	PRESENT	0
764747	761714	21064G	PARTICIPANT	\N	PRESENT	0
764748	761714	21059K	PARTICIPANT	\N	PRESENT	0
764749	761714	11045K	PARTICIPANT	\N	PRESENT	0
764750	761714	20092G	PARTICIPANT	\N	PRESENT	0
764751	761714	20044X	PARTICIPANT	\N	PRESENT	0
764752	761714	19687N	PARTICIPANT	\N	PRESENT	0
764753	761714	20098N	PARTICIPANT	\N	PRESENT	0
764754	761714	21079P	PARTICIPANT	\N	PRESENT	0
764755	761714	01058X	PARTICIPANT	\N	PRESENT	0
764756	761714	21049H	PARTICIPANT	\N	PRESENT	0
764757	761714	19703U	PARTICIPANT	\N	PRESENT	0
764758	761714	19713W	PARTICIPANT	\N	PRESENT	0
764759	761714	20062A	PARTICIPANT	\N	PRESENT	0
764760	761714	21094N	PARTICIPANT	\N	PRESENT	0
764761	761714	20084G	PARTICIPANT	\N	PRESENT	0
764762	761714	21069M	PARTICIPANT	\N	PRESENT	0
764763	761714	21095P	PARTICIPANT	\N	PRESENT	0
764764	761714	21061D	PARTICIPANT	\N	PRESENT	0
764765	761714	20064C	PARTICIPANT	\N	PRESENT	0
764766	761714	20046A	PARTICIPANT	\N	PRESENT	0
764767	761714	21031W	PARTICIPANT	\N	PRESENT	0
764768	761714	20026V	PARTICIPANT	\N	PRESENT	0
764769	761714	19749K	PARTICIPANT	\N	PRESENT	0
740159	738008	19711U	PARTICIPANT	\N	PRESENT	0
740160	740118	14151M	PARTICIPANT	\N	PRESENT	0
740163	738008	20066E	PARTICIPANT	\N	PRESENT	0
740165	738263	12041X	PARTICIPANT	\N	PRESENT	0
740166	738263	19565D	PARTICIPANT	\N	PRESENT	0
740167	738263	01058X	PARTICIPANT	\N	PRESENT	0
740168	738263	11027H	PARTICIPANT	\N	PRESENT	0
740169	738263	04042C	PRESIDENT	0	PRESENT	0
740170	738263	11054L	PARTICIPANT	\N	PRESENT	0
740171	738263	11066Q	PARTICIPANT	\N	PRESENT	0
740172	738263	19669L	PARTICIPANT	\N	PRESENT	0
740173	738263	19421M	PARTICIPANT	\N	PRESENT	0
740174	738263	14193X	PARTICIPANT	\N	PRESENT	0
740175	738263	19347U	PARTICIPANT	\N	PRESENT	0
740176	738263	97011G	PARTICIPANT	\N	PRESENT	0
740177	738263	08061X	PARTICIPANT	\N	PRESENT	0
740178	738263	14249W	PARTICIPANT	\N	PRESENT	0
740179	738263	08047A	PARTICIPANT	\N	PRESENT	0
740180	738263	20128B	PARTICIPANT	\N	PRESENT	0
740181	738263	14059S	PARTICIPANT	\N	PRESENT	0
740182	738263	04035D	PARTICIPANT	\N	PRESENT	0
740183	738263	14133K	PARTICIPANT	\N	PRESENT	0
740184	738263	01062T	PARTICIPANT	\N	PRESENT	0
740185	738263	08034U	PARTICIPANT	\N	PRESENT	0
740186	738263	11041F	PARTICIPANT	\N	PRESENT	0
740187	738263	20042V	PARTICIPANT	\N	PRESENT	0
740188	738263	20064C	PARTICIPANT	\N	PRESENT	0
740189	738263	14267Y	PARTICIPANT	\N	PRESENT	0
740190	738263	11083R	PARTICIPANT	\N	PRESENT	0
740191	738263	14211G	PARTICIPANT	\N	PRESENT	0
740192	738263	14255U	PARTICIPANT	\N	PRESENT	0
740193	738263	17023S	PARTICIPANT	\N	PRESENT	0
740194	738008	18083K	PARTICIPANT	\N	PRESENT	0
740196	738008	14021P	PARTICIPANT	\N	PRESENT	0
740201	738008	14249W	PARTICIPANT	\N	PRESENT	0
740198	738008	01048V	PARTICIPANT	\N	PRESENT	0
740199	738008	19749K	PARTICIPANT	\N	PRESENT	0
740200	738008	19575F	PARTICIPANT	\N	PRESENT	0
740202	738008	20110Q	PARTICIPANT	\N	PRESENT	0
740203	738008	07029T	PARTICIPANT	\N	PRESENT	0
740213	738008	20070A	PARTICIPANT	\N	PRESENT	0
740214	738008	19649G	PARTICIPANT	\N	PRESENT	0
740215	738008	19725B	PARTICIPANT	\N	PRESENT	0
740216	738008	20094J	PARTICIPANT	\N	PRESENT	0
740266	738009	14053L	PARTICIPANT	\N	PRESENT	0
740267	738009	19749K	PARTICIPANT	\N	PRESENT	0
740268	738009	19725B	PARTICIPANT	\N	PRESENT	0
740269	738009	11045K	PARTICIPANT	\N	PRESENT	0
740270	738009	20018V	PARTICIPANT	\N	PRESENT	0
740271	738009	20092G	PARTICIPANT	\N	PRESENT	0
740272	738009	20110Q	PARTICIPANT	\N	PRESENT	0
740273	738009	11033F	PARTICIPANT	\N	PRESENT	0
740274	738009	11056N	PARTICIPANT	\N	PRESENT	0
740275	738009	20034V	PARTICIPANT	\N	PRESENT	0
740276	738009	19515S	PARTICIPANT	\N	PRESENT	0
740277	738009	20102Q	PARTICIPANT	\N	PRESENT	0
740278	738009	19747H	PARTICIPANT	\N	PRESENT	0
740279	738009	19649G	PARTICIPANT	\N	PRESENT	0
740280	738009	07029T	PARTICIPANT	\N	PRESENT	0
740281	738009	14107H	PARTICIPANT	\N	PRESENT	0
740282	738009	19447X	PARTICIPANT	\N	PRESENT	0
740283	738009	19713W	PARTICIPANT	\N	PRESENT	0
740284	738009	20248J	PARTICIPANT	\N	PRESENT	0
740285	738009	14331P	PARTICIPANT	\N	PRESENT	0
740286	738009	20032T	PARTICIPANT	\N	PRESENT	0
740293	738009	11072N	PARTICIPANT	\N	PRESENT	0
740288	738009	11090Q	PARTICIPANT	\N	PRESENT	0
740289	738009	14089Y	PARTICIPANT	\N	PRESENT	0
740290	738009	14038Y	PARTICIPANT	\N	PRESENT	0
740291	738009	11099A	PARTICIPANT	\N	PRESENT	0
740292	738009	14187A	PARTICIPANT	\N	PRESENT	0
740304	738009	19758L	PARTICIPANT	\N	PRESENT	0
740305	738263	14097Y	PARTICIPANT	\N	PRESENT	0
740306	738009	20062A	PARTICIPANT	\N	PRESENT	0
740307	738009	14042U	PARTICIPANT	\N	PRESENT	0
740315	738009	14069U	PARTICIPANT	\N	PRESENT	0
740319	738009	20038A	PARTICIPANT	\N	PRESENT	0
740320	738009	20100N	PARTICIPANT	\N	PRESENT	0
740321	738009	04033B	PARTICIPANT	\N	PRESENT	0
740322	738009	01028R	PARTICIPANT	\N	PRESENT	0
740323	738009	19533U	PARTICIPANT	\N	PRESENT	0
740324	738009	14169X	PARTICIPANT	\N	PRESENT	0
740325	738009	14147R	PARTICIPANT	\N	PRESENT	0
740326	738009	11053K	PARTICIPANT	\N	PRESENT	0
740327	738009	14205J	PARTICIPANT	\N	PRESENT	0
740264	738009	95063L	PARTICIPANT	\N	PRESENT	0
740265	738009	14215L	PARTICIPANT	\N	PRESENT	0
740328	738009	08061X	PARTICIPANT	\N	PRESENT	0
740329	738009	14231L	PARTICIPANT	\N	PRESENT	0
740330	738009	14083S	PARTICIPANT	\N	PRESENT	0
740331	738009	20094J	PARTICIPANT	\N	PRESENT	0
740332	738009	20022R	PARTICIPANT	\N	PRESENT	0
740333	738009	17737W	PARTICIPANT	\N	PRESENT	0
740334	738009	19711U	PARTICIPANT	\N	PRESENT	0
740335	738009	14001X	PARTICIPANT	\N	PRESENT	0
740336	738009	14219Q	PARTICIPANT	\N	PRESENT	0
740337	738009	20040T	PARTICIPANT	\N	PRESENT	0
740379	738010	14053L	PARTICIPANT	\N	PRESENT	0
740380	738010	19503N	PARTICIPANT	\N	PRESENT	0
740381	738010	20018V	PARTICIPANT	\N	PRESENT	0
740382	738010	11033F	PARTICIPANT	\N	PRESENT	0
740383	738010	20110Q	PARTICIPANT	\N	PRESENT	0
740384	738010	20102Q	PARTICIPANT	\N	PRESENT	0
740385	738010	14231L	PARTICIPANT	\N	PRESENT	0
740386	738010	14089Y	PARTICIPANT	\N	PRESENT	0
740387	738010	19725B	PARTICIPANT	\N	PRESENT	0
740388	738010	19649G	PARTICIPANT	\N	PRESENT	0
740389	738010	19747H	PARTICIPANT	\N	PRESENT	0
740390	738010	19515S	PARTICIPANT	\N	PRESENT	0
740391	738010	20038A	PARTICIPANT	\N	PRESENT	0
740392	738010	19758L	PARTICIPANT	\N	PRESENT	0
740393	738010	14169X	PARTICIPANT	\N	PRESENT	0
740394	738010	20248J	PARTICIPANT	\N	PRESENT	0
740395	738010	20040T	PARTICIPANT	\N	PRESENT	0
740396	738010	19447X	PARTICIPANT	\N	PRESENT	0
740397	738010	20034V	PARTICIPANT	\N	PRESENT	0
740398	738010	18083K	PARTICIPANT	\N	PRESENT	0
740399	738010	17737W	PARTICIPANT	\N	PRESENT	0
740400	738010	14215L	PARTICIPANT	\N	PRESENT	0
740401	738010	11072N	PARTICIPANT	\N	PRESENT	0
740402	738010	20122U	PARTICIPANT	\N	PRESENT	0
740403	738010	07029T	PARTICIPANT	\N	PRESENT	0
740409	738010	20100N	PARTICIPANT	\N	PRESENT	0
740410	738010	95063L	PARTICIPANT	\N	PRESENT	0
740411	738010	14107H	PARTICIPANT	\N	PRESENT	0
740412	738010	05008E	PARTICIPANT	\N	PRESENT	0
740417	738010	11056N	PARTICIPANT	\N	PRESENT	0
740420	738010	01028R	PARTICIPANT	\N	PRESENT	0
740421	738010	20022R	PARTICIPANT	\N	PRESENT	0
740422	738010	20266L	PARTICIPANT	\N	PRESENT	0
740423	738010	20114U	PARTICIPANT	\N	PRESENT	0
740424	738010	18193Q	PARTICIPANT	\N	PRESENT	0
740425	738010	14147R	PARTICIPANT	\N	PRESENT	0
740426	738010	11026G	PARTICIPANT	\N	PRESENT	0
740427	738010	14069U	PARTICIPANT	\N	PRESENT	0
740428	738010	14071N	PARTICIPANT	\N	PRESENT	0
740377	738010	11070L	PARTICIPANT	\N	PRESENT	0
740378	738010	19749K	PARTICIPANT	\N	PRESENT	0
740429	738010	14219Q	PARTICIPANT	\N	PRESENT	0
740430	738010	20086J	PARTICIPANT	\N	PRESENT	0
740431	738010	14187A	PARTICIPANT	\N	PRESENT	0
740432	738010	14179A	PARTICIPANT	\N	PRESENT	0
740629	740445	19399H	PARTICIPANT	\N	PRESENT	0
740630	740445	20134Y	PARTICIPANT	\N	PRESENT	0
740631	740445	19611R	PARTICIPANT	\N	PRESENT	0
743995	743994	14038Y	PARTICIPANT	\N	PRESENT	0
743997	743996	14038Y	PARTICIPANT	\N	PRESENT	0
743998	743996	20094J	PARTICIPANT	\N	PRESENT	0
744000	743999	14038Y	PARTICIPANT	\N	PRESENT	0
744001	743999	20094J	PARTICIPANT	\N	PRESENT	0
744003	744002	14038Y	PARTICIPANT	\N	PRESENT	0
744004	744002	20094J	PARTICIPANT	\N	PRESENT	0
744006	744005	14038Y	PARTICIPANT	\N	PRESENT	0
744007	744005	20094J	PARTICIPANT	\N	PRESENT	0
744108	744107	14053L	PARTICIPANT	\N	PRESENT	0
744109	744107	11026G	PARTICIPANT	\N	PRESENT	0
744112	744111	14053L	PARTICIPANT	\N	PRESENT	0
744113	744111	11026G	PARTICIPANT	\N	PRESENT	0
744164	738365	05008E	PARTICIPANT	\N	EXCUSE	0
744543	744542	14195A	PARTICIPANT	\N	PRESENT	0
744544	744542	04057K	PARTICIPANT	\N	PRESENT	0
767492	764866	14097Y	PARTICIPANT	\N	PRESENT	0
767493	764866	14133K	PARTICIPANT	\N	PRESENT	0
767494	764866	19531S	PARTICIPANT	\N	PRESENT	0
767495	764866	21073H	PARTICIPANT	\N	PRESENT	0
767496	764866	08069G	PARTICIPANT	\N	PRESENT	0
767497	764866	20064C	PARTICIPANT	\N	PRESENT	0
767498	764866	20252E	PARTICIPANT	\N	PRESENT	0
767499	764866	98022P	PARTICIPANT	\N	PRESENT	0
767500	764866	14267Y	PARTICIPANT	\N	PRESENT	0
767501	764866	11064N	PARTICIPANT	\N	PRESENT	0
767502	764866	99004R	PARTICIPANT	\N	PRESENT	0
767503	764866	14255U	PARTICIPANT	\N	PRESENT	0
767504	764866	14193X	PARTICIPANT	\N	EXCUSE	0
767505	764866	19745F	PARTICIPANT	\N	EXCUSE	0
767506	764866	14211G	PARTICIPANT	\N	EXCUSE	0
767507	764866	17023S	PARTICIPANT	\N	EXCUSE	0
767508	764867	21036C	PARTICIPANT	\N	PRESENT	0
767509	764867	95041E	PARTICIPANT	\N	PRESENT	0
767510	764867	21031W	PARTICIPANT	\N	PRESENT	0
767511	764867	19565D	PARTICIPANT	\N	PRESENT	0
767512	764867	20072C	PARTICIPANT	\N	PRESENT	0
767513	764867	01058X	PARTICIPANT	\N	PRESENT	0
767514	764867	11027H	PARTICIPANT	\N	PRESENT	0
767515	764867	14001X	PARTICIPANT	\N	PRESENT	0
767516	764867	04042C	PARTICIPANT	\N	PRESENT	0
767517	764867	19669L	PARTICIPANT	\N	PRESENT	0
767518	764867	08056B	PARTICIPANT	\N	PRESENT	0
767519	764867	12028B	PARTICIPANT	\N	PRESENT	0
767520	764867	17737W	PARTICIPANT	\N	PRESENT	0
767521	764867	11115U	PARTICIPANT	\N	PRESENT	0
767522	764867	14055N	PARTICIPANT	\N	PRESENT	0
767523	764867	19421M	PARTICIPANT	\N	PRESENT	0
767524	764867	19709B	PARTICIPANT	\N	PRESENT	0
767525	764867	21067K	PARTICIPANT	\N	PRESENT	0
767526	764867	19347U	PARTICIPANT	\N	PRESENT	0
767527	764867	14179A	PARTICIPANT	\N	PRESENT	0
767528	764867	07033P	PARTICIPANT	\N	PRESENT	0
767529	764867	17367Q	PARTICIPANT	\N	PRESENT	0
767530	764867	14249W	PARTICIPANT	\N	PRESENT	0
767531	764867	08047A	PRESIDENT	0	PRESENT	0
767532	764867	14037X	PARTICIPANT	\N	PRESENT	0
767533	764867	14097Y	PARTICIPANT	\N	PRESENT	0
767534	764867	14133K	PARTICIPANT	\N	PRESENT	0
767535	764867	19531S	PARTICIPANT	\N	PRESENT	0
767536	764867	21073H	PARTICIPANT	\N	PRESENT	0
767537	764867	08069G	PARTICIPANT	\N	PRESENT	0
767538	764867	20064C	PARTICIPANT	\N	PRESENT	0
767539	764867	20252E	PARTICIPANT	\N	PRESENT	0
767540	764867	14251Q	PARTICIPANT	\N	PRESENT	0
767541	764867	98022P	PARTICIPANT	\N	PRESENT	0
767542	764867	14267Y	PARTICIPANT	\N	PRESENT	0
767543	764867	11064N	PARTICIPANT	\N	PRESENT	0
767544	764867	99004R	PARTICIPANT	\N	PRESENT	0
767545	764867	14255U	PARTICIPANT	\N	PRESENT	0
767546	764867	14193X	PARTICIPANT	\N	EXCUSE	0
767547	764867	19745F	PARTICIPANT	\N	EXCUSE	0
767548	764867	14211G	PARTICIPANT	\N	EXCUSE	0
767549	764867	17023S	PARTICIPANT	\N	EXCUSE	0
767550	765497	19545Y	PARTICIPANT	\N	PRESENT	0
767552	767551	20136B	PARTICIPANT	\N	PRESENT	0
767553	767551	19820Y	PARTICIPANT	\N	PRESENT	0
767555	767554	20136B	PARTICIPANT	\N	PRESENT	0
767556	767554	19820Y	PARTICIPANT	\N	PRESENT	0
767558	767557	19820Y	PARTICIPANT	\N	PRESENT	0
767559	763756	20032T	PARTICIPANT	\N	PRESENT	0
767560	763756	21084L	PARTICIPANT	\N	PRESENT	0
767561	763756	21035B	PARTICIPANT	\N	EXCUSE	0
767562	763756	08060W	PARTICIPANT	\N	PRESENT	0
767563	763756	21065H	PARTICIPANT	\N	PRESENT	0
767564	763756	19701S	PARTICIPANT	\N	EXCUSE	0
767565	763756	11065P	PARTICIPANT	\N	PRESENT	0
767566	763756	19251M	PARTICIPANT	\N	PRESENT	0
767567	763756	21062E	PARTICIPANT	\N	PRESENT	0
767568	763756	20100N	PARTICIPANT	\N	PRESENT	0
767569	763756	20120S	PARTICIPANT	\N	PRESENT	0
767570	763756	19820Y	PARTICIPANT	\N	PRESENT	0
767571	763756	20068G	PARTICIPANT	\N	PRESENT	0
767572	763756	20106U	PARTICIPANT	\N	PRESENT	0
767573	763756	14219Q	PRESIDENT	0	PRESENT	0
767574	763756	14031R	PARTICIPANT	\N	PRESENT	0
767575	763756	19826F	PARTICIPANT	\N	PRESENT	0
767576	763756	21080G	PARTICIPANT	\N	PRESENT	0
767577	763756	21060C	PARTICIPANT	\N	PRESENT	0
767578	763756	21053D	PARTICIPANT	\N	PRESENT	0
767579	763756	05012A	PARTICIPANT	\N	PRESENT	0
767580	763756	21070E	PARTICIPANT	\N	PRESENT	0
767581	763756	20136B	PARTICIPANT	\N	PRESENT	0
767582	763756	21051B	PARTICIPANT	\N	PRESENT	0
767583	763756	20046A	PARTICIPANT	\N	PRESENT	0
767584	763756	21082J	PARTICIPANT	\N	PRESENT	0
767585	763756	14169X	PARTICIPANT	\N	EXCUSE	0
767586	763756	19681G	PARTICIPANT	\N	EXCUSE	0
767587	765846	19681G	PARTICIPANT	\N	EXCUSE	0
767588	767291	19681G	PARTICIPANT	\N	EXCUSE	0
767589	765403	19507S	PARTICIPANT	\N	PRESENT	0
767590	765403	98022P	PARTICIPANT	\N	PRESENT	0
767592	765403	86034E	PARTICIPANT	\N	PRESENT	0
767593	765403	19798U	PARTICIPANT	\N	PRESENT	0
767594	765403	14331P	PARTICIPANT	\N	PRESENT	0
767595	765403	20068G	PARTICIPANT	\N	PRESENT	0
767596	765403	21068L	PARTICIPANT	\N	PRESENT	0
767597	765403	08028W	PARTICIPANT	\N	PRESENT	0
767598	765403	14189C	PARTICIPANT	\N	PRESENT	0
767599	765403	04008A	PARTICIPANT	\N	PRESENT	0
767600	765403	21029D	PARTICIPANT	\N	PRESENT	0
767601	765403	20074E	PARTICIPANT	\N	PRESENT	0
767602	765403	21040X	PARTICIPANT	\N	PRESENT	0
767603	765403	19782L	PARTICIPANT	\N	PRESENT	0
767604	765403	19705W	PARTICIPANT	\N	PRESENT	0
767605	765403	19707Y	PARTICIPANT	\N	PRESENT	0
767606	765403	21053D	PARTICIPANT	\N	PRESENT	0
767607	765403	20024T	PARTICIPANT	\N	PRESENT	0
767608	765403	17229F	PARTICIPANT	\N	PRESENT	0
767609	765403	14107H	PARTICIPANT	\N	PRESENT	0
767610	765403	19866P	PARTICIPANT	\N	PRESENT	0
767611	765403	14195A	PARTICIPANT	\N	PRESENT	0
767612	765403	11064N	PARTICIPANT	\N	PRESENT	0
767613	765403	21070E	PARTICIPANT	\N	PRESENT	0
767614	765403	21057H	PARTICIPANT	\N	PRESENT	0
767615	765403	19489J	PARTICIPANT	\N	PRESENT	0
767616	765403	19721W	PARTICIPANT	\N	PRESENT	0
767617	765403	19619A	PARTICIPANT	\N	PRESENT	0
767618	765403	08009T	PARTICIPANT	\N	PRESENT	0
767625	765403	14221J	PARTICIPANT	\N	PRESENT	0
767620	765403	21077M	PARTICIPANT	\N	PRESENT	0
767621	765403	04042C	PARTICIPANT	\N	PRESENT	0
767622	765403	99004R	PARTICIPANT	\N	PRESENT	0
767623	765403	21056G	PARTICIPANT	\N	PRESENT	0
767624	765403	14207L	PARTICIPANT	\N	PRESENT	0
767630	765403	21075K	PARTICIPANT	\N	PRESENT	0
767631	765403	19687N	PARTICIPANT	\N	PRESENT	0
767632	765403	20046A	PARTICIPANT	\N	PRESENT	0
767633	765403	19758L	PARTICIPANT	\N	PRESENT	0
767634	765403	19575F	PARTICIPANT	\N	PRESENT	0
767635	765403	11040E	PARTICIPANT	\N	PRESENT	0
767636	765403	14133K	PARTICIPANT	\N	PRESENT	0
767637	765403	19760E	PARTICIPANT	\N	PRESENT	0
767638	765403	19593H	PARTICIPANT	\N	PRESENT	0
767639	765403	21049H	PARTICIPANT	\N	PRESENT	0
767640	765403	19703U	PARTICIPANT	\N	PRESENT	0
767641	765403	20102Q	PARTICIPANT	\N	PRESENT	0
767642	765403	11056N	PARTICIPANT	\N	PRESENT	0
767643	765403	20134Y	PARTICIPANT	\N	PRESENT	0
767644	765403	01058X	PARTICIPANT	\N	PRESENT	0
767645	765403	20142Y	PARTICIPANT	\N	PRESENT	0
767646	765403	20036X	PARTICIPANT	\N	PRESENT	0
767647	765403	19347U	PARTICIPANT	\N	PRESENT	0
767648	765403	20130U	PARTICIPANT	\N	PRESENT	0
767649	765403	20078J	PARTICIPANT	\N	PRESENT	0
767650	765403	20092G	PARTICIPANT	\N	PRESENT	0
767651	765403	18083K	PARTICIPANT	\N	PRESENT	0
767652	765403	21073H	PARTICIPANT	\N	PRESENT	0
767653	765403	19621T	PARTICIPANT	\N	PRESENT	0
767654	765403	19367Y	PARTICIPANT	\N	PRESENT	0
767655	765403	21091K	PARTICIPANT	\N	PRESENT	0
767656	765403	20128B	PARTICIPANT	\N	PRESENT	0
767657	765403	20016T	PARTICIPANT	\N	PRESENT	0
767658	765403	08069G	PARTICIPANT	\N	PRESENT	0
767659	765403	21097R	PARTICIPANT	\N	PRESENT	0
767660	765403	14259Y	PARTICIPANT	\N	PRESENT	0
767661	765403	08061X	PARTICIPANT	\N	PRESENT	0
741503	740805	14189C	PARTICIPANT	\N	EXCUSE	0
741505	740805	04070G	PRESIDENT	0	PRESENT	0
741506	740805	14038Y	PARTICIPANT	\N	PRESENT	0
741507	740805	14179A	PARTICIPANT	\N	PRESENT	0
741820	740805	14147R	PARTICIPANT	\N	PRESENT	0
741821	740805	14237S	PARTICIPANT	\N	PRESENT	0
741822	740805	20138D	PARTICIPANT	\N	PRESENT	0
741824	740805	10015M	PARTICIPANT	\N	PRESENT	0
741825	740805	14030Q	PARTICIPANT	\N	PRESENT	0
741826	740805	20082E	PARTICIPANT	\N	PRESENT	0
741834	740805	20094J	PARTICIPANT	\N	PRESENT	0
741842	740805	20152B	PARTICIPANT	\N	PRESENT	0
741845	740805	20140W	PARTICIPANT	\N	PRESENT	0
741849	740805	20034V	PARTICIPANT	\N	PRESENT	0
741863	740805	20132W	PARTICIPANT	\N	PRESENT	0
741883	740805	20128B	PARTICIPANT	\N	PRESENT	0
748469	741501	19693L	PARTICIPANT	\N	EXCUSE	0
748470	741501	20106U	PARTICIPANT	\N	EXCUSE	0
749509	748107	17965H	PARTICIPANT	\N	PRESENT	0
749507	748107	14225N	PARTICIPANT	\N	PRESENT	0
749508	748107	01043Q	PARTICIPANT	\N	PRESENT	0
749757	748108	95063L	PARTICIPANT	\N	PRESENT	0
749511	748107	11064N	PARTICIPANT	\N	PRESENT	0
749512	748107	20152B	PARTICIPANT	\N	PRESENT	0
749520	748107	20136B	PARTICIPANT	\N	PRESENT	0
749759	748108	19593H	PARTICIPANT	\N	PRESENT	0
749760	748108	19479G	PARTICIPANT	\N	PRESENT	0
749761	748108	19699S	PARTICIPANT	\N	PRESENT	0
749762	748108	20252E	PARTICIPANT	\N	PRESENT	0
749763	748108	19383Y	PARTICIPANT	\N	PRESENT	0
749768	748108	19507S	PARTICIPANT	\N	PRESENT	0
749770	748108	11077T	PARTICIPANT	\N	PRESENT	0
750009	745859	05008E	PARTICIPANT	\N	EXCUSE	0
750010	745859	11010L	PARTICIPANT	\N	EXCUSE	0
750011	745859	11043H	PARTICIPANT	\N	EXCUSE	0
750023	750022	19673G	PARTICIPANT	\N	PRESENT	0
750024	750022	19749K	PARTICIPANT	\N	PRESENT	0
750405	750403	11031D	PARTICIPANT	\N	PRESENT	0
750406	750403	20052X	PARTICIPANT	\N	PRESENT	0
750407	750403	08073C	PARTICIPANT	\N	PRESENT	0
750408	750403	04035D	PARTICIPANT	\N	PRESENT	0
750409	750403	11026G	PARTICIPANT	\N	PRESENT	0
750411	750403	20092G	PARTICIPANT	\N	PRESENT	0
750416	750403	20104S	PARTICIPANT	\N	PRESENT	0
750428	750427	19820Y	PARTICIPANT	\N	PRESENT	0
750429	750427	19745F	PARTICIPANT	\N	PRESENT	0
750430	750427	20076G	PARTICIPANT	\N	PRESENT	0
750431	750427	20914V	PARTICIPANT	\N	EXCUSE	0
750432	750427	14169X	PARTICIPANT	\N	EXCUSE	0
750433	750427	20118Y	PARTICIPANT	\N	EXCUSE	0
750434	750427	14237S	PARTICIPANT	\N	PRESENT	0
750435	750427	20070A	PARTICIPANT	\N	PRESENT	0
750436	750427	19768N	PARTICIPANT	\N	PRESENT	0
750437	750427	05012A	PRESIDENT	0	PRESENT	0
750438	750427	20104S	PARTICIPANT	\N	PRESENT	0
750441	750427	20128B	PARTICIPANT	\N	PRESENT	0
750442	750427	14229S	PARTICIPANT	\N	PRESENT	0
750466	750427	20046A	PARTICIPANT	\N	PRESENT	0
750676	750635	19711U	PARTICIPANT	\N	PRESENT	0
750677	750635	19531S	PARTICIPANT	\N	PRESENT	0
750678	750635	20044X	PARTICIPANT	\N	PRESENT	0
750679	750635	20080C	PARTICIPANT	\N	PRESENT	0
750681	750635	19762G	PARTICIPANT	\N	PRESENT	0
750685	750663	19611R	PRESIDENT	0	PRESENT	0
750686	750663	20142Y	PARTICIPANT	\N	PRESENT	0
750687	750663	19693L	PARTICIPANT	\N	PRESENT	0
750688	750663	20052X	PARTICIPANT	\N	PRESENT	0
750689	750663	14030Q	PARTICIPANT	\N	PRESENT	0
750690	750663	20264J	PARTICIPANT	\N	PRESENT	0
750691	750663	14109K	PARTICIPANT	\N	PRESENT	0
750692	750663	11104D	PARTICIPANT	\N	PRESENT	0
750693	750663	20980G	PARTICIPANT	\N	PRESENT	0
750694	750663	20124W	PARTICIPANT	\N	PRESENT	0
750695	750663	19758L	PARTICIPANT	\N	PRESENT	0
750696	750663	20026V	PARTICIPANT	\N	PRESENT	0
750697	750663	19621T	PARTICIPANT	\N	PRESENT	0
750698	750635	19647E	PARTICIPANT	\N	PRESENT	0
750699	750635	04071H	PARTICIPANT	\N	PRESENT	0
750700	750635	11110B	PARTICIPANT	\N	PRESENT	0
750702	750635	08010L	PARTICIPANT	\N	PRESENT	0
750703	750635	20036X	PARTICIPANT	\N	PRESENT	0
750704	750635	14083S	PARTICIPANT	\N	PRESENT	0
750705	750635	19741B	PARTICIPANT	\N	PRESENT	0
750706	750635	20086J	PARTICIPANT	\N	PRESENT	0
750708	750635	11074Q	PARTICIPANT	\N	PRESENT	0
750710	750635	19671E	PARTICIPANT	\N	PRESENT	0
750711	750663	19533U	PARTICIPANT	\N	PRESENT	0
750712	750663	14073Q	PARTICIPANT	\N	PRESENT	0
750713	750663	20152B	PARTICIPANT	\N	PRESENT	0
750714	750663	14229S	PARTICIPANT	\N	PRESENT	0
750715	750663	20172F	PARTICIPANT	\N	PRESENT	0
750716	750663	19735D	PARTICIPANT	\N	PRESENT	0
750717	750663	08012N	PARTICIPANT	\N	PRESENT	0
750718	750663	20084G	PARTICIPANT	\N	PRESENT	0
750719	750635	14327T	PARTICIPANT	\N	PRESENT	0
750723	750635	07029T	PARTICIPANT	\N	PRESENT	0
750727	749997	14059S	PARTICIPANT	\N	PRESENT	0
750728	749997	14097Y	PARTICIPANT	\N	PRESENT	0
750729	749997	14133K	PARTICIPANT	\N	PRESENT	0
750730	749997	19565D	PARTICIPANT	\N	PRESENT	0
750731	749997	20072C	PARTICIPANT	\N	PRESENT	0
750732	749997	11041F	PARTICIPANT	\N	PRESENT	0
750733	749997	11027H	PARTICIPANT	\N	PRESENT	0
750734	749997	16685X	PARTICIPANT	\N	PRESENT	0
750735	749997	04042C	PRESIDENT	0	PRESENT	0
750736	749997	11054L	PARTICIPANT	\N	PRESENT	0
750737	749997	11066Q	PARTICIPANT	\N	PRESENT	0
750738	749997	14105F	PARTICIPANT	\N	PRESENT	0
750739	749997	19421M	PARTICIPANT	\N	PRESENT	0
750740	749997	19709B	PARTICIPANT	\N	PRESENT	0
750741	749997	98022P	PARTICIPANT	\N	PRESENT	0
750742	749997	14193X	PARTICIPANT	\N	PRESENT	0
750743	749997	14267Y	PARTICIPANT	\N	PRESENT	0
750744	749997	11083R	PARTICIPANT	\N	PRESENT	0
750745	749997	97011G	PARTICIPANT	\N	PRESENT	0
750746	749997	08061X	PARTICIPANT	\N	PRESENT	0
750747	749997	14211G	PARTICIPANT	\N	PRESENT	0
750748	749997	08047A	PARTICIPANT	\N	PRESENT	0
750750	750635	19667J	PARTICIPANT	\N	PRESENT	0
750758	749997	20064C	PARTICIPANT	\N	PRESENT	0
750759	749997	14255U	PARTICIPANT	\N	PRESENT	0
750763	750635	11012A	PARTICIPANT	\N	PRESENT	0
750770	750635	14257W	PARTICIPANT	\N	PRESENT	0
750772	750635	11070L	PARTICIPANT	\N	PRESENT	0
750777	749959	14089Y	PARTICIPANT	\N	PRESENT	0
750778	749959	11056N	PARTICIPANT	\N	PRESENT	0
750779	749959	19729F	PARTICIPANT	\N	PRESENT	0
750780	749959	19649G	PARTICIPANT	\N	PRESENT	0
750781	749959	14111D	PARTICIPANT	\N	PRESENT	0
750782	749959	14069U	PARTICIPANT	\N	PRESENT	0
750783	749959	19447X	PARTICIPANT	\N	PRESENT	0
750784	749959	14215L	PARTICIPANT	\N	PRESENT	0
750785	749959	10015M	PARTICIPANT	\N	PRESENT	0
750786	749959	04047H	PRESIDENT	0	PRESENT	0
750787	749959	19673G	PARTICIPANT	\N	PRESENT	0
750788	749959	19489J	PARTICIPANT	\N	PRESENT	0
750789	749959	14147R	PARTICIPANT	\N	PRESENT	0
750790	749959	20022R	PARTICIPANT	\N	PRESENT	0
750791	749959	19749K	PARTICIPANT	\N	PRESENT	0
750822	749959	14021P	PARTICIPANT	\N	PRESENT	0
750824	750635	11053K	PARTICIPANT	\N	PRESENT	0
750842	749959	01028R	PARTICIPANT	\N	PRESENT	0
750874	749959	20114U	PARTICIPANT	\N	PRESENT	0
750896	750895	20032T	PARTICIPANT	\N	PRESENT	0
750845	749959	17737W	PARTICIPANT	\N	PRESENT	0
750846	749959	19629C	PARTICIPANT	\N	PRESENT	0
750847	749959	14179A	PARTICIPANT	\N	PRESENT	0
750848	749959	14259Y	PARTICIPANT	\N	PRESENT	0
750850	749959	04085P	PARTICIPANT	\N	PRESENT	0
750851	749959	14231L	PARTICIPANT	\N	PRESENT	0
750870	749959	95063L	PARTICIPANT	\N	PRESENT	0
750897	750895	19667J	PARTICIPANT	\N	PRESENT	0
750898	750895	20022R	PARTICIPANT	\N	PRESENT	0
750899	750895	19575F	PARTICIPANT	\N	PRESENT	0
750900	750895	14069U	PARTICIPANT	\N	PRESENT	0
750901	750895	20090E	PARTICIPANT	\N	PRESENT	0
750902	750895	20144B	PARTICIPANT	\N	PRESENT	0
750903	750895	19467C	PARTICIPANT	\N	PRESENT	0
750904	750895	18083K	PARTICIPANT	\N	PRESENT	0
750905	750895	20038A	PARTICIPANT	\N	PRESENT	0
750906	750895	17023S	PARTICIPANT	\N	PRESENT	0
764770	761714	19479G	PARTICIPANT	\N	PRESENT	0
764771	761714	20122U	PARTICIPANT	\N	PRESENT	0
764772	761714	20058E	PARTICIPANT	\N	PRESENT	0
764773	761714	21082J	PARTICIPANT	\N	PRESENT	0
765003	764997	21050A	PARTICIPANT	\N	PRESENT	0
765004	764997	14083S	PARTICIPANT	\N	PRESENT	0
765005	764997	14357A	PARTICIPANT	\N	PRESENT	0
765006	764997	20248J	PARTICIPANT	\N	PRESENT	0
765026	764997	21044C	PARTICIPANT	\N	PRESENT	0
765027	764997	20126Y	PARTICIPANT	\N	PRESENT	0
765028	764997	08015R	PARTICIPANT	\N	PRESENT	0
765029	764997	20052X	PARTICIPANT	\N	PRESENT	0
765030	764997	21058J	PARTICIPANT	\N	PRESENT	0
765031	764997	21040X	PARTICIPANT	\N	PRESENT	0
765032	764997	19563B	PARTICIPANT	\N	PRESENT	0
765033	764997	20028X	PARTICIPANT	\N	PRESENT	0
765034	764997	14237S	PARTICIPANT	\N	PRESENT	0
765035	764997	20054A	PRESIDENT	0	PRESENT	0
765036	764997	21064G	PARTICIPANT	\N	PRESENT	0
765037	764997	21061D	PARTICIPANT	\N	PRESENT	0
765063	764997	20172F	PARTICIPANT	\N	EXCUSE	0
765040	764997	20144B	PARTICIPANT	\N	EXCUSE	0
765042	765038	19667J	PARTICIPANT	\N	PRESENT	0
765044	764997	20078J	PARTICIPANT	\N	EXCUSE	0
765045	765038	19575F	PARTICIPANT	\N	PRESENT	0
765046	765038	19723Y	PARTICIPANT	\N	PRESENT	0
765047	764997	21080G	PARTICIPANT	\N	EXCUSE	0
765048	765038	20092G	PARTICIPANT	\N	PRESENT	0
765050	764997	20056C	PARTICIPANT	\N	EXCUSE	0
765052	765038	19533U	PARTICIPANT	\N	EXCUSE	0
765053	765038	21059K	PARTICIPANT	\N	EXCUSE	0
765054	765038	20072C	PARTICIPANT	\N	EXCUSE	0
765055	765038	01058X	PARTICIPANT	\N	EXCUSE	0
765056	765038	14038Y	PARTICIPANT	\N	EXCUSE	0
765057	765038	20138D	PARTICIPANT	\N	EXCUSE	0
765062	764997	19347U	PARTICIPANT	\N	EXCUSE	0
765064	764997	19551W	PARTICIPANT	\N	EXCUSE	0
765065	764997	19719D	PARTICIPANT	\N	EXCUSE	0
765066	764997	21039F	PARTICIPANT	\N	EXCUSE	0
765067	764997	21047F	PARTICIPANT	\N	EXCUSE	0
765068	764997	19545Y	PARTICIPANT	\N	EXCUSE	0
765069	764997	21051B	PARTICIPANT	\N	EXCUSE	0
765070	764997	21045D	PARTICIPANT	\N	EXCUSE	0
765193	761964	20022R	PARTICIPANT	\N	EXCUSE	0
765194	761964	14026U	PARTICIPANT	\N	EXCUSE	0
765195	761964	19447X	PARTICIPANT	\N	EXCUSE	0
765196	761964	19335Q	PARTICIPANT	\N	EXCUSE	0
765198	761964	20058E	PARTICIPANT	\N	EXCUSE	0
765220	765219	18083K	PARTICIPANT	\N	PRESENT	0
765222	765221	18083K	PARTICIPANT	\N	PRESENT	0
765224	765223	18083K	PARTICIPANT	\N	PRESENT	0
765230	765229	18083K	PARTICIPANT	\N	PRESENT	0
765227	765226	18083K	PARTICIPANT	\N	PRESENT	0
765228	765226	21082J	PARTICIPANT	\N	PRESENT	0
765239	765237	21095P	PARTICIPANT	\N	PRESENT	0
765240	765237	18207D	PARTICIPANT	\N	PRESENT	0
765242	765241	21095P	PARTICIPANT	\N	PRESENT	0
765244	764871	21032X	PARTICIPANT	\N	EXCUSE	0
765254	765253	19699S	PARTICIPANT	\N	PRESENT	0
765255	765252	20132W	PARTICIPANT	\N	PRESENT	0
765456	761720	21091K	PARTICIPANT	\N	PRESENT	0
765457	761720	21072G	PARTICIPANT	\N	PRESENT	0
765458	761720	17737W	PARTICIPANT	\N	PRESENT	0
765459	761720	11070L	PARTICIPANT	\N	PRESENT	0
765460	761720	21093M	PARTICIPANT	\N	PRESENT	0
765465	761720	21085M	PARTICIPANT	\N	PRESENT	0
765466	761720	21057H	PARTICIPANT	\N	PRESENT	0
765470	761720	20252E	PARTICIPANT	\N	PRESENT	0
765473	761720	19591F	PARTICIPANT	\N	PRESENT	0
765477	761720	04042C	PARTICIPANT	\N	PRESENT	0
765479	761720	20248J	PARTICIPANT	\N	PRESENT	0
765482	761720	07029T	PARTICIPANT	\N	PRESENT	0
765483	761720	20148F	PARTICIPANT	\N	PRESENT	0
765484	761720	99004R	PARTICIPANT	\N	PRESENT	0
765485	761720	14021P	PARTICIPANT	\N	PRESENT	0
765490	761720	14109K	PARTICIPANT	\N	PRESENT	0
765491	761720	21071F	PARTICIPANT	\N	PRESENT	0
765492	761720	21073H	PARTICIPANT	\N	PRESENT	0
765493	761720	21094N	PARTICIPANT	\N	PRESENT	0
765501	761720	20070A	PARTICIPANT	\N	PRESENT	0
765517	761720	19667J	PARTICIPANT	\N	PRESENT	0
765518	761720	14251Q	PARTICIPANT	\N	PRESENT	0
765519	761720	21054E	PARTICIPANT	\N	PRESENT	0
765567	761721	14089Y	PARTICIPANT	\N	PRESENT	0
765568	761721	04047H	PARTICIPANT	\N	PRESENT	0
765569	761721	19447X	PARTICIPANT	\N	PRESENT	0
765570	761721	20110Q	PARTICIPANT	\N	PRESENT	0
765571	761721	20100N	PARTICIPANT	\N	PRESENT	0
765572	761721	18231D	PARTICIPANT	\N	PRESENT	0
765573	761721	11045K	PARTICIPANT	\N	PRESENT	0
765597	761721	21094N	PARTICIPANT	\N	PRESENT	0
765633	765631	11027H	PARTICIPANT	\N	PRESENT	0
765576	761721	21075K	PARTICIPANT	\N	PRESENT	0
765577	761721	14037X	PARTICIPANT	\N	PRESENT	0
765578	761721	20062A	PARTICIPANT	\N	PRESENT	0
765579	761721	21093M	PARTICIPANT	\N	PRESENT	0
765580	761721	19667J	PARTICIPANT	\N	PRESENT	0
765581	761721	04033B	PARTICIPANT	\N	PRESENT	0
765582	761721	18207D	PARTICIPANT	\N	PRESENT	0
765583	761721	19649G	PARTICIPANT	\N	PRESENT	0
765584	761721	21053D	PARTICIPANT	\N	PRESENT	0
765585	761721	21089R	PARTICIPANT	\N	PRESENT	0
765586	761721	99004R	PARTICIPANT	\N	PRESENT	0
765587	761721	19673G	PARTICIPANT	\N	PRESENT	0
765588	761721	19629C	PARTICIPANT	\N	PRESENT	0
765589	761721	07029T	PARTICIPANT	\N	PRESENT	0
765590	761721	20148F	PARTICIPANT	\N	PRESENT	0
765591	761721	08018U	PARTICIPANT	\N	PRESENT	0
765592	761721	21071F	PARTICIPANT	\N	PRESENT	0
765593	761721	19697Q	PARTICIPANT	\N	PRESENT	0
765594	761721	20034V	PARTICIPANT	\N	PRESENT	0
765595	761721	19693L	PARTICIPANT	\N	PRESENT	0
765596	761721	21095P	PARTICIPANT	\N	PRESENT	0
765598	761721	21072G	PARTICIPANT	\N	PRESENT	0
765599	761721	19387D	PARTICIPANT	\N	PRESENT	0
765600	761721	21054E	PARTICIPANT	\N	PRESENT	0
765601	761721	19111A	PARTICIPANT	\N	PRESENT	0
765602	761721	20052X	PARTICIPANT	\N	PRESENT	0
765603	761721	21073H	PARTICIPANT	\N	PRESENT	0
765604	761721	19593H	PARTICIPANT	\N	PRESENT	0
765605	761721	21091K	PARTICIPANT	\N	PRESENT	0
765606	761721	20252E	PARTICIPANT	\N	PRESENT	0
765607	761721	21090J	PARTICIPANT	\N	PRESENT	0
765608	761721	21084L	PARTICIPANT	\N	PRESENT	0
765609	761721	20150Y	PARTICIPANT	\N	PRESENT	0
765565	761721	19301E	PARTICIPANT	\N	PRESENT	0
765610	761721	11040E	PARTICIPANT	\N	PRESENT	0
765615	761721	17737W	PARTICIPANT	\N	PRESENT	0
765616	761721	14217N	PARTICIPANT	\N	PRESENT	0
765625	761721	21079P	PARTICIPANT	\N	PRESENT	0
765628	761721	19295A	PARTICIPANT	\N	PRESENT	0
765630	761721	19591F	PARTICIPANT	\N	PRESENT	0
765634	765631	19421M	PARTICIPANT	\N	PRESENT	0
765637	765636	11027H	PARTICIPANT	\N	PRESENT	0
765639	765638	11027H	PARTICIPANT	\N	PRESENT	0
765640	765638	19421M	PARTICIPANT	\N	PRESENT	0
765642	765641	98022P	PARTICIPANT	\N	PRESENT	0
765643	765641	99004R	PARTICIPANT	\N	PRESENT	0
765645	765644	98022P	PARTICIPANT	\N	PRESENT	0
765646	765644	99004R	PARTICIPANT	\N	PRESENT	0
765647	761721	20248J	PARTICIPANT	\N	PRESENT	0
765649	765648	12028B	PARTICIPANT	\N	PRESENT	0
765650	765648	11064N	PARTICIPANT	\N	PRESENT	0
765652	765651	11064N	PARTICIPANT	\N	PRESENT	0
765661	761721	04042C	PARTICIPANT	\N	PRESENT	0
765662	761721	19331L	PARTICIPANT	\N	PRESENT	0
765667	761721	11072N	PARTICIPANT	\N	PRESENT	0
765691	765489	14059S	PARTICIPANT	\N	EXCUSE	0
765692	765489	08010L	PARTICIPANT	\N	EXCUSE	0
765696	765489	20122U	PARTICIPANT	\N	EXCUSE	0
765698	765697	11074Q	PARTICIPANT	\N	PRESENT	0
765699	765697	19349W	PARTICIPANT	\N	PRESENT	0
765701	765700	19399H	PARTICIPANT	\N	PRESENT	0
765815	765812	14331P	PARTICIPANT	\N	PRESENT	0
765816	765812	14073Q	PARTICIPANT	\N	PRESENT	0
765818	765812	14001X	PARTICIPANT	\N	PRESENT	0
765833	765489	05008E	PARTICIPANT	\N	EXCUSE	0
765849	765845	18395Y	PARTICIPANT	\N	PRESENT	1
751832	751567	19695N	PARTICIPANT	\N	PRESENT	0
751937	751936	05008E	PARTICIPANT	\N	PRESENT	0
751938	751936	11053K	PARTICIPANT	\N	PRESENT	0
751939	751936	01028R	PARTICIPANT	\N	PRESENT	0
752215	752214	14053L	PARTICIPANT	\N	PRESENT	0
752216	752214	19749K	PARTICIPANT	\N	PRESENT	0
752267	752253	20116W	PARTICIPANT	\N	PRESENT	0
752268	752253	19349W	PARTICIPANT	\N	PRESENT	0
752269	752253	19479G	PARTICIPANT	\N	PRESENT	0
752270	752253	20086J	PARTICIPANT	\N	PRESENT	0
752258	752253	11074Q	PARTICIPANT	\N	PRESENT	0
752259	752253	11070L	PARTICIPANT	\N	PRESENT	0
752260	752253	14225N	PRESIDENT	0	PRESENT	0
752261	752253	14173T	PARTICIPANT	\N	PRESENT	0
752262	752253	11040E	PARTICIPANT	\N	EXCUSE	0
752263	752253	20080C	PARTICIPANT	\N	EXCUSE	0
752264	752253	20050V	PARTICIPANT	\N	EXCUSE	0
752265	752253	14327T	PARTICIPANT	\N	PRESENT	0
752266	752253	20044X	PARTICIPANT	\N	PRESENT	0
752271	752253	11048N	PARTICIPANT	\N	PRESENT	0
752272	752253	19647E	PARTICIPANT	\N	PRESENT	0
752273	752253	19711U	PARTICIPANT	\N	PRESENT	0
752274	752253	08034U	PARTICIPANT	\N	PRESENT	0
752275	752253	01057W	PARTICIPANT	\N	PRESENT	0
752276	752253	08073C	PARTICIPANT	\N	PRESENT	0
752277	752253	20070A	PARTICIPANT	\N	PRESENT	0
752278	752253	14121F	PARTICIPANT	\N	PRESENT	0
752279	752253	08010L	PARTICIPANT	\N	PRESENT	0
752280	752253	20126Y	PARTICIPANT	\N	PRESENT	0
752281	752253	14331P	PARTICIPANT	\N	PRESENT	0
752282	752253	14189C	PARTICIPANT	\N	PRESENT	0
752283	752253	19667J	PARTICIPANT	\N	PRESENT	0
752284	752253	08011M	PARTICIPANT	\N	PRESENT	0
752288	752253	19545Y	PARTICIPANT	\N	PRESENT	0
752289	752253	07029T	PARTICIPANT	\N	PRESENT	0
752296	752253	12016W	PARTICIPANT	\N	PRESENT	0
752297	752253	11053K	PARTICIPANT	\N	PRESENT	0
752298	752253	14083S	PARTICIPANT	\N	PRESENT	0
752303	752253	08009T	PARTICIPANT	\N	PRESENT	0
752311	752201	14225N	PRESIDENT	0	PRESENT	0
752312	752201	11040E	PARTICIPANT	\N	EXCUSE	0
752313	752201	20080C	PARTICIPANT	\N	EXCUSE	0
752314	752201	20050V	PARTICIPANT	\N	EXCUSE	0
752315	752201	20116W	PARTICIPANT	\N	EXCUSE	0
752316	752201	08034U	PARTICIPANT	\N	PRESENT	0
752317	752201	20126Y	PARTICIPANT	\N	PRESENT	0
752318	752201	07029T	PARTICIPANT	\N	PRESENT	0
752319	752201	11048N	PARTICIPANT	\N	PRESENT	0
752320	752201	19711U	PARTICIPANT	\N	PRESENT	0
752321	752201	11074Q	PARTICIPANT	\N	PRESENT	0
752322	752201	14083S	PARTICIPANT	\N	PRESENT	0
752323	752201	19479G	PARTICIPANT	\N	PRESENT	0
752324	752201	20044X	PARTICIPANT	\N	PRESENT	0
752325	752201	08010L	PARTICIPANT	\N	PRESENT	0
752326	752201	20086J	PARTICIPANT	\N	PRESENT	0
752328	752327	14327T	PARTICIPANT	\N	PRESENT	0
752329	752327	20086J	PARTICIPANT	\N	PRESENT	0
752330	752327	11048N	PARTICIPANT	\N	PRESENT	0
752331	752327	19479G	PARTICIPANT	\N	PRESENT	0
752332	752327	19711U	PARTICIPANT	\N	PRESENT	0
752333	752327	01048V	PARTICIPANT	\N	PRESENT	0
752334	752327	08034U	PARTICIPANT	\N	PRESENT	0
752335	752327	19545Y	PARTICIPANT	\N	PRESENT	0
752336	752327	01057W	PARTICIPANT	\N	PRESENT	0
752337	752327	11074Q	PARTICIPANT	\N	PRESENT	0
752338	752327	08011M	PARTICIPANT	\N	PRESENT	0
752339	752327	20044X	PARTICIPANT	\N	PRESENT	0
752340	752327	14225N	PRESIDENT	0	PRESENT	0
752341	752327	11110B	PARTICIPANT	\N	PRESENT	0
752342	752327	14083S	PARTICIPANT	\N	PRESENT	0
752343	752327	07029T	PARTICIPANT	\N	PRESENT	0
752344	752327	08073C	PARTICIPANT	\N	PRESENT	0
752345	752327	08009T	PARTICIPANT	\N	PRESENT	0
752346	752327	20070A	PARTICIPANT	\N	PRESENT	0
752347	752327	19349W	PARTICIPANT	\N	PRESENT	0
752348	752327	08010L	PARTICIPANT	\N	PRESENT	0
752349	752327	20914V	PARTICIPANT	\N	PRESENT	0
752350	752327	20126Y	PARTICIPANT	\N	PRESENT	0
752351	752327	11040E	PARTICIPANT	\N	EXCUSE	0
752352	752327	20080C	PARTICIPANT	\N	EXCUSE	0
752353	752327	20050V	PARTICIPANT	\N	EXCUSE	0
752354	752327	20116W	PARTICIPANT	\N	EXCUSE	0
752356	752327	14189C	PARTICIPANT	\N	PRESENT	0
752375	740830	07029T	PARTICIPANT	\N	PRESENT	0
752377	752376	07029T	PARTICIPANT	\N	PRESENT	0
752379	752378	07029T	PARTICIPANT	\N	PRESENT	0
752393	752392	20056C	PARTICIPANT	\N	PRESENT	0
752394	752392	04070G	PARTICIPANT	\N	PRESENT	0
753254	752386	14189C	PARTICIPANT	\N	PRESENT	0
753255	752386	05008E	PARTICIPANT	\N	PRESENT	0
753256	752386	20022R	PARTICIPANT	\N	PRESENT	0
753257	752386	20110Q	PARTICIPANT	\N	PRESENT	0
753258	752386	21043B	PARTICIPANT	\N	PRESENT	0
753259	752386	14069U	PARTICIPANT	\N	PRESENT	0
753260	752386	14089Y	PARTICIPANT	\N	PRESENT	0
753261	752386	11056N	PARTICIPANT	\N	PRESENT	0
753262	752386	20114U	PARTICIPANT	\N	PRESENT	0
753263	752386	21088Q	PARTICIPANT	\N	PRESENT	0
753264	752386	19719D	PARTICIPANT	\N	PRESENT	0
753265	752386	04008A	PARTICIPANT	\N	PRESENT	0
753266	752386	14259Y	PARTICIPANT	\N	PRESENT	0
753267	752386	21057H	PARTICIPANT	\N	PRESENT	0
753268	752386	19673G	PARTICIPANT	\N	PRESENT	0
753269	752386	14151M	PARTICIPANT	\N	PRESENT	0
753270	752386	20074E	PARTICIPANT	\N	PRESENT	0
753271	752386	19111A	PARTICIPANT	\N	PRESENT	0
753272	752386	14231L	PARTICIPANT	\N	PRESENT	0
753273	752386	08018U	PARTICIPANT	\N	PRESENT	0
753274	752386	21044C	PARTICIPANT	\N	PRESENT	0
753275	752386	19725B	PARTICIPANT	\N	PRESENT	0
753276	752386	04047H	PRESIDENT	1	PRESENT	0
753277	752386	14053L	PARTICIPANT	0	PRESENT	0
753278	752386	19489J	PARTICIPANT	\N	PRESENT	0
753279	752386	19447X	PARTICIPANT	\N	PRESENT	0
753280	752386	20108W	PARTICIPANT	\N	EXCUSE	0
753281	752386	14215L	PARTICIPANT	\N	PRESENT	0
753282	752386	19649G	PARTICIPANT	\N	PRESENT	0
753283	752386	19729F	PRESIDENT	0	PRESENT	0
753284	752386	18207D	PARTICIPANT	\N	PRESENT	0
753285	752386	14111D	PARTICIPANT	\N	PRESENT	0
753286	752386	11085T	PARTICIPANT	\N	PRESENT	0
753287	752386	21040X	PARTICIPANT	\N	PRESENT	0
753288	752386	14147R	PARTICIPANT	\N	PRESENT	0
753289	752386	11072N	PARTICIPANT	\N	PRESENT	0
753290	752386	18231D	PARTICIPANT	\N	PRESENT	0
753291	752386	20036X	PARTICIPANT	\N	PRESENT	0
753292	752386	10015M	PARTICIPANT	\N	PRESENT	0
753293	752386	21038E	PARTICIPANT	\N	PRESENT	0
753294	752386	21056G	PARTICIPANT	\N	PRESENT	0
753295	752386	20098N	PARTICIPANT	\N	PRESENT	0
753296	752386	04045F	PARTICIPANT	\N	PRESENT	0
753297	752386	21095P	PARTICIPANT	\N	PRESENT	0
753298	752386	14275Y	PARTICIPANT	\N	PRESENT	0
753299	752386	19749K	PARTICIPANT	\N	PRESENT	0
753300	752386	21076L	PARTICIPANT	\N	PRESENT	0
753301	752386	20266L	PARTICIPANT	\N	PRESENT	0
753302	752386	19585H	PARTICIPANT	\N	PRESENT	0
753303	752389	01034P	PARTICIPANT	\N	PRESENT	0
753304	752389	19569H	PARTICIPANT	\N	PRESENT	0
753305	752389	20130U	PARTICIPANT	\N	PRESENT	0
753306	752389	19657G	PARTICIPANT	\N	PRESENT	0
753307	752389	21087P	PARTICIPANT	\N	PRESENT	0
753308	752389	21064G	PARTICIPANT	\N	PRESENT	0
753309	752389	17779H	PARTICIPANT	\N	PRESENT	0
753310	752389	14071N	PARTICIPANT	\N	PRESENT	0
753311	752389	19367Y	PARTICIPANT	\N	PRESENT	0
753312	752389	19866P	PARTICIPANT	\N	PRESENT	0
753313	752389	19683J	PARTICIPANT	\N	PRESENT	0
753314	752389	04092N	PARTICIPANT	\N	PRESENT	0
753315	752389	14195A	PARTICIPANT	\N	PRESENT	0
753316	752389	19691J	PARTICIPANT	\N	PRESENT	0
753317	752389	20096L	PARTICIPANT	\N	PRESENT	0
753318	752389	21071F	PARTICIPANT	\N	PRESENT	0
753319	752389	19760E	PARTICIPANT	\N	PRESENT	0
753320	752389	21046E	PARTICIPANT	\N	PRESENT	0
753321	752389	19758L	PARTICIPANT	\N	PRESENT	0
753322	752389	20090E	PARTICIPANT	\N	PRESENT	0
753323	752389	21045D	PARTICIPANT	\N	PRESENT	0
753324	752389	19629C	PARTICIPANT	\N	PRESENT	0
753325	752389	19295A	PARTICIPANT	\N	PRESENT	0
753326	752389	20140W	PARTICIPANT	\N	PRESENT	0
744165	740804	14189C	PARTICIPANT	\N	EXCUSE	0
744493	743799	04070G	PRESIDENT	0	PRESENT	0
744494	743799	14179A	PARTICIPANT	\N	PRESENT	0
744495	743799	14038Y	PARTICIPANT	\N	PRESENT	0
744500	743799	20152B	PARTICIPANT	\N	PRESENT	0
744502	743799	14147R	PARTICIPANT	\N	PRESENT	0
744503	743799	20094J	PARTICIPANT	\N	PRESENT	0
744504	743799	11045K	PARTICIPANT	\N	PRESENT	0
744520	743799	14151M	PARTICIPANT	\N	PRESENT	0
744522	743799	10015M	PARTICIPANT	\N	PRESENT	0
744523	743799	20138D	PARTICIPANT	\N	PRESENT	0
744533	743799	20052X	PARTICIPANT	\N	PRESENT	0
744538	743799	14030Q	PARTICIPANT	\N	PRESENT	0
746021	746020	19725B	PARTICIPANT	\N	PRESENT	0
746032	746031	07029T	PARTICIPANT	\N	PRESENT	0
746039	746038	14001X	PARTICIPANT	\N	PRESENT	0
746040	746038	14033T	PARTICIPANT	\N	PRESENT	0
750013	750012	19673G	PARTICIPANT	\N	PRESENT	0
750014	750012	19749K	PARTICIPANT	\N	PRESENT	0
751791	751761	14357A	PARTICIPANT	\N	PRESENT	0
751792	751761	14187A	PARTICIPANT	\N	PRESENT	0
751793	751761	19695N	PARTICIPANT	\N	PRESENT	0
751794	751761	20082E	PARTICIPANT	\N	PRESENT	0
751795	751761	14033T	PARTICIPANT	\N	PRESENT	0
751796	751761	11090Q	PRESIDENT	0	PRESENT	0
751797	751761	01025N	PARTICIPANT	\N	PRESENT	0
751798	751761	20062A	PARTICIPANT	\N	PRESENT	0
751799	751761	14251Q	PARTICIPANT	\N	PRESENT	0
751800	751761	20298U	PARTICIPANT	\N	PRESENT	0
751801	751761	14215L	PARTICIPANT	\N	PRESENT	0
751802	751761	20018V	PARTICIPANT	\N	PRESENT	0
751803	751761	14037X	PARTICIPANT	\N	PRESENT	0
751804	751761	19782L	PARTICIPANT	\N	EXCUSE	0
751805	751761	19575F	PARTICIPANT	\N	EXCUSE	0
751806	751761	20144B	PARTICIPANT	\N	EXCUSE	0
751807	751761	20286Q	PARTICIPANT	\N	EXCUSE	0
751808	751761	19369B	PARTICIPANT	\N	EXCUSE	0
751809	751761	20094J	PARTICIPANT	\N	EXCUSE	0
751810	751761	20054A	PARTICIPANT	\N	EXCUSE	0
751811	751761	19563B	PARTICIPANT	\N	EXCUSE	0
757255	757252	14123H	PARTICIPANT	\N	PRESENT	0
757256	757252	21089R	PARTICIPANT	\N	PRESENT	0
757257	757252	14109K	PARTICIPANT	\N	PRESENT	0
757492	755866	14133K	PARTICIPANT	\N	PRESENT	0
757493	755866	17367Q	PARTICIPANT	\N	PRESENT	0
757497	755866	20042V	PARTICIPANT	\N	PRESENT	0
757498	755866	17737W	PARTICIPANT	\N	PRESENT	0
757499	755866	14255U	PARTICIPANT	\N	PRESENT	0
757502	755866	04042C	PARTICIPANT	\N	PRESENT	0
757505	755866	12028B	PARTICIPANT	\N	PRESENT	0
757507	755866	19721W	PARTICIPANT	\N	PRESENT	0
757509	755866	14267Y	PARTICIPANT	\N	PRESENT	0
757512	755866	11027H	PARTICIPANT	\N	PRESENT	0
757514	755866	11115U	PARTICIPANT	\N	PRESENT	0
757517	755866	21067K	PARTICIPANT	\N	PRESENT	0
757519	755866	07033P	PARTICIPANT	\N	PRESENT	0
757521	755866	14249W	PARTICIPANT	\N	PRESENT	0
757523	755866	17023S	PARTICIPANT	\N	PRESENT	0
757524	755866	19347U	PARTICIPANT	\N	PRESENT	0
757527	755866	08056B	PARTICIPANT	\N	PRESENT	0
757528	755866	14211G	PARTICIPANT	\N	PRESENT	0
757530	755866	19565D	PARTICIPANT	\N	PRESENT	0
757533	755866	98022P	PARTICIPANT	\N	PRESENT	0
757536	755866	11064N	PARTICIPANT	\N	PRESENT	0
757537	755866	20072C	PARTICIPANT	\N	PRESENT	0
757538	755866	20128B	PARTICIPANT	\N	PRESENT	0
757539	755866	14179A	PARTICIPANT	\N	PRESENT	0
757540	755866	08069G	PARTICIPANT	\N	PRESENT	0
757541	755866	19531S	PARTICIPANT	\N	PRESENT	0
757543	755866	14097Y	PARTICIPANT	\N	PRESENT	0
757545	755866	99004R	PARTICIPANT	\N	PRESENT	0
757546	755866	14037X	PARTICIPANT	\N	PRESENT	0
757570	755866	14059S	PARTICIPANT	\N	PRESENT	0
757574	755866	14251Q	PARTICIPANT	\N	PRESENT	0
757576	755866	14001X	PARTICIPANT	\N	PRESENT	0
757578	755866	20252E	PARTICIPANT	\N	PRESENT	0
757580	755866	14191V	PARTICIPANT	\N	PRESENT	0
757583	755866	08047A	PARTICIPANT	\N	PRESENT	0
757585	755866	14193X	PARTICIPANT	\N	PRESENT	0
757587	755866	19745F	PARTICIPANT	\N	PRESENT	0
757589	755866	14055N	PARTICIPANT	\N	PRESENT	0
757592	755866	19421M	PARTICIPANT	\N	PRESENT	0
757596	755866	01058X	PARTICIPANT	\N	PRESENT	0
757598	755866	19669L	PARTICIPANT	\N	PRESENT	0
757599	755866	20064C	PARTICIPANT	\N	PRESENT	0
757600	755866	21031W	PARTICIPANT	\N	PRESENT	0
765181	761718	14357A	PARTICIPANT	\N	PRESENT	0
765182	761718	20100N	PARTICIPANT	\N	PRESENT	0
765183	761718	21073H	PARTICIPANT	\N	PRESENT	0
765184	761718	11056N	PARTICIPANT	\N	PRESENT	0
765185	761718	21057H	PARTICIPANT	\N	PRESENT	0
765186	761718	99004R	PARTICIPANT	\N	PRESENT	0
765187	761718	19295A	PARTICIPANT	\N	PRESENT	0
765189	761718	11070L	PARTICIPANT	\N	PRESENT	0
765190	761718	19683J	PARTICIPANT	\N	PRESENT	0
765191	761718	08010L	PARTICIPANT	\N	PRESENT	0
765192	761718	20044X	PARTICIPANT	\N	PRESENT	0
765197	761718	19251M	PARTICIPANT	\N	PRESENT	0
765201	761718	20042V	PARTICIPANT	\N	PRESENT	0
765202	761718	20180F	PARTICIPANT	\N	PRESENT	0
765203	761718	21081H	PARTICIPANT	\N	PRESENT	0
765204	761718	21053D	PARTICIPANT	\N	PRESENT	0
765205	761718	21089R	PARTICIPANT	\N	PRESENT	0
765206	761718	11090Q	PARTICIPANT	\N	PRESENT	0
765209	761718	14083S	PARTICIPANT	\N	PRESENT	0
765210	761718	19399H	PARTICIPANT	\N	PRESENT	0
765211	761718	18083K	PARTICIPANT	\N	PRESENT	0
765212	761718	21064G	PARTICIPANT	\N	PRESENT	0
765213	761718	21097R	PARTICIPANT	\N	PRESENT	0
765214	761718	14021P	PARTICIPANT	\N	PRESENT	0
765215	761718	08034U	PARTICIPANT	\N	PRESENT	0
765216	761718	14071N	PARTICIPANT	\N	PRESENT	0
765217	761718	20086J	PARTICIPANT	\N	PRESENT	0
765218	761718	21038E	PARTICIPANT	\N	PRESENT	0
765231	761718	20122U	PARTICIPANT	\N	PRESENT	0
765232	761718	21084L	PARTICIPANT	\N	PRESENT	0
765233	761718	21040X	PARTICIPANT	\N	PRESENT	0
765234	761718	14179A	PARTICIPANT	\N	PRESENT	0
765235	761718	21095P	PARTICIPANT	\N	PRESENT	0
765236	761718	21078N	PARTICIPANT	\N	PRESENT	0
765238	761718	18207D	PARTICIPANT	\N	PRESENT	0
765243	761718	19695N	PARTICIPANT	\N	PRESENT	0
765245	761718	14205J	PARTICIPANT	\N	PRESENT	0
765246	761718	20142Y	PARTICIPANT	\N	PRESENT	0
765247	761718	20070A	PARTICIPANT	\N	PRESENT	0
765248	761718	14069U	PARTICIPANT	\N	PRESENT	0
765249	761718	19749K	PARTICIPANT	\N	PRESENT	0
765250	761718	19301E	PARTICIPANT	\N	PRESENT	0
765251	761718	20034V	PARTICIPANT	\N	PRESENT	0
765256	761718	20148F	PARTICIPANT	\N	PRESENT	0
765257	761718	20092G	PARTICIPANT	\N	PRESENT	0
765322	761719	19301E	PARTICIPANT	\N	PRESENT	0
765323	761719	14071N	PARTICIPANT	\N	PRESENT	0
765324	761719	21040X	PARTICIPANT	\N	PRESENT	0
765325	761719	19629C	PARTICIPANT	\N	PRESENT	0
765326	761719	14055N	PARTICIPANT	\N	PRESENT	0
765327	761719	20086J	PARTICIPANT	\N	PRESENT	0
765328	761719	14329V	PARTICIPANT	\N	PRESENT	0
765329	761719	20022R	PARTICIPANT	\N	PRESENT	0
765330	761719	14215L	PARTICIPANT	\N	PRESENT	0
765331	761719	99004R	PARTICIPANT	\N	PRESENT	0
765332	761719	20148F	PARTICIPANT	\N	PRESENT	0
765333	761719	20108W	PARTICIPANT	\N	PRESENT	0
765334	761719	21058J	PARTICIPANT	\N	PRESENT	0
765335	761719	20180F	PARTICIPANT	\N	PRESENT	0
765336	761719	14151M	PARTICIPANT	\N	PRESENT	0
765337	761719	18207D	PARTICIPANT	\N	PRESENT	0
765338	761719	19693L	PARTICIPANT	\N	PRESENT	0
765339	761719	19782L	PARTICIPANT	\N	PRESENT	0
765340	761719	08061X	PARTICIPANT	\N	PRESENT	0
765341	761719	21081H	PARTICIPANT	\N	PRESENT	0
765342	761719	20142Y	PARTICIPANT	\N	PRESENT	0
765343	761719	20100N	PARTICIPANT	\N	PRESENT	0
765344	761719	18231D	PARTICIPANT	\N	PRESENT	0
765345	761719	18395Y	PARTICIPANT	\N	PRESENT	0
765346	761719	20110Q	PARTICIPANT	\N	PRESENT	0
765347	761719	21079P	PARTICIPANT	\N	PRESENT	0
765348	761719	20070A	PARTICIPANT	\N	PRESENT	0
765349	761719	19347U	PARTICIPANT	\N	PRESENT	0
765350	761719	19447X	PARTICIPANT	\N	PRESENT	0
745190	744170	19735D	PARTICIPANT	\N	PRESENT	0
745191	744170	19739H	PARTICIPANT	\N	PRESENT	0
745192	744170	14205J	PARTICIPANT	\N	PRESENT	0
745193	744170	20144B	PARTICIPANT	\N	PRESENT	0
745194	744170	19347U	PARTICIPANT	\N	PRESENT	0
745195	744170	20126Y	PARTICIPANT	\N	PRESENT	0
745196	744170	19369B	PARTICIPANT	\N	PRESENT	0
745197	744170	01034P	PARTICIPANT	\N	PRESENT	0
745198	744170	01060R	PARTICIPANT	\N	PRESENT	0
745199	744170	20298U	PARTICIPANT	\N	PRESENT	0
745200	744170	14031R	PARTICIPANT	\N	PRESENT	0
745201	744170	19611R	PARTICIPANT	\N	PRESENT	0
745202	744170	19691J	PARTICIPANT	\N	PRESENT	0
745203	744170	14231L	PARTICIPANT	\N	PRESENT	0
745204	744170	17229F	PARTICIPANT	\N	PRESENT	0
745205	744170	11099A	PARTICIPANT	\N	PRESENT	0
745206	744170	14267Y	PARTICIPANT	\N	PRESENT	0
745207	744170	17023S	PARTICIPANT	\N	PRESENT	0
745208	744170	14251Q	PARTICIPANT	\N	PRESENT	0
745209	744170	14083S	PARTICIPANT	\N	PRESENT	0
745210	744170	14089Y	PARTICIPANT	\N	PRESENT	0
745211	744170	19749K	PARTICIPANT	\N	PRESENT	0
745212	744170	20040T	PARTICIPANT	\N	PRESENT	0
745213	744170	20248J	PARTICIPANT	\N	PRESENT	0
745215	744170	19826F	PARTICIPANT	\N	PRESENT	0
745216	744170	19577H	PARTICIPANT	\N	PRESENT	0
745217	745214	20024T	PARTICIPANT	\N	PRESENT	0
745218	744170	14189C	PARTICIPANT	\N	PRESENT	0
745219	744170	11085T	PARTICIPANT	\N	PRESENT	0
745220	745214	11099A	PARTICIPANT	\N	PRESENT	0
745221	744170	20066E	PARTICIPANT	\N	PRESENT	0
745222	744170	01025N	PARTICIPANT	\N	PRESENT	0
745223	744170	04070G	PARTICIPANT	\N	PRESENT	0
745224	744170	01024M	PARTICIPANT	\N	PRESENT	0
745225	744170	14179A	PARTICIPANT	\N	PRESENT	0
745226	744170	14030Q	PARTICIPANT	\N	PRESENT	0
745227	744170	14327T	PARTICIPANT	\N	PRESENT	0
745228	744170	04043D	PARTICIPANT	\N	PRESENT	0
745229	744170	19619A	PARTICIPANT	\N	PRESENT	0
745230	744170	11012A	PARTICIPANT	\N	PRESENT	0
745231	744170	14123H	PARTICIPANT	\N	PRESENT	0
745232	744170	14225N	PARTICIPANT	\N	PRESENT	0
745233	744170	19551W	PARTICIPANT	\N	PRESENT	0
745234	744170	19721W	PARTICIPANT	\N	PRESENT	0
745235	744170	11090Q	PARTICIPANT	\N	PRESENT	0
745239	744170	19717B	PARTICIPANT	\N	PRESENT	0
745237	744170	95063L	PARTICIPANT	\N	PRESENT	0
745238	744170	11065P	PARTICIPANT	\N	PRESENT	0
745240	744170	10006L	PARTICIPANT	\N	PRESENT	0
745504	744171	12041X	PARTICIPANT	\N	PRESENT	0
745538	744171	20052X	PARTICIPANT	\N	PRESENT	0
745506	744171	14195A	PARTICIPANT	\N	PRESENT	0
745507	744171	19713W	PARTICIPANT	\N	PRESENT	0
745526	744171	14053L	PARTICIPANT	\N	PRESENT	0
745509	744171	19782L	PARTICIPANT	\N	PRESENT	0
745510	744171	08045X	PARTICIPANT	\N	PRESENT	0
745511	744171	20062A	PARTICIPANT	\N	PRESENT	0
745512	744171	14147R	PARTICIPANT	\N	PRESENT	0
745529	744171	19467C	PARTICIPANT	\N	PRESENT	0
745514	744171	19507S	PARTICIPANT	\N	PRESENT	0
745515	744171	14187A	PARTICIPANT	\N	PRESENT	0
745516	744171	19333N	PARTICIPANT	\N	PRESENT	0
745517	744171	20102Q	PARTICIPANT	\N	PRESENT	0
745518	744171	19593H	PARTICIPANT	\N	PRESENT	0
745519	744171	19760E	PARTICIPANT	\N	PRESENT	0
745520	744171	10006L	PARTICIPANT	\N	PRESENT	0
745521	744171	04043D	PARTICIPANT	\N	PRESENT	0
745522	744171	14031R	PARTICIPANT	\N	PRESENT	0
745523	744171	01034P	PARTICIPANT	\N	PRESENT	0
745524	744171	19747H	PARTICIPANT	\N	PRESENT	0
745525	744171	14331P	PARTICIPANT	\N	PRESENT	0
745527	744171	20106U	PARTICIPANT	\N	PRESENT	0
745528	744171	04057K	PARTICIPANT	\N	PRESENT	0
745530	744171	20116W	PARTICIPANT	\N	PRESENT	0
745531	744171	20072C	PARTICIPANT	\N	PRESENT	0
745532	744171	19695N	PARTICIPANT	\N	PRESENT	0
745533	744171	19503N	PARTICIPANT	\N	PRESENT	0
745534	744171	20034V	PARTICIPANT	\N	PRESENT	0
745535	744171	19758L	PARTICIPANT	\N	PRESENT	0
745536	744171	20100N	PARTICIPANT	\N	PRESENT	0
745537	744171	14071N	PARTICIPANT	\N	PRESENT	0
745539	744171	14133K	PARTICIPANT	\N	PRESENT	0
745540	744171	17023S	PARTICIPANT	\N	PRESENT	0
745541	744171	19657G	PARTICIPANT	\N	PRESENT	0
745542	744171	20104S	PARTICIPANT	\N	PRESENT	0
745543	744171	14193X	PARTICIPANT	\N	PRESENT	0
745544	744171	14097Y	PARTICIPANT	\N	PRESENT	0
745545	744171	20266L	PARTICIPANT	\N	PRESENT	0
745546	744171	19549D	PARTICIPANT	\N	PRESENT	0
745547	744171	20032T	PARTICIPANT	\N	PRESENT	0
745548	744171	14231L	PARTICIPANT	\N	PRESENT	0
745549	744171	20248J	PARTICIPANT	\N	PRESENT	0
745550	744171	19703U	PARTICIPANT	\N	PRESENT	0
745551	744171	20112S	PARTICIPANT	\N	PRESENT	0
745552	744171	19691J	PARTICIPANT	\N	PRESENT	0
745553	744171	11012A	PARTICIPANT	\N	PRESENT	0
745554	744171	08061X	PARTICIPANT	\N	PRESENT	0
745555	744171	19697Q	PARTICIPANT	\N	PRESENT	0
745556	744171	20180F	PARTICIPANT	\N	PRESENT	0
745561	744171	14217N	PARTICIPANT	\N	PRESENT	0
745562	744171	01048V	PARTICIPANT	\N	PRESENT	0
745563	744171	20036X	PARTICIPANT	\N	PRESENT	0
745564	744171	01024M	PARTICIPANT	\N	PRESENT	0
745565	744171	19701S	PARTICIPANT	\N	PRESENT	0
745566	744171	14259Y	PARTICIPANT	\N	PRESENT	0
745567	744171	14083S	PARTICIPANT	\N	PRESENT	0
745568	744171	20056C	PARTICIPANT	\N	PRESENT	0
745569	744171	14033T	PARTICIPANT	\N	PRESENT	0
745570	744171	19447X	PARTICIPANT	\N	PRESENT	0
745571	744171	20022R	PARTICIPANT	\N	PRESENT	0
745572	744171	11090Q	PARTICIPANT	\N	PRESENT	0
745573	744171	20038A	PARTICIPANT	\N	PRESENT	0
745574	744171	19533U	PARTICIPANT	\N	PRESENT	0
745575	744171	20044X	PARTICIPANT	\N	PRESENT	0
745576	744171	20026V	PARTICIPANT	\N	PRESENT	0
745577	744171	20054A	PARTICIPANT	\N	PRESENT	0
745578	744171	11097X	PARTICIPANT	\N	PRESENT	0
745579	744171	11056N	PARTICIPANT	\N	PRESENT	0
745580	744171	20130U	PARTICIPANT	\N	PRESENT	0
745581	744171	14189C	PARTICIPANT	\N	PRESENT	0
745582	744171	14030Q	PARTICIPANT	\N	PRESENT	0
745583	744171	20132W	PARTICIPANT	\N	PRESENT	0
745584	744171	20120S	PARTICIPANT	\N	PRESENT	0
745586	744171	14207L	PARTICIPANT	\N	PRESENT	0
745590	744171	14215L	PARTICIPANT	\N	PRESENT	0
745591	744171	14219Q	PARTICIPANT	\N	PRESENT	0
745592	744171	20080C	PARTICIPANT	\N	PRESENT	0
745593	744171	20028X	PARTICIPANT	\N	PRESENT	0
745594	744171	20092G	PARTICIPANT	\N	PRESENT	0
745595	744171	20046A	PARTICIPANT	\N	PRESENT	0
745644	744173	12041X	PARTICIPANT	\N	PRESENT	0
745645	744173	20080C	PARTICIPANT	\N	PRESENT	0
745646	744173	19503N	PARTICIPANT	\N	PRESENT	0
745647	744173	20028X	PARTICIPANT	\N	PRESENT	0
745648	744173	20092G	PARTICIPANT	\N	PRESENT	0
745649	744173	11056N	PARTICIPANT	\N	PRESENT	0
745650	744173	14219Q	PARTICIPANT	\N	PRESENT	0
745651	744173	20120S	PARTICIPANT	\N	PRESENT	0
745652	744173	19695N	PARTICIPANT	\N	PRESENT	0
745653	744173	20046A	PARTICIPANT	\N	PRESENT	0
745654	744173	11012A	PARTICIPANT	\N	PRESENT	0
745655	744173	14147R	PARTICIPANT	\N	PRESENT	0
745656	744173	10006L	PARTICIPANT	\N	PRESENT	0
745657	744173	20062A	PARTICIPANT	\N	PRESENT	0
745658	744173	20066E	PARTICIPANT	\N	PRESENT	0
745659	744173	20052X	PARTICIPANT	\N	PRESENT	0
745660	744173	19713W	PARTICIPANT	\N	PRESENT	0
745661	744173	01024M	PARTICIPANT	\N	PRESENT	0
745662	744173	14030Q	PARTICIPANT	\N	PRESENT	0
745663	744173	14207L	PARTICIPANT	\N	PRESENT	0
745664	744173	20180F	PARTICIPANT	\N	PRESENT	0
745665	744173	20038A	PARTICIPANT	\N	PRESENT	0
745666	744173	14257W	PARTICIPANT	\N	PRESENT	0
745667	744173	20044X	PARTICIPANT	\N	PRESENT	0
745668	744173	20022R	PARTICIPANT	\N	PRESENT	0
745669	744173	11090Q	PARTICIPANT	\N	PRESENT	0
745670	744173	14031R	PARTICIPANT	\N	PRESENT	0
745671	744173	14169X	PARTICIPANT	\N	PRESENT	0
745672	744173	20124W	PARTICIPANT	\N	PRESENT	0
745673	744173	14215L	PARTICIPANT	\N	PRESENT	0
745674	744173	19441R	PARTICIPANT	\N	PRESENT	0
740516	738260	97011G	PARTICIPANT	\N	PRESENT	0
740557	733724	20146D	PARTICIPANT	\N	PRESENT	0
740558	733724	20148F	PARTICIPANT	\N	PRESENT	0
740559	733724	97011G	PARTICIPANT	\N	PRESENT	0
740560	733724	14059S	PRESIDENT	0	PRESENT	0
740562	733724	19717B	PARTICIPANT	\N	PRESENT	1
741401	741397	17737W	PARTICIPANT	\N	PRESENT	0
741403	741397	14331P	PARTICIPANT	\N	PRESENT	0
741413	741411	17737W	PARTICIPANT	\N	PRESENT	0
741426	741423	17737W	PARTICIPANT	\N	PRESENT	0
741473	741472	17737W	PARTICIPANT	\N	PRESENT	0
741474	741472	14133K	PARTICIPANT	\N	PRESENT	0
741478	741477	17737W	PARTICIPANT	\N	PRESENT	0
741511	741482	14069U	PARTICIPANT	\N	PRESENT	0
741512	741482	17737W	PARTICIPANT	\N	PRESENT	0
741513	741482	20248J	PARTICIPANT	\N	PRESENT	0
741515	741482	11026G	PARTICIPANT	\N	PRESENT	0
741516	741482	14169X	PARTICIPANT	\N	PRESENT	0
747812	747804	01048V	PARTICIPANT	\N	PRESENT	0
747813	747804	19693L	PARTICIPANT	\N	PRESENT	0
747814	747804	19503N	PARTICIPANT	\N	PRESENT	0
747816	747804	20072C	PARTICIPANT	\N	EXCUSE	0
747817	747804	20128B	PARTICIPANT	\N	EXCUSE	0
747818	747804	20066E	PARTICIPANT	\N	EXCUSE	0
747820	745903	14259Y	PARTICIPANT	\N	PRESENT	0
747821	745903	01028R	PARTICIPANT	\N	PRESENT	0
747822	747804	19723Y	PARTICIPANT	\N	PRESENT	0
747824	747804	04043D	PARTICIPANT	\N	PRESENT	0
747828	747804	19735D	PARTICIPANT	\N	EXCUSE	0
747829	747804	11067R	PARTICIPANT	\N	PRESENT	0
750299	741502	20080C	PARTICIPANT	\N	EXCUSE	0
750300	741502	20106U	PARTICIPANT	\N	EXCUSE	0
750301	741502	07029T	PARTICIPANT	\N	EXCUSE	0
750302	741502	14109K	PARTICIPANT	\N	EXCUSE	0
750303	741502	19866P	PARTICIPANT	\N	EXCUSE	0
750304	741502	20118Y	PARTICIPANT	\N	EXCUSE	0
750305	741502	20130U	PARTICIPANT	\N	EXCUSE	0
750306	741502	14030Q	PRESIDENT	0	PRESENT	0
750307	741502	19715Y	PARTICIPANT	\N	PRESENT	0
750308	741502	20098N	PARTICIPANT	\N	PRESENT	0
750309	741502	19717B	PARTICIPANT	\N	PRESENT	0
750349	741502	19577H	PARTICIPANT	\N	PRESENT	0
750350	741502	20034V	PARTICIPANT	\N	PRESENT	0
750351	741502	20024T	PARTICIPANT	\N	PRESENT	0
750378	741502	19749K	PARTICIPANT	\N	PRESENT	0
750379	741502	14147R	PARTICIPANT	\N	PRESENT	0
750381	741502	20146D	PARTICIPANT	\N	PRESENT	0
750395	741502	97011G	PARTICIPANT	\N	PRESENT	0
750423	741502	17023S	PARTICIPANT	\N	PRESENT	0
751493	750891	14133K	PARTICIPANT	\N	PRESENT	0
751494	750891	19701S	PARTICIPANT	\N	PRESENT	0
751495	750891	11026G	PARTICIPANT	\N	PRESENT	0
751496	750891	08034U	PARTICIPANT	\N	PRESENT	0
751497	750891	14097Y	PARTICIPANT	\N	PRESENT	0
751498	750891	14073Q	PARTICIPANT	\N	PRESENT	0
751499	750891	14001X	PARTICIPANT	\N	PRESENT	0
751500	750891	12041X	PARTICIPANT	\N	PRESENT	0
752024	752022	11053K	PARTICIPANT	\N	PRESENT	0
751502	750891	14331P	PRESIDENT	0	PRESENT	0
751503	750891	10015M	PARTICIPANT	\N	PRESENT	0
751504	750891	11101A	PARTICIPANT	\N	PRESENT	0
752023	752022	05008E	PARTICIPANT	\N	PRESENT	0
752025	752022	01028R	PARTICIPANT	\N	PRESENT	0
753502	753251	20116W	PARTICIPANT	\N	PRESENT	0
753500	753251	19667J	PARTICIPANT	\N	EXCUSE	0
753501	753251	20024T	PARTICIPANT	\N	PRESENT	0
753503	753251	21048G	PARTICIPANT	\N	PRESENT	0
753504	753251	20086J	PARTICIPANT	\N	PRESENT	0
753505	753251	20094J	PARTICIPANT	\N	PRESENT	0
753506	753251	20080C	PARTICIPANT	\N	PRESENT	0
753507	753251	14083S	PARTICIPANT	\N	PRESENT	0
753508	753251	11053K	PARTICIPANT	\N	PRESENT	0
753509	753251	21090J	PARTICIPANT	\N	PRESENT	0
753510	753251	21072G	PARTICIPANT	\N	PRESENT	0
753511	753251	20070A	PARTICIPANT	\N	PRESENT	0
753512	753251	21041Y	PARTICIPANT	\N	PRESENT	0
753513	753251	14327T	PARTICIPANT	\N	PRESENT	0
753514	753251	20134Y	PARTICIPANT	\N	PRESENT	0
753515	753251	11074Q	PARTICIPANT	\N	PRESENT	0
753516	753251	11110B	PARTICIPANT	\N	PRESENT	0
753517	753251	19647E	PARTICIPANT	\N	PRESENT	0
753518	753251	07004J	PARTICIPANT	\N	PRESENT	0
753519	753251	19399H	PARTICIPANT	\N	PRESENT	0
753520	753251	11048N	PARTICIPANT	\N	PRESENT	0
753521	753251	14121F	PARTICIPANT	\N	PRESENT	0
753522	753251	20126Y	PARTICIPANT	\N	PRESENT	0
753523	753251	07029T	PARTICIPANT	\N	PRESENT	0
753524	753251	19711U	PARTICIPANT	\N	PRESENT	0
753525	753251	08010L	PARTICIPANT	\N	PRESENT	0
753526	753251	08034U	PARTICIPANT	\N	PRESENT	0
753527	753251	12016W	PARTICIPANT	\N	PRESENT	0
753528	753251	19335Q	PARTICIPANT	\N	PRESENT	0
753529	753251	08011M	PARTICIPANT	\N	PRESENT	0
753530	753251	14253S	PARTICIPANT	\N	PRESENT	0
753531	753251	19573D	PARTICIPANT	\N	PRESENT	0
753532	753251	20050V	PARTICIPANT	\N	PRESENT	0
753533	753251	19349W	PARTICIPANT	\N	PRESENT	0
753534	753251	14331P	PARTICIPANT	\N	PRESENT	0
753535	753251	14225N	PRESIDENT	0	PRESENT	0
753536	753251	20044X	PARTICIPANT	\N	PRESENT	0
753537	753251	19687N	PARTICIPANT	\N	PRESENT	0
753538	753251	21079P	PARTICIPANT	\N	PRESENT	0
753539	753251	20062A	PARTICIPANT	\N	PRESENT	0
753540	753251	21069M	PARTICIPANT	\N	PRESENT	0
753541	753251	19479G	PARTICIPANT	\N	PRESENT	0
753542	753251	08009T	PARTICIPANT	\N	EXCUSE	0
753543	753251	14173T	PARTICIPANT	\N	EXCUSE	0
767029	765402	14179A	PARTICIPANT	\N	PRESENT	0
767030	766040	19703U	PRESIDENT	0	PRESENT	0
767031	766040	19760E	PARTICIPANT	\N	PRESENT	0
767032	766040	14026U	PARTICIPANT	\N	PRESENT	0
767033	766040	14217N	PARTICIPANT	\N	PRESENT	0
767034	766040	19569H	PARTICIPANT	\N	PRESENT	0
767035	766040	19798U	PARTICIPANT	\N	PRESENT	0
767036	766040	20090E	PARTICIPANT	\N	PRESENT	0
767037	766040	19691J	PARTICIPANT	\N	PRESENT	0
767038	766040	01034P	PARTICIPANT	\N	PRESENT	0
767039	766040	21064G	PARTICIPANT	\N	PRESENT	0
767040	766040	04092N	PARTICIPANT	\N	PRESENT	0
767041	766040	19657G	PARTICIPANT	\N	PRESENT	0
767042	766040	19723Y	PARTICIPANT	\N	PRESENT	0
767043	766040	14213J	PARTICIPANT	\N	PRESENT	0
767044	766040	21081H	PARTICIPANT	\N	PRESENT	0
767045	766040	20148F	PARTICIPANT	\N	PRESENT	0
767046	766040	21087P	PARTICIPANT	\N	EXCUSE	0
767047	765402	14071N	PARTICIPANT	\N	PRESENT	0
767048	765402	14042U	PARTICIPANT	\N	PRESENT	0
767049	765402	14195A	PARTICIPANT	\N	PRESENT	0
767050	765402	21070E	PARTICIPANT	\N	PRESENT	0
767051	765402	04045F	PARTICIPANT	\N	PRESENT	0
767052	765402	19301E	PARTICIPANT	\N	PRESENT	0
767053	765402	18193Q	PARTICIPANT	\N	PRESENT	0
767054	765402	19683J	PARTICIPANT	\N	PRESENT	0
767055	765402	19760E	PARTICIPANT	\N	PRESENT	0
767056	765402	20130U	PARTICIPANT	\N	PRESENT	0
767057	765402	14231L	PARTICIPANT	\N	PRESENT	0
767058	765402	17965H	PARTICIPANT	\N	PRESENT	0
767059	765402	19713W	PARTICIPANT	\N	PRESENT	0
767060	765402	19798U	PARTICIPANT	\N	PRESENT	0
767061	765402	14053L	PARTICIPANT	\N	PRESENT	0
767062	765402	20090E	PARTICIPANT	\N	PRESENT	0
767063	765402	20148F	PARTICIPANT	\N	PRESENT	0
767064	765402	14033T	PARTICIPANT	\N	PRESENT	0
767065	765402	19569H	PARTICIPANT	\N	PRESENT	0
767066	765402	04092N	PARTICIPANT	\N	PRESENT	0
767067	765402	19687N	PARTICIPANT	\N	PRESENT	0
767068	765402	20028X	PARTICIPANT	\N	PRESENT	0
767069	765402	18207D	PARTICIPANT	\N	PRESENT	0
767070	765402	19758L	PARTICIPANT	\N	PRESENT	0
767071	765402	14187A	PARTICIPANT	\N	PRESENT	0
767072	765402	21081H	PARTICIPANT	\N	PRESENT	0
767073	765402	21039F	PARTICIPANT	\N	PRESENT	0
767074	765402	21058J	PARTICIPANT	\N	PRESENT	0
767075	765402	20132W	PARTICIPANT	\N	PRESENT	0
767076	765402	21066J	PARTICIPANT	\N	PRESENT	0
753327	752389	14217N	PARTICIPANT	\N	PRESENT	0
753328	752389	20248J	PARTICIPANT	\N	PRESENT	0
753329	752389	14042U	PARTICIPANT	\N	PRESENT	0
753330	752389	20040T	PARTICIPANT	\N	PRESENT	0
753331	752389	14281W	PARTICIPANT	\N	PRESENT	0
753332	752389	08045X	PARTICIPANT	\N	PRESENT	0
753333	752389	14355X	PARTICIPANT	\N	PRESENT	0
753334	752389	14026U	PARTICIPANT	\N	PRESENT	0
753335	752389	19553Y	PARTICIPANT	\N	PRESENT	0
753336	752389	19591F	PARTICIPANT	\N	PRESENT	0
753337	752389	14213J	PARTICIPANT	\N	PRESENT	0
753338	752389	21081H	PARTICIPANT	\N	PRESENT	0
753339	752389	19723Y	PARTICIPANT	\N	PRESENT	0
753340	752389	18193Q	PARTICIPANT	\N	PRESENT	0
753341	752389	14223L	PARTICIPANT	\N	PRESENT	0
755854	755853	11048N	PARTICIPANT	\N	PRESENT	0
753343	752389	08061X	PARTICIPANT	\N	PRESENT	0
753344	752389	20148F	PARTICIPANT	\N	PRESENT	0
753345	752389	17965H	PARTICIPANT	\N	PRESENT	0
753346	752389	19679N	PARTICIPANT	\N	PRESENT	0
753347	752389	19798U	PARTICIPANT	\N	PRESENT	0
753348	752389	11045K	PARTICIPANT	\N	PRESENT	0
753349	752389	21049H	PARTICIPANT	\N	PRESENT	0
753350	752389	19703U	PARTICIPANT	\N	PRESENT	0
753351	752389	19713W	PARTICIPANT	\N	PRESENT	0
753650	753649	14255U	PARTICIPANT	\N	PRESENT	0
753743	752395	14030Q	PARTICIPANT	\N	EXCUSE	0
754615	753670	21039F	PARTICIPANT	\N	PRESENT	0
754616	753670	21049H	PARTICIPANT	\N	PRESENT	0
754617	753670	20096L	PARTICIPANT	\N	PRESENT	0
754620	754619	15197G	PARTICIPANT	\N	PRESENT	0
754621	753670	20140W	PARTICIPANT	\N	PRESENT	0
754661	753670	19591F	PARTICIPANT	\N	PRESENT	0
754662	753670	19301E	PARTICIPANT	\N	PRESENT	0
754665	753670	08061X	PARTICIPANT	\N	PRESENT	0
754666	753670	21071F	PARTICIPANT	\N	PRESENT	0
754668	753669	19553Y	PARTICIPANT	\N	PRESENT	0
754669	753669	19569H	PARTICIPANT	\N	PRESENT	0
754670	753669	14217N	PARTICIPANT	\N	PRESENT	0
754671	753669	19713W	PARTICIPANT	\N	PRESENT	0
754672	753669	19657G	PARTICIPANT	\N	PRESENT	0
754673	753669	19760E	PARTICIPANT	\N	PRESENT	0
754674	753669	20090E	PARTICIPANT	\N	EXCUSE	0
754675	753669	17965H	PARTICIPANT	\N	PRESENT	0
754676	753669	14042U	PARTICIPANT	\N	PRESENT	0
754677	753669	04092N	PARTICIPANT	\N	PRESENT	0
754678	753669	20148F	PARTICIPANT	\N	PRESENT	0
754679	753669	14213J	PARTICIPANT	\N	PRESENT	0
754680	753669	19798U	PARTICIPANT	\N	PRESENT	0
754681	753669	19679N	PARTICIPANT	\N	PRESENT	0
755850	755849	11048N	PARTICIPANT	\N	PRESENT	0
754683	753669	18193Q	PARTICIPANT	\N	PRESENT	0
754684	753669	14223L	PARTICIPANT	\N	PRESENT	0
754685	753669	14026U	PARTICIPANT	\N	PRESENT	0
754686	753669	01034P	PARTICIPANT	\N	PRESENT	0
754687	753669	20248J	PARTICIPANT	\N	PRESENT	0
754688	753669	19367Y	PARTICIPANT	\N	PRESENT	0
754689	753669	21045D	PARTICIPANT	\N	PRESENT	0
754690	753669	08045X	PARTICIPANT	\N	PRESENT	0
754691	753669	21094N	PARTICIPANT	\N	PRESENT	0
754692	753669	17779H	PARTICIPANT	\N	PRESENT	0
754693	753669	21081H	PARTICIPANT	\N	PRESENT	0
754694	753669	19301E	PARTICIPANT	\N	PRESENT	0
754695	753669	19591F	PARTICIPANT	\N	PRESENT	0
754696	753669	21071F	PARTICIPANT	\N	PRESENT	0
754697	753669	08061X	PARTICIPANT	\N	PRESENT	0
754698	753669	14195A	PARTICIPANT	\N	PRESENT	0
754699	753669	21046E	PARTICIPANT	\N	PRESENT	0
754700	753669	21087P	PARTICIPANT	\N	PRESENT	0
754701	753669	20140W	PARTICIPANT	\N	PRESENT	0
754702	753669	14281W	PARTICIPANT	\N	PRESENT	0
754703	753669	19691J	PARTICIPANT	\N	PRESENT	0
754704	753669	19866P	PARTICIPANT	\N	PRESENT	0
754705	753669	21064G	PARTICIPANT	\N	PRESENT	0
754706	753669	19683J	PARTICIPANT	\N	PRESENT	0
754707	753669	21049H	PARTICIPANT	\N	PRESENT	0
754708	753669	21039F	PARTICIPANT	\N	PRESENT	0
754709	753669	21097R	PARTICIPANT	\N	PRESENT	0
754710	753669	20130U	PARTICIPANT	\N	PRESENT	0
754711	753669	19758L	PARTICIPANT	\N	PRESENT	0
754712	753669	20096L	PARTICIPANT	\N	PRESENT	0
754713	753669	14071N	PRESIDENT	\N	PRESENT	0
754756	753669	19703U	PARTICIPANT	\N	PRESENT	0
755852	755851	11048N	PARTICIPANT	\N	PRESENT	0
755856	755855	11048N	PARTICIPANT	\N	PRESENT	0
757709	757708	20108W	PARTICIPANT	\N	PRESENT	0
757710	757708	21044C	PARTICIPANT	\N	PRESENT	0
757711	756911	20108W	PARTICIPANT	\N	PRESENT	0
757712	757087	19798U	PARTICIPANT	\N	PRESENT	0
757713	757087	20130U	PARTICIPANT	\N	PRESENT	0
757714	757087	21045D	PARTICIPANT	\N	PRESENT	0
757743	757742	20026V	PARTICIPANT	\N	PRESENT	0
757744	757742	08012N	PARTICIPANT	\N	PRESENT	0
757746	757745	08012N	PARTICIPANT	\N	PRESENT	0
757747	757741	08012N	PARTICIPANT	\N	PRESENT	0
757748	757741	11043H	PARTICIPANT	\N	PRESENT	0
757749	757741	19954N	PARTICIPANT	\N	PRESENT	0
757750	756310	08012N	PARTICIPANT	\N	PRESENT	0
758171	757795	11090Q	PARTICIPANT	\N	PRESENT	0
758178	757954	19798U	PARTICIPANT	\N	PRESENT	0
758179	757954	21049H	PARTICIPANT	\N	PRESENT	0
758180	757954	20130U	PARTICIPANT	\N	PRESENT	0
758181	757955	21049H	PARTICIPANT	\N	PRESENT	0
758182	757955	20130U	PARTICIPANT	\N	PRESENT	0
758188	757955	19798U	PARTICIPANT	\N	PRESENT	0
758208	757795	19713W	PARTICIPANT	\N	PRESENT	0
758209	757795	21094N	PARTICIPANT	\N	PRESENT	0
758210	757795	19758L	PARTICIPANT	\N	PRESENT	0
758211	757795	19553Y	PARTICIPANT	\N	PRESENT	0
758212	757795	21097R	PARTICIPANT	\N	PRESENT	0
758214	757795	17965H	PARTICIPANT	\N	PRESENT	0
758215	757795	21081H	PARTICIPANT	\N	PRESENT	0
758216	757795	21069M	PARTICIPANT	\N	PRESENT	0
758217	757795	14195A	PARTICIPANT	\N	PRESENT	0
758218	757795	19691J	PARTICIPANT	\N	PRESENT	0
758219	757795	21043B	PARTICIPANT	\N	PRESENT	0
758220	757795	20140W	PARTICIPANT	\N	PRESENT	0
758221	757795	20180F	PARTICIPANT	\N	PRESENT	0
758222	757795	14069U	PARTICIPANT	\N	PRESENT	0
758232	757795	19954N	PARTICIPANT	\N	PRESENT	0
758229	757795	11043H	PARTICIPANT	\N	PRESENT	0
758230	757795	21070E	PARTICIPANT	\N	PRESENT	0
758233	757795	21068L	PARTICIPANT	\N	PRESENT	0
758234	757795	08028W	PARTICIPANT	\N	PRESENT	0
758235	757795	21076L	PARTICIPANT	\N	PRESENT	0
758236	757795	14213J	PARTICIPANT	\N	PRESENT	0
758237	757795	21067K	PARTICIPANT	\N	PRESENT	0
758238	757795	21058J	PARTICIPANT	\N	PRESENT	0
758239	757795	20062A	PARTICIPANT	\N	PRESENT	0
758240	757795	08009T	PARTICIPANT	\N	PRESENT	0
758241	757795	20130U	PARTICIPANT	\N	PRESENT	0
758242	757795	21039F	PARTICIPANT	\N	PRESENT	0
758243	757795	20118Y	PARTICIPANT	\N	PRESENT	0
758244	757795	19798U	PARTICIPANT	\N	PRESENT	0
758245	757795	20248J	PARTICIPANT	\N	PRESENT	0
758246	757795	21046E	PARTICIPANT	\N	PRESENT	0
758247	757795	21087P	PARTICIPANT	\N	PRESENT	0
758248	757795	19683J	PARTICIPANT	\N	PRESENT	0
758249	757795	14223L	PARTICIPANT	\N	PRESENT	0
758250	757795	14073Q	PARTICIPANT	\N	PRESENT	0
758251	757795	20072C	PARTICIPANT	\N	PRESENT	0
758252	757795	21071F	PARTICIPANT	\N	PRESENT	0
758253	757795	20022R	PARTICIPANT	\N	PRESENT	0
758254	757795	19729F	PARTICIPANT	\N	PRESENT	0
758255	757795	20096L	PARTICIPANT	\N	PRESENT	0
758256	757795	20148F	PARTICIPANT	\N	PRESENT	0
758257	757795	07029T	PARTICIPANT	\N	PRESENT	0
758258	757795	21064G	PARTICIPANT	\N	PRESENT	0
758259	757795	19367Y	PARTICIPANT	\N	PRESENT	0
758260	757795	20076G	PARTICIPANT	\N	PRESENT	0
758261	757795	19629C	PARTICIPANT	\N	PRESENT	0
758262	757795	14207L	PARTICIPANT	\N	PRESENT	0
758263	757795	19565D	PARTICIPANT	\N	PRESENT	0
758264	757795	20046A	PARTICIPANT	\N	PRESENT	0
758265	757795	21047F	PARTICIPANT	\N	PRESENT	0
758266	757795	21085M	PARTICIPANT	\N	PRESENT	0
758267	757795	19760E	PARTICIPANT	\N	PRESENT	0
758268	757795	14071N	PARTICIPANT	\N	PRESENT	0
758269	757795	18193Q	PARTICIPANT	\N	PRESENT	0
758270	757795	21091K	PARTICIPANT	\N	PRESENT	0
758271	757795	98022P	PARTICIPANT	\N	PRESENT	0
743811	740642	14215L	PARTICIPANT	\N	PRESENT	0
743933	740810	11031D	PARTICIPANT	\N	PRESENT	0
743934	740810	20266L	PRESIDENT	0	PRESENT	0
748120	748119	14001X	PARTICIPANT	\N	PRESENT	0
748121	748119	04057K	PARTICIPANT	\N	PRESENT	0
748125	748123	14001X	PARTICIPANT	\N	PRESENT	0
748126	748123	04057K	PARTICIPANT	\N	PRESENT	0
748608	748103	01025N	PARTICIPANT	\N	PRESENT	0
748609	748103	01024M	PARTICIPANT	\N	PRESENT	0
748610	748428	19593H	PARTICIPANT	\N	PRESENT	0
748611	748428	19643A	PARTICIPANT	\N	PRESENT	0
748612	748428	20064C	PRESIDENT	0	PRESENT	0
748613	748428	14251Q	PARTICIPANT	\N	PRESENT	0
748614	748428	20068G	PARTICIPANT	\N	PRESENT	0
748615	748428	11083R	PARTICIPANT	\N	PRESENT	0
748616	748428	14147R	PARTICIPANT	\N	PRESENT	0
748617	748428	11090Q	PARTICIPANT	\N	PRESENT	0
748618	748428	20152B	PARTICIPANT	\N	PRESENT	0
748619	748428	04070G	PARTICIPANT	\N	EXCUSE	0
748620	748428	17737W	PARTICIPANT	\N	EXCUSE	0
748621	748428	14193X	PARTICIPANT	\N	EXCUSE	0
748622	748103	04070G	PARTICIPANT	\N	PRESENT	0
748623	748103	19826F	PARTICIPANT	\N	PRESENT	0
748624	748103	20134Y	PARTICIPANT	\N	PRESENT	0
748625	748103	20106U	PARTICIPANT	\N	PRESENT	0
748626	748103	14207L	PARTICIPANT	\N	PRESENT	0
748627	748103	20052X	PARTICIPANT	\N	PRESENT	0
748628	748103	20980G	PARTICIPANT	\N	PRESENT	0
748629	748103	19467C	PARTICIPANT	\N	PRESENT	0
748630	748103	20104S	PARTICIPANT	\N	PRESENT	0
748631	748103	20152B	PARTICIPANT	\N	PRESENT	0
748632	748103	20056C	PARTICIPANT	\N	PRESENT	0
748633	748103	20124W	PARTICIPANT	\N	PRESENT	0
748634	748103	20094J	PARTICIPANT	\N	PRESENT	0
748635	748103	20038A	PARTICIPANT	\N	PRESENT	0
748712	748104	14038Y	PARTICIPANT	\N	PRESENT	0
748713	748104	20094J	PARTICIPANT	\N	PRESENT	0
748714	748104	19593H	PARTICIPANT	\N	PRESENT	0
748715	748104	14257W	PARTICIPANT	\N	PRESENT	0
748716	748104	08045X	PARTICIPANT	\N	PRESENT	0
748717	748104	18193Q	PARTICIPANT	\N	PRESENT	0
748718	748104	20134Y	PARTICIPANT	\N	PRESENT	0
748719	748104	19387D	PARTICIPANT	\N	PRESENT	0
748720	748104	20132W	PARTICIPANT	\N	PRESENT	0
748721	748104	19553Y	PARTICIPANT	\N	PRESENT	0
748722	748104	14107H	PARTICIPANT	\N	PRESENT	0
748723	748104	19713W	PARTICIPANT	\N	PRESENT	0
748724	748104	20052X	PARTICIPANT	\N	PRESENT	0
748725	748104	14030Q	PARTICIPANT	\N	PRESENT	0
748726	748104	14073Q	PARTICIPANT	\N	PRESENT	0
748727	748104	20066E	PARTICIPANT	\N	PRESENT	0
748728	748104	98022P	PARTICIPANT	\N	PRESENT	0
748729	748104	20124W	PARTICIPANT	\N	PRESENT	0
748730	748104	20032T	PARTICIPANT	\N	PRESENT	0
748731	748104	20104S	PARTICIPANT	\N	PRESENT	0
748732	748104	20026V	PARTICIPANT	\N	PRESENT	0
748733	748104	20180F	PARTICIPANT	\N	PRESENT	0
748734	748104	20980G	PARTICIPANT	\N	PRESENT	0
748735	748104	20034V	PARTICIPANT	\N	PRESENT	0
748736	748104	20056C	PARTICIPANT	\N	PRESENT	0
748737	748104	20112S	PARTICIPANT	\N	PRESENT	0
748738	748104	19565D	PARTICIPANT	\N	PRESENT	0
748739	748104	19758L	PARTICIPANT	\N	PRESENT	0
748740	748104	11045K	PARTICIPANT	\N	PRESENT	0
748741	748104	20106U	PARTICIPANT	\N	PRESENT	0
748742	748104	19782L	PARTICIPANT	\N	PRESENT	0
748743	748104	04045F	PARTICIPANT	\N	PRESENT	0
748744	748104	01025N	PARTICIPANT	\N	PRESENT	0
748745	748104	19611R	PARTICIPANT	\N	PRESENT	0
748746	748104	20152B	PARTICIPANT	\N	PRESENT	0
748747	748104	19533U	PARTICIPANT	\N	PRESENT	0
748748	748104	20024T	PARTICIPANT	\N	PRESENT	0
748749	748104	14191V	PARTICIPANT	\N	PRESENT	0
748750	748104	19723Y	PARTICIPANT	\N	PRESENT	0
748751	748104	19447X	PARTICIPANT	\N	PRESENT	0
748752	748104	20038A	PARTICIPANT	\N	PRESENT	0
748753	748104	20076G	PARTICIPANT	\N	PRESENT	0
748754	748104	19467C	PARTICIPANT	\N	PRESENT	0
748755	748104	04070G	PARTICIPANT	\N	PRESENT	0
748763	748104	20128B	PARTICIPANT	\N	PRESENT	0
748757	748104	14207L	PARTICIPANT	\N	PRESENT	0
748758	748104	20022R	PARTICIPANT	\N	PRESENT	0
748759	748104	19745F	PARTICIPANT	\N	PRESENT	0
748760	748104	14031R	PARTICIPANT	\N	PRESENT	0
748761	748104	19762G	PARTICIPANT	\N	PRESENT	0
748762	748104	20082E	PARTICIPANT	\N	PRESENT	0
748764	748104	14205J	PARTICIPANT	\N	PRESENT	0
748765	748104	11012A	PARTICIPANT	\N	PRESENT	0
748766	748104	20140W	PARTICIPANT	\N	PRESENT	0
748767	748104	14213J	PARTICIPANT	\N	PRESENT	0
748768	748104	14151M	PARTICIPANT	\N	PRESENT	0
748769	748104	20142Y	PARTICIPANT	\N	PRESENT	0
748770	748104	11067R	PARTICIPANT	\N	PRESENT	0
748771	748104	14229S	PARTICIPANT	\N	PRESENT	0
748772	748104	19798U	PARTICIPANT	\N	PRESENT	0
748773	748104	14331P	PARTICIPANT	\N	PRESENT	0
748774	748104	14147R	PARTICIPANT	\N	PRESENT	0
748775	748104	20138D	PARTICIPANT	\N	PRESENT	0
748776	748104	19649G	PARTICIPANT	\N	PRESENT	0
748777	748104	20122U	PARTICIPANT	\N	PRESENT	0
748778	748104	19701S	PARTICIPANT	\N	PRESENT	0
748779	748104	14259Y	PARTICIPANT	\N	PRESENT	0
748780	748104	19679N	PARTICIPANT	\N	PRESENT	0
748781	748104	20018V	PARTICIPANT	\N	PRESENT	0
748782	748104	19739H	PARTICIPANT	\N	PRESENT	0
749225	748140	14189C	PARTICIPANT	\N	PRESENT	0
749226	748140	20094J	PARTICIPANT	\N	PRESENT	0
749227	748140	11101A	PARTICIPANT	\N	PRESENT	0
749228	748140	14357A	PARTICIPANT	\N	PRESENT	0
748710	748104	12041X	PARTICIPANT	\N	PRESENT	0
748711	748104	14179A	PARTICIPANT	\N	PRESENT	0
749229	748140	20100N	PARTICIPANT	\N	PRESENT	0
749230	748140	11083R	PARTICIPANT	\N	PRESENT	0
749231	748140	14026U	PARTICIPANT	\N	PRESENT	0
749232	748140	19725B	PARTICIPANT	\N	PRESENT	0
749233	748140	19333N	PARTICIPANT	\N	PRESENT	0
749234	748140	19711U	PARTICIPANT	\N	PRESENT	0
749235	748140	08034U	PARTICIPANT	\N	PRESENT	0
749236	748140	04070G	PARTICIPANT	\N	PRESENT	0
749237	748140	14169X	PARTICIPANT	\N	PRESENT	0
749238	748140	14237S	PARTICIPANT	\N	PRESENT	0
749241	748140	14033T	PARTICIPANT	\N	PRESENT	0
749240	748140	14331P	PRESIDENT	0	PRESENT	0
751682	751681	14215L	PARTICIPANT	\N	PRESENT	0
753354	753249	19768N	PARTICIPANT	\N	PRESENT	0
753355	753249	20088L	PARTICIPANT	\N	PRESENT	0
753356	753249	19782L	PARTICIPANT	\N	PRESENT	0
753357	753249	20092G	PARTICIPANT	\N	PRESENT	0
753358	753249	14357A	PARTICIPANT	\N	PRESENT	0
753359	753249	20078J	PARTICIPANT	\N	PRESENT	0
753360	753249	19413M	PARTICIPANT	\N	PRESENT	0
753361	753249	20082E	PARTICIPANT	\N	PRESENT	0
753362	753249	14221J	PARTICIPANT	\N	PRESENT	0
753363	753249	20104S	PARTICIPANT	\N	PRESENT	0
753364	753249	19631V	PARTICIPANT	\N	PRESENT	0
753365	753249	08015R	PARTICIPANT	\N	PRESENT	0
753366	753249	19575F	PARTICIPANT	\N	PRESENT	0
753367	753249	20018V	PARTICIPANT	\N	PRESENT	0
753368	753249	08028W	PARTICIPANT	\N	PRESENT	0
753369	753249	19563B	PARTICIPANT	\N	PRESENT	0
753370	753249	21050A	PARTICIPANT	\N	PRESENT	0
753371	753249	21096Q	PARTICIPANT	\N	PRESENT	0
753372	753249	20028X	PARTICIPANT	\N	PRESENT	0
753373	753249	14038Y	PARTICIPANT	\N	PRESENT	0
753374	753249	20030R	PARTICIPANT	\N	PRESENT	0
753375	753249	21052C	PARTICIPANT	\N	PRESENT	0
753376	753249	20034V	PARTICIPANT	\N	PRESENT	0
753377	753249	21054E	PARTICIPANT	\N	PRESENT	0
753378	753249	14187A	PRESIDENT	0	PRESENT	0
753379	753249	20038A	PARTICIPANT	\N	PRESENT	0
753380	753249	21075K	PARTICIPANT	\N	PRESENT	0
753381	753249	21083K	PARTICIPANT	\N	PRESENT	0
753382	753249	20144B	PARTICIPANT	\N	PRESENT	0
753383	753249	21086N	PARTICIPANT	\N	PRESENT	0
753384	753249	19695N	PARTICIPANT	\N	PRESENT	0
753385	753249	21092L	PARTICIPANT	\N	PRESENT	0
753386	753249	14033T	PARTICIPANT	\N	PRESENT	0
753387	753249	11090Q	PARTICIPANT	\N	PRESENT	0
753388	753249	21093M	PARTICIPANT	\N	PRESENT	0
753389	753249	20054A	PARTICIPANT	\N	PRESENT	0
745680	744173	19758L	PARTICIPANT	\N	PRESENT	0
745681	744173	20104S	PARTICIPANT	\N	PRESENT	0
745717	744172	14026U	PARTICIPANT	\N	PRESENT	0
745683	744173	14231L	PARTICIPANT	\N	PRESENT	0
745719	744172	19503N	PARTICIPANT	\N	PRESENT	0
745720	744172	20028X	PARTICIPANT	\N	PRESENT	0
745721	744172	20092G	PARTICIPANT	\N	PRESENT	0
745675	744173	19747H	PARTICIPANT	\N	PRESENT	0
745676	744173	19447X	PARTICIPANT	\N	PRESENT	0
745722	744172	20100N	PARTICIPANT	\N	PRESENT	0
745723	744172	20050V	PARTICIPANT	\N	PRESENT	0
745724	744172	14207L	PARTICIPANT	\N	PRESENT	0
745725	744172	11097X	PARTICIPANT	\N	PRESENT	0
745726	744172	20062A	PARTICIPANT	\N	PRESENT	0
745727	744172	20044X	PARTICIPANT	\N	PRESENT	0
745728	744172	14169X	PARTICIPANT	\N	PRESENT	0
745729	744172	14031R	PARTICIPANT	\N	PRESENT	0
745730	744172	11090Q	PARTICIPANT	\N	PRESENT	0
745731	744172	14071N	PARTICIPANT	\N	PRESENT	0
745732	744172	14219Q	PARTICIPANT	\N	PRESENT	0
745733	744172	20120S	PARTICIPANT	\N	PRESENT	0
745734	744172	20082E	PARTICIPANT	\N	PRESENT	0
745735	744172	19251M	PARTICIPANT	\N	PRESENT	0
745736	744172	19695N	PARTICIPANT	\N	PRESENT	0
745737	744172	20054A	PARTICIPANT	\N	PRESENT	0
745738	744172	14187A	PARTICIPANT	\N	PRESENT	0
745739	744172	10015M	PARTICIPANT	\N	PRESENT	0
745740	744172	14033T	PARTICIPANT	\N	PRESENT	0
745741	744172	20180F	PARTICIPANT	\N	PRESENT	0
745742	744172	20026V	PARTICIPANT	\N	PRESENT	0
745743	744172	20038A	PARTICIPANT	\N	PRESENT	0
745744	744172	20124W	PARTICIPANT	\N	PRESENT	0
745745	744172	19701S	PARTICIPANT	\N	PRESENT	0
745746	744172	20056C	PARTICIPANT	\N	PRESENT	0
745747	744172	19447X	PARTICIPANT	\N	PRESENT	0
745748	744172	20046A	PARTICIPANT	\N	PRESENT	0
745749	744172	14215L	PARTICIPANT	\N	PRESENT	0
745750	744172	14231L	PARTICIPANT	\N	PRESENT	0
745751	744172	14357A	PARTICIPANT	\N	PRESENT	0
745718	744172	20080C	PARTICIPANT	\N	PRESENT	0
745752	744172	14257W	PARTICIPANT	\N	PRESENT	0
745753	744172	14217N	PARTICIPANT	\N	PRESENT	0
745754	744172	20070A	PARTICIPANT	\N	PRESENT	0
745755	744172	19347U	PARTICIPANT	\N	PRESENT	0
745756	744172	11056N	PARTICIPANT	\N	PRESENT	0
745757	744172	19782L	PARTICIPANT	\N	PRESENT	0
745758	744172	14083S	PARTICIPANT	\N	PRESENT	0
745759	744172	14193X	PARTICIPANT	\N	PRESENT	0
745760	744172	19575F	PARTICIPANT	\N	PRESENT	0
745761	744172	19441R	PARTICIPANT	\N	PRESENT	0
745762	744172	08061X	PARTICIPANT	\N	PRESENT	0
745763	744172	20136B	PARTICIPANT	\N	PRESENT	0
745764	741499	19749K	PARTICIPANT	\N	PRESENT	0
745771	741499	20098N	PARTICIPANT	\N	PRESENT	0
745772	741499	14030Q	PRESIDENT	0	PRESENT	0
745773	741499	11031D	PARTICIPANT	\N	PRESENT	0
745774	744161	14357A	PARTICIPANT	\N	PRESENT	0
745775	744161	10015M	PARTICIPANT	\N	PRESENT	0
745776	744161	20094J	PARTICIPANT	\N	PRESENT	0
745777	744161	04070G	PARTICIPANT	\N	PRESENT	0
745778	744161	14331P	PRESIDENT	0	PRESENT	0
745779	744161	19593H	PARTICIPANT	\N	PRESENT	0
745780	744161	12041X	PARTICIPANT	\N	PRESENT	0
745781	744161	19441R	PARTICIPANT	\N	PRESENT	0
745782	744161	19611R	PARTICIPANT	\N	PRESENT	0
745783	744161	14169X	PARTICIPANT	\N	PRESENT	0
745802	744161	19711U	PARTICIPANT	\N	PRESENT	0
745803	744161	20104S	PARTICIPANT	\N	PRESENT	0
745810	745808	10006L	PARTICIPANT	\N	PRESENT	0
745811	745809	10006L	PARTICIPANT	\N	PRESENT	0
745812	745809	18193Q	PARTICIPANT	\N	PRESENT	0
745827	744161	20026V	PARTICIPANT	\N	PRESENT	0
745830	744161	20132W	PARTICIPANT	\N	PRESENT	0
745831	744161	20056C	PARTICIPANT	\N	PRESENT	0
745832	744161	19699S	PARTICIPANT	\N	PRESENT	0
745834	744161	20124W	PARTICIPANT	\N	PRESENT	0
745836	744161	04057K	PARTICIPANT	\N	EXCUSE	0
745854	744161	20084G	PARTICIPANT	\N	PRESENT	0
746044	745765	14026U	PARTICIPANT	\N	PRESENT	0
746045	745765	14281W	PARTICIPANT	\N	PRESENT	0
746046	745765	11067R	PARTICIPANT	\N	PRESENT	0
746047	745765	20130U	PARTICIPANT	\N	PRESENT	0
746048	745765	11097X	PARTICIPANT	\N	PRESENT	0
746049	746022	14026U	PARTICIPANT	\N	PRESENT	0
746050	746022	14281W	PARTICIPANT	\N	PRESENT	0
746051	746022	11067R	PARTICIPANT	\N	PRESENT	0
746052	746022	20130U	PARTICIPANT	\N	PRESENT	0
746053	746037	14026U	PARTICIPANT	\N	PRESENT	0
746054	746037	20130U	PARTICIPANT	\N	PRESENT	0
746055	746041	14026U	PARTICIPANT	\N	PRESENT	0
746056	746041	20130U	PARTICIPANT	\N	PRESENT	0
746582	746017	19697Q	PARTICIPANT	\N	PRESENT	0
746583	746017	11067R	PARTICIPANT	\N	PRESENT	0
746584	746017	20090E	PARTICIPANT	\N	PRESENT	0
746788	744790	19333N	PARTICIPANT	\N	PRESENT	0
746789	744790	20076G	PARTICIPANT	\N	PRESENT	0
746587	746017	18193Q	PARTICIPANT	\N	PRESENT	0
746588	746017	14223L	PARTICIPANT	\N	PRESENT	0
746589	746017	19553Y	PARTICIPANT	\N	PRESENT	0
746590	746017	11031D	PARTICIPANT	\N	PRESENT	0
746591	746017	14281W	PARTICIPANT	\N	PRESENT	0
746592	746017	19679N	PARTICIPANT	\N	PRESENT	0
746593	746017	14195A	PARTICIPANT	\N	PRESENT	0
746594	746017	14213J	PARTICIPANT	\N	PRESENT	0
746595	746017	19367Y	PARTICIPANT	\N	PRESENT	0
746596	746017	14217N	PARTICIPANT	\N	PRESENT	0
746597	746017	10006L	PRESIDENT	0	PRESENT	0
746790	744790	19549D	PARTICIPANT	\N	PRESENT	0
746599	746017	20130U	PARTICIPANT	\N	PRESENT	0
746600	746017	04092N	PARTICIPANT	\N	PRESENT	0
746601	746017	19713W	PARTICIPANT	\N	PRESENT	0
746602	746017	20040T	PARTICIPANT	\N	PRESENT	0
746626	744230	19647E	PARTICIPANT	\N	PRESENT	0
746604	746017	17965H	PARTICIPANT	\N	PRESENT	0
746605	746017	20148F	PARTICIPANT	\N	PRESENT	0
746606	746017	20248J	PARTICIPANT	\N	PRESENT	0
746607	746017	20066E	PARTICIPANT	\N	PRESENT	0
746819	744790	19739H	PARTICIPANT	\N	PRESENT	0
746609	746017	14071N	PARTICIPANT	\N	PRESENT	0
746610	746017	19760E	PARTICIPANT	\N	PRESENT	0
746611	746017	19415P	PARTICIPANT	\N	PRESENT	0
746612	746017	14042U	PARTICIPANT	\N	PRESENT	0
746613	746017	19723Y	PARTICIPANT	\N	PRESENT	0
746614	744230	14331P	PARTICIPANT	\N	PRESENT	0
746791	744790	19820Y	PARTICIPANT	\N	PRESENT	0
746792	744790	14219Q	PRESIDENT	0	PRESENT	0
746617	744230	19531S	PARTICIPANT	\N	PRESENT	0
746793	744790	19826F	PARTICIPANT	\N	PRESENT	0
746794	744790	20102Q	PARTICIPANT	\N	PRESENT	0
746795	744790	19599P	PARTICIPANT	\N	PRESENT	0
746796	744790	19637C	PARTICIPANT	\N	PRESENT	0
746622	744230	19335Q	PARTICIPANT	\N	PRESENT	0
746623	744230	19671E	PARTICIPANT	\N	PRESENT	0
746624	744230	20126Y	PARTICIPANT	\N	PRESENT	0
746797	744790	20096L	PARTICIPANT	\N	PRESENT	0
746798	744790	20100N	PARTICIPANT	\N	PRESENT	0
746799	744790	19551W	PARTICIPANT	\N	PRESENT	0
746800	744790	18083K	PARTICIPANT	\N	PRESENT	0
746801	744790	14237S	PARTICIPANT	\N	PRESENT	0
746631	744230	20070A	PARTICIPANT	\N	PRESENT	0
746802	744790	05012A	PARTICIPANT	\N	PRESENT	0
746633	744230	14327T	PARTICIPANT	\N	PRESENT	0
746803	744790	20106U	PARTICIPANT	\N	PRESENT	0
746635	744230	14225N	PRESIDENT	0	PRESENT	0
746804	744790	19503N	PARTICIPANT	\N	PRESENT	0
746805	744790	20020P	PARTICIPANT	\N	PRESENT	0
746638	744230	20252E	PARTICIPANT	\N	PRESENT	0
746639	744230	99004R	PARTICIPANT	\N	PRESENT	0
746806	744790	19685L	PARTICIPANT	\N	PRESENT	0
746807	744790	17367Q	PARTICIPANT	\N	PRESENT	0
746808	744790	19681G	PARTICIPANT	\N	PRESENT	0
746809	744790	20024T	PARTICIPANT	\N	PRESENT	0
746810	744790	11065P	PARTICIPANT	\N	PRESENT	0
746811	744790	19525U	PARTICIPANT	\N	PRESENT	0
746812	744790	20120S	PARTICIPANT	\N	PRESENT	0
746813	744790	20032T	PARTICIPANT	\N	PRESENT	0
746814	744790	20136B	PARTICIPANT	\N	PRESENT	0
746815	744790	20038A	PARTICIPANT	\N	PRESENT	0
746816	744790	14031R	PARTICIPANT	\N	PRESENT	0
746817	744790	20140W	PARTICIPANT	\N	PRESENT	0
746818	744790	14169X	PARTICIPANT	\N	PRESENT	0
739773	738297	19369B	PARTICIPANT	\N	EXCUSE	0
739774	738297	20126Y	PARTICIPANT	\N	EXCUSE	0
739775	738297	04045F	PARTICIPANT	\N	EXCUSE	0
739776	738297	20050V	PARTICIPANT	\N	EXCUSE	0
740447	737030	20106U	PARTICIPANT	\N	EXCUSE	0
740448	737030	14189C	PARTICIPANT	\N	EXCUSE	0
740449	737030	20024T	PARTICIPANT	\N	EXCUSE	0
740450	737030	20130U	PARTICIPANT	\N	EXCUSE	0
740451	737030	20118Y	PARTICIPANT	\N	EXCUSE	0
740452	737030	20080C	PARTICIPANT	\N	EXCUSE	0
740453	737030	19866P	PARTICIPANT	\N	EXCUSE	0
740454	737030	20098N	PARTICIPANT	\N	EXCUSE	0
740455	737030	19717B	PARTICIPANT	\N	PRESENT	1
740456	737030	14030Q	PRESIDENT	0	PRESENT	0
740466	737030	20148F	PARTICIPANT	\N	PRESENT	0
740471	737030	14147R	PARTICIPANT	\N	PRESENT	0
740507	737030	20034V	PARTICIPANT	\N	PRESENT	0
740515	737030	97011G	PARTICIPANT	\N	PRESENT	0
742838	740834	20086J	PARTICIPANT	\N	PRESENT	0
742845	740834	20070A	PARTICIPANT	\N	PRESENT	0
742846	740834	19647E	PARTICIPANT	\N	PRESENT	0
742847	740834	01057W	PARTICIPANT	\N	PRESENT	0
742849	740834	19531S	PARTICIPANT	\N	PRESENT	0
742850	740834	19711U	PARTICIPANT	\N	PRESENT	0
742852	740834	20252E	PARTICIPANT	\N	PRESENT	0
742853	740834	08011M	PARTICIPANT	\N	PRESENT	0
742854	740834	14331P	PARTICIPANT	\N	PRESENT	0
742855	740834	20150Y	PARTICIPANT	\N	PRESENT	0
742856	740834	19762G	PARTICIPANT	\N	PRESENT	0
744525	738365	19717B	PRESIDENT	0	PRESENT	0
744526	738365	14059S	PARTICIPANT	\N	PRESENT	0
744527	738365	14331P	PARTICIPANT	\N	PRESENT	0
744528	738365	19657G	PARTICIPANT	\N	PRESENT	0
744529	738365	08073C	PARTICIPANT	\N	PRESENT	0
744530	738365	19319Q	PARTICIPANT	\N	PRESENT	0
744531	738365	20146D	PARTICIPANT	\N	PRESENT	1
744532	738365	19301E	PARTICIPANT	\N	PRESENT	0
748056	746059	14331P	PRESIDENT	0	PRESENT	0
748057	746059	14001X	PARTICIPANT	\N	PRESENT	0
748058	746059	04057K	PARTICIPANT	\N	PRESENT	0
748059	746059	19725B	PARTICIPANT	\N	PRESENT	0
748060	746059	14237S	PARTICIPANT	\N	PRESENT	0
748061	746059	12041X	PARTICIPANT	\N	PRESENT	0
748062	746059	08034U	PARTICIPANT	\N	PRESENT	0
748063	746059	14133K	PARTICIPANT	\N	PRESENT	0
748067	746059	19441R	PARTICIPANT	\N	PRESENT	0
748068	746059	20098N	PARTICIPANT	\N	PRESENT	0
748069	746059	20100N	PARTICIPANT	\N	PRESENT	0
748070	746059	14097Y	PARTICIPANT	\N	PRESENT	0
748071	746059	04070G	PARTICIPANT	\N	PRESENT	0
749772	748445	19649G	PARTICIPANT	\N	PRESENT	0
748073	746059	11083R	PARTICIPANT	\N	PRESENT	0
748074	746059	20286Q	PARTICIPANT	\N	PRESENT	0
748075	746059	14169X	PARTICIPANT	\N	PRESENT	0
749802	748445	20022R	PARTICIPANT	\N	PRESENT	0
749803	748445	19543W	PARTICIPANT	\N	PRESENT	0
749804	748445	04085P	PARTICIPANT	\N	PRESENT	0
749805	748445	14215L	PARTICIPANT	\N	PRESENT	0
749806	748445	19673G	PARTICIPANT	\N	PRESENT	0
749807	748445	11010L	PARTICIPANT	\N	PRESENT	0
749808	748445	14231L	PARTICIPANT	\N	PRESENT	0
749809	748445	14179A	PARTICIPANT	\N	PRESENT	0
749810	748445	19447X	PARTICIPANT	\N	PRESENT	0
749812	748445	14021P	PARTICIPANT	\N	PRESENT	0
749813	748445	14111D	PARTICIPANT	\N	PRESENT	0
749815	748445	14147R	PARTICIPANT	\N	PRESENT	0
749816	748445	20074E	PARTICIPANT	\N	PRESENT	0
749823	748445	19301E	PARTICIPANT	\N	PRESENT	0
749870	748006	04047H	PRESIDENT	0	PRESENT	0
749871	748006	19673G	PARTICIPANT	\N	PRESENT	0
749872	748006	19749K	PARTICIPANT	\N	PRESENT	0
749874	748006	14215L	PRESIDENT	1	PRESENT	0
749875	748006	14231L	PARTICIPANT	\N	PRESENT	0
749876	748006	14053L	PARTICIPANT	\N	PRESENT	0
749877	748006	20022R	PARTICIPANT	\N	PRESENT	0
750835	750213	01048V	PARTICIPANT	\N	PRESENT	0
750836	750213	19533U	PARTICIPANT	\N	PRESENT	0
750837	750213	19503N	PARTICIPANT	\N	PRESENT	0
750840	750213	04043D	PARTICIPANT	\N	EXCUSE	0
750863	740812	14030Q	PARTICIPANT	\N	PRESENT	0
750864	740812	19673G	PARTICIPANT	\N	PRESENT	0
750865	740812	11083R	PARTICIPANT	\N	PRESENT	0
750866	740812	20056C	PARTICIPANT	\N	PRESENT	0
750867	740811	19673G	PARTICIPANT	\N	PRESENT	0
750868	740811	20056C	PARTICIPANT	\N	PRESENT	0
750869	740811	20066E	PARTICIPANT	\N	PRESENT	0
752174	752121	14030Q	PRESIDENT	0	PRESENT	0
752175	752121	20114U	PARTICIPANT	\N	PRESENT	0
752176	752121	11031D	PARTICIPANT	\N	PRESENT	0
752177	752121	04035D	PARTICIPANT	\N	PRESENT	0
752178	752121	19798U	PARTICIPANT	\N	PRESENT	0
752179	752121	11045K	PARTICIPANT	\N	PRESENT	0
752180	752121	19749K	PARTICIPANT	\N	PRESENT	0
752181	752121	17737W	PARTICIPANT	\N	PRESENT	0
752182	752121	14147R	PARTICIPANT	\N	PRESENT	0
752183	752121	11067R	PARTICIPANT	\N	PRESENT	0
752184	752121	14179A	PARTICIPANT	\N	PRESENT	0
752355	752211	19679N	PARTICIPANT	\N	PRESENT	0
754794	753747	20040T	PARTICIPANT	\N	PRESENT	0
761724	761723	20120S	PARTICIPANT	\N	PRESENT	0
759281	757735	21044C	PARTICIPANT	\N	PRESENT	0
759282	757735	21043B	PARTICIPANT	\N	PRESENT	0
759283	757735	19725B	PARTICIPANT	\N	PRESENT	0
759284	757735	19749K	PARTICIPANT	\N	PRESENT	0
764565	764243	19631V	PARTICIPANT	\N	EXCUSE	0
764566	764243	12016W	PARTICIPANT	\N	PRESENT	0
759287	757735	14053L	PARTICIPANT	\N	PRESENT	0
764567	764243	19331L	PARTICIPANT	\N	PRESENT	0
759289	757735	21095P	PARTICIPANT	\N	PRESENT	0
759290	757735	21040X	PARTICIPANT	\N	PRESENT	0
764568	764243	21055F	PARTICIPANT	\N	PRESENT	0
759292	757735	19649G	PARTICIPANT	\N	PRESENT	0
764569	764243	19691J	PARTICIPANT	\N	PRESENT	0
764570	764243	14053L	PARTICIPANT	\N	PRESENT	0
764571	764243	08073C	PARTICIPANT	\N	PRESENT	0
764634	764243	21071F	PARTICIPANT	\N	PRESENT	0
764637	764243	05008E	PARTICIPANT	\N	PRESENT	0
764638	764243	04042C	PARTICIPANT	\N	PRESENT	0
764647	764243	21034A	PARTICIPANT	\N	PRESENT	0
759300	757735	20074E	PARTICIPANT	\N	PRESENT	0
759301	757735	20098N	PARTICIPANT	\N	PRESENT	0
759302	757735	14231L	PARTICIPANT	\N	PRESENT	0
759303	757735	14069U	PARTICIPANT	\N	PRESENT	0
759304	757735	14259Y	PARTICIPANT	\N	PRESENT	0
759305	757735	18207D	PARTICIPANT	\N	PRESENT	0
759306	757735	20114U	PARTICIPANT	\N	PRESENT	0
764648	764243	14259Y	PARTICIPANT	\N	PRESENT	0
764650	764243	17229F	PARTICIPANT	\N	PRESENT	0
759309	757735	14147R	PARTICIPANT	\N	PRESENT	0
764652	764243	19673G	PARTICIPANT	\N	PRESENT	0
759311	757735	08018U	PARTICIPANT	\N	PRESENT	0
759312	757735	14215L	PARTICIPANT	\N	PRESENT	0
764654	764243	20034V	PARTICIPANT	\N	PRESENT	0
759314	757735	19489J	PARTICIPANT	\N	PRESENT	0
764656	764243	14121F	PARTICIPANT	\N	PRESENT	0
764657	764243	08010L	PARTICIPANT	\N	PRESENT	0
759317	757735	04047H	PRESIDENT	0	PRESENT	0
764660	764243	14059S	PARTICIPANT	\N	PRESENT	0
759319	757735	18231D	PARTICIPANT	\N	PRESENT	0
759320	757735	20108W	PARTICIPANT	\N	PRESENT	0
759321	757735	21056G	PARTICIPANT	\N	PRESENT	0
764661	764243	21073H	PARTICIPANT	\N	PRESENT	0
764664	764243	20148F	PARTICIPANT	\N	PRESENT	0
764666	764243	20146D	PARTICIPANT	\N	PRESENT	0
764667	764243	20150Y	PARTICIPANT	\N	PRESENT	0
764683	764243	19669L	PARTICIPANT	\N	PRESENT	0
764730	764243	20016T	PARTICIPANT	\N	PRESENT	0
764774	764243	21096Q	PARTICIPANT	\N	PRESENT	0
764775	764243	21097R	PARTICIPANT	\N	PRESENT	0
764814	764243	21033Y	PARTICIPANT	\N	EXCUSE	0
758272	757795	19723Y	PARTICIPANT	\N	PRESENT	0
758273	757795	20116W	PARTICIPANT	\N	PRESENT	0
758274	757795	21040X	PARTICIPANT	\N	PRESENT	0
758275	757795	07004J	PARTICIPANT	\N	PRESENT	0
758276	757795	14133K	PARTICIPANT	\N	PRESENT	0
758277	757795	21049H	PARTICIPANT	\N	PRESENT	0
758278	757795	21072G	PARTICIPANT	\N	PRESENT	0
758279	757795	20032T	PARTICIPANT	\N	PRESENT	0
758280	757795	21053D	PARTICIPANT	\N	PRESENT	0
758281	757795	20090E	PARTICIPANT	\N	PRESENT	0
758282	757795	14107H	PARTICIPANT	\N	PRESENT	0
758283	757795	08061X	PARTICIPANT	\N	PRESENT	0
758284	757795	20128B	PARTICIPANT	\N	PRESENT	0
758285	757795	14042U	PARTICIPANT	\N	PRESENT	0
758286	757795	20122U	PARTICIPANT	\N	PRESENT	0
758287	757795	11045K	PARTICIPANT	\N	PRESENT	0
758288	757795	11072N	PARTICIPANT	\N	PRESENT	0
758289	757795	19507S	PARTICIPANT	\N	PRESENT	0
758293	757795	20044X	PARTICIPANT	\N	PRESENT	0
758291	757795	04092N	PARTICIPANT	\N	PRESENT	0
758292	757795	04045F	PARTICIPANT	\N	PRESENT	0
758294	757795	14219Q	PARTICIPANT	\N	PRESENT	0
758295	757795	19703U	PARTICIPANT	\N	PRESENT	0
758300	757795	19347U	PARTICIPANT	\N	PRESENT	0
758301	757795	19782L	PARTICIPANT	\N	PRESENT	0
758302	757795	19711U	PARTICIPANT	\N	PRESENT	0
758303	757795	14109K	PARTICIPANT	\N	PRESENT	0
758304	757795	21083K	PARTICIPANT	\N	PRESENT	0
758305	757795	19725B	PARTICIPANT	\N	PRESENT	0
758306	757795	14221J	PARTICIPANT	\N	PRESENT	0
758310	757795	20038A	PARTICIPANT	\N	PRESENT	0
758308	757795	21059K	PARTICIPANT	\N	PRESENT	0
758309	757795	14001X	PARTICIPANT	\N	PRESENT	0
758311	757795	14083S	PARTICIPANT	\N	PRESENT	0
758312	757795	14281W	PARTICIPANT	\N	PRESENT	0
758313	757795	19331L	PARTICIPANT	\N	PRESENT	0
758314	757795	19479G	PARTICIPANT	\N	PRESENT	0
758315	757795	21057H	PARTICIPANT	\N	PRESENT	0
758316	757795	14026U	PARTICIPANT	\N	PRESENT	0
758317	757795	21066J	PARTICIPANT	\N	PRESENT	0
758318	757795	18083K	PARTICIPANT	\N	PRESENT	0
758319	757795	21065H	PARTICIPANT	\N	PRESENT	0
758320	757795	21054E	PARTICIPANT	\N	PRESENT	0
758321	757795	19826F	PARTICIPANT	\N	PRESENT	0
758322	757795	21074J	PARTICIPANT	\N	PRESENT	0
758323	757795	19768N	PARTICIPANT	\N	PRESENT	0
758324	757795	08045X	PARTICIPANT	\N	PRESENT	0
758325	757795	20018V	PARTICIPANT	\N	PRESENT	0
758326	757795	14205J	PARTICIPANT	\N	PRESENT	0
758327	757795	14031R	PARTICIPANT	\N	PRESENT	0
758328	757795	18395Y	PARTICIPANT	\N	PRESENT	0
758329	757795	08060W	PARTICIPANT	\N	PRESENT	0
758330	757795	21045D	PARTICIPANT	\N	PRESENT	0
758331	757795	18207D	PARTICIPANT	\N	PRESENT	0
758332	757795	20052X	PARTICIPANT	\N	PRESENT	0
758333	757795	14231L	PARTICIPANT	\N	PRESENT	0
758336	757795	14257W	PARTICIPANT	\N	PRESENT	0
758337	757795	20056C	PARTICIPANT	\N	PRESENT	0
758338	757795	21089R	PARTICIPANT	\N	PRESENT	0
758339	757795	21077M	PARTICIPANT	\N	PRESENT	0
758340	757795	21056G	PARTICIPANT	\N	PRESENT	0
758341	757795	14259Y	PARTICIPANT	\N	PRESENT	0
758342	757795	21035B	PARTICIPANT	\N	PRESENT	0
758343	757795	20082E	PARTICIPANT	\N	PRESENT	0
758346	757795	21062E	PARTICIPANT	\N	PRESENT	0
758347	757795	18231D	PARTICIPANT	\N	PRESENT	0
758348	757795	14121F	PARTICIPANT	\N	PRESENT	0
758349	757795	19701S	PARTICIPANT	\N	PRESENT	0
758350	757795	20106U	PARTICIPANT	\N	PRESENT	0
758351	757795	19649G	PARTICIPANT	\N	PRESENT	0
758352	757795	21041Y	PARTICIPANT	\N	PRESENT	0
758353	757795	20108W	PARTICIPANT	\N	PRESENT	0
758357	757795	20026V	PARTICIPANT	\N	PRESENT	0
758358	757795	20068G	PARTICIPANT	\N	PRESENT	0
758359	757795	20024T	PARTICIPANT	\N	PRESENT	0
758360	757795	21079P	PARTICIPANT	\N	PRESENT	0
758361	757795	20074E	PARTICIPANT	\N	PRESENT	0
758362	757795	20092G	PARTICIPANT	\N	PRESENT	0
758363	757795	08034U	PARTICIPANT	\N	PRESENT	0
758364	757795	21092L	PARTICIPANT	\N	PRESENT	0
758365	757795	21061D	PARTICIPANT	\N	PRESENT	0
758366	757795	20098N	PARTICIPANT	\N	PRESENT	0
758367	757795	20054A	PARTICIPANT	\N	PRESENT	0
758368	757795	08018U	PARTICIPANT	\N	PRESENT	0
758369	757795	14215L	PARTICIPANT	\N	PRESENT	0
758370	757795	20084G	PARTICIPANT	\N	PRESENT	0
758371	757795	20070A	PARTICIPANT	\N	PRESENT	0
758372	757795	21063F	PARTICIPANT	\N	PRESENT	0
758374	757795	20088L	PARTICIPANT	\N	PRESENT	0
758376	757795	20100N	PARTICIPANT	\N	PRESENT	0
758377	757795	19631V	PARTICIPANT	\N	PRESENT	0
758378	757795	21095P	PARTICIPANT	\N	PRESENT	0
758379	757795	21090J	PARTICIPANT	\N	PRESENT	0
758380	757795	20094J	PARTICIPANT	\N	PRESENT	0
758381	757795	14229S	PARTICIPANT	\N	PRESENT	0
758382	757795	20104S	PARTICIPANT	\N	PRESENT	0
758383	757795	14021P	PARTICIPANT	\N	PRESENT	0
758384	757795	14173T	PARTICIPANT	\N	PRESENT	0
758385	757795	20124W	PARTICIPANT	\N	PRESENT	0
758386	757795	20264J	PARTICIPANT	\N	PRESENT	0
758387	757795	08015R	PARTICIPANT	\N	PRESENT	0
758388	757795	21080G	PARTICIPANT	\N	PRESENT	0
758389	757795	14033T	PARTICIPANT	\N	PRESENT	0
758390	757795	20028X	PARTICIPANT	\N	PRESENT	0
758492	757797	86034E	PARTICIPANT	\N	PRESENT	0
758493	757797	20100N	PARTICIPANT	\N	PRESENT	0
758494	757797	20130U	PARTICIPANT	\N	PRESENT	0
758495	757797	21079P	PARTICIPANT	\N	PRESENT	0
758496	757797	14195A	PARTICIPANT	\N	PRESENT	0
758497	757797	14249W	PARTICIPANT	\N	PRESENT	0
758498	757797	19697Q	PARTICIPANT	\N	PRESENT	0
758499	757797	21066J	PARTICIPANT	\N	PRESENT	0
758500	757797	08061X	PARTICIPANT	\N	PRESENT	0
758501	757797	21097R	PARTICIPANT	\N	PRESENT	0
758502	757797	21088Q	PARTICIPANT	\N	PRESENT	0
758503	757797	20102Q	PARTICIPANT	\N	PRESENT	0
758504	757797	19347U	PARTICIPANT	\N	PRESENT	0
758505	757797	21093M	PARTICIPANT	\N	PRESENT	0
758506	757797	21043B	PARTICIPANT	\N	PRESENT	0
758507	757797	11072N	PARTICIPANT	\N	PRESENT	0
758508	757797	21087P	PARTICIPANT	\N	PRESENT	0
758509	757797	20050V	PARTICIPANT	\N	PRESENT	0
758510	757797	21054E	PARTICIPANT	\N	PRESENT	0
758511	757797	14251Q	PARTICIPANT	\N	PRESENT	0
758512	757797	19866P	PARTICIPANT	\N	PRESENT	0
758513	757797	20132W	PARTICIPANT	\N	PRESENT	0
758514	757797	21041Y	PARTICIPANT	\N	PRESENT	0
758515	757797	98022P	PARTICIPANT	\N	PRESENT	0
758516	757797	14207L	PARTICIPANT	\N	PRESENT	0
758517	757797	19629C	PARTICIPANT	\N	PRESENT	0
758518	757797	14107H	PARTICIPANT	\N	PRESENT	0
758519	757797	21040X	PARTICIPANT	\N	PRESENT	0
758520	757797	19553Y	PARTICIPANT	\N	PRESENT	0
758521	757797	21074J	PARTICIPANT	\N	PRESENT	0
758522	757797	21092L	PARTICIPANT	\N	PRESENT	0
758523	757797	21035B	PARTICIPANT	\N	PRESENT	0
758524	757797	20094J	PARTICIPANT	\N	PRESENT	0
758525	757797	08060W	PARTICIPANT	\N	PRESENT	0
758526	757797	20088L	PARTICIPANT	\N	PRESENT	0
758527	757797	21089R	PARTICIPANT	\N	PRESENT	0
758528	757797	21057H	PARTICIPANT	\N	PRESENT	0
758529	757797	20264J	PARTICIPANT	\N	PRESENT	0
758530	757797	21067K	PARTICIPANT	\N	PRESENT	0
758531	757797	18395Y	PARTICIPANT	\N	PRESENT	0
758532	757797	21062E	PARTICIPANT	\N	PRESENT	0
758533	757797	19647E	PARTICIPANT	\N	PRESENT	0
758534	757797	14281W	PARTICIPANT	\N	PRESENT	0
758535	757797	19820Y	PARTICIPANT	\N	PRESENT	0
758536	757797	20266L	PARTICIPANT	\N	PRESENT	0
758537	757797	19683J	PARTICIPANT	\N	PRESENT	0
758538	757797	14021P	PARTICIPANT	\N	PRESENT	0
758539	757797	19489J	PARTICIPANT	\N	PRESENT	0
758540	757797	19649G	PARTICIPANT	\N	PRESENT	0
758541	757797	18193Q	PARTICIPANT	\N	PRESENT	0
758542	757797	17779H	PARTICIPANT	\N	PRESENT	0
758543	757797	20028X	PARTICIPANT	\N	PRESENT	0
758544	757797	20018V	PARTICIPANT	\N	PRESENT	0
758545	757797	14257W	PARTICIPANT	\N	PRESENT	0
758546	757797	14225N	PARTICIPANT	\N	PRESENT	0
758547	757797	20082E	PARTICIPANT	\N	PRESENT	0
758548	757797	19758L	PARTICIPANT	\N	PRESENT	0
740076	738364	20080C	PARTICIPANT	\N	PRESENT	0
740077	738008	95063L	PARTICIPANT	\N	PRESENT	0
740078	738008	19713W	PARTICIPANT	\N	PRESENT	0
740079	738008	20114U	PARTICIPANT	\N	PRESENT	0
740080	738008	19583F	PARTICIPANT	\N	PRESENT	0
740081	738008	14187A	PARTICIPANT	\N	PRESENT	0
740099	738008	19782L	PARTICIPANT	\N	PRESENT	0
740083	738008	17737W	PARTICIPANT	\N	PRESENT	0
740084	738008	19507S	PARTICIPANT	\N	PRESENT	0
740085	738008	19515S	PARTICIPANT	\N	PRESENT	0
740086	738008	19057M	PARTICIPANT	\N	PRESENT	0
740087	738364	20086J	PARTICIPANT	\N	PRESENT	0
740088	738364	11048N	PARTICIPANT	\N	PRESENT	0
740089	738364	14225N	PRESIDENT	0	PRESENT	0
740092	738008	20092G	PARTICIPANT	\N	PRESENT	0
740093	738008	04057K	PARTICIPANT	\N	PRESENT	0
740094	738008	14207L	PARTICIPANT	\N	PRESENT	0
740095	738008	11077T	PARTICIPANT	\N	PRESENT	0
740096	738008	11090Q	PARTICIPANT	\N	PRESENT	0
740097	738008	14215L	PARTICIPANT	\N	PRESENT	0
740098	738008	14069U	PARTICIPANT	\N	PRESENT	0
740100	738364	07029T	PARTICIPANT	\N	PRESENT	0
740101	738364	19479G	PARTICIPANT	\N	PRESENT	0
740102	738364	20070A	PARTICIPANT	\N	PRESENT	0
740103	738008	19631V	PARTICIPANT	\N	PRESENT	0
740104	738008	20018V	PARTICIPANT	\N	PRESENT	0
740105	738008	14205J	PARTICIPANT	\N	PRESENT	0
740106	738008	20124W	PARTICIPANT	\N	PRESENT	0
740107	738008	14147R	PARTICIPANT	\N	PRESENT	0
740108	738008	20032T	PARTICIPANT	\N	PRESENT	0
740109	738008	11053K	PARTICIPANT	\N	PRESENT	0
740111	738008	01043Q	PARTICIPANT	\N	PRESENT	0
740112	738364	20252E	PARTICIPANT	\N	PRESENT	0
740113	738008	20298U	PARTICIPANT	\N	PRESENT	0
740114	738008	19251M	PARTICIPANT	\N	PRESENT	0
740116	738008	14089Y	PARTICIPANT	\N	PRESENT	0
740117	738008	11045K	PARTICIPANT	\N	PRESENT	0
740119	740118	14038Y	PARTICIPANT	\N	PRESENT	0
740120	740118	04070G	PRESIDENT	0	PRESENT	0
740121	740118	19768N	PARTICIPANT	\N	PRESENT	0
740122	740118	20034V	PARTICIPANT	\N	PRESENT	0
740123	740118	14179A	PARTICIPANT	\N	PRESENT	0
740124	740118	14030Q	PARTICIPANT	\N	PRESENT	0
740125	740118	20094J	PARTICIPANT	\N	PRESENT	0
740129	738008	19747H	PARTICIPANT	\N	PRESENT	0
740132	738008	19581D	PARTICIPANT	\N	PRESENT	0
740133	738008	19489J	PARTICIPANT	\N	PRESENT	0
740134	740118	19593H	PARTICIPANT	\N	PRESENT	0
740135	740118	20132W	PARTICIPANT	\N	PRESENT	0
740136	740118	20052X	PARTICIPANT	\N	PRESENT	0
740137	740118	19591F	PARTICIPANT	\N	PRESENT	0
740138	740118	11045K	PARTICIPANT	\N	PRESENT	0
740140	738008	14237S	PARTICIPANT	\N	PRESENT	0
740142	738364	19741B	PARTICIPANT	\N	PRESENT	0
740143	738364	20126Y	PARTICIPANT	\N	PRESENT	0
740144	738364	19349W	PARTICIPANT	\N	PRESENT	0
740145	738008	20060X	PARTICIPANT	\N	PRESENT	0
740146	738008	19369B	PARTICIPANT	\N	PRESENT	0
740147	738008	19447X	PARTICIPANT	\N	PRESENT	0
740148	738008	19533U	PARTICIPANT	\N	PRESENT	0
740149	738008	20048C	PARTICIPANT	\N	PRESENT	0
740150	738008	20102Q	PARTICIPANT	\N	PRESENT	0
740151	738008	19798U	PARTICIPANT	\N	PRESENT	0
740152	738008	14257W	PARTICIPANT	\N	PRESENT	0
740153	740118	20138D	PARTICIPANT	\N	PRESENT	0
740154	740118	20140W	PARTICIPANT	\N	PRESENT	0
740155	740118	20062A	PARTICIPANT	\N	PRESENT	0
740156	740118	14147R	PARTICIPANT	\N	PRESENT	0
740157	740118	20022R	PARTICIPANT	\N	PRESENT	0
740158	738008	14107H	PARTICIPANT	\N	PRESENT	0
740512	736293	20048C	PARTICIPANT	\N	PRESENT	0
740513	736293	11109J	PARTICIPANT	\N	EXCUSE	0
740514	736293	19735D	PARTICIPANT	\N	EXCUSE	0
741139	741138	19701S	PARTICIPANT	\N	PRESENT	0
741140	741138	11026G	PARTICIPANT	\N	PRESENT	0
741141	741138	19699S	PARTICIPANT	\N	PRESENT	0
741142	741138	19671E	PARTICIPANT	\N	PRESENT	0
741143	741138	20064C	PARTICIPANT	\N	PRESENT	0
741145	741144	19593H	PARTICIPANT	\N	PRESENT	0
741146	741144	19251M	PARTICIPANT	\N	PRESENT	0
741147	741144	14147R	PARTICIPANT	\N	PRESENT	0
741148	741144	20084G	PARTICIPANT	\N	PRESENT	0
749391	749387	05008E	PARTICIPANT	\N	PRESENT	0
749392	749387	11053K	PARTICIPANT	\N	PRESENT	0
749393	749387	01028R	PARTICIPANT	\N	PRESENT	0
752248	752221	19593H	PARTICIPANT	\N	PRESENT	0
752250	752221	01058X	PARTICIPANT	\N	PRESENT	0
753390	753249	21033Y	PARTICIPANT	\N	PRESENT	0
753391	753249	21034A	PARTICIPANT	\N	PRESENT	0
753392	753249	14205J	PARTICIPANT	\N	PRESENT	0
753393	753249	20060X	PARTICIPANT	\N	PRESENT	0
753394	753249	20066E	PARTICIPANT	\N	PRESENT	0
753395	753249	21066J	PARTICIPANT	\N	PRESENT	0
753396	753249	20286Q	PARTICIPANT	\N	PRESENT	0
753397	753249	14207L	PARTICIPANT	\N	PRESENT	0
753398	753249	14257W	PARTICIPANT	\N	PRESENT	0
753399	753249	20084G	PARTICIPANT	\N	PRESENT	0
753449	753253	19697Q	PARTICIPANT	\N	PRESENT	0
753450	753253	04070G	PARTICIPANT	\N	PRESENT	0
753451	753253	19699S	PARTICIPANT	\N	PRESENT	0
753452	753253	19533U	PARTICIPANT	\N	PRESENT	0
753453	753253	04033B	PARTICIPANT	\N	PRESENT	0
753454	753253	21058J	PARTICIPANT	\N	PRESENT	0
753455	753253	21059K	PARTICIPANT	\N	PRESENT	0
753456	753253	20102Q	PARTICIPANT	\N	PRESENT	0
753457	753253	14229S	PARTICIPANT	\N	PRESENT	0
753458	753253	19954N	PARTICIPANT	\N	PRESENT	0
753459	753253	21032X	PARTICIPANT	\N	PRESENT	0
753460	753253	18395Y	PARTICIPANT	\N	PRESENT	0
753461	753253	20112S	PARTICIPANT	\N	PRESENT	0
753462	753253	21089R	PARTICIPANT	\N	PRESENT	0
753463	753253	21037D	PARTICIPANT	\N	PRESENT	0
753464	753253	08012N	PARTICIPANT	\N	PRESENT	0
753465	753253	20016T	PARTICIPANT	\N	PRESENT	0
753466	753253	21091K	PARTICIPANT	\N	PRESENT	0
753467	753253	20124W	PARTICIPANT	\N	PRESENT	0
753468	753253	20026V	PARTICIPANT	\N	PRESENT	0
753469	753253	19593H	PARTICIPANT	\N	PRESENT	0
753470	753253	20132W	PARTICIPANT	\N	PRESENT	0
753471	753253	21055F	PARTICIPANT	\N	PRESENT	0
753472	753253	20122U	PARTICIPANT	\N	PRESENT	0
753473	753253	14073Q	PARTICIPANT	\N	PRESENT	0
753474	753253	19611R	PARTICIPANT	\N	PRESENT	0
753475	753253	20138D	PARTICIPANT	\N	PRESENT	0
753476	753253	20142Y	PARTICIPANT	\N	PRESENT	0
753477	753253	20048C	PARTICIPANT	\N	PRESENT	0
753478	753253	19693L	PARTICIPANT	\N	PRESENT	0
753479	753253	20052X	PARTICIPANT	\N	PRESENT	0
753480	753253	20172F	PARTICIPANT	\N	PRESENT	0
753481	753253	14030Q	PARTICIPANT	\N	PRESENT	0
753482	753253	20058E	PARTICIPANT	\N	PRESENT	0
753483	753253	20056C	PARTICIPANT	\N	PRESENT	0
753484	753253	20180F	PARTICIPANT	\N	PRESENT	0
753485	753253	20264J	PARTICIPANT	\N	PRESENT	0
753486	753253	21063F	PARTICIPANT	\N	PRESENT	0
753487	753253	19735D	PARTICIPANT	\N	PRESENT	0
753488	753253	19057M	PARTICIPANT	\N	PRESENT	0
753489	753253	14109K	PARTICIPANT	\N	PRESENT	0
753490	753253	14123H	PARTICIPANT	\N	PRESENT	0
753491	753253	11043H	PARTICIPANT	\N	PRESENT	0
753492	753253	21074J	PARTICIPANT	\N	PRESENT	0
753493	753253	21077M	PARTICIPANT	\N	PRESENT	0
753494	753253	21078N	PARTICIPANT	\N	PRESENT	0
753495	753253	14021P	PARTICIPANT	\N	PRESENT	0
753496	753253	19621T	PARTICIPANT	\N	PRESENT	0
753544	753497	21082J	PARTICIPANT	\N	PRESENT	0
753545	753497	14331P	PRESIDENT	0	PRESENT	0
753546	753497	04070G	PARTICIPANT	\N	PRESENT	0
753547	753497	19701S	PARTICIPANT	\N	PRESENT	0
753548	753497	14357A	PARTICIPANT	\N	PRESENT	0
753549	753497	19569H	PARTICIPANT	\N	PRESENT	0
753550	753497	14001X	PARTICIPANT	\N	PRESENT	0
753551	753497	20094J	PARTICIPANT	\N	PRESENT	0
753552	753497	14026U	PARTICIPANT	\N	PRESENT	0
753553	753497	20104S	PARTICIPANT	\N	PRESENT	0
753554	753497	20098N	PARTICIPANT	\N	PRESENT	0
753555	753497	14237S	PARTICIPANT	\N	PRESENT	0
753556	753497	20100N	PARTICIPANT	\N	PRESENT	0
746820	744790	19745F	PARTICIPANT	\N	PRESENT	0
746900	746025	20068G	PARTICIPANT	\N	PRESENT	0
746901	746025	98022P	PARTICIPANT	\N	PRESENT	0
746902	746025	01025N	PARTICIPANT	\N	PRESENT	0
746903	746025	19507S	PARTICIPANT	\N	PRESENT	0
746904	746025	19565D	PARTICIPANT	\N	PRESENT	0
746905	746025	20146D	PARTICIPANT	\N	PRESENT	0
746906	746025	11077T	PARTICIPANT	\N	PRESENT	0
746907	746025	20024T	PARTICIPANT	\N	PRESENT	0
746908	746025	19581D	PARTICIPANT	\N	PRESENT	0
746909	746025	20148F	PARTICIPANT	\N	PRESENT	0
746910	746025	19349W	PARTICIPANT	\N	PRESENT	0
746911	746025	19413M	PARTICIPANT	\N	PRESENT	0
746912	746025	20090E	PARTICIPANT	\N	PRESENT	0
746913	746025	20056C	PARTICIPANT	\N	PRESENT	0
746914	746025	20062A	PARTICIPANT	\N	PRESENT	0
746919	746025	19543W	PARTICIPANT	\N	PRESENT	0
746920	746025	08028W	PARTICIPANT	\N	PRESENT	0
746921	746025	20074E	PARTICIPANT	\N	PRESENT	0
746922	746025	19687N	PARTICIPANT	\N	PRESENT	0
746923	746025	14111D	PARTICIPANT	\N	PRESENT	0
746924	746025	20028X	PARTICIPANT	\N	PRESENT	0
746925	746025	11040E	PARTICIPANT	\N	PRESENT	0
746926	746025	20102Q	PARTICIPANT	\N	PRESENT	0
746927	746025	20086J	PARTICIPANT	\N	PRESENT	0
746928	746025	20026V	PARTICIPANT	\N	PRESENT	0
746929	746025	14033T	PARTICIPANT	\N	PRESENT	0
746930	746025	20116W	PARTICIPANT	\N	PRESENT	0
746931	746025	19421M	PARTICIPANT	\N	PRESENT	0
746932	746025	20088L	PARTICIPANT	\N	PRESENT	0
746933	746025	08056B	PARTICIPANT	\N	PRESENT	0
746934	746025	20128B	PARTICIPANT	\N	PRESENT	0
746935	746025	14259Y	PARTICIPANT	\N	PRESENT	0
746936	746025	18083K	PARTICIPANT	\N	PRESENT	0
746937	746025	04045F	PARTICIPANT	\N	PRESENT	0
746938	746025	14059S	PARTICIPANT	\N	PRESENT	0
746939	746025	11043H	PARTICIPANT	\N	PRESENT	0
746940	746025	14123H	PARTICIPANT	\N	PRESENT	0
746941	746025	14219Q	PARTICIPANT	\N	PRESENT	0
746942	746025	19826F	PARTICIPANT	\N	PRESENT	0
746943	746025	19611R	PARTICIPANT	\N	PRESENT	0
746944	746025	14223L	PARTICIPANT	\N	PRESENT	0
746945	746025	14109K	PARTICIPANT	\N	PRESENT	0
746946	746025	20082E	PARTICIPANT	\N	PRESENT	0
746947	746025	19701S	PARTICIPANT	\N	PRESENT	0
746948	746025	19699S	PARTICIPANT	\N	PRESENT	0
746949	746025	14151M	PARTICIPANT	\N	PRESENT	0
746950	746025	20084G	PARTICIPANT	\N	PRESENT	0
746951	746025	19515S	PARTICIPANT	\N	PRESENT	0
746952	746025	20048C	PARTICIPANT	\N	PRESENT	0
746953	746025	19745F	PARTICIPANT	\N	PRESENT	0
746954	746025	19369B	PARTICIPANT	\N	PRESENT	0
746955	746025	19739H	PARTICIPANT	\N	PRESENT	0
746956	746025	19319Q	PARTICIPANT	\N	PRESENT	0
746957	746025	20144B	PARTICIPANT	\N	PRESENT	0
746958	746025	19691J	PARTICIPANT	\N	PRESENT	0
746960	746025	11085T	PARTICIPANT	\N	PRESENT	0
746961	746025	19479G	PARTICIPANT	\N	PRESENT	0
746962	746025	14205J	PARTICIPANT	\N	PRESENT	0
746963	746025	19681G	PARTICIPANT	\N	PRESENT	0
746964	746025	14107H	PARTICIPANT	\N	PRESENT	0
746965	746025	19866P	PARTICIPANT	\N	PRESENT	0
746966	746025	19629C	PARTICIPANT	\N	PRESENT	0
746967	746025	19719D	PARTICIPANT	\N	PRESENT	0
746968	746025	20134Y	PARTICIPANT	\N	PRESENT	0
746969	746025	20142Y	PARTICIPANT	\N	PRESENT	0
746970	746025	11045K	PARTICIPANT	\N	PRESENT	0
746971	746025	11066Q	PARTICIPANT	\N	PRESENT	0
746972	746025	11104D	PARTICIPANT	\N	PRESENT	0
746973	746025	19760E	PARTICIPANT	\N	PRESENT	0
746974	746025	04085P	PARTICIPANT	\N	PRESENT	0
746975	746025	19758L	PARTICIPANT	\N	PRESENT	0
746976	746025	19695N	PARTICIPANT	\N	PRESENT	0
746977	746025	12041X	PARTICIPANT	\N	PRESENT	0
746978	746025	19593H	PARTICIPANT	\N	PRESENT	0
746979	746025	20046A	PARTICIPANT	\N	PRESENT	0
746980	746025	20914V	PARTICIPANT	\N	PRESENT	0
746981	746025	19621T	PARTICIPANT	\N	PRESENT	0
746982	746025	19347U	PARTICIPANT	\N	PRESENT	0
746983	746025	20100N	PARTICIPANT	\N	PRESENT	0
746984	746025	11099A	PARTICIPANT	\N	PRESENT	0
746985	746025	20092G	PARTICIPANT	\N	PRESENT	0
746986	746025	20266L	PARTICIPANT	\N	PRESENT	0
746987	746025	20130U	PARTICIPANT	\N	PRESENT	0
746988	746025	19651A	PARTICIPANT	\N	PRESENT	0
746989	746025	19782L	PARTICIPANT	\N	PRESENT	0
746990	746025	19525U	PARTICIPANT	\N	PRESENT	0
746991	746025	14249W	PARTICIPANT	\N	PRESENT	0
746992	746025	20106U	PARTICIPANT	\N	PRESENT	0
746993	746025	19591F	PARTICIPANT	\N	PRESENT	0
746994	746025	14037X	PARTICIPANT	\N	PRESENT	0
746995	746025	19637C	PARTICIPANT	\N	PRESENT	0
746996	746025	11072N	PARTICIPANT	\N	PRESENT	0
746997	746025	08061X	PARTICIPANT	\N	PRESENT	0
746998	746025	11065P	PARTICIPANT	\N	PRESENT	0
746999	746025	14038Y	PARTICIPANT	\N	PRESENT	0
747000	746025	14055N	PARTICIPANT	\N	PRESENT	0
747001	746025	20034V	PARTICIPANT	\N	PRESENT	0
747002	746025	14207L	PARTICIPANT	\N	PRESENT	0
747003	746025	17367Q	PARTICIPANT	\N	PRESENT	0
747004	746025	20132W	PARTICIPANT	\N	PRESENT	0
747005	746025	19663E	PARTICIPANT	\N	PRESENT	0
747006	746025	19467C	PARTICIPANT	\N	PRESENT	0
747007	746025	19553Y	PARTICIPANT	\N	PRESENT	0
747008	746025	11012A	PARTICIPANT	\N	PRESENT	0
747009	746025	19573D	PARTICIPANT	\N	PRESENT	0
747010	746025	20072C	PARTICIPANT	\N	PRESENT	0
747011	746025	14071N	PARTICIPANT	\N	PRESENT	0
747012	746025	20098N	PARTICIPANT	\N	PRESENT	0
747013	746025	14195A	PARTICIPANT	\N	PRESENT	0
747014	746025	20980G	PARTICIPANT	\N	PRESENT	0
747015	746025	08018U	PARTICIPANT	\N	PRESENT	0
747016	746025	11083R	PARTICIPANT	\N	PRESENT	0
747017	746025	11064N	PARTICIPANT	\N	PRESENT	0
747018	746025	11048N	PARTICIPANT	\N	PRESENT	0
747019	746025	20038A	PARTICIPANT	\N	PRESENT	0
747020	746025	19545Y	PARTICIPANT	\N	PRESENT	0
747021	746025	07029T	PARTICIPANT	\N	PRESENT	0
747022	746025	08015R	PARTICIPANT	\N	PRESENT	0
747023	746025	14069U	PARTICIPANT	\N	PRESENT	0
747024	746025	20104S	PARTICIPANT	\N	PRESENT	0
747025	746025	14213J	PARTICIPANT	\N	PRESENT	0
747026	746025	19768N	PARTICIPANT	\N	PRESENT	0
747027	746025	11115U	PARTICIPANT	\N	PRESENT	0
747028	746025	20140W	PARTICIPANT	\N	PRESENT	0
747029	746025	19667J	PARTICIPANT	\N	PRESENT	0
747030	746025	19585H	PARTICIPANT	\N	PRESENT	0
747031	746025	20050V	PARTICIPANT	\N	PRESENT	0
747032	746025	19563B	PARTICIPANT	\N	PRESENT	0
747033	746025	19741B	PARTICIPANT	\N	PRESENT	0
747034	746025	04057K	PARTICIPANT	\N	PRESENT	0
747035	746025	19643A	PARTICIPANT	\N	PRESENT	0
747036	746025	19631V	PARTICIPANT	\N	PRESENT	0
747037	746025	19766L	PARTICIPANT	\N	PRESENT	0
747038	746025	04059M	PARTICIPANT	\N	PRESENT	0
747039	746025	20096L	PARTICIPANT	\N	PRESENT	0
747040	746025	19549D	PARTICIPANT	\N	PRESENT	0
747041	746025	01057W	PARTICIPANT	\N	PRESENT	0
747042	746025	08060W	PARTICIPANT	\N	PRESENT	0
747043	746025	04033B	PARTICIPANT	\N	PRESENT	0
747044	746025	05012A	PARTICIPANT	\N	PRESENT	0
747045	746025	14030Q	PARTICIPANT	\N	PRESENT	0
747046	746025	04071H	PARTICIPANT	\N	PRESENT	0
747047	746025	20114U	PARTICIPANT	\N	PRESENT	0
747048	746025	08069G	PARTICIPANT	\N	PRESENT	0
747049	746025	12028B	PARTICIPANT	\N	PRESENT	0
747050	746025	20076G	PARTICIPANT	\N	PRESENT	0
747051	746025	11027H	PARTICIPANT	\N	PRESENT	0
747052	746025	19679N	PARTICIPANT	\N	PRESENT	0
747053	746025	20070A	PARTICIPANT	\N	PRESENT	0
747054	746025	20080C	PARTICIPANT	\N	PRESENT	0
747055	746025	20264J	PARTICIPANT	\N	PRESENT	0
747056	746025	08011M	PARTICIPANT	\N	PRESENT	0
747057	746025	19251M	PARTICIPANT	\N	PRESENT	0
747058	746025	19693L	PARTICIPANT	\N	PRESENT	0
747059	746025	11074Q	PARTICIPANT	\N	PRESENT	0
747060	746025	19647E	PARTICIPANT	\N	PRESENT	0
747061	746025	19575F	PARTICIPANT	\N	PRESENT	0
747062	746025	14281W	PARTICIPANT	\N	PRESENT	0
747064	746025	19711U	PARTICIPANT	\N	PRESENT	0
742012	740613	11067R	PARTICIPANT	\N	PRESENT	0
742031	740613	20082E	PARTICIPANT	\N	PRESENT	0
742032	740613	08015R	PARTICIPANT	\N	PRESENT	0
742033	740613	08028W	PARTICIPANT	\N	PRESENT	0
742016	740613	19651A	PARTICIPANT	\N	PRESENT	0
742017	740613	19758L	PARTICIPANT	\N	PRESENT	0
742018	740613	19565D	PARTICIPANT	\N	PRESENT	0
742019	740613	14030Q	PARTICIPANT	\N	PRESENT	0
742020	740613	01025N	PARTICIPANT	\N	PRESENT	0
742021	740613	04070G	PARTICIPANT	\N	PRESENT	0
742022	740613	19611R	PARTICIPANT	\N	PRESENT	0
742023	740613	20132W	PARTICIPANT	\N	PRESENT	0
742024	740613	17589D	PARTICIPANT	\N	PRESENT	0
742025	740613	20052X	PARTICIPANT	\N	PRESENT	0
742026	740613	19699S	PARTICIPANT	\N	PRESENT	0
742027	740613	14215L	PARTICIPANT	\N	PRESENT	0
742028	740613	97011G	PARTICIPANT	\N	PRESENT	0
742029	740613	20090E	PARTICIPANT	\N	PRESENT	0
742030	740613	19703U	PARTICIPANT	\N	PRESENT	0
742034	740613	20056C	PARTICIPANT	\N	PRESENT	0
742035	740613	20026V	PARTICIPANT	\N	PRESENT	0
742036	740613	20180F	PARTICIPANT	\N	PRESENT	0
742037	740613	20084G	PARTICIPANT	\N	PRESENT	0
742038	740613	14109K	PARTICIPANT	\N	PRESENT	0
742039	740613	19713W	PARTICIPANT	\N	PRESENT	0
742040	740613	14147R	PARTICIPANT	\N	PRESENT	0
742041	740613	19621T	PARTICIPANT	\N	PRESENT	0
742042	740613	19747H	PARTICIPANT	\N	PRESENT	0
742043	740613	14069U	PARTICIPANT	\N	PRESENT	0
742044	740613	19693L	PARTICIPANT	\N	PRESENT	0
742045	740613	19593H	PARTICIPANT	\N	PRESENT	0
742046	740613	20112S	PARTICIPANT	\N	PRESENT	0
742047	740613	14189C	PARTICIPANT	\N	PRESENT	0
742051	740613	19643A	PARTICIPANT	\N	PRESENT	0
742049	740613	14223L	PARTICIPANT	\N	PRESENT	0
742050	740613	20142Y	PARTICIPANT	\N	PRESENT	0
742052	740613	19399H	PARTICIPANT	\N	PRESENT	0
742053	740613	20980G	PARTICIPANT	\N	PRESENT	0
742054	740613	19467C	PARTICIPANT	\N	PRESENT	0
742058	740613	20124W	PARTICIPANT	\N	PRESENT	0
742059	740613	20038A	PARTICIPANT	\N	PRESENT	0
742060	740613	20034V	PARTICIPANT	\N	PRESENT	0
742061	740613	20104S	PARTICIPANT	\N	PRESENT	0
742062	740613	20062A	PARTICIPANT	\N	PRESENT	0
742063	740613	14229S	PARTICIPANT	\N	PRESENT	0
742064	740613	04059M	PARTICIPANT	\N	PRESENT	0
742105	740614	14229S	PARTICIPANT	\N	PRESENT	0
742106	740614	04059M	PARTICIPANT	\N	PRESENT	0
742107	740614	14073Q	PARTICIPANT	\N	PRESENT	0
742108	740614	19713W	PARTICIPANT	\N	PRESENT	0
742109	740614	01025N	PARTICIPANT	\N	PRESENT	0
742110	740614	20132W	PARTICIPANT	\N	PRESENT	0
742111	740614	17589D	PARTICIPANT	\N	PRESENT	0
742112	740614	20134Y	PARTICIPANT	\N	PRESENT	0
742010	740613	14026U	PARTICIPANT	\N	PRESENT	0
742011	740613	20134Y	PARTICIPANT	\N	PRESENT	0
742113	740614	19593H	PARTICIPANT	\N	PRESENT	0
742114	740614	20084G	PARTICIPANT	\N	PRESENT	0
742115	740614	20062A	PARTICIPANT	\N	PRESENT	0
742116	740614	20124W	PARTICIPANT	\N	PRESENT	0
742117	740614	20034V	PARTICIPANT	\N	PRESENT	0
742118	740614	20056C	PARTICIPANT	\N	PRESENT	0
742119	740614	19467C	PARTICIPANT	\N	PRESENT	0
742120	740614	20026V	PARTICIPANT	\N	PRESENT	0
742121	740614	20180F	PARTICIPANT	\N	PRESENT	0
742122	740614	20980G	PARTICIPANT	\N	PRESENT	0
742123	740614	20104S	PARTICIPANT	\N	PRESENT	0
742124	740614	19399H	PARTICIPANT	\N	PRESENT	0
742125	740614	19611R	PARTICIPANT	\N	PRESENT	0
742126	740614	97011G	PARTICIPANT	\N	PRESENT	0
742127	740614	14147R	PARTICIPANT	\N	PRESENT	0
742128	740614	20032T	PARTICIPANT	\N	PRESENT	0
742129	740614	19703U	PARTICIPANT	\N	PRESENT	0
742130	740614	14223L	PARTICIPANT	\N	PRESENT	0
742131	740614	19621T	PARTICIPANT	\N	PRESENT	0
742132	740614	19553Y	PARTICIPANT	\N	PRESENT	0
742133	740614	19699S	PARTICIPANT	\N	PRESENT	0
742134	740614	20052X	PARTICIPANT	\N	PRESENT	0
742135	740614	20112S	PARTICIPANT	\N	PRESENT	0
742136	740614	20142Y	PARTICIPANT	\N	PRESENT	0
742137	740614	14033T	PARTICIPANT	\N	PRESENT	0
742138	740614	19693L	PARTICIPANT	\N	PRESENT	0
742139	740614	20082E	PARTICIPANT	\N	PRESENT	0
742140	740614	19565D	PARTICIPANT	\N	PRESENT	0
742141	740614	01048V	PARTICIPANT	\N	PRESENT	0
742142	740614	19747H	PARTICIPANT	\N	PRESENT	0
742103	740614	14026U	PARTICIPANT	\N	PRESENT	0
742104	740614	19651A	PARTICIPANT	\N	PRESENT	0
742143	740614	20098N	PARTICIPANT	\N	PRESENT	0
742144	740614	20044X	PARTICIPANT	\N	PRESENT	0
742145	740614	18083K	PARTICIPANT	\N	PRESENT	0
742146	740614	20090E	PARTICIPANT	\N	PRESENT	0
742147	740614	14219Q	PARTICIPANT	\N	PRESENT	0
742148	740614	19758L	PARTICIPANT	\N	PRESENT	0
742149	740614	20038A	PARTICIPANT	\N	PRESENT	0
742150	740614	20058E	PARTICIPANT	\N	PRESENT	0
742151	740614	19447X	PARTICIPANT	\N	PRESENT	0
742152	740614	19741B	PARTICIPANT	\N	PRESENT	0
742153	740614	11012A	PARTICIPANT	\N	PRESENT	0
742154	740614	14217N	PARTICIPANT	\N	PRESENT	0
742155	740614	19349W	PARTICIPANT	\N	PRESENT	0
742156	740614	14069U	PARTICIPANT	\N	PRESENT	0
742157	740833	20086J	PARTICIPANT	\N	PRESENT	0
742158	740833	20080C	PARTICIPANT	\N	PRESENT	0
742159	740833	19741B	PARTICIPANT	\N	PRESENT	0
742160	740614	99004R	PARTICIPANT	\N	PRESENT	0
742161	740614	20024T	PARTICIPANT	\N	PRESENT	0
742162	740614	20116W	PARTICIPANT	\N	PRESENT	0
742163	740614	19643A	PARTICIPANT	\N	PRESENT	0
742167	740614	19441R	PARTICIPANT	\N	PRESENT	0
742168	741947	20090E	PARTICIPANT	\N	PRESENT	0
742169	741947	11077T	PARTICIPANT	\N	PRESENT	0
742170	741947	14187A	PRESIDENT	0	PRESENT	0
742171	741947	19347U	PARTICIPANT	\N	PRESENT	0
742172	741947	20298U	PARTICIPANT	\N	PRESENT	0
742173	741947	20124W	PARTICIPANT	\N	PRESENT	0
742174	741947	19525U	PARTICIPANT	\N	PRESENT	0
742175	741947	14257W	PARTICIPANT	\N	PRESENT	0
742176	741947	20286Q	PARTICIPANT	\N	EXCUSE	0
742177	741947	20018V	PARTICIPANT	\N	EXCUSE	0
742178	740614	20088L	PARTICIPANT	\N	PRESENT	0
742182	740614	20252E	PARTICIPANT	\N	PRESENT	0
742180	740614	20054A	PARTICIPANT	\N	PRESENT	0
742181	740614	14215L	PARTICIPANT	\N	PRESENT	0
742183	740614	14179A	PARTICIPANT	\N	PRESENT	0
742184	740614	19563B	PARTICIPANT	\N	PRESENT	0
742185	740614	08061X	PARTICIPANT	\N	PRESENT	0
742186	740614	20048C	PARTICIPANT	\N	PRESENT	0
742187	740614	14071N	PARTICIPANT	\N	PRESENT	0
742188	740614	17023S	PARTICIPANT	\N	PRESENT	0
742191	740853	19333N	PARTICIPANT	\N	PRESENT	0
742192	740853	19701S	PARTICIPANT	\N	PRESENT	0
742193	740853	20076G	PARTICIPANT	\N	PRESENT	0
742194	740853	19387D	PARTICIPANT	\N	PRESENT	0
742195	740853	14219Q	PRESIDENT	0	PRESENT	0
742196	740853	19820Y	PARTICIPANT	\N	PRESENT	0
742197	740853	19826F	PARTICIPANT	\N	PRESENT	0
742198	740853	14221J	PARTICIPANT	\N	PRESENT	0
742199	740853	20102Q	PARTICIPANT	\N	PRESENT	0
742200	740853	20096L	PARTICIPANT	\N	PRESENT	0
742201	740853	14237S	PARTICIPANT	\N	PRESENT	0
742202	740853	18083K	PARTICIPANT	\N	PRESENT	0
742203	740853	20100N	PARTICIPANT	\N	PRESENT	0
742204	740853	05012A	PARTICIPANT	\N	PRESENT	0
742205	740853	08060W	PARTICIPANT	\N	PRESENT	0
742206	740853	19503N	PARTICIPANT	\N	PRESENT	0
742207	740853	19685L	PARTICIPANT	\N	PRESENT	0
742208	740853	20024T	PARTICIPANT	\N	PRESENT	0
742209	740853	11065P	PARTICIPANT	\N	PRESENT	0
742210	740853	17637T	PARTICIPANT	\N	PRESENT	0
742211	740853	19525U	PARTICIPANT	\N	PRESENT	0
742212	740853	20120S	PARTICIPANT	\N	PRESENT	0
742213	740853	20032T	PARTICIPANT	\N	PRESENT	0
742214	740853	20136B	PARTICIPANT	\N	PRESENT	0
742215	740853	14031R	PARTICIPANT	\N	PRESENT	0
742216	740853	20038A	PARTICIPANT	\N	PRESENT	0
742217	740853	20140W	PARTICIPANT	\N	PRESENT	0
742218	740853	19251M	PARTICIPANT	\N	PRESENT	0
742219	740853	20046A	PARTICIPANT	\N	PRESENT	0
742220	740853	14033T	PARTICIPANT	\N	PRESENT	0
742221	740853	14169X	PARTICIPANT	\N	PRESENT	0
758551	757797	14229S	PARTICIPANT	\N	PRESENT	0
758552	757797	21056G	PARTICIPANT	\N	PRESENT	0
758553	757797	11045K	PARTICIPANT	\N	PRESENT	0
758554	757797	20084G	PARTICIPANT	\N	PRESENT	0
758555	757797	19669L	PARTICIPANT	\N	PRESENT	0
758556	757797	20064C	PARTICIPANT	\N	PRESENT	0
758557	757797	21031W	PARTICIPANT	\N	PRESENT	0
758558	757797	21077M	PARTICIPANT	\N	PRESENT	0
758559	757797	19725B	PARTICIPANT	\N	PRESENT	0
758560	757797	20046A	PARTICIPANT	\N	PRESENT	0
758561	757797	21042A	PARTICIPANT	\N	PRESENT	0
758562	757797	14189C	PARTICIPANT	\N	PRESENT	0
758563	757797	14001X	PARTICIPANT	\N	PRESENT	0
758564	757797	14255U	PARTICIPANT	\N	PRESENT	0
758565	757797	19703U	PARTICIPANT	\N	PRESENT	0
758566	757797	19621T	PARTICIPANT	\N	PRESENT	0
758567	757797	19711U	PARTICIPANT	\N	PRESENT	0
758568	757797	20070A	PARTICIPANT	\N	PRESENT	0
758569	757797	14267Y	PARTICIPANT	\N	PRESENT	0
758570	757797	19367Y	PARTICIPANT	\N	PRESENT	0
758571	757797	19691J	PARTICIPANT	\N	PRESENT	0
758572	757797	19745F	PARTICIPANT	\N	PRESENT	0
758573	757797	08009T	PARTICIPANT	\N	PRESENT	0
758574	757797	11085T	PARTICIPANT	\N	PRESENT	0
758575	757797	20052X	PARTICIPANT	\N	PRESENT	0
758576	757797	20048C	PARTICIPANT	\N	PRESENT	0
758577	757797	11048N	PARTICIPANT	\N	PRESENT	0
758578	757797	19479G	PARTICIPANT	\N	PRESENT	0
758579	757797	99004R	PARTICIPANT	\N	PRESENT	0
758580	757797	14073Q	PARTICIPANT	\N	PRESENT	0
758581	757797	20248J	PARTICIPANT	\N	PRESENT	0
758582	757797	14259Y	PARTICIPANT	\N	PRESENT	0
758583	757797	19713W	PARTICIPANT	\N	PRESENT	0
758584	757797	21053D	PARTICIPANT	\N	PRESENT	0
758585	757797	19826F	PARTICIPANT	\N	PRESENT	0
758586	757797	21086N	PARTICIPANT	\N	PRESENT	0
758587	757797	21064G	PARTICIPANT	\N	PRESENT	0
758588	757797	20076G	PARTICIPANT	\N	PRESENT	0
758589	757797	20074E	PARTICIPANT	\N	PRESENT	0
758610	757797	14223L	PARTICIPANT	\N	PRESENT	0
758591	757797	14179A	PARTICIPANT	\N	PRESENT	0
758592	757797	21071F	PARTICIPANT	\N	PRESENT	0
758593	757797	14133K	PARTICIPANT	\N	PRESENT	0
758594	757797	04042C	PARTICIPANT	\N	PRESENT	0
758549	757797	20106U	PARTICIPANT	\N	PRESENT	0
758550	757797	04045F	PARTICIPANT	\N	PRESENT	0
758595	757797	20032T	PARTICIPANT	\N	PRESENT	0
758596	757797	20024T	PARTICIPANT	\N	PRESENT	0
758597	757797	14193X	PARTICIPANT	\N	PRESENT	0
758598	757797	05008E	PARTICIPANT	\N	PRESENT	0
758599	757797	20022R	PARTICIPANT	\N	PRESENT	0
758600	757797	08018U	PARTICIPANT	\N	PRESENT	0
758601	757797	14069U	PARTICIPANT	\N	PRESENT	0
758602	757797	08034U	PARTICIPANT	\N	PRESENT	0
758603	757797	14059S	PARTICIPANT	\N	PRESENT	0
758604	757797	05012A	PARTICIPANT	\N	PRESENT	0
758605	757797	20062A	PARTICIPANT	\N	PRESENT	0
758606	757797	04033B	PARTICIPANT	\N	PRESENT	0
758607	757797	19383Y	PARTICIPANT	\N	PRESENT	0
758608	757797	08028W	PARTICIPANT	\N	PRESENT	0
758609	757797	20078J	PARTICIPANT	\N	PRESENT	0
758611	757797	11043H	PARTICIPANT	\N	PRESENT	0
758612	757797	21063F	PARTICIPANT	\N	PRESENT	0
758613	757797	20104S	PARTICIPANT	\N	PRESENT	0
758614	757797	21090J	PARTICIPANT	\N	PRESENT	0
758615	757797	21044C	PARTICIPANT	\N	PRESENT	0
758616	757797	20054A	PARTICIPANT	\N	PRESENT	0
758617	757797	14357A	PARTICIPANT	\N	PRESENT	0
758618	757797	21072G	PARTICIPANT	\N	PRESENT	0
758619	757797	19701S	PARTICIPANT	\N	PRESENT	0
758620	757797	21080G	PARTICIPANT	\N	PRESENT	0
758621	757797	21091K	PARTICIPANT	\N	PRESENT	0
758622	757797	20124W	PARTICIPANT	\N	PRESENT	0
758623	757797	14187A	PARTICIPANT	\N	PRESENT	0
758624	757797	21061D	PARTICIPANT	\N	PRESENT	0
758625	757797	20172F	PARTICIPANT	\N	PRESENT	0
758626	757797	14033T	PARTICIPANT	\N	PRESENT	0
758627	757797	14123H	PARTICIPANT	\N	PRESENT	0
758628	757797	20068G	PARTICIPANT	\N	PRESENT	0
758629	757797	20044X	PARTICIPANT	\N	PRESENT	0
758630	757797	20180F	PARTICIPANT	\N	PRESENT	0
758631	757773	21036C	PARTICIPANT	\N	PRESENT	0
758632	757773	21031W	PARTICIPANT	\N	PRESENT	0
758633	757773	19565D	PARTICIPANT	\N	PRESENT	0
758634	757773	20072C	PARTICIPANT	\N	PRESENT	0
758635	757773	01058X	PARTICIPANT	\N	PRESENT	0
758636	757773	11027H	PARTICIPANT	\N	PRESENT	0
758637	757773	14001X	PARTICIPANT	\N	PRESENT	0
758638	757773	04042C	PARTICIPANT	\N	PRESENT	0
758639	757773	19669L	PARTICIPANT	\N	PRESENT	0
758640	757773	19421M	PARTICIPANT	\N	PRESENT	0
758641	757773	21067K	PARTICIPANT	\N	PRESENT	0
758642	757773	14193X	PRESIDENT	0	PRESENT	0
758643	757773	19347U	PARTICIPANT	\N	PRESENT	0
758644	757773	08047A	PARTICIPANT	\N	PRESENT	0
758645	757773	20128B	PARTICIPANT	\N	PRESENT	0
758646	757773	14059S	PARTICIPANT	\N	PRESENT	0
758647	757773	14097Y	PARTICIPANT	\N	PRESENT	0
758648	757773	14133K	PARTICIPANT	\N	PRESENT	0
758649	757773	21073H	PARTICIPANT	\N	PRESENT	0
758650	757773	20042V	PARTICIPANT	\N	PRESENT	0
758651	757773	20064C	PARTICIPANT	\N	PRESENT	0
758652	757773	20252E	PARTICIPANT	\N	PRESENT	0
758653	757773	98022P	PARTICIPANT	\N	PRESENT	0
758654	757773	99004R	PARTICIPANT	\N	PRESENT	0
758655	757773	19745F	PARTICIPANT	\N	PRESENT	0
758656	757773	14255U	PARTICIPANT	\N	PRESENT	0
758657	757773	17023S	PARTICIPANT	\N	PRESENT	0
758658	757773	12028B	PARTICIPANT	\N	EXCUSE	0
758659	757773	14267Y	PARTICIPANT	\N	EXCUSE	0
758661	757797	14213J	PARTICIPANT	\N	PRESENT	0
758662	757797	20056C	PARTICIPANT	\N	PRESENT	0
758663	757797	08015R	PARTICIPANT	\N	PRESENT	0
758665	757797	19729F	PARTICIPANT	\N	PRESENT	0
758666	757797	19709B	PARTICIPANT	\N	PRESENT	0
758667	757797	20108W	PARTICIPANT	\N	PRESENT	0
758668	757797	14031R	PARTICIPANT	\N	PRESENT	0
758669	757797	21058J	PARTICIPANT	\N	PRESENT	0
758670	757797	20252E	PARTICIPANT	\N	PRESENT	0
758671	757797	14071N	PARTICIPANT	\N	PRESENT	0
758672	757797	14231L	PARTICIPANT	\N	PRESENT	0
758673	757797	21039F	PARTICIPANT	\N	PRESENT	0
758674	757797	21055F	PARTICIPANT	\N	PRESENT	0
758675	757797	21047F	PARTICIPANT	\N	PRESENT	0
758676	757797	11090Q	PARTICIPANT	\N	PRESENT	0
758677	757797	21068L	PARTICIPANT	\N	PRESENT	0
758678	757797	19798U	PARTICIPANT	\N	PRESENT	0
758679	757797	20020P	PARTICIPANT	\N	PRESENT	0
758680	757797	20098N	PARTICIPANT	\N	PRESENT	0
758681	757797	20136B	PARTICIPANT	\N	PRESENT	0
758682	757797	20026V	PARTICIPANT	\N	PRESENT	0
758683	757797	14173T	PARTICIPANT	\N	PRESENT	0
758684	757797	21084L	PARTICIPANT	\N	PRESENT	0
758685	757797	19687N	PARTICIPANT	\N	PRESENT	0
758686	757797	21049H	PARTICIPANT	\N	PRESENT	0
758687	757797	11056N	PARTICIPANT	\N	PRESENT	0
758688	757797	19447X	PARTICIPANT	\N	PRESENT	0
758689	757797	20036X	PARTICIPANT	\N	PRESENT	0
758690	757797	17023S	PARTICIPANT	\N	PRESENT	0
758691	757797	19399H	PARTICIPANT	\N	PRESENT	0
758692	757797	21095P	PARTICIPANT	\N	PRESENT	0
758693	757797	14151M	PARTICIPANT	\N	PRESENT	0
758694	757797	21046E	PARTICIPANT	\N	PRESENT	0
758695	757797	19507S	PARTICIPANT	\N	PRESENT	0
758696	757797	19563B	PARTICIPANT	\N	PRESENT	0
758697	757797	20126Y	PARTICIPANT	\N	PRESENT	0
758698	757797	20140W	PARTICIPANT	\N	PRESENT	0
758701	757797	11027H	PARTICIPANT	\N	PRESENT	0
758702	757797	18207D	PARTICIPANT	\N	PRESENT	0
758703	757797	14097Y	PARTICIPANT	\N	PRESENT	0
758706	757797	21073H	PARTICIPANT	\N	PRESENT	0
758707	757797	21048G	PARTICIPANT	\N	PRESENT	0
758710	757797	20080C	PARTICIPANT	\N	PRESENT	0
758711	757797	12028B	PARTICIPANT	\N	PRESENT	0
758712	757797	19735D	PARTICIPANT	\N	PRESENT	0
758713	757797	07029T	PARTICIPANT	\N	PRESENT	0
758714	757797	20118Y	PARTICIPANT	\N	PRESENT	0
758715	757797	12016W	PARTICIPANT	\N	PRESENT	0
758716	757797	21082J	PARTICIPANT	\N	PRESENT	0
758717	757797	20092G	PARTICIPANT	\N	PRESENT	0
758718	757797	20112S	PARTICIPANT	\N	PRESENT	0
740719	738369	01048V	PARTICIPANT	\N	EXCUSE	0
752102	752101	14053L	PARTICIPANT	\N	PRESENT	0
752103	752101	14089Y	PARTICIPANT	\N	PRESENT	0
752104	752101	11026G	PARTICIPANT	\N	PRESENT	0
753557	753497	17737W	PARTICIPANT	\N	PRESENT	0
753558	753497	21032X	PARTICIPANT	\N	PRESENT	0
753559	753497	18207D	PARTICIPANT	\N	PRESENT	0
753560	753497	19709B	PARTICIPANT	\N	PRESENT	0
753561	753497	18395Y	PARTICIPANT	\N	PRESENT	0
753562	753497	21037D	PARTICIPANT	\N	PRESENT	0
753563	753497	19683J	PARTICIPANT	\N	PRESENT	0
753564	753497	14097Y	PARTICIPANT	\N	PRESENT	0
753565	753497	21054E	PARTICIPANT	\N	PRESENT	0
753566	753497	19711U	PARTICIPANT	\N	PRESENT	0
753567	753497	14073Q	PARTICIPANT	\N	PRESENT	0
753568	753497	08034U	PARTICIPANT	\N	PRESENT	0
753569	753497	14189C	PARTICIPANT	\N	PRESENT	0
753570	753497	14133K	PARTICIPANT	\N	PRESENT	0
753571	753497	20042V	PARTICIPANT	\N	PRESENT	0
753572	753497	10015M	PARTICIPANT	\N	PRESENT	0
753573	753497	21076L	PARTICIPANT	\N	PRESENT	0
753574	753497	14033T	PARTICIPANT	\N	PRESENT	0
753575	753497	14169X	PARTICIPANT	\N	PRESENT	0
753576	753497	20248J	PARTICIPANT	\N	PRESENT	0
753577	753497	20286Q	PARTICIPANT	\N	PRESENT	0
753578	753497	19760E	PARTICIPANT	\N	PRESENT	0
753579	753497	21078N	PARTICIPANT	\N	PRESENT	0
753580	752412	86034E	PARTICIPANT	\N	PRESENT	0
760502	757801	14111D	PARTICIPANT	\N	PRESENT	0
760527	757801	20094J	PARTICIPANT	\N	PRESENT	0
760528	757801	11040E	PARTICIPANT	\N	PRESENT	0
760530	757801	20024T	PARTICIPANT	\N	PRESENT	0
760532	757801	21048G	PARTICIPANT	\N	PRESENT	0
760533	757801	21073H	PARTICIPANT	\N	PRESENT	0
760535	757801	20032T	PARTICIPANT	\N	PRESENT	0
760537	757801	14033T	PARTICIPANT	\N	PRESENT	0
760539	757801	21087P	PARTICIPANT	\N	PRESENT	0
760540	757801	19693L	PARTICIPANT	\N	PRESENT	0
760542	757801	14207L	PARTICIPANT	\N	PRESENT	0
760543	757801	20052X	PARTICIPANT	\N	PRESENT	0
760544	757801	20134Y	PARTICIPANT	\N	PRESENT	0
760545	757801	21041Y	PARTICIPANT	\N	PRESENT	0
760546	757801	21075K	PARTICIPANT	\N	PRESENT	0
760547	757801	98022P	PARTICIPANT	\N	PRESENT	0
760548	757801	19711U	PARTICIPANT	\N	PRESENT	0
760549	757801	14249W	PARTICIPANT	\N	PRESENT	0
760550	757801	07004J	PARTICIPANT	\N	PRESENT	0
760552	757801	19565D	PARTICIPANT	\N	PRESENT	0
760553	757801	14147R	PARTICIPANT	\N	PRESENT	0
760554	757801	20062A	PARTICIPANT	\N	PRESENT	0
760558	757801	11070L	PARTICIPANT	\N	PRESENT	0
760570	757801	14073Q	PARTICIPANT	\N	PRESENT	0
760571	757801	19531S	PARTICIPANT	\N	PRESENT	0
760575	757801	21096Q	PARTICIPANT	\N	PRESENT	0
760576	757801	20264J	PARTICIPANT	\N	PRESENT	0
760583	757801	21053D	PARTICIPANT	\N	PRESENT	0
760593	757801	19563B	PARTICIPANT	\N	PRESENT	0
760598	757801	21042A	PARTICIPANT	\N	PRESENT	0
760606	757801	14069U	PARTICIPANT	\N	PRESENT	0
760611	757801	20070A	PARTICIPANT	\N	PRESENT	0
760612	757801	19057M	PARTICIPANT	\N	PRESENT	0
760613	757801	19705W	PARTICIPANT	\N	PRESENT	0
761164	761029	12016W	PARTICIPANT	\N	EXCUSE	0
761179	761171	19699S	PARTICIPANT	\N	PRESENT	0
761180	761171	14229S	PARTICIPANT	\N	PRESENT	0
761192	761191	14331P	PARTICIPANT	\N	PRESENT	0
761200	761198	14331P	PARTICIPANT	\N	PRESENT	0
761197	761194	14331P	PARTICIPANT	\N	PRESENT	0
761206	761205	14331P	PARTICIPANT	\N	PRESENT	0
761202	761201	14331P	PARTICIPANT	\N	PRESENT	0
761208	761207	08034U	PARTICIPANT	\N	PRESENT	0
761214	761212	08034U	PARTICIPANT	\N	PRESENT	0
761224	761223	08034U	PARTICIPANT	\N	PRESENT	0
761226	761225	08034U	PARTICIPANT	\N	PRESENT	0
763513	763512	14249W	PARTICIPANT	\N	PRESENT	0
765424	765422	19531S	PARTICIPANT	\N	PRESENT	0
765426	765425	19565D	PARTICIPANT	\N	PRESENT	0
765427	765425	14267Y	PARTICIPANT	\N	PRESENT	0
765487	765486	14267Y	PARTICIPANT	\N	PRESENT	0
765488	765486	19565D	PARTICIPANT	\N	PRESENT	0
766929	766927	14123H	PARTICIPANT	\N	PRESENT	1
767793	765403	19111A	PARTICIPANT	\N	PRESENT	0
767794	765403	11027H	PARTICIPANT	\N	PRESENT	0
767795	765403	11085T	PARTICIPANT	\N	PRESENT	0
767796	765403	20070A	PARTICIPANT	\N	PRESENT	0
767797	765403	14267Y	PARTICIPANT	\N	PRESENT	0
767798	765403	08060W	PARTICIPANT	\N	PRESENT	0
767799	765403	15197G	PARTICIPANT	\N	PRESENT	0
767800	765403	18395Y	PARTICIPANT	\N	PRESENT	0
767801	765403	21067K	PARTICIPANT	\N	PRESENT	0
767802	765403	19251M	PARTICIPANT	\N	PRESENT	0
767803	765403	14151M	PARTICIPANT	\N	PRESENT	0
767804	765403	21064G	PARTICIPANT	\N	PRESENT	0
767805	765403	21089R	PARTICIPANT	\N	PRESENT	0
767806	765403	19563B	PARTICIPANT	\N	PRESENT	0
767807	765403	14257W	PARTICIPANT	\N	PRESENT	0
767808	765403	21086N	PARTICIPANT	\N	PRESENT	0
767809	765403	21062E	PARTICIPANT	\N	PRESENT	0
767810	765403	14255U	PARTICIPANT	\N	PRESENT	0
767811	765403	14281W	PARTICIPANT	\N	PRESENT	0
767812	765403	21038E	PARTICIPANT	\N	PRESENT	0
767813	765403	19820Y	PARTICIPANT	\N	PRESENT	0
765351	761719	04047H	PARTICIPANT	\N	PRESENT	0
765423	765422	04042C	PARTICIPANT	\N	PRESENT	0
767814	765403	14121F	PARTICIPANT	\N	PRESENT	0
767815	765403	20060X	PARTICIPANT	\N	PRESENT	0
767816	765403	11070L	PARTICIPANT	\N	PRESENT	0
767817	765403	19725B	PARTICIPANT	\N	PRESENT	0
767818	765403	19826F	PARTICIPANT	\N	PRESENT	0
767819	765403	19531S	PARTICIPANT	\N	PRESENT	0
767820	765403	21042A	PARTICIPANT	\N	PRESENT	0
767821	765403	19683J	PARTICIPANT	\N	PRESENT	0
767822	765403	19713W	PARTICIPANT	\N	PRESENT	0
767823	765403	18207D	PARTICIPANT	\N	PRESENT	0
767824	765403	20040T	PARTICIPANT	\N	PRESENT	0
767825	765403	20248J	PARTICIPANT	\N	PRESENT	0
767826	765403	21093M	PARTICIPANT	\N	PRESENT	0
767827	765403	08012N	PARTICIPANT	\N	PRESENT	0
767828	765403	14073Q	PARTICIPANT	\N	PRESENT	0
767829	765403	14083S	PARTICIPANT	\N	PRESENT	0
767830	765403	95041E	PARTICIPANT	\N	PRESENT	0
767831	765403	14001X	PARTICIPANT	\N	PRESENT	0
767832	765403	21048G	PARTICIPANT	\N	PRESENT	0
767833	765403	20028X	PARTICIPANT	\N	PRESENT	0
767834	765403	14097Y	PARTICIPANT	\N	PRESENT	0
767835	765403	18231D	PARTICIPANT	\N	PRESENT	0
767836	765403	19699S	PARTICIPANT	\N	PRESENT	0
767837	765403	21060C	PARTICIPANT	\N	PRESENT	0
767838	765403	20030R	PARTICIPANT	\N	PRESENT	0
767839	765403	20118Y	PARTICIPANT	\N	PRESENT	0
767840	765403	17965H	PARTICIPANT	\N	PRESENT	0
767841	765403	14225N	PARTICIPANT	\N	PRESENT	0
767842	765403	20082E	PARTICIPANT	\N	PRESENT	0
767843	765403	14231L	PARTICIPANT	\N	PRESENT	0
767844	765403	19569H	PARTICIPANT	\N	PRESENT	0
767845	765403	19685L	PARTICIPANT	\N	PRESENT	0
767846	765403	20048C	PARTICIPANT	\N	PRESENT	0
767847	765403	20066E	PARTICIPANT	\N	PRESENT	0
767848	765403	19611R	PARTICIPANT	\N	PRESENT	0
767849	765403	20052X	PARTICIPANT	\N	PRESENT	0
767850	765403	14219Q	PARTICIPANT	\N	PRESENT	0
767851	765403	14055N	PARTICIPANT	\N	PRESENT	0
767852	765403	19749K	PARTICIPANT	\N	PRESENT	0
767853	765403	19479G	PARTICIPANT	\N	PRESENT	0
767854	765403	14275Y	PARTICIPANT	\N	PRESENT	0
767855	765403	20136B	PARTICIPANT	\N	PRESENT	0
767856	765403	04047H	PARTICIPANT	\N	PRESENT	0
767857	765403	14229S	PARTICIPANT	\N	PRESENT	0
767858	765403	11045K	PARTICIPANT	\N	PRESENT	0
767859	765403	21059K	PARTICIPANT	\N	PRESENT	0
767860	765403	20084G	PARTICIPANT	\N	PRESENT	0
767861	765403	19669L	PARTICIPANT	\N	PRESENT	0
767862	765403	19413M	PARTICIPANT	\N	PRESENT	0
767863	765403	21051B	PARTICIPANT	\N	PRESENT	0
767864	765403	20018V	PARTICIPANT	\N	PRESENT	0
767865	765403	20114U	PARTICIPANT	\N	PRESENT	0
767866	765403	14215L	PARTICIPANT	\N	PRESENT	0
767867	765403	21031W	PARTICIPANT	\N	PRESENT	0
767868	765403	21082J	PARTICIPANT	\N	PRESENT	0
767869	765403	07004J	PARTICIPANT	\N	PRESENT	0
767870	765403	20132W	PARTICIPANT	\N	PRESENT	0
747065	746025	17637T	PARTICIPANT	\N	PRESENT	0
747066	746025	04008A	PARTICIPANT	\N	PRESENT	0
747067	746025	11101A	PARTICIPANT	\N	PRESENT	0
747068	746025	19820Y	PARTICIPANT	\N	PRESENT	0
747069	746025	08010L	PARTICIPANT	\N	PRESENT	0
747070	746025	19725B	PARTICIPANT	\N	PRESENT	0
747071	746025	04047H	PARTICIPANT	\N	PRESENT	0
747072	746025	11033F	PARTICIPANT	\N	PRESENT	0
747073	746025	14026U	PARTICIPANT	\N	PRESENT	0
747074	746025	19333N	PARTICIPANT	\N	PRESENT	0
747075	746025	19551W	PARTICIPANT	\N	PRESENT	0
747076	746025	08034U	PARTICIPANT	\N	PRESENT	0
747077	746025	14121F	PARTICIPANT	\N	PRESENT	0
747078	746025	14133K	PARTICIPANT	\N	PRESENT	0
747079	746025	04092N	PARTICIPANT	\N	PRESENT	0
747080	746025	19683J	PARTICIPANT	\N	PRESENT	0
747081	746025	05008E	PARTICIPANT	\N	PRESENT	0
747082	746025	11097X	PARTICIPANT	\N	PRESENT	0
747083	746025	19415P	PARTICIPANT	\N	PRESENT	0
747084	746025	19599P	PARTICIPANT	\N	PRESENT	0
747085	746025	14215L	PARTICIPANT	\N	PRESENT	0
747086	746025	14021P	PARTICIPANT	\N	PRESENT	0
747087	746025	14053L	PARTICIPANT	\N	PRESENT	0
747088	746025	19489J	PARTICIPANT	\N	PRESENT	0
747089	746025	20060X	PARTICIPANT	\N	PRESENT	0
747090	746025	19649G	PARTICIPANT	\N	PRESENT	0
747091	746025	18193Q	PARTICIPANT	\N	PRESENT	0
747092	746025	20118Y	PARTICIPANT	\N	PRESENT	0
747093	746025	10006L	PARTICIPANT	\N	PRESENT	0
747094	746025	14001X	PARTICIPANT	\N	PRESENT	0
747095	746025	19798U	PARTICIPANT	\N	PRESENT	0
747096	746025	14193X	PARTICIPANT	\N	PRESENT	0
747097	746025	14237S	PARTICIPANT	\N	PRESENT	0
747098	746025	19671E	PARTICIPANT	\N	PRESENT	0
747099	746025	19367Y	PARTICIPANT	\N	PRESENT	0
747100	746025	20252E	PARTICIPANT	\N	PRESENT	0
747101	746025	20054A	PARTICIPANT	\N	PRESENT	0
747102	746025	20152B	PARTICIPANT	\N	PRESENT	0
747103	746025	20020P	PARTICIPANT	\N	PRESENT	0
747104	746025	19762G	PARTICIPANT	\N	PRESENT	0
747105	746025	20126Y	PARTICIPANT	\N	PRESENT	0
747106	746025	20124W	PARTICIPANT	\N	PRESENT	0
747107	746025	14357A	PARTICIPANT	\N	PRESENT	0
747108	746025	19383Y	PARTICIPANT	\N	PRESENT	0
747109	746025	14229S	PARTICIPANT	\N	PRESENT	0
747110	746025	01028R	PARTICIPANT	\N	PRESENT	0
747111	746025	97011G	PARTICIPANT	\N	PRESENT	0
747112	746025	01062T	PARTICIPANT	\N	PRESENT	0
747113	746025	14147R	PARTICIPANT	\N	PRESENT	0
747114	746025	20064C	PARTICIPANT	\N	PRESENT	0
747115	746025	20172F	PARTICIPANT	\N	PRESENT	0
747116	746025	20138D	PARTICIPANT	\N	PRESENT	0
747117	746025	11090Q	PARTICIPANT	\N	PRESENT	0
747118	746025	95063L	PARTICIPANT	\N	PRESENT	0
747119	746025	11080N	PARTICIPANT	\N	PRESENT	0
747120	746025	14255U	PARTICIPANT	\N	PRESENT	0
747121	746025	14187A	PARTICIPANT	\N	PRESENT	0
747122	746025	14083S	PARTICIPANT	\N	PRESENT	0
747123	746025	11053K	PARTICIPANT	\N	PRESENT	0
747124	746025	19721W	PARTICIPANT	\N	PRESENT	0
747125	746025	14267Y	PARTICIPANT	\N	PRESENT	0
747126	746025	11070L	PARTICIPANT	\N	PRESENT	0
747127	746025	99004R	PARTICIPANT	\N	PRESENT	0
747128	746025	17229F	PARTICIPANT	\N	PRESENT	0
747129	746025	04043D	PARTICIPANT	\N	PRESENT	0
747130	746025	01024M	PARTICIPANT	\N	PRESENT	0
747153	746025	20248J	PARTICIPANT	\N	PRESENT	0
747132	746025	20044X	PARTICIPANT	\N	PRESENT	0
747133	746025	19577H	PARTICIPANT	\N	PRESENT	0
747134	746025	14042U	PARTICIPANT	\N	PRESENT	0
747135	746025	20040T	PARTICIPANT	\N	PRESENT	0
747136	746025	14253S	PARTICIPANT	\N	PRESENT	0
747137	746025	14231L	PARTICIPANT	\N	PRESENT	0
747138	746025	07004J	PARTICIPANT	\N	PRESENT	0
747139	746025	19723Y	PARTICIPANT	\N	PRESENT	0
747140	746025	19569H	PARTICIPANT	\N	PRESENT	0
747141	746025	14179A	PARTICIPANT	\N	PRESENT	0
747142	746025	19685L	PARTICIPANT	\N	PRESENT	0
747143	746025	20066E	PARTICIPANT	\N	PRESENT	0
747144	746025	20032T	PARTICIPANT	\N	PRESENT	0
747145	746025	11010L	PARTICIPANT	\N	PRESENT	0
747146	746025	19447X	PARTICIPANT	\N	PRESENT	0
747147	746025	17965H	PARTICIPANT	\N	PRESENT	0
747148	746025	11041F	PARTICIPANT	\N	PRESENT	0
747149	746025	19533U	PARTICIPANT	\N	PRESENT	0
747150	746025	01060R	PARTICIPANT	\N	PRESENT	0
747151	746025	20042V	PARTICIPANT	\N	PRESENT	0
747152	746025	19057M	PARTICIPANT	\N	PRESENT	0
747154	746025	20286Q	PARTICIPANT	\N	PRESENT	0
747160	746025	19335Q	PARTICIPANT	\N	PRESENT	0
747156	746025	20052X	PARTICIPANT	\N	PRESENT	0
747157	746025	16685X	PARTICIPANT	\N	PRESENT	0
747158	746025	19441R	PARTICIPANT	\N	PRESENT	0
747159	746025	11031D	PARTICIPANT	\N	PRESENT	0
747161	746025	04070G	PARTICIPANT	\N	PRESENT	0
747162	746025	19713W	PARTICIPANT	\N	PRESENT	0
747163	746025	14275Y	PARTICIPANT	\N	PRESENT	0
747164	746025	01034P	PARTICIPANT	\N	PRESENT	0
747165	746025	17779H	PARTICIPANT	\N	PRESENT	0
747167	746025	01043Q	PARTICIPANT	\N	PRESENT	0
747168	746025	14251Q	PARTICIPANT	\N	PRESENT	0
747169	746025	14225N	PARTICIPANT	\N	PRESENT	0
747170	746025	04042C	PARTICIPANT	\N	PRESENT	0
747171	746025	14217N	PARTICIPANT	\N	PRESENT	0
747172	746025	19673G	PARTICIPANT	\N	PRESENT	0
747173	746025	11056N	PARTICIPANT	\N	PRESENT	0
747174	746025	20094J	PARTICIPANT	\N	PRESENT	0
747175	746025	11067R	PARTICIPANT	\N	PRESENT	0
747176	746025	20058E	PARTICIPANT	\N	PRESENT	0
747177	746025	17023S	PARTICIPANT	\N	PRESENT	0
747178	746025	08009T	PARTICIPANT	\N	PRESENT	0
747179	744231	19741B	PARTICIPANT	\N	PRESENT	0
747180	744231	19667J	PARTICIPANT	\N	PRESENT	0
747181	744231	20116W	PARTICIPANT	\N	PRESENT	0
747182	744231	11040E	PARTICIPANT	\N	PRESENT	0
747183	744231	20914V	PARTICIPANT	\N	PRESENT	0
747184	746025	14097Y	PARTICIPANT	\N	PRESENT	0
747185	744231	20080C	PARTICIPANT	\N	PRESENT	0
747186	744231	14083S	PARTICIPANT	\N	PRESENT	0
747187	744231	11053K	PARTICIPANT	\N	PRESENT	0
747188	746025	19709B	PARTICIPANT	\N	PRESENT	0
747189	744231	20070A	PARTICIPANT	\N	PRESENT	0
747190	744231	11070L	PARTICIPANT	\N	PRESENT	0
747191	744231	14327T	PARTICIPANT	\N	PRESENT	0
747192	744231	04071H	PARTICIPANT	\N	PRESENT	0
747193	744231	19647E	PARTICIPANT	\N	PRESENT	0
747194	744231	01057W	PARTICIPANT	\N	PRESENT	0
747195	744231	11048N	PARTICIPANT	\N	PRESENT	0
747196	744231	14121F	PARTICIPANT	\N	PRESENT	0
747197	744231	19531S	PARTICIPANT	\N	PRESENT	0
747198	744231	99004R	PARTICIPANT	\N	PRESENT	0
747199	744231	20126Y	PARTICIPANT	\N	PRESENT	0
747200	744231	07029T	PARTICIPANT	\N	PRESENT	0
747201	744231	19711U	PARTICIPANT	\N	PRESENT	0
747202	744231	08010L	PARTICIPANT	\N	PRESENT	0
747203	744231	20252E	PARTICIPANT	\N	PRESENT	0
747204	744231	19671E	PARTICIPANT	\N	PRESENT	0
747205	744231	19335Q	PARTICIPANT	\N	PRESENT	0
747206	744231	08011M	PARTICIPANT	\N	PRESENT	0
747207	744231	14253S	PARTICIPANT	\N	PRESENT	0
747208	744231	20050V	PARTICIPANT	\N	PRESENT	0
747209	744231	08073C	PARTICIPANT	\N	PRESENT	0
747210	744231	19349W	PARTICIPANT	\N	PRESENT	0
747211	744231	14331P	PARTICIPANT	\N	PRESENT	0
747212	744231	14225N	PRESIDENT	0	PRESENT	0
747213	744231	11012A	PARTICIPANT	\N	PRESENT	0
747214	744231	20044X	PARTICIPANT	\N	PRESENT	0
747215	744231	19687N	PARTICIPANT	\N	PRESENT	0
747216	744231	19479G	PARTICIPANT	\N	PRESENT	0
747217	746025	14211G	PARTICIPANT	\N	PRESENT	0
747218	746025	20120S	PARTICIPANT	\N	PRESENT	0
747219	746025	20136B	PARTICIPANT	\N	PRESENT	0
747220	746025	14331P	PARTICIPANT	\N	PRESENT	0
747224	746025	04035D	PARTICIPANT	\N	PRESENT	0
747230	746025	14169X	PARTICIPANT	\N	PRESENT	0
742222	740853	20062A	PARTICIPANT	\N	PRESENT	0
742223	740853	20068G	PARTICIPANT	\N	PRESENT	0
742224	740853	19745F	PARTICIPANT	\N	PRESENT	0
742225	740853	20106U	PARTICIPANT	\N	EXCUSE	0
742226	740853	19549D	PARTICIPANT	\N	EXCUSE	0
742227	740853	19637C	PARTICIPANT	\N	EXCUSE	0
742228	740853	17229F	PARTICIPANT	\N	EXCUSE	0
742254	740616	86034E	PARTICIPANT	\N	PRESENT	0
742260	740834	14225N	PRESIDENT	0	PRESENT	0
742261	740834	14173T	PARTICIPANT	\N	PRESENT	0
742263	740834	14327T	PARTICIPANT	\N	PRESENT	0
742264	740834	08009T	PARTICIPANT	\N	PRESENT	0
742265	740834	19687N	PARTICIPANT	\N	PRESENT	0
742266	740834	12016W	PARTICIPANT	\N	PRESENT	0
742273	740834	11040E	PARTICIPANT	\N	PRESENT	0
742274	740834	07029T	PARTICIPANT	\N	PRESENT	0
742275	740834	19741B	PARTICIPANT	\N	PRESENT	0
742276	740834	11074Q	PARTICIPANT	\N	PRESENT	0
742277	740834	14253S	PARTICIPANT	\N	PRESENT	0
742279	740834	11048N	PARTICIPANT	\N	PRESENT	0
742280	740834	20036X	PARTICIPANT	\N	PRESENT	0
742281	740834	01048V	PARTICIPANT	\N	PRESENT	0
742282	740834	19545Y	PARTICIPANT	\N	PRESENT	0
742283	740834	20050V	PARTICIPANT	\N	PRESENT	0
742284	740834	19671E	PARTICIPANT	\N	PRESENT	0
742285	740834	14083S	PARTICIPANT	\N	PRESENT	0
742286	740834	11012A	PARTICIPANT	\N	PRESENT	0
742287	740834	20116W	PARTICIPANT	\N	PRESENT	0
742288	740834	99004R	PARTICIPANT	\N	PRESENT	0
742289	740834	20914V	PARTICIPANT	\N	PRESENT	0
742290	740834	19335Q	PARTICIPANT	\N	PRESENT	0
742291	738440	19766L	PARTICIPANT	\N	PRESENT	0
742292	738440	19699S	PARTICIPANT	\N	PRESENT	0
742293	738440	19533U	PARTICIPANT	\N	PRESENT	0
742294	738440	04033B	PARTICIPANT	\N	PRESENT	0
742295	738440	20098N	PARTICIPANT	\N	PRESENT	0
742296	738440	20112S	PARTICIPANT	\N	PRESENT	0
742297	738440	08012N	PARTICIPANT	\N	PRESENT	0
742298	738440	20124W	PARTICIPANT	\N	PRESENT	0
742299	738440	20026V	PARTICIPANT	\N	PRESENT	0
742300	738440	19593H	PARTICIPANT	\N	PRESENT	0
742301	738440	19527W	PARTICIPANT	\N	PRESENT	0
742302	738440	19643A	PARTICIPANT	\N	PRESENT	0
742303	738440	20132W	PARTICIPANT	\N	PRESENT	0
742304	738440	20134Y	PARTICIPANT	\N	PRESENT	0
742305	738440	14073Q	PARTICIPANT	\N	PRESENT	0
742306	738440	20138D	PARTICIPANT	\N	PRESENT	0
742307	738440	19611R	PRESIDENT	0	PRESENT	0
742308	738440	20142Y	PARTICIPANT	\N	PRESENT	0
742309	738440	20048C	PARTICIPANT	\N	PRESENT	0
742310	738440	19693L	PARTICIPANT	\N	PRESENT	0
742311	738440	19399H	PARTICIPANT	\N	PRESENT	0
742312	738440	20052X	PARTICIPANT	\N	PRESENT	0
742313	738440	19719D	PARTICIPANT	\N	PRESENT	0
742314	738440	20172F	PARTICIPANT	\N	PRESENT	0
742315	738440	14030Q	PARTICIPANT	\N	PRESENT	0
742316	738440	20058E	PARTICIPANT	\N	PRESENT	0
742317	738440	20056C	PARTICIPANT	\N	PRESENT	0
742318	738440	20180F	PARTICIPANT	\N	PRESENT	0
742319	738440	20264J	PARTICIPANT	\N	PRESENT	0
742320	738440	19735D	PARTICIPANT	\N	PRESENT	0
742321	738440	19057M	PARTICIPANT	\N	PRESENT	0
742322	738440	14109K	PARTICIPANT	\N	PRESENT	0
742323	738440	14123H	PARTICIPANT	\N	PRESENT	0
742324	738440	11104D	PARTICIPANT	\N	PRESENT	0
742325	738440	19758L	PARTICIPANT	\N	PRESENT	0
742326	738440	17589D	PARTICIPANT	\N	PRESENT	0
742327	738440	19621T	PARTICIPANT	\N	PRESENT	0
742328	738440	20084G	PARTICIPANT	\N	PRESENT	0
742329	740834	04071H	PARTICIPANT	\N	PRESENT	0
742330	740834	11053K	PARTICIPANT	\N	PRESENT	0
742331	740834	20080C	PARTICIPANT	\N	PRESENT	0
742332	740834	11070L	PARTICIPANT	\N	PRESENT	0
742333	740834	19349W	PARTICIPANT	\N	PRESENT	0
742334	740834	08010L	PARTICIPANT	\N	PRESENT	0
742335	740834	20126Y	PARTICIPANT	\N	PRESENT	0
742336	740834	19479G	PARTICIPANT	\N	PRESENT	0
742337	740834	14189C	PARTICIPANT	\N	PRESENT	0
742338	740834	20044X	PARTICIPANT	\N	PRESENT	0
742339	740834	08073C	PARTICIPANT	\N	PRESENT	0
742437	740162	20090E	PARTICIPANT	\N	PRESENT	0
742438	740162	14355X	PARTICIPANT	\N	PRESENT	0
742439	740162	19798U	PARTICIPANT	\N	PRESENT	0
742440	740162	11097X	PARTICIPANT	\N	PRESENT	0
742441	740162	19329S	PARTICIPANT	\N	PRESENT	0
742442	740162	14026U	PARTICIPANT	\N	PRESENT	0
742443	740162	17779H	PARTICIPANT	\N	PRESENT	0
742444	740162	19553Y	PARTICIPANT	\N	PRESENT	0
742445	740162	19703U	PARTICIPANT	\N	PRESENT	0
742446	740162	14281W	PARTICIPANT	\N	PRESENT	0
742447	740162	19679N	PARTICIPANT	\N	PRESENT	0
742448	740162	14195A	PARTICIPANT	\N	PRESENT	0
742449	740162	14213J	PARTICIPANT	\N	PRESENT	0
742450	740162	14217N	PARTICIPANT	\N	PRESENT	0
742451	740162	10006L	PRESIDENT	0	PRESENT	0
742452	740162	20130U	PARTICIPANT	\N	PRESENT	0
742453	740162	01034P	PARTICIPANT	\N	PRESENT	0
742454	740162	04057K	PARTICIPANT	\N	PRESENT	0
742455	740162	04092N	PARTICIPANT	\N	PRESENT	0
742456	740162	19713W	PARTICIPANT	\N	PRESENT	0
742457	740162	08045X	PARTICIPANT	\N	PRESENT	0
742458	740162	19663E	PARTICIPANT	\N	PRESENT	0
742459	740162	19715Y	PARTICIPANT	\N	PRESENT	0
742460	740162	19691J	PARTICIPANT	\N	PRESENT	0
742461	740162	19295A	PARTICIPANT	\N	PRESENT	0
742462	740162	19723Y	PARTICIPANT	\N	PRESENT	0
742463	740162	20248J	PARTICIPANT	\N	PRESENT	0
742464	740162	20066E	PARTICIPANT	\N	PRESENT	0
742465	740162	20266L	PARTICIPANT	\N	PRESENT	0
742467	740162	14071N	PARTICIPANT	\N	PRESENT	0
742468	740162	04043D	PARTICIPANT	\N	PRESENT	0
742469	740162	19697Q	PARTICIPANT	\N	PRESENT	0
742470	740162	14223L	PARTICIPANT	\N	PRESENT	0
742471	740162	18193Q	PARTICIPANT	\N	PRESENT	0
742472	740162	19683J	PARTICIPANT	\N	PRESENT	0
742473	740162	19591F	PARTICIPANT	\N	PRESENT	0
742474	740162	17965H	PARTICIPANT	\N	PRESENT	0
742475	740754	01028R	PARTICIPANT	\N	PRESENT	0
742476	740754	05008E	PARTICIPANT	\N	PRESENT	0
742477	740754	20114U	PARTICIPANT	\N	PRESENT	0
742478	740754	11026G	PARTICIPANT	\N	PRESENT	0
742479	740754	14089Y	PARTICIPANT	\N	PRESENT	0
742480	740162	11067R	PARTICIPANT	\N	PRESENT	0
742481	740162	19569H	PARTICIPANT	\N	PRESENT	0
742482	740162	14042U	PARTICIPANT	\N	PRESENT	0
742483	740162	20040T	PARTICIPANT	\N	PRESENT	0
742484	742272	12041X	PARTICIPANT	\N	PRESENT	0
742485	742272	19565D	PARTICIPANT	\N	PRESENT	0
742486	742272	20072C	PARTICIPANT	\N	PRESENT	0
742487	742272	11080N	PARTICIPANT	\N	PRESENT	0
742488	742272	01058X	PARTICIPANT	\N	PRESENT	0
742489	742272	11027H	PARTICIPANT	\N	PRESENT	0
742490	742272	16685X	PARTICIPANT	\N	PRESENT	0
742491	742272	04042C	PRESIDENT	0	PRESENT	0
742492	742272	11054L	PARTICIPANT	\N	PRESENT	0
742493	742272	19669L	PARTICIPANT	\N	PRESENT	0
742494	742272	11066Q	PARTICIPANT	\N	PRESENT	0
742495	742272	08056B	PARTICIPANT	\N	PRESENT	0
742496	742272	12028B	PARTICIPANT	\N	PRESENT	0
742497	742272	11115U	PARTICIPANT	\N	PRESENT	0
742498	742272	14055N	PARTICIPANT	\N	PRESENT	0
742499	742272	19421M	PARTICIPANT	\N	PRESENT	0
742501	742272	19347U	PARTICIPANT	\N	PRESENT	0
742502	742272	14193X	PARTICIPANT	\N	PRESENT	0
742503	742272	07033P	PARTICIPANT	\N	PRESENT	0
742504	742272	08061X	PARTICIPANT	\N	PRESENT	0
742505	742272	14249W	PARTICIPANT	\N	PRESENT	0
742506	742272	20128B	PARTICIPANT	\N	PRESENT	0
742507	742272	08047A	PARTICIPANT	\N	PRESENT	0
742508	742272	14059S	PARTICIPANT	\N	PRESENT	0
742509	742272	14097Y	PARTICIPANT	\N	PRESENT	0
742510	742272	04035D	PARTICIPANT	\N	PRESENT	0
742511	742272	14133K	PARTICIPANT	\N	PRESENT	0
742512	742272	01062T	PARTICIPANT	\N	PRESENT	0
742513	742272	11041F	PARTICIPANT	\N	PRESENT	0
742514	742272	20042V	PARTICIPANT	\N	PRESENT	0
742515	742272	01024M	PARTICIPANT	\N	PRESENT	0
742516	742272	14105F	PARTICIPANT	\N	PRESENT	0
742517	742272	20064C	PARTICIPANT	\N	PRESENT	0
758719	757797	19349W	PARTICIPANT	\N	PRESENT	0
758720	757797	20072C	PARTICIPANT	\N	PRESENT	0
758721	757797	14205J	PARTICIPANT	\N	PRESENT	0
758722	757797	14211G	PARTICIPANT	\N	PRESENT	0
758723	757797	19782L	PARTICIPANT	\N	PRESENT	0
758724	757797	08045X	PARTICIPANT	\N	PRESENT	0
758726	757797	19533U	PARTICIPANT	\N	PRESENT	0
758751	757844	04070G	PARTICIPANT	\N	PRESENT	0
758752	757844	19697Q	PARTICIPANT	\N	PRESENT	0
758753	757844	21058J	PARTICIPANT	\N	PRESENT	0
758754	757844	21059K	PARTICIPANT	\N	PRESENT	0
758755	757844	20102Q	PARTICIPANT	\N	PRESENT	0
758756	757844	14229S	PARTICIPANT	\N	PRESENT	0
758757	757844	18395Y	PARTICIPANT	\N	PRESENT	0
758758	757844	20112S	PARTICIPANT	\N	PRESENT	0
758759	757844	21089R	PARTICIPANT	\N	PRESENT	0
758760	757844	21037D	PARTICIPANT	\N	PRESENT	0
758761	757844	21091K	PARTICIPANT	\N	PRESENT	0
758762	757844	20124W	PARTICIPANT	\N	PRESENT	0
758763	757844	20026V	PARTICIPANT	\N	PRESENT	0
758764	757844	21055F	PARTICIPANT	\N	PRESENT	0
758765	757844	20142Y	PARTICIPANT	\N	PRESENT	0
758766	757844	20048C	PARTICIPANT	\N	PRESENT	0
758767	757844	20052X	PARTICIPANT	\N	PRESENT	0
758768	757844	20058E	PARTICIPANT	\N	PRESENT	0
758769	757844	20056C	PARTICIPANT	\N	PRESENT	0
758770	757844	20180F	PARTICIPANT	\N	PRESENT	0
758771	757844	20264J	PARTICIPANT	\N	PRESENT	0
758772	757844	19735D	PARTICIPANT	\N	PRESENT	0
758773	757844	14109K	PARTICIPANT	\N	PRESENT	0
758774	757844	14123H	PARTICIPANT	\N	PRESENT	0
758775	757844	11043H	PARTICIPANT	\N	PRESENT	0
758776	757844	21077M	PARTICIPANT	\N	PRESENT	0
758777	757844	19699S	PARTICIPANT	\N	EXCUSE	0
758780	757797	21085M	PARTICIPANT	\N	PRESENT	0
758781	757797	14038Y	PARTICIPANT	\N	PRESENT	0
758980	757796	19479G	PARTICIPANT	\N	PRESENT	0
758999	757796	08045X	PARTICIPANT	\N	PRESENT	0
759000	757796	17779H	PARTICIPANT	\N	PRESENT	0
759001	757796	21049H	PARTICIPANT	\N	PRESENT	0
759038	757796	20062A	PARTICIPANT	\N	PRESENT	0
759003	757796	20094J	PARTICIPANT	\N	PRESENT	0
759004	757796	21079P	PARTICIPANT	\N	PRESENT	0
759005	757796	17965H	PARTICIPANT	\N	PRESENT	0
759006	757796	18193Q	PARTICIPANT	\N	PRESENT	0
759007	757796	21094N	PARTICIPANT	\N	PRESENT	0
759008	757796	19683J	PARTICIPANT	\N	PRESENT	0
759009	757796	21046E	PARTICIPANT	\N	PRESENT	0
759010	757796	14195A	PARTICIPANT	\N	PRESENT	0
759011	757796	21045D	PARTICIPANT	\N	PRESENT	0
759012	757796	20076G	PARTICIPANT	\N	PRESENT	0
759013	757796	21091K	PARTICIPANT	\N	PRESENT	0
759014	757796	19798U	PARTICIPANT	\N	PRESENT	0
759015	757796	07029T	PARTICIPANT	\N	PRESENT	0
759016	757796	21063F	PARTICIPANT	\N	PRESENT	0
759017	757796	20090E	PARTICIPANT	\N	PRESENT	0
759018	757796	20118Y	PARTICIPANT	\N	PRESENT	0
759019	757796	21080G	PARTICIPANT	\N	PRESENT	0
759020	757796	14073Q	PARTICIPANT	\N	PRESENT	0
759021	757796	19563B	PARTICIPANT	\N	PRESENT	0
759022	757796	19703U	PARTICIPANT	\N	PRESENT	0
759023	757796	14042U	PARTICIPANT	\N	PRESENT	0
759024	757796	21042A	PARTICIPANT	\N	PRESENT	0
759025	757796	14223L	PARTICIPANT	\N	PRESENT	0
759026	757796	21053D	PARTICIPANT	\N	PRESENT	0
759027	757796	20148F	PARTICIPANT	\N	PRESENT	0
759028	757796	19553Y	PARTICIPANT	\N	PRESENT	0
759029	757796	20024T	PARTICIPANT	\N	PRESENT	0
759030	757796	21092L	PARTICIPANT	\N	PRESENT	0
759031	757796	19725B	PARTICIPANT	\N	PRESENT	0
759032	757796	21064G	PARTICIPANT	\N	PRESENT	0
759033	757796	19701S	PARTICIPANT	\N	PRESENT	0
759034	757796	19758L	PARTICIPANT	\N	PRESENT	0
759035	757796	19760E	PARTICIPANT	\N	PRESENT	0
759036	757796	19713W	PARTICIPANT	\N	PRESENT	0
759037	757796	04092N	PARTICIPANT	\N	PRESENT	0
759039	757796	20140W	PARTICIPANT	\N	PRESENT	0
759040	757796	14213J	PARTICIPANT	\N	PRESENT	0
759041	757796	14071N	PARTICIPANT	\N	PRESENT	0
759042	757796	21071F	PARTICIPANT	\N	PRESENT	0
759043	757796	21058J	PARTICIPANT	\N	PRESENT	0
759044	757796	20180F	PARTICIPANT	\N	PRESENT	0
759045	757796	21097R	PARTICIPANT	\N	PRESENT	0
759046	757796	21087P	PARTICIPANT	\N	PRESENT	0
759047	757796	19531S	PARTICIPANT	\N	PRESENT	0
759048	757796	21043B	PARTICIPANT	\N	PRESENT	0
759049	757796	07004J	PARTICIPANT	\N	PRESENT	0
759050	757796	14026U	PARTICIPANT	\N	PRESENT	0
759051	757796	19723Y	PARTICIPANT	\N	PRESENT	0
759052	757796	14069U	PARTICIPANT	\N	PRESENT	0
759053	757796	20096L	PARTICIPANT	\N	PRESENT	0
759054	757796	21089R	PARTICIPANT	\N	PRESENT	0
759055	757796	21081H	PARTICIPANT	\N	PRESENT	0
759056	757796	14083S	PARTICIPANT	\N	PRESENT	0
759057	757796	14217N	PARTICIPANT	\N	PRESENT	0
759058	757796	20104S	PARTICIPANT	\N	PRESENT	0
759059	757796	18395Y	PARTICIPANT	\N	PRESENT	0
759060	757796	19367Y	PARTICIPANT	\N	PRESENT	0
759061	757796	21095P	PARTICIPANT	\N	PRESENT	0
759062	757796	21068L	PARTICIPANT	\N	PRESENT	0
759063	757796	21039F	PARTICIPANT	\N	PRESENT	0
759064	757796	11048N	PARTICIPANT	\N	PRESENT	0
759065	757796	20070A	PARTICIPANT	\N	PRESENT	0
759066	757796	14147R	PARTICIPANT	\N	PRESENT	0
759067	757796	19782L	PARTICIPANT	\N	PRESENT	0
759068	757796	14033T	PARTICIPANT	\N	PRESENT	0
759069	757796	20026V	PARTICIPANT	\N	PRESENT	0
759070	757796	18083K	PARTICIPANT	\N	PRESENT	0
759071	757796	01058X	PARTICIPANT	\N	PRESENT	0
759072	757796	04045F	PARTICIPANT	\N	PRESENT	0
759073	757796	14215L	PARTICIPANT	\N	PRESENT	0
759074	757796	19575F	PARTICIPANT	\N	PRESENT	0
759075	757796	20116W	PARTICIPANT	\N	PRESENT	0
759076	757796	19629C	PARTICIPANT	\N	PRESENT	0
759077	757796	20082E	PARTICIPANT	\N	PRESENT	0
759078	757796	14089Y	PARTICIPANT	\N	PRESENT	0
759079	757796	19507S	PARTICIPANT	\N	PRESENT	0
759080	757796	19383Y	PARTICIPANT	\N	PRESENT	0
759081	757796	20132W	PARTICIPANT	\N	PRESENT	0
759082	757796	20172F	PARTICIPANT	\N	PRESENT	0
759094	757693	19367Y	PARTICIPANT	\N	PRESENT	0
759095	757693	21046E	PARTICIPANT	\N	PRESENT	0
759096	757693	21087P	PARTICIPANT	\N	PRESENT	0
759097	757693	19798U	PARTICIPANT	\N	PRESENT	0
759098	757693	19691J	PARTICIPANT	\N	PRESENT	0
759099	757693	14026U	PARTICIPANT	\N	PRESENT	0
759100	757693	20090E	PARTICIPANT	\N	PRESENT	0
759101	757693	19703U	PARTICIPANT	\N	PRESENT	0
759102	757693	21064G	PARTICIPANT	\N	PRESENT	0
759103	757693	20130U	PARTICIPANT	\N	PRESENT	0
759119	757693	14042U	PARTICIPANT	\N	PRESENT	0
759105	757693	14071N	PRESIDENT	0	PRESENT	0
759121	757693	18193Q	PARTICIPANT	\N	PRESENT	0
759122	757693	14281W	PARTICIPANT	\N	PRESENT	0
759123	757693	21097R	PARTICIPANT	\N	EXCUSE	0
759124	757693	19723Y	PARTICIPANT	\N	PRESENT	0
759131	757693	19760E	PARTICIPANT	\N	PRESENT	0
759132	757693	19758L	PARTICIPANT	\N	PRESENT	0
759133	757693	14213J	PARTICIPANT	\N	PRESENT	0
759134	757693	14223L	PARTICIPANT	\N	PRESENT	0
759168	757693	21045D	PARTICIPANT	\N	PRESENT	0
759170	757693	21081H	PARTICIPANT	\N	PRESENT	0
759175	757693	20140W	PARTICIPANT	\N	PRESENT	0
759176	757693	21071F	PARTICIPANT	\N	PRESENT	0
759177	757693	20148F	PARTICIPANT	\N	PRESENT	0
759178	757693	04092N	PARTICIPANT	\N	PRESENT	0
759179	757693	19679N	PARTICIPANT	\N	PRESENT	0
759180	757693	19569H	PARTICIPANT	\N	PRESENT	0
759185	757693	08061X	PARTICIPANT	\N	PRESENT	0
759186	757693	14195A	PARTICIPANT	\N	PRESENT	0
759216	757693	14217N	PARTICIPANT	\N	PRESENT	0
759261	757693	17779H	PARTICIPANT	\N	PRESENT	0
759262	757693	19683J	PARTICIPANT	\N	PRESENT	0
759263	757693	19553Y	PARTICIPANT	\N	PRESENT	0
759264	757693	17965H	PARTICIPANT	\N	PRESENT	0
759265	757693	21049H	PARTICIPANT	\N	PRESENT	0
759266	757693	21039F	PARTICIPANT	\N	PRESENT	0
759269	757693	20248J	PARTICIPANT	\N	PRESENT	0
759365	759364	20038A	PARTICIPANT	\N	PRESENT	0
760443	760442	14231L	PRESIDENT	0	PRESENT	0
760444	760442	21068L	PARTICIPANT	\N	PRESENT	0
748022	748021	08010L	PARTICIPANT	\N	PRESENT	0
748023	748021	20120S	PARTICIPANT	\N	PRESENT	0
748025	748024	08010L	PARTICIPANT	\N	PRESENT	0
749906	748110	20122U	PARTICIPANT	\N	PRESENT	0
749932	748110	19333N	PARTICIPANT	\N	PRESENT	0
749904	748110	99004R	PARTICIPANT	\N	PRESENT	0
749905	748110	20074E	PARTICIPANT	\N	PRESENT	0
748082	748077	20024T	PARTICIPANT	\N	PRESENT	0
749908	748110	11072N	PARTICIPANT	\N	PRESENT	0
748086	748085	12016W	PARTICIPANT	\N	PRESENT	0
748087	748085	20080C	PARTICIPANT	\N	PRESENT	0
749909	748110	19599P	PARTICIPANT	\N	PRESENT	0
749921	748110	20046A	PARTICIPANT	\N	PRESENT	0
749922	748110	19749K	PARTICIPANT	\N	PRESENT	0
749923	748110	14030Q	PARTICIPANT	\N	PRESENT	0
749924	748110	20090E	PARTICIPANT	\N	PRESENT	0
749925	748110	14215L	PARTICIPANT	\N	PRESENT	0
749926	748110	20914V	PARTICIPANT	\N	PRESENT	0
749927	748110	04047H	PARTICIPANT	\N	PRESENT	0
749928	748110	11012A	PARTICIPANT	\N	PRESENT	0
749929	748110	14073Q	PARTICIPANT	\N	PRESENT	0
749930	748110	20056C	PARTICIPANT	\N	PRESENT	0
749931	748110	97011G	PARTICIPANT	\N	PRESENT	0
749933	748110	19798U	PARTICIPANT	\N	PRESENT	0
749934	748110	14213J	PARTICIPANT	\N	PRESENT	0
749935	748110	20070A	PARTICIPANT	\N	PRESENT	0
749991	749990	14133K	PARTICIPANT	\N	PRESENT	0
749993	749992	19709B	PARTICIPANT	\N	PRESENT	0
749995	749994	20072C	PARTICIPANT	\N	PRESENT	0
749996	749994	14059S	PARTICIPANT	\N	PRESENT	0
752292	752291	14331P	PARTICIPANT	\N	PRESENT	0
752293	752291	20100N	PARTICIPANT	\N	PRESENT	0
752294	752291	19725B	PARTICIPANT	\N	PRESENT	0
753595	753594	14133K	PARTICIPANT	\N	PRESENT	0
753596	753594	17367Q	PARTICIPANT	\N	PRESENT	0
753597	753594	20042V	PARTICIPANT	\N	PRESENT	0
753598	753594	14255U	PARTICIPANT	\N	PRESENT	0
753599	753594	04042C	PARTICIPANT	\N	PRESENT	0
753600	753594	12028B	PARTICIPANT	\N	PRESENT	0
753601	753594	19721W	PRESIDENT	0	PRESENT	0
753602	753594	14267Y	PARTICIPANT	\N	PRESENT	0
753603	753594	11027H	PARTICIPANT	\N	PRESENT	0
753604	753594	11115U	PARTICIPANT	\N	PRESENT	0
753605	753594	21067K	PARTICIPANT	\N	PRESENT	0
753606	753594	07033P	PARTICIPANT	\N	PRESENT	0
753607	753594	14249W	PARTICIPANT	\N	PRESENT	0
753608	753594	17023S	PARTICIPANT	\N	PRESENT	0
753609	753594	19347U	PARTICIPANT	\N	PRESENT	0
753610	753594	08056B	PARTICIPANT	\N	PRESENT	0
753611	753594	19565D	PARTICIPANT	\N	PRESENT	0
753612	753594	98022P	PARTICIPANT	\N	PRESENT	0
753613	753594	11064N	PARTICIPANT	\N	PRESENT	0
753614	753594	20072C	PARTICIPANT	\N	PRESENT	0
753615	753594	20128B	PARTICIPANT	\N	PRESENT	0
753616	753594	14179A	PARTICIPANT	\N	PRESENT	0
753617	753594	19531S	PARTICIPANT	\N	PRESENT	0
753618	753594	14097Y	PARTICIPANT	\N	PRESENT	0
753619	753594	95041E	PARTICIPANT	\N	PRESENT	0
753620	753594	99004R	PARTICIPANT	\N	PRESENT	0
753621	753594	19709B	PARTICIPANT	\N	PRESENT	0
753622	753594	14037X	PARTICIPANT	\N	PRESENT	0
753623	753594	14059S	PARTICIPANT	\N	PRESENT	0
753624	753594	14251Q	PARTICIPANT	\N	PRESENT	0
753625	753594	14001X	PARTICIPANT	\N	PRESENT	0
753626	753594	20252E	PARTICIPANT	\N	PRESENT	0
753627	753594	21073H	PARTICIPANT	\N	PRESENT	0
753628	753594	08047A	PARTICIPANT	\N	PRESENT	0
753629	753594	14193X	PARTICIPANT	\N	PRESENT	0
753630	753594	19745F	PARTICIPANT	\N	PRESENT	0
753631	753594	21036C	PARTICIPANT	\N	PRESENT	0
753632	753594	19421M	PARTICIPANT	\N	PRESENT	0
753633	753594	19669L	PARTICIPANT	\N	PRESENT	0
753634	753594	20064C	PARTICIPANT	\N	PRESENT	0
753635	753594	21031W	PARTICIPANT	\N	PRESENT	0
753636	753594	21030V	PARTICIPANT	\N	PRESENT	0
753637	753594	14105F	PARTICIPANT	\N	EXCUSE	0
753638	753594	14211G	PARTICIPANT	\N	EXCUSE	0
753639	753594	08069G	PARTICIPANT	\N	EXCUSE	0
753640	753594	14191V	PARTICIPANT	\N	EXCUSE	0
753641	753594	01058X	PARTICIPANT	\N	EXCUSE	0
753762	753671	21046E	PARTICIPANT	\N	PRESENT	0
753763	753671	18193Q	PARTICIPANT	\N	PRESENT	0
753764	753671	21087P	PARTICIPANT	\N	PRESENT	0
753765	753671	21045D	PARTICIPANT	\N	PRESENT	0
753766	753671	19569H	PARTICIPANT	\N	PRESENT	0
753767	753671	14217N	PARTICIPANT	\N	PRESENT	0
753768	753671	14071N	PRESIDENT	0	PRESENT	0
753802	753671	19703U	PARTICIPANT	\N	PRESENT	0
753803	753671	19798U	PARTICIPANT	\N	PRESENT	0
753805	753671	20096L	PARTICIPANT	\N	PRESENT	0
753808	753671	19691J	PARTICIPANT	\N	PRESENT	0
753809	753671	21081H	PARTICIPANT	\N	PRESENT	0
753812	753671	04092N	PARTICIPANT	\N	PRESENT	0
753816	753671	20090E	PARTICIPANT	\N	EXCUSE	0
753827	753671	19657G	PARTICIPANT	\N	PRESENT	0
753828	753671	21049H	PARTICIPANT	\N	PRESENT	0
753829	753671	08061X	PARTICIPANT	\N	PRESENT	0
753830	753671	19758L	PARTICIPANT	\N	PRESENT	0
753831	753671	14026U	PARTICIPANT	\N	PRESENT	0
753840	753671	21097R	PARTICIPANT	\N	PRESENT	0
753862	753671	19553Y	PARTICIPANT	\N	PRESENT	0
753871	753671	19760E	PARTICIPANT	\N	PRESENT	0
753892	753671	21064G	PARTICIPANT	\N	PRESENT	0
754152	753671	14213J	PARTICIPANT	\N	PRESENT	0
755824	755823	20136B	PARTICIPANT	\N	PRESENT	0
755825	755823	19551W	PARTICIPANT	\N	PRESENT	0
755826	755823	21082J	PARTICIPANT	\N	PRESENT	0
755832	755831	20136B	PARTICIPANT	\N	PRESENT	0
757826	757825	14217N	PARTICIPANT	\N	PRESENT	0
757827	757825	19760E	PARTICIPANT	\N	PRESENT	0
757828	757825	14281W	PARTICIPANT	\N	PRESENT	0
757829	757825	14195A	PARTICIPANT	\N	PRESENT	0
757830	757825	20130U	PARTICIPANT	\N	PRESENT	0
758122	758121	19611R	PARTICIPANT	\N	PRESENT	0
758123	758121	21089R	PARTICIPANT	\N	PRESENT	0
758124	758121	21091K	PARTICIPANT	\N	PRESENT	0
758125	758121	19593H	PARTICIPANT	\N	PRESENT	0
758126	758121	14109K	PARTICIPANT	\N	PRESENT	1
758127	758121	20026V	PARTICIPANT	\N	PRESENT	1
758128	758121	20142Y	PARTICIPANT	\N	PRESENT	1
758129	758121	19954N	PARTICIPANT	\N	PRESENT	1
758130	758121	20114U	PARTICIPANT	\N	PRESENT	0
758131	758121	04047H	PARTICIPANT	\N	PRESENT	0
758140	757833	21091K	PARTICIPANT	\N	PRESENT	1
758141	757833	19611R	PARTICIPANT	\N	PRESENT	0
758142	757833	20142Y	PARTICIPANT	\N	PRESENT	1
758143	757833	14109K	PARTICIPANT	\N	PRESENT	1
758144	757833	19954N	PARTICIPANT	\N	PRESENT	1
758145	757833	21089R	PARTICIPANT	\N	PRESENT	0
758146	757833	20114U	PARTICIPANT	\N	PRESENT	0
758147	757833	04047H	PARTICIPANT	\N	PRESENT	1
758153	757736	19593H	PARTICIPANT	\N	PRESENT	0
758151	757736	21091K	PARTICIPANT	\N	PRESENT	0
758152	757736	21089R	PARTICIPANT	\N	PRESENT	0
758154	757736	19954N	PARTICIPANT	\N	PRESENT	0
758155	757736	20180F	PARTICIPANT	\N	PRESENT	0
758156	757736	14109K	PARTICIPANT	\N	PRESENT	0
758157	757737	19593H	PARTICIPANT	\N	PRESENT	0
758158	757737	21091K	PARTICIPANT	\N	PRESENT	0
758159	757737	14030Q	PARTICIPANT	\N	PRESENT	0
758160	757737	19954N	PARTICIPANT	\N	PRESENT	0
758161	757736	20114U	PARTICIPANT	\N	PRESENT	0
758162	757736	04047H	PARTICIPANT	\N	PRESENT	0
758163	757737	04047H	PARTICIPANT	\N	PRESENT	1
765704	765703	11074Q	PARTICIPANT	\N	PRESENT	0
765705	765703	19349W	PARTICIPANT	\N	PRESENT	0
765707	765706	19399H	PARTICIPANT	\N	PRESENT	0
767627	767626	20132W	PARTICIPANT	\N	PRESENT	0
767628	767626	14109K	PARTICIPANT	\N	PRESENT	0
767629	767626	14030Q	PARTICIPANT	\N	PRESENT	0
767721	767711	14031R	PARTICIPANT	\N	PRESENT	0
767727	767711	18395Y	PARTICIPANT	\N	PRESENT	0
767728	767711	11065P	PARTICIPANT	\N	PRESENT	0
767871	765403	11065P	PARTICIPANT	\N	PRESENT	0
767872	765403	20034V	PARTICIPANT	\N	PRESENT	0
767873	765403	14109K	PARTICIPANT	\N	PRESENT	0
767874	765403	19421M	PARTICIPANT	\N	PRESENT	0
767875	765403	19719D	PARTICIPANT	\N	PRESENT	0
767876	765403	19553Y	PARTICIPANT	\N	PRESENT	0
767877	765403	21041Y	PARTICIPANT	\N	PRESENT	0
767878	765403	14042U	PARTICIPANT	\N	PRESENT	0
747511	746026	99004R	PARTICIPANT	\N	PRESENT	0
747552	746026	12028B	PARTICIPANT	\N	PRESENT	0
747519	747513	20106U	PARTICIPANT	\N	PRESENT	0
747520	747513	20038A	PARTICIPANT	\N	PRESENT	0
747521	747513	20264J	PARTICIPANT	\N	PRESENT	0
747522	747513	20142Y	PARTICIPANT	\N	PRESENT	0
747523	747513	14109K	PARTICIPANT	\N	PRESENT	0
747524	747513	20980G	PARTICIPANT	\N	PRESENT	0
747525	747513	19335Q	PRESIDENT	0	PRESENT	0
747526	747513	20026V	PARTICIPANT	\N	PRESENT	0
747527	747513	19621T	PARTICIPANT	\N	PRESENT	0
747528	746026	14195A	PARTICIPANT	\N	PRESENT	0
747529	746026	19565D	PARTICIPANT	\N	PRESENT	0
747530	746026	20128B	PARTICIPANT	\N	PRESENT	0
747531	746026	19479G	PARTICIPANT	\N	PRESENT	0
747533	746026	08034U	PARTICIPANT	\N	PRESENT	0
747535	746026	04042C	PARTICIPANT	\N	PRESENT	0
747536	746026	14267Y	PARTICIPANT	\N	PRESENT	0
747537	746026	14255U	PARTICIPANT	\N	PRESENT	0
747539	746026	14331P	PARTICIPANT	\N	PRESENT	0
747542	746026	20064C	PARTICIPANT	\N	PRESENT	0
747544	746026	20042V	PARTICIPANT	\N	PRESENT	0
747545	746026	19651A	PARTICIPANT	\N	PRESENT	0
747546	746026	20024T	PARTICIPANT	\N	PRESENT	0
747547	746026	12041X	PARTICIPANT	\N	PRESENT	0
747549	746026	11066Q	PARTICIPANT	\N	PRESENT	0
747550	746026	98022P	PARTICIPANT	\N	PRESENT	0
747551	746026	20072C	PARTICIPANT	\N	PRESENT	0
747553	746026	19637C	PARTICIPANT	\N	PRESENT	0
747554	746026	14249W	PARTICIPANT	\N	PRESENT	0
747555	746026	14059S	PARTICIPANT	\N	PRESENT	0
747556	746026	97011G	PARTICIPANT	\N	PRESENT	0
747557	746026	14033T	PARTICIPANT	\N	PRESENT	0
747558	746026	19347U	PARTICIPANT	\N	PRESENT	0
747560	746026	19669L	PARTICIPANT	\N	PRESENT	0
747562	746026	20048C	PARTICIPANT	\N	PRESENT	0
747564	746026	20054A	PARTICIPANT	\N	PRESENT	0
747568	746026	14193X	PARTICIPANT	\N	PRESENT	0
747570	746026	14133K	PARTICIPANT	\N	PRESENT	0
747571	746026	19421M	PARTICIPANT	\N	PRESENT	0
747572	746026	19695N	PARTICIPANT	\N	PRESENT	0
747575	746026	08047A	PARTICIPANT	\N	PRESENT	0
747576	746026	07033P	PARTICIPANT	\N	PRESENT	0
747577	746026	17023S	PARTICIPANT	\N	PRESENT	0
747580	746026	16685X	PARTICIPANT	\N	PRESENT	0
747588	746026	11045K	PARTICIPANT	\N	PRESENT	0
747589	746026	11027H	PARTICIPANT	\N	PRESENT	0
747590	746026	19507S	PARTICIPANT	\N	PRESENT	0
747591	746026	19467C	PARTICIPANT	\N	PRESENT	0
747592	746026	20172F	PARTICIPANT	\N	PRESENT	0
747593	747534	20086J	PARTICIPANT	\N	PRESENT	0
747594	747534	20032T	PARTICIPANT	\N	PRESENT	0
747595	747534	01043Q	PRESIDENT	0	PRESENT	0
747596	747534	19545Y	PARTICIPANT	\N	PRESENT	0
747597	747534	20082E	PARTICIPANT	\N	PRESENT	0
747598	747534	19631V	PARTICIPANT	\N	PRESENT	0
747599	747534	20098N	PARTICIPANT	\N	PRESENT	0
747600	747534	14231L	PARTICIPANT	\N	PRESENT	0
747601	747534	20058E	PARTICIPANT	\N	PRESENT	0
747602	747534	14205J	PARTICIPANT	\N	PRESENT	0
747603	747534	11056N	PARTICIPANT	\N	PRESENT	0
747604	747534	19489J	PARTICIPANT	\N	PRESENT	0
747605	747534	19525U	PARTICIPANT	\N	PRESENT	0
747606	747534	20120S	PARTICIPANT	\N	PRESENT	0
747607	747534	14219Q	PARTICIPANT	\N	EXCUSE	0
747608	747534	20044X	PARTICIPANT	\N	EXCUSE	0
747609	747534	19399H	PARTICIPANT	\N	EXCUSE	0
747610	747534	11065P	PARTICIPANT	\N	EXCUSE	0
747611	747534	05008E	PARTICIPANT	\N	EXCUSE	0
747614	746026	14357A	PARTICIPANT	\N	PRESENT	0
747615	746026	20062A	PARTICIPANT	\N	PRESENT	0
747616	746026	20102Q	PARTICIPANT	\N	PRESENT	0
747617	746026	04047H	PARTICIPANT	\N	PRESENT	0
747618	746026	20056C	PARTICIPANT	\N	PRESENT	0
747619	746026	19782L	PARTICIPANT	\N	PRESENT	0
747620	746026	11064N	PARTICIPANT	\N	PRESENT	0
747621	746026	11054L	PARTICIPANT	\N	PRESENT	0
747622	746026	01062T	PARTICIPANT	\N	PRESENT	0
747623	746026	08010L	PARTICIPANT	\N	PRESENT	0
747624	746026	19699S	PARTICIPANT	\N	PRESENT	0
747625	746026	08069G	PARTICIPANT	\N	PRESENT	0
747626	746026	14038Y	PARTICIPANT	\N	PRESENT	0
747628	746026	14030Q	PARTICIPANT	\N	PRESENT	0
747629	746026	08061X	PARTICIPANT	\N	PRESENT	0
747631	746026	14215L	PARTICIPANT	\N	PRESENT	0
747633	746026	20034V	PARTICIPANT	\N	PRESENT	0
747634	746026	19719D	PARTICIPANT	\N	PRESENT	0
747635	746026	14097Y	PARTICIPANT	\N	PRESENT	0
747637	746026	19251M	PARTICIPANT	\N	PRESENT	0
747638	746026	19593H	PARTICIPANT	\N	PRESENT	0
747639	746026	14069U	PARTICIPANT	\N	PRESENT	0
747640	746026	20066E	PARTICIPANT	\N	PRESENT	0
747642	746026	19319Q	PARTICIPANT	\N	PRESENT	0
747643	746026	01024M	PARTICIPANT	\N	PRESENT	0
747644	746026	07029T	PARTICIPANT	\N	PRESENT	0
747645	746026	04035D	PARTICIPANT	\N	PRESENT	0
747646	746026	05008E	PARTICIPANT	\N	PRESENT	0
747647	746026	14147R	PARTICIPANT	\N	PRESENT	0
747649	746026	20076G	PARTICIPANT	\N	PRESENT	0
747650	746026	14109K	PARTICIPANT	\N	PRESENT	0
747651	746026	20100N	PARTICIPANT	\N	PRESENT	0
747652	746026	20032T	PARTICIPANT	\N	PRESENT	0
747653	746026	20142Y	PARTICIPANT	\N	PRESENT	0
747654	746026	20120S	PARTICIPANT	\N	PRESENT	0
747655	746026	20052X	PARTICIPANT	\N	PRESENT	0
747656	746026	19687N	PARTICIPANT	\N	PRESENT	0
747658	746026	19577H	PARTICIPANT	\N	PRESENT	0
747659	746026	14053L	PARTICIPANT	\N	PRESENT	0
747660	746026	19441R	PARTICIPANT	\N	PRESENT	0
747661	746026	08018U	PARTICIPANT	\N	PRESENT	0
747662	746026	20082E	PARTICIPANT	\N	PRESENT	0
747663	746026	19713W	PARTICIPANT	\N	PRESENT	0
747664	746026	01028R	PARTICIPANT	\N	PRESENT	0
747665	746026	14259Y	PARTICIPANT	\N	PRESENT	0
747666	746026	20090E	PARTICIPANT	\N	PRESENT	0
747667	746026	19569H	PARTICIPANT	\N	PRESENT	0
747668	746026	19758L	PARTICIPANT	\N	PRESENT	0
747669	746026	14207L	PARTICIPANT	\N	PRESENT	0
747674	746026	14217N	PARTICIPANT	\N	PRESENT	0
747672	746026	20092G	PARTICIPANT	\N	PRESENT	0
747673	746026	19709B	PARTICIPANT	\N	PRESENT	0
747675	746026	04045F	PARTICIPANT	\N	PRESENT	0
747720	746027	95063L	PARTICIPANT	\N	PRESENT	0
747753	746027	20124W	PARTICIPANT	\N	PRESENT	0
747722	746027	12041X	PARTICIPANT	\N	PRESENT	0
747723	746027	20076G	PARTICIPANT	\N	PRESENT	0
747724	746027	19347U	PARTICIPANT	\N	PRESENT	0
747725	746027	19669L	PARTICIPANT	\N	PRESENT	0
747751	746027	01062T	PARTICIPANT	\N	PRESENT	0
747727	746027	14193X	PARTICIPANT	\N	PRESENT	0
747728	746027	04042C	PARTICIPANT	\N	PRESENT	0
747729	746027	14097Y	PARTICIPANT	\N	PRESENT	0
747730	746027	20090E	PARTICIPANT	\N	PRESENT	0
747731	746027	20104S	PARTICIPANT	\N	PRESENT	0
747732	746027	08047A	PARTICIPANT	\N	PRESENT	0
747733	746027	19782L	PARTICIPANT	\N	PRESENT	0
747734	746027	11027H	PARTICIPANT	\N	PRESENT	0
747735	746027	20100N	PARTICIPANT	\N	PRESENT	0
747736	746027	19565D	PARTICIPANT	\N	PRESENT	0
747737	746027	19758L	PARTICIPANT	\N	PRESENT	0
747738	746027	12028B	PARTICIPANT	\N	PRESENT	0
747739	746027	98022P	PARTICIPANT	\N	PRESENT	0
747740	746027	14267Y	PARTICIPANT	\N	PRESENT	0
747741	746027	19421M	PARTICIPANT	\N	PRESENT	0
747742	746027	08034U	PARTICIPANT	\N	PRESENT	0
747743	746027	19709B	PARTICIPANT	\N	PRESENT	0
747744	746027	19447X	PARTICIPANT	\N	PRESENT	0
747745	746027	11066Q	PARTICIPANT	\N	PRESENT	0
747746	746027	05008E	PARTICIPANT	\N	PRESENT	0
747747	746027	20142Y	PARTICIPANT	\N	PRESENT	0
747748	746027	20072C	PARTICIPANT	\N	PRESENT	0
747749	746027	20042V	PARTICIPANT	\N	PRESENT	0
747750	746027	19719D	PARTICIPANT	\N	PRESENT	0
747752	746027	20122U	PARTICIPANT	\N	PRESENT	0
747754	746027	11054L	PARTICIPANT	\N	PRESENT	0
747755	746027	20128B	PARTICIPANT	\N	PRESENT	0
747756	746027	20064C	PARTICIPANT	\N	PRESENT	0
747757	746027	14187A	PARTICIPANT	\N	PRESENT	0
747758	746027	14133K	PARTICIPANT	\N	PRESENT	0
747759	746027	14059S	PARTICIPANT	\N	PRESENT	0
747760	746027	14249W	PARTICIPANT	\N	PRESENT	0
741949	740612	19713W	PARTICIPANT	\N	PRESENT	0
741950	740612	17637T	PARTICIPANT	\N	PRESENT	0
741951	740612	01025N	PARTICIPANT	\N	PRESENT	0
741952	740612	01024M	PARTICIPANT	\N	PRESENT	0
742518	742272	98022P	PARTICIPANT	\N	PRESENT	0
742519	742272	14267Y	PARTICIPANT	\N	PRESENT	0
742520	742272	11064N	PARTICIPANT	\N	PRESENT	0
742521	742272	11083R	PARTICIPANT	\N	PRESENT	0
742522	742272	19583F	PARTICIPANT	\N	PRESENT	0
742523	742272	14255U	PARTICIPANT	\N	PRESENT	0
742524	742272	17023S	PARTICIPANT	\N	PRESENT	0
742525	742272	95041E	PARTICIPANT	\N	PRESENT	0
742526	742272	14211G	PARTICIPANT	\N	PRESENT	0
742528	740835	01057W	PARTICIPANT	\N	PRESENT	0
743533	743379	19768N	PARTICIPANT	\N	PRESENT	0
743534	743379	19515S	PARTICIPANT	\N	PRESENT	0
743535	743379	19782L	PARTICIPANT	\N	PRESENT	0
743536	743379	20092G	PARTICIPANT	\N	PRESENT	0
743538	743379	19441R	PARTICIPANT	\N	PRESENT	0
743539	743379	20094J	PARTICIPANT	\N	PRESENT	0
743540	743379	04045F	PARTICIPANT	\N	PRESENT	0
743541	743379	19631V	PARTICIPANT	\N	PRESENT	0
743542	743379	20104S	PARTICIPANT	\N	PRESENT	0
743543	743379	11099A	PARTICIPANT	\N	PRESENT	0
743544	743379	19575F	PARTICIPANT	\N	PRESENT	0
743545	743379	19369B	PARTICIPANT	\N	PRESENT	0
743546	743379	19467C	PARTICIPANT	\N	PRESENT	0
743547	743379	20034V	PARTICIPANT	\N	PRESENT	0
743548	743379	14187A	PARTICIPANT	\N	PRESENT	0
743549	743379	20144B	PARTICIPANT	\N	PRESENT	0
743550	743379	19695N	PARTICIPANT	\N	PRESENT	0
743551	743379	14033T	PARTICIPANT	\N	PRESENT	0
743552	743379	11090Q	PRESIDENT	0	PRESENT	0
743553	743379	20054A	PARTICIPANT	\N	PRESENT	0
743554	743379	14205J	PARTICIPANT	\N	PRESENT	0
743555	743379	20062A	PARTICIPANT	\N	PRESENT	0
743556	743379	19507S	PARTICIPANT	\N	PRESENT	0
743557	743379	20298U	PARTICIPANT	\N	PRESENT	0
743558	743379	14207L	PARTICIPANT	\N	PRESENT	0
743559	743379	14257W	PARTICIPANT	\N	PRESENT	0
743560	743379	19383Y	PARTICIPANT	\N	EXCUSE	0
743561	743379	20018V	PARTICIPANT	\N	EXCUSE	0
743562	740617	19687N	PARTICIPANT	\N	PRESENT	0
743563	740617	20092G	PARTICIPANT	\N	PRESENT	0
743564	740617	19503N	PARTICIPANT	\N	PRESENT	0
743616	740640	11031D	PARTICIPANT	\N	PRESENT	0
743617	740640	19760E	PARTICIPANT	\N	PRESENT	0
743618	740640	19758L	PARTICIPANT	\N	PRESENT	0
743619	740640	11077T	PARTICIPANT	\N	PRESENT	0
743620	740640	20088L	PARTICIPANT	\N	PRESENT	0
743621	740640	19503N	PARTICIPANT	\N	PRESENT	0
743622	740640	20092G	PARTICIPANT	\N	PRESENT	0
743623	740640	20134Y	PARTICIPANT	\N	PRESENT	0
743624	740640	20110Q	PARTICIPANT	\N	PRESENT	0
743625	740640	20128B	PARTICIPANT	\N	PRESENT	0
743626	740640	19301E	PARTICIPANT	\N	PRESENT	0
743627	740640	08061X	PARTICIPANT	\N	PRESENT	0
743628	740640	04045F	PARTICIPANT	\N	PRESENT	0
743629	740640	11012A	PARTICIPANT	\N	PRESENT	0
743630	740640	20116W	PARTICIPANT	\N	PRESENT	0
743631	740640	07004J	PARTICIPANT	\N	PRESENT	0
743632	740640	20032T	PARTICIPANT	\N	PRESENT	0
743633	740640	20172F	PARTICIPANT	\N	PRESENT	0
743634	740640	20026V	PARTICIPANT	\N	PRESENT	0
743635	740640	10015M	PARTICIPANT	\N	PRESENT	0
743636	740640	14215L	PARTICIPANT	\N	PRESENT	0
743637	740640	20080C	PARTICIPANT	\N	PRESENT	0
743638	740640	19447X	PARTICIPANT	\N	PRESENT	0
743639	740640	19723Y	PARTICIPANT	\N	PRESENT	0
743640	740640	14187A	PARTICIPANT	\N	PRESENT	0
743641	740640	14217N	PARTICIPANT	\N	PRESENT	0
743642	740640	20124W	PARTICIPANT	\N	PRESENT	0
743643	740640	14179A	PARTICIPANT	\N	PRESENT	0
743644	740640	20046A	PARTICIPANT	\N	PRESENT	0
743645	740640	14221J	PARTICIPANT	\N	PRESENT	0
743646	740640	19057M	PARTICIPANT	\N	PRESENT	0
743647	740640	14083S	PARTICIPANT	\N	PRESENT	0
743648	740640	20054A	PARTICIPANT	\N	PRESENT	0
743678	740641	20124W	PARTICIPANT	\N	PRESENT	0
743650	740641	19687N	PARTICIPANT	\N	PRESENT	0
743682	740641	04047H	PARTICIPANT	\N	PRESENT	0
743652	740641	11077T	PARTICIPANT	\N	PRESENT	0
743653	740641	20088L	PARTICIPANT	\N	PRESENT	0
743683	740641	20110Q	PARTICIPANT	\N	PRESENT	0
743684	740641	19447X	PARTICIPANT	\N	PRESENT	0
743685	740641	14215L	PARTICIPANT	\N	PRESENT	0
743657	740641	20128B	PARTICIPANT	\N	PRESENT	0
743658	740641	19301E	PARTICIPANT	\N	PRESENT	0
743659	740641	08061X	PARTICIPANT	\N	PRESENT	0
743660	740641	04045F	PARTICIPANT	\N	PRESENT	0
743679	740641	20096L	PARTICIPANT	\N	PRESENT	0
743662	740641	07004J	PARTICIPANT	\N	PRESENT	0
743680	740641	14187A	PARTICIPANT	\N	PRESENT	0
743681	740641	20116W	PARTICIPANT	\N	PRESENT	0
743614	740640	19719D	PARTICIPANT	\N	PRESENT	0
743615	740640	19687N	PARTICIPANT	\N	PRESENT	0
743686	740641	20032T	PARTICIPANT	\N	PRESENT	0
743666	740641	10015M	PARTICIPANT	\N	PRESENT	0
743687	740641	14071N	PARTICIPANT	\N	PRESENT	0
743688	740641	20054A	PARTICIPANT	\N	PRESENT	0
743689	740641	20180F	PARTICIPANT	\N	PRESENT	0
743690	740641	14217N	PARTICIPANT	\N	PRESENT	0
743691	740641	14033T	PARTICIPANT	\N	PRESENT	0
743692	740641	14053L	PARTICIPANT	\N	PRESENT	0
743693	740641	20046A	PARTICIPANT	\N	PRESENT	0
743674	740641	14221J	PARTICIPANT	\N	PRESENT	0
743694	740641	19057M	PARTICIPANT	\N	PRESENT	0
743695	740641	04033B	PARTICIPANT	\N	PRESENT	0
743677	740641	95063L	PARTICIPANT	\N	PRESENT	0
743696	740641	19723Y	PARTICIPANT	\N	PRESENT	0
743697	740641	14069U	PARTICIPANT	\N	PRESENT	0
743698	740641	20090E	PARTICIPANT	\N	PRESENT	0
743699	740641	20062A	PARTICIPANT	\N	PRESENT	0
743700	740641	14213J	PARTICIPANT	\N	PRESENT	0
743701	740641	19782L	PARTICIPANT	\N	PRESENT	0
743702	740641	18083K	PARTICIPANT	\N	PRESENT	0
743703	740641	17737W	PARTICIPANT	\N	PRESENT	0
743716	743705	14225N	PRESIDENT	0	PRESENT	0
743717	743705	11048N	PARTICIPANT	\N	PRESENT	0
743718	743705	20914V	PARTICIPANT	\N	PRESENT	0
743719	743705	99004R	PARTICIPANT	\N	PRESENT	0
743720	743705	11074Q	PARTICIPANT	\N	PRESENT	0
743721	743705	20126Y	PARTICIPANT	\N	PRESENT	0
743723	743705	01048V	PARTICIPANT	\N	PRESENT	0
743729	743705	20070A	PARTICIPANT	\N	PRESENT	0
743750	743705	20080C	PARTICIPANT	\N	PRESENT	0
743754	740642	99004R	PARTICIPANT	\N	PRESENT	0
743755	740642	19699S	PARTICIPANT	\N	PRESENT	0
743756	740642	20052X	PARTICIPANT	\N	PRESENT	0
743757	740642	20132W	PARTICIPANT	\N	PRESENT	0
743758	740642	14211G	PARTICIPANT	\N	PRESENT	0
743759	740642	19643A	PARTICIPANT	\N	PRESENT	0
743760	740642	20142Y	PARTICIPANT	\N	PRESENT	0
743761	740642	04047H	PARTICIPANT	\N	PRESENT	0
743762	740642	14021P	PARTICIPANT	\N	PRESENT	0
743763	740642	04085P	PARTICIPANT	\N	PRESENT	0
743764	740642	19715Y	PARTICIPANT	\N	PRESENT	0
743765	740642	11067R	PARTICIPANT	\N	PRESENT	0
743766	740642	19683J	PARTICIPANT	\N	PRESENT	0
743767	740642	11043H	PARTICIPANT	\N	PRESENT	0
743768	740642	19295A	PARTICIPANT	\N	PRESENT	0
743769	740642	08073C	PARTICIPANT	\N	PRESENT	0
743770	740642	14229S	PARTICIPANT	\N	PRESENT	0
743771	740642	19503N	PARTICIPANT	\N	PRESENT	0
743772	740642	20032T	PARTICIPANT	\N	PRESENT	0
743773	740642	11109J	PARTICIPANT	\N	PRESENT	0
743774	740642	20098N	PARTICIPANT	\N	PRESENT	0
743775	740642	11072N	PARTICIPANT	\N	PRESENT	0
743776	740642	19611R	PARTICIPANT	\N	PRESENT	0
743777	740642	20038A	PARTICIPANT	\N	PRESENT	0
743778	740642	20030R	PARTICIPANT	\N	PRESENT	0
743779	740642	20026V	PARTICIPANT	\N	PRESENT	0
743780	740642	20082E	PARTICIPANT	\N	PRESENT	0
743781	740642	19301E	PARTICIPANT	\N	PRESENT	0
743782	740642	11045K	PARTICIPANT	\N	PRESENT	0
743783	740642	19251M	PARTICIPANT	\N	PRESENT	0
743784	740642	20088L	PARTICIPANT	\N	PRESENT	0
743786	740642	14123H	PARTICIPANT	\N	PRESENT	0
743787	740642	20264J	PARTICIPANT	\N	PRESENT	0
743788	740642	20034V	PARTICIPANT	\N	PRESENT	0
743790	740642	19527W	PARTICIPANT	\N	PRESENT	0
760447	760442	19531S	PARTICIPANT	\N	PRESENT	0
760448	760442	20062A	PARTICIPANT	\N	PRESENT	0
760449	760442	20084G	PARTICIPANT	\N	PRESENT	0
760450	760442	14281W	PARTICIPANT	\N	PRESENT	0
760451	760442	14069U	PARTICIPANT	\N	PRESENT	0
760452	760442	21070E	PARTICIPANT	\N	PRESENT	0
760453	760442	19826F	PARTICIPANT	\N	PRESENT	0
760454	760442	14053L	PARTICIPANT	\N	PRESENT	0
760455	760442	20102Q	PARTICIPANT	\N	PRESENT	0
760456	760442	20110Q	PARTICIPANT	\N	PRESENT	0
760457	760442	20022R	PARTICIPANT	\N	PRESENT	0
760458	760442	20090E	PARTICIPANT	\N	PRESENT	0
760459	760442	05012A	PARTICIPANT	\N	PRESENT	0
760460	760442	20032T	PARTICIPANT	\N	PRESENT	0
760461	760442	19673G	PARTICIPANT	\N	EXCUSE	0
760829	760828	21072G	PARTICIPANT	\N	PRESENT	0
760831	760830	21072G	PARTICIPANT	\N	PRESENT	0
760833	760832	21072G	PARTICIPANT	\N	PRESENT	0
760835	760834	20024T	PARTICIPANT	\N	PRESENT	0
760837	760836	20024T	PARTICIPANT	\N	PRESENT	0
761126	761029	19667J	PARTICIPANT	\N	EXCUSE	0
761127	761029	21072G	PARTICIPANT	\N	PRESENT	0
761132	761131	20062A	PARTICIPANT	\N	PRESENT	0
761133	761131	20134Y	PARTICIPANT	\N	PRESENT	0
761185	761184	19479G	PARTICIPANT	\N	PRESENT	0
761187	761186	19479G	PARTICIPANT	\N	PRESENT	0
761190	761189	14331P	PARTICIPANT	\N	PRESENT	0
761273	760695	20090E	PARTICIPANT	\N	PRESENT	0
761274	760695	19569H	PARTICIPANT	\N	PRESENT	0
761276	761275	20114U	PARTICIPANT	\N	PRESENT	0
761277	761275	14215L	PARTICIPANT	\N	PRESENT	0
761278	760695	21081H	PARTICIPANT	\N	PRESENT	0
761279	760695	18193Q	PARTICIPANT	\N	PRESENT	0
761280	760695	19691J	PARTICIPANT	\N	PRESENT	0
761295	760695	14281W	PARTICIPANT	\N	PRESENT	0
761296	760695	19798U	PARTICIPANT	\N	PRESENT	0
761302	760695	14071N	PRESIDENT	0	PRESENT	0
761306	760695	14042U	PARTICIPANT	\N	PRESENT	0
761315	760695	14026U	PARTICIPANT	\N	PRESENT	0
761329	760695	21071F	PARTICIPANT	\N	PRESENT	0
761330	760695	21064G	PARTICIPANT	\N	PRESENT	0
761341	760695	19723Y	PARTICIPANT	\N	PRESENT	0
761343	760695	19679N	PARTICIPANT	\N	PRESENT	0
761350	760695	01034P	PARTICIPANT	\N	PRESENT	0
761352	760695	20130U	PARTICIPANT	\N	PRESENT	0
761355	760695	14213J	PARTICIPANT	\N	PRESENT	0
761359	760695	21087P	PARTICIPANT	\N	PRESENT	0
761360	760695	21046E	PARTICIPANT	\N	PRESENT	0
761371	760695	14217N	PARTICIPANT	\N	PRESENT	0
761372	760695	08061X	PARTICIPANT	\N	PRESENT	0
761373	760695	19683J	PARTICIPANT	\N	PRESENT	0
761374	760695	19758L	PARTICIPANT	\N	PRESENT	0
761376	760695	20096L	PARTICIPANT	\N	PRESENT	0
761384	760765	21057H	PARTICIPANT	\N	EXCUSE	0
761499	760695	19760E	PARTICIPANT	\N	PRESENT	0
761562	761561	14215L	PARTICIPANT	\N	PRESENT	0
761569	757751	14021P	PARTICIPANT	\N	PRESENT	1
761570	757751	08012N	PARTICIPANT	\N	PRESENT	0
761571	757751	11043H	PARTICIPANT	\N	PRESENT	1
761572	757752	08012N	PARTICIPANT	\N	PRESENT	0
761573	757752	11043H	PARTICIPANT	\N	PRESENT	1
761574	757753	08012N	PARTICIPANT	\N	PRESENT	0
761575	757753	11043H	PARTICIPANT	\N	PRESENT	1
761594	757835	20058E	PARTICIPANT	\N	PRESENT	0
761595	761030	11048N	PARTICIPANT	\N	PRESENT	0
761601	761599	11110B	PARTICIPANT	\N	PRESENT	0
761598	761596	20024T	PARTICIPANT	\N	PRESENT	0
761600	761599	20070A	PARTICIPANT	\N	PRESENT	0
761603	761602	20070A	PARTICIPANT	\N	PRESENT	0
761604	761602	11110B	PARTICIPANT	\N	PRESENT	0
761606	761605	20070A	PARTICIPANT	\N	PRESENT	0
761607	761605	11110B	PARTICIPANT	\N	PRESENT	0
761609	761608	11048N	PARTICIPANT	\N	PRESENT	0
760445	760442	14151M	PARTICIPANT	\N	PRESENT	0
760446	760442	08012N	PARTICIPANT	\N	PRESENT	0
761611	761610	11048N	PARTICIPANT	\N	PRESENT	0
761613	761612	11048N	PARTICIPANT	\N	PRESENT	0
761925	761919	20026V	PARTICIPANT	\N	EXCUSE	0
761926	761919	20018V	PARTICIPANT	\N	EXCUSE	0
761927	761919	21063F	PARTICIPANT	\N	PRESENT	0
761928	761919	19798U	PARTICIPANT	\N	EXCUSE	0
761929	761919	20044X	PARTICIPANT	\N	EXCUSE	0
761930	761919	20066E	PARTICIPANT	\N	EXCUSE	0
761932	761919	20068G	PARTICIPANT	\N	PRESENT	0
761933	761919	20286Q	PARTICIPANT	\N	EXCUSE	0
761934	761919	21041Y	PARTICIPANT	\N	EXCUSE	0
761935	761919	20106U	PARTICIPANT	\N	PRESENT	0
761936	761919	20050V	PARTICIPANT	\N	EXCUSE	0
761938	761919	20132W	PARTICIPANT	\N	EXCUSE	0
761940	761919	20082E	PARTICIPANT	\N	EXCUSE	0
761943	761919	11070L	PARTICIPANT	\N	PRESENT	0
761944	761919	19399H	PARTICIPANT	\N	EXCUSE	0
762253	761563	20036X	PARTICIPANT	\N	EXCUSE	0
762254	761564	20036X	PARTICIPANT	\N	EXCUSE	0
762296	761589	19565D	PARTICIPANT	\N	EXCUSE	0
762297	761711	14259Y	PARTICIPANT	\N	PRESENT	0
762298	761711	11043H	PARTICIPANT	\N	PRESENT	0
762299	761711	18083K	PARTICIPANT	\N	PRESENT	0
762300	761711	19533U	PARTICIPANT	\N	PRESENT	0
762301	761183	07029T	PARTICIPANT	\N	EXCUSE	0
762302	761183	20050V	PARTICIPANT	\N	EXCUSE	0
762303	761183	14225N	PRESIDENT	0	PRESENT	0
762304	761711	21070E	PARTICIPANT	\N	PRESENT	0
762305	761711	04047H	PARTICIPANT	\N	PRESENT	0
762306	761183	19335Q	PARTICIPANT	\N	EXCUSE	0
762307	761711	20026V	PARTICIPANT	\N	PRESENT	0
762308	761711	19954N	PARTICIPANT	\N	PRESENT	0
762309	761711	20090E	PARTICIPANT	\N	PRESENT	0
762310	761183	14327T	PARTICIPANT	\N	PRESENT	0
762311	761183	20116W	PARTICIPANT	\N	PRESENT	0
762312	761711	21078N	PARTICIPANT	\N	PRESENT	0
762313	761711	19111A	PARTICIPANT	\N	PRESENT	0
762314	761711	21058J	PARTICIPANT	\N	PRESENT	0
762315	761711	20180F	PARTICIPANT	\N	PRESENT	0
762316	761711	14021P	PARTICIPANT	\N	PRESENT	0
762317	761711	19649G	PARTICIPANT	\N	PRESENT	0
762318	761183	20044X	PARTICIPANT	\N	PRESENT	0
762319	761711	20030R	PARTICIPANT	\N	PRESENT	0
762320	761183	19399H	PARTICIPANT	\N	PRESENT	0
762321	761711	20088L	PARTICIPANT	\N	PRESENT	0
762322	761183	19667J	PARTICIPANT	\N	PRESENT	0
762323	761711	19673G	PARTICIPANT	\N	PRESENT	0
762324	761711	19621T	PARTICIPANT	\N	PRESENT	0
762325	761711	21044C	PARTICIPANT	\N	PRESENT	0
762326	761711	10015M	PARTICIPANT	\N	PRESENT	0
762327	761183	19573D	PARTICIPANT	\N	PRESENT	0
762328	761183	19479G	PARTICIPANT	\N	PRESENT	0
762329	761711	14053L	PARTICIPANT	\N	PRESENT	0
762330	761183	11040E	PARTICIPANT	\N	PRESENT	0
762331	761183	14331P	PARTICIPANT	\N	PRESENT	0
762332	761711	21060C	PARTICIPANT	\N	PRESENT	0
762333	761711	11027H	PARTICIPANT	\N	PRESENT	0
762334	761183	19349W	PARTICIPANT	\N	PRESENT	0
762335	761711	21034A	PARTICIPANT	\N	PRESENT	0
762336	761183	19723Y	PARTICIPANT	\N	PRESENT	0
762337	761183	19711U	PARTICIPANT	\N	PRESENT	0
762338	761711	21071F	PARTICIPANT	\N	PRESENT	0
762339	761183	20126Y	PARTICIPANT	\N	PRESENT	0
762340	761711	21088Q	PARTICIPANT	\N	PRESENT	0
762341	761711	21091K	PARTICIPANT	\N	PRESENT	0
762342	761711	20134Y	PARTICIPANT	\N	PRESENT	0
762343	761711	20110Q	PARTICIPANT	\N	PRESENT	0
762344	761711	21094N	PARTICIPANT	\N	PRESENT	0
762345	761711	19585H	PARTICIPANT	\N	PRESENT	0
762346	761711	21062E	PARTICIPANT	\N	PRESENT	0
762347	761711	19782L	PARTICIPANT	\N	PRESENT	0
762348	761183	11070L	PARTICIPANT	\N	PRESENT	0
762349	761711	19629C	PARTICIPANT	\N	PRESENT	0
762350	761711	20100N	PARTICIPANT	\N	PRESENT	0
762351	761711	14055N	PARTICIPANT	\N	PRESENT	0
762352	761711	20068G	PARTICIPANT	\N	PRESENT	0
762353	761711	08061X	PARTICIPANT	\N	PRESENT	0
762354	761711	19697Q	PARTICIPANT	\N	PRESENT	0
762355	761183	11048N	PARTICIPANT	\N	PRESENT	0
762356	761183	19687N	PARTICIPANT	\N	PRESENT	0
762357	761183	11053K	PARTICIPANT	\N	PRESENT	0
762358	761183	19545Y	PARTICIPANT	\N	PRESENT	0
762359	761711	21040X	PARTICIPANT	\N	PRESENT	0
762360	761711	08018U	PARTICIPANT	\N	PRESENT	0
762361	761183	21048G	PARTICIPANT	\N	PRESENT	0
762362	761711	21073H	PARTICIPANT	\N	PRESENT	0
740704	740700	04043D	PARTICIPANT	\N	PRESENT	0
740705	740700	01034P	PARTICIPANT	\N	PRESENT	1
741083	740832	14327T	PARTICIPANT	\N	PRESENT	0
741084	740832	14083S	PARTICIPANT	\N	PRESENT	0
741085	740832	11048N	PARTICIPANT	\N	PRESENT	0
741086	740832	19711U	PARTICIPANT	\N	PRESENT	0
741087	740832	20252E	PARTICIPANT	\N	PRESENT	0
741088	740832	19531S	PARTICIPANT	\N	PRESENT	0
741089	740832	08009T	PARTICIPANT	\N	PRESENT	0
741090	740832	12016W	PARTICIPANT	\N	PRESENT	0
741091	740832	20080C	PARTICIPANT	\N	PRESENT	0
741092	740832	14225N	PRESIDENT	0	PRESENT	0
741093	740832	19671E	PARTICIPANT	\N	PRESENT	0
741094	740832	07029T	PARTICIPANT	\N	EXCUSE	0
741095	740753	14001X	PARTICIPANT	\N	PRESENT	0
741096	740753	05008E	PARTICIPANT	\N	PRESENT	0
741097	740753	95063L	PARTICIPANT	\N	PRESENT	0
741098	740753	20110Q	PARTICIPANT	\N	PRESENT	0
741100	740753	19673G	PARTICIPANT	\N	PRESENT	0
741101	740753	17737W	PARTICIPANT	\N	PRESENT	0
741102	740753	20108W	PARTICIPANT	\N	PRESENT	0
741103	740753	14107H	PARTICIPANT	\N	PRESENT	0
741104	740753	14069U	PARTICIPANT	\N	PRESENT	0
742620	740161	11031D	PARTICIPANT	\N	EXCUSE	0
741931	740612	14109K	PARTICIPANT	\N	PRESENT	0
741932	740612	19479G	PARTICIPANT	\N	PRESENT	0
741933	740612	95041E	PARTICIPANT	\N	PRESENT	0
741934	740612	19691J	PARTICIPANT	\N	PRESENT	0
741935	740833	19647E	PARTICIPANT	\N	PRESENT	0
741936	740833	08034U	PARTICIPANT	\N	PRESENT	0
741937	740833	11012A	PARTICIPANT	\N	PRESENT	0
741938	740833	19349W	PARTICIPANT	\N	PRESENT	0
741939	740833	19762G	PARTICIPANT	\N	PRESENT	0
741940	740612	20086J	PARTICIPANT	\N	PRESENT	0
741941	740612	14193X	PARTICIPANT	\N	PRESENT	0
741942	740612	19699S	PARTICIPANT	\N	PRESENT	0
741943	740612	04047H	PARTICIPANT	\N	PRESENT	0
741944	740612	20042V	PARTICIPANT	\N	PRESENT	0
741946	740612	18193Q	PARTICIPANT	\N	PRESENT	0
741948	740612	14073Q	PARTICIPANT	\N	PRESENT	0
742190	742189	17737W	PARTICIPANT	\N	PRESENT	0
743381	740164	14042U	PARTICIPANT	\N	PRESENT	0
743382	740164	19569H	PARTICIPANT	\N	PRESENT	0
743383	740164	14213J	PARTICIPANT	\N	PRESENT	0
743384	740164	19798U	PARTICIPANT	\N	PRESENT	0
743385	740164	18193Q	PARTICIPANT	\N	PRESENT	0
743396	740164	20130U	PARTICIPANT	\N	PRESENT	0
743398	740164	14195A	PARTICIPANT	\N	PRESENT	0
743400	740164	14071N	PARTICIPANT	\N	PRESENT	0
743408	740164	08045X	PARTICIPANT	\N	PRESENT	0
743417	740164	19713W	PARTICIPANT	\N	PRESENT	0
743418	740164	19723Y	PARTICIPANT	\N	PRESENT	0
743420	740164	19703U	PARTICIPANT	\N	PRESENT	0
743433	740164	19760E	PARTICIPANT	\N	PRESENT	0
743434	740164	11031D	PARTICIPANT	\N	PRESENT	0
743453	740164	01034P	PARTICIPANT	\N	PRESENT	0
743454	740164	17965H	PARTICIPANT	\N	PRESENT	0
743464	740164	10006L	PRESIDENT	0	PRESENT	0
743465	740164	14217N	PARTICIPANT	\N	PRESENT	0
743466	740164	19683J	PARTICIPANT	\N	PRESENT	0
743468	740164	19715Y	PARTICIPANT	\N	PRESENT	0
743515	743514	17737W	PARTICIPANT	\N	PRESENT	0
743516	743514	14195A	PARTICIPANT	\N	PRESENT	0
743517	743514	19691J	PARTICIPANT	\N	PRESENT	0
743518	743514	14213J	PARTICIPANT	\N	PRESENT	0
743519	743514	20056C	PARTICIPANT	\N	PRESENT	0
743520	743514	19447X	PARTICIPANT	\N	PRESENT	0
743521	743514	14059S	PARTICIPANT	\N	PRESENT	0
743522	743514	11067R	PARTICIPANT	\N	PRESENT	0
743523	743514	14223L	PARTICIPANT	\N	PRESENT	0
743524	743514	14071N	PARTICIPANT	\N	PRESENT	0
743525	743514	14331P	PARTICIPANT	\N	PRESENT	0
743526	743514	19798U	PARTICIPANT	\N	PRESENT	0
744090	740645	14030Q	PARTICIPANT	\N	PRESENT	0
744091	740645	19467C	PARTICIPANT	\N	PRESENT	0
744102	740645	14083S	PARTICIPANT	\N	PRESENT	0
744103	740645	11040E	PARTICIPANT	\N	PRESENT	0
744104	740645	20914V	PARTICIPANT	\N	PRESENT	0
744105	740645	20048C	PARTICIPANT	\N	PRESENT	0
744106	740645	07029T	PARTICIPANT	\N	PRESENT	0
744110	740645	14229S	PARTICIPANT	\N	PRESENT	0
744141	740646	20136B	PARTICIPANT	\N	PRESENT	0
744142	740646	20038A	PARTICIPANT	\N	PRESENT	0
744143	740646	07029T	PARTICIPANT	\N	PRESENT	0
744144	740646	19467C	PARTICIPANT	\N	PRESENT	0
744145	740646	20914V	PARTICIPANT	\N	PRESENT	0
744146	740646	20150Y	PARTICIPANT	\N	PRESENT	0
744147	740646	19647E	PARTICIPANT	\N	PRESENT	0
744148	740646	14030Q	PARTICIPANT	\N	PRESENT	0
744149	740646	19735D	PARTICIPANT	\N	PRESENT	0
744150	740646	19651A	PARTICIPANT	\N	PRESENT	0
744151	740646	08010L	PARTICIPANT	\N	PRESENT	0
744152	740646	11040E	PARTICIPANT	\N	PRESENT	0
744153	740646	11012A	PARTICIPANT	\N	PRESENT	0
744154	740646	14229S	PARTICIPANT	\N	PRESENT	0
744155	740646	14211G	PARTICIPANT	\N	PRESENT	0
744156	740646	20100N	PARTICIPANT	\N	PRESENT	0
744157	740646	14219Q	PARTICIPANT	\N	PRESENT	0
744158	740646	11053K	PARTICIPANT	\N	PRESENT	0
744159	740646	14083S	PARTICIPANT	\N	PRESENT	0
744162	740646	11074Q	PARTICIPANT	\N	PRESENT	0
744163	740646	97011G	PARTICIPANT	\N	PRESENT	0
761099	761029	14225N	PRESIDENT	0	PRESENT	0
761100	761029	21069M	PARTICIPANT	\N	PRESENT	0
761101	761029	11074Q	PARTICIPANT	\N	PRESENT	0
761102	761029	19399H	PARTICIPANT	\N	PRESENT	0
744139	740646	11045K	PARTICIPANT	\N	PRESENT	0
744140	740646	20026V	PARTICIPANT	\N	PRESENT	0
761103	761029	20024T	PARTICIPANT	\N	PRESENT	0
761269	760739	14107H	PARTICIPANT	\N	PRESENT	0
761270	760739	04045F	PARTICIPANT	\N	PRESENT	0
761271	760739	20098N	PARTICIPANT	\N	PRESENT	0
761272	760739	21095P	PARTICIPANT	\N	PRESENT	0
761281	760739	20036X	PARTICIPANT	\N	PRESENT	0
761282	760739	21044C	PARTICIPANT	\N	PRESENT	0
761283	760739	14073Q	PARTICIPANT	\N	PRESENT	0
761284	760739	11040E	PARTICIPANT	\N	PRESENT	0
761285	761030	08009T	PARTICIPANT	\N	PRESENT	0
761286	761030	21090J	PARTICIPANT	\N	PRESENT	0
761287	761030	19399H	PARTICIPANT	\N	PRESENT	0
761288	761030	14225N	PRESIDENT	0	PRESENT	0
761289	761030	20024T	PARTICIPANT	\N	PRESENT	0
761290	761030	14173T	PARTICIPANT	\N	PRESENT	0
761291	761030	11040E	PARTICIPANT	\N	EXCUSE	0
761292	761030	19687N	PARTICIPANT	\N	EXCUSE	0
761293	761030	12016W	PARTICIPANT	\N	EXCUSE	0
761294	761030	19667J	PARTICIPANT	\N	EXCUSE	0
761297	761030	14331P	PARTICIPANT	\N	PRESENT	0
761298	761030	19647E	PARTICIPANT	\N	PRESENT	0
761299	761030	20062A	PARTICIPANT	\N	PRESENT	0
761300	761030	19349W	PARTICIPANT	\N	PRESENT	0
761301	761030	11074Q	PARTICIPANT	\N	PRESENT	0
761303	761030	20044X	PARTICIPANT	\N	PRESENT	0
761304	760739	21058J	PARTICIPANT	\N	PRESENT	0
761305	760739	20046A	PARTICIPANT	\N	PRESENT	0
761307	760739	21084L	PARTICIPANT	\N	PRESENT	0
761308	760739	21067K	PARTICIPANT	\N	PRESENT	0
761309	761030	11053K	PARTICIPANT	\N	PRESENT	0
761310	761030	20080C	PARTICIPANT	\N	PRESENT	0
761311	761030	20094J	PARTICIPANT	\N	PRESENT	0
761312	761030	20070A	PARTICIPANT	\N	PRESENT	0
761313	760739	21088Q	PARTICIPANT	\N	PRESENT	0
761314	760739	14030Q	PARTICIPANT	\N	PRESENT	0
761377	760739	14109K	PARTICIPANT	\N	PRESENT	0
761317	760739	19826F	PARTICIPANT	\N	PRESENT	0
761318	760739	20056C	PARTICIPANT	\N	PRESENT	0
761319	760739	19687N	PARTICIPANT	\N	PRESENT	0
761320	760739	19649G	PARTICIPANT	\N	PRESENT	0
761321	761030	20126Y	PARTICIPANT	\N	PRESENT	0
761322	760739	04047H	PARTICIPANT	\N	PRESENT	0
761323	760739	20102Q	PARTICIPANT	\N	PRESENT	0
761324	760739	20112S	PARTICIPANT	\N	PRESENT	0
761325	761030	08010L	PARTICIPANT	\N	PRESENT	0
761369	760739	18083K	PARTICIPANT	\N	PRESENT	0
761375	760739	21078N	PARTICIPANT	\N	PRESENT	0
761378	760739	21054E	PARTICIPANT	\N	PRESENT	0
761379	760739	10015M	PARTICIPANT	\N	PRESENT	0
761380	760739	19681G	PARTICIPANT	\N	PRESENT	0
761381	760739	21074J	PARTICIPANT	\N	PRESENT	0
761382	760739	21048G	PARTICIPANT	\N	PRESENT	0
761383	760739	11090Q	PARTICIPANT	\N	PRESENT	0
747761	746027	19687N	PARTICIPANT	\N	PRESENT	0
747762	746027	04035D	PARTICIPANT	\N	PRESENT	0
747763	746027	14033T	PARTICIPANT	\N	PRESENT	0
747764	746027	19826F	PARTICIPANT	\N	PRESENT	0
747765	746027	20052X	PARTICIPANT	\N	PRESENT	0
747766	746027	19723Y	PARTICIPANT	\N	PRESENT	0
747767	746027	14053L	PARTICIPANT	\N	PRESENT	0
747768	746027	19319Q	PARTICIPANT	\N	PRESENT	0
747769	746027	20252E	PARTICIPANT	\N	PRESENT	0
747770	746027	11083R	PARTICIPANT	\N	PRESENT	0
747771	746027	04071H	PARTICIPANT	\N	PRESENT	0
747772	746027	16685X	PARTICIPANT	\N	PRESENT	0
747773	746027	17023S	PARTICIPANT	\N	PRESENT	0
747774	746027	20092G	PARTICIPANT	\N	PRESENT	0
747775	746027	14083S	PARTICIPANT	\N	PRESENT	0
747776	746027	14215L	PARTICIPANT	\N	PRESENT	0
747777	746027	20126Y	PARTICIPANT	\N	PRESENT	0
747778	746027	14255U	PARTICIPANT	\N	PRESENT	0
748138	748137	19762G	PARTICIPANT	\N	PRESENT	0
748139	748137	19531S	PARTICIPANT	\N	PRESENT	0
748143	748142	14189C	PARTICIPANT	\N	PRESENT	0
748145	748144	14189C	PARTICIPANT	\N	PRESENT	0
748147	748146	14189C	PARTICIPANT	\N	PRESENT	0
748149	748148	14189C	PARTICIPANT	\N	PRESENT	0
748150	748135	20114U	PARTICIPANT	\N	PRESENT	0
748151	748135	08018U	PARTICIPANT	\N	PRESENT	0
748393	746773	04092N	PARTICIPANT	\N	PRESENT	0
748799	748003	04047H	PRESIDENT	0	PRESENT	0
748800	748003	10015M	PARTICIPANT	\N	PRESENT	0
748801	748003	14053L	PRESIDENT	1	PRESENT	0
748802	748003	14147R	PARTICIPANT	\N	PRESENT	0
748803	748003	14069U	PARTICIPANT	\N	PRESENT	0
748804	748003	19729F	PARTICIPANT	\N	PRESENT	0
748805	748003	19725B	PARTICIPANT	\N	PRESENT	0
748807	748003	01028R	PARTICIPANT	\N	PRESENT	0
748808	748003	19749K	PARTICIPANT	\N	PRESENT	0
748811	748003	20142Y	PARTICIPANT	\N	PRESENT	0
748813	748003	19758L	PARTICIPANT	\N	PRESENT	0
748814	748003	19533U	PARTICIPANT	\N	PRESENT	0
748815	748003	19611R	PARTICIPANT	\N	PRESENT	0
748816	748003	17737W	PARTICIPANT	\N	EXCUSE	0
748822	748003	19643A	PARTICIPANT	\N	PRESENT	0
748823	748003	20138D	PARTICIPANT	\N	PRESENT	0
748824	748003	20264J	PARTICIPANT	\N	PRESENT	0
748827	748003	19735D	PARTICIPANT	\N	PRESENT	0
748829	748003	14123H	PARTICIPANT	\N	PRESENT	0
748830	748003	14073Q	PARTICIPANT	\N	PRESENT	0
748832	748003	14229S	PARTICIPANT	\N	PRESENT	0
748833	748003	20026V	PARTICIPANT	\N	PRESENT	0
748837	748003	20056C	PARTICIPANT	\N	PRESENT	0
748838	748003	20180F	PARTICIPANT	\N	PRESENT	0
748840	748003	20980G	PARTICIPANT	\N	PRESENT	0
748842	748003	20022R	PARTICIPANT	\N	PRESENT	0
748854	748003	20124W	PARTICIPANT	\N	PRESENT	0
748855	748003	20052X	PARTICIPANT	\N	PRESENT	0
748859	748003	20152B	PARTICIPANT	\N	PRESENT	0
748876	748003	11056N	PARTICIPANT	\N	PRESENT	0
749184	741501	20080C	PARTICIPANT	\N	EXCUSE	0
749514	749513	14109K	PARTICIPANT	\N	PRESENT	0
749515	749513	08015R	PARTICIPANT	\N	PRESENT	0
749516	749513	20028X	PARTICIPANT	\N	PRESENT	0
749517	749513	11012A	PARTICIPANT	\N	PRESENT	0
749518	749513	20046A	PARTICIPANT	\N	PRESENT	0
749519	749513	11097X	PARTICIPANT	\N	PRESENT	0
750183	749953	11031D	PARTICIPANT	\N	EXCUSE	0
750184	749953	11067R	PARTICIPANT	\N	EXCUSE	0
750185	749953	14026U	PARTICIPANT	\N	PRESENT	0
750186	749953	10006L	PRESIDENT	0	PRESENT	0
750187	749953	19553Y	PARTICIPANT	\N	PRESENT	0
750188	749953	14071N	PARTICIPANT	\N	PRESENT	0
750189	749953	14217N	PARTICIPANT	\N	PRESENT	0
750190	749953	19591F	PARTICIPANT	\N	PRESENT	0
750191	749953	14195A	PARTICIPANT	\N	PRESENT	0
750192	749953	11097X	PARTICIPANT	\N	PRESENT	0
750193	749953	19697Q	PARTICIPANT	\N	PRESENT	0
750194	749953	19569H	PARTICIPANT	\N	PRESENT	0
750195	749953	17965H	PARTICIPANT	\N	PRESENT	0
750196	749953	14281W	PARTICIPANT	\N	PRESENT	0
750197	749953	19760E	PARTICIPANT	\N	PRESENT	0
750198	749953	20130U	PARTICIPANT	\N	PRESENT	0
750199	749953	19798U	PARTICIPANT	\N	PRESENT	0
750200	749954	11067R	PARTICIPANT	\N	EXCUSE	0
750201	749954	14217N	PARTICIPANT	\N	PRESENT	0
750202	749954	20090E	PARTICIPANT	\N	PRESENT	0
750203	749954	19798U	PARTICIPANT	\N	PRESENT	0
750204	749954	14071N	PRESIDENT	0	PRESENT	0
750205	749954	14026U	PARTICIPANT	\N	PRESENT	0
750206	749954	14213J	PARTICIPANT	\N	PRESENT	0
750207	749954	11097X	PARTICIPANT	\N	PRESENT	0
750208	749954	04092N	PARTICIPANT	\N	PRESENT	0
750209	749954	14042U	PARTICIPANT	\N	PRESENT	0
750210	749954	19553Y	PARTICIPANT	\N	PRESENT	0
750211	749954	11031D	PARTICIPANT	\N	PRESENT	0
750212	749954	11045K	PARTICIPANT	\N	PRESENT	0
750219	745859	19631V	PARTICIPANT	\N	EXCUSE	0
750220	745859	14219Q	PARTICIPANT	\N	EXCUSE	0
750271	748445	17737W	PARTICIPANT	\N	EXCUSE	0
750755	750754	14038Y	PARTICIPANT	\N	PRESENT	0
750756	750754	14179A	PARTICIPANT	\N	PRESENT	0
750757	750754	20034V	PARTICIPANT	\N	PRESENT	0
750760	750754	14030Q	PARTICIPANT	\N	PRESENT	0
751029	751028	20024T	PARTICIPANT	\N	PRESENT	0
751030	751028	14255U	PARTICIPANT	\N	PRESENT	0
751031	751028	97011G	PARTICIPANT	\N	PRESENT	0
751032	751028	18193Q	PARTICIPANT	\N	PRESENT	0
751033	751028	19798U	PARTICIPANT	\N	PRESENT	0
751034	751028	20252E	PARTICIPANT	\N	PRESENT	0
751035	751028	14213J	PARTICIPANT	\N	PRESENT	0
753400	752390	19713W	PARTICIPANT	\N	PRESENT	0
753401	752390	19703U	PARTICIPANT	\N	PRESENT	0
753402	752390	21049H	PARTICIPANT	\N	PRESENT	0
753403	752390	19866P	PARTICIPANT	\N	PRESENT	0
753404	752390	19367Y	PARTICIPANT	\N	PRESENT	0
753405	752390	14071N	PRESIDENT	0	PRESENT	0
753406	752390	17779H	PARTICIPANT	\N	PRESENT	0
753407	752390	19691J	PARTICIPANT	\N	PRESENT	0
753408	752390	14195A	PARTICIPANT	\N	PRESENT	0
753409	752390	04092N	PARTICIPANT	\N	PRESENT	0
753410	752390	19683J	PARTICIPANT	\N	PRESENT	0
753411	752390	19569H	PARTICIPANT	\N	PRESENT	0
753412	752390	01034P	PARTICIPANT	\N	PRESENT	0
753413	752390	21064G	PARTICIPANT	\N	PRESENT	0
753414	752390	21087P	PARTICIPANT	\N	PRESENT	0
753415	752390	19657G	PARTICIPANT	\N	PRESENT	0
753416	752390	20130U	PARTICIPANT	\N	PRESENT	0
753417	752390	20248J	PARTICIPANT	\N	PRESENT	0
753418	752390	14217N	PARTICIPANT	\N	PRESENT	0
753419	752390	20140W	PARTICIPANT	\N	PRESENT	0
753420	752390	19295A	PARTICIPANT	\N	PRESENT	0
753421	752390	08045X	PARTICIPANT	\N	PRESENT	0
753422	752390	14281W	PARTICIPANT	\N	PRESENT	0
753423	752390	20040T	PARTICIPANT	\N	PRESENT	0
753424	752390	14042U	PARTICIPANT	\N	PRESENT	0
753425	752390	21046E	PARTICIPANT	\N	PRESENT	0
753426	752390	19760E	PARTICIPANT	\N	PRESENT	0
753427	752390	21071F	PARTICIPANT	\N	PRESENT	0
753428	752390	20096L	PARTICIPANT	\N	PRESENT	0
753429	752390	19629C	PARTICIPANT	\N	PRESENT	0
753430	752390	21045D	PARTICIPANT	\N	PRESENT	0
753431	752390	20090E	PARTICIPANT	\N	PRESENT	0
753432	752390	19758L	PARTICIPANT	\N	PRESENT	0
753433	752390	20148F	PARTICIPANT	\N	PRESENT	0
753434	752390	08061X	PARTICIPANT	\N	PRESENT	0
753435	752390	14223L	PARTICIPANT	\N	PRESENT	0
753436	752390	11045K	PARTICIPANT	\N	PRESENT	0
753437	752390	19798U	PARTICIPANT	\N	PRESENT	0
753438	752390	19679N	PARTICIPANT	\N	PRESENT	0
753439	752390	17965H	PARTICIPANT	\N	PRESENT	0
753440	752390	19591F	PARTICIPANT	\N	PRESENT	0
753441	752390	19553Y	PARTICIPANT	\N	PRESENT	0
753442	752390	14026U	PARTICIPANT	\N	PRESENT	0
753443	752390	14355X	PARTICIPANT	\N	PRESENT	0
753444	752390	18193Q	PARTICIPANT	\N	PRESENT	0
753445	752390	19723Y	PARTICIPANT	\N	PRESENT	0
753446	752390	21081H	PARTICIPANT	\N	PRESENT	0
753447	752390	14213J	PARTICIPANT	\N	PRESENT	0
753448	752390	21097R	PARTICIPANT	\N	PRESENT	0
753643	753642	15197G	PARTICIPANT	\N	PRESENT	0
753686	753685	20136B	PARTICIPANT	\N	PRESENT	0
755869	755868	15197G	PARTICIPANT	\N	PRESENT	0
755871	755870	15197G	PARTICIPANT	\N	PRESENT	0
743797	740642	18193Q	PARTICIPANT	\N	PRESENT	0
743798	740642	19745F	PARTICIPANT	\N	PRESENT	0
743800	740642	14069U	PARTICIPANT	\N	PRESENT	0
743801	740642	20090E	PARTICIPANT	\N	PRESENT	0
743805	740642	20048C	PARTICIPANT	\N	PRESENT	0
743806	740642	14083S	PARTICIPANT	\N	PRESENT	0
743807	740642	20298U	PARTICIPANT	\N	PRESENT	0
743808	740642	19711U	PARTICIPANT	\N	PRESENT	0
743809	740642	20062A	PARTICIPANT	\N	PRESENT	0
743810	740642	08012N	PARTICIPANT	\N	PRESENT	0
744207	744206	20134Y	PARTICIPANT	\N	PRESENT	0
744208	744206	20064C	PRESIDENT	0	PRESENT	0
744209	744206	14251Q	PARTICIPANT	\N	PRESENT	0
744210	744206	17737W	PARTICIPANT	\N	EXCUSE	0
744211	744206	14030Q	PARTICIPANT	\N	EXCUSE	0
744215	744214	11040E	PARTICIPANT	\N	PRESENT	0
744216	744214	11048N	PARTICIPANT	\N	PRESENT	0
744217	744214	19711U	PARTICIPANT	\N	PRESENT	0
744218	744214	19687N	PARTICIPANT	\N	PRESENT	0
744219	744214	20080C	PARTICIPANT	\N	PRESENT	0
744220	744214	99004R	PARTICIPANT	\N	PRESENT	0
744221	744214	20914V	PARTICIPANT	\N	PRESENT	0
744222	744214	11074Q	PARTICIPANT	\N	PRESENT	0
744223	744214	20044X	PARTICIPANT	\N	PRESENT	0
744224	744214	14225N	PRESIDENT	0	PRESENT	0
744226	744214	08011M	PARTICIPANT	\N	PRESENT	0
744419	744168	19563B	PARTICIPANT	\N	PRESENT	0
744228	744214	20252E	PARTICIPANT	\N	PRESENT	0
744362	744168	14111D	PARTICIPANT	\N	PRESENT	0
744418	743960	14030Q	PARTICIPANT	\N	EXCUSE	0
744420	744168	04047H	PARTICIPANT	\N	PRESENT	0
744421	744168	19507S	PARTICIPANT	\N	PRESENT	0
744422	743960	20094J	PARTICIPANT	\N	PRESENT	0
744423	744168	14267Y	PARTICIPANT	\N	PRESENT	0
744424	744168	14221J	PARTICIPANT	\N	PRESENT	0
744425	744168	19760E	PARTICIPANT	\N	PRESENT	0
744426	744168	20068G	PARTICIPANT	\N	PRESENT	0
744427	744168	20180F	PARTICIPANT	\N	PRESENT	0
744428	744168	20136B	PARTICIPANT	\N	PRESENT	0
744429	744168	20152B	PARTICIPANT	\N	PRESENT	0
744430	744168	20098N	PARTICIPANT	\N	PRESENT	0
744434	744168	20142Y	PARTICIPANT	\N	PRESENT	0
744432	744168	20058E	PARTICIPANT	\N	PRESENT	0
744433	744168	20048C	PARTICIPANT	\N	PRESENT	0
744435	744168	19651A	PARTICIPANT	\N	PRESENT	0
744436	744168	19687N	PARTICIPANT	\N	PRESENT	0
744437	744168	01024M	PARTICIPANT	\N	PRESENT	0
744438	744168	20144B	PARTICIPANT	\N	PRESENT	0
744439	743960	20128B	PARTICIPANT	\N	PRESENT	0
744440	744168	14021P	PARTICIPANT	\N	PRESENT	0
744441	744168	20056C	PARTICIPANT	\N	PRESENT	0
744442	744168	20022R	PARTICIPANT	\N	PRESENT	0
744443	744168	11045K	PARTICIPANT	\N	PRESENT	0
744444	744168	19441R	PARTICIPANT	\N	PRESENT	0
744445	744168	19699S	PARTICIPANT	\N	PRESENT	0
744446	744168	20034V	PARTICIPANT	\N	PRESENT	0
744447	744168	14030Q	PARTICIPANT	\N	PRESENT	0
744448	744168	14187A	PARTICIPANT	\N	PRESENT	0
744449	744168	11077T	PARTICIPANT	\N	PRESENT	0
744450	744168	20128B	PARTICIPANT	\N	PRESENT	0
744451	744168	19729F	PARTICIPANT	\N	PRESENT	0
744452	744168	14038Y	PARTICIPANT	\N	PRESENT	0
744455	744168	11065P	PARTICIPANT	\N	PRESENT	0
744457	744168	19549D	PARTICIPANT	\N	PRESENT	0
744458	744168	20052X	PARTICIPANT	\N	PRESENT	0
744459	744168	08056B	PARTICIPANT	\N	PRESENT	0
744460	744168	19319Q	PARTICIPANT	\N	PRESENT	0
744461	744168	12041X	PARTICIPANT	\N	PRESENT	0
744462	744168	14195A	PARTICIPANT	\N	PRESENT	0
744465	744168	19569H	PARTICIPANT	\N	PRESENT	0
744466	744168	20140W	PARTICIPANT	\N	PRESENT	0
744468	744168	19647E	PARTICIPANT	\N	PRESENT	0
744469	744168	19367Y	PARTICIPANT	\N	PRESENT	0
744471	744168	20096L	PARTICIPANT	\N	PRESENT	0
744475	744168	20060X	PARTICIPANT	\N	PRESENT	0
744476	744168	19447X	PARTICIPANT	\N	PRESENT	0
744477	744168	01025N	PARTICIPANT	\N	PRESENT	0
744478	744168	14231L	PARTICIPANT	\N	PRESENT	0
744479	744168	20106U	PARTICIPANT	\N	PRESENT	0
744480	744168	98022P	PARTICIPANT	\N	PRESENT	0
744481	744168	19387D	PARTICIPANT	\N	PRESENT	0
744482	744168	14179A	PARTICIPANT	\N	PRESENT	0
744483	744168	14259Y	PARTICIPANT	\N	PRESENT	0
744484	744168	14059S	PARTICIPANT	\N	PRESENT	0
744485	744168	19611R	PARTICIPANT	\N	PRESENT	0
744486	744168	17023S	PARTICIPANT	\N	PRESENT	0
744487	744168	20066E	PARTICIPANT	\N	PRESENT	0
744488	744168	20042V	PARTICIPANT	\N	PRESENT	0
744489	744168	19413M	PARTICIPANT	\N	PRESENT	0
744490	744168	04033B	PARTICIPANT	\N	PRESENT	0
744491	744168	19649G	PARTICIPANT	\N	PRESENT	0
744492	744168	08010L	PARTICIPANT	\N	PRESENT	0
744496	744168	19713W	PARTICIPANT	\N	PRESENT	0
744497	744168	20134Y	PARTICIPANT	\N	PRESENT	0
744498	744168	11101A	PARTICIPANT	\N	PRESENT	0
744499	744168	20118Y	PARTICIPANT	\N	PRESENT	0
744501	744168	05012A	PARTICIPANT	\N	PRESENT	0
744510	744168	19467C	PARTICIPANT	\N	PRESENT	0
744521	744168	08015R	PARTICIPANT	\N	PRESENT	0
744524	744168	19349W	PARTICIPANT	\N	PRESENT	0
744534	744168	14031R	PARTICIPANT	\N	PRESENT	0
744535	744168	11085T	PARTICIPANT	\N	PRESENT	0
744536	744168	14069U	PARTICIPANT	\N	PRESENT	0
744537	744168	01028R	PARTICIPANT	\N	PRESENT	0
744539	744168	20124W	PARTICIPANT	\N	PRESENT	0
744540	744168	19762G	PARTICIPANT	\N	PRESENT	0
744778	744093	19649G	PARTICIPANT	\N	PRESENT	0
744787	744093	11010L	PARTICIPANT	\N	PRESENT	0
745558	745557	14053L	PARTICIPANT	\N	PRESENT	0
745559	745557	14089Y	PARTICIPANT	\N	PRESENT	0
745560	745557	11026G	PARTICIPANT	\N	PRESENT	0
745799	745798	10006L	PARTICIPANT	\N	PRESENT	0
745800	745798	14217N	PARTICIPANT	\N	PRESENT	0
745801	745798	14133K	PARTICIPANT	\N	PRESENT	0
746008	746007	17023S	PARTICIPANT	\N	PRESENT	0
746009	746007	14193X	PARTICIPANT	\N	PRESENT	0
746010	746007	20128B	PARTICIPANT	\N	PRESENT	0
746011	746007	08047A	PARTICIPANT	\N	PRESENT	0
746012	746007	14133K	PARTICIPANT	\N	PRESENT	0
746139	746014	16685X	PARTICIPANT	\N	PRESENT	0
746146	746023	86034E	PARTICIPANT	\N	PRESENT	0
746156	746023	14193X	PARTICIPANT	\N	PRESENT	0
746157	746023	19711U	PARTICIPANT	\N	PRESENT	0
746158	746023	14133K	PARTICIPANT	\N	PRESENT	0
746159	746023	14267Y	PARTICIPANT	\N	PRESENT	0
746160	746023	12028B	PARTICIPANT	\N	PRESENT	0
746161	746023	17023S	PARTICIPANT	\N	PRESENT	0
746162	746023	19577H	PARTICIPANT	\N	PRESENT	0
746163	746023	12041X	PARTICIPANT	\N	PRESENT	0
746164	746023	19565D	PARTICIPANT	\N	PRESENT	0
746165	746023	19826F	PARTICIPANT	\N	PRESENT	0
746166	746023	19319Q	PARTICIPANT	\N	PRESENT	0
746167	746023	08034U	PARTICIPANT	\N	PRESENT	0
746168	746023	08061X	PARTICIPANT	\N	PRESENT	0
746169	746023	20024T	PARTICIPANT	\N	PRESENT	0
746174	746023	11027H	PARTICIPANT	\N	PRESENT	0
746175	746023	20064C	PARTICIPANT	\N	PRESENT	0
746176	746023	20076G	PARTICIPANT	\N	PRESENT	0
746177	746023	19669L	PARTICIPANT	\N	PRESENT	0
746178	746023	01062T	PARTICIPANT	\N	PRESENT	0
746179	746023	11054L	PARTICIPANT	\N	PRESENT	0
746180	746023	11066Q	PARTICIPANT	\N	PRESENT	0
746181	746023	20090E	PARTICIPANT	\N	PRESENT	0
746182	746023	19347U	PARTICIPANT	\N	PRESENT	0
746183	746023	19782L	PARTICIPANT	\N	PRESENT	0
746184	746023	95063L	PARTICIPANT	\N	PRESENT	0
746185	746023	04042C	PARTICIPANT	\N	PRESENT	0
746186	746023	20128B	PARTICIPANT	\N	PRESENT	0
746187	746023	20072C	PARTICIPANT	\N	PRESENT	0
746188	746023	98022P	PARTICIPANT	\N	PRESENT	0
746189	746023	19719D	PARTICIPANT	\N	PRESENT	0
746190	746023	11012A	PARTICIPANT	\N	PRESENT	0
746191	746023	14259Y	PARTICIPANT	\N	PRESENT	0
746192	746023	14107H	PARTICIPANT	\N	PRESENT	0
746193	746023	19721W	PARTICIPANT	\N	PRESENT	0
746194	746023	14033T	PARTICIPANT	\N	PRESENT	0
746196	746023	20042V	PARTICIPANT	\N	PRESENT	0
746197	746023	19709B	PARTICIPANT	\N	PRESENT	0
746198	746023	19745F	PARTICIPANT	\N	PRESENT	0
746199	746023	11083R	PARTICIPANT	\N	PRESENT	0
746200	746023	14021P	PARTICIPANT	\N	PRESENT	0
762363	761711	99004R	PARTICIPANT	\N	PRESENT	0
762364	761711	21054E	PARTICIPANT	\N	PRESENT	0
762365	761711	21083K	PARTICIPANT	\N	PRESENT	0
762366	761711	04033B	PARTICIPANT	\N	PRESENT	0
762367	761711	19347U	PARTICIPANT	\N	PRESENT	0
762368	761711	19679N	PARTICIPANT	\N	PRESENT	0
762369	761711	21069M	PARTICIPANT	\N	PRESENT	0
762370	761711	21053D	PARTICIPANT	\N	PRESENT	0
762371	761711	20062A	PARTICIPANT	\N	PRESENT	0
762372	761711	19826F	PARTICIPANT	\N	PRESENT	0
762373	761711	19699S	PARTICIPANT	\N	PRESENT	0
762374	761711	19611R	PARTICIPANT	\N	PRESENT	0
762375	761711	20286Q	PARTICIPANT	\N	PRESENT	0
762376	761711	19703U	PARTICIPANT	\N	PRESENT	0
762377	761711	14329V	PARTICIPANT	\N	PRESENT	0
762378	761711	08015R	PARTICIPANT	\N	PRESENT	0
762379	761711	19507S	PARTICIPANT	\N	PRESENT	0
762380	761711	08028W	PARTICIPANT	\N	PRESENT	0
762381	761711	21095P	PARTICIPANT	\N	PRESENT	0
762382	761711	14147R	PARTICIPANT	\N	PRESENT	0
762383	761711	20024T	PARTICIPANT	\N	PRESENT	0
762384	761711	20148F	PARTICIPANT	\N	PRESENT	0
762385	761711	20266L	PARTICIPANT	\N	PRESENT	0
762386	761711	20032T	PARTICIPANT	\N	PRESENT	0
762387	761711	12028B	PARTICIPANT	\N	PRESENT	0
762388	761711	20056C	PARTICIPANT	\N	PRESENT	0
762389	761711	19695N	PARTICIPANT	\N	PRESENT	0
762390	761711	21039F	PARTICIPANT	\N	PRESENT	0
762391	761711	21093M	PARTICIPANT	\N	PRESENT	0
762392	761183	20094J	PARTICIPANT	\N	PRESENT	0
762393	761711	21066J	PARTICIPANT	\N	PRESENT	0
762394	761711	19383Y	PARTICIPANT	\N	PRESENT	0
762395	761711	20118Y	PARTICIPANT	\N	PRESENT	0
762396	761711	20252E	PARTICIPANT	\N	PRESENT	0
762397	761711	19798U	PARTICIPANT	\N	PRESENT	0
762398	761711	19367Y	PARTICIPANT	\N	PRESENT	0
762399	761711	11065P	PARTICIPANT	\N	PRESENT	0
762400	761711	20054A	PARTICIPANT	\N	PRESENT	0
762401	761711	95041E	PARTICIPANT	\N	PRESENT	0
762402	761711	20020P	PARTICIPANT	\N	PRESENT	0
762403	761711	21075K	PARTICIPANT	\N	PRESENT	0
762404	761711	21042A	PARTICIPANT	\N	PRESENT	0
762405	761711	20040T	PARTICIPANT	\N	PRESENT	0
762406	761711	14107H	PARTICIPANT	\N	PRESENT	0
762407	761711	20060X	PARTICIPANT	\N	PRESENT	0
762498	762243	20102Q	PARTICIPANT	\N	EXCUSE	0
762496	762243	19621T	PARTICIPANT	\N	PRESENT	0
762497	762243	21037D	PARTICIPANT	\N	PRESENT	0
762500	762243	20124W	PARTICIPANT	\N	PRESENT	0
762690	761931	19383Y	PARTICIPANT	\N	PRESENT	0
762691	761931	19768N	PARTICIPANT	\N	PRESENT	0
762692	761931	20088L	PARTICIPANT	\N	PRESENT	0
762693	761931	19782L	PARTICIPANT	\N	PRESENT	0
762694	761931	20092G	PARTICIPANT	\N	PRESENT	0
762695	761931	14357A	PARTICIPANT	\N	PRESENT	0
762696	761931	20082E	PARTICIPANT	\N	PRESENT	0
762697	761931	19631V	PARTICIPANT	\N	PRESENT	0
762698	761931	20104S	PARTICIPANT	\N	PRESENT	0
762699	761931	08015R	PARTICIPANT	\N	PRESENT	0
762700	761931	20018V	PARTICIPANT	\N	PRESENT	0
762701	761931	19563B	PARTICIPANT	\N	PRESENT	0
762702	761931	21050A	PARTICIPANT	\N	PRESENT	0
762703	761931	21096Q	PARTICIPANT	\N	PRESENT	0
762704	761931	14329V	PARTICIPANT	\N	PRESENT	0
762705	761931	14038Y	PARTICIPANT	\N	PRESENT	0
762706	761931	21052C	PARTICIPANT	\N	PRESENT	0
762707	761931	14187A	PRESIDENT	0	PRESENT	0
762708	761931	21075K	PARTICIPANT	\N	PRESENT	0
762709	761931	19713W	PARTICIPANT	\N	PRESENT	0
762710	761931	21083K	PARTICIPANT	\N	PRESENT	0
762711	761931	21086N	PARTICIPANT	\N	PRESENT	0
762712	761931	14033T	PARTICIPANT	\N	PRESENT	0
762713	761931	20054A	PARTICIPANT	\N	PRESENT	0
762714	761931	21034A	PARTICIPANT	\N	PRESENT	0
762715	761931	14205J	PARTICIPANT	\N	PRESENT	0
762716	761931	20060X	PARTICIPANT	\N	PRESENT	0
762717	761931	20066E	PARTICIPANT	\N	PRESENT	0
762718	761931	19507S	PARTICIPANT	\N	PRESENT	0
762719	761931	20286Q	PARTICIPANT	\N	PRESENT	0
762720	761931	14207L	PARTICIPANT	\N	PRESENT	0
762721	761931	14257W	PARTICIPANT	\N	PRESENT	0
762722	761931	20084G	PARTICIPANT	\N	PRESENT	0
762723	761931	20038A	PARTICIPANT	\N	EXCUSE	0
762724	761931	11090Q	PARTICIPANT	\N	EXCUSE	0
762725	761711	19399H	PARTICIPANT	\N	PRESENT	0
763029	761593	20090E	PARTICIPANT	\N	PRESENT	0
763030	761593	19569H	PARTICIPANT	\N	PRESENT	0
763031	761593	19798U	PARTICIPANT	\N	PRESENT	0
763032	761593	19691J	PARTICIPANT	\N	PRESENT	0
763033	761593	14042U	PARTICIPANT	\N	PRESENT	0
763034	761593	19866P	PARTICIPANT	\N	PRESENT	0
763035	761593	04092N	PARTICIPANT	\N	PRESENT	0
763036	761593	14355X	PARTICIPANT	\N	PRESENT	0
763037	761593	21046E	PARTICIPANT	\N	PRESENT	0
763038	761593	21097R	PARTICIPANT	\N	PRESENT	0
763039	761593	20248J	PARTICIPANT	\N	PRESENT	0
763040	761593	14217N	PARTICIPANT	\N	PRESENT	0
763041	761593	19683J	PARTICIPANT	\N	PRESENT	0
763042	761593	21087P	PARTICIPANT	\N	PRESENT	0
763043	761593	14195A	PARTICIPANT	\N	PRESENT	0
763044	761593	21039F	PARTICIPANT	\N	PRESENT	0
763045	761593	14071N	PRESIDENT	0	PRESENT	0
763046	761593	14026U	PARTICIPANT	\N	PRESENT	0
763047	761593	19301E	PARTICIPANT	\N	PRESENT	0
763048	761593	19703U	PRESIDENT	1	PRESENT	0
763049	761593	21045D	PARTICIPANT	\N	PRESENT	0
763050	761593	21081H	PARTICIPANT	\N	PRESENT	0
763051	761593	19713W	PARTICIPANT	\N	PRESENT	0
763052	761593	19723Y	PARTICIPANT	\N	PRESENT	0
763053	761593	14213J	PARTICIPANT	\N	PRESENT	0
763054	761593	19758L	PARTICIPANT	\N	PRESENT	0
763055	761593	01034P	PARTICIPANT	\N	PRESENT	0
763056	761593	20140W	PARTICIPANT	\N	PRESENT	0
763057	761593	14281W	PARTICIPANT	\N	PRESENT	0
763058	761593	20148F	PARTICIPANT	\N	PRESENT	0
763059	761593	14223L	PARTICIPANT	\N	PRESENT	0
763060	761593	19679N	PARTICIPANT	\N	PRESENT	0
763061	761593	19553Y	PARTICIPANT	\N	PRESENT	0
763069	763068	20286Q	PARTICIPANT	\N	PRESENT	0
763073	762589	20030R	PARTICIPANT	\N	PRESENT	0
763074	762589	21052C	PARTICIPANT	\N	PRESENT	0
763075	762589	14038Y	PARTICIPANT	\N	PRESENT	0
763076	762589	21054E	PARTICIPANT	\N	PRESENT	0
763077	762589	19782L	PARTICIPANT	\N	PRESENT	0
763078	762589	14187A	PRESIDENT	0	PRESENT	0
763079	762589	21083K	PARTICIPANT	\N	PRESENT	0
763081	762589	19695N	PARTICIPANT	\N	PRESENT	0
763082	762589	21092L	PARTICIPANT	\N	PRESENT	0
763083	762589	14033T	PARTICIPANT	\N	PRESENT	0
763084	762589	21034A	PARTICIPANT	\N	PRESENT	0
763085	762589	19631V	PARTICIPANT	\N	PRESENT	0
763086	762589	19705W	PARTICIPANT	\N	PRESENT	0
763087	762589	20066E	PARTICIPANT	\N	PRESENT	0
763088	762589	21066J	PARTICIPANT	\N	PRESENT	0
763089	762589	08015R	PARTICIPANT	\N	PRESENT	0
763090	762589	20286Q	PARTICIPANT	\N	PRESENT	0
763091	762589	19575F	PARTICIPANT	\N	PRESENT	0
763092	762589	20018V	PARTICIPANT	\N	PRESENT	0
763093	762589	08028W	PARTICIPANT	\N	PRESENT	0
763094	762589	19563B	PARTICIPANT	\N	PRESENT	0
763095	762589	20028X	PARTICIPANT	\N	PRESENT	0
763096	762589	20088L	PARTICIPANT	\N	PRESENT	0
763097	762589	14257W	PARTICIPANT	\N	PRESENT	0
763098	762589	20084G	PARTICIPANT	\N	PRESENT	0
763099	762589	20038A	PARTICIPANT	\N	EXCUSE	0
763100	762589	11090Q	PARTICIPANT	\N	PRESENT	0
763101	762589	20078J	PARTICIPANT	\N	PRESENT	0
763102	763072	19697Q	PARTICIPANT	\N	PRESENT	0
763103	763072	19699S	PARTICIPANT	\N	PRESENT	0
763104	763072	21058J	PARTICIPANT	\N	PRESENT	0
763105	763072	21059K	PARTICIPANT	\N	PRESENT	0
763106	763072	20102Q	PARTICIPANT	\N	PRESENT	0
763107	763072	14229S	PARTICIPANT	\N	PRESENT	0
763108	763072	19954N	PARTICIPANT	\N	PRESENT	0
763109	763072	20112S	PARTICIPANT	\N	PRESENT	0
763110	763072	21089R	PARTICIPANT	\N	PRESENT	0
763111	763072	21037D	PARTICIPANT	\N	PRESENT	0
763112	763072	08012N	PARTICIPANT	\N	PRESENT	0
763113	763072	20124W	PARTICIPANT	\N	PRESENT	0
763114	763072	20026V	PARTICIPANT	\N	PRESENT	0
752407	752406	08034U	PARTICIPANT	\N	PRESENT	0
752409	752408	08034U	PARTICIPANT	\N	PRESENT	0
754489	753670	14071N	PRESIDENT	0	PRESENT	0
754490	753670	19758L	PARTICIPANT	\N	PRESENT	0
754491	753670	20130U	PARTICIPANT	\N	PRESENT	0
754492	753670	21097R	PARTICIPANT	\N	PRESENT	0
754493	753670	14281W	PARTICIPANT	\N	PRESENT	0
754494	753670	21087P	PARTICIPANT	\N	PRESENT	0
754495	753670	21046E	PARTICIPANT	\N	PRESENT	0
754496	753670	14195A	PARTICIPANT	\N	PRESENT	0
754497	753670	19683J	PARTICIPANT	\N	PRESENT	0
754498	753670	21064G	PARTICIPANT	\N	PRESENT	0
754499	753670	19866P	PARTICIPANT	\N	PRESENT	0
754500	753670	19691J	PARTICIPANT	\N	PRESENT	0
754501	753670	14213J	PARTICIPANT	\N	PRESENT	0
754502	753670	20148F	PARTICIPANT	\N	PRESENT	0
754503	753670	04092N	PARTICIPANT	\N	PRESENT	0
754504	753670	14042U	PARTICIPANT	\N	PRESENT	0
754505	753670	18193Q	PARTICIPANT	\N	PRESENT	0
754506	753670	19703U	PARTICIPANT	\N	PRESENT	0
754507	753670	19679N	PARTICIPANT	\N	PRESENT	0
754508	753670	19798U	PARTICIPANT	\N	PRESENT	0
754509	753670	19713W	PARTICIPANT	\N	PRESENT	0
754510	753670	14217N	PARTICIPANT	\N	PRESENT	0
754511	753670	19569H	PARTICIPANT	\N	PRESENT	0
754512	753670	19553Y	PARTICIPANT	\N	PRESENT	0
754513	753670	17965H	PARTICIPANT	\N	PRESENT	0
754514	753670	20090E	PARTICIPANT	\N	EXCUSE	0
754515	753670	19760E	PARTICIPANT	\N	PRESENT	0
754516	753670	19657G	PARTICIPANT	\N	PRESENT	0
754518	753670	08045X	PARTICIPANT	\N	PRESENT	0
754520	753670	21045D	PARTICIPANT	\N	PRESENT	0
754521	753670	17779H	PARTICIPANT	\N	PRESENT	0
754523	753670	21094N	PARTICIPANT	\N	PRESENT	0
754525	753670	01034P	PARTICIPANT	\N	PRESENT	0
754526	753670	14026U	PARTICIPANT	\N	PRESENT	0
754528	753670	14223L	PARTICIPANT	\N	PRESENT	0
754611	753670	21081H	PARTICIPANT	\N	PRESENT	0
761386	760739	19347U	PARTICIPANT	\N	PRESENT	0
761387	760739	20054A	PARTICIPANT	\N	PRESENT	0
761389	760739	19593H	PARTICIPANT	\N	PRESENT	0
761391	760739	20110Q	PARTICIPANT	\N	PRESENT	0
761448	760740	20108W	PARTICIPANT	\N	PRESENT	0
761449	760740	21078N	PARTICIPANT	\N	PRESENT	0
761450	760740	21052C	PARTICIPANT	\N	PRESENT	0
761451	760740	19479G	PARTICIPANT	\N	PRESENT	0
761452	760740	14073Q	PARTICIPANT	\N	PRESENT	0
761453	760740	17023S	PARTICIPANT	\N	PRESENT	0
761454	760740	20098N	PARTICIPANT	\N	PRESENT	0
761455	760740	14147R	PARTICIPANT	\N	PRESENT	0
761456	760740	10015M	PARTICIPANT	\N	PRESENT	0
761457	760740	21058J	PARTICIPANT	\N	PRESENT	0
761458	760740	21054E	PARTICIPANT	\N	PRESENT	0
761459	760740	07004J	PARTICIPANT	\N	PRESENT	0
761460	760740	20110Q	PARTICIPANT	\N	PRESENT	0
761461	760740	11040E	PARTICIPANT	\N	PRESENT	0
761462	760740	21043B	PARTICIPANT	\N	PRESENT	0
761463	760740	19649G	PARTICIPANT	\N	PRESENT	0
761464	760740	20102Q	PARTICIPANT	\N	PRESENT	0
761465	760740	19593H	PARTICIPANT	\N	PRESENT	0
761466	760740	20112S	PARTICIPANT	\N	PRESENT	0
761467	760740	20036X	PARTICIPANT	\N	PRESENT	0
761468	760740	21048G	PARTICIPANT	\N	PRESENT	0
761469	760740	19347U	PARTICIPANT	\N	PRESENT	0
761470	760740	20134Y	PARTICIPANT	\N	PRESENT	0
761471	760740	18231D	PARTICIPANT	\N	PRESENT	0
761472	760740	18207D	PARTICIPANT	\N	PRESENT	0
761473	760740	11053K	PARTICIPANT	\N	PRESENT	0
761474	760740	11090Q	PARTICIPANT	\N	PRESENT	0
761475	760740	14109K	PARTICIPANT	\N	PRESENT	0
761476	760740	04047H	PARTICIPANT	\N	PRESENT	0
761479	760740	19531S	PARTICIPANT	\N	PRESENT	0
761480	760740	20054A	PARTICIPANT	\N	PRESENT	0
761481	760740	21067K	PARTICIPANT	\N	PRESENT	0
761482	760740	19565D	PARTICIPANT	\N	PRESENT	0
761483	760740	21075K	PARTICIPANT	\N	PRESENT	0
761484	760740	20056C	PARTICIPANT	\N	PRESENT	0
761485	760740	21069M	PARTICIPANT	\N	PRESENT	0
761486	760740	21089R	PARTICIPANT	\N	PRESENT	0
761487	760740	14151M	PARTICIPANT	\N	PRESENT	0
761488	760740	21085M	PARTICIPANT	\N	PRESENT	0
761489	760740	14037X	PARTICIPANT	\N	PRESENT	0
761490	760740	14033T	PARTICIPANT	\N	PRESENT	0
761491	760740	14053L	PARTICIPANT	\N	PRESENT	0
761492	760740	20058E	PARTICIPANT	\N	PRESENT	0
761494	760740	17367Q	PARTICIPANT	\N	PRESENT	0
761495	760740	19749K	PARTICIPANT	\N	PRESENT	0
761496	760740	21049H	PARTICIPANT	\N	PRESENT	0
761497	760740	20064C	PARTICIPANT	\N	PRESENT	0
761498	760740	11056N	PARTICIPANT	\N	PRESENT	0
761541	760825	19507S	PARTICIPANT	\N	PRESENT	0
761542	760825	19563B	PARTICIPANT	\N	PRESENT	0
761543	760825	19413M	PARTICIPANT	\N	PRESENT	0
761544	760824	19507S	PARTICIPANT	\N	PRESENT	0
761446	760740	14259Y	PARTICIPANT	\N	PRESENT	0
761447	760740	19687N	PARTICIPANT	\N	PRESENT	0
761545	760824	19563B	PARTICIPANT	\N	PRESENT	0
761546	760824	19413M	PARTICIPANT	\N	PRESENT	0
761547	760826	19507S	PARTICIPANT	\N	PRESENT	0
761548	760826	19563B	PARTICIPANT	\N	PRESENT	0
761549	760826	19413M	PARTICIPANT	\N	PRESENT	0
761550	760827	19507S	PARTICIPANT	\N	PRESENT	0
761551	760827	19563B	PARTICIPANT	\N	PRESENT	0
761552	760827	19413M	PARTICIPANT	\N	PRESENT	0
762547	762546	20090E	PARTICIPANT	\N	PRESENT	0
765729	764908	14042U	PARTICIPANT	\N	PRESENT	0
761556	761553	19563B	PARTICIPANT	\N	PRESENT	0
765723	764908	21046E	PARTICIPANT	\N	PRESENT	0
761559	761557	19563B	PARTICIPANT	\N	PRESENT	0
765724	764908	20090E	PARTICIPANT	\N	PRESENT	0
765725	764908	19798U	PARTICIPANT	\N	PRESENT	0
765726	764908	20140W	PARTICIPANT	\N	PRESENT	0
765727	764908	14026U	PARTICIPANT	\N	PRESENT	0
765728	764908	21097R	PARTICIPANT	\N	PRESENT	0
765730	764908	14071N	PRESIDENT	0	PRESENT	0
765731	764908	20148F	PARTICIPANT	\N	PRESENT	0
765732	764908	21039F	PARTICIPANT	\N	PRESENT	0
765733	764908	19569H	PARTICIPANT	\N	PRESENT	0
765734	764908	14281W	PARTICIPANT	\N	PRESENT	0
765735	764908	19683J	PARTICIPANT	\N	PRESENT	0
765736	764908	20130U	PARTICIPANT	\N	PRESENT	0
765737	764908	04092N	PARTICIPANT	\N	PRESENT	0
765738	764908	19723Y	PARTICIPANT	\N	PRESENT	0
765739	764908	14213J	PARTICIPANT	\N	PRESENT	0
765740	764908	19760E	PARTICIPANT	\N	PRESENT	0
765741	764908	21081H	PARTICIPANT	\N	PRESENT	0
765742	764908	19703U	PARTICIPANT	\N	PRESENT	0
765743	764908	19657G	PARTICIPANT	\N	PRESENT	0
765744	764908	14217N	PARTICIPANT	\N	PRESENT	0
765769	765398	14111D	PARTICIPANT	\N	PRESENT	0
765770	765398	14042U	PARTICIPANT	\N	PRESENT	0
765771	765398	14195A	PARTICIPANT	\N	PRESENT	0
765772	765398	21090J	PARTICIPANT	\N	PRESENT	0
765773	765398	20090E	PARTICIPANT	\N	PRESENT	0
765774	765398	19798U	PARTICIPANT	\N	PRESENT	0
765775	765398	14213J	PARTICIPANT	\N	PRESENT	0
765776	765398	14026U	PARTICIPANT	\N	PRESENT	0
765777	765398	19569H	PARTICIPANT	\N	PRESENT	0
765778	765398	21085M	PARTICIPANT	\N	PRESENT	0
765779	765398	21069M	PARTICIPANT	\N	PRESENT	0
765780	765398	19691J	PARTICIPANT	\N	PRESENT	0
765781	765398	21046E	PARTICIPANT	\N	PRESENT	0
765782	765398	14071N	PARTICIPANT	\N	PRESENT	0
765783	765398	14217N	PARTICIPANT	\N	PRESENT	0
765784	765398	11070L	PARTICIPANT	\N	PRESENT	0
765785	765398	20062A	PARTICIPANT	\N	PRESENT	0
765786	765398	19683J	PARTICIPANT	\N	PRESENT	0
765787	765398	21087P	PARTICIPANT	\N	PRESENT	0
765788	765398	17779H	PARTICIPANT	\N	PRESENT	0
765789	765398	19703U	PARTICIPANT	\N	PRESENT	0
765791	765398	19367Y	PARTICIPANT	\N	PRESENT	0
765792	765398	18193Q	PARTICIPANT	\N	PRESENT	0
765793	765398	14281W	PARTICIPANT	\N	PRESENT	0
765794	765398	19758L	PARTICIPANT	\N	PRESENT	0
765796	765398	19657G	PARTICIPANT	\N	PRESENT	0
765798	765398	19760E	PARTICIPANT	\N	PRESENT	0
765799	765398	01034P	PARTICIPANT	\N	PRESENT	0
765800	765398	21081H	PARTICIPANT	\N	PRESENT	0
765801	765398	04092N	PARTICIPANT	\N	PRESENT	0
765802	765398	20130U	PARTICIPANT	\N	PRESENT	0
765803	765398	19866P	PARTICIPANT	\N	PRESENT	0
755872	755868	14219Q	PARTICIPANT	\N	PRESENT	0
753646	752388	14089Y	PARTICIPANT	\N	PRESENT	0
753647	752388	14053L	PARTICIPANT	\N	PRESENT	0
755873	755868	20136B	PARTICIPANT	\N	PRESENT	0
755875	755874	12028B	PARTICIPANT	\N	PRESENT	0
755876	755874	14267Y	PARTICIPANT	\N	PRESENT	0
755877	755874	08010L	PARTICIPANT	\N	PRESENT	0
755879	755878	04070G	PARTICIPANT	\N	PRESENT	0
755880	755878	20056C	PARTICIPANT	\N	PRESENT	0
755883	755882	20112S	PARTICIPANT	\N	PRESENT	0
755884	755881	19699S	PARTICIPANT	\N	PRESENT	0
755889	755888	20058E	PARTICIPANT	\N	PRESENT	0
755890	755888	20264J	PARTICIPANT	\N	PRESENT	0
755891	755887	20058E	PARTICIPANT	\N	PRESENT	1
755892	755887	14123H	PARTICIPANT	\N	PRESENT	1
755893	755887	20264J	PARTICIPANT	\N	PRESENT	1
755894	755886	20058E	PARTICIPANT	\N	PRESENT	0
755895	755886	20264J	PARTICIPANT	\N	PRESENT	0
755896	755886	20180F	PARTICIPANT	\N	PRESENT	0
755897	755886	14229S	PARTICIPANT	\N	PRESENT	0
755898	755886	14026U	PARTICIPANT	\N	PRESENT	0
755899	755885	20058E	PARTICIPANT	\N	PRESENT	0
755922	755921	11040E	PARTICIPANT	\N	PRESENT	0
755923	755921	14331P	PARTICIPANT	\N	PRESENT	0
755924	755921	21079P	PARTICIPANT	\N	PRESENT	0
755925	755921	07004J	PARTICIPANT	\N	PRESENT	0
755926	755921	19687N	PARTICIPANT	\N	PRESENT	0
755927	755921	20116W	PARTICIPANT	\N	PRESENT	0
755928	755921	20044X	PARTICIPANT	\N	PRESENT	0
755929	755921	20024T	PARTICIPANT	\N	PRESENT	0
755930	755921	21048G	PARTICIPANT	\N	PRESENT	0
755931	755921	21041Y	PARTICIPANT	\N	PRESENT	0
755932	755921	21090J	PARTICIPANT	\N	PRESENT	0
755933	755921	14225N	PRESIDENT	0	PRESENT	0
755934	755921	11048N	PARTICIPANT	\N	PRESENT	0
755935	755921	19545Y	PARTICIPANT	\N	PRESENT	0
755936	755921	11070L	PARTICIPANT	\N	PRESENT	0
755937	755921	07029T	PARTICIPANT	\N	PRESENT	0
755938	755921	19349W	PARTICIPANT	\N	PRESENT	0
755939	755921	21072G	PARTICIPANT	\N	PRESENT	0
755940	755921	19647E	PARTICIPANT	\N	PRESENT	0
755941	755921	20070A	PARTICIPANT	\N	PRESENT	0
755942	755921	19711U	PARTICIPANT	\N	PRESENT	0
755947	755857	14111D	PARTICIPANT	\N	PRESENT	0
755948	755857	11048N	PARTICIPANT	\N	PRESENT	0
755949	755857	14225N	PARTICIPANT	\N	PRESENT	0
755950	755857	19687N	PARTICIPANT	\N	PRESENT	0
755951	755857	21069M	PARTICIPANT	\N	PRESENT	0
755952	755857	19545Y	PARTICIPANT	\N	PRESENT	0
755953	755857	11070L	PARTICIPANT	\N	PRESENT	0
755954	755857	20134Y	PARTICIPANT	\N	PRESENT	0
755955	755857	11040E	PARTICIPANT	\N	PRESENT	0
755956	755857	20116W	PARTICIPANT	\N	PRESENT	0
755957	755857	19349W	PARTICIPANT	\N	PRESENT	0
755958	755857	20044X	PARTICIPANT	\N	PRESENT	0
755959	755857	19711U	PARTICIPANT	\N	PRESENT	0
755969	755857	21086N	PARTICIPANT	\N	PRESENT	0
755970	755857	21053D	PARTICIPANT	\N	PRESENT	0
755971	755857	07029T	PARTICIPANT	\N	PRESENT	0
755972	755857	21090J	PARTICIPANT	\N	PRESENT	0
755973	755857	21034A	PARTICIPANT	\N	PRESENT	0
755974	755857	21079P	PARTICIPANT	\N	PRESENT	0
755975	755857	19647E	PARTICIPANT	\N	PRESENT	0
755976	755857	20052X	PARTICIPANT	\N	PRESENT	0
755977	755857	21075K	PARTICIPANT	\N	PRESENT	0
755978	755857	99004R	PARTICIPANT	\N	PRESENT	0
755979	755857	20024T	PARTICIPANT	\N	PRESENT	0
755980	755857	21072G	PARTICIPANT	\N	PRESENT	0
755981	755857	21093M	PARTICIPANT	\N	PRESENT	0
755982	755857	07004J	PARTICIPANT	\N	PRESENT	0
755983	755857	20070A	PARTICIPANT	\N	PRESENT	0
755984	755857	21041Y	PARTICIPANT	\N	PRESENT	0
755985	755857	21048G	PARTICIPANT	\N	PRESENT	0
755986	755857	14021P	PARTICIPANT	\N	PRESENT	0
755987	755857	20080C	PARTICIPANT	\N	PRESENT	0
755988	755857	19573D	PARTICIPANT	\N	PRESENT	0
755989	755857	19679N	PARTICIPANT	\N	PRESENT	0
755990	755857	19479G	PARTICIPANT	\N	PRESENT	0
755991	755857	21085M	PARTICIPANT	\N	PRESENT	0
755992	755857	11110B	PARTICIPANT	\N	PRESENT	0
755993	755857	19563B	PARTICIPANT	\N	PRESENT	0
755994	755857	21092L	PARTICIPANT	\N	PRESENT	0
755995	755857	19667J	PARTICIPANT	\N	PRESENT	0
755996	755857	14217N	PARTICIPANT	\N	PRESENT	0
755997	755857	21091K	PARTICIPANT	\N	PRESENT	0
755998	755857	19447X	PARTICIPANT	\N	PRESENT	0
756000	755857	17965H	PARTICIPANT	\N	PRESENT	0
756001	755857	20076G	PARTICIPANT	\N	PRESENT	0
756002	755857	20136B	PARTICIPANT	\N	PRESENT	0
756003	755857	21088Q	PARTICIPANT	\N	PRESENT	0
756004	755857	11085T	PARTICIPANT	\N	PRESENT	0
756005	755857	14037X	PARTICIPANT	\N	PRESENT	0
756006	755857	14331P	PARTICIPANT	\N	PRESENT	0
756007	755857	08011M	PARTICIPANT	\N	PRESENT	0
756008	755857	20054A	PARTICIPANT	\N	PRESENT	0
756009	755857	19551W	PARTICIPANT	\N	PRESENT	0
756010	755857	14187A	PARTICIPANT	\N	PRESENT	0
756011	755857	08061X	PARTICIPANT	\N	PRESENT	0
756012	755857	08010L	PARTICIPANT	\N	PRESENT	0
756013	755857	21051B	PARTICIPANT	\N	PRESENT	0
756016	755857	20126Y	PARTICIPANT	\N	PRESENT	0
756020	755857	20062A	PARTICIPANT	\N	PRESENT	0
756295	756143	19760E	PARTICIPANT	\N	PRESENT	0
756296	756143	14217N	PARTICIPANT	\N	PRESENT	0
756298	756143	20130U	PARTICIPANT	\N	PRESENT	0
756299	756293	14217N	PARTICIPANT	\N	PRESENT	0
756633	754622	21087P	PARTICIPANT	\N	EXCUSE	0
756634	754622	21077M	PARTICIPANT	\N	EXCUSE	0
756635	754622	19798U	PARTICIPANT	\N	PRESENT	0
756636	754622	14109K	PARTICIPANT	\N	EXCUSE	0
756637	754622	20034V	PARTICIPANT	\N	EXCUSE	0
756638	754622	14179A	PARTICIPANT	\N	PRESENT	0
756639	754622	14189C	PARTICIPANT	\N	EXCUSE	0
756640	754622	19553Y	PARTICIPANT	\N	EXCUSE	0
756641	754622	20038A	PRESIDENT	0	PRESENT	0
756935	755515	19629C	PARTICIPANT	\N	PRESENT	0
756936	755515	20130U	PARTICIPANT	\N	PRESENT	0
757036	755515	19866P	PARTICIPANT	\N	PRESENT	0
757037	755515	21094N	PARTICIPANT	\N	PRESENT	0
757038	755515	11045K	PARTICIPANT	\N	PRESENT	0
757040	755537	01034P	PARTICIPANT	\N	PRESENT	0
757041	755537	19683J	PARTICIPANT	\N	PRESENT	0
757042	755537	21081H	PARTICIPANT	\N	PRESENT	0
757043	755537	20130U	PARTICIPANT	\N	PRESENT	0
757044	755537	14281W	PARTICIPANT	\N	PRESENT	0
757045	755537	19629C	PARTICIPANT	\N	PRESENT	0
757046	755537	20090E	PARTICIPANT	\N	PRESENT	0
757047	755537	19591F	PARTICIPANT	\N	PRESENT	0
757048	755537	19723Y	PARTICIPANT	\N	PRESENT	0
757049	755537	08061X	PARTICIPANT	\N	PRESENT	0
757050	755537	14213J	PARTICIPANT	\N	PRESENT	0
757051	755537	19760E	PARTICIPANT	\N	PRESENT	0
757052	755537	21039F	PARTICIPANT	\N	PRESENT	0
757053	755537	20148F	PARTICIPANT	\N	PRESENT	0
757054	755537	21064G	PARTICIPANT	\N	PRESENT	0
757055	755537	18193Q	PARTICIPANT	\N	PRESENT	0
757056	755537	21045D	PARTICIPANT	\N	PRESENT	0
757057	755537	14026U	PARTICIPANT	\N	PRESENT	0
757058	755537	14071N	PRESIDENT	0	PRESENT	0
757059	755537	08045X	PARTICIPANT	\N	PRESENT	0
757061	755537	04092N	PARTICIPANT	\N	PRESENT	0
757062	755537	19569H	PARTICIPANT	\N	PRESENT	0
757063	755537	19758L	PARTICIPANT	\N	PRESENT	0
757064	755537	14195A	PARTICIPANT	\N	PRESENT	0
757065	755537	14217N	PARTICIPANT	\N	PRESENT	0
757066	755537	14223L	PARTICIPANT	\N	PRESENT	0
757067	755537	19691J	PARTICIPANT	\N	PRESENT	0
757068	755537	19657G	PARTICIPANT	\N	PRESENT	0
757069	755537	11045K	PARTICIPANT	\N	PRESENT	0
757070	755537	19679N	PARTICIPANT	\N	PRESENT	0
757071	755537	21094N	PARTICIPANT	\N	PRESENT	0
757072	755537	17779H	PARTICIPANT	\N	EXCUSE	0
757073	755537	21087P	PARTICIPANT	\N	EXCUSE	0
757074	755537	21046E	PARTICIPANT	\N	EXCUSE	0
757075	755537	21071F	PARTICIPANT	\N	PRESENT	0
757076	755537	14042U	PARTICIPANT	\N	PRESENT	0
757077	755537	19866P	PARTICIPANT	\N	PRESENT	0
757078	755537	19713W	PARTICIPANT	\N	PRESENT	0
757079	755537	21049H	PARTICIPANT	\N	PRESENT	0
740757	740756	11048N	PARTICIPANT	\N	PRESENT	0
740759	740758	11074Q	PARTICIPANT	\N	PRESENT	0
740760	740758	19349W	PARTICIPANT	\N	PRESENT	0
740762	740761	20050V	PARTICIPANT	\N	PRESENT	0
740767	740766	20116W	PARTICIPANT	\N	PRESENT	0
740769	740768	20086J	PARTICIPANT	\N	PRESENT	0
746201	746023	04047H	PARTICIPANT	\N	PRESENT	0
746202	746023	11064N	PARTICIPANT	\N	PRESENT	0
746203	746023	14111D	PARTICIPANT	\N	PRESENT	0
746204	746023	14083S	PARTICIPANT	\N	PRESENT	0
746205	746023	04033B	PARTICIPANT	\N	PRESENT	0
746206	746023	08028W	PARTICIPANT	\N	PRESENT	0
746207	746023	20252E	PARTICIPANT	\N	PRESENT	0
746208	746023	05008E	PARTICIPANT	\N	PRESENT	0
746209	746023	08056B	PARTICIPANT	\N	PRESENT	0
746210	746023	20086J	PARTICIPANT	\N	PRESENT	0
746211	746023	11010L	PARTICIPANT	\N	PRESENT	0
746212	746023	08047A	PARTICIPANT	\N	PRESENT	0
746213	746023	14053L	PARTICIPANT	\N	PRESENT	0
746214	746023	11097X	PARTICIPANT	\N	PRESENT	0
746216	746023	19507S	PARTICIPANT	\N	PRESENT	0
746224	746023	19758L	PARTICIPANT	\N	PRESENT	0
746228	746023	11031D	PARTICIPANT	\N	PRESENT	0
746229	746023	20112S	PARTICIPANT	\N	PRESENT	0
746230	746023	04057K	PARTICIPANT	\N	PRESENT	0
746231	746023	19479G	PARTICIPANT	\N	PRESENT	0
746232	746023	14211G	PARTICIPANT	\N	PRESENT	0
746233	746023	20048C	PARTICIPANT	\N	PRESENT	0
746234	746023	97011G	PARTICIPANT	\N	PRESENT	0
746235	746023	14169X	PARTICIPANT	\N	PRESENT	0
746236	746023	08069G	PARTICIPANT	\N	PRESENT	0
746237	746023	19798U	PARTICIPANT	\N	PRESENT	0
746238	746023	18083K	PARTICIPANT	\N	PRESENT	0
746239	746023	20080C	PARTICIPANT	\N	PRESENT	0
746240	746023	19747H	PARTICIPANT	\N	PRESENT	0
746241	746023	01024M	PARTICIPANT	\N	PRESENT	0
746242	746023	20020P	PARTICIPANT	\N	PRESENT	0
746243	746023	14249W	PARTICIPANT	\N	PRESENT	0
746244	746023	11080N	PARTICIPANT	\N	PRESENT	0
746245	746023	19549D	PARTICIPANT	\N	PRESENT	0
746246	746023	19573D	PARTICIPANT	\N	PRESENT	0
746247	746023	17589D	PARTICIPANT	\N	PRESENT	0
746248	746023	16685X	PARTICIPANT	\N	PRESENT	0
746249	746023	19679N	PARTICIPANT	\N	PRESENT	0
746250	746023	14097Y	PARTICIPANT	\N	PRESENT	0
746251	746023	19739H	PARTICIPANT	\N	PRESENT	0
746252	746023	20144B	PARTICIPANT	\N	PRESENT	0
746253	746023	20136B	PARTICIPANT	\N	PRESENT	0
746254	746023	01057W	PARTICIPANT	\N	PRESENT	0
746255	746023	11085T	PARTICIPANT	\N	PRESENT	0
746256	746023	04035D	PARTICIPANT	\N	PRESENT	0
746291	746023	19647E	PARTICIPANT	\N	PRESENT	0
746258	746023	14207L	PARTICIPANT	\N	PRESENT	0
746259	746023	14059S	PARTICIPANT	\N	PRESENT	0
746260	746023	19569H	PARTICIPANT	\N	PRESENT	0
746261	746023	20038A	PARTICIPANT	\N	PRESENT	0
746262	746023	04085P	PARTICIPANT	\N	PRESENT	0
746263	746023	19467C	PARTICIPANT	\N	PRESENT	0
746264	746023	20056C	PARTICIPANT	\N	PRESENT	0
746265	746023	11104D	PARTICIPANT	\N	PRESENT	0
746266	746023	14223L	PARTICIPANT	\N	PRESENT	0
746267	746023	05012A	PARTICIPANT	\N	PRESENT	0
746268	746023	20032T	PARTICIPANT	\N	PRESENT	0
746269	746023	19741B	PARTICIPANT	\N	PRESENT	0
746270	746023	19367Y	PARTICIPANT	\N	PRESENT	0
746271	746023	08009T	PARTICIPANT	\N	PRESENT	0
746272	746023	20044X	PARTICIPANT	\N	PRESENT	0
746273	746023	20070A	PARTICIPANT	\N	PRESENT	0
746274	746023	20142Y	PARTICIPANT	\N	PRESENT	0
746275	746023	20098N	PARTICIPANT	\N	PRESENT	0
746276	746023	14123H	PARTICIPANT	\N	PRESENT	0
746278	744229	11048N	PARTICIPANT	\N	PRESENT	0
746279	744229	04071H	PARTICIPANT	\N	PRESENT	0
746280	744229	19479G	PARTICIPANT	\N	PRESENT	0
746281	744229	19711U	PARTICIPANT	\N	PRESENT	0
746282	744229	19531S	PARTICIPANT	\N	PRESENT	0
746283	744229	01057W	PARTICIPANT	\N	PRESENT	0
746284	744229	20050V	PARTICIPANT	\N	PRESENT	0
746285	744229	19741B	PARTICIPANT	\N	PRESENT	0
746286	744229	20116W	PARTICIPANT	\N	PRESENT	0
746287	744229	14033T	PARTICIPANT	\N	PRESENT	0
746288	744229	14225N	PRESIDENT	0	PRESENT	0
746289	744229	19762G	PARTICIPANT	\N	PRESENT	0
746290	744229	20044X	PARTICIPANT	\N	PRESENT	0
746293	744229	20126Y	PARTICIPANT	\N	PRESENT	0
746294	744229	20086J	PARTICIPANT	\N	PRESENT	0
746295	746023	20058E	PARTICIPANT	\N	PRESENT	0
746296	746023	14151M	PARTICIPANT	\N	PRESENT	0
746297	746023	08015R	PARTICIPANT	\N	PRESENT	0
746298	746023	07033P	PARTICIPANT	\N	PRESENT	0
746299	746023	19387D	PARTICIPANT	\N	PRESENT	0
746300	746023	14215L	PARTICIPANT	\N	PRESENT	0
746301	746023	20124W	PARTICIPANT	\N	PRESENT	0
746302	746023	01025N	PARTICIPANT	\N	PRESENT	0
746303	746023	19413M	PARTICIPANT	\N	PRESENT	0
746304	746023	14109K	PARTICIPANT	\N	PRESENT	0
746305	746023	14255U	PARTICIPANT	\N	PRESENT	0
746306	746023	14031R	PARTICIPANT	\N	PRESENT	0
746333	746023	20062A	PARTICIPANT	\N	PRESENT	0
746334	746023	14147R	PARTICIPANT	\N	PRESENT	0
746335	746023	20180F	PARTICIPANT	\N	PRESENT	0
746336	746023	19651A	PARTICIPANT	\N	PRESENT	0
746338	746081	04070G	PRESIDENT	0	PRESENT	0
746339	746081	11077T	PARTICIPANT	\N	PRESENT	0
746340	746081	20082E	PARTICIPANT	\N	PRESENT	0
746341	746081	20094J	PARTICIPANT	\N	PRESENT	0
746342	746081	14229S	PARTICIPANT	\N	PRESENT	0
746343	746081	20098N	PARTICIPANT	\N	PRESENT	0
746344	746081	14147R	PARTICIPANT	\N	PRESENT	0
746345	746081	14179A	PARTICIPANT	\N	PRESENT	0
746346	746081	14151M	PARTICIPANT	\N	PRESENT	0
746347	746081	20022R	PARTICIPANT	\N	PRESENT	0
746348	746081	14038Y	PARTICIPANT	\N	PRESENT	0
746349	746081	19593H	PARTICIPANT	\N	PRESENT	0
746350	746081	20132W	PARTICIPANT	\N	PRESENT	0
746351	746081	19647E	PARTICIPANT	\N	PRESENT	0
746352	746081	20134Y	PARTICIPANT	\N	PRESENT	0
746353	746081	20034V	PARTICIPANT	\N	PRESENT	0
746354	746081	20122U	PARTICIPANT	\N	PRESENT	0
746355	746081	19651A	PARTICIPANT	\N	PRESENT	0
746356	746081	20138D	PARTICIPANT	\N	PRESENT	0
746357	746081	11045K	PARTICIPANT	\N	PRESENT	0
746358	746081	20140W	PARTICIPANT	\N	PRESENT	0
746359	746081	20052X	PARTICIPANT	\N	PRESENT	0
746360	746081	14030Q	PARTICIPANT	\N	PRESENT	0
746361	746081	14205J	PARTICIPANT	\N	PRESENT	0
746362	746081	20060X	PARTICIPANT	\N	PRESENT	0
746363	746081	20062A	PARTICIPANT	\N	PRESENT	0
746364	746023	14331P	PARTICIPANT	\N	PRESENT	0
746366	746023	20034V	PARTICIPANT	\N	PRESENT	0
746367	746023	20082E	PARTICIPANT	\N	PRESENT	0
746385	746023	08010L	PARTICIPANT	\N	PRESENT	0
746370	746023	14179A	PARTICIPANT	\N	PRESENT	0
746371	746023	04045F	PARTICIPANT	\N	PRESENT	0
746372	746023	20054A	PARTICIPANT	\N	PRESENT	0
746373	746023	19533U	PARTICIPANT	\N	PRESENT	0
746374	746023	20026V	PARTICIPANT	\N	PRESENT	0
746377	746023	20264J	PARTICIPANT	\N	PRESENT	0
746382	746023	20104S	PARTICIPANT	\N	PRESENT	0
746387	746023	20134Y	PARTICIPANT	\N	PRESENT	0
746388	746023	19441R	PARTICIPANT	\N	PRESENT	0
746390	746023	19762G	PARTICIPANT	\N	PRESENT	0
746391	746023	11048N	PARTICIPANT	\N	PRESENT	0
746392	746023	20052X	PARTICIPANT	\N	PRESENT	0
746393	746023	20116W	PARTICIPANT	\N	PRESENT	0
746404	746023	20092G	PARTICIPANT	\N	PRESENT	0
746395	746023	19697Q	PARTICIPANT	\N	PRESENT	0
746396	746023	20022R	PARTICIPANT	\N	PRESENT	0
746397	746023	20088L	PARTICIPANT	\N	PRESENT	0
746398	746023	14219Q	PARTICIPANT	\N	PRESENT	0
746399	746023	14026U	PARTICIPANT	\N	PRESENT	0
746400	746023	20126Y	PARTICIPANT	\N	PRESENT	0
746401	746023	14205J	PARTICIPANT	\N	PRESENT	0
746402	746023	19369B	PARTICIPANT	\N	PRESENT	0
746403	746023	20100N	PARTICIPANT	\N	PRESENT	0
746405	746023	19503N	PARTICIPANT	\N	PRESENT	0
746406	746023	20172F	PARTICIPANT	\N	PRESENT	0
746407	746023	14225N	PARTICIPANT	\N	PRESENT	0
746408	746023	20102Q	PARTICIPANT	\N	PRESENT	0
746409	746023	14071N	PARTICIPANT	\N	PRESENT	0
746410	746023	19713W	PARTICIPANT	\N	PRESENT	0
759277	759276	14042U	PARTICIPANT	\N	PRESENT	0
759278	759276	14026U	PARTICIPANT	\N	PRESENT	0
759366	757735	20266L	PARTICIPANT	\N	PRESENT	0
759367	757735	21057H	PARTICIPANT	\N	PRESENT	0
759368	757735	19111A	PARTICIPANT	\N	PRESENT	0
759411	757735	19585H	PARTICIPANT	\N	PRESENT	0
759412	757735	14111D	PARTICIPANT	\N	PRESENT	0
759418	757735	19729F	PARTICIPANT	\N	PRESENT	0
759419	757735	14151M	PARTICIPANT	\N	PRESENT	0
759470	759423	14217N	PARTICIPANT	\N	PRESENT	0
759471	759424	14217N	PARTICIPANT	\N	PRESENT	0
759472	759468	14217N	PARTICIPANT	\N	PRESENT	0
759473	759469	14217N	PARTICIPANT	\N	PRESENT	0
763115	763072	19593H	PARTICIPANT	\N	PRESENT	0
763116	763072	20132W	PARTICIPANT	\N	PRESENT	0
763117	763072	21055F	PARTICIPANT	\N	PRESENT	0
763118	763072	20122U	PARTICIPANT	\N	PRESENT	0
763119	763072	20138D	PARTICIPANT	\N	PRESENT	0
763120	763072	19611R	PRESIDENT	0	PRESENT	0
763121	763072	20142Y	PARTICIPANT	\N	PRESENT	0
763122	763072	20048C	PARTICIPANT	\N	PRESENT	0
763123	763072	19693L	PARTICIPANT	\N	PRESENT	0
763124	763072	20052X	PARTICIPANT	\N	PRESENT	0
763125	763072	20172F	PARTICIPANT	\N	PRESENT	0
763126	763072	14030Q	PARTICIPANT	\N	PRESENT	0
763127	763072	20056C	PARTICIPANT	\N	PRESENT	0
763128	763072	21063F	PARTICIPANT	\N	PRESENT	0
763129	763072	20264J	PARTICIPANT	\N	PRESENT	0
763130	763072	19735D	PARTICIPANT	\N	PRESENT	0
763131	763072	14109K	PARTICIPANT	\N	PRESENT	0
763132	763072	21077M	PARTICIPANT	\N	PRESENT	0
763133	763072	19621T	PARTICIPANT	\N	PRESENT	0
763134	763072	21074J	PARTICIPANT	\N	EXCUSE	0
763135	762589	20104S	PARTICIPANT	\N	PRESENT	0
763136	762589	21050A	PARTICIPANT	\N	PRESENT	0
763139	762589	20092G	PARTICIPANT	\N	PRESENT	0
763143	761182	14327T	PARTICIPANT	\N	PRESENT	0
763144	761182	20086J	PARTICIPANT	\N	PRESENT	0
763145	761182	11048N	PARTICIPANT	\N	PRESENT	0
763146	761182	20080C	PARTICIPANT	\N	PRESENT	0
763147	761182	14121F	PARTICIPANT	\N	PRESENT	0
763148	761182	14253S	PARTICIPANT	\N	PRESENT	0
763149	761182	21090J	PARTICIPANT	\N	PRESENT	0
763150	761182	14225N	PRESIDENT	0	PRESENT	0
763151	761593	20130U	PARTICIPANT	\N	PRESENT	0
763153	761593	19367Y	PARTICIPANT	\N	PRESENT	0
763157	761593	19629C	PARTICIPANT	\N	PRESENT	0
763158	761593	19591F	PARTICIPANT	\N	PRESENT	0
763164	762589	19768N	PARTICIPANT	\N	PRESENT	0
763165	762589	14221J	PARTICIPANT	\N	PRESENT	0
763166	762589	21086N	PARTICIPANT	\N	PRESENT	0
763167	762589	20054A	PARTICIPANT	\N	PRESENT	0
763170	763169	19729F	PARTICIPANT	\N	PRESENT	0
763171	762589	19383Y	PARTICIPANT	\N	PRESENT	0
763172	762589	20060X	PARTICIPANT	\N	PRESENT	0
763173	762589	14207L	PARTICIPANT	\N	PRESENT	0
763174	762589	14357A	PARTICIPANT	\N	PRESENT	0
763175	762589	19507S	PARTICIPANT	\N	PRESENT	0
763176	762589	20144B	PARTICIPANT	\N	EXCUSE	0
763178	761593	17779H	PARTICIPANT	\N	PRESENT	0
763179	763177	05008E	PARTICIPANT	\N	PRESENT	0
763245	761593	11045K	PARTICIPANT	\N	PRESENT	0
763295	762589	14205J	PARTICIPANT	\N	PRESENT	0
763418	761566	20022R	PARTICIPANT	\N	EXCUSE	0
763419	761566	19719D	PARTICIPANT	\N	EXCUSE	0
763420	761566	14215L	PARTICIPANT	\N	EXCUSE	0
763421	761566	20108W	PARTICIPANT	\N	EXCUSE	0
763422	761566	19729F	PARTICIPANT	\N	EXCUSE	0
763423	761566	11072N	PARTICIPANT	\N	EXCUSE	0
763424	761566	04045F	PARTICIPANT	\N	EXCUSE	0
763425	761566	21076L	PARTICIPANT	\N	EXCUSE	0
763429	761567	20022R	PARTICIPANT	\N	EXCUSE	0
763430	761567	14215L	PARTICIPANT	\N	EXCUSE	0
763431	761567	20108W	PARTICIPANT	\N	EXCUSE	0
763433	761567	19729F	PARTICIPANT	\N	EXCUSE	0
763434	761567	11072N	PARTICIPANT	\N	EXCUSE	0
763436	761567	04045F	PARTICIPANT	\N	EXCUSE	0
763438	761567	21076L	PARTICIPANT	\N	EXCUSE	0
763449	761713	14223L	PARTICIPANT	\N	PRESENT	0
763451	761713	19507S	PARTICIPANT	\N	PRESENT	0
763452	761713	19531S	PARTICIPANT	\N	PRESENT	0
763453	761713	21070E	PARTICIPANT	\N	PRESENT	0
763454	761713	19399H	PARTICIPANT	\N	PRESENT	0
763455	761713	08018U	PARTICIPANT	\N	PRESENT	0
763456	761713	21055F	PARTICIPANT	\N	PRESENT	0
763457	761713	14073Q	PARTICIPANT	\N	PRESENT	0
763458	761713	08060W	PARTICIPANT	\N	PRESENT	0
763459	761713	21049H	PARTICIPANT	\N	PRESENT	0
763460	761713	19331L	PARTICIPANT	\N	PRESENT	0
763461	761713	20072C	PARTICIPANT	\N	PRESENT	0
763462	761713	19479G	PARTICIPANT	\N	PRESENT	0
763463	761713	19619A	PARTICIPANT	\N	PRESENT	0
763464	761713	98022P	PARTICIPANT	\N	PRESENT	0
763465	761713	20088L	PARTICIPANT	\N	PRESENT	0
763466	761713	17779H	PARTICIPANT	\N	PRESENT	0
763467	761713	20134Y	PARTICIPANT	\N	PRESENT	0
763468	761713	21031W	PARTICIPANT	\N	PRESENT	0
763469	761713	21077M	PARTICIPANT	\N	PRESENT	0
763470	761713	21078N	PARTICIPANT	\N	PRESENT	0
763471	761713	14111D	PARTICIPANT	\N	PRESENT	0
763472	761713	21067K	PARTICIPANT	\N	PRESENT	0
763473	761713	21059K	PARTICIPANT	\N	PRESENT	0
763474	761713	20028X	PARTICIPANT	\N	PRESENT	0
763475	761713	19347U	PARTICIPANT	\N	PRESENT	0
763477	761713	19693L	PARTICIPANT	\N	PRESENT	0
763480	761713	21053D	PARTICIPANT	\N	PRESENT	0
763481	761713	21083K	PARTICIPANT	\N	PRESENT	0
763482	761713	20052X	PARTICIPANT	\N	PRESENT	0
763483	761713	08034U	PARTICIPANT	\N	PRESENT	0
763484	761713	19703U	PARTICIPANT	\N	PRESENT	0
763485	761713	21044C	PARTICIPANT	\N	PRESENT	0
763486	761713	21058J	PARTICIPANT	\N	PRESENT	0
763487	761713	20026V	PARTICIPANT	\N	PRESENT	0
763488	761713	20056C	PARTICIPANT	\N	PRESENT	0
763489	761713	19679N	PARTICIPANT	\N	PRESENT	0
763490	761713	04033B	PARTICIPANT	\N	PRESENT	0
763491	761713	21050A	PARTICIPANT	\N	PRESENT	0
763492	761713	14053L	PARTICIPANT	\N	PRESENT	0
763493	761713	14030Q	PARTICIPANT	\N	PRESENT	0
763494	761713	21087P	PARTICIPANT	\N	PRESENT	0
763495	761713	11090Q	PARTICIPANT	\N	PRESENT	0
763496	761713	05012A	PARTICIPANT	\N	PRESENT	0
763498	761713	14253S	PARTICIPANT	\N	PRESENT	0
763499	761713	07033P	PARTICIPANT	\N	PRESENT	0
763500	761713	14331P	PARTICIPANT	\N	PRESENT	0
763501	761713	04047H	PARTICIPANT	\N	PRESENT	0
763502	761713	20104S	PARTICIPANT	\N	PRESENT	0
763503	761713	11048N	PARTICIPANT	\N	PRESENT	0
763505	761713	20034V	PARTICIPANT	\N	PRESENT	0
763506	761713	14187A	PARTICIPANT	\N	PRESENT	0
763507	761713	14329V	PARTICIPANT	\N	PRESENT	0
763508	761713	14357A	PARTICIPANT	\N	PRESENT	0
763509	761713	08015R	PARTICIPANT	\N	PRESENT	0
763510	761713	14193X	PARTICIPANT	\N	PRESENT	0
763511	761713	21072G	PARTICIPANT	\N	PRESENT	0
763514	761713	19621T	PARTICIPANT	\N	PRESENT	0
763515	761713	18083K	PARTICIPANT	\N	PRESENT	0
763516	761713	19711U	PARTICIPANT	\N	PRESENT	0
763517	761713	04008A	PARTICIPANT	\N	PRESENT	0
763518	761713	19367Y	PARTICIPANT	\N	PRESENT	0
763519	761713	08011M	PARTICIPANT	\N	PRESENT	0
763520	761713	21091K	PARTICIPANT	\N	PRESENT	0
763521	761713	19575F	PARTICIPANT	\N	PRESENT	0
763522	761713	01058X	PARTICIPANT	\N	PRESENT	0
763523	761713	99004R	PARTICIPANT	\N	PRESENT	0
763524	761713	20074E	PARTICIPANT	\N	PRESENT	0
763525	761713	14259Y	PARTICIPANT	\N	PRESENT	0
763526	761713	20076G	PARTICIPANT	\N	PRESENT	0
763527	761713	20078J	PARTICIPANT	\N	PRESENT	0
763528	761713	14123H	PARTICIPANT	\N	PRESENT	0
763529	761713	21080G	PARTICIPANT	\N	PRESENT	0
763530	761713	21061D	PARTICIPANT	\N	PRESENT	0
763531	761713	19573D	PARTICIPANT	\N	PRESENT	0
763532	761713	11043H	PARTICIPANT	\N	PRESENT	0
763533	761713	21071F	PARTICIPANT	\N	PRESENT	0
763534	761713	14237S	PARTICIPANT	\N	PRESENT	0
763535	761713	20044X	PARTICIPANT	\N	PRESENT	0
763536	761713	10015M	PARTICIPANT	\N	PRESENT	0
763537	761713	19673G	PARTICIPANT	\N	PRESENT	0
763538	761713	04042C	PARTICIPANT	\N	PRESENT	0
763539	761713	19667J	PARTICIPANT	\N	PRESENT	0
740205	740204	20142Y	PARTICIPANT	\N	PRESENT	0
740206	740204	19691J	PARTICIPANT	\N	PRESENT	0
740207	740204	19758L	PARTICIPANT	\N	PRESENT	0
740208	740204	20980G	PARTICIPANT	\N	PRESENT	0
740209	740204	20026V	PARTICIPANT	\N	PRESENT	0
740210	740204	20038A	PARTICIPANT	\N	PRESENT	0
740211	740204	19335Q	PRESIDENT	0	PRESENT	0
740212	740204	20106U	PARTICIPANT	\N	PRESENT	0
740218	740217	19621T	PARTICIPANT	\N	PRESENT	0
740219	740217	14030Q	PARTICIPANT	\N	PRESENT	0
740220	740217	14109K	PARTICIPANT	\N	PRESENT	0
740221	740217	20980G	PARTICIPANT	\N	PRESENT	0
749832	749831	01024M	PARTICIPANT	\N	PRESENT	0
749833	749831	04035D	PARTICIPANT	\N	PRESENT	0
749834	749831	14147R	PARTICIPANT	\N	PRESENT	0
749835	749831	19713W	PARTICIPANT	\N	PRESENT	0
749836	749831	14213J	PARTICIPANT	\N	PRESENT	0
753749	753659	14259Y	PARTICIPANT	\N	PRESENT	0
753750	753659	21055F	PARTICIPANT	\N	PRESENT	0
753751	753659	21040X	PARTICIPANT	\N	PRESENT	0
753842	753659	19687N	PARTICIPANT	\N	PRESENT	0
753753	753659	21083K	PARTICIPANT	\N	PRESENT	0
753754	753659	20102Q	PARTICIPANT	\N	PRESENT	0
753755	753659	14231L	PARTICIPANT	\N	PRESENT	0
753756	753659	21090J	PARTICIPANT	\N	PRESENT	0
753757	753659	21067K	PARTICIPANT	\N	PRESENT	0
753758	753659	21075K	PARTICIPANT	\N	PRESENT	0
753759	753659	19782L	PARTICIPANT	\N	PRESENT	0
753760	753659	21039F	PARTICIPANT	\N	PRESENT	0
753761	753659	11040E	PARTICIPANT	\N	PRESENT	0
753769	753745	19383Y	PARTICIPANT	\N	PRESENT	0
753770	753745	19768N	PARTICIPANT	\N	PRESENT	0
753771	753745	20088L	PARTICIPANT	\N	PRESENT	0
753772	753745	20082E	PARTICIPANT	\N	PRESENT	0
753773	753745	14221J	PARTICIPANT	\N	PRESENT	0
753774	753745	19631V	PARTICIPANT	\N	PRESENT	0
753775	753745	20104S	PARTICIPANT	\N	PRESENT	0
753776	753745	08015R	PARTICIPANT	\N	PRESENT	0
753777	753745	19575F	PARTICIPANT	\N	PRESENT	0
753778	753745	20018V	PARTICIPANT	\N	PRESENT	0
753779	753745	08028W	PARTICIPANT	\N	PRESENT	0
753780	753745	19563B	PARTICIPANT	\N	PRESENT	0
753781	753745	21050A	PARTICIPANT	\N	PRESENT	0
753782	753745	20028X	PARTICIPANT	\N	PRESENT	0
753783	753745	21052C	PARTICIPANT	\N	PRESENT	0
753784	753745	14038Y	PARTICIPANT	\N	PRESENT	0
753785	753745	20034V	PARTICIPANT	\N	PRESENT	0
753786	753745	21054E	PARTICIPANT	\N	PRESENT	0
753787	753745	14187A	PRESIDENT	0	PRESENT	0
753788	753745	20038A	PARTICIPANT	\N	PRESENT	0
753789	753745	21086N	PARTICIPANT	\N	PRESENT	0
753790	753745	19695N	PARTICIPANT	\N	PRESENT	0
753791	753745	11090Q	PARTICIPANT	\N	PRESENT	0
753792	753745	14033T	PARTICIPANT	\N	PRESENT	0
753793	753745	21093M	PARTICIPANT	\N	PRESENT	0
753794	753745	20054A	PARTICIPANT	\N	PRESENT	0
753795	753745	20066E	PARTICIPANT	\N	PRESENT	0
753796	753745	21066J	PARTICIPANT	\N	PRESENT	0
753797	753745	20286Q	PARTICIPANT	\N	PRESENT	0
753798	753745	14207L	PARTICIPANT	\N	PRESENT	0
753799	753745	20084G	PARTICIPANT	\N	PRESENT	0
753800	753745	14257W	PARTICIPANT	\N	PRESENT	0
753801	753659	14179A	PARTICIPANT	\N	PRESENT	0
753804	753659	07004J	PARTICIPANT	\N	PRESENT	0
753810	753659	14169X	PARTICIPANT	\N	PRESENT	0
753811	753659	14033T	PARTICIPANT	\N	PRESENT	0
753813	753659	20038A	PARTICIPANT	\N	PRESENT	0
753814	753659	20060X	PARTICIPANT	\N	PRESENT	0
753815	753659	21062E	PARTICIPANT	\N	PRESENT	0
753817	753659	21045D	PARTICIPANT	\N	PRESENT	0
753818	753659	21042A	PARTICIPANT	\N	PRESENT	0
753819	753659	08028W	PARTICIPANT	\N	PRESENT	0
753820	753659	11090Q	PARTICIPANT	\N	PRESENT	0
753821	753659	14187A	PARTICIPANT	\N	PRESENT	0
753822	753659	20034V	PARTICIPANT	\N	PRESENT	0
753823	753659	14038Y	PARTICIPANT	\N	PRESENT	0
753824	753659	20054A	PARTICIPANT	\N	PRESENT	0
753825	753659	20062A	PARTICIPANT	\N	PRESENT	0
753826	753659	20030R	PARTICIPANT	\N	PRESENT	0
753832	753659	21030V	PARTICIPANT	\N	PRESENT	0
753833	753659	21066J	PARTICIPANT	\N	PRESENT	0
753834	753659	21093M	PARTICIPANT	\N	PRESENT	0
753835	753659	20018V	PARTICIPANT	\N	PRESENT	0
753836	753659	11056N	PARTICIPANT	\N	PRESENT	0
753837	753659	21053D	PARTICIPANT	\N	PRESENT	0
753838	753659	14257W	PARTICIPANT	\N	PRESENT	0
753839	753659	21033Y	PARTICIPANT	\N	PRESENT	0
753841	753659	20028X	PARTICIPANT	\N	PRESENT	0
753843	753659	21078N	PARTICIPANT	\N	PRESENT	0
753844	753659	19301E	PARTICIPANT	\N	PRESENT	0
753845	753659	19621T	PARTICIPANT	\N	PRESENT	0
753846	753659	20132W	PARTICIPANT	\N	PRESENT	0
753847	753659	21036C	PARTICIPANT	\N	PRESENT	0
753848	753659	20286Q	PARTICIPANT	\N	PRESENT	0
753849	753659	19387D	PARTICIPANT	\N	PRESENT	0
753853	753659	21050A	PARTICIPANT	\N	PRESENT	0
753851	753659	21032X	PARTICIPANT	\N	PRESENT	0
753852	753659	14111D	PARTICIPANT	\N	PRESENT	0
753854	753659	21054E	PARTICIPANT	\N	PRESENT	0
753855	753659	21076L	PARTICIPANT	\N	PRESENT	0
753856	753659	21052C	PARTICIPANT	\N	PRESENT	0
753857	753659	20084G	PARTICIPANT	\N	PRESENT	0
753858	753659	19631V	PARTICIPANT	\N	PRESENT	0
753859	753659	20082E	PARTICIPANT	\N	PRESENT	0
753860	753659	14021P	PARTICIPANT	\N	PRESENT	0
753861	753659	20088L	PARTICIPANT	\N	PRESENT	0
753863	753659	19565D	PARTICIPANT	\N	PRESENT	0
753864	753659	21091K	PARTICIPANT	\N	PRESENT	0
753872	753659	19399H	PARTICIPANT	\N	PRESENT	0
753866	753659	14147R	PARTICIPANT	\N	PRESENT	0
753867	753659	20024T	PARTICIPANT	\N	PRESENT	0
753868	753659	14083S	PARTICIPANT	\N	PRESENT	0
753869	753659	21072G	PARTICIPANT	\N	PRESENT	0
753870	753659	20056C	PARTICIPANT	\N	PRESENT	0
753873	753659	08056B	PARTICIPANT	\N	PRESENT	0
753874	753659	20098N	PARTICIPANT	\N	PRESENT	0
753875	753659	19383Y	PARTICIPANT	\N	PRESENT	0
753876	753659	21086N	PARTICIPANT	\N	PRESENT	0
753877	753659	19768N	PARTICIPANT	\N	PRESENT	0
753878	753659	19563B	PARTICIPANT	\N	PRESENT	0
753879	753659	20076G	PARTICIPANT	\N	PRESENT	0
753880	753659	21069M	PARTICIPANT	\N	PRESENT	0
753881	753659	21085M	PARTICIPANT	\N	PRESENT	0
753882	753659	21074J	PARTICIPANT	\N	PRESENT	0
753883	753659	20126Y	PARTICIPANT	\N	PRESENT	0
753884	753659	20144B	PARTICIPANT	\N	PRESENT	0
753885	753659	08045X	PARTICIPANT	\N	PRESENT	0
753886	753659	19695N	PARTICIPANT	\N	PRESENT	0
753894	753659	20052X	PARTICIPANT	\N	PRESENT	0
753888	753659	21047F	PARTICIPANT	\N	PRESENT	0
753889	753659	21058J	PARTICIPANT	\N	PRESENT	0
753890	753659	20026V	PARTICIPANT	\N	PRESENT	0
753891	753659	21056G	PARTICIPANT	\N	PRESENT	0
753893	753659	20112S	PARTICIPANT	\N	PRESENT	0
753895	753659	19954N	PARTICIPANT	\N	PRESENT	0
753896	753659	20180F	PARTICIPANT	\N	PRESENT	0
753897	753659	20044X	PARTICIPANT	\N	PRESENT	0
753898	753659	19507S	PARTICIPANT	\N	PRESENT	0
753899	753659	19693L	PARTICIPANT	\N	PRESENT	0
753900	753659	14221J	PARTICIPANT	\N	PRESENT	0
753901	753659	19531S	PARTICIPANT	\N	PRESENT	0
753902	753659	14069U	PARTICIPANT	\N	PRESENT	0
753903	753645	14053L	PARTICIPANT	\N	PRESENT	0
753904	753645	14111D	PARTICIPANT	\N	PRESENT	0
753905	753645	14189C	PARTICIPANT	\N	PRESENT	0
753906	753645	10015M	PARTICIPANT	\N	PRESENT	0
753907	753645	21076L	PARTICIPANT	\N	PRESENT	0
753908	753645	19585H	PARTICIPANT	\N	PRESENT	0
753909	753645	04045F	PARTICIPANT	\N	PRESENT	0
753910	753645	04047H	PRESIDENT	0	PRESENT	0
753911	753645	19673G	PARTICIPANT	\N	PRESENT	0
753912	753645	21040X	PARTICIPANT	\N	PRESENT	0
753913	753645	19447X	PARTICIPANT	\N	PRESENT	0
753914	753645	11056N	PARTICIPANT	\N	PRESENT	0
753915	753645	21044C	PARTICIPANT	\N	PRESENT	0
753916	753645	14147R	PARTICIPANT	\N	PRESENT	0
753917	753645	21088Q	PARTICIPANT	\N	PRESENT	0
753918	753645	14215L	PARTICIPANT	\N	PRESENT	0
753919	753645	08018U	PARTICIPANT	\N	PRESENT	0
753920	753645	21038E	PARTICIPANT	\N	PRESENT	0
753921	753645	21095P	PARTICIPANT	\N	PRESENT	0
756083	755424	21087P	PARTICIPANT	\N	EXCUSE	0
756084	755859	14229S	PARTICIPANT	\N	PRESENT	0
756085	755424	19798U	PARTICIPANT	\N	PRESENT	0
756086	755424	19679N	PARTICIPANT	\N	PRESENT	0
756087	755424	19691J	PARTICIPANT	\N	PRESENT	0
756088	755424	14071N	PRESIDENT	0	PRESENT	0
756089	755424	21039F	PARTICIPANT	\N	PRESENT	0
756090	755424	19760E	PARTICIPANT	\N	PRESENT	0
756091	755424	21081H	PARTICIPANT	\N	PRESENT	0
756092	755424	20140W	PARTICIPANT	\N	PRESENT	0
756093	755424	14213J	PARTICIPANT	\N	PRESENT	0
756094	755424	19657G	PARTICIPANT	\N	PRESENT	0
756095	755424	20130U	PARTICIPANT	\N	PRESENT	0
756096	755424	19367Y	PARTICIPANT	\N	PRESENT	0
756097	755424	20090E	PARTICIPANT	\N	PRESENT	0
756098	755424	14223L	PARTICIPANT	\N	PRESENT	0
756099	755424	14026U	PARTICIPANT	\N	PRESENT	0
756100	755424	21064G	PARTICIPANT	\N	PRESENT	0
756101	755424	20096L	PARTICIPANT	\N	PRESENT	0
756102	755424	19723Y	PARTICIPANT	\N	PRESENT	0
756103	755424	19553Y	PARTICIPANT	\N	PRESENT	0
756104	755424	14217N	PARTICIPANT	\N	PRESENT	0
756105	755424	19591F	PARTICIPANT	\N	PRESENT	0
756106	755859	21052C	PARTICIPANT	\N	PRESENT	0
756107	755859	20024T	PARTICIPANT	\N	PRESENT	0
756108	755859	20086J	PARTICIPANT	\N	PRESENT	0
756109	755859	21066J	PARTICIPANT	\N	PRESENT	0
756110	755859	21040X	PARTICIPANT	\N	PRESENT	0
756111	755859	14191V	PARTICIPANT	\N	PRESENT	0
756112	755859	21039F	PARTICIPANT	\N	PRESENT	0
756113	755859	20068G	PARTICIPANT	\N	PRESENT	0
756114	755859	08028W	PARTICIPANT	\N	PRESENT	0
756115	755859	20072C	PARTICIPANT	\N	PRESENT	0
756116	755859	21043B	PARTICIPANT	\N	PRESENT	0
756117	755859	20090E	PARTICIPANT	\N	PRESENT	0
756121	755859	19569H	PARTICIPANT	\N	PRESENT	0
756122	755859	19691J	PARTICIPANT	\N	PRESENT	0
756123	755859	21041Y	PARTICIPANT	\N	PRESENT	0
756124	755859	21053D	PARTICIPANT	\N	PRESENT	0
756125	755859	21069M	PARTICIPANT	\N	PRESENT	0
756126	755859	19591F	PARTICIPANT	\N	PRESENT	0
756127	755859	20130U	PARTICIPANT	\N	PRESENT	0
756515	755859	11056N	PARTICIPANT	\N	PRESENT	0
756129	755859	21049H	PARTICIPANT	\N	PRESENT	0
756130	755859	19758L	PARTICIPANT	\N	PRESENT	0
756131	755859	20046A	PARTICIPANT	\N	PRESENT	0
756132	755859	20102Q	PARTICIPANT	\N	PRESENT	0
756133	755859	21061D	PARTICIPANT	\N	PRESENT	0
756134	755859	14071N	PARTICIPANT	\N	PRESENT	0
756135	755859	19679N	PARTICIPANT	\N	PRESENT	0
757080	755537	19703U	PARTICIPANT	\N	PRESENT	0
756137	755859	21064G	PARTICIPANT	\N	PRESENT	0
756516	755859	14133K	PARTICIPANT	\N	PRESENT	0
757081	755537	20140W	PARTICIPANT	\N	PRESENT	0
757082	755537	20248J	PARTICIPANT	\N	PRESENT	0
757785	757784	20126Y	PARTICIPANT	\N	PRESENT	0
757143	757141	20110Q	PARTICIPANT	\N	PRESENT	0
757144	757141	14069U	PARTICIPANT	\N	PRESENT	0
757145	757141	08060W	PARTICIPANT	\N	PRESENT	0
757146	757141	20138D	PARTICIPANT	\N	PRESENT	0
757147	757141	12028B	PARTICIPANT	\N	PRESENT	0
757148	757141	14267Y	PARTICIPANT	\N	PRESENT	0
757149	757141	19295A	PARTICIPANT	\N	PRESENT	0
757150	757141	14259Y	PARTICIPANT	\N	PRESENT	0
757151	757141	14215L	PARTICIPANT	\N	PRESENT	0
757152	757141	11064N	PARTICIPANT	\N	PRESENT	0
757153	757141	19553Y	PARTICIPANT	\N	PRESENT	0
757154	757141	14179A	PARTICIPANT	\N	PRESENT	0
757155	757141	19735D	PARTICIPANT	\N	PRESENT	0
757156	757141	86034E	PARTICIPANT	\N	PRESENT	0
757157	757141	08010L	PARTICIPANT	\N	PRESENT	0
757158	757141	14111D	PARTICIPANT	\N	PRESENT	0
757159	757141	19593H	PARTICIPANT	\N	PRESENT	0
757160	757141	11090Q	PARTICIPANT	\N	PRESENT	0
757161	757141	19798U	PARTICIPANT	\N	PRESENT	0
757162	757141	14229S	PARTICIPANT	\N	PRESENT	0
757163	757141	04045F	PARTICIPANT	\N	PRESENT	0
757164	757141	20136B	PARTICIPANT	\N	PRESENT	0
757165	757141	19301E	PARTICIPANT	\N	PRESENT	0
757166	757141	20064C	PARTICIPANT	\N	PRESENT	0
757167	757141	19479G	PARTICIPANT	\N	PRESENT	0
757781	757780	20126Y	PARTICIPANT	\N	PRESENT	0
757783	757782	20050V	PARTICIPANT	\N	PRESENT	0
757787	757786	20126Y	PARTICIPANT	\N	PRESENT	0
757789	757788	20126Y	PARTICIPANT	\N	PRESENT	0
758749	758748	20124W	PARTICIPANT	\N	PRESENT	0
758750	758748	19593H	PARTICIPANT	\N	PRESENT	0
758778	757844	19533U	PARTICIPANT	\N	PRESENT	0
758779	757844	14073Q	PARTICIPANT	\N	PRESENT	0
758981	757697	21094N	PARTICIPANT	\N	PRESENT	0
758982	757697	17965H	PARTICIPANT	\N	PRESENT	0
758983	757697	14195A	PARTICIPANT	\N	PRESENT	0
758984	757697	19713W	PARTICIPANT	\N	PRESENT	0
758985	757697	19553Y	PARTICIPANT	\N	PRESENT	0
758986	757697	14026U	PARTICIPANT	\N	PRESENT	0
758987	757697	20148F	PARTICIPANT	\N	PRESENT	0
758988	757697	21071F	PARTICIPANT	\N	PRESENT	0
758989	757697	21064G	PARTICIPANT	\N	PRESENT	0
758990	757697	20090E	PARTICIPANT	\N	PRESENT	0
758991	757697	19723Y	PARTICIPANT	\N	PRESENT	0
758992	757697	20140W	PARTICIPANT	\N	PRESENT	0
758993	757697	19703U	PARTICIPANT	\N	PRESENT	0
758994	757697	14223L	PARTICIPANT	\N	PRESENT	0
758995	757697	19798U	PARTICIPANT	\N	PRESENT	0
758996	757697	14213J	PARTICIPANT	\N	PRESENT	0
758997	757697	14071N	PRESIDENT	0	PRESENT	0
758998	757697	21045D	PARTICIPANT	\N	PRESENT	0
759565	759564	19489J	PARTICIPANT	\N	PRESENT	0
759608	759600	19489J	PARTICIPANT	\N	PRESENT	0
759652	759634	14042U	PARTICIPANT	\N	PRESENT	0
759668	759634	19758L	PARTICIPANT	\N	PRESENT	0
759657	759634	14213J	PARTICIPANT	\N	PRESENT	0
759666	759634	19553Y	PARTICIPANT	\N	PRESENT	0
759670	759634	17965H	PARTICIPANT	\N	PRESENT	0
760423	760422	19447X	PARTICIPANT	\N	PRESENT	0
760424	760422	14089Y	PARTICIPANT	\N	PRESENT	0
760425	760422	18231D	PARTICIPANT	\N	PRESENT	0
760430	760429	19447X	PARTICIPANT	\N	PRESENT	0
760431	760429	14089Y	PARTICIPANT	\N	PRESENT	0
760432	760429	20074E	PARTICIPANT	\N	PRESENT	0
760435	760433	14089Y	PARTICIPANT	\N	PRESENT	0
760436	760433	19447X	PARTICIPANT	\N	PRESENT	0
760440	760439	14089Y	PARTICIPANT	\N	PRESENT	0
760441	760439	19447X	PARTICIPANT	\N	PRESENT	0
760462	760204	21089R	PARTICIPANT	\N	PRESENT	0
760463	760204	20130U	PARTICIPANT	\N	PRESENT	0
760464	760204	20146D	PARTICIPANT	\N	PRESENT	0
760465	760204	21077M	PARTICIPANT	\N	PRESENT	0
760466	760204	21094N	PARTICIPANT	\N	PRESENT	0
760467	760204	19749K	PARTICIPANT	\N	PRESENT	0
760468	760204	11045K	PARTICIPANT	\N	PRESENT	0
760469	760204	20098N	PARTICIPANT	\N	PRESENT	0
760470	760204	21042A	PARTICIPANT	\N	PRESENT	0
760471	760204	19693L	PARTICIPANT	\N	PRESENT	0
760472	760204	20180F	PARTICIPANT	\N	PRESENT	0
760473	760204	21091K	PARTICIPANT	\N	PRESENT	0
760474	760204	18193Q	PARTICIPANT	\N	PRESENT	0
760475	760204	14179A	PARTICIPANT	\N	PRESENT	0
760476	760204	19798U	PARTICIPANT	\N	PRESENT	0
760477	760204	21061D	PARTICIPANT	\N	PRESENT	0
760478	760204	21071F	PARTICIPANT	\N	PRESENT	0
760479	760204	14147R	PARTICIPANT	\N	PRESENT	0
760480	760204	21087P	PARTICIPANT	\N	PRESENT	0
760487	760484	14217N	PARTICIPANT	\N	PRESENT	0
760489	760484	20130U	PARTICIPANT	\N	PRESENT	0
760491	760204	21044C	PARTICIPANT	\N	PRESENT	0
760496	760490	14205J	PARTICIPANT	\N	PRESENT	0
760497	760490	18231D	PARTICIPANT	\N	PRESENT	0
760498	760490	19533U	PARTICIPANT	\N	PRESENT	0
760499	760490	21059K	PARTICIPANT	\N	PRESENT	0
760500	760490	20092G	PARTICIPANT	\N	PRESENT	0
760501	760490	19667J	PARTICIPANT	\N	PRESENT	0
760503	760204	21038E	PARTICIPANT	\N	PRESENT	0
760516	757696	08061X	PARTICIPANT	\N	PRESENT	0
760517	757696	19569H	PARTICIPANT	\N	PRESENT	0
760518	757696	19683J	PARTICIPANT	\N	PRESENT	0
760519	757696	17965H	PARTICIPANT	\N	PRESENT	0
740195	737972	19826F	PARTICIPANT	\N	EXCUSE	0
740222	738364	14083S	PARTICIPANT	\N	PRESENT	0
740295	740294	19709B	PARTICIPANT	\N	PRESENT	0
740296	740294	20022R	PARTICIPANT	\N	PRESENT	0
740297	740294	19954N	PARTICIPANT	\N	PRESENT	0
740298	740294	19515S	PARTICIPANT	\N	PRESENT	0
740299	740294	19782L	PARTICIPANT	\N	PRESENT	0
740300	740294	20114U	PARTICIPANT	\N	PRESENT	0
740301	740294	19503N	PARTICIPANT	\N	PRESENT	0
740302	740294	19565D	PARTICIPANT	\N	PRESENT	0
740303	740294	20074E	PARTICIPANT	\N	PRESENT	0
745785	743066	20056C	PARTICIPANT	\N	PRESENT	0
745786	743066	19593H	PARTICIPANT	\N	PRESENT	0
745787	743066	04070G	PARTICIPANT	\N	PRESENT	0
745788	743066	20132W	PARTICIPANT	\N	PRESENT	0
745789	743066	19699S	PARTICIPANT	\N	PRESENT	0
745790	743066	19611R	PRESIDENT	0	PRESENT	0
745804	744174	99004R	PARTICIPANT	\N	PRESENT	0
745805	744174	20062A	PARTICIPANT	\N	PRESENT	0
745806	744174	20092G	PARTICIPANT	\N	PRESENT	0
745813	744174	19333N	PARTICIPANT	\N	PRESENT	0
745814	744174	20914V	PARTICIPANT	\N	PRESENT	0
745815	744174	20050V	PARTICIPANT	\N	PRESENT	0
745816	744174	11090Q	PARTICIPANT	\N	PRESENT	0
745817	744174	19699S	PARTICIPANT	\N	PRESENT	0
745818	744174	19711U	PARTICIPANT	\N	PRESENT	0
745819	744174	20046A	PARTICIPANT	\N	PRESENT	0
745820	744174	19503N	PARTICIPANT	\N	PRESENT	0
745821	744174	14207L	PARTICIPANT	\N	PRESENT	0
745822	744174	20098N	PARTICIPANT	\N	PRESENT	0
745823	744174	19467C	PARTICIPANT	\N	PRESENT	0
745824	744174	20100N	PARTICIPANT	\N	PRESENT	0
745825	744174	14031R	PARTICIPANT	\N	PRESENT	0
745826	744174	19447X	PARTICIPANT	\N	PRESENT	0
745829	744174	19782L	PARTICIPANT	\N	PRESENT	0
745846	744174	20106U	PARTICIPANT	\N	PRESENT	0
745835	744174	14169X	PARTICIPANT	\N	PRESENT	0
745837	744174	19758L	PARTICIPANT	\N	PRESENT	0
745838	744174	14257W	PARTICIPANT	\N	PRESENT	0
745839	744174	19347U	PARTICIPANT	\N	PRESENT	0
745840	744174	14038Y	PARTICIPANT	\N	PRESENT	0
745841	744174	14030Q	PARTICIPANT	\N	PRESENT	0
745842	744174	19747H	PARTICIPANT	\N	PRESENT	0
745843	744174	19695N	PARTICIPANT	\N	PRESENT	0
745844	744174	20072C	PARTICIPANT	\N	PRESENT	0
745845	744174	14231L	PARTICIPANT	\N	PRESENT	0
745847	744174	14083S	PARTICIPANT	\N	PRESENT	0
745848	744174	20124W	PARTICIPANT	\N	PRESENT	0
745849	744174	14215L	PARTICIPANT	\N	PRESENT	0
745850	744174	01024M	PARTICIPANT	\N	PRESENT	0
745851	744174	20082E	PARTICIPANT	\N	PRESENT	0
745853	744174	14187A	PARTICIPANT	\N	PRESENT	0
745855	744174	20104S	PARTICIPANT	\N	PRESENT	0
745856	744174	11067R	PARTICIPANT	\N	PRESENT	0
745857	744174	20056C	PARTICIPANT	\N	PRESENT	0
745860	744174	14089Y	PARTICIPANT	\N	PRESENT	0
745861	744174	20084G	PARTICIPANT	\N	PRESENT	0
745862	744174	20080C	PARTICIPANT	\N	PRESENT	0
745863	744174	10015M	PARTICIPANT	\N	PRESENT	0
745866	744174	14069U	PARTICIPANT	\N	PRESENT	0
745867	744174	20034V	PARTICIPANT	\N	PRESENT	0
745868	744174	19441R	PARTICIPANT	\N	PRESENT	0
745869	744174	08061X	PARTICIPANT	\N	PRESENT	0
745874	744174	19647E	PARTICIPANT	\N	PRESENT	0
745875	744174	19549D	PARTICIPANT	\N	PRESENT	0
745910	744177	20264J	PARTICIPANT	\N	PRESENT	0
745908	744177	20062A	PARTICIPANT	\N	PRESENT	0
745909	744177	19713W	PARTICIPANT	\N	PRESENT	0
745911	744177	19705W	PARTICIPANT	\N	PRESENT	0
745912	744177	20034V	PARTICIPANT	\N	PRESENT	0
745913	744177	19782L	PARTICIPANT	\N	PRESENT	0
745914	744177	20092G	PARTICIPANT	\N	PRESENT	0
745915	744177	19503N	PARTICIPANT	\N	PRESENT	0
745916	744177	14257W	PARTICIPANT	\N	PRESENT	0
745917	744177	19711U	PARTICIPANT	\N	PRESENT	0
745918	744177	20050V	PARTICIPANT	\N	PRESENT	0
745919	744177	20046A	PARTICIPANT	\N	PRESENT	0
745920	744177	11012A	PARTICIPANT	\N	PRESENT	0
745921	744177	14031R	PARTICIPANT	\N	PRESENT	0
745922	744177	19447X	PARTICIPANT	\N	PRESENT	0
745923	744177	14215L	PARTICIPANT	\N	PRESENT	0
745924	744177	14219Q	PARTICIPANT	\N	PRESENT	0
745925	744177	20100N	PARTICIPANT	\N	PRESENT	0
745926	744177	19747H	PARTICIPANT	\N	PRESENT	0
745927	744177	14083S	PARTICIPANT	\N	PRESENT	0
745928	744177	19441R	PARTICIPANT	\N	PRESENT	0
745954	744175	19333N	PARTICIPANT	\N	PRESENT	0
745955	744175	19503N	PARTICIPANT	\N	PRESENT	0
745956	744175	14257W	PARTICIPANT	\N	PRESENT	0
745957	744175	20082E	PARTICIPANT	\N	PRESENT	0
745958	744175	19647E	PARTICIPANT	\N	PRESENT	0
745902	744177	11045K	PARTICIPANT	\N	PRESENT	0
745906	744177	19333N	PARTICIPANT	\N	PRESENT	0
745959	744175	20264J	PARTICIPANT	\N	PRESENT	0
745960	744175	20100N	PARTICIPANT	\N	PRESENT	0
745961	744175	20914V	PARTICIPANT	\N	PRESENT	0
745962	744175	19695N	PARTICIPANT	\N	PRESENT	0
745963	744175	20050V	PARTICIPANT	\N	PRESENT	0
745964	744175	20062A	PARTICIPANT	\N	PRESENT	0
745965	744175	19747H	PARTICIPANT	\N	PRESENT	0
745966	744175	19713W	PARTICIPANT	\N	PRESENT	0
745967	744175	14219Q	PARTICIPANT	\N	PRESENT	0
745968	744175	14083S	PARTICIPANT	\N	PRESENT	0
745969	744175	19711U	PARTICIPANT	\N	PRESENT	0
745970	744175	19782L	PARTICIPANT	\N	PRESENT	0
745971	744175	20046A	PARTICIPANT	\N	PRESENT	0
745972	744175	14031R	PARTICIPANT	\N	PRESENT	0
745973	744175	19441R	PARTICIPANT	\N	PRESENT	0
745974	744175	19467C	PARTICIPANT	\N	PRESENT	0
745975	744175	19447X	PARTICIPANT	\N	PRESENT	0
745976	744175	11012A	PARTICIPANT	\N	PRESENT	0
745952	744175	11045K	PARTICIPANT	\N	PRESENT	0
745953	744175	20080C	PARTICIPANT	\N	PRESENT	0
745977	744175	20098N	PARTICIPANT	\N	PRESENT	0
745987	744175	16685X	PARTICIPANT	\N	PRESENT	0
745988	744175	20120S	PARTICIPANT	\N	PRESENT	0
745989	744175	11010L	PARTICIPANT	\N	PRESENT	0
745990	744175	20092G	PARTICIPANT	\N	PRESENT	0
745991	744175	20034V	PARTICIPANT	\N	PRESENT	0
745992	744175	01024M	PARTICIPANT	\N	PRESENT	0
745993	744175	14215L	PARTICIPANT	\N	PRESENT	0
745994	744175	20134Y	PARTICIPANT	\N	PRESENT	0
745995	744175	19549D	PARTICIPANT	\N	PRESENT	0
745996	744175	20022R	PARTICIPANT	\N	PRESENT	0
745997	744175	04047H	PARTICIPANT	\N	PRESENT	0
745998	744175	08034U	PARTICIPANT	\N	PRESENT	0
746005	744175	99004R	PARTICIPANT	\N	PRESENT	0
746006	744175	04085P	PARTICIPANT	\N	PRESENT	0
746013	744175	14179A	PARTICIPANT	\N	PRESENT	0
746411	746023	07029T	PARTICIPANT	\N	PRESENT	0
746412	746023	17965H	PARTICIPANT	\N	PRESENT	0
746413	746023	18193Q	PARTICIPANT	\N	PRESENT	0
746414	746023	19563B	PARTICIPANT	\N	PRESENT	0
746415	746023	14038Y	PARTICIPANT	\N	PRESENT	0
746416	746023	14357A	PARTICIPANT	\N	PRESENT	0
746417	746023	20140W	PARTICIPANT	\N	PRESENT	0
746418	746023	95041E	PARTICIPANT	\N	PRESENT	0
746419	746023	19673G	PARTICIPANT	\N	PRESENT	0
746420	746023	19699S	PARTICIPANT	\N	PRESENT	0
746421	746023	20066E	PARTICIPANT	\N	PRESENT	0
746422	746023	20028X	PARTICIPANT	\N	PRESENT	0
746423	746023	14253S	PARTICIPANT	\N	PRESENT	0
746424	746023	19447X	PARTICIPANT	\N	PRESENT	0
746425	746023	19415P	PARTICIPANT	\N	PRESENT	0
746426	746023	10006L	PARTICIPANT	\N	PRESENT	0
746427	746023	14069U	PARTICIPANT	\N	PRESENT	0
746428	746023	11090Q	PARTICIPANT	\N	PRESENT	0
746429	746023	19820Y	PARTICIPANT	\N	PRESENT	0
746430	746023	14213J	PARTICIPANT	\N	PRESENT	0
746431	746023	14217N	PARTICIPANT	\N	PRESENT	0
746432	746023	14187A	PARTICIPANT	\N	PRESENT	0
746433	746023	14030Q	PARTICIPANT	\N	PRESENT	0
746434	746023	01043Q	PARTICIPANT	\N	PRESENT	0
746435	746023	20298U	PARTICIPANT	\N	PRESENT	0
754795	753674	14001X	PARTICIPANT	\N	EXCUSE	0
762581	762580	14329V	PARTICIPANT	\N	PRESENT	0
762584	762583	14329V	PARTICIPANT	\N	PRESENT	0
763137	763072	18395Y	PARTICIPANT	\N	PRESENT	0
763138	763072	14073Q	PARTICIPANT	\N	PRESENT	0
763140	763072	20016T	PARTICIPANT	\N	PRESENT	0
763141	763072	20058E	PARTICIPANT	\N	PRESENT	0
763142	763072	21078N	PARTICIPANT	\N	PRESENT	0
763152	763072	19533U	PARTICIPANT	\N	PRESENT	0
763154	763072	20180F	PARTICIPANT	\N	PRESENT	0
763168	763072	19057M	PARTICIPANT	\N	PRESENT	0
763243	763072	14021P	PARTICIPANT	\N	PRESENT	0
763244	763072	04033B	PARTICIPANT	\N	PRESENT	0
763247	763072	14123H	PARTICIPANT	\N	PRESENT	0
763296	763072	11043H	PARTICIPANT	\N	PRESENT	0
763540	761713	20136B	PARTICIPANT	\N	PRESENT	0
763541	761713	20138D	PARTICIPANT	\N	PRESENT	0
763542	761713	20032T	PARTICIPANT	\N	PRESENT	0
763543	761713	04092N	PARTICIPANT	\N	PRESENT	0
763544	761713	19447X	PARTICIPANT	\N	PRESENT	0
763545	761713	21068L	PARTICIPANT	\N	PRESENT	0
763546	761713	20180F	PARTICIPANT	\N	PRESENT	0
763547	761713	21081H	PARTICIPANT	\N	PRESENT	0
763548	761713	17737W	PARTICIPANT	\N	PRESENT	0
763549	761713	14038Y	PARTICIPANT	\N	PRESENT	0
763550	761713	19723Y	PARTICIPANT	\N	PRESENT	0
763551	761713	21039F	PARTICIPANT	\N	PRESENT	0
763552	761713	20140W	PARTICIPANT	\N	PRESENT	0
763553	761713	20024T	PARTICIPANT	\N	PRESENT	0
763554	761713	14147R	PARTICIPANT	\N	PRESENT	0
763555	761713	21063F	PARTICIPANT	\N	PRESENT	0
763556	761713	20068G	PARTICIPANT	\N	PRESENT	0
763557	761713	20086J	PARTICIPANT	\N	PRESENT	0
763558	761713	17367Q	PARTICIPANT	\N	PRESENT	0
763559	761713	19709B	PARTICIPANT	\N	PRESENT	0
763560	761713	07029T	PARTICIPANT	\N	PRESENT	0
763561	761713	19768N	PARTICIPANT	\N	PRESENT	0
763562	761713	19705W	PARTICIPANT	\N	PRESENT	0
763563	761713	14059S	PARTICIPANT	\N	PRESENT	0
763564	761713	20124W	PARTICIPANT	\N	PRESENT	0
763565	761713	20126Y	PARTICIPANT	\N	PRESENT	0
763566	761713	20054A	PARTICIPANT	\N	PRESENT	0
763567	761713	19383Y	PARTICIPANT	\N	PRESENT	0
763568	761713	20098N	PARTICIPANT	\N	PRESENT	0
763569	761713	20046A	PARTICIPANT	\N	PRESENT	0
763570	761713	20172F	PARTICIPANT	\N	PRESENT	0
763571	761713	20020P	PARTICIPANT	\N	PRESENT	0
763572	761713	21034A	PARTICIPANT	\N	PRESENT	0
763573	761713	14217N	PARTICIPANT	\N	PRESENT	0
763574	761713	20030R	PARTICIPANT	\N	PRESENT	0
763575	761713	20120S	PARTICIPANT	\N	PRESENT	0
763576	761713	20252E	PARTICIPANT	\N	PRESENT	0
763577	761713	21045D	PARTICIPANT	\N	PRESENT	0
763578	761713	20090E	PARTICIPANT	\N	PRESENT	0
763579	761713	20118Y	PARTICIPANT	\N	PRESENT	0
763580	761713	11110B	PARTICIPANT	\N	PRESENT	0
763581	761713	19647E	PARTICIPANT	\N	PRESENT	0
763582	761713	19798U	PARTICIPANT	\N	PRESENT	0
763583	761713	14071N	PARTICIPANT	\N	PRESENT	0
763584	761713	21056G	PARTICIPANT	\N	PRESENT	0
763585	761713	11045K	PARTICIPANT	\N	PRESENT	0
763586	761713	21051B	PARTICIPANT	\N	PRESENT	0
763587	761713	20062A	PARTICIPANT	\N	PRESENT	0
763588	761713	05008E	PARTICIPANT	\N	PRESENT	0
763589	761713	20082E	PARTICIPANT	\N	PRESENT	0
763590	761713	20070A	PARTICIPANT	\N	PRESENT	0
763591	761713	08010L	PARTICIPANT	\N	PRESENT	0
763592	761713	21057H	PARTICIPANT	\N	PRESENT	0
763593	761713	14097Y	PARTICIPANT	\N	PRESENT	0
763594	761713	14021P	PARTICIPANT	\N	PRESENT	0
763595	761713	19669L	PARTICIPANT	\N	PRESENT	0
763596	761713	14229S	PARTICIPANT	\N	PRESENT	0
763597	761713	20058E	PARTICIPANT	\N	PRESENT	0
763598	761713	17965H	PARTICIPANT	\N	PRESENT	0
763599	761713	14031R	PARTICIPANT	\N	PRESENT	0
763600	761713	12016W	PARTICIPANT	\N	PRESENT	0
763601	761713	18207D	PARTICIPANT	\N	PRESENT	0
763602	761713	14355X	PARTICIPANT	\N	PRESENT	0
763603	761713	20060X	PARTICIPANT	\N	PRESENT	0
763604	761713	21089R	PARTICIPANT	\N	PRESENT	0
763605	761713	19421M	PARTICIPANT	\N	PRESENT	0
763606	761713	21062E	PARTICIPANT	\N	PRESENT	0
763607	761713	19489J	PARTICIPANT	\N	PRESENT	0
763608	761713	08012N	PARTICIPANT	\N	PRESENT	0
763609	761713	20018V	PARTICIPANT	\N	PRESENT	0
763610	761713	20264J	PARTICIPANT	\N	PRESENT	0
763611	761713	21093M	PARTICIPANT	\N	PRESENT	0
763612	761713	14026U	PARTICIPANT	\N	PRESENT	0
763613	761713	21092L	PARTICIPANT	\N	PRESENT	0
763614	761713	20142Y	PARTICIPANT	\N	PRESENT	0
763615	761713	21073H	PARTICIPANT	\N	PRESENT	0
763616	761713	21037D	PARTICIPANT	\N	PRESENT	0
763617	761713	20130U	PARTICIPANT	\N	PRESENT	0
763618	761713	20092G	PARTICIPANT	\N	PRESENT	0
763619	761713	21079P	PARTICIPANT	\N	PRESENT	0
763620	761713	21094N	PARTICIPANT	\N	PRESENT	0
763621	761713	08047A	PARTICIPANT	\N	PRESENT	0
763622	761713	20084G	PARTICIPANT	\N	PRESENT	0
763623	761713	11027H	PARTICIPANT	\N	PRESENT	0
763624	761713	21060C	PARTICIPANT	\N	PRESENT	0
763625	761713	11040E	PARTICIPANT	\N	PRESENT	0
763626	761713	19301E	PARTICIPANT	\N	PRESENT	0
763628	761713	19782L	PARTICIPANT	\N	PRESENT	0
763629	761713	21096Q	PARTICIPANT	\N	PRESENT	0
763630	761713	14249W	PARTICIPANT	\N	PRESENT	0
763631	761713	20106U	PARTICIPANT	\N	PRESENT	0
763632	761713	20128B	PARTICIPANT	\N	PRESENT	0
763633	761713	19591F	PARTICIPANT	\N	PRESENT	0
763634	761713	19697Q	PARTICIPANT	\N	PRESENT	0
763635	761713	08073C	PARTICIPANT	\N	PRESENT	0
763636	761713	08061X	PARTICIPANT	\N	PRESENT	0
763637	761713	21043B	PARTICIPANT	\N	PRESENT	0
763638	761713	20146D	PARTICIPANT	\N	PRESENT	0
763639	761713	19349W	PARTICIPANT	\N	PRESENT	0
763640	761713	20150Y	PARTICIPANT	\N	PRESENT	0
763641	761713	14037X	PARTICIPANT	\N	PRESENT	0
763643	761713	14195A	PARTICIPANT	\N	PRESENT	0
763644	761713	19758L	PARTICIPANT	\N	PRESENT	0
763645	761713	19695N	PARTICIPANT	\N	PRESENT	0
763646	761713	21075K	PARTICIPANT	\N	PRESENT	0
763647	761713	19687N	PARTICIPANT	\N	PRESENT	0
763648	761713	20102Q	PARTICIPANT	\N	PRESENT	0
763649	761713	20112S	PARTICIPANT	\N	PRESENT	0
763650	761713	19681G	PARTICIPANT	\N	PRESENT	0
763651	761713	21088Q	PARTICIPANT	\N	PRESENT	0
763652	761713	19565D	PARTICIPANT	\N	PRESENT	0
763658	761713	21076L	PARTICIPANT	\N	PRESENT	0
763659	761713	20016T	PARTICIPANT	\N	PRESENT	0
763662	761713	14055N	PARTICIPANT	\N	PRESENT	0
763663	761713	21085M	PARTICIPANT	\N	PRESENT	0
763664	761713	19629C	PARTICIPANT	\N	PRESENT	0
763666	761713	21041Y	PARTICIPANT	\N	PRESENT	0
763667	761713	14207L	PARTICIPANT	\N	PRESENT	0
763671	761713	20132W	PARTICIPANT	\N	PRESENT	0
763677	761713	21066J	PARTICIPANT	\N	PRESENT	0
763678	761713	11065P	PARTICIPANT	\N	PRESENT	0
763679	761713	19585H	PARTICIPANT	\N	PRESENT	0
763680	761713	20122U	PARTICIPANT	\N	PRESENT	0
763681	761713	18231D	PARTICIPANT	\N	PRESENT	0
763682	761713	12028B	PARTICIPANT	\N	PRESENT	0
763684	761713	08069G	PARTICIPANT	\N	PRESENT	0
763685	761713	20080C	PARTICIPANT	\N	PRESENT	0
763686	761713	19631V	PARTICIPANT	\N	PRESENT	0
763688	761713	18395Y	PARTICIPANT	\N	PRESENT	0
740691	738757	04070G	PRESIDENT	0	PRESENT	0
740693	738757	19593H	PARTICIPANT	\N	PRESENT	0
740694	738757	14030Q	PARTICIPANT	\N	PRESENT	0
740697	738757	14038Y	PARTICIPANT	\N	PRESENT	0
740698	738757	20134Y	PARTICIPANT	\N	PRESENT	0
740701	738757	20094J	PARTICIPANT	\N	PRESENT	0
740702	738757	20132W	PARTICIPANT	\N	PRESENT	0
740703	738757	20152B	PARTICIPANT	\N	PRESENT	0
740706	738757	14179A	PARTICIPANT	\N	PRESENT	0
740713	738757	14229S	PARTICIPANT	\N	PRESENT	0
744326	744092	14111D	PARTICIPANT	\N	PRESENT	0
744392	744092	05008E	PARTICIPANT	\N	PRESENT	0
746057	746043	14026U	PARTICIPANT	\N	PRESENT	0
747807	746060	14331P	PRESIDENT	0	PRESENT	0
747809	746060	20286Q	PARTICIPANT	\N	PRESENT	0
747810	746060	19441R	PARTICIPANT	\N	PRESENT	0
747811	746060	04045F	PARTICIPANT	\N	PRESENT	0
747819	746060	20128B	PARTICIPANT	\N	PRESENT	0
747827	746060	20104S	PARTICIPANT	\N	PRESENT	0
751548	749979	11070L	PARTICIPANT	\N	PRESENT	0
751549	749979	04042C	PARTICIPANT	\N	PRESENT	0
751550	749979	98022P	PARTICIPANT	\N	PRESENT	0
751552	749979	14133K	PARTICIPANT	\N	PRESENT	0
751555	749979	19545Y	PARTICIPANT	\N	PRESENT	0
751556	749979	19347U	PARTICIPANT	\N	PRESENT	0
751557	749979	20128B	PARTICIPANT	\N	PRESENT	0
751558	749979	19669L	PARTICIPANT	\N	PRESENT	0
751559	749979	12041X	PARTICIPANT	\N	PRESENT	0
751560	749979	14267Y	PARTICIPANT	\N	PRESENT	0
751562	749979	11083R	PARTICIPANT	\N	PRESENT	0
751563	749979	19681G	PARTICIPANT	\N	PRESENT	0
751564	749979	20090E	PARTICIPANT	\N	PRESENT	0
751565	749979	08034U	PARTICIPANT	\N	PRESENT	0
751566	749979	14033T	PARTICIPANT	\N	PRESENT	0
751568	749979	14193X	PARTICIPANT	\N	PRESENT	0
751569	749979	20024T	PARTICIPANT	\N	PRESENT	0
751570	749979	08047A	PARTICIPANT	\N	PRESENT	0
751572	749979	19565D	PARTICIPANT	\N	PRESENT	0
751573	749979	14249W	PARTICIPANT	\N	PRESENT	0
751574	749979	12028B	PARTICIPANT	\N	PRESENT	0
751576	749979	16685X	PARTICIPANT	\N	PRESENT	0
751577	749979	20062A	PARTICIPANT	\N	PRESENT	0
751578	749979	20052X	PARTICIPANT	\N	PRESENT	0
751579	749979	19709B	PARTICIPANT	\N	PRESENT	0
751581	749979	20098N	PARTICIPANT	\N	PRESENT	0
751582	749979	97011G	PARTICIPANT	\N	PRESENT	0
751583	749979	04033B	PARTICIPANT	\N	PRESENT	0
751585	749979	11056N	PARTICIPANT	\N	PRESENT	0
751586	749979	01024M	PARTICIPANT	\N	PRESENT	0
751588	749979	17023S	PARTICIPANT	\N	PRESENT	0
751589	749979	19467C	PARTICIPANT	\N	PRESENT	0
751590	749979	14069U	PARTICIPANT	\N	PRESENT	0
751591	749979	14259Y	PARTICIPANT	\N	PRESENT	0
751592	749979	04035D	PARTICIPANT	\N	PRESENT	0
751593	749979	11067R	PARTICIPANT	\N	PRESENT	0
751601	749979	20032T	PARTICIPANT	\N	PRESENT	0
751621	749979	14097Y	PARTICIPANT	\N	PRESENT	0
751625	749979	14213J	PARTICIPANT	\N	PRESENT	0
751626	749979	20180F	PARTICIPANT	\N	PRESENT	0
751627	749979	14021P	PARTICIPANT	\N	PRESENT	0
751628	749979	20082E	PARTICIPANT	\N	PRESENT	0
751629	749979	01043Q	PARTICIPANT	\N	PRESENT	0
751630	749979	20092G	PARTICIPANT	\N	PRESENT	0
751631	749979	11027H	PARTICIPANT	\N	PRESENT	0
751632	749979	19533U	PARTICIPANT	\N	PRESENT	0
751633	749979	20298U	PARTICIPANT	\N	PRESENT	0
751634	749981	11070L	PARTICIPANT	\N	PRESENT	0
751677	749981	16685X	PARTICIPANT	\N	PRESENT	0
751673	749981	14189C	PARTICIPANT	\N	PRESENT	0
751674	749981	11065P	PARTICIPANT	\N	PRESENT	0
751638	749981	19545Y	PARTICIPANT	\N	PRESENT	0
751675	749981	19735D	PARTICIPANT	\N	PRESENT	0
751640	749981	20128B	PARTICIPANT	\N	PRESENT	0
751676	749981	20086J	PARTICIPANT	\N	PRESENT	0
751678	749981	20058E	PARTICIPANT	\N	PRESENT	0
751685	749981	14021P	PARTICIPANT	\N	PRESENT	0
751644	749981	19681G	PARTICIPANT	\N	PRESENT	0
751645	749981	20090E	PARTICIPANT	\N	PRESENT	0
751679	749981	20124W	PARTICIPANT	\N	PRESENT	0
751647	749981	14033T	PARTICIPANT	\N	PRESENT	0
751683	749981	19347U	PARTICIPANT	\N	PRESENT	0
751684	749981	19611R	PARTICIPANT	\N	PRESENT	0
751686	749981	08010L	PARTICIPANT	\N	PRESENT	0
751687	749981	11045K	PARTICIPANT	\N	PRESENT	0
751688	749981	11012A	PARTICIPANT	\N	PRESENT	0
751653	749981	20062A	PARTICIPANT	\N	PRESENT	0
751689	749981	20084G	PARTICIPANT	\N	PRESENT	0
751655	749981	20098N	PARTICIPANT	\N	PRESENT	0
751656	749981	97011G	PARTICIPANT	\N	PRESENT	0
751657	749981	11056N	PARTICIPANT	\N	PRESENT	0
751658	749981	01024M	PARTICIPANT	\N	PRESENT	0
751659	749981	17023S	PARTICIPANT	\N	PRESENT	0
751660	749981	19467C	PARTICIPANT	\N	PRESENT	0
751690	749981	20134Y	PARTICIPANT	\N	PRESENT	0
751691	749981	04033B	PARTICIPANT	\N	PRESENT	0
751692	749981	19651A	PARTICIPANT	\N	PRESENT	0
751664	749981	20032T	PARTICIPANT	\N	PRESENT	0
751693	749982	19545Y	PARTICIPANT	\N	PRESENT	0
751666	749981	20180F	PARTICIPANT	\N	PRESENT	0
751722	749982	14089Y	PARTICIPANT	\N	PRESENT	0
751668	749981	20082E	PARTICIPANT	\N	PRESENT	0
751669	749981	01043Q	PARTICIPANT	\N	PRESENT	0
751670	749981	20092G	PARTICIPANT	\N	PRESENT	0
751723	749982	19593H	PARTICIPANT	\N	PRESENT	0
751672	749981	20298U	PARTICIPANT	\N	PRESENT	0
751696	749982	20090E	PARTICIPANT	\N	PRESENT	0
751697	749982	14033T	PARTICIPANT	\N	PRESENT	0
751698	749982	20062A	PARTICIPANT	\N	PRESENT	0
751699	749982	97011G	PARTICIPANT	\N	PRESENT	0
752164	752163	14053L	PARTICIPANT	\N	PRESENT	0
751701	749982	01024M	PARTICIPANT	\N	PRESENT	0
751703	749982	20032T	PARTICIPANT	\N	PRESENT	0
751704	749982	20180F	PARTICIPANT	\N	PRESENT	0
752166	752163	11066Q	PARTICIPANT	\N	PRESENT	0
752168	752167	14053L	PARTICIPANT	\N	PRESENT	0
752173	752167	11066Q	PARTICIPANT	\N	PRESENT	0
751712	749982	20124W	PARTICIPANT	\N	PRESENT	0
753922	753659	21059K	PARTICIPANT	\N	PRESENT	0
751714	749982	19611R	PARTICIPANT	\N	PRESENT	0
753923	753659	14121F	PARTICIPANT	\N	PRESENT	0
751716	749982	11045K	PARTICIPANT	\N	PRESENT	0
751717	749982	11012A	PARTICIPANT	\N	PRESENT	0
751718	749982	20084G	PARTICIPANT	\N	PRESENT	0
751719	749982	20134Y	PARTICIPANT	\N	PRESENT	0
753924	753659	21089R	PARTICIPANT	\N	PRESENT	0
751721	749982	19651A	PARTICIPANT	\N	PRESENT	0
753925	753659	19735D	PARTICIPANT	\N	PRESENT	0
753926	753659	20172F	PARTICIPANT	\N	PRESENT	0
753927	753659	20124W	PARTICIPANT	\N	PRESENT	0
753928	753645	21057H	PARTICIPANT	\N	PRESENT	0
753929	753645	20098N	PARTICIPANT	\N	PRESENT	0
753930	753645	18207D	PARTICIPANT	\N	PRESENT	0
753931	753645	18231D	PARTICIPANT	\N	PRESENT	0
753932	753645	20110Q	PARTICIPANT	\N	PRESENT	0
753933	753645	20114U	PARTICIPANT	\N	PRESENT	0
753934	753645	19111A	PARTICIPANT	\N	PRESENT	0
753935	753645	21043B	PARTICIPANT	\N	PRESENT	0
753936	753645	14089Y	PARTICIPANT	\N	PRESENT	0
753937	753645	20266L	PARTICIPANT	\N	PRESENT	0
753938	753645	14069U	PARTICIPANT	\N	PRESENT	0
753939	753645	11085T	PARTICIPANT	\N	PRESENT	0
753940	753659	21070E	PARTICIPANT	\N	PRESENT	0
753941	753659	19575F	PARTICIPANT	\N	PRESENT	0
753942	753659	20086J	PARTICIPANT	\N	PRESENT	0
753943	753659	19533U	PARTICIPANT	\N	PRESENT	0
753944	753659	20128B	PARTICIPANT	\N	PRESENT	0
753945	753659	21057H	PARTICIPANT	\N	PRESENT	0
753946	753659	20032T	PARTICIPANT	\N	PRESENT	0
753947	753659	21088Q	PARTICIPANT	\N	PRESENT	0
753948	753659	04045F	PARTICIPANT	\N	PRESENT	0
753949	753659	19569H	PARTICIPANT	\N	PRESENT	0
753950	753659	14173T	PARTICIPANT	\N	PRESENT	0
753951	753659	20248J	PARTICIPANT	\N	PRESENT	0
753952	753659	20068G	PARTICIPANT	\N	PRESENT	0
753953	753659	18083K	PARTICIPANT	\N	PRESENT	0
753954	753659	19349W	PARTICIPANT	\N	PRESENT	0
756629	755515	14195A	PARTICIPANT	\N	PRESENT	0
756630	755515	19758L	PARTICIPANT	\N	PRESENT	0
756631	755515	04092N	PARTICIPANT	\N	PRESENT	0
756632	755515	08045X	PARTICIPANT	\N	PRESENT	0
756642	752397	19593H	PARTICIPANT	\N	PRESENT	0
756643	752397	20132W	PARTICIPANT	\N	PRESENT	0
756644	752397	19697Q	PARTICIPANT	\N	PRESENT	0
756645	752397	20142Y	PARTICIPANT	\N	PRESENT	0
756646	752397	21059K	PARTICIPANT	\N	PRESENT	0
756647	752397	20102Q	PARTICIPANT	\N	PRESENT	0
756648	752397	20052X	PARTICIPANT	\N	PRESENT	0
756649	752397	20056C	PARTICIPANT	\N	PRESENT	0
756650	752397	20180F	PARTICIPANT	\N	PRESENT	0
756651	752397	21063F	PARTICIPANT	\N	PRESENT	0
756652	752397	20264J	PARTICIPANT	\N	PRESENT	0
756653	752397	14109K	PARTICIPANT	\N	PRESENT	0
756654	752397	21089R	PARTICIPANT	\N	PRESENT	0
756655	752397	21037D	PARTICIPANT	\N	PRESENT	0
756656	752397	08012N	PARTICIPANT	\N	PRESENT	0
756657	752397	21091K	PARTICIPANT	\N	PRESENT	0
756658	752397	20124W	PARTICIPANT	\N	PRESENT	0
756659	752397	21077M	PARTICIPANT	\N	PRESENT	0
756660	752397	20026V	PARTICIPANT	\N	PRESENT	0
756661	752397	19954N	PARTICIPANT	\N	PRESENT	0
756662	755919	14327T	PARTICIPANT	\N	PRESENT	0
756663	755919	20086J	PARTICIPANT	\N	PRESENT	0
756664	755919	14331P	PARTICIPANT	\N	PRESENT	0
756665	755919	20080C	PARTICIPANT	\N	PRESENT	0
756666	755919	20094J	PARTICIPANT	\N	PRESENT	0
756667	755919	19667J	PARTICIPANT	\N	PRESENT	0
756668	755919	11074Q	PARTICIPANT	\N	PRESENT	0
756669	755919	19671E	PARTICIPANT	\N	PRESENT	0
756670	755919	14225N	PRESIDENT	0	PRESENT	0
756671	755919	11070L	PARTICIPANT	\N	PRESENT	0
756672	755919	11110B	PARTICIPANT	\N	PRESENT	0
756673	755919	07029T	PARTICIPANT	\N	PRESENT	0
756674	755919	21079P	PARTICIPANT	\N	PRESENT	0
756675	755919	19573D	PARTICIPANT	\N	PRESENT	0
756676	755919	07004J	PARTICIPANT	\N	PRESENT	0
756677	755919	19349W	PARTICIPANT	\N	PRESENT	0
756678	755919	21090J	PARTICIPANT	\N	PRESENT	0
756679	755919	20116W	PARTICIPANT	\N	PRESENT	0
756680	755919	19335Q	PARTICIPANT	\N	PRESENT	0
756681	755919	20024T	PARTICIPANT	\N	PRESENT	0
756682	755919	11048N	PARTICIPANT	\N	PRESENT	0
756683	755919	19479G	PARTICIPANT	\N	PRESENT	0
756684	755919	20134Y	PARTICIPANT	\N	PRESENT	0
756686	755919	19711U	PARTICIPANT	\N	PRESENT	0
756688	755919	08034U	PARTICIPANT	\N	PRESENT	0
756689	755919	19687N	PARTICIPANT	\N	PRESENT	0
756690	755919	20050V	PARTICIPANT	\N	PRESENT	0
756691	755919	08011M	PARTICIPANT	\N	PRESENT	0
756692	755919	20044X	PARTICIPANT	\N	PRESENT	0
756693	755919	19399H	PARTICIPANT	\N	PRESENT	0
756694	755919	14173T	PARTICIPANT	\N	PRESENT	0
756695	755919	21041Y	PARTICIPANT	\N	PRESENT	0
756696	755919	11040E	PARTICIPANT	\N	PRESENT	0
756697	755919	20062A	PARTICIPANT	\N	PRESENT	0
756699	755919	08073C	PARTICIPANT	\N	PRESENT	0
756700	755919	20070A	PARTICIPANT	\N	PRESENT	0
756701	755919	21069M	PARTICIPANT	\N	PRESENT	0
756702	755919	19741B	PARTICIPANT	\N	PRESENT	0
756703	755919	14121F	PARTICIPANT	\N	PRESENT	0
756705	755919	19762G	PARTICIPANT	\N	PRESENT	0
756707	755919	12016W	PARTICIPANT	\N	EXCUSE	0
756708	755865	21031W	PARTICIPANT	\N	PRESENT	0
756709	755865	19565D	PARTICIPANT	\N	PRESENT	0
756710	755865	20072C	PARTICIPANT	\N	PRESENT	0
756711	755865	01058X	PARTICIPANT	\N	PRESENT	0
756712	755865	14001X	PARTICIPANT	\N	PRESENT	0
756713	755865	19669L	PARTICIPANT	\N	PRESENT	0
756714	755865	08056B	PARTICIPANT	\N	PRESENT	0
756715	755865	12028B	PARTICIPANT	\N	PRESENT	0
756716	755865	17737W	PARTICIPANT	\N	PRESENT	0
756717	755865	11115U	PARTICIPANT	\N	PRESENT	0
756718	755865	14055N	PARTICIPANT	\N	PRESENT	0
756719	755865	19421M	PARTICIPANT	\N	PRESENT	0
756720	755865	21067K	PARTICIPANT	\N	PRESENT	0
756721	755865	14193X	PRESIDENT	0	PRESENT	0
756722	755865	19347U	PARTICIPANT	\N	PRESENT	0
756723	755865	17367Q	PARTICIPANT	\N	PRESENT	0
756724	755865	14249W	PARTICIPANT	\N	PRESENT	0
756725	755865	20128B	PARTICIPANT	\N	PRESENT	0
756726	755865	14037X	PARTICIPANT	\N	PRESENT	0
756727	755865	14059S	PARTICIPANT	\N	PRESENT	0
756728	755865	14097Y	PARTICIPANT	\N	PRESENT	0
756729	755865	14133K	PARTICIPANT	\N	PRESENT	0
756730	755865	19531S	PARTICIPANT	\N	PRESENT	0
756731	755865	08069G	PARTICIPANT	\N	PRESENT	0
756732	755865	20042V	PARTICIPANT	\N	PRESENT	0
756733	755865	14191V	PARTICIPANT	\N	PRESENT	0
756734	755865	19721W	PARTICIPANT	\N	PRESENT	0
756735	755865	20064C	PARTICIPANT	\N	PRESENT	0
756736	755865	20252E	PARTICIPANT	\N	PRESENT	0
756737	755865	98022P	PARTICIPANT	\N	PRESENT	0
756738	755865	14267Y	PARTICIPANT	\N	PRESENT	0
756739	755865	11064N	PARTICIPANT	\N	PRESENT	0
756740	755865	99004R	PARTICIPANT	\N	PRESENT	0
756741	755865	19745F	PARTICIPANT	\N	PRESENT	0
756742	755865	14211G	PARTICIPANT	\N	PRESENT	0
756743	755865	14255U	PARTICIPANT	\N	PRESENT	0
756744	755515	21081H	PARTICIPANT	\N	PRESENT	0
756745	755919	20126Y	PARTICIPANT	\N	PRESENT	0
756746	755919	14083S	PARTICIPANT	\N	PRESENT	0
756747	755919	08009T	PARTICIPANT	\N	PRESENT	0
756748	755919	21072G	PARTICIPANT	\N	PRESENT	0
756749	755919	19545Y	PARTICIPANT	\N	PRESENT	0
756750	755919	08010L	PARTICIPANT	\N	PRESENT	0
756751	755515	01034P	PARTICIPANT	\N	PRESENT	0
756752	755515	20248J	PARTICIPANT	\N	PRESENT	0
756753	755515	19683J	PARTICIPANT	\N	PRESENT	0
756775	755919	11053K	PARTICIPANT	\N	PRESENT	0
756776	755919	14253S	PARTICIPANT	\N	PRESENT	0
756802	755920	14327T	PARTICIPANT	\N	PRESENT	0
756803	755920	14331P	PARTICIPANT	\N	PRESENT	0
756804	755920	19545Y	PARTICIPANT	\N	PRESENT	0
756805	755920	11053K	PARTICIPANT	\N	PRESENT	0
756806	755920	19667J	PARTICIPANT	\N	PRESENT	0
756807	755920	19671E	PARTICIPANT	\N	PRESENT	0
756808	755920	11070L	PARTICIPANT	\N	PRESENT	0
756809	755920	11110B	PARTICIPANT	\N	PRESENT	0
756810	755920	07029T	PARTICIPANT	\N	PRESENT	0
756811	755920	19573D	PARTICIPANT	\N	PRESENT	0
756812	755920	19349W	PARTICIPANT	\N	PRESENT	0
756813	755920	19335Q	PARTICIPANT	\N	PRESENT	0
756814	755920	20024T	PARTICIPANT	\N	PRESENT	0
756815	755920	11048N	PARTICIPANT	\N	PRESENT	0
756817	755920	19687N	PARTICIPANT	\N	PRESENT	0
756818	755920	20050V	PARTICIPANT	\N	PRESENT	0
756819	755920	20044X	PARTICIPANT	\N	PRESENT	0
756820	755920	19399H	PARTICIPANT	\N	PRESENT	0
756821	755920	21041Y	PARTICIPANT	\N	PRESENT	0
756822	755920	11040E	PARTICIPANT	\N	PRESENT	0
756823	755920	14083S	PARTICIPANT	\N	PRESENT	0
756824	755920	20062A	PARTICIPANT	\N	PRESENT	0
756825	755920	08073C	PARTICIPANT	\N	PRESENT	0
756826	755920	20070A	PARTICIPANT	\N	PRESENT	0
756827	755920	21069M	PARTICIPANT	\N	PRESENT	0
756828	755920	14121F	PARTICIPANT	\N	PRESENT	0
756830	755920	21072G	PARTICIPANT	\N	PRESENT	0
756831	755920	20086J	PARTICIPANT	\N	PRESENT	0
756832	755920	20080C	PARTICIPANT	\N	PRESENT	0
756833	755920	20094J	PARTICIPANT	\N	PRESENT	0
756834	755920	11074Q	PARTICIPANT	\N	PRESENT	0
756835	755920	14225N	PRESIDENT	0	PRESENT	0
756836	755920	21079P	PARTICIPANT	\N	PRESENT	0
756837	755920	07004J	PARTICIPANT	\N	PRESENT	0
756838	755920	08010L	PARTICIPANT	\N	PRESENT	0
756839	755920	21090J	PARTICIPANT	\N	PRESENT	0
756840	755920	20116W	PARTICIPANT	\N	PRESENT	0
756841	755920	14253S	PARTICIPANT	\N	PRESENT	0
756842	755920	20126Y	PARTICIPANT	\N	PRESENT	0
756843	755920	19479G	PARTICIPANT	\N	PRESENT	0
756844	755920	20134Y	PARTICIPANT	\N	PRESENT	0
740511	738260	20034V	PARTICIPANT	\N	PRESENT	0
741136	741133	11066Q	PARTICIPANT	\N	PRESENT	0
741149	741137	14042U	PARTICIPANT	\N	PRESENT	0
741150	741137	18193Q	PARTICIPANT	\N	PRESENT	0
741151	741137	19553Y	PARTICIPANT	\N	PRESENT	0
741152	741131	14026U	PARTICIPANT	\N	PRESENT	0
741153	741131	14281W	PARTICIPANT	\N	PRESENT	0
741154	741131	17965H	PARTICIPANT	\N	PRESENT	0
741155	741131	20130U	PARTICIPANT	\N	PRESENT	0
741156	741132	14026U	PARTICIPANT	\N	PRESENT	0
741157	741132	14281W	PARTICIPANT	\N	PRESENT	0
741158	741132	17965H	PARTICIPANT	\N	PRESENT	0
741159	741132	20130U	PARTICIPANT	\N	PRESENT	0
742414	739461	19741B	PRESIDENT	0	PRESENT	0
742415	739461	19866P	PARTICIPANT	\N	PRESENT	0
742416	739461	19631V	PARTICIPANT	\N	PRESENT	0
742417	739461	19585H	PARTICIPANT	\N	PRESENT	0
742419	739461	20042V	PARTICIPANT	\N	PRESENT	0
742420	739461	19569H	PARTICIPANT	\N	PRESENT	0
742421	739461	14053L	PARTICIPANT	\N	PRESENT	0
742422	739461	08073C	PARTICIPANT	\N	PRESENT	0
742423	739461	19619A	PARTICIPANT	\N	PRESENT	0
742424	739461	20108W	PARTICIPANT	\N	PRESENT	0
742425	739461	12016W	PARTICIPANT	\N	PRESENT	0
742426	739461	08010L	PARTICIPANT	\N	PRESENT	0
742427	739461	10015M	PARTICIPANT	\N	PRESENT	0
742428	739461	14033T	PARTICIPANT	\N	PRESENT	0
746504	746024	19669L	PARTICIPANT	\N	PRESENT	0
746505	746024	14097Y	PARTICIPANT	\N	PRESENT	0
746506	746024	12028B	PARTICIPANT	\N	PRESENT	0
746507	746024	11066Q	PARTICIPANT	\N	PRESENT	0
746508	746024	08015R	PARTICIPANT	\N	PRESENT	0
746509	746024	19565D	PARTICIPANT	\N	PRESENT	0
746510	746024	20064C	PARTICIPANT	\N	PRESENT	0
746511	746024	19826F	PARTICIPANT	\N	PRESENT	0
746512	746024	20252E	PARTICIPANT	\N	PRESENT	0
746513	746024	14193X	PARTICIPANT	\N	PRESENT	0
746514	746024	08069G	PARTICIPANT	\N	PRESENT	0
746515	746024	19347U	PARTICIPANT	\N	PRESENT	0
746516	746024	08047A	PARTICIPANT	\N	PRESENT	0
746517	746024	08056B	PARTICIPANT	\N	PRESENT	0
746518	746024	04047H	PARTICIPANT	\N	PRESENT	0
746519	746024	20090E	PARTICIPANT	\N	PRESENT	0
746520	746024	11027H	PARTICIPANT	\N	PRESENT	0
746521	746024	08034U	PARTICIPANT	\N	PRESENT	0
746522	746024	20048C	PARTICIPANT	\N	PRESENT	0
746523	746024	19467C	PARTICIPANT	\N	PRESENT	0
746524	746024	14211G	PARTICIPANT	\N	PRESENT	0
746525	746024	14207L	PARTICIPANT	\N	PRESENT	0
746526	746024	98022P	PARTICIPANT	\N	PRESENT	0
746527	746024	20128B	PARTICIPANT	\N	PRESENT	0
746528	746024	04045F	PARTICIPANT	\N	PRESENT	0
746529	746024	20072C	PARTICIPANT	\N	PRESENT	0
746530	746024	14249W	PARTICIPANT	\N	PRESENT	0
746531	746024	11010L	PARTICIPANT	\N	PRESENT	0
746532	746024	19782L	PARTICIPANT	\N	PRESENT	0
746533	746024	14215L	PARTICIPANT	\N	PRESENT	0
746534	746024	19713W	PARTICIPANT	\N	PRESENT	0
746535	746024	11054L	PARTICIPANT	\N	PRESENT	0
746536	746024	14267Y	PARTICIPANT	\N	PRESENT	0
746537	746024	01062T	PARTICIPANT	\N	PRESENT	0
746538	746024	20040T	PARTICIPANT	\N	PRESENT	0
746539	746024	14133K	PARTICIPANT	\N	PRESENT	0
746540	746024	20180F	PARTICIPANT	\N	PRESENT	0
746541	746024	20054A	PARTICIPANT	\N	PRESENT	0
746542	746024	20140W	PARTICIPANT	\N	PRESENT	0
746543	746024	20056C	PARTICIPANT	\N	PRESENT	0
746544	746024	14059S	PARTICIPANT	\N	PRESENT	0
746545	746024	14255U	PARTICIPANT	\N	PRESENT	0
746546	746024	16685X	PARTICIPANT	\N	PRESENT	0
746547	746024	17367Q	PARTICIPANT	\N	PRESENT	0
746548	746024	14069U	PARTICIPANT	\N	PRESENT	0
746549	746024	20026V	PARTICIPANT	\N	PRESENT	0
746550	746024	14033T	PARTICIPANT	\N	PRESENT	0
746551	746024	04035D	PARTICIPANT	\N	PRESENT	0
746552	746024	14231L	PARTICIPANT	\N	PRESENT	0
746553	746024	19709B	PARTICIPANT	\N	PRESENT	0
746554	746024	18083K	PARTICIPANT	\N	PRESENT	0
746555	746024	14147R	PARTICIPANT	\N	PRESENT	0
746556	746024	08061X	PARTICIPANT	\N	PRESENT	0
746557	746024	20032T	PARTICIPANT	\N	PRESENT	0
746497	746024	01043Q	PARTICIPANT	\N	PRESENT	0
746503	746024	04042C	PARTICIPANT	\N	PRESENT	0
746558	746024	20052X	PARTICIPANT	\N	PRESENT	0
746559	746024	20142Y	PARTICIPANT	\N	PRESENT	0
746560	746024	17023S	PARTICIPANT	\N	PRESENT	0
746561	746024	20106U	PARTICIPANT	\N	PRESENT	0
746562	746024	20034V	PARTICIPANT	\N	PRESENT	0
746563	746024	07029T	PARTICIPANT	\N	PRESENT	0
746564	746024	04033B	PARTICIPANT	\N	PRESENT	0
746565	746024	14179A	PARTICIPANT	\N	PRESENT	0
746566	746024	20022R	PARTICIPANT	\N	PRESENT	0
746567	746024	19447X	PARTICIPANT	\N	PRESENT	0
746568	746024	14071N	PARTICIPANT	\N	PRESENT	0
746569	746024	14187A	PARTICIPANT	\N	PRESENT	0
746570	746024	05008E	PARTICIPANT	\N	PRESENT	0
746571	746024	20038A	PARTICIPANT	\N	PRESENT	0
746572	746024	20070A	PARTICIPANT	\N	PRESENT	0
746573	746024	19349W	PARTICIPANT	\N	PRESENT	0
746574	746024	11065P	PARTICIPANT	\N	PRESENT	0
746575	746024	20092G	PARTICIPANT	\N	PRESENT	0
746576	746024	20042V	PARTICIPANT	\N	PRESENT	0
746577	746024	14213J	PARTICIPANT	\N	PRESENT	0
746578	746024	19691J	PARTICIPANT	\N	PRESENT	0
746579	746024	20134Y	PARTICIPANT	\N	PRESENT	0
746580	746024	11064N	PARTICIPANT	\N	PRESENT	0
746581	746024	20298U	PARTICIPANT	\N	PRESENT	0
746720	744519	19735D	PARTICIPANT	\N	PRESENT	0
746642	744230	11048N	PARTICIPANT	\N	PRESENT	0
746721	744519	14109K	PARTICIPANT	\N	PRESENT	0
746722	744519	11043H	PARTICIPANT	\N	PRESENT	0
746714	744519	19643A	PARTICIPANT	\N	PRESENT	0
746723	744519	20124W	PARTICIPANT	\N	PRESENT	0
746647	744230	07029T	PARTICIPANT	\N	PRESENT	0
746724	744519	19621T	PARTICIPANT	\N	PRESENT	0
746649	744230	20080C	PARTICIPANT	\N	PRESENT	0
746650	746017	14026U	PARTICIPANT	\N	PRESENT	0
746651	746017	19591F	PARTICIPANT	\N	PRESENT	0
746652	746017	19691J	PARTICIPANT	\N	PRESENT	0
746659	744519	20056C	PARTICIPANT	\N	PRESENT	0
746660	744519	19593H	PARTICIPANT	\N	PRESENT	0
746661	744519	19699S	PARTICIPANT	\N	PRESENT	0
746662	744519	19611R	PRESIDENT	0	PRESENT	0
746663	744519	14123H	PARTICIPANT	\N	PRESENT	0
746664	744519	11104D	PARTICIPANT	\N	PRESENT	0
746665	744519	19693L	PARTICIPANT	\N	PRESENT	0
746666	744519	20052X	PARTICIPANT	\N	PRESENT	0
746667	744519	19758L	PARTICIPANT	\N	PRESENT	0
746668	744519	20026V	PARTICIPANT	\N	PRESENT	0
746715	744519	19719D	PARTICIPANT	\N	PRESENT	0
746670	744519	14030Q	PARTICIPANT	\N	PRESENT	0
746672	744519	19766L	PARTICIPANT	\N	PRESENT	0
746673	744519	20112S	PARTICIPANT	\N	PRESENT	0
746677	744230	04071H	PARTICIPANT	\N	PRESENT	0
746678	744230	01057W	PARTICIPANT	\N	PRESENT	0
746679	744230	11053K	PARTICIPANT	\N	PRESENT	0
746680	744230	19667J	PARTICIPANT	\N	PRESENT	0
746681	744230	11070L	PARTICIPANT	\N	PRESENT	0
746682	744230	19349W	PARTICIPANT	\N	PRESENT	0
746683	744230	08010L	PARTICIPANT	\N	PRESENT	0
746684	744230	14253S	PARTICIPANT	\N	PRESENT	0
746686	744230	20116W	PARTICIPANT	\N	PRESENT	0
746687	744230	19479G	PARTICIPANT	\N	PRESENT	0
746688	744230	19711U	PARTICIPANT	\N	PRESENT	0
746689	744230	19687N	PARTICIPANT	\N	PRESENT	0
746690	744230	20050V	PARTICIPANT	\N	PRESENT	0
746691	744230	08011M	PARTICIPANT	\N	PRESENT	0
746692	744230	20044X	PARTICIPANT	\N	PRESENT	0
746693	744230	11040E	PARTICIPANT	\N	PRESENT	0
746694	744230	14083S	PARTICIPANT	\N	PRESENT	0
746695	744230	11012A	PARTICIPANT	\N	PRESENT	0
746696	744230	08073C	PARTICIPANT	\N	PRESENT	0
746697	744230	14121F	PARTICIPANT	\N	PRESENT	0
746698	744230	19741B	PARTICIPANT	\N	PRESENT	0
746699	744230	20914V	PARTICIPANT	\N	PRESENT	0
746716	744519	20172F	PARTICIPANT	\N	PRESENT	0
746717	744519	14229S	PARTICIPANT	\N	PRESENT	0
746718	744519	20098N	PARTICIPANT	\N	PRESENT	0
746719	744519	20180F	PARTICIPANT	\N	PRESENT	0
756193	755843	21076L	PARTICIPANT	\N	PRESENT	0
756190	755843	04047H	PRESIDENT	0	PRESENT	0
756194	755843	14111D	PARTICIPANT	\N	PRESENT	0
756195	755843	19111A	PARTICIPANT	\N	PRESENT	0
756197	755843	19729F	PARTICIPANT	\N	PRESENT	0
756199	755843	05008E	PARTICIPANT	\N	PRESENT	0
756200	755843	21040X	PARTICIPANT	\N	PRESENT	0
756201	755843	19673G	PARTICIPANT	\N	PRESENT	0
756202	755843	21044C	PARTICIPANT	\N	PRESENT	0
756203	755843	14053L	PARTICIPANT	\N	PRESENT	0
756204	755843	14231L	PARTICIPANT	\N	PRESENT	0
756205	755843	10015M	PARTICIPANT	\N	PRESENT	0
756210	755843	14215L	PARTICIPANT	\N	PRESENT	0
756211	755843	20022R	PARTICIPANT	\N	PRESENT	0
756212	755843	21043B	PARTICIPANT	\N	PRESENT	0
756213	755843	20114U	PARTICIPANT	\N	PRESENT	0
756214	755843	19489J	PARTICIPANT	\N	PRESENT	0
756216	755843	14073Q	PARTICIPANT	\N	PRESENT	0
756217	755843	19533U	PARTICIPANT	\N	PRESENT	0
756218	755843	20138D	PARTICIPANT	\N	PRESENT	0
756219	755843	20056C	PARTICIPANT	\N	PRESENT	0
756220	755843	04070G	PARTICIPANT	\N	PRESENT	0
756221	755843	14089Y	PARTICIPANT	\N	PRESENT	0
756222	755843	21091K	PARTICIPANT	\N	PRESENT	0
756223	755843	20036X	PARTICIPANT	\N	PRESENT	0
756224	755843	19593H	PARTICIPANT	\N	PRESENT	0
756225	755843	21055F	PARTICIPANT	\N	PRESENT	0
756228	755843	21089R	PARTICIPANT	\N	PRESENT	0
756229	755843	14109K	PARTICIPANT	\N	PRESENT	0
756230	755843	21059K	PARTICIPANT	\N	PRESENT	0
756231	755843	19611R	PARTICIPANT	\N	PRESENT	0
756232	755843	20132W	PARTICIPANT	\N	PRESENT	0
756233	755843	21074J	PARTICIPANT	\N	PRESENT	0
756234	755843	08018U	PARTICIPANT	\N	PRESENT	0
756235	755843	14147R	PARTICIPANT	\N	PRESENT	0
756236	755843	21038E	PARTICIPANT	\N	PRESENT	0
756237	755843	11072N	PARTICIPANT	\N	PRESENT	0
756239	755843	18231D	PARTICIPANT	\N	PRESENT	0
756240	755843	21088Q	PARTICIPANT	\N	PRESENT	0
756241	755843	11056N	PARTICIPANT	\N	PRESENT	0
756243	755843	19735D	PARTICIPANT	\N	PRESENT	0
756245	755843	20108W	PARTICIPANT	\N	PRESENT	0
756268	755843	04045F	PARTICIPANT	\N	PRESENT	0
756269	755843	14259Y	PARTICIPANT	\N	PRESENT	0
756270	755843	21057H	PARTICIPANT	\N	PRESENT	0
756274	755843	19749K	PARTICIPANT	\N	PRESENT	0
756276	755843	21063F	PARTICIPANT	\N	PRESENT	0
756278	755843	18207D	PARTICIPANT	\N	PRESENT	0
756279	755843	20052X	PARTICIPANT	\N	PRESENT	0
756280	755843	20142Y	PARTICIPANT	\N	PRESENT	0
756284	755843	20026V	PARTICIPANT	\N	PRESENT	0
756286	755843	19585H	PARTICIPANT	\N	EXCUSE	0
756288	755843	20098N	PARTICIPANT	\N	PRESENT	0
756289	755843	20048C	PARTICIPANT	\N	PRESENT	0
756294	755843	14123H	PARTICIPANT	\N	PRESENT	0
756297	755843	21037D	PARTICIPANT	\N	PRESENT	0
756301	755843	20102Q	PARTICIPANT	\N	PRESENT	0
756307	755843	18395Y	PARTICIPANT	\N	PRESENT	0
756471	755843	19954N	PARTICIPANT	\N	PRESENT	0
756472	755843	19621T	PARTICIPANT	\N	PRESENT	0
756473	755843	20264J	PARTICIPANT	\N	PRESENT	0
756474	755843	20180F	PARTICIPANT	\N	PRESENT	0
756475	755843	21077M	PARTICIPANT	\N	PRESENT	0
759120	757844	21074J	PARTICIPANT	\N	PRESENT	0
760587	757768	14169X	PARTICIPANT	\N	EXCUSE	0
763689	761713	11074Q	PARTICIPANT	\N	PRESENT	0
763690	761713	14281W	PARTICIPANT	\N	PRESENT	0
763728	761713	19563B	PARTICIPANT	\N	PRESENT	0
763692	761713	19820Y	PARTICIPANT	\N	PRESENT	0
763693	761713	14257W	PARTICIPANT	\N	PRESENT	0
763712	761713	19685L	PARTICIPANT	\N	PRESENT	0
763695	761713	20114U	PARTICIPANT	\N	PRESENT	0
763696	761713	19725B	PARTICIPANT	\N	PRESENT	0
763697	761713	19649G	PARTICIPANT	\N	PRESENT	0
763719	761713	14179A	PARTICIPANT	\N	PRESENT	0
763723	761713	19611R	PARTICIPANT	\N	PRESENT	0
763700	761713	20064C	PARTICIPANT	\N	PRESENT	0
763754	761713	21097R	PARTICIPANT	\N	PRESENT	0
763702	761713	20266L	PARTICIPANT	\N	PRESENT	0
763703	761713	21054E	PARTICIPANT	\N	PRESENT	0
763704	761713	14251Q	PARTICIPANT	\N	PRESENT	0
763705	761713	21065H	PARTICIPANT	\N	PRESENT	0
763706	761713	14189C	PARTICIPANT	\N	PRESENT	0
763725	761713	08009T	PARTICIPANT	\N	PRESENT	0
763709	761713	14219Q	PARTICIPANT	\N	PRESENT	0
763711	761713	20286Q	PARTICIPANT	\N	PRESENT	0
763713	761713	15197G	PARTICIPANT	\N	PRESENT	0
763714	761713	14231L	PARTICIPANT	\N	PRESENT	0
763715	761713	14205J	PARTICIPANT	\N	PRESENT	0
763716	761713	19826F	PARTICIPANT	\N	PRESENT	0
763717	761713	19691J	PARTICIPANT	\N	PRESENT	0
763718	761713	19569H	PARTICIPANT	\N	PRESENT	0
763720	761713	21069M	PARTICIPANT	\N	PRESENT	0
763721	761713	20066E	PARTICIPANT	\N	PRESENT	0
763722	761713	19735D	PARTICIPANT	\N	PRESENT	0
763724	761713	19699S	PARTICIPANT	\N	PRESENT	0
763726	761713	20094J	PARTICIPANT	\N	PRESENT	0
763727	761713	11070L	PARTICIPANT	\N	PRESENT	0
763729	761713	19111A	PARTICIPANT	\N	PRESENT	0
763730	761713	17229F	PARTICIPANT	\N	PRESENT	0
763731	761713	11115U	PARTICIPANT	\N	PRESENT	0
763732	761713	17023S	PARTICIPANT	\N	PRESENT	0
763733	761713	21086N	PARTICIPANT	\N	PRESENT	0
763734	761713	14083S	PARTICIPANT	\N	PRESENT	0
763735	761713	20248J	PARTICIPANT	\N	PRESENT	0
763736	761713	20040T	PARTICIPANT	\N	PRESENT	0
763737	761713	14042U	PARTICIPANT	\N	PRESENT	0
763738	761713	21042A	PARTICIPANT	\N	PRESENT	0
763739	761713	11053K	PARTICIPANT	\N	PRESENT	0
763740	761713	21038E	PARTICIPANT	\N	PRESENT	0
763741	761713	14255U	PARTICIPANT	\N	PRESENT	0
763742	761713	21064G	PARTICIPANT	\N	PRESENT	0
763744	761713	11085T	PARTICIPANT	\N	PRESENT	0
763745	761713	19713W	PARTICIPANT	\N	PRESENT	0
763746	761713	19553Y	PARTICIPANT	\N	PRESENT	0
763747	761713	21040X	PARTICIPANT	\N	PRESENT	0
763748	761713	19866P	PARTICIPANT	\N	PRESENT	0
763749	761713	19749K	PARTICIPANT	\N	PRESENT	0
763750	761713	19760E	PARTICIPANT	\N	PRESENT	0
763751	761713	14225N	PARTICIPANT	\N	PRESENT	0
763752	761713	11064N	PARTICIPANT	\N	PRESENT	0
763753	761713	21090J	PARTICIPANT	\N	PRESENT	0
763755	761713	21095P	PARTICIPANT	\N	PRESENT	0
763757	761713	14213J	PARTICIPANT	\N	PRESENT	0
763758	761713	14089Y	PARTICIPANT	\N	PRESENT	0
763759	761713	14069U	PARTICIPANT	\N	PRESENT	0
763760	761713	21048G	PARTICIPANT	\N	PRESENT	0
763763	763762	18395Y	PARTICIPANT	\N	PRESENT	0
763764	763762	19735D	PARTICIPANT	\N	PRESENT	0
763765	761713	20048C	PARTICIPANT	\N	PRESENT	0
763766	761130	14109K	PARTICIPANT	\N	PRESENT	0
763767	761130	14030Q	PARTICIPANT	\N	PRESENT	0
764084	761181	19711U	PARTICIPANT	\N	PRESENT	0
743948	743947	19693L	PARTICIPANT	\N	PRESENT	0
743949	743947	19701S	PARTICIPANT	\N	PRESENT	0
753955	753659	19826F	PARTICIPANT	\N	PRESENT	0
753956	753659	20072C	PARTICIPANT	\N	PRESENT	0
753957	753659	14207L	PARTICIPANT	\N	PRESENT	0
753958	753659	21071F	PARTICIPANT	\N	PRESENT	0
753959	753659	21082J	PARTICIPANT	\N	PRESENT	0
753960	753659	14237S	PARTICIPANT	\N	PRESENT	0
753961	753659	21095P	PARTICIPANT	\N	PRESENT	0
753962	753659	20048C	PARTICIPANT	\N	PRESENT	0
753963	753659	21049H	PARTICIPANT	\N	PRESENT	0
753964	753659	19573D	PARTICIPANT	\N	PRESENT	0
753965	753659	18395Y	PARTICIPANT	\N	PRESENT	0
753966	753659	14053L	PARTICIPANT	\N	PRESENT	0
753967	753659	21043B	PARTICIPANT	\N	PRESENT	0
753968	753659	19421M	PARTICIPANT	\N	PRESENT	0
753969	753659	19745F	PARTICIPANT	\N	PRESENT	0
753970	753659	14107H	PARTICIPANT	\N	PRESENT	0
753971	753659	14189C	PARTICIPANT	\N	PRESENT	0
753972	753659	10015M	PARTICIPANT	\N	PRESENT	0
753973	753658	14259Y	PARTICIPANT	\N	PRESENT	0
754070	753658	21048G	PARTICIPANT	\N	PRESENT	0
753975	753658	21040X	PARTICIPANT	\N	PRESENT	0
754063	753658	21083K	PARTICIPANT	\N	PRESENT	0
754064	753658	20248J	PARTICIPANT	\N	PRESENT	0
754068	753658	20056C	PARTICIPANT	\N	PRESENT	0
753979	753658	21075K	PARTICIPANT	\N	PRESENT	0
753980	753658	19782L	PARTICIPANT	\N	PRESENT	0
753981	753658	21039F	PARTICIPANT	\N	PRESENT	0
754060	753658	20084G	PARTICIPANT	\N	PRESENT	0
753983	753658	21042A	PARTICIPANT	\N	PRESENT	0
753984	753658	11090Q	PARTICIPANT	\N	PRESENT	0
753985	753658	14187A	PARTICIPANT	\N	PRESENT	0
753986	753658	20034V	PARTICIPANT	\N	PRESENT	0
754069	753658	20104S	PARTICIPANT	\N	PRESENT	0
753988	753658	21093M	PARTICIPANT	\N	PRESENT	0
753989	753658	21053D	PARTICIPANT	\N	PRESENT	0
753990	753658	21033Y	PARTICIPANT	\N	PRESENT	0
753991	753658	21078N	PARTICIPANT	\N	PRESENT	0
753992	753658	19301E	PARTICIPANT	\N	PRESENT	0
753993	753658	19621T	PARTICIPANT	\N	PRESENT	0
753994	753658	21036C	PARTICIPANT	\N	PRESENT	0
753995	753658	20286Q	PARTICIPANT	\N	PRESENT	0
754059	753658	20088L	PARTICIPANT	\N	PRESENT	0
753997	753658	21032X	PARTICIPANT	\N	PRESENT	0
753998	753658	21050A	PARTICIPANT	\N	PRESENT	0
753999	753658	21054E	PARTICIPANT	\N	PRESENT	0
754065	753658	19631V	PARTICIPANT	\N	PRESENT	0
754001	753658	21052C	PARTICIPANT	\N	PRESENT	0
754061	753658	19687N	PARTICIPANT	\N	PRESENT	0
754003	753658	20082E	PARTICIPANT	\N	PRESENT	0
754062	753658	14257W	PARTICIPANT	\N	PRESENT	0
754005	753658	21072G	PARTICIPANT	\N	PRESENT	0
754006	753658	19399H	PARTICIPANT	\N	PRESENT	0
754007	753658	08056B	PARTICIPANT	\N	PRESENT	0
754008	753658	20098N	PARTICIPANT	\N	PRESENT	0
754009	753658	21086N	PARTICIPANT	\N	PRESENT	0
754010	753658	19768N	PARTICIPANT	\N	PRESENT	0
754071	753658	14231L	PARTICIPANT	\N	PRESENT	0
754012	753658	21085M	PARTICIPANT	\N	PRESENT	0
754066	753658	14179A	PARTICIPANT	\N	PRESENT	0
754072	753658	21064G	PARTICIPANT	\N	PRESENT	0
754015	753658	19695N	PARTICIPANT	\N	PRESENT	0
754016	753658	21047F	PARTICIPANT	\N	PRESENT	0
754073	753658	21058J	PARTICIPANT	\N	PRESENT	0
754018	753658	19954N	PARTICIPANT	\N	PRESENT	0
754019	753658	20180F	PARTICIPANT	\N	PRESENT	0
754020	753658	20044X	PARTICIPANT	\N	PRESENT	0
754021	753658	19693L	PARTICIPANT	\N	PRESENT	0
754022	753658	14221J	PARTICIPANT	\N	PRESENT	0
754067	753658	19383Y	PARTICIPANT	\N	PRESENT	0
754074	753658	20140W	PARTICIPANT	\N	PRESENT	0
754025	753658	20172F	PARTICIPANT	\N	PRESENT	0
754075	753658	21092L	PARTICIPANT	\N	PRESENT	0
754076	753658	08015R	PARTICIPANT	\N	PRESENT	0
754028	753658	20086J	PARTICIPANT	\N	PRESENT	0
754029	753658	19533U	PARTICIPANT	\N	PRESENT	0
754030	753658	21057H	PARTICIPANT	\N	PRESENT	0
754077	753658	19575F	PARTICIPANT	\N	PRESENT	0
754032	753658	21088Q	PARTICIPANT	\N	PRESENT	0
754033	753658	04045F	PARTICIPANT	\N	PRESENT	0
754078	753658	11053K	PARTICIPANT	\N	PRESENT	0
754079	753658	21074J	PARTICIPANT	\N	PRESENT	0
754080	753658	19713W	PARTICIPANT	\N	PRESENT	0
754037	753658	20068G	PARTICIPANT	\N	PRESENT	0
754038	753658	18083K	PARTICIPANT	\N	PRESENT	0
754039	753658	19349W	PARTICIPANT	\N	PRESENT	0
754082	753658	07004J	PARTICIPANT	\N	PRESENT	0
754041	753658	20072C	PARTICIPANT	\N	PRESENT	0
754042	753658	14207L	PARTICIPANT	\N	PRESENT	0
754043	753658	21071F	PARTICIPANT	\N	PRESENT	0
754044	753658	21082J	PARTICIPANT	\N	PRESENT	0
754045	753658	14237S	PARTICIPANT	\N	PRESENT	0
754095	753658	18207D	PARTICIPANT	\N	PRESENT	0
754083	753658	20102Q	PARTICIPANT	\N	PRESENT	0
754048	753658	21049H	PARTICIPANT	\N	PRESENT	0
754084	753658	20046A	PARTICIPANT	\N	PRESENT	0
754050	753658	18395Y	PARTICIPANT	\N	PRESENT	0
754096	753658	20144B	PARTICIPANT	\N	PRESENT	0
754085	753658	19760E	PARTICIPANT	\N	PRESENT	0
754053	753658	19421M	PARTICIPANT	\N	PRESENT	0
754054	753658	19745F	PARTICIPANT	\N	PRESENT	0
754055	753658	14107H	PARTICIPANT	\N	PRESENT	0
754056	753658	14189C	PARTICIPANT	\N	PRESENT	0
754057	753658	10015M	PARTICIPANT	\N	PRESENT	0
754058	753658	21069M	PARTICIPANT	\N	PRESENT	0
754086	753658	20092G	PARTICIPANT	\N	PRESENT	0
754087	753658	20024T	PARTICIPANT	\N	PRESENT	0
754088	753658	20032T	PARTICIPANT	\N	PRESENT	0
754089	753658	08028W	PARTICIPANT	\N	PRESENT	0
754090	753658	14097Y	PARTICIPANT	\N	PRESENT	0
754091	753658	20124W	PARTICIPANT	\N	PRESENT	0
754092	753658	19573D	PARTICIPANT	\N	PRESENT	0
754093	753658	19507S	PARTICIPANT	\N	PRESENT	0
754094	753658	20134Y	PARTICIPANT	\N	PRESENT	0
754097	753658	20126Y	PARTICIPANT	\N	PRESENT	0
754098	753658	99004R	PARTICIPANT	\N	PRESENT	0
754099	753658	21044C	PARTICIPANT	\N	PRESENT	0
754100	753658	11056N	PARTICIPANT	\N	PRESENT	0
754101	753658	20116W	PARTICIPANT	\N	PRESENT	0
754102	753658	19685L	PARTICIPANT	\N	PRESENT	0
754103	753658	14031R	PARTICIPANT	\N	PRESENT	0
754104	753658	14223L	PARTICIPANT	\N	PRESENT	0
754105	753658	19479G	PARTICIPANT	\N	PRESENT	0
754106	753658	21084L	PARTICIPANT	\N	PRESENT	0
754107	753658	19565D	PARTICIPANT	\N	PRESENT	0
754108	753658	20062A	PARTICIPANT	\N	PRESENT	0
754109	753658	18193Q	PARTICIPANT	\N	PRESENT	0
754110	753658	20054A	PARTICIPANT	\N	PRESENT	0
754111	753658	19387D	PARTICIPANT	\N	PRESENT	0
754112	753658	14037X	PARTICIPANT	\N	PRESENT	0
754113	753658	14193X	PARTICIPANT	\N	PRESENT	0
754114	753658	19563B	PARTICIPANT	\N	PRESENT	0
754115	753658	19725B	PARTICIPANT	\N	PRESENT	0
754116	753658	21066J	PARTICIPANT	\N	PRESENT	0
754117	753658	21097R	PARTICIPANT	\N	PRESENT	0
754118	753658	20106U	PARTICIPANT	\N	PRESENT	0
754119	753658	19798U	PARTICIPANT	\N	PRESENT	0
754120	753658	20018V	PARTICIPANT	\N	PRESENT	0
754121	753658	11110B	PARTICIPANT	\N	PRESENT	0
754122	753658	14055N	PARTICIPANT	\N	PRESENT	0
754123	753658	21038E	PARTICIPANT	\N	PRESENT	0
754124	753658	14069U	PARTICIPANT	\N	PRESENT	0
754125	753658	20090E	PARTICIPANT	\N	PRESENT	0
754126	753658	14329V	PARTICIPANT	\N	PRESENT	0
754127	753658	21090J	PARTICIPANT	\N	PRESENT	0
754128	753658	21067K	PARTICIPANT	\N	PRESENT	0
754129	753658	21056G	PARTICIPANT	\N	PRESENT	0
754130	753658	14147R	PARTICIPANT	\N	PRESENT	0
754131	753658	04047H	PARTICIPANT	\N	PRESENT	0
754132	753658	14225N	PARTICIPANT	\N	PRESENT	0
754133	753658	21070E	PARTICIPANT	\N	PRESENT	0
754134	753658	21043B	PARTICIPANT	\N	PRESENT	0
754135	753658	21051B	PARTICIPANT	\N	PRESENT	0
754137	753658	19111A	PARTICIPANT	\N	PRESENT	0
754138	753658	14033T	PARTICIPANT	\N	PRESENT	0
754139	753658	20038A	PARTICIPANT	\N	PRESENT	0
754140	753658	21059K	PARTICIPANT	\N	PRESENT	0
754141	753658	20110Q	PARTICIPANT	\N	PRESENT	0
754142	753658	18231D	PARTICIPANT	\N	PRESENT	0
754143	753658	14169X	PARTICIPANT	\N	PRESENT	0
756845	755920	19711U	PARTICIPANT	\N	PRESENT	0
757251	755861	21059K	PARTICIPANT	\N	PRESENT	0
756847	755920	08034U	PARTICIPANT	\N	PRESENT	0
756849	755920	08011M	PARTICIPANT	\N	PRESENT	0
756851	755920	14173T	PARTICIPANT	\N	PRESENT	0
757253	755861	19295A	PARTICIPANT	\N	PRESENT	0
756854	755920	08009T	PARTICIPANT	\N	PRESENT	0
756856	755920	19741B	PARTICIPANT	\N	PRESENT	0
756858	755920	19762G	PARTICIPANT	\N	PRESENT	0
757254	755861	14191V	PARTICIPANT	\N	PRESENT	0
756861	755920	12016W	PARTICIPANT	\N	EXCUSE	0
757084	755865	04042C	PARTICIPANT	\N	PRESENT	0
757085	755865	14179A	PARTICIPANT	\N	PRESENT	0
757086	755865	14251Q	PARTICIPANT	\N	PRESENT	0
757091	755944	19768N	PARTICIPANT	\N	PRESENT	0
757092	755944	19782L	PARTICIPANT	\N	PRESENT	0
757093	755944	20018V	PARTICIPANT	\N	PRESENT	0
757094	755944	21050A	PARTICIPANT	\N	PRESENT	0
757095	755944	20028X	PARTICIPANT	\N	PRESENT	0
757096	755944	14038Y	PARTICIPANT	\N	PRESENT	0
757097	755944	20030R	PARTICIPANT	\N	PRESENT	0
757098	755944	21052C	PARTICIPANT	\N	PRESENT	0
757099	755944	21054E	PARTICIPANT	\N	PRESENT	0
757100	755944	20034V	PARTICIPANT	\N	PRESENT	0
757101	755944	14187A	PRESIDENT	0	PRESENT	0
757102	755944	20038A	PARTICIPANT	\N	PRESENT	0
757103	755944	21075K	PARTICIPANT	\N	PRESENT	0
757104	755944	21083K	PARTICIPANT	\N	PRESENT	0
757105	755944	21086N	PARTICIPANT	\N	PRESENT	0
757106	755944	21092L	PARTICIPANT	\N	PRESENT	0
757107	755944	19695N	PARTICIPANT	\N	PRESENT	0
757108	755944	21093M	PARTICIPANT	\N	PRESENT	0
757109	755944	11090Q	PARTICIPANT	\N	PRESENT	0
757110	755944	20054A	PARTICIPANT	\N	PRESENT	0
757111	755944	21034A	PARTICIPANT	\N	PRESENT	0
757112	755944	20060X	PARTICIPANT	\N	PRESENT	0
757113	755944	20066E	PARTICIPANT	\N	PRESENT	0
757114	755944	21066J	PARTICIPANT	\N	PRESENT	0
757115	755944	14207L	PARTICIPANT	\N	PRESENT	0
757116	755944	20084G	PARTICIPANT	\N	PRESENT	0
757117	755944	14257W	PARTICIPANT	\N	PRESENT	0
757118	755944	19383Y	PARTICIPANT	\N	PRESENT	0
757119	755944	20088L	PARTICIPANT	\N	PRESENT	0
757120	755944	20092G	PARTICIPANT	\N	PRESENT	0
757121	755944	14357A	PARTICIPANT	\N	PRESENT	0
757122	755944	20078J	PARTICIPANT	\N	PRESENT	0
757123	755944	19413M	PARTICIPANT	\N	PRESENT	0
757124	755944	20082E	PARTICIPANT	\N	PRESENT	0
757125	755944	14221J	PARTICIPANT	\N	PRESENT	0
757126	755944	20104S	PARTICIPANT	\N	PRESENT	0
757127	755944	19631V	PARTICIPANT	\N	PRESENT	0
757128	755944	19705W	PARTICIPANT	\N	PRESENT	0
757129	755944	19707Y	PARTICIPANT	\N	PRESENT	0
757130	755944	08015R	PARTICIPANT	\N	PRESENT	0
757131	755944	19575F	PARTICIPANT	\N	PRESENT	0
757132	755944	08028W	PARTICIPANT	\N	PRESENT	0
757133	755944	19563B	PARTICIPANT	\N	PRESENT	0
757134	755944	14329V	PARTICIPANT	\N	PRESENT	0
757135	755944	20144B	PARTICIPANT	\N	PRESENT	0
757136	755944	14033T	PARTICIPANT	\N	PRESENT	0
757137	755944	14205J	PARTICIPANT	\N	PRESENT	0
757138	755944	19507S	PARTICIPANT	\N	PRESENT	0
757139	755944	20286Q	PARTICIPANT	\N	PRESENT	0
757140	755861	86034E	PARTICIPANT	\N	PRESENT	0
757193	755999	21082J	PARTICIPANT	\N	PRESENT	0
757194	755999	19701S	PARTICIPANT	\N	PRESENT	0
757195	755999	21035B	PARTICIPANT	\N	PRESENT	0
757196	755999	20076G	PARTICIPANT	\N	PRESENT	0
757197	755999	21042A	PARTICIPANT	\N	PRESENT	0
757198	755999	19387D	PARTICIPANT	\N	PRESENT	0
757199	755999	11053K	PARTICIPANT	\N	PRESENT	0
757200	755999	19820Y	PARTICIPANT	\N	PRESENT	0
757201	755999	14219Q	PRESIDENT	0	PRESENT	0
757202	755999	19826F	PARTICIPANT	\N	PRESENT	0
757203	755999	21060C	PARTICIPANT	\N	PRESENT	0
757204	755999	21061D	PARTICIPANT	\N	PRESENT	0
757205	755999	21062E	PARTICIPANT	\N	PRESENT	0
757206	755999	21065H	PARTICIPANT	\N	PRESENT	0
757207	755999	18083K	PARTICIPANT	\N	PRESENT	0
757208	755999	19551W	PARTICIPANT	\N	PRESENT	0
757209	755999	21084L	PARTICIPANT	\N	PRESENT	0
757210	755999	20100N	PARTICIPANT	\N	PRESENT	0
757211	755999	14237S	PARTICIPANT	\N	PRESENT	0
757212	755999	05012A	PARTICIPANT	\N	PRESENT	0
757213	755999	21085M	PARTICIPANT	\N	PRESENT	0
757214	755999	08060W	PARTICIPANT	\N	PRESENT	0
757215	755999	20106U	PARTICIPANT	\N	PRESENT	0
757216	755999	20118Y	PARTICIPANT	\N	PRESENT	0
757217	755999	15197G	PARTICIPANT	\N	PRESENT	0
757218	755999	14107H	PARTICIPANT	\N	PRESENT	0
757219	755999	21080G	PARTICIPANT	\N	PRESENT	0
757220	755999	19331L	PARTICIPANT	\N	PRESENT	0
757221	755999	20020P	PARTICIPANT	\N	PRESENT	0
757222	755999	19685L	PARTICIPANT	\N	PRESENT	0
757223	755999	19681G	PARTICIPANT	\N	PRESENT	0
757224	755999	11065P	PARTICIPANT	\N	PRESENT	0
757225	755999	20120S	PARTICIPANT	\N	PRESENT	0
757226	755999	21051B	PARTICIPANT	\N	PRESENT	0
757227	755999	20032T	PARTICIPANT	\N	PRESENT	0
757228	755999	21053D	PARTICIPANT	\N	PRESENT	0
757229	755999	20136B	PARTICIPANT	\N	PRESENT	0
757230	755999	14031R	PARTICIPANT	\N	PRESENT	0
757231	755999	20040T	PARTICIPANT	\N	PRESENT	0
757232	755999	19251M	PARTICIPANT	\N	PRESENT	0
757233	755999	20046A	PARTICIPANT	\N	PRESENT	0
757234	755999	14169X	PARTICIPANT	\N	PRESENT	0
757235	755999	17229F	PARTICIPANT	\N	PRESENT	0
757236	755999	21047F	PARTICIPANT	\N	PRESENT	0
757237	755999	20068G	PARTICIPANT	\N	PRESENT	0
757238	755999	21068L	PARTICIPANT	\N	PRESENT	0
757239	755999	21070E	PARTICIPANT	\N	PRESENT	0
757240	755999	19619A	PARTICIPANT	\N	PRESENT	0
757258	755861	20102Q	PARTICIPANT	\N	PRESENT	0
757259	755861	19691J	PARTICIPANT	\N	PRESENT	0
757260	755861	20090E	PARTICIPANT	\N	PRESENT	0
757261	755861	21052C	PARTICIPANT	\N	PRESENT	0
757262	755861	98022P	PARTICIPANT	\N	PRESENT	0
757263	755861	19713W	PARTICIPANT	\N	PRESENT	0
757264	755861	19745F	PARTICIPANT	\N	PRESENT	0
757265	755861	08060W	PARTICIPANT	\N	PRESENT	0
757266	755861	21039F	PARTICIPANT	\N	PRESENT	0
757267	755861	14331P	PARTICIPANT	\N	PRESENT	0
757268	755861	08028W	PARTICIPANT	\N	PRESENT	0
757269	755861	19701S	PARTICIPANT	\N	PRESENT	0
757270	755861	19707Y	PARTICIPANT	\N	PRESENT	0
757271	755861	19705W	PARTICIPANT	\N	PRESENT	0
757272	755861	14033T	PARTICIPANT	\N	PRESENT	0
757273	755861	20040T	PARTICIPANT	\N	PRESENT	0
757274	755861	04045F	PARTICIPANT	\N	PRESENT	0
757275	755861	21090J	PARTICIPANT	\N	PRESENT	0
757276	755861	20142Y	PARTICIPANT	\N	PRESENT	0
757277	755861	14030Q	PARTICIPANT	\N	PRESENT	0
757278	755861	04070G	PARTICIPANT	\N	PRESENT	0
757279	755861	19629C	PARTICIPANT	\N	PRESENT	0
757280	755861	21070E	PARTICIPANT	\N	PRESENT	0
757281	755861	21065H	PARTICIPANT	\N	PRESENT	0
757282	755861	14267Y	PARTICIPANT	\N	PRESENT	0
757283	755861	21057H	PARTICIPANT	\N	PRESENT	0
757284	755861	20144B	PARTICIPANT	\N	PRESENT	0
757285	755861	20036X	PARTICIPANT	\N	PRESENT	0
757286	755861	14221J	PARTICIPANT	\N	PRESENT	0
757287	755861	11027H	PARTICIPANT	\N	PRESENT	0
757288	755861	20088L	PARTICIPANT	\N	PRESENT	0
757289	755861	12028B	PARTICIPANT	\N	PRESENT	0
757290	755861	19619A	PARTICIPANT	\N	PRESENT	0
757291	755861	21060C	PARTICIPANT	\N	PRESENT	0
757292	755861	01058X	PARTICIPANT	\N	PRESENT	0
757293	755861	04008A	PARTICIPANT	\N	PRESENT	0
757294	755861	19711U	PARTICIPANT	\N	PRESENT	0
757295	755861	19760E	PARTICIPANT	\N	PRESENT	0
757296	755861	18083K	PARTICIPANT	\N	PRESENT	0
757297	755861	11040E	PARTICIPANT	\N	PRESENT	0
757298	755861	19575F	PARTICIPANT	\N	PRESENT	0
757299	755861	21034A	PARTICIPANT	\N	PRESENT	0
757300	755861	99004R	PARTICIPANT	\N	PRESENT	0
757301	755861	19621T	PARTICIPANT	\N	PRESENT	0
757302	755861	11056N	PARTICIPANT	\N	PRESENT	0
757303	755861	19565D	PARTICIPANT	\N	PRESENT	0
757304	755861	21075K	PARTICIPANT	\N	PRESENT	0
757305	755861	19367Y	PARTICIPANT	\N	PRESENT	0
757306	755861	19593H	PARTICIPANT	\N	PRESENT	0
746725	744519	20058E	PARTICIPANT	\N	PRESENT	0
746727	744519	20138D	PARTICIPANT	\N	PRESENT	0
746728	744519	20134Y	PARTICIPANT	\N	PRESENT	0
746729	744519	20264J	PARTICIPANT	\N	PRESENT	0
746732	744519	19527W	PARTICIPANT	\N	PRESENT	0
746750	746017	01034P	PARTICIPANT	\N	PRESENT	0
746751	746017	19663E	PARTICIPANT	\N	PRESENT	0
746752	746017	19717B	PARTICIPANT	\N	PRESENT	0
746753	746017	20266L	PARTICIPANT	\N	PRESENT	0
746754	746017	04043D	PARTICIPANT	\N	PRESENT	0
746756	746017	19798U	PARTICIPANT	\N	PRESENT	0
746757	746017	11097X	PARTICIPANT	\N	PRESENT	0
746758	746017	17779H	PARTICIPANT	\N	PRESENT	0
746759	746017	19511N	PARTICIPANT	\N	PRESENT	0
746760	746017	11045K	PARTICIPANT	\N	PRESENT	0
746761	746025	86034E	PARTICIPANT	\N	PRESENT	0
746787	746017	19683J	PARTICIPANT	\N	PRESENT	0
747780	747779	20094J	PARTICIPANT	\N	PRESENT	0
747781	747779	14030Q	PARTICIPANT	\N	PRESENT	0
747782	747779	19515S	PRESIDENT	0	PRESENT	0
747783	747779	19467C	PARTICIPANT	\N	PRESENT	0
746825	746018	19679N	PARTICIPANT	\N	PRESENT	0
747784	747779	19575F	PARTICIPANT	\N	PRESENT	0
747785	747779	14083S	PARTICIPANT	\N	PRESENT	0
746828	746018	19553Y	PARTICIPANT	\N	PRESENT	0
746829	746018	14217N	PARTICIPANT	\N	PRESENT	0
746830	746018	19367Y	PARTICIPANT	\N	PRESENT	0
747786	747779	14105F	PARTICIPANT	\N	EXCUSE	0
746832	746018	14213J	PARTICIPANT	\N	PRESENT	0
746833	746018	14195A	PARTICIPANT	\N	PRESENT	0
747787	747779	19545Y	PARTICIPANT	\N	EXCUSE	0
746835	746018	11067R	PARTICIPANT	\N	PRESENT	0
747788	747779	20060X	PARTICIPANT	\N	EXCUSE	0
746837	746018	14223L	PARTICIPANT	\N	PRESENT	0
747789	747779	14329V	PARTICIPANT	\N	EXCUSE	0
746839	746018	18193Q	PARTICIPANT	\N	PRESENT	0
747790	747779	14195A	PARTICIPANT	\N	EXCUSE	0
746841	746018	14026U	PARTICIPANT	\N	PRESENT	0
747791	747779	08028W	PARTICIPANT	\N	EXCUSE	0
746843	746018	20248J	PARTICIPANT	\N	PRESENT	0
746844	746018	20148F	PARTICIPANT	\N	PRESENT	0
746845	746018	14042U	PARTICIPANT	\N	PRESENT	0
746846	746018	19415P	PARTICIPANT	\N	PRESENT	0
747792	747779	14357A	PARTICIPANT	\N	EXCUSE	0
746848	746018	14071N	PARTICIPANT	\N	PRESENT	0
746849	746018	04092N	PARTICIPANT	\N	PRESENT	0
746850	746018	20130U	PARTICIPANT	\N	PRESENT	0
746851	746018	10006L	PRESIDENT	\N	PRESENT	0
746852	746018	17965H	PARTICIPANT	\N	PRESENT	0
747793	747779	20048C	PARTICIPANT	\N	EXCUSE	0
747794	747779	20126Y	PARTICIPANT	\N	EXCUSE	0
747795	747779	08015R	PARTICIPANT	\N	EXCUSE	0
746856	746018	19663E	PARTICIPANT	\N	PRESENT	0
747796	747779	19697Q	PARTICIPANT	\N	EXCUSE	0
747797	747779	14031R	PARTICIPANT	\N	EXCUSE	0
746859	746018	04043D	PARTICIPANT	\N	PRESENT	0
747798	747779	19369B	PARTICIPANT	\N	EXCUSE	0
746861	746018	19723Y	PARTICIPANT	\N	PRESENT	0
747799	747779	14253S	PARTICIPANT	\N	EXCUSE	0
747800	747779	19866P	PARTICIPANT	\N	EXCUSE	0
747801	747779	20030R	PARTICIPANT	\N	EXCUSE	0
747802	747779	20054A	PARTICIPANT	\N	EXCUSE	0
747803	747779	19762G	PARTICIPANT	\N	EXCUSE	0
747941	747940	04047H	PARTICIPANT	\N	PRESENT	0
747942	747940	04042C	PARTICIPANT	\N	PRESENT	0
747943	747940	14053L	PARTICIPANT	\N	PRESENT	0
747948	747940	11066Q	PARTICIPANT	\N	PRESENT	0
749007	748161	14331P	PARTICIPANT	\N	PRESENT	0
749008	748161	19711U	PARTICIPANT	\N	PRESENT	0
749009	748161	20252E	PARTICIPANT	\N	PRESENT	0
749010	748161	01048V	PARTICIPANT	\N	PRESENT	0
749011	748161	01057W	PARTICIPANT	\N	PRESENT	0
749012	748161	20116W	PARTICIPANT	\N	PRESENT	0
749013	748161	14225N	PRESIDENT	0	PRESENT	0
749014	748161	20086J	PARTICIPANT	\N	PRESENT	0
749015	748161	07029T	PARTICIPANT	\N	EXCUSE	0
749016	748161	11048N	PARTICIPANT	\N	PRESENT	0
749019	748161	19479G	PARTICIPANT	\N	PRESENT	0
749037	748161	19349W	PARTICIPANT	\N	PRESENT	0
749039	748161	14121F	PARTICIPANT	\N	PRESENT	0
749040	748161	19741B	PARTICIPANT	\N	PRESENT	0
749042	748161	08010L	PARTICIPANT	\N	PRESENT	0
749043	748161	20126Y	PARTICIPANT	\N	PRESENT	0
749044	749031	14059S	PARTICIPANT	\N	PRESENT	0
749045	749031	04035D	PARTICIPANT	\N	PRESENT	0
749046	749031	01062T	PARTICIPANT	\N	PRESENT	0
749047	749031	19565D	PARTICIPANT	\N	PRESENT	0
749048	749031	20072C	PARTICIPANT	\N	PRESENT	0
749049	749031	11041F	PARTICIPANT	\N	PRESENT	0
749050	749031	16685X	PARTICIPANT	\N	PRESENT	0
749051	749031	04042C	PRESIDENT	0	PRESENT	0
749052	749031	11054L	PARTICIPANT	\N	PRESENT	0
749053	749031	19669L	PARTICIPANT	\N	PRESENT	0
749054	749031	11066Q	PARTICIPANT	\N	PRESENT	0
749055	749031	14191V	PARTICIPANT	\N	PRESENT	0
749056	749031	12028B	PARTICIPANT	\N	PRESENT	0
749057	749031	19319Q	PARTICIPANT	\N	PRESENT	0
749058	749031	20064C	PARTICIPANT	\N	PRESENT	0
749059	749031	19421M	PARTICIPANT	\N	PRESENT	0
749060	749031	19709B	PARTICIPANT	\N	PRESENT	0
749061	749031	98022P	PARTICIPANT	\N	PRESENT	0
749062	749031	14193X	PARTICIPANT	\N	PRESENT	0
749063	749031	11083R	PARTICIPANT	\N	PRESENT	0
749064	749031	97011G	PARTICIPANT	\N	PRESENT	0
749065	749031	08061X	PARTICIPANT	\N	PRESENT	0
749066	749031	08047A	PARTICIPANT	\N	PRESENT	0
749067	748161	14253S	PARTICIPANT	\N	PRESENT	0
749071	748161	20044X	PARTICIPANT	\N	PRESENT	0
749073	748161	20080C	PARTICIPANT	\N	PRESENT	0
749088	748161	14189C	PARTICIPANT	\N	PRESENT	0
749090	748161	14173T	PARTICIPANT	\N	PRESENT	0
749095	748161	11070L	PARTICIPANT	\N	PRESENT	0
749097	748161	19687N	PARTICIPANT	\N	PRESENT	0
749098	748161	14083S	PARTICIPANT	\N	PRESENT	0
749102	748161	11053K	PARTICIPANT	\N	PRESENT	0
749106	748161	14327T	PARTICIPANT	\N	PRESENT	0
749107	748161	04071H	PARTICIPANT	\N	PRESENT	0
749108	748161	99004R	PARTICIPANT	\N	PRESENT	0
749110	749031	12041X	PARTICIPANT	\N	PRESENT	0
749111	749031	19347U	PARTICIPANT	\N	PRESENT	0
749112	749031	07033P	PARTICIPANT	\N	PRESENT	0
749113	749031	14133K	PARTICIPANT	\N	PRESENT	0
749114	749031	08069G	PARTICIPANT	\N	PRESENT	0
749115	749031	01024M	PARTICIPANT	\N	PRESENT	0
749116	749031	14211G	PARTICIPANT	\N	PRESENT	0
749117	749031	14105F	PARTICIPANT	\N	EXCUSE	0
749118	749031	19443T	PARTICIPANT	\N	EXCUSE	0
749119	749031	20042V	PARTICIPANT	\N	EXCUSE	0
749137	749070	19383Y	PARTICIPANT	\N	PRESENT	0
749138	749070	20088L	PARTICIPANT	\N	PRESENT	0
749139	749070	19768N	PARTICIPANT	\N	PRESENT	0
749140	749070	19515S	PARTICIPANT	\N	PRESENT	0
749141	749070	20092G	PARTICIPANT	\N	PRESENT	0
749142	749070	19782L	PARTICIPANT	\N	PRESENT	0
749143	749070	19441R	PARTICIPANT	\N	PRESENT	0
749144	749070	20078J	PARTICIPANT	\N	PRESENT	0
749145	749070	19413M	PARTICIPANT	\N	PRESENT	0
749146	749070	20082E	PARTICIPANT	\N	PRESENT	0
749147	749070	20104S	PARTICIPANT	\N	PRESENT	0
749148	749070	08015R	PARTICIPANT	\N	PRESENT	0
749149	749070	19575F	PARTICIPANT	\N	PRESENT	0
749150	749070	19369B	PARTICIPANT	\N	PRESENT	0
749151	749070	20018V	PARTICIPANT	\N	PRESENT	0
749152	749070	08028W	PARTICIPANT	\N	PRESENT	0
749153	749070	20028X	PARTICIPANT	\N	PRESENT	0
749154	749070	14038Y	PARTICIPANT	\N	PRESENT	0
749155	749070	19467C	PARTICIPANT	\N	PRESENT	0
749156	749070	20034V	PARTICIPANT	\N	PRESENT	0
749157	749070	14187A	PARTICIPANT	\N	PRESENT	0
749158	749070	20144B	PARTICIPANT	\N	PRESENT	0
749159	749070	19695N	PARTICIPANT	\N	PRESENT	0
749160	749070	11090Q	PRESIDENT	0	PRESENT	0
749161	749070	14033T	PARTICIPANT	\N	PRESENT	0
749162	749070	20054A	PARTICIPANT	\N	PRESENT	0
749163	749070	14205J	PARTICIPANT	\N	PRESENT	0
749164	749070	20060X	PARTICIPANT	\N	PRESENT	0
749165	749070	20286Q	PARTICIPANT	\N	PRESENT	0
749166	749070	20298U	PARTICIPANT	\N	PRESENT	0
764373	761714	14179A	PARTICIPANT	\N	PRESENT	0
764375	761714	19649G	PARTICIPANT	\N	PRESENT	0
764376	761714	04047H	PARTICIPANT	\N	PRESENT	0
764377	761714	14089Y	PARTICIPANT	\N	PRESENT	0
764378	761714	19447X	PARTICIPANT	\N	PRESENT	0
764379	761714	20110Q	PARTICIPANT	\N	PRESENT	0
764380	761714	20266L	PARTICIPANT	\N	PRESENT	0
764381	761714	99004R	PARTICIPANT	\N	PRESENT	0
764391	761715	99004R	PARTICIPANT	\N	PRESENT	0
764143	761130	19697Q	PARTICIPANT	\N	PRESENT	0
764105	761181	20044X	PARTICIPANT	\N	PRESENT	0
764144	761130	19699S	PARTICIPANT	\N	PRESENT	0
764390	761715	14179A	PARTICIPANT	\N	PRESENT	0
764392	761715	19649G	PARTICIPANT	\N	PRESENT	0
764393	761715	11045K	PARTICIPANT	\N	PRESENT	0
764446	761715	20148F	PARTICIPANT	\N	PRESENT	0
764395	761715	20110Q	PARTICIPANT	\N	PRESENT	0
764396	761715	04047H	PARTICIPANT	\N	PRESENT	0
764397	761715	14089Y	PARTICIPANT	\N	PRESENT	0
764398	761715	19447X	PARTICIPANT	\N	PRESENT	0
764399	761978	19569H	PARTICIPANT	\N	PRESENT	0
764400	761978	21049H	PARTICIPANT	\N	PRESENT	0
764117	761181	07029T	PARTICIPANT	\N	PRESENT	0
764145	761130	21058J	PARTICIPANT	\N	PRESENT	0
764401	761979	19569H	PARTICIPANT	\N	PRESENT	0
764402	761715	19691J	PARTICIPANT	\N	PRESENT	0
764403	761715	20040T	PARTICIPANT	\N	PRESENT	0
764404	761715	20248J	PARTICIPANT	\N	PRESENT	0
764405	761715	21053D	PARTICIPANT	\N	PRESENT	0
764406	761715	19749K	PARTICIPANT	\N	PRESENT	0
764407	761715	19111A	PARTICIPANT	\N	PRESENT	0
764408	761715	18207D	PARTICIPANT	\N	PRESENT	0
764409	761715	18231D	PARTICIPANT	\N	PRESENT	0
764410	761715	14281W	PARTICIPANT	\N	PRESENT	0
764411	761715	21060C	PARTICIPANT	\N	PRESENT	0
764412	761715	17965H	PARTICIPANT	\N	PRESENT	0
764203	761181	14083S	PARTICIPANT	\N	PRESENT	0
764413	761715	12028B	PARTICIPANT	\N	PRESENT	0
764134	761181	08011M	PARTICIPANT	\N	PRESENT	0
764414	761715	20264J	PARTICIPANT	\N	PRESENT	0
764136	761181	20024T	PARTICIPANT	\N	PRESENT	0
764415	761715	14151M	PARTICIPANT	\N	PRESENT	0
764416	761715	21040X	PARTICIPANT	\N	PRESENT	0
764417	761715	14207L	PARTICIPANT	\N	PRESENT	0
764140	761181	20050V	PARTICIPANT	\N	EXCUSE	0
764418	761715	19629C	PARTICIPANT	\N	PRESENT	0
764419	761715	19553Y	PARTICIPANT	\N	PRESENT	0
764146	761130	21059K	PARTICIPANT	\N	PRESENT	0
764147	761130	20102Q	PARTICIPANT	\N	PRESENT	0
764148	761130	19954N	PARTICIPANT	\N	PRESENT	0
764149	761130	18395Y	PARTICIPANT	\N	PRESENT	0
764150	761130	21089R	PARTICIPANT	\N	PRESENT	0
764151	761130	21091K	PARTICIPANT	\N	PRESENT	0
764152	761130	20124W	PARTICIPANT	\N	PRESENT	0
764153	761130	20026V	PARTICIPANT	\N	PRESENT	0
764154	761130	20132W	PARTICIPANT	\N	PRESENT	0
764155	761130	14073Q	PARTICIPANT	\N	PRESENT	0
764156	761130	20138D	PARTICIPANT	\N	PRESENT	0
764157	761130	19611R	PRESIDENT	0	PRESENT	0
764158	761130	20142Y	PARTICIPANT	\N	PRESENT	0
764159	761130	20048C	PARTICIPANT	\N	PRESENT	0
764160	761130	19693L	PARTICIPANT	\N	PRESENT	0
764161	761130	20052X	PARTICIPANT	\N	PRESENT	0
764162	761130	20058E	PARTICIPANT	\N	PRESENT	0
764163	761130	20056C	PARTICIPANT	\N	PRESENT	0
764164	761130	20180F	PARTICIPANT	\N	PRESENT	0
764165	761130	20264J	PARTICIPANT	\N	PRESENT	0
764166	761130	21063F	PARTICIPANT	\N	PRESENT	0
764167	761130	19735D	PARTICIPANT	\N	PRESENT	0
764168	761130	14123H	PARTICIPANT	\N	PRESENT	0
764169	761130	21077M	PARTICIPANT	\N	PRESENT	0
764170	761130	19621T	PARTICIPANT	\N	PRESENT	0
764420	761715	19569H	PARTICIPANT	\N	PRESENT	0
764172	761181	20080C	PARTICIPANT	\N	EXCUSE	0
764173	761181	19335Q	PARTICIPANT	\N	EXCUSE	0
764174	761181	11053K	PARTICIPANT	\N	PRESENT	0
764176	761181	14225N	PARTICIPANT	\N	PRESENT	0
764177	761181	20070A	PRESIDENT	0	PRESENT	0
764421	761715	21042A	PARTICIPANT	\N	PRESENT	0
764179	761181	11048N	PARTICIPANT	\N	PRESENT	0
764180	761181	21048G	PARTICIPANT	\N	PRESENT	0
764181	761181	20126Y	PARTICIPANT	\N	PRESENT	0
764422	761715	21043B	PARTICIPANT	\N	PRESENT	0
764423	761715	20060X	PARTICIPANT	\N	PRESENT	0
764185	761181	20150Y	PARTICIPANT	\N	PRESENT	0
764186	761181	08034U	PARTICIPANT	\N	PRESENT	0
764424	761715	21069M	PARTICIPANT	\N	PRESENT	0
764425	761715	14055N	PARTICIPANT	\N	PRESENT	0
764189	761181	19479G	PARTICIPANT	\N	PRESENT	0
764426	761715	19798U	PARTICIPANT	\N	PRESENT	0
764427	761715	14187A	PARTICIPANT	\N	PRESENT	0
764428	761715	20090E	PARTICIPANT	\N	PRESENT	0
764194	764193	14255U	PARTICIPANT	\N	PRESENT	0
764429	761715	20126Y	PARTICIPANT	\N	PRESENT	0
764196	761181	14121F	PARTICIPANT	\N	PRESENT	0
764430	761715	08015R	PARTICIPANT	\N	PRESENT	0
764431	761715	08034U	PARTICIPANT	\N	PRESENT	0
764432	761715	19399H	PARTICIPANT	\N	PRESENT	0
764433	761715	20026V	PARTICIPANT	\N	PRESENT	0
764434	761715	21058J	PARTICIPANT	\N	PRESENT	0
764435	761715	21068L	PARTICIPANT	\N	PRESENT	0
764436	761715	19673G	PARTICIPANT	\N	PRESENT	0
764437	761715	21044C	PARTICIPANT	\N	PRESENT	0
764438	761715	20076G	PARTICIPANT	\N	PRESENT	0
764439	761715	20044X	PARTICIPANT	\N	PRESENT	0
764440	761715	08018U	PARTICIPANT	\N	PRESENT	0
764441	761715	14223L	PARTICIPANT	\N	PRESENT	0
764442	761715	21080G	PARTICIPANT	\N	PRESENT	0
764443	761715	21054E	PARTICIPANT	\N	PRESENT	0
764444	761715	20142Y	PARTICIPANT	\N	PRESENT	0
764445	761715	21063F	PARTICIPANT	\N	PRESENT	0
764221	761181	19647E	PARTICIPANT	\N	PRESENT	0
764447	761715	20098N	PARTICIPANT	\N	PRESENT	0
764448	761715	21064G	PARTICIPANT	\N	PRESENT	0
764224	761181	20094J	PARTICIPANT	\N	PRESENT	0
764449	761715	04033B	PARTICIPANT	\N	PRESENT	0
764450	761715	21095P	PARTICIPANT	\N	PRESENT	0
764227	761181	19545Y	PARTICIPANT	\N	PRESENT	0
764451	761715	21091K	PARTICIPANT	\N	PRESENT	0
764229	761130	19593H	PARTICIPANT	\N	PRESENT	0
764452	761715	18083K	PARTICIPANT	\N	PRESENT	0
764453	761715	08028W	PARTICIPANT	\N	PRESENT	0
764454	761715	21081H	PARTICIPANT	\N	PRESENT	0
764455	761715	19954N	PARTICIPANT	\N	PRESENT	0
764456	761715	07029T	PARTICIPANT	\N	PRESENT	0
764457	761715	14033T	PARTICIPANT	\N	PRESENT	0
764458	761715	14259Y	PARTICIPANT	\N	PRESENT	0
764459	761715	20104S	PARTICIPANT	\N	PRESENT	0
764460	761715	21093M	PARTICIPANT	\N	PRESENT	0
764461	761715	19489J	PARTICIPANT	\N	PRESENT	0
764462	761715	21075K	PARTICIPANT	\N	PRESENT	0
764463	761715	19565D	PARTICIPANT	\N	PRESENT	0
764464	761715	21088Q	PARTICIPANT	\N	PRESENT	0
764465	761715	19782L	PARTICIPANT	\N	PRESENT	0
764466	761715	05008E	PARTICIPANT	\N	PRESENT	0
764467	761715	20094J	PARTICIPANT	\N	PRESENT	0
764468	761715	21089R	PARTICIPANT	\N	PRESENT	0
764469	761715	14257W	PARTICIPANT	\N	PRESENT	0
764470	761715	19647E	PARTICIPANT	\N	PRESENT	0
764471	761715	11027H	PARTICIPANT	\N	PRESENT	0
764472	761715	14021P	PARTICIPANT	\N	PRESENT	0
764473	761715	20018V	PARTICIPANT	\N	PRESENT	0
764474	761715	20082E	PARTICIPANT	\N	PRESENT	0
764475	761715	21062E	PARTICIPANT	\N	PRESENT	0
764476	761715	19723Y	PARTICIPANT	\N	PRESENT	0
764259	761181	14189C	PARTICIPANT	\N	EXCUSE	0
764477	761715	20266L	PARTICIPANT	\N	PRESENT	0
764478	761715	20028X	PARTICIPANT	\N	PRESENT	0
764479	761715	20046A	PARTICIPANT	\N	PRESENT	0
764480	761715	20088L	PARTICIPANT	\N	PRESENT	0
764481	761715	21082J	PARTICIPANT	\N	PRESENT	0
764482	761715	14217N	PARTICIPANT	\N	PRESENT	0
764483	761715	14213J	PARTICIPANT	\N	PRESENT	0
764484	761715	14147R	PARTICIPANT	\N	PRESENT	0
764485	761715	11090Q	PARTICIPANT	\N	PRESENT	0
764486	761715	20062A	PARTICIPANT	\N	PRESENT	0
764487	761715	18395Y	PARTICIPANT	\N	PRESENT	0
764488	761715	21056G	PARTICIPANT	\N	PRESENT	0
764489	761715	20070A	PARTICIPANT	\N	PRESENT	0
764490	761715	20180F	PARTICIPANT	\N	PRESENT	0
764491	761715	21092L	PARTICIPANT	\N	PRESENT	0
740875	740874	14038Y	PARTICIPANT	\N	PRESENT	0
740876	740874	20094J	PARTICIPANT	\N	PRESENT	0
740877	740874	20034V	PARTICIPANT	\N	PRESENT	0
740879	740878	14038Y	PARTICIPANT	\N	PRESENT	0
740880	740878	20094J	PARTICIPANT	\N	PRESENT	0
740881	740878	20034V	PARTICIPANT	\N	PRESENT	0
740883	740882	14038Y	PARTICIPANT	\N	PRESENT	0
740884	740882	20094J	PARTICIPANT	\N	PRESENT	0
740885	740882	20034V	PARTICIPANT	\N	PRESENT	0
740887	740873	14038Y	PARTICIPANT	\N	PRESENT	0
740888	740873	20094J	PARTICIPANT	\N	PRESENT	0
740889	740873	20034V	PARTICIPANT	\N	PRESENT	0
740900	740899	14038Y	PARTICIPANT	\N	PRESENT	0
740901	740899	20094J	PARTICIPANT	\N	PRESENT	0
740902	740899	20034V	PARTICIPANT	\N	PRESENT	0
740904	740903	14038Y	PARTICIPANT	\N	PRESENT	0
740905	740903	20094J	PARTICIPANT	\N	PRESENT	0
740907	740906	14038Y	PARTICIPANT	\N	PRESENT	0
740908	740906	20094J	PARTICIPANT	\N	PRESENT	0
740909	740906	19591F	PARTICIPANT	\N	PRESENT	0
740911	740910	14038Y	PARTICIPANT	\N	PRESENT	0
740913	740910	20094J	PARTICIPANT	\N	PRESENT	0
740914	740910	20034V	PARTICIPANT	\N	PRESENT	0
740915	740910	04070G	PARTICIPANT	\N	PRESENT	0
745792	743066	20124W	PARTICIPANT	\N	PRESENT	0
745793	743066	19711U	PARTICIPANT	\N	PRESENT	0
745807	743066	20026V	PARTICIPANT	\N	PRESENT	0
745828	743066	20104S	PARTICIPANT	\N	PRESENT	0
745852	743066	20084G	PARTICIPANT	\N	PRESENT	0
747538	747532	14237S	PARTICIPANT	\N	PRESENT	0
747540	747532	19745F	PARTICIPANT	\N	PRESENT	0
747541	747532	05012A	PRESIDENT	0	PRESENT	0
747543	747532	19820Y	PARTICIPANT	\N	PRESENT	0
747548	747532	14169X	PARTICIPANT	\N	PRESENT	0
749913	749912	20120S	PARTICIPANT	\N	PRESENT	0
749914	749912	20128B	PARTICIPANT	\N	PRESENT	0
749915	749912	08010L	PARTICIPANT	\N	PRESENT	0
749916	749912	20052X	PARTICIPANT	\N	PRESENT	0
749917	749912	20252E	PARTICIPANT	\N	PRESENT	0
749918	749912	19643A	PARTICIPANT	\N	PRESENT	0
749919	749912	19735D	PARTICIPANT	\N	PRESENT	0
749920	749912	11083R	PARTICIPANT	\N	PRESENT	0
749936	748105	20090E	PARTICIPANT	\N	PRESENT	0
749937	748105	18193Q	PARTICIPANT	\N	PRESENT	0
749938	748105	11067R	PARTICIPANT	\N	PRESENT	0
749939	748105	19798U	PARTICIPANT	\N	PRESENT	0
749940	748105	14217N	PARTICIPANT	\N	PRESENT	0
749941	748105	10006L	PRESIDENT	0	PRESENT	0
749942	748105	14213J	PARTICIPANT	\N	PRESENT	0
749943	748105	19683J	PARTICIPANT	\N	PRESENT	0
749944	748105	17965H	PARTICIPANT	\N	PRESENT	0
749945	748105	20130U	PARTICIPANT	\N	PRESENT	0
749946	748105	11031D	PARTICIPANT	\N	PRESENT	0
749947	748105	14026U	PARTICIPANT	\N	PRESENT	0
749948	748105	04092N	PARTICIPANT	\N	PRESENT	0
749949	748105	14281W	PARTICIPANT	\N	PRESENT	0
749950	748105	19713W	PARTICIPANT	\N	PRESENT	0
749951	748105	11045K	PARTICIPANT	\N	PRESENT	0
749952	748105	20248J	PARTICIPANT	\N	PRESENT	0
751763	751762	19575F	PARTICIPANT	\N	PRESENT	0
751765	751764	19575F	PARTICIPANT	\N	PRESENT	0
751767	751766	19575F	PARTICIPANT	\N	PRESENT	0
751768	751766	05012A	PARTICIPANT	\N	PRESENT	0
751977	751976	10006L	PARTICIPANT	\N	PRESENT	0
751978	751976	18193Q	PARTICIPANT	\N	PRESENT	0
754145	753658	19629C	PARTICIPANT	\N	PRESENT	0
754146	753658	20030R	PARTICIPANT	\N	PRESENT	0
754144	753658	21068L	PARTICIPANT	\N	PRESENT	0
754147	753658	19719D	PARTICIPANT	\N	PRESENT	0
754148	753658	14217N	PARTICIPANT	\N	PRESENT	0
754149	753658	14215L	PARTICIPANT	\N	PRESENT	0
754150	753658	21062E	PARTICIPANT	\N	PRESENT	0
754151	753658	21063F	PARTICIPANT	\N	PRESENT	0
754153	753658	14109K	PARTICIPANT	\N	PRESENT	0
754154	753658	19649G	PARTICIPANT	\N	PRESENT	0
754155	753658	21037D	PARTICIPANT	\N	PRESENT	0
754156	753658	20132W	PARTICIPANT	\N	PRESENT	0
754157	753658	19673G	PARTICIPANT	\N	PRESENT	0
754158	753658	20100N	PARTICIPANT	\N	PRESENT	0
754159	753658	20052X	PARTICIPANT	\N	PRESENT	0
754160	753658	08034U	PARTICIPANT	\N	PRESENT	0
754161	753658	05012A	PARTICIPANT	\N	PRESENT	0
754162	753658	11027H	PARTICIPANT	\N	PRESENT	0
754163	753658	19735D	PARTICIPANT	\N	PRESENT	0
754164	753658	05008E	PARTICIPANT	\N	PRESENT	0
754165	753658	19413M	PARTICIPANT	\N	PRESENT	0
754166	753658	21065H	PARTICIPANT	\N	PRESENT	0
754167	753658	08047A	PARTICIPANT	\N	PRESENT	0
754168	753658	08061X	PARTICIPANT	\N	PRESENT	0
754169	753658	21031W	PARTICIPANT	\N	PRESENT	0
754170	753658	20114U	PARTICIPANT	\N	PRESENT	0
754171	753658	14071N	PARTICIPANT	\N	PRESENT	0
754172	753658	19679N	PARTICIPANT	\N	PRESENT	0
754173	753658	14267Y	PARTICIPANT	\N	PRESENT	0
754174	753658	20058E	PARTICIPANT	\N	PRESENT	0
754175	753658	14331P	PARTICIPANT	\N	PRESENT	0
754295	753660	14259Y	PARTICIPANT	\N	PRESENT	0
754296	753660	14215L	PARTICIPANT	\N	PRESENT	0
754297	753660	20046A	PARTICIPANT	\N	PRESENT	0
754298	753660	20114U	PARTICIPANT	\N	PRESENT	0
754299	753660	21051B	PARTICIPANT	\N	PRESENT	0
754300	753660	21031W	PARTICIPANT	\N	PRESENT	0
754301	753660	18395Y	PARTICIPANT	\N	PRESENT	0
754302	753660	20110Q	PARTICIPANT	\N	PRESENT	0
754303	753660	20134Y	PARTICIPANT	\N	PRESENT	0
754304	753660	14037X	PARTICIPANT	\N	PRESENT	0
754305	753660	18207D	PARTICIPANT	\N	PRESENT	0
754306	753660	11056N	PARTICIPANT	\N	PRESENT	0
754307	753660	21043B	PARTICIPANT	\N	PRESENT	0
754308	753660	19693L	PARTICIPANT	\N	PRESENT	0
754309	753660	21065H	PARTICIPANT	\N	PRESENT	0
754310	753660	21070E	PARTICIPANT	\N	PRESENT	0
754311	753660	21054E	PARTICIPANT	\N	PRESENT	0
754312	753660	04045F	PARTICIPANT	\N	PRESENT	0
754313	753660	21062E	PARTICIPANT	\N	PRESENT	0
754314	753660	21085M	PARTICIPANT	\N	PRESENT	0
754315	753660	21038E	PARTICIPANT	\N	PRESENT	0
754316	753660	19387D	PARTICIPANT	\N	PRESENT	0
754317	753660	14231L	PARTICIPANT	\N	PRESENT	0
754318	753660	19111A	PARTICIPANT	\N	PRESENT	0
754319	753660	20124W	PARTICIPANT	\N	PRESENT	0
754320	753660	20098N	PARTICIPANT	\N	PRESENT	0
754321	753660	19383Y	PARTICIPANT	\N	PRESENT	0
754322	753660	14329V	PARTICIPANT	\N	PRESENT	0
754323	753660	20022R	PARTICIPANT	\N	PRESENT	0
754324	753660	21072G	PARTICIPANT	\N	PRESENT	0
754325	753660	14237S	PARTICIPANT	\N	PRESENT	0
754326	753660	19679N	PARTICIPANT	\N	PRESENT	0
754327	753660	20090E	PARTICIPANT	\N	PRESENT	0
754328	753660	14069U	PARTICIPANT	\N	PRESENT	0
754329	753660	19447X	PARTICIPANT	\N	PRESENT	0
754330	753660	11090Q	PARTICIPANT	\N	PRESENT	0
754331	753660	21078N	PARTICIPANT	\N	PRESENT	0
754332	753660	19649G	PARTICIPANT	\N	PRESENT	0
754333	753660	19673G	PARTICIPANT	\N	PRESENT	0
754334	753660	21057H	PARTICIPANT	\N	PRESENT	0
754335	753660	21067K	PARTICIPANT	\N	PRESENT	0
754336	753660	19798U	PARTICIPANT	\N	PRESENT	0
754337	753660	14053L	PARTICIPANT	\N	PRESENT	0
754338	753660	04047H	PARTICIPANT	\N	PRESENT	0
754339	753660	20106U	PARTICIPANT	\N	PRESENT	0
754340	753660	21058J	PARTICIPANT	\N	PRESENT	0
754341	753660	14195A	PARTICIPANT	\N	PRESENT	0
754342	753660	21087P	PARTICIPANT	\N	PRESENT	0
754343	753660	19629C	PARTICIPANT	\N	PRESENT	0
754344	753660	14147R	PARTICIPANT	\N	PRESENT	0
754345	753660	14055N	PARTICIPANT	\N	PRESENT	0
754346	753660	20032T	PARTICIPANT	\N	PRESENT	0
754347	753660	11027H	PARTICIPANT	\N	PRESENT	0
754348	753660	21044C	PARTICIPANT	\N	PRESENT	0
754349	753660	21049H	PARTICIPANT	\N	PRESENT	0
754350	753660	21086N	PARTICIPANT	\N	PRESENT	0
754351	753660	14151M	PARTICIPANT	\N	PRESENT	0
754352	753660	20116W	PARTICIPANT	\N	PRESENT	0
754353	753660	14107H	PARTICIPANT	\N	PRESENT	0
754354	753660	21040X	PARTICIPANT	\N	PRESENT	0
754355	753660	05008E	PARTICIPANT	\N	PRESENT	0
754356	753660	21090J	PARTICIPANT	\N	PRESENT	0
754357	753660	19489J	PARTICIPANT	\N	PRESENT	0
754358	753660	21033Y	PARTICIPANT	\N	PRESENT	0
754359	753660	21053D	PARTICIPANT	\N	PRESENT	0
757307	755861	21049H	PARTICIPANT	\N	PRESENT	0
757308	755861	21091K	PARTICIPANT	\N	PRESENT	0
757309	755861	20076G	PARTICIPANT	\N	PRESENT	0
757310	755861	20074E	PARTICIPANT	\N	PRESENT	0
757311	755861	19758L	PARTICIPANT	\N	PRESENT	0
757312	755861	20078J	PARTICIPANT	\N	PRESENT	0
757313	755861	20046A	PARTICIPANT	\N	PRESENT	0
757314	755861	14259Y	PARTICIPANT	\N	PRESENT	0
757315	755861	19687N	PARTICIPANT	\N	PRESENT	0
757316	755861	19681G	PARTICIPANT	\N	PRESENT	0
757317	755861	04042C	PARTICIPANT	\N	PRESENT	0
757318	755861	14223L	PARTICIPANT	\N	PRESENT	0
757319	755861	19695N	PARTICIPANT	\N	PRESENT	0
757320	755861	21088Q	PARTICIPANT	\N	PRESENT	0
757321	755861	10015M	PARTICIPANT	\N	PRESENT	0
757322	755861	19573D	PARTICIPANT	\N	PRESENT	0
757323	755861	21044C	PARTICIPANT	\N	PRESENT	0
757324	755861	14169X	PARTICIPANT	\N	PRESENT	0
757325	755861	08011M	PARTICIPANT	\N	PRESENT	0
757326	755861	20110Q	PARTICIPANT	\N	PRESENT	0
757440	755861	21071F	PARTICIPANT	\N	PRESENT	0
757328	755861	11065P	PARTICIPANT	\N	PRESENT	0
757329	755861	11043H	PARTICIPANT	\N	PRESENT	0
757330	755861	20134Y	PARTICIPANT	\N	PRESENT	0
757331	755861	20100N	PARTICIPANT	\N	PRESENT	0
757332	755861	14237S	PARTICIPANT	\N	PRESENT	0
757333	755861	19347U	PARTICIPANT	\N	PRESENT	0
757334	755861	14193X	PARTICIPANT	\N	PRESENT	0
757335	755861	20044X	PARTICIPANT	\N	PRESENT	0
757336	755861	21093M	PARTICIPANT	\N	PRESENT	0
757337	755861	21073H	PARTICIPANT	\N	PRESENT	0
757338	755861	21037D	PARTICIPANT	\N	PRESENT	0
757339	755861	20092G	PARTICIPANT	\N	PRESENT	0
757340	755861	21080G	PARTICIPANT	\N	PRESENT	0
757341	755861	21079P	PARTICIPANT	\N	PRESENT	0
757342	755861	11090Q	PARTICIPANT	\N	PRESENT	0
757343	755861	05012A	PARTICIPANT	\N	PRESENT	0
757344	755861	20022R	PARTICIPANT	\N	PRESENT	0
757345	755861	20266L	PARTICIPANT	\N	PRESENT	0
757346	755861	14215L	PARTICIPANT	\N	PRESENT	0
757347	755861	19673G	PARTICIPANT	\N	PRESENT	0
757348	755861	14031R	PARTICIPANT	\N	PRESENT	0
757349	755861	21043B	PARTICIPANT	\N	PRESENT	0
757350	755861	19782L	PARTICIPANT	\N	PRESENT	0
757351	755861	20136B	PARTICIPANT	\N	PRESENT	0
757352	755861	14253S	PARTICIPANT	\N	PRESENT	0
757353	755861	19421M	PARTICIPANT	\N	PRESENT	0
757354	755861	19349W	PARTICIPANT	\N	PRESENT	0
757355	755861	19667J	PARTICIPANT	\N	PRESENT	0
757356	755861	14249W	PARTICIPANT	\N	PRESENT	0
757357	755861	14123H	PARTICIPANT	\N	PRESENT	0
757358	755861	20032T	PARTICIPANT	\N	PRESENT	0
757359	755861	20130U	PARTICIPANT	\N	PRESENT	0
757360	755861	14147R	PARTICIPANT	\N	PRESENT	0
757361	755861	20172F	PARTICIPANT	\N	PRESENT	0
757362	755861	08047A	PARTICIPANT	\N	PRESENT	0
757363	755861	21081H	PARTICIPANT	\N	PRESENT	0
757364	755861	19954N	PARTICIPANT	\N	PRESENT	0
757365	755861	20026V	PARTICIPANT	\N	PRESENT	0
757366	755861	20180F	PARTICIPANT	\N	PRESENT	0
757367	755861	21058J	PARTICIPANT	\N	PRESENT	0
757368	755861	21068L	PARTICIPANT	\N	PRESENT	0
757369	755861	20106U	PARTICIPANT	\N	PRESENT	0
757370	755861	19447X	PARTICIPANT	\N	PRESENT	0
757371	755861	21072G	PARTICIPANT	\N	PRESENT	0
757372	755861	20128B	PARTICIPANT	\N	PRESENT	0
757373	755861	19591F	PARTICIPANT	\N	PRESENT	0
757374	755861	14038Y	PARTICIPANT	\N	PRESENT	0
757375	755861	19723Y	PARTICIPANT	\N	PRESENT	0
757376	755861	14037X	PARTICIPANT	\N	PRESENT	0
757377	755861	20034V	PARTICIPANT	\N	PRESENT	0
757378	755861	19697Q	PARTICIPANT	\N	PRESENT	0
757379	755861	11072N	PARTICIPANT	\N	PRESENT	0
757380	755861	19331L	PARTICIPANT	\N	PRESENT	0
757381	755861	08073C	PARTICIPANT	\N	PRESENT	0
757382	755861	08061X	PARTICIPANT	\N	PRESENT	0
757383	755861	20140W	PARTICIPANT	\N	PRESENT	0
757384	755861	19301E	PARTICIPANT	\N	PRESENT	0
757385	755861	19709B	PARTICIPANT	\N	PRESENT	0
757386	755861	20038A	PARTICIPANT	\N	PRESENT	0
757387	755861	21074J	PARTICIPANT	\N	PRESENT	0
757388	755861	08018U	PARTICIPANT	\N	PRESENT	0
757389	755861	21085M	PARTICIPANT	\N	PRESENT	0
757390	755861	14055N	PARTICIPANT	\N	PRESENT	0
757391	755861	20068G	PARTICIPANT	\N	PRESENT	0
757392	755861	21069M	PARTICIPANT	\N	PRESENT	0
757393	755861	21063F	PARTICIPANT	\N	PRESENT	0
757394	755861	20116W	PARTICIPANT	\N	PRESENT	0
757395	755861	07029T	PARTICIPANT	\N	PRESENT	0
757396	755861	19657G	PARTICIPANT	\N	PRESENT	0
757397	755861	14207L	PARTICIPANT	\N	PRESENT	0
757398	755861	19729F	PARTICIPANT	\N	PRESENT	0
757399	755861	08015R	PARTICIPANT	\N	PRESENT	0
757400	755861	21041Y	PARTICIPANT	\N	PRESENT	0
757401	755861	19768N	PARTICIPANT	\N	PRESENT	0
757402	755861	19719D	PARTICIPANT	\N	PRESENT	0
757403	755861	20132W	PARTICIPANT	\N	PRESENT	0
757404	755861	20024T	PARTICIPANT	\N	PRESENT	0
757405	755861	14213J	PARTICIPANT	\N	PRESENT	0
757406	755861	20108W	PARTICIPANT	\N	PRESENT	0
757407	755861	19553Y	PARTICIPANT	\N	PRESENT	0
757408	755861	20072C	PARTICIPANT	\N	PRESENT	0
757409	755861	19866P	PARTICIPANT	\N	PRESENT	0
757410	755861	20148F	PARTICIPANT	\N	PRESENT	0
757411	755861	14107H	PARTICIPANT	\N	PRESENT	0
757412	755861	20104S	PARTICIPANT	\N	PRESENT	0
757413	755861	19399H	PARTICIPANT	\N	PRESENT	0
757414	755861	21084L	PARTICIPANT	\N	PRESENT	0
757415	755861	20056C	PARTICIPANT	\N	PRESENT	0
757416	755861	19387D	PARTICIPANT	\N	PRESENT	0
757417	755861	21066J	PARTICIPANT	\N	PRESENT	0
757418	755861	21040X	PARTICIPANT	\N	PRESENT	0
757419	755861	21078N	PARTICIPANT	\N	PRESENT	0
757420	755861	19703U	PARTICIPANT	\N	PRESENT	0
757421	755861	19545Y	PARTICIPANT	\N	PRESENT	0
757422	755861	14195A	PARTICIPANT	\N	PRESENT	0
757423	755861	14026U	PARTICIPANT	\N	PRESENT	0
757424	755861	19693L	PARTICIPANT	\N	PRESENT	0
757425	755861	11064N	PARTICIPANT	\N	PRESENT	0
757426	755861	08010L	PARTICIPANT	\N	PRESENT	0
757427	755861	04047H	PARTICIPANT	\N	PRESENT	0
757428	755861	14111D	PARTICIPANT	\N	PRESENT	0
757429	755861	04092N	PARTICIPANT	\N	PRESENT	0
757430	755861	20050V	PARTICIPANT	\N	PRESENT	0
757431	755861	21076L	PARTICIPANT	\N	PRESENT	0
757432	755861	08034U	PARTICIPANT	\N	PRESENT	0
757433	755861	14133K	PARTICIPANT	\N	PRESENT	0
757434	755861	11048N	PARTICIPANT	\N	PRESENT	0
757435	755861	08069G	PARTICIPANT	\N	PRESENT	0
757436	755861	21035B	PARTICIPANT	\N	PRESENT	0
757438	755861	20114U	PARTICIPANT	\N	PRESENT	0
757439	755861	21089R	PARTICIPANT	\N	PRESENT	0
757441	755861	21045D	PARTICIPANT	\N	PRESENT	0
757442	755861	04033B	PARTICIPANT	\N	PRESENT	0
757443	755861	20060X	PARTICIPANT	\N	PRESENT	0
757444	755861	20062A	PARTICIPANT	\N	PRESENT	0
757445	755861	20070A	PARTICIPANT	\N	PRESENT	0
757446	755861	20264J	PARTICIPANT	\N	PRESENT	0
757447	755861	19679N	PARTICIPANT	\N	PRESENT	0
757448	755861	21067K	PARTICIPANT	\N	PRESENT	0
757449	755861	14173T	PARTICIPANT	\N	PRESENT	0
757450	755861	19251M	PARTICIPANT	\N	PRESENT	0
757451	755861	14151M	PARTICIPANT	\N	PRESENT	0
757452	755861	18395Y	PARTICIPANT	\N	PRESENT	0
757453	755861	14071N	PARTICIPANT	\N	PRESENT	0
757454	755861	14187A	PARTICIPANT	\N	PRESENT	0
757455	755861	11074Q	PARTICIPANT	\N	PRESENT	0
757456	755861	14053L	PARTICIPANT	\N	PRESENT	0
757457	755861	19631V	PARTICIPANT	\N	PRESENT	0
757458	755861	21062E	PARTICIPANT	\N	PRESENT	0
757459	755861	19647E	PARTICIPANT	\N	PRESENT	0
757460	755861	19798U	PARTICIPANT	\N	PRESENT	0
757461	755861	14281W	PARTICIPANT	\N	PRESENT	0
757462	755861	19533U	PARTICIPANT	\N	PRESENT	0
757463	755861	19820Y	PARTICIPANT	\N	PRESENT	0
757464	755861	21095P	PARTICIPANT	\N	PRESENT	0
757465	755861	07033P	PARTICIPANT	\N	PRESENT	0
757466	755861	19551W	PARTICIPANT	\N	PRESENT	0
757467	755861	17367Q	PARTICIPANT	\N	PRESENT	0
757468	755861	14217N	PARTICIPANT	\N	PRESENT	0
757469	755861	14357A	PARTICIPANT	\N	PRESENT	0
740405	740404	04059M	PARTICIPANT	\N	PRESENT	0
740406	740404	04042C	PARTICIPANT	\N	PRESENT	0
740407	740404	14187A	PARTICIPANT	\N	PRESENT	0
740408	740404	14281W	PARTICIPANT	\N	PRESENT	0
740414	740413	17737W	PARTICIPANT	\N	PRESENT	0
742359	740835	14327T	PARTICIPANT	\N	PRESENT	0
740416	740413	19713W	PARTICIPANT	\N	PRESENT	0
740418	740413	14069U	PARTICIPANT	\N	PRESENT	0
740419	740413	19643A	PARTICIPANT	\N	PRESENT	0
742340	740754	14053L	PARTICIPANT	\N	PRESENT	0
742341	740754	14111D	PARTICIPANT	\N	PRESENT	0
742342	740754	20074E	PARTICIPANT	\N	PRESENT	0
742343	740754	19301E	PARTICIPANT	\N	PRESENT	0
742344	740754	19543W	PARTICIPANT	\N	PRESENT	0
742345	740754	04047H	PRESIDENT	0	PRESENT	0
742346	740754	19673G	PARTICIPANT	\N	PRESENT	0
742347	740754	19447X	PARTICIPANT	\N	PRESENT	0
742348	740754	19725B	PARTICIPANT	\N	PRESENT	0
742349	740754	19729F	PARTICIPANT	\N	PRESENT	0
742350	740754	07004J	PARTICIPANT	\N	PRESENT	0
742351	740754	20108W	PARTICIPANT	\N	PRESENT	0
742352	740754	20110Q	PARTICIPANT	\N	PRESENT	0
742353	740754	14147R	PARTICIPANT	\N	PRESENT	0
742354	740754	14069U	PARTICIPANT	\N	PRESENT	0
742355	740754	14215L	PARTICIPANT	\N	PRESENT	0
742356	740754	20022R	PARTICIPANT	\N	PRESENT	0
742357	740754	04008A	PARTICIPANT	\N	PRESENT	0
742358	740754	14259Y	PARTICIPANT	\N	PRESENT	0
742360	740835	14331P	PARTICIPANT	\N	PRESENT	0
742361	740835	04071H	PARTICIPANT	\N	PRESENT	0
742362	740835	01048V	PARTICIPANT	\N	PRESENT	0
742363	740835	19545Y	PARTICIPANT	\N	PRESENT	0
742364	740835	11053K	PARTICIPANT	\N	PRESENT	0
742365	740835	20080C	PARTICIPANT	\N	PRESENT	0
742366	740835	11074Q	PARTICIPANT	\N	PRESENT	0
742367	740835	14225N	PRESIDENT	0	PRESENT	0
742368	740835	19671E	PARTICIPANT	\N	PRESENT	0
742369	740835	11070L	PARTICIPANT	\N	PRESENT	0
742370	740835	07029T	PARTICIPANT	\N	PRESENT	0
742371	740835	19349W	PARTICIPANT	\N	PRESENT	0
742372	740835	08010L	PARTICIPANT	\N	PRESENT	0
742373	740835	14253S	PARTICIPANT	\N	PRESENT	0
742374	740835	20116W	PARTICIPANT	\N	PRESENT	0
742375	740835	19335Q	PARTICIPANT	\N	PRESENT	0
742376	740835	20126Y	PARTICIPANT	\N	PRESENT	0
742377	740835	11048N	PARTICIPANT	\N	PRESENT	0
742378	740835	19479G	PARTICIPANT	\N	PRESENT	0
742379	740835	20036X	PARTICIPANT	\N	PRESENT	0
742380	740835	14189C	PARTICIPANT	\N	PRESENT	0
742381	740835	19531S	PARTICIPANT	\N	PRESENT	0
742382	740835	19687N	PARTICIPANT	\N	PRESENT	0
742383	740835	12016W	PARTICIPANT	\N	PRESENT	0
742384	740835	20050V	PARTICIPANT	\N	PRESENT	0
742385	740835	20044X	PARTICIPANT	\N	PRESENT	0
742386	740835	20150Y	PARTICIPANT	\N	PRESENT	0
742387	740835	14173T	PARTICIPANT	\N	PRESENT	0
742388	740835	11040E	PARTICIPANT	\N	PRESENT	0
742389	740835	14083S	PARTICIPANT	\N	PRESENT	0
742390	740835	11012A	PARTICIPANT	\N	PRESENT	0
742391	740835	08073C	PARTICIPANT	\N	PRESENT	0
742392	740835	20252E	PARTICIPANT	\N	PRESENT	0
742393	740835	08009T	PARTICIPANT	\N	PRESENT	0
742394	740835	20070A	PARTICIPANT	\N	PRESENT	0
742395	740835	19741B	PARTICIPANT	\N	PRESENT	0
742396	740835	99004R	PARTICIPANT	\N	PRESENT	0
742397	740835	20914V	PARTICIPANT	\N	PRESENT	0
742398	740835	19762G	PARTICIPANT	\N	PRESENT	0
742399	740754	14151M	PARTICIPANT	\N	PRESENT	0
742400	740754	11072N	PARTICIPANT	\N	PRESENT	0
742401	740754	10015M	PARTICIPANT	\N	PRESENT	0
742402	740754	11033F	PARTICIPANT	\N	PRESENT	0
742403	740754	04085P	PARTICIPANT	\N	PRESENT	0
742404	740754	95063L	PARTICIPANT	\N	PRESENT	0
742405	740835	19647E	PARTICIPANT	\N	PRESENT	0
742406	740835	08011M	PARTICIPANT	\N	PRESENT	0
742407	740754	17737W	PARTICIPANT	\N	PRESENT	0
742408	740754	19489J	PARTICIPANT	\N	PRESENT	0
742409	740754	11085T	PARTICIPANT	\N	PRESENT	0
742410	740754	14021P	PARTICIPANT	\N	PRESENT	0
742411	740754	11056N	PARTICIPANT	\N	PRESENT	0
742412	740835	19711U	PARTICIPANT	\N	PRESENT	0
742413	740754	14231L	PARTICIPANT	\N	PRESENT	0
742434	740835	20086J	PARTICIPANT	\N	PRESENT	0
742529	741108	20088L	PARTICIPANT	\N	PRESENT	0
742530	741108	19768N	PARTICIPANT	\N	PRESENT	0
742531	741108	19515S	PARTICIPANT	\N	PRESENT	0
742532	741108	19782L	PARTICIPANT	\N	PRESENT	0
742533	741108	20092G	PARTICIPANT	\N	PRESENT	0
742534	741108	11077T	PARTICIPANT	\N	PRESENT	0
742535	741108	01043Q	PARTICIPANT	\N	PRESENT	0
742536	741108	14357A	PARTICIPANT	\N	PRESENT	0
742537	741108	20078J	PARTICIPANT	\N	PRESENT	0
742538	741108	19441R	PARTICIPANT	\N	PRESENT	0
742539	741108	19413M	PARTICIPANT	\N	PRESENT	0
742540	741108	20082E	PARTICIPANT	\N	PRESENT	0
742541	741108	20094J	PARTICIPANT	\N	PRESENT	0
742542	741108	04045F	PARTICIPANT	\N	PRESENT	0
742543	741108	19866P	PARTICIPANT	\N	PRESENT	0
742544	741108	19631V	PARTICIPANT	\N	PRESENT	0
742545	741108	20104S	PARTICIPANT	\N	PRESENT	0
742546	741108	11099A	PARTICIPANT	\N	PRESENT	0
742547	741108	19705W	PARTICIPANT	\N	PRESENT	0
742548	741108	19707Y	PARTICIPANT	\N	PRESENT	0
742549	741108	08015R	PARTICIPANT	\N	PRESENT	0
742550	741108	19575F	PARTICIPANT	\N	PRESENT	0
742551	741108	19369B	PARTICIPANT	\N	PRESENT	0
742552	741108	08028W	PARTICIPANT	\N	PRESENT	0
742553	741108	19563B	PARTICIPANT	\N	PRESENT	0
742554	741108	14329V	PARTICIPANT	\N	PRESENT	0
742555	741108	20028X	PARTICIPANT	\N	PRESENT	0
742556	741108	20120S	PARTICIPANT	\N	PRESENT	0
742557	741108	20030R	PARTICIPANT	\N	PRESENT	0
742558	741108	19467C	PARTICIPANT	\N	PRESENT	0
742559	741108	20034V	PARTICIPANT	\N	PRESENT	0
742560	741108	19711U	PARTICIPANT	\N	PRESENT	0
742561	741108	14187A	PARTICIPANT	\N	PRESENT	0
742562	741108	20144B	PARTICIPANT	\N	PRESENT	0
742563	741108	19695N	PARTICIPANT	\N	PRESENT	0
742564	741108	14033T	PARTICIPANT	\N	PRESENT	0
742565	741108	11090Q	PRESIDENT	0	PRESENT	0
742566	741108	01025N	PARTICIPANT	\N	PRESENT	0
742567	741108	14205J	PARTICIPANT	\N	PRESENT	0
742568	741108	20060X	PARTICIPANT	\N	PRESENT	0
742569	741108	20062A	PARTICIPANT	\N	PRESENT	0
742570	741108	14251Q	PARTICIPANT	\N	PRESENT	0
742571	741108	19507S	PARTICIPANT	\N	PRESENT	0
742572	741108	20286Q	PARTICIPANT	\N	PRESENT	0
742573	741108	20298U	PARTICIPANT	\N	PRESENT	0
742574	741108	19747H	PARTICIPANT	\N	PRESENT	0
742575	741108	14207L	PARTICIPANT	\N	PRESENT	0
742576	741108	14257W	PARTICIPANT	\N	PRESENT	0
742577	741108	19383Y	PARTICIPANT	\N	EXCUSE	0
742578	741108	20018V	PARTICIPANT	\N	EXCUSE	0
742579	742272	19721W	PARTICIPANT	\N	PRESENT	0
742580	742272	19319Q	PARTICIPANT	\N	PRESENT	0
742581	742272	08034U	PARTICIPANT	\N	PRESENT	0
742582	740162	11031D	PARTICIPANT	\N	EXCUSE	0
757977	757768	19681G	PARTICIPANT	\N	EXCUSE	0
757978	757768	19251M	PARTICIPANT	\N	EXCUSE	0
757979	757768	20106U	PARTICIPANT	\N	EXCUSE	0
757980	757768	21047F	PARTICIPANT	\N	EXCUSE	0
757989	757988	14215L	PARTICIPANT	\N	PRESENT	0
758100	757790	14069U	PARTICIPANT	\N	PRESENT	0
758101	757790	21072G	PARTICIPANT	\N	PRESENT	0
758103	757790	20068G	PARTICIPANT	\N	PRESENT	0
758104	757790	19691J	PARTICIPANT	\N	PRESENT	0
758105	757790	99004R	PARTICIPANT	\N	PRESENT	0
758106	757790	21075K	PARTICIPANT	\N	PRESENT	0
758107	757790	19826F	PARTICIPANT	\N	PRESENT	0
758108	757790	18231D	PARTICIPANT	\N	PRESENT	0
758109	757790	14229S	PARTICIPANT	\N	PRESENT	0
758110	757790	21070E	PARTICIPANT	\N	PRESENT	0
758111	757790	20020P	PARTICIPANT	\N	PRESENT	0
758112	757790	21095P	PARTICIPANT	\N	PRESENT	0
758728	758725	19723Y	PARTICIPANT	\N	PRESENT	0
758730	758725	19575F	PARTICIPANT	\N	PRESENT	0
758732	758725	14038Y	PARTICIPANT	\N	PRESENT	0
758734	758725	20072C	PARTICIPANT	\N	PRESENT	0
758735	758725	20128B	PARTICIPANT	\N	PRESENT	0
758737	758725	14205J	PARTICIPANT	\N	PRESENT	0
758738	758725	18231D	PARTICIPANT	\N	PRESENT	0
758739	758725	19593H	PARTICIPANT	\N	PRESENT	0
758740	758725	19533U	PARTICIPANT	\N	PRESENT	0
758741	758725	21059K	PARTICIPANT	\N	PRESENT	0
758742	758725	20092G	PARTICIPANT	\N	PRESENT	0
758743	758725	01058X	PARTICIPANT	\N	PRESENT	0
758744	758725	21082J	PARTICIPANT	\N	PRESENT	0
758745	758725	19667J	PARTICIPANT	\N	PRESENT	0
758746	758725	19735D	PARTICIPANT	\N	EXCUSE	0
764494	761715	20054A	PARTICIPANT	\N	PRESENT	0
764495	761715	21034A	PARTICIPANT	\N	PRESENT	0
764281	764182	21043B	PARTICIPANT	\N	PRESENT	0
764282	764182	11056N	PARTICIPANT	\N	PRESENT	0
764283	764182	21044C	PARTICIPANT	\N	PRESENT	0
764284	764182	19649G	PARTICIPANT	\N	PRESENT	0
764285	764182	18231D	PARTICIPANT	\N	PRESENT	0
764286	764182	20110Q	PARTICIPANT	\N	PRESENT	0
764287	764182	14147R	PARTICIPANT	\N	PRESENT	0
764288	764182	08018U	PARTICIPANT	\N	PRESENT	0
764289	764182	04047H	PRESIDENT	0	PRESENT	0
764290	764182	21095P	PARTICIPANT	\N	PRESENT	0
764291	764182	14053L	PARTICIPANT	\N	PRESENT	0
764292	764182	19673G	PARTICIPANT	\N	PRESENT	0
764293	764182	19447X	PARTICIPANT	\N	PRESENT	0
764294	764182	14089Y	PARTICIPANT	\N	PRESENT	0
764295	764182	21056G	PARTICIPANT	\N	PRESENT	0
764296	764182	05008E	PARTICIPANT	\N	PRESENT	0
764297	764182	19111A	PARTICIPANT	\N	PRESENT	0
764298	764182	14069U	PARTICIPANT	\N	PRESENT	0
764299	764182	19749K	PARTICIPANT	\N	PRESENT	0
764496	761715	19693L	PARTICIPANT	\N	PRESENT	0
764497	761715	20116W	PARTICIPANT	\N	PRESENT	0
764498	761715	21066J	PARTICIPANT	\N	PRESENT	0
764305	764182	20022R	PARTICIPANT	\N	EXCUSE	0
764499	761715	20084G	PARTICIPANT	\N	PRESENT	0
764307	764182	19719D	PARTICIPANT	\N	EXCUSE	0
764500	761715	19621T	PARTICIPANT	\N	PRESENT	0
764309	764182	14215L	PARTICIPANT	\N	EXCUSE	0
764310	764182	20074E	PARTICIPANT	\N	EXCUSE	0
764311	764182	20108W	PARTICIPANT	\N	EXCUSE	0
764312	764182	19729F	PARTICIPANT	\N	EXCUSE	0
764313	764182	11072N	PARTICIPANT	\N	EXCUSE	0
764314	764182	04045F	PARTICIPANT	\N	EXCUSE	0
764315	764182	21076L	PARTICIPANT	\N	EXCUSE	0
764501	761715	11048N	PARTICIPANT	\N	PRESENT	0
764502	761715	19347U	PARTICIPANT	\N	PRESENT	0
764503	761715	21072G	PARTICIPANT	\N	PRESENT	0
764504	761715	20128B	PARTICIPANT	\N	PRESENT	0
764505	761715	19709B	PARTICIPANT	\N	PRESENT	0
764506	761715	19826F	PARTICIPANT	\N	PRESENT	0
764507	761715	21038E	PARTICIPANT	\N	PRESENT	0
764508	761715	14053L	PARTICIPANT	\N	PRESENT	0
764509	761715	20134Y	PARTICIPANT	\N	PRESENT	0
764510	761715	20064C	PARTICIPANT	\N	PRESENT	0
764511	761715	21037D	PARTICIPANT	\N	PRESENT	0
764512	761715	21079P	PARTICIPANT	\N	PRESENT	0
764513	761715	21070E	PARTICIPANT	\N	PRESENT	0
764514	761715	14026U	PARTICIPANT	\N	PRESENT	0
764515	761715	21031W	PARTICIPANT	\N	PRESENT	0
764516	761715	17023S	PARTICIPANT	\N	PRESENT	0
764517	761715	14123H	PARTICIPANT	\N	PRESENT	0
764518	761715	17737W	PARTICIPANT	\N	PRESENT	0
764519	761715	14231L	PARTICIPANT	\N	PRESENT	0
764520	761715	19611R	PARTICIPANT	\N	PRESENT	0
764521	761715	19697Q	PARTICIPANT	\N	PRESENT	0
764522	761715	11056N	PARTICIPANT	\N	PRESENT	0
764523	761715	14059S	PARTICIPANT	\N	PRESENT	0
764524	761715	14267Y	PARTICIPANT	\N	PRESENT	0
764525	761715	19563B	PARTICIPANT	\N	PRESENT	0
764526	761715	20052X	PARTICIPANT	\N	PRESENT	0
764527	761715	14083S	PARTICIPANT	\N	PRESENT	0
764528	761715	14073Q	PARTICIPANT	\N	PRESENT	0
764529	761715	19479G	PARTICIPANT	\N	PRESENT	0
764530	761715	11065P	PARTICIPANT	\N	PRESENT	0
764531	761715	19575F	PARTICIPANT	\N	PRESENT	0
764532	761715	19820Y	PARTICIPANT	\N	PRESENT	0
764533	761715	20120S	PARTICIPANT	\N	PRESENT	0
764534	761715	17779H	PARTICIPANT	\N	PRESENT	0
764535	761715	08061X	PARTICIPANT	\N	PRESENT	0
764536	761715	21041Y	PARTICIPANT	\N	PRESENT	0
764537	761715	20032T	PARTICIPANT	\N	PRESENT	0
764538	761715	21051B	PARTICIPANT	\N	PRESENT	0
764539	761715	20106U	PARTICIPANT	\N	PRESENT	0
764540	761715	20022R	PARTICIPANT	\N	PRESENT	0
764541	761715	20100N	PARTICIPANT	\N	PRESENT	0
764542	761715	20252E	PARTICIPANT	\N	PRESENT	0
764543	761715	19531S	PARTICIPANT	\N	PRESENT	0
764544	761715	05012A	PARTICIPANT	\N	PRESENT	0
764545	761715	18193Q	PARTICIPANT	\N	PRESENT	0
764546	761715	14215L	PARTICIPANT	\N	PRESENT	0
764547	761715	08010L	PARTICIPANT	\N	PRESENT	0
764492	761715	21046E	PARTICIPANT	\N	PRESENT	0
764493	761715	14071N	PARTICIPANT	\N	PRESENT	0
764548	761715	20136B	PARTICIPANT	\N	PRESENT	0
764549	761715	21094N	PARTICIPANT	\N	PRESENT	0
764550	761715	20058E	PARTICIPANT	\N	PRESENT	0
764808	761746	14237S	PARTICIPANT	\N	PRESENT	0
764809	761746	14331P	PRESIDENT	0	PRESENT	0
764810	761746	19711U	PARTICIPANT	\N	PRESENT	0
764811	761746	20070A	PARTICIPANT	\N	PRESENT	0
764812	761746	20286Q	PARTICIPANT	\N	PRESENT	0
764813	761746	14255U	PARTICIPANT	\N	PRESENT	0
764815	764243	21032X	PARTICIPANT	\N	EXCUSE	0
764816	764243	11072N	PARTICIPANT	\N	EXCUSE	0
764817	764243	19301E	PARTICIPANT	\N	EXCUSE	0
764818	764243	20122U	PARTICIPANT	\N	EXCUSE	0
764821	761746	14073Q	PARTICIPANT	\N	PRESENT	0
764822	761746	20042V	PARTICIPANT	\N	PRESENT	0
764823	761746	14001X	PARTICIPANT	\N	PRESENT	0
764824	761746	20104S	PARTICIPANT	\N	PRESENT	0
764825	761746	20100N	PARTICIPANT	\N	PRESENT	0
764826	761746	20248J	PARTICIPANT	\N	PRESENT	0
764827	761746	18395Y	PARTICIPANT	\N	PRESENT	0
764828	761746	21037D	PARTICIPANT	\N	PRESENT	0
764829	761746	19683J	PARTICIPANT	\N	PRESENT	0
764830	761746	20024T	PARTICIPANT	\N	PRESENT	0
764831	761746	17737W	PARTICIPANT	\N	EXCUSE	0
764832	761746	19701S	PARTICIPANT	\N	EXCUSE	0
764836	764374	11048N	PARTICIPANT	\N	PRESENT	0
764838	764374	08034U	PARTICIPANT	\N	PRESENT	0
764842	764374	14225N	PRESIDENT	0	PRESENT	0
764844	764374	11040E	PARTICIPANT	\N	EXCUSE	0
764845	764374	19531S	PARTICIPANT	\N	PRESENT	0
764848	764374	12016W	PARTICIPANT	\N	PRESENT	0
743850	743849	05012A	PRESIDENT	0	PRESENT	0
743851	743849	20090E	PARTICIPANT	\N	PRESENT	0
743852	743849	04045F	PARTICIPANT	\N	PRESENT	0
743853	743849	19447X	PARTICIPANT	\N	PRESENT	0
743854	743849	10015M	PARTICIPANT	\N	PRESENT	0
743855	743849	14215L	PARTICIPANT	\N	PRESENT	0
743856	743849	14069U	PARTICIPANT	\N	PRESENT	0
743857	743849	20084G	PARTICIPANT	\N	PRESENT	0
743858	743849	19820Y	PARTICIPANT	\N	PRESENT	0
743859	743849	08010L	PARTICIPANT	\N	PRESENT	0
743860	743849	20062A	PARTICIPANT	\N	PRESENT	0
743861	743849	14217N	PARTICIPANT	\N	PRESENT	0
743862	743849	19711U	PARTICIPANT	\N	PRESENT	0
743863	743849	20110Q	PARTICIPANT	\N	PRESENT	0
743864	743849	20022R	PARTICIPANT	\N	EXCUSE	0
743865	743849	19782L	PARTICIPANT	\N	EXCUSE	0
743866	743849	19735D	PARTICIPANT	\N	EXCUSE	0
743867	743849	14327T	PARTICIPANT	\N	EXCUSE	0
743868	743849	14187A	PARTICIPANT	\N	EXCUSE	0
743869	743849	14231L	PARTICIPANT	\N	EXCUSE	0
743870	743849	19565D	PARTICIPANT	\N	EXCUSE	0
743871	743849	20058E	PARTICIPANT	\N	EXCUSE	0
743874	743873	05012A	PRESIDENT	0	PRESENT	0
743875	743873	19447X	PARTICIPANT	\N	PRESENT	0
743876	743873	04045F	PARTICIPANT	\N	PRESENT	0
743877	743873	20090E	PARTICIPANT	\N	PRESENT	0
743878	743873	10015M	PARTICIPANT	\N	PRESENT	0
743879	743873	14215L	PARTICIPANT	\N	PRESENT	0
743880	743873	14069U	PARTICIPANT	\N	PRESENT	0
743881	743873	20084G	PARTICIPANT	\N	PRESENT	0
743882	743873	19820Y	PARTICIPANT	\N	PRESENT	0
743883	743873	08010L	PARTICIPANT	\N	PRESENT	0
743884	743873	20062A	PARTICIPANT	\N	PRESENT	0
743885	743873	14217N	PARTICIPANT	\N	PRESENT	0
743886	743873	19711U	PARTICIPANT	\N	PRESENT	0
743887	743873	20110Q	PARTICIPANT	\N	PRESENT	0
743888	743873	20022R	PARTICIPANT	\N	EXCUSE	0
743889	743873	19782L	PARTICIPANT	\N	EXCUSE	0
743890	743873	19735D	PARTICIPANT	\N	EXCUSE	0
743891	743873	14327T	PARTICIPANT	\N	EXCUSE	0
743892	743873	14187A	PARTICIPANT	\N	EXCUSE	0
743893	743873	14231L	PARTICIPANT	\N	EXCUSE	0
743894	743873	19565D	PARTICIPANT	\N	EXCUSE	0
743895	743873	20058E	PARTICIPANT	\N	EXCUSE	0
748017	748016	19647E	PARTICIPANT	\N	PRESENT	0
754362	753660	21056G	PARTICIPANT	\N	PRESENT	0
754421	753661	04045F	PARTICIPANT	\N	PRESENT	0
754422	753661	20114U	PARTICIPANT	\N	PRESENT	0
754423	753661	19383Y	PARTICIPANT	\N	PRESENT	0
754424	753661	20022R	PARTICIPANT	\N	PRESENT	0
754425	753661	14055N	PARTICIPANT	\N	PRESENT	0
754426	753661	19693L	PARTICIPANT	\N	PRESENT	0
754427	753661	14329V	PARTICIPANT	\N	PRESENT	0
754428	753661	14237S	PARTICIPANT	\N	PRESENT	0
754429	753661	21051B	PARTICIPANT	\N	PRESENT	0
754430	753661	21056G	PARTICIPANT	\N	PRESENT	0
754431	753661	19631V	PARTICIPANT	\N	PRESENT	0
754432	753661	21062E	PARTICIPANT	\N	PRESENT	0
754433	753661	21082J	PARTICIPANT	\N	PRESENT	0
754434	753661	14151M	PARTICIPANT	\N	PRESENT	0
754435	753661	19489J	PARTICIPANT	\N	PRESENT	0
754436	753661	04047H	PARTICIPANT	\N	PRESENT	0
754437	753661	14215L	PARTICIPANT	\N	PRESENT	0
754438	753661	21087P	PARTICIPANT	\N	PRESENT	0
754439	753661	21097R	PARTICIPANT	\N	PRESENT	0
754440	753661	20106U	PARTICIPANT	\N	PRESENT	0
754441	753661	21042A	PARTICIPANT	\N	PRESENT	0
754442	753661	21053D	PARTICIPANT	\N	PRESENT	0
754443	753661	20098N	PARTICIPANT	\N	PRESENT	0
754444	753661	19798U	PARTICIPANT	\N	PRESENT	0
754445	753661	20090E	PARTICIPANT	\N	PRESENT	0
754446	753661	14033T	PARTICIPANT	\N	PRESENT	0
754447	753661	21044C	PARTICIPANT	\N	PRESENT	0
754448	753661	19447X	PARTICIPANT	\N	PRESENT	0
754449	753661	14231L	PARTICIPANT	\N	PRESENT	0
754450	753661	14069U	PARTICIPANT	\N	PRESENT	0
754451	753661	14053L	PARTICIPANT	\N	PRESENT	0
754452	753661	05008E	PARTICIPANT	\N	PRESENT	0
754453	753661	21058J	PARTICIPANT	\N	PRESENT	0
754454	753661	19673G	PARTICIPANT	\N	PRESENT	0
754455	753661	20092G	PARTICIPANT	\N	PRESENT	0
754456	753661	20110Q	PARTICIPANT	\N	PRESENT	0
754457	753661	20100N	PARTICIPANT	\N	PRESENT	0
754458	753661	18207D	PARTICIPANT	\N	PRESENT	0
754459	753661	21045D	PARTICIPANT	\N	PRESENT	0
754460	753661	14219Q	PARTICIPANT	\N	PRESENT	0
754461	753661	20084G	PARTICIPANT	\N	PRESENT	0
754462	753661	18395Y	PARTICIPANT	\N	PRESENT	0
754463	753661	21057H	PARTICIPANT	\N	PRESENT	0
754464	753661	11056N	PARTICIPANT	\N	PRESENT	0
754465	753661	19760E	PARTICIPANT	\N	PRESENT	0
754466	753661	19758L	PARTICIPANT	\N	PRESENT	0
754467	753661	14071N	PARTICIPANT	\N	PRESENT	0
754468	753661	07004J	PARTICIPANT	\N	PRESENT	0
754469	753661	14147R	PARTICIPANT	\N	PRESENT	0
754470	753661	20086J	PARTICIPANT	\N	PRESENT	0
754471	753661	10015M	PARTICIPANT	\N	PRESENT	0
754472	753661	19573D	PARTICIPANT	\N	PRESENT	0
754473	753661	19507S	PARTICIPANT	\N	PRESENT	0
754360	753660	20128B	PARTICIPANT	\N	PRESENT	0
754361	753660	19631V	PARTICIPANT	\N	PRESENT	0
754474	753661	14133K	PARTICIPANT	\N	PRESENT	0
754475	753661	21089R	PARTICIPANT	\N	PRESENT	0
754476	753661	21078N	PARTICIPANT	\N	PRESENT	0
754419	753661	19301E	PARTICIPANT	\N	PRESENT	0
754420	753661	19629C	PARTICIPANT	\N	PRESENT	0
754477	753661	11110B	PARTICIPANT	\N	PRESENT	0
754478	753661	14037X	PARTICIPANT	\N	PRESENT	0
754479	753661	14259Y	PARTICIPANT	\N	PRESENT	0
754480	753661	20058E	PARTICIPANT	\N	PRESENT	0
754481	753661	21038E	PARTICIPANT	\N	PRESENT	0
754482	753661	14255U	PARTICIPANT	\N	PRESENT	0
754483	753661	20104S	PARTICIPANT	\N	PRESENT	0
754484	753661	21040X	PARTICIPANT	\N	PRESENT	0
754485	753661	14021P	PARTICIPANT	\N	PRESENT	0
754486	753661	18083K	PARTICIPANT	\N	PRESENT	0
754487	753661	19569H	PARTICIPANT	\N	PRESENT	0
754488	753661	20032T	PARTICIPANT	\N	PRESENT	0
756070	756069	04047H	PARTICIPANT	\N	PRESENT	1
756071	756069	20114U	PARTICIPANT	\N	PRESENT	0
756072	756069	19621T	PARTICIPANT	\N	PRESENT	1
756073	756069	19954N	PARTICIPANT	\N	PRESENT	1
756074	756069	14030Q	PARTICIPANT	\N	PRESENT	1
756075	756069	21089R	PARTICIPANT	\N	PRESENT	0
756076	756069	19593H	PARTICIPANT	\N	PRESENT	0
756077	756069	21091K	PARTICIPANT	\N	PRESENT	0
756078	756069	14109K	PARTICIPANT	\N	PRESENT	1
756079	756069	19611R	PARTICIPANT	\N	PRESENT	0
756080	756069	20142Y	PARTICIPANT	\N	PRESENT	1
756081	756069	20264J	PARTICIPANT	\N	PRESENT	1
757846	757845	14213J	PARTICIPANT	\N	PRESENT	0
757847	757845	14071N	PARTICIPANT	\N	PRESENT	0
757868	757849	08045X	PARTICIPANT	\N	PRESENT	0
757875	757850	19553Y	PARTICIPANT	\N	PRESENT	0
757870	757849	14213J	PARTICIPANT	\N	PRESENT	0
757876	757850	14213J	PARTICIPANT	\N	PRESENT	0
757872	757849	14071N	PARTICIPANT	\N	PRESENT	0
757873	757849	20096L	PARTICIPANT	\N	PRESENT	0
757874	757849	21094N	PARTICIPANT	\N	PRESENT	0
757877	757850	21081H	PARTICIPANT	\N	PRESENT	0
757878	757850	19683J	PARTICIPANT	\N	PRESENT	0
757879	757850	19758L	PARTICIPANT	\N	PRESENT	0
757880	757850	18193Q	PARTICIPANT	\N	PRESENT	0
757881	757850	14223L	PARTICIPANT	\N	PRESENT	0
757882	757850	14071N	PARTICIPANT	\N	PRESENT	0
757883	757850	20130U	PARTICIPANT	\N	PRESENT	0
757884	757850	17965H	PARTICIPANT	\N	PRESENT	0
757885	757850	21094N	PARTICIPANT	\N	PRESENT	0
757886	757850	04092N	PARTICIPANT	\N	PRESENT	0
757887	757850	19703U	PARTICIPANT	\N	PRESENT	0
757888	757865	14213J	PARTICIPANT	\N	PRESENT	0
757889	757865	19553Y	PARTICIPANT	\N	PRESENT	0
757890	757865	04092N	PARTICIPANT	\N	PRESENT	0
757891	757865	20130U	PARTICIPANT	\N	PRESENT	0
757892	757865	17965H	PARTICIPANT	\N	PRESENT	0
757893	757865	19703U	PARTICIPANT	\N	PRESENT	0
757894	757865	21081H	PARTICIPANT	\N	PRESENT	0
757895	757864	19553Y	PARTICIPANT	\N	PRESENT	0
757896	757864	14213J	PARTICIPANT	\N	PRESENT	0
757899	757864	14195A	PARTICIPANT	\N	PRESENT	0
753742	753741	19711U	PARTICIPANT	\N	PRESENT	0
756360	755843	14151M	PARTICIPANT	\N	PRESENT	0
756477	756189	05008E	PARTICIPANT	\N	PRESENT	0
756478	756189	20022R	PARTICIPANT	\N	PRESENT	0
756479	756189	21043B	PARTICIPANT	\N	PRESENT	0
756480	756189	14089Y	PARTICIPANT	\N	PRESENT	0
756481	756189	20114U	PARTICIPANT	\N	PRESENT	0
756482	756189	21088Q	PARTICIPANT	\N	PRESENT	0
756483	756189	04047H	PARTICIPANT	\N	PRESENT	0
756484	756189	14053L	PARTICIPANT	\N	PRESENT	0
756486	756189	21057H	PARTICIPANT	\N	PRESENT	0
756487	756189	11056N	PARTICIPANT	\N	PRESENT	0
756488	756189	14259Y	PARTICIPANT	\N	PRESENT	0
756489	756189	14215L	PARTICIPANT	\N	PRESENT	0
756490	756189	14151M	PARTICIPANT	\N	PRESENT	0
756491	756189	19673G	PARTICIPANT	\N	PRESENT	0
756492	756189	08018U	PARTICIPANT	\N	PRESENT	0
756493	756189	19111A	PARTICIPANT	\N	PRESENT	0
756494	756189	14231L	PARTICIPANT	\N	PRESENT	0
756495	756189	21044C	PARTICIPANT	\N	PRESENT	0
756496	756189	19489J	PARTICIPANT	\N	PRESENT	0
756497	756189	19729F	PARTICIPANT	\N	PRESENT	0
756498	756189	20108W	PARTICIPANT	\N	PRESENT	0
756499	756189	18207D	PARTICIPANT	\N	PRESENT	0
756500	756189	14111D	PARTICIPANT	\N	PRESENT	0
756501	756189	21040X	PARTICIPANT	\N	PRESENT	0
756502	756189	14147R	PARTICIPANT	\N	PRESENT	0
756503	756189	11072N	PARTICIPANT	\N	PRESENT	0
756504	756189	18231D	PARTICIPANT	\N	PRESENT	0
756505	756189	20036X	PARTICIPANT	\N	PRESENT	0
756506	756189	10015M	PARTICIPANT	\N	PRESENT	0
756507	756189	21038E	PARTICIPANT	\N	PRESENT	0
756508	756189	20098N	PARTICIPANT	\N	PRESENT	0
756509	756189	04045F	PARTICIPANT	\N	PRESENT	0
756510	756189	19749K	PARTICIPANT	\N	PRESENT	0
756511	756189	21076L	PARTICIPANT	\N	PRESENT	0
757470	755861	20120S	PARTICIPANT	\N	PRESENT	0
757471	755861	95041E	PARTICIPANT	\N	PRESENT	0
757472	755861	20098N	PARTICIPANT	\N	PRESENT	0
757473	755861	20020P	PARTICIPANT	\N	PRESENT	0
757474	755861	20086J	PARTICIPANT	\N	PRESENT	0
757475	755861	19383Y	PARTICIPANT	\N	PRESENT	0
757476	755861	14059S	PARTICIPANT	\N	PRESENT	0
757477	755861	21054E	PARTICIPANT	\N	PRESENT	0
757478	755861	20054A	PARTICIPANT	\N	PRESENT	0
757479	755861	20126Y	PARTICIPANT	\N	PRESENT	0
757480	755861	08056B	PARTICIPANT	\N	PRESENT	0
757481	755861	21092L	PARTICIPANT	\N	PRESENT	0
757482	755861	20118Y	PARTICIPANT	\N	PRESENT	0
757483	755861	14097Y	PARTICIPANT	\N	PRESENT	0
757484	755861	14021P	PARTICIPANT	\N	PRESENT	0
757485	755861	20138D	PARTICIPANT	\N	PRESENT	0
757486	755861	19489J	PARTICIPANT	\N	PRESENT	0
757487	755861	19683J	PARTICIPANT	\N	PRESENT	0
757488	755861	08045X	PARTICIPANT	\N	PRESENT	0
757489	755861	14121F	PARTICIPANT	\N	PRESENT	0
757490	755861	19531S	PARTICIPANT	\N	PRESENT	0
757491	755861	20252E	PARTICIPANT	\N	PRESENT	0
757494	755861	19649G	PARTICIPANT	\N	PRESENT	0
757495	755861	18193Q	PARTICIPANT	\N	PRESENT	0
757496	755861	08012N	PARTICIPANT	\N	PRESENT	0
757500	755861	17779H	PARTICIPANT	\N	PRESENT	0
757501	755861	18207D	PARTICIPANT	\N	PRESENT	0
757503	755861	14001X	PARTICIPANT	\N	PRESENT	0
757504	755861	20028X	PARTICIPANT	\N	PRESENT	0
757506	755861	20018V	PARTICIPANT	\N	PRESENT	0
757508	755861	18231D	PARTICIPANT	\N	PRESENT	0
757510	755861	14257W	PARTICIPANT	\N	PRESENT	0
757511	755861	20030R	PARTICIPANT	\N	PRESENT	0
757513	755861	05008E	PARTICIPANT	\N	PRESENT	0
757515	755861	17965H	PARTICIPANT	\N	PRESENT	0
757516	755861	20084G	PARTICIPANT	\N	PRESENT	0
757518	755861	19669L	PARTICIPANT	\N	PRESENT	0
757520	755861	21051B	PARTICIPANT	\N	PRESENT	0
757522	755861	20064C	PARTICIPANT	\N	PRESENT	0
757525	755861	21031W	PARTICIPANT	\N	PRESENT	0
757526	755861	21082J	PARTICIPANT	\N	PRESENT	0
757529	755861	14225N	PARTICIPANT	\N	PRESENT	0
757531	755861	14229S	PARTICIPANT	\N	PRESENT	0
757532	755861	20082E	PARTICIPANT	\N	PRESENT	0
757534	755861	17737W	PARTICIPANT	\N	PRESENT	0
757535	755861	11045K	PARTICIPANT	\N	PRESENT	0
757542	755861	21042A	PARTICIPANT	\N	PRESENT	0
757544	755861	21050A	PARTICIPANT	\N	PRESENT	0
757547	755861	17023S	PARTICIPANT	\N	PRESENT	0
757548	755861	20042V	PARTICIPANT	\N	PRESENT	0
757549	755861	14073Q	PARTICIPANT	\N	PRESENT	0
757550	755861	14255U	PARTICIPANT	\N	PRESENT	0
757551	755861	21083K	PARTICIPANT	\N	PRESENT	0
757552	755861	14205J	PARTICIPANT	\N	PRESENT	0
757553	755861	19721W	PARTICIPANT	\N	PRESENT	0
757554	755861	20248J	PARTICIPANT	\N	PRESENT	0
757555	755861	19685L	PARTICIPANT	\N	PRESENT	0
757556	755861	14327T	PARTICIPANT	\N	PRESENT	0
757557	755861	17229F	PARTICIPANT	\N	PRESENT	0
757558	755861	19507S	PARTICIPANT	\N	PRESENT	0
757559	755861	14042U	PARTICIPANT	\N	PRESENT	0
757560	755861	15197G	PARTICIPANT	\N	PRESENT	0
757561	755861	21086N	PARTICIPANT	\N	PRESENT	0
757562	755861	19413M	PARTICIPANT	\N	PRESENT	0
757563	755861	19826F	PARTICIPANT	\N	PRESENT	0
757564	755861	19111A	PARTICIPANT	\N	PRESENT	0
757565	755861	14231L	PARTICIPANT	\N	PRESENT	0
757566	755861	07004J	PARTICIPANT	\N	PRESENT	0
757567	755861	20286Q	PARTICIPANT	\N	PRESENT	0
757568	755861	19569H	PARTICIPANT	\N	PRESENT	0
757569	755861	14179A	PARTICIPANT	\N	PRESENT	0
757571	755861	21053D	PARTICIPANT	\N	PRESENT	0
757572	755861	20066E	PARTICIPANT	\N	PRESENT	0
757573	755861	19735D	PARTICIPANT	\N	PRESENT	0
757575	755861	19611R	PARTICIPANT	\N	PRESENT	0
757577	755861	19335Q	PARTICIPANT	\N	PRESENT	0
757579	755861	20052X	PARTICIPANT	\N	PRESENT	0
757581	755861	14219Q	PARTICIPANT	\N	PRESENT	0
757582	755861	11085T	PARTICIPANT	\N	PRESENT	0
757593	755861	14275Y	PARTICIPANT	\N	PRESENT	0
757586	755861	08009T	PARTICIPANT	\N	PRESENT	0
757588	755861	21038E	PARTICIPANT	\N	PRESENT	0
757590	755861	21064G	PARTICIPANT	\N	PRESENT	0
757591	755861	19563B	PARTICIPANT	\N	PRESENT	0
757594	755861	01034P	PARTICIPANT	\N	PRESENT	0
757605	755861	14251Q	PARTICIPANT	\N	PRESENT	0
757597	755861	20058E	PARTICIPANT	\N	PRESENT	0
757601	755861	19479G	PARTICIPANT	\N	PRESENT	0
757603	755861	20124W	PARTICIPANT	\N	PRESENT	0
757604	755861	21056G	PARTICIPANT	\N	PRESENT	0
757606	755861	20080C	PARTICIPANT	\N	PRESENT	0
757607	755861	19725B	PARTICIPANT	\N	PRESENT	0
757608	755861	14109K	PARTICIPANT	\N	PRESENT	0
757609	755861	14069U	PARTICIPANT	\N	PRESENT	0
757610	755861	19057M	PARTICIPANT	\N	PRESENT	0
757611	755861	11053K	PARTICIPANT	\N	PRESENT	0
757612	755861	20094J	PARTICIPANT	\N	PRESENT	0
757613	755861	20048C	PARTICIPANT	\N	PRESENT	0
757614	755861	21094N	PARTICIPANT	\N	PRESENT	0
757654	755861	21047F	PARTICIPANT	\N	PRESENT	0
757616	755861	11115U	PARTICIPANT	\N	PRESENT	0
757650	755861	14083S	PARTICIPANT	\N	PRESENT	0
757655	755867	14059S	PARTICIPANT	\N	PRESENT	0
757656	755867	19531S	PARTICIPANT	\N	PRESENT	0
757657	755867	20042V	PARTICIPANT	\N	PRESENT	0
757658	755867	01058X	PARTICIPANT	\N	PRESENT	0
757659	755867	11027H	PARTICIPANT	\N	PRESENT	0
757660	755867	04042C	PARTICIPANT	\N	PRESENT	0
757661	755867	08056B	PARTICIPANT	\N	PRESENT	0
757662	755867	20252E	PARTICIPANT	\N	PRESENT	0
757663	755867	14267Y	PARTICIPANT	\N	PRESENT	0
757664	755867	11064N	PARTICIPANT	\N	PRESENT	0
757665	755867	14193X	PRESIDENT	0	PRESENT	0
757666	755867	14179A	PARTICIPANT	\N	PRESENT	0
757667	755867	07033P	PARTICIPANT	\N	PRESENT	0
757668	755867	99004R	PARTICIPANT	\N	PRESENT	0
757669	755867	08047A	PARTICIPANT	\N	PRESENT	0
757670	755867	17023S	PARTICIPANT	\N	PRESENT	0
757671	755867	14255U	PARTICIPANT	\N	PRESENT	0
757672	755867	14001X	PARTICIPANT	\N	PRESENT	0
757673	755867	20072C	PARTICIPANT	\N	PRESENT	0
757674	755867	21031W	PARTICIPANT	\N	PRESENT	0
757675	755867	19565D	PARTICIPANT	\N	PRESENT	0
757676	755867	19669L	PARTICIPANT	\N	PRESENT	0
757677	755867	21067K	PARTICIPANT	\N	PRESENT	0
742766	740616	11054L	PARTICIPANT	\N	PRESENT	0
742767	740616	11104D	PARTICIPANT	\N	PRESENT	0
742768	740616	19479G	PARTICIPANT	\N	PRESENT	0
742769	740616	19387D	PARTICIPANT	\N	PRESENT	0
742770	740616	19681G	PARTICIPANT	\N	PRESENT	0
742771	740616	19629C	PARTICIPANT	\N	PRESENT	0
742772	740616	20128B	PARTICIPANT	\N	PRESENT	0
742773	740616	19651A	PARTICIPANT	\N	PRESENT	0
742774	740616	20028X	PARTICIPANT	\N	PRESENT	0
742775	740616	11074Q	PARTICIPANT	\N	PRESENT	0
742776	740616	19599P	PARTICIPANT	\N	PRESENT	0
742777	740616	19565D	PARTICIPANT	\N	PRESENT	0
742778	740616	20088L	PARTICIPANT	\N	PRESENT	0
742779	740616	19762G	PARTICIPANT	\N	PRESENT	0
742780	740616	20076G	PARTICIPANT	\N	PRESENT	0
742781	740616	20074E	PARTICIPANT	\N	PRESENT	0
742782	740616	20084G	PARTICIPANT	\N	PRESENT	0
742783	740616	20132W	PARTICIPANT	\N	PRESENT	0
742784	740616	19563B	PARTICIPANT	\N	PRESENT	0
742706	740616	17589D	PARTICIPANT	\N	PRESENT	0
742707	740616	19511N	PARTICIPANT	\N	PRESENT	0
742708	740616	19319Q	PARTICIPANT	\N	PRESENT	0
742709	740616	19866P	PARTICIPANT	\N	PRESENT	0
742710	740616	98022P	PARTICIPANT	\N	PRESENT	0
742711	740616	20026V	PARTICIPANT	\N	PRESENT	0
742712	740616	08028W	PARTICIPANT	\N	PRESENT	0
742713	740616	20068G	PARTICIPANT	\N	PRESENT	0
742714	740616	20090E	PARTICIPANT	\N	PRESENT	0
742715	740616	20062A	PARTICIPANT	\N	PRESENT	0
742716	740616	14105F	PARTICIPANT	\N	PRESENT	0
742717	740616	17229F	PARTICIPANT	\N	PRESENT	0
742718	740616	20098N	PARTICIPANT	\N	PRESENT	0
742719	740616	19593H	PARTICIPANT	\N	PRESENT	0
742720	740616	19333N	PARTICIPANT	\N	PRESENT	0
742764	740616	14111D	PARTICIPANT	\N	PRESENT	0
742765	740616	19715Y	PARTICIPANT	\N	PRESENT	0
742785	740616	14195A	PARTICIPANT	\N	PRESENT	0
742786	740616	19347U	PARTICIPANT	\N	PRESENT	0
742787	740616	04059M	PARTICIPANT	\N	PRESENT	0
742788	740616	11077T	PARTICIPANT	\N	PRESENT	0
742789	740616	04008A	PARTICIPANT	\N	PRESENT	0
742790	740616	99004R	PARTICIPANT	\N	PRESENT	0
742791	740616	01058X	PARTICIPANT	\N	PRESENT	0
742792	740616	19766L	PARTICIPANT	\N	PRESENT	0
742793	740616	04047H	PARTICIPANT	\N	PRESENT	0
742794	740616	19739H	PARTICIPANT	\N	PRESENT	0
742795	740616	19695N	PARTICIPANT	\N	PRESENT	0
742796	740616	19621T	PARTICIPANT	\N	PRESENT	0
742797	740616	14229S	PARTICIPANT	\N	PRESENT	0
742798	740616	14207L	PARTICIPANT	\N	PRESENT	0
742799	740616	20072C	PARTICIPANT	\N	PRESENT	0
742801	740616	19583F	PARTICIPANT	\N	PRESENT	0
742802	740616	19569H	PARTICIPANT	\N	PRESENT	0
742804	740616	14073Q	PARTICIPANT	\N	PRESENT	0
742805	740616	20144B	PARTICIPANT	\N	PRESENT	0
742806	740616	14267Y	PARTICIPANT	\N	PRESENT	0
742807	740616	14219Q	PARTICIPANT	\N	PRESENT	0
742808	740616	20080C	PARTICIPANT	\N	PRESENT	0
742809	740616	19251M	PARTICIPANT	\N	PRESENT	0
742810	740616	19631V	PARTICIPANT	\N	PRESENT	0
742811	740616	19301E	PARTICIPANT	\N	PRESENT	0
742812	740616	20106U	PARTICIPANT	\N	PRESENT	0
742813	740616	04045F	PARTICIPANT	\N	PRESENT	0
742814	740616	19349W	PARTICIPANT	\N	PRESENT	0
742815	740616	19489J	PARTICIPANT	\N	PRESENT	0
742816	740616	11056N	PARTICIPANT	\N	PRESENT	0
742817	740616	11040E	PARTICIPANT	\N	PRESENT	0
742818	740616	19758L	PARTICIPANT	\N	PRESENT	0
742819	740616	95063L	PARTICIPANT	\N	PRESENT	0
742820	740616	20150Y	PARTICIPANT	\N	PRESENT	0
742821	740616	20036X	PARTICIPANT	\N	PRESENT	0
742822	740616	20100N	PARTICIPANT	\N	PRESENT	0
742824	740616	11045K	PARTICIPANT	\N	PRESENT	0
742825	740616	01028R	PARTICIPANT	\N	PRESENT	0
742826	740616	17779H	PARTICIPANT	\N	PRESENT	0
742827	740616	11027H	PARTICIPANT	\N	PRESENT	0
742828	740616	19760E	PARTICIPANT	\N	PRESENT	0
742829	740616	19687N	PARTICIPANT	\N	PRESENT	0
742830	740616	14151M	PARTICIPANT	\N	PRESENT	0
742831	740616	19683J	PARTICIPANT	\N	PRESENT	0
742832	740616	19649G	PARTICIPANT	\N	PRESENT	0
742833	740616	14021P	PARTICIPANT	\N	PRESENT	0
742834	740616	04085P	PARTICIPANT	\N	PRESENT	0
742835	740616	01062T	PARTICIPANT	\N	PRESENT	0
742836	740616	14097Y	PARTICIPANT	\N	PRESENT	0
742837	740616	20114U	PARTICIPANT	\N	PRESENT	0
742839	740616	11067R	PARTICIPANT	\N	PRESENT	0
742840	740616	20070A	PARTICIPANT	\N	PRESENT	0
742841	740616	19820Y	PARTICIPANT	\N	PRESENT	0
742842	740616	08012N	PARTICIPANT	\N	PRESENT	0
742843	740616	14109K	PARTICIPANT	\N	PRESENT	0
742844	740616	14281W	PARTICIPANT	\N	PRESENT	0
742857	740616	11031D	PARTICIPANT	\N	PRESENT	0
742858	740616	20102Q	PARTICIPANT	\N	PRESENT	0
742859	740616	12041X	PARTICIPANT	\N	PRESENT	0
742860	740616	20046A	PARTICIPANT	\N	PRESENT	0
742861	740616	20110Q	PARTICIPANT	\N	PRESENT	0
742862	740616	20914V	PARTICIPANT	\N	PRESENT	0
742863	740616	11099A	PARTICIPANT	\N	PRESENT	0
742864	740616	17637T	PARTICIPANT	\N	PRESENT	0
742865	740616	20142Y	PARTICIPANT	\N	PRESENT	0
742866	740616	20130U	PARTICIPANT	\N	PRESENT	0
742867	740616	20092G	PARTICIPANT	\N	PRESENT	0
742868	740616	20266L	PARTICIPANT	\N	PRESENT	0
742869	740616	19711U	PARTICIPANT	\N	PRESENT	0
742870	740616	19782L	PARTICIPANT	\N	PRESENT	0
742871	740616	19525U	PARTICIPANT	\N	PRESENT	0
742872	740616	14249W	PARTICIPANT	\N	PRESENT	0
742873	740616	11083R	PARTICIPANT	\N	PRESENT	0
742874	740616	19329S	PARTICIPANT	\N	PRESENT	0
742875	740616	19591F	PARTICIPANT	\N	PRESENT	0
742876	740616	19697Q	PARTICIPANT	\N	PRESENT	0
742877	740616	19637C	PARTICIPANT	\N	PRESENT	0
742878	740616	11072N	PARTICIPANT	\N	PRESENT	0
742879	740616	11115U	PARTICIPANT	\N	PRESENT	0
742880	740616	08073C	PARTICIPANT	\N	PRESENT	0
742881	740616	08061X	PARTICIPANT	\N	PRESENT	0
742882	740616	11033F	PARTICIPANT	\N	PRESENT	0
742883	740616	14055N	PARTICIPANT	\N	PRESENT	0
742884	740616	20058E	PARTICIPANT	\N	PRESENT	0
742885	740616	04092N	PARTICIPANT	\N	PRESENT	0
742886	740616	14038Y	PARTICIPANT	\N	PRESENT	0
742887	740616	14037X	PARTICIPANT	\N	PRESENT	0
742888	740616	20044X	PARTICIPANT	\N	PRESENT	0
742889	740616	19447X	PARTICIPANT	\N	PRESENT	0
742890	740616	14173T	PARTICIPANT	\N	PRESENT	0
742891	740616	20116W	PARTICIPANT	\N	PRESENT	0
742892	740616	19719D	PARTICIPANT	\N	PRESENT	0
742893	740616	20038A	PARTICIPANT	\N	PRESENT	0
742894	740616	19573D	PARTICIPANT	\N	PRESENT	0
742895	740616	11012A	PARTICIPANT	\N	PRESENT	0
742896	740616	19673G	PARTICIPANT	\N	PRESENT	0
742897	740616	19663E	PARTICIPANT	\N	PRESENT	0
742898	740616	19467C	PARTICIPANT	\N	PRESENT	0
742899	740616	14211G	PARTICIPANT	\N	PRESENT	0
742900	740616	11064N	PARTICIPANT	\N	PRESENT	0
742901	740616	11010L	PARTICIPANT	\N	PRESENT	0
742902	740616	14251Q	PARTICIPANT	\N	PRESENT	0
742903	740616	14221J	PARTICIPANT	\N	PRESENT	0
742904	740616	20980G	PARTICIPANT	\N	PRESENT	0
742905	740616	04057K	PARTICIPANT	\N	PRESENT	0
742906	740616	20050V	PARTICIPANT	\N	PRESENT	0
742907	740616	20056C	PARTICIPANT	\N	PRESENT	0
742908	740616	20122U	PARTICIPANT	\N	PRESENT	0
742909	740616	14355X	PARTICIPANT	\N	PRESENT	0
742910	740616	20096L	PARTICIPANT	\N	PRESENT	0
742911	740616	19515S	PARTICIPANT	\N	PRESENT	0
742912	740616	14033T	PARTICIPANT	\N	PRESENT	0
742913	740616	07029T	PARTICIPANT	\N	PRESENT	0
742914	740616	14031R	PARTICIPANT	\N	PRESENT	0
742915	740616	20060X	PARTICIPANT	\N	PRESENT	0
742916	740616	20146D	PARTICIPANT	\N	PRESENT	0
742917	740616	11080N	PARTICIPANT	\N	PRESENT	0
742918	740616	12028B	PARTICIPANT	\N	PRESENT	0
742919	740616	19295A	PARTICIPANT	\N	PRESENT	0
742920	740616	20264J	PARTICIPANT	\N	PRESENT	0
742921	740616	11110B	PARTICIPANT	\N	PRESENT	0
742922	740616	01057W	PARTICIPANT	\N	PRESENT	0
742923	740616	14253S	PARTICIPANT	\N	PRESENT	0
742924	740616	08045X	PARTICIPANT	\N	PRESENT	0
742925	740616	14259Y	PARTICIPANT	\N	PRESENT	0
739747	738007	20034V	PARTICIPANT	\N	PRESENT	0
760810	760507	19479G	PARTICIPANT	\N	PRESENT	0
760813	760812	05008E	PARTICIPANT	\N	PRESENT	0
764873	761716	20088L	PARTICIPANT	\N	PRESENT	0
764850	764374	14327T	PARTICIPANT	\N	PRESENT	0
764851	764374	19711U	PARTICIPANT	\N	PRESENT	0
764852	764374	20094J	PARTICIPANT	\N	PRESENT	0
764853	764374	20044X	PARTICIPANT	\N	PRESENT	0
764854	764374	19399H	PARTICIPANT	\N	PRESENT	0
764855	764374	20150Y	PARTICIPANT	\N	PRESENT	0
764856	764374	20062A	PARTICIPANT	\N	PRESENT	0
764857	764374	08073C	PARTICIPANT	\N	PRESENT	0
764858	764374	20070A	PARTICIPANT	\N	PRESENT	0
764859	764374	21069M	PARTICIPANT	\N	PRESENT	0
764860	764374	14121F	PARTICIPANT	\N	PRESENT	0
764861	764374	20126Y	PARTICIPANT	\N	PRESENT	0
764862	764374	20024T	PARTICIPANT	\N	PRESENT	0
764863	764374	19335Q	PARTICIPANT	\N	EXCUSE	0
764869	761716	19479G	PARTICIPANT	\N	PRESENT	0
764872	761716	20028X	PARTICIPANT	\N	PRESENT	0
764874	761716	17965H	PARTICIPANT	\N	PRESENT	0
764875	761716	20130U	PARTICIPANT	\N	PRESENT	0
764876	761716	21087P	PARTICIPANT	\N	PRESENT	0
764877	761716	21097R	PARTICIPANT	\N	PRESENT	0
764878	761716	19569H	PARTICIPANT	\N	PRESENT	0
764879	761716	21064G	PARTICIPANT	\N	PRESENT	0
764880	761716	19629C	PARTICIPANT	\N	PRESENT	0
764881	761716	20090E	PARTICIPANT	\N	PRESENT	0
764882	761716	14033T	PARTICIPANT	\N	PRESENT	0
764883	761716	14026U	PARTICIPANT	\N	PRESENT	0
764884	761716	14071N	PARTICIPANT	\N	PRESENT	0
764885	761716	21050A	PARTICIPANT	\N	PRESENT	0
764886	764374	21041Y	PARTICIPANT	\N	PRESENT	0
764887	764374	14083S	PARTICIPANT	\N	PRESENT	0
764888	764374	20116W	PARTICIPANT	\N	PRESENT	0
764889	761716	21040X	PARTICIPANT	\N	PRESENT	0
764890	761716	14207L	PARTICIPANT	\N	PRESENT	0
764891	764374	20034V	PARTICIPANT	\N	PRESENT	0
764892	764374	11110B	PARTICIPANT	\N	PRESENT	0
764893	761716	19866P	PARTICIPANT	\N	PRESENT	0
764894	761716	20054A	PARTICIPANT	\N	PRESENT	0
764895	761716	21096Q	PARTICIPANT	\N	PRESENT	0
764896	761716	11085T	PARTICIPANT	\N	PRESENT	0
764897	761716	19531S	PARTICIPANT	\N	PRESENT	0
764898	761716	19760E	PARTICIPANT	\N	PRESENT	0
764899	761716	19563B	PARTICIPANT	\N	PRESENT	0
764900	761716	21034A	PARTICIPANT	\N	PRESENT	0
764901	761716	21092L	PARTICIPANT	\N	PRESENT	0
764902	761716	19331L	PARTICIPANT	\N	PRESENT	0
764903	761716	14031R	PARTICIPANT	\N	PRESENT	0
764904	761716	20092G	PARTICIPANT	\N	PRESENT	0
764905	761716	20040T	PARTICIPANT	\N	PRESENT	0
764906	761716	20024T	PARTICIPANT	\N	PRESENT	0
765462	765461	07033P	PARTICIPANT	\N	PRESENT	0
765464	765463	07033P	PARTICIPANT	\N	PRESENT	0
765468	765467	14133K	PARTICIPANT	\N	PRESENT	0
765469	765467	14097Y	PARTICIPANT	\N	PRESENT	0
765472	765471	14097Y	PARTICIPANT	\N	PRESENT	0
765635	765632	08010L	PARTICIPANT	\N	PRESENT	0
765664	765663	19711U	PARTICIPANT	\N	PRESENT	0
765666	765665	11053K	PARTICIPANT	\N	PRESENT	0
765671	765670	11053K	PARTICIPANT	\N	PRESENT	0
765746	765745	20090E	PARTICIPANT	\N	PRESENT	0
765747	765745	18193Q	PARTICIPANT	\N	PRESENT	1
765748	764908	21071F	PARTICIPANT	\N	PRESENT	0
765749	764908	21045D	PARTICIPANT	\N	PRESENT	0
765750	764908	21064G	PARTICIPANT	\N	PRESENT	0
765751	764908	21094N	PARTICIPANT	\N	PRESENT	0
765752	764908	19553Y	PARTICIPANT	\N	PRESENT	0
765755	764908	18193Q	PARTICIPANT	\N	EXCUSE	0
765758	764908	21087P	PARTICIPANT	\N	EXCUSE	0
765764	764908	19691J	PARTICIPANT	\N	PRESENT	0
766046	765489	14053L	PARTICIPANT	\N	EXCUSE	0
766833	766832	19725B	PARTICIPANT	\N	PRESENT	0
767079	765402	19691J	PARTICIPANT	\N	PRESENT	0
767077	765402	14207L	PARTICIPANT	\N	PRESENT	0
767078	765402	19703U	PARTICIPANT	\N	PRESENT	0
767080	765402	14215L	PARTICIPANT	\N	PRESENT	0
767081	765402	19349W	PARTICIPANT	\N	PRESENT	0
767082	765402	21045D	PARTICIPANT	\N	PRESENT	0
767083	765402	18395Y	PARTICIPANT	\N	PRESENT	0
767084	765402	19679N	PARTICIPANT	\N	PRESENT	0
767085	765402	21049H	PARTICIPANT	\N	PRESENT	0
767086	765402	19657G	PARTICIPANT	\N	PRESENT	0
767087	765402	14281W	PARTICIPANT	\N	PRESENT	0
767088	765402	14217N	PARTICIPANT	\N	PRESENT	0
767089	765402	21063F	PARTICIPANT	\N	PRESENT	0
767090	765402	14213J	PARTICIPANT	\N	PRESENT	0
767091	765402	11090Q	PARTICIPANT	\N	PRESENT	0
767092	765402	19954N	PARTICIPANT	\N	PRESENT	0
767093	765402	21071F	PARTICIPANT	\N	PRESENT	0
767094	765402	20180F	PARTICIPANT	\N	PRESENT	0
767095	765402	20096L	PARTICIPANT	\N	PRESENT	0
767096	765402	21094N	PARTICIPANT	\N	PRESENT	0
767097	765402	20062A	PARTICIPANT	\N	PRESENT	0
767098	765402	14107H	PARTICIPANT	\N	PRESENT	0
767099	765402	21044C	PARTICIPANT	\N	PRESENT	0
767100	765402	21068L	PARTICIPANT	\N	PRESENT	0
767101	765402	14083S	PARTICIPANT	\N	PRESENT	0
767102	765402	20134Y	PARTICIPANT	\N	PRESENT	0
767103	765402	04033B	PARTICIPANT	\N	PRESENT	0
767104	765402	19565D	PARTICIPANT	\N	PRESENT	0
767105	765402	14205J	PARTICIPANT	\N	PRESENT	0
767106	765402	20104S	PARTICIPANT	\N	PRESENT	0
767107	765402	14069U	PARTICIPANT	\N	PRESENT	0
767108	765402	19723Y	PARTICIPANT	\N	PRESENT	0
767109	765402	20106U	PARTICIPANT	\N	PRESENT	0
767110	765402	19447X	PARTICIPANT	\N	PRESENT	0
767111	765402	14169X	PARTICIPANT	\N	PRESENT	0
767112	765402	20082E	PARTICIPANT	\N	PRESENT	0
767113	765402	20032T	PARTICIPANT	\N	PRESENT	0
767114	765402	18083K	PARTICIPANT	\N	PRESENT	0
767115	765402	95041E	PARTICIPANT	\N	PRESENT	0
767116	765402	14249W	PARTICIPANT	\N	PRESENT	0
767117	765402	21097R	PARTICIPANT	\N	PRESENT	0
767118	765402	19782L	PARTICIPANT	\N	PRESENT	0
767119	765402	21082J	PARTICIPANT	\N	PRESENT	0
767120	765402	01034P	PARTICIPANT	\N	PRESENT	0
767121	765402	21064G	PARTICIPANT	\N	PRESENT	0
767122	765402	08010L	PARTICIPANT	\N	PRESENT	0
767123	765402	19367Y	PARTICIPANT	\N	PRESENT	0
767124	765402	19719D	PARTICIPANT	\N	PRESENT	0
767125	765402	19573D	PARTICIPANT	\N	PRESENT	0
767126	765402	14026U	PARTICIPANT	\N	PRESENT	0
767127	765402	17779H	PARTICIPANT	\N	PRESENT	0
767128	765402	19591F	PARTICIPANT	\N	PRESENT	0
767129	765402	19347U	PARTICIPANT	\N	PRESENT	0
767130	765402	14223L	PARTICIPANT	\N	PRESENT	0
767131	765402	21048G	PARTICIPANT	\N	PRESENT	0
767132	765402	19383Y	PARTICIPANT	\N	PRESENT	0
767133	765402	19507S	PARTICIPANT	\N	PRESENT	0
767134	765402	19768N	PARTICIPANT	\N	PRESENT	0
767135	765402	08015R	PARTICIPANT	\N	PRESENT	0
767136	765402	19531S	PARTICIPANT	\N	PRESENT	0
767137	765402	20040T	PARTICIPANT	\N	PRESENT	0
767138	765402	19826F	PARTICIPANT	\N	PRESENT	0
767139	765402	20088L	PARTICIPANT	\N	PRESENT	0
767140	765402	19563B	PARTICIPANT	\N	PRESENT	0
767141	765402	20140W	PARTICIPANT	\N	PRESENT	0
767142	765402	20120S	PARTICIPANT	\N	PRESENT	0
767143	765402	20034V	PARTICIPANT	\N	PRESENT	0
767144	765402	20056C	PARTICIPANT	\N	PRESENT	0
767145	765402	20136B	PARTICIPANT	\N	PRESENT	0
767146	765402	20058E	PARTICIPANT	\N	PRESENT	0
767147	765402	20070A	PARTICIPANT	\N	PRESENT	0
767148	765402	20044X	PARTICIPANT	\N	PRESENT	0
767149	765402	19575F	PARTICIPANT	\N	PRESENT	0
767150	765402	07029T	PARTICIPANT	\N	PRESENT	0
767151	765402	14147R	PARTICIPANT	\N	PRESENT	0
767152	765402	21087P	PARTICIPANT	\N	PRESENT	0
767153	765402	20066E	PARTICIPANT	\N	PRESENT	0
767154	765402	11056N	PARTICIPANT	\N	PRESENT	0
767155	765402	19479G	PARTICIPANT	\N	PRESENT	0
767156	765402	19387D	PARTICIPANT	\N	PRESENT	0
767157	765402	20030R	PARTICIPANT	\N	PRESENT	0
767158	765402	21085M	PARTICIPANT	\N	PRESENT	0
767164	765497	14331P	PARTICIPANT	\N	PRESENT	0
767165	765497	19349W	PARTICIPANT	\N	PRESENT	0
767166	765497	14253S	PARTICIPANT	\N	PRESENT	0
767167	765497	14225N	PRESIDENT	0	PRESENT	0
767168	765497	19399H	PARTICIPANT	\N	PRESENT	0
740472	738189	20126Y	PARTICIPANT	\N	PRESENT	0
740494	738189	20048C	PARTICIPANT	\N	PRESENT	0
740495	738189	08015R	PARTICIPANT	\N	EXCUSE	0
740496	738189	19467C	PARTICIPANT	\N	EXCUSE	0
740497	738189	08028W	PARTICIPANT	\N	EXCUSE	0
740498	738189	20060X	PARTICIPANT	\N	EXCUSE	0
740499	738189	14030Q	PARTICIPANT	\N	EXCUSE	0
740500	738189	16685X	PARTICIPANT	\N	EXCUSE	0
740501	738189	14105F	PARTICIPANT	\N	EXCUSE	0
740502	738189	19545Y	PARTICIPANT	\N	EXCUSE	0
740503	738189	14253S	PARTICIPANT	\N	EXCUSE	0
740504	738189	19866P	PARTICIPANT	\N	EXCUSE	0
740505	738189	19525U	PARTICIPANT	\N	EXCUSE	0
740510	738189	19575F	PARTICIPANT	\N	EXCUSE	0
740575	738334	14231L	PRESIDENT	0	PRESENT	0
740576	738334	19711U	PARTICIPANT	\N	PRESENT	0
740577	738334	14327T	PARTICIPANT	\N	PRESENT	0
740578	738334	14069U	PARTICIPANT	\N	PRESENT	0
740579	738334	19447X	PARTICIPANT	\N	PRESENT	0
740580	738334	19758L	PARTICIPANT	\N	PRESENT	0
740581	738334	17637T	PARTICIPANT	\N	PRESENT	0
740582	738334	20022R	PARTICIPANT	\N	PRESENT	0
740583	738334	14257W	PARTICIPANT	\N	PRESENT	0
740585	738334	19333N	PARTICIPANT	\N	PRESENT	0
740588	738334	14187A	PARTICIPANT	\N	PRESENT	0
740589	738334	20120S	PARTICIPANT	\N	PRESENT	0
740590	738334	19782L	PARTICIPANT	\N	EXCUSE	0
740591	738334	20090E	PARTICIPANT	\N	EXCUSE	0
740592	738334	19681G	PARTICIPANT	\N	EXCUSE	0
740593	738334	19735D	PARTICIPANT	\N	EXCUSE	0
740594	738334	19565D	PARTICIPANT	\N	EXCUSE	0
740595	738334	19489J	PARTICIPANT	\N	EXCUSE	0
740596	738334	08010L	PARTICIPANT	\N	EXCUSE	0
740597	738334	19563B	PARTICIPANT	\N	EXCUSE	0
740598	738334	19349W	PARTICIPANT	\N	EXCUSE	0
740599	738334	14229S	PARTICIPANT	\N	EXCUSE	0
740600	738334	04045F	PARTICIPANT	\N	EXCUSE	0
740601	738334	20062A	PARTICIPANT	\N	EXCUSE	0
740602	738334	20058E	PARTICIPANT	\N	EXCUSE	0
740607	738334	14215L	PARTICIPANT	\N	PRESENT	0
741953	740612	19866P	PARTICIPANT	\N	PRESENT	0
741954	740612	19747H	PARTICIPANT	\N	PRESENT	0
754529	753670	19367Y	PARTICIPANT	\N	PRESENT	0
754531	753670	20248J	PARTICIPANT	\N	PRESENT	0
754549	752395	20264J	PARTICIPANT	\N	PRESENT	0
754558	752395	19611R	PRESIDENT	0	PRESENT	0
754562	752395	21089R	PARTICIPANT	\N	PRESENT	0
754614	752395	14021P	PARTICIPANT	\N	PRESENT	0
754618	752395	19057M	PARTICIPANT	\N	PRESENT	0
754667	752395	19954N	PARTICIPANT	\N	PRESENT	0
756450	756449	14071N	PARTICIPANT	\N	PRESENT	0
756455	756454	14071N	PARTICIPANT	\N	PRESENT	0
756593	755844	20068G	PARTICIPANT	\N	PRESENT	0
756594	755844	20286Q	PARTICIPANT	\N	PRESENT	0
756595	755844	99004R	PARTICIPANT	\N	PRESENT	0
756596	755844	20024T	PARTICIPANT	\N	PRESENT	0
756597	755844	19349W	PARTICIPANT	\N	PRESENT	0
756598	755844	20018V	PARTICIPANT	\N	PRESENT	0
756599	755844	21083K	PARTICIPANT	\N	PRESENT	0
756600	755844	19399H	PARTICIPANT	\N	PRESENT	0
756601	755844	21084L	PARTICIPANT	\N	PRESENT	0
756602	755844	20082E	PARTICIPANT	\N	PRESENT	0
756603	755844	20106U	PARTICIPANT	\N	PRESENT	0
756604	755844	19703U	PARTICIPANT	\N	PRESENT	0
756605	755844	19711U	PARTICIPANT	\N	PRESENT	0
756606	755844	20044X	PARTICIPANT	\N	PRESENT	0
756607	755844	20132W	PARTICIPANT	\N	PRESENT	0
756608	755844	21093M	PARTICIPANT	\N	PRESENT	0
756609	755844	20060X	PARTICIPANT	\N	PRESENT	0
756610	755844	21054E	PARTICIPANT	\N	PRESENT	0
756611	755844	21041Y	PARTICIPANT	\N	PRESENT	0
756616	755844	20086J	PARTICIPANT	\N	EXCUSE	0
756617	755844	19747H	PARTICIPANT	\N	EXCUSE	0
756618	755844	21063F	PARTICIPANT	\N	EXCUSE	0
756619	755844	20140W	PARTICIPANT	\N	EXCUSE	0
756620	755844	14169X	PARTICIPANT	\N	EXCUSE	0
756621	755844	19798U	PARTICIPANT	\N	EXCUSE	0
756622	755844	20026V	PARTICIPANT	\N	EXCUSE	0
757900	757864	20140W	PARTICIPANT	\N	PRESENT	0
757901	757864	14071N	PARTICIPANT	\N	PRESENT	0
757902	757864	20096L	PARTICIPANT	\N	PRESENT	0
757903	757864	20130U	PARTICIPANT	\N	PRESENT	0
757904	757864	21087P	PARTICIPANT	\N	PRESENT	0
757905	757864	19703U	PARTICIPANT	\N	PRESENT	0
757906	757867	19758L	PARTICIPANT	\N	PRESENT	0
757907	757867	14213J	PARTICIPANT	\N	PRESENT	0
757908	757867	19683J	PARTICIPANT	\N	PRESENT	0
757909	757867	14042U	PARTICIPANT	\N	PRESENT	0
757910	757867	21081H	PARTICIPANT	\N	PRESENT	0
757911	757867	14026U	PARTICIPANT	\N	PRESENT	0
757912	757867	21046E	PARTICIPANT	\N	PRESENT	0
757913	757867	18193Q	PARTICIPANT	\N	PRESENT	0
757914	757867	20130U	PARTICIPANT	\N	PRESENT	0
757915	757867	21094N	PARTICIPANT	\N	PRESENT	0
757916	757867	04092N	PARTICIPANT	\N	PRESENT	0
761390	761388	14169X	PARTICIPANT	\N	PRESENT	0
761477	761172	20124W	PARTICIPANT	\N	PRESENT	0
761478	761172	19611R	PARTICIPANT	\N	PRESENT	0
761501	761500	20058E	PARTICIPANT	\N	PRESENT	0
761502	761500	20264J	PARTICIPANT	\N	PRESENT	0
762511	762509	20126Y	PARTICIPANT	\N	PRESENT	0
762280	762277	20286Q	PARTICIPANT	\N	PRESENT	0
762281	762278	20286Q	PARTICIPANT	\N	PRESENT	0
762282	762279	20286Q	PARTICIPANT	\N	PRESENT	0
762506	762505	20126Y	PARTICIPANT	\N	PRESENT	0
762507	762505	12016W	PARTICIPANT	\N	PRESENT	0
762512	762509	12016W	PARTICIPANT	\N	PRESENT	0
762516	762515	20126Y	PARTICIPANT	\N	PRESENT	0
762517	762515	12016W	PARTICIPANT	\N	PRESENT	0
762522	762521	20126Y	PARTICIPANT	\N	PRESENT	0
762523	762521	12016W	PARTICIPANT	\N	PRESENT	0
762528	762526	20090E	PARTICIPANT	\N	PRESENT	0
762529	762526	21049H	PARTICIPANT	\N	PRESENT	0
762530	762526	19760E	PARTICIPANT	\N	PRESENT	0
762537	762535	20090E	PARTICIPANT	\N	PRESENT	0
762539	762535	21045D	PARTICIPANT	\N	PRESENT	0
762544	762541	20126Y	PARTICIPANT	\N	PRESENT	0
762545	762541	12016W	PARTICIPANT	\N	PRESENT	0
762549	762548	20126Y	PARTICIPANT	\N	PRESENT	0
762550	762548	12016W	PARTICIPANT	\N	PRESENT	0
762553	762552	20126Y	PARTICIPANT	\N	PRESENT	0
762554	762552	12016W	PARTICIPANT	\N	PRESENT	0
762564	762562	21069M	PARTICIPANT	\N	PRESENT	0
762568	762567	08011M	PARTICIPANT	\N	PRESENT	0
762577	762576	08011M	PARTICIPANT	\N	PRESENT	0
765804	765398	19301E	PARTICIPANT	\N	PRESENT	0
765805	765398	19591F	PARTICIPANT	\N	PRESENT	0
765806	765398	21049H	PARTICIPANT	\N	PRESENT	0
765807	765398	07004J	PARTICIPANT	\N	PRESENT	0
765811	765398	19723Y	PARTICIPANT	\N	PRESENT	0
765813	765398	21094N	PARTICIPANT	\N	PRESENT	0
765820	765398	19553Y	PARTICIPANT	\N	PRESENT	0
765822	765398	20038A	PARTICIPANT	\N	PRESENT	0
765823	765398	11045K	PARTICIPANT	\N	PRESENT	0
765824	765398	21045D	PARTICIPANT	\N	PRESENT	0
765825	765398	21054E	PARTICIPANT	\N	PRESENT	0
765826	765398	21039F	PARTICIPANT	\N	PRESENT	0
765827	765398	14121F	PARTICIPANT	\N	PRESENT	0
765828	765398	20140W	PARTICIPANT	\N	PRESENT	0
765829	765398	21071F	PARTICIPANT	\N	PRESENT	0
765830	765398	21097R	PARTICIPANT	\N	PRESENT	0
765831	765398	19782L	PARTICIPANT	\N	PRESENT	0
765832	765398	14259Y	PARTICIPANT	\N	PRESENT	0
765837	765398	14107H	PARTICIPANT	\N	PRESENT	0
765838	765398	21064G	PARTICIPANT	\N	PRESENT	0
765839	765398	14191V	PARTICIPANT	\N	PRESENT	0
765840	765398	19347U	PARTICIPANT	\N	PRESENT	0
765841	765398	14257W	PARTICIPANT	\N	PRESENT	0
765851	765398	20148F	PARTICIPANT	\N	PRESENT	0
765856	765398	19295A	PARTICIPANT	\N	PRESENT	0
765857	765398	19687N	PARTICIPANT	\N	PRESENT	0
765858	765398	19713W	PARTICIPANT	\N	PRESENT	0
765859	765398	21040X	PARTICIPANT	\N	PRESENT	0
765860	765398	20044X	PARTICIPANT	\N	PRESENT	0
765866	765398	14037X	PARTICIPANT	\N	PRESENT	0
765867	765398	11085T	PARTICIPANT	\N	PRESENT	0
765868	765398	11064N	PARTICIPANT	\N	PRESENT	0
765869	765398	19749K	PARTICIPANT	\N	PRESENT	0
765870	765398	20048C	PARTICIPANT	\N	PRESENT	0
765871	765398	21056G	PARTICIPANT	\N	PRESENT	0
765872	765398	20114U	PARTICIPANT	\N	PRESENT	0
757678	755867	19347U	PARTICIPANT	\N	PRESENT	0
757679	755867	17367Q	PARTICIPANT	\N	PRESENT	0
757680	755867	14249W	PARTICIPANT	\N	PRESENT	0
757681	755867	14037X	PARTICIPANT	\N	PRESENT	0
757682	755867	19647E	PARTICIPANT	\N	PRESENT	0
757683	755867	21073H	PARTICIPANT	\N	PRESENT	0
757684	755867	21041Y	PARTICIPANT	\N	PRESENT	0
757685	755867	20064C	PARTICIPANT	\N	PRESENT	0
757686	755867	98022P	PARTICIPANT	\N	PRESENT	0
757687	755867	19745F	PARTICIPANT	\N	PRESENT	0
759749	759746	19719D	PARTICIPANT	\N	PRESENT	0
759752	759750	19719D	PARTICIPANT	\N	PRESENT	0
760520	757696	14217N	PARTICIPANT	\N	PRESENT	0
760521	757696	01034P	PARTICIPANT	\N	PRESENT	0
760522	757696	21097R	PARTICIPANT	\N	PRESENT	0
760523	757696	14213J	PARTICIPANT	\N	PRESENT	0
760524	757696	20090E	PARTICIPANT	\N	PRESENT	0
760525	757696	14071N	PRESIDENT	0	PRESENT	0
760526	757696	14042U	PARTICIPANT	\N	PRESENT	0
760529	757696	14026U	PARTICIPANT	\N	PRESENT	0
760531	757696	21081H	PARTICIPANT	\N	PRESENT	0
760534	757696	14223L	PARTICIPANT	\N	PRESENT	0
760536	757696	21045D	PARTICIPANT	\N	PRESENT	0
760538	757696	19758L	PARTICIPANT	\N	PRESENT	0
760541	757696	19760E	PARTICIPANT	\N	PRESENT	0
760551	757696	14281W	PARTICIPANT	\N	PRESENT	0
760574	757696	21064G	PARTICIPANT	\N	PRESENT	0
760577	757696	21046E	PARTICIPANT	\N	PRESENT	0
760578	760560	14033T	PARTICIPANT	\N	PRESENT	0
760579	760560	20018V	PARTICIPANT	\N	PRESENT	0
760580	760560	19575F	PARTICIPANT	\N	PRESENT	0
760581	760561	14033T	PARTICIPANT	\N	PRESENT	0
760582	760561	19575F	PARTICIPANT	\N	PRESENT	0
760584	760561	21033Y	PARTICIPANT	\N	PRESENT	0
760585	760561	14357A	PARTICIPANT	\N	PRESENT	0
760586	760562	14033T	PARTICIPANT	\N	PRESENT	0
760588	760562	19575F	PARTICIPANT	\N	PRESENT	0
760589	760562	21033Y	PARTICIPANT	\N	PRESENT	0
760590	760562	14357A	PARTICIPANT	\N	PRESENT	0
760591	760564	14033T	PARTICIPANT	\N	PRESENT	0
760592	760564	19575F	PARTICIPANT	\N	PRESENT	0
760594	760564	20018V	PARTICIPANT	\N	PRESENT	0
760595	760564	14357A	PARTICIPANT	\N	PRESENT	0
760596	760565	14033T	PARTICIPANT	\N	PRESENT	0
760597	760565	19575F	PARTICIPANT	\N	PRESENT	0
760599	760565	20018V	PARTICIPANT	\N	PRESENT	0
760600	760565	14357A	PARTICIPANT	\N	PRESENT	0
760601	757696	11045K	PARTICIPANT	\N	PRESENT	0
760602	760566	14033T	PARTICIPANT	\N	PRESENT	0
760603	760566	19575F	PARTICIPANT	\N	PRESENT	0
760604	760566	20018V	PARTICIPANT	\N	PRESENT	0
760605	760566	14357A	PARTICIPANT	\N	PRESENT	0
760607	760568	14033T	PARTICIPANT	\N	PRESENT	0
760608	760569	14033T	PARTICIPANT	\N	PRESENT	0
760624	760515	14331P	PARTICIPANT	\N	PRESENT	0
760628	760515	19569H	PARTICIPANT	\N	PRESENT	0
760626	760515	14001X	PARTICIPANT	\N	PRESENT	0
760627	760515	14073Q	PARTICIPANT	\N	PRESENT	0
760629	760515	20100N	PARTICIPANT	\N	PRESENT	0
760842	760823	14331P	PARTICIPANT	\N	PRESENT	0
760843	760823	19479G	PARTICIPANT	\N	PRESENT	0
760844	760823	20134Y	PARTICIPANT	\N	PRESENT	0
760987	760928	14073Q	PARTICIPANT	\N	PRESENT	0
760846	760823	19711U	PARTICIPANT	\N	PRESENT	0
760988	760928	21058J	PARTICIPANT	\N	PRESENT	0
760848	760823	19545Y	PARTICIPANT	\N	PRESENT	0
760849	760823	20080C	PARTICIPANT	\N	PRESENT	0
760850	760823	11074Q	PARTICIPANT	\N	PRESENT	0
760989	760928	14030Q	PARTICIPANT	\N	PRESENT	0
760852	760823	14225N	PRESIDENT	0	PRESENT	0
760853	760823	21041Y	PARTICIPANT	\N	PRESENT	0
760854	760823	11040E	PARTICIPANT	\N	PRESENT	0
760855	760823	07029T	PARTICIPANT	\N	PRESENT	0
760856	760823	20062A	PARTICIPANT	\N	PRESENT	0
760990	760928	21063F	PARTICIPANT	\N	PRESENT	0
760995	760928	19611R	PARTICIPANT	\N	EXCUSE	0
760996	760928	08012N	PARTICIPANT	\N	EXCUSE	0
760860	760823	20024T	PARTICIPANT	\N	PRESENT	0
760861	760823	21048G	PARTICIPANT	\N	PRESENT	0
760862	760823	20126Y	PARTICIPANT	\N	PRESENT	0
760997	760928	21091K	PARTICIPANT	\N	EXCUSE	0
760998	760928	20102Q	PARTICIPANT	\N	EXCUSE	0
760865	760823	12016W	PARTICIPANT	\N	EXCUSE	0
760866	760823	20050V	PARTICIPANT	\N	EXCUSE	0
761014	761008	19735D	PARTICIPANT	\N	PRESENT	0
761015	761008	18395Y	PARTICIPANT	\N	PRESENT	0
761016	761011	18395Y	PARTICIPANT	\N	PRESENT	0
761017	761011	19735D	PARTICIPANT	\N	PRESENT	0
761018	761002	18395Y	PARTICIPANT	\N	PRESENT	0
761019	761002	19735D	PARTICIPANT	\N	PRESENT	0
761020	761002	21089R	PARTICIPANT	\N	PRESENT	0
761024	761003	19735D	PARTICIPANT	\N	PRESENT	0
761022	761003	18395Y	PARTICIPANT	\N	PRESENT	0
761023	761003	21089R	PARTICIPANT	\N	PRESENT	0
761026	761025	20124W	PARTICIPANT	\N	PRESENT	0
761027	761025	14109K	PARTICIPANT	\N	PRESENT	0
761028	761025	19735D	PARTICIPANT	\N	PRESENT	0
761537	759474	21035B	PARTICIPANT	\N	EXCUSE	0
761742	761741	20040T	PARTICIPANT	\N	PRESENT	0
761744	761743	20040T	PARTICIPANT	\N	PRESENT	0
761749	761748	19507S	PARTICIPANT	\N	PRESENT	1
761750	761748	19563B	PARTICIPANT	\N	PRESENT	1
761752	761751	19507S	PARTICIPANT	\N	PRESENT	0
761902	761901	19479G	PARTICIPANT	\N	PRESENT	0
761905	761904	19479G	PARTICIPANT	\N	PRESENT	0
761912	761911	11070L	PARTICIPANT	\N	PRESENT	0
761914	761913	11070L	PARTICIPANT	\N	PRESENT	0
761916	761915	11070L	PARTICIPANT	\N	PRESENT	0
761922	761920	19667J	PARTICIPANT	\N	PRESENT	0
761923	761920	11040E	PARTICIPANT	\N	PRESENT	0
761941	761937	19667J	PARTICIPANT	\N	PRESENT	0
761942	761937	11040E	PARTICIPANT	\N	PRESENT	0
761946	761945	19667J	PARTICIPANT	\N	PRESENT	0
761947	761945	11040E	PARTICIPANT	\N	PRESENT	0
761950	761949	19545Y	PARTICIPANT	\N	PRESENT	0
761951	761949	21079P	PARTICIPANT	\N	PRESENT	0
761953	761952	19545Y	PARTICIPANT	\N	PRESENT	0
761954	761952	21079P	PARTICIPANT	\N	PRESENT	0
761956	761955	19545Y	PARTICIPANT	\N	PRESENT	0
761957	761955	21079P	PARTICIPANT	\N	PRESENT	0
762288	762287	19563B	PARTICIPANT	\N	PRESENT	0
762289	762287	19507S	PARTICIPANT	\N	PRESENT	0
762290	757754	08012N	PARTICIPANT	\N	PRESENT	0
762291	757754	21077M	PARTICIPANT	\N	PRESENT	0
762292	757754	21063F	PARTICIPANT	\N	PRESENT	0
762294	762293	19533U	PARTICIPANT	\N	PRESENT	0
762295	762293	21063F	PARTICIPANT	\N	PRESENT	0
763297	763253	20120S	PARTICIPANT	\N	PRESENT	0
763299	763298	20120S	PARTICIPANT	\N	PRESENT	0
763301	762589	21096Q	PARTICIPANT	\N	PRESENT	0
763302	762589	20034V	PARTICIPANT	\N	PRESENT	0
763303	762589	21075K	PARTICIPANT	\N	PRESENT	0
763304	762589	20082E	PARTICIPANT	\N	PRESENT	0
763310	761567	14053L	PARTICIPANT	\N	PRESENT	0
763311	761567	20074E	PARTICIPANT	\N	PRESENT	0
763312	761567	19673G	PARTICIPANT	\N	PRESENT	0
763313	761567	21044C	PARTICIPANT	\N	PRESENT	0
763314	761567	19111A	PARTICIPANT	\N	PRESENT	0
763315	761567	21043B	PARTICIPANT	\N	PRESENT	0
763316	761567	18231D	PARTICIPANT	\N	PRESENT	0
763317	761567	04047H	PRESIDENT	0	PRESENT	0
763318	761567	11056N	PARTICIPANT	\N	PRESENT	0
763319	761567	14147R	PARTICIPANT	\N	PRESENT	0
763320	761567	14189C	PARTICIPANT	\N	PRESENT	0
763321	761567	08018U	PARTICIPANT	\N	PRESENT	0
763322	761567	20266L	PARTICIPANT	\N	PRESENT	0
764237	761747	14169X	PARTICIPANT	\N	EXCUSE	0
764264	764263	20286Q	PARTICIPANT	\N	PRESENT	0
764791	761964	14231L	PRESIDENT	0	PRESENT	0
764793	761964	19489J	PARTICIPANT	\N	PRESENT	0
764794	761964	20084G	PARTICIPANT	\N	PRESENT	0
764795	761964	19782L	PARTICIPANT	\N	PRESENT	0
764796	761964	19735D	PARTICIPANT	\N	PRESENT	0
742926	740616	19725B	PARTICIPANT	\N	PRESENT	0
742927	740616	19643A	PARTICIPANT	\N	PRESENT	0
742928	740616	14223L	PARTICIPANT	\N	PRESENT	0
742929	740616	19531S	PARTICIPANT	\N	PRESENT	0
742930	740616	04071H	PARTICIPANT	\N	PRESENT	0
742931	740616	17367Q	PARTICIPANT	\N	PRESENT	0
742932	740616	18193Q	PARTICIPANT	\N	PRESENT	0
742933	740616	20086J	PARTICIPANT	\N	PRESENT	0
742934	740616	11026G	PARTICIPANT	\N	PRESENT	0
742935	740616	10015M	PARTICIPANT	\N	PRESENT	0
742936	740616	01048V	PARTICIPANT	\N	PRESENT	0
742937	740616	11090Q	PARTICIPANT	\N	PRESENT	0
742938	740616	14257W	PARTICIPANT	\N	PRESENT	0
742939	740616	05012A	PARTICIPANT	\N	PRESENT	0
742940	740616	20030R	PARTICIPANT	\N	PRESENT	0
742941	740616	19679N	PARTICIPANT	\N	PRESENT	0
742942	740616	17965H	PARTICIPANT	\N	PRESENT	0
742943	740616	19503N	PARTICIPANT	\N	PRESENT	0
742944	740616	20138D	PARTICIPANT	\N	PRESENT	0
742945	740616	08015R	PARTICIPANT	\N	PRESENT	0
742946	740616	14225N	PARTICIPANT	\N	PRESENT	0
742947	740616	19729F	PARTICIPANT	\N	PRESENT	0
742948	740616	19399H	PARTICIPANT	\N	PRESENT	0
742949	740616	20082E	PARTICIPANT	\N	PRESENT	0
742950	740616	19669L	PARTICIPANT	\N	PRESENT	0
742951	740616	20104S	PARTICIPANT	\N	PRESENT	0
742952	740616	19413M	PARTICIPANT	\N	PRESENT	0
742953	740616	19768N	PARTICIPANT	\N	PRESENT	0
742954	740616	20024T	PARTICIPANT	\N	PRESENT	0
742955	740616	20064C	PARTICIPANT	\N	PRESENT	0
742956	740616	14213J	PARTICIPANT	\N	PRESENT	0
742957	740616	11041F	PARTICIPANT	\N	PRESENT	0
742958	740616	19527W	PARTICIPANT	\N	PRESENT	0
742959	740616	11066Q	PARTICIPANT	\N	PRESENT	0
742960	740616	14329V	PARTICIPANT	\N	PRESENT	0
742961	740616	14059S	PARTICIPANT	\N	PRESENT	0
742962	740616	08056B	PARTICIPANT	\N	PRESENT	0
742963	740616	20124W	PARTICIPANT	\N	PRESENT	0
742964	740616	20054A	PARTICIPANT	\N	PRESENT	0
742965	740616	19543W	PARTICIPANT	\N	PRESENT	0
742966	740616	20252E	PARTICIPANT	\N	PRESENT	0
742967	740616	14217N	PARTICIPANT	\N	PRESENT	0
742968	740616	20020P	PARTICIPANT	\N	PRESENT	0
742969	740616	20136B	PARTICIPANT	\N	PRESENT	0
742970	740616	07033P	PARTICIPANT	\N	PRESENT	0
742971	740616	11103C	PARTICIPANT	\N	PRESENT	0
742972	740616	97011G	PARTICIPANT	\N	PRESENT	0
742973	740616	14357A	PARTICIPANT	\N	PRESENT	0
742974	740616	14331P	PARTICIPANT	\N	PRESENT	0
742975	740616	20032T	PARTICIPANT	\N	PRESENT	0
742976	740616	17737W	PARTICIPANT	\N	PRESENT	0
742977	740616	20172F	PARTICIPANT	\N	PRESENT	0
742978	740616	14189C	PARTICIPANT	\N	PRESENT	0
742979	740616	08047A	PARTICIPANT	\N	PRESENT	0
742980	740616	14030Q	PARTICIPANT	\N	PRESENT	0
742981	740616	04035D	PARTICIPANT	\N	PRESENT	0
742982	740616	20118Y	PARTICIPANT	\N	PRESENT	0
742983	740616	14255U	PARTICIPANT	\N	PRESENT	0
742984	740616	14083S	PARTICIPANT	\N	PRESENT	0
742985	740616	11053K	PARTICIPANT	\N	PRESENT	0
742986	740616	19721W	PARTICIPANT	\N	PRESENT	0
742987	740616	10006L	PARTICIPANT	\N	PRESENT	0
742988	740616	19798U	PARTICIPANT	\N	PRESENT	0
742989	740616	14327T	PARTICIPANT	\N	PRESENT	0
742990	740616	95041E	PARTICIPANT	\N	PRESENT	0
742991	740616	01024M	PARTICIPANT	\N	PRESENT	0
742992	740616	20126Y	PARTICIPANT	\N	PRESENT	0
742993	740616	19671E	PARTICIPANT	\N	PRESENT	0
742994	740616	14042U	PARTICIPANT	\N	PRESENT	0
742995	740616	20040T	PARTICIPANT	\N	PRESENT	0
742996	740616	14193X	PARTICIPANT	\N	PRESENT	0
742997	740616	20248J	PARTICIPANT	\N	PRESENT	0
742998	740616	14237S	PARTICIPANT	\N	PRESENT	0
742999	740616	01025N	PARTICIPANT	\N	PRESENT	0
743000	740616	14053L	PARTICIPANT	\N	PRESENT	0
743001	740616	14069U	PARTICIPANT	\N	PRESENT	0
743002	740616	19701S	PARTICIPANT	\N	PRESENT	0
743003	740616	14231L	PARTICIPANT	\N	PRESENT	0
743004	740616	07004J	PARTICIPANT	\N	PRESENT	0
743005	740616	04043D	PARTICIPANT	\N	PRESENT	0
743006	740616	04033B	PARTICIPANT	\N	PRESENT	0
743007	740616	14187A	PARTICIPANT	\N	PRESENT	0
743008	740616	14071N	PARTICIPANT	\N	PRESENT	0
743009	740616	05008E	PARTICIPANT	\N	PRESENT	0
743010	740616	11097X	PARTICIPANT	\N	PRESENT	0
743011	740616	19747H	PARTICIPANT	\N	PRESENT	0
743012	740616	08034U	PARTICIPANT	\N	PRESENT	0
743013	740616	11048N	PARTICIPANT	\N	PRESENT	0
743014	740616	08010L	PARTICIPANT	\N	PRESENT	0
743015	740616	20048C	PARTICIPANT	\N	PRESENT	0
743016	740616	20052X	PARTICIPANT	\N	PRESENT	0
743017	740616	19703U	PARTICIPANT	\N	PRESENT	0
743018	740616	19699S	PARTICIPANT	\N	PRESENT	0
743019	740616	14026U	PARTICIPANT	\N	PRESENT	0
743020	740616	14179A	PARTICIPANT	\N	PRESENT	0
743021	740616	08011M	PARTICIPANT	\N	PRESENT	0
743022	740616	19685L	PARTICIPANT	\N	PRESENT	0
743023	740616	19575F	PARTICIPANT	\N	PRESENT	0
743024	740616	20078J	PARTICIPANT	\N	PRESENT	0
743025	740616	19611R	PARTICIPANT	\N	PRESENT	0
743026	740616	16685X	PARTICIPANT	\N	PRESENT	0
743027	740616	14205J	PARTICIPANT	\N	PRESENT	0
743028	740616	19441R	PARTICIPANT	\N	PRESENT	0
743029	740616	11085T	PARTICIPANT	\N	PRESENT	0
743030	740616	19826F	PARTICIPANT	\N	PRESENT	0
743031	740616	18083K	PARTICIPANT	\N	PRESENT	0
743032	740616	19335Q	PARTICIPANT	\N	PRESENT	0
743033	740616	14123H	PARTICIPANT	\N	PRESENT	0
743034	740616	08069G	PARTICIPANT	\N	PRESENT	0
743035	740616	19369B	PARTICIPANT	\N	PRESENT	0
743036	740616	04042C	PARTICIPANT	\N	PRESENT	0
743038	740616	19691J	PARTICIPANT	\N	PRESENT	0
743039	740616	20298U	PARTICIPANT	\N	PRESENT	0
743040	740616	17023S	PARTICIPANT	\N	PRESENT	0
743041	740616	19713W	PARTICIPANT	\N	PRESENT	0
743042	740616	20022R	PARTICIPANT	\N	PRESENT	0
743043	740616	01034P	PARTICIPANT	\N	PRESENT	0
743044	740616	20286Q	PARTICIPANT	\N	PRESENT	0
743045	740616	14215L	PARTICIPANT	\N	PRESENT	0
743046	740616	20120S	PARTICIPANT	\N	PRESENT	0
743047	740616	19705W	PARTICIPANT	\N	PRESENT	0
743048	740616	19707Y	PARTICIPANT	\N	PRESENT	0
743049	740616	20108W	PARTICIPANT	\N	PRESENT	0
743050	740616	11043H	PARTICIPANT	\N	PRESENT	0
743051	740616	19421M	PARTICIPANT	\N	PRESENT	0
743052	740616	20180F	PARTICIPANT	\N	PRESENT	0
743053	740616	20094J	PARTICIPANT	\N	PRESENT	0
743054	740616	19745F	PARTICIPANT	\N	PRESENT	0
743058	740616	19057M	PARTICIPANT	\N	PRESENT	0
743056	740616	19507S	PARTICIPANT	\N	PRESENT	0
743057	740616	19551W	PARTICIPANT	\N	PRESENT	0
743059	740616	14133K	PARTICIPANT	\N	PRESENT	0
743060	740616	14147R	PARTICIPANT	\N	PRESENT	0
743061	740616	19723Y	PARTICIPANT	\N	PRESENT	0
743062	740616	11065P	PARTICIPANT	\N	PRESENT	0
743063	740616	08018U	PARTICIPANT	\N	PRESENT	0
743064	740616	19647E	PARTICIPANT	\N	PRESENT	0
743065	740616	14001X	PARTICIPANT	\N	PRESENT	0
743067	740616	11109J	PARTICIPANT	\N	PRESENT	0
756932	752397	19693L	PARTICIPANT	\N	PRESENT	0
757437	752397	19621T	PARTICIPANT	\N	PRESENT	0
757617	757083	21050A	PARTICIPANT	\N	PRESENT	0
757618	757083	20078J	PARTICIPANT	\N	PRESENT	0
757619	757083	20088L	PARTICIPANT	\N	PRESENT	0
757620	757083	21088Q	PARTICIPANT	\N	EXCUSE	0
757621	757083	21045D	PARTICIPANT	\N	PRESENT	0
757622	757083	20144B	PARTICIPANT	\N	PRESENT	0
757623	757083	19295A	PARTICIPANT	\N	PRESENT	0
757624	757083	14357A	PRESIDENT	0	PRESENT	0
757625	757083	21067K	PARTICIPANT	\N	PRESENT	0
757626	757083	20248J	PARTICIPANT	\N	PRESENT	0
757627	757083	20172F	PARTICIPANT	\N	PRESENT	0
757628	757083	19347U	PARTICIPANT	\N	PRESENT	0
757629	757083	21092L	PARTICIPANT	\N	PRESENT	0
757630	757083	21044C	PARTICIPANT	\N	PRESENT	0
757631	757083	20056C	PARTICIPANT	\N	PRESENT	0
757632	757083	20126Y	PARTICIPANT	\N	PRESENT	0
757633	757083	08015R	PARTICIPANT	\N	PRESENT	0
757634	757083	19697Q	PARTICIPANT	\N	PRESENT	0
757635	757083	21058J	PARTICIPANT	\N	PRESENT	0
757636	757083	21040X	PARTICIPANT	\N	PRESENT	0
757637	757083	19563B	PARTICIPANT	\N	PRESENT	0
757638	757083	20028X	PARTICIPANT	\N	PRESENT	0
757639	757083	21080G	PARTICIPANT	\N	PRESENT	0
757640	757083	21039F	PARTICIPANT	\N	PRESENT	0
757641	757083	14237S	PARTICIPANT	\N	PRESENT	0
757642	757083	21047F	PARTICIPANT	\N	PRESENT	0
757643	757083	20030R	PARTICIPANT	\N	PRESENT	0
757644	757083	20054A	PRESIDENT	1	PRESENT	0
757645	757083	21064G	PARTICIPANT	\N	PRESENT	0
757646	757083	21061D	PARTICIPANT	\N	PRESENT	0
757647	757083	20104S	PARTICIPANT	\N	EXCUSE	0
757648	757083	19719D	PARTICIPANT	\N	EXCUSE	0
757649	757083	20038A	PARTICIPANT	\N	EXCUSE	0
757689	757035	21045D	PARTICIPANT	\N	PRESENT	0
757653	757651	08047A	PARTICIPANT	\N	PRESENT	0
757688	757035	19798U	PARTICIPANT	\N	PRESENT	0
757690	757035	19758L	PARTICIPANT	\N	PRESENT	0
757691	757035	20130U	PARTICIPANT	\N	PRESENT	0
757700	757698	20172F	PARTICIPANT	\N	PRESENT	0
757701	757698	19693L	PARTICIPANT	\N	PRESENT	0
757702	757698	19593H	PARTICIPANT	\N	PRESENT	0
757703	757698	21059K	PARTICIPANT	\N	PRESENT	0
757704	757699	20172F	PARTICIPANT	\N	PRESENT	0
757705	757699	19593H	PARTICIPANT	\N	PRESENT	0
759476	757715	14026U	PARTICIPANT	\N	PRESENT	0
757707	757699	21059K	PARTICIPANT	\N	PRESENT	0
759475	757715	14097Y	PARTICIPANT	\N	PRESENT	0
759477	757715	19683J	PARTICIPANT	\N	PRESENT	0
759478	757715	08034U	PARTICIPANT	\N	PRESENT	0
759479	757715	20100N	PARTICIPANT	\N	PRESENT	0
759480	757715	14001X	PARTICIPANT	\N	PRESENT	0
767171	765497	11048N	PARTICIPANT	\N	PRESENT	0
759482	757715	14331P	PRESIDENT	0	PRESENT	0
759483	757715	21037D	PARTICIPANT	\N	PRESENT	0
759484	757715	14237S	PARTICIPANT	\N	PRESENT	0
759485	757715	21049H	PARTICIPANT	\N	PRESENT	0
759486	757715	19760E	PARTICIPANT	\N	PRESENT	0
759487	757715	20042V	PARTICIPANT	\N	PRESENT	0
759488	757715	17737W	PARTICIPANT	\N	PRESENT	0
759489	757715	20104S	PARTICIPANT	\N	PRESENT	0
759490	757715	19701S	PARTICIPANT	\N	PRESENT	0
759491	757715	18395Y	PARTICIPANT	\N	PRESENT	0
759492	757715	21032X	PARTICIPANT	\N	PRESENT	0
759493	757715	14033T	PARTICIPANT	\N	PRESENT	0
759494	757715	20106U	PARTICIPANT	\N	PRESENT	0
759495	757715	14073Q	PARTICIPANT	\N	PRESENT	0
759496	757715	18207D	PARTICIPANT	\N	PRESENT	0
759497	757715	21054E	PARTICIPANT	\N	PRESENT	0
759498	757715	21082J	PARTICIPANT	\N	PRESENT	0
767169	765497	07004J	PARTICIPANT	\N	PRESENT	0
767170	765497	11053K	PARTICIPANT	\N	PRESENT	0
767172	765497	20024T	PARTICIPANT	\N	PRESENT	0
767173	765497	21079P	PARTICIPANT	\N	PRESENT	0
767174	765175	20264J	PARTICIPANT	\N	PRESENT	0
767175	765175	04047H	PRESIDENT	0	PRESENT	0
767177	765497	19711U	PARTICIPANT	\N	PRESENT	0
767178	765497	20080C	PARTICIPANT	\N	PRESENT	0
767179	765497	14173T	PARTICIPANT	\N	PRESENT	0
767180	765497	20062A	PARTICIPANT	\N	PRESENT	0
767181	765497	08009T	PARTICIPANT	\N	PRESENT	0
767182	765497	19667J	PARTICIPANT	\N	PRESENT	0
767183	765497	20044X	PARTICIPANT	\N	PRESENT	0
767184	765497	19479G	PARTICIPANT	\N	PRESENT	0
767185	765175	14111D	PARTICIPANT	\N	PRESENT	0
767186	765175	20036X	PARTICIPANT	\N	PRESENT	0
767187	765175	14189C	PARTICIPANT	\N	PRESENT	0
767188	765175	20074E	PARTICIPANT	\N	PRESENT	0
767189	765175	19673G	PARTICIPANT	\N	PRESENT	0
767190	765175	05008E	PARTICIPANT	\N	PRESENT	0
767191	765175	19725B	PARTICIPANT	\N	PRESENT	0
767192	765175	14089Y	PARTICIPANT	\N	PRESENT	0
767193	765175	21043B	PARTICIPANT	\N	PRESENT	0
767194	765175	21044C	PARTICIPANT	\N	PRESENT	0
767195	765175	11056N	PARTICIPANT	\N	PRESENT	0
767196	765175	19489J	PARTICIPANT	\N	PRESENT	0
767197	765175	14275Y	PARTICIPANT	\N	PRESENT	0
767198	765175	18207D	PARTICIPANT	\N	PRESENT	0
767199	765175	14147R	PARTICIPANT	\N	PRESENT	0
767200	765175	21088Q	PARTICIPANT	\N	PRESENT	0
767201	765175	20114U	PARTICIPANT	\N	PRESENT	0
767202	765175	04008A	PARTICIPANT	\N	PRESENT	0
767203	765175	21095P	PARTICIPANT	\N	PRESENT	0
767204	765497	08034U	PARTICIPANT	\N	PRESENT	0
767205	765497	20126Y	PARTICIPANT	\N	PRESENT	0
767206	765175	19447X	PARTICIPANT	\N	PRESENT	0
767207	765175	19729F	PARTICIPANT	\N	EXCUSE	0
767208	765175	21076L	PARTICIPANT	\N	EXCUSE	0
767209	765175	14215L	PARTICIPANT	\N	EXCUSE	0
767210	765175	04045F	PARTICIPANT	\N	EXCUSE	0
767211	765175	20022R	PARTICIPANT	\N	EXCUSE	0
767212	765175	11072N	PARTICIPANT	\N	EXCUSE	0
767213	765497	20070A	PARTICIPANT	\N	PRESENT	0
767214	765497	11070L	PARTICIPANT	\N	PRESENT	0
767215	765497	19687N	PARTICIPANT	\N	PRESENT	0
767216	765497	08010L	PARTICIPANT	\N	PRESENT	0
767217	763071	19699S	PARTICIPANT	\N	PRESENT	0
767218	763071	19533U	PARTICIPANT	\N	PRESENT	0
767219	763071	21058J	PARTICIPANT	\N	PRESENT	0
767220	763071	21059K	PARTICIPANT	\N	PRESENT	0
767221	763071	20102Q	PARTICIPANT	\N	PRESENT	0
767222	763071	14229S	PARTICIPANT	\N	PRESENT	0
767223	763071	19954N	PARTICIPANT	\N	PRESENT	0
767224	763071	18395Y	PARTICIPANT	\N	PRESENT	0
767225	763071	20112S	PARTICIPANT	\N	PRESENT	0
767226	763071	21089R	PARTICIPANT	\N	PRESENT	0
767227	763071	20016T	PARTICIPANT	\N	PRESENT	0
767228	763071	08012N	PARTICIPANT	\N	PRESENT	0
767229	763071	21037D	PARTICIPANT	\N	PRESENT	0
767230	763071	21091K	PARTICIPANT	\N	PRESENT	0
767231	763071	20124W	PARTICIPANT	\N	PRESENT	0
767232	763071	20026V	PARTICIPANT	\N	PRESENT	0
767233	763071	19593H	PARTICIPANT	\N	PRESENT	0
767234	763071	20132W	PARTICIPANT	\N	PRESENT	0
767235	763071	21055F	PARTICIPANT	\N	PRESENT	0
767236	763071	14073Q	PARTICIPANT	\N	PRESENT	0
767237	763071	20138D	PARTICIPANT	\N	PRESENT	0
767238	763071	19611R	PRESIDENT	0	PRESENT	0
767239	763071	20142Y	PARTICIPANT	\N	PRESENT	0
767240	763071	20048C	PARTICIPANT	\N	PRESENT	0
767241	763071	19693L	PARTICIPANT	\N	PRESENT	0
767242	763071	20052X	PARTICIPANT	\N	PRESENT	0
767243	763071	20056C	PARTICIPANT	\N	PRESENT	0
767244	763071	20180F	PARTICIPANT	\N	PRESENT	0
767245	763071	21063F	PARTICIPANT	\N	PRESENT	0
767246	763071	14109K	PARTICIPANT	\N	PRESENT	0
767247	763071	14123H	PARTICIPANT	\N	PRESENT	0
767248	763071	21077M	PARTICIPANT	\N	PRESENT	0
767249	765175	20110Q	PARTICIPANT	\N	PRESENT	0
767250	765175	19111A	PARTICIPANT	\N	PRESENT	0
767251	765175	14151M	PARTICIPANT	\N	PRESENT	0
767252	765175	19649G	PARTICIPANT	\N	PRESENT	0
767253	765175	10015M	PARTICIPANT	\N	PRESENT	0
767254	765175	21040X	PARTICIPANT	\N	PRESENT	0
767255	765175	14069U	PARTICIPANT	\N	PRESENT	0
767256	765175	19749K	PARTICIPANT	\N	PRESENT	0
767257	765497	07029T	PARTICIPANT	\N	PRESENT	0
767258	765497	11040E	PARTICIPANT	\N	PRESENT	0
767259	765497	21041Y	PARTICIPANT	\N	PRESENT	0
767262	765497	20094J	PARTICIPANT	\N	PRESENT	0
744233	744232	05008E	PARTICIPANT	\N	PRESENT	0
744234	744232	11053K	PARTICIPANT	\N	PRESENT	0
744235	744232	01028R	PARTICIPANT	\N	PRESENT	0
744322	744203	20286Q	PARTICIPANT	\N	EXCUSE	0
744323	744203	19631V	PARTICIPANT	\N	EXCUSE	0
744324	744203	19866P	PARTICIPANT	\N	EXCUSE	0
744325	744203	20088L	PARTICIPANT	\N	EXCUSE	0
744674	744225	14327T	PARTICIPANT	\N	PRESENT	0
744675	744225	14331P	PARTICIPANT	\N	PRESENT	0
744676	744225	19479G	PRESIDENT	0	PRESENT	0
744677	744225	04071H	PARTICIPANT	\N	PRESENT	0
744678	744225	20036X	PARTICIPANT	\N	PRESENT	0
744679	744225	19711U	PARTICIPANT	\N	PRESENT	0
744680	744225	01048V	PARTICIPANT	\N	PRESENT	0
744681	744225	08034U	PARTICIPANT	\N	PRESENT	0
744682	744225	14189C	PARTICIPANT	\N	PRESENT	0
744683	744225	01057W	PARTICIPANT	\N	PRESENT	0
744684	744225	20150Y	PARTICIPANT	\N	PRESENT	0
744685	744225	11040E	PARTICIPANT	\N	PRESENT	0
744686	744225	08073C	PARTICIPANT	\N	PRESENT	0
744687	744225	20070A	PARTICIPANT	\N	PRESENT	0
744688	744225	19741B	PARTICIPANT	\N	PRESENT	0
744689	744225	08010L	PARTICIPANT	\N	PRESENT	0
744690	744225	99004R	PARTICIPANT	\N	PRESENT	0
744691	744225	20116W	PARTICIPANT	\N	PRESENT	0
744692	744225	14253S	PARTICIPANT	\N	PRESENT	0
744693	744225	07029T	PARTICIPANT	\N	EXCUSE	0
744694	744093	14001X	PARTICIPANT	\N	PRESENT	0
744695	744225	19647E	PARTICIPANT	\N	PRESENT	0
744696	744225	11048N	PARTICIPANT	\N	PRESENT	0
744697	744225	19531S	PARTICIPANT	\N	PRESENT	0
744698	744225	20044X	PARTICIPANT	\N	PRESENT	0
744699	744225	14083S	PARTICIPANT	\N	PRESENT	0
744700	744225	19762G	PARTICIPANT	\N	PRESENT	0
744701	744225	19671E	PARTICIPANT	\N	EXCUSE	0
744706	744225	19545Y	PARTICIPANT	\N	PRESENT	0
744707	744225	20080C	PARTICIPANT	\N	PRESENT	0
744708	744225	19687N	PARTICIPANT	\N	PRESENT	0
744709	744225	20252E	PARTICIPANT	\N	PRESENT	0
744714	744093	19725B	PARTICIPANT	\N	PRESENT	0
744715	744093	19729F	PARTICIPANT	\N	PRESENT	0
744716	744093	95063L	PARTICIPANT	\N	PRESENT	0
744717	744093	14111D	PARTICIPANT	\N	PRESENT	0
744718	744093	20074E	PARTICIPANT	\N	PRESENT	0
744719	744093	19581D	PARTICIPANT	\N	PRESENT	0
744720	744093	20022R	PARTICIPANT	\N	PRESENT	0
744721	744093	19673G	PARTICIPANT	\N	PRESENT	0
744722	744093	01028R	PARTICIPANT	\N	PRESENT	0
744723	744093	11033F	PARTICIPANT	\N	PRESENT	0
744724	744093	19447X	PARTICIPANT	\N	PRESENT	0
744734	744225	20086J	PARTICIPANT	\N	PRESENT	0
744735	744225	11053K	PARTICIPANT	\N	PRESENT	0
744736	744093	04047H	PRESIDENT	0	PRESENT	0
744737	744093	14231L	PARTICIPANT	\N	PRESENT	0
744738	744093	05008E	PARTICIPANT	\N	PRESENT	0
744739	744093	19489J	PARTICIPANT	\N	PRESENT	0
744740	744093	14179A	PARTICIPANT	\N	PRESENT	0
744741	744093	14147R	PARTICIPANT	\N	PRESENT	0
744742	744093	14151M	PARTICIPANT	\N	PRESENT	0
744743	744093	14215L	PARTICIPANT	\N	PRESENT	0
744744	744093	14259Y	PARTICIPANT	\N	PRESENT	0
744745	744093	10015M	PARTICIPANT	\N	PRESENT	0
744746	744093	04085P	PARTICIPANT	\N	PRESENT	0
744747	744093	14089Y	PARTICIPANT	\N	PRESENT	0
744748	744093	19749K	PARTICIPANT	\N	PRESENT	0
744749	744093	14021P	PARTICIPANT	\N	PRESENT	0
744750	744093	14053L	PARTICIPANT	\N	PRESENT	0
744751	744093	11026G	PARTICIPANT	\N	PRESENT	0
744753	744093	20114U	PARTICIPANT	\N	PRESENT	0
744754	743950	14097Y	PARTICIPANT	\N	PRESENT	0
744755	743950	14059S	PARTICIPANT	\N	PRESENT	0
744756	743950	12041X	PARTICIPANT	\N	PRESENT	0
744757	743950	19565D	PARTICIPANT	\N	PRESENT	0
744758	743950	20072C	PARTICIPANT	\N	PRESENT	0
744759	743950	14133K	PARTICIPANT	\N	PRESENT	0
744760	743950	08069G	PARTICIPANT	\N	PRESENT	0
744761	743950	20042V	PARTICIPANT	\N	PRESENT	0
744762	743950	01058X	PARTICIPANT	\N	PRESENT	0
744763	743950	04042C	PRESIDENT	0	PRESENT	0
744764	743950	01024M	PARTICIPANT	\N	PRESENT	0
744765	743950	11054L	PARTICIPANT	\N	PRESENT	0
744766	743950	11066Q	PARTICIPANT	\N	PRESENT	0
744767	743950	19721W	PARTICIPANT	\N	PRESENT	0
744768	743950	08056B	PARTICIPANT	\N	PRESENT	0
744769	743950	12028B	PARTICIPANT	\N	PRESENT	0
744770	743950	19319Q	PARTICIPANT	\N	PRESENT	0
744771	743950	20064C	PARTICIPANT	\N	PRESENT	0
744772	743950	14267Y	PARTICIPANT	\N	PRESENT	0
744773	743950	11064N	PARTICIPANT	\N	PRESENT	0
744774	743950	14193X	PARTICIPANT	\N	PRESENT	0
744775	743950	19347U	PARTICIPANT	\N	PRESENT	0
744776	743950	08047A	PARTICIPANT	\N	PRESENT	0
744777	743950	20128B	PARTICIPANT	\N	PRESENT	0
744779	743950	11041F	PARTICIPANT	\N	EXCUSE	0
744788	744170	86034E	PARTICIPANT	\N	PRESENT	0
744872	744705	19747H	PARTICIPANT	\N	PRESENT	0
744873	744705	19383Y	PARTICIPANT	\N	PRESENT	0
744874	744705	19705W	PARTICIPANT	\N	PRESENT	0
744876	744705	19369B	PARTICIPANT	\N	PRESENT	0
744877	744705	19507S	PARTICIPANT	\N	PRESENT	0
744878	744641	19701S	PARTICIPANT	\N	PRESENT	0
744879	744641	20076G	PARTICIPANT	\N	PRESENT	0
744880	744641	19549D	PARTICIPANT	\N	PRESENT	0
744881	744641	19387D	PARTICIPANT	\N	PRESENT	0
744882	744641	14219Q	PRESIDENT	0	PRESENT	0
744883	744641	19826F	PARTICIPANT	\N	PRESENT	0
744884	744641	20102Q	PARTICIPANT	\N	PRESENT	0
744885	744641	20100N	PARTICIPANT	\N	PRESENT	0
744886	744641	19551W	PARTICIPANT	\N	PRESENT	0
744887	744641	14237S	PARTICIPANT	\N	PRESENT	0
744888	744641	18083K	PARTICIPANT	\N	PRESENT	0
744889	744641	05012A	PARTICIPANT	\N	PRESENT	0
744890	744641	20106U	PARTICIPANT	\N	PRESENT	0
744891	744641	20118Y	PARTICIPANT	\N	PRESENT	0
744892	744641	19503N	PARTICIPANT	\N	PRESENT	0
744893	744641	20020P	PARTICIPANT	\N	PRESENT	0
744894	744641	17367Q	PARTICIPANT	\N	PRESENT	0
744895	744641	20024T	PARTICIPANT	\N	PRESENT	0
744896	744641	20120S	PARTICIPANT	\N	PRESENT	0
744897	744641	19525U	PARTICIPANT	\N	PRESENT	0
744898	744641	20032T	PARTICIPANT	\N	PRESENT	0
744899	744641	20122U	PARTICIPANT	\N	PRESENT	0
744900	744641	20136B	PARTICIPANT	\N	PRESENT	0
744901	744641	14031R	PRESIDENT	1	PRESENT	0
744902	744641	20038A	PARTICIPANT	\N	PRESENT	0
744903	744641	20140W	PARTICIPANT	\N	PRESENT	0
744904	744641	19251M	PARTICIPANT	\N	PRESENT	0
744905	744641	20046A	PARTICIPANT	\N	PRESENT	0
744906	744641	17229F	PARTICIPANT	\N	PRESENT	0
744907	744641	14169X	PARTICIPANT	\N	PRESENT	0
744908	744641	20068G	PARTICIPANT	\N	PRESENT	0
744909	744641	11101A	PARTICIPANT	\N	PRESENT	0
744910	744641	19739H	PARTICIPANT	\N	PRESENT	0
744911	744641	19577H	PARTICIPANT	\N	PRESENT	0
744912	744641	08060W	PARTICIPANT	\N	EXCUSE	0
744913	744641	19745F	PARTICIPANT	\N	EXCUSE	0
744914	744641	20096L	PARTICIPANT	\N	EXCUSE	0
744940	744170	19507S	PARTICIPANT	\N	PRESENT	0
744973	744170	19693L	PARTICIPANT	\N	PRESENT	0
744974	744170	19711U	PARTICIPANT	\N	PRESENT	0
744975	744170	19687N	PARTICIPANT	\N	PRESENT	0
744976	744170	01058X	PARTICIPANT	\N	PRESENT	0
744977	744170	11056N	PARTICIPANT	\N	PRESENT	0
744978	744170	99004R	PARTICIPANT	\N	PRESENT	0
744979	744170	19758L	PARTICIPANT	\N	PRESENT	0
744980	744170	11045K	PARTICIPANT	\N	PRESENT	0
744981	744170	19703U	PARTICIPANT	\N	PRESENT	0
744982	744170	01028R	PARTICIPANT	\N	PRESENT	0
744983	744170	11101A	PARTICIPANT	\N	PRESENT	0
744984	744170	04059M	PARTICIPANT	\N	PRESENT	0
744985	744170	08010L	PARTICIPANT	\N	PRESENT	0
744986	744170	17779H	PARTICIPANT	\N	PRESENT	0
744987	744170	11027H	PARTICIPANT	\N	PRESENT	0
744988	744170	04047H	PARTICIPANT	\N	PRESENT	0
744989	744170	11074Q	PARTICIPANT	\N	PRESENT	0
744990	744170	14021P	PARTICIPANT	\N	PRESENT	0
744991	744170	14229S	PARTICIPANT	\N	PRESENT	0
744992	744170	08011M	PARTICIPANT	\N	PRESENT	0
744993	744170	19649G	PARTICIPANT	\N	PRESENT	0
744994	744170	19683J	PARTICIPANT	\N	PRESENT	0
744995	744170	19333N	PARTICIPANT	\N	PRESENT	0
755038	755013	11070L	PARTICIPANT	\N	PRESENT	0
755112	755106	20136B	PARTICIPANT	\N	PRESENT	0
755113	755106	20100N	PARTICIPANT	\N	PRESENT	0
755114	755107	20136B	PARTICIPANT	\N	PRESENT	0
755115	755107	20100N	PARTICIPANT	\N	PRESENT	0
755116	755107	20068G	PARTICIPANT	\N	PRESENT	0
755798	753668	19479G	PARTICIPANT	\N	PRESENT	0
755799	753668	07004J	PARTICIPANT	\N	PRESENT	0
755800	753668	19719D	PARTICIPANT	\N	PRESENT	0
755801	753668	21090J	PARTICIPANT	\N	PRESENT	0
755802	753668	19621T	PARTICIPANT	\N	PRESENT	0
755803	753668	14253S	PARTICIPANT	\N	PRESENT	0
755804	753668	21050A	PARTICIPANT	\N	PRESENT	0
755805	753668	20086J	PARTICIPANT	\N	PRESENT	0
755806	753668	21093M	PARTICIPANT	\N	PRESENT	0
755807	753668	21066J	PARTICIPANT	\N	PRESENT	0
755808	753668	04045F	PARTICIPANT	\N	PRESENT	0
755809	753668	14053L	PARTICIPANT	\N	PRESENT	0
755810	753668	21091K	PARTICIPANT	\N	PRESENT	0
755811	753668	21072G	PARTICIPANT	\N	PRESENT	0
755812	753668	21044C	PARTICIPANT	\N	PRESENT	0
755813	753668	20070A	PARTICIPANT	\N	PRESENT	0
755814	753668	20136B	PARTICIPANT	\N	PRESENT	0
755815	753668	08010L	PARTICIPANT	\N	PRESENT	0
755816	753668	21089R	PARTICIPANT	\N	PRESENT	0
755817	753668	07033P	PARTICIPANT	\N	PRESENT	0
755818	753668	20248J	PARTICIPANT	\N	PRESENT	0
755819	753668	20110Q	PARTICIPANT	\N	PRESENT	0
755820	753668	14069U	PARTICIPANT	\N	PRESENT	0
755821	753668	20052X	PARTICIPANT	\N	PRESENT	0
755822	753668	19685L	PARTICIPANT	\N	PRESENT	0
755827	753668	19669L	PARTICIPANT	\N	PRESENT	0
755828	753668	18083K	PARTICIPANT	\N	PRESENT	0
755829	753668	10015M	PARTICIPANT	\N	PRESENT	0
755830	753668	14030Q	PARTICIPANT	\N	PRESENT	0
755833	753668	05012A	PARTICIPANT	\N	PRESENT	0
755834	753668	20098N	PARTICIPANT	\N	PRESENT	0
755835	753668	20090E	PARTICIPANT	\N	PRESENT	0
755836	753668	08060W	PARTICIPANT	\N	PRESENT	0
755837	753668	19531S	PARTICIPANT	\N	PRESENT	0
755838	753668	14229S	PARTICIPANT	\N	PRESENT	0
755839	753668	20080C	PARTICIPANT	\N	PRESENT	0
755840	753668	19758L	PARTICIPANT	\N	PRESENT	0
755841	753668	20264J	PARTICIPANT	\N	PRESENT	0
755842	753668	21079P	PARTICIPANT	\N	PRESENT	0
764799	761964	05012A	PARTICIPANT	\N	PRESENT	0
764800	761964	21068L	PARTICIPANT	\N	PRESENT	0
764801	761964	19758L	PARTICIPANT	\N	PRESENT	0
764802	761964	20102Q	PARTICIPANT	\N	PRESENT	0
764803	761964	20032T	PARTICIPANT	\N	PRESENT	0
764804	761964	20062A	PARTICIPANT	\N	PRESENT	0
764805	761964	20090E	PARTICIPANT	\N	PRESENT	0
764806	761964	19826F	PARTICIPANT	\N	PRESENT	0
764807	761964	20110Q	PARTICIPANT	\N	PRESENT	0
764820	761964	01034P	PARTICIPANT	\N	PRESENT	0
764868	761964	14151M	PARTICIPANT	\N	PRESENT	0
764870	761964	14205J	PARTICIPANT	\N	PRESENT	0
764797	761964	08012N	PARTICIPANT	\N	PRESENT	0
764798	761964	14069U	PARTICIPANT	\N	PRESENT	0
765072	764871	14219Q	PARTICIPANT	\N	EXCUSE	0
765478	765475	14257W	PARTICIPANT	\N	PRESENT	0
765480	765474	14257W	PARTICIPANT	\N	PRESENT	0
765481	765476	14257W	PARTICIPANT	\N	PRESENT	0
765495	765494	21067K	PARTICIPANT	\N	PRESENT	0
765496	765494	08047A	PARTICIPANT	\N	PRESENT	0
765506	765505	12028B	PARTICIPANT	\N	PRESENT	0
765507	765505	14267Y	PARTICIPANT	\N	PRESENT	0
765508	765505	08010L	PARTICIPANT	\N	PRESENT	0
765510	765509	14255U	PARTICIPANT	\N	PRESENT	0
765512	765511	14097Y	PARTICIPANT	\N	PRESENT	0
765514	765513	14255U	PARTICIPANT	\N	PRESENT	0
765515	765513	20064C	PARTICIPANT	\N	PRESENT	0
765520	765516	18395Y	PARTICIPANT	\N	PRESENT	0
765521	765516	19735D	PARTICIPANT	\N	PRESENT	0
765522	765516	20142Y	PARTICIPANT	\N	PRESENT	0
765674	765673	21090J	PARTICIPANT	\N	PRESENT	0
765675	765673	08009T	PARTICIPANT	\N	PRESENT	0
765676	765668	21090J	PARTICIPANT	\N	PRESENT	0
765677	765668	08009T	PARTICIPANT	\N	PRESENT	0
765679	765678	21090J	PARTICIPANT	\N	PRESENT	0
765680	765678	08009T	PARTICIPANT	\N	PRESENT	0
765682	765681	21090J	PARTICIPANT	\N	PRESENT	0
765683	765681	08009T	PARTICIPANT	\N	PRESENT	0
765685	765684	21090J	PARTICIPANT	\N	PRESENT	0
765686	765684	08009T	PARTICIPANT	\N	PRESENT	0
765688	765687	11053K	PARTICIPANT	\N	PRESENT	0
765702	765489	08073C	PARTICIPANT	\N	EXCUSE	0
765761	765489	19745F	PARTICIPANT	\N	EXCUSE	0
765763	765762	14327T	PARTICIPANT	\N	PRESENT	0
765766	765765	14327T	PARTICIPANT	\N	PRESENT	0
765768	765767	14327T	PARTICIPANT	\N	PRESENT	0
765795	765790	14083S	PARTICIPANT	\N	PRESENT	0
765797	765790	21041Y	PARTICIPANT	\N	PRESENT	0
765809	765808	14083S	PARTICIPANT	\N	PRESENT	0
765810	765808	21041Y	PARTICIPANT	\N	PRESENT	0
765817	765814	14083S	PARTICIPANT	\N	PRESENT	0
765819	765814	21041Y	PARTICIPANT	\N	PRESENT	0
765835	765834	14173T	PARTICIPANT	\N	PRESENT	0
765981	765399	19760E	PARTICIPANT	\N	PRESENT	0
765982	765399	19758L	PARTICIPANT	\N	PRESENT	0
765983	765399	07004J	PARTICIPANT	\N	PRESENT	0
765984	765399	19569H	PARTICIPANT	\N	PRESENT	0
765985	765399	21087P	PARTICIPANT	\N	PRESENT	0
765986	765399	20090E	PARTICIPANT	\N	PRESENT	0
765987	765399	20026V	PARTICIPANT	\N	PRESENT	0
765988	765399	20066E	PARTICIPANT	\N	PRESENT	0
765989	765399	20130U	PARTICIPANT	\N	PRESENT	0
765990	765399	19782L	PARTICIPANT	\N	PRESENT	0
765991	765399	21097R	PARTICIPANT	\N	PRESENT	0
765992	765399	17779H	PARTICIPANT	\N	PRESENT	0
765993	765399	08061X	PARTICIPANT	\N	PRESENT	0
765994	765399	14037X	PARTICIPANT	\N	PRESENT	0
765995	765399	14042U	PARTICIPANT	\N	PRESENT	0
765996	765399	14071N	PARTICIPANT	\N	PRESENT	0
765997	765399	21081H	PARTICIPANT	\N	PRESENT	0
765998	765399	14281W	PARTICIPANT	\N	PRESENT	0
765999	765399	20024T	PARTICIPANT	\N	PRESENT	0
766000	765399	20114U	PARTICIPANT	\N	PRESENT	0
766001	765399	19866P	PARTICIPANT	\N	PRESENT	0
766002	765399	20148F	PARTICIPANT	\N	PRESENT	0
766003	765399	20080C	PARTICIPANT	\N	PRESENT	0
766004	765399	14213J	PARTICIPANT	\N	PRESENT	0
765954	765722	19367Y	PARTICIPANT	\N	PRESENT	0
765955	765722	20090E	PARTICIPANT	\N	PRESENT	0
765956	765722	21045D	PARTICIPANT	\N	PRESENT	0
765957	765722	20140W	PARTICIPANT	\N	PRESENT	0
765958	765722	14217N	PARTICIPANT	\N	PRESENT	0
765959	765722	14042U	PARTICIPANT	\N	PRESENT	0
765960	765722	14281W	PARTICIPANT	\N	PRESENT	0
765961	765722	14026U	PARTICIPANT	\N	PRESENT	0
765962	765722	19691J	PARTICIPANT	\N	PRESENT	0
765963	765722	19569H	PARTICIPANT	\N	PRESENT	0
765964	765722	14213J	PARTICIPANT	\N	PRESENT	0
765965	765722	18193Q	PARTICIPANT	\N	PRESENT	0
765966	765722	21087P	PARTICIPANT	\N	PRESENT	0
765967	765722	19657G	PARTICIPANT	\N	PRESENT	0
765968	765722	04092N	PARTICIPANT	\N	PRESENT	0
765969	765722	14071N	PRESIDENT	0	PRESENT	0
765970	765722	21097R	PARTICIPANT	\N	PRESENT	0
765971	765722	21039F	PARTICIPANT	\N	PRESENT	0
765972	765722	19798U	PARTICIPANT	\N	PRESENT	0
765973	765722	21064G	PARTICIPANT	\N	PRESENT	0
765974	765722	19723Y	PARTICIPANT	\N	PRESENT	0
765975	765722	19703U	PARTICIPANT	\N	PRESENT	0
765976	765722	19713W	PARTICIPANT	\N	PRESENT	0
765977	765722	19301E	PARTICIPANT	\N	PRESENT	0
765978	765722	01034P	PARTICIPANT	\N	PRESENT	0
765979	765399	19683J	PARTICIPANT	\N	PRESENT	0
765980	765399	21046E	PARTICIPANT	\N	PRESENT	0
766005	765399	20062A	PARTICIPANT	\N	PRESENT	0
766006	765399	19798U	PARTICIPANT	\N	PRESENT	0
766007	765399	19367Y	PARTICIPANT	\N	PRESENT	0
765928	765399	14259Y	PARTICIPANT	\N	PRESENT	0
766008	765399	21049H	PARTICIPANT	\N	PRESENT	0
766009	765399	21040X	PARTICIPANT	\N	PRESENT	0
766010	765399	21094N	PARTICIPANT	\N	PRESENT	0
766011	765399	19713W	PARTICIPANT	\N	PRESENT	0
766012	765399	18193Q	PARTICIPANT	\N	PRESENT	0
766013	765399	04092N	PARTICIPANT	\N	PRESENT	0
766014	765399	21039F	PARTICIPANT	\N	PRESENT	0
766015	765399	20044X	PARTICIPANT	\N	PRESENT	0
739781	739780	14026U	PARTICIPANT	\N	PRESENT	0
743377	740617	19719D	PARTICIPANT	\N	PRESENT	0
743378	740836	11048N	PARTICIPANT	\N	PRESENT	0
743380	740836	14225N	PRESIDENT	0	PRESENT	0
743386	740617	20114U	PARTICIPANT	\N	PRESENT	0
743387	740617	19329S	PARTICIPANT	\N	PRESENT	0
743422	740617	20116W	PARTICIPANT	\N	PRESENT	0
743389	740617	19349W	PARTICIPANT	\N	PRESENT	0
743390	740617	95063L	PARTICIPANT	\N	PRESENT	0
743391	740617	14215L	PARTICIPANT	\N	PRESENT	0
743426	740617	19629C	PARTICIPANT	\N	PRESENT	0
743409	740617	20022R	PARTICIPANT	\N	PRESENT	0
743394	740617	14055N	PARTICIPANT	\N	PRESENT	0
743395	740617	20090E	PARTICIPANT	\N	PRESENT	0
743421	740617	14219Q	PARTICIPANT	\N	PRESENT	0
743416	740617	20110Q	PARTICIPANT	\N	PRESENT	0
743410	740617	19691J	PARTICIPANT	\N	PRESENT	0
743402	740617	20026V	PARTICIPANT	\N	PRESENT	0
743403	740617	20046A	PARTICIPANT	\N	PRESENT	0
743404	740617	20102Q	PARTICIPANT	\N	PRESENT	0
743405	740836	20914V	PARTICIPANT	\N	PRESENT	0
743406	740617	19758L	PARTICIPANT	\N	PRESENT	0
743407	740617	04045F	PARTICIPANT	\N	PRESENT	0
743411	740836	07029T	PARTICIPANT	\N	PRESENT	0
743412	740617	19745F	PARTICIPANT	\N	PRESENT	0
743413	740617	08061X	PARTICIPANT	\N	PRESENT	0
743414	740617	20058E	PARTICIPANT	\N	PRESENT	0
743415	740836	20126Y	PARTICIPANT	\N	PRESENT	0
743419	740617	19637C	PARTICIPANT	\N	PRESENT	0
743423	740836	14331P	PARTICIPANT	\N	PRESENT	0
743424	740836	19711U	PARTICIPANT	\N	PRESENT	0
743425	740617	01058X	PARTICIPANT	\N	PRESENT	0
743427	740617	19387D	PARTICIPANT	\N	PRESENT	0
743435	740617	14231L	PARTICIPANT	\N	PRESENT	0
743429	740617	04047H	PARTICIPANT	\N	PRESENT	0
743430	740617	18083K	PARTICIPANT	\N	PRESENT	0
743431	740836	19671E	PARTICIPANT	\N	PRESENT	0
743432	740617	20098N	PARTICIPANT	\N	PRESENT	0
743436	740617	11056N	PARTICIPANT	\N	PRESENT	0
743437	740617	10015M	PARTICIPANT	\N	PRESENT	0
743438	740617	14151M	PARTICIPANT	\N	PRESENT	0
743439	740617	07004J	PARTICIPANT	\N	PRESENT	0
743440	740617	20150Y	PARTICIPANT	\N	PRESENT	0
743441	740617	20048C	PARTICIPANT	\N	PRESENT	0
743442	740617	14259Y	PARTICIPANT	\N	PRESENT	0
743443	740617	14147R	PARTICIPANT	\N	PRESENT	0
743444	740617	20122U	PARTICIPANT	\N	PRESENT	0
743445	740836	08034U	PARTICIPANT	\N	PRESENT	0
743446	740836	20044X	PARTICIPANT	\N	PRESENT	0
743447	740617	97011G	PARTICIPANT	\N	PRESENT	0
743448	740617	20032T	PARTICIPANT	\N	PRESENT	0
743449	740617	20100N	PARTICIPANT	\N	PRESENT	0
743450	740617	19301E	PARTICIPANT	\N	PRESENT	0
743456	740617	19447X	PARTICIPANT	\N	PRESENT	0
743452	740617	19525U	PARTICIPANT	\N	PRESENT	0
743455	740617	20980G	PARTICIPANT	\N	PRESENT	0
743457	740617	20052X	PARTICIPANT	\N	PRESENT	0
743458	740836	14189C	PARTICIPANT	\N	PRESENT	0
743459	740617	05008E	PARTICIPANT	\N	PRESENT	0
743460	740617	20128B	PARTICIPANT	\N	PRESENT	0
743461	740617	20086J	PARTICIPANT	\N	PRESENT	0
743462	740836	20080C	PARTICIPANT	\N	PRESENT	0
743463	740836	19741B	PARTICIPANT	\N	PRESENT	0
743467	740617	20108W	PARTICIPANT	\N	PRESENT	0
743469	740617	19057M	PARTICIPANT	\N	PRESENT	0
743470	740617	20044X	PARTICIPANT	\N	PRESENT	0
743471	740617	20172F	PARTICIPANT	\N	PRESENT	0
743472	740617	20082E	PARTICIPANT	\N	PRESENT	0
743473	740617	19673G	PARTICIPANT	\N	PRESENT	0
743475	740617	19651A	PARTICIPANT	\N	PRESENT	0
743477	740617	14021P	PARTICIPANT	\N	PRESENT	0
743481	740836	14083S	PARTICIPANT	\N	PRESENT	0
743483	740617	20088L	PARTICIPANT	\N	PRESENT	0
743484	740617	11012A	PARTICIPANT	\N	PRESENT	0
743486	740617	07029T	PARTICIPANT	\N	PRESENT	0
743487	740617	11077T	PARTICIPANT	\N	PRESENT	0
743488	740617	14187A	PARTICIPANT	\N	PRESENT	0
743489	740617	19631V	PARTICIPANT	\N	PRESENT	0
743490	740617	11072N	PARTICIPANT	\N	PRESENT	0
743491	740836	01048V	PARTICIPANT	\N	PRESENT	0
743492	740617	19782L	PARTICIPANT	\N	PRESENT	0
743493	740617	14069U	PARTICIPANT	\N	PRESENT	0
743494	740617	14030Q	PARTICIPANT	\N	PRESENT	0
743495	740617	14083S	PARTICIPANT	\N	PRESENT	0
743496	740617	14221J	PARTICIPANT	\N	PRESENT	0
743497	740617	19715Y	PARTICIPANT	\N	PRESENT	0
743498	740617	14189C	PARTICIPANT	\N	PRESENT	0
743499	740617	14033T	PARTICIPANT	\N	PRESENT	0
743500	740617	17737W	PARTICIPANT	\N	PRESENT	0
743501	740617	19798U	PARTICIPANT	\N	PRESENT	0
743502	740617	11043H	PARTICIPANT	\N	PRESENT	0
743503	740617	14053L	PARTICIPANT	\N	PRESENT	0
743504	740617	20080C	PARTICIPANT	\N	PRESENT	0
743505	740617	19741B	PARTICIPANT	\N	PRESENT	0
743506	740617	17023S	PARTICIPANT	\N	PRESENT	0
743507	740617	11031D	PARTICIPANT	\N	PRESENT	0
743508	740617	20106U	PARTICIPANT	\N	PRESENT	0
743509	740617	20180F	PARTICIPANT	\N	PRESENT	0
743510	740617	14207L	PARTICIPANT	\N	PRESENT	0
743511	740617	20298U	PARTICIPANT	\N	PRESENT	0
743512	740617	20120S	PARTICIPANT	\N	PRESENT	0
743513	740617	14071N	PARTICIPANT	\N	PRESENT	0
743527	740617	14042U	PARTICIPANT	\N	PRESENT	0
743528	740617	20134Y	PARTICIPANT	\N	PRESENT	0
743529	740617	14217N	PARTICIPANT	\N	PRESENT	0
743530	740617	19760E	PARTICIPANT	\N	PRESENT	0
743531	740617	20124W	PARTICIPANT	\N	PRESENT	0
743532	740617	19723Y	PARTICIPANT	\N	PRESENT	0
743537	740617	14225N	PARTICIPANT	\N	PRESENT	0
743970	741160	14179A	PARTICIPANT	\N	PRESENT	0
743971	741160	20060X	PARTICIPANT	\N	PRESENT	0
743977	740726	14179A	PARTICIPANT	\N	PRESENT	0
743978	740726	20094J	PARTICIPANT	\N	PRESENT	0
744202	744045	20126Y	PARTICIPANT	\N	EXCUSE	0
744212	738365	19631V	PARTICIPANT	\N	EXCUSE	0
744213	738365	20034V	PARTICIPANT	\N	PRESENT	0
744276	744275	19629C	PARTICIPANT	\N	PRESENT	0
744277	744275	20120S	PARTICIPANT	\N	PRESENT	0
744278	744275	19549D	PARTICIPANT	\N	PRESENT	0
744279	744275	04035D	PARTICIPANT	\N	PRESENT	0
744280	744275	20106U	PARTICIPANT	\N	PRESENT	0
744281	744275	14255U	PARTICIPANT	\N	PRESENT	0
744282	744275	19525U	PARTICIPANT	\N	PRESENT	0
744283	744275	14329V	PARTICIPANT	\N	PRESENT	0
744310	743482	19760E	PARTICIPANT	\N	PRESENT	0
744311	743482	14042U	PARTICIPANT	\N	PRESENT	0
744312	743482	14213J	PARTICIPANT	\N	PRESENT	0
744313	743482	19683J	PARTICIPANT	\N	PRESENT	0
744314	743482	11097X	PRESIDENT	0	PRESENT	0
744315	743482	11031D	PARTICIPANT	\N	PRESENT	0
744316	743482	14217N	PARTICIPANT	\N	PRESENT	0
744454	744453	11074Q	PARTICIPANT	\N	PRESENT	0
744456	744453	19349W	PARTICIPANT	\N	PRESENT	0
744464	744463	07029T	PARTICIPANT	\N	PRESENT	0
744470	744467	20050V	PARTICIPANT	\N	PRESENT	0
744473	744472	20070A	PARTICIPANT	\N	PRESENT	0
744474	744472	11110B	PARTICIPANT	\N	PRESENT	0
745871	745870	08009T	PARTICIPANT	\N	PRESENT	0
745872	745870	14169X	PARTICIPANT	\N	PRESENT	0
745873	745870	20120S	PARTICIPANT	\N	PRESENT	0
745999	743066	20094J	PARTICIPANT	\N	PRESENT	0
746000	743066	14357A	PARTICIPANT	\N	PRESENT	0
746001	743066	12041X	PARTICIPANT	\N	PRESENT	0
746002	743066	14169X	PARTICIPANT	\N	PRESENT	0
746003	743066	14331P	PARTICIPANT	\N	PRESENT	0
746004	743066	10015M	PARTICIPANT	\N	PRESENT	0
746307	746016	19760E	PARTICIPANT	\N	PRESENT	0
746308	746016	14195A	PARTICIPANT	\N	PRESENT	0
746309	746016	14281W	PARTICIPANT	\N	PRESENT	0
746310	746016	18193Q	PARTICIPANT	\N	PRESENT	0
746311	746016	04057K	PARTICIPANT	\N	EXCUSE	0
746312	746016	11067R	PARTICIPANT	\N	PRESENT	0
746313	746016	04092N	PARTICIPANT	\N	PRESENT	0
746314	746016	14223L	PARTICIPANT	\N	PRESENT	0
746315	746016	14071N	PARTICIPANT	\N	PRESENT	0
746316	746016	20130U	PARTICIPANT	\N	PRESENT	0
746317	746016	17965H	PARTICIPANT	\N	PRESENT	0
746318	746016	04043D	PARTICIPANT	\N	PRESENT	0
746319	746016	19679N	PARTICIPANT	\N	PRESENT	0
746320	746016	19798U	PARTICIPANT	\N	PRESENT	0
746321	746016	11097X	PARTICIPANT	\N	PRESENT	0
755706	755702	14213J	PARTICIPANT	\N	PRESENT	0
755707	755703	14213J	PARTICIPANT	\N	PRESENT	0
755708	755703	14071N	PARTICIPANT	\N	PRESENT	0
755709	755704	21071F	PARTICIPANT	\N	PRESENT	0
755714	755705	14071N	PARTICIPANT	\N	PRESENT	0
755711	755704	14213J	PARTICIPANT	\N	PRESENT	0
755712	755704	14071N	PARTICIPANT	\N	PRESENT	0
755713	755705	14213J	PARTICIPANT	\N	PRESENT	0
760781	760780	04047H	PARTICIPANT	\N	PRESENT	0
760782	760780	14053L	PARTICIPANT	\N	PRESENT	0
760786	760780	14193X	PARTICIPANT	\N	PRESENT	0
760787	760780	14097Y	PARTICIPANT	\N	PRESENT	0
760791	760788	20040T	PARTICIPANT	\N	PRESENT	0
760793	760792	20040T	PARTICIPANT	\N	PRESENT	0
760795	760794	20040T	PARTICIPANT	\N	PRESENT	0
760797	760796	20040T	PARTICIPANT	\N	PRESENT	0
760799	760798	14329V	PARTICIPANT	\N	PRESENT	0
767263	765175	18231D	PARTICIPANT	\N	PRESENT	0
767264	765175	11085T	PARTICIPANT	\N	PRESENT	0
767265	765175	20108W	PARTICIPANT	\N	EXCUSE	0
767267	765497	19573D	PARTICIPANT	\N	PRESENT	0
767268	765497	14327T	PARTICIPANT	\N	PRESENT	0
767270	765497	21048G	PARTICIPANT	\N	PRESENT	0
767275	765497	14083S	PARTICIPANT	\N	PRESENT	0
767276	765497	20134Y	PARTICIPANT	\N	PRESENT	0
767277	765497	20086J	PARTICIPANT	\N	PRESENT	0
767278	763071	19697Q	PARTICIPANT	\N	PRESENT	0
767279	763071	04033B	PARTICIPANT	\N	PRESENT	0
767280	763071	20172F	PARTICIPANT	\N	PRESENT	0
767281	763071	14030Q	PARTICIPANT	\N	PRESENT	0
767282	763071	20264J	PARTICIPANT	\N	PRESENT	0
767283	763071	19735D	PARTICIPANT	\N	PRESENT	0
767284	763071	19621T	PARTICIPANT	\N	PRESENT	0
767285	763071	21078N	PARTICIPANT	\N	PRESENT	0
767286	763071	04070G	PARTICIPANT	\N	PRESENT	0
767287	763071	20058E	PARTICIPANT	\N	PRESENT	0
767288	765175	21056G	PARTICIPANT	\N	PRESENT	0
767289	765175	14053L	PARTICIPANT	\N	PRESENT	0
767290	765497	20050V	PARTICIPANT	\N	PRESENT	0
767292	765175	14231L	PARTICIPANT	\N	PRESENT	0
767293	765497	21069M	PARTICIPANT	\N	PRESENT	0
767294	765175	20098N	PARTICIPANT	\N	PRESENT	0
767295	765175	21038E	PARTICIPANT	\N	PRESENT	0
767296	765175	19719D	PARTICIPANT	\N	PRESENT	0
767297	765175	20266L	PARTICIPANT	\N	PRESENT	0
767298	765497	21072G	PARTICIPANT	\N	PRESENT	0
767305	765497	19647E	PARTICIPANT	\N	PRESENT	0
767308	763071	11043H	PARTICIPANT	\N	PRESENT	0
767311	765175	14259Y	PARTICIPANT	\N	PRESENT	0
767317	765846	21082J	PARTICIPANT	\N	PRESENT	0
767318	765846	21029D	PARTICIPANT	\N	PRESENT	0
767319	765846	19701S	PARTICIPANT	\N	PRESENT	0
767320	765846	21035B	PARTICIPANT	\N	PRESENT	0
767321	765846	21042A	PARTICIPANT	\N	PRESENT	0
767322	765846	20076G	PARTICIPANT	\N	PRESENT	0
767323	765846	19387D	PARTICIPANT	\N	PRESENT	0
767324	765846	14219Q	PRESIDENT	0	PRESENT	0
767325	765846	19820Y	PARTICIPANT	\N	PRESENT	0
767326	765846	19826F	PARTICIPANT	\N	PRESENT	0
767327	765846	21060C	PARTICIPANT	\N	PRESENT	0
767328	765846	21061D	PARTICIPANT	\N	PRESENT	0
767329	765846	21062E	PARTICIPANT	\N	PRESENT	0
767330	765846	21065H	PARTICIPANT	\N	PRESENT	0
767331	765846	18083K	PARTICIPANT	\N	PRESENT	0
767332	765846	20100N	PARTICIPANT	\N	PRESENT	0
767333	765846	21084L	PARTICIPANT	\N	PRESENT	0
767334	765846	05012A	PARTICIPANT	\N	PRESENT	0
767335	765846	08060W	PARTICIPANT	\N	PRESENT	0
767336	765846	20106U	PARTICIPANT	\N	PRESENT	0
767337	765846	15197G	PARTICIPANT	\N	PRESENT	0
767338	765846	20118Y	PARTICIPANT	\N	PRESENT	0
767339	765846	14107H	PARTICIPANT	\N	PRESENT	0
767340	765846	21080G	PARTICIPANT	\N	PRESENT	0
767341	765846	20020P	PARTICIPANT	\N	PRESENT	0
767342	765846	19685L	PARTICIPANT	\N	PRESENT	0
767343	765846	11065P	PARTICIPANT	\N	PRESENT	0
767344	765846	21051B	PARTICIPANT	\N	PRESENT	0
767345	765846	20120S	PARTICIPANT	\N	PRESENT	0
767346	765846	21053D	PARTICIPANT	\N	PRESENT	0
767347	765846	20032T	PARTICIPANT	\N	PRESENT	0
767348	765846	20136B	PARTICIPANT	\N	PRESENT	0
767349	765846	14031R	PARTICIPANT	\N	PRESENT	0
767350	765846	20040T	PARTICIPANT	\N	PRESENT	0
767351	765846	19251M	PARTICIPANT	\N	PRESENT	0
767352	765846	20046A	PARTICIPANT	\N	PRESENT	0
767353	765846	20146D	PARTICIPANT	\N	PRESENT	0
767354	765846	17229F	PARTICIPANT	\N	PRESENT	0
767355	765846	14169X	PARTICIPANT	\N	PRESENT	0
767356	765846	20068G	PARTICIPANT	\N	PRESENT	0
767357	765846	21068L	PARTICIPANT	\N	PRESENT	0
767358	765846	21070E	PARTICIPANT	\N	PRESENT	0
767359	765846	19619A	PARTICIPANT	\N	PRESENT	0
767366	765497	21090J	PARTICIPANT	\N	PRESENT	0
767374	765175	08018U	PARTICIPANT	\N	PRESENT	0
767378	767176	19383Y	PARTICIPANT	\N	PRESENT	0
767379	767176	19768N	PARTICIPANT	\N	PRESENT	0
767380	767176	20088L	PARTICIPANT	\N	PRESENT	0
767381	767176	19782L	PARTICIPANT	\N	PRESENT	0
767382	767176	20092G	PARTICIPANT	\N	PRESENT	0
767383	767176	14357A	PARTICIPANT	\N	PRESENT	0
767384	767176	20078J	PARTICIPANT	\N	PRESENT	0
767385	767176	19413M	PARTICIPANT	\N	PRESENT	0
767386	767176	20082E	PARTICIPANT	\N	PRESENT	0
767387	767176	14221J	PARTICIPANT	\N	PRESENT	0
767388	767176	20104S	PARTICIPANT	\N	PRESENT	0
767389	767176	19631V	PARTICIPANT	\N	PRESENT	0
767390	767176	19705W	PARTICIPANT	\N	PRESENT	0
767391	767176	08015R	PARTICIPANT	\N	PRESENT	0
767392	767176	19575F	PARTICIPANT	\N	PRESENT	0
767393	767176	20018V	PARTICIPANT	\N	PRESENT	0
767394	767176	08028W	PARTICIPANT	\N	PRESENT	0
767395	767176	19563B	PARTICIPANT	\N	PRESENT	0
767396	767176	20126Y	PARTICIPANT	\N	PRESENT	0
767397	767176	21050A	PARTICIPANT	\N	PRESENT	0
767398	767176	14329V	PARTICIPANT	\N	PRESENT	0
767399	767176	20028X	PARTICIPANT	\N	PRESENT	0
767400	767176	14038Y	PARTICIPANT	\N	PRESENT	0
767401	767176	20030R	PARTICIPANT	\N	PRESENT	0
767402	767176	21052C	PARTICIPANT	\N	PRESENT	0
767403	767176	20034V	PARTICIPANT	\N	PRESENT	0
767404	767176	21054E	PARTICIPANT	\N	PRESENT	0
767405	767176	14187A	PRESIDENT	0	PRESENT	0
767406	767176	21075K	PARTICIPANT	\N	PRESENT	0
767407	767176	21083K	PARTICIPANT	\N	PRESENT	0
767408	767176	21086N	PARTICIPANT	\N	PRESENT	0
767409	767176	19695N	PARTICIPANT	\N	PRESENT	0
767410	767176	14033T	PARTICIPANT	\N	PRESENT	0
767411	767176	11090Q	PARTICIPANT	\N	PRESENT	0
767412	767176	21093M	PARTICIPANT	\N	PRESENT	0
767413	767176	20054A	PARTICIPANT	\N	PRESENT	0
767414	767176	14205J	PARTICIPANT	\N	PRESENT	0
767415	767176	20060X	PARTICIPANT	\N	PRESENT	0
767416	767176	19507S	PARTICIPANT	\N	PRESENT	0
767417	767176	20066E	PARTICIPANT	\N	PRESENT	0
767418	767176	21066J	PARTICIPANT	\N	PRESENT	0
767419	767176	20286Q	PARTICIPANT	\N	PRESENT	0
767420	767176	14207L	PARTICIPANT	\N	PRESENT	0
767421	767176	14257W	PARTICIPANT	\N	PRESENT	0
767422	767176	20084G	PARTICIPANT	\N	PRESENT	0
767423	767176	20038A	PARTICIPANT	\N	EXCUSE	0
767773	765403	08010L	PARTICIPANT	\N	PRESENT	0
767774	765403	21052C	PARTICIPANT	\N	PRESENT	0
767775	765403	21065H	PARTICIPANT	\N	PRESENT	0
767789	765403	12028B	PARTICIPANT	\N	PRESENT	0
767777	765403	19691J	PARTICIPANT	\N	PRESENT	0
767778	765403	21035B	PARTICIPANT	\N	PRESENT	0
767779	765403	19631V	PARTICIPANT	\N	PRESENT	0
767780	765403	14089Y	PARTICIPANT	\N	PRESENT	0
767781	765403	04070G	PARTICIPANT	\N	PRESENT	0
767782	765403	21047F	PARTICIPANT	\N	PRESENT	0
767783	765403	20080C	PARTICIPANT	\N	PRESENT	0
767784	765403	21050A	PARTICIPANT	\N	PRESENT	0
767785	765403	20106U	PARTICIPANT	\N	PRESENT	0
767786	765403	21045D	PARTICIPANT	\N	PRESENT	0
767787	765403	20286Q	PARTICIPANT	\N	PRESENT	0
767788	765403	20112S	PARTICIPANT	\N	PRESENT	0
767791	765403	20264J	PARTICIPANT	\N	PRESENT	0
767792	765403	19295A	PARTICIPANT	\N	PRESENT	0
744915	743991	18193Q	PARTICIPANT	\N	PRESENT	0
744916	743991	11097X	PARTICIPANT	\N	PRESENT	0
744917	743991	20130U	PARTICIPANT	\N	PRESENT	0
744918	743991	17965H	PARTICIPANT	\N	PRESENT	0
744919	743991	11067R	PARTICIPANT	\N	PRESENT	0
744920	743991	19367Y	PARTICIPANT	\N	PRESENT	0
744921	743991	14026U	PARTICIPANT	\N	PRESENT	0
744922	743991	14281W	PARTICIPANT	\N	PRESENT	0
744923	743991	14195A	PARTICIPANT	\N	PRESENT	0
744924	743991	10006L	PRESIDENT	0	PRESENT	0
744925	743991	19798U	PARTICIPANT	\N	PRESENT	0
744926	743991	14042U	PARTICIPANT	\N	PRESENT	0
744927	743991	20090E	PARTICIPANT	\N	PRESENT	0
744928	743991	14071N	PRESIDENT	1	PRESENT	0
744929	743991	17779H	PARTICIPANT	\N	PRESENT	0
744930	743991	14213J	PARTICIPANT	\N	PRESENT	0
744931	743991	20066E	PARTICIPANT	\N	PRESENT	0
744932	743991	19723Y	PARTICIPANT	\N	PRESENT	0
744933	743991	01034P	PARTICIPANT	\N	PRESENT	0
744934	743991	20248J	PARTICIPANT	\N	PRESENT	0
744935	743991	11045K	PARTICIPANT	\N	PRESENT	0
744936	743991	14217N	PARTICIPANT	\N	PRESENT	0
744937	743991	19591F	PARTICIPANT	\N	PRESENT	0
744938	743991	11031D	PARTICIPANT	\N	PRESENT	0
744939	743991	04057K	PARTICIPANT	\N	PRESENT	0
744996	744170	20076G	PARTICIPANT	\N	PRESENT	0
744997	744170	14001X	PARTICIPANT	\N	PRESENT	0
744998	744170	19679N	PARTICIPANT	\N	PRESENT	0
744999	744170	20074E	PARTICIPANT	\N	PRESENT	0
745000	744170	20028X	PARTICIPANT	\N	PRESENT	0
745001	744170	20114U	PARTICIPANT	\N	PRESENT	0
745002	744170	04042C	PARTICIPANT	\N	PRESENT	0
745003	744170	08045X	PARTICIPANT	\N	PRESENT	0
745004	744170	18083K	PARTICIPANT	\N	PRESENT	0
745005	744170	11067R	PARTICIPANT	\N	PRESENT	0
745006	744170	14097Y	PARTICIPANT	\N	PRESENT	0
745007	744170	19575F	PARTICIPANT	\N	PRESENT	0
745008	744170	19669L	PARTICIPANT	\N	PRESENT	0
745009	744170	19549D	PARTICIPANT	\N	PRESENT	0
745010	744170	17367Q	PARTICIPANT	\N	PRESENT	0
745011	744170	08060W	PARTICIPANT	\N	PRESENT	0
745012	744170	19643A	PARTICIPANT	\N	PRESENT	0
745013	744170	11066Q	PARTICIPANT	\N	PRESENT	0
745014	744170	11041F	PARTICIPANT	\N	PRESENT	0
745015	744170	04071H	PARTICIPANT	\N	PRESENT	0
745016	744170	11054L	PARTICIPANT	\N	PRESENT	0
745017	744170	14169X	PARTICIPANT	\N	PRESENT	0
745018	744170	14109K	PARTICIPANT	\N	PRESENT	0
745019	744170	01048V	PARTICIPANT	\N	PRESENT	0
745020	744170	19515S	PARTICIPANT	\N	PRESENT	0
745021	744170	11080N	PARTICIPANT	\N	PRESENT	0
745022	744170	08012N	PARTICIPANT	\N	PRESENT	0
745023	744170	14259Y	PARTICIPANT	\N	PRESENT	0
745024	744170	20070A	PARTICIPANT	\N	PRESENT	0
745025	744170	01057W	PARTICIPANT	\N	PRESENT	0
745026	744170	20068G	PARTICIPANT	\N	PRESENT	0
745027	744170	14281W	PARTICIPANT	\N	PRESENT	0
745028	744170	20022R	PARTICIPANT	\N	PRESENT	0
745029	744170	19413M	PARTICIPANT	\N	PRESENT	0
745030	744170	20038A	PARTICIPANT	\N	PRESENT	0
745031	744170	18193Q	PARTICIPANT	\N	PRESENT	0
745032	744170	19673G	PARTICIPANT	\N	PRESENT	0
745033	744170	11010L	PARTICIPANT	\N	PRESENT	0
745034	744170	14253S	PARTICIPANT	\N	PRESENT	0
745035	744170	19725B	PARTICIPANT	\N	PRESENT	0
745036	744170	20136B	PARTICIPANT	\N	PRESENT	0
745037	744170	20032T	PARTICIPANT	\N	PRESENT	0
745038	744170	20080C	PARTICIPANT	\N	PRESENT	0
745039	744170	20060X	PARTICIPANT	\N	PRESENT	0
745040	744170	14331P	PARTICIPANT	\N	PRESENT	0
745041	744170	14173T	PARTICIPANT	\N	PRESENT	0
745042	744170	19531S	PARTICIPANT	\N	PRESENT	0
745043	744170	20084G	PARTICIPANT	\N	PRESENT	0
745044	744170	19447X	PARTICIPANT	\N	PRESENT	0
745045	744170	19503N	PARTICIPANT	\N	PRESENT	0
745046	744170	20980G	PARTICIPANT	\N	PRESENT	0
745047	744170	12028B	PARTICIPANT	\N	PRESENT	0
745048	744170	20096L	PARTICIPANT	\N	PRESENT	0
745049	744170	20026V	PARTICIPANT	\N	PRESENT	0
745050	744170	20082E	PARTICIPANT	\N	PRESENT	0
745051	744170	20056C	PARTICIPANT	\N	PRESENT	0
745052	744170	20140W	PARTICIPANT	\N	PRESENT	0
745053	744170	08047A	PARTICIPANT	\N	PRESENT	0
745054	744170	20094J	PARTICIPANT	\N	PRESENT	0
745055	744170	14151M	PARTICIPANT	\N	PRESENT	0
745056	744170	20180F	PARTICIPANT	\N	PRESENT	0
745057	744170	14257W	PARTICIPANT	\N	PRESENT	0
745058	744170	20172F	PARTICIPANT	\N	PRESENT	0
745059	744170	19527W	PARTICIPANT	\N	PRESENT	0
745060	744170	14038Y	PARTICIPANT	\N	PRESENT	0
745061	744170	20264J	PARTICIPANT	\N	PRESENT	0
745062	744170	20034V	PARTICIPANT	\N	PRESENT	0
745069	744170	19581D	PARTICIPANT	\N	PRESENT	0
745064	744170	20134Y	PARTICIPANT	\N	PRESENT	0
745065	744170	20142Y	PARTICIPANT	\N	PRESENT	0
745066	744170	20914V	PARTICIPANT	\N	PRESENT	0
745067	744170	20100N	PARTICIPANT	\N	PRESENT	0
745068	744170	20130U	PARTICIPANT	\N	PRESENT	0
745070	744170	20092G	PARTICIPANT	\N	PRESENT	0
745071	744170	19467C	PARTICIPANT	\N	PRESENT	0
745072	744170	20266L	PARTICIPANT	\N	PRESENT	0
745073	744170	04035D	PARTICIPANT	\N	PRESENT	0
745074	744170	20036X	PARTICIPANT	\N	PRESENT	0
745075	744170	08061X	PARTICIPANT	\N	PRESENT	0
745076	744170	20098N	PARTICIPANT	\N	PRESENT	0
745077	744170	12041X	PARTICIPANT	\N	PRESENT	0
745078	744170	14033T	PARTICIPANT	\N	PRESENT	0
745079	744170	19760E	PARTICIPANT	\N	PRESENT	0
745080	744170	11031D	PARTICIPANT	\N	PRESENT	0
745081	744170	20108W	PARTICIPANT	\N	PRESENT	0
745082	744170	20064C	PARTICIPANT	\N	PRESENT	0
745083	744170	20138D	PARTICIPANT	\N	PRESENT	0
745084	744170	17965H	PARTICIPANT	\N	PRESENT	0
745085	744170	14147R	PARTICIPANT	\N	PRESENT	0
745086	744170	11040E	PARTICIPANT	\N	PRESENT	0
745087	744170	04085P	PARTICIPANT	\N	PRESENT	0
745088	744170	20104S	PARTICIPANT	\N	PRESENT	0
745089	744170	20112S	PARTICIPANT	\N	PRESENT	0
745090	744170	20044X	PARTICIPANT	\N	PRESENT	0
745091	744170	19709B	PARTICIPANT	\N	PRESENT	0
745092	744170	19489J	PARTICIPANT	\N	PRESENT	0
745093	744170	19695N	PARTICIPANT	\N	PRESENT	0
745094	744170	19565D	PARTICIPANT	\N	PRESENT	0
745095	744170	19657G	PARTICIPANT	\N	PRESENT	0
745096	744170	20102Q	PARTICIPANT	\N	PRESENT	0
745097	744170	11077T	PARTICIPANT	\N	PRESENT	0
745098	744170	19593H	PARTICIPANT	\N	PRESENT	0
745099	744170	08015R	PARTICIPANT	\N	PRESENT	0
745100	744170	20046A	PARTICIPANT	\N	PRESENT	0
745101	744170	19768N	PARTICIPANT	\N	PRESENT	0
745102	744170	19301E	PARTICIPANT	\N	PRESENT	0
745103	744170	19621T	PARTICIPANT	\N	PRESENT	0
745104	744170	19525U	PARTICIPANT	\N	PRESENT	0
745105	744170	19723Y	PARTICIPANT	\N	PRESENT	0
745106	744170	20128B	PARTICIPANT	\N	PRESENT	0
745107	744170	04045F	PARTICIPANT	\N	PRESENT	0
745108	744170	19705W	PARTICIPANT	\N	PRESENT	0
745109	744170	20024T	PARTICIPANT	\N	PRESENT	0
745110	744170	08073C	PARTICIPANT	\N	PRESENT	0
745111	744170	20106U	PARTICIPANT	\N	PRESENT	0
745112	744170	14213J	PARTICIPANT	\N	PRESENT	0
745113	744170	19697Q	PARTICIPANT	\N	PRESENT	0
745114	744170	20058E	PARTICIPANT	\N	PRESENT	0
745115	744170	14026U	PARTICIPANT	\N	PRESENT	0
745116	744170	19637C	PARTICIPANT	\N	PRESENT	0
745117	744170	08069G	PARTICIPANT	\N	PRESENT	0
745118	744170	19651A	PARTICIPANT	\N	PRESENT	0
745119	744170	19591F	PARTICIPANT	\N	PRESENT	0
745120	744170	20062A	PARTICIPANT	\N	PRESENT	0
745121	744170	11033F	PARTICIPANT	\N	PRESENT	0
745122	744170	14059S	PARTICIPANT	\N	PRESENT	0
745123	744170	19329S	PARTICIPANT	\N	PRESENT	0
745124	744170	08056B	PARTICIPANT	\N	PRESENT	0
745125	744170	20150Y	PARTICIPANT	\N	PRESENT	0
745126	744170	20152B	PARTICIPANT	\N	PRESENT	0
745127	744170	14249W	PARTICIPANT	\N	PRESENT	0
745128	744170	14037X	PARTICIPANT	\N	PRESENT	0
745129	744170	19782L	PARTICIPANT	\N	PRESENT	0
745130	744170	20124W	PARTICIPANT	\N	PRESENT	0
745131	744170	20054A	PARTICIPANT	\N	PRESENT	0
745132	744170	20020P	PARTICIPANT	\N	PRESENT	0
762613	761919	19711U	PARTICIPANT	\N	PRESENT	0
762643	761919	20024T	PARTICIPANT	\N	PRESENT	0
762644	761919	20140W	PARTICIPANT	\N	PRESENT	0
762645	761919	19349W	PARTICIPANT	\N	PRESENT	0
762646	761919	21056G	PARTICIPANT	\N	PRESENT	0
762658	761919	20042V	PARTICIPANT	\N	PRESENT	0
762665	761919	19479G	PARTICIPANT	\N	PRESENT	0
766016	765399	19691J	PARTICIPANT	\N	PRESENT	0
766017	765399	14215L	PARTICIPANT	\N	PRESENT	0
766018	765399	19553Y	PARTICIPANT	\N	PRESENT	0
766019	765399	14187A	PARTICIPANT	\N	PRESENT	0
766020	765399	14217N	PARTICIPANT	\N	PRESENT	0
766021	765399	21064G	PARTICIPANT	\N	PRESENT	0
766022	765399	21045D	PARTICIPANT	\N	PRESENT	0
766023	765399	19657G	PARTICIPANT	\N	PRESENT	0
766024	765399	20140W	PARTICIPANT	\N	PRESENT	0
766025	765399	21037D	PARTICIPANT	\N	PRESENT	0
766026	765399	19703U	PARTICIPANT	\N	PRESENT	0
766027	765399	14026U	PARTICIPANT	\N	PRESENT	0
766028	765399	19723Y	PARTICIPANT	\N	PRESENT	0
766029	765399	20048C	PARTICIPANT	\N	PRESENT	0
766030	765399	21071F	PARTICIPANT	\N	PRESENT	0
766031	765399	19347U	PARTICIPANT	\N	PRESENT	0
766032	765399	21043B	PARTICIPANT	\N	PRESENT	0
766033	765399	21069M	PARTICIPANT	\N	PRESENT	0
766034	765399	14219Q	PARTICIPANT	\N	PRESENT	0
766035	765399	19563B	PARTICIPANT	\N	PRESENT	0
766036	765399	07029T	PARTICIPANT	\N	PRESENT	0
766037	765399	20034V	PARTICIPANT	\N	PRESENT	0
766038	765399	17965H	PARTICIPANT	\N	PRESENT	0
766039	765399	11056N	PARTICIPANT	\N	PRESENT	0
766709	765401	14030Q	PARTICIPANT	\N	PRESENT	0
766710	765401	20096L	PARTICIPANT	\N	PRESENT	0
766783	765401	20264J	PARTICIPANT	\N	PRESENT	0
766712	765401	19713W	PARTICIPANT	\N	PRESENT	0
766713	765401	19565D	PARTICIPANT	\N	PRESENT	0
766714	765401	21053D	PARTICIPANT	\N	PRESENT	0
766715	763305	11040E	PARTICIPANT	\N	PRESENT	0
766716	763305	07004J	PARTICIPANT	\N	PRESENT	0
766717	765401	14069U	PARTICIPANT	\N	PRESENT	0
766718	765401	04092N	PARTICIPANT	\N	PRESENT	0
766719	765401	98022P	PARTICIPANT	\N	PRESENT	0
766720	765401	19629C	PARTICIPANT	\N	PRESENT	0
766721	763305	19667J	PARTICIPANT	\N	PRESENT	0
766722	765401	14107H	PARTICIPANT	\N	PRESENT	0
766723	765401	14026U	PARTICIPANT	\N	PRESENT	0
766724	765401	14042U	PARTICIPANT	\N	PRESENT	0
766725	765401	20076G	PARTICIPANT	\N	PRESENT	0
766726	765401	17779H	PARTICIPANT	\N	PRESENT	0
766727	763305	20116W	PARTICIPANT	\N	PRESENT	0
766781	763305	20070A	PARTICIPANT	\N	PRESENT	0
766729	765401	11045K	PARTICIPANT	\N	PRESENT	0
766730	765401	19683J	PARTICIPANT	\N	PRESENT	0
766782	765401	21058J	PARTICIPANT	\N	PRESENT	0
766732	765401	20130U	PARTICIPANT	\N	PRESENT	0
766733	763305	11074Q	PARTICIPANT	\N	PRESENT	0
766734	765401	17965H	PARTICIPANT	\N	PRESENT	0
766735	763305	19573D	PARTICIPANT	\N	PRESENT	0
766736	763305	14225N	PRESIDENT	0	PRESENT	0
766737	765401	14275Y	PARTICIPANT	\N	PRESENT	0
766738	765401	14281W	PARTICIPANT	\N	PRESENT	0
766739	763305	11048N	PARTICIPANT	\N	PRESENT	0
766740	763305	19687N	PARTICIPANT	\N	PRESENT	0
766741	763305	19399H	PARTICIPANT	\N	PRESENT	0
766742	763305	07029T	PARTICIPANT	\N	PRESENT	0
766743	763305	21048G	PARTICIPANT	\N	PRESENT	0
766744	765401	19760E	PARTICIPANT	\N	PRESENT	0
766745	763305	14083S	PARTICIPANT	\N	PRESENT	0
766746	765401	21084L	PARTICIPANT	\N	PRESENT	0
766747	763305	11053K	PARTICIPANT	\N	PRESENT	0
766748	763305	19349W	PARTICIPANT	\N	PRESENT	0
766749	763305	20024T	PARTICIPANT	\N	PRESENT	0
766750	763305	19647E	PARTICIPANT	\N	PRESENT	0
766751	765401	21049H	PARTICIPANT	\N	PRESENT	0
766752	765401	19758L	PARTICIPANT	\N	PRESENT	0
766753	765401	21045D	PARTICIPANT	\N	PRESENT	0
766754	765401	20122U	PARTICIPANT	\N	PRESENT	0
766755	765401	19569H	PARTICIPANT	\N	PRESENT	0
766756	765401	19699S	PARTICIPANT	\N	PRESENT	0
766757	763305	19711U	PARTICIPANT	\N	PRESENT	0
766758	763305	20080C	PARTICIPANT	\N	PRESENT	0
766759	765401	20028X	PARTICIPANT	\N	PRESENT	0
766760	765401	18231D	PARTICIPANT	\N	PRESENT	0
766761	765401	14073Q	PARTICIPANT	\N	PRESENT	0
766762	763305	19545Y	PARTICIPANT	\N	PRESENT	0
766763	765401	20062A	PARTICIPANT	\N	PRESENT	0
766764	765401	20148F	PARTICIPANT	\N	PRESENT	0
766765	765401	20098N	PARTICIPANT	\N	PRESENT	0
766766	765401	14213J	PARTICIPANT	\N	PRESENT	0
766767	765401	20032T	PARTICIPANT	\N	PRESENT	0
766768	765401	20180F	PARTICIPANT	\N	PRESENT	0
766769	765401	14147R	PARTICIPANT	\N	PRESENT	0
766770	765401	10015M	PARTICIPANT	\N	PRESENT	0
766771	765401	20140W	PARTICIPANT	\N	PRESENT	0
766772	765401	19703U	PARTICIPANT	\N	PRESENT	0
766773	765401	21039F	PARTICIPANT	\N	PRESENT	0
766774	765401	21055F	PARTICIPANT	\N	PRESENT	0
766775	765401	19657G	PARTICIPANT	\N	PRESENT	0
766776	765401	19533U	PARTICIPANT	\N	PRESENT	0
766777	765401	20090E	PARTICIPANT	\N	PRESENT	0
766778	765401	19798U	PARTICIPANT	\N	PRESENT	0
766785	763305	20094J	PARTICIPANT	\N	PRESENT	0
766780	765401	20112S	PARTICIPANT	\N	PRESENT	0
766786	765401	14217N	PARTICIPANT	\N	PRESENT	0
766787	765401	19553Y	PARTICIPANT	\N	PRESENT	0
766788	765401	21081H	PARTICIPANT	\N	PRESENT	0
766789	765401	14071N	PARTICIPANT	\N	PRESENT	0
766790	765401	19691J	PARTICIPANT	\N	PRESENT	0
766794	765401	17367Q	PARTICIPANT	\N	PRESENT	0
766796	765401	21063F	PARTICIPANT	\N	PRESENT	0
766797	765401	18083K	PARTICIPANT	\N	PRESENT	0
766799	763305	21072G	PARTICIPANT	\N	PRESENT	0
766800	765401	20056C	PARTICIPANT	\N	PRESENT	0
766803	765401	21085M	PARTICIPANT	\N	PRESENT	0
766804	765401	21044C	PARTICIPANT	\N	PRESENT	0
766805	765401	19591F	PARTICIPANT	\N	PRESENT	0
766806	765401	19679N	PARTICIPANT	\N	PRESENT	0
766807	765401	11043H	PARTICIPANT	\N	PRESENT	0
766808	765401	21036C	PARTICIPANT	\N	PRESENT	0
766810	765401	19954N	PARTICIPANT	\N	PRESENT	0
766811	765401	19685L	PARTICIPANT	\N	PRESENT	0
766812	765401	20040T	PARTICIPANT	\N	PRESENT	0
766813	765401	14089Y	PARTICIPANT	\N	PRESENT	0
766814	765401	08061X	PARTICIPANT	\N	PRESENT	0
766815	765401	08018U	PARTICIPANT	\N	PRESENT	0
766816	765401	14223L	PARTICIPANT	\N	PRESENT	0
766817	765401	19367Y	PARTICIPANT	\N	PRESENT	0
766818	765401	14059S	PARTICIPANT	\N	PRESENT	0
766819	765401	21057H	PARTICIPANT	\N	PRESENT	0
766820	765401	21043B	PARTICIPANT	\N	PRESENT	0
766821	765401	08056B	PARTICIPANT	\N	PRESENT	0
766822	765401	19723Y	PARTICIPANT	\N	PRESENT	0
766823	765401	20026V	PARTICIPANT	\N	PRESENT	0
766824	763305	14327T	PARTICIPANT	\N	PRESENT	0
766825	765401	21048G	PARTICIPANT	\N	PRESENT	0
766826	765401	20266L	PARTICIPANT	\N	PRESENT	0
766827	765401	19387D	PARTICIPANT	\N	PRESENT	0
766828	765401	08069G	PARTICIPANT	\N	PRESENT	0
766829	763305	14121F	PARTICIPANT	\N	PRESENT	0
766830	765401	20016T	PARTICIPANT	\N	PRESENT	0
766831	763305	20134Y	PARTICIPANT	\N	PRESENT	0
766834	765401	21061D	PARTICIPANT	\N	PRESENT	0
766835	765855	19383Y	PARTICIPANT	\N	PRESENT	0
766836	765855	19768N	PARTICIPANT	\N	PRESENT	0
766837	765855	20088L	PARTICIPANT	\N	PRESENT	0
766838	765855	19782L	PARTICIPANT	\N	PRESENT	0
766839	765855	14357A	PARTICIPANT	\N	PRESENT	0
766840	765855	20078J	PARTICIPANT	\N	PRESENT	0
766841	765855	19413M	PARTICIPANT	\N	PRESENT	0
766842	765855	20082E	PARTICIPANT	\N	PRESENT	0
766843	765855	14221J	PARTICIPANT	\N	PRESENT	0
766844	765855	19631V	PARTICIPANT	\N	PRESENT	0
766845	765855	20104S	PARTICIPANT	\N	PRESENT	0
766846	765855	19705W	PARTICIPANT	\N	PRESENT	0
766847	765855	08015R	PARTICIPANT	\N	PRESENT	0
766848	765855	19575F	PARTICIPANT	\N	PRESENT	0
766849	765855	20018V	PARTICIPANT	\N	PRESENT	0
766850	765855	08028W	PARTICIPANT	\N	PRESENT	0
766851	765855	19563B	PARTICIPANT	\N	PRESENT	0
766852	765855	21096Q	PARTICIPANT	\N	PRESENT	0
766853	765855	21050A	PARTICIPANT	\N	PRESENT	0
740525	736883	14221J	PARTICIPANT	\N	PRESENT	0
740587	733724	12016W	PARTICIPANT	\N	PRESENT	1
746324	746016	14213J	PARTICIPANT	\N	PRESENT	0
746325	746016	19569H	PARTICIPANT	\N	PRESENT	0
746326	746016	14026U	PARTICIPANT	\N	PRESENT	0
746327	746016	14042U	PARTICIPANT	\N	PRESENT	0
746328	746016	14217N	PARTICIPANT	\N	PRESENT	0
746329	746016	10006L	PRESIDENT	0	PRESENT	0
746330	746016	20090E	PARTICIPANT	\N	PRESENT	0
746331	746016	19415P	PARTICIPANT	\N	PRESENT	0
746332	746016	19367Y	PARTICIPANT	\N	PRESENT	0
746369	746016	19713W	PARTICIPANT	\N	PRESENT	0
746499	746498	14213J	PARTICIPANT	\N	PRESENT	0
746500	746498	18193Q	PARTICIPANT	\N	PRESENT	0
746501	746498	04092N	PARTICIPANT	\N	PRESENT	0
746502	746498	14071N	PARTICIPANT	\N	PRESENT	0
746726	744229	20070A	PARTICIPANT	\N	PRESENT	0
746734	746733	14109K	PARTICIPANT	\N	PRESENT	0
746735	746733	19631V	PARTICIPANT	\N	PRESENT	0
746736	746733	20088L	PARTICIPANT	\N	PRESENT	0
746737	746733	19782L	PARTICIPANT	\N	PRESENT	0
746738	746733	20090E	PARTICIPANT	\N	PRESENT	0
746739	746733	11101A	PARTICIPANT	\N	PRESENT	0
746740	746733	01024M	PARTICIPANT	\N	PRESENT	0
746741	746733	14213J	PARTICIPANT	\N	PRESENT	0
746742	746733	14097Y	PARTICIPANT	\N	PRESENT	0
746743	746733	14059S	PARTICIPANT	\N	PRESENT	0
746744	746733	20028X	PARTICIPANT	\N	PRESENT	0
746745	746733	19503N	PARTICIPANT	\N	PRESENT	0
746746	746733	20114U	PARTICIPANT	\N	PRESENT	0
746747	746733	14151M	PARTICIPANT	\N	PRESENT	0
746870	746091	14231L	PRESIDENT	0	PRESENT	0
746871	746091	19489J	PARTICIPANT	\N	PRESENT	0
746872	746091	20070A	PARTICIPANT	\N	PRESENT	0
746873	746091	19820Y	PARTICIPANT	\N	PRESENT	0
746874	746091	14151M	PARTICIPANT	\N	PRESENT	0
746875	746091	20114U	PARTICIPANT	\N	PRESENT	0
746876	746091	17637T	PARTICIPANT	\N	PRESENT	0
746877	746091	07004J	PARTICIPANT	\N	PRESENT	0
746878	746091	01057W	PARTICIPANT	\N	PRESENT	0
746879	746091	14107H	PARTICIPANT	\N	PRESENT	0
746880	746091	19826F	PARTICIPANT	\N	PRESENT	0
746881	746091	05008E	PARTICIPANT	\N	PRESENT	0
746882	746091	19735D	PARTICIPANT	\N	PRESENT	0
746883	746091	14053L	PARTICIPANT	\N	PRESENT	0
746884	746091	19585H	PARTICIPANT	\N	PRESENT	0
746885	746091	14259Y	PARTICIPANT	\N	PRESENT	0
746886	746091	14147R	PARTICIPANT	\N	PRESENT	0
746887	746091	20058E	PARTICIPANT	\N	PRESENT	0
746888	746091	14215L	PARTICIPANT	\N	PRESENT	0
746889	746091	20022R	PARTICIPANT	\N	EXCUSE	0
746890	746091	20110Q	PARTICIPANT	\N	EXCUSE	0
746891	746091	19782L	PARTICIPANT	\N	EXCUSE	0
746892	746091	20090E	PARTICIPANT	\N	EXCUSE	0
746893	746091	14327T	PARTICIPANT	\N	EXCUSE	0
746894	746091	14281W	PARTICIPANT	\N	EXCUSE	0
746895	746091	19447X	PARTICIPANT	\N	EXCUSE	0
746896	746091	19711U	PARTICIPANT	\N	EXCUSE	0
746897	746091	08010L	PARTICIPANT	\N	EXCUSE	0
746898	746091	14071N	PARTICIPANT	\N	EXCUSE	0
746899	746091	14229S	PARTICIPANT	\N	EXCUSE	0
748019	745903	20132W	PARTICIPANT	\N	PRESENT	0
748020	745903	95063L	PARTICIPANT	\N	PRESENT	0
749167	749070	14257W	PARTICIPANT	\N	PRESENT	0
749168	749070	20030R	PARTICIPANT	\N	EXCUSE	0
749169	749070	01025N	PARTICIPANT	\N	EXCUSE	0
749170	749070	14207L	PARTICIPANT	\N	EXCUSE	0
749171	749070	19563B	PARTICIPANT	\N	EXCUSE	0
749181	749031	11064N	PARTICIPANT	\N	PRESENT	0
749182	748161	11074Q	PARTICIPANT	\N	PRESENT	0
749183	748161	19671E	PARTICIPANT	\N	PRESENT	0
749898	741501	20066E	PARTICIPANT	\N	PRESENT	0
749899	741501	14030Q	PRESIDENT	0	PRESENT	0
749900	741501	20046A	PARTICIPANT	\N	PRESENT	0
749901	741501	19798U	PARTICIPANT	\N	PRESENT	0
749902	741501	19749K	PARTICIPANT	\N	PRESENT	0
749903	741501	19715Y	PARTICIPANT	\N	EXCUSE	0
749910	741501	14179A	PARTICIPANT	\N	EXCUSE	0
749911	741501	07029T	PARTICIPANT	\N	EXCUSE	0
749961	748006	17737W	PARTICIPANT	\N	EXCUSE	0
749963	748141	11083R	PARTICIPANT	\N	PRESENT	0
749964	748141	19333N	PARTICIPANT	\N	PRESENT	0
749965	748141	14073Q	PARTICIPANT	\N	PRESENT	0
749966	748141	12041X	PARTICIPANT	\N	PRESENT	0
749967	748141	08034U	PARTICIPANT	\N	PRESENT	0
749968	748141	14001X	PARTICIPANT	\N	PRESENT	0
749969	748141	14331P	PARTICIPANT	\N	PRESENT	0
749970	748141	14026U	PARTICIPANT	\N	PRESENT	0
749999	749998	11048N	PARTICIPANT	\N	PRESENT	0
750001	750000	20024T	PARTICIPANT	\N	PRESENT	0
750002	750000	20090E	PARTICIPANT	\N	PRESENT	0
750003	750000	11053K	PARTICIPANT	\N	PRESENT	0
750004	750000	14211G	PARTICIPANT	\N	PRESENT	0
750005	750000	20056C	PARTICIPANT	\N	PRESENT	0
750006	750000	19671E	PARTICIPANT	\N	PRESENT	0
750007	750000	19745F	PARTICIPANT	\N	PRESENT	0
750008	750000	19739H	PARTICIPANT	\N	PRESENT	0
750025	749971	99004R	PARTICIPANT	\N	PRESENT	0
750026	749971	14026U	PARTICIPANT	\N	PRESENT	0
750027	749971	20130U	PARTICIPANT	\N	PRESENT	0
750028	749971	19569H	PARTICIPANT	\N	PRESENT	0
750029	749971	11033F	PARTICIPANT	\N	PRESENT	0
750030	749971	19553Y	PARTICIPANT	\N	PRESENT	0
750031	749971	14071N	PARTICIPANT	\N	PRESENT	0
750032	749971	14195A	PARTICIPANT	\N	PRESENT	0
750033	749971	19591F	PARTICIPANT	\N	PRESENT	0
750034	749971	17965H	PARTICIPANT	\N	PRESENT	0
750035	749971	19760E	PARTICIPANT	\N	PRESENT	0
750036	749971	19575F	PARTICIPANT	\N	PRESENT	0
750037	749971	14281W	PARTICIPANT	\N	PRESENT	0
750038	749971	20024T	PARTICIPANT	\N	PRESENT	0
750039	749971	04085P	PARTICIPANT	\N	PRESENT	0
750040	749971	18193Q	PARTICIPANT	\N	PRESENT	0
750041	749971	19697Q	PARTICIPANT	\N	PRESENT	0
750042	749971	20102Q	PARTICIPANT	\N	PRESENT	0
750043	749971	20036X	PARTICIPANT	\N	PRESENT	0
750044	749971	20034V	PARTICIPANT	\N	PRESENT	0
750045	749971	11097X	PARTICIPANT	\N	PRESENT	0
750046	749971	14021P	PARTICIPANT	\N	PRESENT	0
750047	749971	19687N	PARTICIPANT	\N	PRESENT	0
750048	749971	17367Q	PARTICIPANT	\N	PRESENT	0
746322	746016	11045K	PARTICIPANT	\N	PRESENT	0
746323	746016	20066E	PARTICIPANT	\N	PRESENT	0
750049	749971	14217N	PARTICIPANT	\N	PRESENT	0
750050	749971	20032T	PARTICIPANT	\N	PRESENT	0
750051	749971	19798U	PARTICIPANT	\N	PRESENT	0
750052	749971	19715Y	PARTICIPANT	\N	PRESENT	0
750053	749971	08061X	PARTICIPANT	\N	PRESENT	0
750054	749971	04043D	PARTICIPANT	\N	PRESENT	0
750055	749971	12041X	PARTICIPANT	\N	PRESENT	0
750056	749971	14030Q	PARTICIPANT	\N	PRESENT	0
750057	749971	10006L	PARTICIPANT	\N	PRESENT	0
750058	749971	19711U	PARTICIPANT	\N	PRESENT	0
750059	749971	19577H	PARTICIPANT	\N	PRESENT	0
750060	749971	01028R	PARTICIPANT	\N	PRESENT	0
750061	749971	20076G	PARTICIPANT	\N	PRESENT	0
750062	749971	20914V	PARTICIPANT	\N	PRESENT	0
750063	749971	11031D	PARTICIPANT	\N	PRESENT	0
750064	749971	04092N	PARTICIPANT	\N	PRESENT	0
750065	749971	19295A	PARTICIPANT	\N	PRESENT	0
750066	749971	20078J	PARTICIPANT	\N	PRESENT	0
750067	749971	20022R	PARTICIPANT	\N	PRESENT	0
750068	749971	20074E	PARTICIPANT	\N	PRESENT	0
750069	749971	04033B	PARTICIPANT	\N	PRESENT	0
750070	749971	01048V	PARTICIPANT	\N	PRESENT	0
750071	749971	14215L	PARTICIPANT	\N	PRESENT	0
750072	749971	19820Y	PARTICIPANT	\N	PRESENT	0
750073	749971	14231L	PARTICIPANT	\N	PRESENT	0
750074	749971	20054A	PARTICIPANT	\N	PRESENT	0
750075	749971	19713W	PARTICIPANT	\N	PRESENT	0
750076	749971	14083S	PARTICIPANT	\N	PRESENT	0
750077	749971	20058E	PARTICIPANT	\N	PRESENT	0
750078	749971	08045X	PARTICIPANT	\N	PRESENT	0
750079	749971	20100N	PARTICIPANT	\N	PRESENT	0
750080	749971	08069G	PARTICIPANT	\N	PRESENT	0
750081	749971	20062A	PARTICIPANT	\N	PRESENT	0
750082	749971	08034U	PARTICIPANT	\N	PRESENT	0
760485	760483	19447X	PARTICIPANT	\N	PRESENT	0
760486	760483	14089Y	PARTICIPANT	\N	PRESENT	0
761000	760999	21090J	PARTICIPANT	\N	PRESENT	0
761001	760999	08009T	PARTICIPANT	\N	PRESENT	0
761005	761004	11053K	PARTICIPANT	\N	PRESENT	0
761007	761006	11053K	PARTICIPANT	\N	PRESENT	0
761010	761009	11053K	PARTICIPANT	\N	PRESENT	0
761013	761012	11048N	PARTICIPANT	\N	PRESENT	0
764907	761746	19826F	PARTICIPANT	\N	PRESENT	0
764911	761716	20084G	PARTICIPANT	\N	PRESENT	0
764914	761716	14069U	PARTICIPANT	\N	PRESENT	0
764915	764374	07029T	PARTICIPANT	\N	EXCUSE	0
764916	764374	20080C	PARTICIPANT	\N	EXCUSE	0
764917	764374	20050V	PARTICIPANT	\N	EXCUSE	0
764918	761716	14133K	PARTICIPANT	\N	PRESENT	0
764919	761716	14213J	PARTICIPANT	\N	PRESENT	0
764920	761716	21066J	PARTICIPANT	\N	PRESENT	0
764921	761716	14021P	PARTICIPANT	\N	PRESENT	0
764922	761716	19758L	PARTICIPANT	\N	PRESENT	0
764923	761716	20248J	PARTICIPANT	\N	PRESENT	0
764924	761716	20052X	PARTICIPANT	\N	PRESENT	0
764925	761716	21075K	PARTICIPANT	\N	PRESENT	0
764926	761716	20082E	PARTICIPANT	\N	PRESENT	0
764927	761716	14205J	PARTICIPANT	\N	PRESENT	0
764928	761716	14187A	PARTICIPANT	\N	PRESENT	0
764929	761716	14073Q	PARTICIPANT	\N	PRESENT	0
764968	761717	14073Q	PARTICIPANT	\N	PRESENT	0
764969	761717	19563B	PARTICIPANT	\N	PRESENT	0
764970	761717	21092L	PARTICIPANT	\N	PRESENT	0
764971	761717	21075K	PARTICIPANT	\N	PRESENT	0
764972	761717	21034A	PARTICIPANT	\N	PRESENT	0
764973	761717	19760E	PARTICIPANT	\N	PRESENT	0
764974	761717	20082E	PARTICIPANT	\N	PRESENT	0
764975	761717	20084G	PARTICIPANT	\N	PRESENT	0
764976	761717	20130U	PARTICIPANT	\N	PRESENT	0
764977	761717	21096Q	PARTICIPANT	\N	PRESENT	0
764978	761717	21054E	PARTICIPANT	\N	PRESENT	0
764979	761717	20116W	PARTICIPANT	\N	PRESENT	0
764980	761717	19629C	PARTICIPANT	\N	PRESENT	0
764981	761717	19866P	PARTICIPANT	\N	PRESENT	0
764982	761717	21040X	PARTICIPANT	\N	PRESENT	0
764983	761717	14207L	PARTICIPANT	\N	PRESENT	0
764984	761717	21066J	PARTICIPANT	\N	PRESENT	0
764985	761717	20054A	PARTICIPANT	\N	PRESENT	0
764986	761717	14133K	PARTICIPANT	\N	PRESENT	0
764987	761717	21056G	PARTICIPANT	\N	PRESENT	0
764988	761717	14071N	PARTICIPANT	\N	PRESENT	0
764989	761717	14357A	PARTICIPANT	\N	PRESENT	0
764990	761717	14213J	PARTICIPANT	\N	PRESENT	0
764991	761717	19399H	PARTICIPANT	\N	PRESENT	0
764992	761717	20032T	PARTICIPANT	\N	PRESENT	0
764993	761717	20090E	PARTICIPANT	\N	PRESENT	0
764994	761717	14026U	PARTICIPANT	\N	PRESENT	0
764995	761717	14187A	PARTICIPANT	\N	PRESENT	0
764996	761717	19758L	PARTICIPANT	\N	PRESENT	0
764998	761717	21050A	PARTICIPANT	\N	PRESENT	0
764999	761717	21071F	PARTICIPANT	\N	PRESENT	0
765000	761717	21097R	PARTICIPANT	\N	PRESENT	0
765001	761717	19782L	PARTICIPANT	\N	PRESENT	0
765002	761717	21046E	PARTICIPANT	\N	PRESENT	0
765007	764871	20086J	PARTICIPANT	\N	PRESENT	0
765008	764871	14133K	PRESIDENT	0	PRESENT	0
764966	761717	19479G	PARTICIPANT	\N	PRESENT	0
764967	761717	14205J	PARTICIPANT	\N	PRESENT	0
765009	764871	14031R	PARTICIPANT	\N	PRESENT	0
765010	764871	21086N	PARTICIPANT	\N	PRESENT	0
765011	764871	21093M	PARTICIPANT	\N	PRESENT	0
765012	764871	19826F	PARTICIPANT	\N	PRESENT	0
765013	764871	20094J	PARTICIPANT	\N	PRESENT	0
765014	764871	14237S	PARTICIPANT	\N	PRESENT	0
765015	764871	21044C	PARTICIPANT	\N	PRESENT	0
765016	764871	20180F	PARTICIPANT	\N	PRESENT	0
765017	764871	18207D	PARTICIPANT	\N	PRESENT	0
765018	764871	21066J	PARTICIPANT	\N	PRESENT	0
765019	764871	20286Q	PARTICIPANT	\N	PRESENT	0
765020	764871	08018U	PARTICIPANT	\N	PRESENT	0
765021	764871	20126Y	PARTICIPANT	\N	PRESENT	0
765022	764871	11065P	PARTICIPANT	\N	PRESENT	0
765023	764871	20084G	PRESIDENT	1	PRESENT	0
765024	764871	20106U	PARTICIPANT	\N	EXCUSE	0
765025	764871	11053K	PARTICIPANT	\N	EXCUSE	0
765058	764374	20086J	PARTICIPANT	\N	PRESENT	0
765059	764374	14331P	PARTICIPANT	\N	PRESENT	0
765060	764374	19667J	PARTICIPANT	\N	PRESENT	0
765061	764374	21090J	PARTICIPANT	\N	PRESENT	0
765071	761717	14069U	PARTICIPANT	\N	PRESENT	0
765073	761717	14217N	PARTICIPANT	\N	PRESENT	0
765074	761717	20248J	PARTICIPANT	\N	PRESENT	0
765075	761717	20062A	PARTICIPANT	\N	PRESENT	0
765076	761717	20070A	PARTICIPANT	\N	PRESENT	0
765100	761718	21055F	PARTICIPANT	\N	PRESENT	0
765101	761718	19447X	PARTICIPANT	\N	PRESENT	0
765103	761718	04047H	PARTICIPANT	\N	PRESENT	0
765105	761718	17737W	PARTICIPANT	\N	PRESENT	0
765106	761718	19569H	PARTICIPANT	\N	PRESENT	0
765107	761718	14089Y	PARTICIPANT	\N	PRESENT	0
765109	761718	08061X	PARTICIPANT	\N	PRESENT	0
765115	761718	18231D	PARTICIPANT	\N	PRESENT	0
765111	761718	21071F	PARTICIPANT	\N	PRESENT	0
765112	761718	14059S	PARTICIPANT	\N	PRESENT	0
765113	761718	21058J	PARTICIPANT	\N	PRESENT	0
765114	761718	21088Q	PARTICIPANT	\N	PRESENT	0
765116	761718	14151M	PARTICIPANT	\N	PRESENT	0
765117	761718	21079P	PARTICIPANT	\N	PRESENT	0
765118	761718	21060C	PARTICIPANT	\N	PRESENT	0
765119	761718	21093M	PARTICIPANT	\N	PRESENT	0
765120	761718	20266L	PARTICIPANT	\N	PRESENT	0
765121	761718	20110Q	PARTICIPANT	\N	PRESENT	0
765122	761718	19649G	PARTICIPANT	\N	PRESENT	0
765123	761718	14251Q	PARTICIPANT	\N	PRESENT	0
765098	761718	14111D	PARTICIPANT	\N	PRESENT	0
765099	761718	21069M	PARTICIPANT	\N	PRESENT	0
765124	761718	19331L	PARTICIPANT	\N	PRESENT	0
765126	761718	21066J	PARTICIPANT	\N	PRESENT	0
765127	761718	19629C	PARTICIPANT	\N	PRESENT	0
765128	761718	11045K	PARTICIPANT	\N	PRESENT	0
765129	761718	19782L	PARTICIPANT	\N	PRESENT	0
765130	761718	19111A	PARTICIPANT	\N	PRESENT	0
765131	761718	20062A	PARTICIPANT	\N	PRESENT	0
765132	761718	04033B	PARTICIPANT	\N	PRESENT	0
765133	761718	20032T	PARTICIPANT	\N	PRESENT	0
765134	761718	14329V	PARTICIPANT	\N	PRESENT	0
765135	761718	20104S	PARTICIPANT	\N	PRESENT	0
765136	761718	08018U	PARTICIPANT	\N	PRESENT	0
765137	761718	21044C	PARTICIPANT	\N	PRESENT	0
765138	761718	19699S	PARTICIPANT	\N	PRESENT	0
765139	761718	14231L	PARTICIPANT	\N	PRESENT	0
765140	761718	19693L	PARTICIPANT	\N	PRESENT	0
765141	761718	21077M	PARTICIPANT	\N	PRESENT	0
765142	761718	14055N	PARTICIPANT	\N	PRESENT	0
765143	761718	14213J	PARTICIPANT	\N	PRESENT	0
765144	761718	19687N	PARTICIPANT	\N	PRESENT	0
765145	761718	20040T	PARTICIPANT	\N	PRESENT	0
765146	761718	21063F	PARTICIPANT	\N	PRESENT	0
765147	761718	20252E	PARTICIPANT	\N	PRESENT	0
765148	761718	19347U	PARTICIPANT	\N	PRESENT	0
765149	761718	20134Y	PARTICIPANT	\N	PRESENT	0
765150	761718	19573D	PARTICIPANT	\N	PRESENT	0
765151	761718	20088L	PARTICIPANT	\N	PRESENT	0
765152	761718	14030Q	PARTICIPANT	\N	PRESENT	0
765153	761718	14281W	PARTICIPANT	\N	PRESENT	0
765154	761718	20052X	PARTICIPANT	\N	PRESENT	0
765155	761718	21091K	PARTICIPANT	\N	PRESENT	0
765156	761718	19673G	PARTICIPANT	\N	PRESENT	0
765157	761718	21082J	PARTICIPANT	\N	PRESENT	0
765158	761718	14038Y	PARTICIPANT	\N	PRESENT	0
765159	761718	19711U	PARTICIPANT	\N	PRESENT	0
765160	761718	05008E	PARTICIPANT	\N	PRESENT	0
765161	761718	11027H	PARTICIPANT	\N	PRESENT	0
765162	761718	19553Y	PARTICIPANT	\N	PRESENT	0
765165	761718	20082E	PARTICIPANT	\N	PRESENT	0
765166	761718	21075K	PARTICIPANT	\N	PRESENT	0
765167	761718	08073C	PARTICIPANT	\N	PRESENT	0
765168	761718	18395Y	PARTICIPANT	\N	PRESENT	0
765169	761718	20068G	PARTICIPANT	\N	PRESENT	0
765170	761718	20248J	PARTICIPANT	\N	PRESENT	0
765171	761718	14121F	PARTICIPANT	\N	PRESENT	0
765179	761718	21034A	PARTICIPANT	\N	PRESENT	0
765180	761718	19621T	PARTICIPANT	\N	PRESENT	0
739778	739777	14107H	PARTICIPANT	\N	PRESENT	0
742429	740314	14179A	PARTICIPANT	\N	PRESENT	0
742430	740314	20094J	PARTICIPANT	\N	PRESENT	0
742431	740318	14179A	PARTICIPANT	\N	PRESENT	0
742432	740318	20094J	PARTICIPANT	\N	PRESENT	0
742433	740318	20060X	PARTICIPANT	\N	PRESENT	0
743812	740643	20048C	PARTICIPANT	\N	PRESENT	0
743813	740643	19745F	PARTICIPANT	\N	PRESENT	0
743814	740643	20052X	PARTICIPANT	\N	PRESENT	0
743815	740643	19699S	PARTICIPANT	\N	PRESENT	0
743816	740643	11012A	PARTICIPANT	\N	PRESENT	0
743817	740643	14229S	PARTICIPANT	\N	PRESENT	0
743818	740643	19683J	PARTICIPANT	\N	PRESENT	0
743819	740643	19057M	PARTICIPANT	\N	PRESENT	0
743821	740643	11045K	PARTICIPANT	\N	PRESENT	0
743840	740643	19527W	PARTICIPANT	\N	PRESENT	0
743844	740643	19295A	PARTICIPANT	\N	PRESENT	0
743846	740643	20142Y	PARTICIPANT	\N	PRESENT	0
743847	740643	20060X	PARTICIPANT	\N	PRESENT	0
743848	740643	20152B	PARTICIPANT	\N	PRESENT	0
743872	740643	14225N	PARTICIPANT	\N	PRESENT	0
743896	740643	01028R	PARTICIPANT	\N	PRESENT	0
743897	740643	20298U	PARTICIPANT	\N	PRESENT	0
743898	740643	18193Q	PARTICIPANT	\N	PRESENT	0
743899	740643	14071N	PARTICIPANT	\N	PRESENT	0
743900	740643	20126Y	PARTICIPANT	\N	PRESENT	0
743952	740644	14030Q	PARTICIPANT	\N	PRESENT	0
743953	740644	19735D	PARTICIPANT	\N	PRESENT	0
743954	740644	14211G	PARTICIPANT	\N	PRESENT	0
743955	740644	19723Y	PARTICIPANT	\N	PRESENT	0
743956	740644	20038A	PARTICIPANT	\N	PRESENT	0
743957	740644	19745F	PARTICIPANT	\N	PRESENT	0
743958	740644	20102Q	PARTICIPANT	\N	PRESENT	0
743959	740644	14071N	PARTICIPANT	\N	PRESENT	0
743961	740644	04057K	PARTICIPANT	\N	PRESENT	0
743962	740644	20040T	PARTICIPANT	\N	PRESENT	0
743963	740644	11012A	PARTICIPANT	\N	PRESENT	0
743964	740644	20090E	PARTICIPANT	\N	PRESENT	0
743965	740644	20130U	PARTICIPANT	\N	PRESENT	0
743967	740644	11031D	PARTICIPANT	\N	PRESENT	0
743968	740644	17965H	PARTICIPANT	\N	PRESENT	0
743972	740644	11053K	PARTICIPANT	\N	PRESENT	0
743973	740644	19699S	PARTICIPANT	\N	PRESENT	0
743974	740644	20100N	PARTICIPANT	\N	PRESENT	0
743975	740644	14217N	PARTICIPANT	\N	PRESENT	0
743976	740644	20064C	PARTICIPANT	\N	PRESENT	0
743979	740644	20026V	PARTICIPANT	\N	PRESENT	0
743980	740644	20108W	PARTICIPANT	\N	PRESENT	0
743981	740644	14059S	PARTICIPANT	\N	PRESENT	0
743982	740644	08010L	PARTICIPANT	\N	PRESENT	0
743983	740644	19503N	PARTICIPANT	\N	PRESENT	0
743984	740644	20252E	PARTICIPANT	\N	PRESENT	0
743985	740644	18193Q	PARTICIPANT	\N	PRESENT	0
743986	740644	19651A	PARTICIPANT	\N	PRESENT	0
743987	740644	20150Y	PARTICIPANT	\N	PRESENT	0
743988	740644	07029T	PARTICIPANT	\N	PRESENT	0
743992	740644	14083S	PARTICIPANT	\N	PRESENT	0
744009	740644	19515S	PARTICIPANT	\N	PRESENT	0
743946	740644	11045K	PARTICIPANT	\N	PRESENT	0
743951	740644	19713W	PARTICIPANT	\N	PRESENT	0
744010	740644	19251M	PARTICIPANT	\N	PRESENT	0
744011	740644	17023S	PARTICIPANT	\N	PRESENT	0
744012	740644	19711U	PARTICIPANT	\N	PRESENT	0
744013	740644	20136B	PARTICIPANT	\N	PRESENT	0
744047	740645	20150Y	PARTICIPANT	\N	PRESENT	0
744048	740645	14211G	PARTICIPANT	\N	PRESENT	0
744049	740645	14219Q	PARTICIPANT	\N	PRESENT	0
744050	740645	19745F	PARTICIPANT	\N	PRESENT	0
744051	740645	19713W	PARTICIPANT	\N	PRESENT	0
744052	740645	11012A	PARTICIPANT	\N	PRESENT	0
744053	740645	19251M	PARTICIPANT	\N	PRESENT	0
744054	740645	19651A	PARTICIPANT	\N	PRESENT	0
744055	740645	20108W	PARTICIPANT	\N	PRESENT	0
744056	740645	10015M	PARTICIPANT	\N	PRESENT	0
744057	740645	19723Y	PARTICIPANT	\N	PRESENT	0
744058	740645	20026V	PARTICIPANT	\N	PRESENT	0
744059	740645	14071N	PARTICIPANT	\N	PRESENT	0
744060	740645	19711U	PARTICIPANT	\N	PRESENT	0
744061	740645	08010L	PARTICIPANT	\N	PRESENT	0
744062	740645	20252E	PARTICIPANT	\N	PRESENT	0
744063	740645	20136B	PARTICIPANT	\N	PRESENT	0
744064	740645	20102Q	PARTICIPANT	\N	PRESENT	0
744065	740645	11053K	PARTICIPANT	\N	PRESENT	0
744066	740645	04043D	PARTICIPANT	\N	PRESENT	0
744067	740645	19735D	PARTICIPANT	\N	PRESENT	0
744068	743969	14038Y	PARTICIPANT	\N	PRESENT	0
744069	743969	04070G	PRESIDENT	0	PRESENT	0
744070	743969	20060X	PARTICIPANT	\N	PRESENT	0
744071	743969	20062A	PARTICIPANT	\N	PRESENT	0
744072	743969	10015M	PARTICIPANT	\N	PRESENT	0
744073	743969	14179A	PARTICIPANT	\N	PRESENT	0
744074	743969	20094J	PARTICIPANT	\N	PRESENT	0
744075	743969	20152B	PARTICIPANT	\N	PRESENT	0
744076	743969	14229S	PARTICIPANT	\N	PRESENT	0
744044	740645	11045K	PARTICIPANT	\N	PRESENT	0
744046	740645	20100N	PARTICIPANT	\N	PRESENT	0
744077	743969	14030Q	PARTICIPANT	\N	PRESENT	0
744511	744045	20024T	PARTICIPANT	\N	PRESENT	0
744512	744045	14213J	PARTICIPANT	\N	PRESENT	0
744513	744045	17965H	PARTICIPANT	\N	PRESENT	0
744514	744045	19725B	PARTICIPANT	\N	PRESENT	0
744515	744045	20066E	PARTICIPANT	\N	PRESENT	0
744516	744045	11031D	PARTICIPANT	\N	PRESENT	0
745133	744170	19383Y	PARTICIPANT	\N	PRESENT	0
744518	744045	19735D	PRESIDENT	0	PRESENT	0
745134	744170	17737W	PARTICIPANT	\N	PRESENT	0
745135	744170	14357A	PARTICIPANT	\N	PRESENT	0
745136	744170	07033P	PARTICIPANT	\N	PRESENT	0
745137	744170	14217N	PARTICIPANT	\N	PRESENT	0
745138	744170	14195A	PARTICIPANT	\N	PRESENT	0
745139	744170	20120S	PARTICIPANT	\N	PRESENT	0
745140	744170	20086J	PARTICIPANT	\N	PRESENT	0
745141	744170	19367Y	PARTICIPANT	\N	PRESENT	0
745142	744170	14221J	PARTICIPANT	\N	PRESENT	0
745143	744170	14111D	PARTICIPANT	\N	PRESENT	0
745144	744170	95041E	PARTICIPANT	\N	PRESENT	0
745145	744170	04057K	PARTICIPANT	\N	PRESENT	0
745146	744170	14193X	PARTICIPANT	\N	PRESENT	0
745147	744170	19545Y	PARTICIPANT	\N	PRESENT	0
745148	744170	19798U	PARTICIPANT	\N	PRESENT	0
745149	744170	14211G	PARTICIPANT	\N	PRESENT	0
745150	744170	20050V	PARTICIPANT	\N	PRESENT	0
745151	744170	19533U	PARTICIPANT	\N	PRESENT	0
745152	744170	20118Y	PARTICIPANT	\N	PRESENT	0
745153	744170	11064N	PARTICIPANT	\N	PRESENT	0
745154	744170	20090E	PARTICIPANT	\N	PRESENT	0
745155	744170	17589D	PARTICIPANT	\N	PRESENT	0
745156	744170	14069U	PARTICIPANT	\N	PRESENT	0
745157	744170	20122U	PARTICIPANT	\N	PRESENT	0
745158	744170	04033B	PARTICIPANT	\N	PRESENT	0
745159	744170	19701S	PARTICIPANT	\N	PRESENT	0
745160	744170	14187A	PARTICIPANT	\N	PRESENT	0
745161	744170	05008E	PARTICIPANT	\N	PRESENT	0
745162	744170	14071N	PARTICIPANT	\N	PRESENT	0
745163	744170	19629C	PARTICIPANT	\N	PRESENT	0
745164	744170	14215L	PARTICIPANT	\N	PRESENT	0
745165	744170	19387D	PARTICIPANT	\N	PRESENT	0
745166	744170	20132W	PARTICIPANT	\N	PRESENT	0
745167	744170	11097X	PARTICIPANT	\N	PRESENT	0
745168	744170	19553Y	PARTICIPANT	\N	PRESENT	0
745169	744170	19563B	PARTICIPANT	\N	PRESENT	0
745170	744170	19747H	PARTICIPANT	\N	PRESENT	0
745171	744170	14133K	PARTICIPANT	\N	PRESENT	0
745172	744170	11048N	PARTICIPANT	\N	PRESENT	0
745174	744170	19719D	PARTICIPANT	\N	PRESENT	0
745175	744170	20116W	PARTICIPANT	\N	PRESENT	0
745176	744170	14207L	PARTICIPANT	\N	PRESENT	0
745177	744170	98022P	PARTICIPANT	\N	PRESENT	0
745178	744170	20072C	PARTICIPANT	\N	PRESENT	0
745179	744170	10015M	PARTICIPANT	\N	PRESENT	0
745180	744170	19713W	PARTICIPANT	\N	PRESENT	0
745181	744170	19319Q	PARTICIPANT	\N	PRESENT	0
745182	744170	20048C	PARTICIPANT	\N	PRESENT	0
745183	744170	19699S	PARTICIPANT	\N	PRESENT	0
745184	744170	20052X	PARTICIPANT	\N	PRESENT	0
745185	744170	19441R	PARTICIPANT	\N	PRESENT	0
745186	744170	14329V	PARTICIPANT	\N	PRESENT	0
745187	744170	19479G	PARTICIPANT	\N	PRESENT	0
745188	744170	14219Q	PARTICIPANT	\N	PRESENT	0
745189	744170	14042U	PARTICIPANT	\N	PRESENT	0
765352	761719	14089Y	PARTICIPANT	\N	PRESENT	0
765353	761719	21084L	PARTICIPANT	\N	PRESENT	0
765354	761719	20134Y	PARTICIPANT	\N	PRESENT	0
765355	761719	21071F	PARTICIPANT	\N	PRESENT	0
765356	761719	14205J	PARTICIPANT	\N	PRESENT	0
765357	761719	21063F	PARTICIPANT	\N	PRESENT	0
765358	761719	21066J	PARTICIPANT	\N	PRESENT	0
765359	761719	08018U	PARTICIPANT	\N	PRESENT	0
765360	761719	21078N	PARTICIPANT	\N	PRESENT	0
765361	761719	19673G	PARTICIPANT	\N	PRESENT	0
765362	761719	20124W	PARTICIPANT	\N	PRESENT	0
765363	761719	21091K	PARTICIPANT	\N	PRESENT	0
765364	761719	21085M	PARTICIPANT	\N	PRESENT	0
765365	761719	21082J	PARTICIPANT	\N	PRESENT	0
765366	761719	19649G	PARTICIPANT	\N	PRESENT	0
765367	761719	14021P	PARTICIPANT	\N	PRESENT	0
765368	761719	19711U	PARTICIPANT	\N	PRESENT	0
765369	761719	17737W	PARTICIPANT	\N	PRESENT	0
765370	761719	21053D	PARTICIPANT	\N	PRESENT	0
765371	761719	21095P	PARTICIPANT	\N	PRESENT	0
765372	761719	21090J	PARTICIPANT	\N	PRESENT	0
765373	761719	20062A	PARTICIPANT	\N	PRESENT	0
765374	761719	11090Q	PARTICIPANT	\N	PRESENT	0
765375	761719	19749K	PARTICIPANT	\N	PRESENT	0
765376	761719	20034V	PARTICIPANT	\N	PRESENT	0
765377	761719	21057H	PARTICIPANT	\N	PRESENT	0
765378	761719	19695N	PARTICIPANT	\N	PRESENT	0
765379	761719	14037X	PARTICIPANT	\N	PRESENT	0
765380	761719	14069U	PARTICIPANT	\N	PRESENT	0
765381	761719	19111A	PARTICIPANT	\N	PRESENT	0
765382	761719	19647E	PARTICIPANT	\N	PRESENT	0
765383	761719	21034A	PARTICIPANT	\N	PRESENT	0
765384	761719	04033B	PARTICIPANT	\N	PRESENT	0
765385	761719	11027H	PARTICIPANT	\N	PRESENT	0
765386	761719	05008E	PARTICIPANT	\N	PRESENT	0
765387	761719	21073H	PARTICIPANT	\N	PRESENT	0
765388	761719	19621T	PARTICIPANT	\N	PRESENT	0
765389	761719	20052X	PARTICIPANT	\N	PRESENT	0
765390	761719	20092G	PARTICIPANT	\N	PRESENT	0
765391	761719	21038E	PARTICIPANT	\N	PRESENT	0
765392	761719	21037D	PARTICIPANT	\N	PRESENT	0
765393	761719	21093M	PARTICIPANT	\N	PRESENT	0
765394	761719	07029T	PARTICIPANT	\N	PRESENT	0
765395	761719	11110B	PARTICIPANT	\N	PRESENT	0
765396	761719	20252E	PARTICIPANT	\N	PRESENT	0
765397	761719	21088Q	PARTICIPANT	\N	PRESENT	0
765406	761719	11048N	PARTICIPANT	\N	PRESENT	0
766854	765855	14329V	PARTICIPANT	\N	PRESENT	0
766855	765855	14038Y	PARTICIPANT	\N	PRESENT	0
766856	765855	21052C	PARTICIPANT	\N	PRESENT	0
766857	765855	21054E	PARTICIPANT	\N	PRESENT	0
766858	765855	14187A	PRESIDENT	0	PRESENT	0
766859	765855	21075K	PARTICIPANT	\N	PRESENT	0
766860	765855	21083K	PARTICIPANT	\N	PRESENT	0
766861	765855	21086N	PARTICIPANT	\N	PRESENT	0
766862	765855	19695N	PARTICIPANT	\N	PRESENT	0
766863	765855	21092L	PARTICIPANT	\N	PRESENT	0
766864	765855	14033T	PARTICIPANT	\N	PRESENT	0
766865	765855	11090Q	PARTICIPANT	\N	PRESENT	0
766866	765855	21093M	PARTICIPANT	\N	PRESENT	0
766867	765855	20054A	PARTICIPANT	\N	PRESENT	0
766868	765855	14205J	PARTICIPANT	\N	PRESENT	0
766869	765855	20060X	PARTICIPANT	\N	PRESENT	0
766870	765855	20066E	PARTICIPANT	\N	PRESENT	0
766871	765855	19507S	PARTICIPANT	\N	PRESENT	0
766872	765855	21066J	PARTICIPANT	\N	PRESENT	0
766873	765855	14207L	PARTICIPANT	\N	PRESENT	0
766874	765855	14257W	PARTICIPANT	\N	PRESENT	0
766875	765855	20084G	PARTICIPANT	\N	PRESENT	0
766876	765401	21071F	PARTICIPANT	\N	PRESENT	0
766877	762245	19593H	PARTICIPANT	\N	PRESENT	0
766878	762245	20132W	PARTICIPANT	\N	PRESENT	0
766879	762245	04070G	PARTICIPANT	\N	PRESENT	0
766880	762245	19699S	PARTICIPANT	\N	PRESENT	0
766881	762245	20122U	PARTICIPANT	\N	PRESENT	0
766882	762245	19533U	PARTICIPANT	\N	PRESENT	0
766883	762245	19611R	PRESIDENT	0	PRESENT	0
766884	762245	04033B	PARTICIPANT	\N	PRESENT	0
766885	762245	20142Y	PARTICIPANT	\N	PRESENT	0
766886	762245	21058J	PARTICIPANT	\N	PRESENT	0
766887	762245	21059K	PARTICIPANT	\N	PRESENT	0
766888	762245	19693L	PARTICIPANT	\N	PRESENT	0
766889	762245	20102Q	PARTICIPANT	\N	PRESENT	0
766890	762245	20052X	PARTICIPANT	\N	PRESENT	0
766891	762245	20056C	PARTICIPANT	\N	PRESENT	0
766892	762245	19954N	PARTICIPANT	\N	PRESENT	0
766893	762245	20180F	PARTICIPANT	\N	PRESENT	0
766894	762245	21037D	PARTICIPANT	\N	PRESENT	0
766895	762245	21077M	PARTICIPANT	\N	PRESENT	0
766896	762245	20026V	PARTICIPANT	\N	PRESENT	0
766897	762245	19735D	PARTICIPANT	\N	EXCUSE	0
766898	762245	14109K	PARTICIPANT	\N	EXCUSE	0
766899	762245	21074J	PARTICIPANT	\N	EXCUSE	0
766900	762245	20172F	PARTICIPANT	\N	EXCUSE	0
766901	762245	20112S	PARTICIPANT	\N	PRESENT	0
766902	765401	20046A	PARTICIPANT	\N	PRESENT	0
766903	765401	20036X	PARTICIPANT	\N	PRESENT	0
766904	765401	21064G	PARTICIPANT	\N	PRESENT	0
766907	765401	11065P	PARTICIPANT	\N	PRESENT	0
766908	765401	14231L	PARTICIPANT	\N	PRESENT	0
766909	765401	14133K	PARTICIPANT	\N	PRESENT	0
766910	762245	20124W	PARTICIPANT	\N	PRESENT	0
766911	765401	19709B	PARTICIPANT	\N	PRESENT	0
766912	765401	20024T	PARTICIPANT	\N	PRESENT	0
766913	765401	20034V	PARTICIPANT	\N	PRESENT	0
766914	765401	14189C	PARTICIPANT	\N	PRESENT	0
766915	765401	20048C	PARTICIPANT	\N	PRESENT	0
766916	765401	18207D	PARTICIPANT	\N	PRESENT	0
766917	765401	20106U	PARTICIPANT	\N	PRESENT	0
766918	765401	21096Q	PARTICIPANT	\N	PRESENT	0
766919	765401	19705W	PARTICIPANT	\N	PRESENT	0
766920	765401	21047F	PARTICIPANT	\N	PRESENT	0
766921	765401	19687N	PARTICIPANT	\N	PRESENT	0
766922	765401	21094N	PARTICIPANT	\N	PRESENT	0
766923	763305	14073Q	PARTICIPANT	\N	PRESENT	0
766924	765401	21046E	PARTICIPANT	\N	PRESENT	0
766925	765401	19695N	PARTICIPANT	\N	PRESENT	0
766926	765401	20020P	PARTICIPANT	\N	PRESENT	0
766928	765401	11027H	PARTICIPANT	\N	PRESENT	0
766930	765401	08028W	PARTICIPANT	\N	PRESENT	0
766931	765401	19347U	PARTICIPANT	\N	PRESENT	0
766933	765401	20044X	PARTICIPANT	\N	PRESENT	0
766934	765401	19701S	PARTICIPANT	\N	PRESENT	0
766935	765401	14097Y	PARTICIPANT	\N	PRESENT	0
766937	765401	20074E	PARTICIPANT	\N	PRESENT	0
766939	765401	05008E	PARTICIPANT	\N	PRESENT	0
766940	765401	21040X	PARTICIPANT	\N	PRESENT	0
766941	765401	14083S	PARTICIPANT	\N	PRESENT	0
766942	765401	20124W	PARTICIPANT	\N	PRESENT	0
766943	765401	04045F	PARTICIPANT	\N	PRESENT	0
766944	765401	01034P	PARTICIPANT	\N	PRESENT	0
766945	765401	21072G	PARTICIPANT	\N	PRESENT	0
766946	765401	21068L	PARTICIPANT	\N	PRESENT	0
766947	765401	19563B	PARTICIPANT	\N	PRESENT	0
766948	765401	14053L	PARTICIPANT	\N	PRESENT	0
766949	765401	18193Q	PARTICIPANT	\N	PRESENT	0
766950	765401	21056G	PARTICIPANT	\N	PRESENT	0
766951	765401	19573D	PARTICIPANT	\N	PRESENT	0
766952	765401	21066J	PARTICIPANT	\N	PRESENT	0
766958	765401	20134Y	PARTICIPANT	\N	PRESENT	0
766959	765401	14033T	PARTICIPANT	\N	PRESENT	0
766960	765401	20092G	PARTICIPANT	\N	PRESENT	0
766961	765401	14257W	PARTICIPANT	\N	PRESENT	0
743707	743706	19515S	PRESIDENT	0	PRESENT	0
743708	743706	19467C	PARTICIPANT	\N	PRESENT	0
743709	743706	14083S	PARTICIPANT	\N	PRESENT	0
743710	743706	19762G	PARTICIPANT	\N	PRESENT	0
743711	743706	20054A	PARTICIPANT	\N	PRESENT	0
743712	743706	19369B	PARTICIPANT	\N	PRESENT	0
743713	743706	14031R	PARTICIPANT	\N	PRESENT	0
743714	743706	19251M	PARTICIPANT	\N	PRESENT	0
743715	743706	14030Q	PARTICIPANT	\N	PRESENT	0
743731	743706	08015R	PARTICIPANT	\N	EXCUSE	0
743732	743706	19575F	PARTICIPANT	\N	EXCUSE	0
743733	743706	20060X	PARTICIPANT	\N	EXCUSE	0
743734	743706	08028W	PARTICIPANT	\N	EXCUSE	0
743735	743706	20126Y	PARTICIPANT	\N	EXCUSE	0
743736	743706	14329V	PARTICIPANT	\N	EXCUSE	0
743737	743706	14026U	PARTICIPANT	\N	EXCUSE	0
743738	743706	08060W	PARTICIPANT	\N	EXCUSE	0
743739	743706	20048C	PARTICIPANT	\N	EXCUSE	0
743740	743706	19671E	PARTICIPANT	\N	EXCUSE	0
747559	746019	10006L	PRESIDENT	0	PRESENT	0
747561	746019	20090E	PARTICIPANT	\N	PRESENT	0
747563	746019	04092N	PARTICIPANT	\N	PRESENT	0
747565	746019	19723Y	PARTICIPANT	\N	PRESENT	0
747566	746019	14213J	PARTICIPANT	\N	PRESENT	0
747567	746019	14217N	PARTICIPANT	\N	PRESENT	0
747569	746019	19798U	PARTICIPANT	\N	PRESENT	0
747573	746019	14071N	PRESIDENT	1	PRESENT	0
747574	746019	20066E	PARTICIPANT	\N	PRESENT	0
747578	746019	18193Q	PARTICIPANT	\N	PRESENT	0
747579	746019	19295A	PARTICIPANT	\N	EXCUSE	0
747584	746019	11097X	PARTICIPANT	\N	PRESENT	0
747586	746019	19703U	PARTICIPANT	\N	EXCUSE	0
747587	746019	11067R	PARTICIPANT	\N	PRESENT	0
747612	746019	14026U	PARTICIPANT	\N	PRESENT	0
747613	746019	17965H	PARTICIPANT	\N	PRESENT	0
747627	746019	14195A	PARTICIPANT	\N	PRESENT	0
747641	746019	14281W	PARTICIPANT	\N	PRESENT	0
747648	746019	19697Q	PARTICIPANT	\N	PRESENT	0
747657	746019	19713W	PARTICIPANT	\N	PRESENT	0
747670	746019	04057K	PARTICIPANT	\N	EXCUSE	0
750134	749972	17965H	PARTICIPANT	\N	PRESENT	0
750135	749972	14281W	PARTICIPANT	\N	PRESENT	0
750136	749972	19553Y	PARTICIPANT	\N	PRESENT	0
750137	749972	19715Y	PARTICIPANT	\N	PRESENT	0
750138	749972	19697Q	PARTICIPANT	\N	PRESENT	0
750139	749972	11031D	PARTICIPANT	\N	PRESENT	0
750140	749972	18193Q	PARTICIPANT	\N	PRESENT	0
750141	749972	19760E	PARTICIPANT	\N	PRESENT	0
750142	749972	19569H	PARTICIPANT	\N	PRESENT	0
750143	749972	14030Q	PARTICIPANT	\N	PRESENT	0
750144	749972	14219Q	PARTICIPANT	\N	PRESENT	0
750145	749972	14195A	PARTICIPANT	\N	PRESENT	0
750146	749972	14083S	PARTICIPANT	\N	PRESENT	0
750147	749972	14215L	PARTICIPANT	\N	PRESENT	0
750148	749972	20054A	PARTICIPANT	\N	PRESENT	0
750149	749972	19798U	PARTICIPANT	\N	PRESENT	0
750150	749972	20076G	PARTICIPANT	\N	PRESENT	0
750151	749972	20074E	PARTICIPANT	\N	PRESENT	0
750152	749972	14071N	PARTICIPANT	\N	PRESENT	0
750153	749972	19447X	PARTICIPANT	\N	PRESENT	0
750154	749972	19820Y	PARTICIPANT	\N	PRESENT	0
750155	749972	14026U	PARTICIPANT	\N	PRESENT	0
750156	749972	10006L	PARTICIPANT	\N	PRESENT	0
750157	749972	19575F	PARTICIPANT	\N	PRESENT	0
750158	749972	20034V	PARTICIPANT	\N	PRESENT	0
750159	749972	20104S	PARTICIPANT	\N	PRESENT	0
750160	749972	14231L	PARTICIPANT	\N	PRESENT	0
750161	749972	20122U	PARTICIPANT	\N	PRESENT	0
750162	749972	14059S	PARTICIPANT	\N	PRESENT	0
750163	749972	95041E	PARTICIPANT	\N	PRESENT	0
750164	749972	04043D	PARTICIPANT	\N	PRESENT	0
750165	749972	20032T	PARTICIPANT	\N	PRESENT	0
750166	749972	20062A	PARTICIPANT	\N	PRESENT	0
750167	749972	19713W	PARTICIPANT	\N	PRESENT	0
750168	749972	04092N	PARTICIPANT	\N	PRESENT	0
750169	749972	11097X	PARTICIPANT	\N	PRESENT	0
750170	749972	20100N	PARTICIPANT	\N	PRESENT	0
750171	749972	20914V	PARTICIPANT	\N	PRESENT	0
750172	749972	14042U	PARTICIPANT	\N	PRESENT	0
750173	749972	20090E	PARTICIPANT	\N	PRESENT	0
750174	749972	19295A	PARTICIPANT	\N	PRESENT	0
750175	749972	14217N	PARTICIPANT	\N	PRESENT	0
750176	749972	04033B	PARTICIPANT	\N	PRESENT	0
750177	749972	19347U	PARTICIPANT	\N	PRESENT	0
750132	749972	12041X	PARTICIPANT	\N	PRESENT	0
750133	749972	20130U	PARTICIPANT	\N	PRESENT	0
750178	749972	20126Y	PARTICIPANT	\N	PRESENT	0
750179	749972	20022R	PARTICIPANT	\N	PRESENT	0
750180	749972	19711U	PARTICIPANT	\N	PRESENT	0
750181	749972	17367Q	PARTICIPANT	\N	PRESENT	0
750182	749972	20058E	PARTICIPANT	\N	PRESENT	0
750214	750213	20066E	PARTICIPANT	\N	EXCUSE	0
750215	750213	19693L	PARTICIPANT	\N	PRESENT	0
750216	750213	11067R	PARTICIPANT	\N	EXCUSE	0
750382	745859	19717B	PRESIDENT	0	PRESENT	0
750383	745859	19715Y	PARTICIPANT	\N	PRESENT	0
750384	745859	20034V	PARTICIPANT	\N	PRESENT	0
750385	745859	19577H	PARTICIPANT	\N	PRESENT	0
750386	745859	20146D	PARTICIPANT	\N	PRESENT	0
750387	745859	14147R	PARTICIPANT	\N	PRESENT	0
750388	745859	20098N	PARTICIPANT	\N	PRESENT	0
750389	745859	14030Q	PARTICIPANT	\N	PRESENT	0
750391	745859	20024T	PARTICIPANT	\N	PRESENT	0
750392	745859	19749K	PARTICIPANT	\N	PRESENT	0
750396	745859	97011G	PARTICIPANT	\N	PRESENT	0
750422	745859	17023S	PARTICIPANT	\N	PRESENT	0
750560	749958	08018U	PARTICIPANT	\N	EXCUSE	0
750561	749958	14053L	PARTICIPANT	\N	EXCUSE	0
750562	749958	20108W	PARTICIPANT	\N	EXCUSE	0
750753	750752	20024T	PARTICIPANT	\N	PRESENT	0
750767	750766	20034V	PARTICIPANT	\N	PRESENT	0
750768	750766	19575F	PARTICIPANT	\N	PRESENT	0
750769	750766	04043D	PARTICIPANT	\N	PRESENT	0
750969	750968	86034E	PARTICIPANT	\N	PRESENT	0
750970	750968	99004R	PARTICIPANT	\N	PRESENT	0
750971	750968	11045K	PARTICIPANT	\N	PRESENT	0
750972	750968	01043Q	PARTICIPANT	\N	PRESENT	0
750973	750968	95063L	PARTICIPANT	\N	PRESENT	0
750974	750968	12041X	PARTICIPANT	\N	PRESENT	0
750975	750968	19719D	PARTICIPANT	\N	PRESENT	0
750976	750968	14026U	PARTICIPANT	\N	PRESENT	0
750977	750968	11070L	PARTICIPANT	\N	PRESENT	0
750978	750968	05008E	PARTICIPANT	\N	PRESENT	0
750979	750968	01028R	PARTICIPANT	\N	PRESENT	0
750980	750968	11053K	PARTICIPANT	\N	PRESENT	0
750981	750968	11033F	PARTICIPANT	\N	PRESENT	0
750982	750968	14357A	PARTICIPANT	\N	PRESENT	0
750983	750968	19673G	PARTICIPANT	\N	PRESENT	0
750984	750968	01025N	PARTICIPANT	\N	PRESENT	0
750985	750968	14033T	PARTICIPANT	\N	PRESENT	0
750986	750968	14123H	PARTICIPANT	\N	PRESENT	0
750987	750968	14179A	PARTICIPANT	\N	PRESENT	0
750988	750968	14213J	PARTICIPANT	\N	PRESENT	0
750989	750968	19715Y	PARTICIPANT	\N	PRESENT	0
750990	750968	14147R	PARTICIPANT	\N	PRESENT	0
750991	750968	19413M	PARTICIPANT	\N	PRESENT	0
751084	749997	20128B	PARTICIPANT	\N	EXCUSE	0
751088	749997	19443T	PARTICIPANT	\N	EXCUSE	0
751103	749997	19583F	PARTICIPANT	\N	EXCUSE	0
751728	751727	14089Y	PARTICIPANT	\N	PRESENT	0
751730	751727	11026G	PARTICIPANT	\N	PRESENT	0
751732	751731	14053L	PARTICIPANT	\N	PRESENT	1
751733	751731	14089Y	PARTICIPANT	\N	PRESENT	0
751734	751731	11026G	PARTICIPANT	\N	PRESENT	0
751736	751735	14089Y	PARTICIPANT	\N	PRESENT	0
751737	751735	11026G	PARTICIPANT	\N	PRESENT	0
751738	751735	14053L	PARTICIPANT	\N	PRESENT	1
751740	751739	95063L	PARTICIPANT	\N	PRESENT	0
751741	751739	14147R	PARTICIPANT	\N	PRESENT	0
751742	751739	17737W	PARTICIPANT	\N	PRESENT	0
751743	751739	20248J	PARTICIPANT	\N	PRESENT	0
751744	751739	20066E	PARTICIPANT	\N	PRESENT	0
751824	751587	04047H	PARTICIPANT	\N	EXCUSE	0
751825	751813	20062A	PARTICIPANT	\N	PRESENT	0
751826	751813	19782L	PARTICIPANT	\N	PRESENT	0
751827	751813	19575F	PARTICIPANT	\N	PRESENT	0
751828	751813	20082E	PARTICIPANT	\N	PRESENT	0
751829	751813	11090Q	PARTICIPANT	\N	PRESENT	0
751830	751813	20018V	PARTICIPANT	\N	PRESENT	0
751831	751813	14037X	PARTICIPANT	\N	PRESENT	0
773462	772595	20108W	PARTICIPANT	\N	PRESENT	0
773463	772595	18395Y	PARTICIPANT	\N	PRESENT	0
773464	772595	14231L	PARTICIPANT	\N	PRESENT	0
773465	772595	14042U	PARTICIPANT	\N	PRESENT	0
773466	772595	20024T	PARTICIPANT	\N	PRESENT	0
773467	772595	20136B	PARTICIPANT	\N	PRESENT	0
773468	772595	21059K	PARTICIPANT	\N	PRESENT	0
773529	773521	19711U	PARTICIPANT	\N	PRESENT	0
773530	773521	19573D	PARTICIPANT	\N	PRESENT	0
773531	773521	20044X	PARTICIPANT	\N	PRESENT	0
773532	773521	20086J	PARTICIPANT	\N	PRESENT	0
773533	773521	19647E	PARTICIPANT	\N	PRESENT	0
773534	773521	20080C	PARTICIPANT	\N	PRESENT	0
773535	773521	20094J	PARTICIPANT	\N	PRESENT	0
773536	773521	20070A	PARTICIPANT	\N	PRESENT	0
773537	772596	14229S	PARTICIPANT	\N	PRESENT	0
773538	773521	08011M	PARTICIPANT	\N	PRESENT	0
773539	772596	14225N	PARTICIPANT	\N	PRESENT	0
773540	772596	11048N	PARTICIPANT	\N	PRESENT	0
773541	772596	11040E	PARTICIPANT	\N	PRESENT	0
773542	772596	20080C	PARTICIPANT	\N	PRESENT	0
773543	772596	11074Q	PARTICIPANT	\N	PRESENT	0
773544	772596	20070A	PARTICIPANT	\N	PRESENT	0
773545	772596	20094J	PARTICIPANT	\N	PRESENT	0
773546	772596	19647E	PARTICIPANT	\N	PRESENT	0
773547	772596	20082E	PARTICIPANT	\N	PRESENT	0
773548	772596	21051B	PARTICIPANT	\N	PRESENT	0
773549	772596	21055F	PARTICIPANT	\N	PRESENT	0
773550	772596	21079P	PARTICIPANT	\N	PRESENT	0
773551	772596	14191V	PARTICIPANT	\N	PRESENT	0
773552	772596	19551W	PARTICIPANT	\N	PRESENT	0
773553	772596	14021P	PARTICIPANT	\N	PRESENT	0
773554	772596	20044X	PARTICIPANT	\N	PRESENT	0
773555	772596	20134Y	PARTICIPANT	\N	PRESENT	0
773556	772596	14253S	PARTICIPANT	\N	PRESENT	0
773557	772596	14042U	PARTICIPANT	\N	PRESENT	0
773558	772596	21091K	PARTICIPANT	\N	PRESENT	0
773559	772596	20052X	PARTICIPANT	\N	PRESENT	0
773560	772596	20036X	PARTICIPANT	\N	PRESENT	0
773561	772596	08011M	PARTICIPANT	\N	PRESENT	0
773562	772596	14231L	PARTICIPANT	\N	PRESENT	0
773563	772596	04033B	PARTICIPANT	\N	PRESENT	0
773564	772596	21083K	PARTICIPANT	\N	PRESENT	0
773565	772596	20062A	PARTICIPANT	\N	PRESENT	0
773566	772596	14083S	PARTICIPANT	\N	PRESENT	0
773567	772596	21090J	PARTICIPANT	\N	PRESENT	0
773568	772596	14327T	PARTICIPANT	\N	PRESENT	0
773569	772596	20086J	PARTICIPANT	\N	PRESENT	0
773570	772596	11053K	PARTICIPANT	\N	PRESENT	0
773571	772596	17229F	PARTICIPANT	\N	PRESENT	0
773572	772596	20024T	PARTICIPANT	\N	PRESENT	0
773573	772596	21087P	PARTICIPANT	\N	PRESENT	0
773574	772596	21029D	PARTICIPANT	\N	PRESENT	0
773575	772596	19563B	PARTICIPANT	\N	PRESENT	0
773576	772596	21039F	PARTICIPANT	\N	PRESENT	0
773577	772596	07029T	PARTICIPANT	\N	PRESENT	0
773578	772596	21042A	PARTICIPANT	\N	PRESENT	0
773579	772596	20056C	PARTICIPANT	\N	PRESENT	0
773580	772596	20072C	PARTICIPANT	\N	PRESENT	0
773522	773521	21090J	PARTICIPANT	\N	PRESENT	0
773523	773521	11074Q	PARTICIPANT	\N	PRESENT	0
773524	773521	14225N	PRESIDENT	0	PRESENT	0
773525	773521	20024T	PARTICIPANT	\N	PRESENT	0
773526	773521	07029T	PARTICIPANT	\N	PRESENT	0
773527	773521	11048N	PARTICIPANT	\N	PRESENT	0
773528	773521	14253S	PARTICIPANT	\N	PRESENT	0
773581	772596	19631V	PARTICIPANT	\N	PRESENT	0
773582	772596	21056G	PARTICIPANT	\N	PRESENT	0
773583	772596	20092G	PARTICIPANT	\N	PRESENT	0
774421	773892	21045D	PARTICIPANT	\N	PRESENT	0
774474	769595	21074J	PARTICIPANT	\N	PRESENT	0
775516	772441	19631V	PARTICIPANT	\N	PRESENT	0
775517	772441	21096Q	PARTICIPANT	\N	PRESENT	0
775518	772441	21034A	PARTICIPANT	\N	PRESENT	0
775519	772441	21032X	PARTICIPANT	\N	PRESENT	1
775520	772441	20034V	PRESIDENT	0	PRESENT	0
775522	772441	21029D	PARTICIPANT	\N	PRESENT	0
775523	772441	21055F	PARTICIPANT	\N	PRESENT	0
775530	772441	08010L	PARTICIPANT	\N	PRESENT	0
775531	772441	14219Q	PARTICIPANT	\N	PRESENT	0
775532	772441	12016W	PARTICIPANT	\N	PRESENT	0
775533	772441	05008E	PARTICIPANT	\N	PRESENT	0
775538	772441	19301E	PARTICIPANT	\N	PRESENT	0
775539	772441	19669L	PARTICIPANT	\N	PRESENT	0
775542	772441	04042C	PARTICIPANT	\N	PRESENT	0
775543	772441	17023S	PARTICIPANT	\N	PRESENT	0
775544	772441	21033Y	PARTICIPANT	\N	PRESENT	0
775546	772441	19657G	PARTICIPANT	\N	PRESENT	1
775547	772441	19331L	PARTICIPANT	\N	PRESENT	0
775551	772441	21030V	PARTICIPANT	\N	PRESENT	0
776127	775825	20084G	PARTICIPANT	\N	PRESENT	0
776128	775825	19575F	PARTICIPANT	\N	PRESENT	0
776130	775824	20084G	PARTICIPANT	\N	PRESENT	0
780022	780021	11048N	PARTICIPANT	\N	PRESENT	0
780023	780021	19711U	PARTICIPANT	\N	PRESENT	0
780024	780021	08034U	PARTICIPANT	\N	PRESENT	0
780025	780021	19349W	PARTICIPANT	\N	PRESENT	0
780026	780021	14121F	PARTICIPANT	\N	PRESENT	0
780027	780021	08010L	PARTICIPANT	\N	PRESENT	0
780028	780021	21090J	PARTICIPANT	\N	PRESENT	0
780029	780021	20044X	PRESIDENT	0	PRESENT	0
780030	780021	07029T	PARTICIPANT	\N	EXCUSE	0
780031	780021	21079P	PARTICIPANT	\N	PRESENT	0
780032	780021	14225N	PARTICIPANT	\N	EXCUSE	0
780033	779642	11090Q	PARTICIPANT	\N	PRESENT	0
780034	779642	21089R	PARTICIPANT	\N	PRESENT	0
780035	779642	14211G	PARTICIPANT	\N	PRESENT	0
780036	779642	21063F	PARTICIPANT	\N	PRESENT	0
780037	779642	21055F	PARTICIPANT	\N	PRESENT	0
780038	779642	14121F	PARTICIPANT	\N	PRESENT	0
780039	779642	08012N	PARTICIPANT	\N	PRESENT	0
780040	779642	20264J	PARTICIPANT	\N	PRESENT	0
780041	779642	14021P	PARTICIPANT	\N	PRESENT	0
780042	779642	20112S	PARTICIPANT	\N	PRESENT	0
780043	779642	19593H	PARTICIPANT	\N	PRESENT	0
780044	779642	20044X	PARTICIPANT	\N	PRESENT	0
780045	779642	19349W	PARTICIPANT	\N	PRESENT	0
780046	779642	20026V	PARTICIPANT	\N	PRESENT	0
780047	779642	11043H	PARTICIPANT	\N	PRESENT	0
780048	779642	20058E	PARTICIPANT	\N	PRESENT	0
780049	779642	21085M	PARTICIPANT	\N	PRESENT	0
780050	779642	21077M	PARTICIPANT	\N	PRESENT	0
780051	779642	19585H	PARTICIPANT	\N	PRESENT	0
780052	779642	21078N	PARTICIPANT	\N	PRESENT	0
780053	779642	21037D	PARTICIPANT	\N	PRESENT	0
780054	779642	21049H	PARTICIPANT	\N	PRESENT	0
780055	779642	11048N	PARTICIPANT	\N	PRESENT	0
780056	779642	14109K	PARTICIPANT	\N	PRESENT	0
780057	779642	21041Y	PARTICIPANT	\N	PRESENT	0
780058	779642	19611R	PARTICIPANT	\N	PRESENT	0
780059	779642	14073Q	PARTICIPANT	\N	PRESENT	0
780060	779642	21059K	PARTICIPANT	\N	PRESENT	0
780061	779642	19533U	PARTICIPANT	\N	PRESENT	0
780062	779642	19711U	PARTICIPANT	\N	PRESENT	0
780063	779642	19621T	PARTICIPANT	\N	PRESENT	0
780064	779642	14229S	PARTICIPANT	\N	PRESENT	0
780065	779642	08034U	PARTICIPANT	\N	PRESENT	0
780066	779642	21054E	PARTICIPANT	\N	PRESENT	0
780067	779642	20180F	PARTICIPANT	\N	PRESENT	0
780068	779642	20056C	PARTICIPANT	\N	PRESENT	0
780069	779642	07004J	PARTICIPANT	\N	PRESENT	0
780070	779642	20286Q	PARTICIPANT	\N	PRESENT	0
780071	779642	21040X	PARTICIPANT	\N	PRESENT	0
780072	779642	20124W	PARTICIPANT	\N	PRESENT	0
780073	779642	14037X	PARTICIPANT	\N	PRESENT	0
780074	779642	20266L	PARTICIPANT	\N	PRESENT	0
780075	779642	21097R	PARTICIPANT	\N	PRESENT	0
776919	776543	14219Q	PARTICIPANT	\N	PRESENT	0
776890	776543	14225N	PARTICIPANT	\N	PRESENT	0
776891	776543	99004R	PARTICIPANT	\N	PRESENT	0
776920	776543	19619A	PARTICIPANT	\N	PRESENT	0
776921	776543	19826F	PARTICIPANT	\N	PRESENT	0
776925	776543	21033Y	PARTICIPANT	\N	PRESENT	0
776895	776543	19387D	PARTICIPANT	\N	PRESENT	0
776896	776543	21053D	PARTICIPANT	\N	PRESENT	0
776926	776543	21072G	PARTICIPANT	\N	PRESENT	0
776898	776543	14033T	PARTICIPANT	\N	PRESENT	0
776899	776543	19573D	PARTICIPANT	\N	PRESENT	0
776900	776543	20034V	PARTICIPANT	\N	PRESENT	0
776901	776543	21029D	PARTICIPANT	\N	PRESENT	0
776902	776543	21093M	PARTICIPANT	\N	PRESENT	0
776903	776543	19687N	PARTICIPANT	\N	PRESENT	0
776904	776543	19711U	PARTICIPANT	\N	PRESENT	0
776927	776543	20046A	PARTICIPANT	\N	PRESENT	0
776906	776543	20124W	PARTICIPANT	\N	PRESENT	0
776928	776543	21060C	PARTICIPANT	\N	PRESENT	0
776908	776543	21079P	PARTICIPANT	\N	PRESENT	0
776909	776543	20068G	PARTICIPANT	\N	PRESENT	0
776910	776543	21090J	PARTICIPANT	\N	PRESENT	0
776911	776543	20120S	PARTICIPANT	\N	PRESENT	0
776912	776543	14031R	PARTICIPANT	\N	PRESENT	0
776913	776543	17229F	PARTICIPANT	\N	PRESENT	0
776914	776543	20100N	PARTICIPANT	\N	PRESENT	0
776915	776543	11053K	PARTICIPANT	\N	PRESENT	0
776916	776543	19820Y	PARTICIPANT	\N	PRESENT	0
776929	776543	19551W	PARTICIPANT	\N	PRESENT	0
776930	776543	20018V	PARTICIPANT	\N	PRESENT	0
776931	776543	11090Q	PARTICIPANT	\N	PRESENT	0
776992	776544	14257W	PARTICIPANT	\N	PRESENT	0
776933	776543	04042C	PARTICIPANT	\N	PRESENT	0
776934	776543	21082J	PARTICIPANT	\N	PRESENT	0
776935	776543	18083K	PARTICIPANT	\N	PRESENT	0
776936	776543	08060W	PARTICIPANT	\N	PRESENT	0
776937	776543	21035B	PARTICIPANT	\N	PRESENT	0
776938	776543	14257W	PARTICIPANT	\N	PRESENT	0
776939	776543	20134Y	PARTICIPANT	\N	PRESENT	0
776940	776543	20106U	PARTICIPANT	\N	PRESENT	0
776942	776544	21040X	PARTICIPANT	\N	PRESENT	0
776993	776544	20018V	PARTICIPANT	\N	PRESENT	0
776994	776544	20124W	PARTICIPANT	\N	PRESENT	0
776945	776544	20136B	PARTICIPANT	\N	PRESENT	0
776946	776544	20044X	PARTICIPANT	\N	PRESENT	0
776947	776544	14225N	PARTICIPANT	\N	PRESENT	0
776948	776544	19387D	PARTICIPANT	\N	PRESENT	0
776995	776544	21053D	PARTICIPANT	\N	PRESENT	0
776996	776544	11065P	PARTICIPANT	\N	PRESENT	0
776951	776544	21029D	PARTICIPANT	\N	PRESENT	0
776997	776544	14033T	PARTICIPANT	\N	PRESENT	0
776953	776544	19711U	PARTICIPANT	\N	PRESENT	0
776998	776544	14089Y	PARTICIPANT	\N	PRESENT	0
776999	776544	21075K	PARTICIPANT	\N	PRESENT	0
777000	776544	21093M	PARTICIPANT	\N	PRESENT	0
776957	776544	21090J	PARTICIPANT	\N	PRESENT	0
777001	776544	21082J	PARTICIPANT	\N	PRESENT	0
776959	776544	14031R	PARTICIPANT	\N	PRESENT	0
776960	776544	20100N	PARTICIPANT	\N	PRESENT	0
776961	776544	11053K	PARTICIPANT	\N	PRESENT	0
776962	776544	19820Y	PARTICIPANT	\N	PRESENT	0
776963	776544	19619A	PARTICIPANT	\N	PRESENT	0
776964	776544	19826F	PARTICIPANT	\N	PRESENT	0
776965	776544	21033Y	PARTICIPANT	\N	PRESENT	0
776966	776544	20046A	PARTICIPANT	\N	PRESENT	0
776967	776544	21060C	PARTICIPANT	\N	PRESENT	0
776968	776544	19551W	PARTICIPANT	\N	PRESENT	0
777004	776544	20050V	PARTICIPANT	\N	PRESENT	0
777005	776544	19695N	PARTICIPANT	\N	PRESENT	0
776971	776544	08060W	PARTICIPANT	\N	PRESENT	0
776972	776544	21035B	PARTICIPANT	\N	PRESENT	0
777006	776544	20068G	PARTICIPANT	\N	PRESENT	0
777007	776544	19693L	PARTICIPANT	\N	PRESENT	0
776975	776544	20106U	PARTICIPANT	\N	PRESENT	0
776990	776544	21084L	PARTICIPANT	\N	PRESENT	0
776986	776544	14111D	PARTICIPANT	\N	PRESENT	0
776989	776544	14219Q	PARTICIPANT	\N	PRESENT	0
776991	776544	19399H	PARTICIPANT	\N	PRESENT	0
777008	776544	21054E	PARTICIPANT	\N	PRESENT	0
777009	776544	14211G	PARTICIPANT	\N	PRESENT	0
777010	776544	20120S	PARTICIPANT	\N	PRESENT	0
777011	776544	17229F	PARTICIPANT	\N	PRESENT	0
777012	776544	11048N	PARTICIPANT	\N	PRESENT	0
777016	776544	21071F	PARTICIPANT	\N	PRESENT	0
777017	776544	19573D	PARTICIPANT	\N	PRESENT	0
777018	776544	20034V	PARTICIPANT	\N	PRESENT	0
777019	776544	21079P	PARTICIPANT	\N	PRESENT	0
777022	776544	21072G	PARTICIPANT	\N	PRESENT	0
777023	776544	14021P	PARTICIPANT	\N	PRESENT	0
777024	776544	11090Q	PARTICIPANT	\N	PRESENT	0
777025	776544	19347U	PARTICIPANT	\N	PRESENT	0
777026	776544	19563B	PARTICIPANT	\N	PRESENT	0
777027	776544	21030V	PARTICIPANT	\N	PRESENT	0
777028	776544	14059S	PARTICIPANT	\N	PRESENT	0
777029	776544	21048G	PARTICIPANT	\N	PRESENT	0
777030	776544	19569H	PARTICIPANT	\N	PRESENT	0
777031	776544	20054A	PARTICIPANT	\N	PRESENT	0
777033	776544	20134Y	PARTICIPANT	\N	PRESENT	0
777034	776544	20062A	PARTICIPANT	\N	PRESENT	0
777035	776544	08061X	PARTICIPANT	\N	PRESENT	0
777036	776544	21061D	PARTICIPANT	\N	PRESENT	0
777039	776544	04033B	PARTICIPANT	\N	PRESENT	0
777041	776544	08010L	PARTICIPANT	\N	PRESENT	0
777042	776544	20026V	PARTICIPANT	\N	PRESENT	0
777046	776544	19954N	PARTICIPANT	\N	PRESENT	0
777044	776544	14187A	PARTICIPANT	\N	PRESENT	0
777045	776544	18083K	PARTICIPANT	\N	PRESENT	0
777047	776544	19531S	PARTICIPANT	\N	PRESENT	0
777048	776544	20266L	PARTICIPANT	\N	PRESENT	0
777049	776544	21085M	PARTICIPANT	\N	PRESENT	0
777098	776545	20072C	PARTICIPANT	\N	PRESENT	0
777051	776545	20136B	PARTICIPANT	\N	PRESENT	0
777052	776545	19387D	PARTICIPANT	\N	PRESENT	0
777053	776545	21029D	PARTICIPANT	\N	PRESENT	0
777054	776545	19711U	PARTICIPANT	\N	PRESENT	0
777055	776545	21090J	PARTICIPANT	\N	PRESENT	0
777056	776545	14031R	PARTICIPANT	\N	PRESENT	0
777057	776545	20100N	PARTICIPANT	\N	PRESENT	0
777058	776545	11053K	PARTICIPANT	\N	PRESENT	0
777106	776545	20024T	PARTICIPANT	\N	PRESENT	0
777060	776545	19619A	PARTICIPANT	\N	PRESENT	0
777061	776545	19826F	PARTICIPANT	\N	PRESENT	0
777062	776545	20046A	PARTICIPANT	\N	PRESENT	0
777063	776545	19551W	PARTICIPANT	\N	PRESENT	0
777064	776545	08060W	PARTICIPANT	\N	PRESENT	0
777065	776545	21035B	PARTICIPANT	\N	PRESENT	0
777066	776545	20106U	PARTICIPANT	\N	PRESENT	0
777095	776545	21082J	PARTICIPANT	\N	PRESENT	0
777068	776545	14219Q	PARTICIPANT	\N	PRESENT	0
777107	776545	18083K	PARTICIPANT	\N	PRESENT	0
777070	776545	20124W	PARTICIPANT	\N	PRESENT	0
777071	776545	21053D	PARTICIPANT	\N	PRESENT	0
777108	776545	21054E	PARTICIPANT	\N	PRESENT	0
777109	776545	19573D	PARTICIPANT	\N	PRESENT	0
777074	776545	21093M	PARTICIPANT	\N	PRESENT	0
777110	776545	20062A	PARTICIPANT	\N	PRESENT	0
777111	776545	08010L	PARTICIPANT	\N	PRESENT	0
777112	776545	20086J	PARTICIPANT	\N	PRESENT	0
777113	776545	11048N	PARTICIPANT	\N	PRESENT	0
777079	776545	21079P	PARTICIPANT	\N	PRESENT	0
777114	776545	21048G	PARTICIPANT	\N	PRESENT	0
777115	776545	19693L	PARTICIPANT	\N	PRESENT	0
777099	776545	20044X	PARTICIPANT	\N	PRESENT	0
777116	776545	21032X	PARTICIPANT	\N	PRESENT	0
777100	776545	08034U	PARTICIPANT	\N	PRESENT	0
777085	776545	21061D	PARTICIPANT	\N	PRESENT	0
777101	776545	21033Y	PARTICIPANT	\N	PRESENT	0
777117	776545	04033B	PARTICIPANT	\N	PRESENT	0
777088	776545	14187A	PARTICIPANT	\N	PRESENT	0
777118	776545	19531S	PARTICIPANT	\N	PRESENT	0
777090	776545	19954N	PARTICIPANT	\N	PRESENT	0
777097	776545	19629C	PARTICIPANT	\N	PRESENT	0
777092	776545	20266L	PARTICIPANT	\N	PRESENT	0
777102	776545	20054A	PARTICIPANT	\N	PRESENT	0
777094	776545	14229S	PARTICIPANT	\N	PRESENT	0
777096	776545	21051B	PARTICIPANT	\N	PRESENT	0
777103	776545	19681G	PARTICIPANT	\N	PRESENT	0
777104	776545	19447X	PARTICIPANT	\N	PRESENT	0
777105	776545	20028X	PARTICIPANT	\N	PRESENT	0
777119	776545	20040T	PARTICIPANT	\N	PRESENT	0
777120	776545	20120S	PARTICIPANT	\N	PRESENT	0
773654	773653	12028B	PARTICIPANT	\N	PRESENT	0
773655	773653	14267Y	PARTICIPANT	\N	PRESENT	0
773656	773653	08010L	PARTICIPANT	\N	PRESENT	0
777391	777388	21031W	PARTICIPANT	\N	PRESENT	0
777929	777918	21071F	PARTICIPANT	\N	PRESENT	0
777936	777918	20090E	PARTICIPANT	\N	PRESENT	0
777937	777918	19758L	PARTICIPANT	\N	PRESENT	0
777938	777918	21045D	PARTICIPANT	\N	PRESENT	0
777939	777918	19629C	PARTICIPANT	\N	PRESENT	0
777940	777918	14195A	PARTICIPANT	\N	EXCUSE	0
777941	777918	19683J	PARTICIPANT	\N	PRESENT	0
777942	777918	14281W	PARTICIPANT	\N	PRESENT	0
777943	777918	21097R	PARTICIPANT	\N	PRESENT	0
777944	777918	08061X	PARTICIPANT	\N	PRESENT	0
777945	777918	11045K	PARTICIPANT	\N	PRESENT	0
777946	777918	18193Q	PARTICIPANT	\N	PRESENT	0
777947	777918	19713W	PARTICIPANT	\N	PRESENT	0
777948	777918	19553Y	PARTICIPANT	\N	PRESENT	0
777949	777918	21064G	PARTICIPANT	\N	PRESENT	0
777950	777918	21081H	PARTICIPANT	\N	PRESENT	0
777951	777918	19691J	PARTICIPANT	\N	PRESENT	0
777952	777918	14217N	PARTICIPANT	\N	PRESENT	0
777953	777918	19301E	PARTICIPANT	\N	PRESENT	0
777954	777918	19657G	PARTICIPANT	\N	PRESENT	0
777955	777918	19798U	PARTICIPANT	\N	PRESENT	0
777956	777918	14213J	PARTICIPANT	\N	PRESENT	0
777957	777918	19703U	PARTICIPANT	\N	PRESENT	0
777958	777918	14071N	PRESIDENT	0	PRESENT	0
777959	777918	21046E	PARTICIPANT	\N	PRESENT	0
777970	777918	20096L	PARTICIPANT	\N	PRESENT	0
777971	777918	19569H	PARTICIPANT	\N	PRESENT	0
777977	775973	21088Q	PARTICIPANT	\N	PRESENT	0
777978	775973	14069U	PARTICIPANT	\N	PRESENT	0
777980	775973	14189C	PARTICIPANT	\N	PRESENT	0
777981	775973	14231L	PARTICIPANT	\N	PRESENT	0
777983	775973	14053L	PARTICIPANT	\N	PRESENT	0
777984	775973	21076L	PARTICIPANT	\N	PRESENT	0
777985	775973	21044C	PARTICIPANT	\N	PRESENT	0
777988	775973	19719D	PARTICIPANT	\N	PRESENT	0
777997	775973	19673G	PARTICIPANT	\N	PRESENT	0
777998	775973	14147R	PARTICIPANT	\N	PRESENT	0
777999	775973	14259Y	PARTICIPANT	\N	PRESENT	0
778000	775973	11056N	PARTICIPANT	\N	PRESENT	0
778013	777911	14327T	PARTICIPANT	\N	PRESENT	0
778014	777911	20086J	PARTICIPANT	\N	PRESENT	0
778015	777911	14331P	PARTICIPANT	\N	PRESENT	0
778016	777911	20080C	PARTICIPANT	\N	PRESENT	0
778017	777911	20094J	PARTICIPANT	\N	PRESENT	0
778018	777911	14225N	PRESIDENT	0	PRESENT	0
778019	777911	11070L	PARTICIPANT	\N	PRESENT	0
778020	777911	11110B	PARTICIPANT	\N	PRESENT	0
778021	777911	07029T	PARTICIPANT	\N	PRESENT	0
778022	777911	21079P	PARTICIPANT	\N	PRESENT	0
778023	777911	07004J	PARTICIPANT	\N	PRESENT	0
778024	777911	19349W	PARTICIPANT	\N	PRESENT	0
778025	777911	08010L	PARTICIPANT	\N	PRESENT	0
778026	777911	21090J	PARTICIPANT	\N	PRESENT	0
778027	777911	20126Y	PARTICIPANT	\N	PRESENT	0
778028	777911	20024T	PARTICIPANT	\N	PRESENT	0
778029	777911	11048N	PARTICIPANT	\N	PRESENT	0
778030	777911	19479G	PARTICIPANT	\N	PRESENT	0
778031	777911	19647E	PARTICIPANT	\N	PRESENT	0
778032	777911	19711U	PARTICIPANT	\N	PRESENT	0
778033	777911	08034U	PARTICIPANT	\N	PRESENT	0
778034	777911	19687N	PARTICIPANT	\N	PRESENT	0
778035	777911	20050V	PARTICIPANT	\N	PRESENT	0
778036	777911	08011M	PARTICIPANT	\N	PRESENT	0
778037	777911	20044X	PARTICIPANT	\N	PRESENT	0
778038	777911	19399H	PARTICIPANT	\N	PRESENT	0
778039	777911	20150Y	PARTICIPANT	\N	PRESENT	0
778040	777911	21041Y	PARTICIPANT	\N	PRESENT	0
778041	777911	14083S	PARTICIPANT	\N	PRESENT	0
778042	777911	20062A	PARTICIPANT	\N	PRESENT	0
778043	777911	08073C	PARTICIPANT	\N	PRESENT	0
778044	777911	08009T	PARTICIPANT	\N	PRESENT	0
778045	777911	20070A	PARTICIPANT	\N	PRESENT	0
778046	777911	14121F	PARTICIPANT	\N	PRESENT	0
778047	776140	19699S	PARTICIPANT	\N	PRESENT	0
778048	776140	19533U	PARTICIPANT	\N	PRESENT	0
778049	776140	21058J	PARTICIPANT	\N	PRESENT	0
778050	776140	20102Q	PARTICIPANT	\N	PRESENT	0
778051	776140	14229S	PARTICIPANT	\N	PRESENT	0
778052	776140	21032X	PARTICIPANT	\N	PRESENT	0
778053	776140	18395Y	PARTICIPANT	\N	PRESENT	0
778054	776140	21089R	PARTICIPANT	\N	PRESENT	0
778055	776140	21037D	PARTICIPANT	\N	PRESENT	0
778056	776140	08012N	PARTICIPANT	\N	PRESENT	0
778057	776140	20124W	PARTICIPANT	\N	PRESENT	0
778058	776140	20026V	PARTICIPANT	\N	PRESENT	0
778059	776140	19593H	PARTICIPANT	\N	PRESENT	0
778060	776140	20132W	PARTICIPANT	\N	PRESENT	0
778061	776140	21055F	PARTICIPANT	\N	PRESENT	0
778062	776140	19611R	PRESIDENT	0	PRESENT	0
778063	776140	19693L	PARTICIPANT	\N	PRESENT	0
778064	776140	20052X	PARTICIPANT	\N	PRESENT	0
778065	776140	20172F	PARTICIPANT	\N	PRESENT	0
778066	776140	14030Q	PARTICIPANT	\N	PRESENT	0
778067	776140	20056C	PARTICIPANT	\N	PRESENT	0
778068	776140	20180F	PARTICIPANT	\N	PRESENT	0
778069	776140	21063F	PARTICIPANT	\N	PRESENT	0
778070	776140	19735D	PARTICIPANT	\N	PRESENT	0
778071	776140	14123H	PARTICIPANT	\N	PRESENT	0
778072	776140	21077M	PARTICIPANT	\N	PRESENT	0
778073	776140	19621T	PARTICIPANT	\N	PRESENT	0
778074	776140	14021P	PARTICIPANT	\N	PRESENT	0
778075	776140	20048C	PARTICIPANT	\N	EXCUSE	0
778076	776551	20044X	PARTICIPANT	\N	PRESENT	0
778077	776551	20080C	PARTICIPANT	\N	PRESENT	0
778078	776551	14189C	PARTICIPANT	\N	PRESENT	0
778079	776551	14225N	PARTICIPANT	\N	PRESENT	0
778080	775973	11085T	PARTICIPANT	\N	PRESENT	0
778087	776030	21029D	PARTICIPANT	\N	PRESENT	0
778088	776030	19701S	PARTICIPANT	\N	PRESENT	0
778089	776030	21035B	PARTICIPANT	\N	PRESENT	0
778090	776030	20076G	PARTICIPANT	\N	PRESENT	0
778091	776030	19387D	PARTICIPANT	\N	PRESENT	0
778092	776030	14219Q	PRESIDENT	0	PRESENT	0
778093	776030	19826F	PARTICIPANT	\N	PRESENT	0
778094	776030	21061D	PARTICIPANT	\N	PRESENT	0
778095	776030	21062E	PARTICIPANT	\N	PRESENT	0
778096	776030	21065H	PARTICIPANT	\N	PRESENT	0
778097	776030	18083K	PARTICIPANT	\N	PRESENT	0
778098	776030	21084L	PARTICIPANT	\N	PRESENT	0
778099	776030	19551W	PARTICIPANT	\N	PRESENT	0
778100	776030	20100N	PARTICIPANT	\N	PRESENT	0
778101	776030	14237S	PARTICIPANT	\N	PRESENT	0
778102	776030	05012A	PARTICIPANT	\N	PRESENT	0
778103	776030	08060W	PARTICIPANT	\N	PRESENT	0
778104	776030	20106U	PARTICIPANT	\N	PRESENT	0
778105	776030	15197G	PARTICIPANT	\N	PRESENT	0
778106	776030	21080G	PARTICIPANT	\N	PRESENT	0
778107	776030	19331L	PARTICIPANT	\N	PRESENT	0
778108	776030	20020P	PARTICIPANT	\N	PRESENT	0
778109	776030	19681G	PARTICIPANT	\N	PRESENT	0
778110	776030	11065P	PARTICIPANT	\N	EXCUSE	0
778111	776030	21051B	PARTICIPANT	\N	PRESENT	0
778112	776030	20120S	PARTICIPANT	\N	PRESENT	0
778113	776030	20032T	PARTICIPANT	\N	PRESENT	0
778114	776030	21053D	PARTICIPANT	\N	PRESENT	0
778115	776030	20136B	PARTICIPANT	\N	PRESENT	0
778116	776030	14031R	PARTICIPANT	\N	PRESENT	0
778117	776030	20040T	PARTICIPANT	\N	PRESENT	0
778118	776030	20046A	PARTICIPANT	\N	PRESENT	0
778119	776030	17229F	PARTICIPANT	\N	PRESENT	0
778120	776030	21047F	PARTICIPANT	\N	PRESENT	0
778121	776030	20068G	PARTICIPANT	\N	PRESENT	0
778122	776030	21068L	PARTICIPANT	\N	PRESENT	0
778123	776030	21070E	PARTICIPANT	\N	PRESENT	0
778124	776030	19619A	PARTICIPANT	\N	PRESENT	0
778125	776030	19251M	PARTICIPANT	\N	EXCUSE	0
778126	776030	19820Y	PARTICIPANT	\N	EXCUSE	0
778220	776551	21085M	PARTICIPANT	\N	PRESENT	0
778221	776551	21069M	PARTICIPANT	\N	PRESENT	0
778222	776551	14089Y	PARTICIPANT	\N	PRESENT	0
778223	776551	21070E	PARTICIPANT	\N	PRESENT	0
778224	776551	19758L	PARTICIPANT	\N	PRESENT	0
778225	776551	08073C	PARTICIPANT	\N	PRESENT	0
778273	776551	20052X	PARTICIPANT	\N	PRESENT	0
778274	776551	21090J	PARTICIPANT	\N	PRESENT	0
778275	776551	19699S	PARTICIPANT	\N	PRESENT	0
778276	776551	21048G	PARTICIPANT	\N	PRESENT	0
773359	772595	07004J	PARTICIPANT	\N	PRESENT	0
773360	772595	19693L	PARTICIPANT	\N	PRESENT	0
773361	772595	20080C	PARTICIPANT	\N	PRESENT	0
773362	772595	14069U	PARTICIPANT	\N	PRESENT	0
773363	772595	20032T	PARTICIPANT	\N	PRESENT	0
773364	772595	14191V	PARTICIPANT	\N	PRESENT	0
773365	772595	08011M	PARTICIPANT	\N	PRESENT	0
773368	772595	20094J	PARTICIPANT	\N	PRESENT	0
773369	772595	21033Y	PARTICIPANT	\N	PRESENT	0
773370	772595	20134Y	PARTICIPANT	\N	PRESENT	0
773371	772595	14253S	PARTICIPANT	\N	PRESENT	0
773372	772595	12016W	PARTICIPANT	\N	PRESENT	0
773357	772595	11048N	PARTICIPANT	\N	PRESENT	0
773358	772595	07029T	PARTICIPANT	\N	PRESENT	0
773374	772595	11070L	PARTICIPANT	\N	PRESENT	0
773387	772595	11074Q	PARTICIPANT	\N	PRESENT	0
773393	772595	19820Y	PARTICIPANT	\N	PRESENT	0
773394	772595	11085T	PARTICIPANT	\N	PRESENT	0
773395	772595	19713W	PARTICIPANT	\N	PRESENT	0
773396	772595	19573D	PARTICIPANT	\N	PRESENT	0
773397	772595	19553Y	PARTICIPANT	\N	PRESENT	0
773398	772595	14107H	PARTICIPANT	\N	PRESENT	0
773399	772595	17229F	PARTICIPANT	\N	PRESENT	0
773400	772595	11053K	PARTICIPANT	\N	PRESENT	0
773401	772595	20036X	PARTICIPANT	\N	PRESENT	0
773402	772595	20034V	PARTICIPANT	\N	PRESENT	0
773403	772595	20086J	PARTICIPANT	\N	PRESENT	0
773404	772595	20142Y	PARTICIPANT	\N	PRESENT	0
773405	772595	14021P	PARTICIPANT	\N	PRESENT	0
773406	772595	21056G	PARTICIPANT	\N	PRESENT	0
773407	772595	04033B	PARTICIPANT	\N	PRESENT	0
773408	772595	20056C	PARTICIPANT	\N	PRESENT	0
773409	772595	14189C	PARTICIPANT	\N	PRESENT	0
773410	772595	08061X	PARTICIPANT	\N	PRESENT	0
773411	772595	20082E	PARTICIPANT	\N	PRESENT	0
773412	772595	19563B	PARTICIPANT	\N	PRESENT	0
773442	772595	19735D	PARTICIPANT	\N	PRESENT	0
773443	772595	11056N	PARTICIPANT	\N	PRESENT	0
773444	772595	14037X	PARTICIPANT	\N	PRESENT	0
773445	772595	19701S	PARTICIPANT	\N	PRESENT	0
773446	772595	21051B	PARTICIPANT	\N	PRESENT	0
773450	772595	21054E	PARTICIPANT	\N	PRESENT	0
773451	772595	21075K	PARTICIPANT	\N	PRESENT	0
773452	772595	20138D	PARTICIPANT	\N	PRESENT	0
773453	772595	07033P	PARTICIPANT	\N	PRESENT	0
773454	772595	19591F	PARTICIPANT	\N	PRESENT	0
773455	772595	19551W	PARTICIPANT	\N	PRESENT	0
773458	772595	21089R	PARTICIPANT	\N	PRESENT	0
773459	772595	21072G	PARTICIPANT	\N	PRESENT	0
773460	772595	19647E	PARTICIPANT	\N	PRESENT	0
773584	772596	19711U	PARTICIPANT	\N	PRESENT	0
773585	772596	14187A	PARTICIPANT	\N	PRESENT	0
773586	772596	20054A	PARTICIPANT	\N	PRESENT	0
773587	772596	14107H	PARTICIPANT	\N	PRESENT	0
773588	772596	14257W	PARTICIPANT	\N	PRESENT	0
773589	772596	05012A	PARTICIPANT	\N	PRESENT	0
773590	772596	19573D	PARTICIPANT	\N	PRESENT	0
773591	772596	14215L	PARTICIPANT	\N	PRESENT	0
773592	772596	19553Y	PARTICIPANT	\N	PRESENT	0
773593	772596	20096L	PARTICIPANT	\N	PRESENT	0
773594	772596	14069U	PARTICIPANT	\N	PRESENT	0
773595	772596	21068L	PARTICIPANT	\N	PRESENT	0
773596	772596	20124W	PARTICIPANT	\N	PRESENT	0
773597	772596	19735D	PARTICIPANT	\N	PRESENT	0
773598	772596	12016W	PARTICIPANT	\N	PRESENT	0
773599	772596	19820Y	PARTICIPANT	\N	PRESENT	0
773600	772596	20136B	PARTICIPANT	\N	PRESENT	0
773601	772596	14031R	PARTICIPANT	\N	PRESENT	0
773602	772596	14219Q	PARTICIPANT	\N	PRESENT	0
773603	772596	20034V	PARTICIPANT	\N	PRESENT	0
773604	772596	19695N	PARTICIPANT	\N	PRESENT	0
773605	772596	21043B	PARTICIPANT	\N	PRESENT	0
773606	772596	20180F	PARTICIPANT	\N	PRESENT	0
773607	772596	11056N	PARTICIPANT	\N	PRESENT	0
773608	772596	20100N	PARTICIPANT	\N	PRESENT	0
773609	772596	19335Q	PARTICIPANT	\N	PRESENT	0
773610	772596	21069M	PARTICIPANT	\N	PRESENT	0
773611	772596	21059K	PARTICIPANT	\N	PRESENT	0
773612	772596	21048G	PARTICIPANT	\N	PRESENT	0
773613	772596	04047H	PARTICIPANT	\N	PRESENT	0
773614	772596	19531S	PARTICIPANT	\N	PRESENT	0
773615	772596	21046E	PARTICIPANT	\N	PRESENT	0
773616	772596	19693L	PARTICIPANT	\N	PRESENT	0
773617	772596	21070E	PARTICIPANT	\N	PRESENT	0
773618	772596	01058X	PARTICIPANT	\N	PRESENT	0
773619	772596	08069G	PARTICIPANT	\N	PRESENT	0
773620	772596	21047F	PARTICIPANT	\N	PRESENT	0
773621	772596	20126Y	PARTICIPANT	\N	PRESENT	0
773622	772596	21045D	PARTICIPANT	\N	PRESENT	0
773623	772596	20106U	PARTICIPANT	\N	PRESENT	0
773624	772596	21072G	PARTICIPANT	\N	PRESENT	0
773625	772421	14053L	PARTICIPANT	\N	PRESENT	0
773626	772421	21043B	PARTICIPANT	\N	PRESENT	0
773627	772421	14111D	PARTICIPANT	\N	PRESENT	0
773628	772421	20114U	PARTICIPANT	\N	PRESENT	0
773629	772421	14215L	PARTICIPANT	\N	PRESENT	0
773630	772421	05008E	PARTICIPANT	\N	PRESENT	0
773631	772421	14231L	PARTICIPANT	\N	PRESENT	0
773632	772421	19447X	PARTICIPANT	\N	PRESENT	0
773633	772421	11072N	PARTICIPANT	\N	PRESENT	0
773634	772421	21076L	PARTICIPANT	\N	PRESENT	0
773635	772421	04045F	PARTICIPANT	\N	PRESENT	0
773636	772421	11056N	PARTICIPANT	\N	PRESENT	0
773637	772421	04047H	PRESIDENT	0	PRESENT	0
773638	772421	20098N	PARTICIPANT	\N	PRESENT	0
773639	772421	21038E	PARTICIPANT	\N	PRESENT	0
773640	772421	14259Y	PARTICIPANT	\N	PRESENT	0
773641	772421	14069U	PARTICIPANT	\N	PRESENT	0
775555	772198	17367Q	PARTICIPANT	\N	PRESENT	0
775556	772198	14151M	PRESIDENT	0	PRESENT	0
775557	772198	20090E	PARTICIPANT	\N	PRESENT	0
775558	772198	99004R	PARTICIPANT	\N	PRESENT	0
775559	772198	19349W	PARTICIPANT	\N	PRESENT	0
775560	772198	21040X	PARTICIPANT	\N	PRESENT	0
775588	772198	17737W	PARTICIPANT	\N	PRESENT	0
775589	772198	20252E	PARTICIPANT	\N	PRESENT	0
775606	772198	20146D	PARTICIPANT	\N	PRESENT	0
775640	772198	18395Y	PARTICIPANT	\N	PRESENT	0
775661	775654	20140W	PARTICIPANT	\N	PRESENT	0
775662	775654	14042U	PARTICIPANT	\N	PRESENT	0
775664	775654	01034P	PARTICIPANT	\N	PRESENT	0
775665	775656	20140W	PARTICIPANT	\N	PRESENT	0
775666	775658	20140W	PARTICIPANT	\N	PRESENT	0
775678	775552	18395Y	PARTICIPANT	\N	PRESENT	0
775679	775552	14033T	PARTICIPANT	\N	PRESENT	0
775680	775552	14189C	PARTICIPANT	\N	PRESENT	0
775681	775553	18395Y	PARTICIPANT	\N	PRESENT	0
775682	775553	14033T	PARTICIPANT	\N	PRESENT	0
775683	775553	14189C	PARTICIPANT	\N	PRESENT	0
777667	773849	20052X	PARTICIPANT	\N	PRESENT	0
777668	773849	20180F	PARTICIPANT	\N	PRESENT	0
777669	773849	20048C	PARTICIPANT	\N	EXCUSE	0
777670	776548	14281W	PARTICIPANT	\N	PRESENT	0
777671	776548	19629C	PARTICIPANT	\N	PRESENT	0
777672	776548	14225N	PARTICIPANT	\N	PRESENT	0
777673	776548	21048G	PARTICIPANT	\N	PRESENT	0
777674	776548	21039F	PARTICIPANT	\N	PRESENT	0
777675	776548	19657G	PARTICIPANT	\N	PRESENT	0
777676	776548	19367Y	PARTICIPANT	\N	PRESENT	0
777677	775971	18207D	PARTICIPANT	\N	EXCUSE	0
777678	775971	21057H	PARTICIPANT	\N	EXCUSE	0
777679	776548	14031R	PARTICIPANT	\N	PRESENT	0
777680	776548	20062A	PARTICIPANT	\N	PRESENT	0
777681	773849	14030Q	PARTICIPANT	\N	PRESENT	0
777682	773849	20124W	PARTICIPANT	\N	PRESENT	0
777683	776548	20044X	PARTICIPANT	\N	PRESENT	0
777684	776548	20098N	PARTICIPANT	\N	PRESENT	0
777685	776548	20086J	PARTICIPANT	\N	PRESENT	0
777686	776548	19701S	PARTICIPANT	\N	PRESENT	0
777687	776548	19387D	PARTICIPANT	\N	PRESENT	0
777688	776548	19349W	PARTICIPANT	\N	PRESENT	0
777690	776548	19667J	PARTICIPANT	\N	PRESENT	0
777691	776548	11090Q	PARTICIPANT	\N	PRESENT	0
777692	776548	14069U	PARTICIPANT	\N	PRESENT	0
777693	776548	19575F	PARTICIPANT	\N	PRESENT	0
777694	776548	21072G	PARTICIPANT	\N	PRESENT	0
777695	776548	19447X	PARTICIPANT	\N	PRESENT	0
777696	776548	20104S	PARTICIPANT	\N	PRESENT	0
777697	776548	08034U	PARTICIPANT	\N	PRESENT	0
777698	776548	21064G	PARTICIPANT	\N	PRESENT	0
777699	776548	08010L	PARTICIPANT	\N	PRESENT	0
769597	768933	20022R	PARTICIPANT	\N	EXCUSE	0
769598	768933	19729F	PARTICIPANT	\N	EXCUSE	0
770553	770552	08010L	PARTICIPANT	\N	PRESENT	0
770567	770566	19349W	PARTICIPANT	\N	PRESENT	0
770570	770569	19349W	PARTICIPANT	\N	PRESENT	0
770571	770569	19399H	PARTICIPANT	\N	PRESENT	0
770599	770598	11048N	PARTICIPANT	\N	PRESENT	0
770602	770601	19545Y	PARTICIPANT	\N	PRESENT	0
770603	770601	21079P	PARTICIPANT	\N	PRESENT	0
770834	770561	08015R	PARTICIPANT	\N	PRESENT	0
770835	770561	20028X	PARTICIPANT	\N	PRESENT	0
770836	770561	19782L	PARTICIPANT	\N	PRESENT	0
770839	770561	19383Y	PARTICIPANT	\N	PRESENT	0
770844	770561	21093M	PARTICIPANT	\N	PRESENT	0
770845	770561	20066E	PARTICIPANT	\N	PRESENT	0
770869	770561	19507S	PARTICIPANT	\N	PRESENT	0
770851	770561	20144B	PARTICIPANT	\N	EXCUSE	0
770852	770561	21054E	PARTICIPANT	\N	PRESENT	0
770920	770561	14033T	PARTICIPANT	\N	PRESENT	0
770921	770918	08010L	PARTICIPANT	\N	PRESENT	0
770922	770918	12028B	PARTICIPANT	\N	PRESENT	0
770923	770918	14267Y	PARTICIPANT	\N	PRESENT	0
770925	770561	20018V	PARTICIPANT	\N	PRESENT	0
772585	772584	04047H	PARTICIPANT	\N	PRESENT	0
772586	772584	18231D	PARTICIPANT	\N	PRESENT	0
778547	778545	14059S	PARTICIPANT	\N	PRESENT	0
778548	778545	20092G	PARTICIPANT	\N	PRESENT	0
778549	778545	21073H	PARTICIPANT	\N	PRESENT	0
779003	779002	20114U	PARTICIPANT	\N	PRESENT	0
779004	779002	14255U	PARTICIPANT	\N	PRESENT	0
779005	779002	19723Y	PARTICIPANT	\N	PRESENT	0
779006	779002	19713W	PARTICIPANT	\N	PRESENT	0
779007	779002	21061D	PARTICIPANT	\N	PRESENT	0
779008	779002	20064C	PARTICIPANT	\N	PRESENT	0
783358	783355	14059S	PARTICIPANT	\N	PRESENT	0
783360	783359	18083K	PARTICIPANT	\N	PRESENT	0
783361	783359	17229F	PARTICIPANT	\N	PRESENT	0
783362	783359	19057M	PARTICIPANT	\N	PRESENT	0
786184	786183	04047H	PARTICIPANT	\N	PRESENT	0
786188	786185	04047H	PARTICIPANT	\N	PRESENT	0
794636	794635	14189C	PARTICIPANT	\N	PRESENT	0
794637	794635	20024T	PARTICIPANT	\N	PRESENT	0
794638	794635	19575F	PARTICIPANT	\N	PRESENT	0
794639	794635	20138D	PARTICIPANT	\N	PRESENT	0
794640	794635	14329V	PARTICIPANT	\N	PRESENT	0
794641	794635	11027H	PARTICIPANT	\N	PRESENT	0
794642	794635	20140W	PARTICIPANT	\N	PRESENT	0
794643	794635	20074E	PARTICIPANT	\N	PRESENT	0
794644	794635	14187A	PARTICIPANT	\N	PRESENT	0
794645	794635	20128B	PARTICIPANT	\N	PRESENT	0
794646	794635	20126Y	PARTICIPANT	\N	PRESENT	0
794647	794635	08010L	PARTICIPANT	\N	PRESENT	0
794648	794635	08012N	PARTICIPANT	\N	PRESENT	0
794664	794660	20082E	PARTICIPANT	\N	PRESENT	0
794665	794660	20026V	PARTICIPANT	\N	PRESENT	0
794666	794661	20082E	PARTICIPANT	\N	PRESENT	0
783356	783355	20118Y	PARTICIPANT	\N	PRESENT	0
783357	783355	20096L	PARTICIPANT	\N	PRESENT	0
794667	794661	20026V	PARTICIPANT	\N	PRESENT	0
794668	794662	20082E	PARTICIPANT	\N	PRESENT	0
794669	794662	20026V	PARTICIPANT	\N	PRESENT	0
794670	794663	20026V	PARTICIPANT	\N	PRESENT	0
794938	794062	14193X	PARTICIPANT	\N	PRESENT	0
794940	794062	08015R	PARTICIPANT	\N	PRESENT	0
794942	794062	21075K	PARTICIPANT	\N	PRESENT	0
794945	794062	21092L	PARTICIPANT	\N	PRESENT	0
794946	794062	21051B	PARTICIPANT	\N	PRESENT	0
794947	794062	14207L	PARTICIPANT	\N	PRESENT	0
794948	794062	19669L	PARTICIPANT	\N	PRESENT	0
794953	794062	19575F	PARTICIPANT	\N	PRESENT	0
794954	794062	19954N	PARTICIPANT	\N	PRESENT	0
794955	794062	20018V	PARTICIPANT	\N	PRESENT	0
794956	794062	19573D	PARTICIPANT	\N	PRESENT	0
794957	794062	14187A	PARTICIPANT	\N	PRESENT	0
794958	794062	19758L	PARTICIPANT	\N	PRESENT	0
794959	794062	21097R	PARTICIPANT	\N	PRESENT	0
794960	794062	04092N	PARTICIPANT	\N	PRESENT	0
794972	794708	14111D	PARTICIPANT	\N	PRESENT	0
794973	794708	14215L	PARTICIPANT	\N	PRESENT	0
794974	794708	20022R	PARTICIPANT	\N	PRESENT	0
794975	794708	04047H	PRESIDENT	0	PRESENT	0
794976	794708	14189C	PARTICIPANT	\N	PRESENT	0
794977	794708	21076L	PARTICIPANT	\N	PRESENT	0
794967	794896	14229S	PARTICIPANT	\N	PRESENT	0
794968	794708	21044C	PARTICIPANT	\N	PRESENT	0
794969	794708	20074E	PARTICIPANT	\N	PRESENT	0
794970	794708	14147R	PARTICIPANT	\N	PRESENT	0
794971	794708	21095P	PARTICIPANT	\N	PRESENT	0
794978	794708	08018U	PARTICIPANT	\N	PRESENT	0
794979	794708	19447X	PARTICIPANT	\N	PRESENT	0
794980	794708	19749K	PARTICIPANT	\N	PRESENT	0
794981	794708	04045F	PARTICIPANT	\N	PRESENT	0
794982	794708	11072N	PARTICIPANT	\N	PRESENT	0
794983	794708	19725B	PARTICIPANT	\N	PRESENT	0
795048	794896	18083K	PARTICIPANT	\N	PRESENT	0
795049	794896	19711U	PARTICIPANT	\N	PRESENT	0
795050	794896	08011M	PARTICIPANT	\N	PRESENT	0
795051	794896	08060W	PARTICIPANT	\N	PRESENT	0
795052	794896	21089R	PARTICIPANT	\N	PRESENT	0
795053	794896	11045K	PARTICIPANT	\N	PRESENT	0
795054	794896	18207D	PARTICIPANT	\N	PRESENT	0
795055	794896	21080G	PARTICIPANT	\N	PRESENT	0
795056	794896	19573D	PARTICIPANT	\N	PRESENT	0
795057	794896	20060X	PARTICIPANT	\N	PRESENT	0
795058	794896	21077M	PARTICIPANT	\N	PRESENT	0
795059	794896	19631V	PARTICIPANT	\N	PRESENT	0
795060	794896	18193Q	PARTICIPANT	\N	PRESENT	0
795061	794896	19413M	PARTICIPANT	\N	PRESENT	0
795062	794896	20264J	PARTICIPANT	\N	PRESENT	0
795063	794896	11065P	PARTICIPANT	\N	PRESENT	0
795064	794896	20026V	PARTICIPANT	\N	PRESENT	0
795065	794896	14121F	PARTICIPANT	\N	PRESENT	0
795066	794896	20180F	PARTICIPANT	\N	PRESENT	0
795067	794896	19647E	PARTICIPANT	\N	PRESENT	0
795068	794896	21029D	PARTICIPANT	\N	PRESENT	0
795069	794896	20114U	PARTICIPANT	\N	PRESENT	0
795070	794896	21071F	PARTICIPANT	\N	PRESENT	0
795071	794896	21094N	PARTICIPANT	\N	PRESENT	0
795072	794896	12016W	PARTICIPANT	\N	PRESENT	0
795073	794896	21043B	PARTICIPANT	\N	PRESENT	0
795074	794896	21097R	PARTICIPANT	\N	PRESENT	0
795075	794896	20032T	PARTICIPANT	\N	PRESENT	0
795076	794896	21096Q	PARTICIPANT	\N	PRESENT	0
795077	794896	14221J	PARTICIPANT	\N	PRESENT	0
795078	794896	21081H	PARTICIPANT	\N	PRESENT	0
795079	794896	14111D	PARTICIPANT	\N	PRESENT	0
795080	794896	08047A	PARTICIPANT	\N	PRESENT	0
795081	794896	19545Y	PARTICIPANT	\N	PRESENT	0
795082	794896	19954N	PARTICIPANT	\N	PRESENT	0
795083	794896	19693L	PARTICIPANT	\N	PRESENT	0
795084	794896	21087P	PARTICIPANT	\N	PRESENT	0
795085	794896	21040X	PARTICIPANT	\N	PRESENT	0
795086	794896	20172F	PARTICIPANT	\N	PRESENT	0
795087	794896	19629C	PARTICIPANT	\N	PRESENT	0
795088	794896	21036C	PARTICIPANT	\N	PRESENT	0
795089	794896	19768N	PARTICIPANT	\N	PRESENT	0
795090	794896	20084G	PARTICIPANT	\N	PRESENT	0
795091	794896	14257W	PARTICIPANT	\N	PRESENT	0
795092	794896	18231D	PARTICIPANT	\N	PRESENT	0
795093	794896	20082E	PARTICIPANT	\N	PRESENT	0
795094	794896	20030R	PARTICIPANT	\N	PRESENT	0
795095	794896	21091K	PARTICIPANT	\N	PRESENT	0
795096	794896	20064C	PARTICIPANT	\N	PRESENT	0
795097	794896	21031W	PARTICIPANT	\N	PRESENT	0
795098	794896	04042C	PARTICIPANT	\N	PRESENT	0
795099	794896	19531S	PARTICIPANT	\N	PRESENT	0
795100	794896	20028X	PARTICIPANT	\N	PRESENT	0
795101	794896	14187A	PARTICIPANT	\N	PRESENT	0
795102	794896	19649G	PARTICIPANT	\N	PRESENT	0
795103	794896	14021P	PARTICIPANT	\N	PRESENT	0
795104	794896	19331L	PARTICIPANT	\N	PRESENT	0
795105	794896	19725B	PARTICIPANT	\N	PRESENT	0
795106	794896	19679N	PARTICIPANT	\N	PRESENT	0
795107	794896	14151M	PARTICIPANT	\N	PRESENT	0
795108	794896	21045D	PARTICIPANT	\N	PRESENT	0
795109	794896	14217N	PARTICIPANT	\N	PRESENT	0
795110	794896	20094J	PARTICIPANT	\N	PRESENT	0
795111	794896	14059S	PARTICIPANT	\N	PRESENT	0
795112	794896	11110B	PARTICIPANT	\N	PRESENT	0
795113	794896	08056B	PARTICIPANT	\N	PRESENT	0
795114	794896	19758L	PARTICIPANT	\N	PRESENT	0
777121	776545	20034V	PARTICIPANT	\N	PRESENT	0
777122	776545	19347U	PARTICIPANT	\N	PRESENT	0
777123	776545	11065P	PARTICIPANT	\N	PRESENT	0
777124	776545	21085M	PARTICIPANT	\N	PRESENT	0
777125	776545	20134Y	PARTICIPANT	\N	PRESENT	0
777126	776545	14042U	PARTICIPANT	\N	PRESENT	0
777127	776545	14030Q	PARTICIPANT	\N	PRESENT	0
777128	776545	07029T	PARTICIPANT	\N	PRESENT	0
777129	776545	11056N	PARTICIPANT	\N	PRESENT	0
781241	779255	20094J	PARTICIPANT	\N	PRESENT	0
781242	779255	19701S	PARTICIPANT	\N	PRESENT	0
781243	779255	20104S	PARTICIPANT	\N	PRESENT	0
781244	779255	20286Q	PARTICIPANT	\N	PRESENT	0
781246	779255	19711U	PARTICIPANT	\N	PRESENT	0
781247	779255	08034U	PARTICIPANT	\N	PRESENT	0
781248	779255	18207D	PARTICIPANT	\N	PRESENT	0
781249	779255	14001X	PARTICIPANT	\N	PRESENT	0
781250	779255	08073C	PARTICIPANT	\N	PRESENT	0
781252	779255	20150Y	PARTICIPANT	\N	PRESENT	0
781254	779255	21082J	PARTICIPANT	\N	PRESENT	0
781257	779255	10015M	PARTICIPANT	\N	PRESENT	0
781258	779255	14225N	PARTICIPANT	\N	PRESENT	0
781259	779255	11048N	PARTICIPANT	\N	PRESENT	0
781260	779255	20044X	PARTICIPANT	\N	PRESENT	0
781300	781299	20024T	PARTICIPANT	\N	PRESENT	0
781301	781299	11027H	PARTICIPANT	\N	PRESENT	0
781302	781299	21088Q	PARTICIPANT	\N	PRESENT	0
781303	781299	11056N	PARTICIPANT	\N	PRESENT	0
781304	781299	21062E	PARTICIPANT	\N	PRESENT	0
781305	781299	20034V	PARTICIPANT	\N	PRESENT	0
781306	781299	14219Q	PARTICIPANT	\N	PRESENT	0
781307	781299	21073H	PARTICIPANT	\N	PRESENT	0
781308	781299	04092N	PARTICIPANT	\N	PRESENT	0
781309	781299	14169X	PARTICIPANT	\N	PRESENT	0
781310	781299	20064C	PARTICIPANT	\N	PRESENT	0
781311	781299	19585H	PARTICIPANT	\N	PRESENT	0
781312	781299	21038E	PARTICIPANT	\N	PRESENT	0
782590	782589	19611R	PARTICIPANT	\N	PRESENT	0
782591	782589	19621T	PARTICIPANT	\N	PRESENT	0
782592	782589	11043H	PARTICIPANT	\N	PRESENT	0
782593	782589	14123H	PARTICIPANT	\N	PRESENT	0
782594	782589	14109K	PARTICIPANT	\N	PRESENT	0
782653	782589	20264J	PARTICIPANT	\N	PRESENT	0
782654	782589	19697Q	PARTICIPANT	\N	PRESENT	0
782663	782589	20112S	PARTICIPANT	\N	PRESENT	0
782666	782589	20142Y	PARTICIPANT	\N	PRESENT	0
782668	782589	20132W	PARTICIPANT	\N	PRESENT	0
782670	782589	20026V	PARTICIPANT	\N	PRESENT	0
782671	782589	20056C	PARTICIPANT	\N	PRESENT	0
782674	782589	21089R	PARTICIPANT	\N	PRESENT	0
782675	782589	20052X	PARTICIPANT	\N	PRESENT	0
782913	778688	20100N	PARTICIPANT	\N	PRESENT	0
782914	778688	14331P	PARTICIPANT	\N	PRESENT	0
782915	778688	14001X	PARTICIPANT	\N	PRESENT	0
782941	779088	20150Y	PARTICIPANT	\N	EXCUSE	0
782960	779088	20146D	PARTICIPANT	\N	EXCUSE	0
782967	779088	21071F	PARTICIPANT	\N	EXCUSE	0
782968	779088	19657G	PARTICIPANT	\N	EXCUSE	0
782970	779088	20122U	PARTICIPANT	\N	PRESENT	0
782971	779088	04042C	PARTICIPANT	\N	PRESENT	0
782972	779088	20034V	PRESIDENT	0	PRESENT	0
782973	779088	21055F	PARTICIPANT	\N	PRESENT	0
782975	779088	21033Y	PARTICIPANT	\N	PRESENT	0
782976	779088	14059S	PARTICIPANT	\N	PRESENT	0
782994	779088	19331L	PARTICIPANT	\N	PRESENT	0
783038	783037	19611R	PARTICIPANT	\N	PRESENT	0
784209	783382	20024T	PARTICIPANT	\N	PRESENT	0
784210	783382	21063F	PARTICIPANT	\N	PRESENT	0
784211	783382	20034V	PARTICIPANT	\N	PRESENT	0
784212	783382	21039F	PARTICIPANT	\N	PRESENT	0
784213	783382	20038A	PARTICIPANT	\N	PRESENT	0
784214	783382	20056C	PARTICIPANT	\N	PRESENT	0
784215	783382	19399H	PARTICIPANT	\N	PRESENT	0
784216	783382	20086J	PARTICIPANT	\N	PRESENT	0
784217	783382	14026U	PARTICIPANT	\N	PRESENT	0
784218	783382	20098N	PARTICIPANT	\N	PRESENT	0
784219	783382	19798U	PARTICIPANT	\N	PRESENT	0
784220	783382	20090E	PARTICIPANT	\N	PRESENT	0
784221	783382	17737W	PARTICIPANT	\N	PRESENT	0
784222	783382	20096L	PARTICIPANT	\N	PRESENT	0
784223	783382	20180F	PARTICIPANT	\N	PRESENT	0
784224	783382	21072G	PARTICIPANT	\N	PRESENT	0
784225	783382	14215L	PARTICIPANT	\N	PRESENT	0
784226	783382	11043H	PARTICIPANT	\N	PRESENT	0
784227	783382	19621T	PARTICIPANT	\N	PRESENT	0
784228	783382	20062A	PARTICIPANT	\N	PRESENT	0
784229	783382	05008E	PARTICIPANT	\N	PRESENT	0
784230	783382	14133K	PARTICIPANT	\N	PRESENT	0
784231	783382	19575F	PARTICIPANT	\N	PRESENT	0
784232	783382	21061D	PARTICIPANT	\N	PRESENT	0
784233	783382	21044C	PARTICIPANT	\N	PRESENT	0
784234	783382	95041E	PARTICIPANT	\N	PRESENT	0
784235	783382	20142Y	PARTICIPANT	\N	PRESENT	0
784236	783382	14083S	PARTICIPANT	\N	PRESENT	0
784237	783382	20018V	PARTICIPANT	\N	PRESENT	0
784238	783382	14147R	PARTICIPANT	\N	PRESENT	0
784239	783382	19565D	PARTICIPANT	\N	PRESENT	0
784240	783382	20102Q	PARTICIPANT	\N	PRESENT	0
784241	783382	21045D	PARTICIPANT	\N	PRESENT	0
784242	783382	20042V	PARTICIPANT	\N	PRESENT	0
784243	783382	19533U	PARTICIPANT	\N	PRESENT	0
784244	783382	20082E	PARTICIPANT	\N	PRESENT	0
784245	783382	08069G	PARTICIPANT	\N	PRESENT	0
784246	783382	08028W	PARTICIPANT	\N	PRESENT	0
784247	783382	99004R	PARTICIPANT	\N	PRESENT	0
784248	783382	21036C	PARTICIPANT	\N	PRESENT	0
784249	783382	08018U	PARTICIPANT	\N	PRESENT	0
784250	783382	19758L	PARTICIPANT	\N	PRESENT	0
784251	783382	21095P	PARTICIPANT	\N	PRESENT	0
784252	783382	08056B	PARTICIPANT	\N	PRESENT	0
784253	783382	20036X	PARTICIPANT	\N	PRESENT	0
784254	783382	14069U	PARTICIPANT	\N	PRESENT	0
784255	783382	19701S	PARTICIPANT	\N	PRESENT	0
784256	783382	20032T	PARTICIPANT	\N	PRESENT	0
784257	783382	20026V	PARTICIPANT	\N	PRESENT	0
784258	783382	20088L	PARTICIPANT	\N	PRESENT	0
784259	783382	19111A	PARTICIPANT	\N	PRESENT	0
784260	783382	21038E	PARTICIPANT	\N	PRESENT	0
784261	783368	21082J	PARTICIPANT	\N	PRESENT	0
784262	783368	14331P	PRESIDENT	0	PRESENT	0
784263	783368	14097Y	PARTICIPANT	\N	PRESENT	0
784264	783368	19701S	PARTICIPANT	\N	PRESENT	0
784265	783368	14073Q	PARTICIPANT	\N	PRESENT	0
784542	783384	14231L	PARTICIPANT	\N	PRESENT	0
784267	783368	20042V	PARTICIPANT	0	PRESENT	0
784268	783368	10015M	PARTICIPANT	\N	PRESENT	0
784269	783368	21076L	PARTICIPANT	\N	PRESENT	0
784270	783368	14001X	PARTICIPANT	\N	PRESENT	0
784271	783368	20094J	PARTICIPANT	\N	PRESENT	0
784272	783368	14169X	PARTICIPANT	\N	PRESENT	0
784273	783368	14237S	PARTICIPANT	\N	PRESENT	0
784274	783368	20100N	PARTICIPANT	\N	PRESENT	0
784275	783368	18395Y	PARTICIPANT	\N	PRESENT	0
784276	783368	20106U	PARTICIPANT	\N	EXCUSE	0
784277	783368	14189C	PARTICIPANT	\N	EXCUSE	0
784286	783382	01058X	PARTICIPANT	\N	PRESENT	0
784289	783382	21058J	PARTICIPANT	\N	PRESENT	0
784530	783384	08069G	PARTICIPANT	\N	PRESENT	0
784531	783384	21045D	PARTICIPANT	\N	PRESENT	0
784535	783384	19719D	PARTICIPANT	\N	PRESENT	0
784536	783368	20104S	PARTICIPANT	\N	PRESENT	0
784540	783384	20096L	PARTICIPANT	\N	PRESENT	0
784541	783384	14147R	PARTICIPANT	\N	PRESENT	0
784543	783384	19768N	PARTICIPANT	\N	PRESENT	0
784544	783384	21073H	PARTICIPANT	\N	PRESENT	0
784545	783384	21043B	PARTICIPANT	\N	PRESENT	0
784546	783384	20026V	PARTICIPANT	\N	PRESENT	0
784547	783384	21083K	PARTICIPANT	\N	PRESENT	0
784548	783384	21095P	PARTICIPANT	\N	PRESENT	0
784549	783384	14255U	PARTICIPANT	\N	PRESENT	0
784550	783384	21046E	PARTICIPANT	\N	PRESENT	0
784551	783384	19649G	PARTICIPANT	\N	PRESENT	0
784552	783384	21055F	PARTICIPANT	\N	PRESENT	0
784557	783384	20100N	PARTICIPANT	\N	PRESENT	0
784558	783384	11056N	PARTICIPANT	\N	PRESENT	0
784559	783384	20068G	PARTICIPANT	\N	PRESENT	0
784560	783384	21064G	PARTICIPANT	\N	PRESENT	0
784561	783384	19631V	PARTICIPANT	\N	PRESENT	0
784562	783384	14069U	PARTICIPANT	\N	PRESENT	0
784563	783384	21050A	PARTICIPANT	\N	PRESENT	0
784564	783384	14031R	PARTICIPANT	\N	PRESENT	0
767880	765403	19533U	PARTICIPANT	\N	PRESENT	0
767886	765403	11115U	PARTICIPANT	\N	PRESENT	0
767884	765403	20064C	PARTICIPANT	\N	PRESENT	0
767885	765403	11048N	PARTICIPANT	\N	PRESENT	0
767887	765403	14327T	PARTICIPANT	\N	PRESENT	0
767888	765403	19693L	PARTICIPANT	\N	PRESENT	0
767889	765403	14249W	PARTICIPANT	\N	PRESENT	0
767890	765403	19735D	PARTICIPANT	\N	PRESENT	0
767891	765403	14179A	PARTICIPANT	\N	PRESENT	0
767892	765403	14205J	PARTICIPANT	\N	PRESENT	0
767893	765403	14030Q	PARTICIPANT	\N	PRESENT	0
767894	765403	11053K	PARTICIPANT	\N	PRESENT	0
767895	765403	20094J	PARTICIPANT	\N	PRESENT	0
767896	765403	21094N	PARTICIPANT	\N	PRESENT	0
767897	765403	21083K	PARTICIPANT	\N	PRESENT	0
767898	765403	14033T	PARTICIPANT	\N	PRESENT	0
767899	765403	20090E	PARTICIPANT	\N	PRESENT	0
767900	765403	17737W	PARTICIPANT	\N	PRESENT	0
767901	765403	14187A	PARTICIPANT	\N	PRESENT	0
767902	765403	20058E	PARTICIPANT	\N	PRESENT	0
767903	765403	20120S	PARTICIPANT	\N	PRESENT	0
768204	765404	14259Y	PARTICIPANT	\N	PRESENT	0
768205	765404	14042U	PARTICIPANT	\N	PRESENT	0
768206	765404	14071N	PARTICIPANT	\N	PRESENT	0
768207	765404	20130U	PARTICIPANT	\N	PRESENT	0
768208	765404	19719D	PARTICIPANT	\N	PRESENT	0
768209	765404	07004J	PARTICIPANT	\N	PRESENT	0
768210	765404	19691J	PARTICIPANT	\N	PRESENT	0
768240	765404	14217N	PARTICIPANT	\N	PRESENT	0
768212	765404	14195A	PARTICIPANT	\N	PRESENT	0
768213	765404	21094N	PARTICIPANT	\N	PRESENT	0
768242	765404	21081H	PARTICIPANT	\N	PRESENT	0
768243	765404	19367Y	PARTICIPANT	\N	PRESENT	0
768216	765404	20114U	PARTICIPANT	\N	PRESENT	0
768217	765404	20090E	PARTICIPANT	\N	PRESENT	0
768218	765404	08069G	PARTICIPANT	\N	PRESENT	0
768219	765404	20140W	PARTICIPANT	\N	PRESENT	0
768220	765404	19798U	PARTICIPANT	\N	PRESENT	0
768221	765404	21069M	PARTICIPANT	\N	PRESENT	0
768222	765404	21074J	PARTICIPANT	\N	PRESENT	0
768223	765404	20062A	PARTICIPANT	\N	PRESENT	0
768224	765404	04092N	PARTICIPANT	\N	PRESENT	0
768234	765404	20098N	PARTICIPANT	\N	PRESENT	0
768244	765404	20106U	PARTICIPANT	\N	PRESENT	0
768227	765404	21082J	PARTICIPANT	\N	PRESENT	0
768228	765404	21060C	PARTICIPANT	\N	PRESENT	0
768229	765404	19565D	PARTICIPANT	\N	PRESENT	0
768246	765404	14083S	PARTICIPANT	\N	PRESENT	0
768247	765404	14205J	PARTICIPANT	\N	PRESENT	0
768248	765404	21071F	PARTICIPANT	\N	PRESENT	0
768255	765404	21045D	PARTICIPANT	\N	PRESENT	0
768259	765404	20136B	PARTICIPANT	\N	PRESENT	0
768262	765404	19553Y	PARTICIPANT	\N	PRESENT	0
768267	765404	20122U	PARTICIPANT	\N	PRESENT	0
768272	765404	17965H	PARTICIPANT	\N	PRESENT	0
768273	765404	19683J	PARTICIPANT	\N	PRESENT	0
768275	765404	19657G	PARTICIPANT	\N	PRESENT	0
768276	765404	20034V	PARTICIPANT	\N	PRESENT	0
768277	765404	19760E	PARTICIPANT	\N	PRESENT	0
768278	765404	19758L	PARTICIPANT	\N	PRESENT	0
768279	765404	19387D	PARTICIPANT	\N	PRESENT	0
768280	765404	19301E	PARTICIPANT	\N	PRESENT	0
768282	765404	14281W	PARTICIPANT	\N	PRESENT	0
768285	767904	21052C	PARTICIPANT	\N	PRESENT	0
768286	767904	19768N	PARTICIPANT	\N	PRESENT	0
768287	767904	14187A	PRESIDENT	0	PRESENT	0
768288	767904	14357A	PARTICIPANT	\N	PRESENT	0
768289	767904	21083K	PARTICIPANT	\N	PRESENT	0
768290	767904	19413M	PARTICIPANT	\N	PRESENT	0
768291	767904	21086N	PARTICIPANT	\N	PRESENT	0
768292	767904	21092L	PARTICIPANT	\N	PRESENT	0
768293	767904	19695N	PARTICIPANT	\N	PRESENT	0
768294	767904	20082E	PARTICIPANT	\N	PRESENT	0
768295	767904	14033T	PRESIDENT	1	PRESENT	0
768296	767904	11090Q	PARTICIPANT	\N	PRESENT	0
768297	767904	14221J	PARTICIPANT	\N	PRESENT	0
768298	767904	19631V	PARTICIPANT	\N	PRESENT	0
768299	767904	14205J	PARTICIPANT	\N	PRESENT	0
768300	767904	08015R	PARTICIPANT	\N	PRESENT	0
768301	767904	21066J	PARTICIPANT	\N	PRESENT	0
768302	767904	19575F	PARTICIPANT	\N	PRESENT	0
768303	767904	20018V	PARTICIPANT	\N	PRESENT	0
768304	767904	14207L	PARTICIPANT	\N	PRESENT	0
768305	767904	19563B	PARTICIPANT	\N	PRESENT	0
768306	767904	14257W	PARTICIPANT	\N	PRESENT	0
768311	765404	20058E	PARTICIPANT	\N	PRESENT	0
768328	765404	19723Y	PARTICIPANT	\N	PRESENT	0
768317	767904	14038Y	PARTICIPANT	\N	PRESENT	0
768318	767904	20092G	PARTICIPANT	\N	PRESENT	0
768320	765404	14107H	PARTICIPANT	\N	PRESENT	0
768321	765404	21040X	PARTICIPANT	\N	PRESENT	0
768322	765404	19569H	PARTICIPANT	\N	PRESENT	0
768324	765404	20126Y	PARTICIPANT	\N	PRESENT	0
768329	765404	08061X	PARTICIPANT	\N	PRESENT	0
768330	765404	19703U	PARTICIPANT	\N	PRESENT	0
768331	767904	20038A	PARTICIPANT	\N	EXCUSE	0
768332	767904	20066E	PARTICIPANT	\N	EXCUSE	0
768334	765404	20048C	PARTICIPANT	\N	PRESENT	0
768335	765404	98022P	PARTICIPANT	\N	PRESENT	0
768336	765404	14223L	PARTICIPANT	\N	PRESENT	0
768338	765404	20128B	PARTICIPANT	\N	PRESENT	0
768339	765404	08056B	PARTICIPANT	\N	PRESENT	0
768342	765404	19347U	PARTICIPANT	\N	PRESENT	0
768343	765404	19866P	PARTICIPANT	\N	PRESENT	0
768344	765404	14026U	PARTICIPANT	\N	PRESENT	0
768345	765404	01058X	PARTICIPANT	\N	PRESENT	0
768349	765404	14257W	PARTICIPANT	\N	PRESENT	0
768350	765404	20040T	PARTICIPANT	\N	PRESENT	0
768351	765404	14121F	PARTICIPANT	\N	PRESENT	0
768356	765404	20030R	PARTICIPANT	\N	PRESENT	0
768361	767904	19782L	PARTICIPANT	\N	PRESENT	0
768362	765404	14123H	PARTICIPANT	\N	PRESENT	0
768363	765404	14147R	PARTICIPANT	\N	PRESENT	0
768364	765404	14249W	PARTICIPANT	\N	PRESENT	0
768365	765404	20052X	PARTICIPANT	\N	PRESENT	0
768372	765404	17779H	PARTICIPANT	\N	PRESENT	0
768373	765404	08015R	PARTICIPANT	\N	PRESENT	0
768374	765404	19749K	PARTICIPANT	\N	PRESENT	0
768375	765404	20180F	PARTICIPANT	\N	PRESENT	0
768376	765404	10015M	PARTICIPANT	\N	PRESENT	0
768377	765404	20026V	PARTICIPANT	\N	PRESENT	0
768378	765404	19826F	PARTICIPANT	\N	PRESENT	0
768380	765404	20172F	PARTICIPANT	\N	PRESENT	0
768381	765404	14109K	PARTICIPANT	\N	PRESENT	0
768382	765404	14097Y	PARTICIPANT	\N	PRESENT	0
768383	765404	21049H	PARTICIPANT	\N	PRESENT	0
768384	765404	21087P	PARTICIPANT	\N	PRESENT	0
768385	765404	19349W	PARTICIPANT	\N	PRESENT	0
768386	765404	21039F	PARTICIPANT	\N	PRESENT	0
768387	765404	19713W	PARTICIPANT	\N	PRESENT	0
768388	765404	19399H	PARTICIPANT	\N	PRESENT	0
768389	765404	19591F	PARTICIPANT	\N	PRESENT	0
768390	765404	21046E	PARTICIPANT	\N	PRESENT	0
768391	765404	04045F	PARTICIPANT	\N	PRESENT	0
768392	765404	21058J	PARTICIPANT	\N	PRESENT	0
768393	765404	21057H	PARTICIPANT	\N	PRESENT	0
768394	765404	19695N	PARTICIPANT	\N	PRESENT	0
768395	765404	20266L	PARTICIPANT	\N	PRESENT	0
768396	765404	14231L	PARTICIPANT	\N	PRESENT	0
768397	765404	20096L	PARTICIPANT	\N	PRESENT	0
768398	765404	20148F	PARTICIPANT	\N	PRESENT	0
768399	765404	21042A	PARTICIPANT	\N	PRESENT	0
768400	765848	21082J	PARTICIPANT	\N	PRESENT	0
768401	765848	19701S	PARTICIPANT	\N	PRESENT	0
768402	765848	21035B	PARTICIPANT	\N	PRESENT	0
768403	765848	20076G	PARTICIPANT	\N	PRESENT	0
768404	765848	19387D	PARTICIPANT	\N	PRESENT	0
768405	765848	14219Q	PARTICIPANT	\N	PRESENT	0
768406	765848	19820Y	PARTICIPANT	\N	PRESENT	0
768407	765848	19826F	PARTICIPANT	\N	PRESENT	0
768408	765848	21062E	PARTICIPANT	\N	PRESENT	0
768409	765848	21065H	PARTICIPANT	\N	PRESENT	0
768410	765848	20100N	PARTICIPANT	\N	PRESENT	0
768411	765848	18083K	PARTICIPANT	\N	PRESENT	0
768412	765848	05012A	PARTICIPANT	\N	PRESENT	0
768413	765848	08060W	PARTICIPANT	\N	PRESENT	0
768414	765848	14107H	PARTICIPANT	\N	PRESENT	0
768415	765848	20020P	PARTICIPANT	\N	PRESENT	0
768416	765848	11065P	PARTICIPANT	\N	PRESENT	0
768417	765848	21051B	PARTICIPANT	\N	PRESENT	0
768418	765848	20032T	PARTICIPANT	\N	PRESENT	0
777700	776548	14033T	PARTICIPANT	\N	PRESENT	0
777701	776548	14147R	PARTICIPANT	\N	PRESENT	0
777703	776548	21062E	PARTICIPANT	\N	PRESENT	0
777705	776548	21093M	PARTICIPANT	\N	PRESENT	0
777716	776548	01058X	PARTICIPANT	\N	PRESENT	0
777741	776548	20066E	PARTICIPANT	\N	PRESENT	0
777742	776548	21068L	PARTICIPANT	\N	PRESENT	0
777743	776548	21078N	PARTICIPANT	\N	PRESENT	0
777744	776548	20022R	PARTICIPANT	\N	PRESENT	0
777745	776548	21090J	PARTICIPANT	\N	PRESENT	0
777746	776548	14026U	PARTICIPANT	\N	PRESENT	0
777747	776548	21042A	PARTICIPANT	\N	PRESENT	0
777748	776548	08061X	PARTICIPANT	\N	PRESENT	0
777749	776548	20120S	PARTICIPANT	\N	PRESENT	0
777750	776548	20180F	PARTICIPANT	\N	PRESENT	0
777751	776548	20142Y	PARTICIPANT	\N	PRESENT	0
777752	776548	14187A	PARTICIPANT	\N	PRESENT	0
777753	776548	21043B	PARTICIPANT	\N	PRESENT	0
777754	776548	19531S	PARTICIPANT	\N	PRESENT	0
777755	776548	08028W	PARTICIPANT	\N	PRESENT	0
777756	776548	19347U	PARTICIPANT	\N	PRESENT	0
777757	776548	05012A	PARTICIPANT	\N	PRESENT	0
777835	776550	20086J	PARTICIPANT	\N	PRESENT	0
777836	776550	19667J	PARTICIPANT	\N	PRESENT	0
777837	776550	11040E	PARTICIPANT	\N	PRESENT	0
777838	776550	20090E	PARTICIPANT	\N	PRESENT	0
777839	776550	19798U	PARTICIPANT	\N	PRESENT	0
777840	776550	20130U	PARTICIPANT	\N	PRESENT	0
777841	776550	21049H	PARTICIPANT	\N	PRESENT	0
777842	776550	19866P	PARTICIPANT	\N	PRESENT	0
777843	776550	19531S	PARTICIPANT	\N	PRESENT	0
777844	776550	18193Q	PARTICIPANT	\N	PRESENT	0
777845	776550	14281W	PARTICIPANT	\N	PRESENT	0
777846	776550	21087P	PARTICIPANT	\N	PRESENT	0
777847	776550	21046E	PARTICIPANT	\N	PRESENT	0
777848	776550	14223L	PARTICIPANT	\N	PRESENT	0
777849	776550	19367Y	PARTICIPANT	\N	PRESENT	0
777850	776550	20096L	PARTICIPANT	\N	PRESENT	0
777851	776550	19749K	PARTICIPANT	\N	PRESENT	0
777852	776550	21042A	PARTICIPANT	\N	PRESENT	0
777853	776550	21058J	PARTICIPANT	\N	PRESENT	0
777854	776550	20180F	PARTICIPANT	\N	PRESENT	0
777855	776550	19565D	PARTICIPANT	\N	PRESENT	0
777856	776550	19691J	PARTICIPANT	\N	PRESENT	0
777857	776550	21097R	PARTICIPANT	\N	PRESENT	0
777858	776550	07029T	PARTICIPANT	\N	PRESENT	0
777859	776550	19629C	PARTICIPANT	\N	PRESENT	0
777860	776550	21066J	PARTICIPANT	\N	PRESENT	0
777861	776550	14147R	PARTICIPANT	\N	PRESENT	0
777862	776550	17779H	PARTICIPANT	\N	PRESENT	0
777863	776550	21039F	PARTICIPANT	\N	PRESENT	0
777864	776550	19387D	PARTICIPANT	\N	PRESENT	0
777865	776550	20062A	PARTICIPANT	\N	PRESENT	0
777866	776550	19782L	PARTICIPANT	\N	PRESENT	0
777867	776550	19591F	PARTICIPANT	\N	PRESENT	0
777868	776550	20104S	PARTICIPANT	\N	PRESENT	0
777869	776550	14217N	PARTICIPANT	\N	PRESENT	0
777870	776550	04092N	PARTICIPANT	\N	PRESENT	0
777871	776550	20076G	PARTICIPANT	\N	PRESENT	0
777872	776550	21083K	PARTICIPANT	\N	PRESENT	0
777873	776550	19723Y	PARTICIPANT	\N	PRESENT	0
777874	776550	17965H	PARTICIPANT	\N	PRESENT	0
777875	776550	04033B	PARTICIPANT	\N	PRESENT	0
777876	776550	14026U	PARTICIPANT	\N	PRESENT	0
777877	776550	14071N	PARTICIPANT	\N	PRESENT	0
777878	776550	21045D	PARTICIPANT	\N	PRESENT	0
777879	776550	21044C	PARTICIPANT	\N	PRESENT	0
777880	776550	19758L	PARTICIPANT	\N	PRESENT	0
777881	776550	21054E	PARTICIPANT	\N	PRESENT	0
777882	776550	11090Q	PARTICIPANT	\N	PRESENT	0
777883	776550	11048N	PARTICIPANT	\N	PRESENT	0
777884	776550	21070E	PARTICIPANT	\N	PRESENT	0
777885	776550	14033T	PARTICIPANT	\N	PRESENT	0
777886	776550	20032T	PARTICIPANT	\N	PRESENT	0
777887	776550	14111D	PARTICIPANT	\N	PRESENT	0
777888	776550	20052X	PARTICIPANT	\N	PRESENT	0
777889	776550	08015R	PARTICIPANT	\N	PRESENT	0
777890	776550	21048G	PARTICIPANT	\N	PRESENT	0
777891	776550	20172F	PARTICIPANT	\N	PRESENT	0
777892	776550	14213J	PARTICIPANT	\N	PRESENT	0
777893	776550	14037X	PARTICIPANT	\N	PRESENT	0
777894	776550	11110B	PARTICIPANT	\N	PRESENT	0
777895	776550	20034V	PARTICIPANT	\N	PRESENT	0
777896	776550	19569H	PARTICIPANT	\N	PRESENT	0
777897	776550	19647E	PARTICIPANT	\N	PRESENT	0
777898	776550	18083K	PARTICIPANT	\N	PRESENT	0
777899	776550	14215L	PARTICIPANT	\N	PRESENT	0
777900	776550	20058E	PARTICIPANT	\N	PRESENT	0
777901	776550	21064G	PARTICIPANT	\N	PRESENT	0
777902	776550	14219Q	PARTICIPANT	\N	PRESENT	0
777903	776550	14251Q	PARTICIPANT	\N	PRESENT	0
777904	776550	14083S	PARTICIPANT	\N	PRESENT	0
777905	776550	14231L	PARTICIPANT	\N	PRESENT	0
777906	776550	20266L	PARTICIPANT	\N	PRESENT	0
777907	776550	14069U	PARTICIPANT	\N	PRESENT	0
777908	776550	20066E	PARTICIPANT	\N	PRESENT	0
777909	776550	19349W	PARTICIPANT	\N	PRESENT	0
777833	776550	14179A	PARTICIPANT	\N	PRESENT	0
777834	776550	21069M	PARTICIPANT	\N	PRESENT	0
777910	776550	19383Y	PARTICIPANT	\N	PRESENT	0
777912	775973	14275Y	PARTICIPANT	\N	PRESENT	0
777913	775973	19649G	PARTICIPANT	\N	PRESENT	0
777914	775973	20108W	PARTICIPANT	\N	PRESENT	0
777915	775973	19111A	PARTICIPANT	\N	PRESENT	0
777916	775973	14111D	PARTICIPANT	\N	PRESENT	0
777917	776551	19593H	PARTICIPANT	\N	PRESENT	0
777920	775973	20036X	PARTICIPANT	\N	PRESENT	0
777921	775973	20074E	PARTICIPANT	\N	PRESENT	0
777922	775973	04047H	PRESIDENT	0	PRESENT	0
777923	775973	21040X	PARTICIPANT	\N	PRESENT	0
777924	775973	05008E	PARTICIPANT	\N	PRESENT	0
777925	775973	19447X	PARTICIPANT	\N	PRESENT	0
777926	775973	14089Y	PARTICIPANT	\N	PRESENT	0
777927	775973	04008A	PARTICIPANT	\N	PRESENT	0
777928	775973	20022R	PARTICIPANT	\N	PRESENT	0
777930	775973	04045F	PARTICIPANT	\N	PRESENT	0
777931	775973	21043B	PARTICIPANT	\N	PRESENT	0
777932	775973	20266L	PARTICIPANT	\N	PRESENT	0
777933	775973	20110Q	PARTICIPANT	\N	PRESENT	0
777934	775973	14215L	PARTICIPANT	\N	PRESENT	0
777935	775973	08018U	PARTICIPANT	\N	PRESENT	0
777960	775973	20098N	PARTICIPANT	\N	PRESENT	0
777961	775973	19489J	PARTICIPANT	\N	PRESENT	0
777962	775973	18231D	PARTICIPANT	\N	PRESENT	0
777963	775973	21038E	PARTICIPANT	\N	PRESENT	0
777964	775973	11072N	PARTICIPANT	\N	PRESENT	0
777965	775973	19725B	PARTICIPANT	\N	PRESENT	0
777966	775973	19729F	PARTICIPANT	\N	PRESENT	0
777967	775973	19749K	PARTICIPANT	\N	PRESENT	0
777968	775973	18207D	PARTICIPANT	\N	PRESENT	0
777969	775973	21057H	PARTICIPANT	\N	EXCUSE	0
778004	778003	14026U	PARTICIPANT	\N	PRESENT	0
778005	778003	19760E	PARTICIPANT	\N	PRESENT	0
778006	778003	19683J	PARTICIPANT	\N	PRESENT	0
778009	778008	14026U	PARTICIPANT	\N	PRESENT	0
778010	778008	19760E	PARTICIPANT	\N	PRESENT	0
778011	778008	19683J	PARTICIPANT	\N	PRESENT	0
778082	778081	20094J	PARTICIPANT	\N	PRESENT	0
778083	778081	19711U	PARTICIPANT	\N	PRESENT	0
778084	776140	20016T	PARTICIPANT	\N	PRESENT	0
778085	775805	14133K	PRESIDENT	0	PRESENT	0
778127	776551	14327T	PARTICIPANT	\N	PRESENT	0
778128	776551	14083S	PARTICIPANT	\N	PRESENT	0
778129	776551	19489J	PARTICIPANT	\N	PRESENT	0
778130	776551	11056N	PARTICIPANT	\N	PRESENT	0
778131	776551	20110Q	PARTICIPANT	\N	PRESENT	0
778132	776551	20086J	PARTICIPANT	\N	PRESENT	0
778133	776551	20020P	PARTICIPANT	\N	PRESENT	0
778134	776551	07029T	PARTICIPANT	\N	PRESENT	0
778135	776551	21041Y	PARTICIPANT	\N	PRESENT	0
778136	776551	19349W	PARTICIPANT	\N	PRESENT	0
778137	776551	14231L	PARTICIPANT	\N	PRESENT	0
778138	776551	14069U	PARTICIPANT	\N	PRESENT	0
778139	776551	21043B	PARTICIPANT	\N	PRESENT	0
778140	776551	20024T	PARTICIPANT	\N	PRESENT	0
778141	776551	20076G	PARTICIPANT	\N	PRESENT	0
778142	776551	20062A	PARTICIPANT	\N	PRESENT	0
778143	776551	05012A	PARTICIPANT	\N	PRESENT	0
778144	776551	19687N	PARTICIPANT	\N	PRESENT	0
778145	776551	14259Y	PARTICIPANT	\N	PRESENT	0
778146	776551	19725B	PARTICIPANT	\N	PRESENT	0
772296	772293	20100N	PARTICIPANT	\N	PRESENT	0
772298	772297	20100N	PARTICIPANT	\N	PRESENT	0
772300	772299	20100N	PARTICIPANT	\N	PRESENT	0
772304	772302	20100N	PARTICIPANT	\N	PRESENT	0
776031	773787	14327T	PARTICIPANT	\N	PRESENT	0
776032	773787	20086J	PARTICIPANT	\N	PRESENT	0
776033	773787	14331P	PARTICIPANT	\N	PRESENT	0
776034	773787	11048N	PARTICIPANT	\N	PRESENT	0
776035	773787	19647E	PARTICIPANT	\N	PRESENT	0
776036	773787	20134Y	PARTICIPANT	\N	PRESENT	0
776037	773787	19711U	PARTICIPANT	\N	PRESENT	0
776038	773787	20050V	PARTICIPANT	\N	PRESENT	0
776039	773787	20094J	PARTICIPANT	\N	PRESENT	0
776040	773787	20044X	PARTICIPANT	\N	PRESENT	0
776041	773787	14225N	PRESIDENT	0	PRESENT	0
776042	773787	11110B	PARTICIPANT	\N	PRESENT	0
776043	773787	07029T	PARTICIPANT	\N	PRESENT	0
776044	773787	20062A	PARTICIPANT	\N	PRESENT	0
776045	773787	19573D	PARTICIPANT	\N	PRESENT	0
776046	773787	21069M	PARTICIPANT	\N	PRESENT	0
776047	773787	08010L	PARTICIPANT	\N	PRESENT	0
776048	773787	21090J	PARTICIPANT	\N	PRESENT	0
776049	773787	20116W	PARTICIPANT	\N	PRESENT	0
776050	773787	20126Y	PARTICIPANT	\N	PRESENT	0
776051	776015	21070E	PARTICIPANT	\N	PRESENT	0
776052	776015	20062A	PARTICIPANT	\N	PRESENT	0
776053	776015	19533U	PARTICIPANT	\N	PRESENT	0
776054	776015	20116W	PARTICIPANT	\N	PRESENT	0
776055	776015	21037D	PARTICIPANT	\N	PRESENT	0
776056	776015	21074J	PARTICIPANT	\N	PRESENT	0
776057	776015	21069M	PARTICIPANT	\N	PRESENT	0
776058	776015	19693L	PARTICIPANT	\N	PRESENT	0
776059	776015	20132W	PARTICIPANT	\N	PRESENT	0
776060	776015	20046A	PARTICIPANT	\N	PRESENT	0
776061	776015	14031R	PARTICIPANT	\N	PRESENT	0
776062	776015	21089R	PARTICIPANT	\N	PRESENT	0
776063	776015	19591F	PARTICIPANT	\N	PRESENT	0
776064	776015	20134Y	PARTICIPANT	\N	PRESENT	0
776065	776015	14109K	PARTICIPANT	\N	PRESENT	0
776066	776015	14030Q	PARTICIPANT	\N	PRESENT	0
776067	776015	19573D	PARTICIPANT	\N	PRESENT	0
776070	776015	14123H	PARTICIPANT	\N	PRESENT	0
776071	776015	11043H	PARTICIPANT	\N	PRESENT	0
776072	776015	14257W	PARTICIPANT	\N	PRESENT	0
776076	772605	11090Q	PARTICIPANT	\N	PRESENT	0
776112	772605	19611R	PARTICIPANT	\N	PRESENT	0
776078	772605	14026U	PARTICIPANT	\N	PRESENT	0
776107	772605	14030Q	PARTICIPANT	\N	PRESENT	0
776080	772605	20102Q	PARTICIPANT	\N	PRESENT	0
776118	772605	21091K	PARTICIPANT	\N	PRESENT	0
776082	772605	21054E	PARTICIPANT	\N	PRESENT	0
776119	772605	20026V	PARTICIPANT	\N	PRESENT	0
776084	772605	20124W	PARTICIPANT	\N	PRESENT	0
776085	772605	19553Y	PARTICIPANT	\N	PRESENT	0
776086	772605	21078N	PARTICIPANT	\N	PRESENT	0
776087	772605	20130U	PARTICIPANT	\N	PRESENT	0
776088	772605	21094N	PARTICIPANT	\N	PRESENT	0
776108	772605	20132W	PARTICIPANT	\N	PRESENT	0
776090	772605	20062A	PARTICIPANT	\N	PRESENT	0
776091	772605	19533U	PARTICIPANT	\N	PRESENT	0
776109	772605	21074J	PARTICIPANT	\N	PRESENT	0
776093	772605	21037D	PARTICIPANT	\N	PRESENT	0
776094	772605	19693L	PARTICIPANT	\N	PRESENT	0
776110	772605	19621T	PARTICIPANT	\N	PRESENT	0
776096	772605	20046A	PARTICIPANT	\N	PRESENT	0
776097	772605	14031R	PARTICIPANT	\N	PRESENT	0
776098	772605	21089R	PARTICIPANT	\N	PRESENT	0
776111	772605	14123H	PARTICIPANT	\N	PRESENT	0
776100	772605	20134Y	PARTICIPANT	\N	PRESENT	0
776101	772605	14109K	PARTICIPANT	\N	PRESENT	0
776113	772605	20044X	PARTICIPANT	\N	PRESENT	0
776103	772605	19573D	PARTICIPANT	\N	PRESENT	0
776114	772605	20180F	PARTICIPANT	\N	PRESENT	0
776105	772605	11043H	PARTICIPANT	\N	PRESENT	0
776106	772605	14257W	PARTICIPANT	\N	PRESENT	0
776116	772605	19697Q	PARTICIPANT	\N	PRESENT	0
776120	772605	20142Y	PARTICIPANT	\N	PRESENT	0
776121	772605	20048C	PARTICIPANT	\N	PRESENT	0
776122	772605	20264J	PARTICIPANT	\N	PRESENT	0
776123	772605	14331P	PARTICIPANT	\N	PRESENT	0
776124	772605	14229S	PARTICIPANT	\N	PRESENT	0
776129	772605	21062E	PARTICIPANT	\N	PRESENT	0
776131	772605	19647E	PARTICIPANT	\N	PRESENT	0
776133	772605	20086J	PARTICIPANT	\N	PRESENT	0
776146	772605	19563B	PARTICIPANT	\N	PRESENT	0
776147	772605	11048N	PARTICIPANT	\N	PRESENT	0
776148	772605	21069M	PARTICIPANT	\N	PRESENT	0
776149	772605	19593H	PARTICIPANT	\N	PRESENT	0
776150	772605	21077M	PARTICIPANT	\N	PRESENT	0
776151	772605	14225N	PARTICIPANT	\N	PRESENT	0
776152	772605	14042U	PARTICIPANT	\N	PRESENT	0
776153	772605	19711U	PARTICIPANT	\N	PRESENT	0
776158	772605	11085T	PARTICIPANT	\N	PRESENT	0
776161	772605	20116W	PARTICIPANT	\N	PRESENT	0
776162	772605	08034U	PARTICIPANT	\N	PRESENT	0
776163	772605	20094J	PARTICIPANT	\N	PRESENT	0
776164	772605	20092G	PARTICIPANT	\N	PRESENT	0
776165	772605	21034A	PARTICIPANT	\N	PRESENT	0
776166	772605	21073H	PARTICIPANT	\N	PRESENT	0
776167	772605	20286Q	PARTICIPANT	\N	PRESENT	0
776168	772605	17023S	PARTICIPANT	\N	PRESENT	0
776215	776211	19593H	PARTICIPANT	\N	PRESENT	0
776216	776211	14329V	PARTICIPANT	\N	PRESENT	0
776217	776211	19573D	PARTICIPANT	\N	PRESENT	0
776218	776211	19611R	PARTICIPANT	\N	PRESENT	0
776219	776211	14123H	PARTICIPANT	\N	PRESENT	0
776220	776211	14030Q	PARTICIPANT	\N	PRESENT	0
776221	776211	19533U	PARTICIPANT	\N	PRESENT	0
776222	776211	14331P	PARTICIPANT	\N	PRESENT	0
776223	776211	21095P	PARTICIPANT	\N	PRESENT	0
776224	776211	19621T	PARTICIPANT	\N	PRESENT	0
776225	776211	21089R	PARTICIPANT	\N	PRESENT	0
776226	776211	20132W	PARTICIPANT	\N	PRESENT	0
776227	776211	14109K	PARTICIPANT	\N	PRESENT	0
776234	776211	20142Y	PARTICIPANT	\N	PRESENT	0
776235	776211	21059K	PARTICIPANT	\N	PRESENT	0
776237	776211	20264J	PARTICIPANT	\N	PRESENT	0
776238	776211	21084L	PARTICIPANT	\N	PRESENT	0
776240	776211	21037D	PARTICIPANT	\N	PRESENT	0
776241	776211	20044X	PARTICIPANT	\N	PRESENT	0
776242	776211	21077M	PARTICIPANT	\N	PRESENT	0
786207	786206	20098N	PARTICIPANT	\N	PRESENT	0
786209	786208	20098N	PARTICIPANT	\N	PRESENT	0
786211	786210	20098N	PARTICIPANT	\N	PRESENT	0
786397	786396	04008A	PARTICIPANT	\N	PRESENT	0
786398	786396	18231D	PARTICIPANT	\N	PRESENT	0
786400	786399	04047H	PARTICIPANT	\N	PRESENT	0
786401	786399	19611R	PARTICIPANT	\N	PRESENT	0
791653	791612	20090E	PARTICIPANT	\N	EXCUSE	0
791655	791654	14151M	PARTICIPANT	\N	PRESENT	0
791656	791654	17367Q	PARTICIPANT	\N	PRESENT	0
791657	791654	21072G	PARTICIPANT	\N	PRESENT	0
791869	791617	19760E	PARTICIPANT	\N	PRESENT	0
791867	791617	11045K	PARTICIPANT	\N	PRESENT	0
791868	791617	08045X	PARTICIPANT	\N	PRESENT	0
791870	791617	19758L	PARTICIPANT	\N	PRESENT	0
791871	791617	14281W	PARTICIPANT	\N	PRESENT	0
791872	791617	18193Q	PARTICIPANT	\N	PRESENT	0
791873	791617	21045D	PARTICIPANT	\N	PRESENT	0
791874	791617	14071N	PRESIDENT	0	PRESENT	0
791875	791617	19703U	PARTICIPANT	\N	PRESENT	0
791876	791617	19691J	PARTICIPANT	\N	PRESENT	0
776213	776211	14229S	PARTICIPANT	\N	PRESENT	0
776214	776211	20102Q	PARTICIPANT	\N	PRESENT	0
791877	791617	20140W	PARTICIPANT	\N	PRESENT	0
791878	791617	14195A	PARTICIPANT	\N	PRESENT	0
791879	791617	17965H	PARTICIPANT	\N	PRESENT	0
791880	791617	21046E	PARTICIPANT	\N	PRESENT	0
791881	791617	21087P	PARTICIPANT	\N	PRESENT	0
791882	791617	19798U	PARTICIPANT	\N	PRESENT	0
791883	791617	21039F	PARTICIPANT	\N	PRESENT	0
791884	791617	20248J	PARTICIPANT	\N	PRESENT	0
791885	791617	19553Y	PARTICIPANT	\N	PRESENT	0
791886	791617	14213J	PARTICIPANT	\N	PRESENT	0
791887	791617	17779H	PARTICIPANT	\N	PRESENT	0
791888	791617	14217N	PARTICIPANT	\N	PRESENT	0
791889	791617	19723Y	PARTICIPANT	\N	PRESENT	0
791890	791617	20148F	PARTICIPANT	\N	PRESENT	0
791891	791617	14042U	PARTICIPANT	\N	PRESENT	0
791892	791617	21094N	PARTICIPANT	\N	PRESENT	0
795115	794896	19421M	PARTICIPANT	\N	PRESENT	0
784567	783384	20078J	PARTICIPANT	\N	PRESENT	0
784568	783384	20056C	PARTICIPANT	\N	PRESENT	0
784565	783384	14331P	PARTICIPANT	\N	PRESENT	0
784566	783384	20040T	PARTICIPANT	\N	PRESENT	0
784569	783384	19335Q	PARTICIPANT	\N	PRESENT	0
784570	783384	14105F	PARTICIPANT	\N	PRESENT	0
784571	783384	19954N	PARTICIPANT	\N	PRESENT	0
784572	783384	14329V	PARTICIPANT	\N	PRESENT	0
784573	783384	14357A	PARTICIPANT	\N	PRESENT	0
784574	783384	21039F	PARTICIPANT	\N	PRESENT	0
784575	783384	21075K	PARTICIPANT	\N	PRESENT	0
784576	783384	21069M	PARTICIPANT	\N	PRESENT	0
784577	783384	14217N	PARTICIPANT	\N	PRESENT	0
784578	783384	20088L	PARTICIPANT	\N	PRESENT	0
784579	783384	21078N	PARTICIPANT	\N	PRESENT	0
784580	783384	19111A	PARTICIPANT	\N	PRESENT	0
784581	783384	14030Q	PARTICIPANT	\N	PRESENT	0
784582	783384	14071N	PARTICIPANT	\N	PRESENT	0
784583	783384	20140W	PARTICIPANT	\N	PRESENT	0
784584	783384	21094N	PARTICIPANT	\N	PRESENT	0
784585	783384	08060W	PARTICIPANT	\N	PRESENT	0
784586	783384	20018V	PARTICIPANT	\N	PRESENT	0
784587	783384	11090Q	PARTICIPANT	\N	PRESENT	0
784588	783384	07033P	PARTICIPANT	\N	PRESENT	0
784589	783384	21076L	PARTICIPANT	\N	PRESENT	0
784590	783384	19685L	PARTICIPANT	\N	PRESENT	0
784591	783384	21061D	PARTICIPANT	\N	PRESENT	0
784592	783384	21063F	PARTICIPANT	\N	PRESENT	0
784593	783384	21059K	PARTICIPANT	\N	PRESENT	0
784594	783384	14281W	PARTICIPANT	\N	PRESENT	0
784595	783384	20084G	PARTICIPANT	\N	PRESENT	0
784596	783384	21029D	PARTICIPANT	\N	PRESENT	0
784597	783384	21037D	PARTICIPANT	\N	PRESENT	0
784598	783384	21079P	PARTICIPANT	\N	PRESENT	0
784599	783384	14059S	PARTICIPANT	\N	PRESENT	0
784600	783384	20058E	PARTICIPANT	\N	PRESENT	0
784601	783384	21068L	PARTICIPANT	\N	PRESENT	0
784602	783384	19447X	PARTICIPANT	\N	PRESENT	0
784603	783384	12028B	PARTICIPANT	\N	PRESENT	0
784604	783384	21077M	PARTICIPANT	\N	PRESENT	0
784605	783384	20080C	PARTICIPANT	\N	PRESENT	0
784606	783384	21093M	PARTICIPANT	\N	PRESENT	0
784607	783384	20130U	PARTICIPANT	\N	PRESENT	0
784608	783384	14219Q	PARTICIPANT	\N	PRESENT	0
784609	783384	08047A	PARTICIPANT	\N	PRESENT	0
784610	783384	19669L	PARTICIPANT	\N	PRESENT	0
784611	783384	14121F	PARTICIPANT	\N	PRESENT	0
784612	783384	21062E	PARTICIPANT	\N	PRESENT	0
784613	783384	14257W	PARTICIPANT	\N	PRESENT	0
784614	783384	21088Q	PARTICIPANT	\N	PRESENT	0
784615	783384	20264J	PARTICIPANT	\N	PRESENT	0
784616	783384	14107H	PARTICIPANT	\N	PRESENT	0
784617	783384	19507S	PARTICIPANT	\N	PRESENT	0
784618	783373	21044C	PARTICIPANT	\N	PRESENT	0
784619	783373	20086J	PARTICIPANT	\N	PRESENT	0
784620	783373	21048G	PARTICIPANT	\N	PRESENT	0
784621	783373	18207D	PARTICIPANT	\N	PRESENT	0
784622	783373	21057H	PARTICIPANT	\N	PRESENT	0
784623	783373	20082E	PARTICIPANT	\N	PRESENT	0
784624	783373	14053L	PARTICIPANT	\N	PRESENT	0
784625	783373	19565D	PARTICIPANT	\N	PRESENT	0
784626	783373	20102Q	PARTICIPANT	\N	PRESENT	0
784627	783373	20046A	PARTICIPANT	\N	PRESENT	0
784628	783373	19782L	PARTICIPANT	\N	PRESENT	0
784629	783373	21041Y	PARTICIPANT	\N	PRESENT	0
784630	783373	19553Y	PARTICIPANT	\N	PRESENT	0
784631	783373	19745F	PARTICIPANT	\N	PRESENT	0
784632	783373	21038E	PARTICIPANT	\N	PRESENT	0
784633	783373	19798U	PARTICIPANT	\N	PRESENT	0
784634	783373	08056B	PARTICIPANT	\N	PRESENT	0
784635	783373	19399H	PARTICIPANT	\N	PRESENT	0
784636	783373	19621T	PARTICIPANT	\N	PRESENT	0
784637	783373	20032T	PARTICIPANT	\N	PRESENT	0
784638	783373	14215L	PARTICIPANT	\N	PRESENT	0
784639	783373	21081H	PARTICIPANT	\N	PRESENT	0
784640	783373	08015R	PARTICIPANT	\N	PRESENT	0
784641	783373	20180F	PARTICIPANT	\N	PRESENT	0
784642	783373	19593H	PARTICIPANT	\N	PRESENT	0
784643	783373	14213J	PARTICIPANT	\N	PRESENT	0
784644	783373	14259Y	PARTICIPANT	\N	PRESENT	0
784645	783373	20090E	PARTICIPANT	\N	PRESENT	0
784646	783373	19749K	PARTICIPANT	\N	PRESENT	0
784647	783373	20028X	PARTICIPANT	\N	PRESENT	0
784648	783373	19679N	PARTICIPANT	\N	PRESENT	0
784649	783373	20116W	PARTICIPANT	\N	PRESENT	0
784650	783373	21053D	PARTICIPANT	\N	PRESENT	0
784651	783373	95041E	PARTICIPANT	\N	PRESENT	0
784652	783373	20036X	PARTICIPANT	\N	PRESENT	0
784653	783373	19699S	PARTICIPANT	\N	PRESENT	0
784654	783373	11043H	PARTICIPANT	\N	PRESENT	0
784655	783373	21042A	PARTICIPANT	\N	PRESENT	0
784656	783373	07004J	PARTICIPANT	\N	PRESENT	0
784657	783373	21054E	PARTICIPANT	\N	PRESENT	0
784658	783373	14073Q	PARTICIPANT	\N	PRESENT	0
784659	783373	21040X	PARTICIPANT	\N	PRESENT	0
784660	783373	20110Q	PARTICIPANT	\N	PRESENT	0
784661	783373	08028W	PARTICIPANT	\N	PRESENT	0
784662	783373	04047H	PARTICIPANT	\N	PRESENT	0
784663	783373	21052C	PARTICIPANT	\N	PRESENT	0
784664	783373	20052X	PARTICIPANT	\N	PRESENT	0
784665	783373	21056G	PARTICIPANT	\N	PRESENT	0
784666	783373	20252E	PARTICIPANT	\N	PRESENT	0
784667	783373	08034U	PARTICIPANT	\N	PRESENT	0
784668	783373	20062A	PARTICIPANT	\N	PRESENT	0
784669	783373	08069G	PARTICIPANT	\N	PRESENT	0
784670	783373	19719D	PARTICIPANT	\N	PRESENT	0
784671	783373	20096L	PARTICIPANT	\N	PRESENT	0
784672	783373	14147R	PARTICIPANT	\N	PRESENT	0
784673	783373	14231L	PARTICIPANT	\N	PRESENT	0
784674	783373	19768N	PARTICIPANT	\N	PRESENT	0
784675	783373	21073H	PARTICIPANT	\N	PRESENT	0
784676	783373	21043B	PARTICIPANT	\N	PRESENT	0
784677	783373	20026V	PARTICIPANT	\N	PRESENT	0
784678	783373	21083K	PARTICIPANT	\N	PRESENT	0
784679	783373	21095P	PARTICIPANT	\N	PRESENT	0
784680	783373	14255U	PARTICIPANT	\N	PRESENT	0
784681	783373	21046E	PARTICIPANT	\N	PRESENT	0
784682	783373	19649G	PARTICIPANT	\N	PRESENT	0
784683	783373	21055F	PARTICIPANT	\N	PRESENT	0
784684	783373	20100N	PARTICIPANT	\N	PRESENT	0
784685	783373	11056N	PARTICIPANT	\N	PRESENT	0
784686	783373	20068G	PARTICIPANT	\N	PRESENT	0
784687	783373	21064G	PARTICIPANT	\N	PRESENT	0
784688	783373	19631V	PARTICIPANT	\N	PRESENT	0
784689	783373	14069U	PARTICIPANT	\N	PRESENT	0
784690	783373	21050A	PARTICIPANT	\N	PRESENT	0
784691	783373	14331P	PARTICIPANT	\N	PRESENT	0
784692	783373	20040T	PARTICIPANT	\N	PRESENT	0
784693	783373	20078J	PARTICIPANT	\N	PRESENT	0
784694	783373	20056C	PARTICIPANT	\N	PRESENT	0
784695	783373	14105F	PARTICIPANT	\N	PRESENT	0
784696	783373	19954N	PARTICIPANT	\N	PRESENT	0
784697	783373	14329V	PARTICIPANT	\N	PRESENT	0
784698	783373	14357A	PARTICIPANT	\N	PRESENT	0
784699	783373	21039F	PARTICIPANT	\N	PRESENT	0
784700	783373	21075K	PARTICIPANT	\N	PRESENT	0
784701	783373	21069M	PARTICIPANT	\N	PRESENT	0
784702	783373	14217N	PARTICIPANT	\N	PRESENT	0
784703	783373	20088L	PARTICIPANT	\N	PRESENT	0
784704	783373	21078N	PARTICIPANT	\N	PRESENT	0
784705	783373	19111A	PARTICIPANT	\N	PRESENT	0
784706	783373	14030Q	PARTICIPANT	\N	PRESENT	0
784707	783373	14071N	PARTICIPANT	\N	PRESENT	0
784708	783373	20140W	PARTICIPANT	\N	PRESENT	0
784709	783373	21094N	PARTICIPANT	\N	PRESENT	0
784710	783373	08060W	PARTICIPANT	\N	PRESENT	0
784711	783373	20018V	PARTICIPANT	\N	PRESENT	0
784712	783373	11090Q	PARTICIPANT	\N	PRESENT	0
784713	783373	07033P	PARTICIPANT	\N	PRESENT	0
784714	783373	21076L	PARTICIPANT	\N	PRESENT	0
784715	783373	19685L	PARTICIPANT	\N	PRESENT	0
784716	783373	21061D	PARTICIPANT	\N	PRESENT	0
784717	783373	21063F	PARTICIPANT	\N	PRESENT	0
784718	783373	21059K	PARTICIPANT	\N	PRESENT	0
784719	783373	14281W	PARTICIPANT	\N	PRESENT	0
784720	783373	20084G	PARTICIPANT	\N	PRESENT	0
784721	783373	21029D	PARTICIPANT	\N	PRESENT	0
784722	783373	21037D	PARTICIPANT	\N	PRESENT	0
784723	783373	21079P	PARTICIPANT	\N	PRESENT	0
784724	783373	14059S	PARTICIPANT	\N	PRESENT	0
784725	783373	20058E	PARTICIPANT	\N	PRESENT	0
768421	765848	20046A	PARTICIPANT	\N	PRESENT	0
768422	765848	14169X	PARTICIPANT	\N	PRESENT	0
768423	765848	20068G	PARTICIPANT	\N	PRESENT	0
768424	765848	21070E	PARTICIPANT	\N	PRESENT	0
768425	765848	19619A	PARTICIPANT	\N	PRESENT	0
768426	765848	19681G	PARTICIPANT	\N	EXCUSE	0
768427	765404	20134Y	PARTICIPANT	\N	PRESENT	0
768428	765404	20100N	PARTICIPANT	\N	PRESENT	0
768429	765404	21097R	PARTICIPANT	\N	PRESENT	0
768430	765404	20042V	PARTICIPANT	\N	PRESENT	0
768432	765404	21085M	PARTICIPANT	\N	PRESENT	0
768466	765404	21035B	PARTICIPANT	\N	PRESENT	0
768436	765404	21070E	PARTICIPANT	\N	PRESENT	0
768437	765404	21052C	PARTICIPANT	\N	PRESENT	0
768438	765404	21066J	PARTICIPANT	\N	PRESENT	0
768439	765404	20046A	PARTICIPANT	\N	PRESENT	0
768440	765404	14069U	PARTICIPANT	\N	PRESENT	0
768442	765404	18231D	PARTICIPANT	\N	PRESENT	0
768444	765404	20248J	PARTICIPANT	\N	PRESENT	0
768445	765404	18193Q	PARTICIPANT	\N	PRESENT	0
768446	765404	19782L	PARTICIPANT	\N	PRESENT	0
768447	765404	18083K	PARTICIPANT	\N	PRESENT	0
768448	765404	20054A	PARTICIPANT	\N	PRESENT	0
768449	765404	21051B	PARTICIPANT	\N	PRESENT	0
768450	765404	14179A	PARTICIPANT	\N	PRESENT	0
768451	765404	11048N	PARTICIPANT	\N	PRESENT	0
768452	765404	14033T	PARTICIPANT	\N	PRESENT	0
768453	765404	19479G	PARTICIPANT	\N	PRESENT	0
768461	765404	11045K	PARTICIPANT	\N	PRESENT	0
768462	765404	14331P	PARTICIPANT	\N	PRESENT	0
768463	765404	14187A	PARTICIPANT	\N	PRESENT	0
768464	765404	21062E	PARTICIPANT	\N	PRESENT	0
768465	765404	20104S	PARTICIPANT	\N	PRESENT	0
768467	765404	20092G	PARTICIPANT	\N	PRESENT	0
768468	765404	20138D	PARTICIPANT	\N	PRESENT	0
768469	765404	19687N	PARTICIPANT	\N	PRESENT	0
768472	765404	14219Q	PARTICIPANT	\N	PRESENT	0
768562	765405	14071N	PARTICIPANT	\N	PRESENT	0
768563	765405	19683J	PARTICIPANT	\N	PRESENT	0
768564	765405	21035B	PARTICIPANT	\N	PRESENT	0
768565	765405	17965H	PARTICIPANT	\N	PRESENT	0
768566	765405	18193Q	PARTICIPANT	\N	PRESENT	0
768567	765405	19691J	PARTICIPANT	\N	PRESENT	0
768568	765405	19553Y	PARTICIPANT	\N	PRESENT	0
768569	765405	20064C	PARTICIPANT	\N	PRESENT	0
768570	765405	20060X	PARTICIPANT	\N	PRESENT	0
768571	765405	19866P	PARTICIPANT	\N	PRESENT	0
768572	765405	14107H	PARTICIPANT	\N	PRESENT	0
768573	765405	21040X	PARTICIPANT	\N	PRESENT	0
768574	765405	14069U	PARTICIPANT	\N	PRESENT	0
768575	765405	19367Y	PARTICIPANT	\N	PRESENT	0
768576	765405	21046E	PARTICIPANT	\N	PRESENT	0
768577	765405	21058J	PARTICIPANT	\N	PRESENT	0
768578	765405	20180F	PARTICIPANT	\N	PRESENT	0
768579	765405	08015R	PARTICIPANT	\N	PRESENT	0
768580	765405	20104S	PARTICIPANT	\N	PRESENT	0
768581	765405	19679N	PARTICIPANT	\N	PRESENT	0
768582	765405	21097R	PARTICIPANT	\N	PRESENT	0
768583	765405	18083K	PARTICIPANT	\N	PRESENT	0
768584	765405	21063F	PARTICIPANT	\N	PRESENT	0
768585	765405	20076G	PARTICIPANT	\N	PRESENT	0
768586	765405	19723Y	PARTICIPANT	\N	PRESENT	0
768587	765405	19798U	PARTICIPANT	\N	PRESENT	0
768588	765405	21066J	PARTICIPANT	\N	PRESENT	0
768589	765405	14223L	PARTICIPANT	\N	PRESENT	0
768590	765405	19629C	PARTICIPANT	\N	PRESENT	0
768591	765405	20248J	PARTICIPANT	\N	PRESENT	0
768592	765405	19713W	PARTICIPANT	\N	PRESENT	0
768593	765405	20054A	PARTICIPANT	\N	PRESENT	0
768594	765405	20090E	PARTICIPANT	\N	PRESENT	0
768595	765405	11090Q	PARTICIPANT	\N	PRESENT	0
768596	765405	20148F	PARTICIPANT	\N	PRESENT	0
768597	765405	21081H	PARTICIPANT	\N	PRESENT	0
768598	765405	20046A	PARTICIPANT	\N	PRESENT	0
768599	765405	14195A	PARTICIPANT	\N	PRESENT	0
768600	765405	20130U	PARTICIPANT	\N	PRESENT	0
768601	765405	08069G	PARTICIPANT	\N	PRESENT	0
768602	765405	14281W	PARTICIPANT	\N	PRESENT	0
768603	765405	21071F	PARTICIPANT	\N	PRESENT	0
768604	765405	20096L	PARTICIPANT	\N	PRESENT	0
768605	765405	21064G	PARTICIPANT	\N	PRESENT	0
768606	765405	21045D	PARTICIPANT	\N	PRESENT	0
768607	765405	19591F	PARTICIPANT	\N	PRESENT	0
768608	765405	19782L	PARTICIPANT	\N	PRESENT	0
768609	765405	04033B	PARTICIPANT	\N	PRESENT	0
768610	765405	20092G	PARTICIPANT	\N	PRESENT	0
768611	765405	20026V	PARTICIPANT	\N	PRESENT	0
768612	765405	20030R	PARTICIPANT	\N	PRESENT	0
768613	765405	19758L	PARTICIPANT	\N	PRESENT	0
768614	765405	17779H	PARTICIPANT	\N	PRESENT	0
768615	765405	19657G	PARTICIPANT	\N	PRESENT	0
768616	765405	21049H	PARTICIPANT	\N	PRESENT	0
768617	765405	19760E	PARTICIPANT	\N	PRESENT	0
768618	765405	20062A	PARTICIPANT	\N	PRESENT	0
768619	765405	14033T	PARTICIPANT	\N	PRESENT	0
768620	765405	14217N	PARTICIPANT	\N	PRESENT	0
768621	765405	21069M	PARTICIPANT	\N	PRESENT	0
768622	765405	19531S	PARTICIPANT	\N	PRESENT	0
768623	765405	21094N	PARTICIPANT	\N	PRESENT	0
768624	765405	14026U	PARTICIPANT	\N	PRESENT	0
768625	765405	14231L	PARTICIPANT	\N	PRESENT	0
768626	765405	19703U	PARTICIPANT	\N	PRESENT	0
768627	765405	21051B	PARTICIPANT	\N	PRESENT	0
768628	765405	20172F	PARTICIPANT	\N	PRESENT	0
768629	765405	14215L	PARTICIPANT	\N	PRESENT	0
768630	765405	14083S	PARTICIPANT	\N	PRESENT	0
768631	765405	04092N	PARTICIPANT	\N	PRESENT	0
773255	773249	14237S	PARTICIPANT	\N	PRESENT	0
773256	773249	18207D	PARTICIPANT	\N	PRESENT	0
773259	773257	21094N	PARTICIPANT	\N	PRESENT	0
773262	773258	21094N	PARTICIPANT	\N	PRESENT	0
774251	772429	14147R	PARTICIPANT	\N	PRESENT	0
774614	772428	19729F	PARTICIPANT	\N	EXCUSE	0
774615	772428	04008A	PARTICIPANT	\N	EXCUSE	0
775952	775950	21044C	PARTICIPANT	\N	PRESENT	0
775962	775198	19719D	PARTICIPANT	\N	EXCUSE	0
775963	775198	04008A	PARTICIPANT	\N	EXCUSE	0
775964	775198	19729F	PARTICIPANT	\N	EXCUSE	0
775966	775198	18207D	PARTICIPANT	\N	EXCUSE	0
775968	775198	04047H	PARTICIPANT	\N	EXCUSE	0
778279	776551	05008E	PARTICIPANT	\N	PRESENT	0
778280	776551	98022P	PARTICIPANT	\N	PRESENT	0
778277	776551	20054A	PARTICIPANT	\N	PRESENT	0
768560	765405	19593H	PARTICIPANT	\N	PRESENT	0
768561	765405	14042U	PARTICIPANT	\N	PRESENT	0
778278	776551	19735D	PARTICIPANT	\N	PRESENT	0
778281	776551	21031W	PARTICIPANT	\N	PRESENT	0
778282	776551	19531S	PARTICIPANT	\N	PRESENT	0
778283	776551	21055F	PARTICIPANT	\N	PRESENT	0
778284	776551	14033T	PARTICIPANT	\N	PRESENT	0
778285	776551	19533U	PARTICIPANT	\N	PRESENT	0
778286	776551	12016W	PARTICIPANT	\N	PRESENT	0
778296	776551	19768N	PARTICIPANT	\N	PRESENT	0
778288	776551	19335Q	PARTICIPANT	\N	PRESENT	0
778289	776551	14215L	PARTICIPANT	\N	PRESENT	0
778290	776551	14133K	PARTICIPANT	\N	PRESENT	0
778291	776551	19399H	PARTICIPANT	\N	PRESENT	0
778292	776551	11053K	PARTICIPANT	\N	PRESENT	0
778293	776551	19551W	PARTICIPANT	\N	PRESENT	0
778294	776551	20036X	PARTICIPANT	\N	PRESENT	0
778295	776551	14053L	PARTICIPANT	\N	PRESENT	0
778297	776551	19347U	PARTICIPANT	\N	PRESENT	0
778298	776551	20040T	PARTICIPANT	\N	PRESENT	0
778299	776551	19565D	PARTICIPANT	\N	PRESENT	0
778300	776551	04070G	PARTICIPANT	\N	PRESENT	0
778301	776551	20028X	PARTICIPANT	\N	PRESENT	0
778302	776551	20136B	PARTICIPANT	\N	PRESENT	0
778303	776551	20134Y	PARTICIPANT	\N	PRESENT	0
778304	776551	20022R	PARTICIPANT	\N	PRESENT	0
778305	776551	14031R	PARTICIPANT	\N	PRESENT	0
778306	776551	21080G	PARTICIPANT	\N	PRESENT	0
778307	776551	08034U	PARTICIPANT	\N	PRESENT	0
778308	776551	20066E	PARTICIPANT	\N	PRESENT	0
778309	776551	20056C	PARTICIPANT	\N	PRESENT	0
778310	776551	19782L	PARTICIPANT	\N	PRESENT	0
778311	776551	20266L	PARTICIPANT	\N	PRESENT	0
778312	776551	19447X	PARTICIPANT	\N	PRESENT	0
778313	776551	14038Y	PARTICIPANT	\N	PRESENT	0
768419	765848	20136B	PARTICIPANT	\N	PRESENT	0
768420	765848	14031R	PARTICIPANT	\N	PRESENT	0
778147	776551	11048N	PARTICIPANT	\N	PRESENT	0
778148	776551	20032T	PARTICIPANT	\N	PRESENT	0
778149	776551	20070A	PARTICIPANT	\N	PRESENT	0
778150	776551	18083K	PARTICIPANT	\N	PRESENT	0
778151	776551	19711U	PARTICIPANT	\N	PRESENT	0
778152	776551	14073Q	PARTICIPANT	\N	PRESENT	0
778153	776551	14001X	PARTICIPANT	\N	PRESENT	0
778154	776551	14111D	PARTICIPANT	\N	PRESENT	0
778155	776140	04070G	PARTICIPANT	\N	PRESENT	0
778157	776140	14109K	PARTICIPANT	\N	PRESENT	0
778158	776551	14179A	PARTICIPANT	\N	PRESENT	0
778159	776551	19629C	PARTICIPANT	\N	PRESENT	0
778160	775973	14042U	PARTICIPANT	\N	PRESENT	0
778161	776551	21072G	PARTICIPANT	\N	PRESENT	0
778162	776551	21053D	PARTICIPANT	\N	PRESENT	0
778163	776551	08012N	PARTICIPANT	\N	PRESENT	0
778164	776551	20094J	PARTICIPANT	\N	PRESENT	0
778166	778165	20094J	PARTICIPANT	\N	PRESENT	0
778167	778165	19711U	PARTICIPANT	\N	PRESENT	0
778168	776551	20058E	PARTICIPANT	\N	PRESENT	0
778169	776551	21068L	PARTICIPANT	\N	PRESENT	0
778170	776551	19563B	PARTICIPANT	\N	PRESENT	0
778171	776551	21054E	PARTICIPANT	\N	PRESENT	0
778172	776551	14331P	PARTICIPANT	\N	PRESENT	0
778173	776551	19681G	PARTICIPANT	\N	PRESENT	0
778174	776551	19383Y	PARTICIPANT	\N	PRESENT	0
778175	776551	20026V	PARTICIPANT	\N	PRESENT	0
778176	776551	19387D	PARTICIPANT	\N	PRESENT	0
778177	777689	19383Y	PARTICIPANT	\N	PRESENT	0
778178	777689	20088L	PARTICIPANT	\N	PRESENT	0
778179	777689	19768N	PARTICIPANT	\N	PRESENT	0
778180	777689	20092G	PARTICIPANT	\N	PRESENT	0
778181	777689	19782L	PARTICIPANT	\N	PRESENT	0
778182	777689	19631V	PARTICIPANT	\N	PRESENT	0
778183	777689	20104S	PARTICIPANT	\N	PRESENT	0
778184	777689	08015R	PARTICIPANT	\N	PRESENT	0
778185	777689	19575F	PARTICIPANT	\N	PRESENT	0
778186	777689	20018V	PARTICIPANT	\N	PRESENT	0
778187	777689	19563B	PARTICIPANT	\N	PRESENT	0
778188	777689	08028W	PARTICIPANT	\N	PRESENT	0
778189	777689	21050A	PARTICIPANT	\N	PRESENT	0
778190	777689	21096Q	PARTICIPANT	\N	PRESENT	0
778191	777689	14329V	PARTICIPANT	\N	PRESENT	0
778192	777689	20028X	PARTICIPANT	\N	PRESENT	0
778193	777689	14038Y	PARTICIPANT	\N	PRESENT	0
778194	777689	21054E	PARTICIPANT	\N	PRESENT	0
778195	777689	20034V	PARTICIPANT	\N	PRESENT	0
778196	777689	14187A	PRESIDENT	0	PRESENT	0
778197	777689	20038A	PARTICIPANT	\N	PRESENT	0
778198	777689	21075K	PARTICIPANT	\N	PRESENT	0
778199	777689	21083K	PARTICIPANT	\N	PRESENT	0
778200	777689	21086N	PARTICIPANT	\N	PRESENT	0
778201	777689	21092L	PARTICIPANT	\N	PRESENT	0
778202	777689	14033T	PARTICIPANT	\N	PRESENT	0
778203	777689	21093M	PARTICIPANT	\N	PRESENT	0
778204	777689	11090Q	PARTICIPANT	\N	PRESENT	0
778205	777689	20054A	PARTICIPANT	\N	PRESENT	0
778206	777689	21033Y	PARTICIPANT	\N	PRESENT	0
778207	777689	21034A	PARTICIPANT	\N	PRESENT	0
778208	777689	14205J	PARTICIPANT	\N	PRESENT	0
778209	777689	20060X	PARTICIPANT	\N	PRESENT	0
778210	777689	20066E	PARTICIPANT	\N	PRESENT	0
778211	777689	19507S	PARTICIPANT	\N	PRESENT	0
778212	777689	21066J	PARTICIPANT	\N	PRESENT	0
778213	777689	20286Q	PARTICIPANT	\N	PRESENT	0
778214	777689	14207L	PARTICIPANT	\N	PRESENT	0
778215	777689	20084G	PARTICIPANT	\N	PRESENT	0
778216	777689	14257W	PARTICIPANT	\N	PRESENT	0
778217	777689	21052C	PARTICIPANT	\N	EXCUSE	0
778218	777689	20078J	PARTICIPANT	\N	EXCUSE	0
778219	777689	19413M	PARTICIPANT	\N	EXCUSE	0
778227	777919	20090E	PARTICIPANT	\N	PRESENT	0
778228	777919	14355X	PARTICIPANT	\N	PRESENT	0
778229	777919	19569H	PARTICIPANT	\N	PRESENT	0
778230	777919	19798U	PARTICIPANT	\N	PRESENT	0
778231	777919	21045D	PARTICIPANT	\N	PRESENT	0
778232	777919	18193Q	PARTICIPANT	\N	PRESENT	0
778233	777919	14026U	PARTICIPANT	\N	PRESENT	0
778234	777919	21064G	PARTICIPANT	\N	PRESENT	0
778235	777919	19703U	PARTICIPANT	\N	PRESENT	0
778236	777919	14281W	PARTICIPANT	\N	PRESENT	0
778237	777919	19679N	PARTICIPANT	\N	PRESENT	0
778238	777919	14042U	PARTICIPANT	\N	PRESENT	0
778239	777919	19367Y	PARTICIPANT	\N	PRESENT	0
778240	777919	14217N	PARTICIPANT	\N	PRESENT	0
778241	777919	19683J	PARTICIPANT	\N	PRESENT	0
778242	777919	21097R	PARTICIPANT	\N	PRESENT	0
778243	777919	20130U	PARTICIPANT	\N	PRESENT	0
778244	777919	19713W	PARTICIPANT	\N	PRESENT	0
778245	777919	11045K	PARTICIPANT	\N	PRESENT	0
778246	777919	08045X	PARTICIPANT	\N	PRESENT	0
778247	777919	20140W	PARTICIPANT	\N	PRESENT	0
778248	777919	17965H	PARTICIPANT	\N	PRESENT	0
778249	777919	19691J	PARTICIPANT	\N	PRESENT	0
778250	777919	21094N	PARTICIPANT	\N	PRESENT	0
778251	777919	19295A	PARTICIPANT	\N	PRESENT	0
778252	777919	19723Y	PARTICIPANT	\N	PRESENT	0
778253	777919	21046E	PARTICIPANT	\N	PRESENT	0
778254	777919	21071F	PARTICIPANT	\N	PRESENT	0
778255	777919	19657G	PARTICIPANT	\N	PRESENT	0
778256	777919	14071N	PRESIDENT	0	PRESENT	0
778257	777919	21081H	PARTICIPANT	\N	PRESENT	0
778258	777919	19591F	PARTICIPANT	\N	PRESENT	0
778259	777919	21039F	PARTICIPANT	\N	PRESENT	0
778260	776551	19507S	PARTICIPANT	\N	PRESENT	0
778261	776551	19719D	PARTICIPANT	\N	PRESENT	0
778262	777919	20096L	PARTICIPANT	\N	PRESENT	0
778263	776551	19479G	PARTICIPANT	\N	PRESENT	0
778264	777919	08061X	PARTICIPANT	\N	PRESENT	0
778315	776551	20100N	PARTICIPANT	\N	PRESENT	0
778316	776551	21059K	PARTICIPANT	\N	PRESENT	0
778317	775805	21030V	PARTICIPANT	\N	PRESENT	0
778318	775805	21031W	PARTICIPANT	\N	PRESENT	0
778319	775805	19565D	PARTICIPANT	\N	PRESENT	0
778320	775805	20072C	PARTICIPANT	\N	PRESENT	0
778321	775805	01058X	PARTICIPANT	\N	PRESENT	0
778322	775805	14001X	PARTICIPANT	\N	PRESENT	0
778323	775805	08056B	PARTICIPANT	\N	PRESENT	0
778324	775805	12028B	PARTICIPANT	\N	PRESENT	0
778325	775805	17737W	PARTICIPANT	\N	PRESENT	0
778326	775805	21067K	PARTICIPANT	\N	PRESENT	0
778327	775805	19347U	PARTICIPANT	\N	PRESENT	0
778328	775805	08047A	PARTICIPANT	\N	PRESENT	0
778329	775805	14097Y	PARTICIPANT	\N	PRESENT	0
778330	775805	14059S	PARTICIPANT	\N	PRESENT	0
778331	775805	21073H	PARTICIPANT	\N	PRESENT	0
778332	775805	19531S	PARTICIPANT	\N	PRESENT	0
778333	775805	08069G	PARTICIPANT	\N	PRESENT	0
778334	775805	20042V	PARTICIPANT	\N	PRESENT	0
778335	775805	20064C	PARTICIPANT	\N	PRESENT	0
778336	775805	20252E	PARTICIPANT	\N	PRESENT	0
778337	775805	14251Q	PARTICIPANT	\N	PRESENT	0
778338	775805	98022P	PARTICIPANT	\N	PRESENT	0
778339	775805	14267Y	PARTICIPANT	\N	PRESENT	0
778340	775805	99004R	PARTICIPANT	\N	PRESENT	0
778341	775805	14255U	PARTICIPANT	\N	PRESENT	0
778342	775805	11115U	PARTICIPANT	\N	EXCUSE	0
778343	775805	14193X	PARTICIPANT	\N	EXCUSE	0
778344	775805	19745F	PARTICIPANT	\N	EXCUSE	0
773260	773248	21071F	PARTICIPANT	\N	PRESENT	0
773261	773248	20130U	PARTICIPANT	\N	PRESENT	0
775582	775198	14089Y	PARTICIPANT	\N	EXCUSE	0
775976	772604	20024T	PARTICIPANT	\N	PRESENT	0
775977	772604	14173T	PARTICIPANT	\N	PRESENT	0
775978	772604	08047A	PARTICIPANT	\N	PRESENT	0
775979	772604	21067K	PARTICIPANT	\N	PRESENT	0
776005	772604	20092G	PARTICIPANT	\N	PRESENT	0
775981	772604	20074E	PARTICIPANT	\N	PRESENT	0
775982	772604	21076L	PARTICIPANT	\N	PRESENT	0
775983	772604	19749K	PARTICIPANT	\N	PRESENT	0
775984	772604	20266L	PARTICIPANT	\N	PRESENT	0
775985	772604	21088Q	PARTICIPANT	\N	PRESENT	0
775986	772604	21040X	PARTICIPANT	\N	PRESENT	0
775987	772604	21043B	PARTICIPANT	\N	PRESENT	0
775988	772604	14151M	PARTICIPANT	\N	PRESENT	0
775989	772604	10015M	PARTICIPANT	\N	PRESENT	0
775990	772604	07004J	PARTICIPANT	\N	PRESENT	0
775991	772604	21075K	PARTICIPANT	\N	PRESENT	0
775992	772604	20086J	PARTICIPANT	\N	PRESENT	0
775993	772604	19399H	PARTICIPANT	\N	PRESENT	0
775994	772604	20044X	PARTICIPANT	\N	PRESENT	0
775995	772604	20124W	PARTICIPANT	\N	PRESENT	0
775996	772604	21054E	PARTICIPANT	\N	PRESENT	0
776000	772604	19713W	PARTICIPANT	\N	PRESENT	0
775998	772604	19573D	PARTICIPANT	\N	PRESENT	0
775999	772604	17023S	PARTICIPANT	\N	PRESENT	0
776001	772604	21034A	PARTICIPANT	\N	PRESENT	0
776002	772604	14026U	PARTICIPANT	\N	PRESENT	0
776003	772604	21037D	PARTICIPANT	\N	PRESENT	0
776004	772604	20100N	PARTICIPANT	\N	PRESENT	0
776006	772604	20062A	PARTICIPANT	\N	PRESENT	0
776007	772604	20252E	PARTICIPANT	\N	PRESENT	0
776008	772604	14037X	PARTICIPANT	\N	PRESENT	0
776009	772604	19647E	PARTICIPANT	\N	PRESENT	0
776010	772604	14123H	PARTICIPANT	\N	PRESENT	0
776011	772604	21090J	PARTICIPANT	\N	PRESENT	0
776012	772604	14225N	PARTICIPANT	\N	PRESENT	0
776013	772604	20172F	PARTICIPANT	\N	PRESENT	0
776014	772604	08010L	PARTICIPANT	\N	PRESENT	0
778557	776115	08010L	PARTICIPANT	\N	PRESENT	0
778560	776115	05008E	PARTICIPANT	\N	EXCUSE	0
778562	776115	14121F	PARTICIPANT	\N	EXCUSE	0
778563	776115	20122U	PARTICIPANT	\N	EXCUSE	0
778564	776115	19673G	PARTICIPANT	\N	EXCUSE	0
778565	776115	19669L	PARTICIPANT	\N	EXCUSE	0
778566	776115	19691J	PARTICIPANT	\N	EXCUSE	0
780112	779643	14111D	PARTICIPANT	\N	PRESENT	0
780120	779643	08010L	PARTICIPANT	\N	PRESENT	0
780121	779643	21076L	PARTICIPANT	\N	PRESENT	0
780122	779643	19749K	PARTICIPANT	\N	PRESENT	0
780123	779643	19725B	PARTICIPANT	\N	PRESENT	0
780137	779643	21095P	PARTICIPANT	\N	PRESENT	0
780125	779643	19649G	PARTICIPANT	\N	PRESENT	0
780126	779643	14069U	PARTICIPANT	\N	PRESENT	0
780127	779643	21085M	PARTICIPANT	\N	PRESENT	0
780128	779643	20266L	PARTICIPANT	\N	PRESENT	0
775832	772603	14179A	PARTICIPANT	\N	PRESENT	0
775833	772604	14179A	PARTICIPANT	\N	PRESENT	0
780129	779643	21088Q	PARTICIPANT	\N	PRESENT	0
780130	779643	21040X	PARTICIPANT	\N	PRESENT	0
780131	779643	07004J	PARTICIPANT	\N	PRESENT	0
780133	779643	14211G	PARTICIPANT	\N	PRESENT	0
780135	779643	19349W	PARTICIPANT	\N	PRESENT	0
780150	779643	21090J	PARTICIPANT	\N	PRESENT	0
780138	779643	14133K	PARTICIPANT	\N	PRESENT	0
780139	779643	07029T	PARTICIPANT	\N	PRESENT	0
780140	779643	20080C	PARTICIPANT	\N	PRESENT	0
780141	779643	19331L	PARTICIPANT	\N	PRESENT	0
780143	779643	14059S	PARTICIPANT	\N	PRESENT	0
780144	779643	19533U	PARTICIPANT	\N	PRESENT	0
780145	779643	20062A	PARTICIPANT	\N	PRESENT	0
780146	779643	21041Y	PARTICIPANT	\N	PRESENT	0
780148	779643	20072C	PARTICIPANT	\N	PRESENT	0
780149	779643	08034U	PARTICIPANT	\N	PRESENT	0
780151	779643	14267Y	PARTICIPANT	\N	PRESENT	0
780152	779643	19563B	PARTICIPANT	\N	PRESENT	0
780154	779643	20044X	PARTICIPANT	\N	PRESENT	0
780155	779643	95041E	PARTICIPANT	\N	PRESENT	0
780156	779643	19687N	PARTICIPANT	\N	PRESENT	0
780157	779643	10015M	PARTICIPANT	\N	PRESENT	0
780158	779643	14191V	PARTICIPANT	\N	PRESENT	0
780159	779643	19565D	PARTICIPANT	\N	PRESENT	0
780160	779643	21035B	PARTICIPANT	\N	PRESENT	0
780161	779643	19711U	PARTICIPANT	\N	PRESENT	0
780162	779643	20026V	PARTICIPANT	\N	PRESENT	0
780163	779643	21073H	PARTICIPANT	\N	PRESENT	0
780164	779643	21084L	PARTICIPANT	\N	PRESENT	0
780165	779643	20036X	PARTICIPANT	\N	PRESENT	0
780166	779643	14215L	PARTICIPANT	\N	PRESENT	0
780167	779643	14121F	PARTICIPANT	\N	PRESENT	0
780168	779643	19585H	PARTICIPANT	\N	PRESENT	0
780169	779643	99004R	PARTICIPANT	\N	PRESENT	0
780170	779643	20180F	PARTICIPANT	\N	PRESENT	0
780171	779643	08061X	PARTICIPANT	\N	PRESENT	0
780172	779643	20124W	PARTICIPANT	\N	PRESENT	0
780173	779643	19657G	PARTICIPANT	\N	PRESENT	0
780174	779643	19573D	PARTICIPANT	\N	PRESENT	0
780175	779643	20150Y	PARTICIPANT	\N	PRESENT	0
780176	779643	21058J	PARTICIPANT	\N	PRESENT	0
780177	779643	07033P	PARTICIPANT	\N	PRESENT	0
780178	779643	01058X	PARTICIPANT	\N	PRESENT	0
780179	779643	19545Y	PARTICIPANT	\N	PRESENT	0
780180	779643	21043B	PARTICIPANT	\N	PRESENT	0
780181	779643	12028B	PARTICIPANT	\N	PRESENT	0
780182	779643	19669L	PARTICIPANT	\N	PRESENT	0
780183	779643	14249W	PARTICIPANT	\N	PRESENT	0
780184	779643	14073Q	PARTICIPANT	\N	PRESENT	0
780185	779643	20252E	PARTICIPANT	\N	PRESENT	0
780186	779645	14111D	PARTICIPANT	\N	PRESENT	0
780196	779645	14211G	PARTICIPANT	\N	PRESENT	0
780197	779645	21095P	PARTICIPANT	\N	PRESENT	0
780198	779645	14133K	PARTICIPANT	\N	PRESENT	0
780203	779645	20062A	PARTICIPANT	\N	PRESENT	0
780205	779645	20072C	PARTICIPANT	\N	PRESENT	0
780207	779645	21090J	PARTICIPANT	\N	PRESENT	0
780209	779645	20044X	PARTICIPANT	\N	PRESENT	0
780210	779645	95041E	PARTICIPANT	\N	PRESENT	0
780213	779645	14191V	PARTICIPANT	\N	PRESENT	0
780214	779645	19565D	PARTICIPANT	\N	PRESENT	0
780215	779645	21035B	PARTICIPANT	\N	PRESENT	0
780216	779645	19711U	PARTICIPANT	\N	PRESENT	0
780219	779645	21084L	PARTICIPANT	\N	PRESENT	0
780220	779645	20036X	PARTICIPANT	\N	PRESENT	0
780221	779645	14121F	PARTICIPANT	\N	PRESENT	0
780222	779645	99004R	PARTICIPANT	\N	PRESENT	0
780223	779645	20180F	PARTICIPANT	\N	PRESENT	0
780225	779645	20124W	PARTICIPANT	\N	PRESENT	0
780226	779645	19657G	PARTICIPANT	\N	PRESENT	0
780227	779645	19573D	PARTICIPANT	\N	PRESENT	0
780228	779645	20150Y	PARTICIPANT	\N	PRESENT	0
780229	779645	21058J	PARTICIPANT	\N	PRESENT	0
780230	779645	07033P	PARTICIPANT	\N	PRESENT	0
780232	779645	19545Y	PARTICIPANT	\N	PRESENT	0
780233	779645	21043B	PARTICIPANT	\N	PRESENT	0
780234	779645	12028B	PARTICIPANT	\N	PRESENT	0
780235	779645	19669L	PARTICIPANT	\N	PRESENT	0
780236	779645	14249W	PARTICIPANT	\N	PRESENT	0
780237	779645	14073Q	PARTICIPANT	\N	PRESENT	0
784726	783373	21068L	PARTICIPANT	\N	PRESENT	0
784727	783373	19447X	PARTICIPANT	\N	PRESENT	0
784728	783373	12028B	PARTICIPANT	\N	PRESENT	0
784729	783373	21077M	PARTICIPANT	\N	PRESENT	0
784730	783373	20080C	PARTICIPANT	\N	PRESENT	0
784731	783373	21093M	PARTICIPANT	\N	PRESENT	0
784732	783373	20130U	PARTICIPANT	\N	PRESENT	0
784733	783373	14219Q	PARTICIPANT	\N	PRESENT	0
784734	783373	08047A	PARTICIPANT	\N	PRESENT	0
784735	783373	19669L	PARTICIPANT	\N	PRESENT	0
784736	783373	14121F	PARTICIPANT	\N	PRESENT	0
784737	783373	21062E	PARTICIPANT	\N	PRESENT	0
784738	783373	14257W	PARTICIPANT	\N	PRESENT	0
784739	783373	21088Q	PARTICIPANT	\N	PRESENT	0
784740	783373	20264J	PARTICIPANT	\N	PRESENT	0
784741	783373	14107H	PARTICIPANT	\N	PRESENT	0
784742	783373	19507S	PARTICIPANT	\N	PRESENT	0
784743	783373	20044X	PARTICIPANT	\N	PRESENT	0
784744	783373	19347U	PARTICIPANT	\N	PRESENT	0
784745	783373	20142Y	PARTICIPANT	\N	PRESENT	0
784746	783373	20022R	PARTICIPANT	\N	PRESENT	0
784747	783373	10015M	PARTICIPANT	\N	PRESENT	0
784748	783373	19723Y	PARTICIPANT	\N	PRESENT	0
784749	783373	07029T	PARTICIPANT	\N	PRESENT	0
784750	783373	21047F	PARTICIPANT	\N	PRESENT	0
784751	783373	19673G	PARTICIPANT	\N	PRESENT	0
784752	783373	20108W	PARTICIPANT	\N	PRESENT	0
784753	783373	18083K	PARTICIPANT	\N	PRESENT	0
784754	783373	21045D	PARTICIPANT	\N	PRESENT	0
784755	783373	20094J	PARTICIPANT	\N	PRESENT	0
784756	783373	14021P	PARTICIPANT	\N	PRESENT	0
784757	783373	14089Y	PARTICIPANT	\N	PRESENT	0
784758	783373	20042V	PARTICIPANT	\N	PRESENT	0
784759	783373	20064C	PARTICIPANT	\N	PRESENT	0
784760	783373	14225N	PARTICIPANT	\N	PRESENT	0
784761	783373	17965H	PARTICIPANT	\N	PRESENT	0
784762	783373	20030R	PARTICIPANT	\N	PRESENT	0
784763	783373	11065P	PARTICIPANT	\N	PRESENT	0
784764	783373	14001X	PARTICIPANT	\N	PRESENT	0
784765	783373	17779H	PARTICIPANT	\N	PRESENT	0
784766	783373	19489J	PARTICIPANT	\N	PRESENT	0
784767	783373	19820Y	PARTICIPANT	\N	PRESENT	0
784768	783373	19647E	PARTICIPANT	\N	PRESENT	0
784769	783373	11074Q	PARTICIPANT	\N	PRESENT	0
784770	783373	18395Y	PARTICIPANT	\N	PRESENT	0
784771	783373	20070A	PARTICIPANT	\N	PRESENT	0
784772	783373	20134Y	PARTICIPANT	\N	PRESENT	0
784773	783373	21092L	PARTICIPANT	\N	PRESENT	0
784774	783373	20092G	PARTICIPANT	\N	PRESENT	0
784775	783373	21049H	PARTICIPANT	\N	PRESENT	0
784776	783373	19687N	PARTICIPANT	\N	PRESENT	0
784777	783373	21084L	PARTICIPANT	\N	PRESENT	0
784778	783373	21030V	PARTICIPANT	\N	PRESENT	0
784779	783373	20106U	PARTICIPANT	\N	PRESENT	0
784780	783373	14037X	PARTICIPANT	\N	PRESENT	0
784781	783373	08061X	PARTICIPANT	\N	PRESENT	0
784782	783373	19349W	PARTICIPANT	\N	PRESENT	0
784783	783373	21085M	PARTICIPANT	\N	PRESENT	0
784784	783373	20122U	PARTICIPANT	\N	PRESENT	0
784785	783373	14195A	PARTICIPANT	\N	PRESENT	0
784786	783373	14207L	PARTICIPANT	\N	PRESENT	0
784787	783373	21067K	PARTICIPANT	\N	PRESENT	0
784788	783373	14211G	PARTICIPANT	\N	PRESENT	0
784789	783373	17023S	PARTICIPANT	\N	PRESENT	0
784790	783373	19479G	PARTICIPANT	\N	PRESENT	0
784791	783373	01034P	PARTICIPANT	\N	PRESENT	0
784792	783373	19713W	PARTICIPANT	\N	PRESENT	0
784793	783373	14173T	PARTICIPANT	\N	PRESENT	0
784794	783373	21036C	PARTICIPANT	\N	PRESENT	0
784795	783373	05008E	PARTICIPANT	\N	PRESENT	0
784796	783373	19575F	PARTICIPANT	\N	PRESENT	0
784797	783373	20138D	PARTICIPANT	\N	PRESENT	0
784798	783373	19383Y	PARTICIPANT	\N	PRESENT	0
784799	783373	17737W	PARTICIPANT	\N	PRESENT	0
784800	783373	04042C	PARTICIPANT	\N	PRESENT	0
784801	783373	20104S	PARTICIPANT	\N	PRESENT	0
784802	783373	21090J	PARTICIPANT	\N	PRESENT	0
784803	783373	14038Y	PARTICIPANT	\N	PRESENT	0
784804	783373	19701S	PARTICIPANT	\N	PRESENT	0
784805	783373	21072G	PARTICIPANT	\N	PRESENT	0
784806	783373	20124W	PARTICIPANT	\N	PRESENT	0
784807	783373	14187A	PARTICIPANT	\N	PRESENT	0
784808	783373	20172F	PARTICIPANT	\N	PRESENT	0
784809	783373	20120S	PARTICIPANT	\N	PRESENT	0
784810	783373	17367Q	PARTICIPANT	\N	PRESENT	0
784811	783373	14123H	PARTICIPANT	\N	PRESENT	0
784812	783373	20114U	PARTICIPANT	\N	PRESENT	0
784813	783373	11048N	PARTICIPANT	\N	PRESENT	0
784814	783373	99004R	PARTICIPANT	\N	PRESENT	0
784815	783373	20126Y	PARTICIPANT	\N	PRESENT	0
784816	783373	19563B	PARTICIPANT	\N	PRESENT	0
784817	783373	19335Q	PARTICIPANT	\N	PRESENT	0
784818	783373	19611R	PARTICIPANT	\N	PRESENT	0
784819	783373	14179A	PARTICIPANT	\N	PRESENT	0
784820	783373	21086N	PARTICIPANT	\N	PRESENT	0
784821	783373	08010L	PARTICIPANT	\N	PRESENT	0
784822	783373	14026U	PARTICIPANT	\N	PRESENT	0
784823	783373	05012A	PARTICIPANT	\N	PRESENT	0
784824	783373	20118Y	PARTICIPANT	\N	PRESENT	0
784825	783373	20098N	PARTICIPANT	\N	PRESENT	0
784826	783373	19533U	PARTICIPANT	\N	PRESENT	0
784827	783373	21071F	PARTICIPANT	\N	PRESENT	0
784828	783373	14133K	PARTICIPANT	\N	PRESENT	0
784829	783373	04033B	PARTICIPANT	\N	PRESENT	0
784830	783373	20054A	PARTICIPANT	\N	PRESENT	0
784831	783373	04092N	PARTICIPANT	\N	PRESENT	0
784832	783373	21058J	PARTICIPANT	\N	PRESENT	0
784833	783373	14031R	PARTICIPANT	\N	PRESENT	0
784834	783373	20038A	PARTICIPANT	\N	PRESENT	0
784835	783373	15197G	PARTICIPANT	\N	PRESENT	0
784836	783373	14042U	PARTICIPANT	\N	PRESENT	0
784837	783373	20128B	PARTICIPANT	\N	PRESENT	0
784838	783373	18193Q	PARTICIPANT	\N	PRESENT	0
784839	783373	21082J	PARTICIPANT	\N	PRESENT	0
784840	783373	18231D	PARTICIPANT	\N	PRESENT	0
784841	783373	20060X	PARTICIPANT	\N	PRESENT	0
784842	783373	08009T	PARTICIPANT	\N	PRESENT	0
784843	783373	19826F	PARTICIPANT	\N	PRESENT	0
784844	783373	20136B	PARTICIPANT	\N	PRESENT	0
784845	783373	14169X	PARTICIPANT	\N	PRESENT	0
784846	783373	14111D	PARTICIPANT	\N	PRESENT	0
784847	783373	14249W	PARTICIPANT	\N	PRESENT	0
784848	783373	19531S	PARTICIPANT	\N	PRESENT	0
784849	783373	19703U	PARTICIPANT	\N	PRESENT	0
784850	783373	21051B	PARTICIPANT	\N	PRESENT	0
784851	783373	19619A	PARTICIPANT	\N	PRESENT	0
784852	783373	19551W	PARTICIPANT	\N	PRESENT	0
784853	783373	19387D	PARTICIPANT	\N	PRESENT	0
784854	783373	14097Y	PARTICIPANT	\N	PRESENT	0
784855	783373	19691J	PARTICIPANT	\N	PRESENT	0
784856	783373	20034V	PARTICIPANT	\N	PRESENT	0
785096	783385	19479G	PARTICIPANT	\N	PRESENT	0
785097	783385	21057H	PARTICIPANT	\N	PRESENT	0
785098	783385	19593H	PARTICIPANT	\N	PRESENT	0
785099	783385	20100N	PARTICIPANT	\N	PRESENT	0
785100	783385	19768N	PARTICIPANT	\N	PRESENT	0
785101	783385	95041E	PARTICIPANT	\N	PRESENT	0
785102	783385	21044C	PARTICIPANT	\N	PRESENT	0
785103	783385	04047H	PARTICIPANT	\N	PRESENT	0
785104	783385	21064G	PARTICIPANT	\N	PRESENT	0
785105	783385	07004J	PARTICIPANT	\N	PRESENT	0
785106	783385	21043B	PARTICIPANT	\N	PRESENT	0
785107	783385	10015M	PARTICIPANT	\N	PRESENT	0
785108	783385	20096L	PARTICIPANT	\N	PRESENT	0
785109	783385	20022R	PARTICIPANT	\N	PRESENT	0
785110	783385	08069G	PARTICIPANT	\N	PRESENT	0
785111	783385	20134Y	PARTICIPANT	\N	PRESENT	0
785112	783385	21052C	PARTICIPANT	\N	PRESENT	0
785113	783385	21054E	PARTICIPANT	\N	PRESENT	0
785114	783385	08015R	PARTICIPANT	\N	PRESENT	0
785115	783385	19719D	PARTICIPANT	\N	PRESENT	0
785116	783385	19749K	PARTICIPANT	\N	PRESENT	0
785117	783385	19701S	PARTICIPANT	\N	PRESENT	0
785118	783385	14215L	PARTICIPANT	\N	PRESENT	0
785119	783385	19679N	PARTICIPANT	\N	PRESENT	0
785120	783385	20052X	PARTICIPANT	\N	PRESENT	0
785121	783385	19447X	PARTICIPANT	\N	PRESENT	0
785122	783385	14053L	PARTICIPANT	\N	PRESENT	0
785123	783385	14147R	PARTICIPANT	\N	PRESENT	0
785124	783385	20056C	PARTICIPANT	\N	PRESENT	0
785125	783385	21058J	PARTICIPANT	\N	PRESENT	0
778314	777689	20082E	PARTICIPANT	\N	PRESENT	0
778667	778666	21045D	PARTICIPANT	\N	PRESENT	0
778668	778666	19565D	PARTICIPANT	\N	PRESENT	0
778669	778666	14026U	PARTICIPANT	\N	PRESENT	0
778670	778666	19553Y	PARTICIPANT	\N	PRESENT	0
778671	778666	11048N	PARTICIPANT	\N	PRESENT	0
778672	778666	19551W	PARTICIPANT	\N	PRESENT	0
778673	778666	18207D	PARTICIPANT	\N	PRESENT	0
778674	778666	21082J	PARTICIPANT	\N	PRESENT	0
778677	778676	21045D	PARTICIPANT	\N	PRESENT	0
778678	778676	19565D	PARTICIPANT	\N	PRESENT	0
778679	778676	14026U	PARTICIPANT	\N	PRESENT	0
778680	778676	19553Y	PARTICIPANT	\N	PRESENT	0
778681	778676	11048N	PARTICIPANT	\N	PRESENT	0
778682	778676	19551W	PARTICIPANT	\N	PRESENT	0
778683	778676	21082J	PARTICIPANT	\N	PRESENT	0
778699	776115	17023S	PARTICIPANT	\N	EXCUSE	0
778759	773917	14037X	PARTICIPANT	\N	PRESENT	0
778760	773917	20110Q	PARTICIPANT	\N	PRESENT	0
778761	773917	17737W	PARTICIPANT	\N	PRESENT	0
778762	773917	19621T	PARTICIPANT	\N	PRESENT	0
778763	773917	14255U	PARTICIPANT	\N	PRESENT	0
778764	773917	04045F	PARTICIPANT	\N	PRESENT	0
778765	773917	21093M	PARTICIPANT	\N	PRESENT	0
778766	773917	20026V	PARTICIPANT	\N	PRESENT	0
778767	773917	20120S	PARTICIPANT	\N	PRESENT	0
778768	773917	20056C	PARTICIPANT	\N	PRESENT	0
778769	773917	20126Y	PARTICIPANT	\N	PRESENT	0
778770	773917	19349W	PARTICIPANT	\N	PRESENT	0
778771	773917	20052X	PARTICIPANT	\N	PRESENT	0
778772	773917	21038E	PARTICIPANT	\N	PRESENT	0
778773	773917	20248J	PARTICIPANT	\N	PRESENT	0
778774	773917	14179A	PARTICIPANT	\N	PRESENT	0
779561	779560	19649G	PARTICIPANT	\N	PRESENT	0
779562	779560	14053L	PARTICIPANT	\N	PRESENT	0
779564	779563	14053L	PARTICIPANT	\N	PRESENT	0
779566	779563	19649G	PARTICIPANT	\N	PRESENT	0
781731	779088	21096Q	PARTICIPANT	\N	EXCUSE	0
781732	779088	14053L	PARTICIPANT	\N	EXCUSE	0
781733	779088	19673G	PARTICIPANT	\N	PRESENT	0
783244	777020	14189C	PARTICIPANT	\N	PRESENT	0
783245	777020	04047H	PARTICIPANT	\N	PRESENT	0
783246	777020	19111A	PARTICIPANT	\N	PRESENT	0
783248	777020	14231L	PARTICIPANT	\N	PRESENT	0
783249	777020	19447X	PARTICIPANT	\N	PRESENT	0
783250	777020	14111D	PARTICIPANT	\N	PRESENT	0
783251	777020	21095P	PARTICIPANT	\N	PRESENT	0
783352	779659	04047H	PARTICIPANT	\N	PRESENT	0
783353	779659	19782L	PARTICIPANT	\N	PRESENT	0
783354	779659	21071F	PARTICIPANT	\N	PRESENT	0
786291	786290	14033T	PARTICIPANT	\N	PRESENT	0
786292	786290	21082J	PARTICIPANT	\N	PRESENT	0
786294	786293	14033T	PARTICIPANT	\N	PRESENT	0
786295	786293	21082J	PARTICIPANT	\N	PRESENT	0
786297	786296	14033T	PARTICIPANT	\N	PRESENT	0
786298	786296	21082J	PARTICIPANT	\N	PRESENT	0
786300	786299	14033T	PARTICIPANT	\N	PRESENT	1
786301	786299	20286Q	PARTICIPANT	\N	PRESENT	0
786302	786299	21082J	PARTICIPANT	\N	PRESENT	0
786304	786303	14033T	PARTICIPANT	\N	PRESENT	1
786305	786303	20286Q	PARTICIPANT	\N	PRESENT	0
786626	786385	11045K	PARTICIPANT	\N	PRESENT	0
786630	786629	11045K	PARTICIPANT	\N	PRESENT	0
787769	786619	11056N	PARTICIPANT	\N	PRESENT	0
787770	786619	20094J	PARTICIPANT	\N	PRESENT	0
787771	786619	21056G	PARTICIPANT	\N	PRESENT	0
787772	786619	20114U	PARTICIPANT	\N	PRESENT	0
787773	786619	21082J	PARTICIPANT	\N	PRESENT	0
787774	786619	14121F	PARTICIPANT	\N	PRESENT	0
787775	786619	20264J	PARTICIPANT	\N	PRESENT	0
787776	786619	19295A	PARTICIPANT	\N	PRESENT	0
787777	786619	14225N	PARTICIPANT	\N	PRESENT	0
787778	786619	20082E	PARTICIPANT	\N	PRESENT	0
787782	786619	19758L	PARTICIPANT	\N	PRESENT	0
787783	786619	19593H	PARTICIPANT	\N	PRESENT	0
787784	786619	21034A	PARTICIPANT	\N	PRESENT	0
787785	786619	21037D	PARTICIPANT	\N	PRESENT	0
787786	786619	19631V	PARTICIPANT	\N	PRESENT	0
787787	786619	19820Y	PARTICIPANT	\N	PRESENT	0
787788	786619	21044C	PARTICIPANT	\N	PRESENT	0
787789	786619	19621T	PARTICIPANT	\N	PRESENT	0
787790	786619	11048N	PARTICIPANT	\N	PRESENT	0
787791	786619	19573D	PARTICIPANT	\N	PRESENT	0
787792	786619	19683J	PARTICIPANT	\N	PRESENT	0
787793	786619	19647E	PARTICIPANT	\N	PRESENT	0
787794	786619	18207D	PARTICIPANT	\N	PRESENT	0
787795	786619	14109K	PARTICIPANT	\N	PRESENT	0
787796	786619	21059K	PARTICIPANT	\N	PRESENT	0
787797	786619	19413M	PARTICIPANT	\N	PRESENT	0
787798	786619	19703U	PARTICIPANT	\N	PRESENT	0
787799	786619	08010L	PARTICIPANT	\N	PRESENT	0
787800	786619	04008A	PARTICIPANT	\N	PRESENT	0
787801	786619	20080C	PARTICIPANT	\N	PRESENT	0
787802	786619	18083K	PARTICIPANT	\N	PRESENT	0
787803	786619	20060X	PARTICIPANT	\N	PRESENT	0
787804	786619	21057H	PARTICIPANT	\N	PRESENT	0
787805	786619	19575F	PARTICIPANT	\N	PRESENT	0
787806	786619	20110Q	PARTICIPANT	\N	PRESENT	0
787807	786619	99004R	PARTICIPANT	\N	PRESENT	0
787808	786619	04047H	PARTICIPANT	\N	PRESENT	0
787809	786619	19719D	PARTICIPANT	\N	PRESENT	0
787810	786619	21035B	PARTICIPANT	\N	PRESENT	0
787811	786619	04092N	PARTICIPANT	\N	PRESENT	0
787812	786619	20100N	PARTICIPANT	\N	PRESENT	0
787813	786619	20092G	PARTICIPANT	\N	PRESENT	0
787814	786619	20128B	PARTICIPANT	\N	PRESENT	0
787815	786619	19760E	PARTICIPANT	\N	PRESENT	0
787816	786619	14026U	PARTICIPANT	\N	PRESENT	0
787817	786619	21088Q	PARTICIPANT	\N	PRESENT	0
787818	786619	04042C	PARTICIPANT	\N	PRESENT	0
787819	786619	21049H	PARTICIPANT	\N	PRESENT	0
787820	786619	20078J	PARTICIPANT	\N	PRESENT	0
787821	786619	20046A	PARTICIPANT	\N	PRESENT	0
787822	786619	21075K	PARTICIPANT	\N	PRESENT	0
787823	786619	14259Y	PARTICIPANT	\N	PRESENT	0
787824	786619	20076G	PARTICIPANT	\N	PRESENT	0
787825	786619	20106U	PARTICIPANT	\N	PRESENT	0
787826	786619	21043B	PARTICIPANT	\N	PRESENT	0
787827	786619	21080G	PARTICIPANT	\N	PRESENT	0
787828	786619	14037X	PARTICIPANT	\N	PRESENT	0
787829	786619	19347U	PARTICIPANT	\N	PRESENT	0
787830	786619	14223L	PARTICIPANT	\N	PRESENT	0
787831	786619	21092L	PARTICIPANT	\N	PRESENT	0
787832	786619	20142Y	PARTICIPANT	\N	PRESENT	0
787833	786619	20130U	PARTICIPANT	\N	PRESENT	0
787834	786619	08028W	PARTICIPANT	\N	PRESENT	0
787835	786619	21079P	PARTICIPANT	\N	PRESENT	0
787836	786619	04033B	PARTICIPANT	\N	PRESENT	0
787837	786619	21094N	PARTICIPANT	\N	PRESENT	0
787838	786619	20266L	PARTICIPANT	\N	PRESENT	0
787839	786619	19679N	PARTICIPANT	\N	PRESENT	0
787840	786619	05008E	PARTICIPANT	\N	PRESENT	0
787841	786619	14053L	PARTICIPANT	\N	PRESENT	0
787842	786619	14249W	PARTICIPANT	\N	PRESENT	0
787843	786619	19701S	PARTICIPANT	\N	PRESENT	0
787844	786619	14187A	PARTICIPANT	\N	PRESENT	0
787845	786619	19591F	PARTICIPANT	\N	PRESENT	0
787846	786619	11090Q	PARTICIPANT	\N	PRESENT	0
787847	786619	11072N	PARTICIPANT	\N	PRESENT	0
787848	786619	05012A	PARTICIPANT	\N	PRESENT	0
787849	786619	14215L	PARTICIPANT	\N	PRESENT	0
787850	786619	20044X	PARTICIPANT	\N	PRESENT	0
787851	786619	08061X	PARTICIPANT	\N	PRESENT	0
787852	786619	20146D	PARTICIPANT	\N	PRESENT	0
787853	786619	14237S	PARTICIPANT	\N	PRESENT	0
787854	786619	19349W	PARTICIPANT	\N	PRESENT	0
787855	786619	21072G	PARTICIPANT	\N	PRESENT	0
787856	786619	19301E	PARTICIPANT	\N	PRESENT	0
787857	786619	20150Y	PARTICIPANT	\N	PRESENT	0
787858	786619	14191V	PARTICIPANT	\N	PRESENT	0
787859	786619	21071F	PARTICIPANT	\N	PRESENT	0
787860	786619	21055F	PARTICIPANT	\N	PRESENT	0
787861	786619	14031R	PARTICIPANT	\N	PRESENT	0
787862	786619	20036X	PARTICIPANT	\N	PRESENT	0
787863	786619	19673G	PARTICIPANT	\N	PRESENT	0
787864	786619	19421M	PARTICIPANT	\N	PRESENT	0
787865	786619	19667J	PARTICIPANT	\N	PRESENT	0
787866	786619	14253S	PARTICIPANT	\N	PRESENT	0
787867	786619	20136B	PARTICIPANT	\N	PRESENT	0
787868	786619	17737W	PARTICIPANT	\N	PRESENT	0
778499	776552	19507S	PARTICIPANT	\N	PRESENT	0
778418	776552	20044X	PARTICIPANT	\N	PRESENT	0
778419	776552	20080C	PARTICIPANT	\N	PRESENT	0
778420	776552	14189C	PARTICIPANT	\N	PRESENT	0
778471	776552	20086J	PARTICIPANT	\N	PRESENT	0
778472	776552	21048G	PARTICIPANT	\N	PRESENT	0
778473	776552	19533U	PARTICIPANT	\N	PRESENT	0
778475	776552	20090E	PARTICIPANT	\N	PRESENT	0
778476	776552	20134Y	PARTICIPANT	\N	PRESENT	0
778477	776552	20110Q	PARTICIPANT	\N	PRESENT	0
778478	776552	20066E	PARTICIPANT	\N	PRESENT	0
778479	776552	19387D	PARTICIPANT	\N	PRESENT	0
778480	776552	14327T	PARTICIPANT	\N	PRESENT	0
778541	776552	20084G	PARTICIPANT	\N	PRESENT	0
778482	776552	12016W	PARTICIPANT	\N	PRESENT	0
778483	776552	14231L	PARTICIPANT	\N	PRESENT	0
778621	776552	14031R	PARTICIPANT	\N	PRESENT	0
778485	776552	21066J	PARTICIPANT	\N	PRESENT	0
778486	776552	19687N	PARTICIPANT	\N	PRESENT	0
778487	776552	21085M	PARTICIPANT	\N	PRESENT	0
778488	776552	14121F	PARTICIPANT	\N	PRESENT	0
778489	776552	19489J	PARTICIPANT	\N	PRESENT	0
778594	776552	21050A	PARTICIPANT	\N	PRESENT	0
778491	776552	14179A	PARTICIPANT	\N	PRESENT	0
778492	776552	07029T	PARTICIPANT	\N	PRESENT	0
778493	776552	21044C	PARTICIPANT	\N	PRESENT	0
778494	776552	19703U	PARTICIPANT	\N	PRESENT	0
778495	776552	21053D	PARTICIPANT	\N	PRESENT	0
778496	776552	21062E	PARTICIPANT	\N	PRESENT	0
778497	776552	19713W	PARTICIPANT	\N	PRESENT	0
778498	776552	20076G	PARTICIPANT	\N	PRESENT	0
778500	776552	20072C	PARTICIPANT	\N	PRESENT	0
778501	776552	19349W	PARTICIPANT	\N	PRESENT	0
778400	776552	19479G	PARTICIPANT	\N	PRESENT	0
778416	776552	21069M	PARTICIPANT	\N	PRESENT	0
778502	776552	20028X	PARTICIPANT	\N	PRESENT	0
778503	776552	21079P	PARTICIPANT	\N	PRESENT	0
778504	776552	20030R	PARTICIPANT	\N	PRESENT	0
778505	776552	19758L	PARTICIPANT	\N	PRESENT	0
778506	776552	20098N	PARTICIPANT	\N	PRESENT	0
778507	776552	20266L	PARTICIPANT	\N	PRESENT	0
778508	776552	21093M	PARTICIPANT	\N	PRESENT	0
778524	776552	19711U	PARTICIPANT	\N	PRESENT	0
778510	775805	19421M	PARTICIPANT	\N	EXCUSE	0
778511	775805	14179A	PARTICIPANT	\N	EXCUSE	0
778512	775805	07033P	PARTICIPANT	\N	EXCUSE	0
778513	775805	19669L	PARTICIPANT	\N	EXCUSE	0
778514	775805	20128B	PARTICIPANT	\N	EXCUSE	0
778515	776552	21081H	PARTICIPANT	\N	PRESENT	0
778516	776552	21076L	PARTICIPANT	\N	PRESENT	0
778517	776552	21070E	PARTICIPANT	\N	PRESENT	0
778518	776552	08073C	PARTICIPANT	\N	PRESENT	0
778519	776552	19383Y	PARTICIPANT	\N	PRESENT	0
778520	776552	19768N	PARTICIPANT	\N	PRESENT	0
778521	776552	20062A	PARTICIPANT	\N	PRESENT	0
778522	776552	11110B	PARTICIPANT	\N	PRESENT	0
778523	776552	20056C	PARTICIPANT	\N	PRESENT	0
778525	776552	19569H	PARTICIPANT	\N	PRESENT	0
778526	776552	01058X	PARTICIPANT	\N	PRESENT	0
778527	776552	19629C	PARTICIPANT	\N	PRESENT	0
778528	776552	14033T	PARTICIPANT	\N	PRESENT	0
778529	776552	14038Y	PARTICIPANT	\N	PRESENT	0
778530	776552	19399H	PARTICIPANT	\N	PRESENT	0
778531	776552	20036X	PARTICIPANT	\N	PRESENT	0
778532	776552	21058J	PARTICIPANT	\N	PRESENT	0
778533	776552	21029D	PARTICIPANT	\N	PRESENT	0
778534	776552	18207D	PARTICIPANT	\N	PRESENT	0
778535	776552	19573D	PARTICIPANT	\N	PRESENT	0
778536	776552	14133K	PARTICIPANT	\N	PRESENT	0
778537	776552	14030Q	PARTICIPANT	\N	PRESENT	0
778538	776552	19723Y	PARTICIPANT	\N	PRESENT	0
778539	776552	19575F	PARTICIPANT	\N	PRESENT	0
778540	776552	14059S	PARTICIPANT	\N	PRESENT	0
778542	776552	14001X	PARTICIPANT	\N	PRESENT	0
778543	776552	08034U	PARTICIPANT	\N	PRESENT	0
778544	776552	14331P	PARTICIPANT	\N	PRESENT	0
778546	776552	20022R	PARTICIPANT	\N	PRESENT	0
778553	776552	14205J	PARTICIPANT	\N	PRESENT	0
778551	776552	21065H	PARTICIPANT	\N	PRESENT	0
778552	776552	14215L	PARTICIPANT	\N	PRESENT	0
778554	776552	19683J	PARTICIPANT	\N	PRESENT	0
778555	776552	11056N	PARTICIPANT	\N	PRESENT	0
778556	776552	14083S	PARTICIPANT	\N	PRESENT	0
778558	776552	14259Y	PARTICIPANT	\N	PRESENT	0
778559	776552	19631V	PARTICIPANT	\N	PRESENT	0
778561	776552	19798U	PARTICIPANT	\N	PRESENT	0
778567	776552	20026V	PARTICIPANT	\N	PRESENT	0
778568	776552	20058E	PARTICIPANT	\N	PRESENT	0
778569	776552	19563B	PARTICIPANT	\N	PRESENT	0
778570	776552	08061X	PARTICIPANT	\N	PRESENT	0
778571	776552	21063F	PARTICIPANT	\N	PRESENT	0
778572	776552	21071F	PARTICIPANT	\N	PRESENT	0
778573	776552	14249W	PARTICIPANT	\N	PRESENT	0
778577	776552	21083K	PARTICIPANT	\N	PRESENT	0
778575	776552	20104S	PARTICIPANT	\N	PRESENT	0
778576	776552	20032T	PARTICIPANT	\N	PRESENT	0
778578	776552	21087P	PARTICIPANT	\N	PRESENT	0
778579	776552	20126Y	PARTICIPANT	\N	PRESENT	0
778580	776552	20124W	PARTICIPANT	\N	PRESENT	0
778581	776552	17737W	PARTICIPANT	\N	PRESENT	0
778582	776552	20108W	PARTICIPANT	\N	PRESENT	0
778583	776552	05008E	PARTICIPANT	\N	PRESENT	0
778584	776552	14219Q	PARTICIPANT	\N	PRESENT	0
778585	776552	21042A	PARTICIPANT	\N	PRESENT	0
778586	776552	21082J	PARTICIPANT	\N	PRESENT	0
778587	776552	21041Y	PARTICIPANT	\N	PRESENT	0
778588	776552	14073Q	PARTICIPANT	\N	PRESENT	0
778589	776552	98022P	PARTICIPANT	\N	PRESENT	0
778590	776552	21047F	PARTICIPANT	\N	PRESENT	0
778591	776552	08015R	PARTICIPANT	\N	PRESENT	0
778592	776552	04045F	PARTICIPANT	\N	PRESENT	0
778593	776552	14225N	PARTICIPANT	\N	PRESENT	0
778595	776552	19691J	PARTICIPANT	\N	PRESENT	0
778596	776552	08011M	PARTICIPANT	\N	PRESENT	0
778597	776552	20068G	PARTICIPANT	\N	PRESENT	0
778598	776552	18083K	PARTICIPANT	\N	PRESENT	0
778599	776552	21034A	PARTICIPANT	\N	PRESENT	0
778600	776552	21043B	PARTICIPANT	\N	PRESENT	0
778601	776552	20088L	PARTICIPANT	\N	PRESENT	0
778602	776552	08056B	PARTICIPANT	\N	PRESENT	0
778603	776552	19647E	PARTICIPANT	\N	PRESENT	0
778604	776552	21090J	PARTICIPANT	\N	PRESENT	0
778605	776552	19335Q	PARTICIPANT	\N	PRESENT	0
778606	776552	21068L	PARTICIPANT	\N	PRESENT	0
778607	776552	20018V	PARTICIPANT	\N	PRESENT	0
778608	776552	14069U	PARTICIPANT	\N	PRESENT	0
778609	776552	21055F	PARTICIPANT	\N	PRESENT	0
778610	776552	21073H	PARTICIPANT	\N	PRESENT	0
778611	776552	19347U	PARTICIPANT	\N	PRESENT	0
778612	776552	14147R	PARTICIPANT	\N	PRESENT	0
778613	776552	05012A	PARTICIPANT	\N	PRESENT	0
778614	776552	08069G	PARTICIPANT	\N	PRESENT	0
778615	776552	18193Q	PARTICIPANT	\N	PRESENT	0
778616	776552	14123H	PARTICIPANT	\N	PRESENT	0
778617	776552	11048N	PARTICIPANT	\N	PRESENT	0
778618	776552	19760E	PARTICIPANT	\N	PRESENT	0
778619	776552	08028W	PARTICIPANT	\N	PRESENT	0
778620	776552	19621T	PARTICIPANT	\N	PRESENT	0
778622	776552	14151M	PARTICIPANT	\N	PRESENT	0
778623	776552	20070A	PARTICIPANT	\N	PRESENT	0
778624	776552	14042U	PARTICIPANT	\N	PRESENT	0
778625	776552	20180F	PARTICIPANT	\N	PRESENT	0
778626	776552	14109K	PARTICIPANT	\N	PRESENT	0
778627	776552	20082E	PARTICIPANT	\N	PRESENT	0
778628	776552	21054E	PARTICIPANT	\N	PRESENT	0
778629	776552	20248J	PARTICIPANT	\N	PRESENT	0
778630	776552	14207L	PARTICIPANT	\N	PRESENT	0
778631	776552	20054A	PARTICIPANT	\N	PRESENT	0
778632	776552	11090Q	PARTICIPANT	\N	PRESENT	0
778633	776552	20052X	PARTICIPANT	\N	PRESENT	0
778634	776552	20172F	PARTICIPANT	\N	PRESENT	0
778635	776552	19725B	PARTICIPANT	\N	PRESENT	0
778648	776552	11045K	PARTICIPANT	\N	PRESENT	0
778650	776552	14097Y	PARTICIPANT	\N	PRESENT	0
778653	776552	19782L	PARTICIPANT	\N	PRESENT	0
778654	776552	19667J	PARTICIPANT	\N	PRESENT	0
778655	776552	08010L	PARTICIPANT	\N	PRESENT	0
778656	776552	20038A	PARTICIPANT	\N	PRESENT	0
778657	776552	14169X	PARTICIPANT	\N	PRESENT	0
778658	776552	20102Q	PARTICIPANT	\N	PRESENT	0
778660	776552	19531S	PARTICIPANT	\N	PRESENT	0
768238	768230	14033T	PARTICIPANT	\N	PRESENT	0
768241	768239	14033T	PARTICIPANT	\N	PRESENT	0
769605	769604	12028B	PARTICIPANT	\N	PRESENT	0
769606	769604	11064N	PARTICIPANT	\N	PRESENT	0
769608	769607	17737W	PARTICIPANT	\N	PRESENT	0
769609	769607	14037X	PARTICIPANT	\N	PRESENT	0
769611	769610	17737W	PARTICIPANT	\N	PRESENT	0
769612	769610	14037X	PARTICIPANT	\N	PRESENT	0
769614	769613	17737W	PARTICIPANT	\N	PRESENT	0
769616	769615	17737W	PARTICIPANT	\N	PRESENT	0
769617	769615	14037X	PARTICIPANT	\N	PRESENT	0
772589	772441	19673G	PARTICIPANT	\N	EXCUSE	0
777727	773849	04047H	PARTICIPANT	\N	PRESENT	0
777728	773849	14189C	PARTICIPANT	\N	PRESENT	0
777729	773849	20022R	PARTICIPANT	\N	PRESENT	0
777730	773849	14215L	PARTICIPANT	\N	PRESENT	0
777731	773849	19673G	PARTICIPANT	\N	PRESENT	0
777732	773849	14231L	PARTICIPANT	\N	PRESENT	0
777733	773849	21044C	PARTICIPANT	\N	PRESENT	0
777734	773849	19729F	PARTICIPANT	\N	PRESENT	0
777735	773849	14147R	PARTICIPANT	\N	PRESENT	0
777740	773849	04045F	PARTICIPANT	\N	PRESENT	0
777737	773849	21076L	PARTICIPANT	\N	PRESENT	0
778910	775655	14151M	PRESIDENT	0	PRESENT	0
778911	775655	17367Q	PARTICIPANT	\N	PRESENT	0
778913	775655	99004R	PARTICIPANT	\N	PRESENT	0
778929	775655	20090E	PARTICIPANT	\N	PRESENT	0
778930	775655	21072G	PARTICIPANT	\N	PRESENT	0
778939	775655	19349W	PARTICIPANT	\N	PRESENT	0
778954	775655	18395Y	PARTICIPANT	\N	PRESENT	0
778955	775655	14255U	PARTICIPANT	\N	PRESENT	0
779018	775655	20146D	PARTICIPANT	\N	EXCUSE	0
780239	779645	04042C	PARTICIPANT	\N	PRESENT	0
779546	779542	19709B	PARTICIPANT	\N	PRESENT	0
780238	779645	20252E	PARTICIPANT	\N	PRESENT	0
780240	779645	14097Y	PARTICIPANT	\N	PRESENT	0
780241	779645	08034U	PARTICIPANT	\N	PRESENT	0
780242	779645	14193X	PARTICIPANT	\N	PRESENT	0
780243	779645	19349W	PARTICIPANT	\N	PRESENT	0
780244	779645	21073H	PARTICIPANT	\N	PRESENT	0
780245	779645	08061X	PARTICIPANT	\N	PRESENT	0
780246	779645	21076L	PARTICIPANT	\N	PRESENT	0
780247	779645	14267Y	PARTICIPANT	\N	PRESENT	0
780248	779645	11048N	PARTICIPANT	\N	PRESENT	0
780249	779645	19421M	PARTICIPANT	\N	PRESENT	0
780250	779645	20024T	PARTICIPANT	\N	PRESENT	0
780251	779645	19713W	PARTICIPANT	\N	PRESENT	0
780252	779645	20026V	PARTICIPANT	\N	PRESENT	0
780253	779645	08047A	PARTICIPANT	\N	PRESENT	0
780254	779645	20128B	PARTICIPANT	\N	PRESENT	0
780255	779645	20070A	PARTICIPANT	\N	PRESENT	0
780256	779645	21074J	PARTICIPANT	\N	PRESENT	0
780257	779645	14059S	PARTICIPANT	\N	PRESENT	0
780258	779645	07029T	PARTICIPANT	\N	PRESENT	0
780259	779645	21087P	PARTICIPANT	\N	PRESENT	0
780260	779645	19531S	PARTICIPANT	\N	PRESENT	0
780265	779645	14255U	PARTICIPANT	\N	PRESENT	0
780266	779645	21063F	PARTICIPANT	\N	PRESENT	0
780267	779645	21093M	PARTICIPANT	\N	PRESENT	0
780268	779645	14069U	PARTICIPANT	\N	PRESENT	0
780269	779645	14215L	PARTICIPANT	\N	PRESENT	0
780270	779645	20058E	PARTICIPANT	\N	PRESENT	0
780271	779645	11053K	PARTICIPANT	\N	PRESENT	0
780272	779645	21092L	PARTICIPANT	\N	PRESENT	0
780273	779645	20080C	PARTICIPANT	\N	PRESENT	0
780274	779645	19687N	PARTICIPANT	\N	PRESENT	0
780275	779645	19347U	PARTICIPANT	\N	PRESENT	0
780276	779645	21040X	PARTICIPANT	\N	PRESENT	0
780277	779645	21055F	PARTICIPANT	\N	PRESENT	0
780278	779645	11056N	PARTICIPANT	\N	PRESENT	0
780279	779645	21030V	PARTICIPANT	\N	PRESENT	0
780287	779645	20094J	PARTICIPANT	\N	PRESENT	0
780297	779645	20264J	PARTICIPANT	\N	PRESENT	0
780304	779646	14111D	PARTICIPANT	\N	PRESENT	0
780361	779646	04033B	PARTICIPANT	\N	PRESENT	0
780363	779646	12028B	PARTICIPANT	\N	PRESENT	0
780307	779646	20072C	PARTICIPANT	\N	PRESENT	0
780308	779646	20044X	PARTICIPANT	\N	PRESENT	0
780309	779646	95041E	PARTICIPANT	\N	PRESENT	0
780310	779646	14191V	PARTICIPANT	\N	PRESENT	0
780311	779646	19565D	PARTICIPANT	\N	PRESENT	0
780312	779646	19711U	PARTICIPANT	\N	PRESENT	0
780313	779646	21084L	PARTICIPANT	\N	PRESENT	0
780314	779646	20036X	PARTICIPANT	\N	PRESENT	0
780362	779646	08034U	PARTICIPANT	\N	PRESENT	0
780316	779646	20124W	PARTICIPANT	\N	PRESENT	0
780317	779646	19657G	PARTICIPANT	\N	PRESENT	0
780318	779646	20150Y	PARTICIPANT	\N	PRESENT	0
780319	779646	21058J	PARTICIPANT	\N	PRESENT	0
780320	779646	19545Y	PARTICIPANT	\N	PRESENT	0
780364	779646	14073Q	PARTICIPANT	\N	PRESENT	0
780322	779646	19669L	PARTICIPANT	\N	PRESENT	0
780323	779646	14249W	PARTICIPANT	\N	PRESENT	0
780360	779646	19573D	PARTICIPANT	\N	PRESENT	0
780325	779646	20252E	PARTICIPANT	\N	PRESENT	0
780365	779646	21054E	PARTICIPANT	\N	PRESENT	0
780327	779646	14097Y	PARTICIPANT	\N	PRESENT	0
780409	779647	14229S	PARTICIPANT	\N	PRESENT	0
780411	779647	19687N	PARTICIPANT	\N	PRESENT	0
780330	779646	21073H	PARTICIPANT	\N	PRESENT	0
780412	779647	20028X	PARTICIPANT	\N	PRESENT	0
780332	779646	11048N	PARTICIPANT	\N	PRESENT	0
780333	779646	19421M	PARTICIPANT	\N	PRESENT	0
780334	779646	20026V	PARTICIPANT	\N	PRESENT	0
780413	779647	20264J	PARTICIPANT	\N	PRESENT	0
780414	779647	21093M	PARTICIPANT	\N	PRESENT	0
780337	779646	20070A	PARTICIPANT	\N	PRESENT	0
780338	779646	21074J	PARTICIPANT	\N	PRESENT	0
780339	779646	14059S	PARTICIPANT	\N	PRESENT	0
780340	779646	07029T	PARTICIPANT	\N	PRESENT	0
780341	779646	21087P	PARTICIPANT	\N	PRESENT	0
780342	779646	19531S	PARTICIPANT	\N	PRESENT	0
780343	779646	21063F	PARTICIPANT	\N	PRESENT	0
780344	779646	21093M	PARTICIPANT	\N	PRESENT	0
780345	779646	14069U	PARTICIPANT	\N	PRESENT	0
780346	779646	14215L	PARTICIPANT	\N	PRESENT	0
780347	779646	20058E	PARTICIPANT	\N	PRESENT	0
780348	779646	11053K	PARTICIPANT	\N	PRESENT	0
780349	779646	21092L	PARTICIPANT	\N	PRESENT	0
780350	779646	20080C	PARTICIPANT	\N	PRESENT	0
780351	779646	19687N	PARTICIPANT	\N	PRESENT	0
780352	779646	19347U	PARTICIPANT	\N	PRESENT	0
780415	779647	20070A	PARTICIPANT	\N	PRESENT	0
780354	779646	21055F	PARTICIPANT	\N	PRESENT	0
780355	779646	11056N	PARTICIPANT	\N	PRESENT	0
780356	779646	21030V	PARTICIPANT	\N	PRESENT	0
780357	779646	20094J	PARTICIPANT	\N	PRESENT	0
780358	779646	20264J	PARTICIPANT	\N	PRESENT	0
780359	779646	19713W	PARTICIPANT	\N	PRESENT	0
780416	779647	07004J	PARTICIPANT	\N	PRESENT	0
780417	779647	19347U	PARTICIPANT	\N	PRESENT	0
780418	779647	14097Y	PARTICIPANT	\N	PRESENT	0
780419	779647	11048N	PARTICIPANT	\N	PRESENT	0
780420	779647	14225N	PARTICIPANT	\N	PRESENT	0
780421	779647	21087P	PARTICIPANT	\N	PRESENT	0
780422	779647	21040X	PARTICIPANT	\N	PRESENT	0
780423	779647	20072C	PARTICIPANT	\N	PRESENT	0
780424	779647	04033B	PARTICIPANT	\N	PRESENT	0
780425	779647	14187A	PARTICIPANT	\N	PRESENT	0
780426	779647	20124W	PARTICIPANT	\N	PRESENT	0
780427	779647	20058E	PARTICIPANT	\N	PRESENT	0
780428	779647	19711U	PARTICIPANT	\N	PRESENT	0
780429	779647	21058J	PARTICIPANT	\N	PRESENT	0
780430	779647	21055F	PARTICIPANT	\N	PRESENT	0
780431	779647	20044X	PARTICIPANT	\N	PRESENT	0
780432	779647	14191V	PARTICIPANT	\N	PRESENT	0
780433	779647	07029T	PARTICIPANT	\N	PRESENT	0
780434	779647	19713W	PARTICIPANT	\N	PRESENT	0
780435	779647	20054A	PARTICIPANT	\N	PRESENT	0
780436	779647	20080C	PARTICIPANT	\N	PRESENT	0
780437	779647	17023S	PARTICIPANT	\N	PRESENT	0
780438	779647	19647E	PARTICIPANT	\N	PRESENT	0
780439	779647	21092L	PARTICIPANT	\N	PRESENT	0
780440	779647	19629C	PARTICIPANT	\N	PRESENT	0
780441	779647	20122U	PARTICIPANT	\N	PRESENT	0
780442	779647	21030V	PARTICIPANT	\N	PRESENT	0
780443	779647	11056N	PARTICIPANT	\N	PRESENT	0
780444	779647	20066E	PARTICIPANT	\N	PRESENT	0
780445	779647	20252E	PARTICIPANT	\N	PRESENT	0
780446	779647	14193X	PARTICIPANT	\N	PRESENT	0
780447	779647	19349W	PARTICIPANT	\N	PRESENT	0
785126	783385	20180F	PARTICIPANT	\N	PRESENT	0
785127	783385	20026V	PARTICIPANT	\N	PRESENT	0
785128	783385	20140W	PARTICIPANT	\N	PRESENT	0
785129	783385	14213J	PARTICIPANT	\N	PRESENT	0
785130	783385	18207D	PARTICIPANT	\N	PRESENT	0
785131	783385	20054A	PARTICIPANT	\N	PRESENT	0
785132	783385	20062A	PARTICIPANT	\N	PRESENT	0
785133	783385	20058E	PARTICIPANT	\N	PRESENT	0
785134	783385	14069U	PARTICIPANT	\N	PRESENT	0
785135	783385	20172F	PARTICIPANT	\N	PRESENT	0
785136	783385	07029T	PARTICIPANT	\N	PRESENT	0
785137	783385	14026U	PARTICIPANT	\N	PRESENT	0
785138	783385	20070A	PARTICIPANT	\N	PRESENT	0
785139	783385	20038A	PARTICIPANT	\N	PRESENT	0
785318	783403	19719D	PARTICIPANT	\N	EXCUSE	0
785319	783403	14189C	PARTICIPANT	\N	EXCUSE	0
785494	785493	19691J	PARTICIPANT	\N	PRESENT	0
785498	785493	20130U	PARTICIPANT	\N	PRESENT	0
785501	785493	19703U	PARTICIPANT	\N	PRESENT	0
786067	783405	19719D	PARTICIPANT	\N	EXCUSE	0
786068	783405	14189C	PARTICIPANT	\N	EXCUSE	0
786202	786201	20040T	PARTICIPANT	\N	PRESENT	0
786096	783371	20100N	PARTICIPANT	\N	PRESENT	0
786097	783371	14331P	PRESIDENT	0	PRESENT	0
786098	783371	14133K	PARTICIPANT	\N	PRESENT	0
786099	783371	08034U	PARTICIPANT	\N	PRESENT	0
786100	783371	10015M	PARTICIPANT	\N	PRESENT	0
786101	783371	20286Q	PARTICIPANT	\N	PRESENT	0
786102	783371	20094J	PARTICIPANT	\N	PRESENT	0
786103	783371	21037D	PARTICIPANT	\N	PRESENT	0
786104	783371	14169X	PARTICIPANT	\N	PRESENT	0
786105	783371	14073Q	PARTICIPANT	\N	EXCUSE	0
786106	783371	14189C	PARTICIPANT	\N	EXCUSE	0
786205	786203	08010L	PARTICIPANT	\N	PRESENT	0
786108	783371	20106U	PARTICIPANT	\N	EXCUSE	0
786204	786203	12028B	PARTICIPANT	\N	PRESENT	0
786246	786245	19569H	PARTICIPANT	\N	PRESENT	0
786248	786247	14189C	PARTICIPANT	\N	PRESENT	0
786249	786247	20024T	PARTICIPANT	\N	PRESENT	0
786250	786247	21043B	PARTICIPANT	\N	PRESENT	0
786251	786247	20086J	PARTICIPANT	\N	PRESENT	0
786252	786247	08060W	PARTICIPANT	\N	PRESENT	0
786253	786247	17737W	PARTICIPANT	\N	PRESENT	0
786254	786247	21063F	PARTICIPANT	\N	PRESENT	0
786255	786247	20090E	PARTICIPANT	\N	PRESENT	0
786256	786247	04042C	PARTICIPANT	\N	PRESENT	0
786257	786247	08028W	PARTICIPANT	\N	PRESENT	0
786258	786247	11115U	PARTICIPANT	\N	PRESENT	0
786259	786247	19693L	PARTICIPANT	\N	PRESENT	0
786260	786247	21074J	PARTICIPANT	\N	PRESENT	0
786261	786247	19673G	PARTICIPANT	\N	PRESENT	0
786262	786247	19647E	PARTICIPANT	\N	PRESENT	0
786263	786247	08018U	PARTICIPANT	\N	PRESENT	0
786264	786247	20120S	PARTICIPANT	\N	PRESENT	0
786265	786247	07004J	PARTICIPANT	\N	PRESENT	0
786266	786247	14123H	PARTICIPANT	\N	PRESENT	0
786267	786247	19691J	PARTICIPANT	\N	PRESENT	0
786268	786247	19569H	PARTICIPANT	\N	PRESENT	0
786269	786247	19685L	PARTICIPANT	\N	PRESENT	0
786270	786247	20056C	PARTICIPANT	\N	PRESENT	0
786271	786247	19531S	PARTICIPANT	\N	PRESENT	0
786272	786247	14021P	PARTICIPANT	\N	PRESENT	0
786273	786247	99004R	PARTICIPANT	\N	PRESENT	0
786274	786247	14073Q	PARTICIPANT	\N	PRESENT	0
786275	786247	19611R	PARTICIPANT	\N	PRESENT	0
786276	786247	19826F	PARTICIPANT	\N	PRESENT	0
786277	786247	20252E	PARTICIPANT	\N	PRESENT	0
786278	786247	21037D	PARTICIPANT	\N	PRESENT	0
786279	786247	14055N	PARTICIPANT	\N	PRESENT	0
786280	786247	10015M	PARTICIPANT	\N	PRESENT	0
786281	786247	21070E	PARTICIPANT	\N	PRESENT	0
786282	786247	21064G	PARTICIPANT	\N	PRESENT	0
786283	786247	19421M	PARTICIPANT	\N	PRESENT	0
786284	786247	21095P	PARTICIPANT	\N	PRESENT	0
786285	786247	21061D	PARTICIPANT	\N	PRESENT	0
786286	786247	19749K	PARTICIPANT	\N	PRESENT	0
786287	786247	20122U	PARTICIPANT	\N	PRESENT	0
786288	786247	21082J	PARTICIPANT	\N	PRESENT	0
786289	786247	86034E	PARTICIPANT	\N	PRESENT	0
786393	786381	11045K	PARTICIPANT	\N	PRESENT	0
786394	786382	11045K	PARTICIPANT	\N	PRESENT	0
786395	786383	11045K	PARTICIPANT	\N	PRESENT	0
786402	786399	21089R	PARTICIPANT	\N	PRESENT	0
786403	786399	19533U	PARTICIPANT	\N	PRESENT	0
786404	786370	19691J	PARTICIPANT	\N	PRESENT	1
786405	786370	19703U	PARTICIPANT	\N	PRESENT	1
786406	786370	14281W	PARTICIPANT	\N	PRESENT	0
786407	786370	20130U	PARTICIPANT	\N	PRESENT	1
786408	786371	14026U	PARTICIPANT	\N	PRESENT	0
786409	786371	19703U	PARTICIPANT	\N	PRESENT	0
786410	786371	20130U	PARTICIPANT	\N	PRESENT	0
786411	786371	14281W	PARTICIPANT	\N	PRESENT	0
786412	786371	19758L	PARTICIPANT	\N	PRESENT	0
786413	786372	19691J	PARTICIPANT	\N	PRESENT	0
786414	786372	19703U	PARTICIPANT	\N	PRESENT	0
786415	786372	20130U	PARTICIPANT	\N	PRESENT	0
786416	786373	19703U	PARTICIPANT	\N	PRESENT	0
786417	786373	19691J	PARTICIPANT	\N	PRESENT	0
786418	786373	20130U	PARTICIPANT	\N	PRESENT	0
786419	786378	19703U	PARTICIPANT	\N	PRESENT	0
786420	786378	18193Q	PARTICIPANT	\N	PRESENT	1
786424	786379	19703U	PARTICIPANT	\N	PRESENT	1
786422	786378	19758L	PARTICIPANT	\N	PRESENT	1
786423	786378	14223L	PARTICIPANT	\N	PRESENT	1
786425	786379	19758L	PARTICIPANT	\N	PRESENT	0
786426	786379	18193Q	PARTICIPANT	\N	PRESENT	1
786437	786436	20026V	PARTICIPANT	\N	PRESENT	1
786438	786436	21063F	PARTICIPANT	\N	PRESENT	1
786439	786436	20172F	PARTICIPANT	\N	PRESENT	1
786440	786436	14030Q	PARTICIPANT	\N	PRESENT	1
786441	786436	20180F	PARTICIPANT	\N	PRESENT	1
786443	786442	20026V	PARTICIPANT	\N	PRESENT	1
786444	786442	21063F	PARTICIPANT	\N	PRESENT	1
786445	786442	20132W	PARTICIPANT	\N	PRESENT	1
786446	786442	14030Q	PARTICIPANT	\N	PRESENT	1
786447	786442	14109K	PARTICIPANT	\N	PRESENT	1
786448	786442	20180F	PARTICIPANT	\N	PRESENT	1
786516	786514	21064G	PARTICIPANT	\N	PRESENT	0
786517	786515	21064G	PARTICIPANT	\N	PRESENT	0
786521	786380	19691J	PARTICIPANT	\N	PRESENT	0
786522	786380	19703U	PARTICIPANT	\N	PRESENT	0
786523	786380	20130U	PARTICIPANT	\N	PRESENT	0
786556	786550	21064G	PARTICIPANT	\N	PRESENT	0
786557	786551	21064G	PARTICIPANT	\N	PRESENT	0
786558	786552	21064G	PARTICIPANT	\N	PRESENT	0
786576	786553	21064G	PARTICIPANT	\N	PRESENT	0
786585	786554	21064G	PARTICIPANT	\N	PRESENT	0
786586	786555	21064G	PARTICIPANT	\N	PRESENT	0
786715	786177	21055F	PARTICIPANT	\N	EXCUSE	0
786716	786176	21055F	PARTICIPANT	\N	EXCUSE	0
787016	787015	14073Q	PARTICIPANT	\N	PRESENT	0
787017	787015	20142Y	PARTICIPANT	\N	PRESENT	0
787018	787015	08012N	PARTICIPANT	\N	PRESENT	0
787210	787200	20086J	PARTICIPANT	\N	PRESENT	0
787211	787200	14331P	PARTICIPANT	\N	PRESENT	0
787212	787200	20134Y	PARTICIPANT	\N	PRESENT	0
787213	787200	11048N	PARTICIPANT	\N	PRESENT	0
787214	787200	19711U	PARTICIPANT	\N	PRESENT	0
787215	787200	11074Q	PARTICIPANT	\N	PRESENT	0
787216	787200	20044X	PARTICIPANT	\N	PRESENT	0
787217	787200	19399H	PARTICIPANT	\N	PRESENT	0
787218	787200	11070L	PARTICIPANT	\N	PRESENT	0
787219	787200	14083S	PARTICIPANT	\N	PRESENT	0
787221	787200	07004J	PARTICIPANT	\N	PRESENT	0
787222	787200	21069M	PARTICIPANT	\N	PRESENT	0
787223	787200	19349W	PARTICIPANT	\N	PRESENT	0
787224	787200	14121F	PARTICIPANT	\N	PRESENT	0
787225	787200	21090J	PARTICIPANT	\N	PRESENT	0
787226	787200	20024T	PARTICIPANT	\N	PRESENT	0
787227	787200	20126Y	PARTICIPANT	\N	PRESENT	0
787228	787200	11040E	PARTICIPANT	\N	EXCUSE	0
787229	787200	21048G	PARTICIPANT	\N	EXCUSE	0
787231	787200	14225N	PRESIDENT	0	PRESENT	0
787232	787200	07029T	PARTICIPANT	\N	PRESENT	0
787233	787200	14253S	PARTICIPANT	\N	PRESENT	0
787245	787200	19545Y	PARTICIPANT	\N	PRESENT	0
787246	787200	21072G	PARTICIPANT	\N	PRESENT	0
787248	787200	21079P	PARTICIPANT	\N	PRESENT	0
787250	787200	19667J	PARTICIPANT	\N	PRESENT	0
768249	765176	20114U	PARTICIPANT	\N	PRESENT	0
768250	765176	19111A	PARTICIPANT	\N	PRESENT	0
768251	765176	19593H	PARTICIPANT	\N	PRESENT	0
768252	765176	04047H	PRESIDENT	0	PRESENT	0
768253	765176	19611R	PARTICIPANT	\N	PRESENT	0
768254	765176	19533U	PARTICIPANT	\N	PRESENT	0
768256	765176	20172F	PARTICIPANT	\N	PRESENT	0
768258	765176	14053L	PARTICIPANT	\N	PRESENT	0
768323	765176	20048C	PARTICIPANT	\N	PRESENT	0
768307	765176	20264J	PARTICIPANT	\N	PRESENT	0
768308	765176	20142Y	PARTICIPANT	\N	PRESENT	0
768309	765176	19735D	PARTICIPANT	\N	PRESENT	0
768310	765176	19673G	PARTICIPANT	\N	PRESENT	0
768312	765176	20132W	PARTICIPANT	\N	PRESENT	0
768314	765176	20102Q	PARTICIPANT	\N	PRESENT	0
768315	765176	14111D	PARTICIPANT	\N	PRESENT	0
768316	765176	19697Q	PARTICIPANT	\N	PRESENT	0
768319	765176	20026V	PARTICIPANT	\N	PRESENT	0
768333	765176	14231L	PARTICIPANT	\N	PRESENT	0
768346	765176	14147R	PARTICIPANT	\N	PRESENT	0
768454	765176	20022R	PARTICIPANT	\N	EXCUSE	0
768455	765176	14215L	PARTICIPANT	\N	EXCUSE	0
768456	765176	20108W	PARTICIPANT	\N	EXCUSE	0
768457	765176	11072N	PARTICIPANT	\N	EXCUSE	0
768458	765176	04045F	PARTICIPANT	\N	EXCUSE	0
768459	765176	21076L	PARTICIPANT	\N	EXCUSE	0
768460	765176	19729F	PARTICIPANT	\N	EXCUSE	0
777014	777013	14267Y	PARTICIPANT	\N	PRESENT	0
777015	777013	08010L	PARTICIPANT	\N	PRESENT	0
777032	776115	14219Q	PARTICIPANT	\N	EXCUSE	0
777040	769250	19713W	PARTICIPANT	\N	PRESENT	0
778818	775974	21057H	PARTICIPANT	\N	EXCUSE	0
781265	779087	20016T	PARTICIPANT	\N	PRESENT	0
781266	779087	20034V	PRESIDENT	0	PRESENT	0
781267	779087	21029D	PARTICIPANT	\N	EXCUSE	0
781268	779087	19673G	PARTICIPANT	\N	EXCUSE	0
781270	779087	21034A	PARTICIPANT	\N	EXCUSE	0
781271	779087	21097R	PARTICIPANT	\N	PRESENT	0
781272	779087	21055F	PARTICIPANT	\N	PRESENT	0
781274	779087	19331L	PARTICIPANT	\N	PRESENT	0
781275	779087	21073H	PARTICIPANT	\N	PRESENT	0
781277	779087	20150Y	PARTICIPANT	\N	PRESENT	0
781289	779087	08073C	PARTICIPANT	\N	PRESENT	0
781290	779087	12016W	PARTICIPANT	\N	PRESENT	0
781291	779087	21030V	PARTICIPANT	\N	PRESENT	0
781292	779087	19631V	PARTICIPANT	\N	PRESENT	0
781293	779087	05008E	PARTICIPANT	\N	PRESENT	0
781294	779087	18083K	PARTICIPANT	\N	PRESENT	0
781295	779087	19669L	PARTICIPANT	\N	PRESENT	0
781296	779087	19691J	PARTICIPANT	\N	EXCUSE	0
781297	779088	19691J	PARTICIPANT	\N	EXCUSE	0
781298	779088	21034A	PARTICIPANT	\N	EXCUSE	0
781313	779087	19745F	PARTICIPANT	\N	PRESENT	0
783459	783363	20090E	PARTICIPANT	\N	EXCUSE	0
783461	783363	21064G	PARTICIPANT	\N	EXCUSE	0
783499	783497	19611R	PARTICIPANT	\N	PRESENT	0
783500	783497	21091K	PARTICIPANT	\N	PRESENT	1
783501	783497	21089R	PARTICIPANT	\N	PRESENT	1
783502	783497	19621T	PARTICIPANT	\N	PRESENT	0
783503	783497	19693L	PARTICIPANT	\N	PRESENT	1
783504	783498	19621T	PARTICIPANT	\N	PRESENT	0
783505	783498	21089R	PARTICIPANT	\N	PRESENT	1
783506	783498	21091K	PARTICIPANT	\N	PRESENT	1
783507	783498	19693L	PARTICIPANT	\N	PRESENT	1
783508	783498	19611R	PARTICIPANT	\N	PRESENT	0
783522	783521	14053L	PARTICIPANT	\N	PRESENT	0
783523	783521	19649G	PARTICIPANT	\N	PRESENT	0
783577	783575	12028B	PARTICIPANT	\N	PRESENT	0
783578	783575	14267Y	PARTICIPANT	\N	PRESENT	0
783579	783575	08010L	PARTICIPANT	\N	PRESENT	0
785938	783405	14147R	PARTICIPANT	\N	PRESENT	0
785947	783405	14259Y	PARTICIPANT	\N	PRESENT	0
786307	786306	14038Y	PARTICIPANT	\N	PRESENT	0
786308	786306	14033T	PARTICIPANT	\N	PRESENT	0
786310	786309	14038Y	PARTICIPANT	\N	PRESENT	0
786311	786309	14033T	PARTICIPANT	\N	PRESENT	0
786338	786337	14021P	PARTICIPANT	\N	PRESENT	0
786339	786337	86034E	PARTICIPANT	\N	PRESENT	0
786340	786337	21094N	PARTICIPANT	\N	PRESENT	0
786341	786337	18207D	PARTICIPANT	\N	PRESENT	0
786342	786337	19111A	PARTICIPANT	\N	PRESENT	0
786343	786337	21095P	PARTICIPANT	\N	PRESENT	0
777003	777002	14253S	PARTICIPANT	\N	PRESENT	0
787321	787257	19782L	PARTICIPANT	\N	PRESENT	0
787322	787257	19251M	PARTICIPANT	\N	PRESENT	0
787323	787257	14215L	PARTICIPANT	\N	PRESENT	0
787324	787257	19673G	PARTICIPANT	\N	PRESENT	0
787325	787257	19647E	PARTICIPANT	\N	PRESENT	0
787326	787257	19111A	PARTICIPANT	\N	PRESENT	0
787327	787257	04070G	PARTICIPANT	\N	PRESENT	0
787328	787257	19593H	PARTICIPANT	\N	PRESENT	0
787329	787257	20118Y	PARTICIPANT	\N	PRESENT	0
787330	787257	04033B	PARTICIPANT	\N	PRESENT	0
787333	787257	14021P	PARTICIPANT	\N	PRESENT	0
787334	787257	21089R	PARTICIPANT	\N	PRESENT	0
787335	787257	20110Q	PARTICIPANT	\N	PRESENT	0
787336	787257	21073H	PARTICIPANT	\N	PRESENT	0
787869	786619	20116W	PARTICIPANT	\N	PRESENT	0
787870	786619	20032T	PARTICIPANT	\N	PRESENT	0
787871	786619	14207L	PARTICIPANT	\N	PRESENT	0
787872	786619	19629C	PARTICIPANT	\N	PRESENT	0
787873	786619	14331P	PARTICIPANT	\N	PRESENT	0
787874	786619	20118Y	PARTICIPANT	\N	PRESENT	0
787875	786619	20132W	PARTICIPANT	\N	PRESENT	0
787876	786619	19387D	PARTICIPANT	\N	PRESENT	0
787877	786619	19533U	PARTICIPANT	\N	PRESENT	0
787878	786619	21066J	PARTICIPANT	\N	PRESENT	0
787879	786619	19798U	PARTICIPANT	\N	PRESENT	0
787880	786619	20120S	PARTICIPANT	\N	PRESENT	0
787881	786619	21090J	PARTICIPANT	\N	PRESENT	0
787882	786619	21040X	PARTICIPANT	\N	PRESENT	0
787883	786619	19553Y	PARTICIPANT	\N	PRESENT	0
787884	786619	14193X	PARTICIPANT	\N	PRESENT	0
787885	786619	14195A	PARTICIPANT	\N	PRESENT	0
787886	786619	21095P	PARTICIPANT	\N	PRESENT	0
787887	786619	07033P	PARTICIPANT	\N	PRESENT	0
787893	786619	14055N	PARTICIPANT	\N	PRESENT	0
787896	786619	19551W	PARTICIPANT	\N	PRESENT	0
787897	786619	19545Y	PARTICIPANT	\N	PRESENT	0
787898	786619	20180F	PARTICIPANT	\N	PRESENT	0
787899	786619	21065H	PARTICIPANT	\N	PRESENT	0
787902	786619	21087P	PARTICIPANT	\N	PRESENT	0
787903	786619	21054E	PARTICIPANT	\N	PRESENT	0
787906	786619	14251Q	PARTICIPANT	\N	PRESENT	0
787908	786619	21070E	PARTICIPANT	\N	PRESENT	0
787910	786619	21076L	PARTICIPANT	\N	PRESENT	0
787912	786619	21045D	PARTICIPANT	\N	PRESENT	0
787915	786619	20070A	PARTICIPANT	\N	PRESENT	0
787919	786619	19251M	PARTICIPANT	\N	PRESENT	0
787921	786619	14151M	PARTICIPANT	\N	PRESENT	0
787922	786619	11074Q	PARTICIPANT	\N	PRESENT	0
787926	786619	21062E	PARTICIPANT	\N	PRESENT	0
787929	786619	21060C	PARTICIPANT	\N	PRESENT	0
787930	786619	14281W	PARTICIPANT	\N	PRESENT	0
778661	776552	17965H	PARTICIPANT	\N	PRESENT	0
778662	776552	14267Y	PARTICIPANT	\N	PRESENT	0
778663	776552	21046E	PARTICIPANT	\N	PRESENT	0
778664	776552	11053K	PARTICIPANT	\N	PRESENT	0
778665	776552	19057M	PARTICIPANT	\N	PRESENT	0
778675	776552	14026U	PARTICIPANT	\N	PRESENT	0
778684	776552	20092G	PARTICIPANT	\N	PRESENT	0
778690	776552	19551W	PARTICIPANT	\N	PRESENT	0
778691	776552	20042V	PARTICIPANT	\N	PRESENT	0
778692	776552	20142Y	PARTICIPANT	\N	PRESENT	0
778694	778693	19711U	PARTICIPANT	\N	PRESENT	0
778695	778693	20094J	PARTICIPANT	\N	PRESENT	0
778696	776552	21072G	PARTICIPANT	\N	PRESENT	0
778697	776552	14357A	PARTICIPANT	\N	PRESENT	0
778698	776552	20096L	PARTICIPANT	\N	PRESENT	0
778700	776552	21061D	PARTICIPANT	\N	PRESENT	0
778758	776554	14229S	PARTICIPANT	\N	PRESENT	0
778702	776552	14213J	PARTICIPANT	\N	PRESENT	0
778777	776554	11056N	PARTICIPANT	\N	PRESENT	0
778778	776554	14225N	PARTICIPANT	\N	PRESENT	0
778779	776554	19629C	PARTICIPANT	\N	PRESENT	0
778780	776554	04045F	PARTICIPANT	\N	PRESENT	0
778781	776554	19489J	PARTICIPANT	\N	PRESENT	0
778782	776554	14069U	PARTICIPANT	\N	PRESENT	0
778783	776554	21087P	PARTICIPANT	\N	PRESENT	0
778784	776554	14189C	PARTICIPANT	\N	PRESENT	0
778785	776554	20036X	PARTICIPANT	\N	PRESENT	0
778786	776554	21088Q	PARTICIPANT	\N	PRESENT	0
778787	776554	20084G	PARTICIPANT	\N	PRESENT	0
778788	776554	14109K	PARTICIPANT	\N	PRESENT	0
778789	776554	19782L	PARTICIPANT	\N	PRESENT	0
778790	776554	21055F	PARTICIPANT	\N	PRESENT	0
778791	776554	21029D	PARTICIPANT	\N	PRESENT	0
778792	776554	21046E	PARTICIPANT	\N	PRESENT	0
778793	776554	20072C	PARTICIPANT	\N	PRESENT	0
778794	776554	04033B	PARTICIPANT	\N	PRESENT	0
778795	776554	20090E	PARTICIPANT	\N	PRESENT	0
778796	776554	21081H	PARTICIPANT	\N	PRESENT	0
778797	776554	19611R	PARTICIPANT	\N	PRESENT	0
778798	776554	07029T	PARTICIPANT	\N	PRESENT	0
778799	776554	20070A	PARTICIPANT	\N	PRESENT	0
778800	776554	21071F	PARTICIPANT	\N	PRESENT	0
778801	776554	14033T	PARTICIPANT	\N	PRESENT	0
778802	776554	20080C	PARTICIPANT	\N	PRESENT	0
778803	776554	14021P	PARTICIPANT	\N	PRESENT	0
778804	776554	14231L	PARTICIPANT	\N	PRESENT	0
778805	776554	20062A	PARTICIPANT	\N	PRESENT	0
778806	776554	20054A	PARTICIPANT	\N	PRESENT	0
778807	776554	20076G	PARTICIPANT	\N	PRESENT	0
778808	776554	18395Y	PARTICIPANT	\N	PRESENT	0
778809	776554	19531S	PARTICIPANT	\N	PRESENT	0
778810	776554	08010L	PARTICIPANT	\N	PRESENT	0
778811	776554	20266L	PARTICIPANT	\N	PRESENT	0
778812	776554	21048G	PARTICIPANT	\N	PRESENT	0
778813	776554	20038A	PARTICIPANT	\N	PRESENT	0
778814	776554	21063F	PARTICIPANT	\N	PRESENT	0
778815	776554	19507S	PARTICIPANT	\N	PRESENT	0
778816	776554	14253S	PARTICIPANT	\N	PRESENT	0
778817	776554	18083K	PARTICIPANT	\N	PRESENT	0
780476	780474	86034E	PARTICIPANT	\N	PRESENT	0
780496	780474	19621T	PARTICIPANT	\N	PRESENT	0
780497	780474	04008A	PARTICIPANT	\N	PRESENT	0
780498	780474	19367Y	PARTICIPANT	\N	PRESENT	0
780499	780474	08011M	PARTICIPANT	\N	PRESENT	0
780500	780474	19673G	PARTICIPANT	\N	PRESENT	0
780501	780474	21091K	PARTICIPANT	\N	PRESENT	0
780502	780474	19575F	PARTICIPANT	\N	PRESENT	0
780503	780474	01058X	PARTICIPANT	\N	PRESENT	0
780504	780474	99004R	PARTICIPANT	\N	PRESENT	0
780505	780474	20076G	PARTICIPANT	\N	PRESENT	0
780506	780474	20074E	PARTICIPANT	\N	PRESENT	0
780507	780474	08069G	PARTICIPANT	\N	PRESENT	0
780508	780474	21044C	PARTICIPANT	\N	PRESENT	0
778776	776554	20094J	PARTICIPANT	\N	PRESENT	0
780509	780474	21080G	PARTICIPANT	\N	PRESENT	0
780510	780474	10015M	PARTICIPANT	\N	PRESENT	0
780511	780474	14223L	PARTICIPANT	\N	PRESENT	0
780512	780474	08028W	PARTICIPANT	\N	PRESENT	0
780513	780474	21071F	PARTICIPANT	\N	PRESENT	0
780514	780474	14191V	PARTICIPANT	\N	PRESENT	0
780515	780474	21072G	PARTICIPANT	\N	PRESENT	0
780516	780474	20044X	PARTICIPANT	\N	PRESENT	0
780517	780474	20022R	PARTICIPANT	\N	PRESENT	0
780518	780474	11090Q	PARTICIPANT	\N	PRESENT	0
780519	780474	21055F	PARTICIPANT	\N	PRESENT	0
780520	780474	21029D	PARTICIPANT	\N	PRESENT	0
780521	780474	14031R	PARTICIPANT	\N	PRESENT	0
780522	780474	19667J	PARTICIPANT	\N	PRESENT	0
780523	780474	20136B	PARTICIPANT	\N	PRESENT	0
780524	780474	14123H	PARTICIPANT	\N	PRESENT	0
780525	780474	17737W	PARTICIPANT	\N	PRESENT	0
780526	780474	20032T	PARTICIPANT	\N	PRESENT	0
780527	780474	14331P	PARTICIPANT	\N	PRESENT	0
780528	780474	11040E	PARTICIPANT	\N	PRESENT	0
780529	780474	21088Q	PARTICIPANT	\N	PRESENT	0
780530	780474	21034A	PARTICIPANT	\N	PRESENT	0
780531	780474	11056N	PARTICIPANT	\N	PRESENT	0
780532	780474	19447X	PARTICIPANT	\N	PRESENT	0
780533	780474	19695N	PARTICIPANT	\N	PRESENT	0
780534	780474	19565D	PARTICIPANT	\N	PRESENT	0
780535	780474	21068L	PARTICIPANT	\N	PRESENT	0
780536	780474	21058J	PARTICIPANT	\N	PRESENT	0
780537	780474	20096L	PARTICIPANT	\N	PRESENT	0
780538	780474	20180F	PARTICIPANT	\N	PRESENT	0
780539	780474	20026V	PARTICIPANT	\N	PRESENT	0
780540	780474	19954N	PARTICIPANT	\N	PRESENT	0
780541	780474	21049H	PARTICIPANT	\N	PRESENT	0
780542	780474	21030V	PARTICIPANT	\N	PRESENT	0
780543	780474	20046A	PARTICIPANT	\N	PRESENT	0
780544	780474	21084L	PARTICIPANT	\N	PRESENT	0
780545	780474	21081H	PARTICIPANT	\N	PRESENT	0
780546	780474	21075K	PARTICIPANT	\N	PRESENT	0
780547	780474	08047A	PARTICIPANT	\N	PRESENT	0
780548	780474	20102Q	PARTICIPANT	\N	PRESENT	0
780549	780474	20172F	PARTICIPANT	\N	PRESENT	0
780550	780474	20110Q	PARTICIPANT	\N	PRESENT	0
780551	780474	21048G	PARTICIPANT	\N	PRESENT	0
780552	780474	19347U	PARTICIPANT	\N	PRESENT	0
780553	780474	21073H	PARTICIPANT	\N	PRESENT	0
780554	780474	21037D	PARTICIPANT	\N	PRESENT	0
780555	780474	20036X	PARTICIPANT	\N	PRESENT	0
780556	780474	21043B	PARTICIPANT	\N	PRESENT	0
780557	780474	21096Q	PARTICIPANT	\N	PRESENT	0
780558	780474	14147R	PARTICIPANT	\N	PRESENT	0
780559	780474	20128B	PARTICIPANT	\N	PRESENT	0
780560	780474	19782L	PARTICIPANT	\N	PRESENT	0
780561	780474	14038Y	PARTICIPANT	\N	PRESENT	0
780562	780474	19591F	PARTICIPANT	\N	PRESENT	0
780563	780474	21033Y	PARTICIPANT	\N	PRESENT	0
780564	780474	19723Y	PARTICIPANT	\N	PRESENT	0
780565	780474	19697Q	PARTICIPANT	\N	PRESENT	0
780566	780474	20140W	PARTICIPANT	\N	PRESENT	0
780567	780474	20038A	PARTICIPANT	\N	PRESENT	0
780568	780474	21097R	PARTICIPANT	\N	PRESENT	0
780569	780474	19331L	PARTICIPANT	\N	PRESENT	0
780570	780474	21039F	PARTICIPANT	\N	PRESENT	0
780571	780474	08073C	PARTICIPANT	\N	PRESENT	0
780572	780474	08061X	PARTICIPANT	\N	PRESENT	0
780573	780474	20056C	PARTICIPANT	\N	PRESENT	0
780574	780474	20146D	PARTICIPANT	\N	PRESENT	0
780575	780474	20148F	PARTICIPANT	\N	PRESENT	0
780576	780474	14329V	PARTICIPANT	\N	PRESENT	0
780577	780474	19349W	PARTICIPANT	\N	PRESENT	0
780578	780474	20150Y	PARTICIPANT	\N	PRESENT	0
780579	780474	04045F	PARTICIPANT	\N	PRESENT	0
780580	780474	21063F	PARTICIPANT	\N	PRESENT	0
780581	780474	19301E	PARTICIPANT	\N	PRESENT	0
780582	780474	20068G	PARTICIPANT	\N	PRESENT	0
780583	780474	14055N	PARTICIPANT	\N	PRESENT	0
780584	780474	21074J	PARTICIPANT	\N	PRESENT	0
780585	780474	07029T	PARTICIPANT	\N	PRESENT	0
780586	780474	19657G	PARTICIPANT	\N	PRESENT	0
780587	780474	19729F	PARTICIPANT	\N	PRESENT	0
780588	780474	14059S	PARTICIPANT	\N	PRESENT	0
780589	780474	20116W	PARTICIPANT	\N	PRESENT	0
780590	780474	14207L	PARTICIPANT	\N	PRESENT	0
780591	780474	14213J	PARTICIPANT	\N	PRESENT	0
780592	780474	20124W	PARTICIPANT	\N	PRESENT	0
780593	780474	20126Y	PARTICIPANT	\N	PRESENT	0
780594	780474	08018U	PARTICIPANT	\N	PRESENT	0
780595	780474	19687N	PARTICIPANT	\N	PRESENT	0
775584	775581	14147R	PARTICIPANT	\N	PRESENT	0
775585	775581	20098N	PARTICIPANT	\N	PRESENT	0
775590	775586	14147R	PARTICIPANT	\N	PRESENT	0
775591	775586	19749K	PARTICIPANT	\N	PRESENT	0
775592	775586	20098N	PARTICIPANT	\N	PRESENT	0
775595	775593	20098N	PARTICIPANT	\N	PRESENT	0
775596	775593	14147R	PARTICIPANT	\N	PRESENT	0
775598	775597	14147R	PARTICIPANT	\N	PRESENT	0
775601	775600	14147R	PARTICIPANT	\N	PRESENT	0
775602	775600	19749K	PARTICIPANT	\N	PRESENT	0
775603	775600	20098N	PARTICIPANT	\N	PRESENT	0
775605	775604	14147R	PARTICIPANT	\N	PRESENT	0
778934	778933	08034U	PARTICIPANT	\N	PRESENT	0
778935	778933	99004R	PARTICIPANT	\N	PRESENT	0
778936	778933	21086N	PARTICIPANT	\N	PRESENT	0
778937	778933	19545Y	PARTICIPANT	\N	PRESENT	0
778938	778933	21079P	PARTICIPANT	\N	PRESENT	0
778940	778933	14121F	PARTICIPANT	\N	PRESENT	0
778941	778933	11070L	PARTICIPANT	\N	PRESENT	0
778943	778933	05012A	PARTICIPANT	\N	PRESENT	0
778959	775975	14231L	PRESIDENT	0	PRESENT	0
778961	775975	21070E	PARTICIPANT	\N	PRESENT	0
778962	775975	19489J	PARTICIPANT	\N	PRESENT	0
778963	775975	19758L	PARTICIPANT	\N	PRESENT	0
778964	775975	20102Q	PARTICIPANT	\N	PRESENT	0
778965	775975	08012N	PARTICIPANT	\N	PRESENT	0
778966	775975	14151M	PARTICIPANT	\N	PRESENT	0
778967	775975	20084G	PARTICIPANT	\N	PRESENT	0
778968	775975	21068L	PARTICIPANT	\N	PRESENT	0
778969	775975	19531S	PARTICIPANT	\N	PRESENT	0
778970	775975	20058E	PARTICIPANT	\N	PRESENT	0
778971	775975	19782L	PARTICIPANT	\N	PRESENT	0
778972	775975	19447X	PARTICIPANT	\N	PRESENT	0
778973	775975	14069U	PARTICIPANT	\N	PRESENT	0
778974	775975	21065H	PARTICIPANT	\N	PRESENT	0
778975	775975	19335Q	PARTICIPANT	\N	PRESENT	0
778976	775975	19573D	PARTICIPANT	\N	PRESENT	0
778977	775975	21048G	PARTICIPANT	\N	PRESENT	0
778978	775975	14026U	PARTICIPANT	\N	PRESENT	0
778979	775975	21079P	PARTICIPANT	\N	PRESENT	0
778980	775975	19349W	PARTICIPANT	\N	PRESENT	0
778981	775975	20032T	PARTICIPANT	\N	PRESENT	0
778982	775975	20090E	PARTICIPANT	\N	PRESENT	0
778983	775975	14215L	PARTICIPANT	\N	PRESENT	0
778984	775975	05012A	PARTICIPANT	\N	PRESENT	0
778985	775975	04045F	PARTICIPANT	\N	PRESENT	0
778986	775975	01034P	PARTICIPANT	\N	PRESENT	0
778987	775975	19735D	PARTICIPANT	\N	PRESENT	0
778988	775975	19826F	PARTICIPANT	\N	PRESENT	0
778989	775975	20022R	PARTICIPANT	\N	PRESENT	0
778990	775975	19866P	PARTICIPANT	\N	PRESENT	0
778991	775975	14053L	PARTICIPANT	\N	PRESENT	0
778992	775975	19621T	PARTICIPANT	\N	EXCUSE	0
778993	775975	14281W	PARTICIPANT	\N	EXCUSE	0
778994	775975	19820Y	PARTICIPANT	\N	EXCUSE	0
778995	775975	20068G	PARTICIPANT	\N	EXCUSE	0
780450	779647	14215L	PARTICIPANT	\N	PRESENT	0
780451	779647	19573D	PARTICIPANT	\N	PRESENT	0
780452	779647	20128B	PARTICIPANT	\N	PRESENT	0
780453	779647	20180F	PARTICIPANT	\N	PRESENT	0
780454	779647	19531S	PARTICIPANT	\N	PRESENT	0
780448	779647	21045D	PARTICIPANT	\N	PRESENT	0
780449	779647	20094J	PARTICIPANT	\N	PRESENT	0
780455	779647	21056G	PARTICIPANT	\N	PRESENT	0
780456	779647	20062A	PARTICIPANT	\N	PRESENT	0
780457	779647	95041E	PARTICIPANT	\N	PRESENT	0
780458	779647	14331P	PARTICIPANT	\N	PRESENT	0
780459	779647	19545Y	PARTICIPANT	\N	PRESENT	0
780460	779647	20136B	PARTICIPANT	\N	PRESENT	0
780461	779647	14083S	PARTICIPANT	\N	PRESENT	0
781239	779650	14083S	PARTICIPANT	\N	PRESENT	0
781240	779650	19545Y	PARTICIPANT	\N	PRESENT	0
782582	782581	19758L	PARTICIPANT	\N	PRESENT	0
782583	782581	14195A	PARTICIPANT	\N	PRESENT	0
782584	782581	20130U	PARTICIPANT	\N	PRESENT	0
782585	782581	14071N	PARTICIPANT	\N	PRESENT	0
782586	782581	18193Q	PARTICIPANT	\N	PRESENT	0
782587	782581	19691J	PARTICIPANT	\N	PRESENT	0
782588	782581	19703U	PARTICIPANT	\N	PRESENT	0
783130	783129	14030Q	PARTICIPANT	\N	PRESENT	0
783131	783129	19057M	PARTICIPANT	\N	PRESENT	0
783132	783129	19673G	PARTICIPANT	\N	PRESENT	0
783133	783129	14147R	PARTICIPANT	\N	PRESENT	0
783406	783401	20090E	PARTICIPANT	\N	EXCUSE	0
783782	783372	20062A	PARTICIPANT	\N	PRESENT	0
783783	783372	21029D	PARTICIPANT	\N	PRESENT	0
783784	783372	19713W	PARTICIPANT	\N	PRESENT	0
783785	783372	19553Y	PARTICIPANT	\N	PRESENT	0
783786	783372	14030Q	PARTICIPANT	\N	PRESENT	0
783787	783372	14083S	PARTICIPANT	\N	PRESENT	0
783788	783372	20090E	PARTICIPANT	\N	PRESENT	0
783789	783372	14069U	PARTICIPANT	\N	PRESENT	0
783790	783372	19347U	PARTICIPANT	\N	PRESENT	0
783791	783372	21058J	PARTICIPANT	\N	PRESENT	0
783792	783372	07004J	PARTICIPANT	\N	PRESENT	0
783793	783372	21068L	PARTICIPANT	\N	PRESENT	0
783794	783372	19758L	PARTICIPANT	\N	PRESENT	0
783795	783372	21082J	PARTICIPANT	\N	PRESENT	0
783796	783372	20024T	PARTICIPANT	\N	PRESENT	0
783797	783372	14053L	PARTICIPANT	\N	PRESENT	0
783798	783372	21037D	PARTICIPANT	\N	PRESENT	0
783814	783372	20098N	PARTICIPANT	\N	PRESENT	0
783800	783372	11065P	PARTICIPANT	\N	PRESENT	0
783801	783372	14147R	PARTICIPANT	\N	PRESENT	0
783802	783372	07033P	PARTICIPANT	\N	PRESENT	0
783816	783372	17965H	PARTICIPANT	\N	PRESENT	0
783817	783372	11115U	PARTICIPANT	\N	PRESENT	0
783818	783372	17737W	PARTICIPANT	\N	PRESENT	0
783819	783372	19531S	PARTICIPANT	\N	PRESENT	0
783820	783372	19768N	PARTICIPANT	\N	PRESENT	0
783821	783372	19621T	PARTICIPANT	\N	PRESENT	0
783822	783372	05012A	PARTICIPANT	\N	PRESENT	0
783823	783372	14037X	PARTICIPANT	\N	PRESENT	0
783824	783372	20286Q	PARTICIPANT	\N	PRESENT	0
783825	783372	14207L	PARTICIPANT	\N	PRESENT	0
783826	783372	21075K	PARTICIPANT	\N	PRESENT	0
783827	783372	14001X	PARTICIPANT	\N	PRESENT	0
783828	783372	08012N	PARTICIPANT	\N	PRESENT	0
783829	783372	20136B	PARTICIPANT	\N	PRESENT	0
783830	783372	18193Q	PARTICIPANT	\N	PRESENT	0
783831	783372	20142Y	PARTICIPANT	\N	PRESENT	0
783842	783098	08018U	PARTICIPANT	\N	PRESENT	0
783843	783098	19711U	PARTICIPANT	\N	PRESENT	0
783844	783098	14237S	PARTICIPANT	\N	PRESENT	0
783845	783098	21084L	PARTICIPANT	\N	PRESENT	0
783846	783098	21086N	PARTICIPANT	\N	PRESENT	0
783837	783098	14133K	PRESIDENT	0	PRESENT	0
783838	783098	21052C	PARTICIPANT	\N	EXCUSE	0
783839	783098	19251M	PARTICIPANT	\N	EXCUSE	0
783840	783098	11053K	PARTICIPANT	\N	PRESENT	0
783841	783098	14189C	PARTICIPANT	\N	EXCUSE	0
783847	783098	19575F	PARTICIPANT	\N	PRESENT	0
783848	783098	19826F	PARTICIPANT	\N	PRESENT	0
783849	783098	20286Q	PARTICIPANT	\N	PRESENT	0
783850	783098	14031R	PARTICIPANT	\N	PRESENT	0
783851	783098	20180F	PARTICIPANT	\N	PRESENT	0
783852	783098	11072N	PARTICIPANT	\N	PRESENT	0
783967	783381	14071N	PARTICIPANT	\N	PRESENT	0
783968	783381	14179A	PARTICIPANT	\N	PRESENT	0
783969	783381	18083K	PARTICIPANT	\N	PRESENT	0
783970	783381	10015M	PARTICIPANT	\N	PRESENT	0
783971	783381	20024T	PARTICIPANT	\N	PRESENT	0
783972	783381	14121F	PARTICIPANT	\N	PRESENT	0
783973	783381	14147R	PARTICIPANT	\N	PRESENT	0
783974	783381	05012A	PARTICIPANT	\N	PRESENT	0
783975	783381	14111D	PARTICIPANT	\N	PRESENT	0
783976	783381	19701S	PARTICIPANT	\N	PRESENT	0
783977	783381	19798U	PARTICIPANT	\N	PRESENT	0
783978	783381	20120S	PARTICIPANT	\N	PRESENT	0
783979	783381	14026U	PARTICIPANT	\N	PRESENT	0
783980	783381	21095P	PARTICIPANT	\N	PRESENT	0
783981	783381	21057H	PARTICIPANT	\N	PRESENT	0
783982	783381	20056C	PARTICIPANT	\N	PRESENT	0
783983	783381	05008E	PARTICIPANT	\N	PRESENT	0
783984	783381	21040X	PARTICIPANT	\N	PRESENT	0
783985	783381	20132W	PARTICIPANT	\N	PRESENT	0
783986	783381	21048G	PARTICIPANT	\N	PRESENT	0
783987	783381	20286Q	PARTICIPANT	\N	PRESENT	0
783988	783381	21094N	PARTICIPANT	\N	PRESENT	0
783989	783381	21044C	PARTICIPANT	\N	PRESENT	0
783990	783381	20096L	PARTICIPANT	\N	PRESENT	0
787254	787200	20094J	PARTICIPANT	\N	PRESENT	0
787255	787200	21041Y	PARTICIPANT	\N	PRESENT	0
787256	787200	11053K	PARTICIPANT	\N	PRESENT	0
787258	787242	21036C	PARTICIPANT	\N	PRESENT	0
787259	787242	21031W	PARTICIPANT	\N	PRESENT	0
787260	787242	19565D	PARTICIPANT	\N	PRESENT	0
787261	787242	20072C	PARTICIPANT	\N	PRESENT	0
787262	787242	14001X	PARTICIPANT	\N	PRESENT	0
787613	786180	14331P	PRESIDENT	0	PRESENT	0
787264	787242	17737W	PARTICIPANT	\N	PRESENT	0
787265	787242	19421M	PARTICIPANT	\N	PRESENT	0
787266	787242	19709B	PARTICIPANT	\N	PRESENT	0
787267	787242	21067K	PARTICIPANT	\N	PRESENT	0
787268	787242	14193X	PRESIDENT	0	PRESENT	0
787269	787242	07033P	PARTICIPANT	\N	PRESENT	0
787270	787242	17367Q	PARTICIPANT	\N	PRESENT	0
787271	787242	08047A	PARTICIPANT	\N	PRESENT	0
787272	787242	20128B	PARTICIPANT	\N	PRESENT	0
787273	787242	14059S	PARTICIPANT	\N	PRESENT	0
787274	787242	19531S	PARTICIPANT	\N	PRESENT	0
787275	787242	14133K	PARTICIPANT	\N	PRESENT	0
787276	787242	08069G	PARTICIPANT	\N	PRESENT	0
787277	787242	14191V	PARTICIPANT	\N	PRESENT	0
787278	787242	19721W	PARTICIPANT	\N	PRESENT	0
787279	787242	20064C	PARTICIPANT	\N	PRESENT	0
787280	787242	98022P	PARTICIPANT	\N	PRESENT	0
787281	787242	14267Y	PARTICIPANT	\N	PRESENT	0
787282	787242	99004R	PARTICIPANT	\N	PRESENT	0
787283	787242	19745F	PARTICIPANT	\N	PRESENT	0
787284	787242	14211G	PARTICIPANT	\N	PRESENT	0
787502	786195	20036X	PARTICIPANT	\N	PRESENT	0
787503	786195	20266L	PARTICIPANT	\N	PRESENT	0
787504	787120	20084G	PARTICIPANT	\N	PRESENT	0
787509	787242	04042C	PARTICIPANT	\N	PRESENT	0
787510	787242	19347U	PARTICIPANT	\N	PRESENT	0
787511	787242	21073H	PARTICIPANT	\N	PRESENT	0
787512	787242	14251Q	PARTICIPANT	\N	PRESENT	0
787513	787242	14105F	PARTICIPANT	\N	EXCUSE	0
787515	786619	86034E	PARTICIPANT	\N	PRESENT	0
787534	787242	19443T	PARTICIPANT	\N	PRESENT	0
787614	786180	14169X	PARTICIPANT	\N	PRESENT	0
787615	786180	20286Q	PARTICIPANT	\N	PRESENT	0
787616	786180	21037D	PARTICIPANT	\N	PRESENT	0
787617	786180	04070G	PARTICIPANT	\N	PRESENT	0
787618	786180	14073Q	PARTICIPANT	\N	PRESENT	0
787619	786180	14001X	PARTICIPANT	\N	PRESENT	0
787620	786180	19701S	PARTICIPANT	\N	PRESENT	0
787633	786197	21076L	PARTICIPANT	\N	PRESENT	0
787251	787200	19479G	PARTICIPANT	\N	PRESENT	0
787252	787200	19687N	PARTICIPANT	\N	PRESENT	0
787253	787200	08010L	PARTICIPANT	\N	PRESENT	0
787634	786197	14219Q	PARTICIPANT	\N	PRESENT	0
787662	782883	07029T	PARTICIPANT	\N	PRESENT	0
787636	786197	11070L	PARTICIPANT	\N	PRESENT	0
787637	786197	19719D	PARTICIPANT	\N	PRESENT	0
787638	786197	19447X	PARTICIPANT	\N	PRESENT	0
787639	786197	20098N	PARTICIPANT	\N	PRESENT	0
787640	786197	21043B	PARTICIPANT	\N	PRESENT	0
787641	786197	21044C	PARTICIPANT	\N	PRESENT	0
787642	786197	18207D	PARTICIPANT	\N	PRESENT	0
787643	786197	20110Q	PARTICIPANT	\N	PRESENT	0
787644	786197	21038E	PARTICIPANT	\N	PRESENT	0
787645	786197	08018U	PRESIDENT	0	PRESENT	0
787646	786197	20022R	PARTICIPANT	\N	PRESENT	0
787647	786197	04045F	PARTICIPANT	\N	PRESENT	0
787661	782883	21042A	PARTICIPANT	\N	EXCUSE	0
788072	788069	21038E	PARTICIPANT	\N	PRESENT	0
788567	786181	20118Y	PARTICIPANT	\N	PRESENT	0
788568	786181	17965H	PARTICIPANT	\N	PRESENT	0
788581	786181	21082J	PARTICIPANT	\N	PRESENT	0
788585	786181	14033T	PARTICIPANT	\N	PRESENT	0
788589	786181	20104S	PARTICIPANT	\N	EXCUSE	0
788707	788706	17367Q	PARTICIPANT	\N	PRESENT	0
788708	788706	14151M	PARTICIPANT	\N	PRESENT	0
788709	788706	20146D	PARTICIPANT	\N	PRESENT	0
788711	788710	17367Q	PARTICIPANT	\N	PRESENT	0
788712	788710	14151M	PARTICIPANT	\N	PRESENT	0
788713	788710	21072G	PARTICIPANT	\N	PRESENT	0
788715	788710	14255U	PARTICIPANT	\N	PRESENT	0
788781	788696	14038Y	PARTICIPANT	\N	PRESENT	0
788753	786182	04070G	PARTICIPANT	\N	PRESENT	0
788754	786182	19701S	PARTICIPANT	\N	PRESENT	0
788755	786182	14189C	PARTICIPANT	\N	PRESENT	0
788756	786182	14073Q	PARTICIPANT	\N	PRESENT	0
788757	786182	19569H	PARTICIPANT	\N	PRESENT	0
788758	786182	14001X	PARTICIPANT	\N	PRESENT	0
788759	786182	20094J	PARTICIPANT	\N	PRESENT	0
788760	786182	14026U	PARTICIPANT	\N	PRESENT	0
788762	786182	20100N	PARTICIPANT	\N	PRESENT	0
788763	786182	21032X	PARTICIPANT	\N	PRESENT	0
788764	786182	21078N	PARTICIPANT	\N	PRESENT	0
788765	786182	18207D	PARTICIPANT	\N	PRESENT	0
788770	788706	21072G	PARTICIPANT	\N	PRESENT	0
788772	788771	04047H	PARTICIPANT	\N	PRESENT	0
788773	788771	11056N	PARTICIPANT	\N	PRESENT	0
788774	788771	19673G	PARTICIPANT	\N	PRESENT	0
788775	788771	18231D	PARTICIPANT	\N	PRESENT	0
788776	788771	20266L	PARTICIPANT	\N	PRESENT	0
788777	788710	20050V	PARTICIPANT	\N	PRESENT	0
788782	788696	21054E	PARTICIPANT	\N	PRESENT	0
788783	788696	19782L	PARTICIPANT	\N	PRESENT	0
788784	788696	14187A	PRESIDENT	0	PRESENT	0
788785	788696	20038A	PARTICIPANT	\N	PRESENT	0
788786	788696	20144B	PARTICIPANT	\N	PRESENT	0
788787	788696	20082E	PARTICIPANT	\N	PRESENT	0
788788	788696	19695N	PARTICIPANT	\N	PRESENT	0
788789	788696	11090Q	PARTICIPANT	\N	PRESENT	0
788790	788696	14033T	PARTICIPANT	\N	PRESENT	0
788791	788696	14205J	PARTICIPANT	\N	PRESENT	0
788792	788696	20018V	PARTICIPANT	\N	PRESENT	0
788793	788696	21050A	PARTICIPANT	\N	PRESENT	0
788794	788696	20066E	PARTICIPANT	\N	EXCUSE	0
788795	788696	19631V	PARTICIPANT	\N	EXCUSE	0
788796	788696	20104S	PARTICIPANT	\N	EXCUSE	0
788821	788817	20022R	PARTICIPANT	\N	PRESENT	0
788822	788817	20110Q	PARTICIPANT	\N	PRESENT	0
788823	788817	21043B	PARTICIPANT	\N	PRESENT	0
788824	788817	14089Y	PARTICIPANT	\N	PRESENT	0
788825	788817	21088Q	PARTICIPANT	\N	PRESENT	0
788826	788817	04047H	PARTICIPANT	\N	PRESENT	0
788827	788817	19673G	PARTICIPANT	\N	PRESENT	0
788828	788817	19111A	PARTICIPANT	\N	PRESENT	0
788829	788817	19447X	PARTICIPANT	\N	PRESENT	0
788830	788817	14021P	PARTICIPANT	\N	PRESENT	0
788831	788817	19649G	PARTICIPANT	\N	PRESENT	0
788832	788817	14251Q	PARTICIPANT	\N	PRESENT	0
788833	788817	18231D	PARTICIPANT	\N	PRESENT	0
788834	788817	04033B	PARTICIPANT	\N	PRESENT	0
788859	788857	04047H	PRESIDENT	0	PRESENT	0
788860	788857	14215L	PARTICIPANT	\N	PRESENT	0
788862	788857	20074E	PARTICIPANT	\N	PRESENT	0
788863	788857	14231L	PARTICIPANT	\N	PRESENT	0
788864	788857	20114U	PARTICIPANT	\N	PRESENT	0
788865	788857	14151M	PARTICIPANT	\N	PRESENT	0
788867	788857	04045F	PARTICIPANT	\N	PRESENT	0
788869	788857	19749K	PARTICIPANT	\N	PRESENT	0
788870	788857	20122U	PARTICIPANT	\N	PRESENT	0
788871	788857	20110Q	PARTICIPANT	\N	PRESENT	0
788887	788881	21048G	PARTICIPANT	\N	PRESENT	0
788889	788881	14083S	PARTICIPANT	\N	PRESENT	0
788890	788881	19545Y	PARTICIPANT	\N	PRESENT	0
788892	788881	20070A	PARTICIPANT	\N	PRESENT	0
788893	788881	14327T	PARTICIPANT	\N	PRESENT	0
788894	788881	11048N	PARTICIPANT	\N	PRESENT	0
788895	788881	19711U	PARTICIPANT	\N	PRESENT	0
788896	788881	19349W	PARTICIPANT	\N	PRESENT	0
788897	788881	14225N	PARTICIPANT	0	PRESENT	0
788898	788881	20044X	PARTICIPANT	\N	PRESENT	0
788900	788881	20062A	PARTICIPANT	\N	PRESENT	0
788921	788881	21046E	PARTICIPANT	\N	PRESENT	0
788924	788881	19691J	PARTICIPANT	\N	PRESENT	0
788925	788881	14213J	PARTICIPANT	\N	PRESENT	0
788926	788881	19683J	PARTICIPANT	\N	PRESENT	0
788927	788881	19723Y	PARTICIPANT	\N	PRESENT	0
769350	760914	20104S	PARTICIPANT	\N	PRESENT	0
769351	760914	14001X	PARTICIPANT	\N	PRESENT	0
779124	775655	21088Q	PARTICIPANT	\N	EXCUSE	0
779125	775655	19563B	PARTICIPANT	\N	EXCUSE	0
783039	779282	21089R	PARTICIPANT	\N	PRESENT	0
783040	779282	20124W	PARTICIPANT	\N	PRESENT	0
783041	779282	20132W	PARTICIPANT	\N	PRESENT	0
783042	779282	14073Q	PARTICIPANT	\N	PRESENT	0
783043	779282	19735D	PARTICIPANT	\N	PRESENT	0
783044	779282	20052X	PARTICIPANT	\N	PRESENT	0
783045	779282	14109K	PARTICIPANT	\N	PRESENT	0
785316	785315	19691J	PARTICIPANT	\N	PRESENT	0
785317	785315	19703U	PARTICIPANT	\N	PRESENT	0
786225	786224	14097Y	PARTICIPANT	\N	PRESENT	0
786226	786224	21084L	PARTICIPANT	\N	PRESENT	0
786227	786224	08060W	PARTICIPANT	\N	PRESENT	0
786228	786224	14249W	PARTICIPANT	\N	PRESENT	0
786229	786224	14281W	PARTICIPANT	\N	PRESENT	0
786230	786224	20120S	PARTICIPANT	\N	PRESENT	0
786231	786224	19347U	PARTICIPANT	\N	PRESENT	0
786232	786224	21066J	PARTICIPANT	\N	PRESENT	0
786233	786224	18231D	PARTICIPANT	\N	PRESENT	0
786234	786224	20062A	PARTICIPANT	\N	PRESENT	0
786235	786224	20046A	PARTICIPANT	\N	PRESENT	0
786237	786236	08018U	PARTICIPANT	\N	PRESENT	0
786238	786236	11056N	PARTICIPANT	\N	PRESENT	0
786239	786236	21029D	PARTICIPANT	\N	PRESENT	0
786240	786236	17229F	PARTICIPANT	\N	PRESENT	0
786241	786236	20110Q	PARTICIPANT	\N	PRESENT	0
786242	786236	08012N	PARTICIPANT	\N	PRESENT	0
786243	786236	19669L	PARTICIPANT	\N	PRESENT	0
786244	786236	20150Y	PARTICIPANT	\N	PRESENT	0
787935	786619	19725B	PARTICIPANT	\N	PRESENT	0
788465	786180	14357A	PARTICIPANT	\N	PRESENT	0
787937	786619	20112S	PARTICIPANT	\N	PRESENT	0
788464	786180	14237S	PARTICIPANT	\N	PRESENT	0
788466	786181	20094J	PARTICIPANT	\N	PRESENT	0
788467	786181	20150Y	PARTICIPANT	\N	PRESENT	0
787941	786619	19057M	PARTICIPANT	\N	PRESENT	0
788468	786181	19709B	PARTICIPANT	\N	PRESENT	0
788469	786181	14169X	PARTICIPANT	\N	PRESENT	0
787944	786619	19531S	PARTICIPANT	\N	PRESENT	0
787945	786619	14021P	PARTICIPANT	\N	PRESENT	0
787946	786619	19489J	PARTICIPANT	\N	PRESENT	0
788470	786181	20248J	PARTICIPANT	\N	PRESENT	0
787948	786619	18193Q	PARTICIPANT	\N	PRESENT	0
788471	786181	14073Q	PARTICIPANT	\N	PRESENT	0
787950	786619	08012N	PARTICIPANT	\N	PRESENT	0
787951	786619	17779H	PARTICIPANT	\N	PRESENT	0
788472	786181	04070G	PARTICIPANT	\N	PRESENT	0
787953	786619	14001X	PARTICIPANT	\N	PRESENT	0
787954	786619	18231D	PARTICIPANT	\N	PRESENT	0
788473	786181	19701S	PARTICIPANT	\N	PRESENT	0
787956	786619	21067K	PARTICIPANT	\N	PRESENT	0
788474	786181	14331P	PRESIDENT	0	PRESENT	0
788475	786181	14001X	PARTICIPANT	\N	PRESENT	0
788476	786181	20100N	PARTICIPANT	\N	PRESENT	0
787960	786619	20084G	PARTICIPANT	\N	PRESENT	0
788477	786181	21037D	PARTICIPANT	\N	PRESENT	0
787962	786619	21051B	PARTICIPANT	\N	PRESENT	0
788478	786181	18207D	PARTICIPANT	\N	PRESENT	0
787965	786619	14229S	PARTICIPANT	\N	PRESENT	0
787966	786619	20064C	PARTICIPANT	\N	PRESENT	0
789259	788696	19575F	PARTICIPANT	\N	EXCUSE	0
789335	788696	14189C	PARTICIPANT	\N	PRESENT	0
789336	788696	20094J	PARTICIPANT	\N	PRESENT	0
789337	788696	20042V	PARTICIPANT	\N	PRESENT	0
789338	788696	17737W	PARTICIPANT	\N	PRESENT	0
789339	788696	19701S	PARTICIPANT	\N	PRESENT	0
789340	788696	20100N	PARTICIPANT	\N	PRESENT	0
789341	788696	21032X	PARTICIPANT	\N	PRESENT	0
789342	788696	14026U	PARTICIPANT	\N	PRESENT	0
789343	788696	19569H	PARTICIPANT	\N	PRESENT	0
789344	788696	14097Y	PARTICIPANT	\N	PRESENT	0
789345	788696	14073Q	PARTICIPANT	\N	PRESENT	0
789346	788696	21078N	PARTICIPANT	\N	PRESENT	0
789347	788696	19711U	PARTICIPANT	\N	PRESENT	0
789348	788696	08034U	PARTICIPANT	\N	PRESENT	0
789349	788696	18207D	PARTICIPANT	\N	PRESENT	0
789350	788696	14001X	PARTICIPANT	\N	PRESENT	0
789351	788696	04070G	PARTICIPANT	\N	PRESENT	0
789352	788696	21037D	PARTICIPANT	\N	PRESENT	0
789353	788696	14237S	PARTICIPANT	\N	PRESENT	0
789354	788696	14331P	PARTICIPANT	\N	PRESENT	0
789355	788696	21076L	PARTICIPANT	\N	PRESENT	0
789356	788696	20086J	PARTICIPANT	\N	PRESENT	0
789357	788696	14083S	PARTICIPANT	\N	PRESENT	0
789358	788696	21090J	PARTICIPANT	\N	PRESENT	0
789359	788696	19693L	PARTICIPANT	\N	PRESENT	0
789360	788696	21067K	PARTICIPANT	\N	PRESENT	0
789361	788696	19347U	PARTICIPANT	\N	PRESENT	0
789362	788696	19399H	PARTICIPANT	\N	PRESENT	0
789363	788696	14147R	PARTICIPANT	\N	PRESENT	0
789364	788696	14193X	PARTICIPANT	\N	PRESENT	0
789365	788696	11045K	PARTICIPANT	\N	PRESENT	0
789366	788696	21036C	PARTICIPANT	\N	PRESENT	0
789367	788696	20044X	PARTICIPANT	\N	PRESENT	0
789368	788696	21031W	PARTICIPANT	\N	PRESENT	0
789377	788835	19667J	PARTICIPANT	\N	EXCUSE	0
789378	788835	20128B	PARTICIPANT	\N	EXCUSE	0
789379	788835	14038Y	PARTICIPANT	\N	EXCUSE	0
789427	789426	19611R	PARTICIPANT	\N	PRESENT	0
789428	789426	21089R	PARTICIPANT	\N	PRESENT	1
789429	789426	20180F	PARTICIPANT	\N	PRESENT	1
789430	789426	14123H	PARTICIPANT	\N	PRESENT	1
789431	789426	04047H	PARTICIPANT	\N	PRESENT	0
789432	789369	14151M	PRESIDENT	0	PRESENT	0
789433	789369	17367Q	PARTICIPANT	\N	PRESENT	0
789434	789369	14255U	PARTICIPANT	\N	PRESENT	0
789435	789369	17737W	PARTICIPANT	\N	PRESENT	0
789478	789369	12028B	PARTICIPANT	\N	PRESENT	0
789494	789369	20146D	PARTICIPANT	\N	PRESENT	0
789496	789479	19685L	PARTICIPANT	\N	EXCUSE	0
789498	789497	19711U	PARTICIPANT	\N	PRESENT	0
789499	789497	20094J	PARTICIPANT	\N	PRESENT	0
789501	789500	19711U	PARTICIPANT	\N	PRESENT	0
789502	789500	20094J	PARTICIPANT	\N	PRESENT	0
789971	789970	20024T	PARTICIPANT	\N	PRESENT	0
789972	789970	20086J	PARTICIPANT	\N	PRESENT	0
789973	789970	14255U	PARTICIPANT	\N	PRESENT	0
789974	789970	20138D	PARTICIPANT	\N	PRESENT	0
789975	789970	19693L	PARTICIPANT	\N	PRESENT	0
789976	789970	17229F	PARTICIPANT	\N	PRESENT	0
789977	789970	20128B	PARTICIPANT	\N	PRESENT	0
789978	789970	08010L	PARTICIPANT	\N	PRESENT	0
789979	789970	20052X	PARTICIPANT	\N	PRESENT	0
789980	789970	19573D	PARTICIPANT	\N	PRESENT	0
789981	789970	19349W	PARTICIPANT	\N	PRESENT	0
789982	789970	20054A	PARTICIPANT	\N	PRESENT	0
789983	789970	19479G	PARTICIPANT	\N	PRESENT	0
790092	790090	14083S	PARTICIPANT	\N	PRESENT	0
790093	790090	19421M	PARTICIPANT	\N	PRESENT	0
790177	789830	19629C	PARTICIPANT	\N	PRESENT	0
790178	789830	14147R	PARTICIPANT	\N	PRESENT	0
790179	789830	20026V	PARTICIPANT	\N	PRESENT	0
790180	789830	19699S	PARTICIPANT	\N	PRESENT	0
790181	789830	08012N	PARTICIPANT	\N	PRESENT	0
790182	789830	20180F	PARTICIPANT	\N	PRESENT	0
790183	789830	20024T	PARTICIPANT	\N	PRESENT	0
790184	789830	21037D	PARTICIPANT	\N	PRESENT	0
790185	789830	14189C	PARTICIPANT	\N	PRESENT	0
790186	789830	14179A	PARTICIPANT	\N	PRESENT	0
790187	789830	19251M	PARTICIPANT	\N	PRESENT	0
790188	789830	20056C	PARTICIPANT	\N	PRESENT	0
790189	789830	20120S	PARTICIPANT	\N	PRESENT	0
790190	789830	14213J	PARTICIPANT	\N	PRESENT	0
790191	789830	20134Y	PARTICIPANT	\N	PRESENT	0
790192	789830	19421M	PARTICIPANT	\N	PRESENT	0
790193	789830	19349W	PARTICIPANT	\N	PRESENT	0
790194	789830	19703U	PARTICIPANT	\N	PRESENT	0
790195	789830	19533U	PARTICIPANT	\N	PRESENT	0
790196	789830	19585H	PARTICIPANT	\N	PRESENT	0
791442	789274	21087P	PARTICIPANT	\N	PRESENT	0
791443	789274	20100N	PARTICIPANT	\N	PRESENT	0
791444	789274	14213J	PARTICIPANT	\N	PRESENT	0
791445	789274	18193Q	PARTICIPANT	\N	PRESENT	0
780596	780474	19629C	PARTICIPANT	\N	PRESENT	0
780597	780474	20054A	PARTICIPANT	\N	PRESENT	0
780598	780474	21041Y	PARTICIPANT	\N	PRESENT	0
780599	780474	14357A	PARTICIPANT	\N	PRESENT	0
780600	780474	19719D	PARTICIPANT	\N	PRESENT	0
780601	780474	20086J	PARTICIPANT	\N	PRESENT	0
780602	780474	20132W	PARTICIPANT	\N	PRESENT	0
780603	780474	20098N	PARTICIPANT	\N	PRESENT	0
780604	780474	19387D	PARTICIPANT	\N	PRESENT	0
780605	780474	21066J	PARTICIPANT	\N	PRESENT	0
780606	780474	20020P	PARTICIPANT	\N	PRESENT	0
780607	780474	98022P	PARTICIPANT	\N	PRESENT	0
780608	780474	21095P	PARTICIPANT	\N	PRESENT	0
780609	780474	21090J	PARTICIPANT	\N	PRESENT	0
780610	780474	14217N	PARTICIPANT	\N	PRESENT	0
780611	780474	20072C	PARTICIPANT	\N	PRESENT	0
780612	780474	21078N	PARTICIPANT	\N	PRESENT	0
780613	780474	20120S	PARTICIPANT	\N	PRESENT	0
780614	780474	21040X	PARTICIPANT	\N	PRESENT	0
780615	780474	19866P	PARTICIPANT	\N	PRESENT	0
780616	780474	14107H	PARTICIPANT	\N	PRESENT	0
780617	780474	21046E	PARTICIPANT	\N	PRESENT	0
780618	780474	21052C	PARTICIPANT	\N	PRESENT	0
780619	780474	14069U	PARTICIPANT	\N	PRESENT	0
780620	780474	19798U	PARTICIPANT	\N	PRESENT	0
780621	780474	21092L	PARTICIPANT	\N	PRESENT	0
780622	780474	95041E	PARTICIPANT	\N	PRESENT	0
780623	780474	19573D	PARTICIPANT	\N	PRESENT	0
780624	780474	14195A	PARTICIPANT	\N	PRESENT	0
780625	780474	14355X	PARTICIPANT	\N	PRESENT	0
780626	780474	21065H	PARTICIPANT	\N	PRESENT	0
780627	780474	19693L	PARTICIPANT	\N	PRESENT	0
780628	780474	14071N	PARTICIPANT	\N	PRESENT	0
780629	780474	14211G	PARTICIPANT	\N	PRESENT	0
780630	780474	19593H	PARTICIPANT	\N	PRESENT	0
780631	780474	14187A	PARTICIPANT	\N	PRESENT	0
780632	780474	21087P	PARTICIPANT	\N	PRESENT	0
780633	780474	19701S	PARTICIPANT	\N	PRESENT	0
780634	780474	14053L	PARTICIPANT	\N	PRESENT	0
780635	780474	19679N	PARTICIPANT	\N	PRESENT	0
780636	780474	04033B	PARTICIPANT	\N	PRESENT	0
780637	780474	04092N	PARTICIPANT	\N	PRESENT	0
780638	780474	14133K	PARTICIPANT	\N	PRESENT	0
780639	780474	08034U	PARTICIPANT	\N	PRESENT	0
780640	780474	04047H	PARTICIPANT	\N	PRESENT	0
780641	780474	14026U	PARTICIPANT	\N	PRESENT	0
780642	780474	18083K	PARTICIPANT	\N	PRESENT	0
780643	780474	19711U	PARTICIPANT	\N	PRESENT	0
780644	780474	14215L	PARTICIPANT	\N	PRESENT	0
780645	780474	21054E	PARTICIPANT	\N	PRESENT	0
780646	780474	14251Q	PARTICIPANT	\N	PRESENT	0
780647	780474	14111D	PARTICIPANT	\N	PRESENT	0
780648	780474	07033P	PARTICIPANT	\N	PRESENT	0
780649	780474	14221J	PARTICIPANT	\N	PRESENT	0
780650	780474	21047F	PARTICIPANT	\N	PRESENT	0
780651	780474	19703U	PARTICIPANT	\N	PRESENT	0
780652	780474	08015R	PARTICIPANT	\N	PRESENT	0
780653	780474	14249W	PARTICIPANT	\N	PRESENT	0
780654	780474	21076L	PARTICIPANT	\N	PRESENT	0
780655	780474	19585H	PARTICIPANT	\N	PRESENT	0
780656	780474	21035B	PARTICIPANT	\N	PRESENT	0
780657	780474	20094J	PARTICIPANT	\N	PRESENT	0
780658	780474	08060W	PARTICIPANT	\N	PRESENT	0
780659	780474	20114U	PARTICIPANT	\N	PRESENT	0
780660	780474	20080C	PARTICIPANT	\N	PRESENT	0
780661	780474	21089R	PARTICIPANT	\N	PRESENT	0
780662	780474	21045D	PARTICIPANT	\N	PRESENT	0
780663	780474	20060X	PARTICIPANT	\N	PRESENT	0
780664	780474	12028B	PARTICIPANT	\N	PRESENT	0
780665	780474	21057H	PARTICIPANT	\N	PRESENT	0
780666	780474	20264J	PARTICIPANT	\N	PRESENT	0
780667	780474	11027H	PARTICIPANT	\N	PRESENT	0
780668	780474	20070A	PARTICIPANT	\N	PRESENT	0
780669	780474	18395Y	PARTICIPANT	\N	PRESENT	0
780670	780474	21067K	PARTICIPANT	\N	PRESENT	0
780671	780474	11074Q	PARTICIPANT	\N	PRESENT	0
780672	780474	21062E	PARTICIPANT	\N	PRESENT	0
780673	780474	20078J	PARTICIPANT	\N	PRESENT	0
780674	780474	19647E	PARTICIPANT	\N	PRESENT	0
780675	780474	14281W	PARTICIPANT	\N	PRESENT	0
780676	780474	14151M	PARTICIPANT	\N	PRESENT	0
780677	780474	19725B	PARTICIPANT	\N	PRESENT	0
780678	780474	14121F	PARTICIPANT	\N	PRESENT	0
780679	780474	19683J	PARTICIPANT	\N	PRESENT	0
780680	780474	14097Y	PARTICIPANT	\N	PRESENT	0
780681	780474	14021P	PARTICIPANT	\N	PRESENT	0
780682	780474	19489J	PARTICIPANT	\N	PRESENT	0
780683	780474	19649G	PARTICIPANT	\N	PRESENT	0
780684	780474	18193Q	PARTICIPANT	\N	PRESENT	0
780685	780474	21079P	PARTICIPANT	\N	PRESENT	0
780686	780474	18207D	PARTICIPANT	\N	PRESENT	0
780687	780474	19705W	PARTICIPANT	\N	PRESENT	0
780688	780474	12016W	PARTICIPANT	\N	PRESENT	0
780689	780474	14001X	PARTICIPANT	\N	PRESENT	0
780690	780474	20028X	PARTICIPANT	\N	PRESENT	0
780691	780474	20018V	PARTICIPANT	\N	PRESENT	0
780692	780474	14109K	PARTICIPANT	\N	PRESENT	0
780693	780474	14257W	PARTICIPANT	\N	PRESENT	0
780694	780474	18231D	PARTICIPANT	\N	PRESENT	0
780695	780474	20030R	PARTICIPANT	\N	PRESENT	0
780696	780474	20088L	PARTICIPANT	\N	PRESENT	0
780697	780474	19531S	PARTICIPANT	\N	PRESENT	0
780698	780474	11110B	PARTICIPANT	\N	PRESENT	0
780699	780474	14225N	PARTICIPANT	\N	PRESENT	0
780700	780474	20082E	PARTICIPANT	\N	PRESENT	0
780701	780474	14229S	PARTICIPANT	\N	PRESENT	0
780702	780474	21056G	PARTICIPANT	\N	PRESENT	0
780703	780474	11045K	PARTICIPANT	\N	PRESENT	0
780704	780474	21059K	PARTICIPANT	\N	PRESENT	0
780705	780474	19669L	PARTICIPANT	\N	PRESENT	0
780706	780474	20084G	PARTICIPANT	\N	PRESENT	0
780707	780474	19707Y	PARTICIPANT	\N	PRESENT	0
780708	780474	21051B	PARTICIPANT	\N	PRESENT	0
780709	780474	20064C	PARTICIPANT	\N	PRESENT	0
780710	780474	21031W	PARTICIPANT	\N	PRESENT	0
780711	780474	21082J	PARTICIPANT	\N	PRESENT	0
780712	780474	21077M	PARTICIPANT	\N	PRESENT	0
780713	780474	14259Y	PARTICIPANT	\N	PRESENT	0
780714	780474	19820Y	PARTICIPANT	\N	PRESENT	0
780715	780474	20034V	PARTICIPANT	\N	PRESENT	0
780716	780474	20122U	PARTICIPANT	\N	PRESENT	0
780717	780474	21042A	PARTICIPANT	\N	PRESENT	0
780718	780474	20092G	PARTICIPANT	\N	PRESENT	0
780719	780474	08056B	PARTICIPANT	\N	PRESENT	0
780720	780474	14030Q	PARTICIPANT	\N	PRESENT	0
780721	780474	21050A	PARTICIPANT	\N	PRESENT	0
780722	780474	19057M	PARTICIPANT	\N	PRESENT	0
780723	780474	14189C	PARTICIPANT	\N	PRESENT	0
780724	780474	14255U	PARTICIPANT	\N	PRESENT	0
780725	780474	21083K	PARTICIPANT	\N	PRESENT	0
780726	780474	14083S	PARTICIPANT	\N	PRESENT	0
780727	780474	14089Y	PARTICIPANT	\N	PRESENT	0
780728	780474	11053K	PARTICIPANT	\N	PRESENT	0
780729	780474	19721W	PARTICIPANT	\N	PRESENT	0
780730	780474	14267Y	PARTICIPANT	\N	PRESENT	0
780731	780474	11070L	PARTICIPANT	\N	PRESENT	0
780732	780474	14327T	PARTICIPANT	\N	PRESENT	0
780733	780474	11043H	PARTICIPANT	\N	PRESENT	0
780734	780474	17229F	PARTICIPANT	\N	PRESENT	0
780735	780474	20248J	PARTICIPANT	\N	PRESENT	0
780736	780474	15197G	PARTICIPANT	\N	PRESENT	0
780737	780474	14042U	PARTICIPANT	\N	PRESENT	0
780738	780474	20040T	PARTICIPANT	\N	PRESENT	0
780739	780474	21086N	PARTICIPANT	\N	PRESENT	0
780740	780474	19111A	PARTICIPANT	\N	PRESENT	0
780743	780474	07004J	PARTICIPANT	\N	PRESENT	0
780744	780474	19691J	PARTICIPANT	\N	PRESENT	0
780745	780474	19569H	PARTICIPANT	\N	PRESENT	0
780746	780474	19685L	PARTICIPANT	\N	PRESENT	0
780747	780474	20048C	PARTICIPANT	\N	PRESENT	0
780748	780474	20066E	PARTICIPANT	\N	PRESENT	0
780749	780474	14073Q	PARTICIPANT	\N	PRESENT	0
780754	780474	19735D	PARTICIPANT	\N	PRESENT	0
780755	780474	19611R	PARTICIPANT	\N	PRESENT	0
780757	780474	20052X	PARTICIPANT	\N	PRESENT	0
780758	780474	14205J	PARTICIPANT	\N	PRESENT	0
780760	780474	19563B	PARTICIPANT	\N	PRESENT	0
780761	780474	19335Q	PARTICIPANT	\N	PRESENT	0
780762	780474	04070G	PARTICIPANT	\N	PRESENT	0
780763	780474	19826F	PARTICIPANT	\N	PRESENT	0
772553	772441	21073H	PARTICIPANT	\N	EXCUSE	0
772556	772441	14053L	PARTICIPANT	\N	EXCUSE	0
772620	772618	21076L	PARTICIPANT	\N	PRESENT	0
772621	772619	21076L	PARTICIPANT	\N	PRESENT	0
773366	768443	14026U	PARTICIPANT	\N	PRESENT	0
773367	768443	20130U	PARTICIPANT	\N	PRESENT	0
773375	773373	20042V	PARTICIPANT	\N	PRESENT	0
773376	773373	11027H	PARTICIPANT	\N	PRESENT	0
773377	773373	21067K	PARTICIPANT	\N	PRESENT	0
773378	773373	17023S	PARTICIPANT	\N	PRESENT	0
773379	773373	19565D	PARTICIPANT	\N	PRESENT	0
773380	773373	20128B	PARTICIPANT	\N	PRESENT	0
773381	773373	20252E	PARTICIPANT	\N	PRESENT	0
773382	773373	08047A	PARTICIPANT	\N	PRESENT	0
773383	773373	19745F	PARTICIPANT	\N	PRESENT	0
773384	773373	19421M	PARTICIPANT	\N	PRESENT	0
773385	773373	20064C	PARTICIPANT	\N	PRESENT	0
773386	773373	21031W	PARTICIPANT	\N	PRESENT	0
778820	776115	19331L	PARTICIPANT	\N	PRESENT	0
778821	776115	21055F	PARTICIPANT	\N	PRESENT	0
778822	776115	21029D	PARTICIPANT	\N	PRESENT	0
778823	776115	19631V	PARTICIPANT	\N	PRESENT	0
778824	776115	20034V	PRESIDENT	0	PRESENT	0
778825	776115	08073C	PARTICIPANT	\N	PRESENT	0
778826	776115	21034A	PARTICIPANT	\N	PRESENT	0
778827	776115	12016W	PARTICIPANT	\N	PRESENT	0
778828	776115	19657G	PARTICIPANT	\N	PRESENT	0
778829	776115	20146D	PARTICIPANT	\N	PRESENT	0
778830	776115	21030V	PARTICIPANT	\N	PRESENT	0
778831	776115	19301E	PARTICIPANT	\N	PRESENT	0
778832	776115	14275Y	PARTICIPANT	\N	PRESENT	0
778833	776115	21035B	PARTICIPANT	\N	PRESENT	0
778834	776115	20016T	PARTICIPANT	\N	PRESENT	0
778835	776115	19295A	PARTICIPANT	\N	PRESENT	0
778836	776115	18083K	PARTICIPANT	\N	EXCUSE	0
778837	776115	21071F	PARTICIPANT	\N	EXCUSE	0
778838	776115	19745F	PARTICIPANT	\N	EXCUSE	0
778839	776115	21033Y	PARTICIPANT	\N	PRESENT	0
778840	776115	21032X	PARTICIPANT	\N	PRESENT	1
778841	776115	11072N	PARTICIPANT	\N	PRESENT	0
778842	776115	21097R	PARTICIPANT	\N	PRESENT	0
778843	776115	20150Y	PARTICIPANT	\N	PRESENT	0
778856	776115	14059S	PARTICIPANT	\N	PRESENT	0
779517	776562	14179A	PARTICIPANT	\N	PRESENT	0
779518	776562	19691J	PARTICIPANT	\N	PRESENT	0
779519	776562	17965H	PARTICIPANT	\N	PRESENT	0
779520	776562	20080C	PARTICIPANT	\N	PRESENT	0
779521	776562	19565D	PARTICIPANT	\N	PRESENT	0
779522	776562	19687N	PARTICIPANT	\N	PRESENT	0
779523	776562	19760E	PARTICIPANT	\N	PRESENT	0
779524	776562	07029T	PARTICIPANT	\N	PRESENT	0
779525	776562	20062A	PARTICIPANT	\N	PRESENT	0
779526	776562	11048N	PARTICIPANT	\N	PRESENT	0
779527	776562	21073H	PARTICIPANT	\N	PRESENT	0
779528	776562	19573D	PARTICIPANT	\N	PRESENT	0
779529	776562	21054E	PARTICIPANT	\N	PRESENT	0
779530	776562	14207L	PARTICIPANT	\N	PRESENT	0
779531	776562	19713W	PARTICIPANT	\N	PRESENT	0
779532	776562	08047A	PARTICIPANT	\N	PRESENT	0
779533	776562	04045F	PARTICIPANT	\N	PRESENT	0
779534	776562	19699S	PARTICIPANT	\N	PRESENT	0
779535	776562	14219Q	PARTICIPANT	\N	PRESENT	0
779536	776562	19657G	PARTICIPANT	\N	PRESENT	0
779537	776562	14083S	PARTICIPANT	\N	PRESENT	0
779538	776562	19709B	PARTICIPANT	\N	PRESENT	0
779539	776562	08010L	PARTICIPANT	\N	PRESENT	0
779547	776562	20076G	PARTICIPANT	\N	PRESENT	0
779548	776562	07033P	PARTICIPANT	\N	PRESENT	0
779549	776562	19701S	PARTICIPANT	\N	PRESENT	0
779550	776562	14109K	PARTICIPANT	\N	PRESENT	0
779551	776562	21030V	PARTICIPANT	\N	PRESENT	0
779552	776562	21090J	PARTICIPANT	\N	PRESENT	0
779553	776562	19782L	PARTICIPANT	\N	PRESENT	0
779554	776562	20072C	PARTICIPANT	\N	PRESENT	0
779555	776562	20116W	PARTICIPANT	\N	PRESENT	0
779556	776562	07004J	PARTICIPANT	\N	PRESENT	0
779557	776562	21093M	PARTICIPANT	\N	PRESENT	0
779558	776562	19531S	PARTICIPANT	\N	PRESENT	0
779559	776562	20034V	PARTICIPANT	\N	PRESENT	0
779565	776562	19711U	PARTICIPANT	\N	PRESENT	0
779567	776562	20126Y	PARTICIPANT	\N	PRESENT	0
779568	776562	14073Q	PARTICIPANT	\N	PRESENT	0
779569	776562	20252E	PARTICIPANT	\N	PRESENT	0
779570	776562	11027H	PARTICIPANT	\N	PRESENT	0
779571	776562	20082E	PARTICIPANT	\N	PRESENT	0
779572	776562	20040T	PARTICIPANT	\N	PRESENT	0
779573	776562	14030Q	PARTICIPANT	\N	PRESENT	0
779574	776562	20070A	PARTICIPANT	\N	PRESENT	0
779575	776562	14001X	PARTICIPANT	\N	PRESENT	0
779576	776562	04042C	PARTICIPANT	\N	PRESENT	0
779577	776562	19647E	PARTICIPANT	\N	PRESENT	0
779578	776562	19347U	PARTICIPANT	\N	PRESENT	0
779579	776562	14037X	PARTICIPANT	\N	PRESENT	0
779580	776562	19669L	PARTICIPANT	\N	PRESENT	0
779581	776562	20264J	PARTICIPANT	\N	PRESENT	0
779582	776562	14255U	PARTICIPANT	\N	PRESENT	0
779583	776563	14179A	PARTICIPANT	\N	PRESENT	0
779584	776563	19691J	PARTICIPANT	\N	PRESENT	0
779585	776563	17965H	PARTICIPANT	\N	PRESENT	0
779586	776563	20080C	PARTICIPANT	\N	PRESENT	0
779587	776563	19760E	PARTICIPANT	\N	PRESENT	0
779588	776563	07029T	PARTICIPANT	\N	PRESENT	0
779589	776563	20062A	PARTICIPANT	\N	PRESENT	0
779590	776563	11048N	PARTICIPANT	\N	PRESENT	0
779591	776563	21073H	PARTICIPANT	\N	PRESENT	0
779592	776563	19573D	PARTICIPANT	\N	PRESENT	0
779593	776563	21054E	PARTICIPANT	\N	PRESENT	0
779594	776563	14207L	PARTICIPANT	\N	PRESENT	0
779595	776563	19713W	PARTICIPANT	\N	PRESENT	0
779596	776563	08047A	PARTICIPANT	\N	PRESENT	0
779597	776563	04045F	PARTICIPANT	\N	PRESENT	0
779598	776563	19699S	PARTICIPANT	\N	PRESENT	0
779599	776563	14219Q	PARTICIPANT	\N	PRESENT	0
779600	776563	19657G	PARTICIPANT	\N	PRESENT	0
779601	776563	14083S	PARTICIPANT	\N	PRESENT	0
779602	776563	19709B	PARTICIPANT	\N	PRESENT	0
779603	776563	08010L	PARTICIPANT	\N	PRESENT	0
779604	776563	20076G	PARTICIPANT	\N	PRESENT	0
779605	776563	07033P	PARTICIPANT	\N	PRESENT	0
779606	776563	19701S	PARTICIPANT	\N	PRESENT	0
779607	776563	14109K	PARTICIPANT	\N	PRESENT	0
779608	776563	21030V	PARTICIPANT	\N	PRESENT	0
779609	776563	21090J	PARTICIPANT	\N	PRESENT	0
779610	776563	19782L	PARTICIPANT	\N	PRESENT	0
779611	776563	20072C	PARTICIPANT	\N	PRESENT	0
779612	776563	20116W	PARTICIPANT	\N	PRESENT	0
779613	776563	07004J	PARTICIPANT	\N	PRESENT	0
779614	776563	21093M	PARTICIPANT	\N	PRESENT	0
779615	776563	19531S	PARTICIPANT	\N	PRESENT	0
779616	776563	20034V	PARTICIPANT	\N	PRESENT	0
779617	776563	19711U	PARTICIPANT	\N	PRESENT	0
779618	776563	20126Y	PARTICIPANT	\N	PRESENT	0
779619	776563	14073Q	PARTICIPANT	\N	PRESENT	0
779620	776563	20252E	PARTICIPANT	\N	PRESENT	0
779621	776563	11027H	PARTICIPANT	\N	PRESENT	0
779622	776563	20082E	PARTICIPANT	\N	PRESENT	0
779623	776563	20040T	PARTICIPANT	\N	PRESENT	0
779624	776563	14030Q	PARTICIPANT	\N	PRESENT	0
779625	776563	20070A	PARTICIPANT	\N	PRESENT	0
779626	776563	14001X	PARTICIPANT	\N	PRESENT	0
779627	776563	04042C	PARTICIPANT	\N	PRESENT	0
779628	776563	19647E	PARTICIPANT	\N	PRESENT	0
779629	776563	19347U	PARTICIPANT	\N	PRESENT	0
779630	776563	14037X	PARTICIPANT	\N	PRESENT	0
779631	776563	19669L	PARTICIPANT	\N	PRESENT	0
779632	776563	20264J	PARTICIPANT	\N	PRESENT	0
779633	776563	14255U	PARTICIPANT	\N	PRESENT	0
779634	776563	99004R	PARTICIPANT	\N	PRESENT	0
779635	776563	21037D	PARTICIPANT	\N	PRESENT	0
779636	776563	19421M	PARTICIPANT	\N	PRESENT	0
779637	776563	21095P	PARTICIPANT	\N	PRESENT	0
779638	776563	14249W	PARTICIPANT	\N	PRESENT	0
779663	776563	19687N	PARTICIPANT	\N	PRESENT	0
779640	776563	21038E	PARTICIPANT	\N	PRESENT	0
779641	776563	21086N	PARTICIPANT	\N	PRESENT	0
779648	776563	19565D	PARTICIPANT	\N	PRESENT	0
779662	776563	19611R	PARTICIPANT	\N	PRESENT	0
789204	789203	20110Q	PARTICIPANT	\N	PRESENT	0
788967	788881	20134Y	PARTICIPANT	\N	PRESENT	0
788932	788881	17965H	PARTICIPANT	\N	PRESENT	0
788933	788881	19713W	PARTICIPANT	\N	PRESENT	0
788934	788881	21094N	PARTICIPANT	\N	PRESENT	0
788937	788881	19621T	PARTICIPANT	\N	PRESENT	0
788938	788881	21089R	PARTICIPANT	\N	PRESENT	0
788939	788881	20180F	PARTICIPANT	\N	PRESENT	0
788940	788881	20056C	PARTICIPANT	\N	PRESENT	0
788941	788881	19611R	PARTICIPANT	0	PRESENT	0
788942	788881	19697Q	PARTICIPANT	\N	PRESENT	0
788943	788881	20142Y	PARTICIPANT	\N	PRESENT	0
788944	788881	04070G	PARTICIPANT	\N	PRESENT	0
788945	788881	19593H	PARTICIPANT	\N	PRESENT	0
788946	788881	21055F	PARTICIPANT	\N	PRESENT	0
788947	788881	14229S	PARTICIPANT	\N	PRESENT	0
788948	788881	20026V	PARTICIPANT	\N	PRESENT	0
788969	788881	11070L	PARTICIPANT	\N	PRESENT	0
788950	788881	21077M	PARTICIPANT	\N	PRESENT	0
788952	788881	11053K	PARTICIPANT	\N	PRESENT	0
788953	788881	19701S	PARTICIPANT	\N	PRESENT	0
788954	788881	15197G	PARTICIPANT	\N	PRESENT	0
788955	788881	20100N	PARTICIPANT	\N	PRESENT	0
788978	787249	17737W	PARTICIPANT	\N	PRESENT	0
789222	786624	19479G	PARTICIPANT	\N	PRESENT	0
788958	788881	20106U	PARTICIPANT	\N	PRESENT	0
788959	788881	19551W	PARTICIPANT	\N	PRESENT	0
788960	788881	14031R	PARTICIPANT	0	PRESENT	0
789206	789203	20114U	PARTICIPANT	\N	PRESENT	0
788962	788881	20136B	PARTICIPANT	\N	PRESENT	0
788963	788881	21051B	PARTICIPANT	\N	PRESENT	0
788964	788881	21076L	PARTICIPANT	\N	PRESENT	0
789207	789203	04047H	PARTICIPANT	\N	PRESENT	0
789208	789203	14053L	PARTICIPANT	\N	PRESENT	0
788984	786182	21036C	PARTICIPANT	\N	PRESENT	0
788985	786182	21031W	PARTICIPANT	\N	PRESENT	0
788986	786182	21067K	PARTICIPANT	\N	PRESENT	0
788987	786182	19347U	PARTICIPANT	\N	PRESENT	0
788988	786182	21054E	PARTICIPANT	\N	PRESENT	0
788989	786182	19693L	PARTICIPANT	\N	PRESENT	0
789223	786624	11065P	PARTICIPANT	\N	PRESENT	0
789210	789203	14215L	PARTICIPANT	\N	PRESENT	0
789224	786624	21053D	PARTICIPANT	\N	PRESENT	0
789231	786624	11056N	PARTICIPANT	\N	PRESENT	0
788996	788881	14071N	PARTICIPANT	\N	PRESENT	0
789213	789203	19649G	PARTICIPANT	\N	PRESENT	0
789232	786624	19745F	PARTICIPANT	\N	PRESENT	0
789215	789203	11072N	PARTICIPANT	\N	PRESENT	0
789216	789203	10015M	PARTICIPANT	\N	PRESENT	0
789217	789203	19749K	PARTICIPANT	\N	PRESENT	0
789025	789024	19621T	PARTICIPANT	\N	PRESENT	0
789026	789024	21089R	PARTICIPANT	\N	PRESENT	0
789027	789024	20180F	PARTICIPANT	\N	PRESENT	0
789028	789024	20056C	PARTICIPANT	\N	PRESENT	0
789029	789024	19611R	PRESIDENT	0	PRESENT	0
789030	789024	19697Q	PARTICIPANT	\N	PRESENT	0
789031	789024	20142Y	PARTICIPANT	\N	PRESENT	0
789032	789024	04070G	PARTICIPANT	\N	PRESENT	0
789033	789024	19593H	PARTICIPANT	\N	PRESENT	0
789034	789024	21055F	PARTICIPANT	\N	PRESENT	0
789035	789024	14229S	PARTICIPANT	\N	PRESENT	0
789036	789024	20026V	PARTICIPANT	\N	PRESENT	0
789233	786624	20032T	PARTICIPANT	\N	PRESENT	0
789038	789024	21077M	PARTICIPANT	\N	PRESENT	0
789234	786624	21084L	PARTICIPANT	\N	PRESENT	0
789235	786624	21062E	PARTICIPANT	\N	PRESENT	0
789236	786624	20082E	PARTICIPANT	\N	PRESENT	0
789058	789057	21048G	PARTICIPANT	\N	PRESENT	0
789059	789057	20080C	PARTICIPANT	\N	PRESENT	0
789060	789057	14083S	PARTICIPANT	\N	PRESENT	0
789061	789057	19545Y	PARTICIPANT	\N	PRESENT	0
789062	789057	21090J	PARTICIPANT	\N	PRESENT	0
789063	789057	20070A	PARTICIPANT	\N	PRESENT	0
789064	789057	14327T	PARTICIPANT	\N	PRESENT	0
789065	789057	11048N	PARTICIPANT	\N	PRESENT	0
789066	789057	19711U	PARTICIPANT	\N	PRESENT	0
789067	789057	19349W	PARTICIPANT	\N	PRESENT	0
789068	789057	14225N	PARTICIPANT	\N	PRESENT	0
789069	789057	20044X	PARTICIPANT	\N	PRESENT	0
789237	786624	14257W	PARTICIPANT	\N	PRESENT	0
789071	789057	20062A	PARTICIPANT	\N	PRESENT	0
789073	789072	21046E	PARTICIPANT	\N	PRESENT	0
789238	786624	21096Q	PARTICIPANT	\N	PRESENT	0
789089	789087	11053K	PARTICIPANT	\N	PRESENT	0
789076	789072	19691J	PARTICIPANT	\N	PRESENT	0
789077	789072	14213J	PARTICIPANT	\N	PRESENT	0
789078	789072	19683J	PARTICIPANT	\N	PRESENT	0
789079	789072	19723Y	PARTICIPANT	\N	PRESENT	0
789090	789087	19701S	PARTICIPANT	\N	PRESENT	0
789091	789087	15197G	PARTICIPANT	\N	PRESENT	0
789082	789072	14071N	PARTICIPANT	\N	PRESENT	0
789092	789087	20100N	PARTICIPANT	\N	PRESENT	0
789084	789072	17965H	PARTICIPANT	\N	PRESENT	0
789085	789072	19713W	PARTICIPANT	\N	PRESENT	0
789086	789072	21094N	PARTICIPANT	\N	PRESENT	0
789120	789118	21071F	PARTICIPANT	\N	PRESENT	0
789105	789103	11053K	PARTICIPANT	\N	PRESENT	0
789095	789087	20106U	PARTICIPANT	\N	PRESENT	0
789096	789087	19551W	PARTICIPANT	\N	PRESENT	0
789097	789087	14031R	PARTICIPANT	\N	PRESENT	0
789106	789103	19545Y	PARTICIPANT	\N	PRESENT	0
789099	789087	20136B	PARTICIPANT	\N	PRESENT	0
789100	789087	21051B	PARTICIPANT	\N	PRESENT	0
789101	789087	21076L	PARTICIPANT	\N	PRESENT	0
789239	786624	21066J	PARTICIPANT	\N	PRESENT	0
789122	789118	21045D	PARTICIPANT	\N	PRESENT	0
789109	789103	20070A	PARTICIPANT	\N	PRESENT	0
789110	789103	11070L	PARTICIPANT	\N	PRESENT	0
789111	789103	20134Y	PARTICIPANT	\N	PRESENT	0
789112	789103	11048N	PARTICIPANT	\N	PRESENT	0
789113	789103	19711U	PARTICIPANT	\N	PRESENT	0
789114	789103	19349W	PARTICIPANT	\N	PRESENT	0
789115	789103	14225N	PARTICIPANT	\N	PRESENT	0
789116	789103	20044X	PARTICIPANT	\N	PRESENT	0
789123	789118	14217N	PARTICIPANT	\N	PRESENT	0
789124	789118	14042U	PARTICIPANT	\N	PRESENT	0
789125	789118	14026U	PARTICIPANT	\N	PRESENT	0
789126	789118	19569H	PARTICIPANT	\N	PRESENT	0
789136	789135	19575F	PARTICIPANT	\N	PRESENT	0
789128	789118	14213J	PARTICIPANT	\N	PRESENT	0
789129	789118	19683J	PARTICIPANT	\N	PRESENT	0
789137	789135	21096Q	PARTICIPANT	\N	PRESENT	0
789131	789118	17779H	PARTICIPANT	\N	PRESENT	0
789132	789118	14071N	PARTICIPANT	\N	PRESENT	0
789133	789118	19798U	PARTICIPANT	\N	PRESENT	0
789134	789118	21094N	PARTICIPANT	\N	PRESENT	0
789138	789135	14329V	PARTICIPANT	\N	PRESENT	0
789139	789135	14357A	PARTICIPANT	\N	PRESENT	0
789140	789135	14187A	PARTICIPANT	\N	PRESENT	0
789141	789135	21092L	PARTICIPANT	\N	PRESENT	0
789142	789135	14205J	PARTICIPANT	\N	PRESENT	0
789143	789135	21054E	PARTICIPANT	\N	PRESENT	0
789145	789135	19563B	PARTICIPANT	\N	PRESENT	0
789146	789135	20018V	PARTICIPANT	\N	PRESENT	0
789147	789135	14257W	PARTICIPANT	\N	PRESENT	0
789148	789135	20082E	PARTICIPANT	\N	PRESENT	0
789149	789135	20054A	PARTICIPANT	\N	PRESENT	0
789189	789188	20110Q	PARTICIPANT	\N	PRESENT	0
789160	789151	20090E	PARTICIPANT	\N	PRESENT	0
789161	789151	14026U	PARTICIPANT	\N	PRESENT	0
789162	789151	19691J	PARTICIPANT	\N	PRESENT	0
789164	789151	18193Q	PARTICIPANT	\N	PRESENT	0
789165	789151	21087P	PARTICIPANT	\N	PRESENT	0
789167	789151	14071N	PARTICIPANT	\N	PRESENT	0
789191	789188	20114U	PARTICIPANT	\N	PRESENT	0
789192	789188	04047H	PARTICIPANT	\N	PRESENT	0
789193	789188	14053L	PARTICIPANT	\N	PRESENT	0
789194	789188	11056N	PARTICIPANT	\N	PRESENT	0
789196	789188	19725B	PARTICIPANT	\N	PRESENT	0
789199	789188	14111D	PARTICIPANT	\N	PRESENT	0
789202	789188	19749K	PARTICIPANT	\N	PRESENT	0
768709	762246	19593H	PARTICIPANT	\N	PRESENT	0
768710	762246	19611R	PRESIDENT	0	PRESENT	0
768711	762246	14109K	PARTICIPANT	\N	PRESENT	0
768712	762246	14229S	PARTICIPANT	\N	PRESENT	0
768713	762246	19693L	PARTICIPANT	\N	PRESENT	0
768714	762246	20132W	PARTICIPANT	\N	PRESENT	0
768715	762246	20048C	PARTICIPANT	\N	PRESENT	0
768716	762246	14030Q	PARTICIPANT	\N	PRESENT	0
768717	762246	20172F	PARTICIPANT	\N	PRESENT	0
768718	762246	19533U	PARTICIPANT	\N	PRESENT	0
768719	762246	19621T	PARTICIPANT	\N	PRESENT	0
768720	762246	21063F	PARTICIPANT	\N	PRESENT	0
768722	762246	21091K	PARTICIPANT	\N	PRESENT	0
768723	762246	20264J	PARTICIPANT	\N	PRESENT	0
768724	762246	21059K	PARTICIPANT	\N	PRESENT	0
768725	762246	21077M	PARTICIPANT	\N	PRESENT	0
768726	762246	21055F	PARTICIPANT	\N	PRESENT	0
768727	762246	19699S	PARTICIPANT	\N	PRESENT	0
768729	762246	21089R	PARTICIPANT	\N	PRESENT	0
768730	762246	21058J	PARTICIPANT	\N	PRESENT	0
768733	762246	21037D	PARTICIPANT	\N	PRESENT	0
768740	762246	19735D	PARTICIPANT	\N	PRESENT	0
768849	764240	20094J	PARTICIPANT	\N	PRESENT	0
768850	764240	20104S	PRESIDENT	0	PRESENT	0
768851	764240	20248J	PARTICIPANT	\N	PRESENT	0
768852	764240	14033T	PARTICIPANT	\N	PRESENT	0
768853	764240	21078N	PARTICIPANT	\N	EXCUSE	0
768854	764240	19711U	PARTICIPANT	\N	PRESENT	0
768855	764240	14001X	PARTICIPANT	\N	PRESENT	0
768856	764240	14169X	PARTICIPANT	\N	PRESENT	0
768857	764240	04070G	PARTICIPANT	\N	PRESENT	0
768858	764240	14331P	PARTICIPANT	\N	EXCUSE	0
768859	764240	20042V	PARTICIPANT	\N	PRESENT	0
768947	768946	19693L	PARTICIPANT	\N	PRESENT	0
768948	768946	19533U	PARTICIPANT	\N	PRESENT	0
768949	768946	19611R	PARTICIPANT	\N	PRESENT	0
768950	768946	20132W	PARTICIPANT	\N	PRESENT	0
768951	768946	19673G	PARTICIPANT	\N	PRESENT	0
768953	768946	20102Q	PARTICIPANT	\N	PRESENT	0
768961	768960	14189C	PARTICIPANT	\N	PRESENT	0
768962	768960	20110Q	PARTICIPANT	\N	PRESENT	0
768963	768960	14069U	PARTICIPANT	\N	PRESENT	0
768964	768960	08060W	PARTICIPANT	\N	PRESENT	0
768965	768960	20138D	PARTICIPANT	\N	PRESENT	0
768966	768960	12028B	PARTICIPANT	\N	PRESENT	0
768967	768960	14267Y	PARTICIPANT	\N	PRESENT	0
768968	768960	19295A	PARTICIPANT	\N	PRESENT	0
768969	768960	14259Y	PARTICIPANT	\N	PRESENT	0
778086	777918	17965H	PARTICIPANT	\N	PRESENT	0
778156	777918	14042U	PARTICIPANT	\N	PRESENT	0
778226	777919	17779H	PARTICIPANT	\N	PRESENT	0
768973	768960	14179A	PARTICIPANT	\N	PRESENT	0
768974	768960	19735D	PARTICIPANT	\N	PRESENT	0
768975	768960	86034E	PARTICIPANT	\N	PRESENT	0
768976	768960	08010L	PARTICIPANT	\N	PRESENT	0
787125	786193	14189C	PARTICIPANT	\N	EXCUSE	0
768978	768960	19593H	PARTICIPANT	\N	PRESENT	0
768979	768960	11090Q	PARTICIPANT	\N	PRESENT	0
768980	768960	19798U	PARTICIPANT	\N	PRESENT	0
768981	768960	14229S	PARTICIPANT	\N	PRESENT	0
786738	786191	14231L	PARTICIPANT	\N	EXCUSE	0
768983	768960	20136B	PARTICIPANT	\N	PRESENT	0
768984	768960	19301E	PARTICIPANT	\N	PRESENT	0
768985	768960	20064C	PARTICIPANT	\N	PRESENT	0
768986	768960	19479G	PARTICIPANT	\N	PRESENT	0
787123	786192	14189C	PARTICIPANT	\N	EXCUSE	0
787124	786192	14231L	PARTICIPANT	\N	EXCUSE	0
787126	786193	14231L	PARTICIPANT	\N	EXCUSE	0
787127	786465	14255U	PARTICIPANT	\N	EXCUSE	0
787345	787338	21081H	PARTICIPANT	\N	PRESENT	0
787346	787342	21081H	PARTICIPANT	\N	PRESENT	0
787347	787343	21081H	PARTICIPANT	\N	PRESENT	0
787445	787444	08012N	PARTICIPANT	\N	PRESENT	0
787446	787444	20056C	PARTICIPANT	\N	PRESENT	0
787447	787444	19565D	PARTICIPANT	\N	PRESENT	0
787448	787444	20114U	PARTICIPANT	\N	PRESENT	0
787451	787450	11074Q	PARTICIPANT	\N	PRESENT	0
787452	787450	20120S	PARTICIPANT	\N	PRESENT	0
787453	787450	21079P	PARTICIPANT	\N	PRESENT	0
787454	787450	21073H	PARTICIPANT	\N	PRESENT	0
787455	787450	19954N	PARTICIPANT	\N	PRESENT	0
787456	787450	08015R	PARTICIPANT	\N	PRESENT	0
787457	787450	20028X	PARTICIPANT	\N	PRESENT	0
788836	788835	20138D	PARTICIPANT	\N	PRESENT	0
791472	789274	14069U	PARTICIPANT	\N	PRESENT	0
788839	788835	14221J	PARTICIPANT	\N	PRESENT	0
788840	788835	18231D	PARTICIPANT	\N	PRESENT	0
788841	788835	19533U	PARTICIPANT	\N	PRESENT	0
788844	788835	21059K	PARTICIPANT	\N	PRESENT	0
788846	788835	20092G	PARTICIPANT	\N	PRESENT	0
788851	788835	19735D	PARTICIPANT	\N	EXCUSE	0
788854	788835	19575F	PARTICIPANT	\N	EXCUSE	0
788856	788835	20072C	PARTICIPANT	\N	EXCUSE	0
788858	788835	19723Y	PARTICIPANT	\N	EXCUSE	0
791446	789274	14083S	PARTICIPANT	\N	PRESENT	0
791447	789274	19760E	PARTICIPANT	\N	PRESENT	0
791473	789274	21071F	PARTICIPANT	\N	PRESENT	0
791474	789274	14281W	PARTICIPANT	\N	PRESENT	0
791475	789274	19413M	PARTICIPANT	\N	PRESENT	0
791476	789274	20048C	PARTICIPANT	\N	PRESENT	0
791477	789274	11056N	PARTICIPANT	\N	PRESENT	0
791478	789274	19691J	PARTICIPANT	\N	PRESENT	0
791479	789274	19699S	PARTICIPANT	\N	PRESENT	0
791480	789274	14071N	PARTICIPANT	\N	PRESENT	0
791503	789275	14071N	PARTICIPANT	\N	PRESENT	0
791504	789275	21087P	PARTICIPANT	\N	PRESENT	0
791505	789275	18193Q	PARTICIPANT	\N	PRESENT	0
791506	789275	21097R	PARTICIPANT	\N	PRESENT	0
791507	789275	19347U	PARTICIPANT	\N	PRESENT	0
791508	789275	14281W	PARTICIPANT	\N	PRESENT	0
791509	789275	14083S	PARTICIPANT	\N	PRESENT	0
791510	789275	14042U	PARTICIPANT	\N	PRESENT	0
791511	789275	21040X	PARTICIPANT	\N	PRESENT	0
791512	789275	21094N	PARTICIPANT	\N	PRESENT	0
791513	789275	19563B	PARTICIPANT	\N	PRESENT	0
791514	789275	20062A	PARTICIPANT	\N	PRESENT	0
791515	789275	20090E	PARTICIPANT	\N	PRESENT	0
791516	789275	21071F	PARTICIPANT	\N	PRESENT	0
791517	789275	19553Y	PARTICIPANT	\N	PRESENT	0
791518	789275	19760E	PARTICIPANT	\N	PRESENT	0
791519	789275	19569H	PARTICIPANT	\N	PRESENT	0
791520	789275	19691J	PARTICIPANT	\N	PRESENT	0
791556	789275	21070E	PARTICIPANT	\N	PRESENT	0
791501	789275	14229S	PARTICIPANT	\N	PRESENT	0
791502	789275	21064G	PARTICIPANT	\N	PRESENT	0
791557	789275	19619A	PARTICIPANT	\N	PRESENT	0
791559	789736	11090Q	PARTICIPANT	\N	PRESENT	0
791560	789736	19954N	PARTICIPANT	\N	EXCUSE	0
791599	789276	20090E	PARTICIPANT	\N	PRESENT	0
791600	789276	19619A	PARTICIPANT	\N	PRESENT	0
791601	789276	11070L	PARTICIPANT	\N	PRESENT	0
791602	789276	21029D	PARTICIPANT	\N	PRESENT	0
791603	789276	04045F	PARTICIPANT	\N	PRESENT	0
791604	789276	19760E	PARTICIPANT	\N	PRESENT	0
791605	789276	21040X	PARTICIPANT	\N	PRESENT	0
791606	789276	21057H	PARTICIPANT	\N	PRESENT	0
791607	789276	14033T	PARTICIPANT	\N	PRESENT	0
791608	789276	21095P	PARTICIPANT	\N	PRESENT	0
791609	789276	20110Q	PARTICIPANT	\N	PRESENT	0
791610	789276	19719D	PARTICIPANT	\N	PRESENT	0
791611	789276	20062A	PARTICIPANT	\N	PRESENT	0
791614	789276	21071F	PARTICIPANT	\N	PRESENT	0
791615	791612	15197G	PARTICIPANT	\N	EXCUSE	0
791616	789276	19533U	PARTICIPANT	\N	PRESENT	0
791634	789276	99004R	PARTICIPANT	\N	PRESENT	0
791597	789276	14179A	PARTICIPANT	\N	PRESENT	0
791598	789276	21070E	PARTICIPANT	\N	PRESENT	0
791635	791612	14255U	PARTICIPANT	\N	EXCUSE	0
791637	789276	19798U	PARTICIPANT	\N	PRESENT	0
791639	791613	14255U	PARTICIPANT	\N	EXCUSE	0
791648	789276	20032T	PARTICIPANT	\N	PRESENT	0
791649	789276	14275Y	PARTICIPANT	\N	PRESENT	0
791650	789276	17023S	PARTICIPANT	\N	PRESENT	0
791722	791721	04047H	PARTICIPANT	\N	PRESENT	0
791723	791721	18231D	PARTICIPANT	\N	PRESENT	0
791835	791834	14053L	PARTICIPANT	\N	PRESENT	0
791836	791834	19649G	PARTICIPANT	\N	PRESENT	0
791838	791834	20266L	PARTICIPANT	\N	PRESENT	0
780765	780474	21053D	PARTICIPANT	\N	PRESENT	0
780766	780474	21038E	PARTICIPANT	\N	PRESENT	0
780767	780474	21064G	PARTICIPANT	\N	PRESENT	0
780768	780474	19713W	PARTICIPANT	\N	PRESENT	0
780769	780474	01034P	PARTICIPANT	\N	PRESENT	0
780770	780474	19479G	PARTICIPANT	\N	PRESENT	0
780771	780474	05008E	PARTICIPANT	\N	PRESENT	0
780772	780474	20112S	PARTICIPANT	\N	PRESENT	0
780773	780474	11048N	PARTICIPANT	\N	PRESENT	0
780774	780474	19758L	PARTICIPANT	\N	PRESENT	0
780776	780474	19421M	PARTICIPANT	\N	PRESENT	0
780777	780474	14173T	PARTICIPANT	\N	PRESENT	0
780778	780474	20062A	PARTICIPANT	\N	PRESENT	0
780779	780474	20058E	PARTICIPANT	\N	PRESENT	0
780785	780474	14193X	PARTICIPANT	\N	PRESENT	0
780787	780474	05012A	PARTICIPANT	\N	PRESENT	0
780788	780474	14253S	PARTICIPANT	\N	PRESENT	0
780789	780474	20138D	PARTICIPANT	\N	PRESENT	0
780790	780474	20024T	PARTICIPANT	\N	PRESENT	0
780791	780474	21069M	PARTICIPANT	\N	PRESENT	0
780792	780474	19545Y	PARTICIPANT	\N	PRESENT	0
780793	780474	14169X	PARTICIPANT	\N	PRESENT	0
780794	780474	20286Q	PARTICIPANT	\N	PRESENT	0
780795	780474	19399H	PARTICIPANT	\N	PRESENT	0
780800	780474	19760E	PARTICIPANT	\N	PRESENT	0
780797	780474	17023S	PARTICIPANT	\N	PRESENT	0
780798	780474	04042C	PARTICIPANT	\N	PRESENT	0
780803	780474	20104S	PARTICIPANT	\N	PRESENT	0
780801	780474	21036C	PARTICIPANT	\N	PRESENT	0
780804	780474	20142Y	PARTICIPANT	\N	PRESENT	0
780805	780474	14037X	PARTICIPANT	\N	PRESENT	0
780806	780474	08012N	PARTICIPANT	\N	PRESENT	0
780807	780474	17779H	PARTICIPANT	\N	PRESENT	0
780808	780474	19631V	PARTICIPANT	\N	PRESENT	0
780809	780474	20134Y	PARTICIPANT	\N	PRESENT	0
780810	780474	20130U	PARTICIPANT	\N	PRESENT	0
780811	780474	08010L	PARTICIPANT	\N	PRESENT	0
780812	780474	17367Q	PARTICIPANT	\N	PRESENT	0
780813	780474	19533U	PARTICIPANT	\N	PRESENT	0
780816	780474	11085T	PARTICIPANT	\N	PRESENT	0
780817	780474	14219Q	PARTICIPANT	\N	PRESENT	0
780818	780474	21032X	PARTICIPANT	\N	PRESENT	0
780854	780474	19745F	PARTICIPANT	\N	PRESENT	0
780855	780474	20118Y	PARTICIPANT	\N	PRESENT	0
780856	780474	21060C	PARTICIPANT	\N	PRESENT	0
780857	780474	20108W	PARTICIPANT	\N	PRESENT	0
780858	780474	08045X	PARTICIPANT	\N	PRESENT	0
780859	780474	19551W	PARTICIPANT	\N	PRESENT	0
780860	780474	21093M	PARTICIPANT	\N	PRESENT	0
780861	780474	20266L	PARTICIPANT	\N	PRESENT	0
780862	780474	11115U	PARTICIPANT	\N	PRESENT	0
780863	780474	20016T	PARTICIPANT	\N	PRESENT	0
781177	779650	14259Y	PARTICIPANT	\N	PRESENT	0
781178	779255	14331P	PRESIDENT	0	PRESENT	0
781179	779255	17737W	PARTICIPANT	\N	PRESENT	0
781180	779255	14189C	PARTICIPANT	\N	EXCUSE	0
781181	779255	20042V	PARTICIPANT	\N	EXCUSE	0
781182	779650	20142Y	PARTICIPANT	\N	PRESENT	0
781183	779650	19693L	PARTICIPANT	\N	PRESENT	0
781184	779650	19479G	PARTICIPANT	\N	PRESENT	0
781185	779650	19745F	PARTICIPANT	\N	PRESENT	0
781186	779650	14073Q	PARTICIPANT	\N	PRESENT	0
781187	779650	20248J	PARTICIPANT	\N	PRESENT	0
781188	779650	20124W	PARTICIPANT	\N	PRESENT	0
781189	779650	19679N	PARTICIPANT	\N	PRESENT	0
781190	779650	21036C	PARTICIPANT	\N	PRESENT	0
781191	779650	20056C	PARTICIPANT	\N	PRESENT	0
781192	779650	19954N	PARTICIPANT	\N	PRESENT	0
781193	779650	20038A	PARTICIPANT	\N	PRESENT	0
781197	779650	21039F	PARTICIPANT	\N	PRESENT	0
781195	779650	21063F	PARTICIPANT	\N	PRESENT	0
781196	779650	21047F	PARTICIPANT	\N	PRESENT	0
781198	779650	19611R	PARTICIPANT	\N	PRESENT	0
781199	779650	20134Y	PARTICIPANT	\N	PRESENT	0
781200	779650	21037D	PARTICIPANT	\N	PRESENT	0
781201	779650	21079P	PARTICIPANT	\N	PRESENT	0
781202	779650	21077M	PARTICIPANT	\N	PRESENT	0
781203	779650	08012N	PARTICIPANT	\N	PRESENT	0
781204	779650	14109K	PARTICIPANT	\N	PRESENT	0
781205	779650	19349W	PARTICIPANT	\N	PRESENT	0
781206	779650	20112S	PARTICIPANT	\N	PRESENT	0
781207	779650	20102Q	PARTICIPANT	\N	PRESENT	0
781208	779650	19723Y	PARTICIPANT	\N	PRESENT	0
781209	779650	11043H	PARTICIPANT	\N	PRESENT	0
781210	779650	08028W	PARTICIPANT	\N	PRESENT	0
781211	779650	20052X	PARTICIPANT	\N	PRESENT	0
781212	779650	20026V	PARTICIPANT	\N	PRESENT	0
781213	779650	21055F	PARTICIPANT	\N	PRESENT	0
781214	779650	19367Y	PARTICIPANT	\N	PRESENT	0
781215	779650	20132W	PARTICIPANT	\N	PRESENT	0
781216	779650	19593H	PARTICIPANT	\N	PRESENT	0
781217	779650	04047H	PARTICIPANT	\N	PRESENT	0
781218	779650	21044C	PARTICIPANT	\N	PRESENT	0
781222	779650	19621T	PARTICIPANT	\N	PRESENT	0
781223	779650	20264J	PARTICIPANT	\N	PRESENT	0
781357	779299	19703U	PARTICIPANT	\N	PRESENT	0
781358	779299	20140W	PARTICIPANT	\N	PRESENT	0
781359	779299	19657G	PARTICIPANT	\N	PRESENT	0
781360	779299	20148F	PARTICIPANT	\N	PRESENT	0
781361	779299	21039F	PARTICIPANT	\N	PRESENT	0
781362	779299	11045K	PARTICIPANT	\N	PRESENT	0
781363	779299	19629C	PARTICIPANT	\N	PRESENT	0
781364	779299	19679N	PARTICIPANT	\N	PRESENT	0
781365	779299	19331L	PARTICIPANT	\N	PRESENT	0
781366	779299	14213J	PARTICIPANT	\N	PRESENT	0
781413	780472	20088L	PARTICIPANT	\N	PRESENT	0
781368	779299	14071N	PRESIDENT	0	PRESENT	0
781369	779299	14217N	PARTICIPANT	\N	PRESENT	0
781370	779299	21081H	PARTICIPANT	\N	PRESENT	0
781371	779299	19301E	PARTICIPANT	\N	PRESENT	0
781372	779299	19691J	PARTICIPANT	\N	PRESENT	0
781373	779299	18193Q	PARTICIPANT	\N	PRESENT	0
781374	779299	14223L	PARTICIPANT	\N	PRESENT	0
781375	779299	19866P	PARTICIPANT	\N	PRESENT	0
781376	779299	19295A	PARTICIPANT	\N	PRESENT	0
781377	779299	20096L	PARTICIPANT	\N	PRESENT	0
781378	779299	20248J	PARTICIPANT	\N	PRESENT	0
781379	779299	21097R	PARTICIPANT	\N	PRESENT	0
781411	779299	14281W	PARTICIPANT	\N	PRESENT	0
781412	779299	19591F	PARTICIPANT	\N	PRESENT	0
781414	780472	14357A	PARTICIPANT	\N	PRESENT	0
781415	780472	14221J	PARTICIPANT	\N	PRESENT	0
781416	780472	20104S	PARTICIPANT	\N	PRESENT	0
781417	780472	19631V	PARTICIPANT	\N	PRESENT	0
781418	780472	08015R	PARTICIPANT	\N	PRESENT	0
781419	780472	19575F	PARTICIPANT	\N	PRESENT	0
781420	780472	20018V	PARTICIPANT	\N	PRESENT	0
781421	780472	08028W	PARTICIPANT	\N	PRESENT	0
781422	780472	19563B	PARTICIPANT	\N	PRESENT	0
781423	780472	14329V	PARTICIPANT	\N	PRESENT	0
781424	780472	20028X	PARTICIPANT	\N	PRESENT	0
781425	780472	14038Y	PARTICIPANT	\N	PRESENT	0
781426	780472	21052C	PARTICIPANT	\N	PRESENT	0
781427	780472	21054E	PARTICIPANT	\N	PRESENT	0
781428	780472	14187A	PRESIDENT	0	PRESENT	0
781429	780472	20038A	PARTICIPANT	\N	PRESENT	0
781430	780472	21083K	PARTICIPANT	\N	PRESENT	0
781431	780472	21086N	PARTICIPANT	\N	PRESENT	0
781432	780472	19695N	PARTICIPANT	\N	PRESENT	0
781433	780472	21092L	PARTICIPANT	\N	PRESENT	0
781434	780472	20054A	PARTICIPANT	\N	PRESENT	0
781435	780472	19507S	PARTICIPANT	\N	PRESENT	0
781436	780472	20066E	PARTICIPANT	\N	PRESENT	0
781437	780472	20286Q	PARTICIPANT	\N	PRESENT	0
781438	780472	14207L	PARTICIPANT	\N	PRESENT	0
781439	780472	14257W	PARTICIPANT	\N	PRESENT	0
781440	780472	20084G	PARTICIPANT	\N	PRESENT	0
781441	780472	21075K	PARTICIPANT	\N	PRESENT	0
781442	779281	14089Y	PRESIDENT	0	PRESENT	0
781443	779281	14053L	PARTICIPANT	\N	PRESENT	0
781444	779281	21044C	PARTICIPANT	\N	PRESENT	0
781445	779281	20036X	PARTICIPANT	\N	PRESENT	0
781446	779281	14111D	PARTICIPANT	\N	PRESENT	0
781447	779281	21057H	PARTICIPANT	\N	PRESENT	0
781448	779281	19111A	PARTICIPANT	\N	PRESENT	0
781449	779281	14069U	PARTICIPANT	\N	PRESENT	0
781450	779281	14215L	PARTICIPANT	\N	PRESENT	0
781451	779281	19585H	PARTICIPANT	\N	PRESENT	0
781452	779281	04008A	PARTICIPANT	\N	PRESENT	0
781453	779281	21040X	PARTICIPANT	\N	PRESENT	0
781454	779281	14231L	PARTICIPANT	\N	PRESENT	0
774161	769595	19593H	PARTICIPANT	\N	PRESENT	0
774162	769595	20132W	PARTICIPANT	\N	PRESENT	0
774163	769595	19699S	PARTICIPANT	\N	PRESENT	0
774164	769595	14073Q	PARTICIPANT	\N	PRESENT	0
774165	769595	19611R	PRESIDENT	0	PRESENT	0
774166	769595	20138D	PARTICIPANT	\N	PRESENT	0
774167	769595	04033B	PARTICIPANT	\N	PRESENT	0
774168	769595	20142Y	PARTICIPANT	\N	PRESENT	0
774169	769595	20048C	PARTICIPANT	\N	PRESENT	0
774170	769595	19693L	PARTICIPANT	\N	PRESENT	0
774171	769595	20102Q	PARTICIPANT	\N	PRESENT	0
774172	769595	20052X	PARTICIPANT	\N	PRESENT	0
774173	769595	20172F	PARTICIPANT	\N	PRESENT	0
774174	769595	20056C	PARTICIPANT	\N	PRESENT	0
774175	769595	20180F	PARTICIPANT	\N	PRESENT	0
774176	769595	20264J	PARTICIPANT	\N	PRESENT	0
774177	769595	18395Y	PARTICIPANT	\N	PRESENT	0
774178	769595	14109K	PARTICIPANT	\N	PRESENT	0
774179	769595	21089R	PARTICIPANT	\N	PRESENT	0
774180	769595	21037D	PARTICIPANT	\N	PRESENT	0
774181	769595	20124W	PARTICIPANT	\N	PRESENT	0
774182	769595	21077M	PARTICIPANT	\N	PRESENT	0
774183	769595	20026V	PARTICIPANT	\N	PRESENT	0
774197	769595	04070G	PARTICIPANT	\N	PRESENT	0
774198	769595	21058J	PARTICIPANT	\N	PRESENT	0
774199	769595	21059K	PARTICIPANT	\N	PRESENT	0
774200	769595	14229S	PARTICIPANT	\N	PRESENT	0
774201	769595	20112S	PARTICIPANT	\N	PRESENT	0
774202	769595	08012N	PARTICIPANT	\N	PRESENT	0
774203	769595	21091K	PARTICIPANT	\N	PRESENT	0
774204	769595	14030Q	PARTICIPANT	\N	PRESENT	0
774205	769595	21063F	PARTICIPANT	\N	PRESENT	0
774206	769595	19735D	PARTICIPANT	\N	PRESENT	0
774207	769595	14123H	PARTICIPANT	\N	PRESENT	0
774208	769595	11043H	PARTICIPANT	\N	PRESENT	0
774209	769595	14021P	PARTICIPANT	\N	PRESENT	0
774210	769595	19621T	PARTICIPANT	\N	PRESENT	0
774211	773244	20092G	PARTICIPANT	\N	PRESENT	0
774212	773244	19782L	PARTICIPANT	\N	PRESENT	0
774301	772599	21079P	PARTICIPANT	\N	PRESENT	0
774214	773244	14221J	PARTICIPANT	\N	PRESENT	0
774215	773244	19631V	PARTICIPANT	\N	PRESENT	0
774216	773244	20104S	PARTICIPANT	\N	PRESENT	0
774217	773244	19705W	PARTICIPANT	\N	PRESENT	0
774218	773244	08015R	PARTICIPANT	\N	PRESENT	0
774219	773244	19575F	PARTICIPANT	\N	PRESENT	0
774220	773244	20018V	PARTICIPANT	\N	PRESENT	0
774221	773244	08028W	PARTICIPANT	\N	PRESENT	0
774222	773244	19563B	PARTICIPANT	\N	PRESENT	0
774223	773244	21096Q	PARTICIPANT	\N	PRESENT	0
774224	773244	20028X	PARTICIPANT	\N	PRESENT	0
774225	773244	14038Y	PARTICIPANT	\N	PRESENT	0
774226	773244	21052C	PARTICIPANT	\N	PRESENT	0
774227	773244	20034V	PARTICIPANT	\N	PRESENT	0
774228	773244	14187A	PRESIDENT	0	PRESENT	0
774229	773244	21075K	PARTICIPANT	\N	PRESENT	0
774230	773244	21083K	PARTICIPANT	\N	PRESENT	0
774231	773244	21086N	PARTICIPANT	\N	PRESENT	0
774232	773244	20144B	PARTICIPANT	\N	PRESENT	0
774233	773244	19695N	PARTICIPANT	\N	PRESENT	0
774234	773244	21092L	PARTICIPANT	\N	PRESENT	0
774235	773244	14033T	PARTICIPANT	\N	PRESENT	0
774236	773244	21033Y	PARTICIPANT	\N	PRESENT	0
774237	773244	20054A	PARTICIPANT	\N	PRESENT	0
774238	773244	21034A	PARTICIPANT	\N	PRESENT	0
774239	773244	20060X	PARTICIPANT	\N	PRESENT	0
774240	773244	20066E	PARTICIPANT	\N	PRESENT	0
774241	773244	19507S	PARTICIPANT	\N	PRESENT	0
774242	773244	21066J	PARTICIPANT	\N	PRESENT	0
774243	773244	20286Q	PARTICIPANT	\N	PRESENT	0
774244	773244	14207L	PARTICIPANT	\N	PRESENT	0
774245	773244	20084G	PARTICIPANT	\N	PRESENT	0
774246	773244	14257W	PARTICIPANT	\N	PRESENT	0
774247	773244	20088L	PARTICIPANT	\N	EXCUSE	0
774248	773244	19383Y	PARTICIPANT	\N	PRESENT	0
774249	769595	19697Q	PARTICIPANT	\N	PRESENT	0
774250	769595	19533U	PARTICIPANT	\N	PRESENT	0
774299	772599	20070A	PARTICIPANT	\N	PRESENT	0
774300	772599	21057H	PARTICIPANT	\N	PRESENT	0
774302	772599	11056N	PARTICIPANT	\N	PRESENT	0
774303	772599	11040E	PARTICIPANT	\N	PRESENT	0
774304	772599	20080C	PARTICIPANT	\N	PRESENT	0
774305	772599	19479G	PARTICIPANT	\N	PRESENT	0
774306	772599	19713W	PARTICIPANT	\N	PRESENT	0
774307	772599	11053K	PARTICIPANT	\N	PRESENT	0
774308	772599	14179A	PARTICIPANT	\N	PRESENT	0
774309	772599	14083S	PARTICIPANT	\N	PRESENT	0
774310	772599	14327T	PARTICIPANT	\N	PRESENT	0
774311	772599	19399H	PARTICIPANT	\N	PRESENT	0
774312	772599	20044X	PARTICIPANT	\N	PRESENT	0
774313	772599	20062A	PARTICIPANT	\N	PRESENT	0
774314	772599	19711U	PARTICIPANT	\N	PRESENT	0
774315	772599	14217N	PARTICIPANT	\N	PRESENT	0
774316	772599	14069U	PARTICIPANT	\N	PRESENT	0
774317	772599	08034U	PARTICIPANT	\N	PRESENT	0
774318	772599	21090J	PARTICIPANT	\N	PRESENT	0
774319	772599	20126Y	PARTICIPANT	\N	PRESENT	0
774320	772599	20024T	PARTICIPANT	\N	PRESENT	0
774321	772599	21044C	PARTICIPANT	\N	PRESENT	0
774322	772599	14225N	PARTICIPANT	\N	PRESENT	0
774323	772599	11048N	PARTICIPANT	\N	PRESENT	0
774324	772599	14107H	PARTICIPANT	\N	PRESENT	0
774325	772599	21040X	PARTICIPANT	\N	PRESENT	0
774326	772599	14121F	PARTICIPANT	\N	PRESENT	0
774327	772599	19749K	PARTICIPANT	\N	PRESENT	0
774328	772599	20266L	PARTICIPANT	\N	PRESENT	0
774329	772599	10015M	PARTICIPANT	\N	PRESENT	0
774330	772599	21048G	PARTICIPANT	\N	PRESENT	0
774331	772599	14331P	PARTICIPANT	\N	PRESENT	0
774336	772599	19647E	PARTICIPANT	\N	PRESENT	0
774337	772599	07004J	PARTICIPANT	\N	PRESENT	0
775324	772600	20066E	PARTICIPANT	\N	PRESENT	0
775325	772600	11048N	PARTICIPANT	\N	PRESENT	0
775326	772600	14225N	PARTICIPANT	\N	PRESENT	0
775327	772600	11065P	PARTICIPANT	\N	PRESENT	0
775328	772600	21043B	PARTICIPANT	\N	PRESENT	0
775329	772600	14021P	PARTICIPANT	\N	PRESENT	0
775330	772600	14030Q	PARTICIPANT	\N	PRESENT	0
775331	772600	18231D	PARTICIPANT	\N	PRESENT	0
775332	772600	21064G	PARTICIPANT	\N	PRESENT	0
775333	772600	14071N	PARTICIPANT	\N	PRESENT	0
775334	772600	14033T	PARTICIPANT	\N	PRESENT	0
775335	772600	14357A	PARTICIPANT	\N	PRESENT	0
775336	772600	20126Y	PARTICIPANT	\N	PRESENT	0
775337	772600	20172F	PARTICIPANT	\N	PRESENT	0
775338	772600	14231L	PARTICIPANT	\N	PRESENT	0
775339	772600	14026U	PARTICIPANT	\N	PRESENT	0
775340	772600	21029D	PARTICIPANT	\N	PRESENT	0
775344	772600	20134Y	PARTICIPANT	\N	PRESENT	0
775345	772600	19301E	PARTICIPANT	\N	PRESENT	0
775346	772600	14327T	PARTICIPANT	\N	PRESENT	0
775412	772615	19593H	PARTICIPANT	\N	PRESENT	0
775413	772615	21034A	PARTICIPANT	\N	PRESENT	0
775414	772615	11040E	PARTICIPANT	\N	PRESENT	0
775415	772615	21079P	PARTICIPANT	\N	PRESENT	0
775416	772615	20084G	PARTICIPANT	\N	PRESENT	0
775417	772615	20142Y	PARTICIPANT	\N	PRESENT	0
775418	772615	19545Y	PARTICIPANT	\N	PRESENT	0
775419	772615	11048N	PARTICIPANT	\N	PRESENT	0
775420	772615	20046A	PARTICIPANT	\N	PRESENT	0
775421	772615	21055F	PARTICIPANT	\N	PRESENT	0
775422	772615	19631V	PARTICIPANT	\N	PRESENT	0
775423	772615	19782L	PARTICIPANT	\N	PRESENT	0
775424	772615	20126Y	PARTICIPANT	\N	PRESENT	0
775425	772615	20054A	PARTICIPANT	\N	PRESENT	0
775426	772615	19798U	PARTICIPANT	\N	PRESENT	0
775427	772615	07004J	PARTICIPANT	\N	PRESENT	0
775428	772615	21062E	PARTICIPANT	\N	PRESENT	0
775429	772615	19647E	PARTICIPANT	\N	PRESENT	0
775430	772615	11065P	PARTICIPANT	\N	PRESENT	0
775431	772615	08010L	PARTICIPANT	\N	PRESENT	0
775432	772615	14195A	PARTICIPANT	\N	PRESENT	0
775433	772615	11043H	PARTICIPANT	\N	PRESENT	0
775434	772615	14357A	PARTICIPANT	\N	PRESENT	0
775435	772615	05012A	PARTICIPANT	\N	PRESENT	0
775436	772615	21090J	PARTICIPANT	\N	PRESENT	0
775437	772615	19565D	PARTICIPANT	\N	PRESENT	0
775438	772615	01058X	PARTICIPANT	\N	PRESENT	0
775439	772615	14069U	PARTICIPANT	\N	PRESENT	0
775440	772615	19399H	PARTICIPANT	\N	PRESENT	0
775441	772615	14173T	PARTICIPANT	\N	PRESENT	0
789168	789151	21097R	PARTICIPANT	\N	PRESENT	0
789169	789151	20130U	PARTICIPANT	\N	PRESENT	0
789170	789151	17965H	PARTICIPANT	\N	PRESENT	0
789240	786624	19629C	PARTICIPANT	\N	PRESENT	0
789173	789172	21071F	PARTICIPANT	\N	PRESENT	0
789174	789172	20080C	PARTICIPANT	\N	PRESENT	0
789175	789172	19782L	PARTICIPANT	\N	PRESENT	0
789176	789172	20144B	PARTICIPANT	\N	PRESENT	0
789177	789172	14187A	PARTICIPANT	\N	PRESENT	0
789242	786624	21076L	PARTICIPANT	\N	PRESENT	0
789179	789172	20120S	PARTICIPANT	\N	PRESENT	0
789180	789172	19711U	PARTICIPANT	\N	PRESENT	0
789181	789172	14219Q	PARTICIPANT	\N	PRESENT	0
789182	789172	14031R	PARTICIPANT	\N	PRESENT	0
789183	789172	14221J	PARTICIPANT	\N	PRESENT	0
789184	789172	20028X	PARTICIPANT	\N	PRESENT	0
789185	789172	14257W	PARTICIPANT	\N	PRESENT	0
789186	789172	20092G	PARTICIPANT	\N	PRESENT	0
789187	789172	20062A	PARTICIPANT	\N	PRESENT	0
789241	786624	21083K	PARTICIPANT	\N	PRESENT	0
789243	786624	20086J	PARTICIPANT	\N	PRESENT	0
789244	786624	20116W	PARTICIPANT	\N	PRESENT	0
789245	786624	21039F	PARTICIPANT	\N	PRESENT	0
789246	786624	19399H	PARTICIPANT	\N	PRESENT	0
789247	786624	21095P	PARTICIPANT	\N	PRESENT	0
789248	786624	14169X	PARTICIPANT	\N	PRESENT	0
789249	786624	14205J	PARTICIPANT	\N	PRESENT	0
789257	786624	20068G	PARTICIPANT	\N	PRESENT	0
789251	786624	21075K	PARTICIPANT	\N	PRESENT	0
789252	786624	20022R	PARTICIPANT	\N	PRESENT	0
789253	786624	20100N	PARTICIPANT	\N	PRESENT	0
789254	786624	21054E	PARTICIPANT	\N	PRESENT	0
789255	786624	21034A	PARTICIPANT	\N	PRESENT	0
789256	786624	14037X	PARTICIPANT	\N	PRESENT	0
789258	786624	21079P	PARTICIPANT	\N	PRESENT	0
789260	786624	14221J	PARTICIPANT	\N	PRESENT	0
789261	786624	20126Y	PARTICIPANT	\N	PRESENT	0
789262	786624	18083K	PARTICIPANT	\N	PRESENT	0
789264	786624	19749K	PARTICIPANT	\N	PRESENT	0
789269	786624	19533U	PARTICIPANT	\N	PRESENT	0
789270	786624	11085T	PARTICIPANT	\N	PRESENT	0
789272	789271	19735D	PARTICIPANT	\N	PRESENT	0
789273	789271	19723Y	PARTICIPANT	\N	PRESENT	0
789317	789316	21089R	PARTICIPANT	\N	PRESENT	0
789318	789316	19782L	PARTICIPANT	\N	PRESENT	0
789319	789316	21083K	PARTICIPANT	\N	PRESENT	0
789320	789316	04042C	PARTICIPANT	\N	PRESENT	0
789321	789316	19251M	PARTICIPANT	\N	PRESENT	0
789322	789316	19647E	PARTICIPANT	\N	PRESENT	0
789323	789316	19111A	PARTICIPANT	\N	PRESENT	0
789324	789316	21085M	PARTICIPANT	\N	PRESENT	0
789325	789316	19349W	PARTICIPANT	\N	PRESENT	0
789326	789316	19593H	PARTICIPANT	\N	PRESENT	0
789327	789316	04070G	PARTICIPANT	\N	PRESENT	0
789328	789316	21073H	PARTICIPANT	\N	PRESENT	0
789329	789316	14021P	PARTICIPANT	\N	PRESENT	0
789330	789316	20110Q	PARTICIPANT	\N	PRESENT	0
789331	789316	20114U	PARTICIPANT	\N	PRESENT	0
789332	789316	14195A	PARTICIPANT	\N	PRESENT	0
789334	789333	19251M	PARTICIPANT	\N	PRESENT	0
789381	789380	14053L	PARTICIPANT	\N	PRESENT	0
789382	789380	19649G	PARTICIPANT	\N	PRESENT	0
789384	789383	14053L	PARTICIPANT	\N	PRESENT	0
789385	789383	19649G	PARTICIPANT	\N	PRESENT	0
789387	789386	14053L	PARTICIPANT	\N	PRESENT	0
789388	789386	19649G	PARTICIPANT	\N	PRESENT	0
789512	789511	12028B	PARTICIPANT	\N	PRESENT	0
789513	789511	14267Y	PARTICIPANT	\N	PRESENT	0
789514	789511	08010L	PARTICIPANT	\N	PRESENT	0
789544	786667	19611R	PRESIDENT	0	PRESENT	0
789545	786667	20052X	PARTICIPANT	\N	PRESENT	0
789547	786667	20026V	PARTICIPANT	\N	PRESENT	0
789558	786667	14109K	PARTICIPANT	\N	PRESENT	0
789550	786667	19735D	PARTICIPANT	\N	EXCUSE	0
789551	786667	19699S	PARTICIPANT	\N	PRESENT	0
789552	786667	20048C	PARTICIPANT	\N	PRESENT	0
789553	786667	19621T	PARTICIPANT	\N	PRESENT	0
789554	786667	11043H	PARTICIPANT	\N	PRESENT	0
789555	786667	20132W	PARTICIPANT	\N	PRESENT	0
789556	786667	20180F	PARTICIPANT	\N	PRESENT	0
789557	786667	21037D	PARTICIPANT	\N	PRESENT	0
789559	786667	08012N	PARTICIPANT	\N	PRESENT	0
789560	786667	21055F	PARTICIPANT	\N	PRESENT	0
789561	786667	20058E	PARTICIPANT	\N	PRESENT	0
789562	786667	21058J	PARTICIPANT	\N	PRESENT	0
789563	786667	21077M	PARTICIPANT	\N	PRESENT	0
789565	786667	21063F	PARTICIPANT	\N	PRESENT	0
789566	786667	14030Q	PARTICIPANT	\N	PRESENT	0
789567	786667	21089R	PARTICIPANT	\N	PRESENT	0
789568	786667	20264J	PARTICIPANT	\N	PRESENT	0
789569	786667	19533U	PARTICIPANT	\N	PRESENT	0
789570	786667	04033B	PARTICIPANT	\N	EXCUSE	0
789571	786667	20142Y	PARTICIPANT	\N	PRESENT	0
789884	789278	20036X	PARTICIPANT	\N	PRESENT	0
789885	789278	14275Y	PARTICIPANT	\N	PRESENT	0
789886	789278	21076L	PARTICIPANT	\N	PRESENT	0
789887	789278	14069U	PARTICIPANT	\N	PRESENT	0
789888	789278	08018U	PARTICIPANT	\N	PRESENT	0
789889	789278	21038E	PARTICIPANT	\N	PRESENT	0
789890	789278	19749K	PARTICIPANT	\N	PRESENT	0
789891	789278	04047H	PRESIDENT	0	PRESENT	0
789893	789278	20074E	PARTICIPANT	\N	PRESENT	0
789894	789278	19585H	PARTICIPANT	\N	PRESENT	0
789895	789278	19447X	PARTICIPANT	\N	PRESENT	0
789896	789278	14231L	PARTICIPANT	\N	PRESENT	0
789897	789278	20098N	PARTICIPANT	\N	PRESENT	0
789898	789278	21056G	PARTICIPANT	\N	PRESENT	0
789899	789278	18207D	PARTICIPANT	\N	PRESENT	0
789900	789278	18231D	PARTICIPANT	\N	PRESENT	0
789901	789278	21088Q	PARTICIPANT	\N	PRESENT	0
789902	789278	20114U	PARTICIPANT	\N	PRESENT	0
789903	789278	21095P	PARTICIPANT	\N	PRESENT	0
789904	789278	14053L	PARTICIPANT	\N	PRESENT	0
789905	789278	14111D	PARTICIPANT	\N	PRESENT	0
789906	789278	14189C	PARTICIPANT	\N	PRESENT	0
789907	789278	10015M	PARTICIPANT	\N	PRESENT	0
789908	789278	21040X	PARTICIPANT	\N	PRESENT	0
789909	789278	19725B	PARTICIPANT	\N	PRESENT	0
789910	789278	14089Y	PARTICIPANT	\N	PRESENT	0
789911	789278	21044C	PARTICIPANT	\N	PRESENT	0
789912	789278	11056N	PARTICIPANT	\N	PRESENT	0
789913	789892	14331P	PARTICIPANT	\N	PRESENT	0
789914	789892	07004J	PARTICIPANT	\N	PRESENT	0
789915	789892	19349W	PARTICIPANT	\N	PRESENT	0
789916	789892	20050V	PARTICIPANT	\N	PRESENT	0
789917	789892	20024T	PARTICIPANT	\N	PRESENT	0
789919	789892	14327T	PARTICIPANT	\N	PRESENT	0
789922	789892	12016W	PARTICIPANT	\N	PRESENT	0
789925	789892	19479G	PARTICIPANT	\N	PRESENT	0
789926	789892	11070L	PARTICIPANT	\N	PRESENT	0
789927	789892	14253S	PARTICIPANT	\N	PRESENT	0
789928	789278	04045F	PARTICIPANT	\N	PRESENT	0
789929	789278	19489J	PARTICIPANT	\N	PRESENT	0
789930	789278	14147R	PARTICIPANT	\N	PRESENT	0
789931	789278	19111A	PARTICIPANT	\N	PRESENT	0
789932	789278	14151M	PARTICIPANT	\N	PRESENT	0
789933	789278	05008E	PARTICIPANT	\N	PRESENT	0
789934	789278	19719D	PARTICIPANT	\N	PRESENT	0
789935	789892	14225N	PRESIDENT	0	PRESENT	0
789936	789892	07029T	PARTICIPANT	\N	PRESENT	0
789937	789892	19573D	PARTICIPANT	\N	PRESENT	0
789938	789892	20116W	PARTICIPANT	\N	PRESENT	0
789940	789892	11048N	PARTICIPANT	\N	PRESENT	0
789941	789892	19711U	PARTICIPANT	\N	PRESENT	0
789942	789892	11040E	PARTICIPANT	\N	PRESENT	0
789943	789892	08073C	PARTICIPANT	\N	PRESENT	0
789944	789892	08009T	PARTICIPANT	\N	PRESENT	0
789945	789892	20080C	PARTICIPANT	\N	PRESENT	0
789947	789892	21079P	PARTICIPANT	\N	PRESENT	0
789949	789892	20044X	PARTICIPANT	\N	PRESENT	0
789950	789892	20150Y	PARTICIPANT	\N	PRESENT	0
789951	789892	14083S	PARTICIPANT	\N	PRESENT	0
789952	789278	14215L	PARTICIPANT	\N	PRESENT	0
768632	765489	18083K	PARTICIPANT	\N	PRESENT	0
768633	765489	20034V	PRESIDENT	0	PRESENT	0
768634	765489	19631V	PARTICIPANT	\N	PRESENT	0
768635	765489	12016W	PARTICIPANT	\N	EXCUSE	0
768636	765489	19657G	PARTICIPANT	\N	PRESENT	0
768637	765489	21029D	PARTICIPANT	\N	PRESENT	0
768638	765489	21055F	PARTICIPANT	\N	PRESENT	0
768639	765489	20148F	PARTICIPANT	\N	PRESENT	0
768640	765489	20146D	PARTICIPANT	\N	PRESENT	0
768641	765489	14275Y	PARTICIPANT	\N	PRESENT	0
768642	765489	14121F	PARTICIPANT	\N	PRESENT	0
768643	765489	19331L	PARTICIPANT	\N	PRESENT	0
768644	765489	21073H	PARTICIPANT	\N	PRESENT	0
768645	765489	20150Y	PARTICIPANT	\N	PRESENT	0
768646	765489	21035B	PARTICIPANT	\N	PRESENT	0
768648	765188	14231L	PRESIDENT	0	PRESENT	0
768649	765188	19489J	PARTICIPANT	\N	PRESENT	0
768650	765188	14069U	PARTICIPANT	\N	PRESENT	0
768651	765188	21065H	PARTICIPANT	\N	PRESENT	0
768652	765188	19820Y	PARTICIPANT	\N	PRESENT	0
768653	765188	14107H	PARTICIPANT	\N	PRESENT	0
768654	765188	20090E	PARTICIPANT	\N	PRESENT	0
768655	765188	14026U	PARTICIPANT	\N	PRESENT	0
768656	765188	14327T	PARTICIPANT	\N	PRESENT	0
768657	765188	14281W	PARTICIPANT	\N	PRESENT	0
768658	765188	19866P	PARTICIPANT	\N	PRESENT	0
768659	765188	19826F	PARTICIPANT	\N	PRESENT	0
768660	765188	20102Q	PARTICIPANT	\N	PRESENT	0
768661	765188	20068G	PARTICIPANT	\N	PRESENT	0
768662	765188	20070A	PARTICIPANT	\N	PRESENT	0
768663	765188	19573D	PARTICIPANT	\N	PRESENT	0
768664	765188	21068L	PARTICIPANT	\N	PRESENT	0
768665	765188	14257W	PARTICIPANT	\N	PRESENT	0
768666	765188	19349W	PARTICIPANT	\N	PRESENT	0
768667	765188	19531S	PARTICIPANT	\N	PRESENT	0
768668	765188	21048G	PARTICIPANT	\N	PRESENT	0
768669	765188	20120S	PARTICIPANT	\N	PRESENT	0
768670	765188	21055F	PARTICIPANT	\N	PRESENT	0
768674	765188	21073H	PARTICIPANT	\N	PRESENT	0
768676	765188	21096Q	PARTICIPANT	\N	PRESENT	0
768677	765188	20148F	PARTICIPANT	\N	PRESENT	0
768679	765188	18083K	PARTICIPANT	\N	PRESENT	0
768681	765188	19631V	PARTICIPANT	\N	PRESENT	0
768682	765188	21035B	PARTICIPANT	\N	PRESENT	0
768684	765188	19691J	PARTICIPANT	\N	PRESENT	0
768685	765188	20034V	PARTICIPANT	\N	PRESENT	0
768687	765188	14275Y	PARTICIPANT	\N	PRESENT	0
768688	765188	21029D	PARTICIPANT	\N	PRESENT	0
768690	765188	20150Y	PARTICIPANT	\N	PRESENT	0
768691	765188	20146D	PARTICIPANT	\N	PRESENT	0
768692	765188	20022R	PARTICIPANT	\N	EXCUSE	0
768693	765188	14215L	PARTICIPANT	\N	EXCUSE	0
768694	765188	19447X	PARTICIPANT	\N	EXCUSE	0
768695	765188	19735D	PARTICIPANT	\N	EXCUSE	0
768696	765188	05012A	PARTICIPANT	\N	EXCUSE	0
768697	765188	04045F	PARTICIPANT	\N	EXCUSE	0
768698	765188	01034P	PARTICIPANT	\N	EXCUSE	0
769601	769600	19820Y	PARTICIPANT	\N	PRESENT	0
769620	769619	19611R	PARTICIPANT	\N	PRESENT	0
769621	769618	19611R	PARTICIPANT	\N	PRESENT	0
769624	769623	14225N	PARTICIPANT	\N	PRESENT	0
769627	769626	11053K	PARTICIPANT	\N	PRESENT	0
769629	769628	21090J	PARTICIPANT	\N	PRESENT	0
769630	769628	08009T	PARTICIPANT	\N	PRESENT	0
769632	769631	11053K	PARTICIPANT	\N	PRESENT	0
772466	772465	19111A	PARTICIPANT	\N	PRESENT	0
772468	772467	19111A	PARTICIPANT	\N	PRESENT	0
772470	770606	20086J	PARTICIPANT	\N	PRESENT	0
772472	772471	20086J	PARTICIPANT	\N	PRESENT	0
775579	773642	21071F	PARTICIPANT	\N	PRESENT	0
775580	773642	20130U	PARTICIPANT	\N	PRESENT	0
775608	775607	21071F	PARTICIPANT	\N	PRESENT	0
775609	775607	20130U	PARTICIPANT	\N	PRESENT	0
776143	776142	04047H	PARTICIPANT	\N	PRESENT	1
776145	776144	04047H	PARTICIPANT	\N	PRESENT	1
776156	776155	21094N	PARTICIPANT	\N	PRESENT	0
776159	776157	19711U	PARTICIPANT	\N	PRESENT	0
776160	776157	20094J	PARTICIPANT	\N	PRESENT	0
776269	776268	14237S	PARTICIPANT	\N	PRESENT	0
776270	776268	20084G	PARTICIPANT	\N	PRESENT	0
776271	776268	19575F	PARTICIPANT	\N	PRESENT	0
776283	776279	14237S	PARTICIPANT	\N	PRESENT	0
776284	776279	19575F	PARTICIPANT	\N	PRESENT	0
776289	776280	14237S	PARTICIPANT	\N	PRESENT	0
776290	776280	19575F	PARTICIPANT	\N	PRESENT	0
776291	776280	11053K	PARTICIPANT	\N	PRESENT	0
784554	784553	20026V	PARTICIPANT	\N	PRESENT	1
784555	784553	21063F	PARTICIPANT	\N	PRESENT	1
784556	784553	14109K	PARTICIPANT	\N	PRESENT	1
786390	786389	21064G	PARTICIPANT	\N	PRESENT	0
789011	789010	20120S	PARTICIPANT	\N	PRESENT	0
789012	789010	14219Q	PARTICIPANT	\N	PRESENT	0
789013	789010	20136B	PARTICIPANT	\N	PRESENT	0
789014	789010	14031R	PARTICIPANT	\N	PRESENT	0
789015	789010	19820Y	PARTICIPANT	\N	PRESENT	0
789016	789010	21051B	PARTICIPANT	\N	PRESENT	0
789017	789010	20106U	PARTICIPANT	\N	PRESENT	0
789018	789010	19693L	PARTICIPANT	\N	PRESENT	0
789019	789010	19251M	PARTICIPANT	\N	PRESENT	0
789020	789010	15197G	PARTICIPANT	\N	PRESENT	0
789021	789010	20100N	PARTICIPANT	\N	PRESENT	0
789625	786182	21050A	PARTICIPANT	\N	PRESENT	0
789626	786182	19782L	PARTICIPANT	\N	PRESENT	0
789628	786182	20144B	PARTICIPANT	\N	PRESENT	0
789629	786182	20038A	PARTICIPANT	\N	PRESENT	0
789630	786182	20018V	PARTICIPANT	\N	PRESENT	0
789631	786182	20082E	PARTICIPANT	\N	PRESENT	0
789664	789663	14255U	PARTICIPANT	\N	PRESENT	0
789665	789663	20066E	PARTICIPANT	\N	PRESENT	0
789666	789663	19531S	PARTICIPANT	\N	PRESENT	0
789667	789663	14205J	PARTICIPANT	\N	PRESENT	0
789668	789663	19745F	PARTICIPANT	\N	PRESENT	0
789669	789663	20092G	PARTICIPANT	\N	PRESENT	0
791784	791783	14193X	PARTICIPANT	\N	PRESENT	0
791785	791612	17367Q	PARTICIPANT	\N	PRESENT	0
791786	791612	14151M	PRESIDENT	0	PRESENT	0
791787	791612	12028B	PARTICIPANT	\N	PRESENT	0
791788	791612	19295A	PARTICIPANT	\N	PRESENT	0
791799	791612	18395Y	PARTICIPANT	\N	PRESENT	0
791813	791812	14151M	PARTICIPANT	\N	PRESENT	0
791814	791812	19295A	PARTICIPANT	\N	PRESENT	0
791815	791812	17367Q	PARTICIPANT	\N	PRESENT	0
791816	791812	18395Y	PARTICIPANT	\N	PRESENT	0
791847	791613	15197G	PARTICIPANT	\N	EXCUSE	0
793296	791618	20090E	PARTICIPANT	\N	PRESENT	0
793297	791618	20140W	PARTICIPANT	\N	PRESENT	0
793298	791618	14217N	PARTICIPANT	\N	PRESENT	0
793299	791618	14281W	PARTICIPANT	\N	PRESENT	0
793300	791618	14026U	PARTICIPANT	\N	PRESENT	0
793301	791618	19691J	PARTICIPANT	\N	PRESENT	0
793302	791618	19553Y	PARTICIPANT	\N	PRESENT	0
793303	791618	14213J	PARTICIPANT	\N	PRESENT	0
793304	791618	21081H	PARTICIPANT	\N	PRESENT	0
793305	791618	19723Y	PARTICIPANT	\N	PRESENT	0
793306	791618	18193Q	PARTICIPANT	\N	PRESENT	0
793307	791618	19657G	PARTICIPANT	\N	PRESENT	0
793308	791618	04092N	PARTICIPANT	\N	PRESENT	0
793309	791618	14071N	PRESIDENT	0	PRESENT	0
793310	791618	20096L	PARTICIPANT	\N	PRESENT	0
793311	791618	21097R	PARTICIPANT	\N	PRESENT	0
793312	791618	21039F	PARTICIPANT	\N	PRESENT	0
793313	791618	20148F	PARTICIPANT	\N	PRESENT	0
793314	791618	21064G	PARTICIPANT	\N	PRESENT	0
793315	791618	19703U	PARTICIPANT	\N	PRESENT	0
793316	791618	19713W	PARTICIPANT	\N	PRESENT	0
793372	793371	08012N	PARTICIPANT	\N	PRESENT	0
793373	793371	14073Q	PARTICIPANT	\N	PRESENT	0
793374	793371	11043H	PARTICIPANT	\N	PRESENT	0
793375	793371	19533U	PARTICIPANT	\N	PRESENT	0
793376	793371	21037D	PARTICIPANT	\N	PRESENT	0
793377	793371	19954N	PARTICIPANT	\N	PRESENT	0
793379	793378	19735D	PRESIDENT	0	PRESENT	0
793380	793378	20142Y	PARTICIPANT	\N	PRESENT	0
793381	793378	21094N	PARTICIPANT	\N	PRESENT	0
793382	793378	21089R	PARTICIPANT	\N	PRESENT	0
793383	793378	18395Y	PARTICIPANT	\N	PRESENT	0
793384	793378	14229S	PARTICIPANT	\N	PRESENT	0
793385	793378	20114U	PARTICIPANT	\N	PRESENT	0
793437	793378	20052X	PARTICIPANT	\N	PRESENT	0
793440	793378	20058E	PARTICIPANT	\N	PRESENT	0
793441	793378	20026V	PARTICIPANT	\N	PRESENT	0
781455	779281	04045F	PARTICIPANT	\N	PRESENT	0
781456	779281	21043B	PARTICIPANT	\N	PRESENT	0
781457	779281	19725B	PARTICIPANT	\N	PRESENT	0
781458	780472	21050A	PARTICIPANT	\N	PRESENT	0
781459	780472	19782L	PARTICIPANT	\N	PRESENT	0
781460	780472	11090Q	PARTICIPANT	\N	PRESENT	0
781461	779281	20074E	PARTICIPANT	\N	PRESENT	0
781462	779281	19673G	PARTICIPANT	\N	PRESENT	0
781463	779281	20098N	PARTICIPANT	\N	PRESENT	0
781464	779281	21056G	PARTICIPANT	\N	PRESENT	0
781465	779281	14147R	PARTICIPANT	\N	PRESENT	0
781466	779281	14151M	PARTICIPANT	\N	PRESENT	0
781467	779281	19649G	PARTICIPANT	\N	PRESENT	0
781468	779281	14189C	PARTICIPANT	\N	PRESENT	0
781469	779281	21076L	PARTICIPANT	\N	PRESENT	0
781470	779281	10015M	PARTICIPANT	\N	PRESENT	0
781471	779281	19719D	PARTICIPANT	\N	PRESENT	0
781472	779281	19729F	PARTICIPANT	\N	PRESENT	0
781473	779281	19749K	PARTICIPANT	\N	PRESENT	0
781479	780472	20082E	PARTICIPANT	\N	PRESENT	0
781475	779281	21088Q	PARTICIPANT	\N	PRESENT	0
781476	780472	20078J	PARTICIPANT	\N	PRESENT	0
781477	779281	05008E	PARTICIPANT	\N	PRESENT	0
781478	779281	11056N	PARTICIPANT	\N	PRESENT	0
781480	780472	21093M	PARTICIPANT	\N	PRESENT	0
781481	780472	14205J	PARTICIPANT	\N	PRESENT	0
781482	780472	20060X	PARTICIPANT	\N	EXCUSE	0
781483	780472	14033T	PARTICIPANT	\N	EXCUSE	0
781484	779281	19489J	PARTICIPANT	\N	PRESENT	0
781485	779281	18207D	PARTICIPANT	\N	PRESENT	0
781486	779281	18231D	PARTICIPANT	\N	PRESENT	0
781487	779281	20114U	PARTICIPANT	\N	PRESENT	0
781488	779281	21038E	PARTICIPANT	\N	PRESENT	0
781489	779281	14259Y	PARTICIPANT	\N	PRESENT	0
781490	780472	21066J	PARTICIPANT	\N	PRESENT	0
781492	781405	21082J	PARTICIPANT	\N	PRESENT	0
781493	781405	21029D	PARTICIPANT	\N	PRESENT	0
781494	781405	21035B	PARTICIPANT	\N	PRESENT	0
781495	781405	21042A	PARTICIPANT	\N	PRESENT	0
781496	781405	19387D	PARTICIPANT	\N	PRESENT	0
781497	781405	14219Q	PRESIDENT	0	PRESENT	0
781498	781405	19820Y	PARTICIPANT	\N	PRESENT	0
781499	781405	19826F	PARTICIPANT	\N	PRESENT	0
781500	781405	21060C	PARTICIPANT	\N	PRESENT	0
781501	781405	21062E	PARTICIPANT	\N	PRESENT	0
781502	781405	18083K	PARTICIPANT	\N	PRESENT	0
781503	781405	19551W	PARTICIPANT	\N	PRESENT	0
781504	781405	21084L	PARTICIPANT	\N	PRESENT	0
781505	781405	20100N	PARTICIPANT	\N	PRESENT	0
781506	781405	05012A	PARTICIPANT	\N	PRESENT	0
781507	781405	08060W	PARTICIPANT	\N	PRESENT	0
781508	781405	20106U	PARTICIPANT	\N	PRESENT	0
781509	781405	20118Y	PARTICIPANT	\N	PRESENT	0
781510	781405	15197G	PARTICIPANT	\N	PRESENT	0
781511	781405	14107H	PARTICIPANT	\N	PRESENT	0
781512	781405	21080G	PARTICIPANT	\N	PRESENT	0
781513	781405	19331L	PARTICIPANT	\N	PRESENT	0
781514	781405	20020P	PARTICIPANT	\N	PRESENT	0
781515	781405	19685L	PARTICIPANT	\N	PRESENT	0
781516	781405	21051B	PARTICIPANT	\N	PRESENT	0
781517	781405	20032T	PARTICIPANT	\N	PRESENT	0
781518	781405	21053D	PARTICIPANT	\N	PRESENT	0
781519	781405	20136B	PARTICIPANT	\N	PRESENT	0
781520	781405	14031R	PARTICIPANT	\N	PRESENT	0
781521	781405	20040T	PARTICIPANT	\N	PRESENT	0
781522	781405	20146D	PARTICIPANT	\N	PRESENT	0
781523	781405	20046A	PARTICIPANT	\N	PRESENT	0
781524	781405	14169X	PARTICIPANT	\N	PRESENT	0
781525	781405	17229F	PARTICIPANT	\N	PRESENT	0
781526	781405	20068G	PARTICIPANT	\N	PRESENT	0
781527	781405	21068L	PARTICIPANT	\N	PRESENT	0
781528	781405	19251M	PARTICIPANT	\N	EXCUSE	0
781529	781405	21061D	PARTICIPANT	\N	EXCUSE	0
781530	781405	19619A	PARTICIPANT	\N	EXCUSE	0
781531	781405	21065H	PARTICIPANT	\N	PRESENT	0
781532	780472	19383Y	PARTICIPANT	\N	PRESENT	0
781533	777021	19697Q	PARTICIPANT	\N	PRESENT	0
781534	777021	04070G	PARTICIPANT	\N	PRESENT	0
781535	777021	21058J	PARTICIPANT	\N	PRESENT	0
781536	777021	20102Q	PARTICIPANT	\N	PRESENT	0
781537	777021	14229S	PARTICIPANT	\N	PRESENT	0
781538	777021	19954N	PARTICIPANT	\N	PRESENT	0
781539	777021	21032X	PARTICIPANT	\N	PRESENT	0
781540	777021	18395Y	PARTICIPANT	\N	PRESENT	0
781541	777021	20112S	PARTICIPANT	\N	PRESENT	0
781542	777021	21089R	PARTICIPANT	\N	PRESENT	0
781543	777021	08012N	PARTICIPANT	\N	PRESENT	0
781544	777021	21037D	PARTICIPANT	\N	PRESENT	0
781545	777021	20016T	PARTICIPANT	\N	PRESENT	0
781546	777021	20124W	PARTICIPANT	\N	PRESENT	0
781547	777021	20026V	PARTICIPANT	\N	PRESENT	0
781548	777021	19593H	PARTICIPANT	\N	PRESENT	0
781549	777021	20132W	PARTICIPANT	\N	PRESENT	0
781550	777021	21055F	PARTICIPANT	\N	PRESENT	0
781551	777021	20122U	PARTICIPANT	\N	PRESENT	0
781552	777021	14073Q	PARTICIPANT	\N	PRESENT	0
781553	777021	19611R	PRESIDENT	0	PRESENT	0
781554	777021	20138D	PARTICIPANT	\N	PRESENT	0
781555	777021	20142Y	PARTICIPANT	\N	PRESENT	0
781556	777021	20048C	PARTICIPANT	\N	PRESENT	0
781557	777021	20052X	PARTICIPANT	\N	PRESENT	0
781558	777021	20172F	PARTICIPANT	\N	PRESENT	0
781559	777021	14030Q	PARTICIPANT	\N	PRESENT	0
781560	777021	20058E	PARTICIPANT	\N	PRESENT	0
781561	777021	20056C	PARTICIPANT	\N	PRESENT	0
781562	777021	20180F	PARTICIPANT	\N	PRESENT	0
781563	777021	20264J	PARTICIPANT	\N	PRESENT	0
781564	777021	21063F	PARTICIPANT	\N	PRESENT	0
781565	777021	14109K	PARTICIPANT	\N	PRESENT	0
781566	777021	14123H	PARTICIPANT	\N	PRESENT	0
781567	777021	11043H	PARTICIPANT	\N	PRESENT	0
781568	777021	14021P	PARTICIPANT	\N	PRESENT	0
781569	777021	19621T	PARTICIPANT	\N	PRESENT	0
781570	779281	04047H	PRESIDENT	1	PRESENT	0
781571	779281	20266L	PARTICIPANT	\N	PRESENT	0
781572	780472	21033Y	PARTICIPANT	\N	PRESENT	0
782804	779282	04047H	PRESIDENT	0	PRESENT	0
782805	779282	21095P	PARTICIPANT	\N	PRESENT	0
782806	779282	19447X	PARTICIPANT	\N	PRESENT	0
782898	780802	14231L	PRESIDENT	0	PRESENT	0
782899	780802	19531S	PARTICIPANT	\N	PRESENT	0
782900	780802	14281W	PARTICIPANT	\N	PRESENT	0
782901	780802	14107H	PARTICIPANT	\N	PRESENT	0
782902	780802	14053L	PARTICIPANT	\N	PRESENT	0
782903	780802	20070A	PARTICIPANT	\N	PRESENT	0
782904	780802	20102Q	PARTICIPANT	\N	PRESENT	0
782905	780802	19866P	PARTICIPANT	\N	PRESENT	0
782906	780802	19826F	PARTICIPANT	\N	PRESENT	0
782907	780802	14327T	PARTICIPANT	\N	PRESENT	0
782908	780802	20062A	PARTICIPANT	\N	PRESENT	0
782909	780802	20032T	PARTICIPANT	\N	PRESENT	0
782910	780802	21065H	PARTICIPANT	\N	PRESENT	0
782911	780802	20068G	PARTICIPANT	\N	PRESENT	0
782912	780802	19782L	PARTICIPANT	\N	PRESENT	0
782916	780802	19489J	PARTICIPANT	\N	PRESENT	0
782918	780802	20022R	PARTICIPANT	\N	EXCUSE	0
782919	780802	20090E	PARTICIPANT	\N	EXCUSE	0
782920	780802	14026U	PARTICIPANT	\N	EXCUSE	0
782921	780802	19447X	PARTICIPANT	\N	EXCUSE	0
782922	780802	19768N	PARTICIPANT	\N	EXCUSE	0
782923	780802	21070E	PARTICIPANT	\N	EXCUSE	0
782924	780802	04045F	PARTICIPANT	\N	EXCUSE	0
782925	780802	20084G	PARTICIPANT	\N	PRESENT	0
782978	782950	14331P	PRESIDENT	0	PRESENT	0
782927	780802	20058E	PARTICIPANT	\N	EXCUSE	0
782969	780802	19335Q	PARTICIPANT	\N	PRESENT	0
782979	782950	14133K	PARTICIPANT	\N	PRESENT	0
782980	782950	04070G	PARTICIPANT	\N	PRESENT	0
782981	782950	18207D	PARTICIPANT	\N	PRESENT	0
782982	782950	21037D	PARTICIPANT	\N	PRESENT	0
782983	782950	20104S	PARTICIPANT	\N	PRESENT	0
782984	782950	14097Y	PARTICIPANT	\N	PRESENT	0
782985	782950	20100N	PARTICIPANT	\N	PRESENT	0
782986	782950	14001X	PARTICIPANT	\N	PRESENT	0
782987	782950	18395Y	PARTICIPANT	\N	PRESENT	0
782988	782950	10015M	PARTICIPANT	\N	PRESENT	0
782989	782950	08034U	PARTICIPANT	\N	PRESENT	0
782990	782950	19711U	PARTICIPANT	\N	PRESENT	0
782991	782950	20084G	PARTICIPANT	\N	PRESENT	0
782992	780802	19820Y	PARTICIPANT	\N	PRESENT	0
783006	780802	14257W	PARTICIPANT	\N	PRESENT	0
769388	769387	14133K	PARTICIPANT	\N	PRESENT	0
769389	769387	14097Y	PARTICIPANT	\N	PRESENT	0
769391	769390	14133K	PARTICIPANT	\N	PRESENT	0
769392	769390	14097Y	PARTICIPANT	\N	PRESENT	0
769394	769393	14133K	PARTICIPANT	\N	PRESENT	0
769395	769393	14097Y	PARTICIPANT	\N	PRESENT	0
769397	769396	14097Y	PARTICIPANT	\N	PRESENT	0
769399	769398	14097Y	PARTICIPANT	\N	PRESENT	0
769401	769400	14097Y	PARTICIPANT	\N	PRESENT	0
769403	769402	14001X	PARTICIPANT	\N	PRESENT	0
769405	769404	07033P	PARTICIPANT	\N	PRESENT	0
769406	769404	14001X	PARTICIPANT	\N	PRESENT	0
769408	769407	14133K	PARTICIPANT	\N	PRESENT	0
769409	769407	14097Y	PARTICIPANT	\N	PRESENT	0
769411	769410	14255U	PARTICIPANT	\N	PRESENT	0
769412	769410	20064C	PARTICIPANT	\N	PRESENT	0
769414	769413	11027H	PARTICIPANT	\N	PRESENT	0
769415	769413	19421M	PARTICIPANT	\N	PRESENT	0
769417	769416	11027H	PARTICIPANT	\N	PRESENT	0
769419	769418	11027H	PARTICIPANT	\N	PRESENT	0
769420	769418	19421M	PARTICIPANT	\N	PRESENT	0
769422	769421	11027H	PARTICIPANT	\N	PRESENT	0
769423	769421	19421M	PARTICIPANT	\N	PRESENT	0
769425	769424	11027H	PARTICIPANT	\N	PRESENT	0
769426	769424	19421M	PARTICIPANT	\N	PRESENT	0
769428	769427	98022P	PARTICIPANT	\N	PRESENT	0
769429	769427	99004R	PARTICIPANT	\N	PRESENT	0
769431	769430	98022P	PARTICIPANT	\N	PRESENT	0
769432	769430	99004R	PARTICIPANT	\N	PRESENT	0
769434	769433	98022P	PARTICIPANT	\N	PRESENT	0
769435	769433	99004R	PARTICIPANT	\N	PRESENT	0
769520	765400	20058E	PARTICIPANT	\N	PRESENT	0
770430	770429	14331P	PARTICIPANT	\N	PRESENT	0
770431	770429	14073Q	PARTICIPANT	\N	PRESENT	0
770433	770429	14001X	PARTICIPANT	\N	PRESENT	0
770605	770604	20086J	PARTICIPANT	\N	PRESENT	0
775444	772615	21068L	PARTICIPANT	\N	PRESENT	0
775445	772615	21058J	PARTICIPANT	\N	PRESENT	0
775446	772615	21029D	PARTICIPANT	\N	PRESENT	0
775447	772615	14327T	PARTICIPANT	\N	PRESENT	0
775448	772615	14053L	PARTICIPANT	\N	PRESENT	0
775449	772615	14207L	PARTICIPANT	\N	PRESENT	0
775450	772615	20070A	PARTICIPANT	\N	PRESENT	0
775451	772615	20116W	PARTICIPANT	\N	PRESENT	0
775452	772615	21040X	PARTICIPANT	\N	PRESENT	0
775453	772615	20112S	PARTICIPANT	\N	PRESENT	0
775454	772615	21087P	PARTICIPANT	\N	PRESENT	0
775455	772615	20032T	PARTICIPANT	\N	PRESENT	0
775456	772615	07029T	PARTICIPANT	\N	PRESENT	0
775457	772615	14331P	PARTICIPANT	\N	PRESENT	0
775458	772615	21072G	PARTICIPANT	\N	PRESENT	0
775459	772615	20090E	PARTICIPANT	\N	PRESENT	0
775460	772615	19611R	PARTICIPANT	\N	PRESENT	0
775461	772615	19711U	PARTICIPANT	\N	PRESENT	0
775462	772615	19629C	PARTICIPANT	\N	PRESENT	0
775463	772615	20094J	PARTICIPANT	\N	PRESENT	0
775464	772615	20080C	PARTICIPANT	\N	PRESENT	0
775465	772615	20066E	PARTICIPANT	\N	PRESENT	0
775466	772615	14121F	PARTICIPANT	\N	PRESENT	0
775467	772615	14021P	PARTICIPANT	\N	PRESENT	0
775468	772615	04033B	PARTICIPANT	\N	PRESENT	0
775469	772615	20062A	PARTICIPANT	\N	PRESENT	0
775470	772615	20058E	PARTICIPANT	\N	PRESENT	0
775471	772615	20104S	PARTICIPANT	\N	PRESENT	0
775472	772615	20172F	PARTICIPANT	\N	PRESENT	0
775473	772615	21053D	PARTICIPANT	\N	PRESENT	0
775474	772615	21081H	PARTICIPANT	\N	PRESENT	0
775475	772615	21070E	PARTICIPANT	\N	PRESENT	0
775476	772615	08015R	PARTICIPANT	\N	PRESENT	0
775477	772615	14219Q	PARTICIPANT	\N	PRESENT	0
775478	772615	14249W	PARTICIPANT	\N	PRESENT	0
775442	772615	20026V	PARTICIPANT	\N	PRESENT	0
775443	772615	21039F	PARTICIPANT	\N	PRESENT	0
775479	772615	14033T	PARTICIPANT	\N	PRESENT	0
775480	772615	14026U	PARTICIPANT	\N	PRESENT	0
775481	772615	19533U	PARTICIPANT	\N	PRESENT	0
775482	772615	08034U	PARTICIPANT	\N	PRESENT	0
775483	772615	19760E	PARTICIPANT	\N	PRESENT	0
775484	772615	19866P	PARTICIPANT	\N	PRESENT	0
775485	772615	19563B	PARTICIPANT	\N	PRESENT	0
775486	772615	20134Y	PARTICIPANT	\N	PRESENT	0
775487	772615	20092G	PARTICIPANT	\N	PRESENT	0
775488	772615	20180F	PARTICIPANT	\N	PRESENT	0
775489	772615	20106U	PARTICIPANT	\N	PRESENT	0
775490	772615	14215L	PARTICIPANT	\N	PRESENT	0
775491	772615	21048G	PARTICIPANT	\N	PRESENT	0
775492	772615	14071N	PARTICIPANT	\N	PRESENT	0
775493	772615	14147R	PARTICIPANT	\N	PRESENT	0
775494	772615	14083S	PARTICIPANT	\N	PRESENT	0
775495	772615	20086J	PARTICIPANT	\N	PRESENT	0
775496	772615	18395Y	PARTICIPANT	\N	PRESENT	0
775497	772615	20038A	PARTICIPANT	\N	PRESENT	0
775498	772615	19758L	PARTICIPANT	\N	PRESENT	0
775499	772615	14225N	PARTICIPANT	\N	PRESENT	0
775500	772615	18193Q	PARTICIPANT	\N	PRESENT	0
775501	772615	20128B	PARTICIPANT	\N	PRESENT	0
775502	772615	19349W	PARTICIPANT	\N	PRESENT	0
775503	772615	14030Q	PARTICIPANT	\N	PRESENT	0
775504	772615	14073Q	PARTICIPANT	\N	PRESENT	0
775505	772615	20052X	PARTICIPANT	\N	PRESENT	0
775506	772615	20136B	PARTICIPANT	\N	PRESENT	0
775507	772615	21063F	PARTICIPANT	\N	PRESENT	0
775508	772615	14123H	PARTICIPANT	\N	PRESENT	0
775949	775947	17737W	PARTICIPANT	\N	PRESENT	0
775951	775947	14037X	PARTICIPANT	\N	PRESENT	0
776835	776821	07029T	PARTICIPANT	\N	EXCUSE	0
778265	775974	04047H	PRESIDENT	0	PRESENT	0
778266	775974	21076L	PARTICIPANT	\N	PRESENT	0
778267	775974	18231D	PARTICIPANT	\N	PRESENT	0
778268	775974	19673G	PARTICIPANT	\N	PRESENT	0
778272	775974	14147R	PARTICIPANT	\N	PRESENT	0
778421	776030	14169X	PARTICIPANT	\N	EXCUSE	0
778685	775941	20140W	PARTICIPANT	\N	PRESENT	0
778686	775942	20140W	PARTICIPANT	\N	PRESENT	0
778687	775943	20140W	PARTICIPANT	\N	PRESENT	0
778425	778012	21084L	PARTICIPANT	\N	PRESENT	0
778426	778012	21035B	PARTICIPANT	\N	PRESENT	0
778689	776115	21073H	PARTICIPANT	\N	EXCUSE	0
779664	776563	11070L	PARTICIPANT	\N	PRESENT	0
778429	778012	18083K	PARTICIPANT	\N	PRESENT	0
778430	778012	19701S	PARTICIPANT	\N	PRESENT	0
778431	778012	19681G	PARTICIPANT	\N	EXCUSE	0
778432	778012	11065P	PARTICIPANT	\N	PRESENT	0
778433	778012	17229F	PARTICIPANT	\N	PRESENT	0
778434	778012	19251M	PARTICIPANT	\N	EXCUSE	0
779665	776563	19111A	PARTICIPANT	\N	PRESENT	0
778436	778012	20040T	PARTICIPANT	\N	PRESENT	0
778437	778012	21062E	PARTICIPANT	\N	PRESENT	0
778438	778012	20100N	PARTICIPANT	\N	PRESENT	0
778439	778012	20120S	PARTICIPANT	\N	PRESENT	0
778440	778012	19820Y	PARTICIPANT	\N	EXCUSE	0
778441	778012	19387D	PARTICIPANT	\N	PRESENT	0
778442	778012	20068G	PARTICIPANT	\N	PRESENT	0
779666	776563	14225N	PARTICIPANT	\N	PRESENT	0
779668	776563	11090Q	PARTICIPANT	\N	PRESENT	0
778446	778012	19551W	PARTICIPANT	\N	PRESENT	0
778447	778012	14219Q	PRESIDENT	0	PRESENT	0
778448	778012	14031R	PARTICIPANT	\N	PRESENT	0
778450	778012	21080G	PARTICIPANT	\N	PRESENT	0
778451	778012	21029D	PARTICIPANT	\N	PRESENT	0
778452	778012	14169X	PARTICIPANT	\N	EXCUSE	0
778454	778012	21060C	PARTICIPANT	\N	PRESENT	0
778465	778012	19619A	PARTICIPANT	\N	PRESENT	0
778466	778012	20136B	PARTICIPANT	\N	PRESENT	0
778467	778012	21051B	PARTICIPANT	\N	PRESENT	0
778468	778012	21061D	PARTICIPANT	\N	PRESENT	0
778469	778012	20046A	PARTICIPANT	\N	PRESENT	0
778470	778012	21082J	PARTICIPANT	\N	PRESENT	0
789953	789278	20266L	PARTICIPANT	\N	PRESENT	0
789954	789278	21043B	PARTICIPANT	\N	EXCUSE	0
789955	789278	19729F	PARTICIPANT	\N	EXCUSE	0
789956	789278	21057H	PARTICIPANT	\N	EXCUSE	0
789957	789892	20086J	PARTICIPANT	\N	PRESENT	0
789958	789892	19545Y	PARTICIPANT	\N	PRESENT	0
789959	789892	11053K	PARTICIPANT	\N	PRESENT	0
789960	789892	21090J	PARTICIPANT	\N	PRESENT	0
789961	789892	20126Y	PARTICIPANT	\N	PRESENT	0
790022	789371	17737W	PARTICIPANT	\N	PRESENT	0
789963	789892	20062A	PARTICIPANT	\N	PRESENT	0
790023	789371	14001X	PARTICIPANT	\N	EXCUSE	0
789965	789892	21069M	PARTICIPANT	\N	PRESENT	0
789966	789892	08034U	PARTICIPANT	\N	PRESENT	0
789967	789278	19673G	PARTICIPANT	\N	PRESENT	0
789968	789892	19647E	PARTICIPANT	\N	PRESENT	0
789969	789892	11110B	PARTICIPANT	\N	PRESENT	0
789987	789371	21030V	PARTICIPANT	\N	PRESENT	0
789988	789371	19565D	PARTICIPANT	\N	PRESENT	0
789989	789371	21031W	PARTICIPANT	\N	PRESENT	0
789990	789371	20072C	PARTICIPANT	\N	PRESENT	0
789991	789371	19669L	PARTICIPANT	\N	PRESENT	0
789992	789371	08056B	PARTICIPANT	\N	PRESENT	0
789993	789371	12028B	PARTICIPANT	\N	PRESENT	0
789994	789371	19421M	PARTICIPANT	\N	PRESENT	0
789995	789371	19709B	PARTICIPANT	\N	PRESENT	0
789996	789371	21067K	PARTICIPANT	\N	PRESENT	0
789997	789371	14193X	PRESIDENT	0	PRESENT	0
789998	789371	07033P	PARTICIPANT	\N	PRESENT	0
789999	789371	17367Q	PARTICIPANT	\N	PRESENT	0
790000	789371	14249W	PARTICIPANT	\N	PRESENT	0
790001	789371	08047A	PARTICIPANT	\N	PRESENT	0
790002	789371	20128B	PARTICIPANT	\N	PRESENT	0
790003	789371	14059S	PARTICIPANT	\N	PRESENT	0
790004	789371	21073H	PARTICIPANT	\N	PRESENT	0
790005	789371	19531S	PARTICIPANT	\N	PRESENT	0
790006	789371	08069G	PARTICIPANT	\N	PRESENT	0
790007	789371	14191V	PARTICIPANT	\N	PRESENT	0
790008	789371	20064C	PARTICIPANT	\N	PRESENT	0
790009	789371	14251Q	PARTICIPANT	\N	PRESENT	0
790010	789371	98022P	PARTICIPANT	\N	PRESENT	0
790011	789371	14267Y	PARTICIPANT	\N	PRESENT	0
790012	789371	99004R	PARTICIPANT	\N	PRESENT	0
790013	789371	14211G	PARTICIPANT	\N	PRESENT	0
790014	789892	20094J	PARTICIPANT	\N	PRESENT	0
790015	789892	21041Y	PARTICIPANT	\N	PRESENT	0
790016	789892	19667J	PARTICIPANT	\N	PRESENT	0
790017	789892	08010L	PARTICIPANT	\N	PRESENT	0
790018	789892	20134Y	PARTICIPANT	\N	PRESENT	0
790019	789892	19399H	PARTICIPANT	\N	PRESENT	0
790020	789892	20070A	PARTICIPANT	\N	PRESENT	0
790021	789892	14173T	PARTICIPANT	\N	EXCUSE	0
790024	789371	19745F	PARTICIPANT	\N	EXCUSE	0
790026	789892	19335Q	PARTICIPANT	\N	PRESENT	0
790055	786668	04070G	PARTICIPANT	\N	PRESENT	0
790056	786668	19699S	PARTICIPANT	\N	PRESENT	0
790057	786668	19533U	PARTICIPANT	\N	PRESENT	0
790058	786668	21058J	PARTICIPANT	\N	PRESENT	0
790059	786668	21059K	PARTICIPANT	\N	PRESENT	0
790060	786668	14229S	PARTICIPANT	\N	PRESENT	0
790061	786668	18395Y	PARTICIPANT	\N	PRESENT	0
790062	786668	20112S	PARTICIPANT	\N	PRESENT	0
790063	786668	21089R	PARTICIPANT	\N	PRESENT	0
790064	786668	21037D	PARTICIPANT	\N	PRESENT	0
790065	786668	08012N	PARTICIPANT	\N	PRESENT	0
790066	786668	21091K	PARTICIPANT	\N	PRESENT	0
790067	786668	20026V	PARTICIPANT	\N	PRESENT	0
790068	786668	19593H	PARTICIPANT	\N	PRESENT	0
790069	786668	20132W	PARTICIPANT	\N	PRESENT	0
790070	786668	21055F	PARTICIPANT	\N	PRESENT	0
790071	786668	19611R	PRESIDENT	0	PRESENT	0
790072	786668	20138D	PARTICIPANT	\N	PRESENT	0
790073	786668	20142Y	PARTICIPANT	\N	PRESENT	0
790074	786668	20048C	PARTICIPANT	\N	PRESENT	0
790075	786668	19693L	PARTICIPANT	\N	PRESENT	0
790076	786668	20052X	PARTICIPANT	\N	PRESENT	0
790077	786668	20172F	PARTICIPANT	\N	PRESENT	0
790078	786668	14030Q	PARTICIPANT	\N	PRESENT	0
790080	786668	20056C	PARTICIPANT	\N	PRESENT	0
790081	786668	20180F	PARTICIPANT	\N	PRESENT	0
790082	786668	20264J	PARTICIPANT	\N	PRESENT	0
790083	786668	21063F	PARTICIPANT	\N	PRESENT	0
790084	786668	19735D	PARTICIPANT	\N	PRESENT	0
790085	786668	14109K	PARTICIPANT	\N	PRESENT	0
790086	786668	14123H	PARTICIPANT	\N	PRESENT	0
790087	786668	19621T	PARTICIPANT	\N	PRESENT	0
790088	786668	14021P	PARTICIPANT	\N	PRESENT	0
790089	786668	19697Q	PARTICIPANT	\N	EXCUSE	0
790098	789371	19721W	PARTICIPANT	\N	PRESENT	0
790100	789371	19347U	PARTICIPANT	\N	PRESENT	0
790101	789371	14255U	PARTICIPANT	\N	PRESENT	0
790106	789371	14037X	PARTICIPANT	\N	PRESENT	0
790107	789371	04042C	PARTICIPANT	\N	PRESENT	0
790132	788983	20148F	PARTICIPANT	\N	PRESENT	0
790133	789278	20022R	PARTICIPANT	\N	PRESENT	0
790134	789371	11115U	PARTICIPANT	\N	PRESENT	0
790135	789371	14133K	PARTICIPANT	\N	PRESENT	0
790136	789371	14179A	PARTICIPANT	\N	PRESENT	0
790137	789372	21030V	PARTICIPANT	\N	PRESENT	0
790138	789372	19565D	PARTICIPANT	\N	PRESENT	0
790139	789372	21031W	PARTICIPANT	\N	PRESENT	0
790140	789372	20072C	PARTICIPANT	\N	PRESENT	0
790141	789372	04042C	PARTICIPANT	\N	PRESENT	0
790142	789372	19669L	PARTICIPANT	\N	PRESENT	0
790143	789372	08056B	PARTICIPANT	\N	PRESENT	0
790144	789372	12028B	PARTICIPANT	\N	PRESENT	0
790145	789372	17737W	PARTICIPANT	\N	PRESENT	0
790146	789372	11115U	PARTICIPANT	\N	PRESENT	0
790147	789372	19421M	PARTICIPANT	\N	PRESENT	0
790148	789372	19709B	PARTICIPANT	\N	PRESENT	0
790149	789372	21067K	PARTICIPANT	\N	PRESENT	0
790150	789372	14193X	PRESIDENT	0	PRESENT	0
790151	789372	19347U	PARTICIPANT	\N	PRESENT	0
790152	789372	14179A	PARTICIPANT	\N	PRESENT	0
790153	789372	07033P	PARTICIPANT	\N	PRESENT	0
790154	789372	17367Q	PARTICIPANT	\N	PRESENT	0
790155	789372	14249W	PARTICIPANT	\N	PRESENT	0
790156	789372	08047A	PARTICIPANT	\N	PRESENT	0
790157	789372	20128B	PARTICIPANT	\N	PRESENT	0
790158	789372	14037X	PARTICIPANT	\N	PRESENT	0
790159	789372	14059S	PARTICIPANT	\N	PRESENT	0
790160	789372	21073H	PARTICIPANT	\N	PRESENT	0
790161	789372	19531S	PARTICIPANT	\N	PRESENT	0
790162	789372	14133K	PARTICIPANT	\N	PRESENT	0
790163	789372	08069G	PARTICIPANT	\N	PRESENT	0
790164	789372	14191V	PARTICIPANT	\N	PRESENT	0
790165	789372	19721W	PARTICIPANT	\N	PRESENT	0
790166	789372	20064C	PARTICIPANT	\N	PRESENT	0
790167	789372	14251Q	PARTICIPANT	\N	PRESENT	0
790168	789372	98022P	PARTICIPANT	\N	PRESENT	0
790169	789372	14267Y	PARTICIPANT	\N	PRESENT	0
790170	789372	99004R	PARTICIPANT	\N	PRESENT	0
790171	789372	14211G	PARTICIPANT	\N	PRESENT	0
790172	789372	14255U	PARTICIPANT	\N	PRESENT	0
790173	789372	14001X	PARTICIPANT	\N	EXCUSE	0
790174	789372	19745F	PARTICIPANT	\N	EXCUSE	0
790175	789372	11027H	PARTICIPANT	\N	PRESENT	0
790176	786668	19954N	PARTICIPANT	\N	PRESENT	0
790639	790637	19553Y	PARTICIPANT	\N	PRESENT	0
790641	790637	14255U	PARTICIPANT	\N	PRESENT	0
790642	790637	04042C	PARTICIPANT	\N	PRESENT	0
790643	790637	14083S	PARTICIPANT	\N	PRESENT	0
790644	790637	21065H	PARTICIPANT	\N	PRESENT	0
790645	790637	11065P	PARTICIPANT	\N	PRESENT	0
790646	790637	20132W	PARTICIPANT	\N	PRESENT	0
790647	790637	19531S	PARTICIPANT	\N	PRESENT	0
790649	790648	18083K	PARTICIPANT	\N	PRESENT	0
790650	790648	11065P	PARTICIPANT	\N	PRESENT	0
790659	790648	21067K	PARTICIPANT	\N	PRESENT	0
790652	790648	21075K	PARTICIPANT	\N	PRESENT	0
790653	790648	14037X	PARTICIPANT	\N	PRESENT	0
790654	790648	14073Q	PARTICIPANT	\N	PRESENT	0
790656	790648	21095P	PARTICIPANT	\N	PRESENT	0
790657	790648	21036C	PARTICIPANT	\N	PRESENT	0
790658	790648	14083S	PARTICIPANT	\N	PRESENT	0
790664	790663	20118Y	PARTICIPANT	\N	PRESENT	0
790665	790663	19531S	PARTICIPANT	\N	PRESENT	0
790666	790663	19711U	PARTICIPANT	\N	PRESENT	0
790667	790663	14059S	PARTICIPANT	\N	PRESENT	0
790672	790670	19798U	PARTICIPANT	\N	PRESENT	0
773457	773456	21094N	PARTICIPANT	\N	PRESENT	0
773756	773755	14255U	PARTICIPANT	\N	PRESENT	0
773758	773755	08009T	PARTICIPANT	\N	PRESENT	0
773759	773755	14169X	PARTICIPANT	\N	PRESENT	0
773760	773755	20056C	PARTICIPANT	\N	PRESENT	0
773761	773755	11074Q	PARTICIPANT	\N	PRESENT	0
773762	773755	21031W	PARTICIPANT	\N	PRESENT	0
775548	774414	18395Y	PARTICIPANT	\N	PRESENT	0
775549	774414	14033T	PARTICIPANT	\N	PRESENT	0
775550	774414	14189C	PARTICIPANT	\N	PRESENT	0
775647	775646	04047H	PARTICIPANT	\N	PRESENT	0
775648	775646	19111A	PARTICIPANT	\N	PRESENT	0
775649	775646	18231D	PARTICIPANT	\N	PRESENT	0
775651	775650	04047H	PARTICIPANT	\N	PRESENT	0
775652	775650	21043B	PARTICIPANT	\N	PRESENT	0
775653	775650	19673G	PARTICIPANT	\N	PRESENT	0
777131	776546	14111D	PARTICIPANT	\N	PRESENT	0
777132	777130	20086J	PARTICIPANT	\N	PRESENT	0
777133	777130	14331P	PARTICIPANT	\N	PRESENT	0
777134	777130	11048N	PARTICIPANT	\N	PRESENT	0
777135	777130	19711U	PARTICIPANT	\N	PRESENT	0
777136	777130	11053K	PARTICIPANT	\N	PRESENT	0
777137	777130	20080C	PARTICIPANT	\N	PRESENT	0
777138	777130	20044X	PARTICIPANT	\N	PRESENT	0
777139	777130	14225N	PRESIDENT	0	PRESENT	0
777140	777130	07029T	PARTICIPANT	\N	PRESENT	0
777141	777130	20062A	PARTICIPANT	\N	PRESENT	0
777142	777130	19573D	PARTICIPANT	\N	PRESENT	0
777143	777130	21079P	PARTICIPANT	\N	PRESENT	0
777144	777130	19349W	PARTICIPANT	\N	PRESENT	0
777145	777130	14253S	PARTICIPANT	\N	PRESENT	0
777146	777130	20024T	PARTICIPANT	\N	PRESENT	0
777147	777130	19687N	PARTICIPANT	\N	PRESENT	0
777148	777130	20094J	PARTICIPANT	\N	PRESENT	0
777149	776546	19693L	PARTICIPANT	\N	PRESENT	0
777150	776546	20018V	PARTICIPANT	\N	PRESENT	0
777151	777130	19647E	PARTICIPANT	\N	PRESENT	0
777152	777130	11040E	PARTICIPANT	\N	PRESENT	0
777153	777130	20070A	PARTICIPANT	\N	PRESENT	0
777154	776546	19593H	PARTICIPANT	\N	PRESENT	0
777155	776546	20084G	PARTICIPANT	\N	PRESENT	0
777156	776546	14267Y	PARTICIPANT	\N	PRESENT	0
777157	776546	14173T	PARTICIPANT	\N	PRESENT	0
777158	776546	20068G	PARTICIPANT	\N	PRESENT	0
777159	776546	21039F	PARTICIPANT	\N	PRESENT	0
777160	776546	19335Q	PARTICIPANT	\N	PRESENT	0
777161	776546	21094N	PARTICIPANT	\N	PRESENT	0
777162	776546	19723Y	PARTICIPANT	\N	PRESENT	0
777163	776546	21053D	PARTICIPANT	\N	PRESENT	0
777164	776546	19954N	PARTICIPANT	\N	PRESENT	0
777168	776546	14259Y	PARTICIPANT	\N	PRESENT	0
777166	776546	19367Y	PARTICIPANT	\N	PRESENT	0
777167	776546	20082E	PARTICIPANT	\N	PRESENT	0
777169	776546	19331L	PARTICIPANT	\N	PRESENT	0
777170	776546	19657G	PARTICIPANT	\N	PRESENT	0
777171	776546	21097R	PARTICIPANT	\N	PRESENT	0
777172	776546	14281W	PARTICIPANT	\N	PRESENT	0
777173	776546	19826F	PARTICIPANT	\N	PRESENT	0
777174	776546	21029D	PARTICIPANT	\N	PRESENT	0
777175	776546	20032T	PARTICIPANT	\N	PRESENT	0
777176	776546	04045F	PARTICIPANT	\N	PRESENT	0
777177	776546	20026V	PARTICIPANT	\N	PRESENT	0
777178	776546	21089R	PARTICIPANT	\N	PRESENT	0
777179	776546	20106U	PARTICIPANT	\N	PRESENT	0
777180	776546	21067K	PARTICIPANT	\N	PRESENT	0
777181	776546	14147R	PARTICIPANT	\N	PRESENT	0
777182	776546	20028X	PARTICIPANT	\N	PRESENT	0
777183	776546	14042U	PARTICIPANT	\N	PRESENT	0
777184	776546	20118Y	PARTICIPANT	\N	PRESENT	0
777185	776546	20172F	PARTICIPANT	\N	PRESENT	0
777186	776546	19695N	PARTICIPANT	\N	PRESENT	0
777187	776546	19573D	PARTICIPANT	\N	PRESENT	0
777188	776546	14123H	PARTICIPANT	\N	PRESENT	0
777189	776546	19725B	PARTICIPANT	\N	PRESENT	0
777190	776546	19631V	PARTICIPANT	\N	PRESENT	0
777191	776546	14205J	PARTICIPANT	\N	PRESENT	0
777192	776546	14089Y	PARTICIPANT	\N	PRESENT	0
777196	776546	01058X	PARTICIPANT	\N	PRESENT	0
777229	776546	19399H	PARTICIPANT	\N	PRESENT	0
777230	776546	12028B	PARTICIPANT	\N	PRESENT	0
777231	776546	21065H	PARTICIPANT	\N	PRESENT	0
777232	776546	19679N	PARTICIPANT	\N	PRESENT	0
777239	776546	20072C	PARTICIPANT	\N	PRESENT	0
777253	776546	20134Y	PARTICIPANT	\N	PRESENT	0
777261	776546	11027H	PARTICIPANT	\N	PRESENT	0
777273	776546	20024T	PARTICIPANT	\N	PRESENT	0
777300	776547	21079P	PARTICIPANT	\N	PRESENT	0
777301	776547	19679N	PARTICIPANT	\N	PRESENT	0
777302	776547	19507S	PARTICIPANT	\N	PRESENT	0
777303	776547	21097R	PARTICIPANT	\N	PRESENT	0
777304	776547	20024T	PARTICIPANT	\N	PRESENT	0
777298	776547	14259Y	PARTICIPANT	\N	PRESENT	0
777299	776547	19545Y	PARTICIPANT	\N	PRESENT	0
777305	776547	21066J	PARTICIPANT	\N	PRESENT	0
777306	776547	21034A	PARTICIPANT	\N	PRESENT	0
777307	776547	19760E	PARTICIPANT	\N	PRESENT	0
777308	776547	14071N	PARTICIPANT	\N	PRESENT	0
777309	776547	20026V	PARTICIPANT	\N	PRESENT	0
777310	776547	21040X	PARTICIPANT	\N	PRESENT	0
777311	776547	20090E	PARTICIPANT	\N	PRESENT	0
777312	776547	21058J	PARTICIPANT	\N	PRESENT	0
777313	776547	21049H	PARTICIPANT	\N	PRESENT	0
777314	776547	20130U	PARTICIPANT	\N	PRESENT	0
777315	776547	14026U	PARTICIPANT	\N	PRESENT	0
777316	776547	21047F	PARTICIPANT	\N	PRESENT	0
777317	776547	21039F	PARTICIPANT	\N	PRESENT	0
777318	776547	20038A	PARTICIPANT	\N	PRESENT	0
777319	776547	14038Y	PARTICIPANT	\N	PRESENT	0
777320	776547	14189C	PARTICIPANT	\N	PRESENT	0
777321	776547	14281W	PARTICIPANT	\N	PRESENT	0
777322	776547	21044C	PARTICIPANT	\N	PRESENT	0
777323	776547	19758L	PARTICIPANT	\N	PRESENT	0
777324	776547	21046E	PARTICIPANT	\N	PRESENT	0
777325	776547	21061D	PARTICIPANT	\N	PRESENT	0
777326	776547	18083K	PARTICIPANT	\N	PRESENT	0
777327	776547	08061X	PARTICIPANT	\N	PRESENT	0
777328	776547	20286Q	PARTICIPANT	\N	PRESENT	0
777329	776547	14231L	PARTICIPANT	\N	PRESENT	0
777330	776547	21072G	PARTICIPANT	\N	PRESENT	0
777331	776547	19591F	PARTICIPANT	\N	PRESENT	0
777332	776547	21071F	PARTICIPANT	\N	PRESENT	0
777333	776547	19866P	PARTICIPANT	\N	PRESENT	0
777334	776547	19683J	PARTICIPANT	\N	PRESENT	0
777335	776547	14121F	PARTICIPANT	\N	PRESENT	0
777336	776547	21064G	PARTICIPANT	\N	PRESENT	0
777337	776547	18193Q	PARTICIPANT	\N	PRESENT	0
777338	776547	21048G	PARTICIPANT	\N	PRESENT	0
777339	776547	14217N	PARTICIPANT	\N	PRESENT	0
777340	776547	20076G	PARTICIPANT	\N	PRESENT	0
777341	776547	21063F	PARTICIPANT	\N	PRESENT	0
777342	776547	14147R	PARTICIPANT	\N	PRESENT	0
777343	776547	21076L	PARTICIPANT	\N	PRESENT	0
777344	776547	21043B	PARTICIPANT	\N	PRESENT	0
777345	776547	14179A	PARTICIPANT	\N	PRESENT	0
777346	776547	20032T	PARTICIPANT	\N	PRESENT	0
777347	776547	20092G	PARTICIPANT	\N	PRESENT	0
777348	776547	20248J	PARTICIPANT	\N	PRESENT	0
777349	776547	08015R	PARTICIPANT	\N	PRESENT	0
777350	776547	11072N	PARTICIPANT	\N	PRESENT	0
777351	776547	21093M	PARTICIPANT	\N	PRESENT	0
777352	776547	14089Y	PARTICIPANT	\N	PRESENT	0
777353	776547	14033T	PARTICIPANT	\N	PRESENT	0
777354	776547	21053D	PARTICIPANT	\N	PRESENT	0
777355	776547	17965H	PARTICIPANT	\N	PRESENT	0
777356	776547	19735D	PARTICIPANT	\N	PRESENT	0
777357	776547	14213J	PARTICIPANT	\N	PRESENT	0
777358	776547	19701S	PARTICIPANT	\N	PRESENT	0
777359	776547	19657G	PARTICIPANT	\N	PRESENT	0
777360	776547	21067K	PARTICIPANT	\N	PRESENT	0
777361	776547	14225N	PARTICIPANT	\N	PRESENT	0
777362	776547	20140W	PARTICIPANT	\N	PRESENT	0
777363	776547	21086N	PARTICIPANT	\N	PRESENT	0
777364	776547	19349W	PARTICIPANT	\N	PRESENT	0
777365	776547	19301E	PARTICIPANT	\N	PRESENT	0
777366	776547	08056B	PARTICIPANT	\N	PRESENT	0
777367	776547	20180F	PARTICIPANT	\N	PRESENT	0
777368	776547	21084L	PARTICIPANT	\N	PRESENT	0
777369	776547	19631V	PARTICIPANT	\N	PRESENT	0
777370	776547	11048N	PARTICIPANT	\N	PRESENT	0
777371	776547	20056C	PARTICIPANT	\N	PRESENT	0
777372	776547	19399H	PARTICIPANT	\N	PRESENT	0
783021	782950	20094J	PARTICIPANT	\N	PRESENT	0
783568	783363	19760E	PARTICIPANT	\N	PRESENT	0
783569	783363	21046E	PARTICIPANT	\N	PRESENT	0
783570	783363	19691J	PARTICIPANT	\N	PRESENT	0
783571	783363	14213J	PARTICIPANT	\N	PRESENT	0
783572	783363	19703U	PARTICIPANT	\N	PRESENT	0
783573	783363	19713W	PARTICIPANT	\N	PRESENT	0
783574	783363	14071N	PARTICIPANT	\N	PRESENT	0
783576	783363	21071F	PRESIDENT	0	PRESENT	0
783580	783363	20130U	PARTICIPANT	\N	PRESENT	0
785860	783404	14151M	PRESIDENT	0	PRESENT	0
785861	783404	17367Q	PARTICIPANT	\N	PRESENT	0
785862	783404	18395Y	PARTICIPANT	\N	PRESENT	0
785872	783404	14255U	PARTICIPANT	\N	PRESENT	0
785924	783404	20090E	PARTICIPANT	\N	PRESENT	0
785936	783404	17737W	PARTICIPANT	\N	PRESENT	0
786081	785337	14195A	PARTICIPANT	\N	PRESENT	0
786082	785337	20130U	PARTICIPANT	\N	PRESENT	0
786083	785337	14281W	PARTICIPANT	\N	PRESENT	0
786084	785337	18193Q	PARTICIPANT	\N	PRESENT	0
786085	785337	19703U	PARTICIPANT	\N	PRESENT	0
786086	785337	19691J	PARTICIPANT	\N	PRESENT	0
786088	786087	20130U	PARTICIPANT	\N	PRESENT	0
786089	786087	14281W	PARTICIPANT	\N	PRESENT	0
786090	786087	14213J	PARTICIPANT	\N	PRESENT	0
786091	786087	19758L	PARTICIPANT	\N	PRESENT	0
786092	786087	19760E	PARTICIPANT	\N	PRESENT	0
786093	786087	18193Q	PARTICIPANT	\N	PRESENT	0
786094	786087	19703U	PARTICIPANT	\N	PRESENT	0
786095	786087	19691J	PARTICIPANT	\N	PRESENT	0
786131	783407	18395Y	PARTICIPANT	\N	PRESENT	0
786132	783407	14033T	PARTICIPANT	\N	PRESENT	0
786133	783408	14189C	PARTICIPANT	\N	PRESENT	0
786134	783408	14033T	PARTICIPANT	\N	PRESENT	0
786135	781791	18395Y	PARTICIPANT	\N	PRESENT	0
786136	781791	14033T	PARTICIPANT	\N	PRESENT	0
786137	781791	14189C	PARTICIPANT	\N	PRESENT	0
786139	786138	14033T	PARTICIPANT	\N	PRESENT	0
786140	786138	18395Y	PARTICIPANT	\N	PRESENT	0
786141	786138	14189C	PARTICIPANT	\N	PRESENT	0
786143	786142	14033T	PARTICIPANT	\N	PRESENT	0
786144	786142	14189C	PARTICIPANT	\N	PRESENT	0
786146	786145	19649G	PARTICIPANT	\N	PRESENT	0
783010	780802	14069U	PARTICIPANT	\N	PRESENT	0
783011	780802	01034P	PARTICIPANT	\N	PRESENT	0
786147	786145	14053L	PARTICIPANT	\N	PRESENT	0
786149	786148	14053L	PARTICIPANT	\N	PRESENT	0
786150	786148	19649G	PARTICIPANT	\N	PRESENT	0
786153	786151	20026V	PARTICIPANT	\N	PRESENT	1
786154	786151	14109K	PARTICIPANT	\N	PRESENT	1
786155	786151	20058E	PARTICIPANT	\N	PRESENT	1
786156	786151	14030Q	PARTICIPANT	\N	PRESENT	1
786157	786151	21063F	PARTICIPANT	\N	PRESENT	1
786159	786158	20026V	PARTICIPANT	\N	PRESENT	1
786160	786158	14030Q	PARTICIPANT	\N	PRESENT	1
786161	786158	19693L	PARTICIPANT	\N	PRESENT	1
786162	786158	20058E	PARTICIPANT	\N	PRESENT	1
786164	786163	20026V	PARTICIPANT	\N	PRESENT	1
786165	786163	14030Q	PARTICIPANT	\N	PRESENT	1
786166	786163	19693L	PARTICIPANT	\N	PRESENT	1
786167	786163	14109K	PARTICIPANT	\N	PRESENT	1
786169	786168	20026V	PARTICIPANT	\N	PRESENT	1
786170	786168	19693L	PARTICIPANT	\N	PRESENT	1
786171	786168	14030Q	PARTICIPANT	\N	PRESENT	1
786173	786172	14187A	PARTICIPANT	\N	PRESENT	0
786174	786172	20286Q	PARTICIPANT	\N	PRESENT	0
786175	786172	19631V	PARTICIPANT	\N	PRESENT	0
786450	786449	21064G	PARTICIPANT	\N	PRESENT	0
786452	786451	14038Y	PARTICIPANT	\N	PRESENT	0
786453	786451	20038A	PARTICIPANT	\N	PRESENT	0
786454	786451	14033T	PARTICIPANT	\N	PRESENT	0
786457	786455	14038Y	PARTICIPANT	\N	PRESENT	0
786458	786455	20038A	PARTICIPANT	\N	PRESENT	0
786459	786455	14033T	PARTICIPANT	\N	PRESENT	0
786461	786460	14038Y	PARTICIPANT	\N	PRESENT	0
786462	786460	20038A	PARTICIPANT	\N	PRESENT	0
786463	786460	14033T	PARTICIPANT	\N	PRESENT	0
786467	786466	14038Y	PARTICIPANT	\N	PRESENT	0
786468	786466	20038A	PARTICIPANT	\N	PRESENT	0
786469	786466	14033T	PARTICIPANT	\N	PRESENT	0
786471	786470	14038Y	PARTICIPANT	\N	PRESENT	0
786472	786470	20038A	PARTICIPANT	\N	PRESENT	0
786473	786470	14033T	PARTICIPANT	\N	PRESENT	0
786474	786470	21086N	PARTICIPANT	\N	PRESENT	0
786476	786475	14038Y	PARTICIPANT	\N	PRESENT	0
786477	786475	14033T	PARTICIPANT	\N	PRESENT	0
786478	786475	21086N	PARTICIPANT	\N	PRESENT	0
786479	786475	20092G	PARTICIPANT	\N	PRESENT	0
786480	786475	19826F	PARTICIPANT	\N	PRESENT	0
786483	786482	14038Y	PARTICIPANT	\N	PRESENT	0
786484	786482	14033T	PARTICIPANT	\N	PRESENT	0
786485	786482	21086N	PARTICIPANT	\N	PRESENT	0
786486	786482	20092G	PARTICIPANT	\N	PRESENT	0
786487	786482	19826F	PARTICIPANT	\N	PRESENT	0
786489	786488	14038Y	PARTICIPANT	\N	PRESENT	0
786490	786488	14033T	PARTICIPANT	\N	PRESENT	0
786491	786488	20038A	PARTICIPANT	\N	PRESENT	0
786493	786492	14038Y	PARTICIPANT	\N	PRESENT	0
786494	786492	14033T	PARTICIPANT	\N	PRESENT	0
786495	786492	20038A	PARTICIPANT	\N	PRESENT	0
786524	786429	21089R	PARTICIPANT	\N	PRESENT	0
786525	786429	20180F	PARTICIPANT	\N	PRESENT	0
786526	786429	18193Q	PARTICIPANT	\N	PRESENT	0
786527	786429	14223L	PARTICIPANT	\N	PRESENT	0
786528	786429	14147R	PARTICIPANT	\N	PRESENT	0
786529	786429	19798U	PARTICIPANT	\N	PRESENT	0
786531	786429	21087P	PARTICIPANT	\N	PRESENT	0
786533	786532	14331P	PARTICIPANT	\N	PRESENT	0
786534	786532	14073Q	PARTICIPANT	\N	PRESENT	0
786535	786532	14001X	PARTICIPANT	\N	PRESENT	0
786536	786430	21089R	PARTICIPANT	\N	PRESENT	0
786537	786430	20180F	PARTICIPANT	\N	PRESENT	0
786538	786430	18193Q	PARTICIPANT	\N	PRESENT	0
786539	786430	14147R	PARTICIPANT	\N	PRESENT	0
786540	786430	14223L	PARTICIPANT	\N	PRESENT	0
786541	786430	19798U	PARTICIPANT	\N	PRESENT	0
786543	786542	14331P	PARTICIPANT	\N	PRESENT	0
786544	786542	14001X	PARTICIPANT	\N	PRESENT	0
786545	786542	14073Q	PARTICIPANT	\N	PRESENT	0
786547	786546	14331P	PARTICIPANT	\N	PRESENT	0
786548	786546	14073Q	PARTICIPANT	\N	PRESENT	0
786549	786546	14001X	PARTICIPANT	\N	PRESENT	0
786577	786177	19673G	PARTICIPANT	\N	PRESENT	0
786578	786177	14219Q	PARTICIPANT	\N	EXCUSE	0
786579	786177	20122U	PARTICIPANT	\N	EXCUSE	0
786580	786177	20146D	PARTICIPANT	\N	EXCUSE	0
786581	786176	19673G	PARTICIPANT	\N	PRESENT	0
786582	786176	14219Q	PARTICIPANT	\N	EXCUSE	0
786583	786176	20122U	PARTICIPANT	\N	EXCUSE	0
786584	786176	20146D	PARTICIPANT	\N	EXCUSE	0
786591	786590	19703U	PARTICIPANT	\N	PRESENT	0
786592	786590	14071N	PARTICIPANT	\N	PRESENT	0
786593	786590	19758L	PARTICIPANT	\N	PRESENT	0
786594	786590	18193Q	PARTICIPANT	\N	PRESENT	0
786595	786587	19760E	PARTICIPANT	\N	PRESENT	0
786596	786587	19691J	PARTICIPANT	\N	PRESENT	0
786597	786587	14281W	PARTICIPANT	\N	PRESENT	0
786598	786587	19703U	PARTICIPANT	\N	PRESENT	0
786599	786587	18193Q	PARTICIPANT	\N	PRESENT	0
786600	786587	20130U	PARTICIPANT	\N	PRESENT	0
786601	786588	14281W	PARTICIPANT	\N	PRESENT	0
786602	786588	20130U	PARTICIPANT	\N	PRESENT	0
786603	786588	18193Q	PARTICIPANT	\N	PRESENT	0
786604	786588	19703U	PARTICIPANT	\N	PRESENT	0
786605	786588	19691J	PARTICIPANT	\N	PRESENT	0
786810	786433	19749K	PARTICIPANT	\N	PRESENT	0
786812	786433	20180F	PARTICIPANT	\N	PRESENT	0
786813	786433	21089R	PARTICIPANT	\N	PRESENT	0
786825	786433	20038A	PARTICIPANT	\N	PRESENT	0
786828	786433	14223L	PARTICIPANT	\N	PRESENT	1
786830	786433	21034A	PARTICIPANT	\N	PRESENT	0
786842	786433	19798U	PARTICIPANT	\N	PRESENT	0
786940	786434	20038A	PARTICIPANT	\N	PRESENT	0
786941	786434	20180F	PARTICIPANT	\N	PRESENT	0
786943	786434	21089R	PARTICIPANT	\N	PRESENT	0
786944	786434	14223L	PARTICIPANT	\N	PRESENT	0
786945	786434	19798U	PARTICIPANT	\N	PRESENT	0
786947	786434	19749K	PARTICIPANT	\N	PRESENT	0
787005	786435	21089R	PARTICIPANT	\N	PRESENT	0
787007	786435	20180F	PARTICIPANT	\N	PRESENT	0
773658	772597	14229S	PARTICIPANT	\N	PRESENT	0
773659	772597	14225N	PARTICIPANT	\N	PRESENT	0
773660	772597	07004J	PARTICIPANT	\N	PRESENT	0
773661	772597	14191V	PARTICIPANT	\N	PRESENT	0
773662	772597	19629C	PARTICIPANT	\N	PRESENT	0
773663	773657	14327T	PARTICIPANT	\N	PRESENT	0
773664	773657	11048N	PARTICIPANT	\N	PRESENT	0
773665	773657	19479G	PARTICIPANT	\N	PRESENT	0
773666	773657	19647E	PARTICIPANT	\N	PRESENT	0
773667	773657	19711U	PARTICIPANT	\N	PRESENT	0
773668	773657	19545Y	PARTICIPANT	\N	PRESENT	0
773669	773657	20080C	PARTICIPANT	\N	PRESENT	0
773670	773657	20094J	PARTICIPANT	\N	PRESENT	0
773671	773657	08011M	PARTICIPANT	\N	PRESENT	0
773672	773657	20044X	PRESIDENT	0	PRESENT	0
773673	773657	19399H	PARTICIPANT	\N	PRESENT	0
773674	773657	14173T	PARTICIPANT	\N	PRESENT	0
773675	773657	07029T	PARTICIPANT	\N	PRESENT	0
773676	773657	19573D	PARTICIPANT	\N	PRESENT	0
773677	773657	20070A	PARTICIPANT	\N	PRESENT	0
773678	773657	19349W	PARTICIPANT	\N	PRESENT	0
773679	773657	14121F	PARTICIPANT	\N	PRESENT	0
773680	773657	20024T	PARTICIPANT	\N	PRESENT	0
773681	772597	11040E	PARTICIPANT	\N	PRESENT	0
773682	772597	14038Y	PARTICIPANT	\N	PRESENT	0
773683	772597	19545Y	PARTICIPANT	\N	PRESENT	0
773684	772597	20090E	PARTICIPANT	\N	PRESENT	0
773685	772597	21048G	PARTICIPANT	\N	PRESENT	0
773686	772597	21033Y	PARTICIPANT	\N	PRESENT	0
773687	772597	19399H	PARTICIPANT	\N	PRESENT	0
773688	772597	20024T	PARTICIPANT	\N	PRESENT	0
773689	772597	08028W	PARTICIPANT	\N	PRESENT	0
773690	772597	20072C	PARTICIPANT	\N	PRESENT	0
773691	772597	21070E	PARTICIPANT	\N	PRESENT	0
773692	772597	21040X	PARTICIPANT	\N	PRESENT	0
773693	772597	20044X	PARTICIPANT	\N	PRESENT	0
773694	772597	11048N	PARTICIPANT	\N	PRESENT	0
773695	772597	20054A	PARTICIPANT	\N	PRESENT	0
773696	772597	21066J	PARTICIPANT	\N	PRESENT	0
773697	772597	19798U	PARTICIPANT	\N	PRESENT	0
773698	772597	19349W	PARTICIPANT	\N	PRESENT	0
773699	772597	19711U	PARTICIPANT	\N	PRESENT	0
773700	772597	21065H	PARTICIPANT	\N	PRESENT	0
773701	772597	19687N	PARTICIPANT	\N	PRESENT	0
773702	772597	21074J	PARTICIPANT	\N	PRESENT	0
773703	772597	20070A	PARTICIPANT	\N	PRESENT	0
773704	772597	08034U	PARTICIPANT	\N	PRESENT	0
773705	772597	07029T	PARTICIPANT	\N	PRESENT	0
773706	772597	14121F	PARTICIPANT	\N	PRESENT	0
773707	772597	20076G	PARTICIPANT	\N	PRESENT	0
773708	772597	21053D	PARTICIPANT	\N	PRESENT	0
773709	772597	21076L	PARTICIPANT	\N	PRESENT	0
773710	772597	20080C	PARTICIPANT	\N	PRESENT	0
773711	772597	04045F	PARTICIPANT	\N	PRESENT	0
773712	772597	19647E	PARTICIPANT	\N	PRESENT	0
773713	772597	18083K	PARTICIPANT	\N	PRESENT	0
773714	772597	14026U	PARTICIPANT	\N	PRESENT	0
773715	772597	20136B	PARTICIPANT	\N	PRESENT	0
773716	772597	14223L	PARTICIPANT	\N	PRESENT	0
773717	772597	20062A	PARTICIPANT	\N	PRESENT	0
773718	772597	19479G	PARTICIPANT	\N	PRESENT	0
773719	772597	20134Y	PARTICIPANT	\N	PRESENT	0
773720	772597	17229F	PARTICIPANT	\N	PRESENT	0
773721	772597	20068G	PARTICIPANT	\N	PRESENT	0
773722	772597	21039F	PARTICIPANT	\N	PRESENT	0
773723	772597	21047F	PARTICIPANT	\N	PRESENT	0
773724	772597	20038A	PARTICIPANT	\N	PRESENT	0
773725	772597	14107H	PARTICIPANT	\N	PRESENT	0
773726	772597	21058J	PARTICIPANT	\N	PRESENT	0
773727	772597	21030V	PARTICIPANT	\N	PRESENT	0
773728	772597	21043B	PARTICIPANT	\N	PRESENT	0
773729	772597	20052X	PARTICIPANT	\N	PRESENT	0
773730	772597	11070L	PARTICIPANT	\N	PRESENT	0
773731	772597	11056N	PARTICIPANT	\N	PRESENT	0
773732	772597	21056G	PARTICIPANT	\N	PRESENT	0
773733	772597	19691J	PARTICIPANT	\N	PRESENT	0
773734	772597	21055F	PARTICIPANT	\N	PRESENT	0
773735	772597	19667J	PARTICIPANT	\N	PRESENT	0
773736	772597	20032T	PARTICIPANT	\N	PRESENT	0
773737	772597	08056B	PARTICIPANT	\N	PRESENT	0
773738	772597	21085M	PARTICIPANT	\N	PRESENT	0
773739	772597	21072G	PARTICIPANT	\N	PRESENT	0
773740	772597	01058X	PARTICIPANT	\N	PRESENT	0
773741	772597	21079P	PARTICIPANT	\N	PRESENT	0
773742	772597	14089Y	PARTICIPANT	\N	PRESENT	0
773743	772597	14109K	PARTICIPANT	\N	PRESENT	0
773744	772597	19713W	PARTICIPANT	\N	PRESENT	0
773745	772597	21090J	PARTICIPANT	\N	PRESENT	0
773746	772597	14213J	PARTICIPANT	\N	PRESENT	0
773747	772597	10015M	PARTICIPANT	\N	PRESENT	0
773748	772597	21041Y	PARTICIPANT	\N	PRESENT	0
773749	772597	14205J	PARTICIPANT	\N	PRESENT	0
773750	772597	19563B	PARTICIPANT	\N	PRESENT	0
773751	772597	20094J	PARTICIPANT	\N	PRESENT	0
773752	772597	19631V	PARTICIPANT	\N	PRESENT	0
773753	772597	19335Q	PARTICIPANT	\N	PRESENT	0
773754	772597	20036X	PARTICIPANT	\N	PRESENT	0
773757	772597	20082E	PARTICIPANT	\N	PRESENT	0
773763	772597	20286Q	PARTICIPANT	\N	PRESENT	0
773764	772597	21067K	PARTICIPANT	\N	PRESENT	0
773765	772597	20092G	PARTICIPANT	\N	PRESENT	0
773766	772597	19703U	PARTICIPANT	\N	PRESENT	0
773767	772597	14173T	PARTICIPANT	\N	PRESENT	0
773768	772597	14231L	PARTICIPANT	\N	PRESENT	0
773769	772597	19507S	PARTICIPANT	\N	PRESENT	0
773770	772597	21052C	PARTICIPANT	\N	PRESENT	0
773771	772597	20126Y	PARTICIPANT	\N	PRESENT	0
773772	772597	14327T	PARTICIPANT	\N	PRESENT	0
773773	772597	19866P	PARTICIPANT	\N	PRESENT	0
773774	772597	19735D	PARTICIPANT	\N	PRESENT	0
773775	772597	08010L	PARTICIPANT	\N	PRESENT	0
773776	772597	21062E	PARTICIPANT	\N	PRESENT	0
773777	772597	14021P	PARTICIPANT	\N	PRESENT	0
773778	772597	19421M	PARTICIPANT	\N	PRESENT	0
773779	772597	05012A	PARTICIPANT	\N	PRESENT	0
773780	772597	08061X	PARTICIPANT	\N	PRESENT	0
773781	772597	21050A	PARTICIPANT	\N	PRESENT	0
773782	772597	20108W	PARTICIPANT	\N	PRESENT	0
773784	772597	14031R	PARTICIPANT	\N	PRESENT	0
773786	772597	14147R	PARTICIPANT	\N	PRESENT	0
773805	772597	20056C	PARTICIPANT	\N	PRESENT	0
773806	772597	19679N	PARTICIPANT	\N	PRESENT	0
773807	772597	19111A	PARTICIPANT	\N	PRESENT	0
773808	772597	20098N	PARTICIPANT	\N	PRESENT	0
773809	772597	11074Q	PARTICIPANT	\N	PRESENT	0
773810	772597	19489J	PARTICIPANT	\N	PRESENT	0
773811	772597	14083S	PARTICIPANT	\N	PRESENT	0
773812	772597	20084G	PARTICIPANT	\N	PRESENT	0
773813	772597	08018U	PARTICIPANT	\N	PRESENT	0
773814	772597	04033B	PARTICIPANT	\N	PRESENT	0
773815	772597	20066E	PARTICIPANT	\N	PRESENT	0
773816	772597	14169X	PARTICIPANT	\N	PRESENT	0
773817	772597	20058E	PARTICIPANT	\N	PRESENT	0
773818	772597	19387D	PARTICIPANT	\N	PRESENT	0
773819	772597	98022P	PARTICIPANT	\N	PRESENT	0
773821	772597	14259Y	PARTICIPANT	\N	PRESENT	0
773822	772597	19725B	PARTICIPANT	\N	PRESENT	0
773823	772597	20026V	PARTICIPANT	\N	PRESENT	0
773824	772597	20142Y	PARTICIPANT	\N	PRESENT	0
773825	772597	20042V	PARTICIPANT	\N	PRESENT	0
773826	772597	19699S	PARTICIPANT	\N	PRESENT	0
773827	772597	19745F	PARTICIPANT	\N	PRESENT	0
773828	772597	21059K	PARTICIPANT	\N	PRESENT	0
773829	772597	20086J	PARTICIPANT	\N	PRESENT	0
773830	772597	19683J	PARTICIPANT	\N	PRESENT	0
773831	772597	19760E	PARTICIPANT	\N	PRESENT	0
773832	772597	11090Q	PARTICIPANT	\N	PRESENT	0
773833	772597	14123H	PARTICIPANT	\N	PRESENT	0
773834	772597	20248J	PARTICIPANT	\N	PRESENT	0
773835	772597	05008E	PARTICIPANT	\N	PRESENT	0
773836	772597	14042U	PARTICIPANT	\N	PRESENT	0
773838	772597	20180F	PARTICIPANT	\N	PRESENT	0
773839	772597	21049H	PARTICIPANT	\N	PRESENT	0
773840	772597	21083K	PARTICIPANT	\N	PRESENT	0
773841	772597	20138D	PARTICIPANT	\N	PRESENT	0
773842	772597	19551W	PARTICIPANT	\N	PRESENT	0
773843	772597	19569H	PARTICIPANT	\N	PRESENT	0
773844	772597	14111D	PARTICIPANT	\N	PRESENT	0
773845	772597	21046E	PARTICIPANT	\N	PRESENT	0
773846	772597	18231D	PARTICIPANT	\N	PRESENT	0
790673	790670	14071N	PARTICIPANT	\N	PRESENT	0
790674	790670	19575F	PARTICIPANT	\N	PRESENT	0
790678	790670	20084G	PARTICIPANT	\N	PRESENT	0
790680	790679	18083K	PARTICIPANT	\N	PRESENT	0
790681	790679	21067K	PARTICIPANT	\N	PRESENT	0
790682	790679	14255U	PARTICIPANT	\N	PRESENT	0
790683	790679	21037D	PARTICIPANT	\N	PRESENT	0
790684	790679	08073C	PARTICIPANT	\N	PRESENT	0
790685	790679	14037X	PARTICIPANT	\N	PRESENT	0
790686	790648	19565D	PARTICIPANT	\N	PRESENT	0
790701	790700	17367Q	PARTICIPANT	\N	PRESENT	0
790702	790700	14151M	PARTICIPANT	\N	PRESENT	0
791151	788456	19866P	PARTICIPANT	\N	EXCUSE	0
791152	788456	20046A	PARTICIPANT	\N	EXCUSE	0
791153	788456	20130U	PARTICIPANT	\N	EXCUSE	0
791154	788456	14147R	PARTICIPANT	\N	EXCUSE	0
791155	788456	14223L	PARTICIPANT	\N	EXCUSE	0
791156	788456	14189C	PARTICIPANT	\N	EXCUSE	0
791157	788456	19798U	PARTICIPANT	\N	EXCUSE	0
791449	791365	21071F	PARTICIPANT	\N	EXCUSE	0
791451	791365	21081H	PARTICIPANT	\N	EXCUSE	0
791453	791365	14195A	PARTICIPANT	\N	EXCUSE	0
791558	790405	20056C	PARTICIPANT	\N	PRESENT	0
791562	791561	20022R	PARTICIPANT	\N	PRESENT	0
791563	791561	14215L	PARTICIPANT	\N	PRESENT	0
791564	791561	04047H	PARTICIPANT	\N	PRESENT	0
791567	791565	19575F	PARTICIPANT	\N	PRESENT	0
791568	791565	14038Y	PARTICIPANT	\N	PRESENT	0
791569	791565	18231D	PARTICIPANT	\N	PRESENT	0
791570	791565	19533U	PARTICIPANT	\N	PRESENT	0
791575	791565	20092G	PARTICIPANT	\N	PRESENT	0
791576	791565	01058X	PARTICIPANT	\N	PRESENT	0
791577	791565	20138D	PARTICIPANT	\N	EXCUSE	0
791578	791565	19667J	PARTICIPANT	\N	EXCUSE	0
791622	791621	20100N	PARTICIPANT	\N	PRESENT	0
791623	791621	21068L	PARTICIPANT	\N	PRESENT	0
791624	791621	19551W	PARTICIPANT	\N	PRESENT	0
791626	791625	20136B	PARTICIPANT	\N	PRESENT	0
791627	791625	21068L	PARTICIPANT	\N	PRESENT	0
791628	791625	14219Q	PARTICIPANT	\N	PRESENT	0
791629	791625	20068G	PARTICIPANT	\N	PRESENT	0
791630	791625	05012A	PARTICIPANT	\N	PRESENT	0
791631	791625	20100N	PARTICIPANT	\N	PRESENT	0
791632	791625	15197G	PARTICIPANT	\N	PRESENT	0
791633	791625	19551W	PARTICIPANT	\N	PRESENT	0
791640	791638	20136B	PARTICIPANT	\N	PRESENT	0
791641	791638	21068L	PARTICIPANT	\N	PRESENT	0
791642	791638	14219Q	PARTICIPANT	\N	PRESENT	0
791643	791638	20068G	PARTICIPANT	\N	PRESENT	0
791644	791638	05012A	PARTICIPANT	\N	PRESENT	0
791645	791638	20100N	PARTICIPANT	\N	PRESENT	0
791646	791638	15197G	PARTICIPANT	\N	PRESENT	0
791647	791638	19551W	PARTICIPANT	\N	PRESENT	0
791740	791733	20020P	PARTICIPANT	\N	PRESENT	0
791823	791822	20114U	PARTICIPANT	\N	PRESENT	0
791824	791822	04047H	PARTICIPANT	\N	PRESENT	0
791825	791822	21057H	PARTICIPANT	\N	PRESENT	0
791826	791822	14001X	PARTICIPANT	\N	PRESENT	0
791827	791822	20018V	PARTICIPANT	\N	PRESENT	0
791828	791822	17965H	PARTICIPANT	\N	PRESENT	0
791829	791822	20136B	PARTICIPANT	\N	PRESENT	0
791830	791822	20064C	PARTICIPANT	\N	PRESENT	0
791831	791822	21031W	PARTICIPANT	\N	PRESENT	0
791832	791822	21077M	PARTICIPANT	\N	PRESENT	0
791833	791822	20096L	PARTICIPANT	\N	PRESENT	0
791840	791839	20252E	PARTICIPANT	\N	PRESENT	0
791841	791839	18193Q	PARTICIPANT	\N	PRESENT	0
791842	791839	19531S	PARTICIPANT	\N	PRESENT	0
791843	791839	21053D	PARTICIPANT	\N	PRESENT	0
791844	791839	20120S	PARTICIPANT	\N	PRESENT	0
792725	792722	12028B	PARTICIPANT	\N	PRESENT	0
792726	792722	14267Y	PARTICIPANT	\N	PRESENT	0
792727	792722	08010L	PARTICIPANT	\N	PRESENT	0
792762	792758	14151M	PARTICIPANT	\N	PRESENT	0
792763	792758	17367Q	PARTICIPANT	\N	PRESENT	0
792768	792764	14151M	PARTICIPANT	\N	PRESENT	0
792769	792764	17367Q	PARTICIPANT	\N	PRESENT	0
793165	793164	18083K	PARTICIPANT	\N	PRESENT	0
793166	793164	21036C	PARTICIPANT	\N	PRESENT	0
793218	793174	14255U	PARTICIPANT	\N	PRESENT	0
793219	793174	14259Y	PARTICIPANT	\N	PRESENT	0
793220	793174	20100N	PARTICIPANT	\N	PRESENT	0
793221	793174	19695N	PARTICIPANT	\N	PRESENT	0
793222	793174	20048C	PARTICIPANT	\N	PRESENT	0
793223	793174	20052X	PARTICIPANT	\N	PRESENT	0
793224	793174	11045K	PARTICIPANT	\N	PRESENT	0
793394	793370	04070G	PARTICIPANT	\N	PRESENT	0
793395	793370	19699S	PARTICIPANT	\N	PRESENT	0
793396	793370	21058J	PARTICIPANT	\N	PRESENT	0
793397	793370	20102Q	PARTICIPANT	\N	PRESENT	0
793398	793370	14229S	PARTICIPANT	\N	PRESENT	0
793399	793370	19954N	PARTICIPANT	\N	PRESENT	0
793400	793370	18395Y	PARTICIPANT	\N	PRESENT	0
793401	793370	20112S	PARTICIPANT	\N	PRESENT	0
793402	793370	21089R	PARTICIPANT	\N	PRESENT	0
793403	793370	08012N	PARTICIPANT	\N	PRESENT	0
793404	793370	21091K	PARTICIPANT	\N	PRESENT	0
793405	793370	20124W	PARTICIPANT	\N	PRESENT	0
793406	793370	20026V	PARTICIPANT	\N	PRESENT	0
793407	793370	19593H	PARTICIPANT	\N	PRESENT	0
793408	793370	20132W	PARTICIPANT	\N	PRESENT	0
793409	793370	19611R	PRESIDENT	0	PRESENT	0
793410	793370	20142Y	PARTICIPANT	\N	PRESENT	0
793411	793370	19693L	PARTICIPANT	\N	PRESENT	0
793412	793370	20052X	PARTICIPANT	\N	PRESENT	0
793413	793370	20058E	PARTICIPANT	\N	PRESENT	0
793414	793370	14030Q	PARTICIPANT	\N	PRESENT	0
793415	793370	20056C	PARTICIPANT	\N	PRESENT	0
793416	793370	20180F	PARTICIPANT	\N	PRESENT	0
793417	793370	20264J	PARTICIPANT	\N	PRESENT	0
793418	793370	21063F	PARTICIPANT	\N	PRESENT	0
793419	793370	19735D	PARTICIPANT	\N	PRESENT	0
793420	793370	11043H	PARTICIPANT	\N	PRESENT	0
793421	793370	21077M	PARTICIPANT	\N	PRESENT	0
793468	791690	20114U	PARTICIPANT	\N	PRESENT	0
793471	791690	14215L	PARTICIPANT	\N	PRESENT	0
793472	791690	21044C	PARTICIPANT	\N	EXCUSE	0
793473	791690	18207D	PARTICIPANT	\N	EXCUSE	0
793475	791690	14053L	PARTICIPANT	\N	PRESENT	0
793476	791690	19649G	PARTICIPANT	\N	PRESENT	0
793477	791690	20036X	PARTICIPANT	\N	PRESENT	0
793478	791690	14189C	PARTICIPANT	\N	PRESENT	0
793479	791690	20074E	PARTICIPANT	\N	PRESENT	0
793480	791690	10015M	PARTICIPANT	\N	PRESENT	0
793481	791690	21057H	PARTICIPANT	\N	PRESENT	0
793482	791690	19673G	PARTICIPANT	\N	PRESENT	0
793483	791690	21040X	PARTICIPANT	\N	PRESENT	0
793484	791690	20098N	PARTICIPANT	\N	PRESENT	0
793485	791690	14151M	PARTICIPANT	\N	PRESENT	0
793486	791690	20022R	PARTICIPANT	\N	PRESENT	0
793487	791690	19447X	PARTICIPANT	\N	PRESENT	0
793488	791690	14231L	PARTICIPANT	\N	PRESENT	0
793489	791690	19725B	PARTICIPANT	\N	PRESENT	0
793490	791690	20266L	PARTICIPANT	\N	PRESENT	0
793491	791690	14147R	PARTICIPANT	\N	PRESENT	0
793492	791690	19489J	PARTICIPANT	\N	PRESENT	0
793493	791690	14089Y	PARTICIPANT	\N	PRESENT	0
793494	791690	19749K	PARTICIPANT	\N	PRESENT	0
793495	791690	04047H	PRESIDENT	0	PRESENT	0
793496	793370	19621T	PARTICIPANT	\N	PRESENT	0
793497	793370	21055F	PARTICIPANT	\N	PRESENT	0
793498	791690	14275Y	PARTICIPANT	\N	PRESENT	0
793499	791690	21038E	PARTICIPANT	\N	PRESENT	0
793500	791690	14069U	PARTICIPANT	\N	PRESENT	0
793501	791690	14111D	PARTICIPANT	\N	PRESENT	0
793502	791690	08018U	PARTICIPANT	\N	PRESENT	0
793503	791690	18231D	PARTICIPANT	\N	PRESENT	0
793504	793370	20048C	PARTICIPANT	\N	PRESENT	0
793505	791690	04045F	PARTICIPANT	\N	PRESENT	0
793506	791690	11056N	PARTICIPANT	\N	PRESENT	0
793507	791690	21056G	PARTICIPANT	\N	PRESENT	0
793508	791690	21088Q	PARTICIPANT	\N	PRESENT	0
793509	791690	19111A	PARTICIPANT	\N	PRESENT	0
793510	791690	21095P	PARTICIPANT	\N	PRESENT	0
793511	791690	14259Y	PARTICIPANT	\N	PRESENT	0
768749	761973	19713W	PARTICIPANT	\N	PRESENT	0
772084	769247	14111D	PARTICIPANT	\N	PRESENT	0
772093	769247	14229S	PARTICIPANT	\N	PRESENT	0
772094	769247	21077M	PARTICIPANT	\N	PRESENT	0
772095	769247	20142Y	PARTICIPANT	\N	PRESENT	0
772096	769247	19697Q	PARTICIPANT	\N	PRESENT	0
772098	769247	19553Y	PARTICIPANT	\N	PRESENT	0
772099	769247	21040X	PARTICIPANT	\N	PRESENT	0
772100	769247	20072C	PARTICIPANT	\N	PRESENT	0
772101	769247	19693L	PARTICIPANT	\N	PRESENT	0
772102	769247	21055F	PARTICIPANT	\N	PRESENT	0
772103	769247	20048C	PARTICIPANT	\N	PRESENT	0
772121	769247	20116W	PARTICIPANT	\N	PRESENT	0
772105	769247	19701S	PARTICIPANT	\N	PRESENT	0
772106	769247	19593H	PARTICIPANT	\N	PRESENT	0
772107	769247	19629C	PARTICIPANT	\N	PRESENT	0
772108	769247	19479G	PARTICIPANT	\N	PRESENT	0
772109	769247	19611R	PARTICIPANT	\N	PRESENT	0
772110	769247	20132W	PARTICIPANT	\N	PRESENT	0
772111	769247	14021P	PARTICIPANT	\N	PRESENT	0
772112	769247	21078N	PARTICIPANT	\N	PRESENT	0
772113	769247	20102Q	PARTICIPANT	\N	PRESENT	0
772114	769247	21053D	PARTICIPANT	\N	PRESENT	0
772116	769247	21032X	PARTICIPANT	\N	PRESENT	0
772117	769247	14207L	PARTICIPANT	\N	PRESENT	0
772118	769247	21037D	PARTICIPANT	\N	PRESENT	0
772119	769247	21066J	PARTICIPANT	\N	PRESENT	0
772120	769247	20124W	PARTICIPANT	\N	PRESENT	0
772122	769247	19719D	PARTICIPANT	\N	PRESENT	0
772123	769247	20032T	PARTICIPANT	\N	PRESENT	0
772124	769247	20040T	PARTICIPANT	\N	PRESENT	0
772125	769247	14073Q	PARTICIPANT	\N	PRESENT	0
772126	769247	14109K	PARTICIPANT	\N	PRESENT	0
772129	769247	20112S	PARTICIPANT	\N	PRESENT	0
772130	769247	19387D	PARTICIPANT	\N	PRESENT	0
772131	769247	14069U	PARTICIPANT	\N	PRESENT	0
772132	769247	21044C	PARTICIPANT	\N	PRESENT	0
772134	769247	20046A	PARTICIPANT	\N	PRESENT	0
772135	769247	19399H	PARTICIPANT	\N	PRESENT	0
772152	769247	19713W	PARTICIPANT	\N	PRESENT	0
772153	769247	18083K	PARTICIPANT	\N	PRESENT	0
772154	769247	20058E	PARTICIPANT	\N	PRESENT	0
772155	769247	20098N	PARTICIPANT	\N	PRESENT	0
772156	769247	08060W	PARTICIPANT	\N	PRESENT	0
772158	769247	21063F	PARTICIPANT	\N	PRESENT	0
772159	769247	14121F	PARTICIPANT	\N	PRESENT	0
772160	769247	20100N	PARTICIPANT	\N	PRESENT	0
772163	769247	19798U	PARTICIPANT	\N	PRESENT	0
772164	769247	14217N	PARTICIPANT	\N	PRESENT	0
772165	769247	14191V	PARTICIPANT	\N	PRESENT	0
772166	769247	11056N	PARTICIPANT	\N	PRESENT	0
772167	769247	19760E	PARTICIPANT	\N	PRESENT	0
772168	769247	19691J	PARTICIPANT	\N	PRESENT	0
772169	769247	17779H	PARTICIPANT	\N	PRESENT	0
772170	772077	14083S	PARTICIPANT	\N	PRESENT	0
772171	772077	19479G	PARTICIPANT	\N	PRESENT	0
772172	772077	11048N	PARTICIPANT	\N	PRESENT	0
772173	772077	19711U	PARTICIPANT	\N	PRESENT	0
772174	772077	21090J	PARTICIPANT	\N	PRESENT	0
772193	772077	20116W	PARTICIPANT	\N	PRESENT	0
772176	772077	12016W	PARTICIPANT	\N	PRESENT	0
772177	769247	14031R	PARTICIPANT	\N	PRESENT	0
772178	769247	21065H	PARTICIPANT	\N	PRESENT	0
772179	772077	20134Y	PARTICIPANT	\N	PRESENT	0
772180	772077	19399H	PARTICIPANT	\N	PRESENT	0
772181	772077	20150Y	PARTICIPANT	\N	PRESENT	0
772182	772077	14225N	PRESIDENT	0	PRESENT	0
772183	772077	11040E	PARTICIPANT	\N	PRESENT	0
772184	772077	07029T	PARTICIPANT	\N	PRESENT	0
772185	772077	08073C	PARTICIPANT	\N	PRESENT	0
772186	772077	20070A	PARTICIPANT	\N	PRESENT	0
772187	772077	19349W	PARTICIPANT	\N	PRESENT	0
772188	772077	14121F	PARTICIPANT	\N	PRESENT	0
772189	772077	21048G	PARTICIPANT	\N	PRESENT	0
772190	772077	20024T	PARTICIPANT	\N	PRESENT	0
772191	769247	21045D	PARTICIPANT	\N	PRESENT	0
772192	772077	19573D	PARTICIPANT	\N	PRESENT	0
772194	772077	08011M	PARTICIPANT	\N	PRESENT	0
772195	772077	20044X	PARTICIPANT	\N	PRESENT	0
772196	772077	21069M	PARTICIPANT	\N	PRESENT	0
772199	772077	11074Q	PARTICIPANT	\N	PRESENT	0
772200	772077	19545Y	PARTICIPANT	\N	PRESENT	0
772201	769247	04070G	PARTICIPANT	\N	PRESENT	0
772202	769247	14189C	PARTICIPANT	\N	PRESENT	0
772203	772077	19647E	PARTICIPANT	\N	PRESENT	0
772204	772077	08034U	PARTICIPANT	\N	PRESENT	0
772205	769247	20106U	PARTICIPANT	\N	PRESENT	0
772206	769247	20052X	PARTICIPANT	\N	PRESENT	0
772208	769247	14030Q	PARTICIPANT	\N	PRESENT	0
772265	769249	14219Q	PARTICIPANT	\N	PRESENT	0
772266	769249	19629C	PARTICIPANT	\N	PRESENT	0
772267	769249	14030Q	PARTICIPANT	\N	PRESENT	0
772268	769249	08060W	PARTICIPANT	\N	PRESENT	0
772269	769249	20124W	PARTICIPANT	\N	PRESENT	0
772270	769249	19713W	PARTICIPANT	\N	PRESENT	0
772271	769249	14191V	PARTICIPANT	\N	PRESENT	0
772272	769249	20020P	PARTICIPANT	\N	PRESENT	0
772273	769249	20090E	PARTICIPANT	\N	PRESENT	0
772274	769249	20100N	PARTICIPANT	\N	PRESENT	0
772275	769249	20106U	PARTICIPANT	\N	PRESENT	0
772276	769249	21065H	PARTICIPANT	\N	PRESENT	0
772277	769249	20072C	PARTICIPANT	\N	PRESENT	0
772278	769249	21032X	PARTICIPANT	\N	PRESENT	0
772279	769249	14042U	PARTICIPANT	\N	PRESENT	0
772280	769249	20046A	PARTICIPANT	\N	PRESENT	0
772281	769249	11056N	PARTICIPANT	\N	PRESENT	0
772282	769249	21030V	PARTICIPANT	\N	PRESENT	0
772283	769249	20040T	PARTICIPANT	\N	PRESENT	0
772284	769249	19553Y	PARTICIPANT	\N	PRESENT	0
772285	769249	20068G	PARTICIPANT	\N	PRESENT	0
772286	769249	18083K	PARTICIPANT	\N	PRESENT	0
772287	769249	21070E	PARTICIPANT	\N	PRESENT	0
772288	769249	14031R	PARTICIPANT	\N	PRESENT	0
772289	769249	10015M	PARTICIPANT	\N	PRESENT	0
772290	769249	04070G	PARTICIPANT	\N	PRESENT	0
772291	769249	19782L	PARTICIPANT	\N	PRESENT	0
772292	769249	21084L	PARTICIPANT	\N	PRESENT	0
772294	769249	20098N	PARTICIPANT	\N	PRESENT	0
772295	769249	21045D	PARTICIPANT	\N	PRESENT	0
772301	769249	21056G	PARTICIPANT	\N	PRESENT	0
772303	769249	20096L	PARTICIPANT	\N	PRESENT	0
772305	769249	20070A	PARTICIPANT	\N	PRESENT	0
772307	772306	20132W	PARTICIPANT	\N	PRESENT	0
772308	772306	04070G	PARTICIPANT	\N	PRESENT	0
772309	772306	19699S	PARTICIPANT	\N	PRESENT	0
772310	772306	19611R	PRESIDENT	0	PRESENT	0
772311	772306	21063F	PARTICIPANT	\N	PRESENT	0
772312	772306	18395Y	PARTICIPANT	\N	PRESENT	0
772313	772306	20142Y	PARTICIPANT	\N	PRESENT	0
772314	772306	14109K	PARTICIPANT	\N	PRESENT	0
772315	772306	21089R	PARTICIPANT	\N	PRESENT	0
772316	772306	20102Q	PARTICIPANT	\N	PRESENT	0
772317	772306	14030Q	PARTICIPANT	\N	PRESENT	0
772318	769249	21078N	PARTICIPANT	\N	PRESENT	0
772319	769249	19701S	PARTICIPANT	\N	PRESENT	0
772320	769249	21066J	PARTICIPANT	\N	PRESENT	0
772321	772306	19697Q	PARTICIPANT	\N	PRESENT	0
772322	772306	21091K	PARTICIPANT	\N	PRESENT	0
772323	769249	19387D	PARTICIPANT	\N	PRESENT	0
772324	769249	18193Q	PARTICIPANT	\N	PRESENT	0
772325	769249	19399H	PARTICIPANT	\N	PRESENT	0
772326	772306	20180F	PARTICIPANT	\N	PRESENT	0
772263	769249	14111D	PARTICIPANT	\N	PRESENT	0
772264	769249	19719D	PARTICIPANT	\N	PRESENT	0
772327	772077	20080C	PARTICIPANT	\N	PRESENT	0
772328	769249	07029T	PARTICIPANT	\N	PRESENT	0
772329	769249	14259Y	PARTICIPANT	\N	PRESENT	0
772330	769249	21041Y	PARTICIPANT	\N	PRESENT	0
787010	786435	14223L	PARTICIPANT	\N	PRESENT	1
787022	787021	19631V	PARTICIPANT	\N	PRESENT	0
787023	787021	14030Q	PARTICIPANT	\N	PRESENT	0
787024	787021	14083S	PARTICIPANT	\N	PRESENT	0
787025	787021	21034A	PARTICIPANT	\N	PRESENT	0
787026	787021	21032X	PARTICIPANT	\N	PRESENT	0
787027	787021	19591F	PARTICIPANT	\N	PRESENT	0
787028	787021	19683J	PARTICIPANT	\N	PRESENT	0
787029	787021	19699S	PARTICIPANT	\N	PRESENT	0
787030	787021	18193Q	PARTICIPANT	\N	PRESENT	0
787031	787021	20052X	PARTICIPANT	\N	PRESENT	0
787032	787021	14059S	PARTICIPANT	\N	PRESENT	0
787033	787021	19331L	PARTICIPANT	\N	PRESENT	0
787034	787021	19421M	PARTICIPANT	\N	PRESENT	0
787035	787021	21079P	PARTICIPANT	\N	PRESENT	0
787104	787103	19611R	PARTICIPANT	\N	PRESENT	0
787105	787103	20142Y	PARTICIPANT	\N	PRESENT	0
787106	787103	19735D	PARTICIPANT	\N	PRESENT	0
787591	787590	19826F	PARTICIPANT	\N	PRESENT	0
787593	787592	19826F	PARTICIPANT	\N	PRESENT	0
787595	787594	19826F	PARTICIPANT	\N	PRESENT	0
787597	787596	19826F	PARTICIPANT	\N	PRESENT	0
787599	787598	19826F	PARTICIPANT	\N	PRESENT	0
787601	787600	19826F	PARTICIPANT	\N	PRESENT	0
787603	787602	19826F	PARTICIPANT	\N	PRESENT	0
787604	787602	20092G	PARTICIPANT	\N	PRESENT	0
787605	787602	14257W	PARTICIPANT	\N	PRESENT	0
787607	787606	19826F	PARTICIPANT	\N	PRESENT	0
787608	787606	14257W	PARTICIPANT	\N	PRESENT	0
787610	787609	19826F	PARTICIPANT	\N	PRESENT	0
787663	786606	21082J	PARTICIPANT	\N	PRESENT	0
787664	786606	08034U	PARTICIPANT	\N	PRESENT	0
787665	786606	20038A	PRESIDENT	1	PRESENT	0
787666	786606	14031R	PARTICIPANT	\N	PRESENT	0
787667	786606	19413M	PARTICIPANT	\N	PRESENT	0
787668	786606	21093M	PARTICIPANT	\N	PRESENT	0
787669	786606	11090Q	PARTICIPANT	\N	PRESENT	0
787670	786606	14221J	PARTICIPANT	\N	PRESENT	0
787671	786606	21084L	PARTICIPANT	\N	PRESENT	0
787672	786606	21066J	PARTICIPANT	\N	PRESENT	0
787673	786606	99004R	PRESIDENT	0	PRESENT	0
787674	786606	21090J	PARTICIPANT	\N	PRESENT	0
787675	786606	21050A	PARTICIPANT	\N	PRESENT	0
787676	786606	17023S	PARTICIPANT	\N	PRESENT	0
787677	786606	19954N	PARTICIPANT	\N	EXCUSE	0
787678	786619	19707Y	PARTICIPANT	\N	PRESENT	0
787679	786619	19705W	PARTICIPANT	\N	PRESENT	0
787680	786619	21053D	PARTICIPANT	\N	PRESENT	0
787681	786619	19721W	PARTICIPANT	\N	PRESENT	0
787684	786619	19479G	PARTICIPANT	\N	PRESENT	0
787685	786619	14221J	PARTICIPANT	\N	PRESENT	0
787687	786619	20088L	PARTICIPANT	\N	PRESENT	0
787689	786619	14097Y	PARTICIPANT	\N	PRESENT	0
787690	786619	14275Y	PARTICIPANT	\N	PRESENT	0
787691	786619	14059S	PARTICIPANT	\N	PRESENT	0
787692	786619	11043H	PARTICIPANT	\N	PRESENT	0
787693	786619	17023S	PARTICIPANT	\N	PRESENT	0
787696	786619	21032X	PARTICIPANT	\N	PRESENT	0
787697	786197	21058J	PARTICIPANT	\N	PRESENT	0
787698	786197	11056N	PARTICIPANT	\N	PRESENT	0
787699	786197	14147R	PARTICIPANT	\N	PRESENT	0
787700	786197	14215L	PARTICIPANT	\N	PRESENT	0
787701	786197	21095P	PARTICIPANT	\N	PRESENT	0
787705	786619	14355X	PARTICIPANT	\N	PRESENT	0
787708	786619	98022P	PARTICIPANT	\N	PRESENT	0
787716	786619	21073H	PARTICIPANT	\N	PRESENT	0
787719	786619	21078N	PARTICIPANT	\N	PRESENT	0
787721	786619	21089R	PARTICIPANT	\N	PRESENT	0
787725	786619	20072C	PARTICIPANT	\N	PRESENT	0
787727	786619	21083K	PARTICIPANT	\N	PRESENT	0
787730	786619	19585H	PARTICIPANT	\N	PRESENT	0
787732	786619	21093M	PARTICIPANT	\N	PRESENT	0
787736	786619	20134Y	PARTICIPANT	\N	PRESENT	0
787739	786619	21077M	PARTICIPANT	\N	PRESENT	0
787744	786619	20018V	PARTICIPANT	\N	PRESENT	0
787748	786619	19693L	PARTICIPANT	\N	PRESENT	0
787751	786619	14257W	PARTICIPANT	\N	PRESENT	0
787752	786619	04045F	PARTICIPANT	\N	PRESENT	0
787753	786619	08009T	PARTICIPANT	\N	PRESENT	0
787754	786619	19649G	PARTICIPANT	\N	PRESENT	0
787755	786619	20028X	PARTICIPANT	\N	PRESENT	0
787756	786619	12028B	PARTICIPANT	\N	PRESENT	0
787757	786619	14211G	PARTICIPANT	\N	PRESENT	0
787759	786619	19826F	PARTICIPANT	\N	PRESENT	0
787760	786619	14231L	PARTICIPANT	\N	PRESENT	0
787761	786619	19749K	PARTICIPANT	\N	PRESENT	0
787762	786619	21050A	PARTICIPANT	\N	PRESENT	0
787763	786619	11045K	PARTICIPANT	\N	PRESENT	0
787764	786619	08060W	PARTICIPANT	\N	PRESENT	0
787765	786619	14073Q	PARTICIPANT	\N	PRESENT	0
787766	786619	19687N	PARTICIPANT	\N	PRESENT	0
787767	786619	20102Q	PARTICIPANT	\N	PRESENT	0
787768	786619	21084L	PARTICIPANT	\N	PRESENT	0
787779	782883	20146D	PARTICIPANT	\N	EXCUSE	0
787780	782883	21061D	PARTICIPANT	\N	EXCUSE	0
787781	782883	20130U	PARTICIPANT	\N	EXCUSE	0
788016	786619	19507S	PARTICIPANT	\N	PRESENT	0
788031	786619	21063F	PARTICIPANT	\N	PRESENT	0
787969	786619	21031W	PARTICIPANT	\N	PRESENT	0
788032	786619	19383Y	PARTICIPANT	\N	PRESENT	0
787971	786619	21042A	PARTICIPANT	\N	PRESENT	0
787972	786619	20058E	PARTICIPANT	\N	PRESENT	0
787973	786619	14030Q	PARTICIPANT	\N	PRESENT	0
787974	786619	14189C	PARTICIPANT	\N	PRESENT	0
787975	786619	14083S	PARTICIPANT	\N	PRESENT	0
787976	786619	20144B	PARTICIPANT	\N	PRESENT	0
787977	786619	11070L	PARTICIPANT	\N	PRESENT	0
787978	786619	14267Y	PARTICIPANT	\N	PRESENT	0
787979	786619	14327T	PARTICIPANT	\N	PRESENT	0
787980	786619	17229F	PARTICIPANT	\N	PRESENT	0
787981	786619	20248J	PARTICIPANT	\N	PRESENT	0
787982	786619	15197G	PARTICIPANT	\N	PRESENT	0
787983	786619	20040T	PARTICIPANT	\N	PRESENT	0
787991	786619	19685L	PARTICIPANT	\N	PRESENT	0
787985	786619	14042U	PARTICIPANT	\N	PRESENT	0
787986	786619	21086N	PARTICIPANT	\N	PRESENT	0
787987	786619	20286Q	PARTICIPANT	\N	PRESENT	0
787988	786619	19691J	PARTICIPANT	\N	PRESENT	0
787989	786619	07004J	PARTICIPANT	\N	PRESENT	0
787990	786619	19569H	PARTICIPANT	\N	PRESENT	0
787992	786619	21069M	PARTICIPANT	\N	PRESENT	0
787993	786619	20048C	PARTICIPANT	\N	PRESENT	0
787994	786619	19611R	PARTICIPANT	\N	PRESENT	0
787995	786619	19699S	PARTICIPANT	\N	PRESENT	0
787996	786619	14205J	PARTICIPANT	\N	PRESENT	0
787997	786619	14219Q	PARTICIPANT	\N	PRESENT	0
787998	786619	19335Q	PARTICIPANT	\N	PRESENT	0
787999	786619	19563B	PARTICIPANT	\N	PRESENT	0
788000	786619	04070G	PARTICIPANT	\N	PRESENT	0
788001	786619	21038E	PARTICIPANT	\N	PRESENT	0
788002	786619	19745F	PARTICIPANT	\N	PRESENT	0
788003	786619	19111A	PARTICIPANT	\N	PRESENT	0
788004	786619	21064G	PARTICIPANT	\N	PRESENT	0
788005	786619	19713W	PARTICIPANT	\N	PRESENT	0
788006	786619	19619A	PARTICIPANT	\N	PRESENT	0
788007	786619	01034P	PARTICIPANT	\N	PRESENT	0
788008	786619	19954N	PARTICIPANT	\N	PRESENT	0
788009	786619	20022R	PARTICIPANT	\N	PRESENT	0
788010	786619	20052X	PARTICIPANT	\N	PRESENT	0
788011	786619	14069U	PARTICIPANT	\N	PRESENT	0
788012	786619	21047F	PARTICIPANT	\N	PRESENT	0
788013	786619	14147R	PARTICIPANT	\N	PRESENT	0
788014	786619	20024T	PARTICIPANT	\N	PRESENT	0
788015	786619	17367Q	PARTICIPANT	\N	PRESENT	0
788017	786619	20090E	PARTICIPANT	\N	PRESENT	0
788018	786619	20140W	PARTICIPANT	\N	PRESENT	0
788019	786619	21091K	PARTICIPANT	\N	PRESENT	0
788020	786619	20038A	PARTICIPANT	\N	PRESENT	0
788021	786619	08018U	PARTICIPANT	\N	PRESENT	0
788022	786619	20172F	PARTICIPANT	\N	PRESENT	0
788023	786619	14357A	PARTICIPANT	\N	PRESENT	0
788024	786619	14038Y	PARTICIPANT	\N	PRESENT	0
788025	786619	14329V	PARTICIPANT	\N	PRESENT	0
788026	786619	20054A	PARTICIPANT	\N	PRESENT	0
788027	786619	20098N	PARTICIPANT	\N	PRESENT	0
788028	786619	08056B	PARTICIPANT	\N	PRESENT	0
788029	786619	14033T	PARTICIPANT	\N	PRESENT	0
788030	786619	20068G	PARTICIPANT	\N	PRESENT	0
788033	786619	20138D	PARTICIPANT	\N	PRESENT	0
788034	786619	20086J	PARTICIPANT	\N	PRESENT	0
788035	786619	19447X	PARTICIPANT	\N	PRESENT	0
772137	772136	19667J	PARTICIPANT	\N	PRESENT	0
772139	772136	14038Y	PARTICIPANT	\N	PRESENT	0
772144	772136	19735D	PARTICIPANT	\N	PRESENT	0
772145	772136	19723Y	PARTICIPANT	\N	PRESENT	0
772146	772136	19533U	PARTICIPANT	\N	PRESENT	0
772147	772136	21059K	PARTICIPANT	\N	PRESENT	0
772149	772136	20092G	PARTICIPANT	\N	PRESENT	0
772150	772136	21082J	PARTICIPANT	\N	PRESENT	0
772151	772136	19575F	PARTICIPANT	\N	PRESENT	0
773847	772597	21037D	PARTICIPANT	\N	PRESENT	0
773848	772597	08011M	PARTICIPANT	\N	PRESENT	0
773850	772597	14179A	PARTICIPANT	\N	PRESENT	0
773851	772597	99004R	PARTICIPANT	\N	PRESENT	0
773868	772597	19383Y	PARTICIPANT	\N	PRESENT	0
773877	772597	21064G	PARTICIPANT	\N	PRESENT	0
773878	772597	11043H	PARTICIPANT	\N	PRESENT	0
773879	772597	14219Q	PARTICIPANT	\N	PRESENT	0
773881	772597	11072N	PARTICIPANT	\N	PRESENT	0
773882	772597	14267Y	PARTICIPANT	\N	PRESENT	0
773885	772597	18193Q	PARTICIPANT	\N	PRESENT	0
773886	772597	19758L	PARTICIPANT	\N	PRESENT	0
773887	772597	19575F	PARTICIPANT	\N	PRESENT	0
773888	772597	17965H	PARTICIPANT	\N	PRESENT	0
773889	772597	08009T	PARTICIPANT	\N	PRESENT	0
773890	772597	19820Y	PARTICIPANT	\N	PRESENT	0
773891	772597	20100N	PARTICIPANT	\N	PRESENT	0
773894	772597	19701S	PARTICIPANT	\N	PRESENT	0
773895	772597	14357A	PARTICIPANT	\N	PRESENT	0
773900	772597	20048C	PARTICIPANT	\N	PRESENT	0
773913	772597	19621T	PARTICIPANT	\N	PRESENT	0
773914	772597	20132W	PARTICIPANT	\N	PRESENT	0
773915	772597	08060W	PARTICIPANT	\N	PRESENT	0
773916	772597	14217N	PARTICIPANT	\N	PRESENT	0
773918	772597	14189C	PARTICIPANT	\N	PRESENT	0
773919	772597	21087P	PARTICIPANT	\N	PRESENT	0
773920	772597	20018V	PARTICIPANT	\N	PRESENT	0
773921	772597	21045D	PARTICIPANT	\N	PRESENT	0
773922	772597	14033T	PARTICIPANT	\N	PRESENT	0
773923	772597	15197G	PARTICIPANT	\N	PRESENT	0
773924	772597	20116W	PARTICIPANT	\N	PRESENT	0
773925	772597	20064C	PARTICIPANT	\N	PRESENT	0
773926	772597	21044C	PARTICIPANT	\N	PRESENT	0
773927	772597	14053L	PARTICIPANT	\N	PRESENT	0
773928	772597	21080G	PARTICIPANT	\N	PRESENT	0
773929	772597	20022R	PARTICIPANT	\N	PRESENT	0
773930	772597	14187A	PARTICIPANT	\N	PRESENT	0
773931	772597	20104S	PARTICIPANT	\N	PRESENT	0
773932	772597	20140W	PARTICIPANT	\N	PRESENT	0
773933	772597	14195A	PARTICIPANT	\N	PRESENT	0
774009	772598	19489J	PARTICIPANT	\N	PRESENT	0
774010	772598	19711U	PARTICIPANT	\N	PRESENT	0
774011	772598	20044X	PARTICIPANT	\N	PRESENT	0
774012	772598	14219Q	PARTICIPANT	\N	PRESENT	0
774013	772598	19798U	PARTICIPANT	\N	PRESENT	0
774014	772598	20090E	PARTICIPANT	\N	PRESENT	0
774064	772598	20086J	PARTICIPANT	\N	PRESENT	0
774016	772598	19563B	PARTICIPANT	\N	PRESENT	0
774062	772598	19551W	PARTICIPANT	\N	PRESENT	0
774018	772598	11048N	PARTICIPANT	\N	PRESENT	0
774019	772598	14225N	PARTICIPANT	\N	PRESENT	0
774020	772598	07029T	PARTICIPANT	\N	PRESENT	0
774063	772598	14030Q	PARTICIPANT	\N	PRESENT	0
774022	772598	21048G	PARTICIPANT	\N	PRESENT	0
774023	772598	20092G	PARTICIPANT	\N	PRESENT	0
774024	772598	20080C	PARTICIPANT	\N	PRESENT	0
774025	772598	14121F	PARTICIPANT	\N	PRESENT	0
774026	772598	19479G	PARTICIPANT	\N	PRESENT	0
774027	772598	20100N	PARTICIPANT	\N	PRESENT	0
774028	772598	21079P	PARTICIPANT	\N	PRESENT	0
774029	772598	17965H	PARTICIPANT	\N	PRESENT	0
774030	772598	19820Y	PARTICIPANT	\N	PRESENT	0
774031	772598	18395Y	PARTICIPANT	\N	PRESENT	0
774032	772598	19647E	PARTICIPANT	\N	PRESENT	0
774033	772598	21087P	PARTICIPANT	\N	PRESENT	0
774034	772598	21046E	PARTICIPANT	\N	PRESENT	0
774035	772598	20066E	PARTICIPANT	\N	PRESENT	0
774036	772598	19691J	PARTICIPANT	\N	PRESENT	0
774037	772598	21053D	PARTICIPANT	\N	PRESENT	0
774038	772598	21064G	PARTICIPANT	\N	PRESENT	0
774039	772598	14189C	PARTICIPANT	\N	PRESENT	0
774040	772598	19631V	PARTICIPANT	\N	PRESENT	0
774041	772598	20060X	PARTICIPANT	\N	PRESENT	0
774042	772598	21045D	PARTICIPANT	\N	PRESENT	0
774043	772598	20028X	PARTICIPANT	\N	PRESENT	0
774044	772598	20124W	PARTICIPANT	\N	PRESENT	0
774045	772598	08034U	PARTICIPANT	\N	PRESENT	0
774046	772598	20024T	PARTICIPANT	\N	PRESENT	0
774047	772598	20058E	PARTICIPANT	\N	PRESENT	0
774048	772598	19701S	PARTICIPANT	\N	PRESENT	0
774049	772598	14053L	PARTICIPANT	\N	PRESENT	0
774050	772598	19679N	PARTICIPANT	\N	PRESENT	0
774051	772598	08028W	PARTICIPANT	\N	PRESENT	0
774052	772598	19621T	PARTICIPANT	\N	PRESENT	0
774053	772598	21063F	PARTICIPANT	\N	PRESENT	0
774054	772598	21058J	PARTICIPANT	\N	PRESENT	0
774055	772598	20096L	PARTICIPANT	\N	PRESENT	0
774056	772598	20180F	PARTICIPANT	\N	PRESENT	0
774057	772598	21080G	PARTICIPANT	\N	PRESENT	0
774058	772598	14215L	PARTICIPANT	\N	PRESENT	0
774059	772598	11043H	PARTICIPANT	\N	PRESENT	0
774060	772598	21044C	PARTICIPANT	\N	PRESENT	0
774061	772598	20070A	PARTICIPANT	\N	PRESENT	0
774065	772598	08015R	PARTICIPANT	\N	PRESENT	0
774066	772598	19687N	PARTICIPANT	\N	PRESENT	0
774067	772598	20038A	PARTICIPANT	\N	PRESENT	0
774068	772598	14026U	PARTICIPANT	\N	PRESENT	0
774069	772598	20056C	PARTICIPANT	\N	PRESENT	0
774070	772598	20026V	PARTICIPANT	\N	PRESENT	0
774071	772598	04033B	PARTICIPANT	\N	PRESENT	0
774072	772598	20108W	PARTICIPANT	\N	PRESENT	0
774073	772598	20140W	PARTICIPANT	\N	PRESENT	0
774074	772598	19349W	PARTICIPANT	\N	PRESENT	0
774075	772598	14357A	PARTICIPANT	\N	PRESENT	0
774076	772598	20062A	PARTICIPANT	\N	PRESENT	0
774077	772598	21068L	PARTICIPANT	\N	PRESENT	0
774078	772598	15197G	PARTICIPANT	\N	PRESENT	0
774079	772598	14231L	PARTICIPANT	\N	PRESENT	0
774080	772598	07004J	PARTICIPANT	\N	PRESENT	0
774081	772598	20054A	PARTICIPANT	\N	PRESENT	0
774082	772598	19703U	PARTICIPANT	\N	PRESENT	0
774083	772598	14173T	PARTICIPANT	\N	PRESENT	0
774084	772598	20106U	PARTICIPANT	\N	PRESENT	0
774007	772598	11090Q	PARTICIPANT	\N	PRESENT	0
774008	772598	11056N	PARTICIPANT	\N	PRESENT	0
774085	772598	21090J	PARTICIPANT	\N	PRESENT	0
774086	772598	19575F	PARTICIPANT	\N	PRESENT	0
774087	772598	14207L	PARTICIPANT	\N	PRESENT	0
774088	772598	20082E	PARTICIPANT	\N	PRESENT	0
774089	772598	21051B	PARTICIPANT	\N	PRESENT	0
774090	772598	14073Q	PARTICIPANT	\N	PRESENT	0
774091	772598	21070E	PARTICIPANT	\N	PRESENT	0
774092	772598	19768N	PARTICIPANT	\N	PRESENT	0
774093	772598	20052X	PARTICIPANT	\N	PRESENT	0
774094	772598	20048C	PARTICIPANT	\N	PRESENT	0
774095	772598	08010L	PARTICIPANT	\N	PRESENT	0
774096	772598	20118Y	PARTICIPANT	\N	PRESENT	0
774097	772598	14213J	PARTICIPANT	\N	PRESENT	0
774098	772598	14089Y	PARTICIPANT	\N	PRESENT	0
774099	772598	21049H	PARTICIPANT	\N	PRESENT	0
774100	772598	14107H	PARTICIPANT	\N	PRESENT	0
774101	772598	19387D	PARTICIPANT	\N	PRESENT	0
774102	772598	14083S	PARTICIPANT	\N	PRESENT	0
774103	772598	14033T	PARTICIPANT	\N	PRESENT	0
774104	772598	21041Y	PARTICIPANT	\N	PRESENT	0
774105	772598	14147R	PARTICIPANT	\N	PRESENT	0
774106	772598	20076G	PARTICIPANT	\N	PRESENT	0
774107	772598	19553Y	PARTICIPANT	\N	PRESENT	0
774108	772598	21040X	PARTICIPANT	\N	PRESENT	0
774109	772598	20094J	PARTICIPANT	\N	PRESENT	0
774110	772598	14187A	PARTICIPANT	\N	PRESENT	0
774111	772598	19507S	PARTICIPANT	\N	PRESENT	0
774112	772598	19383Y	PARTICIPANT	\N	PRESENT	0
774113	772598	18083K	PARTICIPANT	\N	PRESENT	0
774114	772598	21066J	PARTICIPANT	\N	PRESENT	0
774115	772598	19301E	PARTICIPANT	\N	PRESENT	0
793512	791690	19719D	PARTICIPANT	\N	PRESENT	0
793515	793370	14123H	PARTICIPANT	\N	PRESENT	0
793516	793369	19383Y	PARTICIPANT	\N	PRESENT	0
793517	793369	19768N	PARTICIPANT	\N	PRESENT	0
793518	793369	19782L	PARTICIPANT	\N	PRESENT	0
793519	793369	20092G	PARTICIPANT	\N	PRESENT	0
793520	793369	14357A	PARTICIPANT	\N	PRESENT	0
793521	793369	20078J	PARTICIPANT	\N	PRESENT	0
793522	793369	19413M	PARTICIPANT	\N	PRESENT	0
793523	793369	20082E	PARTICIPANT	\N	PRESENT	0
793524	793369	14221J	PARTICIPANT	\N	PRESENT	0
793525	793369	19631V	PARTICIPANT	\N	PRESENT	0
793526	793369	08015R	PARTICIPANT	\N	PRESENT	0
793527	793369	19575F	PARTICIPANT	\N	PRESENT	0
793528	793369	20018V	PARTICIPANT	\N	PRESENT	0
793529	793369	08028W	PARTICIPANT	\N	PRESENT	0
793530	793369	19563B	PARTICIPANT	\N	PRESENT	0
793531	793369	21050A	PARTICIPANT	\N	PRESENT	0
793532	793369	21096Q	PARTICIPANT	\N	PRESENT	0
793533	793369	14329V	PARTICIPANT	\N	PRESENT	0
793534	793369	20028X	PARTICIPANT	\N	PRESENT	0
793535	793369	14187A	PRESIDENT	0	PRESENT	0
793536	793369	20038A	PARTICIPANT	\N	PRESENT	0
793537	793369	21075K	PARTICIPANT	\N	PRESENT	0
793538	793369	21083K	PARTICIPANT	\N	PRESENT	0
793539	793369	21086N	PARTICIPANT	\N	PRESENT	0
793540	793369	20144B	PARTICIPANT	\N	PRESENT	0
793541	793369	19695N	PARTICIPANT	\N	PRESENT	0
793542	793369	14033T	PARTICIPANT	\N	PRESENT	0
793543	793369	11090Q	PARTICIPANT	\N	PRESENT	0
793544	793369	21093M	PARTICIPANT	\N	PRESENT	0
793545	793369	20054A	PARTICIPANT	\N	PRESENT	0
793546	793369	21033Y	PARTICIPANT	\N	PRESENT	0
793547	793369	14205J	PARTICIPANT	\N	PRESENT	0
793548	793369	20060X	PARTICIPANT	\N	PRESENT	0
793549	793369	20066E	PARTICIPANT	\N	PRESENT	0
793550	793369	21066J	PARTICIPANT	\N	PRESENT	0
793551	793369	20286Q	PARTICIPANT	\N	PRESENT	0
793552	793369	14207L	PARTICIPANT	\N	PRESENT	0
793553	793369	14257W	PARTICIPANT	0	PRESENT	0
793554	793369	21052C	PARTICIPANT	\N	EXCUSE	0
793555	791774	21036C	PARTICIPANT	\N	PRESENT	0
793556	791774	21030V	PARTICIPANT	\N	PRESENT	0
793557	791774	21031W	PARTICIPANT	\N	PRESENT	0
793558	791774	19565D	PARTICIPANT	\N	PRESENT	0
793559	791774	20072C	PARTICIPANT	\N	PRESENT	0
793560	791774	14001X	PARTICIPANT	\N	PRESENT	0
793561	791774	11027H	PARTICIPANT	\N	PRESENT	0
793562	791774	19669L	PARTICIPANT	\N	PRESENT	0
793563	791774	08056B	PARTICIPANT	\N	PRESENT	0
793564	791774	12028B	PARTICIPANT	\N	PRESENT	0
793565	791774	17737W	PARTICIPANT	\N	PRESENT	0
793566	791774	19421M	PARTICIPANT	\N	PRESENT	0
793567	791774	19709B	PARTICIPANT	\N	PRESENT	0
793568	791774	21067K	PARTICIPANT	\N	PRESENT	0
793569	791774	19347U	PARTICIPANT	\N	PRESENT	0
793570	791774	17367Q	PARTICIPANT	\N	PRESENT	0
793571	791774	14249W	PARTICIPANT	\N	PRESENT	0
793572	791774	20128B	PARTICIPANT	\N	PRESENT	0
793573	791774	14059S	PARTICIPANT	\N	PRESENT	0
793574	791774	14133K	PRESIDENT	0	PRESENT	0
793575	791774	21073H	PARTICIPANT	\N	PRESENT	0
793576	791774	19531S	PARTICIPANT	\N	PRESENT	0
793577	791774	20042V	PARTICIPANT	\N	PRESENT	0
793578	791774	14191V	PARTICIPANT	\N	PRESENT	0
793579	791774	20064C	PARTICIPANT	\N	PRESENT	0
793580	791774	98022P	PARTICIPANT	\N	PRESENT	0
793581	791774	14267Y	PARTICIPANT	\N	PRESENT	0
793582	791774	99004R	PARTICIPANT	\N	PRESENT	0
793583	791774	17023S	PARTICIPANT	\N	PRESENT	0
793584	791774	14255U	PARTICIPANT	\N	PRESENT	0
793610	791666	21082J	PARTICIPANT	\N	PRESENT	0
793611	791666	21029D	PARTICIPANT	\N	PRESENT	0
793612	791666	19701S	PARTICIPANT	\N	PRESENT	0
793613	791666	19533U	PARTICIPANT	\N	PRESENT	0
793614	791666	21035B	PARTICIPANT	\N	PRESENT	0
793615	791666	20076G	PARTICIPANT	\N	PRESENT	0
793616	791666	21042A	PARTICIPANT	\N	PRESENT	0
793617	791666	19820Y	PARTICIPANT	\N	PRESENT	0
793618	791666	14219Q	PRESIDENT	0	PRESENT	0
793619	791666	19826F	PARTICIPANT	\N	PRESENT	0
793620	791666	21061D	PARTICIPANT	\N	PRESENT	0
793621	791666	21062E	PARTICIPANT	\N	PRESENT	0
793622	791666	21065H	PARTICIPANT	\N	PRESENT	0
793623	791666	21084L	PARTICIPANT	\N	PRESENT	0
793624	791666	20100N	PARTICIPANT	\N	PRESENT	0
793625	791666	19551W	PARTICIPANT	\N	PRESENT	0
793626	791666	18083K	PARTICIPANT	\N	PRESENT	0
793627	791666	14237S	PARTICIPANT	\N	PRESENT	0
793628	791666	05012A	PARTICIPANT	\N	PRESENT	0
793629	791666	08060W	PARTICIPANT	\N	PRESENT	0
793630	791666	20106U	PARTICIPANT	\N	PRESENT	0
793631	791666	15197G	PARTICIPANT	\N	PRESENT	0
793632	791666	14107H	PARTICIPANT	\N	PRESENT	0
793633	791666	21080G	PARTICIPANT	\N	PRESENT	0
793634	791666	19331L	PARTICIPANT	\N	PRESENT	0
793635	791666	20020P	PARTICIPANT	\N	PRESENT	0
793636	791666	19685L	PARTICIPANT	\N	PRESENT	0
793637	791666	11065P	PARTICIPANT	\N	PRESENT	0
793638	791666	20120S	PARTICIPANT	\N	PRESENT	0
793639	791666	21051B	PARTICIPANT	\N	PRESENT	0
793640	791666	14038Y	PARTICIPANT	\N	PRESENT	0
793641	791666	20032T	PARTICIPANT	\N	PRESENT	0
793642	791666	21053D	PARTICIPANT	\N	PRESENT	0
793643	791666	20136B	PARTICIPANT	\N	PRESENT	0
793644	791666	14031R	PARTICIPANT	\N	PRESENT	0
793645	791666	19251M	PARTICIPANT	\N	PRESENT	0
793646	791666	20046A	PARTICIPANT	\N	PRESENT	0
793647	791666	17229F	PARTICIPANT	\N	PRESENT	0
793648	791666	14169X	PARTICIPANT	\N	PRESENT	0
793649	791666	21047F	PARTICIPANT	\N	PRESENT	0
793650	791666	20068G	PARTICIPANT	\N	PRESENT	0
793651	791666	21068L	PARTICIPANT	\N	PRESENT	0
793652	791666	21070E	PARTICIPANT	\N	PRESENT	0
793653	791666	19619A	PARTICIPANT	\N	PRESENT	0
793654	791666	19681G	PARTICIPANT	\N	EXCUSE	0
793687	793369	20030R	PARTICIPANT	\N	PRESENT	0
793688	793369	21054E	PARTICIPANT	\N	PRESENT	0
793689	793369	20034V	PARTICIPANT	\N	PRESENT	0
793690	793369	21092L	PARTICIPANT	\N	PRESENT	0
793705	791392	86034E	PARTICIPANT	\N	PRESENT	0
793709	791392	21055F	PARTICIPANT	\N	PRESENT	0
793710	791392	19367Y	PARTICIPANT	\N	PRESENT	0
793711	791392	98022P	PARTICIPANT	\N	PRESENT	0
793712	791392	14179A	PARTICIPANT	\N	PRESENT	0
793713	791392	20050V	PARTICIPANT	\N	PRESENT	0
793714	791392	21080G	PARTICIPANT	\N	PRESENT	0
793715	791392	20180F	PARTICIPANT	\N	PRESENT	0
793716	791392	14033T	PARTICIPANT	\N	PRESENT	0
793717	791392	21081H	PARTICIPANT	\N	PRESENT	0
793718	791392	14123H	PARTICIPANT	\N	PRESENT	0
793719	791392	99004R	PARTICIPANT	\N	PRESENT	0
793720	791392	21049H	PARTICIPANT	\N	PRESENT	0
793721	791392	21057H	PARTICIPANT	\N	PRESENT	0
793722	791392	14207L	PARTICIPANT	\N	PRESENT	0
793723	791392	21076L	PARTICIPANT	\N	PRESENT	0
793724	791392	14221J	PARTICIPANT	\N	PRESENT	0
793725	791392	08061X	PARTICIPANT	\N	PRESENT	0
793726	791392	19489J	PARTICIPANT	\N	PRESENT	0
793727	791392	19295A	PARTICIPANT	\N	PRESENT	0
793728	791392	20028X	PARTICIPANT	\N	PRESENT	0
793729	791392	19565D	PARTICIPANT	\N	PRESENT	0
793730	791392	11040E	PARTICIPANT	\N	PRESENT	0
793731	791392	21045D	PARTICIPANT	\N	PRESENT	0
793732	791392	21059K	PARTICIPANT	\N	PRESENT	0
793733	791392	21093M	PARTICIPANT	\N	PRESENT	0
793734	791392	19782L	PARTICIPANT	\N	PRESENT	0
793735	791392	14195A	PARTICIPANT	\N	PRESENT	0
793736	791392	19693L	PARTICIPANT	\N	PRESENT	0
793737	791392	14107H	PARTICIPANT	\N	PRESENT	0
793738	791392	19569H	PARTICIPANT	\N	PRESENT	0
793739	791392	19619A	PARTICIPANT	\N	PRESENT	0
793740	791392	19749K	PARTICIPANT	\N	PRESENT	0
793741	791392	21064G	PARTICIPANT	\N	PRESENT	0
793742	791392	19611R	PARTICIPANT	\N	PRESENT	0
793743	791392	14189C	PARTICIPANT	\N	PRESENT	0
793744	791392	19699S	PARTICIPANT	\N	PRESENT	0
793745	791392	14037X	PARTICIPANT	\N	PRESENT	0
793746	791392	21031W	PARTICIPANT	\N	PRESENT	0
793747	791392	14281W	PARTICIPANT	\N	PRESENT	0
793748	791392	18193Q	PARTICIPANT	\N	PRESENT	0
772363	769250	14225N	PARTICIPANT	\N	PRESENT	0
772364	769250	11040E	PARTICIPANT	\N	PRESENT	0
772365	769250	19349W	PARTICIPANT	\N	PRESENT	0
772366	769250	20070A	PARTICIPANT	\N	PRESENT	0
772367	769250	19711U	PARTICIPANT	\N	PRESENT	0
772368	769250	21085M	PARTICIPANT	\N	PRESENT	0
772369	769250	19545Y	PARTICIPANT	\N	PRESENT	0
772370	769250	07004J	PARTICIPANT	\N	PRESENT	0
772371	769250	20134Y	PARTICIPANT	\N	PRESENT	0
772372	769250	19687N	PARTICIPANT	\N	PRESENT	0
772373	769250	21041Y	PARTICIPANT	\N	PRESENT	0
772374	769250	19331L	PARTICIPANT	\N	PRESENT	0
772375	769250	20094J	PARTICIPANT	\N	PRESENT	0
772376	769250	20044X	PARTICIPANT	\N	PRESENT	0
772377	769250	14327T	PARTICIPANT	\N	PRESENT	0
772378	769250	20080C	PARTICIPANT	\N	PRESENT	0
772360	769250	14259Y	PARTICIPANT	\N	PRESENT	0
772362	769250	11048N	PARTICIPANT	\N	PRESENT	0
772379	769250	20054A	PARTICIPANT	\N	PRESENT	0
772380	769250	14083S	PARTICIPANT	\N	PRESENT	0
772381	769250	21090J	PARTICIPANT	\N	PRESENT	0
772382	769250	20090E	PARTICIPANT	\N	PRESENT	0
772383	769250	21053D	PARTICIPANT	\N	PRESENT	0
772384	769250	20098N	PARTICIPANT	\N	PRESENT	0
772387	769250	21079P	PARTICIPANT	\N	PRESENT	0
772388	769250	08011M	PARTICIPANT	\N	PRESENT	0
772389	769250	20052X	PARTICIPANT	\N	PRESENT	0
772390	769250	19683J	PARTICIPANT	\N	PRESENT	0
772391	769250	07029T	PARTICIPANT	\N	PRESENT	0
772392	769250	19399H	PARTICIPANT	\N	PRESENT	0
772393	769250	21054E	PARTICIPANT	\N	PRESENT	0
772394	769250	10015M	PARTICIPANT	\N	PRESENT	0
772395	769250	20062A	PARTICIPANT	\N	PRESENT	0
772396	769250	21048G	PARTICIPANT	\N	PRESENT	0
772397	769250	20130U	PARTICIPANT	\N	PRESENT	0
772398	769250	21044C	PARTICIPANT	\N	PRESENT	0
772399	769250	21095P	PARTICIPANT	\N	PRESENT	0
772400	769250	20024T	PARTICIPANT	\N	PRESENT	0
772401	769250	20018V	PARTICIPANT	\N	PRESENT	0
772402	769250	21045D	PARTICIPANT	\N	PRESENT	0
772403	769250	21089R	PARTICIPANT	\N	PRESENT	0
772404	769250	21074J	PARTICIPANT	\N	PRESENT	0
772405	769250	12016W	PARTICIPANT	\N	PRESENT	0
772406	769250	04033B	PARTICIPANT	\N	PRESENT	0
772407	769250	20088L	PARTICIPANT	\N	PRESENT	0
772408	769250	14281W	PARTICIPANT	\N	PRESENT	0
772409	769250	19782L	PARTICIPANT	\N	PRESENT	0
772410	769250	20132W	PARTICIPANT	\N	PRESENT	0
772411	769250	19647E	PARTICIPANT	\N	PRESENT	0
772412	769250	20116W	PARTICIPANT	\N	PRESENT	0
772413	769250	21066J	PARTICIPANT	\N	PRESENT	0
772414	769250	21072G	PARTICIPANT	\N	PRESENT	0
772415	769250	14229S	PARTICIPANT	\N	PRESENT	0
772416	769250	11045K	PARTICIPANT	\N	PRESENT	0
772417	769250	20104S	PARTICIPANT	\N	PRESENT	0
772418	769250	20124W	PARTICIPANT	\N	PRESENT	0
772419	769250	14189C	PARTICIPANT	\N	PRESENT	0
772420	769250	19301E	PARTICIPANT	\N	PRESENT	0
772422	769250	20068G	PARTICIPANT	\N	PRESENT	0
772424	769250	21033Y	PARTICIPANT	\N	PRESENT	0
772425	769250	20086J	PARTICIPANT	\N	PRESENT	0
772430	769250	20048C	PARTICIPANT	\N	PRESENT	0
772435	769250	21069M	PARTICIPANT	\N	PRESENT	0
772440	769250	19347U	PARTICIPANT	\N	PRESENT	0
772442	769250	19631V	PARTICIPANT	\N	PRESENT	0
772451	769250	19701S	PARTICIPANT	\N	PRESENT	0
772452	769250	19335Q	PARTICIPANT	\N	PRESENT	0
772453	769250	17965H	PARTICIPANT	\N	PRESENT	0
772454	769250	11074Q	PARTICIPANT	\N	PRESENT	0
772455	769250	14038Y	PARTICIPANT	\N	PRESENT	0
772456	769250	21092L	PARTICIPANT	\N	PRESENT	0
772458	769250	19629C	PARTICIPANT	\N	PRESENT	0
772459	769250	20100N	PARTICIPANT	\N	PRESENT	0
772460	769250	19667J	PARTICIPANT	\N	PRESENT	0
772461	769250	20142Y	PARTICIPANT	\N	PRESENT	0
772462	769250	11085T	PARTICIPANT	\N	PRESENT	0
772463	769250	08010L	PARTICIPANT	\N	PRESENT	0
772464	769250	21029D	PARTICIPANT	\N	PRESENT	0
772469	769250	08034U	PARTICIPANT	\N	PRESENT	0
772473	769250	11072N	PARTICIPANT	\N	PRESENT	0
772986	772502	19479G	PARTICIPANT	\N	PRESENT	0
772987	772502	21048G	PARTICIPANT	\N	PRESENT	0
772988	772502	19711U	PARTICIPANT	\N	PRESENT	0
772989	772502	20044X	PARTICIPANT	\N	PRESENT	0
772990	772502	20062A	PARTICIPANT	\N	PRESENT	0
772991	772502	14225N	PARTICIPANT	\N	PRESENT	0
772992	772502	21079P	PARTICIPANT	\N	PRESENT	0
772993	772502	21095P	PARTICIPANT	\N	PRESENT	0
772994	772502	07004J	PARTICIPANT	\N	PRESENT	0
772995	772502	19713W	PARTICIPANT	\N	PRESENT	0
772996	772502	21090J	PARTICIPANT	\N	PRESENT	0
772997	772502	14111D	PARTICIPANT	\N	PRESENT	0
772998	772502	20032T	PARTICIPANT	\N	PRESENT	0
772999	772502	21084L	PARTICIPANT	\N	PRESENT	0
773000	772502	19687N	PARTICIPANT	\N	PRESENT	0
773001	772502	21096Q	PARTICIPANT	\N	PRESENT	0
773002	772502	20034V	PARTICIPANT	\N	PRESENT	0
773003	772502	11072N	PARTICIPANT	\N	PRESENT	0
773004	772502	20130U	PARTICIPANT	\N	PRESENT	0
773005	772502	19619A	PARTICIPANT	\N	PRESENT	0
773006	772502	20086J	PARTICIPANT	\N	PRESENT	0
773007	772502	14253S	PARTICIPANT	\N	PRESENT	0
773008	772502	07029T	PARTICIPANT	\N	PRESENT	0
773009	772502	20070A	PARTICIPANT	\N	PRESENT	0
773010	772502	19820Y	PARTICIPANT	\N	PRESENT	0
773011	772502	14121F	PARTICIPANT	\N	PRESENT	0
773012	772502	04042C	PARTICIPANT	\N	PRESENT	0
773013	772502	12016W	PARTICIPANT	\N	PRESENT	0
773014	772502	19657G	PARTICIPANT	\N	PRESENT	0
773015	772502	14173T	PARTICIPANT	\N	PRESENT	0
773016	772502	14193X	PARTICIPANT	\N	PRESENT	0
773017	772502	20080C	PARTICIPANT	\N	PRESENT	0
773018	772502	14189C	PARTICIPANT	\N	PRESENT	0
773019	772502	11070L	PARTICIPANT	\N	PRESENT	0
773020	772502	20094J	PARTICIPANT	\N	PRESENT	0
773021	772502	20122U	PARTICIPANT	\N	PRESENT	0
773022	772502	20116W	PARTICIPANT	\N	PRESENT	0
773023	772502	21089R	PARTICIPANT	\N	PRESENT	0
773024	772502	19667J	PARTICIPANT	\N	PRESENT	0
773025	772502	14327T	PARTICIPANT	\N	PRESENT	0
773026	772502	19111A	PARTICIPANT	\N	PRESENT	0
773027	772502	08073C	PARTICIPANT	\N	PRESENT	0
773028	772502	19647E	PARTICIPANT	\N	PRESENT	0
773029	772502	19629C	PARTICIPANT	\N	PRESENT	0
773030	772502	20148F	PARTICIPANT	\N	PRESENT	0
773031	772502	20134Y	PARTICIPANT	\N	PRESENT	0
773032	772502	19301E	PARTICIPANT	\N	PRESENT	0
773033	772502	19563B	PARTICIPANT	\N	PRESENT	0
773034	772502	11074Q	PARTICIPANT	\N	PRESENT	0
773035	772502	14069U	PARTICIPANT	\N	PRESENT	0
773036	772502	19621T	PARTICIPANT	\N	PRESENT	0
773037	772502	14083S	PARTICIPANT	\N	PRESENT	0
773038	772502	21082J	PARTICIPANT	\N	PRESENT	0
773039	772502	14219Q	PARTICIPANT	\N	PRESENT	0
773040	772502	20036X	PARTICIPANT	\N	PRESENT	0
773041	772502	11110B	PARTICIPANT	\N	PRESENT	0
773042	772502	11053K	PARTICIPANT	\N	PRESENT	0
773043	772502	05012A	PARTICIPANT	\N	PRESENT	0
773044	772502	21061D	PARTICIPANT	\N	PRESENT	0
773045	772502	08011M	PARTICIPANT	\N	PRESENT	0
773046	772502	21072G	PARTICIPANT	\N	PRESENT	0
773047	772502	14211G	PARTICIPANT	\N	PRESENT	0
773048	772502	21032X	PARTICIPANT	\N	PRESENT	0
773049	772502	14037X	PARTICIPANT	\N	PRESENT	0
788036	786619	20034V	PARTICIPANT	\N	PRESENT	0
788037	786619	20056C	PARTICIPANT	\N	PRESENT	0
788038	786619	08034U	PARTICIPANT	\N	PRESENT	0
788039	786619	19399H	PARTICIPANT	\N	PRESENT	0
788040	786619	21058J	PARTICIPANT	\N	PRESENT	0
788041	786619	19657G	PARTICIPANT	\N	PRESENT	0
788042	786619	19709B	PARTICIPANT	\N	PRESENT	0
788043	786619	19729F	PARTICIPANT	\N	PRESENT	0
788044	786619	08015R	PARTICIPANT	\N	PRESENT	0
788045	786619	19723Y	PARTICIPANT	\N	PRESENT	0
788046	786619	07029T	PARTICIPANT	\N	PRESENT	0
788047	786619	21081H	PARTICIPANT	\N	PRESENT	0
788048	786619	20096L	PARTICIPANT	\N	PRESENT	0
788049	786619	08011M	PARTICIPANT	\N	PRESENT	0
788050	786619	14169X	PARTICIPANT	\N	PRESENT	0
788051	786619	14123H	PARTICIPANT	\N	PRESENT	0
788052	786619	08047A	PARTICIPANT	\N	PRESENT	0
788053	786619	21036C	PARTICIPANT	\N	PRESENT	0
788054	786619	20020P	PARTICIPANT	\N	PRESENT	0
788055	786619	21068L	PARTICIPANT	\N	PRESENT	0
788056	786619	20026V	PARTICIPANT	\N	PRESENT	0
788066	786619	14089Y	PARTICIPANT	\N	PRESENT	0
788058	786619	20126Y	PARTICIPANT	\N	PRESENT	0
788059	786619	21041Y	PARTICIPANT	\N	PRESENT	0
788060	786619	11065P	PARTICIPANT	\N	PRESENT	0
788061	786619	17965H	PARTICIPANT	\N	PRESENT	0
788062	786619	14179A	PARTICIPANT	\N	PRESENT	0
788063	786619	11085T	PARTICIPANT	\N	PRESENT	0
788064	786619	20062A	PARTICIPANT	\N	PRESENT	0
788065	786619	21039F	PARTICIPANT	\N	PRESENT	0
788067	786619	19565D	PARTICIPANT	\N	PRESENT	0
788402	786620	11090Q	PARTICIPANT	\N	PRESENT	0
788076	786619	08069G	PARTICIPANT	\N	PRESENT	0
788077	786619	20042V	PARTICIPANT	\N	PRESENT	0
788403	786620	17737W	PARTICIPANT	\N	PRESENT	0
788404	786620	14055N	PARTICIPANT	\N	PRESENT	0
788406	786620	04033B	PARTICIPANT	\N	PRESENT	0
788407	786620	11043H	PARTICIPANT	\N	PRESENT	0
788408	786620	20086J	PARTICIPANT	\N	PRESENT	0
788409	786620	18207D	PARTICIPANT	\N	PRESENT	0
788410	786620	14021P	PARTICIPANT	\N	PRESENT	0
788411	786620	19593H	PARTICIPANT	\N	PRESENT	0
788412	786620	21073H	PARTICIPANT	\N	PRESENT	0
788413	786620	19758L	PARTICIPANT	\N	PRESENT	0
788414	786620	19479G	PARTICIPANT	\N	PRESENT	0
788415	786620	19691J	PARTICIPANT	\N	PRESENT	0
788416	786620	20102Q	PARTICIPANT	\N	PRESENT	0
788417	786620	19111A	PARTICIPANT	\N	PRESENT	0
788418	786620	20038A	PARTICIPANT	\N	PRESENT	0
788419	786620	14215L	PARTICIPANT	\N	PRESENT	0
788420	786620	21068L	PARTICIPANT	\N	PRESENT	0
788421	786620	21058J	PARTICIPANT	\N	PRESENT	0
788422	786620	20096L	PARTICIPANT	\N	PRESENT	0
788423	786620	20180F	PARTICIPANT	\N	PRESENT	0
788424	786620	07029T	PARTICIPANT	\N	PRESENT	0
788425	786620	17023S	PARTICIPANT	\N	PRESENT	0
788426	786620	19251M	PARTICIPANT	\N	PRESENT	0
788427	786620	20128B	PARTICIPANT	\N	PRESENT	0
788428	786620	98022P	PARTICIPANT	\N	PRESENT	0
788429	786620	19621T	PARTICIPANT	\N	PRESENT	0
788430	786620	19347U	PARTICIPANT	\N	PRESENT	0
788431	786620	14069U	PARTICIPANT	\N	PRESENT	0
788432	786620	21078N	PARTICIPANT	\N	PRESENT	0
788434	786620	19631V	PARTICIPANT	\N	PRESENT	0
788435	786620	14037X	PARTICIPANT	\N	PRESENT	0
788437	786620	18083K	PARTICIPANT	\N	PRESENT	0
788438	786620	21034A	PARTICIPANT	\N	PRESENT	0
788439	786620	14195A	PARTICIPANT	\N	PRESENT	0
788440	786620	21070E	PARTICIPANT	\N	PRESENT	0
788441	786620	21054E	PARTICIPANT	\N	PRESENT	0
788442	786620	19647E	PARTICIPANT	\N	PRESENT	0
788443	786620	19745F	PARTICIPANT	\N	PRESENT	0
788444	786620	14249W	PARTICIPANT	\N	PRESENT	0
788445	786620	20082E	PARTICIPANT	\N	PRESENT	0
788446	786620	21072G	PARTICIPANT	\N	PRESENT	0
788447	786620	20062A	PARTICIPANT	\N	PRESENT	0
788448	786620	14147R	PARTICIPANT	\N	PRESENT	0
788449	786620	20058E	PARTICIPANT	\N	PRESENT	0
788450	786620	20098N	PARTICIPANT	\N	PRESENT	0
788451	786620	14191V	PARTICIPANT	\N	PRESENT	0
788452	786620	19349W	PARTICIPANT	\N	PRESENT	0
788453	786620	11056N	PARTICIPANT	\N	PRESENT	0
788454	786620	20032T	PARTICIPANT	\N	PRESENT	0
788455	786620	19713W	PARTICIPANT	\N	PRESENT	0
788457	786620	14133K	PARTICIPANT	\N	PRESENT	0
788458	786620	19798U	PARTICIPANT	\N	PRESENT	0
788459	786620	20084G	PARTICIPANT	\N	PRESENT	0
788557	788556	14083S	PARTICIPANT	\N	PRESENT	0
788559	788556	14267Y	PARTICIPANT	\N	PRESENT	0
788561	788556	21041Y	PARTICIPANT	\N	PRESENT	0
788562	788556	19725B	PARTICIPANT	\N	PRESENT	0
788564	788556	21036C	PARTICIPANT	\N	PRESENT	0
788565	788556	19421M	PARTICIPANT	\N	PRESENT	0
788566	788556	21095P	PARTICIPANT	\N	PRESENT	0
788580	786465	19349W	PARTICIPANT	\N	PRESENT	0
788636	786195	14259Y	PARTICIPANT	\N	PRESENT	0
788637	786196	11056N	PARTICIPANT	\N	PRESENT	0
788638	786196	14069U	PARTICIPANT	\N	PRESENT	0
788639	786196	08018U	PARTICIPANT	\N	PRESENT	0
788640	786196	04047H	PRESIDENT	\N	PRESENT	0
788641	786196	19673G	PARTICIPANT	\N	PRESENT	0
788642	786196	19447X	PARTICIPANT	\N	PRESENT	0
788643	786196	05008E	PARTICIPANT	\N	PRESENT	0
788644	786196	20098N	PARTICIPANT	\N	PRESENT	0
788645	786196	21057H	PARTICIPANT	\N	PRESENT	0
788646	786196	11085T	PARTICIPANT	\N	PRESENT	0
788647	786196	19585H	PARTICIPANT	\N	PRESENT	0
788648	786196	04045F	PARTICIPANT	\N	PRESENT	0
788649	786196	14259Y	PARTICIPANT	\N	PRESENT	0
788650	786196	14215L	PARTICIPANT	\N	PRESENT	0
788651	786196	21038E	PARTICIPANT	\N	PRESENT	0
788652	786196	20022R	PARTICIPANT	\N	PRESENT	0
788653	786196	21095P	PARTICIPANT	\N	PRESENT	0
788654	786196	14147R	PARTICIPANT	\N	PRESENT	0
788655	786196	20036X	PARTICIPANT	\N	PRESENT	0
788656	786196	14151M	PARTICIPANT	\N	PRESENT	0
788657	786196	20266L	PARTICIPANT	\N	PRESENT	0
788658	786196	20114U	PARTICIPANT	\N	PRESENT	0
788659	786196	19111A	PARTICIPANT	\N	PRESENT	0
788660	786196	18207D	PARTICIPANT	\N	PRESENT	0
788661	786196	18231D	PARTICIPANT	\N	PRESENT	0
788662	786196	20110Q	PARTICIPANT	\N	PRESENT	0
788663	786196	21088Q	PARTICIPANT	\N	PRESENT	0
788664	786196	14231L	PARTICIPANT	\N	PRESENT	0
788665	786196	19489J	PARTICIPANT	\N	PRESENT	0
788666	786196	14275Y	PARTICIPANT	\N	PRESENT	0
788667	786196	21056G	PARTICIPANT	\N	PRESENT	0
788668	786196	19729F	PARTICIPANT	\N	PRESENT	0
788669	786196	04008A	PARTICIPANT	\N	PRESENT	0
788670	786196	19749K	PARTICIPANT	\N	PRESENT	0
788671	786196	19725B	PARTICIPANT	\N	PRESENT	0
788672	786196	14089Y	PARTICIPANT	\N	PRESENT	0
788673	786196	21043B	PARTICIPANT	\N	PRESENT	0
788674	786196	21044C	PARTICIPANT	\N	PRESENT	0
788675	786196	14189C	PARTICIPANT	\N	PRESENT	0
788676	786196	21076L	PARTICIPANT	\N	PRESENT	0
788677	786196	19719D	PARTICIPANT	\N	PRESENT	0
788678	786196	21040X	PARTICIPANT	\N	PRESENT	0
788679	786196	11072N	PARTICIPANT	\N	PRESENT	0
788680	786196	14053L	PARTICIPANT	\N	PRESENT	0
788681	786196	14111D	PARTICIPANT	\N	PRESENT	0
788682	786196	19649G	PARTICIPANT	\N	PRESENT	0
789505	789504	21038E	PARTICIPANT	\N	PRESENT	0
789507	789506	21038E	PARTICIPANT	\N	PRESENT	0
789509	789508	14151M	PARTICIPANT	\N	PRESENT	0
789510	789508	17367Q	PARTICIPANT	\N	PRESENT	0
789632	789277	19729F	PARTICIPANT	\N	EXCUSE	0
789634	789277	21057H	PARTICIPANT	\N	EXCUSE	0
789635	789277	21038E	PARTICIPANT	\N	EXCUSE	0
791319	791318	20054A	PRESIDENT	0	PRESENT	0
791327	791318	21051B	PARTICIPANT	\N	PRESENT	0
791328	791318	21064G	PARTICIPANT	\N	PRESENT	0
791329	791318	21039F	PARTICIPANT	\N	PRESENT	0
791331	791318	20028X	PARTICIPANT	\N	PRESENT	0
791332	791318	21040X	PARTICIPANT	\N	PRESENT	0
791333	791318	21058J	PARTICIPANT	\N	PRESENT	0
791334	791318	20052X	PARTICIPANT	\N	PRESENT	0
791335	791318	20126Y	PARTICIPANT	\N	PRESENT	0
791336	791318	20172F	PARTICIPANT	\N	PRESENT	0
791337	791318	20038A	PARTICIPANT	\N	PRESENT	0
791338	791318	20144B	PARTICIPANT	\N	PRESENT	0
767881	766936	19679N	PARTICIPANT	\N	PRESENT	0
767882	766938	19679N	PARTICIPANT	\N	PRESENT	0
773233	773230	19760E	PARTICIPANT	\N	PRESENT	0
773234	773230	19683J	PARTICIPANT	\N	PRESENT	0
773235	773230	14026U	PARTICIPANT	\N	PRESENT	0
773414	773413	86034E	PARTICIPANT	\N	PRESENT	0
773415	773413	14133K	PARTICIPANT	\N	PRESENT	0
773416	773413	04047H	PARTICIPANT	\N	PRESENT	0
773417	773413	19629C	PARTICIPANT	\N	PRESENT	0
773418	773413	11056N	PARTICIPANT	\N	PRESENT	0
773419	773413	07033P	PARTICIPANT	\N	PRESENT	0
773420	773413	14187A	PARTICIPANT	\N	PRESENT	0
773421	773413	19347U	PARTICIPANT	\N	PRESENT	0
773422	773413	14179A	PARTICIPANT	\N	PRESENT	0
773423	773413	11048N	PARTICIPANT	\N	PRESENT	0
773424	773413	08010L	PARTICIPANT	\N	PRESENT	0
773425	773413	14037X	PARTICIPANT	\N	PRESENT	0
773426	773413	20052X	PARTICIPANT	\N	PRESENT	0
773427	773413	14219Q	PARTICIPANT	\N	PRESENT	0
773428	773413	14251Q	PARTICIPANT	\N	PRESENT	0
773429	773413	14111D	PARTICIPANT	\N	PRESENT	0
773430	773413	11085T	PARTICIPANT	\N	PRESENT	0
773431	773413	14071N	PARTICIPANT	\N	PRESENT	0
773432	773413	19593H	PARTICIPANT	\N	PRESENT	0
773433	773413	11090Q	PARTICIPANT	\N	PRESENT	0
773434	773413	14331P	PARTICIPANT	\N	PRESENT	0
773435	773413	14225N	PARTICIPANT	\N	PRESENT	0
773436	773413	04033B	PARTICIPANT	\N	PRESENT	0
773437	773413	14229S	PARTICIPANT	\N	PRESENT	0
773438	773413	11045K	PARTICIPANT	\N	PRESENT	0
773439	773413	21069M	PARTICIPANT	\N	PRESENT	0
773440	773413	19301E	PARTICIPANT	\N	PRESENT	0
773441	773413	19479G	PARTICIPANT	\N	PRESENT	0
774116	772598	21047F	PARTICIPANT	\N	PRESENT	0
774117	772598	14021P	PARTICIPANT	\N	PRESENT	0
774118	772598	04045F	PARTICIPANT	\N	PRESENT	0
774119	772598	19709B	PARTICIPANT	\N	PRESENT	0
774120	772598	19399H	PARTICIPANT	\N	PRESENT	0
774121	772598	19569H	PARTICIPANT	\N	PRESENT	0
774122	772598	19531S	PARTICIPANT	\N	PRESENT	0
774123	772598	21072G	PARTICIPANT	\N	PRESENT	0
774124	772598	21038E	PARTICIPANT	\N	PRESENT	0
774125	772598	20114U	PARTICIPANT	\N	PRESENT	0
774126	772598	21085M	PARTICIPANT	\N	PRESENT	0
774127	772598	20264J	PARTICIPANT	\N	PRESENT	0
774128	772598	20126Y	PARTICIPANT	\N	PRESENT	0
775922	775198	08018U	PRESIDENT	0	PRESENT	0
775923	775198	14053L	PARTICIPANT	\N	PRESENT	0
775924	775198	19649G	PARTICIPANT	\N	PRESENT	0
775926	775198	20074E	PARTICIPANT	\N	PRESENT	0
775927	775198	18231D	PARTICIPANT	\N	PRESENT	0
775928	775198	21043B	PARTICIPANT	\N	PRESENT	0
775929	775198	19111A	PARTICIPANT	\N	PRESENT	0
775935	775198	10015M	PARTICIPANT	\N	PRESENT	0
775936	775198	14151M	PARTICIPANT	\N	PRESENT	0
775937	775198	14215L	PARTICIPANT	\N	PRESENT	0
777455	777454	04047H	PARTICIPANT	\N	PRESENT	1
778844	775946	14189C	PARTICIPANT	\N	PRESENT	0
778845	775946	20094J	PARTICIPANT	\N	PRESENT	0
778846	775946	20042V	PARTICIPANT	\N	PRESENT	0
778847	775946	18395Y	PARTICIPANT	\N	PRESENT	0
778848	775946	19711U	PARTICIPANT	\N	PRESENT	0
778849	775946	19709B	PARTICIPANT	\N	PRESENT	0
778850	775946	14001X	PARTICIPANT	\N	PRESENT	0
778851	775946	14169X	PARTICIPANT	\N	PRESENT	0
778852	775946	21037D	PARTICIPANT	\N	PRESENT	0
778853	775946	14331P	PRESIDENT	0	PRESENT	0
778854	775946	21076L	PARTICIPANT	\N	PRESENT	0
778855	775946	19701S	PARTICIPANT	\N	PRESENT	0
778858	775946	14097Y	PARTICIPANT	\N	PRESENT	0
778864	775946	20286Q	PARTICIPANT	\N	EXCUSE	0
779710	776564	07004J	PARTICIPANT	\N	PRESENT	0
779711	776564	19647E	PARTICIPANT	\N	PRESENT	0
779712	776564	19565D	PARTICIPANT	\N	PRESENT	0
779713	776564	11027H	PARTICIPANT	\N	PRESENT	0
779728	776564	21030V	PARTICIPANT	\N	PRESENT	0
779715	776564	14255U	PARTICIPANT	\N	PRESENT	0
779716	776564	19709B	PARTICIPANT	\N	PRESENT	0
779729	776564	19669L	PARTICIPANT	\N	PRESENT	0
779730	776564	19711U	PARTICIPANT	\N	PRESENT	0
779744	776564	20126Y	PARTICIPANT	\N	PRESENT	0
779720	776564	20264J	PARTICIPANT	\N	PRESENT	0
779721	776564	21037D	PARTICIPANT	\N	PRESENT	0
779722	776564	19347U	PARTICIPANT	\N	PRESENT	0
779723	776564	21054E	PARTICIPANT	\N	PRESENT	0
779724	776564	14001X	PARTICIPANT	\N	PRESENT	0
779725	776564	19507S	PARTICIPANT	\N	PRESENT	0
779726	776564	14073Q	PARTICIPANT	\N	PRESENT	0
779727	776564	20076G	PARTICIPANT	\N	PRESENT	0
779731	776564	08047A	PARTICIPANT	\N	PRESENT	0
779732	776564	19705W	PARTICIPANT	\N	PRESENT	0
779733	776564	14037X	PARTICIPANT	\N	PRESENT	0
779734	776564	14207L	PARTICIPANT	\N	PRESENT	0
779735	776564	20072C	PARTICIPANT	\N	PRESENT	0
779736	776564	14257W	PARTICIPANT	\N	PRESENT	0
779737	776564	21073H	PARTICIPANT	\N	PRESENT	0
779738	776564	17737W	PARTICIPANT	\N	PRESENT	0
779708	776564	11090Q	PARTICIPANT	\N	PRESENT	0
779709	776564	14225N	PARTICIPANT	\N	PRESENT	0
779739	776564	14083S	PARTICIPANT	\N	PRESENT	0
779740	776564	20062A	PARTICIPANT	\N	PRESENT	0
779741	776564	14030Q	PARTICIPANT	\N	PRESENT	0
779742	776564	20252E	PARTICIPANT	\N	PRESENT	0
779743	776564	18231D	PARTICIPANT	\N	PRESENT	0
779745	776564	11048N	PARTICIPANT	\N	PRESENT	0
779746	776564	19782L	PARTICIPANT	\N	PRESENT	0
779747	776564	19421M	PARTICIPANT	\N	PRESENT	0
779748	776564	19531S	PARTICIPANT	\N	PRESENT	0
779749	776564	21041Y	PARTICIPANT	\N	PRESENT	0
779750	776564	19611R	PARTICIPANT	\N	PRESENT	0
779751	776564	20034V	PARTICIPANT	\N	PRESENT	0
779753	776564	99004R	PARTICIPANT	\N	PRESENT	0
779754	776564	08010L	PARTICIPANT	\N	PRESENT	0
779755	776564	19695N	PARTICIPANT	\N	PRESENT	0
779756	776564	17023S	PARTICIPANT	\N	PRESENT	0
779757	776564	07033P	PARTICIPANT	\N	PRESENT	0
779758	776564	20070A	PARTICIPANT	\N	PRESENT	0
779759	776564	14249W	PARTICIPANT	\N	PRESENT	0
779760	776564	21090J	PARTICIPANT	\N	PRESENT	0
779761	776565	11090Q	PARTICIPANT	\N	PRESENT	0
779762	776565	14225N	PARTICIPANT	\N	PRESENT	0
779765	776565	19565D	PARTICIPANT	\N	PRESENT	0
779767	776565	14255U	PARTICIPANT	\N	PRESENT	0
779768	776565	19709B	PARTICIPANT	\N	PRESENT	0
779771	776565	19347U	PARTICIPANT	\N	PRESENT	0
779772	776565	21054E	PARTICIPANT	\N	PRESENT	0
779773	776565	14001X	PARTICIPANT	\N	PRESENT	0
779774	776565	19507S	PARTICIPANT	\N	PRESENT	0
779776	776565	20076G	PARTICIPANT	\N	PRESENT	0
779778	776565	19669L	PARTICIPANT	\N	PRESENT	0
779779	776565	19711U	PARTICIPANT	\N	PRESENT	0
779780	776565	08047A	PARTICIPANT	\N	PRESENT	0
779781	776565	14037X	PARTICIPANT	\N	PRESENT	0
779782	776565	14207L	PARTICIPANT	\N	PRESENT	0
779783	776565	20072C	PARTICIPANT	\N	PRESENT	0
779786	776565	17737W	PARTICIPANT	\N	PRESENT	0
779787	776565	14083S	PARTICIPANT	\N	PRESENT	0
779790	776565	20126Y	PARTICIPANT	\N	PRESENT	0
779791	776565	11048N	PARTICIPANT	\N	PRESENT	0
779793	776565	19421M	PARTICIPANT	\N	PRESENT	0
779794	776565	19531S	PARTICIPANT	\N	PRESENT	0
779795	776565	21041Y	PARTICIPANT	\N	PRESENT	0
779796	776565	20034V	PARTICIPANT	\N	PRESENT	0
779798	776565	08010L	PARTICIPANT	\N	PRESENT	0
779799	776565	19695N	PARTICIPANT	\N	PRESENT	0
779800	776565	17023S	PARTICIPANT	\N	PRESENT	0
779801	776565	07033P	PARTICIPANT	\N	PRESENT	0
779802	776565	20070A	PARTICIPANT	\N	PRESENT	0
793749	791392	19349W	PARTICIPANT	\N	PRESENT	0
793750	791392	19697Q	PARTICIPANT	\N	PRESENT	0
793751	791392	21097R	PARTICIPANT	\N	PRESENT	0
793752	791392	04045F	PARTICIPANT	\N	PRESENT	0
793753	791392	21066J	PARTICIPANT	\N	PRESENT	0
793754	791392	19866P	PARTICIPANT	\N	PRESENT	0
793755	791392	14225N	PARTICIPANT	\N	PRESENT	0
793756	793691	20140W	PARTICIPANT	\N	EXCUSE	0
793757	793691	19349W	PARTICIPANT	\N	EXCUSE	0
793758	791392	19621T	PARTICIPANT	\N	PRESENT	0
793761	791392	18083K	PARTICIPANT	\N	PRESENT	0
793762	791392	19575F	PARTICIPANT	\N	PRESENT	0
793763	791392	21088Q	PARTICIPANT	\N	PRESENT	0
793764	791392	21089R	PARTICIPANT	\N	PRESENT	0
793765	791392	21091K	PARTICIPANT	\N	PRESENT	0
793766	791392	04047H	PARTICIPANT	\N	PRESENT	0
793767	791392	19703U	PARTICIPANT	\N	PRESENT	0
793768	791392	21071F	PARTICIPANT	\N	PRESENT	0
793769	791392	11048N	PARTICIPANT	\N	PRESENT	0
793770	791392	08034U	PARTICIPANT	\N	PRESENT	0
793771	791392	19760E	PARTICIPANT	\N	PRESENT	0
793772	791392	19758L	PARTICIPANT	\N	PRESENT	0
793773	791392	19695N	PARTICIPANT	\N	PRESENT	0
793774	791392	21075K	PARTICIPANT	\N	PRESENT	0
793775	791392	19711U	PARTICIPANT	\N	PRESENT	0
793776	791392	20078J	PARTICIPANT	\N	PRESENT	0
793777	791392	14259Y	PARTICIPANT	\N	PRESENT	0
793778	791392	08010L	PARTICIPANT	\N	PRESENT	0
793779	791392	14169X	PARTICIPANT	\N	PRESENT	0
793780	791392	19573D	PARTICIPANT	\N	PRESENT	0
793781	791392	10015M	PARTICIPANT	\N	PRESENT	0
793782	791392	11043H	PARTICIPANT	\N	PRESENT	0
793783	791392	20110Q	PARTICIPANT	\N	PRESENT	0
793784	791392	08028W	PARTICIPANT	\N	PRESENT	0
793785	791392	21029D	PARTICIPANT	\N	PRESENT	0
793786	791392	14191V	PARTICIPANT	\N	PRESENT	0
793787	791392	21072G	PARTICIPANT	\N	PRESENT	0
793788	791392	11065P	PARTICIPANT	\N	PRESENT	0
793789	791392	14237S	PARTICIPANT	\N	PRESENT	0
793790	791392	19687N	PARTICIPANT	\N	PRESENT	0
793791	791392	19593H	PARTICIPANT	\N	PRESENT	0
793792	791392	20044X	PARTICIPANT	\N	PRESENT	0
793793	791392	20134Y	PARTICIPANT	\N	PRESENT	0
793794	791392	14215L	PARTICIPANT	\N	PRESENT	0
793795	791392	20100N	PARTICIPANT	\N	PRESENT	0
793796	791392	20022R	PARTICIPANT	\N	PRESENT	0
793797	791392	19347U	PARTICIPANT	\N	PRESENT	0
793798	791392	11090Q	PARTICIPANT	\N	PRESENT	0
793799	791392	05012A	PARTICIPANT	\N	PRESENT	0
793800	791392	20142Y	PARTICIPANT	\N	PRESENT	0
793801	791392	21037D	PARTICIPANT	\N	PRESENT	0
793802	791392	20092G	PARTICIPANT	\N	PRESENT	0
793803	791392	21079P	PARTICIPANT	\N	PRESENT	0
793805	791392	14031R	PARTICIPANT	\N	PRESENT	0
793806	791392	19421M	PARTICIPANT	\N	PRESENT	0
793807	791392	20136B	PARTICIPANT	\N	PRESENT	0
793808	791392	21094N	PARTICIPANT	\N	PRESENT	0
793809	791392	19447X	PARTICIPANT	\N	PRESENT	0
793810	791392	21068L	PARTICIPANT	\N	PRESENT	0
793811	791392	21074J	PARTICIPANT	\N	PRESENT	0
793812	791392	20096L	PARTICIPANT	\N	PRESENT	0
793813	791392	21085M	PARTICIPANT	\N	PRESENT	0
793814	791392	20026V	PARTICIPANT	\N	PRESENT	0
793815	791392	19954N	PARTICIPANT	\N	PRESENT	0
793816	791392	20172F	PARTICIPANT	\N	PRESENT	0
793817	791392	20116W	PARTICIPANT	\N	PRESENT	0
793818	791392	14147R	PARTICIPANT	\N	PRESENT	0
793819	791392	20032T	PARTICIPANT	\N	PRESENT	0
793820	791392	14038Y	PARTICIPANT	\N	PRESENT	0
793821	791392	19723Y	PARTICIPANT	\N	PRESENT	0
793822	791392	20034V	PARTICIPANT	\N	PRESENT	0
793823	791392	21039F	PARTICIPANT	\N	PRESENT	0
793824	791392	21061D	PARTICIPANT	\N	PRESENT	0
793825	791392	19719D	PARTICIPANT	\N	PRESENT	0
793826	791392	20132W	PARTICIPANT	\N	PRESENT	0
793827	791392	20072C	PARTICIPANT	\N	PRESENT	0
793828	791392	21078N	PARTICIPANT	\N	PRESENT	0
793829	791392	21040X	PARTICIPANT	\N	PRESENT	0
793830	791392	21058J	PARTICIPANT	\N	PRESENT	0
793831	791392	20140W	PARTICIPANT	\N	PRESENT	0
793832	791392	21041Y	PARTICIPANT	\N	PRESENT	0
793833	791392	19629C	PARTICIPANT	\N	PRESENT	0
793834	791392	19553Y	PARTICIPANT	\N	PRESENT	0
793835	791392	19399H	PARTICIPANT	\N	PRESENT	0
793836	791392	20056C	PARTICIPANT	\N	PRESENT	0
793837	791392	21096Q	PARTICIPANT	\N	PRESENT	0
793838	791392	08069G	PARTICIPANT	\N	PRESENT	0
793839	791392	20058E	PARTICIPANT	\N	PRESENT	0
793840	791392	14249W	PARTICIPANT	\N	PRESENT	0
793841	791392	21036C	PARTICIPANT	\N	PRESENT	0
793842	791392	20128B	PARTICIPANT	\N	PRESENT	0
793843	791392	21092L	PARTICIPANT	\N	PRESENT	0
793844	791392	19591F	PARTICIPANT	\N	PRESENT	0
793847	791392	21063F	PARTICIPANT	\N	PRESENT	0
793848	791392	17367Q	PARTICIPANT	\N	PRESENT	0
793849	791392	20038A	PARTICIPANT	\N	PRESENT	0
793850	791392	08018U	PARTICIPANT	\N	PRESENT	0
793851	791392	19768N	PARTICIPANT	\N	PRESENT	0
793852	791392	08015R	PARTICIPANT	\N	PRESENT	0
793853	791392	19657G	PARTICIPANT	\N	PRESENT	0
793854	791392	14059S	PARTICIPANT	\N	PRESENT	0
793855	793846	21082J	PARTICIPANT	\N	PRESENT	0
793856	791392	14211G	PARTICIPANT	\N	PRESENT	0
793857	791392	08056B	PARTICIPANT	\N	PRESENT	0
793858	793846	08060W	PARTICIPANT	\N	PRESENT	0
793859	791392	20124W	PARTICIPANT	\N	PRESENT	0
793860	793846	20100N	PARTICIPANT	\N	PRESENT	0
793861	791392	21033Y	PARTICIPANT	\N	PRESENT	0
793862	791392	20126Y	PARTICIPANT	\N	PRESENT	0
793863	791392	20054A	PARTICIPANT	\N	PRESENT	0
793864	791392	20086J	PARTICIPANT	\N	PRESENT	0
793865	791392	21046E	PARTICIPANT	\N	PRESENT	0
793866	791392	20098N	PARTICIPANT	\N	PRESENT	0
793867	791392	07033P	PARTICIPANT	\N	PRESENT	0
793868	791392	19545Y	PARTICIPANT	\N	PRESENT	0
793869	791392	21095P	PARTICIPANT	\N	PRESENT	0
793870	791392	21065H	PARTICIPANT	\N	PRESENT	0
793871	791392	21087P	PARTICIPANT	\N	PRESENT	0
793872	791392	21090J	PARTICIPANT	\N	PRESENT	0
793873	791392	14217N	PARTICIPANT	\N	PRESENT	0
793874	791392	21054E	PARTICIPANT	\N	PRESENT	0
793875	791392	14251Q	PARTICIPANT	\N	PRESENT	0
793876	791392	20252E	PARTICIPANT	\N	PRESENT	0
793877	791392	14111D	PARTICIPANT	\N	PRESENT	0
793878	791392	20120S	PARTICIPANT	\N	PRESENT	0
793879	791392	21070E	PARTICIPANT	\N	PRESENT	0
793880	791392	20122U	PARTICIPANT	\N	PRESENT	0
793881	791392	19585H	PARTICIPANT	\N	PRESENT	0
793882	791392	20090E	PARTICIPANT	\N	PRESENT	0
793883	791392	19533U	PARTICIPANT	\N	PRESENT	0
793884	791392	14069U	PARTICIPANT	\N	PRESENT	0
793885	791392	19798U	PARTICIPANT	\N	PRESENT	0
793886	791392	14053L	PARTICIPANT	\N	PRESENT	0
793887	791392	14071N	PARTICIPANT	\N	PRESENT	0
793888	791392	04033B	PARTICIPANT	\N	PRESENT	0
793889	791392	19679N	PARTICIPANT	\N	PRESENT	0
793890	791392	20062A	PARTICIPANT	\N	PRESENT	0
793891	791392	05008E	PARTICIPANT	\N	PRESENT	0
793892	791392	14133K	PARTICIPANT	\N	PRESENT	0
793893	791392	14026U	PARTICIPANT	\N	PRESENT	0
793894	791392	19383Y	PARTICIPANT	\N	PRESENT	0
793895	791392	14213J	PARTICIPANT	\N	PRESENT	0
793896	791392	14187A	PARTICIPANT	\N	PRESENT	0
793897	791392	21035B	PARTICIPANT	\N	PRESENT	0
793898	791392	14357A	PARTICIPANT	\N	PRESENT	0
793899	791392	08060W	PARTICIPANT	\N	PRESENT	0
793900	791392	20114U	PARTICIPANT	\N	PRESENT	0
793901	791392	11074Q	PARTICIPANT	\N	PRESENT	0
793902	791392	08045X	PARTICIPANT	\N	PRESENT	0
793903	791392	19725B	PARTICIPANT	\N	PRESENT	0
793904	791392	19631V	PARTICIPANT	\N	PRESENT	0
793905	791392	20080C	PARTICIPANT	\N	PRESENT	0
793906	791392	20060X	PARTICIPANT	\N	PRESENT	0
793907	791392	12028B	PARTICIPANT	\N	PRESENT	0
793908	791392	20264J	PARTICIPANT	\N	PRESENT	0
793909	791392	11027H	PARTICIPANT	\N	PRESENT	0
793910	791392	20070A	PARTICIPANT	\N	PRESENT	0
793911	791392	18395Y	PARTICIPANT	\N	PRESENT	0
793912	791392	21067K	PARTICIPANT	\N	PRESENT	0
769437	765500	07029T	PARTICIPANT	\N	PRESENT	0
769438	765500	14331P	PARTICIPANT	\N	PRESENT	0
769439	765500	19711U	PARTICIPANT	\N	PRESENT	0
769440	765500	19687N	PARTICIPANT	\N	PRESENT	0
769441	765500	20070A	PARTICIPANT	\N	PRESENT	0
769442	765500	11053K	PARTICIPANT	\N	PRESENT	0
769443	765500	21090J	PARTICIPANT	\N	PRESENT	0
769444	765500	11074Q	PARTICIPANT	\N	PRESENT	0
769445	765500	14327T	PARTICIPANT	\N	PRESENT	0
769446	765500	11048N	PARTICIPANT	\N	PRESENT	0
769447	765500	14225N	PRESIDENT	0	PRESENT	0
769448	765500	20062A	PARTICIPANT	\N	PRESENT	0
769449	765500	20044X	PARTICIPANT	\N	PRESENT	0
769450	765500	20080C	PARTICIPANT	\N	PRESENT	0
769451	769232	19593H	PARTICIPANT	\N	PRESENT	0
769452	769232	14331P	PARTICIPANT	\N	PRESENT	0
769466	769232	11048N	PARTICIPANT	\N	PRESENT	0
769467	769232	08073C	PARTICIPANT	\N	PRESENT	0
769468	769232	20070A	PARTICIPANT	\N	PRESENT	0
769469	769232	20044X	PARTICIPANT	\N	PRESENT	0
769470	769232	20050V	PARTICIPANT	\N	PRESENT	0
769471	769232	11053K	PARTICIPANT	\N	PRESENT	0
769472	769232	20134Y	PARTICIPANT	\N	PRESENT	0
769473	769232	19687N	PARTICIPANT	\N	PRESENT	0
769474	769232	21041Y	PARTICIPANT	\N	PRESENT	0
769475	769232	20080C	PARTICIPANT	\N	PRESENT	0
769476	769232	20086J	PARTICIPANT	\N	PRESENT	0
769477	769232	11070L	PARTICIPANT	\N	PRESENT	0
769478	769232	21090J	PARTICIPANT	\N	PRESENT	0
769479	769232	20062A	PARTICIPANT	\N	PRESENT	0
769480	769232	19711U	PARTICIPANT	\N	PRESENT	0
769481	769232	19667J	PARTICIPANT	\N	PRESENT	0
769482	769232	07029T	PARTICIPANT	\N	PRESENT	0
769483	769232	14191V	PARTICIPANT	\N	PRESENT	0
769484	769232	14211G	PARTICIPANT	\N	PRESENT	0
769485	769232	21076L	PARTICIPANT	\N	PRESENT	0
769486	769232	21095P	PARTICIPANT	\N	PRESENT	0
769487	769232	19695N	PARTICIPANT	\N	PRESENT	0
769488	769232	19760E	PARTICIPANT	\N	PRESENT	0
769489	769232	14225N	PARTICIPANT	\N	PRESENT	0
769490	769232	14083S	PARTICIPANT	\N	PRESENT	0
769491	769232	21088Q	PARTICIPANT	\N	PRESENT	0
769500	769232	14073Q	PARTICIPANT	\N	PRESENT	0
769493	769232	20252E	PARTICIPANT	\N	PRESENT	0
769494	769232	21056G	PARTICIPANT	\N	PRESENT	0
769495	769232	11074Q	PARTICIPANT	\N	PRESENT	0
769496	769232	19399H	PARTICIPANT	\N	PRESENT	0
769497	769232	20028X	PARTICIPANT	\N	PRESENT	0
769498	769232	14275Y	PARTICIPANT	\N	PRESENT	0
769499	769232	08028W	PARTICIPANT	\N	PRESENT	0
769501	769232	19591F	PARTICIPANT	\N	PRESENT	0
769502	769232	21033Y	PARTICIPANT	\N	PRESENT	0
769506	769232	19331L	PARTICIPANT	\N	PRESENT	0
769508	769232	11072N	PARTICIPANT	\N	PRESENT	0
769509	769232	19573D	PARTICIPANT	\N	PRESENT	0
769510	769232	20142Y	PARTICIPANT	\N	PRESENT	0
769511	769232	20048C	PARTICIPANT	\N	PRESENT	0
769512	769232	19719D	PARTICIPANT	\N	PRESENT	0
769513	769232	14030Q	PARTICIPANT	\N	PRESENT	0
769515	769232	19723Y	PARTICIPANT	\N	PRESENT	0
769518	769232	08061X	PARTICIPANT	\N	PRESENT	0
769519	769232	14179A	PARTICIPANT	\N	PRESENT	0
769521	769232	14021P	PARTICIPANT	\N	PRESENT	0
770830	770829	14073Q	PARTICIPANT	\N	PRESENT	0
770850	765753	19697Q	PARTICIPANT	\N	PRESENT	0
770853	765753	04033B	PARTICIPANT	\N	PRESENT	0
770854	765753	20048C	PARTICIPANT	\N	PRESENT	0
770967	765753	19057M	PARTICIPANT	\N	PRESENT	0
772385	772136	20072C	PARTICIPANT	\N	EXCUSE	0
772386	772136	18231D	PARTICIPANT	\N	EXCUSE	0
773141	769260	14069U	PARTICIPANT	\N	PRESENT	0
773106	769260	21048G	PARTICIPANT	\N	PRESENT	0
773107	769260	19711U	PARTICIPANT	\N	PRESENT	0
773108	769260	14225N	PARTICIPANT	\N	PRESENT	0
773109	769260	20062A	PARTICIPANT	\N	PRESENT	0
773110	769260	14083S	PARTICIPANT	\N	PRESENT	0
773139	769260	20036X	PARTICIPANT	\N	PRESENT	0
773112	769260	19713W	PARTICIPANT	\N	PRESENT	0
773113	769260	19619A	PARTICIPANT	\N	PRESENT	0
773114	769260	20116W	PARTICIPANT	\N	PRESENT	0
773140	769260	14037X	PARTICIPANT	\N	PRESENT	0
773116	769260	07029T	PARTICIPANT	\N	PRESENT	0
773117	769260	21061D	PARTICIPANT	\N	PRESENT	0
773118	769260	20070A	PARTICIPANT	\N	PRESENT	0
773150	769260	20058E	PARTICIPANT	\N	PRESENT	0
773120	769260	20044X	PARTICIPANT	\N	PRESENT	0
773142	769260	21072G	PARTICIPANT	\N	PRESENT	0
773122	769260	21084L	PARTICIPANT	\N	PRESENT	0
773123	769260	12016W	PARTICIPANT	\N	PRESENT	0
773124	769260	11074Q	PARTICIPANT	\N	PRESENT	0
773125	769260	19301E	PARTICIPANT	\N	PRESENT	0
773126	769260	11072N	PARTICIPANT	\N	PRESENT	0
773127	769260	20080C	PARTICIPANT	\N	PRESENT	0
773128	769260	11110B	PARTICIPANT	\N	PRESENT	0
773129	769260	19820Y	PARTICIPANT	\N	PRESENT	0
773130	769260	14211G	PARTICIPANT	\N	PRESENT	0
773131	769260	14231L	PARTICIPANT	\N	PRESENT	0
773132	769260	14327T	PARTICIPANT	\N	PRESENT	0
773133	769260	14189C	PARTICIPANT	\N	PRESENT	0
773134	769260	20034V	PARTICIPANT	\N	PRESENT	0
773135	769260	20086J	PARTICIPANT	\N	PRESENT	0
773136	769260	05012A	PARTICIPANT	\N	PRESENT	0
773137	769260	20032T	PARTICIPANT	\N	PRESENT	0
773138	769260	21071F	PARTICIPANT	\N	PRESENT	0
773143	769260	20148F	PARTICIPANT	\N	PRESENT	0
773144	769260	19621T	PARTICIPANT	\N	PRESENT	0
773103	769260	14111D	PARTICIPANT	\N	PRESENT	0
773104	769260	19687N	PARTICIPANT	\N	PRESENT	0
773145	769260	21090J	PARTICIPANT	\N	PRESENT	0
773146	769260	19573D	PARTICIPANT	\N	PRESENT	0
773147	769260	14219Q	PARTICIPANT	\N	PRESENT	0
773148	769260	20094J	PARTICIPANT	\N	PRESENT	0
773149	769260	21082J	PARTICIPANT	\N	PRESENT	0
773151	769260	19563B	PARTICIPANT	\N	PRESENT	0
773152	769260	19647E	PARTICIPANT	\N	PRESENT	0
773153	769260	08011M	PARTICIPANT	\N	PRESENT	0
773154	769260	20134Y	PARTICIPANT	\N	PRESENT	0
775815	775814	04047H	PARTICIPANT	\N	PRESENT	1
775816	775814	18231D	PARTICIPANT	\N	PRESENT	0
775818	775817	20084G	PARTICIPANT	\N	PRESENT	0
775819	775817	20180F	PARTICIPANT	\N	PRESENT	0
775820	775817	21086N	PARTICIPANT	\N	PRESENT	0
775827	775821	21086N	PARTICIPANT	\N	PRESENT	0
775828	775822	20084G	PARTICIPANT	\N	PRESENT	0
775829	775822	21086N	PARTICIPANT	\N	PRESENT	0
775830	775823	21086N	PARTICIPANT	\N	PRESENT	0
775831	775823	20084G	PARTICIPANT	\N	PRESENT	0
775948	775825	21086N	PARTICIPANT	\N	PRESENT	0
775954	775824	21086N	PARTICIPANT	\N	PRESENT	0
775956	775955	21094N	PARTICIPANT	\N	PRESENT	0
775957	775955	21045D	PARTICIPANT	\N	PRESENT	0
775959	775958	20130U	PARTICIPANT	\N	PRESENT	1
775960	775958	21094N	PARTICIPANT	\N	PRESENT	0
775965	775961	21094N	PARTICIPANT	\N	PRESENT	0
775967	775961	20130U	PARTICIPANT	\N	PRESENT	1
775970	775969	21094N	PARTICIPANT	\N	PRESENT	0
777373	776547	11040E	PARTICIPANT	\N	PRESENT	0
777374	776547	14223L	PARTICIPANT	\N	PRESENT	0
777375	776547	20034V	PARTICIPANT	\N	PRESENT	0
777376	776547	20086J	PARTICIPANT	\N	PRESENT	0
777377	776547	14109K	PARTICIPANT	\N	PRESENT	0
777378	776547	07029T	PARTICIPANT	\N	PRESENT	0
777379	776547	14331P	PARTICIPANT	\N	PRESENT	0
777380	776547	19723Y	PARTICIPANT	\N	PRESENT	0
777381	776547	19782L	PARTICIPANT	\N	PRESENT	0
777382	776547	20042V	PARTICIPANT	\N	PRESENT	0
777383	776547	19713W	PARTICIPANT	\N	PRESENT	0
777384	776547	14111D	PARTICIPANT	\N	PRESENT	0
777385	776547	19729F	PARTICIPANT	\N	PRESENT	0
777386	776547	14249W	PARTICIPANT	\N	PRESENT	0
777387	776547	19367Y	PARTICIPANT	\N	PRESENT	0
777389	776547	21045D	PARTICIPANT	\N	PRESENT	0
777390	776547	14151M	PARTICIPANT	\N	PRESENT	0
777392	776547	14257W	PARTICIPANT	\N	PRESENT	0
777393	776547	14069U	PARTICIPANT	\N	PRESENT	0
777394	776547	19383Y	PARTICIPANT	\N	PRESENT	0
777395	776547	14031R	PARTICIPANT	\N	PRESENT	0
777396	776547	14030Q	PARTICIPANT	\N	PRESENT	0
777397	776547	98022P	PARTICIPANT	\N	PRESENT	0
791339	791318	14083S	PARTICIPANT	\N	PRESENT	0
791340	791318	21045D	PARTICIPANT	\N	PRESENT	0
791341	791318	21050A	PARTICIPANT	\N	PRESENT	0
791366	791318	21067K	PARTICIPANT	\N	PRESENT	0
791579	789503	20134Y	PARTICIPANT	\N	PRESENT	0
791712	791711	14073Q	PARTICIPANT	\N	PRESENT	0
791713	791711	14083S	PARTICIPANT	\N	PRESENT	0
791714	791711	14249W	PARTICIPANT	\N	PRESENT	0
791715	791711	20126Y	PARTICIPANT	\N	PRESENT	0
791716	791711	19611R	PARTICIPANT	\N	PRESENT	0
791717	791711	19723Y	PARTICIPANT	\N	PRESENT	0
791718	791711	14147R	PARTICIPANT	\N	PRESENT	0
791763	791762	20022R	PARTICIPANT	\N	PRESENT	0
791764	791762	20094J	PARTICIPANT	\N	PRESENT	0
791765	791762	21046E	PARTICIPANT	\N	PRESENT	0
791766	791762	19251M	PARTICIPANT	\N	PRESENT	0
791767	791762	20124W	PARTICIPANT	\N	PRESENT	0
791768	791762	20128B	PARTICIPANT	\N	PRESENT	0
791769	791762	19565D	PARTICIPANT	\N	PRESENT	0
791770	791762	20126Y	PARTICIPANT	\N	PRESENT	0
791771	791762	14193X	PARTICIPANT	\N	PRESENT	0
791772	791762	20054A	PARTICIPANT	\N	PRESENT	0
791773	791762	04045F	PARTICIPANT	\N	PRESENT	0
791909	791382	20046A	PARTICIPANT	\N	PRESENT	0
791910	791382	12016W	PARTICIPANT	\N	PRESENT	0
791911	791382	19693L	PARTICIPANT	\N	PRESENT	0
791912	791382	21056G	PARTICIPANT	\N	PRESENT	0
791913	791382	20080C	PARTICIPANT	\N	PRESENT	0
791914	791382	98022P	PARTICIPANT	\N	PRESENT	0
791915	791382	12028B	PARTICIPANT	\N	PRESENT	0
791916	791382	18207D	PARTICIPANT	\N	PRESENT	0
791917	791382	19683J	PARTICIPANT	\N	PRESENT	0
791918	791382	21087P	PARTICIPANT	\N	PRESENT	0
791919	791382	21054E	PARTICIPANT	\N	PRESENT	0
791920	791382	14195A	PARTICIPANT	\N	PRESENT	0
791921	791382	19545Y	PARTICIPANT	\N	PRESENT	0
791922	791382	14001X	PARTICIPANT	\N	PRESENT	0
791923	791382	21046E	PARTICIPANT	\N	PRESENT	0
791924	791382	14151M	PARTICIPANT	\N	PRESENT	0
791925	791382	14089Y	PARTICIPANT	\N	PRESENT	0
791926	791382	14327T	PARTICIPANT	\N	PRESENT	0
791927	791382	21083K	PARTICIPANT	\N	PRESENT	0
791928	791382	14107H	PARTICIPANT	\N	PRESENT	0
791929	791382	20042V	PARTICIPANT	\N	PRESENT	0
791930	791382	21033Y	PARTICIPANT	\N	PRESENT	0
791931	791382	19111A	PARTICIPANT	\N	PRESENT	0
791932	791382	14231L	PARTICIPANT	\N	PRESENT	0
791933	791382	17229F	PARTICIPANT	\N	PRESENT	0
791934	791382	11085T	PARTICIPANT	\N	PRESENT	0
791935	791382	19707Y	PARTICIPANT	\N	PRESENT	0
791936	791382	20036X	PARTICIPANT	\N	PRESENT	0
791937	791382	21097R	PARTICIPANT	\N	PRESENT	0
791938	791382	21080G	PARTICIPANT	\N	PRESENT	0
791939	791382	11043H	PARTICIPANT	\N	PRESENT	0
791940	791382	14191V	PARTICIPANT	\N	PRESENT	0
791941	791382	21078N	PARTICIPANT	\N	PRESENT	0
791942	791382	21088Q	PARTICIPANT	\N	PRESENT	0
791943	791382	11040E	PARTICIPANT	\N	PRESENT	0
791944	791382	19575F	PARTICIPANT	\N	PRESENT	0
791945	791382	99004R	PARTICIPANT	\N	PRESENT	0
791946	791382	11056N	PARTICIPANT	\N	PRESENT	0
791947	791382	21084L	PARTICIPANT	\N	PRESENT	0
791948	791382	19593H	PARTICIPANT	\N	PRESENT	0
791949	791382	19565D	PARTICIPANT	\N	PRESENT	0
791950	791382	19695N	PARTICIPANT	\N	PRESENT	0
791951	791382	19760E	PARTICIPANT	\N	PRESENT	0
791952	791382	20102Q	PARTICIPANT	\N	PRESENT	0
791953	791382	20112S	PARTICIPANT	\N	PRESENT	0
791954	791382	11065P	PARTICIPANT	\N	PRESENT	0
791955	791382	20092G	PARTICIPANT	\N	PRESENT	0
791956	791382	19347U	PARTICIPANT	\N	PRESENT	0
791957	791382	20266L	PARTICIPANT	\N	PRESENT	0
791958	791382	21094N	PARTICIPANT	\N	PRESENT	0
791959	791382	21037D	PARTICIPANT	\N	PRESENT	0
791960	791382	20134Y	PARTICIPANT	\N	PRESENT	0
791961	791382	14055N	PARTICIPANT	\N	PRESENT	0
791962	791382	21092L	PARTICIPANT	\N	PRESENT	0
791963	791382	19591F	PARTICIPANT	\N	PRESENT	0
791964	791382	20106U	PARTICIPANT	\N	PRESENT	0
791965	791382	19349W	PARTICIPANT	\N	PRESENT	0
791966	791382	21043B	PARTICIPANT	\N	PRESENT	0
791967	791382	14249W	PARTICIPANT	\N	PRESENT	0
791968	791382	19331L	PARTICIPANT	\N	PRESENT	0
791969	791382	19057M	PARTICIPANT	\N	PRESENT	0
791970	791382	19782L	PARTICIPANT	\N	PRESENT	0
791971	791382	14037X	PARTICIPANT	\N	PRESENT	0
791972	791382	04008A	PARTICIPANT	\N	PRESENT	0
791973	791382	19711U	PARTICIPANT	\N	PRESENT	0
791974	791382	18083K	PARTICIPANT	\N	PRESENT	0
791975	791382	20116W	PARTICIPANT	\N	PRESENT	0
791976	791382	14207L	PARTICIPANT	\N	PRESENT	0
791977	791382	21041Y	PARTICIPANT	\N	PRESENT	0
791978	791382	19621T	PARTICIPANT	\N	PRESENT	0
791979	791382	19719D	PARTICIPANT	\N	PRESENT	0
791980	791382	20132W	PARTICIPANT	\N	PRESENT	0
791981	791382	19367Y	PARTICIPANT	\N	PRESENT	0
791982	791382	21032X	PARTICIPANT	\N	PRESENT	0
791983	791382	08011M	PARTICIPANT	\N	PRESENT	0
791984	791382	21066J	PARTICIPANT	\N	PRESENT	0
791985	791382	20072C	PARTICIPANT	\N	PRESENT	0
791986	791382	21091K	PARTICIPANT	\N	PRESENT	0
791987	791382	04047H	PARTICIPANT	\N	PRESENT	0
791988	791382	08034U	PARTICIPANT	\N	PRESENT	0
791989	791382	14133K	PARTICIPANT	\N	PRESENT	0
791990	791382	21076L	PARTICIPANT	\N	PRESENT	0
791991	791382	11048N	PARTICIPANT	\N	PRESENT	0
791993	791382	20078J	PARTICIPANT	\N	PRESENT	0
791995	791382	19697Q	PARTICIPANT	\N	PRESENT	0
791996	791382	20074E	PARTICIPANT	\N	PRESENT	0
791997	791382	20122U	PARTICIPANT	\N	PRESENT	0
791998	791382	19585H	PARTICIPANT	\N	PRESENT	0
791999	791382	20076G	PARTICIPANT	\N	PRESENT	0
792000	791382	14259Y	PARTICIPANT	\N	PRESENT	0
792001	791382	14225N	PARTICIPANT	\N	PRESENT	0
792002	791382	14229S	PARTICIPANT	\N	PRESENT	0
792003	791382	14169X	PARTICIPANT	\N	PRESENT	0
792039	791382	19647E	PARTICIPANT	\N	PRESENT	0
792005	791382	21061D	PARTICIPANT	\N	PRESENT	0
792006	791382	20064C	PARTICIPANT	\N	PRESENT	0
792007	791382	19573D	PARTICIPANT	\N	PRESENT	0
792008	791382	10015M	PARTICIPANT	\N	PRESENT	0
792009	791382	21031W	PARTICIPANT	\N	PRESENT	0
792010	791382	08028W	PARTICIPANT	\N	PRESENT	0
792011	791382	19631V	PARTICIPANT	\N	PRESENT	0
792012	791382	21035B	PARTICIPANT	\N	PRESENT	0
792013	791382	04033B	PARTICIPANT	\N	PRESENT	0
792014	791382	20062A	PARTICIPANT	\N	PRESENT	0
792015	791382	08060W	PARTICIPANT	\N	PRESENT	0
792016	791382	20088L	PARTICIPANT	\N	PRESENT	0
792017	791382	05008E	PARTICIPANT	\N	PRESENT	0
792018	791382	20022R	PARTICIPANT	\N	PRESENT	0
792019	791382	21045D	PARTICIPANT	\N	PRESENT	0
792020	791382	21089R	PARTICIPANT	\N	PRESENT	0
792021	791382	14053L	PARTICIPANT	\N	PRESENT	0
792022	791382	19866P	PARTICIPANT	\N	PRESENT	0
792023	791382	19701S	PARTICIPANT	\N	PRESENT	0
792024	791382	21057H	PARTICIPANT	\N	PRESENT	0
792025	791382	20264J	PARTICIPANT	\N	PRESENT	0
792026	791382	14187A	PARTICIPANT	\N	PRESENT	0
792027	791382	19295A	PARTICIPANT	\N	PRESENT	0
792028	791382	11027H	PARTICIPANT	\N	PRESENT	0
792029	791382	14071N	PARTICIPANT	\N	PRESENT	0
792030	791382	20070A	PARTICIPANT	\N	PRESENT	0
792031	791382	18395Y	PARTICIPANT	\N	PRESENT	0
792037	791382	21062E	PARTICIPANT	\N	PRESENT	0
792038	791382	20044X	PARTICIPANT	\N	PRESENT	0
792040	791382	14237S	PARTICIPANT	\N	PRESENT	0
792041	791382	14281W	PARTICIPANT	\N	PRESENT	0
792042	791382	08045X	PARTICIPANT	\N	PRESENT	0
792043	791382	21072G	PARTICIPANT	\N	PRESENT	0
792044	791382	19820Y	PARTICIPANT	\N	PRESENT	0
792045	791382	19725B	PARTICIPANT	\N	PRESENT	0
792046	791382	21071F	PARTICIPANT	\N	PRESENT	0
792047	791382	21055F	PARTICIPANT	\N	PRESENT	0
792048	791382	21029D	PARTICIPANT	\N	PRESENT	0
792049	791382	14031R	PARTICIPANT	\N	PRESENT	0
792050	791382	19421M	PARTICIPANT	\N	PRESENT	0
792051	791382	14021P	PARTICIPANT	\N	PRESENT	0
792052	791382	08010L	PARTICIPANT	\N	PRESENT	0
779284	775554	18395Y	PARTICIPANT	\N	PRESENT	0
779285	775554	14033T	PARTICIPANT	\N	PRESENT	0
779286	775554	14189C	PARTICIPANT	\N	PRESENT	0
779289	779288	18395Y	PARTICIPANT	\N	PRESENT	0
779290	779288	14189C	PARTICIPANT	\N	PRESENT	0
779291	779288	14033T	PARTICIPANT	\N	PRESENT	0
779294	779278	14189C	PARTICIPANT	\N	PRESENT	0
779295	779278	18395Y	PARTICIPANT	\N	PRESENT	0
779360	779359	19611R	PARTICIPANT	\N	PRESENT	0
779361	779359	18395Y	PARTICIPANT	\N	PRESENT	0
779362	779359	20058E	PARTICIPANT	\N	PRESENT	0
779803	776565	14249W	PARTICIPANT	\N	PRESENT	0
779804	776565	21090J	PARTICIPANT	\N	PRESENT	0
779805	776565	14030Q	PARTICIPANT	\N	PRESENT	0
779806	776565	19563B	PARTICIPANT	\N	PRESENT	0
779807	776565	04042C	PARTICIPANT	\N	PRESENT	0
779808	776565	19701S	PARTICIPANT	\N	PRESENT	0
779809	776565	21083K	PARTICIPANT	\N	PRESENT	0
779810	776565	21030V	PARTICIPANT	\N	PRESENT	0
779811	776565	19782L	PARTICIPANT	\N	PRESENT	0
779812	776565	99004R	PARTICIPANT	\N	PRESENT	0
779813	776565	21093M	PARTICIPANT	\N	PRESENT	0
779816	776565	20040T	PARTICIPANT	\N	PRESENT	0
779825	776565	20082E	PARTICIPANT	\N	PRESENT	0
779826	776565	21086N	PARTICIPANT	\N	PRESENT	0
779827	776565	20062A	PARTICIPANT	\N	PRESENT	0
779828	776565	14275Y	PARTICIPANT	\N	PRESENT	0
779829	776565	14187A	PARTICIPANT	\N	PRESENT	0
779830	776565	20030R	PARTICIPANT	\N	PRESENT	0
779831	776565	21029D	PARTICIPANT	\N	PRESENT	0
779832	776565	14257W	PARTICIPANT	\N	PRESENT	0
779833	776565	21034A	PARTICIPANT	\N	PRESENT	0
779834	776565	20054A	PARTICIPANT	\N	PRESENT	0
779835	776565	20132W	PARTICIPANT	\N	PRESENT	0
779836	776565	20084G	PARTICIPANT	\N	PRESENT	0
779883	776566	12016W	PARTICIPANT	\N	PRESENT	0
779884	776566	19507S	PARTICIPANT	\N	PRESENT	0
779885	776566	19347U	PARTICIPANT	\N	PRESENT	0
779886	776566	21093M	PARTICIPANT	\N	PRESENT	0
779887	776566	20092G	PARTICIPANT	\N	PRESENT	0
779910	776566	08010L	PARTICIPANT	\N	PRESENT	0
779889	776566	20070A	PARTICIPANT	\N	PRESENT	0
779890	776566	20084G	PARTICIPANT	\N	PRESENT	0
779891	776566	20030R	PARTICIPANT	\N	PRESENT	0
779892	776566	20082E	PARTICIPANT	\N	PRESENT	0
779893	776566	19647E	PARTICIPANT	\N	PRESENT	0
779894	776566	14207L	PARTICIPANT	\N	PRESENT	0
779895	776566	21054E	PARTICIPANT	\N	PRESENT	0
779896	776566	21041Y	PARTICIPANT	\N	PRESENT	0
779897	776566	20132W	PARTICIPANT	\N	PRESENT	0
779898	776566	14083S	PARTICIPANT	\N	PRESENT	0
779899	776566	20040T	PARTICIPANT	\N	PRESENT	0
779900	776566	21083K	PARTICIPANT	\N	PRESENT	0
779901	776566	21090J	PARTICIPANT	\N	PRESENT	0
779902	776566	19563B	PARTICIPANT	\N	PRESENT	0
779903	776566	17737W	PARTICIPANT	\N	PRESENT	0
779904	776566	21029D	PARTICIPANT	\N	PRESENT	0
779905	776566	20076G	PARTICIPANT	\N	PRESENT	0
779906	776566	14275Y	PARTICIPANT	\N	PRESENT	0
779907	776566	20034V	PARTICIPANT	\N	PRESENT	0
779908	776566	21086N	PARTICIPANT	\N	PRESENT	0
779909	776566	14187A	PARTICIPANT	\N	PRESENT	0
779911	776566	20062A	PARTICIPANT	\N	PRESENT	0
779912	776566	14249W	PARTICIPANT	\N	PRESENT	0
779913	776566	21034A	PARTICIPANT	\N	PRESENT	0
779914	776566	14225N	PARTICIPANT	\N	PRESENT	0
779915	776566	19782L	PARTICIPANT	\N	PRESENT	0
779916	776566	14257W	PARTICIPANT	\N	PRESENT	0
779917	776566	20054A	PARTICIPANT	\N	PRESENT	0
779918	776566	14357A	PARTICIPANT	\N	PRESENT	0
779919	776566	19695N	PARTICIPANT	\N	PRESENT	0
779920	776566	19701S	PARTICIPANT	\N	PRESENT	0
779921	776566	21085M	PARTICIPANT	\N	PRESENT	0
779922	776566	19565D	PARTICIPANT	\N	PRESENT	0
779923	776566	21097R	PARTICIPANT	\N	PRESENT	0
779924	776566	11048N	PARTICIPANT	\N	PRESENT	0
779925	776566	21030V	PARTICIPANT	\N	PRESENT	0
779960	776567	19295A	PARTICIPANT	\N	PRESENT	0
779927	776567	20126Y	PARTICIPANT	\N	PRESENT	0
779881	776566	11090Q	PARTICIPANT	\N	PRESENT	0
779882	776566	20126Y	PARTICIPANT	\N	PRESENT	0
779928	776567	12016W	PARTICIPANT	\N	PRESENT	0
779929	776567	19507S	PARTICIPANT	\N	PRESENT	0
779930	776567	19347U	PARTICIPANT	\N	PRESENT	0
779931	776567	21093M	PARTICIPANT	\N	PRESENT	0
779932	776567	20092G	PARTICIPANT	\N	PRESENT	0
779933	776567	20084G	PARTICIPANT	\N	PRESENT	0
779934	776567	20030R	PARTICIPANT	\N	PRESENT	0
779935	776567	20082E	PARTICIPANT	\N	PRESENT	0
779936	776567	14207L	PARTICIPANT	\N	PRESENT	0
779937	776567	21054E	PARTICIPANT	\N	PRESENT	0
779961	776567	11090Q	PARTICIPANT	\N	PRESENT	0
779962	776567	08069G	PARTICIPANT	\N	PRESENT	0
779940	776567	19563B	PARTICIPANT	\N	PRESENT	0
779963	776567	14275Y	PARTICIPANT	\N	PRESENT	0
779942	776567	20076G	PARTICIPANT	\N	PRESENT	0
779964	776567	19531S	PARTICIPANT	\N	PRESENT	0
779965	776567	21090J	PARTICIPANT	\N	PRESENT	0
779945	776567	14187A	PARTICIPANT	\N	PRESENT	0
779966	776567	08010L	PARTICIPANT	\N	PRESENT	0
779967	776567	20062A	PARTICIPANT	\N	PRESENT	0
779948	776567	21034A	PARTICIPANT	\N	PRESENT	0
779949	776567	19782L	PARTICIPANT	\N	PRESENT	0
779950	776567	14257W	PARTICIPANT	\N	PRESENT	0
779951	776567	20054A	PARTICIPANT	\N	PRESENT	0
779952	776567	14357A	PARTICIPANT	\N	PRESENT	0
779968	776567	21029D	PARTICIPANT	\N	PRESENT	0
779954	776567	19701S	PARTICIPANT	\N	PRESENT	0
779955	776567	19565D	PARTICIPANT	\N	PRESENT	0
779956	776567	21097R	PARTICIPANT	\N	PRESENT	0
779969	776567	19657G	PARTICIPANT	\N	PRESENT	0
779958	776567	19593H	PARTICIPANT	\N	PRESENT	0
779959	776567	20016T	PARTICIPANT	\N	PRESENT	0
779970	776567	20034V	PARTICIPANT	\N	PRESENT	0
779971	776567	19711U	PARTICIPANT	\N	PRESENT	0
779972	776567	20040T	PARTICIPANT	\N	PRESENT	0
779973	776567	20148F	PARTICIPANT	\N	PRESENT	0
780015	779263	20126Y	PARTICIPANT	\N	PRESENT	0
779975	779263	12016W	PARTICIPANT	\N	PRESENT	0
780013	779263	19701S	PARTICIPANT	\N	PRESENT	0
779977	779263	19347U	PARTICIPANT	\N	PRESENT	0
779978	779263	21093M	PARTICIPANT	\N	PRESENT	0
780014	779263	14225N	PARTICIPANT	\N	PRESENT	0
780016	779263	20092G	PARTICIPANT	\N	PRESENT	0
780281	780280	19691J	PARTICIPANT	\N	PRESENT	0
780282	780280	19703U	PARTICIPANT	\N	PRESENT	0
779983	779263	14207L	PARTICIPANT	\N	PRESENT	0
779984	779263	21054E	PARTICIPANT	\N	PRESENT	0
780283	780280	20130U	PARTICIPANT	\N	PRESENT	0
780284	780280	14217N	PARTICIPANT	\N	PRESENT	0
779987	779263	14187A	PARTICIPANT	\N	PRESENT	0
779988	779263	21034A	PARTICIPANT	\N	PRESENT	0
779989	779263	19782L	PARTICIPANT	\N	PRESENT	0
780285	780280	14281W	PARTICIPANT	\N	PRESENT	0
779991	779263	20054A	PARTICIPANT	\N	PRESENT	0
779992	779263	14357A	PARTICIPANT	\N	PRESENT	0
780286	780280	21064G	PARTICIPANT	\N	PRESENT	0
780288	780280	14071N	PARTICIPANT	\N	PRESENT	0
779995	779263	21097R	PARTICIPANT	\N	PRESENT	0
779996	779263	19593H	PARTICIPANT	\N	PRESENT	0
779997	779263	20016T	PARTICIPANT	\N	PRESENT	0
779998	779263	19295A	PARTICIPANT	\N	PRESENT	0
779999	779263	11090Q	PARTICIPANT	\N	PRESENT	0
780290	780289	14217N	PARTICIPANT	\N	PRESENT	0
780291	780289	19691J	PARTICIPANT	\N	PRESENT	0
780292	780289	14281W	PARTICIPANT	\N	PRESENT	0
780003	779263	21090J	PARTICIPANT	\N	PRESENT	0
780293	780289	20130U	PARTICIPANT	\N	PRESENT	0
780005	779263	20062A	PARTICIPANT	\N	PRESENT	0
780006	779263	21029D	PARTICIPANT	\N	PRESENT	0
780007	779263	19657G	PARTICIPANT	\N	PRESENT	0
780008	779263	20034V	PARTICIPANT	\N	PRESENT	0
780009	779263	19711U	PARTICIPANT	\N	PRESENT	0
780294	780289	19703U	PARTICIPANT	\N	PRESENT	0
780011	779263	20148F	PARTICIPANT	\N	PRESENT	0
780012	779263	20150Y	PARTICIPANT	\N	PRESENT	0
780301	780295	14071N	PARTICIPANT	\N	PRESENT	0
780299	780295	14281W	PARTICIPANT	\N	PRESENT	0
780300	780295	19691J	PARTICIPANT	\N	PRESENT	0
780302	780295	20130U	PARTICIPANT	\N	PRESENT	0
780303	780295	19703U	PARTICIPANT	\N	PRESENT	0
793913	791392	19251M	PARTICIPANT	\N	PRESENT	0
793914	791392	14151M	PARTICIPANT	\N	PRESENT	0
793915	791392	11053K	PARTICIPANT	\N	PRESENT	0
793916	791392	21062E	PARTICIPANT	\N	PRESENT	0
793917	791392	19647E	PARTICIPANT	\N	PRESENT	0
793918	791392	19820Y	PARTICIPANT	\N	PRESENT	0
793919	791392	19531S	PARTICIPANT	\N	PRESENT	0
793920	791392	19683J	PARTICIPANT	\N	PRESENT	0
793921	791392	14030Q	PARTICIPANT	\N	PRESENT	0
793922	791392	21050A	PARTICIPANT	\N	PRESENT	0
793923	791392	14021P	PARTICIPANT	\N	PRESENT	0
793924	791392	19649G	PARTICIPANT	\N	PRESENT	0
793925	791392	18207D	PARTICIPANT	\N	PRESENT	0
793926	791392	08012N	PARTICIPANT	\N	PRESENT	0
793927	791392	14267Y	PARTICIPANT	\N	PRESENT	0
793928	791392	12016W	PARTICIPANT	\N	PRESENT	0
793929	791392	14001X	PARTICIPANT	\N	PRESENT	0
793930	791392	19057M	PARTICIPANT	\N	PRESENT	0
793931	791392	20018V	PARTICIPANT	\N	PRESENT	0
793932	791392	14257W	PARTICIPANT	\N	PRESENT	0
793933	791392	17779H	PARTICIPANT	\N	PRESENT	0
793934	791392	14073Q	PARTICIPANT	\N	PRESENT	0
793935	791392	21056G	PARTICIPANT	\N	PRESENT	0
793936	791392	19735D	PARTICIPANT	\N	PRESENT	0
793937	791392	17965H	PARTICIPANT	\N	PRESENT	0
793938	791392	20030R	PARTICIPANT	\N	PRESENT	0
793965	791392	21073H	PARTICIPANT	\N	PRESENT	0
793940	791392	20082E	PARTICIPANT	\N	PRESENT	0
793941	791392	14229S	PARTICIPANT	\N	PRESENT	0
793942	791392	14205J	PARTICIPANT	\N	PRESENT	0
793943	791392	19669L	PARTICIPANT	\N	PRESENT	0
793944	791392	19413M	PARTICIPANT	\N	PRESENT	0
793945	791392	21051B	PARTICIPANT	\N	PRESENT	0
793946	791392	20064C	PARTICIPANT	\N	PRESENT	0
793947	791392	21082J	PARTICIPANT	\N	PRESENT	0
793948	791392	21077M	PARTICIPANT	\N	PRESENT	0
793949	791392	20144B	PARTICIPANT	\N	PRESENT	0
793950	791392	14327T	PARTICIPANT	\N	PRESENT	0
793951	791392	17229F	PARTICIPANT	\N	PRESENT	0
793952	791392	14255U	PARTICIPANT	\N	PRESENT	0
793953	791392	15197G	PARTICIPANT	\N	PRESENT	0
793954	791392	14042U	PARTICIPANT	\N	PRESENT	0
793955	791392	20046A	PARTICIPANT	\N	PRESENT	0
793956	791392	20102Q	PARTICIPANT	\N	PRESENT	0
793957	791392	11056N	PARTICIPANT	\N	PRESENT	0
793958	791392	07004J	PARTICIPANT	\N	PRESENT	0
793959	791392	14231L	PARTICIPANT	\N	PRESENT	0
793960	791392	20286Q	PARTICIPANT	\N	PRESENT	0
793961	791392	21086N	PARTICIPANT	\N	PRESENT	0
793962	791392	19691J	PARTICIPANT	\N	PRESENT	0
793963	791392	20066E	PARTICIPANT	\N	PRESENT	0
793964	791392	20052X	PARTICIPANT	\N	PRESENT	0
793966	791392	17023S	PARTICIPANT	\N	PRESENT	0
793967	791392	14219Q	PARTICIPANT	\N	PRESENT	0
793968	791392	11085T	PARTICIPANT	\N	PRESENT	0
793969	791392	08009T	PARTICIPANT	\N	PRESENT	0
793970	791392	19826F	PARTICIPANT	\N	PRESENT	0
793971	791392	19335Q	PARTICIPANT	\N	PRESENT	0
793972	791392	04070G	PARTICIPANT	\N	PRESENT	0
793973	791392	19745F	PARTICIPANT	\N	PRESENT	0
793974	791392	21053D	PARTICIPANT	\N	PRESENT	0
793975	791392	21038E	PARTICIPANT	\N	PRESENT	0
793976	791392	19713W	PARTICIPANT	\N	PRESENT	0
793977	791392	19479G	PARTICIPANT	\N	PRESENT	0
793978	791392	01034P	PARTICIPANT	\N	PRESENT	0
793979	791392	21042A	PARTICIPANT	\N	PRESENT	0
793980	791392	14089Y	PARTICIPANT	\N	PRESENT	0
793981	791392	20042V	PARTICIPANT	\N	PRESENT	0
793982	791392	21083K	PARTICIPANT	\N	PRESENT	0
793983	791392	95041E	PARTICIPANT	\N	PRESENT	0
793984	791392	19111A	PARTICIPANT	\N	PRESENT	0
793985	791392	19709B	PARTICIPANT	\N	PRESENT	0
793986	791392	20020P	PARTICIPANT	\N	PRESENT	0
793987	791392	21047F	PARTICIPANT	\N	PRESENT	0
793988	791392	20076G	PARTICIPANT	\N	PRESENT	0
793991	793691	20286Q	PARTICIPANT	\N	EXCUSE	0
793992	791392	19701S	PARTICIPANT	\N	PRESENT	0
793993	791392	19331L	PARTICIPANT	\N	PRESENT	0
793994	791392	20106U	PARTICIPANT	\N	PRESENT	0
793995	793691	20082E	PARTICIPANT	\N	EXCUSE	0
793998	791392	19673G	PARTICIPANT	\N	PRESENT	0
793999	791392	19685L	PARTICIPANT	\N	PRESENT	0
794001	791392	21032X	PARTICIPANT	\N	PRESENT	0
794004	791392	11070L	PARTICIPANT	\N	PRESENT	0
794005	791392	20068G	PARTICIPANT	\N	PRESENT	0
794006	791392	21030V	PARTICIPANT	\N	PRESENT	0
794008	791392	19563B	PARTICIPANT	\N	PRESENT	0
794011	793691	21041Y	PARTICIPANT	\N	EXCUSE	0
794057	791392	20266L	PARTICIPANT	\N	PRESENT	0
794061	791392	19551W	PARTICIPANT	\N	PRESENT	0
794063	793691	20106U	PARTICIPANT	\N	EXCUSE	0
794064	793691	21093M	PARTICIPANT	\N	EXCUSE	0
794065	793691	21063F	PARTICIPANT	\N	EXCUSE	0
794066	793370	14073Q	PARTICIPANT	\N	PRESENT	0
794071	794070	14257W	PRESIDENT	0	PRESENT	0
794072	794070	11070L	PARTICIPANT	\N	PRESENT	0
794074	794070	19619A	PARTICIPANT	\N	PRESENT	0
794076	793691	20060X	PARTICIPANT	\N	EXCUSE	0
794077	794070	20068G	PARTICIPANT	\N	PRESENT	0
794079	794070	20042V	PARTICIPANT	\N	PRESENT	0
794080	794070	12016W	PARTICIPANT	\N	PRESENT	0
794082	794070	19575F	PARTICIPANT	\N	PRESENT	0
794083	794070	20092G	PARTICIPANT	\N	PRESENT	0
794369	791394	14259Y	PARTICIPANT	\N	PRESENT	0
794370	791394	19691J	PARTICIPANT	\N	PRESENT	0
794371	791394	21097R	PARTICIPANT	\N	PRESENT	0
794372	791394	17779H	PARTICIPANT	\N	PRESENT	0
794373	791394	18193Q	PARTICIPANT	\N	PRESENT	0
794374	791394	21070E	PARTICIPANT	\N	PRESENT	0
794376	791394	14195A	PARTICIPANT	\N	PRESENT	0
794377	794070	20120S	PARTICIPANT	\N	PRESENT	0
794378	794070	21033Y	PARTICIPANT	\N	PRESENT	0
794379	791394	21087P	PARTICIPANT	\N	PRESENT	0
794380	791394	19553Y	PARTICIPANT	\N	PRESENT	0
794381	791394	19758L	PARTICIPANT	\N	PRESENT	0
794382	791394	19703U	PARTICIPANT	\N	PRESENT	0
794383	791394	14071N	PARTICIPANT	\N	PRESENT	0
794384	791394	14073Q	PARTICIPANT	\N	PRESENT	0
794385	791394	19866P	PARTICIPANT	\N	PRESENT	0
794386	791394	21094N	PARTICIPANT	\N	PRESENT	0
794387	791394	01034P	PARTICIPANT	\N	PRESENT	0
794388	791394	21042A	PARTICIPANT	\N	PRESENT	0
794389	791394	21085M	PARTICIPANT	\N	PRESENT	0
794390	791394	19713W	PARTICIPANT	\N	PRESENT	0
794391	791394	21064G	PARTICIPANT	\N	PRESENT	0
794392	791394	19745F	PARTICIPANT	\N	PRESENT	0
794393	791394	20062A	PARTICIPANT	\N	PRESENT	0
794394	791394	19679N	PARTICIPANT	\N	PRESENT	0
794395	791394	20096L	PARTICIPANT	\N	PRESENT	0
794396	791394	14069U	PARTICIPANT	\N	PRESENT	0
794397	791394	17367Q	PARTICIPANT	\N	PRESENT	0
794398	791394	21072G	PARTICIPANT	\N	PRESENT	0
794399	791394	14215L	PARTICIPANT	\N	PRESENT	0
794400	791394	20098N	PARTICIPANT	\N	PRESENT	0
794401	791394	19798U	PARTICIPANT	\N	PRESENT	0
794402	791394	14030Q	PARTICIPANT	\N	PRESENT	0
794403	791394	14042U	PARTICIPANT	\N	PRESENT	0
794404	791394	21090J	PARTICIPANT	\N	PRESENT	0
794405	791394	14281W	PARTICIPANT	\N	PRESENT	0
794406	791394	08045X	PARTICIPANT	\N	PRESENT	0
794407	791394	21046E	PARTICIPANT	\N	PRESENT	0
794409	791394	14213J	PARTICIPANT	\N	PRESENT	0
794410	791394	14217N	PARTICIPANT	\N	PRESENT	0
794411	791394	20136B	PARTICIPANT	\N	PRESENT	0
794412	791394	20022R	PARTICIPANT	\N	PRESENT	0
794413	791394	19657G	PARTICIPANT	\N	PRESENT	0
794414	791394	19347U	PARTICIPANT	\N	PRESENT	0
794415	791394	19569H	PARTICIPANT	\N	PRESENT	0
794416	791394	21049H	PARTICIPANT	\N	PRESENT	0
794417	791394	19782L	PARTICIPANT	\N	PRESENT	0
794418	794070	14031R	PARTICIPANT	\N	PRESENT	0
794419	791394	21056G	PARTICIPANT	\N	PRESENT	0
794420	791394	19295A	PARTICIPANT	\N	PRESENT	0
794421	791394	20038A	PARTICIPANT	\N	PRESENT	0
794422	791394	19673G	PARTICIPANT	\N	PRESENT	0
794423	794070	14033T	PARTICIPANT	\N	PRESENT	0
794424	791394	19735D	PARTICIPANT	\N	PRESENT	0
794425	794070	20018V	PARTICIPANT	\N	PRESENT	0
794426	791394	20026V	PARTICIPANT	\N	PRESENT	0
794427	791394	20032T	PARTICIPANT	\N	PRESENT	0
794428	791394	14038Y	PARTICIPANT	\N	PRESENT	0
773238	772198	12028B	PARTICIPANT	\N	EXCUSE	0
773314	772197	17367Q	PARTICIPANT	\N	PRESENT	0
773315	772197	14151M	PRESIDENT	0	PRESENT	0
773316	772197	15197G	PARTICIPANT	\N	PRESENT	0
773317	772197	99004R	PARTICIPANT	\N	PRESENT	0
773318	772197	20146D	PARTICIPANT	\N	PRESENT	0
773319	772197	20252E	PARTICIPANT	\N	PRESENT	0
773320	772197	14255U	PARTICIPANT	\N	PRESENT	0
773321	772197	21072G	PARTICIPANT	\N	PRESENT	0
773322	772197	19295A	PARTICIPANT	\N	PRESENT	0
773324	772197	18395Y	PARTICIPANT	\N	PRESENT	0
773461	772197	21088Q	PARTICIPANT	\N	EXCUSE	0
773820	772441	17229F	PARTICIPANT	\N	EXCUSE	0
777398	776547	19798U	PARTICIPANT	\N	PRESENT	0
777399	776547	19691J	PARTICIPANT	\N	PRESENT	0
777400	776547	20136B	PARTICIPANT	\N	PRESENT	0
777401	776547	21092L	PARTICIPANT	\N	PRESENT	0
777402	776547	14133K	PARTICIPANT	\N	PRESENT	0
777403	776547	20266L	PARTICIPANT	\N	PRESENT	0
777404	776547	21078N	PARTICIPANT	\N	PRESENT	0
777405	776547	14173T	PARTICIPANT	\N	PRESENT	0
777406	776547	08034U	PARTICIPANT	\N	PRESENT	0
777407	776547	20098N	PARTICIPANT	\N	PRESENT	0
777408	776547	20108W	PARTICIPANT	\N	PRESENT	0
777409	776547	20066E	PARTICIPANT	\N	PRESENT	0
777410	776547	19719D	PARTICIPANT	\N	PRESENT	0
777411	776547	19533U	PARTICIPANT	\N	PRESENT	0
777412	776547	14205J	PARTICIPANT	\N	PRESENT	0
777413	776547	20106U	PARTICIPANT	\N	PRESENT	0
777414	776547	11056N	PARTICIPANT	\N	PRESENT	0
777415	776547	20070A	PARTICIPANT	\N	PRESENT	0
777416	776547	20054A	PARTICIPANT	\N	PRESENT	0
777417	776547	14053L	PARTICIPANT	\N	PRESENT	0
777418	776547	21073H	PARTICIPANT	\N	PRESENT	0
777419	776547	21085M	PARTICIPANT	\N	PRESENT	0
777420	776547	21069M	PARTICIPANT	\N	PRESENT	0
777421	776547	20082E	PARTICIPANT	\N	PRESENT	0
777422	776547	19826F	PARTICIPANT	\N	PRESENT	0
777423	776547	20084G	PARTICIPANT	\N	PRESENT	0
777424	776547	19699S	PARTICIPANT	\N	PRESENT	0
777425	776547	14215L	PARTICIPANT	\N	PRESENT	0
777426	776547	08045X	PARTICIPANT	\N	PRESENT	0
777429	776547	14042U	PARTICIPANT	\N	PRESENT	0
777430	776547	11070L	PARTICIPANT	\N	PRESENT	0
777431	776547	19563B	PARTICIPANT	\N	PRESENT	0
777434	776547	14083S	PARTICIPANT	\N	PRESENT	0
777435	776547	21083K	PARTICIPANT	\N	PRESENT	0
777436	776547	19553Y	PARTICIPANT	\N	PRESENT	0
777437	776547	19575F	PARTICIPANT	\N	PRESENT	0
777438	776547	20102Q	PARTICIPANT	\N	PRESENT	0
777441	776547	21054E	PARTICIPANT	\N	PRESENT	0
777446	776547	20062A	PARTICIPANT	\N	PRESENT	0
777447	776547	20030R	PARTICIPANT	\N	PRESENT	0
777448	776547	20134Y	PARTICIPANT	\N	PRESENT	0
777449	776547	19569H	PARTICIPANT	\N	PRESENT	0
777450	776547	20018V	PARTICIPANT	\N	PRESENT	0
777451	776547	19551W	PARTICIPANT	\N	PRESENT	0
777452	776547	04045F	PARTICIPANT	\N	PRESENT	0
777453	776547	21081H	PARTICIPANT	\N	PRESENT	0
777551	776548	19723Y	PARTICIPANT	\N	PRESENT	0
777552	776548	19713W	PARTICIPANT	\N	PRESENT	0
777553	776548	21094N	PARTICIPANT	\N	PRESENT	0
777554	776548	19758L	PARTICIPANT	\N	PRESENT	0
777555	776548	19553Y	PARTICIPANT	\N	PRESENT	0
777556	776548	19301E	PARTICIPANT	\N	PRESENT	0
777557	776548	19683J	PARTICIPANT	\N	PRESENT	0
777558	776548	14071N	PARTICIPANT	\N	PRESENT	0
777559	776548	21085M	PARTICIPANT	\N	PRESENT	0
777560	776548	21046E	PARTICIPANT	\N	PRESENT	0
777561	776548	19545Y	PARTICIPANT	\N	PRESENT	0
777562	776548	21054E	PARTICIPANT	\N	PRESENT	0
777563	776548	21070E	PARTICIPANT	\N	PRESENT	0
777564	776548	20286Q	PARTICIPANT	\N	PRESENT	0
777565	776548	19691J	PARTICIPANT	\N	PRESENT	0
777566	776548	19735D	PARTICIPANT	\N	PRESENT	0
777567	776548	14205J	PARTICIPANT	\N	PRESENT	0
777568	776548	14083S	PARTICIPANT	\N	PRESENT	0
777569	776548	21069M	PARTICIPANT	\N	PRESENT	0
777570	776548	20054A	PARTICIPANT	\N	PRESENT	0
777571	776548	19383Y	PARTICIPANT	\N	PRESENT	0
777572	776548	14217N	PARTICIPANT	\N	PRESENT	0
777573	776548	20090E	PARTICIPANT	\N	PRESENT	0
777574	776548	14331P	PARTICIPANT	\N	PRESENT	0
777575	776548	20032T	PARTICIPANT	\N	PRESENT	0
777576	776548	20266L	PARTICIPANT	\N	PRESENT	0
777577	776548	21079P	PARTICIPANT	\N	PRESENT	0
777578	776548	21045D	PARTICIPANT	\N	PRESENT	0
777579	776548	18083K	PARTICIPANT	\N	PRESENT	0
777580	776548	20024T	PARTICIPANT	\N	PRESENT	0
777581	776548	07029T	PARTICIPANT	\N	PRESENT	0
777582	776548	19551W	PARTICIPANT	\N	PRESENT	0
777583	776548	20082E	PARTICIPANT	\N	PRESENT	0
777584	776548	14121F	PARTICIPANT	\N	PRESENT	0
777585	776548	20084G	PARTICIPANT	\N	PRESENT	0
777586	776548	11040E	PARTICIPANT	\N	PRESENT	0
777587	776548	20076G	PARTICIPANT	\N	PRESENT	0
777588	776548	20026V	PARTICIPANT	\N	PRESENT	0
777589	776548	20056C	PARTICIPANT	\N	PRESENT	0
777590	776548	19399H	PARTICIPANT	\N	PRESENT	0
777591	776548	21081H	PARTICIPANT	\N	PRESENT	0
777592	776548	04092N	PARTICIPANT	\N	PRESENT	0
777593	776548	20134Y	PARTICIPANT	\N	PRESENT	0
777594	776548	20130U	PARTICIPANT	\N	PRESENT	0
777595	776548	21063F	PARTICIPANT	\N	PRESENT	0
777596	776548	14173T	PARTICIPANT	\N	PRESENT	0
777597	776548	14038Y	PARTICIPANT	\N	PRESENT	0
777598	776548	19507S	PARTICIPANT	\N	PRESENT	0
777599	776548	14042U	PARTICIPANT	\N	PRESENT	0
777600	776548	04045F	PARTICIPANT	\N	PRESENT	0
777601	776548	21097R	PARTICIPANT	\N	PRESENT	0
777602	776548	98022P	PARTICIPANT	\N	PRESENT	0
777603	776548	14133K	PARTICIPANT	\N	PRESENT	0
777604	776548	21049H	PARTICIPANT	\N	PRESENT	0
777605	776548	14189C	PARTICIPANT	\N	PRESENT	0
777606	776548	14030Q	PARTICIPANT	\N	PRESENT	0
777607	776548	19479G	PARTICIPANT	\N	PRESENT	0
777608	776548	14215L	PARTICIPANT	\N	PRESENT	0
777609	776548	19631V	PARTICIPANT	\N	PRESENT	0
777610	776548	08045X	PARTICIPANT	\N	PRESENT	0
777611	776548	18193Q	PARTICIPANT	\N	PRESENT	0
777612	776548	17965H	PARTICIPANT	\N	PRESENT	0
777613	776548	20028X	PARTICIPANT	\N	PRESENT	0
777614	776548	19591F	PARTICIPANT	\N	PRESENT	0
777615	776548	20248J	PARTICIPANT	\N	PRESENT	0
777616	776548	17779H	PARTICIPANT	\N	PRESENT	0
777617	776548	14213J	PARTICIPANT	\N	PRESENT	0
777620	776548	20038A	PARTICIPANT	\N	PRESENT	0
777621	776548	14223L	PARTICIPANT	\N	PRESENT	0
777625	776548	01034P	PARTICIPANT	\N	PRESENT	0
777637	775971	21044C	PARTICIPANT	\N	PRESENT	0
777638	775971	19729F	PARTICIPANT	\N	PRESENT	0
777639	775971	14147R	PARTICIPANT	\N	PRESENT	0
777640	775971	14215L	PARTICIPANT	\N	PRESENT	0
777641	775971	20022R	PARTICIPANT	\N	PRESENT	0
777642	775971	19673G	PARTICIPANT	\N	PRESENT	0
777643	776548	19798U	PARTICIPANT	\N	PRESENT	0
777644	775971	21076L	PARTICIPANT	\N	PRESENT	0
777645	775971	04047H	PRESIDENT	0	PRESENT	0
777646	775971	14231L	PARTICIPANT	\N	PRESENT	0
777647	773849	19593H	PARTICIPANT	\N	PRESENT	0
777648	773849	20132W	PARTICIPANT	\N	PRESENT	0
777649	773849	19697Q	PARTICIPANT	\N	PRESENT	0
777650	773849	20138D	PARTICIPANT	\N	PRESENT	0
777651	773849	19611R	PARTICIPANT	\N	PRESENT	0
777652	773849	20142Y	PARTICIPANT	\N	PRESENT	0
777653	773849	19693L	PARTICIPANT	\N	PRESENT	0
777654	773849	20102Q	PARTICIPANT	\N	PRESENT	0
777655	773849	20056C	PARTICIPANT	\N	PRESENT	0
777656	773849	20264J	PARTICIPANT	\N	PRESENT	0
777657	773849	19735D	PARTICIPANT	\N	PRESENT	0
777549	776548	14259Y	PARTICIPANT	\N	PRESENT	0
777550	776548	11070L	PARTICIPANT	\N	PRESENT	0
777658	773849	14109K	PARTICIPANT	\N	PRESENT	0
777659	773849	14123H	PARTICIPANT	\N	PRESENT	0
777660	773849	20026V	PARTICIPANT	\N	PRESENT	0
777661	773849	19621T	PARTICIPANT	\N	PRESENT	0
777662	773849	21058J	PARTICIPANT	\N	PRESENT	0
777663	775971	14189C	PARTICIPANT	\N	PRESENT	0
777664	775971	04045F	PARTICIPANT	\N	PRESENT	0
777665	773849	19699S	PARTICIPANT	\N	PRESENT	0
777666	773849	21055F	PARTICIPANT	\N	PRESENT	0
792055	791382	17737W	PARTICIPANT	\N	PRESENT	0
792056	791382	08012N	PARTICIPANT	\N	PRESENT	0
792057	791382	20032T	PARTICIPANT	\N	PRESENT	0
792058	791382	17779H	PARTICIPANT	\N	PRESENT	0
792059	791382	20028X	PARTICIPANT	\N	PRESENT	0
792060	791382	20090E	PARTICIPANT	\N	PRESENT	0
792061	791382	20018V	PARTICIPANT	\N	PRESENT	0
792053	791382	19649G	PARTICIPANT	\N	PRESENT	0
792054	791382	18193Q	PARTICIPANT	\N	PRESENT	0
792062	791382	19533U	PARTICIPANT	\N	PRESENT	0
792063	791382	14257W	PARTICIPANT	\N	PRESENT	0
792064	791382	14069U	PARTICIPANT	\N	PRESENT	0
792065	791382	18231D	PARTICIPANT	\N	PRESENT	0
792066	791382	19798U	PARTICIPANT	\N	PRESENT	0
792067	791382	21060C	PARTICIPANT	\N	PRESENT	0
792068	791382	20030R	PARTICIPANT	\N	PRESENT	0
792069	791382	20120S	PARTICIPANT	\N	PRESENT	0
792070	791382	17965H	PARTICIPANT	\N	PRESENT	0
792071	791382	20082E	PARTICIPANT	\N	PRESENT	0
792072	791382	21095P	PARTICIPANT	\N	PRESENT	0
792073	791382	20084G	PARTICIPANT	\N	PRESENT	0
792074	791382	19669L	PARTICIPANT	\N	PRESENT	0
792075	791382	21090J	PARTICIPANT	\N	PRESENT	0
792076	791382	19413M	PARTICIPANT	\N	PRESENT	0
792077	791382	07033P	PARTICIPANT	\N	PRESENT	0
792078	791382	21051B	PARTICIPANT	\N	PRESENT	0
792079	791382	21082J	PARTICIPANT	\N	PRESENT	0
792080	791382	21077M	PARTICIPANT	\N	PRESENT	0
792081	791382	14147R	PARTICIPANT	\N	PRESENT	0
792082	791382	08047A	PARTICIPANT	\N	PRESENT	0
792083	791382	21081H	PARTICIPANT	\N	PRESENT	0
792084	791382	21042A	PARTICIPANT	\N	PRESENT	0
792085	791382	19954N	PARTICIPANT	\N	PRESENT	0
792086	791382	21050A	PARTICIPANT	\N	PRESENT	0
792087	791382	14255U	PARTICIPANT	\N	PRESENT	0
792088	791382	14026U	PARTICIPANT	\N	PRESENT	0
792089	791382	19721W	PARTICIPANT	\N	PRESENT	0
792090	791382	20026V	PARTICIPANT	\N	PRESENT	0
792091	791382	20096L	PARTICIPANT	\N	PRESENT	0
792092	791382	21068L	PARTICIPANT	\N	PRESENT	0
792093	791382	11070L	PARTICIPANT	\N	PRESENT	0
792094	791382	19447X	PARTICIPANT	\N	PRESENT	0
792095	791382	14038Y	PARTICIPANT	\N	PRESENT	0
792096	791382	19723Y	PARTICIPANT	\N	PRESENT	0
792097	791382	19691J	PARTICIPANT	\N	PRESENT	0
792098	791382	20180F	PARTICIPANT	\N	PRESENT	0
792099	791382	20034V	PARTICIPANT	\N	PRESENT	0
792104	791382	20052X	PARTICIPANT	\N	PRESENT	0
792101	791382	21039F	PARTICIPANT	\N	PRESENT	0
792102	791382	21040X	PARTICIPANT	\N	PRESENT	0
792103	791382	19699S	PARTICIPANT	\N	PRESENT	0
792105	791382	14033T	PARTICIPANT	\N	PRESENT	0
792106	791382	20056C	PARTICIPANT	\N	PRESENT	0
792107	791382	19826F	PARTICIPANT	\N	PRESENT	0
792108	791382	11090Q	PARTICIPANT	\N	PRESENT	0
792109	791382	19611R	PARTICIPANT	\N	PRESENT	0
792110	791382	20148F	PARTICIPANT	\N	PRESENT	0
792111	791382	20024T	PARTICIPANT	\N	PRESENT	0
792112	791382	21064G	PARTICIPANT	\N	PRESENT	0
792113	791382	19745F	PARTICIPANT	\N	PRESENT	0
792114	791382	14213J	PARTICIPANT	\N	PRESENT	0
792115	791382	19713W	PARTICIPANT	\N	PRESENT	0
792116	791382	14357A	PARTICIPANT	\N	PRESENT	0
792117	791382	19749K	PARTICIPANT	\N	PRESENT	0
792118	791382	19383Y	PARTICIPANT	\N	PRESENT	0
792119	791382	17023S	PARTICIPANT	\N	PRESENT	0
792120	791382	20086J	PARTICIPANT	\N	PRESENT	0
792121	791382	20054A	PARTICIPANT	\N	PRESENT	0
792122	791382	95041E	PARTICIPANT	\N	PRESENT	0
792123	791382	19709B	PARTICIPANT	\N	PRESENT	0
792124	791382	20020P	PARTICIPANT	\N	PRESENT	0
792125	791382	20126Y	PARTICIPANT	\N	PRESENT	0
792126	791382	20124W	PARTICIPANT	\N	PRESENT	0
792127	791382	08056B	PARTICIPANT	\N	PRESENT	0
792128	791382	19657G	PARTICIPANT	\N	PRESENT	0
792129	791382	19507S	PARTICIPANT	\N	PRESENT	0
792130	791382	14105F	PARTICIPANT	\N	PRESENT	0
792131	791382	21036C	PARTICIPANT	\N	PRESENT	0
792132	791382	19551W	PARTICIPANT	\N	PRESENT	0
792133	791382	19768N	PARTICIPANT	\N	PRESENT	0
792134	791382	08015R	PARTICIPANT	\N	PRESENT	0
792135	791382	19335Q	PARTICIPANT	\N	PRESENT	0
792136	791382	21047F	PARTICIPANT	\N	PRESENT	0
792137	791382	07029T	PARTICIPANT	\N	PRESENT	0
792138	791382	19703U	PARTICIPANT	\N	PRESENT	0
792139	791382	86034E	PARTICIPANT	\N	PRESENT	0
792140	791382	20140W	PARTICIPANT	\N	PRESENT	0
792141	791382	14217N	PARTICIPANT	\N	PRESENT	0
792142	791382	08018U	PARTICIPANT	\N	PRESENT	0
792143	791382	14329V	PARTICIPANT	\N	PRESENT	0
792144	791382	17367Q	PARTICIPANT	\N	PRESENT	0
792145	791382	20068G	PARTICIPANT	\N	PRESENT	0
792146	791382	21063F	PARTICIPANT	\N	PRESENT	0
792147	791382	04092N	PARTICIPANT	\N	PRESENT	0
792148	791382	20058E	PARTICIPANT	\N	PRESENT	0
792149	791382	20142Y	PARTICIPANT	\N	PRESENT	0
792150	791382	14251Q	PARTICIPANT	\N	PRESENT	0
792151	791382	21030V	PARTICIPANT	\N	PRESENT	0
792152	791382	21049H	PARTICIPANT	\N	PRESENT	0
792153	791382	19563B	PARTICIPANT	\N	PRESENT	0
792158	791382	20252E	PARTICIPANT	\N	PRESENT	0
792160	791382	14073Q	PARTICIPANT	\N	PRESENT	0
792156	791382	19489J	PARTICIPANT	\N	PRESENT	0
792157	791382	20172F	PARTICIPANT	\N	PRESENT	0
792159	791382	19758L	PARTICIPANT	\N	PRESENT	0
792164	791382	21069M	PARTICIPANT	\N	PRESENT	0
792162	791382	08069G	PARTICIPANT	\N	PRESENT	0
792163	791382	21075K	PARTICIPANT	\N	PRESENT	0
792165	791382	21085M	PARTICIPANT	\N	PRESENT	0
792166	791382	20100N	PARTICIPANT	\N	PRESENT	0
792167	791382	14221J	PARTICIPANT	\N	PRESENT	0
792175	791382	14253S	PARTICIPANT	\N	PRESENT	0
792169	791382	20048C	PARTICIPANT	\N	PRESENT	0
792171	791382	20118Y	PARTICIPANT	\N	PRESENT	0
792173	791382	20094J	PARTICIPANT	\N	PRESENT	0
792174	791382	05012A	PARTICIPANT	\N	PRESENT	0
792176	791382	21058J	PARTICIPANT	\N	PRESENT	0
792181	791382	20110Q	PARTICIPANT	\N	PRESENT	0
792182	791382	19673G	PARTICIPANT	\N	PRESENT	0
792183	791382	14059S	PARTICIPANT	\N	PRESENT	0
792185	792184	20286Q	PARTICIPANT	\N	PRESENT	0
792186	792184	14187A	PARTICIPANT	\N	PRESENT	0
792187	792184	19631V	PARTICIPANT	\N	PRESENT	0
792188	791382	21074J	PARTICIPANT	\N	PRESENT	0
792495	791846	14111D	PARTICIPANT	\N	PRESENT	0
792496	791846	21076L	PARTICIPANT	\N	PRESENT	0
792497	791846	14089Y	PARTICIPANT	\N	PRESENT	0
792498	791846	20110Q	PARTICIPANT	\N	PRESENT	0
792499	791846	21088Q	PARTICIPANT	\N	PRESENT	0
792500	791846	21040X	PARTICIPANT	\N	PRESENT	0
792501	791846	04045F	PARTICIPANT	\N	PRESENT	0
792502	791846	14151M	PARTICIPANT	\N	PRESENT	0
792503	791846	04008A	PARTICIPANT	\N	PRESENT	0
792505	792504	21082J	PARTICIPANT	\N	PRESENT	0
792506	792504	08060W	PARTICIPANT	\N	PRESENT	0
792507	791846	21091K	PARTICIPANT	\N	PRESENT	0
792508	791846	20090E	PARTICIPANT	\N	PRESENT	0
792509	791846	20078J	PARTICIPANT	\N	PRESENT	0
792510	791846	20074E	PARTICIPANT	\N	PRESENT	0
792511	791846	21075K	PARTICIPANT	\N	PRESENT	0
792512	791846	19565D	PARTICIPANT	\N	PRESENT	0
792513	791846	20102Q	PARTICIPANT	\N	PRESENT	0
792514	791846	11056N	PARTICIPANT	\N	PRESENT	0
792515	791846	19758L	PARTICIPANT	\N	PRESENT	0
792516	791846	20046A	PARTICIPANT	\N	PRESENT	0
792517	791846	21084L	PARTICIPANT	\N	PRESENT	0
792518	791846	11040E	PARTICIPANT	\N	PRESENT	0
792519	791846	19760E	PARTICIPANT	\N	PRESENT	0
792520	791846	19347U	PARTICIPANT	\N	PRESENT	0
792521	791846	20100N	PARTICIPANT	\N	PRESENT	0
792522	791846	20092G	PARTICIPANT	\N	PRESENT	0
792523	791846	20134Y	PARTICIPANT	\N	PRESENT	0
792524	791846	19697Q	PARTICIPANT	\N	PRESENT	0
792525	791846	21043B	PARTICIPANT	\N	PRESENT	0
792526	791846	19331L	PARTICIPANT	\N	PRESENT	0
792527	791846	21097R	PARTICIPANT	\N	PRESENT	0
792528	791846	21096Q	PARTICIPANT	\N	PRESENT	0
792529	791846	14195A	PARTICIPANT	\N	PRESENT	0
792530	791846	14251Q	PARTICIPANT	\N	PRESENT	0
792531	791846	21046E	PARTICIPANT	\N	PRESENT	0
792532	791846	20050V	PARTICIPANT	\N	PRESENT	0
769949	769948	19709B	PARTICIPANT	\N	PRESENT	0
769950	769948	19347U	PARTICIPANT	\N	PRESENT	0
769952	769951	19709B	PARTICIPANT	\N	PRESENT	0
769964	769963	19347U	PARTICIPANT	\N	PRESENT	0
769965	769963	19709B	PARTICIPANT	\N	PRESENT	0
769969	769968	19347U	PARTICIPANT	\N	PRESENT	0
769970	769968	19709B	PARTICIPANT	\N	PRESENT	0
769972	769971	21067K	PARTICIPANT	\N	PRESENT	0
769973	769971	08047A	PARTICIPANT	\N	PRESENT	0
770316	769073	14189C	PARTICIPANT	\N	EXCUSE	0
770317	769073	21091K	PARTICIPANT	\N	EXCUSE	0
770318	769073	21087P	PARTICIPANT	\N	EXCUSE	0
770319	769073	14147R	PARTICIPANT	\N	EXCUSE	0
770320	769073	19798U	PARTICIPANT	\N	EXCUSE	0
774130	774129	21044C	PARTICIPANT	\N	PRESENT	0
774131	774129	21043B	PARTICIPANT	\N	PRESENT	0
774132	774129	21057H	PARTICIPANT	\N	PRESENT	0
774134	774133	21044C	PARTICIPANT	\N	PRESENT	0
780742	780741	14151M	PARTICIPANT	\N	PRESENT	0
780750	780741	21071F	PARTICIPANT	\N	PRESENT	0
780751	780741	07033P	PARTICIPANT	\N	PRESENT	0
780752	780741	19647E	PARTICIPANT	\N	PRESENT	0
780753	780741	11085T	PARTICIPANT	\N	PRESENT	0
780756	780741	18231D	PARTICIPANT	\N	PRESENT	0
780759	780741	19760E	PARTICIPANT	\N	PRESENT	0
780775	780741	21035B	PARTICIPANT	\N	PRESENT	0
780780	780741	20120S	PARTICIPANT	\N	PRESENT	0
780781	780741	14147R	PARTICIPANT	\N	PRESENT	0
780782	780741	20252E	PARTICIPANT	\N	PRESENT	0
780783	780741	08073C	PARTICIPANT	\N	PRESENT	0
780784	780741	14225N	PARTICIPANT	\N	PRESENT	0
780786	780741	20150Y	PARTICIPANT	\N	PRESENT	0
781389	779299	17779H	PARTICIPANT	\N	PRESENT	0
781390	779299	14042U	PARTICIPANT	\N	PRESENT	0
781391	779299	14195A	PARTICIPANT	\N	PRESENT	0
781392	779299	19723Y	PARTICIPANT	\N	PRESENT	0
781393	779299	19760E	PARTICIPANT	\N	PRESENT	0
781394	779299	21064G	PARTICIPANT	\N	PRESENT	0
781395	779299	21087P	PARTICIPANT	\N	PRESENT	0
781396	779299	21049H	PARTICIPANT	\N	PRESENT	0
781397	779299	19798U	PARTICIPANT	\N	PRESENT	0
781398	779299	19553Y	PARTICIPANT	\N	PRESENT	0
781399	779299	14147R	PARTICIPANT	\N	PRESENT	0
781400	779299	21046E	PARTICIPANT	\N	PRESENT	0
781401	779299	20130U	PARTICIPANT	\N	EXCUSE	0
781402	779299	19367Y	PARTICIPANT	\N	PRESENT	0
781403	779299	08061X	PARTICIPANT	\N	PRESENT	0
781404	779299	19683J	PARTICIPANT	\N	PRESENT	0
781407	779299	14026U	PARTICIPANT	\N	PRESENT	0
781408	779299	19713W	PARTICIPANT	\N	PRESENT	0
781409	779299	21094N	PARTICIPANT	\N	PRESENT	0
781410	779299	21071F	PARTICIPANT	\N	PRESENT	0
781573	777021	19057M	PARTICIPANT	\N	PRESENT	0
781762	769072	14189C	PARTICIPANT	\N	EXCUSE	0
781764	769072	21061D	PARTICIPANT	\N	EXCUSE	0
781765	769072	21087P	PARTICIPANT	\N	EXCUSE	0
782123	779254	14331P	PRESIDENT	0	PRESENT	0
782124	779254	14237S	PARTICIPANT	\N	PRESENT	0
782126	779254	04070G	PARTICIPANT	\N	PRESENT	0
782127	779254	14169X	PARTICIPANT	\N	PRESENT	0
782128	779254	19701S	PARTICIPANT	\N	PRESENT	0
782129	779254	19760E	PARTICIPANT	\N	PRESENT	0
782130	779254	20104S	PARTICIPANT	\N	PRESENT	0
782131	779254	14133K	PARTICIPANT	\N	PRESENT	0
782132	779254	19569H	PARTICIPANT	\N	PRESENT	0
782133	779254	14001X	PARTICIPANT	\N	PRESENT	0
782134	779254	10015M	PARTICIPANT	\N	PRESENT	0
782135	779254	14189C	PARTICIPANT	\N	PRESENT	0
782136	779254	18395Y	PARTICIPANT	\N	PRESENT	0
782137	779254	14026U	PARTICIPANT	\N	PRESENT	0
782138	779254	08034U	PARTICIPANT	\N	PRESENT	0
782139	779254	14073Q	PARTICIPANT	\N	PRESENT	0
782140	779254	20248J	PARTICIPANT	\N	PRESENT	0
782141	779254	20094J	PARTICIPANT	\N	PRESENT	0
782142	779254	20042V	PARTICIPANT	\N	EXCUSE	0
782143	779254	20098N	PARTICIPANT	\N	EXCUSE	0
782144	779254	19711U	PARTICIPANT	\N	EXCUSE	0
782145	779254	14033T	PARTICIPANT	\N	EXCUSE	0
782146	779254	08018U	PARTICIPANT	\N	EXCUSE	0
782147	779254	17737W	PARTICIPANT	\N	EXCUSE	0
782150	782149	12028B	PARTICIPANT	\N	PRESENT	0
782151	782149	08010L	PARTICIPANT	\N	PRESENT	0
782152	782149	14267Y	PARTICIPANT	\N	PRESENT	0
782156	782155	19691J	PARTICIPANT	\N	PRESENT	0
782157	782155	19703U	PARTICIPANT	\N	PRESENT	0
782158	782155	04092N	PARTICIPANT	\N	PRESENT	0
782159	782155	20130U	PARTICIPANT	\N	PRESENT	0
782160	782155	14223L	PARTICIPANT	\N	PRESENT	0
782161	782155	14281W	PARTICIPANT	\N	PRESENT	0
782163	782162	19721W	PARTICIPANT	\N	PRESENT	0
782484	769436	18193Q	PARTICIPANT	\N	PRESENT	0
782485	769436	19749K	PARTICIPANT	\N	PRESENT	0
782488	769436	20114U	PARTICIPANT	\N	PRESENT	0
782500	781491	19681G	PARTICIPANT	\N	EXCUSE	0
782501	781491	11065P	PARTICIPANT	\N	EXCUSE	0
782516	781405	11065P	PARTICIPANT	\N	EXCUSE	0
782517	781405	19681G	PARTICIPANT	\N	EXCUSE	0
782518	781405	20120S	PARTICIPANT	\N	PRESENT	0
782519	781405	14237S	PARTICIPANT	\N	PRESENT	0
782520	781405	21047F	PARTICIPANT	\N	PRESENT	0
782525	769436	14147R	PARTICIPANT	\N	PRESENT	0
782526	769436	14030Q	PARTICIPANT	\N	PRESENT	0
782853	769072	21071F	PARTICIPANT	\N	EXCUSE	0
782860	769072	07029T	PARTICIPANT	\N	EXCUSE	0
782861	769072	19749K	PRESIDENT	0	PRESENT	0
782862	769072	14109K	PARTICIPANT	\N	PRESENT	0
782863	769072	21038E	PARTICIPANT	\N	PRESENT	0
782866	769072	20038A	PARTICIPANT	\N	PRESENT	0
782869	769072	21089R	PARTICIPANT	\N	PRESENT	0
782882	769072	20180F	PARTICIPANT	\N	PRESENT	0
782895	769072	14147R	PARTICIPANT	\N	PRESENT	0
782896	769072	14030Q	PARTICIPANT	\N	PRESENT	0
782943	769072	21077M	PARTICIPANT	\N	PRESENT	0
783007	779088	19669L	PARTICIPANT	\N	PRESENT	0
783008	779088	20016T	PARTICIPANT	\N	PRESENT	0
783009	779088	08073C	PARTICIPANT	\N	PRESENT	0
783027	779656	20104S	PARTICIPANT	\N	PRESENT	0
783586	783401	19295A	PARTICIPANT	\N	EXCUSE	0
783991	783381	20140W	PARTICIPANT	\N	PRESENT	0
783992	783381	11043H	PARTICIPANT	\N	PRESENT	0
783993	783381	20094J	PARTICIPANT	\N	PRESENT	0
783994	783381	21050A	PARTICIPANT	\N	PRESENT	0
783995	783381	11056N	PARTICIPANT	\N	PRESENT	0
783996	783381	11040E	PARTICIPANT	\N	PRESENT	0
783997	783381	21093M	PARTICIPANT	\N	PRESENT	0
783998	783381	17965H	PARTICIPANT	\N	PRESENT	0
783999	783381	21063F	PARTICIPANT	\N	PRESENT	0
784000	783381	19699S	PARTICIPANT	\N	PRESENT	0
784001	783381	19685L	PARTICIPANT	\N	PRESENT	0
784002	783381	21092L	PARTICIPANT	\N	PRESENT	0
784003	783381	21041Y	PARTICIPANT	\N	PRESENT	0
784004	783381	20092G	PARTICIPANT	\N	PRESENT	0
784005	783381	20142Y	PARTICIPANT	\N	PRESENT	0
784006	783381	14173T	PARTICIPANT	\N	PRESENT	0
784007	783381	19719D	PARTICIPANT	\N	PRESENT	0
784008	783381	21058J	PARTICIPANT	\N	PRESENT	0
784009	783381	08034U	PARTICIPANT	\N	PRESENT	0
784010	783381	14237S	PARTICIPANT	\N	PRESENT	0
784011	783381	20098N	PARTICIPANT	\N	PRESENT	0
784012	783381	19826F	PARTICIPANT	\N	PRESENT	0
784013	783381	19954N	PARTICIPANT	\N	PRESENT	0
784014	783381	20248J	PARTICIPANT	\N	PRESENT	0
784015	783381	17737W	PARTICIPANT	\N	PRESENT	0
784016	783381	14215L	PARTICIPANT	\N	PRESENT	0
784017	783381	20048C	PARTICIPANT	\N	PRESENT	0
784018	783381	14133K	PARTICIPANT	\N	PRESENT	0
784019	783381	21056G	PARTICIPANT	\N	PRESENT	0
784020	783381	19569H	PARTICIPANT	\N	PRESENT	0
784021	783381	14059S	PARTICIPANT	\N	PRESENT	0
784022	783381	19335Q	PARTICIPANT	\N	PRESENT	0
784023	783381	14030Q	PARTICIPANT	\N	PRESENT	0
784024	783381	20102Q	PARTICIPANT	\N	PRESENT	0
784025	783381	07033P	PARTICIPANT	\N	PRESENT	0
784026	783381	19533U	PARTICIPANT	\N	PRESENT	0
784027	783381	20036X	PARTICIPANT	\N	PRESENT	0
784028	783381	19347U	PARTICIPANT	\N	PRESENT	0
784029	783381	95041E	PARTICIPANT	\N	PRESENT	0
784030	783381	21039F	PARTICIPANT	\N	PRESENT	0
784031	783381	20034V	PARTICIPANT	\N	PRESENT	0
784032	783381	19387D	PARTICIPANT	\N	PRESENT	0
784033	783381	17779H	PARTICIPANT	\N	PRESENT	0
784034	783381	19565D	PARTICIPANT	\N	PRESENT	0
794429	791394	20124W	PARTICIPANT	\N	PRESENT	0
794430	791394	21037D	PARTICIPANT	\N	PRESENT	0
794431	791394	14053L	PARTICIPANT	\N	PRESENT	0
794432	791394	17965H	PARTICIPANT	\N	PRESENT	0
794433	791394	14026U	PARTICIPANT	\N	PRESENT	0
794434	794070	19533U	PARTICIPANT	\N	PRESENT	0
794435	791394	19565D	PARTICIPANT	\N	PRESENT	0
794436	791394	19629C	PARTICIPANT	\N	PRESENT	0
794437	791394	14267Y	PARTICIPANT	\N	PRESENT	0
794438	791394	21045D	PARTICIPANT	\N	PRESENT	0
794439	791394	08010L	PARTICIPANT	\N	PRESENT	0
794462	791394	20066E	PARTICIPANT	\N	PRESENT	0
794463	791394	20034V	PARTICIPANT	\N	PRESENT	0
794500	791425	14217N	PARTICIPANT	\N	PRESENT	0
794465	791425	19691J	PARTICIPANT	\N	PRESENT	0
794466	791425	21097R	PARTICIPANT	\N	PRESENT	0
794467	791425	17779H	PARTICIPANT	\N	PRESENT	0
794468	791425	18193Q	PARTICIPANT	\N	PRESENT	0
794469	791425	14195A	PARTICIPANT	\N	PRESENT	0
794470	791425	19758L	PARTICIPANT	\N	PRESENT	0
794471	791425	19703U	PARTICIPANT	\N	PRESENT	0
794472	791425	14071N	PARTICIPANT	\N	PRESENT	0
794473	791425	19866P	PARTICIPANT	\N	PRESENT	0
794474	791425	01034P	PARTICIPANT	\N	PRESENT	0
794475	791425	19713W	PARTICIPANT	\N	PRESENT	0
794476	791425	21064G	PARTICIPANT	\N	PRESENT	0
794501	791425	14069U	PARTICIPANT	\N	PRESENT	0
794478	791425	19679N	PARTICIPANT	\N	PRESENT	0
794502	791425	17965H	PARTICIPANT	\N	PRESENT	0
794503	791425	20034V	PARTICIPANT	\N	PRESENT	0
794481	791425	19798U	PARTICIPANT	\N	PRESENT	0
794504	791425	14042U	PARTICIPANT	\N	PRESENT	0
794483	791425	14281W	PARTICIPANT	\N	PRESENT	0
794484	791425	14213J	PARTICIPANT	\N	PRESENT	0
794485	791425	19657G	PARTICIPANT	\N	PRESENT	0
794486	791425	19347U	PARTICIPANT	\N	PRESENT	0
794487	791425	21049H	PARTICIPANT	\N	PRESENT	0
794505	791425	14215L	PARTICIPANT	\N	PRESENT	0
794506	791425	21056G	PARTICIPANT	\N	PRESENT	0
794507	791425	19553Y	PARTICIPANT	\N	PRESENT	0
794508	791425	20062A	PARTICIPANT	\N	PRESENT	0
794509	791425	14033T	PARTICIPANT	\N	PRESENT	0
794493	791425	21037D	PARTICIPANT	\N	PRESENT	0
794510	791425	95041E	PARTICIPANT	\N	PRESENT	0
794495	791425	14026U	PARTICIPANT	\N	PRESENT	0
794496	791425	19629C	PARTICIPANT	\N	PRESENT	0
794497	791425	20066E	PARTICIPANT	\N	PRESENT	0
794511	791425	20092G	PARTICIPANT	\N	PRESENT	0
794499	791425	14229S	PARTICIPANT	\N	PRESENT	0
794512	791425	11048N	PARTICIPANT	\N	PRESENT	0
794513	791425	21079P	PARTICIPANT	\N	PRESENT	0
794514	791425	20032T	PARTICIPANT	\N	PRESENT	0
794633	794632	21082J	PARTICIPANT	\N	PRESENT	0
794634	794632	08060W	PARTICIPANT	\N	PRESENT	0
794672	794671	11070L	PARTICIPANT	\N	PRESENT	0
794673	794671	20042V	PARTICIPANT	\N	PRESENT	0
794674	794671	14257W	PRESIDENT	0	PRESENT	0
794675	794671	21060C	PARTICIPANT	\N	PRESENT	0
794676	794671	20120S	PARTICIPANT	\N	PRESENT	0
794677	794671	19711U	PARTICIPANT	\N	PRESENT	0
794678	794671	19575F	PARTICIPANT	\N	EXCUSE	0
794681	794671	12016W	PARTICIPANT	\N	PRESENT	0
794705	791719	05008E	PARTICIPANT	\N	EXCUSE	0
794706	791719	14219Q	PARTICIPANT	\N	EXCUSE	0
794707	791719	19745F	PARTICIPANT	\N	EXCUSE	0
794712	794605	20248J	PARTICIPANT	\N	EXCUSE	0
794713	794605	21066J	PARTICIPANT	\N	EXCUSE	0
794901	794750	17367Q	PARTICIPANT	\N	PRESENT	0
794902	794750	14151M	PRESIDENT	0	PRESENT	0
794903	794750	18395Y	PARTICIPANT	\N	PRESENT	0
794904	794750	20146D	PARTICIPANT	\N	PRESENT	0
794906	794750	20110Q	PARTICIPANT	\N	PRESENT	0
794907	794750	19349W	PARTICIPANT	\N	PRESENT	0
794908	794750	21081H	PARTICIPANT	\N	PRESENT	0
794909	794750	20078J	PARTICIPANT	\N	PRESENT	0
794910	794750	20090E	PARTICIPANT	\N	PRESENT	0
794911	794750	19563B	PARTICIPANT	\N	PRESENT	0
794944	794943	20094J	PARTICIPANT	\N	PRESENT	0
795116	794896	19667J	PARTICIPANT	\N	PRESENT	0
796004	794751	14355X	PARTICIPANT	\N	PRESENT	0
796005	794751	19798U	PARTICIPANT	\N	PRESENT	0
796006	794751	19866P	PARTICIPANT	\N	PRESENT	0
796007	794751	14223L	PARTICIPANT	\N	PRESENT	0
796008	794751	18193Q	PARTICIPANT	\N	PRESENT	0
796009	794751	20096L	PARTICIPANT	\N	PRESENT	0
796010	794751	17779H	PARTICIPANT	\N	PRESENT	0
796011	794751	19553Y	PARTICIPANT	\N	PRESENT	0
796012	794751	19703U	PARTICIPANT	\N	PRESENT	0
796013	794751	21087P	PARTICIPANT	\N	PRESENT	0
796014	794751	14281W	PARTICIPANT	\N	PRESENT	0
796015	794751	19679N	PARTICIPANT	\N	PRESENT	0
796016	794751	14042U	PARTICIPANT	\N	PRESENT	0
796017	794751	08061X	PARTICIPANT	\N	PRESENT	0
796018	794751	14217N	PARTICIPANT	\N	PRESENT	0
796019	794751	21039F	PARTICIPANT	\N	PRESENT	0
796020	794751	04092N	PARTICIPANT	\N	PRESENT	0
796021	794751	11045K	PARTICIPANT	\N	PRESENT	0
796022	794751	20140W	PARTICIPANT	\N	PRESENT	0
796023	794751	08045X	PARTICIPANT	\N	PRESENT	0
796024	794751	19301E	PARTICIPANT	\N	PRESENT	0
796025	794751	17965H	PARTICIPANT	\N	PRESENT	0
796026	794751	19691J	PARTICIPANT	\N	PRESENT	0
796027	794751	21094N	PARTICIPANT	\N	PRESENT	0
796028	794751	19629C	PARTICIPANT	\N	PRESENT	0
796029	794751	14071N	PRESIDENT	0	PRESENT	0
796030	794751	19657G	PARTICIPANT	\N	PRESENT	0
796031	794751	21071F	PARTICIPANT	\N	PRESENT	0
796032	794751	19758L	PARTICIPANT	\N	PRESENT	0
796033	794751	19760E	PARTICIPANT	\N	PRESENT	0
796034	794751	21081H	PARTICIPANT	\N	PRESENT	0
796035	794751	20130U	PARTICIPANT	\N	EXCUSE	0
796036	794751	14213J	PARTICIPANT	\N	PRESENT	0
796037	794751	21049H	PARTICIPANT	\N	PRESENT	0
796038	794751	14195A	PARTICIPANT	\N	PRESENT	0
796086	794751	21045D	PARTICIPANT	\N	PRESENT	0
796087	794710	20074E	PARTICIPANT	\N	PRESENT	0
796088	794710	21057H	PARTICIPANT	\N	PRESENT	0
796089	794710	04045F	PARTICIPANT	\N	PRESENT	0
796090	794710	19447X	PARTICIPANT	\N	PRESENT	0
796091	794710	14231L	PARTICIPANT	\N	PRESENT	0
796092	794710	19489J	PARTICIPANT	\N	PRESENT	0
796093	794710	18207D	PARTICIPANT	\N	PRESENT	0
796094	794710	21088Q	PARTICIPANT	\N	PRESENT	0
796095	794710	14147R	PARTICIPANT	\N	PRESENT	0
796096	794710	20114U	PARTICIPANT	\N	PRESENT	0
796097	794710	19111A	PARTICIPANT	\N	PRESENT	0
796098	794710	14215L	PARTICIPANT	\N	PRESENT	0
796099	794710	08018U	PRESIDENT	0	PRESENT	0
796100	794710	20022R	PARTICIPANT	\N	PRESENT	0
796101	794710	11072N	PARTICIPANT	\N	PRESENT	0
796102	794710	14053L	PARTICIPANT	\N	PRESENT	0
796103	794710	19649G	PARTICIPANT	\N	PRESENT	0
796104	794710	14111D	PARTICIPANT	\N	PRESENT	0
796105	794710	21076L	PARTICIPANT	\N	PRESENT	0
796106	794710	21040X	PARTICIPANT	\N	PRESENT	0
796107	794710	21043B	PARTICIPANT	\N	PRESENT	0
796108	794710	14089Y	PARTICIPANT	\N	PRESENT	0
796109	794710	19725B	PARTICIPANT	\N	PRESENT	0
796110	794710	21044C	PARTICIPANT	\N	PRESENT	0
796111	794710	19749K	PARTICIPANT	\N	PRESENT	0
796112	794710	21056G	PARTICIPANT	\N	PRESENT	0
796113	794710	20110Q	PARTICIPANT	\N	PRESENT	0
796114	794751	19569H	PARTICIPANT	\N	PRESENT	0
796115	794751	14026U	PARTICIPANT	\N	PRESENT	0
796116	794751	21064G	PARTICIPANT	\N	PRESENT	0
796117	794751	21097R	PARTICIPANT	\N	PRESENT	0
796118	794751	19723Y	PARTICIPANT	\N	PRESENT	0
796119	794710	20136B	PARTICIPANT	\N	PRESENT	0
796120	794710	18231D	PARTICIPANT	\N	PRESENT	0
796121	794710	19585H	PARTICIPANT	\N	EXCUSE	0
796122	794710	05008E	PARTICIPANT	\N	PRESENT	0
796123	794710	21038E	PARTICIPANT	\N	PRESENT	0
796124	794710	14189C	PARTICIPANT	\N	PRESENT	0
796125	794751	19713W	PARTICIPANT	\N	PRESENT	0
796126	794710	20036X	PARTICIPANT	\N	EXCUSE	0
796127	794751	20248J	PARTICIPANT	\N	PRESENT	0
796128	794710	04047H	PRESIDENT	1	PRESENT	0
796129	794710	21095P	PARTICIPANT	\N	PRESENT	0
796130	794710	14069U	PARTICIPANT	\N	PRESENT	0
796133	796132	19545Y	PRESIDENT	0	PRESENT	0
796134	796132	21069M	PARTICIPANT	\N	PRESENT	0
768703	765407	20252E	PARTICIPANT	\N	PRESENT	0
768704	765407	19798U	PARTICIPANT	\N	PRESENT	0
768705	765407	21078N	PARTICIPANT	\N	PRESENT	0
768706	765407	20062A	PARTICIPANT	\N	PRESENT	0
768707	765407	04092N	PARTICIPANT	\N	PRESENT	0
768708	765407	14195A	PARTICIPANT	\N	PRESENT	0
768721	765407	21081H	PARTICIPANT	\N	PRESENT	0
768728	765407	14071N	PARTICIPANT	\N	PRESENT	0
768731	765407	14069U	PARTICIPANT	\N	PRESENT	0
768732	765407	19629C	PARTICIPANT	\N	PRESENT	0
768734	765407	14217N	PARTICIPANT	\N	PRESENT	0
768735	765407	19758L	PARTICIPANT	\N	PRESENT	0
768736	765407	20248J	PARTICIPANT	\N	PRESENT	0
768737	765407	19723Y	PARTICIPANT	\N	PRESENT	0
768738	765407	21065H	PARTICIPANT	\N	PRESENT	0
768743	765407	20128B	PARTICIPANT	\N	PRESENT	0
768741	765407	98022P	PARTICIPANT	\N	PRESENT	0
768742	765407	14033T	PARTICIPANT	\N	PRESENT	0
768744	765407	14042U	PARTICIPANT	\N	PRESENT	0
768745	765407	19782L	PARTICIPANT	\N	PRESENT	0
768746	765407	21073H	PARTICIPANT	\N	PRESENT	0
768747	765407	18083K	PARTICIPANT	\N	PRESENT	0
768748	765407	14281W	PARTICIPANT	\N	PRESENT	0
768750	765407	19683J	PARTICIPANT	\N	PRESENT	0
768787	765408	17779H	PARTICIPANT	\N	PRESENT	0
768788	765408	19782L	PARTICIPANT	\N	PRESENT	0
768789	765408	19866P	PARTICIPANT	\N	PRESENT	0
768790	765408	21066J	PARTICIPANT	\N	PRESENT	0
768791	765408	19629C	PARTICIPANT	\N	PRESENT	0
768792	765408	20130U	PARTICIPANT	\N	PRESENT	0
768793	765408	19758L	PARTICIPANT	\N	PRESENT	0
768794	765408	14195A	PARTICIPANT	\N	PRESENT	0
768795	765408	20248J	PARTICIPANT	\N	PRESENT	0
768796	765408	19569H	PARTICIPANT	\N	PRESENT	0
768797	765408	07004J	PARTICIPANT	\N	PRESENT	0
768798	765408	20090E	PARTICIPANT	\N	PRESENT	0
768799	765408	14217N	PARTICIPANT	\N	PRESENT	0
768800	765408	14033T	PARTICIPANT	\N	PRESENT	0
768801	765408	20252E	PARTICIPANT	\N	PRESENT	0
768802	765408	19798U	PARTICIPANT	\N	PRESENT	0
768803	765408	20062A	PARTICIPANT	\N	PRESENT	0
768804	765408	21081H	PARTICIPANT	\N	PRESENT	0
768805	765408	21039F	PARTICIPANT	\N	PRESENT	0
768806	765408	19723Y	PARTICIPANT	\N	PRESENT	0
768807	765408	14071N	PARTICIPANT	\N	PRESENT	0
768808	765408	14042U	PARTICIPANT	\N	PRESENT	0
768809	765408	14281W	PARTICIPANT	\N	PRESENT	0
768810	765408	11045K	PARTICIPANT	\N	PRESENT	0
768811	765408	98022P	PARTICIPANT	\N	PRESENT	0
768812	765408	14069U	PARTICIPANT	\N	PRESENT	0
768813	765408	04092N	PARTICIPANT	\N	PRESENT	0
768814	765408	17965H	PARTICIPANT	\N	PRESENT	0
768815	765408	19367Y	PARTICIPANT	\N	PRESENT	0
768816	765408	18083K	PARTICIPANT	\N	PRESENT	0
768817	765408	19301E	PARTICIPANT	\N	PRESENT	0
768818	765408	19713W	PARTICIPANT	\N	PRESENT	0
768819	765408	21094N	PARTICIPANT	\N	PRESENT	0
768820	765408	19667J	PARTICIPANT	\N	PRESENT	0
768785	765408	11090Q	PARTICIPANT	\N	PRESENT	0
768786	765408	19683J	PARTICIPANT	\N	PRESENT	0
768821	765408	14030Q	PARTICIPANT	\N	PRESENT	0
768822	765408	19657G	PARTICIPANT	\N	PRESENT	0
768823	765408	21054E	PARTICIPANT	\N	PRESENT	0
768824	765408	19531S	PARTICIPANT	\N	PRESENT	0
768825	765408	14026U	PARTICIPANT	\N	PRESENT	0
768826	765408	19691J	PARTICIPANT	\N	PRESENT	0
768828	765408	21046E	PARTICIPANT	\N	PRESENT	0
768829	765408	19679N	PARTICIPANT	\N	PRESENT	0
768830	765408	21064G	PARTICIPANT	\N	PRESENT	0
768831	765408	19479G	PARTICIPANT	\N	PRESENT	0
768832	765408	21036C	PARTICIPANT	\N	PRESENT	0
768833	765408	21061D	PARTICIPANT	\N	PRESENT	0
768834	765408	21057H	PARTICIPANT	\N	PRESENT	0
768835	765408	19703U	PARTICIPANT	\N	PRESENT	0
768836	765408	21078N	PARTICIPANT	\N	PRESENT	0
768837	765408	14083S	PARTICIPANT	\N	PRESENT	0
768838	765408	19711U	PARTICIPANT	\N	PRESENT	0
768839	765408	08034U	PARTICIPANT	\N	PRESENT	0
768840	765408	14267Y	PARTICIPANT	\N	PRESENT	0
768841	765408	20134Y	PARTICIPANT	\N	PRESENT	0
768842	765408	21058J	PARTICIPANT	\N	PRESENT	0
768843	765408	21095P	PARTICIPANT	\N	PRESENT	0
768844	765408	11085T	PARTICIPANT	\N	PRESENT	0
768845	765408	19533U	PARTICIPANT	\N	PRESENT	0
768846	765408	21037D	PARTICIPANT	\N	PRESENT	0
768847	765408	20172F	PARTICIPANT	\N	PRESENT	0
768848	765408	20096L	PARTICIPANT	\N	PRESENT	0
768860	765408	14179A	PARTICIPANT	\N	PRESENT	0
768901	765409	14257W	PARTICIPANT	\N	PRESENT	0
768902	765409	19683J	PARTICIPANT	\N	PRESENT	0
768903	765409	17965H	PARTICIPANT	\N	PRESENT	0
768904	765409	21097R	PARTICIPANT	\N	PRESENT	0
768905	765409	14195A	PARTICIPANT	\N	PRESENT	0
768906	765409	19693L	PARTICIPANT	\N	PRESENT	0
768907	765409	21094N	PARTICIPANT	\N	PRESENT	0
768908	765409	19758L	PARTICIPANT	\N	PRESENT	0
768909	765409	19691J	PARTICIPANT	\N	PRESENT	0
768910	765409	19569H	PARTICIPANT	\N	PRESENT	0
768911	765409	19479G	PARTICIPANT	\N	PRESENT	0
768912	765409	19798U	PARTICIPANT	\N	PRESENT	0
768913	765409	14217N	PARTICIPANT	\N	PRESENT	0
768914	765409	14026U	PARTICIPANT	\N	PRESENT	0
768915	765409	20062A	PARTICIPANT	\N	PRESENT	0
768916	765409	19679N	PARTICIPANT	\N	PRESENT	0
768917	765409	04092N	PARTICIPANT	\N	PRESENT	0
768918	765409	20090E	PARTICIPANT	\N	PRESENT	0
768919	765409	19703U	PARTICIPANT	\N	PRESENT	0
768920	765409	21081H	PARTICIPANT	\N	PRESENT	0
768921	765409	19657G	PARTICIPANT	\N	PRESENT	0
768922	765409	21058J	PARTICIPANT	\N	PRESENT	0
768923	765409	19367Y	PARTICIPANT	\N	PRESENT	0
768924	765409	21063F	PARTICIPANT	\N	PRESENT	0
768925	765409	19760E	PARTICIPANT	\N	PRESENT	0
768926	765409	14071N	PARTICIPANT	\N	PRESENT	0
768927	765409	21045D	PARTICIPANT	\N	PRESENT	0
768928	765409	21029D	PARTICIPANT	\N	PRESENT	0
768929	765409	19711U	PARTICIPANT	\N	PRESENT	0
768930	765409	14030Q	PARTICIPANT	\N	PRESENT	0
768931	765409	14042U	PARTICIPANT	\N	PRESENT	0
768932	765409	21037D	PARTICIPANT	\N	PRESENT	0
768935	765409	21035B	PARTICIPANT	\N	PRESENT	0
768936	765409	19629C	PARTICIPANT	\N	PRESENT	0
768937	765409	21077M	PARTICIPANT	\N	PRESENT	0
768938	765409	14069U	PARTICIPANT	\N	PRESENT	0
768939	765409	14281W	PARTICIPANT	\N	PRESENT	0
768941	765409	21046E	PARTICIPANT	\N	PRESENT	0
768899	765409	19301E	PARTICIPANT	\N	PRESENT	0
768900	765409	07004J	PARTICIPANT	\N	PRESENT	0
768942	765409	20132W	PARTICIPANT	\N	PRESENT	0
768943	765409	21049H	PARTICIPANT	\N	PRESENT	0
768944	765409	21071F	PARTICIPANT	\N	PRESENT	0
768945	765409	18231D	PARTICIPANT	\N	PRESENT	0
768952	765409	19531S	PARTICIPANT	\N	PRESENT	0
768954	765409	19591F	PARTICIPANT	\N	PRESENT	0
768955	765409	20172F	PARTICIPANT	\N	PRESENT	0
768956	765409	01034P	PARTICIPANT	\N	PRESENT	0
768957	765409	20264J	PARTICIPANT	\N	PRESENT	0
768958	765409	11045K	PARTICIPANT	\N	PRESENT	0
768959	765409	20130U	PARTICIPANT	\N	PRESENT	0
768987	765409	98022P	PARTICIPANT	\N	PRESENT	0
768988	765409	19713W	PARTICIPANT	\N	PRESENT	0
768989	765409	21054E	PARTICIPANT	\N	PRESENT	0
768990	765409	11040E	PARTICIPANT	\N	PRESENT	0
768991	765409	18193Q	PARTICIPANT	\N	PRESENT	0
768992	765409	08010L	PARTICIPANT	\N	PRESENT	0
769049	765409	17779H	PARTICIPANT	\N	PRESENT	0
769050	765409	21075K	PARTICIPANT	\N	PRESENT	0
769068	765409	21074J	PARTICIPANT	\N	PRESENT	0
769070	765409	20248J	PARTICIPANT	\N	PRESENT	0
769076	765409	20094J	PARTICIPANT	\N	PRESENT	0
769082	765409	21087P	PARTICIPANT	\N	PRESENT	0
769083	765409	20148F	PARTICIPANT	\N	PRESENT	0
769088	765409	08034U	PARTICIPANT	\N	PRESENT	0
769089	765409	07029T	PARTICIPANT	\N	PRESENT	0
769090	765409	21090J	PARTICIPANT	\N	PRESENT	0
769091	765409	21092L	PARTICIPANT	\N	PRESENT	0
792533	791846	21054E	PARTICIPANT	\N	PRESENT	0
792534	791846	14267Y	PARTICIPANT	\N	PRESENT	0
792535	791846	19693L	PARTICIPANT	\N	PRESENT	0
792536	791846	21087P	PARTICIPANT	\N	PRESENT	0
792537	791846	20036X	PARTICIPANT	\N	PRESENT	0
792538	791846	21074J	PARTICIPANT	\N	PRESENT	0
792539	791846	21032X	PARTICIPANT	\N	PRESENT	0
792540	791846	19553Y	PARTICIPANT	\N	PRESENT	0
792541	791846	21066J	PARTICIPANT	\N	PRESENT	0
792542	791846	19719D	PARTICIPANT	\N	PRESENT	0
792543	791846	14207L	PARTICIPANT	\N	PRESENT	0
792544	791846	21078N	PARTICIPANT	\N	PRESENT	0
792545	791846	20116W	PARTICIPANT	\N	PRESENT	0
792546	791846	19387D	PARTICIPANT	\N	PRESENT	0
792582	791846	08010L	PARTICIPANT	\N	PRESENT	0
792584	791846	19629C	PARTICIPANT	\N	PRESENT	0
792583	791846	19866P	PARTICIPANT	\N	PRESENT	0
792599	791846	14255U	PARTICIPANT	\N	PRESENT	0
792551	791846	04033B	PARTICIPANT	\N	PRESENT	0
792586	791846	14275Y	PARTICIPANT	\N	PRESENT	0
792588	791846	21065H	PARTICIPANT	\N	PRESENT	0
792554	791846	08028W	PARTICIPANT	\N	PRESENT	0
792585	791846	19749K	PARTICIPANT	\N	PRESENT	0
792556	791846	11090Q	PARTICIPANT	\N	PRESENT	0
792557	791846	14215L	PARTICIPANT	\N	PRESENT	0
792596	791846	19699S	PARTICIPANT	\N	PRESENT	0
792597	791846	14030Q	PARTICIPANT	\N	PRESENT	0
792602	791846	12028B	PARTICIPANT	\N	PRESENT	0
792577	791846	21086N	PARTICIPANT	\N	PRESENT	0
792590	791846	19721W	PARTICIPANT	\N	PRESENT	0
792563	791846	08018U	PARTICIPANT	\N	PRESENT	0
792579	791846	20122U	PARTICIPANT	\N	PRESENT	0
792594	791846	19569H	PARTICIPANT	\N	PRESENT	0
792595	791846	21042A	PARTICIPANT	\N	PRESENT	0
792591	791846	20052X	PARTICIPANT	\N	PRESENT	0
792589	791846	21038E	PARTICIPANT	\N	PRESENT	0
792578	791846	07004J	PARTICIPANT	\N	PRESENT	0
792601	791846	19545Y	PARTICIPANT	\N	PRESENT	0
792571	791846	21053D	PARTICIPANT	\N	PRESENT	0
792572	791846	14221J	PARTICIPANT	\N	PRESENT	0
792573	791846	19735D	PARTICIPANT	\N	PRESENT	0
792574	791846	19611R	PARTICIPANT	\N	PRESENT	0
792575	791846	19563B	PARTICIPANT	\N	PRESENT	0
792576	791846	11070L	PARTICIPANT	\N	PRESENT	0
792580	791846	14169X	PARTICIPANT	\N	PRESENT	0
792581	791846	14107H	PARTICIPANT	\N	PRESENT	0
792592	791846	19691J	PARTICIPANT	\N	PRESENT	0
792593	791846	14073Q	PARTICIPANT	\N	PRESENT	0
792604	791846	19631V	PARTICIPANT	\N	PRESENT	0
792603	791846	14211G	PARTICIPANT	\N	PRESENT	0
792605	791846	21035B	PARTICIPANT	\N	PRESENT	0
792606	791846	20088L	PARTICIPANT	\N	PRESENT	0
792607	791846	20080C	PARTICIPANT	\N	PRESENT	0
792608	791846	10015M	PARTICIPANT	\N	PRESENT	0
792609	791846	21089R	PARTICIPANT	\N	PRESENT	0
792610	791846	21072G	PARTICIPANT	\N	PRESENT	0
792611	791846	21057H	PARTICIPANT	\N	PRESENT	0
792612	791846	20264J	PARTICIPANT	\N	PRESENT	0
792613	791846	19295A	PARTICIPANT	\N	PRESENT	0
792614	791846	20070A	PARTICIPANT	\N	PRESENT	0
792615	791846	18395Y	PARTICIPANT	\N	PRESENT	0
792616	791846	21067K	PARTICIPANT	\N	PRESENT	0
792617	791846	19251M	PARTICIPANT	\N	PRESENT	0
792618	791846	21062E	PARTICIPANT	\N	PRESENT	0
792619	791846	19647E	PARTICIPANT	\N	PRESENT	0
792620	791846	20076G	PARTICIPANT	\N	PRESENT	0
792621	791846	19820Y	PARTICIPANT	\N	PRESENT	0
792622	791846	21045D	PARTICIPANT	\N	PRESENT	0
792623	791846	19725B	PARTICIPANT	\N	PRESENT	0
792624	791846	19683J	PARTICIPANT	\N	PRESENT	0
792625	791846	14021P	PARTICIPANT	\N	PRESENT	0
792626	791846	19649G	PARTICIPANT	\N	PRESENT	0
792627	791846	20032T	PARTICIPANT	\N	PRESENT	0
792628	791846	18207D	PARTICIPANT	\N	PRESENT	0
792629	791846	08012N	PARTICIPANT	\N	PRESENT	0
792630	791846	14147R	PARTICIPANT	\N	PRESENT	0
792631	791846	12016W	PARTICIPANT	\N	PRESENT	0
792632	791846	14001X	PARTICIPANT	\N	PRESENT	0
792633	791846	20028X	PARTICIPANT	\N	PRESENT	0
792634	791846	20018V	PARTICIPANT	\N	PRESENT	0
792635	791846	20172F	PARTICIPANT	\N	PRESENT	0
792636	791846	18231D	PARTICIPANT	\N	PRESENT	0
792637	791846	05012A	PARTICIPANT	\N	PRESENT	0
792638	791846	20030R	PARTICIPANT	\N	PRESENT	0
792639	791846	17965H	PARTICIPANT	\N	PRESENT	0
792663	791846	04047H	PARTICIPANT	\N	PRESENT	0
792641	791846	19705W	PARTICIPANT	\N	PRESENT	0
792642	791846	20082E	PARTICIPANT	\N	PRESENT	0
792643	791846	18193Q	PARTICIPANT	\N	PRESENT	0
792644	791846	21056G	PARTICIPANT	\N	PRESENT	0
792645	791846	11045K	PARTICIPANT	\N	PRESENT	0
792646	791846	14281W	PARTICIPANT	\N	PRESENT	0
792647	791846	20084G	PARTICIPANT	\N	PRESENT	0
792648	791846	21051B	PARTICIPANT	\N	PRESENT	0
792649	791846	20064C	PARTICIPANT	\N	PRESENT	0
792650	791846	21031W	PARTICIPANT	\N	PRESENT	0
792651	791846	19768N	PARTICIPANT	\N	PRESENT	0
792652	791846	21077M	PARTICIPANT	\N	PRESENT	0
792653	791846	21068L	PARTICIPANT	\N	PRESENT	0
792654	791846	20042V	PARTICIPANT	\N	PRESENT	0
792655	791846	19057M	PARTICIPANT	\N	PRESENT	0
792656	791846	14187A	PARTICIPANT	\N	PRESENT	0
792657	791846	11053K	PARTICIPANT	\N	PRESENT	0
792658	791846	05008E	PARTICIPANT	\N	PRESENT	0
792659	791846	20022R	PARTICIPANT	\N	PRESENT	0
792660	791846	19954N	PARTICIPANT	\N	PRESENT	0
792661	791846	19707Y	PARTICIPANT	\N	PRESENT	0
792662	791846	04092N	PARTICIPANT	\N	PRESENT	0
792664	791846	21090J	PARTICIPANT	\N	PRESENT	0
792665	791846	14329V	PARTICIPANT	\N	PRESENT	0
792666	791846	18083K	PARTICIPANT	\N	PRESENT	0
792674	791846	21095P	PARTICIPANT	\N	PRESENT	0
792668	791846	14259Y	PARTICIPANT	\N	PRESENT	0
792669	791846	20140W	PARTICIPANT	\N	PRESENT	0
792670	791846	14217N	PARTICIPANT	\N	PRESENT	0
792671	791846	19367Y	PARTICIPANT	\N	PRESENT	0
792672	791846	14357A	PARTICIPANT	\N	PRESENT	0
792673	791846	20124W	PARTICIPANT	\N	PRESENT	0
792675	791846	20120S	PARTICIPANT	\N	PRESENT	0
792676	791846	20180F	PARTICIPANT	\N	PRESENT	0
792677	791846	08056B	PARTICIPANT	\N	PRESENT	0
792678	791846	14033T	PARTICIPANT	\N	PRESENT	0
792679	791846	20068G	PARTICIPANT	\N	PRESENT	0
792680	791846	08069G	PARTICIPANT	\N	PRESENT	0
792681	791846	19399H	PARTICIPANT	\N	PRESENT	0
792682	791846	19703U	PARTICIPANT	\N	PRESENT	0
792683	791846	07033P	PARTICIPANT	\N	PRESENT	0
792684	791846	14225N	PARTICIPANT	\N	PRESENT	0
792685	791846	08045X	PARTICIPANT	\N	PRESENT	0
792686	791846	20252E	PARTICIPANT	\N	PRESENT	0
792687	791846	99004R	PARTICIPANT	\N	PRESENT	0
792695	791846	14253S	PARTICIPANT	\N	PRESENT	0
792689	791846	08047A	PARTICIPANT	\N	PRESENT	0
792690	791846	07029T	PARTICIPANT	\N	PRESENT	0
792691	791846	19383Y	PARTICIPANT	\N	PRESENT	0
792692	791846	19723Y	PARTICIPANT	\N	PRESENT	0
792693	791846	21081H	PARTICIPANT	\N	PRESENT	0
792694	791846	08015R	PARTICIPANT	\N	PRESENT	0
792696	791846	08034U	PARTICIPANT	\N	PRESENT	0
792697	791846	19709B	PARTICIPANT	\N	PRESENT	0
792698	791846	21058J	PARTICIPANT	\N	PRESENT	0
792699	791846	20148F	PARTICIPANT	\N	PRESENT	0
792700	791846	21080G	PARTICIPANT	\N	PRESENT	0
792701	791846	14071N	PARTICIPANT	\N	PRESENT	0
792702	791846	14133K	PARTICIPANT	\N	PRESENT	0
792719	791822	19703U	PARTICIPANT	\N	PRESENT	0
793171	791391	21046E	PARTICIPANT	\N	PRESENT	0
793172	791391	21058J	PARTICIPANT	\N	PRESENT	0
793173	791391	20128B	PARTICIPANT	\N	PRESENT	0
793175	793065	19383Y	PARTICIPANT	\N	PRESENT	0
793176	793065	19768N	PARTICIPANT	\N	PRESENT	0
793177	793065	20088L	PARTICIPANT	\N	PRESENT	0
793178	793065	19782L	PARTICIPANT	\N	PRESENT	0
793179	793065	20092G	PARTICIPANT	\N	PRESENT	0
793180	793065	14357A	PARTICIPANT	\N	PRESENT	0
793181	793065	20078J	PARTICIPANT	\N	PRESENT	0
793182	793065	19413M	PARTICIPANT	\N	PRESENT	0
793183	793065	20082E	PARTICIPANT	\N	PRESENT	0
793184	793065	19826F	PARTICIPANT	\N	PRESENT	0
793185	793065	19631V	PARTICIPANT	\N	PRESENT	0
793186	793065	08015R	PARTICIPANT	\N	PRESENT	0
770647	768431	20090E	PARTICIPANT	\N	PRESENT	0
770648	768431	21087P	PARTICIPANT	\N	PRESENT	0
770649	768431	20148F	PARTICIPANT	\N	PRESENT	0
770650	768431	20140W	PARTICIPANT	\N	PRESENT	0
770655	768431	21046E	PARTICIPANT	\N	PRESENT	0
770656	768431	20248J	PARTICIPANT	\N	PRESENT	0
770657	768431	14355X	PARTICIPANT	\N	PRESENT	0
770659	768431	19866P	PARTICIPANT	\N	PRESENT	0
770662	768431	14071N	PRESIDENT	0	PRESENT	0
770663	768431	19798U	PARTICIPANT	\N	PRESENT	0
770664	768431	14281W	PARTICIPANT	\N	PRESENT	0
770667	768431	21081H	PARTICIPANT	\N	PRESENT	0
770670	768431	08061X	PARTICIPANT	\N	PRESENT	0
770671	768431	19703U	PARTICIPANT	\N	PRESENT	0
770689	768431	14042U	PARTICIPANT	\N	PRESENT	0
770692	768431	17965H	PARTICIPANT	\N	PRESENT	0
770693	768431	21049H	PARTICIPANT	\N	PRESENT	0
770695	768431	14223L	PARTICIPANT	\N	PRESENT	0
770699	768431	19691J	PARTICIPANT	\N	PRESENT	0
770700	768431	19758L	PARTICIPANT	\N	PRESENT	0
770702	768431	20130U	PARTICIPANT	\N	PRESENT	0
770706	768431	19713W	PARTICIPANT	\N	PRESENT	0
770708	768431	21064G	PARTICIPANT	\N	PRESENT	0
770709	768431	14213J	PARTICIPANT	\N	PRESENT	0
770710	768431	18193Q	PARTICIPANT	\N	PRESENT	0
770735	768431	19679N	PARTICIPANT	\N	PRESENT	0
770737	768431	21045D	PARTICIPANT	\N	PRESENT	0
770738	768431	21097R	PARTICIPANT	\N	PRESENT	0
770742	768431	21071F	PARTICIPANT	\N	PRESENT	0
770758	768431	19723Y	PARTICIPANT	\N	PRESENT	0
770765	768431	19367Y	PARTICIPANT	\N	PRESENT	0
770766	768431	20096L	PARTICIPANT	\N	PRESENT	0
770771	768431	19760E	PARTICIPANT	\N	PRESENT	0
770777	768431	21039F	PARTICIPANT	\N	PRESENT	0
770793	768431	21094N	PARTICIPANT	\N	PRESENT	0
770837	768431	14217N	PARTICIPANT	\N	PRESENT	0
770838	768431	04092N	PARTICIPANT	\N	PRESENT	0
770840	768431	14195A	PARTICIPANT	\N	PRESENT	0
770847	768431	17779H	PARTICIPANT	\N	PRESENT	0
770858	768431	19591F	PARTICIPANT	\N	PRESENT	0
770856	768431	19657G	PARTICIPANT	\N	PRESENT	0
770857	768431	19683J	PARTICIPANT	\N	PRESENT	0
770859	768431	19553Y	PARTICIPANT	\N	PRESENT	0
770860	768431	11045K	PARTICIPANT	\N	PRESENT	0
770861	768431	01034P	PARTICIPANT	\N	PRESENT	0
770871	768431	14026U	PARTICIPANT	\N	PRESENT	0
770872	768433	20130U	PARTICIPANT	\N	PRESENT	0
770873	768433	20096L	PARTICIPANT	\N	PRESENT	0
770874	768433	19367Y	PARTICIPANT	\N	PRESENT	0
770875	768433	21064G	PARTICIPANT	\N	PRESENT	0
770876	768433	19760E	PARTICIPANT	\N	PRESENT	0
770877	768433	19713W	PARTICIPANT	\N	PRESENT	0
770924	768433	21045D	PARTICIPANT	\N	PRESENT	0
770879	768433	19723Y	PARTICIPANT	\N	PRESENT	0
770880	768433	21049H	PARTICIPANT	\N	PRESENT	0
770881	768433	19758L	PARTICIPANT	\N	PRESENT	0
770882	768433	19691J	PARTICIPANT	\N	PRESENT	0
770883	768433	20248J	PARTICIPANT	\N	PRESENT	0
770884	768433	21046E	PARTICIPANT	\N	PRESENT	0
770885	768433	17779H	PARTICIPANT	\N	PRESENT	0
776810	776809	08018U	PARTICIPANT	\N	PRESENT	0
770887	768433	14355X	PARTICIPANT	\N	PRESENT	0
770888	768433	21087P	PARTICIPANT	\N	PRESENT	0
770889	768433	14195A	PARTICIPANT	\N	PRESENT	0
770890	768433	20090E	PARTICIPANT	\N	PRESENT	0
770891	768433	18193Q	PARTICIPANT	\N	PRESENT	0
770892	768433	04092N	PARTICIPANT	\N	PRESENT	0
770893	768433	14213J	PARTICIPANT	\N	PRESENT	0
770894	768433	14217N	PARTICIPANT	\N	PRESENT	0
770895	768433	20140W	PARTICIPANT	\N	PRESENT	0
770896	768433	20148F	PARTICIPANT	\N	PRESENT	0
770897	768433	21039F	PARTICIPANT	\N	PRESENT	0
770898	768433	19703U	PARTICIPANT	\N	PRESENT	0
770899	768433	19679N	PARTICIPANT	\N	PRESENT	0
770900	768433	08061X	PARTICIPANT	\N	PRESENT	0
770901	768433	01034P	PARTICIPANT	\N	PRESENT	0
770902	768433	21097R	PARTICIPANT	\N	PRESENT	0
774627	769234	08009T	PARTICIPANT	\N	PRESENT	0
770904	768433	14281W	PARTICIPANT	\N	PRESENT	0
770905	768433	19657G	PARTICIPANT	\N	PRESENT	0
770906	768433	19798U	PARTICIPANT	\N	PRESENT	0
770907	768433	14071N	PRESIDENT	\N	PRESENT	0
770908	768433	11045K	PARTICIPANT	\N	PRESENT	0
770909	768433	21081H	PARTICIPANT	\N	PRESENT	0
770910	768433	19553Y	PARTICIPANT	\N	PRESENT	0
770911	768433	19591F	PARTICIPANT	\N	PRESENT	0
770912	768433	21094N	PARTICIPANT	\N	PRESENT	0
770913	768433	19683J	PARTICIPANT	\N	PRESENT	0
770914	768433	17965H	PARTICIPANT	\N	PRESENT	0
770915	768433	14042U	PARTICIPANT	\N	PRESENT	0
770916	768433	14026U	PARTICIPANT	\N	PRESENT	0
770917	768433	21071F	PARTICIPANT	\N	PRESENT	0
776811	776809	17229F	PARTICIPANT	\N	PRESENT	0
777622	777619	04047H	PARTICIPANT	\N	PRESENT	0
777623	777619	21043B	PARTICIPANT	\N	PRESENT	0
777624	777619	18231D	PARTICIPANT	\N	PRESENT	0
777626	777619	19111A	PARTICIPANT	\N	PRESENT	0
777631	777629	18231D	PARTICIPANT	\N	PRESENT	0
777628	777619	21076L	PARTICIPANT	\N	PRESENT	0
777630	777629	04047H	PARTICIPANT	\N	PRESENT	0
777632	777629	19111A	PARTICIPANT	\N	PRESENT	0
777633	777629	21076L	PARTICIPANT	\N	PRESENT	0
777634	777618	04047H	PARTICIPANT	\N	PRESENT	0
777635	777618	18231D	PARTICIPANT	\N	PRESENT	0
777636	777618	21076L	PARTICIPANT	\N	PRESENT	0
777702	775971	20138D	PARTICIPANT	\N	PRESENT	0
777704	775971	19621T	PARTICIPANT	\N	PRESENT	0
777706	775971	20124W	PARTICIPANT	\N	PRESENT	0
777707	775971	20180F	PARTICIPANT	\N	PRESENT	0
777708	775971	14123H	PARTICIPANT	\N	PRESENT	0
777709	775971	20056C	PARTICIPANT	\N	PRESENT	0
777710	775971	21058J	PARTICIPANT	\N	PRESENT	0
777711	775971	21055F	PARTICIPANT	\N	PRESENT	0
777712	775971	20026V	PARTICIPANT	\N	PRESENT	0
777713	775971	20264J	PARTICIPANT	\N	PRESENT	0
777714	775971	14109K	PARTICIPANT	\N	PRESENT	0
777715	775971	14030Q	PARTICIPANT	\N	PRESENT	0
777717	775971	19611R	PARTICIPANT	\N	PRESENT	0
777718	775971	19735D	PARTICIPANT	\N	PRESENT	0
777719	775971	19699S	PARTICIPANT	\N	PRESENT	0
777720	775971	20052X	PARTICIPANT	\N	PRESENT	0
777721	775971	19697Q	PARTICIPANT	\N	PRESENT	0
777722	775971	20102Q	PARTICIPANT	\N	PRESENT	0
777723	775971	19593H	PARTICIPANT	\N	PRESENT	0
777724	775971	19693L	PARTICIPANT	\N	PRESENT	0
777725	775971	20142Y	PARTICIPANT	\N	PRESENT	0
777726	775971	20132W	PARTICIPANT	\N	PRESENT	0
784035	783381	19399H	PARTICIPANT	\N	PRESENT	0
784036	783381	21053D	PARTICIPANT	\N	PRESENT	0
784037	783381	20028X	PARTICIPANT	\N	PRESENT	0
784178	783382	14259Y	PARTICIPANT	\N	PRESENT	0
784179	783382	20140W	PARTICIPANT	\N	PRESENT	0
784180	783382	14071N	PARTICIPANT	\N	PRESENT	0
784181	783382	19782L	PARTICIPANT	\N	PRESENT	0
784182	783382	17779H	PARTICIPANT	\N	PRESENT	0
784183	783382	19679N	PARTICIPANT	\N	PRESENT	0
784184	783382	14221J	PARTICIPANT	\N	PRESENT	0
784185	783382	14042U	PARTICIPANT	\N	PRESENT	0
784186	783382	21094N	PARTICIPANT	\N	PRESENT	0
784187	783382	21049H	PARTICIPANT	\N	PRESENT	0
784188	783382	19553Y	PARTICIPANT	\N	PRESENT	0
784189	783382	19387D	PARTICIPANT	\N	PRESENT	0
784190	783382	14107H	PARTICIPANT	\N	PRESENT	0
784191	783382	21040X	PARTICIPANT	\N	PRESENT	0
784192	783382	11072N	PARTICIPANT	\N	PRESENT	0
784193	783382	21057H	PARTICIPANT	\N	PRESENT	0
784194	783382	21056G	PARTICIPANT	\N	PRESENT	0
784195	783382	17965H	PARTICIPANT	\N	PRESENT	0
784196	783382	21082J	PARTICIPANT	\N	PRESENT	0
784197	783382	14121F	PARTICIPANT	\N	PRESENT	0
784198	783382	20070A	PARTICIPANT	\N	PRESENT	0
784199	783382	21048G	PARTICIPANT	\N	PRESENT	0
784200	783382	21041Y	PARTICIPANT	\N	PRESENT	0
784201	783382	14030Q	PARTICIPANT	\N	PRESENT	0
784202	783382	19745F	PARTICIPANT	\N	PRESENT	0
784203	783382	14205J	PARTICIPANT	\N	PRESENT	0
784204	783382	19335Q	PARTICIPANT	\N	PRESENT	0
784205	783382	19685L	PARTICIPANT	\N	PRESENT	0
784206	783382	20054A	PARTICIPANT	\N	PRESENT	0
784207	783382	19826F	PARTICIPANT	\N	PRESENT	0
784208	783382	19507S	PARTICIPANT	\N	PRESENT	0
795119	794896	19687N	PARTICIPANT	\N	PRESENT	0
795120	794896	20046A	PARTICIPANT	\N	PRESENT	0
795121	794896	14253S	PARTICIPANT	\N	PRESENT	0
795122	794896	08045X	PARTICIPANT	\N	PRESENT	0
795123	794896	20110Q	PARTICIPANT	\N	PRESENT	0
795124	794896	20136B	PARTICIPANT	\N	PRESENT	0
795125	794896	20142Y	PARTICIPANT	\N	PRESENT	0
795126	794896	20106U	PARTICIPANT	\N	PRESENT	0
795127	794896	20096L	PARTICIPANT	\N	PRESENT	0
795128	794896	14037X	PARTICIPANT	\N	PRESENT	0
795129	794896	11072N	PARTICIPANT	\N	PRESENT	0
795130	794896	08061X	PARTICIPANT	\N	PRESENT	0
795131	794896	20150Y	PARTICIPANT	\N	PRESENT	0
795132	794896	19301E	PARTICIPANT	\N	PRESENT	0
795133	794896	21068L	PARTICIPANT	\N	PRESENT	0
796135	796132	14121F	PARTICIPANT	\N	PRESENT	0
796136	796132	20116W	PARTICIPANT	\N	PRESENT	0
795136	794896	19447X	PARTICIPANT	\N	PRESENT	0
795137	794896	14038Y	PARTICIPANT	\N	PRESENT	0
796252	794850	14109K	PARTICIPANT	\N	EXCUSE	0
795139	794896	19723Y	PARTICIPANT	\N	PRESENT	0
796253	794850	20052X	PARTICIPANT	\N	EXCUSE	0
796254	794852	04070G	PARTICIPANT	\N	PRESENT	0
796255	794852	19699S	PARTICIPANT	\N	PRESENT	0
796256	794852	19533U	PARTICIPANT	\N	PRESENT	0
795144	794896	21063F	PARTICIPANT	\N	PRESENT	0
796257	794852	04033B	PARTICIPANT	\N	PRESENT	0
796258	794852	21058J	PARTICIPANT	\N	PRESENT	0
795147	794896	20068G	PARTICIPANT	\N	PRESENT	0
796259	794852	21059K	PARTICIPANT	\N	PRESENT	0
796260	794852	20102Q	PARTICIPANT	\N	PRESENT	0
796261	794852	14229S	PARTICIPANT	\N	PRESENT	0
795151	794896	17367Q	PARTICIPANT	\N	PRESENT	0
796262	794852	19954N	PARTICIPANT	\N	PRESENT	0
796263	794852	21032X	PARTICIPANT	\N	PRESENT	0
796264	794852	18395Y	PARTICIPANT	\N	PRESENT	0
796265	794852	20112S	PARTICIPANT	\N	PRESENT	0
796266	794852	21089R	PARTICIPANT	\N	PRESENT	0
796267	794852	21037D	PARTICIPANT	\N	PRESENT	0
796268	794852	20124W	PARTICIPANT	\N	PRESENT	0
796269	794852	20026V	PARTICIPANT	\N	PRESENT	0
796270	794852	19593H	PARTICIPANT	\N	PRESENT	0
796271	794852	20132W	PARTICIPANT	\N	PRESENT	0
796272	794852	20122U	PARTICIPANT	\N	PRESENT	0
796273	794852	14073Q	PARTICIPANT	\N	PRESENT	0
796274	794852	20138D	PARTICIPANT	\N	PRESENT	0
796275	794852	19611R	PRESIDENT	0	PRESENT	0
796276	794852	20142Y	PARTICIPANT	\N	PRESENT	0
796277	794852	20048C	PARTICIPANT	\N	PRESENT	0
796278	794852	20172F	PARTICIPANT	\N	PRESENT	0
796279	794852	14030Q	PARTICIPANT	\N	PRESENT	0
796280	794852	20058E	PARTICIPANT	\N	PRESENT	0
796281	794852	20056C	PARTICIPANT	\N	PRESENT	0
796282	794852	20180F	PARTICIPANT	\N	PRESENT	0
796283	794852	20264J	PARTICIPANT	\N	PRESENT	0
796284	794852	21063F	PARTICIPANT	\N	PRESENT	0
796285	794852	19735D	PARTICIPANT	\N	PRESENT	0
796286	794852	19057M	PARTICIPANT	\N	PRESENT	0
796287	794852	21074J	PARTICIPANT	\N	PRESENT	0
796288	794852	21077M	PARTICIPANT	\N	PRESENT	0
796289	794852	19621T	PARTICIPANT	\N	PRESENT	0
796290	794852	14021P	PARTICIPANT	\N	PRESENT	0
796291	794852	14109K	PARTICIPANT	\N	EXCUSE	0
795117	794896	11056N	PARTICIPANT	\N	PRESENT	0
795118	794896	19593H	PARTICIPANT	\N	PRESENT	0
796292	794852	20052X	PARTICIPANT	\N	EXCUSE	0
796295	794752	19798U	PARTICIPANT	\N	PRESENT	0
796296	794752	08060W	PARTICIPANT	\N	PRESENT	0
796297	794752	19679N	PARTICIPANT	\N	PRESENT	0
796298	794752	19331L	PARTICIPANT	\N	PRESENT	0
796299	794752	21039F	PARTICIPANT	\N	PRESENT	0
796300	794752	11065P	PARTICIPANT	\N	PRESENT	0
796301	794752	21051B	PARTICIPANT	\N	PRESENT	0
796302	794752	20032T	PARTICIPANT	\N	PRESENT	0
796303	794752	21053D	PARTICIPANT	\N	PRESENT	0
796304	794752	04092N	PARTICIPANT	\N	PRESENT	0
796305	794752	20040T	PARTICIPANT	\N	PRESENT	0
796306	794752	19691J	PARTICIPANT	\N	PRESENT	0
796307	794752	20046A	PARTICIPANT	\N	PRESENT	0
796308	794752	17229F	PARTICIPANT	\N	PRESENT	0
796309	794752	21047F	PARTICIPANT	\N	PRESENT	0
796310	794752	20068G	PARTICIPANT	\N	PRESENT	0
796311	794752	21068L	PARTICIPANT	\N	PRESENT	0
796312	794752	21070E	PARTICIPANT	\N	PRESENT	0
796313	794752	21081H	PARTICIPANT	\N	PRESENT	0
796314	794752	21082J	PARTICIPANT	\N	PRESENT	0
796315	794752	19701S	PARTICIPANT	\N	PRESENT	0
796316	794752	14355X	PARTICIPANT	\N	PRESENT	0
796317	794752	21035B	PARTICIPANT	\N	PRESENT	0
796318	794752	19569H	PARTICIPANT	\N	PRESENT	0
796319	794752	20076G	PARTICIPANT	\N	PRESENT	0
796320	794752	21042A	PARTICIPANT	\N	PRESENT	0
796321	794752	21045D	PARTICIPANT	\N	PRESENT	0
796322	794752	18193Q	PARTICIPANT	\N	PRESENT	0
796323	794752	14223L	PARTICIPANT	\N	PRESENT	0
796324	794752	21060C	PARTICIPANT	\N	PRESENT	0
796325	794752	21062E	PARTICIPANT	\N	PRESENT	0
796326	794752	21065H	PARTICIPANT	\N	PRESENT	0
796327	794752	18083K	PARTICIPANT	\N	PRESENT	0
796328	794752	14237S	PARTICIPANT	\N	PRESENT	0
796329	794752	21084L	PARTICIPANT	\N	PRESENT	0
796330	794752	20100N	PARTICIPANT	\N	PRESENT	0
796331	794752	19703U	PRESIDENT	0	PRESENT	0
796332	794752	05012A	PARTICIPANT	\N	PRESENT	0
796333	794752	20106U	PARTICIPANT	\N	PRESENT	0
796334	794752	14107H	PARTICIPANT	\N	PRESENT	0
796335	794752	21080G	PARTICIPANT	\N	PRESENT	0
796336	794752	14195A	PARTICIPANT	\N	PRESENT	0
796337	794752	14213J	PARTICIPANT	\N	PRESENT	0
796338	794752	19713W	PARTICIPANT	\N	PRESENT	0
796339	794752	14031R	PARTICIPANT	\N	PRESENT	0
796340	794752	20140W	PARTICIPANT	\N	PRESENT	0
796341	794752	11045K	PARTICIPANT	\N	PRESENT	0
796342	794752	08045X	PARTICIPANT	\N	PRESENT	0
796343	794752	19251M	PARTICIPANT	\N	PRESENT	0
796344	794752	20248J	PARTICIPANT	\N	PRESENT	0
796345	794752	19657G	PARTICIPANT	\N	PRESENT	0
796346	794752	19758L	PARTICIPANT	\N	PRESENT	0
796347	794752	19760E	PARTICIPANT	\N	PRESENT	0
796348	794752	20130U	PARTICIPANT	\N	EXCUSE	0
796349	794752	21046E	PARTICIPANT	\N	EXCUSE	0
796350	794852	19693L	PARTICIPANT	\N	PRESENT	0
796351	794850	19693L	PARTICIPANT	\N	PRESENT	0
796355	794752	14026U	PARTICIPANT	\N	PRESENT	0
796356	794752	19723Y	PARTICIPANT	\N	PRESENT	0
796357	796132	11053K	PARTICIPANT	\N	PRESENT	0
796358	796085	19383Y	PARTICIPANT	\N	PRESENT	0
796359	796085	20088L	PARTICIPANT	\N	PRESENT	0
796360	796085	19768N	PARTICIPANT	\N	PRESENT	0
796361	796085	20092G	PARTICIPANT	\N	PRESENT	0
796362	796085	19782L	PARTICIPANT	\N	PRESENT	0
796363	796085	14357A	PARTICIPANT	\N	PRESENT	0
796364	796085	20078J	PARTICIPANT	\N	PRESENT	0
796365	796085	19413M	PARTICIPANT	\N	PRESENT	0
796366	796085	20082E	PARTICIPANT	\N	PRESENT	0
796367	796085	14221J	PARTICIPANT	\N	PRESENT	0
796368	796085	19631V	PARTICIPANT	\N	PRESENT	0
796369	796085	08015R	PARTICIPANT	\N	PRESENT	0
796370	796085	19575F	PARTICIPANT	\N	PRESENT	0
796371	796085	20018V	PARTICIPANT	\N	PRESENT	0
796372	796085	08028W	PARTICIPANT	\N	PRESENT	0
796373	796085	19563B	PARTICIPANT	\N	PRESENT	0
796374	796085	21050A	PARTICIPANT	\N	PRESENT	0
796375	796085	21096Q	PARTICIPANT	\N	PRESENT	0
796376	796085	20028X	PARTICIPANT	\N	PRESENT	0
796377	796085	14329V	PARTICIPANT	\N	PRESENT	0
796378	796085	14038Y	PARTICIPANT	\N	PRESENT	0
796379	796085	20030R	PARTICIPANT	\N	PRESENT	0
796380	796085	20034V	PARTICIPANT	\N	PRESENT	0
796381	796085	21054E	PARTICIPANT	\N	PRESENT	0
796382	796085	21075K	PARTICIPANT	\N	PRESENT	0
796383	796085	20038A	PARTICIPANT	\N	PRESENT	0
796384	796085	14187A	PRESIDENT	0	PRESENT	0
796385	796085	21083K	PARTICIPANT	\N	PRESENT	0
796386	796085	20144B	PARTICIPANT	\N	PRESENT	0
796387	796085	21086N	PARTICIPANT	\N	PRESENT	0
796388	796085	19695N	PARTICIPANT	\N	PRESENT	0
796389	796085	21092L	PARTICIPANT	\N	PRESENT	0
796390	796085	21093M	PARTICIPANT	\N	PRESENT	0
796391	796085	14033T	PARTICIPANT	\N	PRESENT	0
796392	796085	11090Q	PARTICIPANT	\N	PRESENT	0
769140	765410	14042U	PARTICIPANT	\N	PRESENT	0
769141	765410	19758L	PARTICIPANT	\N	PRESENT	0
769183	765410	20052X	PARTICIPANT	\N	PRESENT	0
769143	765410	20130U	PARTICIPANT	\N	PRESENT	0
769184	765410	21089R	PARTICIPANT	\N	PRESENT	0
769182	765410	21071F	PARTICIPANT	\N	PRESENT	0
769146	765410	19683J	PARTICIPANT	\N	PRESENT	0
769147	765410	17779H	PARTICIPANT	\N	PRESENT	0
769148	765410	20062A	PARTICIPANT	\N	PRESENT	0
769149	765410	19693L	PARTICIPANT	\N	PRESENT	0
769150	765410	21087P	PARTICIPANT	\N	PRESENT	0
769151	765410	19301E	PARTICIPANT	\N	PRESENT	0
769152	765410	14281W	PARTICIPANT	\N	PRESENT	0
769153	765410	18193Q	PARTICIPANT	\N	PRESENT	0
769154	765410	19569H	PARTICIPANT	\N	PRESENT	0
769155	765410	19691J	PARTICIPANT	\N	PRESENT	0
769156	765410	14069U	PARTICIPANT	\N	PRESENT	0
769157	765410	14026U	PARTICIPANT	\N	PRESENT	0
769158	765410	20090E	PARTICIPANT	\N	PRESENT	0
769159	765410	21081H	PARTICIPANT	\N	PRESENT	0
769160	765410	19657G	PARTICIPANT	\N	PRESENT	0
769161	765410	19713W	PARTICIPANT	\N	PRESENT	0
769162	765410	19798U	PARTICIPANT	\N	PRESENT	0
769163	765410	18231D	PARTICIPANT	\N	PRESENT	0
769164	765410	21045D	PARTICIPANT	\N	PRESENT	0
769165	765410	04092N	PARTICIPANT	\N	PRESENT	0
769166	765410	21037D	PARTICIPANT	\N	PRESENT	0
769167	765410	14217N	PARTICIPANT	\N	PRESENT	0
769168	765410	21090J	PARTICIPANT	\N	PRESENT	0
769169	765410	19711U	PARTICIPANT	\N	PRESENT	0
769170	765410	17965H	PARTICIPANT	\N	PRESENT	0
769171	765410	21094N	PARTICIPANT	\N	PRESENT	0
769172	765410	19553Y	PARTICIPANT	\N	PRESENT	0
769173	765410	20034V	PARTICIPANT	\N	PRESENT	0
769174	765410	20132W	PARTICIPANT	\N	PRESENT	0
769175	765410	01034P	PARTICIPANT	\N	PRESENT	0
769176	765410	19703U	PARTICIPANT	\N	PRESENT	0
769177	765410	20148F	PARTICIPANT	\N	PRESENT	0
769178	765410	19531S	PARTICIPANT	\N	PRESENT	0
769179	765410	21097R	PARTICIPANT	\N	PRESENT	0
769180	765410	21075K	PARTICIPANT	\N	PRESENT	0
769138	765410	19479G	PARTICIPANT	\N	PRESENT	0
769139	765410	14071N	PARTICIPANT	\N	PRESENT	0
769181	765410	21049H	PARTICIPANT	\N	PRESENT	0
769185	765410	19647E	PARTICIPANT	\N	PRESENT	0
769186	765410	14215L	PARTICIPANT	\N	PRESENT	0
769187	765410	19591F	PARTICIPANT	\N	PRESENT	0
769188	765410	14213J	PARTICIPANT	\N	PRESENT	0
769189	765410	21079P	PARTICIPANT	\N	PRESENT	0
769268	769267	20034V	PARTICIPANT	\N	PRESENT	0
769633	769622	14073Q	PARTICIPANT	\N	PRESENT	0
769634	769618	21089R	PARTICIPANT	\N	PRESENT	0
769635	769619	20114U	PARTICIPANT	\N	PRESENT	0
773183	772594	19593H	PARTICIPANT	\N	PRESENT	0
773157	773155	19711U	PARTICIPANT	\N	PRESENT	0
773189	772594	11040E	PARTICIPANT	\N	PRESENT	0
773159	773155	20080C	PARTICIPANT	\N	PRESENT	0
773160	773155	20044X	PARTICIPANT	\N	PRESENT	0
773161	773155	19671E	PARTICIPANT	\N	PRESENT	0
773162	773155	14173T	PARTICIPANT	\N	PRESENT	0
773163	773155	20062A	PARTICIPANT	\N	PRESENT	0
773184	772594	19619A	PARTICIPANT	\N	PRESENT	0
773165	773155	21079P	PARTICIPANT	\N	PRESENT	0
773166	773155	19741B	PARTICIPANT	\N	PRESENT	0
773185	772594	21079P	PARTICIPANT	\N	PRESENT	0
773168	773155	21090J	PARTICIPANT	\N	PRESENT	0
773169	773155	19762G	PARTICIPANT	\N	PRESENT	0
773186	772594	07004J	PARTICIPANT	\N	PRESENT	0
773171	773155	20086J	PARTICIPANT	\N	PRESENT	0
773172	773155	11048N	PARTICIPANT	\N	PRESENT	0
773173	773155	14225N	PRESIDENT	0	PRESENT	0
773174	773155	19573D	PARTICIPANT	\N	PRESENT	0
773175	773155	20070A	PARTICIPANT	\N	PRESENT	0
773176	773155	07029T	PARTICIPANT	\N	PRESENT	0
773177	773155	14083S	PARTICIPANT	\N	PRESENT	0
773187	772594	11048N	PARTICIPANT	\N	PRESENT	0
773188	772594	19621T	PARTICIPANT	\N	PRESENT	0
773190	772594	21088Q	PARTICIPANT	\N	PRESENT	0
773191	772594	21075K	PARTICIPANT	\N	PRESENT	0
773192	772594	19295A	PARTICIPANT	\N	PRESENT	0
773193	772594	20070A	PARTICIPANT	\N	PRESENT	0
773194	772594	20100N	PARTICIPANT	\N	PRESENT	0
773195	772594	21033Y	PARTICIPANT	\N	PRESENT	0
773196	772594	19693L	PARTICIPANT	\N	PRESENT	0
773197	772594	20080C	PARTICIPANT	\N	PRESENT	0
773198	772594	14083S	PARTICIPANT	\N	PRESENT	0
773199	772594	19711U	PARTICIPANT	\N	PRESENT	0
773200	772594	20086J	PARTICIPANT	\N	PRESENT	0
773201	772594	21048G	PARTICIPANT	\N	PRESENT	0
773202	772594	20062A	PARTICIPANT	\N	PRESENT	0
773203	772594	07029T	PARTICIPANT	\N	PRESENT	0
773204	772594	20044X	PARTICIPANT	\N	PRESENT	0
773205	772594	14173T	PARTICIPANT	\N	PRESENT	0
773206	772594	21090J	PARTICIPANT	\N	PRESENT	0
773207	772594	21030V	PARTICIPANT	\N	PRESENT	0
773208	772594	21041Y	PARTICIPANT	\N	PRESENT	0
773209	772594	11074Q	PARTICIPANT	\N	PRESENT	0
773210	772594	14225N	PARTICIPANT	\N	PRESENT	0
773211	772594	99004R	PARTICIPANT	\N	PRESENT	0
773212	772594	20032T	PARTICIPANT	\N	PRESENT	0
773213	772594	21096Q	PARTICIPANT	\N	PRESENT	0
773214	772594	20286Q	PARTICIPANT	\N	PRESENT	0
773215	772594	21074J	PARTICIPANT	\N	PRESENT	0
773216	772594	19573D	PARTICIPANT	\N	PRESENT	0
773217	772594	20058E	PARTICIPANT	\N	PRESENT	0
773218	772594	14107H	PARTICIPANT	\N	PRESENT	0
773219	772594	12016W	PARTICIPANT	\N	PRESENT	0
773220	772594	21069M	PARTICIPANT	\N	PRESENT	0
773221	772594	05008E	PARTICIPANT	\N	PRESENT	0
773222	772594	11070L	PARTICIPANT	\N	PRESENT	0
773223	772594	14189C	PARTICIPANT	\N	PRESENT	0
773224	772594	14219Q	PARTICIPANT	\N	PRESENT	0
773225	772594	14253S	PARTICIPANT	\N	PRESENT	0
773226	772594	14021P	PARTICIPANT	\N	PRESENT	0
773227	772594	20092G	PARTICIPANT	\N	PRESENT	0
773228	772594	14187A	PARTICIPANT	\N	PRESENT	0
773229	772594	20134Y	PARTICIPANT	\N	PRESENT	0
773231	772594	19647E	PARTICIPANT	\N	PRESENT	0
773232	772594	20036X	PARTICIPANT	\N	PRESENT	0
773237	772594	21037D	PARTICIPANT	\N	PRESENT	0
773240	772594	08011M	PARTICIPANT	\N	PRESENT	0
773245	772594	20094J	PARTICIPANT	\N	PRESENT	0
773253	772594	14257W	PARTICIPANT	\N	PRESENT	0
773263	772594	14069U	PARTICIPANT	\N	PRESENT	0
773265	772594	19687N	PARTICIPANT	\N	PRESENT	0
773266	772594	21073H	PARTICIPANT	\N	PRESENT	0
773267	772594	20130U	PARTICIPANT	\N	PRESENT	0
773268	772594	14211G	PARTICIPANT	\N	PRESENT	0
773269	772594	20088L	PARTICIPANT	\N	PRESENT	0
773323	772595	14111D	PARTICIPANT	\N	PRESENT	0
773325	772595	21069M	PARTICIPANT	\N	PRESENT	0
773326	772595	19711U	PARTICIPANT	\N	PRESENT	0
773327	772595	21090J	PARTICIPANT	\N	PRESENT	0
773328	772595	19667J	PARTICIPANT	\N	PRESENT	0
773329	772595	14257W	PARTICIPANT	\N	PRESENT	0
773330	772595	11040E	PARTICIPANT	\N	PRESENT	0
773331	772595	14225N	PARTICIPANT	\N	PRESENT	0
773333	772595	19683J	PARTICIPANT	\N	PRESENT	0
773334	772595	20092G	PARTICIPANT	\N	PRESENT	0
773335	772595	19691J	PARTICIPANT	\N	PRESENT	0
773336	772595	20100N	PARTICIPANT	\N	PRESENT	0
773337	772595	20058E	PARTICIPANT	\N	PRESENT	0
773338	772595	14327T	PARTICIPANT	\N	PRESENT	0
773339	772595	11065P	PARTICIPANT	\N	PRESENT	0
773340	772595	20044X	PARTICIPANT	\N	PRESENT	0
773341	772595	11090Q	PARTICIPANT	\N	PRESENT	0
773342	772595	21041Y	PARTICIPANT	\N	PRESENT	0
773343	772595	19575F	PARTICIPANT	\N	PRESENT	0
773344	772595	21048G	PARTICIPANT	\N	PRESENT	0
773345	772595	20062A	PARTICIPANT	\N	PRESENT	0
773346	772595	14083S	PARTICIPANT	\N	PRESENT	0
773347	772595	05012A	PARTICIPANT	\N	PRESENT	0
773348	772595	20070A	PARTICIPANT	\N	PRESENT	0
773349	772595	19687N	PARTICIPANT	\N	PRESENT	0
773350	772595	21055F	PARTICIPANT	\N	PRESENT	0
773351	772595	19695N	PARTICIPANT	\N	PRESENT	0
773352	772595	11072N	PARTICIPANT	\N	PRESENT	0
773353	772595	21079P	PARTICIPANT	\N	PRESENT	0
773354	772595	20088L	PARTICIPANT	\N	PRESENT	0
773355	772595	19621T	PARTICIPANT	\N	PRESENT	0
773356	772595	14219Q	PARTICIPANT	\N	PRESENT	0
793226	791391	14053L	PARTICIPANT	\N	PRESENT	0
793227	791391	14231L	PARTICIPANT	\N	PRESENT	0
793228	791391	19629C	PARTICIPANT	\N	PRESENT	0
793229	791391	20116W	PARTICIPANT	\N	PRESENT	0
793230	791391	18395Y	PARTICIPANT	\N	PRESENT	0
793231	791391	19349W	PARTICIPANT	\N	PRESENT	0
793232	791391	19723Y	PARTICIPANT	\N	PRESENT	0
793318	791423	17779H	PARTICIPANT	\N	PRESENT	0
793319	791423	17965H	PARTICIPANT	\N	PRESENT	0
793320	791423	14281W	PARTICIPANT	\N	PRESENT	0
793321	791423	21056G	PARTICIPANT	\N	PRESENT	0
793322	791423	21079P	PARTICIPANT	\N	PRESENT	0
793323	791423	21087P	PARTICIPANT	\N	PRESENT	0
793324	791423	21046E	PARTICIPANT	\N	PRESENT	0
793325	791423	19629C	PARTICIPANT	\N	PRESENT	0
793326	791423	18193Q	PARTICIPANT	\N	PRESENT	0
793327	791423	14021P	PARTICIPANT	\N	PRESENT	0
793328	791423	21097R	PARTICIPANT	\N	PRESENT	0
793329	791423	20066E	PARTICIPANT	\N	PRESENT	0
793330	791423	19723Y	PARTICIPANT	\N	PRESENT	0
793331	791423	21039F	PARTICIPANT	\N	PRESENT	0
793332	791423	14033T	PARTICIPANT	\N	PRESENT	0
793333	791423	20140W	PARTICIPANT	\N	PRESENT	0
793334	791423	20096L	PARTICIPANT	\N	PRESENT	0
793335	791423	19657G	PARTICIPANT	\N	PRESENT	0
793336	791423	21081H	PARTICIPANT	\N	PRESENT	0
793337	791423	14147R	PARTICIPANT	\N	PRESENT	0
793338	791423	20090E	PARTICIPANT	\N	PRESENT	0
793339	791423	14217N	PARTICIPANT	\N	PRESENT	0
793340	791423	14213J	PARTICIPANT	\N	PRESENT	0
793341	791423	14026U	PARTICIPANT	\N	PRESENT	0
793342	791423	21058J	PARTICIPANT	\N	PRESENT	0
793343	791423	14042U	PARTICIPANT	\N	PRESENT	0
793344	791423	21064G	PARTICIPANT	\N	PRESENT	0
793345	791423	20148F	PARTICIPANT	\N	PRESENT	0
793346	791423	20062A	PARTICIPANT	\N	PRESENT	0
793347	791423	04092N	PARTICIPANT	\N	PRESENT	0
793348	791423	20034V	PARTICIPANT	\N	PRESENT	0
793349	791423	21051B	PARTICIPANT	\N	PRESENT	0
793350	791423	14207L	PARTICIPANT	\N	PRESENT	0
793351	791423	21045D	PARTICIPANT	\N	PRESENT	0
793352	791423	19758L	PARTICIPANT	\N	PRESENT	0
793353	791423	19569H	PARTICIPANT	\N	PRESENT	0
793354	791423	19760E	PARTICIPANT	\N	PRESENT	0
793355	791423	19820Y	PARTICIPANT	\N	PRESENT	0
793356	791423	21049H	PARTICIPANT	\N	PRESENT	0
793357	791423	14071N	PARTICIPANT	\N	PRESENT	0
793358	791423	19691J	PARTICIPANT	\N	PRESENT	0
793359	791423	19703U	PARTICIPANT	\N	PRESENT	0
793360	791423	21082J	PARTICIPANT	\N	PRESENT	0
793361	791423	14069U	PARTICIPANT	\N	PRESENT	0
793362	791423	20136B	PARTICIPANT	\N	PRESENT	0
793363	791423	19383Y	PARTICIPANT	\N	PRESENT	0
793364	791423	19768N	PARTICIPANT	\N	PRESENT	0
793365	791423	18083K	PARTICIPANT	\N	PRESENT	0
793366	791423	21094N	PARTICIPANT	\N	PRESENT	0
793367	791423	20048C	PARTICIPANT	\N	PRESENT	0
793368	791423	20058E	PARTICIPANT	\N	PRESENT	0
793442	793378	20056C	PARTICIPANT	\N	PRESENT	0
793445	793378	14147R	PARTICIPANT	\N	PRESENT	0
794002	793370	21037D	PARTICIPANT	\N	PRESENT	0
794003	793370	14109K	PARTICIPANT	\N	EXCUSE	0
794527	791395	14259Y	PARTICIPANT	\N	PRESENT	0
794552	791395	21056G	PARTICIPANT	\N	PRESENT	0
794553	791395	21093M	PARTICIPANT	\N	PRESENT	0
794554	791395	20122U	PARTICIPANT	\N	PRESENT	0
794555	791395	21055F	PARTICIPANT	\N	PRESENT	0
794556	791395	20136B	PARTICIPANT	\N	PRESENT	0
794557	791395	20098N	PARTICIPANT	\N	PRESENT	0
793295	791423	11090Q	PARTICIPANT	\N	PRESENT	0
793317	791423	14215L	PARTICIPANT	\N	PRESENT	0
794559	791395	21077M	PARTICIPANT	\N	PRESENT	0
794561	791395	14073Q	PARTICIPANT	\N	PRESENT	0
794563	791395	14069U	PARTICIPANT	\N	PRESENT	0
794591	791395	21073H	PARTICIPANT	\N	PRESENT	0
794680	794679	14053L	PARTICIPANT	\N	PRESENT	0
794683	794682	21057H	PARTICIPANT	\N	PRESENT	0
794684	794682	19111A	PARTICIPANT	\N	PRESENT	0
794685	794682	20120S	PARTICIPANT	\N	PRESENT	0
794686	794682	14251Q	PARTICIPANT	\N	PRESENT	0
794687	794682	14147R	PARTICIPANT	\N	PRESENT	0
794688	794682	19745F	PARTICIPANT	\N	PRESENT	0
794689	794682	19713W	PARTICIPANT	\N	PRESENT	0
794690	794682	21051B	PARTICIPANT	\N	PRESENT	0
794691	794682	21087P	PARTICIPANT	\N	PRESENT	0
794692	794682	21059K	PARTICIPANT	\N	PRESENT	0
794693	794682	20062A	PARTICIPANT	\N	PRESENT	0
794758	794757	20094J	PARTICIPANT	\N	PRESENT	0
794781	793593	21089R	PARTICIPANT	\N	PRESENT	0
794782	793593	20180F	PARTICIPANT	\N	PRESENT	0
794783	793593	21071F	PARTICIPANT	\N	PRESENT	0
794872	794062	14111D	PARTICIPANT	\N	PRESENT	0
794873	794062	12028B	PARTICIPANT	\N	PRESENT	0
794890	794062	19399H	PARTICIPANT	\N	PRESENT	0
794875	794062	20062A	PARTICIPANT	\N	PRESENT	0
794876	794062	19768N	PARTICIPANT	\N	PRESENT	0
794877	794062	20086J	PARTICIPANT	\N	PRESENT	0
794891	794062	14038Y	PARTICIPANT	\N	PRESENT	0
794879	794062	20090E	PARTICIPANT	\N	PRESENT	0
794880	794062	20082E	PARTICIPANT	\N	PRESENT	0
794881	794062	21059K	PARTICIPANT	\N	PRESENT	0
794882	794062	14331P	PARTICIPANT	\N	PRESENT	0
794883	794062	19782L	PARTICIPANT	\N	PRESENT	0
794884	794062	21079P	PARTICIPANT	\N	PRESENT	0
794885	794062	14031R	PARTICIPANT	\N	PRESENT	0
794886	794062	21096Q	PARTICIPANT	\N	PRESENT	0
794887	794062	05012A	PARTICIPANT	\N	PRESENT	0
794888	794062	20084G	PARTICIPANT	\N	PRESENT	0
793187	793065	19575F	PARTICIPANT	\N	PRESENT	0
793188	793065	20018V	PARTICIPANT	\N	PRESENT	0
793189	793065	08028W	PARTICIPANT	\N	PRESENT	0
793190	793065	21050A	PARTICIPANT	\N	PRESENT	0
793191	793065	21096Q	PARTICIPANT	\N	PRESENT	0
793192	793065	14329V	PARTICIPANT	\N	PRESENT	0
793193	793065	14038Y	PARTICIPANT	\N	PRESENT	0
793194	793065	20030R	PARTICIPANT	\N	PRESENT	0
793195	793065	21054E	PARTICIPANT	\N	PRESENT	0
793196	793065	20034V	PARTICIPANT	\N	PRESENT	0
793197	793065	21075K	PARTICIPANT	\N	PRESENT	0
793198	793065	20038A	PARTICIPANT	\N	PRESENT	0
793199	793065	14187A	PRESIDENT	0	PRESENT	0
793200	793065	21083K	PARTICIPANT	\N	PRESENT	0
793201	793065	20144B	PARTICIPANT	\N	PRESENT	0
793202	793065	21086N	PARTICIPANT	\N	PRESENT	0
793203	793065	21092L	PARTICIPANT	\N	PRESENT	0
793204	793065	19695N	PARTICIPANT	\N	PRESENT	0
793205	793065	14033T	PARTICIPANT	\N	PRESENT	0
793206	793065	11090Q	PARTICIPANT	\N	PRESENT	0
793207	793065	21033Y	PARTICIPANT	\N	PRESENT	0
793208	793065	20054A	PARTICIPANT	\N	PRESENT	0
793209	793065	14205J	PARTICIPANT	\N	PRESENT	0
793210	793065	20066E	PARTICIPANT	\N	PRESENT	0
793211	793065	21066J	PARTICIPANT	\N	PRESENT	0
793212	793065	20286Q	PARTICIPANT	\N	PRESENT	0
793213	793065	14207L	PARTICIPANT	\N	PRESENT	0
793214	793065	14257W	PARTICIPANT	\N	PRESENT	0
793215	793065	20084G	PARTICIPANT	\N	PRESENT	0
793216	793065	20060X	PARTICIPANT	\N	EXCUSE	0
793217	793065	21093M	PARTICIPANT	\N	EXCUSE	0
793225	791391	19399H	PARTICIPANT	\N	PRESENT	0
794889	794062	21029D	PARTICIPANT	\N	PRESENT	0
794892	794062	08073C	PARTICIPANT	\N	PRESENT	0
794893	794062	21065H	PARTICIPANT	\N	PRESENT	0
794894	794062	14189C	PARTICIPANT	\N	PRESENT	0
794897	794062	20054A	PARTICIPANT	\N	PRESENT	0
794898	794062	21043B	PARTICIPANT	\N	PRESENT	0
794899	794062	19820Y	PARTICIPANT	\N	PRESENT	0
794900	794062	21070E	PARTICIPANT	\N	PRESENT	0
794905	794062	20026V	PARTICIPANT	\N	PRESENT	0
794912	794062	21068L	PARTICIPANT	\N	PRESENT	0
794923	794062	20056C	PARTICIPANT	\N	PRESENT	0
794924	794062	19533U	PARTICIPANT	\N	PRESENT	0
794927	794062	98022P	PARTICIPANT	\N	PRESENT	0
794930	794062	08060W	PARTICIPANT	\N	PRESENT	0
794931	794062	20092G	PARTICIPANT	\N	PRESENT	0
794932	794062	20146D	PARTICIPANT	\N	PRESENT	0
794933	794062	20142Y	PARTICIPANT	\N	PRESENT	0
794934	794062	20120S	PARTICIPANT	\N	PRESENT	0
794935	794062	19545Y	PARTICIPANT	\N	PRESENT	0
794936	794062	19725B	PARTICIPANT	\N	PRESENT	0
794937	794062	14107H	PARTICIPANT	\N	PRESENT	0
769458	769457	14193X	PARTICIPANT	\N	PRESENT	0
769459	769457	04042C	PARTICIPANT	\N	PRESENT	0
769460	769457	14249W	PARTICIPANT	\N	PRESENT	0
769461	769457	11027H	PARTICIPANT	\N	PRESENT	0
769462	769457	19421M	PARTICIPANT	\N	PRESENT	0
769463	769457	19669L	PARTICIPANT	\N	PRESENT	0
769464	769457	11064N	PARTICIPANT	\N	PRESENT	0
769465	769457	19709B	PARTICIPANT	\N	PRESENT	0
769503	769454	19723Y	PARTICIPANT	\N	PRESENT	0
769504	769453	19723Y	PARTICIPANT	\N	PRESENT	0
769505	769456	19723Y	PARTICIPANT	\N	PRESENT	0
775834	772603	14225N	PARTICIPANT	\N	PRESENT	0
775835	772603	20032T	PARTICIPANT	\N	PRESENT	0
775836	772603	21071F	PARTICIPANT	\N	PRESENT	0
775837	772603	19667J	PARTICIPANT	\N	PRESENT	0
775838	772603	20116W	PARTICIPANT	\N	PRESENT	0
775839	772603	14030Q	PARTICIPANT	\N	PRESENT	0
775840	772603	21043B	PARTICIPANT	\N	PRESENT	0
775841	772603	11040E	PARTICIPANT	\N	PRESENT	0
775842	772603	20080C	PARTICIPANT	\N	PRESENT	0
775843	772603	21089R	PARTICIPANT	\N	PRESENT	0
775844	772603	19758L	PARTICIPANT	\N	PRESENT	0
775845	772603	20090E	PARTICIPANT	\N	PRESENT	0
775846	772603	21045D	PARTICIPANT	\N	PRESENT	0
775847	772603	14083S	PARTICIPANT	\N	PRESENT	0
775848	772603	19545Y	PARTICIPANT	\N	PRESENT	0
775849	772603	21090J	PARTICIPANT	\N	PRESENT	0
775850	772603	14267Y	PARTICIPANT	\N	PRESENT	0
775851	772603	21072G	PARTICIPANT	\N	PRESENT	0
775852	772603	21034A	PARTICIPANT	\N	PRESENT	0
775853	772603	20070A	PARTICIPANT	\N	PRESENT	0
775854	772603	19693L	PARTICIPANT	\N	PRESENT	0
775855	772603	14327T	PARTICIPANT	\N	PRESENT	0
775856	772603	20134Y	PARTICIPANT	\N	PRESENT	0
775857	772603	07033P	PARTICIPANT	\N	PRESENT	0
775858	772603	20074E	PARTICIPANT	\N	PRESENT	0
775859	772603	14151M	PARTICIPANT	\N	PRESENT	0
775860	772603	21074J	PARTICIPANT	\N	PRESENT	0
775861	772603	11074Q	PARTICIPANT	\N	PRESENT	0
775862	772603	21062E	PARTICIPANT	\N	PRESENT	0
775863	772603	20132W	PARTICIPANT	\N	PRESENT	0
775864	772603	21033Y	PARTICIPANT	\N	PRESENT	0
775865	772603	20172F	PARTICIPANT	\N	PRESENT	0
775866	772603	20180F	PARTICIPANT	\N	PRESENT	0
775867	772603	07004J	PARTICIPANT	\N	PRESENT	0
775868	772603	14033T	PARTICIPANT	\N	PRESENT	0
775869	772603	14123H	PARTICIPANT	\N	PRESENT	0
775870	772603	19399H	PARTICIPANT	\N	PRESENT	0
775871	772603	11048N	PARTICIPANT	\N	PRESENT	0
775872	772603	21093M	PARTICIPANT	\N	PRESENT	0
775873	772603	19683J	PARTICIPANT	\N	PRESENT	0
775874	772603	14021P	PARTICIPANT	\N	PRESENT	0
775875	772603	99004R	PARTICIPANT	\N	PRESENT	0
775876	772603	21081H	PARTICIPANT	\N	PRESENT	0
775877	772603	20126Y	PARTICIPANT	\N	PRESENT	0
775878	772603	19611R	PARTICIPANT	\N	PRESENT	0
775879	772603	20102Q	PARTICIPANT	\N	PRESENT	0
775880	772603	07029T	PARTICIPANT	\N	PRESENT	0
775881	772603	21078N	PARTICIPANT	\N	PRESENT	0
775882	772603	19711U	PARTICIPANT	\N	PRESENT	0
775883	772603	08010L	PARTICIPANT	\N	PRESENT	0
775884	772603	14037X	PARTICIPANT	\N	PRESENT	0
775885	772603	21054E	PARTICIPANT	\N	PRESENT	0
775886	772603	20142Y	PARTICIPANT	\N	PRESENT	0
775887	772603	21075K	PARTICIPANT	\N	PRESENT	0
775888	772603	19826F	PARTICIPANT	\N	PRESENT	0
775889	772603	21040X	PARTICIPANT	\N	PRESENT	0
775890	772603	19335Q	PARTICIPANT	\N	PRESENT	0
775891	772603	14109K	PARTICIPANT	\N	PRESENT	0
775892	772603	14257W	PARTICIPANT	\N	PRESENT	0
775893	772603	14071N	PARTICIPANT	\N	PRESENT	0
775894	772603	21038E	PARTICIPANT	\N	PRESENT	0
775895	772603	21037D	PARTICIPANT	\N	PRESENT	0
775896	772603	19593H	PARTICIPANT	\N	PRESENT	0
775897	772603	19573D	PARTICIPANT	\N	PRESENT	0
775898	772603	20050V	PARTICIPANT	\N	PRESENT	0
775899	772603	21055F	PARTICIPANT	\N	PRESENT	0
775900	772603	21053D	PARTICIPANT	\N	PRESENT	0
775901	772603	20130U	PARTICIPANT	\N	PRESENT	0
775902	772603	19349W	PARTICIPANT	\N	PRESENT	0
775903	772603	14331P	PARTICIPANT	\N	PRESENT	0
775904	772603	10015M	PARTICIPANT	\N	PRESENT	0
775905	772603	04033B	PARTICIPANT	\N	PRESENT	0
775906	772603	21068L	PARTICIPANT	\N	PRESENT	0
775907	772603	19798U	PARTICIPANT	\N	PRESENT	0
775908	772603	14229S	PARTICIPANT	\N	PRESENT	0
775909	772603	21056G	PARTICIPANT	\N	PRESENT	0
775910	772603	11043H	PARTICIPANT	\N	PRESENT	0
775911	772603	19687N	PARTICIPANT	\N	PRESENT	0
775912	772603	21079P	PARTICIPANT	\N	PRESENT	0
775913	772603	01058X	PARTICIPANT	\N	PRESENT	0
775914	772603	20062A	PARTICIPANT	\N	PRESENT	0
775915	772603	20084G	PARTICIPANT	\N	PRESENT	0
775916	772603	21069M	PARTICIPANT	\N	PRESENT	0
775917	772603	20046A	PARTICIPANT	\N	PRESENT	0
775918	772603	20026V	PARTICIPANT	\N	PRESENT	0
775919	772603	14173T	PARTICIPANT	\N	PRESENT	0
775920	772603	21076L	PARTICIPANT	\N	PRESENT	0
775921	772603	21082J	PARTICIPANT	\N	PRESENT	0
776822	776821	19711U	PARTICIPANT	\N	PRESENT	0
776823	776821	21079P	PARTICIPANT	\N	PRESENT	0
776824	776821	19573D	PARTICIPANT	\N	PRESENT	0
776825	776821	11053K	PARTICIPANT	\N	PRESENT	0
776826	776821	21090J	PARTICIPANT	\N	PRESENT	0
776827	776821	20094J	PARTICIPANT	\N	PRESENT	0
776828	776821	20044X	PARTICIPANT	\N	PRESENT	0
776829	776821	21072G	PARTICIPANT	\N	PRESENT	0
776830	776821	14225N	PRESIDENT	0	PRESENT	0
776831	776821	11070L	PARTICIPANT	\N	PRESENT	0
776832	776542	19301E	PARTICIPANT	\N	PRESENT	0
776833	776542	21072G	PARTICIPANT	\N	PRESENT	0
776834	776542	14089Y	PARTICIPANT	\N	PRESENT	0
776836	776542	21040X	PARTICIPANT	\N	PRESENT	0
776837	776542	19693L	PARTICIPANT	\N	PRESENT	0
776838	776542	20050V	PARTICIPANT	\N	PRESENT	0
776839	776542	20110Q	PARTICIPANT	\N	PRESENT	0
776840	776542	20136B	PARTICIPANT	\N	PRESENT	0
776841	776542	18231D	PARTICIPANT	\N	PRESENT	0
776842	776542	21033Y	PARTICIPANT	\N	PRESENT	0
776843	776542	19111A	PARTICIPANT	\N	PRESENT	0
776844	776542	20044X	PARTICIPANT	\N	PRESENT	0
776845	776542	19697Q	PARTICIPANT	\N	PRESENT	0
776846	776542	14225N	PARTICIPANT	\N	PRESENT	0
776847	776542	99004R	PARTICIPANT	\N	PRESENT	0
776848	776542	21089R	PARTICIPANT	\N	PRESENT	0
776849	776542	21074J	PARTICIPANT	\N	PRESENT	0
776850	776542	21088Q	PARTICIPANT	\N	PRESENT	0
776851	776542	19387D	PARTICIPANT	\N	PRESENT	0
776852	776542	21053D	PARTICIPANT	\N	PRESENT	0
776853	776542	20134Y	PARTICIPANT	\N	PRESENT	0
776854	776542	14033T	PARTICIPANT	\N	PRESENT	0
776855	776542	19573D	PARTICIPANT	\N	PRESENT	0
776856	776542	20034V	PARTICIPANT	\N	PRESENT	0
776860	776542	19687N	PARTICIPANT	\N	PRESENT	0
776858	776542	21029D	PARTICIPANT	\N	PRESENT	0
776859	776542	21093M	PARTICIPANT	\N	PRESENT	0
776861	776542	19711U	PARTICIPANT	\N	PRESENT	0
776862	776542	19619A	PARTICIPANT	\N	PRESENT	0
776863	776542	20124W	PARTICIPANT	\N	PRESENT	0
776864	776542	11085T	PARTICIPANT	\N	PRESENT	0
776865	776542	21079P	PARTICIPANT	\N	PRESENT	0
776866	776542	20068G	PARTICIPANT	\N	PRESENT	0
776868	776542	21090J	PARTICIPANT	\N	PRESENT	0
776869	776542	20120S	PARTICIPANT	\N	PRESENT	0
776870	776542	14031R	PARTICIPANT	\N	PRESENT	0
776871	776542	17229F	PARTICIPANT	\N	PRESENT	0
776872	776542	20100N	PARTICIPANT	\N	PRESENT	0
776873	776542	11053K	PARTICIPANT	\N	PRESENT	0
776874	776542	19820Y	PARTICIPANT	\N	PRESENT	0
776877	776543	19301E	PARTICIPANT	\N	PRESENT	0
776880	776543	21040X	PARTICIPANT	\N	PRESENT	0
776881	776543	19693L	PARTICIPANT	\N	PRESENT	0
776882	776543	20050V	PARTICIPANT	\N	PRESENT	0
776883	776543	20110Q	PARTICIPANT	\N	PRESENT	0
776884	776543	20136B	PARTICIPANT	\N	PRESENT	0
776885	776543	18231D	PARTICIPANT	\N	PRESENT	0
776887	776543	19111A	PARTICIPANT	\N	PRESENT	0
776888	776543	20044X	PARTICIPANT	\N	PRESENT	0
795266	794708	19585H	PARTICIPANT	\N	EXCUSE	0
795267	794708	20036X	PARTICIPANT	\N	EXCUSE	0
795920	795678	19685L	PARTICIPANT	\N	EXCUSE	0
796039	794857	19383Y	PARTICIPANT	\N	PRESENT	0
796040	794857	20088L	PARTICIPANT	\N	PRESENT	0
796041	794857	19768N	PARTICIPANT	\N	PRESENT	0
796042	794857	20092G	PARTICIPANT	\N	PRESENT	0
796043	794857	19782L	PARTICIPANT	\N	PRESENT	0
796044	794857	14357A	PARTICIPANT	\N	PRESENT	0
796045	794857	19413M	PARTICIPANT	\N	PRESENT	0
796046	794857	20082E	PARTICIPANT	\N	PRESENT	0
796047	794857	14221J	PARTICIPANT	\N	PRESENT	0
796048	794857	19631V	PARTICIPANT	\N	PRESENT	0
796049	794857	08015R	PARTICIPANT	\N	PRESENT	0
796050	794857	19575F	PARTICIPANT	\N	PRESENT	0
796051	794857	20018V	PARTICIPANT	\N	PRESENT	0
796052	794857	08028W	PARTICIPANT	\N	PRESENT	0
796053	794857	19563B	PARTICIPANT	\N	PRESENT	0
796054	794857	21050A	PARTICIPANT	\N	PRESENT	0
796055	794857	21096Q	PARTICIPANT	\N	PRESENT	0
796056	794857	20028X	PARTICIPANT	\N	PRESENT	0
796057	794857	14329V	PARTICIPANT	\N	PRESENT	0
796058	794857	14038Y	PARTICIPANT	\N	PRESENT	0
796059	794857	20030R	PARTICIPANT	\N	PRESENT	0
796060	794857	20034V	PARTICIPANT	\N	PRESENT	0
796061	794857	21054E	PARTICIPANT	\N	PRESENT	0
796062	794857	21075K	PARTICIPANT	\N	PRESENT	0
796063	794857	20038A	PARTICIPANT	\N	PRESENT	0
796064	794857	14187A	PRESIDENT	0	PRESENT	0
796065	794857	21083K	PARTICIPANT	\N	PRESENT	0
796066	794857	20144B	PARTICIPANT	\N	PRESENT	0
796067	794857	21086N	PARTICIPANT	\N	PRESENT	0
796068	794857	19695N	PARTICIPANT	\N	PRESENT	0
796069	794857	21092L	PARTICIPANT	\N	PRESENT	0
796070	794857	21093M	PARTICIPANT	\N	PRESENT	0
796071	794857	14033T	PARTICIPANT	\N	PRESENT	0
796072	794857	11090Q	PARTICIPANT	\N	PRESENT	0
796073	794857	20054A	PARTICIPANT	\N	PRESENT	0
796074	794857	21034A	PARTICIPANT	\N	PRESENT	0
796075	794857	14205J	PARTICIPANT	\N	PRESENT	0
796076	794857	19507S	PARTICIPANT	\N	PRESENT	0
796077	794857	21066J	PARTICIPANT	\N	PRESENT	0
796078	794857	20286Q	PARTICIPANT	\N	PRESENT	0
796079	794857	14207L	PARTICIPANT	\N	PRESENT	0
796080	794857	14257W	PARTICIPANT	\N	PRESENT	0
796081	794857	20084G	PARTICIPANT	\N	PRESENT	0
796082	794857	21052C	PARTICIPANT	\N	EXCUSE	0
796083	794857	20104S	PARTICIPANT	\N	EXCUSE	0
796084	794751	21046E	PARTICIPANT	\N	EXCUSE	0
796137	796132	20024T	PARTICIPANT	\N	PRESENT	0
796138	796132	19479G	PARTICIPANT	\N	PRESENT	0
796139	796132	07004J	PARTICIPANT	\N	PRESENT	0
796140	796132	19399H	PARTICIPANT	\N	PRESENT	0
796141	796132	11040E	PARTICIPANT	\N	PRESENT	0
796142	796132	19349W	PARTICIPANT	\N	PRESENT	0
796143	796132	21090J	PARTICIPANT	\N	PRESENT	0
796144	796132	20062A	PARTICIPANT	\N	PRESENT	0
796145	794710	19719D	PARTICIPANT	\N	PRESENT	0
796146	794710	11085T	PARTICIPANT	\N	PRESENT	0
796147	796132	19711U	PARTICIPANT	\N	PRESENT	0
796148	796132	14231L	PARTICIPANT	\N	PRESENT	0
796149	796132	20080C	PARTICIPANT	\N	PRESENT	0
796150	796132	19667J	PARTICIPANT	\N	PRESENT	0
796151	796132	20044X	PARTICIPANT	\N	PRESENT	0
796152	796132	14083S	PARTICIPANT	\N	PRESENT	0
796153	796132	14331P	PARTICIPANT	\N	PRESENT	0
796154	796132	11048N	PARTICIPANT	\N	PRESENT	0
796155	796132	20094J	PARTICIPANT	\N	PRESENT	0
796156	796132	20086J	PARTICIPANT	\N	PRESENT	0
796157	796132	21079P	PARTICIPANT	\N	PRESENT	0
796158	796132	19573D	PARTICIPANT	\N	PRESENT	0
796159	796132	08034U	PARTICIPANT	\N	PRESENT	0
796160	796132	07029T	PARTICIPANT	\N	PRESENT	0
796161	796132	19335Q	PARTICIPANT	\N	PRESENT	0
796162	796132	08010L	PARTICIPANT	\N	PRESENT	0
796163	796132	11110B	PARTICIPANT	\N	PRESENT	0
796164	796132	14225N	PARTICIPANT	\N	EXCUSE	0
796168	794710	11056N	PARTICIPANT	\N	PRESENT	0
796169	794694	21082J	PARTICIPANT	\N	PRESENT	0
796170	794694	21029D	PARTICIPANT	\N	PRESENT	0
796171	794694	19701S	PARTICIPANT	\N	PRESENT	0
796172	794694	21035B	PARTICIPANT	\N	PRESENT	0
796173	794694	20076G	PARTICIPANT	\N	PRESENT	0
796174	794694	21042A	PARTICIPANT	\N	PRESENT	0
796175	794694	14219Q	PRESIDENT	0	PRESENT	0
796176	794694	19820Y	PARTICIPANT	\N	PRESENT	0
796177	794694	19826F	PARTICIPANT	\N	PRESENT	0
796178	794694	21060C	PARTICIPANT	\N	PRESENT	0
796179	794694	21062E	PARTICIPANT	\N	PRESENT	0
796180	794694	21065H	PARTICIPANT	\N	PRESENT	0
796181	794694	20100N	PARTICIPANT	\N	PRESENT	0
796182	794694	14237S	PARTICIPANT	\N	PRESENT	0
796183	794694	21084L	PARTICIPANT	\N	PRESENT	0
796184	794694	18083K	PARTICIPANT	\N	PRESENT	0
796185	794694	21085M	PARTICIPANT	\N	PRESENT	0
796186	794694	05012A	PARTICIPANT	\N	PRESENT	0
796187	794694	08060W	PARTICIPANT	\N	PRESENT	0
796188	794694	20106U	PARTICIPANT	\N	PRESENT	0
796189	794694	15197G	PARTICIPANT	\N	PRESENT	0
796190	794694	20118Y	PARTICIPANT	\N	PRESENT	0
796191	794694	14107H	PARTICIPANT	\N	PRESENT	0
796192	794694	21080G	PARTICIPANT	\N	PRESENT	0
796193	794694	19331L	PARTICIPANT	\N	PRESENT	0
796194	794694	20020P	PARTICIPANT	\N	PRESENT	0
796195	794694	21051B	PARTICIPANT	\N	PRESENT	0
796196	794694	20032T	PARTICIPANT	\N	PRESENT	0
796197	794694	21053D	PARTICIPANT	\N	PRESENT	0
796198	794694	20136B	PARTICIPANT	\N	PRESENT	0
796199	794694	14031R	PARTICIPANT	\N	PRESENT	0
796200	794694	20040T	PARTICIPANT	\N	PRESENT	0
796201	794694	19251M	PARTICIPANT	\N	PRESENT	0
796202	794694	20146D	PARTICIPANT	\N	PRESENT	0
796203	794694	20046A	PARTICIPANT	\N	PRESENT	0
796204	794694	17229F	PARTICIPANT	\N	PRESENT	0
796205	794694	14169X	PARTICIPANT	\N	PRESENT	0
796206	794694	20068G	PARTICIPANT	\N	PRESENT	0
796207	794694	21068L	PARTICIPANT	\N	PRESENT	0
796208	794694	21070E	PARTICIPANT	\N	PRESENT	0
796209	794694	19619A	PARTICIPANT	\N	PRESENT	0
796210	794694	19551W	PARTICIPANT	\N	EXCUSE	0
796211	794694	19685L	PARTICIPANT	\N	EXCUSE	0
796212	794694	19681G	PARTICIPANT	\N	EXCUSE	0
796213	794694	21061D	PARTICIPANT	\N	EXCUSE	0
796214	794710	14259Y	PARTICIPANT	\N	PRESENT	0
796215	794850	04070G	PARTICIPANT	\N	PRESENT	0
796216	794850	19699S	PARTICIPANT	\N	PRESENT	0
796217	794850	19533U	PARTICIPANT	\N	PRESENT	0
796218	794850	04033B	PARTICIPANT	\N	PRESENT	0
796219	794850	21058J	PARTICIPANT	\N	PRESENT	0
796220	794850	21059K	PARTICIPANT	\N	PRESENT	0
796221	794850	20102Q	PARTICIPANT	\N	PRESENT	0
796222	794850	14229S	PARTICIPANT	\N	PRESENT	0
796223	794850	19954N	PARTICIPANT	\N	PRESENT	0
796224	794850	21032X	PARTICIPANT	\N	PRESENT	0
796225	794850	18395Y	PARTICIPANT	\N	PRESENT	0
796226	794850	20112S	PARTICIPANT	\N	PRESENT	0
796227	794850	21089R	PARTICIPANT	\N	PRESENT	0
796228	794850	21037D	PARTICIPANT	\N	PRESENT	0
796229	794850	20124W	PARTICIPANT	\N	PRESENT	0
796230	794850	20026V	PARTICIPANT	\N	PRESENT	0
796231	794850	19593H	PARTICIPANT	\N	PRESENT	0
796232	794850	20132W	PARTICIPANT	\N	PRESENT	0
796233	794850	20122U	PARTICIPANT	\N	PRESENT	0
796234	794850	14073Q	PARTICIPANT	\N	PRESENT	0
796235	794850	20138D	PARTICIPANT	\N	PRESENT	0
796236	794850	19611R	PRESIDENT	0	PRESENT	0
796237	794850	20142Y	PARTICIPANT	\N	PRESENT	0
796238	794850	20048C	PARTICIPANT	\N	PRESENT	0
796239	794850	20172F	PARTICIPANT	\N	PRESENT	0
796240	794850	14030Q	PARTICIPANT	\N	PRESENT	0
796241	794850	20058E	PARTICIPANT	\N	PRESENT	0
796242	794850	20056C	PARTICIPANT	\N	PRESENT	0
796243	794850	20180F	PARTICIPANT	\N	PRESENT	0
796244	794850	20264J	PARTICIPANT	\N	PRESENT	0
796245	794850	21063F	PARTICIPANT	\N	PRESENT	0
796246	794850	19735D	PARTICIPANT	\N	PRESENT	0
796247	794850	19057M	PARTICIPANT	\N	PRESENT	0
796248	794850	21074J	PARTICIPANT	\N	PRESENT	0
796249	794850	21077M	PARTICIPANT	\N	PRESENT	0
796250	794850	19621T	PARTICIPANT	\N	PRESENT	0
796251	794850	14021P	PARTICIPANT	\N	PRESENT	0
781715	781491	21053D	PARTICIPANT	\N	PRESENT	0
781716	781491	20136B	PARTICIPANT	\N	PRESENT	0
781717	781491	14031R	PARTICIPANT	\N	PRESENT	0
781718	781491	20040T	PARTICIPANT	\N	PRESENT	0
781719	781491	20146D	PARTICIPANT	\N	PRESENT	0
781720	781491	20046A	PARTICIPANT	\N	PRESENT	0
781721	781491	14169X	PARTICIPANT	\N	PRESENT	0
781722	781491	17229F	PARTICIPANT	\N	PRESENT	0
781723	781491	21047F	PARTICIPANT	\N	PRESENT	0
781724	781491	20068G	PARTICIPANT	\N	PRESENT	0
781725	781491	21068L	PARTICIPANT	\N	PRESENT	0
781726	781491	19251M	PARTICIPANT	\N	EXCUSE	0
781727	781491	21061D	PARTICIPANT	\N	EXCUSE	0
781728	781491	19619A	PARTICIPANT	\N	EXCUSE	0
781729	781491	21065H	PARTICIPANT	\N	PRESENT	0
781730	779652	86034E	PARTICIPANT	\N	PRESENT	0
781900	779652	20146D	PARTICIPANT	\N	PRESENT	0
781901	779652	07029T	PARTICIPANT	\N	PRESENT	0
781902	779652	19657G	PARTICIPANT	\N	PRESENT	0
781903	779652	04045F	PARTICIPANT	\N	PRESENT	0
781904	779652	19729F	PARTICIPANT	\N	PRESENT	0
781905	779652	21074J	PARTICIPANT	\N	PRESENT	0
781906	779652	19707Y	PARTICIPANT	\N	PRESENT	0
781907	779652	14055N	PARTICIPANT	\N	PRESENT	0
781908	779652	19768N	PARTICIPANT	\N	PRESENT	0
781909	779652	14207L	PARTICIPANT	\N	PRESENT	0
781910	779652	08010L	PARTICIPANT	\N	PRESENT	0
781911	779652	19719D	PARTICIPANT	\N	PRESENT	0
781912	779652	04047H	PARTICIPANT	\N	PRESENT	0
781913	779652	20132W	PARTICIPANT	\N	PRESENT	0
781914	779652	19387D	PARTICIPANT	\N	PRESENT	0
781915	779652	14026U	PARTICIPANT	\N	PRESENT	0
781916	779652	98022P	PARTICIPANT	\N	PRESENT	0
781917	779652	14133K	PARTICIPANT	\N	PRESENT	0
781918	779652	19553Y	PARTICIPANT	\N	PRESENT	0
781919	779652	20072C	PARTICIPANT	\N	PRESENT	0
781920	779652	14123H	PARTICIPANT	\N	PRESENT	0
781921	779652	21078N	PARTICIPANT	\N	PRESENT	0
781922	779652	19866P	PARTICIPANT	\N	PRESENT	0
781923	779652	08034U	PARTICIPANT	\N	PRESENT	0
781924	779652	19545Y	PARTICIPANT	\N	PRESENT	0
781925	779652	14195A	PARTICIPANT	\N	PRESENT	0
781926	779652	05008E	PARTICIPANT	\N	PRESENT	0
781927	779652	21065H	PARTICIPANT	\N	PRESENT	0
781928	779652	04033B	PARTICIPANT	\N	PRESENT	0
781929	779652	14071N	PARTICIPANT	\N	PRESENT	0
781930	779652	14211G	PARTICIPANT	\N	PRESENT	0
781931	779652	14187A	PARTICIPANT	\N	PRESENT	0
781932	779652	19701S	PARTICIPANT	\N	PRESENT	0
782109	779652	20126Y	PARTICIPANT	\N	PRESENT	0
781934	779652	14053L	PARTICIPANT	\N	PRESENT	0
781935	779652	21054E	PARTICIPANT	\N	PRESENT	0
781936	779652	19798U	PARTICIPANT	\N	PRESENT	0
781937	779652	14111D	PARTICIPANT	\N	PRESENT	0
781938	779652	21095P	PARTICIPANT	\N	PRESENT	0
781939	779652	14221J	PARTICIPANT	\N	PRESENT	0
782103	779652	19383Y	PARTICIPANT	\N	PRESENT	0
781941	779652	21070E	PARTICIPANT	\N	PRESENT	0
781942	779652	19585H	PARTICIPANT	\N	PRESENT	0
781943	779652	14217N	PARTICIPANT	\N	PRESENT	0
782104	779652	11090Q	PARTICIPANT	\N	PRESENT	0
781945	779652	21087P	PARTICIPANT	\N	PRESENT	0
781947	779652	20094J	PARTICIPANT	\N	PRESENT	0
782105	779652	21058J	PARTICIPANT	\N	PRESENT	0
781950	779652	19631V	PARTICIPANT	\N	PRESENT	0
782106	779652	20252E	PARTICIPANT	\N	PRESENT	0
781952	779652	21089R	PARTICIPANT	\N	PRESENT	0
782112	779652	21032X	PARTICIPANT	\N	PRESENT	0
781954	779652	21045D	PARTICIPANT	\N	PRESENT	0
782108	779652	20120S	PARTICIPANT	\N	PRESENT	0
782154	779652	95041E	PARTICIPANT	\N	PRESENT	0
781957	779652	12028B	PARTICIPANT	\N	PRESENT	0
782110	779652	14251Q	PARTICIPANT	\N	PRESENT	0
781959	779652	21057H	PARTICIPANT	\N	PRESENT	0
782111	779652	21073H	PARTICIPANT	\N	PRESENT	0
781961	779652	20264J	PARTICIPANT	\N	PRESENT	0
782113	779652	21048G	PARTICIPANT	\N	PRESENT	0
781963	779652	11027H	PARTICIPANT	\N	PRESENT	0
782114	779652	21033Y	PARTICIPANT	\N	PRESENT	0
781965	779652	20070A	PARTICIPANT	\N	PRESENT	0
782115	779652	20122U	PARTICIPANT	\N	PRESENT	0
781967	779652	21067K	PARTICIPANT	\N	PRESENT	0
782121	779652	19954N	PARTICIPANT	\N	PRESENT	0
782116	779652	11053K	PARTICIPANT	\N	PRESENT	0
782120	779652	19507S	PARTICIPANT	\N	PRESENT	0
782118	779652	14193X	PARTICIPANT	\N	PRESENT	0
782148	779652	11110B	PARTICIPANT	\N	PRESENT	0
781973	779652	11074Q	PARTICIPANT	\N	PRESENT	0
782122	779652	14069U	PARTICIPANT	\N	PRESENT	0
781981	779652	14281W	PARTICIPANT	\N	PRESENT	0
782125	779652	11085T	PARTICIPANT	\N	PRESENT	0
781977	779652	21062E	PARTICIPANT	\N	PRESENT	0
782153	779652	20086J	PARTICIPANT	\N	PRESENT	0
782053	779652	20286Q	PARTICIPANT	\N	PRESENT	0
782047	779652	14255U	PARTICIPANT	\N	PRESENT	0
781983	779652	08045X	PARTICIPANT	\N	PRESENT	0
781984	779652	19725B	PARTICIPANT	\N	PRESENT	0
781985	779652	19551W	PARTICIPANT	\N	PRESENT	0
782041	779652	19826F	PARTICIPANT	\N	PRESENT	0
782059	779652	17023S	PARTICIPANT	\N	PRESENT	0
781991	779652	19531S	PARTICIPANT	\N	PRESENT	0
781992	779652	19683J	PARTICIPANT	\N	PRESENT	0
781993	779652	14097Y	PARTICIPANT	\N	PRESENT	0
782055	779652	14042U	PARTICIPANT	\N	PRESENT	0
781995	779652	19489J	PARTICIPANT	\N	PRESENT	0
781997	779652	18193Q	PARTICIPANT	\N	PRESENT	0
781998	779652	18207D	PARTICIPANT	\N	PRESENT	0
782000	779652	08012N	PARTICIPANT	\N	PRESENT	0
782058	779652	19111A	PARTICIPANT	\N	PRESENT	0
782002	779652	20018V	PARTICIPANT	\N	PRESENT	0
782004	779652	20028X	PARTICIPANT	\N	PRESENT	0
782005	779652	14109K	PARTICIPANT	\N	PRESENT	0
782048	779652	17229F	PARTICIPANT	\N	PRESENT	0
782007	779652	18231D	PARTICIPANT	\N	PRESENT	0
782008	779652	21060C	PARTICIPANT	\N	PRESENT	0
782009	779652	14225N	PARTICIPANT	\N	PRESENT	0
782040	779652	21050A	PARTICIPANT	\N	PRESENT	0
782015	779652	20082E	PARTICIPANT	\N	PRESENT	0
782016	779652	19057M	PARTICIPANT	\N	PRESENT	0
782017	779652	14229S	PARTICIPANT	\N	PRESENT	0
782018	779652	21056G	PARTICIPANT	\N	PRESENT	0
782057	779652	21086N	PARTICIPANT	\N	PRESENT	0
782020	779652	11045K	PARTICIPANT	\N	PRESENT	0
782046	779652	14089Y	PARTICIPANT	\N	PRESENT	0
782060	779652	19735D	PARTICIPANT	\N	PRESENT	0
782023	779652	14037X	PARTICIPANT	\N	PRESENT	0
782050	779652	20248J	PARTICIPANT	\N	PRESENT	0
782025	779652	20084G	PARTICIPANT	\N	PRESENT	0
782027	779652	19669L	PARTICIPANT	\N	PRESENT	0
782029	779652	21051B	PARTICIPANT	\N	PRESENT	0
782030	779652	21031W	PARTICIPANT	\N	PRESENT	0
782031	779652	21077M	PARTICIPANT	\N	PRESENT	0
782033	779652	14219Q	PARTICIPANT	\N	PRESENT	0
782034	779652	21069M	PARTICIPANT	\N	PRESENT	0
782035	781770	14189C	PARTICIPANT	\N	PRESENT	0
782036	781770	14033T	PARTICIPANT	\N	PRESENT	0
782037	781770	18395Y	PARTICIPANT	\N	PRESENT	0
782038	779652	14189C	PARTICIPANT	\N	PRESENT	0
782039	779652	21042A	PARTICIPANT	\N	PRESENT	0
782056	779652	20040T	PARTICIPANT	\N	PRESENT	0
782044	779652	19721W	PARTICIPANT	\N	PRESENT	0
782045	779652	14083S	PARTICIPANT	\N	PRESENT	0
782049	779652	21083K	PARTICIPANT	\N	PRESENT	0
782051	779652	14327T	PARTICIPANT	\N	PRESENT	0
782054	779652	15197G	PARTICIPANT	\N	PRESENT	0
782061	779652	14231L	PARTICIPANT	\N	PRESENT	0
769085	769084	12028B	PARTICIPANT	\N	PRESENT	0
769086	769084	14267Y	PARTICIPANT	\N	PRESENT	0
769087	769084	08010L	PARTICIPANT	\N	PRESENT	0
770420	768934	21040X	PARTICIPANT	\N	PRESENT	0
770421	768934	20074E	PARTICIPANT	\N	PRESENT	0
770422	768934	20098N	PARTICIPANT	\N	PRESENT	0
770423	768934	04047H	PRESIDENT	0	PRESENT	0
770427	768934	21057H	PARTICIPANT	\N	PRESENT	0
770428	768934	11072N	PARTICIPANT	\N	PRESENT	0
770434	768934	20034V	PARTICIPANT	\N	PRESENT	0
770435	768934	04045F	PARTICIPANT	\N	PRESENT	0
770436	768934	18207D	PARTICIPANT	\N	PRESENT	0
770437	768934	19719D	PARTICIPANT	\N	PRESENT	0
770438	768934	19489J	PARTICIPANT	\N	PRESENT	0
770439	768934	11056N	PARTICIPANT	\N	PRESENT	0
770441	768934	14147R	PARTICIPANT	\N	PRESENT	0
780820	780819	20264J	PARTICIPANT	\N	PRESENT	0
780821	780819	11027H	PARTICIPANT	\N	PRESENT	0
780822	780819	14357A	PARTICIPANT	\N	PRESENT	0
780823	780819	14281W	PARTICIPANT	\N	PRESENT	0
780824	780819	21032X	PARTICIPANT	\N	PRESENT	0
780825	780819	20126Y	PARTICIPANT	\N	PRESENT	0
780826	780819	19649G	PARTICIPANT	\N	PRESENT	0
780827	780819	14037X	PARTICIPANT	\N	PRESENT	0
780828	780819	21087P	PARTICIPANT	\N	PRESENT	0
780829	780819	21058J	PARTICIPANT	\N	PRESENT	0
780830	780819	20252E	PARTICIPANT	\N	PRESENT	0
780831	780819	18231D	PARTICIPANT	\N	PRESENT	0
780832	780819	20026V	PARTICIPANT	\N	PRESENT	0
780833	780819	19749K	PARTICIPANT	\N	PRESENT	0
780835	780834	20264J	PARTICIPANT	\N	PRESENT	0
780836	780834	11027H	PARTICIPANT	\N	PRESENT	0
780837	780834	14357A	PARTICIPANT	\N	PRESENT	0
780838	780834	14281W	PARTICIPANT	\N	PRESENT	0
780839	780834	21032X	PARTICIPANT	\N	PRESENT	0
780840	780834	20126Y	PARTICIPANT	\N	PRESENT	0
780841	780834	19649G	PARTICIPANT	\N	PRESENT	0
780842	780834	14037X	PARTICIPANT	\N	PRESENT	0
780843	780834	21087P	PARTICIPANT	\N	PRESENT	0
780844	780834	21058J	PARTICIPANT	\N	PRESENT	0
780845	780834	20252E	PARTICIPANT	\N	PRESENT	0
780846	780834	18231D	PARTICIPANT	\N	PRESENT	0
780847	780834	20026V	PARTICIPANT	\N	PRESENT	0
780848	780834	19749K	PARTICIPANT	\N	PRESENT	0
785360	783387	14133K	PARTICIPANT	\N	PRESENT	0
785361	783387	20032T	PARTICIPANT	\N	PRESENT	0
785362	783387	19707Y	PARTICIPANT	\N	PRESENT	0
785364	783387	21057H	PARTICIPANT	\N	PRESENT	0
785365	783387	05012A	PARTICIPANT	\N	PRESENT	0
785367	783387	21067K	PARTICIPANT	\N	PRESENT	0
785368	783387	18083K	PARTICIPANT	\N	PRESENT	0
785369	783387	19575F	PARTICIPANT	\N	PRESENT	0
785370	783387	20046A	PARTICIPANT	\N	PRESENT	0
785371	783387	19760E	PARTICIPANT	\N	PRESENT	0
785372	783387	19573D	PARTICIPANT	\N	PRESENT	0
785373	783387	19758L	PARTICIPANT	\N	PRESENT	0
785374	783387	10015M	PARTICIPANT	\N	PRESENT	0
785375	783387	21072G	PARTICIPANT	\N	PRESENT	0
785376	783387	11043H	PARTICIPANT	\N	PRESENT	0
785377	783387	14215L	PARTICIPANT	\N	PRESENT	0
785378	783387	20044X	PARTICIPANT	\N	PRESENT	0
785379	783387	21042A	PARTICIPANT	\N	PRESENT	0
785380	783387	19711U	PARTICIPANT	\N	PRESENT	0
785381	783387	14255U	PARTICIPANT	\N	PRESENT	0
785382	783387	19667J	PARTICIPANT	\N	PRESENT	0
785383	783387	19533U	PARTICIPANT	\N	PRESENT	0
785384	783387	20058E	PARTICIPANT	\N	PRESENT	0
785385	783387	08010L	PARTICIPANT	\N	PRESENT	0
785386	783387	20038A	PARTICIPANT	\N	PRESENT	0
785387	783387	08034U	PARTICIPANT	\N	PRESENT	0
785434	783387	14259Y	PARTICIPANT	\N	PRESENT	0
785389	783387	19621T	PARTICIPANT	\N	PRESENT	0
785390	783387	14026U	PARTICIPANT	\N	PRESENT	0
785391	783387	04047H	PARTICIPANT	\N	PRESENT	0
785392	783387	21088Q	PARTICIPANT	\N	PRESENT	0
785393	783387	11040E	PARTICIPANT	\N	PRESENT	0
785394	783387	11048N	PARTICIPANT	\N	PRESENT	0
785395	783387	21075K	PARTICIPANT	\N	PRESENT	0
785396	783387	14123H	PARTICIPANT	\N	PRESENT	0
785397	783387	21084L	PARTICIPANT	\N	PRESENT	0
785398	783387	08069G	PARTICIPANT	\N	PRESENT	0
785399	783387	19687N	PARTICIPANT	\N	PRESENT	0
785400	783387	20078J	PARTICIPANT	\N	PRESENT	0
785401	783387	21044C	PARTICIPANT	\N	PRESENT	0
785402	783387	21061D	PARTICIPANT	\N	PRESENT	0
785403	783387	19681G	PARTICIPANT	\N	PRESENT	0
785404	783387	19593H	PARTICIPANT	\N	PRESENT	0
785405	783387	21049H	PARTICIPANT	\N	PRESENT	0
785406	783387	21030V	PARTICIPANT	\N	PRESENT	0
785407	783387	19679N	PARTICIPANT	\N	PRESENT	0
785408	783387	20110Q	PARTICIPANT	\N	PRESENT	0
785409	783387	21048G	PARTICIPANT	\N	PRESENT	0
785410	783387	20062A	PARTICIPANT	\N	PRESENT	0
785411	783387	11065P	PARTICIPANT	\N	PRESENT	0
785412	783387	20134Y	PARTICIPANT	\N	PRESENT	0
785413	783387	19701S	PARTICIPANT	\N	PRESENT	0
785414	783387	14187A	PARTICIPANT	\N	PRESENT	0
785415	783387	21073H	PARTICIPANT	\N	PRESENT	0
785416	783387	20142Y	PARTICIPANT	\N	PRESENT	0
785417	783387	14071N	PARTICIPANT	\N	PRESENT	0
785418	783387	21093M	PARTICIPANT	\N	PRESENT	0
785419	783387	20022R	PARTICIPANT	\N	PRESENT	0
785420	783387	21037D	PARTICIPANT	\N	PRESENT	0
785421	783387	21079P	PARTICIPANT	\N	PRESENT	0
785422	783387	21071F	PARTICIPANT	\N	PRESENT	0
785423	783387	19421M	PARTICIPANT	\N	PRESENT	0
785424	783387	14253S	PARTICIPANT	\N	PRESENT	0
785425	783387	14031R	PARTICIPANT	\N	PRESENT	0
785426	783387	20130U	PARTICIPANT	\N	PRESENT	0
785427	783387	20118Y	PARTICIPANT	\N	PRESENT	0
785428	783387	14069U	PARTICIPANT	\N	PRESENT	0
785429	783387	21043B	PARTICIPANT	\N	PRESENT	0
785430	783387	20120S	PARTICIPANT	\N	PRESENT	0
785431	783387	19782L	PARTICIPANT	\N	PRESENT	0
785432	783387	21090J	PARTICIPANT	\N	PRESENT	0
785433	783387	21094N	PARTICIPANT	\N	PRESENT	0
785435	783387	21095P	PARTICIPANT	\N	PRESENT	0
785436	783387	11090Q	PARTICIPANT	\N	PRESENT	0
785437	783387	19703U	PARTICIPANT	\N	PRESENT	0
785438	783387	07033P	PARTICIPANT	\N	PRESENT	0
785439	783387	14147R	PARTICIPANT	\N	PRESENT	0
785440	783387	21092L	PARTICIPANT	\N	PRESENT	0
785441	783387	20172F	PARTICIPANT	\N	PRESENT	0
785442	783387	20128B	PARTICIPANT	\N	PRESENT	0
785443	783387	20138D	PARTICIPANT	\N	PRESENT	0
785444	783387	08047A	PARTICIPANT	\N	PRESENT	0
785445	783387	11072N	PARTICIPANT	\N	PRESENT	0
785446	783387	21081H	PARTICIPANT	\N	PRESENT	0
785447	783387	20026V	PARTICIPANT	\N	PRESENT	0
785448	783387	20056C	PARTICIPANT	\N	PRESENT	0
785449	783387	19954N	PARTICIPANT	\N	PRESENT	0
785450	783387	20180F	PARTICIPANT	\N	PRESENT	0
785451	783387	20096L	PARTICIPANT	\N	PRESENT	0
785452	783387	21068L	PARTICIPANT	\N	PRESENT	0
785453	783387	21058J	PARTICIPANT	\N	PRESENT	0
785454	783387	14038Y	PARTICIPANT	\N	PRESENT	0
785455	783387	19723Y	PARTICIPANT	\N	PRESENT	0
785456	783387	20034V	PARTICIPANT	\N	PRESENT	0
785457	783387	21039F	PARTICIPANT	\N	PRESENT	0
785458	783387	20140W	PARTICIPANT	\N	PRESENT	0
785459	783387	19399H	PARTICIPANT	\N	PRESENT	0
785460	783387	20104S	PARTICIPANT	\N	PRESENT	0
785461	783387	21046E	PARTICIPANT	\N	PRESENT	0
785462	783387	14213J	PARTICIPANT	\N	PRESENT	0
785463	783387	14329V	PARTICIPANT	\N	PRESENT	0
785464	783387	14217N	PARTICIPANT	\N	PRESENT	0
785465	783387	14357A	PARTICIPANT	\N	PRESENT	0
785466	783387	19383Y	PARTICIPANT	\N	PRESENT	0
785467	783387	20098N	PARTICIPANT	\N	PRESENT	0
785468	783387	14037X	PARTICIPANT	\N	PRESENT	0
785469	783387	20126Y	PARTICIPANT	\N	PRESENT	0
785470	783387	20124W	PARTICIPANT	\N	PRESENT	0
785471	783387	20106U	PARTICIPANT	\N	PRESENT	0
785472	783387	14059S	PARTICIPANT	\N	PRESENT	0
785473	783387	19697Q	PARTICIPANT	\N	PRESENT	0
785474	783387	20146D	PARTICIPANT	\N	PRESENT	0
785475	783387	19507S	PARTICIPANT	\N	PRESENT	0
785476	783387	19705W	PARTICIPANT	\N	PRESENT	0
785477	783387	21085M	PARTICIPANT	\N	PRESENT	0
785478	783387	19768N	PARTICIPANT	\N	PRESENT	0
785479	783387	20116W	PARTICIPANT	\N	PRESENT	0
771306	769238	14225N	PARTICIPANT	\N	PRESENT	0
771307	769238	14229S	PARTICIPANT	\N	PRESENT	0
771308	769238	21056G	PARTICIPANT	\N	PRESENT	0
771309	769238	11045K	PARTICIPANT	\N	PRESENT	0
771310	769238	21059K	PARTICIPANT	\N	PRESENT	0
771311	769238	21051B	PARTICIPANT	\N	PRESENT	0
771312	769238	19413M	PARTICIPANT	\N	PRESENT	0
771313	769238	20064C	PARTICIPANT	\N	PRESENT	0
771314	769238	20084G	PARTICIPANT	\N	PRESENT	0
771315	769238	19111A	PARTICIPANT	\N	PRESENT	0
771316	769238	11074Q	PARTICIPANT	\N	PRESENT	0
771317	769238	19251M	PARTICIPANT	\N	PRESENT	0
771318	769238	14111D	PARTICIPANT	\N	PRESENT	0
771319	769238	20018V	PARTICIPANT	\N	PRESENT	0
771320	769238	14231L	PARTICIPANT	\N	PRESENT	0
771321	769238	21042A	PARTICIPANT	\N	PRESENT	0
771322	769238	21050A	PARTICIPANT	\N	PRESENT	0
771323	769238	20042V	PARTICIPANT	\N	PRESENT	0
771324	769238	07004J	PARTICIPANT	\N	PRESENT	0
771325	769238	19691J	PARTICIPANT	\N	PRESENT	0
771326	769238	19685L	PARTICIPANT	\N	PRESENT	0
771327	769238	21083K	PARTICIPANT	\N	PRESENT	0
771328	769238	11053K	PARTICIPANT	\N	PRESENT	0
771329	769238	14083S	PARTICIPANT	\N	PRESENT	0
771343	769238	14327T	PARTICIPANT	\N	PRESENT	0
771331	769238	20248J	PARTICIPANT	\N	PRESENT	0
771332	769238	20040T	PARTICIPANT	\N	PRESENT	0
771333	769238	21086N	PARTICIPANT	\N	PRESENT	0
771334	769238	17023S	PARTICIPANT	\N	PRESENT	0
771335	769238	04070G	PARTICIPANT	\N	PRESENT	0
771336	769238	14205J	PARTICIPANT	\N	PRESENT	0
771337	769238	19826F	PARTICIPANT	\N	PRESENT	0
771338	769238	19335Q	PARTICIPANT	\N	PRESENT	0
771352	769238	20094J	PARTICIPANT	\N	PRESENT	0
771340	769238	21053D	PARTICIPANT	\N	PRESENT	0
771341	769238	19745F	PARTICIPANT	\N	PRESENT	0
771347	769238	21064G	PARTICIPANT	\N	PRESENT	0
771349	769238	19713W	PARTICIPANT	\N	PRESENT	0
771350	769238	19723Y	PARTICIPANT	\N	PRESENT	0
771354	769238	21085M	PARTICIPANT	\N	PRESENT	0
771358	769238	20120S	PARTICIPANT	\N	PRESENT	0
771356	769238	11115U	PARTICIPANT	\N	PRESENT	0
771357	769238	19553Y	PARTICIPANT	\N	PRESENT	0
771359	769238	14215L	PARTICIPANT	\N	PRESENT	0
771360	769238	07033P	PARTICIPANT	\N	PRESENT	0
771361	769238	17737W	PARTICIPANT	\N	PRESENT	0
771362	769238	14123H	PARTICIPANT	\N	PRESENT	0
771363	769238	14169X	PARTICIPANT	\N	PRESENT	0
771364	769238	08056B	PARTICIPANT	\N	PRESENT	0
771368	769238	14179A	PARTICIPANT	\N	PRESENT	0
771369	769238	21047F	PARTICIPANT	\N	PRESENT	0
771694	769239	14259Y	PARTICIPANT	\N	PRESENT	0
771373	769238	08009T	PARTICIPANT	\N	PRESENT	0
771695	769239	08060W	PARTICIPANT	\N	PRESENT	0
771696	769239	12016W	PARTICIPANT	\N	PRESENT	0
771697	769239	20128B	PARTICIPANT	\N	PRESENT	0
771698	769239	21095P	PARTICIPANT	\N	PRESENT	0
771699	769239	20114U	PARTICIPANT	\N	PRESENT	0
771700	769239	21060C	PARTICIPANT	\N	PRESENT	0
771742	769239	19647E	PARTICIPANT	\N	PRESENT	0
771702	769239	20090E	PARTICIPANT	\N	PRESENT	0
771703	769239	18207D	PARTICIPANT	\N	PRESENT	0
771704	769239	19649G	PARTICIPANT	\N	PRESENT	0
771705	769239	21043B	PARTICIPANT	\N	PRESENT	0
771706	769239	14215L	PARTICIPANT	\N	PRESENT	0
771707	769239	14109K	PARTICIPANT	\N	PRESENT	0
771708	769239	19745F	PARTICIPANT	\N	PRESENT	0
771754	769239	17965H	PARTICIPANT	\N	PRESENT	0
771755	769239	19673G	PARTICIPANT	\N	PRESENT	0
771711	769239	20074E	PARTICIPANT	\N	PRESENT	0
771712	770926	20086J	PARTICIPANT	\N	PRESENT	0
771713	770926	14327T	PARTICIPANT	\N	PRESENT	0
771714	770926	07029T	PARTICIPANT	\N	PRESENT	0
771715	770926	19711U	PARTICIPANT	\N	PRESENT	0
771716	770926	19545Y	PARTICIPANT	\N	PRESENT	0
771717	770926	20080C	PARTICIPANT	\N	PRESENT	0
771718	770926	21090J	PARTICIPANT	\N	PRESENT	0
771719	770926	19399H	PARTICIPANT	\N	PRESENT	0
771720	770926	19631V	PARTICIPANT	\N	PRESENT	0
771721	770926	21062E	PARTICIPANT	\N	PRESENT	0
771722	769239	19533U	PARTICIPANT	\N	PRESENT	0
771723	769239	18083K	PARTICIPANT	\N	PRESENT	0
771724	769239	20136B	PARTICIPANT	\N	PRESENT	0
771725	769239	19669L	PARTICIPANT	\N	PRESENT	0
771726	769239	20266L	PARTICIPANT	\N	PRESENT	0
771727	769239	20142Y	PARTICIPANT	\N	PRESENT	0
771728	769239	21088Q	PARTICIPANT	\N	PRESENT	0
771729	770926	19713W	PARTICIPANT	\N	PRESENT	0
771730	770926	21048G	PARTICIPANT	\N	PRESENT	0
771731	769239	21057H	PARTICIPANT	\N	PRESENT	0
771732	769239	20028X	PARTICIPANT	\N	PRESENT	0
771733	769239	19413M	PARTICIPANT	\N	PRESENT	0
771734	769239	19551W	PARTICIPANT	\N	PRESENT	0
771735	769239	19111A	PARTICIPANT	\N	PRESENT	0
771736	769239	14191V	PARTICIPANT	\N	PRESENT	0
771737	769239	21055F	PARTICIPANT	\N	PRESENT	0
771738	769239	21044C	PARTICIPANT	\N	PRESENT	0
771739	769239	14217N	PARTICIPANT	\N	PRESENT	0
771740	769239	14123H	PARTICIPANT	\N	PRESENT	0
771741	769239	20098N	PARTICIPANT	\N	PRESENT	0
771743	769239	14089Y	PARTICIPANT	\N	PRESENT	0
771744	769239	20064C	PARTICIPANT	\N	PRESENT	0
771745	769239	19489J	PARTICIPANT	\N	PRESENT	0
771746	769239	19820Y	PARTICIPANT	\N	PRESENT	0
771747	769239	11045K	PARTICIPANT	\N	PRESENT	0
771748	769239	14021P	PARTICIPANT	\N	PRESENT	0
771749	769239	20018V	PARTICIPANT	\N	PRESENT	0
771750	769239	20062A	PARTICIPANT	\N	PRESENT	0
771751	769239	19447X	PARTICIPANT	\N	PRESENT	0
771752	769239	21094N	PARTICIPANT	\N	PRESENT	0
771753	769239	04047H	PARTICIPANT	\N	PRESENT	0
771756	769239	14189C	PARTICIPANT	\N	PRESENT	0
771757	769239	21077M	PARTICIPANT	\N	PRESENT	0
771758	769239	19723Y	PARTICIPANT	\N	PRESENT	0
771759	769239	14151M	PARTICIPANT	\N	PRESENT	0
771760	769239	21070E	PARTICIPANT	\N	PRESENT	0
771761	769239	14357A	PARTICIPANT	\N	PRESENT	0
771764	769239	14111D	PARTICIPANT	\N	PRESENT	0
771765	769239	21036C	PARTICIPANT	\N	PRESENT	0
771766	769239	19719D	PARTICIPANT	\N	PRESENT	0
771767	770926	11048N	PARTICIPANT	\N	PRESENT	0
771768	770926	08034U	PARTICIPANT	\N	PRESENT	0
771769	770926	20044X	PARTICIPANT	\N	PRESENT	0
771770	770926	11110B	PARTICIPANT	\N	PRESENT	0
771771	770926	20070A	PARTICIPANT	\N	PRESENT	0
771772	770926	20116W	PARTICIPANT	\N	PRESENT	0
771773	770926	21072G	PARTICIPANT	\N	PRESENT	0
771774	769239	20106U	PARTICIPANT	\N	PRESENT	0
771775	769239	19725B	PARTICIPANT	\N	PRESENT	0
771776	769239	10015M	PARTICIPANT	\N	PRESENT	0
771777	769239	21045D	PARTICIPANT	\N	PRESENT	0
771778	769239	17779H	PARTICIPANT	\N	PRESENT	0
771779	769239	21035B	PARTICIPANT	\N	PRESENT	0
771780	769239	14229S	PARTICIPANT	\N	PRESENT	0
771781	770926	14225N	PRESIDENT	0	PRESENT	0
771782	770926	14083S	PARTICIPANT	\N	PRESENT	0
771783	769239	19683J	PARTICIPANT	\N	PRESENT	0
771784	769239	21039F	PARTICIPANT	\N	PRESENT	0
771785	769239	07033P	PARTICIPANT	\N	PRESENT	0
771786	769239	21059K	PARTICIPANT	\N	PRESENT	0
771787	769239	20084G	PARTICIPANT	\N	PRESENT	0
771788	769239	20264J	PARTICIPANT	\N	PRESENT	0
771810	770926	19573D	PARTICIPANT	\N	PRESENT	0
771793	769239	14281W	PARTICIPANT	\N	PRESENT	0
771794	769239	20026V	PARTICIPANT	\N	PRESENT	0
771795	769239	18395Y	PARTICIPANT	\N	PRESENT	0
771799	769239	20056C	PARTICIPANT	\N	PRESENT	0
771800	769239	18231D	PARTICIPANT	\N	PRESENT	0
771801	769239	19798U	PARTICIPANT	\N	PRESENT	0
771803	769239	14055N	PARTICIPANT	\N	PRESENT	0
771805	769239	14147R	PARTICIPANT	\N	PRESENT	0
771806	770926	14169X	PARTICIPANT	\N	PRESENT	0
771807	769239	21082J	PARTICIPANT	\N	PRESENT	0
771811	770926	14121F	PARTICIPANT	\N	PRESENT	0
771812	769239	20110Q	PARTICIPANT	\N	PRESENT	0
771813	769239	19760E	PARTICIPANT	\N	PRESENT	0
771814	769239	19687N	PARTICIPANT	\N	PRESENT	0
771815	770926	19349W	PARTICIPANT	\N	PRESENT	0
771820	769239	20036X	PARTICIPANT	\N	PRESENT	0
771821	769239	14073Q	PARTICIPANT	\N	PRESENT	0
771824	769239	11027H	PARTICIPANT	\N	PRESENT	0
769227	769226	19489J	PARTICIPANT	\N	PRESENT	0
769263	769262	21062E	PARTICIPANT	\N	PRESENT	0
769266	769264	21062E	PARTICIPANT	\N	PRESENT	0
775509	761872	21071F	PARTICIPANT	\N	EXCUSE	0
775510	761872	07029T	PARTICIPANT	\N	EXCUSE	0
775511	761872	20146D	PARTICIPANT	\N	PRESENT	0
775512	761872	19798U	PARTICIPANT	\N	PRESENT	0
775513	761872	14147R	PARTICIPANT	\N	PRESENT	0
775514	761872	19693L	PARTICIPANT	\N	PRESENT	0
775515	761872	11045K	PARTICIPANT	\N	PRESENT	0
775521	761872	19866P	PARTICIPANT	\N	PRESENT	0
775524	761872	19749K	PRESIDENT	0	PRESENT	0
775525	761872	14109K	PARTICIPANT	\N	PRESENT	0
775526	761872	14030Q	PARTICIPANT	\N	PRESENT	0
775527	761872	21089R	PARTICIPANT	\N	PRESENT	0
775528	761872	18193Q	PARTICIPANT	\N	PRESENT	0
775529	761872	14189C	PARTICIPANT	\N	PRESENT	0
775534	761872	21034A	PARTICIPANT	\N	EXCUSE	0
775535	761872	20114U	PARTICIPANT	\N	EXCUSE	0
775536	761872	19553Y	PARTICIPANT	\N	EXCUSE	0
775537	761872	20180F	PARTICIPANT	\N	PRESENT	0
775540	761872	14223L	PARTICIPANT	\N	EXCUSE	0
775541	761872	21087P	PARTICIPANT	\N	EXCUSE	0
775545	761872	21038E	PARTICIPANT	\N	PRESENT	0
778888	778887	21044C	PARTICIPANT	\N	PRESENT	0
778889	778887	19749K	PARTICIPANT	\N	PRESENT	0
778891	778890	21044C	PARTICIPANT	\N	PRESENT	0
778893	778892	21044C	PARTICIPANT	\N	PRESENT	0
778894	778890	21043B	PARTICIPANT	\N	PRESENT	0
778895	778890	19749K	PARTICIPANT	\N	PRESENT	0
778902	778896	19649G	PARTICIPANT	\N	PRESENT	0
778905	778896	14053L	PARTICIPANT	\N	PRESENT	0
786056	783390	14038Y	PARTICIPANT	\N	PRESENT	0
786057	783390	14215L	PARTICIPANT	\N	PRESENT	0
786058	783390	19954N	PARTICIPANT	\N	PRESENT	0
786059	783390	20180F	PARTICIPANT	\N	PRESENT	0
786060	783390	11065P	PARTICIPANT	\N	PRESENT	0
786061	783390	07029T	PARTICIPANT	\N	PRESENT	0
786019	783390	14111D	PARTICIPANT	\N	PRESENT	0
786020	783390	14001X	PARTICIPANT	\N	PRESENT	0
786021	783390	21082J	PARTICIPANT	\N	PRESENT	0
786022	783390	21093M	PARTICIPANT	\N	PRESENT	0
786023	783390	20084G	PARTICIPANT	\N	PRESENT	0
786024	783390	21041Y	PARTICIPANT	\N	PRESENT	0
786025	783390	11053K	PARTICIPANT	\N	PRESENT	0
786062	783390	08010L	PARTICIPANT	\N	PRESENT	0
786376	786374	04008A	PARTICIPANT	\N	PRESENT	0
786028	783390	21084L	PARTICIPANT	\N	PRESENT	0
786029	783390	21052C	PARTICIPANT	\N	PRESENT	0
786030	783390	19711U	PARTICIPANT	\N	PRESENT	0
786031	783390	19575F	PARTICIPANT	\N	PRESENT	0
786032	783390	08018U	PARTICIPANT	\N	PRESENT	0
786033	783390	20128B	PARTICIPANT	\N	PRESENT	0
786034	783390	11072N	PARTICIPANT	\N	PRESENT	0
786035	783390	20132W	PARTICIPANT	\N	PRESENT	0
786036	783390	20062A	PARTICIPANT	\N	PRESENT	0
786037	783390	14237S	PARTICIPANT	\N	PRESENT	0
786038	783390	21086N	PARTICIPANT	\N	PRESENT	0
786039	783390	14133K	PARTICIPANT	\N	PRESENT	0
786040	783390	18207D	PARTICIPANT	\N	PRESENT	0
786041	783390	20100N	PARTICIPANT	\N	PRESENT	0
786042	783390	19713W	PARTICIPANT	\N	PRESENT	0
786377	786375	04008A	PARTICIPANT	\N	PRESENT	0
786044	783390	14147R	PARTICIPANT	\N	PRESENT	0
786045	783390	21049H	PARTICIPANT	\N	PRESENT	0
786046	783390	14030Q	PARTICIPANT	\N	PRESENT	0
786047	783390	19533U	PARTICIPANT	\N	PRESENT	0
786048	783390	21057H	PARTICIPANT	\N	PRESENT	0
786055	783390	14031R	PARTICIPANT	\N	PRESENT	0
789304	786623	17779H	PARTICIPANT	\N	PRESENT	0
789305	786623	14031R	PARTICIPANT	\N	PRESENT	0
789306	786623	14147R	PARTICIPANT	\N	PRESENT	0
789307	786623	04070G	PARTICIPANT	\N	PRESENT	0
789308	786623	21037D	PARTICIPANT	\N	PRESENT	0
789309	786623	14237S	PARTICIPANT	\N	PRESENT	0
789310	786623	11045K	PARTICIPANT	\N	PRESENT	0
789311	786623	20044X	PARTICIPANT	\N	PRESENT	0
789312	786623	19687N	PARTICIPANT	\N	PRESENT	0
789313	786623	21079P	PARTICIPANT	\N	PRESENT	0
789314	786623	19301E	PARTICIPANT	\N	PRESENT	0
789315	786623	20058E	PARTICIPANT	\N	PRESENT	0
789417	789415	04042C	PARTICIPANT	\N	EXCUSE	0
789418	789415	14219Q	PARTICIPANT	\N	EXCUSE	0
789425	789424	21038E	PARTICIPANT	\N	PRESENT	0
789516	789263	19301E	PARTICIPANT	\N	PRESENT	0
789517	789277	14053L	PARTICIPANT	\N	PRESENT	0
789518	789277	21044C	PARTICIPANT	\N	PRESENT	0
789519	789277	19447X	PARTICIPANT	\N	PRESENT	0
789520	789277	08018U	PARTICIPANT	\N	PRESENT	0
789521	789277	21095P	PARTICIPANT	\N	PRESENT	0
789522	789277	04008A	PARTICIPANT	\N	PRESENT	0
789523	789277	10015M	PARTICIPANT	\N	PRESENT	0
789524	789277	14215L	PARTICIPANT	\N	PRESENT	0
789525	789277	14189C	PARTICIPANT	\N	PRESENT	0
789526	789277	20098N	PARTICIPANT	\N	PRESENT	0
789527	789277	20036X	PARTICIPANT	\N	PRESENT	0
789528	789277	20074E	PARTICIPANT	\N	PRESENT	0
789529	789277	04047H	PRESIDENT	0	PRESENT	0
789530	789277	20110Q	PARTICIPANT	\N	PRESENT	0
789531	789277	14147R	PARTICIPANT	\N	PRESENT	0
789532	789277	21056G	PARTICIPANT	\N	PRESENT	0
789533	789263	04047H	PARTICIPANT	\N	PRESENT	0
789534	789263	04008A	PARTICIPANT	\N	PRESENT	0
789535	789263	20110Q	PARTICIPANT	\N	PRESENT	0
789536	789263	21088Q	PARTICIPANT	\N	PRESENT	0
789537	789263	21040X	PARTICIPANT	\N	PRESENT	0
789538	789263	04045F	PARTICIPANT	\N	PRESENT	0
789539	789263	18231D	PARTICIPANT	\N	PRESENT	0
789540	789263	10015M	PARTICIPANT	\N	PRESENT	0
789541	789263	21074J	PARTICIPANT	\N	PRESENT	0
789542	789263	21076L	PARTICIPANT	\N	PRESENT	0
789543	789263	14089Y	PARTICIPANT	\N	PRESENT	0
789546	789263	20108W	PARTICIPANT	\N	PRESENT	0
789548	789263	21095P	PARTICIPANT	\N	PRESENT	0
789564	789263	21085M	PARTICIPANT	\N	PRESENT	0
789572	789263	99004R	PARTICIPANT	\N	PRESENT	0
789573	789263	14053L	PARTICIPANT	\N	PRESENT	0
789574	789263	21066J	PARTICIPANT	\N	PRESENT	0
789575	789263	19826F	PARTICIPANT	\N	PRESENT	0
789576	789263	19798U	PARTICIPANT	\N	PRESENT	0
789577	789263	20102Q	PARTICIPANT	\N	PRESENT	0
789578	789263	19565D	PARTICIPANT	\N	PRESENT	0
789579	789263	21039F	PARTICIPANT	\N	PRESENT	0
789580	789263	21058J	PARTICIPANT	\N	PRESENT	0
789581	789263	04033B	PARTICIPANT	\N	PRESENT	0
789582	789263	14147R	PARTICIPANT	\N	PRESENT	0
789583	789263	20076G	PARTICIPANT	\N	PRESENT	0
789584	789263	14069U	PARTICIPANT	\N	PRESENT	0
789585	789263	19649G	PARTICIPANT	\N	PRESENT	0
789586	789263	20098N	PARTICIPANT	\N	PRESENT	0
789587	789263	21055F	PARTICIPANT	\N	PRESENT	0
789588	789263	14211G	PARTICIPANT	\N	PRESENT	0
789589	789263	14030Q	PARTICIPANT	\N	PRESENT	0
789590	789263	07004J	PARTICIPANT	\N	PRESENT	0
782062	779652	19611R	PARTICIPANT	\N	PRESENT	0
782693	779654	98022P	PARTICIPANT	\N	PRESENT	0
782694	782692	19691J	PARTICIPANT	\N	PRESENT	0
782695	782692	19703U	PARTICIPANT	\N	PRESENT	0
782696	779654	19447X	PARTICIPANT	\N	PRESENT	0
782697	779654	14042U	PARTICIPANT	\N	PRESENT	0
782698	779654	19629C	PARTICIPANT	\N	PRESENT	0
782699	779654	19479G	PARTICIPANT	\N	PRESENT	0
782700	779654	20038A	PARTICIPANT	\N	PRESENT	0
782701	779654	18395Y	PARTICIPANT	\N	PRESENT	0
782702	779654	19593H	PARTICIPANT	\N	PRESENT	0
782703	779654	20134Y	PARTICIPANT	\N	PRESENT	0
782704	779654	14217N	PARTICIPANT	\N	PRESENT	0
782705	779654	19347U	PARTICIPANT	\N	PRESENT	0
782706	779654	19611R	PARTICIPANT	\N	PRESENT	0
782707	779654	14071N	PARTICIPANT	\N	PRESENT	0
782708	779654	19383Y	PARTICIPANT	\N	PRESENT	0
782709	782692	14281W	PARTICIPANT	\N	PRESENT	0
782711	779654	20100N	PARTICIPANT	\N	PRESENT	0
782714	779654	20126Y	PARTICIPANT	\N	PRESENT	0
782720	779654	20062A	PARTICIPANT	\N	PRESENT	0
782721	779654	20070A	PARTICIPANT	\N	PRESENT	0
782836	779655	21052C	PARTICIPANT	\N	PRESENT	0
782837	779655	21076L	PARTICIPANT	\N	PRESENT	0
782838	779655	19760E	PARTICIPANT	\N	PRESENT	0
782839	779655	14069U	PARTICIPANT	\N	PRESENT	0
782840	779655	18395Y	PARTICIPANT	\N	PRESENT	0
782841	779655	20100N	PARTICIPANT	\N	PRESENT	0
782842	779655	14147R	PARTICIPANT	\N	PRESENT	0
782843	779655	20086J	PARTICIPANT	\N	PRESENT	0
782844	779655	19531S	PARTICIPANT	\N	PRESENT	0
782845	779655	04045F	PARTICIPANT	\N	PRESENT	0
782846	779655	20126Y	PARTICIPANT	\N	PRESENT	0
783410	783409	19713W	PARTICIPANT	\N	PRESENT	0
783412	783411	20114U	PARTICIPANT	\N	PRESENT	0
783413	783411	19545Y	PARTICIPANT	\N	PRESENT	0
783414	783411	21057H	PARTICIPANT	\N	PRESENT	0
783415	783411	17023S	PARTICIPANT	\N	PRESENT	0
783416	783411	20120S	PARTICIPANT	\N	PRESENT	0
783417	783411	14021P	PARTICIPANT	\N	PRESENT	0
783418	783411	19723Y	PARTICIPANT	\N	PRESENT	0
783419	783411	14147R	PARTICIPANT	\N	PRESENT	0
783420	783411	14223L	PARTICIPANT	\N	PRESENT	0
783421	783411	19745F	PARTICIPANT	\N	PRESENT	0
783422	783411	20118Y	PARTICIPANT	\N	PRESENT	0
783423	783411	21070E	PARTICIPANT	\N	PRESENT	0
783424	783411	21059K	PARTICIPANT	\N	PRESENT	0
783425	783411	21049H	PARTICIPANT	\N	PRESENT	0
783426	783411	19713W	PARTICIPANT	\N	PRESENT	0
783428	783427	14151M	PARTICIPANT	\N	PRESENT	0
783429	783427	07033P	PARTICIPANT	\N	PRESENT	0
783430	783401	14151M	PRESIDENT	0	PRESENT	0
783431	783401	17367Q	PARTICIPANT	\N	PRESENT	0
783432	783401	20146D	PARTICIPANT	\N	PRESENT	0
783433	783401	12028B	PARTICIPANT	\N	PRESENT	0
783434	783401	14255U	PARTICIPANT	\N	PRESENT	0
783435	783401	20252E	PARTICIPANT	\N	PRESENT	0
782807	780815	20086J	PARTICIPANT	\N	PRESENT	0
782808	780815	21052C	PARTICIPANT	\N	PRESENT	0
782809	780815	19711U	PARTICIPANT	\N	PRESENT	0
782810	780815	14133K	PRESIDENT	0	PRESENT	0
782811	780815	21076L	PARTICIPANT	\N	PRESENT	0
782812	780815	21086N	PARTICIPANT	\N	PRESENT	0
782813	780815	14001X	PARTICIPANT	\N	PRESENT	0
782814	780815	11053K	PARTICIPANT	\N	PRESENT	0
782815	780815	20094J	PARTICIPANT	\N	PRESENT	0
782816	780815	14026U	PARTICIPANT	\N	PRESENT	0
782817	780815	14237S	PARTICIPANT	\N	PRESENT	0
782818	780815	21084L	PARTICIPANT	\N	PRESENT	0
782819	780815	21044C	PARTICIPANT	\N	PRESENT	0
782820	780815	20180F	PARTICIPANT	\N	PRESENT	0
782821	780815	20106U	PARTICIPANT	\N	PRESENT	0
782822	780815	19507S	PARTICIPANT	\N	PRESENT	0
782823	780815	18207D	PARTICIPANT	\N	PRESENT	0
782824	780815	14147R	PARTICIPANT	\N	PRESENT	0
782825	780815	19575F	PARTICIPANT	\N	PRESENT	0
782826	780815	11065P	PARTICIPANT	\N	PRESENT	0
782827	780815	20084G	PARTICIPANT	\N	PRESENT	0
782828	780815	14031R	PARTICIPANT	\N	EXCUSE	0
782829	780815	21057H	PARTICIPANT	\N	EXCUSE	0
782830	780815	14219Q	PARTICIPANT	\N	EXCUSE	0
782831	780815	19251M	PARTICIPANT	\N	EXCUSE	0
782832	780815	20114U	PARTICIPANT	\N	EXCUSE	0
782833	780815	19826F	PARTICIPANT	\N	EXCUSE	0
782834	780815	20022R	PARTICIPANT	\N	EXCUSE	0
782835	779655	21044C	PARTICIPANT	\N	PRESENT	0
783741	783372	14111D	PARTICIPANT	\N	PRESENT	0
783742	783394	14331P	PARTICIPANT	\N	PRESENT	0
783743	783394	11048N	PARTICIPANT	\N	PRESENT	0
783744	783394	11070L	PARTICIPANT	\N	PRESENT	0
783745	783394	14327T	PARTICIPANT	\N	PRESENT	0
783746	783394	19349W	PARTICIPANT	\N	PRESENT	0
783747	783394	14225N	PRESIDENT	0	PRESENT	0
783748	783394	20024T	PARTICIPANT	\N	PRESENT	0
783749	783394	20134Y	PARTICIPANT	\N	PRESENT	0
783750	783394	19711U	PARTICIPANT	\N	PRESENT	0
783751	783394	19687N	PARTICIPANT	\N	PRESENT	0
783752	783394	20044X	PARTICIPANT	\N	PRESENT	0
783753	783394	07029T	PARTICIPANT	\N	PRESENT	0
783754	783394	20070A	PARTICIPANT	\N	PRESENT	0
783755	783394	21090J	PARTICIPANT	\N	PRESENT	0
783756	783394	20126Y	PARTICIPANT	\N	PRESENT	0
783757	783394	20080C	PARTICIPANT	\N	PRESENT	0
783758	783394	20094J	PARTICIPANT	\N	PRESENT	0
783759	783394	14083S	PARTICIPANT	\N	PRESENT	0
783760	783394	19573D	PARTICIPANT	\N	PRESENT	0
783761	783394	07004J	PARTICIPANT	\N	PRESENT	0
783762	783394	08009T	PARTICIPANT	\N	PRESENT	0
783763	783394	19335Q	PARTICIPANT	\N	PRESENT	0
783764	783394	11053K	PARTICIPANT	\N	PRESENT	0
783765	783394	08010L	PARTICIPANT	\N	PRESENT	0
783766	783372	20030R	PARTICIPANT	\N	PRESENT	0
783767	783372	20028X	PARTICIPANT	\N	PRESENT	0
783768	783372	21083K	PARTICIPANT	\N	PRESENT	0
783769	783372	19679N	PARTICIPANT	\N	PRESENT	0
783770	783372	14038Y	PARTICIPANT	\N	PRESENT	0
783771	783372	19820Y	PARTICIPANT	\N	PRESENT	0
783772	783372	21053D	PARTICIPANT	\N	PRESENT	0
783773	783394	20116W	PARTICIPANT	\N	PRESENT	0
783774	783394	19647E	PARTICIPANT	\N	PRESENT	0
783775	783372	18083K	PARTICIPANT	\N	PRESENT	0
783776	783372	08010L	PARTICIPANT	\N	PRESENT	0
783777	783372	19719D	PARTICIPANT	\N	PRESENT	0
783781	783372	19685L	PARTICIPANT	\N	PRESENT	0
783806	783803	21037D	PARTICIPANT	\N	PRESENT	0
783780	783372	20086J	PARTICIPANT	\N	PRESENT	0
783804	783803	19565D	PARTICIPANT	\N	PRESENT	0
783805	783803	20132W	PARTICIPANT	\N	PRESENT	0
783807	783803	19575F	PARTICIPANT	\N	PRESENT	0
783808	783803	14069U	PARTICIPANT	\N	PRESENT	0
783809	783803	20126Y	PARTICIPANT	\N	PRESENT	0
783810	783803	14059S	PARTICIPANT	\N	PRESENT	0
783811	783803	21082J	PARTICIPANT	\N	PRESENT	0
783812	783803	20052X	PARTICIPANT	\N	PRESENT	0
783813	783803	14255U	PARTICIPANT	\N	PRESENT	0
783815	783803	14042U	PARTICIPANT	\N	PRESENT	0
783853	783098	14001X	PARTICIPANT	\N	PRESENT	0
783854	783098	20084G	PARTICIPANT	\N	PRESENT	0
783855	783098	14026U	PARTICIPANT	\N	PRESENT	0
783856	783098	21044C	PARTICIPANT	\N	PRESENT	0
783860	783381	21055F	PARTICIPANT	\N	PRESENT	0
783858	783381	14259Y	PARTICIPANT	\N	PRESENT	0
783859	783381	11070L	PARTICIPANT	\N	PRESENT	0
783861	783381	14331P	PARTICIPANT	\N	PRESENT	0
783862	783381	11048N	PARTICIPANT	\N	PRESENT	0
783863	783381	21029D	PARTICIPANT	\N	PRESENT	0
783864	783381	20090E	PARTICIPANT	\N	PRESENT	0
783865	783381	21090J	PARTICIPANT	\N	PRESENT	0
783866	783381	19782L	PARTICIPANT	\N	PRESENT	0
783867	783381	20032T	PARTICIPANT	\N	PRESENT	0
783868	783402	14089Y	PARTICIPANT	\N	EXCUSE	0
783869	783402	21043B	PARTICIPANT	\N	EXCUSE	0
783870	783402	19649G	PARTICIPANT	\N	EXCUSE	0
783871	783402	18231D	PARTICIPANT	\N	EXCUSE	0
783872	783402	20110Q	PARTICIPANT	\N	EXCUSE	0
783873	783402	21088Q	PARTICIPANT	\N	EXCUSE	0
783874	783402	19111A	PARTICIPANT	\N	EXCUSE	0
783875	783402	04047H	PARTICIPANT	\N	EXCUSE	0
783876	783402	20022R	PARTICIPANT	\N	EXCUSE	0
783877	783402	19673G	PARTICIPANT	\N	EXCUSE	0
783878	783402	19447X	PARTICIPANT	\N	EXCUSE	0
773254	773252	11048N	PARTICIPANT	\N	PRESENT	0
774512	774509	04047H	PARTICIPANT	\N	PRESENT	0
774510	774509	86034E	PARTICIPANT	\N	PRESENT	0
774511	774509	19621T	PARTICIPANT	\N	PRESENT	0
774513	774509	19629C	PARTICIPANT	\N	PRESENT	0
774514	774509	11056N	PARTICIPANT	\N	PRESENT	0
774515	774509	14187A	PARTICIPANT	\N	PRESENT	0
774516	774509	19347U	PARTICIPANT	\N	PRESENT	0
774517	774509	14026U	PARTICIPANT	\N	PRESENT	0
774518	774509	11048N	PARTICIPANT	\N	PRESENT	0
774519	774509	14021P	PARTICIPANT	\N	PRESENT	0
774520	774509	08010L	PARTICIPANT	\N	PRESENT	0
774521	774509	14111D	PARTICIPANT	\N	PRESENT	0
774522	774509	11085T	PARTICIPANT	\N	PRESENT	0
774523	774509	19593H	PARTICIPANT	\N	PRESENT	0
774524	774509	08047A	PARTICIPANT	\N	PRESENT	0
774525	774509	11090Q	PARTICIPANT	\N	PRESENT	0
774526	774509	14331P	PARTICIPANT	\N	PRESENT	0
774527	774509	14225N	PARTICIPANT	\N	PRESENT	0
774528	774509	04033B	PARTICIPANT	\N	PRESENT	0
774529	774509	14229S	PARTICIPANT	\N	PRESENT	0
774530	774509	04045F	PARTICIPANT	\N	PRESENT	0
774531	774509	21069M	PARTICIPANT	\N	PRESENT	0
774532	774509	19479G	PARTICIPANT	\N	PRESENT	0
774628	772448	17367Q	PARTICIPANT	\N	EXCUSE	0
774906	772441	19691J	PARTICIPANT	\N	PRESENT	0
774907	772441	19745F	PARTICIPANT	\N	EXCUSE	0
774908	772441	11090Q	PARTICIPANT	\N	EXCUSE	0
774909	761872	20038A	PARTICIPANT	\N	EXCUSE	0
774910	761872	21044C	PARTICIPANT	\N	EXCUSE	0
774911	761872	21042A	PARTICIPANT	\N	EXCUSE	0
774912	761872	21061D	PARTICIPANT	\N	EXCUSE	0
775278	775268	14026U	PARTICIPANT	\N	PRESENT	0
775279	775268	21066J	PARTICIPANT	\N	PRESENT	0
775280	775269	21086N	PARTICIPANT	\N	PRESENT	0
775281	775269	14026U	PARTICIPANT	\N	PRESENT	0
775276	775268	21086N	PARTICIPANT	\N	PRESENT	0
775277	775268	19575F	PARTICIPANT	\N	PRESENT	0
775312	775270	21086N	PARTICIPANT	\N	PRESENT	0
775313	775270	14026U	PARTICIPANT	\N	PRESENT	0
775314	775271	21086N	PARTICIPANT	\N	PRESENT	0
775315	775271	14026U	PARTICIPANT	\N	PRESENT	0
777211	777209	20106U	PARTICIPANT	\N	PRESENT	0
777212	777209	21073H	PARTICIPANT	\N	PRESENT	0
777213	777209	11048N	PARTICIPANT	\N	PRESENT	0
777214	777209	14059S	PARTICIPANT	\N	PRESENT	0
777215	777209	20118Y	PARTICIPANT	\N	PRESENT	0
777216	777209	21032X	PARTICIPANT	\N	PRESENT	0
778401	777918	21049H	PARTICIPANT	\N	EXCUSE	0
778402	777919	14195A	PARTICIPANT	\N	EXCUSE	0
778403	777919	04092N	PARTICIPANT	\N	EXCUSE	0
778404	777919	21049H	PARTICIPANT	\N	EXCUSE	0
778405	775944	17737W	PARTICIPANT	\N	PRESENT	0
778406	775944	19711U	PARTICIPANT	\N	PRESENT	0
778407	775944	08034U	PARTICIPANT	\N	PRESENT	0
778408	775944	19709B	PARTICIPANT	\N	PRESENT	0
778409	775944	14001X	PARTICIPANT	\N	PRESENT	0
778410	775944	14331P	PRESIDENT	0	PRESENT	0
778411	775944	20286Q	PARTICIPANT	\N	EXCUSE	0
778412	775944	20042V	PARTICIPANT	\N	PRESENT	0
778413	775944	18207D	PARTICIPANT	\N	PRESENT	0
778414	775944	19701S	PARTICIPANT	\N	PRESENT	0
778415	775944	20248J	PARTICIPANT	\N	PRESENT	0
778474	775944	21037D	PARTICIPANT	\N	PRESENT	0
783020	779282	14189C	PARTICIPANT	\N	PRESENT	0
783025	779282	19111A	PARTICIPANT	\N	PRESENT	0
785480	783387	08015R	PARTICIPANT	\N	PRESENT	0
796543	796541	21045D	PARTICIPANT	\N	PRESENT	0
796544	796541	19545Y	PARTICIPANT	\N	PRESENT	0
796546	796541	14357A	PARTICIPANT	\N	PRESENT	0
796547	796541	20248J	PARTICIPANT	\N	PRESENT	0
796548	796541	20172F	PARTICIPANT	\N	PRESENT	0
796549	796541	21092L	PARTICIPANT	\N	PRESENT	0
796550	796541	21044C	PARTICIPANT	\N	PRESENT	0
796551	796541	19697Q	PARTICIPANT	\N	EXCUSE	0
796552	796541	21058J	PARTICIPANT	\N	PRESENT	0
796553	796541	21040X	PARTICIPANT	\N	PRESENT	0
796554	796541	21039F	PARTICIPANT	\N	PRESENT	0
796555	796541	21080G	PARTICIPANT	\N	PRESENT	0
796556	796541	21047F	PARTICIPANT	\N	PRESENT	0
796557	796541	20054A	PRESIDENT	0	PRESENT	0
796558	796541	21064G	PARTICIPANT	\N	PRESENT	0
796576	796541	21067K	PARTICIPANT	\N	EXCUSE	0
796577	796541	19719D	PARTICIPANT	\N	EXCUSE	0
796578	796541	14083S	PARTICIPANT	\N	EXCUSE	0
796579	796541	20052X	PARTICIPANT	\N	EXCUSE	0
796580	796541	21088Q	PARTICIPANT	\N	EXCUSE	0
796581	796541	21050A	PARTICIPANT	\N	EXCUSE	0
796582	796541	08015R	PARTICIPANT	\N	EXCUSE	0
796583	796541	21052C	PARTICIPANT	\N	EXCUSE	0
796584	796541	20030R	PARTICIPANT	\N	EXCUSE	0
796585	796541	20126Y	PARTICIPANT	\N	EXCUSE	0
796586	796541	20078J	PARTICIPANT	\N	EXCUSE	0
796587	796541	20144B	PARTICIPANT	\N	EXCUSE	0
796588	796541	19295A	PARTICIPANT	\N	EXCUSE	0
796589	796541	19563B	PARTICIPANT	\N	EXCUSE	0
796649	794075	21065H	PARTICIPANT	\N	PRESENT	0
796650	794075	19383Y	PARTICIPANT	\N	PRESENT	0
796651	794075	14059S	PARTICIPANT	\N	PRESENT	0
796652	794075	21029D	PARTICIPANT	\N	PRESENT	0
796653	794075	21078N	PARTICIPANT	\N	PRESENT	0
796654	794075	19866P	PARTICIPANT	\N	PRESENT	0
796655	794075	21057H	PARTICIPANT	\N	PRESENT	0
796656	794075	21049H	PARTICIPANT	\N	PRESENT	0
796657	794075	20042V	PARTICIPANT	\N	PRESENT	0
796658	794075	11053K	PARTICIPANT	\N	PRESENT	0
796659	794075	14205J	PARTICIPANT	\N	PRESENT	0
796660	794075	19593H	PARTICIPANT	\N	PRESENT	0
796661	794075	19695N	PARTICIPANT	\N	PRESENT	0
796662	794075	19758L	PARTICIPANT	\N	PRESENT	0
796663	794075	20028X	PARTICIPANT	\N	PRESENT	0
796664	794075	08060W	PARTICIPANT	\N	PRESENT	0
796665	794075	19782L	PARTICIPANT	\N	PRESENT	0
796666	794075	20150Y	PARTICIPANT	\N	PRESENT	0
796667	794075	20018V	PARTICIPANT	\N	PRESENT	0
796668	794075	19251M	PARTICIPANT	\N	PRESENT	0
796669	794075	14121F	PARTICIPANT	\N	PRESENT	0
796670	794075	19301E	PARTICIPANT	\N	PRESENT	0
796671	794075	21092L	PARTICIPANT	\N	PRESENT	0
796672	794075	19649G	PARTICIPANT	\N	PRESENT	0
796673	794075	11085T	PARTICIPANT	\N	PRESENT	0
796674	794075	14281W	PARTICIPANT	\N	PRESENT	0
796675	794075	17229F	PARTICIPANT	\N	PRESENT	0
796676	794075	21086N	PARTICIPANT	\N	PRESENT	0
796677	794075	21084L	PARTICIPANT	\N	PRESENT	0
796678	794075	19565D	PARTICIPANT	\N	PRESENT	0
796679	794075	20102Q	PARTICIPANT	\N	PRESENT	0
796680	794075	21075K	PARTICIPANT	\N	PRESENT	0
796681	794075	19687N	PARTICIPANT	\N	PRESENT	0
796682	794075	11065P	PARTICIPANT	\N	PRESENT	0
796683	794075	19347U	PARTICIPANT	\N	PRESENT	0
796684	794075	21093M	PARTICIPANT	\N	PRESENT	0
796685	794075	20142Y	PARTICIPANT	\N	PRESENT	0
796686	794075	20092G	PARTICIPANT	\N	PRESENT	0
796687	794075	21079P	PARTICIPANT	\N	PRESENT	0
796688	794075	19621T	PARTICIPANT	\N	PRESENT	0
796689	794075	21037D	PARTICIPANT	\N	PRESENT	0
796690	794075	18083K	PARTICIPANT	\N	PRESENT	0
796691	794075	19711U	PARTICIPANT	\N	PRESENT	0
796692	794075	21074J	PARTICIPANT	\N	PRESENT	0
796693	794075	21085M	PARTICIPANT	\N	PRESENT	0
796694	794075	21091K	PARTICIPANT	\N	PRESENT	0
796695	794075	21069M	PARTICIPANT	\N	PRESENT	0
796696	794075	99004R	PARTICIPANT	\N	PRESENT	0
796697	794075	21073H	PARTICIPANT	\N	PRESENT	0
796698	794075	20076G	PARTICIPANT	\N	PRESENT	0
796699	794075	21043B	PARTICIPANT	\N	PRESENT	0
796700	794075	21096Q	PARTICIPANT	\N	PRESENT	0
796701	794075	20078J	PARTICIPANT	\N	PRESENT	0
796702	794075	20106U	PARTICIPANT	\N	PRESENT	0
796703	794075	08069G	PARTICIPANT	\N	PRESENT	0
796704	794075	20128B	PARTICIPANT	\N	PRESENT	0
796705	794075	04042C	PARTICIPANT	\N	PRESENT	0
796706	794075	14037X	PARTICIPANT	\N	PRESENT	0
796707	794075	11072N	PARTICIPANT	\N	PRESENT	0
796708	794075	14169X	PARTICIPANT	\N	PRESENT	0
796709	794075	21097R	PARTICIPANT	\N	PRESENT	0
796710	794075	19573D	PARTICIPANT	\N	PRESENT	0
796711	794075	14223L	PARTICIPANT	\N	PRESENT	0
796712	794075	08061X	PARTICIPANT	\N	PRESENT	0
796713	794075	20146D	PARTICIPANT	\N	PRESENT	0
796714	794075	19349W	PARTICIPANT	\N	PRESENT	0
771827	769239	19593H	PARTICIPANT	\N	PRESENT	0
771828	769239	11072N	PARTICIPANT	\N	PRESENT	0
771829	769239	19479G	PARTICIPANT	\N	PRESENT	0
771830	769239	21085M	PARTICIPANT	\N	PRESENT	0
771833	770926	08010L	PARTICIPANT	\N	PRESENT	0
771836	769239	20060X	PARTICIPANT	\N	PRESENT	0
771840	769239	08061X	PARTICIPANT	\N	PRESENT	0
771841	769239	21031W	PARTICIPANT	\N	PRESENT	0
771842	769239	19347U	PARTICIPANT	\N	PRESENT	0
771843	769239	20052X	PARTICIPANT	\N	PRESENT	0
771844	769239	19699S	PARTICIPANT	\N	PRESENT	0
771845	769239	21056G	PARTICIPANT	\N	PRESENT	0
771846	769239	20138D	PARTICIPANT	\N	PRESENT	0
771847	769239	14223L	PARTICIPANT	\N	PRESENT	0
771848	769239	08028W	PARTICIPANT	\N	PRESENT	0
771849	769239	20030R	PARTICIPANT	\N	PRESENT	0
771850	769239	20120S	PARTICIPANT	\N	PRESENT	0
771851	769239	21069M	PARTICIPANT	\N	PRESENT	0
771852	769239	14187A	PARTICIPANT	\N	PRESENT	0
771853	769239	21062E	PARTICIPANT	\N	PRESENT	0
771854	769239	05008E	PARTICIPANT	\N	PRESENT	0
771855	769239	21067K	PARTICIPANT	\N	PRESENT	0
771856	769239	14097Y	PARTICIPANT	\N	PRESENT	0
771857	769239	08056B	PARTICIPANT	\N	PRESENT	0
771858	769239	17737W	PARTICIPANT	\N	PRESENT	0
771859	769239	18193Q	PARTICIPANT	\N	PRESENT	0
771860	769239	14207L	PARTICIPANT	\N	PRESENT	0
771862	769239	17367Q	PARTICIPANT	\N	PRESENT	0
772161	762526	19667J	PARTICIPANT	\N	PRESENT	0
772162	762526	11040E	PARTICIPANT	\N	PRESENT	0
773647	773264	21071F	PARTICIPANT	\N	PRESENT	0
773648	773264	20130U	PARTICIPANT	\N	PRESENT	0
773651	773649	21071F	PARTICIPANT	\N	PRESENT	0
773652	773649	20130U	PARTICIPANT	\N	PRESENT	0
773893	773892	21094N	PARTICIPANT	\N	PRESENT	0
773902	773901	19749K	PARTICIPANT	\N	PRESENT	0
773903	773901	14053L	PARTICIPANT	\N	PRESENT	0
773905	773904	14053L	PARTICIPANT	\N	PRESENT	0
773906	773904	19749K	PARTICIPANT	\N	PRESENT	0
773908	773907	19649G	PARTICIPANT	\N	PRESENT	0
773909	773907	14053L	PARTICIPANT	\N	PRESENT	0
773910	773907	19749K	PARTICIPANT	\N	PRESENT	0
773912	773911	21044C	PARTICIPANT	\N	PRESENT	0
774252	769595	20058E	PARTICIPANT	\N	PRESENT	0
775627	775610	07029T	PARTICIPANT	\N	PRESENT	0
775628	775610	20062A	PARTICIPANT	\N	PRESENT	0
775629	775610	21079P	PARTICIPANT	\N	PRESENT	0
775630	775610	19573D	PARTICIPANT	\N	PRESENT	0
775631	775610	20070A	PARTICIPANT	\N	PRESENT	0
775632	775610	14121F	PARTICIPANT	\N	PRESENT	0
775633	775610	20116W	PARTICIPANT	\N	PRESENT	0
775634	775610	19667J	PARTICIPANT	\N	PRESENT	0
775635	775610	19545Y	PARTICIPANT	\N	PRESENT	0
775636	775610	11074Q	PARTICIPANT	\N	PRESENT	0
775637	775610	20134Y	PARTICIPANT	\N	PRESENT	0
775638	775610	14331P	PARTICIPANT	\N	PRESENT	0
775642	775610	20126Y	PARTICIPANT	\N	PRESENT	0
775643	775610	19647E	PARTICIPANT	\N	PRESENT	0
775684	775674	19251M	PARTICIPANT	\N	PRESENT	0
775685	775674	21066J	PARTICIPANT	\N	PRESENT	0
775686	775674	20172F	PARTICIPANT	\N	PRESENT	0
775687	775674	14031R	PARTICIPANT	\N	PRESENT	0
775689	775688	14031R	PARTICIPANT	\N	PRESENT	0
775690	775688	21066J	PARTICIPANT	\N	PRESENT	0
775691	775688	20172F	PARTICIPANT	\N	PRESENT	0
775770	772133	14331P	PRESIDENT	0	PRESENT	0
775771	772133	21076L	PARTICIPANT	\N	PRESENT	0
775772	772133	10015M	PARTICIPANT	\N	PRESENT	0
775773	772133	08034U	PARTICIPANT	\N	PRESENT	0
775774	772133	19701S	PARTICIPANT	\N	PRESENT	0
775775	772133	14001X	PARTICIPANT	\N	PRESENT	0
775776	772133	14097Y	PARTICIPANT	\N	PRESENT	0
775777	772133	14073Q	PARTICIPANT	\N	PRESENT	0
775779	772133	20104S	PARTICIPANT	\N	PRESENT	0
775780	772133	14189C	PARTICIPANT	\N	PRESENT	0
775781	772133	18395Y	PARTICIPANT	\N	PRESENT	0
775782	772133	14357A	PARTICIPANT	\N	PRESENT	0
775783	772133	19760E	PARTICIPANT	\N	PRESENT	0
775785	772133	20286Q	PARTICIPANT	\N	PRESENT	0
775786	772133	14033T	PARTICIPANT	\N	PRESENT	0
775787	772133	21082J	PARTICIPANT	\N	PRESENT	0
775788	772133	21037D	PARTICIPANT	\N	PRESENT	0
775789	772133	19713W	PARTICIPANT	\N	PRESENT	0
775790	772133	20042V	PARTICIPANT	\N	EXCUSE	0
775792	772133	20106U	PARTICIPANT	\N	EXCUSE	0
775794	772133	14237S	PARTICIPANT	\N	EXCUSE	0
775795	772133	20098N	PARTICIPANT	\N	EXCUSE	0
776069	776068	19709B	PARTICIPANT	\N	PRESENT	0
776074	776073	19709B	PARTICIPANT	\N	PRESENT	0
776075	776073	19347U	PARTICIPANT	\N	PRESENT	0
776229	776228	08018U	PARTICIPANT	\N	PRESENT	0
776230	776228	19489J	PARTICIPANT	\N	PRESENT	0
776232	776231	08018U	PARTICIPANT	\N	PRESENT	0
776233	776231	19489J	PARTICIPANT	\N	PRESENT	0
776239	776236	08018U	PARTICIPANT	\N	PRESENT	0
776249	776247	08018U	PARTICIPANT	\N	PRESENT	0
776250	776247	19649G	PARTICIPANT	\N	PRESENT	0
776258	776256	08018U	PARTICIPANT	\N	PRESENT	0
776260	776259	08018U	PARTICIPANT	\N	PRESENT	0
776261	776259	20266L	PARTICIPANT	\N	PRESENT	0
776264	776263	08018U	PARTICIPANT	\N	PRESENT	0
776278	776277	14031R	PARTICIPANT	\N	PRESENT	0
776282	776281	14031R	PARTICIPANT	\N	PRESENT	0
776371	776370	04070G	PARTICIPANT	\N	PRESENT	0
776372	776370	19593H	PARTICIPANT	\N	PRESENT	0
776373	776370	19621T	PARTICIPANT	\N	PRESENT	0
776374	776367	04070G	PARTICIPANT	\N	PRESENT	0
776375	776367	14038Y	PARTICIPANT	\N	PRESENT	0
776376	776367	14179A	PARTICIPANT	\N	PRESENT	0
776377	776368	04070G	PARTICIPANT	\N	PRESENT	0
776378	776369	19621T	PARTICIPANT	\N	PRESENT	0
776379	776369	19593H	PARTICIPANT	\N	PRESENT	0
776380	776369	21077M	PARTICIPANT	\N	PRESENT	0
776381	776369	04070G	PARTICIPANT	\N	PRESENT	0
776569	772608	14229S	PARTICIPANT	\N	PRESENT	0
776570	772608	21079P	PARTICIPANT	\N	PRESENT	0
776571	772608	21054E	PARTICIPANT	\N	PRESENT	0
776572	772608	21040X	PARTICIPANT	\N	PRESENT	0
776573	772608	14257W	PARTICIPANT	\N	PRESENT	0
776574	772608	19687N	PARTICIPANT	\N	PRESENT	0
776575	772608	11040E	PARTICIPANT	\N	PRESENT	0
776576	772608	14083S	PARTICIPANT	\N	PRESENT	0
776577	772608	20062A	PARTICIPANT	\N	PRESENT	0
776578	772608	21086N	PARTICIPANT	\N	PRESENT	0
776579	772608	20070A	PARTICIPANT	\N	PRESENT	0
776580	772608	14253S	PARTICIPANT	\N	PRESENT	0
776581	772608	21069M	PARTICIPANT	\N	PRESENT	0
776582	772608	21033Y	PARTICIPANT	\N	PRESENT	0
776583	772608	20116W	PARTICIPANT	\N	PRESENT	0
776584	772608	21041Y	PARTICIPANT	\N	PRESENT	0
776585	772608	19575F	PARTICIPANT	\N	PRESENT	0
776586	772608	99004R	PARTICIPANT	\N	PRESENT	0
776587	772608	14225N	PARTICIPANT	\N	PRESENT	0
776588	772608	08011M	PARTICIPANT	\N	PRESENT	0
776589	772608	19631V	PARTICIPANT	\N	PRESENT	0
776590	772608	20124W	PARTICIPANT	\N	PRESENT	0
776591	772608	20034V	PARTICIPANT	\N	PRESENT	0
776592	772608	14038Y	PARTICIPANT	\N	PRESENT	0
776596	772608	19695N	PARTICIPANT	\N	PRESENT	0
776594	772608	11090Q	PARTICIPANT	\N	PRESENT	0
776595	772608	20044X	PARTICIPANT	\N	PRESENT	0
776597	772608	14069U	PARTICIPANT	\N	PRESENT	0
776598	772608	08010L	PARTICIPANT	\N	PRESENT	0
776599	772608	21037D	PARTICIPANT	\N	PRESENT	0
776600	772608	20028X	PARTICIPANT	\N	PRESENT	0
776609	772608	12016W	PARTICIPANT	\N	PRESENT	0
776602	772608	19331L	PARTICIPANT	\N	PRESENT	0
776607	772608	20082E	PARTICIPANT	\N	PRESENT	0
776605	772608	14205J	PARTICIPANT	\N	PRESENT	0
776608	772608	11048N	PARTICIPANT	\N	PRESENT	0
776610	772608	20092G	PARTICIPANT	\N	PRESENT	0
776611	772608	11110B	PARTICIPANT	\N	PRESENT	0
776612	772608	19768N	PARTICIPANT	\N	PRESENT	0
776613	772608	19705W	PARTICIPANT	\N	PRESENT	0
789593	789263	14026U	PARTICIPANT	\N	PRESENT	0
789594	789263	14215L	PARTICIPANT	\N	PRESENT	0
789595	789263	20024T	PARTICIPANT	\N	PRESENT	0
789596	789263	19673G	PARTICIPANT	\N	PRESENT	0
789597	789263	20026V	PARTICIPANT	\N	PRESENT	0
789598	789263	14189C	PARTICIPANT	\N	PRESENT	0
789599	789263	21044C	PARTICIPANT	\N	PRESENT	0
789600	789263	19331L	PARTICIPANT	\N	PRESENT	0
789601	789263	11056N	PARTICIPANT	\N	PRESENT	0
789602	789263	19447X	PARTICIPANT	\N	PRESENT	0
789603	789263	21089R	PARTICIPANT	\N	PRESENT	0
789604	789263	21077M	PARTICIPANT	\N	PRESENT	0
789605	789263	20032T	PARTICIPANT	\N	PRESENT	0
789606	789263	20086J	PARTICIPANT	\N	PRESENT	0
789607	789263	21075K	PARTICIPANT	\N	PRESENT	0
789608	789263	21072G	PARTICIPANT	\N	PRESENT	0
789609	789263	11085T	PARTICIPANT	\N	PRESENT	0
789610	789263	21070E	PARTICIPANT	\N	PRESENT	0
789611	789263	14111D	PARTICIPANT	\N	PRESENT	0
789612	789263	19585H	PARTICIPANT	\N	PRESENT	0
789620	789263	19679N	PARTICIPANT	\N	PRESENT	0
789614	789263	14205J	PARTICIPANT	\N	PRESENT	0
789615	789263	20264J	PARTICIPANT	\N	PRESENT	0
789616	789263	11110B	PARTICIPANT	\N	PRESENT	0
789617	789263	20090E	PARTICIPANT	\N	PRESENT	0
789618	789263	08061X	PARTICIPANT	\N	PRESENT	0
789619	789263	21068L	PARTICIPANT	\N	PRESENT	0
789621	789263	20056C	PARTICIPANT	\N	PRESENT	0
789622	789263	14107H	PARTICIPANT	\N	PRESENT	0
789623	789263	14223L	PARTICIPANT	\N	PRESENT	0
789624	789263	20062A	PARTICIPANT	\N	PRESENT	0
789627	789263	20082E	PARTICIPANT	\N	PRESENT	0
789633	789263	19723Y	PARTICIPANT	\N	PRESENT	0
789636	789263	14083S	PARTICIPANT	\N	PRESENT	0
789640	789263	14033T	PARTICIPANT	\N	PRESENT	0
789638	789263	20018V	PARTICIPANT	\N	PRESENT	0
789639	789263	17737W	PARTICIPANT	\N	PRESENT	0
789641	789263	20074E	PARTICIPANT	\N	PRESENT	0
789642	789263	19760E	PARTICIPANT	\N	PRESENT	0
789643	789263	20136B	PARTICIPANT	\N	PRESENT	0
789644	789263	14217N	PARTICIPANT	\N	PRESENT	0
789645	789263	11048N	PARTICIPANT	\N	PRESENT	0
789649	789263	19569H	PARTICIPANT	\N	PRESENT	0
789647	789263	20140W	PARTICIPANT	\N	PRESENT	0
789648	789263	14259Y	PARTICIPANT	\N	PRESENT	0
789650	789263	21097R	PARTICIPANT	\N	PRESENT	0
789651	789263	08056B	PARTICIPANT	\N	PRESENT	0
789658	789263	20134Y	PARTICIPANT	\N	PRESENT	0
789653	789263	20120S	PARTICIPANT	\N	PRESENT	0
789654	789263	19533U	PARTICIPANT	\N	PRESENT	0
789655	789263	14121F	PARTICIPANT	\N	PRESENT	0
789656	789263	20044X	PARTICIPANT	\N	PRESENT	0
789657	789263	19745F	PARTICIPANT	\N	PRESENT	0
789659	789263	19703U	PARTICIPANT	\N	PRESENT	0
789660	789263	19489J	PARTICIPANT	\N	PRESENT	0
789661	789263	18207D	PARTICIPANT	\N	PRESENT	0
789662	789263	20048C	PARTICIPANT	\N	PRESENT	0
789670	789263	19531S	PARTICIPANT	\N	PRESENT	0
789671	789263	21030V	PARTICIPANT	\N	PRESENT	0
789672	789263	20180F	PARTICIPANT	\N	PRESENT	0
789673	789263	14021P	PARTICIPANT	\N	PRESENT	0
789674	789263	19335Q	PARTICIPANT	\N	PRESENT	0
789675	789263	14042U	PARTICIPANT	\N	PRESENT	0
789676	789263	19399H	PARTICIPANT	\N	PRESENT	0
789677	789263	20054A	PARTICIPANT	\N	PRESENT	0
789678	789263	08028W	PARTICIPANT	\N	PRESENT	0
789679	789263	19593H	PARTICIPANT	\N	PRESENT	0
789680	789263	14123H	PARTICIPANT	\N	PRESENT	0
789591	789263	14191V	PARTICIPANT	\N	PRESENT	0
789592	789263	20038A	PARTICIPANT	\N	PRESENT	0
789681	789263	08045X	PARTICIPANT	\N	PRESENT	0
789682	789263	19573D	PARTICIPANT	\N	PRESENT	0
789683	789263	19383Y	PARTICIPANT	\N	PRESENT	0
789684	789263	19545Y	PARTICIPANT	\N	PRESENT	0
789685	789263	14031R	PARTICIPANT	\N	PRESENT	0
789702	789263	14207L	PARTICIPANT	\N	PRESENT	0
789703	789263	21073H	PARTICIPANT	\N	PRESENT	0
789704	789263	19479G	PARTICIPANT	\N	PRESENT	0
789705	789263	14133K	PARTICIPANT	\N	PRESENT	0
789706	789263	19725B	PARTICIPANT	\N	PRESENT	0
789707	789263	21059K	PARTICIPANT	\N	PRESENT	0
789708	789263	08015R	PARTICIPANT	\N	PRESENT	0
789709	789263	21046E	PARTICIPANT	\N	PRESENT	0
789710	789263	18083K	PARTICIPANT	\N	PRESENT	0
789711	789263	19713W	PARTICIPANT	\N	PRESENT	0
789712	789263	20124W	PARTICIPANT	\N	PRESENT	0
789713	789263	19701S	PARTICIPANT	\N	PRESENT	0
789717	789263	20052X	PARTICIPANT	\N	PRESENT	0
789720	789263	20112S	PARTICIPANT	\N	PRESENT	0
789721	789263	19367Y	PARTICIPANT	\N	PRESENT	0
789727	789263	14231L	PARTICIPANT	\N	PRESENT	0
789729	789263	19782L	PARTICIPANT	\N	PRESENT	0
789730	789263	19693L	PARTICIPANT	\N	PRESENT	0
789731	789263	05008E	PARTICIPANT	\N	PRESENT	0
789732	789263	20116W	PARTICIPANT	\N	PRESENT	0
789733	789263	20132W	PARTICIPANT	\N	PRESENT	0
789734	789263	19575F	PARTICIPANT	\N	PRESENT	0
789735	789263	21064G	PARTICIPANT	\N	PRESENT	0
789737	789263	14213J	PARTICIPANT	\N	PRESENT	0
789738	789263	20266L	PARTICIPANT	\N	PRESENT	0
789739	789263	20138D	PARTICIPANT	\N	PRESENT	0
789740	789263	19057M	PARTICIPANT	\N	PRESENT	0
789741	789263	14071N	PARTICIPANT	\N	PRESENT	0
789742	789263	14257W	PARTICIPANT	\N	PRESENT	0
789800	789265	19782L	PARTICIPANT	\N	PRESENT	0
789801	789265	19057M	PARTICIPANT	\N	PRESENT	0
789802	789265	20058E	PARTICIPANT	\N	PRESENT	0
789803	789265	14215L	PARTICIPANT	\N	PRESENT	0
789804	789265	20140W	PARTICIPANT	\N	PRESENT	0
789805	789265	21058J	PARTICIPANT	\N	PRESENT	0
789806	789265	20180F	PARTICIPANT	\N	PRESENT	0
789807	789265	20032T	PARTICIPANT	\N	PRESENT	0
789808	789265	08028W	PARTICIPANT	\N	PRESENT	0
789810	789265	20266L	PARTICIPANT	\N	PRESENT	0
789811	789265	14083S	PARTICIPANT	\N	PRESENT	0
789812	789265	14030Q	PARTICIPANT	\N	PRESENT	0
789813	789265	19479G	PARTICIPANT	\N	PRESENT	0
789814	789265	14231L	PARTICIPANT	\N	PRESENT	0
789815	789265	20116W	PARTICIPANT	\N	PRESENT	0
789816	789265	20132W	PARTICIPANT	\N	PRESENT	0
789817	789265	21040X	PARTICIPANT	\N	PRESENT	0
789818	789265	19693L	PARTICIPANT	\N	PRESENT	0
789819	789265	20098N	PARTICIPANT	\N	PRESENT	0
789820	789265	19507S	PARTICIPANT	\N	PRESENT	0
789821	789265	20138D	PARTICIPANT	\N	PRESENT	0
789822	789265	20056C	PARTICIPANT	\N	PRESENT	0
789823	789265	21063F	PARTICIPANT	\N	PRESENT	0
789824	789265	20264J	PARTICIPANT	\N	PRESENT	0
789825	789265	20102Q	PARTICIPANT	\N	PRESENT	0
789826	789265	19611R	PARTICIPANT	\N	PRESENT	0
789827	789265	20124W	PARTICIPANT	\N	PRESENT	0
789828	789265	21068L	PARTICIPANT	\N	PRESENT	0
789829	789265	14109K	PARTICIPANT	\N	PRESENT	0
789831	789830	11043H	PARTICIPANT	\N	PRESENT	0
789832	789830	19705W	PARTICIPANT	\N	PRESENT	0
789833	789265	19621T	PARTICIPANT	\N	PRESENT	0
789834	789265	18083K	PARTICIPANT	\N	PRESENT	0
789835	789265	21071F	PARTICIPANT	\N	PRESENT	0
789836	789265	14229S	PARTICIPANT	\N	PRESENT	0
789837	789265	20142Y	PARTICIPANT	\N	PRESENT	0
789838	789265	14123H	PARTICIPANT	\N	PRESENT	0
789839	789265	20054A	PARTICIPANT	\N	PRESENT	0
789840	789265	14071N	PARTICIPANT	\N	PRESENT	0
789841	789265	20024T	PARTICIPANT	\N	PRESENT	0
789842	789265	19703U	PARTICIPANT	\N	PRESENT	0
789843	789265	08056B	PARTICIPANT	\N	PRESENT	0
789844	789265	20038A	PARTICIPANT	\N	PRESENT	0
789845	789265	14191V	PARTICIPANT	\N	PRESENT	0
789846	789265	21044C	PARTICIPANT	\N	PRESENT	0
789847	789265	20128B	PARTICIPANT	\N	PRESENT	0
789848	789265	20080C	PARTICIPANT	\N	PRESENT	0
789849	789265	21079P	PARTICIPANT	\N	PRESENT	0
789850	789265	21073H	PARTICIPANT	\N	PRESENT	0
789851	789265	19629C	PARTICIPANT	\N	PRESENT	0
789852	789265	21055F	PARTICIPANT	\N	PRESENT	0
789853	789265	18395Y	PARTICIPANT	\N	PRESENT	0
789854	789265	19533U	PARTICIPANT	\N	PRESENT	0
789855	789265	19679N	PARTICIPANT	\N	PRESENT	0
789798	789265	19301E	PARTICIPANT	\N	PRESENT	0
789799	789265	20026V	PARTICIPANT	\N	PRESENT	0
783879	783381	20044X	PARTICIPANT	\N	PRESENT	0
783881	783381	19575F	PARTICIPANT	\N	PRESENT	0
783883	783381	21081H	PARTICIPANT	\N	PRESENT	0
783884	783402	19489J	PARTICIPANT	\N	PRESENT	0
783885	783402	14111D	PARTICIPANT	\N	PRESENT	0
783886	783402	21076L	PARTICIPANT	\N	PRESENT	0
783887	783402	10015M	PARTICIPANT	\N	PRESENT	0
783888	783402	14147R	PARTICIPANT	\N	PRESENT	0
783889	783402	19719D	PARTICIPANT	\N	PRESENT	0
783890	783402	05008E	PARTICIPANT	\N	PRESENT	0
783891	783381	19679N	PARTICIPANT	\N	PRESENT	0
783892	783381	19711U	PARTICIPANT	\N	PRESENT	0
783893	783381	20080C	PARTICIPANT	\N	PRESENT	0
783894	783381	19647E	PARTICIPANT	\N	PRESENT	0
783895	783381	21079P	PARTICIPANT	\N	PRESENT	0
783896	783381	20134Y	PARTICIPANT	\N	PRESENT	0
783897	783381	21046E	PARTICIPANT	\N	PRESENT	0
783898	783381	19545Y	PARTICIPANT	\N	PRESENT	0
783899	783381	19687N	PARTICIPANT	\N	PRESENT	0
783900	783381	11072N	PARTICIPANT	\N	PRESENT	0
783901	783381	14207L	PARTICIPANT	\N	PRESENT	0
783902	783381	08028W	PARTICIPANT	\N	PRESENT	0
783903	783381	20070A	PARTICIPANT	\N	PRESENT	0
783904	783381	19349W	PARTICIPANT	\N	PRESENT	0
783905	783381	14073Q	PARTICIPANT	\N	PRESENT	0
783906	783381	21083K	PARTICIPANT	\N	PRESENT	0
783907	783381	07004J	PARTICIPANT	\N	PRESENT	0
783908	783381	14327T	PARTICIPANT	\N	PRESENT	0
783909	783381	14205J	PARTICIPANT	\N	PRESENT	0
783910	783381	14083S	PARTICIPANT	\N	PRESENT	0
783911	783381	21068L	PARTICIPANT	\N	PRESENT	0
783912	783381	14225N	PARTICIPANT	\N	PRESENT	0
783913	783381	14069U	PARTICIPANT	\N	PRESENT	0
783914	783381	20116W	PARTICIPANT	\N	PRESENT	0
783915	783381	19553Y	PARTICIPANT	\N	PRESENT	0
783916	783402	14189C	PARTICIPANT	\N	PRESENT	0
783917	783402	21057H	PARTICIPANT	\N	PRESENT	0
783918	783402	08018U	PRESIDENT	0	PRESENT	0
783919	783402	21095P	PARTICIPANT	\N	PRESENT	0
783920	783402	19749K	PARTICIPANT	\N	PRESENT	0
783921	783381	21072G	PARTICIPANT	\N	PRESENT	0
783922	783381	21061D	PARTICIPANT	\N	PRESENT	0
783923	783381	20038A	PARTICIPANT	\N	PRESENT	0
783924	783381	19621T	PARTICIPANT	\N	PRESENT	0
783925	783381	21042A	PARTICIPANT	\N	PRESENT	0
783926	783381	20026V	PARTICIPANT	\N	PRESENT	0
783927	783381	21089R	PARTICIPANT	\N	PRESENT	0
783928	783381	14107H	PARTICIPANT	\N	PRESENT	0
783929	783381	14221J	PARTICIPANT	\N	PRESENT	0
783930	783381	19507S	PARTICIPANT	\N	PRESENT	0
783931	783381	20062A	PARTICIPANT	\N	PRESENT	0
783932	783381	19573D	PARTICIPANT	\N	PRESENT	0
783933	783381	19745F	PARTICIPANT	\N	PRESENT	0
783934	783381	20086J	PARTICIPANT	\N	PRESENT	0
783935	783381	20124W	PARTICIPANT	\N	PRESENT	0
783937	783381	14213J	PARTICIPANT	\N	PRESENT	0
783942	783381	21073H	PARTICIPANT	\N	PRESENT	0
783948	783402	21056G	PARTICIPANT	\N	PRESENT	0
783949	783402	18207D	PARTICIPANT	\N	PRESENT	0
783950	783381	14105F	PARTICIPANT	\N	PRESENT	0
783952	783381	08015R	PARTICIPANT	\N	PRESENT	0
783957	783381	14231L	PARTICIPANT	\N	PRESENT	0
783958	783381	20172F	PARTICIPANT	\N	PRESENT	0
783959	783381	19713W	PARTICIPANT	\N	PRESENT	0
783961	783381	14031R	PARTICIPANT	\N	PRESENT	0
783962	783381	14038Y	PARTICIPANT	\N	PRESENT	0
783963	783381	19820Y	PARTICIPANT	\N	PRESENT	0
783964	783381	20126Y	PARTICIPANT	\N	PRESENT	0
783965	783381	21047F	PARTICIPANT	\N	PRESENT	0
783966	783381	21051B	PARTICIPANT	\N	PRESENT	0
784279	784278	20252E	PARTICIPANT	\N	PRESENT	0
784280	784278	21048G	PARTICIPANT	\N	PRESENT	0
784281	784278	20024T	PARTICIPANT	\N	PRESENT	0
784282	784278	04042C	PARTICIPANT	\N	PRESENT	0
784283	784278	21057H	PARTICIPANT	\N	PRESENT	0
784284	784278	20120S	PARTICIPANT	\N	PRESENT	0
784285	784278	18193Q	PARTICIPANT	\N	PRESENT	0
784287	784278	21037D	PARTICIPANT	\N	PRESENT	0
784288	784278	21053D	PARTICIPANT	\N	PRESENT	0
784290	784278	19798U	PARTICIPANT	\N	PRESENT	0
784424	783383	14038Y	PARTICIPANT	\N	PRESENT	0
784292	783368	19711U	PARTICIPANT	\N	PRESENT	0
784293	783382	19479G	PARTICIPANT	\N	PRESENT	0
784294	783382	14111D	PARTICIPANT	\N	PRESENT	0
784358	783383	21044C	PARTICIPANT	\N	PRESENT	0
784359	783383	20056C	PARTICIPANT	\N	PRESENT	0
784360	783383	20086J	PARTICIPANT	\N	PRESENT	0
784361	783383	21048G	PARTICIPANT	\N	PRESENT	0
784362	783383	18207D	PARTICIPANT	\N	PRESENT	0
784363	783383	21057H	PARTICIPANT	\N	PRESENT	0
784364	783383	20082E	PARTICIPANT	\N	PRESENT	0
784365	783383	21045D	PARTICIPANT	\N	PRESENT	0
784366	783383	14053L	PARTICIPANT	\N	PRESENT	0
784367	783383	20088L	PARTICIPANT	\N	PRESENT	0
784368	783383	19565D	PARTICIPANT	\N	PRESENT	0
784369	783383	20102Q	PARTICIPANT	\N	PRESENT	0
784370	783383	20046A	PARTICIPANT	\N	PRESENT	0
784371	783383	19111A	PARTICIPANT	\N	PRESENT	0
784372	783383	21040X	PARTICIPANT	\N	PRESENT	0
784373	783383	19782L	PARTICIPANT	\N	PRESENT	0
784374	783383	14107H	PARTICIPANT	\N	PRESENT	0
784375	783383	21041Y	PARTICIPANT	\N	PRESENT	0
784376	783383	11072N	PARTICIPANT	\N	PRESENT	0
784377	783383	19553Y	PARTICIPANT	\N	PRESENT	0
784378	783383	19745F	PARTICIPANT	\N	PRESENT	0
784379	783383	19479G	PARTICIPANT	\N	PRESENT	0
784380	783383	21038E	PARTICIPANT	\N	PRESENT	0
784381	783383	19798U	PARTICIPANT	\N	PRESENT	0
784382	783383	14205J	PARTICIPANT	\N	PRESENT	0
784383	783383	08056B	PARTICIPANT	\N	PRESENT	0
784384	783383	19507S	PARTICIPANT	\N	PRESENT	0
784385	783383	14133K	PARTICIPANT	\N	PRESENT	0
784386	783383	21036C	PARTICIPANT	\N	PRESENT	0
784387	783383	01058X	PARTICIPANT	\N	PRESENT	0
784388	783383	19399H	PARTICIPANT	\N	PRESENT	0
784389	783383	14042U	PARTICIPANT	\N	PRESENT	0
784390	783383	14083S	PARTICIPANT	\N	PRESENT	0
784391	783383	18083K	PARTICIPANT	\N	PRESENT	0
784392	783383	14123H	PARTICIPANT	\N	PRESENT	0
784393	783383	08028W	PARTICIPANT	\N	PRESENT	0
784394	783383	19621T	PARTICIPANT	\N	PRESENT	0
784395	783383	20032T	PARTICIPANT	\N	PRESENT	0
784396	783383	19758L	PARTICIPANT	\N	PRESENT	0
784397	783383	14215L	PARTICIPANT	\N	PRESENT	0
784398	783383	01034P	PARTICIPANT	\N	PRESENT	0
784399	783383	20098N	PARTICIPANT	\N	PRESENT	0
784400	783383	21058J	PARTICIPANT	\N	PRESENT	0
784401	783383	14030Q	PARTICIPANT	\N	PRESENT	0
784402	783383	20026V	PARTICIPANT	\N	PRESENT	0
784403	783383	21081H	PARTICIPANT	\N	PRESENT	0
784404	783383	21059K	PARTICIPANT	\N	PRESENT	0
784405	783383	08015R	PARTICIPANT	\N	PRESENT	0
784406	783383	20114U	PARTICIPANT	\N	PRESENT	0
784407	783383	20180F	PARTICIPANT	\N	PRESENT	0
784408	783383	21094N	PARTICIPANT	\N	PRESENT	0
784409	783383	14021P	PARTICIPANT	\N	PRESENT	0
784410	783383	19593H	PARTICIPANT	\N	PRESENT	0
784411	783383	14111D	PARTICIPANT	\N	PRESENT	0
784412	783383	14147R	PARTICIPANT	\N	PRESENT	0
784413	783383	14213J	PARTICIPANT	\N	PRESENT	0
784414	783383	08018U	PARTICIPANT	\N	PRESENT	0
784415	783383	14259Y	PARTICIPANT	\N	PRESENT	0
784416	783368	21037D	PARTICIPANT	\N	PRESENT	0
784417	783383	19387D	PARTICIPANT	\N	PRESENT	0
784418	783383	20090E	PARTICIPANT	\N	PRESENT	0
784356	783383	21063F	PARTICIPANT	\N	PRESENT	0
784357	783383	20140W	PARTICIPANT	\N	PRESENT	0
784419	783383	14255U	PARTICIPANT	\N	PRESENT	0
784420	783383	14059S	PARTICIPANT	\N	PRESENT	0
784421	783368	14026U	PARTICIPANT	\N	PRESENT	0
784422	783383	19749K	PARTICIPANT	\N	PRESENT	0
784423	783383	21095P	PARTICIPANT	\N	PRESENT	0
784425	783383	20028X	PARTICIPANT	\N	PRESENT	0
784426	783383	19679N	PARTICIPANT	\N	PRESENT	0
784427	783383	20116W	PARTICIPANT	\N	PRESENT	0
784428	783383	19533U	PARTICIPANT	\N	PRESENT	0
784429	783383	21053D	PARTICIPANT	\N	PRESENT	0
784430	783383	95041E	PARTICIPANT	\N	PRESENT	0
784431	783383	20036X	PARTICIPANT	\N	PRESENT	0
784432	783383	19699S	PARTICIPANT	\N	PRESENT	0
784433	783383	20042V	PARTICIPANT	\N	PRESENT	0
773643	772421	04008A	PARTICIPANT	\N	EXCUSE	0
773644	772421	20022R	PARTICIPANT	\N	EXCUSE	0
773645	772421	18207D	PARTICIPANT	\N	EXCUSE	0
773646	772421	19729F	PARTICIPANT	\N	EXCUSE	0
773852	772429	04047H	PRESIDENT	0	PRESENT	0
773853	772429	19749K	PARTICIPANT	\N	PRESENT	0
773854	772429	19673G	PARTICIPANT	\N	PRESENT	0
773855	772429	14053L	PARTICIPANT	0	PRESENT	0
773856	772429	19447X	PARTICIPANT	\N	PRESENT	0
773857	772429	14111D	PARTICIPANT	\N	PRESENT	0
773858	772429	21076L	PARTICIPANT	\N	PRESENT	0
773859	772429	14215L	PARTICIPANT	\N	PRESENT	0
773860	772429	14089Y	PARTICIPANT	\N	PRESENT	0
773861	772429	21040X	PARTICIPANT	\N	PRESENT	0
773862	772429	19719D	PARTICIPANT	\N	PRESENT	0
773863	772429	21043B	PARTICIPANT	\N	PRESENT	0
773864	772429	21056G	PARTICIPANT	\N	PRESENT	0
773865	772429	21057H	PARTICIPANT	\N	PRESENT	0
773866	772429	20022R	PARTICIPANT	\N	PRESENT	0
773867	772429	19725B	PARTICIPANT	\N	PRESENT	0
773869	772429	14151M	PARTICIPANT	\N	PRESENT	0
773870	772429	10015M	PARTICIPANT	\N	PRESENT	0
773871	772429	04008A	PARTICIPANT	\N	EXCUSE	0
773872	772429	19729F	PARTICIPANT	\N	EXCUSE	0
773873	772429	18207D	PARTICIPANT	\N	EXCUSE	0
773874	772429	21038E	PARTICIPANT	\N	PRESENT	0
773875	772429	20108W	PARTICIPANT	\N	PRESENT	0
773876	772429	19649G	PARTICIPANT	\N	PRESENT	0
773880	772429	20098N	PARTICIPANT	\N	PRESENT	0
773883	772429	20114U	PARTICIPANT	\N	PRESENT	0
773899	772429	05008E	PARTICIPANT	\N	PRESENT	0
783028	779656	20122U	PARTICIPANT	\N	PRESENT	0
783029	779656	08073C	PARTICIPANT	\N	PRESENT	0
783030	779656	19697Q	PARTICIPANT	\N	PRESENT	0
783031	779656	21037D	PARTICIPANT	\N	PRESENT	0
783032	779656	21097R	PARTICIPANT	\N	PRESENT	0
783033	779656	21035B	PARTICIPANT	\N	PRESENT	0
783034	779656	21044C	PARTICIPANT	\N	PRESENT	0
783035	779656	04045F	PARTICIPANT	\N	PRESENT	0
783036	779656	20038A	PARTICIPANT	\N	PRESENT	0
783046	779657	19479G	PARTICIPANT	\N	PRESENT	0
783083	779657	17023S	PARTICIPANT	\N	PRESENT	0
783090	779657	20122U	PARTICIPANT	\N	PRESENT	0
783088	779657	21030V	PARTICIPANT	\N	PRESENT	0
783050	779657	19719D	PARTICIPANT	\N	PRESENT	0
783084	779657	19657G	PARTICIPANT	\N	PRESENT	0
783089	779657	19782L	PARTICIPANT	\N	PRESENT	0
783087	779657	20032T	PARTICIPANT	\N	PRESENT	0
783085	779657	20034V	PARTICIPANT	\N	PRESENT	0
783086	779657	19711U	PARTICIPANT	\N	PRESENT	0
783056	779657	21079P	PARTICIPANT	\N	PRESENT	0
783093	779657	20148F	PARTICIPANT	\N	PRESENT	0
783058	779657	14249W	PARTICIPANT	\N	PRESENT	0
783059	779657	14037X	PARTICIPANT	\N	PRESENT	0
783060	779657	19331L	PARTICIPANT	\N	PRESENT	0
783095	779657	20098N	PARTICIPANT	\N	PRESENT	0
783096	779657	20062A	PARTICIPANT	\N	PRESENT	0
783063	779657	19697Q	PARTICIPANT	\N	PRESENT	0
783097	779657	19629C	PARTICIPANT	\N	PRESENT	0
783100	779657	20106U	PARTICIPANT	\N	PRESENT	0
783101	779657	21032X	PARTICIPANT	\N	PRESENT	0
783162	783102	21093M	PARTICIPANT	\N	PRESENT	0
783068	779657	21033Y	PARTICIPANT	\N	PRESENT	0
783163	783102	21079P	PARTICIPANT	\N	PRESENT	0
783070	779657	19533U	PARTICIPANT	\N	PRESENT	0
783071	779657	19301E	PARTICIPANT	\N	PRESENT	0
783072	779657	20100N	PARTICIPANT	\N	PRESENT	0
783073	779657	21073H	PARTICIPANT	\N	PRESENT	0
783164	783102	19383Y	PARTICIPANT	\N	PRESENT	0
783165	783102	20148F	PARTICIPANT	\N	PRESENT	0
783166	783102	19331L	PARTICIPANT	\N	PRESENT	0
783077	779657	08073C	PARTICIPANT	\N	PRESENT	0
783167	783102	19657G	PARTICIPANT	\N	PRESENT	0
783079	779657	21097R	PARTICIPANT	\N	PRESENT	0
783080	779657	21035B	PARTICIPANT	\N	PRESENT	0
783081	779657	21044C	PARTICIPANT	\N	PRESENT	0
783082	779657	04045F	PARTICIPANT	\N	PRESENT	0
783168	783102	17023S	PARTICIPANT	\N	PRESENT	0
783169	783102	19749K	PARTICIPANT	\N	PRESENT	0
783170	783102	07004J	PARTICIPANT	\N	PRESENT	0
783171	783102	21032X	PARTICIPANT	\N	PRESENT	0
783172	783102	19629C	PARTICIPANT	\N	PRESENT	0
783173	783102	19782L	PARTICIPANT	\N	PRESENT	0
783174	783102	08061X	PARTICIPANT	\N	PRESENT	0
783175	783102	21030V	PARTICIPANT	\N	PRESENT	0
783176	783102	21033Y	PARTICIPANT	\N	PRESENT	0
783177	783102	21073H	PARTICIPANT	\N	PRESENT	0
783178	783102	21036C	PARTICIPANT	\N	PRESENT	0
783179	783102	20034V	PARTICIPANT	\N	PRESENT	0
783180	783102	14083S	PARTICIPANT	\N	PRESENT	0
783181	783102	21044C	PARTICIPANT	\N	PRESENT	0
783182	783102	08009T	PARTICIPANT	\N	PRESENT	0
783183	783102	19301E	PARTICIPANT	\N	PRESENT	0
783184	783102	11053K	PARTICIPANT	\N	PRESENT	0
783185	783102	14249W	PARTICIPANT	\N	PRESENT	0
783186	783102	21035B	PARTICIPANT	\N	PRESENT	0
783187	783102	11040E	PARTICIPANT	\N	PRESENT	0
783161	783102	14229S	PARTICIPANT	\N	PRESENT	0
783188	783102	20062A	PARTICIPANT	\N	PRESENT	0
783189	783102	19057M	PARTICIPANT	\N	PRESENT	0
783190	783102	19647E	PARTICIPANT	\N	PRESENT	0
783191	783102	20116W	PARTICIPANT	\N	PRESENT	0
783192	783102	21053D	PARTICIPANT	\N	PRESENT	0
783193	783102	20032T	PARTICIPANT	\N	PRESENT	0
783194	783102	14195A	PARTICIPANT	\N	PRESENT	0
783195	779658	14229S	PARTICIPANT	\N	PRESENT	0
783196	779658	21079P	PARTICIPANT	\N	PRESENT	0
783197	779658	19383Y	PARTICIPANT	\N	PRESENT	0
783231	779658	20096L	PARTICIPANT	\N	PRESENT	0
783229	779658	14219Q	PARTICIPANT	\N	PRESENT	0
783232	779658	14231L	PARTICIPANT	\N	PRESENT	0
783201	779658	19749K	PARTICIPANT	\N	PRESENT	0
783202	779658	07004J	PARTICIPANT	\N	PRESENT	0
783230	779658	17023S	PARTICIPANT	\N	PRESENT	0
783226	779658	19573D	PARTICIPANT	\N	PRESENT	0
783227	779658	21065H	PARTICIPANT	\N	PRESENT	0
783228	779658	19629C	PARTICIPANT	\N	PRESENT	0
783233	779658	20098N	PARTICIPANT	\N	PRESENT	0
783234	779658	11045K	PARTICIPANT	\N	PRESENT	0
783209	779658	21036C	PARTICIPANT	\N	PRESENT	0
783235	779658	19735D	PARTICIPANT	\N	PRESENT	0
783211	779658	14083S	PARTICIPANT	\N	PRESENT	0
783212	779658	21044C	PARTICIPANT	\N	PRESENT	0
783213	779658	08009T	PARTICIPANT	\N	PRESENT	0
783236	779658	14257W	PARTICIPANT	\N	PRESENT	0
783215	779658	11053K	PARTICIPANT	\N	PRESENT	0
783237	779658	14225N	PARTICIPANT	\N	PRESENT	0
783238	779658	21063F	PARTICIPANT	\N	PRESENT	0
783218	779658	11040E	PARTICIPANT	\N	PRESENT	0
783219	779658	20062A	PARTICIPANT	\N	PRESENT	0
783239	779658	14215L	PARTICIPANT	\N	PRESENT	0
783221	779658	19647E	PARTICIPANT	\N	PRESENT	0
783222	779658	20116W	PARTICIPANT	\N	PRESENT	0
783223	779658	21053D	PARTICIPANT	\N	PRESENT	0
783224	779658	20032T	PARTICIPANT	\N	PRESENT	0
783225	779658	14195A	PARTICIPANT	\N	PRESENT	0
783240	779658	19335Q	PARTICIPANT	\N	PRESENT	0
783241	779658	20082E	PARTICIPANT	\N	PRESENT	0
783242	779658	19331L	PARTICIPANT	\N	PRESENT	0
783243	779658	19683J	PARTICIPANT	\N	PRESENT	0
783247	779658	08061X	PARTICIPANT	\N	PRESENT	0
783252	779658	14030Q	PARTICIPANT	\N	PRESENT	0
783253	779658	19687N	PARTICIPANT	\N	PRESENT	0
783254	779658	19782L	PARTICIPANT	\N	PRESENT	0
783255	779658	04045F	PARTICIPANT	\N	PRESENT	0
783256	779658	19057M	PARTICIPANT	\N	PRESENT	0
783257	779658	19533U	PARTICIPANT	\N	PRESENT	0
783258	779658	20100N	PARTICIPANT	\N	PRESENT	0
783259	779658	19711U	PARTICIPANT	\N	PRESENT	0
783260	779658	19621T	PARTICIPANT	\N	PRESENT	0
783261	779658	14037X	PARTICIPANT	\N	PRESENT	0
783262	779658	20126Y	PARTICIPANT	\N	PRESENT	0
783263	779658	08069G	PARTICIPANT	\N	PRESENT	0
783264	779658	20070A	PARTICIPANT	\N	PRESENT	0
783265	779658	21075K	PARTICIPANT	\N	PRESENT	0
783266	779658	14147R	PARTICIPANT	\N	PRESENT	0
783267	779658	14042U	PARTICIPANT	\N	PRESENT	0
783268	779658	19693L	PARTICIPANT	\N	PRESENT	0
783269	779658	21043B	PARTICIPANT	\N	PRESENT	0
783270	779658	19673G	PARTICIPANT	\N	PRESENT	0
783271	779658	08018U	PARTICIPANT	\N	PRESENT	0
776652	772609	11090Q	PARTICIPANT	\N	PRESENT	0
776653	772609	20070A	PARTICIPANT	\N	PRESENT	0
776654	772609	11110B	PARTICIPANT	\N	PRESENT	0
776655	772609	14257W	PARTICIPANT	\N	PRESENT	0
776656	772609	14205J	PARTICIPANT	\N	PRESENT	0
776657	772609	19768N	PARTICIPANT	\N	PRESENT	0
776658	772609	21040X	PARTICIPANT	\N	PRESENT	0
776659	772609	21033Y	PARTICIPANT	\N	PRESENT	0
776660	772609	20028X	PARTICIPANT	\N	PRESENT	0
776661	772609	14038Y	PARTICIPANT	\N	PRESENT	0
776662	772609	21054E	PARTICIPANT	\N	PRESENT	0
776663	772609	21086N	PARTICIPANT	\N	PRESENT	0
776664	772609	21092L	PARTICIPANT	\N	PRESENT	0
776665	772609	19695N	PARTICIPANT	\N	PRESENT	0
776666	772609	19705W	PARTICIPANT	\N	PRESENT	0
776667	772609	21050A	PARTICIPANT	\N	PRESENT	0
776668	772609	14225N	PARTICIPANT	\N	PRESENT	0
776669	772609	20124W	PARTICIPANT	\N	PRESENT	0
776670	772609	20062A	PARTICIPANT	\N	PRESENT	0
776671	772609	99004R	PARTICIPANT	\N	PRESENT	0
776672	772609	11048N	PARTICIPANT	\N	PRESENT	0
776673	772609	19719D	PARTICIPANT	\N	PRESENT	0
776674	772609	21041Y	PARTICIPANT	\N	PRESENT	0
776675	772609	19631V	PARTICIPANT	\N	PRESENT	0
776676	772609	20082E	PARTICIPANT	\N	PRESENT	0
776677	772609	11072N	PARTICIPANT	\N	PRESENT	0
776678	772609	19687N	PARTICIPANT	\N	PRESENT	0
776679	772609	12016W	PARTICIPANT	\N	PRESENT	0
776680	772609	20034V	PARTICIPANT	\N	PRESENT	0
776681	772609	21037D	PARTICIPANT	\N	PRESENT	0
776682	772609	21090J	PARTICIPANT	\N	PRESENT	0
776683	772609	20094J	PARTICIPANT	\N	PRESENT	0
776684	772609	14083S	PARTICIPANT	\N	PRESENT	0
776688	772609	19111A	PARTICIPANT	\N	PRESENT	0
776686	772609	19331L	PARTICIPANT	\N	PRESENT	0
776687	772609	11085T	PARTICIPANT	\N	PRESENT	0
776689	772609	20092G	PARTICIPANT	\N	PRESENT	0
776690	772609	20134Y	PARTICIPANT	\N	PRESENT	0
776691	772609	21038E	PARTICIPANT	\N	PRESENT	0
776692	772609	19693L	PARTICIPANT	\N	PRESENT	0
776693	772609	08034U	PARTICIPANT	\N	PRESENT	0
776694	772609	20252E	PARTICIPANT	\N	PRESENT	0
776695	772609	21069M	PARTICIPANT	\N	PRESENT	0
776696	772609	21075K	PARTICIPANT	\N	PRESENT	0
776697	772609	20044X	PARTICIPANT	\N	PRESENT	0
776698	772609	21091K	PARTICIPANT	\N	PRESENT	0
776699	772609	11053K	PARTICIPANT	\N	PRESENT	0
776700	772609	20116W	PARTICIPANT	\N	PRESENT	0
776701	772609	19489J	PARTICIPANT	\N	PRESENT	0
776702	772609	19711U	PARTICIPANT	\N	PRESENT	0
776703	772609	19647E	PARTICIPANT	\N	PRESENT	0
776704	772609	21048G	PARTICIPANT	\N	PRESENT	0
776705	776154	11090Q	PARTICIPANT	\N	PRESENT	0
776752	776154	21075K	PARTICIPANT	\N	PRESENT	0
776753	776154	20116W	PARTICIPANT	\N	PRESENT	0
776749	776154	11048N	PARTICIPANT	\N	PRESENT	0
776709	776154	21033Y	PARTICIPANT	\N	PRESENT	0
776750	776154	20062A	PARTICIPANT	\N	PRESENT	0
776751	776154	21054E	PARTICIPANT	\N	PRESENT	0
776754	776154	19693L	PARTICIPANT	\N	PRESENT	0
776748	776154	20092G	PARTICIPANT	\N	PRESENT	0
776714	776154	19695N	PARTICIPANT	\N	PRESENT	0
776755	776154	20024T	PARTICIPANT	\N	PRESENT	0
776756	776154	20124W	PARTICIPANT	\N	PRESENT	0
776757	776154	14253S	PARTICIPANT	\N	PRESENT	0
776758	776154	14038Y	PARTICIPANT	\N	PRESENT	0
776719	776154	99004R	PARTICIPANT	\N	PRESENT	0
776759	776154	21090J	PARTICIPANT	\N	PRESENT	0
776721	776154	19719D	PARTICIPANT	\N	PRESENT	0
776722	776154	21041Y	PARTICIPANT	\N	PRESENT	0
776760	776154	20028X	PARTICIPANT	\N	PRESENT	0
776724	776154	20082E	PARTICIPANT	\N	PRESENT	0
776761	776154	19687N	PARTICIPANT	\N	PRESENT	0
776762	776154	20070A	PARTICIPANT	\N	PRESENT	0
776727	776154	12016W	PARTICIPANT	\N	PRESENT	0
776728	776154	21037D	PARTICIPANT	\N	PRESENT	0
776763	776154	19649G	PARTICIPANT	\N	PRESENT	0
776764	776154	21097R	PARTICIPANT	\N	PRESENT	0
776765	776154	20064C	PARTICIPANT	\N	PRESENT	0
776766	776154	21038E	PARTICIPANT	\N	PRESENT	0
776733	776154	20134Y	PARTICIPANT	\N	PRESENT	0
776767	776154	14225N	PARTICIPANT	\N	PRESENT	0
776768	776154	20034V	PARTICIPANT	\N	PRESENT	0
776736	776154	20252E	PARTICIPANT	\N	PRESENT	0
776737	776154	21069M	PARTICIPANT	\N	PRESENT	0
776769	776154	14205J	PARTICIPANT	\N	PRESENT	0
776739	776154	20044X	PARTICIPANT	\N	PRESENT	0
776740	776154	21091K	PARTICIPANT	\N	PRESENT	0
776741	776154	11053K	PARTICIPANT	\N	PRESENT	0
776770	776154	20050V	PARTICIPANT	\N	PRESENT	0
776743	776154	19489J	PARTICIPANT	\N	PRESENT	0
776744	776154	19711U	PARTICIPANT	\N	PRESENT	0
776745	776154	19647E	PARTICIPANT	\N	PRESENT	0
776746	776154	21048G	PARTICIPANT	\N	PRESENT	0
776747	776154	21040X	PARTICIPANT	\N	PRESENT	0
776771	776154	19631V	PARTICIPANT	\N	PRESENT	0
776772	772611	11090Q	PARTICIPANT	\N	PRESENT	0
776808	772611	11053K	PARTICIPANT	\N	PRESENT	0
776812	772611	20044X	PARTICIPANT	\N	PRESENT	0
776775	772611	19719D	PARTICIPANT	\N	PRESENT	0
776776	772611	12016W	PARTICIPANT	\N	PRESENT	0
776777	772611	20134Y	PARTICIPANT	\N	PRESENT	0
776778	772611	21069M	PARTICIPANT	\N	PRESENT	0
776867	776115	14053L	PARTICIPANT	\N	EXCUSE	0
776977	776976	14237S	PARTICIPANT	\N	PRESENT	0
776781	772611	19489J	PARTICIPANT	\N	PRESENT	0
776782	772611	19711U	PARTICIPANT	\N	PRESENT	0
776783	772611	19647E	PARTICIPANT	\N	PRESENT	0
776784	772611	21048G	PARTICIPANT	\N	PRESENT	0
776785	772611	20092G	PARTICIPANT	\N	PRESENT	0
776918	776875	20084G	PARTICIPANT	\N	PRESENT	0
776922	776876	21086N	PARTICIPANT	\N	PRESENT	0
776788	772611	21075K	PARTICIPANT	\N	PRESENT	0
776789	772611	20116W	PARTICIPANT	\N	PRESENT	0
776790	772611	20024T	PARTICIPANT	\N	PRESENT	0
776791	772611	20124W	PARTICIPANT	\N	PRESENT	0
776792	772611	14253S	PARTICIPANT	\N	PRESENT	0
776923	776876	20084G	PARTICIPANT	\N	PRESENT	0
776794	772611	21090J	PARTICIPANT	\N	PRESENT	0
776924	776875	21086N	PARTICIPANT	\N	PRESENT	0
776796	772611	19687N	PARTICIPANT	\N	PRESENT	0
776797	772611	20070A	PARTICIPANT	\N	PRESENT	0
776798	772611	19649G	PARTICIPANT	\N	PRESENT	0
776799	772611	21097R	PARTICIPANT	\N	PRESENT	0
776800	772611	20064C	PARTICIPANT	\N	PRESENT	0
776801	772611	21038E	PARTICIPANT	\N	PRESENT	0
776802	772611	14225N	PARTICIPANT	\N	PRESENT	0
776803	772611	20034V	PARTICIPANT	\N	PRESENT	0
776979	776978	14237S	PARTICIPANT	\N	PRESENT	0
776805	772611	20050V	PARTICIPANT	\N	PRESENT	0
776806	772611	19631V	PARTICIPANT	\N	PRESENT	0
776807	772611	21040X	PARTICIPANT	\N	PRESENT	0
776980	776978	20084G	PARTICIPANT	\N	PRESENT	0
776985	776983	14237S	PARTICIPANT	\N	PRESENT	0
776987	776981	14237S	PARTICIPANT	\N	PRESENT	0
776988	776982	14237S	PARTICIPANT	\N	PRESENT	0
778857	776556	19301E	PARTICIPANT	\N	PRESENT	0
778866	778819	19479G	PARTICIPANT	\N	PRESENT	0
778867	778819	11048N	PARTICIPANT	\N	PRESENT	0
778868	778819	19647E	PARTICIPANT	\N	PRESENT	0
778869	778819	08034U	PARTICIPANT	\N	PRESENT	0
778870	778819	12016W	PARTICIPANT	\N	PRESENT	0
778871	778819	20080C	PARTICIPANT	\N	PRESENT	0
778872	778819	11074Q	PARTICIPANT	\N	PRESENT	0
778873	778819	19399H	PARTICIPANT	\N	PRESENT	0
778874	778819	20150Y	PARTICIPANT	\N	PRESENT	0
778875	778819	14225N	PRESIDENT	0	PRESENT	0
778876	778819	21041Y	PARTICIPANT	\N	PRESENT	0
778877	778819	14083S	PARTICIPANT	\N	PRESENT	0
778878	778819	07029T	PARTICIPANT	\N	PRESENT	0
778879	778819	20062A	PARTICIPANT	\N	PRESENT	0
778880	778819	08073C	PARTICIPANT	\N	PRESENT	0
778881	778819	19573D	PARTICIPANT	\N	PRESENT	0
778882	778819	07004J	PARTICIPANT	\N	PRESENT	0
778883	778819	19349W	PARTICIPANT	\N	PRESENT	0
778884	778819	08010L	PARTICIPANT	\N	PRESENT	0
778885	778819	14253S	PARTICIPANT	\N	PRESENT	0
778886	778819	20126Y	PARTICIPANT	\N	PRESENT	0
778897	776556	21035B	PARTICIPANT	\N	PRESENT	0
778898	776556	21034A	PARTICIPANT	\N	PRESENT	0
778899	776556	21073H	PARTICIPANT	\N	PRESENT	0
771863	769239	14069U	PARTICIPANT	\N	PRESENT	0
771864	769239	20100N	PARTICIPANT	\N	PRESENT	0
771941	769245	05008E	PARTICIPANT	\N	PRESENT	0
771942	769245	14089Y	PARTICIPANT	\N	PRESENT	0
771943	769245	20110Q	PARTICIPANT	\N	PRESENT	0
771944	769245	11056N	PARTICIPANT	\N	PRESENT	0
771945	769245	19760E	PARTICIPANT	\N	PRESENT	0
771946	769245	14207L	PARTICIPANT	\N	PRESENT	0
771947	769245	11072N	PARTICIPANT	\N	PRESENT	0
771948	769245	19489J	PARTICIPANT	\N	PRESENT	0
771949	769245	21044C	PARTICIPANT	\N	PRESENT	0
771950	769245	14055N	PARTICIPANT	\N	PRESENT	0
771951	769245	21070E	PARTICIPANT	\N	PRESENT	0
771952	769245	14191V	PARTICIPANT	\N	PRESENT	0
771953	769245	21039F	PARTICIPANT	\N	PRESENT	0
771954	769245	11090Q	PARTICIPANT	\N	PRESENT	0
771955	769245	20104S	PARTICIPANT	\N	PRESENT	0
771956	769245	20098N	PARTICIPANT	\N	PRESENT	0
771957	769245	14215L	PARTICIPANT	\N	PRESENT	0
771958	769245	14229S	PARTICIPANT	\N	PRESENT	0
771959	769245	14021P	PARTICIPANT	\N	PRESENT	0
771960	769245	11045K	PARTICIPANT	\N	PRESENT	0
771961	769245	21094N	PARTICIPANT	\N	PRESENT	0
771962	769245	20100N	PARTICIPANT	\N	PRESENT	0
771963	769245	21077M	PARTICIPANT	\N	PRESENT	0
771964	769245	11027H	PARTICIPANT	\N	PRESENT	0
771965	769245	21051B	PARTICIPANT	\N	PRESENT	0
771966	769245	18193Q	PARTICIPANT	\N	PRESENT	0
771967	769245	12016W	PARTICIPANT	\N	PRESENT	0
771968	769245	20060X	PARTICIPANT	\N	PRESENT	0
771969	769245	21035B	PARTICIPANT	\N	PRESENT	0
771970	769245	18231D	PARTICIPANT	\N	PRESENT	0
771971	769245	17965H	PARTICIPANT	\N	PRESENT	0
771972	769245	19629C	PARTICIPANT	\N	PRESENT	0
771973	769245	19447X	PARTICIPANT	\N	PRESENT	0
771974	769245	20084G	PARTICIPANT	\N	PRESENT	0
771975	769245	20026V	PARTICIPANT	\N	PRESENT	0
771976	769245	18207D	PARTICIPANT	\N	PRESENT	0
771977	769245	19413M	PARTICIPANT	\N	PRESENT	0
771978	769245	21067K	PARTICIPANT	\N	PRESENT	0
771979	769245	20266L	PARTICIPANT	\N	PRESENT	0
771980	769245	17779H	PARTICIPANT	\N	PRESENT	0
771981	769245	21088Q	PARTICIPANT	\N	PRESENT	0
771982	769245	04047H	PARTICIPANT	\N	PRESENT	0
771983	769245	20062A	PARTICIPANT	\N	PRESENT	0
771984	769245	21095P	PARTICIPANT	\N	PRESENT	0
771985	769245	17023S	PARTICIPANT	\N	PRESENT	0
771986	769245	14097Y	PARTICIPANT	\N	PRESENT	0
771987	769245	19533U	PARTICIPANT	\N	PRESENT	0
771988	769245	19545Y	PARTICIPANT	\N	PRESENT	0
771989	769245	21048G	PARTICIPANT	\N	PRESENT	0
771990	769245	21046E	PARTICIPANT	\N	PRESENT	0
771991	769245	19551W	PARTICIPANT	\N	PRESENT	0
771992	769245	19399H	PARTICIPANT	\N	PRESENT	0
771993	769245	14189C	PARTICIPANT	\N	PRESENT	0
771994	769245	20024T	PARTICIPANT	\N	PRESENT	0
771995	769245	14147R	PARTICIPANT	\N	PRESENT	0
771996	769245	20064C	PARTICIPANT	\N	PRESENT	0
771997	769245	21037D	PARTICIPANT	\N	PRESENT	0
771998	769245	11043H	PARTICIPANT	\N	PRESENT	0
771999	769245	14071N	PARTICIPANT	\N	PRESENT	0
772000	769245	19673G	PARTICIPANT	\N	PRESENT	0
772001	769245	18395Y	PARTICIPANT	\N	PRESENT	0
772002	769245	20080C	PARTICIPANT	\N	PRESENT	0
772003	769245	19687N	PARTICIPANT	\N	PRESENT	0
772004	769245	19758L	PARTICIPANT	\N	PRESENT	0
772010	769245	19647E	PARTICIPANT	\N	PRESENT	0
772006	769245	19347U	PARTICIPANT	\N	PRESENT	0
772007	769245	20070A	PARTICIPANT	\N	PRESENT	0
772008	769245	12028B	PARTICIPANT	\N	PRESENT	0
772009	769245	21089R	PARTICIPANT	\N	PRESENT	0
772011	769245	20142Y	PARTICIPANT	\N	PRESENT	0
772012	769245	21045D	PARTICIPANT	\N	PRESENT	0
772058	769246	20134Y	PARTICIPANT	\N	PRESENT	0
772059	769246	19545Y	PARTICIPANT	\N	PRESENT	0
772060	769246	20080C	PARTICIPANT	\N	PRESENT	0
771939	769245	14259Y	PARTICIPANT	\N	PRESENT	0
771940	769245	20264J	PARTICIPANT	\N	PRESENT	0
772061	769246	19399H	PARTICIPANT	\N	PRESENT	0
772062	769246	20070A	PARTICIPANT	\N	PRESENT	0
772063	769246	19687N	PARTICIPANT	\N	PRESENT	0
772064	769246	11056N	PARTICIPANT	\N	PRESENT	0
772065	769246	11053K	PARTICIPANT	\N	PRESENT	0
772066	769246	19349W	PARTICIPANT	\N	PRESENT	0
772067	769246	20062A	PARTICIPANT	\N	PRESENT	0
772068	769246	20116W	PARTICIPANT	\N	PRESENT	0
772069	769246	14225N	PARTICIPANT	\N	PRESENT	0
772070	769246	20044X	PARTICIPANT	\N	PRESENT	0
772071	769246	20142Y	PARTICIPANT	\N	PRESENT	0
772072	769246	08010L	PARTICIPANT	\N	PRESENT	0
772073	769246	14083S	PARTICIPANT	\N	PRESENT	0
772074	769246	20094J	PARTICIPANT	\N	PRESENT	0
772075	769246	21045D	PARTICIPANT	\N	PRESENT	0
772076	769246	19647E	PARTICIPANT	\N	PRESENT	0
774333	774332	14033T	PARTICIPANT	\N	PRESENT	0
774334	774332	14189C	PARTICIPANT	\N	PRESENT	0
774335	774332	18395Y	PARTICIPANT	\N	PRESENT	0
781219	778865	19760E	PARTICIPANT	\N	PRESENT	0
781220	778865	21097R	PARTICIPANT	\N	PRESENT	0
781221	778865	14042U	PARTICIPANT	\N	PRESENT	0
781269	779280	19719D	PARTICIPANT	\N	EXCUSE	0
786361	783026	98022P	PARTICIPANT	\N	PRESENT	0
786362	783026	19760E	PARTICIPANT	\N	PRESENT	0
786363	783026	21035B	PARTICIPANT	\N	PRESENT	0
786364	783026	20248J	PARTICIPANT	\N	PRESENT	0
786365	783026	19673G	PARTICIPANT	\N	PRESENT	0
786366	783026	19565D	PARTICIPANT	\N	PRESENT	0
786367	783026	20102Q	PARTICIPANT	\N	PRESENT	0
786368	783026	19301E	PARTICIPANT	\N	PRESENT	0
786369	783026	14059S	PARTICIPANT	\N	PRESENT	0
789856	789265	20062A	PARTICIPANT	\N	PRESENT	0
789857	789265	21064G	PARTICIPANT	\N	PRESENT	0
789858	789265	14223L	PARTICIPANT	\N	PRESENT	0
789860	789859	19711U	PARTICIPANT	\N	PRESENT	0
789861	789859	20094J	PARTICIPANT	\N	PRESENT	0
790025	788983	19760E	PARTICIPANT	\N	PRESENT	0
790027	788983	21046E	PARTICIPANT	\N	PRESENT	0
790028	788983	19367Y	PARTICIPANT	\N	PRESENT	0
772056	769246	14229S	PARTICIPANT	\N	PRESENT	0
772057	769246	11048N	PARTICIPANT	\N	PRESENT	0
790029	788983	20090E	PARTICIPANT	\N	PRESENT	0
790030	788983	14042U	PARTICIPANT	\N	PRESENT	0
790031	788983	14281W	PARTICIPANT	\N	PRESENT	0
790032	788983	19691J	PARTICIPANT	\N	PRESENT	0
790033	788983	19683J	PARTICIPANT	\N	PRESENT	0
790034	788983	21081H	PARTICIPANT	\N	PRESENT	0
790035	788983	18193Q	PARTICIPANT	\N	PRESENT	0
790036	788983	21087P	PARTICIPANT	\N	PRESENT	0
790037	788983	17779H	PARTICIPANT	\N	PRESENT	0
790038	788983	14223L	PARTICIPANT	\N	PRESENT	0
790039	788983	04092N	PARTICIPANT	\N	EXCUSE	0
790040	788983	14071N	PRESIDENT	0	PRESENT	0
790041	788983	20140W	PARTICIPANT	\N	PRESENT	0
790042	788983	14213J	PARTICIPANT	\N	PRESENT	0
790043	788983	19723Y	PARTICIPANT	\N	PRESENT	0
790044	788983	21097R	PARTICIPANT	\N	PRESENT	0
790045	788983	21039F	PARTICIPANT	\N	PRESENT	0
790046	788983	08061X	PARTICIPANT	\N	PRESENT	0
790047	788983	19866P	PARTICIPANT	\N	PRESENT	0
790048	788983	17965H	PARTICIPANT	\N	PRESENT	0
790049	788983	19679N	PARTICIPANT	\N	PRESENT	0
790050	788983	21064G	PARTICIPANT	\N	PRESENT	0
790051	788983	11045K	PARTICIPANT	\N	PRESENT	0
790052	788983	21049H	PARTICIPANT	\N	PRESENT	0
790053	788983	19703U	PARTICIPANT	\N	PRESENT	0
790054	788983	14217N	PARTICIPANT	\N	PRESENT	0
790079	788983	19798U	PARTICIPANT	\N	PRESENT	0
790091	788983	19301E	PARTICIPANT	\N	PRESENT	0
790094	788983	20130U	PARTICIPANT	\N	PRESENT	0
790095	788983	19553Y	PARTICIPANT	\N	PRESENT	0
790096	788983	21094N	PARTICIPANT	\N	PRESENT	0
790097	788983	19758L	PARTICIPANT	\N	PRESENT	0
790099	788983	19713W	PARTICIPANT	\N	PRESENT	0
790102	788983	01034P	PARTICIPANT	\N	PRESENT	0
790103	788983	14026U	PARTICIPANT	\N	PRESENT	0
790104	788983	20096L	PARTICIPANT	\N	PRESENT	0
790105	788983	21071F	PARTICIPANT	\N	PRESENT	0
790108	788983	08045X	PARTICIPANT	\N	PRESENT	0
790120	790119	14151M	PARTICIPANT	\N	PRESENT	0
790121	790119	07033P	PARTICIPANT	\N	PRESENT	0
790122	790119	14037X	PARTICIPANT	\N	PRESENT	0
784434	783383	11043H	PARTICIPANT	\N	PRESENT	0
784435	783383	21042A	PARTICIPANT	\N	PRESENT	0
784436	783383	07004J	PARTICIPANT	\N	PRESENT	0
784437	783383	19703U	PARTICIPANT	\N	PRESENT	0
784438	783384	21044C	PARTICIPANT	\N	PRESENT	0
784439	783384	20086J	PARTICIPANT	\N	PRESENT	0
784440	783384	21048G	PARTICIPANT	\N	PRESENT	0
784441	783384	18207D	PARTICIPANT	\N	PRESENT	0
784442	783384	21057H	PARTICIPANT	\N	PRESENT	0
784443	783384	20082E	PARTICIPANT	\N	PRESENT	0
784444	783384	14053L	PARTICIPANT	\N	PRESENT	0
784445	783384	19565D	PARTICIPANT	\N	PRESENT	0
784446	783384	20102Q	PARTICIPANT	\N	PRESENT	0
784447	783384	20046A	PARTICIPANT	\N	PRESENT	0
784505	783384	21054E	PARTICIPANT	\N	PRESENT	0
784506	783384	14073Q	PARTICIPANT	\N	PRESENT	0
784450	783384	19782L	PARTICIPANT	\N	PRESENT	0
784451	783384	21041Y	PARTICIPANT	\N	PRESENT	0
784513	783384	21052C	PARTICIPANT	\N	PRESENT	0
784453	783384	19553Y	PARTICIPANT	\N	PRESENT	0
784454	783384	19745F	PARTICIPANT	\N	PRESENT	0
784455	783384	19798U	PARTICIPANT	\N	PRESENT	0
784456	783384	08056B	PARTICIPANT	\N	PRESENT	0
784457	783384	21036C	PARTICIPANT	\N	PRESENT	0
784458	783384	18083K	PARTICIPANT	\N	PRESENT	0
784507	783384	21040X	PARTICIPANT	\N	PRESENT	0
784460	783384	19621T	PARTICIPANT	\N	PRESENT	0
784461	783384	20032T	PARTICIPANT	\N	PRESENT	0
784462	783384	21081H	PARTICIPANT	\N	PRESENT	0
784463	783384	08015R	PARTICIPANT	\N	PRESENT	0
784464	783384	20114U	PARTICIPANT	\N	PRESENT	0
784465	783384	20180F	PARTICIPANT	\N	PRESENT	0
784508	783384	20110Q	PARTICIPANT	\N	PRESENT	0
784467	783384	19593H	PARTICIPANT	\N	PRESENT	0
784509	783384	08028W	PARTICIPANT	\N	PRESENT	0
784469	783384	14213J	PARTICIPANT	\N	PRESENT	0
784514	783384	20052X	PARTICIPANT	\N	PRESENT	0
784471	783384	14259Y	PARTICIPANT	\N	PRESENT	0
784510	783384	04047H	PARTICIPANT	\N	PRESENT	0
785888	785885	19697Q	PARTICIPANT	\N	PRESENT	0
784474	783384	19749K	PARTICIPANT	\N	PRESENT	0
784515	783384	21056G	PARTICIPANT	\N	PRESENT	0
784516	783384	20252E	PARTICIPANT	\N	PRESENT	0
784477	783384	20028X	PARTICIPANT	\N	PRESENT	0
784478	783384	19679N	PARTICIPANT	\N	PRESENT	0
784479	783384	20116W	PARTICIPANT	\N	PRESENT	0
784518	783384	08034U	PARTICIPANT	\N	PRESENT	0
784481	783384	21053D	PARTICIPANT	\N	PRESENT	0
784482	783384	95041E	PARTICIPANT	\N	PRESENT	0
784483	783384	20036X	PARTICIPANT	\N	PRESENT	0
784484	783384	19699S	PARTICIPANT	\N	PRESENT	0
784485	783384	20042V	PARTICIPANT	\N	PRESENT	0
784486	783384	11043H	PARTICIPANT	\N	PRESENT	0
784487	783384	21042A	PARTICIPANT	\N	PRESENT	0
784488	783384	07004J	PARTICIPANT	\N	PRESENT	0
784489	783384	19703U	PARTICIPANT	\N	PRESENT	0
784490	783384	19399H	PARTICIPANT	\N	PRESENT	0
784492	783384	20090E	PARTICIPANT	\N	PRESENT	0
784497	783384	14215L	PARTICIPANT	\N	PRESENT	0
784501	783384	21038E	PARTICIPANT	\N	PRESENT	0
784503	783384	19758L	PARTICIPANT	\N	PRESENT	0
784524	783384	20062A	PARTICIPANT	\N	PRESENT	0
785886	785885	19611R	PRESIDENT	0	PRESENT	0
785889	785885	20102Q	PARTICIPANT	\N	PRESENT	0
785897	785885	19621T	PARTICIPANT	\N	PRESENT	0
785898	785885	14053L	PARTICIPANT	\N	PRESENT	0
785902	785885	14215L	PARTICIPANT	\N	PRESENT	0
785903	785885	19673G	PARTICIPANT	\N	PRESENT	0
785905	785885	10015M	PARTICIPANT	\N	PRESENT	0
785910	785885	14073Q	PARTICIPANT	\N	PRESENT	0
785911	785885	14030Q	PARTICIPANT	\N	PRESENT	0
785912	785885	20052X	PARTICIPANT	\N	PRESENT	0
785914	785885	20048C	PARTICIPANT	\N	PRESENT	0
785916	785885	21089R	PARTICIPANT	\N	PRESENT	0
785917	785885	20142Y	PARTICIPANT	\N	PRESENT	0
785918	785885	20132W	PARTICIPANT	\N	PRESENT	0
785922	785885	21058J	PARTICIPANT	\N	PRESENT	0
785925	785885	19954N	PARTICIPANT	\N	PRESENT	0
785926	785885	20180F	PARTICIPANT	\N	PRESENT	0
785928	785885	19533U	PARTICIPANT	\N	PRESENT	0
785929	785885	20022R	PARTICIPANT	\N	PRESENT	0
785932	785885	21055F	PARTICIPANT	\N	PRESENT	0
785937	785885	14147R	PARTICIPANT	\N	PRESENT	0
785941	785885	19735D	PARTICIPANT	\N	EXCUSE	0
785942	785885	21091K	PARTICIPANT	\N	EXCUSE	0
785943	785885	19693L	PARTICIPANT	\N	PRESENT	0
785949	785885	14259Y	PARTICIPANT	\N	PRESENT	0
785964	785885	04047H	PARTICIPANT	\N	PRESENT	0
786016	785885	20124W	PARTICIPANT	\N	PRESENT	0
786313	786312	99004R	PARTICIPANT	\N	PRESENT	0
786314	786312	19954N	PARTICIPANT	\N	PRESENT	0
786315	786312	19367Y	PARTICIPANT	\N	PRESENT	0
786316	786312	20138D	PARTICIPANT	\N	PRESENT	0
786317	786312	20114U	PARTICIPANT	\N	PRESENT	0
786318	786312	19621T	PARTICIPANT	\N	PRESENT	0
786319	786312	07033P	PARTICIPANT	\N	PRESENT	0
786320	786312	19673G	PARTICIPANT	\N	PRESENT	0
786321	786312	14231L	PARTICIPANT	\N	PRESENT	0
786322	786312	20120S	PARTICIPANT	\N	PRESENT	0
786323	786312	19611R	PARTICIPANT	\N	PRESENT	0
786324	786312	20052X	PARTICIPANT	\N	PRESENT	0
786325	786312	11085T	PARTICIPANT	\N	PRESENT	0
786326	786312	19573D	PARTICIPANT	\N	PRESENT	0
786327	786312	10015M	PARTICIPANT	\N	PRESENT	0
786328	786312	04045F	PARTICIPANT	\N	PRESENT	0
786330	786329	14281W	PARTICIPANT	\N	PRESENT	0
786331	786329	21078N	PARTICIPANT	\N	PRESENT	0
786333	786332	14071N	PARTICIPANT	\N	PRESENT	0
786334	786332	19575F	PARTICIPANT	\N	PRESENT	0
786335	786332	19798U	PARTICIPANT	\N	PRESENT	0
786336	786332	20084G	PARTICIPANT	\N	PRESENT	0
786481	780474	19749K	PARTICIPANT	\N	PRESENT	0
788103	786197	04047H	PARTICIPANT	\N	EXCUSE	0
788400	786465	17367Q	PARTICIPANT	\N	PRESENT	0
788401	786465	20090E	PARTICIPANT	\N	PRESENT	0
788405	786465	15197G	PARTICIPANT	\N	PRESENT	0
788433	786465	14151M	PRESIDENT	0	PRESENT	0
788436	786465	20146D	PARTICIPANT	\N	PRESENT	0
788460	786465	19295A	PARTICIPANT	\N	PRESENT	0
788461	786465	20110Q	PARTICIPANT	\N	PRESENT	0
788697	782883	14109K	PARTICIPANT	\N	PRESENT	0
788698	782883	14030Q	PARTICIPANT	\N	PRESENT	0
788699	782883	21071F	PARTICIPANT	\N	PRESENT	0
788700	782883	21089R	PARTICIPANT	\N	PRESENT	0
788701	782883	21034A	PARTICIPANT	\N	PRESENT	0
788702	782883	21091K	PARTICIPANT	\N	PRESENT	0
788703	782883	21038E	PARTICIPANT	\N	PRESENT	0
788704	782883	19749K	PARTICIPANT	\N	PRESENT	0
788705	782883	20180F	PARTICIPANT	\N	PRESENT	0
788714	787205	19631V	PARTICIPANT	\N	PRESENT	0
788717	787205	19575F	PARTICIPANT	\N	PRESENT	0
788718	787205	21050A	PARTICIPANT	\N	PRESENT	0
788719	787205	20078J	PARTICIPANT	\N	PRESENT	0
788720	787205	19383Y	PARTICIPANT	\N	PRESENT	0
788721	787205	21052C	PARTICIPANT	\N	PRESENT	0
788722	787205	19782L	PARTICIPANT	\N	PRESENT	0
788723	787205	14207L	PARTICIPANT	\N	PRESENT	0
788724	787205	21083K	PARTICIPANT	\N	PRESENT	0
788725	787205	20060X	PARTICIPANT	\N	PRESENT	0
788726	787205	14329V	PARTICIPANT	\N	PRESENT	0
788727	787205	14038Y	PARTICIPANT	\N	PRESENT	0
788728	787205	08028W	PARTICIPANT	\N	PRESENT	0
788729	787205	20144B	PARTICIPANT	\N	PRESENT	0
788730	787205	21034A	PARTICIPANT	\N	PRESENT	0
788731	787205	14357A	PARTICIPANT	\N	PRESENT	0
788732	787205	19507S	PARTICIPANT	\N	PRESENT	0
788733	787205	14187A	PARTICIPANT	\N	PRESENT	0
788734	787205	21086N	PARTICIPANT	\N	PRESENT	0
788735	787205	20038A	PARTICIPANT	\N	PRESENT	0
788736	787205	20286Q	PARTICIPANT	\N	PRESENT	0
788737	787205	19695N	PARTICIPANT	\N	PRESENT	0
788738	787205	21066J	PARTICIPANT	\N	PRESENT	0
788739	787205	21092L	PARTICIPANT	\N	PRESENT	0
788740	787205	20034V	PARTICIPANT	\N	PRESENT	0
788741	787205	21093M	PARTICIPANT	\N	PRESENT	0
788742	787205	08015R	PARTICIPANT	\N	PRESENT	0
788743	787205	14205J	PARTICIPANT	\N	PRESENT	0
788744	787205	21054E	PARTICIPANT	\N	PRESENT	0
788745	787205	21075K	PARTICIPANT	\N	PRESENT	0
788746	787205	19563B	PARTICIPANT	\N	PRESENT	0
788747	787205	20028X	PARTICIPANT	\N	PRESENT	0
769079	769077	04070G	PARTICIPANT	\N	PRESENT	0
769080	769077	20058E	PARTICIPANT	\N	PRESENT	0
769081	769078	20058E	PARTICIPANT	\N	PRESENT	0
771351	768827	14097Y	PARTICIPANT	\N	PRESENT	0
771353	768827	14237S	PARTICIPANT	\N	PRESENT	0
771367	771366	19421M	PARTICIPANT	\N	PRESENT	0
771371	771370	19713W	PARTICIPANT	\N	PRESENT	0
771763	771762	10006L	PARTICIPANT	\N	PRESENT	0
771791	771790	19701S	PARTICIPANT	\N	PRESENT	0
771792	771790	19762G	PARTICIPANT	\N	PRESENT	0
771797	771796	11085T	PARTICIPANT	\N	PRESENT	0
771798	740801	14331P	PARTICIPANT	\N	PRESENT	0
771804	771802	19711U	PARTICIPANT	\N	PRESENT	0
771809	771808	11083R	PARTICIPANT	\N	PRESENT	0
771817	771816	14053L	PARTICIPANT	\N	PRESENT	0
771819	771818	10015M	PARTICIPANT	\N	PRESENT	0
771823	771822	17737W	PARTICIPANT	\N	PRESENT	0
771826	771825	19713W	PARTICIPANT	\N	PRESENT	0
771832	771831	14053L	PARTICIPANT	\N	PRESENT	0
771835	771834	07004J	PARTICIPANT	\N	PRESENT	0
771838	771837	08018U	PARTICIPANT	\N	PRESENT	0
771839	771837	11065P	PARTICIPANT	\N	PRESENT	0
782928	782897	14225N	PRESIDENT	0	PRESENT	0
782929	782897	14331P	PARTICIPANT	\N	EXCUSE	0
782930	782897	20070A	PARTICIPANT	\N	EXCUSE	0
782931	782897	20080C	PARTICIPANT	\N	EXCUSE	0
782932	782897	08009T	PARTICIPANT	\N	PRESENT	0
782933	782897	20044X	PARTICIPANT	\N	PRESENT	0
782934	782897	11053K	PARTICIPANT	\N	PRESENT	0
782935	782897	21090J	PARTICIPANT	\N	PRESENT	0
782936	782897	19647E	PARTICIPANT	\N	PRESENT	0
782937	782897	20126Y	PARTICIPANT	\N	PRESENT	0
782938	782897	20094J	PARTICIPANT	\N	PRESENT	0
782939	782897	19711U	PARTICIPANT	\N	PRESENT	0
782940	782897	08034U	PARTICIPANT	\N	PRESENT	0
782995	779656	19479G	PARTICIPANT	\N	PRESENT	0
782996	779656	20106U	PARTICIPANT	\N	PRESENT	0
782997	779656	20044X	PARTICIPANT	\N	PRESENT	0
782998	779656	20046A	PARTICIPANT	\N	PRESENT	0
782999	779656	19719D	PARTICIPANT	\N	PRESENT	0
783000	779656	19782L	PARTICIPANT	\N	PRESENT	0
783001	779656	14225N	PARTICIPANT	\N	PRESENT	0
783002	779656	19621T	PARTICIPANT	\N	PRESENT	0
783003	779656	21052C	PARTICIPANT	\N	PRESENT	0
783004	779656	19335Q	PARTICIPANT	\N	PRESENT	0
783005	779656	21079P	PARTICIPANT	\N	PRESENT	0
783012	779656	14069U	PARTICIPANT	\N	PRESENT	0
783013	779656	19711U	PARTICIPANT	\N	PRESENT	0
783014	779656	14249W	PARTICIPANT	\N	PRESENT	0
783015	779656	08061X	PARTICIPANT	\N	PRESENT	0
783016	779656	14037X	PARTICIPANT	\N	PRESENT	0
783017	779656	19331L	PARTICIPANT	\N	PRESENT	0
783018	779656	14083S	PARTICIPANT	\N	PRESENT	0
783019	779656	20126Y	PARTICIPANT	\N	PRESENT	0
783022	779656	08034U	PARTICIPANT	\N	PRESENT	0
783023	779656	20032T	PARTICIPANT	\N	PRESENT	0
783024	779656	14147R	PARTICIPANT	\N	PRESENT	0
783317	779659	19749K	PARTICIPANT	\N	PRESENT	0
783318	779659	19693L	PARTICIPANT	\N	PRESENT	0
783319	779659	14195A	PARTICIPANT	\N	PRESENT	0
783320	779659	21079P	PARTICIPANT	\N	PRESENT	0
783321	779659	21043B	PARTICIPANT	\N	PRESENT	0
783322	779659	18231D	PARTICIPANT	\N	PRESENT	0
783323	779659	11045K	PARTICIPANT	\N	PRESENT	0
783324	779659	04045F	PARTICIPANT	\N	PRESENT	0
783325	779659	08061X	PARTICIPANT	\N	PRESENT	0
783326	779659	21063F	PARTICIPANT	\N	PRESENT	0
783327	779659	19533U	PARTICIPANT	\N	PRESENT	0
783328	779659	14215L	PARTICIPANT	\N	PRESENT	0
783329	779659	19621T	PARTICIPANT	\N	PRESENT	0
783330	779659	20062A	PARTICIPANT	\N	PRESENT	0
783331	779659	20126Y	PARTICIPANT	\N	PRESENT	0
783332	779659	20098N	PARTICIPANT	\N	PRESENT	0
783333	779659	19673G	PARTICIPANT	\N	PRESENT	0
783334	779659	19711U	PARTICIPANT	\N	PRESENT	0
783335	779659	14030Q	PARTICIPANT	\N	PRESENT	0
783336	779659	21075K	PARTICIPANT	\N	PRESENT	0
783340	779659	14147R	PARTICIPANT	\N	PRESENT	0
783341	779659	08018U	PARTICIPANT	\N	PRESENT	0
783342	779659	14042U	PARTICIPANT	\N	PRESENT	0
783343	779659	14083S	PARTICIPANT	\N	PRESENT	0
783344	779659	20100N	PARTICIPANT	\N	PRESENT	0
783345	779659	21092L	PARTICIPANT	\N	PRESENT	0
783346	779659	20134Y	PARTICIPANT	\N	PRESENT	0
793386	791619	19629C	PARTICIPANT	\N	PRESENT	0
793387	791619	19683J	PARTICIPANT	\N	PRESENT	0
793388	791619	20130U	PARTICIPANT	\N	EXCUSE	0
793389	791619	11045K	PARTICIPANT	\N	PRESENT	0
793390	791619	18193Q	PARTICIPANT	\N	PRESENT	0
793391	791619	14071N	PRESIDENT	0	PRESENT	0
793392	791619	14195A	PARTICIPANT	\N	PRESENT	0
793393	791619	21094N	PARTICIPANT	\N	PRESENT	0
793424	791619	19713W	PARTICIPANT	\N	PRESENT	0
793425	791619	19758L	PARTICIPANT	\N	PRESENT	0
793426	791619	21046E	PARTICIPANT	\N	PRESENT	0
793427	791619	19760E	PARTICIPANT	\N	PRESENT	0
793428	791619	19553Y	PARTICIPANT	\N	PRESENT	0
793429	791619	20148F	PARTICIPANT	\N	PRESENT	0
793430	791619	20096L	PARTICIPANT	\N	PRESENT	0
793431	791619	19691J	PARTICIPANT	\N	PRESENT	0
783315	779659	14229S	PARTICIPANT	\N	PRESENT	0
783316	779659	19735D	PARTICIPANT	\N	PRESENT	0
793432	791619	20140W	PARTICIPANT	\N	PRESENT	0
793433	791619	14217N	PARTICIPANT	\N	PRESENT	0
793434	791619	19679N	PARTICIPANT	\N	PRESENT	0
793435	791619	19798U	PARTICIPANT	\N	PRESENT	0
793436	791619	14042U	PARTICIPANT	\N	PRESENT	0
793438	791619	21081H	PARTICIPANT	\N	PRESENT	0
793439	791619	21097R	PARTICIPANT	\N	PRESENT	0
793443	791619	20090E	PARTICIPANT	\N	PRESENT	0
793444	791619	19703U	PARTICIPANT	\N	PRESENT	0
793446	791619	21039F	PARTICIPANT	\N	PRESENT	0
793447	791619	14213J	PARTICIPANT	\N	PRESENT	0
793448	791619	19723Y	PARTICIPANT	\N	PRESENT	0
793449	791619	19367Y	PARTICIPANT	\N	PRESENT	0
793450	791619	14355X	PARTICIPANT	\N	EXCUSE	0
793451	791619	20248J	PARTICIPANT	\N	PRESENT	0
793452	791619	19657G	PARTICIPANT	\N	PRESENT	0
793453	791619	19866P	PARTICIPANT	\N	PRESENT	0
793454	791619	21049H	PARTICIPANT	\N	PRESENT	0
793455	791619	08045X	PARTICIPANT	\N	PRESENT	0
793456	791619	21045D	PARTICIPANT	\N	PRESENT	0
793467	791619	08061X	PARTICIPANT	\N	PRESENT	0
793469	791619	19569H	PARTICIPANT	\N	PRESENT	0
793470	791619	19591F	PARTICIPANT	\N	PRESENT	0
793474	791619	21064G	PARTICIPANT	\N	PRESENT	0
793513	791619	14026U	PARTICIPANT	\N	PRESENT	0
793514	791619	21087P	PARTICIPANT	\N	PRESENT	0
793590	791619	14281W	PARTICIPANT	\N	PRESENT	0
793591	791619	17965H	PARTICIPANT	\N	PRESENT	0
796715	794075	14249W	PARTICIPANT	\N	PRESENT	0
796716	794075	08073C	PARTICIPANT	\N	PRESENT	0
796717	794075	20116W	PARTICIPANT	\N	PRESENT	0
796718	794075	14207L	PARTICIPANT	\N	PRESENT	0
796719	794075	21071F	PARTICIPANT	\N	PRESENT	0
796720	794075	14191V	PARTICIPANT	\N	PRESENT	0
796721	794075	21041Y	PARTICIPANT	\N	PRESENT	0
796722	794075	19719D	PARTICIPANT	\N	PRESENT	0
796723	794075	21072G	PARTICIPANT	\N	PRESENT	0
796724	794075	20132W	PARTICIPANT	\N	PRESENT	0
796725	794075	21032X	PARTICIPANT	\N	PRESENT	0
796726	794075	21066J	PARTICIPANT	\N	PRESENT	0
796727	794075	14237S	PARTICIPANT	\N	PRESENT	0
796728	794075	20072C	PARTICIPANT	\N	PRESENT	0
796729	794075	20044X	PARTICIPANT	\N	PRESENT	0
796730	794075	20134Y	PARTICIPANT	\N	PRESENT	0
796731	794075	05012A	PARTICIPANT	\N	PRESENT	0
796732	794075	20110Q	PARTICIPANT	\N	PRESENT	0
796733	794075	11090Q	PARTICIPANT	\N	PRESENT	0
796734	794075	14193X	PARTICIPANT	\N	PRESENT	0
796735	794075	14259Y	PARTICIPANT	\N	PRESENT	0
796736	794075	14031R	PARTICIPANT	\N	PRESENT	0
796737	794075	19667J	PARTICIPANT	\N	PRESENT	0
796738	794075	19421M	PARTICIPANT	\N	PRESENT	0
796739	794075	14253S	PARTICIPANT	\N	PRESENT	0
796740	794075	20136B	PARTICIPANT	\N	PRESENT	0
796741	794075	20032T	PARTICIPANT	\N	PRESENT	0
796742	794075	14331P	PARTICIPANT	\N	PRESENT	0
796743	794075	19447X	PARTICIPANT	\N	PRESENT	0
796744	794075	20096L	PARTICIPANT	\N	PRESENT	0
796745	794075	20180F	PARTICIPANT	\N	PRESENT	0
778900	776556	19782L	PARTICIPANT	\N	PRESENT	0
778901	776556	11072N	PARTICIPANT	\N	PRESENT	0
778903	776556	21096Q	PARTICIPANT	\N	PRESENT	0
778904	776556	19657G	PARTICIPANT	\N	PRESENT	0
778906	776556	21055F	PARTICIPANT	\N	PRESENT	0
778907	776556	14253S	PARTICIPANT	\N	PRESENT	0
778908	776556	11048N	PARTICIPANT	\N	PRESENT	0
778909	776556	08073C	PARTICIPANT	\N	PRESENT	0
778912	776556	20150Y	PARTICIPANT	\N	PRESENT	0
778914	776556	19295A	PARTICIPANT	\N	PRESENT	0
778915	776556	19760E	PARTICIPANT	\N	PRESENT	0
778916	776556	20016T	PARTICIPANT	\N	PRESENT	0
778917	776556	14225N	PARTICIPANT	\N	PRESENT	0
778918	776556	14275Y	PARTICIPANT	\N	PRESENT	0
778919	776556	20062A	PARTICIPANT	\N	PRESENT	0
778920	776556	21029D	PARTICIPANT	\N	PRESENT	0
778921	776556	19479G	PARTICIPANT	\N	PRESENT	0
778922	776556	21033Y	PARTICIPANT	\N	PRESENT	0
778923	776556	21032X	PARTICIPANT	\N	PRESENT	0
778924	776556	19629C	PARTICIPANT	\N	PRESENT	0
778925	776556	21041Y	PARTICIPANT	\N	PRESENT	0
778926	776556	21030V	PARTICIPANT	\N	PRESENT	0
778927	776556	12016W	PARTICIPANT	\N	PRESENT	0
778928	776556	20034V	PARTICIPANT	\N	PRESENT	0
778931	776556	20084G	PARTICIPANT	\N	PRESENT	0
778932	776556	20076G	PARTICIPANT	\N	PRESENT	0
778942	776556	21097R	PARTICIPANT	\N	PRESENT	0
778944	776556	14059S	PARTICIPANT	\N	PRESENT	0
778945	776556	20148F	PARTICIPANT	\N	PRESENT	0
778946	776556	14083S	PARTICIPANT	\N	PRESENT	0
778947	776556	20104S	PARTICIPANT	\N	PRESENT	0
778948	776556	20146D	PARTICIPANT	\N	PRESENT	0
778949	776556	14021P	PARTICIPANT	\N	PRESENT	0
778950	776556	19331L	PARTICIPANT	\N	PRESENT	0
778951	776556	21093M	PARTICIPANT	\N	PRESENT	0
778952	776556	21066J	PARTICIPANT	\N	PRESENT	0
778953	776556	19631V	PARTICIPANT	\N	PRESENT	0
778956	776556	14189C	PARTICIPANT	\N	PRESENT	0
778957	776556	21082J	PARTICIPANT	\N	PRESENT	0
778958	776556	21069M	PARTICIPANT	\N	PRESENT	0
778960	776556	21061D	PARTICIPANT	\N	PRESENT	0
778999	776556	21046E	PARTICIPANT	\N	PRESENT	0
779000	776556	07029T	PARTICIPANT	\N	PRESENT	0
779001	776556	19691J	PARTICIPANT	\N	PRESENT	0
779009	776556	19699S	PARTICIPANT	\N	PRESENT	0
779010	776556	19399H	PARTICIPANT	\N	PRESENT	0
779011	776556	20266L	PARTICIPANT	\N	PRESENT	0
779012	776556	19573D	PARTICIPANT	\N	PRESENT	0
779013	776556	20072C	PARTICIPANT	\N	PRESENT	0
779014	776556	18193Q	PARTICIPANT	\N	PRESENT	0
779015	776556	19687N	PARTICIPANT	\N	PRESENT	0
779016	776556	21071F	PARTICIPANT	\N	PRESENT	0
779017	776556	01034P	PARTICIPANT	\N	PRESENT	0
779019	776556	21095P	PARTICIPANT	\N	PRESENT	0
779020	776556	20040T	PARTICIPANT	\N	PRESENT	0
779021	776556	20070A	PARTICIPANT	\N	PRESENT	0
779022	776556	20090E	PARTICIPANT	\N	PRESENT	0
779023	776556	14213J	PARTICIPANT	\N	PRESENT	0
779024	776556	21040X	PARTICIPANT	\N	PRESENT	0
779025	776556	19349W	PARTICIPANT	\N	PRESENT	0
779026	776556	20052X	PARTICIPANT	\N	PRESENT	0
779027	776556	20032T	PARTICIPANT	\N	PRESENT	0
779028	776556	20102Q	PARTICIPANT	\N	PRESENT	0
779029	776556	04045F	PARTICIPANT	\N	PRESENT	0
779090	776557	20148F	PARTICIPANT	\N	PRESENT	0
779091	776557	19657G	PARTICIPANT	\N	PRESENT	0
779092	776557	08073C	PARTICIPANT	\N	PRESENT	0
779093	776557	20150Y	PARTICIPANT	\N	PRESENT	0
779094	776557	20090E	PARTICIPANT	\N	PRESENT	0
779095	776557	21055F	PARTICIPANT	\N	PRESENT	0
779096	776557	14225N	PARTICIPANT	\N	PRESENT	0
779097	776557	12016W	PARTICIPANT	\N	PRESENT	0
779098	776557	21029D	PARTICIPANT	\N	PRESENT	0
779099	776557	20034V	PARTICIPANT	\N	PRESENT	0
779100	776557	99004R	PARTICIPANT	\N	PRESENT	0
779101	776557	21071F	PARTICIPANT	\N	PRESENT	0
779102	776557	21046E	PARTICIPANT	\N	PRESENT	0
779103	776557	19295A	PARTICIPANT	\N	PRESENT	0
779104	776557	21034A	PARTICIPANT	\N	PRESENT	0
779105	776557	20084G	PARTICIPANT	\N	PRESENT	0
779106	776557	19631V	PARTICIPANT	\N	PRESENT	0
779107	776557	21030V	PARTICIPANT	\N	PRESENT	0
779108	776557	21073H	PARTICIPANT	\N	PRESENT	0
779109	776557	21097R	PARTICIPANT	\N	PRESENT	0
779110	776557	21096Q	PARTICIPANT	\N	PRESENT	0
779111	776557	21033Y	PARTICIPANT	\N	PRESENT	0
779112	776557	19301E	PARTICIPANT	\N	PRESENT	0
779113	776557	21032X	PARTICIPANT	\N	PRESENT	0
779114	776557	14275Y	PARTICIPANT	\N	PRESENT	0
779115	776557	21069M	PARTICIPANT	\N	PRESENT	0
779116	776557	21095P	PARTICIPANT	\N	PRESENT	0
779117	776557	19573D	PARTICIPANT	\N	PRESENT	0
779118	776557	19399H	PARTICIPANT	\N	PRESENT	0
779119	776557	19349W	PARTICIPANT	\N	PRESENT	0
779120	776557	20062A	PARTICIPANT	\N	PRESENT	0
779121	776557	20016T	PARTICIPANT	\N	PRESENT	0
779122	776557	20102Q	PARTICIPANT	\N	PRESENT	0
779123	776557	11072N	PARTICIPANT	\N	PRESENT	0
779126	776557	21093M	PARTICIPANT	\N	PRESENT	0
779127	776557	14021P	PARTICIPANT	\N	PRESENT	0
779128	776557	20070A	PARTICIPANT	\N	PRESENT	0
779129	776557	14215L	PARTICIPANT	\N	PRESENT	0
779130	776557	20076G	PARTICIPANT	\N	PRESENT	0
779131	776557	20112S	PARTICIPANT	\N	PRESENT	0
779132	776557	14229S	PARTICIPANT	\N	PRESENT	0
779133	776557	20052X	PARTICIPANT	\N	PRESENT	0
779134	776557	20032T	PARTICIPANT	\N	PRESENT	0
779135	776557	98022P	PARTICIPANT	\N	PRESENT	0
779136	776557	01034P	PARTICIPANT	\N	PRESENT	0
779137	776557	20042V	PARTICIPANT	\N	PRESENT	0
779138	776557	19691J	PARTICIPANT	\N	PRESENT	0
779139	776557	11040E	PARTICIPANT	\N	PRESENT	0
779140	776557	19683J	PARTICIPANT	\N	PRESENT	0
779141	776557	19629C	PARTICIPANT	\N	PRESENT	0
779142	776557	20080C	PARTICIPANT	\N	PRESENT	0
779143	776557	11048N	PARTICIPANT	\N	PRESENT	0
779144	776557	19687N	PARTICIPANT	\N	PRESENT	0
779145	776557	14207L	PARTICIPANT	\N	PRESENT	0
779146	776557	14253S	PARTICIPANT	\N	PRESENT	0
779147	776557	21072G	PARTICIPANT	\N	PRESENT	0
779086	776557	11090Q	PARTICIPANT	\N	PRESENT	0
779089	776557	21035B	PARTICIPANT	\N	PRESENT	0
779148	776557	19331L	PARTICIPANT	\N	PRESENT	0
779149	776557	20058E	PARTICIPANT	\N	PRESENT	0
779150	776557	19711U	PARTICIPANT	\N	PRESENT	0
779153	776557	07004J	PARTICIPANT	\N	PRESENT	0
779206	776558	11090Q	PARTICIPANT	\N	PRESENT	0
779207	776558	14253S	PARTICIPANT	\N	PRESENT	0
779208	776558	19479G	PARTICIPANT	\N	PRESENT	0
779209	776558	14026U	PARTICIPANT	\N	PRESENT	0
779210	776558	14215L	PARTICIPANT	\N	PRESENT	0
779211	776558	18207D	PARTICIPANT	\N	PRESENT	0
779212	776558	19711U	PARTICIPANT	\N	PRESENT	0
779213	776558	21046E	PARTICIPANT	\N	PRESENT	0
779214	776558	20058E	PARTICIPANT	\N	PRESENT	0
779215	776558	21071F	PARTICIPANT	\N	PRESENT	0
779216	776558	98022P	PARTICIPANT	\N	PRESENT	0
779217	776558	14207L	PARTICIPANT	\N	PRESENT	0
779218	776558	19782L	PARTICIPANT	\N	PRESENT	0
779219	776558	19629C	PARTICIPANT	\N	PRESENT	0
779220	776558	19691J	PARTICIPANT	\N	PRESENT	0
779221	776558	20042V	PARTICIPANT	\N	PRESENT	0
779222	776558	20062A	PARTICIPANT	\N	PRESENT	0
779223	776558	20076G	PARTICIPANT	\N	PRESENT	0
779224	776558	20034V	PARTICIPANT	\N	PRESENT	0
779225	776558	21072G	PARTICIPANT	\N	PRESENT	0
779226	776558	21093M	PARTICIPANT	\N	PRESENT	0
779227	776558	20134Y	PARTICIPANT	\N	PRESENT	0
779228	776558	20070A	PARTICIPANT	\N	PRESENT	0
779229	776558	21089R	PARTICIPANT	\N	PRESENT	0
779230	776558	20080C	PARTICIPANT	\N	PRESENT	0
779231	776558	14225N	PARTICIPANT	\N	PRESENT	0
779232	776558	21029D	PARTICIPANT	\N	PRESENT	0
779233	776558	21055F	PARTICIPANT	\N	PRESENT	0
779234	776558	07004J	PARTICIPANT	\N	PRESENT	0
779235	776558	11040E	PARTICIPANT	\N	PRESENT	0
779236	776558	19631V	PARTICIPANT	\N	PRESENT	0
779237	776558	21097R	PARTICIPANT	\N	PRESENT	0
779238	776558	20016T	PARTICIPANT	\N	PRESENT	0
779239	776558	04045F	PARTICIPANT	\N	PRESENT	0
779240	776558	21063F	PARTICIPANT	\N	PRESENT	0
771246	769073	21077M	PARTICIPANT	\N	EXCUSE	0
777037	775655	17737W	PARTICIPANT	\N	EXCUSE	0
777038	775655	19826F	PARTICIPANT	\N	EXCUSE	0
786222	786221	14089Y	PARTICIPANT	\N	PRESENT	0
786223	786221	21075K	PARTICIPANT	\N	PRESENT	0
787339	787240	19057M	PARTICIPANT	\N	PRESENT	0
787341	787240	14021P	PARTICIPANT	\N	PRESENT	0
787458	787240	21055F	PARTICIPANT	\N	PRESENT	0
787505	787240	19735D	PARTICIPANT	\N	EXCUSE	0
789687	789686	19631V	PARTICIPANT	\N	PRESENT	0
789688	789686	21050A	PARTICIPANT	\N	PRESENT	0
789689	789686	20090E	PARTICIPANT	\N	PRESENT	0
789690	789686	21096Q	PARTICIPANT	\N	PRESENT	0
789691	789686	14255U	PARTICIPANT	\N	PRESENT	0
789692	789686	14083S	PARTICIPANT	\N	PRESENT	0
789693	789686	19629C	PARTICIPANT	\N	PRESENT	0
789694	789686	14329V	PARTICIPANT	\N	PRESENT	0
789695	789686	20120S	PARTICIPANT	\N	PRESENT	0
789696	789686	20180F	PARTICIPANT	\N	PRESENT	0
789697	789686	20048C	PARTICIPANT	\N	PRESENT	0
789698	789686	08015R	PARTICIPANT	\N	PRESENT	0
789699	789686	21073H	PARTICIPANT	\N	PRESENT	0
789700	789686	08073C	PARTICIPANT	\N	PRESENT	0
789701	789686	19687N	PARTICIPANT	\N	PRESENT	0
790123	790119	21054E	PARTICIPANT	\N	PRESENT	0
790124	790119	14147R	PARTICIPANT	\N	PRESENT	0
790125	790119	18231D	PARTICIPANT	\N	PRESENT	0
790126	790119	20050V	PARTICIPANT	\N	PRESENT	0
790127	790119	08073C	PARTICIPANT	\N	PRESENT	0
790128	790119	21056G	PARTICIPANT	\N	PRESENT	0
790129	790119	21059K	PARTICIPANT	\N	PRESENT	0
790130	790119	11056N	PARTICIPANT	\N	PRESENT	0
790131	790119	20112S	PARTICIPANT	\N	PRESENT	0
790274	790118	21035B	PARTICIPANT	\N	EXCUSE	0
790275	790118	21080G	PARTICIPANT	\N	EXCUSE	0
790276	790118	14237S	PARTICIPANT	\N	EXCUSE	0
790277	789280	14111D	PARTICIPANT	\N	PRESENT	0
790278	789280	14189C	PARTICIPANT	\N	PRESENT	0
790279	789280	10015M	PARTICIPANT	\N	PRESENT	0
790280	789280	21040X	PARTICIPANT	\N	PRESENT	0
790281	789280	21088Q	PARTICIPANT	\N	PRESENT	0
790282	789280	20114U	PARTICIPANT	\N	PRESENT	0
790283	789280	21095P	PARTICIPANT	\N	PRESENT	0
790284	789280	19673G	PARTICIPANT	\N	PRESENT	0
790285	789280	14053L	PARTICIPANT	\N	PRESENT	0
790286	789280	20098N	PARTICIPANT	\N	PRESENT	0
790287	789280	21056G	PARTICIPANT	\N	PRESENT	0
790288	789280	18207D	PARTICIPANT	\N	PRESENT	0
790289	789280	18231D	PARTICIPANT	\N	PRESENT	0
790290	789280	20074E	PARTICIPANT	\N	PRESENT	0
790291	789280	19585H	PARTICIPANT	\N	PRESENT	0
790292	789280	19447X	PARTICIPANT	\N	PRESENT	0
790293	789280	14231L	PARTICIPANT	\N	PRESENT	0
790294	789280	19725B	PARTICIPANT	\N	PRESENT	0
790295	789280	14089Y	PARTICIPANT	\N	PRESENT	0
790296	789280	21044C	PARTICIPANT	\N	PRESENT	0
790297	789280	11056N	PARTICIPANT	\N	PRESENT	0
790298	789280	05008E	PARTICIPANT	\N	PRESENT	0
790299	789280	19719D	PARTICIPANT	\N	PRESENT	0
790300	789280	19489J	PARTICIPANT	\N	PRESENT	0
790301	789280	14147R	PARTICIPANT	\N	PRESENT	0
790302	789280	19111A	PARTICIPANT	\N	PRESENT	0
790303	789280	14151M	PARTICIPANT	\N	PRESENT	0
790304	789280	04045F	PARTICIPANT	\N	PRESENT	0
790305	789280	21038E	PARTICIPANT	\N	PRESENT	0
790306	789280	20266L	PARTICIPANT	\N	PRESENT	0
790307	789280	19749K	PARTICIPANT	\N	PRESENT	0
790308	789280	21043B	PARTICIPANT	\N	EXCUSE	0
790309	789280	04047H	PRESIDENT	\N	PRESENT	0
790310	789280	19729F	PARTICIPANT	\N	EXCUSE	0
790311	789280	21057H	PARTICIPANT	\N	EXCUSE	0
790312	789280	14275Y	PARTICIPANT	\N	PRESENT	0
790313	789280	21076L	PARTICIPANT	\N	PRESENT	0
790314	789280	14069U	PARTICIPANT	\N	PRESENT	0
790315	789280	08018U	PARTICIPANT	\N	PRESENT	0
790316	789280	14215L	PARTICIPANT	\N	PRESENT	0
790317	789280	20036X	PARTICIPANT	\N	PRESENT	0
790318	789280	20022R	PARTICIPANT	\N	PRESENT	0
790347	790342	20094J	PARTICIPANT	\N	PRESENT	0
790348	790342	14255U	PARTICIPANT	\N	PRESENT	0
790350	790342	21090J	PARTICIPANT	\N	PRESENT	0
790352	790342	19565D	PARTICIPANT	\N	PRESENT	0
790354	790342	19826F	PARTICIPANT	\N	PRESENT	0
790355	790342	14257W	PARTICIPANT	\N	PRESENT	0
790359	790342	04070G	PARTICIPANT	\N	PRESENT	0
790360	790342	21029D	PARTICIPANT	\N	PRESENT	0
790361	790342	21055F	PARTICIPANT	\N	PRESENT	0
790362	790342	19533U	PARTICIPANT	\N	PRESENT	0
791012	791011	19585H	PARTICIPANT	\N	PRESENT	0
791013	791011	20096L	PARTICIPANT	\N	PRESENT	0
791014	791011	20050V	PARTICIPANT	\N	PRESENT	0
791015	791011	14255U	PARTICIPANT	\N	PRESENT	0
791016	791011	19545Y	PARTICIPANT	\N	PRESENT	0
791017	791011	08056B	PARTICIPANT	\N	PRESENT	0
791018	791010	19760E	PARTICIPANT	\N	PRESENT	0
791022	791010	21046E	PARTICIPANT	\N	PRESENT	0
791020	789495	14071N	PRESIDENT	0	PRESENT	0
791021	791010	14030Q	PARTICIPANT	\N	PRESENT	0
791023	791010	20114U	PARTICIPANT	\N	PRESENT	0
791024	791010	20090E	PARTICIPANT	\N	PRESENT	0
791025	789495	04092N	PARTICIPANT	\N	EXCUSE	0
791026	791010	14053L	PARTICIPANT	\N	PRESENT	0
791027	789495	01034P	PARTICIPANT	\N	PRESENT	0
791028	789495	19703U	PARTICIPANT	\N	PRESENT	0
791034	791010	14217N	PARTICIPANT	\N	PRESENT	0
791030	789495	19760E	PARTICIPANT	\N	PRESENT	0
791032	789495	19295A	PARTICIPANT	\N	PRESENT	0
791033	791010	19693L	PARTICIPANT	\N	PRESENT	0
791035	789495	14042U	PARTICIPANT	\N	PRESENT	0
791036	791010	14042U	PARTICIPANT	\N	PRESENT	0
791037	789495	14281W	PARTICIPANT	\N	PRESENT	0
791038	791010	14281W	PARTICIPANT	\N	PRESENT	0
791040	789495	19691J	PARTICIPANT	\N	PRESENT	0
791039	791010	14026U	PARTICIPANT	\N	PRESENT	0
791041	789495	14213J	PARTICIPANT	\N	PRESENT	0
791042	791010	19691J	PARTICIPANT	\N	PRESENT	0
791044	791010	14213J	PARTICIPANT	\N	PRESENT	0
791045	791010	20034V	PARTICIPANT	\N	PRESENT	0
791047	791010	20056C	PARTICIPANT	\N	PRESENT	0
791048	789495	19301E	PARTICIPANT	\N	PRESENT	0
791049	789495	19798U	PARTICIPANT	\N	PRESENT	0
791050	791010	19447X	PARTICIPANT	\N	PRESENT	0
791051	789495	21064G	PARTICIPANT	\N	PRESENT	0
791052	791010	07029T	PARTICIPANT	\N	PRESENT	0
791053	789495	20130U	PARTICIPANT	\N	PRESENT	0
791054	791010	18193Q	PARTICIPANT	\N	PRESENT	0
791055	791010	21087P	PARTICIPANT	\N	PRESENT	0
791057	789495	21039F	PARTICIPANT	\N	PRESENT	0
791058	791010	14059S	PARTICIPANT	\N	PRESENT	0
791059	789495	19713W	PARTICIPANT	\N	PRESENT	0
791060	791010	14147R	PARTICIPANT	\N	PRESENT	0
791062	791010	14223L	PARTICIPANT	\N	PRESENT	0
791064	791010	14071N	PARTICIPANT	\N	PRESENT	0
791065	791010	14331P	PARTICIPANT	\N	PRESENT	0
791066	791010	19798U	PARTICIPANT	\N	PRESENT	0
791068	789495	14026U	PARTICIPANT	\N	PRESENT	0
791069	791010	19703U	PARTICIPANT	\N	PRESENT	0
791070	789495	08045X	PARTICIPANT	\N	PRESENT	0
791071	791010	20026V	PARTICIPANT	\N	PRESENT	0
791072	789495	14217N	PARTICIPANT	\N	PRESENT	0
791077	789495	21071F	PARTICIPANT	\N	PRESENT	0
791078	789495	19553Y	PARTICIPANT	\N	PRESENT	0
791084	789495	21049H	PARTICIPANT	\N	PRESENT	0
791089	789495	21046E	PARTICIPANT	\N	PRESENT	0
791090	789495	21087P	PARTICIPANT	\N	PRESENT	0
791091	789495	17965H	PARTICIPANT	\N	PRESENT	0
791105	789495	21097R	PARTICIPANT	\N	PRESENT	0
791120	789495	08061X	PARTICIPANT	\N	PRESENT	0
791123	789495	18193Q	PARTICIPANT	\N	PRESENT	0
791316	788456	21061D	PARTICIPANT	\N	EXCUSE	0
791317	791158	21061D	PARTICIPANT	\N	EXCUSE	0
791344	789389	21082J	PARTICIPANT	\N	PRESENT	0
791345	789389	14331P	PRESIDENT	0	PRESENT	0
791346	789389	19711U	PARTICIPANT	\N	PRESENT	0
791347	789389	08034U	PARTICIPANT	\N	PRESENT	0
791348	789389	10015M	PARTICIPANT	\N	PRESENT	0
791349	789389	21076L	PARTICIPANT	\N	PRESENT	0
791350	789389	20094J	PARTICIPANT	\N	PRESENT	0
791351	789389	14169X	PARTICIPANT	\N	PRESENT	0
791352	789389	20100N	PARTICIPANT	\N	PRESENT	0
785366	785363	19721W	PARTICIPANT	\N	PRESENT	0
788748	787205	20018V	PARTICIPANT	\N	PRESENT	0
788749	787205	14257W	PARTICIPANT	\N	PRESENT	0
788750	787205	11090Q	PARTICIPANT	\N	PRESENT	0
788751	787205	20082E	PARTICIPANT	\N	PRESENT	0
788752	787205	19705W	PARTICIPANT	\N	PRESENT	0
788766	787205	20054A	PARTICIPANT	\N	PRESENT	0
788767	787205	20092G	PARTICIPANT	\N	PRESENT	0
788768	787205	20084G	PARTICIPANT	\N	PRESENT	0
788769	787205	19413M	PARTICIPANT	\N	PRESENT	0
788842	786177	04042C	PARTICIPANT	\N	EXCUSE	0
788843	786177	18083K	PARTICIPANT	\N	PRESENT	0
788845	786177	21034A	PARTICIPANT	\N	PRESENT	0
788847	786177	17229F	PARTICIPANT	\N	PRESENT	0
788848	786177	20034V	PRESIDENT	0	PRESENT	0
788849	786177	08010L	PARTICIPANT	\N	PRESENT	0
788850	786177	14059S	PARTICIPANT	\N	PRESENT	0
788852	786177	05008E	PARTICIPANT	\N	EXCUSE	0
788853	786177	11072N	PARTICIPANT	\N	PRESENT	0
788855	786177	14275Y	PARTICIPANT	\N	PRESENT	0
788861	786177	19331L	PARTICIPANT	\N	PRESENT	0
788866	786177	20148F	PARTICIPANT	\N	EXCUSE	0
788868	786177	21029D	PARTICIPANT	\N	EXCUSE	0
788872	786177	19669L	PARTICIPANT	\N	EXCUSE	0
788873	786177	19691J	PARTICIPANT	\N	EXCUSE	0
788874	786177	17023S	PARTICIPANT	\N	EXCUSE	0
788875	786177	21073H	PARTICIPANT	\N	EXCUSE	0
788883	786176	05008E	PARTICIPANT	\N	EXCUSE	0
788884	786176	04042C	PARTICIPANT	\N	EXCUSE	0
788885	786176	18083K	PARTICIPANT	\N	PRESENT	0
788901	786176	21034A	PARTICIPANT	\N	PRESENT	0
788902	786176	17229F	PARTICIPANT	\N	PRESENT	0
788904	786176	17023S	PARTICIPANT	\N	EXCUSE	0
788905	786176	19691J	PARTICIPANT	\N	EXCUSE	0
788907	786176	20034V	PARTICIPANT	\N	PRESENT	0
788908	786176	08010L	PARTICIPANT	\N	PRESENT	0
788909	786176	14059S	PARTICIPANT	\N	PRESENT	0
788910	786176	12016W	PARTICIPANT	\N	PRESENT	1
788911	786176	21073H	PARTICIPANT	\N	EXCUSE	0
788912	786176	11072N	PARTICIPANT	\N	PRESENT	0
788913	786176	21029D	PARTICIPANT	\N	EXCUSE	0
788914	786176	19331L	PARTICIPANT	\N	PRESENT	0
788915	786176	20148F	PARTICIPANT	\N	EXCUSE	0
788916	786176	19669L	PARTICIPANT	\N	EXCUSE	0
788917	786176	14275Y	PARTICIPANT	\N	PRESENT	0
788918	786176	14259Y	PARTICIPANT	\N	PRESENT	0
788920	786176	20150Y	PARTICIPANT	\N	PRESENT	0
788935	786177	14259Y	PARTICIPANT	\N	PRESENT	0
788936	786177	20150Y	PARTICIPANT	\N	PRESENT	0
788965	786177	19657G	PARTICIPANT	\N	PRESENT	0
788966	786177	21035B	PARTICIPANT	\N	PRESENT	0
788968	786177	12016W	PARTICIPANT	\N	PRESENT	1
788973	786176	21035B	PARTICIPANT	\N	PRESENT	0
788974	786176	19657G	PARTICIPANT	\N	PRESENT	0
788976	786177	21097R	PARTICIPANT	\N	PRESENT	1
788977	786176	21097R	PARTICIPANT	\N	PRESENT	0
789391	789390	04047H	PARTICIPANT	\N	PRESENT	0
789393	789392	14053L	PARTICIPANT	\N	PRESENT	0
789394	789392	14193X	PARTICIPANT	\N	PRESENT	0
789395	789392	14097Y	PARTICIPANT	\N	PRESENT	0
789399	776125	20022R	PARTICIPANT	\N	PRESENT	0
789400	776125	19575F	PARTICIPANT	\N	PRESENT	0
789401	776125	20094J	PARTICIPANT	\N	PRESENT	0
789402	776125	21046E	PARTICIPANT	\N	PRESENT	0
790197	790118	21082J	PARTICIPANT	\N	PRESENT	0
789405	776125	20128B	PARTICIPANT	\N	PRESENT	0
789407	776125	20054A	PARTICIPANT	\N	PRESENT	0
789408	776125	04045F	PARTICIPANT	\N	PRESENT	0
789411	789409	19735D	PARTICIPANT	\N	PRESENT	0
789412	789409	19723Y	PARTICIPANT	\N	PRESENT	0
789413	789410	19735D	PARTICIPANT	\N	PRESENT	0
789414	789410	19723Y	PARTICIPANT	\N	PRESENT	0
789423	789422	20094J	PARTICIPANT	\N	PRESENT	0
789437	789436	19954N	PARTICIPANT	\N	PRESENT	0
789438	789436	14030Q	PARTICIPANT	\N	PRESENT	0
789439	789436	20138D	PARTICIPANT	\N	PRESENT	0
789440	789436	19621T	PARTICIPANT	\N	PRESENT	0
789441	789436	21089R	PARTICIPANT	\N	PRESENT	0
789442	789436	21063F	PARTICIPANT	\N	PRESENT	0
789443	789436	19057M	PARTICIPANT	\N	PRESENT	0
789444	789436	20264J	PARTICIPANT	\N	PRESENT	0
789445	789436	19693L	PARTICIPANT	\N	PRESENT	0
789446	789436	21091K	PARTICIPANT	\N	PRESENT	0
789447	789436	20132W	PARTICIPANT	\N	PRESENT	0
789448	789436	20172F	PARTICIPANT	\N	PRESENT	0
789449	789436	21032X	PARTICIPANT	\N	PRESENT	0
789450	789436	20180F	PARTICIPANT	\N	PRESENT	0
789451	789436	14123H	PARTICIPANT	\N	PRESENT	0
789452	789436	20056C	PARTICIPANT	\N	PRESENT	0
789453	789436	20048C	PARTICIPANT	\N	PRESENT	0
789454	789436	14021P	PARTICIPANT	\N	PRESENT	0
789455	789436	14073Q	PARTICIPANT	\N	PRESENT	0
789456	789436	19611R	PARTICIPANT	\N	PRESENT	0
789457	789436	21078N	PARTICIPANT	\N	PRESENT	0
789458	789436	20102Q	PARTICIPANT	\N	PRESENT	0
789459	789436	19735D	PARTICIPANT	\N	EXCUSE	0
789460	789436	19699S	PARTICIPANT	\N	PRESENT	0
789461	789436	20052X	PARTICIPANT	\N	PRESENT	0
789462	789436	08012N	PARTICIPANT	\N	PRESENT	0
789463	789436	20142Y	PARTICIPANT	\N	PRESENT	0
789464	789436	21058J	PARTICIPANT	\N	PRESENT	0
789465	789436	14109K	PARTICIPANT	\N	PRESENT	0
789466	789436	21037D	PARTICIPANT	\N	PRESENT	0
789467	789436	19593H	PARTICIPANT	\N	PRESENT	0
789468	789436	21055F	PARTICIPANT	\N	PRESENT	0
789469	789436	19533U	PARTICIPANT	\N	PRESENT	0
789470	789436	14229S	PARTICIPANT	\N	PRESENT	0
789471	789436	21059K	PARTICIPANT	\N	PRESENT	0
789472	789436	04033B	PARTICIPANT	\N	PRESENT	0
789473	789436	11043H	PARTICIPANT	\N	PRESENT	0
789474	789436	20026V	PARTICIPANT	\N	PRESENT	0
789475	789436	20058E	PARTICIPANT	\N	PRESENT	0
789476	789436	21077M	PARTICIPANT	\N	PRESENT	0
789477	789436	21074J	PARTICIPANT	\N	EXCUSE	0
789480	789479	18083K	PARTICIPANT	\N	PRESENT	0
789481	789479	20120S	PARTICIPANT	\N	PRESENT	0
789482	789479	14033T	PARTICIPANT	\N	PRESENT	0
789483	789479	20068G	PARTICIPANT	\N	PRESENT	0
789484	789479	14031R	PARTICIPANT	\N	PRESENT	0
789485	789479	19533U	PARTICIPANT	\N	PRESENT	0
789486	789479	20042V	PARTICIPANT	\N	PRESENT	0
789487	789479	11070L	PARTICIPANT	\N	PRESENT	0
789488	789479	19619A	PARTICIPANT	\N	EXCUSE	0
789489	789479	14257W	PRESIDENT	0	PRESENT	0
789490	789479	20106U	PARTICIPANT	\N	EXCUSE	0
789491	789479	14207L	PARTICIPANT	\N	EXCUSE	0
789492	789479	19695N	PARTICIPANT	\N	PRESENT	0
789493	789479	20092G	PARTICIPANT	\N	PRESENT	0
789715	789714	20112S	PARTICIPANT	\N	PRESENT	0
789716	789714	20138D	PARTICIPANT	\N	PRESENT	0
789718	789714	19735D	PARTICIPANT	\N	PRESENT	0
789719	789714	14229S	PARTICIPANT	\N	PRESENT	0
789723	789722	20112S	PARTICIPANT	\N	PRESENT	0
789724	789722	20138D	PARTICIPANT	\N	PRESENT	0
789725	789722	19735D	PARTICIPANT	\N	PRESENT	0
789726	789722	19693L	PARTICIPANT	\N	PRESENT	0
789728	789722	20142Y	PARTICIPANT	\N	PRESENT	0
789882	789881	20094J	PARTICIPANT	\N	PRESENT	0
789883	789881	14133K	PARTICIPANT	\N	PRESENT	0
790198	790118	20090E	PARTICIPANT	\N	PRESENT	0
790199	790118	21029D	PARTICIPANT	\N	PRESENT	0
790200	790118	19701S	PARTICIPANT	\N	PRESENT	0
790201	790118	20076G	PARTICIPANT	\N	PRESENT	0
790202	790118	21042A	PARTICIPANT	\N	PRESENT	0
790203	790118	19387D	PARTICIPANT	\N	PRESENT	0
790204	790118	14219Q	PRESIDENT	0	PRESENT	0
790205	790118	19820Y	PARTICIPANT	\N	PRESENT	0
790206	790118	19826F	PARTICIPANT	\N	PRESENT	0
790207	790118	21062E	PARTICIPANT	\N	PRESENT	0
790208	790118	21065H	PARTICIPANT	\N	PRESENT	0
790209	790118	18083K	PARTICIPANT	\N	PRESENT	0
790210	790118	21084L	PARTICIPANT	\N	PRESENT	0
790211	790118	20100N	PARTICIPANT	\N	PRESENT	0
790212	790118	05012A	PARTICIPANT	\N	PRESENT	0
790213	790118	08060W	PARTICIPANT	\N	PRESENT	0
790214	790118	14107H	PARTICIPANT	\N	PRESENT	0
790215	790118	20110Q	PARTICIPANT	\N	PRESENT	0
790216	790118	20020P	PARTICIPANT	\N	PRESENT	0
775930	775925	04047H	PARTICIPANT	\N	PRESENT	1
775931	775925	19111A	PARTICIPANT	\N	PRESENT	0
775932	775925	21043B	PARTICIPANT	\N	PRESENT	0
775933	775925	14053L	PARTICIPANT	\N	PRESENT	0
775934	775925	18231D	PARTICIPANT	\N	PRESENT	0
775938	775650	18231D	PARTICIPANT	\N	PRESENT	0
781276	781273	14030Q	PARTICIPANT	\N	PRESENT	0
781278	781273	14255U	PARTICIPANT	\N	PRESENT	0
781279	781273	19545Y	PARTICIPANT	\N	PRESENT	0
781280	781273	20070A	PARTICIPANT	\N	PRESENT	0
781281	781273	20120S	PARTICIPANT	\N	PRESENT	0
781282	781273	20180F	PARTICIPANT	\N	PRESENT	0
781283	781273	19531S	PARTICIPANT	\N	PRESENT	0
781284	781273	20126Y	PARTICIPANT	\N	PRESENT	0
781285	781273	08015R	PARTICIPANT	\N	PRESENT	0
781286	781273	14001X	PARTICIPANT	\N	PRESENT	0
781287	781273	21031W	PARTICIPANT	\N	PRESENT	0
781288	781273	20064C	PARTICIPANT	\N	PRESENT	0
781315	781314	21043B	PARTICIPANT	\N	PRESENT	0
781316	781314	20094J	PARTICIPANT	\N	PRESENT	0
781317	781314	20088L	PARTICIPANT	\N	PRESENT	0
781318	781314	19621T	PARTICIPANT	\N	PRESENT	0
781319	781314	14255U	PARTICIPANT	\N	PRESENT	0
781320	781314	04042C	PARTICIPANT	\N	PRESENT	0
781321	781314	20060X	PARTICIPANT	\N	PRESENT	0
781322	781314	11027H	PARTICIPANT	\N	PRESENT	0
781323	781314	14357A	PARTICIPANT	\N	PRESENT	0
781324	781314	20124W	PARTICIPANT	\N	PRESENT	0
781325	781314	14249W	PARTICIPANT	\N	PRESENT	0
781326	781314	14187A	PARTICIPANT	\N	PRESENT	0
781327	781314	14281W	PARTICIPANT	\N	PRESENT	0
781328	781314	20120S	PARTICIPANT	\N	PRESENT	0
781329	781314	20068G	PARTICIPANT	\N	PRESENT	0
781330	781314	19591F	PARTICIPANT	\N	PRESENT	0
781331	781314	99004R	PARTICIPANT	\N	PRESENT	0
781332	781314	14073Q	PARTICIPANT	\N	PRESENT	0
781333	781314	20126Y	PARTICIPANT	\N	PRESENT	0
781334	781314	19699S	PARTICIPANT	\N	PRESENT	0
781335	781314	14205J	PARTICIPANT	\N	PRESENT	0
781336	781314	11085T	PARTICIPANT	\N	PRESENT	0
781337	781314	20018V	PARTICIPANT	\N	PRESENT	0
781338	781314	04070G	PARTICIPANT	\N	PRESENT	0
781339	781314	18231D	PARTICIPANT	\N	PRESENT	0
781340	781314	21047F	PARTICIPANT	\N	PRESENT	0
781341	781314	21059K	PARTICIPANT	\N	PRESENT	0
781343	781342	20032T	PARTICIPANT	\N	PRESENT	0
781344	781342	20022R	PARTICIPANT	\N	PRESENT	0
781345	781342	17737W	PARTICIPANT	\N	PRESENT	0
781346	781342	21057H	PARTICIPANT	\N	PRESENT	0
781347	781342	21067K	PARTICIPANT	\N	PRESENT	0
781348	781342	20074E	PARTICIPANT	\N	PRESENT	0
781349	781342	14169X	PARTICIPANT	\N	PRESENT	0
781350	781342	19713W	PARTICIPANT	\N	PRESENT	0
781351	781342	21031W	PARTICIPANT	\N	PRESENT	0
781353	781352	08009T	PARTICIPANT	\N	PRESENT	0
781354	781352	20248J	PARTICIPANT	\N	PRESENT	0
781355	781352	10015M	PARTICIPANT	\N	PRESENT	0
781356	781352	21059K	PARTICIPANT	\N	PRESENT	0
781736	781735	20042V	PARTICIPANT	\N	PRESENT	0
781737	781735	20066E	PARTICIPANT	\N	PRESENT	0
781738	781735	21063F	PARTICIPANT	\N	PRESENT	0
781739	781735	20286Q	PARTICIPANT	\N	PRESENT	0
781740	781735	20018V	PARTICIPANT	\N	PRESENT	0
781741	781735	21056G	PARTICIPANT	\N	PRESENT	0
781742	781735	21083K	PARTICIPANT	\N	PRESENT	0
781743	781735	20086J	PARTICIPANT	\N	PRESENT	0
781744	781735	20026V	PARTICIPANT	\N	PRESENT	0
781745	781735	20106U	PARTICIPANT	\N	PRESENT	0
781746	781735	20132W	PARTICIPANT	\N	PRESENT	0
781747	781735	20082E	PARTICIPANT	\N	PRESENT	0
781748	781735	19711U	PARTICIPANT	\N	PRESENT	0
781749	781735	21093M	PARTICIPANT	\N	PRESENT	0
781750	781735	19349W	PARTICIPANT	\N	PRESENT	0
781751	781735	19399H	PARTICIPANT	\N	PRESENT	0
781752	781735	20044X	PARTICIPANT	\N	PRESENT	0
781753	781735	21041Y	PARTICIPANT	\N	PRESENT	0
781754	781735	21057H	PARTICIPANT	\N	EXCUSE	0
781755	781735	14169X	PARTICIPANT	\N	EXCUSE	0
781756	781735	20050V	PARTICIPANT	\N	EXCUSE	0
781757	781735	19703U	PARTICIPANT	\N	EXCUSE	0
781758	781735	19798U	PARTICIPANT	\N	EXCUSE	0
781759	781735	19479G	PARTICIPANT	\N	EXCUSE	0
781760	781735	20068G	PARTICIPANT	\N	EXCUSE	0
781761	781735	20024T	PARTICIPANT	\N	EXCUSE	0
785550	785541	11090Q	PARTICIPANT	\N	PRESENT	0
785553	785541	20286Q	PARTICIPANT	\N	PRESENT	0
785554	785541	14205J	PARTICIPANT	\N	PRESENT	0
785557	785541	19711U	PARTICIPANT	\N	PRESENT	0
785559	785541	14225N	PARTICIPANT	\N	PRESENT	0
785560	785541	14331P	PARTICIPANT	\N	PRESENT	0
785561	785541	14257W	PARTICIPANT	\N	PRESENT	0
785564	785541	14001X	PARTICIPANT	\N	PRESENT	0
785944	783404	20146D	PARTICIPANT	\N	PRESENT	0
785946	783404	21081H	PARTICIPANT	\N	PRESENT	0
785966	783404	21072G	PARTICIPANT	\N	PRESENT	0
786064	786063	14053L	PARTICIPANT	\N	PRESENT	0
786736	786735	19563B	PARTICIPANT	\N	PRESENT	0
786740	786739	20286Q	PARTICIPANT	\N	PRESENT	0
786741	786739	14187A	PARTICIPANT	\N	PRESENT	0
786742	786177	19631V	PARTICIPANT	\N	EXCUSE	0
786743	786176	19631V	PARTICIPANT	\N	EXCUSE	0
786745	786744	08028W	PARTICIPANT	\N	PRESENT	0
786746	786744	21044C	PARTICIPANT	\N	PRESENT	0
786747	786744	20052X	PARTICIPANT	\N	PRESENT	0
786748	786744	14221J	PARTICIPANT	\N	PRESENT	0
786749	786744	20018V	PARTICIPANT	\N	PRESENT	0
786750	786744	14223L	PARTICIPANT	\N	PRESENT	0
786751	786744	19703U	PARTICIPANT	\N	PRESENT	0
786752	786744	17965H	PARTICIPANT	\N	PRESENT	0
786757	786192	04047H	PRESIDENT	0	PRESENT	0
786758	786192	19673G	PARTICIPANT	\N	PRESENT	0
786759	786192	11072N	PARTICIPANT	\N	PRESENT	0
786760	786192	19729F	PARTICIPANT	\N	PRESENT	0
786761	786192	14147R	PARTICIPANT	\N	PRESENT	0
786763	786192	21043B	PARTICIPANT	\N	PRESENT	0
786765	786192	18231D	PARTICIPANT	\N	PRESENT	0
786804	786192	19489J	PARTICIPANT	\N	PRESENT	0
786778	786192	20110Q	PARTICIPANT	\N	PRESENT	0
786789	786192	18207D	PARTICIPANT	\N	PRESENT	0
786809	786192	04045F	PARTICIPANT	\N	PRESENT	0
786821	786192	20022R	PARTICIPANT	\N	PRESENT	0
786839	786192	14151M	PARTICIPANT	\N	PRESENT	0
786846	786192	21076L	PARTICIPANT	\N	PRESENT	0
786858	786193	04047H	PRESIDENT	0	PRESENT	0
786859	786193	18231D	PARTICIPANT	\N	PRESENT	0
786860	786193	18207D	PARTICIPANT	\N	PRESENT	0
786861	786193	19673G	PARTICIPANT	\N	PRESENT	0
786925	786193	14151M	PARTICIPANT	\N	PRESENT	0
786926	786193	20110Q	PARTICIPANT	\N	PRESENT	0
786929	786193	19489J	PARTICIPANT	\N	PRESENT	0
786952	786193	21044C	PARTICIPANT	\N	PRESENT	0
786954	786193	19649G	PARTICIPANT	\N	PRESENT	0
786959	786193	14147R	PARTICIPANT	\N	PRESENT	0
788479	786620	21089R	PARTICIPANT	\N	PRESENT	0
788480	786620	19301E	PARTICIPANT	\N	PRESENT	0
788481	786620	19782L	PARTICIPANT	\N	PRESENT	0
788482	786620	19399H	PARTICIPANT	\N	PRESENT	0
788483	786620	21071F	PARTICIPANT	\N	PRESENT	0
788484	786620	19693L	PARTICIPANT	\N	PRESENT	0
788485	786620	14231L	PARTICIPANT	\N	PRESENT	0
788486	786620	07004J	PARTICIPANT	\N	PRESENT	0
788487	786620	20132W	PARTICIPANT	\N	PRESENT	0
788488	786620	21094N	PARTICIPANT	\N	PRESENT	0
788489	786620	19719D	PARTICIPANT	\N	PRESENT	0
788490	786620	14193X	PARTICIPANT	\N	PRESENT	0
779243	776558	11048N	PARTICIPANT	\N	PRESENT	0
779244	776558	19699S	PARTICIPANT	\N	PRESENT	0
779245	776558	20102Q	PARTICIPANT	\N	PRESENT	0
779246	776558	14083S	PARTICIPANT	\N	PRESENT	0
779247	776558	19349W	PARTICIPANT	\N	PRESENT	0
779248	776558	21079P	PARTICIPANT	\N	PRESENT	0
779249	776558	19347U	PARTICIPANT	\N	PRESENT	0
779250	776558	19681G	PARTICIPANT	\N	PRESENT	0
779251	776558	14189C	PARTICIPANT	\N	PRESENT	0
779252	776558	19687N	PARTICIPANT	\N	PRESENT	0
779253	776558	01058X	PARTICIPANT	\N	PRESENT	0
779256	776558	18395Y	PARTICIPANT	\N	PRESENT	0
779257	776558	21034A	PARTICIPANT	\N	PRESENT	0
779258	776558	19573D	PARTICIPANT	\N	PRESENT	0
779259	776558	99004R	PARTICIPANT	\N	PRESENT	0
779260	776558	21054E	PARTICIPANT	\N	PRESENT	0
779261	776558	20082E	PARTICIPANT	\N	PRESENT	0
779241	776558	11043H	PARTICIPANT	\N	PRESENT	0
779242	776558	20056C	PARTICIPANT	\N	PRESENT	0
779262	776558	19533U	PARTICIPANT	\N	PRESENT	0
779264	776558	20084G	PARTICIPANT	\N	PRESENT	0
779265	776558	20138D	PARTICIPANT	\N	PRESENT	0
779266	776558	19735D	PARTICIPANT	\N	PRESENT	0
779267	776558	19531S	PARTICIPANT	\N	PRESENT	0
779268	776558	14109K	PARTICIPANT	\N	PRESENT	0
779269	776558	14021P	PARTICIPANT	\N	PRESENT	0
779270	776558	19693L	PARTICIPANT	\N	PRESENT	0
779271	776558	20052X	PARTICIPANT	\N	PRESENT	0
779272	776558	20124W	PARTICIPANT	\N	PRESENT	0
779273	776558	08034U	PARTICIPANT	\N	PRESENT	0
779274	776558	08010L	PARTICIPANT	\N	PRESENT	0
779275	776558	20126Y	PARTICIPANT	\N	PRESENT	0
779276	776558	19399H	PARTICIPANT	\N	PRESENT	0
779277	776558	20132W	PARTICIPANT	\N	PRESENT	0
779279	776558	07029T	PARTICIPANT	\N	PRESENT	0
779283	776558	19111A	PARTICIPANT	\N	PRESENT	0
779287	776558	19713W	PARTICIPANT	\N	PRESENT	0
779292	776558	19611R	PARTICIPANT	\N	PRESENT	0
779293	776558	20142Y	PARTICIPANT	\N	PRESENT	0
779296	776558	14179A	PARTICIPANT	\N	PRESENT	0
779297	776558	19697Q	PARTICIPANT	\N	PRESENT	0
779298	776558	14229S	PARTICIPANT	\N	PRESENT	0
779302	776560	11090Q	PARTICIPANT	\N	PRESENT	0
779357	776560	20042V	PARTICIPANT	\N	PRESENT	0
779358	776560	04070G	PARTICIPANT	\N	PRESENT	0
779305	776560	14026U	PARTICIPANT	\N	PRESENT	0
779306	776560	14215L	PARTICIPANT	\N	PRESENT	0
779307	776560	98022P	PARTICIPANT	\N	PRESENT	0
779370	776560	20138D	PARTICIPANT	\N	PRESENT	0
779309	776560	19782L	PARTICIPANT	\N	PRESENT	0
779310	776560	20062A	PARTICIPANT	\N	PRESENT	0
779311	776560	20076G	PARTICIPANT	\N	PRESENT	0
779312	776560	20034V	PARTICIPANT	\N	PRESENT	0
779313	776560	21072G	PARTICIPANT	\N	PRESENT	0
779314	776560	21093M	PARTICIPANT	\N	PRESENT	0
779315	776560	20134Y	PARTICIPANT	\N	PRESENT	0
779316	776560	21089R	PARTICIPANT	\N	PRESENT	0
779317	776560	20080C	PARTICIPANT	\N	PRESENT	0
779318	776560	14225N	PARTICIPANT	\N	PRESENT	0
779319	776560	21055F	PARTICIPANT	\N	PRESENT	0
779363	776560	20142Y	PARTICIPANT	\N	PRESENT	0
779321	776560	11040E	PARTICIPANT	\N	PRESENT	0
779322	776560	20016T	PARTICIPANT	\N	PRESENT	0
779323	776560	04045F	PARTICIPANT	\N	PRESENT	0
779324	776560	21063F	PARTICIPANT	\N	PRESENT	0
779325	776560	20056C	PARTICIPANT	\N	PRESENT	0
779326	776560	11048N	PARTICIPANT	\N	PRESENT	0
779327	776560	19699S	PARTICIPANT	\N	PRESENT	0
779328	776560	20102Q	PARTICIPANT	\N	PRESENT	0
779329	776560	14083S	PARTICIPANT	\N	PRESENT	0
779330	776560	19349W	PARTICIPANT	\N	PRESENT	0
779331	776560	19687N	PARTICIPANT	\N	PRESENT	0
779332	776560	18395Y	PARTICIPANT	\N	PRESENT	0
779333	776560	21034A	PARTICIPANT	\N	PRESENT	0
779334	776560	19573D	PARTICIPANT	\N	PRESENT	0
779335	776560	99004R	PARTICIPANT	\N	PRESENT	0
779336	776560	21054E	PARTICIPANT	\N	PRESENT	0
779337	776560	20082E	PARTICIPANT	\N	PRESENT	0
779364	776560	14253S	PARTICIPANT	\N	PRESENT	0
779339	776560	19735D	PARTICIPANT	\N	PRESENT	0
779340	776560	19531S	PARTICIPANT	\N	PRESENT	0
779341	776560	14109K	PARTICIPANT	\N	PRESENT	0
779342	776560	19693L	PARTICIPANT	\N	PRESENT	0
779343	776560	20052X	PARTICIPANT	\N	PRESENT	0
779344	776560	20124W	PARTICIPANT	\N	PRESENT	0
779345	776560	08034U	PARTICIPANT	\N	PRESENT	0
779346	776560	08010L	PARTICIPANT	\N	PRESENT	0
779347	776560	20126Y	PARTICIPANT	\N	PRESENT	0
779348	776560	19399H	PARTICIPANT	\N	PRESENT	0
779349	776560	20132W	PARTICIPANT	\N	PRESENT	0
779350	776560	07029T	PARTICIPANT	\N	PRESENT	0
779351	776560	19111A	PARTICIPANT	\N	PRESENT	0
779352	776560	19713W	PARTICIPANT	\N	PRESENT	0
779353	776560	19611R	PARTICIPANT	\N	PRESENT	0
779354	776560	19697Q	PARTICIPANT	\N	PRESENT	0
779355	776560	14229S	PARTICIPANT	\N	PRESENT	0
779356	776560	11074Q	PARTICIPANT	\N	PRESENT	0
779365	776560	19479G	PARTICIPANT	\N	PRESENT	0
779366	776560	21046E	PARTICIPANT	\N	PRESENT	0
779367	776560	21094N	PARTICIPANT	\N	PRESENT	0
779368	776560	20112S	PARTICIPANT	\N	PRESENT	0
779369	776560	14249W	PARTICIPANT	\N	PRESENT	0
779371	776560	20084G	PARTICIPANT	\N	PRESENT	0
779372	776560	19347U	PARTICIPANT	\N	PRESENT	0
779373	776560	14207L	PARTICIPANT	\N	PRESENT	0
779374	776560	14030Q	PARTICIPANT	\N	PRESENT	0
779375	776560	21037D	PARTICIPANT	\N	PRESENT	0
779376	776560	14231L	PARTICIPANT	\N	PRESENT	0
779377	776560	20058E	PARTICIPANT	\N	PRESENT	0
779378	776560	20072C	PARTICIPANT	\N	PRESENT	0
779379	776560	20116W	PARTICIPANT	\N	PRESENT	0
779380	776560	19593H	PARTICIPANT	\N	PRESENT	0
779381	776560	21030V	PARTICIPANT	\N	PRESENT	0
779383	776560	17023S	PARTICIPANT	\N	PRESENT	0
779429	779382	18395Y	PARTICIPANT	\N	PRESENT	0
779430	779382	20080C	PARTICIPANT	\N	PRESENT	0
779431	779382	21089R	PARTICIPANT	\N	PRESENT	0
779432	779382	20102Q	PARTICIPANT	\N	PRESENT	0
779433	779382	19593H	PARTICIPANT	\N	PRESENT	0
779434	779382	19349W	PARTICIPANT	\N	PRESENT	0
779435	779382	11074Q	PARTICIPANT	\N	PRESENT	0
779436	779382	19699S	PARTICIPANT	\N	PRESENT	0
779437	779382	20052X	PARTICIPANT	\N	PRESENT	0
779438	779382	19697Q	PARTICIPANT	\N	PRESENT	0
779439	779382	19693L	PARTICIPANT	\N	PRESENT	0
779440	779382	21046E	PARTICIPANT	\N	PRESENT	0
779441	779382	20132W	PARTICIPANT	\N	PRESENT	0
779442	779382	19611R	PARTICIPANT	\N	PRESENT	0
779443	779382	14109K	PARTICIPANT	\N	PRESENT	0
779444	779382	20124W	PARTICIPANT	\N	PRESENT	0
779445	779382	14229S	PARTICIPANT	\N	PRESENT	0
779446	779382	04045F	PARTICIPANT	\N	PRESENT	0
779447	779382	19735D	PARTICIPANT	\N	PRESENT	0
779448	779382	14187A	PARTICIPANT	\N	PRESENT	0
779449	779382	20062A	PARTICIPANT	\N	PRESENT	0
779450	779382	21063F	PARTICIPANT	\N	PRESENT	0
779451	779382	20056C	PARTICIPANT	\N	PRESENT	0
779452	779382	20076G	PARTICIPANT	\N	PRESENT	0
779453	779382	14253S	PARTICIPANT	\N	PRESENT	0
779454	779382	20112S	PARTICIPANT	\N	PRESENT	0
779455	779382	19399H	PARTICIPANT	\N	PRESENT	0
779456	779382	11090Q	PARTICIPANT	\N	PRESENT	0
779457	779382	99004R	PARTICIPANT	\N	PRESENT	0
779458	779382	19782L	PARTICIPANT	\N	PRESENT	0
779459	779382	20142Y	PARTICIPANT	\N	PRESENT	0
779460	779382	08010L	PARTICIPANT	\N	PRESENT	0
779461	779382	04070G	PARTICIPANT	\N	PRESENT	0
779462	779382	19573D	PARTICIPANT	\N	PRESENT	0
779463	779382	21033Y	PARTICIPANT	\N	PRESENT	0
779464	779382	20116W	PARTICIPANT	\N	PRESENT	0
779465	779382	98022P	PARTICIPANT	\N	PRESENT	0
779466	779382	17023S	PARTICIPANT	\N	PRESENT	0
779467	779382	20058E	PARTICIPANT	\N	PRESENT	0
779468	779382	20016T	PARTICIPANT	\N	PRESENT	0
779469	779382	08047A	PARTICIPANT	\N	PRESENT	0
779470	776561	19479G	PARTICIPANT	\N	PRESENT	0
779471	776561	21037D	PARTICIPANT	\N	PRESENT	0
779427	779382	19479G	PARTICIPANT	\N	PRESENT	0
779428	779382	21037D	PARTICIPANT	\N	PRESENT	0
779472	776561	18395Y	PARTICIPANT	\N	PRESENT	0
779473	776561	20080C	PARTICIPANT	\N	PRESENT	0
778636	775945	20094J	PARTICIPANT	\N	PRESENT	0
778637	775945	19683J	PARTICIPANT	\N	PRESENT	0
778638	775945	21037D	PARTICIPANT	\N	PRESENT	0
778639	775945	14001X	PARTICIPANT	\N	PRESENT	0
778640	775945	14331P	PRESIDENT	0	PRESENT	0
778641	775945	14169X	PARTICIPANT	\N	PRESENT	0
778642	775945	20104S	PARTICIPANT	\N	PRESENT	0
778643	775945	19701S	PARTICIPANT	\N	PRESENT	0
778644	775945	19569H	PARTICIPANT	\N	PRESENT	0
778645	775945	14073Q	PARTICIPANT	\N	PRESENT	0
778646	775945	20042V	PARTICIPANT	\N	PRESENT	0
778647	775945	20106U	PARTICIPANT	\N	PRESENT	0
778649	775945	21076L	PARTICIPANT	\N	PRESENT	0
778651	775945	20286Q	PARTICIPANT	\N	EXCUSE	0
778652	775945	19531S	PARTICIPANT	\N	PRESENT	0
778659	775945	01058X	PARTICIPANT	\N	PRESENT	0
778997	778996	19611R	PARTICIPANT	\N	PRESENT	0
778998	778996	20112S	PARTICIPANT	\N	PRESENT	1
780850	780849	14179A	PARTICIPANT	\N	PRESENT	0
780851	780849	14255U	PARTICIPANT	\N	PRESENT	0
780852	780849	19531S	PARTICIPANT	\N	PRESENT	0
780853	780849	19701S	PARTICIPANT	\N	PRESENT	0
787611	786625	11040E	PARTICIPANT	\N	EXCUSE	0
787612	786625	21048G	PARTICIPANT	\N	EXCUSE	0
791353	789389	17737W	PARTICIPANT	\N	PRESENT	0
791354	789389	08073C	PARTICIPANT	\N	PRESENT	0
791355	789389	19709B	PARTICIPANT	\N	PRESENT	0
791356	789389	18395Y	PARTICIPANT	\N	PRESENT	0
791357	789389	14237S	PARTICIPANT	\N	EXCUSE	0
791358	789389	21054E	PARTICIPANT	\N	EXCUSE	0
791359	789389	19701S	PARTICIPANT	\N	EXCUSE	0
791360	789389	20106U	PARTICIPANT	\N	EXCUSE	0
791361	789389	14189C	PARTICIPANT	\N	EXCUSE	0
791362	789389	20098N	PARTICIPANT	\N	EXCUSE	0
791367	789389	14026U	PARTICIPANT	\N	PRESENT	0
791368	789415	21035B	PARTICIPANT	\N	EXCUSE	0
791380	789274	14229S	PARTICIPANT	\N	PRESENT	0
791398	789274	20028X	PARTICIPANT	\N	PRESENT	0
791399	789274	19349W	PARTICIPANT	\N	PRESENT	0
791400	789274	21040X	PARTICIPANT	\N	PRESENT	0
791401	789274	21070E	PARTICIPANT	\N	PRESENT	0
791402	789274	19563B	PARTICIPANT	\N	PRESENT	0
791403	789274	14205J	PARTICIPANT	\N	PRESENT	0
791404	789274	21083K	PARTICIPANT	\N	PRESENT	0
791412	789274	21050A	PARTICIPANT	\N	PRESENT	0
791407	791365	14071N	PRESIDENT	0	PRESENT	0
791408	791365	14281W	PARTICIPANT	\N	PRESENT	0
791409	791365	19760E	PARTICIPANT	\N	PRESENT	0
791410	789274	20172F	PARTICIPANT	\N	PRESENT	0
791411	791365	21087P	PARTICIPANT	\N	PRESENT	0
791413	791365	14213J	PARTICIPANT	\N	PRESENT	0
791414	789274	20098N	PARTICIPANT	\N	PRESENT	0
791415	789274	11090Q	PARTICIPANT	\N	PRESENT	0
791416	791365	20090E	PARTICIPANT	\N	PRESENT	0
791417	791365	19691J	PARTICIPANT	\N	PRESENT	0
791418	791365	14042U	PARTICIPANT	\N	PRESENT	0
791419	789274	19347U	PARTICIPANT	\N	PRESENT	0
791420	791365	19569H	PARTICIPANT	\N	PRESENT	0
791421	791365	21064G	PARTICIPANT	\N	PRESENT	0
791422	791365	21094N	PARTICIPANT	\N	PRESENT	0
791424	789274	21076L	PARTICIPANT	\N	PRESENT	0
791426	789736	21084L	PARTICIPANT	\N	PRESENT	0
791427	789736	21082J	PARTICIPANT	\N	PRESENT	0
791428	789736	21056G	PARTICIPANT	\N	PRESENT	0
791429	789736	08034U	PARTICIPANT	\N	PRESENT	0
791430	789736	14031R	PARTICIPANT	\N	PRESENT	0
791431	789736	20038A	PARTICIPANT	\N	PRESENT	0
791432	789736	21066J	PARTICIPANT	\N	PRESENT	0
791433	789736	19413M	PARTICIPANT	\N	PRESENT	0
791434	789736	21090J	PARTICIPANT	\N	PRESENT	0
791435	789736	99004R	PRESIDENT	0	PRESENT	0
791436	789736	21093M	PARTICIPANT	\N	PRESENT	0
791437	789736	17023S	PARTICIPANT	\N	PRESENT	0
791438	789736	21050A	PARTICIPANT	\N	EXCUSE	0
791439	789274	20052X	PARTICIPANT	\N	PRESENT	0
791440	789274	20090E	PARTICIPANT	\N	PRESENT	0
791450	791448	21082J	PARTICIPANT	\N	PRESENT	0
791452	791448	08060W	PARTICIPANT	\N	PRESENT	0
791455	791454	21082J	PARTICIPANT	\N	PRESENT	0
791456	791454	08060W	PARTICIPANT	\N	PRESENT	0
791457	791454	20076G	PARTICIPANT	\N	PRESENT	0
791458	791454	20100N	PARTICIPANT	\N	PRESENT	0
791460	791459	21082J	PARTICIPANT	\N	PRESENT	0
791461	791459	08060W	PARTICIPANT	\N	PRESENT	0
791462	791459	20076G	PARTICIPANT	\N	PRESENT	0
791463	791459	20100N	PARTICIPANT	\N	PRESENT	0
791465	791464	21082J	PARTICIPANT	\N	PRESENT	0
791466	791464	08060W	PARTICIPANT	\N	PRESENT	0
791467	791464	20076G	PARTICIPANT	\N	PRESENT	0
791468	791464	20100N	PARTICIPANT	\N	PRESENT	0
791470	791469	21082J	PARTICIPANT	\N	PRESENT	0
791471	791469	08060W	PARTICIPANT	\N	PRESENT	0
791549	791548	14187A	PARTICIPANT	\N	PRESENT	0
791550	791548	20286Q	PARTICIPANT	\N	PRESENT	0
791551	791548	19631V	PARTICIPANT	\N	PRESENT	0
791553	791552	14187A	PARTICIPANT	\N	PRESENT	0
791554	791552	19631V	PARTICIPANT	\N	PRESENT	0
791555	791552	20286Q	PARTICIPANT	\N	PRESENT	0
791636	789736	21031W	PARTICIPANT	\N	EXCUSE	0
791687	791612	17737W	PARTICIPANT	\N	EXCUSE	0
791693	791692	21082J	PARTICIPANT	\N	PRESENT	0
791694	791692	20100N	PARTICIPANT	\N	PRESENT	0
791696	791695	21082J	PARTICIPANT	\N	PRESENT	0
791697	791695	20100N	PARTICIPANT	\N	PRESENT	0
791699	791698	21082J	PARTICIPANT	\N	PRESENT	0
791700	791698	20100N	PARTICIPANT	\N	PRESENT	0
791702	791701	21082J	PARTICIPANT	\N	PRESENT	0
791704	791703	21082J	PARTICIPANT	\N	PRESENT	0
791706	791705	14193X	PARTICIPANT	\N	PRESENT	0
791707	791705	07033P	PARTICIPANT	\N	PRESENT	0
791708	791705	21030V	PARTICIPANT	\N	PRESENT	0
791709	791705	14255U	PARTICIPANT	\N	PRESENT	0
791710	791705	04042C	PARTICIPANT	\N	PRESENT	0
791800	791761	21084L	PARTICIPANT	\N	PRESENT	0
791801	791761	21056G	PARTICIPANT	\N	PRESENT	0
791802	791761	21031W	PARTICIPANT	\N	PRESENT	0
791803	791761	19413M	PARTICIPANT	\N	PRESENT	0
791804	791761	99004R	PRESIDENT	0	PRESENT	0
791805	791761	21090J	PARTICIPANT	\N	PRESENT	0
791806	791761	21093M	PARTICIPANT	\N	PRESENT	0
791807	791761	17023S	PARTICIPANT	\N	PRESENT	0
791808	791761	19954N	PARTICIPANT	\N	EXCUSE	0
791809	791761	19782L	PARTICIPANT	\N	EXCUSE	0
791810	791761	21066J	PARTICIPANT	\N	EXCUSE	0
791817	791613	14151M	PRESIDENT	0	PRESENT	0
791818	791613	17367Q	PARTICIPANT	\N	PRESENT	0
791819	791613	12028B	PARTICIPANT	\N	PRESENT	0
791820	791613	18395Y	PARTICIPANT	\N	PRESENT	0
791821	791613	21095P	PARTICIPANT	\N	PRESENT	0
791893	791688	14111D	PARTICIPANT	\N	PRESENT	0
791894	791688	20036X	PARTICIPANT	\N	PRESENT	0
791895	791688	20074E	PARTICIPANT	\N	PRESENT	0
791896	791688	10015M	PARTICIPANT	\N	PRESENT	0
791897	791688	14069U	PARTICIPANT	\N	PRESENT	0
791898	791688	04045F	PARTICIPANT	\N	PRESENT	0
791899	791688	04047H	PRESIDENT	0	PRESENT	0
791900	791688	20098N	PARTICIPANT	\N	PRESENT	0
791901	791688	14215L	PARTICIPANT	\N	PRESENT	0
791902	791688	19447X	PARTICIPANT	\N	PRESENT	0
791903	791688	14053L	PARTICIPANT	\N	PRESENT	0
791904	791688	19489J	PARTICIPANT	\N	PRESENT	0
791905	791688	21056G	PARTICIPANT	\N	PRESENT	0
791906	791688	14147R	PARTICIPANT	\N	PRESENT	0
791907	791688	21043B	PARTICIPANT	\N	PRESENT	0
791908	791688	08018U	PARTICIPANT	\N	PRESENT	0
792032	791382	21067K	PARTICIPANT	\N	PRESENT	0
792033	791382	14215L	PARTICIPANT	\N	PRESENT	0
792034	791382	19251M	PARTICIPANT	\N	PRESENT	0
792035	791382	11045K	PARTICIPANT	\N	PRESENT	0
792036	791382	11110B	PARTICIPANT	\N	PRESENT	0
792170	791688	21044C	PARTICIPANT	\N	EXCUSE	0
792177	791617	19713W	PARTICIPANT	\N	PRESENT	0
792178	791617	21064G	PARTICIPANT	\N	PRESENT	0
792179	791617	19657G	PARTICIPANT	\N	PRESENT	0
792180	791617	14026U	PARTICIPANT	\N	PRESENT	0
792703	791846	21029D	PARTICIPANT	\N	PRESENT	0
792704	791846	21039F	PARTICIPANT	\N	PRESENT	0
792705	791846	14191V	PARTICIPANT	\N	PRESENT	0
792706	791846	19673G	PARTICIPANT	\N	PRESENT	0
792707	791846	21047F	PARTICIPANT	\N	PRESENT	0
792708	791846	14053L	PARTICIPANT	\N	PRESENT	0
787648	786530	19657G	PARTICIPANT	\N	PRESENT	0
787622	786530	20130U	PARTICIPANT	\N	PRESENT	0
787623	786530	19760E	PARTICIPANT	\N	PRESENT	0
787624	786530	14042U	PARTICIPANT	\N	PRESENT	0
787625	786530	14213J	PARTICIPANT	\N	PRESENT	0
787626	786530	19798U	PARTICIPANT	\N	PRESENT	0
787627	786530	17965H	PARTICIPANT	\N	PRESENT	0
787628	786530	19683J	PARTICIPANT	\N	PRESENT	0
787629	786530	14026U	PARTICIPANT	\N	PRESENT	0
787630	786530	18193Q	PARTICIPANT	\N	PRESENT	0
787631	786530	21097R	PARTICIPANT	\N	EXCUSE	0
787632	786530	04092N	PRESIDENT	0	PRESENT	0
787649	786530	19553Y	PARTICIPANT	\N	PRESENT	0
787650	786530	19703U	PARTICIPANT	\N	PRESENT	0
787651	786530	21087P	PARTICIPANT	\N	PRESENT	0
790217	790118	11065P	PARTICIPANT	\N	PRESENT	0
790218	790118	21051B	PARTICIPANT	\N	PRESENT	0
790219	790118	20120S	PARTICIPANT	\N	PRESENT	0
790220	790118	20032T	PARTICIPANT	\N	PRESENT	0
790221	790118	21053D	PARTICIPANT	\N	PRESENT	0
790222	790118	20136B	PARTICIPANT	\N	PRESENT	0
790223	790118	14031R	PARTICIPANT	\N	PRESENT	0
790224	790118	20040T	PARTICIPANT	\N	PRESENT	0
790225	790118	19251M	PARTICIPANT	\N	PRESENT	0
790226	790118	20046A	PARTICIPANT	\N	PRESENT	0
790227	790118	17229F	PARTICIPANT	\N	PRESENT	0
790228	790118	14169X	PARTICIPANT	\N	PRESENT	0
790229	790118	20068G	PARTICIPANT	\N	PRESENT	0
790230	790118	21068L	PARTICIPANT	\N	PRESENT	0
790231	790118	21070E	PARTICIPANT	\N	PRESENT	0
790232	790118	20106U	PARTICIPANT	\N	EXCUSE	0
790233	790118	19681G	PARTICIPANT	\N	EXCUSE	0
790234	789503	20086J	PARTICIPANT	\N	PRESENT	0
790235	789503	14331P	PARTICIPANT	\N	PRESENT	0
790236	789503	20080C	PARTICIPANT	\N	PRESENT	0
790237	789503	11053K	PARTICIPANT	\N	PRESENT	0
790238	789503	19667J	PARTICIPANT	\N	PRESENT	0
790239	789503	20094J	PARTICIPANT	\N	PRESENT	0
790240	789503	14225N	PRESIDENT	0	PRESENT	0
790241	789503	11110B	PARTICIPANT	\N	PRESENT	0
790242	789503	21079P	PARTICIPANT	\N	PRESENT	0
790243	789503	19573D	PARTICIPANT	\N	PRESENT	0
790244	789503	19349W	PARTICIPANT	\N	PRESENT	0
790245	789503	08010L	PARTICIPANT	\N	PRESENT	0
790246	789503	20116W	PARTICIPANT	\N	PRESENT	0
790247	789503	21090J	PARTICIPANT	\N	PRESENT	0
790248	789503	14253S	PARTICIPANT	\N	PRESENT	0
790249	789503	20024T	PARTICIPANT	\N	PRESENT	0
790250	789503	20126Y	PARTICIPANT	\N	PRESENT	0
790251	789503	11048N	PARTICIPANT	\N	PRESENT	0
790252	789503	19479G	PARTICIPANT	\N	PRESENT	0
790322	789266	19705W	PARTICIPANT	\N	PRESENT	0
790254	789503	19711U	PARTICIPANT	\N	PRESENT	0
790320	789266	20028X	PARTICIPANT	\N	PRESENT	0
790256	789503	08034U	PARTICIPANT	\N	PRESENT	0
790257	789503	12016W	PARTICIPANT	\N	PRESENT	0
790258	789503	20044X	PARTICIPANT	\N	PRESENT	0
790259	789503	19399H	PARTICIPANT	\N	PRESENT	0
790260	789503	20150Y	PARTICIPANT	\N	PRESENT	0
790261	789503	21041Y	PARTICIPANT	\N	PRESENT	0
790262	789503	11040E	PARTICIPANT	\N	PRESENT	0
790263	789503	14083S	PARTICIPANT	\N	PRESENT	0
790264	789503	20062A	PARTICIPANT	\N	PRESENT	0
790321	789266	20046A	PARTICIPANT	\N	PRESENT	0
790266	789503	08073C	PARTICIPANT	\N	PRESENT	0
790267	789503	20070A	PARTICIPANT	\N	PRESENT	0
790268	789503	08009T	PARTICIPANT	\N	PRESENT	0
790323	789266	20148F	PARTICIPANT	\N	PRESENT	0
790324	789266	19413M	PARTICIPANT	\N	PRESENT	0
790271	789503	14173T	PARTICIPANT	\N	EXCUSE	0
790319	789266	21031W	PARTICIPANT	\N	PRESENT	0
790325	789266	98022P	PARTICIPANT	\N	PRESENT	0
790326	789266	14275Y	PARTICIPANT	\N	PRESENT	0
790327	789266	19619A	PARTICIPANT	\N	PRESENT	0
790328	789266	04070G	PARTICIPANT	\N	PRESENT	0
790329	789266	08028W	PARTICIPANT	\N	PRESENT	0
790330	789266	19707Y	PARTICIPANT	\N	PRESENT	0
790331	789266	19866P	PARTICIPANT	\N	PRESENT	0
790332	789266	19573D	PARTICIPANT	\N	PRESENT	0
790336	789266	14267Y	PARTICIPANT	\N	PRESENT	0
790337	789266	19711U	PARTICIPANT	\N	PRESENT	0
790338	789266	14031R	PARTICIPANT	\N	PRESENT	0
790339	789266	19701S	PARTICIPANT	\N	PRESENT	0
790340	789266	14030Q	PARTICIPANT	\N	PRESENT	0
790341	789266	14207L	PARTICIPANT	\N	PRESENT	0
790343	789266	08061X	PARTICIPANT	\N	PRESENT	0
790344	789266	12016W	PARTICIPANT	\N	PRESENT	0
790345	789266	21055F	PARTICIPANT	\N	PRESENT	0
790346	789266	21047F	PARTICIPANT	\N	PRESENT	0
790349	789266	20032T	PARTICIPANT	\N	PRESENT	0
790351	789266	19111A	PARTICIPANT	\N	PRESENT	0
790353	789266	21066J	PARTICIPANT	\N	PRESENT	0
790356	789266	21078N	PARTICIPANT	\N	PRESENT	0
790357	789266	15197G	PARTICIPANT	\N	PRESENT	0
790358	789266	19721W	PARTICIPANT	\N	PRESENT	0
790363	789266	21040X	PARTICIPANT	\N	PRESENT	0
790364	789266	21050A	PARTICIPANT	\N	PRESENT	0
790365	789266	19611R	PARTICIPANT	\N	PRESENT	0
790366	789266	20052X	PARTICIPANT	\N	PRESENT	0
790367	789266	14111D	PARTICIPANT	\N	PRESENT	0
790368	789266	08045X	PARTICIPANT	\N	PRESENT	0
790369	789266	20082E	PARTICIPANT	\N	PRESENT	0
790370	789266	21059K	PARTICIPANT	\N	PRESENT	0
790372	789266	20018V	PARTICIPANT	\N	PRESENT	0
790373	789266	20036X	PARTICIPANT	\N	PRESENT	0
790374	789266	20144B	PARTICIPANT	\N	PRESENT	0
790375	789266	12028B	PARTICIPANT	\N	PRESENT	0
790376	789266	20092G	PARTICIPANT	\N	PRESENT	0
790377	789266	08060W	PARTICIPANT	\N	PRESENT	0
790378	789266	19387D	PARTICIPANT	\N	PRESENT	0
790379	789266	19719D	PARTICIPANT	\N	PRESENT	0
790380	789266	21077M	PARTICIPANT	\N	PRESENT	0
790381	789266	20264J	PARTICIPANT	\N	PRESENT	0
790382	789266	20110Q	PARTICIPANT	\N	PRESENT	0
790383	789266	20142Y	PARTICIPANT	\N	PRESENT	0
790384	789266	21086N	PARTICIPANT	\N	PRESENT	0
790385	789266	20100N	PARTICIPANT	\N	PRESENT	0
790386	789266	11110B	PARTICIPANT	\N	PRESENT	0
790387	789266	19683J	PARTICIPANT	\N	PRESENT	0
790388	789266	20064C	PARTICIPANT	\N	PRESENT	0
790389	789266	19479G	PARTICIPANT	\N	PRESENT	0
790390	789266	14189C	PARTICIPANT	\N	PRESENT	0
790391	789266	19563B	PARTICIPANT	\N	PRESENT	0
790392	789266	21070E	PARTICIPANT	\N	PRESENT	0
790393	789266	21087P	PARTICIPANT	\N	PRESENT	0
790394	789266	20146D	PARTICIPANT	\N	PRESENT	0
790395	789266	19691J	PARTICIPANT	\N	PRESENT	0
790396	789266	14042U	PARTICIPANT	\N	PRESENT	0
790397	789266	21096Q	PARTICIPANT	\N	PRESENT	0
790398	789266	21053D	PARTICIPANT	\N	PRESENT	0
790399	789266	19713W	PARTICIPANT	\N	PRESENT	0
790400	789266	19826F	PARTICIPANT	\N	PRESENT	0
790401	789266	14211G	PARTICIPANT	\N	PRESENT	0
790402	789266	14221J	PARTICIPANT	\N	PRESENT	0
790403	789266	19629C	PARTICIPANT	\N	PRESENT	0
790404	789266	04045F	PARTICIPANT	\N	PRESENT	0
790406	789266	19301E	PARTICIPANT	\N	PRESENT	0
790407	789266	08073C	PARTICIPANT	\N	PRESENT	0
790408	789266	20128B	PARTICIPANT	\N	PRESENT	0
790409	789266	21097R	PARTICIPANT	\N	PRESENT	0
790410	789266	19782L	PARTICIPANT	\N	PRESENT	0
790411	790405	20138D	PARTICIPANT	\N	PRESENT	0
790412	790405	21046E	PARTICIPANT	\N	PRESENT	0
790413	790405	20090E	PARTICIPANT	\N	PRESENT	0
790414	790405	19693L	PARTICIPANT	\N	PRESENT	0
790415	790405	20140W	PARTICIPANT	\N	PRESENT	0
790416	790405	14213J	PARTICIPANT	\N	PRESENT	0
790417	790405	19735D	PARTICIPANT	\N	PRESENT	0
790418	790405	19723Y	PARTICIPANT	\N	PRESENT	0
790419	790405	21087P	PARTICIPANT	\N	PRESENT	0
790420	790405	14223L	PARTICIPANT	\N	PRESENT	0
790421	790405	14071N	PARTICIPANT	\N	PRESENT	0
790422	790405	20096L	PARTICIPANT	\N	PRESENT	0
790423	790405	14331P	PARTICIPANT	\N	PRESENT	0
790424	790405	19798U	PARTICIPANT	\N	PRESENT	0
790425	790405	20150Y	PARTICIPANT	\N	PRESENT	0
790426	789266	19349W	PARTICIPANT	\N	PRESENT	0
790427	789266	11048N	PARTICIPANT	\N	PRESENT	0
790428	789266	19575F	PARTICIPANT	\N	PRESENT	0
790429	789266	19621T	PARTICIPANT	\N	PRESENT	0
790430	789266	14249W	PARTICIPANT	\N	PRESENT	0
778269	775939	20140W	PARTICIPANT	\N	PRESENT	0
778270	775939	21039F	PARTICIPANT	\N	PRESENT	0
778271	775940	20140W	PARTICIPANT	\N	PRESENT	0
788538	786621	21094N	PARTICIPANT	\N	PRESENT	0
788539	786621	19693L	PARTICIPANT	\N	PRESENT	0
788540	786621	21054E	PARTICIPANT	\N	PRESENT	0
788541	786621	21070E	PARTICIPANT	\N	PRESENT	0
788542	786621	19745F	PARTICIPANT	\N	PRESENT	0
788543	786621	19713W	PARTICIPANT	\N	PRESENT	0
788544	786621	17023S	PARTICIPANT	\N	PRESENT	0
788545	786621	14189C	PARTICIPANT	\N	PRESENT	0
788546	786621	14231L	PARTICIPANT	\N	PRESENT	0
788547	786621	20132W	PARTICIPANT	\N	PRESENT	0
788548	786621	19629C	PARTICIPANT	\N	PRESENT	0
788549	786621	21078N	PARTICIPANT	\N	PRESENT	0
788550	786621	20032T	PARTICIPANT	\N	PRESENT	0
788551	786621	11043H	PARTICIPANT	\N	PRESENT	0
788552	786621	07029T	PARTICIPANT	\N	PRESENT	0
788553	786621	14215L	PARTICIPANT	\N	PRESENT	0
788554	786621	14147R	PARTICIPANT	\N	PRESENT	0
788555	786621	21071F	PARTICIPANT	\N	PRESENT	0
788558	786621	21045D	PARTICIPANT	\N	PRESENT	0
788560	786621	19758L	PARTICIPANT	\N	PRESENT	0
788563	786621	20180F	PARTICIPANT	\N	PRESENT	0
788579	786621	19719D	PARTICIPANT	\N	PRESENT	0
788582	786621	19725B	PARTICIPANT	\N	PRESENT	0
788583	786621	14026U	PARTICIPANT	\N	PRESENT	0
788584	786621	19399H	PARTICIPANT	\N	PRESENT	0
788586	786621	19782L	PARTICIPANT	\N	PRESENT	0
788587	786621	14267Y	PARTICIPANT	\N	PRESENT	0
788588	786621	14073Q	PARTICIPANT	\N	PRESENT	0
788614	786622	08012N	PARTICIPANT	\N	PRESENT	0
788615	786622	20134Y	PARTICIPANT	\N	PRESENT	0
788616	786622	20052X	PARTICIPANT	\N	PRESENT	0
788536	786621	11090Q	PARTICIPANT	\N	PRESENT	0
788537	786621	19301E	PARTICIPANT	\N	PRESENT	0
788617	786622	19611R	PARTICIPANT	\N	PRESENT	0
788618	786622	14073Q	PARTICIPANT	\N	PRESENT	0
788619	786622	20048C	PARTICIPANT	\N	PRESENT	0
788620	786622	19349W	PARTICIPANT	\N	PRESENT	0
788621	786622	21077M	PARTICIPANT	\N	PRESENT	0
788622	786622	21070E	PARTICIPANT	\N	PRESENT	0
788623	786622	21078N	PARTICIPANT	\N	PRESENT	0
788624	786622	11043H	PARTICIPANT	\N	PRESENT	0
788625	786622	14147R	PARTICIPANT	\N	PRESENT	0
788626	786622	19399H	PARTICIPANT	\N	PRESENT	0
788627	786622	11056N	PARTICIPANT	\N	PRESENT	0
788628	786622	20102Q	PARTICIPANT	\N	PRESENT	0
788629	786622	19533U	PARTICIPANT	\N	PRESENT	0
788630	786622	17023S	PARTICIPANT	\N	PRESENT	0
788631	786622	21095P	PARTICIPANT	\N	PRESENT	0
788632	786622	14069U	PARTICIPANT	\N	PRESENT	0
788633	786622	14031R	PARTICIPANT	\N	PRESENT	0
788634	786622	20092G	PARTICIPANT	\N	PRESENT	0
788635	786622	20042V	PARTICIPANT	\N	PRESENT	0
788612	786622	19593H	PARTICIPANT	\N	PRESENT	0
788613	786622	19725B	PARTICIPANT	\N	PRESENT	0
791320	788456	14109K	PARTICIPANT	\N	PRESENT	0
791321	788456	21042A	PARTICIPANT	\N	PRESENT	0
791322	788456	20180F	PARTICIPANT	\N	PRESENT	0
791323	788456	21089R	PARTICIPANT	\N	PRESENT	0
791324	788456	19749K	PRESIDENT	0	PRESENT	0
791325	788456	11045K	PARTICIPANT	\N	PRESENT	0
791326	788456	20062A	PARTICIPANT	\N	PRESENT	0
791330	788456	20098N	PARTICIPANT	\N	PRESENT	0
791342	788456	18193Q	PARTICIPANT	\N	PRESENT	0
791343	788456	07029T	PARTICIPANT	\N	EXCUSE	0
791363	788456	14030Q	PARTICIPANT	\N	PRESENT	0
791364	788456	21077M	PARTICIPANT	\N	PRESENT	0
791369	791158	19749K	PRESIDENT	0	PRESENT	0
791370	791158	21077M	PARTICIPANT	\N	PRESENT	0
791371	791158	11045K	PARTICIPANT	\N	PRESENT	0
791372	791158	21089R	PARTICIPANT	\N	PRESENT	0
791373	791158	20180F	PARTICIPANT	\N	PRESENT	0
791374	791158	14030Q	PARTICIPANT	\N	PRESENT	0
791375	791158	07029T	PARTICIPANT	\N	EXCUSE	0
791376	791158	18193Q	PARTICIPANT	\N	PRESENT	0
791377	791158	20098N	PARTICIPANT	\N	PRESENT	0
791378	791158	20062A	PARTICIPANT	\N	PRESENT	0
791379	791158	14109K	PARTICIPANT	\N	PRESENT	0
794517	793592	21091K	PARTICIPANT	\N	EXCUSE	0
794519	793592	19749K	PRESIDENT	0	PRESENT	0
794520	793592	11045K	PARTICIPANT	\N	PRESENT	0
794521	793592	19798U	PARTICIPANT	\N	PRESENT	0
794522	793592	21042A	PARTICIPANT	\N	PRESENT	0
794523	793592	21038E	PARTICIPANT	\N	PRESENT	0
794524	793592	20062A	PARTICIPANT	\N	EXCUSE	0
794525	793592	20098N	PARTICIPANT	\N	PRESENT	0
794526	793592	14179A	PARTICIPANT	\N	PRESENT	0
794530	793592	21094N	PARTICIPANT	\N	EXCUSE	0
794551	793592	18193Q	PARTICIPANT	\N	PRESENT	0
796746	794075	20026V	PARTICIPANT	\N	PRESENT	0
796747	794075	19954N	PARTICIPANT	\N	PRESENT	0
796748	794075	20138D	PARTICIPANT	\N	PRESENT	0
796749	794075	20172F	PARTICIPANT	\N	PRESENT	0
796750	794075	14147R	PARTICIPANT	\N	PRESENT	0
796751	794075	14038Y	PARTICIPANT	\N	PRESENT	0
796752	794075	19723Y	PARTICIPANT	\N	PRESENT	0
796753	794075	21047F	PARTICIPANT	\N	PRESENT	0
796754	794075	20140W	PARTICIPANT	\N	PRESENT	0
796755	794075	20038A	PARTICIPANT	\N	PRESENT	0
796756	794075	19399H	PARTICIPANT	\N	PRESENT	0
796757	794075	20034V	PARTICIPANT	\N	PRESENT	0
796758	794075	19575F	PARTICIPANT	\N	PRESENT	0
796759	794075	20056C	PARTICIPANT	\N	PRESENT	0
796760	794075	20104S	PARTICIPANT	\N	PRESENT	0
796761	794075	20058E	PARTICIPANT	\N	PRESENT	0
796762	794075	21063F	PARTICIPANT	\N	PRESENT	0
796763	794075	20068G	PARTICIPANT	\N	PRESENT	0
796764	794075	17367Q	PARTICIPANT	\N	PRESENT	0
796765	794075	14355X	PARTICIPANT	\N	PRESENT	0
796766	794075	07029T	PARTICIPANT	\N	PRESENT	0
796767	794075	19657G	PARTICIPANT	\N	PRESENT	0
796768	794075	20050V	PARTICIPANT	\N	PRESENT	0
796769	794075	21070E	PARTICIPANT	\N	PRESENT	0
796770	794075	08015R	PARTICIPANT	\N	PRESENT	0
796771	794075	19768N	PARTICIPANT	\N	PRESENT	0
796772	794075	21036C	PARTICIPANT	\N	PRESENT	0
796773	794075	19545Y	PARTICIPANT	\N	PRESENT	0
796774	794075	19693L	PARTICIPANT	\N	PRESENT	0
796775	794075	08056B	PARTICIPANT	\N	PRESENT	0
796776	794075	20124W	PARTICIPANT	\N	PRESENT	0
796777	794075	20054A	PARTICIPANT	\N	PRESENT	0
796778	794075	14357A	PARTICIPANT	\N	PRESENT	0
796779	794075	21054E	PARTICIPANT	\N	PRESENT	0
796780	794075	20086J	PARTICIPANT	\N	PRESENT	0
796781	794075	21095P	PARTICIPANT	\N	PRESENT	0
796782	794075	21090J	PARTICIPANT	\N	PRESENT	0
796783	794075	14217N	PARTICIPANT	\N	PRESENT	0
796784	794075	20118Y	PARTICIPANT	\N	PRESENT	0
796785	794075	20020P	PARTICIPANT	\N	PRESENT	0
796786	794075	19533U	PARTICIPANT	\N	PRESENT	0
796787	794075	14221J	PARTICIPANT	\N	PRESENT	0
796788	794075	20122U	PARTICIPANT	\N	PRESENT	0
796789	794075	21076L	PARTICIPANT	\N	PRESENT	0
796790	794075	14069U	PARTICIPANT	\N	PRESENT	0
796791	794075	19631V	PARTICIPANT	\N	PRESENT	0
796792	794075	21035B	PARTICIPANT	\N	PRESENT	0
796793	794075	20094J	PARTICIPANT	\N	PRESENT	0
796794	794075	20088L	PARTICIPANT	\N	PRESENT	0
796795	794075	20114U	PARTICIPANT	\N	PRESENT	0
796796	794075	14071N	PARTICIPANT	\N	PRESENT	0
796797	794075	14187A	PARTICIPANT	\N	PRESENT	0
796798	794075	20080C	PARTICIPANT	\N	PRESENT	0
796799	794075	19701S	PARTICIPANT	\N	PRESENT	0
796800	794075	21089R	PARTICIPANT	\N	PRESENT	0
796801	794075	14053L	PARTICIPANT	\N	PRESENT	0
796802	794075	19679N	PARTICIPANT	\N	PRESENT	0
796803	794075	04033B	PARTICIPANT	\N	PRESENT	0
796804	794075	20062A	PARTICIPANT	\N	PRESENT	0
796805	794075	05008E	PARTICIPANT	\N	PRESENT	0
796806	794075	11048N	PARTICIPANT	\N	PRESENT	0
796807	794075	21045D	PARTICIPANT	\N	PRESENT	0
796808	794075	20060X	PARTICIPANT	\N	PRESENT	0
796809	794075	04092N	PARTICIPANT	\N	PRESENT	0
796810	794075	14133K	PARTICIPANT	\N	PRESENT	0
796811	794075	08034U	PARTICIPANT	\N	PRESENT	0
796812	794075	12028B	PARTICIPANT	\N	PRESENT	0
796813	794075	08010L	PARTICIPANT	\N	PRESENT	0
796814	794075	20264J	PARTICIPANT	\N	PRESENT	0
796815	794075	04047H	PARTICIPANT	\N	PRESENT	0
779474	776561	21089R	PARTICIPANT	\N	PRESENT	0
779475	776561	20102Q	PARTICIPANT	\N	PRESENT	0
779476	776561	19593H	PARTICIPANT	\N	PRESENT	0
779477	776561	19349W	PARTICIPANT	\N	PRESENT	0
779478	776561	11074Q	PARTICIPANT	\N	PRESENT	0
779479	776561	19699S	PARTICIPANT	\N	PRESENT	0
779480	776561	20052X	PARTICIPANT	\N	PRESENT	0
779481	776561	19697Q	PARTICIPANT	\N	PRESENT	0
779482	776561	19693L	PARTICIPANT	\N	PRESENT	0
779483	776561	21046E	PARTICIPANT	\N	PRESENT	0
779484	776561	20132W	PARTICIPANT	\N	PRESENT	0
779485	776561	19611R	PARTICIPANT	\N	PRESENT	0
779486	776561	14109K	PARTICIPANT	\N	PRESENT	0
779487	776561	20124W	PARTICIPANT	\N	PRESENT	0
779488	776561	14229S	PARTICIPANT	\N	PRESENT	0
779489	776561	04045F	PARTICIPANT	\N	PRESENT	0
779490	776561	19735D	PARTICIPANT	\N	PRESENT	0
779491	776561	14187A	PARTICIPANT	\N	PRESENT	0
779492	776561	20062A	PARTICIPANT	\N	PRESENT	0
779493	776561	21063F	PARTICIPANT	\N	PRESENT	0
779494	776561	20056C	PARTICIPANT	\N	PRESENT	0
779495	776561	20076G	PARTICIPANT	\N	PRESENT	0
779496	776561	14253S	PARTICIPANT	\N	PRESENT	0
779497	776561	20112S	PARTICIPANT	\N	PRESENT	0
779498	776561	19399H	PARTICIPANT	\N	PRESENT	0
779499	776561	11090Q	PARTICIPANT	\N	PRESENT	0
779500	776561	99004R	PARTICIPANT	\N	PRESENT	0
779501	776561	19782L	PARTICIPANT	\N	PRESENT	0
779502	776561	20142Y	PARTICIPANT	\N	PRESENT	0
779503	776561	08010L	PARTICIPANT	\N	PRESENT	0
779504	776561	04070G	PARTICIPANT	\N	PRESENT	0
779505	776561	19573D	PARTICIPANT	\N	PRESENT	0
779506	776561	21033Y	PARTICIPANT	\N	PRESENT	0
779507	776561	20116W	PARTICIPANT	\N	PRESENT	0
779508	776561	98022P	PARTICIPANT	\N	PRESENT	0
779509	776561	17023S	PARTICIPANT	\N	PRESENT	0
779510	776561	20058E	PARTICIPANT	\N	PRESENT	0
779511	776561	20016T	PARTICIPANT	\N	PRESENT	0
779512	776561	08047A	PARTICIPANT	\N	PRESENT	0
779513	776561	20114U	PARTICIPANT	\N	PRESENT	0
779514	776561	19531S	PARTICIPANT	\N	PRESENT	0
779515	776561	11027H	PARTICIPANT	\N	PRESENT	0
779516	776561	07029T	PARTICIPANT	\N	PRESENT	0
779541	779540	14097Y	PARTICIPANT	\N	PRESENT	0
781251	781245	19691J	PARTICIPANT	\N	PRESENT	0
781253	781245	14071N	PARTICIPANT	\N	PRESENT	0
781255	781245	20130U	PARTICIPANT	\N	PRESENT	0
781256	781245	19703U	PARTICIPANT	\N	PRESENT	0
781262	781261	19691J	PARTICIPANT	\N	PRESENT	0
781263	781261	20130U	PARTICIPANT	\N	PRESENT	0
781264	781261	19703U	PARTICIPANT	\N	PRESENT	0
781577	779299	20090E	PARTICIPANT	\N	EXCUSE	0
781578	779151	21036C	PARTICIPANT	\N	PRESENT	0
781579	779151	95041E	PARTICIPANT	\N	PRESENT	0
781580	779151	21031W	PARTICIPANT	\N	PRESENT	0
781581	779151	19565D	PARTICIPANT	\N	PRESENT	0
781582	779151	20072C	PARTICIPANT	\N	PRESENT	0
781583	779151	01058X	PARTICIPANT	\N	PRESENT	0
781584	779151	11027H	PARTICIPANT	\N	PRESENT	0
781585	779151	04042C	PARTICIPANT	\N	PRESENT	0
781586	779151	19669L	PARTICIPANT	\N	PRESENT	0
781587	779151	08056B	PARTICIPANT	\N	PRESENT	0
781588	779151	12028B	PARTICIPANT	\N	PRESENT	0
781589	779151	17737W	PARTICIPANT	\N	PRESENT	0
781590	779151	11115U	PARTICIPANT	\N	PRESENT	0
781591	779151	19421M	PARTICIPANT	\N	PRESENT	0
781592	779151	21067K	PARTICIPANT	\N	PRESENT	0
781593	779151	14193X	PRESIDENT	0	PRESENT	0
781594	779151	14179A	PARTICIPANT	\N	PRESENT	0
781595	779151	17367Q	PARTICIPANT	\N	PRESENT	0
781596	779151	14249W	PARTICIPANT	\N	PRESENT	0
781597	779151	08047A	PARTICIPANT	\N	PRESENT	0
781598	779151	20128B	PARTICIPANT	\N	PRESENT	0
781599	779151	14037X	PARTICIPANT	\N	PRESENT	0
781600	779151	14097Y	PARTICIPANT	\N	PRESENT	0
781601	779151	14059S	PARTICIPANT	\N	PRESENT	0
781602	779151	14133K	PARTICIPANT	\N	PRESENT	0
781603	779151	21073H	PARTICIPANT	\N	PRESENT	0
781604	779151	19531S	PARTICIPANT	\N	PRESENT	0
781605	779151	08069G	PARTICIPANT	\N	PRESENT	0
781606	779151	19721W	PARTICIPANT	\N	PRESENT	0
781607	779151	20064C	PARTICIPANT	\N	PRESENT	0
781608	779151	20252E	PARTICIPANT	\N	PRESENT	0
781609	779151	14251Q	PARTICIPANT	\N	PRESENT	0
781610	779151	98022P	PARTICIPANT	\N	PRESENT	0
781611	779151	14267Y	PARTICIPANT	\N	PRESENT	0
781612	779151	99004R	PARTICIPANT	\N	PRESENT	0
781613	779151	19745F	PARTICIPANT	\N	PRESENT	0
781614	779151	14211G	PARTICIPANT	\N	PRESENT	0
781615	779151	14255U	PARTICIPANT	\N	PRESENT	0
781616	779151	17023S	PARTICIPANT	\N	PRESENT	0
781617	779151	14001X	PARTICIPANT	\N	EXCUSE	0
781618	779151	07033P	PARTICIPANT	\N	EXCUSE	0
781734	779281	20022R	PARTICIPANT	\N	EXCUSE	0
781763	779652	14107H	PARTICIPANT	\N	PRESENT	0
781766	779652	21052C	PARTICIPANT	\N	PRESENT	0
781767	779652	21046E	PARTICIPANT	\N	PRESENT	0
781768	779652	21040X	PARTICIPANT	\N	PRESENT	0
781769	779652	14030Q	PARTICIPANT	\N	PRESENT	0
781771	779652	20100N	PARTICIPANT	\N	PRESENT	0
781772	779652	21066J	PARTICIPANT	\N	PRESENT	0
781773	779652	21053D	PARTICIPANT	\N	PRESENT	0
781774	779652	12016W	PARTICIPANT	\N	PRESENT	0
781775	779652	20016T	PARTICIPANT	\N	PRESENT	0
781776	779652	19782L	PARTICIPANT	\N	PRESENT	0
781777	779652	19629C	PARTICIPANT	\N	PRESENT	0
781778	779652	14267Y	PARTICIPANT	\N	PRESENT	0
781779	779652	20144B	PARTICIPANT	\N	PRESENT	0
781780	779652	14073Q	PARTICIPANT	\N	PRESENT	0
781781	779652	20116W	PARTICIPANT	\N	PRESENT	0
781782	779652	14001X	PARTICIPANT	\N	PRESENT	0
781783	779652	21076L	PARTICIPANT	\N	PRESENT	0
781784	779652	21041Y	PARTICIPANT	\N	PRESENT	0
781785	779652	19421M	PARTICIPANT	\N	PRESENT	0
781786	779652	20172F	PARTICIPANT	\N	PRESENT	0
781787	779652	14253S	PARTICIPANT	\N	PRESENT	0
781788	779652	20078J	PARTICIPANT	\N	PRESENT	0
781789	779652	19820Y	PARTICIPANT	\N	PRESENT	0
781790	779652	17779H	PARTICIPANT	\N	PRESENT	0
781792	779652	21082J	PARTICIPANT	\N	PRESENT	0
781793	779652	18395Y	PARTICIPANT	\N	PRESENT	0
781794	779652	20088L	PARTICIPANT	\N	PRESENT	0
781795	779652	20030R	PARTICIPANT	\N	PRESENT	0
781796	779652	20064C	PARTICIPANT	\N	PRESENT	0
781797	779652	08060W	PARTICIPANT	\N	PRESENT	0
781798	779652	14257W	PARTICIPANT	\N	PRESENT	0
781799	779652	14021P	PARTICIPANT	\N	PRESENT	0
781800	779652	20114U	PARTICIPANT	\N	PRESENT	0
781802	779652	14151M	PARTICIPANT	\N	PRESENT	0
781803	779652	19711U	PARTICIPANT	\N	PRESENT	0
781804	779652	19621T	PARTICIPANT	\N	PRESENT	0
781805	779652	19575F	PARTICIPANT	\N	PRESENT	0
781806	779652	01058X	PARTICIPANT	\N	PRESENT	0
781807	779652	08011M	PARTICIPANT	\N	PRESENT	0
781808	779652	19367Y	PARTICIPANT	\N	PRESENT	0
781809	779652	11048N	PARTICIPANT	\N	PRESENT	0
781810	779652	21091K	PARTICIPANT	\N	PRESENT	0
781811	779652	04042C	PARTICIPANT	\N	PRESENT	0
781812	779652	08069G	PARTICIPANT	\N	PRESENT	0
781813	779652	14259Y	PARTICIPANT	\N	PRESENT	0
781814	779652	11056N	PARTICIPANT	\N	PRESENT	0
781815	779652	20076G	PARTICIPANT	\N	PRESENT	0
781816	779652	21088Q	PARTICIPANT	\N	PRESENT	0
781817	779652	21084L	PARTICIPANT	\N	PRESENT	0
781818	779652	20074E	PARTICIPANT	\N	PRESENT	0
781819	779652	19760E	PARTICIPANT	\N	PRESENT	0
781820	779652	21075K	PARTICIPANT	\N	PRESENT	0
781821	779652	21044C	PARTICIPANT	\N	PRESENT	0
781822	779652	21080G	PARTICIPANT	\N	PRESENT	0
781823	779652	21049H	PARTICIPANT	\N	PRESENT	0
781824	779652	14169X	PARTICIPANT	\N	PRESENT	0
781825	779652	20046A	PARTICIPANT	\N	PRESENT	0
781826	779652	19687N	PARTICIPANT	\N	PRESENT	0
781827	779652	11043H	PARTICIPANT	\N	PRESENT	0
781828	779652	08028W	PARTICIPANT	\N	PRESENT	0
781830	779652	21071F	PARTICIPANT	\N	PRESENT	0
781831	779652	21035B	PARTICIPANT	\N	PRESENT	0
781832	779652	14191V	PARTICIPANT	\N	PRESENT	0
781833	779652	20080C	PARTICIPANT	\N	PRESENT	0
788079	788078	14030Q	PARTICIPANT	\N	PRESENT	0
788080	788078	21046E	PARTICIPANT	\N	PRESENT	0
788081	788078	04042C	PARTICIPANT	\N	PRESENT	0
788082	788078	19545Y	PARTICIPANT	\N	PRESENT	0
788083	788078	14357A	PARTICIPANT	\N	PRESENT	0
788084	788078	20248J	PARTICIPANT	\N	PRESENT	0
788085	788078	19647E	PARTICIPANT	\N	PRESENT	0
788086	788078	14026U	PARTICIPANT	\N	PRESENT	0
788087	788078	11048N	PARTICIPANT	\N	PRESENT	0
788088	788078	14097Y	PARTICIPANT	\N	PRESENT	0
791669	791667	20064C	PARTICIPANT	\N	PRESENT	0
788090	788078	08034U	PARTICIPANT	\N	PRESENT	0
788091	788078	21087P	PARTICIPANT	\N	PRESENT	0
788092	788078	21058J	PARTICIPANT	\N	PRESENT	0
788093	788078	14147R	PARTICIPANT	\N	PRESENT	0
788094	788078	14223L	PARTICIPANT	\N	PRESENT	0
788095	788078	21070E	PARTICIPANT	\N	PRESENT	0
788096	788078	20064C	PARTICIPANT	\N	PRESENT	0
788097	788078	21082J	PARTICIPANT	\N	PRESENT	0
791668	791667	14147R	PARTICIPANT	\N	PRESENT	0
791670	791667	21082J	PARTICIPANT	\N	PRESENT	0
791672	791671	14030Q	PARTICIPANT	\N	PRESENT	0
791673	791671	20094J	PARTICIPANT	\N	PRESENT	0
791674	791671	14069U	PARTICIPANT	\N	PRESENT	0
791675	791671	20114U	PARTICIPANT	\N	PRESENT	0
791676	791671	17737W	PARTICIPANT	\N	PRESENT	0
791677	791671	14255U	PARTICIPANT	\N	PRESENT	0
791678	791671	20264J	PARTICIPANT	\N	PRESENT	0
791679	791671	17023S	PARTICIPANT	\N	PRESENT	0
791680	791671	19565D	PARTICIPANT	\N	PRESENT	0
791681	791671	20056C	PARTICIPANT	\N	PRESENT	0
791682	791671	19611R	PARTICIPANT	\N	PRESENT	0
791683	791671	08015R	PARTICIPANT	\N	PRESENT	0
791684	791671	20052X	PARTICIPANT	\N	PRESENT	0
791685	791671	04070G	PARTICIPANT	\N	PRESENT	0
791686	791671	19421M	PARTICIPANT	\N	PRESENT	0
792709	791846	19798U	PARTICIPANT	\N	PRESENT	0
792710	791846	20054A	PARTICIPANT	\N	PRESENT	0
792711	791846	21036C	PARTICIPANT	\N	PRESENT	0
792712	791846	19657G	PARTICIPANT	\N	PRESENT	0
792713	791846	20098N	PARTICIPANT	\N	PRESENT	0
792714	791846	20026V	PARTICIPANT	\N	PRESENT	0
792715	791846	20062A	PARTICIPANT	\N	PRESENT	0
792716	791846	20058E	PARTICIPANT	\N	PRESENT	0
792717	791846	14059S	PARTICIPANT	\N	PRESENT	0
792718	791846	20126Y	PARTICIPANT	\N	PRESENT	0
792720	791846	20056C	PARTICIPANT	\N	PRESENT	0
792721	791846	19447X	PARTICIPANT	\N	PRESENT	0
792723	791846	11065P	PARTICIPANT	\N	PRESENT	0
792724	791846	20142Y	PARTICIPANT	\N	PRESENT	0
792728	791846	98022P	PARTICIPANT	\N	PRESENT	0
792729	791846	14038Y	PARTICIPANT	\N	PRESENT	0
792730	791846	20034V	PARTICIPANT	\N	PRESENT	0
792731	791846	11074Q	PARTICIPANT	\N	PRESENT	0
792732	791846	19575F	PARTICIPANT	\N	PRESENT	0
792733	791846	19489J	PARTICIPANT	\N	PRESENT	0
792734	791846	21094N	PARTICIPANT	\N	PRESENT	0
792735	791846	19713W	PARTICIPANT	\N	PRESENT	0
792736	791846	19621T	PARTICIPANT	\N	PRESENT	0
792737	791846	19826F	PARTICIPANT	\N	PRESENT	0
792741	791846	17023S	PARTICIPANT	\N	PRESENT	0
792739	791846	21049H	PARTICIPANT	\N	PRESENT	0
792740	791846	21030V	PARTICIPANT	\N	PRESENT	0
792742	791846	21033Y	PARTICIPANT	\N	PRESENT	0
792743	791846	20112S	PARTICIPANT	\N	PRESENT	0
792744	791846	14231L	PARTICIPANT	\N	PRESENT	0
792745	791846	19701S	PARTICIPANT	\N	PRESENT	0
792746	791846	19669L	PARTICIPANT	\N	PRESENT	0
792747	791846	20096L	PARTICIPANT	\N	PRESENT	0
792748	791846	20072C	PARTICIPANT	\N	PRESENT	0
792749	791846	19745F	PARTICIPANT	\N	PRESENT	0
792750	791846	19111A	PARTICIPANT	\N	PRESENT	0
792751	791846	21037D	PARTICIPANT	\N	PRESENT	0
792752	791846	21079P	PARTICIPANT	\N	PRESENT	0
792753	791846	14037X	PARTICIPANT	\N	PRESENT	0
792754	791846	20094J	PARTICIPANT	\N	PRESENT	0
792755	791846	19711U	PARTICIPANT	\N	PRESENT	0
792756	791846	19421M	PARTICIPANT	\N	PRESENT	0
792757	791846	19335Q	PARTICIPANT	\N	PRESENT	0
792759	791846	17229F	PARTICIPANT	\N	PRESENT	0
792760	791846	19413M	PARTICIPANT	\N	PRESENT	0
792761	791846	14327T	PARTICIPANT	\N	PRESENT	0
792765	791846	14026U	PARTICIPANT	\N	PRESENT	0
792767	791846	19782L	PARTICIPANT	\N	PRESENT	0
792770	791846	20106U	PARTICIPANT	\N	PRESENT	0
792771	791846	14257W	PARTICIPANT	\N	PRESENT	0
792772	791846	14189C	PARTICIPANT	\N	PRESENT	0
792773	791846	95041E	PARTICIPANT	\N	PRESENT	0
792774	791846	19479G	PARTICIPANT	\N	PRESENT	0
792775	791846	20048C	PARTICIPANT	\N	PRESENT	0
792776	791846	20038A	PARTICIPANT	\N	PRESENT	0
792777	791846	21064G	PARTICIPANT	\N	PRESENT	0
792778	791846	21063F	PARTICIPANT	\N	PRESENT	0
792779	791846	17779H	PARTICIPANT	\N	PRESENT	0
792780	791846	11110B	PARTICIPANT	\N	PRESENT	0
792781	791846	19695N	PARTICIPANT	\N	PRESENT	0
792782	791846	19593H	PARTICIPANT	\N	PRESENT	0
792783	791846	17367Q	PARTICIPANT	\N	PRESENT	0
792784	791846	14055N	PARTICIPANT	\N	PRESENT	0
792785	791846	14249W	PARTICIPANT	\N	PRESENT	0
792786	791846	14237S	PARTICIPANT	\N	PRESENT	0
792787	791846	14229S	PARTICIPANT	\N	PRESENT	0
792788	791846	20066E	PARTICIPANT	\N	PRESENT	0
792789	791846	21093M	PARTICIPANT	\N	PRESENT	0
792790	791846	20128B	PARTICIPANT	\N	PRESENT	0
792791	791846	14042U	PARTICIPANT	\N	PRESENT	0
792792	791846	21083K	PARTICIPANT	\N	PRESENT	0
792793	791846	08011M	PARTICIPANT	\N	PRESENT	0
792794	791846	01034P	PARTICIPANT	\N	PRESENT	0
792795	791846	11027H	PARTICIPANT	\N	PRESENT	0
792796	791846	20286Q	PARTICIPANT	\N	PRESENT	0
792797	791846	20248J	PARTICIPANT	\N	PRESENT	0
792798	791846	17737W	PARTICIPANT	\N	PRESENT	0
792799	791846	19507S	PARTICIPANT	\N	PRESENT	0
792800	791846	21082J	PARTICIPANT	\N	PRESENT	0
793066	791391	14111D	PARTICIPANT	\N	PRESENT	0
793067	791391	01034P	PARTICIPANT	\N	PRESENT	0
793068	791391	14071N	PARTICIPANT	\N	PRESENT	0
793069	791391	19691J	PARTICIPANT	\N	PRESENT	0
793070	791391	19703U	PARTICIPANT	\N	PRESENT	0
793071	791391	19713W	PARTICIPANT	\N	PRESENT	0
793072	791391	20080C	PARTICIPANT	\N	PRESENT	0
793073	791391	21057H	PARTICIPANT	\N	PRESENT	0
793074	791391	21056G	PARTICIPANT	\N	PRESENT	0
793075	791391	19649G	PARTICIPANT	\N	PRESENT	0
793076	791391	14281W	PARTICIPANT	\N	PRESENT	0
793077	791391	08045X	PARTICIPANT	\N	PRESENT	0
793078	791391	20082E	PARTICIPANT	\N	PRESENT	0
793079	791391	17779H	PARTICIPANT	\N	PRESENT	0
793080	791391	18231D	PARTICIPANT	\N	PRESENT	0
793081	791391	20028X	PARTICIPANT	\N	PRESENT	0
793082	791391	14147R	PARTICIPANT	\N	PRESENT	0
793083	791391	20030R	PARTICIPANT	\N	PRESENT	0
793084	791391	20018V	PARTICIPANT	\N	PRESENT	0
793085	791391	19631V	PARTICIPANT	\N	PRESENT	0
793086	791391	19725B	PARTICIPANT	\N	PRESENT	0
793087	791391	19820Y	PARTICIPANT	\N	PRESENT	0
793088	791391	21079P	PARTICIPANT	\N	PRESENT	0
793089	791391	20092G	PARTICIPANT	\N	PRESENT	0
793090	791391	19347U	PARTICIPANT	\N	PRESENT	0
793091	791391	21094N	PARTICIPANT	\N	PRESENT	0
793092	791391	18193Q	PARTICIPANT	\N	PRESENT	0
793093	791391	14195A	PARTICIPANT	\N	PRESENT	0
793094	791391	14107H	PARTICIPANT	\N	PRESENT	0
793095	791391	19866P	PARTICIPANT	\N	PRESENT	0
793096	791391	98022P	PARTICIPANT	\N	PRESENT	0
793097	791391	21097R	PARTICIPANT	\N	PRESENT	0
793098	791391	21064G	PARTICIPANT	\N	PRESENT	0
793099	791391	19479G	PARTICIPANT	\N	PRESENT	0
793100	791391	19111A	PARTICIPANT	\N	PRESENT	0
793101	791391	14042U	PARTICIPANT	\N	PRESENT	0
793102	791391	14205J	PARTICIPANT	\N	PRESENT	0
793103	791391	20066E	PARTICIPANT	\N	PRESENT	0
793104	791391	19745F	PARTICIPANT	\N	PRESENT	0
793105	791391	19798U	PARTICIPANT	\N	PRESENT	0
793106	791391	21074J	PARTICIPANT	\N	PRESENT	0
793107	791391	14055N	PARTICIPANT	\N	PRESENT	0
793108	791391	20124W	PARTICIPANT	\N	PRESENT	0
793109	791391	14059S	PARTICIPANT	\N	PRESENT	0
793110	791391	19383Y	PARTICIPANT	\N	PRESENT	0
793111	791391	20090E	PARTICIPANT	\N	PRESENT	0
787490	787487	20076G	PARTICIPANT	\N	PRESENT	0
787491	787487	21084L	PARTICIPANT	\N	PRESENT	0
787492	787487	21052C	PARTICIPANT	\N	PRESENT	0
787493	787487	14033T	PARTICIPANT	\N	PRESENT	0
787494	787487	19723Y	PARTICIPANT	\N	PRESENT	0
787495	787487	14205J	PARTICIPANT	\N	PRESENT	0
787496	787487	20028X	PARTICIPANT	\N	PRESENT	0
787497	787487	20082E	PARTICIPANT	\N	PRESENT	0
787498	787487	20092G	PARTICIPANT	\N	PRESENT	0
787499	787487	04045F	PARTICIPANT	\N	PRESENT	0
790431	789266	18083K	PARTICIPANT	\N	PRESENT	0
790432	789266	99004R	PARTICIPANT	\N	PRESENT	0
790433	789266	21069M	PARTICIPANT	\N	PRESENT	0
790434	789266	19367Y	PARTICIPANT	\N	PRESENT	0
790435	789266	21091K	PARTICIPANT	\N	PRESENT	0
790436	789266	20076G	PARTICIPANT	\N	PRESENT	0
790437	789266	20074E	PARTICIPANT	\N	PRESENT	0
790438	789266	20116W	PARTICIPANT	\N	PRESENT	0
790439	789266	21044C	PARTICIPANT	\N	PRESENT	0
790440	789266	08069G	PARTICIPANT	\N	PRESENT	0
790441	789266	14223L	PARTICIPANT	\N	PRESENT	0
790442	789266	10015M	PARTICIPANT	\N	PRESENT	0
790443	789266	04042C	PARTICIPANT	\N	PRESENT	0
790444	789266	14169X	PARTICIPANT	\N	PRESENT	0
790445	789266	20132W	PARTICIPANT	\N	PRESENT	0
790446	789266	14026U	PARTICIPANT	\N	PRESENT	0
790447	789266	20072C	PARTICIPANT	\N	PRESENT	0
790448	789266	14107H	PARTICIPANT	\N	PRESENT	0
790449	789266	21072G	PARTICIPANT	\N	PRESENT	0
790450	789266	21071F	PARTICIPANT	\N	PRESENT	0
790451	789266	14191V	PARTICIPANT	\N	PRESENT	0
790452	789266	20044X	PARTICIPANT	\N	PRESENT	0
790453	789266	21046E	PARTICIPANT	\N	PRESENT	0
790454	789266	05012A	PARTICIPANT	\N	PRESENT	0
790455	789266	21065H	PARTICIPANT	\N	PRESENT	0
790456	789266	19693L	PARTICIPANT	\N	PRESENT	0
790457	789266	19553Y	PARTICIPANT	\N	PRESENT	0
790458	789266	19673G	PARTICIPANT	\N	PRESENT	0
790459	789266	21054E	PARTICIPANT	\N	PRESENT	0
790460	789266	21029D	PARTICIPANT	\N	PRESENT	0
790461	789266	14251Q	PARTICIPANT	\N	PRESENT	0
790462	789266	19667J	PARTICIPANT	\N	PRESENT	0
790463	789266	19421M	PARTICIPANT	\N	PRESENT	0
790464	789266	21076L	PARTICIPANT	\N	PRESENT	0
790465	789266	11090Q	PARTICIPANT	\N	PRESENT	0
790466	789266	20136B	PARTICIPANT	\N	PRESENT	0
790467	789266	14331P	PARTICIPANT	\N	PRESENT	0
790468	789266	14253S	PARTICIPANT	\N	PRESENT	0
790469	789266	11065P	PARTICIPANT	\N	PRESENT	0
790470	789266	20134Y	PARTICIPANT	\N	PRESENT	0
790471	789266	21068L	PARTICIPANT	\N	PRESENT	0
790472	789266	19347U	PARTICIPANT	\N	PRESENT	0
790473	789266	19447X	PARTICIPANT	\N	PRESENT	0
790474	789266	21058J	PARTICIPANT	\N	PRESENT	0
790475	789266	21093M	PARTICIPANT	\N	PRESENT	0
790476	789266	20180F	PARTICIPANT	\N	PRESENT	0
790477	789266	19954N	PARTICIPANT	\N	PRESENT	0
790478	789266	21073H	PARTICIPANT	\N	PRESENT	0
790479	789266	20096L	PARTICIPANT	\N	PRESENT	0
790480	789266	14215L	PARTICIPANT	\N	PRESENT	0
790481	789266	20130U	PARTICIPANT	\N	PRESENT	0
790482	789266	21081H	PARTICIPANT	\N	PRESENT	0
790483	789266	21079P	PARTICIPANT	\N	PRESENT	0
790484	789266	21094N	PARTICIPANT	\N	PRESENT	0
790485	789266	20026V	PARTICIPANT	\N	PRESENT	0
790486	789266	08047A	PARTICIPANT	\N	PRESENT	0
790487	789266	19760E	PARTICIPANT	\N	PRESENT	0
790488	789266	21088Q	PARTICIPANT	\N	PRESENT	0
790489	789266	19758L	PARTICIPANT	\N	PRESENT	0
790490	789266	11040E	PARTICIPANT	\N	PRESENT	0
790491	789266	20138D	PARTICIPANT	\N	PRESENT	0
790492	789266	21049H	PARTICIPANT	\N	PRESENT	0
790493	789266	11056N	PARTICIPANT	\N	PRESENT	0
790494	789266	14147R	PARTICIPANT	\N	PRESENT	0
790495	789266	19565D	PARTICIPANT	\N	PRESENT	0
790496	789266	20172F	PARTICIPANT	\N	PRESENT	0
790497	789266	21030V	PARTICIPANT	\N	PRESENT	0
790498	789266	19593H	PARTICIPANT	\N	PRESENT	0
790499	789266	21075K	PARTICIPANT	\N	PRESENT	0
790500	789266	20102Q	PARTICIPANT	\N	PRESENT	0
790501	789266	17737W	PARTICIPANT	\N	PRESENT	0
790502	789266	20034V	PARTICIPANT	\N	PRESENT	0
790503	789266	14038Y	PARTICIPANT	\N	PRESENT	0
790504	789266	21039F	PARTICIPANT	\N	PRESENT	0
790505	789266	20140W	PARTICIPANT	\N	PRESENT	0
790506	789266	20038A	PARTICIPANT	\N	PRESENT	0
790507	789266	14033T	PARTICIPANT	\N	PRESENT	0
790508	789266	20056C	PARTICIPANT	\N	PRESENT	0
790509	789266	14037X	PARTICIPANT	\N	PRESENT	0
790510	789266	19399H	PARTICIPANT	\N	PRESENT	0
790511	789266	19687N	PARTICIPANT	\N	PRESENT	0
790512	789266	20024T	PARTICIPANT	\N	PRESENT	0
790513	789266	14213J	PARTICIPANT	\N	PRESENT	0
790514	789266	19331L	PARTICIPANT	\N	PRESENT	0
790515	789266	20150Y	PARTICIPANT	\N	PRESENT	0
790516	789266	21092L	PARTICIPANT	\N	PRESENT	0
790517	789266	21037D	PARTICIPANT	\N	PRESENT	0
790518	789266	08011M	PARTICIPANT	\N	PRESENT	0
790519	789266	19768N	PARTICIPANT	\N	PRESENT	0
790520	789266	08015R	PARTICIPANT	\N	PRESENT	0
790521	789266	21074J	PARTICIPANT	\N	PRESENT	0
790522	789266	07029T	PARTICIPANT	\N	PRESENT	0
790523	789266	20068G	PARTICIPANT	\N	PRESENT	0
790524	789266	21063F	PARTICIPANT	\N	PRESENT	0
790525	789266	19709B	PARTICIPANT	\N	PRESENT	0
790526	789266	20094J	PARTICIPANT	\N	PRESENT	0
790527	789266	20088L	PARTICIPANT	\N	PRESENT	0
790528	789266	19703U	PARTICIPANT	\N	PRESENT	0
790529	789266	08010L	PARTICIPANT	\N	PRESENT	0
790530	789266	04047H	PARTICIPANT	\N	PRESENT	0
790531	789266	20114U	PARTICIPANT	\N	PRESENT	0
790532	789266	08034U	PARTICIPANT	\N	PRESENT	0
790533	789266	04033B	PARTICIPANT	\N	PRESENT	0
790534	789266	20080C	PARTICIPANT	\N	PRESENT	0
790535	789266	21089R	PARTICIPANT	\N	PRESENT	0
790536	789266	21045D	PARTICIPANT	\N	PRESENT	0
790537	789266	19679N	PARTICIPANT	\N	PRESENT	0
790538	789266	20062A	PARTICIPANT	\N	PRESENT	0
790539	789266	20060X	PARTICIPANT	\N	PRESENT	0
790540	789266	14053L	PARTICIPANT	\N	PRESENT	0
790541	789266	19295A	PARTICIPANT	\N	PRESENT	0
790542	789266	11027H	PARTICIPANT	\N	PRESENT	0
790543	789266	20070A	PARTICIPANT	\N	PRESENT	0
790544	789266	18395Y	PARTICIPANT	\N	PRESENT	0
790545	789266	21067K	PARTICIPANT	\N	PRESENT	0
790546	789266	14071N	PARTICIPANT	\N	PRESENT	0
790547	789266	19251M	PARTICIPANT	\N	PRESENT	0
790548	789266	14187A	PARTICIPANT	\N	PRESENT	0
790549	789266	11074Q	PARTICIPANT	\N	PRESENT	0
790550	789266	21062E	PARTICIPANT	\N	PRESENT	0
790551	789266	19647E	PARTICIPANT	\N	PRESENT	0
790552	789266	14281W	PARTICIPANT	\N	PRESENT	0
790553	789266	20090E	PARTICIPANT	\N	PRESENT	0
790554	789266	19533U	PARTICIPANT	\N	PRESENT	0
790555	789266	19820Y	PARTICIPANT	\N	PRESENT	0
790556	789266	19798U	PARTICIPANT	\N	PRESENT	0
790557	789266	19725B	PARTICIPANT	\N	PRESENT	0
790558	789266	14121F	PARTICIPANT	\N	PRESENT	0
790559	789266	14021P	PARTICIPANT	\N	PRESENT	0
790560	789266	21095P	PARTICIPANT	\N	PRESENT	0
790561	789266	19531S	PARTICIPANT	\N	PRESENT	0
790562	789266	20022R	PARTICIPANT	\N	PRESENT	0
790563	789266	19489J	PARTICIPANT	\N	PRESENT	0
790564	789266	19723Y	PARTICIPANT	\N	PRESENT	0
790565	789266	14069U	PARTICIPANT	\N	PRESENT	0
790566	789266	21041Y	PARTICIPANT	\N	PRESENT	0
790567	789266	18193Q	PARTICIPANT	\N	PRESENT	0
790568	789266	19507S	PARTICIPANT	\N	PRESENT	0
790569	789266	07033P	PARTICIPANT	\N	PRESENT	0
790570	789266	21090J	PARTICIPANT	\N	PRESENT	0
790571	789266	08012N	PARTICIPANT	\N	PRESENT	0
790572	789266	20120S	PARTICIPANT	\N	PRESENT	0
790573	789266	14217N	PARTICIPANT	\N	PRESENT	0
790574	789266	14109K	PARTICIPANT	\N	PRESENT	0
790575	789266	14257W	PARTICIPANT	\N	PRESENT	0
790576	789266	14357A	PARTICIPANT	\N	PRESENT	0
790577	789266	18231D	PARTICIPANT	\N	PRESENT	0
790578	789266	14329V	PARTICIPANT	\N	PRESENT	0
790580	789266	19383Y	PARTICIPANT	\N	PRESENT	0
790581	789266	20030R	PARTICIPANT	\N	PRESENT	0
769190	765411	14229S	PARTICIPANT	\N	PRESENT	0
769191	765411	14195A	PARTICIPANT	\N	PRESENT	0
769192	765411	19798U	PARTICIPANT	\N	PRESENT	0
769193	765411	19711U	PARTICIPANT	\N	PRESENT	0
769194	765411	20090E	PARTICIPANT	\N	PRESENT	0
769195	765411	21094N	PARTICIPANT	\N	PRESENT	0
769196	765411	20130U	PARTICIPANT	\N	PRESENT	0
769197	765411	19301E	PARTICIPANT	\N	PRESENT	0
769198	765411	18193Q	PARTICIPANT	\N	PRESENT	0
769199	765411	21045D	PARTICIPANT	\N	PRESENT	0
769200	765411	19758L	PARTICIPANT	\N	PRESENT	0
769201	765411	19693L	PARTICIPANT	\N	PRESENT	0
769202	765411	14071N	PARTICIPANT	\N	PRESENT	0
769203	765411	14213J	PARTICIPANT	\N	PRESENT	0
769204	765411	20062A	PARTICIPANT	\N	PRESENT	0
769205	765411	19687N	PARTICIPANT	\N	PRESENT	0
769206	765411	19553Y	PARTICIPANT	\N	PRESENT	0
769207	765411	14042U	PARTICIPANT	\N	PRESENT	0
769208	765411	14217N	PARTICIPANT	\N	PRESENT	0
769209	765411	14021P	PARTICIPANT	\N	PRESENT	0
769210	765411	19569H	PARTICIPANT	\N	PRESENT	0
769211	765411	04092N	PARTICIPANT	\N	PRESENT	0
769212	765411	17965H	PARTICIPANT	\N	PRESENT	0
769213	765411	19703U	PARTICIPANT	\N	PRESENT	0
769214	765411	11045K	PARTICIPANT	\N	PRESENT	0
769215	765411	19683J	PARTICIPANT	\N	PRESENT	0
769216	765411	19760E	PARTICIPANT	\N	PRESENT	0
769217	765411	19713W	PARTICIPANT	\N	PRESENT	0
769229	765411	20252E	PARTICIPANT	\N	PRESENT	0
769219	765411	07004J	PARTICIPANT	\N	PRESENT	0
769220	765411	14281W	PARTICIPANT	\N	PRESENT	0
769228	765411	14026U	PARTICIPANT	\N	PRESENT	0
769222	765411	19657G	PARTICIPANT	\N	PRESENT	0
769223	765411	01034P	PARTICIPANT	\N	PRESENT	0
769224	765411	19691J	PARTICIPANT	\N	PRESENT	0
769225	765411	08034U	PARTICIPANT	\N	PRESENT	0
769230	765411	21097R	PARTICIPANT	\N	PRESENT	0
769231	765411	20070A	PARTICIPANT	\N	PRESENT	0
769240	765411	21037D	PARTICIPANT	\N	PRESENT	0
769241	765411	19591F	PARTICIPANT	\N	PRESENT	0
769242	765411	21046E	PARTICIPANT	\N	PRESENT	0
769243	765411	21049H	PARTICIPANT	\N	PRESENT	0
769244	765411	17779H	PARTICIPANT	\N	PRESENT	0
769248	765411	14030Q	PARTICIPANT	\N	PRESENT	0
769257	765411	20148F	PARTICIPANT	\N	PRESENT	0
769261	765411	21087P	PARTICIPANT	\N	PRESENT	0
769269	765411	21095P	PARTICIPANT	\N	PRESENT	0
769306	765412	19758L	PARTICIPANT	\N	PRESENT	0
769307	765412	20090E	PARTICIPANT	\N	PRESENT	0
769308	765412	14071N	PARTICIPANT	\N	PRESENT	0
769309	765412	14042U	PARTICIPANT	\N	PRESENT	0
769310	765412	19683J	PARTICIPANT	\N	PRESENT	0
769311	765412	14281W	PARTICIPANT	\N	PRESENT	0
769312	765412	17779H	PARTICIPANT	\N	PRESENT	0
769313	765412	20130U	PARTICIPANT	\N	PRESENT	0
769319	765412	01034P	PARTICIPANT	\N	PRESENT	0
769315	765412	19798U	PARTICIPANT	\N	PRESENT	0
769316	765412	07004J	PARTICIPANT	\N	PRESENT	0
769317	765412	19691J	PARTICIPANT	\N	PRESENT	0
769318	765412	20148F	PARTICIPANT	\N	PRESENT	0
769320	765412	17965H	PARTICIPANT	\N	PRESENT	0
769321	765412	21037D	PARTICIPANT	\N	PRESENT	0
769322	765412	20062A	PARTICIPANT	\N	PRESENT	0
769323	765412	14217N	PARTICIPANT	\N	PRESENT	0
769324	765412	04092N	PARTICIPANT	\N	PRESENT	0
769325	765412	20034V	PARTICIPANT	\N	PRESENT	0
769326	765412	21091K	PARTICIPANT	\N	PRESENT	0
769327	765412	21087P	PARTICIPANT	\N	PRESENT	0
769328	765412	14026U	PARTICIPANT	\N	PRESENT	0
769329	765412	19760E	PARTICIPANT	\N	PRESENT	0
769330	765412	19693L	PARTICIPANT	\N	PRESENT	0
769331	765412	19687N	PARTICIPANT	\N	PRESENT	0
769332	765412	19657G	PARTICIPANT	\N	PRESENT	0
769333	765412	21097R	PARTICIPANT	\N	PRESENT	0
769334	765412	18193Q	PARTICIPANT	\N	PRESENT	0
769335	765412	21049H	PARTICIPANT	\N	PRESENT	0
769336	765412	19569H	PARTICIPANT	\N	PRESENT	0
769337	765412	21071F	PARTICIPANT	\N	PRESENT	0
769338	765412	14213J	PARTICIPANT	\N	PRESENT	0
769339	765412	19591F	PARTICIPANT	\N	PRESENT	0
769340	765412	21088Q	PARTICIPANT	\N	PRESENT	0
769304	765412	11090Q	PARTICIPANT	\N	PRESENT	0
769305	765412	11045K	PARTICIPANT	\N	PRESENT	0
769341	765412	12016W	PARTICIPANT	\N	PRESENT	0
769342	765412	19301E	PARTICIPANT	\N	PRESENT	0
769343	765412	20252E	PARTICIPANT	\N	PRESENT	0
769344	765412	98022P	PARTICIPANT	\N	PRESENT	0
769345	765412	19713W	PARTICIPANT	\N	PRESENT	0
769346	765412	19553Y	PARTICIPANT	\N	PRESENT	0
769347	765412	19711U	PARTICIPANT	\N	PRESENT	0
769349	765412	14215L	PARTICIPANT	\N	PRESENT	0
769352	765412	21090J	PARTICIPANT	\N	PRESENT	0
769353	765412	21094N	PARTICIPANT	\N	PRESENT	0
769354	765412	14030Q	PARTICIPANT	\N	PRESENT	0
769355	765412	21095P	PARTICIPANT	\N	PRESENT	0
769356	765412	18231D	PARTICIPANT	\N	PRESENT	0
769357	765412	14021P	PARTICIPANT	\N	PRESENT	0
769365	765412	21092L	PARTICIPANT	\N	PRESENT	0
769382	769381	04042C	PARTICIPANT	\N	PRESENT	0
769383	769381	19531S	PARTICIPANT	\N	PRESENT	0
769385	769384	04042C	PARTICIPANT	\N	PRESENT	0
769386	769384	19531S	PARTICIPANT	\N	PRESENT	0
776016	776015	11090Q	PARTICIPANT	\N	PRESENT	0
776017	776015	14042U	PARTICIPANT	\N	PRESENT	0
776018	776015	14026U	PARTICIPANT	\N	PRESENT	0
776019	776015	19683J	PARTICIPANT	\N	PRESENT	0
776020	776015	20102Q	PARTICIPANT	\N	PRESENT	0
776021	776015	19760E	PARTICIPANT	\N	PRESENT	0
776022	776015	21054E	PARTICIPANT	\N	PRESENT	0
776023	776015	19569H	PARTICIPANT	\N	PRESENT	0
776024	776015	20124W	PARTICIPANT	\N	PRESENT	0
776025	776015	19553Y	PARTICIPANT	\N	PRESENT	0
776026	776015	21040X	PARTICIPANT	\N	PRESENT	0
776027	776015	21078N	PARTICIPANT	\N	PRESENT	0
776028	776015	20130U	PARTICIPANT	\N	PRESENT	0
776029	776015	21094N	PARTICIPANT	\N	PRESENT	0
776243	776211	21096Q	PARTICIPANT	\N	PRESENT	0
776244	776211	19693L	PARTICIPANT	\N	PRESENT	0
776245	776211	19697Q	PARTICIPANT	\N	PRESENT	0
776246	776211	20062A	PARTICIPANT	\N	PRESENT	0
776248	776211	20048C	PARTICIPANT	\N	PRESENT	0
776251	776211	21074J	PARTICIPANT	\N	PRESENT	0
776252	776211	20026V	PARTICIPANT	\N	PRESENT	0
776253	776211	11090Q	PARTICIPANT	\N	PRESENT	0
776254	776211	20172F	PARTICIPANT	\N	PRESENT	0
776255	776211	11043H	PARTICIPANT	\N	PRESENT	0
776257	776211	21091K	PARTICIPANT	\N	PRESENT	0
776262	776211	20124W	PARTICIPANT	\N	PRESENT	0
776265	776211	20116W	PARTICIPANT	\N	PRESENT	0
776266	776211	14225N	PARTICIPANT	\N	PRESENT	0
776267	776211	08034U	PARTICIPANT	\N	PRESENT	0
776272	776211	14253S	PARTICIPANT	\N	PRESENT	0
776273	776211	21040X	PARTICIPANT	\N	PRESENT	0
776274	776211	20050V	PARTICIPANT	\N	PRESENT	0
776275	776211	14257W	PARTICIPANT	\N	PRESENT	0
776276	776211	19563B	PARTICIPANT	\N	PRESENT	0
776285	776211	14031R	PARTICIPANT	\N	PRESENT	0
776286	776211	19711U	PARTICIPANT	\N	PRESENT	0
776287	776211	20286Q	PARTICIPANT	\N	PRESENT	0
776288	776211	11048N	PARTICIPANT	\N	PRESENT	0
776292	772606	14229S	PARTICIPANT	\N	PRESENT	0
776294	772606	19593H	PARTICIPANT	\N	PRESENT	0
776295	772606	14329V	PARTICIPANT	\N	PRESENT	0
776296	772606	19573D	PARTICIPANT	\N	PRESENT	0
776297	772606	19611R	PARTICIPANT	\N	PRESENT	0
776299	772606	14030Q	PARTICIPANT	\N	PRESENT	0
776300	772606	19533U	PARTICIPANT	\N	PRESENT	0
776301	772606	14331P	PARTICIPANT	\N	PRESENT	0
776302	772606	21095P	PARTICIPANT	\N	PRESENT	0
776303	772606	19621T	PARTICIPANT	\N	PRESENT	0
776304	772606	21089R	PARTICIPANT	\N	PRESENT	0
776307	772606	21059K	PARTICIPANT	\N	PRESENT	0
776309	772606	21084L	PARTICIPANT	\N	PRESENT	0
776311	772606	20044X	PARTICIPANT	\N	PRESENT	0
776312	772606	21077M	PARTICIPANT	\N	PRESENT	0
781834	779652	20112S	PARTICIPANT	\N	PRESENT	0
781835	779652	21072G	PARTICIPANT	\N	PRESENT	0
781836	779652	20102Q	PARTICIPANT	\N	PRESENT	0
781837	779652	19593H	PARTICIPANT	\N	PRESENT	0
781838	779652	19695N	PARTICIPANT	\N	PRESENT	0
781839	779652	20044X	PARTICIPANT	\N	PRESENT	0
781840	779652	19758L	PARTICIPANT	\N	PRESENT	0
781841	779652	14215L	PARTICIPANT	\N	PRESENT	0
781842	779652	05012A	PARTICIPANT	\N	PRESENT	0
781843	779652	20032T	PARTICIPANT	\N	PRESENT	0
781844	779652	20136B	PARTICIPANT	\N	PRESENT	0
781845	779652	19667J	PARTICIPANT	\N	PRESENT	0
781846	779652	21029D	PARTICIPANT	\N	PRESENT	0
781847	779652	19673G	PARTICIPANT	\N	PRESENT	0
781848	779652	21055F	PARTICIPANT	\N	PRESENT	0
781849	779652	21030V	PARTICIPANT	\N	PRESENT	0
781850	779652	14173T	PARTICIPANT	\N	PRESENT	0
781851	779652	19565D	PARTICIPANT	\N	PRESENT	0
781852	779652	19447X	PARTICIPANT	\N	PRESENT	0
781853	779652	20180F	PARTICIPANT	\N	PRESENT	0
781854	779652	20092G	PARTICIPANT	\N	PRESENT	0
781855	779652	20026V	PARTICIPANT	\N	PRESENT	0
781856	779652	20036X	PARTICIPANT	\N	PRESENT	0
781857	779652	19347U	PARTICIPANT	\N	PRESENT	0
781858	779652	21068L	PARTICIPANT	\N	PRESENT	0
781859	779652	21093M	PARTICIPANT	\N	PRESENT	0
781860	779652	20142Y	PARTICIPANT	\N	PRESENT	0
781861	779652	08047A	PARTICIPANT	\N	PRESENT	0
781862	779652	21037D	PARTICIPANT	\N	PRESENT	0
781863	779652	20138D	PARTICIPANT	\N	PRESENT	0
781864	779652	20134Y	PARTICIPANT	\N	PRESENT	0
781865	779652	20096L	PARTICIPANT	\N	PRESENT	0
781866	779652	20110Q	PARTICIPANT	\N	PRESENT	0
781867	779652	20104S	PARTICIPANT	\N	PRESENT	0
781868	779652	19399H	PARTICIPANT	\N	PRESENT	0
781869	779652	21079P	PARTICIPANT	\N	PRESENT	0
781870	779652	20266L	PARTICIPANT	\N	PRESENT	0
781871	779652	08061X	PARTICIPANT	\N	PRESENT	0
781872	779652	20128B	PARTICIPANT	\N	PRESENT	0
781873	779652	20108W	PARTICIPANT	\N	PRESENT	0
781874	779652	19301E	PARTICIPANT	\N	PRESENT	0
781875	779652	21043B	PARTICIPANT	\N	PRESENT	0
781876	779652	21096Q	PARTICIPANT	\N	PRESENT	0
781877	779652	10015M	PARTICIPANT	\N	PRESENT	0
781878	779652	14147R	PARTICIPANT	\N	PRESENT	0
781879	779652	20056C	PARTICIPANT	\N	PRESENT	0
781880	779652	21092L	PARTICIPANT	\N	PRESENT	0
781881	779652	20038A	PARTICIPANT	\N	PRESENT	0
781882	779652	14249W	PARTICIPANT	\N	PRESENT	0
781883	779652	20140W	PARTICIPANT	\N	PRESENT	0
781884	779652	21039F	PARTICIPANT	\N	PRESENT	0
781885	779652	20106U	PARTICIPANT	\N	PRESENT	0
781886	779652	21047F	PARTICIPANT	\N	PRESENT	0
781887	779652	14038Y	PARTICIPANT	\N	PRESENT	0
781888	779652	19723Y	PARTICIPANT	\N	PRESENT	0
781889	779652	20058E	PARTICIPANT	\N	PRESENT	0
781890	779652	19591F	PARTICIPANT	\N	PRESENT	0
781891	779652	21063F	PARTICIPANT	\N	PRESENT	0
781892	779652	19697Q	PARTICIPANT	\N	PRESENT	0
781893	779652	19349W	PARTICIPANT	\N	PRESENT	0
781894	779652	17367Q	PARTICIPANT	\N	PRESENT	0
781895	779652	21097R	PARTICIPANT	\N	PRESENT	0
781896	779652	14237S	PARTICIPANT	\N	PRESENT	0
781897	779652	19331L	PARTICIPANT	\N	PRESENT	0
781898	779652	08073C	PARTICIPANT	\N	PRESENT	0
781899	779652	08018U	PARTICIPANT	\N	PRESENT	0
782063	779652	07004J	PARTICIPANT	\N	PRESENT	0
782064	779652	19691J	PARTICIPANT	\N	PRESENT	0
782065	779652	19569H	PARTICIPANT	\N	PRESENT	0
782066	779652	20052X	PARTICIPANT	\N	PRESENT	0
782067	779652	14179A	PARTICIPANT	\N	PRESENT	0
782068	779652	19685L	PARTICIPANT	\N	PRESENT	0
782069	779652	20048C	PARTICIPANT	\N	PRESENT	0
782070	779652	20066E	PARTICIPANT	\N	PRESENT	0
782071	779652	14205J	PARTICIPANT	\N	PRESENT	0
782072	779652	19563B	PARTICIPANT	\N	PRESENT	0
782073	779652	19335Q	PARTICIPANT	\N	PRESENT	0
782074	779652	04070G	PARTICIPANT	\N	PRESENT	0
782075	779652	21038E	PARTICIPANT	\N	PRESENT	0
782076	779652	19745F	PARTICIPANT	\N	PRESENT	0
782077	779652	21064G	PARTICIPANT	\N	PRESENT	0
782078	779652	19479G	PARTICIPANT	\N	PRESENT	0
782079	779652	19713W	PARTICIPANT	\N	PRESENT	0
782080	779652	19749K	PARTICIPANT	\N	PRESENT	0
782081	779652	14331P	PARTICIPANT	\N	PRESENT	0
782082	779652	21090J	PARTICIPANT	\N	PRESENT	0
782083	779652	21059K	PARTICIPANT	\N	PRESENT	0
782084	779652	18083K	PARTICIPANT	\N	PRESENT	0
782085	779652	14329V	PARTICIPANT	\N	PRESENT	0
782086	779652	14357A	PARTICIPANT	\N	PRESENT	0
782087	779652	14223L	PARTICIPANT	\N	PRESENT	0
782088	779652	08056B	PARTICIPANT	\N	PRESENT	0
782089	779652	19703U	PARTICIPANT	\N	PRESENT	0
782090	779652	20020P	PARTICIPANT	\N	PRESENT	0
782091	779652	21036C	PARTICIPANT	\N	PRESENT	0
782092	779652	20054A	PARTICIPANT	\N	PRESENT	0
782093	779652	19705W	PARTICIPANT	\N	PRESENT	0
782094	779652	20148F	PARTICIPANT	\N	PRESENT	0
782095	779652	20118Y	PARTICIPANT	\N	PRESENT	0
782096	779652	19533U	PARTICIPANT	\N	PRESENT	0
782097	779652	11115U	PARTICIPANT	\N	PRESENT	0
782098	779652	20124W	PARTICIPANT	\N	PRESENT	0
782099	779652	20034V	PARTICIPANT	\N	PRESENT	0
782100	779652	20068G	PARTICIPANT	\N	PRESENT	0
782101	779652	14213J	PARTICIPANT	\N	PRESENT	0
782102	779652	14059S	PARTICIPANT	\N	PRESENT	0
782464	779653	11090Q	PARTICIPANT	\N	PRESENT	0
782465	779653	08060W	PARTICIPANT	\N	PRESENT	0
782466	779653	19347U	PARTICIPANT	\N	PRESENT	0
782467	779653	20100N	PARTICIPANT	\N	PRESENT	0
782469	779653	21053D	PARTICIPANT	\N	PRESENT	0
782470	779653	20092G	PARTICIPANT	\N	PRESENT	0
782471	779653	19507S	PARTICIPANT	\N	PRESENT	0
782472	779653	21051B	PARTICIPANT	\N	PRESENT	0
782473	779653	21060C	PARTICIPANT	\N	PRESENT	0
782474	779653	14205J	PARTICIPANT	\N	PRESENT	0
782493	779653	21097R	PARTICIPANT	\N	PRESENT	0
782476	779653	21093M	PARTICIPANT	\N	PRESENT	0
782489	779653	21052C	PARTICIPANT	\N	PRESENT	0
782490	779653	21040X	PARTICIPANT	\N	PRESENT	0
782491	779653	14107H	PARTICIPANT	\N	PRESENT	0
782492	779653	21045D	PARTICIPANT	\N	PRESENT	0
782494	777020	20132W	PARTICIPANT	\N	PRESENT	0
782495	777020	19611R	PRESIDENT	0	PRESENT	0
782496	777020	19735D	PARTICIPANT	\N	PRESENT	0
782497	777020	14109K	PARTICIPANT	\N	PRESENT	0
782498	777020	21089R	PARTICIPANT	\N	PRESENT	0
782499	777020	20052X	PARTICIPANT	\N	PRESENT	0
782502	779653	14219Q	PARTICIPANT	\N	PRESENT	0
782503	779653	21084L	PARTICIPANT	\N	PRESENT	0
782504	779653	21092L	PARTICIPANT	\N	PRESENT	0
782505	779653	21079P	PARTICIPANT	\N	PRESENT	0
782506	779653	19387D	PARTICIPANT	\N	PRESENT	0
782507	779653	20046A	PARTICIPANT	\N	PRESENT	0
782508	779653	19782L	PARTICIPANT	\N	PRESENT	0
782509	779653	20142Y	PARTICIPANT	\N	PRESENT	0
782510	779653	21037D	PARTICIPANT	\N	PRESENT	0
782511	779653	21062E	PARTICIPANT	\N	PRESENT	0
782512	779653	19551W	PARTICIPANT	\N	PRESENT	0
782513	779653	21064G	PARTICIPANT	\N	PRESENT	0
782515	779653	21043B	PARTICIPANT	\N	PRESENT	0
782521	779282	14111D	PARTICIPANT	\N	PRESENT	0
782522	779282	19611R	PARTICIPANT	\N	PRESENT	0
782523	779653	20056C	PARTICIPANT	\N	PRESENT	0
782524	779653	20110Q	PARTICIPANT	\N	PRESENT	0
782527	779653	19593H	PARTICIPANT	\N	PRESENT	0
782528	779653	14195A	PARTICIPANT	\N	PRESENT	0
782529	779653	21070E	PARTICIPANT	\N	PRESENT	0
782530	779653	14069U	PARTICIPANT	\N	PRESENT	0
782531	779653	21094N	PARTICIPANT	\N	PRESENT	0
782532	779653	20264J	PARTICIPANT	\N	PRESENT	0
782533	779653	19758L	PARTICIPANT	\N	PRESENT	0
782534	779653	19629C	PARTICIPANT	\N	PRESENT	0
782535	779653	20134Y	PARTICIPANT	\N	PRESENT	0
782536	779653	20082E	PARTICIPANT	\N	PRESENT	0
782537	779653	14331P	PARTICIPANT	\N	PRESENT	0
768233	768232	14053L	PARTICIPANT	\N	PRESENT	0
768235	768232	19749K	PARTICIPANT	\N	PRESENT	0
771017	768827	20286Q	PARTICIPANT	\N	EXCUSE	0
771018	768827	14033T	PARTICIPANT	\N	EXCUSE	0
771019	768827	20098N	PARTICIPANT	\N	EXCUSE	0
771020	768827	14169X	PARTICIPANT	\N	EXCUSE	0
771021	768827	20106U	PARTICIPANT	\N	EXCUSE	0
771022	768827	08018U	PARTICIPANT	\N	EXCUSE	0
771023	768827	17737W	PARTICIPANT	\N	PRESENT	0
771024	768827	19711U	PARTICIPANT	\N	PRESENT	0
771025	768827	20042V	PARTICIPANT	\N	PRESENT	0
771026	768827	20150Y	PARTICIPANT	\N	PRESENT	0
771027	768827	19701S	PARTICIPANT	\N	PRESENT	0
771028	768827	14331P	PRESIDENT	0	PRESENT	0
771029	768827	14073Q	PARTICIPANT	\N	PRESENT	0
771030	768827	14001X	PARTICIPANT	\N	PRESENT	0
771031	768827	18207D	PARTICIPANT	\N	PRESENT	0
771032	768827	21032X	PARTICIPANT	\N	PRESENT	0
771035	768827	14357A	PARTICIPANT	\N	PRESENT	0
771036	768827	18395Y	PARTICIPANT	\N	PRESENT	0
775641	775639	20180F	PARTICIPANT	\N	PRESENT	0
775644	775639	20084G	PARTICIPANT	\N	PRESENT	0
775645	775639	21086N	PARTICIPANT	\N	PRESENT	0
793112	791391	21055F	PARTICIPANT	\N	PRESENT	0
793113	791391	21063F	PARTICIPANT	\N	PRESENT	0
793114	791391	21039F	PARTICIPANT	\N	PRESENT	0
793115	791391	20140W	PARTICIPANT	\N	PRESENT	0
793116	791391	20026V	PARTICIPANT	\N	PRESENT	0
793117	791391	20180F	PARTICIPANT	\N	PRESENT	0
793118	791391	20136B	PARTICIPANT	\N	PRESENT	0
793119	791391	20120S	PARTICIPANT	\N	PRESENT	0
793120	791391	14031R	PARTICIPANT	\N	PRESENT	0
793121	791391	14237S	PARTICIPANT	\N	PRESENT	0
793122	791391	21081H	PARTICIPANT	\N	PRESENT	0
793123	791391	19954N	PARTICIPANT	\N	PRESENT	0
793124	791391	20148F	PARTICIPANT	\N	PRESENT	0
793125	791391	20098N	PARTICIPANT	\N	PRESENT	0
793126	791391	19367Y	PARTICIPANT	\N	PRESENT	0
793127	791391	20074E	PARTICIPANT	\N	PRESENT	0
793128	791391	05012A	PARTICIPANT	\N	PRESENT	0
793129	791391	14215L	PARTICIPANT	\N	PRESENT	0
793130	791391	20062A	PARTICIPANT	\N	PRESENT	0
793131	791391	04092N	PARTICIPANT	\N	PRESENT	0
793132	791391	04047H	PARTICIPANT	\N	PRESENT	0
793133	791391	19657G	PARTICIPANT	\N	PRESENT	0
793134	791391	21029D	PARTICIPANT	\N	PRESENT	0
793135	791391	21033Y	PARTICIPANT	\N	PRESENT	0
793136	791391	19413M	PARTICIPANT	\N	PRESENT	0
793137	791391	19758L	PARTICIPANT	\N	PRESENT	0
793138	791391	19719D	PARTICIPANT	\N	PRESENT	0
793139	791391	20032T	PARTICIPANT	\N	PRESENT	0
793140	791391	20248J	PARTICIPANT	\N	PRESENT	0
793141	791391	19569H	PARTICIPANT	\N	PRESENT	0
793142	791391	14073Q	PARTICIPANT	\N	PRESENT	0
793143	791391	17965H	PARTICIPANT	\N	PRESENT	0
793144	791391	21040X	PARTICIPANT	\N	PRESENT	0
793145	791391	14030Q	PARTICIPANT	\N	PRESENT	0
793146	791391	14217N	PARTICIPANT	\N	PRESENT	0
793147	791391	20022R	PARTICIPANT	\N	PRESENT	0
793149	791391	21049H	PARTICIPANT	\N	PRESENT	0
793150	791391	19760E	PARTICIPANT	\N	PRESENT	0
793151	791391	21087P	PARTICIPANT	\N	PRESENT	0
793156	791391	21045D	PARTICIPANT	\N	PRESENT	0
793157	791391	20068G	PARTICIPANT	\N	PRESENT	0
793158	791391	19553Y	PARTICIPANT	\N	PRESENT	0
793159	791391	21095P	PARTICIPANT	\N	PRESENT	0
793160	791391	20126Y	PARTICIPANT	\N	PRESENT	0
793161	791391	20056C	PARTICIPANT	\N	PRESENT	0
793162	791391	20024T	PARTICIPANT	\N	PRESENT	0
793163	791391	14069U	PARTICIPANT	\N	PRESENT	0
793167	791391	14213J	PARTICIPANT	\N	PRESENT	0
793168	791391	14026U	PARTICIPANT	\N	PRESENT	0
793169	791391	20048C	PARTICIPANT	\N	PRESENT	0
793170	791391	17229F	PARTICIPANT	\N	PRESENT	0
793608	793607	21082J	PARTICIPANT	\N	PRESENT	0
793609	793607	08060W	PARTICIPANT	\N	PRESENT	0
794013	791620	19758L	PARTICIPANT	\N	PRESENT	0
794014	791620	21046E	PARTICIPANT	\N	PRESENT	0
794015	791620	19760E	PARTICIPANT	\N	PRESENT	0
794016	791620	19553Y	PARTICIPANT	\N	PRESENT	0
794017	791620	19713W	PARTICIPANT	\N	PRESENT	0
794018	791620	20090E	PARTICIPANT	\N	PRESENT	0
794019	791620	19703U	PARTICIPANT	\N	PRESENT	0
794020	791620	21081H	PARTICIPANT	\N	PRESENT	0
794021	791620	21097R	PARTICIPANT	\N	PRESENT	0
794022	791620	14217N	PARTICIPANT	\N	PRESENT	0
794023	791620	19679N	PARTICIPANT	\N	PRESENT	0
794024	791620	19798U	PARTICIPANT	\N	PRESENT	0
794025	791620	14042U	PARTICIPANT	\N	PRESENT	0
794026	791620	20148F	PARTICIPANT	\N	PRESENT	0
794027	791620	20096L	PARTICIPANT	\N	PRESENT	0
794028	791620	19691J	PARTICIPANT	\N	PRESENT	0
794029	791620	20140W	PARTICIPANT	\N	PRESENT	0
794030	791620	21094N	PARTICIPANT	\N	PRESENT	0
794031	791620	11045K	PARTICIPANT	\N	PRESENT	0
794032	791620	19866P	PARTICIPANT	\N	PRESENT	0
794033	791620	18193Q	PARTICIPANT	\N	PRESENT	0
794034	791620	21049H	PARTICIPANT	\N	PRESENT	0
794035	791620	14071N	PRESIDENT	\N	PRESENT	0
794036	791620	08045X	PARTICIPANT	\N	PRESENT	0
794037	791620	14195A	PARTICIPANT	\N	PRESENT	0
794038	791620	21045D	PARTICIPANT	\N	PRESENT	0
794039	791620	19367Y	PARTICIPANT	\N	PRESENT	0
794040	791620	14026U	PARTICIPANT	\N	PRESENT	0
794041	791620	19629C	PARTICIPANT	\N	PRESENT	0
794042	791620	14355X	PARTICIPANT	\N	EXCUSE	0
794043	791620	21087P	PARTICIPANT	\N	PRESENT	0
794044	791620	19683J	PARTICIPANT	\N	PRESENT	0
794045	791620	20248J	PARTICIPANT	\N	PRESENT	0
794046	791620	20130U	PARTICIPANT	\N	EXCUSE	0
794047	791620	19657G	PARTICIPANT	\N	PRESENT	0
794048	791620	21039F	PARTICIPANT	\N	PRESENT	0
794049	791620	14213J	PARTICIPANT	\N	PRESENT	0
794050	791620	19723Y	PARTICIPANT	\N	PRESENT	0
794051	791620	21064G	PARTICIPANT	\N	PRESENT	0
794052	791620	19569H	PARTICIPANT	\N	PRESENT	0
794053	791620	19591F	PARTICIPANT	\N	PRESENT	0
794054	791620	08061X	PARTICIPANT	\N	PRESENT	0
794055	791620	14281W	PARTICIPANT	\N	PRESENT	0
794056	791620	17965H	PARTICIPANT	\N	PRESENT	0
794060	791690	19729F	PARTICIPANT	\N	EXCUSE	0
794441	794440	19631V	PARTICIPANT	\N	PRESENT	0
794442	794440	20114U	PARTICIPANT	\N	PRESENT	0
794443	794440	14255U	PARTICIPANT	\N	PRESENT	0
794444	794440	19701S	PARTICIPANT	\N	PRESENT	0
794445	794440	21067K	PARTICIPANT	\N	PRESENT	0
794446	794440	21091K	PARTICIPANT	\N	PRESENT	0
794447	794440	19565D	PARTICIPANT	\N	PRESENT	0
794448	794440	14179A	PARTICIPANT	\N	PRESENT	0
794449	794440	21078N	PARTICIPANT	\N	PRESENT	0
794450	794440	21073H	PARTICIPANT	\N	PRESENT	0
794451	794440	20062A	PARTICIPANT	\N	PRESENT	0
794452	794440	19669L	PARTICIPANT	\N	PRESENT	0
794453	794440	19413M	PARTICIPANT	\N	PRESENT	0
794454	794440	21077M	PARTICIPANT	\N	PRESENT	0
794456	794455	14071N	PARTICIPANT	\N	PRESENT	0
794457	794455	14187A	PARTICIPANT	\N	PRESENT	0
794458	794455	19826F	PARTICIPANT	\N	PRESENT	0
794459	794455	19575F	PARTICIPANT	\N	PRESENT	0
794460	794455	20038A	PARTICIPANT	\N	PRESENT	0
794461	794455	19798U	PARTICIPANT	\N	PRESENT	0
794528	793691	19703U	PARTICIPANT	\N	EXCUSE	0
794560	794010	08047A	PARTICIPANT	\N	PRESENT	0
794550	789515	21067K	PARTICIPANT	\N	PRESENT	0
794558	794010	14179A	PARTICIPANT	\N	PRESENT	0
794562	794010	20128B	PARTICIPANT	\N	PRESENT	0
794577	794012	14179A	PARTICIPANT	\N	PRESENT	0
794583	794580	08047A	PARTICIPANT	\N	PRESENT	0
794579	794012	08047A	PARTICIPANT	\N	PRESENT	0
794581	794580	20128B	PARTICIPANT	\N	PRESENT	0
794582	794580	14179A	PARTICIPANT	\N	PRESENT	0
794585	794584	20128B	PARTICIPANT	\N	PRESENT	0
794586	794584	14179A	PARTICIPANT	\N	PRESENT	0
794587	794584	08047A	PARTICIPANT	\N	PRESENT	0
794589	794000	19669L	PARTICIPANT	\N	PRESENT	0
794590	794000	08047A	PARTICIPANT	\N	PRESENT	0
794593	794592	08034U	PARTICIPANT	\N	PRESENT	0
794594	794592	99004R	PARTICIPANT	\N	PRESENT	0
794595	794592	19711U	PARTICIPANT	\N	PRESENT	0
794596	794592	20080C	PARTICIPANT	\N	PRESENT	0
794597	794592	21086N	PARTICIPANT	\N	PRESENT	0
782596	782595	19673G	PARTICIPANT	\N	PRESENT	0
782597	782595	20054A	PARTICIPANT	\N	PRESENT	0
782598	782595	14147R	PARTICIPANT	\N	PRESENT	0
782599	782595	20056C	PARTICIPANT	\N	PRESENT	0
784039	784038	07033P	PARTICIPANT	\N	PRESENT	0
784040	784038	20120S	PARTICIPANT	\N	PRESENT	0
784041	784038	19569H	PARTICIPANT	\N	PRESENT	0
784042	784038	14179A	PARTICIPANT	\N	PRESENT	0
784043	784038	19551W	PARTICIPANT	\N	PRESENT	0
784044	784038	14205J	PARTICIPANT	\N	PRESENT	0
784045	784038	14059S	PARTICIPANT	\N	PRESENT	0
784046	784038	14147R	PARTICIPANT	\N	PRESENT	0
784047	784038	21053D	PARTICIPANT	\N	PRESENT	0
784048	784038	21059K	PARTICIPANT	\N	PRESENT	0
784049	784038	21061D	PARTICIPANT	\N	PRESENT	0
784519	784494	14281W	PARTICIPANT	\N	PRESENT	0
784520	784494	19691J	PARTICIPANT	\N	PRESENT	0
784521	784494	14223L	PARTICIPANT	\N	PRESENT	0
784522	784494	20130U	PARTICIPANT	\N	PRESENT	0
784523	784494	19703U	PARTICIPANT	\N	PRESENT	0
784525	784504	19691J	PARTICIPANT	\N	PRESENT	0
784526	784504	14223L	PARTICIPANT	\N	PRESENT	0
784527	784504	14071N	PARTICIPANT	\N	PRESENT	0
784528	784504	20130U	PARTICIPANT	\N	PRESENT	0
784529	784504	19703U	PARTICIPANT	\N	PRESENT	0
784532	784512	19691J	PARTICIPANT	\N	PRESENT	0
784533	784512	20130U	PARTICIPANT	\N	PRESENT	0
784534	784512	19703U	PARTICIPANT	\N	PRESENT	0
784537	784517	19691J	PARTICIPANT	\N	PRESENT	0
784538	784517	14213J	PARTICIPANT	\N	PRESENT	0
784539	784517	19703U	PARTICIPANT	\N	PRESENT	0
787506	787120	19413M	PARTICIPANT	\N	PRESENT	0
787507	787120	20082E	PARTICIPANT	\N	PRESENT	0
790582	789266	17965H	PARTICIPANT	\N	PRESENT	0
790583	789266	14225N	PARTICIPANT	\N	PRESENT	0
790584	789266	20020P	PARTICIPANT	\N	PRESENT	0
790585	789266	20098N	PARTICIPANT	\N	PRESENT	0
790586	789266	14229S	PARTICIPANT	\N	PRESENT	0
790587	789266	14193X	PARTICIPANT	\N	PRESENT	0
790588	789266	21056G	PARTICIPANT	\N	PRESENT	0
790589	789266	20054A	PARTICIPANT	\N	PRESENT	0
790590	789266	11045K	PARTICIPANT	\N	PRESENT	0
790591	789266	20126Y	PARTICIPANT	\N	PRESENT	0
790592	789266	20086J	PARTICIPANT	\N	PRESENT	0
790593	789266	19669L	PARTICIPANT	\N	PRESENT	0
790594	789266	21051B	PARTICIPANT	\N	PRESENT	0
790595	789266	21082J	PARTICIPANT	\N	PRESENT	0
790596	789266	20286Q	PARTICIPANT	\N	PRESENT	0
790597	789266	21042A	PARTICIPANT	\N	PRESENT	0
790598	789266	14231L	PARTICIPANT	\N	PRESENT	0
790599	789266	14327T	PARTICIPANT	\N	PRESENT	0
790600	789266	17229F	PARTICIPANT	\N	PRESENT	0
790618	789266	14219Q	PARTICIPANT	\N	PRESENT	0
790602	789266	14255U	PARTICIPANT	\N	PRESENT	0
790603	789266	14179A	PARTICIPANT	\N	PRESENT	0
790604	789266	14083S	PARTICIPANT	\N	PRESENT	0
790605	789266	19745F	PARTICIPANT	\N	PRESENT	0
790606	789266	11053K	PARTICIPANT	\N	PRESENT	0
790607	789266	21064G	PARTICIPANT	\N	PRESENT	0
790608	789266	11085T	PARTICIPANT	\N	PRESENT	0
790609	789266	20040T	PARTICIPANT	\N	PRESENT	0
790613	789266	20066E	PARTICIPANT	\N	PRESENT	0
790611	789266	19749K	PARTICIPANT	\N	PRESENT	0
790612	789266	20048C	PARTICIPANT	\N	PRESENT	0
790614	789266	19735D	PARTICIPANT	\N	PRESENT	0
790621	789266	19699S	PARTICIPANT	\N	PRESENT	0
790616	789266	14089Y	PARTICIPANT	\N	PRESENT	0
790617	789266	14205J	PARTICIPANT	\N	PRESENT	0
790619	789266	08009T	PARTICIPANT	\N	PRESENT	0
790627	789266	19335Q	PARTICIPANT	\N	PRESENT	0
790628	789266	08056B	PARTICIPANT	\N	PRESENT	0
790624	789266	17023S	PARTICIPANT	\N	PRESENT	0
790626	789266	05008E	PARTICIPANT	\N	PRESENT	0
790629	789266	86034E	PARTICIPANT	\N	PRESENT	0
790630	789266	01034P	PARTICIPANT	\N	PRESENT	0
790631	789266	20118Y	PARTICIPANT	\N	PRESENT	0
790632	789266	21060C	PARTICIPANT	\N	PRESENT	0
790633	789266	07004J	PARTICIPANT	\N	PRESENT	0
790634	789266	18207D	PARTICIPANT	\N	PRESENT	0
790635	789266	21038E	PARTICIPANT	\N	PRESENT	0
790636	789266	19545Y	PARTICIPANT	\N	PRESENT	0
790640	789266	17367Q	PARTICIPANT	\N	PRESENT	0
790655	789266	19057M	PARTICIPANT	\N	PRESENT	0
790660	789266	14151M	PARTICIPANT	\N	PRESENT	0
790661	789266	19631V	PARTICIPANT	\N	PRESENT	0
790662	789266	11070L	PARTICIPANT	\N	PRESENT	0
790668	789266	11115U	PARTICIPANT	\N	PRESENT	0
790669	789266	19551W	PARTICIPANT	\N	PRESENT	0
790675	789266	20050V	PARTICIPANT	\N	PRESENT	0
790676	789266	14059S	PARTICIPANT	\N	PRESENT	0
790677	789266	14259Y	PARTICIPANT	\N	PRESENT	0
790687	789266	20266L	PARTICIPANT	\N	PRESENT	0
790688	789266	19695N	PARTICIPANT	\N	PRESENT	0
790689	789266	14123H	PARTICIPANT	\N	PRESENT	0
790690	789266	20058E	PARTICIPANT	\N	PRESENT	0
790691	789415	14059S	PARTICIPANT	\N	EXCUSE	0
790692	789415	19657G	PARTICIPANT	\N	EXCUSE	0
790693	789415	17229F	PARTICIPANT	\N	EXCUSE	0
790694	789415	08010L	PARTICIPANT	\N	EXCUSE	0
790695	789415	19631V	PARTICIPANT	\N	EXCUSE	0
790696	789415	20150Y	PARTICIPANT	\N	EXCUSE	0
790697	789415	19673G	PARTICIPANT	\N	EXCUSE	0
790698	789415	19745F	PARTICIPANT	\N	EXCUSE	0
790699	789415	21073H	PARTICIPANT	\N	EXCUSE	0
791000	789267	11090Q	PARTICIPANT	\N	PRESENT	0
790997	789267	20116W	PARTICIPANT	\N	PRESENT	0
790998	789267	19711U	PARTICIPANT	\N	PRESENT	0
790999	789267	19349W	PARTICIPANT	\N	PRESENT	0
791001	789267	12016W	PARTICIPANT	\N	PRESENT	0
791002	789267	20022R	PARTICIPANT	\N	PRESENT	0
791003	789267	21069M	PARTICIPANT	\N	PRESENT	0
791004	789267	20050V	PARTICIPANT	\N	PRESENT	0
791005	789267	14083S	PARTICIPANT	\N	PRESENT	0
791006	789267	20134Y	PARTICIPANT	\N	PRESENT	0
791007	789267	19687N	PARTICIPANT	\N	PRESENT	0
791008	789267	14257W	PARTICIPANT	\N	PRESENT	0
791009	789267	20062A	PARTICIPANT	\N	PRESENT	0
791031	789267	20128B	PARTICIPANT	\N	PRESENT	0
791043	789267	14225N	PARTICIPANT	\N	PRESENT	0
791046	789267	21045D	PARTICIPANT	\N	PRESENT	0
791056	789267	14033T	PARTICIPANT	\N	PRESENT	0
791061	789267	19954N	PARTICIPANT	\N	PRESENT	0
791063	789267	20180F	PARTICIPANT	\N	PRESENT	0
791067	789267	14031R	PARTICIPANT	\N	PRESENT	0
791073	789267	21091K	PARTICIPANT	\N	PRESENT	0
791074	789267	14205J	PARTICIPANT	\N	PRESENT	0
791075	789267	11070L	PARTICIPANT	\N	PRESENT	0
791076	789267	21053D	PARTICIPANT	\N	PRESENT	0
791079	789267	21090J	PARTICIPANT	\N	PRESENT	0
791080	789267	21072G	PARTICIPANT	\N	PRESENT	0
791081	789267	14021P	PARTICIPANT	\N	PRESENT	0
791082	789267	20070A	PARTICIPANT	\N	PRESENT	0
791083	789267	21051B	PARTICIPANT	\N	PRESENT	0
791103	789267	14147R	PARTICIPANT	\N	PRESENT	0
791086	789267	19399H	PARTICIPANT	\N	PRESENT	0
791087	789267	18395Y	PARTICIPANT	\N	PRESENT	0
791088	789267	20018V	PARTICIPANT	\N	PRESENT	0
791092	789267	21089R	PARTICIPANT	\N	PRESENT	0
791093	789267	21077M	PARTICIPANT	\N	PRESENT	0
791094	789267	20264J	PARTICIPANT	\N	PRESENT	0
791095	789267	20064C	PARTICIPANT	\N	PRESENT	0
791096	789267	18231D	PARTICIPANT	\N	PRESENT	0
791097	789267	21070E	PARTICIPANT	\N	PRESENT	0
791098	789267	19479G	PARTICIPANT	\N	PRESENT	0
791099	789267	19647E	PARTICIPANT	\N	PRESENT	0
791100	789267	19699S	PARTICIPANT	\N	PRESENT	0
791101	789267	20144B	PARTICIPANT	\N	PRESENT	0
791102	789267	11048N	PARTICIPANT	\N	PRESENT	0
791104	789267	08061X	PARTICIPANT	\N	PRESENT	0
791106	789267	08060W	PARTICIPANT	\N	PRESENT	0
791107	789267	19669L	PARTICIPANT	\N	PRESENT	0
791108	789267	21066J	PARTICIPANT	\N	PRESENT	0
791109	789267	20132W	PARTICIPANT	\N	PRESENT	0
791110	789267	20094J	PARTICIPANT	\N	PRESENT	0
791111	789267	20088L	PARTICIPANT	\N	PRESENT	0
791112	789267	20082E	PARTICIPANT	\N	PRESENT	0
791113	789267	20080C	PARTICIPANT	\N	PRESENT	0
791114	789267	14189C	PARTICIPANT	\N	PRESENT	0
791115	789267	20126Y	PARTICIPANT	\N	PRESENT	0
791116	789267	20090E	PARTICIPANT	\N	PRESENT	0
791117	789267	20044X	PARTICIPANT	\N	PRESENT	0
770555	765403	20042V	PARTICIPANT	\N	PRESENT	0
772505	772197	17737W	PARTICIPANT	\N	EXCUSE	0
772510	772197	12028B	PARTICIPANT	\N	EXCUSE	0
774496	771033	20040T	PARTICIPANT	\N	EXCUSE	0
776313	772606	21096Q	PARTICIPANT	\N	PRESENT	0
776314	772606	19693L	PARTICIPANT	\N	PRESENT	0
776315	772606	19697Q	PARTICIPANT	\N	PRESENT	0
776316	772606	20062A	PARTICIPANT	\N	PRESENT	0
776337	772606	21032X	PARTICIPANT	\N	PRESENT	0
776318	772606	20026V	PARTICIPANT	\N	PRESENT	0
776319	772606	11090Q	PARTICIPANT	\N	PRESENT	0
776320	772606	20172F	PARTICIPANT	\N	PRESENT	0
776338	772606	14031R	PARTICIPANT	\N	PRESENT	0
776339	772606	20142Y	PARTICIPANT	\N	PRESENT	0
776323	772606	20124W	PARTICIPANT	\N	PRESENT	0
776340	772606	21037D	PARTICIPANT	\N	PRESENT	0
776325	772606	14225N	PARTICIPANT	\N	PRESENT	0
776326	772606	08034U	PARTICIPANT	\N	PRESENT	0
776327	772606	14253S	PARTICIPANT	\N	PRESENT	0
776341	772606	20264J	PARTICIPANT	\N	PRESENT	0
776336	772606	20048C	PARTICIPANT	\N	PRESENT	0
776330	772606	14257W	PARTICIPANT	\N	PRESENT	0
776331	772606	19563B	PARTICIPANT	\N	PRESENT	0
776332	772606	19711U	PARTICIPANT	\N	PRESENT	0
776333	772606	20286Q	PARTICIPANT	\N	PRESENT	0
776334	772606	11048N	PARTICIPANT	\N	PRESENT	0
776335	772606	20050V	PARTICIPANT	\N	PRESENT	0
776342	772606	21054E	PARTICIPANT	\N	PRESENT	0
776343	772606	20092G	PARTICIPANT	\N	PRESENT	0
776344	772606	08010L	PARTICIPANT	\N	PRESENT	0
776345	772606	20102Q	PARTICIPANT	\N	PRESENT	0
776346	772606	21071F	PARTICIPANT	\N	PRESENT	0
776347	772606	21074J	PARTICIPANT	\N	PRESENT	0
776348	772606	21062E	PARTICIPANT	\N	PRESENT	0
776349	772606	21076L	PARTICIPANT	\N	PRESENT	0
776350	772606	20100N	PARTICIPANT	\N	PRESENT	0
776351	772606	14249W	PARTICIPANT	\N	PRESENT	0
776352	772606	21073H	PARTICIPANT	\N	PRESENT	0
776353	772606	14109K	PARTICIPANT	\N	PRESENT	0
776354	772606	21069M	PARTICIPANT	\N	PRESENT	0
776355	772606	21070E	PARTICIPANT	\N	PRESENT	0
776356	772606	14187A	PARTICIPANT	\N	PRESENT	0
776357	772606	19631V	PARTICIPANT	\N	PRESENT	0
776358	772606	19331L	PARTICIPANT	\N	PRESENT	0
776359	772606	19667J	PARTICIPANT	\N	PRESENT	0
776360	772606	20086J	PARTICIPANT	\N	PRESENT	0
776361	772606	20094J	PARTICIPANT	\N	PRESENT	0
776362	772606	21091K	PARTICIPANT	\N	PRESENT	0
776363	772606	21093M	PARTICIPANT	\N	PRESENT	0
776364	772606	21048G	PARTICIPANT	\N	PRESENT	0
776365	772606	19713W	PARTICIPANT	\N	PRESENT	0
776366	772606	21083K	PARTICIPANT	\N	PRESENT	0
776382	772606	21040X	PARTICIPANT	\N	PRESENT	0
776383	772606	20060X	PARTICIPANT	\N	PRESENT	0
776384	772606	05012A	PARTICIPANT	\N	PRESENT	0
776385	772606	11065P	PARTICIPANT	\N	PRESENT	0
776386	772606	20116W	PARTICIPANT	\N	PRESENT	0
776387	772606	14327T	PARTICIPANT	\N	PRESENT	0
776388	772606	14169X	PARTICIPANT	\N	PRESENT	0
776389	776212	14229S	PARTICIPANT	\N	PRESENT	0
776390	776212	19593H	PARTICIPANT	\N	PRESENT	0
776391	776212	14329V	PARTICIPANT	\N	PRESENT	0
776445	776212	20116W	PARTICIPANT	\N	PRESENT	0
776446	776212	21075K	PARTICIPANT	\N	PRESENT	0
776440	776212	21062E	PARTICIPANT	\N	PRESENT	0
776447	776212	20120S	PARTICIPANT	\N	PRESENT	0
776448	776212	19647E	PARTICIPANT	\N	PRESENT	0
776397	776212	21089R	PARTICIPANT	\N	PRESENT	0
776441	776212	20122U	PARTICIPANT	\N	PRESENT	0
776399	776212	21084L	PARTICIPANT	\N	PRESENT	0
776400	776212	21096Q	PARTICIPANT	\N	PRESENT	0
776449	776212	20046A	PARTICIPANT	\N	PRESENT	0
776402	776212	20062A	PARTICIPANT	\N	PRESENT	0
776403	776212	20026V	PARTICIPANT	\N	PRESENT	0
776404	776212	11090Q	PARTICIPANT	\N	PRESENT	0
776450	776212	21037D	PARTICIPANT	\N	PRESENT	0
776451	776212	20044X	PARTICIPANT	\N	PRESENT	0
776407	776212	14253S	PARTICIPANT	\N	PRESENT	0
776408	776212	19563B	PARTICIPANT	\N	PRESENT	0
776409	776212	20286Q	PARTICIPANT	\N	PRESENT	0
776442	776212	19479G	PARTICIPANT	\N	PRESENT	0
776443	776212	14327T	PARTICIPANT	\N	PRESENT	0
776412	776212	14031R	PARTICIPANT	\N	PRESENT	0
776452	776212	21040X	PARTICIPANT	\N	PRESENT	0
776444	776212	14225N	PARTICIPANT	\N	PRESENT	0
776453	776212	14069U	PARTICIPANT	\N	PRESENT	0
776454	776212	20124W	PARTICIPANT	\N	PRESENT	0
776417	776212	20102Q	PARTICIPANT	\N	PRESENT	0
776455	776212	21088Q	PARTICIPANT	\N	PRESENT	0
776500	772607	21089R	PARTICIPANT	\N	PRESENT	0
776420	776212	14249W	PARTICIPANT	\N	PRESENT	0
776421	776212	21069M	PARTICIPANT	\N	PRESENT	0
776422	776212	14187A	PARTICIPANT	\N	PRESENT	0
776423	776212	19631V	PARTICIPANT	\N	PRESENT	0
776501	772607	19647E	PARTICIPANT	\N	PRESENT	0
776425	776212	20086J	PARTICIPANT	\N	PRESENT	0
776502	772607	11110B	PARTICIPANT	\N	PRESENT	0
776503	772607	14187A	PARTICIPANT	\N	PRESENT	0
776428	776212	21093M	PARTICIPANT	\N	PRESENT	0
776429	776212	21048G	PARTICIPANT	\N	PRESENT	0
776430	776212	19713W	PARTICIPANT	\N	PRESENT	0
776431	776212	21083K	PARTICIPANT	\N	PRESENT	0
776504	772607	21095P	PARTICIPANT	\N	PRESENT	0
776433	776212	20060X	PARTICIPANT	\N	PRESENT	0
776434	776212	05012A	PARTICIPANT	\N	PRESENT	0
776435	776212	11065P	PARTICIPANT	\N	PRESENT	0
776505	772607	20120S	PARTICIPANT	\N	PRESENT	0
776506	772607	19713W	PARTICIPANT	\N	PRESENT	0
776438	776212	14169X	PARTICIPANT	\N	PRESENT	0
776439	776212	21051B	PARTICIPANT	\N	PRESENT	0
776507	772607	20122U	PARTICIPANT	\N	PRESENT	0
776508	772607	21083K	PARTICIPANT	\N	PRESENT	0
776509	772607	20026V	PARTICIPANT	\N	PRESENT	0
776510	772607	14031R	PARTICIPANT	\N	PRESENT	0
776511	772607	14069U	PARTICIPANT	\N	PRESENT	0
776512	772607	20044X	PARTICIPANT	\N	PRESENT	0
776513	772607	11090Q	PARTICIPANT	\N	PRESENT	0
776514	772607	11048N	PARTICIPANT	\N	PRESENT	0
776515	772607	05012A	PARTICIPANT	\N	PRESENT	0
776516	772607	20062A	PARTICIPANT	\N	PRESENT	0
776517	772607	20124W	PARTICIPANT	\N	PRESENT	0
776518	772607	21051B	PARTICIPANT	\N	PRESENT	0
776519	772607	19631V	PARTICIPANT	\N	PRESENT	0
776520	772607	21084L	PARTICIPANT	\N	PRESENT	0
776521	772607	14327T	PARTICIPANT	\N	PRESENT	0
776522	772607	20086J	PARTICIPANT	\N	PRESENT	0
776523	772607	14329V	PARTICIPANT	\N	PRESENT	0
776524	772607	21075K	PARTICIPANT	\N	PRESENT	0
776525	772607	20060X	PARTICIPANT	\N	PRESENT	0
776526	772607	21040X	PARTICIPANT	\N	PRESENT	0
776527	772607	21054E	PARTICIPANT	\N	PRESENT	0
776528	772607	21062E	PARTICIPANT	\N	PRESENT	0
776529	772607	21090J	PARTICIPANT	\N	PRESENT	0
776530	772607	20130U	PARTICIPANT	\N	PRESENT	0
776531	772607	19563B	PARTICIPANT	\N	PRESENT	0
776532	772607	20286Q	PARTICIPANT	\N	PRESENT	0
776533	772607	21096Q	PARTICIPANT	\N	PRESENT	0
776534	772607	20046A	PARTICIPANT	\N	PRESENT	0
776535	772607	11065P	PARTICIPANT	\N	PRESENT	0
776536	772607	21093M	PARTICIPANT	\N	PRESENT	0
776537	772607	20028X	PARTICIPANT	\N	PRESENT	0
776538	772607	21048G	PARTICIPANT	\N	PRESENT	0
776539	772607	21037D	PARTICIPANT	\N	PRESENT	0
776540	772607	21069M	PARTICIPANT	\N	PRESENT	0
776541	772607	19693L	PARTICIPANT	\N	PRESENT	0
776498	772607	19479G	PARTICIPANT	\N	PRESENT	0
776499	772607	21088Q	PARTICIPANT	\N	PRESENT	0
776568	772607	14225N	PARTICIPANT	\N	PRESENT	0
777428	777427	11053K	PARTICIPANT	\N	PRESENT	0
777433	777432	11053K	PARTICIPANT	\N	PRESENT	0
777443	777439	11053K	PARTICIPANT	\N	PRESENT	0
777444	777439	19251M	PARTICIPANT	\N	PRESENT	0
777445	777439	14357A	PARTICIPANT	\N	PRESENT	0
781576	779088	19745F	PARTICIPANT	\N	EXCUSE	0
781619	779301	19683J	PARTICIPANT	\N	PRESENT	0
782480	779282	14231L	PARTICIPANT	\N	PRESENT	0
782540	779653	21080G	PARTICIPANT	\N	PRESENT	0
782541	779653	21090J	PARTICIPANT	\N	PRESENT	0
782542	779653	21050A	PARTICIPANT	\N	PRESENT	0
782543	779653	14111D	PARTICIPANT	\N	PRESENT	0
782544	779653	21065H	PARTICIPANT	\N	PRESENT	0
782545	779653	20106U	PARTICIPANT	\N	PRESENT	0
782546	779653	21078N	PARTICIPANT	\N	PRESENT	0
782547	779653	19760E	PARTICIPANT	\N	PRESENT	0
782548	779653	21047F	PARTICIPANT	\N	PRESENT	0
782549	777020	14073Q	PARTICIPANT	\N	PRESENT	0
782550	777020	20124W	PARTICIPANT	\N	PRESENT	0
782551	779653	18083K	PARTICIPANT	\N	PRESENT	0
782552	779653	20076G	PARTICIPANT	\N	PRESENT	0
782553	779653	14259Y	PARTICIPANT	\N	PRESENT	0
782554	779653	19866P	PARTICIPANT	\N	PRESENT	0
782555	779653	14037X	PARTICIPANT	\N	PRESENT	0
782556	779653	21073H	PARTICIPANT	\N	PRESENT	0
782557	779653	19711U	PARTICIPANT	\N	PRESENT	0
782558	779653	14083S	PARTICIPANT	\N	PRESENT	0
782559	779653	19479G	PARTICIPANT	\N	PRESENT	0
782560	779653	14189C	PARTICIPANT	\N	PRESENT	0
782562	782561	19575F	PARTICIPANT	\N	PRESENT	0
782563	782561	19758L	PARTICIPANT	\N	PRESENT	0
782564	782561	14255U	PARTICIPANT	\N	PRESENT	0
782565	782561	11027H	PARTICIPANT	\N	PRESENT	0
782566	782561	21062E	PARTICIPANT	\N	PRESENT	0
782567	782561	19826F	PARTICIPANT	\N	PRESENT	0
782568	782561	14221J	PARTICIPANT	\N	PRESENT	0
782569	782561	21079P	PARTICIPANT	\N	PRESENT	0
782570	779653	21044C	PARTICIPANT	\N	PRESENT	0
782571	779653	14026U	PARTICIPANT	\N	PRESENT	0
782572	779653	19719D	PARTICIPANT	\N	PRESENT	0
782573	779653	98022P	PARTICIPANT	\N	PRESENT	0
782574	779653	20104S	PARTICIPANT	\N	PRESENT	0
782575	779088	21029D	PARTICIPANT	\N	EXCUSE	0
782576	779088	21035B	PARTICIPANT	\N	EXCUSE	0
782577	779088	21073H	PARTICIPANT	\N	EXCUSE	0
782578	779653	20248J	PARTICIPANT	\N	PRESENT	0
782579	779653	20058E	PARTICIPANT	\N	PRESENT	0
782580	779653	08034U	PARTICIPANT	\N	PRESENT	0
782600	779654	11090Q	PARTICIPANT	\N	PRESENT	0
782673	782652	21058J	PARTICIPANT	\N	PRESENT	0
782661	782652	08012N	PARTICIPANT	\N	PRESENT	0
782660	782652	14037X	PARTICIPANT	\N	PRESENT	0
782604	779654	20092G	PARTICIPANT	\N	PRESENT	0
782605	779654	19507S	PARTICIPANT	\N	PRESENT	0
782664	782652	05012A	PARTICIPANT	\N	PRESENT	0
782662	782652	04070G	PARTICIPANT	\N	PRESENT	0
782608	779654	21093M	PARTICIPANT	\N	PRESENT	0
782609	779654	21045D	PARTICIPANT	\N	PRESENT	0
782610	779654	21097R	PARTICIPANT	\N	PRESENT	0
782665	779654	20142Y	PARTICIPANT	\N	PRESENT	0
782685	782679	19545Y	PARTICIPANT	\N	PRESENT	0
782613	779654	21092L	PARTICIPANT	\N	PRESENT	0
782614	779654	19387D	PARTICIPANT	\N	PRESENT	0
782683	782679	14069U	PARTICIPANT	\N	PRESENT	0
782616	779654	19782L	PARTICIPANT	\N	PRESENT	0
782617	779654	21037D	PARTICIPANT	\N	PRESENT	0
782618	779654	21062E	PARTICIPANT	\N	PRESENT	0
782619	779654	20110Q	PARTICIPANT	\N	PRESENT	0
782620	779654	14195A	PARTICIPANT	\N	PRESENT	0
782669	782652	20064C	PARTICIPANT	\N	PRESENT	0
782622	779654	20264J	PARTICIPANT	\N	PRESENT	0
782623	779654	19758L	PARTICIPANT	\N	PRESENT	0
782676	779654	21094N	PARTICIPANT	\N	PRESENT	0
782625	779654	20082E	PARTICIPANT	\N	PRESENT	0
782678	779654	14147R	PARTICIPANT	\N	PRESENT	0
782677	779654	18193Q	PARTICIPANT	\N	PRESENT	0
782657	782652	14069U	PARTICIPANT	\N	PRESENT	0
782719	782715	19703U	PARTICIPANT	\N	PRESENT	0
782538	779653	20108W	PARTICIPANT	\N	PRESENT	0
782539	779653	14191V	PARTICIPANT	\N	PRESENT	0
782680	779654	14191V	PARTICIPANT	\N	PRESENT	0
782631	779654	21078N	PARTICIPANT	\N	PRESENT	0
782632	779654	19760E	PARTICIPANT	\N	PRESENT	0
782681	782679	20094J	PARTICIPANT	\N	PRESENT	0
782682	782679	19575F	PARTICIPANT	\N	PRESENT	0
782684	782679	21083K	PARTICIPANT	\N	PRESENT	0
782686	782679	21032X	PARTICIPANT	\N	PRESENT	0
782637	779654	19866P	PARTICIPANT	\N	PRESENT	0
782687	782679	19826F	PARTICIPANT	\N	PRESENT	0
782639	779654	21073H	PARTICIPANT	\N	PRESENT	0
782640	779654	19711U	PARTICIPANT	\N	PRESENT	0
782658	782652	21074J	PARTICIPANT	\N	PRESENT	0
782659	782652	14179A	PARTICIPANT	\N	PRESENT	0
782643	779654	14189C	PARTICIPANT	\N	PRESENT	0
782688	782679	05012A	PARTICIPANT	\N	PRESENT	0
782645	779654	14026U	PARTICIPANT	\N	PRESENT	0
782689	782679	08012N	PARTICIPANT	\N	PRESENT	0
782690	782679	21054E	PARTICIPANT	\N	PRESENT	0
782648	779654	20104S	PARTICIPANT	\N	PRESENT	0
782649	779654	20248J	PARTICIPANT	\N	PRESENT	0
782650	779654	20058E	PARTICIPANT	\N	PRESENT	0
782651	779654	08034U	PARTICIPANT	\N	PRESENT	0
782655	782652	19575F	PARTICIPANT	\N	PRESENT	0
782656	782652	20094J	PARTICIPANT	\N	PRESENT	0
782667	782652	20098N	PARTICIPANT	\N	PRESENT	0
782672	779654	20266L	PARTICIPANT	\N	PRESENT	0
782691	779654	11110B	PARTICIPANT	\N	PRESENT	0
782712	782710	19691J	PARTICIPANT	\N	PRESENT	0
782713	782710	19703U	PARTICIPANT	\N	PRESENT	0
782717	782715	19691J	PARTICIPANT	\N	PRESENT	0
782718	782715	18193Q	PARTICIPANT	\N	PRESENT	0
782757	780814	20086J	PARTICIPANT	\N	PRESENT	0
782758	780814	14001X	PARTICIPANT	\N	PRESENT	0
782759	780814	21057H	PARTICIPANT	\N	PRESENT	0
782760	780814	11053K	PARTICIPANT	\N	PRESENT	0
782761	780814	19826F	PARTICIPANT	\N	PRESENT	0
782762	780814	20094J	PARTICIPANT	\N	PRESENT	0
782763	780814	14237S	PARTICIPANT	\N	PRESENT	0
782764	780814	21084L	PARTICIPANT	\N	PRESENT	0
782765	780814	20106U	PARTICIPANT	\N	PRESENT	0
782766	780814	18207D	PARTICIPANT	\N	PRESENT	0
782767	780814	19575F	PARTICIPANT	\N	PRESENT	0
782768	780814	20114U	PARTICIPANT	\N	PRESENT	0
782769	780814	08018U	PARTICIPANT	\N	PRESENT	0
782770	780814	20126Y	PARTICIPANT	\N	PRESENT	0
782771	780814	11065P	PARTICIPANT	\N	PRESENT	0
782772	780814	21052C	PARTICIPANT	\N	PRESENT	0
782773	780814	19711U	PARTICIPANT	\N	PRESENT	0
782774	780814	14133K	PRESIDENT	0	PRESENT	0
782775	780814	14189C	PARTICIPANT	\N	PRESENT	0
782776	780814	21076L	PARTICIPANT	\N	PRESENT	0
782777	780814	21086N	PARTICIPANT	\N	PRESENT	0
782778	780814	21093M	PARTICIPANT	\N	PRESENT	0
782779	780814	21044C	PARTICIPANT	\N	PRESENT	0
782780	780814	20180F	PARTICIPANT	\N	PRESENT	0
782781	780814	21049H	PARTICIPANT	\N	PRESENT	0
782782	780814	19507S	PARTICIPANT	\N	PRESENT	0
782783	780814	20084G	PARTICIPANT	\N	PRESENT	0
782784	780814	14031R	PARTICIPANT	\N	EXCUSE	0
782785	780814	19251M	PARTICIPANT	\N	EXCUSE	0
782786	780814	20022R	PARTICIPANT	\N	EXCUSE	0
782787	780814	14026U	PARTICIPANT	\N	EXCUSE	0
782788	780814	14219Q	PARTICIPANT	\N	EXCUSE	0
782789	779655	19593H	PARTICIPANT	\N	PRESENT	0
782790	779655	21037D	PARTICIPANT	\N	PRESENT	0
782791	779655	14133K	PARTICIPANT	\N	PRESENT	0
782792	779655	20044X	PARTICIPANT	\N	PRESENT	0
782793	779655	14331P	PARTICIPANT	\N	PRESENT	0
782794	779655	21049H	PARTICIPANT	\N	PRESENT	0
782795	779655	21032X	PARTICIPANT	\N	PRESENT	0
782796	779655	20106U	PARTICIPANT	\N	PRESENT	0
782797	779655	14001X	PARTICIPANT	\N	PRESENT	0
782798	779655	19711U	PARTICIPANT	\N	PRESENT	0
782800	779655	20248J	PARTICIPANT	\N	PRESENT	0
782801	779655	18207D	PARTICIPANT	\N	PRESENT	0
782802	779655	14237S	PARTICIPANT	\N	PRESENT	0
782803	779655	20104S	PARTICIPANT	\N	PRESENT	0
782951	782945	19667J	PARTICIPANT	\N	PRESENT	0
782956	782945	19533U	PARTICIPANT	\N	PRESENT	0
782959	782945	20092G	PARTICIPANT	\N	PRESENT	0
782961	782945	01058X	PARTICIPANT	\N	PRESENT	0
782993	782945	18231D	PARTICIPANT	\N	PRESENT	0
783091	782945	19735D	PARTICIPANT	\N	EXCUSE	0
783092	782945	21059K	PARTICIPANT	\N	EXCUSE	0
786431	786427	21089R	PARTICIPANT	\N	PRESENT	0
786498	786427	19749K	PARTICIPANT	\N	PRESENT	0
786496	786427	20180F	PARTICIPANT	\N	PRESENT	0
786497	786427	21087P	PARTICIPANT	\N	PRESENT	0
786499	786427	11045K	PARTICIPANT	\N	PRESENT	0
786500	786427	18193Q	PARTICIPANT	\N	PRESENT	0
786501	786427	14223L	PARTICIPANT	\N	PRESENT	0
786502	786427	19798U	PARTICIPANT	\N	PRESENT	0
786503	786427	14147R	PARTICIPANT	\N	PRESENT	0
786504	786428	21089R	PARTICIPANT	\N	PRESENT	0
786505	786428	20180F	PARTICIPANT	\N	PRESENT	0
786674	786673	20110Q	PARTICIPANT	\N	PRESENT	0
786507	786428	18193Q	PARTICIPANT	\N	PRESENT	0
786508	786428	14223L	PARTICIPANT	\N	PRESENT	0
786509	786428	14147R	PARTICIPANT	\N	PRESENT	0
786510	786428	19798U	PARTICIPANT	\N	PRESENT	0
786511	786428	11045K	PARTICIPANT	\N	PRESENT	0
786512	786428	19749K	PARTICIPANT	\N	PRESENT	0
786513	786428	21091K	PARTICIPANT	\N	PRESENT	0
786519	786518	19719D	PARTICIPANT	\N	PRESENT	0
786675	786673	11056N	PARTICIPANT	\N	PRESENT	0
786676	786673	17229F	PARTICIPANT	\N	PRESENT	0
786678	786673	20150Y	PARTICIPANT	\N	PRESENT	0
786679	786673	19669L	PARTICIPANT	\N	PRESENT	0
786680	786673	21029D	PARTICIPANT	\N	PRESENT	0
786681	786673	08012N	PARTICIPANT	\N	PRESENT	0
786683	786673	08018U	PARTICIPANT	\N	PRESENT	0
794600	794592	14121F	PARTICIPANT	\N	EXCUSE	0
794601	794592	21079P	PARTICIPANT	\N	EXCUSE	0
794696	794695	20078J	PARTICIPANT	\N	PRESENT	0
794697	794695	21045D	PARTICIPANT	\N	PRESENT	0
794698	794695	19545Y	PARTICIPANT	\N	PRESENT	0
794699	794695	20144B	PARTICIPANT	\N	PRESENT	0
794700	794695	21067K	PARTICIPANT	\N	PRESENT	0
794701	794695	20038A	PARTICIPANT	\N	PRESENT	0
794702	794695	20056C	PARTICIPANT	\N	PRESENT	0
794756	786625	20024T	PARTICIPANT	\N	PRESENT	0
794760	794759	11115U	PARTICIPANT	\N	PRESENT	0
794761	794759	14255U	PARTICIPANT	\N	PRESENT	0
794762	794759	20114U	PARTICIPANT	\N	PRESENT	0
794763	794759	20060X	PARTICIPANT	\N	PRESENT	0
794764	794759	21081H	PARTICIPANT	\N	PRESENT	0
794765	794759	14059S	PARTICIPANT	\N	PRESENT	0
794766	794759	20082E	PARTICIPANT	\N	PRESENT	0
794767	794759	10015M	PARTICIPANT	\N	PRESENT	0
794768	794759	20058E	PARTICIPANT	\N	PRESENT	0
794771	794770	19735D	PARTICIPANT	\N	PRESENT	0
794772	794770	19723Y	PARTICIPANT	\N	PRESENT	0
794773	794769	19735D	PARTICIPANT	\N	PRESENT	0
794774	794769	19723Y	PARTICIPANT	\N	PRESENT	0
794776	794775	11045K	PARTICIPANT	\N	PRESENT	0
794778	794777	11045K	PARTICIPANT	\N	PRESENT	0
794780	794779	11045K	PARTICIPANT	\N	PRESENT	0
794785	794784	14189C	PARTICIPANT	\N	PRESENT	0
794786	794784	20024T	PARTICIPANT	\N	PRESENT	0
794787	794784	14069U	PARTICIPANT	\N	PRESENT	0
794788	794784	20138D	PARTICIPANT	\N	PRESENT	0
794789	794784	19347U	PARTICIPANT	\N	PRESENT	0
794790	794784	20128B	PARTICIPANT	\N	PRESENT	0
794791	794784	14021P	PARTICIPANT	\N	PRESENT	0
794792	794784	19735D	PARTICIPANT	\N	PRESENT	0
794807	794806	05008E	PARTICIPANT	\N	PRESENT	0
794794	794784	14257W	PARTICIPANT	\N	PRESENT	0
794795	794784	19745F	PARTICIPANT	\N	PRESENT	0
794796	794784	20056C	PARTICIPANT	\N	PRESENT	0
794797	794784	19421M	PARTICIPANT	\N	PRESENT	0
794798	794784	19489J	PARTICIPANT	\N	PRESENT	0
794799	794784	14213J	PARTICIPANT	\N	PRESENT	0
794800	794784	14187A	PARTICIPANT	\N	PRESENT	0
794801	794784	21059K	PARTICIPANT	\N	PRESENT	0
794802	794784	20022R	PARTICIPANT	\N	PRESENT	0
794803	794784	19575F	PARTICIPANT	\N	PRESENT	0
794804	794784	20060X	PARTICIPANT	\N	PRESENT	0
794805	794784	20032T	PARTICIPANT	\N	PRESENT	0
794809	794808	05008E	PARTICIPANT	\N	PRESENT	0
794811	794810	05008E	PARTICIPANT	\N	PRESENT	0
794813	794812	19749K	PARTICIPANT	\N	PRESENT	0
794815	794814	19749K	PARTICIPANT	\N	PRESENT	0
794817	794816	19749K	PARTICIPANT	\N	PRESENT	0
794854	793594	20180F	PARTICIPANT	\N	PRESENT	0
794855	793594	14147R	PARTICIPANT	\N	PRESENT	0
794856	793594	21089R	PARTICIPANT	\N	PRESENT	0
794858	793594	19693L	PARTICIPANT	\N	PRESENT	0
794914	794913	21042A	PARTICIPANT	\N	PRESENT	0
794915	794913	21074J	PARTICIPANT	\N	PRESENT	0
794916	794913	19685L	PARTICIPANT	\N	PRESENT	0
794917	794913	21085M	PARTICIPANT	\N	PRESENT	0
794918	794913	20052X	PARTICIPANT	\N	PRESENT	0
794919	794913	21069M	PARTICIPANT	\N	PRESENT	0
794925	794863	21082J	PARTICIPANT	\N	PRESENT	0
794928	794926	14151M	PARTICIPANT	\N	PRESENT	0
794929	794926	17367Q	PARTICIPANT	\N	PRESENT	0
794941	794939	14053L	PARTICIPANT	\N	PRESENT	0
794950	794949	20074E	PARTICIPANT	\N	PRESENT	0
794952	794951	20074E	PARTICIPANT	\N	PRESENT	0
795614	795611	20112S	PARTICIPANT	\N	PRESENT	0
795616	795611	11043H	PARTICIPANT	\N	PRESENT	0
795618	794067	21040X	PARTICIPANT	\N	PRESENT	0
795619	794067	20124W	PARTICIPANT	\N	PRESENT	0
795620	794067	14217N	PARTICIPANT	\N	PRESENT	0
795621	794067	19798U	PARTICIPANT	\N	PRESENT	0
795622	794067	20022R	PARTICIPANT	\N	PRESENT	0
795623	794067	19701S	PARTICIPANT	\N	PRESENT	0
795624	794067	14053L	PARTICIPANT	\N	PRESENT	0
795625	794067	19111A	PARTICIPANT	\N	PRESENT	0
795626	794067	07004J	PARTICIPANT	\N	PRESENT	0
795627	794067	19569H	PARTICIPANT	\N	PRESENT	0
794598	794592	19545Y	PARTICIPANT	\N	PRESENT	0
794599	794592	05012A	PARTICIPANT	\N	PRESENT	0
795628	794067	14195A	PARTICIPANT	\N	PRESENT	0
795629	794067	21087P	PARTICIPANT	\N	PRESENT	0
795630	794067	21046E	PARTICIPANT	\N	PRESENT	0
795631	794067	21076L	PARTICIPANT	\N	PRESENT	0
795632	794067	19591F	PARTICIPANT	\N	PRESENT	0
795633	794067	14021P	PARTICIPANT	\N	PRESENT	0
795634	794067	19657G	PARTICIPANT	\N	PRESENT	0
795635	794067	11090Q	PARTICIPANT	\N	PRESENT	0
795639	795638	20042V	PARTICIPANT	\N	PRESENT	0
795640	795638	14207L	PARTICIPANT	\N	PRESENT	0
795641	795638	11070L	PARTICIPANT	\N	PRESENT	0
795642	795638	20068G	PARTICIPANT	\N	PRESENT	0
795643	795638	12016W	PARTICIPANT	\N	PRESENT	0
795644	794067	14169X	PARTICIPANT	\N	PRESENT	0
795645	795638	14031R	PARTICIPANT	\N	PRESENT	0
795646	795638	20018V	PARTICIPANT	\N	PRESENT	0
795647	795638	14257W	PRESIDENT	0	PRESENT	0
795648	795638	21060C	PARTICIPANT	\N	PRESENT	0
795649	795638	19533U	PARTICIPANT	\N	PRESENT	0
795650	795638	19619A	PARTICIPANT	\N	PRESENT	0
795651	795638	20092G	PARTICIPANT	\N	PRESENT	0
795652	795636	20024T	PARTICIPANT	\N	PRESENT	0
795653	795636	19954N	PARTICIPANT	\N	PRESENT	0
795654	795636	19575F	PARTICIPANT	\N	PRESENT	0
795655	795636	14255U	PARTICIPANT	\N	PRESENT	0
795656	795636	20264J	PARTICIPANT	\N	PRESENT	0
795657	795636	19693L	PARTICIPANT	\N	PRESENT	0
795658	795636	14026U	PARTICIPANT	\N	PRESENT	0
795659	795636	14037X	PARTICIPANT	\N	PRESENT	0
795660	795636	04070G	PARTICIPANT	\N	PRESENT	0
795661	795636	21064G	PARTICIPANT	\N	PRESENT	0
795662	795636	21036C	PARTICIPANT	\N	PRESENT	0
795663	795636	20064C	PARTICIPANT	\N	PRESENT	0
795664	795636	21077M	PARTICIPANT	\N	PRESENT	0
795665	794067	21072G	PARTICIPANT	\N	PRESENT	0
795666	794067	19723Y	PARTICIPANT	\N	PRESENT	0
795667	794067	08018U	PARTICIPANT	\N	PRESENT	0
795668	795611	19251M	PARTICIPANT	\N	PRESENT	0
795669	795611	20056C	PARTICIPANT	\N	PRESENT	0
795670	795611	19711U	PARTICIPANT	\N	PRESENT	0
795671	795611	21037D	PARTICIPANT	\N	PRESENT	0
795672	795611	19349W	PARTICIPANT	\N	PRESENT	0
795673	795611	19954N	PARTICIPANT	\N	PRESENT	0
795674	795611	19575F	PARTICIPANT	\N	PRESENT	0
795675	795611	20026V	PARTICIPANT	\N	PRESENT	0
795676	795636	21032X	PARTICIPANT	\N	PRESENT	0
795677	794067	14147R	PARTICIPANT	\N	PRESENT	0
795679	794067	21075K	PARTICIPANT	\N	PRESENT	0
795680	794067	19565D	PARTICIPANT	\N	PRESENT	0
795682	794067	17779H	PARTICIPANT	\N	PRESENT	0
795683	794067	21056G	PARTICIPANT	\N	PRESENT	0
795684	794067	14281W	PARTICIPANT	\N	PRESENT	0
787683	787682	19553Y	PARTICIPANT	\N	PRESENT	0
788462	786177	08073C	PARTICIPANT	\N	PRESENT	1
788463	786176	08073C	PARTICIPANT	\N	PRESENT	1
791118	789267	21058J	PARTICIPANT	\N	PRESENT	0
791119	789267	14191V	PARTICIPANT	\N	PRESENT	0
791121	789267	19489J	PARTICIPANT	\N	PRESENT	0
791122	789267	14151M	PARTICIPANT	\N	PRESENT	0
791124	789267	11045K	PARTICIPANT	\N	PRESENT	0
791125	789267	19347U	PARTICIPANT	\N	PRESENT	0
791126	789267	19413M	PARTICIPANT	\N	PRESENT	0
791127	789267	14331P	PARTICIPANT	\N	PRESENT	0
791128	789267	20032T	PARTICIPANT	\N	PRESENT	0
791129	789267	08056B	PARTICIPANT	\N	PRESENT	0
791130	789267	07029T	PARTICIPANT	\N	PRESENT	0
791131	789267	19820Y	PARTICIPANT	\N	PRESENT	0
791132	789267	21067K	PARTICIPANT	\N	PRESENT	0
791133	789267	21046E	PARTICIPANT	\N	PRESENT	0
791134	789267	19798U	PARTICIPANT	\N	PRESENT	0
791135	789267	19713W	PARTICIPANT	\N	PRESENT	0
791136	789267	21097R	PARTICIPANT	\N	PRESENT	0
791137	789267	14213J	PARTICIPANT	\N	PRESENT	0
791138	789267	17965H	PARTICIPANT	\N	PRESENT	0
791139	789267	18193Q	PARTICIPANT	\N	PRESENT	0
791140	789267	19782L	PARTICIPANT	\N	PRESENT	0
791141	789267	21039F	PARTICIPANT	\N	PRESENT	0
791142	789267	20074E	PARTICIPANT	\N	PRESENT	0
791143	789267	08034U	PARTICIPANT	\N	PRESENT	0
791144	789267	19295A	PARTICIPANT	\N	PRESENT	0
791145	789267	14215L	PARTICIPANT	\N	PRESENT	0
791146	789267	04045F	PARTICIPANT	\N	PRESENT	0
791147	789267	07004J	PARTICIPANT	\N	PRESENT	0
791148	789267	21094N	PARTICIPANT	\N	PRESENT	0
791149	789267	19673G	PARTICIPANT	\N	PRESENT	0
791150	789267	20060X	PARTICIPANT	\N	PRESENT	0
791159	789267	20040T	PARTICIPANT	\N	PRESENT	0
791160	791158	14189C	PARTICIPANT	\N	EXCUSE	0
791161	791158	19798U	PARTICIPANT	\N	EXCUSE	0
791162	791158	20130U	PARTICIPANT	\N	EXCUSE	0
791163	791158	20046A	PARTICIPANT	\N	EXCUSE	0
791164	791158	19866P	PARTICIPANT	\N	EXCUSE	0
791165	791158	14147R	PARTICIPANT	\N	EXCUSE	0
791166	791158	14223L	PARTICIPANT	\N	EXCUSE	0
791168	791167	19057M	PARTICIPANT	\N	PRESENT	0
791169	789267	14026U	PARTICIPANT	\N	PRESENT	0
791170	791167	14026U	PARTICIPANT	\N	PRESENT	0
791172	791171	14026U	PARTICIPANT	\N	PRESENT	0
791174	791173	19057M	PARTICIPANT	\N	PRESENT	0
791175	791173	04042C	PARTICIPANT	\N	PRESENT	0
791176	791173	20142Y	PARTICIPANT	\N	PRESENT	0
791177	791173	14255U	PARTICIPANT	\N	PRESENT	0
791178	791173	14026U	PARTICIPANT	\N	PRESENT	0
791179	791173	17737W	PARTICIPANT	\N	PRESENT	0
791180	791173	20114U	PARTICIPANT	\N	PRESENT	0
791181	789267	19691J	PARTICIPANT	\N	PRESENT	0
791182	789267	08069G	PARTICIPANT	\N	PRESENT	0
791258	789268	11045K	PARTICIPANT	\N	PRESENT	0
791259	789268	14026U	PARTICIPANT	\N	PRESENT	0
791260	789268	21097R	PARTICIPANT	\N	PRESENT	0
791261	789268	04045F	PARTICIPANT	\N	PRESENT	0
791262	789268	19349W	PARTICIPANT	\N	PRESENT	0
791263	789268	20134Y	PARTICIPANT	\N	PRESENT	0
791264	789268	21094N	PARTICIPANT	\N	PRESENT	0
791265	789268	21046E	PARTICIPANT	\N	PRESENT	0
791266	789268	19553Y	PARTICIPANT	\N	PRESENT	0
791267	789268	21066J	PARTICIPANT	\N	PRESENT	0
791268	789268	20116W	PARTICIPANT	\N	PRESENT	0
791269	789268	21051B	PARTICIPANT	\N	PRESENT	0
791270	789268	20074E	PARTICIPANT	\N	PRESENT	0
791271	789268	14215L	PARTICIPANT	\N	PRESENT	0
791272	789268	19673G	PARTICIPANT	\N	PRESENT	0
791273	789268	21091K	PARTICIPANT	\N	PRESENT	0
791274	789268	20180F	PARTICIPANT	\N	PRESENT	0
791275	789268	21058J	PARTICIPANT	\N	PRESENT	0
791276	789268	21039F	PARTICIPANT	\N	PRESENT	0
791277	789268	20038A	PARTICIPANT	\N	PRESENT	0
791278	789268	07029T	PARTICIPANT	\N	PRESENT	0
791279	789268	21045D	PARTICIPANT	\N	PRESENT	0
791280	789268	14083S	PARTICIPANT	\N	PRESENT	0
791281	789268	07004J	PARTICIPANT	\N	PRESENT	0
791282	789268	20040T	PARTICIPANT	\N	PRESENT	0
791283	789268	19713W	PARTICIPANT	\N	PRESENT	0
791284	789268	19798U	PARTICIPANT	\N	PRESENT	0
791285	789268	20090E	PARTICIPANT	\N	PRESENT	0
791286	789268	20018V	PARTICIPANT	\N	PRESENT	0
791287	789268	19760E	PARTICIPANT	\N	PRESENT	0
791288	789268	19687N	PARTICIPANT	\N	PRESENT	0
791289	789268	21088Q	PARTICIPANT	\N	PRESENT	0
791290	789268	21089R	PARTICIPANT	\N	PRESENT	0
791291	789268	21077M	PARTICIPANT	\N	PRESENT	0
791292	789268	18193Q	PARTICIPANT	\N	PRESENT	0
791293	789268	19489J	PARTICIPANT	\N	PRESENT	0
791294	789268	19551W	PARTICIPANT	\N	PRESENT	0
791295	789268	20060X	PARTICIPANT	\N	PRESENT	0
791296	789268	20028X	PARTICIPANT	\N	PRESENT	0
791297	789268	12016W	PARTICIPANT	\N	PRESENT	0
791298	789268	20064C	PARTICIPANT	\N	PRESENT	0
791299	789268	20048C	PARTICIPANT	\N	PRESENT	0
791300	789268	19691J	PARTICIPANT	\N	PRESENT	0
791301	789268	19725B	PARTICIPANT	\N	PRESENT	0
791302	789268	21064G	PARTICIPANT	\N	PRESENT	0
791303	789268	19569H	PARTICIPANT	\N	PRESENT	0
791304	789268	14042U	PARTICIPANT	\N	PRESENT	0
791305	789268	14071N	PARTICIPANT	\N	PRESENT	0
791306	789268	14033T	PARTICIPANT	\N	PRESENT	0
791307	789268	20070A	PARTICIPANT	\N	PRESENT	0
791308	789268	20062A	PARTICIPANT	\N	PRESENT	0
791309	789268	14021P	PARTICIPANT	\N	PRESENT	0
791310	789268	11056N	PARTICIPANT	\N	PRESENT	0
791311	789268	18395Y	PARTICIPANT	\N	PRESENT	0
791312	789268	19413M	PARTICIPANT	\N	PRESENT	0
791313	789268	21090J	PARTICIPANT	\N	PRESENT	0
791314	789268	19347U	PARTICIPANT	\N	PRESENT	0
791315	789268	12028B	PARTICIPANT	\N	PRESENT	0
791381	789415	05008E	PARTICIPANT	\N	PRESENT	0
791383	789415	20034V	PRESIDENT	0	PRESENT	0
791384	789415	14275Y	PARTICIPANT	\N	PRESENT	0
791385	789415	20148F	PARTICIPANT	\N	PRESENT	0
791386	789415	19331L	PARTICIPANT	\N	PRESENT	0
791387	789415	21029D	PARTICIPANT	\N	PRESENT	0
791388	789415	21030V	PARTICIPANT	\N	PRESENT	0
791389	789415	21097R	PARTICIPANT	\N	PRESENT	0
791390	789415	17023S	PARTICIPANT	\N	PRESENT	0
791522	791521	14189C	PARTICIPANT	\N	PRESENT	0
791523	791521	20110Q	PARTICIPANT	\N	PRESENT	0
791524	791521	14069U	PARTICIPANT	\N	PRESENT	0
791526	791521	20138D	PARTICIPANT	\N	PRESENT	0
791527	791521	12028B	PARTICIPANT	\N	PRESENT	0
791256	789268	11090Q	PARTICIPANT	\N	PRESENT	0
791257	789268	19647E	PARTICIPANT	\N	PRESENT	0
791528	791521	14267Y	PARTICIPANT	\N	PRESENT	0
791529	791521	19295A	PARTICIPANT	\N	PRESENT	0
791530	791521	14259Y	PARTICIPANT	\N	PRESENT	0
791531	791521	14215L	PARTICIPANT	\N	PRESENT	0
791533	791521	19553Y	PARTICIPANT	\N	PRESENT	0
791534	791521	14179A	PARTICIPANT	\N	PRESENT	0
791535	791521	19735D	PARTICIPANT	\N	PRESENT	0
791536	791521	86034E	PARTICIPANT	\N	PRESENT	0
791537	791521	08010L	PARTICIPANT	\N	PRESENT	0
791538	791521	14111D	PARTICIPANT	\N	PRESENT	0
791539	791521	19593H	PARTICIPANT	\N	PRESENT	0
791540	791521	11090Q	PARTICIPANT	\N	PRESENT	0
791541	791521	19798U	PARTICIPANT	\N	PRESENT	0
791542	791521	14229S	PARTICIPANT	\N	PRESENT	0
791543	791521	04045F	PARTICIPANT	\N	PRESENT	0
791544	791521	20136B	PARTICIPANT	\N	PRESENT	0
791545	791521	19301E	PARTICIPANT	\N	PRESENT	0
791546	791521	20064C	PARTICIPANT	\N	PRESENT	0
791547	791521	19479G	PARTICIPANT	\N	PRESENT	0
791661	791660	14053L	PARTICIPANT	\N	PRESENT	0
791665	791660	14193X	PARTICIPANT	\N	PRESENT	0
791725	791724	20110Q	PARTICIPANT	\N	PRESENT	0
791726	791724	19782L	PARTICIPANT	\N	PRESENT	0
791728	791727	20112S	PARTICIPANT	\N	PRESENT	1
791729	791727	20138D	PARTICIPANT	\N	PRESENT	1
791730	791727	19735D	PARTICIPANT	\N	PRESENT	1
791731	791727	14229S	PARTICIPANT	\N	PRESENT	1
791732	791727	20142Y	PARTICIPANT	\N	PRESENT	1
791736	791734	19723Y	PARTICIPANT	\N	PRESENT	0
768237	768236	20136B	PARTICIPANT	\N	PRESENT	0
768647	765407	11090Q	PARTICIPANT	\N	PRESENT	0
768671	765407	19679N	PARTICIPANT	\N	PRESENT	0
768672	765407	19866P	PARTICIPANT	\N	PRESENT	0
768673	765407	19591F	PARTICIPANT	\N	PRESENT	0
768675	765407	17779H	PARTICIPANT	\N	PRESENT	0
768678	765407	20090E	PARTICIPANT	\N	PRESENT	0
768680	765407	21046E	PARTICIPANT	\N	PRESENT	0
768683	765407	19569H	PARTICIPANT	\N	PRESENT	0
768686	765407	20130U	PARTICIPANT	\N	PRESENT	0
768689	765407	19760E	PARTICIPANT	\N	PRESENT	0
768699	765407	14083S	PARTICIPANT	\N	PRESENT	0
768700	765407	21064G	PARTICIPANT	\N	PRESENT	0
768701	765407	07004J	PARTICIPANT	\N	PRESENT	0
768702	765407	21066J	PARTICIPANT	\N	PRESENT	0
769522	767591	21088Q	PARTICIPANT	\N	EXCUSE	0
769523	767591	12028B	PARTICIPANT	\N	PRESENT	0
769524	767591	20090E	PARTICIPANT	\N	PRESENT	0
769525	767591	20078J	PARTICIPANT	\N	PRESENT	0
769526	767591	18395Y	PARTICIPANT	\N	PRESENT	0
769527	767591	14151M	PRESIDENT	1	PRESENT	0
769528	767591	20146D	PARTICIPANT	\N	PRESENT	0
769529	767591	99004R	PRESIDENT	0	PRESENT	0
769530	767591	19826F	PARTICIPANT	\N	PRESENT	0
769531	767591	17367Q	PARTICIPANT	\N	PRESENT	0
769532	767591	19295A	PARTICIPANT	\N	PRESENT	0
769533	767591	15197G	PARTICIPANT	\N	PRESENT	0
769534	767591	19563B	PARTICIPANT	\N	PRESENT	0
769535	767591	21081H	PARTICIPANT	\N	PRESENT	0
769536	767591	17737W	PARTICIPANT	\N	PRESENT	0
769540	769537	14331P	PARTICIPANT	\N	PRESENT	0
769638	769234	17737W	PARTICIPANT	\N	PRESENT	0
769636	769234	19691J	PARTICIPANT	\N	PRESENT	0
769637	769234	14275Y	PARTICIPANT	\N	PRESENT	0
769544	769537	19741B	PARTICIPANT	\N	PRESENT	0
769639	769234	21057H	PARTICIPANT	\N	PRESENT	0
769546	769537	21090J	PARTICIPANT	\N	PRESENT	0
769547	769537	20044X	PARTICIPANT	\N	PRESENT	0
769548	769537	19671E	PARTICIPANT	\N	PRESENT	0
769549	769537	20124W	PARTICIPANT	\N	PRESENT	0
769550	769537	19762G	PARTICIPANT	\N	PRESENT	0
769551	769537	07029T	PARTICIPANT	\N	EXCUSE	0
769640	769234	21055F	PARTICIPANT	\N	PRESENT	0
769554	768933	21043B	PARTICIPANT	\N	PRESENT	0
769555	768933	14111D	PARTICIPANT	\N	PRESENT	0
769556	768933	18207D	PARTICIPANT	\N	PRESENT	0
769557	768933	21076L	PARTICIPANT	\N	PRESENT	0
769558	768933	14147R	PARTICIPANT	\N	PRESENT	0
769559	768933	04047H	PRESIDENT	0	PRESENT	0
769560	768933	19749K	PARTICIPANT	\N	PRESENT	0
769561	768933	19719D	PARTICIPANT	\N	PRESENT	0
769562	768933	11072N	PARTICIPANT	\N	PRESENT	0
769563	768933	19447X	PARTICIPANT	\N	PRESENT	0
769564	769537	20086J	PARTICIPANT	\N	PRESENT	0
769565	769537	11048N	PARTICIPANT	\N	PRESENT	0
769566	769537	19711U	PARTICIPANT	\N	PRESENT	0
769567	769537	20080C	PARTICIPANT	\N	PRESENT	0
769568	769537	14225N	PRESIDENT	0	PRESENT	0
769569	769537	19349W	PARTICIPANT	\N	PRESENT	0
769570	769537	20070A	PARTICIPANT	\N	PRESENT	0
769571	769537	18395Y	PARTICIPANT	\N	PRESENT	0
769572	768933	21038E	PARTICIPANT	\N	PRESENT	0
769573	768933	20098N	PARTICIPANT	\N	PRESENT	0
769574	769537	11074Q	PARTICIPANT	\N	PRESENT	0
769575	769537	19573D	PARTICIPANT	\N	PRESENT	0
769576	769537	08010L	PARTICIPANT	\N	PRESENT	0
769577	769537	20024T	PARTICIPANT	\N	PRESENT	0
769578	769537	21041Y	PARTICIPANT	\N	PRESENT	0
769579	769537	14083S	PARTICIPANT	\N	PRESENT	0
769580	769537	20062A	PARTICIPANT	\N	PRESENT	0
769581	768933	14275Y	PARTICIPANT	\N	PRESENT	0
769582	768933	14215L	PARTICIPANT	\N	PRESENT	0
769583	768933	18231D	PARTICIPANT	\N	PRESENT	0
769584	768933	21095P	PARTICIPANT	\N	PRESENT	0
769585	769537	08034U	PARTICIPANT	\N	PRESENT	0
769586	768933	14089Y	PARTICIPANT	\N	PRESENT	0
769587	768933	14069U	PARTICIPANT	\N	PRESENT	0
769588	768933	14259Y	PARTICIPANT	\N	PRESENT	0
769589	768933	11056N	PARTICIPANT	\N	PRESENT	0
769590	767591	20108W	PARTICIPANT	\N	PRESENT	0
769591	767591	21072G	PARTICIPANT	\N	PRESENT	0
769592	769537	20094J	PARTICIPANT	\N	PRESENT	0
769593	769537	21072G	PARTICIPANT	\N	PRESENT	0
769594	768933	20036X	PARTICIPANT	\N	PRESENT	0
769596	768933	14053L	PARTICIPANT	\N	PRESENT	0
769641	769234	19798U	PARTICIPANT	\N	PRESENT	0
769642	769234	21080G	PARTICIPANT	\N	PRESENT	0
769643	769234	14055N	PARTICIPANT	\N	PRESENT	0
769644	769234	21030V	PARTICIPANT	\N	PRESENT	0
769645	769234	17779H	PARTICIPANT	\N	PRESENT	0
769646	769234	19479G	PARTICIPANT	\N	PRESENT	0
769647	769234	19569H	PARTICIPANT	\N	PRESENT	0
769648	769234	21046E	PARTICIPANT	\N	PRESENT	0
769649	769234	19693L	PARTICIPANT	\N	PRESENT	0
769650	769234	19399H	PARTICIPANT	\N	PRESENT	0
769651	769234	21058J	PARTICIPANT	\N	PRESENT	0
769652	769234	21052C	PARTICIPANT	\N	PRESENT	0
769653	769234	19387D	PARTICIPANT	\N	PRESENT	0
769654	769234	14211G	PARTICIPANT	\N	PRESENT	0
769655	769234	15197G	PARTICIPANT	\N	PRESENT	0
769656	769234	20020P	PARTICIPANT	\N	PRESENT	0
769657	769234	20062A	PARTICIPANT	\N	PRESENT	0
769658	769234	19683J	PARTICIPANT	\N	PRESENT	0
769659	769234	14225N	PARTICIPANT	\N	PRESENT	0
769660	769234	08060W	PARTICIPANT	\N	PRESENT	0
769661	769234	14001X	PARTICIPANT	\N	PRESENT	0
769662	769234	21067K	PARTICIPANT	\N	PRESENT	0
769663	769234	14121F	PARTICIPANT	\N	PRESENT	0
769664	769234	19545Y	PARTICIPANT	\N	PRESENT	0
769665	769234	21087P	PARTICIPANT	\N	PRESENT	0
769666	769234	14221J	PARTICIPANT	\N	PRESENT	0
769667	769234	20122U	PARTICIPANT	\N	PRESENT	0
769668	769234	20050V	PARTICIPANT	\N	PRESENT	0
769669	769234	99004R	PARTICIPANT	\N	PRESENT	0
769670	769234	20046A	PARTICIPANT	\N	PRESENT	0
769675	769234	19565D	PARTICIPANT	\N	PRESENT	0
769672	769234	21084L	PARTICIPANT	\N	PRESENT	0
769673	769234	19695N	PARTICIPANT	\N	PRESENT	0
769674	769234	19681G	PARTICIPANT	\N	PRESENT	0
769676	769234	20102Q	PARTICIPANT	\N	PRESENT	0
769677	769234	21075K	PARTICIPANT	\N	PRESENT	0
769678	769234	19758L	PARTICIPANT	\N	PRESENT	0
769679	769234	20036X	PARTICIPANT	\N	PRESENT	0
769680	769234	20266L	PARTICIPANT	\N	PRESENT	0
769681	769234	21094N	PARTICIPANT	\N	PRESENT	0
769682	769234	21037D	PARTICIPANT	\N	PRESENT	0
769683	769234	21073H	PARTICIPANT	\N	PRESENT	0
769684	769234	21093M	PARTICIPANT	\N	PRESENT	0
769685	769234	19575F	PARTICIPANT	\N	PRESENT	0
769686	769234	19703U	PARTICIPANT	\N	PRESENT	0
769687	769234	04008A	PARTICIPANT	\N	PRESENT	0
769688	769234	19367Y	PARTICIPANT	\N	PRESENT	0
769689	769234	04045F	PARTICIPANT	\N	PRESENT	0
769690	769234	19301E	PARTICIPANT	\N	PRESENT	0
769691	769234	18083K	PARTICIPANT	\N	PRESENT	0
769692	769234	14249W	PARTICIPANT	\N	PRESENT	0
769693	769234	19711U	PARTICIPANT	\N	PRESENT	0
769694	769234	20146D	PARTICIPANT	\N	PRESENT	0
769695	769234	19349W	PARTICIPANT	\N	PRESENT	0
769696	769234	19621T	PARTICIPANT	\N	PRESENT	0
769697	769234	19697Q	PARTICIPANT	\N	PRESENT	0
769698	769234	08011M	PARTICIPANT	\N	PRESENT	0
769699	769234	21091K	PARTICIPANT	\N	PRESENT	0
769700	769234	01058X	PARTICIPANT	\N	PRESENT	0
769701	769234	20078J	PARTICIPANT	\N	PRESENT	0
769702	769234	20076G	PARTICIPANT	\N	PRESENT	0
769703	769234	20074E	PARTICIPANT	\N	PRESENT	0
769704	769234	20060X	PARTICIPANT	\N	PRESENT	0
769705	769234	08028W	PARTICIPANT	\N	PRESENT	0
769706	769234	21035B	PARTICIPANT	\N	PRESENT	0
769707	769234	11043H	PARTICIPANT	\N	PRESENT	0
769708	769234	20070A	PARTICIPANT	\N	PRESENT	0
769709	769234	21044C	PARTICIPANT	\N	PRESENT	0
769710	769234	20088L	PARTICIPANT	\N	PRESENT	0
769711	769234	20080C	PARTICIPANT	\N	PRESENT	0
769712	769234	14169X	PARTICIPANT	\N	PRESENT	0
769713	769234	19782L	PARTICIPANT	\N	PRESENT	0
769714	769234	21071F	PARTICIPANT	\N	PRESENT	0
769715	769234	14191V	PARTICIPANT	\N	PRESENT	0
769716	769234	12028B	PARTICIPANT	\N	PRESENT	0
769717	769234	21072G	PARTICIPANT	\N	PRESENT	0
783094	782945	19575F	PARTICIPANT	\N	EXCUSE	0
783135	783134	14189C	PARTICIPANT	\N	PRESENT	0
783136	783134	20110Q	PARTICIPANT	\N	PRESENT	0
783137	783134	14069U	PARTICIPANT	\N	PRESENT	0
783338	783337	18083K	PARTICIPANT	\N	PRESENT	0
783339	783337	20038A	PARTICIPANT	\N	PRESENT	0
783140	783134	12028B	PARTICIPANT	\N	PRESENT	0
783141	783134	14267Y	PARTICIPANT	\N	PRESENT	0
783349	783348	14059S	PARTICIPANT	\N	PRESENT	0
783143	783134	14259Y	PARTICIPANT	\N	PRESENT	0
783144	783134	14215L	PARTICIPANT	\N	PRESENT	0
783350	783348	20096L	PARTICIPANT	\N	PRESENT	0
783146	783134	19553Y	PARTICIPANT	\N	PRESENT	0
783147	783134	14179A	PARTICIPANT	\N	PRESENT	0
783148	783134	19735D	PARTICIPANT	\N	PRESENT	0
783149	783134	86034E	PARTICIPANT	\N	PRESENT	0
783150	783134	08010L	PARTICIPANT	\N	PRESENT	0
783151	783134	14111D	PARTICIPANT	\N	PRESENT	0
783152	783134	19593H	PARTICIPANT	\N	PRESENT	0
783153	783134	11090Q	PARTICIPANT	\N	PRESENT	0
783154	783134	19798U	PARTICIPANT	\N	PRESENT	0
783155	783134	14229S	PARTICIPANT	\N	PRESENT	0
783156	783134	04045F	PARTICIPANT	\N	PRESENT	0
783157	783134	20136B	PARTICIPANT	\N	PRESENT	0
783158	783134	19301E	PARTICIPANT	\N	PRESENT	0
783351	783348	20118Y	PARTICIPANT	\N	PRESENT	0
783160	783134	19479G	PARTICIPANT	\N	PRESENT	0
783436	783374	11090Q	PARTICIPANT	\N	PRESENT	0
783440	783374	14031R	PARTICIPANT	\N	PRESENT	0
783441	783374	21090J	PARTICIPANT	\N	PRESENT	0
783442	783374	21078N	PARTICIPANT	\N	PRESENT	0
783443	783374	21046E	PARTICIPANT	\N	PRESENT	0
783444	783374	14219Q	PARTICIPANT	\N	PRESENT	0
783445	783374	20136B	PARTICIPANT	\N	PRESENT	0
783446	783374	21076L	PARTICIPANT	\N	PRESENT	0
783447	783374	15197G	PARTICIPANT	\N	PRESENT	0
783448	783374	20100N	PARTICIPANT	\N	PRESENT	0
783449	783374	21084L	PARTICIPANT	\N	PRESENT	0
783450	783374	20106U	PARTICIPANT	\N	PRESENT	0
783451	783374	19551W	PARTICIPANT	\N	PRESENT	0
783452	783374	20068G	PARTICIPANT	\N	PRESENT	0
783453	783374	14231L	PARTICIPANT	\N	PRESENT	0
783454	783374	21095P	PARTICIPANT	\N	PRESENT	0
783455	783374	21087P	PARTICIPANT	\N	PRESENT	0
783456	783374	21051B	PARTICIPANT	\N	PRESENT	0
783457	783374	19683J	PARTICIPANT	\N	PRESENT	0
783458	783374	21040X	PARTICIPANT	\N	PRESENT	0
783460	783374	17023S	PARTICIPANT	\N	PRESENT	0
783462	783374	19697Q	PARTICIPANT	\N	PRESENT	0
783463	783374	20086J	PARTICIPANT	\N	PRESENT	0
783464	783374	19760E	PARTICIPANT	\N	PRESENT	0
783465	783374	14053L	PARTICIPANT	\N	PRESENT	0
783466	783374	11053K	PARTICIPANT	\N	PRESENT	0
783467	783375	11090Q	PARTICIPANT	\N	PRESENT	0
783468	783375	14031R	PARTICIPANT	\N	PRESENT	0
783469	783375	21090J	PARTICIPANT	\N	PRESENT	0
783470	783375	21078N	PARTICIPANT	\N	PRESENT	0
783471	783375	21046E	PARTICIPANT	\N	PRESENT	0
783472	783375	14219Q	PARTICIPANT	\N	PRESENT	0
783493	783375	19687N	PARTICIPANT	\N	PRESENT	0
783474	783375	21076L	PARTICIPANT	\N	PRESENT	0
783475	783375	15197G	PARTICIPANT	\N	PRESENT	0
783476	783375	20100N	PARTICIPANT	\N	PRESENT	0
783477	783375	21084L	PARTICIPANT	\N	PRESENT	0
783478	783375	20106U	PARTICIPANT	\N	PRESENT	0
783479	783375	19551W	PARTICIPANT	\N	PRESENT	0
783491	783375	14231L	PARTICIPANT	\N	PRESENT	0
783481	783375	21095P	PARTICIPANT	\N	PRESENT	0
783482	783375	21087P	PARTICIPANT	\N	PRESENT	0
783483	783375	21051B	PARTICIPANT	\N	PRESENT	0
783492	783375	20136B	PARTICIPANT	\N	PRESENT	0
783485	783375	21040X	PARTICIPANT	\N	PRESENT	0
783486	783375	19697Q	PARTICIPANT	\N	PRESENT	0
783487	783375	20086J	PARTICIPANT	\N	PRESENT	0
783488	783375	19760E	PARTICIPANT	\N	PRESENT	0
783489	783375	14053L	PARTICIPANT	\N	PRESENT	0
783490	783375	11053K	PARTICIPANT	\N	PRESENT	0
783494	783375	19593H	PARTICIPANT	\N	PRESENT	0
783495	783375	21073H	PARTICIPANT	\N	PRESENT	0
783496	783375	20052X	PARTICIPANT	\N	PRESENT	0
783509	783375	08061X	PARTICIPANT	\N	PRESENT	0
783510	783375	20134Y	PARTICIPANT	\N	PRESENT	0
783511	783375	21061D	PARTICIPANT	\N	PRESENT	0
783512	783375	17965H	PARTICIPANT	\N	PRESENT	0
783513	783375	21048G	PARTICIPANT	\N	PRESENT	0
783514	783375	18193Q	PARTICIPANT	\N	PRESENT	0
783515	783375	19691J	PARTICIPANT	\N	PRESENT	0
783516	783375	20132W	PARTICIPANT	\N	PRESENT	0
783517	783375	04070G	PARTICIPANT	\N	PRESENT	0
783518	783375	19621T	PARTICIPANT	\N	PRESENT	0
783519	783375	14215L	PARTICIPANT	\N	PRESENT	0
783520	783375	21077M	PARTICIPANT	\N	PRESENT	0
783524	783375	19611R	PARTICIPANT	\N	PRESENT	0
783525	783376	11090Q	PARTICIPANT	\N	PRESENT	0
783526	783376	14031R	PARTICIPANT	\N	PRESENT	0
783527	783376	21078N	PARTICIPANT	\N	PRESENT	0
783528	783376	21046E	PARTICIPANT	\N	PRESENT	0
783560	783376	15197G	PARTICIPANT	\N	PRESENT	0
783561	783376	21077M	PARTICIPANT	\N	PRESENT	0
783562	783376	14229S	PARTICIPANT	\N	PRESENT	0
783532	783376	21084L	PARTICIPANT	\N	PRESENT	0
783563	783376	20048C	PARTICIPANT	\N	PRESENT	0
783534	783376	14231L	PARTICIPANT	\N	PRESENT	0
783535	783376	21087P	PARTICIPANT	\N	PRESENT	0
783564	783376	19335Q	PARTICIPANT	\N	PRESENT	0
783537	783376	21040X	PARTICIPANT	\N	PRESENT	0
783538	783376	19697Q	PARTICIPANT	\N	PRESENT	0
783539	783376	19760E	PARTICIPANT	\N	PRESENT	0
783540	783376	14053L	PARTICIPANT	\N	PRESENT	0
783565	783376	19551W	PARTICIPANT	\N	PRESENT	0
783542	783376	20136B	PARTICIPANT	\N	PRESENT	0
783543	783376	19687N	PARTICIPANT	\N	PRESENT	0
783544	783376	19593H	PARTICIPANT	\N	PRESENT	0
783545	783376	21073H	PARTICIPANT	\N	PRESENT	0
783546	783376	20052X	PARTICIPANT	\N	PRESENT	0
783547	783376	08061X	PARTICIPANT	\N	PRESENT	0
783548	783376	20134Y	PARTICIPANT	\N	PRESENT	0
783549	783376	21061D	PARTICIPANT	\N	PRESENT	0
783566	783376	21056G	PARTICIPANT	\N	PRESENT	0
783551	783376	21048G	PARTICIPANT	\N	PRESENT	0
783552	783376	18193Q	PARTICIPANT	\N	PRESENT	0
783553	783376	19691J	PARTICIPANT	\N	PRESENT	0
783554	783376	20132W	PARTICIPANT	\N	PRESENT	0
783555	783376	04070G	PARTICIPANT	\N	PRESENT	0
783556	783376	19621T	PARTICIPANT	\N	PRESENT	0
783557	783376	14215L	PARTICIPANT	\N	PRESENT	0
783567	783376	20138D	PARTICIPANT	\N	PRESENT	0
783559	783376	19611R	PARTICIPANT	\N	PRESENT	0
783581	783376	20062A	PARTICIPANT	\N	PRESENT	0
783582	783376	19758L	PARTICIPANT	\N	PRESENT	0
783583	783376	20058E	PARTICIPANT	\N	PRESENT	0
783584	783376	20130U	PARTICIPANT	\N	PRESENT	0
783585	783376	14213J	PARTICIPANT	\N	PRESENT	0
783587	783377	11090Q	PARTICIPANT	\N	PRESENT	0
783588	783377	14031R	PARTICIPANT	\N	PRESENT	0
783589	783377	14231L	PARTICIPANT	\N	PRESENT	0
783590	783377	21087P	PARTICIPANT	\N	PRESENT	0
783591	783377	21040X	PARTICIPANT	\N	PRESENT	0
783592	783377	19697Q	PARTICIPANT	\N	PRESENT	0
783593	783377	14053L	PARTICIPANT	\N	PRESENT	0
783594	783377	19593H	PARTICIPANT	\N	PRESENT	0
783595	783377	21073H	PARTICIPANT	\N	PRESENT	0
783597	783377	08061X	PARTICIPANT	\N	PRESENT	0
783598	783377	20134Y	PARTICIPANT	\N	PRESENT	0
783601	783377	20132W	PARTICIPANT	\N	PRESENT	0
783604	783377	14215L	PARTICIPANT	\N	PRESENT	0
783606	783377	21077M	PARTICIPANT	\N	PRESENT	0
783607	783377	14229S	PARTICIPANT	\N	PRESENT	0
783610	783377	21056G	PARTICIPANT	\N	PRESENT	0
783611	783377	20138D	PARTICIPANT	\N	PRESENT	0
783612	783377	20062A	PARTICIPANT	\N	PRESENT	0
783613	783377	19758L	PARTICIPANT	\N	PRESENT	0
783614	783377	20058E	PARTICIPANT	\N	PRESENT	0
770651	769539	12016W	PARTICIPANT	\N	PRESENT	0
770652	769539	14225N	PRESIDENT	0	PRESENT	0
770653	769539	21090J	PARTICIPANT	\N	PRESENT	0
770654	769539	19399H	PARTICIPANT	\N	PRESENT	0
770658	769539	14121F	PARTICIPANT	\N	PRESENT	0
770660	769539	11048N	PARTICIPANT	\N	PRESENT	0
770661	769539	14331P	PARTICIPANT	\N	PRESENT	0
770665	769539	20094J	PARTICIPANT	\N	PRESENT	0
770666	769539	20044X	PARTICIPANT	\N	PRESENT	0
770668	769539	19349W	PARTICIPANT	\N	PRESENT	0
770669	769539	20126Y	PARTICIPANT	\N	PRESENT	0
770672	769539	08009T	PARTICIPANT	\N	PRESENT	0
770673	768940	19649G	PARTICIPANT	\N	PRESENT	0
770674	768940	20074E	PARTICIPANT	\N	PRESENT	0
770675	768940	04045F	PARTICIPANT	\N	PRESENT	0
770676	768940	04047H	PRESIDENT	0	PRESENT	0
770677	768940	19673G	PARTICIPANT	\N	PRESENT	0
770678	768940	21040X	PARTICIPANT	\N	PRESENT	0
770679	768940	19447X	PARTICIPANT	\N	PRESENT	0
770680	768940	21043B	PARTICIPANT	\N	PRESENT	0
770681	768940	21044C	PARTICIPANT	\N	PRESENT	0
770682	768940	14147R	PARTICIPANT	\N	PRESENT	0
770683	768940	14151M	PARTICIPANT	\N	PRESENT	0
770684	768940	14215L	PARTICIPANT	\N	PRESENT	0
770685	768940	19749K	PARTICIPANT	\N	PRESENT	0
770686	768940	19729F	PARTICIPANT	\N	EXCUSE	0
770687	769539	20116W	PARTICIPANT	\N	PRESENT	0
770688	769539	11053K	PARTICIPANT	\N	PRESENT	0
770690	769539	08034U	PARTICIPANT	\N	PRESENT	0
770691	769539	11070L	PARTICIPANT	\N	PRESENT	0
770694	769539	20134Y	PARTICIPANT	\N	PRESENT	0
770696	769539	14327T	PARTICIPANT	\N	PRESENT	0
770697	769539	07004J	PARTICIPANT	\N	PRESENT	0
770698	769539	14253S	PARTICIPANT	\N	PRESENT	0
770701	769539	20150Y	PARTICIPANT	\N	PRESENT	0
770703	769539	19711U	PARTICIPANT	\N	PRESENT	0
770704	769539	19647E	PARTICIPANT	\N	PRESENT	0
770705	769539	11040E	PARTICIPANT	\N	PRESENT	0
770707	769539	20070A	PARTICIPANT	\N	PRESENT	0
771861	769239	20124W	PARTICIPANT	\N	PRESENT	0
774254	773244	19768N	PARTICIPANT	\N	PRESENT	0
774255	773244	14357A	PARTICIPANT	\N	PRESENT	0
774256	773244	20082E	PARTICIPANT	\N	PRESENT	0
774257	773244	21093M	PARTICIPANT	\N	PRESENT	0
774258	773244	11090Q	PARTICIPANT	\N	PRESENT	0
774259	773244	14205J	PARTICIPANT	\N	PRESENT	0
774260	772448	21030V	PARTICIPANT	\N	PRESENT	0
774261	772448	21031W	PARTICIPANT	\N	PRESENT	0
774262	772448	19565D	PARTICIPANT	\N	PRESENT	0
774263	772448	01058X	PARTICIPANT	\N	PRESENT	0
774264	772448	11027H	PARTICIPANT	\N	PRESENT	0
774265	772448	14001X	PARTICIPANT	\N	PRESENT	0
774266	772448	04042C	PARTICIPANT	\N	PRESENT	0
774267	772448	19669L	PARTICIPANT	\N	PRESENT	0
774268	772448	08056B	PARTICIPANT	\N	PRESENT	0
774269	772448	17737W	PARTICIPANT	\N	PRESENT	0
774270	772448	19421M	PARTICIPANT	\N	PRESENT	0
774271	772448	19709B	PARTICIPANT	\N	PRESENT	0
774272	772448	21067K	PARTICIPANT	\N	PRESENT	0
774273	772448	14179A	PARTICIPANT	\N	PRESENT	0
774274	772448	07033P	PRESIDENT	0	PRESENT	0
774275	772448	08047A	PARTICIPANT	\N	PRESENT	0
774276	772448	20128B	PARTICIPANT	\N	PRESENT	0
774277	772448	14037X	PARTICIPANT	\N	PRESENT	0
774278	772448	14097Y	PARTICIPANT	\N	PRESENT	0
774279	772448	19531S	PARTICIPANT	\N	PRESENT	0
774280	772448	08069G	PARTICIPANT	\N	PRESENT	0
774281	772448	20042V	PARTICIPANT	\N	PRESENT	0
774282	772448	19721W	PARTICIPANT	\N	PRESENT	0
774283	772448	20064C	PARTICIPANT	\N	PRESENT	0
774284	772448	14251Q	PARTICIPANT	\N	PRESENT	0
774285	772448	20252E	PARTICIPANT	\N	PRESENT	0
774286	772448	14267Y	PARTICIPANT	\N	PRESENT	0
774287	772448	99004R	PARTICIPANT	\N	PRESENT	0
774288	772448	14255U	PARTICIPANT	\N	PRESENT	0
774289	772448	17023S	PARTICIPANT	\N	PRESENT	0
774290	772448	12028B	PARTICIPANT	\N	EXCUSE	0
774291	772448	14133K	PARTICIPANT	\N	EXCUSE	0
774292	772448	14193X	PARTICIPANT	\N	EXCUSE	0
774293	772448	19347U	PARTICIPANT	\N	EXCUSE	0
774294	772448	95041E	PARTICIPANT	\N	PRESENT	0
774295	772448	19745F	PARTICIPANT	\N	EXCUSE	0
774296	772599	14111D	PARTICIPANT	\N	PRESENT	0
774297	772599	11070L	PARTICIPANT	\N	PRESENT	0
774298	773244	21050A	PARTICIPANT	\N	PRESENT	0
774338	772599	21087P	PARTICIPANT	\N	PRESENT	0
774339	772428	14053L	PARTICIPANT	\N	PRESENT	0
774340	772428	19649G	PARTICIPANT	\N	PRESENT	0
774341	772428	20036X	PARTICIPANT	\N	PRESENT	0
774342	772428	20074E	PARTICIPANT	\N	PRESENT	0
774343	772428	10015M	PARTICIPANT	\N	PRESENT	0
774344	772428	21057H	PARTICIPANT	\N	PRESENT	0
774345	772428	04045F	PARTICIPANT	\N	PRESENT	0
774346	772428	04047H	PRESIDENT	0	PRESENT	0
774347	772428	19719D	PARTICIPANT	\N	PRESENT	0
774348	772428	05008E	PARTICIPANT	\N	PRESENT	0
774349	772428	20098N	PARTICIPANT	\N	PRESENT	0
774350	772428	19447X	PARTICIPANT	\N	PRESENT	0
774351	772428	19725B	PARTICIPANT	\N	PRESENT	0
774352	772428	21043B	PARTICIPANT	\N	PRESENT	0
774353	772428	21044C	PARTICIPANT	\N	PRESENT	0
774354	772428	18207D	PARTICIPANT	\N	PRESENT	0
774355	772428	18231D	PARTICIPANT	\N	PRESENT	0
774356	772428	20266L	PARTICIPANT	\N	PRESENT	0
774357	772428	14147R	PARTICIPANT	\N	PRESENT	0
774358	772428	20114U	PARTICIPANT	\N	PRESENT	0
774359	772428	14151M	PARTICIPANT	\N	PRESENT	0
774360	772428	14069U	PARTICIPANT	\N	PRESENT	0
774361	772428	19749K	PARTICIPANT	\N	PRESENT	0
774362	772428	14111D	PARTICIPANT	\N	PRESENT	0
774363	772428	14189C	PARTICIPANT	\N	PRESENT	0
774364	772428	21076L	PARTICIPANT	\N	PRESENT	0
774365	772428	19673G	PARTICIPANT	\N	PRESENT	0
774366	772428	21040X	PARTICIPANT	\N	PRESENT	0
774367	772428	14231L	PARTICIPANT	\N	PRESENT	0
774368	772428	14089Y	PARTICIPANT	\N	PRESENT	0
774369	772428	11056N	PARTICIPANT	\N	PRESENT	0
774370	772428	19489J	PARTICIPANT	\N	PRESENT	0
774371	772428	21056G	PARTICIPANT	\N	PRESENT	0
774372	772428	20108W	PARTICIPANT	\N	PRESENT	0
774373	772428	21088Q	PARTICIPANT	\N	PRESENT	0
774374	772428	19111A	PARTICIPANT	\N	PRESENT	0
774375	772428	08018U	PARTICIPANT	\N	PRESENT	0
774376	772428	21038E	PARTICIPANT	\N	PRESENT	0
774377	772428	20022R	PARTICIPANT	\N	PRESENT	0
774378	772599	21039F	PARTICIPANT	\N	PRESENT	0
774379	772599	20090E	PARTICIPANT	\N	PRESENT	0
774380	772599	19681G	PARTICIPANT	\N	PRESENT	0
774381	772599	21038E	PARTICIPANT	\N	PRESENT	0
774382	772599	19798U	PARTICIPANT	\N	PRESENT	0
774383	772599	20026V	PARTICIPANT	\N	PRESENT	0
774384	772599	20130U	PARTICIPANT	\N	PRESENT	0
774385	772599	07029T	PARTICIPANT	\N	PRESENT	0
774386	772599	14147R	PARTICIPANT	\N	PRESENT	0
774387	772599	20056C	PARTICIPANT	\N	PRESENT	0
774388	772599	20106U	PARTICIPANT	\N	PRESENT	0
774389	772599	19533U	PARTICIPANT	\N	PRESENT	0
774390	772599	19691J	PARTICIPANT	\N	PRESENT	0
774391	772599	20098N	PARTICIPANT	\N	PRESENT	0
774392	772599	14195A	PARTICIPANT	\N	PRESENT	0
774393	772599	20116W	PARTICIPANT	\N	PRESENT	0
774394	772599	14231L	PARTICIPANT	\N	PRESENT	0
774395	772599	19349W	PARTICIPANT	\N	PRESENT	0
774396	772599	04045F	PARTICIPANT	\N	PRESENT	0
774397	772599	11043H	PARTICIPANT	\N	PRESENT	0
774398	772599	19735D	PARTICIPANT	\N	PRESENT	0
774399	772599	19760E	PARTICIPANT	\N	PRESENT	0
774400	772599	20032T	PARTICIPANT	\N	PRESENT	0
774401	772599	14030Q	PARTICIPANT	\N	PRESENT	0
774402	772599	14213J	PARTICIPANT	\N	PRESENT	0
774403	772599	20142Y	PARTICIPANT	\N	PRESENT	0
774404	772599	15197G	PARTICIPANT	\N	PRESENT	0
774405	772448	21073H	PARTICIPANT	\N	EXCUSE	0
774406	772599	05008E	PARTICIPANT	\N	PRESENT	0
774407	772599	20086J	PARTICIPANT	\N	PRESENT	0
774411	772599	21043B	PARTICIPANT	\N	PRESENT	0
774409	772599	05012A	PARTICIPANT	\N	PRESENT	0
774410	772599	21064G	PARTICIPANT	\N	PRESENT	0
774412	772599	14189C	PARTICIPANT	\N	PRESENT	0
774413	772599	08011M	PARTICIPANT	\N	PRESENT	0
774415	772599	14042U	PARTICIPANT	\N	PRESENT	0
791739	791735	19735D	PARTICIPANT	\N	PRESENT	0
791743	791742	19611R	PARTICIPANT	\N	PRESENT	0
791744	791742	20058E	PARTICIPANT	\N	PRESENT	0
791746	791745	19611R	PARTICIPANT	\N	PRESENT	0
791747	791745	20058E	PARTICIPANT	\N	PRESENT	0
791749	791748	19611R	PARTICIPANT	\N	PRESENT	0
791750	791748	20058E	PARTICIPANT	\N	PRESENT	0
791751	791748	20112S	PARTICIPANT	\N	PRESENT	0
791753	791752	19611R	PARTICIPANT	\N	PRESENT	0
791778	791777	20138D	PARTICIPANT	\N	PRESENT	1
791779	791777	20112S	PARTICIPANT	\N	PRESENT	1
791780	791777	19735D	PARTICIPANT	\N	PRESENT	1
791781	791777	19693L	PARTICIPANT	\N	PRESENT	1
791782	791777	20142Y	PARTICIPANT	\N	PRESENT	1
791790	791789	19545Y	PARTICIPANT	\N	PRESENT	0
791791	791789	21082J	PARTICIPANT	\N	PRESENT	0
791792	791789	21046E	PARTICIPANT	\N	PRESENT	0
791793	791789	21087P	PARTICIPANT	\N	PRESENT	0
791795	791794	11048N	PARTICIPANT	\N	PRESENT	0
793154	793152	19565D	PARTICIPANT	\N	PRESENT	0
791798	791797	11048N	PARTICIPANT	\N	PRESENT	0
793153	793152	19647E	PARTICIPANT	\N	PRESENT	0
793155	793152	20122U	PARTICIPANT	\N	PRESENT	0
793423	793065	21052C	PARTICIPANT	\N	EXCUSE	0
793458	793457	19631V	PARTICIPANT	\N	PRESENT	0
793459	793457	18083K	PARTICIPANT	\N	PRESENT	0
793460	793457	20034V	PARTICIPANT	\N	PRESENT	0
793461	793457	12016W	PARTICIPANT	\N	PRESENT	0
793462	793457	19657G	PARTICIPANT	\N	PRESENT	0
793463	793457	19331L	PARTICIPANT	\N	PRESENT	0
793464	793457	21055F	PARTICIPANT	\N	PRESENT	0
793465	793457	14275Y	PARTICIPANT	\N	PRESENT	0
793466	793457	21030V	PARTICIPANT	\N	PRESENT	0
793585	791690	05008E	PARTICIPANT	\N	PRESENT	0
793586	791774	14193X	PARTICIPANT	\N	EXCUSE	0
793587	791774	19745F	PARTICIPANT	\N	EXCUSE	0
793588	791774	14211G	PARTICIPANT	\N	EXCUSE	0
793589	791774	14037X	PARTICIPANT	\N	PRESENT	0
793598	791774	95041E	PARTICIPANT	\N	PRESENT	0
793599	791774	14179A	PARTICIPANT	\N	PRESENT	0
793600	793592	14030Q	PARTICIPANT	\N	PRESENT	0
793601	793592	21061D	PARTICIPANT	\N	EXCUSE	0
793602	793592	20130U	PARTICIPANT	\N	EXCUSE	0
793603	793592	14147R	PARTICIPANT	\N	EXCUSE	0
793604	793592	20038A	PARTICIPANT	\N	EXCUSE	0
793605	793592	14223L	PARTICIPANT	\N	EXCUSE	0
793606	793592	14109K	PARTICIPANT	\N	EXCUSE	0
793655	791811	14327T	PARTICIPANT	\N	PRESENT	0
793656	791811	20086J	PARTICIPANT	\N	PRESENT	0
793657	791811	19545Y	PARTICIPANT	\N	PRESENT	0
793658	791811	20080C	PARTICIPANT	\N	PRESENT	0
793659	791811	11053K	PARTICIPANT	\N	PRESENT	0
793660	791811	20094J	PARTICIPANT	\N	PRESENT	0
793661	791811	11074Q	PARTICIPANT	\N	PRESENT	0
793662	791811	14225N	PRESIDENT	0	PRESENT	0
793663	791811	19573D	PARTICIPANT	\N	PRESENT	0
793664	791811	21079P	PARTICIPANT	\N	PRESENT	0
793665	791811	19349W	PARTICIPANT	\N	PRESENT	0
793666	791811	08010L	PARTICIPANT	\N	PRESENT	0
793667	791811	14253S	PARTICIPANT	\N	PRESENT	0
793668	791811	20116W	PARTICIPANT	\N	PRESENT	0
793669	791811	21090J	PARTICIPANT	\N	PRESENT	0
793670	791811	19335Q	PARTICIPANT	\N	PRESENT	0
793671	791811	20024T	PARTICIPANT	\N	PRESENT	0
793672	791811	20126Y	PARTICIPANT	\N	PRESENT	0
793673	791811	11048N	PARTICIPANT	\N	PRESENT	0
793674	791811	19479G	PARTICIPANT	\N	PRESENT	0
793675	791811	08034U	PARTICIPANT	\N	PRESENT	0
793676	791811	19687N	PARTICIPANT	\N	PRESENT	0
793677	791811	20044X	PARTICIPANT	\N	PRESENT	0
793678	791811	11040E	PARTICIPANT	\N	PRESENT	0
793679	791811	20062A	PARTICIPANT	\N	PRESENT	0
793680	791811	20070A	PARTICIPANT	\N	PRESENT	0
793681	791811	08009T	PARTICIPANT	\N	PRESENT	0
793682	791811	07029T	PARTICIPANT	\N	EXCUSE	0
793683	791811	21069M	PARTICIPANT	\N	EXCUSE	0
793684	791811	19399H	PARTICIPANT	\N	EXCUSE	0
793685	791811	14173T	PARTICIPANT	\N	EXCUSE	0
791737	791734	19735D	PARTICIPANT	\N	PRESENT	0
791738	791735	19723Y	PARTICIPANT	\N	PRESENT	0
793686	793592	20180F	PARTICIPANT	\N	EXCUSE	0
793692	793691	21057H	PARTICIPANT	\N	EXCUSE	0
793693	793691	14169X	PARTICIPANT	\N	EXCUSE	0
793694	793691	20044X	PARTICIPANT	\N	EXCUSE	0
793695	793691	21054E	PARTICIPANT	\N	EXCUSE	0
793696	793691	20018V	PARTICIPANT	\N	PRESENT	0
793697	793691	21083K	PARTICIPANT	\N	EXCUSE	0
793698	793691	19479G	PARTICIPANT	\N	EXCUSE	0
793699	793691	21056G	PARTICIPANT	\N	EXCUSE	0
793700	793691	19711U	PARTICIPANT	\N	PRESENT	0
793701	793691	11056N	PARTICIPANT	\N	EXCUSE	0
793702	793691	20132W	PARTICIPANT	\N	PRESENT	0
793703	793691	19798U	PARTICIPANT	\N	EXCUSE	0
793704	793691	20024T	PARTICIPANT	\N	EXCUSE	0
793708	793707	04047H	PARTICIPANT	\N	PRESENT	0
793759	793592	19693L	PARTICIPANT	\N	EXCUSE	0
793760	793592	20046A	PARTICIPANT	\N	EXCUSE	0
793989	793592	21087P	PARTICIPANT	\N	EXCUSE	0
793990	793592	21089R	PARTICIPANT	\N	EXCUSE	0
794059	794058	04047H	PARTICIPANT	\N	PRESENT	0
794515	793691	20086J	PARTICIPANT	\N	PRESENT	0
794516	793691	20026V	PARTICIPANT	\N	PRESENT	0
794518	793691	20042V	PARTICIPANT	\N	PRESENT	0
794529	793148	14231L	PRESIDENT	0	PRESENT	0
794531	793148	05012A	PARTICIPANT	\N	PRESENT	0
794532	793148	19758L	PARTICIPANT	\N	PRESENT	0
794533	793148	20102Q	PARTICIPANT	\N	PRESENT	0
794534	793148	21068L	PARTICIPANT	\N	PRESENT	0
794535	793148	20070A	PARTICIPANT	\N	PRESENT	0
794536	793148	21070E	PARTICIPANT	\N	PRESENT	0
794537	793148	21065H	PARTICIPANT	\N	PRESENT	0
794538	793148	20022R	PARTICIPANT	\N	PRESENT	0
794539	793148	19782L	PARTICIPANT	\N	PRESENT	0
794540	793148	20068G	PARTICIPANT	\N	PRESENT	0
794541	793148	20058E	PARTICIPANT	\N	PRESENT	0
794542	793148	19447X	PARTICIPANT	\N	PRESENT	0
794543	793148	20032T	PARTICIPANT	\N	PRESENT	0
794544	793148	20062A	PARTICIPANT	\N	PRESENT	0
794545	793148	14069U	PARTICIPANT	\N	PRESENT	0
794546	793148	19573D	PARTICIPANT	\N	PRESENT	0
794547	793148	14026U	PARTICIPANT	\N	PRESENT	0
794548	793148	14215L	PARTICIPANT	\N	PRESENT	0
794564	791719	21035B	PARTICIPANT	\N	PRESENT	0
794565	791719	21096Q	PARTICIPANT	\N	PRESENT	0
794566	791719	19673G	PARTICIPANT	\N	PRESENT	0
794567	791719	20034V	PRESIDENT	0	PRESENT	0
794568	791719	08010L	PARTICIPANT	\N	PRESENT	0
794569	791719	14059S	PARTICIPANT	\N	PRESENT	0
794570	791719	19657G	PARTICIPANT	\N	PRESENT	0
794571	791719	21073H	PARTICIPANT	\N	EXCUSE	0
794572	791719	21029D	PARTICIPANT	\N	PRESENT	0
794573	791719	21097R	PARTICIPANT	\N	PRESENT	0
794574	791719	19331L	PARTICIPANT	\N	PRESENT	0
794575	791719	08073C	PARTICIPANT	\N	PRESENT	1
794576	791719	20148F	PARTICIPANT	\N	PRESENT	0
794588	793148	14257W	PARTICIPANT	\N	PRESENT	0
794602	793148	86034E	PARTICIPANT	\N	PRESENT	0
794603	793148	20086J	PARTICIPANT	\N	PRESENT	0
794604	793148	20066E	PARTICIPANT	\N	PRESENT	0
794606	793148	21048G	PARTICIPANT	\N	EXCUSE	0
794607	793148	20090E	PARTICIPANT	\N	EXCUSE	0
794608	793148	19820Y	PARTICIPANT	\N	EXCUSE	0
794609	793148	19735D	PARTICIPANT	\N	EXCUSE	0
794610	793148	19768N	PARTICIPANT	\N	EXCUSE	0
794611	793148	19866P	PARTICIPANT	\N	EXCUSE	0
794612	793148	14107H	PARTICIPANT	\N	EXCUSE	0
794613	793148	20084G	PARTICIPANT	\N	EXCUSE	0
794614	793148	01034P	PARTICIPANT	\N	EXCUSE	0
794616	793148	14237S	PARTICIPANT	\N	EXCUSE	0
794617	793148	14147R	PARTICIPANT	\N	EXCUSE	0
794624	793148	14223L	PARTICIPANT	\N	EXCUSE	0
794626	793148	21087P	PARTICIPANT	\N	EXCUSE	0
794628	793148	14169X	PARTICIPANT	\N	EXCUSE	0
769718	769234	14237S	PARTICIPANT	\N	PRESENT	0
769719	769234	20044X	PARTICIPANT	\N	PRESENT	0
769720	769234	19760E	PARTICIPANT	\N	PRESENT	0
769721	769234	14215L	PARTICIPANT	\N	PRESENT	0
769722	769234	05012A	PARTICIPANT	\N	PRESENT	0
769723	769234	21029D	PARTICIPANT	\N	PRESENT	0
769724	769234	19667J	PARTICIPANT	\N	PRESENT	0
769725	769234	19331L	PARTICIPANT	\N	PRESENT	0
769726	769234	21097R	PARTICIPANT	\N	PRESENT	0
769727	769234	14253S	PARTICIPANT	\N	PRESENT	0
769728	769234	19591F	PARTICIPANT	\N	PRESENT	0
769729	769234	14331P	PARTICIPANT	\N	PRESENT	0
769730	769234	20090E	PARTICIPANT	\N	PRESENT	0
769731	769234	11074Q	PARTICIPANT	\N	PRESENT	0
769732	769234	11110B	PARTICIPANT	\N	PRESENT	0
769733	769234	21062E	PARTICIPANT	\N	PRESENT	0
769734	769234	14173T	PARTICIPANT	\N	PRESENT	0
769735	769234	20118Y	PARTICIPANT	\N	PRESENT	0
769736	769234	19413M	PARTICIPANT	\N	PRESENT	0
769737	769234	19593H	PARTICIPANT	\N	PRESENT	0
769738	769234	19447X	PARTICIPANT	\N	PRESENT	0
769739	769234	19251M	PARTICIPANT	\N	PRESENT	0
769740	769234	08047A	PARTICIPANT	\N	PRESENT	0
769741	769234	21081H	PARTICIPANT	\N	PRESENT	0
769742	769234	14147R	PARTICIPANT	\N	PRESENT	0
769743	769234	21088Q	PARTICIPANT	\N	PRESENT	0
769744	769234	14329V	PARTICIPANT	\N	PRESENT	0
769745	769234	18395Y	PARTICIPANT	\N	PRESENT	0
769746	769234	14213J	PARTICIPANT	\N	PRESENT	0
769747	769234	20024T	PARTICIPANT	\N	PRESENT	0
769748	769234	21049H	PARTICIPANT	\N	PRESENT	0
769749	769234	20148F	PARTICIPANT	\N	PRESENT	0
769750	769234	19631V	PARTICIPANT	\N	PRESENT	0
769751	769234	19347U	PARTICIPANT	\N	PRESENT	0
769752	769234	20130U	PARTICIPANT	\N	PRESENT	0
769753	769234	19657G	PARTICIPANT	\N	PRESENT	0
769754	769234	19768N	PARTICIPANT	\N	PRESENT	0
769755	769234	07029T	PARTICIPANT	\N	PRESENT	0
769756	769234	21043B	PARTICIPANT	\N	PRESENT	0
769757	769234	21068L	PARTICIPANT	\N	PRESENT	0
769758	769234	21089R	PARTICIPANT	\N	PRESENT	0
769759	769234	21077M	PARTICIPANT	\N	PRESENT	0
769760	769234	14038Y	PARTICIPANT	\N	PRESENT	0
769761	769234	19723Y	PARTICIPANT	\N	PRESENT	0
769762	769234	21047F	PARTICIPANT	\N	PRESENT	0
769763	769234	20140W	PARTICIPANT	\N	PRESENT	0
769764	769234	20120S	PARTICIPANT	\N	PRESENT	0
769765	769234	08018U	PARTICIPANT	\N	PRESENT	0
769766	769234	20068G	PARTICIPANT	\N	PRESENT	0
769767	769234	21063F	PARTICIPANT	\N	PRESENT	0
769768	769234	20058E	PARTICIPANT	\N	PRESENT	0
769769	769234	14355X	PARTICIPANT	\N	PRESENT	0
769770	769234	19709B	PARTICIPANT	\N	PRESENT	0
769771	769234	21039F	PARTICIPANT	\N	PRESENT	0
769772	769234	21074J	PARTICIPANT	\N	PRESENT	0
769773	769234	08073C	PARTICIPANT	\N	PRESENT	0
769774	769234	14033T	PARTICIPANT	\N	PRESENT	0
769775	769234	20104S	PARTICIPANT	\N	PRESENT	0
769776	769234	11072N	PARTICIPANT	\N	PRESENT	0
769777	769234	20056C	PARTICIPANT	\N	PRESENT	0
769778	769234	19673G	PARTICIPANT	\N	PRESENT	0
769779	769234	20126Y	PARTICIPANT	\N	PRESENT	0
769780	769234	20116W	PARTICIPANT	\N	PRESENT	0
769781	769234	14207L	PARTICIPANT	\N	PRESENT	0
769782	769234	20038A	PARTICIPANT	\N	PRESENT	0
769783	769234	19629C	PARTICIPANT	\N	PRESENT	0
769784	769234	08056B	PARTICIPANT	\N	PRESENT	0
769785	769234	21041Y	PARTICIPANT	\N	PRESENT	0
769786	769234	19719D	PARTICIPANT	\N	PRESENT	0
769787	769234	20086J	PARTICIPANT	\N	PRESENT	0
769788	769234	20132W	PARTICIPANT	\N	PRESENT	0
769789	769234	20124W	PARTICIPANT	\N	PRESENT	0
769790	769234	21090J	PARTICIPANT	\N	PRESENT	0
769791	769234	20084G	PARTICIPANT	\N	PRESENT	0
769792	769234	07033P	PARTICIPANT	\N	PRESENT	0
769793	769234	21095P	PARTICIPANT	\N	PRESENT	0
769794	769234	19553Y	PARTICIPANT	\N	PRESENT	0
769795	769234	19954N	PARTICIPANT	\N	PRESENT	0
769796	769234	98022P	PARTICIPANT	\N	PRESENT	0
769797	769234	20252E	PARTICIPANT	\N	PRESENT	0
769798	769234	20072C	PARTICIPANT	\N	PRESENT	0
769799	769234	20134Y	PARTICIPANT	\N	PRESENT	0
769800	769234	19533U	PARTICIPANT	\N	PRESENT	0
769801	769234	14257W	PARTICIPANT	\N	PRESENT	0
769802	769234	14109K	PARTICIPANT	\N	PRESENT	0
769803	769234	11090Q	PARTICIPANT	\N	PRESENT	0
769804	769234	14217N	PARTICIPANT	\N	PRESENT	0
769805	769234	21051B	PARTICIPANT	\N	PRESENT	0
769806	769234	14187A	PARTICIPANT	\N	PRESENT	0
769807	769234	14053L	PARTICIPANT	\N	PRESENT	0
769808	769234	21078N	PARTICIPANT	\N	PRESENT	0
769809	769234	05008E	PARTICIPANT	\N	PRESENT	0
769810	769234	14107H	PARTICIPANT	\N	PRESENT	0
769811	769234	19866P	PARTICIPANT	\N	PRESENT	0
769812	769234	04033B	PARTICIPANT	\N	PRESENT	0
769813	769234	21040X	PARTICIPANT	\N	PRESENT	0
769814	769234	20032T	PARTICIPANT	\N	PRESENT	0
769815	769234	14195A	PARTICIPANT	\N	PRESENT	0
769816	769234	19679N	PARTICIPANT	\N	PRESENT	0
769817	769234	04092N	PARTICIPANT	\N	PRESENT	0
769818	769234	08034U	PARTICIPANT	\N	PRESENT	0
769819	769234	21065H	PARTICIPANT	\N	PRESENT	0
769820	769234	08010L	PARTICIPANT	\N	PRESENT	0
769821	769234	14026U	PARTICIPANT	\N	PRESENT	0
769822	769234	14111D	PARTICIPANT	\N	PRESENT	0
769823	769234	19705W	PARTICIPANT	\N	PRESENT	0
769824	769234	21070E	PARTICIPANT	\N	PRESENT	0
769825	769234	19585H	PARTICIPANT	\N	PRESENT	0
769826	769234	14231L	PARTICIPANT	\N	PRESENT	0
769827	769234	21045D	PARTICIPANT	\N	PRESENT	0
769828	769234	17229F	PARTICIPANT	\N	PRESENT	0
769829	769234	21031W	PARTICIPANT	\N	PRESENT	0
769830	769234	20264J	PARTICIPANT	\N	PRESENT	0
769831	769234	14281W	PARTICIPANT	\N	PRESENT	0
769832	769234	19725B	PARTICIPANT	\N	PRESENT	0
769833	769234	04070G	PARTICIPANT	\N	PRESENT	0
769834	769234	19111A	PARTICIPANT	\N	PRESENT	0
769835	769234	11070L	PARTICIPANT	\N	PRESENT	0
769836	769234	14021P	PARTICIPANT	\N	PRESENT	0
769837	769234	20286Q	PARTICIPANT	\N	PRESENT	0
769838	769234	21038E	PARTICIPANT	\N	PRESENT	0
769839	769234	19649G	PARTICIPANT	\N	PRESENT	0
769840	769234	14097Y	PARTICIPANT	\N	PRESENT	0
769841	769234	21086N	PARTICIPANT	\N	PRESENT	0
769842	769234	19713W	PARTICIPANT	\N	PRESENT	0
769843	769234	18193Q	PARTICIPANT	\N	PRESENT	0
769844	769234	20098N	PARTICIPANT	\N	PRESENT	0
769845	769234	18207D	PARTICIPANT	\N	PRESENT	0
769846	769234	19489J	PARTICIPANT	\N	PRESENT	0
769847	769234	20096L	PARTICIPANT	\N	PRESENT	0
769848	769234	10015M	PARTICIPANT	\N	PRESENT	0
769849	769234	12016W	PARTICIPANT	\N	PRESENT	0
769850	769234	20028X	PARTICIPANT	\N	PRESENT	0
769851	769234	20018V	PARTICIPANT	\N	PRESENT	0
769852	769234	21053D	PARTICIPANT	\N	PRESENT	0
769853	769234	19826F	PARTICIPANT	\N	PRESENT	0
769854	769234	21042A	PARTICIPANT	\N	PRESENT	0
769855	769234	19563B	PARTICIPANT	\N	PRESENT	0
769856	769234	20030R	PARTICIPANT	\N	PRESENT	0
769857	769234	20040T	PARTICIPANT	\N	PRESENT	0
769858	769234	20248J	PARTICIPANT	\N	PRESENT	0
769859	769234	17965H	PARTICIPANT	\N	PRESENT	0
769860	769234	14229S	PARTICIPANT	\N	PRESENT	0
769861	769234	19745F	PARTICIPANT	\N	PRESENT	0
769862	769234	18231D	PARTICIPANT	\N	PRESENT	0
769863	769234	14193X	PARTICIPANT	\N	PRESENT	0
769864	769234	19707Y	PARTICIPANT	\N	PRESENT	0
769865	769234	21056G	PARTICIPANT	\N	PRESENT	0
769866	769234	21059K	PARTICIPANT	\N	PRESENT	0
769867	769234	14031R	PARTICIPANT	\N	PRESENT	0
769868	769234	19669L	PARTICIPANT	\N	PRESENT	0
769869	769234	21082J	PARTICIPANT	\N	PRESENT	0
769870	769234	20042V	PARTICIPANT	\N	PRESENT	0
769871	769234	11115U	PARTICIPANT	\N	PRESENT	0
769872	769234	17023S	PARTICIPANT	\N	PRESENT	0
769873	769234	19685L	PARTICIPANT	\N	PRESENT	0
769874	769234	14327T	PARTICIPANT	\N	PRESENT	0
769875	769234	19820Y	PARTICIPANT	\N	PRESENT	0
769876	769234	08045X	PARTICIPANT	\N	PRESENT	0
769877	769234	14223L	PARTICIPANT	\N	PRESENT	0
769878	769234	20114U	PARTICIPANT	\N	PRESENT	0
783615	783377	20130U	PARTICIPANT	\N	PRESENT	0
783616	783377	14213J	PARTICIPANT	\N	PRESENT	0
783617	783377	21046E	PARTICIPANT	\N	PRESENT	0
783618	783377	19335Q	PARTICIPANT	\N	PRESENT	0
783619	783377	18193Q	PARTICIPANT	\N	PRESENT	0
783620	783377	21055F	PARTICIPANT	\N	PRESENT	0
783621	783377	20106U	PARTICIPANT	\N	PRESENT	0
783622	783377	19760E	PARTICIPANT	\N	PRESENT	0
783623	783377	17965H	PARTICIPANT	\N	PRESENT	0
783624	783377	20044X	PARTICIPANT	\N	PRESENT	0
783625	783377	21048G	PARTICIPANT	\N	PRESENT	0
783626	783377	21085M	PARTICIPANT	\N	PRESENT	0
783627	783377	21078N	PARTICIPANT	\N	PRESENT	0
783628	783377	19621T	PARTICIPANT	\N	PRESENT	0
783629	783377	19723Y	PARTICIPANT	\N	PRESENT	0
783630	783377	11056N	PARTICIPANT	\N	PRESENT	0
783660	783379	21094N	PARTICIPANT	\N	PRESENT	0
783661	783379	19758L	PARTICIPANT	\N	PRESENT	0
783662	783379	19553Y	PARTICIPANT	\N	PRESENT	0
783663	783379	19697Q	PARTICIPANT	\N	PRESENT	0
783664	783379	17965H	PARTICIPANT	\N	PRESENT	0
783665	783379	19723Y	PARTICIPANT	\N	PRESENT	0
783666	783379	21046E	PARTICIPANT	\N	PRESENT	0
783667	783379	19713W	PARTICIPANT	\N	PRESENT	0
783668	783379	18193Q	PARTICIPANT	\N	PRESENT	0
783669	783379	14071N	PARTICIPANT	\N	PRESENT	0
783670	783379	21055F	PARTICIPANT	\N	PRESENT	0
783671	783379	20132W	PARTICIPANT	\N	PRESENT	0
783672	783379	21073H	PARTICIPANT	\N	PRESENT	0
783673	783379	11090Q	PARTICIPANT	\N	PRESENT	0
783674	783379	19760E	PARTICIPANT	\N	PRESENT	0
783675	783379	21071F	PARTICIPANT	\N	PRESENT	0
783676	783379	19335Q	PARTICIPANT	\N	PRESENT	0
783677	783379	20028X	PARTICIPANT	\N	PRESENT	0
783678	783379	20062A	PARTICIPANT	\N	PRESENT	0
783679	783379	19703U	PARTICIPANT	\N	PRESENT	0
783680	783379	21045D	PARTICIPANT	\N	PRESENT	0
783681	783379	20090E	PARTICIPANT	\N	PRESENT	0
783682	783379	20130U	PARTICIPANT	\N	PRESENT	0
783683	783379	14215L	PARTICIPANT	\N	PRESENT	0
783684	783379	19531S	PARTICIPANT	\N	PRESENT	0
783685	783379	21056G	PARTICIPANT	\N	PRESENT	0
783686	783379	20138D	PARTICIPANT	\N	PRESENT	0
783658	783379	19593H	PARTICIPANT	\N	PRESENT	0
783659	783379	14213J	PARTICIPANT	\N	PRESENT	0
783687	783379	07029T	PARTICIPANT	\N	PRESENT	0
783688	783379	20058E	PARTICIPANT	\N	PRESENT	0
783689	783380	19593H	PARTICIPANT	\N	PRESENT	0
783690	783380	14213J	PARTICIPANT	\N	PRESENT	0
783719	783380	11056N	PARTICIPANT	\N	PRESENT	0
783692	783380	19758L	PARTICIPANT	\N	PRESENT	0
783693	783380	19553Y	PARTICIPANT	\N	PRESENT	0
783694	783380	19697Q	PARTICIPANT	\N	PRESENT	0
783695	783380	17965H	PARTICIPANT	\N	PRESENT	0
783696	783380	19723Y	PARTICIPANT	\N	PRESENT	0
783697	783380	21046E	PARTICIPANT	\N	PRESENT	0
783698	783380	19713W	PARTICIPANT	\N	PRESENT	0
783699	783380	18193Q	PARTICIPANT	\N	PRESENT	0
783700	783380	14071N	PARTICIPANT	\N	PRESENT	0
783701	783380	21055F	PARTICIPANT	\N	PRESENT	0
783720	783380	21048G	PARTICIPANT	\N	PRESENT	0
783703	783380	11090Q	PARTICIPANT	\N	PRESENT	0
783704	783380	19760E	PARTICIPANT	\N	PRESENT	0
783705	783380	21071F	PARTICIPANT	\N	PRESENT	0
783706	783380	19335Q	PARTICIPANT	\N	PRESENT	0
783721	783380	20130U	PARTICIPANT	\N	PRESENT	0
783708	783380	20062A	PARTICIPANT	\N	PRESENT	0
783709	783380	19703U	PARTICIPANT	\N	PRESENT	0
783710	783380	21045D	PARTICIPANT	\N	PRESENT	0
783711	783380	20090E	PARTICIPANT	\N	PRESENT	0
783722	783380	14083S	PARTICIPANT	\N	PRESENT	0
783713	783380	14215L	PARTICIPANT	\N	PRESENT	0
783714	783380	19531S	PARTICIPANT	\N	PRESENT	0
783715	783380	21056G	PARTICIPANT	\N	PRESENT	0
783716	783380	20138D	PARTICIPANT	\N	PRESENT	0
783717	783380	07029T	PARTICIPANT	\N	PRESENT	0
783718	783380	20058E	PARTICIPANT	\N	PRESENT	0
783880	783366	19866P	PARTICIPANT	\N	EXCUSE	0
783882	783366	14355X	PARTICIPANT	\N	EXCUSE	0
783938	783936	04042C	PARTICIPANT	\N	PRESENT	0
783939	783936	14069U	PARTICIPANT	\N	PRESENT	0
783940	783936	21046E	PARTICIPANT	\N	PRESENT	0
783941	783936	19545Y	PARTICIPANT	\N	PRESENT	0
783943	783936	19647E	PARTICIPANT	\N	PRESENT	0
783944	783936	14179A	PARTICIPANT	\N	PRESENT	0
783945	783936	08015R	PARTICIPANT	\N	PRESENT	0
783946	783936	08034U	PARTICIPANT	\N	PRESENT	0
783947	783936	21087P	PARTICIPANT	\N	PRESENT	0
783951	783936	21058J	PARTICIPANT	\N	PRESENT	0
783953	783936	14169X	PARTICIPANT	\N	PRESENT	0
783954	783936	04045F	PARTICIPANT	\N	PRESENT	0
783955	783936	20062A	PARTICIPANT	\N	PRESENT	0
783956	783936	20064C	PARTICIPANT	\N	PRESENT	0
783960	783936	14147R	PARTICIPANT	\N	PRESENT	0
784493	784491	19691J	PARTICIPANT	\N	PRESENT	0
784495	784491	14281W	PARTICIPANT	\N	PRESENT	0
784496	784491	19703U	PARTICIPANT	\N	PRESENT	0
784498	784491	18193Q	PARTICIPANT	\N	PRESENT	0
784499	784491	20130U	PARTICIPANT	\N	PRESENT	0
784500	784491	01034P	PARTICIPANT	\N	PRESENT	0
784511	784038	19421M	PARTICIPANT	\N	PRESENT	0
785164	780475	19699S	PARTICIPANT	\N	PRESENT	0
785165	780475	21055F	PARTICIPANT	\N	PRESENT	0
785166	780475	14073Q	PARTICIPANT	\N	PRESENT	0
785167	780475	20138D	PARTICIPANT	\N	PRESENT	0
785168	780475	20142Y	PARTICIPANT	\N	PRESENT	0
785169	780475	19693L	PARTICIPANT	\N	PRESENT	0
785170	780475	20102Q	PARTICIPANT	\N	PRESENT	0
785171	780475	20052X	PARTICIPANT	\N	PRESENT	0
785172	780475	14229S	PARTICIPANT	\N	PRESENT	0
785173	780475	20056C	PARTICIPANT	\N	PRESENT	0
785174	780475	20180F	PARTICIPANT	\N	PRESENT	0
785175	780475	20264J	PARTICIPANT	\N	PRESENT	0
785176	780475	18395Y	PARTICIPANT	\N	PRESENT	0
785177	780475	20026V	PARTICIPANT	\N	PRESENT	0
785179	780475	21058J	PARTICIPANT	\N	EXCUSE	0
785180	780475	21089R	PARTICIPANT	\N	EXCUSE	0
785181	780475	21091K	PARTICIPANT	\N	EXCUSE	0
785182	780475	19593H	PARTICIPANT	\N	PRESENT	0
785198	785196	14255U	PARTICIPANT	\N	PRESENT	0
785199	785196	19701S	PARTICIPANT	\N	PRESENT	0
785200	785196	19693L	PARTICIPANT	\N	PRESENT	0
785201	785196	20068G	PARTICIPANT	\N	PRESENT	0
785202	785196	20180F	PARTICIPANT	\N	PRESENT	0
785203	785196	14179A	PARTICIPANT	\N	PRESENT	0
785204	785196	20064C	PARTICIPANT	\N	PRESENT	0
785205	785196	04092N	PARTICIPANT	\N	PRESENT	0
785206	785196	14001X	PARTICIPANT	\N	PRESENT	0
785207	785196	14031R	PARTICIPANT	\N	PRESENT	0
785210	783403	04047H	PRESIDENT	0	PRESENT	0
785211	783403	14151M	PARTICIPANT	\N	PRESENT	0
785212	783403	05008E	PARTICIPANT	\N	PRESENT	0
785213	783403	19489J	PARTICIPANT	\N	PRESENT	0
785214	783403	20036X	PARTICIPANT	\N	PRESENT	0
785215	783403	10015M	PARTICIPANT	\N	PRESENT	0
785216	783403	11072N	PARTICIPANT	\N	PRESENT	0
785217	783403	08018U	PARTICIPANT	\N	PRESENT	0
785218	783403	14259Y	PARTICIPANT	\N	PRESENT	0
785219	783403	18207D	PARTICIPANT	\N	PRESENT	0
785220	783403	14111D	PARTICIPANT	\N	PRESENT	0
785221	783403	14147R	PARTICIPANT	\N	PRESENT	0
785222	783403	14215L	PARTICIPANT	\N	PRESENT	0
785223	783403	21043B	PARTICIPANT	\N	PRESENT	0
785225	783403	18231D	PARTICIPANT	\N	PRESENT	0
785226	783403	19673G	PARTICIPANT	\N	PRESENT	0
785227	783403	21044C	PARTICIPANT	\N	PRESENT	0
785228	783403	21038E	PARTICIPANT	\N	PRESENT	0
785229	783403	21056G	PARTICIPANT	\N	PRESENT	0
785230	783403	14089Y	PARTICIPANT	\N	PRESENT	0
785232	783403	14231L	PARTICIPANT	\N	PRESENT	0
785233	783403	14069U	PARTICIPANT	\N	PRESENT	0
785267	783403	21057H	PARTICIPANT	\N	PRESENT	0
785270	783403	19111A	PARTICIPANT	\N	PRESENT	0
785313	783403	14053L	PARTICIPANT	\N	PRESENT	0
785314	783403	20022R	PARTICIPANT	\N	PRESENT	0
785321	785320	14357A	PARTICIPANT	\N	PRESENT	0
785322	785320	21058J	PARTICIPANT	\N	PRESENT	0
785323	785320	14147R	PARTICIPANT	\N	PRESENT	0
785324	785320	14169X	PARTICIPANT	\N	PRESENT	0
785325	785320	20126Y	PARTICIPANT	\N	PRESENT	0
768994	768993	21052C	PARTICIPANT	\N	PRESENT	0
768995	768993	14083S	PARTICIPANT	\N	PRESENT	0
768996	768993	20248J	PARTICIPANT	\N	PRESENT	0
768997	768993	19347U	PARTICIPANT	\N	PRESENT	0
768998	768993	08015R	PARTICIPANT	\N	PRESENT	0
768999	768993	21058J	PARTICIPANT	\N	PRESENT	0
769000	768993	21040X	PARTICIPANT	\N	PRESENT	0
769051	768993	21039F	PARTICIPANT	\N	PRESENT	0
769052	768993	20054A	PRESIDENT	0	PRESENT	0
769053	768993	21064G	PARTICIPANT	\N	PRESENT	0
769054	768993	21051B	PARTICIPANT	\N	PRESENT	0
769055	768993	21061D	PARTICIPANT	\N	PRESENT	0
769056	768993	14237S	PARTICIPANT	\N	EXCUSE	0
769057	768993	21044C	PARTICIPANT	\N	EXCUSE	0
769058	768993	21050A	PARTICIPANT	\N	EXCUSE	0
769059	768993	21080G	PARTICIPANT	\N	EXCUSE	0
769060	768993	20144B	PARTICIPANT	\N	EXCUSE	0
769061	768993	19545Y	PARTICIPANT	\N	EXCUSE	0
769062	768993	20126Y	PARTICIPANT	\N	EXCUSE	0
769063	768993	20056C	PARTICIPANT	\N	EXCUSE	0
769064	768993	19697Q	PARTICIPANT	\N	EXCUSE	0
769065	768993	20088L	PARTICIPANT	\N	EXCUSE	0
769066	768993	20038A	PARTICIPANT	\N	EXCUSE	0
769067	768993	21047F	PARTICIPANT	\N	EXCUSE	0
772714	769254	19301E	PARTICIPANT	\N	PRESENT	0
772715	769254	11048N	PARTICIPANT	\N	PRESENT	0
772716	769254	20086J	PARTICIPANT	\N	PRESENT	0
772717	769254	20032T	PARTICIPANT	\N	PRESENT	0
772718	769254	20062A	PARTICIPANT	\N	PRESENT	0
772719	769254	19711U	PARTICIPANT	\N	PRESENT	0
772720	769254	21095P	PARTICIPANT	\N	PRESENT	0
772721	769254	20044X	PARTICIPANT	\N	PRESENT	0
772722	769254	19667J	PARTICIPANT	\N	PRESENT	0
772723	769254	08010L	PARTICIPANT	\N	PRESENT	0
772724	769254	11070L	PARTICIPANT	\N	PRESENT	0
772725	769254	14083S	PARTICIPANT	\N	PRESENT	0
772726	769254	21079P	PARTICIPANT	\N	PRESENT	0
772727	769254	20036X	PARTICIPANT	\N	PRESENT	0
772728	769254	19687N	PARTICIPANT	\N	PRESENT	0
772729	769254	11040E	PARTICIPANT	\N	PRESENT	0
772730	769254	21048G	PARTICIPANT	\N	PRESENT	0
772731	769254	12016W	PARTICIPANT	\N	PRESENT	0
772732	769254	20080C	PARTICIPANT	\N	PRESENT	0
772733	769254	14121F	PARTICIPANT	\N	PRESENT	0
772734	769254	21082J	PARTICIPANT	\N	PRESENT	0
772735	769254	20054A	PARTICIPANT	\N	PRESENT	0
772736	769254	08034U	PARTICIPANT	\N	PRESENT	0
772737	769254	99004R	PARTICIPANT	\N	PRESENT	0
772738	769254	19647E	PARTICIPANT	\N	PRESENT	0
772739	769254	20094J	PARTICIPANT	\N	PRESENT	0
772740	769254	07029T	PARTICIPANT	\N	PRESENT	0
772741	769254	21090J	PARTICIPANT	\N	PRESENT	0
772742	769254	20116W	PARTICIPANT	\N	PRESENT	0
772743	769254	19349W	PARTICIPANT	\N	PRESENT	0
772744	769254	19545Y	PARTICIPANT	\N	PRESENT	0
772745	769254	14327T	PARTICIPANT	\N	PRESENT	0
772746	769254	20034V	PARTICIPANT	\N	PRESENT	0
772747	769254	20024T	PARTICIPANT	\N	PRESENT	0
772748	769254	14225N	PARTICIPANT	\N	PRESENT	0
772749	769254	11074Q	PARTICIPANT	\N	PRESENT	0
772750	769254	19701S	PARTICIPANT	\N	PRESENT	0
772751	769254	20134Y	PARTICIPANT	\N	PRESENT	0
772752	769254	19619A	PARTICIPANT	\N	PRESENT	0
772753	769254	21092L	PARTICIPANT	\N	PRESENT	0
772754	769254	19533U	PARTICIPANT	\N	PRESENT	0
772755	769254	21088Q	PARTICIPANT	\N	PRESENT	0
772759	769254	08073C	PARTICIPANT	\N	PRESENT	0
772757	769254	19331L	PARTICIPANT	\N	PRESENT	0
772758	769254	20148F	PARTICIPANT	\N	PRESENT	0
772760	769254	21037D	PARTICIPANT	\N	PRESENT	0
772761	769254	21060C	PARTICIPANT	\N	PRESENT	0
772762	769254	19820Y	PARTICIPANT	\N	PRESENT	0
772809	769255	99004R	PARTICIPANT	\N	PRESENT	0
772810	769255	20034V	PARTICIPANT	\N	PRESENT	0
772811	769255	11040E	PARTICIPANT	\N	PRESENT	0
772812	769255	19711U	PARTICIPANT	\N	PRESENT	0
772813	769255	11048N	PARTICIPANT	\N	PRESENT	0
772814	769255	14225N	PARTICIPANT	\N	PRESENT	0
772815	769255	20080C	PARTICIPANT	\N	PRESENT	0
772816	769255	20024T	PARTICIPANT	\N	PRESENT	0
772817	769255	20148F	PARTICIPANT	\N	PRESENT	0
772818	769255	12016W	PARTICIPANT	\N	PRESENT	0
772819	769255	21037D	PARTICIPANT	\N	PRESENT	0
772820	769255	19647E	PARTICIPANT	\N	PRESENT	0
772821	769255	19349W	PARTICIPANT	\N	PRESENT	0
772822	769255	20134Y	PARTICIPANT	\N	PRESENT	0
772823	769255	21096Q	PARTICIPANT	\N	PRESENT	0
772824	769255	19619A	PARTICIPANT	\N	PRESENT	0
772825	769255	19667J	PARTICIPANT	\N	PRESENT	0
772826	769255	20054A	PARTICIPANT	\N	PRESENT	0
772827	769255	20086J	PARTICIPANT	\N	PRESENT	0
772828	769255	21079P	PARTICIPANT	\N	PRESENT	0
772829	769255	19687N	PARTICIPANT	\N	PRESENT	0
772830	769255	14327T	PARTICIPANT	\N	PRESENT	0
772831	769255	07004J	PARTICIPANT	\N	PRESENT	0
772832	769255	20062A	PARTICIPANT	\N	PRESENT	0
772833	769255	20032T	PARTICIPANT	\N	PRESENT	0
772834	769255	21060C	PARTICIPANT	\N	PRESENT	0
772835	769255	20036X	PARTICIPANT	\N	PRESENT	0
772836	769255	20116W	PARTICIPANT	\N	PRESENT	0
772837	769255	08073C	PARTICIPANT	\N	PRESENT	0
772838	769255	21092L	PARTICIPANT	\N	PRESENT	0
772839	769255	07029T	PARTICIPANT	\N	PRESENT	0
772840	769255	11070L	PARTICIPANT	\N	PRESENT	0
772841	769255	14121F	PARTICIPANT	\N	PRESENT	0
772842	769255	21048G	PARTICIPANT	\N	PRESENT	0
772843	769255	19545Y	PARTICIPANT	\N	PRESENT	0
772844	769255	20044X	PARTICIPANT	\N	PRESENT	0
772845	769255	08034U	PARTICIPANT	\N	PRESENT	0
772846	769255	11053K	PARTICIPANT	\N	PRESENT	0
772847	769255	20094J	PARTICIPANT	\N	PRESENT	0
772854	769255	19820Y	PARTICIPANT	\N	PRESENT	0
772849	769255	21032X	PARTICIPANT	\N	PRESENT	0
772850	769255	08010L	PARTICIPANT	\N	PRESENT	0
772851	769255	21063F	PARTICIPANT	\N	PRESENT	0
772852	769255	19621T	PARTICIPANT	\N	PRESENT	0
772807	769255	11090Q	PARTICIPANT	\N	PRESENT	0
772808	769255	21090J	PARTICIPANT	\N	PRESENT	0
772853	769255	19533U	PARTICIPANT	\N	PRESENT	0
772855	769255	20070A	PARTICIPANT	\N	PRESENT	0
772856	769255	14173T	PARTICIPANT	\N	PRESENT	0
772857	769255	19573D	PARTICIPANT	\N	PRESENT	0
772858	769255	19301E	PARTICIPANT	\N	PRESENT	0
772859	769255	19399H	PARTICIPANT	\N	PRESENT	0
772860	769255	21082J	PARTICIPANT	\N	PRESENT	0
772861	769255	14253S	PARTICIPANT	\N	PRESENT	0
772862	769255	21088Q	PARTICIPANT	\N	PRESENT	0
772863	769255	19551W	PARTICIPANT	\N	PRESENT	0
772864	769255	21084L	PARTICIPANT	\N	PRESENT	0
772865	769255	14071N	PARTICIPANT	\N	PRESENT	0
772866	769255	21071F	PARTICIPANT	\N	PRESENT	0
772867	769255	21046E	PARTICIPANT	\N	PRESENT	0
772868	769255	14189C	PARTICIPANT	\N	PRESENT	0
772869	769255	19657G	PARTICIPANT	\N	PRESENT	0
772870	769255	21072G	PARTICIPANT	\N	PRESENT	0
772871	769255	14331P	PARTICIPANT	\N	PRESENT	0
772872	769255	19479G	PARTICIPANT	\N	PRESENT	0
772873	769255	04042C	PARTICIPANT	\N	PRESENT	0
772874	769255	11085T	PARTICIPANT	\N	PRESENT	0
789984	776125	19565D	PARTICIPANT	\N	PRESENT	0
789985	776125	19251M	PARTICIPANT	\N	PRESENT	0
789986	776125	20126Y	PARTICIPANT	\N	PRESENT	0
790110	790109	14193X	PARTICIPANT	\N	PRESENT	0
790111	790109	19421M	PARTICIPANT	\N	PRESENT	0
790112	790109	19565D	PARTICIPANT	\N	PRESENT	0
790113	790109	17737W	PARTICIPANT	\N	PRESENT	0
790114	790109	19709B	PARTICIPANT	\N	PRESENT	0
790115	790109	20128B	PARTICIPANT	\N	PRESENT	0
790116	790109	11115U	PARTICIPANT	\N	PRESENT	0
790117	790109	11027H	PARTICIPANT	\N	PRESENT	0
794715	794714	08009T	PARTICIPANT	\N	PRESENT	0
794630	791719	21055F	PARTICIPANT	\N	PRESENT	0
794631	793148	14073Q	PARTICIPANT	\N	EXCUSE	0
794649	794605	21084L	PARTICIPANT	\N	PRESENT	0
794650	794605	21082J	PARTICIPANT	\N	PRESENT	0
794651	794605	19782L	PARTICIPANT	\N	PRESENT	0
794652	794605	21031W	PARTICIPANT	\N	PRESENT	0
794653	794605	08034U	PARTICIPANT	\N	PRESENT	0
794654	794605	14031R	PARTICIPANT	\N	PRESENT	0
794655	794605	19413M	PARTICIPANT	\N	PRESENT	0
794656	794605	21090J	PARTICIPANT	\N	PRESENT	0
794657	794605	99004R	PRESIDENT	0	PRESENT	0
794658	794605	11090Q	PARTICIPANT	\N	PRESENT	0
794659	794605	21093M	PARTICIPANT	\N	PRESENT	0
794716	794714	14169X	PARTICIPANT	\N	PRESENT	0
794717	794714	10015M	PARTICIPANT	\N	PRESENT	0
794718	794714	21084L	PARTICIPANT	\N	PRESENT	0
794719	794714	19713W	PARTICIPANT	\N	PRESENT	0
794720	794714	20042V	PARTICIPANT	\N	PRESENT	0
794722	794721	20086J	PARTICIPANT	\N	PRESENT	0
794723	794721	14255U	PARTICIPANT	\N	PRESENT	0
794724	794721	18083K	PARTICIPANT	\N	PRESENT	0
794725	794721	11065P	PARTICIPANT	\N	PRESENT	0
794726	794721	19673G	PARTICIPANT	\N	PRESENT	0
794727	794721	14033T	PARTICIPANT	\N	PRESENT	0
794728	794721	21093M	PARTICIPANT	\N	PRESENT	0
794729	794721	19531S	PARTICIPANT	\N	PRESENT	0
794730	794721	08015R	PARTICIPANT	\N	PRESENT	0
794731	794721	04045F	PARTICIPANT	\N	PRESENT	0
794733	794732	04033B	PARTICIPANT	\N	PRESENT	0
794734	794732	19251M	PARTICIPANT	\N	PRESENT	0
794736	794735	20024T	PARTICIPANT	\N	PRESENT	0
794737	794735	20114U	PARTICIPANT	\N	PRESENT	0
794738	794735	11056N	PARTICIPANT	\N	PRESENT	0
794739	794735	20180F	PARTICIPANT	\N	PRESENT	0
794740	794735	20106U	PARTICIPANT	\N	PRESENT	0
794741	794735	19649G	PARTICIPANT	\N	PRESENT	0
794742	794735	19723Y	PARTICIPANT	\N	PRESENT	0
794743	794735	14059S	PARTICIPANT	\N	PRESENT	0
794744	794735	20142Y	PARTICIPANT	\N	PRESENT	0
794745	794735	21053D	PARTICIPANT	\N	PRESENT	0
794746	794735	21094N	PARTICIPANT	\N	PRESENT	0
794747	794735	20058E	PARTICIPANT	\N	PRESENT	0
794748	794735	20082E	PARTICIPANT	\N	PRESENT	0
794749	794735	20118Y	PARTICIPANT	\N	PRESENT	0
794755	794750	14255U	PARTICIPANT	\N	EXCUSE	0
794819	794818	12028B	PARTICIPANT	\N	PRESENT	0
794820	794818	14267Y	PARTICIPANT	\N	PRESENT	0
794821	794818	08010L	PARTICIPANT	\N	PRESENT	0
794842	794841	14237S	PARTICIPANT	\N	PRESENT	0
794843	794841	04045F	PARTICIPANT	\N	PRESENT	0
794844	794841	14069U	PARTICIPANT	\N	PRESENT	0
794845	794841	20114U	PARTICIPANT	\N	PRESENT	0
794846	794841	14267Y	PARTICIPANT	\N	PRESENT	0
794847	794841	14073Q	PARTICIPANT	\N	PRESENT	0
794848	794841	14111D	PARTICIPANT	\N	PRESENT	0
794849	794841	14221J	PARTICIPANT	\N	PRESENT	0
794864	794863	21084L	PARTICIPANT	\N	PRESENT	0
794865	794863	99004R	PRESIDENT	0	PRESENT	0
794866	794863	21093M	PARTICIPANT	\N	PRESENT	0
794867	794863	19782L	PARTICIPANT	\N	EXCUSE	0
794868	794863	21031W	PARTICIPANT	\N	EXCUSE	0
794869	794863	14031R	PARTICIPANT	\N	EXCUSE	0
794870	794863	19413M	PARTICIPANT	\N	EXCUSE	0
794871	794863	21090J	PARTICIPANT	\N	EXCUSE	0
794921	794920	18395Y	PARTICIPANT	\N	PRESENT	0
794922	794920	21059K	PARTICIPANT	\N	PRESENT	0
794984	794708	14053L	PARTICIPANT	\N	PRESENT	0
794985	794896	21046E	PARTICIPANT	\N	PRESENT	0
794986	794896	14331P	PARTICIPANT	\N	PRESENT	0
794987	794896	20140W	PARTICIPANT	\N	PRESENT	0
794988	794896	14191V	PARTICIPANT	\N	PRESENT	0
794989	794896	19565D	PARTICIPANT	\N	PRESENT	0
794990	794896	11074Q	PARTICIPANT	\N	PRESENT	0
794991	794896	14215L	PARTICIPANT	\N	PRESENT	0
794992	794896	19695N	PARTICIPANT	\N	PRESENT	0
794993	794896	21049H	PARTICIPANT	\N	PRESENT	0
794994	794896	21034A	PARTICIPANT	\N	PRESENT	0
794995	794896	11040E	PARTICIPANT	\N	PRESENT	0
794996	794896	04047H	PARTICIPANT	\N	PRESENT	0
794997	794896	99004R	PARTICIPANT	\N	PRESENT	0
794999	794896	20062A	PARTICIPANT	\N	PRESENT	0
795000	794896	19798U	PARTICIPANT	\N	PRESENT	0
795001	794896	20044X	PARTICIPANT	\N	PRESENT	0
795002	794896	20022R	PARTICIPANT	\N	PRESENT	0
795003	794896	14071N	PARTICIPANT	\N	PRESENT	0
795004	794896	14213J	PARTICIPANT	\N	PRESENT	0
795005	794896	20054A	PARTICIPANT	\N	PRESENT	0
795006	794896	19399H	PARTICIPANT	\N	PRESENT	0
795007	794896	20038A	PARTICIPANT	\N	PRESENT	0
795008	794896	21039F	PARTICIPANT	\N	PRESENT	0
795009	794896	21058J	PARTICIPANT	\N	PRESENT	0
795010	794896	21093M	PARTICIPANT	\N	PRESENT	0
795011	794896	20092G	PARTICIPANT	\N	PRESENT	0
795012	794896	20100N	PARTICIPANT	\N	PRESENT	0
795013	794896	21035B	PARTICIPANT	\N	PRESENT	0
795014	794896	21056G	PARTICIPANT	\N	PRESENT	0
795015	794896	21073H	PARTICIPANT	\N	PRESENT	0
795016	794896	21059K	PARTICIPANT	\N	PRESENT	0
795017	794896	21051B	PARTICIPANT	\N	PRESENT	0
795018	794896	05012A	PARTICIPANT	\N	PRESENT	0
795019	794896	14281W	PARTICIPANT	\N	PRESENT	0
795020	794896	19551W	PARTICIPANT	\N	PRESENT	0
795021	794896	19251M	PARTICIPANT	\N	PRESENT	0
795022	794896	17779H	PARTICIPANT	\N	PRESENT	0
795023	794896	20080C	PARTICIPANT	\N	PRESENT	0
795024	794896	11043H	PARTICIPANT	\N	PRESENT	0
795025	794896	21083K	PARTICIPANT	\N	PRESENT	0
795026	794896	14053L	PARTICIPANT	\N	PRESENT	0
795027	794896	19335Q	PARTICIPANT	\N	PRESENT	0
795028	794896	20134Y	PARTICIPANT	\N	PRESENT	0
795029	794896	04033B	PARTICIPANT	\N	PRESENT	0
795030	794896	20146D	PARTICIPANT	\N	PRESENT	0
795031	794896	08073C	PARTICIPANT	\N	PRESENT	0
795032	794896	04045F	PARTICIPANT	\N	PRESENT	0
795033	794896	20128B	PARTICIPANT	\N	PRESENT	0
795034	794896	19866P	PARTICIPANT	\N	PRESENT	0
795035	794896	21062E	PARTICIPANT	\N	PRESENT	0
795036	794896	21084L	PARTICIPANT	\N	PRESENT	0
795037	794896	04092N	PARTICIPANT	\N	PRESENT	0
795038	794896	20018V	PARTICIPANT	\N	PRESENT	0
795039	794896	19760E	PARTICIPANT	\N	PRESENT	0
795040	794896	08034U	PARTICIPANT	\N	PRESENT	0
795041	794896	21030V	PARTICIPANT	\N	PRESENT	0
795042	794896	21067K	PARTICIPANT	\N	PRESENT	0
795043	794896	17965H	PARTICIPANT	\N	PRESENT	0
795044	794896	19621T	PARTICIPANT	\N	PRESENT	0
795045	794896	20102Q	PARTICIPANT	\N	PRESENT	0
795046	794896	14001X	PARTICIPANT	\N	PRESENT	0
795047	794896	19820Y	PARTICIPANT	\N	PRESENT	0
795157	794896	14026U	PARTICIPANT	\N	PRESENT	0
795160	794896	11053K	PARTICIPANT	\N	PRESENT	0
795161	794896	11115U	PARTICIPANT	\N	PRESENT	0
795162	794896	14327T	PARTICIPANT	\N	PRESENT	0
795163	794896	18395Y	PARTICIPANT	\N	PRESENT	0
795164	794896	21060C	PARTICIPANT	\N	PRESENT	0
795165	794896	15197G	PARTICIPANT	\N	PRESENT	0
795166	794896	20122U	PARTICIPANT	\N	PRESENT	0
795167	794896	19611R	PARTICIPANT	\N	PRESENT	0
795168	794896	19111A	PARTICIPANT	\N	PRESENT	0
795169	794896	20286Q	PARTICIPANT	\N	PRESENT	0
795170	794896	19553Y	PARTICIPANT	\N	PRESENT	0
795171	794896	14223L	PARTICIPANT	\N	PRESENT	0
795172	794896	98022P	PARTICIPANT	\N	PRESENT	0
795173	794896	21066J	PARTICIPANT	\N	PRESENT	0
795174	794896	21032X	PARTICIPANT	\N	PRESENT	0
769879	769234	14357A	PARTICIPANT	\N	PRESENT	0
769880	769234	20172F	PARTICIPANT	\N	PRESENT	0
769881	769234	19383Y	PARTICIPANT	\N	PRESENT	0
769882	769234	20054A	PARTICIPANT	\N	PRESENT	0
769883	769234	14073Q	PARTICIPANT	\N	PRESENT	0
769884	769234	01034P	PARTICIPANT	\N	PRESENT	0
769885	769234	19619A	PARTICIPANT	\N	PRESENT	0
769886	769234	20034V	PARTICIPANT	\N	PRESENT	0
769887	769234	14030Q	PARTICIPANT	\N	PRESENT	0
769888	769234	21050A	PARTICIPANT	\N	PRESENT	0
769889	769234	14189C	PARTICIPANT	\N	PRESENT	0
769890	769234	21064G	PARTICIPANT	\N	PRESENT	0
769891	769234	20100N	PARTICIPANT	\N	PRESENT	0
769901	769234	14251Q	PARTICIPANT	\N	PRESENT	0
769893	769234	11065P	PARTICIPANT	\N	PRESENT	0
769894	769234	19735D	PARTICIPANT	\N	PRESENT	0
769895	769234	19721W	PARTICIPANT	\N	PRESENT	0
769896	769234	14042U	PARTICIPANT	\N	PRESENT	0
769897	769234	07004J	PARTICIPANT	\N	PRESENT	0
769898	769234	14205J	PARTICIPANT	\N	PRESENT	0
769899	769234	14089Y	PARTICIPANT	\N	PRESENT	0
769900	769234	19611R	PARTICIPANT	\N	PRESENT	0
769902	769234	86034E	PARTICIPANT	\N	PRESENT	0
769903	769234	14071N	PARTICIPANT	\N	PRESENT	0
769904	769234	20066E	PARTICIPANT	\N	PRESENT	0
769905	769234	14219Q	PARTICIPANT	\N	PRESENT	0
769906	769234	95041E	PARTICIPANT	\N	PRESENT	0
769907	769234	19699S	PARTICIPANT	\N	PRESENT	0
769908	769234	20052X	PARTICIPANT	\N	PRESENT	0
769909	769234	20092G	PARTICIPANT	\N	PRESENT	0
769914	769234	11056N	PARTICIPANT	\N	PRESENT	0
769911	769234	08015R	PARTICIPANT	\N	PRESENT	0
769912	769234	19687N	PARTICIPANT	\N	PRESENT	0
769913	769234	11053K	PARTICIPANT	\N	PRESENT	0
769915	769234	08061X	PARTICIPANT	\N	PRESENT	0
769916	769234	11048N	PARTICIPANT	\N	PRESENT	0
769917	769234	19573D	PARTICIPANT	\N	PRESENT	0
769925	769234	14151M	PARTICIPANT	\N	PRESENT	0
769919	769234	20128B	PARTICIPANT	\N	PRESENT	0
769920	769234	21033Y	PARTICIPANT	\N	PRESENT	0
769921	769234	20112S	PARTICIPANT	\N	PRESENT	0
769922	769234	20142Y	PARTICIPANT	\N	PRESENT	0
769923	769234	20048C	PARTICIPANT	\N	PRESENT	0
769924	769234	11085T	PARTICIPANT	\N	PRESENT	0
769926	769234	19551W	PARTICIPANT	\N	PRESENT	0
769927	769234	19507S	PARTICIPANT	\N	PRESENT	0
769928	769234	21060C	PARTICIPANT	\N	PRESENT	0
769929	769234	14179A	PARTICIPANT	\N	PRESENT	0
769930	769234	21036C	PARTICIPANT	\N	PRESENT	0
769931	769234	14267Y	PARTICIPANT	\N	PRESENT	0
769932	769234	20108W	PARTICIPANT	\N	PRESENT	0
769933	769234	08069G	PARTICIPANT	\N	PRESENT	0
769934	769234	14259Y	PARTICIPANT	\N	PRESENT	0
769935	769234	21048G	PARTICIPANT	\N	PRESENT	0
769936	769234	20106U	PARTICIPANT	\N	PRESENT	0
769937	769234	21032X	PARTICIPANT	\N	PRESENT	0
769938	769234	20094J	PARTICIPANT	\N	PRESENT	0
769939	769234	08012N	PARTICIPANT	\N	PRESENT	0
769940	769234	19421M	PARTICIPANT	\N	PRESENT	0
769941	769234	14083S	PARTICIPANT	\N	PRESENT	0
769942	769234	20026V	PARTICIPANT	\N	PRESENT	0
769943	769234	20150Y	PARTICIPANT	\N	PRESENT	0
769944	769234	21066J	PARTICIPANT	\N	PRESENT	0
769945	769234	17367Q	PARTICIPANT	\N	PRESENT	0
769946	769234	20138D	PARTICIPANT	\N	PRESENT	0
769947	769234	20180F	PARTICIPANT	\N	PRESENT	0
769953	769234	21083K	PARTICIPANT	\N	PRESENT	0
769954	769234	04047H	PARTICIPANT	\N	PRESENT	0
769955	769234	14123H	PARTICIPANT	\N	PRESENT	0
769956	769234	20136B	PARTICIPANT	\N	PRESENT	0
769957	769234	21069M	PARTICIPANT	\N	PRESENT	0
769958	769234	14069U	PARTICIPANT	\N	PRESENT	0
769962	769234	21085M	PARTICIPANT	\N	PRESENT	0
769960	769234	21092L	PARTICIPANT	\N	PRESENT	0
769974	769234	21076L	PARTICIPANT	\N	PRESENT	0
769966	769234	21061D	PARTICIPANT	\N	PRESENT	0
769967	769234	19701S	PARTICIPANT	\N	PRESENT	0
769975	769234	04042C	PARTICIPANT	\N	PRESENT	0
770296	769235	19479G	PARTICIPANT	\N	PRESENT	0
770297	769235	19820Y	PARTICIPANT	\N	PRESENT	0
770301	769235	21048G	PARTICIPANT	\N	PRESENT	0
770299	769235	20086J	PARTICIPANT	\N	PRESENT	0
770300	769235	21065H	PARTICIPANT	\N	PRESENT	0
770302	769235	21053D	PARTICIPANT	\N	PRESENT	0
770303	769235	20046A	PARTICIPANT	\N	PRESENT	0
770304	769235	19387D	PARTICIPANT	\N	PRESENT	0
770337	769235	18083K	PARTICIPANT	\N	PRESENT	0
770306	769235	20024T	PARTICIPANT	\N	PRESENT	0
770307	769235	20104S	PARTICIPANT	\N	PRESENT	0
770308	769235	19619A	PARTICIPANT	\N	PRESENT	0
770309	769235	21059K	PARTICIPANT	\N	PRESENT	0
770346	769235	14021P	PARTICIPANT	\N	PRESENT	0
770311	769235	21082J	PARTICIPANT	\N	PRESENT	0
770312	769235	14031R	PARTICIPANT	\N	PRESENT	0
770313	769235	20124W	PARTICIPANT	\N	PRESENT	0
770314	769235	20056C	PARTICIPANT	\N	PRESENT	0
770315	769235	14257W	PARTICIPANT	\N	PRESENT	0
770321	769235	14055N	PARTICIPANT	\N	PRESENT	0
770322	769235	20090E	PARTICIPANT	\N	PRESENT	0
770323	769235	21035B	PARTICIPANT	\N	PRESENT	0
770324	769235	21060C	PARTICIPANT	\N	PRESENT	0
770325	769235	20080C	PARTICIPANT	\N	PRESENT	0
770326	769235	14097Y	PARTICIPANT	\N	PRESENT	0
770327	769235	21062E	PARTICIPANT	\N	PRESENT	0
770328	769235	21087P	PARTICIPANT	\N	PRESENT	0
770329	769235	20098N	PARTICIPANT	\N	PRESENT	0
770330	769235	20030R	PARTICIPANT	\N	PRESENT	0
770331	769235	08061X	PARTICIPANT	\N	PRESENT	0
770332	769235	21097R	PARTICIPANT	\N	PRESENT	0
770333	769235	18207D	PARTICIPANT	\N	PRESENT	0
770334	769235	21067K	PARTICIPANT	\N	PRESENT	0
770335	769235	20112S	PARTICIPANT	\N	PRESENT	0
770336	769235	19399H	PARTICIPANT	\N	PRESENT	0
770338	769235	19703U	PARTICIPANT	\N	PRESENT	0
770339	769235	19631V	PARTICIPANT	\N	PRESENT	0
770340	769235	14147R	PARTICIPANT	\N	PRESENT	0
770341	769235	20106U	PARTICIPANT	\N	PRESENT	0
770345	769235	20118Y	PARTICIPANT	\N	PRESENT	0
770343	769235	12016W	PARTICIPANT	\N	PRESENT	0
770344	769235	20180F	PARTICIPANT	\N	PRESENT	0
770347	769235	20032T	PARTICIPANT	\N	PRESENT	0
770348	769235	18193Q	PARTICIPANT	\N	PRESENT	0
770349	769235	19954N	PARTICIPANT	\N	PRESENT	0
770350	769235	20026V	PARTICIPANT	\N	PRESENT	0
770351	769235	21040X	PARTICIPANT	\N	PRESENT	0
770352	769235	14223L	PARTICIPANT	\N	PRESENT	0
770353	769235	19798U	PARTICIPANT	\N	PRESENT	0
770354	769235	21066J	PARTICIPANT	\N	PRESENT	0
770355	769235	21093M	PARTICIPANT	\N	PRESENT	0
770356	769235	19758L	PARTICIPANT	\N	PRESENT	0
770357	769235	14089Y	PARTICIPANT	\N	PRESENT	0
770358	769235	14123H	PARTICIPANT	\N	PRESENT	0
770359	769235	14191V	PARTICIPANT	\N	PRESENT	0
770360	769235	14069U	PARTICIPANT	\N	PRESENT	0
770361	769235	14030Q	PARTICIPANT	\N	PRESENT	0
770362	769235	19563B	PARTICIPANT	\N	PRESENT	0
770363	769235	04045F	PARTICIPANT	\N	PRESENT	0
770364	769235	21086N	PARTICIPANT	\N	PRESENT	0
770365	769235	20038A	PARTICIPANT	\N	PRESENT	0
770366	769235	11110B	PARTICIPANT	\N	PRESENT	0
770367	769235	20018V	PARTICIPANT	\N	PRESENT	0
770368	769235	14281W	PARTICIPANT	\N	PRESENT	0
770369	769235	14357A	PARTICIPANT	\N	PRESENT	0
770370	769235	14033T	PARTICIPANT	\N	PRESENT	0
770371	769235	14107H	PARTICIPANT	\N	PRESENT	0
770372	769235	20028X	PARTICIPANT	\N	PRESENT	0
770373	769235	19782L	PARTICIPANT	\N	PRESENT	0
770374	769235	21089R	PARTICIPANT	\N	PRESENT	0
770375	769235	19413M	PARTICIPANT	\N	PRESENT	0
770376	769235	14179A	PARTICIPANT	\N	PRESENT	0
770377	769235	19347U	PARTICIPANT	\N	PRESENT	0
770378	769538	20086J	PARTICIPANT	\N	PRESENT	0
770379	769538	14331P	PARTICIPANT	\N	PRESENT	0
770380	769538	20134Y	PARTICIPANT	\N	PRESENT	0
770381	769538	11048N	PARTICIPANT	\N	PRESENT	0
770382	769538	19711U	PARTICIPANT	\N	PRESENT	0
770383	769538	19545Y	PARTICIPANT	\N	PRESENT	0
770384	769538	11053K	PARTICIPANT	\N	PRESENT	0
770385	769538	20050V	PARTICIPANT	\N	PRESENT	0
770386	769538	19667J	PARTICIPANT	\N	PRESENT	0
770387	769538	11074Q	PARTICIPANT	\N	PRESENT	0
785326	785320	20114U	PARTICIPANT	\N	PRESENT	0
785327	785320	20264J	PARTICIPANT	\N	PRESENT	0
785328	785320	21051B	PARTICIPANT	\N	PRESENT	0
785329	785320	20064C	PARTICIPANT	\N	PRESENT	0
785330	785320	14255U	PARTICIPANT	\N	PRESENT	0
785331	785320	20248J	PARTICIPANT	\N	PRESENT	0
785332	785320	21086N	PARTICIPANT	\N	PRESENT	0
785333	785320	04070G	PARTICIPANT	\N	PRESENT	0
785334	785320	19749K	PARTICIPANT	\N	PRESENT	0
785335	785320	21087P	PARTICIPANT	\N	PRESENT	0
785336	785320	11065P	PARTICIPANT	\N	PRESENT	0
785880	783405	20022R	PARTICIPANT	\N	PRESENT	0
785882	783405	14215L	PARTICIPANT	\N	PRESENT	0
785890	783405	14053L	PARTICIPANT	\N	PRESENT	0
785892	783405	10015M	PARTICIPANT	\N	PRESENT	0
785893	783405	04047H	PRESIDENT	0	PRESENT	0
785895	783405	19611R	PARTICIPANT	\N	PRESENT	0
785900	783405	19697Q	PARTICIPANT	\N	PRESENT	0
785901	783405	19621T	PARTICIPANT	\N	PRESENT	0
785904	783405	19673G	PARTICIPANT	\N	PRESENT	0
785906	783405	21089R	PARTICIPANT	\N	PRESENT	0
785908	783405	20132W	PARTICIPANT	\N	PRESENT	0
785909	783405	14030Q	PARTICIPANT	\N	PRESENT	0
785919	783405	20142Y	PARTICIPANT	\N	PRESENT	0
785920	783405	20052X	PARTICIPANT	\N	PRESENT	0
785921	783405	19954N	PARTICIPANT	\N	PRESENT	0
786109	783371	19711U	PARTICIPANT	\N	EXCUSE	0
786111	786110	19954N	PARTICIPANT	\N	PRESENT	0
786112	786110	14069U	PARTICIPANT	\N	PRESENT	0
786113	786110	20138D	PARTICIPANT	\N	PRESENT	0
786114	786110	21052C	PARTICIPANT	\N	PRESENT	0
786115	786110	19693L	PARTICIPANT	\N	PRESENT	0
786116	786110	14215L	PARTICIPANT	\N	PRESENT	0
786117	786110	14151M	PARTICIPANT	\N	PRESENT	0
786118	786110	20120S	PARTICIPANT	\N	PRESENT	0
786119	786110	20180F	PARTICIPANT	\N	PRESENT	0
786120	786110	19569H	PARTICIPANT	\N	PRESENT	0
786121	786110	19531S	PARTICIPANT	\N	PRESENT	0
786122	786110	20126Y	PARTICIPANT	\N	PRESENT	0
786123	786110	20102Q	PARTICIPANT	\N	PRESENT	0
786124	786110	19723Y	PARTICIPANT	\N	PRESENT	0
786125	786110	14001X	PARTICIPANT	\N	PRESENT	0
786126	786110	21073H	PARTICIPANT	\N	PRESENT	0
786127	786110	14147R	PARTICIPANT	\N	PRESENT	0
786128	786110	21056G	PARTICIPANT	\N	PRESENT	0
786129	786110	20026V	PARTICIPANT	\N	PRESENT	0
786130	786110	20052X	PARTICIPANT	\N	PRESENT	0
786190	782897	11048N	PARTICIPANT	\N	EXCUSE	0
786214	786213	11027H	PARTICIPANT	\N	PRESENT	0
786560	786559	20026V	PARTICIPANT	\N	PRESENT	1
786561	786559	21089R	PARTICIPANT	\N	PRESENT	1
786562	786559	20056C	PARTICIPANT	\N	PRESENT	1
786563	786559	20180F	PARTICIPANT	\N	PRESENT	1
786564	786559	14109K	PARTICIPANT	\N	PRESENT	1
786565	786559	20058E	PARTICIPANT	\N	PRESENT	1
786566	786559	14030Q	PARTICIPANT	\N	PRESENT	1
786568	786567	20026V	PARTICIPANT	\N	PRESENT	1
786569	786567	14030Q	PARTICIPANT	\N	PRESENT	1
786570	786567	20058E	PARTICIPANT	\N	PRESENT	1
786571	786567	21089R	PARTICIPANT	\N	PRESENT	1
786572	786567	20056C	PARTICIPANT	\N	PRESENT	1
786573	786567	20180F	PARTICIPANT	\N	PRESENT	1
786574	786567	14109K	PARTICIPANT	\N	PRESENT	1
786575	786567	19693L	PARTICIPANT	\N	PRESENT	1
786611	786609	19735D	PARTICIPANT	\N	PRESENT	0
786612	786609	19723Y	PARTICIPANT	\N	PRESENT	0
786613	786610	19735D	PARTICIPANT	\N	PRESENT	0
786614	786610	19723Y	PARTICIPANT	\N	PRESENT	0
786642	786641	86034E	PARTICIPANT	\N	PRESENT	0
786643	786641	04047H	PARTICIPANT	\N	PRESENT	0
786644	786641	19629C	PARTICIPANT	\N	PRESENT	0
786645	786641	11056N	PARTICIPANT	\N	PRESENT	0
786646	786641	14259Y	PARTICIPANT	\N	PRESENT	0
786647	786641	14042U	PARTICIPANT	\N	PRESENT	0
786648	786641	14187A	PARTICIPANT	\N	PRESENT	0
786649	786641	19347U	PARTICIPANT	\N	PRESENT	0
786650	786641	14179A	PARTICIPANT	\N	PRESENT	0
786651	786641	14021P	PARTICIPANT	\N	PRESENT	0
786652	786641	19611R	PARTICIPANT	\N	PRESENT	0
786653	786641	14219Q	PARTICIPANT	\N	PRESENT	0
786654	786641	14251Q	PARTICIPANT	\N	PRESENT	0
786655	786641	14111D	PARTICIPANT	\N	PRESENT	0
786656	786641	11085T	PARTICIPANT	\N	PRESENT	0
786657	786641	14071N	PARTICIPANT	\N	PRESENT	0
786658	786641	19593H	PARTICIPANT	\N	PRESENT	0
786659	786641	08061X	PARTICIPANT	\N	PRESENT	0
786660	786641	14193X	PARTICIPANT	\N	PRESENT	0
786661	786641	14331P	PARTICIPANT	\N	PRESENT	0
786662	786641	14225N	PARTICIPANT	\N	PRESENT	0
786663	786641	04033B	PARTICIPANT	\N	PRESENT	0
786664	786641	14229S	PARTICIPANT	\N	PRESENT	0
786665	786641	19301E	PARTICIPANT	\N	PRESENT	0
786666	786641	19479G	PARTICIPANT	\N	PRESENT	0
786669	786464	14151M	PRESIDENT	0	PRESENT	0
786670	786464	17367Q	PARTICIPANT	\N	PRESENT	0
786671	786464	20146D	PARTICIPANT	\N	PRESENT	0
786672	786464	20050V	PARTICIPANT	\N	PRESENT	0
786677	786464	14255U	PARTICIPANT	\N	EXCUSE	0
786682	786464	20090E	PARTICIPANT	\N	EXCUSE	0
786684	786464	19295A	PARTICIPANT	\N	PRESENT	0
786686	786685	14038Y	PARTICIPANT	\N	PRESENT	0
786687	786685	20038A	PARTICIPANT	\N	PRESENT	0
786688	786685	20092G	PARTICIPANT	\N	PRESENT	0
786690	786689	14038Y	PARTICIPANT	\N	PRESENT	0
786691	786689	20038A	PARTICIPANT	\N	PRESENT	0
786692	786689	14033T	PARTICIPANT	\N	PRESENT	0
786693	786689	20092G	PARTICIPANT	\N	PRESENT	0
786695	786694	14038Y	PARTICIPANT	\N	PRESENT	0
786696	786694	14033T	PARTICIPANT	\N	PRESENT	0
786697	786694	20038A	PARTICIPANT	\N	PRESENT	0
786699	786698	14038Y	PARTICIPANT	\N	PRESENT	0
786700	786698	14033T	PARTICIPANT	\N	PRESENT	0
786701	786698	20038A	PARTICIPANT	\N	PRESENT	0
786703	786702	14038Y	PARTICIPANT	\N	PRESENT	0
786704	786702	20092G	PARTICIPANT	\N	PRESENT	0
786705	786464	15197G	PARTICIPANT	\N	PRESENT	0
786707	786706	14038Y	PARTICIPANT	\N	PRESENT	0
786708	786706	14033T	PARTICIPANT	\N	PRESENT	0
786709	786706	20092G	PARTICIPANT	\N	PRESENT	0
786711	786710	14038Y	PARTICIPANT	\N	PRESENT	0
786712	786710	14033T	PARTICIPANT	\N	PRESENT	0
786713	786710	20092G	PARTICIPANT	\N	PRESENT	0
786714	786464	12028B	PARTICIPANT	\N	PRESENT	0
786717	786191	14053L	PARTICIPANT	\N	PRESENT	0
786718	786191	21043B	PARTICIPANT	\N	PRESENT	0
786719	786191	21056G	PARTICIPANT	\N	PRESENT	0
786720	786191	14069U	PARTICIPANT	\N	PRESENT	0
786721	786191	14215L	PARTICIPANT	\N	PRESENT	0
786722	786191	04045F	PARTICIPANT	\N	PRESENT	0
786723	786191	20022R	PARTICIPANT	\N	PRESENT	0
786724	786191	04047H	PRESIDENT	0	PRESENT	0
786725	786191	19447X	PARTICIPANT	\N	PRESENT	0
786726	786191	20098N	PARTICIPANT	\N	PRESENT	0
786727	786191	21076L	PARTICIPANT	\N	PRESENT	0
786728	786191	19489J	PARTICIPANT	\N	PRESENT	0
786729	786191	21038E	PARTICIPANT	\N	PRESENT	0
786730	786191	11072N	PARTICIPANT	\N	PRESENT	0
786731	786191	21095P	PARTICIPANT	\N	PRESENT	0
786732	786191	21057H	PARTICIPANT	\N	PRESENT	0
786733	786191	05008E	PARTICIPANT	\N	PRESENT	0
786734	786191	21088Q	PARTICIPANT	\N	PRESENT	0
786753	786615	14111D	PARTICIPANT	\N	PRESENT	0
786754	786615	14207L	PARTICIPANT	\N	PRESENT	0
786764	786615	21093M	PARTICIPANT	\N	PRESENT	0
786756	786615	20082E	PARTICIPANT	\N	PRESENT	0
786762	786615	19413M	PARTICIPANT	\N	PRESENT	0
786766	786615	21076L	PARTICIPANT	\N	PRESENT	0
786768	786615	21054E	PARTICIPANT	\N	PRESENT	0
786769	786615	14205J	PARTICIPANT	\N	PRESENT	0
786770	786615	08028W	PARTICIPANT	\N	PRESENT	0
786771	786615	11040E	PARTICIPANT	\N	PRESENT	0
786772	786615	11090Q	PARTICIPANT	\N	PRESENT	0
786773	786615	19695N	PARTICIPANT	\N	PRESENT	0
786774	786615	19687N	PARTICIPANT	\N	PRESENT	0
786775	786615	19758L	PARTICIPANT	\N	PRESENT	0
786776	786615	11043H	PARTICIPANT	\N	PRESENT	0
786777	786615	14037X	PARTICIPANT	\N	PRESENT	0
786779	786615	20106U	PARTICIPANT	\N	PRESENT	0
786780	786615	14331P	PARTICIPANT	\N	PRESENT	0
786781	786615	20286Q	PARTICIPANT	\N	PRESENT	0
786782	786615	21069M	PARTICIPANT	\N	PRESENT	0
769359	769358	19820Y	PARTICIPANT	\N	PRESENT	0
769360	769358	20136B	PARTICIPANT	\N	PRESENT	0
769363	769361	19820Y	PARTICIPANT	\N	PRESENT	0
769364	769361	15197G	PARTICIPANT	\N	PRESENT	0
770768	768934	20022R	PARTICIPANT	\N	EXCUSE	0
770769	768934	19729F	PARTICIPANT	\N	EXCUSE	0
772929	769256	20086J	PARTICIPANT	\N	PRESENT	0
772930	769256	19711U	PARTICIPANT	\N	PRESENT	0
772977	769256	14173T	PARTICIPANT	\N	PRESENT	0
772932	769256	19687N	PARTICIPANT	\N	PRESENT	0
772933	769256	20080C	PARTICIPANT	\N	PRESENT	0
772934	769256	19647E	PARTICIPANT	\N	PRESENT	0
772935	769256	20134Y	PARTICIPANT	\N	PRESENT	0
772936	769256	21079P	PARTICIPANT	\N	PRESENT	0
772937	769256	21048G	PARTICIPANT	\N	PRESENT	0
772954	769256	19619A	PARTICIPANT	\N	PRESENT	0
772939	769256	20116W	PARTICIPANT	\N	PRESENT	0
772940	769256	07004J	PARTICIPANT	\N	PRESENT	0
772941	769256	11090Q	PARTICIPANT	\N	PRESENT	0
772942	769256	07029T	PARTICIPANT	\N	PRESENT	0
772943	769256	14121F	PARTICIPANT	\N	PRESENT	0
772944	769256	11048N	PARTICIPANT	\N	PRESENT	0
772945	769256	14225N	PARTICIPANT	\N	PRESENT	0
772946	769256	20044X	PARTICIPANT	\N	PRESENT	0
772981	769256	20032T	PARTICIPANT	\N	PRESENT	0
772948	769256	14327T	PARTICIPANT	\N	PRESENT	0
772949	769256	20062A	PARTICIPANT	\N	PRESENT	0
772950	769256	12016W	PARTICIPANT	\N	PRESENT	0
772951	769256	20036X	PARTICIPANT	\N	PRESENT	0
772952	769256	21096Q	PARTICIPANT	\N	PRESENT	0
772953	769256	20050V	PARTICIPANT	\N	PRESENT	0
772955	769256	19629C	PARTICIPANT	\N	PRESENT	0
772957	769256	21088Q	PARTICIPANT	\N	PRESENT	0
772958	769256	20148F	PARTICIPANT	\N	PRESENT	0
772959	769256	19399H	PARTICIPANT	\N	PRESENT	0
772927	769256	19479G	PARTICIPANT	\N	PRESENT	0
772979	769256	11110B	PARTICIPANT	\N	PRESENT	0
772960	769256	14253S	PARTICIPANT	\N	PRESENT	0
772961	769256	21071F	PARTICIPANT	\N	PRESENT	0
772962	769256	19551W	PARTICIPANT	\N	PRESENT	0
772963	769256	21063F	PARTICIPANT	\N	PRESENT	0
772964	769256	21072G	PARTICIPANT	\N	PRESENT	0
772965	769256	20070A	PARTICIPANT	\N	PRESENT	0
772966	769256	20094J	PARTICIPANT	\N	PRESENT	0
772967	769256	19667J	PARTICIPANT	\N	PRESENT	0
772968	769256	21090J	PARTICIPANT	\N	PRESENT	0
772969	769256	14331P	PARTICIPANT	\N	PRESENT	0
772970	769256	21082J	PARTICIPANT	\N	PRESENT	0
772971	769256	19621T	PARTICIPANT	\N	PRESENT	0
772972	769256	20054A	PARTICIPANT	\N	PRESENT	0
772973	769256	19657G	PARTICIPANT	\N	PRESENT	0
772974	769256	08010L	PARTICIPANT	\N	PRESENT	0
772975	769256	14071N	PARTICIPANT	\N	PRESENT	0
772976	769256	21084L	PARTICIPANT	\N	PRESENT	0
772978	769256	11040E	PARTICIPANT	\N	PRESENT	0
772980	769256	04042C	PARTICIPANT	\N	PRESENT	0
772982	769256	11053K	PARTICIPANT	\N	PRESENT	0
772983	769256	21032X	PARTICIPANT	\N	PRESENT	0
772984	769256	19349W	PARTICIPANT	\N	PRESENT	0
772985	769256	14229S	PARTICIPANT	\N	PRESENT	0
774135	772504	14071N	PRESIDENT	0	PRESENT	0
774136	772504	20090E	PARTICIPANT	\N	PRESENT	0
774137	772504	19798U	PARTICIPANT	\N	PRESENT	0
774138	772504	19713W	PARTICIPANT	\N	PRESENT	0
774139	772504	21039F	PARTICIPANT	\N	PRESENT	0
774140	772504	14042U	PARTICIPANT	\N	PRESENT	0
774141	772504	19629C	PARTICIPANT	\N	PRESENT	0
774142	772504	21046E	PARTICIPANT	\N	PRESENT	0
774143	772504	21087P	PARTICIPANT	\N	PRESENT	0
774194	772504	20096L	PARTICIPANT	\N	PRESENT	0
774145	772504	19691J	PARTICIPANT	\N	PRESENT	0
774146	772504	19679N	PARTICIPANT	\N	PRESENT	0
774147	772504	20130U	PARTICIPANT	\N	PRESENT	0
774148	772504	17779H	PARTICIPANT	\N	PRESENT	0
774149	772504	19569H	PARTICIPANT	\N	PRESENT	0
774150	772504	19683J	PARTICIPANT	\N	PRESENT	0
774151	772504	19760E	PARTICIPANT	\N	PRESENT	0
774152	772504	19758L	PARTICIPANT	\N	PRESENT	0
774153	772504	18193Q	PARTICIPANT	\N	PRESENT	0
774154	772504	21064G	PARTICIPANT	\N	PRESENT	0
774155	772504	14281W	PARTICIPANT	\N	PRESENT	0
774156	772504	19301E	PARTICIPANT	\N	PRESENT	0
774157	772504	19703U	PARTICIPANT	\N	PRESENT	0
774158	772504	14223L	PARTICIPANT	\N	PRESENT	0
774159	772504	14217N	PARTICIPANT	\N	PRESENT	0
774160	772504	19723Y	PARTICIPANT	\N	PRESENT	0
774184	772504	19553Y	PARTICIPANT	\N	PRESENT	0
774185	772504	21045D	PARTICIPANT	\N	PRESENT	0
774186	772504	11045K	PARTICIPANT	\N	PRESENT	0
774187	772504	14026U	PARTICIPANT	\N	PRESENT	0
774188	772504	19866P	PARTICIPANT	\N	PRESENT	0
774189	772504	04092N	PARTICIPANT	\N	PRESENT	0
774190	772504	20248J	PARTICIPANT	\N	PRESENT	0
774191	772504	14213J	PARTICIPANT	\N	PRESENT	0
774192	772504	21071F	PARTICIPANT	\N	PRESENT	0
774193	772504	14195A	PARTICIPANT	\N	PRESENT	0
774195	772504	17965H	PARTICIPANT	\N	PRESENT	0
774196	772504	21094N	PARTICIPANT	\N	PRESENT	0
774253	772504	19591F	PARTICIPANT	\N	PRESENT	0
774416	772599	20042V	PARTICIPANT	\N	PRESENT	0
774417	772599	20138D	PARTICIPANT	\N	PRESENT	0
774418	772599	21059K	PARTICIPANT	\N	PRESENT	0
774419	772599	21089R	PARTICIPANT	\N	PRESENT	0
774420	772599	20058E	PARTICIPANT	\N	PRESENT	0
774422	771033	21082J	PARTICIPANT	\N	PRESENT	0
774423	771033	21029D	PARTICIPANT	\N	PRESENT	0
774424	771033	19701S	PARTICIPANT	\N	PRESENT	0
774425	771033	20076G	PARTICIPANT	\N	PRESENT	0
774426	771033	19387D	PARTICIPANT	\N	PRESENT	0
774427	771033	19820Y	PARTICIPANT	\N	PRESENT	0
774428	771033	14219Q	PRESIDENT	0	PRESENT	0
774429	771033	19826F	PARTICIPANT	\N	PRESENT	0
774430	771033	21060C	PARTICIPANT	\N	PRESENT	0
774431	771033	21061D	PARTICIPANT	\N	PRESENT	0
774432	771033	21062E	PARTICIPANT	\N	PRESENT	0
774433	771033	21065H	PARTICIPANT	\N	PRESENT	0
774434	771033	21084L	PARTICIPANT	\N	PRESENT	0
774435	771033	20100N	PARTICIPANT	\N	PRESENT	0
774436	771033	18083K	PARTICIPANT	\N	PRESENT	0
774437	771033	19551W	PARTICIPANT	\N	PRESENT	0
774438	771033	14237S	PARTICIPANT	\N	PRESENT	0
774439	771033	05012A	PARTICIPANT	\N	PRESENT	0
774440	771033	21085M	PARTICIPANT	\N	PRESENT	0
774441	771033	08060W	PARTICIPANT	\N	PRESENT	0
774442	771033	20106U	PARTICIPANT	\N	PRESENT	0
774443	771033	15197G	PARTICIPANT	\N	PRESENT	0
774444	771033	20118Y	PARTICIPANT	\N	PRESENT	0
774445	771033	14107H	PARTICIPANT	\N	PRESENT	0
774446	771033	21080G	PARTICIPANT	\N	PRESENT	0
774447	771033	19331L	PARTICIPANT	\N	PRESENT	0
774448	771033	20020P	PARTICIPANT	\N	PRESENT	0
774449	771033	19681G	PARTICIPANT	\N	PRESENT	0
774450	771033	11065P	PARTICIPANT	\N	PRESENT	0
774451	771033	21051B	PARTICIPANT	\N	PRESENT	0
774452	771033	20120S	PARTICIPANT	\N	PRESENT	0
774453	771033	20032T	PARTICIPANT	\N	PRESENT	0
774454	771033	21053D	PARTICIPANT	\N	PRESENT	0
774455	771033	20136B	PARTICIPANT	\N	PRESENT	0
774456	771033	14031R	PARTICIPANT	\N	PRESENT	0
774457	771033	20146D	PARTICIPANT	\N	PRESENT	0
774458	771033	20046A	PARTICIPANT	\N	PRESENT	0
774459	771033	17229F	PARTICIPANT	\N	PRESENT	0
774460	771033	14169X	PARTICIPANT	\N	PRESENT	0
774461	771033	21047F	PARTICIPANT	\N	PRESENT	0
774462	771033	20068G	PARTICIPANT	\N	PRESENT	0
774463	771033	08009T	PARTICIPANT	\N	PRESENT	0
774464	771033	21068L	PARTICIPANT	\N	PRESENT	0
774465	771033	21070E	PARTICIPANT	\N	PRESENT	0
774466	771033	21042A	PARTICIPANT	\N	EXCUSE	0
774467	771033	19251M	PARTICIPANT	\N	EXCUSE	0
774468	771033	19685L	PARTICIPANT	\N	EXCUSE	0
774469	771033	19619A	PARTICIPANT	\N	EXCUSE	0
774470	772599	20050V	PARTICIPANT	\N	PRESENT	0
774471	772599	21070E	PARTICIPANT	\N	PRESENT	0
774472	772599	19679N	PARTICIPANT	\N	PRESENT	0
774473	772599	21082J	PARTICIPANT	\N	PRESENT	0
774475	772599	19725B	PARTICIPANT	\N	PRESENT	0
774476	772599	19507S	PARTICIPANT	\N	PRESENT	0
774477	772599	18395Y	PARTICIPANT	\N	PRESENT	0
767879	766932	19679N	PARTICIPANT	\N	PRESENT	0
795175	794896	20132W	PARTICIPANT	\N	PRESENT	0
795176	794896	19719D	PARTICIPANT	\N	PRESENT	0
795177	794896	14207L	PARTICIPANT	\N	PRESENT	0
795178	794896	14231L	PARTICIPANT	\N	PRESENT	0
795179	794896	14133K	PARTICIPANT	\N	PRESENT	0
795180	794896	20052X	PARTICIPANT	\N	PRESENT	0
795181	794896	14205J	PARTICIPANT	\N	PRESENT	0
795182	794896	14219Q	PARTICIPANT	\N	PRESENT	0
795183	794896	11085T	PARTICIPANT	\N	PRESENT	0
795184	794896	20076G	PARTICIPANT	\N	PRESENT	0
795185	794896	21038E	PARTICIPANT	\N	PRESENT	0
795186	794896	21064G	PARTICIPANT	\N	PRESENT	0
795187	794896	19619A	PARTICIPANT	\N	PRESENT	0
795188	794896	19749K	PARTICIPANT	\N	PRESENT	0
795189	794896	21078N	PARTICIPANT	\N	PRESENT	0
795190	794896	14107H	PARTICIPANT	\N	PRESENT	0
795191	794896	14195A	PARTICIPANT	\N	PRESENT	0
795192	794896	21065H	PARTICIPANT	\N	PRESENT	0
795193	794896	21085M	PARTICIPANT	\N	PRESENT	0
795194	794896	20252E	PARTICIPANT	\N	PRESENT	0
795195	794896	14251Q	PARTICIPANT	\N	PRESENT	0
795196	794896	20050V	PARTICIPANT	\N	PRESENT	0
795197	794896	21070E	PARTICIPANT	\N	PRESENT	0
795198	794896	21090J	PARTICIPANT	\N	PRESENT	0
795199	794896	21076L	PARTICIPANT	\N	PRESENT	0
795200	794896	20048C	PARTICIPANT	\N	PRESENT	0
795201	794896	14357A	PARTICIPANT	\N	PRESENT	0
795202	794896	14189C	PARTICIPANT	\N	PRESENT	0
795203	794896	19826F	PARTICIPANT	\N	PRESENT	0
795204	794896	14030Q	PARTICIPANT	\N	PRESENT	0
795205	794896	01034P	PARTICIPANT	\N	PRESENT	0
795206	794896	20116W	PARTICIPANT	\N	PRESENT	0
795207	794896	14329V	PARTICIPANT	\N	PRESENT	0
795208	794896	19735D	PARTICIPANT	\N	PRESENT	0
795209	794896	14255U	PARTICIPANT	\N	PRESENT	0
795210	794896	19533U	PARTICIPANT	\N	PRESENT	0
795211	794896	20124W	PARTICIPANT	\N	PRESENT	0
795212	794896	20040T	PARTICIPANT	\N	PRESENT	0
795213	794896	14193X	PARTICIPANT	\N	PRESENT	0
795214	794896	14249W	PARTICIPANT	\N	PRESENT	0
795215	794896	20120S	PARTICIPANT	\N	PRESENT	0
795216	794896	19703U	PARTICIPANT	\N	PRESENT	0
795217	794896	14169X	PARTICIPANT	\N	PRESENT	0
795218	794896	19575F	PARTICIPANT	\N	PRESENT	0
795219	794896	08015R	PARTICIPANT	\N	PRESENT	0
795223	794896	14147R	PARTICIPANT	\N	PRESENT	0
795221	794896	05008E	PARTICIPANT	\N	PRESENT	0
795222	794896	14055N	PARTICIPANT	\N	PRESENT	0
795224	794896	17229F	PARTICIPANT	\N	PRESENT	0
795225	794896	95041E	PARTICIPANT	\N	PRESENT	0
795226	794896	07029T	PARTICIPANT	\N	PRESENT	0
795227	794896	19057M	PARTICIPANT	\N	PRESENT	0
795228	794896	19669L	PARTICIPANT	\N	PRESENT	0
795229	794896	07004J	PARTICIPANT	\N	PRESENT	0
795230	794896	21044C	PARTICIPANT	\N	PRESENT	0
795231	794896	20056C	PARTICIPANT	\N	PRESENT	0
795232	794896	20074E	PARTICIPANT	\N	PRESENT	0
795233	794896	08010L	PARTICIPANT	\N	PRESENT	0
795234	794896	07033P	PARTICIPANT	\N	PRESENT	0
795235	794896	11090Q	PARTICIPANT	\N	PRESENT	0
795236	794896	08018U	PARTICIPANT	\N	PRESENT	0
795237	794896	14355X	PARTICIPANT	\N	PRESENT	0
795241	794896	19657G	PARTICIPANT	\N	PRESENT	0
795239	794896	08028W	PARTICIPANT	\N	PRESENT	0
795240	794896	20058E	PARTICIPANT	\N	PRESENT	0
795242	794896	14033T	PARTICIPANT	\N	PRESENT	0
795243	794896	20118Y	PARTICIPANT	\N	PRESENT	0
795244	794896	20078J	PARTICIPANT	\N	PRESENT	0
795245	794896	21072G	PARTICIPANT	\N	PRESENT	0
795250	794896	21054E	PARTICIPANT	\N	PRESENT	0
795247	794896	20024T	PARTICIPANT	\N	PRESENT	0
795248	794896	14259Y	PARTICIPANT	\N	PRESENT	0
795249	794896	04070G	PARTICIPANT	\N	PRESENT	0
795251	794896	19782L	PARTICIPANT	\N	PRESENT	0
795252	794896	19591F	PARTICIPANT	\N	PRESENT	0
795253	794896	19383Y	PARTICIPANT	\N	PRESENT	0
795254	794896	20112S	PARTICIPANT	\N	PRESENT	0
795255	794896	20104S	PARTICIPANT	\N	PRESENT	0
795256	794896	21074J	PARTICIPANT	\N	PRESENT	0
795257	794896	21079P	PARTICIPANT	\N	PRESENT	0
795258	794896	19699S	PARTICIPANT	\N	PRESENT	0
795259	794896	19347U	PARTICIPANT	\N	PRESENT	0
795260	794896	19701S	PARTICIPANT	\N	PRESENT	0
795261	794896	20138D	PARTICIPANT	\N	PRESENT	0
795262	794896	14031R	PARTICIPANT	\N	PRESENT	0
795263	794896	08009T	PARTICIPANT	\N	PRESENT	0
795264	794896	17023S	PARTICIPANT	\N	PRESENT	0
795265	794896	19691J	PARTICIPANT	\N	PRESENT	0
795268	794896	21095P	PARTICIPANT	\N	PRESENT	0
795269	794896	19489J	PARTICIPANT	\N	PRESENT	0
795270	794896	21041Y	PARTICIPANT	\N	PRESENT	0
795271	794896	21069M	PARTICIPANT	\N	PRESENT	0
795272	794896	21047F	PARTICIPANT	\N	PRESENT	0
795273	794896	14237S	PARTICIPANT	\N	PRESENT	0
795274	794896	20126Y	PARTICIPANT	\N	PRESENT	0
795541	794067	14229S	PARTICIPANT	\N	PRESENT	0
795542	794067	21062E	PARTICIPANT	\N	PRESENT	0
795543	794067	20082E	PARTICIPANT	\N	PRESENT	0
795544	794067	20030R	PARTICIPANT	\N	PRESENT	0
795545	794067	20028X	PARTICIPANT	\N	PRESENT	0
795546	794067	20046A	PARTICIPANT	\N	PRESENT	0
795547	794067	20114U	PARTICIPANT	\N	PRESENT	0
795548	794067	21044C	PARTICIPANT	\N	PRESENT	0
795549	794067	18207D	PARTICIPANT	\N	PRESENT	0
795550	794067	21031W	PARTICIPANT	\N	PRESENT	0
795551	794067	21071F	PARTICIPANT	\N	PRESENT	0
795552	794067	20100N	PARTICIPANT	\N	PRESENT	0
795553	794067	19631V	PARTICIPANT	\N	PRESENT	0
795554	794067	21067K	PARTICIPANT	\N	PRESENT	0
795555	794067	20128B	PARTICIPANT	\N	PRESENT	0
795556	794067	04045F	PARTICIPANT	\N	PRESENT	0
795557	794067	19725B	PARTICIPANT	\N	PRESENT	0
795558	794067	19649G	PARTICIPANT	\N	PRESENT	0
795559	794067	19782L	PARTICIPANT	\N	PRESENT	0
795560	794067	20106U	PARTICIPANT	\N	PRESENT	0
795561	794067	20150Y	PARTICIPANT	\N	PRESENT	0
795562	794067	19629C	PARTICIPANT	\N	PRESENT	0
795563	794067	14107H	PARTICIPANT	\N	PRESENT	0
795564	794067	21043B	PARTICIPANT	\N	PRESENT	0
795565	794067	19693L	PARTICIPANT	\N	PRESENT	0
795566	794067	21094N	PARTICIPANT	\N	PRESENT	0
795567	794067	18231D	PARTICIPANT	\N	PRESENT	0
795568	794067	14030Q	PARTICIPANT	\N	PRESENT	0
795569	794067	04070G	PARTICIPANT	\N	PRESENT	0
795570	794067	20286Q	PARTICIPANT	\N	PRESENT	0
795571	794067	19749K	PARTICIPANT	\N	PRESENT	0
795572	794067	14255U	PARTICIPANT	\N	PRESENT	0
795573	794067	21038E	PARTICIPANT	\N	PRESENT	0
795574	794067	18193Q	PARTICIPANT	\N	PRESENT	0
795575	794067	21034A	PARTICIPANT	\N	PRESENT	0
795576	794067	98022P	PARTICIPANT	\N	PRESENT	0
795577	794067	19553Y	PARTICIPANT	\N	PRESENT	0
795578	794067	11072N	PARTICIPANT	\N	PRESENT	0
795579	794067	19719D	PARTICIPANT	\N	PRESENT	0
795580	794067	19691J	PARTICIPANT	\N	PRESENT	0
795581	794067	11085T	PARTICIPANT	\N	PRESENT	0
795582	794067	19563B	PARTICIPANT	\N	PRESENT	0
795583	794067	05008E	PARTICIPANT	\N	PRESENT	0
795584	794067	20062A	PARTICIPANT	\N	PRESENT	0
795585	794067	21095P	PARTICIPANT	\N	PRESENT	0
795586	794067	21036C	PARTICIPANT	\N	PRESENT	0
795587	794067	20024T	PARTICIPANT	\N	PRESENT	0
795588	794067	14213J	PARTICIPANT	\N	PRESENT	0
795589	794067	14249W	PARTICIPANT	\N	PRESENT	0
795590	794067	14329V	PARTICIPANT	\N	PRESENT	0
795591	794067	14357A	PARTICIPANT	\N	PRESENT	0
795592	794067	19383Y	PARTICIPANT	\N	PRESENT	0
795593	794067	14059S	PARTICIPANT	\N	PRESENT	0
795594	794067	14215L	PARTICIPANT	\N	PRESENT	0
795595	794067	20056C	PARTICIPANT	\N	PRESENT	0
795596	794067	20140W	PARTICIPANT	\N	PRESENT	0
795597	794067	20026V	PARTICIPANT	\N	PRESENT	0
795598	794067	20180F	PARTICIPANT	\N	PRESENT	0
795599	794067	20096L	PARTICIPANT	\N	PRESENT	0
795600	794067	20038A	PARTICIPANT	\N	PRESENT	0
795601	794067	21039F	PARTICIPANT	\N	PRESENT	0
795602	794067	21058J	PARTICIPANT	\N	PRESENT	0
795603	794067	21029D	PARTICIPANT	\N	PRESENT	0
795604	794067	19447X	PARTICIPANT	\N	PRESENT	0
795605	794067	14191V	PARTICIPANT	\N	PRESENT	0
770388	769538	20044X	PARTICIPANT	\N	PRESENT	0
770389	769538	14225N	PRESIDENT	0	PRESENT	0
770390	769538	07029T	PARTICIPANT	\N	PRESENT	0
770391	769538	14083S	PARTICIPANT	\N	PRESENT	0
770392	769538	20062A	PARTICIPANT	\N	PRESENT	0
770393	769538	21079P	PARTICIPANT	\N	PRESENT	0
770394	769538	19573D	PARTICIPANT	\N	PRESENT	0
770395	769538	19679N	PARTICIPANT	\N	PRESENT	0
770396	769538	19349W	PARTICIPANT	\N	PRESENT	0
770397	769538	14121F	PARTICIPANT	\N	PRESENT	0
770398	769538	21090J	PARTICIPANT	\N	PRESENT	0
770399	769538	19335Q	PARTICIPANT	\N	PRESENT	0
770400	769538	20126Y	PARTICIPANT	\N	PRESENT	0
770401	769538	20024T	PARTICIPANT	\N	PRESENT	0
770402	769235	21080G	PARTICIPANT	\N	PRESENT	0
770403	769235	14038Y	PARTICIPANT	\N	PRESENT	0
770404	769235	04070G	PARTICIPANT	\N	PRESENT	0
770405	769235	11065P	PARTICIPANT	\N	PRESENT	0
770406	769235	19349W	PARTICIPANT	\N	PRESENT	0
770407	769235	19629C	PARTICIPANT	\N	PRESENT	0
770408	769235	19573D	PARTICIPANT	\N	PRESENT	0
770409	769235	20044X	PARTICIPANT	\N	PRESENT	0
770410	769235	07029T	PARTICIPANT	\N	PRESENT	0
770411	769235	14121F	PARTICIPANT	\N	PRESENT	0
770412	769235	19723Y	PARTICIPANT	\N	PRESENT	0
770413	769235	11048N	PARTICIPANT	\N	PRESENT	0
770414	769235	21057H	PARTICIPANT	\N	PRESENT	0
770415	769235	19711U	PARTICIPANT	\N	PRESENT	0
770416	769235	19551W	PARTICIPANT	\N	PRESENT	0
770417	769235	17965H	PARTICIPANT	\N	PRESENT	0
770418	769235	20116W	PARTICIPANT	\N	PRESENT	0
770419	769235	21055F	PARTICIPANT	\N	PRESENT	0
770424	769235	14187A	PARTICIPANT	\N	PRESENT	0
770425	769235	20136B	PARTICIPANT	\N	PRESENT	0
770426	769235	20140W	PARTICIPANT	\N	PRESENT	0
770432	769235	19335Q	PARTICIPANT	\N	PRESENT	0
770440	769235	08009T	PARTICIPANT	\N	PRESENT	0
770501	769236	20180F	PARTICIPANT	\N	PRESENT	0
770502	769236	10015M	PARTICIPANT	\N	PRESENT	0
770503	769236	21055F	PARTICIPANT	\N	PRESENT	0
770504	769236	19399H	PARTICIPANT	\N	PRESENT	0
770505	769236	20032T	PARTICIPANT	\N	PRESENT	0
770506	769236	19703U	PARTICIPANT	\N	PRESENT	0
770507	769236	14223L	PARTICIPANT	\N	PRESENT	0
770508	769236	19711U	PARTICIPANT	\N	PRESENT	0
770509	769236	20090E	PARTICIPANT	\N	PRESENT	0
770510	769236	19573D	PARTICIPANT	\N	PRESENT	0
770511	769236	20118Y	PARTICIPANT	\N	PRESENT	0
770512	769236	19335Q	PARTICIPANT	\N	PRESENT	0
770513	769236	14073Q	PARTICIPANT	\N	PRESENT	0
770514	769236	08009T	PARTICIPANT	\N	PRESENT	0
770515	769236	20116W	PARTICIPANT	\N	PRESENT	0
770516	769236	19545Y	PARTICIPANT	\N	PRESENT	0
770517	769236	21087P	PARTICIPANT	\N	PRESENT	0
770518	769236	20106U	PARTICIPANT	\N	PRESENT	0
770519	769236	21048G	PARTICIPANT	\N	PRESENT	0
770520	769236	14257W	PARTICIPANT	\N	PRESENT	0
770521	769236	17965H	PARTICIPANT	\N	PRESENT	0
770522	769236	12016W	PARTICIPANT	\N	PRESENT	0
770524	769236	11110B	PARTICIPANT	\N	PRESENT	0
770525	769236	21059K	PARTICIPANT	\N	PRESENT	0
770526	769236	21089R	PARTICIPANT	\N	PRESENT	0
770527	769236	14121F	PARTICIPANT	\N	PRESENT	0
770528	769236	20080C	PARTICIPANT	\N	PRESENT	0
770529	769236	21068L	PARTICIPANT	\N	PRESENT	0
770530	769236	20024T	PARTICIPANT	\N	PRESENT	0
770531	769236	14225N	PARTICIPANT	\N	PRESENT	0
770532	769236	19758L	PARTICIPANT	\N	PRESENT	0
770534	769236	21088Q	PARTICIPANT	\N	PRESENT	0
770535	769236	20134Y	PARTICIPANT	\N	PRESENT	0
770536	769236	11048N	PARTICIPANT	\N	PRESENT	0
770537	769236	17737W	PARTICIPANT	\N	PRESENT	0
770538	769236	14030Q	PARTICIPANT	\N	PRESENT	0
770539	769236	98022P	PARTICIPANT	\N	PRESENT	0
770540	769236	20062A	PARTICIPANT	\N	PRESENT	0
770541	769236	21070E	PARTICIPANT	\N	PRESENT	0
770543	769236	11070L	PARTICIPANT	\N	PRESENT	0
770544	769236	21047F	PARTICIPANT	\N	PRESENT	0
770545	769236	19507S	PARTICIPANT	\N	PRESENT	0
770546	769236	19647E	PARTICIPANT	\N	PRESENT	0
770547	769236	20052X	PARTICIPANT	\N	PRESENT	0
770548	769236	19553Y	PARTICIPANT	\N	PRESENT	0
770549	769236	20098N	PARTICIPANT	\N	PRESENT	0
770550	769236	21046E	PARTICIPANT	\N	PRESENT	0
770551	769236	20018V	PARTICIPANT	\N	PRESENT	0
770554	769236	19349W	PARTICIPANT	\N	PRESENT	0
770556	769236	20108W	PARTICIPANT	\N	PRESENT	0
770557	769236	20120S	PARTICIPANT	\N	PRESENT	0
770558	769236	14147R	PARTICIPANT	\N	PRESENT	0
770559	769236	14083S	PARTICIPANT	\N	PRESENT	0
770560	769236	14033T	PARTICIPANT	\N	PRESENT	0
770562	769236	21056G	PARTICIPANT	\N	PRESENT	0
770563	769236	08018U	PARTICIPANT	\N	PRESENT	0
770564	769236	21045D	PARTICIPANT	\N	PRESENT	0
770499	769236	19479G	PARTICIPANT	\N	PRESENT	0
770500	769236	20044X	PARTICIPANT	\N	PRESENT	0
770565	769236	21057H	PARTICIPANT	\N	PRESENT	0
770568	769236	07029T	PARTICIPANT	\N	PRESENT	0
770608	769237	12028B	PARTICIPANT	\N	PRESENT	0
770609	769237	20042V	PARTICIPANT	\N	PRESENT	0
770610	769237	14037X	PARTICIPANT	\N	PRESENT	0
770611	769237	21070E	PARTICIPANT	\N	PRESENT	0
770612	769237	19565D	PARTICIPANT	\N	PRESENT	0
770613	769237	21073H	PARTICIPANT	\N	PRESENT	0
770614	769237	98022P	PARTICIPANT	\N	PRESENT	0
770615	769237	14055N	PARTICIPANT	\N	PRESENT	0
770616	769237	12016W	PARTICIPANT	\N	PRESENT	0
770617	769237	14001X	PARTICIPANT	\N	PRESENT	0
770618	769237	21067K	PARTICIPANT	\N	PRESENT	0
770619	769237	14021P	PARTICIPANT	\N	PRESENT	0
770620	769237	21089R	PARTICIPANT	\N	PRESENT	0
770621	769237	04042C	PARTICIPANT	\N	PRESENT	0
770622	769237	18083K	PARTICIPANT	\N	PRESENT	0
770623	769237	19553Y	PARTICIPANT	\N	PRESENT	0
770624	769237	14147R	PARTICIPANT	\N	PRESENT	0
770625	769237	20142Y	PARTICIPANT	\N	PRESENT	0
770626	769237	19669L	PARTICIPANT	\N	PRESENT	0
770627	769237	19647E	PARTICIPANT	\N	PRESENT	0
770628	769237	11043H	PARTICIPANT	\N	PRESENT	0
770629	769237	14249W	PARTICIPANT	\N	PRESENT	0
770630	769237	20094J	PARTICIPANT	\N	PRESENT	0
770631	769237	20064C	PARTICIPANT	\N	PRESENT	0
770632	769237	04033B	PARTICIPANT	\N	PRESENT	0
770633	769237	19679N	PARTICIPANT	\N	PRESENT	0
770600	769237	11090Q	PARTICIPANT	\N	PRESENT	0
770607	769237	14193X	PARTICIPANT	\N	PRESENT	0
770634	769237	01058X	PARTICIPANT	\N	PRESENT	0
770635	769237	07029T	PARTICIPANT	\N	PRESENT	0
770636	769237	21030V	PARTICIPANT	\N	PRESENT	0
770637	769237	20134Y	PARTICIPANT	\N	PRESENT	0
770638	769237	10015M	PARTICIPANT	\N	PRESENT	0
770639	769237	14031R	PARTICIPANT	\N	PRESENT	0
770640	769237	21045D	PARTICIPANT	\N	PRESENT	0
770641	769237	17023S	PARTICIPANT	\N	PRESENT	0
770642	769237	19563B	PARTICIPANT	\N	PRESENT	0
770643	769237	14033T	PARTICIPANT	\N	PRESENT	0
770644	769237	20048C	PARTICIPANT	\N	PRESENT	0
770645	769237	11048N	PARTICIPANT	\N	PRESENT	0
770646	769237	19573D	PARTICIPANT	\N	PRESENT	0
772078	769073	20038A	PARTICIPANT	\N	PRESENT	0
772079	769073	19749K	PRESIDENT	0	PRESENT	0
772080	769073	21061D	PARTICIPANT	\N	PRESENT	0
772081	769073	21094N	PARTICIPANT	\N	PRESENT	0
772082	769073	19553Y	PARTICIPANT	\N	PRESENT	0
772083	769073	20180F	PARTICIPANT	\N	PRESENT	0
772085	769073	20114U	PARTICIPANT	\N	PRESENT	0
772086	769073	21038E	PARTICIPANT	\N	PRESENT	0
772087	769073	18193Q	PARTICIPANT	\N	PRESENT	0
772088	769073	20062A	PARTICIPANT	\N	PRESENT	0
772089	769073	11045K	PARTICIPANT	\N	PRESENT	0
772090	769073	14109K	PARTICIPANT	\N	PRESENT	0
772091	769073	14030Q	PARTICIPANT	\N	PRESENT	0
772092	769073	21042A	PARTICIPANT	\N	PRESENT	0
772097	769073	21089R	PARTICIPANT	\N	PRESENT	0
772115	769073	20098N	PARTICIPANT	\N	PRESENT	0
772127	769073	20046A	PARTICIPANT	\N	EXCUSE	0
772128	769073	20146D	PARTICIPANT	\N	EXCUSE	0
772157	769073	19693L	PARTICIPANT	\N	EXCUSE	0
772207	769073	21044C	PARTICIPANT	\N	EXCUSE	0
772209	769073	21071F	PARTICIPANT	\N	EXCUSE	0
772511	772509	14327T	PARTICIPANT	\N	PRESENT	0
786783	786615	21053D	PARTICIPANT	\N	PRESENT	0
786800	786615	21075K	PARTICIPANT	\N	PRESENT	0
786785	786615	21086N	PARTICIPANT	\N	PRESENT	0
786786	786615	19798U	PARTICIPANT	\N	PRESENT	0
786787	786615	19507S	PARTICIPANT	\N	PRESENT	0
786788	786615	20098N	PARTICIPANT	\N	PRESENT	0
786790	786615	19399H	PARTICIPANT	\N	PRESENT	0
786791	786615	21080G	PARTICIPANT	\N	PRESENT	0
786792	786615	21039F	PARTICIPANT	\N	PRESENT	0
786793	786615	21047F	PARTICIPANT	\N	PRESENT	0
786794	786615	14191V	PARTICIPANT	\N	PRESENT	0
786795	786615	14133K	PARTICIPANT	\N	PRESENT	0
786796	786615	07004J	PARTICIPANT	\N	PRESENT	0
786797	786615	19629C	PARTICIPANT	\N	PRESENT	0
786798	786615	14107H	PARTICIPANT	\N	PRESENT	0
786799	786615	21088Q	PARTICIPANT	\N	PRESENT	0
786801	786615	19719D	PARTICIPANT	\N	PRESENT	0
786802	786615	19782L	PARTICIPANT	\N	PRESENT	0
786803	786615	20046A	PARTICIPANT	\N	PRESENT	0
786805	786615	14042U	PARTICIPANT	\N	PRESENT	0
786806	786615	21070E	PARTICIPANT	\N	PRESENT	0
786807	786615	11056N	PARTICIPANT	\N	PRESENT	0
786808	786615	20088L	PARTICIPANT	\N	PRESENT	0
786811	786615	21041Y	PARTICIPANT	\N	PRESENT	0
786814	786615	14030Q	PARTICIPANT	\N	PRESENT	0
786815	786615	14069U	PARTICIPANT	\N	PRESENT	0
786816	786615	20028X	PARTICIPANT	\N	PRESENT	0
786817	786615	18083K	PARTICIPANT	\N	PRESENT	0
786818	786615	20032T	PARTICIPANT	\N	PRESENT	0
786819	786615	19573D	PARTICIPANT	\N	PRESENT	0
786820	786615	14187A	PARTICIPANT	\N	PRESENT	0
786822	786615	19954N	PARTICIPANT	\N	PRESENT	0
786823	786615	21058J	PARTICIPANT	\N	PRESENT	0
786824	786615	08015R	PARTICIPANT	\N	PRESENT	0
786826	786615	20180F	PARTICIPANT	\N	PRESENT	0
786827	786615	14275Y	PARTICIPANT	\N	PRESENT	0
786829	786615	14189C	PARTICIPANT	\N	PRESENT	0
786831	786615	20172F	PARTICIPANT	\N	PRESENT	0
786832	786615	20070A	PARTICIPANT	\N	PRESENT	0
786833	786615	14237S	PARTICIPANT	\N	PRESENT	0
786834	786615	21083K	PARTICIPANT	\N	PRESENT	0
786835	786615	21085M	PARTICIPANT	\N	PRESENT	0
786836	786615	14147R	PARTICIPANT	\N	PRESENT	0
786837	786615	20044X	PARTICIPANT	\N	PRESENT	0
786838	786615	21066J	PARTICIPANT	\N	PRESENT	0
786840	786615	21082J	PARTICIPANT	\N	PRESENT	0
786841	786615	11110B	PARTICIPANT	\N	PRESENT	0
786843	786615	21094N	PARTICIPANT	\N	PRESENT	0
786844	786615	20076G	PARTICIPANT	\N	PRESENT	0
786845	786615	14001X	PARTICIPANT	\N	PRESENT	0
786847	786615	14031R	PARTICIPANT	\N	PRESENT	0
786848	786615	19760E	PARTICIPANT	\N	PRESENT	0
786849	786615	14026U	PARTICIPANT	\N	PRESENT	0
786850	786615	11072N	PARTICIPANT	\N	PRESENT	0
786851	786615	21043B	PARTICIPANT	\N	PRESENT	0
786852	786615	14223L	PARTICIPANT	\N	PRESENT	0
786853	786615	14221J	PARTICIPANT	\N	PRESENT	0
786854	786615	14217N	PARTICIPANT	\N	PRESENT	0
786855	786615	20022R	PARTICIPANT	\N	PRESENT	0
786856	786615	20112S	PARTICIPANT	\N	PRESENT	0
786857	786615	20140W	PARTICIPANT	\N	PRESENT	0
786862	786616	14111D	PARTICIPANT	\N	PRESENT	0
786927	786616	20028X	PARTICIPANT	\N	PRESENT	0
786864	786616	20082E	PARTICIPANT	\N	PRESENT	0
786865	786616	19413M	PARTICIPANT	\N	PRESENT	0
786928	786616	19347U	PARTICIPANT	\N	PRESENT	0
786867	786616	21054E	PARTICIPANT	\N	PRESENT	0
786930	786616	19349W	PARTICIPANT	\N	PRESENT	0
786935	786616	20026V	PARTICIPANT	\N	PRESENT	0
786936	786616	20032T	PARTICIPANT	\N	PRESENT	0
786931	786616	20144B	PARTICIPANT	\N	PRESENT	0
786932	786616	19479G	PARTICIPANT	\N	PRESENT	0
786933	786616	21050A	PARTICIPANT	\N	PRESENT	0
786874	786616	11043H	PARTICIPANT	\N	PRESENT	0
786875	786616	20106U	PARTICIPANT	\N	PRESENT	0
786937	786616	20044X	PARTICIPANT	\N	PRESENT	0
786877	786616	20286Q	PARTICIPANT	\N	PRESENT	0
786934	786616	19679N	PARTICIPANT	\N	PRESENT	0
786879	786616	21053D	PARTICIPANT	\N	PRESENT	0
786880	786616	19798U	PARTICIPANT	\N	PRESENT	0
786946	786616	19383Y	PARTICIPANT	\N	PRESENT	0
786882	786616	20098N	PARTICIPANT	\N	PRESENT	0
786938	786616	14147R	PARTICIPANT	\N	PRESENT	0
786884	786616	21080G	PARTICIPANT	\N	PRESENT	0
786885	786616	21039F	PARTICIPANT	\N	PRESENT	0
786939	786616	20172F	PARTICIPANT	\N	PRESENT	0
786942	786616	08056B	PARTICIPANT	\N	PRESENT	0
786888	786616	19629C	PARTICIPANT	\N	PRESENT	0
786889	786616	14107H	PARTICIPANT	\N	PRESENT	0
786948	786616	20120S	PARTICIPANT	\N	PRESENT	0
786949	786616	19621T	PARTICIPANT	\N	PRESENT	0
786892	786616	19782L	PARTICIPANT	\N	PRESENT	0
786950	786616	19575F	PARTICIPANT	\N	PRESENT	0
786894	786616	21070E	PARTICIPANT	\N	PRESENT	0
786895	786616	11056N	PARTICIPANT	\N	PRESENT	0
786896	786616	20088L	PARTICIPANT	\N	PRESENT	0
786897	786616	21041Y	PARTICIPANT	\N	PRESENT	0
786951	786616	14221J	PARTICIPANT	\N	PRESENT	0
786953	786616	20054A	PARTICIPANT	\N	PRESENT	0
786955	786616	21040X	PARTICIPANT	\N	PRESENT	0
786956	786616	21082J	PARTICIPANT	\N	PRESENT	0
786902	786616	14187A	PARTICIPANT	\N	PRESENT	0
786957	786616	14237S	PARTICIPANT	\N	PRESENT	0
786958	786616	14275Y	PARTICIPANT	\N	PRESENT	0
786905	786616	14189C	PARTICIPANT	\N	PRESENT	0
786960	786616	14205J	PARTICIPANT	\N	PRESENT	0
786961	786616	14223L	PARTICIPANT	\N	PRESENT	0
786962	786616	19713W	PARTICIPANT	\N	PRESENT	0
786963	786616	14030Q	PARTICIPANT	\N	PRESENT	0
786964	786616	20024T	PARTICIPANT	\N	PRESENT	0
786911	786616	11110B	PARTICIPANT	\N	PRESENT	0
786912	786616	20076G	PARTICIPANT	\N	PRESENT	0
786965	786616	18083K	PARTICIPANT	\N	PRESENT	0
786966	786616	19691J	PARTICIPANT	\N	PRESENT	0
786967	786616	19565D	PARTICIPANT	\N	PRESENT	0
786968	786616	08061X	PARTICIPANT	\N	PRESENT	0
786917	786616	11072N	PARTICIPANT	\N	PRESENT	0
786918	786616	21043B	PARTICIPANT	\N	PRESENT	0
786970	786969	21084L	PARTICIPANT	\N	PRESENT	0
786971	786969	20024T	PARTICIPANT	\N	PRESENT	0
786972	786969	20114U	PARTICIPANT	\N	PRESENT	0
786973	786969	21045D	PARTICIPANT	\N	PRESENT	0
786923	786616	20112S	PARTICIPANT	\N	PRESENT	0
786924	786616	20140W	PARTICIPANT	\N	PRESENT	0
786974	786969	14083S	PARTICIPANT	\N	PRESENT	0
786975	786969	19721W	PARTICIPANT	\N	PRESENT	0
786976	786969	18083K	PARTICIPANT	\N	PRESENT	0
786977	786969	20070A	PARTICIPANT	\N	PRESENT	0
786978	786969	11074Q	PARTICIPANT	\N	PRESENT	0
786979	786969	21032X	PARTICIPANT	\N	PRESENT	0
786980	786969	07004J	PARTICIPANT	\N	PRESENT	0
786981	786969	19565D	PARTICIPANT	\N	PRESENT	0
786982	786969	14213J	PARTICIPANT	\N	PRESENT	0
786983	786969	19531S	PARTICIPANT	\N	PRESENT	0
786984	786969	19683J	PARTICIPANT	\N	PRESENT	0
786985	786969	10015M	PARTICIPANT	\N	PRESENT	0
786986	786969	14229S	PARTICIPANT	\N	PRESENT	0
786987	786969	21059K	PARTICIPANT	\N	PRESENT	0
786988	786969	21036C	PARTICIPANT	\N	PRESENT	0
786989	786969	19687N	PARTICIPANT	\N	PRESENT	0
786990	786969	21094N	PARTICIPANT	\N	PRESENT	0
786991	786616	19760E	PARTICIPANT	\N	PRESENT	0
786992	786969	21031W	PARTICIPANT	\N	PRESENT	0
786993	786969	21082J	PARTICIPANT	\N	PRESENT	0
786994	786616	19703U	PARTICIPANT	\N	PRESENT	0
786995	786616	08028W	PARTICIPANT	\N	PRESENT	0
786996	786616	19631V	PARTICIPANT	\N	PRESENT	0
786997	786616	14109K	PARTICIPANT	\N	PRESENT	0
786998	786616	14219Q	PARTICIPANT	\N	PRESENT	0
786999	786616	20056C	PARTICIPANT	\N	PRESENT	0
787000	786616	17023S	PARTICIPANT	\N	PRESENT	0
787001	786616	11070L	PARTICIPANT	\N	PRESENT	0
787002	786616	14038Y	PARTICIPANT	\N	PRESENT	0
787003	786616	11090Q	PARTICIPANT	\N	PRESENT	0
787004	786616	20058E	PARTICIPANT	\N	PRESENT	0
787008	786616	14059S	PARTICIPANT	\N	PRESENT	0
787011	786616	19507S	PARTICIPANT	\N	PRESENT	0
787012	786616	14133K	PARTICIPANT	\N	PRESENT	0
787013	786616	20078J	PARTICIPANT	\N	PRESENT	0
787014	786616	20092G	PARTICIPANT	\N	PRESENT	0
787019	786616	14033T	PARTICIPANT	\N	PRESENT	0
768257	768245	19611R	PRESIDENT	0	PRESENT	0
768260	768245	19533U	PARTICIPANT	\N	PRESENT	0
768261	768245	19593H	PARTICIPANT	\N	PRESENT	0
768263	768245	20102Q	PARTICIPANT	\N	PRESENT	0
768264	768245	20172F	PARTICIPANT	\N	PRESENT	0
768265	768245	19697Q	PARTICIPANT	\N	PRESENT	0
768266	768245	20026V	PARTICIPANT	\N	PRESENT	0
768268	768245	20124W	PARTICIPANT	\N	PRESENT	0
768269	768245	20056C	PARTICIPANT	\N	PRESENT	0
768270	768245	19735D	PARTICIPANT	\N	PRESENT	0
768271	768245	14109K	PARTICIPANT	\N	PRESENT	0
768274	768245	04047H	PARTICIPANT	\N	PRESENT	0
768283	768245	20048C	PARTICIPANT	\N	PRESENT	0
768284	768245	20264J	PARTICIPANT	\N	PRESENT	0
768325	768245	20132W	PARTICIPANT	\N	PRESENT	0
768326	768245	14053L	PARTICIPANT	\N	PRESENT	0
768327	768245	20114U	PARTICIPANT	\N	PRESENT	0
768337	768245	21058J	PARTICIPANT	\N	PRESENT	0
768340	768245	20142Y	PARTICIPANT	\N	PRESENT	0
768341	768245	14147R	PARTICIPANT	\N	PRESENT	0
768347	768245	19673G	PARTICIPANT	\N	PRESENT	0
768352	768245	19111A	PARTICIPANT	\N	PRESENT	0
768353	768245	14231L	PARTICIPANT	\N	PRESENT	0
768354	768245	14111D	PARTICIPANT	\N	PRESENT	0
768355	768245	18231D	PARTICIPANT	\N	PRESENT	0
768367	768245	19693L	PARTICIPANT	\N	PRESENT	0
768369	768245	14030Q	PARTICIPANT	\N	PRESENT	0
768370	768245	19749K	PARTICIPANT	\N	PRESENT	0
768441	765489	19673G	PARTICIPANT	\N	EXCUSE	0
768470	767790	19679N	PARTICIPANT	\N	PRESENT	0
768471	767790	21049H	PARTICIPANT	\N	PRESENT	0
774478	772599	14033T	PARTICIPANT	\N	PRESENT	0
774479	772599	21053D	PARTICIPANT	\N	PRESENT	0
774480	772599	18083K	PARTICIPANT	\N	PRESENT	0
774481	772599	20120S	PARTICIPANT	\N	PRESENT	0
774482	772599	14191V	PARTICIPANT	\N	PRESENT	0
774483	772599	19621T	PARTICIPANT	\N	PRESENT	0
774484	772599	19575F	PARTICIPANT	\N	PRESENT	0
774485	772599	19545Y	PARTICIPANT	\N	PRESENT	0
774486	772599	20066E	PARTICIPANT	\N	PRESENT	0
774487	772599	14073Q	PARTICIPANT	\N	PRESENT	0
774488	772599	20052X	PARTICIPANT	\N	PRESENT	0
774489	772599	19758L	PARTICIPANT	\N	PRESENT	0
774490	772599	14053L	PARTICIPANT	\N	PRESENT	0
774491	772599	11072N	PARTICIPANT	\N	PRESENT	0
774492	772599	19611R	PARTICIPANT	\N	PRESENT	0
774493	772599	21068L	PARTICIPANT	\N	PRESENT	0
774494	772599	20022R	PARTICIPANT	\N	PRESENT	0
774495	772599	20092G	PARTICIPANT	\N	PRESENT	0
774497	772599	21046E	PARTICIPANT	\N	PRESENT	0
774498	772599	19629C	PARTICIPANT	\N	PRESENT	0
774499	772599	14173T	PARTICIPANT	\N	PRESENT	0
774500	772599	14038Y	PARTICIPANT	\N	PRESENT	0
774501	772599	21034A	PARTICIPANT	\N	PRESENT	0
774502	772599	19687N	PARTICIPANT	\N	PRESENT	0
774503	772599	11074Q	PARTICIPANT	\N	PRESENT	0
774504	772599	21075K	PARTICIPANT	\N	PRESENT	0
774505	772599	20034V	PARTICIPANT	\N	PRESENT	0
774506	772599	20136B	PARTICIPANT	\N	PRESENT	0
774507	772599	20172F	PARTICIPANT	\N	PRESENT	0
774508	772599	20094J	PARTICIPANT	\N	PRESENT	0
774618	772601	19798U	PARTICIPANT	\N	PRESENT	0
774619	772601	98022P	PARTICIPANT	\N	PRESENT	0
774620	772601	21057H	PARTICIPANT	\N	PRESENT	0
774621	772601	20090E	PARTICIPANT	\N	PRESENT	0
774622	772601	21039F	PARTICIPANT	\N	PRESENT	0
774623	772601	21058J	PARTICIPANT	\N	PRESENT	0
774624	772601	08028W	PARTICIPANT	\N	PRESENT	0
774625	772601	19507S	PARTICIPANT	\N	PRESENT	0
774626	772601	14073Q	PARTICIPANT	\N	PRESENT	0
774629	772601	19760E	PARTICIPANT	\N	PRESENT	0
774630	772601	19711U	PARTICIPANT	\N	PRESENT	0
774631	772601	19621T	PARTICIPANT	\N	PRESENT	0
774632	772601	99004R	PARTICIPANT	\N	PRESENT	0
774633	772601	01058X	PARTICIPANT	\N	PRESENT	0
774634	772601	19575F	PARTICIPANT	\N	PRESENT	0
774636	772601	20114U	PARTICIPANT	\N	PRESENT	0
774637	772601	11074Q	PARTICIPANT	\N	PRESENT	0
774638	772601	21091K	PARTICIPANT	\N	PRESENT	0
774639	772601	20064C	PARTICIPANT	\N	PRESENT	0
774640	772601	08011M	PARTICIPANT	\N	PRESENT	0
774641	772601	21051B	PARTICIPANT	\N	PRESENT	0
774642	772601	04042C	PARTICIPANT	\N	PRESENT	0
774643	772601	14229S	PARTICIPANT	\N	PRESENT	0
774644	772601	08069G	PARTICIPANT	\N	PRESENT	0
774645	772601	14123H	PARTICIPANT	\N	PRESENT	0
774646	772601	19725B	PARTICIPANT	\N	PRESENT	0
774647	772601	20074E	PARTICIPANT	\N	PRESENT	0
774648	772601	11045K	PARTICIPANT	\N	PRESENT	0
774649	772601	20076G	PARTICIPANT	\N	PRESENT	0
774650	772601	21044C	PARTICIPANT	\N	PRESENT	0
774651	772601	19649G	PARTICIPANT	\N	PRESENT	0
774652	772601	14151M	PARTICIPANT	\N	PRESENT	0
774653	772601	21080G	PARTICIPANT	\N	PRESENT	0
774654	772601	08060W	PARTICIPANT	\N	PRESENT	0
774655	772601	14169X	PARTICIPANT	\N	PRESENT	0
774656	772601	10015M	PARTICIPANT	\N	PRESENT	0
774657	772601	18207D	PARTICIPANT	\N	PRESENT	0
774658	772601	11043H	PARTICIPANT	\N	PRESENT	0
774659	772601	14191V	PARTICIPANT	\N	PRESENT	0
774660	772601	20070A	PARTICIPANT	\N	PRESENT	0
774661	772601	14237S	PARTICIPANT	\N	PRESENT	0
774662	772601	20044X	PARTICIPANT	\N	PRESENT	0
774663	772601	17965H	PARTICIPANT	\N	PRESENT	0
774664	772601	11090Q	PARTICIPANT	\N	PRESENT	0
774665	772601	05012A	PARTICIPANT	\N	PRESENT	0
774666	772601	14071N	PARTICIPANT	\N	PRESENT	0
774667	772601	20032T	PARTICIPANT	\N	PRESENT	0
774668	772601	14253S	PARTICIPANT	\N	PRESENT	0
774669	772601	19667J	PARTICIPANT	\N	PRESENT	0
774670	772601	19421M	PARTICIPANT	\N	PRESENT	0
774671	772601	14031R	PARTICIPANT	\N	PRESENT	0
774672	772601	21055F	PARTICIPANT	\N	PRESENT	0
774673	772601	21060C	PARTICIPANT	\N	PRESENT	0
774674	772601	19673G	PARTICIPANT	\N	PRESENT	0
774675	772601	20080C	PARTICIPANT	\N	PRESENT	0
774676	772601	14173T	PARTICIPANT	\N	PRESENT	0
774677	772601	21089R	PARTICIPANT	\N	PRESENT	0
774678	772601	19447X	PARTICIPANT	\N	PRESENT	0
774679	772601	21045D	PARTICIPANT	\N	PRESENT	0
774680	772601	20096L	PARTICIPANT	\N	PRESENT	0
774681	772601	20180F	PARTICIPANT	\N	PRESENT	0
774682	772601	20026V	PARTICIPANT	\N	PRESENT	0
774683	772601	08047A	PARTICIPANT	\N	PRESENT	0
774684	772601	20138D	PARTICIPANT	\N	PRESENT	0
774685	772601	14147R	PARTICIPANT	\N	PRESENT	0
774686	772601	20172F	PARTICIPANT	\N	PRESENT	0
774687	772601	14038Y	PARTICIPANT	\N	PRESENT	0
774688	772601	20034V	PARTICIPANT	\N	PRESENT	0
774689	772601	18231D	PARTICIPANT	\N	PRESENT	0
774690	772601	20058E	PARTICIPANT	\N	PRESENT	0
774691	772601	20060X	PARTICIPANT	\N	PRESENT	0
774692	772601	21047F	PARTICIPANT	\N	PRESENT	0
774693	772601	21063F	PARTICIPANT	\N	PRESENT	0
774694	772601	17779H	PARTICIPANT	\N	PRESENT	0
774695	772601	12016W	PARTICIPANT	\N	PRESENT	0
774696	772601	14001X	PARTICIPANT	\N	PRESENT	0
774697	772601	20068G	PARTICIPANT	\N	PRESENT	0
774698	772601	19723Y	PARTICIPANT	\N	PRESENT	0
774699	772601	20084G	PARTICIPANT	\N	PRESENT	0
774700	772601	21029D	PARTICIPANT	\N	PRESENT	0
774701	772601	19669L	PARTICIPANT	\N	PRESENT	0
774616	772601	21068L	PARTICIPANT	\N	PRESENT	0
774617	772601	21052C	PARTICIPANT	\N	PRESENT	0
774702	772601	07029T	PARTICIPANT	\N	PRESENT	0
774703	772601	14021P	PARTICIPANT	\N	PRESENT	0
774704	772601	19399H	PARTICIPANT	\N	PRESENT	0
774705	772601	14097Y	PARTICIPANT	\N	PRESENT	0
774706	772601	19683J	PARTICIPANT	\N	PRESENT	0
774707	772601	19489J	PARTICIPANT	\N	PRESENT	0
774708	772601	20104S	PARTICIPANT	\N	PRESENT	0
774709	772601	11027H	PARTICIPANT	\N	PRESENT	0
774710	772601	21082J	PARTICIPANT	\N	PRESENT	0
774711	772601	20108W	PARTICIPANT	\N	PRESENT	0
774712	772601	08012N	PARTICIPANT	\N	PRESENT	0
774713	772601	14033T	PARTICIPANT	\N	PRESENT	0
774714	772601	20024T	PARTICIPANT	\N	PRESENT	0
774715	772601	14213J	PARTICIPANT	\N	PRESENT	0
774716	772601	21071F	PARTICIPANT	\N	PRESENT	0
774717	772601	19707Y	PARTICIPANT	\N	PRESENT	0
774718	772601	08015R	PARTICIPANT	\N	PRESENT	0
785951	783405	19693L	PARTICIPANT	\N	PRESENT	0
795606	794067	21080G	PARTICIPANT	\N	PRESENT	0
785954	783405	20180F	PARTICIPANT	\N	PRESENT	0
785956	783405	20048C	PARTICIPANT	\N	PRESENT	0
785957	783405	14073Q	PARTICIPANT	\N	PRESENT	0
785958	783405	20102Q	PARTICIPANT	\N	PRESENT	0
785959	783405	21058J	PARTICIPANT	\N	PRESENT	0
785960	783405	21055F	PARTICIPANT	\N	PRESENT	0
785961	783405	19533U	PARTICIPANT	\N	PRESENT	0
786017	783405	20124W	PARTICIPANT	\N	PRESENT	0
795607	794067	20074E	PARTICIPANT	\N	PRESENT	0
795608	794067	14038Y	PARTICIPANT	\N	PRESENT	0
795609	794067	20054A	PARTICIPANT	\N	PRESENT	0
795610	794067	14223L	PARTICIPANT	\N	PRESENT	0
795612	794067	21045D	PARTICIPANT	\N	PRESENT	0
795613	794067	14111D	PARTICIPANT	\N	PRESENT	0
795615	794067	21070E	PARTICIPANT	\N	PRESENT	0
795617	794067	17965H	PARTICIPANT	\N	PRESENT	0
795685	794067	11048N	PARTICIPANT	\N	PRESENT	0
795686	794067	08028W	PARTICIPANT	\N	PRESENT	0
795688	794067	07029T	PARTICIPANT	\N	PRESENT	0
795689	795687	19631V	PARTICIPANT	\N	PRESENT	0
795690	795687	20112S	PARTICIPANT	\N	PRESENT	0
795691	795687	19954N	PARTICIPANT	\N	PRESENT	0
795692	795687	21063F	PARTICIPANT	\N	PRESENT	0
795693	795687	19629C	PARTICIPANT	\N	PRESENT	0
795694	795687	21065H	PARTICIPANT	\N	PRESENT	0
795695	795687	20132W	PARTICIPANT	\N	PRESENT	0
795696	795687	20180F	PARTICIPANT	\N	PRESENT	0
795697	795687	14213J	PARTICIPANT	\N	PRESENT	0
795698	795687	20056C	PARTICIPANT	\N	PRESENT	0
795699	795687	19711U	PARTICIPANT	\N	PRESENT	0
795700	795687	14147R	PARTICIPANT	\N	PRESENT	0
795701	795687	21037D	PARTICIPANT	\N	PRESENT	0
795702	795687	14237S	PARTICIPANT	\N	PRESENT	0
795703	795687	21047F	PARTICIPANT	\N	PRESENT	0
795704	795687	19349W	PARTICIPANT	\N	PRESENT	0
795705	795687	19421M	PARTICIPANT	\N	PRESENT	0
795706	794067	08034U	PARTICIPANT	\N	PRESENT	0
795707	795687	11043H	PARTICIPANT	\N	PRESENT	0
795708	795687	19703U	PARTICIPANT	\N	PRESENT	0
795709	795687	01034P	PARTICIPANT	\N	PRESENT	0
795710	795687	20026V	PARTICIPANT	\N	PRESENT	0
795711	795687	20058E	PARTICIPANT	\N	PRESENT	0
795712	795687	19611R	PARTICIPANT	\N	PRESENT	0
795713	794067	18395Y	PARTICIPANT	\N	PRESENT	0
795714	794067	14259Y	PARTICIPANT	\N	PRESENT	0
795715	794067	20080C	PARTICIPANT	\N	PRESENT	0
795716	794067	14189C	PARTICIPANT	\N	PRESENT	0
795717	794067	19479G	PARTICIPANT	\N	PRESENT	0
795718	794067	21082J	PARTICIPANT	\N	PRESENT	0
795719	794067	20052X	PARTICIPANT	\N	PRESENT	0
795720	794067	18083K	PARTICIPANT	\N	PRESENT	0
795721	795638	19575F	PARTICIPANT	\N	PRESENT	0
795810	794069	08018U	PARTICIPANT	\N	PRESENT	0
795811	794069	19725B	PARTICIPANT	\N	PRESENT	0
795812	794069	18207D	PARTICIPANT	\N	PRESENT	0
795813	794069	21031W	PARTICIPANT	\N	PRESENT	0
795814	794069	20114U	PARTICIPANT	\N	PRESENT	0
795815	794069	14281W	PARTICIPANT	\N	PRESENT	0
795816	794069	14151M	PARTICIPANT	\N	PRESENT	0
795817	794069	17965H	PARTICIPANT	\N	PRESENT	0
795818	794069	18395Y	PARTICIPANT	\N	PRESENT	0
795819	794069	21034A	PARTICIPANT	\N	PRESENT	0
795820	794069	11040E	PARTICIPANT	\N	PRESENT	0
795821	794069	19649G	PARTICIPANT	\N	PRESENT	0
795822	794069	20128B	PARTICIPANT	\N	PRESENT	0
795823	794069	11072N	PARTICIPANT	\N	PRESENT	0
795824	794069	19565D	PARTICIPANT	\N	PRESENT	0
795825	794069	08061X	PARTICIPANT	\N	PRESENT	0
795826	794069	19719D	PARTICIPANT	\N	PRESENT	0
795827	794069	19569H	PARTICIPANT	\N	PRESENT	0
795828	794069	14030Q	PARTICIPANT	\N	PRESENT	0
795829	794069	07004J	PARTICIPANT	\N	PRESENT	0
795830	794069	21087P	PARTICIPANT	\N	PRESENT	0
795831	794069	14059S	PARTICIPANT	\N	PRESENT	0
795832	794069	20024T	PARTICIPANT	\N	PRESENT	0
795833	794069	08028W	PARTICIPANT	\N	PRESENT	0
795834	794069	14223L	PARTICIPANT	\N	PRESENT	0
795835	794069	14147R	PARTICIPANT	\N	PRESENT	0
795836	794069	20180F	PARTICIPANT	\N	PRESENT	0
795837	794069	14259Y	PARTICIPANT	\N	PRESENT	0
795838	794069	11090Q	PARTICIPANT	\N	PRESENT	0
795839	794069	21044C	PARTICIPANT	\N	PRESENT	0
795840	794069	14191V	PARTICIPANT	\N	PRESENT	0
795841	794069	19447X	PARTICIPANT	\N	PRESENT	0
795842	794069	19703U	PARTICIPANT	\N	PRESENT	0
795843	794069	21095P	PARTICIPANT	\N	PRESENT	0
795844	794069	14053L	PARTICIPANT	\N	PRESENT	0
795845	794069	19111A	PARTICIPANT	\N	PRESENT	0
795846	794069	14083S	PARTICIPANT	\N	PRESENT	0
795847	794069	18193Q	PARTICIPANT	\N	PRESENT	0
795848	794069	19413M	PARTICIPANT	\N	PRESENT	0
795849	794069	20142Y	PARTICIPANT	\N	PRESENT	0
795850	794069	19749K	PARTICIPANT	\N	PRESENT	0
795851	794069	20056C	PARTICIPANT	\N	PRESENT	0
795852	794069	19713W	PARTICIPANT	\N	PRESENT	0
795853	794069	20074E	PARTICIPANT	\N	PRESENT	0
795854	794069	14073Q	PARTICIPANT	\N	PRESENT	0
795855	794069	04045F	PARTICIPANT	\N	PRESENT	0
795856	794069	08010L	PARTICIPANT	\N	PRESENT	0
795857	794069	14215L	PARTICIPANT	\N	PRESENT	0
795858	794069	19399H	PARTICIPANT	\N	PRESENT	0
795859	794069	20044X	PARTICIPANT	\N	PRESENT	0
795860	794069	19782L	PARTICIPANT	\N	PRESENT	0
795861	794069	21076L	PARTICIPANT	\N	PRESENT	0
795862	794069	01034P	PARTICIPANT	\N	PRESENT	0
795863	794069	20090E	PARTICIPANT	\N	PRESENT	0
795864	794069	19798U	PARTICIPANT	\N	PRESENT	0
795865	794069	19347U	PARTICIPANT	\N	PRESENT	0
795866	794069	19758L	PARTICIPANT	\N	PRESENT	0
795867	794069	14231L	PARTICIPANT	\N	PRESENT	0
795868	794069	20084G	PARTICIPANT	\N	PRESENT	0
795869	794069	19760E	PARTICIPANT	\N	PRESENT	0
795870	794069	19954N	PARTICIPANT	\N	PRESENT	0
795871	794069	20038A	PARTICIPANT	\N	PRESENT	0
795872	794069	20092G	PARTICIPANT	\N	PRESENT	0
795873	794069	21082J	PARTICIPANT	\N	PRESENT	0
795874	794069	21070E	PARTICIPANT	\N	PRESENT	0
795875	794069	19533U	PARTICIPANT	\N	PRESENT	0
795876	794069	19701S	PARTICIPANT	\N	PRESENT	0
795877	794069	20100N	PARTICIPANT	\N	PRESENT	0
795878	794069	19687N	PARTICIPANT	\N	PRESENT	0
795879	794069	20032T	PARTICIPANT	\N	PRESENT	0
795880	794069	11056N	PARTICIPANT	\N	PRESENT	0
795881	794069	20022R	PARTICIPANT	\N	PRESENT	0
795882	794069	19679N	PARTICIPANT	\N	PRESENT	0
795883	794069	21080G	PARTICIPANT	\N	PRESENT	0
795884	794069	21046E	PARTICIPANT	\N	PRESENT	0
795885	794069	20116W	PARTICIPANT	\N	PRESENT	0
795886	795678	19701S	PARTICIPANT	\N	PRESENT	0
795887	795678	20076G	PARTICIPANT	\N	PRESENT	0
795888	795678	21042A	PARTICIPANT	\N	PRESENT	0
795889	795678	14219Q	PRESIDENT	0	PRESENT	0
795890	795678	19820Y	PARTICIPANT	\N	PRESENT	0
795891	795678	19826F	PARTICIPANT	\N	PRESENT	0
795892	795678	21062E	PARTICIPANT	\N	PRESENT	0
795893	795678	21065H	PARTICIPANT	\N	PRESENT	0
795894	795678	21084L	PARTICIPANT	\N	PRESENT	0
795895	795678	14237S	PARTICIPANT	\N	PRESENT	0
795808	794069	14229S	PARTICIPANT	\N	PRESENT	0
795809	794069	04047H	PARTICIPANT	\N	PRESENT	0
795896	795678	18083K	PARTICIPANT	\N	PRESENT	0
795897	795678	20100N	PARTICIPANT	\N	PRESENT	0
795898	795678	05012A	PARTICIPANT	\N	PRESENT	0
795899	795678	08060W	PARTICIPANT	\N	PRESENT	0
795900	795678	15197G	PARTICIPANT	\N	PRESENT	0
795901	795678	21080G	PARTICIPANT	\N	PRESENT	0
795902	795678	20020P	PARTICIPANT	\N	PRESENT	0
795903	795678	11065P	PARTICIPANT	\N	PRESENT	0
795904	795678	21051B	PARTICIPANT	\N	PRESENT	0
795905	795678	20120S	PARTICIPANT	\N	PRESENT	0
795906	795678	21053D	PARTICIPANT	\N	PRESENT	0
795907	795678	20032T	PARTICIPANT	\N	PRESENT	0
795908	795678	20136B	PARTICIPANT	\N	PRESENT	0
795909	795678	14031R	PARTICIPANT	\N	PRESENT	0
795910	795678	20040T	PARTICIPANT	\N	PRESENT	0
795911	795678	19251M	PARTICIPANT	\N	PRESENT	0
795912	795678	17229F	PARTICIPANT	\N	PRESENT	0
795913	795678	14169X	PARTICIPANT	\N	PRESENT	0
795914	795678	21047F	PARTICIPANT	\N	PRESENT	0
772543	769252	11040E	PARTICIPANT	\N	PRESENT	0
772544	769252	20134Y	PARTICIPANT	\N	PRESENT	0
772545	769252	21079P	PARTICIPANT	\N	PRESENT	0
772546	769252	21090J	PARTICIPANT	\N	PRESENT	0
772547	769252	20080C	PARTICIPANT	\N	PRESENT	0
772548	769252	14083S	PARTICIPANT	\N	PRESENT	0
772549	769252	07029T	PARTICIPANT	\N	PRESENT	0
772550	769252	20062A	PARTICIPANT	\N	PRESENT	0
772551	769252	11048N	PARTICIPANT	\N	PRESENT	0
772552	769252	20070A	PARTICIPANT	\N	PRESENT	0
772554	769252	19667J	PARTICIPANT	\N	PRESENT	0
772555	769252	21048G	PARTICIPANT	\N	PRESENT	0
772557	769252	21076L	PARTICIPANT	\N	PRESENT	0
772558	769252	19711U	PARTICIPANT	\N	PRESENT	0
772559	769252	20086J	PARTICIPANT	\N	PRESENT	0
772560	769252	19399H	PARTICIPANT	\N	PRESENT	0
772561	769252	19573D	PARTICIPANT	\N	PRESENT	0
772562	769252	14225N	PARTICIPANT	\N	PRESENT	0
772563	769252	19349W	PARTICIPANT	\N	PRESENT	0
772564	769252	20054A	PARTICIPANT	\N	PRESENT	0
772565	769252	20044X	PARTICIPANT	\N	PRESENT	0
772566	769252	21092L	PARTICIPANT	\N	PRESENT	0
772567	769252	19545Y	PARTICIPANT	\N	PRESENT	0
772568	769252	14327T	PARTICIPANT	\N	PRESENT	0
772569	769252	20116W	PARTICIPANT	\N	PRESENT	0
772570	769252	21096Q	PARTICIPANT	\N	PRESENT	0
772571	769252	11072N	PARTICIPANT	\N	PRESENT	0
772572	769252	08011M	PARTICIPANT	\N	PRESENT	0
772573	769252	21072G	PARTICIPANT	\N	PRESENT	0
772574	769252	21060C	PARTICIPANT	\N	PRESENT	0
772575	769252	14121F	PARTICIPANT	\N	PRESENT	0
772576	769252	19619A	PARTICIPANT	\N	PRESENT	0
772577	769252	20142Y	PARTICIPANT	\N	PRESENT	0
772578	769252	19647E	PARTICIPANT	\N	PRESENT	0
772579	769252	08010L	PARTICIPANT	\N	PRESENT	0
772580	769252	19687N	PARTICIPANT	\N	PRESENT	0
772581	769252	21029D	PARTICIPANT	\N	PRESENT	0
772582	769252	21088Q	PARTICIPANT	\N	PRESENT	0
772583	769252	20036X	PARTICIPANT	\N	PRESENT	0
772587	769252	20034V	PARTICIPANT	\N	PRESENT	0
772588	769252	20252E	PARTICIPANT	\N	PRESENT	0
772590	769252	20148F	PARTICIPANT	\N	PRESENT	0
772591	769252	14021P	PARTICIPANT	\N	PRESENT	0
772592	769252	01058X	PARTICIPANT	\N	PRESENT	0
772593	769252	21085M	PARTICIPANT	\N	PRESENT	0
772617	769252	11085T	PARTICIPANT	\N	PRESENT	0
772622	769252	14229S	PARTICIPANT	\N	PRESENT	0
772623	769252	21071F	PARTICIPANT	\N	PRESENT	0
772624	769252	21097R	PARTICIPANT	\N	PRESENT	0
772625	769252	19693L	PARTICIPANT	\N	PRESENT	0
772665	769253	19687N	PARTICIPANT	\N	PRESENT	0
772666	769253	20134Y	PARTICIPANT	\N	PRESENT	0
772667	769253	21079P	PARTICIPANT	\N	PRESENT	0
772668	769253	20142Y	PARTICIPANT	\N	PRESENT	0
772669	769253	19545Y	PARTICIPANT	\N	PRESENT	0
772670	769253	14083S	PARTICIPANT	\N	PRESENT	0
772671	769253	20116W	PARTICIPANT	\N	PRESENT	0
772698	769253	19693L	PARTICIPANT	\N	PRESENT	0
772673	769253	19711U	PARTICIPANT	\N	PRESENT	0
772674	769253	11048N	PARTICIPANT	\N	PRESENT	0
772675	769253	14225N	PARTICIPANT	\N	PRESENT	0
772699	769253	21092L	PARTICIPANT	\N	PRESENT	0
772700	769253	08010L	PARTICIPANT	\N	PRESENT	0
772701	769253	21048G	PARTICIPANT	\N	PRESENT	0
772679	769253	07029T	PARTICIPANT	\N	PRESENT	0
772680	769253	14121F	PARTICIPANT	\N	PRESENT	0
772681	769253	14021P	PARTICIPANT	\N	PRESENT	0
772682	769253	20070A	PARTICIPANT	\N	PRESENT	0
772683	769253	19647E	PARTICIPANT	\N	PRESENT	0
772684	769253	20080C	PARTICIPANT	\N	PRESENT	0
772685	769253	21096Q	PARTICIPANT	\N	PRESENT	0
772686	769253	14327T	PARTICIPANT	\N	PRESENT	0
772687	769253	19619A	PARTICIPANT	\N	PRESENT	0
772688	769253	19349W	PARTICIPANT	\N	PRESENT	0
772689	769253	21085M	PARTICIPANT	\N	PRESENT	0
772690	769253	21071F	PARTICIPANT	\N	PRESENT	0
772512	772509	19545Y	PARTICIPANT	\N	PRESENT	0
772513	772509	20080C	PARTICIPANT	\N	PRESENT	0
772514	772509	11053K	PARTICIPANT	\N	PRESENT	0
772515	772509	19667J	PARTICIPANT	\N	PRESENT	0
772516	772509	19671E	PARTICIPANT	\N	PRESENT	0
772517	772509	14225N	PRESIDENT	0	PRESENT	0
772518	772509	07029T	PARTICIPANT	\N	PRESENT	0
772519	772509	19573D	PARTICIPANT	\N	PRESENT	0
772520	772509	19349W	PARTICIPANT	\N	PRESENT	0
772521	772509	20116W	PARTICIPANT	\N	PRESENT	0
772522	772509	21090J	PARTICIPANT	\N	PRESENT	0
772523	772509	21048G	PARTICIPANT	\N	PRESENT	0
772524	772509	11048N	PARTICIPANT	\N	PRESENT	0
772525	772509	19647E	PARTICIPANT	\N	PRESENT	0
772691	769253	20044X	PARTICIPANT	\N	PRESENT	0
772527	772509	19711U	PARTICIPANT	\N	PRESENT	0
772692	769253	20086J	PARTICIPANT	\N	PRESENT	0
772529	772509	08011M	PARTICIPANT	\N	PRESENT	0
772530	772509	20044X	PARTICIPANT	\N	PRESENT	0
772531	772509	19399H	PARTICIPANT	\N	PRESENT	0
772532	772509	11040E	PARTICIPANT	\N	PRESENT	0
772533	772509	14083S	PARTICIPANT	\N	PRESENT	0
772534	772509	20062A	PARTICIPANT	\N	PRESENT	0
772693	769253	21090J	PARTICIPANT	\N	PRESENT	0
772536	772509	08073C	PARTICIPANT	\N	PRESENT	0
772537	772509	20070A	PARTICIPANT	\N	PRESENT	0
772538	772509	19741B	PARTICIPANT	\N	PRESENT	0
772694	769253	21072G	PARTICIPANT	\N	PRESENT	0
772540	772509	19762G	PARTICIPANT	\N	PRESENT	0
772695	769253	21088Q	PARTICIPANT	\N	PRESENT	0
772542	769252	19593H	PARTICIPANT	\N	PRESENT	0
772696	769253	20148F	PARTICIPANT	\N	PRESENT	0
772697	769253	20062A	PARTICIPANT	\N	PRESENT	0
772702	769253	08011M	PARTICIPANT	\N	PRESENT	0
772703	769253	20054A	PARTICIPANT	\N	PRESENT	0
772704	769253	21032X	PARTICIPANT	\N	PRESENT	0
772705	769253	19573D	PARTICIPANT	\N	PRESENT	0
772663	769253	14179A	PARTICIPANT	\N	PRESENT	0
772664	769253	11040E	PARTICIPANT	\N	PRESENT	0
772706	769253	08034U	PARTICIPANT	\N	PRESENT	0
772707	769253	11074Q	PARTICIPANT	\N	PRESENT	0
772708	769253	21029D	PARTICIPANT	\N	PRESENT	0
772709	769253	20032T	PARTICIPANT	\N	PRESENT	0
772710	769253	11053K	PARTICIPANT	\N	PRESENT	0
772711	769253	20036X	PARTICIPANT	\N	PRESENT	0
772712	769253	20034V	PARTICIPANT	\N	PRESENT	0
772713	769253	21082J	PARTICIPANT	\N	PRESENT	0
775561	772507	20130U	PARTICIPANT	\N	PRESENT	0
775562	772507	19798U	PARTICIPANT	\N	PRESENT	0
775563	772507	21094N	PARTICIPANT	\N	PRESENT	0
775564	772507	14026U	PARTICIPANT	\N	PRESENT	0
775565	772507	19553Y	PARTICIPANT	\N	PRESENT	0
775566	772507	21049H	PARTICIPANT	\N	PRESENT	0
775567	772507	14281W	PARTICIPANT	\N	PRESENT	0
775568	772507	14042U	PARTICIPANT	\N	PRESENT	0
775569	772507	08061X	PARTICIPANT	\N	PRESENT	0
775570	772507	14071N	PRESIDENT	0	PRESENT	0
775571	772507	14217N	PARTICIPANT	\N	PRESENT	0
775572	772507	21039F	PARTICIPANT	\N	PRESENT	0
775573	772507	19683J	PARTICIPANT	\N	PRESENT	0
775574	772507	19758L	PARTICIPANT	\N	PRESENT	0
775575	772507	19760E	PARTICIPANT	\N	PRESENT	0
775576	772507	14213J	PARTICIPANT	\N	EXCUSE	0
775577	772507	19691J	PARTICIPANT	\N	PRESENT	0
775578	772507	21081H	PARTICIPANT	\N	PRESENT	0
775583	772507	19569H	PARTICIPANT	\N	PRESENT	0
775587	772507	11045K	PARTICIPANT	\N	PRESENT	0
775594	772507	21045D	PARTICIPANT	\N	PRESENT	0
775599	772507	19713W	PARTICIPANT	\N	PRESENT	0
775611	775610	14225N	PRESIDENT	0	PRESENT	0
775612	775610	14173T	PARTICIPANT	\N	PRESENT	0
775613	775610	11040E	PARTICIPANT	\N	PRESENT	0
775614	775610	20086J	PARTICIPANT	\N	PRESENT	0
775615	775610	19711U	PARTICIPANT	\N	PRESENT	0
775616	775610	21090J	PARTICIPANT	\N	PRESENT	0
775617	775610	20050V	PARTICIPANT	\N	PRESENT	0
775618	775610	19335Q	PARTICIPANT	\N	PRESENT	0
775619	775610	11048N	PARTICIPANT	\N	PRESENT	0
775620	775610	08034U	PARTICIPANT	\N	PRESENT	0
775621	775610	19687N	PARTICIPANT	\N	PRESENT	0
775622	775610	20080C	PARTICIPANT	\N	PRESENT	0
775623	775610	08011M	PARTICIPANT	\N	PRESENT	0
775624	775610	20094J	PARTICIPANT	\N	PRESENT	0
775625	775610	19399H	PARTICIPANT	\N	PRESENT	0
775626	775610	14083S	PARTICIPANT	\N	PRESENT	0
787020	786616	21052C	PARTICIPANT	\N	PRESENT	0
787036	786616	19695N	PARTICIPANT	\N	PRESENT	0
787037	786616	14257W	PARTICIPANT	\N	PRESENT	0
787038	786616	20048C	PARTICIPANT	\N	PRESENT	0
787039	786616	19619A	PARTICIPANT	\N	PRESENT	0
787040	786616	20052X	PARTICIPANT	\N	PRESENT	0
787041	786616	14073Q	PARTICIPANT	\N	PRESENT	0
787130	786618	17779H	PARTICIPANT	\N	PRESENT	0
787131	786618	11056N	PARTICIPANT	\N	PRESENT	0
787132	786618	20046A	PARTICIPANT	\N	PRESENT	0
787133	786618	17965H	PARTICIPANT	\N	PRESENT	0
787134	786618	20082E	PARTICIPANT	\N	PRESENT	0
787135	786618	14257W	PARTICIPANT	\N	PRESENT	0
787136	786618	19631V	PARTICIPANT	\N	PRESENT	0
787137	786618	19820Y	PARTICIPANT	\N	PRESENT	0
787138	786618	20130U	PARTICIPANT	\N	PRESENT	0
787139	786618	21092L	PARTICIPANT	\N	PRESENT	0
787140	786618	20018V	PARTICIPANT	\N	PRESENT	0
787141	786618	21087P	PARTICIPANT	\N	PRESENT	0
787142	786618	21046E	PARTICIPANT	\N	PRESENT	0
787143	786618	19619A	PARTICIPANT	\N	PRESENT	0
787144	786618	19479G	PARTICIPANT	\N	PRESENT	0
787145	786618	21053D	PARTICIPANT	\N	PRESENT	0
787146	786618	19387D	PARTICIPANT	\N	PRESENT	0
787147	786618	20106U	PARTICIPANT	\N	PRESENT	0
787148	786618	19782L	PARTICIPANT	\N	PRESENT	0
787149	786618	20024T	PARTICIPANT	\N	PRESENT	0
787150	786618	20172F	PARTICIPANT	\N	PRESENT	0
787151	786618	20056C	PARTICIPANT	\N	PRESENT	0
787152	786618	07029T	PARTICIPANT	\N	PRESENT	0
787153	786618	21080G	PARTICIPANT	\N	PRESENT	0
787154	786618	20120S	PARTICIPANT	\N	PRESENT	0
787155	786618	14147R	PARTICIPANT	\N	PRESENT	0
787156	786618	21089R	PARTICIPANT	\N	PRESENT	0
787157	786618	20032T	PARTICIPANT	\N	PRESENT	0
787158	786618	19565D	PARTICIPANT	\N	PRESENT	0
787159	786618	19647E	PARTICIPANT	\N	PRESENT	0
787160	786618	18193Q	PARTICIPANT	\N	PRESENT	0
787161	786618	14083S	PARTICIPANT	\N	PRESENT	0
787162	786618	14179A	PARTICIPANT	\N	PRESENT	0
787163	786618	14021P	PARTICIPANT	\N	PRESENT	0
787164	786618	11065P	PARTICIPANT	\N	PRESENT	0
787165	786627	11045K	PARTICIPANT	\N	PRESENT	0
787166	786627	19760E	PARTICIPANT	\N	PRESENT	0
787167	786627	19866P	PARTICIPANT	\N	PRESENT	0
787168	786627	19301E	PARTICIPANT	\N	PRESENT	0
787169	786627	17965H	PARTICIPANT	\N	PRESENT	0
787170	786627	20130U	PARTICIPANT	\N	PRESENT	0
787171	786627	14281W	PARTICIPANT	\N	PRESENT	0
787172	786627	21046E	PARTICIPANT	\N	PRESENT	0
787173	786627	21087P	PARTICIPANT	\N	PRESENT	0
787174	786627	20140W	PARTICIPANT	\N	PRESENT	0
787175	786627	19679N	PARTICIPANT	\N	PRESENT	0
787176	786627	19691J	PARTICIPANT	\N	PRESENT	0
787177	786627	21081H	PARTICIPANT	\N	PRESENT	0
787178	786627	14071N	PRESIDENT	0	PRESENT	0
787179	786627	21064G	PARTICIPANT	\N	PRESENT	0
787180	786627	19657G	PARTICIPANT	\N	PRESENT	0
787181	786627	14213J	PARTICIPANT	\N	PRESENT	0
787182	786627	19703U	PARTICIPANT	\N	PRESENT	0
787183	786627	14355X	PARTICIPANT	\N	PRESENT	0
787184	786627	21039F	PARTICIPANT	\N	PRESENT	0
787185	786627	19798U	PARTICIPANT	\N	PRESENT	0
787186	786627	14223L	PARTICIPANT	\N	PRESENT	0
787187	786627	19758L	PARTICIPANT	\N	PRESENT	0
787188	786627	18193Q	PARTICIPANT	\N	PRESENT	0
787128	786618	14259Y	PARTICIPANT	\N	PRESENT	0
787129	786618	19413M	PARTICIPANT	\N	PRESENT	0
787189	786627	14195A	PARTICIPANT	\N	PRESENT	0
787190	786627	14217N	PARTICIPANT	\N	PRESENT	0
787191	786627	04092N	PARTICIPANT	\N	PRESENT	0
787192	786627	19713W	PARTICIPANT	\N	PRESENT	0
787193	786627	21045D	PARTICIPANT	\N	PRESENT	0
787194	786435	19798U	PARTICIPANT	\N	PRESENT	1
787195	786627	21094N	PARTICIPANT	\N	PRESENT	0
787196	786627	19683J	PARTICIPANT	\N	PRESENT	0
787197	786627	19629C	PARTICIPANT	\N	PRESENT	0
787198	786627	20248J	PARTICIPANT	\N	PRESENT	0
787199	786627	21071F	PARTICIPANT	\N	PRESENT	0
787201	786627	08061X	PARTICIPANT	\N	PRESENT	0
787202	786627	19553Y	PARTICIPANT	\N	PRESENT	0
787203	786627	19723Y	PARTICIPANT	\N	PRESENT	0
787204	786627	19591F	PARTICIPANT	\N	PRESENT	0
787206	786627	14042U	PARTICIPANT	\N	PRESENT	0
787207	786627	19569H	PARTICIPANT	\N	PRESENT	0
787208	786627	21097R	PARTICIPANT	\N	EXCUSE	0
787209	786627	20090E	PARTICIPANT	\N	EXCUSE	0
787238	787200	19573D	PARTICIPANT	\N	PRESENT	0
787239	787200	14327T	PARTICIPANT	\N	PRESENT	0
787243	787200	20080C	PARTICIPANT	\N	PRESENT	0
787244	787200	20070A	PARTICIPANT	\N	PRESENT	0
787247	786627	14026U	PARTICIPANT	\N	PRESENT	0
787285	787240	19699S	PARTICIPANT	\N	PRESENT	0
787286	787240	19533U	PARTICIPANT	\N	PRESENT	0
787287	787240	04033B	PARTICIPANT	\N	PRESENT	0
787288	787240	21058J	PARTICIPANT	\N	PRESENT	0
787289	787240	21059K	PARTICIPANT	\N	PRESENT	0
787290	787240	20102Q	PARTICIPANT	\N	PRESENT	0
787291	787240	14229S	PARTICIPANT	\N	PRESENT	0
787292	787240	19954N	PARTICIPANT	\N	PRESENT	0
787293	787240	21032X	PARTICIPANT	\N	PRESENT	0
787294	787240	21089R	PARTICIPANT	\N	PRESENT	0
787295	787240	08012N	PARTICIPANT	\N	PRESENT	0
787296	787240	21037D	PARTICIPANT	\N	PRESENT	0
787297	787240	21091K	PARTICIPANT	\N	PRESENT	0
787298	787240	20026V	PARTICIPANT	\N	PRESENT	0
787299	787240	19593H	PARTICIPANT	\N	PRESENT	0
787300	787240	20132W	PARTICIPANT	\N	PRESENT	0
787301	787240	14073Q	PARTICIPANT	\N	PRESENT	0
787302	787240	19611R	PRESIDENT	0	PRESENT	0
787303	787240	20138D	PARTICIPANT	\N	PRESENT	0
787304	787240	20142Y	PARTICIPANT	\N	PRESENT	0
787305	787240	20048C	PARTICIPANT	\N	PRESENT	0
787306	787240	19693L	PARTICIPANT	\N	PRESENT	0
787307	787240	20052X	PARTICIPANT	\N	PRESENT	0
787308	787240	20172F	PARTICIPANT	\N	PRESENT	0
787309	787240	14030Q	PARTICIPANT	\N	PRESENT	0
787310	787240	20058E	PARTICIPANT	\N	PRESENT	0
787311	787240	20056C	PARTICIPANT	\N	PRESENT	0
787312	787240	20180F	PARTICIPANT	\N	PRESENT	0
787313	787240	21063F	PARTICIPANT	\N	PRESENT	0
787314	787240	14109K	PARTICIPANT	\N	PRESENT	0
787315	787240	14123H	PARTICIPANT	\N	PRESENT	0
787316	787240	11043H	PARTICIPANT	\N	PRESENT	0
787317	787240	21077M	PARTICIPANT	\N	PRESENT	0
787318	787240	21078N	PARTICIPANT	\N	PRESENT	0
787319	787240	19621T	PARTICIPANT	\N	PRESENT	0
787320	787240	21074J	PARTICIPANT	\N	EXCUSE	0
787331	786627	17779H	PARTICIPANT	\N	PRESENT	0
787332	786627	20096L	PARTICIPANT	\N	PRESENT	0
787337	787240	20264J	PARTICIPANT	\N	PRESENT	0
787340	787200	19647E	PARTICIPANT	\N	PRESENT	0
787344	786627	21049H	PARTICIPANT	\N	PRESENT	0
787349	787348	19593H	PARTICIPANT	\N	PRESENT	0
787350	787348	20024T	PARTICIPANT	\N	PRESENT	0
787351	787348	19647E	PARTICIPANT	\N	PRESENT	0
787352	787348	14059S	PARTICIPANT	\N	PRESENT	0
787353	787348	08012N	PARTICIPANT	\N	PRESENT	0
787354	787348	14001X	PARTICIPANT	\N	PRESENT	0
787355	787348	21049H	PARTICIPANT	\N	PRESENT	0
787356	787348	20064C	PARTICIPANT	\N	PRESENT	0
787357	787242	17023S	PARTICIPANT	\N	PRESENT	0
787358	786195	21057H	PARTICIPANT	\N	PRESENT	0
787359	786195	19585H	PARTICIPANT	\N	PRESENT	0
787360	786195	04045F	PARTICIPANT	\N	PRESENT	0
787361	786195	04047H	PRESIDENT	0	PRESENT	0
787362	786195	19673G	PARTICIPANT	\N	PRESENT	0
787363	786195	19447X	PARTICIPANT	\N	PRESENT	0
787364	786195	05008E	PARTICIPANT	\N	PRESENT	0
787365	786195	14231L	PARTICIPANT	\N	PRESENT	0
787366	786195	19489J	PARTICIPANT	\N	PRESENT	0
787367	786195	14275Y	PARTICIPANT	\N	PRESENT	0
787368	786195	21056G	PARTICIPANT	\N	PRESENT	0
787369	786195	18207D	PARTICIPANT	\N	PRESENT	0
787370	786195	18231D	PARTICIPANT	\N	PRESENT	0
787371	786195	20110Q	PARTICIPANT	\N	PRESENT	0
787372	786195	21088Q	PARTICIPANT	\N	PRESENT	0
787373	786195	14147R	PARTICIPANT	\N	PRESENT	0
787374	786195	14151M	PARTICIPANT	\N	PRESENT	0
787375	786195	20114U	PARTICIPANT	\N	PRESENT	0
787376	786195	19111A	PARTICIPANT	\N	PRESENT	0
768348	765176	18231D	PARTICIPANT	\N	PRESENT	0
768357	765176	20124W	PARTICIPANT	\N	PRESENT	0
768358	765176	20056C	PARTICIPANT	\N	PRESENT	0
768359	765176	21058J	PARTICIPANT	\N	PRESENT	0
768360	765176	14109K	PARTICIPANT	\N	PRESENT	0
772433	772432	20100N	PARTICIPANT	\N	PRESENT	0
772434	772432	11065P	PARTICIPANT	\N	PRESENT	0
772437	772436	20100N	PARTICIPANT	\N	PRESENT	0
772439	772438	20100N	PARTICIPANT	\N	PRESENT	0
772445	772443	20100N	PARTICIPANT	\N	PRESENT	0
772447	772446	20100N	PARTICIPANT	\N	PRESENT	0
772450	772449	20100N	PARTICIPANT	\N	PRESENT	0
774719	772601	20028X	PARTICIPANT	\N	PRESENT	0
774801	772601	19768N	PARTICIPANT	\N	PRESENT	0
774721	772601	20018V	PARTICIPANT	\N	PRESENT	0
774722	772601	14109K	PARTICIPANT	\N	PRESENT	0
774723	772601	08056B	PARTICIPANT	\N	PRESENT	0
774724	772601	14257W	PARTICIPANT	\N	PRESENT	0
774725	772601	20124W	PARTICIPANT	\N	PRESENT	0
774726	772601	20126Y	PARTICIPANT	\N	PRESENT	0
774727	772601	20054A	PARTICIPANT	\N	PRESENT	0
774728	772601	20020P	PARTICIPANT	\N	PRESENT	0
774729	772601	21030V	PARTICIPANT	\N	PRESENT	0
774730	772601	20086J	PARTICIPANT	\N	PRESENT	0
774731	772601	20046A	PARTICIPANT	\N	PRESENT	0
774732	772601	20098N	PARTICIPANT	\N	PRESENT	0
774733	772601	21049H	PARTICIPANT	\N	PRESENT	0
774734	772601	19687N	PARTICIPANT	\N	PRESENT	0
774735	772601	21075K	PARTICIPANT	\N	PRESENT	0
774736	772601	20102Q	PARTICIPANT	\N	PRESENT	0
774737	772601	19383Y	PARTICIPANT	\N	PRESENT	0
774738	772601	19565D	PARTICIPANT	\N	PRESENT	0
774739	772601	19695N	PARTICIPANT	\N	PRESENT	0
774740	772601	14357A	PARTICIPANT	\N	PRESENT	0
774741	772601	11056N	PARTICIPANT	\N	PRESENT	0
774742	772601	19681G	PARTICIPANT	\N	PRESENT	0
774743	772601	07033P	PARTICIPANT	\N	PRESENT	0
774744	772601	21034A	PARTICIPANT	\N	PRESENT	0
774745	772601	21095P	PARTICIPANT	\N	PRESENT	0
774746	772601	19758L	PARTICIPANT	\N	PRESENT	0
774747	772601	21088Q	PARTICIPANT	\N	PRESENT	0
774748	772601	11040E	PARTICIPANT	\N	PRESENT	0
774749	772601	21090J	PARTICIPANT	\N	PRESENT	0
774750	772601	21084L	PARTICIPANT	\N	PRESENT	0
774751	772601	20112S	PARTICIPANT	\N	PRESENT	0
774752	772601	14217N	PARTICIPANT	\N	PRESENT	0
774753	772601	21048G	PARTICIPANT	\N	PRESENT	0
774754	772601	20120S	PARTICIPANT	\N	PRESENT	0
774755	772601	11065P	PARTICIPANT	\N	PRESENT	0
774756	772601	20100N	PARTICIPANT	\N	PRESENT	0
774757	772601	21092L	PARTICIPANT	\N	PRESENT	0
774758	772601	21093M	PARTICIPANT	\N	PRESENT	0
774759	772601	14069U	PARTICIPANT	\N	PRESENT	0
774760	772601	20142Y	PARTICIPANT	\N	PRESENT	0
774761	772601	21037D	PARTICIPANT	\N	PRESENT	0
774762	772601	19533U	PARTICIPANT	\N	PRESENT	0
774763	772601	20036X	PARTICIPANT	\N	PRESENT	0
774764	772601	20130U	PARTICIPANT	\N	PRESENT	0
774765	772601	20092G	PARTICIPANT	\N	PRESENT	0
774766	772601	21079P	PARTICIPANT	\N	PRESENT	0
774767	772601	14187A	PARTICIPANT	\N	PRESENT	0
774768	772601	21094N	PARTICIPANT	\N	PRESENT	0
774769	772601	14053L	PARTICIPANT	\N	PRESENT	0
774770	772601	19701S	PARTICIPANT	\N	PRESENT	0
774771	772601	04033B	PARTICIPANT	\N	PRESENT	0
774772	772601	21043B	PARTICIPANT	\N	PRESENT	0
774773	772601	19679N	PARTICIPANT	\N	PRESENT	0
774774	772601	19782L	PARTICIPANT	\N	PRESENT	0
774775	772601	20062A	PARTICIPANT	\N	PRESENT	0
774776	772601	21096Q	PARTICIPANT	\N	PRESENT	0
774777	772601	05008E	PARTICIPANT	\N	PRESENT	0
774778	772601	14249W	PARTICIPANT	\N	PRESENT	0
774779	772601	04092N	PARTICIPANT	\N	PRESENT	0
774780	772601	21033Y	PARTICIPANT	\N	PRESENT	0
774781	772601	11048N	PARTICIPANT	\N	PRESENT	0
774782	772601	20106U	PARTICIPANT	\N	PRESENT	0
774783	772601	20128B	PARTICIPANT	\N	PRESENT	0
774784	772601	19591F	PARTICIPANT	\N	PRESENT	0
774785	772601	14037X	PARTICIPANT	\N	PRESENT	0
774786	772601	08034U	PARTICIPANT	\N	PRESENT	0
774787	772601	19697Q	PARTICIPANT	\N	PRESENT	0
774788	772601	19331L	PARTICIPANT	\N	PRESENT	0
774789	772601	04047H	PARTICIPANT	\N	PRESENT	0
774790	772601	08061X	PARTICIPANT	\N	PRESENT	0
774791	772601	08010L	PARTICIPANT	\N	PRESENT	0
774792	772601	20146D	PARTICIPANT	\N	PRESENT	0
774793	772601	19349W	PARTICIPANT	\N	PRESENT	0
774794	772601	14026U	PARTICIPANT	\N	PRESENT	0
774795	772601	19703U	PARTICIPANT	\N	PRESENT	0
774796	772601	21074J	PARTICIPANT	\N	PRESENT	0
774797	772601	08018U	PARTICIPANT	\N	PRESENT	0
774798	772601	21085M	PARTICIPANT	\N	PRESENT	0
774799	772601	21069M	PARTICIPANT	\N	PRESENT	0
774800	772601	20116W	PARTICIPANT	\N	PRESENT	0
774802	772601	14207L	PARTICIPANT	\N	PRESENT	0
774803	772601	19629C	PARTICIPANT	\N	PRESENT	0
774804	772601	21041Y	PARTICIPANT	\N	PRESENT	0
774805	772601	19719D	PARTICIPANT	\N	PRESENT	0
774806	772601	14231L	PARTICIPANT	\N	PRESENT	0
774807	772601	17229F	PARTICIPANT	\N	PRESENT	0
774808	772601	20132W	PARTICIPANT	\N	PRESENT	0
774809	772601	20286Q	PARTICIPANT	\N	PRESENT	0
774810	772601	19691J	PARTICIPANT	\N	PRESENT	0
774811	772601	19553Y	PARTICIPANT	\N	PRESENT	0
774812	772601	19387D	PARTICIPANT	\N	PRESENT	0
774813	772601	14327T	PARTICIPANT	\N	PRESENT	0
774814	772601	21066J	PARTICIPANT	\N	PRESENT	0
774815	772601	14089Y	PARTICIPANT	\N	PRESENT	0
774816	772601	04070G	PARTICIPANT	\N	PRESENT	0
774817	772601	20072C	PARTICIPANT	\N	PRESENT	0
774818	772601	21078N	PARTICIPANT	\N	PRESENT	0
774819	772601	21050A	PARTICIPANT	\N	PRESENT	0
774820	772601	21040X	PARTICIPANT	\N	PRESENT	0
774821	772601	19111A	PARTICIPANT	\N	PRESENT	0
774822	772601	19866P	PARTICIPANT	\N	PRESENT	0
774823	772601	14179A	PARTICIPANT	\N	PRESENT	0
774824	772601	20066E	PARTICIPANT	\N	PRESENT	0
774825	772601	11085T	PARTICIPANT	\N	PRESENT	0
774826	772601	14107H	PARTICIPANT	\N	PRESENT	0
774827	772601	14267Y	PARTICIPANT	\N	PRESENT	0
774828	772601	15197G	PARTICIPANT	\N	PRESENT	0
774829	772601	21064G	PARTICIPANT	\N	PRESENT	0
774830	772601	19545Y	PARTICIPANT	\N	PRESENT	0
774831	772601	21038E	PARTICIPANT	\N	PRESENT	0
774832	772601	14195A	PARTICIPANT	\N	PRESENT	0
774833	772601	14189C	PARTICIPANT	\N	PRESENT	0
774834	772601	21065H	PARTICIPANT	\N	PRESENT	0
774835	772601	19563B	PARTICIPANT	\N	PRESENT	0
774836	772601	19693L	PARTICIPANT	\N	PRESENT	0
774837	772601	21087P	PARTICIPANT	\N	PRESENT	0
774838	772601	14251Q	PARTICIPANT	\N	PRESENT	0
774839	772601	14111D	PARTICIPANT	\N	PRESENT	0
774850	772601	14083S	PARTICIPANT	\N	PRESENT	0
774841	772601	20050V	PARTICIPANT	\N	PRESENT	0
774842	772601	21070E	PARTICIPANT	\N	PRESENT	0
774843	772601	20122U	PARTICIPANT	\N	PRESENT	0
774844	772601	19826F	PARTICIPANT	\N	PRESENT	0
774845	772601	21053D	PARTICIPANT	\N	PRESENT	0
774846	772601	19713W	PARTICIPANT	\N	PRESENT	0
774847	772601	19749K	PARTICIPANT	\N	PRESENT	0
774848	772601	11070L	PARTICIPANT	\N	PRESENT	0
774849	772601	14221J	PARTICIPANT	\N	PRESENT	0
774851	772601	20042V	PARTICIPANT	\N	PRESENT	0
774852	772601	19647E	PARTICIPANT	\N	PRESENT	0
774853	772601	19335Q	PARTICIPANT	\N	PRESENT	0
774854	772601	21083K	PARTICIPANT	\N	PRESENT	0
774855	772601	17023S	PARTICIPANT	\N	PRESENT	0
774856	772601	21059K	PARTICIPANT	\N	PRESENT	0
774857	772601	14205J	PARTICIPANT	\N	PRESENT	0
774858	772601	21067K	PARTICIPANT	\N	PRESENT	0
774859	772601	19685L	PARTICIPANT	\N	PRESENT	0
774860	772601	20248J	PARTICIPANT	\N	PRESENT	0
774861	772601	20266L	PARTICIPANT	\N	PRESENT	0
774862	772601	20264J	PARTICIPANT	\N	PRESENT	0
774863	772601	18395Y	PARTICIPANT	\N	PRESENT	0
774864	772601	21062E	PARTICIPANT	\N	PRESENT	0
774865	772601	19551W	PARTICIPANT	\N	PRESENT	0
774866	772601	14121F	PARTICIPANT	\N	PRESENT	0
774867	772601	19531S	PARTICIPANT	\N	PRESENT	0
774868	772601	18193Q	PARTICIPANT	\N	PRESENT	0
774869	772601	86034E	PARTICIPANT	\N	PRESENT	0
795922	794069	21056G	PARTICIPANT	\N	PRESENT	0
795923	794069	20064C	PARTICIPANT	\N	PRESENT	0
795924	794069	19545Y	PARTICIPANT	\N	PRESENT	0
795925	794069	14257W	PARTICIPANT	\N	PRESENT	0
795926	794069	20026V	PARTICIPANT	\N	PRESENT	0
795927	794069	14133K	PARTICIPANT	\N	PRESENT	0
795928	794069	19349W	PARTICIPANT	\N	PRESENT	0
795929	794069	21062E	PARTICIPANT	\N	PRESENT	0
795930	794069	21058J	PARTICIPANT	\N	PRESENT	0
795931	794069	21081H	PARTICIPANT	\N	PRESENT	0
795932	794069	14033T	PARTICIPANT	\N	PRESENT	0
795933	794069	14021P	PARTICIPANT	\N	PRESENT	0
795934	794069	21045D	PARTICIPANT	\N	PRESENT	0
795935	794069	19479G	PARTICIPANT	\N	PRESENT	0
795936	794069	07029T	PARTICIPANT	\N	PRESENT	0
795977	794073	11040E	PARTICIPANT	\N	PRESENT	0
795978	794073	21087P	PARTICIPANT	\N	PRESENT	0
795979	794073	07004J	PARTICIPANT	\N	PRESENT	0
795980	794073	20090E	PARTICIPANT	\N	PRESENT	0
795981	794073	19679N	PARTICIPANT	\N	PRESENT	0
795982	794073	19447X	PARTICIPANT	\N	PRESENT	0
795983	794073	20074E	PARTICIPANT	\N	PRESENT	0
795984	794073	04047H	PARTICIPANT	\N	PRESENT	0
795985	794073	08018U	PARTICIPANT	\N	PRESENT	0
795986	794073	20100N	PARTICIPANT	\N	PRESENT	0
795987	794073	21066J	PARTICIPANT	\N	PRESENT	0
795988	794073	19719D	PARTICIPANT	\N	PRESENT	0
795989	794073	19565D	PARTICIPANT	\N	PRESENT	0
795990	794073	14215L	PARTICIPANT	\N	PRESENT	0
795991	794073	11072N	PARTICIPANT	\N	PRESENT	0
795992	794073	19687N	PARTICIPANT	\N	PRESENT	0
795993	794073	20110Q	PARTICIPANT	\N	PRESENT	0
795994	794073	19111A	PARTICIPANT	\N	PRESENT	0
795995	794073	19826F	PARTICIPANT	\N	PRESENT	0
795996	794073	20114U	PARTICIPANT	\N	PRESENT	0
796000	794073	20050V	PARTICIPANT	\N	PRESENT	0
795998	794073	14147R	PARTICIPANT	\N	PRESENT	0
795999	794073	20180F	PARTICIPANT	\N	PRESENT	0
796001	794073	19531S	PARTICIPANT	\N	PRESENT	0
796002	794073	21056G	PARTICIPANT	\N	PRESENT	0
796003	794073	21047F	PARTICIPANT	\N	PRESENT	0
796131	795678	21061D	PARTICIPANT	\N	EXCUSE	0
796166	796165	19711U	PARTICIPANT	\N	PRESENT	1
796167	796165	20094J	PARTICIPANT	\N	PRESENT	1
796293	794852	21091K	PARTICIPANT	\N	PRESENT	0
796294	794850	21091K	PARTICIPANT	\N	PRESENT	0
796353	796352	20094J	PARTICIPANT	\N	PRESENT	1
796354	796352	14133K	PARTICIPANT	\N	PRESENT	1
796393	796085	20054A	PARTICIPANT	\N	PRESENT	0
795915	795678	20068G	PARTICIPANT	\N	PRESENT	0
795916	795678	21068L	PARTICIPANT	\N	PRESENT	0
795917	795678	21070E	PARTICIPANT	\N	PRESENT	0
795918	795678	19551W	PARTICIPANT	\N	EXCUSE	0
795919	795678	19681G	PARTICIPANT	\N	EXCUSE	0
795921	794069	21069M	PARTICIPANT	\N	PRESENT	0
796394	796085	21034A	PARTICIPANT	\N	PRESENT	0
796395	796085	14205J	PARTICIPANT	\N	PRESENT	0
796396	796085	20060X	PARTICIPANT	\N	PRESENT	0
796397	796085	19507S	PARTICIPANT	\N	PRESENT	0
795975	794073	11090Q	PARTICIPANT	\N	PRESENT	0
795976	794073	20092G	PARTICIPANT	\N	PRESENT	0
796398	796085	21066J	PARTICIPANT	\N	PRESENT	0
796399	796085	20286Q	PARTICIPANT	\N	PRESENT	0
796400	796085	14207L	PARTICIPANT	\N	PRESENT	0
796401	796085	14257W	PARTICIPANT	\N	PRESENT	0
796402	796085	20084G	PARTICIPANT	\N	PRESENT	0
796403	796085	21052C	PARTICIPANT	\N	EXCUSE	0
796404	796085	20104S	PARTICIPANT	\N	EXCUSE	0
796405	793595	14109K	PARTICIPANT	\N	EXCUSE	0
796406	793595	21061D	PARTICIPANT	\N	EXCUSE	0
796407	793595	20130U	PARTICIPANT	\N	EXCUSE	0
796408	793595	20098N	PARTICIPANT	\N	EXCUSE	0
796409	793595	21042A	PARTICIPANT	\N	EXCUSE	0
796410	793595	14030Q	PARTICIPANT	\N	EXCUSE	0
796411	793595	14147R	PARTICIPANT	\N	EXCUSE	0
796412	793595	21091K	PARTICIPANT	\N	EXCUSE	0
796413	794752	20096L	PARTICIPANT	\N	PRESENT	0
796414	794752	21087P	PARTICIPANT	\N	PRESENT	0
796415	794752	17965H	PARTICIPANT	\N	PRESENT	0
796416	794703	04042C	PARTICIPANT	\N	PRESENT	0
796418	796417	14255U	PARTICIPANT	\N	PRESENT	0
796420	796419	19647E	PARTICIPANT	\N	PRESENT	0
796421	796419	21036C	PARTICIPANT	\N	PRESENT	0
796422	794711	19725B	PARTICIPANT	\N	PRESENT	0
796423	794711	21043B	PARTICIPANT	\N	PRESENT	0
796424	794711	21044C	PARTICIPANT	\N	PRESENT	0
796425	794711	19489J	PARTICIPANT	\N	PRESENT	0
796426	794711	19649G	PARTICIPANT	\N	PRESENT	0
796427	794711	21056G	PARTICIPANT	\N	PRESENT	0
796428	794711	20074E	PARTICIPANT	\N	PRESENT	0
796429	794711	18207D	PARTICIPANT	\N	PRESENT	0
796430	794711	18231D	PARTICIPANT	\N	PRESENT	0
796431	794711	14147R	PARTICIPANT	\N	PRESENT	0
796432	794711	19111A	PARTICIPANT	\N	PRESENT	0
796433	794711	04047H	PRESIDENT	0	PRESENT	0
796434	794711	20036X	PARTICIPANT	\N	EXCUSE	0
796435	794711	19585H	PARTICIPANT	\N	EXCUSE	0
796437	796436	07033P	PARTICIPANT	\N	PRESENT	0
796438	796436	21086N	PARTICIPANT	\N	PRESENT	0
796439	796436	17023S	PARTICIPANT	\N	PRESENT	0
796440	796436	14179A	PARTICIPANT	\N	PRESENT	0
796441	796436	14059S	PARTICIPANT	\N	PRESENT	0
796442	796436	21053D	PARTICIPANT	\N	PRESENT	0
796443	796436	21068L	PARTICIPANT	\N	PRESENT	0
796444	796436	21059K	PARTICIPANT	\N	PRESENT	0
796445	796436	14147R	PARTICIPANT	\N	PRESENT	0
796447	795681	19798U	PARTICIPANT	\N	PRESENT	0
796448	795681	08060W	PARTICIPANT	\N	PRESENT	0
796449	795681	19679N	PARTICIPANT	\N	PRESENT	0
796450	795681	19331L	PARTICIPANT	\N	PRESENT	0
796451	795681	21039F	PARTICIPANT	\N	PRESENT	0
796452	795681	11065P	PARTICIPANT	\N	PRESENT	0
796453	795681	21051B	PARTICIPANT	\N	PRESENT	0
796454	795681	21053D	PARTICIPANT	\N	PRESENT	0
796455	795681	20032T	PARTICIPANT	\N	PRESENT	0
796456	795681	04092N	PARTICIPANT	\N	PRESENT	0
796457	795681	20040T	PARTICIPANT	\N	PRESENT	0
796458	795681	20046A	PARTICIPANT	\N	PRESENT	0
796459	795681	19691J	PARTICIPANT	\N	PRESENT	0
796460	795681	17229F	PARTICIPANT	\N	PRESENT	0
796461	795681	21047F	PARTICIPANT	\N	PRESENT	0
796462	795681	20068G	PARTICIPANT	\N	PRESENT	0
796463	795681	21068L	PARTICIPANT	\N	PRESENT	0
796464	795681	21070E	PARTICIPANT	\N	PRESENT	0
796465	795681	21081H	PARTICIPANT	\N	PRESENT	0
796466	795681	21082J	PARTICIPANT	\N	PRESENT	0
796467	795681	19701S	PARTICIPANT	\N	PRESENT	0
796468	795681	14355X	PARTICIPANT	\N	PRESENT	0
796469	795681	21035B	PARTICIPANT	\N	PRESENT	0
796470	795681	19569H	PARTICIPANT	\N	PRESENT	0
796471	795681	20076G	PARTICIPANT	\N	PRESENT	0
796472	795681	21042A	PARTICIPANT	\N	PRESENT	0
796473	795681	21045D	PARTICIPANT	\N	PRESENT	0
796474	795681	21060C	PARTICIPANT	\N	PRESENT	0
796475	795681	14223L	PARTICIPANT	\N	PRESENT	0
796476	795681	18193Q	PARTICIPANT	\N	PRESENT	0
796477	795681	14026U	PARTICIPANT	\N	PRESENT	0
796478	795681	21062E	PARTICIPANT	\N	PRESENT	0
796479	795681	20096L	PARTICIPANT	\N	PRESENT	0
796480	795681	21065H	PARTICIPANT	\N	PRESENT	0
796481	795681	14237S	PARTICIPANT	\N	PRESENT	0
796482	795681	21084L	PARTICIPANT	\N	PRESENT	0
796483	795681	20100N	PARTICIPANT	\N	PRESENT	0
796484	795681	18083K	PARTICIPANT	\N	PRESENT	0
796485	795681	05012A	PARTICIPANT	\N	PRESENT	0
796486	795681	19703U	PARTICIPANT	\N	PRESENT	0
796487	795681	21087P	PARTICIPANT	\N	PRESENT	0
796488	795681	20106U	PARTICIPANT	\N	PRESENT	0
796489	795681	14107H	PARTICIPANT	\N	PRESENT	0
796490	795681	21080G	PARTICIPANT	\N	PRESENT	0
796491	795681	14195A	PARTICIPANT	\N	PRESENT	0
796492	795681	14213J	PARTICIPANT	\N	PRESENT	0
796493	795681	14031R	PRESIDENT	0	PRESENT	0
796494	795681	19713W	PARTICIPANT	\N	PRESENT	0
796495	795681	11045K	PARTICIPANT	\N	PRESENT	0
796496	795681	08045X	PARTICIPANT	\N	PRESENT	0
796497	795681	20140W	PARTICIPANT	\N	PRESENT	0
796498	795681	19251M	PARTICIPANT	\N	PRESENT	0
796499	795681	17965H	PARTICIPANT	\N	PRESENT	0
796500	795681	19723Y	PARTICIPANT	\N	PRESENT	0
796501	795681	20248J	PARTICIPANT	\N	PRESENT	0
770711	765753	19593H	PARTICIPANT	\N	PRESENT	0
770712	765753	20132W	PARTICIPANT	\N	PRESENT	0
770713	765753	19699S	PARTICIPANT	\N	PRESENT	0
770714	765753	21055F	PARTICIPANT	\N	PRESENT	0
770715	765753	19533U	PARTICIPANT	\N	PRESENT	0
770716	765753	19611R	PRESIDENT	0	PRESENT	0
770717	765753	20142Y	PARTICIPANT	\N	PRESENT	0
770718	765753	21059K	PARTICIPANT	\N	PRESENT	0
770719	765753	19693L	PARTICIPANT	\N	PRESENT	0
770720	765753	20102Q	PARTICIPANT	\N	PRESENT	0
770721	765753	20052X	PARTICIPANT	\N	PRESENT	0
770722	765753	14229S	PARTICIPANT	\N	PRESENT	0
770723	765753	20058E	PARTICIPANT	\N	PRESENT	0
770724	765753	20056C	PARTICIPANT	\N	PRESENT	0
770725	765753	20264J	PARTICIPANT	\N	PRESENT	0
770726	765753	18395Y	PARTICIPANT	\N	PRESENT	0
770727	765753	20112S	PARTICIPANT	\N	PRESENT	0
770728	765753	14109K	PARTICIPANT	\N	PRESENT	0
770729	765753	21089R	PARTICIPANT	\N	PRESENT	0
770730	765753	21091K	PARTICIPANT	\N	PRESENT	0
770731	765753	21074J	PARTICIPANT	\N	PRESENT	0
770732	765753	21077M	PARTICIPANT	\N	PRESENT	0
770733	765753	21078N	PARTICIPANT	\N	PRESENT	0
770734	769539	21041Y	PARTICIPANT	\N	PRESENT	0
770736	769539	11074Q	PARTICIPANT	\N	PRESENT	0
770739	769539	21069M	PARTICIPANT	\N	PRESENT	0
770740	769539	07029T	PARTICIPANT	\N	PRESENT	0
770741	769539	19687N	PARTICIPANT	\N	PRESENT	0
770743	768940	19489J	PARTICIPANT	\N	PRESENT	0
770744	768940	14275Y	PARTICIPANT	\N	PRESENT	0
770745	768940	18207D	PARTICIPANT	\N	PRESENT	0
770746	768940	18231D	PARTICIPANT	\N	PRESENT	0
770747	768940	21088Q	PARTICIPANT	\N	PRESENT	0
770748	768940	20114U	PARTICIPANT	\N	PRESENT	0
770749	768940	21038E	PARTICIPANT	\N	PRESENT	0
770750	768940	21095P	PARTICIPANT	\N	PRESENT	0
770751	768940	14053L	PARTICIPANT	\N	PRESENT	0
770752	768940	10015M	PARTICIPANT	\N	PRESENT	0
770753	768940	21076L	PARTICIPANT	\N	PRESENT	0
770754	768940	19725B	PARTICIPANT	\N	PRESENT	0
770755	768940	14089Y	PARTICIPANT	\N	PRESENT	0
770756	768940	14069U	PARTICIPANT	\N	PRESENT	0
770757	768940	11085T	PARTICIPANT	\N	PRESENT	0
770759	769539	19335Q	PARTICIPANT	\N	PRESENT	0
770760	769539	20080C	PARTICIPANT	\N	PRESENT	0
770761	769539	19479G	PARTICIPANT	\N	PRESENT	0
770762	769539	08010L	PARTICIPANT	\N	PRESENT	0
770763	769539	08011M	PARTICIPANT	\N	PRESENT	0
770764	769539	19573D	PARTICIPANT	\N	PRESENT	0
770767	769539	14189C	PARTICIPANT	\N	EXCUSE	0
770770	769539	20062A	PARTICIPANT	\N	PRESENT	0
770772	768940	20098N	PARTICIPANT	\N	PRESENT	0
770773	768940	14259Y	PARTICIPANT	\N	PRESENT	0
770774	768940	20266L	PARTICIPANT	\N	PRESENT	0
770775	768940	04008A	PARTICIPANT	\N	PRESENT	0
770776	769539	21079P	PARTICIPANT	\N	PRESENT	0
770778	765753	04070G	PARTICIPANT	\N	PRESENT	0
770779	765753	19954N	PARTICIPANT	\N	PRESENT	0
770780	765753	21037D	PARTICIPANT	\N	PRESENT	0
770781	765753	08012N	PARTICIPANT	\N	PRESENT	0
770782	765753	20124W	PARTICIPANT	\N	PRESENT	0
770783	765753	20026V	PARTICIPANT	\N	PRESENT	0
770784	765753	14073Q	PARTICIPANT	\N	PRESENT	0
770785	765753	20138D	PARTICIPANT	\N	PRESENT	0
770786	765753	14030Q	PARTICIPANT	\N	PRESENT	0
770787	765753	20180F	PARTICIPANT	\N	PRESENT	0
770788	765753	21063F	PARTICIPANT	\N	PRESENT	0
770789	765753	19735D	PARTICIPANT	\N	PRESENT	0
770790	765753	14123H	PARTICIPANT	\N	PRESENT	0
770791	765753	11043H	PARTICIPANT	\N	PRESENT	0
770792	769539	14033T	PARTICIPANT	\N	PRESENT	0
770794	769539	20024T	PARTICIPANT	\N	PRESENT	0
770795	770561	20088L	PARTICIPANT	\N	PRESENT	0
770796	770561	19768N	PARTICIPANT	\N	PRESENT	0
770797	770561	20092G	PARTICIPANT	\N	PRESENT	0
770798	770561	14357A	PARTICIPANT	\N	PRESENT	0
770799	770561	20078J	PARTICIPANT	\N	PRESENT	0
770800	770561	19413M	PARTICIPANT	\N	PRESENT	0
770801	770561	14221J	PARTICIPANT	\N	PRESENT	0
770802	770561	19631V	PARTICIPANT	\N	PRESENT	0
770803	770561	19575F	PARTICIPANT	\N	PRESENT	0
770804	770561	08028W	PARTICIPANT	\N	PRESENT	0
770805	770561	19563B	PARTICIPANT	\N	PRESENT	0
770806	770561	21050A	PARTICIPANT	\N	PRESENT	0
770807	770561	14329V	PARTICIPANT	\N	PRESENT	0
770808	770561	21052C	PARTICIPANT	\N	PRESENT	0
770809	770561	14038Y	PARTICIPANT	\N	PRESENT	0
770810	770561	20030R	PARTICIPANT	\N	PRESENT	0
770811	770561	14187A	PRESIDENT	0	PRESENT	0
770812	770561	21075K	PARTICIPANT	\N	PRESENT	0
770813	770561	20038A	PARTICIPANT	\N	PRESENT	0
770814	770561	21083K	PARTICIPANT	\N	PRESENT	0
770815	770561	21086N	PARTICIPANT	\N	PRESENT	0
770816	770561	19695N	PARTICIPANT	\N	PRESENT	0
770817	770561	11090Q	PARTICIPANT	\N	PRESENT	0
770818	770561	21033Y	PARTICIPANT	\N	PRESENT	0
770819	770561	14205J	PARTICIPANT	\N	PRESENT	0
770820	770561	21066J	PARTICIPANT	\N	PRESENT	0
770821	770561	20286Q	PARTICIPANT	\N	PRESENT	0
770822	770561	14207L	PARTICIPANT	\N	PRESENT	0
770823	770561	20084G	PARTICIPANT	\N	PRESENT	0
770824	770561	14257W	PARTICIPANT	\N	PRESENT	0
770825	770561	20060X	PARTICIPANT	\N	EXCUSE	0
770826	770561	14331P	PARTICIPANT	\N	PRESENT	0
770827	770561	20034V	PARTICIPANT	\N	PRESENT	0
770828	770561	21092L	PARTICIPANT	\N	PRESENT	0
770831	769539	20086J	PARTICIPANT	\N	PRESENT	0
770832	770561	20104S	PARTICIPANT	\N	PRESENT	0
770833	769539	20050V	PARTICIPANT	\N	PRESENT	0
770841	769539	08073C	PARTICIPANT	\N	PRESENT	0
770842	769539	21048G	PARTICIPANT	\N	PRESENT	0
770843	769539	14173T	PARTICIPANT	\N	PRESENT	0
770846	769539	20136B	PARTICIPANT	\N	PRESENT	0
770848	769539	14083S	PARTICIPANT	\N	PRESENT	0
770862	768940	21057H	PARTICIPANT	\N	PRESENT	0
770863	768940	05008E	PARTICIPANT	\N	PRESENT	0
770864	768940	19111A	PARTICIPANT	\N	PRESENT	0
770865	768940	20022R	PARTICIPANT	\N	PRESENT	0
770866	768940	20036X	PARTICIPANT	\N	PRESENT	0
770867	768940	11056N	PARTICIPANT	\N	PRESENT	0
770868	768940	19585H	PARTICIPANT	\N	PRESENT	0
770870	768940	20110Q	PARTICIPANT	\N	PRESENT	0
770919	769539	11110B	PARTICIPANT	\N	PRESENT	0
770927	769348	21036C	PARTICIPANT	\N	PRESENT	0
770928	769348	21030V	PARTICIPANT	\N	PRESENT	0
770929	769348	95041E	PARTICIPANT	\N	PRESENT	0
770930	769348	20072C	PARTICIPANT	\N	PRESENT	0
770931	769348	19565D	PARTICIPANT	\N	PRESENT	0
770932	769348	01058X	PARTICIPANT	\N	PRESENT	0
770933	769348	11027H	PARTICIPANT	\N	PRESENT	0
770934	769348	14001X	PARTICIPANT	\N	PRESENT	0
770935	769348	04042C	PARTICIPANT	\N	PRESENT	0
770936	769348	08056B	PARTICIPANT	\N	PRESENT	0
770937	769348	12028B	PARTICIPANT	\N	PRESENT	0
770938	769348	17737W	PARTICIPANT	\N	PRESENT	0
770939	769348	11115U	PARTICIPANT	\N	PRESENT	0
770940	769348	14055N	PARTICIPANT	\N	PRESENT	0
770941	769348	19421M	PARTICIPANT	\N	PRESENT	0
770942	769348	19709B	PARTICIPANT	\N	PRESENT	0
770943	769348	21067K	PARTICIPANT	\N	PRESENT	0
770944	769348	14193X	PRESIDENT	0	PRESENT	0
770945	769348	19347U	PARTICIPANT	\N	PRESENT	0
770946	769348	14179A	PARTICIPANT	\N	PRESENT	0
770947	769348	07033P	PARTICIPANT	\N	PRESENT	0
770948	769348	17367Q	PARTICIPANT	\N	PRESENT	0
770949	769348	14249W	PARTICIPANT	\N	PRESENT	0
770950	769348	08047A	PARTICIPANT	\N	PRESENT	0
770951	769348	20128B	PARTICIPANT	\N	PRESENT	0
770952	769348	14037X	PARTICIPANT	\N	PRESENT	0
770953	769348	14097Y	PARTICIPANT	\N	PRESENT	0
770954	769348	21073H	PARTICIPANT	\N	PRESENT	0
770955	769348	19531S	PARTICIPANT	\N	PRESENT	0
770956	769348	14191V	PARTICIPANT	\N	PRESENT	0
770957	769348	19721W	PARTICIPANT	\N	PRESENT	0
770958	769348	20064C	PARTICIPANT	\N	PRESENT	0
770959	769348	14251Q	PARTICIPANT	\N	PRESENT	0
770960	769348	20252E	PARTICIPANT	\N	PRESENT	0
770961	769348	98022P	PARTICIPANT	\N	PRESENT	0
770962	769348	14267Y	PARTICIPANT	\N	PRESENT	0
770963	769348	99004R	PARTICIPANT	\N	PRESENT	0
770964	769348	19745F	PARTICIPANT	\N	PRESENT	0
786179	786178	04070G	PARTICIPANT	\N	PRESENT	0
787377	786195	14215L	PARTICIPANT	\N	PRESENT	0
787378	786195	21038E	PARTICIPANT	\N	PRESENT	0
787379	786195	20022R	PARTICIPANT	\N	PRESENT	0
787380	786195	21095P	PARTICIPANT	\N	PRESENT	0
787381	786195	11072N	PARTICIPANT	\N	PRESENT	0
787382	786195	14053L	PARTICIPANT	\N	PRESENT	0
787383	786195	14111D	PARTICIPANT	\N	PRESENT	0
787384	786195	19649G	PARTICIPANT	\N	PRESENT	0
787385	786195	14189C	PARTICIPANT	\N	PRESENT	0
787386	786195	21076L	PARTICIPANT	\N	PRESENT	0
787387	786195	19719D	PARTICIPANT	\N	PRESENT	0
787388	786195	21040X	PARTICIPANT	\N	PRESENT	0
787389	786195	19725B	PARTICIPANT	\N	PRESENT	0
787390	786195	14089Y	PARTICIPANT	\N	PRESENT	0
787391	786195	21043B	PARTICIPANT	\N	PRESENT	0
787392	786195	21044C	PARTICIPANT	\N	PRESENT	0
787393	786195	19729F	PARTICIPANT	\N	PRESENT	0
787394	786195	04008A	PARTICIPANT	\N	PRESENT	0
787395	786195	19749K	PARTICIPANT	\N	PRESENT	0
787396	786627	01034P	PARTICIPANT	\N	PRESENT	0
787397	787242	20042V	PARTICIPANT	\N	EXCUSE	0
787398	787242	01058X	PARTICIPANT	\N	EXCUSE	0
787399	787200	08034U	PARTICIPANT	\N	PRESENT	0
787400	786195	08018U	PARTICIPANT	\N	PRESENT	0
787401	786195	11056N	PARTICIPANT	\N	PRESENT	0
787402	786195	14069U	PARTICIPANT	\N	PRESENT	0
787403	787120	19383Y	PARTICIPANT	\N	PRESENT	0
787404	787120	20092G	PARTICIPANT	\N	PRESENT	0
787405	787120	19782L	PARTICIPANT	\N	PRESENT	0
787406	787120	14357A	PARTICIPANT	\N	PRESENT	0
787407	787120	20078J	PARTICIPANT	\N	PRESENT	0
787408	787120	19631V	PARTICIPANT	\N	PRESENT	0
787409	787120	19705W	PARTICIPANT	\N	PRESENT	0
787410	787120	08015R	PARTICIPANT	\N	PRESENT	0
787411	787120	19575F	PARTICIPANT	\N	PRESENT	0
787412	787120	20018V	PARTICIPANT	\N	PRESENT	0
787413	787120	19563B	PARTICIPANT	\N	PRESENT	0
787414	787120	08028W	PARTICIPANT	\N	PRESENT	0
787415	787120	21050A	PARTICIPANT	\N	PRESENT	0
787416	787120	20028X	PARTICIPANT	\N	PRESENT	0
787417	787120	14329V	PARTICIPANT	\N	PRESENT	0
787418	787120	14038Y	PARTICIPANT	\N	PRESENT	0
787419	787120	21052C	PARTICIPANT	\N	PRESENT	0
787420	787120	20034V	PARTICIPANT	\N	PRESENT	0
787421	787120	21054E	PARTICIPANT	\N	PRESENT	0
787422	787120	20038A	PARTICIPANT	\N	PRESENT	0
787423	787120	21075K	PARTICIPANT	\N	PRESENT	0
787424	787120	14187A	PRESIDENT	0	PRESENT	0
787425	787120	21083K	PARTICIPANT	\N	PRESENT	0
787426	787120	21086N	PARTICIPANT	\N	PRESENT	0
787427	787120	20144B	PARTICIPANT	\N	PRESENT	0
787428	787120	19695N	PARTICIPANT	\N	PRESENT	0
787429	787120	21092L	PARTICIPANT	\N	PRESENT	0
787430	787120	14033T	PARTICIPANT	\N	PRESENT	0
787431	787120	11090Q	PARTICIPANT	\N	PRESENT	0
787432	787120	21093M	PARTICIPANT	\N	PRESENT	0
787433	787120	20054A	PARTICIPANT	\N	PRESENT	0
787434	787120	21034A	PARTICIPANT	\N	PRESENT	0
787435	787120	14205J	PARTICIPANT	\N	PRESENT	0
787436	787120	20060X	PARTICIPANT	\N	PRESENT	0
787437	787120	19507S	PARTICIPANT	\N	PRESENT	0
787438	787120	21066J	PARTICIPANT	\N	PRESENT	0
787439	787120	20286Q	PARTICIPANT	\N	PRESENT	0
787440	787120	14207L	PARTICIPANT	\N	PRESENT	0
787441	787120	14257W	PARTICIPANT	\N	PRESENT	0
787442	787120	20066E	PARTICIPANT	\N	EXCUSE	0
787443	787120	20104S	PARTICIPANT	\N	EXCUSE	0
787449	787200	08009T	PARTICIPANT	\N	PRESENT	0
787459	786625	20086J	PARTICIPANT	\N	PRESENT	0
787460	786625	14327T	PARTICIPANT	\N	PRESENT	0
787461	786625	19545Y	PARTICIPANT	\N	PRESENT	0
787462	786625	20080C	PARTICIPANT	\N	PRESENT	0
787463	786625	11053K	PARTICIPANT	\N	PRESENT	0
787464	786625	19667J	PARTICIPANT	\N	PRESENT	0
787465	786625	11074Q	PARTICIPANT	\N	PRESENT	0
787466	786625	14225N	PRESIDENT	0	PRESENT	0
787467	786625	07029T	PARTICIPANT	\N	PRESENT	0
787468	786625	19573D	PARTICIPANT	\N	PRESENT	0
787469	786625	21079P	PARTICIPANT	\N	PRESENT	0
787470	786625	19349W	PARTICIPANT	\N	PRESENT	0
787471	786625	14253S	PARTICIPANT	\N	PRESENT	0
787472	786625	21090J	PARTICIPANT	\N	PRESENT	0
787473	786625	20126Y	PARTICIPANT	\N	PRESENT	0
787474	786625	19647E	PARTICIPANT	\N	PRESENT	0
787475	786625	19711U	PARTICIPANT	\N	PRESENT	0
787476	786625	19687N	PARTICIPANT	\N	PRESENT	0
787477	786625	20044X	PARTICIPANT	\N	PRESENT	0
787478	786625	19399H	PARTICIPANT	\N	PRESENT	0
787479	786625	21041Y	PARTICIPANT	\N	PRESENT	0
787480	786625	14083S	PARTICIPANT	\N	PRESENT	0
787481	786625	08009T	PARTICIPANT	\N	PRESENT	0
787482	786625	20070A	PARTICIPANT	\N	PRESENT	0
787483	786625	14121F	PARTICIPANT	\N	PRESENT	0
787484	786625	11048N	PARTICIPANT	\N	PRESENT	0
787485	786195	20098N	PARTICIPANT	\N	PRESENT	0
787486	786195	11085T	PARTICIPANT	\N	PRESENT	0
787488	786625	08010L	PARTICIPANT	\N	PRESENT	0
787489	786625	08034U	PARTICIPANT	\N	PRESENT	0
787500	786625	19479G	PARTICIPANT	\N	PRESENT	0
787501	786625	21072G	PARTICIPANT	\N	PRESENT	0
787508	786627	19295A	PARTICIPANT	\N	PRESENT	0
787516	787514	19575F	PARTICIPANT	\N	PRESENT	0
787517	787514	20114U	PARTICIPANT	\N	PRESENT	0
787518	787514	21057H	PARTICIPANT	\N	PRESENT	0
787519	787514	14357A	PARTICIPANT	\N	PRESENT	0
787520	787514	20038A	PARTICIPANT	\N	PRESENT	0
787521	787514	19565D	PARTICIPANT	\N	PRESENT	0
787522	787514	20132W	PARTICIPANT	\N	PRESENT	0
787523	787514	20126Y	PARTICIPANT	\N	PRESENT	0
787524	787514	18207D	PARTICIPANT	\N	PRESENT	0
787525	787514	20096L	PARTICIPANT	\N	PRESENT	0
787526	787514	21059K	PARTICIPANT	\N	PRESENT	0
787527	787514	04045F	PARTICIPANT	\N	PRESENT	0
787528	787514	21051B	PARTICIPANT	\N	PRESENT	0
787529	787514	21031W	PARTICIPANT	\N	PRESENT	0
787530	787514	19749K	PARTICIPANT	\N	PRESENT	0
787531	787514	21076L	PARTICIPANT	\N	PRESENT	0
787532	787514	21082J	PARTICIPANT	\N	PRESENT	0
787533	787514	19709B	PARTICIPANT	\N	PRESENT	0
787535	787242	08056B	PARTICIPANT	\N	PRESENT	0
787536	787205	19820Y	PARTICIPANT	\N	PRESENT	0
787537	787205	19826F	PARTICIPANT	\N	PRESENT	0
787538	787205	19551W	PARTICIPANT	\N	PRESENT	0
787539	787205	08060W	PARTICIPANT	\N	PRESENT	0
787540	787205	15197G	PARTICIPANT	\N	PRESENT	0
787541	787205	19331L	PARTICIPANT	\N	PRESENT	0
787542	787205	20020P	PARTICIPANT	\N	PRESENT	0
787544	787205	11065P	PARTICIPANT	\N	PRESENT	0
787545	787205	21051B	PARTICIPANT	\N	PRESENT	0
787546	787205	20032T	PARTICIPANT	\N	PRESENT	0
787547	787205	21053D	PARTICIPANT	\N	PRESENT	0
787548	787205	20040T	PARTICIPANT	\N	PRESENT	0
787549	787205	20046A	PARTICIPANT	\N	PRESENT	0
787550	787205	17229F	PARTICIPANT	\N	PRESENT	0
787551	787205	20068G	PARTICIPANT	\N	PRESENT	0
787552	787205	21068L	PARTICIPANT	\N	PRESENT	0
787553	787205	21070E	PARTICIPANT	\N	PRESENT	0
787554	787205	21082J	PARTICIPANT	\N	PRESENT	0
787555	787205	19701S	PARTICIPANT	\N	PRESENT	0
787556	787205	20076G	PARTICIPANT	\N	PRESENT	0
787557	787205	21042A	PARTICIPANT	\N	PRESENT	0
787558	787205	19387D	PARTICIPANT	\N	PRESENT	0
787559	787205	14219Q	PRESIDENT	0	PRESENT	0
787561	787205	21060C	PARTICIPANT	\N	PRESENT	0
787563	787205	19599P	PARTICIPANT	\N	PRESENT	0
787564	787205	21062E	PARTICIPANT	\N	PRESENT	0
787566	787205	21065H	PARTICIPANT	\N	PRESENT	0
787567	787205	14237S	PARTICIPANT	\N	PRESENT	0
787568	787205	18083K	PARTICIPANT	\N	PRESENT	0
787570	787205	21084L	PARTICIPANT	\N	PRESENT	0
787571	787205	05012A	PARTICIPANT	\N	PRESENT	0
787572	787205	20106U	PARTICIPANT	\N	PRESENT	0
787573	787205	20118Y	PARTICIPANT	\N	PRESENT	0
787574	787205	14107H	PARTICIPANT	\N	PRESENT	0
787575	787205	19503N	PARTICIPANT	\N	PRESENT	0
772474	772361	14327T	PARTICIPANT	\N	PRESENT	0
772475	772361	20086J	PARTICIPANT	\N	PRESENT	0
772476	772361	19545Y	PARTICIPANT	\N	PRESENT	0
772477	772361	20080C	PARTICIPANT	\N	PRESENT	0
772478	772361	11074Q	PARTICIPANT	\N	PRESENT	0
772479	772361	20094J	PARTICIPANT	\N	PRESENT	0
772480	772361	14225N	PARTICIPANT	\N	PRESENT	0
772481	772361	07029T	PARTICIPANT	\N	PRESENT	0
772482	772361	21079P	PARTICIPANT	\N	PRESENT	0
772483	772361	19349W	PARTICIPANT	\N	PRESENT	0
772484	772361	21090J	PARTICIPANT	\N	PRESENT	0
772485	772361	20116W	PARTICIPANT	\N	PRESENT	0
772486	772361	19335Q	PARTICIPANT	\N	PRESENT	0
772487	772361	20024T	PARTICIPANT	\N	PRESENT	0
772488	772361	11048N	PARTICIPANT	\N	PRESENT	0
772489	772361	19647E	PARTICIPANT	\N	PRESENT	0
772490	772361	20134Y	PARTICIPANT	\N	PRESENT	0
772491	772361	19711U	PARTICIPANT	\N	PRESENT	0
772492	772361	08034U	PARTICIPANT	\N	PRESENT	0
772493	772361	19687N	PARTICIPANT	\N	PRESENT	0
772494	772361	08011M	PARTICIPANT	\N	PRESENT	0
772495	772361	20044X	PARTICIPANT	\N	PRESENT	0
772496	772361	19399H	PARTICIPANT	\N	PRESENT	0
772497	772361	11040E	PARTICIPANT	\N	PRESENT	0
772498	772361	20062A	PARTICIPANT	\N	PRESENT	0
772499	772361	20070A	PARTICIPANT	\N	PRESENT	0
772500	769250	14037X	PARTICIPANT	\N	PRESENT	0
772501	769250	19693L	PARTICIPANT	\N	PRESENT	0
773239	773236	11048N	PARTICIPANT	\N	PRESENT	0
773242	773241	11048N	PARTICIPANT	\N	PRESENT	0
773250	772441	21097R	PARTICIPANT	\N	EXCUSE	0
774870	772601	20082E	PARTICIPANT	\N	PRESENT	0
774871	772601	14219Q	PARTICIPANT	\N	PRESENT	0
774872	772601	21031W	PARTICIPANT	\N	PRESENT	0
774873	772601	21077M	PARTICIPANT	\N	PRESENT	0
774874	772601	11053K	PARTICIPANT	\N	PRESENT	0
774875	772601	14225N	PARTICIPANT	\N	PRESENT	0
774876	772601	19705W	PARTICIPANT	\N	PRESENT	0
774877	772601	18083K	PARTICIPANT	\N	PRESENT	0
774878	772601	14030Q	PARTICIPANT	\N	PRESENT	0
774879	772601	19721W	PARTICIPANT	\N	PRESENT	0
774880	772601	20144B	PARTICIPANT	\N	PRESENT	0
774881	772601	14042U	PARTICIPANT	\N	PRESENT	0
774882	772601	07004J	PARTICIPANT	\N	PRESENT	0
774883	772601	20048C	PARTICIPANT	\N	PRESENT	0
774884	772601	19735D	PARTICIPANT	\N	PRESENT	0
774885	772601	19611R	PARTICIPANT	\N	PRESENT	0
774886	772601	19699S	PARTICIPANT	\N	PRESENT	0
774887	772601	01034P	PARTICIPANT	\N	PRESENT	0
774888	772601	19479G	PARTICIPANT	\N	PRESENT	0
774889	772601	20056C	PARTICIPANT	\N	PRESENT	0
774890	772601	17737W	PARTICIPANT	\N	PRESENT	0
774891	772601	19631V	PARTICIPANT	\N	PRESENT	0
774892	772601	14255U	PARTICIPANT	\N	PRESENT	0
774893	772601	20136B	PARTICIPANT	\N	PRESENT	0
774894	772601	20022R	PARTICIPANT	\N	PRESENT	0
774895	772601	04045F	PARTICIPANT	\N	PRESENT	0
774896	772601	11072N	PARTICIPANT	\N	PRESENT	0
774897	772601	14215L	PARTICIPANT	\N	PRESENT	0
774898	772601	20038A	PARTICIPANT	\N	PRESENT	0
774899	772601	20052X	PARTICIPANT	\N	PRESENT	0
774900	772601	19301E	PARTICIPANT	\N	PRESENT	0
774901	772601	14281W	PARTICIPANT	\N	PRESENT	0
774902	772601	19569H	PARTICIPANT	\N	PRESENT	0
775197	772600	14179A	PARTICIPANT	\N	PRESENT	0
774904	772601	14331P	PARTICIPANT	\N	PRESENT	0
774905	772601	20094J	PARTICIPANT	\N	PRESENT	0
775199	772600	20128B	PARTICIPANT	\N	PRESENT	0
775200	772600	20070A	PARTICIPANT	\N	PRESENT	0
775201	772600	14121F	PARTICIPANT	\N	PRESENT	0
775202	772600	20080C	PARTICIPANT	\N	PRESENT	0
775203	772600	21082J	PARTICIPANT	\N	PRESENT	0
775204	772600	21059K	PARTICIPANT	\N	PRESENT	0
775205	772600	12016W	PARTICIPANT	\N	PRESENT	0
775206	772600	20094J	PARTICIPANT	\N	PRESENT	0
775207	772600	21079P	PARTICIPANT	\N	PRESENT	0
775208	772600	19545Y	PARTICIPANT	\N	PRESENT	0
775209	772600	14195A	PARTICIPANT	\N	PRESENT	0
775210	772600	19719D	PARTICIPANT	\N	PRESENT	0
775211	772600	14207L	PARTICIPANT	\N	PRESENT	0
775212	772600	21066J	PARTICIPANT	\N	PRESENT	0
775213	772600	19691J	PARTICIPANT	\N	PRESENT	0
775214	772600	19479G	PARTICIPANT	\N	PRESENT	0
775215	772600	21053D	PARTICIPANT	\N	PRESENT	0
775216	772600	14205J	PARTICIPANT	\N	PRESENT	0
775217	772600	14073Q	PARTICIPANT	\N	PRESENT	0
775218	772600	20086J	PARTICIPANT	\N	PRESENT	0
775219	772600	08034U	PARTICIPANT	\N	PRESENT	0
775220	772600	11053K	PARTICIPANT	\N	PRESENT	0
775221	772600	19798U	PARTICIPANT	\N	PRESENT	0
775222	772600	20062A	PARTICIPANT	\N	PRESENT	0
775223	772600	21040X	PARTICIPANT	\N	PRESENT	0
775224	772600	19349W	PARTICIPANT	\N	PRESENT	0
775225	772600	20060X	PARTICIPANT	\N	PRESENT	0
775226	772600	05012A	PARTICIPANT	\N	PRESENT	0
775227	772600	21087P	PARTICIPANT	\N	PRESENT	0
775228	772600	11074Q	PARTICIPANT	\N	PRESENT	0
775229	772600	11040E	PARTICIPANT	\N	PRESENT	0
775230	772600	20090E	PARTICIPANT	\N	PRESENT	0
775231	772600	20112S	PARTICIPANT	\N	PRESENT	0
775232	772600	20102Q	PARTICIPANT	\N	PRESENT	0
775233	772600	20046A	PARTICIPANT	\N	PRESENT	0
775234	772600	19533U	PARTICIPANT	\N	PRESENT	0
775235	772600	18083K	PARTICIPANT	\N	PRESENT	0
775236	772600	21090J	PARTICIPANT	\N	PRESENT	0
775237	772600	19711U	PARTICIPANT	\N	PRESENT	0
775238	772600	15197G	PARTICIPANT	\N	PRESENT	0
775239	772600	07004J	PARTICIPANT	\N	PRESENT	0
775240	772600	11070L	PARTICIPANT	\N	PRESENT	0
775241	772600	20024T	PARTICIPANT	\N	PRESENT	0
775242	772600	20032T	PARTICIPANT	\N	PRESENT	0
775243	772600	21063F	PARTICIPANT	\N	PRESENT	0
775244	772600	14173T	PARTICIPANT	\N	PRESENT	0
775245	772600	21039F	PARTICIPANT	\N	PRESENT	0
775246	772600	21068L	PARTICIPANT	\N	PRESENT	0
775247	772600	21058J	PARTICIPANT	\N	PRESENT	0
775248	772600	20096L	PARTICIPANT	\N	PRESENT	0
775249	772600	20180F	PARTICIPANT	\N	PRESENT	0
775250	772600	19735D	PARTICIPANT	\N	PRESENT	0
775251	772600	14191V	PARTICIPANT	\N	PRESENT	0
775252	772600	20044X	PARTICIPANT	\N	PRESENT	0
775253	772600	20054A	PARTICIPANT	\N	PRESENT	0
775254	772600	19575F	PARTICIPANT	\N	PRESENT	0
775255	772600	11043H	PARTICIPANT	\N	PRESENT	0
775256	772600	14213J	PARTICIPANT	\N	PRESENT	0
775257	772600	07029T	PARTICIPANT	\N	PRESENT	0
775258	772600	14083S	PARTICIPANT	\N	PRESENT	0
775259	772600	20092G	PARTICIPANT	\N	PRESENT	0
775260	772600	20098N	PARTICIPANT	\N	PRESENT	0
775261	772600	21048G	PARTICIPANT	\N	PRESENT	0
775262	772600	20116W	PARTICIPANT	\N	PRESENT	0
775263	772600	20052X	PARTICIPANT	\N	PRESENT	0
775264	772600	08015R	PARTICIPANT	\N	PRESENT	0
775266	772600	20138D	PARTICIPANT	\N	PRESENT	0
775267	772600	19565D	PARTICIPANT	\N	PRESENT	0
775282	772600	19681G	PARTICIPANT	\N	PRESENT	0
775283	772600	14215L	PARTICIPANT	\N	PRESENT	0
775284	772600	21070E	PARTICIPANT	\N	PRESENT	0
775285	772600	20048C	PARTICIPANT	\N	PRESENT	0
775286	772600	14053L	PARTICIPANT	\N	PRESENT	0
775287	772600	20058E	PARTICIPANT	\N	PRESENT	0
775288	772600	14259Y	PARTICIPANT	\N	PRESENT	0
775289	772600	10015M	PARTICIPANT	\N	PRESENT	0
775290	772600	21049H	PARTICIPANT	\N	PRESENT	0
775291	772600	20026V	PARTICIPANT	\N	PRESENT	0
775292	772600	20056C	PARTICIPANT	\N	PRESENT	0
775293	772600	19647E	PARTICIPANT	\N	PRESENT	0
775294	772600	19699S	PARTICIPANT	\N	PRESENT	0
775295	772600	21084L	PARTICIPANT	\N	PRESENT	0
775296	772600	17023S	PARTICIPANT	\N	PRESENT	0
775297	772600	19629C	PARTICIPANT	\N	PRESENT	0
775298	772600	19695N	PARTICIPANT	\N	PRESENT	0
775299	772600	21055F	PARTICIPANT	\N	PRESENT	0
775300	772600	08061X	PARTICIPANT	\N	PRESENT	0
775301	772600	19611R	PARTICIPANT	\N	PRESENT	0
775302	772600	14069U	PARTICIPANT	\N	PRESENT	0
775303	772600	20100N	PARTICIPANT	\N	PRESENT	0
775304	772600	19563B	PARTICIPANT	\N	PRESENT	0
775305	772600	19531S	PARTICIPANT	\N	PRESENT	0
775306	772600	08011M	PARTICIPANT	\N	PRESENT	0
775307	772600	19335Q	PARTICIPANT	\N	PRESENT	0
775308	772600	19758L	PARTICIPANT	\N	PRESENT	0
775309	772600	14331P	PARTICIPANT	\N	PRESENT	0
785140	783366	21071F	PARTICIPANT	\N	EXCUSE	0
785141	783366	21045D	PARTICIPANT	\N	PRESENT	0
785142	783366	21081H	PARTICIPANT	\N	PRESENT	0
785143	783366	21046E	PARTICIPANT	\N	PRESENT	0
785144	783366	14213J	PARTICIPANT	\N	PRESENT	0
785145	783366	21087P	PARTICIPANT	\N	PRESENT	0
785146	783366	19569H	PARTICIPANT	\N	PRESENT	0
785147	783366	19758L	PARTICIPANT	\N	PRESENT	0
785148	783366	14071N	PRESIDENT	0	PRESENT	0
785149	783366	19703U	PARTICIPANT	\N	PRESENT	0
785150	783366	19798U	PARTICIPANT	\N	PRESENT	0
785151	783366	20090E	PARTICIPANT	\N	PRESENT	0
785152	783366	20140W	PARTICIPANT	\N	PRESENT	0
785153	783366	14195A	PARTICIPANT	\N	PRESENT	0
785154	783366	14217N	PARTICIPANT	\N	PRESENT	0
785155	783366	19679N	PARTICIPANT	\N	PRESENT	0
785156	783366	19691J	PARTICIPANT	\N	PRESENT	0
785157	783366	14042U	PARTICIPANT	\N	PRESENT	0
785158	783366	21064G	PARTICIPANT	\N	PRESENT	0
785159	783366	18193Q	PARTICIPANT	\N	PRESENT	0
785160	783366	04092N	PARTICIPANT	\N	PRESENT	0
785161	783366	17965H	PARTICIPANT	\N	PRESENT	0
785162	783366	19723Y	PARTICIPANT	\N	PRESENT	0
785163	783366	14281W	PARTICIPANT	\N	PRESENT	0
785183	783366	21039F	PARTICIPANT	\N	PRESENT	0
785192	783366	20248J	PARTICIPANT	\N	PRESENT	0
785208	783366	17779H	PARTICIPANT	\N	PRESENT	0
785209	783366	14026U	PARTICIPANT	\N	PRESENT	0
785224	783366	01034P	PARTICIPANT	\N	PRESENT	0
785231	783366	19713W	PARTICIPANT	\N	PRESENT	0
791849	791848	14038Y	PARTICIPANT	\N	PRESENT	0
791850	791848	04070G	PARTICIPANT	\N	PRESENT	0
791851	791848	14169X	PARTICIPANT	\N	PRESENT	0
791852	791848	21078N	PARTICIPANT	\N	PRESENT	0
791853	791848	14229S	PARTICIPANT	\N	PRESENT	0
791854	791848	19693L	PARTICIPANT	\N	PRESENT	0
791855	791848	20134Y	PARTICIPANT	\N	PRESENT	0
791856	791848	20044X	PARTICIPANT	\N	PRESENT	0
791857	791848	18207D	PARTICIPANT	\N	PRESENT	0
791858	791848	20082E	PARTICIPANT	\N	PRESENT	0
791859	791848	21032X	PARTICIPANT	\N	PRESENT	0
791860	791848	19533U	PARTICIPANT	\N	PRESENT	0
791861	791848	21038E	PARTICIPANT	\N	PRESENT	0
791862	791848	21053D	PARTICIPANT	\N	PRESENT	0
791863	791848	14069U	PARTICIPANT	\N	PRESENT	0
791864	791848	20060X	PARTICIPANT	\N	PRESENT	0
791865	791848	20132W	PARTICIPANT	\N	PRESENT	0
791866	791848	21084L	PARTICIPANT	\N	PRESENT	0
796502	795681	19657G	PARTICIPANT	\N	PRESENT	0
796503	795681	19758L	PARTICIPANT	\N	PRESENT	0
796504	795681	19760E	PARTICIPANT	\N	PRESENT	0
796505	795681	19685L	PARTICIPANT	\N	EXCUSE	0
796506	795681	19681G	PARTICIPANT	\N	EXCUSE	0
796507	795681	21061D	PARTICIPANT	\N	EXCUSE	0
796508	794753	21036C	PARTICIPANT	\N	PRESENT	0
796509	794753	21030V	PARTICIPANT	\N	PRESENT	0
796510	794753	19565D	PARTICIPANT	\N	PRESENT	0
796511	794753	20072C	PARTICIPANT	\N	PRESENT	0
796512	794753	21031W	PARTICIPANT	\N	PRESENT	0
796513	794753	19669L	PARTICIPANT	\N	PRESENT	0
796514	794753	08056B	PARTICIPANT	\N	PRESENT	0
796515	794753	19421M	PARTICIPANT	\N	PRESENT	0
796516	794753	21067K	PARTICIPANT	\N	PRESENT	0
796517	794753	14193X	PRESIDENT	0	PRESENT	0
796518	794753	14179A	PARTICIPANT	\N	PRESENT	0
796519	794753	17367Q	PARTICIPANT	\N	PRESENT	0
796520	794753	20128B	PARTICIPANT	\N	PRESENT	0
796521	794753	08047A	PARTICIPANT	\N	PRESENT	0
796522	794753	14037X	PARTICIPANT	\N	PRESENT	0
796523	794753	14059S	PARTICIPANT	\N	PRESENT	0
796524	794753	14133K	PRESIDENT	1	PRESENT	0
796525	794753	19531S	PARTICIPANT	\N	PRESENT	0
796526	794753	19721W	PARTICIPANT	\N	PRESENT	0
796527	794753	14191V	PARTICIPANT	\N	PRESENT	0
796528	794753	20064C	PARTICIPANT	\N	PRESENT	0
796529	794753	14251Q	PARTICIPANT	\N	PRESENT	0
796530	794753	20252E	PARTICIPANT	\N	PRESENT	0
796531	794753	14267Y	PARTICIPANT	\N	PRESENT	0
796532	794753	19745F	PARTICIPANT	\N	PRESENT	0
796533	794753	14255U	PARTICIPANT	\N	PRESENT	0
796534	794753	17023S	PARTICIPANT	\N	PRESENT	0
796535	794753	17737W	PARTICIPANT	\N	EXCUSE	0
796536	794753	98022P	PARTICIPANT	\N	EXCUSE	0
796537	794753	19709B	PARTICIPANT	\N	EXCUSE	0
796538	794753	14211G	PARTICIPANT	\N	EXCUSE	0
796539	793595	21044C	PARTICIPANT	\N	EXCUSE	0
796540	793595	14223L	PARTICIPANT	\N	EXCUSE	0
796559	796545	14187A	PARTICIPANT	\N	PRESENT	0
796560	796545	19383Y	PARTICIPANT	\N	PRESENT	0
796561	796545	21083K	PARTICIPANT	\N	PRESENT	0
796562	796545	20082E	PARTICIPANT	\N	PRESENT	0
796563	796545	21066J	PARTICIPANT	\N	PRESENT	0
796564	796545	19782L	PARTICIPANT	\N	PRESENT	0
796590	796541	20038A	PARTICIPANT	\N	PRESENT	0
796591	796541	20056C	PARTICIPANT	\N	PRESENT	0
796593	796592	19954N	PARTICIPANT	\N	PRESENT	0
796594	796592	21046E	PARTICIPANT	\N	PRESENT	0
796595	796592	19545Y	PARTICIPANT	\N	PRESENT	0
796596	796592	14357A	PARTICIPANT	\N	PRESENT	0
796597	796592	14179A	PARTICIPANT	\N	PRESENT	0
796598	796592	11048N	PARTICIPANT	\N	PRESENT	0
796599	796592	08015R	PARTICIPANT	\N	PRESENT	0
796600	796592	08034U	PARTICIPANT	\N	PRESENT	0
796601	796592	19563B	PARTICIPANT	\N	PRESENT	0
796602	796592	14147R	PARTICIPANT	\N	PRESENT	0
796603	794694	11065P	PARTICIPANT	\N	PRESENT	0
796604	794694	21047F	PARTICIPANT	\N	PRESENT	0
796605	795681	19551W	PARTICIPANT	\N	EXCUSE	0
796606	795681	14219Q	PARTICIPANT	\N	EXCUSE	0
796607	794075	86034E	PARTICIPANT	\N	PRESENT	0
796608	794075	21087P	PARTICIPANT	\N	PRESENT	0
796609	794075	21031W	PARTICIPANT	\N	PRESENT	0
796610	794075	19798U	PARTICIPANT	\N	PRESENT	0
796611	794075	20024T	PARTICIPANT	\N	PRESENT	0
796612	794075	20252E	PARTICIPANT	\N	PRESENT	0
796613	794075	14215L	PARTICIPANT	\N	PRESENT	0
796614	794075	14073Q	PARTICIPANT	\N	PRESENT	0
796615	794075	14231L	PARTICIPANT	\N	PRESENT	0
796616	794075	21068L	PARTICIPANT	\N	PRESENT	0
796617	794075	21081H	PARTICIPANT	\N	PRESENT	0
796618	794075	14030Q	PARTICIPANT	\N	PRESENT	0
796619	794075	11040E	PARTICIPANT	\N	PRESENT	0
796620	794075	19721W	PARTICIPANT	\N	PRESENT	0
796621	794075	20030R	PARTICIPANT	\N	PRESENT	0
796622	794075	21077M	PARTICIPANT	\N	PRESENT	0
796623	794075	19691J	PARTICIPANT	\N	PRESENT	0
796624	794075	19111A	PARTICIPANT	\N	PRESENT	0
796625	794075	19745F	PARTICIPANT	\N	PRESENT	0
796626	794075	14107H	PARTICIPANT	\N	PRESENT	0
796627	794075	08018U	PARTICIPANT	\N	PRESENT	0
796628	794075	21039F	PARTICIPANT	\N	PRESENT	0
796629	794075	08028W	PARTICIPANT	\N	PRESENT	0
796630	794075	21053D	PARTICIPANT	\N	PRESENT	0
796631	794075	19826F	PARTICIPANT	\N	PRESENT	0
796632	794075	14267Y	PARTICIPANT	\N	PRESENT	0
796633	794075	14111D	PARTICIPANT	\N	PRESENT	0
796634	794075	19703U	PARTICIPANT	\N	PRESENT	0
796635	794075	21040X	PARTICIPANT	\N	PRESENT	0
796636	794075	14219Q	PARTICIPANT	\N	PRESENT	0
796637	794075	21044C	PARTICIPANT	\N	PRESENT	0
796638	794075	07004J	PARTICIPANT	\N	PRESENT	0
796639	794075	14195A	PARTICIPANT	\N	PRESENT	0
796640	794075	04045F	PARTICIPANT	\N	PRESENT	0
796641	794075	14257W	PARTICIPANT	\N	PRESENT	0
796642	794075	21080G	PARTICIPANT	\N	PRESENT	0
796643	794075	08047A	PARTICIPANT	\N	PRESENT	0
796644	794075	20046A	PARTICIPANT	\N	PRESENT	0
796645	794075	20074E	PARTICIPANT	\N	PRESENT	0
796646	794075	19619A	PARTICIPANT	\N	PRESENT	0
796647	794075	19713W	PARTICIPANT	\N	PRESENT	0
796648	794075	20084G	PARTICIPANT	\N	PRESENT	0
768366	765176	19693L	PARTICIPANT	\N	PRESENT	0
768368	765176	14030Q	PARTICIPANT	\N	PRESENT	0
768371	765176	19749K	PARTICIPANT	\N	PRESENT	0
770965	769348	14211G	PARTICIPANT	\N	PRESENT	0
770966	769348	17023S	PARTICIPANT	\N	PRESENT	0
770968	769539	19545Y	PARTICIPANT	\N	PRESENT	0
770969	769348	19669L	PARTICIPANT	\N	PRESENT	0
770970	766052	21082J	PARTICIPANT	\N	PRESENT	0
770971	766052	21029D	PARTICIPANT	\N	PRESENT	0
770972	766052	19701S	PARTICIPANT	\N	PRESENT	0
770973	766052	21035B	PARTICIPANT	\N	PRESENT	0
770974	766052	21042A	PARTICIPANT	\N	PRESENT	0
770975	766052	20076G	PARTICIPANT	\N	PRESENT	0
770976	766052	19387D	PARTICIPANT	\N	PRESENT	0
770977	766052	14219Q	PRESIDENT	0	PRESENT	0
770978	766052	19820Y	PARTICIPANT	\N	PRESENT	0
770979	766052	19826F	PARTICIPANT	\N	PRESENT	0
770980	766052	21060C	PARTICIPANT	\N	PRESENT	0
770981	766052	21061D	PARTICIPANT	\N	PRESENT	0
770982	766052	21062E	PARTICIPANT	\N	PRESENT	0
770983	766052	21065H	PARTICIPANT	\N	PRESENT	0
770984	766052	21084L	PARTICIPANT	\N	PRESENT	0
770985	766052	18083K	PARTICIPANT	\N	PRESENT	0
770986	766052	20100N	PARTICIPANT	\N	PRESENT	0
770987	766052	14237S	PARTICIPANT	\N	PRESENT	0
770988	766052	19551W	PARTICIPANT	\N	PRESENT	0
770989	766052	21085M	PARTICIPANT	\N	PRESENT	0
770990	766052	05012A	PARTICIPANT	\N	PRESENT	0
770991	766052	08060W	PARTICIPANT	\N	PRESENT	0
770992	766052	20106U	PARTICIPANT	\N	PRESENT	0
770993	766052	20118Y	PARTICIPANT	\N	PRESENT	0
770994	766052	15197G	PARTICIPANT	\N	PRESENT	0
770995	766052	14107H	PARTICIPANT	\N	PRESENT	0
770996	766052	21080G	PARTICIPANT	\N	PRESENT	0
770997	766052	19331L	PARTICIPANT	\N	PRESENT	0
770998	766052	20020P	PARTICIPANT	\N	PRESENT	0
770999	766052	19681G	PARTICIPANT	\N	PRESENT	0
771000	766052	11065P	PARTICIPANT	\N	PRESENT	0
771001	766052	20120S	PARTICIPANT	\N	PRESENT	0
771002	766052	21051B	PARTICIPANT	\N	PRESENT	0
771003	766052	21053D	PARTICIPANT	\N	PRESENT	0
771004	766052	20136B	PARTICIPANT	\N	PRESENT	0
771005	766052	14031R	PARTICIPANT	\N	PRESENT	0
771006	766052	20040T	PARTICIPANT	\N	PRESENT	0
771007	766052	19251M	PARTICIPANT	\N	PRESENT	0
771008	766052	20046A	PARTICIPANT	\N	PRESENT	0
771009	766052	20146D	PARTICIPANT	\N	PRESENT	0
771010	766052	17229F	PARTICIPANT	\N	PRESENT	0
771011	766052	14169X	PARTICIPANT	\N	PRESENT	0
771012	766052	21047F	PARTICIPANT	\N	PRESENT	0
771013	766052	20068G	PARTICIPANT	\N	PRESENT	0
771014	766052	21068L	PARTICIPANT	\N	PRESENT	0
771015	766052	21070E	PARTICIPANT	\N	PRESENT	0
771016	766052	19619A	PARTICIPANT	\N	PRESENT	0
771037	769238	86034E	PARTICIPANT	\N	PRESENT	0
771038	769238	98022P	PARTICIPANT	\N	PRESENT	0
771039	769238	14191V	PARTICIPANT	\N	PRESENT	0
771040	769238	20068G	PARTICIPANT	\N	PRESENT	0
771041	769238	08028W	PARTICIPANT	\N	PRESENT	0
771042	769238	11070L	PARTICIPANT	\N	PRESENT	0
771043	769238	21052C	PARTICIPANT	\N	PRESENT	0
771044	769238	19798U	PARTICIPANT	\N	PRESENT	0
771045	769238	19703U	PARTICIPANT	\N	PRESENT	0
771046	769238	17229F	PARTICIPANT	\N	PRESENT	0
771047	769238	19681G	PARTICIPANT	\N	PRESENT	0
771048	769238	14259Y	PARTICIPANT	\N	PRESENT	0
771049	769238	14107H	PARTICIPANT	\N	PRESENT	0
771050	769238	08060W	PARTICIPANT	\N	PRESENT	0
771051	769238	21087P	PARTICIPANT	\N	PRESENT	0
771052	769238	19349W	PARTICIPANT	\N	PRESENT	0
771053	769238	21055F	PARTICIPANT	\N	PRESENT	0
771054	769238	20090E	PARTICIPANT	\N	PRESENT	0
771055	769238	20074E	PARTICIPANT	\N	PRESENT	0
771056	769238	19575F	PARTICIPANT	\N	PRESENT	0
771057	769238	01058X	PARTICIPANT	\N	PRESENT	0
771058	769238	99004R	PARTICIPANT	\N	PRESENT	0
771059	769238	19711U	PARTICIPANT	\N	PRESENT	0
771060	769238	04047H	PARTICIPANT	\N	PRESENT	0
771061	769238	08034U	PARTICIPANT	\N	PRESENT	0
771062	769238	14133K	PARTICIPANT	\N	PRESENT	0
771063	769238	19701S	PARTICIPANT	\N	PRESENT	0
771064	769238	04033B	PARTICIPANT	\N	PRESENT	0
771065	769238	04008A	PARTICIPANT	\N	PRESENT	0
771066	769238	18083K	PARTICIPANT	\N	PRESENT	0
771067	769238	19367Y	PARTICIPANT	\N	PRESENT	0
771068	769238	08010L	PARTICIPANT	\N	PRESENT	0
771069	769238	04092N	PARTICIPANT	\N	PRESENT	0
771070	769238	04042C	PARTICIPANT	\N	PRESENT	0
771071	769238	20078J	PARTICIPANT	\N	PRESENT	0
771072	769238	21044C	PARTICIPANT	\N	PRESENT	0
771073	769238	21080G	PARTICIPANT	\N	PRESENT	0
771074	769238	19573D	PARTICIPANT	\N	PRESENT	0
771075	769238	11043H	PARTICIPANT	\N	PRESENT	0
771076	769238	10015M	PARTICIPANT	\N	PRESENT	0
771077	769238	14223L	PARTICIPANT	\N	PRESENT	0
771078	769238	19679N	PARTICIPANT	\N	PRESENT	0
771079	769238	20062A	PARTICIPANT	\N	PRESENT	0
771080	769238	14053L	PARTICIPANT	\N	PRESENT	0
771081	769238	14187A	PARTICIPANT	\N	PRESENT	0
771082	769238	05012A	PARTICIPANT	\N	PRESENT	0
771083	769238	20022R	PARTICIPANT	\N	PRESENT	0
771084	769238	20044X	PARTICIPANT	\N	PRESENT	0
771085	769238	19673G	PARTICIPANT	\N	PRESENT	0
771086	769238	21091K	PARTICIPANT	\N	PRESENT	0
771087	769238	14031R	PARTICIPANT	\N	PRESENT	0
771088	769238	19421M	PARTICIPANT	\N	PRESENT	0
771089	769238	14253S	PARTICIPANT	\N	PRESENT	0
771090	769238	20136B	PARTICIPANT	\N	PRESENT	0
771091	769238	20032T	PARTICIPANT	\N	PRESENT	0
771092	769238	14331P	PARTICIPANT	\N	PRESENT	0
771093	769238	18231D	PARTICIPANT	\N	PRESENT	0
771094	769238	20118Y	PARTICIPANT	\N	PRESENT	0
771095	769238	19533U	PARTICIPANT	\N	PRESENT	0
771096	769238	14069U	PARTICIPANT	\N	PRESENT	0
771097	769238	20252E	PARTICIPANT	\N	PRESENT	0
771098	769238	21061D	PARTICIPANT	\N	PRESENT	0
771099	769238	14217N	PARTICIPANT	\N	PRESENT	0
771100	769238	21090J	PARTICIPANT	\N	PRESENT	0
771101	769238	21095P	PARTICIPANT	\N	PRESENT	0
771102	769238	14026U	PARTICIPANT	\N	PRESENT	0
771103	769238	21072G	PARTICIPANT	\N	PRESENT	0
771104	769238	14237S	PARTICIPANT	\N	PRESENT	0
771105	769238	20138D	PARTICIPANT	\N	PRESENT	0
771106	769238	19954N	PARTICIPANT	\N	PRESENT	0
771107	769238	19760E	PARTICIPANT	\N	PRESENT	0
771108	769238	20026V	PARTICIPANT	\N	PRESENT	0
771109	769238	19758L	PARTICIPANT	\N	PRESENT	0
771110	769238	20180F	PARTICIPANT	\N	PRESENT	0
771111	769238	20046A	PARTICIPANT	\N	PRESENT	0
771112	769238	20096L	PARTICIPANT	\N	PRESENT	0
771113	769238	21058J	PARTICIPANT	\N	PRESENT	0
771114	769238	21084L	PARTICIPANT	\N	PRESENT	0
771115	769238	11040E	PARTICIPANT	\N	PRESENT	0
771116	769238	21068L	PARTICIPANT	\N	PRESENT	0
771117	769238	21049H	PARTICIPANT	\N	PRESENT	0
771118	769238	21075K	PARTICIPANT	\N	PRESENT	0
771119	769238	19447X	PARTICIPANT	\N	PRESENT	0
771120	769238	14173T	PARTICIPANT	\N	PRESENT	0
771121	769238	05008E	PARTICIPANT	\N	PRESENT	0
771122	769238	19695N	PARTICIPANT	\N	PRESENT	0
771123	769238	14038Y	PARTICIPANT	\N	PRESENT	0
771124	769238	20034V	PARTICIPANT	\N	PRESENT	0
771125	769238	21039F	PARTICIPANT	\N	PRESENT	0
771126	769238	19687N	PARTICIPANT	\N	PRESENT	0
771127	769238	20140W	PARTICIPANT	\N	PRESENT	0
771128	769238	21088Q	PARTICIPANT	\N	PRESENT	0
771129	769238	19565D	PARTICIPANT	\N	PRESENT	0
771130	769238	20102Q	PARTICIPANT	\N	PRESENT	0
771131	769238	20038A	PARTICIPANT	\N	PRESENT	0
771132	769238	14033T	PARTICIPANT	\N	PRESENT	0
771133	769238	20056C	PARTICIPANT	\N	PRESENT	0
771134	769238	19593H	PARTICIPANT	\N	PRESENT	0
771135	769238	21030V	PARTICIPANT	\N	PRESENT	0
771136	769238	19399H	PARTICIPANT	\N	PRESENT	0
771137	769238	21081H	PARTICIPANT	\N	PRESENT	0
771138	769238	21048G	PARTICIPANT	\N	PRESENT	0
771139	769238	20104S	PARTICIPANT	\N	PRESENT	0
771140	769238	20110Q	PARTICIPANT	\N	PRESENT	0
771141	769238	20112S	PARTICIPANT	\N	PRESENT	0
771142	769238	20108W	PARTICIPANT	\N	PRESENT	0
771143	769238	21074J	PARTICIPANT	\N	PRESENT	0
783438	783437	20094J	PARTICIPANT	\N	PRESENT	0
783439	783437	19711U	PARTICIPANT	\N	PRESENT	0
786392	786391	21064G	PARTICIPANT	\N	PRESENT	0
787576	787205	21080G	PARTICIPANT	\N	PRESENT	0
787577	787205	20120S	PARTICIPANT	\N	PRESENT	0
787578	787205	20136B	PARTICIPANT	\N	PRESENT	0
787579	787205	14031R	PARTICIPANT	\N	PRESENT	0
788780	788778	21036C	PARTICIPANT	\N	PRESENT	0
787581	787205	19251M	PARTICIPANT	\N	PRESENT	0
787582	787205	14033T	PARTICIPANT	\N	PRESENT	0
787583	787205	14169X	PARTICIPANT	\N	PRESENT	0
788798	787249	21036C	PARTICIPANT	\N	PRESENT	0
787585	787205	19619A	PARTICIPANT	\N	PRESENT	0
788779	788778	19565D	PARTICIPANT	\N	PRESENT	0
788799	787249	21031W	PARTICIPANT	\N	PRESENT	0
787588	787205	19681G	PARTICIPANT	\N	EXCUSE	0
787686	787120	20032T	PARTICIPANT	\N	PRESENT	0
787688	787120	21042A	PARTICIPANT	\N	PRESENT	0
787694	787120	20076G	PARTICIPANT	\N	PRESENT	0
787695	787120	21084L	PARTICIPANT	\N	PRESENT	0
787702	787120	21065H	PARTICIPANT	\N	PRESENT	0
787703	787120	18083K	PARTICIPANT	\N	PRESENT	0
787704	787120	19701S	PARTICIPANT	\N	PRESENT	0
787932	786176	19745F	PARTICIPANT	\N	PRESENT	0
787707	787120	11065P	PARTICIPANT	\N	PRESENT	0
787709	787120	17229F	PARTICIPANT	\N	PRESENT	0
787710	787120	19251M	PARTICIPANT	\N	PRESENT	0
787711	787120	15197G	PARTICIPANT	\N	PRESENT	0
787712	787120	20040T	PARTICIPANT	\N	PRESENT	0
787713	787120	21062E	PARTICIPANT	\N	PRESENT	0
787714	787120	20120S	PARTICIPANT	\N	PRESENT	0
787715	787120	19820Y	PARTICIPANT	\N	PRESENT	0
787717	787120	19387D	PARTICIPANT	\N	PRESENT	0
787718	787120	20068G	PARTICIPANT	\N	PRESENT	0
787720	787120	20106U	PARTICIPANT	\N	PRESENT	0
787722	787120	19551W	PARTICIPANT	\N	PRESENT	0
787723	787120	14219Q	PARTICIPANT	\N	PRESENT	0
787724	787120	14031R	PARTICIPANT	\N	PRESENT	0
787726	787120	19826F	PARTICIPANT	\N	PRESENT	0
787728	787120	21080G	PARTICIPANT	\N	PRESENT	0
787729	787120	14169X	PARTICIPANT	\N	PRESENT	0
787731	787120	19331L	PARTICIPANT	\N	PRESENT	0
787733	787120	21060C	PARTICIPANT	\N	PRESENT	0
787734	787120	14237S	PARTICIPANT	\N	PRESENT	0
787735	787120	21053D	PARTICIPANT	\N	PRESENT	0
787737	787120	20118Y	PARTICIPANT	\N	PRESENT	0
787738	787120	05012A	PARTICIPANT	\N	PRESENT	0
787740	787120	21068L	PARTICIPANT	\N	PRESENT	0
787741	787120	21070E	PARTICIPANT	\N	PRESENT	0
787742	787120	20020P	PARTICIPANT	\N	PRESENT	0
787743	787120	14107H	PARTICIPANT	\N	PRESENT	0
787745	787120	19619A	PARTICIPANT	\N	PRESENT	0
787746	787120	20136B	PARTICIPANT	\N	PRESENT	0
787747	787120	21051B	PARTICIPANT	\N	PRESENT	0
787749	787120	20046A	PARTICIPANT	\N	PRESENT	0
787750	787120	21082J	PARTICIPANT	\N	PRESENT	0
787758	787120	08060W	PARTICIPANT	\N	PRESENT	0
787927	786177	19745F	PARTICIPANT	\N	PRESENT	0
788071	788070	19575F	PARTICIPANT	\N	PRESENT	0
788073	788070	08012N	PARTICIPANT	\N	PRESENT	0
788074	788070	21070E	PARTICIPANT	\N	PRESENT	0
788075	788070	20150Y	PARTICIPANT	\N	PRESENT	0
788099	788098	21081H	PARTICIPANT	\N	PRESENT	1
788100	788098	14223L	PARTICIPANT	\N	PRESENT	1
788101	788098	08045X	PARTICIPANT	\N	PRESENT	1
788102	787242	19669L	PARTICIPANT	\N	EXCUSE	0
788570	788569	20022R	PARTICIPANT	\N	PRESENT	0
788571	788569	20144B	PARTICIPANT	\N	PRESENT	0
788572	788569	14179A	PARTICIPANT	\N	PRESENT	0
788573	788569	14213J	PARTICIPANT	\N	PRESENT	0
788574	788569	08012N	PARTICIPANT	\N	PRESENT	0
788575	788569	19826F	PARTICIPANT	\N	PRESENT	0
788576	788569	14147R	PARTICIPANT	\N	PRESENT	0
788577	788569	05012A	PARTICIPANT	\N	PRESENT	0
788578	788569	20064C	PARTICIPANT	\N	PRESENT	0
788683	786182	14237S	PRESIDENT	0	PRESENT	0
788684	786182	14097Y	PARTICIPANT	\N	PRESENT	0
788685	786182	08034U	PARTICIPANT	\N	PRESENT	0
788686	786182	20042V	PARTICIPANT	\N	PRESENT	0
788687	786182	21076L	PARTICIPANT	\N	PRESENT	0
788688	786182	21037D	PARTICIPANT	\N	PRESENT	0
788689	786182	20106U	PARTICIPANT	\N	EXCUSE	0
788690	786182	20104S	PARTICIPANT	\N	EXCUSE	0
788691	786182	14331P	PARTICIPANT	\N	PRESENT	0
788692	786182	14187A	PARTICIPANT	\N	PRESENT	0
788693	786182	14193X	PARTICIPANT	\N	PRESENT	0
788694	786182	14033T	PARTICIPANT	\N	PRESENT	0
788695	786182	19711U	PARTICIPANT	\N	PRESENT	0
788800	787249	21067K	PARTICIPANT	\N	PRESENT	0
788801	787249	20042V	PARTICIPANT	\N	PRESENT	0
788802	787249	19347U	PARTICIPANT	\N	PRESENT	0
788803	787249	14193X	PRESIDENT	0	PRESENT	0
788804	787249	14001X	PARTICIPANT	\N	PRESENT	0
788805	787249	20064C	PARTICIPANT	\N	EXCUSE	0
788806	787249	19565D	PARTICIPANT	\N	EXCUSE	0
788807	787249	01058X	PARTICIPANT	\N	EXCUSE	0
788808	787249	17367Q	PARTICIPANT	\N	EXCUSE	0
788809	787249	08047A	PARTICIPANT	\N	EXCUSE	0
789220	789218	19673G	PARTICIPANT	\N	PRESENT	0
788811	786182	20086J	PARTICIPANT	\N	PRESENT	0
788812	786182	14147R	PARTICIPANT	\N	PRESENT	0
788813	786182	20044X	PARTICIPANT	\N	PRESENT	0
788814	786182	19399H	PARTICIPANT	\N	PRESENT	0
788815	786182	11045K	PARTICIPANT	\N	PRESENT	0
788816	786182	14083S	PARTICIPANT	\N	PRESENT	0
788818	786182	21090J	PARTICIPANT	\N	PRESENT	0
788819	786182	19695N	PARTICIPANT	\N	PRESENT	0
788820	786182	14257W	PARTICIPANT	\N	PRESENT	0
789221	789218	18231D	PARTICIPANT	\N	PRESENT	0
789228	789225	21081H	PARTICIPANT	\N	PRESENT	0
789229	789226	21081H	PARTICIPANT	\N	PRESENT	0
789039	778775	20110Q	PARTICIPANT	\N	PRESENT	0
789230	789227	21081H	PARTICIPANT	\N	PRESENT	0
789282	786623	14189C	PARTICIPANT	\N	PRESENT	0
789040	778775	17367Q	PARTICIPANT	\N	PRESENT	0
789042	778775	17737W	PARTICIPANT	\N	PRESENT	0
789043	778775	20138D	PARTICIPANT	\N	PRESENT	0
788919	786182	17737W	PARTICIPANT	\N	PRESENT	0
788970	786182	14038Y	PARTICIPANT	\N	PRESENT	0
788971	786182	11090Q	PARTICIPANT	\N	PRESENT	0
788972	786182	14205J	PARTICIPANT	\N	PRESENT	0
789283	786623	21050A	PARTICIPANT	\N	PRESENT	0
789044	778775	19621T	PARTICIPANT	\N	PRESENT	0
789045	778775	14053L	PARTICIPANT	\N	PRESENT	0
789046	778775	20248J	PARTICIPANT	\N	PRESENT	0
789047	778775	20120S	PARTICIPANT	\N	PRESENT	0
789048	778775	19347U	PARTICIPANT	\N	PRESENT	0
789049	778775	20056C	PARTICIPANT	\N	PRESENT	0
789050	778775	14037X	PARTICIPANT	\N	PRESENT	0
789051	778775	14169X	PARTICIPANT	\N	PRESENT	0
789052	778775	20146D	PARTICIPANT	\N	PRESENT	0
789053	778775	11027H	PARTICIPANT	\N	PRESENT	0
789219	789218	04047H	PARTICIPANT	\N	PRESENT	0
789284	786623	14069U	PARTICIPANT	\N	PRESENT	0
789285	786623	20138D	PARTICIPANT	\N	PRESENT	0
789286	786623	21088Q	PARTICIPANT	\N	PRESENT	0
789287	786623	21045D	PARTICIPANT	\N	PRESENT	0
789288	786623	14083S	PARTICIPANT	\N	PRESENT	0
789289	786623	19701S	PARTICIPANT	\N	PRESENT	0
789290	786623	19693L	PARTICIPANT	\N	PRESENT	0
789291	786623	14259Y	PARTICIPANT	\N	PRESENT	0
789292	786623	17229F	PARTICIPANT	\N	PRESENT	0
789293	786623	14249W	PARTICIPANT	\N	PRESENT	0
789294	786623	21091K	PARTICIPANT	\N	PRESENT	0
789295	786623	21062E	PARTICIPANT	\N	PRESENT	0
789296	786623	20100N	PARTICIPANT	\N	PRESENT	0
789297	786623	07004J	PARTICIPANT	\N	PRESENT	0
789298	786623	21066J	PARTICIPANT	\N	PRESENT	0
789299	786623	19691J	PARTICIPANT	\N	PRESENT	0
789300	786623	19683J	PARTICIPANT	\N	PRESENT	0
789301	786623	20052X	PARTICIPANT	\N	PRESENT	0
789302	786623	18207D	PARTICIPANT	\N	PRESENT	0
789303	786623	21054E	PARTICIPANT	\N	PRESENT	0
769001	765174	14259Y	PARTICIPANT	\N	PRESENT	0
769002	765174	08018U	PARTICIPANT	\N	PRESENT	0
769003	765174	20074E	PARTICIPANT	\N	PRESENT	0
769004	765174	19649G	PARTICIPANT	\N	PRESENT	0
769005	765174	14189C	PARTICIPANT	\N	PRESENT	0
769006	765174	14151M	PARTICIPANT	\N	PRESENT	0
769007	765174	20036X	PARTICIPANT	\N	PRESENT	0
769008	765174	19111A	PARTICIPANT	\N	PRESENT	0
769009	765174	14111D	PARTICIPANT	\N	PRESENT	0
769010	765174	20110Q	PARTICIPANT	\N	PRESENT	0
769011	765174	04047H	PRESIDENT	\N	PRESENT	0
769012	765174	20264J	PARTICIPANT	\N	PRESENT	0
769013	765174	21088Q	PARTICIPANT	\N	PRESENT	0
769014	765174	11085T	PARTICIPANT	\N	PRESENT	0
769015	765174	14147R	PARTICIPANT	\N	PRESENT	0
769016	765174	18231D	PARTICIPANT	\N	PRESENT	0
769017	765174	18207D	PARTICIPANT	\N	PRESENT	0
769018	765174	14275Y	PARTICIPANT	\N	PRESENT	0
769019	765174	21095P	PARTICIPANT	\N	PRESENT	0
769020	765174	04008A	PARTICIPANT	\N	PRESENT	0
769021	765174	20114U	PARTICIPANT	\N	PRESENT	0
769022	765174	20108W	PARTICIPANT	\N	EXCUSE	0
769023	765174	14089Y	PARTICIPANT	\N	PRESENT	0
769024	765174	19749K	PARTICIPANT	\N	PRESENT	0
769025	765174	19725B	PARTICIPANT	\N	PRESENT	0
769026	765174	14069U	PARTICIPANT	\N	PRESENT	0
769027	765174	05008E	PARTICIPANT	\N	PRESENT	0
769028	765174	21040X	PARTICIPANT	\N	PRESENT	0
769029	765174	19673G	PARTICIPANT	\N	PRESENT	0
769030	765174	10015M	PARTICIPANT	\N	PRESENT	0
769031	765174	19489J	PARTICIPANT	\N	PRESENT	0
769032	765174	11056N	PARTICIPANT	\N	PRESENT	0
769033	765174	21044C	PARTICIPANT	\N	PRESENT	0
769034	765174	21043B	PARTICIPANT	\N	PRESENT	0
769035	765174	21076L	PARTICIPANT	\N	EXCUSE	0
769036	765174	19729F	PARTICIPANT	\N	EXCUSE	0
769037	765174	19447X	PARTICIPANT	\N	PRESENT	0
769038	765174	11072N	PARTICIPANT	\N	EXCUSE	0
769039	765174	20022R	PARTICIPANT	\N	EXCUSE	0
769040	765174	04045F	PARTICIPANT	\N	EXCUSE	0
769041	765174	14215L	PARTICIPANT	\N	EXCUSE	0
769042	765174	19719D	PARTICIPANT	\N	PRESENT	0
769043	765174	21038E	PARTICIPANT	\N	PRESENT	0
769044	765174	20098N	PARTICIPANT	\N	PRESENT	0
769045	765174	20266L	PARTICIPANT	\N	PRESENT	0
769046	765174	21056G	PARTICIPANT	\N	PRESENT	0
769047	765174	14231L	PARTICIPANT	\N	PRESENT	0
769048	765174	14053L	PARTICIPANT	\N	PRESENT	0
769071	769069	19729F	PARTICIPANT	\N	PRESENT	0
769075	769074	20110Q	PARTICIPANT	\N	PRESENT	0
775310	772600	14189C	PARTICIPANT	\N	PRESENT	0
775311	772600	14219Q	PARTICIPANT	\N	PRESENT	0
775316	772600	14123H	PARTICIPANT	\N	PRESENT	0
775317	772600	20120S	PARTICIPANT	\N	PRESENT	0
775318	772600	21034A	PARTICIPANT	\N	PRESENT	0
775319	772600	19399H	PARTICIPANT	\N	PRESENT	0
775320	772600	14169X	PARTICIPANT	\N	PRESENT	0
775321	772600	21072G	PARTICIPANT	\N	PRESENT	0
775322	772600	20104S	PARTICIPANT	\N	PRESENT	0
775323	772600	14147R	PARTICIPANT	\N	PRESENT	0
775341	775198	14231L	PARTICIPANT	\N	EXCUSE	0
775342	775198	20098N	PARTICIPANT	\N	EXCUSE	0
775343	775198	14147R	PARTICIPANT	\N	EXCUSE	0
776117	776115	17229F	PARTICIPANT	\N	EXCUSE	0
776126	776125	14193X	PARTICIPANT	\N	PRESENT	0
776134	776132	21086N	PARTICIPANT	\N	PRESENT	0
776135	776132	20084G	PARTICIPANT	\N	PRESENT	0
776136	776132	20180F	PARTICIPANT	\N	PRESENT	0
776137	776132	18207D	PARTICIPANT	\N	PRESENT	0
776139	776138	21086N	PARTICIPANT	\N	PRESENT	0
776141	776138	20084G	PARTICIPANT	\N	PRESENT	0
777197	777193	11053K	PARTICIPANT	\N	PRESENT	0
777198	777193	11097X	PARTICIPANT	\N	PRESENT	1
777199	777193	20180F	PARTICIPANT	\N	PRESENT	1
777201	777200	11053K	PARTICIPANT	\N	PRESENT	0
777202	777200	11097X	PARTICIPANT	\N	PRESENT	1
777203	777200	20180F	PARTICIPANT	\N	PRESENT	1
777205	777204	11053K	PARTICIPANT	\N	PRESENT	0
777206	777204	20102Q	PARTICIPANT	\N	PRESENT	0
777207	777204	11097X	PARTICIPANT	\N	PRESENT	1
777210	777208	11053K	PARTICIPANT	\N	PRESENT	0
777218	777217	11053K	PARTICIPANT	\N	PRESENT	0
777219	777217	19251M	PARTICIPANT	\N	PRESENT	0
777220	777217	20084G	PARTICIPANT	\N	PRESENT	0
777221	777217	20180F	PARTICIPANT	\N	PRESENT	0
777222	777217	14357A	PARTICIPANT	\N	PRESENT	0
777224	777223	11053K	PARTICIPANT	\N	PRESENT	0
777225	777223	19251M	PARTICIPANT	\N	PRESENT	0
777226	777223	11097X	PARTICIPANT	\N	PRESENT	1
777227	777223	20180F	PARTICIPANT	\N	PRESENT	1
777228	777223	20084G	PARTICIPANT	\N	PRESENT	0
777234	777233	11053K	PARTICIPANT	\N	PRESENT	0
777235	777233	19251M	PARTICIPANT	\N	PRESENT	0
777236	777233	11097X	PARTICIPANT	\N	PRESENT	1
777237	777233	20180F	PARTICIPANT	\N	PRESENT	1
777238	777233	20084G	PARTICIPANT	\N	PRESENT	0
777241	777240	11053K	PARTICIPANT	\N	PRESENT	0
777242	777240	19251M	PARTICIPANT	\N	PRESENT	0
777243	777240	11097X	PARTICIPANT	\N	PRESENT	1
777244	777240	20180F	PARTICIPANT	\N	PRESENT	1
777245	777240	14357A	PARTICIPANT	\N	PRESENT	1
777246	777240	19762G	PARTICIPANT	\N	PRESENT	0
777248	777247	11053K	PARTICIPANT	\N	PRESENT	0
777249	777247	19251M	PARTICIPANT	\N	PRESENT	0
777250	777247	11097X	PARTICIPANT	\N	PRESENT	0
777251	777247	14357A	PARTICIPANT	\N	PRESENT	0
777252	777247	19762G	PARTICIPANT	\N	PRESENT	0
777255	777254	11053K	PARTICIPANT	\N	PRESENT	0
777256	777254	20180F	PARTICIPANT	\N	PRESENT	0
777257	777254	19251M	PARTICIPANT	\N	PRESENT	1
777258	777254	11097X	PARTICIPANT	\N	PRESENT	0
777260	777259	11053K	PARTICIPANT	\N	PRESENT	0
777262	777259	11097X	PARTICIPANT	\N	PRESENT	0
777263	777259	20180F	PARTICIPANT	\N	PRESENT	0
777265	777264	11053K	PARTICIPANT	\N	PRESENT	0
777266	777264	20084G	PARTICIPANT	\N	PRESENT	1
777268	777267	11053K	PARTICIPANT	\N	PRESENT	0
777269	777267	20084G	PARTICIPANT	\N	PRESENT	1
777271	777270	11053K	PARTICIPANT	\N	PRESENT	0
777272	777270	20084G	PARTICIPANT	\N	PRESENT	0
777279	777278	11053K	PARTICIPANT	\N	PRESENT	0
777276	777274	20084G	PARTICIPANT	\N	PRESENT	1
777277	777274	11053K	PARTICIPANT	\N	PRESENT	0
777280	777278	20084G	PARTICIPANT	\N	PRESENT	1
777281	777278	20180F	PARTICIPANT	\N	PRESENT	1
777283	777282	11053K	PARTICIPANT	\N	PRESENT	0
777284	777282	20180F	PARTICIPANT	\N	PRESENT	1
777286	777285	11053K	PARTICIPANT	\N	PRESENT	0
777287	777285	20180F	PARTICIPANT	\N	PRESENT	1
777294	777293	11053K	PARTICIPANT	\N	PRESENT	0
777295	777293	20180F	PARTICIPANT	\N	PRESENT	1
777297	777296	11053K	PARTICIPANT	\N	PRESENT	0
777972	777918	20140W	PARTICIPANT	\N	PRESENT	0
777973	777918	20248J	PARTICIPANT	\N	PRESENT	0
777974	777918	14223L	PARTICIPANT	\N	PRESENT	0
777975	777918	20130U	PARTICIPANT	\N	PRESENT	0
777976	777918	21094N	PARTICIPANT	\N	PRESENT	0
777979	777918	04092N	PARTICIPANT	\N	EXCUSE	0
777982	777918	19591F	PARTICIPANT	\N	PRESENT	0
777986	777918	08045X	PARTICIPANT	\N	PRESENT	0
777987	777918	19367Y	PARTICIPANT	\N	PRESENT	0
777989	777918	21039F	PARTICIPANT	\N	PRESENT	0
777990	777918	14355X	PARTICIPANT	\N	PRESENT	0
777991	777918	19295A	PARTICIPANT	\N	PRESENT	0
777992	777918	14026U	PARTICIPANT	\N	PRESENT	0
777993	777918	21087P	PARTICIPANT	\N	PRESENT	0
777994	777918	17779H	PARTICIPANT	\N	PRESENT	0
778001	777918	19679N	PARTICIPANT	\N	PRESENT	0
778002	777918	19723Y	PARTICIPANT	\N	PRESENT	0
778007	777918	19866P	PARTICIPANT	\N	PRESENT	0
778860	778859	14179A	PARTICIPANT	\N	PRESENT	0
778861	778859	19701S	PARTICIPANT	\N	PRESENT	0
778862	778859	14255U	PARTICIPANT	\N	PRESENT	0
778863	778859	21073H	PARTICIPANT	\N	PRESENT	0
779752	779087	14219Q	PARTICIPANT	\N	PRESENT	0
779815	779814	20024T	PARTICIPANT	\N	PRESENT	0
779817	779814	20264J	PARTICIPANT	\N	PRESENT	0
779818	779814	08012N	PARTICIPANT	\N	PRESENT	0
779819	779814	14147R	PARTICIPANT	\N	PRESENT	0
779820	779814	05012A	PARTICIPANT	\N	PRESENT	0
779821	779814	20064C	PARTICIPANT	\N	PRESENT	0
782849	782847	21050A	PARTICIPANT	\N	PRESENT	0
782850	782847	21045D	PARTICIPANT	\N	PRESENT	0
782851	782847	14083S	PARTICIPANT	\N	PRESENT	0
782852	782847	14357A	PARTICIPANT	\N	PRESENT	0
782854	782847	20038A	PARTICIPANT	\N	PRESENT	0
782855	782847	21044C	PARTICIPANT	\N	PRESENT	0
782856	782847	20126Y	PARTICIPANT	\N	PRESENT	0
782857	782847	21039F	PARTICIPANT	\N	PRESENT	0
782858	782847	20054A	PRESIDENT	0	PRESENT	0
782859	782847	21064G	PARTICIPANT	\N	PRESENT	0
782864	782847	21040X	PARTICIPANT	\N	PRESENT	0
782865	782847	21061D	PARTICIPANT	\N	EXCUSE	0
782867	782847	14237S	PARTICIPANT	\N	EXCUSE	0
782868	782847	20056C	PARTICIPANT	\N	EXCUSE	0
782870	782847	08015R	PARTICIPANT	\N	EXCUSE	0
782871	782847	21052C	PARTICIPANT	\N	EXCUSE	0
782872	782847	21051B	PARTICIPANT	\N	EXCUSE	0
782873	782847	19347U	PARTICIPANT	\N	EXCUSE	0
782874	782847	19563B	PARTICIPANT	\N	EXCUSE	0
782875	782847	20248J	PARTICIPANT	\N	EXCUSE	0
782876	782847	19697Q	PARTICIPANT	\N	EXCUSE	0
782877	782847	20172F	PARTICIPANT	\N	EXCUSE	0
782878	782847	20078J	PARTICIPANT	\N	EXCUSE	0
782879	782847	21058J	PARTICIPANT	\N	EXCUSE	0
782880	782847	20052X	PARTICIPANT	\N	EXCUSE	0
782881	782847	21047F	PARTICIPANT	\N	EXCUSE	0
782884	782848	21050A	PARTICIPANT	\N	PRESENT	0
782885	782848	21045D	PARTICIPANT	\N	PRESENT	0
785193	780475	19533U	PARTICIPANT	\N	PRESENT	0
782887	782848	14357A	PARTICIPANT	\N	PRESENT	0
782888	782848	20038A	PARTICIPANT	\N	PRESENT	0
782889	782848	21044C	PARTICIPANT	\N	PRESENT	0
782890	782848	20126Y	PARTICIPANT	\N	PRESENT	0
782891	782848	21040X	PARTICIPANT	\N	PRESENT	0
782892	782848	21039F	PARTICIPANT	\N	PRESENT	0
782893	782848	20054A	PRESIDENT	0	PRESENT	0
782894	782848	21064G	PARTICIPANT	\N	PRESENT	0
782917	782848	20052X	PARTICIPANT	\N	PRESENT	0
782942	782848	21061D	PARTICIPANT	\N	EXCUSE	0
782944	782848	14237S	PARTICIPANT	\N	EXCUSE	0
782946	782848	20056C	PARTICIPANT	\N	EXCUSE	0
782947	782848	21052C	PARTICIPANT	\N	EXCUSE	0
782948	782848	08015R	PARTICIPANT	\N	EXCUSE	0
782949	782848	21051B	PARTICIPANT	\N	EXCUSE	0
782953	782848	19347U	PARTICIPANT	\N	EXCUSE	0
782957	782848	19563B	PARTICIPANT	\N	EXCUSE	0
782958	782848	20248J	PARTICIPANT	\N	EXCUSE	0
782962	782848	19697Q	PARTICIPANT	\N	EXCUSE	0
782963	782848	20172F	PARTICIPANT	\N	EXCUSE	0
782964	782848	20078J	PARTICIPANT	\N	EXCUSE	0
782965	782848	21058J	PARTICIPANT	\N	EXCUSE	0
782966	782848	21047F	PARTICIPANT	\N	EXCUSE	0
785184	780475	04070G	PARTICIPANT	\N	PRESENT	0
785185	780475	08012N	PARTICIPANT	\N	PRESENT	0
785186	780475	20124W	PARTICIPANT	\N	PRESENT	0
785187	780475	20172F	PARTICIPANT	\N	PRESENT	0
785188	780475	14030Q	PARTICIPANT	\N	PRESENT	0
785189	780475	21063F	PARTICIPANT	\N	PRESENT	0
785190	780475	14123H	PARTICIPANT	\N	PRESENT	0
785191	780475	19611R	PRESIDENT	0	PRESENT	0
785194	780475	20058E	PARTICIPANT	\N	PRESENT	0
785195	780475	11043H	PARTICIPANT	\N	PRESENT	0
785197	780475	19954N	PARTICIPANT	\N	PRESENT	0
785234	783396	19383Y	PARTICIPANT	\N	PRESENT	0
785235	783396	20088L	PARTICIPANT	\N	PRESENT	0
785236	783396	19768N	PARTICIPANT	\N	PRESENT	0
785237	783396	19782L	PARTICIPANT	\N	PRESENT	0
785238	783396	20092G	PARTICIPANT	\N	PRESENT	0
785239	783396	20078J	PARTICIPANT	\N	PRESENT	0
785240	783396	20082E	PARTICIPANT	\N	PRESENT	0
785241	783396	14221J	PARTICIPANT	\N	PRESENT	0
785242	783396	19631V	PARTICIPANT	\N	PRESENT	0
785243	783396	19575F	PARTICIPANT	\N	PRESENT	0
785244	783396	20018V	PARTICIPANT	\N	PRESENT	0
785245	783396	08028W	PARTICIPANT	\N	PRESENT	0
785246	783396	19563B	PARTICIPANT	\N	PRESENT	0
785247	783396	21050A	PARTICIPANT	\N	PRESENT	0
785248	783396	20028X	PARTICIPANT	\N	PRESENT	0
785249	783396	14329V	PARTICIPANT	\N	PRESENT	0
785250	783396	21052C	PARTICIPANT	\N	PRESENT	0
785251	783396	21054E	PARTICIPANT	\N	PRESENT	0
785252	783396	20034V	PARTICIPANT	\N	PRESENT	0
785253	783396	14187A	PRESIDENT	0	PRESENT	0
785254	783396	20038A	PARTICIPANT	\N	PRESENT	0
785255	783396	21083K	PARTICIPANT	\N	PRESENT	0
785256	783396	11090Q	PARTICIPANT	\N	PRESENT	0
785257	783396	20054A	PARTICIPANT	\N	PRESENT	0
785258	783396	14205J	PARTICIPANT	\N	PRESENT	0
785259	783396	20060X	PARTICIPANT	\N	PRESENT	0
785260	783396	19507S	PARTICIPANT	\N	PRESENT	0
785261	783396	20286Q	PARTICIPANT	\N	PRESENT	0
785262	783396	14207L	PARTICIPANT	\N	PRESENT	0
785263	783396	20084G	PARTICIPANT	\N	PRESENT	0
785264	783396	14257W	PARTICIPANT	\N	PRESENT	0
785265	783396	19413M	PARTICIPANT	\N	EXCUSE	0
785266	783396	14033T	PARTICIPANT	\N	EXCUSE	0
785268	780475	20132W	PARTICIPANT	\N	PRESENT	0
785269	780475	20048C	PARTICIPANT	\N	PRESENT	0
785271	783099	21082J	PARTICIPANT	\N	PRESENT	0
785272	783099	19701S	PARTICIPANT	\N	PRESENT	0
785273	783099	21042A	PARTICIPANT	\N	PRESENT	0
785274	783099	19387D	PARTICIPANT	\N	PRESENT	0
785275	783099	19820Y	PARTICIPANT	\N	PRESENT	0
785276	783099	14219Q	PRESIDENT	0	PRESENT	0
785277	783099	19826F	PARTICIPANT	\N	PRESENT	0
785278	783099	21060C	PARTICIPANT	\N	PRESENT	0
785279	783099	21061D	PARTICIPANT	\N	PRESENT	0
785280	783099	21062E	PARTICIPANT	\N	PRESENT	0
785281	783099	21065H	PARTICIPANT	\N	PRESENT	0
785282	783099	14237S	PARTICIPANT	\N	PRESENT	0
785283	783099	21084L	PARTICIPANT	\N	PRESENT	0
785284	783099	20100N	PARTICIPANT	\N	PRESENT	0
785285	783099	19551W	PARTICIPANT	\N	PRESENT	0
785286	783099	18083K	PARTICIPANT	\N	PRESENT	0
785287	783099	05012A	PARTICIPANT	\N	PRESENT	0
785288	783099	08060W	PARTICIPANT	\N	PRESENT	0
785289	783099	20106U	PARTICIPANT	\N	PRESENT	0
785290	783099	15197G	PARTICIPANT	\N	PRESENT	0
785291	783099	20118Y	PARTICIPANT	\N	PRESENT	0
785292	783099	14107H	PARTICIPANT	\N	PRESENT	0
785293	783099	19685L	PARTICIPANT	\N	PRESENT	0
785294	783099	19681G	PARTICIPANT	\N	PRESENT	0
785295	783099	11065P	PARTICIPANT	\N	PRESENT	0
785296	783099	21051B	PARTICIPANT	\N	PRESENT	0
785297	783099	20032T	PARTICIPANT	\N	PRESENT	0
785298	783099	21053D	PARTICIPANT	\N	PRESENT	0
785299	783099	20136B	PARTICIPANT	\N	PRESENT	0
785300	783099	14031R	PARTICIPANT	\N	PRESENT	0
785301	783099	20040T	PARTICIPANT	\N	PRESENT	0
785302	783099	20046A	PARTICIPANT	\N	PRESENT	0
785303	783099	17229F	PARTICIPANT	\N	PRESENT	0
785304	783099	14169X	PARTICIPANT	\N	PRESENT	0
785305	783099	21047F	PARTICIPANT	\N	PRESENT	0
785306	783099	20068G	PARTICIPANT	\N	PRESENT	0
785307	783099	21068L	PARTICIPANT	\N	PRESENT	0
785308	783099	19619A	PARTICIPANT	\N	PRESENT	0
785309	783099	21035B	PARTICIPANT	\N	EXCUSE	0
785310	783099	21080G	PARTICIPANT	\N	EXCUSE	0
785311	783099	19251M	PARTICIPANT	\N	EXCUSE	0
785312	783099	21070E	PARTICIPANT	\N	EXCUSE	0
785338	783387	08028W	PARTICIPANT	\N	PRESENT	0
785339	783387	14111D	PARTICIPANT	\N	PRESENT	0
785340	783387	20090E	PARTICIPANT	\N	PRESENT	0
785341	783387	14107H	PARTICIPANT	\N	PRESENT	0
785342	783387	04070G	PARTICIPANT	\N	PRESENT	0
785343	783387	14237S	PARTICIPANT	\N	PRESENT	0
785344	783387	08060W	PARTICIPANT	\N	PRESENT	0
785345	783387	04092N	PARTICIPANT	\N	PRESENT	0
785346	783387	14105F	PARTICIPANT	\N	PRESENT	0
785347	783387	20054A	PARTICIPANT	\N	PRESENT	0
785348	783387	14053L	PARTICIPANT	\N	PRESENT	0
785349	783387	19798U	PARTICIPANT	\N	PRESENT	0
785350	783387	20028X	PARTICIPANT	\N	PRESENT	0
785351	783387	17229F	PARTICIPANT	\N	PRESENT	0
785352	783387	14073Q	PARTICIPANT	\N	PRESENT	0
785353	783387	14195A	PARTICIPANT	\N	PRESENT	0
785354	783387	21055F	PARTICIPANT	\N	PRESENT	0
785355	783387	14083S	PARTICIPANT	\N	PRESENT	0
785356	783387	19619A	PARTICIPANT	\N	PRESENT	0
785357	783387	19695N	PARTICIPANT	\N	PRESENT	0
785358	783387	19479G	PARTICIPANT	\N	PRESENT	0
785359	783387	21053D	PARTICIPANT	\N	PRESENT	0
771144	769238	20024T	PARTICIPANT	\N	PRESENT	0
771145	769238	14055N	PARTICIPANT	\N	PRESENT	0
771146	769238	21069M	PARTICIPANT	\N	PRESENT	0
771147	769238	14213J	PARTICIPANT	\N	PRESENT	0
771148	769238	11065P	PARTICIPANT	\N	PRESENT	0
771149	769238	20134Y	PARTICIPANT	\N	PRESENT	0
771150	769238	14329V	PARTICIPANT	\N	PRESENT	0
771151	769238	20100N	PARTICIPANT	\N	PRESENT	0
771152	769238	19347U	PARTICIPANT	\N	PRESENT	0
771153	769238	14357A	PARTICIPANT	\N	PRESENT	0
771154	769238	19383Y	PARTICIPANT	\N	PRESENT	0
771155	769238	21093M	PARTICIPANT	\N	PRESENT	0
771156	769238	20142Y	PARTICIPANT	\N	PRESENT	0
771157	769238	20086J	PARTICIPANT	\N	PRESENT	0
771158	769238	21073H	PARTICIPANT	\N	PRESENT	0
771159	769238	21037D	PARTICIPANT	\N	PRESENT	0
771160	769238	20098N	PARTICIPANT	\N	PRESENT	0
771161	769238	20054A	PARTICIPANT	\N	PRESENT	0
771162	769238	20036X	PARTICIPANT	\N	PRESENT	0
771163	769238	20130U	PARTICIPANT	\N	PRESENT	0
771164	769238	20092G	PARTICIPANT	\N	PRESENT	0
771165	769238	20126Y	PARTICIPANT	\N	PRESENT	0
771166	769238	21079P	PARTICIPANT	\N	PRESENT	0
771167	769238	21094N	PARTICIPANT	\N	PRESENT	0
771168	769238	20266L	PARTICIPANT	\N	PRESENT	0
771169	769238	21043B	PARTICIPANT	\N	PRESENT	0
771170	769238	14193X	PARTICIPANT	\N	PRESENT	0
771171	769238	20124W	PARTICIPANT	\N	PRESENT	0
771172	769238	19782L	PARTICIPANT	\N	PRESENT	0
771173	769238	21096Q	PARTICIPANT	\N	PRESENT	0
771174	769238	19507S	PARTICIPANT	\N	PRESENT	0
771175	769238	19057M	PARTICIPANT	\N	PRESENT	0
771176	769238	14249W	PARTICIPANT	\N	PRESENT	0
771177	769238	21033Y	PARTICIPANT	\N	PRESENT	0
771178	769238	14105F	PARTICIPANT	\N	PRESENT	0
771179	769238	19707Y	PARTICIPANT	\N	PRESENT	0
771180	769238	19705W	PARTICIPANT	\N	PRESENT	0
771181	769238	19768N	PARTICIPANT	\N	PRESENT	0
771182	769238	20106U	PARTICIPANT	\N	PRESENT	0
771183	769238	08015R	PARTICIPANT	\N	PRESENT	0
771184	769238	19657G	PARTICIPANT	\N	PRESENT	0
771185	769238	19591F	PARTICIPANT	\N	PRESENT	0
771186	769238	07029T	PARTICIPANT	\N	PRESENT	0
771187	769238	20128B	PARTICIPANT	\N	PRESENT	0
771188	769238	14037X	PARTICIPANT	\N	PRESENT	0
771189	769238	21029D	PARTICIPANT	\N	PRESENT	0
771190	769238	19697Q	PARTICIPANT	\N	PRESENT	0
771191	769238	11072N	PARTICIPANT	\N	PRESENT	0
771192	769238	14071N	PARTICIPANT	\N	PRESENT	0
771193	769238	21097R	PARTICIPANT	\N	PRESENT	0
771194	769238	19331L	PARTICIPANT	\N	PRESENT	0
771195	769238	19709B	PARTICIPANT	\N	PRESENT	0
771196	769238	14355X	PARTICIPANT	\N	PRESENT	0
771197	769238	08061X	PARTICIPANT	\N	PRESENT	0
771198	769238	08073C	PARTICIPANT	\N	PRESENT	0
771199	769238	17367Q	PARTICIPANT	\N	PRESENT	0
771200	769238	20146D	PARTICIPANT	\N	PRESENT	0
771201	769238	20150Y	PARTICIPANT	\N	PRESENT	0
771202	769238	04045F	PARTICIPANT	\N	PRESENT	0
771203	769238	19301E	PARTICIPANT	\N	PRESENT	0
771204	769238	21063F	PARTICIPANT	\N	PRESENT	0
771205	769238	21036C	PARTICIPANT	\N	PRESENT	0
771206	769238	20116W	PARTICIPANT	\N	PRESENT	0
771207	769238	21071F	PARTICIPANT	\N	PRESENT	0
771208	769238	14207L	PARTICIPANT	\N	PRESENT	0
771209	769238	19629C	PARTICIPANT	\N	PRESENT	0
771210	769238	19719D	PARTICIPANT	\N	PRESENT	0
771211	769238	20132W	PARTICIPANT	\N	PRESENT	0
771212	769238	21032X	PARTICIPANT	\N	PRESENT	0
771213	769238	19387D	PARTICIPANT	\N	PRESENT	0
771214	769238	21066J	PARTICIPANT	\N	PRESENT	0
771215	769238	11090Q	PARTICIPANT	\N	PRESENT	0
771216	769238	20072C	PARTICIPANT	\N	PRESENT	0
771217	769238	21040X	PARTICIPANT	\N	PRESENT	0
771218	769238	19866P	PARTICIPANT	\N	PRESENT	0
771219	769238	95041E	PARTICIPANT	\N	PRESENT	0
771220	769238	19545Y	PARTICIPANT	\N	PRESENT	0
771221	769238	21046E	PARTICIPANT	\N	PRESENT	0
771222	769238	14195A	PARTICIPANT	\N	PRESENT	0
771223	769238	19693L	PARTICIPANT	\N	PRESENT	0
771224	769238	21092L	PARTICIPANT	\N	PRESENT	0
771225	769238	14211G	PARTICIPANT	\N	PRESENT	0
771226	769238	21054E	PARTICIPANT	\N	PRESENT	0
771227	769238	14251Q	PARTICIPANT	\N	PRESENT	0
771228	769238	14221J	PARTICIPANT	\N	PRESENT	0
771229	769238	14147R	PARTICIPANT	\N	PRESENT	0
771230	769238	20050V	PARTICIPANT	\N	PRESENT	0
771231	769238	21070E	PARTICIPANT	\N	PRESENT	0
771232	769238	21076L	PARTICIPANT	\N	PRESENT	0
771233	769238	19585H	PARTICIPANT	\N	PRESENT	0
771234	769238	21065H	PARTICIPANT	\N	PRESENT	0
771235	769238	19631V	PARTICIPANT	\N	PRESENT	0
771236	769238	19735D	PARTICIPANT	\N	PRESENT	0
771237	769238	21035B	PARTICIPANT	\N	PRESENT	0
771238	769238	14219Q	PARTICIPANT	\N	PRESENT	0
771239	769238	08011M	PARTICIPANT	\N	PRESENT	0
771240	769238	20048C	PARTICIPANT	\N	PRESENT	0
771241	769238	14275Y	PARTICIPANT	\N	PRESENT	0
771242	769238	14030Q	PARTICIPANT	\N	PRESENT	0
771243	769238	14042U	PARTICIPANT	\N	PRESENT	0
771244	769238	14073Q	PARTICIPANT	\N	PRESENT	0
771245	769238	19619A	PARTICIPANT	\N	PRESENT	0
771247	769238	20052X	PARTICIPANT	\N	PRESENT	0
771248	769238	19721W	PARTICIPANT	\N	PRESENT	0
771249	769238	21067K	PARTICIPANT	\N	PRESENT	0
771250	769238	08045X	PARTICIPANT	\N	PRESENT	0
771251	769238	14109K	PARTICIPANT	\N	PRESENT	0
771252	769238	18207D	PARTICIPANT	\N	PRESENT	0
771253	769238	14097Y	PARTICIPANT	\N	PRESENT	0
771254	769238	19820Y	PARTICIPANT	\N	PRESENT	0
771255	769238	17965H	PARTICIPANT	\N	PRESENT	0
771256	769238	19683J	PARTICIPANT	\N	PRESENT	0
771257	769238	11048N	PARTICIPANT	\N	PRESENT	0
771258	769238	21082J	PARTICIPANT	\N	PRESENT	0
771259	769238	21077M	PARTICIPANT	\N	PRESENT	0
771260	769238	19699S	PARTICIPANT	\N	PRESENT	0
771261	769238	21031W	PARTICIPANT	\N	PRESENT	0
771262	769238	14267Y	PARTICIPANT	\N	PRESENT	0
771263	769238	19531S	PARTICIPANT	\N	PRESENT	0
771264	769238	19551W	PARTICIPANT	\N	PRESENT	0
771265	769238	19725B	PARTICIPANT	\N	PRESENT	0
771266	769238	11085T	PARTICIPANT	\N	PRESENT	0
771267	769238	21062E	PARTICIPANT	\N	PRESENT	0
771268	769238	14189C	PARTICIPANT	\N	PRESENT	0
771269	769238	11110B	PARTICIPANT	\N	PRESENT	0
771270	769238	14121F	PARTICIPANT	\N	PRESENT	0
771271	769238	14021P	PARTICIPANT	\N	PRESENT	0
771272	769238	19669L	PARTICIPANT	\N	PRESENT	0
771273	769238	20066E	PARTICIPANT	\N	PRESENT	0
771274	769238	20060X	PARTICIPANT	\N	PRESENT	0
771275	769238	21089R	PARTICIPANT	\N	PRESENT	0
771276	769238	19489J	PARTICIPANT	\N	PRESENT	0
771277	769238	12016W	PARTICIPANT	\N	PRESENT	0
771278	769238	01034P	PARTICIPANT	\N	PRESENT	0
771279	769238	20028X	PARTICIPANT	\N	PRESENT	0
771280	769238	20030R	PARTICIPANT	\N	PRESENT	0
771281	769238	20080C	PARTICIPANT	\N	PRESENT	0
771282	769238	20088L	PARTICIPANT	\N	PRESENT	0
771283	769238	19611R	PARTICIPANT	\N	PRESENT	0
771284	769238	21045D	PARTICIPANT	\N	PRESENT	0
771285	769238	12028B	PARTICIPANT	\N	PRESENT	0
771286	769238	19295A	PARTICIPANT	\N	PRESENT	0
771287	769238	20264J	PARTICIPANT	\N	PRESENT	0
771288	769238	21057H	PARTICIPANT	\N	PRESENT	0
771289	769238	11027H	PARTICIPANT	\N	PRESENT	0
771290	769238	18395Y	PARTICIPANT	\N	PRESENT	0
771291	769238	14151M	PARTICIPANT	\N	PRESENT	0
771292	769238	20070A	PARTICIPANT	\N	PRESENT	0
771293	769238	21060C	PARTICIPANT	\N	PRESENT	0
771294	769238	15197G	PARTICIPANT	\N	PRESENT	0
771295	769238	14281W	PARTICIPANT	\N	PRESENT	0
771296	769238	17779H	PARTICIPANT	\N	PRESENT	0
771297	769238	19647E	PARTICIPANT	\N	PRESENT	0
771298	769238	19649G	PARTICIPANT	\N	PRESENT	0
771299	769238	18193Q	PARTICIPANT	\N	PRESENT	0
771300	769238	21038E	PARTICIPANT	\N	PRESENT	0
771301	769238	14257W	PARTICIPANT	\N	PRESENT	0
771302	769238	19749K	PARTICIPANT	\N	PRESENT	0
771303	769238	19479G	PARTICIPANT	\N	PRESENT	0
771304	769238	14001X	PARTICIPANT	\N	PRESENT	0
771305	769238	19563B	PARTICIPANT	\N	PRESENT	0
785481	783387	14207L	PARTICIPANT	\N	PRESENT	0
785482	783387	07029T	PARTICIPANT	\N	PRESENT	0
785483	783387	20132W	PARTICIPANT	\N	PRESENT	0
785484	783387	21047F	PARTICIPANT	\N	PRESENT	0
785485	783387	17367Q	PARTICIPANT	\N	PRESENT	0
785486	783387	21052C	PARTICIPANT	\N	PRESENT	0
785487	783387	20068G	PARTICIPANT	\N	PRESENT	0
785488	783387	21063F	PARTICIPANT	\N	PRESENT	0
785489	783387	14221J	PARTICIPANT	\N	PRESENT	0
785490	783387	21036C	PARTICIPANT	\N	PRESENT	0
785491	783387	19545Y	PARTICIPANT	\N	PRESENT	0
785492	783387	21087P	PARTICIPANT	\N	PRESENT	0
785495	783387	19693L	PARTICIPANT	\N	PRESENT	0
785496	783387	21050A	PARTICIPANT	\N	PRESENT	0
785497	783387	21054E	PARTICIPANT	\N	PRESENT	0
785499	783387	11053K	PARTICIPANT	\N	PRESENT	0
785500	783387	20050V	PARTICIPANT	\N	PRESENT	0
785502	783387	21076L	PARTICIPANT	\N	PRESENT	0
785503	783387	19585H	PARTICIPANT	\N	PRESENT	0
785505	783387	19631V	PARTICIPANT	\N	PRESENT	0
785506	783387	17965H	PARTICIPANT	\N	PRESENT	0
785507	783387	17779H	PARTICIPANT	\N	PRESENT	0
785508	783387	20082E	PARTICIPANT	\N	PRESENT	0
785509	783387	20060X	PARTICIPANT	\N	PRESENT	0
785510	783387	19531S	PARTICIPANT	\N	PRESENT	0
785511	783387	21062E	PARTICIPANT	\N	PRESENT	0
785512	783387	11110B	PARTICIPANT	\N	PRESENT	0
785513	783387	14151M	PARTICIPANT	\N	PRESENT	0
785514	783387	07004J	PARTICIPANT	\N	PRESENT	0
785515	783387	19647E	PARTICIPANT	\N	PRESENT	0
785516	783387	19649G	PARTICIPANT	\N	PRESENT	0
785517	783387	18207D	PARTICIPANT	\N	PRESENT	0
785518	783387	18193Q	PARTICIPANT	\N	PRESENT	0
785519	783387	01034P	PARTICIPANT	\N	PRESENT	0
785520	783387	20084G	PARTICIPANT	\N	PRESENT	0
785521	783387	14121F	PARTICIPANT	\N	PRESENT	0
785522	783387	19489J	PARTICIPANT	\N	PRESENT	0
785523	783387	21051B	PARTICIPANT	\N	PRESENT	0
785524	783387	20036X	PARTICIPANT	\N	PRESENT	0
785525	783387	20114U	PARTICIPANT	\N	PRESENT	0
785526	783387	20264J	PARTICIPANT	\N	PRESENT	0
785527	783387	21077M	PARTICIPANT	\N	PRESENT	0
785528	783387	20080C	PARTICIPANT	\N	PRESENT	0
785529	783387	21089R	PARTICIPANT	\N	PRESENT	0
785530	783387	12028B	PARTICIPANT	\N	PRESENT	0
785531	783387	18395Y	PARTICIPANT	\N	PRESENT	0
785532	783387	21059K	PARTICIPANT	\N	PRESENT	0
785533	783387	14229S	PARTICIPANT	\N	PRESENT	0
785534	783387	19820Y	PARTICIPANT	\N	PRESENT	0
785535	783387	20070A	PARTICIPANT	\N	PRESENT	0
785536	783387	14001X	PARTICIPANT	\N	PRESENT	0
785537	783387	11074Q	PARTICIPANT	\N	PRESENT	0
785538	783387	21082J	PARTICIPANT	\N	PRESENT	0
785539	783387	20094J	PARTICIPANT	\N	PRESENT	0
785540	783387	20088L	PARTICIPANT	\N	PRESENT	0
785542	783387	14281W	PARTICIPANT	\N	PRESENT	0
785543	783387	19551W	PARTICIPANT	\N	PRESENT	0
785544	783387	08012N	PARTICIPANT	\N	PRESENT	0
785545	783387	14205J	PARTICIPANT	\N	PRESENT	0
785546	783387	19826F	PARTICIPANT	\N	PRESENT	0
785856	783389	14111D	PARTICIPANT	\N	PRESENT	0
785548	783387	18231D	PARTICIPANT	\N	PRESENT	0
785549	783387	21060C	PARTICIPANT	\N	PRESENT	0
785551	783387	20048C	PARTICIPANT	\N	PRESENT	0
785552	783387	14249W	PARTICIPANT	\N	PRESENT	0
785555	783387	20064C	PARTICIPANT	\N	PRESENT	0
785556	783387	20286Q	PARTICIPANT	\N	PRESENT	0
785558	783387	21056G	PARTICIPANT	\N	PRESENT	0
785562	783387	14030Q	PARTICIPANT	\N	PRESENT	0
785563	783387	19721W	PARTICIPANT	\N	PRESENT	0
785565	783387	14219Q	PARTICIPANT	\N	PRESENT	0
785566	783387	14042U	PARTICIPANT	\N	PRESENT	0
785567	783387	19569H	PARTICIPANT	\N	PRESENT	0
785568	783387	19611R	PARTICIPANT	\N	PRESENT	0
785569	783387	14327T	PARTICIPANT	\N	PRESENT	0
785570	783387	19691J	PARTICIPANT	\N	PRESENT	0
785571	783387	14231L	PARTICIPANT	\N	PRESENT	0
785572	783387	17023S	PARTICIPANT	\N	PRESENT	0
785573	783387	21083K	PARTICIPANT	\N	PRESENT	0
785574	783387	14179A	PARTICIPANT	\N	PRESENT	0
785575	783387	19685L	PARTICIPANT	\N	PRESENT	0
785576	783387	20040T	PARTICIPANT	\N	PRESENT	0
785577	783387	21086N	PARTICIPANT	\N	PRESENT	0
785578	783387	19111A	PARTICIPANT	\N	PRESENT	0
785579	783387	19745F	PARTICIPANT	\N	PRESENT	0
785580	783387	20042V	PARTICIPANT	\N	PRESENT	0
785581	783387	11115U	PARTICIPANT	\N	PRESENT	0
785582	783387	19335Q	PARTICIPANT	\N	PRESENT	0
785583	783387	19699S	PARTICIPANT	\N	PRESENT	0
785584	783387	20052X	PARTICIPANT	\N	PRESENT	0
785585	783387	21038E	PARTICIPANT	\N	PRESENT	0
785586	783387	14251Q	PARTICIPANT	\N	PRESENT	0
785587	783387	19713W	PARTICIPANT	\N	PRESENT	0
785588	783387	19563B	PARTICIPANT	\N	PRESENT	0
785589	783387	21064G	PARTICIPANT	\N	PRESENT	0
785590	783387	15197G	PARTICIPANT	\N	PRESENT	0
785591	783387	21065H	PARTICIPANT	\N	PRESENT	0
785595	783387	20102Q	PARTICIPANT	\N	PRESENT	0
785606	783387	14089Y	PARTICIPANT	\N	PRESENT	0
785594	783387	19749K	PARTICIPANT	\N	PRESENT	0
785596	783387	19565D	PARTICIPANT	\N	PRESENT	0
785597	783387	19447X	PARTICIPANT	\N	PRESENT	0
785598	783387	17737W	PARTICIPANT	\N	PRESENT	0
785599	783387	20266L	PARTICIPANT	\N	PRESENT	0
785600	783387	20092G	PARTICIPANT	\N	PRESENT	0
785601	783387	20100N	PARTICIPANT	\N	PRESENT	0
785602	783387	19387D	PARTICIPANT	\N	PRESENT	0
785603	783387	19553Y	PARTICIPANT	\N	PRESENT	0
785604	783387	20248J	PARTICIPANT	\N	PRESENT	0
785605	783387	19057M	PARTICIPANT	\N	PRESENT	0
785857	783389	20128B	PARTICIPANT	\N	PRESENT	0
785858	783389	21084L	PARTICIPANT	\N	PRESENT	0
785859	783389	19758L	PARTICIPANT	\N	PRESENT	0
785863	783389	05012A	PARTICIPANT	\N	PRESENT	0
785864	783389	08010L	PARTICIPANT	\N	PRESENT	0
785865	783389	21072G	PARTICIPANT	\N	PRESENT	0
785884	783389	19711U	PARTICIPANT	\N	PRESENT	0
785867	783389	19723Y	PARTICIPANT	\N	PRESENT	0
785899	783389	19553Y	PARTICIPANT	\N	PRESENT	0
785869	783389	20134Y	PARTICIPANT	\N	PRESENT	0
785870	783389	21052C	PARTICIPANT	\N	PRESENT	0
785871	783389	20180F	PARTICIPANT	\N	PRESENT	0
785873	783389	14195A	PARTICIPANT	\N	PRESENT	0
785874	783389	21054E	PARTICIPANT	\N	PRESENT	0
785927	783389	21076L	PARTICIPANT	\N	PRESENT	0
785876	783389	19479G	PARTICIPANT	\N	PRESENT	0
785877	783389	19335Q	PARTICIPANT	\N	PRESENT	0
785878	783389	19954N	PARTICIPANT	\N	PRESENT	0
785879	783389	17737W	PARTICIPANT	\N	PRESENT	0
785881	783389	21093M	PARTICIPANT	\N	PRESENT	0
785883	783389	20084G	PARTICIPANT	\N	PRESENT	0
785887	783389	14069U	PARTICIPANT	\N	PRESENT	0
785891	783389	18083K	PARTICIPANT	\N	PRESENT	0
785894	783389	14249W	PARTICIPANT	\N	PRESENT	0
785896	783389	21065H	PARTICIPANT	\N	PRESENT	0
785907	783389	21049H	PARTICIPANT	\N	PRESENT	0
785913	783389	19551W	PARTICIPANT	\N	PRESENT	0
785915	783389	20100N	PARTICIPANT	\N	PRESENT	0
785931	783389	20032T	PARTICIPANT	\N	PRESENT	0
785930	783389	19565D	PARTICIPANT	\N	PRESENT	0
785933	783389	21082J	PARTICIPANT	\N	PRESENT	0
785934	783389	11072N	PARTICIPANT	\N	PRESENT	0
785935	783389	21041Y	PARTICIPANT	\N	PRESENT	0
785939	783389	14133K	PARTICIPANT	\N	PRESENT	0
785940	783389	08018U	PARTICIPANT	\N	PRESENT	0
785945	783389	07029T	PARTICIPANT	\N	PRESENT	0
785948	783389	20172F	PARTICIPANT	\N	PRESENT	0
785950	783389	14083S	PARTICIPANT	\N	PRESENT	0
785953	783389	21057H	PARTICIPANT	\N	PRESENT	0
785955	783389	21086N	PARTICIPANT	\N	PRESENT	0
785962	783389	11053K	PARTICIPANT	\N	PRESENT	0
785963	783389	20132W	PARTICIPANT	\N	PRESENT	0
785965	783389	14237S	PARTICIPANT	\N	PRESENT	0
773448	773447	21094N	PARTICIPANT	\N	PRESENT	0
779822	779814	20022R	PARTICIPANT	\N	PRESENT	0
779824	779814	19611R	PARTICIPANT	\N	PRESENT	0
780113	777995	14151M	PRESIDENT	0	PRESENT	0
780114	777995	12028B	PARTICIPANT	\N	PRESENT	0
780115	777995	21040X	PARTICIPANT	\N	PRESENT	0
780116	777995	17367Q	PARTICIPANT	\N	PRESENT	0
780117	777995	19563B	PARTICIPANT	\N	PRESENT	0
780118	777995	20050V	PARTICIPANT	\N	EXCUSE	0
780119	777995	20090E	PARTICIPANT	\N	EXCUSE	0
780132	777995	19295A	PARTICIPANT	\N	PRESENT	0
780134	777995	20108W	PARTICIPANT	\N	PRESENT	0
780142	777995	14255U	PARTICIPANT	\N	PRESENT	0
780147	777995	19349W	PARTICIPANT	\N	PRESENT	0
780153	777995	20252E	PARTICIPANT	\N	PRESENT	0
780261	777996	20090E	PARTICIPANT	\N	EXCUSE	0
780262	777996	20050V	PARTICIPANT	\N	EXCUSE	0
780263	777996	17737W	PARTICIPANT	\N	EXCUSE	0
773804	773785	19553Y	PARTICIPANT	\N	PRESENT	0
780264	777996	19563B	PARTICIPANT	\N	PRESENT	0
780410	777996	21088Q	PARTICIPANT	\N	EXCUSE	0
780462	777996	21081H	PARTICIPANT	\N	PRESENT	0
780463	777996	17367Q	PARTICIPANT	\N	PRESENT	0
780464	777996	19826F	PARTICIPANT	\N	PRESENT	0
780465	777996	14151M	PRESIDENT	0	PRESENT	0
780466	777996	20146D	PARTICIPANT	\N	PRESENT	0
780467	777996	18395Y	PARTICIPANT	\N	PRESENT	0
780468	777996	12028B	PARTICIPANT	\N	PRESENT	0
780469	777996	20078J	PARTICIPANT	\N	PRESENT	0
780470	777996	19349W	PARTICIPANT	\N	PRESENT	0
780471	777996	15197G	PARTICIPANT	\N	PRESENT	0
780478	779280	19447X	PARTICIPANT	\N	PRESENT	0
780479	779280	21044C	PARTICIPANT	\N	PRESENT	0
780480	779280	20074E	PARTICIPANT	\N	PRESENT	0
780481	779280	10015M	PARTICIPANT	\N	PRESENT	0
780482	779280	19749K	PARTICIPANT	\N	PRESENT	0
780483	779280	14053L	PARTICIPANT	\N	PRESENT	0
780484	779280	21043B	PARTICIPANT	\N	PRESENT	0
780485	779280	04045F	PARTICIPANT	\N	PRESENT	0
780486	779280	21057H	PARTICIPANT	\N	PRESENT	0
780487	779280	20098N	PARTICIPANT	\N	PRESENT	0
780488	779280	14069U	PARTICIPANT	\N	PRESENT	0
780489	779280	21076L	PARTICIPANT	\N	PRESENT	0
780490	779280	20022R	PARTICIPANT	\N	PRESENT	0
780491	779280	14147R	PARTICIPANT	\N	PRESENT	0
780492	779280	04047H	PRESIDENT	0	PRESENT	0
780493	779280	20110Q	PARTICIPANT	\N	PRESENT	0
780494	779280	08018U	PARTICIPANT	\N	PRESENT	0
780495	779280	21095P	PARTICIPANT	\N	PRESENT	0
781224	778865	04092N	PRESIDENT	0	PRESENT	0
781225	778865	19569H	PARTICIPANT	\N	PRESENT	0
781226	778865	14071N	PARTICIPANT	\N	PRESENT	0
781227	778865	18193Q	PARTICIPANT	\N	PRESENT	0
781228	778865	14217N	PARTICIPANT	\N	PRESENT	0
781229	778865	19798U	PARTICIPANT	\N	PRESENT	0
781230	778865	14026U	PARTICIPANT	\N	PRESENT	0
781231	778865	14213J	PARTICIPANT	\N	PRESENT	0
781232	778865	20130U	PARTICIPANT	\N	PRESENT	0
781233	778865	19553Y	PARTICIPANT	\N	EXCUSE	0
781234	778865	19683J	PARTICIPANT	\N	EXCUSE	0
781235	778865	17965H	PARTICIPANT	\N	EXCUSE	0
781236	778865	19703U	PARTICIPANT	\N	EXCUSE	0
781237	778865	21087P	PARTICIPANT	\N	EXCUSE	0
781238	778865	14195A	PARTICIPANT	\N	EXCUSE	0
781574	779281	19447X	PARTICIPANT	\N	PRESENT	0
781575	779281	20108W	PARTICIPANT	\N	PRESENT	0
781620	779301	19798U	PARTICIPANT	\N	PRESENT	0
781621	779301	14223L	PARTICIPANT	\N	PRESENT	0
781622	779301	14026U	PARTICIPANT	\N	PRESENT	0
781623	779301	20096L	PARTICIPANT	\N	PRESENT	0
781624	779301	21064G	PARTICIPANT	\N	PRESENT	0
781625	779301	19703U	PARTICIPANT	\N	PRESENT	0
781626	779301	19679N	PARTICIPANT	\N	PRESENT	0
781627	779301	14042U	PARTICIPANT	\N	PRESENT	0
781628	779301	14195A	PARTICIPANT	\N	PRESENT	0
781629	779301	14213J	PARTICIPANT	\N	PRESENT	0
779823	779814	20098N	PARTICIPANT	\N	PRESENT	0
781630	779301	19367Y	PARTICIPANT	\N	PRESENT	0
781631	779301	14217N	PARTICIPANT	\N	PRESENT	0
781632	779301	21039F	PARTICIPANT	\N	PRESENT	0
781633	779301	21097R	PARTICIPANT	\N	PRESENT	0
781634	779301	20140W	PARTICIPANT	\N	PRESENT	0
781635	779301	19301E	PARTICIPANT	\N	PRESENT	0
781636	779301	19691J	PARTICIPANT	\N	PRESENT	0
781637	779301	20148F	PARTICIPANT	\N	PRESENT	0
781638	779301	19723Y	PARTICIPANT	\N	PRESENT	0
781639	779301	20248J	PARTICIPANT	\N	PRESENT	0
781640	779301	14071N	PRESIDENT	0	PRESENT	0
781641	779301	19758L	PARTICIPANT	\N	PRESENT	0
781642	779301	19760E	PARTICIPANT	\N	PRESENT	0
781643	779301	21081H	PARTICIPANT	\N	PRESENT	0
781644	779301	18193Q	PARTICIPANT	\N	PRESENT	0
781646	779152	21036C	PARTICIPANT	\N	PRESENT	0
781647	779152	95041E	PARTICIPANT	\N	PRESENT	0
781648	779152	21031W	PARTICIPANT	\N	PRESENT	0
781649	779152	19565D	PARTICIPANT	\N	PRESENT	0
781650	779152	20072C	PARTICIPANT	\N	PRESENT	0
781651	779152	01058X	PARTICIPANT	\N	PRESENT	0
781652	779152	11027H	PARTICIPANT	\N	PRESENT	0
781653	779152	04042C	PARTICIPANT	\N	PRESENT	0
781654	779152	19669L	PARTICIPANT	\N	PRESENT	0
781655	779152	08056B	PARTICIPANT	\N	PRESENT	0
781656	779152	12028B	PARTICIPANT	\N	PRESENT	0
781657	779152	17737W	PARTICIPANT	\N	PRESENT	0
781658	779152	11115U	PARTICIPANT	\N	PRESENT	0
781659	779152	19421M	PARTICIPANT	\N	PRESENT	0
781660	779152	21067K	PARTICIPANT	\N	PRESENT	0
781661	779152	14193X	PRESIDENT	0	PRESENT	0
781662	779152	14179A	PARTICIPANT	\N	PRESENT	0
781663	779152	17367Q	PARTICIPANT	\N	PRESENT	0
781664	779152	14249W	PARTICIPANT	\N	PRESENT	0
781665	779152	08047A	PARTICIPANT	\N	PRESENT	0
781666	779152	20128B	PARTICIPANT	\N	PRESENT	0
781667	779152	14037X	PARTICIPANT	\N	PRESENT	0
781668	779152	14097Y	PARTICIPANT	\N	PRESENT	0
781669	779152	14059S	PARTICIPANT	\N	PRESENT	0
781670	779152	14133K	PARTICIPANT	\N	PRESENT	0
781671	779152	21073H	PARTICIPANT	\N	PRESENT	0
781672	779152	19531S	PARTICIPANT	\N	PRESENT	0
781673	779152	08069G	PARTICIPANT	\N	PRESENT	0
781674	779152	19721W	PARTICIPANT	\N	PRESENT	0
781675	779152	20064C	PARTICIPANT	\N	PRESENT	0
781676	779152	20252E	PARTICIPANT	\N	PRESENT	0
781677	779152	14251Q	PARTICIPANT	\N	PRESENT	0
781678	779152	98022P	PARTICIPANT	\N	PRESENT	0
781679	779152	14267Y	PARTICIPANT	\N	PRESENT	0
781680	779152	99004R	PARTICIPANT	\N	PRESENT	0
781681	779152	19745F	PARTICIPANT	\N	PRESENT	0
781682	779152	14211G	PARTICIPANT	\N	PRESENT	0
781683	779152	14255U	PARTICIPANT	\N	PRESENT	0
781684	779152	17023S	PARTICIPANT	\N	PRESENT	0
781685	779152	14001X	PARTICIPANT	\N	EXCUSE	0
781686	779152	07033P	PARTICIPANT	\N	EXCUSE	0
781687	781491	21082J	PARTICIPANT	\N	PRESENT	0
781688	781491	21029D	PARTICIPANT	\N	PRESENT	0
781689	781491	21035B	PARTICIPANT	\N	PRESENT	0
781690	781491	21042A	PARTICIPANT	\N	PRESENT	0
781691	781491	19387D	PARTICIPANT	\N	PRESENT	0
781692	781491	14219Q	PRESIDENT	0	PRESENT	0
781693	781491	19820Y	PARTICIPANT	\N	PRESENT	0
781694	781491	19826F	PARTICIPANT	\N	PRESENT	0
781695	781491	21060C	PARTICIPANT	\N	PRESENT	0
781696	781491	21062E	PARTICIPANT	\N	PRESENT	0
781697	781491	18083K	PARTICIPANT	\N	PRESENT	0
781698	781491	19551W	PARTICIPANT	\N	PRESENT	0
781699	781491	21084L	PARTICIPANT	\N	PRESENT	0
781700	781491	20100N	PARTICIPANT	\N	PRESENT	0
781701	781491	14237S	PARTICIPANT	\N	PRESENT	0
781702	781491	05012A	PARTICIPANT	\N	PRESENT	0
781703	781491	08060W	PARTICIPANT	\N	PRESENT	0
781704	781491	20106U	PARTICIPANT	\N	PRESENT	0
781705	781491	20118Y	PARTICIPANT	\N	PRESENT	0
781706	781491	15197G	PARTICIPANT	\N	PRESENT	0
781707	781491	14107H	PARTICIPANT	\N	PRESENT	0
781708	781491	21080G	PARTICIPANT	\N	PRESENT	0
781709	781491	19331L	PARTICIPANT	\N	PRESENT	0
781710	781491	20020P	PARTICIPANT	\N	PRESENT	0
781711	781491	19685L	PARTICIPANT	\N	PRESENT	0
781712	781491	21051B	PARTICIPANT	\N	PRESENT	0
781713	781491	20120S	PARTICIPANT	\N	PRESENT	0
781714	781491	20032T	PARTICIPANT	\N	PRESENT	0
797371	797370	19749K	PARTICIPANT	\N	PRESENT	0
797373	797370	21076L	PARTICIPANT	\N	PRESENT	0
797374	797370	19649G	PARTICIPANT	\N	PRESENT	0
797379	797377	19749K	PARTICIPANT	\N	PRESENT	0
797383	797382	19749K	PARTICIPANT	\N	PRESENT	0
797386	797385	19749K	PARTICIPANT	\N	PRESENT	0
797388	797387	19749K	PARTICIPANT	\N	PRESENT	0
797389	797387	21076L	PARTICIPANT	\N	PRESENT	0
797390	797387	21095P	PARTICIPANT	\N	PRESENT	0
797392	797391	19749K	PARTICIPANT	\N	PRESENT	0
797393	797391	21076L	PARTICIPANT	\N	PRESENT	0
797407	797406	19673G	PARTICIPANT	\N	PRESENT	0
797408	797406	19749K	PARTICIPANT	\N	PRESENT	0
797410	797409	19673G	PARTICIPANT	\N	PRESENT	0
797411	797409	19749K	PARTICIPANT	\N	PRESENT	0
797412	797409	20110Q	PARTICIPANT	\N	PRESENT	0
797413	797409	07004J	PARTICIPANT	\N	PRESENT	0
797415	797414	05008E	PARTICIPANT	\N	PRESENT	0
797417	797416	05008E	PARTICIPANT	\N	PRESENT	0
797420	797418	05008E	PARTICIPANT	\N	PRESENT	0
797425	794703	21035B	PARTICIPANT	\N	EXCUSE	0
797426	794703	19673G	PARTICIPANT	\N	EXCUSE	0
797430	797429	21084L	PARTICIPANT	\N	PRESENT	0
797431	797429	21086N	PARTICIPANT	\N	PRESENT	0
797435	797429	20038A	PARTICIPANT	\N	PRESENT	0
797433	797429	14055N	PARTICIPANT	\N	PRESENT	0
797434	797429	04042C	PARTICIPANT	\N	PRESENT	0
797436	797429	19669L	PARTICIPANT	\N	PRESENT	0
797453	794704	21035B	PARTICIPANT	\N	EXCUSE	0
797454	794704	19673G	PARTICIPANT	\N	EXCUSE	0
797455	794704	04042C	PARTICIPANT	\N	EXCUSE	0
797832	797831	14179A	PARTICIPANT	\N	PRESENT	0
797833	797831	08047A	PARTICIPANT	\N	PRESENT	0
797834	794853	21089R	PARTICIPANT	\N	PRESENT	0
797835	794853	18193Q	PARTICIPANT	\N	PRESENT	0
797836	794853	20180F	PARTICIPANT	\N	PRESENT	0
797837	794853	14147R	PARTICIPANT	\N	PRESENT	0
803821	801132	18193Q	PARTICIPANT	\N	EXCUSE	0
803822	801132	21044C	PARTICIPANT	\N	PRESENT	0
803823	801132	20146D	PARTICIPANT	\N	PRESENT	0
803824	801132	14030Q	PARTICIPANT	\N	PRESENT	0
803825	801132	19749K	PARTICIPANT	\N	PRESENT	0
803826	801132	21087P	PARTICIPANT	\N	PRESENT	0
803827	801132	14147R	PARTICIPANT	\N	PRESENT	0
803828	801132	21091K	PARTICIPANT	\N	PRESENT	0
803829	801132	19798U	PARTICIPANT	\N	PRESENT	0
803830	801132	21089R	PARTICIPANT	\N	PRESENT	0
803831	801132	14109K	PARTICIPANT	\N	PRESENT	0
803832	801132	11045K	PARTICIPANT	\N	PRESENT	0
803833	801132	21038E	PARTICIPANT	\N	PRESENT	0
803834	801132	14189C	PARTICIPANT	\N	PRESENT	0
803835	801132	21094N	PARTICIPANT	\N	PRESENT	0
803836	801132	21061D	PARTICIPANT	\N	PRESENT	0
803837	801132	20114U	PARTICIPANT	\N	PRESENT	0
803838	801132	14179A	PARTICIPANT	\N	PRESENT	0
803839	801132	21034A	PARTICIPANT	\N	PRESENT	0
803840	801132	20098N	PARTICIPANT	\N	PRESENT	0
803849	801132	21071F	PARTICIPANT	\N	PRESENT	0
803851	801149	20072C	PARTICIPANT	\N	EXCUSE	0
803874	801149	20138D	PARTICIPANT	\N	EXCUSE	0
803884	801132	07029T	PARTICIPANT	\N	EXCUSE	0
804063	801149	20034V	PARTICIPANT	\N	PRESENT	0
804089	799027	14042U	PARTICIPANT	\N	PRESENT	0
804090	799027	19760E	PARTICIPANT	\N	PRESENT	0
804091	799027	17965H	PARTICIPANT	\N	PRESENT	0
804092	799028	19760E	PARTICIPANT	\N	PRESENT	0
804093	799028	14042U	PARTICIPANT	\N	PRESENT	0
804094	799029	14042U	PARTICIPANT	\N	PRESENT	0
804095	799029	20130U	PARTICIPANT	\N	PRESENT	0
804817	803916	19631V	PARTICIPANT	\N	PRESENT	0
804818	803916	20124W	PARTICIPANT	\N	PRESENT	0
804840	803916	08034U	PARTICIPANT	\N	PRESENT	0
804841	803916	11056N	PARTICIPANT	\N	PRESENT	0
804843	803916	21075K	PARTICIPANT	\N	PRESENT	0
804844	803916	20100N	PARTICIPANT	\N	PRESENT	0
804845	803916	20072C	PARTICIPANT	\N	PRESENT	0
804846	803916	14267Y	PARTICIPANT	\N	PRESENT	0
804847	803916	19669L	PARTICIPANT	\N	PRESENT	0
804848	803916	21082J	PARTICIPANT	\N	PRESENT	0
804849	803916	20136B	PARTICIPANT	\N	PRESENT	0
804850	803916	20068G	PARTICIPANT	\N	PRESENT	0
804851	803916	21071F	PARTICIPANT	\N	PRESENT	0
804852	803916	19347U	PARTICIPANT	\N	PRESENT	0
804853	803916	20134Y	PARTICIPANT	\N	PRESENT	0
804915	803917	14111D	PARTICIPANT	\N	PRESENT	0
804916	803917	21084L	PARTICIPANT	\N	PRESENT	0
804917	803917	21075K	PARTICIPANT	\N	PRESENT	0
804918	803917	19593H	PARTICIPANT	\N	PRESENT	0
804919	803917	14001X	PARTICIPANT	\N	PRESENT	0
804920	803917	20080C	PARTICIPANT	\N	PRESENT	0
804921	803917	19631V	PARTICIPANT	\N	PRESENT	0
804922	803917	14109K	PARTICIPANT	\N	PRESENT	0
804923	803917	20100N	PARTICIPANT	\N	PRESENT	0
804924	803917	14281W	PARTICIPANT	\N	PRESENT	0
804925	803917	20070A	PARTICIPANT	\N	PRESENT	0
804926	803917	19687N	PARTICIPANT	\N	PRESENT	0
804927	803917	20134Y	PARTICIPANT	\N	PRESENT	0
804928	803917	19347U	PARTICIPANT	\N	PRESENT	0
804929	803917	08056B	PARTICIPANT	\N	PRESENT	0
804930	803917	20124W	PARTICIPANT	\N	PRESENT	0
804931	803917	08012N	PARTICIPANT	\N	PRESENT	0
804932	803917	21037D	PARTICIPANT	\N	PRESENT	0
804933	803917	21073H	PARTICIPANT	\N	PRESENT	0
804934	803917	20068G	PARTICIPANT	\N	PRESENT	0
804935	803917	21072G	PARTICIPANT	\N	PRESENT	0
804936	803917	19367Y	PARTICIPANT	\N	PRESENT	0
804937	803917	99004R	PARTICIPANT	\N	PRESENT	0
804938	803917	08028W	PARTICIPANT	\N	PRESENT	0
804939	803917	19954N	PARTICIPANT	\N	PRESENT	0
804940	803917	20128B	PARTICIPANT	\N	PRESENT	0
804941	803917	14037X	PARTICIPANT	\N	PRESENT	0
804942	803917	19669L	PARTICIPANT	\N	PRESENT	0
804943	803917	98022P	PARTICIPANT	\N	PRESENT	0
804944	803917	14249W	PARTICIPANT	\N	PRESENT	0
804945	803917	20072C	PARTICIPANT	\N	PRESENT	0
804946	803917	19629C	PARTICIPANT	\N	PRESENT	0
804947	803917	21040X	PARTICIPANT	\N	PRESENT	0
804948	803917	21066J	PARTICIPANT	\N	PRESENT	0
804949	803917	14207L	PARTICIPANT	\N	PRESENT	0
804950	803917	19866P	PARTICIPANT	\N	PRESENT	0
804951	803917	20050V	PARTICIPANT	\N	PRESENT	0
804952	803917	21070E	PARTICIPANT	\N	PRESENT	0
804953	803917	14083S	PARTICIPANT	\N	PRESENT	0
804954	803917	20042V	PARTICIPANT	\N	PRESENT	0
804955	803917	14327T	PARTICIPANT	\N	PRESENT	0
804956	803917	14267Y	PARTICIPANT	\N	PRESENT	0
804957	803917	21042A	PARTICIPANT	\N	PRESENT	0
804958	803917	21053D	PARTICIPANT	\N	PRESENT	0
804959	803917	14059S	PARTICIPANT	\N	PRESENT	0
804960	803917	19701S	PARTICIPANT	\N	PRESENT	0
804961	803917	21071F	PARTICIPANT	\N	PRESENT	0
804962	803917	14133K	PARTICIPANT	\N	PRESENT	0
804963	803917	19421M	PARTICIPANT	\N	PRESENT	0
804965	803917	20026V	PARTICIPANT	\N	PRESENT	0
804967	803917	21029D	PARTICIPANT	\N	PRESENT	0
804968	803917	21082J	PARTICIPANT	\N	PRESENT	0
804969	803917	20064C	PARTICIPANT	\N	PRESENT	0
804970	803917	14257W	PARTICIPANT	\N	PRESENT	0
804971	803917	21031W	PARTICIPANT	\N	PRESENT	0
804972	803917	20142Y	PARTICIPANT	\N	PRESENT	0
804973	803917	19565D	PARTICIPANT	\N	PRESENT	0
804974	803917	20046A	PARTICIPANT	\N	PRESENT	0
804976	803917	14225N	PARTICIPANT	\N	PRESENT	0
804977	803917	14193X	PARTICIPANT	\N	PRESENT	0
804978	803917	20034V	PARTICIPANT	\N	PRESENT	0
804979	803917	19399H	PARTICIPANT	\N	PRESENT	0
804980	803917	21047F	PARTICIPANT	\N	PRESENT	0
804981	803917	19531S	PARTICIPANT	\N	PRESENT	0
804982	803917	21090J	PARTICIPANT	\N	PRESENT	0
804983	803917	20090E	PARTICIPANT	\N	PRESENT	0
804985	803917	20054A	PARTICIPANT	\N	PRESENT	0
804986	803917	21048G	PARTICIPANT	\N	PRESENT	0
804987	803917	14030Q	PARTICIPANT	\N	PRESENT	0
804988	803917	11048N	PARTICIPANT	\N	PRESENT	0
804989	803917	19798U	PARTICIPANT	\N	PRESENT	0
804990	803917	07029T	PARTICIPANT	\N	PRESENT	0
804991	803917	19575F	PARTICIPANT	\N	PRESENT	0
804992	803917	20140W	PARTICIPANT	\N	PRESENT	0
804993	803917	18083K	PARTICIPANT	\N	PRESENT	0
804994	803917	14069U	PARTICIPANT	\N	PRESENT	0
804995	803917	17023S	PARTICIPANT	\N	PRESENT	0
808290	807329	19679N	PARTICIPANT	\N	PRESENT	0
808291	807329	21049H	PARTICIPANT	\N	PRESENT	0
808292	807329	21046E	PARTICIPANT	\N	PRESENT	0
808293	807373	19679N	PARTICIPANT	\N	PRESENT	0
808294	807373	21049H	PARTICIPANT	\N	PRESENT	0
808295	807373	21046E	PARTICIPANT	\N	PRESENT	0
810569	810557	21048G	PARTICIPANT	\N	PRESENT	0
810570	810557	20086J	PARTICIPANT	\N	PRESENT	0
810571	810557	19573D	PARTICIPANT	\N	PRESENT	0
810572	810557	14327T	PARTICIPANT	\N	PRESENT	0
810573	810557	11110B	PARTICIPANT	\N	PRESENT	0
815096	815092	11040E	PARTICIPANT	\N	PRESENT	0
815093	815092	19760E	PARTICIPANT	\N	PRESENT	0
815095	815092	05008E	PARTICIPANT	\N	PRESENT	0
815097	815092	21046E	PARTICIPANT	\N	PRESENT	0
815098	815092	14053L	PARTICIPANT	\N	PRESENT	0
815099	815092	14213J	PARTICIPANT	\N	PRESENT	0
815100	815092	19447X	PARTICIPANT	\N	PRESENT	0
815101	815092	07029T	PARTICIPANT	\N	PRESENT	0
815102	815092	21087P	PARTICIPANT	\N	PRESENT	0
815103	815092	14059S	PARTICIPANT	\N	PRESENT	0
815104	815092	14147R	PARTICIPANT	\N	PRESENT	0
815105	815092	19798U	PARTICIPANT	\N	PRESENT	0
815107	815092	19703U	PARTICIPANT	\N	PRESENT	0
815108	815092	20062A	PARTICIPANT	\N	PRESENT	0
815109	815092	20026V	PARTICIPANT	\N	PRESENT	0
818862	815901	20128B	PARTICIPANT	\N	PRESENT	0
818864	815901	19575F	PARTICIPANT	\N	PRESENT	0
818867	815901	21059K	PARTICIPANT	\N	EXCUSE	0
818868	815901	19667J	PARTICIPANT	\N	EXCUSE	0
818869	815901	19533U	PARTICIPANT	\N	PRESENT	0
819439	819266	19533U	PARTICIPANT	\N	PRESENT	0
819440	819266	19619A	PARTICIPANT	\N	PRESENT	0
819441	819266	20092G	PARTICIPANT	\N	PRESENT	0
819950	818880	18207D	PARTICIPANT	\N	PRESENT	0
819951	818880	18231D	PARTICIPANT	\N	PRESENT	0
819952	818880	14069U	PARTICIPANT	\N	PRESENT	0
819954	818880	21044C	PARTICIPANT	\N	PRESENT	0
819955	818880	21056G	PARTICIPANT	\N	PRESENT	0
819956	818880	11072N	PARTICIPANT	\N	PRESENT	0
819959	818880	04045F	PARTICIPANT	\N	PRESENT	0
819960	818880	21043B	PARTICIPANT	\N	PRESENT	0
819963	818984	14147R	PARTICIPANT	\N	PRESENT	0
819964	818557	19593H	PARTICIPANT	\N	PRESENT	0
819965	818557	20132W	PARTICIPANT	\N	PRESENT	0
819966	818557	19699S	PARTICIPANT	\N	PRESENT	0
819967	818557	21055F	PARTICIPANT	\N	PRESENT	0
819968	818557	14073Q	PARTICIPANT	\N	PRESENT	0
819969	818557	19611R	PRESIDENT	0	PRESENT	0
819970	818557	20138D	PARTICIPANT	\N	PRESENT	0
819971	818557	20142Y	PARTICIPANT	\N	PRESENT	0
819972	818557	20102Q	PARTICIPANT	\N	PRESENT	0
819973	818557	20052X	PARTICIPANT	\N	PRESENT	0
819974	818557	14229S	PARTICIPANT	\N	PRESENT	0
819975	818557	14030Q	PARTICIPANT	\N	PRESENT	0
818860	815901	20072C	PARTICIPANT	\N	PRESENT	0
819976	818557	20056C	PARTICIPANT	\N	PRESENT	0
819977	818557	19954N	PARTICIPANT	\N	PRESENT	0
819978	818557	14241N	PARTICIPANT	\N	PRESENT	0
819979	818557	21063F	PARTICIPANT	\N	PRESENT	0
819980	818557	08012N	PARTICIPANT	\N	PRESENT	0
819981	818557	21074J	PARTICIPANT	\N	PRESENT	0
819982	818557	21077M	PARTICIPANT	\N	PRESENT	0
819983	818557	19621T	PARTICIPANT	\N	PRESENT	0
819984	818557	21059K	PARTICIPANT	\N	PRESENT	0
819985	818557	21089R	PARTICIPANT	\N	PRESENT	0
819986	818557	21091K	PARTICIPANT	\N	PRESENT	0
819987	818557	20026V	PARTICIPANT	\N	PRESENT	0
819988	818557	21125C	PARTICIPANT	\N	PRESENT	0
819989	818557	14123H	PARTICIPANT	\N	PRESENT	0
819990	818557	11043H	PARTICIPANT	\N	PRESENT	0
819991	818557	21058J	PARTICIPANT	\N	PRESENT	0
819992	818557	20180F	PARTICIPANT	\N	PRESENT	0
819994	818557	19533U	PARTICIPANT	\N	PRESENT	0
819995	818557	20058E	PARTICIPANT	\N	PRESENT	0
819997	819993	19383Y	PARTICIPANT	\N	PRESENT	0
819998	819993	20088L	PARTICIPANT	\N	PRESENT	0
819999	819993	19782L	PARTICIPANT	\N	PRESENT	0
820000	819993	14357A	PARTICIPANT	\N	PRESENT	0
820001	819993	14221J	PARTICIPANT	\N	PRESENT	0
820002	819993	20104S	PARTICIPANT	\N	PRESENT	0
820003	819993	19631V	PARTICIPANT	\N	PRESENT	0
820004	819993	19705W	PARTICIPANT	\N	PRESENT	0
820005	819993	08015R	PARTICIPANT	\N	PRESENT	0
820006	819993	19575F	PARTICIPANT	\N	PRESENT	0
820007	819993	20018V	PARTICIPANT	\N	PRESENT	0
820008	819993	08028W	PARTICIPANT	\N	PRESENT	0
820009	819993	19563B	PARTICIPANT	\N	PRESENT	0
820010	819993	21096Q	PARTICIPANT	\N	PRESENT	0
820011	819993	14329V	PARTICIPANT	\N	PRESENT	0
820012	819993	20028X	PARTICIPANT	\N	PRESENT	0
820013	819993	21054E	PARTICIPANT	\N	PRESENT	0
820014	819993	14187A	PRESIDENT	0	PRESENT	0
820015	819993	21075K	PARTICIPANT	\N	PRESENT	0
820016	819993	21083K	PARTICIPANT	\N	PRESENT	0
820017	819993	21086N	PARTICIPANT	\N	PRESENT	0
820018	819993	14033T	PARTICIPANT	\N	PRESENT	0
820019	819993	11090Q	PARTICIPANT	\N	PRESENT	0
820020	819993	20054A	PARTICIPANT	\N	PRESENT	0
820021	819993	14205J	PARTICIPANT	\N	PRESENT	0
820022	819993	20066E	PARTICIPANT	\N	PRESENT	0
820023	819993	21066J	PARTICIPANT	\N	PRESENT	0
820024	819993	20286Q	PARTICIPANT	\N	PRESENT	0
820025	819993	14207L	PARTICIPANT	\N	PRESENT	0
820026	819993	14257W	PARTICIPANT	\N	PRESENT	0
820027	819993	20084G	PARTICIPANT	\N	PRESENT	0
820038	818557	18395Y	PARTICIPANT	\N	PRESENT	0
820039	818557	20124W	PARTICIPANT	\N	PRESENT	0
820040	818557	20264J	PARTICIPANT	\N	EXCUSE	0
820041	818557	04033B	PARTICIPANT	\N	PRESENT	0
820042	818557	19735D	PARTICIPANT	\N	PRESENT	0
820043	819993	21050A	PARTICIPANT	\N	PRESENT	0
820044	819993	14038Y	PARTICIPANT	\N	PRESENT	0
820045	819993	20144B	PARTICIPANT	\N	PRESENT	0
820046	819993	19507S	PARTICIPANT	\N	PRESENT	0
820047	819993	20082E	PARTICIPANT	\N	EXCUSE	0
820187	816766	21072G	PARTICIPANT	\N	PRESENT	0
820232	818987	86034E	PARTICIPANT	\N	PRESENT	0
820236	818987	08018U	PARTICIPANT	\N	PRESENT	0
820241	818987	19569H	PARTICIPANT	\N	PRESENT	0
820242	818987	21069M	PARTICIPANT	\N	PRESENT	0
820245	818987	21039F	PARTICIPANT	\N	PRESENT	0
820248	818987	19331L	PARTICIPANT	\N	PRESENT	0
820249	818987	14107H	PARTICIPANT	\N	PRESENT	0
820250	818987	20102Q	PARTICIPANT	\N	PRESENT	0
820251	818987	20090E	PARTICIPANT	\N	PRESENT	0
820255	818987	11040E	PARTICIPANT	\N	PRESENT	0
820256	818987	17229F	PARTICIPANT	\N	PRESENT	0
820257	818987	21083K	PARTICIPANT	\N	PRESENT	0
820259	818987	14042U	PARTICIPANT	\N	PRESENT	0
820260	818987	19691J	PARTICIPANT	\N	PRESENT	0
820261	818987	21049H	PARTICIPANT	\N	PRESENT	0
820262	818987	19301E	PARTICIPANT	\N	PRESENT	0
820263	818987	20072C	PARTICIPANT	\N	PRESENT	0
820264	818987	14211G	PARTICIPANT	\N	PRESENT	0
820267	818987	19695N	PARTICIPANT	\N	PRESENT	0
820268	818987	21046E	PARTICIPANT	\N	PRESENT	0
820269	818987	19479G	PARTICIPANT	\N	PRESENT	0
820274	818987	21040X	PARTICIPANT	\N	PRESENT	0
800456	797968	14331P	PRESIDENT	0	PRESENT	0
800457	797968	18395Y	PARTICIPANT	\N	PRESENT	0
800458	797968	14073Q	PARTICIPANT	\N	PRESENT	0
800459	797968	20104S	PARTICIPANT	\N	PRESENT	0
800460	797968	20100N	PARTICIPANT	\N	PRESENT	0
800461	797968	04070G	PARTICIPANT	\N	PRESENT	0
800462	797968	20042V	PARTICIPANT	\N	EXCUSE	0
800463	797968	20286Q	PARTICIPANT	\N	EXCUSE	0
801156	801155	14037X	PARTICIPANT	\N	PRESENT	0
801157	801155	18083K	PARTICIPANT	\N	PRESENT	0
801158	801155	20084G	PARTICIPANT	\N	PRESENT	0
801159	801155	21036C	PARTICIPANT	\N	PRESENT	0
801160	801155	21037D	PARTICIPANT	\N	PRESENT	0
801161	801155	19631V	PARTICIPANT	\N	PRESENT	0
801162	801155	20042V	PARTICIPANT	\N	PRESENT	0
801163	801155	14030Q	PARTICIPANT	\N	PRESENT	0
801164	801155	14059S	PARTICIPANT	\N	PRESENT	0
801166	801165	18083K	PARTICIPANT	\N	PRESENT	0
801167	801165	20084G	PARTICIPANT	\N	PRESENT	0
801168	801165	19749K	PARTICIPANT	\N	PRESENT	0
801169	801165	19575F	PARTICIPANT	\N	PRESENT	0
801170	801165	20024T	PARTICIPANT	\N	PRESENT	0
801361	801360	21067K	PARTICIPANT	\N	PRESENT	0
801362	801360	20252E	PARTICIPANT	\N	PRESENT	0
801364	801363	21067K	PARTICIPANT	\N	PRESENT	0
801366	801365	20252E	PARTICIPANT	\N	PRESENT	0
801368	801367	21067K	PARTICIPANT	\N	PRESENT	0
801369	801367	20252E	PARTICIPANT	\N	PRESENT	0
801371	801370	21067K	PARTICIPANT	\N	PRESENT	0
801372	801370	20252E	PARTICIPANT	\N	PRESENT	0
802827	802826	14249W	PARTICIPANT	\N	PRESENT	0
802829	802826	20124W	PARTICIPANT	\N	PRESENT	0
802830	802826	20056C	PARTICIPANT	\N	PRESENT	0
802831	802826	19647E	PARTICIPANT	\N	PRESENT	0
802834	802833	20024T	PARTICIPANT	\N	PRESENT	0
802835	802833	19563B	PARTICIPANT	\N	PRESENT	0
802836	802833	14249W	PARTICIPANT	\N	PRESENT	0
802837	802833	21064G	PARTICIPANT	\N	PRESENT	0
803412	803410	14031R	PARTICIPANT	\N	PRESENT	0
803413	803410	20090E	PARTICIPANT	\N	PRESENT	0
803414	803410	19826F	PARTICIPANT	\N	PRESENT	0
803415	803410	14030Q	PARTICIPANT	\N	PRESENT	0
803416	803410	20180F	PARTICIPANT	\N	PRESENT	0
803417	803410	14053L	PARTICIPANT	\N	PRESENT	0
803418	803410	21044C	PARTICIPANT	\N	PRESENT	0
803419	803410	20136B	PARTICIPANT	\N	PRESENT	0
803420	803410	19820Y	PARTICIPANT	\N	PRESENT	0
803421	803410	11065P	PARTICIPANT	\N	PRESENT	0
803422	803410	20106U	PARTICIPANT	\N	PRESENT	0
803423	803410	21084L	PARTICIPANT	\N	PRESENT	0
803424	803410	20114U	PARTICIPANT	\N	PRESENT	0
803425	803410	14083S	PARTICIPANT	\N	PRESENT	0
804104	804102	14069U	PARTICIPANT	\N	PRESENT	0
804107	804106	11048N	PARTICIPANT	\N	PRESENT	0
804109	804108	11048N	PARTICIPANT	\N	PRESENT	0
804110	804108	19711U	PARTICIPANT	\N	PRESENT	0
804111	804108	21079P	PARTICIPANT	\N	PRESENT	0
804112	804108	19687N	PARTICIPANT	\N	PRESENT	0
804114	804113	21090J	PARTICIPANT	\N	PRESENT	0
804115	804113	08009T	PARTICIPANT	\N	PRESENT	0
804121	804120	04047H	PARTICIPANT	\N	PRESENT	0
804122	804120	14147R	PARTICIPANT	\N	PRESENT	0
804123	804120	21095P	PARTICIPANT	\N	PRESENT	0
804124	804120	19749K	PARTICIPANT	\N	PRESENT	0
804125	804120	18231D	PARTICIPANT	\N	PRESENT	0
804126	804120	14225N	PARTICIPANT	\N	PRESENT	0
804127	804120	11072N	PARTICIPANT	\N	PRESENT	0
804128	804120	21088Q	PARTICIPANT	\N	PRESENT	0
804129	804120	21046E	PARTICIPANT	\N	PRESENT	0
804132	804131	20022R	PARTICIPANT	\N	PRESENT	0
804133	804131	20110Q	PARTICIPANT	\N	PRESENT	0
804134	804131	20114U	PARTICIPANT	\N	PRESENT	0
804135	804131	04047H	PARTICIPANT	\N	PRESENT	0
804136	804131	14215L	PARTICIPANT	\N	PRESENT	0
804137	804131	14259Y	PARTICIPANT	\N	PRESENT	0
804138	804131	14231L	PARTICIPANT	\N	PRESENT	0
804139	804131	19649G	PARTICIPANT	\N	PRESENT	0
804140	804131	04045F	PARTICIPANT	\N	PRESENT	0
804141	804131	19489J	PARTICIPANT	\N	PRESENT	0
804297	804294	21091K	PARTICIPANT	\N	PRESENT	0
804298	804294	21089R	PARTICIPANT	\N	PRESENT	0
804299	804295	21091K	PARTICIPANT	\N	PRESENT	0
804300	804295	21089R	PARTICIPANT	\N	PRESENT	0
804302	804296	21091K	PARTICIPANT	\N	PRESENT	0
804303	804296	21089R	PARTICIPANT	\N	PRESENT	0
804975	804010	11056N	PARTICIPANT	\N	PRESENT	0
804997	803917	19383Y	PARTICIPANT	\N	PRESENT	0
804998	803917	14215L	PARTICIPANT	\N	PRESENT	0
804999	803917	21044C	PARTICIPANT	\N	PRESENT	0
805000	803917	20018V	PARTICIPANT	\N	PRESENT	0
805001	803917	21056G	PARTICIPANT	\N	PRESENT	0
805003	803917	08034U	PARTICIPANT	\N	PRESENT	0
805004	803917	11027H	PARTICIPANT	\N	PRESENT	0
805005	803917	21079P	PARTICIPANT	\N	PRESENT	0
805006	803917	14189C	PARTICIPANT	\N	PRESENT	0
805007	803917	10015M	PARTICIPANT	\N	PRESENT	0
805008	803917	08061X	PARTICIPANT	\N	PRESENT	0
805009	803917	14071N	PARTICIPANT	\N	PRESENT	0
805010	803917	20052X	PARTICIPANT	\N	PRESENT	0
805011	803917	21058J	PARTICIPANT	\N	PRESENT	0
805012	803917	14097Y	PARTICIPANT	\N	PRESENT	0
805013	803917	14357A	PARTICIPANT	\N	PRESENT	0
805016	803917	19295A	PARTICIPANT	\N	PRESENT	0
805017	803917	21057H	PARTICIPANT	\N	PRESENT	0
805018	803917	19563B	PARTICIPANT	\N	PRESENT	0
805019	803917	14255U	PARTICIPANT	\N	PRESENT	0
805024	803917	19413M	PARTICIPANT	\N	PRESENT	0
805025	803917	20032T	PARTICIPANT	\N	PRESENT	0
805026	803917	17737W	PARTICIPANT	\N	PRESENT	0
805027	803917	14147R	PARTICIPANT	\N	PRESENT	0
805028	803917	20150Y	PARTICIPANT	\N	PRESENT	0
805029	803917	19679N	PARTICIPANT	\N	PRESENT	0
805030	803917	14073Q	PARTICIPANT	\N	PRESENT	0
805031	803917	19713W	PARTICIPANT	\N	PRESENT	0
805032	803917	14329V	PARTICIPANT	\N	PRESENT	0
805033	803917	21043B	PARTICIPANT	\N	PRESENT	0
805034	803917	21078N	PARTICIPANT	\N	PRESENT	0
805035	803917	19335Q	PARTICIPANT	\N	PRESENT	0
805036	803917	21085M	PARTICIPANT	\N	PRESENT	0
805037	803917	14219Q	PARTICIPANT	\N	PRESENT	0
805038	803917	20116W	PARTICIPANT	\N	PRESENT	0
805039	803917	20022R	PARTICIPANT	\N	PRESENT	0
805040	803917	14021P	PARTICIPANT	\N	PRESENT	0
805041	803917	20110Q	PARTICIPANT	\N	PRESENT	0
805042	803917	19479G	PARTICIPANT	\N	PRESENT	0
805043	803917	20076G	PARTICIPANT	\N	PRESENT	0
805044	803917	21083K	PARTICIPANT	\N	PRESENT	0
805045	803917	19758L	PARTICIPANT	\N	PRESENT	0
805046	803917	20092G	PARTICIPANT	\N	PRESENT	0
805122	803918	14259Y	PARTICIPANT	\N	PRESENT	0
805123	803918	14231L	PARTICIPANT	\N	PRESENT	0
805124	803918	19673G	PARTICIPANT	\N	PRESENT	0
805125	803918	19489J	PARTICIPANT	\N	PRESENT	0
805126	803918	11056N	PARTICIPANT	\N	PRESENT	0
805127	803918	14207L	PARTICIPANT	\N	PRESENT	0
805128	803918	21043B	PARTICIPANT	\N	PRESENT	0
805129	803918	21056G	PARTICIPANT	\N	PRESENT	0
805130	803918	99004R	PARTICIPANT	\N	PRESENT	0
805131	803918	21085M	PARTICIPANT	\N	PRESENT	0
805132	803918	21065H	PARTICIPANT	\N	PRESENT	0
805133	803918	14189C	PARTICIPANT	\N	PRESENT	0
805134	803918	20110Q	PARTICIPANT	\N	PRESENT	0
805135	803918	20070A	PARTICIPANT	\N	PRESENT	0
805136	803918	14329V	PARTICIPANT	\N	PRESENT	0
805137	803918	19383Y	PARTICIPANT	\N	PRESENT	0
805138	803918	14021P	PARTICIPANT	\N	PRESENT	0
805139	803918	20084G	PARTICIPANT	\N	PRESENT	0
805140	803918	20082E	PARTICIPANT	\N	PRESENT	0
805141	803918	18395Y	PARTICIPANT	\N	PRESENT	0
805142	803918	19565D	PARTICIPANT	\N	PRESENT	0
805143	803918	19760E	PARTICIPANT	\N	PRESENT	0
805144	803918	19295A	PARTICIPANT	\N	PRESENT	0
805145	803918	17965H	PARTICIPANT	\N	PRESENT	0
805146	803918	21051B	PARTICIPANT	\N	PRESENT	0
805147	803918	19735D	PARTICIPANT	\N	PRESENT	0
805148	803918	20066E	PARTICIPANT	\N	PRESENT	0
805149	803918	14327T	PARTICIPANT	\N	PRESENT	0
805150	803918	11065P	PARTICIPANT	\N	PRESENT	0
805151	803918	21048G	PARTICIPANT	\N	PRESENT	0
805152	803918	20100N	PARTICIPANT	\N	PRESENT	0
805153	803918	19758L	PARTICIPANT	\N	PRESENT	0
804713	803916	14111D	PARTICIPANT	\N	PRESENT	0
804714	803916	14073Q	PARTICIPANT	\N	PRESENT	0
804715	803916	21037D	PARTICIPANT	\N	PRESENT	0
804716	803916	20142Y	PARTICIPANT	\N	PRESENT	0
804717	803916	21048G	PARTICIPANT	\N	PRESENT	0
804718	803916	14021P	PARTICIPANT	\N	PRESENT	0
804719	803916	14121F	PARTICIPANT	\N	PRESENT	0
804720	803916	21057H	PARTICIPANT	\N	PRESENT	0
804721	803916	08028W	PARTICIPANT	\N	PRESENT	0
804722	803916	20144B	PARTICIPANT	\N	PRESENT	0
804723	803916	21078N	PARTICIPANT	\N	PRESENT	0
804724	803916	21040X	PARTICIPANT	\N	PRESENT	0
804725	803916	08012N	PARTICIPANT	\N	PRESENT	0
804726	803916	14059S	PARTICIPANT	\N	PRESENT	0
804727	803916	21077M	PARTICIPANT	\N	PRESENT	0
804728	803916	19649G	PARTICIPANT	\N	PRESENT	0
804729	803916	18193Q	PARTICIPANT	\N	PRESENT	0
804730	803916	20070A	PARTICIPANT	\N	PRESENT	0
804731	803916	20080C	PARTICIPANT	\N	PRESENT	0
804732	803916	20066E	PARTICIPANT	\N	PRESENT	0
804733	803916	20034V	PARTICIPANT	\N	PRESENT	0
804734	803916	19399H	PARTICIPANT	\N	PRESENT	0
804735	803916	20026V	PARTICIPANT	\N	PRESENT	0
804736	803916	19421M	PARTICIPANT	\N	PRESENT	0
804737	803916	20140W	PARTICIPANT	\N	PRESENT	0
804738	803916	20022R	PARTICIPANT	\N	PRESENT	0
804739	803916	20024T	PARTICIPANT	\N	PRESENT	0
804740	803916	19693L	PARTICIPANT	\N	PRESENT	0
804741	803916	21066J	PARTICIPANT	\N	PRESENT	0
804742	803916	19629C	PARTICIPANT	\N	PRESENT	0
804743	803916	21090J	PARTICIPANT	\N	PRESENT	0
804744	803916	19699S	PARTICIPANT	\N	PRESENT	0
804745	803916	14083S	PARTICIPANT	\N	PRESENT	0
804746	803916	14053L	PARTICIPANT	\N	PRESENT	0
804747	803916	19479G	PARTICIPANT	\N	PRESENT	0
804748	803916	20122U	PARTICIPANT	\N	PRESENT	0
804749	803916	21052C	PARTICIPANT	\N	PRESENT	0
804750	803916	19563B	PARTICIPANT	\N	PRESENT	0
804751	803916	21070E	PARTICIPANT	\N	PRESENT	0
804752	803916	21054E	PARTICIPANT	\N	PRESENT	0
804753	803916	19611R	PARTICIPANT	\N	PRESENT	0
804754	803916	19711U	PARTICIPANT	\N	PRESENT	0
804755	803916	19349W	PARTICIPANT	\N	PRESENT	0
814575	804984	20098N	PARTICIPANT	\N	EXCUSE	0
804757	803916	19647E	PARTICIPANT	\N	PRESENT	0
804758	803916	19593H	PARTICIPANT	\N	PRESENT	0
804759	803916	20102Q	PARTICIPANT	\N	PRESENT	0
804760	803916	20082E	PARTICIPANT	\N	PRESENT	0
804761	803916	20064C	PARTICIPANT	\N	PRESENT	0
804762	803916	20248J	PARTICIPANT	\N	PRESENT	0
804763	803916	21053D	PARTICIPANT	\N	PRESENT	0
804764	803916	19798U	PARTICIPANT	\N	PRESENT	0
804765	803916	19533U	PARTICIPANT	\N	PRESENT	0
804766	803916	07033P	PARTICIPANT	\N	PRESENT	0
804767	803916	19383Y	PARTICIPANT	\N	PRESENT	0
804768	803916	19703U	PARTICIPANT	\N	PRESENT	0
804769	803916	20062A	PARTICIPANT	\N	PRESENT	0
804770	803916	99004R	PARTICIPANT	\N	PRESENT	0
804771	803916	19573D	PARTICIPANT	\N	PRESENT	0
804772	803916	20076G	PARTICIPANT	\N	PRESENT	0
804773	803916	20044X	PARTICIPANT	\N	PRESENT	0
804774	803916	14071N	PARTICIPANT	\N	PRESENT	0
804775	803916	11043H	PARTICIPANT	\N	PRESENT	0
804776	803916	21072G	PARTICIPANT	\N	PRESENT	0
804777	803916	20172F	PARTICIPANT	\N	PRESENT	0
804778	803916	20096L	PARTICIPANT	\N	PRESENT	0
804779	803916	21083K	PARTICIPANT	\N	PRESENT	0
804780	803916	98022P	PARTICIPANT	\N	PRESENT	0
804781	803916	21033Y	PARTICIPANT	\N	PRESENT	0
804782	803916	14038Y	PARTICIPANT	\N	PRESENT	0
804783	803916	14211G	PARTICIPANT	\N	PRESENT	0
804784	803916	14213J	PARTICIPANT	\N	PRESENT	0
804785	803916	14217N	PARTICIPANT	\N	PRESENT	0
804786	803916	14033T	PARTICIPANT	\N	PRESENT	0
804791	803916	14173T	PARTICIPANT	\N	PRESENT	0
804796	803916	20032T	PARTICIPANT	\N	PRESENT	0
804800	803916	14031R	PARTICIPANT	\N	PRESENT	0
804803	803916	14030Q	PARTICIPANT	\N	PRESENT	0
804807	803916	21056G	PARTICIPANT	\N	PRESENT	0
804809	803916	19367Y	PARTICIPANT	\N	PRESENT	0
804811	803916	14147R	PARTICIPANT	\N	PRESENT	0
804813	803916	19866P	PARTICIPANT	\N	PRESENT	0
804814	803916	21073H	PARTICIPANT	\N	PRESENT	0
804816	803916	21084L	PARTICIPANT	\N	PRESENT	0
814573	814365	21092L	PARTICIPANT	\N	PRESENT	0
814574	804984	21071F	PARTICIPANT	\N	EXCUSE	0
814576	804984	14147R	PARTICIPANT	\N	EXCUSE	0
814577	804984	21044C	PARTICIPANT	\N	EXCUSE	0
814578	804984	20056C	PARTICIPANT	\N	EXCUSE	0
814579	804984	14030Q	PARTICIPANT	\N	EXCUSE	0
814580	804984	21042A	PARTICIPANT	\N	EXCUSE	0
814802	814801	19479G	PARTICIPANT	\N	PRESENT	0
815904	815903	20094J	PARTICIPANT	\N	PRESENT	0
815905	815903	20264J	PARTICIPANT	\N	PRESENT	0
815906	815903	20084G	PARTICIPANT	\N	PRESENT	0
815907	815903	21029D	PARTICIPANT	\N	PRESENT	0
815908	815903	21055F	PARTICIPANT	\N	PRESENT	0
815909	815903	18207D	PARTICIPANT	\N	PRESENT	0
818754	818753	14031R	PARTICIPANT	\N	PRESENT	0
818755	818753	19820Y	PARTICIPANT	\N	PRESENT	0
818756	818753	20180F	PARTICIPANT	\N	PRESENT	0
818757	818753	21062E	PARTICIPANT	\N	PRESENT	0
818759	818753	08015R	PARTICIPANT	\N	PRESENT	0
818760	818753	21044C	PARTICIPANT	\N	PRESENT	0
818761	818753	20116W	PARTICIPANT	\N	PRESENT	0
818762	818753	21051B	PARTICIPANT	\N	PRESENT	0
818766	818765	14038Y	PARTICIPANT	\N	PRESENT	0
818767	818765	11065P	PARTICIPANT	\N	PRESENT	0
818768	818765	19251M	PARTICIPANT	\N	PRESENT	0
818769	818765	14187A	PARTICIPANT	\N	PRESENT	0
818770	818765	21062E	PARTICIPANT	\N	PRESENT	0
818771	818765	20106U	PARTICIPANT	\N	PRESENT	0
818772	818765	14219Q	PARTICIPANT	\N	PRESENT	0
818773	818765	14031R	PARTICIPANT	\N	PRESENT	0
818774	818765	19826F	PARTICIPANT	\N	PRESENT	0
818775	818765	19619A	PARTICIPANT	\N	PRESENT	0
818776	818765	20136B	PARTICIPANT	\N	PRESENT	0
818778	818777	14038Y	PARTICIPANT	\N	PRESENT	0
818779	818777	11065P	PARTICIPANT	\N	PRESENT	0
818780	818777	19251M	PARTICIPANT	\N	PRESENT	0
818781	818777	14187A	PARTICIPANT	\N	PRESENT	0
818782	818777	21062E	PARTICIPANT	\N	PRESENT	0
818783	818777	20106U	PARTICIPANT	\N	PRESENT	0
818784	818777	14031R	PARTICIPANT	\N	PRESENT	0
818785	818777	19619A	PARTICIPANT	\N	PRESENT	0
818786	818777	20136B	PARTICIPANT	\N	PRESENT	0
818804	818803	99004R	PRESIDENT	2	PRESENT	0
818805	818803	08034U	PRESIDENT	3	PRESENT	0
818806	818803	20150Y	PRESIDENT	4	PRESENT	0
818807	818803	14121F	PRESIDENT	1	PRESENT	0
818808	818803	20080C	PRESIDENT	0	PRESENT	0
818809	818803	21079P	PRESIDENT	5	PRESENT	0
818810	818803	21041Y	PARTICIPANT	\N	EXCUSE	0
818812	818803	19545Y	PARTICIPANT	\N	EXCUSE	0
818817	818803	21086N	PARTICIPANT	\N	EXCUSE	0
818826	818825	14038Y	PARTICIPANT	\N	PRESENT	0
818827	818825	11065P	PARTICIPANT	\N	PRESENT	0
818828	818825	19251M	PARTICIPANT	\N	PRESENT	0
818829	818825	14187A	PARTICIPANT	\N	PRESENT	0
818830	818825	21062E	PARTICIPANT	\N	PRESENT	0
818831	818825	20106U	PARTICIPANT	\N	PRESENT	0
818832	818825	14219Q	PRESIDENT	0	PRESENT	0
818833	818825	14031R	PARTICIPANT	\N	PRESENT	0
818834	818825	19826F	PARTICIPANT	\N	PRESENT	0
818835	818825	19619A	PARTICIPANT	\N	PRESENT	0
818836	818825	20136B	PARTICIPANT	\N	PRESENT	0
819057	819056	07033P	PARTICIPANT	\N	PRESENT	0
819069	819068	21067K	PARTICIPANT	\N	PRESENT	0
819070	819068	20252E	PARTICIPANT	\N	PRESENT	0
819072	819071	21067K	PARTICIPANT	\N	PRESENT	0
819073	819071	20252E	PARTICIPANT	\N	PRESENT	0
819075	819074	20252E	PARTICIPANT	\N	PRESENT	0
819077	819076	21067K	PARTICIPANT	\N	PRESENT	0
820595	813081	21038E	PARTICIPANT	\N	EXCUSE	0
820593	813081	14189C	PARTICIPANT	\N	EXCUSE	0
820594	813081	21089R	PARTICIPANT	\N	EXCUSE	0
820596	813081	19798U	PARTICIPANT	\N	EXCUSE	0
820597	813081	19749K	PARTICIPANT	\N	EXCUSE	0
820598	813081	20098N	PARTICIPANT	\N	EXCUSE	0
820599	813082	14189C	PARTICIPANT	\N	EXCUSE	0
820600	813082	21089R	PARTICIPANT	\N	EXCUSE	0
797676	794862	21084L	PARTICIPANT	\N	PRESENT	0
797677	794862	21082J	PARTICIPANT	\N	PRESENT	0
797678	794862	20248J	PARTICIPANT	\N	PRESENT	0
797679	794862	21031W	PARTICIPANT	\N	PRESENT	0
797680	794862	08034U	PARTICIPANT	\N	PRESENT	0
797681	794862	20038A	PARTICIPANT	\N	PRESENT	0
797682	794862	21066J	PARTICIPANT	\N	PRESENT	0
797683	794862	19413M	PARTICIPANT	\N	PRESENT	0
797684	794862	99004R	PRESIDENT	0	PRESENT	0
797685	794862	21093M	PARTICIPANT	\N	PRESENT	0
797686	794862	21090J	PARTICIPANT	\N	PRESENT	0
797687	794862	19782L	PARTICIPANT	\N	EXCUSE	0
797971	797714	14231L	PARTICIPANT	\N	EXCUSE	0
797972	797714	19719D	PARTICIPANT	\N	EXCUSE	0
797975	797700	17367Q	PARTICIPANT	\N	PRESENT	0
797976	797700	14151M	PRESIDENT	0	PRESENT	0
797977	797700	20110Q	PARTICIPANT	\N	PRESENT	0
797978	797700	18395Y	PARTICIPANT	\N	PRESENT	0
797979	797700	20090E	PARTICIPANT	\N	PRESENT	0
797980	797700	19826F	PARTICIPANT	\N	PRESENT	0
797981	797700	20078J	PARTICIPANT	\N	PRESENT	0
797982	797700	20252E	PARTICIPANT	\N	PRESENT	0
797983	797700	19349W	PARTICIPANT	\N	PRESENT	0
797985	797715	04047H	PRESIDENT	0	PRESENT	0
797986	797715	14053L	PARTICIPANT	\N	PRESENT	0
797987	797715	21076L	PARTICIPANT	\N	PRESENT	0
797988	797715	14111D	PARTICIPANT	\N	PRESENT	0
797989	797715	20074E	PARTICIPANT	\N	PRESENT	0
797990	797715	19673G	PARTICIPANT	\N	PRESENT	0
797991	797715	14151M	PARTICIPANT	\N	PRESENT	0
797992	797715	14215L	PARTICIPANT	\N	PRESENT	0
797993	797715	19749K	PARTICIPANT	\N	PRESENT	0
797994	797715	05008E	PARTICIPANT	\N	PRESENT	0
797995	797715	20098N	PARTICIPANT	\N	PRESENT	0
797996	797715	20022R	PARTICIPANT	\N	PRESENT	0
797997	797715	14147R	PARTICIPANT	\N	PRESENT	0
797998	797715	19111A	PARTICIPANT	\N	PRESENT	0
797999	797715	20036X	PARTICIPANT	\N	PRESENT	0
798000	797715	20266L	PARTICIPANT	\N	PRESENT	0
798001	797715	19719D	PARTICIPANT	\N	EXCUSE	0
798002	797715	14231L	PARTICIPANT	\N	EXCUSE	0
798003	797715	20108W	PARTICIPANT	\N	PRESENT	0
798004	797715	19649G	PARTICIPANT	\N	PRESENT	0
798005	797715	19489J	PARTICIPANT	\N	PRESENT	0
798006	797715	21057H	PARTICIPANT	\N	PRESENT	0
798007	797715	18231D	PARTICIPANT	\N	PRESENT	0
798008	797715	20110Q	PARTICIPANT	\N	PRESENT	0
801961	800752	21057H	PARTICIPANT	\N	PRESENT	0
801962	800752	10015M	PARTICIPANT	\N	PRESENT	0
801963	800752	20022R	PARTICIPANT	\N	PRESENT	0
801964	800752	20108W	PARTICIPANT	\N	PRESENT	0
801965	800752	05008E	PARTICIPANT	\N	PRESENT	0
801966	800752	21038E	PARTICIPANT	\N	PRESENT	0
801968	800752	19251M	PARTICIPANT	\N	PRESENT	0
805280	803927	19367Y	PARTICIPANT	\N	PRESENT	0
801971	800752	20026V	PARTICIPANT	\N	PRESENT	0
801973	800752	19691J	PARTICIPANT	\N	PRESENT	0
801974	800752	21040X	PARTICIPANT	\N	EXCUSE	0
801975	800752	19729F	PARTICIPANT	\N	EXCUSE	0
801976	800752	19585H	PARTICIPANT	\N	EXCUSE	0
801978	800752	11072N	PARTICIPANT	\N	PRESENT	0
801980	800752	14215L	PARTICIPANT	\N	PRESENT	0
801981	800752	19713W	PARTICIPANT	\N	PRESENT	0
804996	803917	04033B	PARTICIPANT	\N	PRESENT	0
805278	803927	19691J	PARTICIPANT	\N	PRESENT	0
805281	803927	19758L	PARTICIPANT	\N	PRESENT	0
805282	803927	21046E	PARTICIPANT	\N	PRESENT	0
805283	803927	14195A	PARTICIPANT	\N	PRESENT	0
805284	803927	20140W	PARTICIPANT	\N	PRESENT	0
805285	803927	20248J	PARTICIPANT	\N	PRESENT	0
805286	803927	14281W	PARTICIPANT	\N	PRESENT	0
805287	803927	08045X	PARTICIPANT	\N	PRESENT	0
805288	803927	14026U	PARTICIPANT	\N	PRESENT	0
805312	803927	19723Y	PARTICIPANT	\N	PRESENT	0
805290	803927	19553Y	PARTICIPANT	\N	PRESENT	0
805291	803927	14213J	PARTICIPANT	\N	PRESENT	0
805292	803927	17779H	PARTICIPANT	\N	PRESENT	0
805293	803927	14223L	PARTICIPANT	\N	PRESENT	0
805294	803927	04092N	PARTICIPANT	\N	PRESENT	0
805295	803927	14071N	PRESIDENT	0	PRESENT	0
805296	803927	21097R	PARTICIPANT	\N	PRESENT	0
805297	803927	21039F	PARTICIPANT	\N	PRESENT	0
805298	803927	19866P	PARTICIPANT	\N	PRESENT	0
805299	803927	20148F	PARTICIPANT	\N	PRESENT	0
805300	803927	19798U	PARTICIPANT	\N	PRESENT	0
805301	803927	19703U	PARTICIPANT	\N	PRESENT	0
805302	803927	19713W	PARTICIPANT	\N	PRESENT	0
805303	803927	19301E	PARTICIPANT	\N	PRESENT	0
805304	803927	21045D	PARTICIPANT	\N	PRESENT	0
805305	803927	19629C	PARTICIPANT	\N	PRESENT	0
805306	803927	14042U	PARTICIPANT	\N	PRESENT	0
805307	803927	18193Q	PARTICIPANT	\N	PRESENT	0
805308	803927	21087P	PARTICIPANT	\N	PRESENT	0
805309	803927	19657G	PARTICIPANT	\N	PRESENT	0
805310	803927	19760E	PARTICIPANT	\N	PRESENT	0
805311	803927	19679N	PARTICIPANT	\N	PRESENT	0
805313	803927	14217N	PARTICIPANT	\N	PRESENT	0
805314	803927	19683J	PARTICIPANT	\N	PRESENT	0
805316	803927	20090E	PARTICIPANT	\N	PRESENT	0
805317	803927	21094N	PARTICIPANT	\N	PRESENT	0
805357	803927	19295A	PARTICIPANT	\N	PRESENT	0
805358	803927	21081H	PARTICIPANT	\N	PRESENT	0
805359	803927	08061X	PARTICIPANT	\N	PRESENT	0
805364	803927	21071F	PARTICIPANT	\N	PRESENT	0
805372	803927	21049H	PARTICIPANT	\N	PRESENT	0
805373	803927	20096L	PARTICIPANT	\N	PRESENT	0
805383	803927	11045K	PARTICIPANT	\N	PRESENT	0
806467	804052	21095P	PARTICIPANT	\N	PRESENT	0
806845	806787	18083K	PARTICIPANT	\N	PRESENT	0
806846	806787	21034A	PARTICIPANT	\N	EXCUSE	0
806847	806787	21035B	PARTICIPANT	\N	EXCUSE	0
806848	806787	19631V	PARTICIPANT	\N	EXCUSE	0
806849	806787	05008E	PARTICIPANT	\N	EXCUSE	0
806850	806787	14259Y	PARTICIPANT	\N	EXCUSE	0
806851	806787	17229F	PARTICIPANT	\N	EXCUSE	0
806852	806787	21032X	PARTICIPANT	\N	EXCUSE	0
806853	806787	19691J	PARTICIPANT	\N	PRESENT	0
806854	806787	20034V	PRESIDENT	0	PRESENT	0
806855	806787	08010L	PARTICIPANT	\N	EXCUSE	0
806856	806787	14059S	PARTICIPANT	\N	PRESENT	0
806857	806787	17023S	PARTICIPANT	\N	EXCUSE	0
806858	806787	21029D	PARTICIPANT	\N	PRESENT	0
806859	806787	21033Y	PARTICIPANT	\N	PRESENT	0
806860	806787	19657G	PARTICIPANT	\N	PRESENT	0
806862	806787	11072N	PARTICIPANT	\N	PRESENT	0
806863	806787	19745F	PARTICIPANT	\N	PRESENT	0
806864	806787	20150Y	PARTICIPANT	\N	PRESENT	0
806866	806787	19673G	PARTICIPANT	\N	EXCUSE	0
812401	812398	11070L	PARTICIPANT	\N	PRESENT	0
812402	812398	14033T	PARTICIPANT	\N	PRESENT	0
812404	812398	20042V	PARTICIPANT	\N	PRESENT	0
812405	812398	14257W	PRESIDENT	0	PRESENT	0
812427	812398	19619A	PARTICIPANT	\N	PRESENT	0
812435	812398	19575F	PARTICIPANT	\N	PRESENT	0
812465	812398	19711U	PARTICIPANT	\N	PRESENT	0
812466	812398	20092G	PARTICIPANT	\N	PRESENT	0
812471	812398	20120S	PARTICIPANT	\N	PRESENT	0
812486	812484	14255U	PARTICIPANT	\N	PRESENT	0
812487	812484	08009T	PARTICIPANT	\N	PRESENT	0
814675	813342	19545Y	PARTICIPANT	\N	PRESENT	0
814676	813342	20062A	PARTICIPANT	\N	PRESENT	0
814679	810556	21082J	PARTICIPANT	\N	PRESENT	0
814680	810556	21029D	PARTICIPANT	\N	PRESENT	0
814681	810556	19701S	PARTICIPANT	\N	PRESENT	0
814682	810556	20076G	PARTICIPANT	\N	PRESENT	0
814683	810556	21042A	PARTICIPANT	\N	PRESENT	0
814684	810556	14219Q	PRESIDENT	0	PRESENT	0
814685	810556	19820Y	PARTICIPANT	\N	PRESENT	0
814686	810556	19826F	PARTICIPANT	\N	PRESENT	0
814687	810556	21062E	PARTICIPANT	\N	PRESENT	0
814688	810556	21065H	PARTICIPANT	\N	PRESENT	0
814689	810556	20100N	PARTICIPANT	\N	PRESENT	0
814690	810556	21084L	PARTICIPANT	\N	PRESENT	0
814691	810556	14237S	PARTICIPANT	\N	PRESENT	0
814692	810556	05012A	PARTICIPANT	\N	PRESENT	0
814693	810556	08060W	PARTICIPANT	\N	PRESENT	0
814694	810556	20106U	PARTICIPANT	\N	PRESENT	0
814695	810556	15197G	PARTICIPANT	\N	PRESENT	0
814696	810556	20118Y	PARTICIPANT	\N	PRESENT	0
814697	810556	14107H	PARTICIPANT	\N	PRESENT	0
814698	810556	21080G	PARTICIPANT	\N	PRESENT	0
814699	810556	20020P	PARTICIPANT	\N	PRESENT	0
814700	810556	19681G	PARTICIPANT	\N	PRESENT	0
814701	810556	21051B	PARTICIPANT	\N	PRESENT	0
814702	810556	20120S	PARTICIPANT	\N	PRESENT	0
814703	810556	20032T	PARTICIPANT	\N	PRESENT	0
814704	810556	21053D	PARTICIPANT	\N	PRESENT	0
814705	810556	20136B	PARTICIPANT	\N	PRESENT	0
814706	810556	20146D	PARTICIPANT	\N	PRESENT	0
814707	810556	17229F	PARTICIPANT	\N	PRESENT	0
814708	810556	20068G	PARTICIPANT	\N	PRESENT	0
814709	810556	21068L	PARTICIPANT	\N	PRESENT	0
814710	810556	21070E	PARTICIPANT	\N	PRESENT	0
814711	810556	14031R	PARTICIPANT	\N	EXCUSE	0
814712	810556	21035B	PARTICIPANT	\N	EXCUSE	0
814713	810556	19387D	PARTICIPANT	\N	EXCUSE	0
814714	810556	20040T	PARTICIPANT	\N	EXCUSE	0
814715	810556	11065P	PARTICIPANT	\N	EXCUSE	0
814772	814716	20056C	PARTICIPANT	\N	PRESENT	0
814773	814716	95041E	PARTICIPANT	\N	PRESENT	0
814774	814716	20122U	PARTICIPANT	\N	PRESENT	0
814775	814716	19611R	PARTICIPANT	\N	PRESENT	0
814776	814716	19735D	PARTICIPANT	\N	PRESENT	0
814777	814716	20142Y	PARTICIPANT	\N	PRESENT	0
814778	814716	14109K	PRESIDENT	1	PRESENT	0
814779	814716	11074Q	PARTICIPANT	\N	PRESENT	0
814780	814716	21039F	PRESIDENT	0	PRESENT	0
814781	814716	21077M	PARTICIPANT	\N	PRESENT	0
814782	814716	20026V	PARTICIPANT	\N	PRESENT	0
814783	814716	20124W	PARTICIPANT	\N	EXCUSE	0
814784	814716	14037X	PARTICIPANT	\N	PRESENT	0
814785	814716	21068L	PARTICIPANT	\N	PRESENT	0
814807	813341	21083K	PARTICIPANT	\N	PRESENT	0
814808	813341	14237S	PARTICIPANT	\N	PRESENT	0
814809	813341	20068G	PARTICIPANT	\N	PRESENT	0
814810	813341	21061D	PARTICIPANT	\N	PRESENT	0
814811	813341	19399H	PARTICIPANT	\N	PRESENT	0
814812	813341	19507S	PARTICIPANT	\N	PRESENT	0
814813	813341	21037D	PARTICIPANT	\N	PRESENT	0
814814	813341	19679N	PARTICIPANT	\N	PRESENT	0
814815	813341	08056B	PARTICIPANT	\N	PRESENT	0
814816	813341	14225N	PARTICIPANT	\N	PRESENT	0
814817	813341	19735D	PARTICIPANT	\N	PRESENT	0
814818	813341	19629C	PARTICIPANT	\N	PRESENT	0
814819	813341	21077M	PARTICIPANT	\N	PRESENT	0
814820	813341	21057H	PARTICIPANT	\N	PRESENT	0
814821	813341	19683J	PARTICIPANT	\N	PRESENT	0
814822	813341	14121F	PARTICIPANT	\N	PRESENT	0
814823	813341	21078N	PARTICIPANT	\N	PRESENT	0
814824	813341	11040E	PARTICIPANT	\N	PRESENT	0
814825	813341	20102Q	PARTICIPANT	\N	PRESENT	0
814826	813341	19565D	PARTICIPANT	\N	PRESENT	0
814827	813341	14107H	PARTICIPANT	\N	PRESENT	0
814828	813341	14211G	PARTICIPANT	\N	PRESENT	0
814829	813341	21046E	PARTICIPANT	\N	PRESENT	0
814830	813341	21059K	PARTICIPANT	\N	PRESENT	0
814831	813341	21079P	PARTICIPANT	\N	PRESENT	0
814832	813341	19820Y	PARTICIPANT	\N	PRESENT	0
814833	813341	19545Y	PARTICIPANT	\N	PRESENT	0
814834	813341	14249W	PARTICIPANT	\N	PRESENT	0
814835	813341	19649G	PARTICIPANT	\N	PRESENT	0
814836	813341	20070A	PARTICIPANT	\N	PRESENT	0
814837	813341	11056N	PARTICIPANT	\N	PRESENT	0
814838	813341	21048G	PARTICIPANT	\N	PRESENT	0
814839	813341	21089R	PARTICIPANT	\N	PRESENT	0
814840	813341	14257W	PARTICIPANT	\N	PRESENT	0
814841	813341	20082E	PARTICIPANT	\N	PRESENT	0
814842	813341	19760E	PARTICIPANT	\N	PRESENT	0
814843	813341	19758L	PARTICIPANT	\N	PRESENT	0
814844	813341	19695N	PARTICIPANT	\N	PRESENT	0
814845	813341	14030Q	PARTICIPANT	\N	PRESENT	0
814846	813341	19699S	PARTICIPANT	\N	PRESENT	0
814847	813341	08009T	PARTICIPANT	\N	PRESENT	0
814848	813341	21044C	PARTICIPANT	\N	PRESENT	0
814849	813341	01058X	PARTICIPANT	\N	PRESENT	0
814850	813341	19711U	PARTICIPANT	\N	PRESENT	0
814851	813341	19703U	PARTICIPANT	\N	PRESENT	0
814852	813341	99004R	PARTICIPANT	\N	PRESENT	0
814853	813341	11048N	PARTICIPANT	\N	PRESENT	0
814854	813341	04092N	PARTICIPANT	\N	PRESENT	0
814855	813341	14021P	PARTICIPANT	\N	PRESENT	0
814856	813341	11045K	PARTICIPANT	\N	PRESENT	0
814857	813341	21056G	PARTICIPANT	\N	PRESENT	0
814858	813341	14229S	PARTICIPANT	\N	PRESENT	0
814859	813341	21051B	PARTICIPANT	\N	PRESENT	0
814860	813341	08010L	PARTICIPANT	\N	PRESENT	0
814861	813341	12028B	PARTICIPANT	\N	PRESENT	0
814862	813341	19573D	PARTICIPANT	\N	PRESENT	0
814863	813341	21045D	PARTICIPANT	\N	PRESENT	0
814864	813341	04033B	PARTICIPANT	\N	PRESENT	0
814865	813341	08045X	PARTICIPANT	\N	PRESENT	0
814866	813341	19725B	PARTICIPANT	\N	PRESENT	0
814867	813341	18395Y	PARTICIPANT	\N	PRESENT	0
814868	813341	14147R	PARTICIPANT	\N	PRESENT	0
814869	813341	14215L	PARTICIPANT	\N	PRESENT	0
814870	813341	19631V	PARTICIPANT	\N	PRESENT	0
814871	813341	20076G	PARTICIPANT	\N	PRESENT	0
814872	813341	20110Q	PARTICIPANT	\N	PRESENT	0
814873	813341	21071F	PARTICIPANT	\N	PRESENT	0
814874	813341	20100N	PARTICIPANT	\N	PRESENT	0
814875	813341	21093M	PARTICIPANT	\N	PRESENT	0
814877	813341	08018U	PARTICIPANT	\N	PRESENT	0
814878	813341	20142Y	PARTICIPANT	\N	PRESENT	0
814879	813341	20134Y	PARTICIPANT	\N	PRESENT	0
814880	813341	20062A	PARTICIPANT	\N	PRESENT	0
814881	813341	11090Q	PARTICIPANT	\N	PRESENT	0
814883	813341	21043B	PARTICIPANT	\N	PRESENT	0
814884	813341	19782L	PARTICIPANT	\N	PRESENT	0
814885	813341	21096Q	PARTICIPANT	\N	PRESENT	0
814886	813341	19057M	PARTICIPANT	\N	PRESENT	0
814887	813341	19621T	PARTICIPANT	\N	PRESENT	0
814888	813341	19367Y	PARTICIPANT	\N	PRESENT	0
814889	813341	14151M	PARTICIPANT	\N	PRESENT	0
814890	813341	08011M	PARTICIPANT	\N	PRESENT	0
814891	813341	21091K	PARTICIPANT	\N	PRESENT	0
814892	813341	19575F	PARTICIPANT	\N	PRESENT	0
814893	813341	21073H	PARTICIPANT	\N	PRESENT	0
814894	813341	19331L	PARTICIPANT	\N	PRESENT	0
814895	813341	19301E	PARTICIPANT	\N	PRESENT	0
814896	813341	21125C	PARTICIPANT	\N	PRESENT	0
814897	813341	19591F	PARTICIPANT	\N	PRESENT	0
814898	813341	21097R	PARTICIPANT	\N	PRESENT	0
814899	813341	20074E	PARTICIPANT	\N	PRESENT	0
814900	813341	08061X	PARTICIPANT	\N	PRESENT	0
814901	813341	20078J	PARTICIPANT	\N	PRESENT	0
814902	813341	08069G	PARTICIPANT	\N	PRESENT	0
814903	813341	04042C	PARTICIPANT	\N	PRESENT	0
814904	813341	21092L	PARTICIPANT	\N	PRESENT	0
814905	813341	20106U	PARTICIPANT	\N	PRESENT	0
814906	813341	21080G	PARTICIPANT	\N	PRESENT	0
814907	813341	10015M	PARTICIPANT	\N	PRESENT	0
814908	813341	11043H	PARTICIPANT	\N	PRESENT	0
814909	813341	20146D	PARTICIPANT	\N	PRESENT	0
814910	813341	08028W	PARTICIPANT	\N	PRESENT	0
814911	813341	19593H	PARTICIPANT	\N	PRESENT	0
814912	813341	14191V	PARTICIPANT	\N	PRESENT	0
814913	813341	14109K	PARTICIPANT	\N	PRESENT	0
814914	813341	21072G	PARTICIPANT	\N	PRESENT	0
799458	799457	20024T	PARTICIPANT	\N	PRESENT	0
799459	799457	19575F	PARTICIPANT	\N	PRESENT	0
799460	799457	18083K	PARTICIPANT	\N	PRESENT	0
799461	799457	20084G	PARTICIPANT	\N	PRESENT	0
799462	799457	19749K	PARTICIPANT	\N	PRESENT	0
799680	797973	11065P	PARTICIPANT	\N	EXCUSE	0
799681	797974	11065P	PARTICIPANT	\N	EXCUSE	0
801078	801077	14083S	PARTICIPANT	\N	PRESENT	0
801079	801077	21082J	PARTICIPANT	\N	PRESENT	0
801080	801077	20044X	PARTICIPANT	\N	PRESENT	0
801081	801077	17965H	PARTICIPANT	\N	PRESENT	0
801082	801077	21053D	PARTICIPANT	\N	PRESENT	0
801083	801077	20080C	PARTICIPANT	\N	PRESENT	0
801084	801077	12016W	PARTICIPANT	\N	PRESENT	0
801094	801093	20080C	PARTICIPANT	\N	PRESENT	0
801096	801095	14329V	PARTICIPANT	\N	PRESENT	0
801098	801097	05008E	PARTICIPANT	\N	PRESENT	0
801812	801807	20286Q	PARTICIPANT	\N	PRESENT	1
801814	801807	21082J	PARTICIPANT	\N	PRESENT	1
801839	801836	20048C	PARTICIPANT	\N	PRESENT	0
801840	801836	21044C	PARTICIPANT	\N	PRESENT	0
801841	801836	19768N	PARTICIPANT	\N	PRESENT	0
801842	801836	14237S	PARTICIPANT	\N	PRESENT	0
801843	801836	19349W	PARTICIPANT	\N	PRESENT	0
801844	801836	14107H	PARTICIPANT	\N	PRESENT	0
801845	801836	20058E	PARTICIPANT	\N	PRESENT	0
801846	801836	14189C	PARTICIPANT	\N	PRESENT	0
801848	801836	19631V	PARTICIPANT	\N	PRESENT	0
801849	801836	19575F	PARTICIPANT	\N	PRESENT	0
801850	801836	19629C	PARTICIPANT	\N	PRESENT	0
805156	803918	20102Q	PARTICIPANT	\N	PRESENT	0
805157	803918	21075K	PARTICIPANT	\N	PRESENT	0
805158	803918	21084L	PARTICIPANT	\N	PRESENT	0
805159	803918	21045D	PARTICIPANT	\N	PRESENT	0
805160	803918	20094J	PARTICIPANT	\N	PRESENT	0
805161	803918	21079P	PARTICIPANT	\N	PRESENT	0
805162	803918	20142Y	PARTICIPANT	\N	PRESENT	0
805163	803918	21096Q	PARTICIPANT	\N	PRESENT	0
805164	803918	21087P	PARTICIPANT	\N	PRESENT	0
805165	803918	20128B	PARTICIPANT	\N	PRESENT	0
805166	803918	20114U	PARTICIPANT	\N	PRESENT	0
805167	803918	14219Q	PARTICIPANT	\N	PRESENT	0
805168	803918	04070G	PARTICIPANT	\N	PRESENT	0
805169	803918	14147R	PARTICIPANT	\N	PRESENT	0
805170	803918	19703U	PARTICIPANT	\N	PRESENT	0
805171	803918	14026U	PARTICIPANT	\N	PRESENT	0
805172	803918	20090E	PARTICIPANT	\N	PRESENT	0
805173	803918	20032T	PARTICIPANT	\N	PRESENT	0
805174	803918	19679N	PARTICIPANT	\N	PRESENT	0
805175	803918	14053L	PARTICIPANT	\N	PRESENT	0
805176	803918	20098N	PARTICIPANT	\N	PRESENT	0
805177	803918	20040T	PARTICIPANT	\N	PRESENT	0
805178	803918	21083K	PARTICIPANT	\N	PRESENT	0
805179	803918	21042A	PARTICIPANT	\N	PRESENT	0
805180	803918	21053D	PARTICIPANT	\N	PRESENT	0
805181	803918	21086N	PARTICIPANT	\N	PRESENT	0
805182	803918	21050A	PARTICIPANT	\N	PRESENT	0
805183	803918	20062A	PARTICIPANT	\N	PRESENT	0
805184	803918	19621T	PARTICIPANT	\N	PRESENT	0
805185	803918	21071F	PARTICIPANT	\N	PRESENT	0
805186	803918	19573D	PARTICIPANT	\N	PRESENT	0
805187	803918	20044X	PARTICIPANT	\N	PRESENT	0
805188	803918	20022R	PARTICIPANT	\N	PRESENT	0
805189	803918	19954N	PARTICIPANT	\N	PRESENT	0
805190	803918	20026V	PARTICIPANT	\N	PRESENT	0
805191	803918	07029T	PARTICIPANT	\N	PRESENT	0
805192	803918	14033T	PARTICIPANT	\N	PRESENT	0
805193	803918	95041E	PARTICIPANT	\N	PRESENT	0
805194	803918	20140W	PARTICIPANT	\N	PRESENT	0
805195	803918	21029D	PARTICIPANT	\N	PRESENT	0
805196	803918	21068L	PARTICIPANT	\N	PRESENT	0
805197	803918	19447X	PARTICIPANT	\N	PRESENT	0
805198	803918	18083K	PARTICIPANT	\N	PRESENT	0
805154	803918	20046A	PARTICIPANT	\N	PRESENT	0
805155	803918	21049H	PARTICIPANT	\N	PRESENT	0
805199	803918	14215L	PARTICIPANT	\N	PRESENT	0
805200	803918	21044C	PARTICIPANT	\N	PRESENT	0
805201	803918	14151M	PARTICIPANT	\N	PRESENT	0
805202	803918	18207D	PARTICIPANT	\N	PRESENT	0
805203	803918	11027H	PARTICIPANT	\N	PRESENT	0
805204	803918	18231D	PARTICIPANT	\N	PRESENT	0
805205	803918	19551W	PARTICIPANT	\N	PRESENT	0
805206	803918	19545Y	PARTICIPANT	\N	PRESENT	0
805207	803918	04047H	PARTICIPANT	\N	PRESENT	0
805208	803918	21057H	PARTICIPANT	\N	PRESENT	0
805209	803918	20080C	PARTICIPANT	\N	PRESENT	0
805210	803918	20052X	PARTICIPANT	\N	PRESENT	0
805211	803918	14205J	PARTICIPANT	\N	PRESENT	0
805212	803918	14073Q	PARTICIPANT	\N	PRESENT	0
805213	803918	19629C	PARTICIPANT	\N	PRESENT	0
805214	803918	14249W	PARTICIPANT	\N	PRESENT	0
805215	803918	21046E	PARTICIPANT	\N	PRESENT	0
805216	803918	21082J	PARTICIPANT	\N	PRESENT	0
805217	803918	19647E	PARTICIPANT	\N	PRESENT	0
805218	803918	20054A	PARTICIPANT	\N	PRESENT	0
805219	803918	14357A	PARTICIPANT	\N	PRESENT	0
805220	803918	19507S	PARTICIPANT	\N	PRESENT	0
805221	803918	21038E	PARTICIPANT	\N	PRESENT	0
805222	803918	14042U	PARTICIPANT	\N	PRESENT	0
805223	803918	19563B	PARTICIPANT	\N	PRESENT	0
805224	803918	14187A	PARTICIPANT	\N	PRESENT	0
805225	803918	21031W	PARTICIPANT	\N	PRESENT	0
805226	803918	19782L	PARTICIPANT	\N	PRESENT	0
805227	803918	14083S	PARTICIPANT	\N	PRESENT	0
805228	803918	19335Q	PARTICIPANT	\N	PRESENT	0
805229	803918	18193Q	PARTICIPANT	\N	PRESENT	0
805230	803918	19768N	PARTICIPANT	\N	PRESENT	0
805231	803918	19347U	PARTICIPANT	\N	PRESENT	0
805232	803918	04033B	PARTICIPANT	\N	PRESENT	0
805233	803918	14069U	PARTICIPANT	\N	PRESENT	0
805234	803918	11048N	PARTICIPANT	\N	PRESENT	0
805235	803918	14133K	PARTICIPANT	\N	PRESENT	0
805236	803918	21032X	PARTICIPANT	\N	PRESENT	0
805237	803918	21070E	PARTICIPANT	\N	PRESENT	0
805238	803918	20172F	PARTICIPANT	\N	PRESENT	0
805239	803918	20092G	PARTICIPANT	\N	PRESENT	0
805240	803918	21066J	PARTICIPANT	\N	PRESENT	0
805241	803918	21041Y	PARTICIPANT	\N	PRESENT	0
805242	803918	20058E	PARTICIPANT	\N	PRESENT	0
805243	803918	20120S	PARTICIPANT	\N	PRESENT	0
805244	803918	20134Y	PARTICIPANT	\N	PRESENT	0
805777	804018	21056G	PARTICIPANT	\N	EXCUSE	0
805778	804018	19729F	PARTICIPANT	\N	EXCUSE	0
805779	804018	19585H	PARTICIPANT	\N	EXCUSE	0
818876	815901	20092G	PARTICIPANT	\N	PRESENT	0
819024	819023	19768N	PARTICIPANT	\N	PRESENT	0
819079	819078	17367Q	PARTICIPANT	\N	PRESENT	0
819080	819078	14151M	PARTICIPANT	\N	PRESENT	0
819081	819078	20110Q	PARTICIPANT	\N	PRESENT	0
819082	819078	17737W	PARTICIPANT	\N	PRESENT	0
819083	819078	20146D	PARTICIPANT	\N	PRESENT	0
821512	819461	14001X	PARTICIPANT	\N	PRESENT	0
821513	819461	14331P	PARTICIPANT	\N	PRESENT	0
821514	819461	20100N	PARTICIPANT	\N	PRESENT	0
821516	819461	20248J	PARTICIPANT	\N	PRESENT	0
821522	819030	20100N	PARTICIPANT	\N	PRESENT	0
821523	819030	14001X	PARTICIPANT	\N	PRESENT	0
821524	819030	19683J	PARTICIPANT	\N	PRESENT	0
821525	819030	14331P	PRESIDENT	0	PRESENT	0
821526	819030	20248J	PARTICIPANT	\N	PRESENT	0
821527	819030	14357A	PARTICIPANT	\N	PRESENT	0
821528	819030	08073C	PARTICIPANT	\N	PRESENT	0
821529	819030	14033T	PARTICIPANT	\N	PRESENT	0
821531	819030	21082J	PARTICIPANT	\N	PRESENT	0
821533	819030	20042V	PARTICIPANT	\N	PRESENT	0
821534	819030	19701S	PARTICIPANT	\N	PRESENT	0
821536	819030	14073Q	PARTICIPANT	\N	EXCUSE	0
809954	807188	14151M	PRESIDENT	0	PRESENT	0
809956	807188	17367Q	PARTICIPANT	\N	PRESENT	0
809958	807188	20146D	PARTICIPANT	\N	PRESENT	0
809970	807188	18395Y	PARTICIPANT	\N	PRESENT	0
809983	807188	19295A	PARTICIPANT	\N	PRESENT	0
811545	810211	19673G	PARTICIPANT	\N	PRESENT	0
811554	810576	21082J	PARTICIPANT	\N	PRESENT	0
811555	810576	20076G	PARTICIPANT	\N	PRESENT	0
811556	810576	21042A	PARTICIPANT	\N	PRESENT	0
811557	810576	14219Q	PRESIDENT	0	PRESENT	0
811558	810576	19820Y	PARTICIPANT	\N	PRESENT	0
811559	810576	19826F	PARTICIPANT	\N	PRESENT	0
811560	810576	21061D	PARTICIPANT	\N	PRESENT	0
811561	810576	21062E	PARTICIPANT	\N	PRESENT	0
811562	810576	21065H	PARTICIPANT	\N	PRESENT	0
811563	810576	18083K	PARTICIPANT	\N	PRESENT	0
811564	810576	21084L	PARTICIPANT	\N	PRESENT	0
811565	810576	20100N	PARTICIPANT	\N	PRESENT	0
811566	810576	14237S	PARTICIPANT	\N	PRESENT	0
811567	810576	05012A	PARTICIPANT	\N	PRESENT	0
811568	810576	08060W	PARTICIPANT	\N	PRESENT	0
811569	810576	20118Y	PARTICIPANT	\N	PRESENT	0
811570	810576	15197G	PARTICIPANT	\N	PRESENT	0
811571	810576	14107H	PARTICIPANT	\N	PRESENT	0
811572	810576	21080G	PARTICIPANT	\N	PRESENT	0
811573	810576	20020P	PARTICIPANT	\N	PRESENT	0
811574	810576	11065P	PARTICIPANT	\N	PRESENT	0
811575	810576	21051B	PARTICIPANT	\N	PRESENT	0
811576	810576	20120S	PARTICIPANT	\N	PRESENT	0
811577	810576	20032T	PARTICIPANT	\N	PRESENT	0
811578	810576	21053D	PARTICIPANT	\N	PRESENT	0
811579	810576	20136B	PARTICIPANT	\N	PRESENT	0
811580	810576	14031R	PRESIDENT	1	PRESENT	0
811581	810576	20040T	PARTICIPANT	\N	PRESENT	0
811582	810576	19251M	PARTICIPANT	\N	PRESENT	0
811583	810576	20046A	PARTICIPANT	\N	PRESENT	0
811584	810576	17229F	PARTICIPANT	\N	PRESENT	0
811585	810576	14169X	PARTICIPANT	\N	PRESENT	0
811586	810576	21047F	PARTICIPANT	\N	PRESENT	0
811587	810576	20068G	PARTICIPANT	\N	PRESENT	0
811588	810576	21068L	PARTICIPANT	\N	PRESENT	0
811589	810576	21070E	PARTICIPANT	\N	PRESENT	0
811590	810576	19619A	PARTICIPANT	\N	PRESENT	0
811591	810576	21029D	PARTICIPANT	\N	EXCUSE	0
811592	810576	19701S	PARTICIPANT	\N	EXCUSE	0
811593	810576	21035B	PARTICIPANT	\N	EXCUSE	0
811594	810576	19387D	PARTICIPANT	\N	EXCUSE	0
816121	816120	12028B	PARTICIPANT	\N	PRESENT	0
811596	810576	19681G	PARTICIPANT	\N	EXCUSE	0
811597	811317	20060X	PARTICIPANT	\N	PRESENT	0
811600	810904	21036C	PARTICIPANT	\N	PRESENT	0
811601	810904	95041E	PARTICIPANT	\N	PRESENT	0
811602	810904	21030V	PARTICIPANT	\N	PRESENT	0
811603	810904	21031W	PARTICIPANT	\N	PRESENT	0
811604	810904	19565D	PARTICIPANT	\N	PRESENT	0
811605	810904	20072C	PARTICIPANT	\N	PRESENT	0
811606	810904	01058X	PARTICIPANT	\N	PRESENT	0
811607	810904	11027H	PARTICIPANT	\N	PRESENT	0
811608	810904	14001X	PARTICIPANT	\N	PRESENT	0
811609	810904	04042C	PARTICIPANT	\N	PRESENT	0
811610	810904	19669L	PARTICIPANT	\N	PRESENT	0
811611	810904	12028B	PARTICIPANT	\N	PRESENT	0
811612	810904	17737W	PARTICIPANT	\N	PRESENT	0
811613	810904	11115U	PARTICIPANT	\N	PRESENT	0
811614	810904	14055N	PARTICIPANT	\N	PRESENT	0
811615	810904	19421M	PARTICIPANT	\N	PRESENT	0
811616	810904	19709B	PARTICIPANT	\N	PRESENT	0
811617	810904	21067K	PARTICIPANT	\N	PRESENT	0
811618	810904	14193X	PRESIDENT	0	PRESENT	0
811619	810904	07033P	PARTICIPANT	\N	PRESENT	0
811620	810904	14249W	PARTICIPANT	\N	PRESENT	0
811621	810904	08047A	PARTICIPANT	\N	PRESENT	0
811622	810904	14037X	PARTICIPANT	\N	PRESENT	0
811623	810904	14059S	PARTICIPANT	\N	PRESENT	0
811624	810904	14097Y	PARTICIPANT	\N	PRESENT	0
811625	810904	14133K	PARTICIPANT	\N	PRESENT	0
811626	810904	19531S	PARTICIPANT	\N	PRESENT	0
811627	810904	21073H	PARTICIPANT	\N	PRESENT	0
811628	810904	20042V	PARTICIPANT	\N	PRESENT	0
811629	810904	14191V	PARTICIPANT	\N	PRESENT	0
811630	810904	19721W	PARTICIPANT	\N	PRESENT	0
811631	810904	20064C	PARTICIPANT	\N	PRESENT	0
811632	810904	20252E	PARTICIPANT	\N	PRESENT	0
811633	810904	14251Q	PARTICIPANT	\N	PRESENT	0
811634	810904	98022P	PARTICIPANT	\N	PRESENT	0
811635	810904	14267Y	PARTICIPANT	\N	PRESENT	0
811636	810904	99004R	PARTICIPANT	\N	PRESENT	0
811637	810904	19745F	PARTICIPANT	\N	PRESENT	0
811638	810904	14211G	PARTICIPANT	\N	PRESENT	0
811639	810904	14255U	PARTICIPANT	\N	PRESENT	0
811640	810904	17023S	PARTICIPANT	\N	PRESENT	0
815115	804984	18193Q	PARTICIPANT	\N	PRESENT	0
816122	816120	14267Y	PARTICIPANT	\N	PRESENT	0
816123	816120	08010L	PARTICIPANT	\N	PRESENT	0
817039	816882	20080C	PARTICIPANT	\N	EXCUSE	0
820601	813082	21038E	PARTICIPANT	\N	EXCUSE	0
821931	821930	14205J	PARTICIPANT	\N	PRESENT	0
821932	821930	14033T	PARTICIPANT	\N	PRESENT	0
821933	821930	08028W	PARTICIPANT	\N	PRESENT	0
821934	821930	20092G	PARTICIPANT	\N	PRESENT	0
821943	821942	14205J	PARTICIPANT	\N	PRESENT	0
821944	821942	14033T	PARTICIPANT	\N	PRESENT	0
821945	821942	08028W	PARTICIPANT	\N	PRESENT	0
821946	821942	20092G	PARTICIPANT	\N	PRESENT	0
797260	794703	18083K	PARTICIPANT	\N	PRESENT	0
797261	794703	17229F	PARTICIPANT	\N	PRESENT	0
797262	794703	20034V	PRESIDENT	0	PRESENT	0
797263	794703	14059S	PARTICIPANT	\N	PRESENT	0
797264	794703	12016W	PARTICIPANT	\N	PRESENT	1
797265	794703	11072N	PARTICIPANT	\N	PRESENT	0
797266	794703	19691J	PARTICIPANT	\N	PRESENT	0
797267	794703	19331L	PARTICIPANT	\N	PRESENT	0
797268	794703	21029D	PARTICIPANT	\N	PRESENT	0
797269	794703	19745F	PARTICIPANT	\N	PRESENT	0
797271	794703	21073H	PARTICIPANT	\N	PRESENT	0
797313	794703	05008E	PARTICIPANT	\N	PRESENT	0
800018	800004	19701S	PARTICIPANT	\N	PRESENT	0
800020	800004	20124W	PARTICIPANT	\N	PRESENT	0
800022	800004	20100N	PARTICIPANT	\N	PRESENT	0
800024	800004	14033T	PARTICIPANT	\N	PRESENT	0
800026	800004	14213J	PARTICIPANT	\N	PRESENT	0
800027	800004	21051B	PARTICIPANT	\N	PRESENT	0
800029	800004	20032T	PARTICIPANT	\N	PRESENT	0
801100	801099	19649G	PARTICIPANT	\N	PRESENT	0
801101	801099	14053L	PARTICIPANT	\N	PRESENT	0
801103	801102	19649G	PARTICIPANT	\N	PRESENT	0
801104	801102	14053L	PARTICIPANT	\N	PRESENT	0
801106	801105	14053L	PARTICIPANT	\N	PRESENT	0
801108	801107	19673G	PARTICIPANT	\N	PRESENT	0
801109	801107	19749K	PARTICIPANT	\N	PRESENT	0
801111	801110	19673G	PARTICIPANT	\N	PRESENT	0
801112	801110	19749K	PARTICIPANT	\N	PRESENT	0
801114	801113	19673G	PARTICIPANT	\N	PRESENT	0
801115	801113	19749K	PARTICIPANT	\N	PRESENT	0
801457	801145	14151M	PRESIDENT	0	PRESENT	0
801458	801145	17367Q	PARTICIPANT	\N	PRESENT	0
801459	801145	20090E	PARTICIPANT	\N	PRESENT	0
801460	801145	19826F	PARTICIPANT	\N	PRESENT	0
801461	801145	21040X	PARTICIPANT	\N	EXCUSE	0
801462	801145	18395Y	PARTICIPANT	\N	PRESENT	0
801463	801145	20078J	PARTICIPANT	\N	PRESENT	0
801466	801465	14231L	PARTICIPANT	\N	PRESENT	0
801939	800752	19749K	PARTICIPANT	\N	PRESENT	0
801940	800752	14213J	PARTICIPANT	\N	PRESENT	0
801941	800752	19611R	PARTICIPANT	\N	PRESENT	0
801942	800752	14151M	PARTICIPANT	\N	PRESENT	0
801944	800752	14053L	PARTICIPANT	\N	PRESENT	0
801945	800752	21043B	PARTICIPANT	\N	PRESENT	0
801946	800752	07004J	PARTICIPANT	\N	PRESENT	0
801947	800752	21089R	PARTICIPANT	\N	PRESENT	0
801948	800752	19111A	PARTICIPANT	\N	PRESENT	0
801949	800752	04047H	PRESIDENT	0	PRESENT	0
801950	800752	14219Q	PARTICIPANT	\N	PRESENT	0
801951	800752	19954N	PARTICIPANT	\N	PRESENT	0
801952	800752	19673G	PARTICIPANT	\N	PRESENT	0
801953	800752	14069U	PARTICIPANT	\N	PRESENT	0
801955	800752	14147R	PARTICIPANT	\N	PRESENT	0
801956	800752	14026U	PARTICIPANT	\N	PRESENT	0
801957	800752	14231L	PARTICIPANT	\N	PRESENT	0
803997	803996	14215L	PARTICIPANT	\N	PRESENT	0
804232	804231	19111A	PARTICIPANT	\N	PRESENT	0
804234	804233	19111A	PARTICIPANT	\N	PRESENT	0
804236	804235	19111A	PARTICIPANT	\N	PRESENT	0
805811	803919	21080G	PARTICIPANT	\N	PRESENT	0
805812	803919	14223L	PARTICIPANT	\N	PRESENT	0
805813	803919	08010L	PARTICIPANT	\N	PRESENT	0
805814	803919	20108W	PARTICIPANT	\N	PRESENT	0
805815	803919	14059S	PARTICIPANT	\N	PRESENT	0
805816	803919	21058J	PARTICIPANT	\N	PRESENT	0
805817	803919	20252E	PARTICIPANT	\N	PRESENT	0
805818	803919	04092N	PARTICIPANT	\N	PRESENT	0
805819	803919	14071N	PARTICIPANT	\N	PRESENT	0
805820	803919	21039F	PARTICIPANT	\N	PRESENT	0
805821	803919	14253S	PARTICIPANT	\N	PRESENT	0
805822	803919	19573D	PARTICIPANT	\N	PRESENT	0
805823	803919	14191V	PARTICIPANT	\N	PRESENT	0
805824	803919	21055F	PARTICIPANT	\N	PRESENT	0
805825	803919	14237S	PARTICIPANT	\N	PRESENT	0
805826	803919	21047F	PARTICIPANT	\N	PRESENT	0
805827	803919	14193X	PARTICIPANT	\N	PRESENT	0
805828	803919	20148F	PARTICIPANT	\N	PRESENT	0
805829	803919	19533U	PARTICIPANT	\N	PRESENT	0
805830	803919	11090Q	PARTICIPANT	\N	PRESENT	0
805831	803919	19679N	PARTICIPANT	\N	PRESENT	0
805832	803919	14331P	PARTICIPANT	\N	PRESENT	0
805833	803919	10015M	PARTICIPANT	\N	PRESENT	0
805834	803919	19421M	PARTICIPANT	\N	PRESENT	0
805835	803919	20044X	PARTICIPANT	\N	PRESENT	0
805836	803919	11043H	PARTICIPANT	\N	PRESENT	0
805837	803919	20098N	PARTICIPANT	\N	PRESENT	0
805838	803919	20020P	PARTICIPANT	\N	PRESENT	0
805839	803919	19760E	PARTICIPANT	\N	PRESENT	0
805840	803919	20112S	PARTICIPANT	\N	PRESENT	0
805841	803919	21088Q	PARTICIPANT	\N	PRESENT	0
805842	803919	19758L	PARTICIPANT	\N	PRESENT	0
805843	803919	11056N	PARTICIPANT	\N	PRESENT	0
805844	803919	19695N	PARTICIPANT	\N	PRESENT	0
805845	803919	19565D	PARTICIPANT	\N	PRESENT	0
805846	803919	20102Q	PARTICIPANT	\N	PRESENT	0
805847	803919	21075K	PARTICIPANT	\N	PRESENT	0
805848	803919	19593H	PARTICIPANT	\N	PRESENT	0
805849	803919	19687N	PARTICIPANT	\N	PRESENT	0
805850	803919	21049H	PARTICIPANT	\N	PRESENT	0
805851	803919	20046A	PARTICIPANT	\N	PRESENT	0
805852	803919	20110Q	PARTICIPANT	\N	PRESENT	0
805853	803919	21048G	PARTICIPANT	\N	PRESENT	0
805854	803919	11065P	PARTICIPANT	\N	PRESENT	0
805858	803919	21092L	PARTICIPANT	\N	PRESENT	0
805856	803919	20100N	PARTICIPANT	\N	PRESENT	0
805857	803919	19347U	PARTICIPANT	\N	PRESENT	0
805859	803919	21093M	PARTICIPANT	\N	PRESENT	0
805860	803919	20142Y	PARTICIPANT	\N	PRESENT	0
805861	803919	21073H	PARTICIPANT	\N	PRESENT	0
805862	803919	21037D	PARTICIPANT	\N	PRESENT	0
805863	803919	20092G	PARTICIPANT	\N	PRESENT	0
805864	803919	21079P	PARTICIPANT	\N	PRESENT	0
805865	803919	21094N	PARTICIPANT	\N	PRESENT	0
805866	803919	20266L	PARTICIPANT	\N	PRESENT	0
805867	803919	20036X	PARTICIPANT	\N	PRESENT	0
805868	803919	21074J	PARTICIPANT	\N	PRESENT	0
805869	803919	21069M	PARTICIPANT	\N	PRESENT	0
805870	803919	21043B	PARTICIPANT	\N	PRESENT	0
805974	803919	19691J	PARTICIPANT	\N	PRESENT	0
805975	803919	14179A	PARTICIPANT	\N	PRESENT	0
805976	803919	20048C	PARTICIPANT	\N	PRESENT	0
805977	803919	20066E	PARTICIPANT	\N	PRESENT	0
805978	803919	19735D	PARTICIPANT	\N	PRESENT	0
805979	803919	19611R	PARTICIPANT	\N	PRESENT	0
805980	803919	19699S	PARTICIPANT	\N	PRESENT	0
805981	803919	14205J	PARTICIPANT	\N	PRESENT	0
805982	803919	14219Q	PARTICIPANT	\N	PRESENT	0
805983	803919	11085T	PARTICIPANT	\N	PRESENT	0
805984	803919	19826F	PARTICIPANT	\N	PRESENT	0
805985	803919	08009T	PARTICIPANT	\N	PRESENT	0
805986	803919	19563B	PARTICIPANT	\N	PRESENT	0
805987	803919	19335Q	PARTICIPANT	\N	PRESENT	0
805988	803919	04070G	PARTICIPANT	\N	PRESENT	0
805989	803919	19745F	PARTICIPANT	\N	PRESENT	0
805990	803919	21038E	PARTICIPANT	\N	PRESENT	0
805991	803919	21064G	PARTICIPANT	\N	PRESENT	0
805992	803919	19619A	PARTICIPANT	\N	PRESENT	0
805993	803919	19713W	PARTICIPANT	\N	PRESENT	0
805994	803919	01034P	PARTICIPANT	\N	PRESENT	0
810333	810332	11090Q	PARTICIPANT	\N	PRESENT	0
810334	810332	19695N	PARTICIPANT	\N	PRESENT	0
810336	810335	11090Q	PARTICIPANT	\N	PRESENT	1
810379	810378	11115U	PARTICIPANT	\N	PRESENT	0
810380	810378	14059S	PARTICIPANT	\N	PRESENT	0
810381	810378	21081H	PARTICIPANT	\N	PRESENT	0
810382	810378	20082E	PARTICIPANT	\N	PRESENT	0
810383	810378	19569H	PARTICIPANT	\N	PRESENT	0
810384	810378	19760E	PARTICIPANT	\N	PRESENT	0
810385	810378	20118Y	PARTICIPANT	\N	PRESENT	0
810386	810378	19723Y	PARTICIPANT	\N	PRESENT	0
810388	810387	19709B	PARTICIPANT	\N	PRESENT	0
810389	810387	20022R	PARTICIPANT	\N	PRESENT	0
810390	810387	19954N	PARTICIPANT	\N	PRESENT	0
810391	810387	17737W	PARTICIPANT	\N	PRESENT	0
810392	810387	14255U	PARTICIPANT	\N	PRESENT	0
810393	810387	19647E	PARTICIPANT	\N	PRESENT	0
810395	810387	20038A	PARTICIPANT	\N	PRESENT	0
810396	810387	19565D	PARTICIPANT	\N	PRESENT	0
810397	810387	19399H	PARTICIPANT	\N	PRESENT	0
810399	810387	18207D	PARTICIPANT	\N	PRESENT	0
810400	810387	21037D	PARTICIPANT	\N	PRESENT	0
807360	807359	14179A	PARTICIPANT	\N	PRESENT	0
807361	807359	19701S	PARTICIPANT	\N	PRESENT	0
814915	813341	21084L	PARTICIPANT	\N	PRESENT	0
814916	813341	20044X	PARTICIPANT	\N	PRESENT	0
814917	813341	05012A	PARTICIPANT	\N	PRESENT	0
814918	813341	19687N	PARTICIPANT	\N	PRESENT	0
814919	813341	17367Q	PARTICIPANT	\N	PRESENT	0
814920	813341	21055F	PARTICIPANT	\N	PRESENT	0
814921	813341	21075K	PARTICIPANT	\N	PRESENT	0
814922	813341	21029D	PARTICIPANT	\N	PRESENT	0
814923	813341	19667J	PARTICIPANT	\N	PRESENT	0
814924	813341	19421M	PARTICIPANT	\N	PRESENT	0
814925	813341	14253S	PARTICIPANT	\N	PRESENT	0
814926	813341	21088Q	PARTICIPANT	\N	PRESENT	0
814927	813341	20032T	PARTICIPANT	\N	PRESENT	0
814928	813341	19447X	PARTICIPANT	\N	PRESENT	0
814929	813341	21068L	PARTICIPANT	\N	PRESENT	0
814930	813341	21058J	PARTICIPANT	\N	PRESENT	0
814931	813341	20180F	PARTICIPANT	\N	PRESENT	0
814932	813341	21067K	PARTICIPANT	\N	PRESENT	0
814933	813341	14133K	PARTICIPANT	\N	PRESENT	0
814934	813341	14026U	PARTICIPANT	\N	PRESENT	0
814935	813341	21069M	PARTICIPANT	\N	PRESENT	0
814936	813341	20026V	PARTICIPANT	\N	PRESENT	0
814937	813341	21085M	PARTICIPANT	\N	PRESENT	0
814938	813341	21081H	PARTICIPANT	\N	PRESENT	0
814939	813341	21074J	PARTICIPANT	\N	PRESENT	0
814940	813341	20138D	PARTICIPANT	\N	PRESENT	0
814941	813341	20092G	PARTICIPANT	\N	PRESENT	0
814942	813341	21094N	PARTICIPANT	\N	PRESENT	0
814943	813341	14038Y	PARTICIPANT	\N	PRESENT	0
814944	813341	19723Y	PARTICIPANT	\N	PRESENT	0
814945	813341	21039F	PARTICIPANT	\N	PRESENT	0
814946	813341	20140W	PARTICIPANT	\N	PRESENT	0
814947	813341	20038A	PARTICIPANT	\N	PRESENT	0
814948	813341	14033T	PARTICIPANT	\N	PRESENT	0
814949	813341	20056C	PARTICIPANT	\N	PRESENT	0
814950	813341	20094J	PARTICIPANT	\N	PRESENT	0
814951	813341	20104S	PARTICIPANT	\N	PRESENT	0
814953	813341	20024T	PARTICIPANT	\N	PRESENT	0
814954	813341	08060W	PARTICIPANT	\N	PRESENT	0
814956	813341	14213J	PARTICIPANT	\N	PRESENT	0
814957	813341	20108W	PARTICIPANT	\N	PRESENT	0
814958	813341	21063F	PARTICIPANT	\N	PRESENT	0
814959	813341	20080C	PARTICIPANT	\N	PRESENT	0
814960	813341	20060X	PARTICIPANT	\N	PRESENT	0
814961	813341	07029T	PARTICIPANT	\N	PRESENT	0
814962	813341	19251M	PARTICIPANT	\N	PRESENT	0
814963	813341	11074Q	PARTICIPANT	\N	PRESENT	0
814964	813341	19768N	PARTICIPANT	\N	PRESENT	0
814965	813341	21062E	PARTICIPANT	\N	PRESENT	0
814966	813341	08015R	PARTICIPANT	\N	PRESENT	0
814967	813341	14059S	PARTICIPANT	\N	PRESENT	0
814968	813341	21036C	PARTICIPANT	\N	PRESENT	0
814970	813341	20124W	PARTICIPANT	\N	PRESENT	0
814971	813341	20054A	PARTICIPANT	\N	PRESENT	0
814972	813341	14281W	PARTICIPANT	\N	PRESENT	0
814973	813341	19383Y	PARTICIPANT	\N	PRESENT	0
814974	813341	20018V	PARTICIPANT	\N	PRESENT	0
814975	813341	20172F	PARTICIPANT	\N	PRESENT	0
814976	813341	21082J	PARTICIPANT	\N	PRESENT	0
814977	813341	14357A	PARTICIPANT	\N	PRESENT	0
814979	813341	20086J	PARTICIPANT	\N	PRESENT	0
814980	813341	20098N	PARTICIPANT	\N	PRESENT	0
814981	813341	20020P	PARTICIPANT	\N	PRESENT	0
814982	813341	95041E	PARTICIPANT	\N	PRESENT	0
814983	813341	19413M	PARTICIPANT	\N	PRESENT	0
814984	813341	21095P	PARTICIPANT	\N	PRESENT	0
814985	813341	20084G	PARTICIPANT	\N	PRESENT	0
814986	813341	21090J	PARTICIPANT	\N	PRESENT	0
814987	813341	14217N	PARTICIPANT	\N	PRESENT	0
814988	813341	20090E	PARTICIPANT	\N	PRESENT	0
814989	813341	20118Y	PARTICIPANT	\N	PRESENT	0
814990	813341	19533U	PARTICIPANT	\N	PRESENT	0
814991	813341	19954N	PARTICIPANT	\N	PRESENT	0
814992	813341	14069U	PARTICIPANT	\N	PRESENT	0
814993	813341	19798U	PARTICIPANT	\N	PRESENT	0
814995	813341	14071N	PARTICIPANT	\N	PRESENT	0
814996	813341	18193Q	PARTICIPANT	\N	PRESENT	0
814997	813341	14187A	PARTICIPANT	\N	PRESENT	0
814998	813341	19701S	PARTICIPANT	\N	PRESENT	0
814999	813341	14097Y	PARTICIPANT	\N	PRESENT	0
815000	813341	14053L	PARTICIPANT	\N	PRESENT	0
815001	813341	05008E	PARTICIPANT	\N	PRESENT	0
815002	813341	20266L	PARTICIPANT	\N	PRESENT	0
815003	813341	08034U	PARTICIPANT	\N	PRESENT	0
815004	813341	14195A	PARTICIPANT	\N	PRESENT	0
815005	813341	04047H	PARTICIPANT	\N	PRESENT	0
815006	813341	21070E	PARTICIPANT	\N	PRESENT	0
815007	813341	14111D	PARTICIPANT	\N	PRESENT	0
815008	813341	14251Q	PARTICIPANT	\N	PRESENT	0
815009	813341	18207D	PARTICIPANT	\N	PRESENT	0
815010	813341	17779H	PARTICIPANT	\N	PRESENT	0
815011	813341	19705W	PARTICIPANT	\N	PRESENT	0
815012	813341	20114U	PARTICIPANT	\N	PRESENT	0
815013	813341	01034P	PARTICIPANT	\N	PRESENT	0
815014	813341	14221J	PARTICIPANT	\N	PRESENT	0
815015	813341	20050V	PARTICIPANT	\N	PRESENT	0
815016	813341	14219Q	PARTICIPANT	\N	PRESENT	0
815017	813341	21076L	PARTICIPANT	\N	PRESENT	0
815018	813341	14267Y	PARTICIPANT	\N	PRESENT	0
815019	813341	11085T	PARTICIPANT	\N	PRESENT	0
815020	813341	14073Q	PARTICIPANT	\N	PRESENT	0
815021	813341	19693L	PARTICIPANT	\N	PRESENT	0
815022	813341	20042V	PARTICIPANT	\N	PRESENT	0
815023	813341	21065H	PARTICIPANT	\N	PRESENT	0
815024	813341	19569H	PARTICIPANT	\N	PRESENT	0
815025	813341	21087P	PARTICIPANT	\N	PRESENT	0
815026	813341	20122U	PARTICIPANT	\N	PRESENT	0
815027	813341	21054E	PARTICIPANT	\N	PRESENT	0
815028	813341	21042A	PARTICIPANT	\N	PRESENT	0
815035	813341	14255U	PARTICIPANT	\N	PRESENT	0
815030	813341	21050A	PARTICIPANT	\N	PRESENT	0
815036	813341	20144B	PARTICIPANT	\N	PRESENT	0
815032	813341	14083S	PARTICIPANT	\N	PRESENT	0
815033	813341	11053K	PARTICIPANT	\N	PRESENT	0
815034	813341	14089Y	PARTICIPANT	\N	PRESENT	0
815037	813341	17229F	PARTICIPANT	\N	PRESENT	0
815038	813341	14042U	PARTICIPANT	\N	PRESENT	0
815039	813341	20248J	PARTICIPANT	\N	PRESENT	0
815040	813341	20022R	PARTICIPANT	\N	PRESENT	0
815041	813341	19826F	PARTICIPANT	\N	PRESENT	0
815042	813341	19111A	PARTICIPANT	\N	PRESENT	0
815043	813341	20126Y	PARTICIPANT	\N	PRESENT	0
815044	813341	11115U	PARTICIPANT	\N	PRESENT	0
815045	813341	20286Q	PARTICIPANT	\N	PRESENT	0
815046	813341	14231L	PARTICIPANT	\N	PRESENT	0
815047	813341	19691J	PARTICIPANT	\N	PRESENT	0
815048	813341	20066E	PARTICIPANT	\N	PRESENT	0
815080	813341	20052X	PARTICIPANT	\N	PRESENT	0
815050	813341	19611R	PARTICIPANT	\N	PRESENT	0
815051	813341	20036X	PARTICIPANT	\N	PRESENT	0
815052	813341	19713W	PARTICIPANT	\N	PRESENT	0
815053	813341	19745F	PARTICIPANT	\N	PRESENT	0
815055	813341	21053D	PARTICIPANT	\N	PRESENT	0
815056	813341	21038E	PARTICIPANT	\N	PRESENT	0
815057	813341	21064G	PARTICIPANT	\N	PRESENT	0
815058	813341	19479G	PARTICIPANT	\N	PRESENT	0
815059	813341	19749K	PARTICIPANT	\N	PRESENT	0
815060	813341	20136B	PARTICIPANT	\N	PRESENT	0
815061	813341	20120S	PARTICIPANT	\N	PRESENT	0
815062	813341	14207L	PARTICIPANT	\N	PRESENT	0
815063	813341	19719D	PARTICIPANT	\N	PRESENT	0
815064	813341	21041Y	PARTICIPANT	\N	PRESENT	0
815065	813341	19553Y	PARTICIPANT	\N	PRESENT	0
815066	813341	19866P	PARTICIPANT	\N	PRESENT	0
815067	813341	21040X	PARTICIPANT	\N	PRESENT	0
815068	813341	20072C	PARTICIPANT	\N	PRESENT	0
815069	813341	21066J	PARTICIPANT	\N	PRESENT	0
815070	813341	20116W	PARTICIPANT	\N	PRESENT	0
815071	813341	14241N	PARTICIPANT	\N	PRESENT	0
815072	813341	20132W	PARTICIPANT	\N	PRESENT	0
815073	813341	20264J	PARTICIPANT	\N	PRESENT	0
815074	813341	07004J	PARTICIPANT	\N	PRESENT	0
815075	813341	19697Q	PARTICIPANT	\N	PRESENT	0
815076	813341	19349W	PARTICIPANT	\N	PRESENT	0
815077	813341	17023S	PARTICIPANT	\N	PRESENT	0
815081	813341	21086N	PARTICIPANT	\N	PRESENT	0
815079	813341	19563B	PARTICIPANT	\N	PRESENT	0
815082	813341	19335Q	PARTICIPANT	\N	PRESENT	0
797863	797861	19667J	PARTICIPANT	\N	PRESENT	0
797864	797862	19667J	PARTICIPANT	\N	PRESENT	0
797866	797865	20082E	PARTICIPANT	\N	PRESENT	0
797867	797865	20028X	PARTICIPANT	\N	PRESENT	0
797868	797865	20092G	PARTICIPANT	\N	PRESENT	0
797869	797865	20018V	PARTICIPANT	\N	PRESENT	0
797870	797865	20114U	PARTICIPANT	\N	PRESENT	0
797871	797865	21041Y	PARTICIPANT	\N	PRESENT	0
797872	797865	08015R	PARTICIPANT	\N	PRESENT	0
797873	797865	14059S	PARTICIPANT	\N	PRESENT	0
797874	797865	14109K	PARTICIPANT	\N	PRESENT	0
797875	797865	11056N	PARTICIPANT	\N	PRESENT	0
797876	797865	20138D	PARTICIPANT	\N	PRESENT	0
797877	797865	19729F	PARTICIPANT	\N	PRESENT	0
797878	797865	05012A	PARTICIPANT	\N	PRESENT	0
797879	797865	21054E	PARTICIPANT	\N	PRESENT	0
797880	797865	20038A	PARTICIPANT	\N	PRESENT	0
797881	797865	20126Y	PARTICIPANT	\N	PRESENT	0
797882	797865	14107H	PARTICIPANT	\N	PRESENT	0
797883	797865	14357A	PARTICIPANT	\N	PRESENT	0
797884	797865	19563B	PARTICIPANT	\N	PRESENT	0
797885	797865	21053D	PARTICIPANT	\N	PRESENT	0
797886	797865	19383Y	PARTICIPANT	\N	PRESENT	0
797887	797865	14033T	PARTICIPANT	\N	PRESENT	0
797888	797865	21050A	PARTICIPANT	\N	PRESENT	0
797889	797865	08069G	PARTICIPANT	\N	PRESENT	0
797890	797865	20056C	PARTICIPANT	\N	PRESENT	0
797891	797865	21062E	PARTICIPANT	\N	PRESENT	0
797892	797865	20026V	PARTICIPANT	\N	PRESENT	0
797893	797865	14038Y	PARTICIPANT	\N	PRESENT	0
797894	797865	14030Q	PARTICIPANT	\N	PRESENT	0
797895	797865	08028W	PARTICIPANT	\N	PRESENT	0
797896	797865	18083K	PARTICIPANT	\N	PRESENT	0
797897	797865	20046A	PARTICIPANT	\N	PRESENT	0
797898	797865	19667J	PARTICIPANT	\N	PRESENT	0
797899	797865	20024T	PARTICIPANT	\N	PRESENT	0
797900	797865	19679N	PARTICIPANT	\N	PRESENT	0
797901	797865	20020P	PARTICIPANT	\N	PRESENT	0
797902	797865	20120S	PARTICIPANT	\N	PRESENT	0
797903	797865	19447X	PARTICIPANT	\N	PRESENT	0
797904	797865	14105F	PARTICIPANT	\N	PRESENT	0
797905	797865	14053L	PARTICIPANT	\N	PRESENT	0
797906	797865	20032T	PARTICIPANT	\N	PRESENT	0
797907	797865	19507S	PARTICIPANT	\N	PRESENT	0
797908	797865	14187A	PARTICIPANT	\N	PRESENT	0
797909	797865	19711U	PARTICIPANT	\N	PRESENT	0
797910	797699	14151M	PRESIDENT	0	PRESENT	0
797911	797699	17367Q	PARTICIPANT	\N	PRESENT	0
797912	797699	20090E	PARTICIPANT	\N	PRESENT	0
797913	797699	20110Q	PARTICIPANT	\N	PRESENT	0
797923	797699	19563B	PARTICIPANT	\N	PRESENT	0
797924	797699	14255U	PARTICIPANT	\N	PRESENT	0
801347	801346	11090Q	PARTICIPANT	\N	PRESENT	0
801348	801346	19695N	PARTICIPANT	\N	PRESENT	0
801351	801350	11090Q	PARTICIPANT	\N	PRESENT	0
801352	801350	19695N	PARTICIPANT	\N	PRESENT	0
810044	810043	19709B	PARTICIPANT	\N	PRESENT	0
810045	810043	04033B	PARTICIPANT	\N	PRESENT	0
810046	810043	08018U	PARTICIPANT	\N	PRESENT	0
810047	810043	14255U	PARTICIPANT	\N	PRESENT	0
810048	810043	20086J	PARTICIPANT	\N	PRESENT	0
810049	810043	21037D	PARTICIPANT	\N	PRESENT	0
810050	810043	11115U	PARTICIPANT	\N	PRESENT	0
813219	813217	19866P	PARTICIPANT	\N	PRESENT	0
813221	813220	19866P	PARTICIPANT	\N	PRESENT	0
818940	818939	19760E	PARTICIPANT	\N	PRESENT	0
818941	818939	14026U	PARTICIPANT	\N	PRESENT	0
818942	818939	19683J	PARTICIPANT	\N	PRESENT	0
820927	820911	14031R	PARTICIPANT	\N	PRESENT	0
820928	820911	20180F	PARTICIPANT	\N	PRESENT	0
820929	820911	14059S	PARTICIPANT	\N	PRESENT	0
820930	820911	20136B	PARTICIPANT	\N	PRESENT	0
820931	820911	14053L	PARTICIPANT	\N	PRESENT	0
820932	820911	14030Q	PARTICIPANT	\N	PRESENT	0
820933	820911	19331L	PARTICIPANT	\N	PRESENT	0
808286	808285	14193X	PARTICIPANT	\N	PRESENT	0
808287	808285	14097Y	PARTICIPANT	\N	PRESENT	0
808288	808285	14053L	PARTICIPANT	\N	PRESENT	0
808308	808304	21067K	PARTICIPANT	\N	PRESENT	0
818872	818870	14187A	PARTICIPANT	\N	PRESENT	0
818873	818870	19631V	PARTICIPANT	\N	PRESENT	0
818874	818870	19768N	PARTICIPANT	\N	PRESENT	0
818875	818870	20286Q	PARTICIPANT	\N	PRESENT	0
819464	818879	21043B	PARTICIPANT	\N	EXCUSE	0
819466	818763	17367Q	PARTICIPANT	\N	PRESENT	0
819467	818763	14151M	PRESIDENT	0	PRESENT	0
819468	818763	20090E	PARTICIPANT	\N	PRESENT	0
819469	818763	19295A	PARTICIPANT	\N	PRESENT	0
819470	818763	20108W	PARTICIPANT	\N	PRESENT	0
819471	818763	20252E	PARTICIPANT	\N	PRESENT	0
819474	818763	18395Y	PARTICIPANT	\N	PRESENT	0
819475	818763	21072G	PARTICIPANT	\N	PRESENT	0
819486	818763	19826F	PARTICIPANT	\N	PRESENT	0
819487	818763	21088Q	PARTICIPANT	\N	PRESENT	0
819488	818763	20146D	PARTICIPANT	\N	PRESENT	0
819489	818763	12028B	PARTICIPANT	\N	PRESENT	0
819499	818763	21095P	PARTICIPANT	\N	PRESENT	0
819502	818763	17737W	PARTICIPANT	\N	PRESENT	0
819508	818763	20110Q	PARTICIPANT	\N	PRESENT	0
819513	819512	19647E	PARTICIPANT	\N	PRESENT	0
819514	819512	21036C	PARTICIPANT	\N	PRESENT	0
819515	819512	21082J	PARTICIPANT	\N	PRESENT	0
821574	813082	20146D	PARTICIPANT	\N	PRESENT	0
821575	813082	07029T	PARTICIPANT	\N	PRESENT	0
821576	813082	20038A	PARTICIPANT	\N	PRESENT	0
821577	813082	11045K	PARTICIPANT	\N	EXCUSE	0
821578	813081	11045K	PARTICIPANT	\N	EXCUSE	0
821582	813082	14109K	PARTICIPANT	\N	PRESENT	0
821586	821585	20050V	PARTICIPANT	\N	PRESENT	0
821572	813082	14030Q	PRESIDENT	0	PRESENT	0
821573	813082	21091K	PARTICIPANT	\N	PRESENT	0
799783	797794	19621T	PARTICIPANT	\N	PRESENT	0
799784	797794	19760E	PARTICIPANT	\N	PRESENT	0
799785	797794	21091K	PARTICIPANT	\N	PRESENT	0
799786	797794	21084L	PARTICIPANT	\N	PRESENT	0
799787	797794	11040E	PARTICIPANT	\N	PRESENT	0
799788	797794	21088Q	PARTICIPANT	\N	PRESENT	0
799789	797794	19703U	PARTICIPANT	\N	PRESENT	0
799790	797794	19758L	PARTICIPANT	\N	PRESENT	0
799791	797794	04047H	PARTICIPANT	\N	PRESENT	0
799792	797794	14026U	PARTICIPANT	\N	PRESENT	0
799793	797794	19575F	PARTICIPANT	\N	PRESENT	0
799794	797794	11048N	PARTICIPANT	\N	PRESENT	0
799795	797794	14133K	PARTICIPANT	\N	PRESENT	0
799800	797794	19367Y	PARTICIPANT	\N	PRESENT	0
799803	797794	20078J	PARTICIPANT	\N	PRESENT	0
799805	797794	20074E	PARTICIPANT	\N	PRESENT	0
799806	797794	20076G	PARTICIPANT	\N	PRESENT	0
799807	797794	14123H	PARTICIPANT	\N	PRESENT	0
799808	797794	21044C	PARTICIPANT	\N	PRESENT	0
799809	797794	21080G	PARTICIPANT	\N	PRESENT	0
799810	797794	19573D	PARTICIPANT	\N	PRESENT	0
799811	797794	11043H	PARTICIPANT	\N	PRESENT	0
799813	797794	14223L	PARTICIPANT	\N	PRESENT	0
799814	797794	08028W	PARTICIPANT	\N	PRESENT	0
799815	797794	21061D	PARTICIPANT	\N	PRESENT	0
799816	797794	21071F	PARTICIPANT	\N	PRESENT	0
799817	797794	14191V	PARTICIPANT	\N	PRESENT	0
799818	797794	20044X	PARTICIPANT	\N	PRESENT	0
799819	797794	14215L	PARTICIPANT	\N	PRESENT	0
799820	797794	14259Y	PARTICIPANT	\N	PRESENT	0
799821	797794	05012A	PARTICIPANT	\N	PRESENT	0
799822	797794	21055F	PARTICIPANT	\N	PRESENT	0
799823	797794	19673G	PARTICIPANT	\N	PRESENT	0
799824	797794	19667J	PARTICIPANT	\N	PRESENT	0
799825	797794	14253S	PARTICIPANT	\N	PRESENT	0
799827	797794	20136B	PARTICIPANT	\N	PRESENT	0
799828	797794	20032T	PARTICIPANT	\N	PRESENT	0
799830	797794	14331P	PARTICIPANT	\N	PRESENT	0
799832	797794	19447X	PARTICIPANT	\N	PRESENT	0
799834	797794	21068L	PARTICIPANT	\N	PRESENT	0
799836	797794	20096L	PARTICIPANT	\N	PRESENT	0
799838	797794	20180F	PARTICIPANT	\N	PRESENT	0
799840	797794	20026V	PARTICIPANT	\N	PRESENT	0
799842	797794	19954N	PARTICIPANT	\N	PRESENT	0
799843	797794	21081H	PARTICIPANT	\N	PRESENT	0
799844	797794	20138D	PARTICIPANT	\N	PRESENT	0
799845	797794	20172F	PARTICIPANT	\N	PRESENT	0
799846	797794	14147R	PARTICIPANT	\N	PRESENT	0
799847	797794	21072G	PARTICIPANT	\N	PRESENT	0
799849	797794	14038Y	PARTICIPANT	\N	PRESENT	0
799850	797794	19723Y	PARTICIPANT	\N	PRESENT	0
799851	797794	20034V	PARTICIPANT	\N	PRESENT	0
799852	797794	21039F	PARTICIPANT	\N	PRESENT	0
799853	797794	20140W	PARTICIPANT	\N	PRESENT	0
799854	797794	11056N	PARTICIPANT	\N	PRESENT	0
799855	797794	20038A	PARTICIPANT	\N	PRESENT	0
799856	797794	14033T	PARTICIPANT	\N	PRESENT	0
799857	797794	20104S	PARTICIPANT	\N	PRESENT	0
799858	797794	19399H	PARTICIPANT	\N	PRESENT	0
799859	797794	20056C	PARTICIPANT	\N	PRESENT	0
799860	797794	20108W	PARTICIPANT	\N	PRESENT	0
799861	797794	20148F	PARTICIPANT	\N	PRESENT	0
799862	797794	20024T	PARTICIPANT	\N	PRESENT	0
799863	797794	14213J	PARTICIPANT	\N	PRESENT	0
799864	797794	20058E	PARTICIPANT	\N	PRESENT	0
799865	797794	21063F	PARTICIPANT	\N	PRESENT	0
799866	797794	20068G	PARTICIPANT	\N	PRESENT	0
799867	797794	21047F	PARTICIPANT	\N	PRESENT	0
799868	797794	14355X	PARTICIPANT	\N	PRESENT	0
799869	797794	19709B	PARTICIPANT	\N	PRESENT	0
799870	797794	08018U	PARTICIPANT	\N	PRESENT	0
799871	797794	19421M	PARTICIPANT	\N	PRESENT	0
799872	797794	08015R	PARTICIPANT	\N	PRESENT	0
799873	797794	19768N	PARTICIPANT	\N	PRESENT	0
799874	797794	19705W	PARTICIPANT	\N	PRESENT	0
799875	797794	19707Y	PARTICIPANT	\N	PRESENT	0
799876	797794	21036C	PARTICIPANT	\N	PRESENT	0
799877	797794	19533U	PARTICIPANT	\N	PRESENT	0
799878	797794	14059S	PARTICIPANT	\N	PRESENT	0
799879	797794	08056B	PARTICIPANT	\N	PRESENT	0
799880	797794	20124W	PARTICIPANT	\N	PRESENT	0
799881	797794	20126Y	PARTICIPANT	\N	PRESENT	0
799882	797794	20054A	PARTICIPANT	\N	PRESENT	0
799883	797794	14329V	PARTICIPANT	\N	PRESENT	0
799884	797794	14357A	PARTICIPANT	\N	PRESENT	0
799885	797794	19383Y	PARTICIPANT	\N	PRESENT	0
799886	797794	20098N	PARTICIPANT	\N	PRESENT	0
799887	797794	21095P	PARTICIPANT	\N	PRESENT	0
799888	797794	21090J	PARTICIPANT	\N	PRESENT	0
799889	797794	20120S	PARTICIPANT	\N	PRESENT	0
799890	797794	20252E	PARTICIPANT	\N	PRESENT	0
799891	797794	14069U	PARTICIPANT	\N	PRESENT	0
799892	797794	19798U	PARTICIPANT	\N	PRESENT	0
799893	797794	14071N	PARTICIPANT	\N	PRESENT	0
799894	797794	14187A	PARTICIPANT	\N	PRESENT	0
799895	797794	19701S	PARTICIPANT	\N	PRESENT	0
799896	797794	04033B	PARTICIPANT	\N	PRESENT	0
799897	797794	19679N	PARTICIPANT	\N	PRESENT	0
799898	797794	14053L	PARTICIPANT	\N	PRESENT	0
799899	797794	20062A	PARTICIPANT	\N	PRESENT	0
799900	797794	05008E	PARTICIPANT	\N	PRESENT	0
799901	797794	04092N	PARTICIPANT	\N	PRESENT	0
799902	797794	08034U	PARTICIPANT	\N	PRESENT	0
799903	797794	08010L	PARTICIPANT	\N	PRESENT	0
799904	797794	99004R	PARTICIPANT	\N	PRESENT	0
799905	797794	14193X	PARTICIPANT	\N	PRESENT	0
799908	797794	20110Q	PARTICIPANT	\N	PRESENT	0
799910	797794	19347U	PARTICIPANT	\N	PRESENT	0
799913	797794	21048G	PARTICIPANT	\N	PRESENT	0
799914	797794	21093M	PARTICIPANT	\N	PRESENT	0
799915	797794	20142Y	PARTICIPANT	\N	PRESENT	0
799917	797794	20092G	PARTICIPANT	\N	PRESENT	0
799919	797794	20266L	PARTICIPANT	\N	PRESENT	0
799921	797794	21079P	PARTICIPANT	\N	PRESENT	0
799927	797794	19631V	PARTICIPANT	\N	PRESENT	0
799928	797794	20102Q	PARTICIPANT	\N	PRESENT	0
799929	797794	19593H	PARTICIPANT	\N	PRESENT	0
799930	797794	19687N	PARTICIPANT	\N	PRESENT	0
799931	797794	21049H	PARTICIPANT	\N	PRESENT	0
799932	797794	21030V	PARTICIPANT	\N	PRESENT	0
799933	797794	19695N	PARTICIPANT	\N	PRESENT	0
799934	797794	14037X	PARTICIPANT	\N	PRESENT	0
799935	797794	04045F	PARTICIPANT	\N	PRESENT	0
799936	797794	08061X	PARTICIPANT	\N	PRESENT	0
799937	797794	08073C	PARTICIPANT	\N	PRESENT	0
799938	797794	19331L	PARTICIPANT	\N	PRESENT	0
799939	797794	21074J	PARTICIPANT	\N	PRESENT	0
799940	797794	21085M	PARTICIPANT	\N	PRESENT	0
799941	797794	14055N	PARTICIPANT	\N	PRESENT	0
799942	797794	20036X	PARTICIPANT	\N	PRESENT	0
799943	797794	20106U	PARTICIPANT	\N	PRESENT	0
799944	797794	14249W	PARTICIPANT	\N	PRESENT	0
799945	797794	21043B	PARTICIPANT	\N	PRESENT	0
799946	797794	20128B	PARTICIPANT	\N	PRESENT	0
799947	797794	11072N	PARTICIPANT	\N	PRESENT	0
799948	797794	14207L	PARTICIPANT	\N	PRESENT	0
799949	797794	19629C	PARTICIPANT	\N	PRESENT	0
799950	797794	20132W	PARTICIPANT	\N	PRESENT	0
799951	797794	21041Y	PARTICIPANT	\N	PRESENT	0
799952	797794	21066J	PARTICIPANT	\N	PRESENT	0
799953	797794	98022P	PARTICIPANT	\N	PRESENT	0
799954	797794	19553Y	PARTICIPANT	\N	PRESENT	0
799955	797794	21040X	PARTICIPANT	\N	PRESENT	0
799956	797794	14107H	PARTICIPANT	\N	PRESENT	0
799957	797794	21058J	PARTICIPANT	\N	PRESENT	0
799958	797794	21046E	PARTICIPANT	\N	PRESENT	0
799959	797794	19545Y	PARTICIPANT	\N	PRESENT	0
799960	797794	14195A	PARTICIPANT	\N	PRESENT	0
799961	797794	19693L	PARTICIPANT	\N	PRESENT	0
799962	797794	21065H	PARTICIPANT	\N	PRESENT	0
799963	797794	14211G	PARTICIPANT	\N	PRESENT	0
799964	797794	21054E	PARTICIPANT	\N	PRESENT	0
799965	797794	14251Q	PARTICIPANT	\N	PRESENT	0
799966	797794	20050V	PARTICIPANT	\N	PRESENT	0
799967	797794	21076L	PARTICIPANT	\N	PRESENT	0
799968	797794	14111D	PARTICIPANT	\N	PRESENT	0
799969	797794	20150Y	PARTICIPANT	\N	PRESENT	0
799970	797794	20116W	PARTICIPANT	\N	PRESENT	0
799971	797794	14021P	PARTICIPANT	\N	PRESENT	0
799972	797794	18207D	PARTICIPANT	\N	PRESENT	0
799973	797794	18231D	PARTICIPANT	\N	PRESENT	0
808857	808856	19735D	PARTICIPANT	\N	PRESENT	0
808858	808856	20114U	PARTICIPANT	\N	PRESENT	0
808859	808856	18395Y	PARTICIPANT	\N	PRESENT	0
808860	808856	21089R	PARTICIPANT	\N	PRESENT	0
808861	808856	20180F	PARTICIPANT	\N	PRESENT	0
808862	808856	20106U	PARTICIPANT	\N	PRESENT	0
808863	808856	20056C	PARTICIPANT	\N	PRESENT	0
808864	808856	20142Y	PARTICIPANT	\N	PRESENT	0
808865	808856	14147R	PARTICIPANT	\N	PRESENT	0
809263	809258	14033T	PARTICIPANT	\N	PRESENT	0
809264	809258	20076G	PARTICIPANT	\N	PRESENT	0
809265	809258	19575F	PARTICIPANT	\N	PRESENT	0
809266	809258	14083S	PARTICIPANT	\N	PRESENT	0
809267	809258	19721W	PARTICIPANT	\N	PRESENT	0
809268	809258	20144B	PARTICIPANT	\N	PRESENT	0
809269	809258	21062E	PARTICIPANT	\N	PRESENT	0
809270	809258	20126Y	PARTICIPANT	\N	PRESENT	0
809271	809258	20018V	PARTICIPANT	\N	PRESENT	0
809273	809258	14169X	PARTICIPANT	\N	PRESENT	0
809274	809258	19533U	PARTICIPANT	\N	PRESENT	0
809275	809258	19619A	PARTICIPANT	\N	PRESENT	0
809349	809347	18395Y	PARTICIPANT	\N	PRESENT	0
810272	810204	05008E	PARTICIPANT	\N	EXCUSE	0
810283	810282	18083K	PARTICIPANT	\N	PRESENT	0
810284	810282	14071N	PARTICIPANT	\N	PRESENT	0
815083	813341	21030V	PARTICIPANT	\N	PRESENT	0
815084	813341	08012N	PARTICIPANT	\N	PRESENT	0
815085	813341	14123H	PARTICIPANT	\N	PRESENT	0
815086	813341	19347U	PARTICIPANT	\N	PRESENT	0
815087	813341	11110B	PARTICIPANT	\N	PRESENT	0
815088	813341	21049H	PARTICIPANT	\N	PRESENT	0
815089	813341	20048C	PARTICIPANT	\N	PRESENT	0
815090	813341	20252E	PARTICIPANT	\N	PRESENT	0
815106	813341	20058E	PARTICIPANT	\N	PRESENT	0
815390	813250	14259Y	PARTICIPANT	\N	PRESENT	0
815391	813250	20134Y	PARTICIPANT	\N	PRESENT	0
815392	813250	20266L	PARTICIPANT	\N	PRESENT	0
815429	813250	20020P	PARTICIPANT	\N	PRESENT	0
815404	813250	21053D	PARTICIPANT	\N	PRESENT	0
815395	813250	20142Y	PARTICIPANT	\N	PRESENT	0
815430	813250	11056N	PARTICIPANT	\N	PRESENT	0
815397	813250	20102Q	PARTICIPANT	\N	PRESENT	0
815398	813250	21037D	PARTICIPANT	\N	PRESENT	0
815399	813250	20062A	PARTICIPANT	\N	PRESENT	0
815400	813250	07004J	PARTICIPANT	\N	PRESENT	0
815401	813250	14083S	PARTICIPANT	\N	PRESENT	0
815402	813250	20286Q	PARTICIPANT	\N	PRESENT	0
815403	813250	20092G	PARTICIPANT	\N	PRESENT	0
815418	813250	20120S	PARTICIPANT	\N	PRESENT	0
815407	813250	21050A	PARTICIPANT	\N	PRESENT	0
815409	813250	19507S	PARTICIPANT	\N	PRESENT	0
815410	813250	07029T	PARTICIPANT	\N	PRESENT	0
815411	813250	20036X	PARTICIPANT	\N	PRESENT	0
815412	813250	21125C	PARTICIPANT	\N	PRESENT	0
815413	813250	19611R	PARTICIPANT	\N	PRESENT	0
815414	813250	19699S	PARTICIPANT	\N	PRESENT	0
815415	813250	19719D	PARTICIPANT	\N	PRESENT	0
815416	813250	21055F	PARTICIPANT	\N	PRESENT	0
815420	813250	14207L	PARTICIPANT	\N	PRESENT	0
815442	813250	14215L	PARTICIPANT	\N	PRESENT	0
815423	813250	19447X	PARTICIPANT	\N	PRESENT	0
815424	813250	21057H	PARTICIPANT	\N	PRESENT	0
815425	813250	21056G	PARTICIPANT	\N	PRESENT	0
818332	818331	18083K	PARTICIPANT	\N	PRESENT	0
815427	813250	14069U	PARTICIPANT	\N	PRESENT	0
815428	813250	21077M	PARTICIPANT	\N	PRESENT	0
815431	813250	04047H	PARTICIPANT	\N	PRESENT	0
815432	812482	19553Y	PARTICIPANT	\N	PRESENT	0
815433	812482	20066E	PRESIDENT	0	PRESENT	0
815434	812482	19691J	PARTICIPANT	\N	PRESENT	0
815435	812482	18193Q	PARTICIPANT	\N	PRESENT	0
815436	812482	19758L	PARTICIPANT	\N	PRESENT	0
815437	812482	14030Q	PARTICIPANT	\N	PRESENT	0
815438	813250	20116W	PARTICIPANT	\N	PRESENT	0
815439	813250	19782L	PARTICIPANT	\N	PRESENT	0
815440	813250	21088Q	PARTICIPANT	\N	PRESENT	0
815441	813250	21090J	PARTICIPANT	\N	PRESENT	0
815917	815854	21068L	PARTICIPANT	\N	EXCUSE	0
818334	818331	11070L	PARTICIPANT	\N	PRESENT	0
818336	818331	20018V	PARTICIPANT	\N	PRESENT	0
818337	818331	14257W	PRESIDENT	0	PRESENT	0
818352	818331	14207L	PARTICIPANT	\N	EXCUSE	0
818356	818331	20042V	PARTICIPANT	\N	EXCUSE	0
818354	818331	19619A	PARTICIPANT	\N	EXCUSE	0
818361	818331	12016W	PARTICIPANT	\N	PRESENT	0
818367	818331	19575F	PARTICIPANT	\N	PRESENT	0
818519	818331	19533U	PARTICIPANT	\N	PRESENT	0
818567	818566	14255U	PARTICIPANT	\N	PRESENT	0
818568	818566	18083K	PARTICIPANT	\N	PRESENT	0
818569	818566	17229F	PARTICIPANT	\N	PRESENT	0
818570	818566	20038A	PARTICIPANT	\N	PRESENT	0
818571	818566	19565D	PARTICIPANT	\N	PRESENT	0
818572	818566	10015M	PARTICIPANT	\N	PRESENT	0
818573	818566	21073H	PARTICIPANT	\N	PRESENT	0
818605	818566	14083S	PARTICIPANT	\N	PRESENT	0
818609	818566	20084G	PARTICIPANT	\N	PRESENT	0
818610	818566	21095P	PARTICIPANT	\N	PRESENT	0
818681	814472	20048C	PARTICIPANT	\N	PRESENT	0
819199	819198	21083K	PARTICIPANT	\N	PRESENT	0
819200	819198	20082E	PARTICIPANT	\N	PRESENT	0
819201	819198	21066J	PARTICIPANT	\N	PRESENT	0
819203	819202	21062E	PARTICIPANT	\N	PRESENT	0
819204	819202	11065P	PARTICIPANT	\N	PRESENT	0
819434	818879	19729F	PARTICIPANT	\N	EXCUSE	0
819435	818879	19585H	PARTICIPANT	\N	EXCUSE	0
819472	818915	19387D	PARTICIPANT	\N	EXCUSE	0
819509	819266	19575F	PARTICIPANT	\N	PRESENT	0
820276	818987	14231L	PARTICIPANT	\N	PRESENT	0
820277	818987	20114U	PARTICIPANT	\N	PRESENT	0
820278	818987	19760E	PARTICIPANT	\N	PRESENT	0
820279	818987	19593H	PARTICIPANT	\N	PRESENT	0
820280	818987	19758L	PARTICIPANT	\N	PRESENT	0
820281	818987	20142Y	PARTICIPANT	\N	PRESENT	0
820284	818987	14223L	PARTICIPANT	\N	PRESENT	0
820287	818987	12028B	PARTICIPANT	\N	PRESENT	0
820288	818987	19295A	PARTICIPANT	\N	PRESENT	0
820289	818987	20070A	PARTICIPANT	\N	PRESENT	0
820290	818987	11027H	PARTICIPANT	\N	PRESENT	0
820291	818987	21059K	PARTICIPANT	\N	PRESENT	0
820294	818987	19545Y	PARTICIPANT	\N	PRESENT	0
820295	818987	19693L	PARTICIPANT	\N	PRESENT	0
820296	818987	21096Q	PARTICIPANT	\N	PRESENT	0
820297	818987	21097R	PARTICIPANT	\N	PRESENT	0
820302	818987	21071F	PARTICIPANT	\N	PRESENT	0
820304	818987	19687N	PARTICIPANT	\N	PRESENT	0
820305	818987	21088Q	PARTICIPANT	\N	PRESENT	0
820306	818987	19711U	PARTICIPANT	\N	PRESENT	0
820307	818987	21084L	PARTICIPANT	\N	PRESENT	0
820308	818987	14259Y	PARTICIPANT	\N	PRESENT	0
820309	818987	19573D	PARTICIPANT	\N	PRESENT	0
820310	818987	19575F	PARTICIPANT	\N	PRESENT	0
820311	818987	21034A	PARTICIPANT	\N	PRESENT	0
820312	818987	19681G	PARTICIPANT	\N	PRESENT	0
820313	818987	11056N	PARTICIPANT	\N	PRESENT	0
820314	818987	19565D	PARTICIPANT	\N	PRESENT	0
820315	818987	20046A	PARTICIPANT	\N	PRESENT	0
820316	818987	11065P	PARTICIPANT	\N	PRESENT	0
820317	818987	20134Y	PARTICIPANT	\N	PRESENT	0
820318	818987	14237S	PARTICIPANT	\N	PRESENT	0
820319	818987	20100N	PARTICIPANT	\N	PRESENT	0
820320	818987	19347U	PARTICIPANT	\N	PRESENT	0
820321	818987	21092L	PARTICIPANT	\N	PRESENT	0
820322	818987	21093M	PARTICIPANT	\N	PRESENT	0
820323	818987	21073H	PARTICIPANT	\N	PRESENT	0
820324	818987	20110Q	PARTICIPANT	\N	PRESENT	0
820325	818987	21037D	PARTICIPANT	\N	PRESENT	0
820326	818987	18083K	PARTICIPANT	\N	PRESENT	0
820327	818987	19782L	PARTICIPANT	\N	PRESENT	0
820328	818987	20106U	PARTICIPANT	\N	PRESENT	0
820329	818987	20128B	PARTICIPANT	\N	PRESENT	0
820330	818987	19591F	PARTICIPANT	\N	PRESENT	0
820331	818987	21125C	PARTICIPANT	\N	PRESENT	0
820332	818987	20074E	PARTICIPANT	\N	PRESENT	0
820333	818987	04042C	PARTICIPANT	\N	PRESENT	0
797717	797709	11048N	PARTICIPANT	\N	PRESENT	0
797752	797750	11048N	PARTICIPANT	\N	PRESENT	0
797756	794857	19707Y	PARTICIPANT	\N	EXCUSE	0
797754	794857	20060X	PARTICIPANT	\N	PRESENT	0
797755	794857	20078J	PARTICIPANT	\N	PRESENT	0
797757	794857	19705W	PARTICIPANT	\N	EXCUSE	0
797758	796085	19707Y	PARTICIPANT	\N	EXCUSE	0
797759	796085	19705W	PARTICIPANT	\N	EXCUSE	0
808012	807326	19760E	PARTICIPANT	\N	PRESENT	0
808011	807326	21071F	PARTICIPANT	\N	PRESENT	0
808013	807326	20024T	PARTICIPANT	\N	PRESENT	0
799742	797969	20042V	PARTICIPANT	\N	PRESENT	0
799743	797969	20286Q	PARTICIPANT	\N	EXCUSE	0
799744	797969	14073Q	PARTICIPANT	\N	PRESENT	0
799745	797969	20094J	PARTICIPANT	\N	PRESENT	0
799746	797969	19683J	PARTICIPANT	\N	PRESENT	0
799747	797969	19569H	PARTICIPANT	\N	PRESENT	0
799748	797969	19701S	PARTICIPANT	\N	PRESENT	0
799749	797969	20098N	PARTICIPANT	\N	PRESENT	0
799750	797969	21037D	PARTICIPANT	\N	PRESENT	0
799751	797969	14331P	PARTICIPANT	\N	PRESENT	0
799752	797969	14001X	PARTICIPANT	\N	PRESENT	0
799753	797969	20100N	PARTICIPANT	\N	PRESENT	0
799754	797969	21049H	PARTICIPANT	\N	PRESENT	0
799755	797969	21082J	PARTICIPANT	\N	PRESENT	0
799756	797969	08034U	PARTICIPANT	\N	PRESENT	0
799757	797969	14026U	PARTICIPANT	\N	PRESENT	0
799758	797969	04070G	PARTICIPANT	\N	PRESENT	0
801402	801401	18395Y	PARTICIPANT	\N	PRESENT	1
801403	801401	19709B	PARTICIPANT	\N	PRESENT	1
801405	801404	18395Y	PARTICIPANT	\N	PRESENT	1
801406	801404	19709B	PARTICIPANT	\N	PRESENT	1
804021	804019	08009T	PARTICIPANT	\N	PRESENT	0
804022	804019	21084L	PARTICIPANT	\N	PRESENT	0
804023	804019	21059K	PARTICIPANT	\N	PRESENT	0
804025	804019	10015M	PARTICIPANT	\N	PRESENT	0
804026	804019	19713W	PARTICIPANT	\N	PRESENT	0
804028	804019	20118Y	PARTICIPANT	\N	PRESENT	0
804029	804019	14037X	PARTICIPANT	\N	PRESENT	0
804030	804019	14169X	PARTICIPANT	\N	PRESENT	0
804031	804019	20042V	PARTICIPANT	\N	PRESENT	0
804032	804019	20248J	PARTICIPANT	\N	PRESENT	0
808015	807326	20116W	PARTICIPANT	\N	PRESENT	0
808016	807326	21043B	PARTICIPANT	\N	PRESENT	0
808017	807326	21045D	PARTICIPANT	\N	PRESENT	0
808018	807326	14053L	PARTICIPANT	\N	PRESENT	0
808020	807326	21057H	PARTICIPANT	\N	PRESENT	0
808021	807326	14195A	PARTICIPANT	\N	PRESENT	0
808022	807326	18083K	PARTICIPANT	\N	PRESENT	0
808023	807326	20140W	PARTICIPANT	\N	PRESENT	0
808024	807326	20040T	PARTICIPANT	\N	PRESENT	0
808025	807326	14249W	PARTICIPANT	\N	PRESENT	0
808026	807326	20100N	PARTICIPANT	\N	PRESENT	0
808027	807326	19111A	PARTICIPANT	\N	PRESENT	0
808028	807326	21033Y	PARTICIPANT	\N	PRESENT	0
808029	807326	19565D	PARTICIPANT	\N	PRESENT	0
808030	807326	14033T	PARTICIPANT	\N	PRESENT	0
808031	807326	19569H	PARTICIPANT	\N	PRESENT	0
808032	807326	14021P	PARTICIPANT	\N	PRESENT	0
808033	807326	08034U	PARTICIPANT	\N	PRESENT	0
808034	807326	20052X	PARTICIPANT	\N	PRESENT	0
808035	807326	18207D	PARTICIPANT	\N	PRESENT	0
808036	807326	14219Q	PARTICIPANT	\N	PRESENT	0
808037	807326	19563B	PARTICIPANT	\N	PRESENT	0
808039	807326	21053D	PARTICIPANT	\N	PRESENT	0
808040	807326	20054A	PARTICIPANT	\N	PRESENT	0
808041	807326	19798U	PARTICIPANT	\N	PRESENT	0
808042	807326	20098N	PARTICIPANT	\N	PRESENT	0
808043	807326	19479G	PARTICIPANT	\N	PRESENT	0
808058	807326	19647E	PARTICIPANT	\N	PRESENT	0
808060	807326	14107H	PARTICIPANT	\N	PRESENT	0
808063	807326	19629C	PARTICIPANT	\N	PRESENT	0
808064	807326	14073Q	PARTICIPANT	\N	PRESENT	0
819476	818561	19954N	PARTICIPANT	\N	PRESENT	0
819477	818561	20264J	PARTICIPANT	\N	PRESENT	0
819478	818561	20052X	PARTICIPANT	\N	PRESENT	0
819480	818561	19593H	PARTICIPANT	\N	PRESENT	0
819495	818561	19693L	PARTICIPANT	\N	PRESENT	0
819540	819537	14038Y	PARTICIPANT	\N	PRESENT	0
819541	819537	14083S	PARTICIPANT	\N	PRESENT	0
819542	819537	19687N	PARTICIPANT	\N	PRESENT	0
819543	819537	19723Y	PARTICIPANT	\N	PRESENT	0
819544	819537	20044X	PARTICIPANT	\N	PRESENT	0
819546	819537	18207D	PARTICIPANT	\N	PRESENT	0
821962	821961	11040E	PARTICIPANT	\N	PRESENT	0
821963	821961	19735D	PARTICIPANT	\N	PRESENT	0
821964	821961	14147R	PARTICIPANT	\N	PRESENT	0
821965	821961	14109K	PARTICIPANT	\N	PRESENT	0
821966	821961	14331P	PARTICIPANT	\N	PRESENT	0
821967	821961	21059K	PARTICIPANT	\N	PRESENT	0
821968	821961	20026V	PARTICIPANT	\N	PRESENT	0
821969	821961	20112S	PARTICIPANT	\N	PRESENT	0
818882	818881	14237S	PARTICIPANT	\N	PRESENT	0
818883	818881	14097Y	PARTICIPANT	\N	PRESENT	0
818885	815896	19679N	PARTICIPANT	\N	PRESENT	0
818886	815896	21046E	PARTICIPANT	\N	PRESENT	0
818887	817147	19679N	PARTICIPANT	\N	PRESENT	0
818888	817147	21046E	PARTICIPANT	\N	PRESENT	0
818889	815897	21046E	PARTICIPANT	\N	PRESENT	0
818890	815897	19679N	PARTICIPANT	\N	PRESENT	0
818891	815898	19679N	PARTICIPANT	\N	PRESENT	0
818892	815898	21046E	PARTICIPANT	\N	PRESENT	0
818901	818893	14207L	PARTICIPANT	\N	EXCUSE	0
818902	818400	20080C	PARTICIPANT	\N	EXCUSE	0
821630	821623	21046E	PARTICIPANT	\N	PRESENT	0
821631	821623	14042U	PARTICIPANT	\N	PRESENT	0
821632	821623	21087P	PARTICIPANT	\N	PRESENT	0
821633	821623	14059S	PARTICIPANT	\N	PRESENT	0
821634	821623	14147R	PARTICIPANT	\N	PRESENT	0
821635	821623	19798U	PARTICIPANT	\N	PRESENT	0
821636	821629	05008E	PARTICIPANT	\N	PRESENT	0
821637	821629	20090E	PARTICIPANT	\N	PRESENT	0
821639	821629	14217N	PARTICIPANT	\N	PRESENT	0
821640	821629	14042U	PARTICIPANT	\N	PRESENT	0
821641	821629	14026U	PARTICIPANT	\N	PRESENT	0
821643	821629	21087P	PARTICIPANT	\N	PRESENT	0
821645	821629	14059S	PARTICIPANT	\N	PRESENT	0
821647	821629	14147R	PARTICIPANT	\N	PRESENT	0
821648	821629	14331P	PARTICIPANT	\N	PRESENT	0
821649	821629	19798U	PARTICIPANT	\N	PRESENT	0
821650	821629	20026V	PARTICIPANT	\N	PRESENT	0
799974	797794	19489J	PARTICIPANT	\N	PRESENT	0
799975	797794	21062E	PARTICIPANT	\N	PRESENT	0
799976	797794	08012N	PARTICIPANT	\N	PRESENT	0
799977	797794	19683J	PARTICIPANT	\N	PRESENT	0
799978	797794	19531S	PARTICIPANT	\N	PRESENT	0
799979	797794	19669L	PARTICIPANT	\N	PRESENT	0
799980	797794	19649G	PARTICIPANT	\N	PRESENT	0
799981	797794	21060C	PARTICIPANT	\N	PRESENT	0
799982	797794	20094J	PARTICIPANT	\N	PRESENT	0
799983	797794	20114U	PARTICIPANT	\N	PRESENT	0
799984	797794	20088L	PARTICIPANT	\N	PRESENT	0
799985	797794	20080C	PARTICIPANT	\N	PRESENT	0
799986	797794	20060X	PARTICIPANT	\N	PRESENT	0
799987	797794	12028B	PARTICIPANT	\N	PRESENT	0
799988	797794	20264J	PARTICIPANT	\N	PRESENT	0
799989	797794	18395Y	PARTICIPANT	\N	PRESENT	0
800097	797794	11074Q	PARTICIPANT	\N	PRESENT	0
799991	797794	19251M	PARTICIPANT	\N	PRESENT	0
799992	797794	21067K	PARTICIPANT	\N	PRESENT	0
799993	797794	14151M	PARTICIPANT	\N	PRESENT	0
799994	797794	20112S	PARTICIPANT	\N	PRESENT	0
799995	797794	11110B	PARTICIPANT	\N	PRESENT	0
799996	797794	19647E	PARTICIPANT	\N	PRESENT	0
799997	797794	19820Y	PARTICIPANT	\N	PRESENT	0
799998	797794	19551W	PARTICIPANT	\N	PRESENT	0
799999	797794	14097Y	PARTICIPANT	\N	PRESENT	0
800000	797794	18193Q	PARTICIPANT	\N	PRESENT	0
800001	797794	17779H	PARTICIPANT	\N	PRESENT	0
800002	797794	14001X	PARTICIPANT	\N	PRESENT	0
800003	797794	20018V	PARTICIPANT	\N	PRESENT	0
800005	797794	14257W	PARTICIPANT	\N	PRESENT	0
800086	797794	11090Q	PARTICIPANT	\N	PRESENT	0
800007	797794	17965H	PARTICIPANT	\N	PRESENT	0
800008	797794	20030R	PARTICIPANT	\N	PRESENT	0
800009	797794	14225N	PARTICIPANT	\N	PRESENT	0
800010	797794	20082E	PARTICIPANT	\N	PRESENT	0
800011	797794	14229S	PARTICIPANT	\N	PRESENT	0
800012	797794	21059K	PARTICIPANT	\N	PRESENT	0
800013	797794	20084G	PARTICIPANT	\N	PRESENT	0
800014	797794	19413M	PARTICIPANT	\N	PRESENT	0
800015	797794	21051B	PARTICIPANT	\N	PRESENT	0
800016	797794	20064C	PARTICIPANT	\N	PRESENT	0
800017	797794	21077M	PARTICIPANT	\N	PRESENT	0
800019	797794	21082J	PARTICIPANT	\N	PRESENT	0
800021	797794	12016W	PARTICIPANT	\N	PRESENT	0
800025	797794	14030Q	PARTICIPANT	\N	PRESENT	0
800030	797794	07004J	PARTICIPANT	\N	PRESENT	0
800031	797794	14189C	PARTICIPANT	\N	PRESENT	0
800033	797794	21042A	PARTICIPANT	\N	PRESENT	0
800034	797794	21050A	PARTICIPANT	\N	PRESENT	0
800036	797794	20042V	PARTICIPANT	\N	PRESENT	0
800038	797794	14089Y	PARTICIPANT	\N	PRESENT	0
800039	797794	14083S	PARTICIPANT	\N	PRESENT	0
800041	797794	19721W	PARTICIPANT	\N	PRESENT	0
800042	797794	14267Y	PARTICIPANT	\N	PRESENT	0
800044	797794	20144B	PARTICIPANT	\N	PRESENT	0
800046	797794	11070L	PARTICIPANT	\N	PRESENT	0
800047	797794	14327T	PARTICIPANT	\N	PRESENT	0
800048	797794	20248J	PARTICIPANT	\N	PRESENT	0
800050	797794	17229F	PARTICIPANT	\N	PRESENT	0
800052	797794	19111A	PARTICIPANT	\N	PRESENT	0
800054	797794	20040T	PARTICIPANT	\N	PRESENT	0
800056	797794	17023S	PARTICIPANT	\N	PRESENT	0
800057	797794	20066E	PARTICIPANT	\N	PRESENT	0
800058	797794	20048C	PARTICIPANT	\N	PRESENT	0
800059	797794	19685L	PARTICIPANT	\N	PRESENT	0
800060	797794	01034P	PARTICIPANT	\N	PRESENT	0
800061	797794	19479G	PARTICIPANT	\N	PRESENT	0
800062	797794	21064G	PARTICIPANT	\N	PRESENT	0
800063	797794	19735D	PARTICIPANT	\N	PRESENT	0
800064	797794	21053D	PARTICIPANT	\N	PRESENT	0
800065	797794	21038E	PARTICIPANT	\N	PRESENT	0
800066	797794	19745F	PARTICIPANT	\N	PRESENT	0
800067	797794	14205J	PARTICIPANT	\N	PRESENT	0
800068	797794	14219Q	PARTICIPANT	\N	PRESENT	0
800069	797794	11085T	PARTICIPANT	\N	PRESENT	0
800070	797794	19826F	PARTICIPANT	\N	PRESENT	0
800071	797794	19335Q	PARTICIPANT	\N	PRESENT	0
800072	797794	04070G	PARTICIPANT	\N	PRESENT	0
800073	797794	19563B	PARTICIPANT	\N	PRESENT	0
800074	797794	19749K	PARTICIPANT	\N	PRESENT	0
800075	797794	19611R	PARTICIPANT	\N	PRESENT	0
800076	797794	14179A	PARTICIPANT	\N	PRESENT	0
800077	797794	19691J	PARTICIPANT	\N	PRESENT	0
800078	797794	11053K	PARTICIPANT	\N	PRESENT	0
800079	797794	20086J	PARTICIPANT	\N	PRESENT	0
800080	797794	19713W	PARTICIPANT	\N	PRESENT	0
800081	797794	14231L	PARTICIPANT	\N	PRESENT	0
800082	797794	11045K	PARTICIPANT	\N	PRESENT	0
800083	797794	21089R	PARTICIPANT	\N	PRESENT	0
800084	797794	14217N	PARTICIPANT	\N	PRESENT	0
800085	797794	07029T	PARTICIPANT	\N	PRESENT	0
800095	797794	07033P	PARTICIPANT	\N	PRESENT	0
800088	797794	20020P	PARTICIPANT	\N	PRESENT	0
800089	797794	14169X	PARTICIPANT	\N	PRESENT	0
800090	797794	04042C	PARTICIPANT	\N	PRESENT	0
800091	797794	08047A	PARTICIPANT	\N	PRESENT	0
800092	797794	20090E	PARTICIPANT	\N	PRESENT	0
800093	797794	20022R	PARTICIPANT	\N	PRESENT	0
800094	797794	17367Q	PARTICIPANT	\N	PRESENT	0
800098	797794	19569H	PARTICIPANT	\N	PRESENT	0
800099	797794	20028X	PARTICIPANT	\N	PRESENT	0
800100	797794	14031R	PARTICIPANT	\N	PRESENT	0
800101	797794	20286Q	PARTICIPANT	\N	PRESENT	0
800389	797795	19593H	PARTICIPANT	\N	PRESENT	0
800417	797795	19749K	PARTICIPANT	\N	PRESENT	0
800420	797795	19545Y	PARTICIPANT	\N	PRESENT	0
800421	797795	21088Q	PARTICIPANT	\N	PRESENT	0
800422	797795	14191V	PARTICIPANT	\N	PRESENT	0
800423	797795	11085T	PARTICIPANT	\N	PRESENT	0
800395	797795	14195A	PARTICIPANT	\N	PRESENT	0
800396	797795	21052C	PARTICIPANT	\N	PRESENT	0
800424	797795	14069U	PARTICIPANT	\N	PRESENT	0
800398	797795	20026V	PARTICIPANT	\N	PRESENT	0
800425	797795	08018U	PARTICIPANT	\N	PRESENT	0
800416	797795	21076L	PARTICIPANT	\N	PRESENT	0
800401	797795	21039F	PARTICIPANT	\N	PRESENT	0
800402	797795	21091K	PARTICIPANT	\N	PRESENT	0
800403	797795	20090E	PARTICIPANT	\N	PRESENT	0
800405	797795	21066J	PARTICIPANT	\N	PRESENT	0
800406	797795	21040X	PARTICIPANT	\N	PRESENT	0
800407	797795	14089Y	PARTICIPANT	\N	PRESENT	0
800426	797795	21054E	PARTICIPANT	\N	PRESENT	0
800415	797795	19649G	PARTICIPANT	\N	PRESENT	0
800427	797795	20116W	PARTICIPANT	\N	PRESENT	0
800428	797795	14038Y	PARTICIPANT	\N	PRESENT	0
800429	797795	21095P	PARTICIPANT	\N	PRESENT	0
800430	797795	20062A	PARTICIPANT	\N	PRESENT	0
800433	797795	19709B	PARTICIPANT	\N	PRESENT	0
800435	797795	20054A	PARTICIPANT	\N	PRESENT	0
800436	797795	20032T	PARTICIPANT	\N	PRESENT	0
800437	797795	14053L	PARTICIPANT	\N	PRESENT	0
800438	797795	21065H	PARTICIPANT	\N	PRESENT	0
800439	797795	21058J	PARTICIPANT	\N	PRESENT	0
800440	797795	21044C	PARTICIPANT	\N	PRESENT	0
800441	797795	14249W	PARTICIPANT	\N	PRESENT	0
800442	797795	14189C	PARTICIPANT	\N	PRESENT	0
800443	797795	08061X	PARTICIPANT	\N	PRESENT	0
800444	797795	20052X	PARTICIPANT	\N	PRESENT	0
800445	797795	19447X	PARTICIPANT	\N	PRESENT	0
800446	797795	20266L	PARTICIPANT	\N	PRESENT	0
800447	797795	14147R	PARTICIPANT	\N	PRESENT	0
800448	797795	14030Q	PARTICIPANT	\N	PRESENT	0
800449	797795	14107H	PARTICIPANT	\N	PRESENT	0
800454	797795	14111D	PARTICIPANT	\N	PRESENT	0
800451	797795	21070E	PARTICIPANT	\N	PRESENT	0
800452	797795	19413M	PARTICIPANT	\N	PRESENT	0
800453	797795	21038E	PARTICIPANT	\N	PRESENT	0
800455	797795	11056N	PARTICIPANT	\N	PRESENT	0
800464	797795	14251Q	PARTICIPANT	\N	PRESENT	0
800465	797795	19629C	PARTICIPANT	\N	PRESENT	0
800470	797795	21087P	PARTICIPANT	\N	PRESENT	0
800471	797795	14213J	PARTICIPANT	\N	PRESENT	0
800472	797795	18207D	PARTICIPANT	\N	PRESENT	0
800473	797795	17965H	PARTICIPANT	\N	PRESENT	0
800474	797795	21089R	PARTICIPANT	\N	PRESENT	0
800475	797795	11045K	PARTICIPANT	\N	PRESENT	0
800476	797795	19693L	PARTICIPANT	\N	PRESENT	0
800477	797795	99004R	PARTICIPANT	\N	PRESENT	0
800478	797795	20098N	PARTICIPANT	\N	PRESENT	0
800480	797609	21073H	PARTICIPANT	\N	EXCUSE	0
811543	811523	21049H	PARTICIPANT	\N	PRESENT	0
811544	811525	21049H	PARTICIPANT	\N	PRESENT	0
812966	812964	21067K	PARTICIPANT	\N	PRESENT	0
812967	812964	20252E	PARTICIPANT	\N	PRESENT	0
814804	814803	19347U	PARTICIPANT	\N	PRESENT	0
814805	814803	20066E	PARTICIPANT	\N	PRESENT	0
814806	814803	20092G	PARTICIPANT	\N	PRESENT	0
820335	818987	19697Q	PARTICIPANT	\N	PRESENT	0
820336	818987	14037X	PARTICIPANT	\N	PRESENT	0
820337	818987	11072N	PARTICIPANT	\N	PRESENT	0
820338	818987	08073C	PARTICIPANT	\N	PRESENT	0
820339	818987	20092G	PARTICIPANT	\N	PRESENT	0
820340	818987	04045F	PARTICIPANT	\N	PRESENT	0
820341	818987	08061X	PARTICIPANT	\N	PRESENT	0
820342	818987	21074J	PARTICIPANT	\N	PRESENT	0
820343	818987	21085M	PARTICIPANT	\N	PRESENT	0
820344	818987	14193X	PARTICIPANT	\N	PRESENT	0
820345	818987	20116W	PARTICIPANT	\N	PRESENT	0
820346	818987	14207L	PARTICIPANT	\N	PRESENT	0
820347	818987	21061D	PARTICIPANT	\N	PRESENT	0
820348	818987	19629C	PARTICIPANT	\N	PRESENT	0
820349	818987	19719D	PARTICIPANT	\N	PRESENT	0
820350	818987	11090Q	PARTICIPANT	\N	PRESENT	0
820351	818987	20132W	PARTICIPANT	\N	PRESENT	0
820352	818987	21055F	PARTICIPANT	\N	PRESENT	0
820353	818987	19673G	PARTICIPANT	\N	PRESENT	0
820354	818987	21029D	PARTICIPANT	\N	PRESENT	0
820355	818987	14241N	PARTICIPANT	\N	PRESENT	0
820356	818987	14195A	PARTICIPANT	\N	PRESENT	0
820357	818987	14031R	PARTICIPANT	\N	PRESENT	0
820358	818987	14253S	PARTICIPANT	\N	PRESENT	0
820359	818987	14331P	PARTICIPANT	\N	PRESENT	0
820360	818987	20032T	PARTICIPANT	\N	PRESENT	0
820361	818987	21080G	PARTICIPANT	\N	PRESENT	0
820362	818987	14251Q	PARTICIPANT	\N	PRESENT	0
820363	818987	19447X	PARTICIPANT	\N	PRESENT	0
820364	818987	19057M	PARTICIPANT	\N	PRESENT	0
820365	818987	14249W	PARTICIPANT	\N	PRESENT	0
820366	818987	21068L	PARTICIPANT	\N	PRESENT	0
820367	818987	20096L	PARTICIPANT	\N	PRESENT	0
820368	818987	20026V	PARTICIPANT	\N	PRESENT	0
820369	818987	19954N	PARTICIPANT	\N	PRESENT	0
820370	818987	21081H	PARTICIPANT	\N	PRESENT	0
820371	818987	20016T	PARTICIPANT	\N	PRESENT	0
820372	818987	20138D	PARTICIPANT	\N	PRESENT	0
820373	818987	21075K	PARTICIPANT	\N	PRESENT	0
820374	818987	14038Y	PARTICIPANT	\N	PRESENT	0
820375	818987	19723Y	PARTICIPANT	\N	PRESENT	0
820376	818987	20050V	PARTICIPANT	\N	PRESENT	0
820377	818987	21070E	PARTICIPANT	\N	PRESENT	0
820378	818987	21076L	PARTICIPANT	\N	PRESENT	0
820379	818987	19585H	PARTICIPANT	\N	PRESENT	0
820380	818987	20038A	PARTICIPANT	\N	PRESENT	0
820381	818987	21035B	PARTICIPANT	\N	PRESENT	0
820382	818987	19399H	PARTICIPANT	\N	PRESENT	0
820383	818987	20056C	PARTICIPANT	\N	PRESENT	0
820384	818987	20104S	PARTICIPANT	\N	PRESENT	0
820385	818987	20058E	PARTICIPANT	\N	PRESENT	0
820386	818987	21063F	PARTICIPANT	\N	PRESENT	0
820387	818987	20068G	PARTICIPANT	\N	PRESENT	0
820388	818987	21047F	PARTICIPANT	\N	PRESENT	0
820389	818987	21030V	PARTICIPANT	\N	PRESENT	0
820390	818987	21072G	PARTICIPANT	\N	PRESENT	0
820391	818987	20130U	PARTICIPANT	\N	PRESENT	0
820392	818987	14355X	PARTICIPANT	\N	PRESENT	0
820393	818987	20022R	PARTICIPANT	\N	PRESENT	0
820394	818987	07029T	PARTICIPANT	\N	PRESENT	0
820395	818987	17367Q	PARTICIPANT	\N	PRESENT	0
820396	818987	20086J	PARTICIPANT	\N	PRESENT	0
820397	818987	21054E	PARTICIPANT	\N	PRESENT	0
820398	818987	20172F	PARTICIPANT	\N	PRESENT	0
820399	818987	19631V	PARTICIPANT	\N	PRESENT	0
820400	818987	08060W	PARTICIPANT	\N	PRESENT	0
820401	818987	20088L	PARTICIPANT	\N	PRESENT	0
820402	818987	20080C	PARTICIPANT	\N	PRESENT	0
820403	818987	08015R	PARTICIPANT	\N	PRESENT	0
820404	818987	21089R	PARTICIPANT	\N	PRESENT	0
820405	818987	19768N	PARTICIPANT	\N	PRESENT	0
820406	818987	21045D	PARTICIPANT	\N	PRESENT	0
820407	818987	19705W	PARTICIPANT	\N	PRESENT	0
820408	818987	20060X	PARTICIPANT	\N	PRESENT	0
820409	818987	21057H	PARTICIPANT	\N	PRESENT	0
820410	818987	21036C	PARTICIPANT	\N	PRESENT	0
820411	818987	18395Y	PARTICIPANT	\N	PRESENT	0
820412	818987	11048N	PARTICIPANT	\N	PRESENT	0
820413	818987	14213J	PARTICIPANT	\N	PRESENT	0
820414	818987	21067K	PARTICIPANT	\N	PRESENT	0
820415	818987	19251M	PARTICIPANT	\N	PRESENT	0
820416	818987	19507S	PARTICIPANT	\N	PRESENT	0
820417	818987	14151M	PARTICIPANT	\N	PRESENT	0
820418	818987	08056B	PARTICIPANT	\N	PRESENT	0
820419	818987	11074Q	PARTICIPANT	\N	PRESENT	0
820420	818987	11110B	PARTICIPANT	\N	PRESENT	0
820421	818987	14059S	PARTICIPANT	\N	PRESENT	0
820422	818987	21062E	PARTICIPANT	\N	PRESENT	0
820423	818987	20124W	PARTICIPANT	\N	PRESENT	0
820424	818987	19553Y	PARTICIPANT	\N	PRESENT	0
820425	818987	14281W	PARTICIPANT	\N	PRESENT	0
820426	818987	20054A	PARTICIPANT	\N	PRESENT	0
820427	818987	19820Y	PARTICIPANT	\N	PRESENT	0
820428	818987	19725B	PARTICIPANT	\N	PRESENT	0
820429	818987	14329V	PARTICIPANT	\N	PRESENT	0
820430	818987	14357A	PARTICIPANT	\N	PRESENT	0
820431	818987	14121F	PARTICIPANT	\N	PRESENT	0
820432	818987	20098N	PARTICIPANT	\N	PRESENT	0
820433	818987	19683J	PARTICIPANT	\N	PRESENT	0
820434	818987	21095P	PARTICIPANT	\N	PRESENT	0
820435	818987	14097Y	PARTICIPANT	\N	PRESENT	0
820436	818987	21087P	PARTICIPANT	\N	PRESENT	0
820437	818987	14217N	PARTICIPANT	\N	PRESENT	0
820438	818987	19649G	PARTICIPANT	\N	PRESENT	0
820439	818987	19533U	PARTICIPANT	\N	PRESENT	0
820440	818987	19489J	PARTICIPANT	\N	PRESENT	0
820441	818987	14069U	PARTICIPANT	\N	PRESENT	0
820442	818987	18193Q	PARTICIPANT	\N	PRESENT	0
820443	818987	20252E	PARTICIPANT	\N	PRESENT	0
820444	818987	18207D	PARTICIPANT	\N	PRESENT	0
820445	818987	19798U	PARTICIPANT	\N	PRESENT	0
820446	818987	19647E	PARTICIPANT	\N	PRESENT	0
820447	818987	14187A	PARTICIPANT	\N	PRESENT	0
820448	818987	08012N	PARTICIPANT	\N	PRESENT	0
820449	818987	14071N	PARTICIPANT	\N	PRESENT	0
820450	818987	17779H	PARTICIPANT	\N	PRESENT	0
820451	818987	19701S	PARTICIPANT	\N	PRESENT	0
820452	818987	14001X	PARTICIPANT	\N	PRESENT	0
820453	818987	20028X	PARTICIPANT	\N	PRESENT	0
820454	818987	14053L	PARTICIPANT	\N	PRESENT	0
820455	818987	04033B	PARTICIPANT	\N	PRESENT	0
820457	818987	19679N	PARTICIPANT	\N	PRESENT	0
820459	818987	20018V	PARTICIPANT	\N	PRESENT	0
820460	818987	14109K	PARTICIPANT	\N	PRESENT	0
820462	818987	05008E	PARTICIPANT	\N	PRESENT	0
820463	818987	18231D	PARTICIPANT	\N	PRESENT	0
820465	818987	21060C	PARTICIPANT	\N	PRESENT	0
820466	818987	20030R	PARTICIPANT	\N	PRESENT	0
820468	818987	08034U	PARTICIPANT	\N	PRESENT	0
820469	818987	17965H	PARTICIPANT	\N	PRESENT	0
820470	818987	08010L	PARTICIPANT	\N	PRESENT	0
820472	818987	20082E	PARTICIPANT	\N	PRESENT	0
820473	818987	14229S	PARTICIPANT	\N	PRESENT	0
820475	818987	21056G	PARTICIPANT	\N	PRESENT	0
820476	818987	11045K	PARTICIPANT	\N	PRESENT	0
820477	818987	20084G	PARTICIPANT	\N	PRESENT	0
820478	818987	04047H	PARTICIPANT	\N	PRESENT	0
820479	818987	19413M	PARTICIPANT	\N	PRESENT	0
820480	818987	14026U	PARTICIPANT	\N	PRESENT	0
820481	818987	21051B	PARTICIPANT	\N	PRESENT	0
820482	818987	19703U	PARTICIPANT	\N	PRESENT	0
820483	818987	20064C	PARTICIPANT	\N	PRESENT	0
820484	818987	21031W	PARTICIPANT	\N	PRESENT	0
820485	818987	01058X	PARTICIPANT	\N	PRESENT	0
820486	818987	21082J	PARTICIPANT	\N	PRESENT	0
820487	818987	21077M	PARTICIPANT	\N	PRESENT	0
820488	818987	14133K	PARTICIPANT	\N	PRESENT	0
820334	818987	08069G	PARTICIPANT	\N	PRESENT	0
820489	818987	19367Y	PARTICIPANT	\N	PRESENT	0
820490	818987	19383Y	PARTICIPANT	\N	PRESENT	0
820491	818987	17737W	PARTICIPANT	\N	PRESENT	0
820492	818987	19621T	PARTICIPANT	\N	PRESENT	0
820493	818987	20180F	PARTICIPANT	\N	PRESENT	0
820494	818987	21091K	PARTICIPANT	\N	PRESENT	0
796823	794075	19760E	PARTICIPANT	\N	PRESENT	0
796824	794075	21030V	PARTICIPANT	\N	PRESENT	0
796825	794075	08045X	PARTICIPANT	\N	PRESENT	0
796826	794075	19820Y	PARTICIPANT	\N	PRESENT	0
796827	794075	19725B	PARTICIPANT	\N	PRESENT	0
796828	794075	19531S	PARTICIPANT	\N	PRESENT	0
796829	794075	14021P	PARTICIPANT	\N	PRESENT	0
796830	794075	19489J	PARTICIPANT	\N	PRESENT	0
796831	794075	18193Q	PARTICIPANT	\N	PRESENT	0
796832	794075	18207D	PARTICIPANT	\N	PRESENT	0
796833	794075	14001X	PARTICIPANT	\N	PRESENT	0
796834	794075	18231D	PARTICIPANT	\N	PRESENT	0
796835	794075	21060C	PARTICIPANT	\N	PRESENT	0
796836	794075	17965H	PARTICIPANT	\N	PRESENT	0
796837	794075	20082E	PARTICIPANT	\N	PRESENT	0
796838	794075	14229S	PARTICIPANT	\N	PRESENT	0
796839	794075	21056G	PARTICIPANT	\N	PRESENT	0
796840	794075	11045K	PARTICIPANT	\N	PRESENT	0
796841	794075	19413M	PARTICIPANT	\N	PRESENT	0
796842	794075	21051B	PARTICIPANT	\N	PRESENT	0
796843	794075	20064C	PARTICIPANT	\N	PRESENT	0
796844	794075	21082J	PARTICIPANT	\N	PRESENT	0
796845	794075	14189C	PARTICIPANT	\N	PRESENT	0
796846	794075	21050A	PARTICIPANT	\N	PRESENT	0
796847	794075	14089Y	PARTICIPANT	\N	PRESENT	0
796848	794075	14255U	PARTICIPANT	\N	PRESENT	0
796849	794075	21083K	PARTICIPANT	\N	PRESENT	0
796850	794075	14083S	PARTICIPANT	\N	PRESENT	0
796851	794075	14055N	PARTICIPANT	\N	PRESENT	0
796852	794075	11115U	PARTICIPANT	\N	PRESENT	0
796853	794075	11070L	PARTICIPANT	\N	PRESENT	0
796854	794075	14327T	PARTICIPANT	\N	PRESENT	0
796855	794075	20248J	PARTICIPANT	\N	PRESENT	0
796856	794075	15197G	PARTICIPANT	\N	PRESENT	0
796857	794075	14042U	PARTICIPANT	\N	PRESENT	0
796858	794075	21094N	PARTICIPANT	\N	PRESENT	0
796859	794075	20100N	PARTICIPANT	\N	PRESENT	0
796860	794075	21042A	PARTICIPANT	\N	PRESENT	0
796861	794075	17023S	PARTICIPANT	\N	PRESENT	0
796862	794075	20286Q	PARTICIPANT	\N	PRESENT	0
796863	794075	19569H	PARTICIPANT	\N	PRESENT	0
796864	794075	20144B	PARTICIPANT	\N	PRESENT	0
796865	794075	20048C	PARTICIPANT	\N	PRESENT	0
796866	794075	19735D	PARTICIPANT	\N	PRESENT	0
796867	794075	19611R	PARTICIPANT	\N	PRESENT	0
796868	794075	19699S	PARTICIPANT	\N	PRESENT	0
796869	794075	19563B	PARTICIPANT	\N	PRESENT	0
796870	794075	19335Q	PARTICIPANT	\N	PRESENT	0
796871	794075	21038E	PARTICIPANT	\N	PRESENT	0
796872	794075	21064G	PARTICIPANT	\N	PRESENT	0
796873	794075	19479G	PARTICIPANT	\N	PRESENT	0
796874	794075	19749K	PARTICIPANT	\N	PRESENT	0
796875	794075	19629C	PARTICIPANT	\N	PRESENT	0
796876	794075	19553Y	PARTICIPANT	\N	PRESENT	0
796877	794075	20112S	PARTICIPANT	\N	PRESENT	0
796878	794075	04070G	PARTICIPANT	\N	PRESENT	0
796879	794075	11110B	PARTICIPANT	\N	PRESENT	0
796880	794075	19331L	PARTICIPANT	\N	PRESENT	0
796881	794075	14213J	PARTICIPANT	\N	PRESENT	0
796882	794075	14329V	PARTICIPANT	\N	PRESENT	0
796883	794075	14251Q	PARTICIPANT	\N	PRESENT	0
796884	794711	11072N	PARTICIPANT	\N	PRESENT	0
796885	794075	19669L	PARTICIPANT	\N	PRESENT	0
796886	794075	21059K	PARTICIPANT	\N	PRESENT	0
796887	794075	14033T	PARTICIPANT	\N	PRESENT	0
796888	794075	14179A	PARTICIPANT	\N	PRESENT	0
796889	794075	20022R	PARTICIPANT	\N	PRESENT	0
796890	794075	19507S	PARTICIPANT	\N	PRESENT	0
796891	794075	21058J	PARTICIPANT	\N	PRESENT	0
796892	794075	20040T	PARTICIPANT	\N	PRESENT	0
796893	794075	11056N	PARTICIPANT	\N	PRESENT	0
798798	797791	20042V	PARTICIPANT	\N	PRESENT	0
804539	804538	19575F	PARTICIPANT	\N	PRESENT	0
804542	804538	20042V	PARTICIPANT	\N	EXCUSE	0
804543	804538	14207L	PARTICIPANT	\N	PRESENT	0
804544	804538	11070L	PARTICIPANT	\N	PRESENT	0
804545	804538	14033T	PARTICIPANT	\N	PRESENT	0
804546	804538	19711U	PARTICIPANT	\N	PRESENT	0
804547	804538	12016W	PARTICIPANT	\N	PRESENT	0
804548	804538	14031R	PARTICIPANT	\N	PRESENT	0
804549	804538	20018V	PARTICIPANT	\N	PRESENT	0
804550	804538	14257W	PRESIDENT	0	PRESENT	0
804551	804538	19619A	PARTICIPANT	\N	PRESENT	0
806865	803924	14179A	PARTICIPANT	\N	PRESENT	0
806913	803924	21091K	PARTICIPANT	\N	PRESENT	0
806914	803924	14219Q	PARTICIPANT	\N	PRESENT	0
806915	803924	14205J	PARTICIPANT	\N	PRESENT	0
806916	803924	20042V	PARTICIPANT	\N	PRESENT	0
806917	803924	21040X	PARTICIPANT	\N	PRESENT	0
806918	803924	19693L	PARTICIPANT	\N	PRESENT	0
806919	803924	14069U	PARTICIPANT	\N	PRESENT	0
806920	803924	19760E	PARTICIPANT	\N	PRESENT	0
806921	803924	21083K	PARTICIPANT	\N	PRESENT	0
806922	803924	19335Q	PARTICIPANT	\N	PRESENT	0
806923	803924	20080C	PARTICIPANT	\N	PRESENT	0
806935	803924	19347U	PARTICIPANT	\N	PRESENT	0
806941	803924	21090J	PARTICIPANT	\N	PRESENT	0
806942	803924	19611R	PARTICIPANT	\N	PRESENT	0
806943	803924	21084L	PARTICIPANT	\N	PRESENT	0
806944	803924	14281W	PARTICIPANT	\N	PRESENT	0
806945	803924	21089R	PARTICIPANT	\N	PRESENT	0
806946	803924	20094J	PARTICIPANT	\N	PRESENT	0
806947	803924	21057H	PARTICIPANT	\N	PRESENT	0
806948	803924	19569H	PARTICIPANT	\N	PRESENT	0
806949	803924	20132W	PARTICIPANT	\N	PRESENT	0
806956	803924	20032T	PARTICIPANT	\N	PRESENT	0
806957	803924	14169X	PARTICIPANT	\N	PRESENT	0
806958	803924	07033P	PARTICIPANT	\N	PRESENT	0
806959	803924	11045K	PARTICIPANT	\N	PRESENT	0
806960	803924	21033Y	PARTICIPANT	\N	PRESENT	0
806963	803924	20108W	PARTICIPANT	\N	PRESENT	0
806974	803924	21071F	PARTICIPANT	\N	PRESENT	0
806975	803924	11072N	PARTICIPANT	\N	PRESENT	0
806983	803924	14083S	PARTICIPANT	\N	PRESENT	0
807006	803924	14042U	PARTICIPANT	\N	PRESENT	0
807007	803924	19699S	PARTICIPANT	\N	PRESENT	0
807039	803925	21033Y	PARTICIPANT	\N	PRESENT	0
807054	803925	21056G	PARTICIPANT	\N	PRESENT	0
807056	803925	14281W	PARTICIPANT	\N	PRESENT	0
807060	803925	19569H	PARTICIPANT	\N	PRESENT	0
807063	803925	19335Q	PARTICIPANT	\N	PRESENT	0
807066	803925	20054A	PARTICIPANT	\N	PRESENT	0
807067	803925	11056N	PARTICIPANT	\N	PRESENT	0
807068	803925	20062A	PARTICIPANT	\N	PRESENT	0
807069	803925	19760E	PARTICIPANT	\N	PRESENT	0
807070	803925	21050A	PARTICIPANT	\N	PRESENT	0
807072	803925	19758L	PARTICIPANT	\N	PRESENT	0
807075	803925	21048G	PARTICIPANT	\N	PRESENT	0
807021	803925	19301E	PARTICIPANT	\N	PRESENT	0
807022	802357	21082J	PARTICIPANT	\N	PRESENT	0
807023	802357	19782L	PARTICIPANT	\N	PRESENT	0
807024	802357	08034U	PARTICIPANT	\N	PRESENT	0
807025	802357	21031W	PARTICIPANT	\N	PRESENT	0
807026	802357	20038A	PARTICIPANT	\N	PRESENT	0
807027	802357	14031R	PARTICIPANT	\N	PRESENT	0
807028	802357	19413M	PARTICIPANT	\N	PRESENT	0
807029	802357	21093M	PARTICIPANT	\N	PRESENT	0
807030	802357	11090Q	PARTICIPANT	\N	PRESENT	0
807031	802357	21084L	PARTICIPANT	\N	PRESENT	0
807032	802357	21056G	PARTICIPANT	\N	PRESENT	0
807033	802357	99004R	PARTICIPANT	\N	PRESENT	0
807034	802357	21050A	PARTICIPANT	\N	PRESENT	0
807035	802357	17023S	PARTICIPANT	\N	PRESENT	0
807036	802357	20248J	PARTICIPANT	\N	EXCUSE	0
807076	803925	20090E	PARTICIPANT	\N	PRESENT	0
807077	803925	21051B	PARTICIPANT	\N	PRESENT	0
807078	803925	19711U	PARTICIPANT	\N	PRESENT	0
807080	803925	14021P	PARTICIPANT	\N	PRESENT	0
807082	803925	19693L	PARTICIPANT	\N	PRESENT	0
807084	803925	19798U	PARTICIPANT	\N	PRESENT	0
807085	803925	21054E	PARTICIPANT	\N	PRESENT	0
807088	803925	21076L	PARTICIPANT	\N	PRESENT	0
807089	803925	14038Y	PARTICIPANT	\N	PRESENT	0
807090	803925	14207L	PARTICIPANT	\N	PRESENT	0
807091	803925	19782L	PARTICIPANT	\N	PRESENT	0
807092	803925	14215L	PARTICIPANT	\N	PRESENT	0
807093	803925	21086N	PARTICIPANT	\N	PRESENT	0
807094	803925	20034V	PARTICIPANT	\N	PRESENT	0
807095	803925	19447X	PARTICIPANT	\N	PRESENT	0
807097	803925	21058J	PARTICIPANT	\N	PRESENT	0
807098	803925	04047H	PARTICIPANT	\N	PRESENT	0
806458	806456	19758L	PARTICIPANT	\N	PRESENT	0
806459	806456	21045D	PARTICIPANT	\N	PRESENT	0
806460	806456	21039F	PARTICIPANT	\N	PRESENT	0
806461	806456	17965H	PARTICIPANT	\N	PRESENT	0
820945	818764	14151M	PRESIDENT	0	PRESENT	0
820946	818764	17367Q	PARTICIPANT	\N	PRESENT	0
820948	818764	20090E	PARTICIPANT	\N	PRESENT	0
820949	818764	20146D	PARTICIPANT	\N	PRESENT	0
820951	818764	18395Y	PARTICIPANT	\N	PRESENT	0
820952	818764	15197G	PARTICIPANT	\N	PRESENT	0
820954	818764	21072G	PARTICIPANT	\N	PRESENT	0
820956	818764	19295A	PARTICIPANT	\N	PRESENT	0
820964	818764	20050V	PARTICIPANT	\N	PRESENT	0
821048	818764	17737W	PARTICIPANT	\N	PRESENT	0
821082	818764	20110Q	PARTICIPANT	\N	PRESENT	0
800481	797609	19691J	PARTICIPANT	\N	EXCUSE	0
800482	797609	14059S	PARTICIPANT	\N	PRESENT	0
800483	797609	19673G	PARTICIPANT	\N	PRESENT	0
800484	797609	20146D	PARTICIPANT	\N	EXCUSE	0
800485	797795	14083S	PARTICIPANT	\N	PRESENT	0
800486	797795	20048C	PARTICIPANT	\N	PRESENT	0
800487	797795	20086J	PARTICIPANT	\N	PRESENT	0
800488	797795	19673G	PARTICIPANT	\N	PRESENT	0
800489	797795	21056G	PARTICIPANT	\N	PRESENT	0
800490	797795	21057H	PARTICIPANT	\N	PRESENT	0
800491	797795	14215L	PARTICIPANT	\N	PRESENT	0
800492	797795	14225N	PARTICIPANT	\N	PRESENT	0
800493	797795	20110Q	PARTICIPANT	\N	PRESENT	0
800494	797795	20050V	PARTICIPANT	\N	PRESENT	0
800495	797795	14217N	PARTICIPANT	\N	PRESENT	0
800496	797795	20114U	PARTICIPANT	\N	PRESENT	0
800498	800497	19251M	PARTICIPANT	\N	PRESENT	0
800499	800497	19593H	PARTICIPANT	\N	PRESENT	0
800500	800497	14179A	PARTICIPANT	\N	PRESENT	0
800501	800497	04042C	PARTICIPANT	\N	PRESENT	0
800502	800497	19111A	PARTICIPANT	\N	PRESENT	0
800504	800503	20080C	PARTICIPANT	\N	PRESENT	0
800505	797795	20038A	PARTICIPANT	\N	PRESENT	0
800506	797795	19533U	PARTICIPANT	\N	PRESENT	0
800507	797795	20126Y	PARTICIPANT	\N	PRESENT	0
800508	797795	20264J	PARTICIPANT	\N	PRESENT	0
800558	797796	20098N	PARTICIPANT	\N	PRESENT	0
800559	797796	20062A	PARTICIPANT	\N	PRESENT	0
800560	797796	99004R	PARTICIPANT	\N	PRESENT	0
800561	797796	20086J	PARTICIPANT	\N	PRESENT	0
800562	797796	21039F	PARTICIPANT	\N	PRESENT	0
800563	797796	21058J	PARTICIPANT	\N	PRESENT	0
800564	797609	21035B	PARTICIPANT	\N	EXCUSE	0
800565	797796	19447X	PARTICIPANT	\N	PRESENT	0
800566	797796	14069U	PARTICIPANT	\N	PRESENT	0
800567	797796	19673G	PARTICIPANT	\N	PRESENT	0
800568	797796	21044C	PARTICIPANT	\N	PRESENT	0
800569	797796	08018U	PARTICIPANT	\N	PRESENT	0
800570	797796	21056G	PARTICIPANT	\N	PRESENT	0
800571	797796	21082J	PARTICIPANT	\N	PRESENT	0
800572	797796	21089R	PARTICIPANT	\N	PRESENT	0
800573	797796	19413M	PARTICIPANT	\N	PRESENT	0
800574	797796	17965H	PARTICIPANT	\N	PRESENT	0
800575	797796	18207D	PARTICIPANT	\N	PRESENT	0
800576	797796	20110Q	PARTICIPANT	\N	PRESENT	0
800577	797796	20020P	PARTICIPANT	\N	PRESENT	0
800578	797796	14195A	PARTICIPANT	\N	PRESENT	0
800579	797796	11045K	PARTICIPANT	\N	PRESENT	0
800580	797796	21046E	PARTICIPANT	\N	PRESENT	0
800581	797796	21052C	PARTICIPANT	\N	PRESENT	0
800582	797796	19693L	PARTICIPANT	\N	PRESENT	0
800583	797796	21076L	PARTICIPANT	\N	PRESENT	0
800584	797796	20114U	PARTICIPANT	\N	PRESENT	0
800585	797796	14083S	PARTICIPANT	\N	PRESENT	0
800586	797796	14207L	PARTICIPANT	\N	PRESENT	0
800587	797796	21043B	PARTICIPANT	\N	PRESENT	0
800588	797796	20046A	PARTICIPANT	\N	PRESENT	0
800589	797796	21087P	PARTICIPANT	\N	PRESENT	0
800590	797796	21040X	PARTICIPANT	\N	PRESENT	0
800591	797796	21057H	PARTICIPANT	\N	PRESENT	0
800592	797796	14215L	PARTICIPANT	\N	PRESENT	0
800600	797796	19347U	PARTICIPANT	\N	PRESENT	0
800594	797796	14073Q	PARTICIPANT	\N	PRESENT	0
800595	797796	14189C	PARTICIPANT	\N	PRESENT	0
800596	797796	14251Q	PARTICIPANT	\N	PRESENT	0
800597	797796	20080C	PARTICIPANT	\N	PRESENT	0
800598	797796	21053D	PARTICIPANT	\N	PRESENT	0
800599	797796	04047H	PARTICIPANT	\N	PRESENT	0
800601	797796	14030Q	PARTICIPANT	\N	PRESENT	0
800602	797796	19629C	PARTICIPANT	\N	PRESENT	0
800603	797796	14231L	PARTICIPANT	\N	PRESENT	0
800604	797796	19760E	PARTICIPANT	\N	PRESENT	0
800605	797796	14033T	PARTICIPANT	\N	PRESENT	0
800556	797796	19593H	PARTICIPANT	\N	PRESENT	0
800557	797796	20090E	PARTICIPANT	\N	PRESENT	0
800606	797796	21079P	PARTICIPANT	\N	PRESENT	0
800607	797796	20102Q	PARTICIPANT	\N	PRESENT	0
800608	797796	20124W	PARTICIPANT	\N	PRESENT	0
800609	797796	14357A	PARTICIPANT	\N	PRESENT	0
800610	797796	20034V	PARTICIPANT	\N	PRESENT	0
800612	797796	19649G	PARTICIPANT	\N	PRESENT	0
800613	797796	14147R	PARTICIPANT	\N	PRESENT	0
800614	797796	07029T	PARTICIPANT	\N	PRESENT	0
800615	797796	17023S	PARTICIPANT	\N	PRESENT	0
800616	797796	21055F	PARTICIPANT	\N	PRESENT	0
800617	797796	20180F	PARTICIPANT	\N	PRESENT	0
800658	797797	20112S	PARTICIPANT	\N	PRESENT	0
800659	797797	19735D	PARTICIPANT	\N	PRESENT	0
800660	797797	18395Y	PARTICIPANT	\N	PRESENT	0
800661	797797	20106U	PARTICIPANT	\N	PRESENT	0
800662	797797	21089R	PARTICIPANT	\N	PRESENT	0
800663	797797	19611R	PARTICIPANT	\N	PRESENT	0
800664	797797	04070G	PARTICIPANT	\N	PRESENT	0
800665	797797	20086J	PARTICIPANT	\N	PRESENT	0
800666	797797	20124W	PARTICIPANT	\N	PRESENT	0
800667	797797	14229S	PARTICIPANT	\N	PRESENT	0
800668	797797	20142Y	PARTICIPANT	\N	PRESENT	0
800669	797797	14033T	PARTICIPANT	\N	PRESENT	0
800670	797797	21039F	PARTICIPANT	\N	PRESENT	0
800671	797797	20180F	PARTICIPANT	\N	PRESENT	0
800672	797797	19621T	PARTICIPANT	\N	PRESENT	0
800673	797797	19693L	PARTICIPANT	\N	PRESENT	0
800674	797797	20102Q	PARTICIPANT	\N	PRESENT	0
800675	797797	19593H	PARTICIPANT	\N	PRESENT	0
800676	797797	20052X	PARTICIPANT	\N	PRESENT	0
800677	797797	19629C	PARTICIPANT	\N	PRESENT	0
800678	797797	20132W	PARTICIPANT	\N	PRESENT	0
800679	797797	20058E	PARTICIPANT	\N	PRESENT	0
800680	797797	14147R	PARTICIPANT	\N	PRESENT	0
800681	797797	14038Y	PARTICIPANT	\N	PRESENT	0
800682	797797	21091K	PARTICIPANT	\N	PRESENT	0
800683	797797	04033B	PARTICIPANT	\N	PRESENT	0
800684	797797	21037D	PARTICIPANT	\N	PRESENT	0
800685	797797	20042V	PARTICIPANT	\N	PRESENT	0
800686	797797	17023S	PARTICIPANT	\N	PRESENT	0
800687	797797	20062A	PARTICIPANT	\N	PRESENT	0
800688	797797	14213J	PARTICIPANT	\N	PRESENT	0
800689	797797	20126Y	PARTICIPANT	\N	PRESENT	0
800690	797797	19533U	PARTICIPANT	\N	PRESENT	0
800691	797797	19575F	PARTICIPANT	\N	PRESENT	0
800745	797798	11090Q	PARTICIPANT	\N	PRESENT	0
800753	797798	17965H	PARTICIPANT	\N	PRESENT	0
800754	797798	19820Y	PARTICIPANT	\N	PRESENT	0
800755	797798	20100N	PARTICIPANT	\N	PRESENT	0
800656	797797	19479G	PARTICIPANT	\N	PRESENT	0
800657	797797	20138D	PARTICIPANT	\N	PRESENT	0
800756	797798	08060W	PARTICIPANT	\N	PRESENT	0
800757	797798	21082J	PARTICIPANT	\N	PRESENT	0
800758	797798	14207L	PARTICIPANT	\N	PRESENT	0
800759	797798	14147R	PARTICIPANT	\N	PRESENT	0
800775	797798	21095P	PARTICIPANT	\N	PRESENT	0
800761	797798	21042A	PARTICIPANT	\N	PRESENT	0
800762	797798	21053D	PARTICIPANT	\N	PRESENT	0
800763	797798	18231D	PARTICIPANT	\N	PRESENT	0
800764	797798	21077M	PARTICIPANT	\N	PRESENT	0
800765	797798	14357A	PARTICIPANT	\N	PRESENT	0
800766	797798	14021P	PARTICIPANT	\N	PRESENT	0
800767	797798	20086J	PARTICIPANT	\N	PRESENT	0
800768	797798	14257W	PARTICIPANT	\N	PRESENT	0
800769	797798	20136B	PARTICIPANT	\N	PRESENT	0
800770	797798	20046A	PARTICIPANT	\N	PRESENT	0
800771	797798	21061D	PARTICIPANT	\N	PRESENT	0
800774	797798	19331L	PARTICIPANT	\N	PRESENT	0
800776	797798	21068L	PARTICIPANT	\N	PRESENT	0
800777	797798	21091K	PARTICIPANT	\N	PRESENT	0
800779	797798	18193Q	PARTICIPANT	\N	PRESENT	0
800780	797798	19551W	PARTICIPANT	\N	PRESENT	0
800781	797798	21089R	PARTICIPANT	\N	PRESENT	0
800782	797798	19701S	PARTICIPANT	\N	PRESENT	0
800783	797798	14219Q	PARTICIPANT	\N	PRESENT	0
800784	797798	14030Q	PARTICIPANT	\N	PRESENT	0
800785	797798	14073Q	PARTICIPANT	\N	PRESENT	0
800786	797798	19629C	PARTICIPANT	\N	PRESENT	0
800787	797798	21054E	PARTICIPANT	\N	PRESENT	0
800788	797798	20082E	PARTICIPANT	\N	PRESENT	0
800789	797798	14059S	PARTICIPANT	\N	PRESENT	0
800790	797798	14169X	PARTICIPANT	\N	PRESENT	0
800791	797798	21055F	PARTICIPANT	\N	PRESENT	0
800792	797798	18207D	PARTICIPANT	\N	PRESENT	0
800793	797798	19687N	PARTICIPANT	\N	PRESENT	0
800798	797798	19347U	PARTICIPANT	\N	PRESENT	0
818845	818787	08034U	PARTICIPANT	\N	PRESENT	0
818846	818787	21031W	PARTICIPANT	\N	PRESENT	0
818847	818787	20038A	PARTICIPANT	\N	PRESENT	0
818848	818787	14031R	PARTICIPANT	\N	PRESENT	0
818849	818787	19413M	PARTICIPANT	\N	PRESENT	0
818850	818787	11090Q	PARTICIPANT	\N	PRESENT	0
818851	818787	21093M	PARTICIPANT	\N	PRESENT	0
818852	818787	21084L	PARTICIPANT	\N	PRESENT	0
818853	818787	21056G	PARTICIPANT	\N	PRESENT	0
818854	818787	21066J	PARTICIPANT	\N	PRESENT	0
818855	818787	21090J	PARTICIPANT	\N	PRESENT	0
818856	818787	99004R	PRESIDENT	0	PRESENT	0
818857	818787	17023S	PARTICIPANT	\N	PRESENT	0
818858	818787	21050A	PARTICIPANT	\N	PRESENT	0
819108	819095	21082J	PARTICIPANT	\N	PRESENT	0
819109	819095	21084L	PARTICIPANT	\N	PRESENT	0
819110	819095	19413M	PARTICIPANT	\N	PRESENT	0
819111	819095	21090J	PARTICIPANT	\N	PRESENT	0
819112	819095	99004R	PRESIDENT	0	PRESENT	0
819113	819095	21093M	PARTICIPANT	\N	PRESENT	0
819114	819095	20248J	PARTICIPANT	\N	EXCUSE	0
819115	819095	14031R	PARTICIPANT	\N	EXCUSE	0
819116	819095	17023S	PARTICIPANT	\N	EXCUSE	0
820495	818987	21042A	PARTICIPANT	\N	PRESENT	0
820496	818987	14215L	PARTICIPANT	\N	PRESENT	0
820497	818987	14189C	PARTICIPANT	\N	PRESENT	0
820498	818987	14030Q	PARTICIPANT	\N	PRESENT	0
820499	818987	21050A	PARTICIPANT	\N	PRESENT	0
820500	818987	20140W	PARTICIPANT	\N	PRESENT	0
820501	818987	20042V	PARTICIPANT	\N	PRESENT	0
820502	818987	14089Y	PARTICIPANT	\N	PRESENT	0
820503	818987	21090J	PARTICIPANT	\N	PRESENT	0
820504	818987	14083S	PARTICIPANT	\N	PRESENT	0
820505	818987	21044C	PARTICIPANT	\N	PRESENT	0
820506	818987	11053K	PARTICIPANT	\N	PRESENT	0
820507	818987	20144B	PARTICIPANT	\N	PRESENT	0
820508	818987	99004R	PARTICIPANT	\N	PRESENT	0
820509	818987	14267Y	PARTICIPANT	\N	PRESENT	0
820510	818987	11115U	PARTICIPANT	\N	PRESENT	0
820511	818987	20126Y	PARTICIPANT	\N	PRESENT	0
820512	818987	21058J	PARTICIPANT	\N	PRESENT	0
820513	818987	14147R	PARTICIPANT	\N	PRESENT	0
820514	818987	04092N	PARTICIPANT	\N	PRESENT	0
820515	818987	14191V	PARTICIPANT	\N	PRESENT	0
820516	818987	08047A	PARTICIPANT	\N	PRESENT	0
820517	818987	10015M	PARTICIPANT	\N	PRESENT	0
820518	818987	20020P	PARTICIPANT	\N	PRESENT	0
820519	818987	19421M	PARTICIPANT	\N	PRESENT	0
820520	818987	11070L	PARTICIPANT	\N	PRESENT	0
820521	818987	20044X	PARTICIPANT	\N	PRESENT	0
820522	818987	11043H	PARTICIPANT	\N	PRESENT	0
820523	818987	15197G	PARTICIPANT	\N	PRESENT	0
820524	818987	20040T	PARTICIPANT	\N	PRESENT	0
820525	818987	21086N	PARTICIPANT	\N	PRESENT	0
820526	818987	20062A	PARTICIPANT	\N	PRESENT	0
820527	818987	20148F	PARTICIPANT	\N	PRESENT	0
820528	818987	19111A	PARTICIPANT	\N	PRESENT	0
820529	818987	14123H	PARTICIPANT	\N	PRESENT	0
820603	813082	19798U	PARTICIPANT	\N	EXCUSE	0
820531	818987	07004J	PARTICIPANT	\N	PRESENT	0
820532	818987	14179A	PARTICIPANT	\N	PRESENT	0
820533	818987	14173T	PARTICIPANT	\N	PRESENT	0
820534	818987	19685L	PARTICIPANT	\N	PRESENT	0
820535	818987	20066E	PARTICIPANT	\N	PRESENT	0
820536	818987	14073Q	PARTICIPANT	\N	PRESENT	0
820537	818987	19735D	PARTICIPANT	\N	PRESENT	0
820538	818987	19611R	PARTICIPANT	\N	PRESENT	0
820539	818987	19699S	PARTICIPANT	\N	PRESENT	0
820540	818987	14205J	PARTICIPANT	\N	PRESENT	0
820541	818987	14219Q	PARTICIPANT	\N	PRESENT	0
820542	818987	11085T	PARTICIPANT	\N	PRESENT	0
820543	818987	19826F	PARTICIPANT	\N	PRESENT	0
820544	818987	08009T	PARTICIPANT	\N	PRESENT	0
820545	818987	07033P	PARTICIPANT	\N	PRESENT	0
820546	818987	19563B	PARTICIPANT	\N	PRESENT	0
820547	818987	19335Q	PARTICIPANT	\N	PRESENT	0
820592	818987	19866P	PARTICIPANT	\N	PRESENT	0
820585	818987	20136B	PARTICIPANT	\N	PRESENT	0
820550	818987	20036X	PARTICIPANT	\N	PRESENT	0
820552	818987	19745F	PARTICIPANT	\N	PRESENT	0
820553	818987	21053D	PARTICIPANT	\N	PRESENT	0
820554	818987	21064G	PARTICIPANT	\N	PRESENT	0
820555	818987	19619A	PARTICIPANT	\N	PRESENT	0
820556	818987	01034P	PARTICIPANT	\N	PRESENT	0
820561	818987	21043B	PARTICIPANT	\N	PRESENT	0
820562	818987	20248J	PARTICIPANT	\N	PRESENT	0
820564	818987	21066J	PARTICIPANT	\N	PRESENT	0
820566	818987	14111D	PARTICIPANT	\N	PRESENT	0
820568	818987	14221J	PARTICIPANT	\N	PRESENT	0
820574	818987	20146D	PARTICIPANT	\N	PRESENT	0
820578	818987	21041Y	PARTICIPANT	\N	PRESENT	0
820580	818987	14021P	PARTICIPANT	\N	PRESENT	0
820581	818987	20048C	PARTICIPANT	\N	PRESENT	0
820582	818987	20052X	PARTICIPANT	\N	PRESENT	0
820583	818987	14257W	PARTICIPANT	\N	PRESENT	0
820584	818987	14033T	PARTICIPANT	\N	PRESENT	0
820586	818987	20094J	PARTICIPANT	\N	PRESENT	0
820590	818987	19551W	PARTICIPANT	\N	PRESENT	0
820591	818987	20120S	PARTICIPANT	\N	PRESENT	0
820602	813082	20130U	PARTICIPANT	\N	EXCUSE	0
820604	813082	19749K	PARTICIPANT	\N	EXCUSE	0
820605	813082	20098N	PARTICIPANT	\N	EXCUSE	0
820609	813081	20130U	PARTICIPANT	\N	EXCUSE	0
820963	818988	14026U	PARTICIPANT	\N	PRESENT	0
820965	820607	20062A	PARTICIPANT	\N	PRESENT	0
820966	820607	14030Q	PARTICIPANT	\N	PRESENT	0
820967	818988	21088Q	PARTICIPANT	\N	PRESENT	0
820968	818988	20084G	PARTICIPANT	\N	PRESENT	0
820969	818988	14089Y	PARTICIPANT	\N	PRESENT	0
820970	818988	20088L	PARTICIPANT	\N	PRESENT	0
820971	818988	19545Y	PARTICIPANT	\N	PRESENT	0
820972	818988	14281W	PARTICIPANT	\N	PRESENT	0
820973	818988	14021P	PARTICIPANT	\N	PRESENT	0
820974	818988	17965H	PARTICIPANT	\N	PRESENT	0
820975	818988	14229S	PARTICIPANT	\N	PRESENT	0
820976	818988	14207L	PARTICIPANT	\N	PRESENT	0
820977	818988	14071N	PARTICIPANT	\N	PRESENT	0
820978	818988	19703U	PARTICIPANT	\N	PRESENT	0
820979	818988	14107H	PARTICIPANT	\N	PRESENT	0
820980	818988	21089R	PARTICIPANT	\N	PRESENT	0
820981	818988	20044X	PARTICIPANT	\N	PRESENT	0
820982	818988	21045D	PARTICIPANT	\N	PRESENT	0
820983	818988	10015M	PARTICIPANT	\N	PRESENT	0
820984	818988	11045K	PARTICIPANT	\N	PRESENT	0
820985	818988	20064C	PARTICIPANT	\N	PRESENT	0
820987	820608	19866P	PARTICIPANT	\N	PRESENT	0
820988	820608	20022R	PARTICIPANT	\N	PRESENT	0
820989	820608	20124W	PARTICIPANT	\N	PRESENT	0
820990	820608	20026V	PARTICIPANT	\N	PRESENT	0
820998	820961	21036C	PARTICIPANT	\N	PRESENT	0
820999	820961	21030V	PARTICIPANT	\N	PRESENT	0
821000	820961	19565D	PARTICIPANT	\N	PRESENT	0
821001	820961	20072C	PARTICIPANT	\N	PRESENT	0
821002	820961	14357A	PARTICIPANT	\N	PRESENT	0
821003	820961	01058X	PARTICIPANT	\N	PRESENT	0
821004	820961	14001X	PARTICIPANT	\N	PRESENT	0
821005	820961	20104S	PARTICIPANT	\N	PRESENT	0
821006	820961	11115U	PARTICIPANT	\N	PRESENT	0
821007	820961	08015R	PARTICIPANT	\N	PRESENT	0
821008	820961	14193X	PARTICIPANT	\N	PRESENT	0
821009	820961	14179A	PARTICIPANT	\N	PRESENT	0
821010	820961	14249W	PARTICIPANT	\N	PRESENT	0
821011	820961	21050A	PARTICIPANT	\N	PRESENT	0
821012	820961	20128B	PARTICIPANT	\N	PRESENT	0
821013	820961	08047A	PARTICIPANT	\N	PRESENT	0
821014	820961	14329V	PARTICIPANT	\N	PRESENT	0
821015	820961	14037X	PARTICIPANT	\N	PRESENT	0
821016	820961	14038Y	PARTICIPANT	\N	PRESENT	0
821018	820961	21073H	PARTICIPANT	\N	PRESENT	0
821019	820961	14187A	PRESIDENT	0	PRESENT	0
821020	820961	20038A	PARTICIPANT	\N	PRESENT	0
821021	820961	20042V	PARTICIPANT	\N	PRESENT	0
821022	820961	19695N	PARTICIPANT	\N	PRESENT	0
821023	820961	11090Q	PARTICIPANT	\N	PRESENT	0
821024	820961	21093M	PARTICIPANT	\N	PRESENT	0
821025	820961	21034A	PARTICIPANT	\N	PRESENT	0
821026	820961	14191V	PARTICIPANT	\N	PRESENT	0
821027	820961	14205J	PARTICIPANT	\N	PRESENT	0
821028	820961	20252E	PARTICIPANT	\N	PRESENT	0
821029	820961	99004R	PARTICIPANT	\N	PRESENT	0
798334	798331	19735D	PARTICIPANT	\N	PRESENT	0
798335	798331	19723Y	PARTICIPANT	\N	PRESENT	0
798336	798333	19735D	PARTICIPANT	\N	PRESENT	0
798337	798333	19723Y	PARTICIPANT	\N	PRESENT	0
798345	798344	21044C	PARTICIPANT	\N	PRESENT	0
798346	798344	14231L	PARTICIPANT	\N	PRESENT	0
798348	798347	14231L	PARTICIPANT	\N	PRESENT	0
798350	798349	14231L	PARTICIPANT	\N	PRESENT	0
798758	798638	14237S	PARTICIPANT	\N	PRESENT	0
798760	798638	18083K	PARTICIPANT	\N	PRESENT	0
804309	804308	20286Q	PARTICIPANT	\N	PRESENT	0
804310	804308	21082J	PARTICIPANT	\N	PRESENT	0
804312	804311	19749K	PARTICIPANT	\N	PRESENT	0
804313	804311	19673G	PARTICIPANT	\N	PRESENT	0
807099	803925	21096Q	PARTICIPANT	\N	PRESENT	0
807100	803925	19673G	PARTICIPANT	\N	PRESENT	0
807101	803925	20142Y	PARTICIPANT	\N	PRESENT	0
807102	803925	14231L	PARTICIPANT	\N	PRESENT	0
807103	803925	19489J	PARTICIPANT	\N	PRESENT	0
807104	803925	19347U	PARTICIPANT	\N	PRESENT	0
807105	803925	21079P	PARTICIPANT	\N	PRESENT	0
807106	803925	19657G	PARTICIPANT	\N	PRESENT	0
807107	803925	21044C	PARTICIPANT	\N	PRESENT	0
807108	803925	21084L	PARTICIPANT	\N	PRESENT	0
807109	803925	20032T	PARTICIPANT	\N	PRESENT	0
807110	803925	19533U	PARTICIPANT	\N	PRESENT	0
807111	803925	18207D	PARTICIPANT	\N	PRESENT	0
807112	803925	14229S	PARTICIPANT	\N	PRESENT	0
807114	803925	19553Y	PARTICIPANT	\N	PRESENT	0
807115	803925	10015M	PARTICIPANT	\N	PRESENT	0
807116	803925	20044X	PARTICIPANT	\N	PRESENT	0
807117	803925	14037X	PARTICIPANT	\N	PRESENT	0
807118	803925	20070A	PARTICIPANT	\N	PRESENT	0
807119	803925	20040T	PARTICIPANT	\N	PRESENT	0
807144	803925	19573D	PARTICIPANT	\N	PRESENT	0
807121	803925	14083S	PARTICIPANT	\N	PRESENT	0
807122	803925	19687N	PARTICIPANT	\N	PRESENT	0
807123	803925	14053L	PARTICIPANT	\N	PRESENT	0
807124	803925	99004R	PARTICIPANT	\N	PRESENT	0
807125	803925	21075K	PARTICIPANT	\N	PRESENT	0
807130	803925	19701S	PARTICIPANT	\N	PRESENT	0
807131	803925	19697Q	PARTICIPANT	\N	PRESENT	0
807132	803925	21032X	PARTICIPANT	\N	PRESENT	0
807133	803925	14030Q	PARTICIPANT	\N	PRESENT	0
807134	803925	05008E	PARTICIPANT	\N	PRESENT	0
807135	803925	21073H	PARTICIPANT	\N	PRESENT	0
807136	803925	21078N	PARTICIPANT	\N	PRESENT	0
807137	803925	08010L	PARTICIPANT	\N	PRESENT	0
807138	803925	20058E	PARTICIPANT	\N	PRESENT	0
807139	803925	21085M	PARTICIPANT	\N	PRESENT	0
807146	803925	14031R	PARTICIPANT	\N	PRESENT	0
807147	803925	21071F	PARTICIPANT	\N	PRESENT	0
807148	803925	21069M	PARTICIPANT	\N	PRESENT	0
807149	803925	08034U	PARTICIPANT	\N	PRESENT	0
807154	803925	14251Q	PARTICIPANT	\N	PRESENT	0
807164	803925	21097R	PARTICIPANT	\N	PRESENT	0
807165	803925	21082J	PARTICIPANT	\N	PRESENT	0
807169	803925	14071N	PARTICIPANT	\N	PRESENT	0
807170	803925	19669L	PARTICIPANT	\N	PRESENT	0
807172	803925	19691J	PARTICIPANT	\N	PRESENT	0
807173	803925	11065P	PARTICIPANT	\N	PRESENT	0
807187	803925	19649G	PARTICIPANT	\N	PRESENT	0
807189	803925	21029D	PARTICIPANT	\N	PRESENT	0
807194	803925	11085T	PARTICIPANT	\N	PRESENT	0
809942	807227	14179A	PARTICIPANT	\N	PRESENT	0
809953	807227	04047H	PARTICIPANT	\N	PRESENT	0
809955	807227	08018U	PARTICIPANT	\N	PRESENT	0
809957	807227	14215L	PARTICIPANT	\N	PRESENT	0
809959	807227	19649G	PARTICIPANT	\N	PRESENT	0
809960	807227	20110Q	PARTICIPANT	\N	PRESENT	0
809961	807227	19111A	PARTICIPANT	\N	PRESENT	0
809962	807227	11040E	PARTICIPANT	\N	PRESENT	0
809963	807227	11072N	PARTICIPANT	\N	PRESENT	0
809964	807227	21034A	PARTICIPANT	\N	PRESENT	0
809965	807227	20086J	PARTICIPANT	\N	PRESENT	0
809966	807227	21053D	PARTICIPANT	\N	PRESENT	0
809967	807227	19629C	PARTICIPANT	\N	PRESENT	0
809968	807227	21076L	PARTICIPANT	\N	PRESENT	0
809969	807227	21054E	PARTICIPANT	\N	PRESENT	0
809971	807227	14259Y	PARTICIPANT	\N	PRESENT	0
809972	807227	21069M	PARTICIPANT	\N	PRESENT	0
809973	807227	21061D	PARTICIPANT	\N	PRESENT	0
809974	807227	20062A	PARTICIPANT	\N	PRESENT	0
809975	807227	21056G	PARTICIPANT	\N	PRESENT	0
809976	807227	21073H	PARTICIPANT	\N	PRESENT	0
809977	807227	19331L	PARTICIPANT	\N	PRESENT	0
809978	807227	14109K	PARTICIPANT	\N	PRESENT	0
809979	807227	19679N	PARTICIPANT	\N	PRESENT	0
809980	807227	14275Y	PARTICIPANT	\N	PRESENT	0
809981	807227	20034V	PARTICIPANT	\N	PRESENT	0
809982	807227	19758L	PARTICIPANT	\N	PRESENT	0
809984	807227	14033T	PARTICIPANT	\N	PRESENT	0
809985	807227	20032T	PARTICIPANT	\N	PRESENT	0
809986	807227	14267Y	PARTICIPANT	\N	PRESENT	0
809987	807227	20128B	PARTICIPANT	\N	PRESENT	0
809988	807227	21055F	PARTICIPANT	\N	PRESENT	0
809989	807227	21074J	PARTICIPANT	\N	PRESENT	0
809990	807227	14083S	PARTICIPANT	\N	PRESENT	0
809991	807227	19760E	PARTICIPANT	\N	PRESENT	0
809992	807227	21079P	PARTICIPANT	\N	PRESENT	0
809993	807227	21068L	PARTICIPANT	\N	PRESENT	0
809994	807227	20248J	PARTICIPANT	\N	PRESENT	0
809995	807227	20180F	PARTICIPANT	\N	PRESENT	0
809996	807228	14179A	PARTICIPANT	\N	PRESENT	0
810032	807228	14249W	PARTICIPANT	\N	PRESENT	0
809998	807228	08018U	PARTICIPANT	\N	PRESENT	0
810033	807228	19629C	PARTICIPANT	\N	PRESENT	0
810000	807228	19649G	PARTICIPANT	\N	PRESENT	0
810001	807228	20110Q	PARTICIPANT	\N	PRESENT	0
810002	807228	19111A	PARTICIPANT	\N	PRESENT	0
810003	807228	11040E	PARTICIPANT	\N	PRESENT	0
810004	807228	11072N	PARTICIPANT	\N	PRESENT	0
810005	807228	21034A	PARTICIPANT	\N	PRESENT	0
810034	807228	14215L	PARTICIPANT	\N	PRESENT	0
810007	807228	21053D	PARTICIPANT	\N	PRESENT	0
810035	807228	14219Q	PARTICIPANT	\N	PRESENT	0
810009	807228	21076L	PARTICIPANT	\N	PRESENT	0
810010	807228	21054E	PARTICIPANT	\N	PRESENT	0
810052	807228	21075K	PARTICIPANT	\N	PRESENT	0
810012	807228	21061D	PARTICIPANT	\N	PRESENT	0
810013	807228	20062A	PARTICIPANT	\N	PRESENT	0
810014	807228	21056G	PARTICIPANT	\N	PRESENT	0
810015	807228	21073H	PARTICIPANT	\N	PRESENT	0
810016	807228	19679N	PARTICIPANT	\N	PRESENT	0
810017	807228	14275Y	PARTICIPANT	\N	PRESENT	0
810018	807228	20034V	PARTICIPANT	\N	PRESENT	0
810019	807228	19758L	PARTICIPANT	\N	PRESENT	0
810053	807228	14109K	PARTICIPANT	\N	PRESENT	0
810021	807228	20032T	PARTICIPANT	\N	PRESENT	0
810054	809943	21084L	PARTICIPANT	\N	PRESENT	0
810055	809943	21031W	PARTICIPANT	\N	PRESENT	0
810024	807228	21055F	PARTICIPANT	\N	PRESENT	0
810056	809943	08034U	PARTICIPANT	\N	PRESENT	0
810026	807228	14083S	PARTICIPANT	\N	PRESENT	0
810027	807228	19760E	PARTICIPANT	\N	PRESENT	0
810028	807228	21079P	PARTICIPANT	\N	PRESENT	0
810029	807228	21068L	PARTICIPANT	\N	PRESENT	0
810030	807228	20248J	PARTICIPANT	\N	PRESENT	0
810031	807228	20180F	PARTICIPANT	\N	PRESENT	0
810057	809943	20038A	PARTICIPANT	\N	PRESENT	0
810058	809943	14031R	PARTICIPANT	\N	PRESENT	0
810059	809943	19413M	PARTICIPANT	\N	PRESENT	0
810060	809943	99004R	PRESIDENT	0	PRESENT	0
810061	809943	21093M	PARTICIPANT	\N	PRESENT	0
810062	809943	21090J	PARTICIPANT	\N	PRESENT	0
810063	809943	11090Q	PARTICIPANT	\N	PRESENT	0
810064	809943	21056G	PARTICIPANT	\N	EXCUSE	0
810065	807228	14031R	PARTICIPANT	\N	PRESENT	0
798096	798056	19545Y	PARTICIPANT	\N	PRESENT	0
798097	798056	18083K	PARTICIPANT	\N	PRESENT	0
798098	798056	08034U	PARTICIPANT	\N	PRESENT	0
798099	798056	19447X	PARTICIPANT	\N	PRESENT	0
798100	798056	14205J	PARTICIPANT	\N	PRESENT	0
800801	797798	14225N	PARTICIPANT	\N	PRESENT	0
800802	797798	17023S	PARTICIPANT	\N	PRESENT	0
800803	797798	14033T	PARTICIPANT	\N	PRESENT	0
800804	797798	14189C	PARTICIPANT	\N	PRESENT	0
800805	797798	11027H	PARTICIPANT	\N	PRESENT	0
800806	797798	18395Y	PARTICIPANT	\N	PRESENT	0
800807	797798	11045K	PARTICIPANT	\N	PRESENT	0
800808	797798	14195A	PARTICIPANT	\N	PRESENT	0
800809	797798	14031R	PARTICIPANT	\N	PRESENT	0
801133	798781	14026U	PARTICIPANT	\N	PRESENT	0
801134	798784	14026U	PARTICIPANT	\N	PRESENT	0
801135	798787	14026U	PARTICIPANT	\N	PRESENT	0
801137	801136	14231L	PARTICIPANT	\N	PRESENT	0
801138	801136	19673G	PARTICIPANT	\N	PRESENT	0
801139	801136	19489J	PARTICIPANT	\N	PRESENT	0
801141	801140	14231L	PARTICIPANT	\N	PRESENT	0
801142	801140	19673G	PARTICIPANT	\N	PRESENT	0
801143	801140	19489J	PARTICIPANT	\N	PRESENT	0
801150	799024	14042U	PARTICIPANT	\N	PRESENT	0
801151	799024	19760E	PARTICIPANT	\N	PRESENT	0
801152	799024	20130U	PARTICIPANT	\N	PRESENT	0
801153	799024	21097R	PARTICIPANT	\N	PRESENT	0
801154	799024	21094N	PARTICIPANT	\N	PRESENT	0
801255	801254	20040T	PARTICIPANT	\N	PRESENT	0
801256	801254	17023S	PARTICIPANT	\N	PRESENT	0
801257	801254	19551W	PARTICIPANT	\N	PRESENT	0
801258	801254	20024T	PARTICIPANT	\N	PRESENT	0
801260	801259	17965H	PARTICIPANT	\N	PRESENT	0
801261	801259	20130U	PARTICIPANT	\N	PRESENT	0
801262	801259	21039F	PARTICIPANT	\N	PRESENT	0
804036	804035	18395Y	PARTICIPANT	\N	PRESENT	0
804038	804035	19709B	PARTICIPANT	\N	PRESENT	0
804046	804043	14215L	PARTICIPANT	\N	PRESENT	0
804048	804047	20098N	PARTICIPANT	\N	PRESENT	0
804051	804050	20098N	PARTICIPANT	\N	PRESENT	0
804283	804282	21071F	PARTICIPANT	\N	PRESENT	1
804520	803915	11048N	PARTICIPANT	\N	PRESENT	0
804521	803915	19703U	PARTICIPANT	\N	PRESENT	0
804522	803915	08028W	PARTICIPANT	\N	PRESENT	0
804523	803915	19507S	PARTICIPANT	\N	PRESENT	0
804524	803915	19563B	PARTICIPANT	\N	PRESENT	0
804525	803915	19421M	PARTICIPANT	\N	PRESENT	0
804526	803915	14259Y	PARTICIPANT	\N	PRESENT	0
804527	803915	21066J	PARTICIPANT	\N	PRESENT	0
804528	803915	19691J	PARTICIPANT	\N	PRESENT	0
804529	803915	19798U	PARTICIPANT	\N	PRESENT	0
804530	803915	14267Y	PARTICIPANT	\N	PRESENT	0
804531	803915	20032T	PARTICIPANT	\N	PRESENT	0
804532	803915	19826F	PARTICIPANT	\N	PRESENT	0
804533	803915	14026U	PARTICIPANT	\N	PRESENT	0
804534	803915	20068G	PARTICIPANT	\N	PRESENT	0
804535	803915	20026V	PARTICIPANT	\N	PRESENT	0
804536	803915	19367Y	PARTICIPANT	\N	PRESENT	0
804537	803915	14059S	PARTICIPANT	\N	PRESENT	0
804540	803915	14221J	PARTICIPANT	\N	PRESENT	0
804541	803915	21080G	PARTICIPANT	\N	PRESENT	0
804552	803915	08060W	PARTICIPANT	\N	PRESENT	0
804553	803915	19479G	PARTICIPANT	\N	PRESENT	0
804554	803915	19631V	PARTICIPANT	\N	PRESENT	0
804555	803915	21078N	PARTICIPANT	\N	PRESENT	0
804556	803915	19866P	PARTICIPANT	\N	PRESENT	0
804557	803915	14281W	PARTICIPANT	\N	PRESENT	0
804558	803915	21052C	PARTICIPANT	\N	PRESENT	0
804559	803915	21042A	PARTICIPANT	\N	PRESENT	0
804560	803915	17737W	PARTICIPANT	\N	PRESENT	0
804561	803915	20034V	PARTICIPANT	\N	PRESENT	0
804562	803915	20066E	PARTICIPANT	\N	PRESENT	0
804564	803915	14021P	PARTICIPANT	\N	PRESENT	0
804566	803915	20144B	PARTICIPANT	\N	PRESENT	0
800799	797798	21067K	PARTICIPANT	\N	PRESENT	0
800800	797798	14217N	PARTICIPANT	\N	PRESENT	0
804568	803915	20108W	PARTICIPANT	\N	PRESENT	0
804569	803915	01058X	PARTICIPANT	\N	PRESENT	0
804570	803915	14073Q	PARTICIPANT	\N	PRESENT	0
804571	803915	18083K	PARTICIPANT	\N	PRESENT	0
804572	803915	08010L	PARTICIPANT	\N	PRESENT	0
804573	804085	14053L	PARTICIPANT	\N	PRESENT	0
804574	804085	19749K	PARTICIPANT	\N	PRESENT	0
804575	804085	18231D	PARTICIPANT	\N	PRESENT	0
804576	804085	20074E	PARTICIPANT	\N	PRESENT	0
804577	803915	18193Q	PARTICIPANT	\N	PRESENT	0
804578	803915	20064C	PARTICIPANT	\N	PRESENT	0
804579	803915	19531S	PARTICIPANT	\N	PRESENT	0
804580	803915	20112S	PARTICIPANT	\N	PRESENT	0
804581	803915	21057H	PARTICIPANT	\N	PRESENT	0
804582	803915	21054E	PARTICIPANT	\N	PRESENT	0
804583	803915	14211G	PARTICIPANT	\N	PRESENT	0
804584	803915	14179A	PARTICIPANT	\N	PRESENT	0
804585	803915	20140W	PARTICIPANT	\N	PRESENT	0
804586	803915	21061D	PARTICIPANT	\N	PRESENT	0
804587	804085	19699S	PARTICIPANT	\N	PRESENT	0
804588	804085	19533U	PARTICIPANT	\N	PRESENT	0
804589	804085	20102Q	PARTICIPANT	\N	PRESENT	0
804590	804085	14229S	PARTICIPANT	\N	PRESENT	0
804591	804085	19954N	PARTICIPANT	\N	PRESENT	0
804592	804085	21089R	PARTICIPANT	\N	PRESENT	0
804593	804085	21091K	PARTICIPANT	\N	PRESENT	0
804594	804085	20124W	PARTICIPANT	\N	PRESENT	0
804595	804085	19593H	PARTICIPANT	\N	PRESENT	0
804596	804085	19611R	PARTICIPANT	\N	PRESENT	0
804597	804085	20142Y	PARTICIPANT	\N	PRESENT	0
804598	804085	20048C	PARTICIPANT	\N	PRESENT	0
804599	804085	19693L	PARTICIPANT	\N	PRESENT	0
804600	804085	20052X	PARTICIPANT	\N	PRESENT	0
804601	804085	14030Q	PARTICIPANT	\N	PRESENT	0
804602	804085	20264J	PARTICIPANT	\N	PRESENT	0
804603	804085	19735D	PARTICIPANT	\N	PRESENT	0
804604	804085	14109K	PARTICIPANT	\N	PRESENT	0
804605	804085	11043H	PARTICIPANT	\N	PRESENT	0
804606	804085	21077M	PARTICIPANT	\N	PRESENT	0
804607	804085	19621T	PARTICIPANT	\N	PRESENT	0
807302	807301	19251M	PARTICIPANT	\N	PRESENT	0
807304	807303	08009T	PARTICIPANT	\N	PRESENT	0
807305	807303	21084L	PARTICIPANT	\N	PRESENT	0
807306	807303	20042V	PARTICIPANT	\N	PRESENT	0
807307	807303	20248J	PARTICIPANT	\N	PRESENT	0
807308	807303	20038A	PARTICIPANT	\N	PRESENT	0
807309	807303	14169X	PARTICIPANT	\N	PRESENT	0
807310	807303	10015M	PARTICIPANT	\N	PRESENT	0
807311	807303	21059K	PARTICIPANT	\N	PRESENT	0
807312	807303	19713W	PARTICIPANT	\N	PRESENT	0
807313	807303	20084G	PARTICIPANT	\N	PRESENT	0
807315	807314	04033B	PARTICIPANT	\N	PRESENT	0
807317	807316	04033B	PARTICIPANT	\N	PRESENT	0
807318	807316	14021P	PARTICIPANT	\N	PRESENT	0
807319	807316	19669L	PARTICIPANT	\N	PRESENT	0
807320	807316	14055N	PARTICIPANT	\N	PRESENT	0
807322	807321	04042C	PARTICIPANT	\N	PRESENT	0
807323	807321	21086N	PARTICIPANT	\N	PRESENT	0
807324	807321	21084L	PARTICIPANT	\N	PRESENT	0
807325	807321	14055N	PARTICIPANT	\N	PRESENT	0
807829	807828	19711U	PARTICIPANT	\N	PRESENT	0
807830	807828	20024T	PARTICIPANT	\N	PRESENT	0
807831	807828	14026U	PARTICIPANT	\N	PRESENT	0
807832	807828	19699S	PARTICIPANT	\N	PRESENT	0
807833	807828	21081H	PARTICIPANT	\N	PRESENT	0
807834	807828	21061D	PARTICIPANT	\N	PRESENT	0
809350	809348	11043H	PARTICIPANT	\N	PRESENT	0
809940	809939	20110Q	PARTICIPANT	\N	PRESENT	0
809941	809939	14083S	PARTICIPANT	\N	PRESENT	0
810401	810387	20098N	PARTICIPANT	\N	PRESENT	0
810402	810387	21031W	PARTICIPANT	\N	PRESENT	0
810403	810387	21082J	PARTICIPANT	\N	PRESENT	0
810906	810905	04092N	PRESIDENT	0	PRESENT	0
810907	810905	14042U	PARTICIPANT	\N	PRESENT	0
810908	810905	21081H	PARTICIPANT	\N	PRESENT	0
811022	810905	19703U	PARTICIPANT	\N	PRESENT	0
811054	810905	19760E	PARTICIPANT	\N	PRESENT	0
811055	810905	14195A	PARTICIPANT	\N	PRESENT	0
813359	813358	19631V	PARTICIPANT	\N	PRESENT	0
813360	813358	14187A	PARTICIPANT	\N	PRESENT	0
813362	813361	20286Q	PARTICIPANT	\N	PRESENT	0
813363	813361	14187A	PARTICIPANT	\N	PRESENT	0
813365	813364	14187A	PARTICIPANT	\N	PRESENT	0
813366	813364	19631V	PARTICIPANT	\N	PRESENT	0
813367	813364	20286Q	PARTICIPANT	\N	PRESENT	0
821030	820961	19745F	PARTICIPANT	\N	PRESENT	0
821031	820961	17023S	PARTICIPANT	\N	PRESENT	0
821036	818988	20248J	PARTICIPANT	\N	PRESENT	0
821037	818988	20040T	PARTICIPANT	\N	PRESENT	0
821038	818988	19399H	PARTICIPANT	\N	PRESENT	0
821039	818988	19551W	PARTICIPANT	\N	PRESENT	0
821040	818988	20060X	PARTICIPANT	\N	PRESENT	0
821041	818988	21077M	PARTICIPANT	\N	PRESENT	0
821042	818988	19413M	PARTICIPANT	\N	PRESENT	0
821043	818988	19489J	PARTICIPANT	\N	PRESENT	0
821044	818988	20142Y	PARTICIPANT	\N	PRESENT	0
821045	818988	20070A	PARTICIPANT	\N	PRESENT	0
821046	818988	19563B	PARTICIPANT	\N	PRESENT	0
821047	818988	19687N	PARTICIPANT	\N	PRESENT	0
821049	818988	21051B	PARTICIPANT	\N	PRESENT	0
821050	818988	19629C	PARTICIPANT	\N	PRESENT	0
821051	818988	21071F	PARTICIPANT	\N	PRESENT	0
821052	818988	19621T	PARTICIPANT	\N	PRESENT	0
821053	819041	21036C	PARTICIPANT	\N	PRESENT	0
821054	819041	21030V	PARTICIPANT	\N	PRESENT	0
821055	819041	19565D	PARTICIPANT	\N	PRESENT	0
821056	819041	21073H	PARTICIPANT	\N	PRESENT	0
821057	819041	20072C	PARTICIPANT	\N	PRESENT	0
821058	819041	20042V	PARTICIPANT	\N	PRESENT	0
821059	819041	01058X	PARTICIPANT	\N	PRESENT	0
821060	819041	14001X	PARTICIPANT	\N	PRESENT	0
821061	819041	19695N	PARTICIPANT	\N	PRESENT	0
821062	819041	14191V	PARTICIPANT	\N	PRESENT	0
821063	819041	11115U	PARTICIPANT	\N	PRESENT	0
821064	819041	20252E	PARTICIPANT	\N	PRESENT	0
821065	819041	21067K	PARTICIPANT	\N	PRESENT	0
821066	819041	14193X	PRESIDENT	0	PRESENT	0
821067	819041	14179A	PARTICIPANT	\N	PRESENT	0
821068	819041	99004R	PARTICIPANT	\N	PRESENT	0
821069	819041	19745F	PARTICIPANT	\N	PRESENT	0
821070	819041	14249W	PARTICIPANT	\N	PRESENT	0
821071	819041	08047A	PARTICIPANT	\N	PRESENT	0
821072	819041	17023S	PARTICIPANT	\N	PRESENT	0
821073	819041	20128B	PARTICIPANT	\N	PRESENT	0
821074	819041	14037X	PARTICIPANT	\N	PRESENT	0
821075	819041	19531S	PARTICIPANT	\N	PRESENT	0
821076	818988	20032T	PARTICIPANT	\N	PRESENT	0
821077	819041	12028B	PARTICIPANT	\N	EXCUSE	0
821078	819041	17737W	PARTICIPANT	\N	EXCUSE	0
821079	819041	20064C	PARTICIPANT	\N	EXCUSE	0
821080	819041	21031W	PARTICIPANT	\N	EXCUSE	0
821081	820961	19782L	PARTICIPANT	\N	PRESENT	0
821083	820961	20054A	PARTICIPANT	\N	PRESENT	0
821084	819041	19782L	PARTICIPANT	\N	PRESENT	0
821085	819041	14357A	PARTICIPANT	\N	PRESENT	0
821086	819041	20104S	PARTICIPANT	\N	PRESENT	0
821087	819041	08015R	PARTICIPANT	\N	PRESENT	0
821088	819041	21050A	PARTICIPANT	\N	PRESENT	0
821089	819041	14329V	PARTICIPANT	\N	PRESENT	0
821090	819041	14038Y	PARTICIPANT	\N	PRESENT	0
821091	819041	14187A	PARTICIPANT	\N	PRESENT	0
821092	819041	20038A	PARTICIPANT	\N	PRESENT	0
821093	819041	11090Q	PARTICIPANT	\N	PRESENT	0
821094	819041	21093M	PARTICIPANT	\N	PRESENT	0
821095	819041	20054A	PARTICIPANT	\N	PRESENT	0
821096	819041	21034A	PARTICIPANT	\N	PRESENT	0
821097	818988	21046E	PARTICIPANT	\N	PRESENT	0
821098	818988	20116W	PARTICIPANT	\N	PRESENT	0
821099	820587	14257W	PRESIDENT	0	PRESENT	0
821100	820587	11070L	PARTICIPANT	\N	PRESENT	0
821101	820587	20092G	PARTICIPANT	\N	PRESENT	0
821102	820587	19533U	PARTICIPANT	\N	PRESENT	0
821103	820587	19619A	PARTICIPANT	\N	PRESENT	0
821104	820587	14033T	PARTICIPANT	\N	PRESENT	0
821105	820587	14221J	PARTICIPANT	\N	PRESENT	0
821106	820587	20120S	PARTICIPANT	\N	PRESENT	0
821107	818988	20102Q	PARTICIPANT	\N	PRESENT	0
821108	820587	20018V	PARTICIPANT	\N	PRESENT	0
821109	819041	14205J	PARTICIPANT	\N	PRESENT	0
821111	821110	19735D	PARTICIPANT	\N	PRESENT	0
821113	821112	20056C	PARTICIPANT	\N	PRESENT	0
821114	821112	14229S	PARTICIPANT	\N	PRESENT	0
821115	821112	20142Y	PARTICIPANT	\N	PRESENT	0
821116	820961	20144B	PARTICIPANT	\N	PRESENT	0
821117	818988	08073C	PARTICIPANT	\N	PRESENT	0
821118	818988	14030Q	PARTICIPANT	\N	PRESENT	0
821119	818988	14147R	PARTICIPANT	\N	PRESENT	0
821120	818988	19479G	PARTICIPANT	\N	PRESENT	0
821121	818988	19699S	PARTICIPANT	\N	PRESENT	0
821122	820961	14251Q	PARTICIPANT	\N	PRESENT	0
821123	819041	20144B	PARTICIPANT	\N	PRESENT	0
821124	819041	14251Q	PARTICIPANT	\N	PRESENT	0
821125	818988	21056G	PARTICIPANT	\N	PRESENT	0
821127	818988	21087P	PARTICIPANT	\N	PRESENT	0
821128	818988	04045F	PARTICIPANT	\N	PRESENT	0
821133	818988	04092N	PARTICIPANT	\N	PRESENT	0
821136	818988	21059K	PARTICIPANT	\N	PRESENT	0
821137	818988	20134Y	PARTICIPANT	\N	PRESENT	0
821303	820961	20286Q	PARTICIPANT	\N	EXCUSE	0
821316	820587	19575F	PARTICIPANT	\N	PRESENT	0
821306	820961	14207L	PARTICIPANT	\N	EXCUSE	0
821317	820587	20042V	PARTICIPANT	\N	EXCUSE	0
821318	820587	14207L	PARTICIPANT	\N	EXCUSE	0
821329	820961	21067K	PARTICIPANT	\N	PRESENT	0
821353	818989	14107H	PARTICIPANT	\N	PRESENT	0
821354	818989	20072C	PARTICIPANT	\N	PRESENT	0
821355	818989	20116W	PARTICIPANT	\N	PRESENT	0
821356	818989	14021P	PARTICIPANT	\N	PRESENT	0
821357	818989	19647E	PARTICIPANT	\N	PRESENT	0
821358	818989	21059K	PARTICIPANT	\N	PRESENT	0
821359	818989	08060W	PARTICIPANT	\N	PRESENT	0
821360	818989	20064C	PARTICIPANT	\N	PRESENT	0
821361	818989	21058J	PARTICIPANT	\N	PRESENT	0
821362	818989	18207D	PARTICIPANT	\N	PRESENT	0
821363	818989	20026V	PARTICIPANT	\N	PRESENT	0
821364	818989	19954N	PARTICIPANT	\N	PRESENT	0
821365	818989	18193Q	PARTICIPANT	\N	PRESENT	0
821366	818989	19533U	PARTICIPANT	\N	PRESENT	0
821367	818989	08012N	PARTICIPANT	\N	PRESENT	0
821368	818989	20090E	PARTICIPANT	\N	PRESENT	0
821369	818989	14215L	PARTICIPANT	\N	PRESENT	0
821370	818989	21089R	PARTICIPANT	\N	PRESENT	0
821371	818989	19673G	PARTICIPANT	\N	PRESENT	0
821372	818989	21077M	PARTICIPANT	\N	PRESENT	0
821373	818989	20058E	PARTICIPANT	\N	PRESENT	0
821374	818989	18231D	PARTICIPANT	\N	PRESENT	0
821375	818989	11043H	PARTICIPANT	\N	PRESENT	0
821376	818989	19413M	PARTICIPANT	\N	PRESENT	0
821377	818989	19611R	PARTICIPANT	\N	PRESENT	0
821378	818989	14121F	PARTICIPANT	\N	PRESENT	0
821379	818989	14053L	PARTICIPANT	\N	PRESENT	0
821380	818989	21066J	PARTICIPANT	\N	PRESENT	0
821381	818989	20052X	PARTICIPANT	\N	PRESENT	0
821382	818989	14030Q	PARTICIPANT	\N	PRESENT	0
821383	818989	20042V	PARTICIPANT	\N	PRESENT	0
821384	818989	01034P	PARTICIPANT	\N	PRESENT	0
821385	818989	14229S	PARTICIPANT	\N	PRESENT	0
821386	818989	21046E	PARTICIPANT	\N	PRESENT	0
821387	818989	19301E	PARTICIPANT	\N	PRESENT	0
821388	818989	19551W	PARTICIPANT	\N	PRESENT	0
821389	818989	17779H	PARTICIPANT	\N	PRESENT	0
821390	818989	17965H	PARTICIPANT	\N	PRESENT	0
821391	818989	20070A	PARTICIPANT	\N	PRESENT	0
821392	818989	20060X	PARTICIPANT	\N	PRESENT	0
821393	818989	19479G	PARTICIPANT	\N	PRESENT	0
821394	818989	19691J	PARTICIPANT	\N	PRESENT	0
821395	818989	14189C	PARTICIPANT	\N	PRESENT	0
821397	818989	19782L	PARTICIPANT	\N	PRESENT	0
821398	818989	21043B	PARTICIPANT	\N	PRESENT	0
821400	818989	19447X	PARTICIPANT	\N	PRESENT	0
821401	818989	14147R	PARTICIPANT	\N	PRESENT	0
821402	818989	19619A	PARTICIPANT	\N	PRESENT	0
821403	818989	21055F	PARTICIPANT	\N	PRESENT	0
821404	818989	14213J	PARTICIPANT	\N	PRESENT	0
821405	818989	19621T	PARTICIPANT	\N	PRESENT	0
821415	818989	19798U	PARTICIPANT	\N	PRESENT	0
821416	818989	14026U	PARTICIPANT	\N	PRESENT	0
821417	818989	14217N	PARTICIPANT	\N	PRESENT	0
821423	818989	19701S	PARTICIPANT	\N	PRESENT	0
821424	818989	17023S	PARTICIPANT	\N	PRESENT	0
804337	804006	14111D	PARTICIPANT	\N	PRESENT	0
804338	804006	14189C	PARTICIPANT	\N	PRESENT	0
804339	804006	20074E	PARTICIPANT	\N	PRESENT	0
804340	804006	10015M	PARTICIPANT	\N	PRESENT	0
804341	804006	21057H	PARTICIPANT	\N	PRESENT	0
804342	804006	04047H	PRESIDENT	0	PRESENT	0
804343	804006	19673G	PARTICIPANT	\N	PRESENT	0
804344	804006	14231L	PARTICIPANT	\N	PRESENT	0
804345	804006	19447X	PARTICIPANT	\N	PRESENT	0
804346	804006	21043B	PARTICIPANT	\N	PRESENT	0
804347	804006	21044C	PARTICIPANT	\N	PRESENT	0
804348	804006	19489J	PARTICIPANT	\N	PRESENT	0
804349	804006	21056G	PARTICIPANT	\N	PRESENT	0
804350	804006	14215L	PARTICIPANT	\N	PRESENT	0
804351	804006	21095P	PARTICIPANT	\N	PRESENT	0
804352	804006	20022R	PARTICIPANT	\N	PRESENT	0
804353	804006	11072N	PARTICIPANT	\N	PRESENT	0
804354	804006	14053L	PARTICIPANT	\N	PRESENT	0
804355	804006	20036X	PARTICIPANT	\N	PRESENT	0
804356	804006	20110Q	PARTICIPANT	\N	PRESENT	0
804357	804006	05008E	PARTICIPANT	\N	PRESENT	0
804358	804006	14151M	PARTICIPANT	\N	PRESENT	0
804361	804006	11056N	PARTICIPANT	\N	PRESENT	0
804362	804006	14259Y	PARTICIPANT	\N	PRESENT	0
804363	804006	20098N	PARTICIPANT	\N	PRESENT	0
804366	804006	14069U	PARTICIPANT	\N	PRESENT	0
804367	804006	19729F	PARTICIPANT	\N	EXCUSE	0
804368	804006	19585H	PARTICIPANT	\N	EXCUSE	0
804369	804006	20108W	PARTICIPANT	\N	PRESENT	0
804379	804006	08018U	PARTICIPANT	\N	PRESENT	0
810834	810036	21071F	PARTICIPANT	\N	PRESENT	0
810835	810036	19723Y	PARTICIPANT	\N	PRESENT	0
813369	813368	19711U	PARTICIPANT	\N	PRESENT	0
813370	813368	14255U	PARTICIPANT	\N	PRESENT	0
813371	813368	21081H	PARTICIPANT	\N	PRESENT	0
813372	813368	21061D	PARTICIPANT	\N	PRESENT	0
813373	813368	20134Y	PARTICIPANT	\N	PRESENT	0
813374	813368	20132W	PARTICIPANT	\N	PRESENT	0
819118	818981	14111D	PARTICIPANT	\N	PRESENT	0
810088	807229	11090Q	PARTICIPANT	\N	PRESENT	0
810102	807229	19335Q	PARTICIPANT	\N	PRESENT	0
819119	819117	21082J	PARTICIPANT	\N	PRESENT	0
819120	819117	20248J	PARTICIPANT	\N	PRESENT	0
819121	819117	21031W	PARTICIPANT	\N	PRESENT	0
819122	819117	14031R	PARTICIPANT	\N	PRESENT	0
819123	819117	20038A	PARTICIPANT	\N	PRESENT	0
819124	819117	19413M	PARTICIPANT	\N	PRESENT	0
819125	819117	21090J	PARTICIPANT	\N	PRESENT	0
819126	819117	99004R	PRESIDENT	0	PRESENT	0
819127	819117	21093M	PARTICIPANT	\N	PRESENT	0
819128	819117	21084L	PARTICIPANT	\N	EXCUSE	0
819129	819117	17023S	PARTICIPANT	\N	EXCUSE	0
819130	818981	20030R	PARTICIPANT	\N	PRESENT	0
819131	818981	19701S	PARTICIPANT	\N	PRESENT	0
819132	818981	19735D	PARTICIPANT	\N	PRESENT	0
819133	818981	19413M	PARTICIPANT	\N	PRESENT	0
819134	818981	21066J	PARTICIPANT	\N	PRESENT	0
819135	818981	95041E	PARTICIPANT	\N	PRESENT	0
819136	818981	21043B	PARTICIPANT	\N	PRESENT	0
819137	818981	20118Y	PARTICIPANT	\N	PRESENT	0
819138	818981	19723Y	PARTICIPANT	\N	PRESENT	0
819139	818981	21065H	PARTICIPANT	\N	PRESENT	0
819140	818981	14083S	PARTICIPANT	\N	PRESENT	0
819141	818981	21070E	PARTICIPANT	\N	PRESENT	0
819142	818981	20024T	PARTICIPANT	\N	PRESENT	0
819143	818981	11115U	PARTICIPANT	\N	PRESENT	0
819144	818981	19331L	PARTICIPANT	\N	PRESENT	0
819145	818981	20138D	PARTICIPANT	\N	PRESENT	0
819146	818981	20120S	PARTICIPANT	\N	PRESENT	0
819147	818981	21050A	PARTICIPANT	\N	PRESENT	0
819148	818981	19399H	PARTICIPANT	\N	PRESENT	0
819149	818981	21036C	PARTICIPANT	\N	PRESENT	0
819152	818981	19685L	PARTICIPANT	\N	PRESENT	0
819160	818981	19573D	PARTICIPANT	\N	PRESENT	0
819161	818981	12028B	PARTICIPANT	\N	PRESENT	0
819162	818981	19679N	PARTICIPANT	\N	PRESENT	0
819163	818981	19301E	PARTICIPANT	\N	PRESENT	0
819164	818981	19367Y	PARTICIPANT	\N	PRESENT	0
819165	818981	14147R	PARTICIPANT	\N	PRESENT	0
819166	818981	07004J	PARTICIPANT	\N	PRESENT	0
819167	818981	21095P	PARTICIPANT	\N	PRESENT	0
819182	818981	19695N	PARTICIPANT	\N	PRESENT	0
819183	818981	14030Q	PARTICIPANT	\N	PRESENT	0
819184	818981	19531S	PARTICIPANT	\N	PRESENT	0
819189	818981	20018V	PARTICIPANT	\N	PRESENT	0
819190	818981	08060W	PARTICIPANT	\N	PRESENT	0
819191	818981	19565D	PARTICIPANT	\N	PRESENT	0
819192	818981	20090E	PARTICIPANT	\N	PRESENT	0
819193	818981	20126Y	PARTICIPANT	\N	PRESENT	0
819194	818981	21097R	PARTICIPANT	\N	PRESENT	0
819195	818981	20286Q	PARTICIPANT	\N	PRESENT	0
819196	818981	21045D	PARTICIPANT	\N	PRESENT	0
819197	818981	19421M	PARTICIPANT	\N	PRESENT	0
819205	818981	20096L	PARTICIPANT	\N	PRESENT	0
819206	818981	20084G	PARTICIPANT	\N	PRESENT	0
819207	818981	20056C	PARTICIPANT	\N	PRESENT	0
819208	818981	11045K	PARTICIPANT	\N	PRESENT	0
819209	818981	20142Y	PARTICIPANT	\N	PRESENT	0
819212	818981	14107H	PARTICIPANT	\N	PRESENT	0
819229	818981	14179A	PARTICIPANT	\N	PRESENT	0
819272	818982	21047F	PARTICIPANT	\N	PRESENT	0
819275	818982	20136B	PARTICIPANT	\N	PRESENT	0
819276	818982	14219Q	PARTICIPANT	\N	PRESENT	0
819277	818982	14111D	PARTICIPANT	\N	PRESENT	0
819240	818982	14259Y	PARTICIPANT	\N	PRESENT	0
819241	818915	21082J	PARTICIPANT	\N	PRESENT	0
819242	818915	21029D	PARTICIPANT	\N	PRESENT	0
819243	818915	19701S	PARTICIPANT	\N	PRESENT	0
819244	818915	19820Y	PARTICIPANT	\N	PRESENT	0
819245	818915	14219Q	PRESIDENT	0	PRESENT	0
819246	818915	21060C	PARTICIPANT	\N	PRESENT	0
819247	818915	21061D	PARTICIPANT	\N	PRESENT	0
819248	818915	21062E	PARTICIPANT	\N	PRESENT	0
819249	818915	18083K	PARTICIPANT	\N	PRESENT	0
819250	818915	21084L	PARTICIPANT	\N	PRESENT	0
819251	818915	19551W	PARTICIPANT	\N	PRESENT	0
819252	818915	14237S	PARTICIPANT	\N	PRESENT	0
819253	818915	20100N	PARTICIPANT	\N	PRESENT	0
819254	818915	20106U	PARTICIPANT	\N	PRESENT	0
819255	818915	20118Y	PARTICIPANT	\N	PRESENT	0
819256	818915	15197G	PARTICIPANT	\N	PRESENT	0
819257	818915	21080G	PARTICIPANT	\N	PRESENT	0
819258	818915	20020P	PARTICIPANT	\N	PRESENT	0
819259	818915	19681G	PARTICIPANT	\N	PRESENT	0
819260	818915	21051B	PARTICIPANT	\N	PRESENT	0
819261	818915	20136B	PARTICIPANT	\N	PRESENT	0
819262	818915	14031R	PARTICIPANT	\N	PRESENT	0
819263	818915	19251M	PARTICIPANT	\N	PRESENT	0
819264	818915	21047F	PARTICIPANT	\N	PRESENT	0
819265	818915	21070E	PARTICIPANT	\N	PRESENT	0
819278	818982	11085T	PARTICIPANT	\N	PRESENT	0
819279	818982	99004R	PARTICIPANT	\N	PRESENT	0
819280	818982	21060C	PARTICIPANT	\N	PRESENT	0
819281	818982	19760E	PARTICIPANT	\N	PRESENT	0
819282	818982	21084L	PARTICIPANT	\N	PRESENT	0
819283	818982	19251M	PARTICIPANT	\N	PRESENT	0
819284	818982	19551W	PARTICIPANT	\N	PRESENT	0
819285	818982	08028W	PARTICIPANT	\N	PRESENT	0
819286	818982	21051B	PARTICIPANT	\N	PRESENT	0
819287	818982	08060W	PARTICIPANT	\N	PRESENT	0
819288	818982	21080G	PARTICIPANT	\N	PRESENT	0
819289	818982	21066J	PARTICIPANT	\N	PRESENT	0
819290	818982	14107H	PARTICIPANT	\N	PRESENT	0
819291	818982	21040X	PARTICIPANT	\N	PRESENT	0
819292	818982	20076G	PARTICIPANT	\N	PRESENT	0
819293	818982	20128B	PARTICIPANT	\N	PRESENT	0
819294	818982	19331L	PARTICIPANT	\N	PRESENT	0
819295	818982	21061D	PARTICIPANT	\N	PRESENT	0
819296	818982	14030Q	PARTICIPANT	\N	PRESENT	0
819297	818982	19735D	PARTICIPANT	\N	PRESENT	0
819298	818982	19573D	PARTICIPANT	\N	PRESENT	0
819299	818982	20102Q	PARTICIPANT	\N	PRESENT	0
819300	818982	20144B	PARTICIPANT	\N	PRESENT	0
819301	818982	14223L	PARTICIPANT	\N	PRESENT	0
819302	818982	20100N	PARTICIPANT	\N	PRESENT	0
819303	818982	20090E	PARTICIPANT	\N	PRESENT	0
819304	818982	21062E	PARTICIPANT	\N	PRESENT	0
819305	818982	20028X	PARTICIPANT	\N	PRESENT	0
819306	818982	19507S	PARTICIPANT	\N	PRESENT	0
819307	818982	19820Y	PARTICIPANT	\N	PRESENT	0
819308	818982	14059S	PARTICIPANT	\N	PRESENT	0
801269	801268	20076G	PARTICIPANT	\N	PRESENT	0
801270	801268	21084L	PARTICIPANT	\N	PRESENT	0
801271	801268	14195A	PARTICIPANT	\N	PRESENT	0
801272	801268	20038A	PARTICIPANT	\N	PRESENT	0
801273	801268	14033T	PARTICIPANT	\N	PRESENT	0
801274	801268	20066E	PARTICIPANT	\N	PRESENT	0
801275	801268	20126Y	PARTICIPANT	\N	PRESENT	0
801276	801268	14205J	PARTICIPANT	\N	PRESENT	0
801277	801268	14059S	PARTICIPANT	\N	PRESENT	0
801278	801268	20050V	PARTICIPANT	\N	PRESENT	0
801279	801268	21047F	PARTICIPANT	\N	PRESENT	0
801280	801268	20082E	PARTICIPANT	\N	PRESENT	0
801281	801268	21079P	PARTICIPANT	\N	PRESENT	0
801282	801268	19713W	PARTICIPANT	\N	PRESENT	0
801283	801268	21082J	PARTICIPANT	\N	PRESENT	0
801286	801284	21071F	PARTICIPANT	\N	PRESENT	0
813920	813243	19719D	PARTICIPANT	\N	PRESENT	0
801289	801287	20082E	PARTICIPANT	\N	PRESENT	0
801290	801287	19383Y	PARTICIPANT	\N	PRESENT	0
801291	801287	21066J	PARTICIPANT	\N	PRESENT	0
813921	813243	19111A	PARTICIPANT	\N	PRESENT	0
813922	813243	19553Y	PARTICIPANT	\N	PRESENT	0
813923	813243	14089Y	PARTICIPANT	\N	PRESENT	0
813924	813243	20144B	PARTICIPANT	\N	PRESENT	0
813925	813243	19479G	PARTICIPANT	\N	PRESENT	0
813926	813243	21054E	PARTICIPANT	\N	PRESENT	0
813927	813243	11043H	PARTICIPANT	\N	PRESENT	0
813928	813243	01058X	PARTICIPANT	\N	PRESENT	0
813929	813243	19575F	PARTICIPANT	\N	PRESENT	0
805998	803919	20054A	PARTICIPANT	\N	PRESENT	0
805999	803919	19749K	PARTICIPANT	\N	PRESENT	0
806314	803920	14229S	PARTICIPANT	\N	PRESENT	0
806315	803920	19593H	PARTICIPANT	\N	PRESENT	0
806316	803920	21087P	PARTICIPANT	\N	PRESENT	0
806317	803920	14195A	PARTICIPANT	\N	PRESENT	0
806320	803920	21059K	PARTICIPANT	\N	PRESENT	0
806321	803920	21089R	PARTICIPANT	\N	PRESENT	0
806322	803920	14121F	PARTICIPANT	\N	PRESENT	0
806324	803920	20264J	PARTICIPANT	\N	PRESENT	0
806326	803920	19693L	PARTICIPANT	\N	PRESENT	0
806327	803920	21076L	PARTICIPANT	\N	PRESENT	0
806330	803920	14207L	PARTICIPANT	\N	PRESENT	0
806333	803920	21041Y	PARTICIPANT	\N	PRESENT	0
806335	803920	19629C	PARTICIPANT	\N	PRESENT	0
806343	803920	19533U	PARTICIPANT	\N	PRESENT	0
806346	803920	19711U	PARTICIPANT	\N	PRESENT	0
806347	803920	20172F	PARTICIPANT	\N	PRESENT	0
806348	803920	11043H	PARTICIPANT	\N	PRESENT	0
806349	803920	14089Y	PARTICIPANT	\N	PRESENT	0
806350	803920	20026V	PARTICIPANT	\N	PRESENT	0
806357	803920	19866P	PARTICIPANT	\N	PRESENT	0
806358	803920	20048C	PARTICIPANT	\N	PRESENT	0
806360	803920	19735D	PARTICIPANT	\N	PRESENT	0
806362	803920	20102Q	PARTICIPANT	\N	PRESENT	0
806363	803920	19697Q	PARTICIPANT	\N	PRESENT	0
806365	803920	14069U	PARTICIPANT	\N	PRESENT	0
806366	803920	14030Q	PARTICIPANT	\N	PRESENT	0
806367	803920	19699S	PARTICIPANT	\N	PRESENT	0
806368	803920	14123H	PARTICIPANT	\N	PRESENT	0
806369	803920	19553Y	PARTICIPANT	\N	PRESENT	0
806370	803920	19621T	PARTICIPANT	\N	PRESENT	0
806373	803920	20034V	PARTICIPANT	\N	PRESENT	0
806374	803920	04033B	PARTICIPANT	\N	PRESENT	0
806377	803920	20032T	PARTICIPANT	\N	PRESENT	0
806378	803920	20132W	PARTICIPANT	\N	PRESENT	0
806381	803920	21069M	PARTICIPANT	\N	PRESENT	0
806385	803920	19782L	PARTICIPANT	\N	PRESENT	0
806389	803920	10015M	PARTICIPANT	\N	PRESENT	0
806462	803920	18395Y	PARTICIPANT	\N	PRESENT	0
806463	803920	19631V	PARTICIPANT	\N	PRESENT	0
806464	803920	14191V	PARTICIPANT	\N	PRESENT	0
806465	803920	21049H	PARTICIPANT	\N	PRESENT	0
806477	803920	20022R	PARTICIPANT	\N	PRESENT	0
806479	803920	21091K	PARTICIPANT	\N	PRESENT	0
806508	803920	14109K	PARTICIPANT	\N	PRESENT	0
806514	803920	14147R	PARTICIPANT	\N	PRESENT	0
806532	803920	20124W	PARTICIPANT	\N	PRESENT	0
806533	803920	21063F	PARTICIPANT	\N	PRESENT	0
806534	803920	19649G	PARTICIPANT	\N	PRESENT	0
806535	803920	20066E	PARTICIPANT	\N	PRESENT	0
806536	803920	21057H	PARTICIPANT	\N	PRESENT	0
806537	803920	21088Q	PARTICIPANT	\N	PRESENT	0
809911	794007	14147R	PARTICIPANT	\N	EXCUSE	0
809912	794007	21077M	PARTICIPANT	\N	EXCUSE	0
809913	794007	19798U	PARTICIPANT	\N	EXCUSE	0
809914	794007	20130U	PARTICIPANT	\N	EXCUSE	0
809915	794007	14189C	PARTICIPANT	\N	EXCUSE	0
809916	794007	21042A	PARTICIPANT	\N	EXCUSE	0
809917	794007	21091K	PARTICIPANT	\N	PRESENT	0
809918	794007	11045K	PARTICIPANT	\N	EXCUSE	0
809919	794007	21061D	PARTICIPANT	\N	PRESENT	0
809920	794007	19749K	PRESIDENT	0	PRESENT	0
809921	794007	07029T	PARTICIPANT	\N	EXCUSE	0
809922	794007	14030Q	PRESIDENT	1	PRESENT	0
809923	794007	20046A	PARTICIPANT	\N	PRESENT	0
809924	794007	21038E	PARTICIPANT	\N	PRESENT	0
809925	794007	20180F	PARTICIPANT	\N	PRESENT	0
809937	794007	21094N	PARTICIPANT	\N	EXCUSE	0
813930	813243	19711U	PARTICIPANT	\N	PRESENT	0
813931	813243	20032T	PARTICIPANT	\N	PRESENT	0
813933	813243	20024T	PARTICIPANT	\N	PRESENT	0
813934	813243	14211G	PARTICIPANT	\N	PRESENT	0
813935	813243	21043B	PARTICIPANT	\N	PRESENT	0
813936	813243	17737W	PARTICIPANT	\N	PRESENT	0
813937	813243	14037X	PARTICIPANT	\N	PRESENT	0
813938	813243	14223L	PARTICIPANT	\N	PRESENT	0
813939	813243	08061X	PARTICIPANT	\N	PRESENT	0
813940	813243	14215L	PARTICIPANT	\N	PRESENT	0
813941	813243	19301E	PARTICIPANT	\N	PRESENT	0
813942	813243	10015M	PARTICIPANT	\N	PRESENT	0
813943	813243	20128B	PARTICIPANT	\N	PRESENT	0
813944	813243	14231L	PARTICIPANT	\N	PRESENT	0
813945	813243	01034P	PARTICIPANT	\N	PRESENT	0
813946	813243	14249W	PARTICIPANT	\N	PRESENT	0
813947	813243	19735D	PARTICIPANT	\N	PRESENT	0
813948	813243	21070E	PARTICIPANT	\N	PRESENT	0
813949	813243	19399H	PARTICIPANT	\N	PRESENT	0
813950	813243	14275Y	PARTICIPANT	\N	PRESENT	0
813951	813243	19721W	PARTICIPANT	\N	PRESENT	0
813952	813243	21076L	PARTICIPANT	\N	PRESENT	0
813953	813243	21087P	PARTICIPANT	\N	PRESENT	0
813954	813243	20134Y	PARTICIPANT	\N	PRESENT	0
813955	813243	21092L	PARTICIPANT	\N	PRESENT	0
813956	813243	05012A	PARTICIPANT	\N	PRESENT	0
813957	813243	21073H	PARTICIPANT	\N	PRESENT	0
813958	813243	19629C	PARTICIPANT	\N	PRESENT	0
813959	813243	12028B	PARTICIPANT	\N	PRESENT	0
813960	813243	14207L	PARTICIPANT	\N	PRESENT	0
813961	813243	18193Q	PARTICIPANT	\N	PRESENT	0
813962	813243	20072C	PARTICIPANT	\N	PRESENT	0
813963	813243	19649G	PARTICIPANT	\N	PRESENT	0
813964	813243	19725B	PARTICIPANT	\N	PRESENT	0
813965	813243	21066J	PARTICIPANT	\N	PRESENT	0
813966	813243	14097Y	PARTICIPANT	\N	PRESENT	0
813967	813243	19697Q	PARTICIPANT	\N	PRESENT	0
813968	813243	19489J	PARTICIPANT	\N	PRESENT	0
813969	813243	14251Q	PARTICIPANT	\N	PRESENT	0
813970	813243	21075K	PARTICIPANT	\N	PRESENT	0
813971	813243	19565D	PARTICIPANT	\N	PRESENT	0
813972	813243	21088Q	PARTICIPANT	\N	PRESENT	0
813973	813243	20108W	PARTICIPANT	\N	PRESENT	0
813974	813243	20082E	PARTICIPANT	\N	PRESENT	0
813975	813243	21096Q	PARTICIPANT	\N	PRESENT	0
813976	813243	21046E	PARTICIPANT	\N	PRESENT	0
813977	813243	14221J	PARTICIPANT	\N	PRESENT	0
813978	813243	21057H	PARTICIPANT	\N	PRESENT	0
813979	813243	14195A	PARTICIPANT	\N	PRESENT	0
813980	813243	21060C	PARTICIPANT	\N	PRESENT	0
813981	813243	19631V	PARTICIPANT	\N	PRESENT	0
813982	813243	08028W	PARTICIPANT	\N	PRESENT	0
813983	813243	20266L	PARTICIPANT	\N	PRESENT	0
813984	813243	20114U	PARTICIPANT	\N	PRESENT	0
813985	813243	20026V	PARTICIPANT	\N	PRESENT	0
813986	813243	20264J	PARTICIPANT	\N	PRESENT	0
813987	813243	21051B	PARTICIPANT	\N	PRESENT	0
813988	813243	20142Y	PARTICIPANT	\N	PRESENT	0
813989	813243	14021P	PARTICIPANT	\N	PRESENT	0
813990	813243	21094N	PARTICIPANT	\N	PRESENT	0
813991	813243	21079P	PARTICIPANT	\N	PRESENT	0
812647	812646	19749K	PARTICIPANT	\N	PRESENT	0
814033	813243	14133K	PARTICIPANT	\N	PRESENT	0
814034	813243	21084L	PARTICIPANT	\N	PRESENT	0
814035	813243	21050A	PARTICIPANT	\N	PRESENT	0
814038	813243	19758L	PARTICIPANT	\N	PRESENT	0
814040	813243	20090E	PARTICIPANT	\N	PRESENT	0
814041	813243	14053L	PARTICIPANT	\N	PRESENT	0
814042	813243	21090J	PARTICIPANT	\N	PRESENT	0
814043	813243	21045D	PARTICIPANT	\N	PRESENT	0
814045	813243	19057M	PARTICIPANT	\N	PRESENT	0
814046	813243	14038Y	PARTICIPANT	\N	PRESENT	0
814050	813243	18083K	PARTICIPANT	\N	PRESENT	0
814052	813243	11056N	PARTICIPANT	\N	PRESENT	0
814053	813243	14259Y	PARTICIPANT	\N	PRESENT	0
814056	813243	14217N	PARTICIPANT	\N	PRESENT	0
814057	813243	19507S	PARTICIPANT	\N	PRESENT	0
814063	813243	99004R	PARTICIPANT	\N	PRESENT	0
814065	813243	14073Q	PARTICIPANT	\N	PRESENT	0
814067	813243	14059S	PARTICIPANT	\N	PRESENT	0
814068	813243	20252E	PARTICIPANT	\N	PRESENT	0
818903	816932	19798U	PARTICIPANT	\N	PRESENT	0
818904	816932	18193Q	PARTICIPANT	\N	PRESENT	0
818905	816932	21049H	PARTICIPANT	\N	PRESENT	0
818906	816926	19798U	PARTICIPANT	\N	PRESENT	0
818907	816926	18193Q	PARTICIPANT	\N	PRESENT	0
818908	816926	21049H	PARTICIPANT	\N	PRESENT	0
818909	816741	14042U	PARTICIPANT	\N	PRESENT	0
818910	816741	20130U	PARTICIPANT	\N	PRESENT	0
818911	816740	14042U	PARTICIPANT	\N	PRESENT	0
818912	816740	20130U	PARTICIPANT	\N	PRESENT	0
818913	816739	14042U	PARTICIPANT	\N	PRESENT	0
818914	816739	20130U	PARTICIPANT	\N	PRESENT	0
819064	819063	14255U	PARTICIPANT	\N	PRESENT	0
819065	819063	21041Y	PARTICIPANT	\N	PRESENT	0
819066	819063	19725B	PARTICIPANT	\N	PRESENT	0
819067	819063	19421M	PARTICIPANT	\N	PRESENT	0
819101	819096	19679N	PARTICIPANT	\N	PRESENT	0
819102	819097	19679N	PARTICIPANT	\N	PRESENT	0
819103	819098	19679N	PARTICIPANT	\N	PRESENT	0
819104	819099	21046E	PARTICIPANT	\N	PRESENT	0
819105	819099	19679N	PARTICIPANT	\N	PRESENT	0
819106	819100	21046E	PARTICIPANT	\N	PRESENT	0
819107	819100	19679N	PARTICIPANT	\N	PRESENT	0
821484	818990	21082J	PARTICIPANT	\N	PRESENT	0
821485	818990	08060W	PARTICIPANT	\N	PRESENT	0
821486	818990	21034A	PARTICIPANT	\N	PRESENT	0
821487	818990	20102Q	PARTICIPANT	\N	PRESENT	0
821488	818990	07029T	PARTICIPANT	\N	PRESENT	0
821489	818990	19782L	PARTICIPANT	\N	PRESENT	0
821490	818990	20116W	PARTICIPANT	\N	PRESENT	0
821491	818990	20134Y	PARTICIPANT	\N	PRESENT	0
821492	818990	20050V	PARTICIPANT	\N	PRESENT	0
821493	818990	20072C	PARTICIPANT	\N	PRESENT	0
821494	818990	14241N	PARTICIPANT	\N	PRESENT	0
821495	818990	19619A	PARTICIPANT	\N	PRESENT	0
821496	818990	01034P	PARTICIPANT	\N	PRESENT	0
821497	818990	19111A	PARTICIPANT	\N	PRESENT	0
821498	818990	20086J	PARTICIPANT	\N	PRESENT	0
821499	818990	21094N	PARTICIPANT	\N	PRESENT	0
821500	818990	20062A	PARTICIPANT	\N	PRESENT	0
821501	818990	14033T	PARTICIPANT	\N	PRESENT	0
821502	818990	19629C	PARTICIPANT	\N	PRESENT	0
821503	818990	20092G	PARTICIPANT	\N	PRESENT	0
821504	818990	20142Y	PARTICIPANT	\N	PRESENT	0
821505	818990	20110Q	PARTICIPANT	\N	PRESENT	0
821506	818990	19347U	PARTICIPANT	\N	PRESENT	0
821507	818990	21066J	PARTICIPANT	\N	PRESENT	0
821508	818990	19647E	PARTICIPANT	\N	PRESENT	0
821509	818990	11065P	PARTICIPANT	\N	PRESENT	0
821510	818990	17023S	PARTICIPANT	\N	PRESENT	0
821571	818991	19479G	PARTICIPANT	\N	PRESENT	0
821587	819030	14026U	PARTICIPANT	\N	PRESENT	0
821588	819030	18207D	PARTICIPANT	\N	PRESENT	0
821589	819030	17737W	PARTICIPANT	\N	PRESENT	0
821590	818991	21034A	PARTICIPANT	\N	PRESENT	0
821591	818991	21061D	PARTICIPANT	\N	PRESENT	0
821592	818991	08060W	PARTICIPANT	\N	PRESENT	0
821593	818991	20146D	PARTICIPANT	\N	PRESENT	0
821594	818991	18083K	PARTICIPANT	\N	PRESENT	0
821595	818991	19629C	PARTICIPANT	\N	PRESENT	0
821596	818991	19866P	PARTICIPANT	\N	PRESENT	0
821597	818991	21066J	PARTICIPANT	\N	PRESENT	0
821598	818991	20118Y	PARTICIPANT	\N	PRESENT	0
821599	818991	14107H	PARTICIPANT	\N	PRESENT	0
821600	818991	14219Q	PARTICIPANT	\N	PRESENT	0
821601	818991	20132W	PARTICIPANT	\N	PRESENT	0
821602	818991	14357A	PARTICIPANT	\N	PRESENT	0
821603	818991	20072C	PARTICIPANT	\N	PRESENT	0
821604	818991	14207L	PARTICIPANT	\N	PRESENT	0
821605	818991	21083K	PARTICIPANT	\N	PRESENT	0
821606	818991	20070A	PARTICIPANT	\N	PRESENT	0
821607	818991	21042A	PARTICIPANT	\N	PRESENT	0
821608	818991	11065P	PARTICIPANT	\N	PRESENT	0
821609	818991	21040X	PARTICIPANT	\N	PRESENT	0
821482	818990	19593H	PARTICIPANT	\N	PRESENT	0
821483	818990	20100N	PARTICIPANT	\N	PRESENT	0
821610	818991	14241N	PARTICIPANT	\N	PRESENT	0
821611	818991	07029T	PARTICIPANT	\N	PRESENT	0
821612	818991	20116W	PARTICIPANT	\N	PRESENT	0
821613	818991	21075K	PARTICIPANT	\N	PRESENT	0
821614	818991	21068L	PARTICIPANT	\N	PRESENT	0
821616	821615	19701S	PARTICIPANT	\N	PRESENT	0
821617	821615	17737W	PARTICIPANT	\N	PRESENT	0
821618	821615	20120S	PARTICIPANT	\N	PRESENT	0
821619	821615	19725B	PARTICIPANT	\N	PRESENT	0
821620	821615	14031R	PARTICIPANT	\N	PRESENT	0
821621	821615	14001X	PARTICIPANT	\N	PRESENT	0
821622	821615	20064C	PARTICIPANT	\N	PRESENT	0
821624	818991	14215L	PARTICIPANT	\N	PRESENT	0
821625	821615	04092N	PARTICIPANT	\N	PRESENT	0
821626	818991	20048C	PARTICIPANT	\N	PRESENT	0
821627	818991	20136B	PARTICIPANT	\N	PRESENT	0
821628	818991	21041Y	PARTICIPANT	\N	PRESENT	0
821638	818991	20032T	PARTICIPANT	\N	PRESENT	0
821642	818991	21046E	PARTICIPANT	\N	PRESENT	0
821644	818991	20090E	PARTICIPANT	\N	PRESENT	0
821651	818991	21070E	PARTICIPANT	\N	PRESENT	0
821652	818991	14189C	PARTICIPANT	\N	PRESENT	0
821653	818991	19447X	PARTICIPANT	\N	PRESENT	0
821654	818991	14097Y	PARTICIPANT	\N	PRESENT	0
821655	818991	14033T	PARTICIPANT	\N	PRESENT	0
821656	818991	14213J	PARTICIPANT	\N	PRESENT	0
821657	818991	21044C	PARTICIPANT	\N	PRESENT	0
821658	818991	14281W	PARTICIPANT	\N	PRESENT	0
821659	818991	20142Y	PARTICIPANT	\N	PRESENT	0
821660	818991	21082J	PARTICIPANT	\N	PRESENT	0
821661	818991	21071F	PARTICIPANT	\N	PRESENT	0
821662	818991	19691J	PARTICIPANT	\N	PRESENT	0
821663	818991	10015M	PARTICIPANT	\N	PRESENT	0
821664	818991	14195A	PARTICIPANT	\N	PRESENT	0
821665	818991	19719D	PARTICIPANT	\N	PRESENT	0
821666	818991	14071N	PARTICIPANT	\N	PRESENT	0
821667	818991	14267Y	PARTICIPANT	\N	PRESENT	0
821668	818991	18193Q	PARTICIPANT	\N	PRESENT	0
821669	818991	21058J	PARTICIPANT	\N	PRESENT	0
821670	818991	19553Y	PARTICIPANT	\N	PRESENT	0
821671	818991	20058E	PARTICIPANT	\N	PRESENT	0
806434	804142	21087P	PARTICIPANT	\N	EXCUSE	0
819309	818982	20046A	PARTICIPANT	\N	PRESENT	0
819310	818982	19565D	PARTICIPANT	\N	PRESENT	0
819311	818982	14329V	PARTICIPANT	\N	PRESENT	0
819312	818982	19758L	PARTICIPANT	\N	PRESENT	0
819313	818982	14026U	PARTICIPANT	\N	PRESENT	0
819314	818982	20130U	PARTICIPANT	\N	PRESENT	0
819315	818982	20248J	PARTICIPANT	\N	PRESENT	0
819316	818982	11053K	PARTICIPANT	\N	PRESENT	0
819317	818982	20108W	PARTICIPANT	\N	PRESENT	0
819318	818982	15197G	PARTICIPANT	\N	PRESENT	0
819319	818982	17229F	PARTICIPANT	\N	PRESENT	0
819320	818982	19399H	PARTICIPANT	\N	PRESENT	0
819321	818982	14267Y	PARTICIPANT	\N	PRESENT	0
819322	818982	19826F	PARTICIPANT	\N	PRESENT	0
819323	818982	20056C	PARTICIPANT	\N	PRESENT	0
819324	818982	20098N	PARTICIPANT	\N	PRESENT	0
819325	818982	21068L	PARTICIPANT	\N	PRESENT	0
819326	818982	19798U	PARTICIPANT	\N	PRESENT	0
819327	818982	21039F	PARTICIPANT	\N	PRESENT	0
819328	818982	19701S	PARTICIPANT	\N	PRESENT	0
819329	818982	14031R	PARTICIPANT	\N	PRESENT	0
819330	818982	21029D	PARTICIPANT	\N	PRESENT	0
819331	818982	14191V	PARTICIPANT	\N	PRESENT	0
819332	818982	18083K	PARTICIPANT	\N	PRESENT	0
819333	818982	21085M	PARTICIPANT	\N	PRESENT	0
819334	818982	21083K	PARTICIPANT	\N	PRESENT	0
819335	818982	21086N	PARTICIPANT	\N	PRESENT	0
819336	818982	19954N	PARTICIPANT	\N	PRESENT	0
819337	818982	20054A	PARTICIPANT	\N	PRESENT	0
819338	818982	20068G	PARTICIPANT	\N	PRESENT	0
819339	818982	20180F	PARTICIPANT	\N	PRESENT	0
819340	818982	21075K	PARTICIPANT	\N	PRESENT	0
819341	818982	19687N	PARTICIPANT	\N	PRESENT	0
819342	818982	21049H	PARTICIPANT	\N	PRESENT	0
819343	818982	14169X	PARTICIPANT	\N	PRESENT	0
819344	818982	20044X	PARTICIPANT	\N	PRESENT	0
819345	818982	04033B	PARTICIPANT	\N	PRESENT	0
819346	818982	20038A	PARTICIPANT	\N	PRESENT	0
819347	818982	21072G	PARTICIPANT	\N	PRESENT	0
819348	818982	19699S	PARTICIPANT	\N	PRESENT	0
819349	818982	21070E	PARTICIPANT	\N	PRESENT	0
819350	818982	14217N	PARTICIPANT	\N	PRESENT	0
819351	818982	05012A	PARTICIPANT	\N	PRESENT	0
819352	818982	20062A	PARTICIPANT	\N	PRESENT	0
819353	818982	19347U	PARTICIPANT	\N	PRESENT	0
819354	818982	14073Q	PARTICIPANT	\N	PRESENT	0
819355	818982	20172F	PARTICIPANT	\N	PRESENT	0
819356	818982	21055F	PARTICIPANT	\N	PRESENT	0
819357	818982	21065H	PARTICIPANT	\N	PRESENT	0
819358	818982	21044C	PARTICIPANT	\N	PRESENT	0
819359	818982	21076L	PARTICIPANT	\N	PRESENT	0
819360	818982	14241N	PARTICIPANT	\N	PRESENT	0
819361	818982	19703U	PARTICIPANT	\N	PRESENT	0
819362	818982	20086J	PARTICIPANT	\N	PRESENT	0
819363	818982	21050A	PARTICIPANT	\N	PRESENT	0
819364	818982	14189C	PARTICIPANT	\N	PRESENT	0
819365	818982	20140W	PARTICIPANT	\N	PRESENT	0
819366	818982	14083S	PARTICIPANT	\N	PRESENT	0
819367	818982	19111A	PARTICIPANT	\N	PRESENT	0
819368	818982	20016T	PARTICIPANT	\N	PRESENT	0
819369	818982	19693L	PARTICIPANT	\N	PRESENT	0
819370	818982	08010L	PARTICIPANT	\N	PRESENT	0
819371	818982	20096L	PARTICIPANT	\N	PRESENT	0
819373	818982	11043H	PARTICIPANT	\N	PRESENT	0
819374	818982	14193X	PARTICIPANT	\N	PRESENT	0
819375	818982	20104S	PARTICIPANT	\N	PRESENT	0
819377	818982	19533U	PARTICIPANT	\N	PRESENT	0
819378	818879	14053L	PARTICIPANT	\N	PRESENT	0
819379	818879	20074E	PARTICIPANT	\N	PRESENT	0
819380	818879	21057H	PARTICIPANT	\N	PRESENT	0
819381	818879	04045F	PARTICIPANT	\N	PRESENT	0
819382	818879	04047H	PRESIDENT	0	PRESENT	0
819383	818879	19673G	PARTICIPANT	\N	PRESENT	0
819384	818879	19719D	PARTICIPANT	\N	PRESENT	0
819385	818879	19725B	PARTICIPANT	\N	PRESENT	0
819386	818879	21056G	PARTICIPANT	\N	PRESENT	0
819387	818879	18207D	PARTICIPANT	\N	PRESENT	0
819388	818879	18231D	PARTICIPANT	\N	PRESENT	0
819389	818879	20110Q	PARTICIPANT	\N	PRESENT	0
819390	818879	14147R	PARTICIPANT	\N	PRESENT	0
819391	818879	14151M	PARTICIPANT	\N	PRESENT	0
819392	818879	14215L	PARTICIPANT	\N	PRESENT	0
819393	818879	19489J	PARTICIPANT	\N	PRESENT	0
819394	818879	14189C	PARTICIPANT	\N	PRESENT	0
819395	818879	10015M	PARTICIPANT	\N	PRESENT	0
819396	818879	21076L	PARTICIPANT	\N	PRESENT	0
819397	818879	19111A	PARTICIPANT	\N	PRESENT	0
819398	818879	20098N	PARTICIPANT	\N	PRESENT	0
819399	818982	20040T	PARTICIPANT	\N	PRESENT	0
819400	818982	19697Q	PARTICIPANT	\N	PRESENT	0
819401	818982	21043B	PARTICIPANT	\N	PRESENT	0
819402	818982	19719D	PARTICIPANT	\N	PRESENT	0
819403	818982	21057H	PARTICIPANT	\N	PRESENT	0
819404	818982	19447X	PARTICIPANT	\N	PRESENT	0
819405	818982	21056G	PARTICIPANT	\N	PRESENT	0
819406	818982	21064G	PARTICIPANT	\N	PRESENT	0
819407	818982	19629C	PARTICIPANT	\N	PRESENT	0
819408	818982	14215L	PARTICIPANT	\N	PRESENT	0
819409	818982	19685L	PARTICIPANT	\N	PRESENT	0
819410	818982	19723Y	PARTICIPANT	\N	PRESENT	0
819411	818982	18207D	PARTICIPANT	\N	PRESENT	0
819412	818982	19679N	PARTICIPANT	\N	PRESENT	0
819413	818982	14053L	PARTICIPANT	\N	PRESENT	0
819414	818982	14195A	PARTICIPANT	\N	PRESENT	0
819426	818982	20118Y	PARTICIPANT	\N	PRESENT	0
819416	818982	04045F	PARTICIPANT	\N	PRESENT	0
819417	818982	20132W	PARTICIPANT	\N	PRESENT	0
819418	818982	14147R	PARTICIPANT	\N	PRESENT	0
819419	818982	21035B	PARTICIPANT	\N	PRESENT	0
819423	818982	19569H	PARTICIPANT	\N	PRESENT	0
819421	818982	20252E	PARTICIPANT	\N	PRESENT	0
819422	818982	21063F	PARTICIPANT	\N	PRESENT	0
819424	818982	20138D	PARTICIPANT	\N	PRESENT	0
819425	818982	19681G	PARTICIPANT	\N	PRESENT	0
819427	818982	21088Q	PARTICIPANT	\N	PRESENT	0
819429	818982	14179A	PARTICIPANT	\N	PRESENT	0
819431	818982	21092L	PARTICIPANT	\N	PRESENT	0
819433	818982	20024T	PARTICIPANT	\N	PRESENT	0
819436	818982	19383Y	PARTICIPANT	\N	PRESENT	0
819443	818982	11072N	PARTICIPANT	\N	PRESENT	0
819438	818982	19413M	PARTICIPANT	\N	PRESENT	0
819442	818982	19563B	PARTICIPANT	\N	PRESENT	0
819444	818982	21096Q	PARTICIPANT	\N	PRESENT	0
819445	818982	18395Y	PARTICIPANT	\N	PRESENT	0
819446	818982	21125C	PARTICIPANT	\N	PRESENT	0
819447	818982	20026V	PARTICIPANT	\N	PRESENT	0
819448	818982	20070A	PARTICIPANT	\N	PRESENT	0
819449	818982	20088L	PARTICIPANT	\N	PRESENT	0
819450	818982	21082J	PARTICIPANT	\N	PRESENT	0
819451	818982	20030R	PARTICIPANT	\N	PRESENT	0
819452	818982	20020P	PARTICIPANT	\N	PRESENT	0
819453	818982	19367Y	PARTICIPANT	\N	PRESENT	0
819454	818982	14231L	PARTICIPANT	\N	PRESENT	0
819455	818982	19725B	PARTICIPANT	\N	PRESENT	0
819456	818982	20126Y	PARTICIPANT	\N	PRESENT	0
819457	818982	21074J	PARTICIPANT	\N	PRESENT	0
819458	818982	14213J	PARTICIPANT	\N	PRESENT	0
819459	818982	20116W	PARTICIPANT	\N	PRESENT	0
819460	818982	21054E	PARTICIPANT	\N	PRESENT	0
819462	818982	21093M	PARTICIPANT	\N	PRESENT	0
819463	818982	20286Q	PARTICIPANT	\N	PRESENT	0
819465	818982	14121F	PARTICIPANT	\N	PRESENT	0
819473	818982	21089R	PARTICIPANT	\N	PRESENT	0
819479	818982	11056N	PARTICIPANT	\N	PRESENT	0
819481	818982	08015R	PARTICIPANT	\N	PRESENT	0
819482	818982	14123H	PARTICIPANT	\N	PRESENT	0
819494	818982	19585H	PARTICIPANT	\N	PRESENT	0
819496	818982	19695N	PARTICIPANT	\N	PRESENT	0
819498	818982	19611R	PARTICIPANT	\N	PRESENT	0
819500	818982	20074E	PARTICIPANT	\N	PRESENT	0
819501	818982	19621T	PARTICIPANT	\N	PRESENT	0
819506	818982	14211G	PARTICIPANT	\N	PRESENT	0
819504	818982	20142Y	PARTICIPANT	\N	PRESENT	0
819505	818982	14237S	PARTICIPANT	\N	PRESENT	0
819507	818982	11090Q	PARTICIPANT	\N	PRESENT	0
819510	818982	01058X	PARTICIPANT	\N	PRESENT	0
819511	818982	14042U	PARTICIPANT	\N	PRESENT	0
819518	818982	20124W	PARTICIPANT	\N	PRESENT	0
819519	818982	21059K	PARTICIPANT	\N	PRESENT	0
819524	818982	20058E	PARTICIPANT	\N	PRESENT	0
818968	818967	14255U	PARTICIPANT	\N	PRESENT	0
812460	810436	14021P	PARTICIPANT	\N	PRESENT	0
812461	810436	14229S	PARTICIPANT	\N	PRESENT	0
818969	818967	18083K	PARTICIPANT	\N	PRESENT	0
818970	818967	11074Q	PARTICIPANT	\N	PRESENT	0
818971	818967	19591F	PARTICIPANT	\N	PRESENT	0
818972	818967	14059S	PARTICIPANT	\N	PRESENT	0
818973	818967	14169X	PARTICIPANT	\N	PRESENT	0
818974	818967	10015M	PARTICIPANT	\N	PRESENT	0
818975	818967	21031W	PARTICIPANT	\N	PRESENT	0
818976	818967	19585H	PARTICIPANT	\N	PRESENT	0
820991	820986	14213J	PARTICIPANT	\N	PRESENT	0
820992	820986	19683J	PARTICIPANT	\N	PRESENT	0
820993	820986	21081H	PARTICIPANT	\N	PRESENT	0
820994	820986	04092N	PARTICIPANT	\N	PRESENT	0
797702	797701	08034U	PARTICIPANT	\N	PRESENT	0
797703	797701	14121F	PARTICIPANT	\N	PRESENT	0
797704	797701	99004R	PARTICIPANT	\N	PRESENT	0
797705	797701	19545Y	PARTICIPANT	\N	PRESENT	0
797706	797701	21079P	PARTICIPANT	\N	PRESENT	0
797707	797701	05012A	PARTICIPANT	\N	PRESENT	0
797708	797701	20080C	PARTICIPANT	\N	EXCUSE	0
802122	801237	14213J	PARTICIPANT	\N	EXCUSE	0
802123	801237	19760E	PARTICIPANT	\N	EXCUSE	0
802124	801237	21039F	PARTICIPANT	\N	EXCUSE	0
802125	801237	21064G	PARTICIPANT	\N	EXCUSE	0
802126	801237	19798U	PARTICIPANT	\N	PRESENT	0
802127	801237	14223L	PARTICIPANT	\N	PRESENT	0
802128	801237	19683J	PARTICIPANT	\N	PRESENT	0
802142	801237	20140W	PARTICIPANT	\N	PRESENT	0
802143	801237	20090E	PARTICIPANT	\N	PRESENT	0
802144	801237	14217N	PARTICIPANT	\N	PRESENT	0
802145	801237	21071F	PARTICIPANT	\N	PRESENT	0
802146	801237	21081H	PARTICIPANT	\N	PRESENT	0
802147	801237	20148F	PARTICIPANT	\N	PRESENT	0
802148	801237	14355X	PARTICIPANT	\N	PRESENT	0
802149	801237	14071N	PRESIDENT	0	PRESENT	0
802152	801237	04092N	PARTICIPANT	\N	PRESENT	0
802153	801237	19703U	PARTICIPANT	\N	PRESENT	0
802154	801237	17965H	PARTICIPANT	\N	PRESENT	0
802155	801237	19758L	PARTICIPANT	\N	PRESENT	0
802156	801237	19301E	PARTICIPANT	\N	PRESENT	0
802157	801237	01034P	PARTICIPANT	\N	PRESENT	0
802158	801237	14042U	PARTICIPANT	\N	PRESENT	0
802159	801237	14195A	PARTICIPANT	\N	PRESENT	0
802160	801237	17779H	PARTICIPANT	\N	PRESENT	0
802161	801237	18193Q	PARTICIPANT	\N	PRESENT	0
802162	801237	19713W	PARTICIPANT	\N	PRESENT	0
802163	801237	19679N	PARTICIPANT	\N	PRESENT	0
802181	801237	19691J	PARTICIPANT	\N	PRESENT	0
802186	801237	19723Y	PARTICIPANT	\N	PRESENT	0
802188	801237	19866P	PARTICIPANT	\N	PRESENT	0
802512	802508	14249W	PARTICIPANT	\N	PRESENT	0
802510	802508	19575F	PARTICIPANT	\N	PRESENT	0
802511	802508	11040E	PARTICIPANT	\N	PRESENT	0
802513	802508	07004J	PARTICIPANT	\N	PRESENT	0
802514	802508	19709B	PARTICIPANT	\N	PRESENT	0
802515	802508	08034U	PRESIDENT	0	PRESENT	0
802516	802508	14059S	PARTICIPANT	\N	PRESENT	0
802517	802508	21073H	PARTICIPANT	\N	PRESENT	0
802518	802508	04070G	PARTICIPANT	\N	PRESENT	0
802519	802508	19745F	PARTICIPANT	\N	PRESENT	0
802520	802508	14225N	PARTICIPANT	\N	PRESENT	0
802521	802508	10015M	PARTICIPANT	\N	PRESENT	0
802522	802508	14229S	PARTICIPANT	\N	PRESENT	0
802523	802508	19669L	PARTICIPANT	\N	PRESENT	0
803160	801147	08034U	PARTICIPANT	\N	PRESENT	0
803162	801147	14073Q	PARTICIPANT	\N	PRESENT	0
803163	801147	19701S	PARTICIPANT	\N	PRESENT	0
803165	801147	21082J	PARTICIPANT	\N	PRESENT	0
803167	801147	21036C	PARTICIPANT	\N	PRESENT	0
803168	801147	14331P	PARTICIPANT	\N	PRESENT	0
803169	801147	14193X	PARTICIPANT	\N	PRESENT	0
803170	801147	14026U	PARTICIPANT	\N	PRESENT	0
803193	801147	20042V	PARTICIPANT	\N	PRESENT	0
803302	801147	19709B	PARTICIPANT	\N	PRESENT	0
803308	801147	17737W	PARTICIPANT	\N	PRESENT	0
803314	801147	07033P	PARTICIPANT	\N	PRESENT	0
803317	801147	19565D	PARTICIPANT	\N	PRESENT	0
803322	801147	21073H	PARTICIPANT	\N	PRESENT	0
803344	801147	17023S	PARTICIPANT	\N	PRESENT	0
807042	804044	21057H	PARTICIPANT	\N	EXCUSE	0
807043	804044	11056N	PARTICIPANT	\N	EXCUSE	0
807046	804044	20050V	PARTICIPANT	\N	EXCUSE	0
807048	804044	20082E	PARTICIPANT	\N	EXCUSE	0
807050	804044	20044X	PARTICIPANT	\N	EXCUSE	0
807051	804044	19349W	PARTICIPANT	\N	EXCUSE	0
807052	804044	20106U	PARTICIPANT	\N	EXCUSE	0
807053	804044	19703U	PARTICIPANT	\N	EXCUSE	0
807055	804044	21093M	PARTICIPANT	\N	EXCUSE	0
807057	804044	21063F	PARTICIPANT	\N	EXCUSE	0
807058	804044	19479G	PARTICIPANT	\N	EXCUSE	0
807059	804044	20024T	PARTICIPANT	\N	EXCUSE	0
807061	804044	20086J	PARTICIPANT	\N	EXCUSE	0
807062	804044	21041Y	PARTICIPANT	\N	EXCUSE	0
807064	804044	20286Q	PARTICIPANT	\N	EXCUSE	0
807065	804044	21054E	PARTICIPANT	\N	EXCUSE	0
807071	804044	19399H	PARTICIPANT	\N	EXCUSE	0
807073	804044	20066E	PARTICIPANT	\N	EXCUSE	0
807074	804044	20060X	PARTICIPANT	\N	EXCUSE	0
807079	804045	19575F	PARTICIPANT	\N	EXCUSE	0
807081	804045	19735D	PARTICIPANT	\N	EXCUSE	0
807083	804045	19667J	PARTICIPANT	\N	EXCUSE	0
807086	804045	20138D	PARTICIPANT	\N	EXCUSE	0
807087	804045	19723Y	PARTICIPANT	\N	EXCUSE	0
807096	804045	19711U	PARTICIPANT	\N	PRESENT	0
808283	804284	21055F	PARTICIPANT	\N	PRESENT	0
811312	811311	08012N	PARTICIPANT	\N	PRESENT	0
811313	811311	14073Q	PARTICIPANT	\N	PRESENT	0
811314	811311	21077M	PARTICIPANT	\N	PRESENT	0
811315	811311	20180F	PARTICIPANT	\N	PRESENT	0
811316	811311	21063F	PARTICIPANT	\N	PRESENT	0
811354	811353	14255U	PARTICIPANT	\N	PRESENT	0
811355	811353	20056C	PARTICIPANT	\N	PRESENT	0
811356	811353	20084G	PARTICIPANT	\N	PRESENT	0
811357	811353	14059S	PARTICIPANT	\N	PRESENT	0
813992	813243	21047F	PARTICIPANT	\N	PRESENT	0
813993	813243	14111D	PARTICIPANT	\N	PRESENT	0
813994	813243	21063F	PARTICIPANT	\N	PRESENT	0
813995	813243	19723Y	PARTICIPANT	\N	PRESENT	0
813996	813243	21068L	PARTICIPANT	\N	PRESENT	0
813997	813243	21055F	PARTICIPANT	\N	PRESENT	0
813998	813243	21029D	PARTICIPANT	\N	PRESENT	0
813999	813243	21071F	PARTICIPANT	\N	PRESENT	0
814000	813243	21044C	PARTICIPANT	\N	PRESENT	0
814001	813243	21080G	PARTICIPANT	\N	PRESENT	0
814002	813243	21061D	PARTICIPANT	\N	PRESENT	0
814003	813243	20044X	PARTICIPANT	\N	PRESENT	0
814004	813243	19421M	PARTICIPANT	\N	PRESENT	0
814005	813243	20076G	PARTICIPANT	\N	PRESENT	0
814006	813243	20058E	PARTICIPANT	\N	PRESENT	0
814007	813243	14193X	PARTICIPANT	\N	PRESENT	0
814008	813243	14107H	PARTICIPANT	\N	PRESENT	0
814012	813243	14109K	PARTICIPANT	\N	PRESENT	0
814013	813243	04047H	PARTICIPANT	\N	PRESENT	0
814014	813243	21040X	PARTICIPANT	\N	PRESENT	0
814015	813243	20036X	PARTICIPANT	\N	PRESENT	0
814016	813243	21042A	PARTICIPANT	\N	PRESENT	0
814017	813243	19611R	PARTICIPANT	\N	PRESENT	0
814018	813243	20098N	PARTICIPANT	\N	PRESENT	0
814019	813243	19669L	PARTICIPANT	\N	PRESENT	0
814020	813243	04045F	PARTICIPANT	\N	PRESENT	0
814021	813243	20062A	PARTICIPANT	\N	PRESENT	0
814022	813243	20038A	PARTICIPANT	\N	PRESENT	0
814025	813243	20180F	PARTICIPANT	\N	PRESENT	0
814026	813243	21036C	PARTICIPANT	\N	PRESENT	0
814027	813243	19695N	PARTICIPANT	\N	PRESENT	0
814028	813243	11040E	PARTICIPANT	\N	PRESENT	0
814029	813243	20064C	PARTICIPANT	\N	PRESENT	0
814030	813243	19749K	PARTICIPANT	\N	PRESENT	0
814031	813243	20084G	PARTICIPANT	\N	PRESENT	0
814032	813243	21065H	PARTICIPANT	\N	PRESENT	0
814036	813243	19447X	PARTICIPANT	\N	PRESENT	0
814037	813243	19569H	PARTICIPANT	\N	PRESENT	0
814094	813243	17023S	PARTICIPANT	\N	PRESENT	0
814051	813243	21048G	PARTICIPANT	\N	PRESENT	0
814062	813243	19954N	PARTICIPANT	\N	PRESENT	0
814064	813243	19713W	PARTICIPANT	\N	PRESENT	0
814070	813243	20042V	PARTICIPANT	\N	PRESENT	0
814071	813243	20020P	PARTICIPANT	\N	PRESENT	0
814072	813243	20054A	PARTICIPANT	\N	PRESENT	0
814073	813243	21095P	PARTICIPANT	\N	PRESENT	0
814074	813243	14191V	PARTICIPANT	\N	PRESENT	0
814075	813243	20092G	PARTICIPANT	\N	PRESENT	0
814076	813243	19699S	PARTICIPANT	\N	PRESENT	0
814077	813243	19347U	PARTICIPANT	\N	PRESENT	0
814090	813243	11085T	PARTICIPANT	\N	PRESENT	0
814091	813243	20116W	PARTICIPANT	\N	PRESENT	0
814092	813243	08018U	PARTICIPANT	\N	PRESENT	0
814093	813243	19331L	PARTICIPANT	\N	PRESENT	0
814095	813243	20136B	PARTICIPANT	\N	PRESENT	0
814096	813243	11048N	PARTICIPANT	\N	PRESENT	0
814102	813243	20048C	PARTICIPANT	\N	PRESENT	0
814103	813243	18207D	PARTICIPANT	\N	PRESENT	0
812669	812668	19709B	PARTICIPANT	\N	PRESENT	0
812670	812668	21082J	PARTICIPANT	\N	PRESENT	0
812671	810378	14255U	PARTICIPANT	\N	PRESENT	0
812676	812672	20060X	PARTICIPANT	\N	PRESENT	0
812674	812672	14133K	PARTICIPANT	\N	PRESENT	0
812675	812672	14083S	PARTICIPANT	\N	PRESENT	0
812677	812672	11115U	PARTICIPANT	\N	PRESENT	0
812678	812672	21081H	PARTICIPANT	\N	PRESENT	0
812679	812672	19723Y	PARTICIPANT	\N	PRESENT	0
812680	812672	14059S	PARTICIPANT	\N	PRESENT	0
812681	812672	20118Y	PARTICIPANT	\N	PRESENT	0
812682	812672	10015M	PARTICIPANT	\N	PRESENT	0
812683	812672	14255U	PARTICIPANT	\N	PRESENT	0
812685	804130	21042A	PARTICIPANT	\N	PRESENT	0
812686	804130	20146D	PARTICIPANT	\N	EXCUSE	0
812687	804130	14109K	PARTICIPANT	\N	EXCUSE	0
812688	804130	20130U	PARTICIPANT	\N	EXCUSE	0
812689	804130	20098N	PARTICIPANT	\N	EXCUSE	0
812690	804130	19798U	PARTICIPANT	\N	EXCUSE	0
812691	804130	14223L	PARTICIPANT	\N	EXCUSE	0
812692	804130	21034A	PARTICIPANT	\N	EXCUSE	0
812693	804130	21061D	PARTICIPANT	\N	EXCUSE	0
812694	804130	20046A	PARTICIPANT	\N	EXCUSE	0
812695	804130	21094N	PARTICIPANT	\N	EXCUSE	0
812696	804130	21038E	PARTICIPANT	\N	PRESENT	0
812697	804130	19749K	PRESIDENT	0	PRESENT	0
812698	804130	21089R	PARTICIPANT	\N	PRESENT	0
812699	804130	20180F	PARTICIPANT	\N	PRESENT	0
812700	804130	11045K	PARTICIPANT	\N	PRESENT	0
812701	804130	19693L	PARTICIPANT	\N	PRESENT	0
812703	804130	21071F	PARTICIPANT	\N	PRESENT	0
812704	804130	14189C	PARTICIPANT	\N	PRESENT	0
812706	804130	07029T	PARTICIPANT	\N	PRESENT	0
812708	804130	18193Q	PARTICIPANT	\N	PRESENT	0
812709	804130	14147R	PARTICIPANT	\N	PRESENT	0
812710	804130	20038A	PARTICIPANT	\N	PRESENT	0
812711	804130	14030Q	PARTICIPANT	\N	PRESENT	0
812712	804130	21091K	PARTICIPANT	\N	PRESENT	0
812870	812869	21092L	PARTICIPANT	\N	PRESENT	0
812871	812869	19820Y	PARTICIPANT	\N	PRESENT	0
812872	812869	21040X	PARTICIPANT	\N	PRESENT	0
812873	812869	14195A	PARTICIPANT	\N	PRESENT	0
812874	812869	20018V	PARTICIPANT	\N	PRESENT	0
812875	812869	18207D	PARTICIPANT	\N	PRESENT	0
812876	812869	20110Q	PARTICIPANT	\N	PRESENT	0
821320	821319	11056N	PARTICIPANT	\N	PRESENT	0
821719	818992	21075K	PARTICIPANT	\N	PRESENT	0
821720	818992	21034A	PARTICIPANT	\N	PRESENT	0
821721	818992	14071N	PARTICIPANT	\N	PRESENT	0
821722	818992	19866P	PARTICIPANT	\N	PRESENT	0
821723	818992	21046E	PARTICIPANT	\N	PRESENT	0
821724	818992	21097R	PARTICIPANT	\N	PRESENT	0
821725	821646	21082J	PARTICIPANT	\N	PRESENT	0
821726	821646	19782L	PARTICIPANT	\N	PRESENT	0
821727	821646	21031W	PARTICIPANT	\N	PRESENT	0
821728	821646	14031R	PARTICIPANT	\N	PRESENT	0
821729	821646	19413M	PARTICIPANT	\N	PRESENT	0
821730	821646	21093M	PARTICIPANT	\N	PRESENT	0
821731	821646	11090Q	PARTICIPANT	\N	PRESENT	0
821732	821646	21084L	PARTICIPANT	\N	PRESENT	0
821733	821646	20248J	PARTICIPANT	\N	PRESENT	0
821734	821646	21090J	PRESIDENT	1	PRESENT	0
821735	821646	99004R	PRESIDENT	0	PRESENT	0
821736	821646	17023S	PARTICIPANT	\N	PRESENT	0
821737	821646	21050A	PARTICIPANT	\N	PRESENT	0
821738	818992	21071F	PARTICIPANT	\N	PRESENT	0
821739	818992	14215L	PARTICIPANT	\N	PRESENT	0
821717	818992	19479G	PARTICIPANT	\N	PRESENT	0
821718	818992	14281W	PARTICIPANT	\N	PRESENT	0
821740	818992	21066J	PARTICIPANT	\N	PRESENT	0
821741	818992	21041Y	PARTICIPANT	\N	PRESENT	0
821742	818992	14213J	PARTICIPANT	\N	PRESENT	0
821743	818992	20072C	PARTICIPANT	\N	PRESENT	0
821744	818992	21044C	PARTICIPANT	\N	PRESENT	0
821745	818992	20032T	PARTICIPANT	\N	PRESENT	0
821746	818992	14107H	PARTICIPANT	\N	PRESENT	0
821747	818992	20058E	PARTICIPANT	\N	PRESENT	0
821748	818992	14241N	PARTICIPANT	\N	PRESENT	0
821749	818992	17023S	PARTICIPANT	\N	PRESENT	0
821750	818992	20116W	PARTICIPANT	\N	PRESENT	0
821751	818992	19553Y	PARTICIPANT	\N	PRESENT	0
821752	818992	19758L	PARTICIPANT	\N	PRESENT	0
821753	818992	07029T	PARTICIPANT	\N	PRESENT	0
821780	821754	21046E	PARTICIPANT	\N	PRESENT	0
821781	821754	19691J	PARTICIPANT	\N	PRESENT	0
821782	821754	20090E	PARTICIPANT	\N	PRESENT	0
821784	821783	08034U	PARTICIPANT	\N	PRESENT	0
821785	821783	14121F	PARTICIPANT	\N	PRESENT	0
821786	821783	21086N	PARTICIPANT	\N	PRESENT	0
821787	821783	19711U	PARTICIPANT	\N	PRESENT	0
821788	821783	11070L	PARTICIPANT	\N	EXCUSE	0
821790	821783	20080C	PARTICIPANT	\N	EXCUSE	0
821791	821783	21041Y	PARTICIPANT	\N	EXCUSE	0
821792	821783	05012A	PARTICIPANT	\N	EXCUSE	0
821793	821783	21079P	PARTICIPANT	\N	EXCUSE	0
821794	821783	19687N	PARTICIPANT	\N	EXCUSE	0
821795	821754	14281W	PARTICIPANT	\N	PRESENT	0
821796	821754	19758L	PARTICIPANT	\N	PRESENT	0
821797	821754	14195A	PARTICIPANT	\N	PRESENT	0
821798	821754	21040X	PARTICIPANT	\N	PRESENT	0
821799	821754	21097R	PARTICIPANT	\N	PRESENT	0
821800	821754	19629C	PARTICIPANT	\N	PRESENT	0
821801	821754	14026U	PARTICIPANT	\N	PRESENT	0
821802	821754	20072C	PARTICIPANT	\N	PRESENT	0
821806	821754	21029D	PARTICIPANT	\N	PRESENT	0
821804	821754	14213J	PARTICIPANT	\N	PRESENT	0
821778	821754	14179A	PARTICIPANT	\N	PRESENT	0
821779	821754	19798U	PARTICIPANT	\N	PRESENT	0
821805	821754	14207L	PARTICIPANT	\N	PRESENT	0
821807	821754	14071N	PARTICIPANT	\N	PRESENT	0
821808	821754	19866P	PARTICIPANT	\N	PRESENT	0
821809	821754	21074J	PARTICIPANT	\N	PRESENT	0
821810	821754	21042A	PARTICIPANT	\N	PRESENT	0
821811	821754	20058E	PARTICIPANT	\N	PRESENT	0
821812	821754	19347U	PARTICIPANT	\N	PRESENT	0
821813	821754	20116W	PARTICIPANT	\N	PRESENT	0
821814	821754	19553Y	PARTICIPANT	\N	PRESENT	0
821815	821754	21066J	PARTICIPANT	\N	PRESENT	0
821816	821754	21075K	PARTICIPANT	\N	PRESENT	0
821817	821112	19693L	PARTICIPANT	\N	PRESENT	0
821818	821754	14107H	PARTICIPANT	\N	PRESENT	0
821819	821754	19711U	PARTICIPANT	\N	PRESENT	0
821820	821754	07029T	PARTICIPANT	\N	PRESENT	0
821821	821754	14215L	PARTICIPANT	\N	PRESENT	0
821822	821754	17023S	PARTICIPANT	\N	PRESENT	0
821823	821754	20134Y	PARTICIPANT	\N	PRESENT	0
821824	821754	21071F	PARTICIPANT	\N	PRESENT	0
821825	821754	11085T	PARTICIPANT	\N	PRESENT	0
821826	821754	05008E	PARTICIPANT	\N	PRESENT	0
821829	821828	20248J	PARTICIPANT	\N	PRESENT	0
821830	821828	21058J	PARTICIPANT	\N	PRESENT	0
821831	821828	21040X	PARTICIPANT	\N	PRESENT	0
821832	821828	19545Y	PARTICIPANT	\N	PRESENT	0
821833	821828	21039F	PARTICIPANT	\N	PRESENT	0
821834	821828	21061D	PARTICIPANT	\N	PRESENT	0
821835	821828	20038A	PARTICIPANT	\N	PRESENT	0
821836	821828	21052C	PARTICIPANT	\N	EXCUSE	0
821837	821828	21050A	PARTICIPANT	\N	PRESENT	0
821838	821828	19719D	PARTICIPANT	\N	PRESENT	0
821839	821828	21047F	PARTICIPANT	\N	PRESENT	0
821840	821828	21080G	PARTICIPANT	\N	PRESENT	0
821841	821828	21044C	PARTICIPANT	\N	PRESENT	0
821842	821828	14083S	PARTICIPANT	\N	PRESENT	0
821843	821828	20126Y	PARTICIPANT	\N	PRESENT	0
821844	821828	20054A	PRESIDENT	0	PRESENT	0
821845	821828	20052X	PARTICIPANT	\N	PRESENT	0
821846	821828	14237S	PARTICIPANT	\N	EXCUSE	0
821847	821828	08015R	PARTICIPANT	\N	EXCUSE	0
821848	821828	19551W	PARTICIPANT	\N	EXCUSE	0
821849	821828	19347U	PARTICIPANT	\N	EXCUSE	0
821850	821828	20078J	PARTICIPANT	\N	EXCUSE	0
821851	821828	21064G	PARTICIPANT	\N	EXCUSE	0
821852	821828	21051B	PARTICIPANT	\N	EXCUSE	0
821853	821828	20144B	PARTICIPANT	\N	EXCUSE	0
821854	821828	19563B	PARTICIPANT	\N	EXCUSE	0
821855	821828	21092L	PARTICIPANT	\N	EXCUSE	0
821856	821828	19697Q	PARTICIPANT	\N	EXCUSE	0
821859	821858	14189C	PARTICIPANT	\N	PRESENT	0
821861	821858	14069U	PARTICIPANT	\N	PRESENT	0
797207	793996	19760E	PARTICIPANT	\N	PRESENT	0
797208	793996	18207D	PARTICIPANT	\N	PRESENT	0
797210	793996	21037D	PARTICIPANT	\N	PRESENT	0
797211	793996	18395Y	PARTICIPANT	\N	PRESENT	0
797212	793996	14001X	PARTICIPANT	\N	PRESENT	0
797213	793996	14033T	PARTICIPANT	\N	PRESENT	0
797214	793996	19798U	PARTICIPANT	\N	PRESENT	0
797215	793996	19679N	PARTICIPANT	\N	PRESENT	0
797218	793996	20042V	PARTICIPANT	\N	PRESENT	0
797225	793996	21082J	PARTICIPANT	\N	PRESENT	0
797226	793996	14281W	PARTICIPANT	\N	PRESENT	0
797227	793996	19569H	PARTICIPANT	\N	PRESENT	0
797230	793996	14026U	PARTICIPANT	\N	PRESENT	0
797231	793996	14073Q	PARTICIPANT	\N	PRESENT	0
797252	793996	19691J	PARTICIPANT	\N	PRESENT	0
797255	793996	19701S	PARTICIPANT	\N	PRESENT	0
797273	793996	19551W	PARTICIPANT	\N	PRESENT	0
797275	793996	14331P	PRESIDENT	0	PRESENT	0
797276	793996	14071N	PARTICIPANT	\N	PRESENT	0
797316	793996	20098N	PARTICIPANT	\N	EXCUSE	0
797317	793996	14133K	PARTICIPANT	\N	EXCUSE	0
797318	793996	19709B	PARTICIPANT	\N	EXCUSE	0
818966	818965	20094J	PARTICIPANT	\N	PRESENT	0
819526	818982	14173T	PARTICIPANT	\N	PRESENT	0
819527	818982	10015M	PARTICIPANT	\N	PRESENT	0
819528	818982	21046E	PARTICIPANT	\N	PRESENT	0
819529	818982	21087P	PARTICIPANT	\N	PRESENT	0
819533	818982	20042V	PARTICIPANT	\N	PRESENT	0
819535	818982	14021P	PARTICIPANT	\N	PRESENT	0
819536	818982	14038Y	PARTICIPANT	\N	PRESENT	0
819538	818982	21077M	PARTICIPANT	\N	PRESENT	0
819545	818982	21069M	PARTICIPANT	\N	PRESENT	0
819547	818982	08061X	PARTICIPANT	\N	PRESENT	0
819548	818982	21058J	PARTICIPANT	\N	PRESENT	0
819551	818982	20052X	PARTICIPANT	\N	PRESENT	0
819554	818982	14257W	PARTICIPANT	\N	PRESENT	0
819651	818983	19573D	PARTICIPANT	\N	PRESENT	0
819652	818983	10015M	PARTICIPANT	\N	PRESENT	0
819653	818983	14123H	PARTICIPANT	\N	PRESENT	0
819654	818983	14073Q	PARTICIPANT	\N	PRESENT	0
819656	818983	20124W	PARTICIPANT	\N	PRESENT	0
819657	818983	19685L	PARTICIPANT	\N	PRESENT	0
819684	818983	20020P	PARTICIPANT	\N	PRESENT	0
819659	818983	20140W	PARTICIPANT	\N	PRESENT	0
819660	818983	20104S	PARTICIPANT	\N	PRESENT	0
819661	818983	21089R	PARTICIPANT	\N	PRESENT	0
819662	818983	20142Y	PARTICIPANT	\N	PRESENT	0
819663	818983	21070E	PARTICIPANT	\N	PRESENT	0
819664	818983	19585H	PARTICIPANT	\N	PRESENT	0
819665	818983	19611R	PARTICIPANT	\N	PRESENT	0
819666	818983	21063F	PARTICIPANT	\N	PRESENT	0
819667	818983	20046A	PARTICIPANT	\N	PRESENT	0
819668	818983	21084L	PARTICIPANT	\N	PRESENT	0
819669	818983	19679N	PARTICIPANT	\N	PRESENT	0
819670	818983	05012A	PARTICIPANT	\N	PRESENT	0
819671	818983	19421M	PARTICIPANT	\N	PRESENT	0
819672	818983	21058J	PARTICIPANT	\N	PRESENT	0
819673	818983	20056C	PARTICIPANT	\N	PRESENT	0
819674	818983	20102Q	PARTICIPANT	\N	PRESENT	0
819679	818983	20074E	PARTICIPANT	\N	PRESENT	0
819676	818983	14173T	PARTICIPANT	\N	PRESENT	0
819677	818983	19697Q	PARTICIPANT	\N	PRESENT	0
819678	818983	14241N	PARTICIPANT	\N	PRESENT	0
819680	818983	20038A	PARTICIPANT	\N	PRESENT	0
819681	818983	14191V	PARTICIPANT	\N	PRESENT	0
819682	818983	14030Q	PARTICIPANT	\N	PRESENT	0
819683	818983	21039F	PARTICIPANT	\N	PRESENT	0
819685	818983	20090E	PARTICIPANT	\N	PRESENT	0
819686	818983	21125C	PARTICIPANT	\N	PRESENT	0
819687	818983	18395Y	PARTICIPANT	\N	PRESENT	0
819688	818983	20026V	PARTICIPANT	\N	PRESENT	0
819689	818983	21091K	PARTICIPANT	\N	PRESENT	0
819690	818983	21077M	PARTICIPANT	\N	PRESENT	0
819696	818983	20028X	PARTICIPANT	\N	PRESENT	0
819697	818983	18193Q	PARTICIPANT	\N	PRESENT	0
819698	818983	19723Y	PARTICIPANT	\N	PRESENT	0
819699	818983	21040X	PARTICIPANT	\N	PRESENT	0
819700	818983	14107H	PARTICIPANT	\N	PRESENT	0
819701	818983	20092G	PARTICIPANT	\N	PRESENT	0
819702	818983	20100N	PARTICIPANT	\N	PRESENT	0
819703	818983	19711U	PARTICIPANT	\N	PRESENT	0
819704	818983	20126Y	PARTICIPANT	\N	PRESENT	0
819705	818983	14147R	PARTICIPANT	\N	PRESENT	0
819706	818983	19629C	PARTICIPANT	\N	PRESENT	0
819707	818983	20024T	PARTICIPANT	\N	PRESENT	0
819708	818983	07029T	PARTICIPANT	\N	PRESENT	0
819709	818983	20098N	PARTICIPANT	\N	PRESENT	0
819710	818983	19621T	PARTICIPANT	\N	PRESENT	0
819711	818983	11072N	PARTICIPANT	\N	PRESENT	0
819743	818984	21076L	PARTICIPANT	\N	PRESENT	0
819744	818984	21070E	PARTICIPANT	\N	PRESENT	0
819745	818984	20036X	PARTICIPANT	\N	PRESENT	0
819746	818984	20090E	PARTICIPANT	\N	PRESENT	0
819747	818984	20104S	PARTICIPANT	\N	PRESENT	0
819768	818984	14038Y	PARTICIPANT	\N	PRESENT	0
819749	818984	18083K	PARTICIPANT	\N	PRESENT	0
819750	818984	10015M	PARTICIPANT	\N	PRESENT	0
819751	818984	04047H	PARTICIPANT	\N	PRESENT	0
819752	818984	07029T	PARTICIPANT	\N	PRESENT	0
819753	818984	11056N	PARTICIPANT	\N	PRESENT	0
819754	818984	14191V	PARTICIPANT	\N	PRESENT	0
819755	818984	14215L	PARTICIPANT	\N	PRESENT	0
819756	818984	20110Q	PARTICIPANT	\N	PRESENT	0
819757	818984	11072N	PARTICIPANT	\N	PRESENT	0
819758	818984	21082J	PARTICIPANT	\N	PRESENT	0
819759	818984	18207D	PARTICIPANT	\N	PRESENT	0
819760	818984	19695N	PARTICIPANT	\N	PRESENT	0
819761	818984	19679N	PARTICIPANT	\N	PRESENT	0
819762	818984	19723Y	PARTICIPANT	\N	PRESENT	0
819763	818984	19619A	PARTICIPANT	\N	PRESENT	0
819764	818984	20084G	PARTICIPANT	\N	PRESENT	0
819765	818984	20092G	PARTICIPANT	\N	PRESENT	0
819766	818984	21040X	PARTICIPANT	\N	PRESENT	0
819767	818984	20038A	PARTICIPANT	\N	PRESENT	0
819769	818984	20106U	PARTICIPANT	\N	PRESENT	0
819770	818984	21086N	PARTICIPANT	\N	PRESENT	0
819771	818984	21084L	PARTICIPANT	\N	PRESENT	0
819772	818984	14187A	PARTICIPANT	\N	PRESENT	0
819741	818984	11090Q	PARTICIPANT	\N	PRESENT	0
819742	818984	21056G	PARTICIPANT	\N	PRESENT	0
819773	818984	14033T	PARTICIPANT	\N	PRESENT	0
819778	818984	21062E	PARTICIPANT	\N	PRESENT	0
819779	818984	19533U	PARTICIPANT	\N	PRESENT	0
819780	818984	19826F	PARTICIPANT	\N	PRESENT	0
819781	818984	19782L	PARTICIPANT	\N	PRESENT	0
819782	818984	20058E	PARTICIPANT	\N	PRESENT	0
819820	818985	11090Q	PARTICIPANT	\N	PRESENT	0
819821	818985	19826F	PARTICIPANT	\N	PRESENT	0
819649	818983	14259Y	PARTICIPANT	\N	PRESENT	0
819650	818983	20044X	PARTICIPANT	\N	PRESENT	0
819822	818985	20110Q	PARTICIPANT	\N	PRESENT	0
819823	818985	20092G	PARTICIPANT	\N	PRESENT	0
819824	818985	20084G	PARTICIPANT	\N	PRESENT	0
819825	818985	21082J	PARTICIPANT	\N	PRESENT	0
819826	818985	21062E	PARTICIPANT	\N	PRESENT	0
819827	818985	20106U	PARTICIPANT	\N	PRESENT	0
819828	818985	21076L	PARTICIPANT	\N	PRESENT	0
819829	818985	21093M	PARTICIPANT	\N	PRESENT	0
819830	818985	07029T	PARTICIPANT	\N	PRESENT	0
819831	818985	14033T	PARTICIPANT	\N	PRESENT	0
819832	818985	20038A	PARTICIPANT	\N	PRESENT	0
819833	818985	19723Y	PARTICIPANT	\N	PRESENT	0
819834	818985	21040X	PARTICIPANT	\N	PRESENT	0
819835	818985	21066J	PARTICIPANT	\N	PRESENT	0
819836	818985	19719D	PARTICIPANT	\N	PRESENT	0
819837	818985	21070E	PARTICIPANT	\N	PRESENT	0
819838	818985	11065P	PARTICIPANT	\N	PRESENT	0
819839	818985	14215L	PARTICIPANT	\N	PRESENT	0
819840	818985	20090E	PARTICIPANT	\N	PRESENT	0
819841	818985	19619A	PARTICIPANT	\N	PRESENT	0
819842	818985	14187A	PARTICIPANT	\N	PRESENT	0
819843	818985	19533U	PARTICIPANT	\N	PRESENT	0
819844	818985	21069M	PARTICIPANT	\N	PRESENT	0
819845	818985	21086N	PARTICIPANT	\N	PRESENT	0
819846	818985	19695N	PARTICIPANT	\N	PRESENT	0
819847	818985	11056N	PARTICIPANT	\N	PRESENT	0
819848	818985	21041Y	PARTICIPANT	\N	PRESENT	0
819849	818985	19251M	PARTICIPANT	\N	PRESENT	0
819850	818985	19782L	PARTICIPANT	\N	PRESENT	0
819851	818985	14219Q	PARTICIPANT	\N	PRESENT	0
819852	818985	10015M	PARTICIPANT	\N	PRESENT	0
809328	809327	20286Q	PARTICIPANT	\N	PRESENT	0
809329	809327	21075K	PARTICIPANT	\N	PRESENT	0
809330	809327	19447X	PARTICIPANT	\N	PRESENT	0
809331	809327	21092L	PARTICIPANT	\N	PRESENT	0
809332	809327	20114U	PARTICIPANT	\N	PRESENT	0
809333	809327	14147R	PARTICIPANT	\N	PRESENT	0
809336	809335	14205J	PARTICIPANT	\N	PRESENT	0
809337	809335	14033T	PARTICIPANT	\N	PRESENT	0
809338	809335	14207L	PARTICIPANT	\N	PRESENT	0
810577	807570	21084L	PARTICIPANT	\N	PRESENT	0
810578	807570	21082J	PARTICIPANT	\N	PRESENT	0
810579	807570	19413M	PARTICIPANT	\N	PRESENT	0
810580	807570	21093M	PARTICIPANT	\N	PRESENT	0
810581	807570	99004R	PRESIDENT	0	PRESENT	0
810582	807570	21090J	PARTICIPANT	\N	PRESENT	0
810583	807570	17023S	PARTICIPANT	\N	PRESENT	0
810584	807570	21031W	PARTICIPANT	\N	EXCUSE	0
810585	807570	14031R	PARTICIPANT	\N	EXCUSE	0
821164	819430	21081H	PARTICIPANT	\N	PRESENT	0
821165	819430	04092N	PARTICIPANT	\N	PRESENT	0
821304	821300	21081H	PARTICIPANT	\N	PRESENT	0
821321	818423	21035B	PARTICIPANT	\N	EXCUSE	0
821322	818423	04042C	PARTICIPANT	\N	EXCUSE	0
821323	818423	19631V	PARTICIPANT	\N	EXCUSE	0
821324	818423	14053L	PARTICIPANT	\N	EXCUSE	0
821325	818423	19673G	PARTICIPANT	\N	PRESENT	0
821326	818423	20034V	PARTICIPANT	\N	PRESENT	1
821327	818423	08010L	PARTICIPANT	\N	EXCUSE	0
821328	818423	20148F	PRESIDENT	0	PRESENT	0
821515	813081	21091K	PARTICIPANT	\N	PRESENT	0
821517	813081	14030Q	PRESIDENT	0	PRESENT	0
821518	813081	20038A	PARTICIPANT	\N	PRESENT	0
821519	813081	20146D	PARTICIPANT	\N	PRESENT	0
821520	813081	21034A	PARTICIPANT	\N	PRESENT	0
821521	813081	07029T	PARTICIPANT	\N	PRESENT	0
821543	818423	21034A	PARTICIPANT	\N	PRESENT	0
821579	818423	21071F	PARTICIPANT	\N	PRESENT	0
821584	818423	21030V	PARTICIPANT	\N	PRESENT	0
808004	808003	19479G	PARTICIPANT	\N	PRESENT	0
808006	808003	11048N	PARTICIPANT	\N	PRESENT	0
808007	808003	14225N	PARTICIPANT	\N	PRESENT	0
808044	807993	21035B	PARTICIPANT	\N	PRESENT	0
808045	807993	20034V	PRESIDENT	0	PRESENT	0
808046	807993	12016W	PARTICIPANT	\N	PRESENT	1
808047	807993	19657G	PARTICIPANT	\N	PRESENT	0
808048	807993	21032X	PARTICIPANT	\N	PRESENT	0
808049	807993	08073C	PARTICIPANT	\N	PRESENT	0
808050	807993	19673G	PARTICIPANT	\N	PRESENT	0
808051	807993	11072N	PARTICIPANT	\N	PRESENT	0
808052	807993	04042C	PARTICIPANT	\N	EXCUSE	0
808053	807993	21034A	PARTICIPANT	\N	EXCUSE	0
808054	807993	21073H	PARTICIPANT	\N	EXCUSE	0
808055	807993	21097R	PARTICIPANT	\N	EXCUSE	0
808056	807993	08010L	PARTICIPANT	\N	EXCUSE	0
808057	807993	19331L	PARTICIPANT	\N	EXCUSE	0
814104	813243	21041Y	PARTICIPANT	\N	PRESENT	0
814105	813243	20104S	PARTICIPANT	\N	PRESENT	0
814106	813243	20248J	PARTICIPANT	\N	PRESENT	0
814107	813243	14357A	PARTICIPANT	\N	PRESENT	0
814108	813243	19383Y	PARTICIPANT	\N	PRESENT	0
814110	813243	14329V	PARTICIPANT	\N	PRESENT	0
814111	813243	14147R	PARTICIPANT	\N	PRESENT	0
814114	813243	19367Y	PARTICIPANT	\N	PRESENT	0
814115	813243	21067K	PARTICIPANT	\N	PRESENT	0
814116	813243	14151M	PARTICIPANT	\N	PRESENT	0
814117	813243	14030Q	PARTICIPANT	\N	PRESENT	0
814118	813243	14042U	PARTICIPANT	\N	PRESENT	0
814119	813243	21058J	PARTICIPANT	\N	PRESENT	0
814120	813243	19760E	PARTICIPANT	\N	PRESENT	0
814121	813243	20100N	PARTICIPANT	\N	PRESENT	0
814122	813243	14033T	PARTICIPANT	\N	PRESENT	0
814123	812478	19553Y	PARTICIPANT	\N	PRESENT	0
814124	812478	19531S	PARTICIPANT	\N	PRESENT	0
814125	812478	20066E	PRESIDENT	0	PRESENT	0
814126	812478	18193Q	PARTICIPANT	\N	PRESENT	0
814127	812478	20024T	PARTICIPANT	\N	PRESENT	0
814128	812478	19758L	PARTICIPANT	\N	PRESENT	0
814129	812478	21064G	PARTICIPANT	\N	PRESENT	0
814130	812478	19723Y	PARTICIPANT	\N	PRESENT	0
814131	812478	14030Q	PARTICIPANT	\N	PRESENT	0
814134	813243	20124W	PARTICIPANT	\N	PRESENT	0
814141	813243	14257W	PARTICIPANT	\N	PRESENT	0
814142	813243	14083S	PARTICIPANT	\N	PRESENT	0
814143	813243	07029T	PARTICIPANT	\N	PRESENT	0
814144	813243	19413M	PARTICIPANT	\N	PRESENT	0
814146	813243	11090Q	PARTICIPANT	\N	PRESENT	0
814147	813243	14213J	PARTICIPANT	\N	PRESENT	0
814148	813243	19349W	PARTICIPANT	\N	PRESENT	0
814149	813243	19563B	PARTICIPANT	\N	PRESENT	0
814229	813257	04042C	PARTICIPANT	\N	PRESENT	0
814230	813257	19721W	PARTICIPANT	\N	PRESENT	0
814231	813257	21073H	PARTICIPANT	\N	PRESENT	0
814232	813257	19565D	PARTICIPANT	\N	PRESENT	0
814233	813257	21041Y	PARTICIPANT	\N	PRESENT	0
814234	813257	14249W	PARTICIPANT	\N	PRESENT	0
814235	813257	19669L	PARTICIPANT	\N	PRESENT	0
814236	813257	21036C	PARTICIPANT	\N	PRESENT	0
814237	813257	14211G	PARTICIPANT	\N	PRESENT	0
814238	813257	19347U	PARTICIPANT	\N	PRESENT	0
814239	813257	20110Q	PARTICIPANT	\N	PRESENT	0
814240	813257	20100N	PARTICIPANT	\N	PRESENT	0
814241	813257	20266L	PARTICIPANT	\N	PRESENT	0
814242	813257	21079P	PARTICIPANT	\N	PRESENT	0
814243	813257	21046E	PARTICIPANT	\N	PRESENT	0
814244	813257	21087P	PARTICIPANT	\N	PRESENT	0
814245	813257	20036X	PARTICIPANT	\N	PRESENT	0
814246	813257	21029D	PARTICIPANT	\N	PRESENT	0
814247	813257	14255U	PARTICIPANT	\N	PRESENT	0
814248	813257	21068L	PARTICIPANT	\N	PRESENT	0
814249	813257	19629C	PARTICIPANT	\N	PRESENT	0
814250	813257	04045F	PARTICIPANT	\N	PRESENT	0
814251	813257	21076L	PARTICIPANT	\N	PRESENT	0
814252	813257	20172F	PARTICIPANT	\N	PRESENT	0
814253	813257	14193X	PARTICIPANT	\N	PRESENT	0
807997	807996	19479G	PARTICIPANT	\N	PRESENT	0
807998	807996	14219Q	PARTICIPANT	\N	PRESENT	0
814254	813257	20038A	PARTICIPANT	\N	PRESENT	0
814255	813257	20128B	PARTICIPANT	\N	PRESENT	0
814256	813257	19447X	PARTICIPANT	\N	PRESENT	0
814257	813257	19679N	PARTICIPANT	\N	PRESENT	0
814258	813257	21066J	PARTICIPANT	\N	PRESENT	0
814259	813257	19719D	PARTICIPANT	\N	PRESENT	0
814260	813257	21030V	PARTICIPANT	\N	PRESENT	0
814261	813257	21088Q	PARTICIPANT	\N	PRESENT	0
814262	813257	19760E	PARTICIPANT	\N	PRESENT	0
814263	813257	21044C	PARTICIPANT	\N	PRESENT	0
814264	813257	20072C	PARTICIPANT	\N	PRESENT	0
814265	813257	19531S	PARTICIPANT	\N	PRESENT	0
814266	813257	20090E	PARTICIPANT	\N	PRESENT	0
814267	813257	14053L	PARTICIPANT	\N	PRESENT	0
814268	813257	19383Y	PARTICIPANT	\N	PRESENT	0
814269	813257	14147R	PARTICIPANT	\N	PRESENT	0
814273	813257	17023S	PARTICIPANT	\N	PRESENT	0
814271	813257	18395Y	PARTICIPANT	\N	PRESENT	0
814272	813257	11056N	PARTICIPANT	\N	PRESENT	0
814284	813257	04047H	PARTICIPANT	\N	PRESENT	0
814275	813257	20064C	PARTICIPANT	\N	PRESENT	0
814276	813257	14151M	PARTICIPANT	\N	PRESENT	0
814277	813257	11048N	PARTICIPANT	\N	PRESENT	0
814278	813257	20070A	PARTICIPANT	\N	PRESENT	0
814279	813257	14083S	PARTICIPANT	\N	PRESENT	0
814280	813257	07029T	PARTICIPANT	\N	PRESENT	0
814281	813257	20054A	PARTICIPANT	\N	PRESENT	0
814282	813257	18207D	PARTICIPANT	\N	PRESENT	0
814283	813257	14179A	PARTICIPANT	\N	PRESENT	0
814285	813257	14215L	PARTICIPANT	\N	PRESENT	0
814337	813259	07029T	PARTICIPANT	\N	PRESENT	0
814338	813259	20172F	PARTICIPANT	\N	PRESENT	0
814339	813259	14147R	PARTICIPANT	\N	PRESENT	0
814340	813259	20090E	PARTICIPANT	\N	PRESENT	0
814341	813259	04047H	PARTICIPANT	\N	PRESENT	0
814342	813259	19447X	PARTICIPANT	\N	PRESENT	0
814343	813259	19679N	PARTICIPANT	\N	PRESENT	0
814344	813259	20036X	PARTICIPANT	\N	PRESENT	0
814345	813259	14255U	PARTICIPANT	\N	PRESENT	0
814346	813259	21076L	PARTICIPANT	\N	PRESENT	0
814347	813259	19719D	PARTICIPANT	\N	PRESENT	0
814348	813259	21041Y	PARTICIPANT	\N	PRESENT	0
814349	813259	19629C	PARTICIPANT	\N	PRESENT	0
814350	813259	04045F	PARTICIPANT	\N	PRESENT	0
814351	813259	20110Q	PARTICIPANT	\N	PRESENT	0
814352	813259	19347U	PARTICIPANT	\N	PRESENT	0
814353	813259	21079P	PARTICIPANT	\N	PRESENT	0
814354	813259	18207D	PARTICIPANT	\N	PRESENT	0
814355	813259	20070A	PARTICIPANT	\N	PRESENT	0
814356	813259	18395Y	PARTICIPANT	\N	PRESENT	0
814357	813259	21088Q	PARTICIPANT	\N	PRESENT	0
814358	813259	19760E	PARTICIPANT	\N	PRESENT	0
814359	813259	19565D	PARTICIPANT	\N	PRESENT	0
814228	813257	19479G	PARTICIPANT	\N	PRESENT	0
814360	813259	21087P	PARTICIPANT	\N	PRESENT	0
814361	813259	14215L	PARTICIPANT	\N	PRESENT	0
814362	813259	21066J	PARTICIPANT	\N	PRESENT	0
814363	813259	20072C	PARTICIPANT	\N	PRESENT	0
814364	813259	14151M	PARTICIPANT	\N	PRESENT	0
815469	804984	21094N	PARTICIPANT	\N	EXCUSE	0
815477	815443	20094J	PARTICIPANT	\N	PRESENT	0
815487	815485	20094J	PARTICIPANT	\N	PRESENT	0
815491	815489	20094J	PARTICIPANT	\N	PRESENT	0
815493	815492	20094J	PARTICIPANT	\N	PRESENT	0
817481	813080	14189C	PARTICIPANT	\N	EXCUSE	0
817483	813080	14030Q	PARTICIPANT	\N	EXCUSE	0
817485	813080	20038A	PARTICIPANT	\N	EXCUSE	0
817486	813080	20130U	PARTICIPANT	\N	EXCUSE	0
817487	813080	21094N	PARTICIPANT	\N	EXCUSE	0
817498	814470	11043H	PARTICIPANT	\N	PRESENT	0
817499	814470	14241N	PARTICIPANT	\N	PRESENT	0
818701	813080	14147R	PARTICIPANT	\N	PRESENT	0
818702	813080	21034A	PARTICIPANT	\N	PRESENT	0
818703	813080	19749K	PRESIDENT	0	PRESENT	0
818704	813080	19798U	PARTICIPANT	\N	PRESENT	0
818705	813080	11045K	PARTICIPANT	\N	PRESENT	0
818706	813080	21091K	PARTICIPANT	\N	PRESENT	0
818707	813080	21038E	PARTICIPANT	\N	PRESENT	0
818708	813080	21042A	PARTICIPANT	\N	PRESENT	0
818709	813080	19693L	PARTICIPANT	\N	PRESENT	0
814335	813259	19479G	PARTICIPANT	\N	PRESENT	0
814336	813259	20038A	PARTICIPANT	\N	PRESENT	0
818710	813080	20146D	PARTICIPANT	\N	PRESENT	0
810728	810209	19729F	PARTICIPANT	\N	EXCUSE	0
810729	810209	19585H	PARTICIPANT	\N	EXCUSE	0
810730	810209	04047H	PARTICIPANT	\N	EXCUSE	0
816746	816743	14213J	PARTICIPANT	\N	PRESENT	0
816747	816743	04092N	PRESIDENT	0	PRESENT	0
816748	816743	20130U	PARTICIPANT	\N	EXCUSE	0
816749	816743	17965H	PARTICIPANT	\N	PRESENT	0
816750	816743	19703U	PARTICIPANT	\N	PRESENT	0
816752	816743	14042U	PARTICIPANT	\N	PRESENT	0
816754	816743	19760E	PARTICIPANT	\N	PRESENT	0
816767	816743	21064G	PARTICIPANT	\N	PRESENT	0
816768	816743	14026U	PARTICIPANT	\N	PRESENT	0
819516	819029	14001X	PARTICIPANT	\N	PRESENT	0
819517	819029	20286Q	PARTICIPANT	\N	PRESENT	0
819520	819029	14331P	PRESIDENT	0	PRESENT	0
819521	819029	21082J	PARTICIPANT	\N	PRESENT	0
819522	819029	19711U	PARTICIPANT	\N	PRESENT	0
819523	819029	19701S	PARTICIPANT	\N	PRESENT	0
819525	819029	14073Q	PRESIDENT	1	PRESENT	0
819530	819029	14026U	PARTICIPANT	\N	PRESENT	0
819532	819029	19569H	PARTICIPANT	\N	PRESENT	0
819534	819029	18207D	PARTICIPANT	\N	PRESENT	0
819539	819029	20106U	PARTICIPANT	\N	PRESENT	0
820299	820298	20076G	PARTICIPANT	\N	PRESENT	0
820300	820298	21048G	PARTICIPANT	\N	PRESENT	0
820301	820298	20090E	PARTICIPANT	\N	PRESENT	0
820303	820298	14357A	PARTICIPANT	\N	PRESENT	0
820456	820298	20038A	PARTICIPANT	\N	PRESENT	0
820458	820298	14059S	PARTICIPANT	\N	PRESENT	0
820461	820298	14221J	PARTICIPANT	\N	PRESENT	0
820464	820298	20054A	PARTICIPANT	\N	PRESENT	0
820467	820298	14107H	PARTICIPANT	\N	PRESENT	0
820471	820298	20092G	PARTICIPANT	\N	PRESENT	0
820474	820298	20044X	PARTICIPANT	\N	PRESENT	0
820557	820551	20032T	PARTICIPANT	\N	PRESENT	0
820558	820551	21048G	PARTICIPANT	\N	PRESENT	0
820559	820551	21046E	PARTICIPANT	\N	PRESENT	0
820565	820551	21063F	PARTICIPANT	\N	PRESENT	0
820563	820551	20114U	PARTICIPANT	\N	PRESENT	0
820567	820551	14207L	PARTICIPANT	\N	PRESENT	0
820569	820551	14357A	PARTICIPANT	\N	PRESENT	0
820570	820551	20040T	PARTICIPANT	\N	PRESENT	0
820571	820551	19673G	PARTICIPANT	\N	PRESENT	0
820572	820551	19820Y	PARTICIPANT	\N	PRESENT	0
820573	820551	20126Y	PARTICIPANT	\N	PRESENT	0
820575	820551	08015R	PARTICIPANT	\N	PRESENT	0
820576	820551	14059S	PARTICIPANT	\N	PRESENT	0
820577	820551	20030R	PARTICIPANT	\N	PRESENT	0
820579	820551	20084G	PARTICIPANT	\N	PRESENT	0
821864	821858	12028B	PARTICIPANT	\N	PRESENT	0
821865	821858	14267Y	PARTICIPANT	\N	PRESENT	0
821866	821858	19295A	PARTICIPANT	\N	PRESENT	0
821867	821858	14259Y	PARTICIPANT	\N	PRESENT	0
821868	821858	14215L	PARTICIPANT	\N	PRESENT	0
821889	821886	19111A	PARTICIPANT	\N	PRESENT	0
821870	821858	19553Y	PARTICIPANT	\N	PRESENT	0
821871	821858	14179A	PARTICIPANT	\N	PRESENT	0
821872	821858	19735D	PARTICIPANT	\N	PRESENT	0
821873	821858	86034E	PARTICIPANT	\N	PRESENT	0
821874	821858	08010L	PARTICIPANT	\N	PRESENT	0
821875	821858	14111D	PARTICIPANT	\N	PRESENT	0
821876	821858	19593H	PARTICIPANT	\N	PRESENT	0
821877	821858	11090Q	PARTICIPANT	\N	PRESENT	0
821878	821858	19798U	PARTICIPANT	\N	PRESENT	0
821879	821858	14229S	PARTICIPANT	\N	PRESENT	0
821880	821858	04045F	PARTICIPANT	\N	PRESENT	0
821881	821858	20136B	PARTICIPANT	\N	PRESENT	0
821882	821858	19301E	PARTICIPANT	\N	PRESENT	0
821883	821858	20064C	PARTICIPANT	\N	PRESENT	0
821884	821858	19479G	PARTICIPANT	\N	PRESENT	0
821887	821886	11043H	PARTICIPANT	\N	PRESENT	0
821888	821886	19954N	PARTICIPANT	\N	PRESENT	0
821890	821886	20180F	PARTICIPANT	\N	PRESENT	0
821891	821886	14073Q	PARTICIPANT	\N	PRESENT	0
821892	821886	19699S	PARTICIPANT	\N	PRESENT	0
821893	821886	19711U	PARTICIPANT	\N	PRESENT	0
821894	821886	20052X	PARTICIPANT	\N	PRESENT	0
821895	821886	08012N	PARTICIPANT	\N	PRESENT	0
821896	821886	19533U	PARTICIPANT	\N	PRESENT	0
821899	821897	19621T	PARTICIPANT	\N	PRESENT	0
821900	821897	14030Q	PARTICIPANT	\N	PRESENT	0
821901	821897	21089R	PARTICIPANT	\N	PRESENT	0
821902	821897	20142Y	PARTICIPANT	\N	PRESENT	0
821936	821927	18231D	PARTICIPANT	\N	PRESENT	0
821937	821927	14038Y	PARTICIPANT	\N	PRESENT	0
821938	821929	18231D	PARTICIPANT	\N	PRESENT	0
821939	821929	14038Y	PARTICIPANT	\N	PRESENT	0
821940	821935	18231D	PARTICIPANT	\N	PRESENT	0
821941	821935	14038Y	PARTICIPANT	\N	PRESENT	0
821949	821947	14205J	PARTICIPANT	\N	PRESENT	0
821950	821947	14033T	PARTICIPANT	\N	PRESENT	0
821951	821947	20092G	PARTICIPANT	\N	PRESENT	0
821953	821952	20086J	PARTICIPANT	\N	PRESENT	0
821954	821952	19573D	PARTICIPANT	\N	PRESENT	0
821955	821952	14327T	PARTICIPANT	\N	PRESENT	0
821956	821952	11110B	PARTICIPANT	\N	PRESENT	0
821958	821957	20086J	PARTICIPANT	\N	PRESENT	0
797179	794081	19479G	PARTICIPANT	\N	PRESENT	0
797180	794081	21081H	PARTICIPANT	\N	PRESENT	0
797181	794081	21094N	PARTICIPANT	\N	PRESENT	0
797182	794081	21087P	PARTICIPANT	\N	PRESENT	0
797183	794081	21039F	PARTICIPANT	\N	PRESENT	0
797184	794081	20180F	PARTICIPANT	\N	PRESENT	0
797185	794081	21072G	PARTICIPANT	\N	PRESENT	0
797186	794081	14213J	PARTICIPANT	\N	PRESENT	0
797187	794081	20124W	PARTICIPANT	\N	PRESENT	0
797188	794081	04092N	PARTICIPANT	\N	PRESENT	0
797189	794081	20128B	PARTICIPANT	\N	PRESENT	0
797190	794081	20114U	PARTICIPANT	\N	PRESENT	0
797191	794081	14195A	PARTICIPANT	\N	PRESENT	0
797192	794081	21065H	PARTICIPANT	\N	PRESENT	0
797193	794081	19703U	PARTICIPANT	\N	PRESENT	0
797194	794081	21043B	PARTICIPANT	\N	PRESENT	0
797195	794081	14038Y	PARTICIPANT	\N	PRESENT	0
797196	794081	20100N	PARTICIPANT	\N	PRESENT	0
797197	794081	19713W	PARTICIPANT	\N	PRESENT	0
797198	794081	21049H	PARTICIPANT	\N	PRESENT	0
797199	794081	21060C	PARTICIPANT	\N	PRESENT	0
797200	794081	19533U	PARTICIPANT	\N	PRESENT	0
797201	794081	14217N	PARTICIPANT	\N	PRESENT	0
797202	794081	14147R	PARTICIPANT	\N	PRESENT	0
797203	794081	21057H	PARTICIPANT	\N	PRESENT	0
797204	794081	08045X	PARTICIPANT	\N	PRESENT	0
797205	794081	21070E	PARTICIPANT	\N	PRESENT	0
797206	794081	20032T	PARTICIPANT	\N	PRESENT	0
797209	794081	20090E	PARTICIPANT	\N	PRESENT	0
797216	794081	19695N	PARTICIPANT	\N	PRESENT	0
797217	794081	21097R	PARTICIPANT	\N	PRESENT	0
797219	794081	19657G	PARTICIPANT	\N	PRESENT	0
797220	794081	14069U	PARTICIPANT	\N	PRESENT	0
797221	794081	14059S	PARTICIPANT	\N	PRESENT	0
797222	794081	18083K	PARTICIPANT	\N	PRESENT	0
797223	794081	19629C	PARTICIPANT	\N	PRESENT	0
797224	794081	14042U	PARTICIPANT	\N	PRESENT	0
797228	794081	14191V	PARTICIPANT	\N	PRESENT	0
797229	794081	20138D	PARTICIPANT	\N	PRESENT	0
797232	794754	21082J	PARTICIPANT	\N	PRESENT	0
797233	794754	14331P	PARTICIPANT	\N	PRESENT	0
797234	794754	14073Q	PARTICIPANT	\N	PRESENT	0
797235	794754	19798U	PARTICIPANT	\N	PRESENT	0
797236	794754	19569H	PRESIDENT	0	PRESENT	0
797237	794754	20042V	PARTICIPANT	\N	PRESENT	0
797238	794754	14001X	PARTICIPANT	\N	PRESENT	0
797239	794754	14033T	PARTICIPANT	\N	PRESENT	0
797240	794754	14026U	PARTICIPANT	\N	PRESENT	0
797241	794754	14281W	PARTICIPANT	\N	PRESENT	0
797242	794754	18207D	PARTICIPANT	\N	PRESENT	0
797243	794754	19679N	PARTICIPANT	\N	PRESENT	0
797244	794754	18395Y	PARTICIPANT	\N	PRESENT	0
797245	794754	14071N	PARTICIPANT	\N	PRESENT	0
797246	794754	21037D	PARTICIPANT	\N	PRESENT	0
797247	794754	19760E	PARTICIPANT	\N	PRESENT	0
797248	794754	20130U	PARTICIPANT	\N	EXCUSE	0
797249	794754	21046E	PARTICIPANT	\N	EXCUSE	0
797250	794081	20136B	PARTICIPANT	\N	PRESENT	0
797251	794754	19691J	PARTICIPANT	\N	PRESENT	0
797253	794081	21063F	PARTICIPANT	\N	PRESENT	0
797254	794081	21047F	PARTICIPANT	\N	PRESENT	0
797256	794754	19701S	PARTICIPANT	\N	PRESENT	0
797257	794081	20062A	PARTICIPANT	\N	PRESENT	0
797258	794081	20082E	PARTICIPANT	\N	PRESENT	0
797259	794081	14031R	PARTICIPANT	\N	PRESENT	0
797270	794754	19551W	PARTICIPANT	\N	PRESENT	0
797272	794081	18193Q	PARTICIPANT	\N	PRESENT	0
797299	794081	19782L	PARTICIPANT	\N	PRESENT	0
797300	794081	14207L	PARTICIPANT	\N	PRESENT	0
797301	794081	19826F	PARTICIPANT	\N	PRESENT	0
797302	794081	21062E	PARTICIPANT	\N	PRESENT	0
797303	794081	21071F	PARTICIPANT	\N	PRESENT	0
797304	794081	21066J	PARTICIPANT	\N	PRESENT	0
797309	794081	20026V	PARTICIPANT	\N	PRESENT	0
797306	794081	14257W	PARTICIPANT	\N	PRESENT	0
797307	794081	20134Y	PARTICIPANT	\N	PRESENT	0
797308	794081	07029T	PARTICIPANT	\N	PRESENT	0
797310	794081	19399H	PARTICIPANT	\N	PRESENT	0
797311	794081	14187A	PARTICIPANT	\N	PRESENT	0
797312	794081	19251M	PARTICIPANT	\N	PRESENT	0
797314	794081	17965H	PARTICIPANT	\N	PRESENT	0
797315	794081	11065P	PARTICIPANT	\N	PRESENT	0
797319	794081	20092G	PARTICIPANT	\N	PRESENT	0
797320	794084	19479G	PARTICIPANT	\N	PRESENT	0
797364	794084	20144B	PARTICIPANT	\N	PRESENT	0
797372	794084	20106U	PARTICIPANT	\N	PRESENT	0
797375	794084	19758L	PARTICIPANT	\N	PRESENT	0
797324	794084	21039F	PARTICIPANT	\N	PRESENT	0
797380	794084	14031R	PARTICIPANT	\N	PRESENT	0
797365	794084	21092L	PARTICIPANT	\N	PRESENT	0
797327	794084	04092N	PARTICIPANT	\N	PRESENT	0
797376	794084	21041Y	PARTICIPANT	\N	PRESENT	0
797329	794084	14038Y	PARTICIPANT	\N	PRESENT	0
797330	794084	20100N	PARTICIPANT	\N	PRESENT	0
797331	794084	19713W	PARTICIPANT	\N	PRESENT	0
797378	794084	20092G	PARTICIPANT	\N	PRESENT	0
797333	794084	19533U	PARTICIPANT	\N	PRESENT	0
797334	794084	14217N	PARTICIPANT	\N	PRESENT	0
797368	794084	14033T	PARTICIPANT	\N	PRESENT	0
797336	794084	21070E	PARTICIPANT	\N	PRESENT	0
797337	794084	20090E	PARTICIPANT	\N	PRESENT	0
797338	794084	19695N	PARTICIPANT	\N	PRESENT	0
797369	794084	19619A	PARTICIPANT	\N	PRESENT	0
797340	794084	19657G	PARTICIPANT	\N	PRESENT	0
797341	794084	19629C	PARTICIPANT	\N	PRESENT	0
797381	794084	20044X	PARTICIPANT	\N	PRESENT	0
797343	794084	21063F	PARTICIPANT	\N	PRESENT	0
797344	794084	20062A	PARTICIPANT	\N	PRESENT	0
797345	794084	20082E	PARTICIPANT	\N	PRESENT	0
797346	794084	18193Q	PARTICIPANT	\N	PRESENT	0
797384	794084	20046A	PARTICIPANT	\N	PRESENT	0
797348	794084	14207L	PARTICIPANT	\N	PRESENT	0
797349	794084	19826F	PARTICIPANT	\N	PRESENT	0
797350	794084	21062E	PARTICIPANT	\N	PRESENT	0
797394	794084	20124W	PARTICIPANT	\N	PRESENT	0
797352	794084	21066J	PARTICIPANT	\N	PRESENT	0
797353	794084	14257W	PARTICIPANT	\N	PRESENT	0
797354	794084	20134Y	PARTICIPANT	\N	PRESENT	0
797355	794084	07029T	PARTICIPANT	\N	PRESENT	0
797356	794084	20026V	PARTICIPANT	\N	PRESENT	0
797357	794084	19399H	PARTICIPANT	\N	PRESENT	0
797358	794084	14187A	PARTICIPANT	\N	PRESENT	0
797359	794084	19251M	PARTICIPANT	\N	PRESENT	0
797395	794084	18083K	PARTICIPANT	\N	PRESENT	0
797361	794084	11065P	PARTICIPANT	\N	PRESENT	0
797396	794084	21086N	PARTICIPANT	\N	PRESENT	0
797363	794084	14219Q	PARTICIPANT	\N	PRESENT	0
797397	794084	14083S	PARTICIPANT	\N	PRESENT	0
797398	794084	14073Q	PARTICIPANT	\N	PRESENT	0
797399	794084	20248J	PARTICIPANT	\N	PRESENT	0
797400	794084	14055N	PARTICIPANT	\N	PRESENT	0
797401	794084	20136B	PARTICIPANT	\N	PRESENT	0
797402	794084	21029D	PARTICIPANT	\N	PRESENT	0
797403	794084	19798U	PARTICIPANT	\N	PRESENT	0
797404	794084	14191V	PARTICIPANT	\N	PRESENT	0
797405	794084	11090Q	PARTICIPANT	\N	PRESENT	0
797419	794084	20032T	PARTICIPANT	\N	PRESENT	0
797421	794084	19820Y	PARTICIPANT	\N	PRESENT	0
797422	794084	19413M	PARTICIPANT	\N	PRESENT	0
797423	794084	20142Y	PARTICIPANT	\N	PRESENT	0
797424	794084	21079P	PARTICIPANT	\N	PRESENT	0
797427	794084	14169X	PARTICIPANT	\N	PRESENT	0
797428	794084	21082J	PARTICIPANT	\N	PRESENT	0
797437	794084	21085M	PARTICIPANT	\N	PRESENT	0
797448	794084	14147R	PARTICIPANT	\N	PRESENT	0
797449	794084	14215L	PARTICIPANT	\N	PRESENT	0
797450	794084	21068L	PARTICIPANT	\N	PRESENT	0
797451	794084	04045F	PARTICIPANT	\N	PRESENT	0
797452	794084	19551W	PARTICIPANT	\N	PRESENT	0
797456	794084	14357A	PARTICIPANT	\N	PRESENT	0
797457	794084	19621T	PARTICIPANT	\N	PRESENT	0
797458	794084	21069M	PARTICIPANT	\N	PRESENT	0
797459	794084	19631V	PARTICIPANT	\N	PRESENT	0
797460	794084	20180F	PARTICIPANT	\N	PRESENT	0
797461	794084	14053L	PARTICIPANT	\N	PRESENT	0
797462	794084	11048N	PARTICIPANT	\N	PRESENT	0
797463	794084	19760E	PARTICIPANT	\N	PRESENT	0
797464	794084	11056N	PARTICIPANT	\N	PRESENT	0
797465	794084	21075K	PARTICIPANT	\N	PRESENT	0
797466	794084	20110Q	PARTICIPANT	\N	PRESENT	0
797467	794084	19347U	PARTICIPANT	\N	PRESENT	0
821168	821166	20032T	PARTICIPANT	\N	PRESENT	0
821169	821166	21084L	PARTICIPANT	\N	PRESENT	0
821170	821166	19575F	PARTICIPANT	\N	PRESENT	0
821171	821166	20144B	PARTICIPANT	\N	PRESENT	0
821172	821166	14357A	PARTICIPANT	\N	PRESENT	0
821173	821166	14033T	PARTICIPANT	\N	PRESENT	0
821174	821166	20066E	PARTICIPANT	\N	PRESENT	0
821175	821166	19711U	PARTICIPANT	\N	PRESENT	0
821176	821166	14169X	PARTICIPANT	\N	PRESENT	0
821177	821166	19533U	PARTICIPANT	\N	PRESENT	0
821178	821166	20118Y	PARTICIPANT	\N	PRESENT	0
821179	821166	19619A	PARTICIPANT	\N	PRESENT	0
821180	821166	20092G	PARTICIPANT	\N	PRESENT	0
821419	821418	19479G	PARTICIPANT	\N	PRESENT	0
821420	821418	14187A	PARTICIPANT	\N	PRESENT	0
821422	821421	19479G	PARTICIPANT	\N	PRESENT	0
797931	797930	19735D	PARTICIPANT	\N	PRESENT	0
797932	797930	19723Y	PARTICIPANT	\N	PRESENT	0
798771	798770	20024T	PARTICIPANT	\N	PRESENT	0
798774	798770	20116W	PARTICIPANT	\N	PRESENT	0
798776	798770	19383Y	PARTICIPANT	\N	PRESENT	0
798777	798770	19782L	PARTICIPANT	\N	PRESENT	0
798778	798770	20090E	PARTICIPANT	\N	PRESENT	0
798779	798770	14329V	PARTICIPANT	\N	PRESENT	0
798780	798770	18083K	PARTICIPANT	\N	PRESENT	0
798782	798770	14357A	PARTICIPANT	\N	PRESENT	0
798783	798770	14187A	PARTICIPANT	\N	PRESENT	0
798785	798770	20038A	PARTICIPANT	\N	PRESENT	0
798788	798770	08056B	PARTICIPANT	\N	PRESENT	0
798789	798770	14033T	PARTICIPANT	\N	PRESENT	0
798790	798770	14213J	PARTICIPANT	\N	PRESENT	0
798791	798770	19723Y	PARTICIPANT	\N	PRESENT	0
798792	798770	08034U	PARTICIPANT	\N	PRESENT	0
798796	798770	14059S	PARTICIPANT	\N	PRESENT	0
798797	798770	21058J	PARTICIPANT	\N	PRESENT	0
798799	798770	14221J	PARTICIPANT	\N	PRESENT	0
798800	798770	17367Q	PARTICIPANT	\N	PRESENT	0
798801	798770	20018V	PARTICIPANT	\N	PRESENT	0
798806	798770	20030R	PARTICIPANT	\N	PRESENT	0
798807	798770	20118Y	PARTICIPANT	\N	PRESENT	0
798808	798770	05012A	PARTICIPANT	\N	PRESENT	0
798809	798770	14107H	PARTICIPANT	\N	PRESENT	0
798811	798770	20092G	PARTICIPANT	\N	PRESENT	0
798812	798770	20044X	PARTICIPANT	\N	PRESENT	0
798816	798815	21063F	PARTICIPANT	\N	PRESENT	0
798817	798815	19782L	PARTICIPANT	\N	PRESENT	0
798818	798815	14207L	PARTICIPANT	\N	PRESENT	0
798819	798815	19545Y	PARTICIPANT	\N	PRESENT	0
798820	798815	14329V	PARTICIPANT	\N	PRESENT	0
798822	798815	20074E	PARTICIPANT	\N	PRESENT	0
798823	798815	21086N	PARTICIPANT	\N	PRESENT	0
798824	798815	19820Y	PARTICIPANT	\N	PRESENT	0
798825	798815	08056B	PARTICIPANT	\N	PRESENT	0
798826	798815	21044C	PARTICIPANT	\N	PRESENT	0
798827	798815	19723Y	PARTICIPANT	\N	PRESENT	0
798828	798815	08015R	PARTICIPANT	\N	PRESENT	0
798829	798815	14059S	PARTICIPANT	\N	PRESENT	0
798830	798815	21054E	PARTICIPANT	\N	PRESENT	0
798831	798815	14147R	PARTICIPANT	\N	PRESENT	0
798833	798815	20030R	PARTICIPANT	\N	PRESENT	0
798834	798815	05012A	PARTICIPANT	\N	PRESENT	0
798835	798815	21056G	PARTICIPANT	\N	PRESENT	0
798836	798815	21064G	PARTICIPANT	\N	PRESENT	0
798837	798815	04045F	PARTICIPANT	\N	PRESENT	0
798838	798815	20058E	PARTICIPANT	\N	PRESENT	0
798839	798815	14187A	PARTICIPANT	\N	PRESENT	0
798841	798815	08069G	PARTICIPANT	\N	PRESENT	0
799050	799049	14133K	PARTICIPANT	\N	PRESENT	0
799054	799049	14217N	PARTICIPANT	\N	PRESENT	0
799052	799049	20024T	PARTICIPANT	\N	PRESENT	0
799053	799049	14357A	PARTICIPANT	\N	PRESENT	0
799055	799049	19531S	PARTICIPANT	\N	PRESENT	0
799056	799049	20102Q	PARTICIPANT	\N	PRESENT	0
799057	799049	07029T	PARTICIPANT	\N	PRESENT	0
799058	799049	19723Y	PARTICIPANT	\N	PRESENT	0
799059	799049	14059S	PARTICIPANT	\N	PRESENT	0
799060	799049	14147R	PARTICIPANT	\N	PRESENT	0
799061	799049	20062A	PARTICIPANT	\N	PRESENT	0
799069	799068	04047H	PARTICIPANT	\N	PRESENT	0
799070	799068	18231D	PARTICIPANT	\N	PRESENT	0
799072	799071	14215L	PARTICIPANT	\N	PRESENT	0
799835	799761	21036C	PARTICIPANT	\N	PRESENT	0
799848	799779	21036C	PARTICIPANT	\N	PRESENT	0
800479	800408	14207L	PARTICIPANT	\N	PRESENT	0
800810	797798	20092G	PARTICIPANT	\N	PRESENT	0
800811	797798	11056N	PARTICIPANT	\N	PRESENT	0
800812	797798	20264J	PARTICIPANT	\N	PRESENT	0
800813	797798	21079P	PARTICIPANT	\N	PRESENT	0
800814	797798	20044X	PARTICIPANT	\N	PRESENT	0
800815	797798	14281W	PARTICIPANT	\N	PRESENT	0
800816	797798	21057H	PARTICIPANT	\N	PRESENT	0
800817	797798	14083S	PARTICIPANT	\N	PRESENT	0
800818	797798	21045D	PARTICIPANT	\N	PRESENT	0
800819	797798	19413M	PARTICIPANT	\N	PRESENT	0
800820	797798	20080C	PARTICIPANT	\N	PRESENT	0
800821	797798	20048C	PARTICIPANT	\N	PRESENT	0
800822	797798	14071N	PARTICIPANT	\N	PRESENT	0
800823	797798	20034V	PARTICIPANT	\N	PRESENT	0
800824	797798	20180F	PARTICIPANT	\N	PRESENT	0
800825	797798	19667J	PARTICIPANT	\N	PRESENT	0
800826	797798	21071F	PARTICIPANT	\N	PRESENT	0
800827	797798	11048N	PARTICIPANT	\N	PRESENT	0
800828	797798	14069U	PARTICIPANT	\N	PRESENT	0
800829	797798	21087P	PARTICIPANT	\N	PRESENT	0
800830	797798	21046E	PARTICIPANT	\N	PRESENT	0
800831	797798	19709B	PARTICIPANT	\N	PRESENT	0
800832	797798	21049H	PARTICIPANT	\N	PRESENT	0
800833	797798	20098N	PARTICIPANT	\N	PRESENT	0
800834	797798	07029T	PARTICIPANT	\N	PRESENT	0
800896	797799	14071N	PARTICIPANT	\N	PRESENT	0
800897	797799	21053D	PARTICIPANT	\N	PRESENT	0
800898	797799	11027H	PARTICIPANT	\N	PRESENT	0
800899	797799	11045K	PARTICIPANT	\N	PRESENT	0
800900	797799	21071F	PARTICIPANT	\N	PRESENT	0
800901	797799	14021P	PARTICIPANT	\N	PRESENT	0
800902	797799	08060W	PARTICIPANT	\N	PRESENT	0
800903	797799	07029T	PARTICIPANT	\N	PRESENT	0
800904	797799	18207D	PARTICIPANT	\N	PRESENT	0
800905	797799	20180F	PARTICIPANT	\N	PRESENT	0
800906	797799	21082J	PARTICIPANT	\N	PRESENT	0
800932	797799	20248J	PARTICIPANT	\N	PRESENT	0
800935	797799	20082E	PARTICIPANT	\N	PRESENT	0
800909	797799	19820Y	PARTICIPANT	\N	PRESENT	0
800910	797799	19413M	PARTICIPANT	\N	PRESENT	0
800911	797799	20264J	PARTICIPANT	\N	PRESENT	0
800912	797799	21042A	PARTICIPANT	\N	PRESENT	0
800913	797799	20080C	PARTICIPANT	\N	PRESENT	0
800914	797799	18231D	PARTICIPANT	\N	PRESENT	0
800915	797799	21045D	PARTICIPANT	\N	PRESENT	0
800916	797799	14030Q	PARTICIPANT	\N	PRESENT	0
800917	797799	14281W	PARTICIPANT	\N	PRESENT	0
800918	797799	18193Q	PARTICIPANT	\N	PRESENT	0
800919	797799	17965H	PARTICIPANT	\N	PRESENT	0
800920	797799	19649G	PARTICIPANT	\N	PRESENT	0
800929	797799	14147R	PARTICIPANT	\N	PRESENT	0
800922	797799	20092G	PARTICIPANT	\N	PRESENT	0
800923	797799	19629C	PARTICIPANT	\N	PRESENT	0
800924	797799	21087P	PARTICIPANT	\N	PRESENT	0
800925	797799	14195A	PARTICIPANT	\N	PRESENT	0
800926	797799	14207L	PARTICIPANT	\N	PRESENT	0
800927	797799	21046E	PARTICIPANT	\N	PRESENT	0
800928	797799	21079P	PARTICIPANT	\N	PRESENT	0
800930	797799	14217N	PARTICIPANT	\N	PRESENT	0
800931	797799	21049H	PARTICIPANT	\N	PRESENT	0
800933	797799	21089R	PARTICIPANT	\N	PRESENT	0
800934	797799	19551W	PARTICIPANT	\N	PRESENT	0
800936	800749	21084L	PARTICIPANT	\N	PRESENT	0
800937	800749	20248J	PARTICIPANT	\N	PRESENT	0
800938	800749	20038A	PARTICIPANT	\N	PRESENT	0
800939	800749	14031R	PARTICIPANT	\N	PRESENT	0
800940	800749	19413M	PARTICIPANT	\N	PRESENT	0
800941	800749	21090J	PARTICIPANT	\N	PRESENT	0
800942	800749	99004R	PRESIDENT	0	PRESENT	0
800943	800749	21093M	PARTICIPANT	\N	PRESENT	0
800944	800749	21050A	PARTICIPANT	\N	PRESENT	0
800945	800749	17023S	PARTICIPANT	\N	PRESENT	0
800946	800749	21031W	PARTICIPANT	\N	EXCUSE	0
800894	797799	11090Q	PARTICIPANT	\N	PRESENT	0
800895	797799	19331L	PARTICIPANT	\N	PRESENT	0
810721	810720	20086J	PARTICIPANT	\N	PRESENT	0
810722	810720	19573D	PARTICIPANT	\N	PRESENT	0
810723	810720	19545Y	PARTICIPANT	\N	PRESENT	0
810724	810720	14327T	PARTICIPANT	\N	PRESENT	0
810734	810731	11110B	PARTICIPANT	\N	PRESENT	0
810732	810731	20086J	PARTICIPANT	\N	PRESENT	0
810733	810731	14327T	PARTICIPANT	\N	PRESENT	0
810735	810731	19545Y	PARTICIPANT	\N	PRESENT	0
810781	810302	20048C	PARTICIPANT	\N	PRESENT	0
810782	810302	14147R	PARTICIPANT	\N	PRESENT	0
810783	810302	21068L	PARTICIPANT	\N	PRESENT	0
810784	810302	19782L	PARTICIPANT	\N	PRESENT	0
818793	815931	19760E	PARTICIPANT	\N	PRESENT	0
818794	815931	20100N	PARTICIPANT	\N	PRESENT	0
818795	815931	14026U	PARTICIPANT	\N	PRESENT	0
818796	815931	19683J	PARTICIPANT	\N	PRESENT	0
818797	815931	18207D	PARTICIPANT	\N	PRESENT	0
818798	815931	19711U	PARTICIPANT	\N	PRESENT	0
818799	815931	14169X	PARTICIPANT	\N	PRESENT	0
818800	815931	20104S	PARTICIPANT	\N	PRESENT	0
818801	815931	14331P	PARTICIPANT	\N	PRESENT	0
818802	815931	10015M	PARTICIPANT	\N	PRESENT	0
797514	794085	21062E	PARTICIPANT	\N	PRESENT	0
797515	794085	14257W	PARTICIPANT	\N	PRESENT	0
797516	794085	19251M	PARTICIPANT	\N	PRESENT	0
797517	794085	20092G	PARTICIPANT	\N	PRESENT	0
797518	794085	21092L	PARTICIPANT	\N	PRESENT	0
797519	794085	04045F	PARTICIPANT	\N	PRESENT	0
797520	794085	20106U	PARTICIPANT	\N	PRESENT	0
797521	794085	19629C	PARTICIPANT	\N	PRESENT	0
797522	794085	21066J	PARTICIPANT	\N	PRESENT	0
797523	794085	21070E	PARTICIPANT	\N	PRESENT	0
797524	794085	20144B	PARTICIPANT	\N	PRESENT	0
797525	794085	19619A	PARTICIPANT	\N	PRESENT	0
797526	794085	15197G	PARTICIPANT	\N	PRESENT	0
797527	794085	21082J	PARTICIPANT	\N	PRESENT	0
797528	794085	20038A	PARTICIPANT	\N	PRESENT	0
797529	794085	21063F	PARTICIPANT	\N	PRESENT	0
797530	794085	14033T	PARTICIPANT	\N	PRESENT	0
797531	794085	20180F	PARTICIPANT	\N	PRESENT	0
797532	794085	21029D	PARTICIPANT	\N	PRESENT	0
797533	794085	07029T	PARTICIPANT	\N	PRESENT	0
797534	794085	20032T	PARTICIPANT	\N	PRESENT	0
797535	794085	20090E	PARTICIPANT	\N	PRESENT	0
797536	794085	19533U	PARTICIPANT	\N	PRESENT	0
797537	794085	11090Q	PARTICIPANT	\N	PRESENT	0
797538	794085	14069U	PARTICIPANT	\N	PRESENT	0
797539	794085	19621T	PARTICIPANT	\N	PRESENT	0
797540	794085	14207L	PARTICIPANT	\N	PRESENT	0
797541	794085	14187A	PARTICIPANT	\N	PRESENT	0
797542	794085	19695N	PARTICIPANT	\N	PRESENT	0
797543	794085	14219Q	PARTICIPANT	\N	PRESENT	0
797544	794085	19826F	PARTICIPANT	\N	PRESENT	0
797545	794085	14038Y	PARTICIPANT	\N	PRESENT	0
797546	794085	19758L	PARTICIPANT	\N	PRESENT	0
797547	794085	20046A	PARTICIPANT	\N	PRESENT	0
797548	794085	21075K	PARTICIPANT	\N	PRESENT	0
797549	794085	20062A	PARTICIPANT	\N	PRESENT	0
797550	794085	14026U	PARTICIPANT	\N	PRESENT	0
797551	794085	20136B	PARTICIPANT	\N	PRESENT	0
797552	794085	19347U	PARTICIPANT	\N	PRESENT	0
797553	794085	14215L	PARTICIPANT	\N	PRESENT	0
797554	794085	20100N	PARTICIPANT	\N	PRESENT	0
797555	794085	20110Q	PARTICIPANT	\N	PRESENT	0
797512	794085	14179A	PARTICIPANT	\N	PRESENT	0
797513	794085	11056N	PARTICIPANT	\N	PRESENT	0
797559	794085	18083K	PARTICIPANT	\N	PRESENT	0
797560	794085	14213J	PARTICIPANT	\N	PRESENT	0
797561	794085	14083S	PARTICIPANT	\N	PRESENT	0
797933	797929	21084L	PARTICIPANT	\N	PRESENT	0
797934	797929	21082J	PARTICIPANT	\N	PRESENT	0
797935	797929	21056G	PARTICIPANT	\N	PRESENT	0
797936	797929	21031W	PARTICIPANT	\N	PRESENT	0
797937	797929	19413M	PARTICIPANT	\N	PRESENT	0
797938	797929	99004R	PRESIDENT	0	PRESENT	0
797939	797929	21093M	PARTICIPANT	\N	PRESENT	0
797940	797929	21090J	PARTICIPANT	\N	PRESENT	0
797941	797929	21050A	PARTICIPANT	\N	PRESENT	0
797942	797929	17023S	PARTICIPANT	\N	PRESENT	0
797943	797929	20038A	PARTICIPANT	\N	EXCUSE	0
803966	803965	19711U	PARTICIPANT	\N	PRESENT	0
803967	803965	08056B	PARTICIPANT	\N	PRESENT	0
803968	803965	20134Y	PARTICIPANT	\N	PRESENT	0
803969	803965	19647E	PARTICIPANT	\N	PRESENT	0
803970	803965	20114U	PARTICIPANT	\N	PRESENT	0
803971	803965	21081H	PARTICIPANT	\N	PRESENT	0
803972	803965	08010L	PARTICIPANT	\N	PRESENT	0
803973	803965	14026U	PARTICIPANT	\N	PRESENT	0
803974	803965	14187A	PARTICIPANT	\N	PRESENT	0
803975	803965	14255U	PARTICIPANT	\N	PRESENT	0
803976	803965	14179A	PARTICIPANT	\N	PRESENT	0
803977	803965	20024T	PARTICIPANT	\N	PRESENT	0
803978	803965	19699S	PARTICIPANT	\N	PRESENT	0
803979	803965	11027H	PARTICIPANT	\N	PRESENT	0
803980	803965	14189C	PARTICIPANT	\N	PRESENT	0
803981	803965	14215L	PARTICIPANT	\N	PRESENT	0
803982	803965	20026V	PARTICIPANT	\N	PRESENT	0
803983	803965	20132W	PARTICIPANT	\N	PRESENT	0
804432	804380	19621T	PARTICIPANT	\N	PRESENT	0
804433	804380	19611R	PRESIDENT	0	PRESENT	0
804434	804380	20142Y	PARTICIPANT	\N	PRESENT	0
804436	804380	20102Q	PARTICIPANT	\N	PRESENT	0
804437	804380	21089R	PARTICIPANT	\N	PRESENT	0
804438	804380	14109K	PARTICIPANT	\N	PRESENT	0
804439	804380	19593H	PARTICIPANT	\N	PRESENT	0
804441	804380	20052X	PARTICIPANT	\N	PRESENT	0
804442	804380	19699S	PARTICIPANT	\N	PRESENT	0
804443	804380	19735D	PARTICIPANT	\N	PRESENT	0
804444	804380	14030Q	PARTICIPANT	\N	PRESENT	0
804445	804380	19533U	PARTICIPANT	\N	PRESENT	0
804446	804380	11043H	PARTICIPANT	\N	PRESENT	0
804447	804380	21077M	PARTICIPANT	\N	PRESENT	0
804448	804380	19693L	PARTICIPANT	\N	PRESENT	0
804449	804380	21091K	PARTICIPANT	\N	PRESENT	0
804451	804380	14229S	PARTICIPANT	\N	PRESENT	0
804452	804380	20264J	PARTICIPANT	\N	PRESENT	0
804453	804380	20114U	PARTICIPANT	\N	PRESENT	0
804454	804380	19673G	PARTICIPANT	\N	PRESENT	0
804455	804380	14231L	PARTICIPANT	\N	PRESENT	0
804458	804380	05008E	PARTICIPANT	\N	PRESENT	0
804460	804380	19649G	PARTICIPANT	\N	PRESENT	0
804464	804380	14189C	PARTICIPANT	\N	PRESENT	0
804465	804380	20022R	PARTICIPANT	\N	PRESENT	0
804466	804380	04047H	PARTICIPANT	\N	PRESENT	0
804468	804380	14215L	PARTICIPANT	\N	PRESENT	0
804469	804380	19111A	PARTICIPANT	\N	PRESENT	0
804471	804380	19725B	PARTICIPANT	\N	PRESENT	0
804472	804380	21044C	PARTICIPANT	\N	PRESENT	0
804474	804380	11072N	PARTICIPANT	\N	PRESENT	0
804475	804380	18231D	PARTICIPANT	\N	PRESENT	0
804477	804380	19749K	PARTICIPANT	\N	PRESENT	0
804490	804380	20108W	PARTICIPANT	\N	PRESENT	0
804493	804380	20124W	PARTICIPANT	\N	PRESENT	0
804505	804380	19954N	PARTICIPANT	\N	PRESENT	0
804508	804380	20074E	PARTICIPANT	\N	PRESENT	0
804563	804538	20092G	PARTICIPANT	\N	PRESENT	0
805690	805689	19798U	PARTICIPANT	\N	PRESENT	0
804804	804085	19729F	PARTICIPANT	\N	EXCUSE	0
804805	804085	19585H	PARTICIPANT	\N	EXCUSE	0
805692	805691	04092N	PRESIDENT	0	PRESENT	0
805693	805691	21090J	PRESIDENT	1	PRESENT	0
805694	805691	20080C	PARTICIPANT	\N	PRESENT	0
805695	805691	20140W	PARTICIPANT	\N	PRESENT	0
805696	805691	21049H	PARTICIPANT	\N	PRESENT	0
805697	805691	14189C	PARTICIPANT	\N	PRESENT	0
805698	805691	14213J	PARTICIPANT	\N	PRESENT	0
797468	794084	14069U	PARTICIPANT	\N	PRESENT	0
797469	794084	14231L	PARTICIPANT	\N	PRESENT	0
805699	805691	17965H	PARTICIPANT	\N	PRESENT	0
805701	805691	21042A	PARTICIPANT	\N	PRESENT	0
805725	805691	21081H	PARTICIPANT	\N	PRESENT	0
805726	805691	18193Q	PARTICIPANT	\N	PRESENT	0
806640	804289	20116W	PARTICIPANT	\N	PRESENT	0
806641	804289	21048G	PARTICIPANT	\N	PRESENT	0
806642	804289	20080C	PARTICIPANT	\N	PRESENT	0
806643	804289	19667J	PARTICIPANT	\N	PRESENT	0
806644	804289	14083S	PARTICIPANT	\N	PRESENT	0
806645	804289	19545Y	PARTICIPANT	\N	PRESENT	0
806646	804289	21090J	PARTICIPANT	\N	PRESENT	0
806647	804289	20070A	PARTICIPANT	\N	PRESENT	0
806648	804289	21041Y	PARTICIPANT	\N	PRESENT	0
806649	804289	14327T	PARTICIPANT	\N	PRESENT	0
806650	804289	11074Q	PARTICIPANT	\N	PRESENT	0
806651	804289	11110B	PARTICIPANT	\N	PRESENT	0
806652	804289	19647E	PARTICIPANT	\N	PRESENT	0
806653	804289	19399H	PARTICIPANT	\N	PRESENT	0
806654	804289	11048N	PARTICIPANT	\N	PRESENT	0
806655	804289	14121F	PARTICIPANT	\N	PRESENT	0
806656	804289	20126Y	PARTICIPANT	\N	PRESENT	0
806657	804289	07029T	PARTICIPANT	\N	EXCUSE	0
806658	804289	19711U	PARTICIPANT	\N	PRESENT	0
806659	804289	08010L	PARTICIPANT	\N	PRESENT	0
806660	804289	08034U	PARTICIPANT	\N	PRESENT	0
806661	804289	08009T	PARTICIPANT	\N	PRESENT	0
806662	804289	08011M	PARTICIPANT	\N	PRESENT	0
806663	804289	19573D	PARTICIPANT	\N	PRESENT	0
806664	804289	20050V	PARTICIPANT	\N	EXCUSE	0
806665	804289	14225N	PRESIDENT	0	PRESENT	0
806666	804289	20150Y	PARTICIPANT	\N	PRESENT	0
806667	804289	20044X	PARTICIPANT	\N	PRESENT	0
806668	804289	19687N	PARTICIPANT	\N	PRESENT	0
806669	804289	21079P	PARTICIPANT	\N	PRESENT	0
806670	804289	20062A	PARTICIPANT	\N	PRESENT	0
819213	819211	21075K	PARTICIPANT	\N	PRESENT	0
819214	819211	20286Q	PARTICIPANT	\N	PRESENT	0
819215	819211	21059K	PARTICIPANT	\N	PRESENT	0
819216	819211	14147R	PARTICIPANT	\N	PRESENT	0
819217	819211	20060X	PARTICIPANT	\N	PRESENT	0
819218	819211	19782L	PARTICIPANT	\N	PRESENT	0
819219	819211	18207D	PARTICIPANT	\N	PRESENT	0
819220	819211	21092L	PARTICIPANT	\N	PRESENT	0
819222	819221	20286Q	PARTICIPANT	\N	PRESENT	0
819223	819221	21075K	PARTICIPANT	\N	PRESENT	0
819224	819221	21059K	PARTICIPANT	\N	PRESENT	0
819225	819221	21092L	PARTICIPANT	\N	PRESENT	0
819226	819221	20060X	PARTICIPANT	\N	PRESENT	0
819227	819221	18207D	PARTICIPANT	\N	PRESENT	0
819228	819221	19782L	PARTICIPANT	\N	PRESENT	0
819232	819231	21075K	PARTICIPANT	\N	PRESENT	0
819233	819231	20286Q	PARTICIPANT	\N	PRESENT	0
819234	819231	21059K	PARTICIPANT	\N	PRESENT	0
819235	819231	20090E	PARTICIPANT	\N	PRESENT	0
819267	819266	14257W	PRESIDENT	0	PRESENT	0
819268	819266	14031R	PARTICIPANT	\N	EXCUSE	0
819269	819266	11070L	PARTICIPANT	\N	PRESENT	0
819270	819266	14207L	PARTICIPANT	\N	PRESENT	0
819271	819266	20018V	PARTICIPANT	\N	PRESENT	0
819273	819266	14033T	PARTICIPANT	\N	PRESENT	0
819274	819266	20042V	PARTICIPANT	\N	PRESENT	0
798651	797721	04047H	PRESIDENT	0	PRESENT	0
798652	797721	05008E	PARTICIPANT	\N	PRESENT	0
798653	797721	20108W	PARTICIPANT	\N	PRESENT	0
798655	797721	20036X	PARTICIPANT	\N	PRESENT	0
798657	797721	20074E	PARTICIPANT	\N	PRESENT	0
798660	797721	18231D	PARTICIPANT	\N	PRESENT	0
798661	797721	21057H	PARTICIPANT	\N	PRESENT	0
798663	797721	11085T	PARTICIPANT	\N	PRESENT	0
798664	797721	08018U	PARTICIPANT	\N	PRESENT	0
798666	797721	10015M	PARTICIPANT	\N	PRESENT	0
798668	797721	04045F	PARTICIPANT	\N	PRESENT	0
798669	797721	20266L	PARTICIPANT	\N	PRESENT	0
798676	797721	20022R	PARTICIPANT	\N	PRESENT	0
798677	797721	14053L	PARTICIPANT	\N	PRESENT	0
798679	797721	19447X	PARTICIPANT	\N	PRESENT	0
798693	797721	14151M	PARTICIPANT	\N	PRESENT	0
798695	797721	19649G	PARTICIPANT	\N	PRESENT	0
798697	797721	14089Y	PARTICIPANT	\N	PRESENT	0
798700	797721	21038E	PARTICIPANT	\N	PRESENT	0
798731	797721	19719D	PARTICIPANT	\N	EXCUSE	0
798707	797721	14189C	PARTICIPANT	\N	PRESENT	0
798728	797721	19585H	PARTICIPANT	\N	EXCUSE	0
798730	797721	14231L	PARTICIPANT	\N	EXCUSE	0
798740	797721	14147R	PARTICIPANT	\N	PRESENT	0
798745	797721	19489J	PARTICIPANT	\N	PRESENT	0
798749	797721	21043B	PARTICIPANT	\N	PRESENT	0
798750	797721	14069U	PARTICIPANT	\N	PRESENT	0
798763	797721	21056G	PARTICIPANT	\N	PRESENT	0
799014	798638	20120S	PARTICIPANT	\N	PRESENT	0
800980	797800	14111D	PARTICIPANT	\N	PRESENT	0
800981	797800	21045D	PARTICIPANT	\N	PRESENT	0
800982	797800	21077M	PARTICIPANT	\N	PRESENT	0
800983	797800	11027H	PARTICIPANT	\N	PRESENT	0
800984	797800	20248J	PARTICIPANT	\N	PRESENT	0
800985	797800	11045K	PARTICIPANT	\N	PRESENT	0
800986	797800	19331L	PARTICIPANT	\N	PRESENT	0
800987	797800	20180F	PARTICIPANT	\N	PRESENT	0
800988	797800	14195A	PARTICIPANT	\N	PRESENT	0
800989	797800	21087P	PARTICIPANT	\N	PRESENT	0
800990	797800	21079P	PARTICIPANT	\N	PRESENT	0
800991	797800	21049H	PARTICIPANT	\N	PRESENT	0
800992	797800	19629C	PARTICIPANT	\N	PRESENT	0
800993	797800	20034V	PARTICIPANT	\N	PRESENT	0
800994	797800	14217N	PARTICIPANT	\N	PRESENT	0
800995	797800	21089R	PARTICIPANT	\N	PRESENT	0
800996	797800	14071N	PARTICIPANT	\N	PRESENT	0
800997	797800	20090E	PARTICIPANT	\N	PRESENT	0
800998	797800	21038E	PARTICIPANT	\N	PRESENT	0
800999	797800	19649G	PARTICIPANT	\N	PRESENT	0
801000	797800	19647E	PARTICIPANT	\N	PRESENT	0
801001	797800	14038Y	PARTICIPANT	\N	PRESENT	0
801002	797800	18193Q	PARTICIPANT	\N	PRESENT	0
801003	797800	20264J	PARTICIPANT	\N	PRESENT	0
801004	797800	14281W	PARTICIPANT	\N	PRESENT	0
801005	797800	19413M	PARTICIPANT	\N	PRESENT	0
801006	797800	14229S	PARTICIPANT	\N	PRESENT	0
801007	797800	21071F	PARTICIPANT	\N	PRESENT	0
801008	797800	21082J	PARTICIPANT	\N	PRESENT	0
801009	797800	07029T	PARTICIPANT	\N	PRESENT	0
801010	797800	12016W	PARTICIPANT	\N	PRESENT	0
801011	797800	14021P	PARTICIPANT	\N	PRESENT	0
801012	797800	17965H	PARTICIPANT	\N	PRESENT	0
801013	797800	20080C	PARTICIPANT	\N	PRESENT	0
801014	797800	20092G	PARTICIPANT	\N	PRESENT	0
801015	797800	18207D	PARTICIPANT	\N	PRESENT	0
801016	797800	14030Q	PARTICIPANT	\N	PRESENT	0
801017	797800	08060W	PARTICIPANT	\N	PRESENT	0
801018	797800	21046E	PARTICIPANT	\N	PRESENT	0
801019	797800	14225N	PARTICIPANT	\N	PRESENT	0
801020	797800	20042V	PARTICIPANT	\N	PRESENT	0
801021	797800	14083S	PARTICIPANT	\N	PRESENT	0
801022	797800	21053D	PARTICIPANT	\N	PRESENT	0
801023	797800	14147R	PARTICIPANT	\N	PRESENT	0
801024	797800	19687N	PARTICIPANT	\N	PRESENT	0
801030	797800	20038A	PARTICIPANT	\N	PRESENT	0
801031	797800	19533U	PARTICIPANT	\N	PRESENT	0
801032	797800	19667J	PARTICIPANT	\N	PRESENT	0
801033	797800	18231D	PARTICIPANT	\N	PRESENT	0
801034	797800	20094J	PARTICIPANT	\N	PRESENT	0
801035	797800	21095P	PARTICIPANT	\N	PRESENT	0
801036	797800	08010L	PARTICIPANT	\N	PRESENT	0
801037	797800	14169X	PARTICIPANT	\N	PRESENT	0
801054	797800	19820Y	PARTICIPANT	\N	PRESENT	0
801075	797800	99004R	PARTICIPANT	\N	PRESENT	0
801409	801408	12028B	PARTICIPANT	\N	PRESENT	0
801410	801408	14267Y	PARTICIPANT	\N	PRESENT	0
801411	801408	08010L	PARTICIPANT	\N	PRESENT	0
801413	801412	08009T	PARTICIPANT	\N	PRESENT	0
801414	801412	21090J	PARTICIPANT	\N	PRESENT	0
801416	801415	08009T	PARTICIPANT	\N	PRESENT	0
801417	801415	21090J	PARTICIPANT	\N	PRESENT	0
801419	801418	08034U	PARTICIPANT	\N	PRESENT	0
801421	801420	08034U	PARTICIPANT	\N	PRESENT	0
801423	801422	08034U	PARTICIPANT	\N	PRESENT	0
801425	801424	08034U	PARTICIPANT	\N	PRESENT	0
801427	801426	08034U	PARTICIPANT	\N	PRESENT	0
801429	801428	08034U	PARTICIPANT	\N	PRESENT	0
801432	801431	19573D	PARTICIPANT	\N	PRESENT	0
801434	801433	11048N	PARTICIPANT	\N	PRESENT	0
801436	801435	11048N	PARTICIPANT	\N	PRESENT	0
804315	804314	14331P	PARTICIPANT	\N	PRESENT	0
804316	804314	14107H	PARTICIPANT	\N	PRESENT	0
804317	804314	19820Y	PARTICIPANT	\N	PRESENT	0
804319	804318	14331P	PARTICIPANT	\N	PRESENT	0
804320	804318	14107H	PARTICIPANT	\N	PRESENT	0
804321	804318	19820Y	PARTICIPANT	\N	PRESENT	0
804323	804322	14331P	PARTICIPANT	\N	PRESENT	0
804324	804322	14107H	PARTICIPANT	\N	PRESENT	0
804325	804322	19681G	PARTICIPANT	\N	PRESENT	0
804327	804326	14331P	PARTICIPANT	\N	PRESENT	0
804328	804326	14107H	PARTICIPANT	\N	PRESENT	0
804330	804329	14331P	PARTICIPANT	\N	PRESENT	0
804331	804329	14107H	PARTICIPANT	\N	PRESENT	0
804332	804329	11065P	PARTICIPANT	\N	PRESENT	0
804334	804333	14331P	PARTICIPANT	\N	PRESENT	0
804336	804335	14331P	PARTICIPANT	\N	PRESENT	0
805387	804287	14327T	PARTICIPANT	\N	PRESENT	0
805388	804287	14331P	PARTICIPANT	\N	PRESENT	0
805389	804287	19545Y	PARTICIPANT	\N	PRESENT	0
805390	804287	11053K	PARTICIPANT	\N	PRESENT	0
805391	804287	19667J	PARTICIPANT	\N	PRESENT	0
805392	804287	11070L	PARTICIPANT	\N	PRESENT	0
805393	804287	07029T	PARTICIPANT	\N	PRESENT	0
805394	804287	19573D	PARTICIPANT	\N	PRESENT	0
805395	804287	19335Q	PARTICIPANT	\N	PRESENT	0
805396	804287	20024T	PARTICIPANT	\N	PRESENT	0
805397	804287	11048N	PARTICIPANT	\N	PRESENT	0
805398	804287	19647E	PARTICIPANT	\N	PRESENT	0
805400	804287	19687N	PARTICIPANT	\N	PRESENT	0
805401	804287	20050V	PARTICIPANT	\N	PRESENT	0
805402	804287	20044X	PARTICIPANT	\N	PRESENT	0
805403	804287	19399H	PARTICIPANT	\N	PRESENT	0
805404	804287	21041Y	PARTICIPANT	\N	PRESENT	0
805405	804287	11040E	PARTICIPANT	\N	PRESENT	0
805406	804287	14083S	PARTICIPANT	\N	PRESENT	0
805407	804287	20062A	PARTICIPANT	\N	PRESENT	0
805408	804287	20070A	PARTICIPANT	\N	PRESENT	0
805409	804287	21069M	PARTICIPANT	\N	PRESENT	0
805410	804287	14121F	PARTICIPANT	\N	PRESENT	0
805412	804287	21072G	PARTICIPANT	\N	PRESENT	0
805413	804287	20080C	PARTICIPANT	\N	PRESENT	0
805414	804287	20094J	PARTICIPANT	\N	PRESENT	0
805415	804287	11074Q	PARTICIPANT	\N	PRESENT	0
805416	804287	14225N	PRESIDENT	0	PRESENT	0
805417	804287	21079P	PARTICIPANT	\N	PRESENT	0
805418	804287	07004J	PARTICIPANT	\N	PRESENT	0
805419	804287	08010L	PARTICIPANT	\N	PRESENT	0
805420	804287	20116W	PARTICIPANT	\N	PRESENT	0
805421	804287	21090J	PARTICIPANT	\N	PRESENT	0
805422	804287	14253S	PARTICIPANT	\N	PRESENT	0
805423	804287	20126Y	PARTICIPANT	\N	PRESENT	0
805424	804287	19479G	PARTICIPANT	\N	PRESENT	0
805425	804287	19711U	PARTICIPANT	\N	PRESENT	0
805427	804287	08034U	PARTICIPANT	\N	PRESENT	0
805429	804287	08011M	PARTICIPANT	\N	PRESENT	0
805430	804287	20150Y	PARTICIPANT	\N	PRESENT	0
805431	804287	14173T	PARTICIPANT	\N	PRESENT	0
805433	804287	08009T	PARTICIPANT	\N	PRESENT	0
813735	808394	19295A	PARTICIPANT	\N	PRESENT	0
796817	794075	14026U	PARTICIPANT	\N	PRESENT	0
796818	794075	18395Y	PARTICIPANT	\N	PRESENT	0
796819	794075	21067K	PARTICIPANT	\N	PRESENT	0
806671	804289	21069M	PARTICIPANT	\N	PRESENT	0
806674	806673	19479G	PARTICIPANT	\N	PRESENT	0
796822	794075	21062E	PARTICIPANT	\N	PRESENT	0
800746	797967	20070A	PARTICIPANT	\N	EXCUSE	0
806675	806673	19533U	PARTICIPANT	\N	PRESENT	0
806677	806676	19479G	PARTICIPANT	\N	PRESENT	0
806678	806676	14231L	PARTICIPANT	\N	PRESENT	0
806680	806679	19479G	PARTICIPANT	\N	PRESENT	0
806681	806679	14231L	PARTICIPANT	\N	PRESENT	0
806686	806676	20110Q	PARTICIPANT	\N	PRESENT	0
807332	807286	14038Y	PARTICIPANT	\N	PRESENT	0
807333	807286	18231D	PARTICIPANT	\N	PRESENT	0
807334	807330	19735D	PARTICIPANT	\N	PRESENT	0
807335	807330	19723Y	PARTICIPANT	\N	PRESENT	0
807336	807331	19735D	PARTICIPANT	\N	PRESENT	0
807337	807331	19723Y	PARTICIPANT	\N	PRESENT	0
807346	807345	21067K	PARTICIPANT	\N	PRESENT	0
807340	807282	20252E	PARTICIPANT	\N	PRESENT	0
807344	807343	21067K	PARTICIPANT	\N	PRESENT	0
807348	807347	20094J	PARTICIPANT	\N	PRESENT	0
807349	807347	18207D	PARTICIPANT	\N	PRESENT	0
807350	807347	21055F	PARTICIPANT	\N	PRESENT	0
807351	807347	05012A	PARTICIPANT	\N	PRESENT	0
807352	807347	20060X	PARTICIPANT	\N	PRESENT	0
810830	810745	19723Y	PARTICIPANT	\N	PRESENT	0
810831	810745	21064G	PARTICIPANT	\N	PRESENT	0
818369	818012	14179A	PARTICIPANT	\N	PRESENT	0
818371	818012	99004R	PARTICIPANT	\N	PRESENT	0
818372	818012	14191V	PARTICIPANT	\N	PRESENT	0
818373	818012	17367Q	PARTICIPANT	\N	PRESENT	0
818374	818012	14267Y	PARTICIPANT	\N	PRESENT	0
818376	818012	07033P	PARTICIPANT	\N	PRESENT	0
818377	818012	04042C	PARTICIPANT	\N	PRESENT	0
818379	818012	14097Y	PARTICIPANT	\N	PRESENT	0
818380	818012	21067K	PARTICIPANT	\N	PRESENT	0
818382	818012	14001X	PARTICIPANT	\N	PRESENT	0
818383	818012	21031W	PARTICIPANT	\N	PRESENT	0
818384	818012	21073H	PARTICIPANT	\N	PRESENT	0
818385	818012	19565D	PARTICIPANT	\N	PRESENT	0
818386	818012	20072C	PARTICIPANT	\N	PRESENT	0
818387	818012	14193X	PRESIDENT	0	PRESENT	0
818388	818012	19721W	PARTICIPANT	\N	PRESENT	0
818389	818012	14255U	PARTICIPANT	\N	PRESENT	0
818390	818012	19531S	PARTICIPANT	\N	PRESENT	0
818391	818012	01058X	PARTICIPANT	\N	PRESENT	0
818392	818012	19745F	PARTICIPANT	\N	PRESENT	0
818393	818012	19701S	PARTICIPANT	\N	PRESENT	0
818394	818012	19725B	PARTICIPANT	\N	PRESENT	0
818396	818012	17737W	PARTICIPANT	\N	PRESENT	0
818397	818012	08069G	PARTICIPANT	\N	PRESENT	0
818427	818426	86034E	PARTICIPANT	\N	PRESENT	0
818429	818426	04047H	PARTICIPANT	\N	PRESENT	0
818430	818426	12028B	PARTICIPANT	\N	PRESENT	0
818432	818426	19629C	PARTICIPANT	\N	PRESENT	0
818433	818426	11056N	PARTICIPANT	\N	PRESENT	0
818434	818426	14259Y	PARTICIPANT	\N	PRESENT	0
818435	818426	14042U	PARTICIPANT	\N	PRESENT	0
818436	818426	14187A	PARTICIPANT	\N	PRESENT	0
818437	818426	19347U	PARTICIPANT	\N	PRESENT	0
818438	818426	14179A	PARTICIPANT	\N	PRESENT	0
818478	818426	11048N	PARTICIPANT	\N	PRESENT	0
818480	818426	14021P	PARTICIPANT	\N	PRESENT	0
818482	818426	19611R	PARTICIPANT	\N	PRESENT	0
818483	818426	14219Q	PARTICIPANT	\N	PRESENT	0
818484	818426	14251Q	PARTICIPANT	\N	PRESENT	0
818485	818426	11085T	PARTICIPANT	\N	PRESENT	0
818486	818426	14071N	PARTICIPANT	\N	PRESENT	0
818488	818426	19593H	PARTICIPANT	\N	PRESENT	0
818490	818426	08061X	PARTICIPANT	\N	PRESENT	0
818491	818426	14193X	PARTICIPANT	\N	PRESENT	0
818493	818426	14331P	PARTICIPANT	\N	PRESENT	0
818495	818426	14225N	PARTICIPANT	\N	PRESENT	0
818497	818426	04033B	PARTICIPANT	\N	PRESENT	0
818498	818426	14229S	PARTICIPANT	\N	PRESENT	0
818500	818426	21069M	PARTICIPANT	\N	PRESENT	0
818502	818426	19301E	PARTICIPANT	\N	PRESENT	0
818503	818426	19479G	PARTICIPANT	\N	PRESENT	0
818962	818961	19760E	PARTICIPANT	\N	PRESENT	1
818963	818961	14026U	PARTICIPANT	\N	PRESENT	1
818964	818961	19683J	PARTICIPANT	\N	PRESENT	1
818978	818977	19683J	PARTICIPANT	\N	PRESENT	0
818979	818977	19569H	PARTICIPANT	\N	PRESENT	0
818980	818977	20130U	PARTICIPANT	\N	PRESENT	0
818994	818993	14249W	PARTICIPANT	\N	PRESENT	0
818995	818993	20056C	PARTICIPANT	\N	PRESENT	0
818996	818993	19647E	PARTICIPANT	\N	PRESENT	0
818997	818993	20052X	PARTICIPANT	\N	PRESENT	0
818998	818993	04042C	PARTICIPANT	\N	PRESENT	0
818999	818993	17737W	PARTICIPANT	\N	PRESENT	0
819008	815825	14217N	PARTICIPANT	\N	PRESENT	0
819009	815825	21094N	PARTICIPANT	\N	PRESENT	0
819010	815826	14217N	PARTICIPANT	\N	PRESENT	0
819011	815826	21094N	PARTICIPANT	\N	PRESENT	0
819012	815826	21097R	PARTICIPANT	\N	PRESENT	0
819016	819015	21089R	PARTICIPANT	\N	PRESENT	0
819017	819015	20102Q	PARTICIPANT	\N	PRESENT	0
819018	819015	19954N	PARTICIPANT	\N	PRESENT	0
819019	819015	19621T	PARTICIPANT	\N	PRESENT	0
819020	819015	14030Q	PARTICIPANT	\N	PRESENT	0
819855	818985	21056G	PARTICIPANT	\N	PRESENT	0
819856	818985	18207D	PARTICIPANT	\N	PRESENT	0
819857	818985	14133K	PARTICIPANT	\N	PRESENT	0
819858	818985	21084L	PARTICIPANT	\N	PRESENT	0
819853	818985	19679N	PARTICIPANT	\N	PRESENT	0
819854	818985	14038Y	PARTICIPANT	\N	PRESENT	0
819859	818985	19383Y	PARTICIPANT	\N	PRESENT	0
819860	818985	14191V	PARTICIPANT	\N	PRESENT	0
819861	818986	11090Q	PARTICIPANT	\N	PRESENT	0
819900	818986	14219Q	PARTICIPANT	\N	PRESENT	0
819901	818986	14237S	PARTICIPANT	\N	PRESENT	0
819864	818986	20092G	PARTICIPANT	\N	PRESENT	0
819865	818986	20084G	PARTICIPANT	\N	PRESENT	0
819902	818986	21086N	PARTICIPANT	\N	PRESENT	0
819867	818986	21062E	PARTICIPANT	\N	PRESENT	0
819868	818986	20106U	PARTICIPANT	\N	PRESENT	0
819869	818986	21076L	PARTICIPANT	\N	PRESENT	0
819870	818986	21093M	PARTICIPANT	\N	PRESENT	0
819871	818986	07029T	PARTICIPANT	\N	PRESENT	0
819905	819088	19367Y	PARTICIPANT	\N	PRESENT	0
819873	818986	20038A	PARTICIPANT	\N	PRESENT	0
819906	819088	14195A	PARTICIPANT	\N	PRESENT	0
819907	819088	20140W	PARTICIPANT	\N	PRESENT	0
819876	818986	21066J	PARTICIPANT	\N	PRESENT	0
819877	818986	19719D	PARTICIPANT	\N	PRESENT	0
819878	818986	21070E	PARTICIPANT	\N	PRESENT	0
819879	818986	11065P	PARTICIPANT	\N	PRESENT	0
819880	818986	14215L	PARTICIPANT	\N	PRESENT	0
819908	819088	14217N	PARTICIPANT	\N	PRESENT	0
819909	819088	14042U	PARTICIPANT	\N	PRESENT	0
819910	819088	08045X	PARTICIPANT	\N	EXCUSE	0
819911	819088	19760E	PARTICIPANT	\N	PRESENT	0
819912	819088	21046E	PARTICIPANT	\N	PRESENT	0
819913	819088	19758L	PARTICIPANT	\N	PRESENT	0
819914	819088	20248J	PARTICIPANT	\N	PRESENT	0
819888	818986	21041Y	PARTICIPANT	\N	PRESENT	0
819915	819088	19691J	PARTICIPANT	\N	PRESENT	0
819890	818986	19782L	PARTICIPANT	\N	PRESENT	0
819916	819088	19569H	PARTICIPANT	\N	PRESENT	0
819892	818986	19679N	PARTICIPANT	\N	PRESENT	0
819917	819088	14213J	PARTICIPANT	\N	PRESENT	0
819894	818986	21056G	PARTICIPANT	\N	PRESENT	0
819895	818986	18207D	PARTICIPANT	\N	PRESENT	0
819896	818986	14133K	PARTICIPANT	\N	PRESENT	0
819897	818986	21084L	PARTICIPANT	\N	PRESENT	0
819918	819088	19683J	PARTICIPANT	\N	PRESENT	0
819899	818986	14191V	PARTICIPANT	\N	PRESENT	0
819919	819088	21081H	PARTICIPANT	\N	PRESENT	0
819920	819088	14223L	PARTICIPANT	\N	PRESENT	0
819921	819088	04092N	PARTICIPANT	\N	PRESENT	0
819922	819088	14071N	PRESIDENT	0	PRESENT	0
819923	819088	20090E	PARTICIPANT	\N	PRESENT	0
819924	819088	17965H	PARTICIPANT	\N	PRESENT	0
819925	819088	19798U	PARTICIPANT	\N	PRESENT	0
819926	819088	19679N	PARTICIPANT	\N	PRESENT	0
819927	819088	19703U	PARTICIPANT	\N	PRESENT	0
819928	819088	19301E	PARTICIPANT	\N	PRESENT	0
819943	819088	19723Y	PARTICIPANT	\N	PRESENT	0
819944	819088	14355X	PARTICIPANT	\N	PRESENT	0
821333	821331	19611R	PARTICIPANT	\N	PRESENT	0
821334	821331	11043H	PARTICIPANT	\N	PRESENT	0
821335	821331	14073Q	PARTICIPANT	\N	PRESENT	0
821336	821331	08012N	PARTICIPANT	\N	PRESENT	0
821399	821396	14030Q	PARTICIPANT	\N	PRESENT	0
821406	821396	20114U	PARTICIPANT	\N	PRESENT	0
821407	821396	14329V	PARTICIPANT	\N	PRESENT	0
821408	821396	19111A	PARTICIPANT	\N	PRESENT	0
821409	821396	20180F	PARTICIPANT	\N	PRESENT	0
821410	821396	14059S	PARTICIPANT	\N	PRESENT	0
821411	821396	14147R	PARTICIPANT	\N	PRESENT	0
821412	821396	14169X	PARTICIPANT	\N	PRESENT	0
821413	821396	21059K	PARTICIPANT	\N	PRESENT	0
821414	821396	19479G	PARTICIPANT	\N	PRESENT	0
801467	798794	19683J	PARTICIPANT	\N	PRESENT	0
801468	798794	19760E	PARTICIPANT	\N	PRESENT	0
805488	804017	21095P	PARTICIPANT	\N	PRESENT	0
805435	804287	19349W	PARTICIPANT	\N	EXCUSE	0
805436	804017	18231D	PARTICIPANT	\N	PRESENT	0
805437	804017	20022R	PARTICIPANT	\N	PRESENT	0
805438	804017	21057H	PARTICIPANT	\N	PRESENT	0
805489	804017	14111D	PARTICIPANT	\N	PRESENT	0
805440	804017	14231L	PARTICIPANT	\N	PRESENT	0
805441	804017	19725B	PARTICIPANT	\N	PRESENT	0
805442	804017	18207D	PARTICIPANT	\N	PRESENT	0
805443	804017	20108W	PARTICIPANT	\N	PRESENT	0
805444	804017	14215L	PARTICIPANT	\N	PRESENT	0
805445	804017	19489J	PARTICIPANT	\N	PRESENT	0
805490	804017	05008E	PARTICIPANT	\N	PRESENT	0
805447	804017	19749K	PARTICIPANT	\N	PRESENT	0
805448	804017	11072N	PARTICIPANT	\N	PRESENT	0
805449	804017	11056N	PARTICIPANT	\N	PRESENT	0
805450	804017	21044C	PARTICIPANT	\N	PRESENT	0
805451	804017	14147R	PARTICIPANT	\N	PRESENT	0
805452	804017	14151M	PARTICIPANT	\N	PRESENT	0
805453	804017	20110Q	PARTICIPANT	\N	PRESENT	0
805454	804017	19585H	PARTICIPANT	\N	EXCUSE	0
805455	804017	21043B	PARTICIPANT	\N	PRESENT	0
805456	804017	14259Y	PARTICIPANT	\N	PRESENT	0
805457	804017	21038E	PARTICIPANT	\N	PRESENT	0
805491	804017	19729F	PARTICIPANT	\N	EXCUSE	0
805459	804017	14089Y	PARTICIPANT	\N	PRESENT	0
805460	804017	14275Y	PARTICIPANT	\N	PRESENT	0
805461	804017	19649G	PARTICIPANT	\N	PRESENT	0
805492	804017	21056G	PARTICIPANT	\N	EXCUSE	0
805463	804017	20036X	PARTICIPANT	\N	PRESENT	0
805464	804017	21076L	PARTICIPANT	\N	PRESENT	0
805465	804017	04047H	PRESIDENT	0	PRESENT	0
805466	804017	21040X	PARTICIPANT	\N	PRESENT	0
805467	804017	14069U	PARTICIPANT	\N	PRESENT	0
805468	804017	19447X	PARTICIPANT	\N	PRESENT	0
805469	804017	14053L	PARTICIPANT	\N	PRESENT	0
805493	804087	95041E	PARTICIPANT	\N	PRESENT	0
805471	804017	20074E	PARTICIPANT	\N	PRESENT	0
805472	804017	10015M	PARTICIPANT	\N	PRESENT	0
805473	804017	19673G	PARTICIPANT	\N	PRESENT	0
805474	804017	20114U	PARTICIPANT	\N	PRESENT	0
805475	804017	20098N	PARTICIPANT	\N	PRESENT	0
805476	804017	21088Q	PARTICIPANT	\N	PRESENT	0
805477	804017	19111A	PARTICIPANT	\N	PRESENT	0
805478	804017	08018U	PARTICIPANT	\N	PRESENT	0
805479	804017	14189C	PARTICIPANT	\N	PRESENT	0
805494	804087	21031W	PARTICIPANT	\N	PRESENT	0
805495	804087	20072C	PARTICIPANT	\N	PRESENT	0
805496	804087	19565D	PARTICIPANT	\N	PRESENT	0
805497	804087	01058X	PARTICIPANT	\N	PRESENT	0
805498	804087	11027H	PARTICIPANT	\N	PRESENT	0
805499	804087	04042C	PARTICIPANT	\N	PRESENT	0
805500	804087	19669L	PARTICIPANT	\N	PRESENT	0
805501	804087	08056B	PARTICIPANT	\N	PRESENT	0
805502	804087	12028B	PARTICIPANT	\N	PRESENT	0
805503	804087	17737W	PARTICIPANT	\N	PRESENT	0
805504	804087	11115U	PARTICIPANT	\N	PRESENT	0
805505	804087	19421M	PARTICIPANT	\N	PRESENT	0
805506	804087	21067K	PARTICIPANT	\N	PRESENT	0
805507	804087	14193X	PRESIDENT	0	PRESENT	0
805508	804087	19347U	PARTICIPANT	\N	PRESENT	0
805509	804087	07033P	PARTICIPANT	\N	PRESENT	0
805510	804087	17367Q	PARTICIPANT	\N	PRESENT	0
805511	804087	14249W	PARTICIPANT	\N	PRESENT	0
805512	804087	20128B	PARTICIPANT	\N	PRESENT	0
805513	804087	14037X	PARTICIPANT	\N	PRESENT	0
805514	804087	14059S	PARTICIPANT	\N	PRESENT	0
805515	804087	14097Y	PARTICIPANT	\N	PRESENT	0
805516	804087	14133K	PARTICIPANT	\N	PRESENT	0
805517	804087	21073H	PARTICIPANT	\N	PRESENT	0
805518	804087	19531S	PARTICIPANT	\N	PRESENT	0
805519	804087	08069G	PARTICIPANT	\N	PRESENT	0
805520	804087	20042V	PARTICIPANT	\N	PRESENT	0
805521	804087	14191V	PARTICIPANT	\N	PRESENT	0
805522	804087	19721W	PARTICIPANT	\N	PRESENT	0
805523	804087	20064C	PARTICIPANT	\N	PRESENT	0
805524	804087	20252E	PARTICIPANT	\N	PRESENT	0
805525	804087	98022P	PARTICIPANT	\N	PRESENT	0
805526	804087	14267Y	PARTICIPANT	\N	PRESENT	0
805527	804087	99004R	PARTICIPANT	\N	PRESENT	0
805528	804087	19745F	PARTICIPANT	\N	PRESENT	0
805529	804087	14211G	PARTICIPANT	\N	PRESENT	0
805530	804087	14255U	PARTICIPANT	\N	PRESENT	0
805531	804087	17023S	PARTICIPANT	\N	PRESENT	0
805532	804087	08047A	PARTICIPANT	\N	EXCUSE	0
805586	804086	95041E	PARTICIPANT	\N	PRESENT	0
805587	804086	21031W	PARTICIPANT	\N	PRESENT	0
805588	804086	20072C	PARTICIPANT	\N	PRESENT	0
805589	804086	19565D	PARTICIPANT	\N	PRESENT	0
805590	804086	01058X	PARTICIPANT	\N	PRESENT	0
805591	804086	11027H	PARTICIPANT	\N	PRESENT	0
805592	804086	04042C	PARTICIPANT	\N	PRESENT	0
805593	804086	19669L	PARTICIPANT	\N	PRESENT	0
805594	804086	08056B	PARTICIPANT	\N	PRESENT	0
805595	804086	12028B	PARTICIPANT	\N	PRESENT	0
805596	804086	17737W	PARTICIPANT	\N	PRESENT	0
805597	804086	11115U	PARTICIPANT	\N	PRESENT	0
805598	804086	19421M	PARTICIPANT	\N	PRESENT	0
805599	804086	21067K	PARTICIPANT	\N	PRESENT	0
805600	804086	14193X	PRESIDENT	0	PRESENT	0
805601	804086	19347U	PARTICIPANT	\N	PRESENT	0
805602	804086	07033P	PARTICIPANT	\N	PRESENT	0
805603	804086	17367Q	PARTICIPANT	\N	PRESENT	0
805604	804086	14249W	PARTICIPANT	\N	PRESENT	0
805605	804086	20128B	PARTICIPANT	\N	PRESENT	0
805606	804086	14037X	PARTICIPANT	\N	PRESENT	0
805607	804086	14059S	PARTICIPANT	\N	PRESENT	0
805608	804086	14097Y	PARTICIPANT	\N	PRESENT	0
805609	804086	14133K	PARTICIPANT	\N	PRESENT	0
805610	804086	21073H	PARTICIPANT	\N	PRESENT	0
805611	804086	19531S	PARTICIPANT	\N	PRESENT	0
805612	804086	08069G	PARTICIPANT	\N	PRESENT	0
805613	804086	20042V	PARTICIPANT	\N	PRESENT	0
805614	804086	14191V	PARTICIPANT	\N	PRESENT	0
805615	804086	19721W	PARTICIPANT	\N	PRESENT	0
805616	804086	20064C	PARTICIPANT	\N	PRESENT	0
805617	804086	20252E	PARTICIPANT	\N	PRESENT	0
805618	804086	14251Q	PARTICIPANT	\N	PRESENT	0
805619	804086	98022P	PARTICIPANT	\N	PRESENT	0
805620	804086	14267Y	PARTICIPANT	\N	PRESENT	0
805621	804086	99004R	PARTICIPANT	\N	PRESENT	0
805622	804086	19745F	PARTICIPANT	\N	PRESENT	0
805623	804086	14211G	PARTICIPANT	\N	PRESENT	0
805624	804086	14255U	PARTICIPANT	\N	PRESENT	0
805625	804086	17023S	PARTICIPANT	\N	PRESENT	0
805626	804086	08047A	PARTICIPANT	\N	EXCUSE	0
805773	803919	21065H	PARTICIPANT	\N	PRESENT	0
805774	803919	14217N	PARTICIPANT	\N	PRESENT	0
805775	803919	21044C	PARTICIPANT	\N	PRESENT	0
805776	803919	14357A	PARTICIPANT	\N	PRESENT	0
805781	803919	20114U	PARTICIPANT	\N	PRESENT	0
805782	803919	20052X	PARTICIPANT	\N	PRESENT	0
805783	803919	14151M	PARTICIPANT	\N	PRESENT	0
805784	803919	21057H	PARTICIPANT	\N	PRESENT	0
805785	803919	19629C	PARTICIPANT	\N	PRESENT	0
805786	803919	14267Y	PARTICIPANT	\N	PRESENT	0
805787	803919	19383Y	PARTICIPANT	\N	PRESENT	0
805788	803919	19683J	PARTICIPANT	\N	PRESENT	0
805789	803919	08061X	PARTICIPANT	\N	PRESENT	0
805790	803919	19591F	PARTICIPANT	\N	PRESENT	0
805791	803919	14107H	PARTICIPANT	\N	PRESENT	0
805792	803919	21040X	PARTICIPANT	\N	PRESENT	0
805793	803919	21076L	PARTICIPANT	\N	PRESENT	0
805794	803919	14111D	PARTICIPANT	\N	PRESENT	0
805795	803919	21066J	PARTICIPANT	\N	PRESENT	0
805796	803919	20144B	PARTICIPANT	\N	PRESENT	0
805797	803919	21089R	PARTICIPANT	\N	PRESENT	0
805798	803919	21084L	PARTICIPANT	\N	PRESENT	0
805799	803919	11040E	PARTICIPANT	\N	PRESENT	0
805800	803919	21041Y	PARTICIPANT	\N	PRESENT	0
805801	803919	20082E	PARTICIPANT	\N	PRESENT	0
805802	803919	21045D	PARTICIPANT	\N	PRESENT	0
805803	803919	18231D	PARTICIPANT	\N	PRESENT	0
805804	803919	21077M	PARTICIPANT	\N	PRESENT	0
805805	803919	18395Y	PARTICIPANT	\N	PRESENT	0
805806	803919	14257W	PARTICIPANT	\N	PRESENT	0
805807	803919	19489J	PARTICIPANT	\N	PRESENT	0
805808	803919	19725B	PARTICIPANT	\N	PRESENT	0
805809	803919	21031W	PARTICIPANT	\N	PRESENT	0
808400	808399	20136B	PARTICIPANT	\N	PRESENT	0
808402	808401	20136B	PARTICIPANT	\N	PRESENT	0
808404	808403	20136B	PARTICIPANT	\N	PRESENT	0
808405	808403	19826F	PARTICIPANT	\N	PRESENT	0
808406	808403	19551W	PARTICIPANT	\N	PRESENT	0
808407	808403	20100N	PARTICIPANT	\N	PRESENT	0
819550	819549	20050V	PARTICIPANT	\N	PRESENT	0
819553	819552	20050V	PARTICIPANT	\N	PRESENT	0
819556	819555	11074Q	PARTICIPANT	\N	PRESENT	0
819692	819691	11053K	PARTICIPANT	\N	PRESENT	0
819694	819693	21090J	PARTICIPANT	\N	PRESENT	0
819695	819693	08009T	PARTICIPANT	\N	PRESENT	0
820029	820028	14189C	PARTICIPANT	\N	PRESENT	0
820030	820028	04047H	PARTICIPANT	\N	PRESENT	0
820031	820028	14215L	PARTICIPANT	\N	PRESENT	0
820032	820028	20074E	PARTICIPANT	\N	PRESENT	0
820033	820028	19447X	PARTICIPANT	\N	PRESENT	0
820034	820028	18207D	PARTICIPANT	\N	PRESENT	0
820035	820028	18231D	PARTICIPANT	\N	PRESENT	0
820036	820028	21056G	PARTICIPANT	\N	PRESENT	0
820037	820028	04045F	PARTICIPANT	\N	PRESENT	0
820062	820061	21089R	PARTICIPANT	\N	PRESENT	0
820063	820061	19421M	PARTICIPANT	\N	PRESENT	0
820108	820106	19575F	PARTICIPANT	\N	PRESENT	0
820109	820106	11040E	PARTICIPANT	\N	PRESENT	0
820111	820106	07004J	PARTICIPANT	\N	PRESENT	0
820112	820106	14179A	PARTICIPANT	\N	PRESENT	0
820113	820106	14097Y	PARTICIPANT	\N	PRESENT	0
820114	820106	21041Y	PARTICIPANT	\N	EXCUSE	0
820115	820106	08034U	PRESIDENT	0	PRESENT	0
820116	820106	14059S	PARTICIPANT	\N	PRESENT	0
820121	820106	21073H	PARTICIPANT	\N	PRESENT	0
820122	820106	04070G	PARTICIPANT	\N	EXCUSE	0
820123	820106	19745F	PARTICIPANT	\N	PRESENT	0
820124	820106	14225N	PARTICIPANT	\N	EXCUSE	0
820125	820106	10015M	PARTICIPANT	\N	PRESENT	0
820127	820106	14229S	PARTICIPANT	\N	PRESENT	0
820128	820106	19669L	PARTICIPANT	\N	PRESENT	0
820185	820184	20024T	PARTICIPANT	\N	PRESENT	0
802370	802368	14073Q	PARTICIPANT	\N	PRESENT	0
802371	802368	11043H	PARTICIPANT	\N	PRESENT	0
802372	802368	21037D	PARTICIPANT	\N	PRESENT	0
802373	802368	20142Y	PARTICIPANT	\N	PRESENT	0
802374	802368	08012N	PARTICIPANT	\N	PRESENT	0
804117	804116	11053K	PARTICIPANT	\N	PRESENT	0
804119	804118	11053K	PARTICIPANT	\N	PRESENT	0
804144	804143	08009T	PARTICIPANT	\N	PRESENT	0
804145	804143	21048G	PARTICIPANT	\N	PRESENT	0
804146	804143	20086J	PARTICIPANT	\N	PRESENT	0
804147	804143	11040E	PARTICIPANT	\N	PRESENT	0
804151	804143	19399H	PARTICIPANT	\N	PRESENT	0
804149	804143	14083S	PARTICIPANT	\N	PRESENT	0
804150	804143	19545Y	PARTICIPANT	\N	PRESENT	0
804152	804143	11048N	PARTICIPANT	\N	PRESENT	0
804153	804143	14121F	PARTICIPANT	\N	PRESENT	0
804154	804143	19711U	PARTICIPANT	\N	PRESENT	0
804177	804176	20116W	PARTICIPANT	\N	PRESENT	0
804185	804184	20116W	PARTICIPANT	\N	PRESENT	0
804187	804186	20134Y	PARTICIPANT	\N	PRESENT	0
804188	804186	20062A	PARTICIPANT	\N	PRESENT	0
804190	804189	20134Y	PARTICIPANT	\N	PRESENT	0
804191	804189	20062A	PARTICIPANT	\N	PRESENT	0
804193	804192	20134Y	PARTICIPANT	\N	PRESENT	0
804194	804192	20062A	PARTICIPANT	\N	PRESENT	0
804198	804196	11074Q	PARTICIPANT	\N	PRESENT	0
804199	804196	19349W	PARTICIPANT	\N	PRESENT	0
819026	819025	12028B	PARTICIPANT	\N	PRESENT	0
819027	819025	14267Y	PARTICIPANT	\N	PRESENT	0
819028	819025	08010L	PARTICIPANT	\N	PRESENT	0
819033	819031	19667J	PARTICIPANT	\N	PRESENT	0
819034	819032	19667J	PARTICIPANT	\N	PRESENT	0
819948	819088	20148F	PARTICIPANT	\N	PRESENT	0
819949	819088	14281W	PARTICIPANT	\N	PRESENT	0
819957	819088	21039F	PARTICIPANT	\N	PRESENT	0
819958	819088	20096L	PARTICIPANT	\N	PRESENT	0
819961	819088	21064G	PARTICIPANT	\N	PRESENT	0
819962	819088	19866P	PARTICIPANT	\N	PRESENT	0
819996	819088	21071F	PARTICIPANT	\N	PRESENT	0
820053	819088	11045K	PARTICIPANT	\N	PRESENT	0
820054	819088	21097R	PARTICIPANT	\N	PRESENT	0
820055	819088	19629C	PARTICIPANT	\N	PRESENT	0
820060	819088	14026U	PARTICIPANT	\N	PRESENT	0
820069	819088	08061X	PARTICIPANT	\N	PRESENT	0
820070	819088	21045D	PARTICIPANT	\N	PRESENT	0
820071	819088	17779H	PARTICIPANT	\N	PRESENT	0
820072	819088	21094N	PARTICIPANT	\N	EXCUSE	0
820910	818988	19301E	PARTICIPANT	\N	PRESENT	0
820074	819088	21087P	PARTICIPANT	\N	PRESENT	0
820606	818987	17023S	PARTICIPANT	\N	PRESENT	0
820912	818988	19820Y	PARTICIPANT	\N	PRESENT	0
820913	818988	08060W	PARTICIPANT	\N	PRESENT	0
820935	818988	19569H	PARTICIPANT	\N	PRESENT	0
820936	818988	17779H	PARTICIPANT	\N	PRESENT	0
820937	818988	20130U	PARTICIPANT	\N	PRESENT	0
821129	821126	20132W	PARTICIPANT	\N	PRESENT	0
821130	821126	19591F	PARTICIPANT	\N	PRESENT	0
820919	818988	20128B	PARTICIPANT	\N	PRESENT	0
821131	821126	21090J	PRESIDENT	0	PRESENT	0
820921	818988	19697Q	PARTICIPANT	\N	PRESENT	0
820922	818988	14195A	PARTICIPANT	\N	PRESENT	0
820923	820607	19553Y	PARTICIPANT	\N	PRESENT	0
820924	820607	19798U	PARTICIPANT	\N	PRESENT	0
820925	820607	20066E	PRESIDENT	0	PRESENT	0
820926	820607	19691J	PARTICIPANT	\N	PRESENT	0
820934	820607	14147R	PARTICIPANT	\N	PRESENT	0
820938	818988	19760E	PARTICIPANT	\N	PRESENT	0
820939	818988	14217N	PARTICIPANT	\N	PRESENT	0
820940	820608	21068L	PARTICIPANT	\N	PRESENT	0
820941	820608	14109K	PRESIDENT	0	PRESENT	0
820942	820608	95041E	PARTICIPANT	\N	EXCUSE	0
820943	820608	21086N	PARTICIPANT	\N	EXCUSE	0
820944	818988	19758L	PARTICIPANT	\N	PRESENT	0
820947	818988	18193Q	PARTICIPANT	\N	PRESENT	0
820950	818988	14097Y	PARTICIPANT	\N	PRESENT	0
821132	821126	14073Q	PARTICIPANT	\N	PRESENT	0
820955	818988	14083S	PARTICIPANT	\N	PRESENT	0
820957	818988	21085M	PARTICIPANT	\N	PRESENT	0
820958	820608	20122U	PARTICIPANT	\N	PRESENT	0
820959	820608	11074Q	PARTICIPANT	\N	PRESENT	0
820960	820608	21039F	PARTICIPANT	\N	PRESENT	0
820962	818988	21069M	PARTICIPANT	\N	PRESENT	0
821134	821126	10015M	PARTICIPANT	\N	PRESENT	0
821138	821135	20044X	PRESIDENT	0	PRESENT	0
821139	821135	20086J	PARTICIPANT	\N	PRESENT	0
821140	821135	07029T	PARTICIPANT	\N	PRESENT	0
821141	821135	11048N	PARTICIPANT	\N	PRESENT	0
821142	821135	19711U	PARTICIPANT	\N	PRESENT	0
821143	821135	08034U	PARTICIPANT	\N	PRESENT	0
821144	821135	21072G	PARTICIPANT	\N	PRESENT	0
821145	821135	19399H	PARTICIPANT	\N	PRESENT	0
821146	821135	14331P	PARTICIPANT	\N	PRESENT	0
821147	821135	19647E	PARTICIPANT	\N	PRESENT	0
821148	821135	20094J	PARTICIPANT	\N	PRESENT	0
821149	821135	11110B	PARTICIPANT	\N	PRESENT	0
821150	821135	20070A	PARTICIPANT	\N	PRESENT	0
821151	821135	14121F	PARTICIPANT	\N	PRESENT	0
821152	821135	20062A	PARTICIPANT	\N	PRESENT	0
821153	821135	19479G	PARTICIPANT	\N	PRESENT	0
821154	821135	20134Y	PARTICIPANT	\N	PRESENT	0
821155	821135	19545Y	PARTICIPANT	\N	PRESENT	0
821156	821135	19687N	PARTICIPANT	\N	PRESENT	0
821157	821135	14083S	PARTICIPANT	\N	PRESENT	0
821158	821135	08073C	PARTICIPANT	\N	PRESENT	0
821159	821135	07004J	PARTICIPANT	\N	PRESENT	0
821160	821135	21069M	PARTICIPANT	\N	PRESENT	0
821161	821135	21079P	PARTICIPANT	\N	EXCUSE	0
821162	821135	14225N	PARTICIPANT	\N	EXCUSE	0
821163	821135	21048G	PARTICIPANT	\N	EXCUSE	0
821167	820608	14205J	PARTICIPANT	\N	PRESENT	0
821181	818988	19673G	PARTICIPANT	\N	PRESENT	0
821182	818988	20042V	PARTICIPANT	\N	PRESENT	0
821183	818988	21092L	PARTICIPANT	\N	PRESENT	0
821184	818988	19691J	PARTICIPANT	\N	PRESENT	0
821185	818988	19782L	PARTICIPANT	\N	PRESENT	0
821186	818988	19447X	PARTICIPANT	\N	PRESENT	0
821348	818989	21087P	PARTICIPANT	\N	PRESENT	0
821349	818989	14195A	PARTICIPANT	\N	PRESENT	0
821254	818989	21092L	PARTICIPANT	\N	PRESENT	0
821350	818989	20134Y	PARTICIPANT	\N	PRESENT	0
821351	818989	14207L	PARTICIPANT	\N	PRESENT	0
821352	818989	19629C	PARTICIPANT	\N	PRESENT	0
821511	818423	17229F	PARTICIPANT	\N	EXCUSE	0
821530	818423	05008E	PARTICIPANT	\N	PRESENT	0
821532	818423	18083K	PARTICIPANT	\N	PRESENT	0
821261	818989	21037D	PARTICIPANT	\N	PRESENT	0
821535	818423	19691J	PARTICIPANT	\N	PRESENT	0
821537	818423	21097R	PARTICIPANT	\N	PRESENT	0
821538	818423	11072N	PARTICIPANT	\N	PRESENT	0
821539	818423	21029D	PARTICIPANT	\N	PRESENT	0
821540	818423	19331L	PARTICIPANT	\N	PRESENT	0
821541	818423	21055F	PARTICIPANT	\N	PRESENT	0
821542	818423	19745F	PARTICIPANT	\N	PRESENT	0
821544	819014	14053L	PRESIDENT	0	PRESENT	0
821545	819014	20022R	PARTICIPANT	\N	EXCUSE	0
821546	819014	21065H	PARTICIPANT	\N	EXCUSE	0
821547	819014	14327T	PARTICIPANT	\N	EXCUSE	0
821548	819014	14215L	PARTICIPANT	\N	EXCUSE	0
821549	819014	14231L	PARTICIPANT	\N	EXCUSE	0
821550	819014	19531S	PARTICIPANT	\N	EXCUSE	0
821346	818989	19697Q	PARTICIPANT	\N	PRESENT	0
821551	819014	19735D	PARTICIPANT	\N	EXCUSE	0
821552	819014	05012A	PARTICIPANT	\N	EXCUSE	0
821279	818989	20142Y	PARTICIPANT	\N	PRESENT	0
821553	819014	21079P	PARTICIPANT	\N	EXCUSE	0
821554	819014	14173T	PARTICIPANT	\N	EXCUSE	0
821282	818989	20102Q	PARTICIPANT	\N	PRESENT	0
821283	818989	21034A	PARTICIPANT	\N	PRESENT	0
821555	819014	20084G	PARTICIPANT	\N	PRESENT	0
821556	819014	19489J	PARTICIPANT	\N	PRESENT	0
821557	819014	19758L	PARTICIPANT	\N	PRESENT	0
821558	819014	14107H	PARTICIPANT	\N	PRESENT	0
821559	819014	14281W	PARTICIPANT	\N	PRESENT	0
821560	819014	19782L	PARTICIPANT	\N	PRESENT	0
821561	819014	21070E	PARTICIPANT	\N	PRESENT	0
821562	819014	10015M	PARTICIPANT	\N	PRESENT	0
821563	819014	21044C	PARTICIPANT	\N	PRESENT	0
821564	819014	11085T	PARTICIPANT	\N	PRESENT	0
821565	819014	20058E	PARTICIPANT	\N	PRESENT	0
821566	819014	19447X	PARTICIPANT	\N	PRESENT	0
821347	818989	04045F	PARTICIPANT	\N	PRESENT	0
811521	811520	14133K	PARTICIPANT	\N	PRESENT	0
811522	811520	20094J	PARTICIPANT	\N	PRESENT	0
811531	811530	14133K	PARTICIPANT	\N	PRESENT	0
811532	811530	20094J	PARTICIPANT	\N	PRESENT	0
818672	814472	19533U	PARTICIPANT	\N	PRESENT	0
818673	814472	21074J	PARTICIPANT	\N	PRESENT	0
818674	814472	19699S	PARTICIPANT	\N	PRESENT	0
818675	814472	21091K	PARTICIPANT	\N	PRESENT	0
818945	818943	19611R	PARTICIPANT	\N	PRESENT	0
818946	818943	11043H	PARTICIPANT	\N	PRESENT	0
818947	818943	21037D	PARTICIPANT	\N	PRESENT	0
818948	818944	19611R	PARTICIPANT	\N	PRESENT	0
818949	818944	11043H	PARTICIPANT	\N	PRESENT	0
819775	819774	20264J	PARTICIPANT	\N	PRESENT	0
819776	819774	20052X	PARTICIPANT	\N	PRESENT	0
819777	819774	19954N	PARTICIPANT	\N	PRESENT	0
797805	797804	14225N	PARTICIPANT	\N	PRESENT	0
797806	797804	11048N	PARTICIPANT	\N	PRESENT	0
797807	797804	19335Q	PARTICIPANT	\N	PRESENT	0
797808	797804	14331P	PARTICIPANT	\N	PRESENT	0
797812	797811	14225N	PARTICIPANT	\N	PRESENT	0
797814	797813	11065P	PARTICIPANT	\N	PRESENT	0
797816	797815	20094J	PARTICIPANT	\N	PRESENT	0
797820	797819	04008A	PARTICIPANT	\N	PRESENT	0
797821	797819	14213J	PARTICIPANT	\N	PRESENT	0
797822	797819	21054E	PARTICIPANT	\N	PRESENT	0
797823	797819	21029D	PARTICIPANT	\N	PRESENT	0
797824	797819	19531S	PARTICIPANT	\N	PRESENT	0
797825	797819	14147R	PARTICIPANT	\N	PRESENT	0
797827	797826	20286Q	PARTICIPANT	\N	PRESENT	1
797828	797826	21082J	PARTICIPANT	\N	PRESENT	1
805810	803919	21059K	PARTICIPANT	\N	PRESENT	0
805878	803919	11072N	PARTICIPANT	\N	PRESENT	0
805879	803919	21097R	PARTICIPANT	\N	PRESENT	0
805880	803919	19331L	PARTICIPANT	\N	PRESENT	0
805884	803919	20150Y	PARTICIPANT	\N	PRESENT	0
805882	803919	20146D	PARTICIPANT	\N	PRESENT	0
805883	803919	14069U	PARTICIPANT	\N	PRESENT	0
805885	803919	19301E	PARTICIPANT	\N	PRESENT	0
805886	803919	04047H	PARTICIPANT	\N	PRESENT	0
805887	803919	14187A	PARTICIPANT	\N	PRESENT	0
805888	803919	21091K	PARTICIPANT	\N	PRESENT	0
805889	803919	20116W	PARTICIPANT	\N	PRESENT	0
805890	803919	20038A	PARTICIPANT	\N	PRESENT	0
805891	803919	14207L	PARTICIPANT	\N	PRESENT	0
805892	803919	08018U	PARTICIPANT	\N	PRESENT	0
805893	803919	19719D	PARTICIPANT	\N	PRESENT	0
805894	803919	20172F	PARTICIPANT	\N	PRESENT	0
805895	803919	20132W	PARTICIPANT	\N	PRESENT	0
805896	803919	20120S	PARTICIPANT	\N	PRESENT	0
805897	803919	14033T	PARTICIPANT	\N	PRESENT	0
805898	803919	19553Y	PARTICIPANT	\N	PRESENT	0
805899	803919	14123H	PARTICIPANT	\N	PRESENT	0
805900	803919	20072C	PARTICIPANT	\N	PRESENT	0
805901	803919	14026U	PARTICIPANT	\N	PRESENT	0
805902	803919	21046E	PARTICIPANT	\N	PRESENT	0
805903	803919	19399H	PARTICIPANT	\N	PRESENT	0
805904	803919	19545Y	PARTICIPANT	\N	PRESENT	0
805905	803919	11048N	PARTICIPANT	\N	PRESENT	0
805906	803919	14195A	PARTICIPANT	\N	PRESENT	0
805907	803919	14213J	PARTICIPANT	\N	PRESENT	0
805908	803919	19693L	PARTICIPANT	\N	PRESENT	0
805909	803919	14211G	PARTICIPANT	\N	PRESENT	0
805910	803919	21054E	PARTICIPANT	\N	PRESENT	0
805911	803919	14251Q	PARTICIPANT	\N	PRESENT	0
805912	803919	19447X	PARTICIPANT	\N	PRESENT	0
805913	803919	21087P	PARTICIPANT	\N	PRESENT	0
805914	803919	19705W	PARTICIPANT	\N	PRESENT	0
805915	803919	04033B	PARTICIPANT	\N	PRESENT	0
805916	803919	14221J	PARTICIPANT	\N	PRESENT	0
805917	803919	21070E	PARTICIPANT	\N	PRESENT	0
805918	803919	21068L	PARTICIPANT	\N	PRESENT	0
805919	803919	19798U	PARTICIPANT	\N	PRESENT	0
806788	804142	19798U	PARTICIPANT	\N	PRESENT	0
805921	803919	20122U	PARTICIPANT	\N	PRESENT	0
805922	803919	19631V	PARTICIPANT	\N	PRESENT	0
805923	803919	20094J	PARTICIPANT	\N	PRESENT	0
805924	803919	08060W	PARTICIPANT	\N	PRESENT	0
805925	803919	20080C	PARTICIPANT	\N	PRESENT	0
805926	803919	12028B	PARTICIPANT	\N	PRESENT	0
805927	803919	20264J	PARTICIPANT	\N	PRESENT	0
805928	803919	11027H	PARTICIPANT	\N	PRESENT	0
805929	803919	20070A	PARTICIPANT	\N	PRESENT	0
805930	803919	21067K	PARTICIPANT	\N	PRESENT	0
805931	803919	19251M	PARTICIPANT	\N	PRESENT	0
805932	803919	11074Q	PARTICIPANT	\N	PRESENT	0
805933	803919	19551W	PARTICIPANT	\N	PRESENT	0
805934	803919	14121F	PARTICIPANT	\N	PRESENT	0
805935	803919	19531S	PARTICIPANT	\N	PRESENT	0
805936	803919	14097Y	PARTICIPANT	\N	PRESENT	0
805937	803919	14021P	PARTICIPANT	\N	PRESENT	0
805938	803919	19649G	PARTICIPANT	\N	PRESENT	0
805939	803919	18207D	PARTICIPANT	\N	PRESENT	0
805940	803919	08012N	PARTICIPANT	\N	PRESENT	0
805941	803919	17779H	PARTICIPANT	\N	PRESENT	0
805942	803919	14109K	PARTICIPANT	\N	PRESENT	0
805943	803919	20030R	PARTICIPANT	\N	PRESENT	0
805944	803919	17965H	PARTICIPANT	\N	PRESENT	0
805945	803919	14225N	PARTICIPANT	\N	PRESENT	0
805946	803919	11045K	PARTICIPANT	\N	PRESENT	0
805947	803919	20084G	PARTICIPANT	\N	PRESENT	0
805948	803919	19669L	PARTICIPANT	\N	PRESENT	0
805949	803919	19413M	PARTICIPANT	\N	PRESENT	0
805950	803919	21051B	PARTICIPANT	\N	PRESENT	0
805951	803919	20064C	PARTICIPANT	\N	PRESENT	0
805952	803919	21082J	PARTICIPANT	\N	PRESENT	0
805953	803919	21042A	PARTICIPANT	\N	PRESENT	0
805954	803919	14189C	PARTICIPANT	\N	PRESENT	0
805955	803919	14030Q	PARTICIPANT	\N	PRESENT	0
805956	803919	21050A	PARTICIPANT	\N	PRESENT	0
805957	803919	20042V	PARTICIPANT	\N	PRESENT	0
805958	803919	14089Y	PARTICIPANT	\N	PRESENT	0
805959	803919	14255U	PARTICIPANT	\N	PRESENT	0
805960	803919	21083K	PARTICIPANT	\N	PRESENT	0
805961	803919	14083S	PARTICIPANT	\N	PRESENT	0
805962	803919	11053K	PARTICIPANT	\N	PRESENT	0
805963	803919	19721W	PARTICIPANT	\N	PRESENT	0
805964	803919	11115U	PARTICIPANT	\N	PRESENT	0
805965	803919	11070L	PARTICIPANT	\N	PRESENT	0
805966	803919	14327T	PARTICIPANT	\N	PRESENT	0
805967	803919	17229F	PARTICIPANT	\N	PRESENT	0
805968	803919	15197G	PARTICIPANT	\N	PRESENT	0
805969	803919	14042U	PARTICIPANT	\N	PRESENT	0
805970	803919	21086N	PARTICIPANT	\N	PRESENT	0
805971	803919	19111A	PARTICIPANT	\N	PRESENT	0
805972	803919	17023S	PARTICIPANT	\N	PRESENT	0
805973	803919	14231L	PARTICIPANT	\N	PRESENT	0
806786	804142	14179A	PARTICIPANT	\N	EXCUSE	0
806789	804142	14109K	PARTICIPANT	\N	PRESENT	0
806790	804142	20038A	PARTICIPANT	\N	PRESENT	0
806791	804142	14147R	PARTICIPANT	\N	PRESENT	0
806792	804142	19693L	PARTICIPANT	\N	PRESENT	0
806793	804142	19749K	PRESIDENT	0	PRESENT	0
806794	804142	14038Y	PARTICIPANT	\N	PRESENT	0
806795	804142	19711U	PARTICIPANT	\N	PRESENT	0
806796	804142	19533U	PARTICIPANT	\N	PRESENT	0
806797	804142	20072C	PARTICIPANT	\N	PRESENT	0
806798	804142	20092G	PARTICIPANT	\N	PRESENT	0
806799	804142	20018V	PARTICIPANT	\N	PRESENT	0
806800	804142	18231D	PARTICIPANT	\N	PRESENT	0
806801	804142	20026V	PARTICIPANT	\N	PRESENT	0
806802	804142	20132W	PARTICIPANT	\N	PRESENT	0
806803	804142	86034E	PARTICIPANT	\N	PRESENT	0
806804	804142	21038E	PARTICIPANT	\N	PRESENT	0
806818	804142	21094N	PARTICIPANT	\N	PRESENT	0
806843	804142	21089R	PARTICIPANT	\N	PRESENT	0
806861	804142	21091K	PARTICIPANT	\N	EXCUSE	0
806953	804142	20042V	PARTICIPANT	\N	PRESENT	0
807196	807195	19649G	PARTICIPANT	\N	PRESENT	0
807197	807195	21095P	PARTICIPANT	\N	PRESENT	0
807199	807198	21095P	PARTICIPANT	\N	PRESENT	0
807201	807200	21095P	PARTICIPANT	\N	PRESENT	0
807203	807202	21095P	PARTICIPANT	\N	PRESENT	0
807209	807208	04047H	PARTICIPANT	\N	PRESENT	0
807210	807208	21057H	PARTICIPANT	\N	PRESENT	0
807211	807208	21044C	PARTICIPANT	\N	PRESENT	0
807212	807208	21095P	PARTICIPANT	\N	PRESENT	0
807213	807208	19749K	PARTICIPANT	\N	PRESENT	0
807214	807208	19649G	PARTICIPANT	\N	PRESENT	0
807215	807208	11072N	PARTICIPANT	\N	PRESENT	0
807216	807208	21038E	PARTICIPANT	\N	PRESENT	0
807217	807208	21054E	PARTICIPANT	\N	PRESENT	0
810258	810204	14059S	PARTICIPANT	\N	EXCUSE	0
810764	810036	14217N	PARTICIPANT	\N	PRESENT	0
810268	810267	20076G	PARTICIPANT	\N	PRESENT	0
810270	810269	20076G	PARTICIPANT	\N	PRESENT	0
810762	810036	08045X	PARTICIPANT	\N	PRESENT	0
810763	810036	20248J	PARTICIPANT	\N	EXCUSE	0
810765	810036	20090E	PARTICIPANT	\N	PRESENT	0
810766	810036	14026U	PARTICIPANT	\N	PRESENT	0
810767	810036	14213J	PARTICIPANT	\N	PRESENT	0
810768	810036	17779H	PARTICIPANT	\N	PRESENT	0
810769	810036	21039F	PARTICIPANT	\N	PRESENT	0
810770	810036	19703U	PARTICIPANT	\N	PRESENT	0
810771	810036	14071N	PRESIDENT	0	PRESENT	0
810772	810036	19691J	PARTICIPANT	\N	PRESENT	0
820093	819088	21049H	PARTICIPANT	\N	PRESENT	0
820129	819088	01034P	PARTICIPANT	\N	PRESENT	0
820188	819953	04092N	PARTICIPANT	\N	PRESENT	0
820189	819953	14071N	PRESIDENT	\N	PRESENT	0
820190	819953	20090E	PARTICIPANT	\N	PRESENT	0
820191	819953	17965H	PARTICIPANT	\N	PRESENT	0
820192	819953	14213J	PARTICIPANT	\N	PRESENT	0
820193	819953	19683J	PARTICIPANT	\N	PRESENT	0
820194	819953	21081H	PARTICIPANT	\N	PRESENT	0
820195	819953	14223L	PARTICIPANT	\N	PRESENT	0
820196	819953	19758L	PARTICIPANT	\N	PRESENT	0
820197	819953	20248J	PARTICIPANT	\N	PRESENT	0
820198	819953	19691J	PARTICIPANT	\N	PRESENT	0
820199	819953	19569H	PARTICIPANT	\N	PRESENT	0
820200	819953	14042U	PARTICIPANT	\N	PRESENT	0
820201	819953	08045X	PARTICIPANT	\N	EXCUSE	0
820202	819953	19760E	PARTICIPANT	\N	PRESENT	0
820203	819953	21046E	PARTICIPANT	\N	PRESENT	0
820204	819953	01034P	PARTICIPANT	\N	PRESENT	0
820205	819953	21071F	PARTICIPANT	\N	PRESENT	0
820206	819953	14026U	PARTICIPANT	\N	PRESENT	0
820207	819953	19798U	PARTICIPANT	\N	PRESENT	0
820208	819953	11045K	PARTICIPANT	\N	PRESENT	0
820209	819953	19679N	PARTICIPANT	\N	PRESENT	0
820210	819953	21097R	PARTICIPANT	\N	PRESENT	0
820211	819953	19703U	PARTICIPANT	\N	PRESENT	0
820212	819953	19629C	PARTICIPANT	\N	PRESENT	0
820213	819953	19301E	PARTICIPANT	\N	PRESENT	0
820214	819953	14281W	PARTICIPANT	\N	PRESENT	0
820215	819953	21087P	PARTICIPANT	\N	PRESENT	0
820216	819953	20148F	PARTICIPANT	\N	PRESENT	0
820217	819953	08061X	PARTICIPANT	\N	PRESENT	0
820218	819953	21045D	PARTICIPANT	\N	PRESENT	0
820219	819953	19723Y	PARTICIPANT	\N	PRESENT	0
820220	819953	17779H	PARTICIPANT	\N	PRESENT	0
820221	819953	14355X	PARTICIPANT	\N	PRESENT	0
820222	819953	21094N	PARTICIPANT	\N	EXCUSE	0
820223	819953	19367Y	PARTICIPANT	\N	PRESENT	0
820224	819953	14195A	PARTICIPANT	\N	PRESENT	0
820225	819953	20140W	PARTICIPANT	\N	PRESENT	0
820226	819953	14217N	PARTICIPANT	\N	PRESENT	0
820227	819953	21049H	PARTICIPANT	\N	PRESENT	0
820228	819953	21064G	PARTICIPANT	\N	PRESENT	0
820229	819953	19866P	PARTICIPANT	\N	PRESENT	0
820230	819953	21039F	PARTICIPANT	\N	PRESENT	0
820231	819953	20096L	PARTICIPANT	\N	PRESENT	0
820996	820995	14021P	PARTICIPANT	\N	PRESENT	0
820997	820995	19745F	PARTICIPANT	\N	PRESENT	0
821032	820995	21059K	PARTICIPANT	\N	PRESENT	0
821033	820995	21069M	PARTICIPANT	\N	PRESENT	0
821034	820995	20128B	PARTICIPANT	\N	PRESENT	0
821035	820995	04042C	PARTICIPANT	\N	PRESENT	0
797596	794704	05008E	PARTICIPANT	\N	PRESENT	0
797597	794704	08010L	PARTICIPANT	\N	PRESENT	0
797598	794704	19657G	PARTICIPANT	\N	PRESENT	0
797599	794704	11072N	PARTICIPANT	\N	PRESENT	0
797600	794704	12016W	PARTICIPANT	\N	PRESENT	0
797601	794704	20148F	PARTICIPANT	\N	PRESENT	0
797602	794704	19331L	PARTICIPANT	\N	PRESENT	0
797603	794704	08073C	PARTICIPANT	\N	PRESENT	1
797604	794704	20034V	PRESIDENT	0	PRESENT	0
797605	794704	20146D	PARTICIPANT	\N	PRESENT	0
797607	794704	21030V	PARTICIPANT	\N	PRESENT	0
797628	794704	17023S	PARTICIPANT	\N	PRESENT	0
797630	794704	21034A	PARTICIPANT	\N	PRESENT	0
797631	794704	14059S	PARTICIPANT	\N	PRESENT	0
797632	794704	21029D	PARTICIPANT	\N	PRESENT	0
798772	798769	14042U	PARTICIPANT	\N	PRESENT	0
798775	798769	19760E	PARTICIPANT	\N	PRESENT	0
801358	801357	19695N	PARTICIPANT	\N	PRESENT	0
801359	801357	11090Q	PARTICIPANT	\N	PRESENT	0
803844	801149	19533U	PARTICIPANT	\N	PRESENT	0
803846	801149	20092G	PARTICIPANT	\N	PRESENT	0
803848	801149	19575F	PARTICIPANT	\N	PRESENT	0
807640	807635	19760E	PARTICIPANT	\N	PRESENT	0
807641	807635	20248J	PARTICIPANT	\N	PRESENT	0
807642	807635	04092N	PARTICIPANT	\N	PRESENT	0
807643	807639	19760E	PARTICIPANT	\N	PRESENT	0
807645	807639	20248J	PARTICIPANT	\N	PRESENT	0
807646	807639	04092N	PARTICIPANT	\N	PRESENT	0
807728	807353	19707Y	PARTICIPANT	\N	EXCUSE	0
807729	807353	20078J	PARTICIPANT	\N	EXCUSE	0
807730	807353	20104S	PARTICIPANT	\N	EXCUSE	0
807735	807353	14038Y	PARTICIPANT	\N	EXCUSE	0
807736	807353	20038A	PARTICIPANT	\N	EXCUSE	0
807737	807353	19705W	PARTICIPANT	\N	EXCUSE	0
810869	810868	14237S	PARTICIPANT	\N	PRESENT	0
810870	810868	19575F	PARTICIPANT	\N	PRESENT	0
810872	810868	20058E	PARTICIPANT	\N	PRESENT	0
810873	810868	19631V	PARTICIPANT	\N	PRESENT	0
810874	810868	14107H	PARTICIPANT	\N	PRESENT	0
810875	810868	19768N	PARTICIPANT	\N	PRESENT	0
813315	813314	14071N	PARTICIPANT	\N	PRESENT	0
813316	813314	19575F	PARTICIPANT	\N	PRESENT	0
813317	813314	14053L	PARTICIPANT	\N	PRESENT	0
813318	813314	20038A	PARTICIPANT	\N	PRESENT	0
813319	813314	19826F	PARTICIPANT	\N	PRESENT	0
813320	813314	19798U	PARTICIPANT	\N	PRESENT	0
813321	813314	20054A	PARTICIPANT	\N	PRESENT	0
813322	813314	20084G	PARTICIPANT	\N	PRESENT	0
813323	813314	21082J	PARTICIPANT	\N	PRESENT	0
813325	813324	21045D	PARTICIPANT	\N	PRESENT	0
813327	813326	21045D	PARTICIPANT	\N	PRESENT	0
813329	813328	21045D	PARTICIPANT	\N	PRESENT	1
813344	813188	14151M	PRESIDENT	0	PRESENT	0
813345	813188	17367Q	PARTICIPANT	\N	PRESENT	0
813346	813188	19295A	PARTICIPANT	\N	PRESENT	0
813347	813188	12028B	PARTICIPANT	\N	PRESENT	0
813348	813188	17737W	PARTICIPANT	\N	PRESENT	0
813349	813188	20090E	PARTICIPANT	\N	PRESENT	0
813350	813188	15197G	PARTICIPANT	\N	PRESENT	0
813351	813188	18395Y	PARTICIPANT	\N	PRESENT	0
813352	813191	12028B	PARTICIPANT	\N	EXCUSE	0
813353	810435	21089R	PARTICIPANT	\N	PRESENT	0
813354	810435	14229S	PARTICIPANT	\N	PRESENT	0
813355	810435	14021P	PARTICIPANT	\N	PRESENT	0
815111	815110	08012N	PARTICIPANT	\N	PRESENT	0
815112	815110	14073Q	PARTICIPANT	\N	PRESENT	0
815113	815110	11043H	PARTICIPANT	\N	PRESENT	0
815114	815110	21037D	PARTICIPANT	\N	PRESENT	0
815406	813191	14151M	PRESIDENT	0	PRESENT	0
815417	813191	14255U	PARTICIPANT	\N	PRESENT	0
815419	813191	17367Q	PARTICIPANT	\N	PRESENT	0
815422	813191	20110Q	PARTICIPANT	\N	PRESENT	0
816355	800611	14147R	PARTICIPANT	\N	PRESENT	0
816356	800611	19575F	PARTICIPANT	\N	PRESENT	0
816358	800611	20044X	PARTICIPANT	\N	PRESENT	0
816360	800611	08018U	PARTICIPANT	\N	PRESENT	0
816362	800611	20024T	PARTICIPANT	\N	PRESENT	0
816363	800611	14059S	PARTICIPANT	\N	PRESENT	0
816364	800611	21082J	PARTICIPANT	\N	PRESENT	0
816365	800611	19631V	PARTICIPANT	\N	PRESENT	0
816366	800611	19647E	PARTICIPANT	\N	PRESENT	0
816368	800611	21064G	PARTICIPANT	\N	PRESENT	0
816735	815870	14231L	PARTICIPANT	\N	EXCUSE	0
816736	815870	19729F	PARTICIPANT	\N	EXCUSE	0
819045	819042	04092N	PARTICIPANT	\N	PRESENT	0
819046	819042	20248J	PARTICIPANT	\N	PRESENT	0
819047	819042	19760E	PARTICIPANT	\N	PRESENT	0
819048	819042	21081H	PARTICIPANT	\N	PRESENT	0
819049	819042	20130U	PARTICIPANT	\N	PRESENT	0
819050	819043	19760E	PARTICIPANT	\N	PRESENT	0
819051	819043	20248J	PARTICIPANT	\N	PRESENT	0
819052	819043	04092N	PARTICIPANT	\N	PRESENT	0
819053	819044	19760E	PARTICIPANT	\N	PRESENT	0
819054	819044	20248J	PARTICIPANT	\N	PRESENT	0
819055	819044	04092N	PARTICIPANT	\N	PRESENT	0
819059	819058	19798U	PARTICIPANT	\N	PRESENT	0
819060	819058	14223L	PARTICIPANT	\N	PRESENT	0
819061	819058	14281W	PARTICIPANT	\N	PRESENT	0
819062	819058	19691J	PARTICIPANT	\N	PRESENT	0
819084	815836	21094N	PARTICIPANT	\N	PRESENT	0
819085	815836	14217N	PARTICIPANT	\N	PRESENT	0
819086	819013	14217N	PARTICIPANT	\N	PRESENT	0
819087	819013	21094N	PARTICIPANT	\N	PRESENT	0
820234	820233	04047H	PARTICIPANT	\N	PRESENT	0
821569	819014	20090E	PARTICIPANT	\N	PRESENT	0
821570	819014	19621T	PARTICIPANT	\N	PRESENT	0
821580	819014	21068L	PARTICIPANT	\N	PRESENT	0
821581	819014	20070A	PARTICIPANT	\N	PRESENT	0
821921	819432	21081H	PARTICIPANT	\N	PRESENT	1
821922	819432	19723Y	PARTICIPANT	\N	PRESENT	1
821313	818989	19347U	PARTICIPANT	\N	PRESENT	0
821339	818989	20100N	PARTICIPANT	\N	PRESENT	0
821345	818989	18083K	PARTICIPANT	\N	PRESENT	0
821567	819014	20098N	PARTICIPANT	\N	PRESENT	0
821568	819014	20032T	PARTICIPANT	\N	PRESENT	0
808082	805354	14071N	PRESIDENT	0	PRESENT	0
808083	805354	19760E	PARTICIPANT	\N	PRESENT	0
808084	805354	19367Y	PARTICIPANT	\N	PRESENT	0
808085	805354	20248J	PARTICIPANT	\N	PRESENT	0
808086	805354	14217N	PARTICIPANT	\N	PRESENT	0
808101	805354	17965H	PARTICIPANT	\N	PRESENT	0
808102	805354	19657G	PARTICIPANT	\N	PRESENT	0
808103	805354	04092N	PARTICIPANT	\N	PRESENT	0
808104	805354	14223L	PARTICIPANT	\N	PRESENT	0
808105	805354	21039F	PARTICIPANT	\N	PRESENT	0
808106	805354	19798U	PARTICIPANT	\N	PRESENT	0
808107	805354	18193Q	PARTICIPANT	\N	PRESENT	0
808108	805354	21081H	PARTICIPANT	\N	PRESENT	0
808109	805354	19569H	PARTICIPANT	\N	PRESENT	0
808110	805354	08045X	PARTICIPANT	\N	PRESENT	0
808111	805354	19723Y	PARTICIPANT	\N	PRESENT	0
808112	805354	20140W	PARTICIPANT	\N	PRESENT	0
808113	805354	14195A	PARTICIPANT	\N	PRESENT	0
808117	805354	21064G	PARTICIPANT	\N	PRESENT	0
808118	805354	19703U	PARTICIPANT	\N	PRESENT	0
808119	805354	20082E	PARTICIPANT	\N	PRESENT	0
808123	805354	19679N	PARTICIPANT	\N	PRESENT	0
808124	805354	19691J	PARTICIPANT	\N	PRESENT	0
808125	805354	20090E	PARTICIPANT	\N	EXCUSE	0
808126	805354	21046E	PARTICIPANT	\N	EXCUSE	0
808130	805354	19683J	PARTICIPANT	\N	PRESENT	0
808131	805354	14213J	PARTICIPANT	\N	PRESENT	0
808174	805354	14281W	PARTICIPANT	\N	PRESENT	0
808175	805354	21045D	PARTICIPANT	\N	PRESENT	0
808178	805354	14026U	PARTICIPANT	\N	PRESENT	0
808196	805354	20130U	PARTICIPANT	\N	EXCUSE	0
808197	805354	21071F	PARTICIPANT	\N	PRESENT	0
808198	805354	19629C	PARTICIPANT	\N	PRESENT	0
808199	805354	19591F	PARTICIPANT	\N	PRESENT	0
808201	805354	21049H	PARTICIPANT	\N	PRESENT	0
808228	805354	21087P	PARTICIPANT	\N	PRESENT	0
808229	805354	21094N	PARTICIPANT	\N	PRESENT	0
808270	805354	08061X	PARTICIPANT	\N	PRESENT	0
808271	805354	01034P	PARTICIPANT	\N	PRESENT	0
808284	805354	17779H	PARTICIPANT	\N	PRESENT	0
808310	805354	20096L	PARTICIPANT	\N	PRESENT	0
810725	810590	20098N	PARTICIPANT	\N	EXCUSE	0
810726	810590	14251Q	PARTICIPANT	\N	EXCUSE	0
810746	810745	20066E	PRESIDENT	0	PRESENT	0
810747	810745	19553Y	PARTICIPANT	\N	PRESENT	0
810748	810745	18193Q	PARTICIPANT	\N	PRESENT	0
810749	810745	20096L	PARTICIPANT	\N	PRESENT	0
810750	810745	14030Q	PARTICIPANT	\N	PRESENT	0
810751	810745	19798U	PARTICIPANT	\N	PRESENT	0
810752	810745	17965H	PARTICIPANT	\N	PRESENT	0
810753	810745	21094N	PARTICIPANT	\N	EXCUSE	0
810754	810745	20098N	PARTICIPANT	\N	EXCUSE	0
810756	810745	14147R	PARTICIPANT	\N	PRESENT	0
810761	810745	21045D	PARTICIPANT	\N	PRESENT	0
819174	819173	20252E	PARTICIPANT	\N	PRESENT	0
819175	819173	17965H	PARTICIPANT	\N	PRESENT	0
819176	819173	19531S	PARTICIPANT	\N	PRESENT	0
821924	821923	19591F	PARTICIPANT	\N	PRESENT	0
821925	821923	20132W	PARTICIPANT	\N	PRESENT	1
821926	821923	21087P	PARTICIPANT	\N	PRESENT	1
821971	821970	14133K	PARTICIPANT	\N	PRESENT	0
821972	821970	20094J	PARTICIPANT	\N	PRESENT	0
801611	801496	19533U	PARTICIPANT	\N	PRESENT	0
801614	801496	21060C	PARTICIPANT	\N	PRESENT	0
802660	801486	14038Y	PARTICIPANT	\N	PRESENT	1
802662	801486	21080G	PARTICIPANT	\N	PRESENT	0
802665	801486	20132W	PARTICIPANT	\N	PRESENT	0
802673	801486	19687N	PARTICIPANT	\N	PRESENT	0
802669	801486	21059K	PARTICIPANT	\N	PRESENT	0
802672	801486	18207D	PARTICIPANT	\N	PRESENT	0
803852	801373	14231L	PRESIDENT	0	PRESENT	0
803853	801373	19820Y	PARTICIPANT	\N	PRESENT	0
803854	801373	14281W	PARTICIPANT	\N	PRESENT	0
803855	801373	14151M	PARTICIPANT	\N	PRESENT	0
803856	801373	19782L	PARTICIPANT	\N	PRESENT	0
803857	801373	20084G	PARTICIPANT	\N	PRESENT	0
803858	801373	21079P	PARTICIPANT	\N	PRESENT	0
803859	801373	19735D	PARTICIPANT	\N	PRESENT	0
803860	801373	19621T	PARTICIPANT	\N	PRESENT	0
803861	801373	19758L	PARTICIPANT	\N	PRESENT	0
803862	801373	04045F	PARTICIPANT	\N	PRESENT	0
803863	801373	20068G	PARTICIPANT	\N	PRESENT	0
803864	801373	20102Q	PARTICIPANT	\N	PRESENT	0
803865	801373	14026U	PARTICIPANT	\N	PRESENT	0
803866	801373	19447X	PARTICIPANT	\N	PRESENT	0
803867	801373	20090E	PARTICIPANT	\N	PRESENT	0
803868	801373	21065H	PARTICIPANT	\N	PRESENT	0
803869	801373	21068L	PARTICIPANT	\N	PRESENT	0
803870	801373	20022R	PARTICIPANT	\N	PRESENT	0
803871	801373	21048G	PARTICIPANT	\N	PRESENT	0
803872	801373	21047F	PARTICIPANT	\N	PRESENT	0
803873	801373	14053L	PARTICIPANT	\N	EXCUSE	0
803875	801373	14215L	PARTICIPANT	\N	EXCUSE	0
803876	801373	19531S	PARTICIPANT	\N	EXCUSE	0
803877	801373	19489J	PARTICIPANT	\N	EXCUSE	0
803878	801373	08012N	PARTICIPANT	\N	EXCUSE	0
803879	801373	19826F	PARTICIPANT	\N	EXCUSE	0
803880	801373	05012A	PARTICIPANT	\N	EXCUSE	0
803881	801373	14107H	PARTICIPANT	\N	EXCUSE	0
803882	801373	20058E	PARTICIPANT	\N	EXCUSE	0
803883	801373	14173T	PARTICIPANT	\N	EXCUSE	0
803886	803885	19709B	PARTICIPANT	\N	PRESENT	0
803887	803885	20096L	PARTICIPANT	\N	PRESENT	0
803888	803885	18207D	PARTICIPANT	\N	PRESENT	0
803889	803885	20074E	PARTICIPANT	\N	PRESENT	0
803890	803885	19399H	PARTICIPANT	\N	PRESENT	0
803891	803885	19954N	PARTICIPANT	\N	PRESENT	0
803893	803885	17737W	PARTICIPANT	\N	PRESENT	0
803894	803885	21057H	PARTICIPANT	\N	PRESENT	0
803896	801670	21087P	PARTICIPANT	\N	PRESENT	0
803899	801670	04092N	PARTICIPANT	\N	PRESENT	0
803901	801670	14071N	PARTICIPANT	\N	EXCUSE	0
803902	801670	19683J	PARTICIPANT	\N	PRESENT	0
803903	801670	14042U	PARTICIPANT	\N	PRESENT	0
803904	801670	21097R	PARTICIPANT	\N	PRESENT	0
803905	801670	19798U	PARTICIPANT	\N	PRESENT	0
803908	801670	19760E	PARTICIPANT	\N	PRESENT	0
803909	801670	17965H	PARTICIPANT	\N	PRESENT	0
803910	801670	18193Q	PARTICIPANT	\N	EXCUSE	0
803911	801670	14213J	PARTICIPANT	\N	EXCUSE	0
803912	801670	20130U	PARTICIPANT	\N	EXCUSE	0
803913	801670	19657G	PARTICIPANT	\N	PRESENT	0
810773	810036	19713W	PARTICIPANT	\N	PRESENT	0
810774	810036	19295A	PARTICIPANT	\N	PRESENT	0
810775	810036	20140W	PARTICIPANT	\N	PRESENT	0
810776	810036	21087P	PARTICIPANT	\N	EXCUSE	0
810777	810036	21045D	PARTICIPANT	\N	EXCUSE	0
810778	810036	19367Y	PARTICIPANT	\N	EXCUSE	0
810863	810862	21089R	PARTICIPANT	\N	PRESENT	0
810864	810862	21041Y	PARTICIPANT	\N	PRESENT	0
810865	810862	19421M	PARTICIPANT	\N	PRESENT	0
813066	813065	20076G	PARTICIPANT	\N	PRESENT	0
813069	813067	20076G	PARTICIPANT	\N	PRESENT	0
813071	813070	14107H	PARTICIPANT	\N	PRESENT	0
813078	813077	14107H	PARTICIPANT	\N	PRESENT	0
813153	813151	20248J	PARTICIPANT	\N	PRESENT	0
813154	813151	04092N	PARTICIPANT	\N	PRESENT	0
813155	813151	19760E	PARTICIPANT	\N	PRESENT	0
813158	813157	19760E	PARTICIPANT	\N	PRESENT	0
813160	813157	20248J	PARTICIPANT	\N	PRESENT	0
813161	813157	04092N	PARTICIPANT	\N	PRESENT	0
813258	813212	19691J	PARTICIPANT	\N	EXCUSE	0
813265	810591	14053L	PARTICIPANT	\N	PRESENT	0
813266	810591	20172F	PARTICIPANT	\N	PRESENT	0
813267	810591	19553Y	PARTICIPANT	\N	PRESENT	0
813268	810591	14001X	PARTICIPANT	\N	PRESENT	0
813269	810591	05012A	PARTICIPANT	\N	PRESENT	0
813270	810591	21064G	PARTICIPANT	\N	PRESENT	0
813271	810591	20062A	PARTICIPANT	\N	PRESENT	0
813272	810591	21082J	PARTICIPANT	\N	PRESENT	0
815480	815479	21090J	PRESIDENT	0	PRESENT	0
815481	815479	20132W	PARTICIPANT	\N	PRESENT	0
815482	815479	14213J	PARTICIPANT	\N	PRESENT	0
815483	815479	10015M	PARTICIPANT	\N	PRESENT	0
815484	815479	19591F	PARTICIPANT	\N	PRESENT	0
815547	815479	21049H	PARTICIPANT	\N	PRESENT	0
815556	815479	20080C	PARTICIPANT	\N	EXCUSE	0
815557	815479	14189C	PARTICIPANT	\N	EXCUSE	0
815559	815479	20028X	PARTICIPANT	\N	EXCUSE	0
815564	815479	20040T	PARTICIPANT	\N	EXCUSE	0
815853	815852	11090Q	PARTICIPANT	\N	PRESENT	0
815874	815873	14107H	PARTICIPANT	\N	PRESENT	0
818711	813080	21089R	PARTICIPANT	\N	PRESENT	0
818712	815920	14231L	PRESIDENT	0	PRESENT	0
818713	815920	05012A	PARTICIPANT	\N	PRESENT	0
818714	815920	21070E	PARTICIPANT	\N	PRESENT	0
818715	815920	21079P	PARTICIPANT	\N	PRESENT	0
818716	815920	19782L	PARTICIPANT	\N	PRESENT	0
818717	815920	14026U	PARTICIPANT	\N	PRESENT	0
818718	815920	19349W	PARTICIPANT	\N	PRESENT	0
818719	815920	19820Y	PARTICIPANT	\N	PRESENT	0
818720	815920	19531S	PARTICIPANT	\N	PRESENT	0
818721	815920	08012N	PARTICIPANT	\N	PRESENT	0
818722	815920	20070A	PARTICIPANT	\N	PRESENT	0
818723	815920	14327T	PARTICIPANT	\N	PRESENT	0
818724	815920	19735D	PARTICIPANT	\N	PRESENT	0
818725	815920	19866P	PARTICIPANT	\N	PRESENT	0
818726	815920	20068G	PARTICIPANT	\N	PRESENT	0
818727	815920	19573D	PARTICIPANT	\N	PRESENT	0
818728	815920	21068L	PARTICIPANT	\N	PRESENT	0
818729	815920	21065H	PARTICIPANT	\N	PRESENT	0
818730	815920	19447X	PARTICIPANT	\N	PRESENT	0
818731	815920	14219Q	PARTICIPANT	\N	PRESENT	0
818735	815920	20022R	PARTICIPANT	\N	PRESENT	0
818733	815920	19826F	PARTICIPANT	\N	PRESENT	0
818734	815920	20102Q	PARTICIPANT	\N	PRESENT	0
818736	815920	14259Y	PARTICIPANT	\N	PRESENT	0
818737	815920	14331P	PARTICIPANT	\N	PRESENT	0
818738	815920	04047H	PARTICIPANT	\N	PRESENT	0
818739	815920	19621T	PARTICIPANT	\N	PRESENT	0
818740	815920	14215L	PARTICIPANT	\N	PRESENT	0
818741	815920	11085T	PARTICIPANT	\N	PRESENT	0
818742	815920	19758L	PARTICIPANT	\N	EXCUSE	0
818743	815920	20090E	PARTICIPANT	\N	EXCUSE	0
818744	815920	14053L	PARTICIPANT	\N	EXCUSE	0
818745	815920	14281W	PARTICIPANT	\N	EXCUSE	0
818746	815920	20120S	PARTICIPANT	\N	EXCUSE	0
818747	815920	19489J	PARTICIPANT	\N	EXCUSE	0
818748	815920	14107H	PARTICIPANT	\N	EXCUSE	0
818749	815920	04045F	PARTICIPANT	\N	EXCUSE	0
818750	815920	20062A	PARTICIPANT	\N	EXCUSE	0
818751	815920	20058E	PARTICIPANT	\N	EXCUSE	0
818752	815920	14173T	PARTICIPANT	\N	EXCUSE	0
818758	815920	19111A	PARTICIPANT	\N	PRESENT	0
818789	818788	19569H	PARTICIPANT	\N	PRESENT	0
818790	818788	14213J	PARTICIPANT	\N	PRESENT	0
818791	818788	19683J	PARTICIPANT	\N	PRESENT	0
818792	818788	20130U	PARTICIPANT	\N	PRESENT	0
818813	818811	14038Y	PARTICIPANT	\N	PRESENT	0
818814	818811	11065P	PARTICIPANT	\N	PRESENT	0
818815	818811	19251M	PARTICIPANT	\N	PRESENT	0
818816	818811	14187A	PARTICIPANT	\N	PRESENT	0
818818	818811	21062E	PARTICIPANT	\N	PRESENT	0
818819	818811	20106U	PARTICIPANT	\N	PRESENT	0
818820	818811	14219Q	PRESIDENT	0	PRESENT	0
818821	818811	14031R	PARTICIPANT	\N	PRESENT	0
818822	818811	19826F	PARTICIPANT	\N	PRESENT	0
818823	818811	19619A	PARTICIPANT	\N	PRESENT	0
818824	818811	20136B	PARTICIPANT	\N	PRESENT	0
818838	818837	14133K	PARTICIPANT	\N	PRESENT	0
818839	818837	14237S	PARTICIPANT	\N	PRESENT	0
818840	818837	21086N	PARTICIPANT	\N	PRESENT	0
818841	818837	19711U	PARTICIPANT	\N	PRESENT	0
818842	818837	18207D	PARTICIPANT	\N	PRESENT	0
807392	807391	08028W	PARTICIPANT	\N	PRESENT	0
807393	807391	20018V	PARTICIPANT	\N	PRESENT	0
807394	807391	19703U	PARTICIPANT	\N	PRESENT	0
807400	807399	20286Q	PARTICIPANT	\N	PRESENT	0
807401	807399	14187A	PARTICIPANT	\N	PRESENT	0
810150	809348	21063F	PARTICIPANT	\N	PRESENT	0
810151	809348	14073Q	PARTICIPANT	\N	PRESENT	0
810153	809348	19711U	PARTICIPANT	\N	PRESENT	0
810154	809348	08012N	PARTICIPANT	\N	PRESENT	0
810155	809348	18231D	PARTICIPANT	\N	PRESENT	0
819483	818871	20132W	PARTICIPANT	\N	PRESENT	0
819484	818871	19591F	PARTICIPANT	\N	PRESENT	0
819485	818871	10015M	PARTICIPANT	\N	PRESENT	0
819490	818871	18193Q	PARTICIPANT	\N	PRESENT	0
819491	818871	14213J	PARTICIPANT	\N	PRESENT	0
819492	818871	20028X	PARTICIPANT	\N	PRESENT	0
819493	818871	21090J	PRESIDENT	0	PRESENT	0
819497	818871	17965H	PARTICIPANT	\N	PRESENT	0
820048	819993	19768N	PARTICIPANT	\N	PRESENT	0
820049	819993	20038A	PARTICIPANT	\N	PRESENT	0
820050	819993	21093M	PARTICIPANT	\N	PRESENT	0
820051	818880	20036X	PARTICIPANT	\N	PRESENT	0
820052	819993	21052C	PARTICIPANT	\N	EXCUSE	0
820056	819993	20060X	PARTICIPANT	\N	PRESENT	0
820057	818880	19673G	PARTICIPANT	\N	PRESENT	0
820058	818880	20114U	PARTICIPANT	\N	PRESENT	0
820059	818880	14259Y	PARTICIPANT	\N	PRESENT	0
820064	818557	21037D	PARTICIPANT	\N	PRESENT	0
820065	818557	20048C	PARTICIPANT	\N	PRESENT	0
820066	818557	19697Q	PARTICIPANT	\N	PRESENT	0
820067	818880	10015M	PARTICIPANT	\N	PRESENT	0
820068	818880	19719D	PARTICIPANT	\N	PRESENT	0
820075	818557	20016T	PARTICIPANT	\N	PRESENT	0
820076	818557	21078N	PARTICIPANT	\N	EXCUSE	0
820077	818880	05008E	PARTICIPANT	\N	PRESENT	0
820078	818880	19111A	PARTICIPANT	\N	PRESENT	0
820079	818880	20022R	PARTICIPANT	\N	PRESENT	0
820080	818880	21040X	PARTICIPANT	\N	PRESENT	0
820081	818557	19057M	PARTICIPANT	\N	PRESENT	0
820082	818557	14021P	PARTICIPANT	\N	PRESENT	0
820083	816766	20134Y	PARTICIPANT	\N	PRESENT	0
820084	816766	14121F	PARTICIPANT	\N	PRESENT	0
820085	816766	20116W	PARTICIPANT	\N	PRESENT	0
820086	816766	20094J	PARTICIPANT	\N	PRESENT	0
820087	816766	20024T	PRESIDENT	0	PRESENT	0
820088	816766	11040E	PARTICIPANT	\N	PRESENT	0
820089	816766	19687N	PARTICIPANT	\N	PRESENT	0
820090	816766	19647E	PARTICIPANT	\N	PRESENT	0
820091	816766	11110B	PARTICIPANT	\N	PRESENT	0
820092	818880	19489J	PARTICIPANT	\N	PRESENT	0
820094	816766	11048N	PARTICIPANT	\N	PRESENT	0
820095	816766	14083S	PARTICIPANT	\N	PRESENT	0
820096	816766	07029T	PARTICIPANT	\N	PRESENT	0
820097	816766	08009T	PARTICIPANT	\N	PRESENT	0
820098	816766	19335Q	PARTICIPANT	\N	PRESENT	0
820099	816766	14331P	PARTICIPANT	\N	PRESENT	0
820100	816766	19573D	PARTICIPANT	\N	PRESENT	0
820101	816766	19711U	PARTICIPANT	\N	PRESENT	0
820102	816766	19545Y	PARTICIPANT	\N	PRESENT	0
820103	816766	11053K	PARTICIPANT	\N	PRESENT	0
820104	816766	08034U	PARTICIPANT	\N	PRESENT	0
820105	816766	14173T	PARTICIPANT	\N	PRESENT	0
820107	816766	19399H	PARTICIPANT	\N	PRESENT	0
820110	816766	21090J	PARTICIPANT	\N	PRESENT	0
820117	816766	21079P	PARTICIPANT	\N	EXCUSE	0
820118	816766	20044X	PARTICIPANT	\N	EXCUSE	0
820119	816766	14225N	PARTICIPANT	\N	EXCUSE	0
820120	816766	21048G	PARTICIPANT	\N	EXCUSE	0
820126	816766	08010L	PARTICIPANT	\N	PRESENT	0
820130	816766	20080C	PARTICIPANT	\N	PRESENT	0
820131	816766	20126Y	PARTICIPANT	\N	PRESENT	0
820132	816766	20070A	PARTICIPANT	\N	PRESENT	0
820133	818916	21082J	PARTICIPANT	\N	PRESENT	0
820134	818916	21029D	PARTICIPANT	\N	PRESENT	0
820135	818916	19701S	PARTICIPANT	\N	PRESENT	0
820136	818916	21035B	PARTICIPANT	\N	PRESENT	0
820137	818916	21042A	PARTICIPANT	\N	PRESENT	0
820138	818916	14219Q	PRESIDENT	0	PRESENT	0
820139	818916	19820Y	PARTICIPANT	\N	PRESENT	0
820140	818916	19826F	PARTICIPANT	\N	PRESENT	0
820141	818916	21060C	PARTICIPANT	\N	PRESENT	0
820142	818916	21061D	PARTICIPANT	\N	PRESENT	0
820143	818916	21062E	PARTICIPANT	\N	PRESENT	0
820144	818916	18083K	PARTICIPANT	\N	PRESENT	0
820145	818916	21084L	PARTICIPANT	\N	PRESENT	0
820146	818916	20100N	PARTICIPANT	\N	PRESENT	0
820147	818916	19551W	PARTICIPANT	\N	PRESENT	0
820148	818916	14237S	PARTICIPANT	\N	PRESENT	0
820149	818916	05012A	PARTICIPANT	\N	PRESENT	0
820150	818916	21085M	PARTICIPANT	\N	PRESENT	0
820151	818916	08060W	PARTICIPANT	\N	PRESENT	0
820152	818916	20106U	PARTICIPANT	\N	PRESENT	0
820153	818916	15197G	PARTICIPANT	\N	PRESENT	0
820154	818916	20118Y	PARTICIPANT	\N	PRESENT	0
820155	818916	14107H	PARTICIPANT	\N	PRESENT	0
820156	818916	21080G	PARTICIPANT	\N	PRESENT	0
820157	818916	19331L	PARTICIPANT	\N	PRESENT	0
820158	818916	20020P	PARTICIPANT	\N	PRESENT	0
820159	818916	19685L	PARTICIPANT	\N	PRESENT	0
820160	818916	19681G	PARTICIPANT	\N	PRESENT	0
820161	818916	11065P	PARTICIPANT	\N	PRESENT	0
820162	818916	20120S	PARTICIPANT	\N	PRESENT	0
820163	818916	21051B	PARTICIPANT	\N	PRESENT	0
820164	818916	21053D	PARTICIPANT	\N	PRESENT	0
820165	818916	20032T	PARTICIPANT	\N	PRESENT	0
820166	818916	20136B	PARTICIPANT	\N	PRESENT	0
820167	818916	14031R	PARTICIPANT	\N	PRESENT	0
820168	818916	20040T	PARTICIPANT	\N	PRESENT	0
820169	818916	19251M	PARTICIPANT	\N	PRESENT	0
820170	818916	20146D	PARTICIPANT	\N	PRESENT	0
820171	818916	20046A	PARTICIPANT	\N	PRESENT	0
820172	818916	17229F	PARTICIPANT	\N	PRESENT	0
820173	818916	14169X	PARTICIPANT	\N	PRESENT	0
820174	818916	21047F	PARTICIPANT	\N	PRESENT	0
820175	818916	20068G	PARTICIPANT	\N	PRESENT	0
820176	818916	21068L	PARTICIPANT	\N	PRESENT	0
820177	818916	21070E	PARTICIPANT	\N	PRESENT	0
820178	818916	19619A	PARTICIPANT	\N	PRESENT	0
820179	818916	20076G	PARTICIPANT	\N	EXCUSE	0
820180	818916	19387D	PARTICIPANT	\N	EXCUSE	0
820181	818916	21065H	PARTICIPANT	\N	EXCUSE	0
820182	819993	19695N	PARTICIPANT	\N	PRESENT	0
820183	819993	21034A	PARTICIPANT	\N	PRESENT	0
820186	818880	20098N	PARTICIPANT	\N	PRESENT	0
820235	818987	08028W	PARTICIPANT	\N	PRESENT	0
797773	797769	19349W	PARTICIPANT	\N	PRESENT	0
797775	797770	19479G	PARTICIPANT	\N	PRESENT	0
797774	797769	19479G	PARTICIPANT	\N	PRESENT	0
797776	797770	19349W	PARTICIPANT	\N	PRESENT	0
797777	797771	19479G	PARTICIPANT	\N	PRESENT	0
797778	797771	19349W	PARTICIPANT	\N	PRESENT	0
797779	797772	19667J	PARTICIPANT	\N	PRESENT	0
797780	797766	20082E	PARTICIPANT	\N	PRESENT	0
797781	797766	20026V	PARTICIPANT	\N	PRESENT	0
797782	797767	20082E	PARTICIPANT	\N	PRESENT	0
797783	797767	20026V	PARTICIPANT	\N	PRESENT	0
797784	797768	20082E	PARTICIPANT	\N	PRESENT	0
797785	797768	20026V	PARTICIPANT	\N	PRESENT	0
799339	794860	19611R	PRESIDENT	0	PRESENT	0
799340	794860	20112S	PARTICIPANT	\N	PRESENT	0
799341	794860	19593H	PARTICIPANT	\N	PRESENT	0
799342	794860	20102Q	PARTICIPANT	\N	PRESENT	0
799343	794860	21037D	PARTICIPANT	\N	PRESENT	0
799344	794860	20142Y	PARTICIPANT	\N	PRESENT	0
799345	794860	08012N	PARTICIPANT	\N	PRESENT	0
799346	794860	14021P	PARTICIPANT	\N	PRESENT	0
799347	794860	19693L	PARTICIPANT	\N	PRESENT	0
799348	794860	21089R	PARTICIPANT	\N	PRESENT	0
799349	794860	14123H	PARTICIPANT	\N	PRESENT	0
799350	794860	20132W	PARTICIPANT	\N	PRESENT	0
799351	794860	21074J	PARTICIPANT	\N	PRESENT	0
799352	794860	14229S	PARTICIPANT	\N	PRESENT	0
799353	794860	14109K	PARTICIPANT	\N	EXCUSE	0
799354	794860	20172F	PARTICIPANT	\N	PRESENT	0
799355	794860	21063F	PARTICIPANT	\N	PRESENT	0
799356	794860	04033B	PARTICIPANT	\N	PRESENT	0
799357	794860	20138D	PARTICIPANT	\N	PRESENT	0
799358	794860	14030Q	PARTICIPANT	\N	PRESENT	0
799397	794860	19954N	PARTICIPANT	\N	PRESENT	0
799398	794860	19735D	PARTICIPANT	\N	PRESENT	0
799399	794860	14073Q	PARTICIPANT	\N	PRESENT	0
799400	794860	21077M	PARTICIPANT	\N	PRESENT	0
799401	794860	18395Y	PARTICIPANT	\N	PRESENT	0
799402	794860	20026V	PARTICIPANT	\N	PRESENT	0
799403	794860	20124W	PARTICIPANT	\N	PRESENT	0
799404	794860	20052X	PARTICIPANT	\N	PRESENT	0
799405	794860	20056C	PARTICIPANT	\N	PRESENT	0
799406	794860	11043H	PARTICIPANT	\N	PRESENT	0
799407	794860	21055F	PARTICIPANT	\N	PRESENT	0
799408	794860	19533U	PARTICIPANT	\N	PRESENT	0
799409	794860	19621T	PARTICIPANT	\N	PRESENT	0
799410	794860	19697Q	PARTICIPANT	\N	PRESENT	0
799411	794860	21059K	PARTICIPANT	\N	PRESENT	0
799412	794860	20180F	PARTICIPANT	\N	PRESENT	0
799413	794860	21058J	PARTICIPANT	\N	PRESENT	0
799463	794860	20058E	PARTICIPANT	\N	PRESENT	0
799464	794860	21091K	PARTICIPANT	\N	PRESENT	0
799498	794860	20048C	PARTICIPANT	\N	PRESENT	0
799544	794860	20264J	PARTICIPANT	\N	PRESENT	0
799690	799689	20252E	PARTICIPANT	\N	PRESENT	0
804004	804003	17229F	PARTICIPANT	\N	PRESENT	0
804005	804003	19713W	PARTICIPANT	\N	PRESENT	0
804158	804157	21087P	PARTICIPANT	\N	PRESENT	0
804159	804157	14217N	PARTICIPANT	\N	PRESENT	0
804160	804157	21094N	PARTICIPANT	\N	PRESENT	0
804161	804157	21097R	PARTICIPANT	\N	PRESENT	0
804162	801395	21094N	PARTICIPANT	\N	PRESENT	0
804163	801395	21097R	PARTICIPANT	\N	PRESENT	0
804164	801395	21087P	PARTICIPANT	\N	PRESENT	0
804165	801395	14217N	PARTICIPANT	\N	PRESENT	0
804167	804166	14217N	PARTICIPANT	\N	PRESENT	0
804168	804166	21087P	PARTICIPANT	\N	PRESENT	0
804169	804166	21097R	PARTICIPANT	\N	PRESENT	0
804170	804166	21094N	PARTICIPANT	\N	PRESENT	0
804172	804171	14217N	PARTICIPANT	\N	PRESENT	0
804173	804171	21087P	PARTICIPANT	\N	PRESENT	0
804174	804171	21094N	PARTICIPANT	\N	PRESENT	0
804175	804171	21097R	PARTICIPANT	\N	PRESENT	0
804202	804042	20054A	PRESIDENT	0	PRESENT	0
804204	804042	19697Q	PARTICIPANT	\N	PRESENT	0
804205	804042	14083S	PARTICIPANT	\N	PRESENT	0
804206	804042	14357A	PARTICIPANT	\N	PRESENT	0
804207	804042	21058J	PARTICIPANT	\N	PRESENT	0
804208	804042	20052X	PARTICIPANT	\N	PRESENT	0
804209	804042	19695N	PARTICIPANT	\N	PRESENT	0
804210	804042	20038A	PARTICIPANT	\N	PRESENT	0
804211	804042	21064G	PARTICIPANT	\N	EXCUSE	0
804212	804042	20078J	PARTICIPANT	\N	EXCUSE	0
804213	804042	20144B	PARTICIPANT	\N	EXCUSE	0
804214	804042	21080G	PARTICIPANT	\N	EXCUSE	0
804215	804042	08015R	PARTICIPANT	\N	EXCUSE	0
804216	804042	19719D	PARTICIPANT	\N	EXCUSE	0
804217	804042	20088L	PARTICIPANT	\N	EXCUSE	0
804218	804042	21092L	PARTICIPANT	\N	EXCUSE	0
804219	804042	19347U	PARTICIPANT	\N	EXCUSE	0
804220	804042	21052C	PARTICIPANT	\N	EXCUSE	0
804221	804042	21067K	PARTICIPANT	\N	EXCUSE	0
804222	804042	20056C	PARTICIPANT	\N	EXCUSE	0
804223	804042	20126Y	PARTICIPANT	\N	EXCUSE	0
804224	804042	20172F	PARTICIPANT	\N	EXCUSE	0
804225	804042	21045D	PARTICIPANT	\N	EXCUSE	0
804226	804042	21039F	PARTICIPANT	\N	EXCUSE	0
804227	804042	14237S	PARTICIPANT	\N	EXCUSE	0
804228	804042	21051B	PARTICIPANT	\N	EXCUSE	0
804229	804042	21061D	PARTICIPANT	\N	EXCUSE	0
804230	804042	21050A	PARTICIPANT	\N	EXCUSE	0
804385	803915	14111D	PARTICIPANT	\N	PRESENT	0
804386	804286	11048N	PARTICIPANT	\N	PRESENT	0
804387	804286	11053K	PARTICIPANT	\N	PRESENT	0
804388	804286	21090J	PARTICIPANT	\N	PRESENT	0
804389	804286	20116W	PARTICIPANT	\N	PRESENT	0
804390	804286	19399H	PARTICIPANT	\N	PRESENT	0
804391	804286	14225N	PRESIDENT	0	PRESENT	0
804392	804286	20024T	PARTICIPANT	\N	PRESENT	0
804393	804286	08034U	PARTICIPANT	\N	PRESENT	0
804394	804286	20044X	PARTICIPANT	\N	PRESENT	0
804395	804286	21041Y	PARTICIPANT	\N	EXCUSE	0
804396	804286	14083S	PARTICIPANT	\N	PRESENT	0
804397	804286	14121F	PARTICIPANT	\N	PRESENT	0
804398	804286	14327T	PARTICIPANT	\N	PRESENT	0
804399	804286	19573D	PARTICIPANT	\N	PRESENT	0
804400	804286	20070A	PARTICIPANT	\N	PRESENT	0
804410	804286	19647E	PARTICIPANT	\N	PRESENT	0
804411	804286	19687N	PARTICIPANT	\N	PRESENT	0
804412	804286	20080C	PARTICIPANT	\N	PRESENT	0
804413	804286	19349W	PARTICIPANT	\N	PRESENT	0
804414	804286	19335Q	PARTICIPANT	\N	PRESENT	0
804459	803915	19667J	PARTICIPANT	\N	PRESENT	0
804461	803915	19693L	PARTICIPANT	\N	PRESENT	0
804463	803915	14189C	PARTICIPANT	\N	PRESENT	0
804467	803915	21048G	PARTICIPANT	\N	PRESENT	0
804608	803915	20054A	PARTICIPANT	\N	PRESENT	0
804473	803915	21040X	PARTICIPANT	\N	PRESENT	0
804609	803915	08056B	PARTICIPANT	\N	PRESENT	0
804610	803915	14038Y	PARTICIPANT	\N	PRESENT	0
804479	803915	19383Y	PARTICIPANT	\N	PRESENT	0
804611	803915	14069U	PARTICIPANT	\N	PRESENT	0
804481	803915	11074Q	PARTICIPANT	\N	PRESENT	0
804482	803915	21063F	PARTICIPANT	\N	PRESENT	0
804483	803915	11110B	PARTICIPANT	\N	PRESENT	0
804484	803915	20120S	PARTICIPANT	\N	PRESENT	0
804485	803915	21047F	PARTICIPANT	\N	PRESENT	0
804487	803915	05012A	PARTICIPANT	\N	PRESENT	0
804488	803915	21068L	PARTICIPANT	\N	PRESENT	0
804504	803915	21070E	PARTICIPANT	\N	PRESENT	0
804509	803915	20044X	PARTICIPANT	\N	PRESENT	0
804510	803915	19573D	PARTICIPANT	\N	PRESENT	0
804511	803915	20024T	PARTICIPANT	\N	PRESENT	0
804512	803915	19399H	PARTICIPANT	\N	PRESENT	0
804513	803915	20028X	PARTICIPANT	\N	PRESENT	0
804514	803915	14121F	PARTICIPANT	\N	PRESENT	0
804515	803915	99004R	PARTICIPANT	\N	PRESENT	0
804516	803915	21059K	PARTICIPANT	\N	PRESENT	0
804517	803915	20076G	PARTICIPANT	\N	PRESENT	0
804518	803915	20046A	PARTICIPANT	\N	PRESENT	0
804612	803915	20070A	PARTICIPANT	\N	PRESENT	0
804613	803915	21077M	PARTICIPANT	\N	PRESENT	0
804614	803915	20248J	PARTICIPANT	\N	PRESENT	0
804615	803915	20022R	PARTICIPANT	\N	PRESENT	0
804616	803915	14123H	PARTICIPANT	\N	PRESENT	0
804617	803915	21083K	PARTICIPANT	\N	PRESENT	0
804618	803915	20122U	PARTICIPANT	\N	PRESENT	0
804619	803915	19629C	PARTICIPANT	\N	PRESENT	0
804620	803915	19593H	PARTICIPANT	\N	PRESENT	0
804621	803915	19699S	PARTICIPANT	\N	PRESENT	0
804622	803915	20102Q	PARTICIPANT	\N	PRESENT	0
804623	803915	19649G	PARTICIPANT	\N	PRESENT	0
807179	807166	17965H	PARTICIPANT	\N	PRESENT	0
807180	807166	21039F	PARTICIPANT	\N	PRESENT	0
807181	807167	19758L	PARTICIPANT	\N	PRESENT	0
807182	807167	21039F	PARTICIPANT	\N	PRESENT	0
807183	807167	17965H	PARTICIPANT	\N	PRESENT	0
807184	807168	21039F	PARTICIPANT	\N	PRESENT	0
807185	807168	17965H	PARTICIPANT	\N	PRESENT	0
798018	798016	14071N	PARTICIPANT	\N	PRESENT	0
798012	798010	05008E	PARTICIPANT	\N	PRESENT	0
798015	798014	14026U	PARTICIPANT	\N	PRESENT	0
798017	798016	14026U	PARTICIPANT	\N	PRESENT	0
798019	798016	14195A	PARTICIPANT	\N	PRESENT	0
801497	801496	14257W	PRESIDENT	0	PRESENT	0
801498	801496	12016W	PARTICIPANT	\N	EXCUSE	0
801499	801496	19619A	PARTICIPANT	\N	PRESENT	0
801500	801496	14237S	PARTICIPANT	\N	PRESENT	0
801501	801496	11070L	PARTICIPANT	\N	PRESENT	0
801502	801496	19711U	PARTICIPANT	\N	PRESENT	0
801503	801496	19685L	PARTICIPANT	\N	PRESENT	0
801504	801496	20092G	PARTICIPANT	\N	PRESENT	0
801534	801496	20042V	PARTICIPANT	\N	PRESENT	0
801572	801496	20120S	PARTICIPANT	\N	PRESENT	0
802506	801132	20180F	PARTICIPANT	\N	EXCUSE	0
802507	801132	21042A	PARTICIPANT	\N	EXCUSE	0
802848	802847	20098N	PARTICIPANT	\N	PRESENT	0
804054	804053	14111D	PARTICIPANT	\N	PRESENT	0
804061	804058	18231D	PARTICIPANT	\N	PRESENT	0
804057	804055	14111D	PARTICIPANT	\N	PRESENT	0
804059	804058	04047H	PARTICIPANT	\N	PRESENT	0
804060	804058	21044C	PARTICIPANT	\N	PRESENT	0
804062	804058	19111A	PARTICIPANT	\N	PRESENT	0
807191	807190	20076G	PARTICIPANT	\N	PRESENT	0
807193	807192	20076G	PARTICIPANT	\N	PRESENT	0
807255	807253	21067K	PARTICIPANT	\N	PRESENT	0
807257	807253	20252E	PARTICIPANT	\N	PRESENT	0
807259	807258	21067K	PARTICIPANT	\N	PRESENT	0
812069	812068	19693L	PARTICIPANT	\N	PRESENT	0
812070	812068	20074E	PARTICIPANT	\N	PRESENT	0
812071	812068	19723Y	PARTICIPANT	\N	PRESENT	0
812072	812068	19798U	PARTICIPANT	\N	PRESENT	0
813246	813244	14331P	PARTICIPANT	\N	PRESENT	0
813249	813248	14331P	PARTICIPANT	\N	PRESENT	0
813274	813273	04047H	PARTICIPANT	\N	PRESENT	0
813275	813273	18231D	PARTICIPANT	\N	PRESENT	0
813379	813356	21084L	PARTICIPANT	\N	EXCUSE	0
813380	813356	20248J	PARTICIPANT	\N	EXCUSE	0
813381	813356	21031W	PARTICIPANT	\N	EXCUSE	0
817489	817488	14026U	PARTICIPANT	\N	PRESENT	0
817490	817488	14001X	PARTICIPANT	\N	PRESENT	0
817491	817488	04070G	PARTICIPANT	\N	PRESENT	0
817492	817488	14069U	PARTICIPANT	\N	PRESENT	0
817493	817488	17737W	PARTICIPANT	\N	PRESENT	0
817494	817488	14329V	PARTICIPANT	\N	PRESENT	0
817495	817488	11056N	PARTICIPANT	\N	PRESENT	0
817496	817488	07033P	PARTICIPANT	\N	PRESENT	0
817497	817488	21032X	PARTICIPANT	\N	PRESENT	0
817551	817550	04042C	PARTICIPANT	\N	PRESENT	0
817552	817550	01058X	PARTICIPANT	\N	PRESENT	0
817553	817550	19421M	PARTICIPANT	\N	PRESENT	0
817554	817550	14251Q	PARTICIPANT	\N	PRESENT	0
817555	817550	14211G	PARTICIPANT	\N	PRESENT	0
817556	817550	19709B	PARTICIPANT	\N	PRESENT	0
817557	817550	20042V	PARTICIPANT	\N	PRESENT	0
817558	817550	14267Y	PARTICIPANT	\N	PRESENT	0
817559	817550	11115U	PARTICIPANT	\N	PRESENT	0
817560	817550	14001X	PARTICIPANT	\N	PRESENT	0
817561	817550	14097Y	PARTICIPANT	\N	PRESENT	0
817562	817550	11027H	PARTICIPANT	\N	PRESENT	0
817564	817550	12028B	PARTICIPANT	\N	PRESENT	0
817565	817550	19565D	PARTICIPANT	\N	PRESENT	0
817566	817550	20064C	PARTICIPANT	\N	PRESENT	0
817567	817550	21031W	PARTICIPANT	\N	PRESENT	0
817568	817550	19745F	PARTICIPANT	\N	PRESENT	0
817569	817550	20072C	PARTICIPANT	\N	PRESENT	0
817570	817550	21067K	PARTICIPANT	\N	PRESENT	0
817571	817550	14249W	PARTICIPANT	\N	PRESENT	0
817572	817550	19531S	PARTICIPANT	\N	PRESENT	0
817573	817550	17023S	PARTICIPANT	\N	PRESENT	0
817574	817550	21073H	PARTICIPANT	\N	PRESENT	0
817575	817550	20128B	PARTICIPANT	\N	PRESENT	0
817576	817550	14059S	PARTICIPANT	\N	PRESENT	0
817577	817550	14179A	PARTICIPANT	\N	PRESENT	0
817578	817550	07033P	PARTICIPANT	\N	PRESENT	0
817579	817550	14193X	PRESIDENT	0	PRESENT	0
817580	817550	14255U	PARTICIPANT	\N	PRESENT	0
817581	817550	17737W	PARTICIPANT	\N	PRESENT	0
817582	817550	08047A	PARTICIPANT	\N	PRESENT	0
817586	817550	19611R	PARTICIPANT	\N	PRESENT	0
818676	815939	21048G	PARTICIPANT	\N	PRESENT	0
818677	815939	18231D	PARTICIPANT	\N	PRESENT	0
818678	815939	20102Q	PARTICIPANT	\N	PRESENT	0
818679	815939	21055F	PARTICIPANT	\N	PRESENT	0
818680	815939	20038A	PARTICIPANT	\N	PRESENT	0
818843	818837	21084L	PARTICIPANT	\N	PRESENT	0
818844	818837	21093M	PARTICIPANT	\N	PRESENT	0
818894	818893	20042V	PARTICIPANT	\N	PRESENT	0
818895	818893	11070L	PARTICIPANT	\N	PRESENT	0
818896	818893	12016W	PARTICIPANT	\N	PRESENT	0
818897	818893	14257W	PRESIDENT	0	PRESENT	0
818898	818893	20092G	PARTICIPANT	\N	PRESENT	0
818899	818893	19619A	PARTICIPANT	\N	PRESENT	0
818900	818893	14031R	PARTICIPANT	\N	EXCUSE	0
818921	818920	14249W	PARTICIPANT	\N	PRESENT	0
818922	818920	08034U	PRESIDENT	0	PRESENT	0
818923	818920	04070G	PARTICIPANT	\N	PRESENT	0
818924	818920	10015M	PARTICIPANT	\N	PRESENT	0
818925	818920	14229S	PARTICIPANT	\N	PRESENT	0
818926	818920	19669L	PARTICIPANT	\N	PRESENT	0
818928	818920	19575F	PARTICIPANT	\N	EXCUSE	0
818929	818920	07004J	PARTICIPANT	\N	EXCUSE	0
818930	818920	19745F	PARTICIPANT	\N	EXCUSE	0
818932	818919	21090J	PARTICIPANT	\N	PRESENT	0
818933	818919	19591F	PARTICIPANT	\N	PRESENT	0
818934	818919	20132W	PARTICIPANT	\N	PRESENT	1
818935	818927	21090J	PARTICIPANT	\N	PRESENT	0
818936	818927	19591F	PARTICIPANT	\N	PRESENT	0
818937	818931	21090J	PARTICIPANT	\N	PRESENT	0
818938	818931	19591F	PARTICIPANT	\N	PRESENT	0
818951	818950	04047H	PARTICIPANT	\N	PRESENT	0
818954	818950	14097Y	PARTICIPANT	\N	PRESENT	0
818956	818950	14193X	PARTICIPANT	\N	PRESENT	0
818958	818957	14059S	PARTICIPANT	\N	PRESENT	0
818960	818959	11027H	PARTICIPANT	\N	PRESENT	0
819001	819000	08018U	PARTICIPANT	\N	PRESENT	0
819003	819002	19749K	PARTICIPANT	\N	PRESENT	0
819004	819002	19725B	PARTICIPANT	\N	PRESENT	0
819005	819002	20098N	PARTICIPANT	\N	PRESENT	0
819007	819006	19749K	PARTICIPANT	\N	PRESENT	0
819151	819150	17023S	PARTICIPANT	\N	PRESENT	0
819154	819153	17023S	PARTICIPANT	\N	PRESENT	0
819155	819153	20030R	PARTICIPANT	\N	PRESENT	0
819156	819153	14329V	PARTICIPANT	\N	PRESENT	0
819157	819153	21029D	PARTICIPANT	\N	PRESENT	0
819158	819153	14073Q	PARTICIPANT	\N	PRESENT	0
819159	819153	20044X	PARTICIPANT	\N	PRESENT	0
819169	819168	21075K	PARTICIPANT	\N	PRESENT	0
819170	819168	20286Q	PARTICIPANT	\N	PRESENT	0
819171	819168	20090E	PARTICIPANT	\N	PRESENT	0
819172	819168	21065H	PARTICIPANT	\N	PRESENT	0
819178	819177	21075K	PARTICIPANT	\N	PRESENT	0
819179	819177	20286Q	PARTICIPANT	\N	PRESENT	0
819180	819177	20090E	PARTICIPANT	\N	PRESENT	0
819181	819177	18207D	PARTICIPANT	\N	PRESENT	0
819186	819185	08018U	PARTICIPANT	\N	PRESENT	0
819188	819187	08018U	PARTICIPANT	\N	PRESENT	0
819655	818871	21042A	PARTICIPANT	\N	EXCUSE	0
819903	818880	19729F	PARTICIPANT	\N	EXCUSE	0
819904	818880	19585H	PARTICIPANT	\N	PRESENT	0
819929	818880	14053L	PARTICIPANT	\N	PRESENT	0
819930	818880	14111D	PARTICIPANT	\N	PRESENT	0
819931	818880	19649G	PARTICIPANT	\N	PRESENT	0
819932	818880	14189C	PARTICIPANT	\N	PRESENT	0
819933	818880	20074E	PARTICIPANT	\N	PRESENT	0
819934	818880	21076L	PARTICIPANT	\N	PRESENT	0
819935	818880	21057H	PARTICIPANT	\N	PRESENT	0
819936	818880	04047H	PRESIDENT	0	PRESENT	0
819937	818880	14231L	PARTICIPANT	\N	PRESENT	0
819938	818880	19725B	PARTICIPANT	\N	PRESENT	0
819939	818880	11056N	PARTICIPANT	\N	PRESENT	0
819940	818880	20110Q	PARTICIPANT	\N	PRESENT	0
819941	818880	14147R	PARTICIPANT	\N	PRESENT	0
819942	818880	14151M	PARTICIPANT	\N	PRESENT	0
819945	818880	19447X	PARTICIPANT	\N	PRESENT	0
819946	818880	21088Q	PARTICIPANT	\N	PRESENT	0
819947	818880	14215L	PARTICIPANT	\N	PRESENT	0
807585	807584	21084L	PARTICIPANT	\N	PRESENT	0
807586	807584	20024T	PARTICIPANT	\N	PRESENT	0
807587	807584	20114U	PARTICIPANT	\N	PRESENT	0
807588	807584	14083S	PARTICIPANT	\N	PRESENT	0
807589	807584	11027H	PARTICIPANT	\N	PRESENT	0
807590	807584	20070A	PARTICIPANT	\N	PRESENT	0
807591	807584	15197G	PARTICIPANT	\N	PRESENT	0
807592	807584	11074Q	PARTICIPANT	\N	PRESENT	0
807593	807584	17023S	PARTICIPANT	\N	PRESENT	0
807594	807584	20120S	PARTICIPANT	\N	PRESENT	0
807595	807584	19347U	PARTICIPANT	\N	PRESENT	0
807596	807584	19611R	PARTICIPANT	\N	PRESENT	0
807597	807584	14037X	PARTICIPANT	\N	PRESENT	0
807599	807584	20064C	PARTICIPANT	\N	PRESENT	0
810785	810302	19693L	PARTICIPANT	\N	PRESENT	0
810786	810302	14195A	PARTICIPANT	\N	PRESENT	0
810787	810302	21076L	PARTICIPANT	\N	PRESENT	0
810788	810302	18395Y	PARTICIPANT	\N	PRESENT	0
810789	810302	08018U	PARTICIPANT	\N	PRESENT	0
816849	813212	21034A	PARTICIPANT	\N	PRESENT	0
816850	813212	17229F	PARTICIPANT	\N	PRESENT	0
816851	813212	20034V	PRESIDENT	0	PRESENT	0
816852	813212	21073H	PARTICIPANT	\N	PRESENT	0
816853	813212	21030V	PARTICIPANT	\N	PRESENT	0
816854	813212	08073C	PARTICIPANT	\N	PRESENT	0
816856	813212	21035B	PARTICIPANT	\N	PRESENT	0
816857	813212	05008E	PARTICIPANT	\N	PRESENT	0
816862	813212	19331L	PARTICIPANT	\N	PRESENT	0
816863	813212	19657G	PARTICIPANT	\N	PRESENT	0
816864	813212	14059S	PARTICIPANT	\N	EXCUSE	0
816865	813212	19745F	PARTICIPANT	\N	EXCUSE	0
816961	813212	18083K	PARTICIPANT	\N	PRESENT	0
816977	813212	19673G	PARTICIPANT	\N	PRESENT	0
816978	813212	21055F	PARTICIPANT	\N	PRESENT	0
817020	814010	05008E	PARTICIPANT	\N	PRESENT	0
817022	814010	21035B	PARTICIPANT	\N	PRESENT	0
817023	814010	18083K	PARTICIPANT	\N	PRESENT	0
817024	814010	21034A	PARTICIPANT	\N	PRESENT	0
817025	814010	17229F	PARTICIPANT	\N	PRESENT	0
817026	814010	19673G	PARTICIPANT	\N	PRESENT	0
817027	814010	20034V	PARTICIPANT	\N	PRESENT	0
817028	814010	21073H	PARTICIPANT	\N	PRESENT	0
817029	814010	21029D	PARTICIPANT	\N	PRESENT	0
817030	814010	19331L	PARTICIPANT	\N	PRESENT	0
817031	814010	08073C	PARTICIPANT	\N	PRESENT	0
817032	814010	21055F	PARTICIPANT	\N	PRESENT	0
817033	814010	19745F	PARTICIPANT	\N	EXCUSE	0
817034	814010	21030V	PARTICIPANT	\N	PRESENT	0
817036	814010	14059S	PARTICIPANT	\N	EXCUSE	0
817037	814010	19691J	PARTICIPANT	\N	EXCUSE	0
810694	810591	17737W	PARTICIPANT	\N	PRESENT	0
810695	810591	21074J	PARTICIPANT	\N	PRESENT	0
810696	810591	19719D	PARTICIPANT	\N	PRESENT	0
810697	810591	20040T	PARTICIPANT	\N	PRESENT	0
810698	810591	20022R	PARTICIPANT	\N	PRESENT	0
810608	810209	14053L	PARTICIPANT	\N	PRESENT	0
810609	810209	14111D	PARTICIPANT	\N	PRESENT	0
810610	810209	20074E	PARTICIPANT	\N	PRESENT	0
810611	810209	21076L	PARTICIPANT	\N	PRESENT	0
810612	810209	21057H	PARTICIPANT	\N	PRESENT	0
810613	810209	04045F	PARTICIPANT	\N	PRESENT	0
810614	810209	14231L	PARTICIPANT	\N	PRESENT	0
810615	810209	19447X	PARTICIPANT	\N	PRESENT	0
810616	810209	20098N	PARTICIPANT	\N	PRESENT	0
810617	810209	21043B	PARTICIPANT	\N	PRESENT	0
810618	810209	14089Y	PARTICIPANT	\N	PRESENT	0
810619	810209	21044C	PARTICIPANT	\N	PRESENT	0
810620	810209	18207D	PARTICIPANT	\N	PRESENT	0
810621	810209	08018U	PRESIDENT	0	PRESENT	0
810622	810209	14259Y	PARTICIPANT	\N	PRESENT	0
810623	810209	19749K	PARTICIPANT	\N	PRESENT	0
810699	810591	14179A	PARTICIPANT	\N	PRESENT	0
810700	810591	20096L	PARTICIPANT	\N	PRESENT	0
810701	810591	19687N	PARTICIPANT	\N	PRESENT	0
810702	810591	19631V	PARTICIPANT	\N	PRESENT	0
810703	810591	14253S	PARTICIPANT	\N	PRESENT	0
810704	810591	11056N	PARTICIPANT	\N	PRESENT	0
810705	810591	14229S	PARTICIPANT	\N	PRESENT	0
810706	810591	20060X	PARTICIPANT	\N	PRESENT	0
810707	810591	20140W	PARTICIPANT	\N	PRESENT	0
810708	810591	20044X	PARTICIPANT	\N	PRESENT	0
810709	810591	20122U	PARTICIPANT	\N	PRESENT	0
810710	810591	14042U	PARTICIPANT	\N	PRESENT	0
810711	810591	21068L	PARTICIPANT	\N	PRESENT	0
810712	810591	21057H	PARTICIPANT	\N	PRESENT	0
810713	810591	19782L	PARTICIPANT	\N	PRESENT	0
810714	810591	20066E	PARTICIPANT	\N	PRESENT	0
810715	810591	14231L	PARTICIPANT	\N	PRESENT	0
810716	810591	20048C	PARTICIPANT	\N	PRESENT	0
810737	810736	14073Q	PARTICIPANT	\N	PRESENT	0
810738	810736	20138D	PARTICIPANT	\N	PRESENT	0
810646	810590	20060X	PARTICIPANT	\N	PRESENT	0
810648	804842	14042U	PARTICIPANT	\N	PRESENT	0
810649	804842	19760E	PARTICIPANT	\N	PRESENT	0
810650	804842	20130U	PARTICIPANT	\N	PRESENT	0
810651	804836	14042U	PARTICIPANT	\N	PRESENT	0
810719	810302	14229S	PARTICIPANT	\N	PRESENT	0
810653	804836	19760E	PARTICIPANT	\N	PRESENT	0
810654	804836	20130U	PARTICIPANT	\N	PRESENT	0
810655	804837	14042U	PARTICIPANT	\N	PRESENT	0
810656	804837	19760E	PARTICIPANT	\N	PRESENT	0
810657	804837	20130U	PARTICIPANT	\N	PRESENT	0
810658	810647	14042U	PARTICIPANT	\N	PRESENT	0
810659	810647	19760E	PARTICIPANT	\N	PRESENT	0
810660	810647	20130U	PARTICIPANT	\N	PRESENT	0
810739	810736	21063F	PARTICIPANT	\N	PRESENT	0
810740	810736	19611R	PRESIDENT	0	PRESENT	0
810663	810204	08010L	PARTICIPANT	\N	EXCUSE	0
810741	810736	21091K	PARTICIPANT	\N	PRESENT	0
810742	810736	20102Q	PARTICIPANT	\N	PRESENT	0
810666	810591	21061D	PARTICIPANT	\N	PRESENT	0
810667	810591	20086J	PARTICIPANT	\N	PRESENT	0
810743	810736	14030Q	PARTICIPANT	\N	PRESENT	0
810669	810591	04045F	PARTICIPANT	\N	PRESENT	0
810744	810736	19621T	PARTICIPANT	\N	PRESENT	0
810821	810302	21044C	PARTICIPANT	\N	PRESENT	0
810674	810591	19826F	PARTICIPANT	\N	PRESENT	0
811075	811074	20032T	PARTICIPANT	\N	PRESENT	0
810676	810591	08045X	PARTICIPANT	\N	PRESENT	0
810677	810591	19251M	PARTICIPANT	\N	PRESENT	0
811076	811074	20120S	PARTICIPANT	\N	PRESENT	0
811077	811074	21053D	PARTICIPANT	\N	PRESENT	0
811078	811074	21062E	PARTICIPANT	\N	PRESENT	0
811079	811074	11065P	PARTICIPANT	\N	PRESENT	0
811082	811081	20032T	PARTICIPANT	\N	PRESENT	0
811083	811081	20120S	PARTICIPANT	\N	PRESENT	0
811084	811081	21053D	PARTICIPANT	\N	PRESENT	0
811085	811081	21062E	PARTICIPANT	\N	PRESENT	0
811090	811089	20120S	PARTICIPANT	\N	PRESENT	0
811091	811089	21062E	PARTICIPANT	\N	PRESENT	0
810688	810591	21080G	PARTICIPANT	\N	PRESENT	0
810689	810591	21058J	PARTICIPANT	\N	PRESENT	0
810690	810591	14237S	PARTICIPANT	\N	PRESENT	0
810691	810591	04042C	PARTICIPANT	\N	PRESENT	0
810692	810591	14193X	PARTICIPANT	\N	PRESENT	0
810693	810591	20110Q	PARTICIPANT	\N	PRESENT	0
811092	811089	20032T	PARTICIPANT	\N	PRESENT	0
811093	811089	21053D	PARTICIPANT	\N	PRESENT	0
811318	810779	14253S	PARTICIPANT	\N	PRESENT	0
811381	810779	07029T	PARTICIPANT	\N	PRESENT	0
811321	810779	21090J	PARTICIPANT	\N	PRESENT	0
811322	810779	19399H	PARTICIPANT	\N	PRESENT	0
811323	810779	11040E	PARTICIPANT	\N	PRESENT	0
811324	810779	14121F	PARTICIPANT	\N	PRESENT	0
811325	810779	19573D	PARTICIPANT	\N	PRESENT	0
811326	810779	19349W	PARTICIPANT	\N	PRESENT	0
811327	810779	20024T	PARTICIPANT	\N	PRESENT	0
811328	810779	11074Q	PARTICIPANT	\N	PRESENT	0
811329	810779	11048N	PARTICIPANT	\N	PRESENT	0
811330	810211	21043B	PARTICIPANT	\N	PRESENT	0
811331	810211	19649G	PARTICIPANT	\N	PRESENT	0
811332	810211	20074E	PARTICIPANT	\N	PRESENT	0
811333	810211	21076L	PARTICIPANT	\N	PRESENT	0
811334	810211	19111A	PARTICIPANT	\N	PRESENT	0
811335	810211	14215L	PARTICIPANT	\N	PRESENT	0
811336	810211	08018U	PARTICIPANT	\N	PRESENT	0
811337	810211	21095P	PARTICIPANT	\N	PRESENT	0
811338	810211	19749K	PARTICIPANT	\N	PRESENT	0
811339	810211	04047H	PRESIDENT	0	PRESENT	0
811340	810211	19447X	PARTICIPANT	\N	PRESENT	0
811341	810211	11072N	PARTICIPANT	\N	PRESENT	0
811342	810211	19729F	PARTICIPANT	\N	EXCUSE	0
811343	810211	19585H	PARTICIPANT	\N	EXCUSE	0
811344	810211	19719D	PARTICIPANT	\N	EXCUSE	0
811345	810779	14083S	PARTICIPANT	\N	PRESENT	0
811346	810779	20062A	PARTICIPANT	\N	PRESENT	0
811347	810779	19667J	PARTICIPANT	\N	PRESENT	0
811348	810211	14053L	PARTICIPANT	\N	PRESENT	0
811349	810211	14111D	PARTICIPANT	\N	PRESENT	0
811350	810211	04045F	PARTICIPANT	\N	PRESENT	0
811351	810211	14089Y	PARTICIPANT	\N	PRESENT	0
811352	810779	20094J	PARTICIPANT	\N	PRESENT	0
811358	810779	21048G	PARTICIPANT	\N	PRESENT	0
811360	810779	19647E	PARTICIPANT	\N	PRESENT	0
811361	810211	21057H	PARTICIPANT	\N	PRESENT	0
811362	810211	21056G	PARTICIPANT	\N	PRESENT	0
811363	810211	18231D	PARTICIPANT	\N	PRESENT	0
811364	810211	20110Q	PARTICIPANT	\N	PRESENT	0
811365	810211	20022R	PARTICIPANT	\N	PRESENT	0
811366	810779	21041Y	PARTICIPANT	\N	PRESENT	0
811367	810779	14331P	PARTICIPANT	\N	PRESENT	0
811368	810211	05008E	PARTICIPANT	\N	PRESENT	0
811369	810211	14147R	PARTICIPANT	\N	PRESENT	0
811370	810211	20036X	PARTICIPANT	\N	PRESENT	0
811371	810211	21044C	PARTICIPANT	\N	PRESENT	0
811372	810211	11056N	PARTICIPANT	\N	PRESENT	0
811373	810211	14069U	PARTICIPANT	\N	PRESENT	0
811374	810779	19711U	PARTICIPANT	\N	PRESENT	0
811375	810779	20070A	PARTICIPANT	\N	PRESENT	0
811376	810779	20080C	PARTICIPANT	\N	PRESENT	0
811377	810779	20044X	PARTICIPANT	\N	PRESENT	0
811378	810211	18207D	PARTICIPANT	\N	PRESENT	0
811379	810211	14189C	PARTICIPANT	\N	PRESENT	0
811380	810211	19725B	PARTICIPANT	\N	PRESENT	0
811382	810779	19479G	PARTICIPANT	\N	PRESENT	0
811383	810211	19489J	PARTICIPANT	\N	PRESENT	0
811384	810211	20114U	PARTICIPANT	\N	PRESENT	0
811385	810211	21038E	PARTICIPANT	\N	PRESENT	0
811386	810211	20266L	PARTICIPANT	\N	PRESENT	0
811389	810211	21040X	PARTICIPANT	\N	PRESENT	0
811404	810211	14259Y	PARTICIPANT	\N	PRESENT	0
811420	810779	20086J	PARTICIPANT	\N	PRESENT	0
811421	810779	19545Y	PARTICIPANT	\N	PRESENT	0
811424	811317	19383Y	PARTICIPANT	\N	PRESENT	0
811425	811317	19768N	PARTICIPANT	\N	PRESENT	0
811426	811317	20092G	PARTICIPANT	\N	PRESENT	0
811427	811317	19782L	PARTICIPANT	\N	PRESENT	0
811428	811317	14357A	PARTICIPANT	\N	PRESENT	0
811429	811317	20078J	PARTICIPANT	\N	PRESENT	0
802121	801464	20088L	PARTICIPANT	\N	EXCUSE	0
802192	801237	19591F	PARTICIPANT	\N	PRESENT	0
802308	801237	08045X	PARTICIPANT	\N	PRESENT	0
804097	804096	11048N	PARTICIPANT	\N	PRESENT	0
804099	804098	11048N	PARTICIPANT	\N	PRESENT	0
804101	804100	11048N	PARTICIPANT	\N	PRESENT	0
804105	804103	11048N	PARTICIPANT	\N	PRESENT	0
807972	807969	14053L	PARTICIPANT	\N	PRESENT	0
807973	807969	19649G	PARTICIPANT	\N	PRESENT	0
807975	807969	21043B	PARTICIPANT	\N	PRESENT	0
807978	807969	21057H	PARTICIPANT	\N	PRESENT	0
807979	807969	19725B	PARTICIPANT	\N	PRESENT	0
807981	807969	21044C	PARTICIPANT	\N	PRESENT	0
807984	807969	18231D	PARTICIPANT	\N	PRESENT	0
808728	808727	11090Q	PARTICIPANT	\N	PRESENT	0
808730	808727	14205J	PARTICIPANT	\N	PRESENT	0
808731	808727	14097Y	PARTICIPANT	\N	PRESENT	0
808732	808727	14331P	PARTICIPANT	\N	PRESENT	0
808734	808727	14225N	PARTICIPANT	\N	PRESENT	0
808846	808844	19569H	PARTICIPANT	\N	PRESENT	0
808847	808844	14213J	PARTICIPANT	\N	PRESENT	0
808848	808844	21081H	PARTICIPANT	\N	PRESENT	0
808849	808844	19683J	PARTICIPANT	\N	PRESENT	0
810526	810264	20146D	PARTICIPANT	\N	EXCUSE	0
810550	810264	17367Q	PARTICIPANT	\N	PRESENT	0
810551	810264	14151M	PRESIDENT	0	PRESENT	0
810552	810264	20108W	PARTICIPANT	\N	PRESENT	0
815451	813191	21081H	PARTICIPANT	\N	PRESENT	0
815453	813191	18395Y	PARTICIPANT	\N	PRESENT	0
815456	813191	20090E	PARTICIPANT	\N	PRESENT	0
815578	815577	20264J	PARTICIPANT	\N	PRESENT	0
815579	815577	19954N	PARTICIPANT	\N	PRESENT	0
815580	815577	20052X	PARTICIPANT	\N	PRESENT	0
818422	815937	20034V	PARTICIPANT	\N	PRESENT	0
818424	815937	04042C	PARTICIPANT	\N	PRESENT	0
818425	815937	14147R	PARTICIPANT	\N	PRESENT	0
818428	815937	14249W	PARTICIPANT	\N	PRESENT	0
818479	815938	19479G	PARTICIPANT	\N	PRESENT	0
818487	815938	21073H	PARTICIPANT	\N	PRESENT	0
818489	815938	21043B	PARTICIPANT	\N	PRESENT	0
818492	815938	14249W	PARTICIPANT	\N	PRESENT	0
818494	815938	14147R	PARTICIPANT	\N	PRESENT	0
818496	815938	20032T	PARTICIPANT	\N	PRESENT	0
818499	815938	21082J	PARTICIPANT	\N	PRESENT	0
818501	815938	21056G	PARTICIPANT	\N	PRESENT	0
818504	815938	20070A	PARTICIPANT	\N	PRESENT	0
818505	815938	20128B	PARTICIPANT	\N	PRESENT	0
818506	815938	20072C	PARTICIPANT	\N	PRESENT	0
818507	815938	14231L	PARTICIPANT	\N	PRESENT	0
818508	815938	20248J	PARTICIPANT	\N	PRESENT	0
818509	815938	19745F	PARTICIPANT	\N	PRESENT	0
818510	815938	14133K	PARTICIPANT	\N	PRESENT	0
818511	815938	14215L	PARTICIPANT	\N	PRESENT	0
818512	815938	20034V	PARTICIPANT	\N	PRESENT	0
818513	815938	20024T	PARTICIPANT	\N	PRESENT	0
818514	815938	14193X	PARTICIPANT	\N	PRESENT	0
818515	815938	04042C	PARTICIPANT	\N	PRESENT	0
818516	815938	19565D	PARTICIPANT	\N	PRESENT	0
818517	815938	14191V	PARTICIPANT	\N	PRESENT	0
818518	815938	14253S	PARTICIPANT	\N	PRESENT	0
818520	815938	14211G	PARTICIPANT	\N	PRESENT	0
818521	815938	19593H	PARTICIPANT	\N	PRESENT	0
818522	815938	19531S	PARTICIPANT	\N	PRESENT	0
818523	815938	21039F	PARTICIPANT	\N	PRESENT	0
818524	815938	20252E	PARTICIPANT	\N	PRESENT	0
818525	815938	21040X	PARTICIPANT	\N	PRESENT	0
818526	815938	21057H	PARTICIPANT	\N	PRESENT	0
818527	815938	21067K	PARTICIPANT	\N	PRESENT	0
818528	815938	19954N	PARTICIPANT	\N	PRESENT	0
818529	815938	20122U	PARTICIPANT	\N	PRESENT	0
818531	815938	20116W	PARTICIPANT	\N	PRESENT	0
818532	815938	14257W	PARTICIPANT	\N	PRESENT	0
818534	818533	14187A	PARTICIPANT	\N	PRESENT	0
818535	818533	21083K	PARTICIPANT	\N	PRESENT	0
818536	818533	20082E	PARTICIPANT	\N	PRESENT	0
818537	815938	17023S	PARTICIPANT	\N	PRESENT	0
818538	818533	19782L	PARTICIPANT	\N	PRESENT	0
818481	815938	21031W	PARTICIPANT	\N	PRESENT	0
818540	818539	14187A	PARTICIPANT	\N	PRESENT	0
818544	818539	19782L	PARTICIPANT	\N	PRESENT	0
818542	818539	21083K	PARTICIPANT	\N	PRESENT	0
818543	818539	20082E	PARTICIPANT	\N	PRESENT	0
818546	818545	20032T	PARTICIPANT	\N	PRESENT	0
818547	818545	21053D	PARTICIPANT	\N	PRESENT	0
818548	818545	21062E	PARTICIPANT	\N	PRESENT	0
818549	818545	11065P	PARTICIPANT	\N	PRESENT	0
818550	818545	19681G	PARTICIPANT	\N	PRESENT	0
818552	818551	20032T	PARTICIPANT	\N	PRESENT	0
818553	818551	21053D	PARTICIPANT	\N	PRESENT	0
818554	818551	21062E	PARTICIPANT	\N	PRESENT	0
818555	818551	11065P	PARTICIPANT	\N	PRESENT	0
818556	818551	19681G	PARTICIPANT	\N	PRESENT	0
818558	815938	19691J	PARTICIPANT	\N	PRESENT	0
818559	815938	19711U	PARTICIPANT	\N	PRESENT	0
818560	815938	19533U	PARTICIPANT	\N	PRESENT	0
818562	815938	20082E	PARTICIPANT	\N	PRESENT	0
818565	818563	19954N	PARTICIPANT	\N	PRESENT	0
818608	815939	20082E	PARTICIPANT	\N	PRESENT	0
818611	815939	14257W	PARTICIPANT	\N	PRESENT	0
818612	815939	20122U	PARTICIPANT	\N	PRESENT	0
818613	815939	20080C	PARTICIPANT	\N	PRESENT	0
818614	815939	12016W	PARTICIPANT	\N	PRESENT	0
818615	815939	20134Y	PARTICIPANT	\N	PRESENT	0
818616	815939	14083S	PARTICIPANT	\N	PRESENT	0
818617	815939	19745F	PARTICIPANT	\N	PRESENT	0
818618	815939	14133K	PARTICIPANT	\N	PRESENT	0
818619	815939	21069M	PARTICIPANT	\N	PRESENT	0
818620	815939	19533U	PARTICIPANT	\N	PRESENT	0
818621	815939	20024T	PARTICIPANT	\N	PRESENT	0
818622	815939	07029T	PARTICIPANT	\N	PRESENT	0
818623	815939	19954N	PARTICIPANT	\N	PRESENT	0
818624	815939	14215L	PARTICIPANT	\N	PRESENT	0
818625	815939	20032T	PARTICIPANT	\N	PRESENT	0
818626	815939	14191V	PARTICIPANT	\N	PRESENT	0
818627	815939	19711U	PARTICIPANT	\N	PRESENT	0
818628	815939	19695N	PARTICIPANT	\N	PRESENT	0
818629	815939	19760E	PARTICIPANT	\N	PRESENT	0
818630	815939	20116W	PARTICIPANT	\N	PRESENT	0
818631	815939	20072C	PARTICIPANT	\N	PRESENT	0
818632	815939	20062A	PARTICIPANT	\N	PRESENT	0
818633	815939	20018V	PARTICIPANT	\N	PRESENT	0
818634	815939	19413M	PARTICIPANT	\N	PRESENT	0
818635	815939	20064C	PARTICIPANT	\N	PRESENT	0
818636	815939	19331L	PARTICIPANT	\N	PRESENT	0
818637	815939	20128B	PARTICIPANT	\N	PRESENT	0
818638	815939	20044X	PARTICIPANT	\N	PRESENT	0
818639	815939	11048N	PARTICIPANT	\N	PRESENT	0
818640	815939	14331P	PARTICIPANT	\N	PRESENT	0
818606	815939	19593H	PARTICIPANT	\N	PRESENT	0
818607	815939	19347U	PARTICIPANT	\N	PRESENT	0
818641	815939	14225N	PARTICIPANT	\N	PRESENT	0
818642	815939	20104S	PARTICIPANT	\N	PRESENT	0
818643	814472	20132W	PARTICIPANT	\N	PRESENT	0
818644	814472	18395Y	PARTICIPANT	\N	PRESENT	0
818645	814472	20142Y	PARTICIPANT	\N	PRESENT	0
818646	814472	19611R	PRESIDENT	0	PRESENT	0
818647	814472	21037D	PARTICIPANT	\N	PRESENT	0
818648	814472	21058J	PARTICIPANT	\N	PRESENT	0
818649	814472	21063F	PARTICIPANT	\N	PRESENT	0
818650	814472	20102Q	PARTICIPANT	\N	PRESENT	0
818651	814472	21055F	PARTICIPANT	\N	PRESENT	0
818652	814472	14030Q	PARTICIPANT	\N	PRESENT	0
818653	814472	20264J	PARTICIPANT	\N	PRESENT	0
818654	814472	04070G	PARTICIPANT	\N	PRESENT	0
818655	814472	19621T	PARTICIPANT	\N	PRESENT	0
818656	814472	14123H	PARTICIPANT	\N	PRESENT	0
818657	814472	21089R	PARTICIPANT	\N	PRESENT	0
818658	814472	21077M	PARTICIPANT	\N	PRESENT	0
818659	814472	21059K	PARTICIPANT	\N	PRESENT	0
818660	814472	14109K	PARTICIPANT	\N	PRESENT	0
818661	814472	21125C	PARTICIPANT	\N	PRESENT	0
818662	814472	20180F	PARTICIPANT	\N	PRESENT	0
818663	814472	20056C	PARTICIPANT	\N	PRESENT	0
818664	814472	19693L	PARTICIPANT	\N	PRESENT	0
818665	814472	19954N	PARTICIPANT	\N	PRESENT	0
818666	814472	11043H	PARTICIPANT	\N	PRESENT	0
818667	814472	19573D	PARTICIPANT	\N	PRESENT	0
818668	814472	20124W	PARTICIPANT	\N	PRESENT	0
818669	814472	14241N	PARTICIPANT	\N	PRESENT	0
818670	814472	19697Q	PARTICIPANT	\N	PRESENT	0
818671	814472	20026V	PARTICIPANT	\N	PRESENT	0
801057	801039	14215L	PARTICIPANT	\N	EXCUSE	0
801058	801039	20120S	PARTICIPANT	\N	EXCUSE	0
801059	801039	20068G	PARTICIPANT	\N	EXCUSE	0
801060	801039	19531S	PARTICIPANT	\N	EXCUSE	0
801061	801039	19447X	PARTICIPANT	\N	EXCUSE	0
801062	801039	08012N	PARTICIPANT	\N	EXCUSE	0
801063	801039	19826F	PARTICIPANT	\N	EXCUSE	0
801064	801039	14257W	PARTICIPANT	\N	EXCUSE	0
801065	801039	21068L	PARTICIPANT	\N	EXCUSE	0
801066	801039	21070E	PARTICIPANT	\N	EXCUSE	0
801067	801039	04045F	PARTICIPANT	\N	EXCUSE	0
801068	801039	20084G	PARTICIPANT	\N	EXCUSE	0
801069	801039	01034P	PARTICIPANT	\N	EXCUSE	0
801070	801039	20058E	PARTICIPANT	\N	EXCUSE	0
801071	801039	14173T	PARTICIPANT	\N	EXCUSE	0
801072	797790	21033Y	PARTICIPANT	\N	PRESENT	1
801073	797790	19657G	PARTICIPANT	\N	PRESENT	1
801074	797790	21097R	PARTICIPANT	\N	PRESENT	1
801076	797790	21073H	PARTICIPANT	\N	PRESENT	0
801232	791846	21069M	PARTICIPANT	\N	PRESENT	0
801445	801437	21084L	PARTICIPANT	\N	PRESENT	0
801446	801437	20038A	PARTICIPANT	\N	PRESENT	0
801447	801437	19413M	PARTICIPANT	\N	PRESENT	0
801448	801437	21090J	PARTICIPANT	\N	PRESENT	0
801449	801437	99004R	PRESIDENT	0	PRESENT	0
801450	801437	21093M	PARTICIPANT	\N	PRESENT	0
801451	801437	11090Q	PARTICIPANT	\N	PRESENT	0
801452	801437	21050A	PARTICIPANT	\N	PRESENT	0
801453	801437	17023S	PARTICIPANT	\N	PRESENT	0
801454	801437	20248J	PARTICIPANT	\N	EXCUSE	0
801455	801437	21031W	PARTICIPANT	\N	EXCUSE	0
801456	801437	14031R	PARTICIPANT	\N	EXCUSE	0
803195	801132	19693L	PARTICIPANT	\N	EXCUSE	0
803539	801390	21071F	PARTICIPANT	\N	PRESENT	0
803540	801390	20032T	PARTICIPANT	\N	PRESENT	0
803541	801390	21042A	PARTICIPANT	\N	PRESENT	0
803542	801390	19760E	PARTICIPANT	\N	PRESENT	0
803543	801390	14189C	PARTICIPANT	\N	PRESENT	0
803545	801390	19631V	PARTICIPANT	\N	PRESENT	0
803546	801390	19707Y	PARTICIPANT	\N	PRESENT	0
803547	801390	21084L	PARTICIPANT	\N	PRESENT	0
803548	801390	05008E	PARTICIPANT	\N	PRESENT	0
803549	801390	21035B	PARTICIPANT	\N	PRESENT	0
803550	801390	20024T	PARTICIPANT	\N	PRESENT	0
803551	801390	20022R	PARTICIPANT	\N	PRESENT	0
803552	801390	20110Q	PARTICIPANT	\N	PRESENT	0
803553	801390	19575F	PARTICIPANT	\N	PRESENT	0
803554	801390	20116W	PARTICIPANT	\N	PRESENT	0
803555	801390	14030Q	PARTICIPANT	\N	PRESENT	0
803557	801390	21043B	PARTICIPANT	\N	PRESENT	0
803558	801390	17367Q	PARTICIPANT	\N	PRESENT	0
803559	801390	20086J	PARTICIPANT	\N	PRESENT	0
803560	801390	21048G	PARTICIPANT	\N	PRESENT	0
803561	801390	20094J	PARTICIPANT	\N	PRESENT	0
803562	801390	21050A	PARTICIPANT	\N	PRESENT	0
803563	801390	11040E	PARTICIPANT	\N	PRESENT	0
803564	801390	14069U	PARTICIPANT	\N	PRESENT	0
803565	801390	08060W	PARTICIPANT	\N	PRESENT	0
803566	801390	20078J	PARTICIPANT	\N	PRESENT	0
803567	801390	20138D	PARTICIPANT	\N	PRESENT	0
803568	801390	21046E	PARTICIPANT	\N	PRESENT	0
803569	801390	20114U	PARTICIPANT	\N	PRESENT	0
803571	801390	21052C	PARTICIPANT	\N	PRESENT	0
803573	801390	20080C	PARTICIPANT	\N	PRESENT	0
803574	801390	19621T	PARTICIPANT	\N	PRESENT	0
803575	801390	21088Q	PARTICIPANT	\N	PRESENT	0
803576	801390	21089R	PARTICIPANT	\N	PRESENT	0
803577	801390	19758L	PARTICIPANT	\N	PRESENT	0
803578	801390	21063F	PARTICIPANT	\N	PRESENT	0
803579	801390	04047H	PARTICIPANT	\N	PRESENT	0
803580	801390	19782L	PARTICIPANT	\N	PRESENT	0
803581	801390	20090E	PARTICIPANT	\N	PRESENT	0
803582	801390	21096Q	PARTICIPANT	\N	PRESENT	0
803583	801390	20104S	PARTICIPANT	\N	PRESENT	0
803584	801390	04042C	PARTICIPANT	\N	PRESENT	0
803585	801390	21045D	PARTICIPANT	\N	PRESENT	0
803586	801390	14053L	PARTICIPANT	\N	PRESENT	0
803587	801390	14083S	PARTICIPANT	\N	PRESENT	0
803588	801390	11053K	PARTICIPANT	\N	PRESENT	0
803589	801390	19545Y	PARTICIPANT	\N	PRESENT	0
803590	801390	20060X	PARTICIPANT	\N	PRESENT	0
803591	801390	12028B	PARTICIPANT	\N	PRESENT	0
803592	801390	21090J	PARTICIPANT	\N	PRESENT	0
803593	801390	19629C	PARTICIPANT	\N	PRESENT	0
803594	801390	21057H	PARTICIPANT	\N	PRESENT	0
803595	801390	14038Y	PARTICIPANT	\N	PRESENT	0
803596	801390	20264J	PARTICIPANT	\N	PRESENT	0
803597	801390	14195A	PARTICIPANT	\N	PRESENT	0
803598	801390	21065H	PARTICIPANT	\N	PRESENT	0
803599	801390	18083K	PARTICIPANT	\N	PRESENT	0
803600	801390	19701S	PARTICIPANT	\N	PRESENT	0
803601	801390	14267Y	PARTICIPANT	\N	PRESENT	0
803602	801390	21072G	PARTICIPANT	\N	PRESENT	0
803603	801390	19295A	PARTICIPANT	\N	PRESENT	0
803604	801390	21034A	PARTICIPANT	\N	PRESENT	0
803605	801390	11115U	PARTICIPANT	\N	PRESENT	0
803608	801390	20070A	PARTICIPANT	\N	PRESENT	0
803609	801390	11056N	PARTICIPANT	\N	PRESENT	0
803610	801390	14357A	PARTICIPANT	\N	PRESENT	0
803611	801390	18395Y	PARTICIPANT	\N	PRESENT	0
803612	801390	11065P	PARTICIPANT	\N	PRESENT	0
803613	801390	19693L	PARTICIPANT	\N	PRESENT	0
803614	801390	14259Y	PARTICIPANT	\N	PRESENT	0
803615	801390	21067K	PARTICIPANT	\N	PRESENT	0
803616	801390	21041Y	PARTICIPANT	\N	PRESENT	0
803617	801390	11070L	PARTICIPANT	\N	PRESENT	0
803618	801390	19719D	PARTICIPANT	\N	PRESENT	0
803619	801390	14327T	PARTICIPANT	\N	PRESENT	0
803620	801390	20140W	PARTICIPANT	\N	PRESENT	0
803621	801390	14217N	PARTICIPANT	\N	PRESENT	0
803622	801390	20248J	PARTICIPANT	\N	PRESENT	0
803623	801390	15197G	PARTICIPANT	\N	PRESENT	0
803624	801390	14215L	PARTICIPANT	\N	PRESENT	0
803625	801390	20134Y	PARTICIPANT	\N	PRESENT	0
803626	801390	20124W	PARTICIPANT	\N	PRESENT	0
803627	801390	20040T	PARTICIPANT	\N	PRESENT	0
803628	801390	07033P	PARTICIPANT	\N	PRESENT	0
803629	801390	20074E	PARTICIPANT	\N	PRESENT	0
803630	801390	14151M	PARTICIPANT	\N	PRESENT	0
803631	801390	14249W	PARTICIPANT	\N	PRESENT	0
803632	801390	21074J	PARTICIPANT	\N	PRESENT	0
803633	801390	11110B	PARTICIPANT	\N	PRESENT	0
803634	801390	14187A	PARTICIPANT	\N	PRESENT	0
803635	801390	19673G	PARTICIPANT	\N	PRESENT	0
803636	801390	21091K	PARTICIPANT	\N	PRESENT	0
803637	801390	21086N	PARTICIPANT	\N	PRESENT	0
803638	801390	20038A	PARTICIPANT	\N	PRESENT	0
803639	801390	19647E	PARTICIPANT	\N	PRESENT	0
803640	801390	14281W	PARTICIPANT	\N	PRESENT	0
803641	801390	20100N	PARTICIPANT	\N	PRESENT	0
803642	801390	20132W	PARTICIPANT	\N	PRESENT	0
803643	801390	08045X	PARTICIPANT	\N	PRESENT	0
803644	801390	19111A	PARTICIPANT	\N	PRESENT	0
803645	801390	17023S	PARTICIPANT	\N	PRESENT	0
803646	801390	21033Y	PARTICIPANT	\N	PRESENT	0
803647	801390	08018U	PARTICIPANT	\N	PRESENT	0
803648	801390	20286Q	PARTICIPANT	\N	PRESENT	0
803649	801390	14231L	PARTICIPANT	\N	PRESENT	0
803650	801390	14355X	PARTICIPANT	\N	PRESENT	0
803651	801390	19820Y	PARTICIPANT	\N	PRESENT	0
803652	801390	19347U	PARTICIPANT	\N	PRESENT	0
803653	801390	20180F	PARTICIPANT	\N	PRESENT	0
803654	801390	14211G	PARTICIPANT	\N	PRESENT	0
803655	801390	19565D	PARTICIPANT	\N	PRESENT	0
803656	801390	14033T	PARTICIPANT	\N	PRESENT	0
803657	801390	14123H	PARTICIPANT	\N	PRESENT	0
803658	801390	14026U	PARTICIPANT	\N	PRESENT	0
803659	801390	21092L	PARTICIPANT	\N	PRESENT	0
803660	801390	20072C	PARTICIPANT	\N	PRESENT	0
803661	801390	20106U	PARTICIPANT	\N	PRESENT	0
803662	801390	20128B	PARTICIPANT	\N	PRESENT	0
803663	801390	14179A	PARTICIPANT	\N	PRESENT	0
803664	801390	20048C	PARTICIPANT	\N	PRESENT	0
803665	801390	21085M	PARTICIPANT	\N	PRESENT	0
803666	801390	08069G	PARTICIPANT	\N	PRESENT	0
803667	801390	19399H	PARTICIPANT	\N	PRESENT	0
803668	801390	11048N	PARTICIPANT	\N	PRESENT	0
803669	801390	19591F	PARTICIPANT	\N	PRESENT	0
803670	801390	20066E	PARTICIPANT	\N	PRESENT	0
803671	801390	20034V	PARTICIPANT	\N	PRESENT	0
803673	801390	19551W	PARTICIPANT	\N	PRESENT	0
809844	809843	86034E	PARTICIPANT	\N	PRESENT	0
809845	809843	04047H	PARTICIPANT	\N	PRESENT	0
809846	809843	20104S	PARTICIPANT	\N	PRESENT	0
809847	809843	12028B	PARTICIPANT	\N	PRESENT	0
809848	809843	19629C	PARTICIPANT	\N	PRESENT	0
809849	809843	11056N	PARTICIPANT	\N	PRESENT	0
809850	809843	14259Y	PARTICIPANT	\N	PRESENT	0
809851	809843	14187A	PARTICIPANT	\N	PRESENT	0
809852	809843	19347U	PARTICIPANT	\N	PRESENT	0
809853	809843	14179A	PARTICIPANT	\N	PRESENT	0
809854	809843	11048N	PARTICIPANT	\N	PRESENT	0
809855	809843	19611R	PARTICIPANT	\N	PRESENT	0
809856	809843	14251Q	PARTICIPANT	\N	PRESENT	0
809857	809843	14071N	PARTICIPANT	\N	PRESENT	0
809858	809843	08061X	PARTICIPANT	\N	PRESENT	0
809859	809843	14193X	PARTICIPANT	\N	PRESENT	0
809860	809843	11090Q	PARTICIPANT	\N	PRESENT	0
809861	809843	14331P	PARTICIPANT	\N	PRESENT	0
809862	809843	14225N	PARTICIPANT	\N	PRESENT	0
809863	809843	04033B	PARTICIPANT	\N	PRESENT	0
809864	809843	14229S	PARTICIPANT	\N	PRESENT	0
809865	809843	19669L	PARTICIPANT	\N	PRESENT	0
809866	809843	19479G	PARTICIPANT	\N	PRESENT	0
810780	810302	01058X	PARTICIPANT	\N	PRESENT	0
810790	810302	19295A	PARTICIPANT	\N	PRESENT	0
810791	810302	21083K	PARTICIPANT	\N	PRESENT	0
810792	810302	19713W	PARTICIPANT	\N	PRESENT	0
810802	810302	19703U	PARTICIPANT	\N	PRESENT	0
810806	810302	11056N	PARTICIPANT	\N	PRESENT	0
810807	810302	14191V	PARTICIPANT	\N	PRESENT	0
810808	810302	08045X	PARTICIPANT	\N	PRESENT	0
810809	810302	20074E	PARTICIPANT	\N	PRESENT	0
810810	810302	21049H	PARTICIPANT	\N	PRESENT	0
810811	810302	21093M	PARTICIPANT	\N	PRESENT	0
810812	810302	20102Q	PARTICIPANT	\N	PRESENT	0
810813	810302	14281W	PARTICIPANT	\N	PRESENT	0
810814	810302	20128B	PARTICIPANT	\N	PRESENT	0
810817	810302	19866P	PARTICIPANT	\N	PRESENT	0
810819	810302	21040X	PARTICIPANT	\N	PRESENT	0
810820	810302	21043B	PARTICIPANT	\N	PRESENT	0
812921	812920	14026U	PARTICIPANT	\N	PRESENT	0
812922	812920	19691J	PARTICIPANT	\N	PRESENT	0
812923	812920	21081H	PARTICIPANT	\N	PRESENT	0
812924	812920	14071N	PARTICIPANT	\N	PRESENT	0
812925	812920	17965H	PARTICIPANT	\N	PRESENT	0
812926	812920	14281W	PARTICIPANT	\N	PRESENT	0
812927	812920	20106U	PARTICIPANT	\N	PRESENT	0
812928	812920	21046E	PARTICIPANT	\N	PRESENT	0
812929	812920	21094N	PARTICIPANT	\N	PRESENT	0
817690	815930	21082J	PARTICIPANT	\N	PRESENT	0
817692	815936	14111D	PARTICIPANT	\N	PRESENT	0
817693	815930	21076L	PARTICIPANT	\N	EXCUSE	0
817694	815936	20100N	PARTICIPANT	\N	PRESENT	0
817695	815936	21057H	PARTICIPANT	\N	PRESENT	0
817696	815936	20028X	PARTICIPANT	\N	PRESENT	0
817697	815936	19745F	PARTICIPANT	\N	PRESENT	0
817698	815936	14169X	PARTICIPANT	\N	PRESENT	0
817699	815936	19711U	PARTICIPANT	\N	PRESENT	0
817700	815936	11048N	PARTICIPANT	\N	PRESENT	0
817701	815936	20136B	PARTICIPANT	\N	PRESENT	0
817702	815936	14211G	PARTICIPANT	\N	PRESENT	0
817703	815936	21043B	PARTICIPANT	\N	PRESENT	0
817704	815936	19866P	PARTICIPANT	\N	PRESENT	0
817705	815936	18193Q	PARTICIPANT	\N	PRESENT	0
817706	815936	21090J	PARTICIPANT	\N	PRESENT	0
817707	815936	21083K	PARTICIPANT	\N	PRESENT	0
817708	815936	19679N	PARTICIPANT	\N	PRESENT	0
817709	815936	99004R	PARTICIPANT	\N	PRESENT	0
817710	815936	08011M	PARTICIPANT	\N	PRESENT	0
817711	815936	21044C	PARTICIPANT	\N	PRESENT	0
817713	817712	20024T	PARTICIPANT	\N	PRESENT	0
817714	817712	20252E	PARTICIPANT	\N	PRESENT	0
817715	817712	17965H	PARTICIPANT	\N	PRESENT	0
817716	817712	19531S	PARTICIPANT	\N	PRESENT	0
817717	817712	21053D	PARTICIPANT	\N	PRESENT	0
817718	817712	18193Q	PARTICIPANT	\N	PRESENT	0
817719	817712	19798U	PARTICIPANT	\N	PRESENT	0
817720	815936	14215L	PARTICIPANT	\N	PRESENT	0
817721	815936	08010L	PARTICIPANT	\N	PRESENT	0
817722	815936	19621T	PARTICIPANT	\N	PRESENT	0
817723	815936	18083K	PARTICIPANT	\N	PRESENT	0
817724	815936	19367Y	PARTICIPANT	\N	PRESENT	0
817725	815936	14259Y	PARTICIPANT	\N	PRESENT	0
817726	815936	20076G	PARTICIPANT	\N	PRESENT	0
817727	815936	20074E	PARTICIPANT	\N	PRESENT	0
817728	815936	04042C	PARTICIPANT	\N	PRESENT	0
817729	815936	19575F	PARTICIPANT	\N	PRESENT	0
817730	815936	01058X	PARTICIPANT	\N	PRESENT	0
817731	815936	14123H	PARTICIPANT	\N	PRESENT	0
817732	815936	20078J	PARTICIPANT	\N	PRESENT	0
817733	815936	08069G	PARTICIPANT	\N	PRESENT	0
817734	815936	08028W	PARTICIPANT	\N	PRESENT	0
817735	815936	14223L	PARTICIPANT	\N	PRESENT	0
817736	815936	21080G	PARTICIPANT	\N	PRESENT	0
817737	815936	21061D	PARTICIPANT	\N	PRESENT	0
817738	815936	19573D	PARTICIPANT	\N	PRESENT	0
817739	815936	10015M	PARTICIPANT	\N	PRESENT	0
817740	815936	19760E	PARTICIPANT	\N	PRESENT	0
817741	815936	21091K	PARTICIPANT	\N	PRESENT	0
817742	815936	21084L	PARTICIPANT	\N	PRESENT	0
817743	815936	11040E	PARTICIPANT	\N	PRESENT	0
817744	815936	20044X	PARTICIPANT	\N	PRESENT	0
817745	815936	19758L	PARTICIPANT	\N	PRESENT	0
817746	815936	19695N	PARTICIPANT	\N	PRESENT	0
817747	815936	19565D	PARTICIPANT	\N	PRESENT	0
817748	815936	21071F	PARTICIPANT	\N	PRESENT	0
817749	815936	20102Q	PARTICIPANT	\N	PRESENT	0
817750	815936	14191V	PARTICIPANT	\N	PRESENT	0
817751	815936	14193X	PARTICIPANT	\N	PRESENT	0
817752	815936	20112S	PARTICIPANT	\N	PRESENT	0
817753	815936	21034A	PARTICIPANT	\N	PRESENT	0
817754	815936	19681G	PARTICIPANT	\N	PRESENT	0
817755	815936	19673G	PARTICIPANT	\N	PRESENT	0
817756	815936	21075K	PARTICIPANT	\N	PRESENT	0
817757	815936	19593H	PARTICIPANT	\N	PRESENT	0
817758	815936	19687N	PARTICIPANT	\N	PRESENT	0
817759	815936	20046A	PARTICIPANT	\N	PRESENT	0
817760	815936	21072G	PARTICIPANT	\N	PRESENT	0
817761	815936	19421M	PARTICIPANT	\N	PRESENT	0
817762	815936	14031R	PARTICIPANT	\N	PRESENT	0
817763	815936	20032T	PARTICIPANT	\N	PRESENT	0
817764	815936	21049H	PARTICIPANT	\N	PRESENT	0
817765	815936	21081H	PARTICIPANT	\N	PRESENT	0
817766	815936	20110Q	PARTICIPANT	\N	PRESENT	0
817767	815936	21048G	PARTICIPANT	\N	PRESENT	0
817768	815936	14253S	PARTICIPANT	\N	PRESENT	0
817769	815936	19383Y	PARTICIPANT	\N	PRESENT	0
817770	815936	11065P	PARTICIPANT	\N	PRESENT	0
817771	815936	17737W	PARTICIPANT	\N	PRESENT	0
817772	815936	20134Y	PARTICIPANT	\N	PRESENT	0
817773	815936	20138D	PARTICIPANT	\N	PRESENT	0
817774	815936	19954N	PARTICIPANT	\N	PRESENT	0
817775	815936	19347U	PARTICIPANT	\N	PRESENT	0
817776	815936	21092L	PARTICIPANT	\N	PRESENT	0
817777	815936	21093M	PARTICIPANT	\N	PRESENT	0
817778	815936	19705W	PARTICIPANT	\N	PRESENT	0
817779	815936	20142Y	PARTICIPANT	\N	PRESENT	0
817780	815936	21073H	PARTICIPANT	\N	PRESENT	0
817781	815936	19768N	PARTICIPANT	\N	PRESENT	0
817782	815936	21037D	PARTICIPANT	\N	PRESENT	0
817783	815936	08015R	PARTICIPANT	\N	PRESENT	0
817784	815936	20092G	PARTICIPANT	\N	PRESENT	0
817785	815936	21079P	PARTICIPANT	\N	PRESENT	0
817786	815936	20108W	PARTICIPANT	\N	PRESENT	0
817787	815936	19399H	PARTICIPANT	\N	PRESENT	0
817788	815936	20130U	PARTICIPANT	\N	PRESENT	0
817789	815936	20056C	PARTICIPANT	\N	PRESENT	0
817790	815936	20266L	PARTICIPANT	\N	PRESENT	0
817791	815936	21058J	PARTICIPANT	\N	PRESENT	0
817792	815936	19447X	PARTICIPANT	\N	PRESENT	0
817793	815936	14173T	PARTICIPANT	\N	PRESENT	0
817794	815936	19782L	PARTICIPANT	\N	PRESENT	0
817795	815936	21068L	PARTICIPANT	\N	PRESENT	0
817796	815936	14331P	PARTICIPANT	\N	PRESENT	0
817797	815936	20146D	PARTICIPANT	\N	PRESENT	0
817798	815936	14038Y	PARTICIPANT	\N	PRESENT	0
817799	815936	14249W	PARTICIPANT	\N	PRESENT	0
817800	815936	19723Y	PARTICIPANT	\N	PRESENT	0
817801	815936	20106U	PARTICIPANT	\N	PRESENT	0
817802	815936	21047F	PARTICIPANT	\N	PRESENT	0
817803	815936	19591F	PARTICIPANT	\N	PRESENT	0
811430	811317	19413M	PARTICIPANT	\N	PRESENT	0
811431	811317	20082E	PARTICIPANT	\N	PRESENT	0
811432	811317	20104S	PARTICIPANT	\N	PRESENT	0
811433	811317	19631V	PARTICIPANT	\N	PRESENT	0
811434	811317	08015R	PARTICIPANT	\N	PRESENT	0
811435	811317	19575F	PARTICIPANT	\N	PRESENT	0
811436	811317	20018V	PARTICIPANT	\N	PRESENT	0
811437	811317	08028W	PARTICIPANT	\N	PRESENT	0
811438	811317	19563B	PARTICIPANT	\N	PRESENT	0
811439	811317	21050A	PARTICIPANT	\N	PRESENT	0
811440	811317	14329V	PARTICIPANT	\N	PRESENT	0
811441	811317	20028X	PARTICIPANT	\N	PRESENT	0
811442	811317	14038Y	PARTICIPANT	\N	PRESENT	0
811443	811317	14187A	PRESIDENT	0	PRESENT	0
811444	811317	20038A	PARTICIPANT	\N	PRESENT	0
811445	811317	21083K	PARTICIPANT	\N	PRESENT	0
811446	811317	21086N	PARTICIPANT	\N	PRESENT	0
811447	811317	20144B	PARTICIPANT	\N	PRESENT	0
811448	811317	19695N	PARTICIPANT	\N	PRESENT	0
811449	811317	11090Q	PARTICIPANT	\N	PRESENT	0
811450	811317	14033T	PARTICIPANT	\N	PRESENT	0
811451	811317	21093M	PARTICIPANT	\N	PRESENT	0
811452	811317	20054A	PARTICIPANT	\N	PRESENT	0
811453	811317	14205J	PARTICIPANT	\N	PRESENT	0
811454	811317	20066E	PARTICIPANT	\N	PRESENT	0
811455	811317	19507S	PARTICIPANT	\N	PRESENT	0
811456	811317	21066J	PARTICIPANT	\N	PRESENT	0
811457	811317	20286Q	PARTICIPANT	\N	PRESENT	0
811458	811317	14207L	PARTICIPANT	\N	PRESENT	0
811459	811317	14257W	PARTICIPANT	\N	PRESENT	0
811460	811317	20084G	PARTICIPANT	\N	PRESENT	0
811461	811317	21052C	PARTICIPANT	\N	EXCUSE	0
811462	808394	21081H	PARTICIPANT	\N	PRESENT	0
811465	808394	14042U	PARTICIPANT	\N	PRESENT	0
811469	808394	21094N	PARTICIPANT	\N	EXCUSE	0
811470	808394	14026U	PARTICIPANT	\N	PRESENT	0
811471	808394	17779H	PARTICIPANT	\N	PRESENT	0
811513	811512	14107H	PARTICIPANT	\N	PRESENT	0
811515	811514	14107H	PARTICIPANT	\N	PRESENT	0
811517	808394	21049H	PARTICIPANT	\N	PRESENT	0
811518	808394	20130U	PARTICIPANT	\N	EXCUSE	0
811519	810905	20130U	PARTICIPANT	\N	EXCUSE	0
811540	811535	14205J	PARTICIPANT	\N	PRESENT	0
811541	811535	14033T	PARTICIPANT	\N	PRESENT	0
811542	811535	19413M	PARTICIPANT	\N	PRESENT	0
811741	810211	14151M	PARTICIPANT	\N	EXCUSE	0
811749	811748	14187A	PARTICIPANT	\N	PRESENT	0
811750	811748	19383Y	PARTICIPANT	\N	PRESENT	0
811751	811748	21066J	PARTICIPANT	\N	PRESENT	0
811762	811760	20032T	PARTICIPANT	\N	PRESENT	0
811764	811760	20120S	PARTICIPANT	\N	PRESENT	0
811765	811760	21062E	PARTICIPANT	\N	PRESENT	0
812085	812083	14031R	PARTICIPANT	\N	PRESENT	0
812086	812083	21062E	PARTICIPANT	\N	PRESENT	0
812087	812083	20090E	PARTICIPANT	\N	PRESENT	0
812088	812083	20136B	PARTICIPANT	\N	PRESENT	0
812089	812083	14053L	PARTICIPANT	\N	PRESENT	0
812090	812083	21044C	PARTICIPANT	\N	PRESENT	0
812091	812083	14083S	PARTICIPANT	\N	PRESENT	0
812092	812083	14030Q	PARTICIPANT	\N	PRESENT	0
812093	812083	21051B	PARTICIPANT	\N	PRESENT	0
812094	812083	11065P	PARTICIPANT	\N	PRESENT	0
812718	812717	19758L	PARTICIPANT	\N	PRESENT	0
812719	812717	19866P	PARTICIPANT	\N	PRESENT	0
812788	804130	19057M	PARTICIPANT	\N	PRESENT	0
812839	810311	19647E	PARTICIPANT	\N	PRESENT	0
812840	810311	20180F	PARTICIPANT	\N	PRESENT	0
812841	810311	14069U	PARTICIPANT	\N	PRESENT	0
812842	810311	08018U	PARTICIPANT	\N	PRESENT	0
812843	810311	14211G	PARTICIPANT	\N	PRESENT	0
812844	810311	17965H	PARTICIPANT	\N	PRESENT	0
812845	810311	19683J	PARTICIPANT	\N	PRESENT	0
812846	810311	19111A	PARTICIPANT	\N	PRESENT	0
812847	810311	14042U	PARTICIPANT	\N	PRESENT	0
812848	810311	19709B	PARTICIPANT	\N	PRESENT	0
812850	810311	14179A	PARTICIPANT	\N	PRESENT	0
812851	810311	21046E	PARTICIPANT	\N	PRESENT	0
812858	810311	19693L	PARTICIPANT	\N	PRESENT	0
812859	812849	19679N	PARTICIPANT	\N	PRESENT	0
812860	812849	21046E	PARTICIPANT	\N	PRESENT	0
812861	810311	21085M	PARTICIPANT	\N	PRESENT	0
812862	810311	08015R	PARTICIPANT	\N	PRESENT	0
812863	810311	20106U	PARTICIPANT	\N	PRESENT	0
812866	812857	19679N	PARTICIPANT	\N	PRESENT	0
812867	812857	21046E	PARTICIPANT	\N	PRESENT	0
812877	810311	21060C	PARTICIPANT	\N	PRESENT	0
812878	810311	20038A	PARTICIPANT	\N	PRESENT	0
812879	810311	14147R	PARTICIPANT	\N	PRESENT	0
812880	810311	19673G	PARTICIPANT	\N	PRESENT	0
812881	804839	14042U	PARTICIPANT	\N	PRESENT	0
812882	804839	19760E	PARTICIPANT	\N	PRESENT	0
812883	804839	20130U	PARTICIPANT	\N	PRESENT	0
812884	810311	14083S	PARTICIPANT	\N	PRESENT	0
812886	812885	19758L	PARTICIPANT	\N	PRESENT	0
812887	812885	19569H	PARTICIPANT	\N	PRESENT	0
812888	812885	19683J	PARTICIPANT	\N	PRESENT	0
812889	812885	14213J	PARTICIPANT	\N	PRESENT	0
812890	812885	20130U	PARTICIPANT	\N	PRESENT	0
812891	812885	17965H	PARTICIPANT	\N	PRESENT	0
812892	810311	11053K	PARTICIPANT	\N	PRESENT	0
812893	810311	15197G	PARTICIPANT	\N	PRESENT	0
812894	810311	21089R	PARTICIPANT	\N	PRESENT	0
812895	810311	18193Q	PARTICIPANT	\N	PRESENT	0
812896	810311	21091K	PARTICIPANT	\N	PRESENT	0
812897	810311	14071N	PARTICIPANT	\N	PRESENT	0
812898	810311	20120S	PARTICIPANT	\N	PRESENT	0
812899	810311	19760E	PARTICIPANT	\N	PRESENT	0
812900	810311	21038E	PARTICIPANT	\N	PRESENT	0
812901	810311	20110Q	PARTICIPANT	\N	PRESENT	0
812902	810311	11065P	PARTICIPANT	\N	PRESENT	0
812910	810311	17023S	PARTICIPANT	\N	PRESENT	0
812911	810311	11045K	PARTICIPANT	\N	PRESENT	0
812912	810311	10015M	PARTICIPANT	\N	PRESENT	0
812913	810311	20266L	PARTICIPANT	\N	PRESENT	0
812914	810311	19533U	PARTICIPANT	\N	PRESENT	0
812915	810311	21083K	PARTICIPANT	\N	PRESENT	0
812916	810311	21093M	PARTICIPANT	\N	PRESENT	0
812917	810311	21056G	PARTICIPANT	\N	PRESENT	0
812918	810311	07029T	PARTICIPANT	\N	PRESENT	0
812919	810311	21071F	PARTICIPANT	\N	PRESENT	0
812931	812930	14179A	PARTICIPANT	\N	PRESENT	0
812932	812930	20090E	PARTICIPANT	\N	PRESENT	0
812933	812930	14133K	PARTICIPANT	\N	PRESENT	0
812934	812930	21093M	PARTICIPANT	\N	PRESENT	0
812935	812930	14030Q	PARTICIPANT	\N	PRESENT	0
812936	812930	14042U	PARTICIPANT	\N	PRESENT	0
812937	812930	19569H	PARTICIPANT	\N	PRESENT	0
812938	812930	21042A	PARTICIPANT	\N	PRESENT	0
812939	812930	19507S	PARTICIPANT	\N	PRESENT	0
812940	812930	21085M	PARTICIPANT	\N	PRESENT	0
812941	812930	20134Y	PARTICIPANT	\N	PRESENT	0
812942	812930	14001X	PARTICIPANT	\N	PRESENT	0
812943	812930	20062A	PARTICIPANT	\N	PRESENT	0
812944	812930	14037X	PARTICIPANT	\N	PRESENT	0
812945	812930	19545Y	PARTICIPANT	\N	PRESENT	0
812946	812930	14207L	PARTICIPANT	\N	PRESENT	0
812947	812930	19760E	PARTICIPANT	\N	PRESENT	0
812948	812930	21088Q	PARTICIPANT	\N	PRESENT	0
812949	812930	20264J	PARTICIPANT	\N	PRESENT	0
812950	812930	19593H	PARTICIPANT	\N	PRESENT	0
812951	812930	19565D	PARTICIPANT	\N	PRESENT	0
812952	812930	21055F	PARTICIPANT	\N	PRESENT	0
812953	812930	20092G	PARTICIPANT	\N	PRESENT	0
812954	812930	14205J	PARTICIPANT	\N	PRESENT	0
812955	812930	99004R	PARTICIPANT	\N	PRESENT	0
812956	812930	14357A	PARTICIPANT	\N	PRESENT	0
812957	812930	11090Q	PARTICIPANT	\N	PRESENT	0
812958	812930	14059S	PARTICIPANT	\N	PRESENT	0
812959	812930	19531S	PARTICIPANT	\N	PRESENT	0
812960	812930	14211G	PARTICIPANT	\N	PRESENT	0
812961	812930	21077M	PARTICIPANT	\N	PRESENT	0
812962	812930	19697Q	PARTICIPANT	\N	PRESENT	0
812963	812930	14251Q	PARTICIPANT	\N	PRESENT	0
812965	812930	21076L	PARTICIPANT	\N	PRESENT	0
812968	812930	15197G	PARTICIPANT	\N	PRESENT	0
812969	812930	19758L	PARTICIPANT	\N	PRESENT	0
812970	812930	11056N	PARTICIPANT	\N	PRESENT	0
812971	812930	21075K	PARTICIPANT	\N	PRESENT	0
812972	812930	11040E	PARTICIPANT	\N	PRESENT	0
812973	812930	21073H	PARTICIPANT	\N	PRESENT	0
812974	812930	20030R	PARTICIPANT	\N	PRESENT	0
797277	797274	11090Q	PARTICIPANT	\N	PRESENT	0
797278	797274	14331P	PARTICIPANT	\N	PRESENT	0
797279	797274	19711U	PARTICIPANT	\N	PRESENT	0
797439	797438	11090Q	PARTICIPANT	\N	PRESENT	0
797440	797438	18083K	PARTICIPANT	\N	PRESENT	0
797441	797438	20084G	PARTICIPANT	\N	PRESENT	0
797442	797438	14255U	PARTICIPANT	\N	PRESENT	0
797443	797438	14083S	PARTICIPANT	\N	PRESENT	0
797444	797438	19565D	PARTICIPANT	\N	PRESENT	0
797445	797438	17229F	PARTICIPANT	\N	PRESENT	0
797446	797438	14037X	PARTICIPANT	\N	PRESENT	0
797447	797438	21036C	PARTICIPANT	\N	PRESENT	0
801172	801171	17367Q	PARTICIPANT	\N	PRESENT	0
801173	801171	14151M	PARTICIPANT	\N	PRESENT	0
801174	801171	21072G	PARTICIPANT	\N	PRESENT	0
801175	801171	20110Q	PARTICIPANT	\N	PRESENT	0
801487	801144	17367Q	PARTICIPANT	\N	PRESENT	0
801488	801144	14151M	PRESIDENT	0	PRESENT	0
801489	801144	12028B	PARTICIPANT	\N	PRESENT	0
801490	801144	20146D	PARTICIPANT	\N	PRESENT	0
801491	801144	19295A	PARTICIPANT	\N	PRESENT	0
801492	801144	21040X	PARTICIPANT	\N	EXCUSE	0
801493	801144	19349W	PARTICIPANT	\N	EXCUSE	0
801494	801145	19349W	PARTICIPANT	\N	EXCUSE	0
801655	801396	18193Q	PARTICIPANT	\N	PRESENT	0
801657	801396	14026U	PARTICIPANT	\N	PRESENT	0
801658	801396	19683J	PARTICIPANT	\N	PRESENT	0
801660	801396	19760E	PARTICIPANT	\N	PRESENT	0
801661	801396	14042U	PARTICIPANT	\N	PRESENT	0
801662	801396	04092N	PRESIDENT	0	PRESENT	0
801664	801396	17965H	PARTICIPANT	\N	PRESENT	0
801826	801396	21097R	PARTICIPANT	\N	PRESENT	0
801827	801396	14071N	PARTICIPANT	\N	EXCUSE	0
804364	799591	19760E	PARTICIPANT	\N	PRESENT	0
804365	799591	14042U	PARTICIPANT	\N	PRESENT	0
804370	799591	21094N	PARTICIPANT	\N	PRESENT	0
804371	799592	19760E	PARTICIPANT	\N	PRESENT	0
804372	799592	20130U	PARTICIPANT	\N	PRESENT	0
804373	799592	14042U	PARTICIPANT	\N	PRESENT	0
804374	799592	21094N	PARTICIPANT	\N	PRESENT	0
804375	799593	19760E	PARTICIPANT	\N	PRESENT	0
804376	799593	20130U	PARTICIPANT	\N	PRESENT	0
804377	799593	14042U	PARTICIPANT	\N	PRESENT	0
804378	799593	21094N	PARTICIPANT	\N	PRESENT	0
804492	804049	14151M	PRESIDENT	0	PRESENT	0
804494	804049	17367Q	PARTICIPANT	\N	PRESENT	0
804495	804049	12028B	PARTICIPANT	\N	PRESENT	0
804496	804049	17737W	PARTICIPANT	\N	PRESENT	0
804497	804049	20078J	PARTICIPANT	\N	PRESENT	0
804498	804049	20146D	PARTICIPANT	\N	PRESENT	0
804499	804049	18395Y	PARTICIPANT	\N	PRESENT	0
804502	804049	21095P	PARTICIPANT	\N	PRESENT	0
804503	804049	20110Q	PARTICIPANT	\N	PRESENT	0
805245	804012	14053L	PARTICIPANT	\N	PRESENT	0
805246	804012	14111D	PARTICIPANT	\N	PRESENT	0
805247	804012	20074E	PARTICIPANT	\N	PRESENT	0
805248	804012	10015M	PARTICIPANT	\N	PRESENT	0
805249	804012	21076L	PARTICIPANT	\N	PRESENT	0
805250	804012	04047H	PRESIDENT	0	PRESENT	0
805251	804012	21040X	PARTICIPANT	\N	PRESENT	0
805252	804012	19447X	PARTICIPANT	\N	PRESENT	0
805253	804012	11056N	PARTICIPANT	\N	PRESENT	0
805254	804012	21044C	PARTICIPANT	\N	PRESENT	0
805255	804012	14147R	PARTICIPANT	\N	PRESENT	0
805256	804012	14151M	PARTICIPANT	\N	PRESENT	0
805257	804012	14215L	PARTICIPANT	\N	PRESENT	0
805258	804012	21095P	PARTICIPANT	\N	PRESENT	0
805259	804012	19749K	PARTICIPANT	\N	PRESENT	0
805260	804012	11072N	PARTICIPANT	\N	PRESENT	0
805261	804012	14231L	PARTICIPANT	\N	PRESENT	0
805262	804012	19725B	PARTICIPANT	\N	PRESENT	0
805263	804012	18207D	PARTICIPANT	\N	PRESENT	0
805264	804012	20108W	PARTICIPANT	\N	PRESENT	0
805265	804012	18231D	PARTICIPANT	\N	PRESENT	0
805266	804012	20022R	PARTICIPANT	\N	PRESENT	0
805267	804012	21057H	PARTICIPANT	\N	PRESENT	0
805268	804012	05008E	PARTICIPANT	\N	PRESENT	0
805269	804012	14089Y	PARTICIPANT	\N	PRESENT	0
805270	804012	14275Y	PARTICIPANT	\N	PRESENT	0
805271	804012	19649G	PARTICIPANT	\N	PRESENT	0
805272	804012	21056G	PARTICIPANT	\N	EXCUSE	0
805273	804012	14259Y	PARTICIPANT	\N	PRESENT	0
805274	804012	21038E	PARTICIPANT	\N	PRESENT	0
805276	804012	19729F	PARTICIPANT	\N	EXCUSE	0
805277	804012	19585H	PARTICIPANT	\N	EXCUSE	0
805279	804012	21043B	PARTICIPANT	\N	PRESENT	0
805315	804012	14069U	PARTICIPANT	\N	PRESENT	0
805318	805275	19697Q	PARTICIPANT	\N	PRESENT	0
805319	805275	19699S	PARTICIPANT	\N	PRESENT	0
805320	805275	19533U	PARTICIPANT	\N	PRESENT	0
805321	805275	21058J	PARTICIPANT	\N	PRESENT	0
805322	805275	21059K	PARTICIPANT	\N	PRESENT	0
805323	805275	20102Q	PARTICIPANT	\N	PRESENT	0
805324	805275	14229S	PARTICIPANT	\N	PRESENT	0
805325	805275	19954N	PARTICIPANT	\N	PRESENT	0
805326	805275	20112S	PARTICIPANT	\N	PRESENT	0
805327	805275	21089R	PARTICIPANT	\N	PRESENT	0
805328	805275	08012N	PARTICIPANT	\N	PRESENT	0
805329	805275	21037D	PARTICIPANT	\N	PRESENT	0
805330	805275	21091K	PARTICIPANT	\N	PRESENT	0
805331	805275	20124W	PARTICIPANT	\N	PRESENT	0
805332	805275	20026V	PARTICIPANT	\N	PRESENT	0
805333	805275	19593H	PARTICIPANT	\N	PRESENT	0
805334	805275	20132W	PARTICIPANT	\N	PRESENT	0
805335	805275	20122U	PARTICIPANT	\N	PRESENT	0
805336	805275	19611R	PARTICIPANT	\N	PRESENT	0
805337	805275	20142Y	PARTICIPANT	\N	PRESENT	0
805338	805275	20048C	PARTICIPANT	\N	PRESENT	0
805339	805275	19693L	PARTICIPANT	\N	PRESENT	0
805340	805275	20052X	PARTICIPANT	\N	PRESENT	0
805341	805275	20172F	PARTICIPANT	\N	PRESENT	0
805342	805275	14030Q	PARTICIPANT	\N	PRESENT	0
805343	805275	20058E	PARTICIPANT	\N	PRESENT	0
805344	805275	20264J	PARTICIPANT	\N	PRESENT	0
805345	805275	21063F	PARTICIPANT	\N	PRESENT	0
805346	805275	14123H	PARTICIPANT	\N	PRESENT	0
805347	805275	11043H	PARTICIPANT	\N	PRESENT	0
805348	805275	21074J	PARTICIPANT	\N	PRESENT	0
805349	805275	21077M	PARTICIPANT	\N	PRESENT	0
805350	805275	21078N	PARTICIPANT	\N	PRESENT	0
805667	801407	14237S	PARTICIPANT	\N	PRESENT	0
805352	805275	19621T	PARTICIPANT	\N	PRESENT	0
805353	805275	14021P	PARTICIPANT	\N	PRESENT	0
805360	805275	21032X	PARTICIPANT	\N	PRESENT	0
805361	805275	18395Y	PARTICIPANT	\N	PRESENT	0
805362	805275	14109K	PARTICIPANT	\N	PRESENT	0
805363	805275	04033B	PARTICIPANT	\N	PRESENT	0
805368	804012	20114U	PARTICIPANT	\N	PRESENT	0
805369	804012	19673G	PARTICIPANT	\N	PRESENT	0
805371	805275	04070G	PARTICIPANT	\N	PRESENT	0
805384	804012	20110Q	PARTICIPANT	\N	PRESENT	0
805385	804012	19489J	PARTICIPANT	\N	PRESENT	0
805428	804012	20036X	PARTICIPANT	\N	PRESENT	0
805641	801407	19820Y	PARTICIPANT	\N	PRESENT	0
805642	801407	19826F	PARTICIPANT	\N	PRESENT	0
805643	801407	19551W	PARTICIPANT	\N	PRESENT	0
805644	801407	08060W	PARTICIPANT	\N	PRESENT	0
805645	801407	15197G	PARTICIPANT	\N	PRESENT	0
805646	801407	20020P	PARTICIPANT	\N	PRESENT	0
805648	801407	11065P	PARTICIPANT	\N	PRESENT	0
805649	801407	21051B	PARTICIPANT	\N	PRESENT	0
805650	801407	20032T	PARTICIPANT	\N	PRESENT	0
805651	801407	21053D	PARTICIPANT	\N	PRESENT	0
805652	801407	20040T	PARTICIPANT	\N	PRESENT	0
805653	801407	20046A	PARTICIPANT	\N	PRESENT	0
805654	801407	17229F	PARTICIPANT	\N	PRESENT	0
805655	801407	20068G	PARTICIPANT	\N	PRESENT	0
805656	801407	21068L	PARTICIPANT	\N	PRESENT	0
805657	801407	21070E	PARTICIPANT	\N	PRESENT	0
805658	801407	21082J	PARTICIPANT	\N	PRESENT	0
805659	801407	20076G	PARTICIPANT	\N	PRESENT	0
805660	801407	19387D	PARTICIPANT	\N	PRESENT	0
805661	801407	14219Q	PRESIDENT	0	PRESENT	0
805664	801407	21061D	PARTICIPANT	\N	PRESENT	0
805666	801407	21065H	PARTICIPANT	\N	PRESENT	0
803674	801390	21093M	PARTICIPANT	\N	PRESENT	0
803675	801390	14121F	PARTICIPANT	\N	PRESENT	0
803676	801390	19683J	PARTICIPANT	\N	PRESENT	0
803677	801390	21044C	PARTICIPANT	\N	PRESENT	0
803678	801390	20056C	PARTICIPANT	\N	PRESENT	0
803679	801390	19447X	PARTICIPANT	\N	PRESENT	0
803680	801390	14097Y	PARTICIPANT	\N	PRESENT	0
803681	801390	14021P	PARTICIPANT	\N	PRESENT	0
803682	801390	99004R	PARTICIPANT	\N	PRESENT	0
803683	801390	14073Q	PARTICIPANT	\N	PRESENT	0
803684	801390	19489J	PARTICIPANT	\N	PRESENT	0
803685	801390	21081H	PARTICIPANT	\N	PRESENT	0
803686	801390	19611R	PARTICIPANT	\N	PRESENT	0
803687	801390	20102Q	PARTICIPANT	\N	PRESENT	0
803688	801390	07029T	PARTICIPANT	\N	PRESENT	0
803689	801390	21078N	PARTICIPANT	\N	PRESENT	0
803690	801390	19735D	PARTICIPANT	\N	PRESENT	0
803691	801390	86034E	PARTICIPANT	\N	PRESENT	0
803692	801390	19699S	PARTICIPANT	\N	PRESENT	0
803693	801390	08015R	PARTICIPANT	\N	PRESENT	0
803694	801390	19709B	PARTICIPANT	\N	PRESENT	0
803695	801390	18193Q	PARTICIPANT	\N	PRESENT	0
803696	801390	20108W	PARTICIPANT	\N	PRESENT	0
803697	801390	08010L	PARTICIPANT	\N	PRESENT	0
803698	801390	08034U	PARTICIPANT	\N	PRESENT	0
803700	801390	14037X	PARTICIPANT	\N	PRESENT	0
803701	801390	21087P	PARTICIPANT	\N	PRESENT	0
803702	801390	20052X	PARTICIPANT	\N	PRESENT	0
803703	801390	19697Q	PARTICIPANT	\N	PRESENT	0
803704	801390	19649G	PARTICIPANT	\N	PRESENT	0
803705	801390	18207D	PARTICIPANT	\N	PRESENT	0
803706	801390	14205J	PARTICIPANT	\N	PRESENT	0
803707	801390	14219Q	PARTICIPANT	\N	PRESENT	0
803708	801390	14059S	PARTICIPANT	\N	PRESENT	0
803709	801390	21054E	PARTICIPANT	\N	PRESENT	0
803710	801390	08012N	PARTICIPANT	\N	PRESENT	0
803711	801390	17779H	PARTICIPANT	\N	PRESENT	0
803712	801390	12016W	PARTICIPANT	\N	PRESENT	0
803713	801390	19657G	PARTICIPANT	\N	PRESENT	0
803714	801390	14251Q	PARTICIPANT	\N	PRESENT	0
803715	801390	14031R	PARTICIPANT	\N	PRESENT	0
803716	801390	20142Y	PARTICIPANT	\N	PRESENT	0
803717	801390	21075K	PARTICIPANT	\N	PRESENT	0
803718	801390	11085T	PARTICIPANT	\N	PRESENT	0
803719	801390	19826F	PARTICIPANT	\N	PRESENT	0
803720	801390	21058J	PARTICIPANT	\N	PRESENT	0
803721	801390	21040X	PARTICIPANT	\N	PRESENT	0
803722	801390	08009T	PARTICIPANT	\N	PRESENT	0
803723	801390	14221J	PARTICIPANT	\N	PRESENT	0
803724	801390	20252E	PARTICIPANT	\N	PRESENT	0
803725	801390	21073H	PARTICIPANT	\N	PRESENT	0
803726	801390	19563B	PARTICIPANT	\N	PRESENT	0
803727	801390	14147R	PARTICIPANT	\N	PRESENT	0
803728	801390	20028X	PARTICIPANT	\N	PRESENT	0
803729	801390	21080G	PARTICIPANT	\N	PRESENT	0
803730	801390	20018V	PARTICIPANT	\N	PRESENT	0
803731	801390	04092N	PARTICIPANT	\N	PRESENT	0
803732	801390	11072N	PARTICIPANT	\N	PRESENT	0
803733	801390	14109K	PARTICIPANT	\N	PRESENT	0
803734	801390	14257W	PARTICIPANT	\N	PRESENT	0
803735	801390	14071N	PARTICIPANT	\N	PRESENT	0
803736	801390	04070G	PARTICIPANT	\N	PRESENT	0
803737	801390	21097R	PARTICIPANT	\N	PRESENT	0
803738	801390	18231D	PARTICIPANT	\N	PRESENT	0
803739	801390	21029D	PARTICIPANT	\N	PRESENT	0
803740	801390	14169X	PARTICIPANT	\N	PRESENT	0
803741	801390	19768N	PARTICIPANT	\N	PRESENT	0
803742	801390	14253S	PARTICIPANT	\N	PRESENT	0
803743	801390	21037D	PARTICIPANT	\N	PRESENT	0
803744	801390	21060C	PARTICIPANT	\N	PRESENT	0
803745	801390	19593H	PARTICIPANT	\N	PRESENT	0
803746	801390	19866P	PARTICIPANT	\N	PRESENT	0
803747	801390	14191V	PARTICIPANT	\N	PRESENT	0
803748	801390	08061X	PARTICIPANT	\N	PRESENT	0
803749	801390	21055F	PARTICIPANT	\N	PRESENT	0
803750	801390	21047F	PARTICIPANT	\N	PRESENT	0
803751	801390	14193X	PARTICIPANT	\N	PRESENT	0
803752	801390	19745F	PARTICIPANT	\N	PRESENT	0
803753	801390	19533U	PARTICIPANT	\N	PRESENT	0
803754	801390	21053D	PARTICIPANT	\N	PRESENT	0
803755	801390	20030R	PARTICIPANT	\N	PRESENT	0
803756	801390	20118Y	PARTICIPANT	\N	PRESENT	0
803757	801390	05012A	PARTICIPANT	\N	PRESENT	0
803758	801390	17965H	PARTICIPANT	\N	PRESENT	0
803759	801390	11090Q	PARTICIPANT	\N	PRESENT	0
803760	801390	19679N	PARTICIPANT	\N	PRESENT	0
803761	801390	14331P	PARTICIPANT	\N	PRESENT	0
803762	801390	19349W	PARTICIPANT	\N	PRESENT	0
803763	801390	14055N	PARTICIPANT	\N	PRESENT	0
803764	801390	14225N	PARTICIPANT	\N	PRESENT	0
803765	801390	20082E	PARTICIPANT	\N	PRESENT	0
803766	801390	10015M	PARTICIPANT	\N	PRESENT	0
803767	801390	19705W	PARTICIPANT	\N	PRESENT	0
803768	801390	04033B	PARTICIPANT	\N	PRESENT	0
803769	801390	21068L	PARTICIPANT	\N	PRESENT	0
803770	801390	21038E	PARTICIPANT	\N	PRESENT	0
803771	801390	19798U	PARTICIPANT	\N	PRESENT	0
803772	801390	20054A	PARTICIPANT	\N	PRESENT	0
803773	801390	14229S	PARTICIPANT	\N	PRESENT	0
803774	801390	21070E	PARTICIPANT	\N	PRESENT	0
803775	801390	21056G	PARTICIPANT	\N	PRESENT	0
803777	801390	11045K	PARTICIPANT	\N	PRESENT	0
803778	801390	21059K	PARTICIPANT	\N	PRESENT	0
803779	801390	14107H	PARTICIPANT	\N	PRESENT	0
803781	801390	21036C	PARTICIPANT	\N	PRESENT	0
803783	801390	20092G	PARTICIPANT	\N	PRESENT	0
803784	801390	19421M	PARTICIPANT	\N	PRESENT	0
803785	801390	20044X	PARTICIPANT	\N	PRESENT	0
803786	801390	11043H	PARTICIPANT	\N	PRESENT	0
803787	801390	19687N	PARTICIPANT	\N	PRESENT	0
803788	801390	20098N	PARTICIPANT	\N	PRESENT	0
803789	801390	04045F	PARTICIPANT	\N	PRESENT	0
803790	801390	21079P	PARTICIPANT	\N	PRESENT	0
803791	801390	21049H	PARTICIPANT	\N	PRESENT	0
803792	801390	19703U	PARTICIPANT	\N	PRESENT	0
803793	801390	19713W	PARTICIPANT	\N	PRESENT	0
803794	801390	20062A	PARTICIPANT	\N	PRESENT	0
803795	801390	21094N	PARTICIPANT	\N	PRESENT	0
803796	801390	20084G	PARTICIPANT	\N	PRESENT	0
803797	801390	21069M	PARTICIPANT	\N	PRESENT	0
803798	801390	21095P	PARTICIPANT	\N	PRESENT	0
803799	801390	20136B	PARTICIPANT	\N	PRESENT	0
803800	801390	19669L	PARTICIPANT	\N	PRESENT	0
803801	801390	19301E	PARTICIPANT	\N	PRESENT	0
803802	801390	19413M	PARTICIPANT	\N	PRESENT	0
803803	801390	21061D	PARTICIPANT	\N	PRESENT	0
803804	801390	20064C	PARTICIPANT	\N	PRESENT	0
803805	801390	20046A	PARTICIPANT	\N	PRESENT	0
803806	801390	20026V	PARTICIPANT	\N	PRESENT	0
803807	801390	19749K	PARTICIPANT	\N	PRESENT	0
803808	801390	19479G	PARTICIPANT	\N	PRESENT	0
803809	801390	20122U	PARTICIPANT	\N	PRESENT	0
803810	801390	20058E	PARTICIPANT	\N	PRESENT	0
803811	801390	20266L	PARTICIPANT	\N	PRESENT	0
803812	801390	21076L	PARTICIPANT	\N	PRESENT	0
803813	801390	21082J	PARTICIPANT	\N	PRESENT	0
803814	801390	21077M	PARTICIPANT	\N	PRESENT	0
803929	803926	21090J	PARTICIPANT	\N	PRESENT	0
803930	803926	14217N	PARTICIPANT	\N	PRESENT	0
803931	803926	14215L	PARTICIPANT	\N	PRESENT	0
803932	803926	14281W	PARTICIPANT	\N	PRESENT	0
803934	803926	18193Q	PARTICIPANT	\N	PRESENT	0
803935	803926	14059S	PARTICIPANT	\N	PRESENT	0
803936	803926	14147R	PARTICIPANT	\N	PRESENT	0
803937	803926	14223L	PARTICIPANT	\N	PRESENT	0
803938	803926	19798U	PARTICIPANT	\N	PRESENT	0
803939	803926	20026V	PARTICIPANT	\N	PRESENT	0
803985	803984	04047H	PARTICIPANT	\N	PRESENT	0
803986	803984	21076L	PARTICIPANT	\N	PRESENT	0
803987	803984	18231D	PARTICIPANT	\N	PRESENT	0
803988	803984	19673G	PARTICIPANT	\N	PRESENT	0
804290	804049	21040X	PARTICIPANT	\N	EXCUSE	0
804291	804052	21040X	PARTICIPANT	\N	EXCUSE	0
804382	804381	19758L	PARTICIPANT	\N	PRESENT	0
804383	804381	21039F	PARTICIPANT	\N	PRESENT	0
804384	804381	17965H	PARTICIPANT	\N	PRESENT	0
804787	804010	04047H	PRESIDENT	0	PRESENT	0
804788	804010	14053L	PARTICIPANT	\N	PRESENT	0
804789	804010	19649G	PARTICIPANT	\N	PRESENT	0
804790	804010	14069U	PARTICIPANT	\N	PRESENT	0
804792	804010	21057H	PARTICIPANT	\N	PRESENT	0
797984	791846	21055F	PARTICIPANT	\N	PRESENT	0
802808	802807	18083K	PARTICIPANT	\N	PRESENT	0
802811	802807	20120S	PARTICIPANT	\N	PRESENT	0
802812	802807	14037X	PARTICIPANT	\N	PRESENT	0
802813	802807	20038A	PARTICIPANT	\N	PRESENT	0
802814	802807	20084G	PARTICIPANT	\N	PRESENT	0
806976	806952	19507S	PARTICIPANT	\N	PRESENT	0
806977	806964	19507S	PARTICIPANT	\N	PRESENT	0
806978	806964	14205J	PARTICIPANT	\N	PRESENT	0
806982	806966	14205J	PARTICIPANT	\N	PRESENT	0
806980	806965	19507S	PARTICIPANT	\N	PRESENT	0
806981	806966	19507S	PARTICIPANT	\N	PRESENT	0
806984	806966	19563B	PARTICIPANT	\N	PRESENT	0
806988	806969	19563B	PARTICIPANT	\N	PRESENT	0
806986	806969	19507S	PARTICIPANT	\N	PRESENT	0
806987	806969	14205J	PARTICIPANT	\N	PRESENT	0
806989	806970	19507S	PARTICIPANT	\N	PRESENT	0
806990	806970	14205J	PARTICIPANT	\N	PRESENT	0
806991	806970	14033T	PARTICIPANT	\N	PRESENT	0
806992	806970	19563B	PARTICIPANT	\N	PRESENT	0
806993	806971	19507S	PARTICIPANT	\N	PRESENT	0
806994	806971	14205J	PARTICIPANT	\N	PRESENT	0
806995	806971	19563B	PARTICIPANT	\N	PRESENT	0
806996	806971	14033T	PARTICIPANT	\N	PRESENT	0
806997	806972	19507S	PARTICIPANT	\N	PRESENT	0
806998	806972	14033T	PARTICIPANT	\N	PRESENT	0
806999	806972	14205J	PARTICIPANT	\N	PRESENT	0
807000	806973	19507S	PARTICIPANT	\N	PRESENT	0
807001	806973	14033T	PARTICIPANT	\N	PRESENT	0
807002	806973	14205J	PARTICIPANT	\N	PRESENT	0
807205	807204	04042C	PARTICIPANT	\N	PRESENT	0
807207	807206	04042C	PARTICIPANT	\N	PRESENT	0
807364	807354	20038A	PARTICIPANT	\N	PRESENT	0
807365	807354	21090J	PARTICIPANT	\N	PRESENT	0
807366	807354	99004R	PARTICIPANT	\N	PRESENT	0
807367	807354	21093M	PARTICIPANT	\N	PRESENT	0
807368	807354	11090Q	PARTICIPANT	\N	PRESENT	0
807369	807354	17023S	PARTICIPANT	\N	PRESENT	0
807370	807354	21056G	PARTICIPANT	\N	EXCUSE	0
807371	807354	21031W	PARTICIPANT	\N	EXCUSE	0
807372	807354	19413M	PARTICIPANT	\N	EXCUSE	0
809281	809280	14147R	PARTICIPANT	\N	PRESENT	0
809282	809280	20286Q	PARTICIPANT	\N	PRESENT	0
809283	809280	21075K	PARTICIPANT	\N	PRESENT	0
809284	809280	21059K	PARTICIPANT	\N	PRESENT	0
809285	809280	18207D	PARTICIPANT	\N	PRESENT	0
809286	809280	20090E	PARTICIPANT	\N	PRESENT	0
809287	809280	19768N	PARTICIPANT	\N	PRESENT	0
809288	809280	20124W	PARTICIPANT	\N	PRESENT	0
809289	809280	19447X	PARTICIPANT	\N	PRESENT	0
809306	809305	20286Q	PARTICIPANT	\N	PRESENT	0
809307	809305	21075K	PARTICIPANT	\N	PRESENT	0
809310	809305	19447X	PARTICIPANT	\N	PRESENT	0
809311	809305	17229F	PARTICIPANT	\N	PRESENT	0
809312	809305	21092L	PARTICIPANT	\N	PRESENT	0
809313	809305	21059K	PARTICIPANT	\N	PRESENT	0
809319	809315	20286Q	PARTICIPANT	\N	PRESENT	0
809320	809315	21075K	PARTICIPANT	\N	PRESENT	0
809321	809315	19447X	PARTICIPANT	\N	PRESENT	0
809322	809315	17229F	PARTICIPANT	\N	PRESENT	0
809323	809315	21092L	PARTICIPANT	\N	PRESENT	0
809324	809315	21059K	PARTICIPANT	\N	PRESENT	0
813418	813417	19631V	PARTICIPANT	\N	PRESENT	0
813419	813417	14187A	PARTICIPANT	\N	PRESENT	0
813441	807358	19954N	PARTICIPANT	\N	PRESENT	0
813442	807358	20264J	PARTICIPANT	\N	PRESENT	0
813443	807358	20052X	PARTICIPANT	\N	PRESENT	0
815983	815982	21067K	PARTICIPANT	\N	PRESENT	0
815984	815982	11090Q	PARTICIPANT	\N	PRESENT	0
815986	815985	21067K	PARTICIPANT	\N	PRESENT	0
815987	815985	20252E	PARTICIPANT	\N	PRESENT	0
815988	815985	11090Q	PARTICIPANT	\N	PRESENT	0
815990	815989	20252E	PARTICIPANT	\N	PRESENT	0
815991	815989	11090Q	PARTICIPANT	\N	PRESENT	0
816969	815902	20044X	PARTICIPANT	\N	PRESENT	0
816970	815902	19349W	PARTICIPANT	\N	PRESENT	0
816971	815902	19479G	PARTICIPANT	\N	PRESENT	0
816972	815902	19399H	PARTICIPANT	\N	PRESENT	0
816973	815902	19711U	PARTICIPANT	\N	PRESENT	0
816979	815902	20026V	PARTICIPANT	\N	PRESENT	0
816980	815902	20286Q	PARTICIPANT	\N	PRESENT	0
816981	815902	19703U	PARTICIPANT	\N	PRESENT	0
816982	815902	20106U	PARTICIPANT	\N	PRESENT	0
816985	815902	21063F	PARTICIPANT	\N	PRESENT	0
816987	815902	21041Y	PARTICIPANT	\N	EXCUSE	0
816988	815902	20018V	PARTICIPANT	\N	EXCUSE	0
816989	815902	20066E	PARTICIPANT	\N	EXCUSE	0
816990	815902	19798U	PARTICIPANT	\N	EXCUSE	0
816991	815902	20042V	PARTICIPANT	\N	EXCUSE	0
816992	815902	21054E	PARTICIPANT	\N	EXCUSE	0
817003	815902	20060X	PARTICIPANT	\N	EXCUSE	0
817004	815902	14169X	PARTICIPANT	\N	EXCUSE	0
817071	815902	20082E	PARTICIPANT	\N	PRESENT	0
817804	815936	14037X	PARTICIPANT	\N	PRESENT	0
817805	815936	21063F	PARTICIPANT	\N	PRESENT	0
817806	815936	19697Q	PARTICIPANT	\N	PRESENT	0
817807	815936	17367Q	PARTICIPANT	\N	PRESENT	0
817808	815936	04033B	PARTICIPANT	\N	PRESENT	0
817809	815936	19709B	PARTICIPANT	\N	PRESENT	0
817810	815936	11072N	PARTICIPANT	\N	PRESENT	0
817811	815936	20140W	PARTICIPANT	\N	PRESENT	0
817812	815936	19331L	PARTICIPANT	\N	PRESENT	0
817813	815936	08061X	PARTICIPANT	\N	PRESENT	0
817814	815936	20104S	PARTICIPANT	\N	PRESENT	0
817815	815936	19507S	PARTICIPANT	\N	PRESENT	0
817816	815936	14059S	PARTICIPANT	\N	PRESENT	0
817817	815936	20096L	PARTICIPANT	\N	PRESENT	0
817818	815936	20038A	PARTICIPANT	\N	PRESENT	0
817819	815936	20126Y	PARTICIPANT	\N	PRESENT	0
817820	815936	20124W	PARTICIPANT	\N	PRESENT	0
817821	815936	21074J	PARTICIPANT	\N	PRESENT	0
817822	815936	20098N	PARTICIPANT	\N	PRESENT	0
817823	815936	21085M	PARTICIPANT	\N	PRESENT	0
817824	815936	14055N	PARTICIPANT	\N	PRESENT	0
817825	815936	21069M	PARTICIPANT	\N	PRESENT	0
817826	815936	20020P	PARTICIPANT	\N	PRESENT	0
817827	815936	20116W	PARTICIPANT	\N	PRESENT	0
817828	815936	20252E	PARTICIPANT	\N	PRESENT	0
817829	815936	08073C	PARTICIPANT	\N	PRESENT	0
817830	815936	14217N	PARTICIPANT	\N	PRESENT	0
817831	815936	14207L	PARTICIPANT	\N	PRESENT	0
817832	815936	21041Y	PARTICIPANT	\N	PRESENT	0
817833	815936	20118Y	PARTICIPANT	\N	PRESENT	0
817834	815936	20072C	PARTICIPANT	\N	PRESENT	0
817835	815936	21040X	PARTICIPANT	\N	PRESENT	0
817836	815936	19533U	PARTICIPANT	\N	PRESENT	0
817837	815936	19719D	PARTICIPANT	\N	PRESENT	0
817838	815936	14069U	PARTICIPANT	\N	PRESENT	0
817839	815936	20132W	PARTICIPANT	\N	PRESENT	0
817840	815936	19629C	PARTICIPANT	\N	PRESENT	0
817841	815936	14071N	PARTICIPANT	\N	PRESENT	0
817842	815936	21066J	PARTICIPANT	\N	PRESENT	0
817843	815936	14187A	PARTICIPANT	\N	PRESENT	0
817844	815936	14241N	PARTICIPANT	\N	PRESENT	0
817845	815936	04092N	PARTICIPANT	\N	PRESENT	0
817846	815936	19701S	PARTICIPANT	\N	PRESENT	0
817847	815936	20150Y	PARTICIPANT	\N	PRESENT	0
817848	815936	11090Q	PARTICIPANT	\N	PRESENT	0
817849	815936	20062A	PARTICIPANT	\N	PRESENT	0
817850	815936	21046E	PARTICIPANT	\N	PRESENT	0
817851	815936	05008E	PARTICIPANT	\N	PRESENT	0
817852	815936	14195A	PARTICIPANT	\N	PRESENT	0
817853	815936	21065H	PARTICIPANT	\N	PRESENT	0
817854	815936	14133K	PARTICIPANT	\N	PRESENT	0
817859	815936	14251Q	PARTICIPANT	\N	PRESENT	0
817856	815936	08034U	PARTICIPANT	\N	PRESENT	0
817857	815936	04047H	PARTICIPANT	\N	PRESENT	0
817858	815936	21054E	PARTICIPANT	\N	PRESENT	0
817860	815936	14221J	PARTICIPANT	\N	PRESENT	0
817861	815936	20050V	PARTICIPANT	\N	PRESENT	0
817862	815936	19703U	PARTICIPANT	\N	PRESENT	0
817863	815936	20122U	PARTICIPANT	\N	PRESENT	0
817864	815936	21076L	PARTICIPANT	\N	PRESENT	0
817865	815936	20172F	PARTICIPANT	\N	PRESENT	0
817866	815936	21035B	PARTICIPANT	\N	PRESENT	0
817867	815936	19657G	PARTICIPANT	\N	PRESENT	0
817868	815936	07029T	PARTICIPANT	\N	PRESENT	0
817869	815936	08060W	PARTICIPANT	\N	PRESENT	0
817870	815936	20080C	PARTICIPANT	\N	PRESENT	0
817871	815936	21089R	PARTICIPANT	\N	PRESENT	0
817872	815936	20034V	PARTICIPANT	\N	PRESENT	0
812975	812930	19649G	PARTICIPANT	\N	PRESENT	0
812976	812930	19683J	PARTICIPANT	\N	PRESENT	0
812977	812930	21079P	PARTICIPANT	\N	PRESENT	0
812978	812930	19563B	PARTICIPANT	\N	PRESENT	0
812979	812930	17023S	PARTICIPANT	\N	PRESENT	0
812980	812930	11053K	PARTICIPANT	\N	PRESENT	0
812982	812930	21049H	PARTICIPANT	\N	PRESENT	0
812983	812930	21089R	PARTICIPANT	\N	PRESENT	0
812984	812930	11065P	PARTICIPANT	\N	PRESENT	0
812985	812930	19413M	PARTICIPANT	\N	PRESENT	0
812986	812930	20070A	PARTICIPANT	\N	PRESENT	0
812987	812930	21084L	PARTICIPANT	\N	PRESENT	0
812989	812930	14249W	PARTICIPANT	\N	PRESENT	0
812991	812930	21091K	PARTICIPANT	\N	PRESENT	0
812992	812930	20072C	PARTICIPANT	\N	PRESENT	0
812995	812930	21054E	PARTICIPANT	\N	PRESENT	0
812997	812930	14255U	PARTICIPANT	\N	PRESENT	0
812999	812930	20040T	PARTICIPANT	\N	PRESENT	0
813000	812930	21086N	PARTICIPANT	\N	PRESENT	0
813001	812930	14147R	PARTICIPANT	\N	PRESENT	0
813002	812930	19713W	PARTICIPANT	\N	PRESENT	0
813003	812930	20252E	PARTICIPANT	\N	PRESENT	0
813004	812930	21060C	PARTICIPANT	\N	PRESENT	0
813005	812930	19709B	PARTICIPANT	\N	PRESENT	0
813006	812930	04033B	PARTICIPANT	\N	PRESENT	0
813007	812930	20038A	PARTICIPANT	\N	PRESENT	0
813008	812930	21064G	PARTICIPANT	\N	PRESENT	0
813009	812930	14021P	PARTICIPANT	\N	PRESENT	0
813010	812930	18207D	PARTICIPANT	\N	PRESENT	0
813012	812930	20110Q	PARTICIPANT	\N	PRESENT	0
813013	812930	19695N	PARTICIPANT	\N	PRESENT	0
813014	812930	21066J	PARTICIPANT	\N	PRESENT	0
813015	812930	21039F	PARTICIPANT	\N	PRESENT	0
813016	812930	19711U	PARTICIPANT	\N	PRESENT	0
813017	812930	19687N	PARTICIPANT	\N	PRESENT	0
813018	812930	21071F	PARTICIPANT	\N	PRESENT	0
813019	812930	20042V	PARTICIPANT	\N	PRESENT	0
813020	812930	17737W	PARTICIPANT	\N	PRESENT	0
813021	812930	19693L	PARTICIPANT	\N	PRESENT	0
813033	812930	20068G	PARTICIPANT	\N	PRESENT	0
813051	812930	17965H	PARTICIPANT	\N	PRESENT	0
813064	812930	14259Y	PARTICIPANT	\N	PRESENT	0
813068	812930	14071N	PARTICIPANT	\N	PRESENT	0
813072	812930	20048C	PARTICIPANT	\N	PRESENT	0
813073	812930	19347U	PARTICIPANT	\N	PRESENT	0
813074	812930	20266L	PARTICIPANT	\N	PRESENT	0
813075	812930	19399H	PARTICIPANT	\N	PRESENT	0
813076	812930	19301E	PARTICIPANT	\N	PRESENT	0
813079	812930	19111A	PARTICIPANT	\N	PRESENT	0
813083	812930	20124W	PARTICIPANT	\N	PRESENT	0
813084	812930	19611R	PARTICIPANT	\N	PRESENT	0
813085	812930	21030V	PARTICIPANT	\N	PRESENT	0
813086	812930	21095P	PARTICIPANT	\N	PRESENT	0
813087	812930	19621T	PARTICIPANT	\N	PRESENT	0
813088	812930	21058J	PARTICIPANT	\N	PRESENT	0
813089	812930	04042C	PARTICIPANT	\N	PRESENT	0
813090	812930	11085T	PARTICIPANT	\N	PRESENT	0
813091	812930	20132W	PARTICIPANT	\N	PRESENT	0
813098	812930	19719D	PARTICIPANT	\N	PRESENT	0
813143	813092	19575F	PARTICIPANT	\N	EXCUSE	0
813144	813107	19575F	PARTICIPANT	\N	EXCUSE	0
813145	812930	21090J	PARTICIPANT	\N	PRESENT	0
813147	813146	14193X	PARTICIPANT	\N	PRESENT	0
813148	813146	14097Y	PARTICIPANT	\N	PRESENT	0
813156	812930	19667J	PARTICIPANT	\N	PRESENT	0
813159	812930	14083S	PARTICIPANT	\N	PRESENT	0
813263	813261	20024T	PARTICIPANT	\N	PRESENT	0
813277	813276	19573D	PARTICIPANT	\N	PRESENT	0
813279	813278	19573D	PARTICIPANT	\N	PRESENT	0
813382	810521	20180F	PARTICIPANT	\N	PRESENT	1
813383	810521	20038A	PARTICIPANT	\N	PRESENT	0
813384	810521	19749K	PARTICIPANT	\N	PRESENT	0
813385	810521	21089R	PARTICIPANT	\N	PRESENT	0
813386	810521	14030Q	PARTICIPANT	\N	PRESENT	0
813387	810521	21038E	PARTICIPANT	\N	PRESENT	0
813388	810521	21061D	PARTICIPANT	\N	PRESENT	0
813389	810521	21044C	PARTICIPANT	\N	PRESENT	1
813390	810521	14147R	PARTICIPANT	\N	PRESENT	1
813403	810521	14179A	PARTICIPANT	\N	PRESENT	1
813405	810521	14109K	PARTICIPANT	\N	PRESENT	1
813414	813189	21095P	PARTICIPANT	\N	PRESENT	0
813420	813203	19729F	PARTICIPANT	\N	EXCUSE	0
813421	813203	19585H	PARTICIPANT	\N	EXCUSE	0
813422	813203	14053L	PARTICIPANT	\N	PRESENT	0
813423	813203	21044C	PARTICIPANT	\N	PRESENT	0
813424	813203	19447X	PARTICIPANT	\N	PRESENT	0
813425	813203	04047H	PRESIDENT	0	PRESENT	0
813426	813203	14275Y	PARTICIPANT	\N	PRESENT	0
813427	813203	14231L	PARTICIPANT	\N	PRESENT	0
813428	813203	14111D	PARTICIPANT	\N	PRESENT	0
813429	813203	20074E	PARTICIPANT	\N	PRESENT	0
813430	813203	21076L	PARTICIPANT	\N	PRESENT	0
813431	813203	05008E	PARTICIPANT	\N	PRESENT	0
813432	813203	21043B	PARTICIPANT	\N	PRESENT	0
813433	813203	19489J	PARTICIPANT	\N	PRESENT	0
813434	813203	18231D	PARTICIPANT	\N	PRESENT	0
813435	813203	20110Q	PARTICIPANT	\N	PRESENT	0
813436	813203	14147R	PARTICIPANT	\N	PRESENT	0
813437	813203	19111A	PARTICIPANT	\N	PRESENT	0
813438	813203	14215L	PARTICIPANT	\N	PRESENT	0
813439	813203	08018U	PARTICIPANT	\N	PRESENT	0
813440	813203	21095P	PARTICIPANT	\N	PRESENT	0
813445	813203	10015M	PARTICIPANT	\N	PRESENT	0
813446	813203	14089Y	PARTICIPANT	\N	PRESENT	0
813447	813203	14151M	PARTICIPANT	\N	PRESENT	0
813448	813415	19593H	PARTICIPANT	\N	PRESENT	0
813449	813444	21036C	PARTICIPANT	\N	PRESENT	0
813450	813444	19565D	PARTICIPANT	\N	PRESENT	0
813451	813444	20072C	PARTICIPANT	\N	PRESENT	0
813452	813444	01058X	PARTICIPANT	\N	PRESENT	0
813453	813444	04042C	PARTICIPANT	\N	PRESENT	0
813454	813444	19669L	PARTICIPANT	\N	PRESENT	0
813455	813444	08056B	PARTICIPANT	\N	PRESENT	0
813456	813444	12028B	PARTICIPANT	\N	PRESENT	0
813457	813444	17737W	PARTICIPANT	\N	PRESENT	0
813458	813444	19421M	PARTICIPANT	\N	PRESENT	0
813459	813444	14193X	PRESIDENT	0	PRESENT	0
813460	813444	19347U	PARTICIPANT	\N	PRESENT	0
813461	813444	14179A	PARTICIPANT	\N	PRESENT	0
813462	813444	07033P	PARTICIPANT	\N	PRESENT	0
813463	813444	14249W	PARTICIPANT	\N	PRESENT	0
813464	813444	08047A	PARTICIPANT	\N	PRESENT	0
813465	813444	20128B	PARTICIPANT	\N	PRESENT	0
813466	813444	14037X	PARTICIPANT	\N	PRESENT	0
813467	813444	14059S	PARTICIPANT	\N	PRESENT	0
813468	813444	21073H	PARTICIPANT	\N	PRESENT	0
813469	813444	20042V	PARTICIPANT	\N	PRESENT	0
813470	813444	19721W	PARTICIPANT	\N	PRESENT	0
813471	813444	20064C	PARTICIPANT	\N	PRESENT	0
813472	813444	20252E	PARTICIPANT	\N	PRESENT	0
813473	813444	14267Y	PARTICIPANT	\N	PRESENT	0
813474	813444	99004R	PARTICIPANT	\N	PRESENT	0
813475	813444	19745F	PARTICIPANT	\N	PRESENT	0
813476	813444	14255U	PARTICIPANT	\N	PRESENT	0
813477	813444	14001X	PARTICIPANT	\N	EXCUSE	0
813478	813415	19553Y	PARTICIPANT	\N	PRESENT	0
813479	813415	14327T	PARTICIPANT	\N	PRESENT	0
813480	813415	20084G	PARTICIPANT	\N	PRESENT	0
813481	813415	19295A	PARTICIPANT	\N	PRESENT	0
813482	813415	20090E	PARTICIPANT	\N	PRESENT	0
813483	813415	19691J	PARTICIPANT	\N	PRESENT	0
813484	813415	14257W	PARTICIPANT	\N	PRESENT	0
813485	813415	14121F	PARTICIPANT	\N	PRESENT	0
813486	813415	19507S	PARTICIPANT	\N	PRESENT	0
813487	813415	14073Q	PARTICIPANT	\N	PRESENT	0
813488	813415	21096Q	PARTICIPANT	\N	PRESENT	0
813489	813415	99004R	PARTICIPANT	\N	PRESENT	0
813490	813415	20074E	PARTICIPANT	\N	PRESENT	0
813491	813415	14097Y	PARTICIPANT	\N	PRESENT	0
813492	813415	14195A	PARTICIPANT	\N	PRESENT	0
813493	813415	21084L	PARTICIPANT	\N	PRESENT	0
813494	813415	20098N	PARTICIPANT	\N	PRESENT	0
813495	813415	19545Y	PARTICIPANT	\N	PRESENT	0
813496	813415	21087P	PARTICIPANT	\N	PRESENT	0
813497	813415	19413M	PARTICIPANT	\N	PRESENT	0
813498	813415	21046E	PARTICIPANT	\N	PRESENT	0
813499	813415	14221J	PARTICIPANT	\N	PRESENT	0
813500	813415	20050V	PARTICIPANT	\N	PRESENT	0
813501	813415	20144B	PARTICIPANT	\N	PRESENT	0
813502	813415	07004J	PARTICIPANT	\N	PRESENT	0
801860	801387	19347U	PARTICIPANT	\N	PRESENT	0
801861	801387	20026V	PARTICIPANT	\N	PRESENT	0
801862	801387	21057H	PARTICIPANT	\N	PRESENT	0
801863	801387	14123H	PARTICIPANT	\N	PRESENT	0
801864	801387	19703U	PARTICIPANT	\N	PRESENT	0
801865	801857	14059S	PARTICIPANT	\N	PRESENT	0
801866	801857	21036C	PARTICIPANT	\N	PRESENT	0
801867	801857	14133K	PARTICIPANT	\N	PRESENT	0
801868	801857	20072C	PARTICIPANT	\N	PRESENT	0
801869	801857	21073H	PARTICIPANT	\N	PRESENT	0
801870	801857	21031W	PARTICIPANT	\N	PRESENT	0
801871	801857	20042V	PARTICIPANT	\N	PRESENT	0
801872	801857	04042C	PARTICIPANT	\N	PRESENT	0
801873	801857	19669L	PARTICIPANT	\N	PRESENT	0
801874	801857	08056B	PARTICIPANT	\N	PRESENT	0
801875	801857	12028B	PARTICIPANT	\N	PRESENT	0
801876	801857	20252E	PARTICIPANT	\N	PRESENT	0
801877	801857	19421M	PARTICIPANT	\N	PRESENT	0
801878	801857	21067K	PARTICIPANT	\N	PRESENT	0
801879	801857	98022P	PARTICIPANT	\N	PRESENT	0
801880	801857	19709B	PARTICIPANT	\N	PRESENT	0
801881	801857	14193X	PRESIDENT	0	PRESENT	0
801882	801857	07033P	PARTICIPANT	\N	PRESENT	0
801883	801857	99004R	PARTICIPANT	\N	PRESENT	0
801884	801857	19745F	PARTICIPANT	\N	PRESENT	0
801885	801857	17367Q	PARTICIPANT	\N	PRESENT	0
801886	801857	14249W	PARTICIPANT	\N	PRESENT	0
801887	801857	20128B	PARTICIPANT	\N	PRESENT	0
801888	801857	19531S	PARTICIPANT	\N	EXCUSE	0
801889	801857	11027H	PARTICIPANT	\N	EXCUSE	0
801890	801857	08047A	PARTICIPANT	\N	EXCUSE	0
801891	801387	14189C	PARTICIPANT	\N	PRESENT	0
801892	801387	21043B	PARTICIPANT	\N	PRESENT	0
801893	801857	19565D	PARTICIPANT	\N	PRESENT	0
801894	801857	20064C	PARTICIPANT	\N	PRESENT	0
801895	801857	17023S	PARTICIPANT	\N	PRESENT	0
801896	801387	11056N	PARTICIPANT	\N	PRESENT	0
801897	801856	21036C	PARTICIPANT	\N	PRESENT	0
801898	801856	20072C	PARTICIPANT	\N	PRESENT	0
801899	801856	21031W	PARTICIPANT	\N	PRESENT	0
801900	801856	19565D	PARTICIPANT	\N	PRESENT	0
801901	801856	04042C	PARTICIPANT	\N	PRESENT	0
801902	801856	19669L	PARTICIPANT	\N	PRESENT	0
801903	801856	08056B	PARTICIPANT	\N	PRESENT	0
801904	801856	12028B	PARTICIPANT	\N	PRESENT	0
801905	801856	19421M	PARTICIPANT	\N	PRESENT	0
801906	801856	21067K	PARTICIPANT	\N	PRESENT	0
801907	801856	19709B	PARTICIPANT	\N	PRESENT	0
801908	801856	14193X	PRESIDENT	0	PRESENT	0
801909	801856	07033P	PARTICIPANT	\N	PRESENT	0
801910	801856	17367Q	PARTICIPANT	\N	PRESENT	0
801911	801856	14249W	PARTICIPANT	\N	PRESENT	0
801912	801856	20128B	PARTICIPANT	\N	PRESENT	0
801913	801856	14059S	PARTICIPANT	\N	PRESENT	0
801914	801856	14133K	PARTICIPANT	\N	PRESENT	0
801915	801856	21073H	PARTICIPANT	\N	PRESENT	0
801916	801856	20042V	PARTICIPANT	\N	PRESENT	0
801917	801856	20064C	PARTICIPANT	\N	PRESENT	0
801918	801856	20252E	PARTICIPANT	\N	PRESENT	0
801919	801856	98022P	PARTICIPANT	\N	PRESENT	0
801920	801856	99004R	PARTICIPANT	\N	PRESENT	0
801921	801856	19745F	PARTICIPANT	\N	PRESENT	0
801922	801856	17023S	PARTICIPANT	\N	PRESENT	0
801923	801856	19531S	PARTICIPANT	\N	EXCUSE	0
801924	801856	11027H	PARTICIPANT	\N	EXCUSE	0
801925	801856	08047A	PARTICIPANT	\N	EXCUSE	0
801926	801387	19647E	PARTICIPANT	\N	PRESENT	0
801927	801387	19691J	PARTICIPANT	\N	PRESENT	0
801928	801857	14251Q	PARTICIPANT	\N	PRESENT	0
801929	801856	14097Y	PARTICIPANT	\N	PRESENT	0
801930	801856	14251Q	PARTICIPANT	\N	PRESENT	0
801931	801857	14097Y	PARTICIPANT	\N	PRESENT	0
801932	801387	21068L	PARTICIPANT	\N	PRESENT	0
801933	801387	11072N	PARTICIPANT	\N	PRESENT	0
801934	801387	14147R	PARTICIPANT	\N	PRESENT	0
801935	801387	08045X	PARTICIPANT	\N	PRESENT	0
801936	801387	14231L	PARTICIPANT	\N	PRESENT	0
801937	801857	19347U	PARTICIPANT	\N	PRESENT	0
801938	801856	19347U	PARTICIPANT	\N	PRESENT	0
801943	801387	20066E	PARTICIPANT	\N	PRESENT	0
801954	801387	14030Q	PARTICIPANT	\N	PRESENT	0
801958	801387	20096L	PARTICIPANT	\N	PRESENT	0
801959	801387	20054A	PARTICIPANT	\N	PRESENT	0
801960	801387	21055F	PARTICIPANT	\N	PRESENT	0
801967	801387	19768N	PARTICIPANT	\N	PRESENT	0
801969	801387	19575F	PARTICIPANT	\N	PRESENT	0
801972	801387	20110Q	PARTICIPANT	\N	PRESENT	0
801977	801857	08034U	PARTICIPANT	\N	PRESENT	0
801979	801387	20104S	PARTICIPANT	\N	PRESENT	0
801982	801387	19399H	PARTICIPANT	\N	PRESENT	0
801983	801387	14109K	PARTICIPANT	\N	PRESENT	0
801984	801387	20082E	PARTICIPANT	\N	PRESENT	0
801985	801387	14133K	PARTICIPANT	\N	PRESENT	0
801986	801387	21073H	PARTICIPANT	\N	PRESENT	0
801987	801387	20100N	PARTICIPANT	\N	PRESENT	0
801988	801387	21029D	PARTICIPANT	\N	PRESENT	0
801989	801387	20140W	PARTICIPANT	\N	PRESENT	0
801990	801387	21046E	PARTICIPANT	\N	PRESENT	0
801991	801387	21070E	PARTICIPANT	\N	PRESENT	0
801992	801387	20028X	PARTICIPANT	\N	PRESENT	0
801993	801387	19713W	PARTICIPANT	\N	PRESENT	0
801995	801387	19565D	PARTICIPANT	\N	PRESENT	0
801996	801387	19758L	PARTICIPANT	\N	PRESENT	0
801997	801387	19479G	PARTICIPANT	\N	PRESENT	0
801998	801387	08061X	PARTICIPANT	\N	PRESENT	0
801999	801387	19679N	PARTICIPANT	\N	PRESENT	0
802000	801387	17023S	PARTICIPANT	\N	PRESENT	0
802001	801387	14205J	PARTICIPANT	\N	PRESENT	0
802002	801387	20022R	PARTICIPANT	\N	PRESENT	0
802003	801387	20124W	PARTICIPANT	\N	PRESENT	0
802005	801387	19723Y	PARTICIPANT	\N	PRESENT	0
802057	802046	20092G	PARTICIPANT	\N	PRESENT	0
802058	801388	21075K	PARTICIPANT	\N	PRESENT	0
802059	801388	19565D	PARTICIPANT	\N	PRESENT	0
802060	801388	20082E	PARTICIPANT	\N	PRESENT	0
802061	801388	21089R	PARTICIPANT	\N	PRESENT	0
802062	801388	21052C	PARTICIPANT	\N	PRESENT	0
802063	801388	19347U	PARTICIPANT	\N	PRESENT	0
802064	801388	19631V	PARTICIPANT	\N	PRESENT	0
802065	801388	19629C	PARTICIPANT	\N	PRESENT	0
802066	801388	20110Q	PARTICIPANT	\N	PRESENT	0
802067	801388	21092L	PARTICIPANT	\N	PRESENT	0
802068	801388	20072C	PARTICIPANT	\N	PRESENT	0
802069	801388	21078N	PARTICIPANT	\N	PRESENT	0
802070	801388	18207D	PARTICIPANT	\N	PRESENT	0
802071	801388	21083K	PARTICIPANT	\N	PRESENT	0
802072	801388	14205J	PARTICIPANT	\N	PRESENT	0
802073	801388	14089Y	PARTICIPANT	\N	PRESENT	0
802074	801388	20038A	PARTICIPANT	\N	PRESENT	0
802075	801388	20034V	PARTICIPANT	\N	PRESENT	0
802076	801388	19768N	PARTICIPANT	\N	PRESENT	0
802077	801388	14069U	PARTICIPANT	\N	PRESENT	0
802078	801388	20286Q	PARTICIPANT	\N	PRESENT	0
802079	801388	14187A	PARTICIPANT	\N	PRESENT	0
802080	801388	11072N	PARTICIPANT	\N	PRESENT	0
802081	801388	19782L	PARTICIPANT	\N	PRESENT	0
802082	801388	21033Y	PARTICIPANT	\N	PRESENT	0
802083	801388	19575F	PARTICIPANT	\N	PRESENT	0
802084	801388	18231D	PARTICIPANT	\N	PRESENT	0
802085	801388	20066E	PARTICIPANT	\N	PRESENT	0
802086	801388	14030Q	PARTICIPANT	\N	PRESENT	0
802087	801388	21058J	PARTICIPANT	\N	PRESENT	0
802088	801388	20116W	PARTICIPANT	\N	PRESENT	0
802089	801388	20134Y	PARTICIPANT	\N	PRESENT	0
802090	801388	21050A	PARTICIPANT	\N	PRESENT	0
802091	801388	21044C	PARTICIPANT	\N	PRESENT	0
802092	801388	14231L	PARTICIPANT	\N	PRESENT	0
802093	801388	14033T	PARTICIPANT	\N	PRESENT	0
802094	801388	20106U	PARTICIPANT	\N	PRESENT	0
802095	801388	20048C	PARTICIPANT	\N	PRESENT	0
802045	801388	11090Q	PARTICIPANT	\N	PRESENT	0
802047	802046	14205J	PARTICIPANT	\N	PRESENT	0
802048	802046	19768N	PARTICIPANT	\N	PRESENT	0
802049	802046	21075K	PARTICIPANT	\N	PRESENT	0
802050	802046	14187A	PRESIDENT	0	PRESENT	0
802051	802046	19575F	PARTICIPANT	\N	PRESENT	0
802052	802046	20286Q	PARTICIPANT	\N	PRESENT	0
802053	802046	20082E	PARTICIPANT	\N	PRESENT	0
802054	802046	21092L	PARTICIPANT	\N	PRESENT	0
802055	802046	11090Q	PARTICIPANT	\N	PRESENT	0
802056	802046	19631V	PARTICIPANT	\N	PRESENT	0
804793	804010	08018U	PARTICIPANT	\N	PRESENT	0
804794	804010	19725B	PARTICIPANT	\N	PRESENT	0
804795	804010	21044C	PARTICIPANT	\N	PRESENT	0
804797	804010	14215L	PARTICIPANT	\N	PRESENT	0
804798	804010	19673G	PARTICIPANT	\N	PRESENT	0
804799	804010	20074E	PARTICIPANT	\N	PRESENT	0
804801	804010	20022R	PARTICIPANT	\N	PRESENT	0
804802	804010	20036X	PARTICIPANT	\N	PRESENT	0
804806	804010	18231D	PARTICIPANT	\N	PRESENT	0
804808	804010	20108W	PARTICIPANT	\N	PRESENT	0
804810	804010	19749K	PARTICIPANT	\N	PRESENT	0
804812	804010	20098N	PARTICIPANT	\N	PRESENT	0
804815	804010	14147R	PARTICIPANT	\N	PRESENT	0
805376	805374	20286Q	PARTICIPANT	\N	PRESENT	0
805377	805374	20074E	PARTICIPANT	\N	PRESENT	0
805378	805374	21092L	PARTICIPANT	\N	PRESENT	0
805379	805374	21075K	PARTICIPANT	\N	PRESENT	0
805381	805380	20286Q	PARTICIPANT	\N	PRESENT	0
805382	805380	19631V	PARTICIPANT	\N	PRESENT	0
805480	805275	21055F	PARTICIPANT	\N	PRESENT	0
805533	803927	19591F	PARTICIPANT	\N	EXCUSE	0
805534	803927	20130U	PARTICIPANT	\N	EXCUSE	0
805535	803927	21064G	PARTICIPANT	\N	EXCUSE	0
805536	803928	17965H	PARTICIPANT	\N	PRESENT	0
805537	803928	21094N	PARTICIPANT	\N	PRESENT	0
805538	803928	11045K	PARTICIPANT	\N	PRESENT	0
805539	803928	19758L	PARTICIPANT	\N	PRESENT	0
805540	803928	21046E	PARTICIPANT	\N	PRESENT	0
805541	803928	14195A	PARTICIPANT	\N	PRESENT	0
805542	803928	20140W	PARTICIPANT	\N	PRESENT	0
805543	803928	19591F	PARTICIPANT	\N	EXCUSE	0
805544	803928	19691J	PARTICIPANT	\N	PRESENT	0
805545	803928	20130U	PARTICIPANT	\N	EXCUSE	0
805546	803928	21064G	PARTICIPANT	\N	EXCUSE	0
805547	803928	19367Y	PARTICIPANT	\N	PRESENT	0
805548	803928	21039F	PARTICIPANT	\N	PRESENT	0
805549	803928	19866P	PARTICIPANT	\N	PRESENT	0
805550	803928	20148F	PARTICIPANT	\N	PRESENT	0
805551	803928	19798U	PARTICIPANT	\N	PRESENT	0
805552	803928	21071F	PARTICIPANT	\N	PRESENT	0
805553	803928	14223L	PARTICIPANT	\N	PRESENT	0
805554	803928	19295A	PARTICIPANT	\N	PRESENT	0
805555	803928	04092N	PARTICIPANT	\N	PRESENT	0
805556	803928	21081H	PARTICIPANT	\N	PRESENT	0
805557	803928	14071N	PRESIDENT	\N	PRESENT	0
805558	803928	08061X	PARTICIPANT	\N	PRESENT	0
805559	803928	21097R	PARTICIPANT	\N	PRESENT	0
805560	803928	19553Y	PARTICIPANT	\N	PRESENT	0
805561	803928	14213J	PARTICIPANT	\N	PRESENT	0
805562	803928	17779H	PARTICIPANT	\N	PRESENT	0
805563	803928	20248J	PARTICIPANT	\N	PRESENT	0
805564	803928	14281W	PARTICIPANT	\N	PRESENT	0
805565	803928	08045X	PARTICIPANT	\N	PRESENT	0
805566	803928	14026U	PARTICIPANT	\N	PRESENT	0
805567	803928	14217N	PARTICIPANT	\N	PRESENT	0
805568	803928	19683J	PARTICIPANT	\N	PRESENT	0
805569	803928	20090E	PARTICIPANT	\N	PRESENT	0
805570	803928	19657G	PARTICIPANT	\N	PRESENT	0
805571	803928	20096L	PARTICIPANT	\N	PRESENT	0
805572	803928	19760E	PARTICIPANT	\N	PRESENT	0
805573	803928	19679N	PARTICIPANT	\N	PRESENT	0
805574	803928	19723Y	PARTICIPANT	\N	PRESENT	0
805575	803928	19629C	PARTICIPANT	\N	PRESENT	0
805576	803928	14042U	PARTICIPANT	\N	PRESENT	0
805577	803928	18193Q	PARTICIPANT	\N	PRESENT	0
805578	803928	21087P	PARTICIPANT	\N	PRESENT	0
805579	803928	21049H	PARTICIPANT	\N	PRESENT	0
805580	803928	19703U	PARTICIPANT	\N	PRESENT	0
805581	803928	19713W	PARTICIPANT	\N	PRESENT	0
805582	803928	19301E	PARTICIPANT	\N	PRESENT	0
805583	803928	21045D	PARTICIPANT	\N	PRESENT	0
805585	805584	20286Q	PARTICIPANT	\N	PRESENT	0
805627	805584	21092L	PARTICIPANT	\N	PRESENT	0
805628	805584	21075K	PARTICIPANT	\N	PRESENT	0
805629	805584	19507S	PARTICIPANT	\N	PRESENT	0
805631	805630	20286Q	PARTICIPANT	\N	PRESENT	0
805632	805630	19631V	PARTICIPANT	\N	PRESENT	0
805633	805630	21075K	PARTICIPANT	\N	PRESENT	0
805634	805630	20074E	PARTICIPANT	\N	PRESENT	0
805636	805635	20286Q	PARTICIPANT	\N	PRESENT	0
805703	803998	19683J	PARTICIPANT	\N	PRESENT	0
805638	805635	21075K	PARTICIPANT	\N	PRESENT	0
805639	805584	20074E	PARTICIPANT	\N	PRESENT	0
805640	805635	19631V	PARTICIPANT	\N	PRESENT	0
805702	803998	14331P	PRESIDENT	0	PRESENT	0
805704	803998	14026U	PARTICIPANT	\N	PRESENT	0
805705	803998	20150Y	PARTICIPANT	\N	PRESENT	0
805706	803998	17737W	PARTICIPANT	\N	PRESENT	0
805707	803998	14033T	PARTICIPANT	\N	PRESENT	0
805708	803998	19701S	PARTICIPANT	\N	EXCUSE	0
805709	803998	20098N	PARTICIPANT	\N	EXCUSE	0
805724	803998	19711U	PARTICIPANT	\N	PRESENT	0
805727	803998	14237S	PARTICIPANT	\N	PRESENT	0
805996	804142	14030Q	PARTICIPANT	\N	EXCUSE	0
805997	804142	14189C	PARTICIPANT	\N	EXCUSE	0
806001	806000	11040E	PARTICIPANT	\N	PRESENT	0
806002	806000	21041Y	PARTICIPANT	\N	PRESENT	0
806003	806000	14249W	PARTICIPANT	\N	PRESENT	0
806004	806000	07004J	PARTICIPANT	\N	PRESENT	0
806005	806000	08034U	PARTICIPANT	\N	PRESENT	0
806006	806000	04070G	PARTICIPANT	\N	PRESENT	0
806007	806000	19745F	PARTICIPANT	\N	PRESENT	0
806008	806000	14225N	PARTICIPANT	\N	PRESENT	0
806009	806000	10015M	PARTICIPANT	\N	PRESENT	0
806010	806000	19669L	PARTICIPANT	\N	PRESENT	0
806011	806000	14097Y	PARTICIPANT	\N	PRESENT	0
806012	806000	14229S	PARTICIPANT	\N	PRESENT	0
806338	806337	14033T	PARTICIPANT	\N	PRESENT	0
806339	806337	20068G	PARTICIPANT	\N	PRESENT	0
806341	806337	18083K	PARTICIPANT	\N	PRESENT	0
806342	806337	14257W	PRESIDENT	0	PRESENT	0
806344	806337	11070L	PARTICIPANT	\N	PRESENT	0
806345	806337	14031R	PARTICIPANT	\N	PRESENT	0
806356	806337	20042V	PARTICIPANT	\N	EXCUSE	0
806359	806337	19575F	PARTICIPANT	\N	PRESENT	0
806375	806337	20018V	PARTICIPANT	\N	PRESENT	0
806376	806337	20092G	PARTICIPANT	\N	PRESENT	0
806384	806337	19619A	PARTICIPANT	\N	PRESENT	0
806466	803919	20024T	PARTICIPANT	\N	PRESENT	0
806468	803919	21071F	PARTICIPANT	\N	PRESENT	0
806469	803919	14133K	PARTICIPANT	\N	PRESENT	0
806470	803919	20032T	PARTICIPANT	\N	PRESENT	0
806471	803919	20076G	PARTICIPANT	\N	PRESENT	0
806472	803919	05008E	PARTICIPANT	\N	PRESENT	0
806473	803919	19667J	PARTICIPANT	\N	PRESENT	0
806474	803919	19954N	PARTICIPANT	\N	PRESENT	0
806475	803919	19575F	PARTICIPANT	\N	PRESENT	0
806476	803919	17367Q	PARTICIPANT	\N	PRESENT	0
806478	803919	19367Y	PARTICIPANT	\N	PRESENT	0
806480	803919	17737W	PARTICIPANT	\N	PRESENT	0
806481	803919	19621T	PARTICIPANT	\N	PRESENT	0
806482	803919	21063F	PARTICIPANT	\N	PRESENT	0
806483	803919	20104S	PARTICIPANT	\N	PRESENT	0
806484	803919	04042C	PARTICIPANT	\N	PRESENT	0
806485	803919	20060X	PARTICIPANT	\N	PRESENT	0
806486	803919	14329V	PARTICIPANT	\N	PRESENT	0
806487	803919	14038Y	PARTICIPANT	\N	PRESENT	0
806488	803919	18083K	PARTICIPANT	\N	PRESENT	0
806489	803919	19701S	PARTICIPANT	\N	PRESENT	0
806490	803919	21072G	PARTICIPANT	\N	PRESENT	0
806491	803919	14259Y	PARTICIPANT	\N	PRESENT	0
806492	803919	20124W	PARTICIPANT	\N	PRESENT	0
806493	803919	07033P	PARTICIPANT	\N	PRESENT	0
806494	803919	11110B	PARTICIPANT	\N	PRESENT	0
806495	803919	19673G	PARTICIPANT	\N	PRESENT	0
806496	803919	19647E	PARTICIPANT	\N	PRESENT	0
806497	803919	14281W	PARTICIPANT	\N	PRESENT	0
806498	803919	08045X	PARTICIPANT	\N	PRESENT	0
806499	803919	19820Y	PARTICIPANT	\N	PRESENT	0
806500	803919	08069G	PARTICIPANT	\N	PRESENT	0
806501	803919	20034V	PARTICIPANT	\N	PRESENT	0
806502	803919	95041E	PARTICIPANT	\N	PRESENT	0
806503	803919	99004R	PARTICIPANT	\N	PRESENT	0
806504	803919	21081H	PARTICIPANT	\N	PRESENT	0
806505	803919	20126Y	PARTICIPANT	\N	PRESENT	0
806506	803919	07029T	PARTICIPANT	\N	PRESENT	0
806507	803919	19723Y	PARTICIPANT	\N	PRESENT	0
806509	803919	08015R	PARTICIPANT	\N	PRESENT	0
806510	803919	19711U	PARTICIPANT	\N	PRESENT	0
806511	803919	08034U	PARTICIPANT	\N	PRESENT	0
806512	803919	19657G	PARTICIPANT	\N	PRESENT	0
806513	803919	14147R	PARTICIPANT	\N	PRESENT	0
797563	797562	99004R	PARTICIPANT	\N	PRESENT	0
797564	797562	14189C	PARTICIPANT	\N	PRESENT	0
797565	797562	20024T	PARTICIPANT	\N	PRESENT	0
797566	797562	19367Y	PARTICIPANT	\N	PRESENT	0
797567	797562	20138D	PARTICIPANT	\N	PRESENT	0
797568	797562	17367Q	PARTICIPANT	\N	PRESENT	0
797569	797562	17737W	PARTICIPANT	\N	PRESENT	0
797570	797562	19621T	PARTICIPANT	\N	PRESENT	0
797571	797562	20090E	PARTICIPANT	\N	PRESENT	0
797572	797562	19649G	PARTICIPANT	\N	PRESENT	0
797573	797562	21083K	PARTICIPANT	\N	PRESENT	0
797574	797562	14215L	PARTICIPANT	\N	PRESENT	0
797575	797562	19673G	PARTICIPANT	\N	PRESENT	0
797576	797562	19111A	PARTICIPANT	\N	PRESENT	0
797577	797562	20056C	PARTICIPANT	\N	PRESENT	0
797578	797562	14021P	PARTICIPANT	\N	PRESENT	0
797579	797562	19723Y	PARTICIPANT	\N	PRESENT	0
797580	797562	20052X	PARTICIPANT	\N	PRESENT	0
797581	797562	14221J	PARTICIPANT	\N	PRESENT	0
797582	797562	04070G	PARTICIPANT	\N	PRESENT	0
797583	797562	14223L	PARTICIPANT	\N	PRESENT	0
797584	797562	10015M	PARTICIPANT	\N	PRESENT	0
797585	797562	21059K	PARTICIPANT	\N	PRESENT	0
797586	797562	11045K	PARTICIPANT	\N	PRESENT	0
797587	797562	20122U	PARTICIPANT	\N	PRESENT	0
797689	797688	11070L	PARTICIPANT	\N	PRESENT	0
797690	797688	14033T	PARTICIPANT	\N	PRESENT	0
797691	797688	14257W	PRESIDENT	0	PRESENT	0
797692	797688	14207L	PARTICIPANT	\N	PRESENT	0
797693	797688	19619A	PARTICIPANT	\N	PRESENT	0
797694	797688	12016W	PARTICIPANT	\N	PRESENT	0
797695	797688	20092G	PARTICIPANT	\N	PRESENT	0
797696	797688	14237S	PARTICIPANT	\N	EXCUSE	0
797697	797688	19533U	PARTICIPANT	\N	PRESENT	0
797698	797688	20042V	PARTICIPANT	\N	EXCUSE	0
797850	797849	12028B	PARTICIPANT	\N	PRESENT	0
797851	797849	14267Y	PARTICIPANT	\N	PRESENT	0
797852	797849	08010L	PARTICIPANT	\N	PRESENT	0
797853	797700	14255U	PARTICIPANT	\N	EXCUSE	0
797854	797700	17737W	PARTICIPANT	\N	EXCUSE	0
797855	797699	17737W	PARTICIPANT	\N	EXCUSE	0
802503	800773	19729F	PARTICIPANT	\N	EXCUSE	0
802504	800773	19585H	PARTICIPANT	\N	EXCUSE	0
812721	810311	14001X	PARTICIPANT	\N	PRESENT	0
812713	810311	19301E	PARTICIPANT	\N	PRESENT	0
812720	810311	19573D	PARTICIPANT	\N	PRESENT	0
812722	810311	19413M	PARTICIPANT	\N	PRESENT	0
812723	810311	20264J	PARTICIPANT	\N	PRESENT	0
812724	810311	19711U	PARTICIPANT	\N	PRESENT	0
812725	810311	11056N	PARTICIPANT	\N	PRESENT	0
812726	810311	11040E	PARTICIPANT	\N	PRESENT	0
812727	810311	21049H	PARTICIPANT	\N	PRESENT	0
812728	810311	20090E	PARTICIPANT	\N	PRESENT	0
812729	810311	21088Q	PARTICIPANT	\N	PRESENT	0
812730	810311	20172F	PARTICIPANT	\N	PRESENT	0
812731	810311	19681G	PARTICIPANT	\N	PRESENT	0
812732	810311	14249W	PARTICIPANT	\N	PRESENT	0
812733	810311	14033T	PARTICIPANT	\N	PRESENT	0
812734	810311	20100N	PARTICIPANT	\N	PRESENT	0
812735	810311	20082E	PARTICIPANT	\N	PRESENT	0
812736	810311	20036X	PARTICIPANT	\N	PRESENT	0
812737	810311	21043B	PARTICIPANT	\N	PRESENT	0
812738	810311	14021P	PARTICIPANT	\N	PRESENT	0
812739	810311	14267Y	PARTICIPANT	\N	PRESENT	0
812740	810311	20040T	PARTICIPANT	\N	PRESENT	0
812741	810311	20252E	PARTICIPANT	\N	PRESENT	0
812742	810311	20064C	PARTICIPANT	\N	PRESENT	0
812743	810311	21090J	PARTICIPANT	\N	PRESENT	0
812744	810311	19347U	PARTICIPANT	\N	PRESENT	0
812745	810311	21037D	PARTICIPANT	\N	PRESENT	0
812746	810311	14195A	PARTICIPANT	\N	PRESENT	0
812747	810311	14221J	PARTICIPANT	\N	PRESENT	0
812748	810311	19545Y	PARTICIPANT	\N	PRESENT	0
812749	810311	21070E	PARTICIPANT	\N	PRESENT	0
812750	810311	14251Q	PARTICIPANT	\N	PRESENT	0
812751	810311	19758L	PARTICIPANT	\N	PRESENT	0
812752	810311	21054E	PARTICIPANT	\N	PRESENT	0
812753	810311	19687N	PARTICIPANT	\N	PRESENT	0
812754	810311	21076L	PARTICIPANT	\N	PRESENT	0
812755	810311	19629C	PARTICIPANT	\N	PRESENT	0
812756	810311	20072C	PARTICIPANT	\N	PRESENT	0
812757	810311	14037X	PARTICIPANT	\N	PRESENT	0
812758	810311	19695N	PARTICIPANT	\N	PRESENT	0
812759	810311	19649G	PARTICIPANT	\N	PRESENT	0
812760	810311	21030V	PARTICIPANT	\N	PRESENT	0
812761	810311	20102Q	PARTICIPANT	\N	PRESENT	0
812762	810311	20046A	PARTICIPANT	\N	PRESENT	0
812763	810311	19593H	PARTICIPANT	\N	PRESENT	0
812764	810311	19531S	PARTICIPANT	\N	PRESENT	0
812765	810311	19565D	PARTICIPANT	\N	PRESENT	0
812766	810311	17737W	PARTICIPANT	\N	PRESENT	0
812767	810311	14193X	PARTICIPANT	\N	PRESENT	0
812768	810311	14215L	PARTICIPANT	\N	PRESENT	0
812769	810311	14207L	PARTICIPANT	\N	PRESENT	0
812770	810311	20132W	PARTICIPANT	\N	PRESENT	0
812771	810311	21068L	PARTICIPANT	\N	PRESENT	0
812772	810311	19735D	PARTICIPANT	\N	PRESENT	0
812773	810311	19699S	PARTICIPANT	\N	PRESENT	0
812774	810311	14219Q	PARTICIPANT	\N	PRESENT	0
812775	810311	19569H	PARTICIPANT	\N	PRESENT	0
812776	810311	21079P	PARTICIPANT	\N	PRESENT	0
812777	810311	21055F	PARTICIPANT	\N	PRESENT	0
812778	810311	19479G	PARTICIPANT	\N	PRESENT	0
812779	810311	14205J	PARTICIPANT	\N	PRESENT	0
812780	810311	19563B	PARTICIPANT	\N	PRESENT	0
812781	810311	20052X	PARTICIPANT	\N	PRESENT	0
812782	810311	20068G	PARTICIPANT	\N	PRESENT	0
812783	810311	14189C	PARTICIPANT	\N	PRESENT	0
812784	810311	14255U	PARTICIPANT	\N	PRESENT	0
812785	810311	21058J	PARTICIPANT	\N	PRESENT	0
812786	810311	14133K	PARTICIPANT	\N	PRESENT	0
812787	810311	19507S	PARTICIPANT	\N	PRESENT	0
812789	810311	14055N	PARTICIPANT	\N	PRESENT	0
812790	810311	19713W	PARTICIPANT	\N	PRESENT	0
812791	810311	21042A	PARTICIPANT	\N	PRESENT	0
812792	810311	21086N	PARTICIPANT	\N	PRESENT	0
812793	810311	20062A	PARTICIPANT	\N	PRESENT	0
812794	810311	04033B	PARTICIPANT	\N	PRESENT	0
812795	810311	21095P	PARTICIPANT	\N	PRESENT	0
812796	810311	14357A	PARTICIPANT	\N	PRESENT	0
812797	810311	14059S	PARTICIPANT	\N	PRESENT	0
812798	810311	20028X	PARTICIPANT	\N	PRESENT	0
812799	810311	21061D	PARTICIPANT	\N	PRESENT	0
812801	810311	14187A	PARTICIPANT	\N	PRESENT	0
812802	810311	21063F	PARTICIPANT	\N	PRESENT	0
812803	810311	11048N	PARTICIPANT	\N	PRESENT	0
812804	810311	14259Y	PARTICIPANT	\N	PRESENT	0
812805	810311	20070A	PARTICIPANT	\N	PRESENT	0
812806	810311	04070G	PARTICIPANT	\N	PRESENT	0
812807	810311	20026V	PARTICIPANT	\N	PRESENT	0
812808	810311	19719D	PARTICIPANT	\N	PRESENT	0
812809	810311	18207D	PARTICIPANT	\N	PRESENT	0
812810	810311	20092G	PARTICIPANT	\N	PRESENT	0
812811	812800	21084L	PARTICIPANT	\N	PRESENT	0
812812	812800	21056G	PARTICIPANT	\N	PRESENT	0
812813	812800	20248J	PARTICIPANT	\N	PRESENT	0
812814	812800	21031W	PARTICIPANT	\N	PRESENT	0
812815	812800	14031R	PARTICIPANT	\N	PRESENT	0
812816	812800	21066J	PARTICIPANT	\N	PRESENT	0
812817	812800	99004R	PRESIDENT	0	PRESENT	0
812818	812800	11090Q	PARTICIPANT	\N	PRESENT	0
812819	812800	21093M	PARTICIPANT	\N	PRESENT	0
812820	812800	17023S	PARTICIPANT	\N	PRESENT	0
812821	810311	20134Y	PARTICIPANT	\N	PRESENT	0
812822	810311	20048C	PARTICIPANT	\N	PRESENT	0
812823	810311	20042V	PARTICIPANT	\N	PRESENT	0
812824	810311	19611R	PARTICIPANT	\N	PRESENT	0
812825	810311	21073H	PARTICIPANT	\N	PRESENT	0
812826	810311	19621T	PARTICIPANT	\N	PRESENT	0
812827	810311	04042C	PARTICIPANT	\N	PRESENT	0
812828	810311	14169X	PARTICIPANT	\N	PRESENT	0
812829	810311	21075K	PARTICIPANT	\N	PRESENT	0
812830	810311	19691J	PARTICIPANT	\N	PRESENT	0
812831	810311	19697Q	PARTICIPANT	\N	PRESENT	0
812832	810311	18231D	PARTICIPANT	\N	PRESENT	0
812833	810311	21094N	PARTICIPANT	\N	PRESENT	0
812835	810311	19399H	PARTICIPANT	\N	PRESENT	0
812836	810311	20124W	PARTICIPANT	\N	PRESENT	0
812837	810311	14030Q	PARTICIPANT	\N	PRESENT	0
812838	810311	19866P	PARTICIPANT	\N	PRESENT	0
812436	810421	19611R	PRESIDENT	0	PRESENT	0
812437	810421	21059K	PARTICIPANT	\N	PRESENT	0
812438	810421	21077M	PARTICIPANT	\N	PRESENT	0
812439	810421	18395Y	PARTICIPANT	\N	PRESENT	0
812440	810421	19533U	PARTICIPANT	\N	PRESENT	0
812441	810421	19593H	PARTICIPANT	\N	PRESENT	0
812442	810421	20132W	PARTICIPANT	\N	PRESENT	0
812443	810421	20142Y	PARTICIPANT	\N	PRESENT	0
812444	810421	21091K	PARTICIPANT	\N	PRESENT	0
812445	810421	08012N	PARTICIPANT	\N	PRESENT	0
812446	810421	20102Q	PARTICIPANT	\N	PRESENT	0
812447	810421	20056C	PARTICIPANT	\N	PRESENT	0
812452	810421	14229S	PARTICIPANT	\N	PRESENT	0
812449	810421	21058J	PARTICIPANT	\N	PRESENT	0
812450	810421	20026V	PARTICIPANT	\N	PRESENT	0
812451	810421	19697Q	PARTICIPANT	\N	PRESENT	0
812464	810421	20172F	PARTICIPANT	\N	PRESENT	0
812472	810421	19621T	PARTICIPANT	\N	PRESENT	0
812473	810421	21089R	PARTICIPANT	\N	PRESENT	0
812494	810421	21037D	PARTICIPANT	\N	PRESENT	0
813503	813415	20110Q	PARTICIPANT	\N	PRESENT	0
813504	813415	21071F	PARTICIPANT	\N	PRESENT	0
813505	813415	19703U	PARTICIPANT	\N	PRESENT	0
813506	813415	11043H	PARTICIPANT	\N	PRESENT	0
813507	813415	08028W	PARTICIPANT	\N	PRESENT	0
813508	813415	21125C	PARTICIPANT	\N	PRESENT	0
813509	813415	20044X	PARTICIPANT	\N	PRESENT	0
813510	813415	21055F	PARTICIPANT	\N	PRESENT	0
813511	813415	19447X	PARTICIPANT	\N	PRESENT	0
813512	813415	19695N	PARTICIPANT	\N	PRESENT	0
813557	813415	20062A	PARTICIPANT	\N	PRESENT	0
813554	813415	04042C	PARTICIPANT	\N	PRESENT	0
813560	813415	19954N	PARTICIPANT	\N	PRESENT	0
813516	813415	08061X	PARTICIPANT	\N	PRESENT	0
813517	813415	18083K	PARTICIPANT	\N	PRESENT	0
813518	813415	21043B	PARTICIPANT	\N	PRESENT	0
813519	813415	19711U	PARTICIPANT	\N	PRESENT	0
813520	813415	20106U	PARTICIPANT	\N	PRESENT	0
813521	813415	08011M	PARTICIPANT	\N	PRESENT	0
813522	813415	20128B	PARTICIPANT	\N	PRESENT	0
813523	813415	19697Q	PARTICIPANT	\N	PRESENT	0
813524	813415	14037X	PARTICIPANT	\N	PRESENT	0
813525	813415	21091K	PARTICIPANT	\N	PRESENT	0
813526	813415	19301E	PARTICIPANT	\N	PRESENT	0
813527	813415	11072N	PARTICIPANT	\N	PRESENT	0
813528	813415	21044C	PARTICIPANT	\N	PRESENT	0
813529	813415	21080G	PARTICIPANT	\N	PRESENT	0
813530	813415	14259Y	PARTICIPANT	\N	PRESENT	0
813531	813415	14191V	PARTICIPANT	\N	PRESENT	0
813532	813415	14111D	PARTICIPANT	\N	PRESENT	0
813533	813415	21070E	PARTICIPANT	\N	PRESENT	0
813534	813415	20022R	PARTICIPANT	\N	PRESENT	0
813535	813415	14215L	PARTICIPANT	\N	PRESENT	0
813536	813415	14241N	PARTICIPANT	\N	PRESENT	0
813537	813415	20136B	PARTICIPANT	\N	PRESENT	0
813538	813415	20072C	PARTICIPANT	\N	PRESENT	0
813539	813415	14207L	PARTICIPANT	\N	PRESENT	0
813540	813415	19421M	PARTICIPANT	\N	PRESENT	0
813541	813415	19629C	PARTICIPANT	\N	PRESENT	0
813542	813415	21041Y	PARTICIPANT	\N	PRESENT	0
813543	813415	19667J	PARTICIPANT	\N	PRESENT	0
813544	813415	20132W	PARTICIPANT	\N	PRESENT	0
813545	813415	21058J	PARTICIPANT	\N	PRESENT	0
813546	813415	20180F	PARTICIPANT	\N	PRESENT	0
813547	813415	19866P	PARTICIPANT	\N	PRESENT	0
813548	813415	21081H	PARTICIPANT	\N	PRESENT	0
813549	813415	14107H	PARTICIPANT	\N	PRESENT	0
813550	813415	08047A	PARTICIPANT	\N	PRESENT	0
813551	813415	19383Y	PARTICIPANT	\N	PRESENT	0
813552	813415	17737W	PARTICIPANT	\N	PRESENT	0
813692	813415	14026U	PARTICIPANT	\N	PRESENT	0
813709	813415	19687N	PARTICIPANT	\N	PRESENT	0
813556	813415	19760E	PARTICIPANT	\N	PRESENT	0
813558	813415	21047F	PARTICIPANT	\N	PRESENT	0
813559	813415	21073H	PARTICIPANT	\N	PRESENT	0
813561	813415	11056N	PARTICIPANT	\N	PRESENT	0
813562	813415	08018U	PARTICIPANT	\N	PRESENT	0
813563	813415	07029T	PARTICIPANT	\N	PRESENT	0
813564	813415	19399H	PARTICIPANT	\N	PRESENT	0
813565	813415	08015R	PARTICIPANT	\N	PRESENT	0
813566	813415	20024T	PARTICIPANT	\N	PRESENT	0
813567	813415	14133K	PARTICIPANT	\N	PRESENT	0
813568	813415	21040X	PARTICIPANT	\N	PRESENT	0
813569	813415	14059S	PARTICIPANT	\N	PRESENT	0
813570	813415	08056B	PARTICIPANT	\N	PRESENT	0
813571	813415	20114U	PARTICIPANT	\N	PRESENT	0
813572	813415	20126Y	PARTICIPANT	\N	PRESENT	0
813573	813415	20080C	PARTICIPANT	\N	PRESENT	0
813574	813415	20054A	PARTICIPANT	\N	PRESENT	0
813575	813415	20020P	PARTICIPANT	\N	PRESENT	0
813576	813415	21045D	PARTICIPANT	\N	PRESENT	0
813577	813415	20060X	PARTICIPANT	\N	PRESENT	0
813578	813415	21095P	PARTICIPANT	\N	PRESENT	0
813579	813415	19347U	PARTICIPANT	\N	PRESENT	0
813691	813415	95041E	PARTICIPANT	\N	PRESENT	0
813693	813415	21077M	PARTICIPANT	\N	PRESENT	0
813694	813415	19251M	PARTICIPANT	\N	PRESENT	0
813695	813415	20056C	PARTICIPANT	\N	PRESENT	0
813696	813415	21036C	PARTICIPANT	\N	PRESENT	0
813697	813415	04047H	PARTICIPANT	\N	PRESENT	0
813698	813415	21029D	PARTICIPANT	\N	PRESENT	0
813699	813415	19705W	PARTICIPANT	\N	PRESENT	0
813700	813415	21085M	PARTICIPANT	\N	PRESENT	0
813701	813415	21063F	PARTICIPANT	\N	PRESENT	0
813702	813415	19649G	PARTICIPANT	\N	PRESENT	0
813703	813415	21054E	PARTICIPANT	\N	PRESENT	0
813704	813415	21038E	PARTICIPANT	\N	PRESENT	0
813705	813415	20066E	PARTICIPANT	\N	PRESENT	0
813706	813415	19367Y	PARTICIPANT	\N	PRESENT	0
813707	813415	20116W	PARTICIPANT	\N	PRESENT	0
813708	813415	05008E	PARTICIPANT	\N	PRESENT	0
813714	813415	20124W	PARTICIPANT	\N	PRESENT	0
813711	813415	20146D	PARTICIPANT	\N	PRESENT	0
813717	813415	19335Q	PARTICIPANT	\N	PRESENT	0
813713	813415	07033P	PARTICIPANT	\N	PRESENT	0
813715	813415	19111A	PARTICIPANT	\N	PRESENT	0
813716	813415	14249W	PARTICIPANT	\N	PRESENT	0
813718	813415	21059K	PARTICIPANT	\N	PRESENT	0
813719	813415	20120S	PARTICIPANT	\N	PRESENT	0
813720	813415	14042U	PARTICIPANT	\N	PRESENT	0
813721	813415	05012A	PARTICIPANT	\N	PRESENT	0
813722	813415	11040E	PARTICIPANT	\N	PRESENT	0
813723	813415	14089Y	PARTICIPANT	\N	PRESENT	0
813727	813415	19533U	PARTICIPANT	\N	PRESENT	0
813725	813415	04092N	PARTICIPANT	\N	PRESENT	0
813729	813415	20122U	PARTICIPANT	\N	PRESENT	0
813728	813415	19331L	PARTICIPANT	\N	PRESENT	0
813730	813415	19565D	PARTICIPANT	\N	PRESENT	0
813731	813415	14083S	PARTICIPANT	\N	PRESENT	0
813732	813415	20086J	PARTICIPANT	\N	PRESENT	0
813734	813415	21060C	PARTICIPANT	\N	PRESENT	0
813736	813415	19057M	PARTICIPANT	\N	PRESENT	0
813737	813415	14211G	PARTICIPANT	\N	PRESENT	0
813738	813415	19749K	PARTICIPANT	\N	PRESENT	0
813739	813415	17023S	PARTICIPANT	\N	PRESENT	0
813740	813415	14251Q	PARTICIPANT	\N	PRESENT	0
813741	813415	21074J	PARTICIPANT	\N	PRESENT	0
813750	813415	19679N	PARTICIPANT	\N	PRESENT	0
813743	813415	14033T	PARTICIPANT	\N	PRESENT	0
813749	813415	20140W	PARTICIPANT	\N	PRESENT	0
813752	813415	19758L	PARTICIPANT	\N	PRESENT	0
813746	813415	19479G	PARTICIPANT	\N	PRESENT	0
813747	813415	11110B	PARTICIPANT	\N	PRESENT	0
813748	813415	14329V	PARTICIPANT	\N	PRESENT	0
813751	813415	21088Q	PARTICIPANT	\N	PRESENT	0
813753	813415	19591F	PARTICIPANT	\N	PRESENT	0
813754	813415	17367Q	PARTICIPANT	\N	PRESENT	0
813758	813415	14123H	PARTICIPANT	\N	PRESENT	0
813756	813415	20104S	PARTICIPANT	\N	PRESENT	0
813760	813415	14219Q	PARTICIPANT	\N	PRESENT	0
813759	813415	14151M	PARTICIPANT	\N	PRESENT	0
813761	813415	20076G	PARTICIPANT	\N	PRESENT	0
813762	813415	21066J	PARTICIPANT	\N	PRESENT	0
813763	813415	21030V	PARTICIPANT	\N	PRESENT	0
813918	813243	19335Q	PARTICIPANT	\N	PRESENT	0
814024	814023	14107H	PARTICIPANT	\N	PRESENT	0
814047	814044	21090J	PRESIDENT	0	PRESENT	0
814048	814044	19591F	PARTICIPANT	\N	PRESENT	0
814049	814044	18193Q	PARTICIPANT	\N	PRESENT	0
814054	814044	10015M	PARTICIPANT	\N	PRESENT	0
814055	814044	20028X	PARTICIPANT	\N	EXCUSE	0
802096	801388	20090E	PARTICIPANT	\N	PRESENT	0
802097	801388	14215L	PARTICIPANT	\N	PRESENT	0
802098	801388	14026U	PARTICIPANT	\N	PRESENT	0
802099	801388	19679N	PARTICIPANT	\N	PRESENT	0
802100	801388	19695N	PARTICIPANT	\N	PRESENT	0
802101	801388	21082J	PARTICIPANT	\N	PRESENT	0
802102	801388	14147R	PARTICIPANT	\N	PRESENT	0
802103	801388	14083S	PARTICIPANT	\N	PRESENT	0
802104	801388	19647E	PARTICIPANT	\N	PRESENT	0
802105	801388	19383Y	PARTICIPANT	\N	PRESENT	0
802106	801388	21086N	PARTICIPANT	\N	PRESENT	0
802107	801388	20052X	PARTICIPANT	\N	PRESENT	0
802108	801388	20092G	PARTICIPANT	\N	PRESENT	0
802109	801388	14037X	PARTICIPANT	\N	PRESENT	0
805668	801407	18083K	PARTICIPANT	\N	PRESENT	0
805669	801407	20100N	PARTICIPANT	\N	PRESENT	0
805670	801407	21084L	PARTICIPANT	\N	PRESENT	0
805671	801407	05012A	PARTICIPANT	\N	PRESENT	0
805672	801407	20106U	PARTICIPANT	\N	PRESENT	0
805728	803919	20248J	PARTICIPANT	\N	PRESENT	0
805674	801407	14107H	PARTICIPANT	\N	PRESENT	0
805675	801407	21080G	PARTICIPANT	\N	PRESENT	0
805676	801407	20136B	PARTICIPANT	\N	PRESENT	0
805677	801407	14031R	PARTICIPANT	\N	PRESENT	0
805700	803919	86034E	PARTICIPANT	\N	PRESENT	0
805679	801407	19251M	PARTICIPANT	\N	EXCUSE	0
805710	805689	19531S	PARTICIPANT	\N	PRESENT	0
805681	801407	20146D	PARTICIPANT	\N	PRESENT	0
805682	801407	14169X	PARTICIPANT	\N	PRESENT	0
805711	805689	21045D	PARTICIPANT	\N	PRESENT	0
805684	801407	19619A	PARTICIPANT	\N	PRESENT	0
805685	801407	21035B	PARTICIPANT	\N	EXCUSE	0
805712	805689	17965H	PRESIDENT	0	PRESENT	0
805687	801407	19681G	PARTICIPANT	\N	EXCUSE	0
805688	801407	21062E	PARTICIPANT	\N	EXCUSE	0
805713	805689	18193Q	PARTICIPANT	\N	PRESENT	0
805714	805689	21064G	PARTICIPANT	\N	PRESENT	0
805715	805689	20096L	PARTICIPANT	\N	PRESENT	0
805716	805689	19723Y	PARTICIPANT	\N	PRESENT	0
805717	805689	20098N	PARTICIPANT	\N	PRESENT	0
805718	805689	21043B	PARTICIPANT	\N	PRESENT	0
805719	805689	19553Y	PARTICIPANT	\N	PRESENT	0
805720	805689	20066E	PRESIDENT	1	PRESENT	0
805721	805689	14147R	PARTICIPANT	\N	PRESENT	0
805722	805689	20024T	PARTICIPANT	\N	PRESENT	0
805723	805689	19758L	PARTICIPANT	\N	PRESENT	0
805729	803919	21052C	PARTICIPANT	\N	PRESENT	0
805730	803919	08056B	PARTICIPANT	\N	PRESENT	0
805731	803919	14215L	PARTICIPANT	\N	PRESENT	0
805732	803919	20068G	PARTICIPANT	\N	PRESENT	0
805733	803919	20022R	PARTICIPANT	\N	PRESENT	0
805734	803919	05012A	PARTICIPANT	\N	PRESENT	0
805735	803919	19507S	PARTICIPANT	\N	PRESENT	0
805736	803919	21053D	PARTICIPANT	\N	PRESENT	0
805737	803919	14275Y	PARTICIPANT	\N	PRESENT	0
805738	803919	18193Q	PARTICIPANT	\N	PRESENT	0
805739	803919	20074E	PARTICIPANT	\N	PRESENT	0
805740	804018	14053L	PARTICIPANT	\N	PRESENT	0
805741	804018	14111D	PARTICIPANT	\N	PRESENT	0
805742	804018	14189C	PARTICIPANT	\N	PRESENT	0
805743	804018	20074E	PARTICIPANT	\N	PRESENT	0
805744	804018	21076L	PARTICIPANT	\N	PRESENT	0
805745	804018	21057H	PARTICIPANT	\N	PRESENT	0
805746	804018	20044X	PARTICIPANT	\N	PRESENT	0
805747	804018	19447X	PARTICIPANT	\N	PRESENT	0
805748	804018	19551W	PARTICIPANT	\N	PRESENT	0
805749	804018	19954N	PARTICIPANT	\N	PRESENT	0
805750	804018	21044C	PARTICIPANT	\N	PRESENT	0
805751	804018	11056N	PARTICIPANT	\N	PRESENT	0
805752	804018	21063F	PARTICIPANT	\N	PRESENT	0
805753	804018	18231D	PARTICIPANT	\N	PRESENT	0
805754	804018	20110Q	PARTICIPANT	\N	PRESENT	0
805755	804018	14147R	PARTICIPANT	\N	PRESENT	0
805756	804018	14215L	PARTICIPANT	\N	PRESENT	0
805757	804018	08018U	PRESIDENT	0	PRESENT	0
805758	804018	21038E	PARTICIPANT	\N	PRESENT	0
805759	804018	14259Y	PARTICIPANT	\N	PRESENT	0
805760	804018	19749K	PARTICIPANT	\N	PRESENT	0
805761	804018	20022R	PARTICIPANT	\N	PRESENT	0
805762	804018	11072N	PARTICIPANT	\N	PRESENT	0
805763	803919	20140W	PARTICIPANT	\N	PRESENT	0
805764	803919	20090E	PARTICIPANT	\N	PRESENT	0
805765	803919	19866P	PARTICIPANT	\N	PRESENT	0
805766	803919	19479G	PARTICIPANT	\N	PRESENT	0
805767	803919	21032X	PARTICIPANT	\N	PRESENT	0
805768	803919	21085M	PARTICIPANT	\N	PRESENT	0
805769	803919	98022P	PARTICIPANT	\N	PRESENT	0
805770	803919	21090J	PARTICIPANT	\N	PRESENT	0
805771	803919	08028W	PARTICIPANT	\N	PRESENT	0
805772	803919	14053L	PARTICIPANT	\N	PRESENT	0
807838	807837	14107H	PARTICIPANT	\N	PRESENT	0
807894	807893	08012N	PARTICIPANT	\N	PRESENT	0
807949	807893	14073Q	PARTICIPANT	\N	PRESENT	0
807951	807893	19954N	PARTICIPANT	\N	PRESENT	0
807963	807893	19533U	PARTICIPANT	\N	PRESENT	0
808538	808537	14187A	PARTICIPANT	\N	PRESENT	0
808539	808537	19383Y	PARTICIPANT	\N	PRESENT	0
808540	808537	21083K	PARTICIPANT	\N	PRESENT	0
808542	808537	20082E	PARTICIPANT	\N	PRESENT	0
808543	808537	21066J	PARTICIPANT	\N	PRESENT	0
810755	810204	14053L	PARTICIPANT	\N	PRESENT	0
810757	810204	20034V	PRESIDENT	0	PRESENT	0
810758	810204	11072N	PARTICIPANT	\N	PRESENT	0
810759	810204	19631V	PARTICIPANT	\N	PRESENT	0
810760	810204	08073C	PARTICIPANT	\N	PRESENT	0
810893	810879	20136B	PARTICIPANT	\N	PRESENT	0
810894	810879	20100N	PARTICIPANT	\N	PRESENT	0
810903	810902	20136B	PARTICIPANT	\N	PRESENT	0
810993	810911	14281W	PARTICIPANT	\N	PRESENT	0
810994	810911	19723Y	PARTICIPANT	\N	PRESENT	0
810996	810911	14071N	PARTICIPANT	\N	PRESENT	0
810997	810911	20096L	PARTICIPANT	\N	PRESENT	0
810999	810911	21064G	PARTICIPANT	\N	PRESENT	0
812656	809359	14033T	PARTICIPANT	\N	PRESENT	0
812657	809359	20100N	PARTICIPANT	\N	PRESENT	0
812658	809359	19709B	PARTICIPANT	\N	PRESENT	0
812659	809359	14331P	PARTICIPANT	\N	PRESENT	0
812660	809359	10015M	PARTICIPANT	\N	PRESENT	0
812661	809359	14169X	PARTICIPANT	\N	PRESENT	0
812662	809359	14357A	PARTICIPANT	\N	PRESENT	0
812663	809359	14189C	PARTICIPANT	\N	PRESENT	0
812664	809359	19569H	PARTICIPANT	\N	PRESENT	0
812665	809359	18207D	PARTICIPANT	\N	PRESENT	0
812666	809359	14059S	PARTICIPANT	\N	PRESENT	0
812667	809359	19565D	PARTICIPANT	\N	PRESENT	0
812684	809359	04070G	PARTICIPANT	\N	PRESENT	0
812702	809359	21076L	PARTICIPANT	\N	PRESENT	0
812705	809359	14133K	PARTICIPANT	\N	PRESENT	0
812707	809359	20042V	PARTICIPANT	\N	PRESENT	0
812714	809359	19701S	PARTICIPANT	\N	PRESENT	0
812715	809359	19711U	PARTICIPANT	\N	PRESENT	0
812716	809359	17737W	PARTICIPANT	\N	PRESENT	0
812853	812852	19479G	PARTICIPANT	\N	PRESENT	0
812854	812852	14331P	PARTICIPANT	\N	PRESENT	0
812856	812855	19479G	PARTICIPANT	\N	PRESENT	0
812904	812903	14083S	PARTICIPANT	\N	PRESENT	0
812905	812903	14073Q	PARTICIPANT	\N	PRESENT	0
812906	812903	19723Y	PARTICIPANT	\N	PRESENT	0
812907	812903	14147R	PARTICIPANT	\N	PRESENT	0
812908	812903	14331P	PARTICIPANT	\N	PRESENT	0
812909	812903	14169X	PARTICIPANT	\N	PRESENT	0
814009	813212	04042C	PARTICIPANT	\N	EXCUSE	0
814011	814010	04042C	PARTICIPANT	\N	EXCUSE	0
814366	810883	14225N	PRESIDENT	0	PRESENT	0
814367	810883	11048N	PARTICIPANT	\N	PRESENT	0
814368	810883	19711U	PARTICIPANT	\N	PRESENT	0
814369	810883	07004J	PARTICIPANT	\N	PRESENT	0
814370	810883	21069M	PARTICIPANT	\N	PRESENT	0
814371	810883	14121F	PARTICIPANT	\N	PRESENT	0
814372	810883	19399H	PARTICIPANT	\N	PRESENT	0
814373	810883	14327T	PARTICIPANT	\N	PRESENT	0
814374	810883	20086J	PARTICIPANT	\N	PRESENT	0
814375	810883	11053K	PARTICIPANT	\N	PRESENT	0
814376	810883	19667J	PARTICIPANT	\N	PRESENT	0
814377	810883	19573D	PARTICIPANT	\N	PRESENT	0
814378	810883	21079P	PARTICIPANT	\N	PRESENT	0
814379	810883	19349W	PARTICIPANT	\N	PRESENT	0
814380	810883	08010L	PARTICIPANT	\N	PRESENT	0
814381	810883	14253S	PARTICIPANT	\N	PRESENT	0
814382	810883	20116W	PARTICIPANT	\N	PRESENT	0
814383	810883	19335Q	PARTICIPANT	\N	PRESENT	0
806515	803919	20018V	PARTICIPANT	\N	PRESENT	0
806516	803919	20096L	PARTICIPANT	\N	PRESENT	0
806517	803919	08011M	PARTICIPANT	\N	PRESENT	0
806518	803919	21029D	PARTICIPANT	\N	PRESENT	0
806519	803919	14169X	PARTICIPANT	\N	PRESENT	0
806520	803919	19768N	PARTICIPANT	\N	PRESENT	0
806521	803919	14229S	PARTICIPANT	\N	PRESENT	0
806522	803919	21056G	PARTICIPANT	\N	PRESENT	0
806523	803919	01058X	PARTICIPANT	\N	PRESENT	0
806524	803919	19703U	PARTICIPANT	\N	PRESENT	0
806525	803919	20062A	PARTICIPANT	\N	PRESENT	0
806526	803919	21095P	PARTICIPANT	\N	PRESENT	0
806527	803919	20136B	PARTICIPANT	\N	PRESENT	0
806528	803919	21061D	PARTICIPANT	\N	PRESENT	0
806529	803919	20026V	PARTICIPANT	\N	PRESENT	0
806530	803919	20058E	PARTICIPANT	\N	PRESENT	0
806531	803919	14173T	PARTICIPANT	\N	PRESENT	0
807129	803917	20024T	PARTICIPANT	\N	PRESENT	0
807248	807247	19573D	PARTICIPANT	\N	PRESENT	0
807250	807249	11053K	PARTICIPANT	\N	PRESENT	0
807252	807251	11053K	PARTICIPANT	\N	PRESENT	0
807256	807254	11053K	PARTICIPANT	\N	PRESENT	0
807261	807260	11053K	PARTICIPANT	\N	PRESENT	0
807263	807262	20134Y	PARTICIPANT	\N	PRESENT	0
807264	807262	20062A	PARTICIPANT	\N	PRESENT	0
807266	807265	20134Y	PARTICIPANT	\N	PRESENT	0
807267	807265	20062A	PARTICIPANT	\N	PRESENT	0
807269	807268	20134Y	PARTICIPANT	\N	PRESENT	0
807270	807268	20062A	PARTICIPANT	\N	PRESENT	0
807272	804286	11074Q	PARTICIPANT	\N	PRESENT	0
807273	804286	19545Y	PARTICIPANT	\N	PRESENT	0
807274	804286	19711U	PARTICIPANT	\N	PRESENT	0
807276	804289	20134Y	PARTICIPANT	\N	EXCUSE	0
807278	807277	20116W	PARTICIPANT	\N	PRESENT	0
807281	807279	20116W	PARTICIPANT	\N	PRESENT	0
807566	804287	20134Y	PARTICIPANT	\N	EXCUSE	0
807579	804086	14055N	PARTICIPANT	\N	PRESENT	0
808276	808273	11090Q	PARTICIPANT	\N	PRESENT	0
808281	808273	19695N	PARTICIPANT	\N	PRESENT	0
808668	807221	20146D	PARTICIPANT	\N	PRESENT	0
808679	807221	14357A	PARTICIPANT	\N	PRESENT	0
808670	807221	19705W	PARTICIPANT	\N	PRESENT	0
808671	807221	19707Y	PARTICIPANT	\N	PRESENT	0
808672	807221	14249W	PARTICIPANT	\N	PRESENT	0
808673	807221	19507S	PARTICIPANT	\N	PRESENT	0
808674	807221	20124W	PARTICIPANT	\N	PRESENT	0
808675	807221	19331L	PARTICIPANT	\N	PRESENT	0
808676	807221	20126Y	PARTICIPANT	\N	PRESENT	0
808677	807221	20054A	PARTICIPANT	\N	PRESENT	0
808678	807221	14329V	PARTICIPANT	\N	PRESENT	0
808680	807221	19383Y	PARTICIPANT	\N	PRESENT	0
808681	807221	20086J	PARTICIPANT	\N	PRESENT	0
808682	807221	20098N	PARTICIPANT	\N	PRESENT	0
808683	807221	07033P	PARTICIPANT	\N	PRESENT	0
808684	807221	21095P	PARTICIPANT	\N	PRESENT	0
808685	807221	14217N	PARTICIPANT	\N	PRESENT	0
808686	807221	20118Y	PARTICIPANT	\N	PRESENT	0
808687	807221	19533U	PARTICIPANT	\N	PRESENT	0
808688	807221	14069U	PARTICIPANT	\N	PRESENT	0
808689	807221	19798U	PARTICIPANT	\N	PRESENT	0
808690	807221	14187A	PARTICIPANT	\N	PRESENT	0
808691	807221	14071N	PARTICIPANT	\N	PRESENT	0
808692	807221	14053L	PARTICIPANT	\N	PRESENT	0
808693	807221	04033B	PARTICIPANT	\N	PRESENT	0
808694	807221	19679N	PARTICIPANT	\N	PRESENT	0
808695	807221	20062A	PARTICIPANT	\N	PRESENT	0
808696	807221	11048N	PARTICIPANT	\N	PRESENT	0
808697	807221	04092N	PARTICIPANT	\N	PRESENT	0
808698	807221	19629C	PARTICIPANT	\N	PRESENT	0
808699	807221	14169X	PARTICIPANT	\N	PRESENT	0
808700	807221	20136B	PARTICIPANT	\N	PRESENT	0
808701	807221	14033T	PARTICIPANT	\N	PRESENT	0
808702	807221	08034U	PARTICIPANT	\N	PRESENT	0
808703	807221	21066J	PARTICIPANT	\N	PRESENT	0
808704	807221	08010L	PARTICIPANT	\N	PRESENT	0
808705	807221	20132W	PARTICIPANT	\N	PRESENT	0
808706	807221	14026U	PARTICIPANT	\N	PRESENT	0
808707	807221	19703U	PARTICIPANT	\N	PRESENT	0
808708	807221	14207L	PARTICIPANT	\N	PRESENT	0
808709	807221	20116W	PARTICIPANT	\N	PRESENT	0
808710	807221	21040X	PARTICIPANT	\N	PRESENT	0
808711	807221	14133K	PARTICIPANT	\N	PRESENT	0
808712	807221	14107H	PARTICIPANT	\N	PRESENT	0
808713	807221	20072C	PARTICIPANT	\N	PRESENT	0
808714	807221	14195A	PARTICIPANT	\N	PRESENT	0
808715	807221	07029T	PARTICIPANT	\N	PRESENT	0
808716	807221	19693L	PARTICIPANT	\N	PRESENT	0
808717	807221	19768N	PARTICIPANT	\N	PRESENT	0
808718	807221	19573D	PARTICIPANT	\N	PRESENT	0
808719	807221	11043H	PARTICIPANT	\N	PRESENT	0
808720	807221	21087P	PARTICIPANT	\N	PRESENT	0
808721	807221	14211G	PARTICIPANT	\N	PRESENT	0
808722	807221	14251Q	PARTICIPANT	\N	PRESENT	0
808723	807221	21076L	PARTICIPANT	\N	PRESENT	0
808724	807221	21054E	PARTICIPANT	\N	PRESENT	0
808725	807221	21070E	PARTICIPANT	\N	PRESENT	0
808726	807221	21065H	PARTICIPANT	\N	PRESENT	0
808729	807221	19631V	PARTICIPANT	\N	PRESENT	0
808733	807221	12028B	PARTICIPANT	\N	PRESENT	0
808735	807221	20264J	PARTICIPANT	\N	PRESENT	0
808736	807221	08060W	PARTICIPANT	\N	PRESENT	0
808737	807221	20070A	PARTICIPANT	\N	PRESENT	0
808738	807221	18395Y	PARTICIPANT	\N	PRESENT	0
808739	807221	14151M	PARTICIPANT	\N	PRESENT	0
808740	807221	11074Q	PARTICIPANT	\N	PRESENT	0
808741	807221	11110B	PARTICIPANT	\N	PRESENT	0
808743	807221	21062E	PARTICIPANT	\N	PRESENT	0
808744	807221	14021P	PARTICIPANT	\N	PRESENT	0
808745	807221	19683J	PARTICIPANT	\N	PRESENT	0
808746	807221	14097Y	PARTICIPANT	\N	PRESENT	0
808747	808742	19575F	PARTICIPANT	\N	PRESENT	0
808748	807221	19531S	PARTICIPANT	\N	PRESENT	0
808749	808742	11040E	PARTICIPANT	\N	PRESENT	0
808750	808742	21041Y	PARTICIPANT	\N	PRESENT	0
808751	807221	19649G	PARTICIPANT	\N	PRESENT	0
808752	807221	18193Q	PARTICIPANT	\N	PRESENT	0
808753	808742	14249W	PARTICIPANT	\N	EXCUSE	0
808754	807221	18207D	PARTICIPANT	\N	PRESENT	0
808755	807221	08012N	PARTICIPANT	\N	PRESENT	0
808756	808742	07004J	PARTICIPANT	\N	EXCUSE	0
808757	807221	14001X	PARTICIPANT	\N	PRESENT	0
808758	808742	14097Y	PARTICIPANT	\N	PRESENT	0
808759	807221	14109K	PARTICIPANT	\N	PRESENT	0
808761	808742	08034U	PRESIDENT	0	PRESENT	0
808760	807221	14257W	PARTICIPANT	\N	PRESENT	0
808762	808742	14059S	PARTICIPANT	\N	PRESENT	0
808763	807221	21060C	PARTICIPANT	\N	PRESENT	0
808764	808742	19745F	PARTICIPANT	\N	PRESENT	0
808765	807221	20080C	PARTICIPANT	\N	PRESENT	0
808766	807221	20060X	PARTICIPANT	\N	PRESENT	0
808767	808742	10015M	PARTICIPANT	\N	PRESENT	0
808768	807221	17779H	PARTICIPANT	\N	PRESENT	0
808769	808742	14229S	PARTICIPANT	\N	PRESENT	0
808770	807221	21075K	PARTICIPANT	\N	PRESENT	0
808771	808742	19669L	PARTICIPANT	\N	PRESENT	0
808772	807221	14229S	PARTICIPANT	\N	PRESENT	0
808773	807221	19669L	PARTICIPANT	\N	PRESENT	0
808774	807221	19413M	PARTICIPANT	\N	PRESENT	0
808775	807221	21031W	PARTICIPANT	\N	PRESENT	0
808776	807221	21082J	PARTICIPANT	\N	PRESENT	0
808777	807221	21056G	PARTICIPANT	\N	PRESENT	0
808778	807221	21051B	PARTICIPANT	\N	PRESENT	0
808779	807221	14281W	PARTICIPANT	\N	PRESENT	0
808780	807221	19647E	PARTICIPANT	\N	PRESENT	0
808781	807221	14030Q	PARTICIPANT	\N	PRESENT	0
808782	807221	19725B	PARTICIPANT	\N	PRESENT	0
808783	807221	19551W	PARTICIPANT	\N	PRESENT	0
808784	807221	14225N	PARTICIPANT	\N	PRESENT	0
808785	807221	21050A	PARTICIPANT	\N	PRESENT	0
808786	807221	21042A	PARTICIPANT	\N	PRESENT	0
808787	807221	21083K	PARTICIPANT	\N	PRESENT	0
808794	807221	14267Y	PARTICIPANT	\N	PRESENT	0
808789	807221	14255U	PARTICIPANT	\N	PRESENT	0
808790	807221	14089Y	PARTICIPANT	\N	PRESENT	0
808791	807221	14083S	PARTICIPANT	\N	PRESENT	0
808792	807221	11053K	PARTICIPANT	\N	PRESENT	0
808793	807221	20042V	PARTICIPANT	\N	PRESENT	0
808795	807221	20144B	PARTICIPANT	\N	PRESENT	0
808796	807221	19721W	PARTICIPANT	\N	PRESENT	0
808797	807221	11085T	PARTICIPANT	\N	PRESENT	0
808798	807221	01034P	PARTICIPANT	\N	PRESENT	0
797711	797710	86034E	PARTICIPANT	\N	PRESENT	0
797712	797710	04047H	PARTICIPANT	\N	PRESENT	0
797713	797710	12028B	PARTICIPANT	\N	PRESENT	0
797716	797710	19629C	PARTICIPANT	\N	PRESENT	0
797718	797710	11056N	PARTICIPANT	\N	PRESENT	0
797720	797710	14259Y	PARTICIPANT	\N	PRESENT	0
797722	797710	14042U	PARTICIPANT	\N	PRESENT	0
797725	797710	14187A	PARTICIPANT	\N	PRESENT	0
797727	797710	14231L	PARTICIPANT	\N	PRESENT	0
797728	797710	19347U	PARTICIPANT	\N	PRESENT	0
797729	797710	14179A	PARTICIPANT	\N	PRESENT	0
797730	797710	11048N	PARTICIPANT	\N	PRESENT	0
797731	797710	20034V	PARTICIPANT	\N	PRESENT	0
797732	797710	14021P	PARTICIPANT	\N	PRESENT	0
797733	797710	19611R	PARTICIPANT	\N	PRESENT	0
797734	797710	19711U	PARTICIPANT	\N	PRESENT	0
797735	797710	14219Q	PARTICIPANT	\N	PRESENT	0
797736	797710	14251Q	PARTICIPANT	\N	PRESENT	0
797737	797710	14111D	PARTICIPANT	\N	PRESENT	0
797738	797710	11085T	PARTICIPANT	\N	PRESENT	0
797739	797710	14071N	PARTICIPANT	\N	PRESENT	0
797740	797710	08061X	PARTICIPANT	\N	PRESENT	0
797741	797710	14193X	PARTICIPANT	\N	PRESENT	0
797742	797710	19533U	PARTICIPANT	\N	PRESENT	0
797743	797710	14225N	PARTICIPANT	\N	PRESENT	0
797744	797710	10015M	PARTICIPANT	\N	PRESENT	0
797745	797710	04033B	PARTICIPANT	\N	PRESENT	0
797746	797710	20054A	PARTICIPANT	\N	PRESENT	0
797747	797710	14229S	PARTICIPANT	\N	PRESENT	0
797748	797710	19301E	PARTICIPANT	\N	PRESENT	0
797749	797710	19749K	PARTICIPANT	\N	PRESENT	0
797751	797710	19479G	PARTICIPANT	\N	PRESENT	0
799249	797973	21082J	PARTICIPANT	\N	PRESENT	0
799250	797973	19701S	PARTICIPANT	\N	PRESENT	0
799251	797973	21042A	PARTICIPANT	\N	PRESENT	0
799252	797973	20076G	PARTICIPANT	\N	PRESENT	0
799253	797973	14219Q	PRESIDENT	0	PRESENT	0
799254	797973	19820Y	PARTICIPANT	\N	PRESENT	0
799255	797973	19826F	PARTICIPANT	\N	PRESENT	0
799256	797973	21060C	PARTICIPANT	\N	PRESENT	0
799257	797973	21061D	PARTICIPANT	\N	PRESENT	0
799258	797973	21065H	PARTICIPANT	\N	PRESENT	0
799259	797973	21084L	PARTICIPANT	\N	PRESENT	0
799260	797973	20100N	PARTICIPANT	\N	PRESENT	0
799261	797973	14237S	PARTICIPANT	\N	PRESENT	0
799262	797973	19551W	PARTICIPANT	\N	PRESENT	0
799263	797973	21085M	PARTICIPANT	\N	PRESENT	0
799264	797973	20106U	PARTICIPANT	\N	PRESENT	0
799265	797973	08060W	PARTICIPANT	\N	PRESENT	0
799266	797973	14107H	PARTICIPANT	\N	PRESENT	0
799267	797973	21080G	PARTICIPANT	\N	PRESENT	0
799268	797973	20020P	PARTICIPANT	\N	PRESENT	0
799269	797973	20120S	PARTICIPANT	\N	PRESENT	0
799270	797973	21051B	PARTICIPANT	\N	PRESENT	0
799271	797973	20032T	PARTICIPANT	\N	PRESENT	0
799272	797973	21053D	PARTICIPANT	\N	PRESENT	0
799273	797973	20136B	PARTICIPANT	\N	PRESENT	0
799274	797973	14031R	PARTICIPANT	\N	PRESENT	0
799275	797973	20040T	PARTICIPANT	\N	PRESENT	0
799276	797973	19251M	PARTICIPANT	\N	PRESENT	0
799277	797973	20046A	PARTICIPANT	\N	PRESENT	0
799278	797973	17229F	PARTICIPANT	\N	PRESENT	0
799279	797973	14169X	PARTICIPANT	\N	PRESENT	0
799280	797973	20068G	PARTICIPANT	\N	PRESENT	0
799281	797973	21068L	PARTICIPANT	\N	PRESENT	0
799282	797973	21070E	PARTICIPANT	\N	PRESENT	0
799283	797973	19619A	PARTICIPANT	\N	PRESENT	0
799284	797973	21035B	PARTICIPANT	\N	EXCUSE	0
799285	797973	19681G	PARTICIPANT	\N	EXCUSE	0
799359	797802	21036C	PARTICIPANT	\N	PRESENT	0
799360	797802	95041E	PARTICIPANT	\N	PRESENT	0
799361	797802	20072C	PARTICIPANT	\N	PRESENT	0
799362	797802	14001X	PARTICIPANT	\N	PRESENT	0
799363	797802	04042C	PARTICIPANT	\N	PRESENT	0
799364	797802	19669L	PARTICIPANT	\N	PRESENT	0
799365	797802	08056B	PARTICIPANT	\N	PRESENT	0
799366	797802	12028B	PARTICIPANT	\N	PRESENT	0
799367	797802	11115U	PARTICIPANT	\N	PRESENT	0
799368	797802	14055N	PARTICIPANT	\N	PRESENT	0
799369	797802	19421M	PARTICIPANT	\N	PRESENT	0
799370	797802	19709B	PARTICIPANT	\N	PRESENT	0
799371	797802	21067K	PARTICIPANT	\N	PRESENT	0
799372	797802	14193X	PRESIDENT	0	PRESENT	0
799373	797802	19347U	PARTICIPANT	\N	PRESENT	0
799374	797802	07033P	PARTICIPANT	\N	PRESENT	0
799375	797802	17367Q	PARTICIPANT	\N	PRESENT	0
799376	797802	14249W	PARTICIPANT	\N	PRESENT	0
799377	797802	08047A	PARTICIPANT	\N	PRESENT	0
799378	797802	14037X	PARTICIPANT	\N	PRESENT	0
799379	797802	14059S	PARTICIPANT	\N	PRESENT	0
799380	797802	14097Y	PARTICIPANT	\N	PRESENT	0
799381	797802	14133K	PRESIDENT	1	PRESENT	0
799382	797802	21073H	PARTICIPANT	\N	PRESENT	0
799383	797802	19531S	PARTICIPANT	\N	PRESENT	0
799384	797802	08069G	PARTICIPANT	\N	PRESENT	0
799385	797802	20042V	PARTICIPANT	\N	PRESENT	0
799386	797802	14191V	PARTICIPANT	\N	PRESENT	0
799387	797802	19721W	PARTICIPANT	\N	PRESENT	0
799388	797802	20064C	PARTICIPANT	\N	PRESENT	0
799389	797802	20252E	PARTICIPANT	\N	PRESENT	0
799390	797802	14251Q	PARTICIPANT	\N	PRESENT	0
799391	797802	98022P	PARTICIPANT	\N	PRESENT	0
799392	797802	14267Y	PARTICIPANT	\N	PRESENT	0
799393	797802	99004R	PARTICIPANT	\N	PRESENT	0
799394	797802	19745F	PARTICIPANT	\N	PRESENT	0
799395	797802	14211G	PARTICIPANT	\N	PRESENT	0
799396	797802	17023S	PARTICIPANT	\N	PRESENT	0
799414	797803	21036C	PARTICIPANT	\N	PRESENT	0
799415	797803	95041E	PARTICIPANT	\N	PRESENT	0
799416	797803	20072C	PARTICIPANT	\N	PRESENT	0
799417	797803	14001X	PARTICIPANT	\N	PRESENT	0
799418	797803	04042C	PARTICIPANT	\N	PRESENT	0
799419	797803	19669L	PARTICIPANT	\N	PRESENT	0
799420	797803	08056B	PARTICIPANT	\N	PRESENT	0
799421	797803	12028B	PARTICIPANT	\N	PRESENT	0
799422	797803	11115U	PARTICIPANT	\N	PRESENT	0
799423	797803	14055N	PARTICIPANT	\N	PRESENT	0
799424	797803	19421M	PARTICIPANT	\N	PRESENT	0
799425	797803	19709B	PARTICIPANT	\N	PRESENT	0
799426	797803	21067K	PARTICIPANT	\N	PRESENT	0
799427	797803	14193X	PRESIDENT	0	PRESENT	0
799428	797803	19347U	PARTICIPANT	\N	PRESENT	0
799429	797803	07033P	PARTICIPANT	\N	PRESENT	0
799430	797803	17367Q	PARTICIPANT	\N	PRESENT	0
799431	797803	14249W	PARTICIPANT	\N	PRESENT	0
799432	797803	08047A	PARTICIPANT	\N	PRESENT	0
799433	797803	14037X	PARTICIPANT	\N	PRESENT	0
799434	797803	14059S	PARTICIPANT	\N	PRESENT	0
799435	797803	14097Y	PARTICIPANT	\N	PRESENT	0
799436	797803	14133K	PRESIDENT	1	PRESENT	0
799437	797803	21073H	PARTICIPANT	\N	PRESENT	0
799438	797803	19531S	PARTICIPANT	\N	PRESENT	0
799439	797803	08069G	PARTICIPANT	\N	PRESENT	0
799440	797803	20042V	PARTICIPANT	\N	PRESENT	0
799441	797803	14191V	PARTICIPANT	\N	PRESENT	0
799442	797803	19721W	PARTICIPANT	\N	PRESENT	0
799443	797803	20064C	PARTICIPANT	\N	PRESENT	0
799444	797803	20252E	PARTICIPANT	\N	PRESENT	0
799445	797803	14251Q	PARTICIPANT	\N	PRESENT	0
799446	797803	98022P	PARTICIPANT	\N	PRESENT	0
799447	797803	14267Y	PARTICIPANT	\N	PRESENT	0
799448	797803	99004R	PARTICIPANT	\N	PRESENT	0
799449	797803	19745F	PARTICIPANT	\N	PRESENT	0
799450	797803	14211G	PARTICIPANT	\N	PRESENT	0
799451	797803	17023S	PARTICIPANT	\N	PRESENT	0
799452	797802	20128B	PARTICIPANT	\N	PRESENT	0
799546	799207	19383Y	PARTICIPANT	\N	PRESENT	0
799547	799207	20088L	PARTICIPANT	\N	PRESENT	0
799548	799207	19768N	PARTICIPANT	\N	PRESENT	0
799549	799207	20092G	PARTICIPANT	\N	PRESENT	0
799550	799207	14357A	PARTICIPANT	\N	PRESENT	0
799551	799207	20078J	PARTICIPANT	\N	PRESENT	0
799552	799207	19413M	PARTICIPANT	\N	PRESENT	0
799553	799207	20082E	PARTICIPANT	\N	PRESENT	0
799554	799207	14221J	PARTICIPANT	\N	PRESENT	0
799555	799207	19631V	PARTICIPANT	\N	PRESENT	0
799556	799207	20104S	PARTICIPANT	\N	PRESENT	0
799557	799207	19705W	PARTICIPANT	\N	PRESENT	0
799558	799207	08015R	PARTICIPANT	\N	PRESENT	0
799559	799207	19575F	PARTICIPANT	\N	PRESENT	0
799560	799207	20018V	PARTICIPANT	\N	PRESENT	0
814058	814044	14189C	PARTICIPANT	\N	EXCUSE	0
814059	814044	20080C	PARTICIPANT	\N	EXCUSE	0
814060	814044	20132W	PARTICIPANT	\N	PRESENT	0
814061	814044	21042A	PARTICIPANT	\N	PRESENT	0
814066	814044	21071F	PARTICIPANT	\N	PRESENT	0
814069	814044	14213J	PARTICIPANT	\N	PRESENT	0
814098	814097	19954N	PARTICIPANT	\N	PRESENT	0
814099	814097	19693L	PARTICIPANT	\N	PRESENT	0
814100	814097	20264J	PARTICIPANT	\N	PRESENT	0
814101	814097	20052X	PARTICIPANT	\N	PRESENT	0
814133	814132	20024T	PARTICIPANT	\N	PRESENT	0
814135	814132	20126Y	PARTICIPANT	\N	PRESENT	0
814136	814132	07033P	PARTICIPANT	\N	PRESENT	0
814137	814132	21039F	PARTICIPANT	\N	PRESENT	0
814138	814132	20056C	PARTICIPANT	\N	PRESENT	0
814139	814132	08010L	PARTICIPANT	\N	PRESENT	0
814140	814132	20054A	PARTICIPANT	\N	PRESENT	0
814145	814044	14073Q	PARTICIPANT	\N	PRESENT	0
814396	811598	14071N	PRESIDENT	0	PRESENT	0
814397	811598	19760E	PARTICIPANT	\N	PRESENT	0
814398	811598	21046E	PARTICIPANT	\N	PRESENT	0
814399	811598	19758L	PARTICIPANT	\N	PRESENT	0
814400	811598	20090E	PARTICIPANT	\N	PRESENT	0
814401	811598	19367Y	PARTICIPANT	\N	PRESENT	0
814402	811598	14281W	PARTICIPANT	\N	PRESENT	0
814403	811598	18193Q	PARTICIPANT	\N	PRESENT	0
814404	811598	14223L	PARTICIPANT	\N	PRESENT	0
814405	811598	14195A	PARTICIPANT	\N	PRESENT	0
814406	811598	20248J	PARTICIPANT	\N	PRESENT	0
814407	811598	21087P	PARTICIPANT	\N	PRESENT	0
814408	811598	21039F	PARTICIPANT	\N	PRESENT	0
814409	811598	19301E	PARTICIPANT	\N	PRESENT	0
814410	811598	19703U	PARTICIPANT	\N	PRESENT	0
814411	811598	21064G	PARTICIPANT	\N	PRESENT	0
814412	811598	19798U	PARTICIPANT	\N	PRESENT	0
814413	811598	11045K	PARTICIPANT	\N	PRESENT	0
814414	811598	20140W	PARTICIPANT	\N	PRESENT	0
814415	811598	08061X	PARTICIPANT	\N	PRESENT	0
814416	811598	19683J	PARTICIPANT	\N	PRESENT	0
814417	811598	19569H	PARTICIPANT	\N	PRESENT	0
814446	811598	14213J	PARTICIPANT	\N	PRESENT	0
814447	811598	19691J	PARTICIPANT	\N	PRESENT	0
814449	811598	19723Y	PARTICIPANT	\N	PRESENT	0
814450	811598	14217N	PARTICIPANT	\N	PRESENT	0
814451	811598	04092N	PARTICIPANT	\N	PRESENT	0
814452	811598	21045D	PARTICIPANT	\N	PRESENT	0
814453	811598	19713W	PARTICIPANT	\N	PRESENT	0
814454	811598	19679N	PARTICIPANT	\N	PRESENT	0
814456	811598	19553Y	PARTICIPANT	\N	PRESENT	0
814457	811598	08045X	PARTICIPANT	\N	PRESENT	0
814478	814477	04070G	PARTICIPANT	\N	PRESENT	0
814479	814477	14038Y	PARTICIPANT	\N	PRESENT	0
814480	814477	20022R	PARTICIPANT	\N	PRESENT	0
814481	814477	20062A	PARTICIPANT	\N	PRESENT	0
814482	814477	20060X	PARTICIPANT	\N	PRESENT	0
814483	814477	11045K	PARTICIPANT	\N	PRESENT	0
814484	814477	20128B	PARTICIPANT	\N	PRESENT	0
814485	814477	14179A	PARTICIPANT	\N	PRESENT	0
814486	814477	20134Y	PARTICIPANT	\N	PRESENT	0
814718	814717	20032T	PARTICIPANT	\N	PRESENT	0
814719	814717	20076G	PARTICIPANT	\N	PRESENT	0
814720	814717	20024T	PARTICIPANT	\N	PRESENT	0
814721	814717	19954N	PARTICIPANT	\N	PRESENT	0
814722	814717	21050A	PARTICIPANT	\N	PRESENT	0
814723	814717	14069U	PARTICIPANT	\N	PRESENT	0
814724	814717	19383Y	PARTICIPANT	\N	PRESENT	0
814725	814717	19782L	PARTICIPANT	\N	PRESENT	0
814726	814717	20090E	PARTICIPANT	\N	PRESENT	0
814727	814717	14207L	PARTICIPANT	\N	PRESENT	0
814728	814717	14053L	PARTICIPANT	\N	PRESENT	0
814729	814717	14083S	PARTICIPANT	\N	PRESENT	0
814730	814717	14195A	PARTICIPANT	\N	PRESENT	0
814731	814717	20144B	PARTICIPANT	\N	PRESENT	0
814732	814717	21065H	PARTICIPANT	\N	PRESENT	0
814733	814717	14357A	PARTICIPANT	\N	PRESENT	0
814734	814717	21067K	PARTICIPANT	\N	PRESENT	0
814735	814717	14217N	PARTICIPANT	\N	PRESENT	0
814736	814717	14215L	PARTICIPANT	\N	PRESENT	0
814737	814717	14187A	PARTICIPANT	\N	PRESENT	0
814738	814717	20038A	PARTICIPANT	\N	PRESENT	0
814739	814717	20172F	PARTICIPANT	\N	PRESENT	0
814740	814717	20180F	PARTICIPANT	\N	PRESENT	0
814741	814717	14033T	PARTICIPANT	\N	PRESENT	0
814742	814717	14213J	PARTICIPANT	\N	PRESENT	0
814743	814717	21044C	PARTICIPANT	\N	PRESENT	0
814744	814717	20056C	PARTICIPANT	\N	PRESENT	0
814745	814717	19447X	PARTICIPANT	\N	PRESENT	0
814746	814717	20126Y	PARTICIPANT	\N	PRESENT	0
814747	814717	19507S	PARTICIPANT	\N	PRESENT	0
814748	814717	08015R	PARTICIPANT	\N	PRESENT	0
814749	814717	18193Q	PARTICIPANT	\N	PRESENT	0
814750	814717	14059S	PARTICIPANT	\N	PRESENT	0
814751	814717	21054E	PARTICIPANT	\N	PRESENT	0
814752	814717	14221J	PARTICIPANT	\N	PRESENT	0
814753	814717	20018V	PARTICIPANT	\N	PRESENT	0
814754	814717	14109K	PARTICIPANT	\N	PRESENT	0
814755	814717	21053D	PARTICIPANT	\N	PRESENT	0
814756	814717	20118Y	PARTICIPANT	\N	PRESENT	0
814757	814717	19679N	PARTICIPANT	\N	PRESENT	0
814758	814717	20082E	PARTICIPANT	\N	PRESENT	0
814759	814717	21068L	PARTICIPANT	\N	PRESENT	0
814760	814717	19798U	PARTICIPANT	\N	PRESENT	0
814761	814717	20020P	PARTICIPANT	\N	PRESENT	0
814762	814717	21064G	PARTICIPANT	\N	PRESENT	0
814763	814717	14107H	PARTICIPANT	\N	PRESENT	0
814764	814717	20092G	PARTICIPANT	\N	PRESENT	0
814765	814717	20044X	PARTICIPANT	\N	PRESENT	0
814766	814717	19713W	PARTICIPANT	\N	PRESENT	0
814767	814717	19703U	PARTICIPANT	\N	PRESENT	0
814768	814717	20084G	PARTICIPANT	\N	PRESENT	0
814769	814717	19413M	PARTICIPANT	\N	PRESENT	0
814770	814717	20026V	PARTICIPANT	\N	PRESENT	0
814771	814717	11090Q	PARTICIPANT	\N	PRESENT	0
814786	811044	20264J	PARTICIPANT	\N	PRESENT	0
814787	811044	19711U	PARTICIPANT	\N	PRESENT	0
814788	811044	19954N	PARTICIPANT	\N	PRESENT	0
814789	813190	14151M	PRESIDENT	0	PRESENT	0
814790	813190	18395Y	PARTICIPANT	\N	PRESENT	0
814791	813190	19826F	PARTICIPANT	\N	PRESENT	0
814792	813190	17367Q	PARTICIPANT	\N	PRESENT	0
814793	811044	19693L	PARTICIPANT	\N	PRESENT	0
814794	813190	12028B	PARTICIPANT	\N	PRESENT	0
814795	813190	20108W	PARTICIPANT	\N	PRESENT	0
814796	813190	20110Q	PARTICIPANT	\N	PRESENT	0
814797	813190	21081H	PARTICIPANT	\N	PRESENT	0
814798	813190	20078J	PARTICIPANT	\N	PRESENT	0
814799	813190	20146D	PARTICIPANT	\N	PRESENT	0
814800	813190	19295A	PARTICIPANT	\N	PRESENT	0
814876	808184	19679N	PARTICIPANT	\N	PRESENT	0
814882	808184	21046E	PARTICIPANT	\N	PRESENT	0
814952	808194	21046E	PARTICIPANT	\N	PRESENT	0
814955	808194	19679N	PARTICIPANT	\N	PRESENT	0
814969	808227	19679N	PARTICIPANT	\N	PRESENT	0
814978	808227	21046E	PARTICIPANT	\N	PRESENT	0
815461	815460	19713W	PARTICIPANT	\N	PRESENT	0
815462	815460	21070E	PARTICIPANT	\N	PRESENT	0
815463	815460	20074E	PARTICIPANT	\N	PRESENT	0
815464	815460	20042V	PARTICIPANT	\N	PRESENT	0
815465	815460	21031W	PARTICIPANT	\N	PRESENT	0
815837	812504	14331P	PRESIDENT	0	PRESENT	0
815838	812504	04070G	PARTICIPANT	\N	PRESENT	0
815839	812504	21054E	PARTICIPANT	\N	PRESENT	0
815840	812504	19711U	PARTICIPANT	\N	PRESENT	0
815841	812504	20042V	PARTICIPANT	\N	PRESENT	0
815842	812504	18395Y	PARTICIPANT	\N	PRESENT	0
815843	812504	14026U	PARTICIPANT	\N	PRESENT	0
815844	812504	20104S	PARTICIPANT	\N	PRESENT	0
815845	812504	14237S	PARTICIPANT	\N	EXCUSE	0
815846	812504	17737W	PARTICIPANT	\N	EXCUSE	0
815847	812504	14073Q	PARTICIPANT	\N	EXCUSE	0
815848	812504	14001X	PARTICIPANT	\N	EXCUSE	0
815849	812504	19701S	PARTICIPANT	\N	PRESENT	0
815850	812504	14169X	PARTICIPANT	\N	PRESENT	0
815851	812504	21082J	PARTICIPANT	\N	PRESENT	0
815855	815854	20032T	PARTICIPANT	\N	PRESENT	0
815856	815854	20022R	PARTICIPANT	\N	PRESENT	0
815857	815854	20124W	PARTICIPANT	\N	PRESENT	0
815858	815854	11074Q	PARTICIPANT	\N	PRESENT	0
815859	815854	19735D	PARTICIPANT	\N	PRESENT	0
815860	815854	20142Y	PARTICIPANT	\N	PRESENT	0
815861	815854	14109K	PRESIDENT	0	PRESENT	0
797917	797916	19667J	PARTICIPANT	\N	PRESENT	0
797918	797916	19057M	PARTICIPANT	\N	PRESENT	0
797919	797916	14329V	PARTICIPANT	\N	PRESENT	0
797920	797916	14059S	PARTICIPANT	\N	PRESENT	0
797921	797916	20054A	PARTICIPANT	\N	PRESENT	0
797922	797916	20038A	PARTICIPANT	\N	PRESENT	0
797927	797926	11090Q	PARTICIPANT	\N	PRESENT	0
797928	797926	19695N	PARTICIPANT	\N	PRESENT	0
801495	801386	14179A	PARTICIPANT	\N	PRESENT	0
801505	800750	20074E	PARTICIPANT	\N	PRESENT	0
801506	800750	10015M	PARTICIPANT	\N	PRESENT	0
801507	800750	20108W	PARTICIPANT	\N	PRESENT	0
801508	800750	14147R	PARTICIPANT	\N	PRESENT	0
801509	800750	11085T	PARTICIPANT	\N	PRESENT	0
801510	800750	20022R	PARTICIPANT	\N	PRESENT	0
801511	800750	21095P	PARTICIPANT	\N	PRESENT	0
801512	800750	14259Y	PARTICIPANT	\N	PRESENT	0
801513	800750	05008E	PARTICIPANT	\N	PRESENT	0
801514	800750	20098N	PARTICIPANT	\N	PRESENT	0
801515	800750	19447X	PARTICIPANT	\N	PRESENT	0
801516	800750	11072N	PARTICIPANT	\N	PRESENT	0
801517	800750	14189C	PARTICIPANT	\N	PRESENT	0
801518	800750	04047H	PRESIDENT	0	PRESENT	0
801519	801386	21029D	PARTICIPANT	\N	PRESENT	0
801520	801386	21083K	PARTICIPANT	\N	PRESENT	0
801521	801386	05008E	PARTICIPANT	\N	PRESENT	0
801522	801386	18231D	PARTICIPANT	\N	PRESENT	0
801523	801386	14221J	PARTICIPANT	\N	PRESENT	0
801524	801386	11085T	PARTICIPANT	\N	PRESENT	0
801525	801386	20266L	PARTICIPANT	\N	PRESENT	0
801526	801386	21030V	PARTICIPANT	\N	PRESENT	0
801527	801386	20072C	PARTICIPANT	\N	PRESENT	0
801528	801386	11072N	PARTICIPANT	\N	PRESENT	0
801529	801386	14021P	PARTICIPANT	\N	PRESENT	0
801620	801386	20252E	PARTICIPANT	\N	PRESENT	0
801531	800750	19729F	PARTICIPANT	\N	EXCUSE	0
801532	800750	19585H	PARTICIPANT	\N	EXCUSE	0
801533	800750	21040X	PARTICIPANT	\N	EXCUSE	0
801535	801386	20046A	PARTICIPANT	\N	PRESENT	0
801536	801386	19695N	PARTICIPANT	\N	PRESENT	0
801537	801386	21044C	PARTICIPANT	\N	PRESENT	0
801538	801386	21034A	PARTICIPANT	\N	PRESENT	0
801539	801386	19669L	PARTICIPANT	\N	PRESENT	0
801540	801386	21076L	PARTICIPANT	\N	PRESENT	0
801541	801386	19611R	PARTICIPANT	\N	PRESENT	0
801542	801386	14073Q	PARTICIPANT	\N	PRESENT	0
801543	801386	19479G	PARTICIPANT	\N	PRESENT	0
801544	801386	20128B	PARTICIPANT	\N	PRESENT	0
801545	801386	21043B	PARTICIPANT	\N	PRESENT	0
801546	801386	14189C	PARTICIPANT	\N	PRESENT	0
801547	801386	21095P	PARTICIPANT	\N	PRESENT	0
801548	801386	14133K	PARTICIPANT	\N	PRESENT	0
801549	801386	20024T	PARTICIPANT	\N	PRESENT	0
801550	801386	20022R	PARTICIPANT	\N	PRESENT	0
801551	801386	20108W	PARTICIPANT	\N	PRESENT	0
801552	801386	20032T	PARTICIPANT	\N	PRESENT	0
801553	801386	21081H	PARTICIPANT	\N	PRESENT	0
801554	801386	20074E	PARTICIPANT	\N	PRESENT	0
801555	801386	14191V	PARTICIPANT	\N	PRESENT	0
801556	801386	21058J	PARTICIPANT	\N	PRESENT	0
801557	801386	19709B	PARTICIPANT	\N	PRESENT	0
801558	801386	18083K	PARTICIPANT	\N	PRESENT	0
801559	801386	20026V	PARTICIPANT	\N	PRESENT	0
801560	801386	19629C	PARTICIPANT	\N	PRESENT	0
801561	801386	19745F	PARTICIPANT	\N	PRESENT	0
801562	801386	20048C	PARTICIPANT	\N	PRESENT	0
801563	801386	21073H	PARTICIPANT	\N	PRESENT	0
801564	801386	21090J	PARTICIPANT	\N	PRESENT	0
801565	801386	18207D	PARTICIPANT	\N	PRESENT	0
801566	801386	19295A	PARTICIPANT	\N	PRESENT	0
801567	801386	21084L	PARTICIPANT	\N	PRESENT	0
801568	801386	20100N	PARTICIPANT	\N	PRESENT	0
801569	801386	21057H	PARTICIPANT	\N	PRESENT	0
801570	801386	04047H	PARTICIPANT	\N	PRESENT	0
801573	801386	11056N	PARTICIPANT	\N	PRESENT	0
801574	801386	21080G	PARTICIPANT	\N	PRESENT	0
801575	801386	21068L	PARTICIPANT	\N	PRESENT	0
801576	801386	19798U	PARTICIPANT	\N	PRESENT	0
801577	801386	20034V	PARTICIPANT	\N	PRESENT	0
801578	801386	20038A	PARTICIPANT	\N	PRESENT	0
801579	801386	14231L	PARTICIPANT	\N	PRESENT	0
801580	801386	21093M	PARTICIPANT	\N	PRESENT	0
801581	801386	14038Y	PARTICIPANT	\N	PRESENT	0
801582	801386	19489J	PARTICIPANT	\N	PRESENT	0
801583	801386	19782L	PARTICIPANT	\N	PRESENT	0
801584	801386	20066E	PARTICIPANT	\N	PRESENT	0
801585	801386	21052C	PARTICIPANT	\N	PRESENT	0
801586	801386	08028W	PARTICIPANT	\N	PRESENT	0
801587	801386	14151M	PARTICIPANT	\N	PRESENT	0
801588	801464	19383Y	PARTICIPANT	\N	PRESENT	0
801589	801464	21052C	PARTICIPANT	\N	PRESENT	0
801590	801464	19768N	PARTICIPANT	\N	PRESENT	0
801591	801464	20034V	PARTICIPANT	\N	PRESENT	0
801592	801464	19782L	PARTICIPANT	\N	PRESENT	0
801593	801464	14187A	PRESIDENT	0	PRESENT	0
801594	801464	20038A	PARTICIPANT	\N	PRESENT	0
801595	801464	21086N	PARTICIPANT	\N	PRESENT	0
801596	801464	21092L	PARTICIPANT	\N	PRESENT	0
801597	801464	19695N	PARTICIPANT	\N	PRESENT	0
801598	801464	20054A	PARTICIPANT	\N	PRESENT	0
801599	801464	19631V	PARTICIPANT	\N	PRESENT	0
801600	801464	21034A	PARTICIPANT	\N	PRESENT	0
801601	801464	20104S	PARTICIPANT	\N	PRESENT	0
801602	801464	20066E	PARTICIPANT	\N	PRESENT	0
801603	801464	19575F	PARTICIPANT	\N	PRESENT	0
801604	801464	20286Q	PARTICIPANT	\N	PRESENT	0
801605	801464	08028W	PARTICIPANT	\N	PRESENT	0
801606	801464	21066J	PARTICIPANT	\N	EXCUSE	0
801607	801386	21050A	PARTICIPANT	\N	PRESENT	0
801608	801386	19631V	PARTICIPANT	\N	PRESENT	0
801609	801386	20054A	PARTICIPANT	\N	PRESENT	0
801610	801386	08056B	PARTICIPANT	\N	PRESENT	0
801612	801386	21048G	PARTICIPANT	\N	PRESENT	0
801613	801386	14267Y	PARTICIPANT	\N	PRESENT	0
801615	801386	08045X	PARTICIPANT	\N	PRESENT	0
801616	801386	19826F	PARTICIPANT	\N	PRESENT	0
801617	801386	19301E	PARTICIPANT	\N	PRESENT	0
801618	801386	21094N	PARTICIPANT	\N	PRESENT	0
801619	801386	20068G	PARTICIPANT	\N	PRESENT	0
801621	801386	14259Y	PARTICIPANT	\N	PRESENT	0
801622	801386	19347U	PARTICIPANT	\N	PRESENT	0
801623	801386	20058E	PARTICIPANT	\N	PRESENT	0
801624	801386	19713W	PARTICIPANT	\N	PRESENT	0
801626	801386	19649G	PARTICIPANT	\N	PRESENT	0
801629	801386	20098N	PARTICIPANT	\N	PRESENT	0
801630	801386	20044X	PARTICIPANT	\N	PRESENT	0
801631	801386	20286Q	PARTICIPANT	\N	PRESENT	0
801632	801386	21085M	PARTICIPANT	\N	PRESENT	0
801633	801386	21055F	PARTICIPANT	\N	PRESENT	0
801635	801386	20064C	PARTICIPANT	\N	PRESENT	0
801636	801386	14121F	PARTICIPANT	\N	PRESENT	0
801637	801386	21082J	PARTICIPANT	\N	PRESENT	0
801641	801386	21036C	PARTICIPANT	\N	PRESENT	0
801642	801386	21078N	PARTICIPANT	\N	PRESENT	0
801643	801386	04033B	PARTICIPANT	\N	PRESENT	0
801644	801386	21038E	PARTICIPANT	\N	PRESENT	0
801648	801386	21075K	PARTICIPANT	\N	PRESENT	0
801646	801386	20112S	PARTICIPANT	\N	PRESENT	0
801647	801386	20090E	PARTICIPANT	\N	PRESENT	0
801649	801386	20086J	PARTICIPANT	\N	PRESENT	0
801650	801386	21092L	PARTICIPANT	\N	PRESENT	0
801651	801386	14187A	PARTICIPANT	\N	PRESENT	0
801652	801386	14069U	PARTICIPANT	\N	PRESENT	0
801653	801386	21067K	PARTICIPANT	\N	PRESENT	0
801654	801386	20056C	PARTICIPANT	\N	PRESENT	0
801656	801386	19399H	PARTICIPANT	\N	PRESENT	0
801659	801386	11053K	PARTICIPANT	\N	PRESENT	0
801663	801386	19673G	PARTICIPANT	\N	PRESENT	0
801665	801386	20134Y	PARTICIPANT	\N	PRESENT	0
801666	801386	21033Y	PARTICIPANT	\N	PRESENT	0
801667	801386	21089R	PARTICIPANT	\N	PRESENT	0
801668	801386	19954N	PARTICIPANT	\N	PRESENT	0
801669	801386	21060C	PARTICIPANT	\N	PRESENT	0
801671	801386	14053L	PARTICIPANT	\N	PRESENT	0
801672	801386	20060X	PARTICIPANT	\N	PRESENT	0
808799	807221	19713W	PARTICIPANT	\N	PRESENT	0
808800	807221	20248J	PARTICIPANT	\N	PRESENT	0
808801	807221	15197G	PARTICIPANT	\N	PRESENT	0
808802	807221	17229F	PARTICIPANT	\N	PRESENT	0
808803	807221	20040T	PARTICIPANT	\N	PRESENT	0
808804	807221	21086N	PARTICIPANT	\N	PRESENT	0
808805	807221	19111A	PARTICIPANT	\N	PRESENT	0
808806	807221	17023S	PARTICIPANT	\N	PRESENT	0
808807	807221	19685L	PARTICIPANT	\N	PRESENT	0
808808	807221	14179A	PARTICIPANT	\N	PRESENT	0
808809	807221	19569H	PARTICIPANT	\N	PRESENT	0
808810	807221	19691J	PARTICIPANT	\N	PRESENT	0
808811	807221	14231L	PARTICIPANT	\N	PRESENT	0
808812	807221	20066E	PARTICIPANT	\N	PRESENT	0
808813	807221	20048C	PARTICIPANT	\N	PRESENT	0
808814	807221	14073Q	PARTICIPANT	\N	PRESENT	0
808815	807221	19611R	PARTICIPANT	\N	PRESENT	0
808816	807221	14205J	PARTICIPANT	\N	PRESENT	0
808817	807221	19699S	PARTICIPANT	\N	PRESENT	0
808818	807221	20036X	PARTICIPANT	\N	PRESENT	0
808819	807221	19826F	PARTICIPANT	\N	PRESENT	0
808820	807221	04070G	PARTICIPANT	\N	PRESENT	0
808821	807221	08009T	PARTICIPANT	\N	PRESENT	0
808822	807221	19745F	PARTICIPANT	\N	PRESENT	0
808823	807221	21038E	PARTICIPANT	\N	PRESENT	0
808824	807221	21064G	PARTICIPANT	\N	PRESENT	0
808825	807221	19619A	PARTICIPANT	\N	PRESENT	0
808826	807221	19760E	PARTICIPANT	\N	PRESENT	0
808827	807221	20134Y	PARTICIPANT	\N	PRESENT	0
808828	807221	21094N	PARTICIPANT	\N	PRESENT	0
808829	807221	19057M	PARTICIPANT	\N	PRESENT	0
808830	807221	20094J	PARTICIPANT	\N	PRESENT	0
808831	807221	19563B	PARTICIPANT	\N	PRESENT	0
808832	807221	14219Q	PARTICIPANT	\N	PRESENT	0
808833	807221	19735D	PARTICIPANT	\N	PRESENT	0
808834	807221	20122U	PARTICIPANT	\N	PRESENT	0
808835	807221	20052X	PARTICIPANT	\N	PRESENT	0
808836	807221	20082E	PARTICIPANT	\N	PRESENT	0
808837	807221	08045X	PARTICIPANT	\N	PRESENT	0
808838	807221	20286Q	PARTICIPANT	\N	PRESENT	0
808839	807221	20096L	PARTICIPANT	\N	PRESENT	0
808840	807221	20020P	PARTICIPANT	\N	PRESENT	0
808841	807221	20120S	PARTICIPANT	\N	PRESENT	0
808842	807221	05008E	PARTICIPANT	\N	PRESENT	0
808867	808866	19760E	PARTICIPANT	\N	PRESENT	0
808845	807221	20046A	PARTICIPANT	\N	PRESENT	0
808850	807221	21032X	PARTICIPANT	\N	PRESENT	0
808851	807221	11115U	PARTICIPANT	\N	PRESENT	0
808852	807221	21041Y	PARTICIPANT	\N	PRESENT	0
808853	807221	19489J	PARTICIPANT	\N	PRESENT	0
808854	807221	20018V	PARTICIPANT	\N	PRESENT	0
808855	807221	14327T	PARTICIPANT	\N	PRESENT	0
808868	808866	21050A	PARTICIPANT	\N	PRESENT	0
808869	808866	14053L	PARTICIPANT	\N	PRESENT	0
808870	808866	14195A	PARTICIPANT	\N	PRESENT	0
808871	808866	19693L	PARTICIPANT	\N	PRESENT	0
808872	808866	20140W	PARTICIPANT	\N	PRESENT	0
808873	808866	14217N	PARTICIPANT	\N	PRESENT	0
808874	808866	14215L	PARTICIPANT	\N	PRESENT	0
808875	808866	14281W	PARTICIPANT	\N	PRESENT	0
808876	808866	19691J	PARTICIPANT	\N	PRESENT	0
808877	808866	20034V	PARTICIPANT	\N	PRESENT	0
808878	808866	18193Q	PARTICIPANT	\N	PRESENT	0
808879	808866	21087P	PARTICIPANT	\N	PRESENT	0
808880	808866	19657G	PARTICIPANT	\N	PRESENT	0
808881	808866	14147R	PARTICIPANT	\N	PRESENT	0
808882	808866	14223L	PARTICIPANT	\N	PRESENT	0
808883	808866	14071N	PARTICIPANT	\N	PRESENT	0
808884	808866	19798U	PARTICIPANT	\N	PRESENT	0
808885	808866	19703U	PARTICIPANT	\N	PRESENT	0
808886	808866	19713W	PARTICIPANT	\N	PRESENT	0
808887	808866	20058E	PARTICIPANT	\N	PRESENT	0
809181	807222	86034E	PARTICIPANT	\N	PRESENT	0
809182	807222	14225N	PARTICIPANT	\N	PRESENT	0
809183	807222	14071N	PARTICIPANT	\N	PRESENT	0
809184	807222	14083S	PARTICIPANT	\N	PRESENT	0
809185	807222	20134Y	PARTICIPANT	\N	PRESENT	0
809186	807222	11040E	PARTICIPANT	\N	PRESENT	0
809245	807222	21058J	PARTICIPANT	\N	PRESENT	0
809188	807222	19349W	PARTICIPANT	\N	PRESENT	0
809189	807222	20080C	PARTICIPANT	\N	PRESENT	0
809215	807222	14073Q	PARTICIPANT	\N	PRESENT	0
809244	807222	21055F	PARTICIPANT	\N	PRESENT	0
809246	807222	20066E	PARTICIPANT	\N	PRESENT	0
809193	807222	20044X	PARTICIPANT	\N	PRESENT	0
809194	807222	20092G	PARTICIPANT	\N	PRESENT	0
809195	807222	21084L	PARTICIPANT	\N	PRESENT	0
809196	807222	20070A	PARTICIPANT	\N	PRESENT	0
809197	807222	20030R	PARTICIPANT	\N	PRESENT	0
809198	807222	14257W	PARTICIPANT	\N	PRESENT	0
809199	807222	18193Q	PARTICIPANT	\N	PRESENT	0
809200	807222	21079P	PARTICIPANT	\N	PRESENT	0
809201	807222	19565D	PARTICIPANT	\N	PRESENT	0
809202	807222	19687N	PARTICIPANT	\N	PRESENT	0
809203	807008	19681G	PARTICIPANT	\N	EXCUSE	0
809204	807008	11065P	PARTICIPANT	\N	EXCUSE	0
809205	807008	19387D	PARTICIPANT	\N	EXCUSE	0
809206	807222	20094J	PARTICIPANT	\N	PRESENT	0
809207	807008	21029D	PARTICIPANT	\N	EXCUSE	0
809208	807222	20018V	PARTICIPANT	\N	PRESENT	0
809209	807222	21033Y	PARTICIPANT	\N	PRESENT	0
809210	807222	19331L	PARTICIPANT	\N	PRESENT	0
809211	807222	21093M	PARTICIPANT	\N	PRESENT	0
809212	807222	21031W	PARTICIPANT	\N	PRESENT	0
809213	807222	19697Q	PARTICIPANT	\N	PRESENT	0
809214	807222	20128B	PARTICIPANT	\N	PRESENT	0
809216	807222	21076L	PARTICIPANT	\N	PRESENT	0
809217	807222	19573D	PARTICIPANT	\N	PRESENT	0
809218	807222	14275Y	PARTICIPANT	\N	PRESENT	0
809219	807222	20074E	PARTICIPANT	\N	PRESENT	0
809220	807222	14189C	PARTICIPANT	\N	PRESENT	0
809221	807222	20076G	PARTICIPANT	\N	PRESENT	0
809222	807222	10015M	PARTICIPANT	\N	PRESENT	0
809223	807222	19479G	PARTICIPANT	\N	PRESENT	0
809224	807222	01034P	PARTICIPANT	\N	PRESENT	0
809225	807222	08028W	PARTICIPANT	\N	PRESENT	0
809226	807222	11085T	PARTICIPANT	\N	PRESENT	0
809227	807222	04033B	PARTICIPANT	\N	PRESENT	0
809228	807222	14089Y	PARTICIPANT	\N	PRESENT	0
809229	807222	19667J	PARTICIPANT	\N	PRESENT	0
809230	807222	19685L	PARTICIPANT	\N	PRESENT	0
809231	807222	04092N	PARTICIPANT	\N	PRESENT	0
809232	807222	19421M	PARTICIPANT	\N	PRESENT	0
809233	807222	08034U	PARTICIPANT	\N	PRESENT	0
809234	807222	07029T	PARTICIPANT	\N	PRESENT	0
809235	807222	01058X	PARTICIPANT	\N	PRESENT	0
809236	807222	20022R	PARTICIPANT	\N	PRESENT	0
809237	807222	20172F	PARTICIPANT	\N	PRESENT	0
809238	807222	99004R	PARTICIPANT	\N	PRESENT	0
809239	807222	11048N	PARTICIPANT	\N	PRESENT	0
809240	807222	19711U	PARTICIPANT	\N	PRESENT	0
809241	807222	21039F	PARTICIPANT	\N	PRESENT	0
809242	807222	14033T	PARTICIPANT	\N	PRESENT	0
809243	807222	21068L	PARTICIPANT	\N	PRESENT	0
809247	807222	14030Q	PARTICIPANT	\N	PRESENT	0
809248	807222	21056G	PARTICIPANT	\N	PRESENT	0
809249	807222	20050V	PARTICIPANT	\N	PRESENT	0
809250	807222	19745F	PARTICIPANT	\N	PRESENT	0
809251	807222	19111A	PARTICIPANT	\N	PRESENT	0
809252	807222	19826F	PARTICIPANT	\N	PRESENT	0
809253	807222	21086N	PARTICIPANT	\N	PRESENT	0
809254	807222	14253S	PARTICIPANT	\N	PRESENT	0
809255	807222	21064G	PARTICIPANT	\N	PRESENT	0
809256	807222	19735D	PARTICIPANT	\N	PRESENT	0
809257	807222	20104S	PARTICIPANT	\N	PRESENT	0
809259	807222	20038A	PARTICIPANT	\N	PRESENT	0
809260	807222	14357A	PARTICIPANT	\N	PRESENT	0
809261	807222	20020P	PARTICIPANT	\N	PRESENT	0
809262	807222	14021P	PARTICIPANT	\N	PRESENT	0
809272	807222	08012N	PARTICIPANT	\N	PRESENT	0
809276	807222	08045X	PARTICIPANT	\N	PRESENT	0
809277	807222	20056C	PARTICIPANT	\N	PRESENT	0
809278	807222	21057H	PARTICIPANT	\N	PRESENT	0
809279	807222	17779H	PARTICIPANT	\N	PRESENT	0
809290	807222	20062A	PARTICIPANT	\N	PRESENT	0
809291	807222	17367Q	PARTICIPANT	\N	PRESENT	0
809292	807222	20144B	PARTICIPANT	\N	PRESENT	0
809293	807222	21070E	PARTICIPANT	\N	PRESENT	0
809294	807222	21063F	PARTICIPANT	\N	PRESENT	0
809295	807222	19533U	PARTICIPANT	\N	PRESENT	0
809296	807222	17965H	PARTICIPANT	\N	PRESENT	0
799561	799207	08028W	PARTICIPANT	\N	PRESENT	0
799562	799207	19563B	PARTICIPANT	\N	PRESENT	0
799563	799207	21050A	PARTICIPANT	\N	PRESENT	0
799564	799207	20028X	PARTICIPANT	\N	PRESENT	0
799565	799207	14329V	PARTICIPANT	\N	PRESENT	0
799566	799207	21052C	PARTICIPANT	\N	PRESENT	0
799567	799207	20030R	PARTICIPANT	\N	PRESENT	0
799568	799207	14038Y	PARTICIPANT	\N	PRESENT	0
799569	799207	20034V	PARTICIPANT	\N	PRESENT	0
799570	799207	21054E	PARTICIPANT	\N	PRESENT	0
799571	799207	14187A	PRESIDENT	0	PRESENT	0
799572	799207	20038A	PARTICIPANT	\N	PRESENT	0
799573	799207	21083K	PARTICIPANT	\N	PRESENT	0
799574	799207	21086N	PARTICIPANT	\N	PRESENT	0
799575	799207	20144B	PARTICIPANT	\N	PRESENT	0
799576	799207	19695N	PARTICIPANT	\N	PRESENT	0
799577	799207	21093M	PARTICIPANT	\N	PRESENT	0
799578	799207	11090Q	PARTICIPANT	\N	PRESENT	0
799579	799207	14033T	PARTICIPANT	\N	PRESENT	0
799580	799207	20054A	PARTICIPANT	\N	PRESENT	0
799581	799207	14205J	PARTICIPANT	\N	PRESENT	0
799582	799207	20060X	PARTICIPANT	\N	PRESENT	0
799583	799207	19507S	PARTICIPANT	\N	PRESENT	0
799584	799207	20066E	PARTICIPANT	\N	PRESENT	0
799585	799207	21066J	PARTICIPANT	\N	PRESENT	0
799586	799207	20286Q	PARTICIPANT	\N	PRESENT	0
799587	799207	14207L	PARTICIPANT	\N	PRESENT	0
799588	799207	14257W	PARTICIPANT	\N	PRESENT	0
799589	799207	20084G	PARTICIPANT	\N	PRESENT	0
799590	799207	19782L	PARTICIPANT	\N	EXCUSE	0
799595	797724	21057H	PARTICIPANT	\N	PRESENT	0
799596	797724	19673G	PARTICIPANT	\N	PRESENT	0
799597	797724	14231L	PARTICIPANT	\N	PRESENT	0
799598	797724	19447X	PARTICIPANT	\N	PRESENT	0
799599	797724	21043B	PARTICIPANT	\N	PRESENT	0
799600	797724	21044C	PARTICIPANT	\N	PRESENT	0
799601	797724	19489J	PARTICIPANT	\N	PRESENT	0
799602	797724	18207D	PARTICIPANT	\N	PRESENT	0
799603	797724	20108W	PARTICIPANT	\N	PRESENT	0
799604	797724	18231D	PARTICIPANT	\N	PRESENT	0
799605	797724	14147R	PARTICIPANT	\N	PRESENT	0
799606	797724	20114U	PARTICIPANT	\N	PRESENT	0
799607	797724	14215L	PARTICIPANT	\N	PRESENT	0
799608	797724	08018U	PRESIDENT	1	PRESENT	0
799609	797724	21030V	PARTICIPANT	\N	PRESENT	0
799610	797724	20074E	PARTICIPANT	\N	PRESENT	0
799611	797724	04045F	PARTICIPANT	\N	PRESENT	0
799612	797724	04047H	PRESIDENT	0	PRESENT	0
799613	797724	20098N	PARTICIPANT	\N	PRESENT	0
799614	797724	05008E	PARTICIPANT	\N	PRESENT	0
799615	797724	21056G	PARTICIPANT	\N	PRESENT	0
799616	797724	20110Q	PARTICIPANT	\N	PRESENT	0
799617	797724	21088Q	PARTICIPANT	\N	PRESENT	0
799618	797724	19111A	PARTICIPANT	\N	PRESENT	0
799619	797724	14151M	PARTICIPANT	\N	PRESENT	0
799620	797724	21038E	PARTICIPANT	\N	PRESENT	0
799621	797724	21095P	PARTICIPANT	\N	PRESENT	0
799622	797724	20022R	PARTICIPANT	\N	PRESENT	0
799623	797724	14259Y	PARTICIPANT	\N	PRESENT	0
799624	797724	11072N	PARTICIPANT	\N	PRESENT	0
799625	797724	14053L	PARTICIPANT	\N	PRESENT	0
799626	797724	19649G	PARTICIPANT	\N	PRESENT	0
799627	797724	14111D	PARTICIPANT	\N	PRESENT	0
799628	797724	20036X	PARTICIPANT	\N	PRESENT	0
799629	797724	14189C	PARTICIPANT	\N	PRESENT	0
799630	797724	21076L	PARTICIPANT	\N	PRESENT	0
799631	797724	21040X	PARTICIPANT	\N	PRESENT	0
799632	797724	14089Y	PARTICIPANT	\N	PRESENT	0
799633	797724	20266L	PARTICIPANT	\N	PRESENT	0
799634	797724	14069U	PARTICIPANT	\N	PRESENT	0
799635	797724	11085T	PARTICIPANT	\N	PRESENT	0
799636	797724	19749K	PARTICIPANT	\N	PRESENT	0
799738	799207	19707Y	PARTICIPANT	\N	PRESENT	0
799739	799207	21075K	PARTICIPANT	\N	PRESENT	0
799740	799207	21092L	PARTICIPANT	\N	PRESENT	0
799759	797794	86034E	PARTICIPANT	\N	PRESENT	0
799762	797794	08060W	PARTICIPANT	\N	PRESENT	0
799763	797794	14281W	PARTICIPANT	\N	PRESENT	0
799764	797794	14109K	PARTICIPANT	\N	PRESENT	0
799765	797794	21057H	PARTICIPANT	\N	PRESENT	0
799766	797794	21045D	PARTICIPANT	\N	PRESENT	0
799767	797794	21037D	PARTICIPANT	\N	PRESENT	0
799768	797794	21087P	PARTICIPANT	\N	PRESENT	0
799769	797794	21052C	PARTICIPANT	\N	PRESENT	0
799770	797794	21086N	PARTICIPANT	\N	PRESENT	0
799771	797794	20052X	PARTICIPANT	\N	PRESENT	0
799772	797794	14073Q	PARTICIPANT	\N	PRESENT	0
799773	797794	21083K	PARTICIPANT	\N	PRESENT	0
799774	797794	21070E	PARTICIPANT	\N	PRESENT	0
799775	797794	21056G	PARTICIPANT	\N	PRESENT	0
799776	797794	20046A	PARTICIPANT	\N	PRESENT	0
799777	797794	14221J	PARTICIPANT	\N	PRESENT	0
799778	797794	19619A	PARTICIPANT	\N	PRESENT	0
799780	797794	21073H	PARTICIPANT	\N	PRESENT	0
799781	797794	19349W	PARTICIPANT	\N	PRESENT	0
800466	797973	15197G	PARTICIPANT	\N	EXCUSE	0
800467	797973	19387D	PARTICIPANT	\N	EXCUSE	0
800468	797974	15197G	PARTICIPANT	\N	EXCUSE	0
800469	797974	19387D	PARTICIPANT	\N	EXCUSE	0
801126	801120	14215L	PARTICIPANT	\N	PRESENT	0
801176	801144	14255U	PARTICIPANT	\N	EXCUSE	0
801177	801145	14255U	PARTICIPANT	\N	EXCUSE	0
801178	801146	14255U	PARTICIPANT	\N	EXCUSE	0
801180	801179	20032T	PARTICIPANT	\N	PRESENT	0
801181	801179	20076G	PARTICIPANT	\N	PRESENT	0
801182	801179	21084L	PARTICIPANT	\N	PRESENT	0
801183	801179	19575F	PARTICIPANT	\N	PRESENT	0
801184	801179	14069U	PARTICIPANT	\N	PRESENT	0
801185	801179	14083S	PARTICIPANT	\N	PRESENT	0
801186	801179	14038Y	PARTICIPANT	\N	PRESENT	0
801187	801179	20144B	PARTICIPANT	\N	PRESENT	0
801188	801179	21067K	PARTICIPANT	\N	PRESENT	0
801189	801179	21062E	PARTICIPANT	\N	PRESENT	0
801190	801179	14033T	PARTICIPANT	\N	PRESENT	0
801191	801179	20066E	PARTICIPANT	\N	PRESENT	0
801192	801179	14031R	PARTICIPANT	\N	PRESENT	0
801193	801179	19563B	PARTICIPANT	\N	PRESENT	0
801194	801179	20018V	PARTICIPANT	\N	PRESENT	0
801195	801179	21056G	PARTICIPANT	\N	PRESENT	0
801197	801196	14231L	PARTICIPANT	\N	PRESENT	0
801199	801198	20074E	PARTICIPANT	\N	PRESENT	0
801201	801200	19673G	PARTICIPANT	\N	PRESENT	0
801202	801200	14231L	PARTICIPANT	\N	PRESENT	0
801204	801203	19673G	PARTICIPANT	\N	PRESENT	0
801205	801203	14231L	PARTICIPANT	\N	PRESENT	0
801206	801203	19489J	PARTICIPANT	\N	PRESENT	0
801208	801207	19673G	PARTICIPANT	\N	PRESENT	0
801209	801207	14231L	PARTICIPANT	\N	PRESENT	0
801210	801207	19489J	PARTICIPANT	\N	PRESENT	0
801212	801211	14231L	PARTICIPANT	\N	PRESENT	0
801213	801211	19673G	PARTICIPANT	\N	PRESENT	0
801214	801211	19489J	PARTICIPANT	\N	PRESENT	0
801234	801233	21067K	PARTICIPANT	\N	PRESENT	0
801236	801235	20252E	PARTICIPANT	\N	PRESENT	0
801240	801238	19679N	PARTICIPANT	\N	PRESENT	0
801241	801238	21046E	PARTICIPANT	\N	PRESENT	0
801242	801238	18193Q	PARTICIPANT	\N	PRESENT	0
801244	801243	21046E	PARTICIPANT	\N	PRESENT	0
801245	801243	19679N	PARTICIPANT	\N	PRESENT	0
801246	801243	18193Q	PARTICIPANT	\N	PRESENT	0
801248	801247	21046E	PARTICIPANT	\N	PRESENT	0
801249	801247	19679N	PARTICIPANT	\N	PRESENT	0
801250	801247	18193Q	PARTICIPANT	\N	PRESENT	0
802129	801440	20086J	PARTICIPANT	\N	PRESENT	0
802130	801440	14331P	PARTICIPANT	\N	PRESENT	0
802131	801440	11048N	PARTICIPANT	\N	PRESENT	0
802132	801440	14133K	PARTICIPANT	\N	PRESENT	0
802133	801440	08034U	PARTICIPANT	\N	PRESENT	0
802134	801440	19399H	PARTICIPANT	\N	PRESENT	0
802135	801440	14225N	PRESIDENT	0	PRESENT	0
802136	801440	07004J	PARTICIPANT	\N	PRESENT	0
802137	801440	14193X	PARTICIPANT	\N	PRESENT	0
802138	801440	14121F	PARTICIPANT	\N	PRESENT	0
802139	801440	20116W	PARTICIPANT	\N	PRESENT	0
802140	801440	14253S	PARTICIPANT	\N	PRESENT	0
802150	801440	07029T	PARTICIPANT	\N	PRESENT	0
802151	801440	20024T	PARTICIPANT	\N	PRESENT	0
802164	801440	20080C	PARTICIPANT	\N	PRESENT	0
802165	801440	19667J	PARTICIPANT	\N	PRESENT	0
802166	801440	11070L	PARTICIPANT	\N	PRESENT	0
813306	813305	14038Y	PARTICIPANT	\N	PRESENT	0
813307	813305	18231D	PARTICIPANT	\N	PRESENT	0
813308	813302	14038Y	PARTICIPANT	\N	PRESENT	0
813309	813302	18231D	PARTICIPANT	\N	PRESENT	0
813311	813310	14038Y	PARTICIPANT	\N	PRESENT	0
813312	813303	14038Y	PARTICIPANT	\N	PRESENT	0
813313	813303	18231D	PARTICIPANT	\N	PRESENT	0
815862	815854	21039F	PARTICIPANT	\N	PRESENT	0
815863	815854	20122U	PARTICIPANT	\N	PRESENT	0
815864	815854	21077M	PARTICIPANT	\N	PRESENT	0
815865	815854	21084L	PARTICIPANT	\N	EXCUSE	0
815866	815854	21086N	PARTICIPANT	\N	EXCUSE	0
815867	815854	95041E	PARTICIPANT	\N	EXCUSE	0
815868	815854	19611R	PARTICIPANT	\N	EXCUSE	0
815869	815854	19866P	PARTICIPANT	\N	EXCUSE	0
815878	815875	19760E	PARTICIPANT	\N	PRESENT	0
815879	815875	14042U	PARTICIPANT	\N	PRESENT	0
815880	815875	17965H	PARTICIPANT	\N	PRESENT	1
815881	815876	19760E	PARTICIPANT	\N	PRESENT	0
815882	815876	14042U	PARTICIPANT	\N	PRESENT	0
815883	815876	20130U	PARTICIPANT	\N	PRESENT	1
815884	815877	14042U	PARTICIPANT	\N	PRESENT	0
815885	815877	20130U	PARTICIPANT	\N	PRESENT	1
815886	813357	21084L	PARTICIPANT	\N	EXCUSE	0
815887	813357	20248J	PARTICIPANT	\N	PRESENT	0
815888	813357	08034U	PARTICIPANT	\N	PRESENT	0
815889	813357	20038A	PARTICIPANT	\N	PRESENT	0
815890	813357	14031R	PARTICIPANT	\N	PRESENT	0
815891	813357	19413M	PARTICIPANT	\N	PRESENT	0
815892	813357	99004R	PRESIDENT	0	PRESENT	0
815893	813357	21093M	PARTICIPANT	\N	PRESENT	0
815894	813357	21090J	PARTICIPANT	\N	PRESENT	0
815895	813357	17023S	PARTICIPANT	\N	EXCUSE	0
815899	813357	21031W	PARTICIPANT	\N	PRESENT	0
815900	813357	21056G	PARTICIPANT	\N	PRESENT	0
815911	815910	11074Q	PARTICIPANT	\N	PRESENT	0
815912	815910	08045X	PARTICIPANT	\N	PRESENT	0
815918	813243	20056C	PARTICIPANT	\N	PRESENT	0
815919	813243	14189C	PARTICIPANT	\N	PRESENT	0
815923	815922	07004J	PARTICIPANT	\N	PRESENT	0
815924	815922	08034U	PRESIDENT	0	PRESENT	0
815925	815922	14059S	PARTICIPANT	\N	PRESENT	0
815926	815922	21073H	PARTICIPANT	\N	PRESENT	0
815927	815922	19745F	PARTICIPANT	\N	PRESENT	0
815928	815922	14229S	PARTICIPANT	\N	PRESENT	0
815929	815922	19669L	PARTICIPANT	\N	PRESENT	0
815941	815922	19575F	PARTICIPANT	\N	EXCUSE	0
815942	815922	21041Y	PARTICIPANT	\N	EXCUSE	0
815943	815922	14225N	PARTICIPANT	\N	EXCUSE	0
815947	815946	19575F	PARTICIPANT	\N	PRESENT	0
815948	815946	20138D	PARTICIPANT	\N	PRESENT	0
815949	815946	21044C	PARTICIPANT	\N	PRESENT	0
815950	815946	14237S	PARTICIPANT	\N	PRESENT	0
815951	815946	19349W	PARTICIPANT	\N	PRESENT	0
815952	815946	19347U	PARTICIPANT	\N	PRESENT	0
815954	815953	21046E	PARTICIPANT	\N	PRESENT	0
815955	815953	14357A	PARTICIPANT	\N	PRESENT	0
815956	815953	08015R	PARTICIPANT	\N	PRESENT	0
815957	815953	08034U	PARTICIPANT	\N	PRESENT	0
815958	815953	14147R	PARTICIPANT	\N	PRESENT	0
815959	815953	21087P	PARTICIPANT	\N	PRESENT	0
815961	815960	19611R	PARTICIPANT	\N	PRESENT	0
815962	815960	20264J	PARTICIPANT	\N	PRESENT	0
815963	815960	20026V	PARTICIPANT	\N	PRESENT	0
815964	815960	20058E	PARTICIPANT	\N	PRESENT	0
815965	815960	14109K	PARTICIPANT	\N	PRESENT	0
815966	815960	19697Q	PARTICIPANT	\N	PRESENT	0
815967	815960	20180F	PARTICIPANT	\N	PRESENT	0
815968	815960	20052X	PARTICIPANT	\N	PRESENT	0
815969	815960	20102Q	PARTICIPANT	\N	PRESENT	0
815970	815960	19693L	PARTICIPANT	\N	PRESENT	0
815971	815960	21037D	PARTICIPANT	\N	PRESENT	0
816042	816041	14237S	PARTICIPANT	\N	PRESENT	0
816043	816041	14267Y	PARTICIPANT	\N	PRESENT	0
816044	816041	14073Q	PARTICIPANT	\N	PRESENT	0
816045	816041	20052X	PARTICIPANT	\N	PRESENT	0
816046	816041	14219Q	PARTICIPANT	\N	PRESENT	0
816047	816041	14111D	PARTICIPANT	\N	PRESENT	0
816048	816041	19826F	PARTICIPANT	\N	PRESENT	0
816050	816049	14111D	PARTICIPANT	\N	PRESENT	0
816051	816049	14237S	PARTICIPANT	\N	PRESENT	0
816065	816064	19711U	PARTICIPANT	\N	PRESENT	0
816067	816066	19553Y	PARTICIPANT	\N	PRESENT	0
816068	816066	20066E	PRESIDENT	0	PRESENT	0
816069	816066	14147R	PARTICIPANT	\N	PRESENT	0
816070	816066	14030Q	PARTICIPANT	\N	PRESENT	0
816071	816066	19723Y	PARTICIPANT	\N	PRESENT	0
816072	816066	18193Q	PARTICIPANT	\N	PRESENT	0
816073	816066	17965H	PARTICIPANT	\N	PRESENT	0
816074	816066	21064G	PARTICIPANT	\N	PRESENT	0
816075	816061	86034E	PARTICIPANT	\N	PRESENT	0
816076	815870	21044C	PARTICIPANT	\N	PRESENT	0
816077	815870	20074E	PARTICIPANT	\N	PRESENT	0
816078	815870	21057H	PARTICIPANT	\N	PRESENT	0
816079	815870	21038E	PARTICIPANT	\N	PRESENT	0
816080	815870	04047H	PRESIDENT	0	PRESENT	0
816081	815870	19447X	PARTICIPANT	\N	PRESENT	0
816082	815870	10015M	PARTICIPANT	\N	PRESENT	0
816084	815870	14053L	PARTICIPANT	\N	PRESENT	0
816085	815870	14147R	PARTICIPANT	\N	PRESENT	0
816086	815870	05008E	PARTICIPANT	\N	PRESENT	0
816087	816083	14001X	PARTICIPANT	\N	PRESENT	0
816088	816061	20034V	PARTICIPANT	\N	PRESENT	0
816089	816061	21055F	PARTICIPANT	\N	PRESENT	0
816090	815870	11072N	PARTICIPANT	\N	PRESENT	0
816091	816083	14069U	PARTICIPANT	\N	PRESENT	0
816092	816083	20042V	PARTICIPANT	\N	PRESENT	0
816093	816083	20114U	PARTICIPANT	\N	PRESENT	0
816094	816083	21057H	PARTICIPANT	\N	PRESENT	0
816095	816083	14329V	PARTICIPANT	\N	PRESENT	0
816096	816083	07033P	PARTICIPANT	\N	PRESENT	0
816097	816083	20074E	PARTICIPANT	\N	PRESENT	0
816098	816083	20120S	PARTICIPANT	\N	PRESENT	0
816099	816083	19681G	PARTICIPANT	\N	PRESENT	0
816100	816061	20136B	PARTICIPANT	\N	PRESENT	0
816101	815870	19585H	PARTICIPANT	\N	EXCUSE	0
816102	816061	19735D	PARTICIPANT	\N	PRESENT	0
816103	816061	21057H	PARTICIPANT	\N	PRESENT	0
816104	816061	19507S	PARTICIPANT	\N	PRESENT	0
816105	816061	14053L	PARTICIPANT	\N	PRESENT	0
816106	816061	20074E	PARTICIPANT	\N	PRESENT	0
816107	816061	21039F	PARTICIPANT	\N	PRESENT	0
816108	816061	14191V	PARTICIPANT	\N	PRESENT	0
816109	816061	18083K	PARTICIPANT	\N	PRESENT	0
816110	816061	14038Y	PARTICIPANT	\N	PRESENT	0
816111	816061	19673G	PARTICIPANT	\N	PRESENT	0
816112	816061	21040X	PARTICIPANT	\N	PRESENT	0
816113	816061	21076L	PARTICIPANT	\N	PRESENT	0
816114	816061	12016W	PARTICIPANT	\N	PRESENT	0
816115	816061	19866P	PARTICIPANT	\N	PRESENT	0
816116	816061	14221J	PARTICIPANT	\N	PRESENT	0
816117	816061	19421M	PARTICIPANT	\N	PRESENT	0
816118	816061	10015M	PARTICIPANT	\N	PRESENT	0
816119	816061	14205J	PARTICIPANT	\N	PRESENT	0
816124	816061	19367Y	PARTICIPANT	\N	PRESENT	0
816125	816061	19703U	PARTICIPANT	\N	PRESENT	0
816126	816061	19691J	PARTICIPANT	\N	PRESENT	0
816127	816061	14097Y	PARTICIPANT	\N	PRESENT	0
816128	816061	19611R	PARTICIPANT	\N	PRESENT	0
816129	816061	21080G	PARTICIPANT	\N	PRESENT	0
816130	816061	17229F	PARTICIPANT	\N	PRESENT	0
816131	816061	18231D	PARTICIPANT	\N	PRESENT	0
816132	816061	19669L	PARTICIPANT	\N	PRESENT	0
816133	816061	14257W	PARTICIPANT	\N	PRESENT	0
816134	816061	11072N	PARTICIPANT	\N	PRESENT	0
816135	816061	20150Y	PARTICIPANT	\N	PRESENT	0
816136	816061	08073C	PARTICIPANT	\N	PRESENT	0
816137	816061	05008E	PARTICIPANT	\N	PRESENT	0
816138	816061	04047H	PARTICIPANT	\N	PRESENT	0
816139	816061	21083K	PARTICIPANT	\N	PRESENT	0
816140	816061	20102Q	PARTICIPANT	\N	PRESENT	0
816141	816061	21056G	PARTICIPANT	\N	PRESENT	0
816142	816061	18207D	PARTICIPANT	\N	PRESENT	0
816143	816061	14001X	PARTICIPANT	\N	PRESENT	0
816144	816061	19760E	PARTICIPANT	\N	PRESENT	0
816145	816061	19758L	PARTICIPANT	\N	PRESENT	0
816146	816061	01058X	PARTICIPANT	\N	PRESENT	0
816147	816061	11040E	PARTICIPANT	\N	PRESENT	0
816148	816061	21075K	PARTICIPANT	\N	PRESENT	0
816149	816061	19593H	PARTICIPANT	\N	PRESENT	0
816150	816061	20076G	PARTICIPANT	\N	PRESENT	0
801762	801387	20074E	PARTICIPANT	\N	PRESENT	0
801763	801387	21094N	PARTICIPANT	\N	PRESENT	0
801764	801387	20142Y	PARTICIPANT	\N	PRESENT	0
801765	801387	21092L	PARTICIPANT	\N	PRESENT	0
801766	801387	21048G	PARTICIPANT	\N	PRESENT	0
801767	801387	14187A	PARTICIPANT	\N	PRESENT	0
801768	801387	19295A	PARTICIPANT	\N	PRESENT	0
801769	801387	21075K	PARTICIPANT	\N	PRESENT	0
801770	801387	19695N	PARTICIPANT	\N	PRESENT	0
801771	801387	20046A	PARTICIPANT	\N	PRESENT	0
801772	801387	20112S	PARTICIPANT	\N	PRESENT	0
801773	801387	08028W	PARTICIPANT	\N	PRESENT	0
801774	801387	14069U	PARTICIPANT	\N	PRESENT	0
801775	801387	14257W	PARTICIPANT	\N	PRESENT	0
801776	801387	14121F	PARTICIPANT	\N	PRESENT	0
801777	801387	20064C	PARTICIPANT	\N	PRESENT	0
801778	801387	19673G	PARTICIPANT	\N	PRESENT	0
801779	801387	18231D	PARTICIPANT	\N	PRESENT	0
801780	801387	18207D	PARTICIPANT	\N	PRESENT	0
801781	801387	19631V	PARTICIPANT	\N	PRESENT	0
801782	801387	21089R	PARTICIPANT	\N	PRESENT	0
801783	801387	20024T	PARTICIPANT	\N	PRESENT	0
801784	801387	20134Y	PARTICIPANT	\N	PRESENT	0
801786	801387	20108W	PARTICIPANT	\N	PRESENT	0
801787	801387	20128B	PARTICIPANT	\N	PRESENT	0
801788	801387	19413M	PARTICIPANT	\N	PRESENT	0
801789	801387	21033Y	PARTICIPANT	\N	PRESENT	0
801791	801387	21052C	PARTICIPANT	\N	PRESENT	0
801792	801387	19301E	PARTICIPANT	\N	PRESENT	0
801793	801387	14219Q	PARTICIPANT	\N	PRESENT	0
801794	801387	14195A	PARTICIPANT	\N	PRESENT	0
801795	801387	19649G	PARTICIPANT	\N	PRESENT	0
801796	801387	20072C	PARTICIPANT	\N	PRESENT	0
801797	801387	19629C	PARTICIPANT	\N	PRESENT	0
801798	801387	21078N	PARTICIPANT	\N	PRESENT	0
801799	801387	21050A	PARTICIPANT	\N	PRESENT	0
801800	801387	20090E	PARTICIPANT	\N	PRESENT	0
801801	801387	19954N	PARTICIPANT	\N	PRESENT	0
801802	801387	18083K	PARTICIPANT	\N	PRESENT	0
801803	801387	14217N	PARTICIPANT	\N	PRESENT	0
801804	801387	20068G	PARTICIPANT	\N	PRESENT	0
801805	801387	14073Q	PARTICIPANT	\N	PRESENT	0
801806	801387	14038Y	PARTICIPANT	\N	PRESENT	0
801808	801387	20034V	PARTICIPANT	\N	PRESENT	0
801809	801387	21058J	PARTICIPANT	\N	PRESENT	0
801810	801387	20056C	PARTICIPANT	\N	PRESENT	0
801811	801387	19383Y	PARTICIPANT	\N	PRESENT	0
801813	801387	20038A	PARTICIPANT	\N	PRESENT	0
801822	801387	21088Q	PARTICIPANT	\N	PRESENT	0
801823	801387	19735D	PARTICIPANT	\N	PRESENT	0
801824	801387	14021P	PARTICIPANT	\N	PRESENT	0
801825	801387	19782L	PARTICIPANT	\N	PRESENT	0
801828	801387	21077M	PARTICIPANT	\N	PRESENT	0
801829	801387	21082J	PARTICIPANT	\N	PRESENT	0
801830	801387	21042A	PARTICIPANT	\N	PRESENT	0
801831	801387	21083K	PARTICIPANT	\N	PRESENT	0
801833	801387	20092G	PARTICIPANT	\N	PRESENT	0
801847	801387	14191V	PARTICIPANT	\N	PRESENT	0
801851	801387	21059K	PARTICIPANT	\N	PRESENT	0
801852	801387	21086N	PARTICIPANT	\N	PRESENT	0
801853	801387	14259Y	PARTICIPANT	\N	PRESENT	0
801854	801387	14031R	PARTICIPANT	\N	PRESENT	0
801855	801387	21063F	PARTICIPANT	\N	PRESENT	0
801858	801387	11048N	PARTICIPANT	\N	PRESENT	0
801859	801387	11043H	PARTICIPANT	\N	PRESENT	0
803953	803914	21056G	PARTICIPANT	\N	PRESENT	0
803954	803914	20248J	PARTICIPANT	\N	PRESENT	0
803955	803914	19782L	PARTICIPANT	\N	PRESENT	0
803956	803914	08034U	PARTICIPANT	\N	PRESENT	0
803957	803914	20038A	PARTICIPANT	\N	PRESENT	0
803958	803914	21090J	PARTICIPANT	\N	PRESENT	0
803959	803914	99004R	PARTICIPANT	\N	PRESENT	0
803960	803914	21093M	PARTICIPANT	\N	PRESENT	0
803961	803914	21050A	PARTICIPANT	\N	PRESENT	0
803962	803914	21084L	PARTICIPANT	\N	EXCUSE	0
803963	803914	21031W	PARTICIPANT	\N	EXCUSE	0
803964	803914	14031R	PARTICIPANT	\N	EXCUSE	0
806318	803941	14071N	PRESIDENT	0	PRESENT	0
806319	803941	19679N	PARTICIPANT	\N	PRESENT	0
806323	803941	14213J	PARTICIPANT	\N	PRESENT	0
801760	801387	14179A	PARTICIPANT	\N	PRESENT	0
801761	801387	20286Q	PARTICIPANT	\N	PRESENT	0
806325	803941	19760E	PARTICIPANT	\N	PRESENT	0
806328	803941	20248J	PARTICIPANT	\N	PRESENT	0
806329	803941	21071F	PARTICIPANT	\N	PRESENT	0
806331	803941	14281W	PARTICIPANT	\N	PRESENT	0
806332	803941	21045D	PARTICIPANT	\N	PRESENT	0
806334	803941	19591F	PARTICIPANT	\N	PRESENT	0
806336	803941	19657G	PARTICIPANT	\N	PRESENT	0
806340	803941	19798U	PARTICIPANT	\N	PRESENT	0
806351	803941	21097R	PARTICIPANT	\N	PRESENT	0
806352	803941	18193Q	PARTICIPANT	\N	PRESENT	0
806353	803941	17779H	PARTICIPANT	\N	PRESENT	0
806354	803941	20096L	PARTICIPANT	\N	PRESENT	0
806355	803941	21081H	PARTICIPANT	\N	PRESENT	0
806361	803941	11045K	PARTICIPANT	\N	PRESENT	0
806364	803941	01034P	PARTICIPANT	\N	PRESENT	0
806371	803941	19691J	PARTICIPANT	\N	PRESENT	0
806372	803941	14026U	PARTICIPANT	\N	PRESENT	0
806386	803941	19713W	PARTICIPANT	\N	PRESENT	0
806387	803941	14217N	PARTICIPANT	\N	PRESENT	0
806388	803941	14042U	PARTICIPANT	\N	PRESENT	0
806390	803941	20130U	PARTICIPANT	\N	EXCUSE	0
807219	807218	19679N	PARTICIPANT	\N	PRESENT	0
807220	807218	21046E	PARTICIPANT	\N	PRESENT	0
807233	807232	11074Q	PARTICIPANT	\N	PRESENT	0
807234	807232	19349W	PARTICIPANT	\N	PRESENT	0
807236	807235	11074Q	PARTICIPANT	\N	PRESENT	0
807237	807235	19349W	PARTICIPANT	\N	PRESENT	0
807243	807242	19695N	PARTICIPANT	\N	PRESENT	0
807244	807242	11090Q	PARTICIPANT	\N	PRESENT	0
807275	807271	19695N	PARTICIPANT	\N	PRESENT	0
807995	807326	19749K	PARTICIPANT	\N	PRESENT	0
807999	807326	19413M	PARTICIPANT	\N	PRESENT	0
808000	807326	20070A	PARTICIPANT	\N	PRESENT	0
808001	807326	14231L	PARTICIPANT	\N	PRESENT	0
808002	807326	14083S	PARTICIPANT	\N	PRESENT	0
808005	807326	21083K	PARTICIPANT	\N	PRESENT	0
808008	807326	21086N	PARTICIPANT	\N	PRESENT	0
808009	807326	14071N	PARTICIPANT	\N	PRESENT	0
808010	807326	21058J	PARTICIPANT	\N	PRESENT	0
808061	807326	20136B	PARTICIPANT	\N	PRESENT	0
808019	807326	20058E	PARTICIPANT	\N	PRESENT	0
808038	807326	19673G	PARTICIPANT	\N	PRESENT	0
808059	807326	19545Y	PARTICIPANT	\N	PRESENT	0
808062	807326	17367Q	PARTICIPANT	\N	PRESENT	0
808297	807771	21079P	PARTICIPANT	\N	PRESENT	0
810104	810103	14329V	PARTICIPANT	\N	PRESENT	0
810105	810103	14187A	PARTICIPANT	\N	PRESENT	0
810106	810103	20286Q	PARTICIPANT	\N	PRESENT	0
810107	810103	19631V	PARTICIPANT	\N	PRESENT	0
810108	810103	18207D	PARTICIPANT	\N	PRESENT	0
810109	810103	21033Y	PARTICIPANT	\N	PRESENT	0
810110	810103	21050A	PARTICIPANT	\N	PRESENT	0
810111	810103	19647E	PARTICIPANT	\N	PRESENT	0
810112	810103	21075K	PARTICIPANT	\N	PRESENT	0
810113	810103	21070E	PARTICIPANT	\N	PRESENT	0
810364	810363	18395Y	PARTICIPANT	\N	PRESENT	0
810365	810363	19709B	PARTICIPANT	\N	PRESENT	0
810367	810366	19709B	PARTICIPANT	\N	PRESENT	0
810368	810366	18395Y	PARTICIPANT	\N	PRESENT	0
810374	810373	19709B	PARTICIPANT	\N	PRESENT	0
810375	810373	18395Y	PARTICIPANT	\N	PRESENT	0
810398	810394	08011M	PARTICIPANT	\N	PRESENT	0
810405	810404	08011M	PARTICIPANT	\N	PRESENT	0
810407	810406	11048N	PARTICIPANT	\N	PRESENT	0
810420	810409	11048N	PARTICIPANT	\N	PRESENT	0
810423	810422	21090J	PARTICIPANT	\N	PRESENT	0
810424	810422	08009T	PARTICIPANT	\N	PRESENT	0
810426	810425	21090J	PARTICIPANT	\N	PRESENT	0
810427	810425	08009T	PARTICIPANT	\N	PRESENT	0
810430	810429	11053K	PARTICIPANT	\N	PRESENT	0
810438	810437	11053K	PARTICIPANT	\N	PRESENT	0
810442	810441	11053K	PARTICIPANT	\N	PRESENT	0
810445	810444	11053K	PARTICIPANT	\N	PRESENT	0
810447	810446	21090J	PARTICIPANT	\N	PRESENT	0
810448	810446	08009T	PARTICIPANT	\N	PRESENT	0
810450	810449	11053K	PARTICIPANT	\N	PRESENT	0
810467	810461	11048N	PARTICIPANT	\N	PRESENT	0
810469	810468	11048N	PARTICIPANT	\N	PRESENT	0
810471	810470	11048N	PARTICIPANT	\N	PRESENT	0
809297	807222	19629C	PARTICIPANT	\N	PRESENT	0
809298	807222	19399H	PARTICIPANT	\N	PRESENT	0
809299	807222	20068G	PARTICIPANT	\N	PRESENT	0
809300	807222	11043H	PARTICIPANT	\N	PRESENT	0
809301	807222	20048C	PARTICIPANT	\N	PRESENT	0
809302	807222	21065H	PARTICIPANT	\N	PRESENT	0
809303	807222	21075K	PARTICIPANT	\N	PRESENT	0
809304	807222	18231D	PARTICIPANT	\N	PRESENT	0
809308	807222	21035B	PARTICIPANT	\N	PRESENT	0
809309	807222	20264J	PARTICIPANT	\N	PRESENT	0
809314	807222	20084G	PARTICIPANT	\N	PRESENT	0
809317	807222	14147R	PARTICIPANT	\N	PRESENT	0
809318	807222	19335Q	PARTICIPANT	\N	PRESENT	0
809325	807222	20034V	PARTICIPANT	\N	PRESENT	0
809326	807222	14069U	PARTICIPANT	\N	PRESENT	0
809334	807222	14195A	PARTICIPANT	\N	PRESENT	0
809339	807222	14259Y	PARTICIPANT	\N	PRESENT	0
809340	807222	20032T	PARTICIPANT	\N	PRESENT	0
809341	807222	20136B	PARTICIPANT	\N	PRESENT	0
809342	807222	19683J	PARTICIPANT	\N	PRESENT	0
809343	807222	20042V	PARTICIPANT	\N	PRESENT	0
809344	807222	21074J	PARTICIPANT	\N	PRESENT	0
809345	807222	21061D	PARTICIPANT	\N	PRESENT	0
809346	807222	14267Y	PARTICIPANT	\N	PRESENT	0
809351	807222	21085M	PARTICIPANT	\N	PRESENT	0
809352	807222	21069M	PARTICIPANT	\N	PRESENT	0
809353	807222	20126Y	PARTICIPANT	\N	PRESENT	0
809354	807222	14059S	PARTICIPANT	\N	PRESENT	0
809355	807222	19798U	PARTICIPANT	\N	PRESENT	0
809356	807222	20116W	PARTICIPANT	\N	PRESENT	0
809357	807222	20026V	PARTICIPANT	\N	PRESENT	0
809358	807222	14191V	PARTICIPANT	\N	PRESENT	0
809360	807222	21073H	PARTICIPANT	\N	PRESENT	0
809361	807222	14281W	PARTICIPANT	\N	PRESENT	0
809362	807222	19295A	PARTICIPANT	\N	PRESENT	0
809363	807222	14215L	PARTICIPANT	\N	PRESENT	0
809364	807222	19723Y	PARTICIPANT	\N	PRESENT	0
809365	807222	14097Y	PARTICIPANT	\N	PRESENT	0
809366	807222	11072N	PARTICIPANT	\N	PRESENT	0
809367	807222	04045F	PARTICIPANT	\N	PRESENT	0
809368	807222	20100N	PARTICIPANT	\N	PRESENT	0
809369	807222	21094N	PARTICIPANT	\N	PRESENT	0
809370	807222	19347U	PARTICIPANT	\N	PRESENT	0
809371	807222	19669L	PARTICIPANT	\N	PRESENT	0
809372	807222	17023S	PARTICIPANT	\N	PRESENT	0
809464	807225	21033Y	PARTICIPANT	\N	PRESENT	0
809465	807225	21094N	PARTICIPANT	\N	PRESENT	0
809466	807225	19347U	PARTICIPANT	\N	PRESENT	0
809467	807225	20100N	PARTICIPANT	\N	PRESENT	0
809468	807225	21073H	PARTICIPANT	\N	PRESENT	0
809469	807225	20264J	PARTICIPANT	\N	PRESENT	0
809470	807225	21035B	PARTICIPANT	\N	PRESENT	0
809471	807225	17779H	PARTICIPANT	\N	PRESENT	0
809472	807225	20030R	PARTICIPANT	\N	PRESENT	0
809473	807225	20082E	PARTICIPANT	\N	PRESENT	0
809474	807225	10015M	PARTICIPANT	\N	PRESENT	0
809475	807225	04033B	PARTICIPANT	\N	PRESENT	0
809476	807225	20084G	PARTICIPANT	\N	PRESENT	0
809477	807225	20064C	PARTICIPANT	\N	PRESENT	0
809478	807225	21057H	PARTICIPANT	\N	PRESENT	0
809479	807225	21063F	PARTICIPANT	\N	PRESENT	0
809480	807225	20080C	PARTICIPANT	\N	PRESENT	0
809481	807225	19758L	PARTICIPANT	\N	PRESENT	0
809482	807225	20046A	PARTICIPANT	\N	PRESENT	0
809483	807225	21088Q	PARTICIPANT	\N	PRESENT	0
809484	807225	19565D	PARTICIPANT	\N	PRESENT	0
809485	807225	20102Q	PARTICIPANT	\N	PRESENT	0
809486	807225	19695N	PARTICIPANT	\N	PRESENT	0
809487	807225	14097Y	PARTICIPANT	\N	PRESENT	0
809488	807225	20056C	PARTICIPANT	\N	PRESENT	0
809489	807225	19683J	PARTICIPANT	\N	PRESENT	0
809490	807225	20094J	PARTICIPANT	\N	PRESENT	0
809491	807225	17367Q	PARTICIPANT	\N	PRESENT	0
809492	807225	14151M	PARTICIPANT	\N	PRESENT	0
809493	807225	14021P	PARTICIPANT	\N	PRESENT	0
809494	807225	19669L	PARTICIPANT	\N	PRESENT	0
809495	807225	21031W	PARTICIPANT	\N	PRESENT	0
809496	807225	21087P	PARTICIPANT	\N	PRESENT	0
809497	807225	14225N	PARTICIPANT	\N	PRESENT	0
809498	807225	14331P	PARTICIPANT	\N	PRESENT	0
809499	807225	14037X	PARTICIPANT	\N	PRESENT	0
809500	807225	14205J	PARTICIPANT	\N	PRESENT	0
809501	807225	14073Q	PARTICIPANT	\N	PRESENT	0
809502	807225	14189C	PARTICIPANT	\N	PRESENT	0
809503	807225	20042V	PARTICIPANT	\N	PRESENT	0
809504	807225	14089Y	PARTICIPANT	\N	PRESENT	0
809505	807225	19591F	PARTICIPANT	\N	PRESENT	0
809506	807225	04045F	PARTICIPANT	\N	PRESENT	0
809507	807225	20106U	PARTICIPANT	\N	PRESENT	0
809508	807225	19697Q	PARTICIPANT	\N	PRESENT	0
809509	807225	21043B	PARTICIPANT	\N	PRESENT	0
809510	807225	20142Y	PARTICIPANT	\N	PRESENT	0
809511	807225	20092G	PARTICIPANT	\N	PRESENT	0
809512	807225	21093M	PARTICIPANT	\N	PRESENT	0
809513	807225	21056G	PARTICIPANT	\N	PRESENT	0
809514	807225	21082J	PARTICIPANT	\N	PRESENT	0
809515	807225	14249W	PARTICIPANT	\N	PRESENT	0
809516	807225	14211G	PARTICIPANT	\N	PRESENT	0
809517	807225	14207L	PARTICIPANT	\N	PRESENT	0
809518	807225	20132W	PARTICIPANT	\N	PRESENT	0
809519	807225	20116W	PARTICIPANT	\N	PRESENT	0
809520	807225	20128B	PARTICIPANT	\N	PRESENT	0
809521	807225	19629C	PARTICIPANT	\N	PRESENT	0
809522	807225	20072C	PARTICIPANT	\N	PRESENT	0
809523	807225	20068G	PARTICIPANT	\N	PRESENT	0
809524	807225	21041Y	PARTICIPANT	\N	PRESENT	0
809525	807225	19693L	PARTICIPANT	\N	PRESENT	0
809526	807225	21067K	PARTICIPANT	\N	PRESENT	0
809527	807225	14251Q	PARTICIPANT	\N	PRESENT	0
809528	807225	21075K	PARTICIPANT	\N	PRESENT	0
809529	807225	14031R	PARTICIPANT	\N	PRESENT	0
809530	807225	11085T	PARTICIPANT	\N	PRESENT	0
809531	807225	19826F	PARTICIPANT	\N	PRESENT	0
809532	807225	21058J	PARTICIPANT	\N	PRESENT	0
809533	807225	14001X	PARTICIPANT	\N	PRESENT	0
809534	807225	08009T	PARTICIPANT	\N	PRESENT	0
809535	807225	19657G	PARTICIPANT	\N	PRESENT	0
809536	807225	19569H	PARTICIPANT	\N	PRESENT	0
809537	807225	14083S	PARTICIPANT	\N	PRESENT	0
809538	807225	21070E	PARTICIPANT	\N	PRESENT	0
809539	807225	11115U	PARTICIPANT	\N	PRESENT	0
809540	807225	19479G	PARTICIPANT	\N	PRESENT	0
809541	807225	19735D	PARTICIPANT	\N	PRESENT	0
809542	807225	19649G	PARTICIPANT	\N	PRESENT	0
809543	807225	07029T	PARTICIPANT	\N	PRESENT	0
809544	807225	19711U	PARTICIPANT	\N	PRESENT	0
809545	807225	08015R	PARTICIPANT	\N	PRESENT	0
809546	807225	19723Y	PARTICIPANT	\N	PRESENT	0
809547	807225	19611R	PARTICIPANT	\N	PRESENT	0
809548	807225	01034P	PARTICIPANT	\N	PRESENT	0
809549	807225	20050V	PARTICIPANT	\N	PRESENT	0
809550	807225	21076L	PARTICIPANT	\N	PRESENT	0
809551	807225	19709B	PARTICIPANT	\N	PRESENT	0
809552	807225	08018U	PARTICIPANT	\N	PRESENT	0
809462	807225	86034E	PARTICIPANT	\N	PRESENT	0
809463	807225	14195A	PARTICIPANT	\N	PRESENT	0
809553	807225	19619A	PARTICIPANT	\N	PRESENT	0
809554	807225	20144B	PARTICIPANT	\N	PRESENT	0
809555	807225	17023S	PARTICIPANT	\N	PRESENT	0
809556	807225	14179A	PARTICIPANT	\N	PRESENT	0
809557	807225	19563B	PARTICIPANT	\N	PRESENT	0
809558	807225	14267Y	PARTICIPANT	\N	PRESENT	0
809559	807225	20040T	PARTICIPANT	\N	PRESENT	0
809560	807225	19335Q	PARTICIPANT	\N	PRESENT	0
809561	807225	19685L	PARTICIPANT	\N	PRESENT	0
809562	807225	21085M	PARTICIPANT	\N	PRESENT	0
809563	807225	20248J	PARTICIPANT	\N	PRESENT	0
809564	807225	21069M	PARTICIPANT	\N	PRESENT	0
809565	807225	19713W	PARTICIPANT	\N	PRESENT	0
809566	807225	21053D	PARTICIPANT	\N	PRESENT	0
809567	807225	21042A	PARTICIPANT	\N	PRESENT	0
809568	807225	15197G	PARTICIPANT	\N	PRESENT	0
809569	807225	21064G	PARTICIPANT	\N	PRESENT	0
809570	807225	19745F	PARTICIPANT	\N	PRESENT	0
809571	807225	20066E	PARTICIPANT	\N	PRESENT	0
809572	807225	19111A	PARTICIPANT	\N	PRESENT	0
809573	807225	21050A	PARTICIPANT	\N	PRESENT	0
809574	807225	08034U	PARTICIPANT	\N	PRESENT	0
809575	807225	04092N	PARTICIPANT	\N	PRESENT	0
809576	807225	14193X	PARTICIPANT	\N	PRESENT	0
809577	807225	11090Q	PARTICIPANT	\N	PRESENT	0
800709	797609	11072N	PARTICIPANT	\N	PRESENT	0
800710	797609	20034V	PRESIDENT	0	PRESENT	0
800711	797609	21030V	PARTICIPANT	\N	PRESENT	0
800712	797609	08073C	PARTICIPANT	\N	PRESENT	0
800713	797609	19331L	PARTICIPANT	\N	PRESENT	0
800714	797609	21055F	PARTICIPANT	\N	PRESENT	0
800715	797609	19745F	PARTICIPANT	\N	PRESENT	0
800716	797609	19669L	PARTICIPANT	\N	EXCUSE	0
800717	797609	21071F	PARTICIPANT	\N	EXCUSE	0
800751	797609	20150Y	PARTICIPANT	\N	EXCUSE	0
801439	801438	19667J	PARTICIPANT	\N	PRESENT	0
801444	801443	19111A	PARTICIPANT	\N	PRESENT	0
801627	801625	14205J	PARTICIPANT	\N	PRESENT	0
801628	801625	14033T	PARTICIPANT	\N	PRESENT	0
801834	801832	14205J	PARTICIPANT	\N	PRESENT	0
801835	801832	14033T	PARTICIPANT	\N	PRESENT	0
801837	801472	14205J	PARTICIPANT	\N	PRESENT	0
801838	801472	14033T	PARTICIPANT	\N	PRESENT	0
802167	801440	21079P	PARTICIPANT	\N	PRESENT	0
802168	801440	19349W	PARTICIPANT	\N	PRESENT	0
802169	801440	08010L	PARTICIPANT	\N	PRESENT	0
802170	801440	19335Q	PARTICIPANT	\N	PRESENT	0
802171	801440	20126Y	PARTICIPANT	\N	PRESENT	0
802172	801440	20134Y	PARTICIPANT	\N	PRESENT	0
802173	801440	19711U	PARTICIPANT	\N	PRESENT	0
802174	801440	19687N	PARTICIPANT	\N	PRESENT	0
802175	801440	20050V	PARTICIPANT	\N	PRESENT	0
802176	801440	20044X	PARTICIPANT	\N	PRESENT	0
802177	801440	11040E	PARTICIPANT	\N	PRESENT	0
802178	801440	14083S	PARTICIPANT	\N	PRESENT	0
802179	801440	20070A	PARTICIPANT	\N	PRESENT	0
802180	801440	21069M	PARTICIPANT	\N	PRESENT	0
802182	801440	21041Y	PARTICIPANT	\N	PRESENT	0
802183	801440	11053K	PARTICIPANT	\N	PRESENT	0
802184	801440	12016W	PARTICIPANT	\N	PRESENT	0
802185	801440	14173T	PARTICIPANT	\N	EXCUSE	0
802187	801440	21090J	PARTICIPANT	\N	PRESENT	0
802189	801440	11110B	PARTICIPANT	\N	PRESENT	0
802190	801440	19647E	PARTICIPANT	\N	PRESENT	0
802191	801440	20094J	PARTICIPANT	\N	PRESENT	0
802193	797914	19699S	PARTICIPANT	\N	PRESENT	0
802194	797914	21058J	PARTICIPANT	\N	PRESENT	0
802195	797914	20102Q	PARTICIPANT	\N	PRESENT	0
802196	797914	19954N	PARTICIPANT	\N	PRESENT	0
802197	797914	20112S	PARTICIPANT	\N	PRESENT	0
802198	797914	21089R	PARTICIPANT	\N	PRESENT	0
802199	797914	08012N	PARTICIPANT	\N	PRESENT	0
802200	797914	21037D	PARTICIPANT	\N	PRESENT	0
802201	797914	21091K	PARTICIPANT	\N	PRESENT	0
802202	797914	20124W	PARTICIPANT	\N	PRESENT	0
802203	797914	19593H	PARTICIPANT	\N	PRESENT	0
802204	797914	20132W	PARTICIPANT	\N	PRESENT	0
802205	797914	21055F	PARTICIPANT	\N	PRESENT	0
802206	797914	20122U	PARTICIPANT	\N	PRESENT	0
802207	797914	19611R	PRESIDENT	0	PRESENT	0
802208	797914	20142Y	PARTICIPANT	\N	PRESENT	0
802209	797914	20048C	PARTICIPANT	\N	PRESENT	0
802210	797914	20052X	PARTICIPANT	\N	PRESENT	0
802211	797914	14030Q	PARTICIPANT	\N	PRESENT	0
802212	797914	20056C	PARTICIPANT	\N	PRESENT	0
802213	797914	20180F	PARTICIPANT	\N	PRESENT	0
802214	797914	20264J	PARTICIPANT	\N	PRESENT	0
802215	797914	14123H	PARTICIPANT	\N	PRESENT	0
802216	797914	11043H	PARTICIPANT	\N	PRESENT	0
802217	797914	14021P	PARTICIPANT	\N	PRESENT	0
802218	797914	19621T	PARTICIPANT	\N	PRESENT	0
802219	797914	18395Y	PARTICIPANT	\N	EXCUSE	0
802220	797914	14109K	PARTICIPANT	\N	EXCUSE	0
802221	801440	19479G	PARTICIPANT	\N	PRESENT	0
802223	801440	08011M	PARTICIPANT	\N	PRESENT	0
802224	801442	20086J	PARTICIPANT	\N	PRESENT	0
802225	801442	14331P	PARTICIPANT	\N	PRESENT	0
802226	801442	20080C	PARTICIPANT	\N	PRESENT	0
802227	801442	11053K	PARTICIPANT	\N	PRESENT	0
802228	801442	19667J	PARTICIPANT	\N	PRESENT	0
802229	801442	20094J	PARTICIPANT	\N	PRESENT	0
802230	801442	14225N	PRESIDENT	0	PRESENT	0
802231	801442	07029T	PARTICIPANT	\N	PRESENT	0
802232	801442	21079P	PARTICIPANT	\N	PRESENT	0
802233	801442	07004J	PARTICIPANT	\N	PRESENT	0
802524	801389	12016W	PARTICIPANT	\N	PRESENT	0
802235	801442	19349W	PARTICIPANT	\N	PRESENT	0
802236	801442	08010L	PARTICIPANT	\N	PRESENT	0
802237	801442	20116W	PARTICIPANT	\N	PRESENT	0
802238	801442	14253S	PARTICIPANT	\N	PRESENT	0
802239	801442	21090J	PARTICIPANT	\N	PRESENT	0
802240	801442	19335Q	PARTICIPANT	\N	PRESENT	0
802241	801442	20024T	PARTICIPANT	\N	PRESENT	0
802242	801442	20126Y	PARTICIPANT	\N	PRESENT	0
802243	801442	11048N	PARTICIPANT	\N	PRESENT	0
802244	801442	20134Y	PARTICIPANT	\N	PRESENT	0
802245	801442	19647E	PARTICIPANT	\N	PRESENT	0
802246	801442	19479G	PARTICIPANT	\N	PRESENT	0
802247	801442	19711U	PARTICIPANT	\N	PRESENT	0
802525	801389	21033Y	PARTICIPANT	\N	PRESENT	0
802249	801442	08034U	PARTICIPANT	\N	PRESENT	0
802250	801442	19687N	PARTICIPANT	\N	PRESENT	0
802251	801442	12016W	PARTICIPANT	\N	PRESENT	0
802252	801442	20050V	PARTICIPANT	\N	PRESENT	0
802253	801442	08011M	PARTICIPANT	\N	PRESENT	0
802254	801442	20044X	PARTICIPANT	\N	PRESENT	0
802256	801442	19399H	PARTICIPANT	\N	PRESENT	0
802258	801442	21041Y	PARTICIPANT	\N	PRESENT	0
802259	801442	11040E	PARTICIPANT	\N	PRESENT	0
802260	801442	14083S	PARTICIPANT	\N	PRESENT	0
802263	801442	20070A	PARTICIPANT	\N	PRESENT	0
802265	801442	21069M	PARTICIPANT	\N	PRESENT	0
802266	801442	14121F	PARTICIPANT	\N	PRESENT	0
802270	801442	11070L	PARTICIPANT	\N	PRESENT	0
802271	801442	11110B	PARTICIPANT	\N	PRESENT	0
802273	801442	14173T	PARTICIPANT	\N	EXCUSE	0
802505	801389	86034E	PARTICIPANT	\N	PRESENT	0
802526	801389	20134Y	PARTICIPANT	\N	PRESENT	0
802527	801389	20100N	PARTICIPANT	\N	PRESENT	0
802528	801389	21034A	PARTICIPANT	\N	PRESENT	0
802529	801389	20102Q	PARTICIPANT	\N	PRESENT	0
802530	801389	21077M	PARTICIPANT	\N	PRESENT	0
802531	801389	21043B	PARTICIPANT	\N	PRESENT	0
802532	801389	18395Y	PARTICIPANT	\N	PRESENT	0
802533	801389	14097Y	PARTICIPANT	\N	PRESENT	0
802534	801389	21078N	PARTICIPANT	\N	PRESENT	0
802535	801389	04045F	PARTICIPANT	\N	PRESENT	0
802536	801389	19866P	PARTICIPANT	\N	PRESENT	0
802537	801389	08061X	PARTICIPANT	\N	PRESENT	0
802538	801389	17023S	PARTICIPANT	\N	PRESENT	0
802539	801389	14267Y	PARTICIPANT	\N	PRESENT	0
802540	801389	19111A	PARTICIPANT	\N	PRESENT	0
802541	801389	19479G	PARTICIPANT	\N	PRESENT	0
802542	801389	14189C	PARTICIPANT	\N	PRESENT	0
802543	801389	21052C	PARTICIPANT	\N	PRESENT	0
802544	801389	21076L	PARTICIPANT	\N	PRESENT	0
802810	801389	20146D	PARTICIPANT	\N	PRESENT	0
802815	801389	14026U	PARTICIPANT	\N	PRESENT	0
802816	801389	11048N	PARTICIPANT	\N	PRESENT	0
802817	801389	19760E	PARTICIPANT	\N	PRESENT	0
802818	801389	04070G	PARTICIPANT	\N	PRESENT	0
802819	801389	21038E	PARTICIPANT	\N	PRESENT	0
802820	801389	19295A	PARTICIPANT	\N	PRESENT	0
802832	801389	21094N	PARTICIPANT	\N	PRESENT	0
802841	801389	19669L	PARTICIPANT	\N	PRESENT	0
802823	801389	21041Y	PARTICIPANT	\N	PRESENT	0
802824	801389	14069U	PARTICIPANT	\N	PRESENT	0
802828	801389	19551W	PARTICIPANT	\N	PRESENT	0
802838	801389	21036C	PARTICIPANT	\N	PRESENT	0
802840	801389	14151M	PARTICIPANT	\N	PRESENT	0
802842	801389	14133K	PARTICIPANT	\N	PRESENT	0
802846	801389	14033T	PARTICIPANT	\N	PRESENT	0
802844	801389	21093M	PARTICIPANT	\N	PRESENT	0
802845	801389	11056N	PARTICIPANT	\N	PRESENT	0
802849	801389	21056G	PARTICIPANT	\N	PRESENT	0
816151	816061	21034A	PARTICIPANT	\N	PRESENT	0
816152	816061	19695N	PARTICIPANT	\N	PRESENT	0
816153	816061	21044C	PARTICIPANT	\N	PRESENT	0
816154	816061	21030V	PARTICIPANT	\N	PRESENT	0
816155	816061	19565D	PARTICIPANT	\N	PRESENT	0
816156	816061	21092L	PARTICIPANT	\N	PRESENT	0
816157	816061	14225N	PARTICIPANT	\N	PRESENT	0
816158	816061	17779H	PARTICIPANT	\N	PRESENT	0
816159	816061	19649G	PARTICIPANT	\N	PRESENT	0
816160	816061	19697Q	PARTICIPANT	\N	PRESENT	0
816161	816061	21059K	PARTICIPANT	\N	PRESENT	0
816162	816061	21082J	PARTICIPANT	\N	PRESENT	0
816163	816061	14026U	PARTICIPANT	\N	PRESENT	0
816164	816061	19647E	PARTICIPANT	\N	PRESENT	0
816165	816061	20018V	PARTICIPANT	\N	PRESENT	0
816166	816061	17737W	PARTICIPANT	\N	PRESENT	0
816167	816061	21043B	PARTICIPANT	\N	PRESENT	0
816168	816061	20128B	PARTICIPANT	\N	PRESENT	0
816169	816061	04033B	PARTICIPANT	\N	PRESENT	0
816170	816061	19782L	PARTICIPANT	\N	PRESENT	0
816171	816061	21081H	PARTICIPANT	\N	PRESENT	0
816172	816061	20032T	PARTICIPANT	\N	PRESENT	0
816173	816061	14133K	PARTICIPANT	\N	PRESENT	0
816174	816061	19725B	PARTICIPANT	\N	PRESENT	0
816175	816061	21071F	PARTICIPANT	\N	PRESENT	0
816176	816061	14021P	PARTICIPANT	\N	PRESENT	0
816177	816061	20252E	PARTICIPANT	\N	PRESENT	0
816178	816061	19631V	PARTICIPANT	\N	PRESENT	0
816179	816061	19693L	PARTICIPANT	\N	PRESENT	0
816180	816061	21070E	PARTICIPANT	\N	PRESENT	0
816181	816061	14111D	PARTICIPANT	\N	PRESENT	0
816182	816061	19545Y	PARTICIPANT	\N	PRESENT	0
816183	816061	21046E	PARTICIPANT	\N	PRESENT	0
816184	816061	14211G	PARTICIPANT	\N	PRESENT	0
816185	816061	20050V	PARTICIPANT	\N	PRESENT	0
816186	816061	19681G	PARTICIPANT	\N	PRESENT	0
816187	816061	11056N	PARTICIPANT	\N	PRESENT	0
816188	816061	20100N	PARTICIPANT	\N	PRESENT	0
816189	816061	21079P	PARTICIPANT	\N	PRESENT	0
816190	816061	20266L	PARTICIPANT	\N	PRESENT	0
816191	816061	19711U	PARTICIPANT	\N	PRESENT	0
816192	816061	21037D	PARTICIPANT	\N	PRESENT	0
816193	816061	19621T	PARTICIPANT	\N	PRESENT	0
816194	816061	21091K	PARTICIPANT	\N	PRESENT	0
816195	816061	99004R	PARTICIPANT	\N	PRESENT	0
816196	816061	14123H	PARTICIPANT	\N	PRESENT	0
816197	816061	21035B	PARTICIPANT	\N	PRESENT	0
816198	816061	19573D	PARTICIPANT	\N	PRESENT	0
816199	816061	08060W	PARTICIPANT	\N	PRESENT	0
816200	816061	21061D	PARTICIPANT	\N	PRESENT	0
816201	816061	21089R	PARTICIPANT	\N	PRESENT	0
816202	816061	14223L	PARTICIPANT	\N	PRESENT	0
816203	816061	21045D	PARTICIPANT	\N	PRESENT	0
816204	816061	20264J	PARTICIPANT	\N	PRESENT	0
816205	816061	14187A	PARTICIPANT	\N	PRESENT	0
816206	816061	11090Q	PARTICIPANT	\N	PRESENT	0
816207	816061	18395Y	PARTICIPANT	\N	PRESENT	0
816208	816061	20022R	PARTICIPANT	\N	PRESENT	0
816209	816061	21067K	PARTICIPANT	\N	PRESENT	0
816210	816061	20080C	PARTICIPANT	\N	PRESENT	0
816211	816061	19251M	PARTICIPANT	\N	PRESENT	0
816212	816061	08069G	PARTICIPANT	\N	PRESENT	0
816213	816061	20044X	PARTICIPANT	\N	PRESENT	0
816214	816061	21062E	PARTICIPANT	\N	PRESENT	0
816215	816061	14281W	PARTICIPANT	\N	PRESENT	0
816216	816061	19820Y	PARTICIPANT	\N	PRESENT	0
816217	816061	14121F	PARTICIPANT	\N	PRESENT	0
816218	816061	21029D	PARTICIPANT	\N	PRESENT	0
816219	816061	21094N	PARTICIPANT	\N	PRESENT	0
816220	816061	04042C	PARTICIPANT	\N	PRESENT	0
816221	816061	14253S	PARTICIPANT	\N	PRESENT	0
816222	816061	14331P	PARTICIPANT	\N	PRESENT	0
816223	816061	20118Y	PARTICIPANT	\N	PRESENT	0
816224	816061	14229S	PARTICIPANT	\N	PRESENT	0
816225	816061	20082E	PARTICIPANT	\N	PRESENT	0
816226	816061	19798U	PARTICIPANT	\N	PRESENT	0
816227	816061	21060C	PARTICIPANT	\N	PRESENT	0
816228	816061	20084G	PARTICIPANT	\N	PRESENT	0
816229	816061	21095P	PARTICIPANT	\N	PRESENT	0
816230	816061	19531S	PARTICIPANT	\N	PRESENT	0
816231	816061	21090J	PARTICIPANT	\N	PRESENT	0
816232	816061	17965H	PARTICIPANT	\N	PRESENT	0
816233	816061	11045K	PARTICIPANT	\N	PRESENT	0
816234	816061	14071N	PARTICIPANT	\N	PRESENT	0
816235	816061	08047A	PARTICIPANT	\N	PRESENT	0
816236	816061	14031R	PARTICIPANT	\N	PRESENT	0
816237	816061	20146D	PARTICIPANT	\N	PRESENT	0
816238	816061	20094J	PARTICIPANT	\N	PRESENT	0
816239	816061	21031W	PARTICIPANT	\N	PRESENT	0
816240	816061	21077M	PARTICIPANT	\N	PRESENT	0
816241	816061	19954N	PARTICIPANT	\N	PRESENT	0
816242	816061	19533U	PARTICIPANT	\N	PRESENT	0
816243	816061	21073H	PARTICIPANT	\N	PRESENT	0
816244	816061	14217N	PARTICIPANT	\N	PRESENT	0
816245	816061	21068L	PARTICIPANT	\N	PRESENT	0
816246	816061	19447X	PARTICIPANT	\N	PRESENT	0
816247	816061	19723Y	PARTICIPANT	\N	PRESENT	0
816248	816061	14033T	PARTICIPANT	\N	PRESENT	0
816249	816061	19399H	PARTICIPANT	\N	PRESENT	0
816250	816061	20098N	PARTICIPANT	\N	PRESENT	0
816251	816061	19551W	PARTICIPANT	\N	PRESENT	0
816252	816061	20020P	PARTICIPANT	\N	PRESENT	0
816253	816061	21065H	PARTICIPANT	\N	PRESENT	0
816254	816061	20054A	PARTICIPANT	\N	PRESENT	0
816255	816061	14055N	PARTICIPANT	\N	PRESENT	0
816256	816061	21069M	PARTICIPANT	\N	PRESENT	0
816257	816061	21085M	PARTICIPANT	\N	PRESENT	0
816258	816061	14189C	PARTICIPANT	\N	PRESENT	0
816259	816061	21042A	PARTICIPANT	\N	PRESENT	0
816260	816061	19768N	PARTICIPANT	\N	PRESENT	0
816261	816061	14030Q	PARTICIPANT	\N	PRESENT	0
816262	816061	21050A	PARTICIPANT	\N	PRESENT	0
816263	816061	19657G	PARTICIPANT	\N	PRESENT	0
816264	816061	07029T	PARTICIPANT	\N	PRESENT	0
816265	816061	14089Y	PARTICIPANT	\N	PRESENT	0
816266	816061	08018U	PARTICIPANT	\N	PRESENT	0
816267	816061	14083S	PARTICIPANT	\N	PRESENT	0
816268	816061	19709B	PARTICIPANT	\N	PRESENT	0
816269	816061	17367Q	PARTICIPANT	\N	PRESENT	0
816270	816061	14267Y	PARTICIPANT	\N	PRESENT	0
816271	816061	20086J	PARTICIPANT	\N	PRESENT	0
816272	816061	20144B	PARTICIPANT	\N	PRESENT	0
816273	816061	21047F	PARTICIPANT	\N	PRESENT	0
816274	816061	20040T	PARTICIPANT	\N	PRESENT	0
816275	816061	21063F	PARTICIPANT	\N	PRESENT	0
816276	816061	19111A	PARTICIPANT	\N	PRESENT	0
816277	816061	14042U	PARTICIPANT	\N	PRESENT	0
816278	816061	19563B	PARTICIPANT	\N	PRESENT	0
816279	816061	19335Q	PARTICIPANT	\N	PRESENT	0
816280	816061	21053D	PARTICIPANT	\N	PRESENT	0
816281	816061	14219Q	PARTICIPANT	\N	PRESENT	0
816282	816061	21038E	PARTICIPANT	\N	PRESENT	0
816283	816061	07004J	PARTICIPANT	\N	PRESENT	0
816284	816061	21064G	PARTICIPANT	\N	PRESENT	0
816285	816061	01034P	PARTICIPANT	\N	PRESENT	0
816286	816061	19749K	PARTICIPANT	\N	PRESENT	0
816287	816061	20052X	PARTICIPANT	\N	PRESENT	0
816288	816061	20092G	PARTICIPANT	\N	PRESENT	0
816289	816061	21093M	PARTICIPANT	\N	PRESENT	0
816290	816061	20132W	PARTICIPANT	\N	PRESENT	0
816291	816061	19826F	PARTICIPANT	\N	PRESENT	0
816292	816061	20134Y	PARTICIPANT	\N	PRESENT	0
816293	816061	14193X	PARTICIPANT	\N	PRESENT	0
816294	816061	19479G	PARTICIPANT	\N	PRESENT	0
816295	816061	11070L	PARTICIPANT	\N	PRESENT	0
816300	816061	14059S	PARTICIPANT	\N	PRESENT	0
816297	816061	07033P	PARTICIPANT	\N	PRESENT	0
816298	816061	21125C	PARTICIPANT	\N	PRESENT	0
816299	816061	19679N	PARTICIPANT	\N	PRESENT	0
816305	816061	20038A	PARTICIPANT	\N	PRESENT	0
816302	816061	08028W	PARTICIPANT	\N	PRESENT	0
816303	816061	20056C	PARTICIPANT	\N	PRESENT	0
816307	816061	11115U	PARTICIPANT	\N	PRESENT	0
816306	816061	19699S	PARTICIPANT	\N	PRESENT	0
816308	816061	21058J	PARTICIPANT	\N	PRESENT	0
816309	816061	14259Y	PARTICIPANT	\N	PRESENT	0
816310	816061	11027H	PARTICIPANT	\N	PRESENT	0
816311	816061	19347U	PARTICIPANT	\N	PRESENT	0
816312	816061	12028B	PARTICIPANT	\N	PRESENT	0
816313	816061	08010L	PARTICIPANT	\N	PRESENT	0
816314	816061	20026V	PARTICIPANT	\N	PRESENT	0
807412	807005	19729F	PARTICIPANT	\N	EXCUSE	0
807413	807005	19585H	PARTICIPANT	\N	EXCUSE	0
807414	807005	19719D	PARTICIPANT	\N	EXCUSE	0
807415	807174	14259Y	PARTICIPANT	\N	PRESENT	0
807442	807174	20098N	PARTICIPANT	\N	PRESENT	0
807443	807174	14073Q	PARTICIPANT	\N	PRESENT	0
807444	807174	20046A	PARTICIPANT	\N	PRESENT	0
807445	807174	20102Q	PARTICIPANT	\N	PRESENT	0
807446	807174	19725B	PARTICIPANT	\N	PRESENT	0
807447	807174	21070E	PARTICIPANT	\N	PRESENT	0
807448	807174	21040X	PARTICIPANT	\N	PRESENT	0
807449	807174	21039F	PARTICIPANT	\N	PRESENT	0
807450	807174	21076L	PARTICIPANT	\N	PRESENT	0
807451	807174	14215L	PARTICIPANT	\N	PRESENT	0
807452	807174	19749K	PARTICIPANT	\N	PRESENT	0
807453	807174	14147R	PARTICIPANT	\N	PRESENT	0
807454	807174	04047H	PARTICIPANT	\N	PRESENT	0
807455	807174	21043B	PARTICIPANT	\N	PRESENT	0
807456	807174	21053D	PARTICIPANT	\N	PRESENT	0
807457	807174	14111D	PARTICIPANT	\N	PRESENT	0
807458	807174	20038A	PARTICIPANT	\N	PRESENT	0
807459	807174	19399H	PARTICIPANT	\N	PRESENT	0
807460	807174	20108W	PARTICIPANT	\N	PRESENT	0
807461	807174	20032T	PARTICIPANT	\N	PRESENT	0
807462	807174	18083K	PARTICIPANT	\N	PRESENT	0
807463	807174	14069U	PARTICIPANT	\N	PRESENT	0
807464	807174	18207D	PARTICIPANT	\N	PRESENT	0
807465	807174	21045D	PARTICIPANT	\N	PRESENT	0
807466	807174	04045F	PARTICIPANT	\N	PRESENT	0
807467	807174	21073H	PARTICIPANT	\N	PRESENT	0
807468	807174	21066J	PARTICIPANT	\N	PRESENT	0
807469	807174	20180F	PARTICIPANT	\N	PRESENT	0
807470	807174	19673G	PARTICIPANT	\N	PRESENT	0
807471	807174	14249W	PARTICIPANT	\N	PRESENT	0
807472	807174	20026V	PARTICIPANT	\N	PRESENT	0
807473	807174	14053L	PARTICIPANT	\N	PRESENT	0
807474	807174	20022R	PARTICIPANT	\N	PRESENT	0
807501	807174	20028X	PARTICIPANT	\N	PRESENT	0
807482	807174	19954N	PARTICIPANT	\N	PRESENT	0
807477	807174	19745F	PARTICIPANT	\N	PRESENT	0
807478	807174	21057H	PARTICIPANT	\N	PRESENT	0
807479	807174	18231D	PARTICIPANT	\N	PRESENT	0
807480	807174	19367Y	PARTICIPANT	\N	PRESENT	0
807481	807174	20048C	PARTICIPANT	\N	PRESENT	0
807483	807174	98022P	PARTICIPANT	\N	PRESENT	0
807484	807174	20140W	PARTICIPANT	\N	PRESENT	0
807485	807174	14030Q	PARTICIPANT	\N	PRESENT	0
807486	807174	14257W	PARTICIPANT	\N	PRESENT	0
807487	807174	21082J	PARTICIPANT	\N	PRESENT	0
807488	807174	20034V	PARTICIPANT	\N	PRESENT	0
807489	807174	19703U	PARTICIPANT	\N	PRESENT	0
807490	807174	21038E	PARTICIPANT	\N	PRESENT	0
807491	807174	11043H	PARTICIPANT	\N	PRESENT	0
807495	807174	19545Y	PARTICIPANT	\N	PRESENT	0
807502	807174	20110Q	PARTICIPANT	\N	PRESENT	0
807494	807174	20172F	PARTICIPANT	\N	PRESENT	0
807496	807174	19629C	PARTICIPANT	\N	PRESENT	0
807497	807174	21063F	PARTICIPANT	\N	PRESENT	0
807498	807174	14223L	PARTICIPANT	\N	PRESENT	0
807499	807174	19251M	PARTICIPANT	\N	PRESENT	0
807500	807174	21072G	PARTICIPANT	\N	PRESENT	0
807503	807174	19531S	PARTICIPANT	\N	PRESENT	0
807504	807174	19111A	PARTICIPANT	\N	PRESENT	0
807505	807174	20056C	PARTICIPANT	\N	PRESENT	0
807506	807174	20100N	PARTICIPANT	\N	PRESENT	0
807507	807174	14189C	PARTICIPANT	\N	PRESENT	0
807508	807174	21056G	PARTICIPANT	\N	PRESENT	0
807509	807175	14259Y	PARTICIPANT	\N	PRESENT	0
807510	807175	20046A	PARTICIPANT	\N	PRESENT	0
807511	807175	20102Q	PARTICIPANT	\N	PRESENT	0
807512	807175	19725B	PARTICIPANT	\N	PRESENT	0
807513	807175	21070E	PARTICIPANT	\N	PRESENT	0
807514	807175	21040X	PARTICIPANT	\N	PRESENT	0
807515	807175	21039F	PARTICIPANT	\N	PRESENT	0
807516	807175	21076L	PARTICIPANT	\N	PRESENT	0
807517	807175	14215L	PARTICIPANT	\N	PRESENT	0
807559	807175	04047H	PARTICIPANT	\N	PRESENT	0
807560	807175	19798U	PARTICIPANT	\N	PRESENT	0
807561	807175	19701S	PARTICIPANT	\N	PRESENT	0
807521	807175	21053D	PARTICIPANT	\N	PRESENT	0
807522	807175	14111D	PARTICIPANT	\N	PRESENT	0
807523	807175	20038A	PARTICIPANT	\N	PRESENT	0
807524	807175	19399H	PARTICIPANT	\N	PRESENT	0
807562	807175	14217N	PARTICIPANT	\N	PRESENT	0
807526	807175	18207D	PARTICIPANT	\N	PRESENT	0
807568	807175	19697Q	PARTICIPANT	\N	PRESENT	0
807528	807175	04045F	PARTICIPANT	\N	PRESENT	0
807563	807175	20044X	PARTICIPANT	\N	PRESENT	0
807530	807175	21066J	PARTICIPANT	\N	PRESENT	0
807564	807175	21047F	PARTICIPANT	\N	PRESENT	0
807532	807175	14249W	PARTICIPANT	\N	PRESENT	0
807533	807175	20022R	PARTICIPANT	\N	PRESENT	0
807534	807175	19745F	PARTICIPANT	\N	PRESENT	0
807535	807175	21057H	PARTICIPANT	\N	PRESENT	0
807565	807175	14275Y	PARTICIPANT	\N	PRESENT	0
807537	807175	19367Y	PARTICIPANT	\N	PRESENT	0
807538	807175	98022P	PARTICIPANT	\N	PRESENT	0
807539	807175	20140W	PARTICIPANT	\N	PRESENT	0
807540	807175	14030Q	PARTICIPANT	\N	PRESENT	0
807541	807175	21082J	PARTICIPANT	\N	PRESENT	0
807542	807175	19703U	PARTICIPANT	\N	PRESENT	0
807543	807175	21038E	PARTICIPANT	\N	PRESENT	0
807544	807175	11043H	PARTICIPANT	\N	PRESENT	0
807545	807175	20172F	PARTICIPANT	\N	PRESENT	0
807546	807175	19545Y	PARTICIPANT	\N	PRESENT	0
807547	807175	19629C	PARTICIPANT	\N	PRESENT	0
807548	807175	21063F	PARTICIPANT	\N	PRESENT	0
807549	807175	14223L	PARTICIPANT	\N	PRESENT	0
807550	807175	19251M	PARTICIPANT	\N	PRESENT	0
807551	807175	21072G	PARTICIPANT	\N	PRESENT	0
807567	807175	14121F	PARTICIPANT	\N	PRESENT	0
807569	807175	11056N	PARTICIPANT	\N	PRESENT	0
807554	807175	20056C	PARTICIPANT	\N	PRESENT	0
807555	807175	20100N	PARTICIPANT	\N	PRESENT	0
807556	807175	14189C	PARTICIPANT	\N	PRESENT	0
807557	807175	21056G	PARTICIPANT	\N	PRESENT	0
807558	807175	20032T	PARTICIPANT	\N	PRESENT	0
807571	807175	17023S	PARTICIPANT	\N	PRESENT	0
807572	807175	21067K	PARTICIPANT	\N	PRESENT	0
807573	807175	19551W	PARTICIPANT	\N	PRESENT	0
807574	807175	20110Q	PARTICIPANT	\N	PRESENT	0
807575	807175	14031R	PARTICIPANT	\N	PRESENT	0
807576	807175	20136B	PARTICIPANT	\N	PRESENT	0
807577	807175	20070A	PARTICIPANT	\N	PRESENT	0
807578	807175	14083S	PARTICIPANT	\N	PRESENT	0
807580	807175	14173T	PARTICIPANT	\N	PRESENT	0
807581	807175	19735D	PARTICIPANT	\N	PRESENT	0
807582	807175	19826F	PARTICIPANT	\N	PRESENT	0
807583	807175	21055F	PARTICIPANT	\N	PRESENT	0
807598	807175	20034V	PARTICIPANT	\N	PRESENT	0
807600	807175	19507S	PARTICIPANT	\N	PRESENT	0
807601	807175	20026V	PARTICIPANT	\N	PRESENT	0
807602	807353	19383Y	PARTICIPANT	\N	PRESENT	0
807603	807353	19768N	PARTICIPANT	\N	PRESENT	0
807604	807353	20092G	PARTICIPANT	\N	PRESENT	0
807605	807353	14357A	PARTICIPANT	\N	PRESENT	0
807606	807353	19413M	PARTICIPANT	\N	PRESENT	0
807607	807353	20082E	PARTICIPANT	\N	PRESENT	0
807608	807353	19631V	PARTICIPANT	\N	PRESENT	0
807609	807353	08015R	PARTICIPANT	\N	PRESENT	0
807610	807353	19575F	PARTICIPANT	\N	PRESENT	0
807611	807353	19563B	PARTICIPANT	\N	PRESENT	0
807612	807353	08028W	PARTICIPANT	\N	PRESENT	0
807613	807353	21050A	PARTICIPANT	\N	PRESENT	0
807614	807353	14329V	PARTICIPANT	\N	PRESENT	0
807615	807353	20028X	PARTICIPANT	\N	PRESENT	0
807616	807353	20034V	PARTICIPANT	\N	PRESENT	0
807617	807353	21054E	PARTICIPANT	\N	PRESENT	0
807618	807353	14187A	PRESIDENT	0	PRESENT	0
807619	807353	21075K	PARTICIPANT	\N	PRESENT	0
807620	807353	20144B	PARTICIPANT	\N	PRESENT	0
807621	807353	21086N	PARTICIPANT	\N	PRESENT	0
807622	807353	21093M	PARTICIPANT	\N	PRESENT	0
807623	807353	11090Q	PARTICIPANT	\N	PRESENT	0
807624	807353	14033T	PARTICIPANT	\N	PRESENT	0
807625	807353	20054A	PARTICIPANT	\N	PRESENT	0
807626	807353	14205J	PARTICIPANT	\N	PRESENT	0
807627	807353	19507S	PARTICIPANT	\N	PRESENT	0
807628	807353	20066E	PARTICIPANT	\N	PRESENT	0
807629	807353	20286Q	PARTICIPANT	\N	PRESENT	0
807630	807353	14207L	PARTICIPANT	\N	PRESENT	0
809580	807225	05008E	PARTICIPANT	\N	PRESENT	0
809581	807225	14053L	PARTICIPANT	\N	PRESENT	0
809582	807225	19701S	PARTICIPANT	\N	PRESENT	0
809583	807225	14187A	PARTICIPANT	\N	PRESENT	0
809584	807225	11072N	PARTICIPANT	\N	PRESENT	0
809585	807225	14071N	PARTICIPANT	\N	PRESENT	0
809586	807225	19798U	PARTICIPANT	\N	PRESENT	0
809587	807225	20054A	PARTICIPANT	\N	PRESENT	0
809588	807225	14069U	PARTICIPANT	\N	PRESENT	0
809589	807225	19533U	PARTICIPANT	\N	PRESENT	0
809590	807225	20120S	PARTICIPANT	\N	PRESENT	0
809591	807225	14217N	PARTICIPANT	\N	PRESENT	0
809592	807225	21090J	PARTICIPANT	\N	PRESENT	0
809593	807225	21095P	PARTICIPANT	\N	PRESENT	0
809594	807225	20098N	PARTICIPANT	\N	PRESENT	0
809595	807225	20020P	PARTICIPANT	\N	PRESENT	0
809596	807225	20124W	PARTICIPANT	\N	PRESENT	0
809597	807225	01058X	PARTICIPANT	\N	PRESENT	0
809598	807225	14357A	PARTICIPANT	\N	PRESENT	0
809599	807225	14329V	PARTICIPANT	\N	PRESENT	0
809600	807225	14147R	PARTICIPANT	\N	PRESENT	0
809601	807225	14026U	PARTICIPANT	\N	PRESENT	0
809602	807225	14033T	PARTICIPANT	\N	PRESENT	0
809603	807225	20026V	PARTICIPANT	\N	PRESENT	0
809604	807225	19421M	PARTICIPANT	\N	PRESENT	0
809605	807225	20044X	PARTICIPANT	\N	PRESENT	0
809606	807225	21061D	PARTICIPANT	\N	PRESENT	0
809607	807225	11056N	PARTICIPANT	\N	PRESENT	0
809608	807225	21091K	PARTICIPANT	\N	PRESENT	0
809609	807225	19575F	PARTICIPANT	\N	PRESENT	0
809610	807225	18083K	PARTICIPANT	\N	PRESENT	0
809611	807225	99004R	PARTICIPANT	\N	PRESENT	0
809612	807225	20074E	PARTICIPANT	\N	PRESENT	0
809613	807225	20076G	PARTICIPANT	\N	PRESENT	0
809614	807225	19573D	PARTICIPANT	\N	PRESENT	0
809615	807225	14169X	PARTICIPANT	\N	PRESENT	0
809616	807225	19621T	PARTICIPANT	\N	PRESENT	0
809617	807225	14259Y	PARTICIPANT	\N	PRESENT	0
809618	807225	21055F	PARTICIPANT	\N	PRESENT	0
809619	807225	19673G	PARTICIPANT	\N	PRESENT	0
809620	807225	21068L	PARTICIPANT	\N	PRESENT	0
809621	807225	20096L	PARTICIPANT	\N	PRESENT	0
809622	807225	20180F	PARTICIPANT	\N	PRESENT	0
809578	807225	19679N	PARTICIPANT	\N	PRESENT	0
809579	807225	20062A	PARTICIPANT	\N	PRESENT	0
809623	807225	20038A	PARTICIPANT	\N	PRESENT	0
809624	807225	21039F	PARTICIPANT	\N	PRESENT	0
809625	807225	20034V	PARTICIPANT	\N	PRESENT	0
809626	807225	04042C	PARTICIPANT	\N	PRESENT	0
809627	807225	11043H	PARTICIPANT	\N	PRESENT	0
809628	807225	05012A	PARTICIPANT	\N	PRESENT	0
809629	807225	20032T	PARTICIPANT	\N	PRESENT	0
809630	807225	20136B	PARTICIPANT	\N	PRESENT	0
809631	807225	14253S	PARTICIPANT	\N	PRESENT	0
809632	807225	14215L	PARTICIPANT	\N	PRESENT	0
809633	807225	19954N	PARTICIPANT	\N	PRESENT	0
809634	807225	08047A	PARTICIPANT	\N	PRESENT	0
809635	807225	21081H	PARTICIPANT	\N	PRESENT	0
809636	807225	19399H	PARTICIPANT	\N	PRESENT	0
809637	807225	20104S	PARTICIPANT	\N	PRESENT	0
809638	807225	14213J	PARTICIPANT	\N	PRESENT	0
809639	807225	04047H	PARTICIPANT	\N	PRESENT	0
809640	807225	20126Y	PARTICIPANT	\N	PRESENT	0
809641	807225	21054E	PARTICIPANT	\N	PRESENT	0
809642	807225	20052X	PARTICIPANT	\N	PRESENT	0
809643	807225	08061X	PARTICIPANT	\N	PRESENT	0
809644	807225	20134Y	PARTICIPANT	\N	PRESENT	0
809645	807225	21084L	PARTICIPANT	\N	PRESENT	0
809646	807225	21049H	PARTICIPANT	\N	PRESENT	0
809647	807225	19687N	PARTICIPANT	\N	PRESENT	0
809648	807225	19760E	PARTICIPANT	\N	PRESENT	0
809649	807225	20018V	PARTICIPANT	\N	PRESENT	0
809650	807225	11074Q	PARTICIPANT	\N	PRESENT	0
809651	807225	19295A	PARTICIPANT	\N	PRESENT	0
809652	807225	12028B	PARTICIPANT	\N	PRESENT	0
809653	807225	20070A	PARTICIPANT	\N	PRESENT	0
809654	807225	19647E	PARTICIPANT	\N	PRESENT	0
809655	807225	21062E	PARTICIPANT	\N	PRESENT	0
809656	807225	08012N	PARTICIPANT	\N	PRESENT	0
809657	807225	21089R	PARTICIPANT	\N	PRESENT	0
809658	807225	19531S	PARTICIPANT	\N	PRESENT	0
809659	807225	19489J	PARTICIPANT	\N	PRESENT	0
809660	807225	18231D	PARTICIPANT	\N	PRESENT	0
809661	807225	17965H	PARTICIPANT	\N	PRESENT	0
809662	807225	08045X	PARTICIPANT	\N	PRESENT	0
809663	807225	19413M	PARTICIPANT	\N	PRESENT	0
809664	807225	21037D	PARTICIPANT	\N	PRESENT	0
809665	807225	21079P	PARTICIPANT	\N	PRESENT	0
809666	807225	18207D	PARTICIPANT	\N	PRESENT	0
809667	807225	21060C	PARTICIPANT	\N	PRESENT	0
809668	807225	14255U	PARTICIPANT	\N	PRESENT	0
809669	807225	19631V	PARTICIPANT	\N	PRESENT	0
809670	807225	11110B	PARTICIPANT	\N	PRESENT	0
809671	807225	19057M	PARTICIPANT	\N	PRESENT	0
809672	807225	14281W	PARTICIPANT	\N	PRESENT	0
809673	807225	18193Q	PARTICIPANT	\N	PRESENT	0
809674	807225	19593H	PARTICIPANT	\N	PRESENT	0
809675	807225	20122U	PARTICIPANT	\N	PRESENT	0
809676	807225	11053K	PARTICIPANT	\N	PRESENT	0
809677	807225	14030Q	PARTICIPANT	\N	PRESENT	0
809678	807225	20060X	PARTICIPANT	\N	PRESENT	0
809679	807225	08010L	PARTICIPANT	\N	PRESENT	0
809680	807225	18395Y	PARTICIPANT	\N	PRESENT	0
809681	807225	19447X	PARTICIPANT	\N	PRESENT	0
809898	807226	19954N	PARTICIPANT	\N	PRESENT	0
809867	807226	19593H	PARTICIPANT	\N	PRESENT	0
809868	807226	20102Q	PARTICIPANT	\N	PRESENT	0
809869	807226	21089R	PARTICIPANT	\N	PRESENT	0
809870	807226	21037D	PARTICIPANT	\N	PRESENT	0
809871	807226	19693L	PARTICIPANT	\N	PRESENT	0
809872	807226	21078N	PARTICIPANT	\N	PRESENT	0
809873	807226	21032X	PARTICIPANT	\N	PRESENT	0
809874	807226	20142Y	PARTICIPANT	\N	PRESENT	0
809875	807226	21064G	PARTICIPANT	\N	PRESENT	0
809876	807226	14030Q	PARTICIPANT	\N	PRESENT	0
809877	807226	14089Y	PARTICIPANT	\N	PRESENT	0
809878	807226	20040T	PARTICIPANT	\N	PRESENT	0
809879	807226	04033B	PARTICIPANT	\N	PRESENT	0
809880	807226	11048N	PARTICIPANT	\N	PRESENT	0
809881	807226	19621T	PARTICIPANT	\N	PRESENT	0
809882	807226	20124W	PARTICIPANT	\N	PRESENT	0
809883	807226	20026V	PARTICIPANT	\N	PRESENT	0
809884	807226	21068L	PARTICIPANT	\N	PRESENT	0
809885	807226	21055F	PARTICIPANT	\N	PRESENT	0
809886	807226	21058J	PARTICIPANT	\N	PRESENT	0
809887	807226	21091K	PARTICIPANT	\N	PRESENT	0
809888	807226	21063F	PARTICIPANT	\N	PRESENT	0
809889	807226	19697Q	PARTICIPANT	\N	PRESENT	0
809890	807226	19611R	PARTICIPANT	\N	PRESENT	0
809891	807226	20264J	PARTICIPANT	\N	PRESENT	0
809892	807226	19573D	PARTICIPANT	\N	PRESENT	0
809893	807226	14109K	PARTICIPANT	\N	PRESENT	0
809894	807226	21087P	PARTICIPANT	\N	PRESENT	0
809895	807226	14073Q	PARTICIPANT	\N	PRESENT	0
809896	807226	19758L	PARTICIPANT	\N	PRESENT	0
809897	807226	19679N	PARTICIPANT	\N	PRESENT	0
809899	807226	20180F	PARTICIPANT	\N	PRESENT	0
809900	807226	14179A	PARTICIPANT	\N	PRESENT	0
809901	807226	20052X	PARTICIPANT	\N	PRESENT	0
809902	807226	20058E	PARTICIPANT	\N	PRESENT	0
809903	807226	14083S	PARTICIPANT	\N	PRESENT	0
809904	807226	20066E	PARTICIPANT	\N	PRESENT	0
809905	807226	21069M	PARTICIPANT	\N	PRESENT	0
809906	807226	07029T	PARTICIPANT	\N	PRESENT	0
809907	807226	21085M	PARTICIPANT	\N	PRESENT	0
809908	807226	14215L	PARTICIPANT	\N	PRESENT	0
809909	807226	20054A	PARTICIPANT	\N	PRESENT	0
809910	807226	20126Y	PARTICIPANT	\N	PRESENT	0
809926	807992	20034V	PRESIDENT	0	PRESENT	0
809927	807992	21055F	PARTICIPANT	\N	PRESENT	0
809928	807992	14059S	PARTICIPANT	\N	PRESENT	0
809929	807992	19673G	PARTICIPANT	\N	PRESENT	0
809930	807992	21033Y	PARTICIPANT	\N	PRESENT	0
809931	807992	19331L	PARTICIPANT	\N	PRESENT	0
809932	807992	11072N	PARTICIPANT	\N	PRESENT	0
809933	807992	21073H	PARTICIPANT	\N	PRESENT	0
809934	807992	14275Y	PARTICIPANT	\N	PRESENT	0
809935	807992	05008E	PARTICIPANT	\N	PRESENT	0
809936	807992	21035B	PARTICIPANT	\N	PRESENT	0
809944	807992	04042C	PARTICIPANT	\N	EXCUSE	0
809945	807992	17229F	PARTICIPANT	\N	EXCUSE	0
803504	801392	14229S	PARTICIPANT	\N	PRESENT	0
803505	801392	14187A	PARTICIPANT	\N	PRESENT	0
803506	801392	20286Q	PARTICIPANT	\N	PRESENT	0
803507	801392	19631V	PARTICIPANT	\N	PRESENT	0
803508	801392	21089R	PARTICIPANT	\N	PRESENT	0
803509	801392	19647E	PARTICIPANT	\N	PRESENT	0
803510	801392	18231D	PARTICIPANT	\N	PRESENT	0
803511	801392	21059K	PARTICIPANT	\N	PRESENT	0
803512	801392	18395Y	PARTICIPANT	\N	PRESENT	0
803513	801392	21092L	PARTICIPANT	\N	PRESENT	0
803514	801392	21040X	PARTICIPANT	\N	PRESENT	0
803515	801392	21033Y	PARTICIPANT	\N	PRESENT	0
803516	801392	19782L	PARTICIPANT	\N	PRESENT	0
803517	801392	21096Q	PARTICIPANT	\N	PRESENT	0
803518	801392	14205J	PARTICIPANT	\N	PRESENT	0
803519	801392	21050A	PARTICIPANT	\N	PRESENT	0
803520	801392	19679N	PARTICIPANT	\N	PRESENT	0
803521	801392	20090E	PARTICIPANT	\N	PRESENT	0
803522	801392	07029T	PARTICIPANT	\N	PRESENT	0
803523	801392	20180F	PARTICIPANT	\N	PRESENT	0
803524	801392	21058J	PARTICIPANT	\N	PRESENT	0
803525	801392	21075K	PARTICIPANT	\N	PRESENT	0
803526	801392	19758L	PARTICIPANT	\N	PRESENT	0
803527	801392	21084L	PARTICIPANT	\N	PRESENT	0
803528	801392	21070E	PARTICIPANT	\N	PRESENT	0
803529	801392	18207D	PARTICIPANT	\N	PRESENT	0
803530	801392	14257W	PARTICIPANT	\N	PRESENT	0
803531	801392	20266L	PARTICIPANT	\N	PRESENT	0
803532	801392	20034V	PARTICIPANT	\N	PRESENT	0
803533	801392	20054A	PARTICIPANT	\N	PRESENT	0
803534	801392	14021P	PARTICIPANT	\N	PRESENT	0
803535	801392	21056G	PARTICIPANT	\N	PRESENT	0
803536	801392	14215L	PARTICIPANT	\N	PRESENT	0
803537	801392	11072N	PARTICIPANT	\N	PRESENT	0
803538	801392	19760E	PARTICIPANT	\N	PRESENT	0
803544	801392	19533U	PARTICIPANT	\N	PRESENT	0
803556	801392	19701S	PARTICIPANT	\N	PRESENT	0
803570	801392	14357A	PARTICIPANT	\N	PRESENT	0
803572	801392	19713W	PARTICIPANT	\N	PRESENT	0
803606	801392	21082J	PARTICIPANT	\N	PRESENT	0
803607	801392	20066E	PARTICIPANT	\N	PRESENT	0
803672	801392	19575F	PARTICIPANT	\N	PRESENT	0
803699	801392	19629C	PARTICIPANT	\N	PRESENT	0
803776	801392	20040T	PARTICIPANT	\N	PRESENT	0
803780	801392	19447X	PARTICIPANT	\N	PRESENT	0
803782	801392	14026U	PARTICIPANT	\N	PRESENT	0
803815	801392	14147R	PARTICIPANT	\N	PRESENT	0
803816	801392	04042C	PARTICIPANT	\N	PRESENT	0
803817	801392	20100N	PARTICIPANT	\N	PRESENT	0
803818	801392	20092G	PARTICIPANT	\N	PRESENT	0
803819	801392	19347U	PARTICIPANT	\N	PRESENT	0
803999	803989	19533U	PARTICIPANT	\N	PRESENT	0
804001	804000	19479G	PARTICIPANT	\N	PRESENT	0
804015	804013	20034V	PARTICIPANT	\N	PRESENT	0
804011	804000	20110Q	PARTICIPANT	\N	PRESENT	0
804014	804013	19479G	PARTICIPANT	\N	PRESENT	0
804237	804178	14038Y	PARTICIPANT	\N	PRESENT	0
804024	804020	19479G	PARTICIPANT	\N	PRESENT	0
804027	804020	19711U	PARTICIPANT	\N	PRESENT	0
804238	804179	14038Y	PARTICIPANT	\N	PRESENT	0
804239	804201	19349W	PARTICIPANT	\N	PRESENT	0
804240	804201	19479G	PARTICIPANT	\N	PRESENT	0
804241	804201	19711U	PARTICIPANT	\N	PRESENT	0
804242	804201	20042V	PARTICIPANT	\N	PRESENT	0
804243	804201	20060X	PARTICIPANT	\N	PRESENT	0
804244	804201	19399H	PARTICIPANT	\N	PRESENT	0
804245	804201	20086J	PARTICIPANT	\N	PRESENT	0
804246	804203	19349W	PARTICIPANT	\N	PRESENT	0
804247	804203	19479G	PARTICIPANT	\N	PRESENT	0
804248	804203	19703U	PARTICIPANT	\N	PRESENT	0
804249	804203	20024T	PARTICIPANT	\N	PRESENT	0
804250	804203	19711U	PARTICIPANT	\N	PRESENT	0
804251	804197	19735D	PARTICIPANT	\N	PRESENT	0
804252	804197	19723Y	PARTICIPANT	\N	PRESENT	0
804253	804180	14038Y	PARTICIPANT	\N	PRESENT	0
804254	804180	18231D	PARTICIPANT	\N	PRESENT	0
804255	804181	14038Y	PARTICIPANT	\N	PRESENT	0
804256	804181	18231D	PARTICIPANT	\N	PRESENT	0
804257	804182	14038Y	PARTICIPANT	\N	PRESENT	0
804258	804182	18231D	PARTICIPANT	\N	PRESENT	0
804259	804183	14038Y	PARTICIPANT	\N	PRESENT	0
804260	804183	18231D	PARTICIPANT	\N	PRESENT	0
804261	804195	19735D	PARTICIPANT	\N	PRESENT	0
804262	804195	19723Y	PARTICIPANT	\N	PRESENT	0
804263	804200	19735D	PARTICIPANT	\N	PRESENT	0
804264	804200	19723Y	PARTICIPANT	\N	PRESENT	0
804519	803915	95041E	PARTICIPANT	\N	PRESENT	0
804820	804819	21052C	PARTICIPANT	\N	PRESENT	0
804821	804819	19758L	PARTICIPANT	\N	PRESENT	0
804822	804819	14255U	PARTICIPANT	\N	PRESENT	0
804823	804819	18083K	PARTICIPANT	\N	PRESENT	0
804824	804819	20100N	PARTICIPANT	\N	PRESENT	0
804825	804819	17023S	PARTICIPANT	\N	PRESENT	0
804826	804819	19695N	PARTICIPANT	\N	PRESENT	0
804827	804819	20120S	PARTICIPANT	\N	PRESENT	0
804828	804819	20048C	PARTICIPANT	\N	PRESENT	0
804829	804819	19649G	PARTICIPANT	\N	PRESENT	0
804830	804819	20052X	PARTICIPANT	\N	PRESENT	0
804831	804819	21054E	PARTICIPANT	\N	PRESENT	0
804832	804819	04070G	PARTICIPANT	\N	PRESENT	0
804833	804819	14169X	PARTICIPANT	\N	PRESENT	0
804834	804819	11045K	PARTICIPANT	\N	PRESENT	0
804835	804819	21077M	PARTICIPANT	\N	PRESENT	0
804966	804964	19111A	PARTICIPANT	\N	PRESENT	0
805386	803927	17965H	PARTICIPANT	\N	PRESENT	0
806805	804045	86034E	PARTICIPANT	\N	PRESENT	0
806806	804045	21038E	PARTICIPANT	\N	PRESENT	0
806807	804045	19749K	PARTICIPANT	\N	PRESENT	0
806808	804045	19693L	PARTICIPANT	\N	PRESENT	0
806809	804045	14109K	PARTICIPANT	\N	PRESENT	0
806810	804045	20038A	PARTICIPANT	\N	PRESENT	0
806811	804045	14147R	PARTICIPANT	\N	PRESENT	0
806812	804045	19798U	PARTICIPANT	\N	PRESENT	0
806813	804045	14038Y	PARTICIPANT	\N	PRESENT	0
806815	804045	18231D	PARTICIPANT	\N	PRESENT	0
806816	804045	19533U	PARTICIPANT	\N	PRESENT	0
806817	804045	20092G	PARTICIPANT	\N	PRESENT	0
806819	804045	21094N	PARTICIPANT	\N	PRESENT	0
806820	804045	20018V	PARTICIPANT	\N	PRESENT	0
806821	804045	20132W	PARTICIPANT	\N	PRESENT	0
806822	804045	20072C	PARTICIPANT	\N	PRESENT	0
806823	804045	20026V	PARTICIPANT	\N	PRESENT	0
806824	804044	19693L	PARTICIPANT	\N	PRESENT	0
806825	804044	20038A	PARTICIPANT	\N	PRESENT	0
806826	804044	14147R	PARTICIPANT	\N	PRESENT	0
806827	804044	14109K	PARTICIPANT	\N	PRESENT	0
806828	804044	21038E	PARTICIPANT	\N	PRESENT	0
806829	804044	19798U	PARTICIPANT	\N	PRESENT	0
806830	804044	21094N	PARTICIPANT	\N	PRESENT	0
806831	804044	19749K	PARTICIPANT	\N	PRESENT	0
806832	804044	20132W	PARTICIPANT	\N	PRESENT	0
806833	804044	19711U	PARTICIPANT	\N	PRESENT	0
806834	804044	20018V	PARTICIPANT	\N	PRESENT	0
806835	804044	20026V	PARTICIPANT	\N	PRESENT	0
806836	804044	19533U	PARTICIPANT	\N	PRESENT	0
814619	813183	21054E	PARTICIPANT	\N	PRESENT	0
814620	813183	01058X	PARTICIPANT	\N	PRESENT	0
814621	813183	20106U	PARTICIPANT	\N	PRESENT	0
814622	813183	20044X	PARTICIPANT	\N	PRESENT	0
814623	813183	19575F	PARTICIPANT	\N	PRESENT	0
814624	813183	19399H	PARTICIPANT	\N	PRESENT	0
814625	813183	20026V	PARTICIPANT	\N	PRESENT	0
814626	813183	20138D	PARTICIPANT	\N	PRESENT	0
814627	813183	19703U	PARTICIPANT	\N	PRESENT	0
814628	813183	19667J	PARTICIPANT	\N	PRESENT	0
814629	813183	19735D	PARTICIPANT	\N	PRESENT	0
814630	813183	21059K	PARTICIPANT	\N	PRESENT	0
814631	813183	19533U	PARTICIPANT	\N	PRESENT	0
814632	813183	19711U	PARTICIPANT	\N	PRESENT	0
814633	813183	19479G	PARTICIPANT	\N	PRESENT	0
814634	813183	20132W	PARTICIPANT	\N	PRESENT	0
814635	813183	14026U	PARTICIPANT	\N	PRESENT	0
814636	813183	21079P	PARTICIPANT	\N	PRESENT	0
814637	813183	20018V	PARTICIPANT	\N	PRESENT	0
814638	813183	19723Y	PARTICIPANT	\N	PRESENT	0
814639	813183	19349W	PARTICIPANT	\N	PRESENT	0
814642	813183	20072C	PARTICIPANT	\N	EXCUSE	0
814643	813182	19667J	PARTICIPANT	\N	PRESENT	0
814644	813182	19575F	PARTICIPANT	\N	PRESENT	0
814645	813182	20138D	PARTICIPANT	\N	PRESENT	0
814646	813182	19735D	PARTICIPANT	\N	PRESENT	0
814647	813182	19723Y	PARTICIPANT	\N	PRESENT	0
814648	813182	19533U	PARTICIPANT	\N	PRESENT	0
814649	813182	21059K	PARTICIPANT	\N	PRESENT	0
814650	813182	01058X	PARTICIPANT	\N	PRESENT	0
814651	813182	20132W	PARTICIPANT	\N	PRESENT	0
814652	813182	14026U	PARTICIPANT	\N	PRESENT	0
814653	813182	20106U	PARTICIPANT	\N	PRESENT	0
814654	813182	19399H	PARTICIPANT	\N	PRESENT	0
814655	813182	19711U	PARTICIPANT	\N	PRESENT	0
814656	813182	21054E	PARTICIPANT	\N	PRESENT	0
814658	813182	20018V	PARTICIPANT	\N	PRESENT	0
814660	813182	19349W	PARTICIPANT	\N	PRESENT	0
814662	813182	20044X	PARTICIPANT	\N	PRESENT	0
814663	813182	21079P	PARTICIPANT	\N	PRESENT	0
814665	813182	19703U	PARTICIPANT	\N	PRESENT	0
814666	813182	20026V	PARTICIPANT	\N	PRESENT	0
814667	813182	19479G	PARTICIPANT	\N	PRESENT	0
816315	816061	08061X	PARTICIPANT	\N	PRESENT	0
816316	816061	21051B	PARTICIPANT	\N	PRESENT	0
816317	816061	19687N	PARTICIPANT	\N	PRESENT	0
816318	816061	14169X	PARTICIPANT	\N	PRESENT	0
816319	816061	20116W	PARTICIPANT	\N	PRESENT	0
816320	816061	19629C	PARTICIPANT	\N	PRESENT	0
816321	816061	21041Y	PARTICIPANT	\N	PRESENT	0
816322	816061	19719D	PARTICIPANT	\N	PRESENT	0
816323	816061	21066J	PARTICIPANT	\N	PRESENT	0
816324	816061	20142Y	PARTICIPANT	\N	PRESENT	0
816325	816061	04092N	PARTICIPANT	\N	PRESENT	0
816326	816061	19057M	PARTICIPANT	\N	PRESENT	0
816327	816061	14249W	PARTICIPANT	\N	PRESENT	0
816328	816061	20286Q	PARTICIPANT	\N	PRESENT	0
816329	816061	11085T	PARTICIPANT	\N	PRESENT	0
816330	816061	20072C	PARTICIPANT	\N	PRESENT	0
816331	816061	08009T	PARTICIPANT	\N	PRESENT	0
816332	816061	21054E	PARTICIPANT	\N	PRESENT	0
816333	816061	20036X	PARTICIPANT	\N	PRESENT	0
816334	816061	19713W	PARTICIPANT	\N	PRESENT	0
816335	816061	20030R	PARTICIPANT	\N	PRESENT	0
816336	816061	14109K	PARTICIPANT	\N	PRESENT	0
816337	816061	14207L	PARTICIPANT	\N	PRESENT	0
816338	816061	21078N	PARTICIPANT	\N	PRESENT	0
816339	816061	20028X	PARTICIPANT	\N	PRESENT	0
816340	816061	14255U	PARTICIPANT	\N	PRESENT	0
816341	816061	14237S	PARTICIPANT	\N	PRESENT	0
816342	816061	14213J	PARTICIPANT	\N	PRESENT	0
816343	816061	20096L	PARTICIPANT	\N	PRESENT	0
816344	816061	08034U	PARTICIPANT	\N	PRESENT	0
816345	816061	11048N	PARTICIPANT	\N	PRESENT	0
816346	816061	20114U	PARTICIPANT	\N	PRESENT	0
816347	816061	19683J	PARTICIPANT	\N	PRESENT	0
816348	816061	20124W	PARTICIPANT	\N	PRESENT	0
816349	816061	21048G	PARTICIPANT	\N	PRESENT	0
816353	816061	14251Q	PARTICIPANT	\N	PRESENT	0
816351	816061	20126Y	PARTICIPANT	\N	PRESENT	0
816352	816061	20122U	PARTICIPANT	\N	PRESENT	0
816354	816061	19553Y	PARTICIPANT	\N	PRESENT	0
816357	816061	17023S	PARTICIPANT	\N	PRESENT	0
816359	816061	21086N	PARTICIPANT	\N	PRESENT	0
816361	816061	19705W	PARTICIPANT	\N	PRESENT	0
816367	816061	14241N	PARTICIPANT	\N	PRESENT	0
816369	816061	21087P	PARTICIPANT	\N	PRESENT	0
816370	816061	14151M	PARTICIPANT	\N	PRESENT	0
816371	816061	14147R	PARTICIPANT	\N	PRESENT	0
816372	816061	19575F	PARTICIPANT	\N	PRESENT	0
816373	816061	19619A	PARTICIPANT	\N	PRESENT	0
816378	816061	14179A	PARTICIPANT	\N	PRESENT	0
816375	816061	20110Q	PARTICIPANT	\N	PRESENT	0
816376	816061	20060X	PARTICIPANT	\N	PRESENT	0
816377	816061	08015R	PARTICIPANT	\N	PRESENT	0
816379	816061	20078J	PARTICIPANT	\N	PRESENT	0
816380	816061	20106U	PARTICIPANT	\N	PRESENT	0
816381	816061	19489J	PARTICIPANT	\N	PRESENT	0
816382	816061	18193Q	PARTICIPANT	\N	PRESENT	0
816383	816061	20048C	PARTICIPANT	\N	PRESENT	0
816384	816061	20248J	PARTICIPANT	\N	PRESENT	0
816385	816061	20024T	PARTICIPANT	\N	PRESENT	0
816386	816061	20066E	PARTICIPANT	\N	PRESENT	0
816387	816061	11053K	PARTICIPANT	\N	PRESENT	0
816388	816061	14069U	PARTICIPANT	\N	PRESENT	0
816389	816061	20180F	PARTICIPANT	\N	PRESENT	0
816390	816061	14355X	PARTICIPANT	\N	PRESENT	0
816391	816061	20172F	PARTICIPANT	\N	PRESENT	0
816392	816061	20046A	PARTICIPANT	\N	PRESENT	0
816396	816061	15197G	PARTICIPANT	\N	PRESENT	0
816394	816061	20104S	PARTICIPANT	\N	PRESENT	0
816395	816061	14107H	PARTICIPANT	\N	PRESENT	0
816397	816061	14357A	PARTICIPANT	\N	PRESENT	0
816398	816061	19685L	PARTICIPANT	\N	PRESENT	0
816399	816061	20070A	PARTICIPANT	\N	PRESENT	0
816400	816061	20138D	PARTICIPANT	\N	PRESENT	0
816684	815932	14111D	PARTICIPANT	\N	PRESENT	0
816685	815932	04070G	PARTICIPANT	\N	PRESENT	0
816686	815932	14038Y	PARTICIPANT	\N	PRESENT	0
816690	815932	20134Y	PARTICIPANT	\N	PRESENT	0
816688	815932	20122U	PARTICIPANT	\N	PRESENT	0
816689	815932	14179A	PARTICIPANT	\N	PRESENT	0
816691	815932	19687N	PARTICIPANT	\N	PRESENT	0
816692	815932	20132W	PARTICIPANT	\N	PRESENT	0
816693	815932	20128B	PARTICIPANT	\N	PRESENT	0
816694	815932	20094J	PARTICIPANT	\N	PRESENT	0
816695	815932	19649G	PARTICIPANT	\N	PRESENT	0
816696	815932	19725B	PARTICIPANT	\N	PRESENT	0
816697	815932	21057H	PARTICIPANT	\N	PRESENT	0
816698	815932	20060X	PARTICIPANT	\N	PRESENT	0
816699	815932	20082E	PARTICIPANT	\N	PRESENT	0
816700	815932	20028X	PARTICIPANT	\N	PRESENT	0
816701	815932	21045D	PARTICIPANT	\N	PRESENT	0
816702	815932	11045K	PARTICIPANT	\N	PRESENT	0
816703	815932	18193Q	PARTICIPANT	\N	PRESENT	0
816704	815932	19545Y	PARTICIPANT	\N	PRESENT	0
816705	815932	21070E	PARTICIPANT	\N	PRESENT	0
816706	815932	19479G	PARTICIPANT	\N	PRESENT	0
816707	815932	19719D	PARTICIPANT	\N	PRESENT	0
816708	815932	14059S	PARTICIPANT	\N	PRESENT	0
816709	815932	21039F	PARTICIPANT	\N	PRESENT	0
816710	815932	20180F	PARTICIPANT	\N	PRESENT	0
816711	815932	14237S	PARTICIPANT	\N	PRESENT	0
816712	815932	19573D	PARTICIPANT	\N	PRESENT	0
816713	815932	14031R	PARTICIPANT	\N	PRESENT	0
816714	815932	20096L	PARTICIPANT	\N	PRESENT	0
816715	815932	08028W	PARTICIPANT	\N	PRESENT	0
816716	815932	21034A	PARTICIPANT	\N	PRESENT	0
816717	815932	20286Q	PARTICIPANT	\N	PRESENT	0
816718	815932	19758L	PARTICIPANT	\N	PRESENT	0
816719	815932	07004J	PARTICIPANT	\N	PRESENT	0
816720	815932	19954N	PARTICIPANT	\N	PRESENT	0
816721	815932	20022R	PARTICIPANT	\N	PRESENT	0
816722	815932	20034V	PARTICIPANT	\N	PRESENT	0
816723	815932	14191V	PARTICIPANT	\N	PRESENT	0
816724	815932	20038A	PARTICIPANT	\N	PRESENT	0
816725	815932	21043B	PARTICIPANT	\N	PRESENT	0
816726	815932	14030Q	PARTICIPANT	\N	PRESENT	0
816727	815932	19745F	PARTICIPANT	\N	PRESENT	0
801086	801085	14193X	PARTICIPANT	\N	PRESENT	0
801087	801085	14097Y	PARTICIPANT	\N	PRESENT	0
801088	801085	14053L	PARTICIPANT	\N	PRESENT	0
801092	801085	04047H	PARTICIPANT	\N	PRESENT	0
807631	807353	14257W	PARTICIPANT	\N	PRESENT	0
807632	807353	20030R	PARTICIPANT	\N	EXCUSE	0
807633	807353	21052C	PARTICIPANT	\N	EXCUSE	0
807634	807353	20084G	PARTICIPANT	\N	EXCUSE	0
807636	807175	14205J	PARTICIPANT	\N	PRESENT	0
807637	807175	20066E	PARTICIPANT	\N	PRESENT	0
807638	807175	14207L	PARTICIPANT	\N	PRESENT	0
807644	807175	21050A	PARTICIPANT	\N	PRESENT	0
807647	807175	20036X	PARTICIPANT	\N	PRESENT	0
807648	807175	21049H	PARTICIPANT	\N	PRESENT	0
807649	807175	19760E	PARTICIPANT	\N	PRESENT	0
807650	807175	14069U	PARTICIPANT	\N	PRESENT	0
807651	807175	18083K	PARTICIPANT	\N	PRESENT	0
807652	807175	19679N	PARTICIPANT	\N	PRESENT	0
807653	807175	08028W	PARTICIPANT	\N	PRESENT	0
807654	807175	20028X	PARTICIPANT	\N	PRESENT	0
807655	807175	01058X	PARTICIPANT	\N	PRESENT	0
807656	807175	14147R	PARTICIPANT	\N	PRESENT	0
807657	807176	14259Y	PARTICIPANT	\N	PRESENT	0
807658	807176	20046A	PARTICIPANT	\N	PRESENT	0
807659	807176	20102Q	PARTICIPANT	\N	PRESENT	0
807776	807771	11048N	PARTICIPANT	\N	PRESENT	0
807661	807176	21070E	PARTICIPANT	\N	PRESENT	0
807777	807771	19479G	PARTICIPANT	\N	PRESENT	0
807663	807176	21039F	PARTICIPANT	\N	PRESENT	0
807778	807771	19711U	PARTICIPANT	\N	PRESENT	0
807665	807176	14111D	PARTICIPANT	\N	PRESENT	0
807666	807176	20038A	PARTICIPANT	\N	PRESENT	0
807779	807771	19545Y	PARTICIPANT	\N	PRESENT	0
807668	807176	20032T	PARTICIPANT	\N	PRESENT	0
807669	807176	18207D	PARTICIPANT	\N	PRESENT	0
807670	807176	04045F	PARTICIPANT	\N	PRESENT	0
807780	807771	20080C	PARTICIPANT	\N	PRESENT	0
807672	807176	20140W	PARTICIPANT	\N	PRESENT	0
807781	807771	11074Q	PARTICIPANT	\N	PRESENT	0
807674	807176	21038E	PARTICIPANT	\N	PRESENT	0
807675	807176	11043H	PARTICIPANT	\N	PRESENT	0
807782	807771	20094J	PARTICIPANT	\N	PRESENT	0
807783	807771	20044X	PARTICIPANT	\N	PRESENT	0
807678	807176	14223L	PARTICIPANT	\N	PRESENT	0
807679	807176	19251M	PARTICIPANT	\N	PRESENT	0
807784	807771	19399H	PARTICIPANT	\N	PRESENT	0
807785	807771	14225N	PRESIDENT	0	PRESENT	0
807682	807176	20100N	PARTICIPANT	\N	PRESENT	0
807683	807176	14189C	PARTICIPANT	\N	PRESENT	0
807786	807771	14083S	PARTICIPANT	\N	PRESENT	0
807788	807771	20070A	PARTICIPANT	\N	PRESENT	0
807686	807176	19798U	PARTICIPANT	\N	PRESENT	0
807687	807176	14217N	PARTICIPANT	\N	PRESENT	0
807789	807771	21090J	PARTICIPANT	\N	PRESENT	0
807790	807771	20024T	PARTICIPANT	\N	PRESENT	0
807690	807176	14121F	PARTICIPANT	\N	PRESENT	0
808192	807004	18231D	PARTICIPANT	\N	PRESENT	0
808193	807004	21038E	PARTICIPANT	\N	PRESENT	0
807693	807176	21067K	PARTICIPANT	\N	PRESENT	0
807694	807176	19551W	PARTICIPANT	\N	PRESENT	0
807695	807176	20110Q	PARTICIPANT	\N	PRESENT	0
808195	804284	20132W	PARTICIPANT	\N	PRESENT	0
807697	807176	20136B	PARTICIPANT	\N	PRESENT	0
808200	807004	20098N	PARTICIPANT	\N	PRESENT	0
807699	807176	14083S	PARTICIPANT	\N	PRESENT	0
808202	808129	08034U	PARTICIPANT	\N	PRESENT	0
807701	807176	19735D	PARTICIPANT	\N	PRESENT	0
807702	807176	19826F	PARTICIPANT	\N	PRESENT	0
808203	808129	19687N	PARTICIPANT	\N	PRESENT	0
807704	807176	20034V	PARTICIPANT	\N	PRESENT	0
808204	808129	20080C	PARTICIPANT	\N	PRESENT	0
807706	807176	20026V	PARTICIPANT	\N	PRESENT	0
807707	807176	14205J	PARTICIPANT	\N	PRESENT	0
807708	807176	20066E	PARTICIPANT	\N	PRESENT	0
808205	808129	11053K	PARTICIPANT	\N	PRESENT	0
807710	807176	21050A	PARTICIPANT	\N	PRESENT	0
807711	807176	20036X	PARTICIPANT	\N	PRESENT	0
807712	807176	21049H	PARTICIPANT	\N	PRESENT	0
807713	807176	19760E	PARTICIPANT	\N	PRESENT	0
808206	808129	11074Q	PARTICIPANT	\N	PRESENT	0
808207	808129	08011M	PARTICIPANT	\N	PRESENT	0
807716	807176	19679N	PARTICIPANT	\N	PRESENT	0
808208	808129	19399H	PARTICIPANT	\N	PRESENT	0
807718	807176	20028X	PARTICIPANT	\N	PRESENT	0
807719	807176	01058X	PARTICIPANT	\N	PRESENT	0
807720	807176	14147R	PARTICIPANT	\N	PRESENT	0
808209	808129	11110B	PARTICIPANT	\N	PRESENT	0
808210	808129	14173T	PARTICIPANT	\N	PRESENT	0
808211	808129	11040E	PARTICIPANT	\N	PRESENT	0
808212	808129	14083S	PARTICIPANT	\N	PRESENT	0
808213	808129	20062A	PARTICIPANT	\N	PRESENT	0
808214	808129	21079P	PARTICIPANT	\N	PRESENT	0
808215	808129	19349W	PARTICIPANT	\N	PRESENT	0
808216	808129	14121F	PARTICIPANT	\N	PRESENT	0
808217	808129	20116W	PARTICIPANT	\N	PRESENT	0
808218	808129	19335Q	PARTICIPANT	\N	PRESENT	0
808219	808129	20086J	PARTICIPANT	\N	PRESENT	0
808220	808129	19667J	PARTICIPANT	\N	PRESENT	0
808221	808129	19573D	PARTICIPANT	\N	PRESENT	0
808222	808129	20024T	PARTICIPANT	\N	PRESENT	0
808223	808129	11048N	PARTICIPANT	\N	PRESENT	0
808224	808129	19479G	PARTICIPANT	\N	PRESENT	0
808225	807221	86034E	PARTICIPANT	\N	PRESENT	0
808226	808129	20070A	PARTICIPANT	\N	PRESENT	0
808230	807246	20072C	PARTICIPANT	\N	PRESENT	0
808231	807246	19565D	PARTICIPANT	\N	PRESENT	0
808232	807246	21031W	PARTICIPANT	\N	PRESENT	0
808233	807246	01058X	PARTICIPANT	\N	PRESENT	0
808234	807246	14001X	PARTICIPANT	\N	PRESENT	0
808235	807246	11027H	PARTICIPANT	\N	PRESENT	0
808236	807246	04042C	PARTICIPANT	\N	PRESENT	0
808237	807246	19669L	PARTICIPANT	\N	PRESENT	0
808238	807246	12028B	PARTICIPANT	\N	PRESENT	0
808239	807246	17737W	PARTICIPANT	\N	PRESENT	0
808240	807246	19421M	PARTICIPANT	\N	PRESENT	0
808241	807246	21067K	PARTICIPANT	\N	PRESENT	0
808242	807246	19709B	PARTICIPANT	\N	PRESENT	0
808243	807246	19347U	PARTICIPANT	\N	PRESENT	0
808244	807246	14193X	PRESIDENT	0	PRESENT	0
808245	807246	14179A	PARTICIPANT	\N	PRESENT	0
808246	807246	07033P	PARTICIPANT	\N	PRESENT	0
808247	807246	17367Q	PARTICIPANT	\N	PRESENT	0
808248	807246	14249W	PARTICIPANT	\N	PRESENT	0
808249	807246	08047A	PARTICIPANT	\N	PRESENT	0
808250	807246	20128B	PARTICIPANT	\N	PRESENT	0
808251	807246	14037X	PARTICIPANT	\N	PRESENT	0
808252	807246	14097Y	PARTICIPANT	\N	PRESENT	0
808253	807246	21073H	PARTICIPANT	\N	PRESENT	0
808254	807246	19531S	PARTICIPANT	\N	PRESENT	0
808256	807246	08069G	PARTICIPANT	\N	PRESENT	0
808257	807246	20042V	PARTICIPANT	\N	PRESENT	0
808258	807246	19721W	PARTICIPANT	\N	PRESENT	0
808259	807246	14191V	PARTICIPANT	\N	PRESENT	0
808260	807246	20064C	PARTICIPANT	\N	PRESENT	0
808261	807246	14251Q	PARTICIPANT	\N	PRESENT	0
808262	807246	14267Y	PARTICIPANT	\N	PRESENT	0
808263	807246	99004R	PARTICIPANT	\N	PRESENT	0
808264	807246	14211G	PARTICIPANT	\N	PRESENT	0
808265	807246	14255U	PARTICIPANT	\N	PRESENT	0
808266	808129	08010L	PARTICIPANT	\N	PRESENT	0
808267	808129	19647E	PARTICIPANT	\N	PRESENT	0
808268	808129	14331P	PARTICIPANT	\N	PRESENT	0
808269	808129	20044X	PARTICIPANT	\N	PRESENT	0
808272	807004	11085T	PARTICIPANT	\N	PRESENT	0
808274	808129	20094J	PARTICIPANT	\N	PRESENT	0
808275	808129	14225N	PRESIDENT	0	PRESENT	0
808277	804284	04070G	PARTICIPANT	\N	PRESENT	0
808278	804284	21058J	PARTICIPANT	\N	PRESENT	0
808279	804284	20124W	PARTICIPANT	\N	PRESENT	0
808280	804284	20052X	PARTICIPANT	\N	PRESENT	0
808282	808129	20126Y	PARTICIPANT	\N	PRESENT	0
808289	807004	04047H	PRESIDENT	1	PRESENT	0
808309	807004	20054A	PARTICIPANT	\N	PRESENT	0
808311	807246	14059S	PARTICIPANT	\N	PRESENT	0
808312	807246	19507S	PARTICIPANT	\N	PRESENT	0
808313	807246	19745F	PARTICIPANT	\N	PRESENT	0
809948	807992	21071F	PARTICIPANT	\N	EXCUSE	0
809949	807992	21029D	PARTICIPANT	\N	EXCUSE	0
809950	807992	19745F	PARTICIPANT	\N	EXCUSE	0
809951	807992	20150Y	PARTICIPANT	\N	EXCUSE	0
810090	810089	20096L	PARTICIPANT	\N	PRESENT	0
810092	810091	20104S	PARTICIPANT	\N	PRESENT	0
810093	810091	18193Q	PARTICIPANT	\N	PRESENT	0
810094	810091	21059K	PARTICIPANT	\N	PRESENT	0
810095	810091	19687N	PARTICIPANT	\N	PRESENT	0
810096	810091	20026V	PARTICIPANT	\N	PRESENT	0
810097	810091	20096L	PARTICIPANT	\N	PRESENT	0
810098	810091	19573D	PARTICIPANT	\N	PRESENT	0
810099	810091	21032X	PARTICIPANT	\N	PRESENT	0
810101	810100	20104S	PARTICIPANT	\N	PRESENT	0
810114	807229	11040E	PARTICIPANT	\N	PRESENT	0
810115	807229	21034A	PARTICIPANT	\N	PRESENT	0
810116	807229	21070E	PARTICIPANT	\N	PRESENT	0
810117	807229	21049H	PARTICIPANT	\N	PRESENT	0
810118	807229	11048N	PARTICIPANT	\N	PRESENT	0
810119	807229	14253S	PARTICIPANT	\N	PRESENT	0
810120	807229	19667J	PARTICIPANT	\N	PRESENT	0
810121	807229	21079P	PARTICIPANT	\N	PRESENT	0
810122	807229	11072N	PARTICIPANT	\N	PRESENT	0
810124	810123	14133K	PARTICIPANT	\N	PRESENT	0
810144	807229	20062A	PARTICIPANT	\N	PRESENT	0
810127	810126	14133K	PARTICIPANT	\N	PRESENT	0
810129	810128	14133K	PARTICIPANT	\N	PRESENT	0
810131	810130	14133K	PARTICIPANT	\N	PRESENT	0
810132	807229	11053K	PARTICIPANT	\N	PRESENT	0
810133	807229	21082J	PARTICIPANT	\N	PRESENT	0
810134	807229	08045X	PARTICIPANT	\N	PRESENT	0
810135	807229	14083S	PARTICIPANT	\N	PRESENT	0
810136	807229	21073H	PARTICIPANT	\N	PRESENT	0
810137	807229	19629C	PARTICIPANT	\N	PRESENT	0
810138	807229	20034V	PARTICIPANT	\N	PRESENT	0
810139	807229	19631V	PARTICIPANT	\N	PRESENT	0
810140	807229	19647E	PARTICIPANT	\N	PRESENT	0
810142	807229	19553Y	PARTICIPANT	\N	PRESENT	0
810146	807229	21038E	PARTICIPANT	\N	PRESENT	0
810145	807229	14255U	PARTICIPANT	\N	PRESENT	0
810147	807229	20094J	PARTICIPANT	\N	PRESENT	0
810148	807229	14030Q	PARTICIPANT	\N	PRESENT	0
810149	807229	14275Y	PARTICIPANT	\N	PRESENT	0
810152	807229	07029T	PARTICIPANT	\N	PRESENT	0
810185	807230	07029T	PARTICIPANT	\N	PRESENT	0
810186	807230	21038E	PARTICIPANT	\N	PRESENT	0
810187	807230	14030Q	PARTICIPANT	\N	PRESENT	0
810188	807230	14275Y	PARTICIPANT	\N	PRESENT	0
810189	807230	14255U	PARTICIPANT	\N	PRESENT	0
810190	807230	21070E	PARTICIPANT	\N	PRESENT	0
810191	807230	21079P	PARTICIPANT	\N	PRESENT	0
810192	807230	21082J	PARTICIPANT	\N	PRESENT	0
810193	807230	08045X	PARTICIPANT	\N	PRESENT	0
810194	807230	19647E	PARTICIPANT	\N	PRESENT	0
810195	807230	20094J	PARTICIPANT	\N	PRESENT	0
810196	807230	11040E	PARTICIPANT	\N	PRESENT	0
810197	807230	21034A	PARTICIPANT	\N	PRESENT	0
810198	807230	19553Y	PARTICIPANT	\N	PRESENT	0
810199	807230	11072N	PARTICIPANT	\N	PRESENT	0
810200	807230	19335Q	PARTICIPANT	\N	PRESENT	0
810201	807230	14083S	PARTICIPANT	\N	PRESENT	0
810202	807230	11048N	PARTICIPANT	\N	PRESENT	0
810203	807230	20062A	PARTICIPANT	\N	PRESENT	0
810205	807230	20048C	PARTICIPANT	\N	PRESENT	0
810212	807230	20052X	PARTICIPANT	\N	PRESENT	0
810213	806962	19709B	PARTICIPANT	\N	PRESENT	0
810214	806962	21076L	PARTICIPANT	\N	PRESENT	0
810215	806962	21082J	PARTICIPANT	\N	PRESENT	0
810216	806962	14331P	PRESIDENT	0	PRESENT	0
810217	806962	18207D	PARTICIPANT	\N	PRESENT	0
810218	806962	19569H	PARTICIPANT	\N	PRESENT	0
810183	807230	11090Q	PARTICIPANT	\N	PRESENT	0
810184	807230	14253S	PARTICIPANT	\N	PRESENT	0
810219	807230	21049H	PARTICIPANT	\N	PRESENT	0
810220	806962	20100N	PARTICIPANT	\N	PRESENT	0
810221	807230	20034V	PARTICIPANT	\N	PRESENT	0
810222	807230	14031R	PARTICIPANT	\N	PRESENT	0
810223	806962	14033T	PARTICIPANT	\N	PRESENT	0
810224	806962	04092N	PARTICIPANT	\N	PRESENT	0
810225	806962	19565D	PARTICIPANT	\N	PRESENT	0
810226	807230	21054E	PARTICIPANT	\N	PRESENT	0
810247	807231	21054E	PARTICIPANT	\N	PRESENT	0
810248	807231	08045X	PARTICIPANT	\N	PRESENT	0
810249	807231	14071N	PARTICIPANT	\N	PRESENT	0
810250	807231	21071F	PARTICIPANT	\N	PRESENT	0
810251	807231	14275Y	PARTICIPANT	\N	PRESENT	0
810252	807231	21034A	PARTICIPANT	\N	PRESENT	0
810253	807231	19553Y	PARTICIPANT	\N	PRESENT	0
810254	807231	11072N	PARTICIPANT	\N	PRESENT	0
810255	807231	20034V	PARTICIPANT	\N	PRESENT	0
810256	807231	21094N	PARTICIPANT	\N	PRESENT	0
810257	807231	07029T	PARTICIPANT	\N	PRESENT	0
810259	807231	21049H	PARTICIPANT	\N	PRESENT	0
810260	807231	14255U	PARTICIPANT	\N	PRESENT	0
810262	807231	21075K	PARTICIPANT	\N	PRESENT	0
810263	807231	20134Y	PARTICIPANT	\N	PRESENT	0
810331	810330	19573D	PARTICIPANT	\N	PRESENT	0
810338	810337	19573D	PARTICIPANT	\N	PRESENT	0
810351	810349	19573D	PARTICIPANT	\N	PRESENT	0
810245	807231	11090Q	PARTICIPANT	\N	PRESENT	0
810246	807231	14030Q	PARTICIPANT	\N	PRESENT	0
810361	810359	20116W	PARTICIPANT	\N	PRESENT	0
810370	810369	20116W	PARTICIPANT	\N	PRESENT	0
809946	807992	19691J	PARTICIPANT	\N	EXCUSE	0
809947	807992	20016T	PARTICIPANT	\N	EXCUSE	0
810372	810371	20116W	PARTICIPANT	\N	PRESENT	0
810377	810376	20116W	PARTICIPANT	\N	PRESENT	0
810410	810408	19631V	PARTICIPANT	\N	PRESENT	0
810411	810408	21050A	PARTICIPANT	\N	PRESENT	0
810412	810408	14329V	PARTICIPANT	\N	PRESENT	0
810413	810408	14187A	PARTICIPANT	\N	PRESENT	0
810414	810408	19647E	PARTICIPANT	\N	PRESENT	0
810415	810408	21033Y	PARTICIPANT	\N	PRESENT	0
810416	810408	20286Q	PARTICIPANT	\N	PRESENT	0
810417	810408	18207D	PARTICIPANT	\N	PRESENT	0
810418	810408	21075K	PARTICIPANT	\N	PRESENT	0
810419	810408	21070E	PARTICIPANT	\N	PRESENT	0
810473	810472	11048N	PARTICIPANT	\N	PRESENT	0
810475	810474	11048N	PARTICIPANT	\N	PRESENT	0
810523	810522	19683J	PARTICIPANT	\N	PRESENT	0
810524	810522	14026U	PARTICIPANT	\N	PRESENT	0
810525	810522	19760E	PARTICIPANT	\N	PRESENT	0
810528	810476	14187A	PARTICIPANT	\N	PRESENT	0
810531	810476	20286Q	PARTICIPANT	\N	PRESENT	0
810532	810476	19768N	PARTICIPANT	\N	PRESENT	0
810535	809316	21089R	PARTICIPANT	\N	PRESENT	0
810536	809316	20180F	PARTICIPANT	\N	PRESENT	0
810537	809316	19749K	PARTICIPANT	\N	PRESENT	0
810538	809316	14147R	PARTICIPANT	\N	PRESENT	0
810542	810541	19631V	PARTICIPANT	\N	PRESENT	0
810543	810541	21050A	PARTICIPANT	\N	PRESENT	0
810544	810541	21086N	PARTICIPANT	\N	PRESENT	0
810545	810541	21066J	PARTICIPANT	\N	PRESENT	0
810546	810541	21092L	PARTICIPANT	\N	PRESENT	0
810547	810541	20018V	PARTICIPANT	\N	PRESENT	0
810548	810541	19768N	PARTICIPANT	\N	PRESENT	0
810549	810541	20030R	PARTICIPANT	\N	PRESENT	0
810553	810264	14255U	PARTICIPANT	\N	PRESENT	0
810554	810264	17737W	PARTICIPANT	\N	PRESENT	0
810565	810204	17229F	PARTICIPANT	\N	PRESENT	0
810567	810566	19479G	PARTICIPANT	\N	PRESENT	0
810568	810566	19749K	PARTICIPANT	\N	PRESENT	0
810575	810266	20146D	PARTICIPANT	\N	EXCUSE	0
810794	810793	19575F	PARTICIPANT	\N	PRESENT	0
810795	810793	14207L	PARTICIPANT	\N	EXCUSE	0
810796	810793	18083K	PARTICIPANT	\N	PRESENT	0
810797	810793	20120S	PARTICIPANT	\N	PRESENT	0
810798	810793	14031R	PARTICIPANT	\N	PRESENT	0
810799	810793	20018V	PARTICIPANT	\N	PRESENT	0
810800	810793	19619A	PARTICIPANT	\N	PRESENT	0
810801	810793	19533U	PARTICIPANT	\N	PRESENT	0
810803	810793	14033T	PARTICIPANT	\N	PRESENT	0
810804	810793	11070L	PARTICIPANT	\N	PRESENT	0
810805	810793	14257W	PRESIDENT	0	PRESENT	0
810815	810204	21073H	PARTICIPANT	\N	EXCUSE	0
810816	810204	19331L	PARTICIPANT	\N	EXCUSE	0
810818	810204	21071F	PARTICIPANT	\N	EXCUSE	0
810822	810302	04092N	PARTICIPANT	\N	PRESENT	0
810823	810302	19563B	PARTICIPANT	\N	PRESENT	0
810824	810302	14217N	PARTICIPANT	\N	PRESENT	0
810825	810302	19479G	PARTICIPANT	\N	PRESENT	0
802309	797914	21077M	PARTICIPANT	\N	PRESENT	0
802310	797914	14229S	PARTICIPANT	\N	PRESENT	0
802311	801571	21082J	PARTICIPANT	\N	PRESENT	0
802312	801571	21029D	PARTICIPANT	\N	PRESENT	0
802313	801571	19701S	PARTICIPANT	\N	PRESENT	0
802314	801571	21035B	PARTICIPANT	\N	PRESENT	0
802315	801571	20076G	PARTICIPANT	\N	PRESENT	0
802316	801571	21042A	PARTICIPANT	\N	PRESENT	0
802317	801571	14219Q	PRESIDENT	0	PRESENT	0
802318	801571	19820Y	PARTICIPANT	\N	PRESENT	0
802319	801571	19826F	PARTICIPANT	\N	PRESENT	0
802320	801571	21060C	PARTICIPANT	\N	PRESENT	0
802321	801571	21061D	PARTICIPANT	\N	PRESENT	0
802322	801571	21065H	PARTICIPANT	\N	PRESENT	0
802323	801571	20100N	PARTICIPANT	\N	PRESENT	0
802324	801571	19551W	PARTICIPANT	\N	PRESENT	0
802325	801571	18083K	PARTICIPANT	\N	PRESENT	0
802326	801571	14237S	PARTICIPANT	\N	PRESENT	0
802327	801571	21084L	PARTICIPANT	\N	PRESENT	0
802328	801571	19954N	PARTICIPANT	\N	PRESENT	0
802329	801571	05012A	PARTICIPANT	\N	PRESENT	0
802330	801571	20106U	PARTICIPANT	\N	PRESENT	0
802331	801571	08060W	PARTICIPANT	\N	PRESENT	0
802332	801571	15197G	PARTICIPANT	\N	PRESENT	0
802333	801571	20118Y	PARTICIPANT	\N	PRESENT	0
802334	801571	14107H	PARTICIPANT	\N	PRESENT	0
802335	801571	21080G	PARTICIPANT	\N	PRESENT	0
802336	801571	19685L	PARTICIPANT	\N	PRESENT	0
802337	801571	11065P	PARTICIPANT	\N	PRESENT	0
802338	801571	20120S	PARTICIPANT	\N	PRESENT	0
802339	801571	21053D	PARTICIPANT	\N	PRESENT	0
802340	801571	20136B	PARTICIPANT	\N	PRESENT	0
802341	801571	14031R	PARTICIPANT	\N	PRESENT	0
802342	801571	20040T	PARTICIPANT	\N	PRESENT	0
802343	801571	19251M	PARTICIPANT	\N	PRESENT	0
802344	801571	20046A	PARTICIPANT	\N	PRESENT	0
802345	801571	20146D	PARTICIPANT	\N	PRESENT	0
802346	801571	17229F	PARTICIPANT	\N	PRESENT	0
802347	801571	21047F	PARTICIPANT	\N	PRESENT	0
802348	801571	20068G	PARTICIPANT	\N	PRESENT	0
802349	801571	21068L	PARTICIPANT	\N	PRESENT	0
802350	801571	21070E	PARTICIPANT	\N	PRESENT	0
802545	801389	14195A	PARTICIPANT	\N	PRESENT	0
802352	801571	19681G	PARTICIPANT	\N	EXCUSE	0
802353	801571	21062E	PARTICIPANT	\N	EXCUSE	0
802354	801571	21051B	PARTICIPANT	\N	EXCUSE	0
802375	802222	21036C	PARTICIPANT	\N	PRESENT	0
802376	802222	20072C	PARTICIPANT	\N	PRESENT	0
802377	802222	19565D	PARTICIPANT	\N	PRESENT	0
802378	802222	21031W	PARTICIPANT	\N	PRESENT	0
802379	802222	01058X	PARTICIPANT	\N	PRESENT	0
802380	802222	04042C	PARTICIPANT	\N	PRESENT	0
802381	802222	08056B	PARTICIPANT	\N	PRESENT	0
802382	802222	12028B	PARTICIPANT	\N	PRESENT	0
802383	802222	19421M	PARTICIPANT	\N	PRESENT	0
802384	802222	21067K	PARTICIPANT	\N	PRESENT	0
802385	802222	19709B	PARTICIPANT	\N	PRESENT	0
802386	802222	14193X	PRESIDENT	1	PRESENT	0
802387	802222	19347U	PARTICIPANT	\N	PRESENT	0
802388	802222	14179A	PARTICIPANT	\N	PRESENT	0
802389	802222	07033P	PRESIDENT	0	PRESENT	0
802390	802222	17367Q	PARTICIPANT	\N	PRESENT	0
802391	802222	08047A	PARTICIPANT	\N	PRESENT	0
802392	802222	20128B	PARTICIPANT	\N	PRESENT	0
802393	802222	14037X	PARTICIPANT	\N	PRESENT	0
802394	802222	14059S	PARTICIPANT	\N	PRESENT	0
802395	802222	14097Y	PARTICIPANT	\N	PRESENT	0
802396	802222	21073H	PARTICIPANT	\N	PRESENT	0
802397	802222	20042V	PARTICIPANT	\N	PRESENT	0
802398	802222	14191V	PARTICIPANT	\N	PRESENT	0
802399	802222	20252E	PARTICIPANT	\N	PRESENT	0
802400	802222	98022P	PARTICIPANT	\N	PRESENT	0
802401	802222	14267Y	PARTICIPANT	\N	PRESENT	0
802402	802222	19745F	PARTICIPANT	\N	PRESENT	0
802403	802222	99004R	PARTICIPANT	\N	PRESENT	0
802404	802222	14211G	PARTICIPANT	\N	PRESENT	0
802405	802222	17023S	PARTICIPANT	\N	PRESENT	0
802406	802222	14105F	PARTICIPANT	\N	PRESENT	0
802407	802222	17737W	PARTICIPANT	\N	PRESENT	0
802408	802222	14133K	PARTICIPANT	\N	PRESENT	0
802409	802222	20064C	PARTICIPANT	\N	EXCUSE	0
802410	802222	19531S	PARTICIPANT	\N	EXCUSE	0
802411	802222	11027H	PARTICIPANT	\N	EXCUSE	0
802412	802222	14001X	PARTICIPANT	\N	EXCUSE	0
802413	800773	20074E	PARTICIPANT	\N	PRESENT	0
802414	800773	10015M	PARTICIPANT	\N	PRESENT	0
802415	800773	21057H	PARTICIPANT	\N	PRESENT	0
802416	800773	04047H	PRESIDENT	0	PRESENT	0
802417	800773	19673G	PARTICIPANT	\N	PRESENT	0
802418	800773	19719D	PARTICIPANT	\N	PRESENT	0
802419	800773	14231L	PARTICIPANT	\N	PRESENT	0
802420	800773	19447X	PARTICIPANT	\N	PRESENT	0
802421	800773	21044C	PARTICIPANT	\N	PRESENT	0
802422	800773	19489J	PARTICIPANT	\N	PRESENT	0
802423	800773	21056G	PARTICIPANT	\N	PRESENT	0
802424	800773	18207D	PARTICIPANT	\N	PRESENT	0
802425	800773	18231D	PARTICIPANT	\N	PRESENT	0
802426	800773	20110Q	PARTICIPANT	\N	PRESENT	0
802427	800773	19111A	PARTICIPANT	\N	PRESENT	0
802428	800773	14215L	PARTICIPANT	\N	PRESENT	0
802429	800773	21038E	PARTICIPANT	\N	PRESENT	0
802430	800773	20022R	PARTICIPANT	\N	PRESENT	0
802431	800773	14053L	PARTICIPANT	\N	PRESENT	0
802432	800773	19649G	PARTICIPANT	\N	PRESENT	0
802433	800773	14189C	PARTICIPANT	\N	PRESENT	0
802434	800773	21076L	PARTICIPANT	\N	PRESENT	0
802435	800773	04045F	PARTICIPANT	\N	PRESENT	0
802436	800773	21040X	PARTICIPANT	\N	PRESENT	0
802437	800773	20098N	PARTICIPANT	\N	PRESENT	0
802438	800773	05008E	PARTICIPANT	\N	PRESENT	0
802439	800773	14089Y	PARTICIPANT	\N	PRESENT	0
802440	800773	21043B	PARTICIPANT	\N	PRESENT	0
802441	800773	19725B	PARTICIPANT	\N	PRESENT	0
802442	800773	20266L	PARTICIPANT	\N	PRESENT	0
802443	800773	20108W	PARTICIPANT	\N	PRESENT	0
802444	800773	21088Q	PARTICIPANT	\N	PRESENT	0
802445	800773	14147R	PARTICIPANT	\N	PRESENT	0
802446	800773	14069U	PARTICIPANT	\N	PRESENT	0
802447	800773	20114U	PARTICIPANT	\N	PRESENT	0
802448	800773	11085T	PARTICIPANT	\N	PRESENT	0
802449	800773	08018U	PARTICIPANT	\N	PRESENT	0
802450	800773	14259Y	PARTICIPANT	\N	PRESENT	0
802451	800773	19749K	PARTICIPANT	\N	PRESENT	0
802452	800773	21095P	PARTICIPANT	\N	PRESENT	0
802453	800773	11072N	PARTICIPANT	\N	PRESENT	0
802546	801389	14221J	PARTICIPANT	\N	PRESENT	0
802547	801389	98022P	PARTICIPANT	\N	PRESENT	0
802548	801389	19782L	PARTICIPANT	\N	PRESENT	0
802549	801389	21042A	PARTICIPANT	\N	PRESENT	0
802550	801389	14121F	PARTICIPANT	\N	PRESENT	0
802551	801389	21040X	PARTICIPANT	\N	PRESENT	0
802552	801389	21065H	PARTICIPANT	\N	PRESENT	0
802553	801389	20042V	PARTICIPANT	\N	PRESENT	0
802554	801389	19301E	PARTICIPANT	\N	PRESENT	0
802555	801389	21084L	PARTICIPANT	\N	PRESENT	0
802556	801389	18193Q	PARTICIPANT	\N	PRESENT	0
802557	801389	18083K	PARTICIPANT	\N	PRESENT	0
802558	801389	19611R	PARTICIPANT	\N	PRESENT	0
802559	801389	15197G	PARTICIPANT	\N	PRESENT	0
802560	801389	14030Q	PARTICIPANT	\N	PRESENT	0
802561	801389	19691J	PARTICIPANT	\N	PRESENT	0
802562	801389	14211G	PARTICIPANT	\N	PRESENT	0
802563	801389	21087P	PARTICIPANT	\N	PRESENT	0
802564	801389	14107H	PARTICIPANT	\N	PRESENT	0
802565	801389	14037X	PARTICIPANT	\N	PRESENT	0
802566	801389	21097R	PARTICIPANT	\N	PRESENT	0
802567	801389	19349W	PARTICIPANT	\N	PRESENT	0
802568	801389	20266L	PARTICIPANT	\N	PRESENT	0
802569	801389	21067K	PARTICIPANT	\N	PRESENT	0
802570	801389	20106U	PARTICIPANT	\N	PRESENT	0
802571	801389	21088Q	PARTICIPANT	\N	PRESENT	0
802572	801389	19758L	PARTICIPANT	\N	PRESENT	0
802573	801389	19565D	PARTICIPANT	\N	PRESENT	0
802574	801389	19575F	PARTICIPANT	\N	PRESENT	0
802575	801389	21075K	PARTICIPANT	\N	PRESENT	0
802576	801389	19593H	PARTICIPANT	\N	PRESENT	0
802577	801389	08011M	PARTICIPANT	\N	PRESENT	0
802578	801389	19687N	PARTICIPANT	\N	PRESENT	0
802579	801389	20046A	PARTICIPANT	\N	PRESENT	0
802580	801389	99004R	PARTICIPANT	\N	PRESENT	0
802581	801389	19703U	PARTICIPANT	\N	PRESENT	0
816728	815932	20036X	PARTICIPANT	\N	PRESENT	0
816729	815932	21080G	PARTICIPANT	\N	PRESENT	0
816730	815932	21125C	PARTICIPANT	\N	PRESENT	0
816731	815932	19367Y	PARTICIPANT	\N	PRESENT	0
816732	815932	08069G	PARTICIPANT	\N	PRESENT	0
816733	815932	10015M	PARTICIPANT	\N	PRESENT	0
816734	815932	21044C	PARTICIPANT	\N	PRESENT	0
816737	815932	14069U	PARTICIPANT	\N	PRESENT	0
816738	815932	20266L	PARTICIPANT	\N	PRESENT	0
816742	815932	21089R	PARTICIPANT	\N	PRESENT	0
816744	815932	21056G	PARTICIPANT	\N	PRESENT	0
816745	815932	21059K	PARTICIPANT	\N	PRESENT	0
816751	815932	08061X	PARTICIPANT	\N	PRESENT	0
816813	815933	19745F	PARTICIPANT	\N	PRESENT	0
816755	815932	21078N	PARTICIPANT	\N	PRESENT	0
816756	815932	01058X	PARTICIPANT	\N	PRESENT	0
816757	815932	14033T	PARTICIPANT	\N	PRESENT	0
816758	815932	20026V	PARTICIPANT	\N	PRESENT	0
816759	815932	21058J	PARTICIPANT	\N	PRESENT	0
816760	815932	20264J	PARTICIPANT	\N	PRESENT	0
816761	815932	19593H	PARTICIPANT	\N	PRESENT	0
816762	815932	20102Q	PARTICIPANT	\N	PRESENT	0
816763	815932	19629C	PARTICIPANT	\N	PRESENT	0
816764	815932	19697Q	PARTICIPANT	\N	PRESENT	0
816814	815933	20052X	PARTICIPANT	\N	PRESENT	0
816815	815933	19699S	PARTICIPANT	\N	PRESENT	0
816816	815933	20122U	PARTICIPANT	\N	PRESENT	0
816817	815933	19693L	PARTICIPANT	\N	PRESENT	0
816818	815933	21070E	PARTICIPANT	\N	PRESENT	0
816819	815933	20134Y	PARTICIPANT	\N	PRESENT	0
816820	815933	20266L	PARTICIPANT	\N	PRESENT	0
816821	815933	20128B	PARTICIPANT	\N	PRESENT	0
816822	815933	19697Q	PARTICIPANT	\N	PRESENT	0
816823	815933	21057H	PARTICIPANT	\N	PRESENT	0
816825	815933	20028X	PARTICIPANT	\N	PRESENT	0
816826	815933	20060X	PARTICIPANT	\N	PRESENT	0
816827	815933	20080C	PARTICIPANT	\N	PRESENT	0
816828	815933	19758L	PARTICIPANT	\N	PRESENT	0
816829	815933	14179A	PARTICIPANT	\N	PRESENT	0
816830	815933	21089R	PARTICIPANT	\N	PRESENT	0
816831	815933	21059K	PARTICIPANT	\N	PRESENT	0
816832	815933	19649G	PARTICIPANT	\N	PRESENT	0
816833	815933	14097Y	PARTICIPANT	\N	PRESENT	0
816834	815933	19611R	PARTICIPANT	\N	PRESENT	0
816835	815933	19593H	PARTICIPANT	\N	PRESENT	0
816836	815933	20102Q	PARTICIPANT	\N	PRESENT	0
816837	815933	19573D	PARTICIPANT	\N	PRESENT	0
816838	815933	20044X	PARTICIPANT	\N	PRESENT	0
816839	815933	14259Y	PARTICIPANT	\N	PRESENT	0
816840	815933	20026V	PARTICIPANT	\N	PRESENT	0
816841	815933	21039F	PARTICIPANT	\N	PRESENT	0
816842	815933	20038A	PARTICIPANT	\N	PRESENT	0
816843	815933	21058J	PARTICIPANT	\N	PRESENT	0
816844	815933	20180F	PARTICIPANT	\N	PRESENT	0
816845	815933	21044C	PARTICIPANT	\N	PRESENT	0
816846	815933	14133K	PARTICIPANT	\N	PRESENT	0
816848	815933	21078N	PARTICIPANT	\N	PRESENT	0
816855	815933	20264J	PARTICIPANT	\N	PRESENT	0
816858	815933	21047F	PARTICIPANT	\N	PRESENT	0
816859	815933	11072N	PARTICIPANT	\N	PRESENT	0
816860	815933	21037D	PARTICIPANT	\N	PRESENT	0
816861	815933	21087P	PARTICIPANT	\N	PRESENT	0
816866	815933	20072C	PARTICIPANT	\N	PRESENT	0
816867	815933	19399H	PARTICIPANT	\N	PRESENT	0
816811	815933	14111D	PARTICIPANT	\N	PRESENT	0
816812	815933	21085M	PARTICIPANT	\N	PRESENT	0
816868	815933	14267Y	PARTICIPANT	\N	PRESENT	0
816869	815933	20066E	PARTICIPANT	\N	PRESENT	0
816870	815933	20142Y	PARTICIPANT	\N	PRESENT	0
816871	815933	21055F	PARTICIPANT	\N	PRESENT	0
816872	815933	14030Q	PARTICIPANT	\N	PRESENT	0
816873	815933	20124W	PARTICIPANT	\N	PRESENT	0
816874	815933	14053L	PARTICIPANT	\N	PRESENT	0
816875	815933	21093M	PARTICIPANT	\N	PRESENT	0
816876	815933	08061X	PARTICIPANT	\N	PRESENT	0
816877	815933	20090E	PARTICIPANT	\N	PRESENT	0
816878	815933	99004R	PARTICIPANT	\N	PRESENT	0
816879	815933	19621T	PARTICIPANT	\N	PRESENT	0
816880	815933	14231L	PARTICIPANT	\N	PRESENT	0
816881	815933	21038E	PARTICIPANT	\N	PRESENT	0
816941	815934	19758L	PARTICIPANT	\N	PRESENT	0
816930	815934	21070E	PARTICIPANT	\N	PRESENT	0
816933	815934	19697Q	PARTICIPANT	\N	PRESENT	0
816934	815934	11072N	PARTICIPANT	\N	PRESENT	0
816936	815934	20128B	PARTICIPANT	\N	PRESENT	0
816937	815934	20142Y	PARTICIPANT	\N	PRESENT	0
816938	815934	21037D	PARTICIPANT	\N	PRESENT	0
816939	815934	19693L	PARTICIPANT	\N	PRESENT	0
816940	815934	20110Q	PARTICIPANT	\N	PRESENT	0
816942	815934	20066E	PARTICIPANT	\N	PRESENT	0
816943	815934	14030Q	PARTICIPANT	\N	PRESENT	0
816944	815934	14231L	PARTICIPANT	\N	PRESENT	0
816945	815934	14053L	PARTICIPANT	\N	PRESENT	0
816946	815934	19649G	PARTICIPANT	\N	PRESENT	0
816947	815934	21057H	PARTICIPANT	\N	PRESENT	0
816948	815934	11056N	PARTICIPANT	\N	PRESENT	0
816949	815934	21047F	PARTICIPANT	\N	PRESENT	0
816950	815934	20026V	PARTICIPANT	\N	PRESENT	0
816952	815934	20180F	PARTICIPANT	\N	PRESENT	0
816953	815934	21055F	PARTICIPANT	\N	PRESENT	0
816954	815934	19826F	PARTICIPANT	\N	PRESENT	0
816955	815934	21039F	PARTICIPANT	\N	PRESENT	0
816956	815934	20090E	PARTICIPANT	\N	PRESENT	0
816957	815934	20124W	PARTICIPANT	\N	PRESENT	0
816958	815934	99004R	PARTICIPANT	\N	PRESENT	0
816959	815934	19573D	PARTICIPANT	\N	PRESENT	0
816960	815934	21038E	PARTICIPANT	\N	PRESENT	0
816962	815934	04047H	PARTICIPANT	\N	PRESENT	0
816963	815934	21044C	PARTICIPANT	\N	PRESENT	0
816964	815934	19593H	PARTICIPANT	\N	PRESENT	0
816965	815934	20102Q	PARTICIPANT	\N	PRESENT	0
816967	815934	20098N	PARTICIPANT	\N	PRESENT	0
816968	815934	14107H	PARTICIPANT	\N	PRESENT	0
816974	815934	20074E	PARTICIPANT	\N	PRESENT	0
816975	815934	19719D	PARTICIPANT	\N	PRESENT	0
816976	815934	04092N	PARTICIPANT	\N	PRESENT	0
816983	815934	20096L	PARTICIPANT	\N	PRESENT	0
816984	815934	19954N	PARTICIPANT	\N	PRESENT	0
816986	815934	05012A	PARTICIPANT	\N	PRESENT	0
816993	815934	20022R	PARTICIPANT	\N	PRESENT	0
816994	815934	14189C	PARTICIPANT	\N	PRESENT	0
816924	815934	14111D	PARTICIPANT	\N	PRESENT	0
816925	815934	08061X	PARTICIPANT	\N	PRESENT	0
816995	815934	21043B	PARTICIPANT	\N	PRESENT	0
816996	815934	20058E	PARTICIPANT	\N	PRESENT	0
816997	815934	14147R	PARTICIPANT	\N	PRESENT	0
817001	815934	20024T	PARTICIPANT	\N	PRESENT	0
816999	815934	14089Y	PARTICIPANT	\N	PRESENT	0
817000	815934	19760E	PARTICIPANT	\N	PRESENT	0
817002	815934	14259Y	PARTICIPANT	\N	PRESENT	0
817005	816847	21043B	PARTICIPANT	\N	PRESENT	0
817006	816847	20066E	PRESIDENT	0	PRESENT	0
817007	816847	14147R	PARTICIPANT	\N	PRESENT	0
817014	816847	19531S	PARTICIPANT	\N	PRESENT	0
817009	816847	20024T	PARTICIPANT	\N	PRESENT	0
817010	815934	20086J	PARTICIPANT	\N	PRESENT	0
817011	815934	14133K	PARTICIPANT	\N	PRESENT	0
817012	815934	20112S	PARTICIPANT	\N	PRESENT	0
817013	816847	18193Q	PARTICIPANT	\N	PRESENT	0
817015	815934	19533U	PARTICIPANT	\N	PRESENT	0
817016	816847	17965H	PARTICIPANT	\N	PRESENT	0
817018	816847	19758L	PARTICIPANT	\N	PRESENT	0
817019	816847	14030Q	PARTICIPANT	\N	PRESENT	0
817021	816847	19553Y	PARTICIPANT	\N	PRESENT	0
817035	815934	21056G	PARTICIPANT	\N	PRESENT	0
817038	816847	21064G	PARTICIPANT	\N	PRESENT	0
817040	815934	20032T	PARTICIPANT	\N	PRESENT	0
797612	793997	14331P	PARTICIPANT	\N	PRESENT	0
797613	793997	14073Q	PARTICIPANT	\N	PRESENT	0
797614	793997	14357A	PARTICIPANT	\N	PRESENT	0
797615	793997	20248J	PARTICIPANT	\N	PRESENT	0
797616	793997	18207D	PARTICIPANT	\N	PRESENT	0
797617	793997	14169X	PARTICIPANT	\N	PRESENT	0
797618	793997	20100N	PARTICIPANT	\N	PRESENT	0
797619	793997	14001X	PARTICIPANT	\N	PRESENT	0
797620	793997	14033T	PARTICIPANT	\N	PRESENT	0
797621	793997	21082J	PARTICIPANT	\N	PRESENT	0
797622	793997	20286Q	PARTICIPANT	\N	PRESENT	0
797623	793997	21076L	PARTICIPANT	\N	PRESENT	0
797624	793997	14133K	PARTICIPANT	\N	EXCUSE	0
797625	793997	14026U	PARTICIPANT	\N	EXCUSE	0
797626	793997	19709B	PARTICIPANT	\N	EXCUSE	0
797627	793997	20098N	PARTICIPANT	\N	EXCUSE	0
797629	793997	20104S	PARTICIPANT	\N	PRESENT	0
799729	797724	19719D	PARTICIPANT	\N	EXCUSE	0
799731	797724	19729F	PARTICIPANT	\N	EXCUSE	0
799734	797724	19585H	PARTICIPANT	\N	EXCUSE	0
801216	801215	20032T	PARTICIPANT	\N	PRESENT	0
801217	801215	19575F	PARTICIPANT	\N	PRESENT	0
801218	801215	19782L	PARTICIPANT	\N	PRESENT	0
801219	801215	19721W	PARTICIPANT	\N	PRESENT	0
801220	801215	14038Y	PARTICIPANT	\N	PRESENT	0
801221	801215	20144B	PARTICIPANT	\N	PRESENT	0
801222	801215	21067K	PARTICIPANT	\N	PRESENT	0
801223	801215	11070L	PARTICIPANT	\N	PRESENT	0
801224	801215	21062E	PARTICIPANT	\N	PRESENT	0
801225	801215	21086N	PARTICIPANT	\N	PRESENT	0
801226	801215	14033T	PARTICIPANT	\N	PRESENT	0
801227	801215	20252E	PARTICIPANT	\N	PRESENT	0
801228	801215	19533U	PARTICIPANT	\N	PRESENT	0
801229	801215	19619A	PARTICIPANT	\N	PRESENT	0
801470	801469	11072N	PARTICIPANT	\N	PRESENT	0
805367	805365	20074E	PARTICIPANT	\N	PRESENT	0
805366	805365	20286Q	PARTICIPANT	\N	PRESENT	0
801474	791783	04045F	PARTICIPANT	\N	PRESENT	0
805370	805365	21075K	PARTICIPANT	\N	PRESENT	0
801476	791783	20128B	PARTICIPANT	\N	PRESENT	0
801477	791783	21046E	PARTICIPANT	\N	PRESENT	0
801478	791783	19565D	PARTICIPANT	\N	PRESENT	0
806431	806430	18395Y	PARTICIPANT	\N	PRESENT	0
806432	806430	21059K	PARTICIPANT	\N	PRESENT	0
806887	806886	20032T	PARTICIPANT	\N	PRESENT	0
806888	806886	20076G	PARTICIPANT	\N	PRESENT	0
806889	806886	20116W	PARTICIPANT	\N	PRESENT	0
806890	806886	19383Y	PARTICIPANT	\N	PRESENT	0
806891	806886	20090E	PARTICIPANT	\N	PRESENT	0
806892	806886	14329V	PARTICIPANT	\N	PRESENT	0
806893	806886	18083K	PARTICIPANT	\N	PRESENT	0
806894	806886	14357A	PARTICIPANT	\N	PRESENT	0
806895	806886	14187A	PARTICIPANT	\N	PRESENT	0
806896	806886	14213J	PARTICIPANT	\N	PRESENT	0
806897	806886	20126Y	PARTICIPANT	\N	PRESENT	0
806898	806886	08034U	PARTICIPANT	\N	PRESENT	0
806899	806886	21054E	PARTICIPANT	\N	PRESENT	0
806900	806886	21058J	PARTICIPANT	\N	PRESENT	0
806901	806886	14221J	PARTICIPANT	\N	PRESENT	0
806902	806886	19563B	PARTICIPANT	\N	PRESENT	0
806903	806886	20018V	PARTICIPANT	\N	PRESENT	0
806904	806886	14169X	PARTICIPANT	\N	PRESENT	0
806905	806886	05012A	PARTICIPANT	\N	PRESENT	0
806906	806886	14331P	PARTICIPANT	\N	PRESENT	0
806907	806886	20054A	PARTICIPANT	\N	PRESENT	0
806908	806886	19619A	PARTICIPANT	\N	PRESENT	0
806909	806886	20092G	PARTICIPANT	\N	PRESENT	0
806910	806886	20044X	PARTICIPANT	\N	PRESENT	0
806911	806886	19713W	PARTICIPANT	\N	PRESENT	0
806912	806886	20062A	PARTICIPANT	\N	PRESENT	0
808180	808179	14071N	PARTICIPANT	\N	PRESENT	0
808181	808179	19575F	PARTICIPANT	\N	PRESENT	0
808182	808179	14097Y	PARTICIPANT	\N	PRESENT	0
808183	808179	19826F	PARTICIPANT	\N	PRESENT	0
808185	808179	19798U	PARTICIPANT	\N	PRESENT	0
808186	808179	20038A	PARTICIPANT	\N	PRESENT	0
808187	808179	20126Y	PARTICIPANT	\N	PRESENT	0
808188	808179	20054A	PARTICIPANT	\N	PRESENT	0
808189	808179	20118Y	PARTICIPANT	\N	PRESENT	0
808190	808179	14229S	PARTICIPANT	\N	PRESENT	0
808298	808296	14071N	PARTICIPANT	\N	PRESENT	0
808299	808296	19703U	PARTICIPANT	\N	PRESENT	0
808300	808296	20098N	PARTICIPANT	\N	PRESENT	0
808301	808296	19691J	PARTICIPANT	\N	PRESENT	0
808302	808296	14281W	PARTICIPANT	\N	PRESENT	0
808303	808296	18193Q	PARTICIPANT	\N	PRESENT	0
808305	808296	14195A	PARTICIPANT	\N	PRESENT	0
808306	808296	21097R	PARTICIPANT	\N	PRESENT	0
808307	808296	21094N	PARTICIPANT	\N	PRESENT	0
808314	807246	17023S	PARTICIPANT	\N	PRESENT	0
808397	807245	14133K	PARTICIPANT	\N	PRESENT	0
808408	808075	19383Y	PARTICIPANT	\N	PRESENT	0
808409	808075	19768N	PARTICIPANT	\N	PRESENT	0
808410	808075	20092G	PARTICIPANT	\N	PRESENT	0
808411	808075	14357A	PARTICIPANT	\N	PRESENT	0
808412	808075	19413M	PARTICIPANT	\N	PRESENT	0
808413	808075	19631V	PARTICIPANT	\N	PRESENT	0
808414	808075	20104S	PARTICIPANT	\N	PRESENT	0
808415	808075	08015R	PARTICIPANT	\N	PRESENT	0
808416	808075	19575F	PARTICIPANT	\N	PRESENT	0
808417	808075	20018V	PARTICIPANT	\N	PRESENT	0
808418	808075	19563B	PARTICIPANT	\N	PRESENT	0
808419	808075	21050A	PARTICIPANT	\N	PRESENT	0
808420	808075	20028X	PARTICIPANT	\N	PRESENT	0
808421	808075	20030R	PARTICIPANT	\N	PRESENT	0
808422	808075	20034V	PARTICIPANT	\N	PRESENT	0
808423	808075	21054E	PARTICIPANT	\N	PRESENT	0
808424	808075	20038A	PARTICIPANT	\N	PRESENT	0
808425	808075	14187A	PRESIDENT	0	PRESENT	0
808426	808075	21075K	PARTICIPANT	\N	PRESENT	0
808427	808075	21083K	PARTICIPANT	\N	PRESENT	0
808428	808075	20144B	PARTICIPANT	\N	PRESENT	0
808429	808075	14033T	PARTICIPANT	\N	PRESENT	0
808430	808075	11090Q	PARTICIPANT	\N	PRESENT	0
808431	808075	21093M	PARTICIPANT	\N	PRESENT	0
808432	808075	21033Y	PARTICIPANT	\N	PRESENT	0
808433	808075	20054A	PARTICIPANT	\N	PRESENT	0
808434	808075	14205J	PARTICIPANT	\N	PRESENT	0
808435	808075	19507S	PARTICIPANT	\N	PRESENT	0
808436	808075	20066E	PARTICIPANT	\N	PRESENT	0
808437	808075	21066J	PARTICIPANT	\N	PRESENT	0
808438	808075	20286Q	PARTICIPANT	\N	PRESENT	0
810826	810302	20056C	PARTICIPANT	\N	PRESENT	0
810827	810302	14053L	PARTICIPANT	\N	PRESENT	0
810832	810302	20026V	PARTICIPANT	\N	PRESENT	0
810833	810302	20248J	PARTICIPANT	\N	PRESENT	0
810836	810302	20054A	PARTICIPANT	\N	PRESENT	0
810837	810302	14223L	PARTICIPANT	\N	PRESENT	0
810838	810302	14211G	PARTICIPANT	\N	PRESENT	0
810839	810302	21094N	PARTICIPANT	\N	PRESENT	0
810840	810302	21057H	PARTICIPANT	\N	PRESENT	0
810841	810302	18193Q	PARTICIPANT	\N	PRESENT	0
810842	810302	20022R	PARTICIPANT	\N	PRESENT	0
810843	810302	14030Q	PARTICIPANT	\N	PRESENT	0
810844	810302	14042U	PARTICIPANT	\N	PRESENT	0
810845	810302	14215L	PARTICIPANT	\N	PRESENT	0
810846	810302	19507S	PARTICIPANT	\N	PRESENT	0
810847	810302	19826F	PARTICIPANT	\N	PRESENT	0
810848	810302	11045K	PARTICIPANT	\N	PRESENT	0
810849	810302	19383Y	PARTICIPANT	\N	PRESENT	0
810850	810302	14187A	PARTICIPANT	\N	PRESENT	0
810851	810302	21045D	PARTICIPANT	\N	PRESENT	0
810852	810302	14231L	PARTICIPANT	\N	PRESENT	0
810853	810302	14021P	PARTICIPANT	\N	PRESENT	0
810854	810302	19413M	PARTICIPANT	\N	PRESENT	0
810855	810302	20098N	PARTICIPANT	\N	PRESENT	0
810856	810302	21069M	PARTICIPANT	\N	PRESENT	0
810857	810302	21085M	PARTICIPANT	\N	PRESENT	0
810858	810302	21078N	PARTICIPANT	\N	PRESENT	0
810859	810302	20106U	PARTICIPANT	\N	PRESENT	0
810860	810302	04045F	PARTICIPANT	\N	PRESENT	0
810861	810302	20034V	PARTICIPANT	\N	PRESENT	0
810866	810302	21074J	PARTICIPANT	\N	PRESENT	0
810867	810302	21089R	PARTICIPANT	\N	PRESENT	0
810871	810302	20142Y	PARTICIPANT	\N	PRESENT	0
810876	810302	14121F	PARTICIPANT	\N	PRESENT	0
810877	810302	08061X	PARTICIPANT	\N	PRESENT	0
810878	810302	19697Q	PARTICIPANT	\N	PRESENT	0
810880	810302	19735D	PARTICIPANT	\N	PRESENT	0
810881	810302	19798U	PARTICIPANT	\N	PRESENT	0
810882	810302	20076G	PARTICIPANT	\N	PRESENT	0
810884	810302	21091K	PARTICIPANT	\N	PRESENT	0
810885	810302	18083K	PARTICIPANT	\N	PRESENT	0
810886	810302	20180F	PARTICIPANT	\N	PRESENT	0
810887	810302	21055F	PARTICIPANT	\N	PRESENT	0
810888	810302	19621T	PARTICIPANT	\N	PRESENT	0
810889	810302	14033T	PARTICIPANT	\N	PRESENT	0
810890	810302	19647E	PARTICIPANT	\N	PRESENT	0
810891	810302	19719D	PARTICIPANT	\N	PRESENT	0
810892	810302	21065H	PARTICIPANT	\N	PRESENT	0
810895	810302	11048N	PARTICIPANT	\N	PRESENT	0
810896	810302	14111D	PARTICIPANT	\N	PRESENT	0
810897	810302	11090Q	PARTICIPANT	\N	PRESENT	0
810899	810302	21071F	PARTICIPANT	\N	PRESENT	0
810900	810302	20044X	PARTICIPANT	\N	PRESENT	0
810901	810302	14031R	PARTICIPANT	\N	PRESENT	0
810910	810302	19611R	PARTICIPANT	\N	PRESENT	0
810998	810303	19611R	PARTICIPANT	\N	PRESENT	0
811000	810303	19758L	PARTICIPANT	\N	PRESENT	0
811001	810303	20102Q	PARTICIPANT	\N	PRESENT	0
811002	810303	20030R	PARTICIPANT	\N	PRESENT	0
811003	810303	20018V	PARTICIPANT	\N	PRESENT	0
811004	810303	19413M	PARTICIPANT	\N	PRESENT	0
811005	810303	14121F	PARTICIPANT	\N	PRESENT	0
811006	810303	18395Y	PARTICIPANT	\N	PRESENT	0
811007	810303	21089R	PARTICIPANT	\N	PRESENT	0
811008	810303	19647E	PARTICIPANT	\N	PRESENT	0
811009	810303	11045K	PARTICIPANT	\N	PRESENT	0
811010	810303	20142Y	PARTICIPANT	\N	PRESENT	0
811011	810303	21093M	PARTICIPANT	\N	PRESENT	0
811012	810303	21065H	PARTICIPANT	\N	PRESENT	0
811013	810303	21040X	PARTICIPANT	\N	PRESENT	0
811014	810303	20106U	PARTICIPANT	\N	PRESENT	0
811015	810303	21078N	PARTICIPANT	\N	PRESENT	0
811016	810303	20144B	PARTICIPANT	\N	PRESENT	0
811017	810303	14073Q	PARTICIPANT	\N	PRESENT	0
811018	810303	19699S	PARTICIPANT	\N	PRESENT	0
811019	810303	21053D	PARTICIPANT	\N	PRESENT	0
811020	810303	19679N	PARTICIPANT	\N	PRESENT	0
811021	810303	20098N	PARTICIPANT	\N	PRESENT	0
811023	810303	14053L	PARTICIPANT	\N	PRESENT	0
811024	810303	20054A	PARTICIPANT	\N	PRESENT	0
811025	810303	08028W	PARTICIPANT	\N	PRESENT	0
811026	810303	11090Q	PARTICIPANT	\N	PRESENT	0
811027	810303	19621T	PARTICIPANT	\N	PRESENT	0
811028	810303	14147R	PARTICIPANT	\N	PRESENT	0
811029	810303	19711U	PARTICIPANT	\N	PRESENT	0
811030	810303	18083K	PARTICIPANT	\N	PRESENT	0
811031	810303	20026V	PARTICIPANT	\N	PRESENT	0
811032	810303	20180F	PARTICIPANT	\N	PRESENT	0
811033	810303	20044X	PARTICIPANT	\N	PRESENT	0
811034	810303	14259Y	PARTICIPANT	\N	PRESENT	0
811035	810303	20076G	PARTICIPANT	\N	PRESENT	0
811036	810303	20074E	PARTICIPANT	\N	PRESENT	0
811037	810303	14191V	PARTICIPANT	\N	PRESENT	0
811038	810303	21055F	PARTICIPANT	\N	PRESENT	0
811039	810303	14033T	PARTICIPANT	\N	PRESENT	0
811040	810303	21058J	PARTICIPANT	\N	PRESENT	0
811041	810303	18193Q	PARTICIPANT	\N	PRESENT	0
811042	810303	19719D	PARTICIPANT	\N	PRESENT	0
811043	810303	19697Q	PARTICIPANT	\N	PRESENT	0
811045	810303	14179A	PARTICIPANT	\N	PRESENT	0
811046	810303	20056C	PARTICIPANT	\N	PRESENT	0
811047	810303	01034P	PARTICIPANT	\N	PRESENT	0
811048	810303	21037D	PARTICIPANT	\N	PRESENT	0
811049	810303	20062A	PARTICIPANT	\N	PRESENT	0
811050	810303	21063F	PARTICIPANT	\N	PRESENT	0
811051	810303	21039F	PARTICIPANT	\N	PRESENT	0
811052	810303	04045F	PARTICIPANT	\N	PRESENT	0
811053	810303	14038Y	PARTICIPANT	\N	PRESENT	0
811056	810303	21044C	PARTICIPANT	\N	PRESENT	0
811057	810303	21056G	PARTICIPANT	\N	PRESENT	0
811058	810303	19251M	PARTICIPANT	\N	PRESENT	0
811059	810303	20096L	PARTICIPANT	\N	PRESENT	0
811060	810303	19629C	PARTICIPANT	\N	PRESENT	0
811061	810303	20136B	PARTICIPANT	\N	PRESENT	0
811062	810303	21077M	PARTICIPANT	\N	PRESENT	0
811064	811063	19479G	PARTICIPANT	\N	PRESENT	0
811065	811063	20054A	PARTICIPANT	\N	PRESENT	0
811066	810303	21071F	PARTICIPANT	\N	PRESENT	0
811068	811067	19479G	PARTICIPANT	\N	PRESENT	0
811069	811067	14193X	PARTICIPANT	\N	PRESENT	0
811070	810303	11048N	PARTICIPANT	\N	PRESENT	0
811071	810303	19693L	PARTICIPANT	\N	PRESENT	0
811072	810303	19749K	PARTICIPANT	\N	PRESENT	0
811073	810303	20024T	PARTICIPANT	\N	PRESENT	0
811080	810303	14083S	PARTICIPANT	\N	PRESENT	0
811086	810303	17023S	PARTICIPANT	\N	PRESENT	0
811087	810303	14107H	PARTICIPANT	\N	PRESENT	0
811088	810303	19745F	PARTICIPANT	\N	PRESENT	0
811094	810303	08018U	PARTICIPANT	\N	PRESENT	0
811096	811095	14083S	PARTICIPANT	\N	PRESENT	0
811097	811095	14069U	PARTICIPANT	\N	PRESENT	0
811098	811095	14331P	PARTICIPANT	\N	PRESENT	0
810992	810303	14229S	PARTICIPANT	\N	PRESENT	0
810995	810303	21091K	PARTICIPANT	\N	PRESENT	0
797809	797699	20146D	PARTICIPANT	\N	EXCUSE	0
797810	797700	20146D	PARTICIPANT	\N	EXCUSE	0
797841	797838	14053L	PARTICIPANT	\N	PRESENT	0
797842	797838	19649G	PARTICIPANT	\N	PRESENT	0
797843	797838	20022R	PARTICIPANT	\N	PRESENT	0
797844	797839	04047H	PARTICIPANT	\N	PRESENT	0
797845	797839	14053L	PARTICIPANT	\N	PRESENT	0
797846	797839	20022R	PARTICIPANT	\N	PRESENT	0
797847	797839	19649G	PARTICIPANT	\N	PRESENT	0
798640	798638	12016W	PARTICIPANT	\N	PRESENT	0
798641	798638	14257W	PRESIDENT	0	PRESENT	0
798647	798638	20018V	PARTICIPANT	\N	PRESENT	0
798648	798638	11070L	PARTICIPANT	\N	PRESENT	0
798659	798638	19619A	PARTICIPANT	\N	PRESENT	0
798680	798638	14031R	PARTICIPANT	\N	PRESENT	0
802582	801389	20142Y	PARTICIPANT	\N	PRESENT	0
802583	801389	21037D	PARTICIPANT	\N	PRESENT	0
802584	801389	10015M	PARTICIPANT	\N	PRESENT	0
802585	801389	20092G	PARTICIPANT	\N	PRESENT	0
802586	801389	05012A	PARTICIPANT	\N	PRESENT	0
802587	801389	21079P	PARTICIPANT	\N	PRESENT	0
802588	801389	04092N	PARTICIPANT	\N	PRESENT	0
802589	801389	08034U	PARTICIPANT	\N	PRESENT	0
802590	801389	14249W	PARTICIPANT	\N	PRESENT	0
802591	801389	04033B	PARTICIPANT	\N	PRESENT	0
802592	801389	19591F	PARTICIPANT	\N	PRESENT	0
802593	801389	19697Q	PARTICIPANT	\N	PRESENT	0
802594	801389	14223L	PARTICIPANT	\N	PRESENT	0
802595	801389	14055N	PARTICIPANT	\N	PRESENT	0
802596	801389	19711U	PARTICIPANT	\N	PRESENT	0
802597	801389	19367Y	PARTICIPANT	\N	PRESENT	0
802598	801389	20076G	PARTICIPANT	\N	PRESENT	0
802599	801389	20116W	PARTICIPANT	\N	PRESENT	0
802600	801389	14207L	PARTICIPANT	\N	PRESENT	0
802601	801389	20074E	PARTICIPANT	\N	PRESENT	0
802602	801389	19719D	PARTICIPANT	\N	PRESENT	0
802603	801389	20078J	PARTICIPANT	\N	PRESENT	0
802604	801389	20132W	PARTICIPANT	\N	PRESENT	0
802605	801389	08069G	PARTICIPANT	\N	PRESENT	0
802606	801389	04042C	PARTICIPANT	\N	PRESENT	0
802607	801389	20072C	PARTICIPANT	\N	PRESENT	0
802608	801389	21046E	PARTICIPANT	\N	PRESENT	0
802609	801389	21044C	PARTICIPANT	\N	PRESENT	0
802610	801389	21061D	PARTICIPANT	\N	PRESENT	0
802611	801389	19693L	PARTICIPANT	\N	PRESENT	0
802612	801389	21054E	PARTICIPANT	\N	PRESENT	0
802613	801389	11043H	PARTICIPANT	\N	PRESENT	0
802614	801389	14251Q	PARTICIPANT	\N	PRESENT	0
802615	801389	14111D	PARTICIPANT	\N	PRESENT	0
802616	801389	08028W	PARTICIPANT	\N	PRESENT	0
802617	801389	20050V	PARTICIPANT	\N	PRESENT	0
802618	801389	21071F	PARTICIPANT	\N	PRESENT	0
802619	801389	21070E	PARTICIPANT	\N	PRESENT	0
802620	801389	20122U	PARTICIPANT	\N	PRESENT	0
802621	801389	14191V	PARTICIPANT	\N	PRESENT	0
802622	801389	14193X	PARTICIPANT	\N	PRESENT	0
802623	801389	20044X	PARTICIPANT	\N	PRESENT	0
802624	801389	14215L	PARTICIPANT	\N	PRESENT	0
802625	801389	21092L	PARTICIPANT	\N	PRESENT	0
802626	801389	21080G	PARTICIPANT	\N	PRESENT	0
802627	801389	19347U	PARTICIPANT	\N	PRESENT	0
802628	801389	11090Q	PARTICIPANT	\N	PRESENT	0
802629	801389	19545Y	PARTICIPANT	\N	PRESENT	0
802630	801389	19673G	PARTICIPANT	\N	PRESENT	0
802631	801389	21029D	PARTICIPANT	\N	PRESENT	0
802632	801389	21073H	PARTICIPANT	\N	PRESENT	0
802633	801389	14031R	PARTICIPANT	\N	PRESENT	0
802634	801389	19667J	PARTICIPANT	\N	PRESENT	0
802635	801389	21049H	PARTICIPANT	\N	PRESENT	0
802636	801389	19421M	PARTICIPANT	\N	PRESENT	0
802637	801389	14253S	PARTICIPANT	\N	PRESENT	0
802638	801389	20136B	PARTICIPANT	\N	PRESENT	0
802639	801389	17737W	PARTICIPANT	\N	PRESENT	0
802640	801389	14259Y	PARTICIPANT	\N	PRESENT	0
802641	801389	19447X	PARTICIPANT	\N	PRESENT	0
802642	801389	08060W	PARTICIPANT	\N	PRESENT	0
802643	801389	21068L	PARTICIPANT	\N	PRESENT	0
802644	801389	21058J	PARTICIPANT	\N	PRESENT	0
802645	801389	20096L	PARTICIPANT	\N	PRESENT	0
802647	801389	20080C	PARTICIPANT	\N	PRESENT	0
802648	801389	20180F	PARTICIPANT	\N	PRESENT	0
802649	801389	21089R	PARTICIPANT	\N	PRESENT	0
802650	801389	20060X	PARTICIPANT	\N	PRESENT	0
802651	801389	12028B	PARTICIPANT	\N	PRESENT	0
802652	801389	21057H	PARTICIPANT	\N	PRESENT	0
802653	801389	20264J	PARTICIPANT	\N	PRESENT	0
802654	801389	20026V	PARTICIPANT	\N	PRESENT	0
802655	801389	19954N	PARTICIPANT	\N	PRESENT	0
802656	801389	21081H	PARTICIPANT	\N	PRESENT	0
802657	801389	20070A	PARTICIPANT	\N	PRESENT	0
802658	801389	19383Y	PARTICIPANT	\N	PRESENT	0
802659	801389	19251M	PARTICIPANT	\N	PRESENT	0
802661	801389	11110B	PARTICIPANT	\N	PRESENT	0
802663	801389	19631V	PARTICIPANT	\N	PRESENT	0
802664	801389	20062A	PARTICIPANT	\N	PRESENT	0
802667	801389	20128B	PARTICIPANT	\N	PRESENT	0
802668	801389	19647E	PARTICIPANT	\N	PRESENT	0
802670	801389	07033P	PARTICIPANT	\N	PRESENT	0
802671	801389	14281W	PARTICIPANT	\N	PRESENT	0
802674	801389	19820Y	PARTICIPANT	\N	PRESENT	0
802675	801389	19725B	PARTICIPANT	\N	PRESENT	0
802676	801389	19683J	PARTICIPANT	\N	PRESENT	0
802677	801389	14021P	PARTICIPANT	\N	PRESENT	0
802678	801389	11040E	PARTICIPANT	\N	PRESENT	0
802679	801389	19489J	PARTICIPANT	\N	PRESENT	0
802680	801389	19649G	PARTICIPANT	\N	PRESENT	0
802681	801389	21072G	PARTICIPANT	\N	PRESENT	0
802682	801389	18207D	PARTICIPANT	\N	PRESENT	0
802683	801389	08012N	PARTICIPANT	\N	PRESENT	0
802684	801389	17779H	PARTICIPANT	\N	PRESENT	0
802685	801389	20032T	PARTICIPANT	\N	PRESENT	0
802686	801389	20114U	PARTICIPANT	\N	PRESENT	0
802687	801389	14147R	PARTICIPANT	\N	PRESENT	0
802688	801389	14038Y	PARTICIPANT	\N	PRESENT	0
802689	801389	19413M	PARTICIPANT	\N	PRESENT	0
802690	801389	19723Y	PARTICIPANT	\N	PRESENT	0
802691	801389	21051B	PARTICIPANT	\N	PRESENT	0
802692	801389	20064C	PARTICIPANT	\N	PRESENT	0
802693	801389	21082J	PARTICIPANT	\N	PRESENT	0
802694	801389	20034V	PARTICIPANT	\N	PRESENT	0
802695	801389	20140W	PARTICIPANT	\N	PRESENT	0
802696	801389	20084G	PARTICIPANT	\N	PRESENT	0
802697	801389	20038A	PARTICIPANT	\N	PRESENT	0
802698	801389	21059K	PARTICIPANT	\N	PRESENT	0
802699	801389	11045K	PARTICIPANT	\N	PRESENT	0
802700	801389	20056C	PARTICIPANT	\N	PRESENT	0
802701	801389	20082E	PARTICIPANT	\N	PRESENT	0
802702	801389	14225N	PARTICIPANT	\N	PRESENT	0
802703	801389	17965H	PARTICIPANT	\N	PRESENT	0
802704	801389	20030R	PARTICIPANT	\N	PRESENT	0
802705	801389	21060C	PARTICIPANT	\N	PRESENT	0
802706	801389	14229S	PARTICIPANT	\N	PRESENT	0
802707	801389	14257W	PARTICIPANT	\N	PRESENT	0
802708	801389	19399H	PARTICIPANT	\N	PRESENT	0
802709	801389	08045X	PARTICIPANT	\N	PRESENT	0
802710	801389	14109K	PARTICIPANT	\N	PRESENT	0
802711	801389	20104S	PARTICIPANT	\N	PRESENT	0
802712	801389	20018V	PARTICIPANT	\N	PRESENT	0
802713	801389	20028X	PARTICIPANT	\N	PRESENT	0
802714	801389	21050A	PARTICIPANT	\N	PRESENT	0
802715	801389	20024T	PARTICIPANT	\N	PRESENT	0
802716	801389	20022R	PARTICIPANT	\N	PRESENT	0
802717	801389	21083K	PARTICIPANT	\N	PRESENT	0
802718	801389	20108W	PARTICIPANT	\N	PRESENT	0
802719	801389	14083S	PARTICIPANT	\N	PRESENT	0
802720	801389	11053K	PARTICIPANT	\N	PRESENT	0
802721	801389	19721W	PARTICIPANT	\N	PRESENT	0
802722	801389	11115U	PARTICIPANT	\N	PRESENT	0
802723	801389	11070L	PARTICIPANT	\N	PRESENT	0
802724	801389	20058E	PARTICIPANT	\N	PRESENT	0
802725	801389	14327T	PARTICIPANT	\N	PRESENT	0
802726	801389	21047F	PARTICIPANT	\N	PRESENT	0
802727	801389	20248J	PARTICIPANT	\N	PRESENT	0
802728	801389	17229F	PARTICIPANT	\N	PRESENT	0
802729	801389	20068G	PARTICIPANT	\N	PRESENT	0
802730	801389	21045D	PARTICIPANT	\N	PRESENT	0
802731	801389	17367Q	PARTICIPANT	\N	PRESENT	0
802732	801389	20040T	PARTICIPANT	\N	PRESENT	0
802733	801389	14355X	PARTICIPANT	\N	PRESENT	0
802734	801389	20110Q	PARTICIPANT	\N	PRESENT	0
802735	801389	21048G	PARTICIPANT	\N	PRESENT	0
811463	810211	21088Q	PARTICIPANT	\N	PRESENT	0
811464	810211	11085T	PARTICIPANT	\N	PRESENT	0
811466	810211	20098N	PARTICIPANT	\N	PRESENT	0
811467	810779	08010L	PARTICIPANT	\N	PRESENT	0
811468	810779	21072G	PARTICIPANT	\N	PRESENT	0
811474	810211	14231L	PARTICIPANT	\N	PRESENT	0
811475	810141	04070G	PARTICIPANT	\N	PRESENT	0
811476	810141	19699S	PARTICIPANT	\N	PRESENT	0
811477	810141	19533U	PARTICIPANT	\N	PRESENT	0
811478	810141	21058J	PARTICIPANT	\N	PRESENT	0
811479	810141	20102Q	PARTICIPANT	\N	PRESENT	0
811480	810141	14229S	PARTICIPANT	\N	PRESENT	0
811481	810141	18395Y	PARTICIPANT	\N	PRESENT	0
811482	810141	21089R	PARTICIPANT	\N	PRESENT	0
811483	810141	21037D	PARTICIPANT	\N	PRESENT	0
811484	810141	20124W	PARTICIPANT	\N	PRESENT	0
811485	810141	20026V	PARTICIPANT	\N	PRESENT	0
811486	810141	19593H	PARTICIPANT	\N	PRESENT	0
811487	810141	20132W	PARTICIPANT	\N	PRESENT	0
811488	810141	21055F	PARTICIPANT	\N	PRESENT	0
811489	810141	19611R	PRESIDENT	0	PRESENT	0
811490	810141	20142Y	PARTICIPANT	\N	PRESENT	0
811491	810141	19693L	PARTICIPANT	\N	PRESENT	0
811492	810141	20172F	PARTICIPANT	\N	PRESENT	0
811493	810141	14030Q	PARTICIPANT	\N	PRESENT	0
811494	810141	20058E	PARTICIPANT	\N	PRESENT	0
811495	810141	20056C	PARTICIPANT	\N	PRESENT	0
811496	810141	20180F	PARTICIPANT	\N	PRESENT	0
811497	810141	20264J	PARTICIPANT	\N	PRESENT	0
811498	810141	21063F	PARTICIPANT	\N	PRESENT	0
811499	810141	19735D	PARTICIPANT	\N	PRESENT	0
811500	810141	14123H	PARTICIPANT	\N	PRESENT	0
811501	810141	11043H	PARTICIPANT	\N	PRESENT	0
811502	810141	21077M	PARTICIPANT	\N	PRESENT	0
811776	810306	21059K	PARTICIPANT	\N	PRESENT	0
811773	810306	21057H	PARTICIPANT	\N	PRESENT	0
811774	810306	18193Q	PARTICIPANT	\N	PRESENT	0
811777	810306	11040E	PARTICIPANT	\N	PRESENT	0
811778	810306	21089R	PARTICIPANT	\N	PRESENT	0
811509	810779	11053K	PARTICIPANT	\N	PRESENT	0
811510	810779	20124W	PARTICIPANT	\N	PRESENT	0
811511	811317	21092L	PARTICIPANT	\N	PRESENT	0
811516	810779	11110B	PARTICIPANT	\N	PRESENT	0
811641	810909	21036C	PARTICIPANT	\N	PRESENT	0
811642	810909	95041E	PARTICIPANT	\N	PRESENT	0
811643	810909	21030V	PARTICIPANT	\N	PRESENT	0
811644	810909	21031W	PARTICIPANT	\N	PRESENT	0
811645	810909	19565D	PARTICIPANT	\N	PRESENT	0
811646	810909	20072C	PARTICIPANT	\N	PRESENT	0
811647	810909	01058X	PARTICIPANT	\N	PRESENT	0
811648	810909	11027H	PARTICIPANT	\N	PRESENT	0
811649	810909	14001X	PARTICIPANT	\N	PRESENT	0
811650	810909	04042C	PARTICIPANT	\N	PRESENT	0
811651	810909	19669L	PARTICIPANT	\N	PRESENT	0
811652	810909	12028B	PARTICIPANT	\N	PRESENT	0
811653	810909	17737W	PARTICIPANT	\N	PRESENT	0
811654	810909	11115U	PARTICIPANT	\N	PRESENT	0
811655	810909	14055N	PARTICIPANT	\N	PRESENT	0
811656	810909	19421M	PARTICIPANT	\N	PRESENT	0
811657	810909	19709B	PARTICIPANT	\N	PRESENT	0
811658	810909	21067K	PARTICIPANT	\N	PRESENT	0
811659	810909	14193X	PRESIDENT	0	PRESENT	0
811660	810909	07033P	PARTICIPANT	\N	PRESENT	0
811661	810909	14249W	PARTICIPANT	\N	PRESENT	0
811662	810909	08047A	PARTICIPANT	\N	PRESENT	0
811663	810909	14037X	PARTICIPANT	\N	PRESENT	0
811664	810909	14059S	PARTICIPANT	\N	PRESENT	0
811665	810909	14097Y	PARTICIPANT	\N	PRESENT	0
811666	810909	14133K	PARTICIPANT	\N	PRESENT	0
811667	810909	19531S	PARTICIPANT	\N	PRESENT	0
811668	810909	21073H	PARTICIPANT	\N	PRESENT	0
811669	810909	20042V	PARTICIPANT	\N	PRESENT	0
811670	810909	14191V	PARTICIPANT	\N	PRESENT	0
811671	810909	19721W	PARTICIPANT	\N	PRESENT	0
811672	810909	20064C	PARTICIPANT	\N	PRESENT	0
811673	810909	20252E	PARTICIPANT	\N	PRESENT	0
811674	810909	14251Q	PARTICIPANT	\N	PRESENT	0
811675	810909	98022P	PARTICIPANT	\N	PRESENT	0
811676	810909	14267Y	PARTICIPANT	\N	PRESENT	0
811677	810909	99004R	PARTICIPANT	\N	PRESENT	0
811678	810909	19745F	PARTICIPANT	\N	PRESENT	0
811679	810909	14211G	PARTICIPANT	\N	PRESENT	0
811680	810909	14255U	PARTICIPANT	\N	PRESENT	0
811681	810909	17023S	PARTICIPANT	\N	PRESENT	0
811682	810206	21036C	PARTICIPANT	\N	PRESENT	0
811683	810206	95041E	PARTICIPANT	\N	PRESENT	0
811684	810206	21030V	PARTICIPANT	\N	PRESENT	0
811685	810206	21031W	PARTICIPANT	\N	PRESENT	0
811686	810206	19565D	PARTICIPANT	\N	PRESENT	0
811687	810206	20072C	PARTICIPANT	\N	PRESENT	0
811688	810206	01058X	PARTICIPANT	\N	PRESENT	0
811689	810206	11027H	PARTICIPANT	\N	PRESENT	0
811690	810206	14001X	PARTICIPANT	\N	PRESENT	0
811691	810206	04042C	PARTICIPANT	\N	PRESENT	0
811692	810206	19669L	PARTICIPANT	\N	PRESENT	0
811693	810206	12028B	PARTICIPANT	\N	PRESENT	0
811694	810206	17737W	PARTICIPANT	\N	PRESENT	0
811695	810206	11115U	PARTICIPANT	\N	PRESENT	0
811696	810206	14055N	PARTICIPANT	\N	PRESENT	0
811697	810206	19421M	PARTICIPANT	\N	PRESENT	0
811698	810206	19709B	PARTICIPANT	\N	PRESENT	0
811699	810206	21067K	PARTICIPANT	\N	PRESENT	0
811700	810206	14193X	PRESIDENT	0	PRESENT	0
811701	810206	07033P	PARTICIPANT	\N	PRESENT	0
811702	810206	14249W	PARTICIPANT	\N	PRESENT	0
811703	810206	08047A	PARTICIPANT	\N	PRESENT	0
811704	810206	14037X	PARTICIPANT	\N	PRESENT	0
811705	810206	14059S	PARTICIPANT	\N	PRESENT	0
811706	810206	14097Y	PARTICIPANT	\N	PRESENT	0
811707	810206	14133K	PARTICIPANT	\N	PRESENT	0
811708	810206	19531S	PARTICIPANT	\N	PRESENT	0
811709	810206	21073H	PARTICIPANT	\N	PRESENT	0
811710	810206	20042V	PARTICIPANT	\N	PRESENT	0
811711	810206	14191V	PARTICIPANT	\N	PRESENT	0
811712	810206	19721W	PARTICIPANT	\N	PRESENT	0
811713	810206	20064C	PARTICIPANT	\N	PRESENT	0
811714	810206	20252E	PARTICIPANT	\N	PRESENT	0
811715	810206	14251Q	PARTICIPANT	\N	PRESENT	0
811716	810206	98022P	PARTICIPANT	\N	PRESENT	0
811717	810206	14267Y	PARTICIPANT	\N	PRESENT	0
811718	810206	99004R	PARTICIPANT	\N	PRESENT	0
811719	810206	19745F	PARTICIPANT	\N	PRESENT	0
811720	810206	14211G	PARTICIPANT	\N	PRESENT	0
811721	810206	14255U	PARTICIPANT	\N	PRESENT	0
811722	810206	17023S	PARTICIPANT	\N	PRESENT	0
811724	811723	20056C	PARTICIPANT	\N	PRESENT	0
811725	811723	19553Y	PARTICIPANT	\N	PRESENT	0
811726	811723	20066E	PRESIDENT	0	PRESENT	0
811727	811723	17965H	PARTICIPANT	\N	PRESENT	0
811728	811723	14147R	PARTICIPANT	\N	PRESENT	0
811730	811723	20024T	PARTICIPANT	\N	PRESENT	0
811779	810306	20028X	PARTICIPANT	\N	PRESENT	0
811780	810306	20248J	PARTICIPANT	\N	PRESENT	0
811781	810306	19569H	PARTICIPANT	\N	PRESENT	0
811782	810306	19721W	PARTICIPANT	\N	PRESENT	0
811783	810306	14267Y	PARTICIPANT	\N	PRESENT	0
811784	810306	11045K	PARTICIPANT	\N	PRESENT	0
811785	810306	19649G	PARTICIPANT	\N	PRESENT	0
811786	810306	19866P	PARTICIPANT	\N	PRESENT	0
811787	810306	21040X	PARTICIPANT	\N	PRESENT	0
811788	810306	14207L	PARTICIPANT	\N	PRESENT	0
811789	810306	20072C	PARTICIPANT	\N	PRESENT	0
811790	810306	14107H	PARTICIPANT	\N	PRESENT	0
811791	810306	21048G	PARTICIPANT	\N	PRESENT	0
811792	810306	20142Y	PARTICIPANT	\N	PRESENT	0
811793	810306	19758L	PARTICIPANT	\N	PRESENT	0
811794	810306	14121F	PARTICIPANT	\N	PRESENT	0
811795	810306	20054A	PARTICIPANT	\N	PRESENT	0
811796	810306	14059S	PARTICIPANT	\N	PRESENT	0
811797	810306	14105F	PARTICIPANT	\N	PRESENT	0
811798	810306	20124W	PARTICIPANT	\N	PRESENT	0
811799	810306	21061D	PARTICIPANT	\N	PRESENT	0
811800	810306	20136B	PARTICIPANT	\N	PRESENT	0
811801	810306	14281W	PARTICIPANT	\N	PRESENT	0
811802	810306	14229S	PARTICIPANT	\N	PRESENT	0
811803	810306	21056G	PARTICIPANT	\N	PRESENT	0
811804	810306	19820Y	PARTICIPANT	\N	PRESENT	0
811805	810306	21125C	PARTICIPANT	\N	PRESENT	0
811806	810306	21044C	PARTICIPANT	\N	PRESENT	0
804039	804033	21038E	PARTICIPANT	\N	PRESENT	0
804040	804033	14215L	PARTICIPANT	\N	PRESENT	0
805015	805014	19479G	PARTICIPANT	\N	PRESENT	0
805021	805020	19479G	PARTICIPANT	\N	PRESENT	0
805022	805020	14042U	PARTICIPANT	\N	PRESENT	0
805023	805020	14071N	PARTICIPANT	\N	PRESENT	0
806870	806869	20032T	PARTICIPANT	\N	PRESENT	0
806871	806869	20114U	PARTICIPANT	\N	PRESENT	0
806872	806869	20090E	PARTICIPANT	\N	PRESENT	0
806873	806869	20096L	PARTICIPANT	\N	PRESENT	0
806874	806869	14173T	PARTICIPANT	\N	PRESENT	0
806875	806869	19667J	PARTICIPANT	\N	PRESENT	0
806878	806877	08015R	PARTICIPANT	\N	PRESENT	0
806879	806877	14109K	PARTICIPANT	\N	PRESENT	0
806880	806877	21054E	PARTICIPANT	\N	PRESENT	0
806881	806877	20032T	PARTICIPANT	\N	PRESENT	0
806882	806877	20092G	PARTICIPANT	\N	PRESENT	0
806883	806877	14069U	PARTICIPANT	\N	PRESENT	0
806884	806877	20084G	PARTICIPANT	\N	PRESENT	0
807355	807178	20146D	PRESIDENT	0	PRESENT	0
807356	807178	17367Q	PARTICIPANT	\N	PRESENT	0
808529	807221	19711U	PARTICIPANT	\N	PRESENT	0
808439	808075	14207L	PARTICIPANT	\N	PRESENT	0
808440	808075	14257W	PARTICIPANT	\N	PRESENT	0
808441	808075	14038Y	PARTICIPANT	\N	EXCUSE	0
808442	808075	21052C	PARTICIPANT	\N	EXCUSE	0
808443	808075	20088L	PARTICIPANT	\N	EXCUSE	0
808444	808075	20082E	PARTICIPANT	\N	EXCUSE	0
808445	808075	08028W	PARTICIPANT	\N	EXCUSE	0
808446	808075	20084G	PARTICIPANT	\N	EXCUSE	0
808447	808129	07029T	PARTICIPANT	\N	EXCUSE	0
808531	807221	21078N	PARTICIPANT	\N	PRESENT	0
808532	807221	21053D	PARTICIPANT	\N	PRESENT	0
808533	807221	20050V	PARTICIPANT	\N	PRESENT	0
808534	807221	14189C	PARTICIPANT	\N	PRESENT	0
808535	807221	21090J	PARTICIPANT	\N	PRESENT	0
808536	807221	14059S	PARTICIPANT	\N	PRESENT	0
808541	807221	20102Q	PARTICIPANT	\N	PRESENT	0
808544	807221	21057H	PARTICIPANT	\N	PRESENT	0
808545	807221	11027H	PARTICIPANT	\N	PRESENT	0
808546	807221	21068L	PARTICIPANT	\N	PRESENT	0
808547	807221	21080G	PARTICIPANT	\N	PRESENT	0
808548	807221	14123H	PARTICIPANT	\N	PRESENT	0
808549	807221	19749K	PARTICIPANT	\N	PRESENT	0
808550	807221	19479G	PARTICIPANT	\N	PRESENT	0
808551	807221	14275Y	PARTICIPANT	\N	PRESENT	0
808552	807221	04047H	PARTICIPANT	\N	PRESENT	0
808553	807221	21033Y	PARTICIPANT	\N	PRESENT	0
808554	807221	14121F	PARTICIPANT	\N	PRESENT	0
808555	807221	17965H	PARTICIPANT	\N	PRESENT	0
808556	807221	19251M	PARTICIPANT	\N	PRESENT	0
808557	807221	21049H	PARTICIPANT	\N	PRESENT	0
808558	807221	11040E	PARTICIPANT	\N	PRESENT	0
808559	807221	20064C	PARTICIPANT	\N	PRESENT	0
808560	807221	20028X	PARTICIPANT	\N	PRESENT	0
808561	807221	20084G	PARTICIPANT	\N	PRESENT	0
808562	807221	21084L	PARTICIPANT	\N	PRESENT	0
808563	807221	20030R	PARTICIPANT	\N	PRESENT	0
808564	807221	21067K	PARTICIPANT	\N	PRESENT	0
808565	807221	19593H	PARTICIPANT	\N	PRESENT	0
808566	807221	19695N	PARTICIPANT	\N	PRESENT	0
808567	807221	19565D	PARTICIPANT	\N	PRESENT	0
808568	807221	19687N	PARTICIPANT	\N	PRESENT	0
808569	807221	21088Q	PARTICIPANT	\N	PRESENT	0
808570	807221	20112S	PARTICIPANT	\N	PRESENT	0
808571	807221	11056N	PARTICIPANT	\N	PRESENT	0
808572	807221	20110Q	PARTICIPANT	\N	PRESENT	0
808573	807221	19621T	PARTICIPANT	\N	PRESENT	0
808574	807221	20100N	PARTICIPANT	\N	PRESENT	0
808575	807221	18083K	PARTICIPANT	\N	PRESENT	0
808576	807221	19347U	PARTICIPANT	\N	PRESENT	0
808577	807221	19367Y	PARTICIPANT	\N	PRESENT	0
808578	807221	21093M	PARTICIPANT	\N	PRESENT	0
808579	807221	20142Y	PARTICIPANT	\N	PRESENT	0
808580	807221	19575F	PARTICIPANT	\N	PRESENT	0
808581	807221	21073H	PARTICIPANT	\N	PRESENT	0
808582	807221	08011M	PARTICIPANT	\N	PRESENT	0
808583	807221	21091K	PARTICIPANT	\N	PRESENT	0
808585	807221	21037D	PARTICIPANT	\N	PRESENT	0
808586	807221	01058X	PARTICIPANT	\N	PRESENT	0
808587	807221	99004R	PARTICIPANT	\N	PRESENT	0
808588	807221	20092G	PARTICIPANT	\N	PRESENT	0
808589	807221	21079P	PARTICIPANT	\N	PRESENT	0
808590	807221	20076G	PARTICIPANT	\N	PRESENT	0
808591	807221	20074E	PARTICIPANT	\N	PRESENT	0
808592	807221	14259Y	PARTICIPANT	\N	PRESENT	0
808593	807221	08069G	PARTICIPANT	\N	PRESENT	0
808594	807221	04042C	PARTICIPANT	\N	PRESENT	0
808595	807221	21043B	PARTICIPANT	\N	PRESENT	0
808596	807221	21044C	PARTICIPANT	\N	PRESENT	0
808597	807221	10015M	PARTICIPANT	\N	PRESENT	0
808598	807221	21061D	PARTICIPANT	\N	PRESENT	0
808599	807221	14223L	PARTICIPANT	\N	PRESENT	0
808600	807221	04045F	PARTICIPANT	\N	PRESENT	0
808601	807221	08028W	PARTICIPANT	\N	PRESENT	0
808602	807221	21071F	PARTICIPANT	\N	PRESENT	0
808603	807221	14191V	PARTICIPANT	\N	PRESENT	0
808604	807221	14237S	PARTICIPANT	\N	PRESENT	0
808605	807221	20044X	PARTICIPANT	\N	PRESENT	0
808606	807221	14193X	PARTICIPANT	\N	PRESENT	0
808607	807221	14215L	PARTICIPANT	\N	PRESENT	0
808608	807221	05012A	PARTICIPANT	\N	PRESENT	0
808609	807221	11090Q	PARTICIPANT	\N	PRESENT	0
808610	807221	20106U	PARTICIPANT	\N	PRESENT	0
808611	807221	19673G	PARTICIPANT	\N	PRESENT	0
808612	807221	14031R	PARTICIPANT	\N	PRESENT	0
808613	807221	19667J	PARTICIPANT	\N	PRESENT	0
808614	807221	19421M	PARTICIPANT	\N	PRESENT	0
808615	807221	14253S	PARTICIPANT	\N	PRESENT	0
808616	807221	17737W	PARTICIPANT	\N	PRESENT	0
808617	807221	20032T	PARTICIPANT	\N	PRESENT	0
808618	807221	14331P	PARTICIPANT	\N	PRESENT	0
808619	807221	21055F	PARTICIPANT	\N	PRESENT	0
808620	807221	14173T	PARTICIPANT	\N	PRESENT	0
808621	807221	19447X	PARTICIPANT	\N	PRESENT	0
808622	807221	21074J	PARTICIPANT	\N	PRESENT	0
808623	807221	21058J	PARTICIPANT	\N	PRESENT	0
808624	807221	21085M	PARTICIPANT	\N	PRESENT	0
808625	807221	21069M	PARTICIPANT	\N	PRESENT	0
808626	807221	20180F	PARTICIPANT	\N	PRESENT	0
808627	807221	20026V	PARTICIPANT	\N	PRESENT	0
808628	807221	19954N	PARTICIPANT	\N	PRESENT	0
808629	807221	21081H	PARTICIPANT	\N	PRESENT	0
808630	807221	08047A	PARTICIPANT	\N	PRESENT	0
808631	807221	20138D	PARTICIPANT	\N	PRESENT	0
808632	807221	21035B	PARTICIPANT	\N	PRESENT	0
808633	807221	14147R	PARTICIPANT	\N	PRESENT	0
808634	807221	14038Y	PARTICIPANT	\N	PRESENT	0
808635	807221	18231D	PARTICIPANT	\N	PRESENT	0
808636	807221	19723Y	PARTICIPANT	\N	PRESENT	0
808637	807221	20034V	PARTICIPANT	\N	PRESENT	0
808638	807221	21039F	PARTICIPANT	\N	PRESENT	0
808639	807221	20172F	PARTICIPANT	\N	PRESENT	0
808640	807221	20114U	PARTICIPANT	\N	PRESENT	0
808641	807221	20140W	PARTICIPANT	\N	PRESENT	0
808642	807221	20038A	PARTICIPANT	\N	PRESENT	0
808643	807221	20056C	PARTICIPANT	\N	PRESENT	0
808644	807221	19399H	PARTICIPANT	\N	PRESENT	0
808645	807221	20104S	PARTICIPANT	\N	PRESENT	0
808646	807221	20108W	PARTICIPANT	\N	PRESENT	0
808647	807221	20024T	PARTICIPANT	\N	PRESENT	0
808648	807221	14213J	PARTICIPANT	\N	PRESENT	0
808649	807221	21089R	PARTICIPANT	\N	PRESENT	0
808650	807221	20058E	PARTICIPANT	\N	PRESENT	0
808651	807221	21047F	PARTICIPANT	\N	PRESENT	0
808652	807221	21063F	PARTICIPANT	\N	PRESENT	0
808653	807221	08061X	PARTICIPANT	\N	PRESENT	0
808654	807221	11072N	PARTICIPANT	\N	PRESENT	0
808655	807221	20128B	PARTICIPANT	\N	PRESENT	0
808656	807221	14037X	PARTICIPANT	\N	PRESENT	0
808657	807221	20068G	PARTICIPANT	\N	PRESENT	0
808658	807221	08073C	PARTICIPANT	\N	PRESENT	0
808659	807221	17367Q	PARTICIPANT	\N	PRESENT	0
808660	807221	19591F	PARTICIPANT	\N	PRESENT	0
808661	807221	19709B	PARTICIPANT	\N	PRESENT	0
808662	807221	19697Q	PARTICIPANT	\N	PRESENT	0
808663	807221	20022R	PARTICIPANT	\N	PRESENT	0
808664	807221	19349W	PARTICIPANT	\N	PRESENT	0
808665	807221	08018U	PARTICIPANT	\N	PRESENT	0
808666	807221	19657G	PARTICIPANT	\N	PRESENT	0
808667	807221	08015R	PARTICIPANT	\N	PRESENT	0
811150	810304	20054A	PARTICIPANT	\N	PRESENT	0
811151	810304	21037D	PARTICIPANT	\N	PRESENT	0
811152	810304	21057H	PARTICIPANT	\N	PRESENT	0
811153	810304	21089R	PARTICIPANT	\N	PRESENT	0
811154	810304	19647E	PARTICIPANT	\N	PRESENT	0
811155	810304	19693L	PARTICIPANT	\N	PRESENT	0
811156	810304	14073Q	PARTICIPANT	\N	PRESENT	0
811157	810304	19749K	PARTICIPANT	\N	PRESENT	0
811158	810304	19545Y	PARTICIPANT	\N	PRESENT	0
811160	811159	19569H	PARTICIPANT	\N	PRESENT	0
811161	811159	19683J	PARTICIPANT	\N	PRESENT	0
811162	811159	14213J	PARTICIPANT	\N	PRESENT	0
811163	810304	08018U	PARTICIPANT	\N	PRESENT	0
811164	810304	20074E	PARTICIPANT	\N	PRESENT	0
811165	810304	21058J	PARTICIPANT	\N	PRESENT	0
811167	810304	20044X	PARTICIPANT	\N	PRESENT	0
811168	810304	20062A	PARTICIPANT	\N	PRESENT	0
811169	810304	18083K	PARTICIPANT	\N	PRESENT	0
811170	810304	19533U	PARTICIPANT	\N	PRESENT	0
811171	810304	20024T	PARTICIPANT	\N	PRESENT	0
811172	810304	14147R	PARTICIPANT	\N	PRESENT	0
811173	810304	20126Y	PARTICIPANT	\N	PRESENT	0
811148	810304	14229S	PARTICIPANT	\N	PRESENT	0
811149	810304	20098N	PARTICIPANT	\N	PRESENT	0
811175	810304	19711U	PARTICIPANT	\N	PRESENT	0
811176	811174	14213J	PARTICIPANT	\N	PRESENT	0
811177	811166	17367Q	PARTICIPANT	\N	PRESENT	0
811178	811174	19683J	PARTICIPANT	\N	PRESENT	0
811179	811166	14151M	PARTICIPANT	\N	PRESENT	0
811180	811174	19569H	PARTICIPANT	\N	PRESENT	0
811181	810304	19697Q	PARTICIPANT	\N	PRESENT	0
811182	810304	19629C	PARTICIPANT	\N	PRESENT	0
811183	810304	14107H	PARTICIPANT	\N	PRESENT	0
811184	810304	19347U	PARTICIPANT	\N	PRESENT	0
811185	810304	14083S	PARTICIPANT	\N	PRESENT	0
811186	810304	20102Q	PARTICIPANT	\N	PRESENT	0
811187	810304	21044C	PARTICIPANT	\N	PRESENT	0
811188	810304	20106U	PARTICIPANT	\N	PRESENT	0
811189	810304	11090Q	PARTICIPANT	\N	PRESENT	0
811190	810304	21063F	PARTICIPANT	\N	PRESENT	0
811191	810304	14331P	PARTICIPANT	\N	PRESENT	0
811192	810304	19719D	PARTICIPANT	\N	PRESENT	0
811193	810304	19251M	PARTICIPANT	\N	PRESENT	0
811194	810304	19695N	PARTICIPANT	\N	PRESENT	0
811195	810304	14151M	PARTICIPANT	\N	PRESENT	0
811196	810304	21061D	PARTICIPANT	\N	PRESENT	0
811197	810304	14053L	PARTICIPANT	\N	PRESENT	0
811198	810304	19507S	PARTICIPANT	\N	PRESENT	0
811199	810304	19563B	PARTICIPANT	\N	PRESENT	0
811200	810304	20090E	PARTICIPANT	\N	PRESENT	0
811201	810304	20104S	PARTICIPANT	\N	PRESENT	0
811202	810304	14215L	PARTICIPANT	\N	PRESENT	0
811204	810304	14267Y	PARTICIPANT	\N	PRESENT	0
811205	810304	19479G	PARTICIPANT	\N	PRESENT	0
811206	811203	21045D	PARTICIPANT	\N	PRESENT	1
811207	811203	17779H	PARTICIPANT	\N	PRESENT	1
811208	810304	21051B	PARTICIPANT	\N	PRESENT	0
811209	810304	21066J	PARTICIPANT	\N	PRESENT	0
811210	810304	04045F	PARTICIPANT	\N	PRESENT	0
811211	810304	21093M	PARTICIPANT	\N	PRESENT	0
811212	810304	14038Y	PARTICIPANT	\N	PRESENT	0
811213	810304	04033B	PARTICIPANT	\N	PRESENT	0
811215	811214	21045D	PARTICIPANT	\N	PRESENT	0
811216	810304	21082J	PARTICIPANT	\N	PRESENT	0
811217	810304	19679N	PARTICIPANT	\N	PRESENT	0
811219	810304	20076G	PARTICIPANT	\N	PRESENT	0
811220	811218	21045D	PARTICIPANT	\N	PRESENT	0
811221	810304	20032T	PARTICIPANT	\N	PRESENT	0
811222	810304	14329V	PARTICIPANT	\N	PRESENT	0
811223	810304	19447X	PARTICIPANT	\N	PRESENT	0
811225	811224	19760E	PARTICIPANT	\N	PRESENT	0
811226	811224	04092N	PARTICIPANT	\N	PRESENT	0
811227	811224	20130U	PARTICIPANT	\N	PRESENT	1
811228	810304	21048G	PARTICIPANT	\N	PRESENT	0
811229	810304	20140W	PARTICIPANT	\N	PRESENT	0
811230	810304	14195A	PARTICIPANT	\N	PRESENT	0
811231	810304	21070E	PARTICIPANT	\N	PRESENT	0
811232	810304	20086J	PARTICIPANT	\N	PRESENT	0
811233	810304	20022R	PARTICIPANT	\N	PRESENT	0
811234	810304	20100N	PARTICIPANT	\N	PRESENT	0
811280	810305	11048N	PARTICIPANT	\N	PRESENT	0
811281	810305	07033P	PARTICIPANT	\N	PRESENT	0
811282	810305	19760E	PARTICIPANT	\N	PRESENT	0
811283	810305	21078N	PARTICIPANT	\N	PRESENT	0
811284	810305	08073C	PARTICIPANT	\N	PRESENT	0
811285	810305	14097Y	PARTICIPANT	\N	PRESENT	0
811286	810305	20104S	PARTICIPANT	\N	PRESENT	0
811287	810305	21076L	PARTICIPANT	\N	PRESENT	0
811288	810305	19569H	PARTICIPANT	\N	PRESENT	0
811289	810305	20100N	PARTICIPANT	\N	PRESENT	0
811290	810305	21082J	PARTICIPANT	\N	PRESENT	0
811291	810305	14237S	PARTICIPANT	\N	PRESENT	0
811292	810305	14073Q	PARTICIPANT	\N	PRESENT	0
811293	810305	14026U	PARTICIPANT	\N	PRESENT	0
811294	810305	20040T	PARTICIPANT	\N	PRESENT	0
811295	810305	11065P	PARTICIPANT	\N	PRESENT	0
811296	810305	21053D	PARTICIPANT	\N	PRESENT	0
811297	810305	21048G	PARTICIPANT	\N	PRESENT	0
811298	810305	21049H	PARTICIPANT	\N	PRESENT	0
811299	810305	11056N	PARTICIPANT	\N	PRESENT	0
811300	810305	19679N	PARTICIPANT	\N	PRESENT	0
811301	810305	14001X	PARTICIPANT	\N	PRESENT	0
811302	810305	20066E	PARTICIPANT	\N	PRESENT	0
811303	810305	14147R	PARTICIPANT	\N	PRESENT	0
811304	810305	20094J	PARTICIPANT	\N	PRESENT	0
811305	810305	20082E	PARTICIPANT	\N	PRESENT	0
811306	810305	18395Y	PARTICIPANT	\N	PRESENT	0
811307	810305	21057H	PARTICIPANT	\N	PRESENT	0
811308	810305	20086J	PARTICIPANT	\N	PRESENT	0
811309	810305	14083S	PARTICIPANT	\N	PRESENT	0
811310	810305	14033T	PARTICIPANT	\N	PRESENT	0
811387	808394	14071N	PRESIDENT	0	PRESENT	0
811388	808394	19691J	PARTICIPANT	\N	PRESENT	0
811390	808394	18193Q	PARTICIPANT	\N	PRESENT	0
811391	808394	20148F	PARTICIPANT	\N	PRESENT	0
811392	808394	08061X	PARTICIPANT	\N	PRESENT	0
811393	808394	19798U	PARTICIPANT	\N	PRESENT	0
811394	808394	04092N	PARTICIPANT	\N	PRESENT	0
811395	808394	21039F	PARTICIPANT	\N	PRESENT	0
811396	808394	14217N	PARTICIPANT	\N	PRESENT	0
811397	808394	20090E	PARTICIPANT	\N	PRESENT	0
811398	808394	19703U	PRESIDENT	1	PRESENT	0
811399	808394	14223L	PARTICIPANT	\N	PRESENT	0
811278	810305	11090Q	PARTICIPANT	\N	PRESENT	0
811279	810305	14331P	PARTICIPANT	\N	PRESENT	0
811400	808394	14213J	PARTICIPANT	\N	PRESENT	0
811401	808394	20140W	PARTICIPANT	\N	PRESENT	0
811402	808394	19569H	PARTICIPANT	\N	PRESENT	0
811403	808394	17965H	PARTICIPANT	\N	PRESENT	0
811405	808394	19866P	PARTICIPANT	\N	PRESENT	0
811406	808394	19723Y	PARTICIPANT	\N	PRESENT	0
811407	808394	14281W	PARTICIPANT	\N	PRESENT	0
811408	808394	19683J	PARTICIPANT	\N	PRESENT	0
811409	808394	19758L	PARTICIPANT	\N	PRESENT	0
811410	808394	19713W	PARTICIPANT	\N	PRESENT	0
811411	808394	21046E	PARTICIPANT	\N	PRESENT	0
811412	808394	19367Y	PARTICIPANT	\N	EXCUSE	0
811413	808394	21045D	PARTICIPANT	\N	PRESENT	0
811414	808394	20248J	PARTICIPANT	\N	EXCUSE	0
811415	808394	21087P	PARTICIPANT	\N	EXCUSE	0
811416	808394	19591F	PARTICIPANT	\N	PRESENT	0
811417	808394	21064G	PARTICIPANT	\N	PRESENT	0
811418	808394	19679N	PARTICIPANT	\N	PRESENT	0
811419	808394	19760E	PARTICIPANT	\N	PRESENT	0
811422	808394	14195A	PARTICIPANT	\N	PRESENT	0
811423	808394	20096L	PARTICIPANT	\N	PRESENT	0
811473	811472	14107H	PARTICIPANT	\N	PRESENT	0
811526	811523	19798U	PARTICIPANT	\N	PRESENT	0
811527	811523	18193Q	PARTICIPANT	\N	PRESENT	0
811528	811525	19798U	PARTICIPANT	\N	PRESENT	0
811529	811525	18193Q	PARTICIPANT	\N	PRESENT	0
811534	811533	19057M	PARTICIPANT	\N	PRESENT	0
811536	811533	20114U	PARTICIPANT	\N	PRESENT	0
811537	811533	14001X	PARTICIPANT	\N	PRESENT	0
811538	811533	04042C	PARTICIPANT	\N	PRESENT	0
811539	811533	14133K	PARTICIPANT	\N	PRESENT	0
811547	811546	12028B	PARTICIPANT	\N	PRESENT	0
811548	811546	14267Y	PARTICIPANT	\N	PRESENT	0
811549	811546	08010L	PARTICIPANT	\N	PRESENT	0
811551	811550	12028B	PARTICIPANT	\N	PRESENT	0
811552	811550	14267Y	PARTICIPANT	\N	PRESENT	0
801634	801464	14257W	PARTICIPANT	\N	EXCUSE	0
801785	801464	21050A	PARTICIPANT	\N	PRESENT	0
801790	801464	20078J	PARTICIPANT	\N	EXCUSE	0
801815	801464	19705W	PARTICIPANT	\N	EXCUSE	0
801816	801464	11090Q	PARTICIPANT	\N	EXCUSE	0
801817	801464	08015R	PARTICIPANT	\N	EXCUSE	0
801818	801464	14033T	PARTICIPANT	\N	EXCUSE	0
801819	801464	14357A	PARTICIPANT	\N	EXCUSE	0
801820	801464	14329V	PARTICIPANT	\N	EXCUSE	0
801821	801464	19707Y	PARTICIPANT	\N	EXCUSE	0
801994	800752	14097Y	PARTICIPANT	\N	PRESENT	0
802004	800752	20124W	PARTICIPANT	\N	PRESENT	0
802736	801389	21086N	PARTICIPANT	\N	PRESENT	0
802737	801389	14231L	PARTICIPANT	\N	PRESENT	0
802738	801389	19709B	PARTICIPANT	\N	PRESENT	0
802739	801389	14179A	PARTICIPANT	\N	PRESENT	0
802740	801389	08018U	PARTICIPANT	\N	PRESENT	0
802741	801389	07029T	PARTICIPANT	\N	PRESENT	0
802742	801389	08015R	PARTICIPANT	\N	PRESENT	0
802743	801389	11065P	PARTICIPANT	\N	PRESENT	0
802744	801389	19768N	PARTICIPANT	\N	PRESENT	0
802745	801389	19705W	PARTICIPANT	\N	PRESENT	0
802746	801389	19685L	PARTICIPANT	\N	PRESENT	0
802747	801389	20048C	PARTICIPANT	\N	PRESENT	0
802748	801389	19707Y	PARTICIPANT	\N	PRESENT	0
802749	801389	18231D	PARTICIPANT	\N	PRESENT	0
802750	801389	14073Q	PARTICIPANT	\N	PRESENT	0
802751	801389	20066E	PARTICIPANT	\N	PRESENT	0
802752	801389	08010L	PARTICIPANT	\N	PRESENT	0
802753	801389	14059S	PARTICIPANT	\N	PRESENT	0
802754	801389	08056B	PARTICIPANT	\N	PRESENT	0
802755	801389	19699S	PARTICIPANT	\N	PRESENT	0
802756	801389	20124W	PARTICIPANT	\N	PRESENT	0
802757	801389	20052X	PARTICIPANT	\N	PRESENT	0
802758	801389	20054A	PARTICIPANT	\N	PRESENT	0
802759	801389	14205J	PARTICIPANT	\N	PRESENT	0
802760	801389	20286Q	PARTICIPANT	\N	PRESENT	0
802761	801389	14357A	PARTICIPANT	\N	PRESENT	0
802762	801389	11085T	PARTICIPANT	\N	PRESENT	0
802763	801389	19826F	PARTICIPANT	\N	PRESENT	0
802764	801389	14219Q	PARTICIPANT	\N	PRESENT	0
802765	801389	08009T	PARTICIPANT	\N	PRESENT	0
802766	801389	20086J	PARTICIPANT	\N	PRESENT	0
802767	801389	19335Q	PARTICIPANT	\N	PRESENT	0
802768	801389	20098N	PARTICIPANT	\N	PRESENT	0
802769	801389	19745F	PARTICIPANT	\N	PRESENT	0
802770	801389	21095P	PARTICIPANT	\N	PRESENT	0
802771	801389	21053D	PARTICIPANT	\N	PRESENT	0
802772	801389	19621T	PARTICIPANT	\N	PRESENT	0
802773	801389	21090J	PARTICIPANT	\N	PRESENT	0
802774	801389	19619A	PARTICIPANT	\N	PRESENT	0
802775	801389	14217N	PARTICIPANT	\N	PRESENT	0
802776	801389	20120S	PARTICIPANT	\N	PRESENT	0
802777	801389	19713W	PARTICIPANT	\N	PRESENT	0
802778	801389	20252E	PARTICIPANT	\N	PRESENT	0
802779	801389	01034P	PARTICIPANT	\N	PRESENT	0
802780	801389	14331P	PARTICIPANT	\N	PRESENT	0
802781	801389	14089Y	PARTICIPANT	\N	PRESENT	0
802782	801389	20090E	PARTICIPANT	\N	PRESENT	0
802783	801389	19749K	PARTICIPANT	\N	PRESENT	0
802784	801389	20118Y	PARTICIPANT	\N	PRESENT	0
802785	801389	19798U	PARTICIPANT	\N	PRESENT	0
802786	801389	07004J	PARTICIPANT	\N	PRESENT	0
802787	801389	14071N	PARTICIPANT	\N	PRESENT	0
802788	801389	14187A	PARTICIPANT	\N	PRESENT	0
802789	801389	19701S	PARTICIPANT	\N	PRESENT	0
802790	801389	14053L	PARTICIPANT	\N	PRESENT	0
802791	801389	20094J	PARTICIPANT	\N	PRESENT	0
802792	801389	19679N	PARTICIPANT	\N	PRESENT	0
802793	801389	05008E	PARTICIPANT	\N	PRESENT	0
802794	801389	21074J	PARTICIPANT	\N	PRESENT	0
802795	801389	21085M	PARTICIPANT	\N	PRESENT	0
802806	801389	19657G	PARTICIPANT	\N	PRESENT	0
802797	801389	21069M	PARTICIPANT	\N	PRESENT	0
802798	801389	21035B	PARTICIPANT	\N	PRESENT	0
802799	801389	20148F	PARTICIPANT	\N	PRESENT	0
802800	801389	04047H	PARTICIPANT	\N	PRESENT	0
802801	801389	21055F	PARTICIPANT	\N	PRESENT	0
802802	801389	20126Y	PARTICIPANT	\N	PRESENT	0
802803	801389	14123H	PARTICIPANT	\N	PRESENT	0
802804	801389	21091K	PARTICIPANT	\N	PRESENT	0
802805	801389	14169X	PARTICIPANT	\N	PRESENT	0
802809	801389	08073C	PARTICIPANT	\N	PRESENT	0
805486	805484	21046E	PARTICIPANT	\N	PRESENT	0
804402	804085	04047H	PRESIDENT	0	PRESENT	0
805487	805484	19679N	PARTICIPANT	\N	PRESENT	0
804404	804085	19111A	PARTICIPANT	\N	PRESENT	0
804405	804085	20022R	PARTICIPANT	\N	PRESENT	0
805871	803919	19782L	PARTICIPANT	\N	PRESENT	0
805872	803919	21096Q	PARTICIPANT	\N	PRESENT	0
805873	803919	14249W	PARTICIPANT	\N	PRESENT	0
805874	803919	21033Y	PARTICIPANT	\N	PRESENT	0
805875	803919	20128B	PARTICIPANT	\N	PRESENT	0
804416	804085	11072N	PARTICIPANT	\N	PRESENT	0
805876	803919	14037X	PARTICIPANT	\N	PRESENT	0
805877	803919	19697Q	PARTICIPANT	\N	PRESENT	0
804419	804085	19673G	PARTICIPANT	\N	PRESENT	0
806391	804088	21031W	PARTICIPANT	\N	PRESENT	0
804421	804085	20114U	PARTICIPANT	\N	PRESENT	0
804422	804085	14231L	PARTICIPANT	\N	PRESENT	0
804423	804085	19725B	PARTICIPANT	\N	PRESENT	0
806392	804088	19565D	PARTICIPANT	\N	PRESENT	0
804425	804085	14215L	PARTICIPANT	\N	PRESENT	0
804426	804085	14189C	PARTICIPANT	\N	PRESENT	0
806393	804088	20072C	PARTICIPANT	\N	PRESENT	0
806394	804088	01058X	PARTICIPANT	\N	PRESENT	0
804429	804085	21044C	PARTICIPANT	\N	PRESENT	0
806395	804088	04042C	PARTICIPANT	\N	PRESENT	0
806396	804088	19669L	PARTICIPANT	\N	PRESENT	0
806397	804088	12028B	PARTICIPANT	\N	PRESENT	0
806398	804088	17737W	PARTICIPANT	\N	PRESENT	0
806399	804088	19421M	PARTICIPANT	\N	PRESENT	0
806400	804088	14193X	PRESIDENT	0	PRESENT	0
806401	804088	14179A	PARTICIPANT	\N	PRESENT	0
804462	804085	19649G	PARTICIPANT	\N	PRESENT	0
804486	804085	05008E	PARTICIPANT	\N	PRESENT	0
804489	804085	20108W	PARTICIPANT	\N	PRESENT	0
806402	804088	07033P	PARTICIPANT	\N	PRESENT	0
806403	804088	14249W	PARTICIPANT	\N	PRESENT	0
806404	804088	20128B	PARTICIPANT	\N	PRESENT	0
806405	804088	14037X	PARTICIPANT	\N	PRESENT	0
806406	804088	14097Y	PARTICIPANT	\N	PRESENT	0
806407	804088	14059S	PARTICIPANT	\N	PRESENT	0
806408	804088	14133K	PARTICIPANT	\N	PRESENT	0
806409	804088	19531S	PARTICIPANT	\N	PRESENT	0
806410	804088	21073H	PARTICIPANT	\N	PRESENT	0
806411	804088	14105F	PARTICIPANT	\N	PRESENT	0
806412	804088	20064C	PARTICIPANT	\N	PRESENT	0
806413	804088	98022P	PARTICIPANT	\N	PRESENT	0
806414	804088	99004R	PARTICIPANT	\N	PRESENT	0
806415	804088	19745F	PARTICIPANT	\N	PRESENT	0
806416	804088	14211G	PARTICIPANT	\N	PRESENT	0
806417	804088	17023S	PARTICIPANT	\N	PRESENT	0
806418	804088	14001X	PARTICIPANT	\N	EXCUSE	0
806419	804088	08047A	PARTICIPANT	\N	EXCUSE	0
806420	803920	21037D	PARTICIPANT	\N	PRESENT	0
806421	803920	21058J	PARTICIPANT	\N	PRESENT	0
806422	803920	20142Y	PARTICIPANT	\N	PRESENT	0
806423	803920	21065H	PARTICIPANT	\N	PRESENT	0
806424	803920	21077M	PARTICIPANT	\N	PRESENT	0
806425	803920	14357A	PARTICIPANT	\N	PRESENT	0
806426	803920	21040X	PARTICIPANT	\N	PRESENT	0
806427	803920	21072G	PARTICIPANT	\N	PRESENT	0
806428	803920	21094N	PARTICIPANT	\N	PRESENT	0
806429	803920	19954N	PARTICIPANT	\N	PRESENT	0
803391	803390	19575F	PARTICIPANT	\N	PRESENT	0
803392	803390	19711U	PARTICIPANT	\N	PRESENT	0
803393	803390	11070L	PARTICIPANT	\N	PRESENT	0
803394	803390	14257W	PRESIDENT	0	PRESENT	0
806433	804088	19347U	PARTICIPANT	\N	PRESENT	0
803396	803390	14207L	PARTICIPANT	\N	EXCUSE	0
803397	803390	20042V	PARTICIPANT	\N	EXCUSE	0
806435	804088	11027H	PARTICIPANT	\N	PRESENT	0
806538	803922	14229S	PARTICIPANT	\N	PRESENT	0
806544	803922	14207L	PARTICIPANT	\N	PRESENT	0
806539	803922	19593H	PARTICIPANT	\N	PRESENT	0
806540	803922	21059K	PARTICIPANT	\N	PRESENT	0
806541	803922	21089R	PARTICIPANT	\N	PRESENT	0
806542	803922	20264J	PARTICIPANT	\N	PRESENT	0
804041	804034	21071F	PARTICIPANT	\N	PRESENT	0
811807	810306	08069G	PARTICIPANT	\N	PRESENT	0
811808	810306	14223L	PARTICIPANT	\N	PRESENT	0
811809	810306	20044X	PARTICIPANT	\N	PRESENT	0
811810	810306	14215L	PARTICIPANT	\N	PRESENT	0
811811	810306	14231L	PARTICIPANT	\N	PRESENT	0
811812	810306	20046A	PARTICIPANT	\N	PRESENT	0
811813	810306	19621T	PARTICIPANT	\N	PRESENT	0
811814	810306	21049H	PARTICIPANT	\N	PRESENT	0
811815	810306	19687N	PARTICIPANT	\N	PRESENT	0
811816	810306	18083K	PARTICIPANT	\N	PRESENT	0
811817	810306	19711U	PARTICIPANT	\N	PRESENT	0
811818	810306	11056N	PARTICIPANT	\N	PRESENT	0
811819	810306	19575F	PARTICIPANT	\N	PRESENT	0
811820	810306	21084L	PARTICIPANT	\N	PRESENT	0
811821	810306	99004R	PARTICIPANT	\N	PRESENT	0
811822	810306	01058X	PARTICIPANT	\N	PRESENT	0
811823	810306	21030V	PARTICIPANT	\N	PRESENT	0
811824	810306	04042C	PARTICIPANT	\N	PRESENT	0
811825	810306	20110Q	PARTICIPANT	\N	PRESENT	0
811826	810306	20078J	PARTICIPANT	\N	PRESENT	0
811827	810306	19347U	PARTICIPANT	\N	PRESENT	0
811828	810306	21091K	PARTICIPANT	\N	PRESENT	0
811829	810306	21092L	PARTICIPANT	\N	PRESENT	0
811830	810306	20074E	PARTICIPANT	\N	PRESENT	0
811831	810306	21093M	PARTICIPANT	\N	PRESENT	0
811832	810306	20076G	PARTICIPANT	\N	PRESENT	0
811833	810306	21073H	PARTICIPANT	\N	PRESENT	0
811834	810306	21037D	PARTICIPANT	\N	PRESENT	0
811835	810306	20092G	PARTICIPANT	\N	PRESENT	0
811836	810306	21079P	PARTICIPANT	\N	PRESENT	0
811837	810306	19573D	PARTICIPANT	\N	PRESENT	0
811838	810306	08028W	PARTICIPANT	\N	PRESENT	0
811839	810306	10015M	PARTICIPANT	\N	PRESENT	0
811840	810306	21080G	PARTICIPANT	\N	PRESENT	0
811841	810306	21071F	PARTICIPANT	\N	PRESENT	0
811842	810306	14191V	PARTICIPANT	\N	PRESENT	0
811843	810306	20022R	PARTICIPANT	\N	PRESENT	0
811844	810306	20032T	PARTICIPANT	\N	PRESENT	0
811845	810306	19760E	PARTICIPANT	\N	PRESENT	0
811846	810306	19681G	PARTICIPANT	\N	PRESENT	0
811847	810306	19565D	PARTICIPANT	\N	PRESENT	0
811848	810306	19421M	PARTICIPANT	\N	PRESENT	0
811849	810306	20102Q	PARTICIPANT	\N	PRESENT	0
811850	810306	19667J	PARTICIPANT	\N	PRESENT	0
811851	810306	19673G	PARTICIPANT	\N	PRESENT	0
811852	810306	20134Y	PARTICIPANT	\N	PRESENT	0
811853	810306	21055F	PARTICIPANT	\N	PRESENT	0
811854	810306	14173T	PARTICIPANT	\N	PRESENT	0
811855	810306	19447X	PARTICIPANT	\N	PRESENT	0
811856	810306	21068L	PARTICIPANT	\N	PRESENT	0
811857	810306	21058J	PARTICIPANT	\N	PRESENT	0
811858	810306	20180F	PARTICIPANT	\N	PRESENT	0
811859	810306	20026V	PARTICIPANT	\N	PRESENT	0
811860	810306	14193X	PARTICIPANT	\N	PRESENT	0
811861	810306	21081H	PARTICIPANT	\N	PRESENT	0
811862	810306	08047A	PARTICIPANT	\N	PRESENT	0
811863	810306	14331P	PARTICIPANT	\N	PRESENT	0
811864	810306	20172F	PARTICIPANT	\N	PRESENT	0
811865	810306	14147R	PARTICIPANT	\N	PRESENT	0
811866	810306	14213J	PARTICIPANT	\N	PRESENT	0
811867	810306	20024T	PARTICIPANT	\N	PRESENT	0
811868	810306	21072G	PARTICIPANT	\N	PRESENT	0
811869	810306	20058E	PARTICIPANT	\N	PRESENT	0
811870	810306	14038Y	PARTICIPANT	\N	PRESENT	0
811871	810306	19723Y	PARTICIPANT	\N	PRESENT	0
811872	810306	20266L	PARTICIPANT	\N	PRESENT	0
811873	810306	20068G	PARTICIPANT	\N	PRESENT	0
811874	810306	21047F	PARTICIPANT	\N	PRESENT	0
811875	810306	14033T	PARTICIPANT	\N	PRESENT	0
811876	810306	21043B	PARTICIPANT	\N	PRESENT	0
811877	810306	20056C	PARTICIPANT	\N	PRESENT	0
811878	810306	14031R	PARTICIPANT	\N	PRESENT	0
811879	810306	19399H	PARTICIPANT	\N	PRESENT	0
811880	810306	19782L	PARTICIPANT	\N	PRESENT	0
811881	810306	21063F	PARTICIPANT	\N	PRESENT	0
811882	810306	14249W	PARTICIPANT	\N	PRESENT	0
811883	810306	14355X	PARTICIPANT	\N	PRESENT	0
811884	810306	19709B	PARTICIPANT	\N	PRESENT	0
811885	810306	20128B	PARTICIPANT	\N	PRESENT	0
811886	810306	19591F	PARTICIPANT	\N	PRESENT	0
811887	810306	08015R	PARTICIPANT	\N	PRESENT	0
811888	810306	14037X	PARTICIPANT	\N	PRESENT	0
811889	810306	19768N	PARTICIPANT	\N	PRESENT	0
811890	810306	19697Q	PARTICIPANT	\N	PRESENT	0
811891	810306	11043H	PARTICIPANT	\N	PRESENT	0
811892	810306	11072N	PARTICIPANT	\N	PRESENT	0
811893	810306	20148F	PARTICIPANT	\N	PRESENT	0
811894	810306	08061X	PARTICIPANT	\N	PRESENT	0
811895	810306	07029T	PARTICIPANT	\N	PRESENT	0
811896	810306	19349W	PARTICIPANT	\N	PRESENT	0
811897	810306	20104S	PARTICIPANT	\N	PRESENT	0
811898	810306	19301E	PARTICIPANT	\N	PRESENT	0
811899	810306	04045F	PARTICIPANT	\N	PRESENT	0
811900	810306	19507S	PARTICIPANT	\N	PRESENT	0
811901	810306	17737W	PARTICIPANT	\N	PRESENT	0
811902	810306	19383Y	PARTICIPANT	\N	PRESENT	0
811903	810306	14357A	PARTICIPANT	\N	PRESENT	0
811904	810306	21074J	PARTICIPANT	\N	PRESENT	0
811905	810306	07033P	PARTICIPANT	\N	PRESENT	0
811906	810306	21085M	PARTICIPANT	\N	PRESENT	0
811907	810306	21069M	PARTICIPANT	\N	PRESENT	0
811908	810306	20086J	PARTICIPANT	\N	PRESENT	0
811909	810306	14055N	PARTICIPANT	\N	PRESENT	0
811910	810306	14069U	PARTICIPANT	\N	PRESENT	0
811911	810306	19798U	PARTICIPANT	\N	PRESENT	0
811912	810306	19701S	PARTICIPANT	\N	PRESENT	0
811913	810306	14026U	PARTICIPANT	\N	PRESENT	0
811914	810306	21090J	PARTICIPANT	\N	PRESENT	0
811915	810306	20090E	PARTICIPANT	\N	PRESENT	0
811916	810306	20118Y	PARTICIPANT	\N	PRESENT	0
811917	810306	05008E	PARTICIPANT	\N	PRESENT	0
811918	810306	14071N	PARTICIPANT	\N	PRESENT	0
811919	810306	14187A	PARTICIPANT	\N	PRESENT	0
811920	810306	08034U	PARTICIPANT	\N	PRESENT	0
811921	810306	19703U	PARTICIPANT	\N	PRESENT	0
811922	810306	19629C	PARTICIPANT	\N	PRESENT	0
811923	810306	21041Y	PARTICIPANT	\N	PRESENT	0
811924	810306	14259Y	PARTICIPANT	\N	PRESENT	0
811925	810306	14329V	PARTICIPANT	\N	PRESENT	0
811926	810306	20140W	PARTICIPANT	\N	PRESENT	0
811927	810306	20132W	PARTICIPANT	\N	PRESENT	0
811928	810306	21066J	PARTICIPANT	\N	PRESENT	0
811929	810306	20038A	PARTICIPANT	\N	PRESENT	0
811930	810306	19553Y	PARTICIPANT	\N	PRESENT	0
811931	810306	19593H	PARTICIPANT	\N	PRESENT	0
811932	810306	20100N	PARTICIPANT	\N	PRESENT	0
811933	810306	11065P	PARTICIPANT	\N	PRESENT	0
811934	810306	04047H	PARTICIPANT	\N	PRESENT	0
811935	810306	20252E	PARTICIPANT	\N	PRESENT	0
811936	810306	21036C	PARTICIPANT	\N	PRESENT	0
811937	810306	21046E	PARTICIPANT	\N	PRESENT	0
811938	810306	20020P	PARTICIPANT	\N	PRESENT	0
811939	810306	19545Y	PARTICIPANT	\N	PRESENT	0
811940	810306	14195A	PARTICIPANT	\N	PRESENT	0
811941	810306	11090Q	PARTICIPANT	\N	PRESENT	0
811942	810306	19693L	PARTICIPANT	\N	PRESENT	0
811943	810306	14211G	PARTICIPANT	\N	PRESENT	0
811944	810306	04033B	PARTICIPANT	\N	PRESENT	0
811945	810306	21054E	PARTICIPANT	\N	PRESENT	0
811946	810306	19679N	PARTICIPANT	\N	PRESENT	0
811947	810306	14251Q	PARTICIPANT	\N	PRESENT	0
811948	810306	14111D	PARTICIPANT	\N	PRESENT	0
811949	810306	21095P	PARTICIPANT	\N	PRESENT	0
811950	810306	21065H	PARTICIPANT	\N	PRESENT	0
811951	810306	21070E	PARTICIPANT	\N	PRESENT	0
811952	810306	21076L	PARTICIPANT	\N	PRESENT	0
811953	810306	19631V	PARTICIPANT	\N	PRESENT	0
811954	810306	19705W	PARTICIPANT	\N	PRESENT	0
811955	810306	86034E	PARTICIPANT	\N	PRESENT	0
811956	810306	04092N	PARTICIPANT	\N	PRESENT	0
811957	810306	20062A	PARTICIPANT	\N	PRESENT	0
811958	810306	11048N	PARTICIPANT	\N	PRESENT	0
811959	810306	95041E	PARTICIPANT	\N	PRESENT	0
811960	810306	20114U	PARTICIPANT	\N	PRESENT	0
811961	810306	20080C	PARTICIPANT	\N	PRESENT	0
811962	810306	21045D	PARTICIPANT	\N	PRESENT	0
811963	810306	08010L	PARTICIPANT	\N	PRESENT	0
811964	810306	20060X	PARTICIPANT	\N	PRESENT	0
811965	810306	12028B	PARTICIPANT	\N	PRESENT	0
811966	810306	19533U	PARTICIPANT	\N	PRESENT	0
811967	810306	20264J	PARTICIPANT	\N	PRESENT	0
797944	797714	14053L	PARTICIPANT	\N	PRESENT	0
797945	797714	21044C	PARTICIPANT	\N	PRESENT	0
797946	797714	20036X	PARTICIPANT	\N	PRESENT	0
797947	797714	20074E	PARTICIPANT	\N	PRESENT	0
797948	797714	18207D	PARTICIPANT	\N	PRESENT	0
797949	797714	20108W	PARTICIPANT	\N	PRESENT	0
797950	797714	21076L	PARTICIPANT	\N	PRESENT	0
797951	797714	21095P	PARTICIPANT	\N	PRESENT	0
797952	797714	20022R	PARTICIPANT	\N	PRESENT	0
797953	797714	04047H	PRESIDENT	0	PRESENT	0
797954	797714	14259Y	PARTICIPANT	\N	PRESENT	0
797955	797714	19447X	PARTICIPANT	\N	PRESENT	0
797956	797714	19585H	PARTICIPANT	\N	EXCUSE	0
797957	797714	21043B	PARTICIPANT	\N	PRESENT	0
797958	797714	14089Y	PARTICIPANT	\N	PRESENT	0
797959	797714	18231D	PARTICIPANT	\N	PRESENT	0
797960	797714	11072N	PARTICIPANT	\N	PRESENT	0
797961	797714	14111D	PARTICIPANT	\N	PRESENT	0
797962	797714	11085T	PARTICIPANT	\N	PRESENT	0
797963	797714	11056N	PARTICIPANT	\N	PRESENT	0
798013	797964	86034E	PARTICIPANT	\N	PRESENT	0
798020	797719	14111D	PARTICIPANT	\N	PRESENT	0
798021	797719	14189C	PARTICIPANT	\N	PRESENT	0
798022	797719	20074E	PARTICIPANT	\N	PRESENT	0
798023	797719	10015M	PARTICIPANT	\N	PRESENT	0
798024	797719	21076L	PARTICIPANT	\N	PRESENT	0
798025	797719	21057H	PARTICIPANT	\N	PRESENT	0
798026	797719	04047H	PRESIDENT	0	PRESENT	0
798027	797719	19447X	PARTICIPANT	\N	PRESENT	0
798028	797719	21044C	PARTICIPANT	\N	PRESENT	0
798029	797719	20110Q	PARTICIPANT	\N	PRESENT	0
798030	797719	14147R	PARTICIPANT	\N	PRESENT	0
798031	797719	19111A	PARTICIPANT	\N	PRESENT	0
798032	797719	14069U	PARTICIPANT	\N	PRESENT	0
798033	797719	14215L	PARTICIPANT	\N	PRESENT	0
798034	797719	20022R	PARTICIPANT	\N	PRESENT	0
798035	797719	21095P	PARTICIPANT	\N	PRESENT	0
798036	797964	20140W	PARTICIPANT	\N	PRESENT	0
798037	797964	19709B	PARTICIPANT	\N	PRESENT	0
798038	797964	21039F	PARTICIPANT	\N	PRESENT	0
798039	797964	21055F	PARTICIPANT	\N	PRESENT	0
798040	797964	14191V	PARTICIPANT	\N	PRESENT	0
798041	797964	21057H	PARTICIPANT	\N	PRESENT	0
798042	797964	21056G	PARTICIPANT	\N	PRESENT	0
798043	797964	20102Q	PARTICIPANT	\N	PRESENT	0
798044	797964	20052X	PARTICIPANT	\N	PRESENT	0
798045	797964	04042C	PARTICIPANT	\N	PRESENT	0
798046	797964	21044C	PARTICIPANT	\N	PRESENT	0
798047	797964	19399H	PARTICIPANT	\N	PRESENT	0
798048	797964	20024T	PARTICIPANT	\N	PRESENT	0
798050	797964	20032T	PARTICIPANT	\N	PRESENT	0
798051	797964	20090E	PARTICIPANT	\N	PRESENT	0
798052	797964	20098N	PARTICIPANT	\N	PRESENT	0
798053	797964	11090Q	PARTICIPANT	\N	PRESENT	0
798054	797964	21031W	PARTICIPANT	\N	PRESENT	0
798055	797964	21040X	PARTICIPANT	\N	PRESENT	0
798057	797964	20100N	PARTICIPANT	\N	PRESENT	0
798058	797964	18083K	PARTICIPANT	\N	PRESENT	0
798059	797964	19826F	PARTICIPANT	\N	PRESENT	0
798060	797964	99004R	PARTICIPANT	\N	PRESENT	0
798061	797964	14215L	PARTICIPANT	\N	PRESENT	0
798062	797964	21062E	PARTICIPANT	\N	PRESENT	0
798063	797964	21052C	PARTICIPANT	\N	PRESENT	0
798064	797964	19367Y	PARTICIPANT	\N	PRESENT	0
798065	797964	21058J	PARTICIPANT	\N	PRESENT	0
798066	797964	14038Y	PARTICIPANT	\N	PRESENT	0
798067	797964	19631V	PARTICIPANT	\N	PRESENT	0
798068	797964	14257W	PARTICIPANT	\N	PRESENT	0
798069	797964	04045F	PARTICIPANT	\N	PRESENT	0
798070	797964	14211G	PARTICIPANT	\N	PRESENT	0
798071	797964	14195A	PARTICIPANT	\N	PRESENT	0
798072	797964	20120S	PARTICIPANT	\N	PRESENT	0
798073	797964	20148F	PARTICIPANT	\N	PRESENT	0
798074	797964	20046A	PARTICIPANT	\N	PRESENT	0
798075	797964	21061D	PARTICIPANT	\N	PRESENT	0
798076	797964	21091K	PARTICIPANT	\N	PRESENT	0
798077	797964	14037X	PARTICIPANT	\N	PRESENT	0
798078	797964	08061X	PARTICIPANT	\N	PRESENT	0
798079	797964	20088L	PARTICIPANT	\N	PRESENT	0
798080	797964	21045D	PARTICIPANT	\N	PRESENT	0
798081	797964	19619A	PARTICIPANT	\N	PRESENT	0
798082	797964	15197G	PARTICIPANT	\N	PRESENT	0
798083	797964	19691J	PARTICIPANT	\N	PRESENT	0
798084	797964	20084G	PARTICIPANT	\N	PRESENT	0
798085	797964	19683J	PARTICIPANT	\N	PRESENT	0
798086	797964	11074Q	PARTICIPANT	\N	PRESENT	0
798087	797964	20064C	PARTICIPANT	\N	PRESENT	0
798088	797964	14151M	PARTICIPANT	\N	PRESENT	0
798089	797964	14179A	PARTICIPANT	\N	PRESENT	0
798090	797964	19111A	PARTICIPANT	\N	PRESENT	0
798091	797964	19745F	PARTICIPANT	\N	PRESENT	0
798092	797964	19569H	PARTICIPANT	\N	PRESENT	0
798093	797964	14189C	PARTICIPANT	\N	PRESENT	0
798094	797964	19479G	PARTICIPANT	\N	PRESENT	0
798095	797964	14073Q	PARTICIPANT	\N	PRESENT	0
798101	797964	19545Y	PARTICIPANT	\N	PRESENT	0
798102	797964	19693L	PARTICIPANT	\N	PRESENT	0
798112	797964	20122U	PARTICIPANT	\N	PRESENT	0
798113	797964	20116W	PARTICIPANT	\N	PRESENT	0
798114	797964	14207L	PARTICIPANT	\N	PRESENT	0
798115	797964	19629C	PARTICIPANT	\N	PRESENT	0
798116	797964	20132W	PARTICIPANT	\N	PRESENT	0
798117	797964	11043H	PARTICIPANT	\N	PRESENT	0
798118	797964	21066J	PARTICIPANT	\N	PRESENT	0
798119	797964	98022P	PARTICIPANT	\N	PRESENT	0
798120	797964	19553Y	PARTICIPANT	\N	PRESENT	0
798121	797964	20072C	PARTICIPANT	\N	PRESENT	0
798122	797964	14107H	PARTICIPANT	\N	PRESENT	0
798123	797964	19760E	PARTICIPANT	\N	PRESENT	0
798124	797964	21084L	PARTICIPANT	\N	PRESENT	0
798125	797964	14147R	PARTICIPANT	\N	PRESENT	0
798126	797964	19758L	PARTICIPANT	\N	PRESENT	0
798127	797964	11056N	PARTICIPANT	\N	PRESENT	0
798128	797964	21088Q	PARTICIPANT	\N	PRESENT	0
798129	797964	19705W	PARTICIPANT	\N	PRESENT	0
798130	797964	21030V	PARTICIPANT	\N	PRESENT	0
798131	797964	19687N	PARTICIPANT	\N	PRESENT	0
798132	797964	11040E	PARTICIPANT	\N	PRESENT	0
798133	797964	19707Y	PARTICIPANT	\N	PRESENT	0
798134	797964	19593H	PARTICIPANT	\N	PRESENT	0
798135	797964	21049H	PARTICIPANT	\N	PRESENT	0
798136	797964	20126Y	PARTICIPANT	\N	PRESENT	0
798137	797964	21048G	PARTICIPANT	\N	PRESENT	0
798138	797964	20110Q	PARTICIPANT	\N	PRESENT	0
798139	797964	20134Y	PARTICIPANT	\N	PRESENT	0
798140	797964	19347U	PARTICIPANT	\N	PRESENT	0
798141	797964	21092L	PARTICIPANT	\N	PRESENT	0
798142	797964	20180F	PARTICIPANT	\N	PRESENT	0
798143	797964	21093M	PARTICIPANT	\N	PRESENT	0
798144	797964	20142Y	PARTICIPANT	\N	PRESENT	0
798145	797964	21073H	PARTICIPANT	\N	PRESENT	0
798146	797964	20092G	PARTICIPANT	\N	PRESENT	0
798147	797964	21079P	PARTICIPANT	\N	PRESENT	0
798148	797964	20074E	PARTICIPANT	\N	PRESENT	0
798149	797964	20266L	PARTICIPANT	\N	PRESENT	0
798150	797964	21043B	PARTICIPANT	\N	PRESENT	0
798151	797964	19782L	PARTICIPANT	\N	PRESENT	0
798152	797964	20076G	PARTICIPANT	\N	PRESENT	0
798153	797964	14249W	PARTICIPANT	\N	PRESENT	0
798154	797964	20106U	PARTICIPANT	\N	PRESENT	0
798155	797964	04047H	PARTICIPANT	\N	PRESENT	0
798156	797964	20128B	PARTICIPANT	\N	PRESENT	0
798157	797964	08010L	PARTICIPANT	\N	PRESENT	0
798158	797964	05008E	PARTICIPANT	\N	PRESENT	0
798159	797964	11072N	PARTICIPANT	\N	PRESENT	0
798160	797964	08073C	PARTICIPANT	\N	PRESENT	0
798161	797964	20062A	PARTICIPANT	\N	PRESENT	0
798162	797964	19349W	PARTICIPANT	\N	PRESENT	0
798163	797964	20150Y	PARTICIPANT	\N	PRESENT	0
798164	797964	19621T	PARTICIPANT	\N	PRESENT	0
798165	797964	21074J	PARTICIPANT	\N	PRESENT	0
798166	797964	21085M	PARTICIPANT	\N	PRESENT	0
811553	811550	08010L	PARTICIPANT	\N	PRESENT	0
811599	810576	19551W	PARTICIPANT	\N	EXCUSE	0
811732	810358	14331P	PRESIDENT	0	PRESENT	0
811733	810358	14189C	PARTICIPANT	\N	PRESENT	0
811734	810358	18395Y	PARTICIPANT	\N	PRESENT	0
811735	810358	14033T	PARTICIPANT	\N	PRESENT	0
811736	810358	19683J	PARTICIPANT	\N	PRESENT	0
811737	810358	19709B	PARTICIPANT	\N	PRESENT	0
811738	810358	19711U	PARTICIPANT	\N	PRESENT	0
811739	810358	10015M	PARTICIPANT	\N	PRESENT	0
811740	810358	21054E	PARTICIPANT	\N	PRESENT	0
811742	810358	21082J	PARTICIPANT	\N	PRESENT	0
811743	810358	17737W	PARTICIPANT	\N	PRESENT	0
811744	810358	20094J	PARTICIPANT	\N	PRESENT	0
811745	810358	14133K	PARTICIPANT	\N	PRESENT	0
811746	810358	20286Q	PARTICIPANT	\N	PRESENT	0
811747	810358	18207D	PARTICIPANT	\N	PRESENT	0
811753	811752	11040E	PARTICIPANT	\N	PRESENT	0
811754	811752	21041Y	PARTICIPANT	\N	PRESENT	0
811755	811752	14249W	PARTICIPANT	\N	PRESENT	0
811756	811752	14179A	PARTICIPANT	\N	PRESENT	0
811757	811752	14097Y	PARTICIPANT	\N	PRESENT	0
811758	811752	08034U	PRESIDENT	0	PRESENT	0
811759	811752	14059S	PARTICIPANT	\N	PRESENT	0
811761	811752	21073H	PARTICIPANT	\N	PRESENT	0
811763	811752	04070G	PARTICIPANT	\N	PRESENT	0
811766	811752	19745F	PARTICIPANT	\N	PRESENT	0
811767	811752	19669L	PARTICIPANT	\N	PRESENT	0
811768	811752	07004J	PARTICIPANT	\N	EXCUSE	0
811769	811752	19709B	PARTICIPANT	\N	EXCUSE	0
811770	811752	14225N	PARTICIPANT	\N	EXCUSE	0
811771	811752	14133K	PARTICIPANT	\N	EXCUSE	0
811772	811752	20150Y	PARTICIPANT	\N	EXCUSE	0
811775	810358	14026U	PARTICIPANT	\N	PRESENT	0
812063	810779	14225N	PRESIDENT	0	PRESENT	0
812080	812078	11090Q	PARTICIPANT	\N	PRESENT	0
812081	812078	19695N	PARTICIPANT	\N	PRESENT	0
812096	812095	21067K	PARTICIPANT	\N	PRESENT	0
812097	812095	20252E	PARTICIPANT	\N	PRESENT	0
812641	812640	19621T	PARTICIPANT	\N	PRESENT	0
812642	812640	21089R	PARTICIPANT	\N	PRESENT	0
812865	812864	19695N	PARTICIPANT	\N	PRESENT	0
812868	812864	11090Q	PARTICIPANT	\N	PRESENT	0
812988	812981	10015M	PARTICIPANT	\N	PRESENT	0
812990	812981	20028X	PARTICIPANT	\N	PRESENT	0
812993	812981	20106U	PARTICIPANT	\N	PRESENT	0
812994	812981	20132W	PARTICIPANT	\N	PRESENT	0
812996	812981	21090J	PRESIDENT	0	PRESENT	0
812998	812981	17965H	PARTICIPANT	\N	PRESENT	0
813011	807384	19745F	PARTICIPANT	\N	PRESENT	0
813022	810265	19711U	PARTICIPANT	\N	PRESENT	0
813023	810265	20042V	PARTICIPANT	\N	PRESENT	0
813024	810265	20132W	PARTICIPANT	\N	PRESENT	0
813025	810265	19479G	PARTICIPANT	\N	PRESENT	0
813026	810265	21063F	PARTICIPANT	\N	PRESENT	0
813027	810265	19399H	PARTICIPANT	\N	PRESENT	0
813028	810265	21056G	PARTICIPANT	\N	PRESENT	0
813029	810265	21057H	PARTICIPANT	\N	EXCUSE	0
813030	810265	21093M	PARTICIPANT	\N	EXCUSE	0
813031	810265	20082E	PARTICIPANT	\N	EXCUSE	0
813032	810265	20286Q	PARTICIPANT	\N	EXCUSE	0
813034	810265	20066E	PARTICIPANT	\N	EXCUSE	0
813036	810265	20024T	PARTICIPANT	\N	EXCUSE	0
813037	813035	19479G	PARTICIPANT	\N	PRESENT	0
813038	810265	19798U	PARTICIPANT	\N	EXCUSE	0
813039	813035	04047H	PARTICIPANT	\N	PRESENT	0
813040	810265	21041Y	PARTICIPANT	\N	EXCUSE	0
813041	813035	20110Q	PARTICIPANT	\N	PRESENT	0
813042	810265	11070L	PARTICIPANT	\N	EXCUSE	0
813043	810265	20140W	PARTICIPANT	\N	EXCUSE	0
813044	810265	20086J	PARTICIPANT	\N	EXCUSE	0
813045	810265	20050V	PARTICIPANT	\N	EXCUSE	0
813046	810265	21083K	PARTICIPANT	\N	EXCUSE	0
813048	813047	19479G	PARTICIPANT	\N	PRESENT	0
813049	813047	19611R	PARTICIPANT	\N	PRESENT	0
813050	810265	20044X	PARTICIPANT	\N	EXCUSE	0
813052	810281	19575F	PARTICIPANT	\N	PRESENT	0
813053	810281	21059K	PARTICIPANT	\N	PRESENT	0
813057	810281	19533U	PARTICIPANT	\N	PRESENT	0
813058	810281	19723Y	PARTICIPANT	\N	PRESENT	0
813059	810281	19667J	PARTICIPANT	\N	PRESENT	0
813061	810281	20072C	PARTICIPANT	\N	EXCUSE	0
813062	810281	20138D	PARTICIPANT	\N	EXCUSE	0
813063	810281	01058X	PARTICIPANT	\N	EXCUSE	0
813093	813092	14133K	PARTICIPANT	\N	EXCUSE	0
813094	813092	20086J	PARTICIPANT	\N	EXCUSE	0
813095	813092	21041Y	PARTICIPANT	\N	PRESENT	0
813096	813092	14249W	PARTICIPANT	\N	EXCUSE	0
813097	813092	07004J	PARTICIPANT	\N	EXCUSE	0
813099	813092	14179A	PARTICIPANT	\N	PRESENT	0
813100	813092	08034U	PRESIDENT	0	PRESENT	0
813101	813092	19745F	PARTICIPANT	\N	PRESENT	0
813102	813092	14225N	PARTICIPANT	\N	EXCUSE	0
813103	813092	10015M	PARTICIPANT	\N	PRESENT	0
813104	813092	14229S	PARTICIPANT	\N	PRESENT	0
813105	813092	20150Y	PARTICIPANT	\N	EXCUSE	0
813106	813092	19669L	PARTICIPANT	\N	PRESENT	0
813108	813107	14133K	PARTICIPANT	\N	EXCUSE	0
813109	813107	20086J	PARTICIPANT	\N	EXCUSE	0
813110	813107	21041Y	PARTICIPANT	\N	PRESENT	0
813111	813107	14249W	PARTICIPANT	\N	EXCUSE	0
813112	813107	07004J	PARTICIPANT	\N	EXCUSE	0
813113	813107	19709B	PARTICIPANT	\N	EXCUSE	0
813114	813107	08034U	PRESIDENT	0	PRESENT	0
813115	813107	19745F	PARTICIPANT	\N	PRESENT	0
813117	813116	14189C	PARTICIPANT	\N	PRESENT	0
813118	813107	14225N	PARTICIPANT	\N	EXCUSE	0
813119	813116	20110Q	PARTICIPANT	\N	PRESENT	0
813120	813116	17737W	PARTICIPANT	\N	PRESENT	0
813121	813116	19621T	PARTICIPANT	\N	PRESENT	0
813122	813107	10015M	PARTICIPANT	\N	PRESENT	0
813123	813107	14229S	PARTICIPANT	\N	PRESENT	0
813124	813116	21083K	PARTICIPANT	\N	PRESENT	0
813125	813116	19545Y	PARTICIPANT	\N	PRESENT	0
813126	813107	20150Y	PARTICIPANT	\N	EXCUSE	0
813127	813116	14195A	PARTICIPANT	\N	PRESENT	0
813128	813107	19669L	PARTICIPANT	\N	PRESENT	0
813129	813116	14259Y	PARTICIPANT	\N	PRESENT	0
813130	813116	20248J	PARTICIPANT	\N	PRESENT	0
813131	813116	19251M	PARTICIPANT	\N	PRESENT	0
813132	813116	17023S	PARTICIPANT	\N	PRESENT	0
813133	813116	21085M	PARTICIPANT	\N	PRESENT	0
813134	813116	20056C	PARTICIPANT	\N	PRESENT	0
813135	813116	20026V	PARTICIPANT	\N	PRESENT	0
813136	813116	20046A	PARTICIPANT	\N	PRESENT	0
813137	813116	11045K	PARTICIPANT	\N	PRESENT	0
813138	813116	14229S	PARTICIPANT	\N	PRESENT	0
813139	813116	19349W	PARTICIPANT	\N	PRESENT	0
813140	813116	19593H	PARTICIPANT	\N	PRESENT	0
813141	813116	04070G	PARTICIPANT	\N	PRESENT	0
813142	813116	21080G	PARTICIPANT	\N	PRESENT	0
813150	812981	04092N	PARTICIPANT	\N	EXCUSE	0
813152	812981	21094N	PARTICIPANT	\N	EXCUSE	0
813163	813162	19251M	PARTICIPANT	\N	PRESENT	0
813164	813162	17737W	PARTICIPANT	\N	PRESENT	0
813165	813162	19711U	PARTICIPANT	\N	PRESENT	0
813166	812981	21042A	PARTICIPANT	\N	EXCUSE	0
813168	813167	19251M	PARTICIPANT	\N	PRESENT	0
813169	813167	14021P	PARTICIPANT	\N	PRESENT	0
813170	813167	17737W	PARTICIPANT	\N	PRESENT	0
813171	813167	04042C	PARTICIPANT	\N	PRESENT	0
813172	813167	19647E	PARTICIPANT	\N	PRESENT	0
813173	813167	17023S	PARTICIPANT	\N	PRESENT	0
813174	813167	04033B	PARTICIPANT	\N	PRESENT	0
813175	813167	14055N	PARTICIPANT	\N	PRESENT	0
813176	813167	19593H	PARTICIPANT	\N	PRESENT	0
813177	813167	14037X	PARTICIPANT	\N	PRESENT	0
813178	813167	21095P	PARTICIPANT	\N	PRESENT	0
813179	813167	19347U	PARTICIPANT	\N	PRESENT	0
813181	813180	11085T	PARTICIPANT	\N	PRESENT	0
813185	813184	19673G	PARTICIPANT	\N	PRESENT	0
813187	813186	19251M	PARTICIPANT	\N	PRESENT	0
813193	813192	20114U	PARTICIPANT	\N	PRESENT	0
813194	813192	08012N	PARTICIPANT	\N	PRESENT	0
813195	813192	11053K	PARTICIPANT	\N	PRESENT	0
813196	813192	20066E	PARTICIPANT	\N	PRESENT	0
813198	813197	11074Q	PARTICIPANT	\N	PRESENT	0
813199	813197	08045X	PARTICIPANT	\N	PRESENT	0
801252	801251	21039F	PARTICIPANT	\N	PRESENT	0
801253	801251	17965H	PARTICIPANT	\N	PRESENT	0
801265	801263	21039F	PARTICIPANT	\N	PRESENT	0
801266	801263	17965H	PARTICIPANT	\N	PRESENT	0
801267	801263	20130U	PARTICIPANT	\N	PRESENT	0
803898	801146	17737W	PARTICIPANT	\N	PRESENT	0
803900	801146	20090E	PARTICIPANT	\N	PRESENT	0
803906	801146	18395Y	PARTICIPANT	\N	PRESENT	0
803907	801146	20146D	PARTICIPANT	\N	PRESENT	0
803428	802502	14193X	PRESIDENT	0	PRESENT	0
803940	803933	19667J	PARTICIPANT	\N	PRESENT	0
803942	803933	20138D	PARTICIPANT	\N	PRESENT	0
803431	802502	14211G	PARTICIPANT	\N	EXCUSE	0
803943	803933	21046E	PARTICIPANT	\N	PRESENT	0
803944	803933	20090E	PARTICIPANT	\N	PRESENT	0
806571	803922	21087P	PARTICIPANT	\N	PRESENT	0
803435	802502	20064C	PARTICIPANT	\N	EXCUSE	0
803436	802502	19531S	PARTICIPANT	\N	EXCUSE	0
803437	802502	11027H	PARTICIPANT	\N	EXCUSE	0
803438	802502	14001X	PARTICIPANT	\N	EXCUSE	0
803945	803933	20140W	PARTICIPANT	\N	PRESENT	0
803946	803933	19735D	PARTICIPANT	\N	PRESENT	0
803947	803933	19723Y	PARTICIPANT	\N	PRESENT	0
803948	803933	14223L	PARTICIPANT	\N	PRESENT	0
803949	803933	19798U	PARTICIPANT	\N	PRESENT	0
803950	803933	21064G	PARTICIPANT	\N	PRESENT	0
803951	803933	19713W	PARTICIPANT	\N	PRESENT	0
803952	803933	20064C	PARTICIPANT	\N	PRESENT	0
804565	804380	20048C	PARTICIPANT	\N	PRESENT	0
806573	803922	19649G	PARTICIPANT	\N	PRESENT	0
803449	802502	21082J	PARTICIPANT	\N	PRESENT	0
803450	802502	21036C	PARTICIPANT	\N	PRESENT	0
803451	802502	19701S	PARTICIPANT	\N	PRESENT	0
803452	802502	21073H	PARTICIPANT	\N	PRESENT	0
803453	802502	08034U	PARTICIPANT	\N	PRESENT	0
803454	802502	14073Q	PARTICIPANT	\N	PRESENT	0
803455	802502	20042V	PARTICIPANT	\N	PRESENT	0
803456	802502	14026U	PARTICIPANT	\N	PRESENT	0
803457	802502	17737W	PARTICIPANT	\N	PRESENT	0
803458	802502	19709B	PARTICIPANT	\N	PRESENT	0
803459	802502	07033P	PARTICIPANT	\N	PRESENT	0
803460	802502	17023S	PARTICIPANT	\N	PRESENT	0
806546	803922	19533U	PARTICIPANT	\N	PRESENT	0
806547	803922	20026V	PARTICIPANT	\N	PRESENT	0
806572	803922	14281W	PARTICIPANT	\N	PRESENT	0
806574	803922	20018V	PARTICIPANT	\N	PRESENT	0
806550	803922	20102Q	PARTICIPANT	\N	PRESENT	0
806551	803922	19697Q	PARTICIPANT	\N	PRESENT	0
806552	803922	14030Q	PARTICIPANT	\N	PRESENT	0
806575	803922	19301E	PARTICIPANT	\N	PRESENT	0
806554	803922	19621T	PARTICIPANT	\N	PRESENT	0
806555	803922	20034V	PARTICIPANT	\N	PRESENT	0
806556	803922	20032T	PARTICIPANT	\N	PRESENT	0
806557	803922	20132W	PARTICIPANT	\N	PRESENT	0
806558	803922	21058J	PARTICIPANT	\N	PRESENT	0
806559	803922	20142Y	PARTICIPANT	\N	PRESENT	0
803895	801146	14151M	PRESIDENT	0	PRESENT	0
803897	801146	17367Q	PARTICIPANT	\N	PRESENT	0
806576	803922	20038A	PARTICIPANT	\N	PRESENT	0
806561	803922	21077M	PARTICIPANT	\N	PRESENT	0
806562	803922	18395Y	PARTICIPANT	\N	PRESENT	0
806578	803922	14107H	PARTICIPANT	\N	PRESENT	0
806564	803922	21049H	PARTICIPANT	\N	PRESENT	0
806565	803922	14109K	PARTICIPANT	\N	PRESENT	0
806566	803922	20124W	PARTICIPANT	\N	PRESENT	0
806567	803922	21063F	PARTICIPANT	\N	PRESENT	0
806577	803922	14037X	PARTICIPANT	\N	PRESENT	0
806569	803922	21057H	PARTICIPANT	\N	PRESENT	0
806570	803922	21088Q	PARTICIPANT	\N	PRESENT	0
806579	803922	21076L	PARTICIPANT	\N	PRESENT	0
806580	803922	14021P	PARTICIPANT	\N	PRESENT	0
806581	803922	19954N	PARTICIPANT	\N	PRESENT	0
806582	803922	14069U	PARTICIPANT	\N	PRESENT	0
806583	803922	20090E	PARTICIPANT	\N	PRESENT	0
806584	803922	18207D	PARTICIPANT	\N	PRESENT	0
806585	803922	21043B	PARTICIPANT	\N	PRESENT	0
806586	803922	19563B	PARTICIPANT	\N	PRESENT	0
806587	803922	14169X	PARTICIPANT	\N	PRESENT	0
806588	803922	14073Q	PARTICIPANT	\N	PRESENT	0
806589	803922	14189C	PARTICIPANT	\N	PRESENT	0
806590	803922	14219Q	PARTICIPANT	\N	PRESENT	0
806591	803922	19735D	PARTICIPANT	\N	PRESENT	0
806592	803922	21055F	PARTICIPANT	\N	PRESENT	0
806593	803922	18083K	PARTICIPANT	\N	PRESENT	0
806594	803922	19713W	PARTICIPANT	\N	PRESENT	0
806595	803922	21040X	PARTICIPANT	\N	PRESENT	0
806596	803922	19413M	PARTICIPANT	\N	PRESENT	0
806597	803922	19719D	PARTICIPANT	\N	PRESENT	0
806598	803922	21069M	PARTICIPANT	\N	PRESENT	0
806599	803922	21071F	PARTICIPANT	\N	PRESENT	0
806600	803922	20048C	PARTICIPANT	\N	PRESENT	0
806601	803922	20092G	PARTICIPANT	\N	PRESENT	0
806683	803923	20034V	PARTICIPANT	\N	PRESENT	0
806684	803923	21055F	PARTICIPANT	\N	PRESENT	0
806685	803923	14042U	PARTICIPANT	\N	PRESENT	0
806687	803923	21087P	PARTICIPANT	\N	PRESENT	0
806688	803923	21050A	PARTICIPANT	\N	PRESENT	0
806689	803923	19673G	PARTICIPANT	\N	PRESENT	0
806690	803923	14231L	PARTICIPANT	\N	PRESENT	0
806691	803923	19489J	PARTICIPANT	\N	PRESENT	0
806692	803923	21051B	PARTICIPANT	\N	PRESENT	0
806693	803923	20110Q	PARTICIPANT	\N	PRESENT	0
806694	803923	14053L	PARTICIPANT	\N	PRESENT	0
806695	803923	19798U	PARTICIPANT	\N	PRESENT	0
806696	803923	21031W	PARTICIPANT	\N	PRESENT	0
806697	803923	21079P	PARTICIPANT	\N	PRESENT	0
806698	803923	20054A	PARTICIPANT	\N	PRESENT	0
806699	803923	19347U	PARTICIPANT	\N	PRESENT	0
806700	803923	20062A	PARTICIPANT	\N	PRESENT	0
806701	803923	11065P	PARTICIPANT	\N	PRESENT	0
806702	803923	14215L	PARTICIPANT	\N	PRESENT	0
806703	803923	19768N	PARTICIPANT	\N	PRESENT	0
806704	803923	11056N	PARTICIPANT	\N	PRESENT	0
806705	803923	20102Q	PARTICIPANT	\N	PRESENT	0
806706	803923	20026V	PARTICIPANT	\N	PRESENT	0
806707	803923	19758L	PARTICIPANT	\N	PRESENT	0
806708	803923	21056G	PARTICIPANT	\N	PRESENT	0
806709	803923	21058J	PARTICIPANT	\N	PRESENT	0
806710	803923	19295A	PARTICIPANT	\N	PRESENT	0
806711	803923	21039F	PARTICIPANT	\N	PRESENT	0
806712	803923	14189C	PARTICIPANT	\N	PRESENT	0
806713	803923	21043B	PARTICIPANT	\N	PRESENT	0
806714	803923	21096Q	PARTICIPANT	\N	PRESENT	0
806715	803923	21082J	PARTICIPANT	\N	PRESENT	0
806716	803923	10015M	PARTICIPANT	\N	PRESENT	0
806717	803923	20120S	PARTICIPANT	\N	PRESENT	0
806718	803923	21033Y	PARTICIPANT	\N	PRESENT	0
806719	803923	19760E	PARTICIPANT	\N	PRESENT	0
806720	803923	21086N	PARTICIPANT	\N	PRESENT	0
806721	803923	20090E	PARTICIPANT	\N	PRESENT	0
806672	803923	19301E	PARTICIPANT	\N	PRESENT	0
806682	803923	21053D	PARTICIPANT	\N	PRESENT	0
806722	803923	19335Q	PARTICIPANT	\N	PRESENT	0
806723	803923	21083K	PARTICIPANT	\N	PRESENT	0
806724	803923	19691J	PARTICIPANT	\N	PRESENT	0
806725	803923	14327T	PARTICIPANT	\N	PRESENT	0
806726	803923	20040T	PARTICIPANT	\N	PRESENT	0
806727	803923	19573D	PARTICIPANT	\N	PRESENT	0
806728	803923	20122U	PARTICIPANT	\N	PRESENT	0
806729	803923	11043H	PARTICIPANT	\N	PRESENT	0
806730	803923	19719D	PARTICIPANT	\N	PRESENT	0
806731	803923	18207D	PARTICIPANT	\N	PRESENT	0
806732	803923	21048G	PARTICIPANT	\N	PRESENT	0
806733	803923	11090Q	PARTICIPANT	\N	PRESENT	0
806734	803923	20066E	PARTICIPANT	\N	PRESENT	0
806735	803923	21049H	PARTICIPANT	\N	PRESENT	0
806736	803923	20092G	PARTICIPANT	\N	PRESENT	0
806737	803923	14219Q	PARTICIPANT	\N	PRESENT	0
806738	803923	21032X	PARTICIPANT	\N	PRESENT	0
806739	803923	14083S	PARTICIPANT	\N	PRESENT	0
806740	803923	14195A	PARTICIPANT	\N	PRESENT	0
806741	803923	14069U	PARTICIPANT	\N	PRESENT	0
806742	803923	14147R	PARTICIPANT	\N	PRESENT	0
806747	803923	20142Y	PARTICIPANT	\N	PRESENT	0
806744	803923	21091K	PARTICIPANT	\N	PRESENT	0
806745	803923	21044C	PARTICIPANT	\N	PRESENT	0
806746	803923	19533U	PARTICIPANT	\N	PRESENT	0
806748	803923	20124W	PARTICIPANT	\N	PRESENT	0
806749	803923	19447X	PARTICIPANT	\N	PRESENT	0
806750	803923	04047H	PARTICIPANT	\N	PRESENT	0
806751	803923	18193Q	PARTICIPANT	\N	PRESENT	0
796816	794075	11027H	PARTICIPANT	\N	PRESENT	0
811968	810306	08018U	PARTICIPANT	\N	PRESENT	0
811969	810306	11027H	PARTICIPANT	\N	PRESENT	0
811970	810306	20070A	PARTICIPANT	\N	PRESENT	0
811971	810306	18395Y	PARTICIPANT	\N	PRESENT	0
811972	810306	21067K	PARTICIPANT	\N	PRESENT	0
811973	810306	14217N	PARTICIPANT	\N	PRESENT	0
811974	810306	19251M	PARTICIPANT	\N	PRESENT	0
811975	810306	11074Q	PARTICIPANT	\N	PRESENT	0
811976	810306	21062E	PARTICIPANT	\N	PRESENT	0
811977	810306	19647E	PARTICIPANT	\N	PRESENT	0
811978	810306	08045X	PARTICIPANT	\N	PRESENT	0
811979	810306	19725B	PARTICIPANT	\N	PRESENT	0
811980	810306	19531S	PARTICIPANT	\N	PRESENT	0
811981	810306	19683J	PARTICIPANT	\N	PRESENT	0
811982	810306	14097Y	PARTICIPANT	\N	PRESENT	0
811983	810306	14021P	PARTICIPANT	\N	PRESENT	0
811984	810306	19489J	PARTICIPANT	\N	PRESENT	0
811985	810306	18207D	PARTICIPANT	\N	PRESENT	0
811986	810306	08012N	PARTICIPANT	\N	PRESENT	0
811987	810306	21050A	PARTICIPANT	\N	PRESENT	0
811988	810306	14001X	PARTICIPANT	\N	PRESENT	0
811989	810306	20018V	PARTICIPANT	\N	PRESENT	0
811990	810306	14257W	PARTICIPANT	\N	PRESENT	0
811991	810306	18231D	PARTICIPANT	\N	PRESENT	0
811992	810306	08011M	PARTICIPANT	\N	PRESENT	0
811993	810306	20030R	PARTICIPANT	\N	PRESENT	0
811994	810306	20120S	PARTICIPANT	\N	PRESENT	0
811995	810306	21051B	PARTICIPANT	\N	PRESENT	0
811996	810306	08060W	PARTICIPANT	\N	PRESENT	0
811997	810306	17965H	PARTICIPANT	\N	PRESENT	0
811998	810306	14225N	PARTICIPANT	\N	PRESENT	0
811999	810306	20082E	PARTICIPANT	\N	PRESENT	0
812000	810306	05012A	PARTICIPANT	\N	PRESENT	0
812001	810306	20084G	PARTICIPANT	\N	PRESENT	0
812002	810306	19669L	PARTICIPANT	\N	PRESENT	0
812003	810306	19413M	PARTICIPANT	\N	PRESENT	0
812004	810306	20064C	PARTICIPANT	\N	PRESENT	0
812005	810306	21031W	PARTICIPANT	\N	PRESENT	0
812006	810306	21082J	PARTICIPANT	\N	PRESENT	0
812007	810306	21077M	PARTICIPANT	\N	PRESENT	0
812008	810306	20138D	PARTICIPANT	\N	PRESENT	0
812009	810306	21042A	PARTICIPANT	\N	PRESENT	0
812010	810306	14189C	PARTICIPANT	\N	PRESENT	0
812011	810306	14030Q	PARTICIPANT	\N	PRESENT	0
812012	810306	20042V	PARTICIPANT	\N	PRESENT	0
812013	810306	14089Y	PARTICIPANT	\N	PRESENT	0
812014	810306	14255U	PARTICIPANT	\N	PRESENT	0
812015	810306	21083K	PARTICIPANT	\N	PRESENT	0
812016	810306	14083S	PARTICIPANT	\N	PRESENT	0
812017	810306	11053K	PARTICIPANT	\N	PRESENT	0
812018	810306	20144B	PARTICIPANT	\N	PRESENT	0
812019	810306	11115U	PARTICIPANT	\N	PRESENT	0
812020	810306	11070L	PARTICIPANT	\N	PRESENT	0
812021	810306	14327T	PARTICIPANT	\N	PRESENT	0
812022	810306	17229F	PARTICIPANT	\N	PRESENT	0
812023	810306	15197G	PARTICIPANT	\N	PRESENT	0
812024	810306	14042U	PARTICIPANT	\N	PRESENT	0
812025	810306	20040T	PARTICIPANT	\N	PRESENT	0
812026	810306	21086N	PARTICIPANT	\N	PRESENT	0
812027	810306	19111A	PARTICIPANT	\N	PRESENT	0
812028	810306	17023S	PARTICIPANT	\N	PRESENT	0
812029	810306	20286Q	PARTICIPANT	\N	PRESENT	0
812030	810306	19691J	PARTICIPANT	\N	PRESENT	0
812031	810306	14179A	PARTICIPANT	\N	PRESENT	0
812032	810306	19685L	PARTICIPANT	\N	PRESENT	0
812033	810306	20048C	PARTICIPANT	\N	PRESENT	0
812034	810306	14073Q	PARTICIPANT	\N	PRESENT	0
812035	810306	20066E	PARTICIPANT	\N	PRESENT	0
812036	810306	19735D	PARTICIPANT	\N	PRESENT	0
812037	810306	19611R	PARTICIPANT	\N	PRESENT	0
812038	810306	19699S	PARTICIPANT	\N	PRESENT	0
812042	810306	11085T	PARTICIPANT	\N	PRESENT	0
812040	810306	14205J	PARTICIPANT	\N	PRESENT	0
812041	810306	14219Q	PARTICIPANT	\N	PRESENT	0
812043	810306	19826F	PARTICIPANT	\N	PRESENT	0
812044	810306	19563B	PARTICIPANT	\N	PRESENT	0
812045	810306	19335Q	PARTICIPANT	\N	PRESENT	0
812046	810306	04070G	PARTICIPANT	\N	PRESENT	0
812047	810306	20098N	PARTICIPANT	\N	PRESENT	0
812048	810306	20036X	PARTICIPANT	\N	PRESENT	0
812049	810306	19745F	PARTICIPANT	\N	PRESENT	0
812050	810306	21053D	PARTICIPANT	\N	PRESENT	0
812051	810306	21038E	PARTICIPANT	\N	PRESENT	0
812052	810306	21064G	PARTICIPANT	\N	PRESENT	0
812053	810306	19619A	PARTICIPANT	\N	PRESENT	0
812054	810306	19713W	PARTICIPANT	\N	PRESENT	0
812055	810306	19479G	PARTICIPANT	\N	PRESENT	0
812056	810306	19695N	PARTICIPANT	\N	PRESENT	0
812057	810306	21088Q	PARTICIPANT	\N	PRESENT	0
812058	810306	11110B	PARTICIPANT	\N	PRESENT	0
812059	810306	20094J	PARTICIPANT	\N	PRESENT	0
812060	810306	17779H	PARTICIPANT	\N	PRESENT	0
812061	810306	14221J	PARTICIPANT	\N	PRESENT	0
812062	810306	19749K	PARTICIPANT	\N	PRESENT	0
812064	810306	14123H	PARTICIPANT	\N	PRESENT	0
812065	810306	21075K	PARTICIPANT	\N	PRESENT	0
812075	810306	19057M	PARTICIPANT	\N	PRESENT	0
812067	810306	21060C	PARTICIPANT	\N	PRESENT	0
812073	810306	14133K	PARTICIPANT	\N	PRESENT	0
812076	810306	08073C	PARTICIPANT	\N	PRESENT	0
812079	810306	14169X	PARTICIPANT	\N	PRESENT	0
812082	810306	20096L	PARTICIPANT	\N	PRESENT	0
812084	810306	08009T	PARTICIPANT	\N	PRESENT	0
812098	811723	19798U	PARTICIPANT	\N	PRESENT	0
812396	810307	14111D	PARTICIPANT	\N	PRESENT	0
812399	810307	21093M	PARTICIPANT	\N	PRESENT	0
812400	810307	20134Y	PARTICIPANT	\N	PRESENT	0
812403	810307	20266L	PARTICIPANT	\N	PRESENT	0
812406	810307	20030R	PARTICIPANT	\N	PRESENT	0
812407	810307	20114U	PARTICIPANT	\N	PRESENT	0
812408	810307	14195A	PARTICIPANT	\N	PRESENT	0
812409	810307	21072G	PARTICIPANT	\N	PRESENT	0
812410	810307	19693L	PARTICIPANT	\N	PRESENT	0
812411	810307	14215L	PARTICIPANT	\N	PRESENT	0
812412	810307	20036X	PARTICIPANT	\N	PRESENT	0
812413	810307	14331P	PARTICIPANT	\N	PRESENT	0
812414	810307	19691J	PARTICIPANT	\N	PRESENT	0
812415	810307	19749K	PARTICIPANT	\N	PRESENT	0
812416	810307	20098N	PARTICIPANT	\N	PRESENT	0
812417	810307	20128B	PARTICIPANT	\N	PRESENT	0
812418	810307	14069U	PARTICIPANT	\N	PRESENT	0
812419	810307	04045F	PARTICIPANT	\N	PRESENT	0
812420	810307	20124W	PARTICIPANT	\N	PRESENT	0
812421	810307	01058X	PARTICIPANT	\N	PRESENT	0
812422	810307	21036C	PARTICIPANT	\N	PRESENT	0
812423	810307	20038A	PARTICIPANT	\N	PRESENT	0
812424	810307	11072N	PARTICIPANT	\N	PRESENT	0
812425	810307	21066J	PARTICIPANT	\N	PRESENT	0
812426	810307	18083K	PARTICIPANT	\N	PRESENT	0
812428	810307	19687N	PARTICIPANT	\N	PRESENT	0
812429	810307	21055F	PARTICIPANT	\N	PRESENT	0
812430	810307	19745F	PARTICIPANT	\N	PRESENT	0
812431	810307	19713W	PARTICIPANT	\N	PRESENT	0
812432	810307	21053D	PARTICIPANT	\N	PRESENT	0
812433	810307	14231L	PARTICIPANT	\N	PRESENT	0
812434	810307	14191V	PARTICIPANT	\N	PRESENT	0
812453	810307	14030Q	PARTICIPANT	\N	PRESENT	0
812454	810307	21040X	PARTICIPANT	\N	PRESENT	0
812455	810307	14207L	PARTICIPANT	\N	PRESENT	0
812456	810307	19447X	PARTICIPANT	\N	PRESENT	0
812457	810307	19413M	PARTICIPANT	\N	PRESENT	0
812458	810307	19251M	PARTICIPANT	\N	PRESENT	0
812459	810307	11045K	PARTICIPANT	\N	PRESENT	0
812462	810307	08061X	PARTICIPANT	\N	PRESENT	0
812463	810307	19111A	PARTICIPANT	\N	PRESENT	0
812467	810307	14121F	PARTICIPANT	\N	PRESENT	0
812468	810307	21071F	PARTICIPANT	\N	PRESENT	0
812469	810307	11065P	PARTICIPANT	\N	PRESENT	0
812470	810307	14189C	PARTICIPANT	\N	PRESENT	0
812474	810307	14073Q	PARTICIPANT	\N	PRESENT	0
812475	810307	04047H	PARTICIPANT	\N	PRESENT	0
812476	810307	19563B	PARTICIPANT	\N	PRESENT	0
812477	810307	20100N	PARTICIPANT	\N	PRESENT	0
812479	810307	20054A	PARTICIPANT	\N	PRESENT	0
812480	810307	21043B	PARTICIPANT	\N	PRESENT	0
812481	810307	21049H	PARTICIPANT	\N	PRESENT	0
812483	810307	20090E	PARTICIPANT	\N	PRESENT	0
812485	810307	19573D	PARTICIPANT	\N	PRESENT	0
812488	810307	14147R	PARTICIPANT	\N	PRESENT	0
812489	810307	19768N	PARTICIPANT	\N	PRESENT	0
797787	797786	21037D	PARTICIPANT	\N	PRESENT	0
797788	797786	19565D	PARTICIPANT	\N	PRESENT	0
797789	797786	14151M	PARTICIPANT	\N	PRESENT	0
798167	797964	19703U	PARTICIPANT	\N	PRESENT	0
798168	797964	20094J	PARTICIPANT	\N	PRESENT	0
798169	797964	20114U	PARTICIPANT	\N	PRESENT	0
798170	797964	20080C	PARTICIPANT	\N	PRESENT	0
798171	797964	20060X	PARTICIPANT	\N	PRESENT	0
798172	797964	14026U	PARTICIPANT	\N	PRESENT	0
798173	797964	12028B	PARTICIPANT	\N	PRESENT	0
798174	797964	20264J	PARTICIPANT	\N	PRESENT	0
798175	797964	14133K	PARTICIPANT	\N	PRESENT	0
798176	797964	18395Y	PARTICIPANT	\N	PRESENT	0
798177	797964	04092N	PARTICIPANT	\N	PRESENT	0
798178	797964	21067K	PARTICIPANT	\N	PRESENT	0
798179	797964	19251M	PARTICIPANT	\N	PRESENT	0
798180	797964	14123H	PARTICIPANT	\N	PRESENT	0
798181	797964	11110B	PARTICIPANT	\N	PRESENT	0
798182	797964	20078J	PARTICIPANT	\N	PRESENT	0
798183	797964	19647E	PARTICIPANT	\N	PRESENT	0
798184	797964	14281W	PARTICIPANT	\N	PRESENT	0
798185	797964	19820Y	PARTICIPANT	\N	PRESENT	0
798186	797964	14259Y	PARTICIPANT	\N	PRESENT	0
798187	797964	19551W	PARTICIPANT	\N	PRESENT	0
798188	797964	21080G	PARTICIPANT	\N	PRESENT	0
798189	797964	14121F	PARTICIPANT	\N	PRESENT	0
798190	797964	19573D	PARTICIPANT	\N	PRESENT	0
798191	797964	14021P	PARTICIPANT	\N	PRESENT	0
798192	797964	19489J	PARTICIPANT	\N	PRESENT	0
798193	797964	14169X	PARTICIPANT	\N	PRESENT	0
798194	797964	19649G	PARTICIPANT	\N	PRESENT	0
798195	797964	10015M	PARTICIPANT	\N	PRESENT	0
798196	797964	18193Q	PARTICIPANT	\N	PRESENT	0
798197	797964	18207D	PARTICIPANT	\N	PRESENT	0
798198	797964	08012N	PARTICIPANT	\N	PRESENT	0
798199	797964	17779H	PARTICIPANT	\N	PRESENT	0
798200	797964	12016W	PARTICIPANT	\N	PRESENT	0
798201	797964	14223L	PARTICIPANT	\N	PRESENT	0
798202	797964	14001X	PARTICIPANT	\N	PRESENT	0
798203	797964	08028W	PARTICIPANT	\N	PRESENT	0
798204	797964	20028X	PARTICIPANT	\N	PRESENT	0
798205	797964	04033B	PARTICIPANT	\N	PRESENT	0
798206	797964	19679N	PARTICIPANT	\N	PRESENT	0
798207	797964	20018V	PARTICIPANT	\N	PRESENT	0
798208	797964	18231D	PARTICIPANT	\N	PRESENT	0
798209	797964	21060C	PARTICIPANT	\N	PRESENT	0
798210	797964	20030R	PARTICIPANT	\N	PRESENT	0
798211	797964	17965H	PARTICIPANT	\N	PRESENT	0
798212	797964	19701S	PARTICIPANT	\N	PRESENT	0
798213	797964	20082E	PARTICIPANT	\N	PRESENT	0
798214	797964	14071N	PARTICIPANT	\N	PRESENT	0
798215	797964	14229S	PARTICIPANT	\N	PRESENT	0
798216	797964	11045K	PARTICIPANT	\N	PRESENT	0
798217	797964	21059K	PARTICIPANT	\N	PRESENT	0
798218	797964	21072G	PARTICIPANT	\N	PRESENT	0
798219	797964	19413M	PARTICIPANT	\N	PRESENT	0
798220	797964	20044X	PARTICIPANT	\N	PRESENT	0
798221	797964	21051B	PARTICIPANT	\N	PRESENT	0
798222	797964	21082J	PARTICIPANT	\N	PRESENT	0
798223	797964	21077M	PARTICIPANT	\N	PRESENT	0
798224	797964	21042A	PARTICIPANT	\N	PRESENT	0
798225	797964	19673G	PARTICIPANT	\N	PRESENT	0
798226	797964	14030Q	PARTICIPANT	\N	PRESENT	0
798227	797964	21050A	PARTICIPANT	\N	PRESENT	0
798228	797964	20042V	PARTICIPANT	\N	PRESENT	0
798229	797964	14031R	PARTICIPANT	\N	PRESENT	0
798230	797964	14089Y	PARTICIPANT	\N	PRESENT	0
798231	797964	21083K	PARTICIPANT	\N	PRESENT	0
798232	797964	19667J	PARTICIPANT	\N	PRESENT	0
798233	797964	14083S	PARTICIPANT	\N	PRESENT	0
798234	797964	11053K	PARTICIPANT	\N	PRESENT	0
798235	797964	19421M	PARTICIPANT	\N	PRESENT	0
798236	797964	19721W	PARTICIPANT	\N	PRESENT	0
798237	797964	20144B	PARTICIPANT	\N	PRESENT	0
798238	797964	14267Y	PARTICIPANT	\N	PRESENT	0
798239	797964	11115U	PARTICIPANT	\N	PRESENT	0
798240	797964	14331P	PARTICIPANT	\N	PRESENT	0
798241	797964	11070L	PARTICIPANT	\N	PRESENT	0
798242	797964	14327T	PARTICIPANT	\N	PRESENT	0
798243	797964	17229F	PARTICIPANT	\N	PRESENT	0
798244	797964	20248J	PARTICIPANT	\N	PRESENT	0
798245	797964	19533U	PARTICIPANT	\N	PRESENT	0
798246	797964	14042U	PARTICIPANT	\N	PRESENT	0
798247	797964	14069U	PARTICIPANT	\N	PRESENT	0
798248	797964	20040T	PARTICIPANT	\N	PRESENT	0
798249	797964	21086N	PARTICIPANT	\N	PRESENT	0
798250	797964	19798U	PARTICIPANT	\N	PRESENT	0
798251	797964	17023S	PARTICIPANT	\N	PRESENT	0
798252	797964	20286Q	PARTICIPANT	\N	PRESENT	0
798253	797964	14231L	PARTICIPANT	\N	PRESENT	0
798254	797964	20252E	PARTICIPANT	\N	PRESENT	0
798255	797964	21095P	PARTICIPANT	\N	PRESENT	0
798256	797964	20066E	PARTICIPANT	\N	PRESENT	0
798257	797964	19611R	PARTICIPANT	\N	PRESENT	0
798258	797964	14217N	PARTICIPANT	\N	PRESENT	0
798259	797964	14205J	PARTICIPANT	\N	PRESENT	0
798260	797964	21090J	PARTICIPANT	\N	PRESENT	0
798261	797964	07033P	PARTICIPANT	\N	PRESENT	0
798262	797964	14219Q	PARTICIPANT	\N	PRESENT	0
798263	797964	11085T	PARTICIPANT	\N	PRESENT	0
798264	797964	20172F	PARTICIPANT	\N	PRESENT	0
798265	797964	20138D	PARTICIPANT	\N	PRESENT	0
798266	797964	19563B	PARTICIPANT	\N	PRESENT	0
798267	797964	08047A	PARTICIPANT	\N	PRESENT	0
798268	797964	21081H	PARTICIPANT	\N	PRESENT	0
798269	797964	21038E	PARTICIPANT	\N	PRESENT	0
798270	797964	20026V	PARTICIPANT	\N	PRESENT	0
798271	797964	21053D	PARTICIPANT	\N	PRESENT	0
798272	797964	21064G	PARTICIPANT	\N	PRESENT	0
798273	797964	19713W	PARTICIPANT	\N	PRESENT	0
798274	797964	01034P	PARTICIPANT	\N	PRESENT	0
798275	797964	20096L	PARTICIPANT	\N	PRESENT	0
798276	797964	19749K	PARTICIPANT	\N	PRESENT	0
798277	797964	21068L	PARTICIPANT	\N	PRESENT	0
798278	797964	21065H	PARTICIPANT	\N	PRESENT	0
798279	797964	19447X	PARTICIPANT	\N	PRESENT	0
798280	797964	21087P	PARTICIPANT	\N	PRESENT	0
798281	797964	19723Y	PARTICIPANT	\N	PRESENT	0
798282	797964	21054E	PARTICIPANT	\N	PRESENT	0
798283	797964	14251Q	PARTICIPANT	\N	PRESENT	0
798284	797964	20034V	PARTICIPANT	\N	PRESENT	0
798285	797964	14111D	PARTICIPANT	\N	PRESENT	0
798286	797964	21047F	PARTICIPANT	\N	PRESENT	0
798287	797964	14221J	PARTICIPANT	\N	PRESENT	0
798288	797964	20050V	PARTICIPANT	\N	PRESENT	0
798289	797964	21070E	PARTICIPANT	\N	PRESENT	0
798290	797964	21076L	PARTICIPANT	\N	PRESENT	0
798291	797964	20038A	PARTICIPANT	\N	PRESENT	0
798292	797964	19669L	PARTICIPANT	\N	PRESENT	0
798293	797964	14033T	PARTICIPANT	\N	PRESENT	0
798294	797964	20056C	PARTICIPANT	\N	PRESENT	0
798295	797964	14213J	PARTICIPANT	\N	PRESENT	0
798296	797964	14357A	PARTICIPANT	\N	PRESENT	0
798297	797964	14329V	PARTICIPANT	\N	PRESENT	0
798298	797964	19383Y	PARTICIPANT	\N	PRESENT	0
798299	797964	20020P	PARTICIPANT	\N	PRESENT	0
798300	797964	20054A	PARTICIPANT	\N	PRESENT	0
798301	797964	08034U	PARTICIPANT	\N	PRESENT	0
798302	797964	20124W	PARTICIPANT	\N	PRESENT	0
798303	797964	14059S	PARTICIPANT	\N	PRESENT	0
798304	797964	19507S	PARTICIPANT	\N	PRESENT	0
798305	797964	19768N	PARTICIPANT	\N	PRESENT	0
798306	797964	20086J	PARTICIPANT	\N	PRESENT	0
798307	797964	07029T	PARTICIPANT	\N	PRESENT	0
798308	797964	08018U	PARTICIPANT	\N	PRESENT	0
798309	797964	17367Q	PARTICIPANT	\N	PRESENT	0
798310	797964	20068G	PARTICIPANT	\N	PRESENT	0
798311	797964	21063F	PARTICIPANT	\N	PRESENT	0
798318	797964	20108W	PARTICIPANT	\N	PRESENT	0
798313	797964	11048N	PARTICIPANT	\N	PRESENT	0
798314	797964	20058E	PARTICIPANT	\N	PRESENT	0
798315	797964	21036C	PARTICIPANT	\N	PRESENT	0
798316	797964	14187A	PARTICIPANT	\N	PRESENT	0
798317	797964	07004J	PARTICIPANT	\N	PRESENT	0
798319	797964	08056B	PARTICIPANT	\N	PRESENT	0
798320	797964	21089R	PARTICIPANT	\N	PRESENT	0
798321	797964	08060W	PARTICIPANT	\N	PRESENT	0
798322	797964	20048C	PARTICIPANT	\N	PRESENT	0
798323	797964	21041Y	PARTICIPANT	\N	PRESENT	0
798324	797964	14225N	PARTICIPANT	\N	PRESENT	0
798325	797964	19575F	PARTICIPANT	\N	PRESENT	0
813200	813197	20120S	PARTICIPANT	\N	PRESENT	0
813201	813197	08015R	PARTICIPANT	\N	PRESENT	0
813202	813197	21079P	PARTICIPANT	\N	PRESENT	0
813208	813207	19701S	PARTICIPANT	\N	PRESENT	0
813209	813207	21092L	PARTICIPANT	\N	PRESENT	0
813210	813207	20100N	PARTICIPANT	\N	PRESENT	0
813211	813207	14083S	PARTICIPANT	\N	PRESENT	0
813213	807342	14195A	PARTICIPANT	\N	PRESENT	0
813214	807342	21094N	PARTICIPANT	\N	PRESENT	0
813215	807342	14217N	PARTICIPANT	\N	PRESENT	0
813216	807374	14217N	PARTICIPANT	\N	PRESENT	0
813218	807374	21094N	PARTICIPANT	\N	PRESENT	0
813222	807375	14217N	PARTICIPANT	\N	PRESENT	0
813223	807375	21094N	PARTICIPANT	\N	PRESENT	0
813224	807376	14195A	PARTICIPANT	\N	PRESENT	0
813225	807376	14217N	PARTICIPANT	\N	PRESENT	0
813226	807376	21094N	PARTICIPANT	\N	PRESENT	0
813228	813227	14217N	PARTICIPANT	\N	PRESENT	0
813229	813227	21094N	PARTICIPANT	\N	PRESENT	0
813231	813230	19669L	PARTICIPANT	\N	PRESENT	0
813233	813232	20106U	PARTICIPANT	\N	PRESENT	0
813234	813232	19649G	PARTICIPANT	\N	PRESENT	0
813236	813235	20134Y	PARTICIPANT	\N	PRESENT	0
813237	813235	20062A	PARTICIPANT	\N	PRESENT	0
813239	813238	20134Y	PARTICIPANT	\N	PRESENT	0
813240	813238	20062A	PARTICIPANT	\N	PRESENT	0
813242	813241	14331P	PARTICIPANT	\N	PRESENT	0
813255	813254	10015M	PARTICIPANT	\N	PRESENT	0
813281	813280	20050V	PARTICIPANT	\N	PRESENT	0
813283	813282	11074Q	PARTICIPANT	\N	PRESENT	0
813284	813282	19349W	PARTICIPANT	\N	PRESENT	0
813286	813285	21090J	PARTICIPANT	\N	PRESENT	0
813287	813285	08009T	PARTICIPANT	\N	PRESENT	0
813289	813288	21090J	PARTICIPANT	\N	PRESENT	0
813290	813288	08009T	PARTICIPANT	\N	PRESENT	0
813292	813291	20136B	PARTICIPANT	\N	PRESENT	0
813293	813291	19251M	PARTICIPANT	\N	PRESENT	0
813296	813294	20082E	PARTICIPANT	\N	PRESENT	0
813297	813295	20082E	PARTICIPANT	\N	PRESENT	0
813298	813295	20026V	PARTICIPANT	\N	PRESENT	0
813300	813299	19667J	PARTICIPANT	\N	PRESENT	0
813407	813406	04047H	PARTICIPANT	\N	PRESENT	0
813375	813356	19413M	PARTICIPANT	\N	PRESENT	0
813376	813356	99004R	PRESIDENT	0	PRESENT	0
813377	813356	21090J	PARTICIPANT	\N	PRESENT	0
813378	813356	21093M	PARTICIPANT	\N	PRESENT	0
813408	813406	14231L	PARTICIPANT	\N	PRESENT	0
813409	813406	20022R	PARTICIPANT	\N	PRESENT	0
813410	813406	20074E	PARTICIPANT	\N	PRESENT	0
813411	813406	18207D	PARTICIPANT	\N	PRESENT	0
813412	813406	21057H	PARTICIPANT	\N	PRESENT	0
813413	813406	21043B	PARTICIPANT	\N	PRESENT	0
813580	813415	21079P	PARTICIPANT	\N	PRESENT	0
813581	813415	19621T	PARTICIPANT	\N	PRESENT	0
813582	813415	21037D	PARTICIPANT	\N	PRESENT	0
813583	813415	21061D	PARTICIPANT	\N	PRESENT	0
813584	813415	12028B	PARTICIPANT	\N	PRESENT	0
813585	813415	20108W	PARTICIPANT	\N	PRESENT	0
813586	813415	14217N	PARTICIPANT	\N	PRESENT	0
813587	813415	21090J	PARTICIPANT	\N	PRESENT	0
813588	813415	20264J	PARTICIPANT	\N	PRESENT	0
813589	813415	14069U	PARTICIPANT	\N	PRESENT	0
813590	813415	20252E	PARTICIPANT	\N	PRESENT	0
813591	813415	20070A	PARTICIPANT	\N	PRESENT	0
813592	813415	19798U	PARTICIPANT	\N	PRESENT	0
813593	813415	18395Y	PARTICIPANT	\N	PRESENT	0
813594	813415	21067K	PARTICIPANT	\N	PRESENT	0
813595	813415	11048N	PARTICIPANT	\N	PRESENT	0
813596	813415	19631V	PARTICIPANT	\N	PRESENT	0
813597	813415	14223L	PARTICIPANT	\N	PRESENT	0
813598	813415	14071N	PARTICIPANT	\N	PRESENT	0
813599	813415	21094N	PARTICIPANT	\N	PRESENT	0
813600	813415	14193X	PARTICIPANT	\N	PRESENT	0
813601	813415	14355X	PARTICIPANT	\N	PRESENT	0
813602	813415	11074Q	PARTICIPANT	\N	PRESENT	0
813603	813415	21062E	PARTICIPANT	\N	PRESENT	0
813604	813415	20038A	PARTICIPANT	\N	PRESENT	0
813605	813415	01058X	PARTICIPANT	\N	PRESENT	0
813606	813415	19820Y	PARTICIPANT	\N	PRESENT	0
813607	813415	19725B	PARTICIPANT	\N	PRESENT	0
813608	813415	19551W	PARTICIPANT	\N	PRESENT	0
813609	813415	19683J	PARTICIPANT	\N	PRESENT	0
813610	813415	14187A	PARTICIPANT	\N	PRESENT	0
813611	813415	08034U	PARTICIPANT	\N	PRESENT	0
813612	813415	20078J	PARTICIPANT	\N	PRESENT	0
813613	813415	18193Q	PARTICIPANT	\N	PRESENT	0
813614	813415	14021P	PARTICIPANT	\N	PRESENT	0
813615	813415	20092G	PARTICIPANT	\N	PRESENT	0
813616	813415	14253S	PARTICIPANT	\N	PRESENT	0
813617	813415	18207D	PARTICIPANT	\N	PRESENT	0
813618	813415	14001X	PARTICIPANT	\N	PRESENT	0
813619	813415	20018V	PARTICIPANT	\N	PRESENT	0
813620	813415	21092L	PARTICIPANT	\N	PRESENT	0
813621	813415	19647E	PARTICIPANT	\N	PRESENT	0
813622	813415	19768N	PARTICIPANT	\N	PRESENT	0
813623	813415	19573D	PARTICIPANT	\N	PRESENT	0
813624	813415	14225N	PARTICIPANT	\N	PRESENT	0
813625	813415	21089R	PARTICIPANT	\N	PRESENT	0
813626	813415	19669L	PARTICIPANT	\N	PRESENT	0
813627	813415	21051B	PARTICIPANT	\N	PRESENT	0
813628	813415	20064C	PARTICIPANT	\N	PRESENT	0
813629	813415	20148F	PARTICIPANT	\N	PRESENT	0
813630	813415	21031W	PARTICIPANT	\N	PRESENT	0
813631	813415	14053L	PARTICIPANT	\N	PRESENT	0
813632	813415	21042A	PARTICIPANT	\N	PRESENT	0
813633	813415	20266L	PARTICIPANT	\N	PRESENT	0
813634	813415	21076L	PARTICIPANT	\N	PRESENT	0
813635	813415	14030Q	PARTICIPANT	\N	PRESENT	0
813636	813415	21050A	PARTICIPANT	\N	PRESENT	0
813637	813415	20042V	PARTICIPANT	\N	PRESENT	0
813638	813415	14255U	PARTICIPANT	\N	PRESENT	0
813639	813415	21083K	PARTICIPANT	\N	PRESENT	0
813640	813415	08060W	PARTICIPANT	\N	PRESENT	0
813641	813415	19721W	PARTICIPANT	\N	PRESENT	0
813642	813415	14267Y	PARTICIPANT	\N	PRESENT	0
813643	813415	19489J	PARTICIPANT	\N	PRESENT	0
813644	813415	17229F	PARTICIPANT	\N	PRESENT	0
813645	813415	21057H	PARTICIPANT	\N	PRESENT	0
813646	813415	11045K	PARTICIPANT	\N	PRESENT	0
813647	813415	14229S	PARTICIPANT	\N	PRESENT	0
813648	813415	14109K	PARTICIPANT	\N	PRESENT	0
813649	813415	20172F	PARTICIPANT	\N	PRESENT	0
813650	813415	14231L	PARTICIPANT	\N	PRESENT	0
813651	813415	08010L	PARTICIPANT	\N	PRESENT	0
813652	813415	19569H	PARTICIPANT	\N	PRESENT	0
813653	813415	19735D	PARTICIPANT	\N	PRESENT	0
813654	813415	19611R	PARTICIPANT	\N	PRESENT	0
813655	813415	19699S	PARTICIPANT	\N	PRESENT	0
813656	813415	20052X	PARTICIPANT	\N	PRESENT	0
813657	813415	14213J	PARTICIPANT	\N	PRESENT	0
813658	813415	19826F	PARTICIPANT	\N	PRESENT	0
813659	813415	21068L	PARTICIPANT	\N	PRESENT	0
813660	813415	20082E	PARTICIPANT	\N	PRESENT	0
813661	813415	20142Y	PARTICIPANT	\N	PRESENT	0
813662	813415	10015M	PARTICIPANT	\N	PRESENT	0
813663	813415	19745F	PARTICIPANT	\N	PRESENT	0
813664	813415	21053D	PARTICIPANT	\N	PRESENT	0
813665	813415	14038Y	PARTICIPANT	\N	PRESENT	0
813666	813415	01034P	PARTICIPANT	\N	PRESENT	0
813667	813415	14275Y	PARTICIPANT	\N	PRESENT	0
813668	813415	20118Y	PARTICIPANT	\N	PRESENT	0
813669	813415	19713W	PARTICIPANT	\N	PRESENT	0
813670	813415	20026V	PARTICIPANT	\N	PRESENT	0
813671	813415	14147R	PARTICIPANT	\N	PRESENT	0
813672	813415	14179A	PARTICIPANT	\N	PRESENT	0
813673	813415	14237S	PARTICIPANT	\N	PRESENT	0
813674	813415	19719D	PARTICIPANT	\N	PRESENT	0
813675	813415	04070G	PARTICIPANT	\N	PRESENT	0
813676	813415	20248J	PARTICIPANT	\N	PRESENT	0
813677	813415	20032T	PARTICIPANT	\N	PRESENT	0
813678	813415	20036X	PARTICIPANT	\N	PRESENT	0
813679	813415	20134Y	PARTICIPANT	\N	PRESENT	0
813680	813415	08045X	PARTICIPANT	\N	PRESENT	0
813681	813415	21069M	PARTICIPANT	\N	PRESENT	0
813682	813415	08012N	PARTICIPANT	\N	PRESENT	0
813683	813415	19681G	PARTICIPANT	\N	PRESENT	0
813684	813415	21075K	PARTICIPANT	\N	PRESENT	0
813685	813415	19531S	PARTICIPANT	\N	PRESENT	0
813686	813415	17779H	PARTICIPANT	\N	PRESENT	0
813687	813415	20138D	PARTICIPANT	\N	PRESENT	0
813688	813415	11053K	PARTICIPANT	\N	PRESENT	0
799797	799796	20114U	PARTICIPANT	\N	PRESENT	0
799798	799796	11053K	PARTICIPANT	\N	PRESENT	0
799799	799796	20056C	PARTICIPANT	\N	PRESENT	0
799801	799796	21087P	PARTICIPANT	\N	PRESENT	0
799802	799796	08012N	PARTICIPANT	\N	PRESENT	0
799804	799796	20148F	PARTICIPANT	\N	PRESENT	0
800028	800023	14249W	PARTICIPANT	\N	PRESENT	0
800032	800023	14097Y	PARTICIPANT	\N	PRESENT	0
800035	800023	19709B	PARTICIPANT	\N	PRESENT	0
800037	800023	08034U	PRESIDENT	0	PRESENT	0
800040	800023	14059S	PARTICIPANT	\N	PRESENT	0
800043	800023	19745F	PARTICIPANT	\N	PRESENT	0
800045	800023	14225N	PARTICIPANT	\N	PRESENT	0
800049	800023	14229S	PARTICIPANT	\N	PRESENT	0
800051	800023	20150Y	PARTICIPANT	\N	PRESENT	0
800053	800023	11043H	PARTICIPANT	\N	PRESENT	0
800055	800023	19669L	PARTICIPANT	\N	PRESENT	0
800096	800023	10015M	PARTICIPANT	\N	EXCUSE	0
800409	800408	11070L	PARTICIPANT	\N	PRESENT	0
800410	800408	14257W	PRESIDENT	0	PRESENT	0
800411	800408	19619A	PARTICIPANT	\N	PRESENT	0
802359	801381	19679N	PARTICIPANT	\N	PRESENT	0
800414	800408	20106U	PARTICIPANT	\N	PRESENT	0
800418	800408	20042V	PARTICIPANT	\N	PRESENT	0
800419	800408	14033T	PARTICIPANT	\N	PRESENT	0
800431	800408	20018V	PARTICIPANT	\N	PRESENT	0
800432	800408	20092G	PARTICIPANT	\N	PRESENT	0
800434	800408	20120S	PARTICIPANT	\N	PRESENT	0
802360	801381	21046E	PARTICIPANT	\N	PRESENT	0
802361	801381	21049H	PARTICIPANT	\N	PRESENT	0
802362	801382	21046E	PARTICIPANT	\N	PRESENT	0
802363	801382	19679N	PARTICIPANT	\N	PRESENT	0
802364	801382	21049H	PARTICIPANT	\N	PRESENT	0
802365	801571	14169X	PARTICIPANT	\N	EXCUSE	0
802366	801383	19679N	PARTICIPANT	\N	PRESENT	0
802367	801383	21049H	PARTICIPANT	\N	PRESENT	0
802495	801383	21046E	PARTICIPANT	\N	PRESENT	0
802496	801384	21049H	PARTICIPANT	\N	PRESENT	0
802497	801384	19679N	PARTICIPANT	\N	PRESENT	0
802498	801384	21046E	PARTICIPANT	\N	PRESENT	0
802499	801385	21049H	PARTICIPANT	\N	PRESENT	0
802500	801385	19679N	PARTICIPANT	\N	PRESENT	0
802501	801385	21046E	PARTICIPANT	\N	PRESENT	0
802839	801571	19387D	PARTICIPANT	\N	EXCUSE	0
803201	802850	20098N	PARTICIPANT	\N	PRESENT	0
804008	804007	14073Q	PARTICIPANT	\N	PRESENT	0
804009	804007	08012N	PARTICIPANT	\N	PRESENT	0
804281	803989	19575F	PARTICIPANT	\N	EXCUSE	0
806752	803923	04033B	PARTICIPANT	\N	PRESENT	0
806753	803923	07029T	PARTICIPANT	\N	PRESENT	0
806754	803923	21085M	PARTICIPANT	\N	PRESENT	0
806755	803923	19563B	PARTICIPANT	\N	PRESENT	0
806756	803923	14275Y	PARTICIPANT	\N	PRESENT	0
806757	803923	05012A	PARTICIPANT	\N	PRESENT	0
806758	803923	21089R	PARTICIPANT	\N	PRESENT	0
806759	803923	14030Q	PARTICIPANT	\N	PRESENT	0
806760	803923	21069M	PARTICIPANT	\N	PRESENT	0
806761	803923	14037X	PARTICIPANT	\N	PRESENT	0
806762	803923	18395Y	PARTICIPANT	\N	PRESENT	0
806763	803923	11110B	PARTICIPANT	\N	PRESENT	0
806764	803923	14329V	PARTICIPANT	\N	PRESENT	0
806765	803923	11048N	PARTICIPANT	\N	PRESENT	0
806766	803923	20048C	PARTICIPANT	\N	PRESENT	0
806767	803923	20042V	PARTICIPANT	\N	PRESENT	0
806768	803923	20126Y	PARTICIPANT	\N	PRESENT	0
806769	803923	19621T	PARTICIPANT	\N	PRESENT	0
806770	803923	20070A	PARTICIPANT	\N	PRESENT	0
806771	803923	14026U	PARTICIPANT	\N	PRESENT	0
806772	803923	20044X	PARTICIPANT	\N	PRESENT	0
806773	803923	19531S	PARTICIPANT	\N	PRESENT	0
806774	803923	21057H	PARTICIPANT	\N	PRESENT	0
806775	803923	21040X	PARTICIPANT	\N	PRESENT	0
806776	803923	21054E	PARTICIPANT	\N	PRESENT	0
806777	803923	14021P	PARTICIPANT	\N	PRESENT	0
806778	803923	21071F	PARTICIPANT	\N	PRESENT	0
806779	803923	18083K	PARTICIPANT	\N	PRESENT	0
806780	803923	14213J	PARTICIPANT	\N	PRESENT	0
806781	803923	20116W	PARTICIPANT	\N	PRESENT	0
806782	803923	14073Q	PARTICIPANT	\N	PRESENT	0
806783	803923	20134Y	PARTICIPANT	\N	PRESENT	0
806784	803923	14205J	PARTICIPANT	\N	PRESENT	0
806785	803923	14207L	PARTICIPANT	\N	PRESENT	0
806837	804044	86034E	PARTICIPANT	\N	PRESENT	0
806838	804044	18231D	PARTICIPANT	\N	PRESENT	0
806839	804044	14038Y	PARTICIPANT	\N	PRESENT	0
806840	804044	20072C	PARTICIPANT	\N	PRESENT	0
806841	804044	20092G	PARTICIPANT	\N	PRESENT	0
806842	804045	21089R	PARTICIPANT	\N	PRESENT	0
806844	804044	21089R	PARTICIPANT	\N	PRESENT	0
806925	806924	20100N	PARTICIPANT	\N	PRESENT	0
806926	806924	19251M	PARTICIPANT	\N	PRESENT	0
806927	806924	19619A	PARTICIPANT	\N	PRESENT	0
806928	806924	21029D	PARTICIPANT	\N	PRESENT	0
806929	806924	20046A	PARTICIPANT	\N	PRESENT	0
806930	806924	17229F	PARTICIPANT	\N	PRESENT	0
806931	806924	11065P	PARTICIPANT	\N	PRESENT	0
806932	806924	21082J	PARTICIPANT	\N	PRESENT	0
806933	806924	14169X	PARTICIPANT	\N	PRESENT	0
806934	806924	20136B	PARTICIPANT	\N	PRESENT	0
806937	806936	19701S	PARTICIPANT	\N	PRESENT	0
806938	806936	19820Y	PARTICIPANT	\N	PRESENT	0
806939	806936	14213J	PARTICIPANT	\N	PRESENT	0
806940	806936	11085T	PARTICIPANT	\N	PRESENT	0
806954	804044	20042V	PARTICIPANT	\N	PRESENT	0
806955	804045	20042V	PARTICIPANT	\N	PRESENT	0
807038	807037	19111A	PARTICIPANT	\N	PRESENT	0
807041	807040	19575F	PARTICIPANT	\N	EXCUSE	0
807044	807040	11070L	PARTICIPANT	\N	PRESENT	0
807045	807040	14257W	PRESIDENT	0	PRESENT	0
807047	807040	20092G	PARTICIPANT	\N	PRESENT	0
807049	807040	19619A	PARTICIPANT	\N	PRESENT	0
807113	807040	14031R	PARTICIPANT	\N	PRESENT	0
807140	805691	19591F	PARTICIPANT	\N	PRESENT	0
807141	805691	20028X	PARTICIPANT	\N	EXCUSE	0
807142	805691	10015M	PARTICIPANT	\N	EXCUSE	0
807143	805691	14073Q	PARTICIPANT	\N	EXCUSE	0
807145	805691	20106U	PARTICIPANT	\N	EXCUSE	0
807151	807150	07004J	PARTICIPANT	\N	PRESENT	0
807152	807150	14179A	PARTICIPANT	\N	PRESENT	0
807153	807150	14097Y	PARTICIPANT	\N	PRESENT	0
807155	807150	08034U	PRESIDENT	0	PRESENT	0
807156	807150	19745F	PARTICIPANT	\N	PRESENT	0
807157	807150	10015M	PARTICIPANT	\N	PRESENT	0
807158	807150	20150Y	PARTICIPANT	\N	PRESENT	0
807159	807150	19669L	PARTICIPANT	\N	PRESENT	0
807160	807150	17367Q	PARTICIPANT	\N	EXCUSE	0
807161	807150	19575F	PARTICIPANT	\N	EXCUSE	0
807162	807150	20050V	PARTICIPANT	\N	EXCUSE	0
807163	807150	14225N	PARTICIPANT	\N	EXCUSE	0
807363	807362	11048N	PARTICIPANT	\N	PRESENT	0
807380	807379	11048N	PARTICIPANT	\N	PRESENT	0
807382	807381	11048N	PARTICIPANT	\N	PRESENT	0
807386	807186	14151M	PRESIDENT	0	PRESENT	0
807387	807186	17367Q	PARTICIPANT	\N	PRESENT	0
807388	807186	12028B	PARTICIPANT	\N	PRESENT	0
807389	807186	17737W	PARTICIPANT	\N	PRESENT	0
807390	807186	21081H	PARTICIPANT	\N	PRESENT	0
807397	807186	21040X	PARTICIPANT	\N	PRESENT	0
807398	807186	18395Y	PARTICIPANT	\N	PRESENT	0
807404	807403	14255U	PARTICIPANT	\N	PRESENT	0
807405	807403	14037X	PARTICIPANT	\N	PRESENT	0
807406	807403	19421M	PARTICIPANT	\N	PRESENT	0
807409	807408	14219Q	PARTICIPANT	\N	PRESENT	0
807410	807408	11090Q	PARTICIPANT	\N	PRESENT	0
807424	807005	14053L	PARTICIPANT	\N	PRESENT	0
807425	807005	14111D	PARTICIPANT	\N	PRESENT	0
807426	807005	10015M	PARTICIPANT	\N	PRESENT	0
807427	807005	21057H	PARTICIPANT	\N	PRESENT	0
807428	807005	04045F	PARTICIPANT	\N	PRESENT	0
807429	807005	04047H	PRESIDENT	0	PRESENT	0
807430	807005	14231L	PARTICIPANT	\N	PRESENT	0
807431	807005	19447X	PARTICIPANT	\N	PRESENT	0
807432	807005	20098N	PARTICIPANT	\N	PRESENT	0
807433	807005	21044C	PARTICIPANT	\N	PRESENT	0
807434	807005	21056G	PARTICIPANT	\N	PRESENT	0
807435	807005	18207D	PARTICIPANT	\N	PRESENT	0
807436	807005	18231D	PARTICIPANT	\N	PRESENT	0
807437	807005	14147R	PARTICIPANT	\N	PRESENT	0
807438	807005	19111A	PARTICIPANT	\N	PRESENT	0
807439	807005	14215L	PARTICIPANT	\N	PRESENT	0
807440	807005	21038E	PARTICIPANT	\N	PRESENT	0
812490	810307	20028X	PARTICIPANT	\N	PRESENT	0
812491	810307	20046A	PARTICIPANT	\N	PRESENT	0
812492	810307	18207D	PARTICIPANT	\N	PRESENT	0
812493	810307	21048G	PARTICIPANT	\N	PRESENT	0
812495	810307	20086J	PARTICIPANT	\N	PRESENT	0
812496	810307	20026V	PARTICIPANT	\N	PRESENT	0
812497	810307	21058J	PARTICIPANT	\N	PRESENT	0
812498	810307	19681G	PARTICIPANT	\N	PRESENT	0
812499	810307	19697Q	PARTICIPANT	\N	PRESENT	0
812500	810307	19533U	PARTICIPANT	\N	PRESENT	0
812501	810307	07029T	PARTICIPANT	\N	PRESENT	0
812502	810307	14083S	PARTICIPANT	\N	PRESENT	0
812503	810307	20022R	PARTICIPANT	\N	PRESENT	0
812505	810307	20172F	PARTICIPANT	\N	PRESENT	0
812506	810307	10015M	PARTICIPANT	\N	PRESENT	0
812507	810307	20018V	PARTICIPANT	\N	PRESENT	0
812508	810307	08018U	PARTICIPANT	\N	PRESENT	0
812509	810307	14217N	PARTICIPANT	\N	PRESENT	0
812510	810307	20110Q	PARTICIPANT	\N	PRESENT	0
812511	810307	19719D	PARTICIPANT	\N	PRESENT	0
812512	810307	21075K	PARTICIPANT	\N	PRESENT	0
812513	810307	21042A	PARTICIPANT	\N	PRESENT	0
812514	810307	17965H	PARTICIPANT	\N	PRESENT	0
812515	810307	19569H	PARTICIPANT	\N	PRESENT	0
812516	810307	20048C	PARTICIPANT	\N	PRESENT	0
812517	810307	19683J	PARTICIPANT	\N	PRESENT	0
812518	810307	20080C	PARTICIPANT	\N	PRESENT	0
812519	810307	19399H	PARTICIPANT	\N	PRESENT	0
812520	810307	20070A	PARTICIPANT	\N	PRESENT	0
812521	810307	21068L	PARTICIPANT	\N	PRESENT	0
812590	810308	21055F	PARTICIPANT	\N	PRESENT	0
812591	810308	14069U	PARTICIPANT	\N	PRESENT	0
812592	810308	14215L	PARTICIPANT	\N	PRESENT	0
812593	810308	14231L	PARTICIPANT	\N	PRESENT	0
812594	810308	19621T	PARTICIPANT	\N	PRESENT	0
812595	810308	20172F	PARTICIPANT	\N	PRESENT	0
812596	810308	20080C	PARTICIPANT	\N	PRESENT	0
812597	810308	20070A	PARTICIPANT	\N	PRESENT	0
812598	810308	14217N	PARTICIPANT	\N	PRESENT	0
812599	810308	20018V	PARTICIPANT	\N	PRESENT	0
812600	810308	14147R	PARTICIPANT	\N	PRESENT	0
812601	810308	21093M	PARTICIPANT	\N	PRESENT	0
812602	810308	14133K	PARTICIPANT	\N	PRESENT	0
812603	810308	19399H	PARTICIPANT	\N	PRESENT	0
812604	810308	07029T	PARTICIPANT	\N	PRESENT	0
812605	810308	21068L	PARTICIPANT	\N	PRESENT	0
812606	810308	21058J	PARTICIPANT	\N	PRESENT	0
812607	810308	21042A	PARTICIPANT	\N	PRESENT	0
812608	810308	20048C	PARTICIPANT	\N	PRESENT	0
812609	810308	14207L	PARTICIPANT	\N	PRESENT	0
812610	810308	20036X	PARTICIPANT	\N	PRESENT	0
812611	810308	19749K	PARTICIPANT	\N	PRESENT	0
812612	810308	20124W	PARTICIPANT	\N	PRESENT	0
812613	810308	20266L	PARTICIPANT	\N	PRESENT	0
812614	810308	20134Y	PARTICIPANT	\N	PRESENT	0
812615	810308	21043B	PARTICIPANT	\N	PRESENT	0
812616	810308	21066J	PARTICIPANT	\N	PRESENT	0
812617	810308	17965H	PARTICIPANT	\N	PRESENT	0
812618	810308	19683J	PARTICIPANT	\N	PRESENT	0
812619	810308	18207D	PARTICIPANT	\N	PRESENT	0
812620	810308	20110Q	PARTICIPANT	\N	PRESENT	0
812621	810308	14189C	PARTICIPANT	\N	PRESENT	0
812622	810308	21053D	PARTICIPANT	\N	PRESENT	0
812623	810308	04047H	PARTICIPANT	\N	PRESENT	0
812624	810308	19693L	PARTICIPANT	\N	PRESENT	0
812625	810308	19629C	PARTICIPANT	\N	PRESENT	0
812626	810308	14033T	PARTICIPANT	\N	PRESENT	0
812627	810308	21063F	PARTICIPANT	\N	PRESENT	0
812628	810308	11048N	PARTICIPANT	\N	PRESENT	0
812629	810308	20090E	PARTICIPANT	\N	PRESENT	0
812630	810308	20026V	PARTICIPANT	\N	PRESENT	0
812631	810308	19573D	PARTICIPANT	\N	PRESENT	0
812632	810308	19758L	PARTICIPANT	\N	PRESENT	0
812633	810308	19713W	PARTICIPANT	\N	PRESENT	0
812634	810308	14021P	PARTICIPANT	\N	PRESENT	0
812635	810308	19413M	PARTICIPANT	\N	PRESENT	0
812636	810308	14042U	PARTICIPANT	\N	PRESENT	0
812637	810308	21049H	PARTICIPANT	\N	PRESENT	0
812638	810308	21070E	PARTICIPANT	\N	PRESENT	0
812643	810308	21085M	PARTICIPANT	\N	PRESENT	0
812644	810308	17023S	PARTICIPANT	\N	PRESENT	0
812645	810308	21056G	PARTICIPANT	\N	PRESENT	0
812648	810308	20098N	PARTICIPANT	\N	PRESENT	0
812649	810308	21047F	PARTICIPANT	\N	PRESENT	0
812650	810308	20092G	PARTICIPANT	\N	PRESENT	0
812651	810308	21071F	PARTICIPANT	\N	PRESENT	0
812652	810308	20062A	PARTICIPANT	\N	PRESENT	0
812653	810308	14259Y	PARTICIPANT	\N	PRESENT	0
812654	810308	20100N	PARTICIPANT	\N	PRESENT	0
812655	810308	21080G	PARTICIPANT	\N	PRESENT	0
815799	813182	20042V	PARTICIPANT	\N	EXCUSE	0
815800	813182	20024T	PARTICIPANT	\N	EXCUSE	0
815801	813182	14169X	PARTICIPANT	\N	EXCUSE	0
815802	813182	21063F	PARTICIPANT	\N	EXCUSE	0
815803	813182	20066E	PARTICIPANT	\N	EXCUSE	0
812588	810308	14111D	PARTICIPANT	\N	PRESENT	0
812589	810308	19673G	PARTICIPANT	\N	PRESENT	0
815807	810829	14231L	PRESIDENT	0	PRESENT	0
815808	810829	14215L	PARTICIPANT	\N	PRESENT	0
815809	810829	20058E	PARTICIPANT	\N	PRESENT	0
815810	810829	19447X	PARTICIPANT	\N	PRESENT	0
815811	810829	20102Q	PARTICIPANT	\N	PRESENT	0
815812	810829	20084G	PARTICIPANT	\N	PRESENT	0
815813	810829	19758L	PARTICIPANT	\N	PRESENT	0
815814	810829	19573D	PARTICIPANT	\N	PRESENT	0
815815	810829	19820Y	PARTICIPANT	\N	PRESENT	0
815816	810829	21079P	PARTICIPANT	\N	PRESENT	0
815817	810829	14327T	PARTICIPANT	\N	PRESENT	0
815818	810829	21048G	PARTICIPANT	\N	PRESENT	0
815819	810829	21065H	PARTICIPANT	\N	PRESENT	0
815820	810829	20032T	PARTICIPANT	\N	PRESENT	0
815821	810829	20090E	PARTICIPANT	\N	PRESENT	0
815822	810829	05012A	PARTICIPANT	\N	PRESENT	0
815823	810829	20120S	PARTICIPANT	\N	PRESENT	0
815824	810829	20022R	PARTICIPANT	\N	PRESENT	0
815827	810829	20068G	PARTICIPANT	\N	PRESENT	0
815828	810829	14053L	PARTICIPANT	\N	EXCUSE	0
815829	810829	19489J	PARTICIPANT	\N	EXCUSE	0
815830	810829	14257W	PARTICIPANT	\N	EXCUSE	0
815831	810829	21068L	PARTICIPANT	\N	EXCUSE	0
815832	810829	21070E	PARTICIPANT	\N	EXCUSE	0
815833	810829	14107H	PARTICIPANT	\N	EXCUSE	0
815834	810829	01034P	PARTICIPANT	\N	EXCUSE	0
815835	810829	14173T	PARTICIPANT	\N	EXCUSE	0
817075	817074	14083S	PARTICIPANT	\N	PRESENT	0
817076	817074	19553Y	PARTICIPANT	\N	PRESENT	0
817077	817074	21065H	PARTICIPANT	\N	PRESENT	0
817078	817074	19713W	PARTICIPANT	\N	PRESENT	0
817079	815054	14217N	PARTICIPANT	\N	PRESENT	0
817080	815054	21097R	PARTICIPANT	\N	PRESENT	0
817081	815054	21094N	PARTICIPANT	\N	PRESENT	0
817082	815935	21079P	PARTICIPANT	\N	PRESENT	0
817083	815935	21094N	PARTICIPANT	\N	PRESENT	0
817084	815935	21035B	PARTICIPANT	\N	PRESENT	0
817085	815935	18193Q	PARTICIPANT	\N	PRESENT	0
817086	815935	21089R	PARTICIPANT	\N	PRESENT	0
817087	815935	17965H	PARTICIPANT	\N	PRESENT	0
817088	815935	19758L	PARTICIPANT	\N	PRESENT	0
817089	815935	20056C	PARTICIPANT	\N	PRESENT	0
817090	815935	21081H	PARTICIPANT	\N	PRESENT	0
817072	815935	14229S	PARTICIPANT	\N	PRESENT	0
817073	816847	20096L	PARTICIPANT	\N	PRESENT	0
817091	815935	20034V	PARTICIPANT	\N	PRESENT	0
817092	815935	14033T	PARTICIPANT	\N	PRESENT	0
817093	815935	21047F	PARTICIPANT	\N	PRESENT	0
817094	815935	21058J	PARTICIPANT	\N	PRESENT	0
817095	815935	19447X	PARTICIPANT	\N	PRESENT	0
817096	815935	14213J	PARTICIPANT	\N	PRESENT	0
817097	815935	21090J	PARTICIPANT	\N	PRESENT	0
817098	815935	21073H	PARTICIPANT	\N	PRESENT	0
817099	815935	14195A	PARTICIPANT	\N	PRESENT	0
817100	815935	20106U	PARTICIPANT	\N	PRESENT	0
817101	815935	21034A	PARTICIPANT	\N	PRESENT	0
817102	815935	19553Y	PARTICIPANT	\N	PRESENT	0
817103	815935	14089Y	PARTICIPANT	\N	PRESENT	0
817104	815935	14042U	PARTICIPANT	\N	PRESENT	0
817105	815935	21053D	PARTICIPANT	\N	PRESENT	0
817106	815935	21064G	PARTICIPANT	\N	PRESENT	0
817107	815935	20096L	PARTICIPANT	\N	PRESENT	0
797638	797637	14231L	PRESIDENT	0	PRESENT	0
797639	797637	19782L	PARTICIPANT	\N	EXCUSE	0
797640	797637	14259Y	PARTICIPANT	\N	PRESENT	0
797641	797637	20022R	PARTICIPANT	\N	EXCUSE	0
797642	797637	21048G	PARTICIPANT	\N	EXCUSE	0
797643	797637	19621T	PARTICIPANT	\N	EXCUSE	0
797644	797637	20090E	PARTICIPANT	\N	EXCUSE	0
797645	797637	14053L	PARTICIPANT	\N	EXCUSE	0
797646	797637	14327T	PARTICIPANT	\N	EXCUSE	0
797647	797637	14151M	PARTICIPANT	\N	EXCUSE	0
797648	797637	19489J	PARTICIPANT	\N	EXCUSE	0
797649	797637	19735D	PARTICIPANT	\N	EXCUSE	0
797650	797637	20102Q	PARTICIPANT	\N	EXCUSE	0
797651	797637	08012N	PARTICIPANT	\N	EXCUSE	0
797652	797637	14257W	PARTICIPANT	\N	EXCUSE	0
797653	797637	04045F	PARTICIPANT	\N	EXCUSE	0
797654	797637	20084G	PARTICIPANT	\N	PRESENT	0
797655	797637	01034P	PARTICIPANT	\N	EXCUSE	0
797656	797637	20058E	PARTICIPANT	\N	EXCUSE	0
797657	797637	14026U	PARTICIPANT	\N	PRESENT	0
797658	797637	20062A	PARTICIPANT	\N	PRESENT	0
797659	797637	21085M	PARTICIPANT	\N	PRESENT	0
797660	797637	21070E	PARTICIPANT	\N	PRESENT	0
797661	797637	19758L	PARTICIPANT	\N	PRESENT	0
797662	797637	19826F	PARTICIPANT	\N	PRESENT	0
797663	797637	20068G	PARTICIPANT	\N	PRESENT	0
797664	797637	20032T	PARTICIPANT	\N	PRESENT	0
797665	797637	21068L	PARTICIPANT	\N	PRESENT	0
797666	797637	19820Y	PARTICIPANT	\N	PRESENT	0
797667	797637	14281W	PARTICIPANT	\N	PRESENT	0
797668	797637	19531S	PARTICIPANT	\N	PRESENT	0
797669	797637	21065H	PARTICIPANT	\N	PRESENT	0
797670	797637	19573D	PARTICIPANT	\N	PRESENT	0
797671	797637	19447X	PARTICIPANT	\N	PRESENT	0
797672	797637	05012A	PARTICIPANT	\N	PRESENT	0
797675	797637	14215L	PARTICIPANT	\N	PRESENT	0
798326	797964	14053L	PARTICIPANT	\N	PRESENT	0
798327	797964	19335Q	PARTICIPANT	\N	PRESENT	0
798328	797964	14253S	PARTICIPANT	\N	PRESENT	0
798329	797964	08069G	PARTICIPANT	\N	PRESENT	0
798330	797964	19954N	PARTICIPANT	\N	PRESENT	0
798332	797964	08015R	PARTICIPANT	\N	PRESENT	0
798338	797964	21037D	PARTICIPANT	\N	PRESENT	0
798339	797964	14237S	PARTICIPANT	\N	PRESENT	0
798340	797964	20022R	PARTICIPANT	\N	PRESENT	0
798341	797964	08009T	PARTICIPANT	\N	PRESENT	0
798342	797964	14193X	PARTICIPANT	\N	PRESENT	0
798343	797964	20104S	PARTICIPANT	\N	PRESENT	0
798637	797791	86034E	PARTICIPANT	\N	PRESENT	0
798639	797791	19507S	PARTICIPANT	\N	PRESENT	0
798642	797791	21047F	PARTICIPANT	\N	PRESENT	0
798643	797791	14059S	PARTICIPANT	\N	PRESENT	0
798644	797791	08015R	PARTICIPANT	\N	PRESENT	0
798645	797791	14213J	PARTICIPANT	\N	PRESENT	0
798646	797791	14147R	PARTICIPANT	\N	PRESENT	0
798649	797791	14331P	PARTICIPANT	\N	PRESENT	0
798650	797791	14223L	PARTICIPANT	\N	PRESENT	0
798654	797791	20044X	PARTICIPANT	\N	PRESENT	0
798656	797791	21090J	PARTICIPANT	\N	PRESENT	0
798658	797791	20126Y	PARTICIPANT	\N	PRESENT	0
798662	797791	14055N	PARTICIPANT	\N	PRESENT	0
798665	797791	19713W	PARTICIPANT	\N	PRESENT	0
798667	797791	14205J	PARTICIPANT	\N	PRESENT	0
798670	797791	11053K	PARTICIPANT	\N	PRESENT	0
798671	797791	14219Q	PARTICIPANT	\N	PRESENT	0
798672	797791	14189C	PARTICIPANT	\N	PRESENT	0
798673	797791	21070E	PARTICIPANT	\N	PRESENT	0
798674	797791	14251Q	PARTICIPANT	\N	PRESENT	0
798675	797791	21041Y	PARTICIPANT	\N	PRESENT	0
798678	797791	14207L	PARTICIPANT	\N	PRESENT	0
798681	797791	98022P	PARTICIPANT	\N	PRESENT	0
798682	797791	20072C	PARTICIPANT	\N	PRESENT	0
798683	797791	14357A	PARTICIPANT	\N	PRESENT	0
798684	797791	19349W	PARTICIPANT	\N	PRESENT	0
798685	797791	20128B	PARTICIPANT	\N	PRESENT	0
798686	797791	20150Y	PARTICIPANT	\N	PRESENT	0
798687	797791	14037X	PARTICIPANT	\N	PRESENT	0
798688	797791	14225N	PARTICIPANT	\N	PRESENT	0
798689	797791	20080C	PARTICIPANT	\N	PRESENT	0
798690	797791	20084G	PARTICIPANT	\N	PRESENT	0
798691	797791	19413M	PARTICIPANT	\N	PRESENT	0
798692	797791	20264J	PARTICIPANT	\N	PRESENT	0
798694	797791	20100N	PARTICIPANT	\N	PRESENT	0
798696	797791	20092G	PARTICIPANT	\N	PRESENT	0
798698	797791	19347U	PARTICIPANT	\N	PRESENT	0
798699	797791	20046A	PARTICIPANT	\N	PRESENT	0
798701	797791	21076L	PARTICIPANT	\N	PRESENT	0
798702	797791	21052C	PARTICIPANT	\N	PRESENT	0
798703	797791	20144B	PARTICIPANT	\N	PRESENT	0
798704	797791	21061D	PARTICIPANT	\N	PRESENT	0
798705	797791	11043H	PARTICIPANT	\N	PRESENT	0
798708	797791	21080G	PARTICIPANT	\N	PRESENT	0
798709	797791	19679N	PARTICIPANT	\N	PRESENT	0
798710	797791	18083K	PARTICIPANT	\N	PRESENT	0
798711	797791	14259Y	PARTICIPANT	\N	PRESENT	0
798712	797791	20076G	PARTICIPANT	\N	PRESENT	0
798713	797791	19367Y	PARTICIPANT	\N	PRESENT	0
798714	797791	21058J	PARTICIPANT	\N	PRESENT	0
798715	797791	21039F	PARTICIPANT	\N	PRESENT	0
798716	797791	19421M	PARTICIPANT	\N	PRESENT	0
798717	797791	20026V	PARTICIPANT	\N	PRESENT	0
798718	797791	20056C	PARTICIPANT	\N	PRESENT	0
798719	797791	20172F	PARTICIPANT	\N	PRESENT	0
798720	797791	19768N	PARTICIPANT	\N	PRESENT	0
798721	797791	20024T	PARTICIPANT	\N	PRESENT	0
798722	797791	14187A	PARTICIPANT	\N	PRESENT	0
798723	797791	14069U	PARTICIPANT	\N	PRESENT	0
798724	797791	11090Q	PARTICIPANT	\N	PRESENT	0
798725	797791	20062A	PARTICIPANT	\N	PRESENT	0
798726	797791	04033B	PARTICIPANT	\N	PRESENT	0
798727	797791	19621T	PARTICIPANT	\N	PRESENT	0
798729	797791	20180F	PARTICIPANT	\N	PRESENT	0
798732	797791	19782L	PARTICIPANT	\N	PRESENT	0
798733	797791	20116W	PARTICIPANT	\N	PRESENT	0
798734	797791	21043B	PARTICIPANT	\N	PRESENT	0
798735	797791	20106U	PARTICIPANT	\N	PRESENT	0
798736	797791	21054E	PARTICIPANT	\N	PRESENT	0
798737	797791	14107H	PARTICIPANT	\N	PRESENT	0
798738	797791	21084L	PARTICIPANT	\N	PRESENT	0
798739	797791	19629C	PARTICIPANT	\N	PRESENT	0
798741	797791	19798U	PARTICIPANT	\N	PRESENT	0
798742	797791	21044C	PARTICIPANT	\N	PRESENT	0
798743	797791	14033T	PARTICIPANT	\N	PRESENT	0
798744	797791	19531S	PARTICIPANT	\N	PRESENT	0
798746	797791	07004J	PARTICIPANT	\N	PRESENT	0
798747	797791	19691J	PARTICIPANT	\N	PRESENT	0
798748	797791	20066E	PARTICIPANT	\N	PRESENT	0
798751	797791	21065H	PARTICIPANT	\N	PRESENT	0
798752	797791	21040X	PARTICIPANT	\N	PRESENT	0
798753	797791	20088L	PARTICIPANT	\N	PRESENT	0
798754	797791	14221J	PARTICIPANT	\N	PRESENT	0
798755	797791	19745F	PARTICIPANT	\N	PRESENT	0
798756	797791	21045D	PARTICIPANT	\N	PRESENT	0
798757	797791	20054A	PARTICIPANT	\N	PRESENT	0
798759	797791	21042A	PARTICIPANT	\N	PRESENT	0
798761	797791	19563B	PARTICIPANT	\N	PRESENT	0
798762	797791	14026U	PARTICIPANT	\N	PRESENT	0
798764	797791	19399H	PARTICIPANT	\N	PRESENT	0
798765	797791	21092L	PARTICIPANT	\N	PRESENT	0
798766	797791	19553Y	PARTICIPANT	\N	PRESENT	0
798767	797791	04045F	PARTICIPANT	\N	PRESENT	0
798768	797791	21055F	PARTICIPANT	\N	PRESENT	0
798773	797791	08028W	PARTICIPANT	\N	PRESENT	0
798813	797791	19569H	PARTICIPANT	\N	PRESENT	0
798814	797791	14038Y	PARTICIPANT	\N	PRESENT	0
798821	797791	20034V	PARTICIPANT	\N	PRESENT	0
798832	797791	20068G	PARTICIPANT	\N	PRESENT	0
798840	798638	21060C	PARTICIPANT	\N	PRESENT	0
798842	797791	19479G	PARTICIPANT	\N	PRESENT	0
798843	797791	21050A	PARTICIPANT	\N	PRESENT	0
798844	797791	19701S	PARTICIPANT	\N	PRESENT	0
798845	797791	19826F	PARTICIPANT	\N	PRESENT	0
798846	797791	14042U	PARTICIPANT	\N	PRESENT	0
798847	797791	21057H	PARTICIPANT	\N	PRESENT	0
798848	797791	19111A	PARTICIPANT	\N	PRESENT	0
798849	797791	20038A	PARTICIPANT	\N	PRESENT	0
798850	797791	14217N	PARTICIPANT	\N	PRESENT	0
798851	797791	20140W	PARTICIPANT	\N	PRESENT	0
798852	797791	14089Y	PARTICIPANT	\N	PRESENT	0
798853	797791	21064G	PARTICIPANT	\N	PRESENT	0
798854	797791	17023S	PARTICIPANT	\N	PRESENT	0
813689	813415	21078N	PARTICIPANT	\N	PRESENT	0
813690	813415	18231D	PARTICIPANT	\N	PRESENT	0
814078	813243	05008E	PARTICIPANT	\N	PRESENT	0
814079	813243	14069U	PARTICIPANT	\N	PRESENT	0
814080	813243	20080C	PARTICIPANT	\N	PRESENT	0
814081	813243	20066E	PARTICIPANT	\N	PRESENT	0
814082	813243	18231D	PARTICIPANT	\N	PRESENT	0
814083	813243	19593H	PARTICIPANT	\N	PRESENT	0
814084	813243	19745F	PARTICIPANT	\N	PRESENT	0
814085	813243	21053D	PARTICIPANT	\N	PRESENT	0
814086	813243	19679N	PARTICIPANT	\N	PRESENT	0
814087	813243	19798U	PARTICIPANT	\N	PRESENT	0
814088	813243	19703U	PARTICIPANT	\N	PRESENT	0
814089	813243	21030V	PARTICIPANT	\N	PRESENT	0
814112	814109	14213J	PARTICIPANT	\N	PRESENT	0
814113	814109	19866P	PARTICIPANT	\N	PRESENT	0
814384	810883	20024T	PARTICIPANT	\N	PRESENT	0
814385	810883	20126Y	PARTICIPANT	\N	PRESENT	0
814386	810883	19479G	PARTICIPANT	\N	PRESENT	0
814387	810883	20134Y	PARTICIPANT	\N	PRESENT	0
814388	810883	19687N	PARTICIPANT	\N	PRESENT	0
814389	810883	08011M	PARTICIPANT	\N	PRESENT	0
814390	810883	20044X	PARTICIPANT	\N	PRESENT	0
814391	810883	11040E	PARTICIPANT	\N	PRESENT	0
814392	810883	14083S	PARTICIPANT	\N	PRESENT	0
814393	810883	20070A	PARTICIPANT	\N	PRESENT	0
814394	810883	08009T	PARTICIPANT	\N	PRESENT	0
814418	814395	19699S	PARTICIPANT	\N	PRESENT	0
814419	814395	21058J	PARTICIPANT	\N	PRESENT	0
814420	814395	20102Q	PARTICIPANT	\N	PRESENT	0
814421	814395	19954N	PARTICIPANT	\N	PRESENT	0
814422	814395	21089R	PARTICIPANT	\N	PRESENT	0
814423	814395	21037D	PARTICIPANT	\N	PRESENT	0
814424	814395	20124W	PARTICIPANT	\N	PRESENT	0
814425	814395	20026V	PARTICIPANT	\N	PRESENT	0
814426	814395	21125C	PARTICIPANT	\N	PRESENT	0
814427	814395	19593H	PARTICIPANT	\N	PRESENT	0
814428	814395	20132W	PARTICIPANT	\N	PRESENT	0
814429	814395	21055F	PARTICIPANT	\N	PRESENT	0
814430	814395	14073Q	PARTICIPANT	\N	PRESENT	0
814431	814395	19611R	PRESIDENT	0	PRESENT	0
814432	814395	20142Y	PARTICIPANT	\N	PRESENT	0
814433	814395	20052X	PARTICIPANT	\N	PRESENT	0
814434	814395	20172F	PARTICIPANT	\N	PRESENT	0
814435	814395	14030Q	PARTICIPANT	\N	PRESENT	0
814436	814395	20056C	PARTICIPANT	\N	PRESENT	0
814437	814395	20180F	PARTICIPANT	\N	PRESENT	0
814438	814395	21063F	PARTICIPANT	\N	PRESENT	0
814439	814395	19735D	PARTICIPANT	\N	PRESENT	0
814440	814395	14109K	PARTICIPANT	\N	PRESENT	0
814441	814395	14123H	PARTICIPANT	\N	PRESENT	0
814442	814395	11043H	PARTICIPANT	\N	PRESENT	0
814443	814395	21077M	PARTICIPANT	\N	PRESENT	0
814459	811598	14026U	PARTICIPANT	\N	PRESENT	0
814445	814395	19621T	PARTICIPANT	\N	PRESENT	0
814448	814395	14229S	PARTICIPANT	\N	PRESENT	0
814458	811598	21094N	PARTICIPANT	\N	PRESENT	0
814460	810883	20080C	PARTICIPANT	\N	PRESENT	0
814461	810883	11074Q	PARTICIPANT	\N	PRESENT	0
814462	810883	11110B	PARTICIPANT	\N	PRESENT	0
814463	810883	07029T	PARTICIPANT	\N	PRESENT	0
814464	810883	21090J	PARTICIPANT	\N	PRESENT	0
814465	810883	21048G	PARTICIPANT	\N	PRESENT	0
814466	810883	08034U	PARTICIPANT	\N	PRESENT	0
814467	810883	20050V	PARTICIPANT	\N	PRESENT	0
814468	810883	21041Y	PARTICIPANT	\N	PRESENT	0
814469	810883	21072G	PARTICIPANT	\N	PRESENT	0
814471	811598	14042U	PARTICIPANT	\N	PRESENT	0
814474	814473	10015M	PARTICIPANT	\N	PRESENT	0
814476	814475	10015M	PARTICIPANT	\N	PRESENT	0
814487	810883	20094J	PARTICIPANT	\N	PRESENT	0
814488	813342	14327T	PARTICIPANT	\N	PRESENT	0
814489	813342	20086J	PARTICIPANT	\N	PRESENT	0
814490	813342	11053K	PARTICIPANT	\N	PRESENT	0
814491	813342	20080C	PARTICIPANT	\N	PRESENT	0
814492	813342	19667J	PARTICIPANT	\N	PRESENT	0
814493	813342	11074Q	PARTICIPANT	\N	PRESENT	0
814494	813342	20094J	PARTICIPANT	\N	PRESENT	0
814495	813342	14225N	PRESIDENT	0	PRESENT	0
814496	813342	11110B	PARTICIPANT	\N	PRESENT	0
814497	813342	07029T	PARTICIPANT	\N	PRESENT	0
814498	813342	19573D	PARTICIPANT	\N	PRESENT	0
814499	813342	21079P	PARTICIPANT	\N	PRESENT	0
814500	813342	07004J	PARTICIPANT	\N	PRESENT	0
814501	813342	19349W	PARTICIPANT	\N	PRESENT	0
814502	813342	08010L	PARTICIPANT	\N	PRESENT	0
814503	813342	14253S	PARTICIPANT	\N	PRESENT	0
814504	813342	20116W	PARTICIPANT	\N	PRESENT	0
814505	813342	21090J	PARTICIPANT	\N	PRESENT	0
814506	813342	19335Q	PARTICIPANT	\N	PRESENT	0
814507	813342	20024T	PARTICIPANT	\N	PRESENT	0
814508	813342	20126Y	PARTICIPANT	\N	PRESENT	0
814509	813342	21048G	PARTICIPANT	\N	PRESENT	0
814510	813342	11048N	PARTICIPANT	\N	PRESENT	0
814511	813342	19479G	PARTICIPANT	\N	PRESENT	0
814512	813342	20134Y	PARTICIPANT	\N	PRESENT	0
814513	813342	19711U	PARTICIPANT	\N	PRESENT	0
814514	813342	08034U	PARTICIPANT	\N	PRESENT	0
814515	813342	19687N	PARTICIPANT	\N	PRESENT	0
814516	813342	20050V	PARTICIPANT	\N	PRESENT	0
814517	813342	08011M	PARTICIPANT	\N	PRESENT	0
814518	813342	20044X	PARTICIPANT	\N	PRESENT	0
814519	813342	19399H	PARTICIPANT	\N	PRESENT	0
814520	813342	21041Y	PARTICIPANT	\N	PRESENT	0
814521	813342	11040E	PARTICIPANT	\N	PRESENT	0
814522	813342	14083S	PARTICIPANT	\N	PRESENT	0
814523	813342	20070A	PARTICIPANT	\N	PRESENT	0
814524	813342	08009T	PARTICIPANT	\N	PRESENT	0
814525	813342	21069M	PARTICIPANT	\N	PRESENT	0
814526	813342	14121F	PARTICIPANT	\N	PRESENT	0
814527	813342	21072G	PARTICIPANT	\N	PRESENT	0
814528	814132	17229F	PARTICIPANT	\N	PRESENT	0
814529	813206	19729F	PARTICIPANT	\N	EXCUSE	0
814530	813206	19585H	PARTICIPANT	\N	EXCUSE	0
814531	813206	19673G	PARTICIPANT	\N	EXCUSE	0
814532	814365	19383Y	PARTICIPANT	\N	PRESENT	0
814533	814365	19768N	PARTICIPANT	\N	PRESENT	0
814534	814365	20092G	PARTICIPANT	\N	PRESENT	0
814535	814365	19782L	PARTICIPANT	\N	PRESENT	0
814536	814365	14357A	PARTICIPANT	\N	PRESENT	0
814537	814365	20078J	PARTICIPANT	\N	PRESENT	0
814538	814365	19413M	PARTICIPANT	\N	PRESENT	0
814539	814365	20082E	PARTICIPANT	\N	PRESENT	0
814540	814365	14221J	PARTICIPANT	\N	PRESENT	0
814541	814365	20104S	PARTICIPANT	\N	PRESENT	0
814542	814365	19631V	PARTICIPANT	\N	PRESENT	0
814543	814365	08015R	PARTICIPANT	\N	PRESENT	0
814544	814365	19575F	PARTICIPANT	\N	PRESENT	0
814545	814365	20018V	PARTICIPANT	\N	PRESENT	0
814546	814365	19563B	PARTICIPANT	\N	PRESENT	0
814547	814365	21096Q	PARTICIPANT	\N	PRESENT	0
814548	814365	21050A	PARTICIPANT	\N	PRESENT	0
814549	814365	14038Y	PARTICIPANT	\N	PRESENT	0
814550	814365	21054E	PARTICIPANT	\N	PRESENT	0
814551	814365	14187A	PRESIDENT	0	PRESENT	0
814552	814365	21075K	PARTICIPANT	\N	PRESENT	0
814553	814365	20038A	PARTICIPANT	\N	PRESENT	0
814554	814365	21083K	PARTICIPANT	\N	PRESENT	0
814555	814365	20144B	PARTICIPANT	\N	PRESENT	0
814556	814365	19695N	PARTICIPANT	\N	PRESENT	0
814557	814365	14033T	PARTICIPANT	\N	PRESENT	0
814558	814365	21093M	PARTICIPANT	\N	PRESENT	0
814559	814365	11090Q	PARTICIPANT	\N	PRESENT	0
814560	814365	20054A	PARTICIPANT	\N	PRESENT	0
814561	814365	20060X	PARTICIPANT	\N	PRESENT	0
814562	814365	19507S	PARTICIPANT	\N	PRESENT	0
814563	814365	21066J	PARTICIPANT	\N	PRESENT	0
814564	814365	20286Q	PARTICIPANT	\N	PRESENT	0
814565	814365	14207L	PARTICIPANT	\N	PRESENT	0
814566	814365	14257W	PARTICIPANT	\N	PRESENT	0
814567	814365	20084G	PARTICIPANT	\N	PRESENT	0
814568	814365	14205J	PARTICIPANT	\N	EXCUSE	0
814569	814365	21052C	PARTICIPANT	\N	EXCUSE	0
814570	814365	20088L	PARTICIPANT	\N	EXCUSE	0
814571	811598	19866P	PARTICIPANT	\N	PRESENT	0
814572	814395	08012N	PARTICIPANT	\N	PRESENT	0
814581	813206	20074E	PARTICIPANT	\N	PRESENT	0
814582	813206	21057H	PARTICIPANT	\N	PRESENT	0
814583	813206	04047H	PRESIDENT	0	PRESENT	0
814584	813206	05008E	PARTICIPANT	\N	PRESENT	0
814585	813206	14231L	PARTICIPANT	\N	PRESENT	0
797280	790371	20024T	PARTICIPANT	\N	PRESENT	0
797281	790371	19954N	PARTICIPANT	\N	PRESENT	0
797282	790371	20114U	PARTICIPANT	\N	PRESENT	0
797283	790371	14215L	PARTICIPANT	\N	PRESENT	0
797284	790371	14281W	PARTICIPANT	\N	PRESENT	0
797285	790371	14026U	PARTICIPANT	\N	PRESENT	0
797286	790371	19691J	PARTICIPANT	\N	PRESENT	0
797287	790371	07029T	PARTICIPANT	\N	PRESENT	0
797288	790371	21087P	PARTICIPANT	\N	PRESENT	0
797289	790371	19657G	PARTICIPANT	\N	PRESENT	0
797290	790371	14071N	PARTICIPANT	\N	PRESENT	0
797291	790371	21039F	PARTICIPANT	\N	PRESENT	0
797292	790371	08047A	PARTICIPANT	\N	PRESENT	0
797293	790371	19745F	PARTICIPANT	\N	PRESENT	0
797294	790371	19349W	PARTICIPANT	\N	PRESENT	0
797295	790371	21068L	PARTICIPANT	\N	PRESENT	0
797296	790371	19798U	PARTICIPANT	\N	PRESENT	0
797297	790371	04045F	PARTICIPANT	\N	PRESENT	0
797298	790371	19713W	PARTICIPANT	\N	PRESENT	0
799692	799691	20112S	PARTICIPANT	\N	PRESENT	0
799693	799691	19954N	PARTICIPANT	\N	PRESENT	0
799694	799691	14030Q	PARTICIPANT	\N	PRESENT	0
799695	799691	20138D	PARTICIPANT	\N	PRESENT	0
799696	799691	19621T	PARTICIPANT	\N	PRESENT	0
799697	799691	21089R	PARTICIPANT	\N	PRESENT	0
799698	799691	21063F	PARTICIPANT	\N	PRESENT	0
799699	799691	20264J	PARTICIPANT	\N	PRESENT	0
799700	799691	18395Y	PARTICIPANT	\N	PRESENT	0
799701	799691	19693L	PARTICIPANT	\N	PRESENT	0
799702	799691	21074J	PARTICIPANT	\N	PRESENT	0
799703	799691	20124W	PARTICIPANT	\N	PRESENT	0
799704	799691	21091K	PARTICIPANT	\N	PRESENT	0
799705	799691	20132W	PARTICIPANT	\N	PRESENT	0
799706	799691	20172F	PARTICIPANT	\N	PRESENT	0
799707	799691	20180F	PARTICIPANT	\N	PRESENT	0
799708	799691	14123H	PARTICIPANT	\N	PRESENT	0
799709	799691	20056C	PARTICIPANT	\N	PRESENT	0
799710	799691	20048C	PARTICIPANT	\N	PRESENT	0
799711	799691	14021P	PARTICIPANT	\N	PRESENT	0
799712	799691	14073Q	PARTICIPANT	\N	PRESENT	0
799713	799691	19611R	PRESIDENT	0	PRESENT	0
799714	799691	20102Q	PARTICIPANT	\N	PRESENT	0
801302	801301	19673G	PARTICIPANT	\N	PRESENT	0
799716	799691	19735D	PARTICIPANT	\N	PRESENT	0
799717	799691	19699S	PARTICIPANT	\N	PRESENT	0
799718	799691	20052X	PARTICIPANT	\N	PRESENT	0
799719	799691	08012N	PARTICIPANT	\N	PRESENT	0
799720	799691	20142Y	PARTICIPANT	\N	PRESENT	0
799721	799691	21058J	PARTICIPANT	\N	PRESENT	0
799722	799691	14109K	PARTICIPANT	\N	EXCUSE	0
799723	799691	21037D	PARTICIPANT	\N	PRESENT	0
799724	799691	19593H	PARTICIPANT	\N	PRESENT	0
799725	799691	21055F	PARTICIPANT	\N	PRESENT	0
799726	799691	19533U	PARTICIPANT	\N	PRESENT	0
799727	799691	04033B	PARTICIPANT	\N	PRESENT	0
799728	799691	14229S	PARTICIPANT	\N	PRESENT	0
799730	799691	21059K	PARTICIPANT	\N	PRESENT	0
799732	799691	11043H	PARTICIPANT	\N	PRESENT	0
799733	799691	20026V	PARTICIPANT	\N	PRESENT	0
799735	799691	21077M	PARTICIPANT	\N	PRESENT	0
801303	801301	14231L	PARTICIPANT	\N	PRESENT	0
799737	799691	20058E	PARTICIPANT	\N	PRESENT	0
801304	801301	19489J	PARTICIPANT	\N	PRESENT	0
801305	801301	19649G	PARTICIPANT	\N	PRESENT	0
801307	801306	19673G	PARTICIPANT	\N	PRESENT	0
801308	801306	14231L	PARTICIPANT	\N	PRESENT	0
801309	801306	19489J	PARTICIPANT	\N	PRESENT	0
801338	801284	21094N	PARTICIPANT	\N	PRESENT	0
801317	801315	11090Q	PARTICIPANT	\N	PRESENT	0
801318	801315	19695N	PARTICIPANT	\N	PRESENT	0
801339	801285	21071F	PARTICIPANT	\N	PRESENT	0
801321	801319	11090Q	PARTICIPANT	\N	PRESENT	0
801322	801319	19695N	PARTICIPANT	\N	PRESENT	0
801341	801340	20098N	PARTICIPANT	\N	PRESENT	1
801343	801342	20098N	PARTICIPANT	\N	PRESENT	1
801326	801324	11090Q	PARTICIPANT	\N	PRESENT	0
801327	801324	19695N	PARTICIPANT	\N	PRESENT	0
801344	801342	19749K	PARTICIPANT	\N	PRESENT	1
803892	801373	19768N	PARTICIPANT	\N	PRESENT	0
801331	801329	11090Q	PARTICIPANT	\N	PRESENT	0
807441	807005	20022R	PARTICIPANT	\N	PRESENT	0
807721	807176	14231L	PARTICIPANT	\N	PRESENT	0
801335	801333	11090Q	PARTICIPANT	\N	PRESENT	0
807722	807176	21088Q	PARTICIPANT	\N	PRESENT	0
807723	807176	14215L	PARTICIPANT	\N	PRESENT	0
807724	807176	21043B	PARTICIPANT	\N	PRESENT	0
807725	807176	19573D	PARTICIPANT	\N	PRESENT	0
807726	807176	10015M	PARTICIPANT	\N	PRESENT	0
807727	807176	08015R	PARTICIPANT	\N	PRESENT	0
807731	807176	20056C	PARTICIPANT	\N	PRESENT	0
807733	807176	14026U	PARTICIPANT	\N	PRESENT	0
807734	807176	19565D	PARTICIPANT	\N	PRESENT	0
807738	807732	14205J	PARTICIPANT	\N	PRESENT	0
807739	807732	14033T	PARTICIPANT	\N	PRESENT	0
807740	807732	08028W	PARTICIPANT	\N	PRESENT	0
807741	807732	11090Q	PARTICIPANT	\N	PRESENT	0
807742	807732	20054A	PARTICIPANT	\N	PRESENT	0
807743	807176	04047H	PARTICIPANT	\N	PRESENT	0
807744	807176	19631V	PARTICIPANT	\N	PRESENT	0
807745	807176	14030Q	PARTICIPANT	\N	PRESENT	0
807746	807176	14069U	PARTICIPANT	\N	PRESENT	0
807747	807176	20054A	PARTICIPANT	\N	PRESENT	0
807748	807176	21040X	PARTICIPANT	\N	PRESENT	0
807749	807176	19563B	PARTICIPANT	\N	PRESENT	0
807750	807176	19507S	PARTICIPANT	\N	PRESENT	0
807751	807176	08061X	PARTICIPANT	\N	PRESENT	0
807752	807176	20108W	PARTICIPANT	\N	PRESENT	0
807753	807176	21057H	PARTICIPANT	\N	PRESENT	0
807754	807176	19745F	PARTICIPANT	\N	PRESENT	0
807756	807755	20022R	PARTICIPANT	\N	PRESENT	0
807757	807176	19749K	PARTICIPANT	\N	PRESENT	0
807758	807755	21063F	PARTICIPANT	\N	PRESENT	0
807759	807755	14207L	PARTICIPANT	\N	PRESENT	0
807760	807755	14357A	PARTICIPANT	\N	PRESENT	0
807761	807755	21086N	PARTICIPANT	\N	PRESENT	0
807762	807755	20120S	PARTICIPANT	\N	PRESENT	0
807763	807755	21044C	PARTICIPANT	\N	PRESENT	0
807764	807755	20126Y	PARTICIPANT	\N	PRESENT	0
807765	807755	19723Y	PARTICIPANT	\N	PRESENT	0
807766	807755	08015R	PARTICIPANT	\N	PRESENT	0
807767	807755	14147R	PARTICIPANT	\N	PRESENT	0
807768	807755	20096L	PARTICIPANT	\N	PRESENT	0
807769	807755	21047F	PARTICIPANT	\N	PRESENT	0
807770	807755	21064G	PARTICIPANT	\N	PRESENT	0
807772	807176	21063F	PARTICIPANT	\N	PRESENT	0
807773	807176	18083K	PARTICIPANT	\N	PRESENT	0
807774	807176	19533U	PARTICIPANT	\N	PRESENT	0
807775	807176	20112S	PARTICIPANT	\N	PRESENT	0
807804	807176	08028W	PARTICIPANT	\N	PRESENT	0
807826	807176	20076G	PARTICIPANT	\N	PRESENT	0
807806	807771	08034U	PARTICIPANT	\N	PRESENT	0
807807	807771	20126Y	PARTICIPANT	\N	PRESENT	0
807808	807176	21056G	PARTICIPANT	\N	PRESENT	0
807809	797761	14205J	PARTICIPANT	\N	PRESENT	0
807810	797761	14033T	PARTICIPANT	\N	PRESENT	0
807812	807811	14033T	PARTICIPANT	\N	PRESENT	0
807813	807811	14205J	PARTICIPANT	\N	PRESENT	0
807814	807176	19649G	PARTICIPANT	\N	PRESENT	0
807816	807815	14205J	PARTICIPANT	\N	PRESENT	0
807817	807176	19629C	PARTICIPANT	\N	PRESENT	0
807818	807815	14033T	PARTICIPANT	\N	PRESENT	0
807819	807176	21061D	PARTICIPANT	\N	PRESENT	0
807820	807176	21066J	PARTICIPANT	\N	PRESENT	0
807821	807771	19647E	PARTICIPANT	\N	PRESENT	0
807822	807176	20086J	PARTICIPANT	\N	PRESENT	0
807823	807176	14187A	PARTICIPANT	\N	PRESENT	0
807824	807176	14073Q	PARTICIPANT	\N	PRESENT	0
807825	807176	19954N	PARTICIPANT	\N	PRESENT	0
807827	807176	18231D	PARTICIPANT	\N	PRESENT	0
807835	807176	19723Y	PARTICIPANT	\N	PRESENT	0
807841	807771	14173T	PARTICIPANT	\N	PRESENT	0
807842	807771	07029T	PARTICIPANT	\N	EXCUSE	0
807843	807176	21044C	PARTICIPANT	\N	PRESENT	0
807844	807771	20116W	PARTICIPANT	\N	EXCUSE	0
807845	807176	21085M	PARTICIPANT	\N	PRESENT	0
807846	807176	19335Q	PARTICIPANT	\N	PRESENT	0
807847	807411	19611R	PRESIDENT	0	PRESENT	0
807848	807411	14030Q	PARTICIPANT	\N	PRESENT	0
807849	807411	19533U	PARTICIPANT	\N	PRESENT	0
807850	807411	14123H	PARTICIPANT	\N	PRESENT	0
807851	807411	19621T	PARTICIPANT	\N	PRESENT	0
817108	815935	14147R	PARTICIPANT	\N	PRESENT	0
817109	815935	21085M	PARTICIPANT	\N	PRESENT	0
817110	815935	04092N	PARTICIPANT	\N	PRESENT	0
817111	815935	19679N	PARTICIPANT	\N	PRESENT	0
817112	815935	19703U	PARTICIPANT	\N	PRESENT	0
817113	815935	20124W	PARTICIPANT	\N	PRESENT	0
817114	815935	14217N	PARTICIPANT	\N	PRESENT	0
817115	815935	11048N	PARTICIPANT	\N	PRESENT	0
817116	815935	21044C	PARTICIPANT	\N	PRESENT	0
817117	815935	20092G	PARTICIPANT	\N	PRESENT	0
817118	815935	14026U	PARTICIPANT	\N	PRESENT	0
817119	815935	20138D	PARTICIPANT	\N	PRESENT	0
817120	815935	19723Y	PARTICIPANT	\N	PRESENT	0
817121	815935	20038A	PARTICIPANT	\N	PRESENT	0
817122	815935	07029T	PARTICIPANT	\N	PRESENT	0
817123	815935	20070A	PARTICIPANT	\N	PRESENT	0
817124	815935	20066E	PARTICIPANT	\N	PRESENT	0
817126	817125	04033B	PARTICIPANT	\N	PRESENT	0
817127	817125	19647E	PARTICIPANT	\N	PRESENT	0
817128	817125	17367Q	PARTICIPANT	\N	PRESENT	0
817129	817125	17737W	PARTICIPANT	\N	PRESENT	0
817130	817125	14089Y	PARTICIPANT	\N	PRESENT	0
817131	817125	21029D	PARTICIPANT	\N	PRESENT	0
817132	817125	20056C	PARTICIPANT	\N	PRESENT	0
817133	815935	20172F	PARTICIPANT	\N	PRESENT	0
817134	817125	19545Y	PARTICIPANT	\N	PRESENT	0
817135	817125	14357A	PARTICIPANT	\N	PRESENT	0
817136	817125	19673G	PARTICIPANT	\N	PRESENT	0
817137	817125	20038A	PARTICIPANT	\N	PRESENT	0
817138	817125	14147R	PARTICIPANT	\N	PRESENT	0
817139	817125	08034U	PARTICIPANT	\N	PRESENT	0
817140	817125	08015R	PARTICIPANT	\N	PRESENT	0
817141	817125	10015M	PARTICIPANT	\N	PRESENT	0
817142	817125	14169X	PARTICIPANT	\N	PRESENT	0
817143	817125	04070G	PARTICIPANT	\N	PRESENT	0
817144	815935	20058E	PARTICIPANT	\N	PRESENT	0
817145	815935	21045D	PARTICIPANT	\N	PRESENT	0
817168	816824	19683J	PARTICIPANT	\N	PRESENT	0
817169	816824	14213J	PARTICIPANT	\N	PRESENT	0
817218	817173	14195A	PARTICIPANT	\N	PRESENT	0
817219	817173	19367Y	PARTICIPANT	\N	PRESENT	0
817220	817173	19758L	PARTICIPANT	\N	PRESENT	0
817221	817173	19760E	PARTICIPANT	\N	PRESENT	0
817222	817146	08011M	PARTICIPANT	\N	PRESENT	0
817223	817173	14217N	PARTICIPANT	\N	PRESENT	0
817224	817173	21046E	PARTICIPANT	\N	PRESENT	0
817225	817173	19866P	PARTICIPANT	\N	PRESENT	0
817226	817173	14042U	PARTICIPANT	\N	PRESENT	0
817227	817173	08045X	PARTICIPANT	\N	EXCUSE	0
817228	817173	19691J	PARTICIPANT	\N	PRESENT	0
817229	817173	19569H	PARTICIPANT	\N	PRESENT	0
817230	817173	14213J	PARTICIPANT	\N	PRESENT	0
817231	817173	19683J	PARTICIPANT	\N	PRESENT	0
817232	817173	21081H	PARTICIPANT	\N	PRESENT	0
817233	817173	19723Y	PARTICIPANT	\N	PRESENT	0
817234	817173	14223L	PARTICIPANT	\N	PRESENT	0
817235	817173	04092N	PARTICIPANT	\N	PRESENT	0
817236	817173	14071N	PRESIDENT	0	PRESENT	0
817237	817173	20096L	PARTICIPANT	\N	PRESENT	0
817238	817173	20130U	PARTICIPANT	\N	EXCUSE	0
817239	817173	19679N	PARTICIPANT	\N	PRESENT	0
817240	817173	19703U	PARTICIPANT	\N	PRESENT	0
817241	817173	19713W	PARTICIPANT	\N	PRESENT	0
817242	817173	21094N	PARTICIPANT	\N	EXCUSE	0
817243	817173	19553Y	PARTICIPANT	\N	PRESENT	0
817244	817173	21045D	PARTICIPANT	\N	PRESENT	0
817245	817173	17965H	PARTICIPANT	\N	PRESENT	0
817250	817173	21039F	PARTICIPANT	\N	PRESENT	0
817251	817173	21049H	PARTICIPANT	\N	PRESENT	0
817252	817173	19657G	PARTICIPANT	\N	PRESENT	0
817253	817173	14026U	PARTICIPANT	\N	PRESENT	0
817286	817173	18193Q	PARTICIPANT	\N	PRESENT	0
817287	817173	20090E	PARTICIPANT	\N	PRESENT	0
817288	817173	11045K	PARTICIPANT	\N	PRESENT	0
817294	817173	08061X	PARTICIPANT	\N	PRESENT	0
817296	817295	14151M	PARTICIPANT	\N	PRESENT	0
817297	817295	07033P	PARTICIPANT	\N	PRESENT	0
817298	817295	20144B	PARTICIPANT	\N	PRESENT	0
817299	817295	14225N	PARTICIPANT	\N	PRESENT	0
817300	817173	19629C	PARTICIPANT	\N	PRESENT	0
817301	817295	21059K	PARTICIPANT	\N	PRESENT	0
817302	817295	21035B	PARTICIPANT	\N	PRESENT	0
817303	817295	18231D	PARTICIPANT	\N	PRESENT	0
817304	817295	20048C	PARTICIPANT	\N	PRESENT	0
817305	817295	14147R	PARTICIPANT	\N	PRESENT	0
817306	817295	14133K	PARTICIPANT	\N	PRESENT	0
817307	817295	21054E	PARTICIPANT	\N	PRESENT	0
817313	817173	17779H	PARTICIPANT	\N	PRESENT	0
817314	817173	20140W	PARTICIPANT	\N	PRESENT	0
817318	817173	21087P	PARTICIPANT	\N	PRESENT	0
817319	817173	20248J	PARTICIPANT	\N	PRESENT	0
817320	817173	01034P	PARTICIPANT	\N	PRESENT	0
817322	817173	14281W	PARTICIPANT	\N	PRESENT	0
817393	814470	20172F	PARTICIPANT	\N	PRESENT	0
817394	814470	04070G	PARTICIPANT	\N	PRESENT	0
817395	817183	19723Y	PARTICIPANT	\N	PRESENT	0
817396	817183	14223L	PARTICIPANT	\N	PRESENT	0
817397	817183	04092N	PARTICIPANT	\N	PRESENT	0
817398	817183	14071N	PRESIDENT	\N	PRESENT	0
817400	817183	19569H	PARTICIPANT	\N	PRESENT	0
817401	817183	14213J	PARTICIPANT	\N	PRESENT	0
817402	817183	08061X	PARTICIPANT	\N	PRESENT	0
817403	817183	19683J	PARTICIPANT	\N	PRESENT	0
817404	817183	21081H	PARTICIPANT	\N	PRESENT	0
817405	817183	19866P	PARTICIPANT	\N	PRESENT	0
817406	817183	14042U	PARTICIPANT	\N	PRESENT	0
817407	817183	08045X	PARTICIPANT	\N	EXCUSE	0
817408	817183	19691J	PARTICIPANT	\N	PRESENT	0
817409	817183	19760E	PARTICIPANT	\N	PRESENT	0
817410	817183	18193Q	PARTICIPANT	\N	PRESENT	0
817411	817183	14217N	PARTICIPANT	\N	PRESENT	0
817412	817183	20090E	PARTICIPANT	\N	PRESENT	0
817413	817183	21046E	PARTICIPANT	\N	PRESENT	0
817414	817183	11045K	PARTICIPANT	\N	PRESENT	0
817415	817183	17779H	PARTICIPANT	\N	PRESENT	0
817416	817183	21039F	PARTICIPANT	\N	PRESENT	0
817417	817183	20140W	PARTICIPANT	\N	PRESENT	0
817418	817183	21049H	PARTICIPANT	\N	PRESENT	0
817419	817183	19657G	PARTICIPANT	\N	PRESENT	0
817420	817183	17965H	PARTICIPANT	\N	PRESENT	0
817421	817183	19713W	PARTICIPANT	\N	PRESENT	0
817422	817183	21094N	PARTICIPANT	\N	EXCUSE	0
817423	817183	19553Y	PARTICIPANT	\N	PRESENT	0
817424	817183	21045D	PARTICIPANT	\N	PRESENT	0
817425	817183	20096L	PARTICIPANT	\N	PRESENT	0
817426	817183	20130U	PARTICIPANT	\N	EXCUSE	0
817427	817183	19679N	PARTICIPANT	\N	PRESENT	0
817428	817183	19703U	PRESIDENT	1	PRESENT	0
817429	817183	14281W	PARTICIPANT	\N	PRESENT	0
817430	817183	14026U	PARTICIPANT	\N	PRESENT	0
817431	817183	21087P	PARTICIPANT	\N	PRESENT	0
817432	817183	20248J	PARTICIPANT	\N	PRESENT	0
817433	817183	01034P	PARTICIPANT	\N	PRESENT	0
817434	817183	14195A	PARTICIPANT	\N	PRESENT	0
817435	817183	19367Y	PARTICIPANT	\N	PRESENT	0
817436	817183	19758L	PARTICIPANT	\N	PRESENT	0
817437	817255	19383Y	PARTICIPANT	\N	PRESENT	0
817438	817255	19768N	PARTICIPANT	\N	PRESENT	0
817439	817255	20092G	PARTICIPANT	\N	PRESENT	0
817440	817255	19782L	PARTICIPANT	\N	PRESENT	0
817441	817255	14357A	PARTICIPANT	\N	PRESENT	0
817442	817255	20078J	PARTICIPANT	\N	PRESENT	0
817443	817255	20082E	PARTICIPANT	\N	PRESENT	0
817444	817255	19631V	PARTICIPANT	\N	PRESENT	0
817445	817255	20104S	PARTICIPANT	\N	PRESENT	0
817446	817255	08015R	PARTICIPANT	\N	PRESENT	0
817447	817255	19575F	PARTICIPANT	\N	PRESENT	0
817448	817255	20018V	PARTICIPANT	\N	PRESENT	0
817449	817255	19563B	PARTICIPANT	\N	PRESENT	0
817450	817255	21050A	PARTICIPANT	\N	PRESENT	0
817451	817255	20028X	PARTICIPANT	\N	PRESENT	0
817452	817255	20030R	PARTICIPANT	\N	PRESENT	0
817453	817255	14038Y	PARTICIPANT	\N	PRESENT	0
817454	817255	20034V	PARTICIPANT	\N	PRESENT	0
817455	817255	21054E	PARTICIPANT	\N	PRESENT	0
817456	817255	14187A	PRESIDENT	0	PRESENT	0
817457	817255	20038A	PARTICIPANT	\N	PRESENT	0
817458	817255	21083K	PARTICIPANT	\N	PRESENT	0
817459	817255	20144B	PARTICIPANT	\N	PRESENT	0
817460	817255	21086N	PARTICIPANT	\N	PRESENT	0
798855	797791	20090E	PARTICIPANT	\N	PRESENT	0
798856	797791	19954N	PARTICIPANT	\N	PRESENT	0
798857	797791	20124W	PARTICIPANT	\N	PRESENT	0
798858	797791	19703U	PARTICIPANT	\N	PRESENT	0
798859	797791	19575F	PARTICIPANT	\N	PRESENT	0
798860	797791	20136B	PARTICIPANT	\N	PRESENT	0
798861	797791	20030R	PARTICIPANT	\N	PRESENT	0
798862	797791	14031R	PARTICIPANT	\N	PRESENT	0
798863	797791	21048G	PARTICIPANT	\N	PRESENT	0
798864	797791	20098N	PARTICIPANT	\N	PRESENT	0
798865	797791	20058E	PARTICIPANT	\N	PRESENT	0
798866	797791	08056B	PARTICIPANT	\N	PRESENT	0
798867	797791	19649G	PARTICIPANT	\N	PRESENT	0
798868	797791	20048C	PARTICIPANT	\N	PRESENT	0
798869	797791	21081H	PARTICIPANT	\N	PRESENT	0
798870	797791	11056N	PARTICIPANT	\N	PRESENT	0
798871	797791	08018U	PARTICIPANT	\N	PRESENT	0
798872	797791	07029T	PARTICIPANT	\N	PRESENT	0
798873	797791	19709B	PARTICIPANT	\N	PRESENT	0
798874	797791	20110Q	PARTICIPANT	\N	PRESENT	0
798875	797791	21087P	PARTICIPANT	\N	PRESENT	0
798876	797791	08061X	PARTICIPANT	\N	PRESENT	0
798953	797792	08018U	PARTICIPANT	\N	PRESENT	0
798954	797792	11056N	PARTICIPANT	\N	PRESENT	0
798955	797792	21084L	PARTICIPANT	\N	PRESENT	0
798956	797792	20088L	PARTICIPANT	\N	PRESENT	0
798957	797792	20030R	PARTICIPANT	\N	PRESENT	0
798958	797792	21045D	PARTICIPANT	\N	PRESENT	0
798959	797792	21057H	PARTICIPANT	\N	PRESENT	0
798960	797792	19551W	PARTICIPANT	\N	PRESENT	0
798961	797792	20092G	PARTICIPANT	\N	PRESENT	0
798962	797792	20110Q	PARTICIPANT	\N	PRESENT	0
798963	797792	20100N	PARTICIPANT	\N	PRESENT	0
798964	797792	19782L	PARTICIPANT	\N	PRESENT	0
798965	797792	21043B	PARTICIPANT	\N	PRESENT	0
798966	797792	21048G	PARTICIPANT	\N	PRESENT	0
798967	797792	19649G	PARTICIPANT	\N	PRESENT	0
798968	797792	20022R	PARTICIPANT	\N	PRESENT	0
798969	797792	21070E	PARTICIPANT	\N	PRESENT	0
798970	797792	20134Y	PARTICIPANT	\N	PRESENT	0
798971	797792	20048C	PARTICIPANT	\N	PRESENT	0
798972	797792	19111A	PARTICIPANT	\N	PRESENT	0
798973	797792	21064G	PARTICIPANT	\N	PRESENT	0
798974	797792	19826F	PARTICIPANT	\N	PRESENT	0
798975	797792	21053D	PARTICIPANT	\N	PRESENT	0
798976	797792	19553Y	PARTICIPANT	\N	PRESENT	0
798977	797792	15197G	PARTICIPANT	\N	PRESENT	0
798978	797792	20106U	PARTICIPANT	\N	PRESENT	0
798979	797792	21044C	PARTICIPANT	\N	PRESENT	0
798980	797792	21055F	PARTICIPANT	\N	PRESENT	0
798981	797792	21068L	PARTICIPANT	\N	PRESENT	0
798982	797792	21058J	PARTICIPANT	\N	PRESENT	0
798983	797792	20068G	PARTICIPANT	\N	PRESENT	0
798984	797792	21047F	PARTICIPANT	\N	PRESENT	0
798985	797792	20038A	PARTICIPANT	\N	PRESENT	0
798986	797792	19709B	PARTICIPANT	\N	PRESENT	0
798987	797792	14033T	PARTICIPANT	\N	PRESENT	0
798988	797792	20026V	PARTICIPANT	\N	PRESENT	0
798989	797792	14031R	PARTICIPANT	\N	PRESENT	0
798990	797792	07029T	PARTICIPANT	\N	PRESENT	0
798991	797792	20056C	PARTICIPANT	\N	PRESENT	0
798992	797792	19954N	PARTICIPANT	\N	PRESENT	0
798993	797792	21081H	PARTICIPANT	\N	PRESENT	0
798994	797792	20140W	PARTICIPANT	\N	PRESENT	0
798995	797792	19768N	PARTICIPANT	\N	PRESENT	0
798996	797792	19383Y	PARTICIPANT	\N	PRESENT	0
798997	797792	11090Q	PARTICIPANT	\N	PRESENT	0
798998	797792	08028W	PARTICIPANT	\N	PRESENT	0
798999	797792	05008E	PARTICIPANT	\N	PRESENT	0
799000	797792	08056B	PARTICIPANT	\N	PRESENT	0
799001	797792	21090J	PARTICIPANT	\N	PRESENT	0
799002	797792	19703U	PARTICIPANT	\N	PRESENT	0
799003	797792	19575F	PARTICIPANT	\N	PRESENT	0
799004	797792	18083K	PARTICIPANT	\N	PRESENT	0
799005	797792	08015R	PARTICIPANT	\N	PRESENT	0
799006	797792	14026U	PARTICIPANT	\N	PRESENT	0
799007	797792	21095P	PARTICIPANT	\N	PRESENT	0
799008	797792	20020P	PARTICIPANT	\N	PRESENT	0
799009	797792	21039F	PARTICIPANT	\N	PRESENT	0
799010	797792	14151M	PARTICIPANT	\N	PRESENT	0
799011	797792	19758L	PARTICIPANT	\N	PRESENT	0
799012	797792	19399H	PARTICIPANT	\N	PRESENT	0
799013	797792	19679N	PARTICIPANT	\N	PRESENT	0
799015	797792	20082E	PARTICIPANT	\N	PRESENT	0
799016	797792	20114U	PARTICIPANT	\N	PRESENT	0
799017	797792	21076L	PARTICIPANT	\N	PRESENT	0
799018	797792	20098N	PARTICIPANT	\N	PRESENT	0
799019	797792	21082J	PARTICIPANT	\N	PRESENT	0
799020	797792	20032T	PARTICIPANT	\N	PRESENT	0
799022	797792	20090E	PARTICIPANT	\N	PRESENT	0
799023	797792	14215L	PARTICIPANT	\N	PRESENT	0
799025	797792	21061D	PARTICIPANT	\N	PRESENT	0
799026	797792	19563B	PARTICIPANT	\N	PRESENT	0
799030	797792	20040T	PARTICIPANT	\N	PRESENT	0
799031	797792	14213J	PARTICIPANT	\N	PRESENT	0
799032	797792	21085M	PARTICIPANT	\N	PRESENT	0
798951	797792	14259Y	PARTICIPANT	\N	PRESENT	0
798952	797792	20136B	PARTICIPANT	\N	PRESENT	0
799033	797792	19629C	PARTICIPANT	\N	PRESENT	0
799034	797792	11053K	PARTICIPANT	\N	PRESENT	0
799035	797792	20124W	PARTICIPANT	\N	PRESENT	0
799036	797792	14069U	PARTICIPANT	\N	PRESENT	0
799037	797792	20024T	PARTICIPANT	\N	PRESENT	0
799038	797792	14083S	PARTICIPANT	\N	PRESENT	0
799039	797792	07004J	PARTICIPANT	\N	PRESENT	0
799040	797792	20042V	PARTICIPANT	\N	PRESENT	0
799041	797792	20044X	PARTICIPANT	\N	PRESENT	0
799042	797792	18207D	PARTICIPANT	\N	PRESENT	0
799043	797792	21079P	PARTICIPANT	\N	PRESENT	0
799044	797792	19701S	PARTICIPANT	\N	PRESENT	0
799045	797792	14219Q	PARTICIPANT	\N	PRESENT	0
799046	797792	14147R	PARTICIPANT	\N	PRESENT	0
799047	797792	20086J	PARTICIPANT	\N	PRESENT	0
799048	797792	19533U	PARTICIPANT	\N	PRESENT	0
799062	797792	20046A	PARTICIPANT	\N	PRESENT	0
799063	797792	14053L	PARTICIPANT	\N	PRESENT	0
799064	797792	20076G	PARTICIPANT	\N	PRESENT	0
799065	797792	20062A	PARTICIPANT	\N	PRESENT	0
799066	797792	14021P	PARTICIPANT	\N	PRESENT	0
799067	797792	19723Y	PARTICIPANT	\N	PRESENT	0
799073	797792	04047H	PARTICIPANT	\N	PRESENT	0
799129	797793	11090Q	PARTICIPANT	\N	PRESENT	0
799130	797793	21084L	PARTICIPANT	\N	PRESENT	0
799131	797793	21057H	PARTICIPANT	\N	PRESENT	0
799132	797793	20110Q	PARTICIPANT	\N	PRESENT	0
799133	797793	04047H	PARTICIPANT	\N	PRESENT	0
799134	797793	20022R	PARTICIPANT	\N	PRESENT	0
799135	797793	19629C	PARTICIPANT	\N	PRESENT	0
799136	797793	21040X	PARTICIPANT	\N	PRESENT	0
799137	797793	19798U	PARTICIPANT	\N	PRESENT	0
799138	797793	14069U	PARTICIPANT	\N	PRESENT	0
799139	797793	21070E	PARTICIPANT	\N	PRESENT	0
799140	797793	14219Q	PARTICIPANT	\N	PRESENT	0
799141	797793	19649G	PARTICIPANT	\N	PRESENT	0
799142	797793	19551W	PARTICIPANT	\N	PRESENT	0
799143	797793	07029T	PARTICIPANT	\N	PRESENT	0
799144	797793	21068L	PARTICIPANT	\N	PRESENT	0
799145	797793	20136B	PARTICIPANT	\N	PRESENT	0
799146	797793	21080G	PARTICIPANT	\N	PRESENT	0
799147	797793	20100N	PARTICIPANT	\N	PRESENT	0
799148	797793	19111A	PARTICIPANT	\N	PRESENT	0
799149	797793	20076G	PARTICIPANT	\N	PRESENT	0
799150	797793	21058J	PARTICIPANT	\N	PRESENT	0
799151	797793	21039F	PARTICIPANT	\N	PRESENT	0
799152	797793	19447X	PARTICIPANT	\N	PRESENT	0
799153	797793	20090E	PARTICIPANT	\N	PRESENT	0
799154	797793	14053L	PARTICIPANT	\N	PRESENT	0
799155	797793	21090J	PARTICIPANT	\N	PRESENT	0
799156	797793	20086J	PARTICIPANT	\N	PRESENT	0
799157	797793	15197G	PARTICIPANT	\N	PRESENT	0
799158	797793	19826F	PARTICIPANT	\N	PRESENT	0
799159	797793	19479G	PARTICIPANT	\N	PRESENT	0
799160	797793	20072C	PARTICIPANT	\N	PRESENT	0
799161	797793	14215L	PARTICIPANT	\N	PRESENT	0
799162	797793	21082J	PARTICIPANT	\N	PRESENT	0
799163	797793	21079P	PARTICIPANT	\N	PRESENT	0
799164	797793	04033B	PARTICIPANT	\N	PRESENT	0
799165	797793	20134Y	PARTICIPANT	\N	PRESENT	0
799166	797793	19679N	PARTICIPANT	\N	PRESENT	0
799167	797793	21047F	PARTICIPANT	\N	PRESENT	0
799168	797793	20054A	PARTICIPANT	\N	PRESENT	0
814586	813206	19447X	PARTICIPANT	\N	PRESENT	0
814587	813206	19489J	PARTICIPANT	\N	PRESENT	0
814588	813206	21056G	PARTICIPANT	\N	PRESENT	0
814589	813206	18207D	PARTICIPANT	\N	PRESENT	0
814590	813206	20108W	PARTICIPANT	\N	PRESENT	0
814591	813206	18231D	PARTICIPANT	\N	PRESENT	0
814592	813206	20110Q	PARTICIPANT	\N	PRESENT	0
814593	813206	21088Q	PARTICIPANT	\N	PRESENT	0
814594	813206	20114U	PARTICIPANT	\N	PRESENT	0
814595	813206	19111A	PARTICIPANT	\N	PRESENT	0
814596	813206	14215L	PARTICIPANT	\N	PRESENT	0
814597	813206	20022R	PARTICIPANT	\N	PRESENT	0
814598	813206	21095P	PARTICIPANT	\N	PRESENT	0
814599	813206	14053L	PARTICIPANT	\N	PRESENT	0
814600	813206	19649G	PARTICIPANT	\N	PRESENT	0
814601	813206	10015M	PARTICIPANT	\N	PRESENT	0
814602	813206	21076L	PARTICIPANT	\N	PRESENT	0
814603	813206	21040X	PARTICIPANT	\N	PRESENT	0
814604	813206	19725B	PARTICIPANT	\N	PRESENT	0
814605	813206	14089Y	PARTICIPANT	\N	PRESENT	0
814606	813206	21043B	PARTICIPANT	\N	PRESENT	0
814607	813206	21044C	PARTICIPANT	\N	PRESENT	0
814608	813206	11056N	PARTICIPANT	\N	PRESENT	0
814609	813206	20266L	PARTICIPANT	\N	PRESENT	0
814610	813206	14069U	PARTICIPANT	\N	PRESENT	0
814664	813341	14259Y	PARTICIPANT	\N	PRESENT	0
814612	813206	19749K	PARTICIPANT	\N	PRESENT	0
814668	813206	14147R	PARTICIPANT	\N	PRESENT	0
814614	813206	20098N	PARTICIPANT	\N	PRESENT	0
814615	813206	21038E	PARTICIPANT	\N	PRESENT	0
814616	813206	14259Y	PARTICIPANT	\N	PRESENT	0
814617	813206	20036X	PARTICIPANT	\N	PRESENT	0
814618	813206	19719D	PARTICIPANT	\N	PRESENT	0
814659	814657	11074Q	PARTICIPANT	\N	PRESENT	0
814661	814657	08045X	PARTICIPANT	\N	PRESENT	0
814669	813206	14151M	PARTICIPANT	\N	PRESENT	0
814670	813206	08018U	PARTICIPANT	\N	PRESENT	0
814672	814671	20058E	PARTICIPANT	\N	PRESENT	0
814673	814671	14229S	PARTICIPANT	\N	PRESENT	0
814674	814671	21037D	PARTICIPANT	\N	PRESENT	0
815445	813250	21048G	PARTICIPANT	\N	PRESENT	0
815446	813250	20056C	PARTICIPANT	\N	PRESENT	0
815447	813250	20032T	PARTICIPANT	\N	PRESENT	0
815452	813250	21042A	PARTICIPANT	\N	PRESENT	0
815449	813250	20026V	PARTICIPANT	\N	PRESENT	0
815450	813250	19703U	PARTICIPANT	\N	PRESENT	0
815454	813250	20022R	PARTICIPANT	\N	PRESENT	0
815455	812482	21043B	PARTICIPANT	\N	PRESENT	0
815457	813250	19573D	PARTICIPANT	\N	PRESENT	0
815458	813250	14033T	PARTICIPANT	\N	PRESENT	0
815459	813250	19745F	PARTICIPANT	\N	PRESENT	0
815466	812482	14147R	PARTICIPANT	\N	PRESENT	0
815467	812482	20098N	PARTICIPANT	\N	PRESENT	0
815468	813250	21095P	PARTICIPANT	\N	PRESENT	0
815470	813250	08034U	PARTICIPANT	\N	PRESENT	0
815471	813250	19545Y	PARTICIPANT	\N	PRESENT	0
815472	813250	21070E	PARTICIPANT	\N	PRESENT	0
815473	813250	21046E	PARTICIPANT	\N	PRESENT	0
815474	813250	19563B	PARTICIPANT	\N	PRESENT	0
815475	813250	21038E	PARTICIPANT	\N	PRESENT	0
815476	812482	21045D	PARTICIPANT	\N	PRESENT	0
815478	813250	20042V	PARTICIPANT	\N	PRESENT	0
815486	813250	20124W	PARTICIPANT	\N	PRESENT	0
815488	813250	20172F	PARTICIPANT	\N	PRESENT	0
815490	813250	21036C	PARTICIPANT	\N	PRESENT	0
815494	813250	14191V	PARTICIPANT	\N	PRESENT	0
815495	813250	14147R	PARTICIPANT	\N	PRESENT	0
815496	813250	20090E	PARTICIPANT	\N	PRESENT	0
815497	813250	21078N	PARTICIPANT	\N	PRESENT	0
815498	813250	19533U	PARTICIPANT	\N	PRESENT	0
815539	813251	11056N	PARTICIPANT	\N	PRESENT	0
815540	813251	21057H	PARTICIPANT	\N	PRESENT	0
815541	813251	19631V	PARTICIPANT	\N	PRESENT	0
815542	813251	20134Y	PARTICIPANT	\N	PRESENT	0
815543	813251	20266L	PARTICIPANT	\N	PRESENT	0
815544	813251	21048G	PARTICIPANT	\N	PRESENT	0
815545	813251	21070E	PARTICIPANT	\N	PRESENT	0
815546	813251	19629C	PARTICIPANT	\N	PRESENT	0
815548	813251	20116W	PARTICIPANT	\N	PRESENT	0
815549	813251	21092L	PARTICIPANT	\N	PRESENT	0
815550	813251	21078N	PARTICIPANT	\N	PRESENT	0
815551	813251	19745F	PARTICIPANT	\N	PRESENT	0
815552	813251	14083S	PARTICIPANT	\N	PRESENT	0
815553	813251	20042V	PARTICIPANT	\N	PRESENT	0
815554	813251	21038E	PARTICIPANT	\N	PRESENT	0
815555	813251	21050A	PARTICIPANT	\N	PRESENT	0
815558	813251	20062A	PARTICIPANT	\N	PRESENT	0
815560	813251	20090E	PARTICIPANT	\N	PRESENT	0
815561	813251	19533U	PARTICIPANT	\N	PRESENT	0
815562	813251	21053D	PARTICIPANT	\N	PRESENT	0
815563	813251	19507S	PARTICIPANT	\N	PRESENT	0
815565	813251	14147R	PARTICIPANT	\N	PRESENT	0
815566	813251	20172F	PARTICIPANT	\N	PRESENT	0
815567	813251	19703U	PARTICIPANT	\N	PRESENT	0
815568	813251	14215L	PARTICIPANT	\N	PRESENT	0
815569	813251	20026V	PARTICIPANT	\N	PRESENT	0
815570	813251	20180F	PARTICIPANT	\N	PRESENT	0
815571	813251	21058J	PARTICIPANT	\N	PRESENT	0
815572	813251	21039F	PARTICIPANT	\N	PRESENT	0
815573	813251	14187A	PARTICIPANT	\N	PRESENT	0
815574	813251	19782L	PARTICIPANT	\N	PRESENT	0
815575	813251	21075K	PARTICIPANT	\N	PRESENT	0
815576	813251	20054A	PARTICIPANT	\N	PRESENT	0
815581	813251	20032T	PARTICIPANT	\N	PRESENT	0
815582	813251	19447X	PARTICIPANT	\N	PRESENT	0
815583	813251	19866P	PARTICIPANT	\N	PRESENT	0
815584	813251	19691J	PARTICIPANT	\N	PRESENT	0
815585	813191	21072G	PARTICIPANT	\N	PRESENT	0
815537	813251	14259Y	PARTICIPANT	\N	PRESENT	0
815538	813251	20286Q	PARTICIPANT	\N	PRESENT	0
815586	813251	14281W	PARTICIPANT	\N	PRESENT	0
815587	813251	21082J	PARTICIPANT	\N	PRESENT	0
815588	813251	19701S	PARTICIPANT	\N	PRESENT	0
815589	813251	14191V	PARTICIPANT	\N	PRESENT	0
815590	813251	21085M	PARTICIPANT	\N	PRESENT	0
815591	813251	21046E	PARTICIPANT	\N	PRESENT	0
815592	813251	14107H	PARTICIPANT	\N	PRESENT	0
815594	815593	19621T	PARTICIPANT	\N	PRESENT	0
815595	815593	21089R	PARTICIPANT	\N	PRESENT	0
815596	815593	20180F	PARTICIPANT	\N	PRESENT	0
815597	815593	21037D	PARTICIPANT	\N	PRESENT	0
815598	815593	14030Q	PARTICIPANT	\N	PRESENT	0
815599	813251	20082E	PARTICIPANT	\N	PRESENT	0
815600	813251	19573D	PARTICIPANT	\N	PRESENT	0
815601	810556	18083K	PARTICIPANT	\N	EXCUSE	0
815602	813251	20124W	PARTICIPANT	\N	PRESENT	0
815603	813251	14195A	PARTICIPANT	\N	PRESENT	0
815604	813251	20084G	PARTICIPANT	\N	PRESENT	0
815605	813251	14217N	PARTICIPANT	\N	PRESENT	0
815606	813251	21086N	PARTICIPANT	\N	PRESENT	0
815607	813251	18231D	PARTICIPANT	\N	PRESENT	0
815646	813252	14259Y	PARTICIPANT	\N	PRESENT	0
815647	813252	19703U	PARTICIPANT	\N	PRESENT	0
815648	813252	20082E	PARTICIPANT	\N	PRESENT	0
815649	813252	21075K	PARTICIPANT	\N	PRESENT	0
815650	813252	21058J	PARTICIPANT	\N	PRESENT	0
815651	813252	19760E	PARTICIPANT	\N	PRESENT	0
815652	813252	21097R	PARTICIPANT	\N	PRESENT	0
815653	813252	19782L	PARTICIPANT	\N	PRESENT	0
815654	813252	14195A	PARTICIPANT	\N	PRESENT	0
815655	813252	21046E	PARTICIPANT	\N	PRESENT	0
815656	813252	14107H	PARTICIPANT	\N	PRESENT	0
815657	813252	19866P	PARTICIPANT	\N	PRESENT	0
815658	813252	20116W	PARTICIPANT	\N	PRESENT	0
815659	813252	19629C	PARTICIPANT	\N	PRESENT	0
815660	813252	21094N	PARTICIPANT	\N	PRESENT	0
815661	813252	14281W	PARTICIPANT	\N	PRESENT	0
815662	813252	21086N	PARTICIPANT	\N	PRESENT	0
815663	813252	21053D	PARTICIPANT	\N	PRESENT	0
815664	813252	21085M	PARTICIPANT	\N	PRESENT	0
815665	813252	20054A	PARTICIPANT	\N	PRESENT	0
815666	813252	20062A	PARTICIPANT	\N	PRESENT	0
815667	813252	20090E	PARTICIPANT	\N	PRESENT	0
815668	813252	14217N	PARTICIPANT	\N	PRESENT	0
815669	813252	14147R	PARTICIPANT	\N	PRESENT	0
815670	813252	20172F	PARTICIPANT	\N	PRESENT	0
815671	813252	14215L	PARTICIPANT	\N	PRESENT	0
815672	813252	21039F	PARTICIPANT	\N	PRESENT	0
815673	813252	19691J	PARTICIPANT	\N	PRESENT	0
815674	813252	14083S	PARTICIPANT	\N	PRESENT	0
815675	813252	04092N	PARTICIPANT	\N	PRESENT	0
800692	797970	14331P	PRESIDENT	0	PRESENT	0
800693	797970	20094J	PARTICIPANT	\N	PRESENT	0
800694	797970	14073Q	PARTICIPANT	\N	PRESENT	0
800695	797970	14357A	PARTICIPANT	\N	PRESENT	0
800796	800794	20286Q	PARTICIPANT	\N	PRESENT	0
800697	797970	14189C	PARTICIPANT	\N	PRESENT	0
800698	797970	18395Y	PARTICIPANT	\N	PRESENT	0
800699	797970	14033T	PARTICIPANT	\N	PRESENT	0
800700	797970	21054E	PARTICIPANT	\N	PRESENT	0
800701	797970	20248J	PARTICIPANT	\N	PRESENT	0
800702	797970	20104S	PARTICIPANT	\N	PRESENT	0
800703	797970	14169X	PARTICIPANT	\N	PRESENT	0
800704	797970	19709B	PARTICIPANT	\N	PRESENT	0
800705	797970	20042V	PARTICIPANT	\N	PRESENT	0
800706	797970	19701S	PARTICIPANT	\N	PRESENT	0
800707	797970	20286Q	PARTICIPANT	\N	EXCUSE	0
800708	797970	18207D	PARTICIPANT	\N	PRESENT	0
800748	797970	21076L	PARTICIPANT	\N	PRESENT	0
800795	800794	14187A	PARTICIPANT	\N	PRESENT	0
800797	800794	19631V	PARTICIPANT	\N	PRESENT	0
804065	804064	20086J	PARTICIPANT	\N	PRESENT	0
804066	804064	21041Y	PARTICIPANT	\N	PRESENT	0
804067	804064	07004J	PARTICIPANT	\N	PRESENT	0
804068	804064	14179A	PARTICIPANT	\N	PRESENT	0
804082	804081	11072N	PARTICIPANT	\N	PRESENT	0
804070	804064	14059S	PARTICIPANT	\N	PRESENT	0
804071	804064	21073H	PARTICIPANT	\N	PRESENT	0
804072	804064	04070G	PARTICIPANT	\N	PRESENT	0
804073	804064	19745F	PARTICIPANT	\N	PRESENT	0
804074	804064	10015M	PARTICIPANT	\N	PRESENT	0
804075	804064	14229S	PARTICIPANT	\N	PRESENT	0
804076	804064	19669L	PARTICIPANT	\N	PRESENT	0
804077	804064	19575F	PARTICIPANT	\N	EXCUSE	0
804078	804064	11040E	PARTICIPANT	\N	EXCUSE	0
804079	804064	14225N	PARTICIPANT	\N	EXCUSE	0
804080	804064	08034U	PRESIDENT	0	PRESENT	0
804083	804081	14275Y	PARTICIPANT	\N	PRESENT	0
804084	804052	14255U	PARTICIPANT	\N	EXCUSE	0
806379	804052	14151M	PRESIDENT	0	PRESENT	0
806380	804052	17367Q	PARTICIPANT	\N	PRESENT	0
806382	804052	20090E	PARTICIPANT	\N	PRESENT	0
806383	804052	20146D	PARTICIPANT	\N	PRESENT	0
807852	807411	20124W	PARTICIPANT	\N	PRESENT	0
807853	807411	19954N	PARTICIPANT	\N	PRESENT	0
807854	807411	21091K	PARTICIPANT	\N	PRESENT	0
807855	807411	04070G	PARTICIPANT	\N	PRESENT	0
807856	807411	20132W	PARTICIPANT	\N	PRESENT	0
807857	807411	14073Q	PARTICIPANT	\N	PRESENT	0
807858	807411	19693L	PARTICIPANT	\N	PRESENT	0
807859	807411	20172F	PARTICIPANT	\N	PRESENT	0
807860	807411	21074J	PARTICIPANT	\N	PRESENT	0
807861	807411	21063F	PARTICIPANT	\N	PRESENT	0
807862	807411	19697Q	PARTICIPANT	\N	PRESENT	0
807863	807411	20058E	PARTICIPANT	\N	PRESENT	0
807864	807411	18395Y	PARTICIPANT	\N	PRESENT	0
807865	807411	20142Y	PARTICIPANT	\N	PRESENT	0
807866	807411	19593H	PARTICIPANT	\N	PRESENT	0
807867	807411	14021P	PARTICIPANT	\N	PRESENT	0
807868	807411	21089R	PARTICIPANT	\N	PRESENT	0
807869	807411	14109K	PARTICIPANT	\N	PRESENT	0
807870	807411	20112S	PARTICIPANT	\N	PRESENT	0
807871	807411	21037D	PARTICIPANT	\N	PRESENT	0
807872	807411	21077M	PARTICIPANT	\N	EXCUSE	0
807873	807411	11043H	PARTICIPANT	\N	PRESENT	0
807874	807411	14229S	PARTICIPANT	\N	PRESENT	0
807875	807411	21055F	PARTICIPANT	\N	PRESENT	0
807876	807176	21071F	PARTICIPANT	\N	PRESENT	0
807877	807411	21058J	PARTICIPANT	\N	PRESENT	0
807878	807411	08012N	PARTICIPANT	\N	PRESENT	0
807879	807411	20052X	PARTICIPANT	\N	PRESENT	0
807880	807411	19699S	PARTICIPANT	\N	PRESENT	0
807881	807411	19735D	PARTICIPANT	\N	PRESENT	0
807882	807411	20102Q	PARTICIPANT	\N	PRESENT	0
807883	807176	14191V	PARTICIPANT	\N	PRESENT	0
807884	807176	20096L	PARTICIPANT	\N	PRESENT	0
807885	807176	21073H	PARTICIPANT	\N	PRESENT	0
807886	807176	19768N	PARTICIPANT	\N	PRESENT	0
807887	807176	14329V	PARTICIPANT	\N	PRESENT	0
807888	807176	19447X	PARTICIPANT	\N	PRESENT	0
807889	807176	21068L	PARTICIPANT	\N	PRESENT	0
807890	807176	19383Y	PARTICIPANT	\N	PRESENT	0
807891	807176	07033P	PARTICIPANT	\N	PRESENT	0
807892	807176	19489J	PARTICIPANT	\N	PRESENT	0
807953	807326	14147R	PARTICIPANT	\N	PRESENT	0
807954	807326	20076G	PARTICIPANT	\N	PRESENT	0
807955	807326	20110Q	PARTICIPANT	\N	PRESENT	0
807956	807326	21044C	PARTICIPANT	\N	PRESENT	0
808068	807004	11056N	PARTICIPANT	\N	PRESENT	0
807958	807326	10015M	PARTICIPANT	\N	PRESENT	0
807959	807326	19649G	PARTICIPANT	\N	PRESENT	0
807960	807326	19723Y	PARTICIPANT	\N	PRESENT	0
807961	807326	08028W	PARTICIPANT	\N	PRESENT	0
807962	807326	08015R	PARTICIPANT	\N	PRESENT	0
807964	807326	19745F	PARTICIPANT	\N	PRESENT	0
807965	807326	04047H	PARTICIPANT	\N	PRESENT	0
807966	807326	14191V	PARTICIPANT	\N	PRESENT	0
807967	807326	14215L	PARTICIPANT	\N	PRESENT	0
807968	807326	19489J	PARTICIPANT	\N	PRESENT	0
807970	807326	18231D	PARTICIPANT	\N	PRESENT	0
807971	807326	21068L	PARTICIPANT	\N	PRESENT	0
807974	807326	21066J	PARTICIPANT	\N	PRESENT	0
807976	807326	21070E	PARTICIPANT	\N	PRESENT	0
807977	807326	19679N	PARTICIPANT	\N	PRESENT	0
807980	807326	14069U	PARTICIPANT	\N	PRESENT	0
807982	807326	19335Q	PARTICIPANT	\N	PRESENT	0
807983	807326	20096L	PARTICIPANT	\N	PRESENT	0
807985	807326	21085M	PARTICIPANT	\N	PRESENT	0
807986	807326	21038E	PARTICIPANT	\N	PRESENT	0
807987	807326	19507S	PARTICIPANT	\N	PRESENT	0
808069	807004	14275Y	PARTICIPANT	\N	PRESENT	0
807989	807326	04045F	PARTICIPANT	\N	PRESENT	0
807990	807326	21088Q	PARTICIPANT	\N	PRESENT	0
807991	807411	20056C	PARTICIPANT	\N	PRESENT	0
807994	807326	20022R	PARTICIPANT	\N	PRESENT	0
808065	807004	19729F	PARTICIPANT	\N	EXCUSE	0
808066	807004	19585H	PARTICIPANT	\N	EXCUSE	0
808067	807004	19719D	PARTICIPANT	\N	EXCUSE	0
808070	807004	20036X	PARTICIPANT	\N	PRESENT	0
808071	807004	14189C	PARTICIPANT	\N	PRESENT	0
808072	807004	19111A	PARTICIPANT	\N	PRESENT	0
808073	807004	14215L	PARTICIPANT	\N	PRESENT	0
808074	807004	08018U	PRESIDENT	0	PRESENT	0
808076	807004	14053L	PARTICIPANT	\N	PRESENT	0
808077	807004	20074E	PARTICIPANT	\N	PRESENT	0
808078	807004	19673G	PARTICIPANT	\N	PRESENT	0
808079	807004	19447X	PARTICIPANT	\N	PRESENT	0
808080	807004	21044C	PARTICIPANT	\N	PRESENT	0
808081	807004	14147R	PARTICIPANT	\N	PRESENT	0
808087	807004	04045F	PARTICIPANT	\N	PRESENT	0
808088	807004	14231L	PARTICIPANT	\N	PRESENT	0
808089	807004	18207D	PARTICIPANT	\N	PRESENT	0
808090	807004	20108W	PARTICIPANT	\N	PRESENT	0
808091	807004	20110Q	PARTICIPANT	\N	PRESENT	0
808092	807004	20114U	PARTICIPANT	\N	PRESENT	0
808093	807004	21095P	PARTICIPANT	\N	PRESENT	0
808094	807004	20022R	PARTICIPANT	\N	PRESENT	0
808095	807004	11072N	PARTICIPANT	\N	PRESENT	0
807950	807326	14259Y	PARTICIPANT	\N	PRESENT	0
807952	807326	21073H	PARTICIPANT	\N	PRESENT	0
808096	807004	14111D	PARTICIPANT	\N	PRESENT	0
808097	807004	10015M	PARTICIPANT	\N	PRESENT	0
808098	807004	21076L	PARTICIPANT	\N	PRESENT	0
808099	807004	21043B	PARTICIPANT	\N	PRESENT	0
808100	807004	14069U	PARTICIPANT	\N	PRESENT	0
808114	807004	21056G	PARTICIPANT	\N	PRESENT	0
808115	807004	14151M	PARTICIPANT	\N	PRESENT	0
808116	807004	14089Y	PARTICIPANT	\N	PRESENT	0
808120	807004	19649G	PARTICIPANT	\N	PRESENT	0
808121	807004	19725B	PARTICIPANT	\N	PRESENT	0
808122	807004	19749K	PARTICIPANT	\N	PRESENT	0
808127	807004	19489J	PARTICIPANT	\N	PRESENT	0
808128	807004	21088Q	PARTICIPANT	\N	PRESENT	0
808132	807004	21057H	PARTICIPANT	\N	PRESENT	0
808133	807004	14259Y	PARTICIPANT	\N	PRESENT	0
808134	808129	19711U	PARTICIPANT	\N	PRESENT	0
808135	804284	19697Q	PARTICIPANT	\N	PRESENT	0
808136	804284	19699S	PARTICIPANT	\N	PRESENT	0
808137	804284	19533U	PARTICIPANT	\N	PRESENT	0
808138	804284	04033B	PARTICIPANT	\N	PRESENT	0
808139	804284	20102Q	PARTICIPANT	\N	PRESENT	0
808140	804284	19954N	PARTICIPANT	\N	PRESENT	0
817461	817255	19695N	PARTICIPANT	\N	PRESENT	0
817462	817255	21092L	PARTICIPANT	\N	PRESENT	0
817463	817255	14033T	PARTICIPANT	\N	PRESENT	0
817464	817255	11090Q	PARTICIPANT	\N	PRESENT	0
817465	817255	21093M	PARTICIPANT	\N	PRESENT	0
817466	817255	20054A	PARTICIPANT	\N	PRESENT	0
817467	817255	21034A	PARTICIPANT	\N	PRESENT	0
817468	817255	14205J	PARTICIPANT	\N	PRESENT	0
817469	817255	20060X	PARTICIPANT	\N	PRESENT	0
817470	817255	19507S	PARTICIPANT	\N	PRESENT	0
817471	817255	20066E	PARTICIPANT	\N	PRESENT	0
817472	817255	21066J	PARTICIPANT	\N	PRESENT	0
817473	817255	20286Q	PARTICIPANT	\N	PRESENT	0
817474	817255	14207L	PARTICIPANT	\N	PRESENT	0
817475	817255	20084G	PARTICIPANT	\N	PRESENT	0
817476	817255	14257W	PARTICIPANT	\N	PRESENT	0
817477	817255	21052C	PARTICIPANT	\N	EXCUSE	0
817478	817255	20088L	PARTICIPANT	\N	EXCUSE	0
817479	817255	08028W	PARTICIPANT	\N	EXCUSE	0
817480	817255	14329V	PARTICIPANT	\N	EXCUSE	0
817500	814470	04033B	PARTICIPANT	\N	PRESENT	0
817501	815921	21082J	PARTICIPANT	\N	PRESENT	0
817502	815921	21029D	PARTICIPANT	\N	PRESENT	0
817503	815921	19701S	PARTICIPANT	\N	PRESENT	0
817504	815921	21035B	PARTICIPANT	\N	PRESENT	0
817505	815921	20076G	PARTICIPANT	\N	PRESENT	0
817506	815921	21042A	PARTICIPANT	\N	PRESENT	0
817507	815921	14219Q	PRESIDENT	0	PRESENT	0
817508	815921	19820Y	PARTICIPANT	\N	PRESENT	0
817509	815921	19826F	PARTICIPANT	\N	PRESENT	0
817510	815921	21060C	PARTICIPANT	\N	PRESENT	0
817511	815921	21061D	PARTICIPANT	\N	PRESENT	0
817512	815921	21062E	PARTICIPANT	\N	PRESENT	0
817513	815921	21065H	PARTICIPANT	\N	PRESENT	0
817514	815921	19551W	PARTICIPANT	\N	PRESENT	0
817515	815921	20100N	PARTICIPANT	\N	PRESENT	0
817516	815921	21084L	PARTICIPANT	\N	PRESENT	0
817517	815921	18083K	PARTICIPANT	\N	PRESENT	0
817518	815921	14237S	PARTICIPANT	\N	PRESENT	0
817519	815921	21085M	PARTICIPANT	\N	PRESENT	0
817520	815921	05012A	PARTICIPANT	\N	PRESENT	0
817521	815921	20106U	PARTICIPANT	\N	PRESENT	0
817522	815921	08060W	PARTICIPANT	\N	PRESENT	0
817523	815921	15197G	PARTICIPANT	\N	PRESENT	0
817524	815921	20118Y	PARTICIPANT	\N	PRESENT	0
817525	815921	14107H	PARTICIPANT	\N	PRESENT	0
817526	815921	21080G	PARTICIPANT	\N	PRESENT	0
817527	815921	19331L	PARTICIPANT	\N	PRESENT	0
817528	815921	20020P	PARTICIPANT	\N	PRESENT	0
817529	815921	19685L	PARTICIPANT	\N	PRESENT	0
817530	815921	19681G	PARTICIPANT	\N	PRESENT	0
817531	815921	11065P	PARTICIPANT	\N	PRESENT	0
817532	815921	21051B	PARTICIPANT	\N	PRESENT	0
817533	815921	21053D	PARTICIPANT	\N	PRESENT	0
817534	815921	20032T	PARTICIPANT	\N	PRESENT	0
817535	815921	20136B	PARTICIPANT	\N	PRESENT	0
817536	815921	14031R	PARTICIPANT	\N	PRESENT	0
817537	815921	20040T	PARTICIPANT	\N	PRESENT	0
817538	815921	19251M	PARTICIPANT	\N	PRESENT	0
817539	815921	20146D	PARTICIPANT	\N	PRESENT	0
817540	815921	20046A	PARTICIPANT	\N	PRESENT	0
817541	815921	17229F	PARTICIPANT	\N	PRESENT	0
817542	815921	14169X	PARTICIPANT	\N	PRESENT	0
817543	815921	21047F	PARTICIPANT	\N	PRESENT	0
817544	815921	20068G	PARTICIPANT	\N	PRESENT	0
817545	815921	21068L	PARTICIPANT	\N	PRESENT	0
817546	815921	21070E	PARTICIPANT	\N	PRESENT	0
817547	815921	19619A	PARTICIPANT	\N	PRESENT	0
817548	815921	19387D	PARTICIPANT	\N	EXCUSE	0
817549	815921	20120S	PARTICIPANT	\N	EXCUSE	0
817563	815932	14147R	PARTICIPANT	\N	PRESENT	0
817583	817183	19629C	PARTICIPANT	\N	PRESENT	0
817584	817183	19798U	PARTICIPANT	\N	PRESENT	0
817585	817183	21064G	PARTICIPANT	\N	PRESENT	0
817587	816769	11053K	PARTICIPANT	\N	PRESENT	0
817588	816769	20094J	PARTICIPANT	\N	PRESENT	0
817589	816769	12016W	PARTICIPANT	\N	PRESENT	0
817590	816769	20070A	PARTICIPANT	\N	PRESENT	0
817591	816769	21072G	PARTICIPANT	\N	PRESENT	0
817605	815944	14331P	PRESIDENT	0	PRESENT	0
817606	815944	14189C	PARTICIPANT	\N	PRESENT	0
817607	815944	18395Y	PARTICIPANT	\N	PRESENT	0
817608	815944	14073Q	PARTICIPANT	\N	EXCUSE	0
817609	815944	21076L	PARTICIPANT	\N	EXCUSE	0
817610	815944	20098N	PARTICIPANT	\N	EXCUSE	0
817611	815944	21054E	PARTICIPANT	\N	EXCUSE	0
817612	815944	19701S	PARTICIPANT	\N	PRESENT	0
817613	815944	21049H	PARTICIPANT	\N	PRESENT	0
817614	815944	08073C	PARTICIPANT	\N	PRESENT	0
817615	815944	20100N	PARTICIPANT	\N	PRESENT	0
817616	815944	14001X	PARTICIPANT	\N	PRESENT	0
817617	815944	10015M	PARTICIPANT	\N	PRESENT	0
817618	816063	20056C	PARTICIPANT	\N	PRESENT	0
817619	816063	21084L	PARTICIPANT	\N	PRESENT	0
817620	816063	20032T	PARTICIPANT	\N	PRESENT	0
817621	816063	20122U	PARTICIPANT	\N	PRESENT	0
817622	816063	14109K	PRESIDENT	0	PRESENT	0
817623	816063	11074Q	PARTICIPANT	\N	PRESENT	0
817624	816063	19866P	PARTICIPANT	\N	PRESENT	0
817625	816063	21039F	PARTICIPANT	\N	PRESENT	0
817650	815936	20024T	PARTICIPANT	\N	PRESENT	0
817627	816063	20026V	PARTICIPANT	\N	PRESENT	0
817628	816063	95041E	PARTICIPANT	\N	EXCUSE	0
817629	816063	20058E	PARTICIPANT	\N	EXCUSE	0
817631	815944	08034U	PARTICIPANT	\N	PRESENT	0
817632	816063	21086N	PARTICIPANT	\N	PRESENT	0
817633	815944	21037D	PARTICIPANT	\N	PRESENT	0
817634	815944	19711U	PARTICIPANT	\N	PRESENT	0
817635	815944	20106U	PARTICIPANT	\N	PRESENT	0
817636	815944	19569H	PARTICIPANT	\N	PRESENT	0
817637	815944	14133K	PARTICIPANT	\N	PRESENT	0
817638	815944	20094J	PARTICIPANT	\N	PRESENT	0
817639	815944	14033T	PARTICIPANT	\N	PRESENT	0
817640	815944	04070G	PARTICIPANT	\N	PRESENT	0
817641	815944	19683J	PARTICIPANT	\N	PRESENT	0
817642	815944	14169X	PARTICIPANT	\N	PRESENT	0
817643	815944	17737W	PARTICIPANT	\N	PRESENT	0
817644	815944	21082J	PARTICIPANT	\N	PRESENT	0
817645	816063	20142Y	PARTICIPANT	\N	PRESENT	0
817646	816063	21068L	PARTICIPANT	\N	PRESENT	0
817647	816063	20124W	PARTICIPANT	\N	PRESENT	0
817648	815936	86034E	PARTICIPANT	\N	PRESENT	0
817649	815936	11043H	PARTICIPANT	\N	PRESENT	0
817873	815936	21045D	PARTICIPANT	\N	PRESENT	0
817874	815936	20060X	PARTICIPANT	\N	PRESENT	0
817875	815936	21095P	PARTICIPANT	\N	PRESENT	0
817876	815936	18395Y	PARTICIPANT	\N	PRESENT	0
817877	815936	20070A	PARTICIPANT	\N	PRESENT	0
817878	815936	21067K	PARTICIPANT	\N	PRESENT	0
817895	815936	14237S	PARTICIPANT	\N	PRESENT	0
817880	815936	19631V	PARTICIPANT	\N	PRESENT	0
817881	815936	14026U	PARTICIPANT	\N	PRESENT	0
817882	815936	14147R	PARTICIPANT	\N	PRESENT	0
817883	815936	14151M	PARTICIPANT	\N	PRESENT	0
817884	815936	11074Q	PARTICIPANT	\N	PRESENT	0
817885	815936	21062E	PARTICIPANT	\N	PRESENT	0
817886	815936	19647E	PARTICIPANT	\N	PRESENT	0
817887	815936	14281W	PARTICIPANT	\N	PRESENT	0
817896	815936	19531S	PARTICIPANT	\N	PRESENT	0
817889	815936	19725B	PARTICIPANT	\N	PRESENT	0
817890	815936	19551W	PARTICIPANT	\N	PRESENT	0
817891	815936	14357A	PARTICIPANT	\N	PRESENT	0
817892	815936	14121F	PARTICIPANT	\N	PRESENT	0
817893	815936	20026V	PARTICIPANT	\N	PRESENT	0
817894	815936	19683J	PARTICIPANT	\N	PRESENT	0
817897	815936	14097Y	PARTICIPANT	\N	PRESENT	0
817898	815936	14021P	PARTICIPANT	\N	PRESENT	0
817899	815936	19649G	PARTICIPANT	\N	PRESENT	0
817900	815936	19553Y	PARTICIPANT	\N	PRESENT	0
817901	815936	18207D	PARTICIPANT	\N	PRESENT	0
817902	815936	19798U	PARTICIPANT	\N	PRESENT	0
817903	815936	17779H	PARTICIPANT	\N	PRESENT	0
817904	815936	12016W	PARTICIPANT	\N	PRESENT	0
817905	815936	08018U	PARTICIPANT	\N	PRESENT	0
817906	815936	14001X	PARTICIPANT	\N	PRESENT	0
817907	815936	20018V	PARTICIPANT	\N	PRESENT	0
817908	815936	14109K	PARTICIPANT	\N	PRESENT	0
817909	815936	20180F	PARTICIPANT	\N	PRESENT	0
817910	815936	14257W	PARTICIPANT	\N	PRESENT	0
817911	815936	18231D	PARTICIPANT	\N	PRESENT	0
817912	815936	07033P	PARTICIPANT	\N	PRESENT	0
799169	797793	14071N	PARTICIPANT	\N	PRESENT	0
799170	797793	21053D	PARTICIPANT	\N	PRESENT	0
799171	797793	20044X	PARTICIPANT	\N	PRESENT	0
799172	797793	20140W	PARTICIPANT	\N	PRESENT	0
799173	797793	20056C	PARTICIPANT	\N	PRESENT	0
799174	797793	21044C	PARTICIPANT	\N	PRESENT	0
799175	797793	20048C	PARTICIPANT	\N	PRESENT	0
799176	797793	21048G	PARTICIPANT	\N	PRESENT	0
799177	797793	14147R	PARTICIPANT	\N	PRESENT	0
799178	797793	20126Y	PARTICIPANT	\N	PRESENT	0
799179	797793	14031R	PARTICIPANT	\N	PRESENT	0
799180	797793	19954N	PARTICIPANT	\N	PRESENT	0
799181	797793	14231L	PARTICIPANT	\N	PRESENT	0
799182	797793	18207D	PARTICIPANT	\N	PRESENT	0
799183	797793	21045D	PARTICIPANT	\N	PRESENT	0
799184	797793	14151M	PARTICIPANT	\N	PRESENT	0
799185	797793	20052X	PARTICIPANT	\N	PRESENT	0
799186	797793	14187A	PARTICIPANT	\N	PRESENT	0
799187	797793	19701S	PARTICIPANT	\N	PRESENT	0
799188	797793	20120S	PARTICIPANT	\N	PRESENT	0
799189	797793	20062A	PARTICIPANT	\N	PRESENT	0
799190	797793	14033T	PARTICIPANT	\N	PRESENT	0
799191	797793	14213J	PARTICIPANT	\N	PRESENT	0
799192	797793	19703U	PARTICIPANT	\N	PRESENT	0
799193	797793	20114U	PARTICIPANT	\N	PRESENT	0
799194	797793	14083S	PARTICIPANT	\N	PRESENT	0
799195	797793	21043B	PARTICIPANT	\N	PRESENT	0
799196	797793	21081H	PARTICIPANT	\N	PRESENT	0
799197	797793	20124W	PARTICIPANT	\N	PRESENT	0
799198	797793	19553Y	PARTICIPANT	\N	PRESENT	0
799199	797793	21063F	PARTICIPANT	\N	PRESENT	0
799200	797793	21064G	PARTICIPANT	\N	PRESENT	0
799201	797793	20180F	PARTICIPANT	\N	PRESENT	0
799202	797793	20032T	PARTICIPANT	\N	PRESENT	0
799203	797793	11056N	PARTICIPANT	\N	PRESENT	0
799204	797793	20058E	PARTICIPANT	\N	PRESENT	0
799208	797611	14071N	PRESIDENT	0	PRESENT	0
799209	797611	14281W	PARTICIPANT	\N	PRESENT	0
799210	797611	17779H	PARTICIPANT	\N	PRESENT	0
799211	797611	14223L	PARTICIPANT	\N	PRESENT	0
799212	797611	21081H	PARTICIPANT	\N	PRESENT	0
799213	797611	21039F	PARTICIPANT	\N	PRESENT	0
799214	797611	19367Y	PARTICIPANT	\N	PRESENT	0
799215	797611	11045K	PARTICIPANT	\N	PRESENT	0
799216	797611	20140W	PARTICIPANT	\N	PRESENT	0
799217	797611	21064G	PARTICIPANT	\N	PRESENT	0
799218	797611	19798U	PARTICIPANT	\N	PRESENT	0
799219	797611	20148F	PARTICIPANT	\N	PRESENT	0
799220	797611	17965H	PARTICIPANT	\N	PRESENT	0
799221	797611	08061X	PARTICIPANT	\N	PRESENT	0
799222	797611	14195A	PARTICIPANT	\N	PRESENT	0
799223	797611	19553Y	PARTICIPANT	\N	PRESENT	0
799224	797611	19758L	PARTICIPANT	\N	PRESENT	0
799225	797611	19679N	PARTICIPANT	\N	PRESENT	0
799226	797611	19866P	PARTICIPANT	\N	EXCUSE	0
799227	797611	21071F	PARTICIPANT	\N	PRESENT	0
799228	797611	14217N	PARTICIPANT	\N	PRESENT	0
799229	797611	04092N	PARTICIPANT	\N	PRESENT	0
799230	797611	19569H	PARTICIPANT	\N	PRESENT	0
799231	797611	19713W	PARTICIPANT	\N	PRESENT	0
799232	797611	21046E	PARTICIPANT	\N	PRESENT	0
799233	797611	21087P	PARTICIPANT	\N	PRESENT	0
799234	797611	19703U	PARTICIPANT	\N	PRESENT	0
799235	797611	14355X	PARTICIPANT	\N	EXCUSE	0
799236	797611	14213J	PARTICIPANT	\N	PRESENT	0
799237	797611	20096L	PARTICIPANT	\N	PRESENT	0
799238	797611	20090E	PARTICIPANT	\N	PRESENT	0
799239	797611	20130U	PARTICIPANT	\N	EXCUSE	0
799241	797611	18193Q	PARTICIPANT	\N	PRESENT	0
799242	797611	21045D	PARTICIPANT	\N	PRESENT	0
799243	797611	19760E	PARTICIPANT	\N	PRESENT	0
799244	797611	21049H	PARTICIPANT	\N	PRESENT	0
799245	797611	19723Y	PARTICIPANT	\N	PRESENT	0
799246	797611	20248J	PARTICIPANT	\N	PRESENT	0
799247	797611	14042U	PARTICIPANT	\N	PRESENT	0
799248	797611	19683J	PARTICIPANT	\N	PRESENT	0
799286	797973	18083K	PARTICIPANT	\N	PRESENT	0
799287	797973	21062E	PARTICIPANT	\N	PRESENT	0
799288	797973	19331L	PARTICIPANT	\N	PRESENT	0
799289	797973	21047F	PARTICIPANT	\N	PRESENT	0
799290	797610	19723Y	PARTICIPANT	\N	PRESENT	0
799291	797610	20248J	PARTICIPANT	\N	PRESENT	0
799331	797610	19691J	PARTICIPANT	\N	PRESENT	0
799293	797610	19683J	PARTICIPANT	\N	PRESENT	0
799294	797610	18193Q	PARTICIPANT	\N	PRESENT	0
799295	797610	21045D	PARTICIPANT	\N	PRESENT	0
799296	797610	19760E	PARTICIPANT	\N	PRESENT	0
799297	797610	21049H	PARTICIPANT	\N	PRESENT	0
799298	797610	20096L	PARTICIPANT	\N	PRESENT	0
799299	797610	20090E	PARTICIPANT	\N	PRESENT	0
799300	797610	20130U	PARTICIPANT	\N	EXCUSE	0
799301	797610	21064G	PARTICIPANT	\N	PRESENT	0
799302	797610	19798U	PARTICIPANT	\N	PRESENT	0
799303	797610	20148F	PARTICIPANT	\N	PRESENT	0
799304	797610	17965H	PARTICIPANT	\N	PRESENT	0
799305	797610	21039F	PARTICIPANT	\N	PRESENT	0
799306	797610	19367Y	PARTICIPANT	\N	PRESENT	0
799307	797610	11045K	PARTICIPANT	\N	PRESENT	0
799308	797610	20140W	PARTICIPANT	\N	PRESENT	0
799332	797611	14026U	PARTICIPANT	\N	PRESENT	0
799334	797610	01034P	PARTICIPANT	\N	PRESENT	0
799311	797610	14223L	PARTICIPANT	\N	PRESENT	0
799312	797610	21081H	PARTICIPANT	\N	PRESENT	0
799313	797610	14071N	PRESIDENT	\N	PRESENT	0
799314	797610	21087P	PARTICIPANT	\N	PRESENT	0
799315	797610	19703U	PARTICIPANT	\N	PRESENT	0
799316	797610	14355X	PARTICIPANT	\N	EXCUSE	0
799317	797610	14213J	PARTICIPANT	\N	PRESENT	0
799318	797610	04092N	PARTICIPANT	\N	PRESENT	0
799333	797611	19691J	PARTICIPANT	\N	PRESENT	0
799320	797610	19713W	PARTICIPANT	\N	PRESENT	0
799321	797610	21046E	PARTICIPANT	\N	PRESENT	0
799322	797610	19679N	PARTICIPANT	\N	PRESENT	0
799323	797610	19866P	PARTICIPANT	\N	EXCUSE	0
799335	797610	19569H	PARTICIPANT	\N	PRESENT	0
799325	797610	14217N	PARTICIPANT	\N	PRESENT	0
799336	797610	14042U	PARTICIPANT	\N	PRESENT	0
799327	797610	14195A	PARTICIPANT	\N	PRESENT	0
799337	797611	01034P	PARTICIPANT	\N	PRESENT	0
799329	797610	19758L	PARTICIPANT	\N	PRESENT	0
799330	797610	14026U	PARTICIPANT	\N	PRESENT	0
799338	797610	21071F	PARTICIPANT	\N	PRESENT	0
799453	797973	19685L	PARTICIPANT	\N	PRESENT	0
799454	797973	05012A	PARTICIPANT	\N	PRESENT	0
799455	797802	21030V	PARTICIPANT	\N	PRESENT	0
799456	797802	14179A	PARTICIPANT	\N	PRESENT	0
799465	797967	20086J	PARTICIPANT	\N	PRESENT	0
799466	797967	14327T	PARTICIPANT	\N	PRESENT	0
799467	797967	14331P	PARTICIPANT	\N	PRESENT	0
799468	797967	19479G	PARTICIPANT	\N	PRESENT	0
799469	797967	11048N	PARTICIPANT	\N	PRESENT	0
799470	797967	20080C	PARTICIPANT	\N	PRESENT	0
799471	797967	14225N	PRESIDENT	0	PRESENT	0
799472	797967	11070L	PARTICIPANT	\N	PRESENT	0
799473	797967	14169X	PARTICIPANT	\N	PRESENT	0
799474	797967	11040E	PARTICIPANT	\N	PRESENT	0
799475	797967	14083S	PARTICIPANT	\N	PRESENT	0
799476	797967	20062A	PARTICIPANT	\N	PRESENT	0
799477	797967	08009T	PARTICIPANT	\N	PRESENT	0
799478	797967	19349W	PARTICIPANT	\N	PRESENT	0
799479	797967	14121F	PARTICIPANT	\N	PRESENT	0
799480	797967	21090J	PARTICIPANT	\N	PRESENT	0
799481	797967	20126Y	PARTICIPANT	\N	PRESENT	0
799482	797967	07029T	PARTICIPANT	\N	EXCUSE	0
799484	797967	14173T	PARTICIPANT	\N	EXCUSE	0
799485	797967	19667J	PARTICIPANT	\N	PRESENT	0
799486	797967	19573D	PARTICIPANT	\N	PRESENT	0
799487	797967	20116W	PARTICIPANT	\N	PRESENT	0
799488	797967	19335Q	PARTICIPANT	\N	PRESENT	0
799489	797967	20024T	PARTICIPANT	\N	PRESENT	0
799490	797967	20044X	PARTICIPANT	\N	PRESENT	0
799491	797967	19399H	PARTICIPANT	\N	PRESENT	0
799492	797967	20094J	PARTICIPANT	\N	PRESENT	0
799493	797967	21048G	PARTICIPANT	\N	PRESENT	0
799494	797967	19545Y	PARTICIPANT	\N	PRESENT	0
799495	797967	08010L	PARTICIPANT	\N	PRESENT	0
799496	797967	08034U	PARTICIPANT	\N	PRESENT	0
799497	797967	21041Y	PARTICIPANT	\N	PRESENT	0
799499	799205	19383Y	PARTICIPANT	\N	PRESENT	0
799500	799205	20088L	PARTICIPANT	\N	PRESENT	0
813391	813189	14151M	PRESIDENT	0	PRESENT	0
813392	813189	17367Q	PARTICIPANT	\N	PRESENT	0
813393	813189	21081H	PARTICIPANT	\N	PRESENT	0
813394	813189	20090E	PARTICIPANT	\N	PRESENT	0
813395	813189	19563B	PARTICIPANT	\N	PRESENT	0
813396	813189	17737W	PARTICIPANT	\N	PRESENT	0
813397	813189	15197G	PARTICIPANT	\N	PRESENT	0
813398	813189	18395Y	PARTICIPANT	\N	PRESENT	0
813399	813189	19295A	PARTICIPANT	\N	PRESENT	0
813400	813189	20110Q	PARTICIPANT	\N	PRESENT	0
813401	813189	12028B	PARTICIPANT	\N	PRESENT	0
813402	813189	14255U	PARTICIPANT	\N	PRESENT	0
813404	813189	21072G	PARTICIPANT	\N	PRESENT	0
814455	814395	19533U	PARTICIPANT	\N	PRESENT	0
815678	813252	19447X	PARTICIPANT	\N	PRESENT	0
815679	813252	18193Q	PARTICIPANT	\N	PRESENT	0
815680	813252	14213J	PARTICIPANT	\N	PRESENT	0
815681	813252	19758L	PARTICIPANT	\N	PRESENT	0
815682	813252	19679N	PARTICIPANT	\N	PRESENT	0
815683	813252	19563B	PARTICIPANT	\N	PRESENT	0
815684	813252	05012A	PARTICIPANT	\N	PRESENT	0
815685	813252	19649G	PARTICIPANT	\N	PRESENT	0
815676	813252	19713W	PARTICIPANT	\N	PRESENT	0
815677	813252	20042V	PARTICIPANT	\N	PRESENT	0
815686	813252	19413M	PARTICIPANT	\N	PRESENT	0
815687	813252	20070A	PARTICIPANT	\N	PRESENT	0
815688	813252	21057H	PARTICIPANT	\N	PRESENT	0
815689	813252	21038E	PARTICIPANT	\N	PRESENT	0
815690	813252	07029T	PARTICIPANT	\N	PRESENT	0
815691	813252	21043B	PARTICIPANT	\N	PRESENT	0
815692	813252	20110Q	PARTICIPANT	\N	PRESENT	0
815693	813252	20106U	PARTICIPANT	\N	PRESENT	0
815694	813252	21049H	PARTICIPANT	\N	PRESENT	0
815743	813253	19649G	PARTICIPANT	\N	PRESENT	0
815744	813253	19413M	PARTICIPANT	\N	PRESENT	0
815745	813253	21046E	PARTICIPANT	\N	PRESENT	0
815746	813253	21075K	PARTICIPANT	\N	PRESENT	0
815747	813253	21038E	PARTICIPANT	\N	PRESENT	0
815748	813253	21053D	PARTICIPANT	\N	PRESENT	0
815749	813253	21095P	PARTICIPANT	\N	PRESENT	0
815750	813253	20106U	PARTICIPANT	\N	PRESENT	0
815751	813253	21097R	PARTICIPANT	\N	PRESENT	0
815752	813253	18395Y	PARTICIPANT	\N	PRESENT	0
815753	813253	20138D	PARTICIPANT	\N	PRESENT	0
815754	813253	21058J	PARTICIPANT	\N	PRESENT	0
815755	813253	20090E	PARTICIPANT	\N	PRESENT	0
815756	813253	19782L	PARTICIPANT	\N	PRESENT	0
815757	813253	14215L	PARTICIPANT	\N	PRESENT	0
815758	813253	20054A	PARTICIPANT	\N	PRESENT	0
815759	813253	20062A	PARTICIPANT	\N	PRESENT	0
815760	813253	19703U	PARTICIPANT	\N	PRESENT	0
815761	813253	20110Q	PARTICIPANT	\N	PRESENT	0
815762	813253	20104S	PARTICIPANT	\N	PRESENT	0
815763	813253	21039F	PARTICIPANT	\N	PRESENT	0
815764	813253	20026V	PARTICIPANT	\N	PRESENT	0
815765	813253	20180F	PARTICIPANT	\N	PRESENT	0
815766	813253	19713W	PARTICIPANT	\N	PRESENT	0
815767	813253	14231L	PARTICIPANT	\N	PRESENT	0
815768	813253	21040X	PARTICIPANT	\N	PRESENT	0
815769	813253	19866P	PARTICIPANT	\N	PRESENT	0
815770	813253	19679N	PARTICIPANT	\N	PRESENT	0
815771	813253	20124W	PARTICIPANT	\N	PRESENT	0
815772	813253	21079P	PARTICIPANT	\N	PRESENT	0
815773	813253	19447X	PARTICIPANT	\N	PRESENT	0
815774	813253	21049H	PARTICIPANT	\N	PRESENT	0
815775	813253	19629C	PARTICIPANT	\N	PRESENT	0
815776	813253	20070A	PARTICIPANT	\N	PRESENT	0
815777	813253	20266L	PARTICIPANT	\N	PRESENT	0
815781	813253	21082J	PARTICIPANT	\N	PRESENT	0
815779	813253	14026U	PARTICIPANT	\N	PRESENT	0
815780	813253	21056G	PARTICIPANT	\N	PRESENT	0
815782	813253	19749K	PARTICIPANT	\N	PRESENT	0
815783	813253	14213J	PARTICIPANT	\N	PRESENT	0
815784	813253	20052X	PARTICIPANT	\N	PRESENT	0
815785	813253	07029T	PARTICIPANT	\N	PRESENT	0
815786	813253	08010L	PARTICIPANT	\N	PRESENT	0
815787	813253	20082E	PARTICIPANT	\N	PRESENT	0
815788	813253	21043B	PARTICIPANT	\N	PRESENT	0
815789	813253	20048C	PARTICIPANT	\N	PRESENT	0
815741	813253	19593H	PARTICIPANT	\N	PRESENT	0
815742	813253	04047H	PARTICIPANT	\N	PRESENT	0
815790	804984	21089R	PARTICIPANT	\N	PRESENT	0
815791	804984	20180F	PARTICIPANT	\N	PRESENT	0
815792	804984	19749K	PRESIDENT	0	PRESENT	0
815793	804984	21077M	PARTICIPANT	\N	PRESENT	0
815794	804984	21091K	PARTICIPANT	\N	PRESENT	0
815795	804984	20038A	PARTICIPANT	\N	PRESENT	0
815796	804984	14109K	PARTICIPANT	\N	PRESENT	0
815797	804984	07029T	PARTICIPANT	\N	PRESENT	0
815798	804984	21061D	PARTICIPANT	\N	PRESENT	0
815806	804984	21038E	PARTICIPANT	\N	PRESENT	0
815914	815913	19631V	PARTICIPANT	\N	PRESENT	0
815915	815913	19575F	PARTICIPANT	\N	PRESENT	0
815916	815913	19669L	PARTICIPANT	\N	PRESENT	0
815973	815972	19749K	PARTICIPANT	\N	PRESENT	0
815975	815974	19749K	PARTICIPANT	\N	PRESENT	0
815976	815974	20266L	PARTICIPANT	\N	PRESENT	0
815978	815977	19749K	PARTICIPANT	\N	PRESENT	0
815980	815979	19649G	PARTICIPANT	\N	PRESENT	0
815981	815979	14053L	PARTICIPANT	\N	PRESENT	0
815993	815992	19735D	PARTICIPANT	\N	PRESENT	0
815997	815994	14038Y	PARTICIPANT	\N	PRESENT	0
815998	815994	18231D	PARTICIPANT	\N	PRESENT	0
815999	815995	14038Y	PARTICIPANT	\N	PRESENT	0
816000	815995	18231D	PARTICIPANT	\N	PRESENT	0
816001	815996	14038Y	PARTICIPANT	\N	PRESENT	0
816002	815996	18231D	PARTICIPANT	\N	PRESENT	0
816004	816003	21090J	PARTICIPANT	\N	PRESENT	0
816005	816003	20132W	PARTICIPANT	\N	PRESENT	0
816008	816006	20132W	PARTICIPANT	\N	PRESENT	0
816009	816006	21090J	PARTICIPANT	\N	PRESENT	0
816011	816010	20116W	PARTICIPANT	\N	PRESENT	0
816013	816012	21072G	PARTICIPANT	\N	PRESENT	0
816015	816014	21072G	PARTICIPANT	\N	PRESENT	0
816017	816016	20050V	PARTICIPANT	\N	PRESENT	0
816019	816018	20050V	PARTICIPANT	\N	PRESENT	0
816021	816020	20050V	PARTICIPANT	\N	PRESENT	0
816023	816022	20050V	PARTICIPANT	\N	PRESENT	0
816927	816882	17965H	PARTICIPANT	\N	PRESENT	0
816929	816882	18193Q	PARTICIPANT	\N	PRESENT	0
816931	816882	21090J	PARTICIPANT	\N	PRESENT	0
816935	816882	19591F	PARTICIPANT	\N	PRESENT	0
816951	816882	10015M	PARTICIPANT	\N	PRESENT	0
816966	816882	14213J	PARTICIPANT	\N	PRESENT	0
817148	817146	11048N	PARTICIPANT	\N	PRESENT	0
817149	817146	11074Q	PARTICIPANT	\N	PRESENT	0
817150	817146	20044X	PARTICIPANT	\N	PRESENT	0
817151	817146	11070L	PARTICIPANT	\N	PRESENT	0
817152	817146	19399H	PARTICIPANT	\N	PRESENT	0
817153	817146	14225N	PRESIDENT	0	PRESENT	0
817154	817146	14173T	PARTICIPANT	\N	PRESENT	0
817155	817146	07029T	PARTICIPANT	\N	PRESENT	0
817156	817146	14083S	PARTICIPANT	\N	PRESENT	0
817157	817146	21079P	PARTICIPANT	\N	PRESENT	0
817158	817146	07004J	PARTICIPANT	\N	PRESENT	0
817159	817146	08009T	PARTICIPANT	\N	PRESENT	0
817160	817146	14121F	PARTICIPANT	\N	PRESENT	0
817161	817146	20116W	PARTICIPANT	\N	PRESENT	0
817162	817146	21090J	PARTICIPANT	\N	PRESENT	0
817163	817146	14253S	PARTICIPANT	\N	PRESENT	0
817164	817146	19335Q	PARTICIPANT	\N	PRESENT	0
817165	817146	21048G	PARTICIPANT	\N	PRESENT	0
817166	817146	20024T	PARTICIPANT	\N	PRESENT	0
817167	817146	20126Y	PARTICIPANT	\N	PRESENT	0
817170	817146	19573D	PARTICIPANT	\N	PRESENT	0
817171	817146	08010L	PARTICIPANT	\N	PRESENT	0
817174	817146	14331P	PARTICIPANT	\N	PRESENT	0
817175	817146	20080C	PARTICIPANT	\N	PRESENT	0
817176	817146	19647E	PARTICIPANT	\N	PRESENT	0
817177	817146	19479G	PARTICIPANT	\N	PRESENT	0
817178	817146	19711U	PARTICIPANT	\N	PRESENT	0
817179	817146	08034U	PARTICIPANT	\N	PRESENT	0
817180	817146	19687N	PARTICIPANT	\N	PRESENT	0
817181	817146	08073C	PARTICIPANT	\N	PRESENT	0
817182	817146	14327T	PARTICIPANT	\N	PRESENT	0
817184	817146	21041Y	PARTICIPANT	\N	PRESENT	0
817185	816769	14327T	PARTICIPANT	\N	PRESENT	0
817186	816769	14331P	PARTICIPANT	\N	PRESENT	0
817187	816769	20080C	PARTICIPANT	\N	PRESENT	0
817188	816769	11074Q	PARTICIPANT	\N	PRESENT	0
817189	816769	11070L	PARTICIPANT	\N	PRESENT	0
802355	801237	14281W	PARTICIPANT	\N	PRESENT	0
802356	801237	19367Y	PARTICIPANT	\N	PRESENT	0
803990	803989	19711U	PARTICIPANT	\N	PRESENT	0
803991	803989	11070L	PARTICIPANT	\N	PRESENT	0
803992	803989	14257W	PRESIDENT	0	PRESENT	0
803993	803989	20042V	PARTICIPANT	\N	EXCUSE	0
803994	803989	14207L	PARTICIPANT	\N	EXCUSE	0
803995	803989	19695N	PRESIDENT	1	PRESENT	0
807417	807416	14053L	PARTICIPANT	\N	PRESENT	0
807418	807416	14097Y	PARTICIPANT	\N	PRESENT	0
807419	807416	14193X	PARTICIPANT	\N	PRESENT	0
807421	807420	14053L	PARTICIPANT	\N	PRESENT	0
807422	807420	14097Y	PARTICIPANT	\N	PRESENT	0
807423	807420	14193X	PARTICIPANT	\N	PRESENT	0
808141	804284	21032X	PARTICIPANT	\N	PRESENT	0
808142	804284	18395Y	PARTICIPANT	\N	PRESENT	0
808143	804284	20112S	PARTICIPANT	\N	PRESENT	0
808144	804284	21089R	PARTICIPANT	\N	PRESENT	0
808145	804284	21037D	PARTICIPANT	\N	PRESENT	0
808146	804284	08012N	PARTICIPANT	\N	PRESENT	0
808147	804284	21091K	PARTICIPANT	\N	PRESENT	0
808148	804284	20026V	PARTICIPANT	\N	PRESENT	0
808149	804284	19593H	PARTICIPANT	\N	PRESENT	0
808150	804284	20122U	PARTICIPANT	\N	PRESENT	0
808151	804284	14073Q	PARTICIPANT	\N	PRESENT	0
808152	804284	19611R	PRESIDENT	0	PRESENT	0
808153	804284	20138D	PARTICIPANT	\N	PRESENT	0
808154	804284	20142Y	PARTICIPANT	\N	PRESENT	0
808155	804284	20048C	PARTICIPANT	\N	PRESENT	0
808156	804284	19693L	PARTICIPANT	\N	PRESENT	0
808157	804284	20172F	PARTICIPANT	\N	PRESENT	0
808158	804284	14030Q	PARTICIPANT	\N	PRESENT	0
808159	804284	20058E	PARTICIPANT	\N	PRESENT	0
808160	804284	20056C	PARTICIPANT	\N	PRESENT	0
808161	804284	20180F	PARTICIPANT	\N	PRESENT	0
808162	804284	20264J	PARTICIPANT	\N	PRESENT	0
808163	804284	21063F	PARTICIPANT	\N	PRESENT	0
808164	804284	19735D	PARTICIPANT	\N	PRESENT	0
808165	804284	19057M	PARTICIPANT	\N	PRESENT	0
808166	804284	14109K	PARTICIPANT	\N	PRESENT	0
808167	804284	14123H	PARTICIPANT	\N	PRESENT	0
808168	804284	11043H	PARTICIPANT	\N	PRESENT	0
808169	804284	21074J	PARTICIPANT	\N	PRESENT	0
808170	804284	21078N	PARTICIPANT	\N	PRESENT	0
808171	804284	19621T	PARTICIPANT	\N	PRESENT	0
808172	804284	21077M	PARTICIPANT	\N	EXCUSE	0
808173	804284	14021P	PARTICIPANT	\N	PRESENT	0
808176	808129	14327T	PARTICIPANT	\N	PRESENT	0
808177	808129	21090J	PARTICIPANT	\N	PRESENT	0
808191	807004	21040X	PARTICIPANT	\N	PRESENT	0
808354	807245	20072C	PARTICIPANT	\N	PRESENT	0
808355	807245	19565D	PARTICIPANT	\N	PRESENT	0
808356	807245	21031W	PARTICIPANT	\N	PRESENT	0
808357	807245	01058X	PARTICIPANT	\N	PRESENT	0
808358	807245	14001X	PARTICIPANT	\N	PRESENT	0
808359	807245	11027H	PARTICIPANT	\N	PRESENT	0
808360	807245	04042C	PARTICIPANT	\N	PRESENT	0
808361	807245	19669L	PARTICIPANT	\N	PRESENT	0
808362	807245	12028B	PARTICIPANT	\N	PRESENT	0
808363	807245	17737W	PARTICIPANT	\N	PRESENT	0
808364	807245	19421M	PARTICIPANT	\N	PRESENT	0
808365	807245	21067K	PARTICIPANT	\N	PRESENT	0
808366	807245	19709B	PARTICIPANT	\N	PRESENT	0
808367	807245	19347U	PARTICIPANT	\N	PRESENT	0
808368	807245	14193X	PRESIDENT	0	PRESENT	0
808369	807245	14179A	PARTICIPANT	\N	PRESENT	0
808370	807245	07033P	PARTICIPANT	\N	PRESENT	0
808371	807245	17367Q	PARTICIPANT	\N	PRESENT	0
808372	807245	14249W	PARTICIPANT	\N	PRESENT	0
808373	807245	08047A	PARTICIPANT	\N	PRESENT	0
808374	807245	20128B	PARTICIPANT	\N	PRESENT	0
808375	807245	14037X	PARTICIPANT	\N	PRESENT	0
808376	807245	14097Y	PARTICIPANT	\N	PRESENT	0
808377	807245	14059S	PARTICIPANT	\N	PRESENT	0
808378	807245	21073H	PARTICIPANT	\N	PRESENT	0
808379	807245	19531S	PARTICIPANT	\N	PRESENT	0
808380	807245	08069G	PARTICIPANT	\N	PRESENT	0
808381	807245	20042V	PARTICIPANT	\N	PRESENT	0
808382	807245	19721W	PARTICIPANT	\N	PRESENT	0
808383	807245	14191V	PARTICIPANT	\N	PRESENT	0
808384	807245	20064C	PARTICIPANT	\N	PRESENT	0
808385	807245	14251Q	PARTICIPANT	\N	PRESENT	0
808386	807245	19507S	PARTICIPANT	\N	PRESENT	0
808387	807245	14267Y	PARTICIPANT	\N	PRESENT	0
808388	807245	99004R	PARTICIPANT	\N	PRESENT	0
808389	807245	19745F	PARTICIPANT	\N	PRESENT	0
808390	807245	14211G	PARTICIPANT	\N	PRESENT	0
808391	807245	14255U	PARTICIPANT	\N	PRESENT	0
808392	807245	17023S	PARTICIPANT	\N	PRESENT	0
808489	807008	21082J	PARTICIPANT	\N	PRESENT	0
808490	807008	21035B	PARTICIPANT	\N	PRESENT	0
808491	807008	20076G	PARTICIPANT	\N	PRESENT	0
808492	807008	21042A	PARTICIPANT	\N	PRESENT	0
808493	807008	14219Q	PRESIDENT	0	PRESENT	0
808494	807008	19820Y	PARTICIPANT	\N	PRESENT	0
808495	807008	19826F	PARTICIPANT	\N	PRESENT	0
808496	807008	21060C	PARTICIPANT	\N	PRESENT	0
808497	807008	21061D	PARTICIPANT	\N	PRESENT	0
808498	807008	21062E	PARTICIPANT	\N	PRESENT	0
808499	807008	21065H	PARTICIPANT	\N	PRESENT	0
808500	807008	14237S	PARTICIPANT	\N	PRESENT	0
808501	807008	18083K	PARTICIPANT	\N	PRESENT	0
808502	807008	20100N	PARTICIPANT	\N	PRESENT	0
808503	807008	21084L	PARTICIPANT	\N	PRESENT	0
808504	807008	19551W	PARTICIPANT	\N	PRESENT	0
808505	807008	05012A	PARTICIPANT	\N	PRESENT	0
808506	807008	20106U	PARTICIPANT	\N	PRESENT	0
808507	807008	15197G	PARTICIPANT	\N	PRESENT	0
808508	807008	20118Y	PARTICIPANT	\N	PRESENT	0
808509	807008	14107H	PARTICIPANT	\N	PRESENT	0
808510	807008	21080G	PARTICIPANT	\N	PRESENT	0
808511	807008	20020P	PARTICIPANT	\N	PRESENT	0
808512	807008	19685L	PARTICIPANT	\N	PRESENT	0
808513	807008	21051B	PARTICIPANT	\N	PRESENT	0
808514	807008	20032T	PARTICIPANT	\N	PRESENT	0
808515	807008	21053D	PARTICIPANT	\N	PRESENT	0
808516	807008	20136B	PARTICIPANT	\N	PRESENT	0
808517	807008	14031R	PARTICIPANT	\N	PRESENT	0
808518	807008	20040T	PARTICIPANT	\N	PRESENT	0
808519	807008	19251M	PARTICIPANT	\N	PRESENT	0
808520	807008	20046A	PARTICIPANT	\N	PRESENT	0
808521	807008	17229F	PARTICIPANT	\N	PRESENT	0
808522	807008	14169X	PARTICIPANT	\N	PRESENT	0
808523	807008	21047F	PARTICIPANT	\N	PRESENT	0
808524	807008	20068G	PARTICIPANT	\N	PRESENT	0
808525	807008	08009T	PARTICIPANT	\N	PRESENT	0
808526	807008	21068L	PARTICIPANT	\N	PRESENT	0
808527	807008	21070E	PARTICIPANT	\N	PRESENT	0
810038	810037	14193X	PARTICIPANT	\N	PRESENT	0
809938	794007	14109K	PARTICIPANT	\N	PRESENT	0
810039	810037	14179A	PARTICIPANT	\N	PRESENT	0
810040	810037	08047A	PARTICIPANT	\N	PRESENT	0
810041	810037	19669L	PARTICIPANT	\N	PRESENT	0
810042	810037	20128B	PARTICIPANT	\N	PRESENT	0
810051	807188	14255U	PARTICIPANT	\N	PRESENT	0
810271	810204	21035B	PARTICIPANT	\N	EXCUSE	0
810274	810273	99004R	PARTICIPANT	\N	PRESENT	0
810275	810273	19111A	PARTICIPANT	\N	PRESENT	0
810276	810273	19569H	PARTICIPANT	\N	PRESENT	0
810277	810273	20052X	PARTICIPANT	\N	PRESENT	0
810279	810278	19713W	PARTICIPANT	\N	PRESENT	0
810280	810278	21064G	PARTICIPANT	\N	PRESENT	0
810285	807338	14217N	PARTICIPANT	\N	PRESENT	0
810286	807338	21094N	PARTICIPANT	\N	PRESENT	0
810287	807338	21064G	PARTICIPANT	\N	PRESENT	0
810289	810288	19760E	PARTICIPANT	\N	PRESENT	0
810290	810288	21094N	PARTICIPANT	\N	PRESENT	0
810291	810288	14217N	PARTICIPANT	\N	PRESENT	0
810292	807341	14217N	PARTICIPANT	\N	PRESENT	0
810293	807341	21064G	PARTICIPANT	\N	PRESENT	0
810296	810294	20130U	PARTICIPANT	\N	PRESENT	0
810297	810294	17965H	PARTICIPANT	\N	PRESENT	0
810298	810294	21039F	PARTICIPANT	\N	PRESENT	0
810299	810295	20130U	PARTICIPANT	\N	PRESENT	0
810300	810295	17965H	PARTICIPANT	\N	PRESENT	0
810301	810295	21039F	PARTICIPANT	\N	PRESENT	0
810318	810314	20026V	PARTICIPANT	\N	PRESENT	0
810319	810315	20082E	PARTICIPANT	\N	PRESENT	0
810320	810315	20026V	PARTICIPANT	\N	PRESENT	0
810322	810321	20026V	PARTICIPANT	\N	PRESENT	0
810323	810321	20082E	PARTICIPANT	\N	PRESENT	0
817482	815872	19729F	PARTICIPANT	\N	EXCUSE	0
817484	815872	19585H	PARTICIPANT	\N	EXCUSE	0
817913	815936	19489J	PARTICIPANT	\N	PRESENT	0
817914	815936	21060C	PARTICIPANT	\N	PRESENT	0
817915	815936	05012A	PARTICIPANT	\N	PRESENT	0
817916	815936	19251M	PARTICIPANT	\N	PRESENT	0
817917	815936	20030R	PARTICIPANT	\N	PRESENT	0
817918	815936	17965H	PARTICIPANT	\N	PRESENT	0
817919	815936	14225N	PARTICIPANT	\N	PRESENT	0
817923	815936	21056G	PARTICIPANT	\N	PRESENT	0
817921	815936	19820Y	PARTICIPANT	\N	PRESENT	0
817922	815936	14229S	PARTICIPANT	\N	PRESENT	0
817924	815936	11045K	PARTICIPANT	\N	PRESENT	0
817925	815936	21059K	PARTICIPANT	\N	PRESENT	0
817926	815936	19669L	PARTICIPANT	\N	PRESENT	0
817927	815936	21051B	PARTICIPANT	\N	PRESENT	0
817928	815936	20064C	PARTICIPANT	\N	PRESENT	0
817929	815936	21031W	PARTICIPANT	\N	PRESENT	0
817930	815936	21082J	PARTICIPANT	\N	PRESENT	0
817931	815936	21077M	PARTICIPANT	\N	PRESENT	0
817932	815936	19413M	PARTICIPANT	\N	PRESENT	0
817933	815936	19713W	PARTICIPANT	\N	PRESENT	0
817934	815936	11070L	PARTICIPANT	\N	PRESENT	0
817935	815936	08009T	PARTICIPANT	\N	PRESENT	0
817936	815936	11053K	PARTICIPANT	\N	PRESENT	0
817937	815936	21042A	PARTICIPANT	\N	PRESENT	0
817938	815936	21050A	PARTICIPANT	\N	PRESENT	0
817939	815936	14255U	PARTICIPANT	\N	PRESENT	0
817940	815936	14030Q	PARTICIPANT	\N	PRESENT	0
817941	815936	14042U	PARTICIPANT	\N	PRESENT	0
817942	815936	15197G	PARTICIPANT	\N	PRESENT	0
817943	815936	14189C	PARTICIPANT	\N	PRESENT	0
817944	815936	19111A	PARTICIPANT	\N	PRESENT	0
817945	815936	20286Q	PARTICIPANT	\N	PRESENT	0
817946	815936	14231L	PARTICIPANT	\N	PRESENT	0
817947	815936	19721W	PARTICIPANT	\N	PRESENT	0
817948	815936	20144B	PARTICIPANT	\N	PRESENT	0
817949	815936	14267Y	PARTICIPANT	\N	PRESENT	0
817950	815936	11115U	PARTICIPANT	\N	PRESENT	0
817951	815936	14327T	PARTICIPANT	\N	PRESENT	0
817952	815936	17229F	PARTICIPANT	\N	PRESENT	0
817953	815936	20248J	PARTICIPANT	\N	PRESENT	0
817954	815936	21086N	PARTICIPANT	\N	PRESENT	0
817955	815936	14083S	PARTICIPANT	\N	PRESENT	0
817956	815936	19691J	PARTICIPANT	\N	PRESENT	0
817957	815936	17023S	PARTICIPANT	\N	PRESENT	0
817958	815936	19569H	PARTICIPANT	\N	PRESENT	0
817959	815936	14179A	PARTICIPANT	\N	PRESENT	0
817960	815936	19685L	PARTICIPANT	\N	PRESENT	0
817961	815936	20048C	PARTICIPANT	\N	PRESENT	0
817962	815936	20066E	PARTICIPANT	\N	PRESENT	0
817963	815936	19735D	PARTICIPANT	\N	PRESENT	0
817964	815936	19611R	PARTICIPANT	\N	PRESENT	0
817965	815936	19699S	PARTICIPANT	\N	PRESENT	0
817966	815936	20052X	PARTICIPANT	\N	PRESENT	0
817967	815936	14205J	PARTICIPANT	\N	PRESENT	0
817968	815936	14219Q	PARTICIPANT	\N	PRESENT	0
817969	815936	11085T	PARTICIPANT	\N	PRESENT	0
817970	815936	19826F	PARTICIPANT	\N	PRESENT	0
817971	815936	19335Q	PARTICIPANT	\N	PRESENT	0
817972	815936	04070G	PARTICIPANT	\N	PRESENT	0
817973	815936	20036X	PARTICIPANT	\N	PRESENT	0
817974	815936	21053D	PARTICIPANT	\N	PRESENT	0
817975	815936	21064G	PARTICIPANT	\N	PRESENT	0
817976	815936	19619A	PARTICIPANT	\N	PRESENT	0
817977	815936	01034P	PARTICIPANT	\N	PRESENT	0
817978	815936	19749K	PARTICIPANT	\N	PRESENT	0
817979	815936	21125C	PARTICIPANT	\N	PRESENT	0
817986	815936	20022R	PARTICIPANT	\N	PRESENT	0
817981	815936	11056N	PARTICIPANT	\N	PRESENT	0
817982	815936	14107H	PARTICIPANT	\N	PRESENT	0
817983	815936	20094J	PARTICIPANT	\N	PRESENT	0
817984	815936	14213J	PARTICIPANT	\N	PRESENT	0
817988	815936	20040T	PARTICIPANT	\N	PRESENT	0
817987	815936	21038E	PARTICIPANT	\N	PRESENT	0
817990	817989	19782L	PARTICIPANT	\N	PRESENT	0
817991	817989	14255U	PARTICIPANT	\N	PRESENT	0
817992	817989	17229F	PARTICIPANT	\N	PRESENT	0
817996	815936	19479G	PARTICIPANT	\N	PRESENT	0
817994	817989	21093M	PARTICIPANT	\N	PRESENT	0
817995	817989	08009T	PARTICIPANT	\N	PRESENT	0
817997	817989	14147R	PARTICIPANT	\N	PRESENT	0
817998	817989	04092N	PARTICIPANT	\N	PRESENT	0
817999	817989	19713W	PARTICIPANT	\N	PRESENT	0
818000	817989	21061D	PARTICIPANT	\N	PRESENT	0
818001	817989	21059K	PARTICIPANT	\N	PRESENT	0
818002	815936	19057M	PARTICIPANT	\N	PRESENT	0
818003	813080	07029T	PARTICIPANT	\N	EXCUSE	0
818004	813080	19866P	PARTICIPANT	\N	EXCUSE	0
818006	817630	19553Y	PARTICIPANT	\N	PRESENT	0
818007	817630	20062A	PARTICIPANT	\N	PRESENT	0
818008	817630	20066E	PRESIDENT	0	PRESENT	0
818009	817630	19758L	PARTICIPANT	\N	PRESENT	0
818010	817630	20096L	PARTICIPANT	\N	PRESENT	0
818011	816066	20098N	PARTICIPANT	\N	PRESENT	0
818013	818012	14133K	PARTICIPANT	\N	PRESENT	0
818016	818014	20138D	PARTICIPANT	\N	PRESENT	0
818017	818014	21046E	PARTICIPANT	\N	PRESENT	0
818018	818014	19723Y	PARTICIPANT	\N	PRESENT	0
818321	815937	19479G	PARTICIPANT	\N	PRESENT	0
818323	818322	20094J	PARTICIPANT	\N	PRESENT	0
818324	818322	14133K	PARTICIPANT	\N	PRESENT	0
818327	815937	21031W	PARTICIPANT	\N	PRESENT	0
818328	815937	12016W	PARTICIPANT	\N	PRESENT	0
818329	815937	19331L	PARTICIPANT	\N	PRESENT	0
818330	815937	14231L	PARTICIPANT	\N	PRESENT	0
818333	815937	21076L	PARTICIPANT	\N	PRESENT	0
818335	815937	21034A	PARTICIPANT	\N	PRESENT	0
818338	815937	20030R	PARTICIPANT	\N	PRESENT	0
818339	815937	19565D	PARTICIPANT	\N	PRESENT	0
818340	815937	19782L	PARTICIPANT	\N	PRESENT	0
818341	815937	20072C	PARTICIPANT	\N	PRESENT	0
818342	815937	21040X	PARTICIPANT	\N	PRESENT	0
818343	815937	14030Q	PARTICIPANT	\N	PRESENT	0
818344	815937	14205J	PARTICIPANT	\N	PRESENT	0
818345	815937	20062A	PARTICIPANT	\N	PRESENT	0
818346	815937	19713W	PARTICIPANT	\N	PRESENT	0
818347	815937	04047H	PARTICIPANT	\N	PRESENT	0
818348	815937	18207D	PARTICIPANT	\N	PRESENT	0
818349	815937	20252E	PARTICIPANT	\N	PRESENT	0
818350	815937	20022R	PARTICIPANT	\N	PRESENT	0
818351	815937	21039F	PARTICIPANT	\N	PRESENT	0
818355	815937	14069U	PARTICIPANT	\N	PRESENT	0
818357	815937	20128B	PARTICIPANT	\N	PRESENT	0
818358	815937	21043B	PARTICIPANT	\N	PRESENT	0
818359	815937	14211G	PARTICIPANT	\N	PRESENT	0
818360	815937	20110Q	PARTICIPANT	\N	PRESENT	0
818362	818005	19553Y	PARTICIPANT	\N	PRESENT	0
818363	818005	20066E	PRESIDENT	0	PRESENT	0
818364	818005	14147R	PARTICIPANT	\N	PRESENT	0
818365	818005	19691J	PARTICIPANT	\N	PRESENT	0
818366	815937	19745F	PARTICIPANT	\N	PRESENT	0
818368	815937	21038E	PARTICIPANT	\N	PRESENT	0
818370	818005	19798U	PARTICIPANT	\N	PRESENT	0
818375	818005	19531S	PARTICIPANT	\N	PRESENT	0
818378	815937	21073H	PARTICIPANT	\N	PRESENT	0
818381	815937	14191V	PARTICIPANT	\N	PRESENT	0
818395	815937	20024T	PARTICIPANT	\N	PRESENT	0
818398	815937	19507S	PARTICIPANT	\N	PRESENT	0
818399	815937	19629C	PARTICIPANT	\N	PRESENT	0
818401	818400	21090J	PRESIDENT	0	PRESENT	0
818402	818400	19591F	PARTICIPANT	\N	PRESENT	0
818403	818400	18193Q	PARTICIPANT	\N	PRESENT	0
818404	818400	10015M	PARTICIPANT	\N	PRESENT	0
818405	815937	19383Y	PARTICIPANT	\N	PRESENT	0
818406	815937	20032T	PARTICIPANT	\N	PRESENT	0
818407	815937	21082J	PARTICIPANT	\N	PRESENT	0
818408	815937	21056G	PARTICIPANT	\N	PRESENT	0
818409	815937	20054A	PARTICIPANT	\N	PRESENT	0
818410	817146	20094J	PARTICIPANT	\N	PRESENT	0
818411	818400	21049H	PARTICIPANT	\N	PRESENT	0
818412	817146	11040E	PARTICIPANT	\N	PRESENT	0
818413	817146	21072G	PARTICIPANT	\N	PRESENT	0
818414	817146	20070A	PARTICIPANT	\N	PRESENT	0
818415	817146	12016W	PARTICIPANT	\N	PRESENT	0
818416	818400	21042A	PARTICIPANT	\N	PRESENT	0
818417	815937	21044C	PARTICIPANT	\N	PRESENT	0
818418	815937	20248J	PARTICIPANT	\N	PRESENT	0
818419	815937	14133K	PARTICIPANT	\N	PRESENT	0
818420	815937	20048C	PARTICIPANT	\N	PRESENT	0
818421	815937	20070A	PARTICIPANT	\N	PRESENT	0
799501	799205	19768N	PARTICIPANT	\N	PRESENT	0
799502	799205	20092G	PARTICIPANT	\N	PRESENT	0
799503	799205	14357A	PARTICIPANT	\N	PRESENT	0
799504	799205	20078J	PARTICIPANT	\N	PRESENT	0
799505	799205	19413M	PARTICIPANT	\N	PRESENT	0
799506	799205	20082E	PARTICIPANT	\N	PRESENT	0
799507	799205	14221J	PARTICIPANT	\N	PRESENT	0
799508	799205	19631V	PARTICIPANT	\N	PRESENT	0
799509	799205	20104S	PARTICIPANT	\N	PRESENT	0
799510	799205	19705W	PARTICIPANT	\N	PRESENT	0
799511	799205	08015R	PARTICIPANT	\N	PRESENT	0
799512	799205	19575F	PARTICIPANT	\N	PRESENT	0
799513	799205	20018V	PARTICIPANT	\N	PRESENT	0
799514	799205	08028W	PARTICIPANT	\N	PRESENT	0
799515	799205	19563B	PARTICIPANT	\N	PRESENT	0
799516	799205	21050A	PARTICIPANT	\N	PRESENT	0
799517	799205	20028X	PARTICIPANT	\N	PRESENT	0
799518	799205	14329V	PARTICIPANT	\N	PRESENT	0
799519	799205	21052C	PARTICIPANT	\N	PRESENT	0
799520	799205	20030R	PARTICIPANT	\N	PRESENT	0
799521	799205	14038Y	PARTICIPANT	\N	PRESENT	0
799522	799205	20034V	PARTICIPANT	\N	PRESENT	0
799523	799205	14187A	PRESIDENT	0	PRESENT	0
799524	799205	20038A	PARTICIPANT	\N	PRESENT	0
799525	799205	21083K	PARTICIPANT	\N	PRESENT	0
799526	799205	21086N	PARTICIPANT	\N	PRESENT	0
799527	799205	20144B	PARTICIPANT	\N	PRESENT	0
799528	799205	19695N	PARTICIPANT	\N	PRESENT	0
799529	799205	21093M	PARTICIPANT	\N	PRESENT	0
799530	799205	11090Q	PARTICIPANT	\N	PRESENT	0
799531	799205	14033T	PARTICIPANT	\N	PRESENT	0
799532	799205	20054A	PARTICIPANT	\N	PRESENT	0
799533	799205	14205J	PARTICIPANT	\N	PRESENT	0
799534	799205	20060X	PARTICIPANT	\N	PRESENT	0
799535	799205	19507S	PARTICIPANT	\N	PRESENT	0
799536	799205	20066E	PARTICIPANT	\N	PRESENT	0
799537	799205	21066J	PARTICIPANT	\N	PRESENT	0
799538	799205	20286Q	PARTICIPANT	\N	PRESENT	0
799539	799205	14207L	PARTICIPANT	\N	PRESENT	0
799540	799205	14257W	PARTICIPANT	\N	PRESENT	0
799541	799205	20084G	PARTICIPANT	\N	PRESENT	0
799542	799205	19782L	PARTICIPANT	\N	EXCUSE	0
799543	797967	11053K	PARTICIPANT	\N	PRESENT	0
799545	799205	21054E	PARTICIPANT	\N	PRESENT	0
799637	797974	21082J	PARTICIPANT	\N	PRESENT	0
799638	797974	19701S	PARTICIPANT	\N	PRESENT	0
799639	797974	21042A	PARTICIPANT	\N	PRESENT	0
799640	797974	20076G	PARTICIPANT	\N	PRESENT	0
799641	797974	14219Q	PARTICIPANT	\N	PRESENT	0
799642	797974	19820Y	PARTICIPANT	\N	PRESENT	0
799643	797974	19826F	PARTICIPANT	\N	PRESENT	0
799644	797974	21060C	PARTICIPANT	\N	PRESENT	0
799645	797974	21061D	PARTICIPANT	\N	PRESENT	0
799646	797974	21062E	PARTICIPANT	\N	PRESENT	0
799647	797974	21065H	PARTICIPANT	\N	PRESENT	0
799648	797974	21084L	PARTICIPANT	\N	PRESENT	0
799649	797974	20100N	PARTICIPANT	\N	PRESENT	0
799650	797974	14237S	PARTICIPANT	\N	PRESENT	0
799651	797974	19551W	PARTICIPANT	\N	PRESENT	0
799652	797974	18083K	PARTICIPANT	\N	PRESENT	0
799653	797974	21085M	PARTICIPANT	\N	PRESENT	0
799654	797974	05012A	PARTICIPANT	\N	PRESENT	0
799655	797974	20106U	PARTICIPANT	\N	PRESENT	0
799656	797974	08060W	PARTICIPANT	\N	PRESENT	0
799657	797974	14107H	PARTICIPANT	\N	PRESENT	0
799658	797974	21080G	PARTICIPANT	\N	PRESENT	0
799659	797974	19331L	PARTICIPANT	\N	PRESENT	0
799660	797974	20020P	PARTICIPANT	\N	PRESENT	0
799661	797974	19685L	PARTICIPANT	\N	PRESENT	0
799662	797974	20120S	PARTICIPANT	\N	PRESENT	0
799663	797974	21051B	PARTICIPANT	\N	PRESENT	0
799664	797974	20032T	PARTICIPANT	\N	PRESENT	0
799665	797974	21053D	PARTICIPANT	\N	PRESENT	0
799666	797974	20136B	PARTICIPANT	\N	PRESENT	0
799667	797974	14031R	PARTICIPANT	\N	PRESENT	0
799668	797974	20040T	PARTICIPANT	\N	PRESENT	0
799669	797974	19251M	PARTICIPANT	\N	PRESENT	0
799670	797974	20046A	PARTICIPANT	\N	PRESENT	0
799671	797974	17229F	PARTICIPANT	\N	PRESENT	0
799672	797974	14169X	PARTICIPANT	\N	PRESENT	0
799673	797974	21047F	PARTICIPANT	\N	PRESENT	0
799674	797974	20068G	PARTICIPANT	\N	PRESENT	0
799675	797974	21068L	PARTICIPANT	\N	PRESENT	0
799676	797974	21070E	PARTICIPANT	\N	PRESENT	0
799677	797974	19619A	PARTICIPANT	\N	PRESENT	0
799678	797974	21035B	PARTICIPANT	\N	EXCUSE	0
799679	797974	19681G	PARTICIPANT	\N	EXCUSE	0
799682	797802	19565D	PARTICIPANT	\N	EXCUSE	0
799683	797802	21031W	PARTICIPANT	\N	EXCUSE	0
799684	797803	21030V	PARTICIPANT	\N	PRESENT	0
799685	797803	14179A	PARTICIPANT	\N	PRESENT	0
799686	797803	20128B	PARTICIPANT	\N	PRESENT	0
799687	797803	19565D	PARTICIPANT	\N	EXCUSE	0
799688	797803	21031W	PARTICIPANT	\N	EXCUSE	0
799829	799826	20028X	PARTICIPANT	\N	PRESENT	0
799831	799826	08015R	PARTICIPANT	\N	PRESENT	0
799833	799826	20090E	PARTICIPANT	\N	PRESENT	0
799837	799826	14329V	PARTICIPANT	\N	PRESENT	0
799839	799826	21041Y	PARTICIPANT	\N	PRESENT	0
799841	799826	14109K	PARTICIPANT	\N	PRESENT	0
800718	797790	20094J	PARTICIPANT	\N	PRESENT	0
800719	797790	20080C	PARTICIPANT	\N	PRESENT	0
800720	797790	14083S	PARTICIPANT	\N	PRESENT	0
800721	797790	11053K	PARTICIPANT	\N	PRESENT	0
800722	797790	21072G	PARTICIPANT	\N	PRESENT	0
800723	797790	08010L	PARTICIPANT	\N	PRESENT	0
800724	797790	08034U	PARTICIPANT	\N	PRESENT	0
800725	797790	12016W	PARTICIPANT	\N	PRESENT	0
800726	797790	19573D	PARTICIPANT	\N	PRESENT	0
800727	797790	08073C	PARTICIPANT	\N	PRESENT	0
800728	797790	19349W	PARTICIPANT	\N	PRESENT	0
800729	797790	20150Y	PARTICIPANT	\N	PRESENT	0
800730	797790	20044X	PRESIDENT	1	PRESENT	0
800731	797790	19479G	PARTICIPANT	\N	PRESENT	0
800732	797790	14225N	PRESIDENT	0	PRESENT	0
800733	797790	11048N	PARTICIPANT	\N	PRESENT	0
800734	797790	19399H	PARTICIPANT	\N	EXCUSE	0
800735	797790	07029T	PARTICIPANT	\N	EXCUSE	0
800736	797790	14173T	PARTICIPANT	\N	EXCUSE	0
800737	797790	21035B	PARTICIPANT	\N	PRESENT	1
800738	797790	14259Y	PARTICIPANT	\N	PRESENT	0
800739	797790	19691J	PARTICIPANT	\N	PRESENT	0
800740	797790	20034V	PARTICIPANT	\N	PRESENT	0
800741	797790	11072N	PARTICIPANT	\N	PRESENT	0
800742	797790	19331L	PARTICIPANT	\N	PRESENT	0
800743	797790	21055F	PARTICIPANT	\N	PRESENT	0
800744	797790	19745F	PARTICIPANT	\N	PRESENT	0
800747	797790	20070A	PARTICIPANT	\N	EXCUSE	0
801026	801025	20026V	PARTICIPANT	\N	PRESENT	0
801027	801025	20082E	PARTICIPANT	\N	PRESENT	0
801028	799021	14042U	PARTICIPANT	\N	PRESENT	0
801029	799021	19760E	PARTICIPANT	\N	PRESENT	0
801038	797790	19301E	PARTICIPANT	\N	PRESENT	1
801040	801039	14231L	PARTICIPANT	\N	PRESENT	0
801041	801039	20090E	PARTICIPANT	\N	PRESENT	0
801042	801039	19621T	PARTICIPANT	\N	PRESENT	0
801043	801039	19735D	PARTICIPANT	\N	PRESENT	0
801044	801039	14026U	PARTICIPANT	\N	PRESENT	0
801045	801039	21079P	PARTICIPANT	\N	PRESENT	0
801046	801039	20062A	PARTICIPANT	\N	PRESENT	0
801047	801039	19593H	PARTICIPANT	\N	PRESENT	0
801048	801039	19111A	PARTICIPANT	\N	PRESENT	0
801049	801039	20018V	PARTICIPANT	\N	PRESENT	0
801050	801039	20032T	PARTICIPANT	\N	EXCUSE	0
801051	801039	20022R	PARTICIPANT	\N	EXCUSE	0
801052	801039	19782L	PARTICIPANT	\N	EXCUSE	0
801053	801039	14053L	PARTICIPANT	\N	EXCUSE	0
801055	801039	21065H	PARTICIPANT	\N	EXCUSE	0
801056	801039	14327T	PARTICIPANT	\N	EXCUSE	0
817190	816769	14225N	PRESIDENT	0	PRESENT	0
817191	816769	07029T	PARTICIPANT	\N	PRESENT	0
817192	816769	21079P	PARTICIPANT	\N	PRESENT	0
817193	816769	19573D	PARTICIPANT	\N	PRESENT	0
817194	816769	07004J	PARTICIPANT	\N	PRESENT	0
817195	816769	08010L	PARTICIPANT	\N	PRESENT	0
817196	816769	20116W	PARTICIPANT	\N	PRESENT	0
817197	816769	21090J	PARTICIPANT	\N	PRESENT	0
817198	816769	14253S	PARTICIPANT	\N	PRESENT	0
817199	816769	19335Q	PARTICIPANT	\N	PRESENT	0
817200	816769	21048G	PARTICIPANT	\N	PRESENT	0
817201	816769	20024T	PARTICIPANT	0	PRESENT	0
817202	816769	20126Y	PARTICIPANT	\N	PRESENT	0
817203	816769	11048N	PARTICIPANT	\N	PRESENT	0
817204	816769	19647E	PARTICIPANT	\N	PRESENT	0
817205	816769	19479G	PARTICIPANT	\N	PRESENT	0
817206	816769	19711U	PARTICIPANT	\N	PRESENT	0
817207	816769	08034U	PARTICIPANT	\N	PRESENT	0
817208	816769	19687N	PARTICIPANT	\N	PRESENT	0
817209	816769	20044X	PRESIDENT	1	PRESENT	0
817210	816769	19399H	PARTICIPANT	\N	PRESENT	0
817211	816769	14173T	PARTICIPANT	\N	PRESENT	0
817212	816769	21041Y	PARTICIPANT	\N	PRESENT	0
817213	816769	14083S	PARTICIPANT	\N	PRESENT	0
817214	816769	08073C	PARTICIPANT	\N	PRESENT	0
817215	816769	08009T	PARTICIPANT	\N	PRESENT	0
817216	816769	14121F	PARTICIPANT	\N	PRESENT	0
817217	816769	08011M	PARTICIPANT	\N	PRESENT	0
817246	817146	19349W	PARTICIPANT	\N	PRESENT	0
817247	816769	20086J	PARTICIPANT	\N	PRESENT	0
817248	817146	20086J	PARTICIPANT	\N	PRESENT	0
817249	816769	19349W	PARTICIPANT	\N	PRESENT	0
817254	816769	11110B	PARTICIPANT	\N	PRESENT	0
817256	817146	11110B	PARTICIPANT	\N	PRESENT	0
817257	814470	19593H	PARTICIPANT	\N	PRESENT	0
817258	814470	21055F	PARTICIPANT	\N	PRESENT	0
817259	814470	19533U	PARTICIPANT	\N	PRESENT	0
817260	814470	19611R	PRESIDENT	0	PRESENT	0
817261	814470	20142Y	PARTICIPANT	\N	PRESENT	0
817262	814470	20048C	PARTICIPANT	\N	PRESENT	0
817263	814470	21058J	PARTICIPANT	\N	PRESENT	0
817264	814470	21059K	PARTICIPANT	\N	PRESENT	0
817265	814470	20102Q	PARTICIPANT	\N	PRESENT	0
817266	814470	20052X	PARTICIPANT	\N	PRESENT	0
817267	814470	14229S	PARTICIPANT	\N	PRESENT	0
817268	814470	20056C	PARTICIPANT	\N	PRESENT	0
817269	814470	19954N	PARTICIPANT	\N	PRESENT	0
817270	814470	20180F	PARTICIPANT	\N	PRESENT	0
817271	814470	20264J	PARTICIPANT	\N	PRESENT	0
817272	814470	18395Y	PARTICIPANT	\N	PRESENT	0
817273	814470	20112S	PARTICIPANT	\N	PRESENT	0
817274	814470	21089R	PARTICIPANT	\N	PRESENT	0
817275	814470	21037D	PARTICIPANT	\N	PRESENT	0
817276	814470	21091K	PARTICIPANT	\N	PRESENT	0
817277	814470	20124W	PARTICIPANT	\N	PRESENT	0
817278	814470	21074J	PARTICIPANT	\N	PRESENT	0
817279	814470	20026V	PARTICIPANT	\N	PRESENT	0
817280	814470	19621T	PARTICIPANT	\N	PRESENT	0
817281	814470	20058E	PARTICIPANT	\N	PRESENT	0
817282	814470	21063F	PARTICIPANT	\N	PRESENT	0
817283	814470	14021P	PARTICIPANT	\N	PRESENT	0
817285	814470	20122U	PARTICIPANT	\N	PRESENT	0
817289	814470	14123H	PARTICIPANT	\N	PRESENT	0
817290	814470	19697Q	PARTICIPANT	\N	PRESENT	0
817291	814470	19699S	PARTICIPANT	\N	PRESENT	0
817292	814470	21077M	PARTICIPANT	\N	PRESENT	0
817293	814470	21078N	PARTICIPANT	\N	PRESENT	0
817308	814470	20132W	PARTICIPANT	\N	PRESENT	0
817309	814470	14109K	PARTICIPANT	\N	PRESENT	0
817310	816769	11040E	PARTICIPANT	\N	PRESENT	0
817311	814470	21125C	PARTICIPANT	\N	PRESENT	0
817312	814470	19735D	PARTICIPANT	\N	PRESENT	0
817315	814470	20138D	PARTICIPANT	\N	PRESENT	0
817316	814470	14030Q	PARTICIPANT	\N	PRESENT	0
817317	814470	19693L	PARTICIPANT	\N	PRESENT	0
817321	814470	19057M	PARTICIPANT	\N	PRESENT	0
817323	815872	21057H	PARTICIPANT	\N	PRESENT	0
817324	815872	04047H	PRESIDENT	0	PRESENT	0
817325	815872	19673G	PARTICIPANT	\N	PRESENT	0
817328	815872	05008E	PARTICIPANT	\N	PRESENT	0
817330	815872	19447X	PARTICIPANT	\N	PRESENT	0
817332	815872	20098N	PARTICIPANT	\N	PRESENT	0
817333	815872	14231L	PARTICIPANT	\N	PRESENT	0
817335	815872	19489J	PARTICIPANT	\N	PRESENT	0
817337	815872	21056G	PARTICIPANT	\N	PRESENT	0
817339	815872	18231D	PARTICIPANT	\N	PRESENT	0
817340	815872	20108W	PARTICIPANT	\N	PRESENT	0
817341	815872	20110Q	PARTICIPANT	\N	PRESENT	0
817342	815872	14147R	PARTICIPANT	\N	PRESENT	0
817348	815872	21088Q	PARTICIPANT	\N	PRESENT	0
817349	815872	14151M	PARTICIPANT	\N	PRESENT	0
817351	815872	20114U	PARTICIPANT	\N	PRESENT	0
817352	815872	08018U	PARTICIPANT	\N	PRESENT	0
817354	815872	20022R	PARTICIPANT	\N	PRESENT	0
817356	815872	11072N	PARTICIPANT	\N	PRESENT	0
817359	815872	14053L	PARTICIPANT	\N	PRESENT	0
817361	815872	19649G	PARTICIPANT	\N	PRESENT	0
817363	815872	20036X	PARTICIPANT	\N	PRESENT	0
817364	815872	14111D	PARTICIPANT	\N	PRESENT	0
817366	815872	14189C	PARTICIPANT	\N	PRESENT	0
817368	815872	10015M	PARTICIPANT	\N	PRESENT	0
817371	815872	21076L	PARTICIPANT	\N	PRESENT	0
817372	815872	21043B	PARTICIPANT	\N	PRESENT	0
817373	815872	19725B	PARTICIPANT	\N	PRESENT	0
817375	815872	14089Y	PARTICIPANT	\N	PRESENT	0
817377	815872	21044C	PARTICIPANT	\N	PRESENT	0
817379	815872	11056N	PARTICIPANT	\N	PRESENT	0
817383	815872	14069U	PARTICIPANT	\N	PRESENT	0
817386	815872	19749K	PARTICIPANT	\N	PRESENT	0
817387	815872	18207D	PARTICIPANT	\N	PRESENT	0
817388	815872	14259Y	PARTICIPANT	\N	PRESENT	0
817594	817593	20090E	PARTICIPANT	\N	PRESENT	0
817595	817593	19447X	PARTICIPANT	\N	PRESENT	0
817596	817593	20118Y	PARTICIPANT	\N	PRESENT	0
817597	817593	14173T	PARTICIPANT	\N	PRESENT	0
817599	817598	20056C	PARTICIPANT	\N	PRESENT	0
817600	817598	14229S	PARTICIPANT	\N	PRESENT	0
817601	817598	20142Y	PARTICIPANT	\N	PRESENT	0
817602	817598	19693L	PARTICIPANT	\N	PRESENT	0
817603	817598	19735D	PARTICIPANT	\N	PRESENT	0
817604	817598	21089R	PARTICIPANT	\N	PRESENT	0
817651	815936	20086J	PARTICIPANT	\N	PRESENT	0
817652	815936	11027H	PARTICIPANT	\N	PRESENT	0
817653	815936	07004J	PARTICIPANT	\N	PRESENT	0
817654	815936	20264J	PARTICIPANT	\N	PRESENT	0
817655	815930	14331P	PRESIDENT	0	PRESENT	0
817656	815930	14133K	PARTICIPANT	\N	PRESENT	0
817657	815930	14189C	PARTICIPANT	\N	PRESENT	0
817658	815930	20094J	PARTICIPANT	\N	PRESENT	0
817659	815930	17737W	PARTICIPANT	\N	PRESENT	0
817660	815930	19701S	PARTICIPANT	\N	PRESENT	0
817661	815930	18395Y	PARTICIPANT	\N	PRESENT	0
817662	815930	20248J	PARTICIPANT	\N	EXCUSE	0
817663	815930	20100N	PARTICIPANT	\N	PRESENT	0
817664	815930	14033T	PARTICIPANT	\N	PRESENT	0
817665	815930	20106U	PARTICIPANT	\N	PRESENT	0
817666	815930	19569H	PARTICIPANT	\N	PRESENT	0
817667	815930	19683J	PARTICIPANT	\N	PRESENT	0
817668	815930	14073Q	PARTICIPANT	\N	EXCUSE	0
817669	815936	12028B	PARTICIPANT	\N	PRESENT	0
817670	815930	19711U	PARTICIPANT	\N	PRESENT	0
817671	815936	20114U	PARTICIPANT	\N	PRESENT	0
817672	815930	08034U	PARTICIPANT	\N	PRESENT	0
817673	815930	21054E	PARTICIPANT	\N	EXCUSE	0
817674	815936	19563B	PARTICIPANT	\N	PRESENT	0
817675	815936	20128B	PARTICIPANT	\N	PRESENT	0
817676	815930	14001X	PARTICIPANT	\N	PRESENT	0
817677	815936	14033T	PARTICIPANT	\N	PRESENT	0
817678	815930	04070G	PARTICIPANT	\N	PRESENT	0
817679	815936	21039F	PARTICIPANT	\N	PRESENT	0
817680	815930	14169X	PARTICIPANT	\N	PRESENT	0
817681	815930	21037D	PARTICIPANT	\N	PRESENT	0
817682	815936	20068G	PARTICIPANT	\N	PRESENT	0
817683	815930	08073C	PARTICIPANT	\N	PRESENT	0
817684	815936	21029D	PARTICIPANT	\N	PRESENT	0
817685	815930	10015M	PARTICIPANT	\N	PRESENT	0
817686	815936	21055F	PARTICIPANT	\N	PRESENT	0
817687	815930	20098N	PARTICIPANT	\N	EXCUSE	0
817688	815930	21049H	PARTICIPANT	\N	PRESENT	0
817689	815936	20054A	PARTICIPANT	\N	PRESENT	0
817691	815936	21087P	PARTICIPANT	\N	PRESENT	0
797588	793595	20038A	PARTICIPANT	\N	PRESENT	0
797589	793595	21034A	PARTICIPANT	\N	PRESENT	0
797590	793595	20180F	PARTICIPANT	\N	PRESENT	0
797591	793595	19798U	PARTICIPANT	\N	PRESENT	0
797592	793595	21087P	PARTICIPANT	\N	PRESENT	0
797593	793595	19749K	PRESIDENT	0	PRESENT	0
797594	793595	21089R	PARTICIPANT	\N	PRESENT	0
797595	793595	19693L	PARTICIPANT	\N	PRESENT	0
797606	793595	11045K	PARTICIPANT	\N	PRESENT	0
797608	793595	07029T	PARTICIPANT	\N	EXCUSE	0
797634	797633	19760E	PARTICIPANT	\N	PRESENT	0
797635	797633	14026U	PARTICIPANT	\N	PRESENT	0
797636	797633	19683J	PARTICIPANT	\N	PRESENT	0
797673	793997	20094J	PARTICIPANT	\N	PRESENT	0
797674	793997	08034U	PARTICIPANT	\N	PRESENT	0
797765	797609	08010L	PARTICIPANT	\N	EXCUSE	0
797801	797609	17229F	PARTICIPANT	\N	EXCUSE	0
801118	801116	19679N	PARTICIPANT	\N	PRESENT	0
801119	801116	21046E	PARTICIPANT	\N	PRESENT	0
801121	801116	21049H	PARTICIPANT	\N	PRESENT	0
801122	801117	21046E	PARTICIPANT	\N	PRESENT	0
801123	801117	21049H	PARTICIPANT	\N	PRESENT	0
801124	801117	19679N	PARTICIPANT	\N	PRESENT	0
801125	801117	18193Q	PARTICIPANT	\N	PRESENT	0
801128	801127	14215L	PARTICIPANT	\N	PRESENT	0
801129	801127	18231D	PARTICIPANT	\N	PRESENT	0
801130	801127	19649G	PARTICIPANT	\N	PRESENT	0
801131	801127	21038E	PARTICIPANT	\N	PRESENT	0
801484	801483	14205J	PARTICIPANT	\N	PRESENT	1
801485	801483	14033T	PARTICIPANT	\N	PRESENT	1
806440	806438	19693L	PARTICIPANT	\N	PRESENT	0
806441	806438	14213J	PARTICIPANT	\N	PRESENT	0
806442	806438	19735D	PARTICIPANT	\N	PRESENT	0
806443	806438	19723Y	PARTICIPANT	\N	PRESENT	0
806444	806438	14223L	PARTICIPANT	\N	PRESENT	0
806445	806438	14071N	PARTICIPANT	\N	PRESENT	0
806446	806438	19798U	PARTICIPANT	\N	PRESENT	0
806447	806438	04092N	PARTICIPANT	\N	PRESENT	0
806448	806438	21081H	PARTICIPANT	\N	PRESENT	0
806450	806449	17965H	PARTICIPANT	\N	PRESENT	0
806451	806449	21039F	PARTICIPANT	\N	PRESENT	0
806452	805482	19758L	PARTICIPANT	\N	PRESENT	0
806453	805482	21045D	PARTICIPANT	\N	PRESENT	0
806454	805482	21039F	PARTICIPANT	\N	PRESENT	0
806455	805482	17965H	PARTICIPANT	\N	PRESENT	0
808448	807402	14071N	PRESIDENT	\N	PRESENT	0
808449	807402	19760E	PARTICIPANT	\N	PRESENT	0
808450	807402	19367Y	PARTICIPANT	\N	PRESENT	0
808451	807402	08061X	PARTICIPANT	\N	PRESENT	0
808452	807402	01034P	PARTICIPANT	\N	PRESENT	0
808453	807402	21049H	PARTICIPANT	\N	PRESENT	0
808454	807402	21071F	PARTICIPANT	\N	PRESENT	0
808455	807402	19629C	PARTICIPANT	\N	PRESENT	0
808456	807402	19591F	PARTICIPANT	\N	PRESENT	0
808457	807402	21087P	PARTICIPANT	\N	PRESENT	0
808458	807402	17779H	PARTICIPANT	\N	PRESENT	0
808459	807402	20248J	PARTICIPANT	\N	PRESENT	0
808460	807402	14217N	PARTICIPANT	\N	PRESENT	0
808461	807402	14195A	PARTICIPANT	\N	PRESENT	0
808462	807402	14026U	PARTICIPANT	\N	PRESENT	0
808463	807402	19569H	PARTICIPANT	\N	PRESENT	0
808464	807402	08045X	PARTICIPANT	\N	PRESENT	0
808465	807402	14281W	PARTICIPANT	\N	PRESENT	0
808466	807402	19723Y	PARTICIPANT	\N	PRESENT	0
808467	807402	21045D	PARTICIPANT	\N	PRESENT	0
808468	807402	20140W	PARTICIPANT	\N	PRESENT	0
808469	807402	21039F	PARTICIPANT	\N	PRESENT	0
808470	807402	19798U	PARTICIPANT	\N	PRESENT	0
808471	807402	18193Q	PARTICIPANT	\N	PRESENT	0
808472	807402	21081H	PARTICIPANT	\N	PRESENT	0
808473	807402	17965H	PARTICIPANT	\N	PRESENT	0
808474	807402	21094N	PARTICIPANT	\N	PRESENT	0
808475	807402	19657G	PARTICIPANT	\N	PRESENT	0
808476	807402	04092N	PARTICIPANT	\N	PRESENT	0
808477	807402	14223L	PARTICIPANT	\N	PRESENT	0
808478	807402	19683J	PARTICIPANT	\N	PRESENT	0
808479	807402	14213J	PARTICIPANT	\N	PRESENT	0
808480	807402	20130U	PARTICIPANT	\N	EXCUSE	0
808481	807402	20090E	PARTICIPANT	\N	EXCUSE	0
808482	807402	21046E	PARTICIPANT	\N	EXCUSE	0
808483	807402	19679N	PARTICIPANT	\N	PRESENT	0
808484	807402	19691J	PARTICIPANT	\N	PRESENT	0
808485	807402	21064G	PARTICIPANT	\N	PRESENT	0
808486	807402	19703U	PARTICIPANT	\N	PRESENT	0
808487	807402	20096L	PARTICIPANT	\N	PRESENT	0
810326	810317	20082E	PARTICIPANT	\N	PRESENT	0
810324	810316	20082E	PARTICIPANT	\N	PRESENT	0
810325	810316	20026V	PARTICIPANT	\N	PRESENT	0
810327	810317	20026V	PARTICIPANT	\N	PRESENT	0
810329	810328	20076G	PARTICIPANT	\N	PRESENT	0
810343	810342	04042C	PARTICIPANT	\N	PRESENT	0
810344	810342	19565D	PARTICIPANT	\N	PRESENT	0
810345	810342	99004R	PARTICIPANT	\N	PRESENT	0
810346	810342	14097Y	PARTICIPANT	\N	PRESENT	0
810347	810342	19421M	PARTICIPANT	\N	PRESENT	0
810348	810342	14255U	PARTICIPANT	\N	PRESENT	0
810352	810339	18231D	PARTICIPANT	\N	PRESENT	0
810353	810340	14281W	PARTICIPANT	\N	PRESENT	0
810354	810340	14071N	PARTICIPANT	\N	PRESENT	0
810355	810340	21064G	PARTICIPANT	\N	PRESENT	0
810356	810340	19723Y	PARTICIPANT	\N	PRESENT	0
810357	810350	14038Y	PARTICIPANT	\N	PRESENT	0
810362	810360	21067K	PARTICIPANT	\N	PRESENT	0
810431	810428	04047H	PARTICIPANT	\N	PRESENT	0
810432	810428	05008E	PARTICIPANT	\N	PRESENT	0
810433	810428	14089Y	PARTICIPANT	\N	PRESENT	0
810434	810428	18231D	PARTICIPANT	\N	PRESENT	0
810453	810452	20094J	PARTICIPANT	\N	PRESENT	0
810454	810452	14329V	PARTICIPANT	\N	PRESENT	0
810455	810452	17023S	PARTICIPANT	\N	PRESENT	0
810456	810452	14073Q	PARTICIPANT	\N	PRESENT	0
810457	810452	14031R	PARTICIPANT	\N	PRESENT	0
810458	810452	14221J	PARTICIPANT	\N	PRESENT	0
810459	810452	20030R	PARTICIPANT	\N	PRESENT	0
810460	810452	19349W	PARTICIPANT	\N	PRESENT	0
810462	810452	20082E	PARTICIPANT	\N	PRESENT	0
810463	810452	20044X	PARTICIPANT	\N	PRESENT	0
810464	810452	04045F	PARTICIPANT	\N	PRESENT	0
810465	810452	20062A	PARTICIPANT	\N	PRESENT	0
810466	810452	20084G	PARTICIPANT	\N	PRESENT	0
810479	810440	21090J	PARTICIPANT	\N	PRESENT	0
810480	810440	19591F	PARTICIPANT	\N	PRESENT	0
810481	810440	14215L	PARTICIPANT	\N	PRESENT	0
810482	810440	21042A	PARTICIPANT	\N	PRESENT	0
810483	810440	20132W	PARTICIPANT	\N	PRESENT	0
810484	810440	19657G	PARTICIPANT	\N	PRESENT	0
810485	810440	14073Q	PARTICIPANT	\N	PRESENT	0
810486	810440	10015M	PARTICIPANT	\N	PRESENT	0
810487	810439	21090J	PARTICIPANT	\N	PRESENT	0
810488	810439	19591F	PARTICIPANT	\N	PRESENT	0
810489	810439	18193Q	PARTICIPANT	\N	PRESENT	1
810490	810443	21090J	PARTICIPANT	\N	PRESENT	0
810491	810443	19591F	PARTICIPANT	\N	PRESENT	0
810492	810451	21090J	PARTICIPANT	\N	PRESENT	0
810493	810451	19591F	PARTICIPANT	\N	PRESENT	0
810494	810478	21090J	PARTICIPANT	\N	PRESENT	0
810495	810478	19591F	PARTICIPANT	\N	PRESENT	0
810496	810478	20132W	PARTICIPANT	\N	PRESENT	1
810500	810498	14083S	PARTICIPANT	\N	PRESENT	0
810501	810497	14083S	PARTICIPANT	\N	PRESENT	0
810503	810502	14083S	PARTICIPANT	\N	PRESENT	0
810504	810502	21041Y	PARTICIPANT	\N	PRESENT	0
810529	810527	20136B	PARTICIPANT	\N	PRESENT	0
810530	810527	20100N	PARTICIPANT	\N	PRESENT	0
810534	810533	20136B	PARTICIPANT	\N	PRESENT	0
810586	810266	14151M	PRESIDENT	0	PRESENT	0
810587	810266	17367Q	PARTICIPANT	\N	PRESENT	0
810588	810266	12028B	PARTICIPANT	\N	PRESENT	0
810589	810266	17737W	PARTICIPANT	\N	PRESENT	0
810593	810590	14038Y	PARTICIPANT	\N	PRESENT	0
810594	810590	04070G	PRESIDENT	0	PRESENT	0
810595	810590	20134Y	PARTICIPANT	\N	PRESENT	0
810596	810590	20062A	PARTICIPANT	\N	PRESENT	0
810597	810590	11045K	PARTICIPANT	\N	PRESENT	0
810598	810590	14179A	PARTICIPANT	\N	PRESENT	0
810599	810590	20094J	PARTICIPANT	\N	PRESENT	0
810600	810590	20022R	PARTICIPANT	\N	PRESENT	0
810601	810590	14030Q	PARTICIPANT	\N	PRESENT	0
\.


--
-- Data for Name: activite_senateur; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY activite_senateur (actsenid, senmat, typactsencod, datdeb, datfin, libelle) FROM stdin;
54	11054L	REU_TRAV_PARL	2016-10-03 10:00:00	2016-10-03 11:00:00	Président Assemblée nationale
44	11054L	COLL_TER	2016-10-07 09:00:00	2016-10-07 11:00:00	Rencontres Bond'Innov
56	11054L	ACC_VISIT	2016-10-06 09:00:00	2016-10-06 10:00:00	rendez-vous
59	11054L	ELUS_LOCAUX	2016-10-07 11:00:00	2016-10-07 12:00:00	Maire de Bondy
75	08034U	REU_TRAV_PARL	2016-10-11 19:00:00	2016-10-11 20:30:00	AG AMICALE GAULLISTE
76	08034U	REU_TRAV_PARL	2016-10-11 20:30:00	2016-10-11 22:00:00	DÎNER-DEBAT AMICALE GAULLISTE AVEC YVES DE GAULLE
77	08034U	REU_TRAV_PARL	2016-10-12 08:00:00	2016-10-12 09:00:00	REUNION MSA
78	08034U	REU_TRAV_PARL	2016-10-12 13:00:00	2016-10-12 14:30:00	RV CAISSE DES DEPÔTS
80	97011G	ORGEXTPAR	2016-10-11 08:00:00	2016-10-11 20:00:00	Conseil de l'Europe
86	11091R	ELUS_LOCAUX	2016-10-10 08:30:00	2016-10-10 10:30:00	Sécurité dans les écoles et collèges
87	08010L	REU_GVT	2016-09-28 12:00:00	2016-09-28 14:30:00	Budget Justice
89	11091R	ACC_DEPL_INTER	2016-10-12 18:30:00	2016-10-12 20:30:00	Ambassade Espagne
92	08010L	ELUS_LOCAUX	2016-09-28 18:15:00	2016-09-28 19:15:00	\N
95	11090Q	ORG_POL	2016-09-28 14:30:00	2016-09-28 15:00:00	\N
99	11090Q	ORG_POL	2016-09-21 19:00:00	2016-09-21 22:00:00	\N
97	11090Q	ORGEXTPAR	2016-09-22 10:00:00	2016-09-22 13:00:00	\N
98	11090Q	REU_TRAV_PARL	2016-09-21 10:30:00	2016-09-21 13:00:00	\N
100	11090Q	ELUS_LOCAUX	2016-09-21 14:00:00	2016-09-21 16:00:00	\N
101	11090Q	ACC_VISIT	2016-09-27 14:45:00	2016-09-27 16:00:00	Rendez-vous
102	11090Q	ACC_VISIT	2016-09-27 17:30:00	2016-09-27 18:30:00	Rendez-vous
188	14107H	ORG_POL	2016-10-06 14:00:00	2016-10-06 16:00:00	ASSEMBLEE NATIONALE
189	14107H	COLL_TER	2016-10-10 09:00:00	2016-10-10 12:00:00	Commission AT CD04
185	14107H	REU_TRAV_PARL	2016-10-13 09:00:00	2016-10-13 19:00:00	Congres ANEM
190	14107H	COLL_TER	2016-10-10 14:00:00	2016-10-10 16:00:00	Commission Finances CD04
229	11054L	REU_TRAV_PARL	2016-10-25 10:00:00	2016-10-25 12:30:00	Groupe PS
230	11054L	ELUS_LOCAUX	2016-10-25 12:30:00	2016-10-25 14:00:00	\N
231	11054L	ELUS_LOCAUX	2016-10-25 20:00:00	2016-10-25 22:00:00	\N
232	11054L	ACC_VISIT	2016-10-26 12:30:00	2016-10-26 14:00:00	\N
233	11054L	ORGEXTPAR	2016-10-27 09:00:00	2016-10-27 22:00:00	AP-OTAN - Séminaire conjoint - Rome
234	11054L	ORGEXTPAR	2016-10-28 09:00:00	2016-10-28 22:00:00	AP-OTAN - Séminaire conjoint - Rome
348	11029K	ACC_VISIT	2016-10-24 17:00:00	2016-10-24 18:00:00	\N
343	11054L	ELUS_LOCAUX	2016-11-03 12:30:00	2016-11-03 14:00:00	\N
347	11054L	ELUS_LOCAUX	2016-11-17 12:30:00	2016-11-17 14:00:00	\N
383	14107H	ELUS_LOCAUX	2016-10-20 09:00:00	2016-10-20 17:00:00	rencontre des Maires du 04
384	14107H	ELUS_LOCAUX	2016-10-21 09:00:00	2016-10-21 17:00:00	rencontre des Maires du 04
581	95063L	ORGEXTPAR	2016-11-03 14:00:00	2016-11-03 16:00:00	Conseil National de la Transition Ecologique 
582	95063L	REU_GVT	2016-11-02 12:00:00	2016-11-02 13:00:00	Réunion Projet de loi Statut de Paris avec le Cabinet de la Ministre du  Logement
592	14107H	ELUS_LOCAUX	2016-11-07 09:00:00	2016-11-07 10:30:00	mairie PEYRUIS
770	11054L	REU_TRAV_PARL	2016-11-22 10:00:00	2016-11-22 13:00:00	Bureau et groupe PS
602	01024M	ELUS_LOCAUX	2016-11-16 10:30:00	2016-11-16 15:00:00	Visite de maires marnais au Sénat
772	11054L	ELUS_LOCAUX	2016-11-23 12:30:00	2016-11-23 14:00:00	\N
771	11054L	ELUS_LOCAUX	2016-11-22 20:00:00	2016-11-22 22:30:00	\N
773	11054L	DEL_ACT_PAR	2016-11-24 11:00:00	2016-11-24 12:00:00	\N
774	11054L	ORG_POL	2016-11-24 20:00:00	2016-11-24 22:30:00	\N
775	11054L	COLL_TER	2016-11-25 17:30:00	2016-11-25 19:00:00	Rendez-vous avec le Ministère de l'Ecologie au sujet de Bond'Innov - Bondy
776	11054L	COLL_TER	2016-11-28 09:00:00	2016-11-28 11:30:00	Assemblée générale de Bondy Innovation
1204	14041T	ELUS_LOCAUX	2016-11-09 09:00:00	2016-11-09 21:00:00	déplacement Inde
778	11054L	REU_TRAV_PARL	2016-11-29 10:00:00	2016-11-29 13:00:00	Bureau et groupe PS
779	11054L	ORG_POL	2016-11-30 20:00:00	2016-11-30 22:00:00	\N
780	11054L	ORGEXTPAR	2016-12-01 09:00:00	2016-12-01 18:30:00	Forum transatlantique Washington
781	11054L	ORGEXTPAR	2016-12-02 09:00:00	2016-12-02 18:30:00	Forum transatlantique Washington
782	11054L	ORGEXTPAR	2016-12-05 09:00:00	2016-12-05 18:30:00	Forum transatlantique Washington
783	11054L	ORGEXTPAR	2016-12-06 09:00:00	2016-12-06 18:30:00	Forum transatlantique Washington
784	11054L	ORG_POL	2016-12-08 17:00:00	2016-12-08 22:00:00	\N
821	08009T	DEPL_PRES_GVT	2016-11-15 09:00:00	2016-11-15 19:00:00	\N
822	08009T	DEPL_PRES_GVT	2016-11-16 09:00:00	2016-11-16 19:00:00	\N
823	08009T	REU_TRAV_PARL	2016-11-17 16:15:00	2016-11-17 18:00:00	Audition de Jean-Michel BAYLET
861	04040A	DEPL_PRES_GVT	2016-11-22 08:00:00	2016-11-22 14:19:00	Déplacement à Starsbourg du groupe de suivi sur le retrait du Royaume-Uni et la refondation de l'Union européenne
901	11063M	REU_TRAV_PARL	2016-11-21 14:00:00	2016-11-21 16:00:00	sur l'Aide à Domicile
902	11063M	ACC_VISIT	2016-11-14 09:30:00	2016-11-14 15:00:00	Maires du Pas-de-Calais
903	11063M	REU_TRAV_PARL	2016-11-07 14:00:00	2016-11-07 17:00:00	sur les Mineurs de 1948
904	11063M	ELUS_LOCAUX	2016-11-09 18:30:00	2016-11-09 21:00:00	sur les Finances Locales
921	11063M	REU_TRAV_PARL	2016-11-04 09:30:00	2016-11-04 13:00:00	sur l'automobile
922	11063M	REU_TRAV_PARL	2016-10-20 09:00:00	2016-10-20 21:00:00	sur les Conseils Municipaux de Jeunes, à Grenay, Leforest et Saint-Etienne-au-Mont
923	11063M	REU_TRAV_PARL	2016-10-13 09:00:00	2016-10-13 12:00:00	sur les conditions de travail dans l'Agroalimentaire, à Boulogne
924	11063M	REU_TRAV_PARL	2016-10-10 09:00:00	2016-10-10 18:00:00	sur la situation à Calais : rencontre et échanges avec les responsables nationaux du PCF, avec les associatifs présents dans la Lande, rencontre avec les syndicalistes du port, du tunnel et visite du camp de migrants.
1202	08010L	ORG_POL	2016-11-29 11:00:00	2016-11-29 13:00:00	\N
1206	14041T	ELUS_LOCAUX	2016-11-23 09:00:00	2016-11-23 21:00:00	déplacement Singapour
1207	14041T	ELUS_LOCAUX	2016-11-24 09:00:00	2016-11-24 21:00:00	déplacement Singapour
1208	14041T	ELUS_LOCAUX	2016-11-29 09:00:00	2016-11-29 21:00:00	déplacement Singapour
1281	04042C	ORG_POL	2016-11-29 11:00:00	2016-11-29 13:00:00	Groupe Les Républicains du Sénat
1282	04042C	ORG_POL	2016-11-29 17:45:00	2016-11-29 20:00:00	Réunion du Bureau Politique National Les Républicains
1283	04042C	ACC_DEPL_INTER	2016-11-30 18:30:00	2016-11-30 21:30:00	Cérémonie de remise des insignes du Wissam Al Alaoui - ambassade du Maroc en France 
1303	14089Y	ELUS_LOCAUX	2016-12-19 15:00:00	2016-12-19 16:00:00	\N
1304	14089Y	ELUS_LOCAUX	2016-12-02 20:00:00	2016-12-02 22:00:00	\N
1305	04042C	CEREMONIE	2016-11-24 14:00:00	2016-11-24 16:00:00	25ème anniversaire du CFA Sup 000 de l'académie de Créteil
1306	04042C	ELUS_LOCAUX	2016-11-24 18:30:00	2016-11-24 23:30:00	Accueil au Sénat des élus d'opposition de Choisy-le-Roi
1307	04042C	ORG_POL	2016-11-23 17:00:00	2016-11-23 17:30:00	Débat sur Public Sénat sur la fermeture des voies sur berges par la mairie de Paris
3802	04042C	COLL_TER	2016-06-17 09:30:00	2016-06-17 10:00:00	\N
1308	04042C	ORG_POL	2016-11-22 11:00:00	2016-11-22 12:30:00	Réunion du Groupe Les Républicains du Sénat
1309	04042C	ELUS_LOCAUX	2016-11-17 13:00:00	2016-11-17 14:30:00	déjeuner avec des élus du Val-de-Marne
1310	04042C	ELUS_LOCAUX	2016-11-17 17:30:00	2016-11-17 20:00:00	Réunion de la commission "Projet métropolitain" de la Métropole du grand Paris
1321	04042C	REU_TRAV_PARL	2016-07-06 16:00:00	2016-07-06 18:00:00	Visite de la Garde Républicaine par le Bureau du Sénat avec Gérard Larcher, Président du Sénat
1322	04042C	ELUS_LOCAUX	2016-07-06 18:45:00	2016-07-06 23:30:00	Rencontre au Sénat avec les élus de Saint-Maur-des-Fossés
1323	04042C	ELUS_LOCAUX	2016-07-05 15:30:00	2016-07-05 18:00:00	Rendez-vous en mairie de Saint-Maurice
1324	04042C	ELUS_LOCAUX	2016-06-30 13:00:00	2016-06-30 14:30:00	déjeuner avec un élu du Val-de-Marne
1325	04042C	ELUS_LOCAUX	2016-06-30 16:30:00	2016-06-30 18:30:00	Rendez-vous avec des élus du Val-de-Marne
1326	04042C	ACC_DEPL_INTER	2016-06-29 15:30:00	2016-06-29 16:30:00	Entretien avec l'ambassadeur britannique, Sir Julian Kind, à l'Ambassade
1327	04042C	REU_GVT	2016-06-29 19:15:00	2016-06-29 21:00:00	cérémonie de signature du contrat d'objectifs de l'AEFE au Quai d'Orsay
1328	04042C	ORG_POL	2016-06-28 11:00:00	2016-06-28 12:30:00	Réunion du Groupe Les Républicains du Sénat
1329	04042C	ORG_POL	2016-06-28 07:45:00	2016-06-28 10:30:00	Réunion du Bureau politique départemental
1330	04042C	ELUS_LOCAUX	2016-06-28 13:00:00	2016-06-28 14:30:00	Déjeuner avec des parlemenaires
1341	04042C	REU_GVT	2016-06-15 08:30:00	2016-06-15 11:00:00	Cérémonie de ratification de l'accord de Paris sur la Climat à l'Elysée
1342	04042C	REU_TRAV_PARL	2016-06-15 19:30:00	2016-06-15 20:30:00	Conférence des Président du Sénat
1404	04042C	REU_TRAV_PARL	2016-05-04 15:00:00	2016-05-04 16:00:00	auditon du Groupe de travail Australie
1405	04042C	ORG_POL	2016-05-03 11:00:00	2016-05-03 12:30:00	Réunion du Groupe Les Républicains du Sénat
141	11054L	REU_TRAV_PARL	2016-10-11 10:00:00	2016-10-11 13:00:00	groupe PS
308	14041T	ORG_POL	2016-09-27 11:00:00	2016-09-27 12:30:00	Groupe LR Sénat
143	11054L	REU_TRAV_PARL	2016-10-11 14:00:00	2016-10-11 15:00:00	coordination
144	11054L	ELUS_LOCAUX	2016-10-12 19:00:00	2016-10-12 20:00:00	93
145	11054L	ELUS_LOCAUX	2016-10-12 20:00:00	2016-10-12 22:00:00	bondy
146	11054L	ACC_VISIT	2016-10-13 08:30:00	2016-10-13 09:30:00	\N
154	11054L	CEREMONIE	2016-10-18 10:30:00	2016-10-18 12:00:00	Lancement des travaux de la nouvelle branche du Tram 4
155	11054L	COLL_TER	2016-10-18 20:00:00	2016-10-18 22:00:00	Réunion PLU Bondy
156	11054L	REU_TRAV_PARL	2016-10-20 11:30:00	2016-10-20 17:00:00	EURONAVAL au Bourget
158	14061L	ELUS_LOCAUX	2016-10-19 11:00:00	2016-10-19 15:00:00	\N
159	14061L	COLLOQUE	2016-10-19 18:00:00	2016-10-19 20:00:00	\N
162	14061L	ELUS_LOCAUX	2016-10-06 18:00:00	2016-10-06 20:00:00	\N
304	14041T	ELUS_LOCAUX	2016-10-21 09:00:00	2016-10-21 21:00:00	déplacement Australie
307	14041T	ORG_POL	2016-10-04 11:00:00	2016-10-04 12:30:00	Groupe LR Sénat
324	08047A	ORG_POL	2016-10-18 11:00:00	2016-10-18 13:00:00	REUNION GROUPE LR
312	08010L	ORG_POL	2016-10-18 12:00:00	2016-10-18 12:30:00	\N
322	08047A	REU_TRAV_PARL	2016-10-19 09:00:00	2016-10-19 13:00:00	COMMISSION AFFAIRES ETRANGERES
323	08047A	REU_TRAV_PARL	2016-10-19 14:00:00	2016-10-19 18:00:00	SEANCE
325	08047A	ACC_VISIT	2016-10-18 14:30:00	2016-10-18 16:00:00	\N
326	08047A	REU_TRAV_PARL	2016-10-25 10:15:00	2016-10-25 11:00:00	COMMISSAIRES CAE
327	08047A	ORG_POL	2016-10-25 11:00:00	2016-10-25 13:00:00	REUNION LR
328	08047A	COLL_TER	2016-10-25 15:00:00	2016-10-25 16:00:00	CCI CHINE EN FRANCE
329	08047A	ORG_POL	2016-10-25 18:00:00	2016-10-25 20:00:00	\N
335	11031D	ORG_POL	2016-10-17 09:00:00	2016-10-17 17:00:00	\N
340	11031D	REU_TRAV_PARL	2016-10-19 09:00:00	2016-10-19 12:00:00	Commission Affaires Sociales
464	04043D	COLLOQUE	2016-10-25 14:30:00	2016-10-25 16:00:00	Vaccins
465	04043D	ELUS_LOCAUX	2016-10-26 15:00:00	2016-10-26 16:00:00	\N
466	04043D	REU_TRAV_PARL	2016-10-26 12:30:00	2016-10-26 14:00:00	\N
467	04043D	CEREMONIE	2016-11-02 11:00:00	2016-11-02 12:00:00	ANAI
501	08010L	ORG_POL	2016-11-02 12:00:00	2016-11-02 13:00:00	\N
507	04040A	DEPL_PRES_GVT	2016-11-08 07:30:00	2016-11-08 19:00:00	Déplacement officiel avec M. Gérard LARCHER, Président du Sénat
508	04040A	DEPL_PRES_GVT	2016-11-09 08:00:00	2016-11-09 11:00:00	Déplacement officiel avec M. Gérard LARCHER, Président du Sénat
506	04040A	COLLOQUE	2016-11-03 13:30:00	2016-11-03 19:00:00	Colloque organisé par M. Jean-Marie BOCKEL : "L'Afrique est notre avenir : pour le pire ou pour le meillleur ?"
505	04040A	ACC_DEPL_INTER	2016-11-03 11:30:00	2016-11-03 13:00:00	Entretien du Président du Sénat avec la Présidente du Bundesrat, Mme Malu Dreyer
509	04040A	CEREMONIE	2016-11-10 08:45:00	2016-11-10 09:00:00	Intervention dans le cadre des Rencontres Parlementaires de la Cybersécurité
521	04042C	COLLOQUE	2016-09-06 10:00:00	2016-09-06 14:00:00	Université de la Défense
522	04042C	ORG_POL	2016-09-06 18:00:00	2016-09-06 20:00:00	Bureau Les Républicains
523	04042C	ORG_POL	2016-09-07 12:00:00	2016-09-07 13:00:00	Conférence de presse sur la fermetures des voies sur berge de Paris
524	04042C	ELUS_LOCAUX	2016-09-07 18:30:00	2016-09-07 20:30:00	Conférence EPT des Maires et Vice-présidents
525	04042C	ORG_POL	2016-09-27 11:00:00	2016-09-27 13:00:00	Réunion de Groupe Les Républicains du Sénat
526	04042C	REU_TRAV_PARL	2016-09-27 15:45:00	2016-09-27 16:15:00	Réunion préparatoire au Groupe de travail Brexit
527	04042C	REU_TRAV_PARL	2016-09-27 16:15:00	2016-09-27 17:45:00	Audition Groupe de travail Brexit
532	08009T	REU_TRAV_PARL	2016-11-09 17:45:00	2016-11-09 18:45:00	\N
529	08009T	REU_TRAV_PARL	2016-11-08 11:00:00	2016-11-08 12:00:00	\N
530	08009T	ORG_POL	2016-11-09 12:00:00	2016-11-09 13:00:00	\N
531	08009T	REU_TRAV_PARL	2016-11-09 15:00:00	2016-11-09 17:00:00	\N
533	04042C	ACC_DEPL_INTER	2016-09-27 17:00:00	2016-09-27 20:00:00	Audition du Président de l'Assemblée Nationale populaire de Chine à la Présidence du Sénat
534	04042C	ORG_POL	2016-09-27 20:30:00	2016-09-27 22:30:00	Débat sur les Primaires de la droite et du centre à Bry-sur-Marne
535	04042C	ACC_DEPL_INTER	2016-09-28 08:30:00	2016-09-28 10:00:00	Entretien avec Jane D.Hartley, Ambassadeur des Etats-Unis en France
536	04042C	ORG_POL	2016-09-28 15:00:00	2016-09-28 16:00:00	Groupe Les Républicains du Sénat
537	04042C	CEREMONIE	2016-09-28 17:00:00	2016-09-28 18:30:00	Hommage au Sénateur Jacques Dominati
538	04042C	ORG_POL	2016-10-04 11:00:00	2016-10-04 13:00:00	Réunion de Groupe Les Républicains du Sénat
539	04042C	REU_TRAV_PARL	2016-10-04 14:30:00	2016-10-04 16:30:00	Auditions du Groupe Brexit
540	04042C	CEREMONIE	2016-10-04 18:30:00	2016-10-04 19:30:00	Remise des insignes de chevaliers de l'Ordre National du Mérite à un élu du Val-de-Marne
541	04042C	ORG_POL	2016-10-04 20:00:00	2016-10-04 22:00:00	Dîner autour de Valery Giscard d'Estaing
542	04042C	REU_GVT	2016-10-05 08:00:00	2016-10-05 09:15:00	Entretien avec jean-Marc Ayrault - Ministre des Affaires étrangères
6787	14065Q	ORG_POL	2017-07-04 15:00:00	2017-07-04 15:00:00	\N
543	04042C	ORG_POL	2016-10-06 19:00:00	2016-10-06 22:00:00	Comité d'organisation des Primaires de la droite et du centre du Val-de-Marne
544	04042C	REU_TRAV_PARL	2016-10-11 08:30:00	2016-10-11 10:00:00	Réunion du Bureau de la commission des Affaires étrangères, de la Défense et des Forces armées
545	04042C	ORG_POL	2016-10-11 11:00:00	2016-10-11 13:00:00	Réunion du Groupe Les Républicains du Sénat
546	04042C	ACC_DEPL_INTER	2016-10-12 13:00:00	2016-10-12 15:00:00	Entretien avec l'Ambassadeur  du Canada en France
547	04042C	ACC_DEPL_INTER	2016-10-12 19:30:00	2016-10-12 21:00:00	Audition du Président de la Grande Assemblée nationale de Turquie à la Présidence du Sénat
548	04042C	ORG_POL	2016-10-18 11:00:00	2016-10-18 12:30:00	Réunion du Groupe Les Républicains du Sénat
549	04042C	REU_TRAV_PARL	2016-10-19 13:00:00	2016-10-19 14:30:00	Déjeuner de travail du Groupe de travail Brexit en l'honneur de Lord Green et lord Gay
550	04042C	ACC_DEPL_INTER	2016-10-19 12:00:00	2016-10-19 13:00:00	Inauguration du centre culturel et spirituel orthodoxe russe
551	04042C	ELUS_LOCAUX	2016-10-20 11:00:00	2016-10-20 13:00:00	Comité du Syndicat des Eaux d'Ile-de-France
552	04042C	ELUS_LOCAUX	2016-10-25 08:30:00	2016-10-25 12:00:00	Réunion du Syndicat des Eaux d'Ile-de-France
553	04042C	REU_TRAV_PARL	2016-10-26 15:30:00	2016-10-26 16:30:00	Réunion groupe de travail Australie
554	04042C	ACC_DEPL_INTER	2016-10-27 18:00:00	2016-10-27 19:30:00	Audition du Premier ministre Ukrainien à la Présidence du Sénat
555	04042C	ORG_POL	2016-10-27 20:30:00	2016-10-27 22:00:00	Réunion sur les Primaires de la droite et du centre du Val-de-Marne
556	04042C	ORG_POL	2016-11-02 12:45:00	2016-11-02 13:30:00	Réunion du Groupe Les Républicains du Sénat
557	04042C	ELUS_LOCAUX	2016-11-02 19:00:00	2016-11-02 21:00:00	Conseil de Territoire
558	04042C	ELUS_LOCAUX	2016-11-03 08:00:00	2016-11-03 11:00:00	Réunion du Syndicat des Eaux d'Ile-de-France
559	04042C	ACC_VISIT	2016-11-03 18:00:00	2016-11-03 19:30:00	Conférence Groupe interparlementaire d'Amitié France Maroc au Sénat
560	04042C	ORG_POL	2016-07-05 11:00:00	2016-07-05 12:30:00	Réunion du Groupe Les Républicains du Sénat
561	04042C	ELUS_LOCAUX	2016-07-12 09:00:00	2016-07-12 10:00:00	Réunion sur la fermeture des voies sur berge de Paris
562	04042C	ORG_POL	2016-07-12 10:30:00	2016-07-12 12:00:00	Seminaire du Groupe Les républicains du Sénat
563	04042C	REU_TRAV_PARL	2016-07-12 13:00:00	2016-07-12 14:30:00	Réunion du Bureau du Sénat
564	04042C	ACC_DEPL_INTER	2016-07-13 09:00:00	2016-07-13 10:00:00	Audition du Ministre des Affaires étrangères de Tunisie à la Présidence du Sénat
621	11054L	REU_TRAV_PARL	2016-11-10 14:30:00	2016-11-10 16:30:00	Visite du centre de recrutement de Vincennes
622	11054L	ELUS_LOCAUX	2016-11-10 12:00:00	2016-11-10 13:30:00	\N
623	11054L	REU_TRAV_PARL	2016-11-10 11:00:00	2016-11-10 12:00:00	\N
624	04085P	ORG_POL	2016-10-10 08:00:00	2016-10-10 19:00:00	En délégation PCF à Calais: Rencontre avec les élus, syndicats et associations
625	08010L	ORG_POL	2016-11-08 11:00:00	2016-11-08 12:30:00	\N
626	08010L	REU_TRAV_PARL	2016-11-09 08:00:00	2016-11-09 09:30:00	\N
627	04085P	ORG_POL	2016-09-27 11:00:00	2016-09-27 12:00:00	St Ouen - Soutien aux Salariés d'Alstom
628	04085P	ORG_POL	2016-10-14 09:00:00	2016-10-14 19:00:00	Toulouse-débat sur les politiques migratoires et l'accueil en France et en Europe
629	04085P	ACC_VISIT	2016-10-24 15:00:00	2016-10-24 16:00:00	RDV avec Monsieur le Préfet de Seine-Saint-Denis
641	08010L	REU_TRAV_PARL	2016-11-09 13:00:00	2016-11-09 14:30:00	\N
631	04085P	ACC_VISIT	2016-11-14 17:00:00	2016-11-14 18:00:00	RDV SG préfecture de Seine-Saint-Denis
632	04085P	REU_GVT	2016-11-15 16:30:00	2016-11-15 18:00:00	Matignon: Point de situation après les attentats 
147	11054L	ACC_VISIT	2016-10-17 12:00:00	2016-10-17 16:00:00	visite Sénat
262	08010L	REU_TRAV_PARL	2016-10-12 13:00:00	2016-10-12 14:30:00	RDV Caisse des Dépots
149	14061L	ORG_POL	2016-10-11 11:00:00	2016-10-11 12:00:00	\N
150	14061L	REU_TRAV_PARL	2016-10-11 14:00:00	2016-10-11 18:00:00	\N
151	14061L	COLLOQUE	2016-10-11 18:00:00	2016-10-11 21:00:00	\N
152	14061L	CEREMONIE	2016-10-18 10:00:00	2016-10-18 12:00:00	\N
264	14103D	REU_TRAV_PARL	2016-10-04 11:00:00	2016-10-04 12:30:00	\N
157	14061L	DEL_ACT_PAR	2016-10-12 12:00:00	2016-10-12 14:00:00	sport
160	14061L	CEREMONIE	2016-10-25 17:45:00	2016-10-25 20:00:00	\N
161	14061L	ELUS_LOCAUX	2016-10-04 20:00:00	2016-10-04 23:00:00	\N
163	08034U	REU_TRAV_PARL	2016-10-26 08:00:00	2016-10-26 09:00:00	REUNION FNSEA
164	08034U	ORGEXTPAR	2016-10-20 09:00:00	2016-10-20 10:00:00	REUNION CCSDN
225	11091R	ORG_POL	2016-10-10 19:30:00	2016-10-10 23:00:00	\N
192	08010L	ORG_POL	2016-10-11 11:00:00	2016-10-11 12:30:00	\N
186	14107H	REU_TRAV_PARL	2016-10-14 09:00:00	2016-10-14 19:00:00	Congres ANEM
187	14107H	ORG_POL	2016-10-04 11:00:00	2016-10-04 13:00:00	SENAT
221	11054L	COLL_TER	2016-10-12 12:30:00	2016-10-12 14:30:00	\N
223	11054L	ELUS_LOCAUX	2016-10-13 12:30:00	2016-10-13 14:00:00	\N
224	11091R	ORG_POL	2016-10-17 19:30:00	2016-10-17 23:00:00	\N
330	11031D	DEPL_PRES_GVT	2016-10-03 09:00:00	2016-10-03 19:00:00	Conseil Administration Sciences Po Toulouse
263	14103D	REU_GVT	2016-10-04 14:30:00	2016-10-04 16:00:00	Rendez-vous avec le cabinet de Ségolène Neuville, Secrétaire d'État auprès de la ministre des Affaires sociales et de la Santé, chargée des Personnes handicapées et de la Lutte contre l'exclusion
265	14103D	REU_TRAV_PARL	2016-10-11 11:00:00	2016-10-11 12:30:00	\N
281	04043D	ELUS_LOCAUX	2016-09-22 19:00:00	2016-09-22 20:00:00	\N
301	14041T	ELUS_LOCAUX	2016-10-18 09:00:00	2016-10-18 21:00:00	déplacement Australie
302	14041T	ELUS_LOCAUX	2016-10-19 09:00:00	2016-10-19 21:00:00	déplacement Australie
303	14041T	ELUS_LOCAUX	2016-10-20 09:00:00	2016-10-20 21:00:00	déplacement Australie
305	14041T	ELUS_LOCAUX	2016-10-10 15:30:00	2016-10-10 17:00:00	\N
306	14041T	ORG_POL	2016-10-11 11:00:00	2016-10-11 12:30:00	Groupe LR Sénat
332	11031D	COLL_TER	2016-10-10 15:00:00	2016-10-10 17:00:00	Intervention Colloque Conseil Départemental du Val-de-Marne
331	11031D	ORG_POL	2016-10-10 09:00:00	2016-10-10 11:00:00	\N
321	11054L	ACC_VISIT	2016-10-20 18:00:00	2016-10-20 19:00:00	\N
333	11031D	COLL_TER	2016-10-11 19:00:00	2016-10-11 21:00:00	Couverture RER B Gentilly
334	11031D	DEPL_PRES_GVT	2016-10-13 09:00:00	2016-10-13 12:00:00	Visite Maison Arrêt Fresnes
339	11031D	CEREMONIE	2016-10-18 19:00:00	2016-10-18 21:00:00	70ème Anniversaire Maison Amérique Latine
337	11031D	ORG_POL	2016-10-18 13:30:00	2016-10-18 15:00:00	\N
338	11031D	ACC_DEPL_INTER	2016-10-18 10:00:00	2016-10-18 11:30:00	\N
341	11054L	COLL_TER	2016-10-24 09:30:00	2016-10-24 10:30:00	\N
342	11054L	ACC_VISIT	2016-10-24 12:00:00	2016-10-24 13:00:00	\N
344	11054L	ACC_VISIT	2016-11-07 12:30:00	2016-11-07 14:00:00	\N
345	11054L	REU_TRAV_PARL	2016-11-09 16:30:00	2016-11-09 17:30:00	Ministère de l'Ecologie sur dossier Fort de Vaujours
346	11054L	COLL_TER	2016-11-16 12:30:00	2016-11-16 14:00:00	\N
349	11029K	COLLOQUE	2016-10-25 09:00:00	2016-10-25 10:30:00	Les journalistes face aux vaccins
350	11029K	COLLOQUE	2016-10-25 18:00:00	2016-10-25 20:00:00	Projection-Débat du film "Tout devient silencieux"
363	01015L	ORG_POL	2016-10-18 18:30:00	2016-10-18 21:00:00	journées biodiversité
364	01015L	DEL_ACT_PAR	2016-10-20 15:00:00	2016-10-20 16:30:00	Taxis-VTC
365	01015L	DEL_ACT_PAR	2016-10-25 10:00:00	2016-10-25 11:30:00	Budget-Déchets
366	01015L	DEL_ACT_PAR	2016-10-25 14:00:00	2016-10-25 16:00:00	Déchets-conditions de travail
367	01015L	ORG_POL	2016-10-25 18:30:00	2016-10-25 21:00:00	Journées biodiversité
368	01015L	DEL_ACT_PAR	2016-10-26 14:00:00	2016-10-26 16:00:00	\N
369	01015L	DEL_ACT_PAR	2016-11-08 10:00:00	2016-11-08 11:30:00	autoroute
421	11054L	REU_TRAV_PARL	2016-10-25 14:30:00	2016-10-25 16:30:00	Réception d'une délégation du Parlement iranien.
422	14103D	REU_TRAV_PARL	2016-10-18 11:00:00	2016-10-18 12:30:00	\N
423	14103D	ACC_VISIT	2016-10-18 19:00:00	2016-10-18 21:00:00	\N
424	14103D	REU_GVT	2016-10-25 10:00:00	2016-10-25 11:00:00	Réunion avec le cabinet de Madame Pascale Boistard, Secrétaire d'État auprès de la ministre des Affaires sociales et de la Santé, chargée des Personnes âgées et de l¿Autonomie
425	14103D	REU_TRAV_PARL	2016-10-25 11:00:00	2016-10-25 12:30:00	\N
426	14103D	REU_TRAV_PARL	2016-10-26 08:30:00	2016-10-26 09:30:00	\N
481	08047A	REU_TRAV_PARL	2016-10-26 14:00:00	2016-10-26 18:00:00	SEANCE / PERMANENCE
486	01024M	COLL_TER	2016-11-02 14:00:00	2016-11-02 17:00:00	Grand Reims
583	04043D	CEREMONIE	2016-11-04 16:00:00	2016-11-04 19:00:00	Jardin d'agronomie tropicale bois de Vincennes - Pavillon du Maroc
584	95063L	ORGEXTPAR	2016-11-08 09:30:00	2016-11-08 11:00:00	Comité des Finances Locales
585	95063L	REU_TRAV_PARL	2016-11-08 11:00:00	2016-11-08 13:00:00	Réunion du Groupe socialiste
586	11054L	ACC_VISIT	2016-11-07 14:00:00	2016-11-07 15:00:00	\N
587	11054L	REU_TRAV_PARL	2016-11-08 10:00:00	2016-11-08 13:00:00	Bureau et groupe PS
588	11054L	ACC_VISIT	2016-11-08 09:00:00	2016-11-08 10:00:00	\N
589	11054L	ELUS_LOCAUX	2016-11-08 18:45:00	2016-11-08 19:45:00	\N
590	11054L	ELUS_LOCAUX	2016-11-09 12:30:00	2016-11-09 14:00:00	\N
591	11054L	REU_TRAV_PARL	2016-11-15 10:00:00	2016-11-15 13:00:00	Bureau et groupe PS
661	04040A	REU_TRAV_PARL	2016-11-15 11:00:00	2016-11-15 12:00:00	Réunion de Groupe UDI-UC
662	04040A	COLLOQUE	2016-11-16 13:30:00	2016-11-16 15:00:00	Colloque "Numérique et Santé" 
691	14028W	REU_TRAV_PARL	2016-10-26 15:30:00	2016-10-26 16:30:00	Commission des Affaires Etrangères - Groupe de travail Australie
690	14028W	REU_TRAV_PARL	2016-10-25 18:15:00	2016-10-25 19:15:00	Délégation sénatoriale aux collectivités territoriales et à la décentralisation - RI évolution des missions des services déconcentrés
692	08010L	ORG_POL	2016-11-15 11:00:00	2016-11-15 12:30:00	\N
706	08047A	ORG_POL	2016-11-08 11:00:00	2016-11-08 13:00:00	REUNION GROUPE LR
707	08047A	REU_TRAV_PARL	2016-11-08 14:30:00	2016-11-08 16:30:00	SEANCE
708	08047A	ORG_POL	2016-11-08 18:00:00	2016-11-08 19:00:00	PRIMAIRES LR
709	08047A	REU_TRAV_PARL	2016-11-08 20:30:00	2016-11-08 22:30:00	FORUM HIPPOCAMPE
710	08047A	ORG_POL	2016-11-14 19:00:00	2016-11-14 22:30:00	PRIMAIRES LR
714	08047A	ORG_POL	2016-11-15 18:00:00	2016-11-15 19:00:00	PRIMAIRES LR
712	08047A	ORG_POL	2016-11-15 11:00:00	2016-11-15 13:00:00	REUNION GROUPE LR
713	08047A	REU_TRAV_PARL	2016-11-15 14:30:00	2016-11-15 16:30:00	SEANCE
715	08047A	ACC_VISIT	2016-11-15 16:00:00	2016-11-15 17:00:00	FINISTERE
720	04043D	CEREMONIE	2016-11-11 11:30:00	2016-11-11 13:00:00	Commémoration du 11 novembre à Vincennes
721	04043D	DEL_ACT_PAR	2016-11-08 12:30:00	2016-11-08 14:00:00	réunion sur l'épigénétique avec des scientifiques et présidents d'Instituts de Recherche 
722	04043D	CEREMONIE	2016-11-09 19:00:00	2016-11-09 20:00:00	Cérémonie en l'Hommage du décès du Général de Gaulle à Saint-Mandé et Vincennes
723	04043D	COLL_TER	2016-11-14 11:00:00	2016-11-14 14:30:00	Réunion et visite avec le Chef de Corps de la Brigade de Sapeurs-pompiers de Villeneuve-St-Georges
725	04042C	REU_TRAV_PARL	2015-12-01 13:00:00	2015-12-01 14:30:00	réunion avec le Président de Public Sénat
726	04042C	ELUS_LOCAUX	2015-11-03 09:00:00	2015-11-03 10:30:00	Conférence de presse à Maisons-Alfort
727	04042C	ORG_POL	2015-11-03 18:00:00	2015-11-03 20:00:00	Bureau politique Les républicains 
729	04042C	ACC_VISIT	2015-11-04 14:30:00	2015-11-04 15:00:00	Visite du Sénat du Conseil Municipal des jeunes de L'Haÿ-les-Roses
730	04042C	REU_TRAV_PARL	2015-11-04 15:00:00	2015-11-04 16:30:00	Réunion du Bureau de la commission des affaires étrangères, de la Defense et des Forces armées du Sénat
731	04042C	ORG_POL	2015-11-10 13:00:00	2015-11-10 14:30:00	Déjeuner de travail Les Républicains du Sénat
732	04042C	ELUS_LOCAUX	2015-11-10 18:00:00	2015-11-10 19:00:00	Réunion des élus du Val-de-Marne
733	04042C	CEREMONIE	2015-11-10 19:30:00	2015-11-10 22:00:00	Célébration du 60ème anniversaire des Accords de la celle St Cloud au quai d'Orsay
734	04042C	CEREMONIE	2015-11-11 09:00:00	2015-11-11 14:30:00	Cérémonie du 11 novembre
201	14034U	ORG_POL	2016-10-11 20:00:00	2016-10-11 22:00:00	\N
361	01015L	ACC_VISIT	2016-10-19 14:00:00	2016-10-19 15:30:00	Conseil municipal de jeunes
445	01059Y	ACC_VISIT	2016-10-25 15:30:00	2016-10-25 16:30:00	Audition du groupe CRC de l'association Jean Louis Mégnien, association contre le harcèlement professionnel, pour le Projet de Loi de Finance de la Sécurité Sociale 2017
385	14107H	ELUS_LOCAUX	2016-10-17 09:00:00	2016-10-17 16:00:00	SEYNE-La MOTTE DU CAIRE
442	11091R	ELUS_LOCAUX	2016-10-25 17:00:00	2016-10-25 19:00:00	Préfecture Accueil Migrants dans les Yvelines Yvelines
386	14107H	ELUS_LOCAUX	2016-10-24 09:00:00	2016-10-24 17:00:00	rencontre des Maires du 04
388	14253S	DEL_ACT_PAR	2016-11-01 14:00:00	2016-11-01 19:00:00	Auditions - Délégation aux entreprises
443	01059Y	ACC_VISIT	2016-10-26 14:30:00	2016-10-26 15:30:00	Auditions du groupe CRC de l'association ANDEVA, association nationale de défense des victimes de l'amiante, pour discuter du Projet de Loi de Finance de la Sécurité Sociale 2017
446	01059Y	ACC_VISIT	2016-10-25 16:30:00	2016-10-25 17:30:00	Audition du groupe CRC de l'Union Nationale des Association de Tourisme et de plein air, pour le Projet de Loi de Finance de la Sécurité Sociale 2017
447	01059Y	ACC_VISIT	2016-10-26 13:30:00	2016-10-26 14:30:00	Groupe d'amitié-Rencontre avec de jeunes palestiniens d'un camp de réfugiés du Liban
448	04043D	COLL_TER	2016-10-24 10:30:00	2016-10-24 16:00:00	\N
728	04042C	REU_TRAV_PARL	2015-11-04 13:00:00	2015-11-04 14:30:00	Déjeuner des parlementaires autour de Valérie Pecresse
735	04042C	ELUS_LOCAUX	2015-11-12 13:00:00	2015-11-12 14:30:00	Déjeuner de travail avec élus du Val-de-Marne
736	04042C	ACC_DEPL_INTER	2015-11-12 18:30:00	2015-11-12 19:30:00	Réception à la Résidence de l'ambassade du Japon
737	04042C	ELUS_LOCAUX	2015-11-12 19:30:00	2015-11-12 21:00:00	Débat des jeunes Républicains du Val-de-Marne pour les élections régionales
738	04042C	REU_TRAV_PARL	2015-11-12 22:30:00	2015-11-12 23:00:00	Débat sur la chaîne parlementaire Public Sénat
739	04042C	ACC_DEPL_INTER	2015-11-17 08:30:00	2015-11-17 09:30:00	Réunion avec l'ambassadeur de France à Cuba
740	04042C	REU_TRAV_PARL	2015-11-17 10:00:00	2015-11-17 11:00:00	Réunion des commissaires de la commissions des Affaires étrangères, de la Défense et des Forces armées du Sénat
741	14107H	ELUS_LOCAUX	2016-11-10 09:00:00	2016-11-10 17:00:00	rencontre des Maires du 04
742	04042C	ORG_POL	2015-11-17 11:00:00	2015-11-17 12:00:00	Réunion de Groupe Les Républicains du Sénat
743	04042C	ELUS_LOCAUX	2015-11-17 12:00:00	2015-11-17 14:00:00	Déjeuner de travail avec élus du Val-de-Marne
744	14107H	DEPL_PRES_GVT	2016-11-14 09:00:00	2016-11-14 16:00:00	PEYRUIS - DIGNE LES BAINS
745	04042C	ACC_DEPL_INTER	2015-11-18 13:00:00	2015-11-18 15:00:00	Audition du Président de Mongolie à la Présidence du Sénat
746	04042C	ELUS_LOCAUX	2015-11-18 18:30:00	2015-11-18 19:30:00	Bureau municipal
747	04042C	ELUS_LOCAUX	2015-11-18 19:30:00	2015-11-18 21:30:00	Réunion publique PLU
748	04042C	CEREMONIE	2015-11-19 10:00:00	2015-11-19 12:00:00	Cérémonie en mémoire des fonctionnaires policiers décédés les 12 derniers mois
749	04042C	ELUS_LOCAUX	2015-11-19 18:00:00	2015-11-19 21:00:00	réunions des maires et parlementaires du Val-de-Marne
761	11054L	ELUS_LOCAUX	2016-11-14 12:30:00	2016-11-14 14:00:00	\N
762	11054L	REU_TRAV_PARL	2016-11-15 14:00:00	2016-11-15 15:00:00	\N
763	11054L	ELUS_LOCAUX	2016-11-15 15:00:00	2016-11-15 16:00:00	\N
764	11054L	ACC_VISIT	2016-11-17 16:30:00	2016-11-17 17:00:00	\N
765	11054L	COLL_TER	2016-11-18 11:00:00	2016-11-18 12:00:00	\N
766	11054L	COLL_TER	2016-11-18 14:30:00	2016-11-18 15:30:00	\N
767	11054L	COLL_TER	2016-11-21 09:00:00	2016-11-21 10:00:00	Bondy Innovation
768	11054L	ACC_VISIT	2016-11-21 11:00:00	2016-11-21 12:00:00	\N
769	11054L	COLL_TER	2016-11-21 15:00:00	2016-11-21 16:00:00	Rencontre CGT Hôpital Jean Verdier
805	01015L	ORG_POL	2016-11-30 09:30:00	2016-11-30 13:30:00	\N
862	04040A	REU_TRAV_PARL	2016-11-23 08:00:00	2016-11-23 08:30:00	Petit-déjeuner du Groupe d'amitité France-Pays de la Corne de l'Afrique 
863	04040A	REU_TRAV_PARL	2016-11-24 08:30:00	2016-11-24 09:30:00	Petit-déjeuner du Groupe d'amitité France-Pays de la Corne de l'Afrique 
881	08048B	ACC_VISIT	2016-11-16 13:00:00	2016-11-16 14:30:00	Visite du Sénat des membres de l¿Union Nationale des Arbitres de Football de Provence (UNAF Provence) 
941	11054L	CEREMONIE	2016-11-22 18:30:00	2016-11-22 20:00:00	15ème édition Talents des Cités
1004	08010L	CEREMONIE	2016-11-10 10:00:00	2016-11-10 13:00:00	\N
1021	11063M	REU_TRAV_PARL	2016-11-08 10:30:00	2016-11-08 13:00:00	\N
1061	08047A	ORG_POL	2016-11-22 11:00:00	2016-11-22 13:00:00	REUNION GROUPE LR
1062	08047A	CEREMONIE	2016-11-24 15:00:00	2016-11-24 16:30:00	INAUGURATION MUSEE BATEAU INSTITUT MONDE ARABE
1063	08047A	REU_TRAV_PARL	2016-11-23 18:30:00	2016-11-23 00:00:00	SEANCE / PERMANENCE
1084	08009T	REU_TRAV_PARL	2016-11-23 08:00:00	2016-11-23 09:00:00	\N
1082	08009T	REU_GVT	2016-11-21 18:00:00	2016-11-21 19:00:00	Cabinet Bernard Cazeneuve
1083	08009T	REU_TRAV_PARL	2016-11-22 11:00:00	2016-11-22 12:30:00	Réunion de groupe 
1101	08010L	REU_TRAV_PARL	2016-11-24 08:30:00	2016-11-24 09:30:00	conférence de presse
1121	14327T	REU_TRAV_PARL	2016-11-16 16:00:00	2016-11-16 17:00:00	Audition FRSEA Auvergne-Rhône Alpes : loi montagne
1141	04040A	REU_TRAV_PARL	2016-11-29 11:00:00	2016-11-29 12:00:00	Réunion du Groupe UDI-UC
1161	11063M	CEREMONIE	2016-11-24 17:00:00	2016-11-24 19:00:00	Centenaire ONAC-VG
1186	11063M	REU_TRAV_PARL	2016-09-23 09:00:00	2016-09-23 11:00:00	Visite du centre de santé de La Manaie
1181	11063M	REU_TRAV_PARL	2016-10-07 09:00:00	2016-10-07 20:00:00	sur l'aide à domicile dans les Pyrénées Orientales
1182	11063M	CEREMONIE	2016-10-03 18:30:00	2016-10-03 21:00:00	Inauguration de l'Espace Ludovic Leroy à Sains-en-Gohelle
1184	11063M	CEREMONIE	2016-09-30 18:30:00	2016-09-30 21:00:00	Lancement pièce théâtre sur la lutte des ex-salariées de Samsonite
1185	11063M	CEREMONIE	2016-09-30 10:30:00	2016-09-30 12:00:00	Inauguration de la nouvelle salle d'escalade de Rouvroy
1187	04043D	ELUS_LOCAUX	2016-11-23 15:00:00	2016-11-23 16:00:00	Entretien avec un élu local au Sénat
1241	08010L	ELUS_LOCAUX	2016-11-30 18:00:00	2016-11-30 19:30:00	élus des Hauts-de-France 
1301	14089Y	ORG_POL	2016-12-13 11:00:00	2016-12-13 12:00:00	Réunion de groupe 
1343	04042C	ELUS_LOCAUX	2016-06-16 15:00:00	2016-06-16 16:30:00	Rendez-vous avec des élus du Val-de-Marne
1344	04042C	ELUS_LOCAUX	2016-06-14 15:00:00	2016-06-14 16:30:00	Rendez-vous avec des élus du Val-de-Marne
1345	04042C	ORG_POL	2016-06-14 11:00:00	2016-06-14 12:30:00	Réunion du Groupe Les Républicains du Sénat
1346	04042C	ORG_POL	2016-06-14 19:30:00	2016-06-14 21:30:00	Commission nationale d'investiture
1347	04042C	REU_TRAV_PARL	2016-06-14 10:15:00	2016-06-14 11:00:00	Réunion des commissaires LR de la commission des Affaires étrangères, de la Défense et des Forces armées
1348	04042C	ELUS_LOCAUX	2016-06-16 10:00:00	2016-06-16 11:30:00	Réunion du Comité du Syndicat des Eaux d'Ile-de-France
1349	04042C	ORG_POL	2016-06-07 11:00:00	2016-06-07 12:30:00	Réunion du Groupe Les Républicains du Sénat
1350	04042C	ORG_POL	2016-06-07 17:00:00	2016-06-07 18:30:00	Bureau politique National Les Républicains
1351	04042C	ELUS_LOCAUX	2016-06-07 18:30:00	2016-06-07 23:30:00	Conseil Municipal
1352	04042C	ORG_POL	2016-06-08 13:00:00	2016-06-08 14:30:00	Déjeuner des parlementaires avec Valérie Pecresse
1353	04042C	ELUS_LOCAUX	2016-06-08 18:45:00	2016-06-08 23:30:00	Rencontre au Sénat avec les élus de Joinville-le-Pont et Le Perreux-sur-Marne
1354	04042C	COLLOQUE	2016-06-09 09:00:00	2016-06-09 11:30:00	Colloque sur le climat présidé par le Président gérard Larcher et la Ministre Ségolène Royal
1355	04042C	ACC_DEPL_INTER	2016-06-09 12:00:00	2016-06-09 14:00:00	Fête Nationale de Russie à l'Ambassade de Russie
1356	04042C	ELUS_LOCAUX	2016-06-09 18:30:00	2016-06-09 20:00:00	Commission assainissement EPT
1357	04042C	ELUS_LOCAUX	2016-06-01 12:30:00	2016-06-01 14:30:00	Déjeuner Congrès des Maires
1358	04042C	REU_GVT	2016-06-01 17:00:00	2016-06-01 18:30:00	Réunion à Matignon avec Manuel Valls sur le thème de la sécurité
1359	04042C	ELUS_LOCAUX	2016-05-31 16:00:00	2016-05-31 16:30:00	Rendez-vous avec un élu du Val-de-Marne
1360	04042C	ORG_POL	2016-05-31 11:00:00	2016-05-31 12:30:00	Réunion du Groupe Les Républicains du Val-de-Marne
1361	04042C	COLLOQUE	2016-06-02 16:00:00	2016-06-02 18:00:00	Colloque sur la Sahara Marocain
1362	04042C	ORG_POL	2016-06-02 20:00:00	2016-06-02 22:30:00	réunion du Bureau Les Républicains du Sénat
1363	04042C	ACC_DEPL_INTER	2016-05-26 17:30:00	2016-05-26 18:30:00	Audience du Grand Imam Egyptien de la mosquée Al Azhar à la Présidence du Sénat
71	11054L	ORG_POL	2016-10-04 20:00:00	2016-10-04 23:00:00	bondy
42	11054L	REU_TRAV_PARL	2016-10-06 14:30:00	2016-10-06 18:00:00	Colloque sur les institutions Assemblée Nationale
283	04043D	DEL_ACT_PAR	2016-08-31 09:00:00	2016-08-31 19:00:00	Déplacement mission avenir des matériaux 
45	11054L	DEPL_PRES_GVT	2016-10-07 14:00:00	2016-10-07 17:00:00	Candidature JO 2024 visite de sites Le Bourget
64	11054L	ELUS_LOCAUX	2016-10-03 14:00:00	2016-10-03 15:00:00	sénat
7669	04042C	ORG_POL	2017-12-19 11:00:00	2017-12-19 12:00:00	\N
62	11054L	ORG_POL	2016-10-07 19:00:00	2016-10-07 21:00:00	Bondy
81	14073Q	ORG_POL	2016-10-11 11:00:00	2016-10-11 13:00:00	Groupe UDI-UC
63	11054L	REU_TRAV_PARL	2016-10-04 10:00:00	2016-10-04 13:00:00	groupe PS
82	14073Q	REU_TRAV_PARL	2016-10-11 17:30:00	2016-10-11 19:00:00	Audition PPL Ethique du sport
83	14073Q	REU_TRAV_PARL	2016-10-11 19:00:00	2016-10-11 20:00:00	Audition Mathias FEKL
121	11054L	COLL_TER	2016-10-10 10:00:00	2016-10-10 11:00:00	Rendez-vous avec la Région au sujet de Bond'Innov - Bondy
93	11090Q	REU_TRAV_PARL	2016-10-04 11:00:00	2016-10-04 13:00:00	\N
94	11090Q	DEL_ACT_PAR	2016-10-05 08:00:00	2016-10-05 09:30:00	\N
122	11054L	ORG_POL	2016-10-10 19:00:00	2016-10-10 21:00:00	PARIS
243	08048B	ORG_POL	2016-10-11 19:00:00	2016-10-11 21:00:00	Assemblée Générale de l'Amicale Gaulliste
124	08010L	COLL_TER	2016-09-29 10:00:00	2016-09-29 13:00:00	Comité Directeeur AMF
125	08010L	ORG_POL	2016-10-04 11:00:00	2016-10-04 12:30:00	\N
126	08010L	ORG_POL	2016-09-27 11:00:00	2016-09-27 12:30:00	\N
128	97011G	ORGEXTPAR	2016-10-12 08:00:00	2016-10-12 20:00:00	Conseil de l'Europe
244	08048B	CEREMONIE	2016-10-04 18:30:00	2016-10-04 20:00:00	Remise des insignes de Chevalier dans l'Ordre National du Mérite
130	97011G	ORGEXTPAR	2016-10-13 08:00:00	2016-10-13 14:00:00	Conseil de l'Europe
282	04043D	CEREMONIE	2016-09-01 09:30:00	2016-09-01 11:00:00	Inauguration lycée international Bry-sur-Marne/Noisy-le-Grand
401	11089X	ORG_POL	2016-10-18 11:00:00	2016-10-18 13:00:00	\N
402	11089X	ORG_POL	2016-10-18 10:00:00	2016-10-18 11:00:00	\N
406	11089X	ORG_POL	2016-10-11 11:00:00	2016-10-11 13:00:00	\N
441	11091R	CEREMONIE	2016-11-11 09:30:00	2016-11-11 12:00:00	Commémoration armistice
405	11089X	ORG_POL	2016-10-11 10:00:00	2016-10-11 11:00:00	\N
407	11089X	ORG_POL	2016-10-19 09:30:00	2016-10-19 10:00:00	\N
408	11054L	REU_TRAV_PARL	2016-10-26 15:00:00	2016-10-26 16:30:00	Séminaire du SGDSN de sensibilisation des acteurs de la vie politiqu aux risques liées aux attaques informatiques
444	01059Y	ACC_VISIT	2016-10-26 16:30:00	2016-10-26 18:00:00	Audition du groupe CRC de la CGT sur le Project de Loi de Finance de la Sécurité Sociale
449	04043D	COLL_TER	2016-10-17 15:00:00	2016-10-17 18:00:00	\N
450	04043D	ACC_VISIT	2016-10-05 13:30:00	2016-10-05 14:30:00	CMJ Saint-Mandé
461	01025N	REU_TRAV_PARL	2016-10-27 09:00:00	2016-10-27 12:30:00	Les Journées juridiques du patrimoine
462	14107H	COLL_TER	2016-10-28 09:00:00	2016-10-28 12:00:00	CDPTT Digne
463	14107H	ELUS_LOCAUX	2016-10-28 14:00:00	2016-10-28 17:00:00	permanence
482	08047A	ORG_POL	2016-11-02 12:00:00	2016-11-02 13:00:00	REUNION GROUPE LR
483	08047A	ACC_VISIT	2016-11-02 16:00:00	2016-11-02 17:00:00	\N
484	08047A	COLL_TER	2016-11-03 09:00:00	2016-11-03 10:00:00	Fréquence médicale à DNZ
485	08047A	ACC_VISIT	2016-11-03 12:30:00	2016-11-03 14:00:00	\N
487	01024M	COLL_TER	2016-10-12 17:00:00	2016-10-12 19:00:00	Grand Reims
601	01024M	COLL_TER	2016-11-10 14:00:00	2016-11-10 18:00:00	CTAP Grand Est
801	01015L	REU_TRAV_PARL	2016-11-22 13:00:00	2016-11-22 15:00:00	Projet de loi Montagne
802	01015L	ELUS_LOCAUX	2016-11-24 09:00:00	2016-11-24 21:00:00	Après-mines
981	14211G	ORG_POL	2016-11-22 09:30:00	2016-11-22 11:00:00	\N
1001	08010L	ORG_POL	2016-11-22 09:30:00	2016-11-22 11:00:00	\N
1002	08010L	ORG_POL	2016-11-22 11:00:00	2016-11-22 11:45:00	\N
1003	08010L	REU_TRAV_PARL	2016-11-22 11:45:00	2016-11-22 13:00:00	\N
1163	11063M	ORG_POL	2016-11-04 18:00:00	2016-11-04 20:00:00	\N
1164	11063M	REU_TRAV_PARL	2016-10-28 10:30:00	2016-10-28 12:00:00	Conférence de presse
1165	11063M	REU_TRAV_PARL	2016-10-27 16:30:00	2016-10-27 18:30:00	Directeur Général ANGDM
1166	11063M	REU_TRAV_PARL	2016-10-21 10:00:00	2016-10-21 12:00:00	Aide à domicile Bruay/Escaut
1167	11063M	ORG_POL	2016-10-21 18:30:00	2016-10-21 20:00:00	Evasion fiscale avec Eric Bocquet
1168	11063M	REU_TRAV_PARL	2016-10-18 14:00:00	2016-10-18 16:40:00	Auditions préparatoires au PLFSS 2017 - Syndicats de retraités puis Association des Paralysés de France
1188	11063M	CEREMONIE	2016-09-23 11:30:00	2016-09-23 12:30:00	Anniversaire du foyer logement de Drocourt Les Genêts
1189	11063M	CEREMONIE	2016-09-23 19:00:00	2016-09-23 21:00:00	Décoration de M. Edgard Chavatte, Chevalier de l'Ordre du Mérite Agricole
1190	11063M	REU_TRAV_PARL	2016-09-19 10:30:00	2016-09-19 12:00:00	Rencontre avec l'association Aced Metallia
1201	11054L	REU_TRAV_PARL	2016-11-30 09:00:00	2016-11-30 10:00:00	Rendez-vous associations pour parler de la situation à Gaza
1203	14041T	ELUS_LOCAUX	2016-11-08 09:00:00	2016-11-08 21:00:00	déplacement Inde
1205	14041T	ELUS_LOCAUX	2016-11-10 09:00:00	2016-11-10 21:00:00	déplacement Inde
1209	14041T	ELUS_LOCAUX	2016-11-30 09:00:00	2016-11-30 21:00:00	déplacement Singapour
1210	14041T	ELUS_LOCAUX	2016-12-01 09:00:00	2016-12-01 21:00:00	déplacement Singapour
1261	08010L	COLL_TER	2016-12-01 11:00:00	2016-12-01 13:00:00	Comité Directeur AMF
1262	08010L	ACC_VISIT	2016-12-01 16:00:00	2016-12-01 17:30:00	\N
1364	04042C	ACC_DEPL_INTER	2016-05-25 20:30:00	2016-05-25 22:00:00	Dîner à l'Ambassade d'Egypte
1365	04042C	REU_TRAV_PARL	2016-05-24 10:15:00	2016-05-24 11:00:00	Réunion des commissaires LR de la commission des affaires étrngères, de la Défense et des Forces armées du Sénat
1366	04042C	ORG_POL	2016-05-24 11:00:00	2016-05-24 12:30:00	Réunion du Groupe Les républicains du Sénat
1367	04042C	REU_TRAV_PARL	2016-05-24 12:45:00	2016-05-24 14:30:00	Déjeuner de travail sur l'immunothérapie
1368	04042C	REU_TRAV_PARL	2016-05-24 15:30:00	2016-05-24 16:30:00	Audition du Groupe Australie
1369	04042C	ORG_POL	2016-05-24 18:00:00	2016-05-24 18:30:00	Débat sur Public Sénat
1401	04042C	ACC_VISIT	2016-05-11 15:00:00	2016-05-11 16:00:00	Visite du sénat du Conseil Municipal des Jeunes de Sucy-en-Brie
1381	04042C	REU_TRAV_PARL	2016-05-12 08:00:00	2016-05-12 10:00:00	Petit-déjeuner avec l'Ambassadeur de France en Libye
1372	04042C	ACC_VISIT	2016-05-18 14:30:00	2016-05-18 15:00:00	Visite du Sénat du Conseil Municipal des Jeunes du Plessis-Trevise
1373	04042C	REU_TRAV_PARL	2016-05-18 18:00:00	2016-05-18 18:30:00	Débat sur la chaîne parlementaire Public Sénat
1374	04042C	ELUS_LOCAUX	2016-05-18 18:45:00	2016-05-18 23:30:00	rencontre au Sénat avec les élus de Villiers-sur-Marne et Bry-sur-Marne
1382	04042C	ELUS_LOCAUX	2016-05-12 16:15:00	2016-05-12 17:00:00	Réunion avec des élus sur les actions du Groupe Interparlementaire d'Amitié France Maroc
1402	04042C	ACC_DEPL_INTER	2016-05-11 17:00:00	2016-05-11 19:00:00	Réception de départ de l'Ambassadeur du Japon en France
1403	04042C	ORG_POL	2016-05-10 11:00:00	2016-05-10 12:30:00	Réunion du Groupe Les Républicains du Sénat
1406	04042C	COLLOQUE	2016-05-03 18:30:00	2016-05-03 22:00:00	Table ronde du Groupe Interparlementaire d'Amitié France Maroc du Sénat à l'Ambassade du Maroc en France
1407	04042C	ELUS_LOCAUX	2016-11-16 18:45:00	2016-11-16 23:30:00	Rencontre au Sénat avec les élus d'opposition d'Arcueil, Cachan, et le Kremlin-Bicêtre
1421	14089Y	CEREMONIE	2016-12-02 19:00:00	2016-12-02 20:00:00	\N
1422	14089Y	REU_TRAV_PARL	2016-11-29 20:00:00	2016-11-29 22:30:00	\N
1441	14089Y	REU_TRAV_PARL	2016-11-30 16:15:00	2016-11-30 17:15:00	\N
1442	14089Y	ELUS_LOCAUX	2016-11-28 19:00:00	2016-11-28 21:00:00	\N
1443	14089Y	REU_TRAV_PARL	2016-11-23 11:00:00	2016-11-23 12:00:00	\N
1444	14089Y	ORG_POL	2016-11-22 11:00:00	2016-11-22 12:00:00	\N
1445	14089Y	ORG_POL	2016-11-02 11:30:00	2016-11-02 12:30:00	\N
1446	14089Y	ELUS_LOCAUX	2016-11-04 13:30:00	2016-11-04 15:30:00	\N
1447	14089Y	CEREMONIE	2016-11-04 17:00:00	2016-11-04 18:00:00	\N
1448	14089Y	CEREMONIE	2016-11-04 18:30:00	2016-11-04 19:30:00	\N
1449	14089Y	REU_TRAV_PARL	2016-11-09 18:00:00	2016-11-09 19:00:00	\N
1450	14089Y	REU_TRAV_PARL	2016-11-10 15:30:00	2016-11-10 16:30:00	\N
1451	14089Y	CEREMONIE	2016-11-10 16:30:00	2016-11-10 17:30:00	\N
1452	14089Y	CEREMONIE	2016-11-11 09:00:00	2016-11-11 10:00:00	\N
1453	14089Y	CEREMONIE	2016-11-11 10:30:00	2016-11-11 11:30:00	\N
1454	14089Y	CEREMONIE	2016-11-14 18:30:00	2016-11-14 19:30:00	\N
1455	14089Y	ELUS_LOCAUX	2016-11-14 20:30:00	2016-11-14 22:30:00	\N
1456	14089Y	REU_TRAV_PARL	2016-11-16 17:00:00	2016-11-16 18:00:00	\N
1457	14089Y	REU_TRAV_PARL	2016-11-18 11:00:00	2016-11-18 12:00:00	\N
1458	14089Y	ELUS_LOCAUX	2016-11-18 18:00:00	2016-11-18 19:00:00	\N
1459	14089Y	ELUS_LOCAUX	2016-11-21 17:00:00	2016-11-21 18:00:00	\N
1460	14089Y	REU_TRAV_PARL	2016-11-24 16:30:00	2016-11-24 17:30:00	\N
1601	04040A	ACC_DEPL_INTER	2016-12-07 12:30:00	2016-12-07 14:30:00	Déjeuner à l'Elysée en l'honneur de la Présidente de l'Estonie Mme Kersti Kaljulaid
1621	08010L	REU_TRAV_PARL	2016-12-06 12:30:00	2016-12-06 14:30:00	1er Président de la Cour de Cassation
1641	08009T	REU_TRAV_PARL	2016-11-29 09:30:00	2016-11-29 10:30:00	\N
1623	08010L	ORG_POL	2016-12-06 11:00:00	2016-12-06 12:30:00	\N
1624	08010L	ORG_POL	2016-12-06 19:30:00	2016-12-06 21:00:00	\N
1642	08009T	REU_TRAV_PARL	2016-11-29 10:30:00	2016-11-29 11:00:00	Préparation GT Aménagement du territoire
1643	08009T	REU_TRAV_PARL	2016-11-29 11:00:00	2016-11-29 12:00:00	Réunion du groupe UDI
1644	08009T	REU_TRAV_PARL	2016-11-29 16:00:00	2016-11-29 17:00:00	Point CMP PPL Grandguillaume et PL CDG Express
1645	08009T	REU_TRAV_PARL	2016-11-29 17:00:00	2016-11-29 18:00:00	\N
1646	08009T	REU_TRAV_PARL	2016-11-30 08:30:00	2016-11-30 09:15:00	Rdv Jean-Marc Janaillac
1647	08009T	REU_TRAV_PARL	2016-11-30 17:30:00	2016-11-30 20:30:00	CMP PL Grandguillaume et PL CDG Express
1648	08009T	REU_TRAV_PARL	2016-12-01 10:00:00	2016-12-01 12:00:00	Groupe de travail Aménagement du territoire
1649	08009T	ELUS_LOCAUX	2016-12-01 19:00:00	2016-12-01 20:30:00	Réunion sur la fusion de communautés de communes
3563	04042C	COLL_TER	2016-12-09 16:00:00	2016-12-09 16:30:00	\N
3564	04042C	COLL_TER	2016-12-09 16:30:00	2016-12-09 17:00:00	\N
3565	04042C	COLL_TER	2016-12-09 17:00:00	2016-12-09 17:30:00	\N
3566	04042C	COLL_TER	2016-12-09 17:30:00	2016-12-09 18:00:00	\N
2643	04042C	ACC_DEPL_INTER	2017-01-12 13:00:00	2017-01-12 14:30:00	Ambassadeur de Taiwan
2644	04042C	ELUS_LOCAUX	2017-01-12 18:30:00	2017-01-12 21:30:00	Cérémonie des voeux de Noiseau
2761	08047A	ORG_POL	2016-12-06 11:00:00	2016-12-06 13:00:00	REUNION LR
2762	08047A	ACC_VISIT	2016-12-06 14:30:00	2016-12-06 16:00:00	\N
2763	08047A	ORG_POL	2016-12-06 16:30:00	2016-12-06 18:00:00	\N
2764	08047A	ORG_POL	2016-12-13 11:00:00	2016-12-13 13:00:00	REUNION LR
2765	08047A	REU_TRAV_PARL	2016-12-13 15:00:00	2016-12-13 18:00:00	SEANCE
2781	08047A	REU_TRAV_PARL	2016-12-06 14:30:00	2016-12-06 15:45:00	SEANCE
2782	08047A	ACC_VISIT	2016-12-14 10:45:00	2016-12-14 12:00:00	Fédération Aide à la personne
2801	08047A	REU_TRAV_PARL	2016-12-13 21:00:00	2016-12-13 23:00:00	SEANCE
2821	08047A	ORG_POL	2016-12-20 11:00:00	2016-12-20 13:00:00	REUNION LR
2841	08047A	ORG_POL	2017-01-10 10:00:00	2017-01-10 11:00:00	REUNION LR
2842	08047A	ORG_POL	2017-01-10 11:30:00	2017-01-10 13:00:00	REUNION SIEGE LR
2843	08047A	REU_TRAV_PARL	2017-01-10 14:00:00	2017-01-10 15:30:00	PREPARATION CAE
2844	08047A	REU_TRAV_PARL	2017-01-10 14:30:00	2017-01-10 16:30:00	SEANCE
2845	08047A	REU_TRAV_PARL	2017-01-10 21:00:00	2017-01-10 23:00:00	SEANCE
2850	08047A	REU_TRAV_PARL	2017-01-18 09:00:00	2017-01-18 12:30:00	COMMISSION LOIS
2847	08047A	ORG_POL	2017-01-17 11:00:00	2017-01-17 13:00:00	REUNION LR
2848	08047A	REU_TRAV_PARL	2017-01-17 14:30:00	2017-01-17 18:00:00	SEANCE
2849	08047A	ACC_VISIT	2017-01-17 15:00:00	2017-01-17 16:00:00	\N
2881	08048B	REU_TRAV_PARL	2017-01-18 08:30:00	2017-01-18 09:30:00	Petit déjeuner de travail avec les membres de la commission des affaires sociales autour du médecin général des armées Jean-Marc Debonne
2882	08048B	CEREMONIE	2017-01-17 19:00:00	2017-01-17 20:00:00	Voeux du Président Gérard Larcher aux Sénateurs
2883	04040A	ORG_POL	2017-01-24 12:30:00	2017-01-24 13:00:00	Déjeuner du Groupe UDI-UC
2884	04040A	REU_TRAV_PARL	2017-01-24 13:00:00	2017-01-24 14:00:00	Déjeuner à la Présidence du Sénat dans le cadre des travaux de la Délégation aux collectivités territoriales
2885	04040A	ORGEXTPAR	2017-01-24 20:00:00	2017-01-24 22:00:00	Diner France Télévisions
2886	04040A	REU_TRAV_PARL	2017-01-25 15:00:00	2017-01-25 16:30:00	Réunion AFD-Délégation aux collectivités territoriales
2961	04043D	ORG_POL	2017-01-10 11:00:00	2017-01-10 13:30:00	\N
2962	04043D	DEL_ACT_PAR	2017-01-11 08:00:00	2017-01-11 09:10:00	Groupe des parlementaires pour l'Espace
2963	04043D	REU_TRAV_PARL	2017-01-10 15:00:00	2017-01-10 16:00:00	Réunion AGAS
2964	04043D	CEREMONIE	2017-01-10 16:30:00	2017-01-10 17:30:00	Voeux de l'IGN (Saint-Mandé)
2965	04043D	CEREMONIE	2017-01-10 18:00:00	2017-01-10 19:30:00	Voeux du Préfet du Val-de-Marne (Créteil)
2966	04043D	ACC_VISIT	2017-01-11 18:30:00	2017-01-11 21:00:00	Accueil élus du Val-de-Marne
2967	04043D	CEREMONIE	2017-01-12 11:00:00	2017-01-12 12:30:00	Service historique de la Défense (Château de Vincennes)
2968	04043D	CEREMONIE	2017-01-12 19:00:00	2017-01-12 21:00:00	Voeux de Noiseau
2969	04043D	CEREMONIE	2017-01-13 19:30:00	2017-01-13 21:00:00	Voeux de Périgny-sur-Yerres
2981	04043D	ACC_VISIT	2017-01-23 13:30:00	2017-01-23 15:00:00	Lycéens Noisy-le-Grand
2982	04043D	ACC_VISIT	2017-01-23 15:30:00	2017-01-23 16:15:00	Entretien avec un professionnel du Val-de-Marne
2983	04043D	ORG_POL	2017-01-24 11:00:00	2017-01-24 12:30:00	\N
3567	04042C	CEREMONIE	2016-12-09 19:00:00	2016-12-09 21:00:00	Réception des médaillés du travail
3654	04042C	ORG_POL	2016-10-24 11:00:00	2016-10-24 12:00:00	\N
3655	04042C	COLL_TER	2016-10-24 12:30:00	2016-10-24 14:30:00	commerçants
3656	04042C	COLL_TER	2016-10-24 15:00:00	2016-10-24 15:30:00	\N
3657	04042C	COLL_TER	2016-10-24 15:30:00	2016-10-24 16:00:00	commerçant
3658	04042C	ACC_DEPL_INTER	2016-10-24 17:00:00	2016-10-24 18:00:00	Audience à la Présidence du Sénat de Julain King, commissaire Européen en charge de la sécurité 
3659	04042C	ORG_POL	2016-10-24 19:00:00	2016-10-24 22:00:00	Débat sur la Primaire LR
3660	04042C	CEREMONIE	2016-11-01 11:00:00	2016-11-01 12:00:00	cimetière de Saint-Maurice
3661	04042C	COLL_TER	2016-10-21 09:00:00	2016-10-21 09:30:00	\N
3662	04042C	ELUS_LOCAUX	2016-10-21 09:30:00	2016-10-21 10:00:00	\N
3663	04042C	COLL_TER	2016-10-21 10:00:00	2016-10-21 10:30:00	Logement
3664	04042C	COLL_TER	2016-10-21 10:30:00	2016-10-21 11:30:00	logement
3665	04042C	ELUS_LOCAUX	2016-10-21 12:00:00	2016-10-21 14:30:00	\N
3666	04042C	COLL_TER	2016-10-21 15:00:00	2016-10-21 16:30:00	Immobilier
3667	04042C	ELUS_LOCAUX	2016-10-21 16:30:00	2016-10-21 17:00:00	Information PLU
3668	04042C	COLL_TER	2016-10-21 17:00:00	2016-10-21 17:30:00	\N
3681	04042C	ELUS_LOCAUX	2016-10-17 10:00:00	2016-10-17 11:30:00	Bureau EPT 10
3682	04042C	ELUS_LOCAUX	2016-10-17 11:30:00	2016-10-17 14:30:00	Maires EPT10
3683	04042C	COLL_TER	2016-10-17 14:30:00	2016-10-17 16:00:00	Conseil de surveillance des Hôpitaux de Saint-Maurice
3684	04042C	COLL_TER	2016-10-17 16:00:00	2016-10-17 16:30:00	Logement
3685	04042C	COLL_TER	2016-10-17 16:30:00	2016-10-17 17:00:00	Culture
3686	04042C	COLL_TER	2016-10-17 17:00:00	2016-10-17 17:30:00	Logement
3687	04042C	ELUS_LOCAUX	2016-10-14 08:45:00	2016-10-14 10:00:00	Bureau du Syndicat des Eaux d'Ile-de-France
3688	04042C	ELUS_LOCAUX	2016-10-14 10:00:00	2016-10-14 12:00:00	avec Prefet de Police de Paris et le Prefet du Val-de-Marne
3689	04042C	COLL_TER	2016-10-14 15:00:00	2016-10-14 16:00:00	EPT 10
3690	04042C	COLL_TER	2016-10-14 17:00:00	2016-10-14 18:00:00	logement
3691	04042C	CEREMONIE	2016-10-14 18:00:00	2016-10-14 20:30:00	des jeunes diplômés de Saint-Maurice
3737	04042C	COLL_TER	2016-09-02 09:00:00	2016-09-02 10:00:00	Urbanisme
3738	04042C	COLL_TER	2016-09-02 10:00:00	2016-09-02 10:30:00	Hôpitaux de Saint-Maurice
3739	04042C	COLL_TER	2016-09-02 10:30:00	2016-09-02 11:00:00	Police Municipale
3740	04042C	COLL_TER	2016-09-02 11:00:00	2016-09-02 12:00:00	Commerçant
3741	04042C	COLL_TER	2016-09-02 15:30:00	2016-09-02 16:00:00	Finances
3742	04042C	ELUS_LOCAUX	2016-09-02 16:00:00	2016-09-02 17:00:00	\N
3743	04042C	COLL_TER	2016-09-01 07:30:00	2016-09-01 12:00:00	Rentrée scolaire
3744	04042C	COLL_TER	2016-08-31 09:00:00	2016-08-31 10:00:00	Inauguration local commercial
3745	04042C	ACC_VISIT	2016-08-31 13:00:00	2016-08-31 14:30:00	Visite du sénat d'une association de Saint-Maurice
3746	04042C	ORG_POL	2016-08-31 15:00:00	2016-08-31 16:00:00	\N
3747	04042C	COLL_TER	2016-08-31 16:00:00	2016-08-31 16:30:00	Urbanisme
3748	04042C	COLL_TER	2016-08-31 16:30:00	2016-08-31 17:30:00	Bâtiment
3749	04042C	COLL_TER	2016-08-31 17:00:00	2016-08-31 18:00:00	Sport
3750	04042C	COLL_TER	2016-08-30 12:00:00	2016-08-30 14:30:00	Hôpitaux de Saint-Maurice
3751	04042C	COLL_TER	2016-07-15 11:00:00	2016-07-15 11:30:00	Commerçant du marché
3752	04042C	COLL_TER	2016-07-15 12:00:00	2016-07-15 13:30:00	\N
3761	04042C	CEREMONIE	2016-07-14 09:00:00	2016-07-14 12:00:00	du 14 juillet sur les Champs-Elysées
3762	04042C	ACC_VISIT	2016-07-11 09:30:00	2016-07-11 11:00:00	Visite du sénat de l'Office municipal de Maisons-Alfort
3763	04042C	COLL_TER	2016-07-11 14:00:00	2016-07-11 15:00:00	\N
3764	04042C	ACC_DEPL_INTER	2016-07-11 16:00:00	2016-07-11 17:30:00	A la présidence du Sénat du Président de la république d'Afrique du Sud
3765	04042C	ELUS_LOCAUX	2016-07-11 18:45:00	2016-07-11 23:00:00	Accueil au Sénat d'élus du Val-de-Marne
3766	04042C	COLL_TER	2016-07-07 12:00:00	2016-07-07 14:30:00	\N
3767	04042C	ELUS_LOCAUX	2016-07-07 14:30:00	2016-07-07 16:00:00	\N
3827	04042C	ELUS_LOCAUX	2016-06-10 08:45:00	2016-06-10 12:00:00	Bureau du Syndicat des Eaux d'Ile-de-France
3828	04042C	COLL_TER	2016-06-10 15:30:00	2016-06-10 16:00:00	\N
3829	04042C	COLL_TER	2016-06-10 16:00:00	2016-06-10 17:00:00	Urbanisme
3830	04042C	COLL_TER	2016-06-10 17:00:00	2016-06-10 18:00:00	Comité de suivi rythmes scolaires
3831	04042C	COLL_TER	2016-06-06 10:30:00	2016-06-06 11:30:00	logement
3832	04042C	COLL_TER	2016-06-06 14:30:00	2016-06-06 15:30:00	bâtiment
3833	04042C	COLL_TER	2016-06-06 15:30:00	2016-06-06 16:00:00	\N
3834	04042C	COLL_TER	2016-06-06 16:00:00	2016-06-06 17:00:00	commerçants
3835	04042C	ELUS_LOCAUX	2016-06-06 17:00:00	2016-06-06 18:00:00	Conseil de Territoire
3836	04042C	ELUS_LOCAUX	2016-06-06 18:00:00	2016-06-06 20:30:00	\N
3837	04042C	COLL_TER	2016-06-03 09:30:00	2016-06-03 10:30:00	Antennes relais
3838	04042C	ELUS_LOCAUX	2016-06-03 10:30:00	2016-06-03 11:30:00	\N
3839	04042C	COLL_TER	2016-06-03 12:00:00	2016-06-03 14:00:00	\N
3840	04042C	COLL_TER	2016-06-03 15:30:00	2016-06-03 16:00:00	affaires culturelles
3841	04042C	COLL_TER	2016-06-03 16:00:00	2016-06-03 17:00:00	Marché
3842	04042C	COLL_TER	2016-06-03 17:00:00	2016-06-03 17:30:00	PLU
1461	14089Y	REU_TRAV_PARL	2016-10-05 16:00:00	2016-10-05 17:00:00	\N
1462	14089Y	ORG_POL	2016-10-03 13:30:00	2016-10-03 20:30:00	\N
1463	14089Y	REU_TRAV_PARL	2016-10-05 18:30:00	2016-10-05 19:30:00	\N
1464	14089Y	CEREMONIE	2016-10-06 18:00:00	2016-10-06 20:00:00	\N
1502	14089Y	ACC_VISIT	2016-12-06 18:00:00	2016-12-06 20:00:00	\N
2046	14089Y	REU_TRAV_PARL	2016-10-13 10:00:00	2016-10-13 21:00:00	Strasbourg
1505	14089Y	ELUS_LOCAUX	2016-12-12 20:30:00	2016-12-12 22:00:00	\N
1521	01015L	DEL_ACT_PAR	2016-12-07 11:30:00	2016-12-07 13:00:00	L'avenir de la poste
1522	01015L	DEL_ACT_PAR	2016-12-20 10:00:00	2016-12-20 11:30:00	problématique des déchets
1541	14107H	ELUS_LOCAUX	2016-11-11 09:00:00	2016-11-11 17:00:00	rencontre des Maires du 04
3844	04042C	ELUS_LOCAUX	2016-05-30 11:00:00	2016-05-30 11:30:00	Interview par la presse
2048	14089Y	DEL_ACT_PAR	2016-10-17 11:00:00	2016-10-17 12:00:00	\N
2047	14089Y	REU_TRAV_PARL	2016-10-14 12:00:00	2016-10-14 20:00:00	Nice
2049	14089Y	REU_TRAV_PARL	2016-10-17 19:00:00	2016-10-17 20:00:00	\N
2050	14089Y	DEPL_PRES_GVT	2016-10-20 08:00:00	2016-10-20 21:00:00	Unesco Ségovie
2051	14089Y	DEPL_PRES_GVT	2016-10-21 08:00:00	2016-10-21 21:00:00	Unesco Ségovie
2052	14089Y	CEREMONIE	2016-11-30 08:00:00	2016-11-30 09:00:00	\N
2061	14327T	REU_TRAV_PARL	2016-12-08 09:30:00	2016-12-08 11:30:00	Comité Directeur ANEM - loi montagne
2062	14327T	COLL_TER	2016-12-09 17:00:00	2016-12-09 20:00:00	Conseil Départemental de l'Eduction Nationale, présentation de du projet de sectorisation des collège
2081	04040A	REU_TRAV_PARL	2016-12-13 11:00:00	2016-12-13 12:00:00	Réunion du Groupe UDI-UC
2082	04040A	COLLOQUE	2016-12-13 15:40:00	2016-12-13 16:30:00	Intervention dans le cadre du colloque "Hydrodiplomatie et Changement Climatique pour la Paix au Moyen-Orient : Cas du Bassin du Jourdain" 
2101	14089Y	DEPL_PRES_GVT	2016-10-24 08:00:00	2016-10-24 22:00:00	Caire
2102	14089Y	DEPL_PRES_GVT	2016-10-25 08:00:00	2016-10-25 22:00:00	Caire
2103	14089Y	DEPL_PRES_GVT	2016-10-26 08:00:00	2016-10-26 15:00:00	Caire
2242	08009T	ACC_DEPL_INTER	2016-12-06 15:00:00	2016-12-06 16:00:00	Ambassadeur ukraine
2243	08009T	ORG_POL	2016-12-06 18:00:00	2016-12-06 20:00:00	\N
2244	08009T	REU_TRAV_PARL	2016-12-07 08:00:00	2016-12-07 09:00:00	IRSN
2245	08009T	ELUS_LOCAUX	2016-12-07 17:30:00	2016-12-07 18:30:00	\N
2261	08009T	ELUS_LOCAUX	2016-12-08 17:00:00	2016-12-08 20:00:00	\N
2262	08009T	REU_TRAV_PARL	2016-12-13 11:00:00	2016-12-13 12:00:00	Réunion de groupe - UDI
2263	08009T	COLL_TER	2016-12-15 10:00:00	2016-12-15 17:00:00	Séance plénière Conseil régional
2264	08009T	ELUS_LOCAUX	2016-12-15 18:00:00	2016-12-15 19:30:00	\N
2286	14089Y	COLL_TER	2016-12-23 09:30:00	2016-12-23 12:00:00	\N
7453	04042C	ORG_POL	2017-11-21 11:00:00	2017-11-21 12:30:00	\N
2301	14089Y	CEREMONIE	2016-12-01 17:00:00	2016-12-01 18:00:00	\N
2302	14089Y	COLL_TER	2016-12-02 14:00:00	2016-12-02 16:00:00	\N
2324	14089Y	ELUS_LOCAUX	2016-12-09 09:00:00	2016-12-09 10:00:00	\N
2322	14089Y	COLL_TER	2016-12-02 16:00:00	2016-12-02 17:30:00	\N
2323	14089Y	COLL_TER	2016-12-06 10:00:00	2016-12-06 15:30:00	\N
2325	14089Y	ELUS_LOCAUX	2016-12-09 12:30:00	2016-12-09 14:00:00	\N
2326	14089Y	COLL_TER	2016-12-09 14:30:00	2016-12-09 15:30:00	\N
2327	14089Y	COLL_TER	2016-12-09 16:00:00	2016-12-09 17:00:00	\N
2328	14089Y	COLL_TER	2016-12-12 10:30:00	2016-12-12 12:00:00	\N
2329	14089Y	COLL_TER	2016-12-12 12:00:00	2016-12-12 14:00:00	\N
2330	14089Y	COLL_TER	2016-12-12 14:30:00	2016-12-12 16:00:00	\N
2331	14089Y	COLL_TER	2016-12-12 16:30:00	2016-12-12 18:00:00	\N
2341	14089Y	CEREMONIE	2016-12-14 11:30:00	2016-12-14 12:30:00	\N
2481	14089Y	REU_TRAV_PARL	2017-01-05 12:00:00	2017-01-05 14:00:00	\N
2482	14089Y	CEREMONIE	2017-01-05 15:00:00	2017-01-05 16:00:00	\N
2483	14089Y	CEREMONIE	2017-01-05 19:30:00	2017-01-05 20:30:00	\N
2484	14089Y	CEREMONIE	2017-01-06 11:00:00	2017-01-06 12:00:00	\N
2485	14089Y	REU_TRAV_PARL	2017-01-06 15:30:00	2017-01-06 16:30:00	\N
2486	14089Y	CEREMONIE	2017-01-06 18:00:00	2017-01-06 19:00:00	\N
2487	14089Y	CEREMONIE	2017-01-06 19:30:00	2017-01-06 20:30:00	\N
2488	14089Y	COLL_TER	2017-01-09 12:00:00	2017-01-09 14:00:00	\N
2489	14089Y	CEREMONIE	2017-01-09 18:30:00	2017-01-09 19:30:00	\N
3843	04042C	ACC_DEPL_INTER	2016-06-03 18:00:00	2016-06-03 20:00:00	ambassade de Russie
3845	04042C	ELUS_LOCAUX	2016-05-30 15:30:00	2016-05-30 16:30:00	\N
3846	04042C	ELUS_LOCAUX	2016-05-30 16:30:00	2016-05-30 17:30:00	\N
3847	04042C	ACC_DEPL_INTER	2016-05-30 18:30:00	2016-05-30 20:00:00	Partenariat France/Australie
3848	04042C	ELUS_LOCAUX	2016-05-27 09:30:00	2016-05-27 10:00:00	\N
3849	04042C	ELUS_LOCAUX	2016-05-27 10:00:00	2016-05-27 11:30:00	\N
3850	04042C	ELUS_LOCAUX	2016-05-27 12:00:00	2016-05-27 14:00:00	\N
3851	04042C	ELUS_LOCAUX	2016-05-27 15:30:00	2016-05-27 16:30:00	\N
3852	04042C	COLL_TER	2016-05-27 16:30:00	2016-05-27 17:30:00	affaires sportives
3853	04042C	COLL_TER	2016-05-27 17:30:00	2016-05-27 18:30:00	\N
3854	04042C	COLL_TER	2016-05-27 19:00:00	2016-05-27 23:00:00	Fête des voisins dans la Ville
3855	04042C	DEL_ACT_PAR	2016-05-23 08:00:00	2016-05-23 20:00:00	Mission à Londres - Entretiens sur le referendum britannique sur le Brexit
3856	04042C	COLL_TER	2016-05-20 09:00:00	2016-05-20 09:30:00	\N
3857	04042C	COLL_TER	2016-05-20 09:30:00	2016-05-20 10:30:00	Bâtiment
3858	04042C	ELUS_LOCAUX	2016-05-20 10:30:00	2016-05-20 11:30:00	Bâtiment
3859	04042C	COLL_TER	2016-05-20 11:30:00	2016-05-20 12:00:00	Espaces verts
3860	04042C	ELUS_LOCAUX	2016-05-20 12:00:00	2016-05-20 14:00:00	\N
3861	04042C	ELUS_LOCAUX	2016-05-19 12:00:00	2016-05-19 14:30:00	\N
3881	04042C	ELUS_LOCAUX	2016-05-13 08:45:00	2016-05-13 12:00:00	Bureau du syndicat des Eaux d'Ile-de-France
3901	04042C	ACC_VISIT	2016-05-09 09:00:00	2016-05-09 10:30:00	Visite du Sénat de l'association d'histoire et d'archéologie de Charenton-Saint Maurice
3902	04042C	COLL_TER	2016-05-09 10:30:00	2016-05-09 11:30:00	Logement social
3903	04042C	COLL_TER	2016-05-09 11:30:00	2016-05-09 14:00:00	\N
3904	04042C	COLLOQUE	2016-05-09 16:00:00	2016-05-09 17:30:00	\N
3905	04042C	ACC_DEPL_INTER	2016-05-09 17:30:00	2016-05-09 18:30:00	à la Présidence du Sénat
3906	04042C	ACC_VISIT	2016-05-06 09:00:00	2016-05-06 10:30:00	Visite du Sénat du jumelage Franco-Allemand d'Ablon
3907	04042C	REU_TRAV_PARL	2016-05-02 08:00:00	2016-05-02 09:00:00	Débat sur France Bleu
3908	04042C	COLL_TER	2016-05-02 10:00:00	2016-05-02 12:00:00	réunion de direction
3909	04042C	COLL_TER	2016-05-02 14:30:00	2016-05-02 16:30:00	Conseil de surveillance des Hôpitaux de Saint-Maurice
3910	04042C	COLL_TER	2016-05-02 16:30:00	2016-05-02 17:00:00	logement
3911	04042C	ELUS_LOCAUX	2016-05-02 18:00:00	2016-05-02 20:30:00	Election du nouveau Maire de Charenton-le-Pont
3912	04042C	REU_TRAV_PARL	2016-05-02 21:30:00	2016-05-02 22:00:00	Débat sur Public Sénat
3913	04042C	COLL_TER	2016-04-29 10:00:00	2016-04-29 11:00:00	\N
3914	04042C	COLL_TER	2016-04-29 15:00:00	2016-04-29 15:30:00	Petite enfance
3915	04042C	COLL_TER	2016-04-29 15:30:00	2016-04-29 17:00:00	Urbanisme
3916	04042C	COLL_TER	2016-04-29 17:00:00	2016-04-29 18:00:00	installation cabinet médical
3917	04042C	DEL_ACT_PAR	2016-04-25 04:00:00	2016-04-25 11:00:00	Cérémonie commémorative australienne d'Anzac Day à Villers-le-Bretonneux
3918	04042C	REU_TRAV_PARL	2016-04-25 16:00:00	2016-04-25 16:30:00	Débat sur Public Sénat
3919	04042C	ELUS_LOCAUX	2016-04-08 08:45:00	2016-04-08 10:00:00	Bureau du Syndicat des Eaux d'Ile-de-France
3920	04042C	COLL_TER	2016-04-08 11:00:00	2016-04-08 12:00:00	urbanisme
3921	04042C	COLL_TER	2016-04-08 15:00:00	2016-04-08 15:30:00	evenementiel
3922	04042C	COLL_TER	2016-04-08 16:00:00	2016-04-08 16:30:00	stationnement
3923	04042C	COLL_TER	2016-04-08 16:30:00	2016-04-08 17:30:00	bâtiment
3924	04042C	ACC_VISIT	2016-04-04 09:00:00	2016-04-04 10:30:00	Visite du Sénat de l'école Duquesne
3925	04042C	COLL_TER	2016-04-04 12:00:00	2016-04-04 14:00:00	Syndicat des Eaux d'Ile-de-France
3926	04042C	REU_TRAV_PARL	2016-04-04 16:00:00	2016-04-04 16:30:00	débat sur le plateau de Public Sénat
3927	04042C	ACC_DEPL_INTER	2016-04-04 17:30:00	2016-04-04 19:00:00	Conférence de presse du festival de musiques sacrées de Fès
3928	04042C	ACC_VISIT	2016-04-01 09:00:00	2016-04-01 10:00:00	Visite du Sénat d'une école de Saint-Maurice
3929	04042C	COLL_TER	2016-04-01 10:00:00	2016-04-01 11:00:00	bâtiment
3930	04042C	COLL_TER	2016-04-01 11:00:00	2016-04-01 12:00:00	\N
3941	04042C	COLL_TER	2016-04-01 15:30:00	2016-04-01 16:30:00	Urbanisme
3942	04042C	COLL_TER	2016-04-01 17:00:00	2016-04-01 18:30:00	Bureau de Territoire
3943	04042C	COLL_TER	2016-04-01 19:00:00	2016-04-01 21:00:00	Jumelage délégation Allemande
3944	04042C	COLL_TER	2016-03-25 10:00:00	2016-03-25 10:30:00	commerçant
3945	04042C	ELUS_LOCAUX	2016-03-25 10:30:00	2016-03-25 11:00:00	\N
3946	04042C	COLL_TER	2016-03-25 11:00:00	2016-03-25 12:00:00	\N
3947	04042C	ELUS_LOCAUX	2016-03-25 12:00:00	2016-03-25 13:00:00	\N
3948	04042C	ELUS_LOCAUX	2016-03-25 16:30:00	2016-03-25 17:00:00	\N
3949	04042C	ELUS_LOCAUX	2016-03-25 17:00:00	2016-03-25 17:30:00	\N
3950	04042C	ACC_VISIT	2016-03-21 09:30:00	2016-03-21 10:30:00	Visite des élèves d'une école de Saint-Maurice
3951	04042C	COLL_TER	2016-03-21 10:30:00	2016-03-21 12:00:00	Urbanisme
3952	04042C	COLL_TER	2016-03-21 15:30:00	2016-03-21 16:00:00	Bâtiment
3953	04042C	COLL_TER	2016-03-21 16:00:00	2016-03-21 17:00:00	logement social
3954	04042C	COLL_TER	2016-03-21 18:00:00	2016-03-21 19:30:00	ureau des Territoires
3955	04042C	COLL_TER	2016-03-21 20:30:00	2016-03-21 23:30:00	Conseil Municipal
3956	04042C	ELUS_LOCAUX	2016-03-18 09:00:00	2016-03-18 12:00:00	Comité d'installation du Syndicat des Eaux d'Ile-de-France
3957	04042C	ELUS_LOCAUX	2016-03-18 13:00:00	2016-03-18 14:30:00	avec les nouveaux Conseillers régionaux
3958	04042C	COLL_TER	2016-03-14 10:30:00	2016-03-14 11:30:00	Bâtiment
3959	04042C	COLL_TER	2016-03-14 11:30:00	2016-03-14 12:30:00	sécurité/logement
7631	19705W	ORG_POL	2017-12-05 10:30:00	2017-12-05 12:30:00	\N
3960	04042C	COLL_TER	2016-03-14 15:30:00	2016-03-14 16:30:00	Urbanisme
3961	04042C	ELUS_LOCAUX	2016-03-14 16:30:00	2016-03-14 17:00:00	\N
3962	04042C	ELUS_LOCAUX	2016-03-14 18:45:00	2016-03-14 23:00:00	au Sénat avec les élus de Chevilly-Larue, Rungis et Thiais
3963	04042C	ELUS_LOCAUX	2016-03-11 09:00:00	2016-03-11 10:15:00	Conseil métropolitain
3964	04042C	COLL_TER	2016-03-11 10:30:00	2016-03-11 12:00:00	\N
3965	04042C	COLL_TER	2016-03-11 15:30:00	2016-03-11 16:00:00	\N
3966	04042C	ELUS_LOCAUX	2016-03-11 16:00:00	2016-03-11 16:30:00	\N
3967	04042C	ELUS_LOCAUX	2016-03-11 16:30:00	2016-03-11 17:00:00	\N
1801	04042C	ORG_POL	2016-12-06 11:00:00	2016-12-06 12:30:00	Réunion du Groupe Les Républicains du Sénat
1802	04042C	ELUS_LOCAUX	2016-12-06 13:00:00	2016-12-06 16:00:00	déjeuner de fin d'année des Séniors de Saint-Maurice
1803	04042C	ORG_POL	2016-12-06 18:30:00	2016-12-06 20:00:00	Réunion autour de François Fillon
1804	04042C	ELUS_LOCAUX	2016-12-06 20:00:00	2016-12-06 23:00:00	Voeux du Syndicat des Eaux d'Ile-de-France
1805	04042C	REU_GVT	2016-12-07 12:30:00	2016-12-07 15:00:00	Rencontre avec la Présidente d'Estonie en présence du Président de la République à l'Elysée
1806	04042C	ACC_DEPL_INTER	2016-12-08 19:00:00	2016-12-08 21:00:00	Réception de fin d'année à l'Ambassade des Etats-Unis
1807	04042C	ACC_DEPL_INTER	2016-04-28 16:15:00	2016-04-28 17:30:00	Entretien avec Marko Mihkelson, Président de la commission de la Défense du Parlement d'Estonie
1808	04042C	REU_TRAV_PARL	2016-04-27 13:00:00	2016-04-27 15:00:00	Déjeuner avec Eric Ruf, administrateur général de la Comédie Française
1809	04042C	ACC_DEPL_INTER	2016-04-27 19:00:00	2016-04-27 22:00:00	Inauguration du Cercle des Ambassadeurs à Paris
1810	04042C	ORG_POL	2016-04-26 11:00:00	2016-04-26 12:30:00	Réunion du Groupe Les Républicains du Sénat
1811	04042C	ELUS_LOCAUX	2016-04-26 12:45:00	2016-04-26 15:00:00	Déjeuner avec le Préfet JF Carenco sur le thème "Quels grands chantier pour le Grand Paris ?"
1812	04042C	REU_GVT	2016-04-26 20:30:00	2016-04-26 23:00:00	Dîner d'Etat Australien à l'Elysée
1813	04042C	REU_TRAV_PARL	2016-04-05 09:30:00	2016-04-05 10:45:00	Conseil d'Administration d'Expertise France
1814	04042C	ORG_POL	2016-04-05 11:00:00	2016-04-05 12:30:00	Réunion du Groupe Les Républicains du Sénat
1815	04042C	REU_TRAV_PARL	2016-04-05 13:00:00	2016-04-05 14:30:00	Déjeuner avec des ONG
1816	04042C	REU_TRAV_PARL	2016-04-05 14:45:00	2016-04-05 15:00:00	Réunion du groupe de Travail Australie
1817	04042C	ORG_POL	2016-04-05 18:00:00	2016-04-05 19:00:00	Réunion du Bureau politique National Les Républicains
1818	04042C	ELUS_LOCAUX	2016-04-05 19:00:00	2016-04-05 23:00:00	Accueil au Sénat des élus de Saint-Mandé et Fontenay-aux-Roses
1819	04042C	REU_TRAV_PARL	2016-04-06 13:00:00	2016-04-06 15:00:00	Déjeuner-débat du Club de la Table Française
1820	04042C	REU_TRAV_PARL	2016-04-06 19:00:00	2016-04-06 20:30:00	Conférences des Présidents du Sénat
1821	04042C	ELUS_LOCAUX	2016-04-07 17:30:00	2016-04-07 18:30:00	Réunion avec la DRIEA/DIRIF sur les protéctions phoniques de l'A4
1822	04042C	ELUS_LOCAUX	2016-04-07 18:30:00	2016-04-07 19:30:00	Rendez-vous avec un élu du Val-de-Marne
1823	04042C	ELUS_LOCAUX	2016-04-07 21:00:00	2016-04-07 23:00:00	Réunion d'information : soin des arbres en milieu urbain
1824	04042C	CEREMONIE	2016-03-31 10:00:00	2016-03-31 12:00:00	Cérémonie Franco-Allemande au monument ossuaire de Champigny-sur-Marne
1828	04042C	REU_TRAV_PARL	2016-03-29 10:00:00	2016-03-29 11:00:00	Réunion des commissaires Les Républicains de la commission des affaires étrangères, de la Défense et des Faorces armées du Sénat
1829	04042C	ORG_POL	2016-03-29 11:00:00	2016-03-29 12:30:00	Réunion du Groupe Les Républicains du Sénat
1827	04042C	REU_TRAV_PARL	2016-03-30 08:15:00	2016-03-30 09:30:00	Réunion du Bureau du Groupe Interparlementaire d'Amitié France-Maroc
1830	04042C	REU_TRAV_PARL	2016-03-29 12:30:00	2016-03-29 14:30:00	déjeuner avec le Président du Groupe Interparlementaire d'Amitié Maroc-France
1831	04042C	ORG_POL	2016-03-29 18:00:00	2016-03-29 19:00:00	Réunion du Bureau politique National
1832	04042C	ELUS_LOCAUX	2016-03-24 18:30:00	2016-03-24 20:00:00	réunion pour la mise en place d'un dispositif commun sécuritaire entre les communes de Saint-Maurice et Joinville-le-Pont
1833	04042C	COLLOQUE	2016-03-23 09:00:00	2016-03-23 10:00:00	Colloque sur la loi Oudin-Santini
1834	04042C	ACC_DEPL_INTER	2016-03-23 17:00:00	2016-03-23 18:30:00	Entretien à la Présidence du Sénat avec Sir Julian King, nouvel ambassadeur du Royaume-Uni
1835	04042C	ELUS_LOCAUX	2016-03-23 19:00:00	2016-03-23 23:00:00	Réunion et dîner avec des élus du Val-de-Marne
1836	04042C	REU_TRAV_PARL	2016-03-22 08:30:00	2016-03-22 10:00:00	Réunion du Bureau de la commission des affaires étrangères, de la Défens et des Forces armées en présence du Président du Sénat
1837	04042C	ORG_POL	2016-03-22 11:00:00	2016-03-22 12:30:00	Réunion du Groupe Les Républicains du Sénat
1838	04042C	ORG_POL	2016-03-22 19:30:00	2016-03-22 20:30:00	Réunion du Bureau politique élargi du Val-de-Marne
1839	04042C	ELUS_LOCAUX	2016-03-22 20:45:00	2016-03-22 22:00:00	Comité Départemental du Val-de-Marne
1840	04042C	ACC_VISIT	2016-03-17 12:00:00	2016-03-17 13:00:00	Visiote du Sénat à la direction des Hôpitaux de Saint-Maurice
1841	04042C	REU_TRAV_PARL	2016-03-17 13:00:00	2016-03-17 14:30:00	Déjeuner avec la direction des Hôpitaux de Saint-Maurice
1846	04042C	ACC_DEPL_INTER	2016-03-15 18:30:00	2016-03-15 20:00:00	Reception à l'Ambassade de Roumanie
1843	04042C	ORG_POL	2016-03-16 08:30:00	2016-03-16 09:30:00	Réunion sur les Primaires de la Droite et du Centre
1844	04042C	REU_TRAV_PARL	2016-03-16 12:45:00	2016-03-16 14:30:00	Déjeuner du Groupe Interparlementaire d'Amitié France-Italie
1845	04042C	ORG_POL	2016-03-16 19:30:00	2016-03-16 21:00:00	réunion d'un comité de circonscription du Val-de-Marne
1847	04042C	ELUS_LOCAUX	2016-03-10 09:00:00	2016-03-10 12:00:00	Réunion avec la Présidente de la Région, Valérie Pecresse
1848	04042C	ACC_DEPL_INTER	2016-03-10 12:30:00	2016-03-10 14:20:00	Déjeuner avec le Président de la commission des Affaires étrangères Russe et le Groupe Interparlementaire d'Amitié France-Russie
1849	04042C	ACC_DEPL_INTER	2016-03-10 14:30:00	2016-03-10 16:00:00	Rencontre à la Président du Sénat du roi et de la reine des Pays-Bas
1850	04042C	ACC_DEPL_INTER	2016-03-10 17:30:00	2016-03-10 18:30:00	Entretien avec le Vice-président permanent de la commission des relations extérieurs du parti communiste Vietnamien
1851	04042C	ACC_DEPL_INTER	2016-03-10 19:00:00	2016-03-10 20:00:00	Rencontre avec l'Ambassadeur d'Argentine
1852	04042C	ELUS_LOCAUX	2016-03-09 13:00:00	2016-03-09 14:30:00	Déjeuner avec des élus du Val-de-Marne
1853	04042C	ELUS_LOCAUX	2016-03-09 18:45:00	2016-03-09 23:00:00	Accueil au Sénat des élus de Charenton-Saint Maurice
1854	04042C	REU_TRAV_PARL	2016-03-08 10:15:00	2016-03-08 11:30:00	Réunion des commissaires Les Républicains de la commission des affaires étrangères, de la Défense et des Forces armées du Sénat
1855	04042C	ORG_POL	2016-03-08 11:45:00	2016-03-08 13:00:00	Réunion du groupe Les Républicains du Sénat
3622	04042C	ELUS_LOCAUX	2016-11-18 16:30:00	2016-11-18 17:30:00	\N
1856	04042C	ORG_POL	2016-03-08 18:00:00	2016-03-08 20:00:00	Réunion du Bureau politique National Les Républicains
1857	04042C	ACC_DEPL_INTER	2016-03-08 20:30:00	2016-03-08 23:00:00	entretien avec l'Ambassadeur du Maroc auprès de l'Unesco
1858	04042C	REU_TRAV_PARL	2016-03-02 09:30:00	2016-03-02 10:30:00	Réunion avec les commissaires Les républicains de la commissions des Affaires étrangères, de la Défense et des Forces armées du Sénat
1859	04042C	REU_TRAV_PARL	2016-03-02 13:00:00	2016-03-02 14:30:00	Rencontre avec le Directeur d'Expertise France
1860	04042C	ORG_POL	2016-03-01 11:00:00	2016-03-01 12:30:00	Réunion du Groupe Les Républicains du Sénat
1861	04042C	REU_GVT	2016-03-01 18:00:00	2016-03-01 20:00:00	Réunion à Matignon - Bilan après les attentats du 13 novembre
1863	04042C	ACC_DEPL_INTER	2016-02-25 12:00:00	2016-02-25 14:00:00	55ème anniversaire de l'indépendance de l'Etat du Koweit à l'Ambassade
1884	04042C	COLL_TER	2016-02-18 09:00:00	2016-02-18 12:00:00	Conseil de Métropole
1885	04042C	REU_TRAV_PARL	2016-02-18 16:30:00	2016-02-18 17:30:00	Rendez-vous avec de représentants de l'Agence Régionale de Santé et les Groupements hospitaliers de territoire
1886	04042C	ELUS_LOCAUX	2016-02-18 18:30:00	2016-02-18 19:30:00	assemblée Générale de l'association "Au petit Plus"
1887	04042C	ELUS_LOCAUX	2016-02-18 19:30:00	2016-02-18 20:30:00	Réunion de section du Val-de-Marne
1888	04042C	REU_TRAV_PARL	2016-02-17 08:00:00	2016-02-17 09:30:00	Entretien avec l'Ambassadeur de France en Arabie Saoudite
1889	04042C	ORG_POL	2016-02-17 12:00:00	2016-02-17 14:30:00	Réunion sur Les Primaires de la Droite et du Centre
1661	14089Y	CEREMONIE	2016-12-09 18:00:00	2016-12-09 19:00:00	\N
1662	14089Y	REU_TRAV_PARL	2016-12-14 13:45:00	2016-12-14 14:45:00	\N
1681	01025N	ORGEXTPAR	2016-12-07 14:30:00	2016-12-07 18:00:00	HAUT-CONSEIL DES MUSÉES DE FRANCE
1682	14089Y	REU_TRAV_PARL	2016-10-11 16:00:00	2016-10-11 17:00:00	\N
1721	14327T	REU_GVT	2016-09-12 17:30:00	2016-09-12 18:30:00	rencontre avec Jean-Michel Baylet, Ministre de l'Aménagement du Territoire, de la Ruralité et des Collectivités territoriales
1722	14327T	ELUS_LOCAUX	2016-09-15 18:30:00	2016-09-15 21:00:00	Commune de Riom-ès-Montagnes
1723	14327T	ELUS_LOCAUX	2016-09-19 19:00:00	2016-09-19 21:00:00	Conseil municipal de Saint-Flour
1724	14327T	DEL_ACT_PAR	2016-09-22 10:00:00	2016-09-22 17:00:00	Commission des lois dans le Cantal
1725	14327T	DEL_ACT_PAR	2016-09-22 17:00:00	2016-09-22 19:00:00	Accueil commission des lois Maison des Services du pays de Murat
1726	14327T	COLL_TER	2016-10-03 20:00:00	2016-10-03 23:00:00	Réunion élus fusion des 3 intercommunalités pays de Massiac, Cézallier et Murat
1727	14327T	REU_TRAV_PARL	2016-10-05 18:00:00	2016-10-05 19:00:00	Audition dans le cadre de la PPL Transport public particulier de personnes 
1728	14327T	REU_TRAV_PARL	2016-10-07 10:30:00	2016-10-07 12:00:00	Lancement collectif élus et agriculteurs en soutien à l'agriculture du Massif-Central
1729	14327T	ELUS_LOCAUX	2016-10-17 14:30:00	2016-10-17 17:00:00	Commission DETR à la Préfecture
1730	14327T	COLL_TER	2016-10-17 18:00:00	2016-10-17 20:00:00	Conseil Départemental de l'Eduction Nationale, présentation de du projet de sectorisation des collège
1741	14327T	CEREMONIE	2016-10-20 15:00:00	2016-10-20 16:00:00	Signature avenant de la convention scolaire
1761	14327T	ACC_VISIT	2016-10-27 11:00:00	2016-10-27 16:00:00	Délégation élus du canton de Murat
1762	14327T	CEREMONIE	2016-10-28 11:00:00	2016-10-28 17:00:00	Déplacement du Président Larcher en Haute-Loire
1763	14327T	COLL_TER	2016-11-04 14:30:00	2016-11-04 17:00:00	Session du Conseil départemental
1764	14327T	CEREMONIE	2016-11-07 11:00:00	2016-11-07 12:00:00	Arrivée de Madame le Préfet
1765	14327T	CEREMONIE	2016-11-07 14:30:00	2016-11-07 17:00:00	Inaugurations sur la commune Le Rouget -Pers
1766	14327T	REU_TRAV_PARL	2016-11-09 12:00:00	2016-11-09 13:00:00	réunion de groupe sur la loi montagne
1767	14327T	REU_TRAV_PARL	2016-11-09 19:30:00	2016-11-09 20:30:00	Audition loi montagne ARCEP
1768	14327T	ELUS_LOCAUX	2016-11-10 20:30:00	2016-11-10 23:00:00	Communauté de communes du Pays de Maurs
1769	14327T	ELUS_LOCAUX	2016-11-14 14:30:00	2016-11-14 15:00:00	réunion DETR arrondissement de Saint-Flour
1770	14327T	CEREMONIE	2016-11-14 16:00:00	2016-11-14 17:30:00	Inauguration par Bernard Cazeneuve du nouveau centre d'incendie et de secours d'Aurillac
1771	14327T	REU_TRAV_PARL	2016-11-16 17:00:00	2016-11-16 19:00:00	L'emploi agricole et la dynamique de Territoire
1772	14327T	COLL_TER	2016-11-18 09:30:00	2016-11-18 12:30:00	Conférence des territoires - conseil départemental
1773	14327T	REU_TRAV_PARL	2016-11-18 15:00:00	2016-11-18 16:00:00	rendez-vous de travail sur déploiement THD et téléphonie dans le Cantal
1774	14327T	REU_TRAV_PARL	2016-11-23 16:00:00	2016-11-23 17:00:00	Audition Orange dans le cadre du projet de loi montagne
1775	14327T	ACC_VISIT	2016-11-24 10:30:00	2016-11-24 15:00:00	Equipe de la communauté de communes du pays de Murat
1776	14327T	REU_TRAV_PARL	2016-11-30 14:00:00	2016-11-30 15:00:00	Rencontre services ministère agriculture pour dossiers cantaliens
1777	14327T	REU_TRAV_PARL	2016-11-30 19:00:00	2016-11-30 20:00:00	Audition loi montagne ARCEP
1778	14327T	CEREMONIE	2016-12-02 11:00:00	2016-12-02 13:00:00	Inauguration du marché couvert rénové d'Aurillac par Martine Pinville Secrétaire d'Etat
1781	08010L	COLL_TER	2016-12-08 18:00:00	2016-12-08 21:00:00	\N
1890	04042C	ELUS_LOCAUX	2016-02-17 18:30:00	2016-02-17 21:00:00	réunion sur Les Primaires de la Droite et du Centre
1891	04042C	ORG_POL	2016-02-16 11:00:00	2016-02-16 12:30:00	Réunion du Groupe Les Républicains du Sénat
1892	04042C	ACC_DEPL_INTER	2016-02-16 20:00:00	2016-02-16 22:00:00	rencontre avec l'Ambassadeur d'Israel en France
2181	08010L	REU_TRAV_PARL	2016-12-14 14:00:00	2016-12-14 16:00:00	\N
2201	14089Y	CEREMONIE	2016-11-02 18:30:00	2016-11-02 19:30:00	\N
2202	14089Y	COLL_TER	2016-11-04 09:00:00	2016-11-04 10:00:00	\N
2203	14089Y	COLL_TER	2016-11-04 11:00:00	2016-11-04 12:00:00	\N
2222	14089Y	COLL_TER	2016-11-18 09:30:00	2016-11-18 11:00:00	\N
2223	14089Y	CEREMONIE	2016-11-25 16:00:00	2016-11-25 17:30:00	\N
2224	14089Y	COLL_TER	2016-11-28 08:30:00	2016-11-28 10:00:00	\N
2225	14089Y	COLL_TER	2016-11-28 14:30:00	2016-11-28 16:30:00	\N
2226	14089Y	COLL_TER	2016-11-28 12:00:00	2016-11-28 14:00:00	\N
2421	04040A	REU_TRAV_PARL	2016-12-20 11:00:00	2016-12-20 12:00:00	Réunion de Groupe UDI-UC
2441	08010L	ORG_POL	2016-12-20 11:00:00	2016-12-20 12:30:00	\N
2461	14089Y	REU_TRAV_PARL	2016-12-21 11:00:00	2016-12-21 16:00:00	\N
2462	14089Y	CEREMONIE	2016-12-22 11:00:00	2016-12-22 12:00:00	\N
2521	14179A	ORGEXTPAR	2017-01-12 09:30:00	2017-01-12 12:00:00	CNIL
2522	14179A	ORGEXTPAR	2017-01-19 09:30:00	2017-01-19 12:00:00	CNIL
2523	14179A	ORGEXTPAR	2017-01-26 09:30:00	2017-01-26 12:00:00	CNIL
2526	14179A	ORGEXTPAR	2017-02-23 09:30:00	2017-02-23 12:00:00	CNIL
2529	14179A	ORGEXTPAR	2017-03-16 09:30:00	2017-03-16 12:00:00	CNIL
2541	04040A	REU_TRAV_PARL	2017-01-10 11:00:00	2017-01-10 12:00:00	Réunion du groupe UDI-UC
2542	04040A	REU_TRAV_PARL	2017-01-10 15:00:00	2017-01-10 17:00:00	Visite du CIE
2581	11054L	COLL_TER	2017-01-09 09:00:00	2017-01-09 11:30:00	Assemblée générale et conseil d'administration Bondinnov
2582	11054L	ORG_POL	2017-01-10 10:00:00	2017-01-10 12:30:00	Bureau et groupe PS
2583	11054L	ACC_VISIT	2017-01-10 14:00:00	2017-01-10 16:00:00	Accueil classes du collège Eluard de Montreuil
2584	11054L	COLL_TER	2017-01-09 18:30:00	2017-01-09 20:30:00	V¿ux commune des Lilas
2601	08010L	ORG_POL	2017-01-10 10:00:00	2017-01-10 11:00:00	\N
2602	08010L	ORG_POL	2017-01-10 11:30:00	2017-01-10 12:30:00	\N
2603	08010L	REU_TRAV_PARL	2017-01-11 10:00:00	2017-01-11 12:00:00	\N
2621	14089Y	ELUS_LOCAUX	2017-01-12 19:30:00	2017-01-12 22:00:00	\N
2622	14089Y	ACC_DEPL_INTER	2017-01-10 14:30:00	2017-01-10 15:30:00	\N
2623	14089Y	CEREMONIE	2017-01-13 19:00:00	2017-01-13 20:00:00	\N
2624	14089Y	CEREMONIE	2017-01-13 21:00:00	2017-01-13 22:00:00	\N
2625	14089Y	ELUS_LOCAUX	2017-01-16 15:00:00	2017-01-16 16:00:00	\N
2631	14089Y	REU_TRAV_PARL	2017-01-11 11:00:00	2017-01-11 12:00:00	\N
2661	08009T	REU_TRAV_PARL	2017-01-10 05:00:00	2017-01-10 10:00:00	Visite Marché international de Rungis
2662	08009T	REU_TRAV_PARL	2017-01-10 10:00:00	2017-01-10 11:00:00	\N
2663	08009T	ORG_POL	2017-01-10 11:00:00	2017-01-10 12:00:00	\N
2664	08009T	REU_TRAV_PARL	2017-01-10 15:00:00	2017-01-10 17:00:00	Réunion de commission
2665	08009T	REU_GVT	2017-01-10 18:00:00	2017-01-10 20:00:00	Voeux Elysée
2666	08009T	REU_TRAV_PARL	2017-01-11 07:30:00	2017-01-11 08:30:00	Rdv Président du Sénat
2667	08009T	REU_TRAV_PARL	2017-01-11 08:30:00	2017-01-11 11:30:00	Réunion de commission
2681	11054L	ACC_VISIT	2017-01-16 12:00:00	2017-01-16 14:00:00	\N
2669	08009T	REU_TRAV_PARL	2017-01-11 14:00:00	2017-01-11 16:00:00	Audition APVF
2670	08009T	ELUS_LOCAUX	2017-01-11 17:00:00	2017-01-11 20:00:00	\N
2672	08009T	ELUS_LOCAUX	2017-01-12 12:00:00	2017-01-12 16:00:00	\N
2673	08009T	REU_TRAV_PARL	2017-01-12 10:00:00	2017-01-12 11:00:00	\N
2721	04041B	CEREMONIE	2017-01-17 18:30:00	2017-01-17 18:45:00	Voeux du Président Larcher au Sénat
2861	08010L	ORG_POL	2017-01-17 11:00:00	2017-01-17 12:30:00	\N
3021	11063M	REU_TRAV_PARL	2016-12-12 10:30:00	2016-12-12 12:00:00	Réunion de travail avec le maire de Drocourt au sujet de la pharmacie Carmi de sa commune.
3022	11063M	REU_TRAV_PARL	2016-12-13 18:00:00	2016-12-13 21:00:00	Rencontre des élus ruraux à Beaurainville.
3023	11063M	REU_TRAV_PARL	2016-12-15 10:00:00	2016-12-15 12:00:00	Rencontre avec les acteurs de l'aide à domicile pour préparer un colloque au mois de mars.
3024	11063M	ELUS_LOCAUX	2016-12-16 10:00:00	2016-12-16 12:00:00	Préparation de la rencontre avec l'ARS.
3025	11063M	ELUS_LOCAUX	2016-12-16 14:00:00	2016-12-16 16:00:00	Préparation de la rencontre avec la CARMI.
3026	11063M	CEREMONIE	2017-01-25 19:00:00	2017-01-25 21:00:00	Voeux à l'Association Départementale des Elus Communistes et Républicains du Pas-de-Calais
3027	11063M	ELUS_LOCAUX	2017-01-27 14:00:00	2017-01-27 18:00:00	Rencontre avec Mme Ricomes, DG de l'ARS.
3043	04042C	REU_TRAV_PARL	2017-01-18 08:30:00	2017-01-18 09:30:00	Réunion du Bureau de la commission des Affaires étrangères
3045	04042C	ORG_POL	2017-01-18 13:00:00	2017-01-18 14:30:00	avec la Présidente de la Région Ile-de-France
3044	04042C	ORG_POL	2017-01-18 12:00:00	2017-01-18 13:00:00	des parlementaires LR
3046	04042C	ORG_POL	2017-01-24 11:00:00	2017-01-24 12:30:00	Groupe Les Républicains du Sénat
3047	04042C	ACC_VISIT	2017-01-24 12:30:00	2017-01-24 14:45:00	Visite du Sénat et rencontre avec des chefs d'entreprises
3061	04042C	COLL_TER	2017-01-24 15:00:00	2017-01-24 16:00:00	Syndicat des Eaux d'Ile-de-France
2626	14089Y	REU_TRAV_PARL	2017-01-17 14:15:00	2017-01-17 15:15:00	\N
2627	14089Y	CEREMONIE	2017-01-17 19:00:00	2017-01-17 20:00:00	\N
2628	14089Y	CEREMONIE	2017-01-19 17:30:00	2017-01-19 18:30:00	\N
2629	14089Y	CEREMONIE	2017-01-20 19:00:00	2017-01-20 20:00:00	\N
2630	14089Y	CEREMONIE	2017-01-20 20:15:00	2017-01-20 21:00:00	\N
3241	08010L	ACC_VISIT	2017-01-31 15:00:00	2017-01-31 15:30:00	délégation d'Angola
3266	08009T	DEPL_PRES_GVT	2017-02-02 08:00:00	2017-02-02 17:00:00	\N
3262	08009T	REU_TRAV_PARL	2017-01-31 15:30:00	2017-01-31 17:00:00	\N
3001	11063M	CEREMONIE	2016-12-02 11:00:00	2016-12-02 12:30:00	Pose de la première pierre de l'EHPA de Drocourt
3002	11063M	ELUS_LOCAUX	2016-12-06 08:00:00	2016-12-06 12:00:00	Intervention au CIDEFE sur les suites de la loi Adaptation de la Société au Vieillissement
3003	11063M	REU_TRAV_PARL	2016-12-08 09:30:00	2016-12-08 12:00:00	Intervention au congrès de la FSU retraités.
3062	04042C	ELUS_LOCAUX	2017-01-24 19:00:00	2017-01-24 20:30:00	Cérémonie des voeux de la Président de la région Ile-de-France
3063	04042C	ELUS_LOCAUX	2017-01-25 13:00:00	2017-01-25 14:30:00	\N
3081	04042C	ELUS_LOCAUX	2017-01-25 19:00:00	2017-01-25 20:30:00	Cérémonie des voeux de Limeil-Brévannes
3082	04042C	ACC_DEPL_INTER	2017-01-26 19:00:00	2017-01-26 20:00:00	Cérémonie des voeux de l'Ambassadeur de Russie
3083	04042C	COLL_TER	2017-01-26 20:00:00	2017-01-26 21:30:00	Cérémonie des voeux du VEDIF
3084	08009T	REU_TRAV_PARL	2017-01-17 08:30:00	2017-01-17 09:30:00	Rdv Transdev
3085	08009T	REU_TRAV_PARL	2017-01-17 10:00:00	2017-01-17 11:00:00	Rdv ARF
3086	08009T	REU_TRAV_PARL	2017-01-17 11:00:00	2017-01-17 12:00:00	Réunion de groupe - UDI
3090	08009T	ELUS_LOCAUX	2017-01-18 18:00:00	2017-01-18 20:30:00	\N
3088	08009T	COLLOQUE	2017-01-17 18:00:00	2017-01-17 19:00:00	Audition think tank TDIE
3089	08009T	ORGEXTPAR	2017-01-18 15:00:00	2017-01-18 17:00:00	Commission numérique ARF
3091	08009T	ELUS_LOCAUX	2017-01-19 14:00:00	2017-01-19 20:00:00	\N
3092	08009T	REU_GVT	2017-01-24 09:30:00	2017-01-24 11:00:00	Audition Secrétaire général du gouvernement
3093	08009T	REU_TRAV_PARL	2017-01-24 14:30:00	2017-01-24 15:00:00	\N
3094	08009T	COLLOQUE	2017-01-24 16:30:00	2017-01-24 18:00:00	\N
3095	08009T	REU_TRAV_PARL	2017-01-25 17:00:00	2017-01-25 18:30:00	Rdv ANSES
3101	08010L	REU_TRAV_PARL	2017-01-26 11:30:00	2017-01-26 12:15:00	agriculture
3097	08009T	REU_TRAV_PARL	2017-01-26 08:45:00	2017-01-26 09:30:00	Rdv Caisse des dépôts
3098	08009T	ELUS_LOCAUX	2017-01-26 18:00:00	2017-01-26 20:15:00	\N
3141	08010L	ORG_POL	2017-01-31 11:00:00	2017-01-31 12:30:00	Groupe LR
3182	04040A	ORG_POL	2017-01-31 19:00:00	2017-01-31 20:00:00	Bureau exécutif UDI
3162	08010L	REU_TRAV_PARL	2017-01-31 14:00:00	2017-01-31 14:30:00	agriculture
3181	04040A	ORG_POL	2017-01-31 17:45:00	2017-01-31 19:00:00	Bureau politique UDI "Défense et relations internationales"
3183	04040A	REU_TRAV_PARL	2017-01-31 09:00:00	2017-01-31 11:00:00	Séance de travail de la commission du Livre Blanc sur la Pénitentiaire
3184	04040A	REU_TRAV_PARL	2017-01-31 11:00:00	2017-01-31 12:00:00	Réunion de groupe UDI
3185	04042C	ORG_POL	2017-01-31 11:00:00	2017-01-31 12:30:00	Groupe Les Républicains du Sénat
3302	08009T	ORG_POL	2017-01-31 17:30:00	2017-01-31 19:30:00	Comité exécutif UDI
3264	08009T	ORG_POL	2017-02-01 08:30:00	2017-02-01 09:30:00	Convention UDI
3265	08009T	DEPL_PRES_GVT	2017-02-01 11:30:00	2017-02-01 20:00:00	\N
3281	04040A	REU_TRAV_PARL	2017-02-09 08:30:00	2017-02-09 12:30:00	Réunion de l'Assemblée parlementaire de l'OTAN à l'OCDE
3301	08009T	REU_TRAV_PARL	2017-01-31 11:00:00	2017-01-31 12:30:00	Réunion de groupe - UDI
3321	14053L	REU_TRAV_PARL	2017-02-01 09:30:00	2017-02-01 11:00:00	Commission des Affaires Sociales
3322	14053L	REU_TRAV_PARL	2017-02-08 09:00:00	2017-02-08 11:00:00	Commission des Affaires Sociales
3341	14053L	ACC_VISIT	2017-02-08 11:30:00	2017-02-08 15:30:00	\N
3342	14053L	REU_TRAV_PARL	2017-02-08 16:30:00	2017-02-08 18:30:00	Mission d'évaluation MECCS
3343	14053L	REU_TRAV_PARL	2017-02-09 09:30:00	2017-02-09 10:30:00	Audition Mission parlementaire sur les fraudes
3381	14179A	CEREMONIE	2017-01-06 19:00:00	2017-01-06 21:00:00	Voeux de la mairie de Marnaz
3382	14179A	CEREMONIE	2017-01-09 19:00:00	2017-01-09 21:00:00	Voeux de la mairie de Thyez
3383	14179A	ELUS_LOCAUX	2017-01-09 16:00:00	2017-01-09 17:00:00	\N
3384	14179A	ACC_VISIT	2017-01-11 09:00:00	2017-01-11 14:00:00	\N
3385	14179A	ORG_POL	2017-01-11 17:00:00	2017-01-11 18:00:00	\N
3386	14179A	ACC_DEPL_INTER	2017-01-11 18:30:00	2017-01-11 20:00:00	\N
3387	14179A	CEREMONIE	2017-01-12 12:00:00	2017-01-12 13:00:00	Voeux du Ministre Baylet
3388	14179A	COLL_TER	2017-01-13 09:00:00	2017-01-13 12:00:00	\N
3389	14179A	CEREMONIE	2017-01-13 19:00:00	2017-01-13 21:00:00	Voeux de la Mairie de Magland
3390	14179A	CEREMONIE	2017-01-16 11:00:00	2017-01-16 12:00:00	Voeux du Préfet de la Haute-Savoie
3391	14179A	ELUS_LOCAUX	2017-01-16 14:30:00	2017-01-16 15:30:00	Territoires respirables
3392	14179A	REU_TRAV_PARL	2017-01-17 16:00:00	2017-01-17 16:30:00	\N
3393	14179A	CEREMONIE	2017-01-17 19:00:00	2017-01-17 20:00:00	Voeux du Président du Sénat
3394	14179A	ORG_POL	2017-01-18 18:00:00	2017-01-18 19:00:00	\N
3395	14179A	ACC_DEPL_INTER	2017-01-18 15:30:00	2017-01-18 16:30:00	\N
3396	14179A	CEREMONIE	2017-01-19 19:00:00	2017-01-19 21:00:00	Voeux de la Maire de Vétraz-Monthoux
3397	14179A	CEREMONIE	2017-01-20 09:30:00	2017-01-20 11:00:00	Inauguration installation du Brévent
3398	14179A	ELUS_LOCAUX	2017-01-20 14:30:00	2017-01-20 16:00:00	ZSP
3399	14179A	COLL_TER	2017-01-16 17:00:00	2017-01-16 19:00:00	2CCAM
3400	14179A	COLL_TER	2017-01-16 20:00:00	2017-01-16 22:00:00	Mairie de Marnaz
3401	14179A	CEREMONIE	2017-01-20 19:00:00	2017-01-20 21:00:00	Voeux de la Mairie de Scionzier
3402	14179A	ELUS_LOCAUX	2017-01-23 09:00:00	2017-01-23 10:00:00	\N
3403	14179A	ELUS_LOCAUX	2017-01-23 11:00:00	2017-01-23 12:00:00	Groupe de travail pollution
3404	14179A	CEREMONIE	2017-01-23 18:00:00	2017-01-23 19:00:00	\N
3405	14179A	COLL_TER	2017-01-24 18:00:00	2017-01-24 20:00:00	2CCAM
3406	14179A	CEREMONIE	2017-01-25 18:00:00	2017-01-25 19:00:00	\N
3407	14179A	CEREMONIE	2017-01-26 17:00:00	2017-01-26 18:00:00	\N
3408	14179A	COLL_TER	2017-01-26 18:30:00	2017-01-26 20:00:00	2CCAM
3421	14179A	CEREMONIE	2017-01-20 12:00:00	2017-01-20 13:00:00	\N
3422	14179A	ELUS_LOCAUX	2017-01-27 10:00:00	2017-01-27 11:00:00	\N
3423	14179A	CEREMONIE	2017-01-27 13:30:00	2017-01-27 15:00:00	Inauguration tapis de neige Le Reposoir
3424	14179A	CEREMONIE	2017-01-27 18:30:00	2017-01-27 20:00:00	Voeux de la maiie du Mont-Saxonnet
3425	14179A	ELUS_LOCAUX	2017-01-30 10:00:00	2017-01-30 11:00:00	Groupe de travail pollution
3426	14179A	CEREMONIE	2017-01-30 11:30:00	2017-01-30 12:30:00	Installation du Sous-Prefet de St Julien en Genevois
3427	14179A	COLL_TER	2017-01-30 15:00:00	2017-01-30 17:00:00	2CCAM
3428	14179A	COLL_TER	2017-01-30 17:30:00	2017-01-30 18:30:00	Mairie de Marnaz
3429	14179A	CEREMONIE	2017-01-30 19:00:00	2017-01-30 21:00:00	Voeux de la mairie de Taninges
3430	14179A	ELUS_LOCAUX	2017-01-31 11:00:00	2017-01-31 12:30:00	Groupe de travail pollution
3431	14179A	ORG_POL	2017-01-31 17:30:00	2017-01-31 18:30:00	\N
3432	14179A	ORG_POL	2017-01-31 19:00:00	2017-01-31 21:00:00	\N
3433	14179A	ELUS_LOCAUX	2017-02-02 11:00:00	2017-02-02 12:00:00	\N
3434	14179A	ELUS_LOCAUX	2017-02-02 15:00:00	2017-02-02 17:00:00	\N
3435	14179A	COLL_TER	2017-02-02 17:30:00	2017-02-02 22:00:00	2CCAM
3436	14179A	CEREMONIE	2017-02-03 10:00:00	2017-02-03 12:00:00	Inauguration tapis du Grand Bornand
3442	14179A	CEREMONIE	2017-02-03 15:30:00	2017-02-03 16:30:00	Inauguration MSAP de Fillière
3443	14179A	ELUS_LOCAUX	2017-02-03 17:00:00	2017-02-03 18:00:00	\N
3444	14179A	CEREMONIE	2017-02-03 18:30:00	2017-02-03 19:00:00	\N
3445	14179A	CEREMONIE	2017-02-03 19:00:00	2017-02-03 20:00:00	\N
3446	08047A	ORG_POL	2017-01-24 11:00:00	2017-01-24 13:00:00	REUNION LR
3447	08047A	ORG_POL	2017-01-31 11:00:00	2017-01-31 13:00:00	REUNION LR
3448	08047A	REU_TRAV_PARL	2017-02-01 14:30:00	2017-02-01 16:00:00	SEANCE
3461	14179A	COLL_TER	2017-02-06 08:45:00	2017-02-06 09:45:00	Mairie de Marnaz
3462	14179A	ELUS_LOCAUX	2017-02-06 10:00:00	2017-02-06 12:00:00	\N
3463	14179A	CEREMONIE	2017-02-06 14:30:00	2017-02-06 15:30:00	Inauguration travaux SM3A
3464	14179A	COLL_TER	2017-02-06 19:00:00	2017-02-06 22:00:00	Mairie de Marnaz
3486	04042C	COLL_TER	2017-01-20 08:45:00	2017-01-20 12:00:00	Bureau du Syndicat des Eaux d'Ile-de-France
3487	04042C	ELUS_LOCAUX	2017-01-20 19:00:00	2017-01-20 20:30:00	Cérémonie des voeux de Rungis
3488	04042C	COLL_TER	2017-01-13 11:15:00	2017-01-13 11:45:00	CFA Sup2000
3489	04042C	COLL_TER	2017-01-13 11:45:00	2017-01-13 13:00:00	culture
3490	04042C	ELUS_LOCAUX	2017-01-13 13:00:00	2017-01-13 14:30:00	\N
3491	04042C	COLL_TER	2017-01-13 16:30:00	2017-01-13 17:00:00	emploi
3492	04042C	ELUS_LOCAUX	2017-01-13 17:00:00	2017-01-13 17:30:00	\N
3493	04042C	COLL_TER	2017-01-13 17:30:00	2017-01-13 18:30:00	commerce
3494	04042C	ELUS_LOCAUX	2017-01-13 19:00:00	2017-01-13 21:00:00	Cérémonie des voeux de Périgny-sur-Yerres
3495	04042C	COLL_TER	2017-01-09 11:00:00	2017-01-09 12:30:00	urbanisme
3496	04042C	COLL_TER	2017-01-09 13:00:00	2017-01-09 14:30:00	Déjeuner des Maires EPT 10
3497	04042C	ACC_VISIT	2017-01-09 14:30:00	2017-01-09 15:30:00	Visite du Sénat d'une classe de CM2 d'une école de Villejuif
3498	04042C	COLL_TER	2017-01-09 16:00:00	2017-01-09 16:30:00	\N
3499	04042C	COLL_TER	2017-01-09 16:30:00	2017-01-09 17:00:00	\N
3500	04042C	COLL_TER	2017-01-09 17:30:00	2017-01-09 18:00:00	\N
3501	04042C	COLL_TER	2017-01-09 20:30:00	2017-01-09 22:00:00	Hôpitaux de Saint-Maurice
3502	04042C	COLL_TER	2017-01-06 10:00:00	2017-01-06 11:00:00	association
4321	04042C	COLL_TER	2017-01-23 17:00:00	2017-01-23 18:15:00	Galette du personnel
1942	04042C	ELUS_LOCAUX	2015-12-21 19:30:00	2015-12-21 23:30:00	Reception des voeux de Saint-Maurice
1943	04042C	ELUS_LOCAUX	2016-01-06 19:00:00	2016-01-06 23:30:00	Reception des voeux de Maisons-Alfort
1944	04042C	ELUS_LOCAUX	2016-01-05 19:30:00	2016-01-05 23:30:00	Réception des voeux de Saint-Maurice
1945	04042C	ELUS_LOCAUX	2016-01-07 10:30:00	2016-01-07 12:30:00	Rendez-vous avec des élus du Val-de-Marne
1946	04042C	ACC_VISIT	2016-01-07 13:30:00	2016-01-07 15:00:00	Visite du Sénate d'une école de Cachan
1947	04042C	ELUS_LOCAUX	2016-01-07 16:00:00	2016-01-07 18:30:00	Rendez-vous avec des élus du Val-de-Marne
1948	04042C	ELUS_LOCAUX	2016-01-07 19:30:00	2016-01-07 23:30:00	Réception des voeux de Joinville-le-Pont
3641	04042C	COLL_TER	2016-11-18 17:30:00	2016-11-18 18:30:00	culture
1949	04042C	ORG_POL	2016-01-12 11:00:00	2016-01-12 12:30:00	Réunion du Groupe Les Républicains du Sénat
1950	04042C	ORG_POL	2016-01-12 17:00:00	2016-01-12 18:00:00	Réunion au siège des Républicains
1951	04042C	ELUS_LOCAUX	2016-01-12 18:00:00	2016-01-12 22:00:00	Réception des voeux du Préfet du Val-de-Marne
1952	04042C	CEREMONIE	2016-01-13 12:30:00	2016-01-13 15:00:00	Réception des voeux des anciens combattants du Val-de-Marne
1953	04042C	REU_GVT	2016-01-13 17:00:00	2016-01-13 20:00:00	Réception des voeux du Président de la République à l'Elysée
1954	04042C	ELUS_LOCAUX	2016-01-13 20:30:00	2016-01-13 23:00:00	Réception des voeux de l'Association Générale des Familles
1955	04042C	CEREMONIE	2016-01-14 10:00:00	2016-01-14 12:00:00	Obsèques de M. Louis Manchon
1956	04042C	ELUS_LOCAUX	2016-01-14 20:00:00	2016-01-14 23:00:00	Réception des voeux des élus minoritaires à Fontenay-aux-Roses
1957	04042C	ORG_POL	2016-01-19 11:00:00	2016-01-19 12:30:00	du Groupe Les Républicains du Sénat
1958	04042C	REU_TRAV_PARL	2016-01-19 13:00:00	2016-01-19 14:30:00	Déjeuner des parlementaires avec Valérie Pécresse, Président de la région Ile-de-France
1959	04042C	REU_TRAV_PARL	2016-01-19 15:00:00	2016-01-19 16:00:00	Bureau de la commission des Affaires étrangères, de la Défense et des Forces armées du Sénat
1960	04042C	ORG_POL	2016-01-19 17:30:00	2016-01-19 18:30:00	Bureau politique national Les Républicains
1961	04042C	ELUS_LOCAUX	2016-01-19 19:00:00	2016-01-19 20:00:00	Réception des voeux des élus Républicains du Conseil régional d'Ile-de-France
1962	04042C	CEREMONIE	2016-01-19 20:00:00	2016-01-19 22:00:00	Réception des voeux des Hôpitaux de Saint-Maurice
1963	04042C	ELUS_LOCAUX	2016-01-20 17:45:00	2016-01-20 19:00:00	séance d'installation du Conseil métropolitain du territoire
1964	04042C	CEREMONIE	2016-01-20 19:00:00	2016-01-20 21:00:00	Réception des voeux du Président du Sénat à la présidence du Sénat
1972	04042C	ORG_POL	2016-02-09 11:00:00	2016-02-09 12:30:00	Réunion de Groupe Les Républicains du Sénat
1973	04042C	REU_TRAV_PARL	2016-02-09 13:00:00	2016-02-09 14:30:00	Déjeuner du Bureau de la commission des Affaires étrangères de la Défense et des Forces armées
1974	04042C	ORG_POL	2016-02-10 19:30:00	2016-02-10 21:00:00	Election du Président Les Républicains de la Métropole du Grand Paris au siège des Républicains
1975	04042C	REU_TRAV_PARL	2016-02-11 13:00:00	2016-02-11 14:30:00	\N
1976	04042C	ACC_VISIT	2016-02-11 18:45:00	2016-02-11 23:30:00	Réunion avec les élus de Maisons-Alfort au Sénat
2041	14089Y	REU_TRAV_PARL	2016-11-09 08:00:00	2016-11-09 14:30:00	Bruxelles
2042	14089Y	ORG_POL	2016-10-04 20:00:00	2016-10-04 21:30:00	\N
2043	14089Y	COLL_TER	2016-10-10 18:00:00	2016-10-10 19:00:00	\N
2044	14089Y	ACC_DEPL_INTER	2016-10-12 13:00:00	2016-10-12 14:00:00	\N
2053	14089Y	ELUS_LOCAUX	2016-12-05 14:30:00	2016-12-05 16:30:00	\N
2054	14089Y	COLL_TER	2016-12-05 12:00:00	2016-12-05 14:00:00	\N
2161	11054L	REU_TRAV_PARL	2016-12-15 09:00:00	2016-12-15 10:00:00	Rendez-vous IRSN
2162	11054L	REU_TRAV_PARL	2016-12-15 14:00:00	2016-12-15 15:00:00	\N
2163	11054L	ACC_VISIT	2016-12-15 20:00:00	2016-12-15 22:00:00	\N
2204	14089Y	COLL_TER	2016-11-07 15:00:00	2016-11-07 16:00:00	\N
2221	14089Y	CEREMONIE	2016-11-10 18:30:00	2016-11-10 19:30:00	\N
2528	14179A	ORGEXTPAR	2017-03-09 09:30:00	2017-03-09 12:00:00	CNIL
2530	14179A	ORGEXTPAR	2017-03-23 09:30:00	2017-03-23 12:00:00	CNIL
2641	04042C	ORG_POL	2017-01-11 17:00:00	2017-01-11 17:30:00	Débat sur le non-cumul des mandats sur la chaîne parlementaire Public Sénat
2642	04042C	ELUS_LOCAUX	2017-01-11 18:45:00	2017-01-11 23:00:00	Visite du Sénat des élus du Val-de-Marne
3221	08010L	ORG_POL	2017-02-01 13:00:00	2017-02-01 14:30:00	\N
3222	08010L	REU_GVT	2017-02-01 18:00:00	2017-02-01 19:00:00	\N
3361	04042C	ACC_DEPL_INTER	2017-02-02 11:45:00	2017-02-02 13:00:00	M.Jeannot Ahoussou, Ministre Etat ivoirien chargé du dialogue politique et relations avec institutions à la Présidence du Sénat
3503	04042C	COLL_TER	2017-01-06 11:00:00	2017-01-06 12:00:00	transport
3504	04042C	COLL_TER	2017-01-06 12:00:00	2017-01-06 12:30:00	\N
3521	04042C	COLL_TER	2017-01-06 13:00:00	2017-01-06 14:30:00	Syndicat des Eaux d'Ile-de-France
3541	04042C	ACC_VISIT	2017-01-06 14:30:00	2017-01-06 15:00:00	Visite du Sénat des élèves de 3ème du collège de Joinville-le-Pont
3542	04042C	COLL_TER	2017-01-06 16:30:00	2017-01-06 17:30:00	urbanisme
3543	04042C	ELUS_LOCAUX	2017-01-06 18:30:00	2017-01-06 19:30:00	Cérémonie des voeux d'Ablon
3544	04042C	ELUS_LOCAUX	2017-01-06 19:30:00	2017-01-06 20:30:00	Cérémonie des voeux de Mandres-les-Roses
3568	04042C	COLL_TER	2016-12-05 11:00:00	2016-12-05 11:30:00	\N
3569	04042C	COLL_TER	2016-12-05 11:30:00	2016-12-05 12:00:00	\N
3570	04042C	COLL_TER	2016-12-05 12:00:00	2016-12-05 12:30:00	\N
3571	04042C	COLL_TER	2016-12-05 12:30:00	2016-12-05 13:00:00	\N
3572	04042C	COLL_TER	2016-12-05 15:30:00	2016-12-05 17:30:00	Syndicat des Eaux d'Ile-de-France
3573	04042C	COLL_TER	2016-12-05 18:30:00	2016-12-05 23:30:00	Conseil Municipal
3574	04042C	COLL_TER	2016-12-02 08:45:00	2016-12-02 11:00:00	Bureau du Syndicat des Eaux d'Ile-de-France
3575	04042C	ACC_VISIT	2016-12-02 11:00:00	2016-12-02 12:00:00	Visite du Sénat des séniors de Villejuif
3576	04042C	ELUS_LOCAUX	2016-12-02 12:00:00	2016-12-02 12:30:00	Rendez-vous avec un élu du Val-de-Marne
3577	04042C	COLL_TER	2016-12-02 16:00:00	2016-12-02 17:00:00	\N
3578	04042C	COLL_TER	2016-12-02 17:00:00	2016-12-02 18:30:00	réforme des rythmes scolaires
3579	04042C	ELUS_LOCAUX	2016-12-02 19:00:00	2016-12-02 22:00:00	Election du nouveau Maire du Perreux-sur-Marne
3580	04042C	COLL_TER	2016-11-28 11:30:00	2016-11-28 12:30:00	\N
3581	04042C	COLL_TER	2016-11-28 16:00:00	2016-11-28 17:00:00	\N
3582	04042C	ELUS_LOCAUX	2016-11-28 17:00:00	2016-11-28 17:30:00	\N
3583	04042C	ELUS_LOCAUX	2016-11-28 17:30:00	2016-11-28 18:00:00	Installation du Conseil Municipal des Jeunes de Saint-Maurice
3584	04042C	ELUS_LOCAUX	2016-11-28 19:00:00	2016-11-28 20:30:00	Conseil de Territoire
3585	04042C	COLL_TER	2016-11-25 09:00:00	2016-11-25 11:00:00	Conseil de MGP
3586	04042C	COLL_TER	2016-11-25 11:30:00	2016-11-25 12:00:00	logement
3587	04042C	ELUS_LOCAUX	2016-11-25 13:00:00	2016-11-25 14:30:00	Prefet du Val-de-Marne
3588	04042C	COLL_TER	2016-11-25 15:00:00	2016-11-25 16:00:00	PLU
3589	04042C	COLL_TER	2016-11-25 16:30:00	2016-11-25 17:00:00	Ruches de Saint-Maurice
3590	04042C	ORG_POL	2016-11-25 19:00:00	2016-11-25 21:00:00	\N
3591	04042C	COLL_TER	2016-11-21 10:30:00	2016-11-21 11:00:00	PLU
3592	04042C	COLL_TER	2016-11-21 11:00:00	2016-11-21 12:00:00	logement social
3593	04042C	COLL_TER	2016-11-21 13:00:00	2016-11-21 14:30:00	\N
3594	04042C	COLL_TER	2016-11-21 16:00:00	2016-11-21 16:30:00	\N
3595	04042C	COLL_TER	2016-11-21 16:30:00	2016-11-21 17:00:00	\N
3596	04042C	ORG_POL	2016-11-21 20:30:00	2016-11-21 23:00:00	\N
3601	04042C	COLL_TER	2016-11-18 10:00:00	2016-11-18 10:30:00	Soin des arbres en milieu urbain
3602	04042C	COLL_TER	2016-11-18 10:30:00	2016-11-18 11:30:00	logement
3603	04042C	COLL_TER	2016-11-18 11:45:00	2016-11-18 12:30:00	commerce
3621	04042C	ELUS_LOCAUX	2016-11-18 12:30:00	2016-11-18 14:30:00	Déjeuner EPT 10
3642	04042C	ELUS_LOCAUX	2016-11-18 18:30:00	2016-11-18 19:30:00	culture
3643	04042C	COLL_TER	2016-11-14 16:00:00	2016-11-14 16:30:00	célébration du 102ème anniversaire d'une habitante de Saint-Maurice
3644	04042C	COLL_TER	2016-11-14 16:30:00	2016-11-14 17:00:00	Prix Saint-Maurice
3645	04042C	COLL_TER	2016-11-14 17:00:00	2016-11-14 17:30:00	\N
3646	04042C	COLL_TER	2016-11-14 17:30:00	2016-11-14 18:00:00	sécurité
3647	04042C	ORG_POL	2016-11-14 19:00:00	2016-11-14 22:00:00	\N
3648	04042C	CEREMONIE	2016-11-11 09:30:00	2016-11-11 14:00:00	Commémoration du 98ème anniversaire de l'Armistice du 11 novembre 1918 à Charenton et Saint-Maurice
3649	04042C	ELUS_LOCAUX	2016-11-04 08:45:00	2016-11-04 13:00:00	Bureau du Syndicat des Eaux d'Ile-de-France
3650	04042C	COLL_TER	2016-11-04 16:00:00	2016-11-04 17:00:00	\N
3651	04042C	CEREMONIE	2016-11-04 17:00:00	2016-11-04 20:00:00	Départ du commandant de police de Charenton-Saint Maurice
3652	04042C	COLL_TER	2016-10-28 09:00:00	2016-10-28 10:30:00	Urbanisme
3653	04042C	ELUS_LOCAUX	2016-10-28 10:30:00	2016-10-28 12:00:00	Préfet du Val-de-Marne
3692	04042C	COLL_TER	2016-10-10 10:00:00	2016-10-10 12:00:00	Réunion de direction
3693	04042C	ELUS_LOCAUX	2016-10-10 12:00:00	2016-10-10 14:30:00	\N
3694	04042C	COLL_TER	2016-10-10 15:00:00	2016-10-10 15:30:00	logement social
3701	04042C	COLL_TER	2016-10-10 15:30:00	2016-10-10 16:00:00	sécurité
3702	04042C	COLL_TER	2016-10-10 16:00:00	2016-10-10 16:30:00	commerçant
3703	04042C	COLL_TER	2016-10-10 16:30:00	2016-10-10 17:00:00	association
3704	04042C	COLL_TER	2016-10-10 17:00:00	2016-10-10 17:30:00	scolaire
3705	04042C	COLL_TER	2016-10-10 19:30:00	2016-10-10 21:00:00	commission urbanisme
3706	04042C	DEL_ACT_PAR	2016-12-12 08:00:00	2016-12-12 20:00:00	Séminaire franco-britannique à Londres 
2561	04042C	ELUS_LOCAUX	2017-01-03 19:00:00	2017-01-03 23:00:00	Cérémonie des voeux de Saint-Maurice
2562	04042C	ACC_DEPL_INTER	2017-01-04 13:00:00	2017-01-04 14:30:00	Ambassadeur de Turquie
2563	04042C	ELUS_LOCAUX	2017-01-04 19:00:00	2017-01-04 23:00:00	Cérémonie des voeux de Maisons-Alfort
2564	04042C	ELUS_LOCAUX	2017-01-05 19:00:00	2017-01-05 23:00:00	Cérémonie des voeux de Joinville-le-Pont
2565	04042C	ORG_POL	2017-01-10 10:00:00	2017-01-10 11:00:00	Groupe Les Républicains du Sénat
2566	04042C	ORG_POL	2017-01-10 11:30:00	2017-01-10 14:00:00	Voeux de François FILLON
2567	04042C	CEREMONIE	2017-01-10 17:00:00	2017-01-10 20:00:00	Voeux du Président de la République à l'Elysée
2901	14089Y	REU_TRAV_PARL	2017-01-23 09:00:00	2017-01-23 10:00:00	\N
2902	14089Y	CEREMONIE	2017-01-23 14:00:00	2017-01-23 16:30:00	\N
2903	14089Y	CEREMONIE	2017-01-23 16:00:00	2017-01-23 17:30:00	\N
2904	14089Y	CEREMONIE	2017-01-23 18:00:00	2017-01-23 19:00:00	\N
2905	14089Y	REU_TRAV_PARL	2017-01-24 16:00:00	2017-01-24 17:00:00	\N
2906	14089Y	COLL_TER	2017-01-24 18:00:00	2017-01-24 20:30:00	\N
2907	14089Y	REU_TRAV_PARL	2017-01-25 12:00:00	2017-01-25 13:00:00	\N
2908	14089Y	REU_TRAV_PARL	2017-01-25 14:30:00	2017-01-25 15:30:00	\N
2909	14089Y	ACC_VISIT	2017-01-26 11:30:00	2017-01-26 12:30:00	\N
2910	14089Y	REU_TRAV_PARL	2017-01-26 13:30:00	2017-01-26 15:00:00	\N
2911	14089Y	ORG_POL	2017-01-26 20:00:00	2017-01-26 21:00:00	\N
2912	14089Y	CEREMONIE	2017-01-27 18:00:00	2017-01-27 19:00:00	\N
2921	08010L	ORG_POL	2017-01-24 11:00:00	2017-01-24 12:30:00	\N
3707	04042C	ELUS_LOCAUX	2016-10-07 10:30:00	2016-10-07 11:30:00	Observatoire métropolitain "voies sur berges"
3708	04042C	COLL_TER	2016-10-07 11:30:00	2016-10-07 14:00:00	\N
3709	04042C	COLL_TER	2016-10-07 15:30:00	2016-10-07 16:00:00	Situation administrative
3710	04042C	COLL_TER	2016-10-07 16:00:00	2016-10-07 16:30:00	Stationnement
3711	04042C	COLL_TER	2016-10-07 16:30:00	2016-10-07 17:30:00	Direction
3712	04042C	ACC_DEPL_INTER	2016-10-07 19:00:00	2016-10-07 23:00:00	Ministère de la Défense avec des Sénateurs américains
3713	04042C	COLL_TER	2016-10-03 09:30:00	2016-10-03 12:00:00	sécurité 
3714	04042C	ACC_VISIT	2016-10-03 14:00:00	2016-10-03 15:30:00	Visite du Sénat des séniors de l'Haÿ-les-Roses
3715	04042C	COLL_TER	2016-10-03 16:00:00	2016-10-03 17:00:00	finances
3716	04042C	COLL_TER	2016-10-03 18:30:00	2016-10-03 23:00:00	Conseil Municipal
3721	04042C	ELUS_LOCAUX	2016-09-26 09:30:00	2016-09-26 11:00:00	à la mairie de Paris contre la fermeture des voies sur berges
3722	04042C	ELUS_LOCAUX	2016-09-26 11:00:00	2016-09-26 12:15:00	Conférence de presse contre la fermeture des voies sur berges
3723	04042C	COLL_TER	2016-09-26 16:00:00	2016-09-26 17:00:00	Petite enfance
3724	04042C	ORG_POL	2016-09-26 17:30:00	2016-09-26 18:00:00	Inteview télévisée
3725	04042C	ACC_DEPL_INTER	2016-09-26 18:00:00	2016-09-26 21:00:00	à la Présidence du Sénat de l'Assemblée nationale populaire de Chine 
3726	04042C	ELUS_LOCAUX	2016-09-12 08:00:00	2016-09-12 11:00:00	Manifestation contre l'aire d'accueil des gens du voyage à Santeny
3727	04042C	ELUS_LOCAUX	2016-09-12 13:00:00	2016-09-12 14:30:00	\N
3728	04042C	COLL_TER	2016-09-09 10:00:00	2016-09-09 11:00:00	bâtiment
3729	04042C	ACC_VISIT	2016-09-09 14:00:00	2016-09-09 15:30:00	Visite du Sénat des villes jumelées de Saint-Mandé
3730	04042C	ACC_VISIT	2016-09-08 13:00:00	2016-09-08 14:30:00	Déjeuner de presse
3731	04042C	COLL_TER	2016-09-08 09:00:00	2016-09-08 11:00:00	Informatique
3732	04042C	ELUS_LOCAUX	2016-09-05 07:30:00	2016-09-05 10:00:00	Préfet du Val-de-Marne et la rectrice de l'académie
3733	04042C	COLL_TER	2016-09-05 11:00:00	2016-09-05 12:00:00	Direction
3734	04042C	COLL_TER	2016-09-05 15:00:00	2016-09-05 16:30:00	Voirie
3735	04042C	COLL_TER	2016-09-05 16:30:00	2016-09-05 17:00:00	Reseau internet
3736	04042C	DEL_ACT_PAR	2016-09-05 19:00:00	2016-09-05 21:00:00	14ème Université d'été de la Défense
3768	04042C	ORG_POL	2016-07-06 13:30:00	2016-07-06 14:30:00	\N
3769	04042C	ACC_VISIT	2016-07-04 09:00:00	2016-07-04 10:30:00	Visite du sénat par les Villes jumelées de Saint-Maurice
3770	04042C	ACC_DEPL_INTER	2016-07-04 14:30:00	2016-07-04 15:30:00	A la présidence du Sénat du nouveau Président du Sénat du Canada
3771	04042C	REU_TRAV_PARL	2016-07-04 16:00:00	2016-07-04 17:00:00	\N
3772	04042C	ELUS_LOCAUX	2016-07-04 18:00:00	2016-07-04 21:30:00	\N
3773	04042C	REU_TRAV_PARL	2016-07-04 22:00:00	2016-07-04 22:30:00	Débat sur Public Sénat
3774	04042C	ELUS_LOCAUX	2016-07-01 08:45:00	2016-07-01 12:00:00	Bureau du Syndicat des Eaux d'Ile-de-France
3775	04042C	COLL_TER	2016-06-27 09:00:00	2016-06-27 11:00:00	\N
3776	04042C	COLL_TER	2016-06-27 11:00:00	2016-06-27 12:00:00	affaires sociales
3777	04042C	COLL_TER	2016-06-27 14:00:00	2016-06-27 15:00:00	CHSCT
3778	04042C	REU_TRAV_PARL	2016-06-27 15:30:00	2016-06-27 16:00:00	Débat sur Public Sénat
3779	04042C	ORG_POL	2016-06-27 17:00:00	2016-06-27 18:00:00	Bureau Les Républicains
3780	04042C	ELUS_LOCAUX	2016-06-27 19:30:00	2016-06-27 21:00:00	Fête de la 6ème circonscription
3781	04042C	ELUS_LOCAUX	2016-06-24 08:00:00	2016-06-24 12:00:00	Conseil Métropolitain
3782	04042C	ACC_VISIT	2016-06-20 09:30:00	2016-06-20 11:00:00	Visite du Sénat d'une école de Maisons-Alfort
3801	04042C	COLL_TER	2016-06-17 09:00:00	2016-06-17 09:30:00	\N
3803	04042C	COLL_TER	2016-06-17 10:00:00	2016-06-17 10:30:00	Urbanisme
3821	04042C	ELUS_LOCAUX	2016-06-17 10:30:00	2016-06-17 11:00:00	association
3822	04042C	COLL_TER	2016-06-17 11:00:00	2016-06-17 12:00:00	Hôpitaux de Saint-Maurice
3823	04042C	COLL_TER	2016-06-17 14:00:00	2016-06-17 16:00:00	Conseil de surveillance des Hôpitaux de Saint-Maurice
3824	04042C	COLL_TER	2016-06-17 16:30:00	2016-06-17 17:00:00	\N
3825	04042C	COLL_TER	2016-06-17 19:30:00	2016-06-17 20:30:00	culture
3826	04042C	COLL_TER	2016-06-13 12:00:00	2016-06-13 16:00:00	\N
3968	04042C	COLL_TER	2016-03-11 17:00:00	2016-03-11 17:30:00	\N
3969	04042C	COLL_TER	2016-03-11 17:30:00	2016-03-11 18:00:00	\N
3970	04042C	ELUS_LOCAUX	2016-03-11 18:00:00	2016-03-11 18:30:00	\N
3971	04042C	COLL_TER	2016-03-11 19:30:00	2016-03-11 20:30:00	\N
3972	04042C	COLL_TER	2016-03-07 10:00:00	2016-03-07 11:00:00	\N
3973	04042C	COLL_TER	2016-03-07 11:00:00	2016-03-07 12:00:00	\N
3974	04042C	ELUS_LOCAUX	2016-03-07 12:30:00	2016-03-07 14:30:00	\N
3975	04042C	REU_TRAV_PARL	2016-03-07 17:00:00	2016-03-07 17:30:00	Débat sur Public Sénat
3976	04042C	ELUS_LOCAUX	2016-03-07 18:00:00	2016-03-07 19:30:00	Bureau du Conseil de Territoire
3977	04042C	DEL_ACT_PAR	2016-02-29 19:00:00	2016-02-29 23:00:00	\N
3978	04042C	COLL_TER	2016-02-22 12:00:00	2016-02-22 13:00:00	\N
3979	04042C	COLL_TER	2016-02-22 16:00:00	2016-02-22 16:30:00	\N
3980	04042C	COLL_TER	2016-02-22 16:30:00	2016-02-22 17:00:00	\N
3981	04042C	COLL_TER	2016-02-22 17:00:00	2016-02-22 17:30:00	\N
3982	04042C	COLL_TER	2016-02-22 17:30:00	2016-02-22 18:00:00	\N
3983	04042C	COLL_TER	2016-02-23 09:00:00	2016-02-23 11:00:00	\N
3984	04042C	COLL_TER	2016-02-23 16:30:00	2016-02-23 17:30:00	\N
3985	04042C	COLL_TER	2016-02-23 17:30:00	2016-02-23 18:30:00	avec le sous-préfet de Nogent
3986	04042C	REU_TRAV_PARL	2016-02-19 09:00:00	2016-02-19 17:00:00	Forum parlemantaire international sur la justice sociale au Maroc
3987	04042C	ELUS_LOCAUX	2016-02-15 08:30:00	2016-02-15 10:00:00	du Bureau LR du Val-de-Marne
3988	04042C	COLL_TER	2016-02-15 10:30:00	2016-02-15 11:00:00	\N
3989	04042C	COLL_TER	2016-02-15 12:30:00	2016-02-15 14:00:00	\N
3990	04042C	ELUS_LOCAUX	2016-02-15 14:00:00	2016-02-15 15:00:00	Conférence des Maires T10
3991	04042C	COLL_TER	2016-02-15 16:00:00	2016-02-15 17:00:00	\N
3992	04042C	COLL_TER	2016-02-15 17:00:00	2016-02-15 18:00:00	\N
3993	04042C	COLL_TER	2016-02-15 18:30:00	2016-02-15 23:00:00	Conseil Municipal
4001	14089Y	CEREMONIE	2017-01-30 09:00:00	2017-01-30 10:00:00	\N
4002	14089Y	CEREMONIE	2017-01-30 10:00:00	2017-01-30 11:00:00	\N
4003	14089Y	CEREMONIE	2017-01-30 11:00:00	2017-01-30 12:00:00	\N
4007	14089Y	COLL_TER	2017-02-03 09:00:00	2017-02-03 10:30:00	\N
4005	14089Y	COLL_TER	2017-01-30 20:00:00	2017-01-30 22:30:00	\N
4006	14089Y	REU_TRAV_PARL	2017-02-01 11:45:00	2017-02-01 12:45:00	\N
4008	14089Y	CEREMONIE	2017-02-03 15:00:00	2017-02-03 16:00:00	\N
4009	14089Y	CEREMONIE	2017-02-03 18:00:00	2017-02-03 19:00:00	\N
4010	14089Y	CEREMONIE	2017-02-03 19:00:00	2017-02-03 20:00:00	\N
4011	14089Y	REU_TRAV_PARL	2017-02-06 16:45:00	2017-02-06 17:45:00	\N
4012	14089Y	REU_TRAV_PARL	2017-02-07 10:00:00	2017-02-07 11:15:00	\N
4013	14089Y	REU_TRAV_PARL	2017-02-07 11:00:00	2017-02-07 12:00:00	\N
4014	14089Y	REU_TRAV_PARL	2017-02-07 17:00:00	2017-02-07 18:00:00	\N
4015	08010L	ORG_POL	2017-02-08 14:30:00	2017-02-08 15:00:00	Groupe LR
4020	14089Y	REU_TRAV_PARL	2017-02-20 11:15:00	2017-02-20 12:00:00	\N
4017	04042C	ACC_VISIT	2016-02-01 09:30:00	2016-02-01 11:00:00	Visite du Sénat d'un collège d'Ormesson
4018	14089Y	COLL_TER	2017-02-09 18:30:00	2017-02-09 21:00:00	\N
4019	14089Y	CEREMONIE	2017-02-10 14:00:00	2017-02-10 15:00:00	\N
4021	04042C	COLL_TER	2016-02-12 10:00:00	2016-02-12 11:00:00	avec la nouvelle directrice académique
4022	14089Y	REU_TRAV_PARL	2017-02-22 13:30:00	2017-02-22 14:30:00	\N
4023	04042C	ELUS_LOCAUX	2016-02-12 11:00:00	2016-02-12 11:30:00	\N
4024	04042C	COLL_TER	2016-02-12 11:30:00	2016-02-12 12:00:00	sur Hôpitaux de Saint-Maurice
4025	04042C	ELUS_LOCAUX	2016-02-12 14:30:00	2016-02-12 16:30:00	Nouveau comité du Bois de Vincennes
4026	04042C	COLL_TER	2016-02-12 17:00:00	2016-02-12 18:00:00	Réorganisation du réseau de la direction des finances publiques du Val-de-Marne
4027	04042C	COLL_TER	2016-02-12 18:00:00	2016-02-12 18:30:00	sur le logement
4028	04042C	COLL_TER	2016-02-08 10:00:00	2016-02-08 11:30:00	Activités sportives
4041	04042C	COLL_TER	2016-02-08 11:00:00	2016-02-08 11:30:00	\N
4042	04042C	COLL_TER	2016-02-08 11:30:00	2016-02-08 12:30:00	Réunion de direction
4043	04042C	ELUS_LOCAUX	2016-02-08 15:30:00	2016-02-08 16:00:00	\N
4044	04042C	COLL_TER	2016-02-08 16:00:00	2016-02-08 17:00:00	avec directeur de cabinet du Préfet du Val-de-Marne
1465	14089Y	REU_TRAV_PARL	2016-10-07 10:30:00	2016-10-07 11:30:00	\N
1466	14089Y	ELUS_LOCAUX	2016-10-07 16:00:00	2016-10-07 17:15:00	\N
1467	14089Y	ELUS_LOCAUX	2016-10-07 18:30:00	2016-10-07 19:30:00	\N
1468	14089Y	ELUS_LOCAUX	2016-10-10 16:00:00	2016-10-10 17:15:00	\N
1469	14089Y	REU_TRAV_PARL	2016-10-18 15:45:00	2016-10-18 16:45:00	\N
1470	14089Y	REU_TRAV_PARL	2016-10-26 18:30:00	2016-10-26 19:30:00	\N
1471	14089Y	CEREMONIE	2016-10-28 19:00:00	2016-10-28 20:00:00	\N
1481	01015L	ORG_POL	2016-12-08 15:00:00	2016-12-08 21:00:00	COP 22
1501	01015L	ACC_VISIT	2016-12-06 17:00:00	2016-12-06 18:00:00	Auditeur Institut du Sénat
1503	14089Y	REU_TRAV_PARL	2016-12-07 11:15:00	2016-12-07 12:15:00	\N
1561	08047A	REU_TRAV_PARL	2016-11-29 14:30:00	2016-11-29 18:00:00	SEANCE
1683	14089Y	REU_TRAV_PARL	2016-10-12 17:00:00	2016-10-12 18:00:00	\N
1701	14089Y	REU_TRAV_PARL	2016-10-27 11:00:00	2016-10-27 12:00:00	\N
1901	11054L	REU_TRAV_PARL	2016-12-12 09:00:00	2016-12-12 17:00:00	Séminaire sur le thème « France et Royaume-Uni : faire plus ensemble pour faire avancer la paix au Moyen-Orient » - Londres
1902	11054L	REU_TRAV_PARL	2016-12-13 10:00:00	2016-12-13 13:00:00	Bureau et groupe PS
1921	11054L	ACC_VISIT	2016-12-13 15:00:00	2016-12-13 16:30:00	Classe du lycée Boulloche de Livry-Gargan
1922	11054L	ORG_POL	2016-12-13 20:30:00	2016-12-13 22:00:00	\N
1923	11054L	REU_TRAV_PARL	2016-12-08 14:30:00	2016-12-08 15:30:00	Rendez-vous sur la traçabilité du tabac
1924	11054L	COLL_TER	2016-12-09 11:00:00	2016-12-09 12:30:00	Signature contrat Est Ensemble
1925	11054L	COLL_TER	2016-12-09 14:30:00	2016-12-09 15:30:00	Réunion avec la Maire de Bondy
1941	04042C	REU_TRAV_PARL	2016-02-16 13:00:00	2016-02-16 15:00:00	Réunion Expertise France
1965	04042C	ORG_POL	2016-01-26 11:00:00	2016-01-26 12:30:00	Réunion du Groupe Les Républicains du Sénat
1966	04042C	REU_TRAV_PARL	2016-01-26 16:00:00	2016-01-26 17:00:00	Réunion du Groupe de travail Australie
1967	04042C	ELUS_LOCAUX	2016-01-27 20:30:00	2016-01-27 21:30:00	Réception des voeux de la Présidente du Conseil régional d'Ile-de-France
1968	04042C	REU_TRAV_PARL	2016-01-28 11:30:00	2016-01-28 12:15:00	Réunion du Groupe de travail Australie
1969	04042C	ELUS_LOCAUX	2016-01-28 12:30:00	2016-01-28 14:30:00	Déjeuner avec des élus du Val-de-Marne
1970	04042C	ELUS_LOCAUX	2016-01-28 16:30:00	2016-01-28 19:00:00	Rendez-vous avec des élus du Val-de-Marne
1971	04042C	ELUS_LOCAUX	2016-01-28 19:00:00	2016-01-28 21:00:00	Galette des Républicains de Maisons-Alfort
1977	04042C	REU_TRAV_PARL	2016-02-10 22:30:00	2016-02-10 23:00:00	Débat sur la chaîne parlementaire Public Sénat
1981	04042C	ELUS_LOCAUX	2015-12-03 12:30:00	2015-12-03 14:30:00	Déjeuner avec le Préfet et un élus du Val-de-Marne
1982	04042C	ORG_POL	2015-12-03 19:30:00	2015-12-03 21:00:00	Meeting élections Régionales de Valérie Précresse
1983	04042C	ORG_POL	2015-12-08 11:00:00	2015-12-08 12:30:00	Réunion du Groupe Les Républicains du Sénat
1984	04042C	ELUS_LOCAUX	2015-12-08 13:00:00	2015-12-08 14:30:00	Déjeuner des parlementaires avec Valérie Précresse
1985	04042C	REU_TRAV_PARL	2015-12-09 18:00:00	2015-12-09 19:30:00	Conférence des Présidents du Sénat
1986	04042C	ELUS_LOCAUX	2015-12-09 19:30:00	2015-12-09 21:00:00	Réunion Les Républicains du Val-de-Marne
1987	04042C	ACC_DEPL_INTER	2015-12-10 20:00:00	2015-12-10 21:00:00	50ème indépendance de Singapour
1988	04042C	ORG_POL	2015-12-15 11:00:00	2015-12-15 12:00:00	Réunion du Groupe Les Républicains du Sénat
1989	04042C	ELUS_LOCAUX	2015-12-15 12:15:00	2015-12-15 14:30:00	Déjeuner de Noël des anciens de Saint-Maurice
2001	04042C	ELUS_LOCAUX	2015-12-15 17:30:00	2015-12-15 18:30:00	Fête de Noël de la crèche familiale de Saint-Maurice
2002	04042C	ORG_POL	2015-12-15 19:30:00	2015-12-15 21:00:00	Réception de fin d'année du Président Les Républicains du Sénat
2021	04042C	REU_TRAV_PARL	2015-12-16 13:00:00	2015-12-16 14:30:00	Déjeuner avec un parlementaire
2022	04042C	ORG_POL	2015-12-17 08:30:00	2015-12-17 09:30:00	Réunion Les Primaires de la Droite et du Centre
2023	04042C	COLL_TER	2015-12-17 10:00:00	2015-12-17 13:00:00	Comité du Syndicat des Eaux d'Ile-de-France
2024	04042C	ELUS_LOCAUX	2015-12-17 16:30:00	2015-12-17 17:00:00	Fête de Noël de la crèche Delacroix de Saint-Maurice
2025	04042C	ELUS_LOCAUX	2015-12-17 17:00:00	2015-12-17 18:00:00	Rendez-vous en mairie
2026	04042C	ELUS_LOCAUX	2015-12-17 19:00:00	2015-12-17 20:15:00	Réception de voeux
2027	04042C	ELUS_LOCAUX	2015-12-17 20:00:00	2015-12-17 23:30:00	Conseil Municipal de Saint-Maurice
2028	04042C	ORG_POL	2015-11-24 11:00:00	2015-11-24 12:30:00	Réunion de Groupe Les Républicains du Sénat
2029	04042C	REU_TRAV_PARL	2015-11-24 19:45:00	2015-11-24 23:00:00	réunion avec le Président d'Air France
2030	04042C	ACC_DEPL_INTER	2015-11-25 13:00:00	2015-11-25 14:30:00	Déjeuner avec l'Ambassadeur de Turquie
2031	04042C	ELUS_LOCAUX	2015-11-25 18:45:00	2015-11-25 23:30:00	Rencontre au Sénat avec les élus de Périgny, Santeny et Mandres-les-Roses
2032	04042C	REU_GVT	2015-11-26 11:30:00	2015-11-26 14:30:00	Déjeuner avec le Président de la République à l'Elysée à l'occasion du Sommet Franco-Océanie
2033	04042C	REU_TRAV_PARL	2015-11-26 16:15:00	2015-11-26 18:00:00	\N
2034	04042C	REU_TRAV_PARL	2015-11-26 19:30:00	2015-11-26 21:30:00	Dîner en présence de la Ministre de l'environnement du Maroc
2121	08010L	ORG_POL	2016-12-13 11:00:00	2016-12-13 12:30:00	\N
2122	08010L	REU_TRAV_PARL	2016-12-13 17:30:00	2016-12-13 18:30:00	\N
2141	04043D	ORG_POL	2016-12-13 11:00:00	2016-12-13 13:00:00	Réunion groupe LR
2241	08009T	REU_TRAV_PARL	2016-12-06 11:00:00	2016-12-06 12:00:00	Réunion de groupe - UDI
2281	14089Y	DEPL_PRES_GVT	2016-12-16 08:00:00	2016-12-16 21:00:00	Bruxelles
2282	14089Y	COLL_TER	2016-12-19 09:00:00	2016-12-19 12:00:00	\N
2283	14089Y	ORG_POL	2016-12-20 11:00:00	2016-12-20 12:00:00	\N
2284	14089Y	REU_TRAV_PARL	2016-12-20 18:45:00	2016-12-20 20:00:00	\N
2285	14089Y	ORG_POL	2016-12-20 20:00:00	2016-12-20 21:00:00	\N
2361	04042C	ACC_VISIT	2016-12-14 14:30:00	2016-12-14 15:30:00	Visite du Sénat du Conseil Municipal des Jeunes de Joinville-le-Pont
2362	04042C	ELUS_LOCAUX	2016-12-14 20:00:00	2016-12-14 20:45:00	Comité départemental du Val-de-Marne
2381	04042C	ELUS_LOCAUX	2016-12-14 20:45:00	2016-12-14 23:00:00	Réception pour les bénévoles des Primaires u Val-de-Marne
2382	04042C	REU_TRAV_PARL	2016-12-15 13:00:00	2016-12-15 14:30:00	Déjeuner du Bureau du Sénat
2383	04042C	REU_GVT	2016-12-15 16:30:00	2016-12-15 17:30:00	rendez-vous au Ministère de l'intérieur avec deux élus du Val-de-Marne sur les effectifs de police de Charenton-Saint Maurice
2384	04042C	CEREMONIE	2016-12-15 19:00:00	2016-12-15 20:30:00	Cérémonie des voeux de l'Evêque de Créteil
2401	04042C	ACC_DEPL_INTER	2016-12-14 12:30:00	2016-12-14 13:30:00	Ambassade du Qatar
2702	04040A	ORG_POL	2017-01-17 19:00:00	2017-01-17 20:00:00	Bureau exécutif UDI
2544	04040A	ORG_POL	2017-01-11 12:00:00	2017-01-11 13:00:00	Voeux de l'UDI
2545	04040A	ORG_POL	2017-01-11 10:00:00	2017-01-11 11:00:00	Comité exécutif de l'UDI
2701	04040A	ORG_POL	2017-01-17 11:00:00	2017-01-17 12:00:00	Réunion du Groupe UDI-UC
3441	08010L	REU_TRAV_PARL	2017-02-07 18:00:00	2017-02-07 19:00:00	controle budgétaire
3465	04042C	COLL_TER	2017-02-03 10:30:00	2017-02-03 11:00:00	urbanisme
3466	04042C	COLL_TER	2017-02-03 11:00:00	2017-02-03 12:30:00	Conseil de surveillance des Hôpitaux de Sain-Maurice
3467	04042C	ELUS_LOCAUX	2017-02-03 12:30:00	2017-02-03 14:30:00	\N
3468	04042C	ELUS_LOCAUX	2017-02-03 15:00:00	2017-02-03 16:00:00	\N
3472	04042C	COLL_TER	2017-01-27 12:30:00	2017-01-27 14:30:00	\N
3470	04042C	COLL_TER	2017-01-27 10:00:00	2017-01-27 11:00:00	Réunion amicale des locataires Saint-Maurice
3471	04042C	ELUS_LOCAUX	2017-01-27 11:00:00	2017-01-27 12:00:00	\N
3473	04042C	COLL_TER	2017-01-27 16:30:00	2017-01-27 19:00:00	\N
3474	04042C	ELUS_LOCAUX	2017-01-27 19:30:00	2017-01-27 21:00:00	Voeux des élus minoritaires de Choisy-le-Roi
3481	04042C	COLL_TER	2017-01-23 11:00:00	2017-01-23 12:00:00	\N
3482	04042C	COLL_TER	2017-01-23 12:30:00	2017-01-23 14:30:00	Voeux des Hôpitaux de Saint-Maurice
3483	04042C	ELUS_LOCAUX	2017-01-23 15:30:00	2017-01-23 16:30:00	\N
3484	04042C	COLL_TER	2017-01-23 16:30:00	2017-01-23 17:00:00	\N
3485	04042C	COLL_TER	2017-01-23 18:30:00	2017-01-23 20:00:00	\N
3545	04042C	ELUS_LOCAUX	2017-01-02 18:30:00	2017-01-02 21:00:00	Cérémonie des voeux de Charenton-le-Pont
3546	11054L	ACC_VISIT	2017-01-30 12:00:00	2017-01-30 14:00:00	\N
3547	04042C	COLL_TER	2016-12-16 09:00:00	2016-12-16 12:00:00	Conseil de surveillance des Hôpitaux de Saint-Maurice
3548	11054L	ACC_DEPL_INTER	2017-02-08 10:30:00	2017-02-08 11:30:00	Entretien avec S.E. Mahmoud ABBAS Président de l'Autorité palestinienne
3549	04042C	ELUS_LOCAUX	2016-12-16 13:00:00	2016-12-16 14:30:00	\N
3550	04042C	COLL_TER	2016-12-16 15:00:00	2016-12-16 16:00:00	logement social
3551	04042C	COLL_TER	2016-12-16 16:00:00	2016-12-16 17:00:00	Pose de la 1ère pierre de logements sociaux
3552	04042C	COLL_TER	2016-12-16 17:30:00	2016-12-16 18:00:00	\N
3553	04042C	COLL_TER	2016-12-16 18:00:00	2016-12-16 18:30:00	\N
3561	04042C	COLL_TER	2016-12-09 09:30:00	2016-12-09 12:00:00	Commission solidarité-eau du Syndicat des Eaux d'Ile-de-France
3562	04042C	COLL_TER	2016-12-09 15:30:00	2016-12-09 16:00:00	\N
4441	04040A	REU_TRAV_PARL	2017-02-14 11:00:00	2017-02-14 12:00:00	Réunion du Groupe UDI-UC
4961	14065Q	REU_GVT	2017-01-24 14:30:00	2017-01-24 16:00:00	sur la PPL Efficacité de la justice pénale
4461	08010L	ORG_POL	2017-02-14 11:00:00	2017-02-14 12:30:00	Groupe LR
4962	14065Q	ORG_POL	2017-01-25 09:00:00	2017-01-25 09:30:00	\N
4963	14065Q	REU_TRAV_PARL	2017-01-25 14:00:00	2017-01-25 14:30:00	Interview
7811	14065Q	COLL_TER	2017-12-15 10:00:00	2017-12-15 12:30:00	\N
4964	14065Q	CEREMONIE	2017-01-25 18:00:00	2017-01-25 19:30:00	Voeux du Premier ministre
4965	14065Q	REU_TRAV_PARL	2017-01-30 11:00:00	2017-01-30 11:30:00	\N
4966	14065Q	COLL_TER	2017-01-30 19:00:00	2017-01-30 22:00:00	SCOTERS
4967	14065Q	ORG_POL	2017-01-31 11:00:00	2017-01-31 13:00:00	\N
4968	14065Q	REU_TRAV_PARL	2017-02-03 08:30:00	2017-02-03 10:00:00	\N
4969	14065Q	ELUS_LOCAUX	2017-02-03 12:30:00	2017-02-03 14:00:00	Institut du Sénat
4970	14065Q	ORGEXTPAR	2017-02-06 09:30:00	2017-02-06 14:30:00	Commission du droit local d'Alsace Moselle
4971	14065Q	REU_TRAV_PARL	2017-02-09 14:30:00	2017-02-09 15:00:00	\N
4972	14065Q	ORG_POL	2017-02-21 11:00:00	2017-02-21 13:00:00	\N
5301	08010L	ORG_POL	2017-03-07 11:00:00	2017-03-07 12:30:00	Groupe LR sénat
5321	08010L	ACC_DEPL_INTER	2017-03-16 16:00:00	2017-03-16 17:00:00	GIA France Botswana
5322	08010L	ACC_VISIT	2017-03-07 15:00:00	2017-03-07 16:00:00	\N
5341	08010L	ACC_DEPL_INTER	2017-03-07 09:30:00	2017-03-07 10:30:00	ambassadeur de France en Angola
5401	14225N	ACC_VISIT	2017-01-17 13:00:00	2017-01-17 14:30:00	Rdv Mme Joyce Bessis - thèse de doctorat Sciences Po Paris « Acteurs politiques et réseaux sociaux: les dilemmes politiques du temps-réel »
5403	14225N	CEREMONIE	2017-01-18 19:00:00	2017-01-18 20:00:00	Voeux Mairie de Colomiers
5404	14225N	ACC_VISIT	2017-01-19 09:00:00	2017-01-19 12:00:00	Permanence à Toulouse
5405	14225N	CEREMONIE	2017-01-19 12:00:00	2017-01-19 14:00:00	Voeux Personnel Toulouse Metropole
5406	14225N	COLLOQUE	2017-01-24 09:00:00	2017-01-24 18:00:00	Cycle des hautes études européennes - Strasbourg
5407	14225N	COLLOQUE	2017-01-25 09:00:00	2017-01-25 17:00:00	Cycle des hautes études européennes - Strasbourg
5408	14225N	COLL_TER	2017-01-26 20:00:00	2017-01-26 22:00:00	Réunion Groupe Mairie de Tournefeuille 
5483	14225N	COLL_TER	2017-02-02 12:00:00	2017-02-02 12:00:00	Conférence métropolitaine
5481	14225N	COLLOQUE	2017-02-01 14:00:00	2017-02-01 14:00:00	Dejeuner Spedidam - Les artistes interprètes, la musique et le numérique - François Nowak
5482	14225N	COLL_TER	2017-02-02 10:00:00	2017-02-02 10:00:00	Bureau Toulouse Métropole
5484	14225N	ELUS_LOCAUX	2017-02-02 17:00:00	2017-02-02 17:00:00	\N
5485	14225N	CEREMONIE	2017-02-02 18:00:00	2017-02-02 18:00:00	15ème Anniversaire + forum 2017 OTIE
5486	14225N	COLL_TER	2017-02-02 21:00:00	2017-02-02 21:00:00	Mairie Tournefeuille
5487	14225N	ORG_POL	2017-02-14 12:00:00	2017-02-14 12:00:00	Commission Finances et Fiscalités
5488	14225N	COLLOQUE	2017-02-14 22:00:00	2017-02-14 22:00:00	Diner section trufficulture, oléiculture et cultures traditionnelles du Sénat
5489	14225N	ORG_POL	2017-02-16 22:00:00	2017-02-16 22:00:00	Comité départemental de campagne
5490	14225N	COLLOQUE	2017-02-21 14:00:00	2017-02-21 14:00:00	Cercle Emploi et Société - Quelles perspectives pour l'emploi en 2017 - Patrick Artus
5491	14225N	COLLOQUE	2017-02-22 18:00:00	2017-02-22 18:00:00	Cycle des Hautes Etudes Européennes - ENA
5492	14225N	COLLOQUE	2017-02-23 18:00:00	2017-02-23 18:00:00	Cycle des Hautes Etudes Européennes - ENA
5493	14225N	DEPL_PRES_GVT	2017-02-28 18:00:00	2017-02-28 18:00:00	Déplacement ONCT
5494	14225N	DEPL_PRES_GVT	2017-03-01 18:00:00	2017-03-01 18:00:00	Déplacement ONCT
5495	14225N	DEPL_PRES_GVT	2017-03-02 18:00:00	2017-03-02 18:00:00	Déplacement ONCT
5496	14225N	COLL_TER	2017-03-02 21:00:00	2017-03-02 21:00:00	Conseil Municipal Tournefeuille
5497	14225N	COLLOQUE	2017-03-14 18:00:00	2017-03-14 18:00:00	Cycle des Hautes Etudes Européennes - ENA
5498	14225N	COLLOQUE	2017-03-15 18:00:00	2017-03-15 18:00:00	Cycle des Hautes Etudes Européennes - ENA
5499	14225N	COLLOQUE	2017-03-16 18:00:00	2017-03-16 18:00:00	Cycle des Hautes Etudes Européennes - ENA
5500	14225N	ACC_VISIT	2017-03-21 15:00:00	2017-03-21 16:00:00	Etudiant thése emprunts toxiques
5501	14225N	ORG_POL	2017-03-21 12:00:00	2017-03-21 12:00:00	Réunion Groupe Socialiste
5502	14225N	REU_TRAV_PARL	2017-03-22 10:00:00	2017-03-22 10:00:00	Réunion Préparatoire CNERP
5503	14225N	CEREMONIE	2017-03-22 14:00:00	2017-03-22 14:00:00	Conf de presse Baylet-Eckert emprunts toxiques
5504	14225N	ORG_POL	2017-03-23 18:00:00	2017-03-23 18:00:00	1er journée France Urbaine 
5541	08010L	ORG_POL	2017-04-04 11:00:00	2017-04-04 12:30:00	Groupe LR sénat
5901	14089Y	REU_TRAV_PARL	2017-04-26 17:00:00	2017-04-26 17:00:00	\N
6101	08010L	REU_TRAV_PARL	2017-05-31 13:00:00	2017-05-31 14:30:00	com des finances 
5902	14089Y	CEREMONIE	2017-04-26 12:00:00	2017-04-26 12:00:00	\N
5903	14089Y	COLL_TER	2017-04-24 09:00:00	2017-04-24 12:00:00	\N
6426	11029K	REU_TRAV_PARL	2017-06-19 11:30:00	2017-06-19 11:30:00	RDV avec la préfète
6121	08010L	ORG_POL	2017-06-13 10:00:00	2017-06-13 12:30:00	Groupe LR sénat
6141	08010L	ORG_POL	2017-06-20 10:00:00	2017-06-20 12:00:00	Groupe LR sénat
6181	08010L	COLL_TER	2017-06-22 10:00:00	2017-06-22 12:30:00	Comité Directeur AMF
6201	08010L	ORG_POL	2017-06-27 10:00:00	2017-06-27 12:30:00	Groupe LR sénat
6427	11029K	ELUS_LOCAUX	2017-06-19 15:30:00	2017-06-19 15:30:00	Joel Bigot maire Ponts de Cé
6428	11029K	REU_TRAV_PARL	2017-06-19 18:00:00	2017-06-19 18:00:00	\N
6430	11029K	REU_TRAV_PARL	2017-06-12 15:00:00	2017-06-12 15:00:00	\N
6431	11029K	REU_TRAV_PARL	2017-06-12 16:00:00	2017-06-12 16:00:00	\N
6433	11029K	REU_TRAV_PARL	2017-06-09 11:30:00	2017-06-09 11:30:00	\N
6440	11029K	REU_TRAV_PARL	2017-05-22 12:00:00	2017-05-22 12:00:00	RDV Monsieur Cherbonnier- petit pavé - écologie politique
6441	11029K	REU_TRAV_PARL	2017-05-22 15:00:00	2017-05-22 15:00:00	\N
6442	11029K	REU_TRAV_PARL	2017-05-22 15:30:00	2017-05-22 15:30:00	Réunion sur CADA
6443	11029K	REU_TRAV_PARL	2017-05-22 20:00:00	2017-05-22 20:00:00	Colloque "La Race et l'histoire" fac d'Angers
6496	11029K	REU_TRAV_PARL	2017-03-31 11:30:00	2017-03-31 11:30:00	RDV téléphonique INTW Intersexes
6497	11029K	REU_TRAV_PARL	2017-03-31 17:30:00	2017-03-31 17:30:00	Goûter avec collégiens et parents 5ème du collège Montaigne
6495	11029K	REU_TRAV_PARL	2017-03-31 10:45:00	2017-03-31 10:45:00	 Asso arbre vert
6527	11029K	REU_TRAV_PARL	2017-03-24 11:00:00	2017-03-24 11:00:00	Bibliothèque nationale de France
6528	11029K	REU_TRAV_PARL	2017-03-24 12:30:00	2017-03-24 12:30:00	\N
6529	11029K	REU_TRAV_PARL	2017-03-24 15:30:00	2017-03-24 15:30:00	 RDV INTW
6541	11029K	REU_TRAV_PARL	2017-03-24 18:00:00	2017-03-24 18:00:00	 Groupe de travail contre le harcelement au travail
6581	08010L	REU_TRAV_PARL	2017-06-20 13:00:00	2017-06-20 18:30:00	rencontres commission des finances Salon du Bourget
6601	08010L	ORG_POL	2017-07-18 11:00:00	2017-07-18 12:30:00	Groupe LR sénat
6602	08010L	REU_TRAV_PARL	2017-05-09 13:00:00	2017-05-09 18:30:00	Commission des finances contrôle budgétaire déplacement centre pénitentiaire de Fresnes
6621	11091R	DEPL_PRES_GVT	2017-07-24 10:00:00	2017-07-24 11:30:00	Ministre de la Culture - Château de Versailles
6622	11091R	REU_GVT	2017-07-17 18:00:00	2017-07-17 18:00:00	Conférence nationale des Territoires
6784	14065Q	COLL_TER	2017-07-03 16:00:00	2017-07-03 16:00:00	SCOTERS
6785	14065Q	CEREMONIE	2017-07-03 22:00:00	2017-07-03 22:00:00	\N
6786	14065Q	ORG_POL	2017-07-04 13:00:00	2017-07-04 13:00:00	\N
6788	14065Q	ELUS_LOCAUX	2017-07-06 22:00:00	2017-07-06 22:00:00	\N
6789	14065Q	ORG_POL	2017-07-11 13:00:00	2017-07-11 13:00:00	\N
6790	14065Q	REU_TRAV_PARL	2017-07-11 21:00:00	2017-07-11 21:00:00	PL Sécuroté intérieure
6791	14065Q	ORG_POL	2017-07-18 13:00:00	2017-07-18 13:00:00	\N
6792	14065Q	ORG_POL	2017-07-25 13:00:00	2017-07-25 13:00:00	\N
6793	14065Q	REU_TRAV_PARL	2017-07-25 19:00:00	2017-07-25 19:00:00	\N
6794	14065Q	CEREMONIE	2017-07-25 21:30:00	2017-07-25 21:30:00	\N
6801	08009T	REU_TRAV_PARL	2017-07-26 11:35:00	2017-07-26 13:00:00	\N
6802	08009T	ORG_POL	2017-07-25 19:00:00	2017-07-25 20:00:00	\N
6805	08009T	REU_TRAV_PARL	2017-07-25 14:00:00	2017-07-25 14:35:00	\N
6804	08009T	REU_GVT	2017-07-25 20:00:00	2017-07-25 21:00:00	\N
6806	08009T	ORG_POL	2017-07-25 11:00:00	2017-07-25 13:00:00	\N
6807	08009T	REU_GVT	2017-07-25 08:00:00	2017-07-25 09:00:00	\N
6808	08009T	REU_TRAV_PARL	2017-07-25 09:30:00	2017-07-25 11:00:00	Questions Orales
6809	08009T	REU_TRAV_PARL	2017-07-20 09:30:00	2017-07-20 11:00:00	\N
6810	08009T	REU_GVT	2017-07-19 16:30:00	2017-07-19 17:30:00	\N
6811	08009T	ORG_POL	2017-07-19 12:30:00	2017-07-19 14:00:00	\N
6812	08009T	REU_TRAV_PARL	2017-07-19 08:00:00	2017-07-19 09:30:00	\N
6813	08009T	REU_GVT	2017-07-18 09:00:00	2017-07-18 10:00:00	\N
6814	08009T	ORG_POL	2017-07-18 11:00:00	2017-07-18 13:00:00	\N
6815	08009T	REU_TRAV_PARL	2017-07-12 16:00:00	2017-07-12 16:30:00	\N
6816	08009T	REU_TRAV_PARL	2017-07-11 10:00:00	2017-07-11 11:00:00	\N
6817	08009T	ORG_POL	2017-07-11 11:00:00	2017-07-11 13:00:00	\N
6818	08009T	REU_TRAV_PARL	2017-07-11 13:00:00	2017-07-11 14:00:00	\N
6819	08009T	REU_GVT	2017-07-11 19:30:00	2017-07-11 20:30:00	\N
6820	08009T	REU_GVT	2017-07-06 13:00:00	2017-07-06 14:30:00	\N
6821	08009T	REU_TRAV_PARL	2017-07-05 08:30:00	2017-07-05 09:30:00	\N
6841	08009T	CEREMONIE	2017-07-05 10:30:00	2017-07-05 11:30:00	\N
6842	08009T	REU_TRAV_PARL	2017-07-05 15:15:00	2017-07-05 16:45:00	\N
6843	08009T	REU_TRAV_PARL	2017-07-05 18:25:00	2017-07-05 19:30:00	\N
6844	08009T	REU_TRAV_PARL	2017-07-04 08:30:00	2017-07-04 09:30:00	\N
6845	08009T	ORG_POL	2017-07-04 11:00:00	2017-07-04 13:00:00	\N
4045	04042C	COLL_TER	2016-02-08 17:00:00	2016-02-08 18:00:00	sur le pôle psychiatrie de l'Hôpital National de Saint-Maurice
4046	04042C	ELUS_LOCAUX	2016-02-08 18:00:00	2016-02-08 19:00:00	Conseil de Territoire
4047	04042C	COLL_TER	2016-01-29 09:30:00	2016-01-29 12:00:00	Conseil de surveillance des Hôpitaux de Saint-Maurice
4048	04042C	COLL_TER	2016-01-29 12:30:00	2016-01-29 14:30:00	Cérémonie des voeux des Hôpitaux de Saint-Maurice
4061	04042C	ELUS_LOCAUX	2016-01-29 19:00:00	2016-01-29 20:30:00	Voeux du Cercle Eugène Delacroix
4062	04042C	COLL_TER	2016-01-25 10:30:00	2016-01-25 12:00:00	Présentation du Projet résidence du Valais
4063	04042C	COLL_TER	2016-01-25 15:00:00	2016-01-25 16:00:00	sur le logement
4064	04042C	COLL_TER	2016-01-25 16:00:00	2016-01-25 17:00:00	sur les logements sociaux
4065	04042C	COLL_TER	2016-01-25 17:00:00	2016-01-25 18:00:00	avec l'Inspection général de l'administration et l'inspection générale de la police nationale
4066	04042C	ELUS_LOCAUX	2016-01-25 19:00:00	2016-01-25 19:30:00	Galette militante à Joinville-le-Pont
4067	04042C	ELUS_LOCAUX	2016-01-25 19:30:00	2016-01-25 20:30:00	Voeux Jeunes Pop
4068	04042C	ELUS_LOCAUX	2016-01-25 20:45:00	2016-01-25 22:00:00	sur le T11 à Sucy
4069	04042C	REU_TRAV_PARL	2016-01-21 15:30:00	2016-01-21 22:00:00	Forum Euromed Capital
4070	04042C	REU_TRAV_PARL	2016-01-22 08:00:00	2016-01-22 22:00:00	Forum Euromed Capital
4071	04042C	CEREMONIE	2016-01-21 11:30:00	2016-01-21 13:00:00	Voeux du Président du Sénat
4077	04042C	ELUS_LOCAUX	2016-01-15 10:00:00	2016-01-15 13:00:00	Bureau du Syndicat des Eaux d'Ile-de-France
4078	04042C	ELUS_LOCAUX	2016-01-15 14:00:00	2016-01-15 15:00:00	Réunion préparatoire au Conseil de territorial
4079	04042C	ELUS_LOCAUX	2016-01-15 15:00:00	2016-01-15 18:00:00	1er Conseil de Territoire avec les élections du Président et des Vice-présidents
4080	04042C	ELUS_LOCAUX	2016-01-15 19:00:00	2016-01-15 20:00:00	Rception des voeux de Perigny-sur-Yerres
4081	04042C	ELUS_LOCAUX	2016-01-15 20:00:00	2016-01-15 21:00:00	Galette militante d'Arcueil
4082	04042C	COLL_TER	2016-01-11 11:00:00	2016-01-11 13:00:00	\N
4083	04042C	REU_TRAV_PARL	2016-01-11 15:00:00	2016-01-11 16:00:00	avec le Président de la Chambre française de commerce et d'industrie du Maroc
4084	04042C	COLL_TER	2016-01-11 16:00:00	2016-01-11 17:00:00	sur l'Actep
4085	04042C	ELUS_LOCAUX	2016-01-11 19:30:00	2016-01-11 21:00:00	Cérémonie des Voeux de Thiais
4101	11053K	REU_TRAV_PARL	2017-02-09 15:00:00	2017-02-09 16:00:00	QAG
4109	04042C	ELUS_LOCAUX	2016-01-08 20:00:00	2016-01-08 21:00:00	Cérémonie des vouex de Mandres-les-Roses
4110	04042C	ELUS_LOCAUX	2016-01-04 18:30:00	2016-01-04 22:00:00	Cérémonie des voeux de Charenton-le-Pont
4111	04042C	ELUS_LOCAUX	2015-12-18 09:45:00	2015-12-18 13:00:00	Installation du Conseil régional d'Ile-de-France
4112	04042C	COLL_TER	2015-12-18 16:30:00	2015-12-18 17:00:00	Anciens combattants
4113	04042C	COLL_TER	2015-12-18 17:00:00	2015-12-18 17:30:00	\N
4114	04042C	ACC_DEPL_INTER	2015-12-18 18:30:00	2015-12-18 20:30:00	Ambassade du Qatar
4202	04042C	COLL_TER	2015-11-09 09:30:00	2015-11-09 11:30:00	PLU
4203	04042C	REU_TRAV_PARL	2015-11-09 12:30:00	2015-11-09 14:30:00	Colloque France-Maroc
4204	04042C	COLL_TER	2015-11-09 15:00:00	2015-11-09 17:30:00	Assemblée générale de l'AM94
4205	04042C	ELUS_LOCAUX	2015-11-09 19:30:00	2015-11-09 22:00:00	Meeting élections régionales 
4206	04042C	ELUS_LOCAUX	2015-11-06 08:30:00	2015-11-06 12:00:00	Bureau du Syndicat des Eaux d'Ile-de-France
4207	04042C	COLL_TER	2015-11-06 17:00:00	2015-11-06 17:30:00	urbanisme
4208	04042C	COLL_TER	2015-11-06 17:30:00	2015-11-06 18:00:00	logement
4209	04042C	ORG_POL	2015-11-06 19:00:00	2015-11-06 20:00:00	Bureau départemental
4210	04042C	ORG_POL	2015-11-06 20:00:00	2015-11-06 22:00:00	Comité départemental
4211	04042C	COLL_TER	2015-11-02 11:00:00	2015-11-02 12:00:00	sur la situation des agents de la communauté de communes
4212	04042C	COLL_TER	2015-11-02 12:00:00	2015-11-02 13:00:00	réunion de direction
4213	04042C	COLL_TER	2015-11-02 16:00:00	2015-11-02 17:30:00	logement social
4214	04042C	COLL_TER	2015-11-02 17:30:00	2015-11-02 18:00:00	associations
4215	04042C	COLL_TER	2015-11-02 18:00:00	2015-11-02 18:30:00	commerce
4216	04042C	COLL_TER	2015-11-02 19:00:00	2015-11-02 21:00:00	Conseil intercommunal
4221	04042C	ORG_POL	2017-02-08 14:30:00	2017-02-08 15:15:00	Groupe Les Républicains du Sénat
4741	14065Q	REU_GVT	2016-09-21 14:30:00	2016-09-21 15:30:00	sur le projet de loi "Justice du 21ème siècle"
4602	14065Q	DEPL_PRES_GVT	2016-09-13 08:00:00	2016-09-13 20:00:00	Groupe d'amitié France-Estonie
4721	08010L	ACC_DEPL_INTER	2017-02-16 15:00:00	2017-02-16 16:30:00	GIA France Etats-Unis
4761	14065Q	REU_TRAV_PARL	2016-09-21 15:30:00	2016-09-21 16:30:00	sur le projet de loi "Justice du 21ème siècle"
4981	08009T	ELUS_LOCAUX	2017-02-16 18:00:00	2017-02-16 20:00:00	\N
4982	08009T	ORG_POL	2017-02-21 11:00:00	2017-02-21 12:30:00	Réunion de groupe - UDI
4983	08009T	REU_TRAV_PARL	2017-02-21 10:00:00	2017-02-21 11:00:00	Interview TDIE
4984	08009T	REU_TRAV_PARL	2017-02-22 08:30:00	2017-02-22 09:30:00	Réunion de bureau
5001	08009T	REU_TRAV_PARL	2017-02-22 11:45:00	2017-02-22 12:30:00	GT Aménagement du Territoire
5021	14225N	COLL_TER	2016-11-29 12:30:00	2016-11-29 14:00:00	Rencontre avec Monsieur le Préfet de la Meurthe et Moselle
5041	14225N	REU_TRAV_PARL	2016-11-29 17:30:00	2016-11-29 18:30:00	Interview Public Sénat
5042	14225N	REU_TRAV_PARL	2016-11-29 19:30:00	2016-11-29 22:00:00	Rencontre Jean Claude Trichet - echanges sur le Brexit
5043	14225N	REU_TRAV_PARL	2016-11-30 12:30:00	2016-11-30 14:00:00	Rencontre avec Monsieur Matthieu PEYRAUD, sous-directeur des Amériques et des Caraïbes au Ministère des Affaires Etrangères
5044	14225N	COLL_TER	2016-12-01 09:00:00	2016-12-01 12:00:00	Bureau Toulouse Métropole
5045	14225N	ELUS_LOCAUX	2016-12-01 19:00:00	2016-12-01 22:00:00	Réunion des élus de Tournefeuille
5061	14225N	REU_TRAV_PARL	2016-12-06 12:00:00	2016-12-06 14:00:00	"Rencontre avec le Professeur François Bricaire  Comment combattre les maladies infectieuses en France"\tMaison de la Recherche
5062	14225N	REU_TRAV_PARL	2016-12-06 17:00:00	2016-12-06 19:00:00	Cycle des Hautes Etudes Européennes (ENA) 
5063	14225N	REU_TRAV_PARL	2016-12-07 12:00:00	2016-12-07 14:00:00	Rencontre Pierre Blayau -  Echange sur Le coût des catastrophes naturelles en France
5081	14225N	ELUS_LOCAUX	2016-12-08 09:00:00	2016-12-08 12:00:00	Permanence à Toulouse
5082	14225N	ORG_POL	2016-12-13 20:00:00	2016-12-13 22:00:00	Rencontre Manuel Valls 
5083	14225N	COLL_TER	2016-12-15 09:00:00	2016-12-15 18:00:00	Conseil de Communauté\tCentre Pierre Baudis (Toulouse) 
5084	14225N	REU_TRAV_PARL	2017-01-11 08:00:00	2017-01-11 09:00:00	Rancontre avec alain Charmeau, pdg Airbus Safran Launchers
5085	14225N	CEREMONIE	2017-01-12 12:00:00	2017-01-12 14:00:00	V¿ux de Monsieur le Ministre de l¿Aménagement du territoire, de la Ruralité et des Collectivités territoriales
5101	14225N	CEREMONIE	2017-01-12 19:00:00	2017-01-12 21:00:00	V¿ux aux Maires\tConseil Départemental de la Haute-Garonne
5102	14225N	COLL_TER	2016-11-10 10:00:00	2016-11-10 16:00:00	Conseil de Métropole 
5201	04042C	COLL_TER	2017-02-24 08:45:00	2017-02-24 11:00:00	Bureau du syndicat des Eaux d'Ile-de-France
5202	04042C	COLL_TER	2017-02-24 12:30:00	2017-02-24 14:30:00	EPT 10
5203	04042C	ORG_POL	2017-02-24 18:30:00	2017-02-24 22:30:00	Meeting de François Fillon à Maisons-Alfort
5281	14089Y	DEPL_PRES_GVT	2017-03-14 11:00:00	2017-03-14 20:00:00	\N
5282	14089Y	DEPL_PRES_GVT	2017-03-15 08:00:00	2017-03-15 20:00:00	\N
5283	14089Y	DEPL_PRES_GVT	2017-03-16 08:00:00	2017-03-16 17:00:00	\N
5302	08010L	REU_TRAV_PARL	2017-03-07 12:45:00	2017-03-07 14:30:00	\N
5303	08010L	ELUS_LOCAUX	2017-03-08 09:00:00	2017-03-08 16:00:00	journée des femmes maires
5381	08010L	ACC_DEPL_INTER	2017-03-29 11:30:00	2017-03-29 12:30:00	\N
5402	14225N	CEREMONIE	2017-01-17 19:00:00	2017-01-17 21:00:00	Réception Nouvelle Année - Sénat
5411	14225N	REU_TRAV_PARL	2017-01-31 09:00:00	2017-01-31 12:00:00	RDV M Tribot La Spiere - Délégué général CEPS - Centre d'Etude et de Prospective Stratégique
6423	11029K	REU_TRAV_PARL	2017-06-26 15:00:00	2017-06-26 15:00:00	\N
6424	11029K	CEREMONIE	2017-06-26 18:00:00	2017-06-26 18:00:00	Cérémonie d'accueil dans la citoyenneté française à la Préfecture
6429	11029K	REU_TRAV_PARL	2017-06-23 12:00:00	2017-06-23 12:00:00	Hackathon Cada en partenariat avec la Cour des comptes Liberté Living Lab
6432	11029K	REU_TRAV_PARL	2017-06-16 18:00:00	2017-06-16 18:00:00	Festival de tourisme Angers
6434	11029K	REU_TRAV_PARL	2017-05-29 15:15:00	2017-05-29 15:15:00	RDV CGT SDIS 49 
6435	11029K	REU_TRAV_PARL	2017-05-29 16:30:00	2017-05-29 16:30:00	\N
6436	11029K	REU_TRAV_PARL	2017-05-29 17:30:00	2017-05-29 17:30:00	\N
6437	11029K	REU_TRAV_PARL	2017-06-02 10:00:00	2017-06-02 10:00:00	\N
6438	11029K	REU_TRAV_PARL	2017-06-02 11:30:00	2017-06-02 11:30:00	Permanence
6439	11029K	REU_TRAV_PARL	2017-06-02 12:30:00	2017-06-02 12:30:00	Vernissage et cocktail Chateau d'Angers The stopover
6447	11029K	REU_TRAV_PARL	2017-05-15 09:45:00	2017-05-15 09:45:00	\N
4342	04042C	ACC_VISIT	2016-09-19 09:00:00	2016-09-19 10:30:00	Visite du Sénat de l'Amicale du 3ème âge de Charenton-le-Pont
4343	04042C	ELUS_LOCAUX	2016-09-07 13:00:00	2016-09-07 14:30:00	\N
4344	04042C	COLL_TER	2016-07-12 15:00:00	2016-07-12 16:00:00	PLU
4345	04042C	COLL_TER	2016-07-12 16:00:00	2016-07-12 16:30:00	association sociale
4346	04042C	COLL_TER	2016-07-12 16:30:00	2016-07-12 17:00:00	association culturelle
4347	04042C	ORG_POL	2016-07-12 17:30:00	2016-07-12 18:30:00	\N
4348	04042C	ORG_POL	2016-07-12 18:30:00	2016-07-12 21:00:00	Les Républicains du Sénat
4361	04042C	COLL_TER	2016-06-13 20:30:00	2016-06-13 22:00:00	Préfet du Val-de-Marne
4383	08009T	REU_TRAV_PARL	2017-02-07 16:00:00	2017-02-07 17:00:00	Interview Ouest France
4384	08009T	ORG_POL	2017-02-07 19:00:00	2017-02-07 21:00:00	Réunion UDI
4385	08009T	REU_TRAV_PARL	2017-02-08 08:30:00	2017-02-08 09:30:00	Groupe d'amitiés France-Caucase
4386	08009T	REU_TRAV_PARL	2017-02-08 11:30:00	2017-02-08 12:00:00	SNCF Réseau
4387	08009T	REU_TRAV_PARL	2017-02-08 17:00:00	2017-02-08 18:00:00	Situation Ukraine
4388	08009T	REU_TRAV_PARL	2017-02-09 08:30:00	2017-02-09 09:30:00	Petit-Déjeuner Avenir de l'agriculture
4389	08009T	REU_TRAV_PARL	2017-02-09 10:45:00	2017-02-09 12:30:00	Groupe de travail Aménagement du territoire
4390	08009T	ELUS_LOCAUX	2017-02-09 17:30:00	2017-02-09 19:30:00	\N
4581	04042C	ACC_DEPL_INTER	2017-02-15 13:00:00	2017-02-15 14:30:00	\N
4582	04042C	ORG_POL	2017-02-16 10:00:00	2017-02-16 12:00:00	\N
5361	08010L	ELUS_LOCAUX	2017-03-22 09:00:00	2017-03-22 15:00:00	AMF audition des candidats à l'élection présidentielle 
5362	08010L	REU_TRAV_PARL	2017-03-22 16:00:00	2017-03-22 17:00:00	commission des finances 
5363	08010L	REU_TRAV_PARL	2017-03-22 17:00:00	2017-03-22 19:00:00	\N
5461	08010L	COLL_TER	2017-03-30 10:00:00	2017-03-30 14:00:00	Fédération des EPL
5505	14225N	COLL_TER	2017-03-30 10:00:00	2017-03-30 10:00:00	Bureau Toulouse Métropole
5506	14225N	COLL_TER	2017-03-30 12:00:00	2017-03-30 12:00:00	Conférence Métropolitaine 
5507	14225N	ELUS_LOCAUX	2017-03-30 15:00:00	2017-03-30 16:00:00	Permanence à Toulouse
5508	14225N	ELUS_LOCAUX	2017-03-30 17:00:00	2017-03-30 17:00:00	Visite avant réalisation du futur Espace Mémoire Aéro
5509	14225N	ORG_POL	2017-02-14 12:00:00	2017-02-14 12:00:00	Groupe socialiste
5521	08010L	REU_TRAV_PARL	2017-03-30 18:30:00	2017-03-30 21:00:00	conférence sur la fonction d'élu
5861	08009T	DEPL_PRES_GVT	2017-03-07 00:01:00	2017-03-07 23:59:00	Tapei
5843	08010L	REU_TRAV_PARL	2017-04-18 11:00:00	2017-04-18 12:30:00	Groupe LR du sénat
5862	08009T	DEPL_PRES_GVT	2017-03-08 00:01:00	2017-03-08 23:59:00	Tapei
6261	14179A	COLL_TER	2017-04-12 10:30:00	2017-04-12 10:30:00	\N
6262	14179A	COLL_TER	2017-04-12 16:00:00	2017-04-12 16:00:00	CIID
6263	14179A	ELUS_LOCAUX	2017-04-13 12:30:00	2017-04-13 12:30:00	\N
6264	14179A	COLL_TER	2017-04-13 16:00:00	2017-04-13 16:00:00	2CCAM
6265	14179A	COLL_TER	2017-04-13 23:00:00	2017-04-13 23:00:00	Conseil municipal Marnaz
6266	14179A	ELUS_LOCAUX	2017-04-14 21:00:00	2017-04-14 21:00:00	Cantons Sciez Thonon
6267	14179A	ELUS_LOCAUX	2017-04-18 10:30:00	2017-04-18 10:30:00	Megève
6268	14179A	CEREMONIE	2017-04-18 12:00:00	2017-04-18 12:00:00	Inauguration borne Marnaz
6269	14179A	COLL_TER	2017-04-18 15:00:00	2017-04-18 15:00:00	2CCAM
6270	14179A	ELUS_LOCAUX	2017-04-18 19:00:00	2017-04-18 19:00:00	\N
6271	14179A	ORGEXTPAR	2017-04-20 12:00:00	2017-04-20 12:00:00	CNIL
6272	14179A	COLL_TER	2017-04-20 21:00:00	2017-04-20 21:00:00	Mairie de Marnaz
6281	14179A	ELUS_LOCAUX	2017-04-24 15:00:00	2017-04-24 15:00:00	GDV
6282	14179A	COLL_TER	2017-04-24 17:00:00	2017-04-24 17:00:00	2CCAM
6283	14179A	ORG_POL	2017-04-24 22:00:00	2017-04-24 22:00:00	\N
6284	14179A	ORG_POL	2017-04-25 14:00:00	2017-04-25 14:00:00	\N
6285	14179A	CEREMONIE	2017-04-26 19:30:00	2017-04-26 19:30:00	\N
6286	14179A	ORGEXTPAR	2017-04-27 12:00:00	2017-04-27 12:00:00	CNIL
6287	14179A	ELUS_LOCAUX	2017-05-02 20:00:00	2017-05-02 20:00:00	Commune nouvelle Annecy
6288	14179A	ELUS_LOCAUX	2017-05-03 14:00:00	2017-05-03 14:00:00	\N
6289	14179A	COLL_TER	2017-05-03 20:00:00	2017-05-03 20:00:00	2CCAM
6290	14179A	ELUS_LOCAUX	2017-05-03 23:00:00	2017-05-03 23:00:00	\N
6291	14179A	DEPL_PRES_GVT	2017-05-04 14:00:00	2017-05-04 14:00:00	\N
6292	14179A	COLL_TER	2017-05-04 21:00:00	2017-05-04 21:00:00	2CCAM
6293	14179A	COLL_TER	2017-05-05 12:00:00	2017-05-05 12:00:00	Mairie de Marnaz
6294	14179A	ELUS_LOCAUX	2017-05-05 16:00:00	2017-05-05 16:00:00	Conseil surveillance HPMB
6295	14179A	CEREMONIE	2017-05-08 10:00:00	2017-05-08 10:00:00	Vougy
6296	14179A	CEREMONIE	2017-05-08 12:30:00	2017-05-08 12:30:00	Marnaz
6297	14179A	CEREMONIE	2017-05-08 18:00:00	2017-05-08 18:00:00	Marnaz
6298	14179A	CEREMONIE	2017-05-08 20:00:00	2017-05-08 20:00:00	St Julien en Genevois
6299	14179A	ORGEXTPAR	2017-05-09 12:00:00	2017-05-09 12:00:00	CNIL
6300	14179A	ORG_POL	2017-05-09 22:00:00	2017-05-09 22:00:00	\N
6301	14179A	ELUS_LOCAUX	2017-05-10 11:00:00	2017-05-10 11:00:00	CLSPD
6302	14179A	COLL_TER	2017-05-10 17:00:00	2017-05-10 17:00:00	2CCAM
6303	14179A	COLL_TER	2017-05-10 22:00:00	2017-05-10 22:00:00	Mairie de Marnaz
6304	14179A	ELUS_LOCAUX	2017-05-11 13:00:00	2017-05-11 13:00:00	CAUE
6305	14179A	ELUS_LOCAUX	2017-05-11 18:00:00	2017-05-11 18:00:00	Pole Mont-Blanc Industrie
6306	14179A	ELUS_LOCAUX	2017-05-12 14:00:00	2017-05-12 14:00:00	UDOTSI
6307	14179A	ELUS_LOCAUX	2017-05-12 16:00:00	2017-05-12 16:00:00	CORA
6308	14179A	ELUS_LOCAUX	2017-05-12 20:00:00	2017-05-12 20:00:00	Communes forestières 74
6309	14179A	ELUS_LOCAUX	2017-05-15 09:00:00	2017-05-15 10:30:00	GDV
6310	14179A	COLL_TER	2017-05-15 14:00:00	2017-05-15 16:00:00	2CCAM
6311	14179A	ELUS_LOCAUX	2017-05-15 18:00:00	2017-05-15 19:30:00	Mairie d'Arenthon
6312	14179A	COLL_TER	2017-05-15 20:00:00	2017-05-15 22:00:00	Marnaz
6313	14179A	CEREMONIE	2017-05-16 20:00:00	2017-05-16 20:00:00	\N
6314	14179A	COLL_TER	2017-05-17 09:00:00	2017-05-17 17:00:00	2CCAM
6315	14179A	ORG_POL	2017-05-17 18:00:00	2017-05-17 20:00:00	\N
6316	14179A	ELUS_LOCAUX	2017-05-18 09:00:00	2017-05-18 16:00:00	\N
6317	14179A	ELUS_LOCAUX	2017-05-19 09:00:00	2017-05-19 20:00:00	Canton de la Roche
6318	14179A	ELUS_LOCAUX	2017-05-22 09:00:00	2017-05-22 10:00:00	\N
6319	14179A	ORG_POL	2017-05-22 11:00:00	2017-05-22 12:00:00	\N
6320	14179A	COLL_TER	2017-05-22 15:00:00	2017-05-22 17:00:00	2CCAM
6321	14179A	ELUS_LOCAUX	2017-05-23 09:00:00	2017-05-23 20:00:00	Canton Rumilly
6322	14179A	REU_TRAV_PARL	2017-05-29 16:00:00	2017-05-29 17:00:00	GDV
6323	14179A	ORG_POL	2017-05-29 20:00:00	2017-05-29 22:00:00	\N
6324	14179A	ELUS_LOCAUX	2017-05-30 09:00:00	2017-05-30 20:00:00	Canton Annecy 1
6325	14179A	REU_TRAV_PARL	2017-05-31 10:00:00	2017-05-31 14:00:00	Visite Atelier St Martin
6326	14179A	CEREMONIE	2017-05-31 19:00:00	2017-05-31 20:00:00	\N
6327	14179A	ORGEXTPAR	2017-06-01 12:00:00	2017-06-01 12:00:00	CNIL
6328	14179A	COLL_TER	2017-06-02 08:30:00	2017-06-02 09:30:00	\N
6329	14179A	CEREMONIE	2017-06-02 10:00:00	2017-06-02 11:30:00	\N
6330	14179A	COLL_TER	2017-06-02 14:00:00	2017-06-02 16:00:00	2CCAM
6331	14179A	ORG_POL	2017-06-06 12:00:00	2017-06-06 14:00:00	\N
6332	14179A	COLL_TER	2017-06-07 18:00:00	2017-06-07 20:00:00	2CCAM
6333	14179A	COLL_TER	2017-06-08 15:30:00	2017-06-08 16:30:00	CNAC 
6337	14179A	ELUS_LOCAUX	2017-06-09 11:00:00	2017-06-09 12:00:00	\N
6335	08010L	ORG_POL	2017-07-04 10:00:00	2017-07-04 14:00:00	séminaire LR Sénat
6336	14179A	COLL_TER	2017-06-09 08:45:00	2017-06-09 09:45:00	2CCAM
6338	14179A	ELUS_LOCAUX	2017-06-09 15:30:00	2017-06-09 16:30:00	\N
6339	14179A	COLL_TER	2017-06-12 17:30:00	2017-06-12 17:30:00	Mairie de Marnaz
6340	14179A	CEREMONIE	2017-06-12 22:30:00	2017-06-12 23:00:00	\N
6341	14179A	ELUS_LOCAUX	2017-06-13 12:00:00	2017-06-13 20:00:00	Canton ALV
6361	14179A	ACC_DEPL_INTER	2017-06-15 09:00:00	2017-06-15 15:00:00	Délégation québécoise
6362	14179A	COLL_TER	2017-06-15 20:00:00	2017-06-15 22:00:00	Mairie de Marnaz
6363	14179A	CEREMONIE	2017-06-16 18:00:00	2017-06-16 20:00:00	\N
6364	14179A	COLL_TER	2017-06-19 11:00:00	2017-06-19 12:00:00	2CCAM
6365	14179A	COLL_TER	2017-06-19 13:30:00	2017-06-19 19:30:00	2CCAM
6366	14179A	ORG_POL	2017-06-20 11:00:00	2017-06-20 12:00:00	\N
6367	14179A	CEREMONIE	2017-06-20 19:30:00	2017-06-20 22:00:00	\N
6368	14179A	DEL_ACT_PAR	2017-06-21 09:00:00	2017-06-21 17:00:00	GPE Espace Le Bourget
6369	14179A	ORGEXTPAR	2017-06-22 09:00:00	2017-06-22 12:00:00	CNIL
6370	14179A	REU_TRAV_PARL	2017-06-23 10:30:00	2017-06-23 14:00:00	GDV
6371	14179A	COLL_TER	2017-06-23 17:00:00	2017-06-23 18:00:00	Mairie de Marnaz
6372	14179A	CEREMONIE	2017-06-23 18:00:00	2017-06-23 20:00:00	Chêne en Semine
6373	14179A	COLL_TER	2017-06-26 09:00:00	2017-06-26 11:30:00	2CCAM
6381	14179A	ELUS_LOCAUX	2017-06-26 12:00:00	2017-06-26 14:00:00	Canton Mont-Blanc Sallanches
6382	14179A	COLL_TER	2017-06-26 14:00:00	2017-06-26 16:30:00	2
6383	14179A	ELUS_LOCAUX	2017-06-26 18:30:00	2017-06-26 20:00:00	Canton Mont-Blanc Sallanches
6384	14179A	ORGEXTPAR	2017-06-27 09:00:00	2017-06-27 11:00:00	CNIL
6385	14179A	ORG_POL	2017-06-27 11:00:00	2017-06-27 12:30:00	\N
6386	14179A	ACC_VISIT	2017-06-27 19:00:00	2017-06-27 20:00:00	\N
6387	14179A	CEREMONIE	2017-06-28 10:00:00	2017-06-28 12:00:00	\N
6388	14179A	COLL_TER	2017-06-28 18:30:00	2017-06-28 21:00:00	2CCAM
6389	14179A	COLL_TER	2017-06-29 11:00:00	2017-06-29 11:00:00	SYANE
6390	14179A	CEREMONIE	2017-06-29 11:00:00	2017-06-29 12:30:00	\N
6391	14179A	COLL_TER	2017-06-29 14:30:00	2017-06-29 15:30:00	2CCAM
6392	14179A	COLL_TER	2017-06-29 19:00:00	2017-06-29 21:00:00	SIVOM
6393	14179A	COLL_TER	2017-06-30 09:30:00	2017-06-30 11:30:00	EPF
6394	14179A	COLL_TER	2017-06-30 14:30:00	2017-06-30 17:00:00	2CCAM
6395	14179A	ORG_POL	2017-07-04 11:00:00	2017-07-04 12:00:00	\N
6396	14179A	ORGEXTPAR	2017-07-06 11:00:00	2017-07-06 11:00:00	CNIL
6397	14179A	REU_TRAV_PARL	2017-07-06 14:00:00	2017-07-06 14:00:00	ARS
6401	11029K	CEREMONIE	2017-07-03 18:00:00	2017-07-03 19:00:00	Congrès de Versailles
6402	11029K	REU_TRAV_PARL	2017-07-07 12:00:00	2017-07-07 12:00:00	Rencontre avec l'association l'arbre vert
4481	14179A	CEREMONIE	2017-02-10 10:30:00	2017-02-10 11:30:00	Inauguration pôle d'échange multimodal de Bonneville
4482	14179A	ELUS_LOCAUX	2017-02-10 11:30:00	2017-02-10 12:30:00	2CCAM
4483	14179A	ELUS_LOCAUX	2017-02-13 08:30:00	2017-02-13 09:30:00	\N
4484	14179A	ELUS_LOCAUX	2017-02-13 10:30:00	2017-02-13 11:30:00	Réunion en Préfecture -Bouquetins du Bargy
4485	14179A	COLL_TER	2017-02-13 12:00:00	2017-02-13 14:00:00	2CCAM
4486	14179A	ELUS_LOCAUX	2017-02-13 15:00:00	2017-02-13 17:30:00	CIL
4487	14179A	COLL_TER	2017-02-14 10:00:00	2017-02-14 11:00:00	2CCAM
4488	14179A	COLL_TER	2017-02-14 14:30:00	2017-02-14 15:30:00	CDAC pour 2CCAM
4501	08010L	REU_TRAV_PARL	2017-02-14 17:45:00	2017-02-14 19:00:00	controle budgétaire AGRASC
5221	04042C	ACC_VISIT	2017-02-27 14:00:00	2017-02-27 15:30:00	Visite du Sénat des Séniors de Joinville-le-Pont
5921	08010L	ORG_POL	2017-04-25 10:00:00	2017-04-25 12:30:00	groupe LR senat
5941	08010L	ORG_POL	2017-05-09 11:00:00	2017-05-09 12:30:00	Groupe LR sénat
6081	08010L	ORG_POL	2017-05-30 10:00:00	2017-05-30 12:30:00	Groupe LR sénat
6403	11029K	REU_TRAV_PARL	2017-07-10 11:00:00	2017-07-10 11:00:00	Rencontre avec des associations
6404	11029K	CEREMONIE	2017-07-14 12:00:00	2017-07-14 12:00:00	14 juillet à Angers
6448	11029K	REU_TRAV_PARL	2017-05-15 11:00:00	2017-05-15 11:00:00	Président clinique de l'Anjou - Remise de l'ouvrage sur l'hospitalisation privée
6449	11029K	REU_TRAV_PARL	2017-05-15 12:30:00	2017-05-15 12:30:00	Eric Grellier - Président de la CCI 
6450	11029K	REU_TRAV_PARL	2017-05-15 15:00:00	2017-05-15 15:00:00	\N
6451	11029K	REU_TRAV_PARL	2017-05-15 16:00:00	2017-05-15 17:00:00	Journaliste
6461	11029K	REU_TRAV_PARL	2017-05-19 14:00:00	2017-05-19 14:00:00	Vernissage expo "JC Brialy, l'enchanteur" 
6462	11029K	CEREMONIE	2017-05-08 12:15:00	2017-05-08 12:15:00	Commémoration Victoire 8 mai
6463	11029K	REU_TRAV_PARL	2017-05-12 12:30:00	2017-05-12 12:30:00	Colloque sur les discriminations
6464	11029K	REU_TRAV_PARL	2017-05-12 14:00:00	2017-05-12 14:00:00	Déjeuner colloque
6465	11029K	REU_TRAV_PARL	2017-05-12 20:30:00	2017-05-12 20:30:00	25 ans RCF Anjou 
6466	11029K	REU_TRAV_PARL	2017-04-24 15:30:00	2017-04-24 15:30:00	Christian Chevalier - Asso LCD discriminations
6467	11029K	REU_TRAV_PARL	2017-04-24 16:30:00	2017-04-24 16:30:00	\N
6468	11029K	REU_TRAV_PARL	2017-04-24 17:30:00	2017-04-24 17:30:00	Pauline Deboffles - Reportage sur femmes en politique
6469	11029K	REU_TRAV_PARL	2017-04-28 11:00:00	2017-04-28 11:00:00	\N
6470	11029K	REU_TRAV_PARL	2017-04-28 11:30:00	2017-04-28 11:30:00	Claire Bossé Asso Eoliharpe
6471	11029K	REU_TRAV_PARL	2017-04-28 12:30:00	2017-04-28 12:30:00	\N
6472	11029K	REU_TRAV_PARL	2017-04-10 12:00:00	2017-04-10 12:00:00	Inauguration du Centre d'activités Foch
6481	11029K	REU_TRAV_PARL	2017-04-10 21:45:00	2017-04-10 21:45:00	Projection débat "Qu'est ce qu'on attend" La Canopée bleue 400 coups
6482	11029K	REU_TRAV_PARL	2017-04-03 10:00:00	2017-04-03 10:00:00	\N
6483	11029K	REU_TRAV_PARL	2017-04-03 12:30:00	2017-04-03 12:30:00	Séminaire équipe Angers - Retour sur l'année - PPL - écritures
6484	11029K	REU_TRAV_PARL	2017-04-03 16:30:00	2017-04-03 16:30:00	Visite salle de spectacle / cinéma
6485	11029K	REU_TRAV_PARL	2017-04-03 18:00:00	2017-04-03 18:00:00	Temps convivial
6486	11029K	REU_TRAV_PARL	2017-04-07 12:00:00	2017-04-07 12:00:00	Rdv sur mémoire de Master sur restitution des oeuvres d'art
6487	11029K	REU_TRAV_PARL	2017-04-07 12:30:00	2017-04-07 12:30:00	Rdv téléphonique cadrage ITW france inter ENA 
6488	11029K	ORG_POL	2017-04-07 19:00:00	2017-04-07 19:00:00	Rdv départ bus devant le siège de la Fédé PS
6489	11029K	ORG_POL	2017-04-07 23:30:00	2017-04-07 23:30:00	Meeting Benoit Hamon à Nantes
6492	11029K	REU_TRAV_PARL	2017-03-27 18:00:00	2017-03-27 18:00:00	Arrivée de la Marche citoyenne des oubliés - Débat avec les hand-bikers
6493	11029K	REU_TRAV_PARL	2017-03-27 10:30:00	2017-03-27 10:30:00	interview
6494	11029K	REU_TRAV_PARL	2017-03-27 16:30:00	2017-03-27 16:30:00	Rdv téléphonique
6521	11029K	REU_TRAV_PARL	2017-03-20 11:00:00	2017-03-20 11:00:00	Data santé
6522	11029K	REU_TRAV_PARL	2017-03-20 12:30:00	2017-03-20 12:30:00	Réunion Crédit Mutuel
6523	11029K	REU_TRAV_PARL	2017-03-20 15:30:00	2017-03-20 15:30:00	Gilles Galopin, président de l'association sur projet EcoSanté 
6524	11029K	REU_TRAV_PARL	2017-03-20 16:45:00	2017-03-20 16:45:00	\N
6525	11029K	CEREMONIE	2017-03-20 17:45:00	2017-03-20 17:45:00	Cérémonie d'accueil dans la citoyenneté
6526	11029K	REU_TRAV_PARL	2017-03-20 19:00:00	2017-03-20 19:00:00	 vernissage de Bente hoppe
6561	08010L	ORG_POL	2017-07-11 11:00:00	2017-07-11 12:30:00	Groupe LR sénat
6641	08010L	ORG_POL	2017-07-25 12:00:00	2017-07-25 12:00:00	Groupe LR sénat
6661	08010L	ORG_POL	2017-08-01 11:00:00	2017-08-01 12:30:00	Groupe LR sénat
6662	08010L	REU_TRAV_PARL	2017-08-01 18:00:00	2017-08-01 19:30:00	réforme institutionelle
6681	08010L	REU_TRAV_PARL	2017-08-01 14:30:00	2017-08-01 14:30:00	normes
6701	14065Q	ACC_VISIT	2017-03-01 20:30:00	2017-03-01 20:30:00	Table ronde "Crise de la démocratie ?"
6702	14065Q	DEPL_PRES_GVT	2017-03-06 15:00:00	2017-03-06 15:00:00	JJ Urvoas, Ministre de la Justice
6703	14065Q	ORG_POL	2017-03-07 13:00:00	2017-03-07 13:00:00	\N
6704	14065Q	ORGEXTPAR	2017-03-10 10:00:00	2017-03-10 12:00:00	Commission du droit local d'Alsace-Moselle
6705	14065Q	COLL_TER	2017-03-13 16:30:00	2017-03-13 16:30:00	SCOTERS
6706	14065Q	ACC_VISIT	2017-03-13 22:30:00	2017-03-13 22:30:00	Réunion publique
6707	14065Q	COLL_TER	2017-03-14 10:00:00	2017-03-14 10:00:00	CDCI
6708	14065Q	REU_TRAV_PARL	2017-03-15 17:30:00	2017-03-15 17:30:00	Redressement de la justice
6709	14065Q	CEREMONIE	2017-03-16 21:30:00	2017-03-16 21:30:00	Remise de prix
6710	14065Q	ACC_VISIT	2017-03-17 10:00:00	2017-03-17 12:00:00	Opération "Artisan d'un jour"
6711	14065Q	ACC_VISIT	2017-03-17 19:00:00	2017-03-17 19:00:00	Rencontre-débat sur l'état d'urgence
6712	14065Q	COLL_TER	2017-03-20 11:00:00	2017-03-20 11:00:00	SCOTERS
6713	14065Q	ORG_POL	2017-03-21 13:00:00	2017-03-21 13:00:00	\N
6714	14065Q	REU_TRAV_PARL	2017-03-21 16:30:00	2017-03-21 16:30:00	Projet de loi sécurité
6715	14065Q	ACC_VISIT	2017-03-27 12:00:00	2017-03-27 12:00:00	Echanges acteurs locaux
6716	14065Q	ORGEXTPAR	2017-03-27 14:30:00	2017-03-27 14:30:00	Commission du droit local d'Alsace
6717	14065Q	ACC_VISIT	2017-03-28 16:30:00	2017-03-28 16:30:00	Conférence
6718	14065Q	COLL_TER	2017-04-03 16:30:00	2017-04-03 16:30:00	SCOTERS
6719	14065Q	ORG_POL	2017-04-03 18:30:00	2017-04-03 18:30:00	\N
6720	14065Q	ORG_POL	2017-04-04 13:00:00	2017-04-04 13:00:00	\N
6721	14065Q	REU_TRAV_PARL	2017-04-04 14:00:00	2017-04-04 14:00:00	\N
6722	14065Q	REU_TRAV_PARL	2017-04-05 10:00:00	2017-04-05 10:00:00	Petit-déjeuner presse
6741	14065Q	COLL_TER	2017-04-07 23:00:00	2017-04-07 23:00:00	Interscot
6742	14065Q	COLL_TER	2017-04-26 16:00:00	2017-04-26 16:00:00	SRADDET/SCOT
6743	14065Q	ACC_DEPL_INTER	2017-04-27 11:30:00	2017-04-27 11:30:00	\N
6744	14065Q	ORGEXTPAR	2017-05-02 18:00:00	2017-05-02 18:00:00	Commission du droit local d'Alsace
6745	14065Q	ACC_DEPL_INTER	2017-05-04 13:30:00	2017-05-04 13:30:00	\N
6746	14065Q	CEREMONIE	2017-05-05 14:00:00	2017-05-05 14:00:00	Inauguration
6747	14065Q	ELUS_LOCAUX	2017-05-05 18:00:00	2017-05-05 18:00:00	\N
6748	14065Q	CEREMONIE	2017-05-08 13:30:00	2017-05-08 13:30:00	\N
6749	14065Q	ACC_VISIT	2017-05-11 11:00:00	2017-05-11 11:00:00	\N
6750	14065Q	ACC_VISIT	2017-05-15 10:00:00	2017-05-15 10:00:00	\N
6751	14065Q	ACC_VISIT	2017-05-16 11:00:00	2017-05-16 11:00:00	\N
6752	14065Q	ELUS_LOCAUX	2017-05-16 21:00:00	2017-05-16 21:00:00	Association des maires du 67
6753	14065Q	ACC_VISIT	2017-05-17 12:00:00	2017-05-17 12:00:00	\N
6754	14065Q	ACC_VISIT	2017-05-18 09:30:00	2017-05-18 09:30:00	Patit-déjeuner débat
6755	14065Q	ACC_VISIT	2017-05-18 19:00:00	2017-05-18 19:00:00	\N
6756	14065Q	ELUS_LOCAUX	2017-05-19 13:00:00	2017-05-19 13:00:00	\N
6757	14065Q	COLL_TER	2017-05-22 12:30:00	2017-05-22 12:30:00	SCOT
6758	14065Q	ACC_VISIT	2017-05-22 20:00:00	2017-05-22 20:00:00	\N
6759	14065Q	ELUS_LOCAUX	2017-05-22 22:30:00	2017-05-22 22:30:00	\N
6760	14065Q	ORG_POL	2017-05-23 11:00:00	2017-05-23 11:00:00	\N
6761	14065Q	ORG_POL	2017-05-23 13:00:00	2017-05-23 13:00:00	\N
6762	14065Q	ACC_VISIT	2017-05-24 11:00:00	2017-05-24 11:00:00	Conférence de presse
6763	14065Q	ACC_VISIT	2017-05-30 09:30:00	2017-05-30 09:30:00	\N
6764	14065Q	COLL_TER	2017-05-30 16:00:00	2017-05-30 16:00:00	SCOT
6765	14065Q	ELUS_LOCAUX	2017-06-01 14:00:00	2017-06-01 14:00:00	\N
6766	14065Q	ACC_VISIT	2017-06-01 22:00:00	2017-06-01 22:00:00	Réunion publique
6767	14065Q	ELUS_LOCAUX	2017-06-02 22:30:00	2017-06-02 22:30:00	Interscot
6768	14065Q	ACC_VISIT	2017-06-06 19:00:00	2017-06-06 19:00:00	\N
6769	14065Q	ACC_VISIT	2017-06-07 10:30:00	2017-06-07 10:30:00	\N
6770	14065Q	ACC_VISIT	2017-06-07 19:00:00	2017-06-07 19:00:00	Café-débat
6771	14065Q	ACC_VISIT	2017-06-08 10:45:00	2017-06-08 10:45:00	\N
6772	14065Q	ORGEXTPAR	2017-06-09 10:00:00	2017-06-09 14:30:00	Commission du droit local d'Alsace
6773	14065Q	ELUS_LOCAUX	2017-06-12 16:30:00	2017-06-12 16:30:00	SCOTERS
6774	14065Q	ACC_VISIT	2017-06-14 12:30:00	2017-06-14 12:30:00	\N
6775	14065Q	ACC_VISIT	2017-06-15 09:00:00	2017-06-15 09:00:00	\N
6776	14065Q	ACC_VISIT	2017-06-15 18:00:00	2017-06-15 18:00:00	\N
6777	14065Q	ORG_POL	2017-06-20 13:00:00	2017-06-20 13:00:00	\N
6778	14065Q	ORG_POL	2017-06-20 15:00:00	2017-06-20 15:00:00	\N
6779	14065Q	CEREMONIE	2017-06-21 19:00:00	2017-06-21 19:00:00	\N
6780	14065Q	COLL_TER	2017-06-23 10:30:00	2017-06-23 10:30:00	SCOTERS
6781	14065Q	ORG_POL	2017-06-27 11:00:00	2017-06-27 11:00:00	\N
6782	14065Q	ORG_POL	2017-06-27 13:00:00	2017-06-27 13:00:00	\N
6783	14065Q	REU_TRAV_PARL	2017-06-27 19:00:00	2017-06-27 19:00:00	PL Moralisation
4521	08010L	REU_TRAV_PARL	2017-02-15 14:30:00	2017-02-15 15:30:00	finances
4522	08010L	ACC_VISIT	2017-02-15 18:00:00	2017-02-15 19:30:00	Elus de l'Aisne
4541	04042C	ELUS_LOCAUX	2017-02-13 08:30:00	2017-02-13 11:00:00	Bureau politique LR du Val-de-Marne
4542	04042C	COLL_TER	2017-02-13 11:00:00	2017-02-13 11:30:00	sécurité
4543	04042C	COLL_TER	2017-02-13 11:30:00	2017-02-13 12:30:00	Urbanisme
4544	04042C	ELUS_LOCAUX	2017-02-13 13:00:00	2017-02-13 14:30:00	\N
4545	04042C	REU_TRAV_PARL	2017-02-13 18:00:00	2017-02-13 18:30:00	Débat sur la chaîne parlementaire Public Sénat sur le droit à l'eau pour tous.
4546	04042C	ORG_POL	2017-02-14 11:00:00	2017-02-14 12:15:00	Groupe Les Républicains du Sénat
4547	04042C	ELUS_LOCAUX	2017-02-14 12:30:00	2017-02-14 14:00:00	\N
4548	04042C	REU_TRAV_PARL	2017-02-14 14:00:00	2017-02-14 15:30:00	Colloque commission culture sur le Maroc
4549	04042C	REU_TRAV_PARL	2017-02-15 19:00:00	2017-02-15 23:00:00	Grand dîner de la table française
4561	08010L	COLL_TER	2017-02-16 10:00:00	2017-02-16 14:00:00	Comité Directeur AMF
4601	14065Q	ELUS_LOCAUX	2016-09-09 09:00:00	2016-09-09 14:00:00	Journée des Maires à la foire européenne de Strasbourg
4621	14065Q	DEPL_PRES_GVT	2016-09-14 08:00:00	2016-09-14 20:00:00	Groupe d'amitié France-Estonie
4641	14065Q	DEPL_PRES_GVT	2016-09-15 08:00:00	2016-09-15 20:00:00	Groupe d'amitié France-Estonie
4642	14065Q	DEPL_PRES_GVT	2016-09-16 08:00:00	2016-09-16 20:00:00	Groupe d'amitié France-Estonie
4643	14065Q	COLL_TER	2016-09-19 09:00:00	2016-09-19 11:00:00	SCOTERS
4644	14065Q	ORG_POL	2016-09-20 09:00:00	2016-09-20 19:30:00	Séminaire de travail
4661	14065Q	ACC_VISIT	2016-09-20 14:30:00	2016-09-20 16:00:00	Elèves de l'INET
4681	08047A	REU_TRAV_PARL	2017-02-14 11:00:00	2017-02-14 13:00:00	REUNION LR
4701	04040A	REU_TRAV_PARL	2017-02-21 11:00:00	2017-02-21 12:00:00	Réunion de Groupe UDI-UC
4702	04040A	REU_TRAV_PARL	2017-02-21 14:30:00	2017-02-21 15:00:00	Réunion Brexit de l'UDI
4703	04040A	ORGEXTPAR	2017-02-23 11:00:00	2017-02-23 12:30:00	Table-ronde sur "le monde selon Donald Trump : politique étrangère et évolution du système international"
4704	04040A	ORGEXTPAR	2017-02-23 12:30:00	2017-02-23 13:30:00	Réception à l'occasion de la fête nationale d'Estonie
5241	14065Q	ACC_VISIT	2017-02-24 09:30:00	2017-02-24 10:30:00	\N
5242	14065Q	DEPL_PRES_GVT	2017-02-27 12:30:00	2017-02-27 14:00:00	M. Baylet
5243	14065Q	REU_TRAV_PARL	2017-02-27 14:30:00	2017-02-27 15:30:00	Clerc de notaire
5244	14065Q	CEREMONIE	2017-02-27 17:00:00	2017-02-27 19:00:00	Départ à la retraite
5261	04040A	ORGEXTPAR	2017-02-28 11:30:00	2017-02-28 14:00:00	Salon de l'agriculture - Stand Grand Est
5262	04040A	REU_GVT	2017-02-28 14:30:00	2017-02-28 17:00:00	Réunion commission livre blanc sur l¿immobilier pénitentiaire
5263	04040A	DEL_ACT_PAR	2017-02-28 19:30:00	2017-02-28 20:30:00	Bureau exécutif UDI
5264	04040A	ORGEXTPAR	2017-03-01 08:45:00	2017-03-01 11:45:00	Rencontre FITS - thème : "Intérêt et limites de l'externalisation en matière de défense et de sécurité"
5265	04040A	ACC_VISIT	2017-03-01 12:15:00	2017-03-01 13:00:00	 Entretien à la Présidence du Sénat à l'occasion de la venue du Pdt de DJIBOUTI  M. Ismaïl Omar GUELLEH
5266	04040A	REU_GVT	2017-03-01 14:30:00	2017-03-01 18:00:00	Réunion commission livre blanc sur l¿immobilier pénitentiaire
5601	14179A	ELUS_LOCAUX	2017-02-20 10:00:00	2017-02-20 10:00:00	\N
5602	14179A	ELUS_LOCAUX	2017-02-20 14:00:00	2017-02-20 14:00:00	\N
5603	14179A	ELUS_LOCAUX	2017-02-20 16:00:00	2017-02-20 16:00:00	\N
5604	14179A	COLL_TER	2017-02-20 19:00:00	2017-02-20 19:00:00	\N
5605	14179A	ELUS_LOCAUX	2017-02-21 12:00:00	2017-02-21 12:00:00	Intervention SIPERREC
5606	14179A	ORG_POL	2017-02-21 13:00:00	2017-02-21 13:00:00	\N
5621	14179A	ORG_POL	2017-02-21 20:00:00	2017-02-21 20:00:00	\N
5622	14179A	ELUS_LOCAUX	2017-02-24 11:00:00	2017-02-24 11:00:00	\N
5623	14179A	ELUS_LOCAUX	2017-02-24 12:30:00	2017-02-24 12:30:00	Entreprise Perroton et AURA
5624	14179A	COLL_TER	2017-02-24 16:30:00	2017-02-24 16:30:00	2CCAM
5625	14179A	ELUS_LOCAUX	2017-02-24 20:00:00	2017-02-24 20:00:00	Conférence EPL
5626	14179A	COLL_TER	2017-02-27 09:45:00	2017-02-27 09:45:00	CT 2CCAM
5627	14179A	ELUS_LOCAUX	2017-02-27 11:30:00	2017-02-27 11:30:00	Comité d'action Pollution
5628	14179A	COLL_TER	2017-02-27 17:00:00	2017-02-27 17:00:00	2CCAM
5629	14179A	ELUS_LOCAUX	2017-02-27 20:00:00	2017-02-27 20:00:00	CAUE Loi NOTRe
5630	14179A	ELUS_LOCAUX	2017-02-28 11:00:00	2017-02-28 11:00:00	Comité d'action Pollution
5631	14179A	COLL_TER	2017-03-01 08:00:00	2017-03-01 18:00:00	Flaine
5632	14179A	ELUS_LOCAUX	2017-03-02 12:00:00	2017-03-02 12:00:00	Funiflaine
5633	14179A	COLL_TER	2017-03-06 12:00:00	2017-03-06 12:00:00	Mairie de Marnaz
5634	14179A	COLL_TER	2017-03-06 18:30:00	2017-03-06 18:30:00	2CCAM
5635	14179A	COLL_TER	2017-03-06 22:00:00	2017-03-06 22:00:00	Mairie de Marnaz
5636	14179A	CEREMONIE	2017-03-07 20:00:00	2017-03-07 20:00:00	\N
5637	14179A	ACC_VISIT	2017-03-08 22:00:00	2017-03-08 22:00:00	\N
5638	14179A	ORG_POL	2017-03-09 09:30:00	2017-03-09 09:30:00	\N
5639	14179A	COLLOQUE	2017-03-09 15:00:00	2017-03-09 15:00:00	UNESCO
5640	14179A	CEREMONIE	2017-03-09 20:00:00	2017-03-09 20:00:00	\N
5641	14179A	COLL_TER	2017-03-10 18:00:00	2017-03-10 18:00:00	2CCAM
5642	14179A	ELUS_LOCAUX	2017-03-13 12:00:00	2017-03-13 12:00:00	\N
5643	14179A	COLL_TER	2017-03-13 17:00:00	2017-03-13 17:00:00	2CCAM
5644	14179A	COLL_TER	2017-03-13 22:00:00	2017-03-13 22:00:00	Mairie de Marnaz
5661	14179A	COLL_TER	2017-03-14 11:30:00	2017-03-14 11:30:00	Mairie de Marnaz
5662	14179A	COLL_TER	2017-03-14 22:00:00	2017-03-14 22:00:00	DSP Eau potable
5663	14179A	ELUS_LOCAUX	2017-03-15 11:00:00	2017-03-15 11:00:00	\N
5664	14179A	DEL_ACT_PAR	2017-03-15 16:00:00	2017-03-15 16:00:00	\N
5665	14179A	COLL_TER	2017-03-15 20:00:00	2017-03-15 20:00:00	2CCAM
5666	14179A	REU_TRAV_PARL	2017-03-16 09:30:00	2017-03-16 09:30:00	\N
5670	14179A	ELUS_LOCAUX	2017-03-17 16:00:00	2017-03-17 16:00:00	\N
5668	14179A	CEREMONIE	2017-03-16 13:00:00	2017-03-16 15:00:00	\N
5669	14179A	CEREMONIE	2017-03-17 12:00:00	2017-03-17 12:00:00	\N
5671	14179A	ELUS_LOCAUX	2017-03-17 20:00:00	2017-03-17 20:00:00	Conférence communes nouvelles
5672	14179A	CEREMONIE	2017-03-17 22:00:00	2017-03-17 22:00:00	\N
5673	14179A	COLL_TER	2017-03-20 12:00:00	2017-03-20 12:00:00	\N
5674	14179A	COLL_TER	2017-03-20 18:00:00	2017-03-20 18:00:00	Mairie de Marnaz
5904	14089Y	REU_TRAV_PARL	2017-04-25 12:00:00	2017-04-25 12:00:00	\N
5905	14089Y	CEREMONIE	2017-04-21 19:00:00	2017-04-21 19:00:00	\N
5906	14089Y	REU_TRAV_PARL	2017-04-18 13:00:00	2017-04-18 13:00:00	\N
5907	14089Y	REU_TRAV_PARL	2017-04-14 10:00:00	2017-04-14 10:00:00	\N
5961	08009T	ORG_POL	2017-05-09 11:00:00	2017-05-09 14:00:00	\N
5962	08009T	DEPL_PRES_GVT	2017-05-09 16:00:00	2017-05-09 23:00:00	\N
5963	08009T	REU_TRAV_PARL	2017-05-02 09:30:00	2017-05-02 10:30:00	\N
5964	08009T	REU_TRAV_PARL	2017-05-02 10:30:00	2017-05-02 11:30:00	\N
5965	08009T	REU_TRAV_PARL	2017-05-03 11:00:00	2017-05-03 12:00:00	\N
5730	08009T	DEPL_PRES_GVT	2017-03-09 00:01:00	2017-03-09 23:59:00	Tapei
5966	08009T	REU_TRAV_PARL	2017-05-03 15:30:00	2017-05-03 16:30:00	\N
5732	08009T	REU_TRAV_PARL	2017-03-15 10:30:00	2017-03-15 11:00:00	\N
5733	08009T	REU_TRAV_PARL	2017-03-15 11:00:00	2017-03-15 12:00:00	Goupe de travail aménagement du territoire
5734	08009T	REU_TRAV_PARL	2017-03-16 10:00:00	2017-03-16 11:00:00	\N
5735	08009T	REU_TRAV_PARL	2017-03-16 11:00:00	2017-03-16 12:00:00	\N
5736	08009T	REU_TRAV_PARL	2017-03-16 12:00:00	2017-03-16 13:00:00	\N
5737	08009T	REU_TRAV_PARL	2017-03-22 09:00:00	2017-03-22 11:00:00	Groupe de travail Aménagement du territoire
5967	08009T	REU_TRAV_PARL	2017-05-04 11:00:00	2017-05-04 12:00:00	\N
5968	08009T	REU_TRAV_PARL	2017-05-09 12:00:00	2017-05-09 13:00:00	\N
5969	08009T	ORG_POL	2017-04-25 12:00:00	2017-04-25 14:00:00	\N
6001	08009T	ORGEXTPAR	2017-04-27 09:00:00	2017-04-27 12:00:00	Conseil de surveillance SNCF
5981	08009T	ORG_POL	2017-04-25 18:30:00	2017-04-25 19:30:00	\N
6002	08009T	ORGEXTPAR	2017-04-19 10:00:00	2017-04-19 11:30:00	Conseil de surveillance extraordinaire SNCF
6005	08009T	ORG_POL	2017-03-21 11:00:00	2017-03-21 14:00:00	\N
6004	08009T	REU_TRAV_PARL	2017-04-19 19:00:00	2017-04-19 20:00:00	conférence de presse
6021	08009T	DEPL_PRES_GVT	2017-02-28 09:00:00	2017-02-28 17:00:00	\N
6022	08009T	ORG_POL	2017-02-28 18:30:00	2017-02-28 20:30:00	\N
6023	08009T	DEPL_PRES_GVT	2017-03-01 09:30:00	2017-03-01 12:30:00	\N
6041	08009T	DEPL_PRES_GVT	2017-05-10 00:01:00	2017-05-10 23:59:00	\N
6224	08009T	ORG_POL	2017-06-27 11:00:00	2017-06-27 13:00:00	\N
6225	08009T	ORGEXTPAR	2017-06-22 09:00:00	2017-06-22 12:00:00	\N
6223	08009T	REU_TRAV_PARL	2017-06-27 17:00:00	2017-06-27 18:00:00	\N
6226	08009T	REU_TRAV_PARL	2017-06-29 16:00:00	2017-06-29 17:00:00	\N
6227	08009T	REU_TRAV_PARL	2017-06-21 18:30:00	2017-06-21 19:30:00	\N
6228	08009T	REU_TRAV_PARL	2017-06-21 16:30:00	2017-06-21 17:30:00	\N
6229	08009T	DEPL_PRES_GVT	2017-06-21 09:30:00	2017-06-21 15:00:00	\N
6230	08009T	REU_TRAV_PARL	2017-06-20 09:30:00	2017-06-20 10:30:00	\N
6231	08009T	ORG_POL	2017-06-20 11:00:00	2017-06-20 13:00:00	\N
6232	08009T	ACC_VISIT	2017-06-20 13:00:00	2017-06-20 14:00:00	\N
6233	08009T	REU_TRAV_PARL	2017-06-20 17:45:00	2017-06-20 18:45:00	\N
6234	08009T	ORG_POL	2017-06-20 19:00:00	2017-06-20 20:30:00	\N
6235	08009T	REU_TRAV_PARL	2017-06-06 12:00:00	2017-06-06 13:00:00	\N
6236	08009T	REU_TRAV_PARL	2017-06-06 14:00:00	2017-06-06 16:00:00	\N
6237	08009T	REU_TRAV_PARL	2017-05-30 14:30:00	2017-05-30 15:30:00	\N
6238	08009T	REU_TRAV_PARL	2017-05-30 15:30:00	2017-05-30 16:00:00	\N
6239	08009T	REU_TRAV_PARL	2017-05-30 11:30:00	2017-05-30 12:00:00	\N
6245	08009T	REU_TRAV_PARL	2017-05-16 10:30:00	2017-05-16 11:30:00	\N
6244	08009T	REU_TRAV_PARL	2017-05-16 09:30:00	2017-05-16 10:30:00	\N
6243	08009T	ORG_POL	2017-05-23 11:00:00	2017-05-23 12:00:00	\N
6246	08009T	ACC_VISIT	2017-05-16 11:30:00	2017-05-16 12:00:00	\N
6247	08009T	REU_TRAV_PARL	2017-05-17 08:30:00	2017-05-17 09:30:00	\N
4261	08010L	REU_TRAV_PARL	2017-02-07 11:00:00	2017-02-07 12:30:00	\N
4403	04042C	COLL_TER	2017-02-10 17:00:00	2017-02-10 17:30:00	Logement
4282	04042C	ORG_POL	2017-02-09 16:00:00	2017-02-09 17:00:00	\N
4283	04042C	ACC_VISIT	2017-02-09 18:30:00	2017-02-09 19:30:00	Au Sénat cérémonie de remise de Légion d'Honneur
4301	04042C	ACC_DEPL_INTER	2017-02-09 20:00:00	2017-02-09 20:30:00	Ambassade du Maroc en France
4341	04042C	COLL_TER	2016-10-14 16:00:00	2016-10-14 17:00:00	Emploi
4381	08009T	REU_TRAV_PARL	2017-02-07 11:00:00	2017-02-07 12:30:00	Réunion de groupe - UDI
4382	08009T	REU_TRAV_PARL	2017-02-07 14:30:00	2017-02-07 15:30:00	Point commission
4401	04042C	COLL_TER	2017-02-10 16:00:00	2017-02-10 16:30:00	Conseil des Séniors de Saint-Maurice
4402	04042C	ELUS_LOCAUX	2017-02-10 16:30:00	2017-02-10 17:00:00	Association sportive
4404	04042C	COLL_TER	2017-02-10 17:30:00	2017-02-10 18:00:00	\N
4405	04042C	ACC_VISIT	2017-02-10 18:45:00	2017-02-10 22:00:00	Visite du Sénat des élus de Vincennes
4421	08047A	ORG_POL	2017-02-07 11:00:00	2017-02-07 13:00:00	REUNION SIEGE LR
4422	08047A	REU_TRAV_PARL	2017-02-07 14:30:00	2017-02-07 18:00:00	SEANCE
5121	14089Y	REU_TRAV_PARL	2017-02-23 12:00:00	2017-02-23 13:00:00	\N
5141	14089Y	REU_TRAV_PARL	2017-03-03 10:00:00	2017-03-03 11:00:00	\N
5161	04042C	COLL_TER	2017-02-20 08:30:00	2017-02-20 10:00:00	avec le Préfet du Val-de-Marne et la rectrice de l'académie de Créteil
5162	04042C	COLL_TER	2017-02-20 11:00:00	2017-02-20 12:00:00	Réunion de direction
5163	04042C	REU_TRAV_PARL	2017-02-20 17:00:00	2017-02-20 18:00:00	\N
5164	04042C	COLL_TER	2017-02-20 18:30:00	2017-02-20 22:00:00	Conseil Municipal
5165	04042C	ORG_POL	2017-02-21 11:00:00	2017-02-21 12:30:00	Groupe LR du Sénat
5181	04042C	CEREMONIE	2017-02-21 20:00:00	2017-02-21 21:00:00	Remise de Légion d'Honneur
5182	04042C	REU_TRAV_PARL	2017-02-21 21:00:00	2017-02-21 23:00:00	Groupe LR du Sénat
5183	04042C	ORG_POL	2017-02-22 11:30:00	2017-02-22 12:30:00	autour de François Fillon
5184	04042C	REU_TRAV_PARL	2017-02-22 13:00:00	2017-02-22 14:30:00	\N
5185	04042C	ACC_VISIT	2017-02-22 14:30:00	2017-02-22 15:00:00	Conseil Municipal des Jeunes de Rungis
5186	04042C	ACC_VISIT	2017-02-22 18:45:00	2017-02-22 21:00:00	Elus du Val-de-Marne
5187	04042C	REU_GVT	2017-02-22 21:00:00	2017-02-22 22:30:00	fin de session parlementaire avec le Ministre de la Défense
5188	04042C	ACC_VISIT	2017-02-23 13:00:00	2017-02-23 15:00:00	Directions EDF du Val-de-Marne
5189	04042C	ACC_VISIT	2017-02-23 18:30:00	2017-02-23 20:00:00	Remise de Légion d'Honneur
5190	04042C	ELUS_LOCAUX	2017-02-23 20:00:00	2017-02-23 23:00:00	Débat sur le thème du transport en Ile-de-France
5561	08010L	REU_TRAV_PARL	2017-04-04 14:00:00	2017-04-04 14:00:00	\N
5581	14089Y	REU_TRAV_PARL	2017-03-27 14:00:00	2017-03-27 14:00:00	\N
5582	14089Y	REU_TRAV_PARL	2017-03-27 15:30:00	2017-03-27 15:30:00	\N
5583	14089Y	ELUS_LOCAUX	2017-03-27 16:30:00	2017-03-27 16:30:00	\N
5584	14089Y	ELUS_LOCAUX	2017-03-27 20:00:00	2017-03-27 20:00:00	\N
5585	14089Y	ELUS_LOCAUX	2017-04-03 15:00:00	2017-04-03 15:00:00	\N
5586	14089Y	COLL_TER	2017-04-03 17:00:00	2017-04-03 17:00:00	\N
5587	14089Y	COLL_TER	2017-04-06 14:00:00	2017-04-06 14:00:00	\N
5588	14089Y	REU_TRAV_PARL	2017-04-07 16:00:00	2017-04-07 16:00:00	\N
5589	14089Y	REU_TRAV_PARL	2017-04-07 16:00:00	2017-04-07 16:30:00	\N
5681	14179A	COLL_TER	2017-03-27 14:30:00	2017-03-27 14:30:00	Mairie de Marnaz
5682	14179A	COLL_TER	2017-03-27 17:00:00	2017-03-27 17:00:00	2CCAM
5683	14179A	COLL_TER	2017-03-27 22:00:00	2017-03-27 22:00:00	Mairie de Marnaz
5684	14179A	ELUS_LOCAUX	2017-03-28 12:00:00	2017-03-28 21:00:00	Canton Annemasse Gaillard
5685	14179A	REU_TRAV_PARL	2017-03-29 11:00:00	2017-03-29 11:00:00	Assises Numériques
5686	14179A	CEREMONIE	2017-03-29 12:00:00	2017-03-29 12:00:00	\N
5687	14179A	COLL_TER	2017-03-29 22:00:00	2017-03-29 22:00:00	Mairie de Marnaz
5688	14179A	COLL_TER	2017-03-30 10:00:00	2017-03-30 10:00:00	Mairie de Marnaz
5689	14179A	ORG_POL	2017-03-30 11:00:00	2017-03-30 11:00:00	\N
5690	14179A	ELUS_LOCAUX	2017-03-30 15:30:00	2017-03-30 17:30:00	CDCI
5691	14179A	CEREMONIE	2017-03-30 18:00:00	2017-03-30 19:00:00	\N
5692	14179A	CEREMONIE	2017-03-30 19:00:00	2017-03-30 21:00:00	\N
5693	14179A	COLL_TER	2017-03-31 09:00:00	2017-03-31 10:00:00	2CCAM
5694	14179A	ELUS_LOCAUX	2017-03-31 12:00:00	2017-03-31 15:00:00	CC du Giffre
5695	14179A	ELUS_LOCAUX	2017-03-31 16:00:00	2017-03-31 17:00:00	Visite ACER avec AURA
5696	14179A	CEREMONIE	2017-03-31 17:30:00	2017-03-31 22:00:00	\N
5697	14179A	DEPL_PRES_GVT	2017-04-03 08:00:00	2017-04-03 22:00:00	Groupe d'amitié France Québec
5698	14179A	DEPL_PRES_GVT	2017-04-04 08:00:00	2017-04-04 22:00:00	Groupe d'amitié France Québec
5699	14179A	DEPL_PRES_GVT	2017-04-05 08:00:00	2017-04-05 22:00:00	Groupe d'amitié France Québec
5700	14179A	DEPL_PRES_GVT	2017-04-06 08:00:00	2017-04-06 22:00:00	Groupe d'amitié France Québec
5701	14179A	DEPL_PRES_GVT	2017-04-07 08:00:00	2017-04-07 22:00:00	Groupe d'amitié France Québec
5702	14179A	COLL_TER	2017-04-10 08:45:00	2017-04-10 10:00:00	Mairie de Marnaz
5703	14179A	COLL_TER	2017-04-10 13:15:00	2017-04-10 16:00:00	2CCAM
5704	14179A	ELUS_LOCAUX	2017-04-10 18:00:00	2017-04-10 20:00:00	Fonds Air Industrie
5705	14179A	ELUS_LOCAUX	2017-04-11 09:30:00	2017-04-11 22:00:00	Canton de Saint Julien
6248	08009T	REU_TRAV_PARL	2017-05-17 09:30:00	2017-05-17 10:30:00	\N
6249	08009T	REU_TRAV_PARL	2017-05-17 10:30:00	2017-05-17 11:30:00	\N
6250	08009T	REU_TRAV_PARL	2017-05-17 11:30:00	2017-05-17 12:30:00	\N
6251	08009T	REU_TRAV_PARL	2017-05-18 11:30:00	2017-05-18 12:30:00	\N
6252	08009T	REU_TRAV_PARL	2017-05-18 15:00:00	2017-05-18 16:00:00	\N
5764	08009T	REU_TRAV_PARL	2017-04-05 15:30:00	2017-04-05 16:30:00	Audition - offres de soins primaires dans les zones sous dotées
5763	08009T	REU_TRAV_PARL	2017-04-05 10:00:00	2017-04-05 11:00:00	Entretien avec Gérard Larcher
5781	11063M	REU_TRAV_PARL	2017-02-15 14:00:00	2017-02-15 16:00:00	Rencontre à Bercy sur le devenir de Faurecia
5782	11063M	ORG_POL	2017-02-15 16:30:00	2017-02-15 18:00:00	Réunion avec la commission Santé du PCF
5783	11063M	ACC_VISIT	2017-02-17 18:00:00	2017-02-17 18:00:00	Réception de l'Institut Universitaire Varenne sur la question des mineurs grévistes de 1948
5784	11063M	REU_TRAV_PARL	2017-02-24 12:00:00	2017-02-24 12:00:00	REncontre avec le directeur départemental de Pôle Emploi
5785	11063M	REU_TRAV_PARL	2017-02-24 17:00:00	2017-02-24 17:00:00	Réunion avec la CARMI
5786	11063M	ORG_POL	2017-03-06 12:00:00	2017-03-06 12:00:00	Formation CIDEFE autour de la Loi Adaptation de la Société au Vieillissement
5787	11063M	COLLOQUE	2017-03-09 14:00:00	2017-03-09 19:00:00	Rencontre nationale des Acteurs de l'Aide à Domicile - Salle Monnerville
5788	11063M	REU_TRAV_PARL	2017-03-23 21:00:00	2017-03-23 21:00:00	Visite Isère autour des questions de Santé
5789	11063M	REU_TRAV_PARL	2017-03-24 21:00:00	2017-03-24 21:00:00	Visite Isère autour des questions de Santé
5790	11063M	REU_TRAV_PARL	2017-03-28 12:00:00	2017-03-28 12:00:00	RDV avec Philippe Vasseur, Haut Commissaire à la réindustrialisation dans les HdF autour du cas ArjoWiggins
5791	11063M	ORG_POL	2017-03-30 11:00:00	2017-03-30 12:00:00	Participation à la manifestation des retraités à Lens
5792	11063M	ORG_POL	2017-03-30 14:30:00	2017-03-30 15:30:00	Participation à la manifestation des retraités à Arras
5793	11063M	ELUS_LOCAUX	2017-03-30 18:00:00	2017-03-30 20:00:00	RDV avec les services de la Préfecture de Région autour des engagements du gouvernement pour le Bassin Minier
5794	11063M	ELUS_LOCAUX	2017-03-31 11:00:00	2017-03-31 12:00:00	Soutien au Comité anti-expulsion locatives de la ville d'Avion
5795	11063M	ORG_POL	2017-03-31 20:00:00	2017-03-31 22:00:00	Débat autour de la projection du film La Sociale
5796	11063M	REU_TRAV_PARL	2017-04-04 14:00:00	2017-04-04 15:00:00	Rassemblement devant l'hôpital de Lens avec les Sénatrices CRC de la Commission des Affaires Sociales
5797	11063M	REU_TRAV_PARL	2017-04-04 16:30:00	2017-04-04 17:30:00	Visite du Centre de Santé Filieris de Méricourt avec les Sénatrices CRC de la Commission des Affaires Sociales
5801	11063M	ELUS_LOCAUX	2017-04-04 18:00:00	2017-04-04 20:00:00	Réunion avec les élus du Bassin Minier avec les Sénatrices CRC de la Commission des Affaires Sociales
5802	11063M	ELUS_LOCAUX	2017-04-05 09:30:00	2017-04-05 10:30:00	Rencontre avec le maire d'Annequin - Visite des sénatrices CRC aux Affaires Sociales
5821	11063M	ELUS_LOCAUX	2017-04-05 11:00:00	2017-04-05 12:00:00	Rencontre avec le maire de Roquetoire - Visite des sénatrices CRC aux Affaires Sociales
4848	14065Q	ACC_VISIT	2016-11-07 10:00:00	2016-11-07 14:00:00	Amicale 52
4849	14065Q	ORG_POL	2016-11-08 11:00:00	2016-11-08 13:00:00	\N
5822	11063M	REU_TRAV_PARL	2017-04-05 14:00:00	2017-04-05 16:00:00	Rencontre avec les salariés d'ArjoWiggins - Visite des sénatrices CRC aux Affaires Sociales
5823	11063M	COLL_TER	2017-04-06 10:00:00	2017-04-06 14:00:00	Réunion avec les conseillers généraux du Nord autour de l'aide à domicile
5824	11063M	REU_TRAV_PARL	2017-04-12 14:00:00	2017-04-12 18:00:00	Débat sur la loi Adaptation de la Société au Vieillissement en Isère
6421	11029K	REU_TRAV_PARL	2017-06-30 11:00:00	2017-06-30 11:00:00	Visite Saint Barthélémy d'Anjou Maison de l'enfance et rendez-vous en mairie
6422	11029K	REU_TRAV_PARL	2017-06-30 12:00:00	2017-06-30 12:00:00	\N
6425	11029K	REU_TRAV_PARL	2017-06-19 10:30:00	2017-06-19 10:30:00	\N
4072	04042C	COLL_TER	2016-01-18 11:00:00	2016-01-18 12:30:00	Réunion de direction
4073	04042C	ELUS_LOCAUX	2016-01-18 13:00:00	2016-01-18 14:30:00	\N
4074	04042C	COLL_TER	2016-01-18 16:00:00	2016-01-18 17:00:00	des services techniques
4075	04042C	COLL_TER	2016-01-18 17:00:00	2016-01-18 18:00:00	Galette du personnel de la Mairie
4076	04042C	ACC_DEPL_INTER	2016-01-18 18:30:00	2016-01-18 20:00:00	Ambassade du Maroc en France
4102	11053K	ORG_POL	2017-01-31 11:00:00	2017-01-31 13:00:00	Réunion de groupe UDI-UC
4103	04042C	ACC_VISIT	2016-01-08 10:00:00	2016-01-08 11:30:00	Visite du Sénat d'un collège de L'Haÿ-les-Roses
4104	04042C	COLL_TER	2016-01-08 16:00:00	2016-01-08 16:30:00	Problèmes de sécurité
4105	04042C	COLL_TER	2016-01-08 16:30:00	2016-01-08 17:00:00	Affaires sociales
4106	04042C	ELUS_LOCAUX	2016-01-08 17:00:00	2016-01-08 17:30:00	\N
4107	04042C	ELUS_LOCAUX	2016-01-08 18:30:00	2016-01-08 19:30:00	Cérémonie des voeux du Plessis-Trévise
4108	04042C	ELUS_LOCAUX	2016-01-08 19:30:00	2016-01-08 20:00:00	Cérémonie des voeux d'Ablon
4115	04042C	ORG_POL	2015-12-14 11:00:00	2015-12-14 13:00:00	Bureau politique LR du Val-de-Marne
4116	04042C	COLL_TER	2015-12-14 15:00:00	2015-12-14 16:00:00	Stationnement
4117	04042C	COLL_TER	2015-12-14 16:00:00	2015-12-14 16:30:00	Logement
4118	04042C	REU_TRAV_PARL	2015-12-14 17:00:00	2015-12-14 17:30:00	Débat dur la chaîne parlementaire Public Sénat
4119	04042C	ELUS_LOCAUX	2015-12-14 18:00:00	2015-12-14 21:00:00	Cérémonie des voeux du Syndicat des Eaux d'Ile-de-France
4120	04042C	COLL_TER	2015-12-11 10:00:00	2015-12-11 12:00:00	PLU
4121	04042C	COLL_TER	2015-12-11 16:30:00	2015-12-11 17:00:00	Urbanisme
4122	04042C	COLL_TER	2015-12-11 17:00:00	2015-12-11 18:00:00	occupation illégale de locaux
4141	04042C	ORG_POL	2015-12-07 11:00:00	2015-12-07 13:00:00	Bureau politique LR
4142	04042C	COLL_TER	2015-12-07 16:00:00	2015-12-07 17:00:00	services techniques
4143	04042C	COLL_TER	2015-12-07 17:00:00	2015-12-07 18:00:00	logements sociaux
4144	04042C	COLL_TER	2015-12-07 18:00:00	2015-12-07 19:00:00	Comité de suivi du Projet Educatif Territorial
4145	04042C	ELUS_LOCAUX	2015-12-04 08:30:00	2015-12-04 11:00:00	Bureau du syndicat des Eaux d'Ile-de-France
4146	04042C	REU_TRAV_PARL	2015-12-04 11:30:00	2015-12-04 12:30:00	\N
4147	04042C	ACC_DEPL_INTER	2015-12-04 15:00:00	2015-12-04 16:00:00	à la Présidence du Sénat - rencontre avec le Président de l'Assemblée nationale du Mali
4148	04042C	COLL_TER	2015-12-04 16:30:00	2015-12-04 17:00:00	\N
4149	04042C	COLL_TER	2015-12-04 17:00:00	2015-12-04 17:30:00	\N
4150	04042C	ACC_DEPL_INTER	2015-12-04 18:00:00	2015-12-04 20:00:00	Ambassade des Etats-Unis en France
4151	04042C	ELUS_LOCAUX	2015-11-30 08:15:00	2015-11-30 10:30:00	avec les Maires du Territoire T10
4152	04042C	COLL_TER	2015-11-30 18:00:00	2015-11-30 19:00:00	Protection civile
4153	04042C	COLL_TER	2015-11-30 19:00:00	2015-11-30 21:00:00	Conseil de communauté de communes
4154	04042C	REU_GVT	2015-11-27 10:00:00	2015-11-27 12:00:00	Hommage national aux victimes des attaques terroristes
4155	04042C	ELUS_LOCAUX	2015-11-27 13:00:00	2015-11-27 14:30:00	Syndicat des Eaux d'Ile-de-France
4156	04042C	ORG_POL	2015-11-27 17:00:00	2015-11-27 18:00:00	\N
4157	04042C	COLL_TER	2015-11-27 18:00:00	2015-11-27 19:00:00	Hôpitaux de Saint-Maurice
4161	04042C	COLL_TER	2015-11-27 19:00:00	2015-11-27 21:00:00	Conseil municipal extraordinaire
4181	04042C	ELUS_LOCAUX	2015-11-23 08:15:00	2015-11-23 10:00:00	Maires du T10
4182	04042C	COLL_TER	2015-11-23 11:00:00	2015-11-23 12:30:00	Réunion de direction
4183	04042C	COLL_TER	2015-11-23 15:00:00	2015-11-23 16:00:00	Comité technique
4184	04042C	COLL_TER	2015-11-23 16:00:00	2015-11-23 17:00:00	CHSCT
4185	04042C	COLL_TER	2015-11-23 17:00:00	2015-11-23 18:00:00	sur le marché de Saint-Maurice
4186	04042C	COLL_TER	2015-11-23 19:00:00	2015-11-23 20:00:00	Conférences sur les gestes qui sauvent
4187	04042C	ELUS_LOCAUX	2015-11-23 20:00:00	2015-11-23 22:00:00	Débat à Vitry
4188	04042C	COLL_TER	2015-11-20 10:00:00	2015-11-20 10:30:00	commerçants
4189	04042C	COLL_TER	2015-11-20 10:30:00	2015-11-20 11:00:00	petite enfance
4190	04042C	ELUS_LOCAUX	2015-11-20 11:00:00	2015-11-20 11:30:00	\N
4191	04042C	ELUS_LOCAUX	2015-11-20 11:30:00	2015-11-20 12:00:00	\N
4192	04042C	COLL_TER	2015-11-20 13:00:00	2015-11-20 14:30:00	logements sociaux
4193	04042C	COLL_TER	2015-11-20 18:00:00	2015-11-20 19:00:00	Conseil Municipal extraordinaire
4194	04042C	ACC_VISIT	2015-11-20 19:00:00	2015-11-20 20:30:00	Réception des médaillés du travail
4195	04042C	COLL_TER	2015-11-16 11:00:00	2015-11-16 13:00:00	Réunion de direction
4196	04042C	COLL_TER	2015-11-13 08:00:00	2015-11-13 10:00:00	Maire du futur EPT 10
4197	04042C	COLL_TER	2015-11-13 11:00:00	2015-11-13 12:00:00	urbanisme
4198	04042C	COLL_TER	2015-11-13 16:00:00	2015-11-13 16:30:00	sécurité
4199	04042C	COLL_TER	2015-11-13 16:30:00	2015-11-13 17:00:00	logement d'urgence
4200	04042C	COLL_TER	2015-11-13 17:00:00	2015-11-13 17:30:00	ACTEP
4201	04042C	COLL_TER	2015-11-13 17:30:00	2015-11-13 18:30:00	transport - pédibus
4781	14065Q	ORGEXTPAR	2016-09-26 10:00:00	2016-09-26 11:00:00	Commission du droit local d'Alsace Moselle
4782	14065Q	ORG_POL	2016-09-27 11:00:00	2016-09-27 13:00:00	\N
4783	14065Q	CEREMONIE	2016-09-28 12:00:00	2016-09-28 13:00:00	\N
4784	14065Q	ORG_POL	2016-09-28 14:00:00	2016-09-28 14:30:00	\N
4801	14065Q	REU_TRAV_PARL	2016-09-29 08:30:00	2016-09-29 10:30:00	sur la PPL Prescription en matière pénale
4802	14065Q	COLL_TER	2016-09-30 19:30:00	2016-09-30 21:30:00	SCOTERS
4803	14065Q	ORG_POL	2016-10-04 11:00:00	2016-10-04 13:00:00	\N
4804	14065Q	REU_TRAV_PARL	2016-10-04 14:30:00	2016-10-04 16:30:00	sur la PPL Prescription en matière pénale
4821	14065Q	ORGEXTPAR	2016-10-04 18:30:00	2016-10-04 20:30:00	UIP
4822	14065Q	ORG_POL	2016-10-05 09:00:00	2016-10-05 09:30:00	\N
4823	14065Q	COLL_TER	2016-10-10 09:00:00	2016-10-10 10:00:00	SCOTERS
4824	14065Q	DEPL_PRES_GVT	2016-10-10 10:00:00	2016-10-10 14:00:00	Mme Vallaud-Belkacem
4841	14065Q	ACC_VISIT	2016-10-12 12:30:00	2016-10-12 17:00:00	APAVIG
4842	14065Q	COLL_TER	2016-10-14 18:00:00	2016-10-14 20:00:00	SCOTERS
4843	14065Q	ELUS_LOCAUX	2016-10-17 10:30:00	2016-10-17 11:00:00	Echange avec un Maire
4844	14065Q	ORGEXTPAR	2016-10-18 09:30:00	2016-10-18 12:30:00	ONDRP
4845	14065Q	ORG_POL	2016-10-19 10:45:00	2016-10-19 14:00:00	FNESR
4846	14065Q	COLL_TER	2016-10-21 14:30:00	2016-10-21 16:30:00	SCOTERS
4847	14065Q	COLL_TER	2016-10-27 09:00:00	2016-10-27 10:00:00	\N
4850	14065Q	CEREMONIE	2016-11-11 11:00:00	2016-11-11 12:00:00	\N
4851	14065Q	ELUS_LOCAUX	2016-11-14 18:30:00	2016-11-14 20:30:00	Association des Maires du Bas-Rhin
4852	14065Q	ORG_POL	2016-11-15 11:00:00	2016-11-15 13:00:00	\N
4853	14065Q	ACC_VISIT	2016-11-16 12:00:00	2016-11-16 17:00:00	Lion's
4854	14065Q	COLL_TER	2016-11-18 14:30:00	2016-11-18 16:00:00	\N
4855	14065Q	ORG_POL	2016-11-22 11:00:00	2016-11-22 13:00:00	\N
4856	14065Q	COLL_TER	2016-11-25 10:00:00	2016-11-25 12:00:00	Institut du droit local d'Alsace Moselle
4861	14065Q	COLL_TER	2016-11-28 09:00:00	2016-11-28 11:00:00	SCOTERS
4862	14065Q	REU_TRAV_PARL	2016-11-29 15:00:00	2016-11-29 17:00:00	PJL Montagne
4863	14065Q	ORG_POL	2016-11-29 11:00:00	2016-11-29 13:00:00	\N
4864	14065Q	ORG_POL	2016-11-30 09:45:00	2016-11-30 10:00:00	\N
4865	14065Q	ORG_POL	2016-12-01 14:30:00	2016-12-01 15:00:00	\N
4866	14065Q	ELUS_LOCAUX	2016-12-02 09:30:00	2016-12-02 14:30:00	Association des Maires du Bas-Rhin
4867	14065Q	ELUS_LOCAUX	2016-12-05 09:00:00	2016-12-05 12:30:00	Echange avec des Maires
4868	14065Q	ORG_POL	2016-12-06 11:00:00	2016-12-06 13:00:00	\N
4869	14065Q	ORG_POL	2016-12-06 17:00:00	2016-12-06 18:00:00	\N
4870	14065Q	ACC_VISIT	2016-12-07 10:00:00	2016-12-07 14:00:00	Conseil municipal des enfants
4881	14065Q	ELUS_LOCAUX	2016-12-08 09:00:00	2016-12-08 10:00:00	Mission de suivi de la réforme territoriale
4901	14065Q	ELUS_LOCAUX	2016-12-09 17:30:00	2016-12-09 18:30:00	Echange avec des Maires
4921	14065Q	ELUS_LOCAUX	2016-12-09 09:00:00	2016-12-09 10:00:00	Echange avec un Maire
4941	14065Q	ORG_POL	2016-12-13 11:00:00	2016-12-13 13:00:00	\N
4942	14065Q	ELUS_LOCAUX	2016-12-13 18:00:00	2016-12-13 19:00:00	Institut du Sénat
4943	14065Q	REU_TRAV_PARL	2016-12-14 13:00:00	2016-12-14 14:00:00	\N
4944	14065Q	ACC_VISIT	2016-12-16 14:30:00	2016-12-16 16:30:00	Conférence à la faculté de droit
4945	14065Q	DEPL_PRES_GVT	2016-12-22 10:00:00	2016-12-22 14:00:00	Mme Grelier
4946	14065Q	ELUS_LOCAUX	2017-01-03 11:00:00	2017-01-03 14:00:00	Echange avec des Maires
4947	14065Q	ORGEXTPAR	2017-01-09 09:00:00	2017-01-09 12:00:00	Commission du droit local d'Alsace Moselle
4948	14065Q	COLL_TER	2017-01-09 14:30:00	2017-01-09 16:00:00	SCOTERS
4949	14065Q	REU_GVT	2017-01-09 16:00:00	2017-01-09 17:00:00	sur le PJL Sécurité publique
4950	14065Q	ORG_POL	2017-01-10 11:00:00	2017-01-10 13:00:00	\N
4951	14065Q	DEPL_PRES_GVT	2017-01-11 08:30:00	2017-01-11 09:30:00	Groupe d'amitié France-Madagascar
4952	14065Q	ELUS_LOCAUX	2017-01-13 08:00:00	2017-01-13 17:30:00	Tournage Public Sénat
4953	14065Q	CEREMONIE	2017-01-13 18:00:00	2017-01-13 19:30:00	Voeux du préfet
4954	14065Q	ELUS_LOCAUX	2017-01-16 16:30:00	2017-01-16 17:00:00	Tournage Public Sénat
4955	14065Q	ORG_POL	2017-01-17 11:00:00	2017-01-17 13:00:00	\N
4956	14065Q	ORGEXTPAR	2017-01-17 12:30:00	2017-01-17 16:00:00	Commission du droit local d'Alsace Moselle
4957	14065Q	ELUS_LOCAUX	2017-01-18 10:00:00	2017-01-18 11:00:00	\N
4958	14065Q	REU_TRAV_PARL	2017-01-18 11:00:00	2017-01-18 11:30:00	\N
4959	14065Q	ORGEXTPAR	2017-01-23 09:30:00	2017-01-23 19:00:00	APCE
4960	14065Q	ORG_POL	2017-01-24 11:00:00	2017-01-24 13:00:00	\N
6981	08010L	ORG_POL	2017-09-27 10:30:00	2017-09-27 14:00:00	Groupe LR du sénat
7121	87003B	ORG_POL	2017-10-10 12:30:00	2017-10-10 12:30:00	\N
7122	87003B	REU_TRAV_PARL	2017-10-11 11:00:00	2017-10-11 12:00:00	Commission de la culture
7123	87003B	REU_TRAV_PARL	2017-10-11 14:30:00	2017-10-11 14:30:00	Bureau de la commission de la culture
7161	11040E	COLL_TER	2017-10-12 10:00:00	2017-10-12 15:00:00	congrès des maires du Nord
7162	11040E	REU_TRAV_PARL	2017-10-11 12:30:00	2017-10-11 14:30:00	Préparation PLF 2018
7163	11040E	REU_TRAV_PARL	2017-10-23 13:00:00	2017-10-23 14:00:00	Permanence Secrétariat du Sénat
7164	11040E	REU_TRAV_PARL	2017-10-31 14:00:00	2017-10-31 15:00:00	Permanence Secrétariat du Sénat
7263	19707Y	ORG_POL	2017-10-17 11:00:00	2017-10-17 12:30:00	\N
7265	19707Y	ORG_POL	2017-10-31 09:30:00	2017-10-31 12:00:00	\N
7264	19707Y	ORG_POL	2017-10-24 11:00:00	2017-10-24 12:30:00	\N
7266	19705W	ORG_POL	2017-10-17 11:00:00	2017-10-17 12:30:00	\N
7267	19705W	ORG_POL	2017-10-31 09:30:00	2017-10-31 12:00:00	\N
7268	19705W	ORG_POL	2017-10-24 11:00:00	2017-10-24 12:30:00	\N
7302	14327T	CEREMONIE	2017-10-09 19:00:00	2017-10-09 19:00:00	Inauguration extension ZA de Vic sur Cère
7303	14327T	CEREMONIE	2017-09-01 12:00:00	2017-09-01 12:00:00	Inauguration cabinet médical de Polminhac
7304	14327T	COLL_TER	2017-09-04 22:30:00	2017-09-04 22:30:00	réunion du conseil municipal d'Allanche
7305	14327T	REU_TRAV_PARL	2017-09-06 12:00:00	2017-09-06 12:00:00	Visite du chantier d'insertion de Riom ès Montagnes
7306	14327T	CEREMONIE	2017-09-11 20:00:00	2017-09-11 20:00:00	Remise du label Petites cités de caractère à la commune de Pleaux
7307	14327T	REU_TRAV_PARL	2017-09-18 16:00:00	2017-09-18 16:00:00	Présentation de la loi montagne aux étudiants de l'IADT à Clermont Ferrand
7308	14327T	COLL_TER	2017-09-18 23:00:00	2017-09-18 23:00:00	Réunion avec le conseil municipal de Valuéjols
7309	14327T	COLL_TER	2017-09-29 17:00:00	2017-09-29 17:00:00	Session au conseil départemental
7310	14327T	REU_TRAV_PARL	2017-10-11 09:30:00	2017-10-11 09:30:00	Réunion avec les parlementaires de la montagne
7311	14327T	ELUS_LOCAUX	2017-10-13 16:00:00	2017-10-13 16:00:00	Table ronde sur la démographie dans le Cantal
7312	14327T	COLL_TER	2017-10-13 21:00:00	2017-10-13 21:00:00	Réunion avec le CM d'Albepierre-Bredons
7313	14327T	REU_TRAV_PARL	2017-10-16 13:00:00	2017-10-16 13:00:00	Réunion sur la situation du réseau Gîtes de France
7314	14327T	COLL_TER	2017-10-16 22:30:00	2017-10-16 22:30:00	Réunion avec le conseil municipal de Velzic
7315	14327T	REU_TRAV_PARL	2017-10-19 11:30:00	2017-10-19 11:30:00	Réunion sur la situation des centimes forestiers
7316	14327T	ELUS_LOCAUX	2017-10-20 15:00:00	2017-10-20 15:00:00	Participation à la manifesation des élus pour le maintien du guichet à la gare de Saint-Flour
7317	14327T	ACC_VISIT	2017-10-26 12:00:00	2017-10-26 12:00:00	Accueil du conseil municipal des jeunes de Ydes
7318	14327T	COLL_TER	2017-10-27 22:00:00	2017-10-27 22:00:00	Visite de la commune et réunion avec le conseil municipal de Ladinhac
7319	14327T	DEPL_PRES_GVT	2017-11-06 18:00:00	2017-11-06 18:00:00	Déplacement de la Ministre Elisabeth Borne à Aurillac dans le cadre des Assises de la mobilité
7320	14041T	ELUS_LOCAUX	2017-10-31 08:00:00	2017-10-31 22:00:00	déplacement à l'étranger
7321	14041T	ELUS_LOCAUX	2017-11-01 08:00:00	2017-11-01 22:00:00	déplacement à l'étranger
7322	14041T	ACC_VISIT	2017-10-03 20:00:00	2017-10-03 22:00:00	élus consulaires 
7642	08010L	ELUS_LOCAUX	2017-12-14 15:30:00	2017-12-14 17:00:00	\N
7643	08010L	COLL_TER	2017-12-14 18:30:00	2017-12-14 21:00:00	Conseil d'Agglomération
7674	08010L	REU_TRAV_PARL	2017-12-20 12:00:00	2017-12-20 13:00:00	\N
8137	08010L	REU_TRAV_PARL	2018-02-07 13:00:00	2018-02-07 14:30:00	EPL Loi Logement
8218	14089Y	COLL_TER	2017-09-28 18:30:00	2017-09-28 22:30:00	\N
8219	14089Y	CEREMONIE	2017-09-29 10:00:00	2017-09-29 11:00:00	\N
8220	14089Y	ELUS_LOCAUX	2017-09-29 15:00:00	2017-09-29 16:00:00	\N
7668	04042C	ORG_POL	2017-12-18 20:00:00	2017-12-18 21:00:00	\N
8221	14089Y	CEREMONIE	2017-09-29 19:00:00	2017-09-29 21:30:00	\N
8222	14089Y	REU_TRAV_PARL	2017-10-03 14:30:00	2017-10-03 15:30:00	\N
8235	14089Y	REU_TRAV_PARL	2017-10-17 16:00:00	2017-10-17 17:00:00	\N
8236	14089Y	REU_TRAV_PARL	2017-10-18 13:30:00	2017-10-18 14:30:00	\N
8237	14089Y	REU_TRAV_PARL	2017-10-19 14:30:00	2017-10-19 15:30:00	\N
8238	14089Y	ELUS_LOCAUX	2017-10-20 12:00:00	2017-10-20 14:00:00	\N
8239	14089Y	CEREMONIE	2017-10-20 17:15:00	2017-10-20 18:15:00	\N
8240	14089Y	REU_TRAV_PARL	2017-10-23 10:30:00	2017-10-23 11:30:00	\N
8241	14089Y	REU_TRAV_PARL	2017-10-23 15:00:00	2017-10-23 16:00:00	\N
8242	14089Y	REU_TRAV_PARL	2017-10-23 16:00:00	2017-10-23 17:00:00	\N
8243	14089Y	REU_TRAV_PARL	2017-10-24 14:15:00	2017-10-24 15:15:00	\N
8244	14089Y	REU_TRAV_PARL	2017-10-24 17:00:00	2017-10-24 18:00:00	\N
8245	14089Y	REU_TRAV_PARL	2017-10-27 10:00:00	2017-10-27 11:00:00	\N
8246	14089Y	ELUS_LOCAUX	2017-10-27 12:00:00	2017-10-27 14:00:00	\N
8247	14089Y	ELUS_LOCAUX	2017-10-27 18:00:00	2017-10-27 19:00:00	\N
8248	14089Y	CEREMONIE	2017-10-27 19:00:00	2017-10-27 20:00:00	\N
8249	14089Y	ELUS_LOCAUX	2017-10-27 20:30:00	2017-10-27 22:30:00	\N
8250	14089Y	REU_TRAV_PARL	2017-11-02 18:00:00	2017-11-02 19:00:00	\N
8251	14089Y	REU_TRAV_PARL	2017-11-03 14:00:00	2017-11-03 14:30:00	\N
8252	14089Y	CEREMONIE	2017-11-03 19:30:00	2017-11-03 20:30:00	\N
8255	14089Y	ELUS_LOCAUX	2017-11-06 10:30:00	2017-11-06 12:00:00	\N
8256	14089Y	ELUS_LOCAUX	2017-11-06 12:15:00	2017-11-06 14:15:00	\N
8257	14089Y	REU_TRAV_PARL	2017-11-07 14:30:00	2017-11-07 15:30:00	\N
8258	14089Y	ELUS_LOCAUX	2017-11-10 09:30:00	2017-11-10 11:00:00	\N
8259	14089Y	REU_TRAV_PARL	2017-11-10 11:15:00	2017-11-10 12:15:00	\N
8260	14089Y	CEREMONIE	2017-11-10 16:30:00	2017-11-10 17:30:00	\N
8261	14089Y	ELUS_LOCAUX	2017-11-10 18:00:00	2017-11-10 20:30:00	\N
8262	14089Y	ELUS_LOCAUX	2017-11-13 12:15:00	2017-11-13 14:00:00	\N
8263	14089Y	COLL_TER	2017-11-13 16:30:00	2017-11-13 17:30:00	\N
8264	14089Y	REU_TRAV_PARL	2017-11-15 14:30:00	2017-11-15 15:30:00	\N
8265	14089Y	COLL_TER	2017-11-17 09:00:00	2017-11-17 10:00:00	\N
8269	14089Y	ELUS_LOCAUX	2017-11-17 16:00:00	2017-11-17 17:30:00	\N
8267	14089Y	REU_TRAV_PARL	2017-11-17 10:00:00	2017-11-17 12:00:00	\N
8268	14089Y	ELUS_LOCAUX	2017-11-17 12:30:00	2017-11-17 14:30:00	\N
8270	14089Y	CEREMONIE	2017-11-17 18:30:00	2017-11-17 20:00:00	\N
8271	14089Y	ELUS_LOCAUX	2017-11-20 12:30:00	2017-11-20 14:00:00	\N
8272	14089Y	REU_TRAV_PARL	2017-11-21 13:45:00	2017-11-21 14:45:00	\N
8273	14089Y	ACC_VISIT	2017-11-22 17:30:00	2017-11-22 19:30:00	\N
8274	19705W	ORG_POL	2018-02-13 11:00:00	2018-02-13 12:30:00	\N
8275	14089Y	REU_TRAV_PARL	2017-11-30 12:00:00	2017-11-30 13:00:00	\N
8276	14089Y	ACC_VISIT	2017-11-30 14:00:00	2017-11-30 15:30:00	\N
8277	14089Y	CEREMONIE	2017-11-30 19:00:00	2017-11-30 21:00:00	\N
8278	14089Y	ELUS_LOCAUX	2017-12-01 10:30:00	2017-12-01 11:30:00	\N
8279	14089Y	ELUS_LOCAUX	2017-12-01 12:30:00	2017-12-01 14:00:00	\N
8280	14089Y	REU_TRAV_PARL	2017-12-01 16:00:00	2017-12-01 17:00:00	\N
8281	14089Y	CEREMONIE	2017-12-01 20:00:00	2017-12-01 21:00:00	\N
8282	19707Y	ORG_POL	2018-02-13 11:00:00	2018-02-13 12:30:00	\N
8283	19707Y	ORG_POL	2018-02-06 11:00:00	2018-02-06 12:30:00	\N
8284	14089Y	ELUS_LOCAUX	2017-12-04 10:30:00	2017-12-04 14:30:00	\N
8285	14089Y	ELUS_LOCAUX	2017-12-04 14:15:00	2017-12-04 15:15:00	\N
8286	14089Y	REU_TRAV_PARL	2017-12-07 14:30:00	2017-12-07 15:30:00	\N
8287	14089Y	REU_TRAV_PARL	2017-12-08 14:00:00	2017-12-08 15:00:00	\N
8288	14089Y	CEREMONIE	2017-12-08 17:00:00	2017-12-08 18:00:00	\N
8289	14089Y	CEREMONIE	2017-12-08 19:00:00	2017-12-08 20:00:00	\N
8290	14089Y	ELUS_LOCAUX	2017-12-11 10:00:00	2017-12-11 11:30:00	\N
8291	14089Y	ELUS_LOCAUX	2017-12-11 12:45:00	2017-12-11 14:00:00	\N
8292	14089Y	COLL_TER	2017-12-11 14:30:00	2017-12-11 16:00:00	\N
8293	14089Y	CEREMONIE	2017-12-11 16:00:00	2017-12-11 17:30:00	\N
8294	14089Y	CEREMONIE	2017-12-11 20:00:00	2017-12-11 21:30:00	\N
8295	14089Y	REU_TRAV_PARL	2017-12-13 17:00:00	2017-12-13 18:00:00	\N
8296	14089Y	CEREMONIE	2017-12-14 11:30:00	2017-12-14 12:30:00	\N
8297	14089Y	ORG_POL	2017-12-14 19:00:00	2017-12-14 20:00:00	\N
8298	14089Y	REU_TRAV_PARL	2017-12-15 10:30:00	2017-12-15 11:30:00	\N
8299	14089Y	REU_TRAV_PARL	2017-12-15 15:00:00	2017-12-15 16:00:00	\N
8300	14089Y	CEREMONIE	2017-12-15 19:00:00	2017-12-15 20:00:00	\N
8301	14089Y	ELUS_LOCAUX	2017-12-18 18:00:00	2017-12-18 20:00:00	\N
8302	14089Y	REU_TRAV_PARL	2017-12-19 19:00:00	2017-12-19 20:00:00	\N
8303	14089Y	REU_TRAV_PARL	2017-12-20 16:00:00	2017-12-20 17:00:00	\N
8304	08010L	ACC_VISIT	2018-02-15 12:00:00	2018-02-15 13:00:00	Consulat d'Allemagne
8308	04086Q	REU_TRAV_PARL	2018-02-08 10:00:00	2018-02-08 10:30:00	Réunion avec un sénateur pour organiser un déplacement dans le cadre du Logement
8309	04086Q	ACC_DEPL_INTER	2018-02-08 15:00:00	2018-02-08 15:30:00	RDV organisation de diverses manifestations dans le cadre de l'année croisée France-Israël
8310	04086Q	COLL_TER	2018-02-08 18:30:00	2018-02-08 19:30:00	Public Sénat Débat sur la police de proximité
8311	04086Q	COLL_TER	2018-02-09 08:30:00	2018-02-09 12:00:00	Réunion budgétaire en mairie des Pavillons-sous-Bois
8312	04086Q	COLL_TER	2018-02-09 13:45:00	2018-02-09 18:00:00	Réunion budgétaire en mairie des Pavillons-sous-Bois
8313	04086Q	COLL_TER	2018-02-12 08:30:00	2018-02-12 12:30:00	Réunion budgétaire en mairie des Pavillons-sous-Bois
8314	04086Q	COLL_TER	2018-02-12 18:30:00	2018-02-12 21:00:00	Réunion du bureau municipal
8315	04086Q	COLL_TER	2018-02-13 18:30:00	2018-02-13 19:00:00	Public Sénat Débat sur le logement
8316	04086Q	ELUS_LOCAUX	2018-02-13 20:00:00	2018-02-13 22:00:00	Conseil de Territoire sur le ROB
8317	04086Q	REU_TRAV_PARL	2018-02-14 08:30:00	2018-02-14 09:30:00	Réunion Vice-présidence
8318	04086Q	COLL_TER	2018-02-14 00:00:00	2018-02-14 00:00:00	Déjeuner de travail 
7041	08010L	REU_TRAV_PARL	2017-10-03 15:00:00	2017-10-03 16:30:00	Moyens de la Justice
7042	08039A	ORG_POL	2017-10-03 19:00:00	2017-10-03 21:00:00	\N
7043	08039A	ORG_POL	2017-10-03 11:00:00	2017-10-03 12:30:00	\N
7045	08039A	DEL_ACT_PAR	2017-09-28 09:00:00	2017-09-28 19:00:00	Congrès National Sites et Cités remarquables Calais 
7053	08039A	DEL_ACT_PAR	2017-10-12 09:00:00	2017-10-12 19:00:00	Pélerinage des Parlementaires à Lourdes
7054	08039A	DEL_ACT_PAR	2017-10-13 09:00:00	2017-10-13 19:00:00	Pélerinage des Parlementaires à Lourdes
7058	08039A	ORG_POL	2017-10-24 11:00:00	2017-10-24 12:00:00	\N
7056	08039A	COLL_TER	2017-10-19 09:00:00	2017-10-19 19:00:00	Colloque Patrimoine Vivant du Pays de Grasse
7057	08039A	COLL_TER	2017-10-20 09:00:00	2017-10-20 19:00:00	Colloque Patrimoine Vivant du Pays de Grasse
7059	08039A	ORG_POL	2017-10-31 09:00:00	2017-10-31 12:30:00	\N
7060	08039A	COLL_TER	2017-11-06 10:30:00	2017-11-06 12:00:00	\N
7061	08039A	COLL_TER	2017-09-05 14:30:00	2017-09-05 16:00:00	\N
7062	08039A	COLL_TER	2017-09-08 17:00:00	2017-09-08 21:00:00	Remise de diplômes 
7063	08039A	REU_TRAV_PARL	2017-09-12 16:30:00	2017-09-12 18:00:00	\N
7064	08039A	COLL_TER	2017-09-15 11:00:00	2017-09-15 13:00:00	Projet Unesco
7065	08039A	ELUS_LOCAUX	2017-09-15 09:00:00	2017-09-15 11:00:00	Conseil départemental
7066	08039A	CEREMONIE	2017-09-19 19:00:00	2017-09-19 21:00:00	Remise de décoration 
7067	08039A	REU_TRAV_PARL	2017-09-21 08:00:00	2017-09-21 10:00:00	\N
7068	08039A	ELUS_LOCAUX	2017-09-22 09:00:00	2017-09-22 13:00:00	Salon des Maires 
7081	08009T	ACC_DEPL_INTER	2017-09-28 12:30:00	2017-09-28 13:30:00	\N
7082	08009T	ORG_POL	2017-09-27 16:00:00	2017-09-27 17:00:00	\N
7083	08009T	REU_TRAV_PARL	2017-09-27 18:00:00	2017-09-27 19:00:00	\N
7084	08009T	ORG_POL	2017-09-26 16:30:00	2017-09-26 18:30:00	\N
7085	08009T	REU_GVT	2017-09-19 15:00:00	2017-09-19 18:30:00	\N
7086	08009T	DEPL_PRES_GVT	2017-09-12 00:00:00	2017-09-12 23:59:00	\N
7087	08009T	DEPL_PRES_GVT	2017-09-13 00:00:00	2017-09-13 23:59:00	\N
7088	08009T	DEPL_PRES_GVT	2017-09-14 00:00:00	2017-09-14 23:59:00	\N
7089	08009T	REU_TRAV_PARL	2017-09-05 10:00:00	2017-09-05 11:00:00	\N
7090	08009T	REU_TRAV_PARL	2017-09-05 14:00:00	2017-09-05 15:00:00	\N
7091	08009T	ORGEXTPAR	2017-09-05 17:00:00	2017-09-05 18:00:00	\N
7092	08009T	REU_TRAV_PARL	2017-09-05 18:00:00	2017-09-05 19:00:00	\N
7093	08009T	REU_TRAV_PARL	2017-09-06 09:30:00	2017-09-06 10:30:00	\N
7094	08009T	REU_TRAV_PARL	2017-09-06 11:00:00	2017-09-06 12:30:00	\N
7095	08009T	REU_TRAV_PARL	2017-09-06 14:00:00	2017-09-06 15:00:00	\N
7096	08009T	REU_TRAV_PARL	2017-09-06 15:00:00	2017-09-06 16:00:00	\N
7097	08009T	REU_TRAV_PARL	2017-09-06 17:00:00	2017-09-06 18:00:00	\N
7143	11067R	ORG_POL	2017-10-10 12:30:00	2017-10-10 12:30:00	Groupe PS
7144	11067R	ELUS_LOCAUX	2017-10-09 12:30:00	2017-10-09 12:30:00	Conférence des territoires en Loire-Atlantique, Orvault
7145	08010L	REU_TRAV_PARL	2017-10-11 15:00:00	2017-10-11 16:00:00	Moyens de la Justice
7367	04086Q	CEREMONIE	2017-11-08 16:00:00	2017-11-08 17:00:00	Remise du prix littéraire de la Résistance - Vice-présidence
7366	08010L	REU_TRAV_PARL	2017-11-09 13:00:00	2017-11-09 14:00:00	Bureau Délégation Territoriale 
7369	04042C	ACC_DEPL_INTER	2017-11-14 19:30:00	2017-11-14 19:30:00	\N
7368	04042C	REU_TRAV_PARL	2017-11-14 11:00:00	2017-11-14 12:00:00	\N
7370	04042C	REU_TRAV_PARL	2017-11-14 16:45:00	2017-11-14 16:45:00	\N
7372	04042C	DEPL_PRES_GVT	2017-11-16 00:00:00	2017-11-16 20:00:00	Mission au Maroc
7373	04042C	COLL_TER	2017-11-17 08:45:00	2017-11-17 12:30:00	Bureau et Commission du SEDIF
7374	04042C	CEREMONIE	2017-11-17 12:30:00	2017-11-17 15:00:00	40ème anniversaire de la RPA
7375	04042C	CEREMONIE	2017-11-17 19:00:00	2017-11-17 23:30:00	Soirée du personnel
7376	04042C	ELUS_LOCAUX	2017-11-14 20:30:00	2017-11-14 21:00:00	\N
7377	04042C	CEREMONIE	2017-11-06 18:30:00	2017-11-06 19:30:00	84ème anniversaire de l'Empereur du Japon
7378	04042C	ELUS_LOCAUX	2017-11-06 20:30:00	2017-11-06 23:00:00	Conseil municipal
7379	04042C	ORG_POL	2017-11-07 10:00:00	2017-11-07 11:00:00	\N
7380	04042C	ORG_POL	2017-11-07 11:00:00	2017-11-07 12:00:00	Réunion de Groupe
7381	04042C	ACC_VISIT	2017-11-07 14:30:00	2017-11-07 15:00:00	\N
7385	04042C	CEREMONIE	2017-11-08 18:30:00	2017-11-08 19:30:00	Fête nationale d'Algérie
7383	04042C	ELUS_LOCAUX	2017-11-07 19:30:00	2017-11-07 23:30:00	Entretien avec des élus du Val-de-Marne
7384	04042C	ACC_DEPL_INTER	2017-11-08 17:30:00	2017-11-08 18:30:00	\N
7386	04042C	ACC_VISIT	2017-11-09 08:30:00	2017-11-09 09:30:00	\N
7387	04042C	REU_TRAV_PARL	2017-11-09 09:00:00	2017-11-09 12:00:00	\N
7388	04042C	REU_TRAV_PARL	2017-11-09 11:30:00	2017-11-09 11:45:00	Comité BREXIT
7389	04042C	ORG_POL	2017-11-09 19:30:00	2017-11-09 21:00:00	\N
7581	08039A	ACC_DEPL_INTER	2017-11-08 08:00:00	2017-11-08 21:00:00	Voyage Officiel en Pologne
7582	08039A	ACC_DEPL_INTER	2017-11-09 08:00:00	2017-11-09 20:00:00	Voyage Officiel en Pologne
7583	08039A	ACC_DEPL_INTER	2017-11-10 00:00:00	2017-11-10 00:00:00	Voyage Officiel en Pologne
7584	08039A	ACC_DEPL_INTER	2017-11-13 08:00:00	2017-11-13 21:00:00	Voyage Officiel en Pologne
7586	08039A	REU_TRAV_PARL	2017-11-14 18:00:00	2017-11-14 19:00:00	Audiovisuel public
7587	08039A	REU_GVT	2017-11-15 00:00:00	2017-11-15 00:00:00	Réunion Matignon
7588	08039A	ACC_DEPL_INTER	2017-11-15 15:00:00	2017-11-15 16:00:00	Réunion Amitié France Pologne
7589	08039A	COLL_TER	2017-11-17 15:00:00	2017-11-17 18:00:00	Réunions Permanence 
7590	08039A	REU_TRAV_PARL	2017-11-20 11:00:00	2017-11-20 12:30:00	Interview Médias 
7593	08039A	COLL_TER	2017-11-27 15:00:00	2017-11-27 18:00:00	Réunions Permanence 
7594	08039A	ACC_VISIT	2017-11-28 15:00:00	2017-11-28 16:30:00	Jeune du département 
7595	08039A	REU_TRAV_PARL	2017-11-28 18:00:00	2017-11-28 19:00:00	Audiovisuel public
7600	08010L	REU_TRAV_PARL	2017-12-06 10:00:00	2017-12-06 10:45:00	Canal seine nord Europe
7628	04042C	COLL_TER	2017-12-14 10:00:00	2017-12-14 12:30:00	Comité du SEDIF
7629	04042C	ACC_DEPL_INTER	2017-12-14 12:30:00	2017-12-14 13:30:00	Rencontre à l'ocasion de la journée nationale célébrant l'anniversaire de l'accession au pouvoir du fondateur de l'Etat du Qatar
7630	04042C	ACC_DEPL_INTER	2017-12-14 14:30:00	2017-12-14 15:00:00	Entretien avec le Président du Comité de la Fédération des affaires internationales
7634	19705W	ORG_POL	2017-12-12 11:00:00	2017-12-12 12:30:00	\N
7635	19705W	REU_TRAV_PARL	2017-12-14 09:30:00	2017-12-14 10:30:00	Groupe d'amitié France-Israël
8014	14089Y	REU_TRAV_PARL	2017-07-12 15:00:00	2017-07-12 16:30:00	\N
8016	14089Y	ELUS_LOCAUX	2017-07-17 10:30:00	2017-07-17 11:30:00	\N
7638	19707Y	REU_TRAV_PARL	2017-12-14 09:30:00	2017-12-14 10:30:00	Groupe d'amitié France-Israël
7639	19707Y	CEREMONIE	2017-12-07 18:00:00	2017-12-07 21:00:00	Comité des Associations Françaises de New York
7640	19707Y	ELUS_LOCAUX	2017-12-12 20:00:00	2017-12-12 22:00:00	Conseillers Consulaires
7641	19707Y	ELUS_LOCAUX	2017-12-05 13:00:00	2017-12-05 15:00:00	Conseiller Consulaires Amérique Centrale
7661	04018C	ORG_POL	2017-12-13 18:30:00	2017-12-13 20:00:00	\N
7675	08010L	COLL_TER	2017-12-21 09:00:00	2017-12-21 11:00:00	Comité pilotage RN2
7681	04042C	DEPL_PRES_GVT	2018-01-08 00:00:00	2018-01-08 00:00:00	Visite en Chine avec le Président de la République française
7682	04042C	DEPL_PRES_GVT	2018-01-09 00:00:00	2018-01-09 00:00:00	Visite en Chine avec le Président de la République française
7684	04042C	CEREMONIE	2018-01-10 19:00:00	2018-01-10 21:00:00	Cérémonie des Voeux à Maisons-Alfort
7685	04042C	ACC_DEPL_INTER	2018-01-04 15:00:00	2018-01-04 17:00:00	Cérémonie des Voeux du Président de la République française au corps diplomatique
7686	04042C	CEREMONIE	2018-01-04 18:00:00	2018-01-04 20:00:00	Cérémonie des Voeux du Préfet de Police de Paris
7721	08010L	ELUS_LOCAUX	2018-01-09 11:00:00	2018-01-09 13:00:00	Fédération des EPL
7727	08010L	COLL_TER	2018-01-11 00:00:00	2018-01-11 00:00:00	Voeux de la Ville de Laon
7817	08010L	REU_TRAV_PARL	2018-01-17 08:00:00	2018-01-17 09:00:00	réseaux sociaux
8015	14089Y	CEREMONIE	2017-07-14 18:00:00	2017-07-14 18:30:00	\N
7819	08010L	REU_TRAV_PARL	2018-01-16 14:00:00	2018-01-16 14:30:00	international
8017	14089Y	REU_TRAV_PARL	2017-07-17 16:00:00	2017-07-17 16:30:00	\N
7889	19707Y	ORG_POL	2018-01-23 10:30:00	2018-01-23 12:30:00	\N
8018	14089Y	REU_TRAV_PARL	2017-07-18 14:00:00	2017-07-18 15:00:00	\N
8019	14089Y	COLL_TER	2017-07-21 09:30:00	2017-07-21 10:30:00	\N
8020	14089Y	COLL_TER	2017-07-21 10:30:00	2017-07-21 11:30:00	\N
8021	14089Y	COLL_TER	2017-07-21 14:00:00	2017-07-21 16:00:00	\N
8022	14089Y	REU_TRAV_PARL	2017-07-21 16:30:00	2017-07-21 17:30:00	\N
8023	14089Y	COLL_TER	2017-07-24 10:00:00	2017-07-24 11:00:00	\N
8024	14089Y	REU_TRAV_PARL	2017-07-24 16:00:00	2017-07-24 17:00:00	\N
8025	14089Y	REU_TRAV_PARL	2017-07-24 17:00:00	2017-07-24 18:00:00	\N
8026	14089Y	REU_TRAV_PARL	2017-07-26 11:30:00	2017-07-26 12:30:00	\N
8027	14089Y	COLL_TER	2017-07-28 11:30:00	2017-07-28 12:30:00	\N
8028	14089Y	CEREMONIE	2017-07-28 19:00:00	2017-07-28 20:30:00	\N
8029	14089Y	ELUS_LOCAUX	2017-07-31 10:00:00	2017-07-31 11:00:00	\N
8030	14089Y	REU_TRAV_PARL	2017-08-01 18:00:00	2017-08-01 19:00:00	\N
8031	14089Y	ACC_VISIT	2017-08-02 15:00:00	2017-08-02 16:00:00	\N
8032	14089Y	REU_TRAV_PARL	2017-08-02 19:30:00	2017-08-02 20:30:00	\N
8033	08010L	ORG_POL	2018-01-30 09:30:00	2018-01-30 12:30:00	séminaire LR Sénat
8034	19707Y	ORG_POL	2018-01-30 09:30:00	2018-01-30 12:00:00	\N
8036	04018C	COLL_TER	2018-01-30 19:00:00	2018-01-30 21:00:00	\N
8037	04018C	COLL_TER	2018-01-31 15:30:00	2018-01-31 17:30:00	\N
8044	14089Y	COLL_TER	2017-08-07 17:00:00	2017-08-07 18:30:00	\N
8048	14089Y	CEREMONIE	2017-08-14 18:00:00	2017-08-14 19:00:00	\N
8046	14089Y	ELUS_LOCAUX	2017-08-08 14:30:00	2017-08-08 15:30:00	\N
8047	14089Y	COLL_TER	2017-08-10 11:00:00	2017-08-10 12:00:00	\N
7202	08010L	COLL_TER	2017-10-19 10:00:00	2017-10-19 11:30:00	CA OPAL de Laon
7281	19707Y	ELUS_LOCAUX	2017-11-02 13:00:00	2017-11-02 14:30:00	Conseillers Consulaires Europe du Nord
7347	04018C	REU_TRAV_PARL	2017-11-07 09:15:00	2017-11-07 10:15:00	\N
7348	04018C	REU_TRAV_PARL	2017-11-07 10:30:00	2017-11-07 12:00:00	\N
7349	04018C	REU_TRAV_PARL	2017-11-07 14:15:00	2017-11-07 15:15:00	\N
7350	04018C	REU_TRAV_PARL	2017-11-07 15:15:00	2017-11-07 16:15:00	\N
7351	04018C	REU_TRAV_PARL	2017-11-07 16:30:00	2017-11-07 18:00:00	\N
7352	04018C	ORG_POL	2017-11-07 18:00:00	2017-11-07 20:00:00	\N
7354	08010L	ACC_VISIT	2017-11-09 14:00:00	2017-11-09 15:00:00	RDV journaliste 
7390	04086Q	REU_TRAV_PARL	2017-11-08 18:00:00	2017-11-08 19:00:00	Réunion de travail du groupe Logement
7408	04086Q	CEREMONIE	2017-11-13 20:00:00	2017-11-13 21:00:00	Inauguration avec G. Larcher de l'exposition des Chrétiens d'Orient à l'Institut du Monde Arabe
7405	04086Q	CEREMONIE	2017-11-13 08:45:00	2017-11-13 09:30:00	Cérémonie en mémoire des victimes des attentats du 13 novembre
7412	08009T	CEREMONIE	2017-11-21 10:00:00	2017-11-21 10:30:00	\N
7413	08009T	ORG_POL	2017-11-21 11:00:00	2017-11-21 13:00:00	\N
7414	08009T	REU_TRAV_PARL	2017-11-21 14:00:00	2017-11-21 14:30:00	\N
7415	08009T	REU_TRAV_PARL	2017-11-21 14:30:00	2017-11-21 15:30:00	\N
7416	08009T	REU_TRAV_PARL	2017-11-16 08:00:00	2017-11-16 10:00:00	\N
7417	08009T	REU_TRAV_PARL	2017-11-15 14:30:00	2017-11-15 15:30:00	\N
7418	08009T	REU_TRAV_PARL	2017-11-15 15:30:00	2017-11-15 16:30:00	\N
7419	08009T	REU_TRAV_PARL	2017-11-09 08:00:00	2017-11-09 09:00:00	\N
7420	08009T	REU_TRAV_PARL	2017-11-09 09:00:00	2017-11-09 10:00:00	\N
7421	08009T	REU_GVT	2017-11-09 16:00:00	2017-11-09 17:00:00	\N
7422	08009T	REU_TRAV_PARL	2017-11-09 17:00:00	2017-11-09 18:00:00	\N
7423	08009T	REU_TRAV_PARL	2017-11-07 10:00:00	2017-11-07 11:00:00	\N
7424	08009T	ORG_POL	2017-11-07 11:00:00	2017-11-07 13:00:00	\N
7425	08009T	REU_GVT	2017-11-07 20:00:00	2017-11-07 21:00:00	\N
7428	08009T	REU_GVT	2017-10-26 09:30:00	2017-10-26 12:30:00	\N
7429	08009T	REU_TRAV_PARL	2017-10-25 08:00:00	2017-10-25 09:00:00	\N
7430	08009T	REU_TRAV_PARL	2017-10-25 14:30:00	2017-10-25 15:30:00	\N
7431	08009T	ORG_POL	2017-10-24 11:00:00	2017-10-24 13:00:00	\N
7432	08009T	COLLOQUE	2017-10-24 14:30:00	2017-10-24 16:00:00	\N
7433	08009T	REU_TRAV_PARL	2017-10-24 16:00:00	2017-10-24 17:00:00	\N
7434	08009T	REU_TRAV_PARL	2017-10-24 18:00:00	2017-10-24 19:30:00	\N
7435	19705W	ORG_POL	2017-11-14 11:00:00	2017-11-14 12:30:00	\N
7437	19705W	ELUS_LOCAUX	2017-11-16 12:30:00	2017-11-16 14:30:00	\N
7438	19707Y	ELUS_LOCAUX	2017-11-14 09:00:00	2017-11-14 10:30:00	Conseiller Consulaire Israël
7439	19707Y	ELUS_LOCAUX	2017-11-14 13:00:00	2017-11-14 14:30:00	Conseiller Consulaire Israël
7440	19707Y	ELUS_LOCAUX	2017-11-14 20:00:00	2017-11-14 22:30:00	Conseillers Consulaires Israël
7441	19707Y	ELUS_LOCAUX	2017-11-15 09:00:00	2017-11-15 10:30:00	Conseiller Consulaire Israël
7442	19707Y	ELUS_LOCAUX	2017-11-16 12:30:00	2017-11-16 14:00:00	\N
7443	19707Y	REU_TRAV_PARL	2017-11-21 09:00:00	2017-11-21 10:30:00	Ecole Française de Mexico
7451	04042C	REU_TRAV_PARL	2017-11-20 15:00:00	2017-11-20 16:30:00	\N
7452	04042C	ELUS_LOCAUX	2017-11-21 10:00:00	2017-11-21 11:00:00	Accueil des élus du Congrès des Maires
7456	04042C	ELUS_LOCAUX	2017-11-21 19:00:00	2017-11-21 22:00:00	Avec la Présidente de la Région d'Ile-de-France
7458	04042C	ACC_DEPL_INTER	2017-11-22 16:00:00	2017-11-22 17:00:00	Entretien avec l'Ambassadeur du Royaume-Uni
7457	04042C	ELUS_LOCAUX	2017-11-22 12:00:00	2017-11-22 15:00:00	Visite du Salon des Maires
7459	04042C	ACC_DEPL_INTER	2017-11-22 17:15:00	2017-11-22 18:15:00	Entretien avec le Secrétaire Général de la ligne islamique mondiale
7460	04042C	REU_GVT	2017-11-23 08:00:00	2017-11-23 09:00:00	Réunion avec la Ministre des armées
7461	04042C	ACC_DEPL_INTER	2017-11-23 20:00:00	2017-11-23 22:00:00	Rencontre avec l'Ambassadeur Suisse
7462	04042C	CEREMONIE	2017-11-24 19:00:00	2017-11-24 21:00:00	Réception de jeunes diplômés
7463	04042C	ORG_POL	2017-09-27 10:30:00	2017-09-27 12:30:00	\N
7464	04042C	ORG_POL	2017-09-27 17:30:00	2017-09-27 18:30:00	Entretien
7465	04042C	ACC_DEPL_INTER	2017-09-26 00:00:00	2017-09-26 00:00:00	Entretien avec le Président Libanais et le Président du Sénat
7466	04042C	REU_TRAV_PARL	2017-09-26 15:00:00	2017-09-26 16:00:00	Commission des Affaires étrangères, de la Défense et des Forces Armées
7467	04042C	REU_TRAV_PARL	2017-09-28 10:30:00	2017-09-28 11:30:00	Entretien avec le Conseil de surveillance
7468	04042C	ACC_VISIT	2017-09-28 18:00:00	2017-09-28 19:00:00	\N
7469	04042C	ELUS_LOCAUX	2017-09-28 20:30:00	2017-09-28 22:30:00	Conseil Municipal
7470	04042C	COLL_TER	2017-09-29 08:00:00	2017-09-29 09:00:00	au Conseil Régional d'Ile-de-France
7471	04042C	ELUS_LOCAUX	2017-09-29 09:00:00	2017-09-29 12:00:00	à la Métropole du Grand Paris
7472	04042C	ACC_VISIT	2017-09-29 12:00:00	2017-09-29 13:00:00	SEDIF
7473	04042C	ACC_DEPL_INTER	2017-09-29 21:00:00	2017-09-29 23:00:00	accueil des délégations
7474	04042C	ORG_POL	2017-10-02 20:00:00	2017-10-02 23:00:00	Réunion de Laurent WAUQUIEZ
7475	04042C	ELUS_LOCAUX	2017-10-03 09:00:00	2017-10-03 10:00:00	3ème Jury Immobilière 3F
7476	04042C	ORG_POL	2017-10-03 10:30:00	2017-10-03 12:30:00	\N
7477	04042C	ORG_POL	2017-10-03 17:00:00	2017-10-03 18:00:00	\N
7478	04042C	CEREMONIE	2017-10-03 19:30:00	2017-10-03 20:30:00	Fête nationale d'Arménie
7479	04042C	CEREMONIE	2017-10-03 20:30:00	2017-10-03 22:00:00	Inauguration Rubens
7480	04042C	ACC_VISIT	2017-10-04 00:00:00	2017-10-04 00:00:00	Rendez-vous avec des administrés
7482	14133K	DEPL_PRES_GVT	2017-11-13 08:30:00	2017-11-13 22:00:00	Forum sur la sécurité en Afrique, Dakar
7484	14133K	DEL_ACT_PAR	2017-11-22 14:00:00	2017-11-22 16:00:00	Milipol Paris, salon mondial de la sécurité intérieure des États
7486	04042C	ACC_DEPL_INTER	2017-10-04 18:30:00	2017-10-04 21:30:00	Réception journée de l'Unité allemande
7487	04042C	REU_TRAV_PARL	2017-10-05 09:00:00	2017-10-05 11:00:00	\N
7488	04042C	REU_TRAV_PARL	2017-10-05 11:00:00	2017-10-05 12:00:00	CAED
7489	04042C	REU_TRAV_PARL	2017-10-05 17:00:00	2017-10-05 18:00:00	Conférence des Présidents
7501	04042C	ELUS_LOCAUX	2017-10-12 15:00:00	2017-10-12 16:00:00	Entretien avec le Maire de Villeneuve-le-Roi 
7514	04042C	REU_TRAV_PARL	2017-10-18 14:30:00	2017-10-18 15:00:00	Scrutin pour élection des juges de la Cour de Justice
7513	04042C	REU_TRAV_PARL	2017-10-18 00:00:00	2017-10-18 00:00:00	\N
7515	04042C	ACC_VISIT	2017-10-18 17:00:00	2017-10-18 18:00:00	\N
7516	04042C	ACC_DEPL_INTER	2017-10-18 19:00:00	2017-10-18 21:00:00	Entretien de fin de mission avec l'Ambassadeur de Russie
7517	04042C	COLL_TER	2017-10-19 00:00:00	2017-10-19 00:00:00	Conseil  de la Métropole du Grand Paris
7518	04042C	COLL_TER	2017-10-19 11:00:00	2017-10-19 12:30:00	Comité du SEDIF
7519	04042C	REU_TRAV_PARL	2017-10-20 12:30:00	2017-10-20 14:00:00	Entretien avec le Chef d'Etat-major de l'Armée de l'air
7520	04042C	ACC_VISIT	2017-10-20 15:00:00	2017-10-20 16:00:00	Réunion Haut Comité d'Evalution de la Condition militairee
7521	04042C	ACC_VISIT	2017-10-20 16:15:00	2017-10-20 17:15:00	Entretien avec le Directeur général de la Gendarmerie nationale
7522	04042C	ACC_VISIT	2017-10-20 17:30:00	2017-10-20 19:00:00	\N
7523	04042C	ELUS_LOCAUX	2017-10-23 16:00:00	2017-10-23 17:00:00	\N
7524	04042C	ACC_DEPL_INTER	2017-10-23 21:00:00	2017-10-23 23:00:00	Entretien avec le nouvel Ambassadeur d'Australie
7525	04042C	ACC_DEPL_INTER	2017-10-24 20:30:00	2017-10-24 23:30:00	avec le Ministre des Affaires étrangères et le Chef d'Etat Egyptien
7526	04042C	REU_TRAV_PARL	2017-11-27 16:00:00	2017-11-27 00:00:00	Séance publique
7527	04042C	ELUS_LOCAUX	2017-11-27 12:30:00	2017-11-27 14:30:00	Avec les premiers adjoints 
7528	04042C	ORG_POL	2017-11-28 09:30:00	2017-11-28 10:30:00	Réunion des commissaires L.R
7529	04042C	ORG_POL	2017-11-28 10:30:00	2017-11-28 11:30:00	Bureau du Groupe
7530	04042C	REU_TRAV_PARL	2017-11-28 15:00:00	2017-11-28 16:00:00	\N
7531	04042C	ELUS_LOCAUX	2017-11-28 18:00:00	2017-11-28 19:00:00	\N
7532	04042C	ACC_DEPL_INTER	2017-11-28 18:30:00	2017-11-28 22:00:00	46ème anniversaire de l'Etat des Emirats Arabes Unis
7533	04042C	ACC_DEPL_INTER	2017-10-25 19:45:00	2017-10-25 23:45:00	Entretien avec le Chef d'Etat Egyptien
7534	04042C	ACC_DEPL_INTER	2017-10-26 10:00:00	2017-10-26 11:00:00	Entretien avec l'Ambassadeur Britannique
7535	04042C	ACC_VISIT	2017-10-26 11:00:00	2017-10-26 12:00:00	\N
7536	04042C	ACC_DEPL_INTER	2017-10-26 14:00:00	2017-10-26 15:00:00	Délégation de Sénateurs italiens
7537	04042C	ACC_VISIT	2017-10-26 16:15:00	2017-10-26 17:00:00	\N
7538	04042C	ACC_DEPL_INTER	2017-10-27 18:30:00	2017-10-27 21:00:00	Entretien avec le Ministre des Affaires étrangères britannique et l'Ambassadeur
7601	04086Q	ELUS_LOCAUX	2017-11-21 10:40:00	2017-11-21 13:00:00	Congrès des Maires : Accueil des Elus Locaux au côté de Gérard Larcher
7602	04086Q	DEL_ACT_PAR	2017-11-28 00:00:00	2017-11-28 00:00:00	Réunion de la Délégations des Activités internationales et groupes d¿amitié
7603	04086Q	ORG_POL	2017-11-28 11:00:00	2017-11-28 12:30:00	Réunion de groupe LR
7604	04086Q	REU_GVT	2017-11-29 13:00:00	2017-11-29 13:45:00	Déjeuner de travail Ministère Cohésion des Territoires
7688	04086Q	CEREMONIE	2018-01-09 19:00:00	2018-01-09 21:00:00	Commémoration des attentats de l'Hyper Cacher 
7689	04086Q	ELUS_LOCAUX	2018-01-12 00:00:00	2018-01-12 00:00:00	Réunion point d'étape sur les projets ANRU de la ville des Pavillons-sous-Bois
7001	08010L	ELUS_LOCAUX	2017-09-28 18:00:00	2017-09-28 21:00:00	Conseil de l'Agglomération de Laon 
7181	08010L	ORG_POL	2017-10-17 11:00:00	2017-10-17 12:30:00	Groupe LR sénat
7182	08010L	REU_TRAV_PARL	2017-10-17 16:00:00	2017-10-17 16:45:00	Canal Seine-Nord Europe
7269	08010L	ORG_POL	2017-10-31 11:00:00	2017-10-31 12:30:00	Groupe LR sénat séminaire Budgétaire
7325	04042C	ORG_POL	2017-10-24 11:00:00	2017-10-24 12:30:00	Réunion Groupe LR du sénat
7326	14211G	ORG_POL	2017-10-31 09:30:00	2017-10-31 12:00:00	Groupe Les Républicains
7328	14211G	ACC_VISIT	2017-10-24 10:00:00	2017-10-24 11:00:00	\N
7329	14211G	ORG_POL	2017-10-24 11:00:00	2017-10-24 12:00:00	Groupe Les Républicains
7330	14211G	ORG_POL	2017-10-17 11:00:00	2017-10-17 12:00:00	Groupe Les Républicains
7331	14211G	ORG_POL	2017-10-10 11:00:00	2017-10-10 12:00:00	Groupe Les Républicains
7334	08010L	ORG_POL	2017-11-07 13:30:00	2017-11-07 14:00:00	Commissaires LR des Finances
7335	08010L	REU_TRAV_PARL	2017-11-08 08:00:00	2017-11-08 09:00:00	Promotion des Hauts de France
7336	19705W	ORG_POL	2017-11-07 11:00:00	2017-11-07 12:30:00	\N
7337	19705W	ELUS_LOCAUX	2017-11-07 12:30:00	2017-11-07 14:00:00	Conseiller Consulaire Asie
7338	19707Y	ORG_POL	2017-11-07 11:00:00	2017-11-07 12:30:00	\N
7339	19707Y	ELUS_LOCAUX	2017-11-07 12:30:00	2017-11-07 14:00:00	Conseiller Consulaire Asie
7340	04042C	REU_TRAV_PARL	2017-11-08 08:00:00	2017-11-08 09:00:00	\N
7345	19575F	REU_TRAV_PARL	2017-11-02 09:00:00	2017-11-02 10:30:00	Délégation aux entreprises 
7346	19575F	CEREMONIE	2017-11-02 12:00:00	2017-11-02 12:15:00	En mémoire aux sénateurs disparus pendant le conflit de 14/18
7353	04018C	COLL_TER	2017-11-08 20:00:00	2017-11-08 23:00:00	\N
7539	08010L	ORG_POL	2017-11-28 10:30:00	2017-11-28 13:00:00	Groupe LR du sénat
7371	04042C	DEPL_PRES_GVT	2017-11-15 16:00:00	2017-11-15 00:00:00	Mission au Maroc
7547	19707Y	ELUS_LOCAUX	2017-11-28 09:00:00	2017-11-28 10:30:00	Conseiller Consulaire Moyen-Orient
7549	04042C	ACC_VISIT	2017-11-29 15:00:00	2017-11-29 16:00:00	Entretien avec le Président CNCTR
7550	04042C	REU_TRAV_PARL	2017-11-29 19:00:00	2017-11-29 20:00:00	\N
7551	04042C	ORG_POL	2017-11-29 20:30:00	2017-11-29 22:00:00	\N
7552	19705W	ORG_POL	2017-11-28 00:00:00	2017-11-28 00:00:00	\N
7553	19705W	ELUS_LOCAUX	2017-11-29 20:00:00	2017-11-29 22:00:00	Israël
7555	19707Y	COLLOQUE	2017-11-28 12:30:00	2017-11-28 13:30:00	Expatriation UFE
7556	19707Y	REU_TRAV_PARL	2017-11-29 14:00:00	2017-11-29 16:00:00	Réformes institutionnelles
7614	04086Q	ORG_POL	2017-12-12 11:00:00	2017-12-12 12:30:00	Réunion de groupe LR
7612	04086Q	REU_TRAV_PARL	2017-12-07 09:00:00	2017-12-07 10:30:00	Réunion du Bureau du Sénat
7613	04086Q	COLL_TER	2017-12-11 20:00:00	2017-12-11 21:30:00	Conseil Municipal Les Pavillons-sous-Bois
7662	04042C	COLLOQUE	2017-12-18 09:15:00	2017-12-18 10:00:00	Ouverture avec l'Ambassadeur d'Allemagne en France du Colloque Saint Cyr Relation Franco-Allemande de défense sur la politique de sécurité en Allemagne
7663	04042C	ACC_DEPL_INTER	2017-12-18 10:00:00	2017-12-18 11:00:00	Entretien avec Madame l'Ambassadeur d'Israël en France
7664	04042C	ACC_DEPL_INTER	2017-12-18 11:30:00	2017-12-18 12:30:00	Entretien avec des membres de l'Ambassade d'Australie
7665	04042C	ACC_VISIT	2017-12-18 13:00:00	2017-12-18 14:30:00	Entretien avec le Maire de Noiseau
7666	04042C	ELUS_LOCAUX	2017-12-18 15:00:00	2017-12-18 17:00:00	réunion avec le Directeur de l'APHP au sujet de l'Hôpital Henri Mondor de Créteil
7667	04042C	ELUS_LOCAUX	2017-12-18 19:00:00	2017-12-18 20:00:00	Conseil de territoire
7670	04042C	ACC_DEPL_INTER	2017-12-19 12:30:00	2017-12-19 14:30:00	Rencontre avec le Secrétaire Général de l'OTAN
7671	04042C	COLL_TER	2017-12-19 15:00:00	2017-12-19 16:00:00	\N
7672	04042C	COLL_TER	2017-12-19 00:00:00	2017-12-19 00:00:00	SEDIF
7673	04086Q	ACC_DEPL_INTER	2017-12-14 17:00:00	2017-12-14 18:00:00	Rencontre avec S.E. Pavel LATUSCHKA Ambassadeur de Biélorussie en France
7676	08010L	COLL_TER	2017-12-21 18:00:00	2017-12-21 19:00:00	Le Nouvion
7690	08009T	REU_TRAV_PARL	2018-01-03 15:00:00	2018-01-03 17:00:00	\N
7701	08009T	ORG_POL	2017-12-12 11:00:00	2017-12-12 13:00:00	\N
7707	08009T	CEREMONIE	2017-12-13 14:00:00	2017-12-13 17:30:00	\N
7703	08009T	REU_TRAV_PARL	2018-01-11 09:00:00	2018-01-11 11:00:00	\N
7694	08009T	ORGEXTPAR	2017-12-19 09:00:00	2017-12-19 12:00:00	\N
7695	08009T	REU_TRAV_PARL	2017-12-19 14:30:00	2017-12-19 15:30:00	\N
7696	08009T	ELUS_LOCAUX	2017-12-19 16:00:00	2017-12-19 16:45:00	\N
7698	08009T	REU_GVT	2017-12-21 09:00:00	2017-12-21 12:00:00	\N
7699	08009T	REU_GVT	2018-01-09 09:30:00	2018-01-09 18:00:00	\N
7700	08009T	REU_GVT	2017-12-12 08:30:00	2017-12-12 09:30:00	\N
7708	08009T	REU_TRAV_PARL	2017-12-13 18:30:00	2017-12-13 19:30:00	\N
7704	08009T	REU_GVT	2018-01-11 16:00:00	2018-01-11 17:00:00	\N
7706	08009T	CEREMONIE	2017-12-12 13:00:00	2017-12-12 19:00:00	\N
7709	08009T	ORG_POL	2017-12-14 09:00:00	2017-12-14 09:30:00	\N
7725	08010L	ELUS_LOCAUX	2018-01-10 00:00:00	2018-01-10 00:00:00	Voeux Conseil Départemental de l'Aisne 
7723	08010L	REU_TRAV_PARL	2018-01-09 15:30:00	2018-01-09 16:30:00	RDV Président LARCHER et Président des EPL
7724	08010L	COLL_TER	2018-01-10 17:30:00	2018-01-10 19:00:00	Voeux commune de Prémontré
7726	08010L	REU_TRAV_PARL	2018-01-11 09:30:00	2018-01-11 12:00:00	AG Union des Syndicats Agricoles de l'Aisne
7730	08010L	ORG_POL	2018-01-16 11:00:00	2018-01-16 12:45:00	Groupe LR du sénat
7729	08010L	ELUS_LOCAUX	2018-01-03 00:00:00	2018-01-03 00:00:00	Voeux maires Canton de Wassigny
7739	04042C	CEREMONIE	2018-01-11 00:00:00	2018-01-11 00:00:00	Cérémonie des voeux de Joinville-le-Pont
7740	04042C	ELUS_LOCAUX	2018-01-15 16:30:00	2018-01-15 17:30:00	Réunion de travail à la Mairie de Saint-Maurice
7741	04042C	CEREMONIE	2018-01-15 19:30:00	2018-01-15 21:30:00	Cérémonie des voeux à Thiais
7750	14065Q	REU_TRAV_PARL	2017-09-15 11:00:00	2017-09-15 12:00:00	Echanges PPL et PPLO Redressement de la justice
7743	04042C	ACC_DEPL_INTER	2018-01-16 15:00:00	2018-01-16 16:00:00	Rencontre avec des sénateurs pakistanais
7744	04042C	CEREMONIE	2018-01-16 18:00:00	2018-01-16 20:00:00	Cérémonie des voeux du Préfet à Créteil
7745	04042C	CEREMONIE	2018-01-12 18:30:00	2018-01-12 23:30:00	Cérémonie des voeux des communes de Périgny-sur-Yerres, Ablon-sur-Seine et Ormesson-sur-Marne
7747	04042C	REU_TRAV_PARL	2018-01-17 16:00:00	2018-01-17 17:00:00	\N
7748	04042C	REU_TRAV_PARL	2018-01-17 17:00:00	2018-01-17 18:30:00	Réunion GA France-Italie
7749	04042C	REU_TRAV_PARL	2018-01-17 08:30:00	2018-01-17 09:30:00	Assemblée générale du GA France-Russie
7751	14065Q	REU_TRAV_PARL	2017-09-15 12:30:00	2017-09-15 14:00:00	Déjeuner de travail PPL et PPL Redressement de la justice
7752	14065Q	ACC_VISIT	2017-09-21 10:15:00	2017-09-21 11:00:00	Visite de courtoisie
7753	14065Q	ACC_VISIT	2017-09-21 14:30:00	2017-09-21 15:30:00	Visite de courtoisie
7779	14065Q	ORG_POL	2017-10-24 10:30:00	2017-10-24 12:30:00	\N
7780	14065Q	ACC_VISIT	2017-10-24 14:45:00	2017-10-24 15:10:00	Interview
7781	14065Q	ORG_POL	2017-10-24 19:30:00	2017-10-24 21:30:00	\N
7782	14065Q	REU_TRAV_PARL	2017-11-07 09:00:00	2017-11-07 10:30:00	\N
7783	14065Q	ORG_POL	2017-11-07 10:30:00	2017-11-07 12:30:00	\N
7791	14065Q	ORG_POL	2017-11-15 12:00:00	2017-11-15 12:30:00	\N
7801	14065Q	ORG_POL	2017-11-29 08:30:00	2017-11-29 09:00:00	\N
7802	14065Q	COLL_TER	2017-12-01 10:00:00	2017-12-01 12:30:00	Plénière CDLAM
7803	14065Q	ELUS_LOCAUX	2017-12-04 11:00:00	2017-12-04 15:00:00	\N
7804	14065Q	ORG_POL	2017-12-05 10:30:00	2017-12-05 12:30:00	\N
7805	14065Q	COLLOQUE	2017-12-11 16:00:00	2017-12-11 18:00:00	\N
7806	14065Q	ORG_POL	2017-12-12 10:30:00	2017-12-12 12:30:00	\N
7807	14065Q	ACC_VISIT	2017-12-12 19:00:00	2017-12-12 21:30:00	\N
7808	14065Q	ORG_POL	2017-12-13 09:30:00	2017-12-13 10:00:00	\N
7809	14065Q	REU_TRAV_PARL	2017-12-13 17:00:00	2017-12-13 17:30:00	\N
7810	14065Q	REU_TRAV_PARL	2017-12-14 13:00:00	2017-12-14 15:00:00	\N
7813	14065Q	ACC_VISIT	2017-12-18 16:30:00	2017-12-18 17:00:00	\N
7816	14065Q	REU_TRAV_PARL	2017-12-20 10:00:00	2017-12-20 11:00:00	\N
7827	14089Y	REU_TRAV_PARL	2017-05-22 08:30:00	2017-05-22 09:30:00	\N
7828	14089Y	CEREMONIE	2017-05-25 11:30:00	2017-05-25 13:30:00	\N
7829	14089Y	CEREMONIE	2017-05-25 17:00:00	2017-05-25 18:00:00	\N
7846	14089Y	REU_TRAV_PARL	2017-06-21 09:30:00	2017-06-21 12:30:00	\N
7847	14089Y	CEREMONIE	2017-06-21 18:30:00	2017-06-21 19:15:00	\N
7848	14089Y	CEREMONIE	2017-06-23 12:00:00	2017-06-23 13:30:00	\N
7849	14089Y	CEREMONIE	2017-06-23 17:00:00	2017-06-23 18:30:00	\N
7850	14089Y	REU_TRAV_PARL	2017-06-26 08:00:00	2017-06-26 08:30:00	\N
7851	14089Y	REU_TRAV_PARL	2017-06-26 08:30:00	2017-06-26 09:30:00	\N
7852	14089Y	COLL_TER	2017-06-26 09:30:00	2017-06-26 12:00:00	\N
7853	14089Y	CEREMONIE	2017-06-26 18:30:00	2017-06-26 20:00:00	\N
7854	14089Y	REU_TRAV_PARL	2017-06-27 19:15:00	2017-06-27 20:00:00	\N
7855	14089Y	REU_TRAV_PARL	2017-06-28 14:30:00	2017-06-28 15:30:00	\N
7856	14089Y	ELUS_LOCAUX	2017-06-29 18:30:00	2017-06-29 22:30:00	\N
7857	08010L	REU_TRAV_PARL	2018-01-18 00:00:00	2018-01-18 00:00:00	commission des lois / vote électronique
7858	14089Y	CEREMONIE	2017-06-30 18:00:00	2017-06-30 19:00:00	\N
7859	14089Y	REU_TRAV_PARL	2017-06-30 16:30:00	2017-06-30 17:00:00	\N
7860	08010L	CEREMONIE	2018-01-18 18:00:00	2018-01-18 20:00:00	Ambassade des Etats-Unis
7865	08010L	CEREMONIE	2018-01-17 18:30:00	2018-01-17 20:00:00	voeux du Président du Sénat
7863	14089Y	ORG_POL	2017-07-03 11:00:00	2017-07-03 12:00:00	\N
7864	14089Y	DEPL_PRES_GVT	2017-07-03 15:00:00	2017-07-03 19:00:00	\N
7866	14089Y	REU_TRAV_PARL	2017-07-04 20:00:00	2017-07-04 23:00:00	\N
7867	14089Y	REU_TRAV_PARL	2017-07-05 11:00:00	2017-07-05 12:30:00	\N
7868	14089Y	COLL_TER	2017-07-07 15:00:00	2017-07-07 16:00:00	\N
6901	08010L	ELUS_LOCAUX	2017-09-19 18:00:00	2017-09-19 20:30:00	rencontres territoriales de mi-mandat Vervins
6921	08010L	ELUS_LOCAUX	2017-09-20 18:00:00	2017-09-20 20:30:00	rencontres territoriales de mi-mandat Soissons
6941	08010L	ELUS_LOCAUX	2017-09-21 11:00:00	2017-09-21 14:00:00	Bureau de l'Union des Maires de l'Aisne
7141	08010L	ELUS_LOCAUX	2017-10-10 18:30:00	2017-10-10 20:00:00	Intergroupe Canal Seine-Nord Europe
7142	08010L	COLL_TER	2017-10-11 10:00:00	2017-10-11 14:00:00	Comité Directeur AMF
7240	08048B	ACC_VISIT	2017-10-11 10:20:00	2017-10-11 11:00:00	Visite du Sénat par le Conseil municipal jeunes de Saint-Chamas
7243	19637C	ORG_POL	2017-10-25 12:00:00	2017-10-25 12:00:00	Groupe LREM
7244	19637C	DEL_ACT_PAR	2017-10-25 09:00:00	2017-10-25 09:00:00	Petit déjeuner FNSEA
7245	19637C	REU_TRAV_PARL	2017-10-25 11:00:00	2017-10-25 11:00:00	Commission Aménagement du Territoire et Développement durable
7870	14089Y	CEREMONIE	2017-07-07 18:30:00	2017-07-07 19:30:00	\N
7633	19705W	CEREMONIE	2017-12-07 18:00:00	2017-12-07 21:00:00	Comité des Associations Françaises de New York
7869	14089Y	COLL_TER	2017-07-07 16:00:00	2017-07-07 17:00:00	\N
7871	14089Y	REU_TRAV_PARL	2017-07-10 09:30:00	2017-07-10 10:30:00	\N
7872	14089Y	ELUS_LOCAUX	2017-07-10 10:30:00	2017-07-10 11:30:00	\N
7873	14089Y	REU_TRAV_PARL	2017-07-10 15:30:00	2017-07-10 16:30:00	\N
7891	08010L	REU_TRAV_PARL	2018-01-24 08:00:00	2018-01-24 09:00:00	LR /Logement
7892	08010L	REU_TRAV_PARL	2018-01-24 09:30:00	2018-01-24 10:30:00	France - Etats Unis 
7893	04042C	CEREMONIE	2018-01-22 18:00:00	2018-01-22 21:00:00	Cérémonie des Voeux de Madame la Ministre des Forces armées
7897	04042C	REU_TRAV_PARL	2018-01-23 12:00:00	2018-01-23 13:00:00	Réunion du Groupe Interparlementaire d'Amitié France-Maroc
7895	04042C	REU_GVT	2018-01-23 09:30:00	2018-01-23 10:30:00	Entretien avec Madame la Ministre des Forces armées
7896	04042C	ORG_POL	2018-01-23 11:00:00	2018-01-23 12:00:00	\N
7898	04042C	REU_TRAV_PARL	2018-01-23 14:00:00	2018-01-23 15:00:00	Réunion du Groupe Interparlementaire d'Amitié France-Maroc
7899	04042C	ACC_VISIT	2018-01-23 15:00:00	2018-01-23 16:00:00	Entretien avec le Président de la CESE
7900	04042C	REU_TRAV_PARL	2018-01-23 18:00:00	2018-01-23 19:00:00	\N
7901	04042C	CEREMONIE	2018-01-23 19:00:00	2018-01-23 20:00:00	Cérémonie des voeux de la Présidente du Conseil Régional d'Ile de France
7902	04042C	ACC_DEPL_INTER	2018-01-23 20:45:00	2018-01-23 22:30:00	Entretien Ambassadeur d'Italie
7946	14179A	COLL_TER	2018-01-08 15:00:00	2018-01-08 16:30:00	2CCAM
7904	04042C	ACC_DEPL_INTER	2018-01-24 13:00:00	2018-01-24 14:00:00	Entretien avec l'Ambassadeur d'Iran
7945	14179A	ELUS_LOCAUX	2018-01-08 09:00:00	2018-01-08 12:00:00	CEVA
7947	14179A	CEREMONIE	2018-01-08 19:00:00	2018-01-08 21:00:00	Voeux Thyez
7948	14179A	CEREMONIE	2018-01-09 19:30:00	2018-01-09 23:00:00	Voeux Neuvecelle
7949	14179A	REU_TRAV_PARL	2018-01-09 09:00:00	2018-01-09 13:30:00	Compétence tourisme
7950	14179A	ELUS_LOCAUX	2018-01-09 15:00:00	2018-01-09 16:00:00	Communes sinistrées
7951	14179A	CEREMONIE	2018-01-10 11:00:00	2018-01-10 12:00:00	Inauguration St Jorioz
7952	14179A	CEREMONIE	2018-01-10 19:00:00	2018-01-10 20:00:00	Voeux CC Cruseilles
7953	14179A	CEREMONIE	2018-01-10 20:00:00	2018-01-10 21:00:00	Voeux Grand Bo
7954	14179A	CEREMONIE	2018-01-11 19:00:00	2018-01-11 21:00:00	Voeux Rumilly
7955	14179A	CEREMONIE	2018-01-12 09:00:00	2018-01-12 13:30:00	Inauguration Grand Bo
7956	14179A	CEREMONIE	2018-01-12 16:00:00	2018-01-12 17:00:00	Voeux CDG
7957	14179A	CEREMONIE	2018-01-12 18:00:00	2018-01-12 19:00:00	Voeux CCVT
7958	14179A	CEREMONIE	2018-01-12 20:00:00	2018-01-12 21:00:00	Voeux Petit Bornand
7959	14179A	CEREMONIE	2018-01-15 11:00:00	2018-01-15 12:00:00	Maison de santé les Houches
7960	14179A	CEREMONIE	2018-01-15 15:00:00	2018-01-15 16:00:00	\N
7961	14179A	CEREMONIE	2018-01-15 17:30:00	2018-01-15 18:30:00	Voeux CD 74
7962	14179A	CEREMONIE	2018-01-16 11:00:00	2018-01-16 12:00:00	Voeux
7966	14179A	CEREMONIE	2018-01-18 18:30:00	2018-01-18 19:30:00	Voeux St Julien
7964	14179A	ORG_POL	2018-01-18 08:30:00	2018-01-18 09:30:00	\N
7965	14179A	ORGEXTPAR	2018-01-18 09:30:00	2018-01-18 12:30:00	CNIL
7967	14179A	ELUS_LOCAUX	2018-01-19 09:00:00	2018-01-19 10:00:00	\N
7968	14179A	CEREMONIE	2018-01-19 13:30:00	2018-01-19 14:30:00	Maison de la Santé Marignier
7969	14179A	CEREMONIE	2018-01-19 18:15:00	2018-01-19 19:15:00	Voeux Annemasse
7970	14179A	CEREMONIE	2018-01-19 19:00:00	2018-01-19 20:00:00	Voeux Veigy-Foncenex
7971	14179A	ELUS_LOCAUX	2018-01-22 09:00:00	2018-01-22 11:00:00	CA Chambéry
7972	14179A	CEREMONIE	2018-01-22 11:00:00	2018-01-22 12:00:00	Audience CA
7973	14179A	COLL_TER	2018-01-22 14:00:00	2018-01-22 15:00:00	2CCAM
7974	14179A	CEREMONIE	2018-01-22 19:00:00	2018-01-22 20:00:00	Voeux
7975	14179A	ORG_POL	2018-01-23 09:00:00	2018-01-23 10:00:00	\N
7976	14179A	ORG_POL	2018-01-23 11:00:00	2018-01-23 12:00:00	\N
7977	14179A	ACC_DEPL_INTER	2018-01-24 08:00:00	2018-01-24 09:30:00	\N
7978	14179A	ORGEXTPAR	2018-01-25 10:30:00	2018-01-25 12:00:00	CNIL
7979	14179A	CEREMONIE	2018-01-25 19:00:00	2018-01-25 21:00:00	Voeux Les Carroz
7985	14179A	COLL_TER	2018-01-26 15:00:00	2018-01-26 17:00:00	\N
7983	14179A	REU_TRAV_PARL	2018-01-26 08:30:00	2018-01-26 10:00:00	\N
7984	14179A	CEREMONIE	2018-01-26 11:00:00	2018-01-26 13:30:00	Label ANDRES
7990	04086Q	ORG_POL	2018-01-24 08:00:00	2018-01-24 10:30:00	Réunion de travail du groupe logement LR
7987	14179A	CEREMONIE	2018-01-26 18:00:00	2018-01-26 19:00:00	Voeux Sous-Pref St Julien
7988	14179A	CEREMONIE	2018-01-26 19:00:00	2018-01-26 21:00:00	Voeux Scionzier
7989	14179A	ORG_POL	2018-01-29 09:00:00	2018-01-29 22:00:00	\N
7991	04086Q	REU_TRAV_PARL	2018-01-24 15:00:00	2018-01-24 16:00:00	Réunion de travail sur thème du logement
7992	08009T	REU_GVT	2018-01-16 09:00:00	2018-01-16 14:00:00	\N
7993	08009T	REU_GVT	2018-01-16 18:00:00	2018-01-16 20:00:00	\N
7994	08009T	REU_TRAV_PARL	2018-01-17 08:00:00	2018-01-17 09:00:00	\N
7995	08009T	REU_TRAV_PARL	2018-01-17 11:30:00	2018-01-17 12:00:00	\N
7996	08009T	REU_TRAV_PARL	2018-01-17 15:30:00	2018-01-17 16:00:00	\N
7997	08009T	REU_TRAV_PARL	2018-01-17 16:00:00	2018-01-17 17:00:00	\N
7998	08009T	REU_GVT	2018-01-18 09:00:00	2018-01-18 11:00:00	\N
7999	08009T	REU_TRAV_PARL	2018-01-18 12:40:00	2018-01-18 13:00:00	\N
8000	08009T	REU_TRAV_PARL	2018-01-23 08:30:00	2018-01-23 09:30:00	\N
8001	08009T	REU_TRAV_PARL	2018-01-23 09:30:00	2018-01-23 10:00:00	\N
8002	08009T	REU_TRAV_PARL	2018-01-23 10:00:00	2018-01-23 11:00:00	\N
8003	08009T	ORG_POL	2018-01-23 11:00:00	2018-01-23 13:00:00	\N
8004	08009T	REU_TRAV_PARL	2018-01-23 13:00:00	2018-01-23 14:30:00	\N
8005	08009T	REU_TRAV_PARL	2018-01-24 12:30:00	2018-01-24 15:00:00	\N
8006	08009T	REU_TRAV_PARL	2018-01-24 16:30:00	2018-01-24 17:00:00	\N
8007	08009T	REU_GVT	2018-01-25 09:30:00	2018-01-25 19:30:00	\N
8008	08010L	ELUS_LOCAUX	2018-01-25 18:00:00	2018-01-25 20:00:00	voeux de la Thiérache du Centre
8009	08010L	COLL_TER	2018-01-25 15:00:00	2018-01-25 16:00:00	Régie de Quartier Laon
8010	04042C	ELUS_LOCAUX	2018-01-29 12:00:00	2018-01-29 13:00:00	Entretien avec le Président de l'Association de Gemmologie
8011	04042C	ACC_DEPL_INTER	2018-01-29 13:00:00	2018-01-29 14:30:00	Entretien avec l'Ambassadeur du Cameroun
8012	04042C	ACC_DEPL_INTER	2018-01-29 15:00:00	2018-01-29 16:00:00	Entretien avec le Nouvel Ambassadeur de Cuba
8013	04042C	COLL_TER	2018-01-26 13:00:00	2018-01-26 15:00:00	\N
8042	14089Y	ELUS_LOCAUX	2017-08-04 10:00:00	2017-08-04 12:00:00	\N
8043	14089Y	ELUS_LOCAUX	2017-08-04 12:30:00	2017-08-04 14:30:00	\N
8049	14089Y	CEREMONIE	2017-08-15 11:30:00	2017-08-15 14:00:00	\N
8050	14089Y	CEREMONIE	2017-08-15 18:00:00	2017-08-15 19:00:00	\N
8051	14089Y	CEREMONIE	2017-08-15 20:00:00	2017-08-15 22:00:00	\N
8052	14089Y	COLL_TER	2017-08-16 15:00:00	2017-08-16 16:00:00	\N
8053	14089Y	ELUS_LOCAUX	2017-08-17 10:30:00	2017-08-17 11:30:00	\N
8054	14089Y	ELUS_LOCAUX	2017-08-17 12:00:00	2017-08-17 14:00:00	\N
8055	14089Y	CEREMONIE	2017-08-18 17:30:00	2017-08-18 19:00:00	\N
8056	14089Y	CEREMONIE	2017-08-18 19:30:00	2017-08-18 20:30:00	\N
8057	14089Y	COLL_TER	2017-08-28 11:00:00	2017-08-28 12:00:00	\N
8058	14089Y	REU_TRAV_PARL	2017-08-31 18:00:00	2017-08-31 19:00:00	\N
8059	14089Y	COLL_TER	2017-09-01 10:00:00	2017-09-01 12:00:00	\N
8060	14089Y	CEREMONIE	2017-09-01 18:30:00	2017-09-01 19:30:00	\N
8061	14089Y	ELUS_LOCAUX	2017-09-01 19:30:00	2017-09-01 20:30:00	\N
8062	14089Y	COLL_TER	2017-09-06 14:00:00	2017-09-06 17:00:00	\N
8063	14089Y	CEREMONIE	2017-09-06 10:30:00	2017-09-06 11:30:00	\N
8064	14089Y	ELUS_LOCAUX	2017-09-07 12:00:00	2017-09-07 14:00:00	\N
8065	14089Y	COLL_TER	2017-09-07 14:00:00	2017-09-07 16:00:00	\N
8066	14089Y	REU_TRAV_PARL	2017-09-07 16:15:00	2017-09-07 17:45:00	\N
8085	04042C	DEPL_PRES_GVT	2018-01-31 00:00:00	2018-01-31 00:00:00	Mission au Sahel avec le Chef d'état-major de l'armée de terre
8084	04042C	DEPL_PRES_GVT	2018-01-30 00:00:00	2018-01-30 00:00:00	Mission au Sahel aux côtés du Chef d'état-major de l'armée de terre 
8086	04042C	DEPL_PRES_GVT	2018-02-01 00:00:00	2018-02-01 00:00:00	Mission au Sahel avec le Chef d'état-major de l'armée de terre
8087	04042C	DEPL_PRES_GVT	2018-02-02 00:00:00	2018-02-02 00:00:00	Mission au Sahel avec le Chef d'état-major de l'armée de terre
8088	04086Q	COLL_TER	2018-01-29 18:30:00	2018-01-29 20:30:00	BM mairie des Pavillons-sous-Bois
6846	08009T	REU_TRAV_PARL	2017-07-04 17:00:00	2017-07-04 18:00:00	\N
6847	08009T	ORG_POL	2017-07-04 19:00:00	2017-07-04 20:00:00	\N
6848	08009T	REU_GVT	2017-02-27 17:30:00	2017-02-27 18:30:00	\N
6849	08009T	REU_GVT	2017-06-28 17:30:00	2017-06-28 18:30:00	\N
7124	08010L	ORG_POL	2017-10-10 11:00:00	2017-10-10 13:00:00	Groupe LR du sénat
7327	14211G	ORG_POL	2017-11-07 11:00:00	2017-11-07 12:00:00	Groupe Les Républicains
7332	14211G	ORG_POL	2017-10-03 10:30:00	2017-10-03 12:00:00	Groupe Les Républicains
7333	14211G	ORG_POL	2017-09-27 10:30:00	2017-09-27 12:00:00	Groupe Les Républicains
7403	04086Q	ACC_DEPL_INTER	2017-11-10 14:30:00	2017-11-10 15:45:00	Rencontre avec "Les femmes oeuvrent pour la paix", dans le cadre du Groupe France-Israël
7404	04086Q	REU_TRAV_PARL	2017-11-10 15:45:00	2017-11-10 17:30:00	Réunion de travail du groupe Logement
7406	04086Q	COLL_TER	2017-11-13 12:30:00	2017-11-13 14:00:00	Déjeuner de travail avec le Président de la Métropole du Grand-Paris
7410	04086Q	REU_TRAV_PARL	2017-11-15 13:00:00	2017-11-15 14:30:00	Réunion de travail du groupe Logement
7409	04086Q	CEREMONIE	2017-11-14 16:15:00	2017-11-14 16:45:00	Hommage à Georges Clémeanceau
7411	04086Q	COLL_TER	2017-11-17 11:00:00	2017-11-17 12:15:00	Mairie des Pavillons-Sous-Bois, Réunion EPIF
7448	19705W	ELUS_LOCAUX	2017-11-23 12:30:00	2017-11-23 14:30:00	Conseiller Consulaire Afrique
7450	19707Y	ELUS_LOCAUX	2017-11-23 12:30:00	2017-11-23 14:30:00	Conseiller Consulaire Afrique
7449	19707Y	ELUS_LOCAUX	2017-11-23 09:00:00	2017-11-23 10:30:00	Conseiller Consulaire Amérique du Nord
7541	04018C	ELUS_LOCAUX	2017-11-16 09:00:00	2017-11-16 11:00:00	\N
7543	04018C	CEREMONIE	2017-11-23 11:30:00	2017-11-23 13:00:00	\N
7544	04018C	ELUS_LOCAUX	2017-11-29 13:15:00	2017-11-29 14:30:00	\N
7585	08039A	REU_TRAV_PARL	2017-11-14 14:30:00	2017-11-14 16:00:00	Audiovisuel public
7591	08039A	ELUS_LOCAUX	2017-11-22 11:00:00	2017-11-22 15:00:00	Congrès des maires
7592	08039A	COLL_TER	2017-11-24 15:00:00	2017-11-24 18:00:00	Réunions Permanence 
7596	08039A	DEL_ACT_PAR	2017-11-29 09:00:00	2017-11-29 14:00:00	Séminaire Patrimoine
7597	08039A	COLL_TER	2017-12-01 15:00:00	2017-12-01 18:00:00	Réunions Permanence 
7598	08010L	ORG_POL	2017-12-05 10:30:00	2017-12-05 11:30:00	Groupe LR du sénat
7599	08010L	CEREMONIE	2017-12-05 00:00:00	2017-12-05 00:00:00	remise des Écharpes d'Or de la Prévention Routière
7644	04042C	ELUS_LOCAUX	2017-12-15 12:00:00	2017-12-15 13:00:00	Rencontre avec des élus du Val-de-Marne
7645	04042C	ACC_VISIT	2017-12-15 15:00:00	2017-12-15 15:30:00	Visite du Collège de Joinville-le-Pont
7646	04042C	ACC_VISIT	2017-12-15 15:30:00	2017-12-15 16:30:00	Entretien avec le Président de l'IFRI
7731	14089Y	REU_TRAV_PARL	2017-05-03 10:00:00	2017-05-03 11:00:00	\N
7732	14089Y	CEREMONIE	2017-05-04 10:30:00	2017-05-04 11:30:00	\N
7733	14089Y	ELUS_LOCAUX	2017-05-04 11:30:00	2017-05-04 12:00:00	\N
7734	14089Y	CEREMONIE	2017-05-05 12:00:00	2017-05-05 13:00:00	\N
7735	14089Y	CEREMONIE	2017-05-08 11:00:00	2017-05-08 12:00:00	\N
7736	14089Y	REU_TRAV_PARL	2017-05-11 20:00:00	2017-05-11 21:00:00	\N
7755	14065Q	ORG_POL	2017-09-26 11:00:00	2017-09-26 13:00:00	\N
7738	14089Y	ELUS_LOCAUX	2017-05-19 15:30:00	2017-05-19 16:30:00	\N
7754	14065Q	ORG_POL	2017-09-26 09:30:00	2017-09-26 11:00:00	\N
7756	14065Q	ORG_POL	2017-09-26 16:00:00	2017-09-26 17:00:00	\N
7757	14065Q	ACC_VISIT	2017-09-28 15:30:00	2017-09-28 16:30:00	\N
7758	14065Q	ORG_POL	2017-10-03 10:30:00	2017-10-03 12:30:00	\N
7759	14065Q	ORG_POL	2017-10-03 18:00:00	2017-10-03 20:00:00	\N
7760	14065Q	ORG_POL	2017-10-04 14:30:00	2017-10-04 15:30:00	\N
7761	14065Q	ORG_POL	2017-10-04 17:00:00	2017-10-04 17:45:00	\N
7762	14065Q	ACC_DEPL_INTER	2017-10-04 18:30:00	2017-10-04 21:30:00	\N
7763	14065Q	ACC_VISIT	2017-10-06 12:15:00	2017-10-06 14:30:00	Déjeuner de travail
7764	14065Q	ORG_POL	2017-10-10 10:30:00	2017-10-10 12:30:00	\N
7765	14065Q	REU_TRAV_PARL	2017-10-10 15:00:00	2017-10-10 16:00:00	\N
7766	14065Q	REU_TRAV_PARL	2017-10-10 17:45:00	2017-10-10 18:30:00	\N
7767	14065Q	ORG_POL	2017-10-11 00:00:00	2017-10-11 00:00:00	\N
7768	14065Q	REU_TRAV_PARL	2017-10-11 09:30:00	2017-10-11 10:00:00	\N
7769	14065Q	ACC_VISIT	2017-10-12 12:30:00	2017-10-12 14:30:00	Déjeuner de travail
7770	14065Q	ACC_VISIT	2017-10-12 14:30:00	2017-10-12 15:30:00	Réunion de travail
7771	14065Q	ACC_VISIT	2017-10-12 15:30:00	2017-10-12 16:30:00	Rencontre de presse
7772	14065Q	ELUS_LOCAUX	2017-10-12 17:00:00	2017-10-12 19:00:00	\N
7773	14065Q	ORG_POL	2017-10-17 10:30:00	2017-10-17 12:30:00	\N
7774	14065Q	REU_TRAV_PARL	2017-10-17 17:45:00	2017-10-17 19:30:00	\N
7775	14065Q	ACC_VISIT	2017-10-17 19:30:00	2017-10-17 20:45:00	\N
7776	14065Q	ORG_POL	2017-10-18 09:30:00	2017-10-18 10:00:00	\N
7777	14065Q	ACC_VISIT	2017-10-18 14:00:00	2017-10-18 14:30:00	Interview
7778	14065Q	ACC_VISIT	2017-10-20 17:00:00	2017-10-20 19:00:00	Intervention festival "Justice en cultures"
7784	14065Q	ACC_VISIT	2017-11-10 12:30:00	2017-11-10 14:00:00	\N
7785	14065Q	ACC_VISIT	2017-11-10 14:30:00	2017-11-10 17:00:00	\N
7789	14065Q	ACC_VISIT	2017-11-14 15:30:00	2017-11-14 16:15:00	\N
7790	14065Q	ORG_POL	2017-11-15 09:30:00	2017-11-15 10:00:00	\N
7788	14065Q	ORG_POL	2017-11-14 10:30:00	2017-11-14 12:30:00	\N
7792	14065Q	ACC_VISIT	2017-11-17 10:00:00	2017-11-17 19:30:00	Colloque CGLPL
7793	14065Q	COLL_TER	2017-11-20 10:00:00	2017-11-20 15:00:00	Institut du droit local
7794	14065Q	ORG_POL	2017-11-21 08:00:00	2017-11-21 09:00:00	\N
7795	14065Q	ORG_POL	2017-11-21 11:00:00	2017-11-21 12:30:00	\N
7796	14065Q	ELUS_LOCAUX	2017-11-21 12:30:00	2017-11-21 15:00:00	Déjeuner du Congrès des Maires
7797	14065Q	ORG_POL	2017-11-22 08:45:00	2017-11-22 09:10:00	\N
7798	14065Q	ACC_VISIT	2017-11-24 15:00:00	2017-11-24 17:30:00	\N
7799	14065Q	ELUS_LOCAUX	2017-11-27 12:30:00	2017-11-27 14:30:00	\N
7800	14065Q	ORG_POL	2017-11-28 10:30:00	2017-11-28 12:30:00	\N
7812	14065Q	ELUS_LOCAUX	2017-12-15 15:00:00	2017-12-15 17:00:00	\N
7814	14065Q	ORG_POL	2017-12-19 11:00:00	2017-12-19 12:30:00	\N
7815	14065Q	ORG_POL	2017-12-19 00:00:00	2017-12-19 00:00:00	\N
7830	14089Y	REU_TRAV_PARL	2017-05-29 14:00:00	2017-05-29 15:00:00	\N
7831	14089Y	ELUS_LOCAUX	2017-06-06 10:30:00	2017-06-06 11:30:00	\N
7832	14089Y	ELUS_LOCAUX	2017-06-06 19:00:00	2017-06-06 20:30:00	\N
7833	14089Y	CEREMONIE	2017-06-07 11:00:00	2017-06-07 12:30:00	\N
7834	14089Y	ORG_POL	2017-06-07 18:30:00	2017-06-07 20:00:00	\N
7835	14089Y	REU_TRAV_PARL	2017-06-08 09:30:00	2017-06-08 10:30:00	\N
7836	14089Y	CEREMONIE	2017-06-08 11:30:00	2017-06-08 12:30:00	\N
7837	14089Y	REU_TRAV_PARL	2017-06-08 14:00:00	2017-06-08 16:00:00	\N
7838	14089Y	COLL_TER	2017-06-08 18:30:00	2017-06-08 21:00:00	\N
7839	14089Y	CEREMONIE	2017-06-09 11:00:00	2017-06-09 12:00:00	\N
7840	14089Y	REU_TRAV_PARL	2017-06-12 15:30:00	2017-06-12 16:30:00	\N
7841	14089Y	ELUS_LOCAUX	2017-06-12 16:30:00	2017-06-12 17:30:00	\N
7842	14089Y	REU_TRAV_PARL	2017-06-15 10:30:00	2017-06-15 11:30:00	\N
7843	14089Y	ELUS_LOCAUX	2017-06-16 16:00:00	2017-06-16 21:00:00	\N
7844	14089Y	REU_TRAV_PARL	2017-06-19 08:30:00	2017-06-19 09:30:00	\N
7845	14089Y	REU_TRAV_PARL	2017-06-20 18:00:00	2017-06-20 19:00:00	\N
7883	04086Q	REU_TRAV_PARL	2018-01-22 14:00:00	2018-01-22 16:00:00	RDV avec M. NEDELEC et ROQUES (Seine-Saint-Denis Habitat)
7881	04086Q	REU_TRAV_PARL	2018-01-17 09:00:00	2018-01-17 09:30:00	\N
7882	04086Q	REU_TRAV_PARL	2018-01-18 17:00:00	2018-01-18 18:00:00	RDV avec M. DEVYS (ARS) sur le devenir de l'Hôpital Jean Verdier à Bondy
7884	04086Q	ACC_DEPL_INTER	2018-01-22 17:30:00	2018-01-22 18:30:00	Accueil du président Arménien Serge SARKISSIAN au côté de Gérard LARCHER
7885	19705W	ORG_POL	2018-01-16 11:00:00	2018-01-16 12:30:00	\N
7886	19705W	ORG_POL	2018-01-23 10:30:00	2018-01-23 12:30:00	\N
7887	19705W	ACC_DEPL_INTER	2017-12-19 13:00:00	2017-12-19 14:30:00	Déjeuner Ministre Arménie / Groupe d'Amitié
7888	19707Y	ORG_POL	2018-01-16 11:00:00	2018-01-16 12:30:00	\N
7890	08010L	ORG_POL	2018-01-23 10:30:00	2018-01-23 12:00:00	Groupe LR du sénat
7943	14179A	CEREMONIE	2018-01-04 20:30:00	2018-01-04 22:30:00	\N
7941	08010L	REU_TRAV_PARL	2018-01-23 12:30:00	2018-01-23 14:30:00	France RFA
7942	14179A	ELUS_LOCAUX	2018-01-04 12:00:00	2018-01-04 15:00:00	\N
7944	14179A	CEREMONIE	2018-01-05 19:00:00	2018-01-05 21:00:00	Voeux Marnaz
8089	04086Q	REU_TRAV_PARL	2018-01-30 15:30:00	2018-01-30 16:30:00	Groupe de travail sur la fiscalité locale
8090	04086Q	DEPL_PRES_GVT	2018-01-30 17:00:00	2018-01-30 19:00:00	Voeux du Président de la République au Palais de l'Elysée
8091	04086Q	ELUS_LOCAUX	2018-01-31 12:30:00	2018-01-31 14:30:00	Déjeuner de travail 
8092	04086Q	REU_TRAV_PARL	2018-01-31 19:00:00	2018-01-31 20:00:00	Conférence des présidents
8093	04086Q	COLL_TER	2018-02-02 08:00:00	2018-02-02 12:00:00	Réunion Métropole du Grand Paris
8094	04086Q	REU_TRAV_PARL	2018-02-02 15:00:00	2018-02-02 16:00:00	\N
8105	04043D	CEREMONIE	2018-01-09 11:00:00	2018-01-09 12:15:00	Voeux château de Vincennes 
8106	04043D	CEREMONIE	2018-01-09 18:30:00	2018-01-09 19:30:00	Commémoration Hyper Cacher
8107	04043D	CEREMONIE	2018-01-09 19:30:00	2018-01-09 20:30:00	Voeux Saint-Maurice
8108	04043D	CEREMONIE	2018-01-10 12:00:00	2018-01-10 14:30:00	Visite de l'ecole Ferrandi
8109	04043D	CEREMONIE	2018-01-10 20:00:00	2018-01-10 21:00:00	Voeux Maison-Alfort
8110	04043D	CEREMONIE	2018-01-11 19:30:00	2018-01-11 20:30:00	Voeux Joinville-le-Pont
8111	04043D	CEREMONIE	2018-01-12 18:30:00	2018-01-12 19:30:00	Voeux Le Plessis-Trévise
8112	04043D	CEREMONIE	2018-01-12 19:30:00	2018-01-12 21:30:00	Voeux d'Ormesson-sur-Marne
8113	04043D	CEREMONIE	2018-01-15 19:30:00	2018-01-15 21:30:00	Voeux Thiais
8114	04043D	ORG_POL	2018-01-16 11:00:00	2018-01-16 12:00:00	Réunion de groupe
8135	11063M	REU_TRAV_PARL	2018-02-02 14:00:00	2018-02-02 20:00:00	Visite de l'EHPAD de Lamballe (22)
8136	11063M	ELUS_LOCAUX	2018-02-02 20:00:00	2018-02-02 21:30:00	Rencontre avec les élus locaux sur l'aide à domicile
7021	08010L	ORG_POL	2017-10-03 10:30:00	2017-10-03 13:00:00	Groupe LR du sénat
7044	08039A	ACC_DEPL_INTER	2017-10-04 11:00:00	2017-10-04 12:00:00	\N
7046	08039A	DEL_ACT_PAR	2017-09-29 09:00:00	2017-09-29 19:00:00	Congrès National Sites et Cités remarquables Calais 
7047	08039A	ORG_POL	2017-10-10 11:00:00	2017-10-10 12:30:00	\N
7070	08039A	ACC_DEPL_INTER	2017-09-26 09:00:00	2017-09-26 13:00:00	Visite de SAS le Prince de Monaco
7069	08039A	COLL_TER	2017-09-25 14:00:00	2017-09-25 16:00:00	\N
7050	08039A	COLL_TER	2017-10-16 09:00:00	2017-10-16 11:00:00	Média
7051	08039A	ORG_POL	2017-10-17 11:00:00	2017-10-17 12:30:00	\N
7071	08039A	REU_TRAV_PARL	2017-09-27 08:30:00	2017-09-27 09:30:00	\N
7072	08039A	ORG_POL	2017-09-27 10:30:00	2017-09-27 14:00:00	\N
7101	04018C	REU_TRAV_PARL	2017-10-10 17:45:00	2017-10-10 18:00:00	\N
7201	08010L	COLL_TER	2017-10-19 18:00:00	2017-10-19 20:00:00	Communauté d'Agglomération de Laon
7103	04018C	COLL_TER	2017-10-17 18:00:00	2017-10-17 20:00:00	\N
7221	08009T	REU_TRAV_PARL	2017-10-10 10:00:00	2017-10-10 11:00:00	\N
7222	08009T	ORG_POL	2017-10-10 11:00:00	2017-10-10 13:00:00	\N
7223	08009T	REU_TRAV_PARL	2017-10-10 18:30:00	2017-10-10 19:00:00	\N
7224	08009T	REU_TRAV_PARL	2017-10-11 08:30:00	2017-10-11 09:30:00	\N
7225	08009T	REU_GVT	2017-10-11 10:00:00	2017-10-11 11:00:00	\N
7226	08009T	REU_TRAV_PARL	2017-10-11 12:00:00	2017-10-11 13:00:00	\N
7227	08009T	REU_TRAV_PARL	2017-10-17 09:30:00	2017-10-17 10:30:00	\N
7228	08009T	ORG_POL	2017-10-17 11:00:00	2017-10-17 13:00:00	\N
7229	08009T	COLLOQUE	2017-10-17 14:00:00	2017-10-17 16:30:00	\N
7230	08009T	REU_TRAV_PARL	2017-10-18 14:30:00	2017-10-18 15:15:00	\N
7231	08009T	REU_TRAV_PARL	2017-10-18 13:00:00	2017-10-18 14:00:00	\N
7232	08009T	REU_TRAV_PARL	2017-10-18 15:30:00	2017-10-18 16:30:00	\N
7233	08009T	REU_TRAV_PARL	2017-10-18 16:30:00	2017-10-18 17:15:00	\N
7234	08009T	REU_TRAV_PARL	2017-10-18 17:15:00	2017-10-18 18:30:00	\N
7235	08009T	REU_TRAV_PARL	2017-10-19 09:00:00	2017-10-19 10:00:00	\N
7236	08009T	REU_TRAV_PARL	2017-10-19 10:00:00	2017-10-19 11:00:00	\N
7237	08009T	REU_TRAV_PARL	2017-10-19 13:00:00	2017-10-19 14:00:00	\N
7238	08009T	REU_TRAV_PARL	2017-10-19 16:00:00	2017-10-19 17:00:00	\N
7301	19413M	ELUS_LOCAUX	2017-11-06 19:00:00	2017-11-06 19:00:00	Election du Président du SIEL
7241	08048B	ORG_POL	2017-10-10 12:00:00	2017-10-10 12:00:00	Groupe Les Républicains du Sénat
7242	08010L	REU_TRAV_PARL	2017-10-24 11:00:00	2017-10-24 13:30:00	Prévention routière 
7323	14041T	ACC_VISIT	2017-10-04 20:30:00	2017-10-04 22:30:00	élus consulaires
7324	14041T	ACC_VISIT	2017-10-04 12:30:00	2017-10-04 14:30:00	élus consulaires
7394	08010L	ORG_POL	2017-11-14 11:00:00	2017-11-14 12:30:00	Groupe LR du sénat
7436	19705W	ORG_POL	2017-11-21 11:00:00	2017-11-21 12:30:00	\N
8104	04043D	CEREMONIE	2018-01-08 16:30:00	2018-01-08 17:30:00	Voeux IGN
7445	19707Y	ORG_POL	2017-11-21 11:00:00	2017-11-21 12:30:00	\N
7446	08010L	ORG_POL	2017-11-21 11:00:00	2017-11-21 12:30:00	Groupe LR du sénat
7490	04042C	REU_TRAV_PARL	2017-10-10 10:00:00	2017-10-10 11:00:00	\N
8205	14089Y	REU_TRAV_PARL	2017-09-14 15:30:00	2017-09-14 16:30:00	\N
7483	14133K	DEPL_PRES_GVT	2017-11-14 09:30:00	2017-11-14 22:00:00	Forum sur la sécurité en Afrique, Dakar
7485	14133K	ELUS_LOCAUX	2017-11-21 19:00:00	2017-11-21 22:00:00	accueil et diner des maires du Calvados
7491	04042C	ORG_POL	2017-10-10 11:00:00	2017-10-10 12:30:00	\N
7492	04042C	REU_TRAV_PARL	2017-10-10 15:00:00	2017-10-10 16:00:00	\N
7493	04042C	ELUS_LOCAUX	2017-10-10 19:30:00	2017-10-10 20:30:00	\N
7494	04042C	CEREMONIE	2017-10-10 21:00:00	2017-10-10 22:30:00	Inauguration Gauguin
7495	04042C	ACC_DEPL_INTER	2017-10-11 15:00:00	2017-10-11 16:00:00	Entretien avec le Vice-président de la Fédération en Russie 
7496	04042C	ACC_DEPL_INTER	2017-10-11 19:00:00	2017-10-11 22:00:00	Festival le Printemps du Violon à l'Ambassade de Russie 
7502	04042C	ACC_DEPL_INTER	2017-10-12 16:15:00	2017-10-12 17:15:00	Entretien avec L'Ambassadeur et le Ministre conseiller d'Allemagne
7498	04042C	REU_TRAV_PARL	2017-10-12 08:30:00	2017-10-12 12:30:00	\N
7504	04042C	ELUS_LOCAUX	2017-10-13 15:00:00	2017-10-13 17:00:00	\N
7500	04042C	ACC_VISIT	2017-10-12 08:00:00	2017-10-12 08:30:00	Entretien avec le Général des Forces armées
7503	04042C	COLL_TER	2017-10-13 08:45:00	2017-10-13 11:30:00	Bureau du SEDIF
7505	04042C	REU_GVT	2017-10-13 12:00:00	2017-10-13 13:00:00	\N
7506	04042C	REU_TRAV_PARL	2017-10-16 16:00:00	2017-10-16 18:00:00	\N
7508	04042C	COLL_TER	2017-10-16 20:00:00	2017-10-16 22:00:00	Entretien avec le Préfet du Val-de-Marne
7509	04042C	ACC_VISIT	2017-10-17 08:00:00	2017-10-17 08:30:00	Entretien avec le Général
7510	04042C	ELUS_LOCAUX	2017-10-17 10:00:00	2017-10-17 11:00:00	Entretien avec Monsieur Vincent Jeanbrun - Maire de l'Haÿ-les-Roses
7511	04042C	REU_GVT	2017-10-17 18:15:00	2017-10-17 19:15:00	Entretien avec la Minsitre des Armées
7512	04042C	DEPL_PRES_GVT	2017-10-17 20:00:00	2017-10-17 00:00:00	Présentation des Forces aériennes stratégiques
7542	04018C	CEREMONIE	2017-11-21 10:00:00	2017-11-21 11:00:00	\N
7615	08010L	ORG_POL	2017-12-12 00:00:00	2017-12-12 00:00:00	Groupe LR du sénat
7617	08039A	REU_TRAV_PARL	2017-12-05 09:00:00	2017-12-05 11:00:00	Colloque Audiovisuel à ASSAS
7618	08039A	REU_TRAV_PARL	2017-12-05 14:30:00	2017-12-05 15:30:00	RDV Audiovisuel
7619	08039A	REU_TRAV_PARL	2017-12-05 15:30:00	2017-12-05 16:30:00	RDV Audiovisuel
7620	08039A	REU_TRAV_PARL	2017-12-06 09:30:00	2017-12-06 11:30:00	Intervention chronologie des médias 
7621	08039A	REU_TRAV_PARL	2017-12-06 16:00:00	2017-12-06 17:00:00	Interview média audiovisuel
7622	08039A	REU_TRAV_PARL	2017-12-06 16:00:00	2017-12-06 17:00:00	RDV Audiovisuel
7683	04042C	DEPL_PRES_GVT	2018-01-10 00:00:00	2018-01-10 00:00:00	Visite en Chine avec le Président de la République française
8035	19705W	ORG_POL	2018-01-30 09:30:00	2018-01-30 12:45:00	\N
8102	04043D	CEREMONIE	2018-01-08 19:30:00	2018-01-08 20:30:00	Voeux Charenton-le-Pont
7928	04042C	CEREMONIE	2018-01-24 19:30:00	2018-01-24 21:30:00	Cérémonie des Voeux de la Commune de Limeil Brévannes
8103	04043D	REU_TRAV_PARL	2018-01-08 14:00:00	2018-01-08 15:30:00	rencontre LECHERVY et organisation Pacifique
8115	04043D	REU_TRAV_PARL	2018-01-17 09:00:00	2018-01-17 10:00:00	Bureau Affaires Economiques
8119	04043D	CEREMONIE	2018-01-18 11:30:00	2018-01-18 12:30:00	Voeux de l'Institut le Val-Mandé
8170	04042C	ACC_VISIT	2018-02-12 14:30:00	2018-02-12 16:00:00	Visite du Sénat d'une classe de l'Haÿ-les-Roses
8118	04043D	REU_TRAV_PARL	2018-01-17 13:45:00	2018-01-17 14:45:00	GIA France-Australie
8120	04043D	CEREMONIE	2018-01-18 16:00:00	2018-01-18 17:00:00	Voeux Hopital d'instruction des Amées Bégin
8121	04043D	CEREMONIE	2018-01-18 19:00:00	2018-01-18 20:00:00	Voeux Noiseau
8122	04043D	CEREMONIE	2018-01-19 19:00:00	2018-01-19 20:00:00	Voeux de Sucy-en-Brie
8123	04043D	ORG_POL	2018-01-23 10:30:00	2018-01-23 12:00:00	Réunion de groupe
8124	04043D	REU_TRAV_PARL	2018-01-23 15:00:00	2018-01-23 16:00:00	FFTelecom avec  S. PRIMAS
8125	04043D	COLL_TER	2018-01-23 19:00:00	2018-01-23 20:00:00	Réunion en circonscription Saint-Mandé
8126	04043D	REU_TRAV_PARL	2018-01-24 18:00:00	2018-01-24 19:00:00	AG - GPE
8127	04043D	CEREMONIE	2018-01-24 19:00:00	2018-01-24 20:00:00	Voeux de la communauté spatiale
8128	04043D	CEREMONIE	2018-01-24 21:00:00	2018-01-24 22:30:00	Voeux Limeil-Brévannes
8132	04043D	CEREMONIE	2018-01-26 19:00:00	2018-01-26 20:00:00	Voeux Rungis
8130	04043D	REU_TRAV_PARL	2018-01-25 14:30:00	2018-01-25 15:30:00	Session Ordinaire droit d¿asile
8131	04043D	CEREMONIE	2018-01-26 12:00:00	2018-01-26 13:00:00	Hopital Saint Camille Bry-sur-Marne
8133	04043D	CEREMONIE	2018-01-29 19:00:00	2018-01-29 21:00:00	Voeux Association des Élus Minoritaires du 94
8134	08010L	ORG_POL	2018-02-06 11:00:00	2018-02-06 12:30:00	Groupe LR du sénat
8140	04086Q	ACC_DEPL_INTER	2018-02-05 15:00:00	2018-02-05 16:00:00	Accueil, au côté de Gérard Larcher, de Aubin MINAKU MDJALAMDJOKO, président de l'Assemblée Nationale de République Démocratique du Congo
8142	04086Q	ACC_DEPL_INTER	2018-02-06 20:00:00	2018-02-06 21:30:00	Réception donnée par l'ambassadrice d'Israël en France en l'honneur d'une délégation parlementaire de la Knesset
8143	04086Q	COLL_TER	2018-02-07 17:30:00	2018-02-07 18:00:00	Débat sur Public Sénat  au sujet de l'organisation territoriale.
8153	04042C	REU_TRAV_PARL	2018-02-07 08:30:00	2018-02-07 09:00:00	Entretien avec le Président du Sénat
8154	04042C	REU_TRAV_PARL	2018-02-07 08:00:00	2018-02-07 08:30:00	\N
8155	04042C	REU_TRAV_PARL	2018-02-07 12:30:00	2018-02-07 17:00:00	Réunion Franco-Britannique à l'Assemblée nationale
8156	04042C	REU_TRAV_PARL	2018-02-07 17:30:00	2018-02-07 18:00:00	Entretien avec le Questeur du Sénat
8161	04043D	REU_TRAV_PARL	2018-01-17 14:45:00	2018-01-17 15:30:00	GIA France-  îles Salomon
8159	08010L	COLLOQUE	2018-02-08 16:00:00	2018-02-08 17:30:00	Clôture Conférence de Consensus sur le Logement 
8168	04042C	ELUS_LOCAUX	2018-02-09 11:30:00	2018-02-09 12:30:00	Mairie de Saint-Maurice
8169	04042C	DEPL_PRES_GVT	2018-02-09 15:00:00	2018-02-09 23:00:00	Visite de deux jours avec le Premier ministre aux Emirats Arabes Unis
8171	04042C	REU_TRAV_PARL	2018-02-12 16:00:00	2018-02-12 17:30:00	\N
8172	04042C	ELUS_LOCAUX	2018-02-12 20:30:00	2018-02-12 22:00:00	Conseil municipal de Saint-Maurice
8176	08010L	REU_TRAV_PARL	2018-02-13 10:00:00	2018-02-13 12:30:00	Bureau Fédération EPL/Logement
8177	14327T	ELUS_LOCAUX	2017-11-17 10:00:00	2017-11-17 12:00:00	Réunion maitien de la ligne ferroviaire Aubrac
6961	08010L	ELUS_LOCAUX	2017-09-26 18:00:00	2017-09-26 20:30:00	rencontres territoriales de mi-mandat Saint-Quentin
6862	08010L	ELUS_LOCAUX	2017-09-12 18:00:00	2017-09-12 20:30:00	rencontres territoriales de mi-mandat Chauny
6881	08010L	COLL_TER	2017-09-13 18:00:00	2017-09-13 19:30:00	Bureau Agglomération du pays de Laon 
7183	08010L	REU_TRAV_PARL	2017-10-17 18:00:00	2017-10-17 18:45:00	Fédération des EPL
7402	04042C	ACC_VISIT	2017-11-20 10:30:00	2017-11-20 11:30:00	Entretien avec des administrés
7401	04042C	ORG_POL	2017-11-20 08:15:00	2017-11-20 10:30:00	Bureau politique
7545	04042C	ORGEXTPAR	2017-11-29 08:00:00	2017-11-29 09:30:00	Rencontre Groupe Marck
7546	19707Y	ORG_POL	2017-11-28 10:30:00	2017-11-28 12:30:00	\N
7548	19707Y	ELUS_LOCAUX	2017-11-29 20:00:00	2017-11-29 22:00:00	Conseiller Consulaire Israël
7554	19705W	REU_TRAV_PARL	2017-11-29 14:00:00	2017-11-29 16:00:00	\N
7560	14133K	ACC_DEPL_INTER	2017-11-29 08:45:00	2017-11-29 12:00:00	rencontres à la Préfecture maritime de la méditerranée, en qualité de Représentant spécial pour les affaires méditerranéennes de l'AP-OSCE
7558	04018C	CEREMONIE	2017-12-05 11:00:00	2017-12-05 12:00:00	Morts pour la France
7559	04018C	ELUS_LOCAUX	2017-12-06 18:30:00	2017-12-06 19:30:00	\N
7561	14133K	ACC_DEPL_INTER	2017-11-29 12:00:00	2017-11-29 18:00:00	rencontres à la base militaire de Toulon, en qualité de Représentant spécial pour les affaires méditerranéennes de l'AP-OSCE
7562	04042C	REU_TRAV_PARL	2017-11-30 08:30:00	2017-11-30 12:00:00	\N
7563	04042C	ORG_POL	2017-11-30 22:00:00	2017-11-30 23:00:00	\N
7605	04042C	ORG_POL	2017-12-12 11:00:00	2017-12-12 12:00:00	\N
7606	04042C	ELUS_LOCAUX	2017-12-12 12:00:00	2017-12-12 13:00:00	Rencontre avec les seniors de Saint-Maurice
7607	04042C	REU_TRAV_PARL	2017-12-12 18:30:00	2017-12-12 19:30:00	Groupe de réflexion de vigilence et de solidarité avec les Chrétiens et les minorités au Moyen-Orient
7608	04086Q	REU_GVT	2017-12-04 16:00:00	2017-12-04 17:00:00	RDV avec les conseillers de l'Elysée au sujet du Grand-Paris
7609	04042C	CEREMONIE	2017-12-12 20:00:00	2017-12-12 23:00:00	Rencontre de sensibilisation et de mobilisation en faveur des Chrétiens d'Orient
7610	04086Q	ORG_POL	2017-12-05 11:00:00	2017-12-05 12:30:00	Réunion de groupe LR
7616	08010L	REU_TRAV_PARL	2017-12-12 12:00:00	2017-12-12 13:00:00	Château Villers-Cotterêts 
7623	08039A	REU_TRAV_PARL	2017-12-07 10:00:00	2017-12-07 11:00:00	CNAP RDV Patrimoine 
7624	08039A	COLL_TER	2017-12-08 14:00:00	2017-12-08 17:00:00	\N
7625	08039A	COLL_TER	2017-12-08 11:00:00	2017-12-08 12:00:00	Inauguration Hopital 
7626	08039A	COLL_TER	2017-12-11 11:00:00	2017-12-11 12:00:00	Interview Médias 
7627	08039A	REU_TRAV_PARL	2017-12-12 16:00:00	2017-12-12 17:00:00	Interview Médias 
7687	04086Q	REU_TRAV_PARL	2018-01-11 09:00:00	2018-01-11 13:00:00	Présidence du groupe de travail Logement "Enjeux et évolutions du secteur social"
7697	08009T	REU_TRAV_PARL	2017-12-20 09:30:00	2017-12-20 10:30:00	\N
7710	08009T	REU_TRAV_PARL	2017-12-14 11:00:00	2017-12-14 12:30:00	\N
7711	08009T	REU_TRAV_PARL	2017-12-05 08:00:00	2017-12-05 09:00:00	\N
7712	08009T	ORG_POL	2017-12-05 11:00:00	2017-12-05 13:00:00	\N
7713	08009T	REU_TRAV_PARL	2017-12-05 16:30:00	2017-12-05 17:30:00	\N
7714	08009T	REU_TRAV_PARL	2017-12-06 08:00:00	2017-12-06 09:00:00	\N
7715	08009T	REU_TRAV_PARL	2017-12-06 13:00:00	2017-12-06 14:00:00	\N
7716	08009T	REU_TRAV_PARL	2017-12-06 18:00:00	2017-12-06 19:00:00	\N
7717	08009T	REU_GVT	2017-12-07 09:30:00	2017-12-07 14:00:00	\N
7821	08010L	REU_TRAV_PARL	2018-01-17 00:00:00	2018-01-17 00:00:00	commission des finances / justice
7822	08010L	REU_TRAV_PARL	2018-01-17 16:00:00	2018-01-17 18:30:00	collaborateurs
7823	04018C	ELUS_LOCAUX	2018-01-10 19:00:00	2018-01-10 20:30:00	\N
7824	04018C	CEREMONIE	2018-01-16 18:00:00	2018-01-16 20:00:00	\N
7825	04018C	CEREMONIE	2018-01-18 18:30:00	2018-01-18 20:30:00	\N
7826	04018C	COLL_TER	2018-01-25 19:00:00	2018-01-25 20:30:00	\N
7922	08010L	ELUS_LOCAUX	2018-01-25 10:00:00	2018-01-25 12:00:00	Office HLM Aisne
8139	04086Q	ACC_VISIT	2018-02-05 11:00:00	2018-02-05 14:00:00	Groupe d'élus et de retraités d'Epinay-sur-Seine
8141	04086Q	ORG_POL	2018-02-06 11:00:00	2018-02-06 12:30:00	Réunion groupe LR
8138	04086Q	ACC_DEPL_INTER	2018-02-02 13:30:00	2018-02-02 15:00:00	Présidence du déjeuner de l'assemblée parlementaire de la Francophonie (représentant Gérard Larcher)
8144	04042C	ACC_DEPL_INTER	2018-02-05 15:00:00	2018-02-05 16:00:00	Entretien avec le Président du Sénat et le Président de l'Assemblée nationale de la République démocratique du Congo
8145	04042C	REU_TRAV_PARL	2018-02-05 16:30:00	2018-02-05 17:30:00	audition
8146	04042C	ELUS_LOCAUX	2018-02-05 19:00:00	2018-02-05 21:00:00	Réunion du Conseil de territoire
8147	04042C	ACC_DEPL_INTER	2018-02-06 10:00:00	2018-02-06 11:00:00	Entretien avec une délégation de la Knesset
8148	04042C	ORG_POL	2018-02-06 11:00:00	2018-02-06 12:00:00	\N
8149	04042C	REU_TRAV_PARL	2018-02-06 16:20:00	2018-02-06 16:45:00	Conférence des Présidents 
8150	04042C	REU_TRAV_PARL	2018-02-06 18:00:00	2018-02-06 19:00:00	Réunion du Groupe Interparlementaire d'Amitié France-Saint-Siège
8151	04042C	CEREMONIE	2018-02-06 19:00:00	2018-02-06 20:00:00	Légion d'Honneur
8152	04042C	ACC_DEPL_INTER	2018-02-06 20:00:00	2018-02-06 22:00:00	Groupe Interparlementaire d'Amitié France Maroc à l'Ambassade du Maroc
8157	04042C	REU_TRAV_PARL	2018-02-08 15:00:00	2018-02-08 16:00:00	Audition
8178	14327T	ACC_VISIT	2017-11-21 18:30:00	2017-11-21 21:00:00	Accueil des élus du Cantal dans le cadre du congrès de maires
8179	14327T	ELUS_LOCAUX	2017-12-01 10:00:00	2017-12-01 12:00:00	Réunion arrondissement de Mauriac sur la DETR 2018
8180	14327T	ELUS_LOCAUX	2017-12-01 18:00:00	2017-12-01 19:00:00	Réunion arrondissement Aurillac sur la DETR 2018
8181	14327T	ELUS_LOCAUX	2017-12-04 00:00:00	2017-12-04 00:00:00	Réunion arrondissement de Saint-Flour DETR 2018
8182	14327T	COLL_TER	2017-12-11 09:30:00	2017-12-11 13:00:00	Conférence des territoires du Cantal
8183	14327T	COLL_TER	2017-12-22 09:30:00	2017-12-22 12:30:00	Session au conseil départemental
8188	14327T	CEREMONIE	2018-01-15 11:00:00	2018-01-15 12:30:00	Voeux du Préfet
8185	14327T	ELUS_LOCAUX	2018-01-11 19:30:00	2018-01-11 22:00:00	Participation au conseil municipal de Naucelles
8186	14327T	ELUS_LOCAUX	2018-01-10 19:30:00	2018-01-10 21:30:00	Participation au conseil municipal de Saignes
8187	14327T	CEREMONIE	2018-01-12 18:30:00	2018-01-12 20:30:00	Voeux de la commune de Mauriac
8189	14327T	REU_TRAV_PARL	2018-01-16 09:00:00	2018-01-16 17:00:00	PaIntervention au colloque "sport-santé" à Dijon
8190	14327T	REU_TRAV_PARL	2018-01-17 13:00:00	2018-01-17 15:00:00	Réunion parlementaire maintien cour d'appel à Riom
8191	14327T	CEREMONIE	2018-01-17 19:30:00	2018-01-17 20:30:00	Voeux du Président du Sénat
8192	14327T	REU_TRAV_PARL	2018-01-19 11:00:00	2018-01-19 12:00:00	avec la section des retraités de la FDSEA sur le sujet des retraites agricoles
8193	14327T	CEREMONIE	2018-01-19 18:00:00	2018-01-19 20:00:00	Voeux de la commune de Massiac
8194	14327T	CEREMONIE	2018-01-22 18:30:00	2018-01-22 20:30:00	Voeux du Sous-Préfet de Saint-Flour
8195	14327T	CEREMONIE	2018-01-26 18:00:00	2018-01-26 20:00:00	Voeux Sous-Préfète de Mauriac
8196	14327T	REU_TRAV_PARL	2018-01-29 09:00:00	2018-01-29 19:00:00	Séminaire du groupe UC
8197	14327T	ELUS_LOCAUX	2018-02-02 19:30:00	2018-02-02 21:00:00	Participation au conseil municipal de Freix-Anglards
8198	14089Y	REU_TRAV_PARL	2017-09-08 14:00:00	2017-09-08 15:00:00	\N
8199	14089Y	REU_TRAV_PARL	2017-09-08 15:00:00	2017-09-08 16:00:00	\N
8200	14089Y	REU_TRAV_PARL	2017-09-11 11:00:00	2017-09-11 12:00:00	\N
8201	14089Y	COLL_TER	2017-09-12 10:00:00	2017-09-12 15:00:00	\N
8202	14089Y	CEREMONIE	2017-09-13 19:00:00	2017-09-13 21:30:00	\N
8203	14089Y	CEREMONIE	2017-09-14 11:00:00	2017-09-14 12:00:00	\N
8204	14089Y	REU_TRAV_PARL	2017-09-14 14:30:00	2017-09-14 15:30:00	\N
8206	14089Y	REU_TRAV_PARL	2017-09-15 11:00:00	2017-09-15 12:00:00	\N
8207	14089Y	COLL_TER	2017-09-15 14:00:00	2017-09-15 15:00:00	\N
8208	14089Y	ELUS_LOCAUX	2017-09-15 18:30:00	2017-09-15 21:30:00	\N
8209	14089Y	ELUS_LOCAUX	2017-09-18 12:00:00	2017-09-18 14:00:00	\N
8210	14089Y	CEREMONIE	2017-09-18 18:30:00	2017-09-18 19:30:00	\N
8211	14089Y	CEREMONIE	2017-09-19 15:00:00	2017-09-19 17:00:00	\N
8212	14089Y	CEREMONIE	2017-09-19 17:00:00	2017-09-19 18:00:00	\N
8213	14089Y	REU_TRAV_PARL	2017-09-22 10:30:00	2017-09-22 11:30:00	\N
8214	14089Y	ELUS_LOCAUX	2017-09-22 12:30:00	2017-09-22 14:00:00	\N
8215	14089Y	CEREMONIE	2017-09-22 16:00:00	2017-09-22 17:00:00	\N
8216	14089Y	CEREMONIE	2017-09-22 17:30:00	2017-09-22 18:30:00	\N
8217	14089Y	REU_TRAV_PARL	2017-09-22 18:30:00	2017-09-22 19:30:00	\N
8223	14089Y	COLL_TER	2017-10-04 15:00:00	2017-10-04 18:00:00	\N
8224	14089Y	ELUS_LOCAUX	2017-10-05 20:30:00	2017-10-05 22:30:00	\N
8225	14089Y	CEREMONIE	2017-10-06 11:30:00	2017-10-06 12:30:00	\N
8226	14089Y	CEREMONIE	2017-10-06 18:00:00	2017-10-06 19:00:00	\N
8227	14089Y	REU_TRAV_PARL	2017-10-11 15:00:00	2017-10-11 16:00:00	\N
8228	14089Y	CEREMONIE	2017-10-13 11:00:00	2017-10-13 12:00:00	\N
8232	14089Y	COLL_TER	2017-10-16 09:00:00	2017-10-16 12:00:00	\N
8230	14089Y	CEREMONIE	2017-10-13 12:00:00	2017-10-13 13:00:00	\N
8231	14089Y	CEREMONIE	2017-10-13 20:30:00	2017-10-13 22:30:00	\N
8233	14089Y	ELUS_LOCAUX	2017-10-16 12:30:00	2017-10-16 14:00:00	\N
8234	14089Y	CEREMONIE	2017-10-16 17:30:00	2017-10-16 18:30:00	\N
8253	14089Y	REU_TRAV_PARL	2017-11-06 08:00:00	2017-11-06 08:30:00	\N
8254	14089Y	ELUS_LOCAUX	2017-11-06 09:30:00	2017-11-06 10:30:00	\N
8442	04043D	CEREMONIE	2018-02-12 20:00:00	2018-02-12 21:00:00	Soirée chien guides
8320	04086Q	COLL_TER	2018-02-15 17:00:00	2018-02-15 19:00:00	CA de l'ADIL
8426	04043D	ACC_VISIT	2018-02-21 15:00:00	2018-02-21 16:00:00	Rencontre groupe de travail scolaire
8445	89017R	REU_TRAV_PARL	2018-01-31 19:00:00	2018-01-31 20:00:00	Conférence des Présidents
8443	04043D	ORG_POL	2018-02-14 18:00:00	2018-02-14 20:00:00	commission nationale d'investitutre LR
8444	04018C	ORGEXTPAR	2018-03-08 00:00:00	2018-03-08 00:00:00	commission régionale de classement des objets mobiliers
8665	19705W	ORG_POL	2018-03-27 11:00:00	2018-03-27 14:30:00	\N
8666	04042C	DEPL_PRES_GVT	2018-03-26 08:25:00	2018-03-26 08:45:00	Accueil du Premier Ministre à Saint-Maurice
8667	04042C	ACC_DEPL_INTER	2018-03-26 18:30:00	2018-03-26 19:30:00	Entretien avec le Secrétaire Génaral du parti Communiste du Vietnam avec le Président du Sénat
8668	04042C	COLL_TER	2018-03-26 20:00:00	2018-03-26 22:00:00	Conseil de territoire
8669	04042C	REU_TRAV_PARL	2018-03-27 10:00:00	2018-03-27 11:00:00	\N
8670	04042C	ORG_POL	2018-03-27 11:00:00	2018-03-27 12:30:00	\N
8671	04042C	ACC_DEPL_INTER	2018-03-27 15:00:00	2018-03-27 16:00:00	Entretien avec la Vice-Présidente d'Argentine, Présidente du Sénat avec le Président du Sénat
8672	04042C	ACC_VISIT	2018-03-27 16:30:00	2018-03-27 16:45:00	Interview Public Sénat sur l'Etat d'urgence
8673	04042C	ACC_DEPL_INTER	2018-03-27 18:30:00	2018-03-27 20:00:00	Ambassade d'argentine à l'occasion de la visite de la Vice-Présidente
8674	04042C	CEREMONIE	2018-03-27 20:00:00	2018-03-27 22:00:00	Accueil de l'Academie de la Marine
8675	04042C	ELUS_LOCAUX	2018-03-28 08:30:00	2018-03-28 09:30:00	Rencontre matinale avec la Présidente de la Région d'Ile-de-France
8676	04042C	CEREMONIE	2018-03-28 11:30:00	2018-03-28 13:00:00	Hommage national au Colonel Arnaud Beltrame aux Invalides
8678	14327T	COLL_TER	2018-03-23 09:00:00	2018-03-23 12:00:00	Commission permanente CD15
8679	14327T	COLL_TER	2018-03-23 14:30:00	2018-03-23 17:30:00	Session au conseil départemental
8680	14327T	COLL_TER	2018-03-23 18:00:00	2018-03-23 21:00:00	Bureau communautaire
8681	14327T	REU_TRAV_PARL	2018-03-27 09:30:00	2018-03-27 10:45:00	Lancement du comité des élus à l'abeille
8682	14327T	REU_TRAV_PARL	2018-03-27 11:00:00	2018-03-27 12:30:00	Réunion groupe UC avec la Ministre Jacqueline Gourault
8732	04042C	ACC_VISIT	2018-04-04 13:00:00	2018-04-04 14:00:00	Rencontre avec le Président del'AEFE
8733	04042C	ACC_DEPL_INTER	2018-04-04 17:00:00	2018-04-04 17:30:00	Entretien avec le Président du Gouvernement autonome de la Vallée d'Aoste - Francophone
8769	19705W	REU_TRAV_PARL	2018-04-10 18:00:00	2018-04-10 19:00:00	Groupe Tourisme
8804	04043D	REU_TRAV_PARL	2018-04-10 18:00:00	2018-04-10 19:00:00	réunion AGAS
8805	04043D	REU_TRAV_PARL	2018-04-11 18:00:00	2018-04-11 19:00:00	RDV avec la secrétaire générale de la Préfecture du Val-de-Marne, Madame Fabienne BALUSSOU
8823	04086Q	COLL_TER	2018-04-09 20:00:00	2018-04-09 22:00:00	Conseil Municipal des Pavillons-sous-Bois
8828	04086Q	ORG_POL	2018-04-13 08:00:00	2018-04-13 09:00:00	Réunion du groupe LR Métropole du Grand Paris
8829	04086Q	COLL_TER	2018-04-13 09:00:00	2018-04-13 12:30:00	Conseil de métropole Grand Paris
8830	04086Q	ELUS_LOCAUX	2018-04-13 17:30:00	2018-04-13 18:30:00	RDV président du CD 93 sur le TZen3
8831	14211G	ELUS_LOCAUX	2018-04-12 12:00:00	2018-04-12 15:30:00	Echange avec les élus du Clermontais
8832	14211G	CEREMONIE	2018-04-12 18:00:00	2018-04-12 19:00:00	Yom Hashoa - Hommage aux victimes de la barbarie nazie 
8833	14211G	ORG_POL	2018-04-10 11:00:00	2018-04-10 12:00:00	Groupe Les Républicains
8834	14211G	ACC_DEPL_INTER	2018-04-11 19:15:00	2018-04-11 22:00:00	Dîner avec des Ambassadeurs de pays d'Afrique
8835	14211G	ORG_POL	2018-04-03 11:00:00	2018-04-03 12:00:00	Groupe Les Républicains
8836	14211G	ELUS_LOCAUX	2018-04-03 09:30:00	2018-04-03 10:30:00	\N
8837	14211G	REU_GVT	2018-04-05 11:30:00	2018-04-05 12:30:00	\N
8838	14211G	ELUS_LOCAUX	2018-03-29 12:00:00	2018-03-29 14:00:00	\N
8839	14211G	ELUS_LOCAUX	2018-03-29 11:00:00	2018-03-29 12:00:00	\N
8840	14211G	CEREMONIE	2018-03-29 16:30:00	2018-03-29 17:00:00	Hommage aux victimes du terrorismes
8841	14211G	CEREMONIE	2018-03-29 17:00:00	2018-03-29 18:00:00	Hommage à Mireille Knoll
8842	14211G	ORG_POL	2018-03-28 08:30:00	2018-03-28 09:30:00	\N
8843	14211G	CEREMONIE	2018-03-28 11:30:00	2018-03-28 12:30:00	Hommage national au Colonel Arnaud Beltrame dans la Cour d'honneur des Invalides
8844	14211G	ORG_POL	2018-03-27 11:00:00	2018-03-27 12:00:00	Groupe Les Républicains
8921	14147R	COLLOQUE	2018-04-18 12:00:00	2018-04-18 13:30:00	Génétique et révision de la loi bioéthique, quels enjeux?
9003	04086Q	DEPL_PRES_GVT	2018-05-02 08:00:00	2018-05-02 23:00:00	Voyage en Israël dans le cadre du groupe d'amitié pour l'année croisée
9004	04086Q	DEPL_PRES_GVT	2018-05-03 00:00:00	2018-05-03 00:00:00	Voyage en Israël dans le cadre du groupe d'amitié pour l'année croisée
9005	04086Q	DEPL_PRES_GVT	2018-05-04 00:00:00	2018-05-04 00:00:00	Voyage en Israël dans le cadre du groupe d'amitié pour l'année croisée
9022	04042C	CEREMONIE	2018-05-08 11:00:00	2018-05-08 14:00:00	Cérémonie du 8 mai 1945 Saint-Maurice et Charenton-le-Pont
9023	04042C	REU_TRAV_PARL	2018-05-09 10:30:00	2018-05-09 12:30:00	réunion de travail sur la Loi de Programmation Militaire
9024	04042C	ACC_DEPL_INTER	2018-05-09 13:00:00	2018-05-09 15:00:00	Rencontre avec le Représentant de Taïwan
9025	04042C	ACC_DEPL_INTER	2018-05-09 16:00:00	2018-05-09 17:00:00	Rencontre avec l'Ambassadeur de Slovénie
9026	04042C	REU_TRAV_PARL	2018-05-09 17:00:00	2018-05-09 18:00:00	\N
9027	04042C	REU_GVT	2018-05-14 10:30:00	2018-05-14 11:30:00	Entretien avec le Secrétaire d'Etat auprès du Premier Ministre, Porte-parole
9028	04042C	ACC_VISIT	2018-05-14 11:45:00	2018-05-14 11:20:00	Talk le Figaro 
9029	04042C	REU_TRAV_PARL	2018-05-14 15:00:00	2018-05-14 16:30:00	Loi de Programmation Militaire
9030	04042C	ACC_VISIT	2018-05-14 16:45:00	2018-05-14 17:15:00	Public Sénat : débat sur le retrait des U.S.A sur le traité sur le nucléaire iranien
9034	04042C	ACC_DEPL_INTER	2018-05-14 20:00:00	2018-05-14 22:00:00	Rencontre avec les Leaders de la Paix
9032	04042C	CEREMONIE	2018-05-14 18:30:00	2018-05-14 19:00:00	Remise de diplôme en partenariat avec l'Ambassade de Slovaquie
9033	04042C	ACC_DEPL_INTER	2018-05-14 19:30:00	2018-05-14 20:00:00	Visite du Secrétaire général de l'OTAN
9035	04042C	ORG_POL	2018-05-15 10:00:00	2018-05-15 11:00:00	\N
9039	04042C	ORG_POL	2018-05-16 08:00:00	2018-05-16 09:00:00	\N
9040	04042C	ACC_VISIT	2018-05-16 15:00:00	2018-05-16 16:00:00	Entretien Naval Group
9081	14327T	DEPL_PRES_GVT	2018-03-29 10:00:00	2018-03-29 18:00:00	Visite Ministérielle Jean-Michel Blanquer et Jacques Mézard
9082	14327T	REU_TRAV_PARL	2018-03-30 10:00:00	2018-03-30 11:30:00	Réunion de travail Comité régional de la retraite sportive sur le développement du sport santé
9083	14327T	REU_TRAV_PARL	2018-03-30 14:30:00	2018-03-30 16:30:00	Fiscalité agricole avec CER France
9084	14327T	REU_TRAV_PARL	2018-04-06 12:30:00	2018-04-06 14:30:00	Police de proximité du quotidien en Préfecture
9085	14327T	ELUS_LOCAUX	2018-04-06 19:00:00	2018-04-06 22:00:00	Commune de Labesserette : présentation des projets de l'année
9086	14327T	ELUS_LOCAUX	2018-04-09 14:30:00	2018-04-09 18:00:00	Réunion sur la RN122
9087	14327T	ELUS_LOCAUX	2018-04-24 20:00:00	2018-04-24 22:00:00	Participation au conseil municial de Vic sur Cère
9088	14327T	ELUS_LOCAUX	2018-04-25 18:00:00	2018-04-25 22:00:00	Participation au conseil municipal de Champs sur Tarentaine
9089	14327T	ELUS_LOCAUX	2018-04-26 10:30:00	2018-04-26 12:30:00	Rencontre de l'AMF 15
9090	14327T	REU_TRAV_PARL	2018-05-14 11:00:00	2018-05-14 14:00:00	visite de l'entreprise Biovitis
9091	14327T	REU_TRAV_PARL	2018-04-03 11:00:00	2018-04-03 12:30:00	Réunion groupe UC
9092	14327T	REU_TRAV_PARL	2018-04-10 11:00:00	2018-04-10 12:30:00	Réunion groupe UC
9093	14327T	REU_TRAV_PARL	2018-04-17 11:00:00	2018-04-17 12:30:00	Réunion gorupe UC
9094	14327T	REU_TRAV_PARL	2018-05-15 11:00:00	2018-05-15 12:30:00	Réunion groupe UC
9095	14327T	REU_TRAV_PARL	2018-05-17 10:00:00	2018-05-17 11:30:00	Réunion groupe de travail fiscalité
9201	19705W	ORG_POL	2018-04-17 11:00:00	2018-04-17 12:30:00	\N
9202	19705W	REU_TRAV_PARL	2018-04-19 00:00:00	2018-04-19 00:00:00	Tourisme
9207	19707Y	ORG_POL	2018-04-17 11:00:00	2018-04-17 12:30:00	\N
9208	19707Y	ORG_POL	2018-05-15 11:00:00	2018-05-15 12:30:00	\N
9211	19707Y	ELUS_LOCAUX	2018-05-23 13:00:00	2018-05-23 14:30:00	Asie
9232	08009T	REU_TRAV_PARL	2018-05-22 18:50:00	2018-05-22 19:30:00	\N
9236	08009T	REU_GVT	2018-05-17 11:30:00	2018-05-17 12:30:00	\N
9234	08009T	REU_GVT	2018-05-17 08:15:00	2018-05-17 09:15:00	\N
9235	08009T	REU_TRAV_PARL	2018-05-17 09:30:00	2018-05-17 10:30:00	\N
9237	08009T	REU_TRAV_PARL	2018-05-16 08:00:00	2018-05-16 09:00:00	\N
9238	08009T	REU_TRAV_PARL	2018-05-16 12:00:00	2018-05-16 13:00:00	\N
9239	08009T	REU_TRAV_PARL	2018-05-16 13:00:00	2018-05-16 14:00:00	\N
9240	08009T	REU_TRAV_PARL	2018-05-16 14:00:00	2018-05-16 15:00:00	\N
9241	08009T	ORG_POL	2018-05-15 11:00:00	2018-05-15 13:00:00	\N
9242	08009T	ORG_POL	2018-05-15 13:00:00	2018-05-15 14:30:00	\N
8427	04042C	REU_TRAV_PARL	2018-02-26 16:00:00	2018-02-26 17:30:00	\N
8452	04042C	DEPL_PRES_GVT	2018-02-28 00:00:00	2018-02-28 00:00:00	Mission du Syndicat des Eaux d'ile-de-France
8453	04042C	DEPL_PRES_GVT	2018-03-01 00:00:00	2018-03-01 00:00:00	Mission du Syndicat des Eaux d'ile-de-France
8451	04042C	DEPL_PRES_GVT	2018-02-27 00:00:00	2018-02-27 00:00:00	Mission du Syndicat des Eaux d'ile-de-France
8454	04042C	DEPL_PRES_GVT	2018-03-02 00:00:00	2018-03-02 00:00:00	Mission du Syndicat des Eaux d'ile-de-France
8455	04042C	ORG_POL	2018-03-05 10:00:00	2018-03-05 11:00:00	\N
8456	04042C	ACC_VISIT	2018-03-05 13:00:00	2018-03-05 15:00:00	Réunion de travail
8457	04042C	ACC_DEPL_INTER	2018-03-05 15:00:00	2018-03-05 16:00:00	Entretien Premier ministre du Québec avec le Président du Sénat
8458	04042C	ACC_VISIT	2018-03-05 16:30:00	2018-03-05 17:30:00	Entretien avec une élue
8459	04042C	ACC_VISIT	2018-03-05 17:30:00	2018-03-05 18:30:00	Rencontre ANAJ-IHEDN
8465	04042C	ORG_POL	2018-03-07 08:00:00	2018-03-07 09:00:00	\N
8466	19705W	ORG_POL	2018-03-06 11:00:00	2018-03-06 12:30:00	\N
8467	19705W	REU_TRAV_PARL	2018-03-06 17:00:00	2018-03-06 19:00:00	\N
8468	19707Y	ORG_POL	2018-03-06 11:00:00	2018-03-06 12:30:00	\N
8489	01025N	COLLOQUE	2018-03-06 17:00:00	2018-03-06 19:00:00	révision constitutionnelle 10 ans après
8490	01025N	ELUS_LOCAUX	2018-03-07 08:00:00	2018-03-07 09:30:00	rencontre Président de région et Vice-présidents Grand Est
8491	14211G	ELUS_LOCAUX	2018-03-08 11:00:00	2018-03-08 12:00:00	\N
8514	14327T	REU_TRAV_PARL	2018-03-07 13:30:00	2018-03-07 16:00:00	Groupe PPL Assainissement
8517	14211G	ORG_POL	2018-02-20 11:00:00	2018-02-20 12:00:00	Groupe Les Républicains
8515	14211G	REU_TRAV_PARL	2018-03-06 20:00:00	2018-03-06 22:30:00	Dîner de travail CAED
8531	14211G	CEREMONIE	2018-01-25 20:00:00	2018-01-25 21:00:00	Voeux de la Région Occitanie
8532	14211G	CEREMONIE	2018-01-24 18:30:00	2018-01-24 20:00:00	Voeux Agglo Pays de l'Or
8497	14327T	REU_GVT	2018-02-16 00:00:00	2018-02-16 00:00:00	En présence des Ministres Lemaire et Travert lancement groupe travail fiscalité agricole
8533	14211G	CEREMONIE	2017-12-25 18:30:00	2017-12-25 20:00:00	Voeux Castelnau-le-Lez
8499	14211G	ELUS_LOCAUX	2018-02-22 16:30:00	2018-02-22 17:30:00	\N
8500	14211G	ORG_POL	2018-02-13 00:00:00	2018-02-13 00:00:00	Groupe Les Républicains
8534	14211G	CEREMONIE	2018-01-11 18:30:00	2018-01-11 20:00:00	Voeux Castelnau-le-Lez
8535	14211G	CEREMONIE	2018-01-09 18:30:00	2018-01-09 20:00:00	Voeux Hérépian
8503	14327T	ELUS_LOCAUX	2018-03-05 09:30:00	2018-03-05 11:30:00	Réunion DETR
8507	14327T	REU_TRAV_PARL	2018-03-06 11:00:00	2018-03-06 12:30:00	Réunion groupe UC
8505	14327T	ELUS_LOCAUX	2018-03-05 13:45:00	2018-03-05 16:45:00	Réunion DETR
8506	14211G	CEREMONIE	2018-02-06 00:00:00	2018-02-06 00:00:00	Hommage au Préfet Erignac
8508	14211G	ELUS_LOCAUX	2018-02-08 20:00:00	2018-02-08 23:00:00	\N
8509	14327T	REU_TRAV_PARL	2018-03-06 14:30:00	2018-03-06 17:00:00	Groupe travail fiscalité
8510	14327T	REU_TRAV_PARL	2018-03-06 17:00:00	2018-03-06 20:00:00	Groupe évolution constitution
8511	14327T	REU_TRAV_PARL	2018-02-21 11:00:00	2018-02-21 12:00:00	Groupe fiscalité
8512	14211G	ORG_POL	2018-03-06 11:00:00	2018-03-06 12:00:00	Groupe Les Républicains
8513	14211G	REU_TRAV_PARL	2018-03-06 17:00:00	2018-03-06 18:30:00	Groupe révision constitutionnelle
8516	14327T	ELUS_LOCAUX	2018-03-09 10:00:00	2018-03-09 12:00:00	Avenir des gares dans l'Est Cantal
8536	14211G	CEREMONIE	2018-01-04 18:30:00	2018-01-04 20:00:00	Voeux Pignan
8537	14211G	ELUS_LOCAUX	2018-02-01 11:00:00	2018-02-01 12:00:00	\N
8687	04042C	ACC_VISIT	2018-03-29 15:00:00	2018-03-29 16:00:00	Rencontre avec un Général de la Garde nationale
8688	04042C	ACC_DEPL_INTER	2018-03-29 16:00:00	2018-03-29 17:00:00	Entretien avec l'Ambassadeur de Corée en France
8689	04042C	ACC_VISIT	2018-03-29 17:00:00	2018-03-29 18:00:00	Rencontre avec un Général de l'ASAF
8690	04042C	COLL_TER	2018-03-29 18:30:00	2018-03-29 20:30:00	Rencontre avec des parlementaires et le Présidents de la SNCF
8761	08010L	ORG_POL	2018-04-10 11:00:00	2018-04-10 12:30:00	Groupe LR du sénat
8762	19705W	ORG_POL	2018-04-10 11:00:00	2018-04-10 12:30:00	\N
8763	19705W	REU_TRAV_PARL	2018-04-04 15:00:00	2018-04-04 17:30:00	Groupe Tourisme
8882	04042C	REU_TRAV_PARL	2018-04-18 15:00:00	2018-04-18 16:00:00	\N
8765	19707Y	ORG_POL	2018-04-10 11:00:00	2018-04-10 12:30:00	\N
8766	19707Y	COLLOQUE	2018-03-22 08:00:00	2018-03-22 10:00:00	Numérique
8767	19707Y	DEPL_PRES_GVT	2018-03-22 12:00:00	2018-03-23 00:00:00	Tunisie
8768	19705W	DEPL_PRES_GVT	2018-03-22 00:00:00	2018-03-22 00:00:00	Tunisie
8881	04042C	ACC_DEPL_INTER	2018-04-18 13:00:00	2018-04-18 14:45:00	Rencontre avec la Délégation du Maroc
8883	04042C	ACC_DEPL_INTER	2018-04-18 17:15:00	2018-04-18 18:00:00	Rencontre ave la Ministre après du Ministre d'Etat et Ministre de l'Intérieur avec la délégation du Maroc
8884	04042C	ACC_DEPL_INTER	2018-04-18 20:00:00	2018-04-18 22:00:00	Rencontre avec S.E l'Ambassadeur du Maroc et la délégation du Maroc
8941	08010L	DEPL_PRES_GVT	2018-04-24 09:00:00	2018-04-24 23:00:00	Visite d'Etat à Washington
9021	04018C	CEREMONIE	2018-05-15 00:00:00	2018-05-15 00:00:00	Policiers morts pour la France - Versailles
9142	04086Q	ORG_POL	2018-05-22 10:30:00	2018-05-22 12:30:00	Réunion du groupe LR
9143	04086Q	ORG_POL	2018-05-23 08:30:00	2018-05-23 09:30:00	Réunion de travail Amicale gaulliste en présence de Bruno Saint-Etienne 
9164	14327T	COLL_TER	2018-05-18 16:30:00	2018-05-18 19:00:00	Bureau communautaire
9147	04086Q	COLL_TER	2018-05-24 19:00:00	2018-05-24 21:00:00	Bureau municipal en mairie des Pavillons-sous-Bois
9148	04086Q	ELUS_LOCAUX	2018-05-25 11:00:00	2018-05-25 12:30:00	Visite de la caserne des pompiers de Bondy, avec présentation de l'unité et tendance des interventions aux Pavillons sous Bois
9165	14327T	REU_TRAV_PARL	2018-05-22 00:00:00	2018-05-22 00:00:00	Réunion groupe UC
9166	14327T	REU_GVT	2018-05-22 18:30:00	2018-05-22 20:00:00	Réunion bilan réforme du régime social des indépendants avec Ministre Darmanin et Buzyn
9167	14327T	COLL_TER	2018-05-25 10:30:00	2018-05-25 12:30:00	Session au conseil départemental
9168	14327T	REU_TRAV_PARL	2018-05-29 11:00:00	2018-05-29 12:30:00	Réunion gorupe UC
9169	14327T	REU_TRAV_PARL	2018-05-30 16:00:00	2018-05-30 17:30:00	Réunion groupe suivi de la politique de cohésion
9183	04042C	REU_TRAV_PARL	2018-05-31 14:30:00	2018-05-31 17:30:00	\N
9203	19705W	ORG_POL	2018-05-15 11:00:00	2018-05-15 12:30:00	\N
9204	19705W	ORG_POL	2018-05-15 13:00:00	2018-05-15 14:30:00	Sénatrices
9205	19705W	ORG_POL	2018-05-22 11:00:00	2018-05-22 12:30:00	\N
9206	19705W	ORG_POL	2018-05-29 11:00:00	2018-05-29 12:30:00	\N
9209	19707Y	ORG_POL	2018-05-22 11:00:00	2018-05-22 12:30:00	\N
9210	19707Y	ORG_POL	2018-05-29 11:00:00	2018-05-29 12:30:00	\N
9243	08009T	REU_TRAV_PARL	2018-05-15 16:00:00	2018-05-15 17:00:00	\N
9245	08009T	REU_GVT	2018-05-02 09:00:00	2018-05-02 11:00:00	\N
9246	08009T	REU_TRAV_PARL	2018-05-02 13:00:00	2018-05-02 14:00:00	\N
9247	08009T	REU_TRAV_PARL	2018-05-02 17:00:00	2018-05-02 18:00:00	\N
9248	08009T	REU_GVT	2018-05-02 18:30:00	2018-05-02 19:30:00	\N
9249	08009T	REU_GVT	2018-05-02 20:00:00	2018-05-02 21:00:00	\N
9250	08009T	REU_TRAV_PARL	2018-04-17 10:00:00	2018-04-17 11:00:00	\N
9251	08009T	ORG_POL	2018-04-17 11:00:00	2018-04-17 13:00:00	\N
9252	08009T	ORG_POL	2018-04-17 13:00:00	2018-04-17 14:30:00	\N
9253	08009T	REU_TRAV_PARL	2018-04-17 15:00:00	2018-04-17 16:00:00	\N
9254	08009T	REU_TRAV_PARL	2018-04-18 13:00:00	2018-04-18 14:00:00	\N
9255	08009T	REU_GVT	2018-04-18 16:30:00	2018-04-18 18:00:00	\N
9256	08009T	REU_GVT	2018-04-18 18:00:00	2018-04-18 19:00:00	\N
9257	08009T	REU_GVT	2018-04-18 19:00:00	2018-04-18 20:00:00	\N
9258	08009T	REU_TRAV_PARL	2018-04-19 09:00:00	2018-04-19 09:30:00	\N
9259	08009T	REU_TRAV_PARL	2018-04-19 09:45:00	2018-04-19 11:00:00	\N
9281	14147R	REU_TRAV_PARL	2018-05-31 09:00:00	2018-05-31 10:45:00	Audition de la Délégation aux droits des femmes du Sénat en tant que rapporteur du groupe de travail de la commission des lois sur les infractions sexuelles sur mineurs et du PJL sur les violences sexuelles et sexistes
9282	14147R	COLLOQUE	2018-06-05 19:45:00	2018-06-05 22:00:00	Réunion-débat de l'Amicale gaulliste du Sénat en présence du sociologue Mathieu Bock-Côté
9283	08039A	ACC_DEPL_INTER	2018-03-21 19:00:00	2018-03-21 21:00:00	Ambassade de Pologne 
9284	08039A	REU_GVT	2018-03-22 09:00:00	2018-03-22 12:30:00	RDV  Matignon 
9285	08039A	COLL_TER	2018-03-26 10:00:00	2018-03-26 12:30:00	RDV Permanence 
9286	08039A	ORG_POL	2018-03-27 11:00:00	2018-03-27 12:30:00	\N
9287	08039A	ACC_DEPL_INTER	2018-03-27 12:00:00	2018-03-27 14:00:00	RDV UNESCO
9288	08039A	REU_TRAV_PARL	2018-03-27 15:00:00	2018-03-27 17:00:00	RDV Audiovisuel
9289	08039A	REU_TRAV_PARL	2018-03-27 18:00:00	2018-03-27 19:30:00	RDV Groupe Loup
9290	08039A	CEREMONIE	2018-03-28 11:00:00	2018-03-28 12:30:00	Hommage National Invalides 
9291	08039A	REU_TRAV_PARL	2018-03-28 16:00:00	2018-03-28 18:00:00	RDV culture
9292	08039A	REU_TRAV_PARL	2018-03-29 13:30:00	2018-03-29 14:30:00	Déjeuner audiovisuel
9293	08039A	COLL_TER	2018-03-30 00:00:00	2018-03-30 00:00:00	RDV Permanence 
9294	08039A	ORG_POL	2018-04-03 11:00:00	2018-04-03 12:30:00	\N
9295	08039A	REU_TRAV_PARL	2018-04-03 15:00:00	2018-04-03 16:00:00	RDV patrimoine 
9296	08039A	CEREMONIE	2018-04-04 18:00:00	2018-04-04 21:00:00	Montée marches Cannesséries
9297	08039A	COLL_TER	2018-04-09 09:00:00	2018-04-09 12:30:00	RDV Permanence 
9298	08039A	ORG_POL	2018-04-10 11:00:00	2018-04-10 12:30:00	\N
8364	08009T	REU_TRAV_PARL	2018-02-14 15:30:00	2018-02-14 16:00:00	\N
8365	08009T	REU_TRAV_PARL	2018-02-14 18:00:00	2018-02-14 19:00:00	\N
8366	08009T	REU_GVT	2018-02-15 09:00:00	2018-02-15 10:30:00	\N
8367	08009T	REU_TRAV_PARL	2018-02-15 14:30:00	2018-02-15 15:00:00	\N
8368	08009T	REU_GVT	2018-02-15 16:30:00	2018-02-15 17:30:00	\N
8582	04086Q	COLL_TER	2018-03-05 14:30:00	2018-03-05 15:30:00	RDV directrice Espace des Arts aux Pavillons-sous-Bois
8583	04086Q	COLL_TER	2018-03-05 17:00:00	2018-03-05 19:00:00	Réunion EPIF
8584	04086Q	COLL_TER	2018-03-05 20:00:00	2018-03-05 22:00:00	Conseil Municipal les Pavillons-sous-Bois
8589	04086Q	CEREMONIE	2018-03-07 21:00:00	2018-03-07 23:00:00	Diner annuel du CRIF en présence du Président de la République
8596	04086Q	DEPL_PRES_GVT	2018-03-15 10:30:00	2018-03-15 14:00:00	Vienne (38) Réunion et déjeuner de travail avec les élus locaux 
8597	04086Q	DEPL_PRES_GVT	2018-03-15 16:30:00	2018-03-15 18:00:00	Voiron (38) Visite d'un projet réhabilité en présence des habitants, du bailleurs social et des élus du département
8598	04086Q	DEPL_PRES_GVT	2018-03-15 18:00:00	2018-03-15 22:00:00	Sassenage (38) Réunion de travail et échange avec les élus locaux
8599	04086Q	COLL_TER	2018-03-16 12:30:00	2018-03-16 18:30:00	20 ans de l'ADIL 93
8600	04086Q	DEPL_PRES_GVT	2018-03-16 10:00:00	2018-03-16 12:30:00	Retour sur Paris depuis Grenoble 
8786	04042C	ACC_DEPL_INTER	2018-04-11 20:15:00	2018-04-11 22:15:00	Rencontre débat de l'IFRI en présence du Ministre des Affaires étrangères de la République Algérienne
8784	04042C	REU_TRAV_PARL	2018-04-11 17:15:00	2018-04-11 18:00:00	Réunion de travail avec le Président du Sénat
8785	04042C	REU_TRAV_PARL	2018-04-11 19:30:00	2018-04-11 20:30:00	Préparation du Colloque des Chrétiens d'Orient
8787	04042C	REU_TRAV_PARL	2018-04-12 13:00:00	2018-04-12 15:00:00	Rencontre avec le GIFAS
8788	04042C	ACC_VISIT	2018-04-12 15:30:00	2018-04-12 16:00:00	Entretien avec le PDG de Public Senat
8789	04042C	COLLOQUE	2018-04-12 16:00:00	2018-04-12 16:30:00	Conclusions du Colloque "Citoyenneté et justice : un défi pour le Moyen-Orient - Quels enseignements pour l'avenir de l'Irak ?
8794	04043D	ACC_VISIT	2018-03-29 13:00:00	2018-03-29 14:00:00	rencontre Jean Marc Yvermogeau
8795	04043D	REU_TRAV_PARL	2018-03-29 18:30:00	2018-03-29 21:30:00	Leçons des attentats terroristes en Europe HIA Bégin
8796	04043D	ORG_POL	2018-04-03 11:30:00	2018-04-03 12:30:00	Réunion de groupe LR
8797	04043D	ACC_VISIT	2018-04-04 12:30:00	2018-04-04 13:30:00	Rencontre Maire Val de Marne
8798	04043D	REU_TRAV_PARL	2018-04-04 18:30:00	2018-04-04 19:00:00	intervention Public Sénat
8799	04043D	REU_TRAV_PARL	2018-04-05 09:30:00	2018-04-05 11:00:00	OPESCT- Présentation du rapport IE de Cédric Villani
8800	04043D	REU_TRAV_PARL	2018-04-05 11:00:00	2018-04-05 12:00:00	CAE : Conclusions de M. Milon & Mme Primas
8801	04043D	ACC_DEPL_INTER	2018-04-05 16:15:00	2018-04-05 17:15:00	accueil consul des Bermudes
8803	04043D	CEREMONIE	2018-04-06 19:00:00	2018-04-06 20:00:00	remise Legion d'Honneur à Richard Dell'Agnola
8821	04086Q	ACC_DEPL_INTER	2018-04-04 09:00:00	2018-04-04 10:00:00	Accueil d'une délégation vénézuélienne 
8822	04086Q	REU_TRAV_PARL	2018-04-04 20:00:00	2018-04-04 21:30:00	Diner de travail parlementaire sur PJL ELAN
8824	04086Q	COLL_TER	2018-04-10 20:00:00	2018-04-10 22:30:00	Conseil de territoire EPT Grand Est
8825	04086Q	COLLOQUE	2018-04-11 13:00:00	2018-04-11 16:00:00	Réunion avec un groupe de prêtres sur la place de l'Eglise dans la métropole Grand Paris
8826	04086Q	DEPL_PRES_GVT	2018-04-11 19:00:00	2018-04-11 20:30:00	Cérémonie de commémoration au Mémorial de la Shoah
8827	04086Q	REU_TRAV_PARL	2018-04-12 10:00:00	2018-04-12 12:30:00	Présidence du Sénat sur la politique de la ville
8845	14211G	CEREMONIE	2018-03-21 18:00:00	2018-03-21 19:30:00	Remise d'une décoration
8846	14211G	ORG_POL	2018-03-20 11:00:00	2018-03-20 12:00:00	Groupe Les Républicains
8847	14211G	REU_GVT	2018-03-20 17:50:00	2018-03-20 18:30:00	\N
8848	14211G	ELUS_LOCAUX	2018-03-15 08:00:00	2018-03-15 09:00:00	\N
8849	14211G	ELUS_LOCAUX	2018-03-15 17:00:00	2018-03-15 18:30:00	\N
8850	14211G	ORG_POL	2018-03-13 11:00:00	2018-03-13 12:00:00	Groupe Les Républicains
8851	14211G	ACC_VISIT	2018-03-13 17:40:00	2018-03-13 18:10:00	Rencontre avec les Auditeurs de l'Institut du Sénat
8983	04042C	DEPL_PRES_GVT	2018-05-04 00:00:00	2018-05-04 00:00:00	Mission du Syndicat desEaux d'Ile-de-France au Laos 
8981	04042C	DEPL_PRES_GVT	2018-05-02 14:00:00	2018-05-02 00:00:00	Mission du Syndicat desEaux d'Ile-de-France au Laos 
8982	04042C	DEPL_PRES_GVT	2018-05-03 00:00:00	2018-05-03 00:00:00	Mission du Syndicat desEaux d'Ile-de-France au Laos 
9001	04043D	CEREMONIE	2018-04-17 12:00:00	2018-04-17 13:00:00	Inauguration de la salle René Monory
9002	04043D	ACC_VISIT	2018-05-04 16:00:00	2018-05-04 17:00:00	visite palais du luxembourg - lycée Berlioz
9006	04086Q	DEPL_PRES_GVT	2018-05-08 10:00:00	2018-05-08 13:00:00	Cérémonie d'hommage aux Pavillons-sous-Bois
9007	04086Q	DEPL_PRES_GVT	2018-05-08 16:00:00	2018-05-08 18:30:00	Cérémonie de commémoration à la préfecture de Bobigny
9122	04042C	CEREMONIE	2018-05-24 18:00:00	2018-05-24 21:00:00	100ème anniversaire de la RAF à l'Ambassade britannique en France 
9099	04043D	CEREMONIE	2018-05-04 18:00:00	2018-05-04 20:00:00	Inauguration local police municipale - Arnaud Beltrame
9121	04042C	ACC_VISIT	2018-05-23 14:40:00	2018-05-23 15:00:00	Interview Public Sénat Loi de Programmation Militaire
9123	04042C	ELUS_LOCAUX	2018-05-25 15:30:00	2018-05-25 16:30:00	Inauguration de nouveaux logements sociaux à Saint-Maurice
9124	04042C	ACC_DEPL_INTER	2018-05-25 19:00:00	2018-05-25 21:00:00	Soirée d'ouverture de la 5ème édition de la semaine de l'Amérique Latine et des Caraïbes
9162	01025N	REU_TRAV_PARL	2018-04-11 14:30:00	2018-04-11 15:30:00	audition CNIV
9163	01025N	REU_TRAV_PARL	2018-04-10 14:45:00	2018-04-10 15:15:00	audition UNIJUS
9244	08009T	REU_TRAV_PARL	2018-05-15 18:00:00	2018-05-15 19:00:00	\N
9260	08009T	ORG_POL	2018-04-11 08:00:00	2018-04-11 09:00:00	\N
9261	08009T	REU_TRAV_PARL	2018-04-11 17:00:00	2018-04-11 18:00:00	\N
9262	08009T	CEREMONIE	2018-04-11 18:30:00	2018-04-11 19:30:00	\N
9263	08009T	ORG_POL	2018-04-10 11:00:00	2018-04-10 13:00:00	\N
9264	08009T	REU_TRAV_PARL	2018-04-10 13:00:00	2018-04-10 14:30:00	\N
9265	08009T	REU_TRAV_PARL	2018-04-10 15:00:00	2018-04-10 16:00:00	\N
9266	08009T	REU_TRAV_PARL	2018-04-10 18:30:00	2018-04-10 20:00:00	\N
9299	08039A	ACC_DEPL_INTER	2018-04-10 15:00:00	2018-04-10 16:00:00	RDV GA France Pologne 
9300	08039A	REU_TRAV_PARL	2018-04-12 09:00:00	2018-04-12 14:00:00	RDV Patrimoine CNPA
9301	08039A	COLL_TER	2018-04-13 14:00:00	2018-04-13 18:00:00	RDV Permanence 
9302	08039A	COLL_TER	2018-04-16 11:00:00	2018-04-16 13:00:00	RDV Batonnier
9303	08039A	COLL_TER	2018-04-16 14:00:00	2018-04-16 17:00:00	RDV Maison d'arrêt
9304	08039A	COLL_TER	2018-04-16 18:00:00	2018-04-16 19:00:00	RDV Permanence 
9305	08039A	ORG_POL	2018-04-17 11:00:00	2018-04-17 12:30:00	\N
9306	08039A	COLL_TER	2018-04-20 15:00:00	2018-04-20 17:00:00	RDV Permanence 
9310	08039A	COLL_TER	2018-05-18 11:00:00	2018-05-18 12:30:00	RDV Parfums Grasse 
9311	08039A	COLL_TER	2018-05-18 19:00:00	2018-05-18 21:00:00	RDV Parfums Grasse 
9312	08039A	ORG_POL	2018-05-22 11:00:00	2018-05-22 12:30:00	\N
9313	08039A	REU_TRAV_PARL	2018-05-22 12:00:00	2018-05-22 14:00:00	Déjeuner audiovisuel
9314	08039A	REU_TRAV_PARL	2018-05-22 16:00:00	2018-05-22 18:00:00	Réunions de rapporteurs 
9315	08039A	REU_TRAV_PARL	2018-05-24 09:00:00	2018-05-24 12:30:00	RDV Patrimoine CNPA
9316	08039A	ACC_DEPL_INTER	2018-05-25 10:00:00	2018-05-25 16:00:00	Accueil délégation UNESCO
9317	08039A	COLL_TER	2018-05-28 11:00:00	2018-05-28 12:30:00	RDV Permanence 
9318	08039A	COLL_TER	2018-05-28 17:00:00	2018-05-28 18:00:00	RDV Permanence 
9319	08039A	ORG_POL	2018-05-29 11:00:00	2018-05-29 12:30:00	\N
9320	08039A	ORG_POL	2018-05-29 18:00:00	2018-05-29 19:30:00	\N
9321	08039A	ORG_POL	2018-05-30 11:00:00	2018-05-30 12:30:00	\N
9322	08039A	COLL_TER	2018-05-30 15:00:00	2018-05-30 17:00:00	RDV Parfums Grasse 
9323	08039A	REU_TRAV_PARL	2018-05-31 09:00:00	2018-05-31 12:30:00	RDV Patrimoine CNPA
9324	08039A	REU_TRAV_PARL	2018-05-31 14:00:00	2018-05-31 16:00:00	RDV Patrimoine sénat 
9325	08039A	CEREMONIE	2018-05-31 16:00:00	2018-05-31 18:00:00	Elysée
9326	08039A	COLL_TER	2018-06-01 11:00:00	2018-06-01 12:30:00	RDV Permanence 
9327	08039A	COLL_TER	2018-06-01 14:00:00	2018-06-01 18:00:00	RDV Permanence 
9336	04042C	ORG_POL	2018-05-30 08:00:00	2018-05-30 09:00:00	Réunion des Présidents des Commissions
9337	04042C	REU_TRAV_PARL	2018-06-06 08:00:00	2018-06-06 09:00:00	Réunion des Présidents de Commissions
9338	04042C	REU_TRAV_PARL	2018-06-06 09:00:00	2018-06-06 10:00:00	Réunion des administrateurs dur la LPM 2019-2025
9339	04042C	ACC_DEPL_INTER	2018-06-06 13:00:00	2018-06-06 14:00:00	Rencontre avec un Général de division
9340	04042C	ACC_VISIT	2018-06-06 14:00:00	2018-06-06 16:00:00	Réunion de travail
9341	19705W	REU_TRAV_PARL	2018-06-07 10:30:00	2018-06-07 11:30:00	Groupe Tourisme
9342	19705W	ORG_POL	2018-06-05 11:00:00	2018-06-05 12:30:00	\N
9361	04043D	ELUS_LOCAUX	2018-06-04 20:00:00	2018-06-04 22:00:00	Réunion en majorité à Bry-sur-Marne 
8321	04086Q	ACC_DEPL_INTER	2018-02-15 11:00:00	2018-02-15 12:30:00	RDV dans le cadre du grouoe d'amitié France-Israël
8406	04086Q	COLL_TER	2018-02-16 08:30:00	2018-02-16 12:30:00	Réunion budgétaire en mairie des Pavillons-sous-Bois
8407	04086Q	COLL_TER	2018-02-16 14:00:00	2018-02-16 15:30:00	Réunion en mairie des Pavillons-sous-Bois aménagement Ilot du Canal
8408	04086Q	COLL_TER	2018-02-16 15:30:00	2018-02-16 18:00:00	Réunion budgétaire en mairie des Pavillons-sous-Bois
8409	04086Q	DEPL_PRES_GVT	2018-02-19 09:00:00	2018-02-19 14:00:00	Visite du RAID avec Gérard Larcher 
8410	04086Q	DEPL_PRES_GVT	2018-02-19 15:00:00	2018-02-19 17:00:00	Visite du Commissariat de Bondy avec Gérard Larcher
8411	04086Q	COLL_TER	2018-02-19 19:00:00	2018-02-19 21:00:00	Bureau municipal en mairie des Pavillons-sous-Bois
8412	04086Q	ORG_POL	2018-02-20 10:00:00	2018-02-20 11:00:00	Bureau du groupe LR
8413	04086Q	ORG_POL	2018-02-20 11:00:00	2018-02-20 12:30:00	Réunion du groupe LR
8414	04086Q	ELUS_LOCAUX	2018-02-20 19:00:00	2018-02-20 21:00:00	Visite des nouveaux locaux de la Région IDF à Saint-Ouen 
8415	04086Q	REU_TRAV_PARL	2018-02-21 19:00:00	2018-02-21 21:00:00	Conférence des Présidents
8446	89017R	REU_TRAV_PARL	2018-02-06 16:20:00	2018-02-06 16:32:00	Conférence des Présidents
8447	14211G	DEPL_PRES_GVT	2018-02-27 00:00:00	2018-02-27 00:00:00	Déplacement au Tchad et au Niger
8448	14211G	DEPL_PRES_GVT	2018-02-28 00:00:00	2018-02-28 00:00:00	Déplacement au Tchad et au Niger
8449	14211G	DEPL_PRES_GVT	2018-03-01 00:00:00	2018-03-01 00:00:00	Déplacement au Tchad et au Niger
8450	14211G	DEPL_PRES_GVT	2018-02-26 00:00:00	2018-02-26 23:59:00	Déplacement au Tchad et au Niger
8469	14041T	ELUS_LOCAUX	2018-03-06 09:00:00	2018-03-06 21:00:00	déplacement à l'étranger
8470	14041T	ELUS_LOCAUX	2018-03-07 09:00:00	2018-03-07 21:00:00	déplacement à l'étranger
8471	14041T	ELUS_LOCAUX	2018-03-08 09:00:00	2018-03-08 21:00:00	déplacement à l'étranger
8472	14041T	ELUS_LOCAUX	2018-03-27 09:00:00	2018-03-27 21:00:00	déplacement à l'étranger
8473	14041T	ELUS_LOCAUX	2018-03-28 09:00:00	2018-03-28 21:00:00	déplacement à l'étranger
8474	14041T	ELUS_LOCAUX	2018-03-29 09:00:00	2018-03-29 21:00:00	déplacement à l'étranger
8475	14041T	ELUS_LOCAUX	2018-03-22 09:00:00	2018-03-22 21:00:00	déplacement à l'étranger
8548	08039A	COLL_TER	2018-03-15 17:00:00	2018-03-15 19:00:00	\N
8549	08039A	COLL_TER	2018-03-16 15:00:00	2018-03-16 16:00:00	\N
8550	08039A	COLL_TER	2018-03-16 16:00:00	2018-03-16 17:00:00	\N
8551	08039A	COLL_TER	2018-03-16 17:00:00	2018-03-16 18:00:00	\N
8552	08039A	COLL_TER	2018-03-19 10:30:00	2018-03-19 11:30:00	\N
8553	08039A	ORG_POL	2018-03-20 11:00:00	2018-03-20 12:30:00	Réunion de Groupe LR
8701	04042C	ELUS_LOCAUX	2018-03-30 09:00:00	2018-03-30 10:00:00	Réunion à la Mairie de Saint-Maurice
8661	01025N	ACC_VISIT	2018-03-20 11:00:00	2018-03-20 12:30:00	\N
8664	08010L	ORG_POL	2018-03-27 11:00:00	2018-03-27 12:30:00	Groupe LR du sénat
8677	08010L	CEREMONIE	2018-03-28 11:00:00	2018-03-28 12:30:00	Invalides - Hommage national au Gendarme Beltrame
8702	04042C	ELUS_LOCAUX	2018-03-30 10:00:00	2018-03-30 13:00:00	Réunion relative à la police de securité qu quotidien à la Préfecture du Val-de-Marne
8783	08010L	ACC_VISIT	2018-04-11 10:30:00	2018-04-11 11:30:00	Etudiants américains 
8790	04042C	ACC_DEPL_INTER	2018-04-13 14:00:00	2018-04-13 00:00:00	Déplacement mission à Rabat
8791	04043D	REU_TRAV_PARL	2018-03-26 08:00:00	2018-03-26 09:00:00	Rencontre avec la Préfet Prévost
8792	04043D	ORG_POL	2018-03-27 11:00:00	2018-03-27 12:00:00	Réunion de groupe LR
8793	04043D	REU_TRAV_PARL	2018-03-28 08:30:00	2018-03-28 09:00:00	Rencontre avec Valérie Pecresse 
8802	04043D	DEPL_PRES_GVT	2018-04-06 08:00:00	2018-04-06 12:00:00	Visite HIA Bégin é Fort Neuf Vincennes
8852	04042C	REU_TRAV_PARL	2018-04-16 12:00:00	2018-04-16 13:00:00	\N
8853	04042C	ACC_VISIT	2018-04-16 16:45:00	2018-04-16 17:00:00	Public Sénat interview sur le débat sur la Syrie
8854	04042C	ACC_DEPL_INTER	2018-04-16 19:30:00	2018-04-16 21:30:00	Inauguration de la Chancellerie et du Centre culturel canadien en présence du Premier Ministre canadien
8855	04042C	ACC_DEPL_INTER	2018-04-17 09:00:00	2018-04-17 10:00:00	Entretien du Premier Ministre canadien avec le Président du Sénat 
8856	04042C	REU_TRAV_PARL	2018-04-17 10:15:00	2018-04-17 11:00:00	\N
8857	04042C	ORG_POL	2018-04-17 11:00:00	2018-04-17 12:30:00	\N
8858	04042C	REU_TRAV_PARL	2018-04-17 13:00:00	2018-04-17 14:15:00	Entretien avec un amiral sur la loi de programmation militaire
8859	04042C	ACC_VISIT	2018-04-17 15:00:00	2018-04-17 15:30:00	Rencontre avec la Secrétaire Générale du Val-de-Marne
8860	04042C	REU_TRAV_PARL	2018-04-17 15:30:00	2018-04-17 16:45:00	\N
8861	04042C	ACC_DEPL_INTER	2018-04-17 19:30:00	2018-04-17 20:00:00	Accueil d'une délégation marocaine
8862	04042C	ACC_DEPL_INTER	2018-04-17 20:00:00	2018-04-17 22:00:00	Rencontre avec des sénateurs marocains du Groupe Interparlementaire d'Amitié
8863	01024M	REU_TRAV_PARL	2018-04-12 09:00:00	2018-04-12 10:00:00	Audition rapporteur  - Commission des Lois - MI Vote électronique
8864	08010L	ORG_POL	2018-04-17 11:00:00	2018-04-17 12:30:00	Groupe LR du sénat
8865	08010L	REU_TRAV_PARL	2018-04-12 08:30:00	2018-04-12 10:00:00	Bureau de la Délégation Territoriale 
8866	08010L	REU_TRAV_PARL	2018-04-10 18:00:00	2018-04-10 19:00:00	France/Etats-Unis, Nicole BACHARAN
8887	08010L	REU_TRAV_PARL	2018-04-18 12:00:00	2018-04-18 13:00:00	Table ronde Bioéthique 
8889	04043D	ORG_POL	2018-04-17 20:30:00	2018-04-17 22:30:00	Rencontre avec la Miinistre chargée des transports
8890	04043D	REU_TRAV_PARL	2018-04-18 12:00:00	2018-04-18 13:00:00	CAE: table ronde thématique sur la bioéthique, intitulée "Génétique et révision de la loi de bioéthique, quels enjeux ?"
8891	04043D	REU_TRAV_PARL	2018-04-19 09:30:00	2018-04-19 10:30:00	audition DG Pôle Emploi
8896	04086Q	ELUS_LOCAUX	2018-04-18 15:00:00	2018-04-18 22:30:00	Tour de France du Logement, Réunion dans les Alpes-Maritimes avec les élus locaux à l'invitation d'H. Leroy
8897	04086Q	REU_TRAV_PARL	2018-04-19 13:00:00	2018-04-19 14:30:00	Déjeuner de travail sur la Loi ELAN
8898	04086Q	CEREMONIE	2018-04-19 19:00:00	2018-04-19 22:30:00	Festivités de Yom Haatsmaout, journée de l'indépendance de l'Etat d'Israël
8899	04042C	REU_GVT	2018-04-19 08:30:00	2018-04-19 09:30:00	Entretien avec Madame la Ministre des Armées
8900	04042C	ACC_DEPL_INTER	2018-04-19 13:15:00	2018-04-19 14:30:00	Rencontre avec une délégation marocaine
8901	04042C	ACC_DEPL_INTER	2018-04-20 00:00:00	2018-04-20 00:00:00	Déplacement à Marseille avec une délégation marocaine
9160	01025N	REU_TRAV_PARL	2018-05-16 08:00:00	2018-05-16 09:30:00	Audition INRA Trufficulture
9097	08010L	REU_TRAV_PARL	2018-05-17 09:00:00	2018-05-17 18:00:00	JOURNEE DE REFLEXION SUR LE THEME DE L'INNOVATION, Généthon - Genopole,   
9098	04043D	CEREMONIE	2018-05-10 11:00:00	2018-05-10 12:00:00	cérémonie organisée à l'occasion de la journée nationale des mémoires de la traite, de l'esclavage et de leurs abolitions
9145	04086Q	ACC_DEPL_INTER	2018-05-23 13:00:00	2018-05-23 14:30:00	Déjeuner avec le groupe d'amitié France-Québec  conduite par son président Jacques Chagnon 
9146	04086Q	REU_TRAV_PARL	2018-05-23 19:30:00	2018-05-23 21:00:00	Dîner de travail sur le logement social en Outre-Mer
9149	04086Q	COLL_TER	2018-05-25 15:30:00	2018-05-25 17:30:00	Réunion Logement (Seine-Saint-Denis Habitat) 
9161	01025N	REU_TRAV_PARL	2018-04-17 13:00:00	2018-04-17 14:30:00	Président Association des Régions de France
9159	01025N	ACC_VISIT	2018-05-22 14:00:00	2018-05-22 16:00:00	Conseil municipal de Vert Toulon
9214	04086Q	COLL_TER	2018-05-29 08:30:00	2018-05-29 09:30:00	Région IDF, réunion sur le TZen 3 au STIF
9215	04086Q	REU_TRAV_PARL	2018-05-29 10:30:00	2018-05-29 11:00:00	Réunion de travail au cabinet du Président du Sénat
9216	04086Q	ORG_POL	2018-05-29 11:00:00	2018-05-29 12:30:00	Réunion du groupe LR
9217	04086Q	COLL_TER	2018-05-29 20:00:00	2018-05-29 22:30:00	Conseil de territoire EPT Grand Est
9218	04086Q	COLL_TER	2018-05-30 20:00:00	2018-05-30 22:30:00	Réunion de quartier aux Pavillons sous Bois
9364	04043D	ELUS_LOCAUX	2018-05-28 10:00:00	2018-05-28 11:00:00	Entretien avec Madame Charlotte Libert-Albanel, Maire de Vincennes
9366	04043D	ACC_DEPL_INTER	2018-05-29 13:00:00	2018-05-29 14:00:00	Réunion de travail du Groupe d'Amitié France-U.S.A avec le Congressional staffs
9365	04043D	REU_TRAV_PARL	2018-05-28 20:00:00	2018-05-28 22:00:00	Réunion militante auprès de Monsieur Thierry-Hebbrecht
9367	04043D	REU_TRAV_PARL	2018-05-31 15:00:00	2018-05-31 16:00:00	Réunion d'information sur l'heboristerie sur le développement de l'herboristerie et des plantes médicinales, des filières et métiers d'avenir
9369	04043D	ACC_VISIT	2018-06-01 10:00:00	2018-06-01 12:00:00	Visite des élèves de CM2 de Choisy-le-Roi
9370	04043D	REU_TRAV_PARL	2018-06-05 13:00:00	2018-06-05 14:00:00	Réunion de travail du bureau de la Commission des Affaires Economiques et du Président du Sénat  
8380	08010L	ORG_POL	2018-02-20 11:00:00	2018-02-20 12:30:00	Groupe LR du sénat
8381	04018C	ORGEXTPAR	2018-02-15 00:00:00	2018-02-15 00:00:00	Commission supérieure des sites, perspectives et paysages
8382	04018C	CEREMONIE	2018-02-20 08:30:00	2018-02-20 11:00:00	Accueil Président de la République aux Mureaux
8383	04018C	ORG_POL	2018-02-15 20:00:00	2018-02-15 22:30:00	Comité Départemental LR
8390	08010L	REU_TRAV_PARL	2018-02-20 18:00:00	2018-02-20 19:00:00	Avenir des Territoires ruraux
8385	04043D	CEREMONIE	2018-02-05 19:00:00	2018-02-05 21:00:00	Inauguration Station F
8386	04043D	ORG_POL	2018-02-06 13:00:00	2018-02-06 14:30:00	Réunion de travail LR
8388	04043D	CEREMONIE	2018-02-06 19:00:00	2018-02-06 20:00:00	Remise légion d'honneur
8481	04042C	ACC_VISIT	2018-03-07 13:00:00	2018-03-07 14:30:00	Rencontre Expertise France
8391	04043D	ACC_VISIT	2018-02-08 14:15:00	2018-02-08 15:15:00	Rencontre étudiant-biotechnologies
8482	04042C	ACC_DEPL_INTER	2018-03-07 15:15:00	2018-03-07 16:00:00	Entretien avec L'Ambassadeur des Etats-Unis d'Amérique en France avec Le Président du Sénat
8483	04042C	REU_TRAV_PARL	2018-03-07 18:45:00	2018-03-07 19:30:00	Conférence des Présidents
8394	04043D	ORG_POL	2018-02-13 11:30:00	2018-02-13 12:30:00	Réunion de groupe LR
8399	04042C	ACC_DEPL_INTER	2018-02-21 15:00:00	2018-02-21 16:00:00	Entretien avec une délégation de parlementaires Maliens
8396	04043D	REU_TRAV_PARL	2018-02-13 18:00:00	2018-02-13 19:00:00	Réunion AGAS
8397	04043D	REU_TRAV_PARL	2018-02-15 16:30:00	2018-02-15 17:30:00	OPESCT 
8398	04042C	ACC_DEPL_INTER	2018-02-21 12:00:00	2018-02-21 14:00:00	Cérémonie des Forces armées de la Fédération de Russie
8400	04043D	DEPL_PRES_GVT	2018-02-16 07:30:00	2018-02-16 18:30:00	Déplacement Marseille - rencontre avec les chercheurs et étudiants au Centre de recherche et de documentation sur l'Océanie (CREDO)
8484	04042C	COLL_TER	2018-03-07 19:30:00	2018-03-07 21:00:00	Réunion de la Métropole du Grand Paris
8402	04042C	REU_TRAV_PARL	2018-02-21 19:00:00	2018-02-21 20:00:00	Conférence des Présidents au Sénat
8485	04042C	REU_TRAV_PARL	2018-03-08 09:00:00	2018-03-08 11:00:00	\N
8486	04042C	ACC_DEPL_INTER	2018-03-08 16:15:00	2018-03-08 17:15:00	Entretien avec une délégation de la Commission des Affaires étrangères de la Chambre des Communes
8487	04042C	ACC_DEPL_INTER	2018-03-08 13:00:00	2018-03-08 16:00:00	Entretien à l'Ambassade du Liban en France à l'occasion de la visite du Ministre de la Défense
8488	01025N	REU_TRAV_PARL	2018-03-08 10:30:00	2018-03-08 12:30:00	présentation projet régional de santé ARS Grand Est
8518	14211G	REU_TRAV_PARL	2018-02-21 08:15:00	2018-02-21 09:30:00	Déjeuner RFF
8519	14327T	REU_TRAV_PARL	2018-03-12 15:00:00	2018-03-12 16:30:00	Rencontre FDSEA évolution de la fiscalité agricole
8520	14211G	REU_TRAV_PARL	2018-02-14 08:15:00	2018-02-14 09:30:00	Groupe Chasse et Pêche
8521	14211G	ORG_POL	2018-02-15 19:30:00	2018-02-15 20:30:00	Bureau Politique LR 34
8522	14211G	ORG_POL	2018-01-30 09:30:00	2018-01-30 12:00:00	Groupe Les Républicains
8523	14211G	ELUS_LOCAUX	2018-01-25 11:00:00	2018-01-25 16:00:00	\N
8524	14211G	COLL_TER	2018-01-25 18:00:00	2018-01-25 20:00:00	Conseil de Métropole
8525	14211G	COLL_TER	2018-02-22 18:00:00	2018-02-22 20:30:00	Conseil de Métropole
8526	14211G	ORG_POL	2018-01-23 10:30:00	2018-01-23 12:00:00	Groupe Les Républicains
8527	14211G	ORG_POL	2018-01-16 11:00:00	2018-01-16 12:00:00	Groupe Les Républicains
8528	14211G	CEREMONIE	2018-01-18 18:30:00	2018-01-18 20:00:00	Voeux Agglo Sète
8540	08039A	ORG_POL	2018-03-06 11:00:00	2018-03-06 12:30:00	Réunion de Groupe LR
8530	14211G	CEREMONIE	2018-01-31 19:00:00	2018-01-31 20:30:00	Voeux CC Sud Hérault
8538	08039A	COLL_TER	2018-03-05 14:00:00	2018-03-05 16:00:00	Réunions Permanence 
8539	08039A	COLL_TER	2018-03-05 10:30:00	2018-03-05 12:30:00	Réunions Permanence 
8541	08039A	REU_TRAV_PARL	2018-03-06 17:30:00	2018-03-06 19:00:00	Groupe de Travail
8542	08039A	REU_TRAV_PARL	2018-03-07 08:30:00	2018-03-07 09:30:00	\N
8543	08039A	REU_TRAV_PARL	2018-03-08 09:30:00	2018-03-08 17:00:00	Présidence de la Commission nationale du Patrimoine et de l'Architecture - Ministère de la Culture 
8544	08039A	COLL_TER	2018-03-09 14:00:00	2018-03-09 16:00:00	Réunions Permanence 
8545	08039A	ELUS_LOCAUX	2018-03-12 09:00:00	2018-03-12 19:00:00	Déplacement en Italie
8546	08039A	ELUS_LOCAUX	2018-03-13 09:00:00	2018-03-13 19:00:00	Déplacement en Italie
8547	08039A	ELUS_LOCAUX	2018-03-14 09:00:00	2018-03-14 19:00:00	Déplacement en Italie
8711	04086Q	ACC_DEPL_INTER	2018-03-20 09:45:00	2018-03-20 11:00:00	Réception à la Présidence en l'Honneur du Grand-Duc et de la Grand-Duchesse du Luxembourg
8588	04086Q	REU_TRAV_PARL	2018-03-06 17:00:00	2018-03-06 18:30:00	Réunion groupe de travail sur la révision constitutionnelle présidée par Gérard Larcher, en présence de Nicolas Sarkozy
8560	04043D	REU_TRAV_PARL	2018-03-15 14:30:00	2018-03-15 15:30:00	PJL - Etat au service d'une société de confiance
8561	08010L	COLLOQUE	2018-03-15 09:00:00	2018-03-15 10:30:00	délégation territoriale et IEP /  communes et intercommunalités
8581	08010L	REU_TRAV_PARL	2018-03-14 12:30:00	2018-03-14 14:30:00	Délégation territoriale / Caisse des Dépôts
8586	04086Q	REU_TRAV_PARL	2018-03-06 09:45:00	2018-03-06 11:45:00	RDV élus sur le sujet du Grand Paris
8587	04086Q	REU_TRAV_PARL	2018-03-06 15:30:00	2018-03-06 16:30:00	Réunion de travail sur la fiscalité
8590	04086Q	COLL_TER	2018-03-12 16:30:00	2018-03-12 18:30:00	Mairie, réunion d'aménagement de l'esplanade la Fourche 
8591	04086Q	COLL_TER	2018-03-12 19:00:00	2018-03-12 21:00:00	Réunion budgétaire en mairie des Pavillons-sous-Bois
8592	04086Q	ACC_VISIT	2018-03-13 12:30:00	2018-03-13 13:00:00	Troisième session de l'Institut du Sénat 
8593	04086Q	REU_TRAV_PARL	2018-03-13 13:15:00	2018-03-13 14:00:00	Déjeuner de travail du président et vices-présidents du Sénat
8594	04086Q	REU_TRAV_PARL	2018-03-13 15:00:00	2018-03-13 16:00:00	Réunion de travail en vu d'un déplacement en Seine-et-Marne
8595	04086Q	REU_TRAV_PARL	2018-03-14 12:30:00	2018-03-14 14:00:00	Déjeuner de travail à la CDC des membres de la délégation Collectivités territoriales 
8601	08010L	ORG_POL	2018-03-20 11:00:00	2018-03-20 12:30:00	Groupe LR du sénat
8602	08010L	ACC_VISIT	2018-03-20 18:00:00	2018-03-20 19:00:00	France / Etats-Unis
8603	08009T	REU_TRAV_PARL	2018-03-20 09:00:00	2018-03-20 10:00:00	\N
8604	08009T	REU_TRAV_PARL	2018-03-20 10:00:00	2018-03-20 11:00:00	\N
8605	08009T	DEPL_PRES_GVT	2018-03-15 08:30:00	2018-03-15 11:00:00	\N
8606	08009T	REU_TRAV_PARL	2018-03-15 12:30:00	2018-03-15 14:00:00	\N
8607	08009T	REU_TRAV_PARL	2018-03-14 14:30:00	2018-03-14 15:00:00	\N
8608	08009T	REU_TRAV_PARL	2018-03-14 15:00:00	2018-03-14 15:30:00	\N
8609	08009T	REU_TRAV_PARL	2018-03-14 15:45:00	2018-03-14 16:15:00	\N
8610	08009T	REU_TRAV_PARL	2018-03-13 08:00:00	2018-03-13 08:30:00	\N
8611	08009T	REU_GVT	2018-03-13 08:30:00	2018-03-13 09:30:00	\N
8612	08009T	ORG_POL	2018-03-13 11:00:00	2018-03-13 13:00:00	\N
8613	08009T	ACC_DEPL_INTER	2018-03-13 13:00:00	2018-03-13 14:00:00	\N
8614	08009T	ORG_POL	2018-03-06 09:45:00	2018-03-06 10:30:00	\N
8615	08009T	ORG_POL	2018-03-06 00:00:00	2018-03-06 00:00:00	\N
8616	08009T	ELUS_LOCAUX	2018-03-07 16:00:00	2018-03-07 16:30:00	\N
8617	08009T	ORGEXTPAR	2018-03-08 00:01:00	2018-03-08 23:59:00	\N
8662	08010L	DEPL_PRES_GVT	2018-03-22 10:00:00	2018-03-22 20:00:00	BERLIN avec le Président LARCHER
8663	04018C	CEREMONIE	2018-03-28 11:00:00	2018-03-28 12:00:00	Hommage au Lt-Colonel Arnaud Beltrame
8710	04086Q	ELUS_LOCAUX	2018-03-20 08:30:00	2018-03-20 09:30:00	Réunion de travail, élus 93
8712	04086Q	REU_TRAV_PARL	2018-03-21 09:00:00	2018-03-21 09:50:00	Réunion de travail dans le cadre du rapport logement
8713	04086Q	ELUS_LOCAUX	2018-03-21 12:30:00	2018-03-21 14:30:00	Réunion avec les élus du CRIF
8714	04086Q	COLLOQUE	2018-03-21 15:15:00	2018-03-21 16:30:00	USH sur le projet de loi ELAN
8718	04086Q	ACC_VISIT	2018-03-26 14:00:00	2018-03-26 15:00:00	Parlement des étudiants
8719	04086Q	ACC_VISIT	2018-03-26 16:15:00	2018-03-26 17:00:00	Réunion de travail sur un projet d'échange international 
8720	04086Q	DEPL_PRES_GVT	2018-03-26 18:30:00	2018-03-26 19:30:00	Accueil du Secrétaire général du Parti Communiste du Viet Nam 
8773	04042C	REU_TRAV_PARL	2018-04-09 14:45:00	2018-04-09 15:45:00	\N
8771	04042C	ACC_VISIT	2018-04-09 10:30:00	2018-04-09 12:00:00	Rendez-vous à la Mairie de Saint-Maurice
8772	04042C	ELUS_LOCAUX	2018-04-09 13:00:00	2018-04-09 14:00:00	Entretien avec un élu du Val-de-Marne
8774	04042C	ACC_VISIT	2018-04-09 18:45:00	2018-04-09 19:15:00	Public Sénat sur la Syrie
8775	04042C	ELUS_LOCAUX	2018-04-09 20:30:00	2018-04-09 22:30:00	Conseil Municipal de la commune de Saint-Maurice
8776	04042C	ORG_POL	2018-04-10 11:00:00	2018-04-10 12:00:00	\N
8777	04042C	REU_TRAV_PARL	2018-04-10 12:30:00	2018-04-10 14:45:00	Rencontre avec un Amiral 
8778	04042C	REU_TRAV_PARL	2018-04-10 15:00:00	2018-04-10 15:30:00	\N
8369	04042C	ELUS_LOCAUX	2018-02-19 13:00:00	2018-02-19 14:30:00	Entretien avec le Maire de La Queue-en-Brie
8370	04042C	ACC_VISIT	2018-02-19 15:00:00	2018-02-19 16:00:00	Entretien avec le Président gu Groupe Marck
8371	04042C	ELUS_LOCAUX	2018-02-19 16:00:00	2018-02-19 16:30:00	Entretien avec un Conseiller municipal de Villejuif
8372	04042C	REU_TRAV_PARL	2018-02-19 16:30:00	2018-02-19 17:15:00	Réunion avec le Directeur de la communication du Sénat
8373	04042C	REU_TRAV_PARL	2018-02-19 17:15:00	2018-02-19 19:00:00	\N
8374	04042C	ORG_POL	2018-02-19 20:30:00	2018-02-19 22:00:00	\N
8416	04086Q	COLL_TER	2018-02-22 13:30:00	2018-02-22 14:00:00	Interview Public Sénat sur le Grand Paris Express
8378	04042C	REU_TRAV_PARL	2018-02-20 14:30:00	2018-02-20 15:00:00	\N
8379	04042C	ACC_DEPL_INTER	2018-02-20 19:00:00	2018-02-20 21:00:00	Ambassade de Suisse
8417	04086Q	COLL_TER	2018-02-22 15:00:00	2018-02-22 17:00:00	Commission Habitat et Logement à la Métropole du Grand Paris
8460	04042C	REU_TRAV_PARL	2018-03-06 10:00:00	2018-03-06 11:00:00	\N
8461	04042C	ORG_POL	2018-03-06 11:00:00	2018-03-06 12:00:00	\N
8462	04042C	REU_TRAV_PARL	2018-03-06 14:00:00	2018-03-06 15:00:00	\N
8463	04042C	COLLOQUE	2018-03-06 17:00:00	2018-03-06 20:00:00	Révision constitutionnelle de 2008 et réforme du Parlement : quel bilan 10 ans après ?
8637	14327T	COLL_TER	2018-03-16 14:30:00	2018-03-16 17:30:00	Réunion du SYTEC
8554	08010L	ORG_POL	2018-03-13 11:00:00	2018-03-13 12:30:00	Groupe LR du sénat
8555	08010L	REU_TRAV_PARL	2018-03-14 16:30:00	2018-03-14 17:30:00	RDV Ministre MEZARD
8638	14327T	REU_TRAV_PARL	2018-03-16 18:00:00	2018-03-16 19:00:00	Travail fiscalité agricole
8639	14327T	CEREMONIE	2018-03-19 11:15:00	2018-03-19 12:15:00	Commémoration Guerre d'Algérie
8640	14327T	ELUS_LOCAUX	2018-03-19 14:00:00	2018-03-19 17:00:00	Réuniion Commission DETR
8641	14327T	REU_TRAV_PARL	2018-03-13 00:00:00	2018-03-13 00:00:00	Réunion groupe UC
8642	14327T	REU_TRAV_PARL	2018-03-13 12:30:00	2018-03-13 14:00:00	Rencontre avec Interbev : plan de filière viande bovine française
8645	14327T	REU_TRAV_PARL	2018-03-20 17:45:00	2018-03-20 18:15:00	Réunion de travail avec les représentants de l'UNAF
8644	14327T	REU_TRAV_PARL	2018-03-20 11:00:00	2018-03-20 12:30:00	Réunion groupe UC
8709	04086Q	COLL_TER	2018-03-19 18:30:00	2018-03-19 20:30:00	Bureau municipal en mairie des Pavillons-sous-Bois
8715	04086Q	REU_TRAV_PARL	2018-03-26 11:00:00	2018-03-26 12:30:00	Reunion de travail avec l'association Action Logement
8354	08009T	REU_TRAV_PARL	2018-02-07 08:30:00	2018-02-07 09:30:00	\N
8716	04086Q	REU_TRAV_PARL	2018-03-26 13:00:00	2018-03-26 14:00:00	Reunion de travail avec le collectif Entr'hotes
8723	04086Q	ELUS_LOCAUX	2018-03-28 08:30:00	2018-03-28 10:30:00	Petit déjeuner de travail élus IDF
8721	04086Q	REU_TRAV_PARL	2018-03-27 13:45:00	2018-03-27 14:30:00	Reunion de travail avec l'association Habitat Réuni
8722	04086Q	DEPL_PRES_GVT	2018-03-27 15:00:00	2018-03-27 16:30:00	Accueil de la Vice-Présidente Argentine
8724	04086Q	COLLOQUE	2018-03-28 10:30:00	2018-03-28 11:00:00	Table ronde gazette des communes 
8725	04086Q	DEPL_PRES_GVT	2018-03-28 16:00:00	2018-03-28 17:30:00	Accueil du président de la Ligue des Etats Arabes
8726	04086Q	ELUS_LOCAUX	2018-03-28 18:30:00	2018-03-28 22:00:00	Colloque sur le projet de loi ELAN à BUSSY-SAINT-GEORGES
8727	04086Q	COLL_TER	2018-03-29 08:00:00	2018-03-29 10:00:00	Réunion avec les industrielles ZI Poudrette, Pavillions-sous-Bois
8728	04086Q	COLL_TER	2018-03-29 18:00:00	2018-03-29 22:00:00	Tour de France du Logement à ANGERS
8729	04086Q	COLL_TER	2018-03-30 17:30:00	2018-03-30 18:30:00	Réunion de travail EPT budget
8730	04086Q	ORG_POL	2018-04-03 21:00:00	2018-04-03 23:00:00	Comité départemental LR 93
8893	04086Q	ELUS_LOCAUX	2018-04-16 18:00:00	2018-04-16 22:30:00	Tour de France du Logement, Réunion dans la Sarthe avec des élus locaux à l'invitation  de  L. J. de Nicolaÿ et J. P. Vogel
8780	04042C	ACC_DEPL_INTER	2018-04-10 19:45:00	2018-04-10 22:00:00	Palais de l'Elysée - Rencontre avec le Présdient de la République du Prince héritier d'Arabie Saoudite, et de Mohamed Bin Salma et le  Premier Ministre libanais Saad Hariri
8781	04042C	ACC_DEPL_INTER	2018-04-11 13:00:00	2018-04-11 14:15:00	Rencontre avec l'Ambassadeur du Canada en France
8888	08010L	CEREMONIE	2018-04-19 13:00:00	2018-04-19 14:00:00	France-Maroc
8903	04086Q	DEPL_PRES_GVT	2018-04-20 15:00:00	2018-04-20 16:00:00	Représente G. Larcher au dévoilement de la plaque en hommage au Capitaine Jugelé
8894	04086Q	ELUS_LOCAUX	2018-04-16 11:00:00	2018-04-16 15:00:00	Tour de France du Logement, Réunion en Ille-et-Vilaine avec les élus locaux,,  à l'invitaion de D. de Legge et F. Gatel
8895	04086Q	COLL_TER	2018-04-17 09:30:00	2018-04-17 12:00:00	Réunion préfecture de Région sur la réalisation de la ligne 16
8961	04042C	DEPL_PRES_GVT	2018-04-23 00:00:00	2018-04-23 00:00:00	Visite d'Etat avec le Président de la République à Washington
8962	04042C	DEPL_PRES_GVT	2018-04-24 00:00:00	2018-04-24 00:00:00	Visite d'Etat avec le Président de la République à Washington
8963	04042C	DEPL_PRES_GVT	2018-04-25 00:00:00	2018-04-25 00:00:00	Visite d'Etat avec le Président de la République à Washington
8964	04042C	DEPL_PRES_GVT	2018-04-26 00:00:00	2018-04-26 00:00:00	Visite d'Etat avec le Président de la République à Washington
9036	04042C	ORG_POL	2018-05-15 11:00:00	2018-05-15 12:30:00	\N
9037	04042C	ACC_DEPL_INTER	2018-05-15 12:30:00	2018-05-15 13:30:00	Rencontre avec l'Ambassadeur de France en Chine
9038	04042C	ACC_DEPL_INTER	2018-05-15 19:00:00	2018-05-15 21:00:00	Soirée de soutien à la candidature du Royaume du Maroc pour le Mondial 2026 à l'Assemblée nationale
9044	08010L	REU_TRAV_PARL	2018-05-16 10:30:00	2018-05-16 11:30:00	commission des finances/ Amendes pénales
9046	04042C	COLL_TER	2018-05-17 09:30:00	2018-05-17 10:00:00	Evènement Eau Solidaire
9043	08010L	REU_TRAV_PARL	2018-05-16 08:15:00	2018-05-16 09:30:00	France-Etats-Unis
9047	04042C	REU_TRAV_PARL	2018-05-17 10:10:00	2018-05-17 10:30:00	\N
9048	04042C	ACC_DEPL_INTER	2018-05-17 12:00:00	2018-05-17 14:00:00	Rencontre du Président de la Knesset avec le Président du Sénat Gérard Larcher
9049	04042C	ACC_VISIT	2018-05-17 14:30:00	2018-05-17 16:00:00	Entretien Délégué Défense
9050	04042C	COLLOQUE	2018-05-17 19:30:00	2018-05-17 22:30:00	Rencontre journée de visite et de réflexion consacrée à l'innovation
9051	04042C	DEPL_PRES_GVT	2018-05-18 06:30:00	2018-05-18 16:00:00	Déplacement à l'Ile Longue avec le Président du Sénat Gérard Larcher 
9054	04086Q	DEPL_PRES_GVT	2018-05-11 08:30:00	2018-05-11 00:00:00	Déplacement au Royaume-Uni dans le cadre du jumelage Les Pavillions-Sous-Bois/Brackley 
9055	04086Q	DEPL_PRES_GVT	2018-05-14 01:00:00	2018-05-14 22:30:00	Déplacement au Royaume-Uni dans le cadre du jumelage Les Pavillions-Sous-Bois/Brackley 
9057	04086Q	ACC_DEPL_INTER	2018-05-16 08:30:00	2018-05-16 12:00:00	Colloque dans le cadre de l'année croisée France/Israël
9058	04086Q	REU_TRAV_PARL	2018-05-16 14:45:00	2018-05-16 15:45:00	Réunion de travail du groupe  logement (au sein des LR)
9059	04086Q	CEREMONIE	2018-05-16 16:00:00	2018-05-16 17:00:00	Cérémonie des justes à l'Assemblée Nationale
9063	04086Q	COLL_TER	2018-05-18 08:30:00	2018-05-18 10:00:00	Petit déjeuner de travail avec le préfet et l'inspection académique concernant la rentrée scolaire 2018
9100	08010L	REU_TRAV_PARL	2018-05-22 10:00:00	2018-05-22 12:30:00	FedEPL/PJL  ELAN
9101	04042C	ORG_POL	2018-05-22 11:00:00	2018-05-22 12:30:00	\N
9102	04042C	REU_TRAV_PARL	2018-05-22 19:30:00	2018-05-22 21:00:00	Association groupe parlementaire Chrétien
9181	04042C	ACC_VISIT	2018-05-30 13:15:00	2018-05-30 15:00:00	Rencontre de travail au sujet de la cité de la Gastronomie de Paris Rungis
9182	04042C	ACC_VISIT	2018-05-30 15:00:00	2018-05-30 16:00:00	Rencontre avec la directrice de l'agence du développement de la RATP du Val-de-Marne et du directeur des relations institutionnelles de la RATP
9307	08039A	ORG_POL	2018-05-15 11:00:00	2018-05-15 12:30:00	\N
9308	08039A	REU_TRAV_PARL	2018-05-16 15:00:00	2018-05-16 17:00:00	RDV audiovisuel
9309	08039A	REU_TRAV_PARL	2018-05-17 09:00:00	2018-05-17 17:00:00	RDV Patrimoine CNPA
9328	04042C	ORG_POL	2018-06-05 11:00:00	2018-06-05 12:00:00	\N
9329	04042C	REU_TRAV_PARL	2018-06-05 12:00:00	2018-06-05 13:00:00	Réunion de service
9330	04042C	ACC_VISIT	2018-06-05 13:00:00	2018-06-05 14:15:00	Rencontre Présidente de la Commission des Affaires étrangères
9331	04018C	CEREMONIE	2018-06-05 10:00:00	2018-06-05 11:30:00	Hommage J. Salvaing et J. Schneider
9332	04042C	REU_TRAV_PARL	2018-06-05 16:30:00	2018-06-05 17:30:00	\N
9333	04042C	ACC_VISIT	2018-06-05 18:20:00	2018-06-05 19:00:00	Magzine du Grain àmoudre sur France Culture : Le Parlement a-t-il vraiment son mot à dire sur l'Armée ?
9334	04042C	ACC_DEPL_INTER	2018-06-05 19:00:00	2018-06-05 20:00:00	70ème anniversaire de l'Etat d'Israël 
9335	04042C	ORG_POL	2018-06-05 21:00:00	2018-06-05 22:00:00	Réunion à Bry-sur-Marne
8341	08009T	REU_GVT	2018-01-30 08:00:00	2018-01-30 09:00:00	\N
8342	08009T	REU_TRAV_PARL	2018-01-30 11:00:00	2018-01-30 12:00:00	\N
8343	08009T	REU_GVT	2018-01-30 13:00:00	2018-01-30 14:00:00	\N
8344	08009T	CEREMONIE	2018-01-30 00:00:00	2018-01-30 00:00:00	\N
8348	08009T	REU_GVT	2018-02-01 09:00:00	2018-02-01 10:00:00	\N
8346	08009T	REU_TRAV_PARL	2018-01-31 08:00:00	2018-01-31 09:00:00	\N
8347	08009T	REU_TRAV_PARL	2018-01-31 14:30:00	2018-01-31 15:30:00	\N
8349	08009T	REU_GVT	2018-02-01 10:00:00	2018-02-01 11:00:00	\N
8350	08009T	DEPL_PRES_GVT	2018-02-01 11:00:00	2018-02-01 20:00:00	\N
8351	08009T	REU_TRAV_PARL	2018-02-06 09:00:00	2018-02-06 09:30:00	\N
8352	08009T	ORG_POL	2018-02-06 11:00:00	2018-02-06 13:00:00	\N
8353	08009T	REU_TRAV_PARL	2018-02-06 18:00:00	2018-02-06 19:00:00	\N
8355	08009T	REU_TRAV_PARL	2018-02-07 13:00:00	2018-02-07 14:00:00	\N
8356	08009T	ORG_POL	2018-02-08 09:00:00	2018-02-08 10:00:00	\N
8357	08009T	REU_TRAV_PARL	2018-02-08 11:00:00	2018-02-08 12:00:00	\N
8358	08009T	REU_TRAV_PARL	2018-02-08 12:00:00	2018-02-08 13:00:00	\N
8359	08009T	REU_TRAV_PARL	2018-02-08 14:30:00	2018-02-08 15:00:00	\N
8360	08009T	ORG_POL	2018-02-13 11:00:00	2018-02-13 13:00:00	\N
8376	04042C	ORG_POL	2018-02-20 10:00:00	2018-02-20 11:00:00	\N
8362	08009T	REU_TRAV_PARL	2018-02-13 18:00:00	2018-02-13 19:30:00	\N
8363	08009T	REU_GVT	2018-02-13 20:30:00	2018-02-13 22:30:00	\N
8377	04042C	ORG_POL	2018-02-20 11:00:00	2018-02-20 12:30:00	\N
8403	08010L	DEL_ACT_PAR	2018-02-21 12:30:00	2018-02-21 14:30:00	OMC
8404	19707Y	ORG_POL	2018-02-20 11:00:00	2018-02-20 12:30:00	\N
8405	19705W	ORG_POL	2018-02-20 11:00:00	2018-02-20 12:30:00	\N
8421	04043D	REU_TRAV_PARL	2018-02-08 16:00:00	2018-02-08 18:00:00	Séance de clôture de la Conférence de consensus sur le logement 
8422	04043D	REU_TRAV_PARL	2018-02-12 12:00:00	2018-02-12 14:00:00	réunion ambassadeur de France
8619	04042C	ELUS_LOCAUX	2018-03-19 11:15:00	2018-03-19 12:00:00	\N
8424	04043D	REU_TRAV_PARL	2018-02-20 10:30:00	2018-02-20 11:30:00	rencontre avec laboratoire Novartis
8425	04043D	ORG_POL	2018-02-20 11:30:00	2018-02-20 12:45:00	Réunion de groupe
8618	08010L	CEREMONIE	2018-03-21 18:00:00	2018-03-21 19:00:00	Ravivage de la Flamme Arc de Triomphe
8620	04042C	ELUS_LOCAUX	2018-03-19 12:00:00	2018-03-19 13:00:00	<entretien avec le Maire de Villeneuve-le-Roi
8621	04042C	COLLOQUE	2018-03-19 14:00:00	2018-03-19 16:00:00	Estonie, Lettonie, Lituanie : 1918-2018
8622	04042C	ACC_VISIT	2018-03-19 16:15:00	2018-03-19 16:20:00	Interview Public Sénat - La Russie
8623	04042C	ACC_DEPL_INTER	2018-03-19 17:30:00	2018-03-19 18:30:00	Délégation du Parlement du Kurdistan
8624	04042C	ACC_DEPL_INTER	2018-03-19 19:00:00	2018-03-19 21:00:00	\N
8625	04042C	ACC_DEPL_INTER	2018-03-20 09:45:00	2018-03-20 10:45:00	Entretien avec Le Président Gérard Larcher du Grand Duc et de la Duchesse du Luxembourg
8626	04042C	ORG_POL	2018-03-20 11:00:00	2018-03-20 12:30:00	\N
8627	04042C	CEREMONIE	2018-03-20 18:30:00	2018-03-20 20:30:00	Cérémonie pour une remise de Légion d'Honneur à L'Haÿ-les-Roses
8628	04042C	REU_TRAV_PARL	2018-03-21 08:00:00	2018-03-21 08:30:00	\N
8629	04042C	REU_TRAV_PARL	2018-03-21 08:30:00	2018-03-21 09:30:00	Réunion du bureau du Groupe interparlementaire d'Amitié France-Maroc
8630	04042C	ACC_DEPL_INTER	2018-03-21 18:00:00	2018-03-21 19:00:00	Entretien avec le Président Gérard LARCHER de l'Ambassadeur de la Fédération de Russie
8631	04042C	REU_TRAV_PARL	2018-03-22 10:15:00	2018-03-22 11:00:00	\N
8632	04042C	ACC_DEPL_INTER	2018-03-22 11:00:00	2018-03-22 12:00:00	Entretien avec l'Ambassadeur de Roumanie
8633	04018C	ORG_POL	2018-03-28 00:00:00	2018-03-28 00:00:00	Versailles
8634	04018C	COLL_TER	2018-04-03 19:45:00	2018-04-03 22:30:00	\N
8635	04018C	ELUS_LOCAUX	2018-04-05 17:30:00	2018-04-05 19:45:00	\N
8636	04018C	ORGEXTPAR	2018-04-12 00:00:00	2018-04-12 00:00:00	Commission sites, perspectives et paysages
8683	04043D	REU_TRAV_PARL	2018-03-13 14:30:00	2018-03-13 16:45:00	PJL - Societe Confiance
8684	04043D	ACC_DEPL_INTER	2018-03-14 10:15:00	2018-03-14 10:45:00	Accueil de la délégation des parlementaires indonésiens de la Commission VIII - égalité hommes-femmes
8685	04043D	REU_TRAV_PARL	2018-03-21 13:00:00	2018-03-21 14:00:00	Rencontre Franck Morel, conseiller Relations sociales, travail et emploi
8686	04043D	CEREMONIE	2018-03-21 20:30:00	2018-03-21 21:30:00	L¿Oréal-UNESCO pour les Femmes et la Science
8703	04042C	REU_TRAV_PARL	2018-04-03 10:00:00	2018-04-03 11:00:00	\N
8704	04042C	ORG_POL	2018-04-03 11:00:00	2018-04-03 12:30:00	\N
8705	04042C	REU_TRAV_PARL	2018-04-03 13:00:00	2018-04-03 14:30:00	Rencontre avec le Président de Dassault Aviation
8706	04042C	ACC_DEPL_INTER	2018-04-03 15:00:00	2018-04-03 16:00:00	Entretien avec le Secrétaire National de Sécurité de la Géorgie et le Chef de l'Administration du Président de la Géorgie
8707	04042C	ACC_DEPL_INTER	2018-04-03 18:00:00	2018-04-03 19:30:00	Remise de décoration à l'Ambassade de Géorgie en Francee
8708	08010L	ORG_POL	2018-04-03 11:00:00	2018-04-03 12:30:00	Groupe LR du sénat
8731	01025N	REU_TRAV_PARL	2018-04-03 15:15:00	2018-04-03 16:20:00	auditions Groupe Tourisme
8741	01024M	COLL_TER	2018-04-05 10:00:00	2018-04-05 12:00:00	Préfecture de la Marne - Rencontre avec le délégué interministériel à la sécurité routière
8745	04042C	ELUS_LOCAUX	2018-04-06 15:00:00	2018-04-06 16:00:00	Réunion avec le Préfet du Val-de-Marne et Madame le Maire de Limeil-Brevannes
8743	08010L	ELUS_LOCAUX	2018-04-05 11:00:00	2018-04-05 14:00:00	CA de la FedEPL / PJL ELAN
8744	04042C	DEPL_PRES_GVT	2018-04-06 08:30:00	2018-04-06 12:00:00	Deplacement dans le Val-de-Marne : Bégin et le fort de Vincennes avec le Président du Sénat
8746	08048B	ACC_VISIT	2018-01-24 10:20:00	2018-01-24 12:00:00	Visite du Sénat par le Groupement des Entreprises du Pays d'Aix
8747	08048B	ACC_VISIT	2018-03-21 14:30:00	2018-03-21 16:00:00	Séance de questions orales pour les élèves de 1ères S du Cours La Bastide
8748	08009T	ORG_POL	2018-04-05 09:00:00	2018-04-05 10:00:00	\N
8749	08009T	REU_GVT	2018-04-05 10:00:00	2018-04-05 12:00:00	\N
8750	08009T	REU_TRAV_PARL	2018-04-04 10:00:00	2018-04-04 11:00:00	\N
8751	08009T	REU_TRAV_PARL	2018-04-04 17:00:00	2018-04-04 18:00:00	\N
8752	08009T	REU_TRAV_PARL	2018-04-04 18:00:00	2018-04-04 19:00:00	\N
8753	08009T	REU_TRAV_PARL	2018-04-04 19:00:00	2018-04-04 20:00:00	\N
8754	08009T	REU_GVT	2018-04-03 08:00:00	2018-04-03 09:00:00	\N
8755	08009T	REU_GVT	2018-04-03 09:30:00	2018-04-03 10:30:00	\N
8756	08009T	REU_TRAV_PARL	2018-04-03 11:00:00	2018-04-03 13:00:00	\N
8757	08009T	REU_TRAV_PARL	2018-04-03 13:00:00	2018-04-03 14:30:00	\N
8758	08009T	REU_TRAV_PARL	2018-04-03 14:30:00	2018-04-03 15:00:00	\N
8942	08010L	DEPL_PRES_GVT	2018-04-25 09:00:00	2018-04-25 23:00:00	Visite d'Etat à Washington
9045	04042C	ACC_DEPL_INTER	2018-05-16 19:30:00	2018-05-16 22:00:00	Rencontre La France China Fondation
9060	04086Q	REU_TRAV_PARL	2018-05-16 19:30:00	2018-05-16 20:30:00	Conférence des présidents
9053	04086Q	CEREMONIE	2018-05-10 10:30:00	2018-05-10 13:00:00	Accueil des officiels et hommage en souvenir de l'abolition de l'esclavage au Jardin du Luxembourg
9056	04086Q	ORG_POL	2018-05-15 11:00:00	2018-05-15 12:30:00	Réunion du groupe LR
9061	04086Q	ACC_DEPL_INTER	2018-05-17 12:00:00	2018-05-17 15:15:00	Audience au côté de G. Larcher du président de la Knesset, Yuli Edelstein, suivi d'un déjeuner officiel
9062	04086Q	ORG_POL	2018-05-17 19:30:00	2018-05-17 22:30:00	Participation à la clôture du Séminaire du groupe LR
9064	04086Q	COLL_TER	2018-05-18 12:00:00	2018-05-18 14:00:00	Inauguration d'un ensemble de logements sociaux aux Pavillons-sous-Bois
9154	04042C	ORG_POL	2018-05-29 11:00:00	2018-05-29 12:30:00	\N
9152	04042C	ACC_DEPL_INTER	2018-05-28 19:00:00	2018-05-28 22:00:00	Rencontre du Patriarche maronite d'Antioche et de tout l'Orient avec le Président du Sénat
9153	04042C	REU_TRAV_PARL	2018-05-29 10:00:00	2018-05-29 11:00:00	\N
9155	04042C	ACC_DEPL_INTER	2018-05-29 18:00:00	2018-05-29 19:00:00	Palais de l'Elysee à l'occasion de la semaine de l'Amérique Latine et des Caraïbes
9156	04042C	ACC_VISIT	2018-05-29 19:15:00	2018-05-29 10:15:00	Accueil des auditeurs des l'IHEDN
9157	08010L	ELUS_LOCAUX	2018-05-29 11:00:00	2018-05-29 12:30:00	Groupe LR du sénat
9219	04086Q	COLL_TER	2018-06-01 09:00:00	2018-06-01 10:30:00	Réunion en mairie des Pavillons-sous-Bois
9212	04086Q	ACC_DEPL_INTER	2018-05-28 12:00:00	2018-05-28 14:30:00	Déjeuner à la Présidence, Semaine de l'Amérique Latine et des Caraïbes 
9213	04086Q	ACC_DEPL_INTER	2018-05-28 19:00:00	2018-05-28 21:00:00	Rencontre avec le Patriarche d'Antioche Bechara Boutros Rai
9220	04086Q	CEREMONIE	2018-06-01 14:30:00	2018-06-01 16:30:00	Obsèque de Serge DASSAULT
9221	04086Q	COLL_TER	2018-06-04 18:30:00	2018-06-04 21:00:00	Bureau municipal en mairie des Pavillons-sous-Bois
9222	08009T	REU_TRAV_PARL	2018-06-05 12:30:00	2018-06-05 14:00:00	\N
9223	08009T	REU_TRAV_PARL	2018-06-05 18:15:00	2018-06-05 19:15:00	\N
9224	08009T	REU_GVT	2018-06-05 20:30:00	2018-06-05 22:00:00	\N
9225	08009T	REU_TRAV_PARL	2018-05-31 09:30:00	2018-05-31 10:30:00	\N
9226	08009T	ORG_POL	2018-05-29 11:00:00	2018-05-29 13:00:00	\N
9227	08009T	REU_TRAV_PARL	2018-05-29 10:30:00	2018-05-29 11:00:00	\N
9228	08009T	REU_TRAV_PARL	2018-05-24 11:30:00	2018-05-24 12:30:00	\N
9229	08009T	REU_TRAV_PARL	2018-05-22 09:00:00	2018-05-22 10:00:00	\N
9230	08009T	ORG_POL	2018-05-22 11:00:00	2018-05-22 13:00:00	\N
9231	08009T	ORG_POL	2018-05-22 13:00:00	2018-05-22 14:30:00	\N
9483	04043D	CEREMONIE	2018-06-18 18:00:00	2018-06-18 18:30:00	Cérémonie 18 juin à SAINT MANDE
9484	04043D	CEREMONIE	2018-06-18 18:30:00	2018-06-18 19:00:00	Cérémonie 18 juin à VINCENNES
9704	01025N	REU_GVT	2018-07-03 10:00:00	2018-07-03 11:00:00	Rencontre au Ministère des Transports
9705	01025N	REU_TRAV_PARL	2018-07-03 16:30:00	2018-07-03 17:30:00	audition Jean-Baptiste Lemoyne, Secrétaire d'Etat à la Francophonie
9706	04042C	ACC_VISIT	2018-07-16 14:00:00	2018-07-16 15:30:00	Visite guidée du Sénat des séniors de Sucy-en-Brie
9721	14211G	DEPL_PRES_GVT	2018-07-19 15:00:00	2018-07-19 16:30:00	Visite de l'entreprise MedInCell
9722	14211G	COLL_TER	2018-07-19 17:00:00	2018-07-19 20:30:00	Conseil de Métropole
9723	14211G	ORG_POL	2018-07-17 11:00:00	2018-07-17 12:00:00	Groupe Les Républicains
9724	14211G	ELUS_LOCAUX	2018-07-19 12:30:00	2018-07-19 14:00:00	\N
9725	14211G	ELUS_LOCAUX	2018-07-18 16:00:00	2018-07-18 17:30:00	\N
9727	04086Q	ORG_POL	2018-07-17 10:30:00	2018-07-17 12:30:00	Réunion du groupe LR
9728	04086Q	COLLOQUE	2018-07-19 09:00:00	2018-07-19 12:30:00	Colloque "Banlieues, pour un électrochoc républicain"
9754	19760E	ORG_POL	2018-07-17 11:30:00	2018-07-17 13:00:00	\N
9961	08010L	ORG_POL	2018-10-02 11:00:00	2018-10-02 12:30:00	Groupe LR du Sénat
10121	04086Q	COLLOQUE	2018-10-15 14:00:00	2018-10-15 15:00:00	Intervention lors du colloque sur l'industrie de la mode 
10130	04086Q	DEPL_PRES_GVT	2018-10-19 07:00:00	2018-10-19 23:00:00	Déplacement en Allemagne dans la cadre du jumelage de la ville des Pavillons-sous-Bois 
10201	14211G	ORG_POL	2018-10-30 11:00:00	2018-10-30 12:00:00	Groupe Les Républicains
10202	14211G	ELUS_LOCAUX	2018-10-25 10:00:00	2018-10-25 15:00:00	\N
10203	14211G	CEREMONIE	2018-10-23 18:00:00	2018-10-23 19:30:00	Inauguration Ecole Microsoft Intelligence Artificielle à Castelnau-le-Lez
10204	14211G	ORG_POL	2018-10-16 11:00:00	2018-10-16 12:00:00	Groupe Les Républicains
10205	14211G	COLL_TER	2018-10-18 18:00:00	2018-10-18 20:00:00	Conseil de Métropole
10206	14211G	DEL_ACT_PAR	2018-10-18 09:00:00	2018-10-18 15:00:00	Déplacement du Groupe Vigne et Vin dans l'Hérault
10207	08009T	REU_TRAV_PARL	2018-10-16 09:45:00	2018-10-16 10:45:00	\N
10208	08009T	ORG_POL	2018-10-16 11:00:00	2018-10-16 13:00:00	\N
10209	08009T	REU_TRAV_PARL	2018-10-17 12:00:00	2018-10-17 13:00:00	\N
10210	08009T	REU_TRAV_PARL	2018-10-17 13:00:00	2018-10-17 14:30:00	\N
10211	08009T	REU_TRAV_PARL	2018-10-18 11:30:00	2018-10-18 12:30:00	\N
10212	08009T	ORG_POL	2018-10-23 11:00:00	2018-10-23 13:00:00	\N
10213	08009T	REU_TRAV_PARL	2018-10-23 13:00:00	2018-10-23 14:00:00	\N
10214	08009T	ORGEXTPAR	2018-10-25 14:00:00	2018-10-25 16:00:00	\N
10239	14211G	ELUS_LOCAUX	2018-11-08 08:30:00	2018-11-08 10:00:00	\N
10240	14211G	REU_TRAV_PARL	2018-11-08 16:15:00	2018-11-08 17:00:00	\N
10241	08010L	ACC_VISIT	2018-11-08 16:30:00	2018-11-08 17:30:00	\N
10262	04086Q	ACC_DEPL_INTER	2018-11-07 12:00:00	2018-11-07 15:15:00	Audience et réception en l'honneur du Président du Sénat de Côte d'Ivoire 
10243	04018C	ORGEXTPAR	2018-11-21 15:00:00	2018-11-21 17:00:00	\N
10261	08010L	REU_TRAV_PARL	2018-11-13 10:00:00	2018-11-13 13:00:00	Bureau des EPL
10263	04086Q	REU_TRAV_PARL	2018-11-07 18:00:00	2018-11-07 19:15:00	Réunion de travail du groupe LR pour le PLF
10264	04086Q	REU_TRAV_PARL	2018-11-07 19:30:00	2018-11-07 20:00:00	Conférence des Présidents
10265	04086Q	COLL_TER	2018-11-12 09:00:00	2018-11-12 12:00:00	Réunion MGP 
10266	04086Q	COLL_TER	2018-11-12 08:30:00	2018-11-12 09:00:00	Réunion de travail MGP
10267	04086Q	REU_TRAV_PARL	2018-11-12 19:00:00	2018-11-12 20:00:00	Réunion de travail du groupe LR pour le PLF 
10268	04086Q	ACC_DEPL_INTER	2018-11-12 20:15:00	2018-11-12 22:30:00	Diner avec les ambassadeurs de l'OCDE
10269	04086Q	CEREMONIE	2018-11-13 08:30:00	2018-11-13 09:30:00	Hommage aux victimes du 13 novembre 2015 au Stade de France
10270	04086Q	CEREMONIE	2018-11-13 12:15:00	2018-11-13 12:30:00	Hommage aux sénateurs et personnels du Sénat morts pour la France 
10271	04042C	ACC_DEPL_INTER	2018-11-12 16:30:00	2018-11-12 17:30:00	Entretien avec le responsable de toutes les opérations de maintien de la paix de l'ONU
10272	04042C	ACC_DEPL_INTER	2018-11-12 18:30:00	2018-11-12 19:30:00	Réception à l'Ambassaade du Japon 
10273	04042C	ACC_DEPL_INTER	2018-11-12 20:00:00	2018-11-12 21:00:00	Rencontre avec le Président du Sénat et les Ambassadeurs de l'OCDE
10274	04042C	DEPL_PRES_GVT	2018-11-14 13:30:00	2018-11-14 23:00:00	Visite du Porte-Avions Charles de Gaulle avec le Président de la République
10275	04042C	DEPL_PRES_GVT	2018-11-15 09:30:00	2018-11-15 20:00:00	Inauguration d'une grande ligne à grande vitessse avec le Président de la République au Maroc
10276	08048B	REU_TRAV_PARL	2018-11-15 11:00:00	2018-11-15 12:00:00	Conférence de presse sur les propositions de Bruno GILLES pour taiter le  logement insalubre à Marseille
10301	08048B	ELUS_LOCAUX	2018-11-20 18:00:00	2018-11-20 20:00:00	Réception des maires des Bouches-duRhône au Sénat à l'occasion du Congrès des Maires de France
10302	08010L	REU_TRAV_PARL	2018-11-20 10:30:00	2018-11-20 12:30:00	PLF 2019 Justice
10306	04043D	CEREMONIE	2018-11-16 11:30:00	2018-11-16 12:30:00	Inauguration du Poste de Police Municipale et du Centre de Supervision Urbaine, Villejuif 
10304	08010L	ACC_VISIT	2018-11-21 19:00:00	2018-11-21 22:30:00	Elus de l'Aisne / Congrès des Maires de France
10305	04043D	CEREMONIE	2018-11-16 10:15:00	2018-11-16 11:00:00	Présentation de Cancer Campus, Villejuif
10307	04043D	ELUS_LOCAUX	2018-11-19 13:00:00	2018-11-19 14:00:00	\N
10308	04043D	ELUS_LOCAUX	2018-11-22 00:00:00	2018-11-22 00:00:00	RV avec Thierry Dallard et les autres sénateurs du Val-de-Marne concernant le Grand Paris
10309	08009T	REU_TRAV_PARL	2018-11-06 10:00:00	2018-11-06 11:00:00	\N
10310	08009T	ORG_POL	2018-11-06 11:00:00	2018-11-06 13:00:00	\N
10311	08009T	REU_TRAV_PARL	2018-11-06 15:00:00	2018-11-06 16:00:00	\N
10312	08009T	REU_TRAV_PARL	2018-11-07 08:00:00	2018-11-07 09:00:00	\N
10313	08009T	REU_TRAV_PARL	2018-11-07 16:30:00	2018-11-07 17:00:00	\N
10314	08009T	ORG_POL	2018-11-13 11:00:00	2018-11-13 13:00:00	\N
10315	08009T	REU_TRAV_PARL	2018-11-13 16:15:00	2018-11-13 16:45:00	\N
10316	08009T	ELUS_LOCAUX	2018-11-14 12:30:00	2018-11-14 14:00:00	\N
10317	08009T	REU_GVT	2018-11-14 16:30:00	2018-11-14 17:10:00	\N
10318	08009T	REU_GVT	2018-11-15 09:00:00	2018-11-15 11:00:00	\N
10319	08010L	ACC_VISIT	2018-11-22 18:30:00	2018-11-22 21:00:00	conseil municipal de Laon
10320	04086Q	REU_TRAV_PARL	2018-11-15 11:30:00	2018-11-15 12:30:00	Réunion de travail des parlementaires du 93
10382	08010L	REU_TRAV_PARL	2018-12-04 08:00:00	2018-12-04 09:30:00	PLF 2019
10341	14041T	ELUS_LOCAUX	2018-11-28 09:00:00	2018-11-28 18:00:00	déplacement à l'étranger
10342	14041T	ELUS_LOCAUX	2018-11-29 09:00:00	2018-11-29 18:00:00	déplacement à l'étranger
10343	14041T	ELUS_LOCAUX	2018-12-04 09:00:00	2018-12-04 18:00:00	déplacement à l'étranger
10344	14041T	ELUS_LOCAUX	2018-12-05 09:00:00	2018-12-05 18:00:00	déplacement à l'étranger
10345	14041T	ELUS_LOCAUX	2018-12-06 09:00:00	2018-12-06 18:00:00	déplacement à l'étranger
10346	08048B	REU_TRAV_PARL	2018-11-27 09:00:00	2018-11-27 14:00:00	Visite du Cours Alexandre Dumas à Montfermeil et rencontre avec le maire de la ville et son équipe municipale  sur les problématiques de réduction du logement insalubre
10347	08010L	DEL_ACT_PAR	2018-11-27 11:00:00	2018-11-27 13:00:00	Groupe LR du sénat
10361	04043D	CEREMONIE	2018-11-26 00:00:00	2018-11-26 00:00:00	Retransmission de l'atterrissage de la mission InSight sur Mars-Cité des Sciences et de l'Industrie
10364	04043D	REU_TRAV_PARL	2018-11-28 15:00:00	2018-11-28 16:00:00	Assemblée Générale du Groupe pour l'Espace
10363	04043D	ORG_POL	2018-11-27 11:00:00	2018-11-27 13:00:00	Réunion de Groupe
10365	04043D	ACC_DEPL_INTER	2018-11-29 08:30:00	2018-11-29 09:30:00	Rencontre avec Monsieur l'Ambassadeur, Secrétaire permanent pour le Pacifique
10366	08010L	REU_TRAV_PARL	2018-11-29 08:00:00	2018-11-29 09:30:00	France-Etats-Unis 
10381	04086Q	ORG_POL	2018-11-27 11:00:00	2018-11-27 12:30:00	Réunion du groupe LR
10383	08010L	ORG_POL	2018-12-04 11:00:00	2018-12-04 12:30:00	Groupe LR du sénat
10401	14089Y	REU_TRAV_PARL	2018-12-06 09:00:00	2018-12-06 12:00:00	\N
10402	14089Y	ELUS_LOCAUX	2018-12-06 18:00:00	2018-12-06 20:00:00	\N
10403	14211G	ORG_POL	2018-11-13 11:00:00	2018-11-13 12:00:00	Groupe Les Républicains
10404	14211G	ORG_POL	2018-12-04 11:00:00	2018-12-04 12:00:00	Groupe Les Républicains
10405	14211G	ORG_POL	2018-11-20 10:30:00	2018-11-20 11:30:00	Groupe Les Républicains
10406	14211G	ORG_POL	2018-11-27 11:00:00	2018-11-27 12:00:00	Groupe Les Républicains
10407	14211G	CEREMONIE	2018-11-22 19:00:00	2018-11-22 20:30:00	Remise Légion d'Honneur à Danièle KÜSS
10408	14211G	ELUS_LOCAUX	2018-11-21 12:30:00	2018-11-21 14:00:00	Déjeuner du Conseil Départemental avec les Maires de l'Hérault
10409	14211G	ELUS_LOCAUX	2018-11-21 20:00:00	2018-11-21 22:00:00	Dîner avec des élus locaux
10410	14211G	ACC_VISIT	2018-11-21 17:00:00	2018-11-21 18:30:00	Visite d'élus locaux
10411	14211G	ACC_VISIT	2018-11-20 11:30:00	2018-11-20 12:30:00	Visite d'élus locaux
10412	14211G	ELUS_LOCAUX	2018-11-20 12:30:00	2018-11-20 14:30:00	Déjeuner avec des élus locaux
9481	04043D	REU_TRAV_PARL	2018-06-12 12:30:00	2018-06-12 13:30:00	Rencontrer avec une délégation de parlementaires australiens
9482	04043D	ELUS_LOCAUX	2018-06-14 19:30:00	2018-06-14 21:00:00	\N
9501	08010L	REU_TRAV_PARL	2018-06-19 10:30:00	2018-06-19 12:00:00	CA Fed EPL/ELAN
9502	04043D	ACC_DEPL_INTER	2018-06-19 17:00:00	2018-06-19 18:00:00	Entretien avec Monsieur Jean-Paul Carteron , Ambassadeur Extraordinaire et Plénipotentiaire des Iles Salomon
9503	04043D	ELUS_LOCAUX	2018-06-19 19:00:00	2018-06-19 21:00:00	Réunion de travail autour de Valérie Pécresse sur la mobilité du futur en Île-de-France
9612	19705W	ORG_POL	2018-06-19 11:00:00	2018-06-19 12:30:00	\N
9613	19705W	ORG_POL	2018-06-26 11:00:00	2018-06-26 12:30:00	\N
9642	08010L	ORG_POL	2018-07-10 11:00:00	2018-07-10 12:30:00	Groupe LR du sénat
9643	08010L	ACC_VISIT	2018-07-10 14:00:00	2018-07-10 14:30:00	\N
9881	04042C	DEPL_PRES_GVT	2018-09-17 00:00:00	2018-09-17 00:00:00	Mission du Syndicat des Eaux d'Ile-de-France au Japon
9882	04042C	DEPL_PRES_GVT	2018-09-18 00:00:00	2018-09-18 00:00:00	Mission du Syndicat des Eaux d'Ile-de-France au Japon
9941	04042C	ELUS_LOCAUX	2018-09-24 11:00:00	2018-09-24 12:30:00	Réunion logements à la Mairie de Saint-Maurice
9942	04042C	ELUS_LOCAUX	2018-09-24 13:00:00	2018-09-24 14:15:00	Réunion ave le Maire de Saint-Maurice
9943	04042C	REU_TRAV_PARL	2018-09-24 17:00:00	2018-09-24 18:00:00	Réunion de Direction
9944	04042C	CEREMONIE	2018-09-24 18:30:00	2018-09-24 19:30:00	Inauguration de l'exposition Venise, les Arts et l'Europe au XVIIIème siècle au Grand Palais
9945	04042C	REU_TRAV_PARL	2018-09-25 10:30:00	2018-09-25 11:00:00	Réunion de direction AP/OTAN
9946	04042C	ORG_POL	2018-09-25 11:00:00	2018-09-25 12:30:00	\N
9947	04042C	ACC_DEPL_INTER	2018-09-25 15:30:00	2018-09-25 16:30:00	Entretien avec le Président du Sénat du Président du Sénat d'Indonésie
9948	04042C	REU_TRAV_PARL	2018-09-25 17:50:00	2018-09-25 18:30:00	\N
9949	04042C	COLLOQUE	2018-09-25 18:30:00	2018-09-25 19:30:00	Reception d'ouverture de la semaine francilienne du Goût
9950	08010L	ORG_POL	2018-09-25 11:00:00	2018-09-25 12:30:00	Groupe LR du sénat
9951	08010L	REU_TRAV_PARL	2018-09-26 08:00:00	2018-09-26 09:30:00	PJL Justice
9952	04018C	COLL_TER	2018-10-10 09:30:00	2018-10-10 17:30:00	Université des Mairies 78
9953	04018C	ACC_DEPL_INTER	2018-10-17 13:00:00	2018-10-17 14:30:00	France-Allemagne
9984	08010L	REU_TRAV_PARL	2018-10-03 15:00:00	2018-10-03 17:30:00	\N
10217	04043D	COLL_TER	2018-11-06 11:30:00	2018-11-06 12:30:00	Réunion Transports avec V. PECRESSE
10216	04043D	ACC_DEPL_INTER	2018-10-30 00:00:00	2018-10-30 00:00:00	Groupe France-USA : entretien avec M. Orrin HATCH, Sénateur de l'Utah
10218	08010L	ORG_POL	2018-11-06 11:00:00	2018-11-06 12:30:00	Groupe LR du sénat
10284	04042C	ACC_VISIT	2018-11-16 13:00:00	2018-11-16 14:15:00	Réunion de travail avec le Syndicat des Eaux d'Ile-de-France
10282	04042C	CEREMONIE	2018-11-16 10:15:00	2018-11-16 11:15:00	Présentation du Cancer Campus en Présence de la Présidente du Conseil régional d'Ile-de-France à Villejuif
10283	04042C	CEREMONIE	2018-11-16 11:15:00	2018-11-16 12:15:00	Inauguration du Poste de police municipale et du Centre de Surveillance Urbaine à Villejuif
10321	04086Q	CEREMONIE	2018-11-16 11:30:00	2018-11-16 12:30:00	Audience solennel en l'honneur de Francois MOLINS en tant que Procureur général près la cour de cassation
10322	04086Q	REU_TRAV_PARL	2018-11-19 11:00:00	2018-11-19 12:30:00	RDV de travail sur le logement intermédiaire
10323	04086Q	CEREMONIE	2018-11-19 18:00:00	2018-11-19 19:00:00	Inauguration de l'expo Soljenitsyne
10324	04086Q	COLLOQUE	2018-11-20 09:30:00	2018-11-20 11:00:00	Intervention au colloque d'Action Logement
10325	04086Q	COLLOQUE	2018-11-20 12:15:00	2018-11-20 13:00:00	Accueil des maires au Sénat dans le cadre du congrès des Maires
10327	04086Q	COLLOQUE	2018-11-21 13:00:00	2018-11-21 14:00:00	Déjeuner pour le centenaire de la naissance de Soljenitsyne
10328	04086Q	REU_TRAV_PARL	2018-11-22 08:30:00	2018-11-22 09:00:00	Réunion de la délégation du bureau chargée de affaires internationales 
10413	14211G	ELUS_LOCAUX	2018-11-20 20:00:00	2018-11-20 22:00:00	Dîner avec des élus locaux
10414	14211G	ELUS_LOCAUX	2018-11-20 16:30:00	2018-11-20 18:00:00	Réunion des Parlementaires d'Occitanie autour de la Présidente Carole DELGA
10415	14211G	ELUS_LOCAUX	2018-11-15 15:00:00	2018-11-15 16:30:00	\N
10422	08009T	REU_TRAV_PARL	2018-11-27 17:15:00	2018-11-27 18:15:00	\N
10417	14211G	ORG_POL	2018-11-14 13:00:00	2018-11-14 14:30:00	\N
10418	14211G	ELUS_LOCAUX	2018-11-29 16:30:00	2018-11-29 18:00:00	\N
10421	08009T	REU_GVT	2018-11-27 09:30:00	2018-11-27 16:00:00	\N
10423	08009T	ORG_POL	2018-11-27 19:30:00	2018-11-27 20:30:00	\N
10424	08009T	REU_GVT	2018-11-28 08:00:00	2018-11-28 09:00:00	\N
10425	08009T	ELUS_LOCAUX	2018-11-28 12:30:00	2018-11-28 14:00:00	\N
10426	08009T	REU_TRAV_PARL	2018-11-28 14:30:00	2018-11-28 15:00:00	\N
10427	08009T	REU_TRAV_PARL	2018-11-29 13:30:00	2018-11-29 15:00:00	\N
10428	08009T	REU_GVT	2018-11-29 17:30:00	2018-11-29 19:30:00	\N
10429	08009T	REU_TRAV_PARL	2018-12-05 09:30:00	2018-12-05 10:30:00	\N
10430	08009T	REU_GVT	2018-12-06 08:30:00	2018-12-06 10:30:00	\N
10431	04043D	ACC_VISIT	2018-12-03 15:00:00	2018-12-03 16:30:00	visite du Sénat de Bel Age de Saint-Mandé
10432	04043D	ORG_POL	2018-12-04 11:00:00	2018-12-04 12:30:00	Réunion de Groupe
10433	04043D	ACC_DEPL_INTER	2018-12-04 16:30:00	2018-12-04 17:30:00	Réunion avec une délégation indonésienne
10434	04043D	CEREMONIE	2018-12-05 09:00:00	2018-12-05 10:00:00	Vincennes
10435	04043D	ELUS_LOCAUX	2018-12-05 12:30:00	2018-12-05 14:00:00	élus de Gentilly
10436	04043D	REU_TRAV_PARL	2018-12-04 13:00:00	2018-12-04 14:30:00	\N
10441	08010L	ORG_POL	2018-12-11 11:30:00	2018-12-11 12:30:00	Groupe LR du sénat
10442	04086Q	ACC_DEPL_INTER	2018-12-03 12:00:00	2018-12-03 14:00:00	Entretien aux côtés de G. Larcher du Maréchal du Sénat de Pologne Stanis¿aw Karczewski
10443	04086Q	REU_TRAV_PARL	2018-12-04 08:00:00	2018-12-04 09:00:00	Petit déjeuner de travail des sénateurs LR membres de la commission des finances
10444	04086Q	ORG_POL	2018-12-04 11:00:00	2018-12-04 12:30:00	Réunion du groupe LR
10445	04086Q	REU_TRAV_PARL	2018-12-04 12:30:00	2018-12-04 14:00:00	Déjeuner de travail du groupe LR
10446	04086Q	REU_TRAV_PARL	2018-12-10 13:00:00	2018-12-10 14:00:00	Déjeuner de travail sur le PLF
10447	04086Q	ORG_POL	2018-12-11 11:00:00	2018-12-11 12:30:00	Réunion du groupe LR
10448	08010L	REU_TRAV_PARL	2018-12-12 12:00:00	2018-12-12 13:00:00	Finances
10452	04043D	ELUS_LOCAUX	2018-12-10 20:00:00	2018-12-10 22:00:00	Comité Départemental Les Républicains 94
10450	08010L	COLLOQUE	2018-12-12 14:30:00	2018-12-12 17:30:00	Délégation à la Prospective : innovation territoriale et tarifications des mobilités
10451	04043D	ORG_POL	2018-12-11 11:00:00	2018-12-11 12:00:00	Réunion de Groupe
10457	04043D	REU_TRAV_PARL	2018-12-12 20:00:00	2018-12-12 22:00:00	reunion de soutien aux parcs animaliers, établissements de conservation, d'éducation et de recherche
10455	04043D	ACC_DEPL_INTER	2018-12-12 14:00:00	2018-12-12 15:00:00	rendez-vous avec Madame Roshika DEO, personnalité fidjienne, experte dans le domaine du droit des femmes 
10462	08010L	REU_TRAV_PARL	2018-12-18 12:30:00	2018-12-18 14:30:00	Délégation Territoriale 
10458	04043D	DEL_ACT_PAR	2018-12-13 09:30:00	2018-12-13 12:00:00	 Office parlementaire d'évaluation des choix scientifiques et technologiques 
10461	08010L	REU_TRAV_PARL	2018-12-18 10:00:00	2018-12-18 12:30:00	CA de la FedEPL
10463	08010L	REU_TRAV_PARL	2018-12-18 16:00:00	2018-12-18 16:45:00	PJL PACTE
10464	08010L	REU_TRAV_PARL	2018-12-18 19:00:00	2018-12-18 19:45:00	Justice
10465	04043D	ORG_POL	2018-12-18 11:00:00	2018-12-18 12:30:00	Réunion de Groupe
10466	04043D	REU_TRAV_PARL	2018-12-18 18:30:00	2018-12-18 19:30:00	Conférence des Présidents
10481	04042C	REU_TRAV_PARL	2018-12-17 17:00:00	2018-12-17 18:00:00	Réunion de direction
10482	04042C	ACC_DEPL_INTER	2018-12-17 19:30:00	2018-12-17 20:30:00	Entretien avec le Président Gérard Larcher du Président du Burkina-Faso
10483	04042C	CEREMONIE	2018-12-17 20:30:00	2018-12-17 22:30:00	Cérémonie des Voeux du Syndicat-des-Eaux d'Ile-de-France
10484	04042C	ORG_POL	2018-12-18 11:00:00	2018-12-18 12:30:00	\N
10501	08009T	REU_TRAV_PARL	2018-12-11 09:00:00	2018-12-11 10:00:00	\N
10502	08009T	ORG_POL	2018-12-11 11:00:00	2018-12-11 12:30:00	\N
10503	08009T	ELUS_LOCAUX	2018-12-11 12:30:00	2018-12-11 14:00:00	\N
10504	08009T	REU_TRAV_PARL	2018-12-11 17:00:00	2018-12-11 18:00:00	\N
10505	08009T	REU_GVT	2018-12-11 20:30:00	2018-12-11 21:30:00	\N
10506	08009T	REU_TRAV_PARL	2018-12-18 10:00:00	2018-12-18 11:00:00	\N
10507	08009T	ORG_POL	2018-12-18 11:00:00	2018-12-18 12:30:00	\N
10508	08009T	REU_TRAV_PARL	2018-12-18 17:45:00	2018-12-18 18:30:00	\N
10509	08009T	REU_TRAV_PARL	2018-12-18 18:30:00	2018-12-18 19:30:00	\N
10510	08009T	ORG_POL	2018-12-18 19:30:00	2018-12-18 20:30:00	\N
10511	08009T	REU_TRAV_PARL	2018-12-19 15:15:00	2018-12-19 16:15:00	\N
10512	08009T	REU_TRAV_PARL	2018-12-20 12:30:00	2018-12-20 14:00:00	\N
10521	04043D	CEREMONIE	2019-01-07 20:00:00	2019-01-07 22:30:00	Voeux de Charenton-le-Pont
10522	04043D	CEREMONIE	2019-01-08 20:00:00	2019-01-08 22:30:00	Voeux de Saint-Maurice
9374	04042C	DEPL_PRES_GVT	2018-06-07 07:00:00	2018-06-07 17:00:00	Mission CTAMARAN avec les Forces de la Marine nationale et de la Royal Navy à Quiberon
9375	04042C	ORG_POL	2018-06-07 19:30:00	2018-06-07 21:00:00	Réunion du Comité de circonscription à Maisons-Alfort
9378	04042C	ACC_DEPL_INTER	2018-06-11 11:30:00	2018-06-11 12:30:00	Entretien avec l'ancien Président de la commission des affaires étrangères de la Douma
9379	04042C	DEPL_PRES_GVT	2018-06-11 13:00:00	2018-06-11 14:00:00	Rencontre au Salon Eurosatory à Villepinte
9380	04042C	REU_TRAV_PARL	2018-06-11 15:00:00	2018-06-11 17:30:00	Réunion préparatoire de la CMP pour la LPM
9381	04042C	ACC_DEPL_INTER	2018-06-11 19:00:00	2018-06-11 20:00:00	Entretien avec le Président de l'Assemblée de l'Ukraine avec le Président Gérard Larcher
9382	04042C	DEPL_PRES_GVT	2018-06-11 20:15:00	2018-06-11 21:30:00	Soirée professionnelle avec le Groupe Thales
9383	08010L	ORG_POL	2018-06-12 11:00:00	2018-06-12 12:30:00	Groupe LR du sénat
9461	04042C	REU_GVT	2018-06-15 18:00:00	2018-06-15 20:00:00	Ministère des Armées
9505	04042C	REU_TRAV_PARL	2018-06-19 19:30:00	2018-06-19 21:30:00	\N
9506	04042C	REU_TRAV_PARL	2018-06-20 19:30:00	2018-06-20 20:30:00	Conférence des Présidents 
9507	04042C	ACC_VISIT	2018-06-20 16:30:00	2018-06-20 17:30:00	Visite guidée du Conseil municipal des jeunes de Bry-sur-Marne
9508	04042C	ELUS_LOCAUX	2018-06-20 12:30:00	2018-06-20 14:30:00	Rencontre avec le Maire de Joinville-Le-Pont
9509	04042C	REU_TRAV_PARL	2018-06-21 09:30:00	2018-06-21 10:30:00	Table Ronde Paris Air Forum - Loi de Programmation Militaire 
9510	04042C	REU_TRAV_PARL	2018-06-21 17:00:00	2018-06-21 18:15:00	Evaluation de la Politique de communication
9511	04042C	DEPL_PRES_GVT	2018-06-21 00:00:00	2018-06-21 00:00:00	Forum Interparlementaire au Maroc avec le Président du Sénat
9512	04042C	DEPL_PRES_GVT	2018-06-22 00:00:00	2018-06-22 00:00:00	Forum Interparlementaire au Maroc avec le Président du Sénat
9561	04086Q	ORG_POL	2018-06-19 00:00:00	2018-06-19 00:00:00	Réunion du groupe LR
9563	04086Q	REU_TRAV_PARL	2018-06-20 08:30:00	2018-06-20 09:30:00	RDV PJL ELAN députés et senateurs LR
9569	04086Q	REU_TRAV_PARL	2018-06-25 10:30:00	2018-06-25 11:00:00	RDV PJL ELAN 
9570	04086Q	REU_TRAV_PARL	2018-06-25 14:00:00	2018-06-25 15:00:00	RDV PJL ELAN 
9571	04086Q	REU_TRAV_PARL	2018-06-26 09:00:00	2018-06-26 10:00:00	RDV avec la conseillère cohésion des territoires de l'Elysée
9572	04086Q	ORG_POL	2018-06-26 10:30:00	2018-06-26 12:30:00	Réunion du groupe LR
9658	04043D	REU_TRAV_PARL	2018-07-11 17:30:00	2018-07-11 18:30:00	Assemblée générale ordinaire de l'AGAS
9761	04042C	REU_TRAV_PARL	2018-07-30 10:30:00	2018-07-30 11:30:00	Affaire Benalla : Audition de M. Michel LALANDE, préfet de la région Hauts-de-France, préfet du Nord
9762	04042C	REU_TRAV_PARL	2018-07-30 00:00:00	2018-07-30 00:00:00	Affaire Benalla : Audition de M. Jean-Marie GIRIER, chef de cabinet de M. Gérard COLLOMB, ministre d¿État, ministre de l¿intérieur, et ancien directeur de la campagne de M. Emmanuel MACRON pour l¿élection présidentielle
9763	04042C	REU_TRAV_PARL	2018-07-30 14:30:00	2018-07-30 16:00:00	 Affaire Benalla : Audition de M. Stéphane FRATACCI, directeur de cabinet de M. Gérard COLLOMB, ministre d¿État, ministre de l¿intérieur
9764	04042C	REU_TRAV_PARL	2018-07-30 16:00:00	2018-07-30 17:30:00	Affaire Benalla : Audition de M. Olivier de MAZIÈRES, préfet de police des Bouches-du-Rhône
9765	04042C	REU_TRAV_PARL	2018-07-30 17:30:00	2018-07-30 18:30:00	Affaire Benalla : Audition du Colonel Lionel LAVERGNE, chef du groupe de sécurité de la Présidence de la République.
9766	04042C	CEREMONIE	2018-07-30 18:30:00	2018-07-30 20:30:00	Ambassade du Maroc en France : 19eme anniversaire de l'intronisation de Sa Majeste Le Roi Mohammed VI
9767	04042C	REU_TRAV_PARL	2018-07-31 08:00:00	2018-07-31 09:30:00	Affaire Benalla : Audition de M. Christophe CASTANER, délégué général du Mouvement La République En Marche.
9821	04042C	ELUS_LOCAUX	2018-09-03 15:30:00	2018-09-03 18:00:00	\N
9822	04042C	REU_TRAV_PARL	2018-09-04 18:00:00	2018-09-04 19:00:00	\N
9841	04043D	ORG_POL	2018-09-10 15:00:00	2018-09-10 20:00:00	Journées Parlementaires groupe LR à Honfleur 
9843	04086Q	DEL_ACT_PAR	2018-08-30 09:00:00	2018-08-30 23:00:00	Commission des finances, Déplacement à Lille dans le cadre du rapport sur les Aides à la pierre. 
9844	04086Q	ELUS_LOCAUX	2018-08-31 08:30:00	2018-08-31 10:30:00	Réunion de travail à la préfecture sur la rentrée scolaire
9929	04043D	ACC_DEPL_INTER	2018-09-24 09:00:00	2018-09-24 20:00:00	déplacement dans les iles du Pacifique en qualité de Présidente du Groupe d'Amitié  Vanuatu
9846	04086Q	ACC_DEPL_INTER	2018-09-05 12:00:00	2018-09-05 14:30:00	Aux côtés de G. LARCHER de Mme Anneke BROEKERS-KNOL présidente de la première Chambre des Etats-Généraux  des Pays-Bas
9923	04043D	ACC_DEPL_INTER	2018-09-19 09:00:00	2018-09-19 20:00:00	déplacement dans les iles du Pacifique en qualité de Présidente du Groupe d'Amitié  Vanuatu
9930	04043D	ACC_DEPL_INTER	2018-09-25 09:00:00	2018-09-25 20:00:00	déplacement dans les iles du Pacifique en qualité de Présidente du Groupe d'Amitié  Vanuatu
9933	04043D	ACC_DEPL_INTER	2018-09-28 09:00:00	2018-09-28 20:00:00	déplacement dans les iles du Pacifique en qualité de Présidente du Groupe d'Amitié  Vanuatu
9958	04042C	COLL_TER	2018-09-28 09:00:00	2018-09-28 11:30:00	Seance du Conseil de la Métropole du Grand Paris
10034	08010L	REU_TRAV_PARL	2018-10-10 15:00:00	2018-10-10 16:00:00	France-Etats-Unis
9960	04042C	ELUS_LOCAUX	2018-09-28 20:00:00	2018-09-28 22:00:00	Fête de la Saint-Maurice
9983	08010L	REU_TRAV_PARL	2018-10-04 08:00:00	2018-10-04 09:15:00	France -Etats-Unis/AFE
10035	14211G	ORG_POL	2018-10-09 11:00:00	2018-10-09 12:00:00	Groupe Les Républicains
10036	14211G	DEPL_PRES_GVT	2018-10-11 10:30:00	2018-10-11 13:00:00	Rencontres Nationales des Conseils de développement - Madame Jacqueline GOURAULT
10037	08048B	REU_TRAV_PARL	2018-10-04 08:45:00	2018-10-04 10:00:00	Groupe de liaison "Chrétiens d'Orient"
10038	08048B	REU_TRAV_PARL	2018-10-11 11:00:00	2018-10-11 12:30:00	Audition budgétaire- PLF19- ONAC-VG
10044	04086Q	COLLOQUE	2018-09-24 20:00:00	2018-09-24 23:00:00	Invitation du CEPS et intervention usr le thème des banlieues
10045	04086Q	ACC_DEPL_INTER	2018-09-25 15:15:00	2018-09-25 16:00:00	Accueil aux côtés de G. Larcher d'Osman Sapta , président du conseil représentatif des régions d'Indonésie
10046	04086Q	COLL_TER	2018-09-25 21:00:00	2018-09-25 23:00:00	Conseil de territoire à l'EPT grand-EST
10047	04086Q	REU_TRAV_PARL	2018-09-26 13:00:00	2018-09-26 14:30:00	Déjeuner de travail à Matignon avec le premier ministre
10049	04086Q	ELUS_LOCAUX	2018-10-01 08:30:00	2018-10-01 18:00:00	Séminaire Elus de l'EPT Grand-Est
10050	04086Q	ORG_POL	2018-10-02 11:00:00	2018-10-02 12:00:00	Réunion du groupe LR
10051	04086Q	CEREMONIE	2018-10-03 18:00:00	2018-10-03 22:00:00	Fête nationale de la République de Chine 
10052	04086Q	CEREMONIE	2018-10-05 10:00:00	2018-10-05 12:00:00	Hommage nationale pour les obsèques de Charles Aznavour
10096	04042C	ELUS_LOCAUX	2018-10-15 10:00:00	2018-10-15 12:00:00	Réunion urbanisme à la Mairie de Saint-Maurice
10097	04042C	ELUS_LOCAUX	2018-10-15 12:30:00	2018-10-15 15:30:00	Rencontre avec des élus
10098	04042C	ELUS_LOCAUX	2018-10-15 20:00:00	2018-10-15 22:00:00	Réunion du Conseil du Territoire 
10099	04042C	ORG_POL	2018-10-16 10:30:00	2018-10-16 12:30:00	\N
10100	04042C	REU_TRAV_PARL	2018-10-16 15:00:00	2018-10-16 16:00:00	Réunion de Direction
10101	04042C	REU_TRAV_PARL	2018-10-16 16:00:00	2018-10-16 16:45:00	\N
10102	04042C	CEREMONIE	2018-10-16 19:00:00	2018-10-16 20:30:00	Messe de Monseigneur Michel Aupetit à l'intention des parlementaires et des responsables politiques
10103	08048B	REU_TRAV_PARL	2018-10-16 00:00:00	2018-10-16 00:00:00	Auditions budgétaires- PLF19- SGA du Ministère de la Défense  et audition de l'Union française des associations de combattants et de victimes de guerre (Ufac)
10141	04042C	DEPL_PRES_GVT	2018-10-19 13:30:00	2018-10-19 19:00:00	Accueil dans l'armée de l'air du 1er A330 MRTT Phénix sous la Présidence de Madame Florence Parly Ministre des armées
10142	04042C	ACC_DEPL_INTER	2018-10-18 10:45:00	2018-10-18 12:00:00	Entretien avec le Président du Sénat du Président du Conseil national de la Répubique de Slovaquie
10143	04042C	ACC_DEPL_INTER	2018-10-18 13:00:00	2018-10-18 14:15:00	Entretien avec un Ambassadeur
10144	04042C	REU_TRAV_PARL	2018-10-18 15:45:00	2018-10-18 16:15:00	Rendez-vous téléphonique
10145	04042C	ACC_DEPL_INTER	2018-10-18 17:30:00	2018-10-18 18:15:00	Entretien avec des journalistes russes
9371	04043D	CEREMONIE	2018-06-06 13:00:00	2018-06-06 14:00:00	Fête nationale suédoise 
9372	04043D	REU_TRAV_PARL	2018-06-06 20:00:00	2018-06-06 22:00:00	Rencontre du Club de l'accession à la propriété autour de  Madame Dominique ESTROSI SASSONE, sénatrice des Alpes-Maritimes 
9373	04043D	CEREMONIE	2018-06-08 18:00:00	2018-06-08 19:00:00	Commémoration des morts pour la France en Indochine
10006	14211G	CEREMONIE	2018-09-13 18:30:00	2018-09-13 20:00:00	Inauguration à Montagnac
9388	04042C	REU_TRAV_PARL	2018-06-12 08:30:00	2018-06-12 08:45:00	Presentation à la Presse des conclusions du rapport d'information sur les nouvelled routes de la soie
9389	04042C	REU_TRAV_PARL	2018-06-12 08:45:00	2018-06-12 09:45:00	Preparation de la CMP de la LMP
9390	04042C	ORG_POL	2018-06-12 10:00:00	2018-06-12 11:00:00	\N
9391	04042C	ACC_VISIT	2018-06-12 11:20:00	2018-06-12 11:30:00	Direct sur France Info TV
9392	04042C	ACC_DEPL_INTER	2018-06-12 12:00:00	2018-06-12 12:45:00	Fete nationale de la Federation de Russie à l'Ambassade
9393	04042C	REU_TRAV_PARL	2018-06-12 13:00:00	2018-06-12 14:00:00	Réunion des Presidents des Commissions du Sénat
9394	04042C	REU_TRAV_PARL	2018-06-12 16:00:00	2018-06-12 16:30:00	Rendez-vous avec un Sénateur
9395	04042C	ACC_VISIT	2018-06-12 18:20:00	2018-06-12 18:30:00	InterviewPublic Sénat
9396	04086Q	ORG_POL	2018-06-05 10:30:00	2018-06-05 12:30:00	Réunion du groupe LR
9397	04086Q	ELUS_LOCAUX	2018-06-05 13:30:00	2018-06-05 14:30:00	Rendez-vous ADELMAD
9398	04086Q	REU_TRAV_PARL	2018-06-05 17:00:00	2018-06-05 18:00:00	Réunion de travail de la commission des finances sur le logement 
9399	04086Q	DEPL_PRES_GVT	2018-06-05 19:00:00	2018-06-05 22:30:00	Ouverture année croisée France-Israël
9401	14213J	ORGEXTPAR	2018-01-18 09:30:00	2018-01-18 13:00:00	Conseil Consultatif National d'Ethique
9404	14213J	ORGEXTPAR	2018-05-17 09:30:00	2018-05-17 13:00:00	Conseil Consultatif National d'Ethique
9405	14213J	ORGEXTPAR	2018-05-17 14:00:00	2018-05-17 16:00:00	Conseil Consultatif National d'Ethique
9406	14213J	ORGEXTPAR	2018-07-05 09:30:00	2018-07-05 13:00:00	Conseil Consultatif National d'Ethique
9407	04086Q	CEREMONIE	2018-06-08 18:00:00	2018-06-08 20:00:00	Mairie des Pavillons-sous-Bois, Vernissage
9408	14213J	ORGEXTPAR	2018-09-06 09:30:00	2018-09-06 13:00:00	Conseil Consultatif National d'Ethique
9524	04043D	ELUS_LOCAUX	2018-06-21 19:30:00	2018-06-21 21:00:00	Association des Sarrazins Sud de Créteil
9525	04043D	COLL_TER	2018-06-22 14:00:00	2018-06-22 16:00:00	Conseil de Surveillance des Hôpitaux de Saint-Maurice 
9523	04043D	REU_TRAV_PARL	2018-06-21 16:30:00	2018-06-21 18:30:00	Mission d'information sur le dévpt de l'herboristerie et des plantes médicinales
9526	14041T	ELUS_LOCAUX	2018-06-06 09:00:00	2018-06-06 18:00:00	déplacement à l'étranger
9527	14041T	ELUS_LOCAUX	2018-07-03 09:00:00	2018-07-03 18:00:00	déplacement à l'étranger
9528	14041T	ELUS_LOCAUX	2018-07-04 09:00:00	2018-07-04 18:00:00	déplacement à l'étranger
9529	14041T	ELUS_LOCAUX	2018-07-05 09:00:00	2018-07-05 18:00:00	déplacement à l'étranger
9621	04043D	ELUS_LOCAUX	2018-07-02 20:30:00	2018-07-02 23:00:00	réunion à Créteil concernant le developpement du projet televal ainsi que des associations d'usagers pour le futur projet d'Ile de France mobilités 
9625	04043D	ACC_DEPL_INTER	2018-07-05 12:45:00	2018-07-05 13:45:00	déjeuner avec la nouvelle ambassadrice de france en grèce, Mme Aglaia Balta
9623	04043D	ACC_VISIT	2018-07-03 14:00:00	2018-07-03 15:00:00	Réunion d'un groupe d'élèves de Saint mandé 
9624	04043D	ACC_DEPL_INTER	2018-07-03 20:00:00	2018-07-03 21:00:00	diner au salon Pourpre du Sénat avec son excellence l'ambassadrice de Suède reçu par le groupe d'amitié France-Europe du Nord
9641	01024M	CEREMONIE	2018-07-09 00:00:00	2018-07-09 00:00:00	Congrès de Versailles
9644	04086Q	ORG_POL	2018-07-03 10:30:00	2018-07-03 12:30:00	Réunion du groupe LR
9645	04086Q	REU_TRAV_PARL	2018-07-04 15:00:00	2018-07-04 16:00:00	Réunion colloque banileue
9649	04086Q	DEPL_PRES_GVT	2018-07-09 09:00:00	2018-07-09 23:30:00	Déplacement en Israël à l'invitation du président de la Knesset 
9647	04086Q	REU_TRAV_PARL	2018-07-04 16:30:00	2018-07-04 17:30:00	Réunion de travail groupe France-Israël
9648	04086Q	DEL_ACT_PAR	2018-07-04 18:30:00	2018-07-04 19:30:00	Intervention sur Public Sénat
9650	04086Q	DEPL_PRES_GVT	2018-07-10 00:30:00	2018-07-10 23:30:00	éplacement en Israël à l'invitation du président de la Knesse
9651	04042C	REU_TRAV_PARL	2018-07-09 15:00:00	2018-07-09 19:00:00	Congrès de Versailles
9652	04042C	ORG_POL	2018-07-10 11:00:00	2018-07-10 12:30:00	\N
9653	04042C	COLL_TER	2018-07-10 13:00:00	2018-07-10 14:15:00	Entretien avec le Préfet du Val-de-Marne
9654	04042C	CEREMONIE	2018-07-10 14:45:00	2018-07-10 15:15:00	Remise de Médailles aux 4 Vice-champions de France d'aviron à Joinville-le-Pont
9655	04042C	ACC_VISIT	2018-07-10 15:30:00	2018-07-10 16:00:00	Entretien Mairie de Saint-Maurice
9726	04086Q	DEPL_PRES_GVT	2018-07-11 08:30:00	2018-07-11 23:00:00	Déplacement en Israël à l'invitation du président de la Knesset
9729	04043D	ORG_POL	2018-07-10 19:00:00	2018-07-10 21:00:00	Réunion LR avec Laurent WAUQUIEZ, Président des Républicains
9741	08010L	REU_TRAV_PARL	2018-07-25 12:30:00	2018-07-25 13:00:00	commission des finances 
9742	08010L	REU_TRAV_PARL	2018-07-25 13:00:00	2018-07-25 14:30:00	dossier des "Américains accidentels" 
9744	19760E	ORG_POL	2018-07-03 00:00:00	2018-07-03 00:00:00	\N
9745	19760E	ORG_POL	2018-07-03 00:00:00	2018-07-03 00:00:00	Préparation PJL Liberté...
9746	19760E	DEPL_PRES_GVT	2018-07-04 12:00:00	2018-07-04 13:00:00	RDV à l'Elysée
9747	19760E	COLLOQUE	2018-07-05 14:00:00	2018-07-05 16:00:00	Colloque à l'Assemblée sur la santé
9748	19760E	DEPL_PRES_GVT	2018-07-09 13:00:00	2018-07-09 14:00:00	Serment du jeu de Paume à Versailles
9749	19760E	DEPL_PRES_GVT	2018-07-09 00:00:00	2018-07-09 00:00:00	Congrès, à Versailles
9750	19760E	ORG_POL	2018-07-10 00:00:00	2018-07-10 00:00:00	\N
9751	19760E	REU_TRAV_PARL	2018-07-16 09:30:00	2018-07-16 10:30:00	Maisons de santé
9752	19760E	REU_TRAV_PARL	2018-07-16 11:00:00	2018-07-16 13:00:00	Réseau Environnement Santé
9753	19760E	REU_TRAV_PARL	2018-07-16 14:00:00	2018-07-16 16:00:00	Groupement des Entreprises Adaptées
9785	04042C	ELUS_LOCAUX	2018-08-29 13:00:00	2018-08-29 14:30:00	Entretien avec le Maire de Maisons-Alfort
9801	04042C	ACC_DEPL_INTER	2018-08-31 09:00:00	2018-08-31 17:30:00	Intervention Colloque La Chine et l'Asie à l'invitation de Monsieur Jean-Pierre Raffarin, ancien Premier ministre à Poitiers
10090	04042C	REU_TRAV_PARL	2018-10-11 09:00:00	2018-10-11 12:30:00	Réunion Délégation parlementaire du Renseignement
9906	01024M	REU_TRAV_PARL	2018-09-10 08:30:00	2018-09-10 12:00:00	Commission des lois - MI Vote électronique
9979	04043D	ORG_POL	2018-10-02 11:00:00	2018-10-02 12:00:00	Réunion du groupe Les Républicains
10091	04042C	ACC_DEPL_INTER	2018-10-11 12:30:00	2018-10-11 14:30:00	Rencontre avec le Chef d'état-major de l'armée de Terre
10092	04042C	ACC_DEPL_INTER	2018-10-11 18:30:00	2018-10-11 20:30:00	Réception à l'Ambassade d'Espagne en France à l'occasion de la Fête nationale
10093	04042C	ELUS_LOCAUX	2018-10-12 18:00:00	2018-10-12 20:30:00	Visite au Salon des métiers d'Art du Plateau Briard à Marolles-en-Brie
10094	08010L	ORG_POL	2018-10-16 10:30:00	2018-10-16 13:00:00	Groupe LR du sénat
10107	14041T	ELUS_LOCAUX	2018-10-30 09:00:00	2018-10-30 18:00:00	déplacement à l'étranger
10108	14041T	ELUS_LOCAUX	2018-10-31 09:00:00	2018-10-31 18:00:00	déplacement à l'étranger
10007	14211G	COLL_TER	2018-09-18 14:30:00	2018-09-18 16:00:00	Commission DETR en Préfecture
10116	04043D	CEREMONIE	2018-10-12 18:00:00	2018-10-12 19:30:00	20ème anniversaire du salon des métiers d'art du Plateau Briard-Marolles-en-Brie
10118	04043D	REU_TRAV_PARL	2018-10-17 13:00:00	2018-10-17 14:30:00	déjeuner Groupe France-USA
10119	04086Q	COLLOQUE	2018-10-11 14:00:00	2018-10-11 15:00:00	Intervention lors du colloque sur l'eau à l'Assemblée nationale
10120	04086Q	COLLOQUE	2018-10-11 17:00:00	2018-10-11 18:30:00	Clôture  du colloque sur l'eau à l'Assemblée nationale
10122	04086Q	REU_TRAV_PARL	2018-10-16 10:00:00	2018-10-16 11:00:00	Audition dans le cadre du PLF 2019
10123	04086Q	ORG_POL	2018-10-16 11:00:00	2018-10-16 12:30:00	Réunion du groupe LR
10124	04086Q	REU_TRAV_PARL	2018-10-16 13:00:00	2018-10-16 14:30:00	Déjeuner de travail avec le consul Général de France à Erbil
10125	04086Q	ORG_POL	2018-10-16 18:00:00	2018-10-16 19:30:00	Comité stratégique LR
10126	04086Q	REU_TRAV_PARL	2018-10-17 08:00:00	2018-10-17 09:00:00	Petit-déjeuner de travail avec les dirigeants de la Fédération des Promoteurs Immobiliers
10127	04086Q	REU_TRAV_PARL	2018-10-17 13:00:00	2018-10-17 14:30:00	Déjeuner des groupes d'amitié France-Allemagne en présence de l'ambassadeur de la République Fédérale d'Allemagne
10128	04086Q	REU_TRAV_PARL	2018-10-17 19:30:00	2018-10-17 20:30:00	Conférence des Présidents
10129	04086Q	COLL_TER	2018-10-18 11:30:00	2018-10-18 12:30:00	Réunion de la Métropole du Grand Paris 
9504	14211G	COLL_TER	2018-06-20 18:00:00	2018-06-20 21:00:00	Conseil de Métropole
9541	08010L	REU_TRAV_PARL	2018-06-27 08:30:00	2018-06-27 09:15:00	\N
9542	04043D	REU_TRAV_PARL	2018-06-25 18:00:00	2018-06-25 19:00:00	Réunion d'échanges relative à mission d'information sur le développement de l'herboristerie et des plantes médicinales
9543	04043D	ORG_POL	2018-06-26 11:00:00	2018-06-26 12:00:00	Réunion de Groupe LR
9544	04043D	REU_TRAV_PARL	2018-06-26 13:45:00	2018-06-26 15:00:00	Réunion commission des Affaires Economiques
9545	04043D	REU_TRAV_PARL	2018-06-26 18:30:00	2018-06-26 19:30:00	Réunion du Conseil d¿administration de l'AGAS
9546	04043D	ELUS_LOCAUX	2018-06-26 19:45:00	2018-06-26 21:45:00	Assemblée Générale LR Saint-Mandé
9547	04042C	ORG_POL	2018-06-27 08:30:00	2018-06-27 09:30:00	Rencontres matinales 
9548	04042C	REU_TRAV_PARL	2018-06-27 12:45:00	2018-06-27 14:00:00	Présentation des Universités de la Défense
9586	08009T	ORG_POL	2018-06-12 11:00:00	2018-06-12 13:00:00	\N
9587	08009T	REU_TRAV_PARL	2018-06-13 08:00:00	2018-06-13 09:00:00	\N
9588	08009T	REU_TRAV_PARL	2018-06-13 16:00:00	2018-06-13 17:00:00	\N
9589	08009T	REU_TRAV_PARL	2018-06-13 17:00:00	2018-06-13 17:30:00	\N
9590	08009T	REU_TRAV_PARL	2018-06-19 09:00:00	2018-06-19 10:00:00	\N
9595	08009T	REU_TRAV_PARL	2018-06-20 08:30:00	2018-06-20 09:30:00	\N
9592	08009T	ORG_POL	2018-06-19 13:00:00	2018-06-19 14:30:00	\N
9593	08009T	ORG_POL	2018-06-19 11:00:00	2018-06-19 13:00:00	\N
9594	08009T	REU_TRAV_PARL	2018-06-19 16:00:00	2018-06-19 17:00:00	\N
9602	08009T	REU_GVT	2018-06-27 08:30:00	2018-06-27 09:30:00	\N
9597	08009T	REU_TRAV_PARL	2018-06-20 16:00:00	2018-06-20 17:00:00	\N
9598	08009T	REU_TRAV_PARL	2018-06-20 17:00:00	2018-06-20 18:00:00	\N
9599	08009T	REU_TRAV_PARL	2018-06-20 20:30:00	2018-06-20 21:30:00	\N
9600	08009T	ORG_POL	2018-06-26 11:00:00	2018-06-26 13:00:00	\N
9601	08009T	REU_TRAV_PARL	2018-06-26 18:30:00	2018-06-26 19:30:00	\N
9606	08009T	REU_GVT	2018-06-28 18:30:00	2018-06-28 20:00:00	\N
9604	08009T	REU_GVT	2018-06-28 10:00:00	2018-06-28 12:00:00	\N
9605	08009T	REU_TRAV_PARL	2018-06-28 13:00:00	2018-06-28 14:00:00	\N
9659	04043D	ACC_VISIT	2018-07-12 11:30:00	2018-07-12 12:30:00	\N
9709	04042C	REU_TRAV_PARL	2018-07-17 17:30:00	2018-07-17 19:00:00	\N
9707	04042C	ORG_POL	2018-07-17 10:30:00	2018-07-17 12:45:00	En présence de François Baroin
9708	04042C	REU_TRAV_PARL	2018-07-17 13:00:00	2018-07-17 14:30:00	Entretien avec le Président de la Défense et des Forces armées de l'Assemblée nationale
9710	04042C	ACC_DEPL_INTER	2018-07-17 19:30:00	2018-07-17 21:30:00	Rencontre avec le Ministre de l'Europe et des Affaires étrangères
9711	08010L	CEREMONIE	2018-07-18 10:00:00	2018-07-18 15:00:00	Observatoire Mangin
9712	08010L	REU_TRAV_PARL	2018-07-18 16:30:00	2018-07-18 19:00:00	PJL ELAN
9730	08010L	ORG_POL	2018-07-24 11:00:00	2018-07-24 12:30:00	Groupe LR du sénat
9826	04042C	ACC_DEPL_INTER	2018-09-05 12:00:00	2018-09-05 14:30:00	Entrtien avec le Président du Sénat de la présidente du Sénat néerlandais
9901	08010L	ORG_POL	2018-09-11 09:00:00	2018-09-11 18:00:00	Séminaire LR
9902	08010L	ELUS_LOCAUX	2018-09-13 11:30:00	2018-09-13 14:30:00	Préfecture 
9903	08010L	REU_TRAV_PARL	2018-09-19 17:30:00	2018-09-19 20:00:00	CA de la FedEPL
9905	08010L	REU_TRAV_PARL	2018-09-20 09:00:00	2018-09-20 13:00:00	Rencontre Nationale des EPL
9907	01024M	REU_TRAV_PARL	2018-09-13 08:00:00	2018-09-13 20:00:00	Commission des lois - Déplacemernt Tallinn MI Vote électronique
9908	01024M	REU_TRAV_PARL	2018-09-14 08:00:00	2018-09-14 18:00:00	Commission des lois - Déplacemernt Tallinn MI Vote électronique
9909	04086Q	COLLOQUE	2018-09-12 10:30:00	2018-09-12 11:30:00	Table ronde Caisse d'épargne : Finances locales, zoom sur les réformes à venir
9910	04086Q	ACC_DEPL_INTER	2018-09-12 12:00:00	2018-09-12 14:30:00	Accueil de Milan Stech, président du Sénat de la République Tchèque
9911	04086Q	REU_TRAV_PARL	2018-09-13 10:00:00	2018-09-13 12:00:00	Réunion de travail des parlementaires suite au Rapport Cornut-Gentile/Kokouendo
9912	04086Q	REU_TRAV_PARL	2018-09-18 11:00:00	2018-09-18 12:30:00	Réunion de travail pour la loi ELAN
9913	04042C	DEPL_PRES_GVT	2018-09-19 00:00:00	2018-09-19 00:00:00	Mission du Syndicat des Eaux d'Ile-de France au Japon
9914	04042C	DEPL_PRES_GVT	2018-09-20 00:00:00	2018-09-20 00:00:00	Mission du Syndicat des Eaux d'Ile-de France au Japon
9915	04042C	DEPL_PRES_GVT	2018-09-21 00:00:00	2018-09-21 00:00:00	Mission du Syndicat des Eaux d'Ile-de France au Japon
9921	04043D	ACC_DEPL_INTER	2018-09-17 09:00:00	2018-09-17 20:20:00	déplacement dans les iles du Pacifique en qualité de Présidente du Groupe d'Amitié  Vanuatu
9922	04043D	ACC_DEPL_INTER	2018-09-18 09:00:00	2018-09-18 20:00:00	déplacement dans les iles du Pacifique en qualité de Présidente du Groupe d'Amitié  Vanuatu
9927	04043D	ACC_DEPL_INTER	2018-09-20 09:00:00	2018-09-20 20:00:00	déplacement dans les iles du Pacifique en qualité de Présidente du Groupe d'Amitié  Vanuatu
9931	04043D	ACC_DEPL_INTER	2018-09-26 09:00:00	2018-09-26 20:00:00	déplacement dans les iles du Pacifique en qualité de Présidente du Groupe d'Amitié  Vanuatu
9928	04043D	ACC_DEPL_INTER	2018-09-21 09:00:00	2018-09-21 20:00:00	déplacement dans les iles du Pacifique en qualité de Présidente du Groupe d'Amitié  Vanuatu
9932	04043D	ACC_DEPL_INTER	2018-09-27 09:00:00	2018-09-27 20:00:00	déplacement dans les iles du Pacifique en qualité de Présidente du Groupe d'Amitié  Vanuatu
9934	08048B	CEREMONIE	2018-09-25 00:00:00	2018-09-25 00:00:00	Ravivage de la Flamme sous l'Arc de Triomphe à l'occasion de la Journée nationale d'hommage aux Harkis 
10002	14211G	REU_GVT	2018-09-04 18:30:00	2018-09-04 20:00:00	\N
10003	14211G	ELUS_LOCAUX	2018-09-06 12:30:00	2018-09-06 14:00:00	\N
10004	14211G	ORG_POL	2018-09-11 08:00:00	2018-09-11 20:00:00	Journées parlementaires
10005	14211G	REU_GVT	2018-09-12 12:00:00	2018-09-12 13:00:00	\N
10008	14211G	CEREMONIE	2018-09-18 18:00:00	2018-09-18 20:00:00	Inauguration de la Médiathèque de Castelnau-le-Lez
10009	14211G	ELUS_LOCAUX	2018-09-19 12:00:00	2018-09-19 14:00:00	\N
10010	14211G	CEREMONIE	2018-09-19 18:00:00	2018-09-19 20:00:00	Yom Kippour
10011	14211G	ELUS_LOCAUX	2018-09-20 12:00:00	2018-09-20 14:00:00	\N
10012	14211G	COLL_TER	2018-09-20 18:00:00	2018-09-20 21:00:00	Conseil de Métropole
10016	14211G	COLL_TER	2018-09-27 19:00:00	2018-09-27 20:00:00	\N
10014	14211G	ORG_POL	2018-09-25 11:00:00	2018-09-25 12:00:00	Groupe Les Républicains
10015	14211G	ELUS_LOCAUX	2018-09-27 11:00:00	2018-09-27 12:00:00	\N
10017	14211G	REU_TRAV_PARL	2018-10-02 10:00:00	2018-10-02 11:00:00	Commissaires LR
10018	14211G	ORG_POL	2018-10-02 11:00:00	2018-10-02 12:00:00	Groupe Les Républicains
10019	14211G	COLL_TER	2018-10-04 09:00:00	2018-10-04 13:00:00	Salon des Maires de l'Hérault
10020	14211G	DEPL_PRES_GVT	2018-08-02 10:30:00	2018-08-02 17:30:00	Jean-Baptiste LEMOYNE à La Grande Motte
10059	08009T	DEPL_PRES_GVT	2018-10-11 10:00:00	2018-10-11 12:30:00	\N
10060	08009T	REU_TRAV_PARL	2018-10-10 08:30:00	2018-10-10 09:30:00	\N
10061	08009T	ELUS_LOCAUX	2018-10-10 11:50:00	2018-10-10 12:30:00	\N
10062	08009T	REU_TRAV_PARL	2018-10-10 12:30:00	2018-10-10 14:00:00	\N
10064	08009T	ACC_DEPL_INTER	2018-10-10 15:30:00	2018-10-10 16:30:00	\N
10065	08009T	REU_TRAV_PARL	2018-10-09 09:00:00	2018-10-09 10:00:00	\N
10066	08009T	REU_TRAV_PARL	2018-10-09 10:00:00	2018-10-09 11:00:00	\N
10067	08009T	ORG_POL	2018-10-09 11:00:00	2018-10-09 12:30:00	\N
10069	08009T	REU_GVT	2018-10-04 09:00:00	2018-10-04 10:30:00	\N
10070	08009T	REU_GVT	2018-10-04 10:30:00	2018-10-04 11:30:00	\N
10071	08009T	REU_TRAV_PARL	2018-10-02 08:00:00	2018-10-02 09:00:00	\N
10072	08009T	REU_TRAV_PARL	2018-10-02 10:00:00	2018-10-02 11:00:00	\N
10073	08009T	ORG_POL	2018-10-02 11:00:00	2018-10-02 12:30:00	\N
10074	08009T	ELUS_LOCAUX	2018-10-02 13:00:00	2018-10-02 14:30:00	\N
10075	08009T	ELUS_LOCAUX	2018-10-02 16:00:00	2018-10-02 16:45:00	\N
10076	08009T	DEPL_PRES_GVT	2018-09-25 00:01:00	2018-09-25 23:59:00	\N
10077	08009T	DEPL_PRES_GVT	2018-09-26 00:01:00	2018-09-26 23:59:00	\N
10078	08009T	DEPL_PRES_GVT	2018-09-27 00:01:00	2018-09-27 23:59:00	\N
10079	08009T	REU_TRAV_PARL	2018-09-19 00:00:00	2018-09-19 00:00:00	\N
10080	08009T	REU_TRAV_PARL	2018-09-19 11:30:00	2018-09-19 12:30:00	\N
10084	08009T	REU_GVT	2018-09-11 17:00:00	2018-09-11 19:00:00	\N
10082	08009T	REU_TRAV_PARL	2018-09-13 10:00:00	2018-09-13 11:00:00	\N
10083	08009T	REU_TRAV_PARL	2018-09-11 16:00:00	2018-09-11 17:00:00	\N
10085	08009T	DEPL_PRES_GVT	2018-09-04 00:01:00	2018-09-04 23:59:00	\N
10086	08009T	DEPL_PRES_GVT	2018-09-05 00:01:00	2018-09-05 23:59:00	\N
10087	08009T	DEPL_PRES_GVT	2018-09-06 00:01:00	2018-09-06 23:59:00	\N
10088	08009T	REU_TRAV_PARL	2018-08-29 11:00:00	2018-08-29 12:00:00	\N
10089	08009T	REU_TRAV_PARL	2018-08-29 12:30:00	2018-08-29 14:30:00	\N
10147	04042C	ACC_DEPL_INTER	2018-10-18 18:30:00	2018-10-18 19:30:00	Entretien avec le négociateur en chef de l'Union Européenne sur le Brexit
10148	04042C	ELUS_LOCAUX	2018-10-22 11:00:00	2018-10-22 11:30:00	Réunion urbanisme à la Mairie de Saint-Maurice
10149	04042C	ACC_VISIT	2018-10-22 11:30:00	2018-10-22 12:30:00	Visite de courtoisie de la nouvelle directrice de la Direction départementale des Finances Publiques
9376	04042C	REU_GVT	2018-06-08 10:30:00	2018-06-08 12:30:00	Réunion Ministère des armées
9377	04042C	ACC_DEPL_INTER	2018-06-08 12:30:00	2018-06-08 14:30:00	rencontre à l'Ambassade du Portugal
9384	14026U	ORG_POL	2018-06-12 10:00:00	2018-06-12 11:00:00	Bureau du Groupe  LR Sénat
9385	14026U	ORG_POL	2018-06-12 11:00:00	2018-06-12 12:00:00	Réunion du groupe LR Sénat
9418	04086Q	REU_TRAV_PARL	2018-06-13 13:00:00	2018-06-13 14:30:00	Réunion de travail avec Action Logement
9387	08010L	REU_TRAV_PARL	2018-06-12 14:00:00	2018-06-12 15:30:00	Ambassade des Etats-Unis
9409	01025N	REU_TRAV_PARL	2018-05-30 16:30:00	2018-05-30 17:00:00	Entretien Président du Souvenir Français
9436	14211G	REU_GVT	2018-05-30 15:30:00	2018-05-30 17:30:00	\N
9437	14211G	COLL_TER	2018-05-31 18:00:00	2018-05-31 20:00:00	Conseil de Métropole
9438	14211G	ORG_POL	2018-06-05 11:00:00	2018-06-05 12:00:00	Groupe Les Républicains
9439	14211G	REU_TRAV_PARL	2018-06-05 12:15:00	2018-06-05 13:00:00	\N
9440	14211G	ORG_POL	2018-06-12 11:00:00	2018-06-12 12:00:00	Groupe Les Républicains
9441	14211G	ACC_DEPL_INTER	2018-06-12 12:30:00	2018-06-12 14:00:00	France-Australie
9442	14211G	DEPL_PRES_GVT	2018-06-13 10:00:00	2018-06-13 13:00:00	42ème Congrès de la Mutualité Française à Montpellier
9443	04042C	CEREMONIE	2018-06-13 20:00:00	2018-06-13 22:00:00	Lancement Eurosatory 2018 par le Chef d'état-major de l'Armée de terre
9444	04042C	DEPL_PRES_GVT	2018-06-14 07:00:00	2018-06-14 16:30:00	Visite avec le Président de la République de la Base aérienne 721 à Rochefort
9445	04042C	ELUS_LOCAUX	2018-06-14 19:00:00	2018-06-14 21:00:00	Lancement du projet Ivry autrement
9549	04043D	ACC_VISIT	2018-06-27 15:00:00	2018-06-27 17:00:00	acceuil de visiteurs de Villiers sur Marne 
9550	04043D	REU_TRAV_PARL	2018-06-27 17:00:00	2018-06-27 18:00:00	Réunion avec Gilles Leblanc, président de l'ACNUSA portant sur les nuisances aéroportuaires par rapport au PJL ELAN et pacte 
9551	04042C	ACC_DEPL_INTER	2018-06-27 18:30:00	2018-06-27 19:00:00	Ambassade de Suisse rencontre avec le Général de division
9552	04042C	ELUS_LOCAUX	2018-06-27 21:00:00	2018-06-27 22:30:00	Conseil municipal de Saint-Maurice
9553	04042C	REU_GVT	2018-06-28 12:30:00	2018-06-28 13:30:00	Ministère des armées à l'occasion de la lecture des conclusions de la CMP/LPM
9554	04042C	ACC_VISIT	2018-06-27 16:00:00	2018-06-27 16:10:00	Interview Public Sénat sur le Service National Universel
9555	04042C	ELUS_LOCAUX	2018-06-28 20:00:00	2018-06-28 22:00:00	Rencontre avec le Conseil municipal de Bry-Sur-Marne
9556	04042C	ACC_DEPL_INTER	2018-06-28 22:00:00	2018-06-28 23:00:00	Ambassade des Etats-Unis d'Amérique à l'occasion du 242ème anniversaire de l'Indépendance 
9562	04086Q	REU_TRAV_PARL	2018-06-19 14:00:00	2018-06-19 14:30:00	RDV PJL ELAN 
9564	04086Q	REU_TRAV_PARL	2018-06-20 20:00:00	2018-06-20 21:00:00	Diner de travail PJL ELAN 
9565	04086Q	REU_TRAV_PARL	2018-06-21 09:00:00	2018-06-21 10:00:00	Réunion de travail Colloque banlieue
9566	04086Q	REU_TRAV_PARL	2018-06-21 11:00:00	2018-06-21 12:30:00	Réunion de travail AN parlementaires SSD
9567	04086Q	DEPL_PRES_GVT	2018-06-21 17:30:00	2018-06-21 23:00:00	Déplacement au Maroc
9568	04086Q	DEPL_PRES_GVT	2018-06-22 01:00:00	2018-06-22 23:00:00	Déplacement au Maroc
9573	04086Q	REU_TRAV_PARL	2018-06-26 12:45:00	2018-06-26 14:30:00	Groupe de travail LR PJL ELAN
9574	04086Q	REU_TRAV_PARL	2018-06-26 18:00:00	2018-06-26 19:30:00	Réunion de travail avec les parlementaires de SSD
9575	04086Q	REU_TRAV_PARL	2018-06-27 12:00:00	2018-06-27 13:30:00	RDV PJL ELAN 
9576	04086Q	REU_TRAV_PARL	2018-06-28 14:30:00	2018-06-28 15:45:00	Audition Rapporteur Com Fin, Rapport aides à la pierre
9577	04086Q	REU_TRAV_PARL	2018-06-28 16:00:00	2018-06-28 17:15:00	Audition Rapporteur Com Fin, Rapport aides à la pierre
9578	04086Q	REU_TRAV_PARL	2018-06-28 17:30:00	2018-06-28 18:30:00	Réunion colloque banileue
9579	04086Q	COLL_TER	2018-06-28 20:00:00	2018-06-28 22:30:00	Intervention lors du diner débat autour des enjeux du Grand Paris
9580	04086Q	DEPL_PRES_GVT	2018-06-29 07:30:00	2018-06-29 18:30:00	Déplacement dnas le cadre du tour de France du Logement avec G. Larcher à Allonnes (72)
9701	04042C	ELUS_LOCAUX	2018-07-16 10:00:00	2018-07-16 12:30:00	Entretien avec le Maire de Saint-Maurice et réunion
9702	04042C	ORG_POL	2018-07-16 10:30:00	2018-07-16 12:30:00	\N
9703	08010L	ORG_POL	2018-07-17 10:30:00	2018-07-17 13:00:00	Groupe LR du sénat + François Baroin
9718	08048B	ORG_POL	2018-06-26 11:00:00	2018-06-26 12:00:00	Réunion du Groupe LR du Sénat
9714	04042C	CEREMONIE	2018-07-18 19:30:00	2018-07-18 23:30:00	Réception de départ du général d'armée aérienne française, chef d'état-major de l'armée de l'air
9715	04042C	ACC_DEPL_INTER	2018-07-19 17:20:00	2018-07-19 18:30:00	Entretien avec le Président du Sénat du Président de la République d'Azerbaïdjan
9719	08048B	ORG_POL	2018-07-10 11:00:00	2018-07-10 12:00:00	Réunion du groupe LR du Sénat
9720	08048B	ORG_POL	2018-07-17 11:00:00	2018-07-17 11:00:00	Réunion du Groupe LR du Sénat
9781	04042C	CEREMONIE	2018-08-27 11:00:00	2018-08-27 13:00:00	Discours du Président de la République à la Conférence des Ambassadeurs et des Ambassadrices
9782	04042C	CEREMONIE	2018-08-27 15:30:00	2018-08-27 17:30:00	Cérémonie d'adieu du général de corps aérien présidé par le général d'arme aérienne 
9784	04042C	CEREMONIE	2018-08-28 20:00:00	2018-08-28 22:00:00	Réception de la Conférence des Ambassadeurs et des Ambassadrices au Ministère des armées
9861	04042C	DEPL_PRES_GVT	2018-09-10 08:30:00	2018-09-10 17:30:00	Université d'été de la Défense
9862	04042C	ORG_POL	2018-09-10 20:30:00	2018-09-10 23:30:00	\N
9863	04042C	DEPL_PRES_GVT	2018-09-11 07:45:00	2018-09-11 17:00:00	Université d'été de la Défense
9864	04042C	ORG_POL	2018-09-11 19:00:00	2018-09-11 20:00:00	réunion des militants de Saint-Maurice
9865	04042C	REU_TRAV_PARL	2018-09-12 11:00:00	2018-09-12 11:45:00	\N
9866	04042C	ACC_DEPL_INTER	2018-09-12 12:00:00	2018-09-12 14:30:00	Entretien avec le Président du Senat avec le Président du Sénat tchèque
9867	04042C	ACC_VISIT	2018-09-12 15:00:00	2018-09-12 16:00:00	Entretien evec le Président de l'IFRI
9868	04042C	ACC_VISIT	2018-09-12 16:00:00	2018-09-12 16:30:00	Entretien pour la préparation d'un colloque "Penser et construire la résilience citoyenne"
9872	04042C	CEREMONIE	2018-09-13 12:30:00	2018-09-13 14:30:00	Les 100 ans de l'aéroport d'Orly
9873	04042C	ELUS_LOCAUX	2018-09-14 08:45:00	2018-09-14 11:30:00	Réunion du Syndicat des Eaux d'Ile-de France
9871	04042C	REU_TRAV_PARL	2018-09-13 08:30:00	2018-09-13 10:00:00	Réunion du bureau de la commission des Affaires étrangères, de la Défense et des Forces armées
9874	04042C	ELUS_LOCAUX	2018-09-14 11:30:00	2018-09-14 13:30:00	Pose de la 1ère pierre pour la refonte de la station de relèvement à Antony
9954	04042C	ACC_DEPL_INTER	2018-09-27 18:50:00	2018-09-27 21:30:00	Entretien avec le Président du Sénat avec le Président du Sénat du Congo
9955	04042C	ACC_VISIT	2018-09-27 16:30:00	2018-09-27 17:30:00	Emission Public Senat relation Etat et collectivités territoriales
9956	04042C	ACC_VISIT	2018-09-27 15:00:00	2018-09-27 16:00:00	Accueil des personnels de l'armée
9957	04042C	ELUS_LOCAUX	2018-09-27 22:00:00	2018-09-27 23:00:00	Reunion du Conseil municipal de Saint-Maurice
10021	08010L	ORG_POL	2018-10-09 11:00:00	2018-10-09 12:30:00	Groupe LR du sénat
10022	04042C	CEREMONIE	2018-10-04 17:00:00	2018-10-04 19:00:00	Cérémonie de la Célébration du 60ème anniversaire de la Constitution
10023	04042C	ORG_POL	2018-10-04 20:00:00	2018-10-04 22:30:00	Réunion publique Groupe Libre 94 sur l'Europe à Saint-Maurice
10024	04042C	ELUS_LOCAUX	2018-10-05 15:00:00	2018-10-05 17:00:00	Réuion Inventons la Métropole à Joinville-le-Pont
10025	04042C	COLL_TER	2018-10-08 11:30:00	2018-10-08 12:30:00	Entretien avec la directrice départementale de la DDSP du Val-de-Marne
10029	04042C	ORG_POL	2018-10-09 11:00:00	2018-10-09 12:30:00	\N
10027	04042C	ACC_DEPL_INTER	2018-10-08 18:00:00	2018-10-08 19:00:00	Entretien  avec le Président du Sénat du Président de la République de l'Ouzbékistan
10028	04042C	ACC_DEPL_INTER	2018-10-08 17:00:00	2018-10-08 18:00:00	Entretien avec le Président du Sénat du Président de la République du Chili
10030	04042C	REU_TRAV_PARL	2018-10-09 12:30:00	2018-10-09 13:00:00	Réunion de Direction
10031	04042C	ACC_VISIT	2018-10-09 14:45:00	2018-10-09 16:15:00	Entretien avec le chef d'état-major de l'armée de l'air
10032	04042C	REU_TRAV_PARL	2018-10-09 16:15:00	2018-10-09 16:45:00	Réunion de Direction
10104	08010L	ACC_VISIT	2018-10-17 11:30:00	2018-10-17 12:30:00	Conseillers municipaux de l'Aisne
10105	08010L	DEL_ACT_PAR	2018-10-17 13:00:00	2018-10-17 14:30:00	France Etat-Unis 
10106	08010L	REU_TRAV_PARL	2018-10-17 15:30:00	2018-10-17 17:30:00	PLF 2019 Justice
10109	14041T	ELUS_LOCAUX	2018-11-06 09:00:00	2018-11-06 18:00:00	déplacement à l'étranger
9400	04086Q	REU_TRAV_PARL	2018-06-06 12:00:00	2018-06-06 12:30:00	Réunion de travail sur le logement avec Bruno Retailleau 
9402	14213J	ORGEXTPAR	2018-02-15 09:30:00	2018-02-15 13:00:00	Conseil Consultatif National d'Ethique
9403	04086Q	COLL_TER	2018-06-08 14:30:00	2018-06-08 16:00:00	Réunion ARS 
9485	04042C	ACC_VISIT	2018-06-18 15:30:00	2018-06-18 16:30:00	Commission Relations internationales et solidarités du Syndicat des Eaux d'Ile-de-France
9486	04042C	REU_TRAV_PARL	2018-06-18 17:00:00	2018-06-18 18:00:00	réunion sur la CMP LPM
9487	04042C	ELUS_LOCAUX	2018-06-18 18:30:00	2018-06-18 19:30:00	Séance d'installation du comité consultatif pour le projet culturel du Cinema à la Mairie de Saint-Maurice
9488	04042C	ORG_POL	2018-06-18 20:00:00	2018-06-18 22:00:00	Réunion à l'Haÿ-les-Roses
9489	04042C	REU_TRAV_PARL	2018-06-19 09:30:00	2018-06-19 11:00:00	CMP LPM
9490	04042C	ORG_POL	2018-06-19 11:00:00	2018-06-19 12:00:00	\N
9491	14211G	ACC_VISIT	2018-06-19 11:00:00	2018-06-19 11:30:00	CMJ de la commune du CRES
9492	14211G	ORG_POL	2018-06-19 11:30:00	2018-06-19 12:00:00	Groupe Les Républicains
9581	04043D	ACC_VISIT	2018-06-28 10:15:00	2018-06-28 12:00:00	Rencontre avec l'ambassadeur de Corée et ses conseillers-musée du Luxembourg
9582	08009T	REU_GVT	2018-06-06 11:00:00	2018-06-06 13:30:00	\N
9583	08009T	REU_TRAV_PARL	2018-06-06 16:00:00	2018-06-06 17:00:00	\N
9584	08009T	REU_TRAV_PARL	2018-06-06 17:30:00	2018-06-06 18:30:00	\N
9585	08009T	REU_GVT	2018-06-06 19:00:00	2018-06-06 20:00:00	\N
9607	04043D	ACC_VISIT	2018-07-02 10:00:00	2018-07-02 11:00:00	Visite étudiants Finlandais de Nogent-sur-Marne
9608	04042C	COLL_TER	2018-06-29 13:00:00	2018-06-29 14:30:00	\N
9609	04042C	ACC_VISIT	2018-06-29 15:00:00	2018-06-29 17:00:00	Visite guidée du Sénat des Amis de la Gendarmerie de Maisons-Alfort
9610	08010L	ORG_POL	2018-07-03 11:00:00	2018-07-03 12:30:00	Groupe LR du sénat
9611	19705W	ORG_POL	2018-06-12 11:00:00	2018-06-12 12:30:00	\N
9656	04043D	REU_TRAV_PARL	2018-07-10 18:00:00	2018-07-10 19:00:00	Mission d¿information sur le développement de l¿herboristerie et des plantes médicinales, des filières et métiers d¿avenir
9657	04043D	REU_TRAV_PARL	2018-07-11 08:00:00	2018-07-11 10:30:00	GPE - Audition de M. Jean-Yves Le Gall,PDG du CNES 
9783	04042C	CEREMONIE	2018-08-27 20:15:00	2018-08-27 22:00:00	Réception de la Conférence des Ambassadeurs et des Ambassadrices au Ministère de l'Europe et des Affaires étrangères
9823	04042C	REU_TRAV_PARL	2018-09-05 10:30:00	2018-09-05 11:30:00	\N
9824	04042C	DEPL_PRES_GVT	2018-09-05 15:30:00	2018-09-05 16:30:00	Visite du Centre de secours de Chevilly-Larue avec la Ministre des armées et le Ministre de l'Intérieur
9825	04042C	DEPL_PRES_GVT	2018-09-05 18:00:00	2018-09-05 20:30:00	Réception à l'occasion du 148ème anniversaire de la proclamation de la République à la Préfecture de Région d'Ile-de-France
9842	04043D	ORG_POL	2018-09-11 10:00:00	2018-09-11 20:00:00	Journées Parlementaires groupe LR à Honfleur
9962	08010L	CEREMONIE	2018-10-02 20:00:00	2018-10-02 21:00:00	Unité Allemande 
9963	04042C	ELUS_LOCAUX	2018-10-01 15:00:00	2018-10-01 16:00:00	Reunion avec le Maire de Saint-Maurice et la Mairie de Paris
9964	04042C	ACC_DEPL_INTER	2018-10-01 16:30:00	2018-10-01 17:30:00	Entretien avec le Président du Sénat du Président du Sénat de Thaïlande 
9965	04042C	COLLOQUE	2018-10-01 18:30:00	2018-10-01 19:30:00	Conférence-débat : Le profil hybride des auteurs d'attentats : de la délinquance au terrorisme
9966	04042C	REU_TRAV_PARL	2018-10-01 17:45:00	2018-10-01 18:30:00	\N
9967	04042C	CEREMONIE	2018-10-01 19:30:00	2018-10-01 21:00:00	Inauguration de l'exposition Miro au Grand Palais
9968	04042C	ORG_POL	2018-10-02 10:00:00	2018-10-02 11:00:00	\N
9969	04042C	ORG_POL	2018-10-02 11:00:00	2018-10-02 12:20:00	\N
9970	04042C	ACC_DEPL_INTER	2018-10-02 13:00:00	2018-10-02 14:15:00	Entretien avec l'Ambassadeur du Maroc en France
9971	04042C	REU_TRAV_PARL	2018-10-02 15:30:00	2018-10-02 16:30:00	\N
9972	04042C	REU_GVT	2018-10-02 18:00:00	2018-10-02 18:30:00	Entretien avec Madame la Ministe des armées
9973	04042C	ACC_DEPL_INTER	2018-10-02 18:30:00	2018-10-02 19:30:00	Cérémonie à l'occasion de la journée de l'Unité allemande 
9974	04042C	ORG_POL	2018-10-02 20:00:00	2018-10-02 22:00:00	Réunion bilan de mi-mandat avec les élus du Conseil régional du Val-de-Marne
9975	04042C	ACC_DEPL_INTER	2018-10-03 15:00:00	2018-10-03 16:00:00	Entretien avec la Commission de la sécurité de la protection des personnes et des biens  de l'AFE
9976	04042C	ACC_VISIT	2018-10-03 16:30:00	2018-10-03 17:30:00	Echange avec la réserve citoyenne de la marine nationale
9977	04042C	ACC_VISIT	2018-10-03 17:30:00	2018-10-03 18:30:00	Entretien avec le Président Directeur Général de Naval Group
9978	04042C	ACC_DEPL_INTER	2018-10-03 19:30:00	2018-10-03 21:15:00	Réception Franco-Allemande au Sénat
10001	04043D	ACC_DEPL_INTER	2018-10-02 14:30:00	2018-10-02 15:30:00	\N
9981	04043D	DEPL_PRES_GVT	2018-10-04 10:00:00	2018-10-04 14:00:00	Déplacement au Mondial de l'Auto-Bureau de la Commission des Affaires Economiques
9982	04043D	REU_TRAV_PARL	2018-10-04 16:00:00	2018-10-04 19:00:00	OPECST : auditions sur l'exploration de MARS 
10039	04043D	ACC_VISIT	2018-10-10 15:00:00	2018-10-10 17:30:00	L'Hay-les-Roses
10040	04043D	CEREMONIE	2018-10-10 18:30:00	2018-10-10 19:30:00	Remise des insignes d'officier dans l'ordre des Palmes Académiques
10165	01025N	REU_TRAV_PARL	2018-10-23 16:30:00	2018-10-23 20:00:00	Auditions PLF 2019 Agriculture
10042	04086Q	DEPL_PRES_GVT	2018-09-20 08:30:00	2018-09-20 23:00:00	Déplacement en Allemagne avec le groupe d'amitié 
10043	04086Q	DEPL_PRES_GVT	2018-09-21 08:30:00	2018-09-21 23:00:00	Déplacement en Allemagne avec le groupe d'amitié 
10048	04086Q	COLL_TER	2018-09-28 09:00:00	2018-09-28 12:00:00	Conseil de la Métropole du Grand-Paris
10053	04086Q	COLLOQUE	2018-10-05 14:30:00	2018-10-05 17:30:00	Opération 5 octobre à la bourse du travail de Bobigny. Colloque avec les élus et acteurs institutionnels de SSD suite au rapport Cornut-Gentile/Kokouendo
10054	04086Q	COLL_TER	2018-10-08 09:30:00	2018-10-08 11:30:00	RDV en Mairie des Pavillons sous bois
10055	04086Q	ACC_DEPL_INTER	2018-10-08 17:00:00	2018-10-08 18:00:00	Accueil aux côtés de G. Larcher de Sebastian Pinera, président de la République du Chili
10056	04086Q	ACC_DEPL_INTER	2018-10-08 18:00:00	2018-10-08 19:00:00	Accueil aux côtés de G. Larcher de Shavkat Miromonovitch Mirziyoyev, président de la République d'Ouzbékistan 
10057	04086Q	REU_TRAV_PARL	2018-10-09 17:00:00	2018-10-09 21:30:00	Séminaire des sénateurs LR de la commission des Finances 
10058	04086Q	ACC_DEPL_INTER	2018-10-10 14:00:00	2018-10-10 15:00:00	Accueil de Mme Ana-Maria Marchado, vice-présidente de l'Assemblée nationale de Cuba
10110	14041T	ELUS_LOCAUX	2018-11-07 09:00:00	2018-11-07 18:00:00	déplacement à l'étranger
10111	14041T	ELUS_LOCAUX	2018-11-08 09:00:00	2018-11-08 18:00:00	déplacement à l'étranger
10112	14041T	ELUS_LOCAUX	2018-11-13 09:00:00	2018-11-13 18:00:00	déplacement à l'étranger
10113	14041T	ELUS_LOCAUX	2018-11-14 09:00:00	2018-11-14 18:00:00	déplacement à l'étranger
10114	14041T	ELUS_LOCAUX	2018-11-15 09:00:00	2018-11-15 18:00:00	déplacement à l'étranger
10115	14041T	ELUS_LOCAUX	2018-11-01 09:00:00	2018-11-01 18:00:00	déplacement à l'étranger
10117	04043D	ORG_POL	2018-10-16 10:30:00	2018-10-16 12:30:00	Réunion du Groupe "Les Républicains"
10150	04042C	ELUS_LOCAUX	2018-10-22 13:00:00	2018-10-22 14:00:00	Déjeuner de travail avec des élus locaux
10151	08010L	ORG_POL	2018-10-23 11:00:00	2018-10-23 12:30:00	Groupe LR du Sénat
10152	04043D	DEPL_PRES_GVT	2018-10-22 00:00:00	2018-10-22 00:00:00	 visite du Salon international de l'alimentation avec la délégation de la Commission des affaires économiques
10153	04043D	ORG_POL	2018-10-23 11:00:00	2018-10-23 12:30:00	Réunion du Groupe "Les Républicains"
10170	04086Q	CEREMONIE	2018-10-23 19:00:00	2018-10-23 21:00:00	Remise du prix Uzi Narkiss par l'association ADELMAD
10162	04043D	REU_TRAV_PARL	2018-10-24 09:30:00	2018-10-24 11:00:00	Commission des affaires économiques
10163	04043D	REU_TRAV_PARL	2018-10-25 08:30:00	2018-10-25 11:00:00	Office parlementaire d'évaluation des choix scientifiques et technologiques : examen d'une note scientifique de l'Office sur les enjeux environnementaux et sanitaires de l'huile de palme 
10164	01025N	ACC_VISIT	2018-10-09 12:00:00	2018-10-09 14:00:00	Conseil municipal Les Mesneux
10169	04086Q	ORG_POL	2018-10-23 11:00:00	2018-10-23 12:30:00	Réunion du groupe LR
10167	01025N	REU_TRAV_PARL	2018-10-24 14:00:00	2018-10-24 20:30:00	Auditions PLF 2019 Agriculture
10168	08048B	REU_TRAV_PARL	2018-10-25 00:00:00	2018-10-25 00:00:00	avec la Secrétaire d'Etat aux Anciens combattants sur le projet de loi de finances 2019 et les dispositions de la mission Anciens Combattants
9410	04086Q	ACC_DEPL_INTER	2018-06-11 15:00:00	2018-06-11 16:00:00	Accueil de Scott Ryan, président du Sénat australien
9411	04086Q	ACC_DEPL_INTER	2018-06-11 19:00:00	2018-06-11 20:00:00	Accueil aux côtés de G. Larcher d'Andry Parouby, président de la Rada (parlement ukrainien)
9412	04086Q	ORG_POL	2018-06-12 10:00:00	2018-06-12 11:00:00	Réunion du bureau du groupe LR
9413	04086Q	ORG_POL	2018-06-12 11:00:00	2018-06-12 12:00:00	Réunion du groupe LR
9414	04086Q	ELUS_LOCAUX	2018-06-12 12:30:00	2018-06-12 13:00:00	Entretien sur le Talk Orange-Figaro
9415	04086Q	ORG_POL	2018-06-12 13:30:00	2018-06-12 14:30:00	Rendez-vous délégués de circonscriptions LR
9420	14211G	CEREMONIE	2018-04-17 13:00:00	2018-04-17 14:00:00	Inauguration de la Salle René Monory
9417	04086Q	ORG_POL	2018-06-12 21:00:00	2018-06-12 23:30:00	Réunion de la commission exécutive LR 93
9419	14211G	ORG_POL	2018-04-17 11:00:00	2018-04-17 12:00:00	Groupe Les Républicains
9421	14211G	ELUS_LOCAUX	2018-04-18 16:00:00	2018-04-18 17:30:00	\N
9422	14211G	COLL_TER	2018-04-19 11:30:00	2018-04-19 12:30:00	Inauguration Siège Agglo Pays de l'Or
9423	14211G	CEREMONIE	2018-04-19 18:30:00	2018-04-19 20:00:00	70 ans de l'Etat d'Israël à Montpellier
9424	14211G	ELUS_LOCAUX	2018-04-24 10:00:00	2018-04-24 17:00:00	Rencontres dans les villages
9425	14211G	CEREMONIE	2018-04-25 18:00:00	2018-04-25 19:00:00	Inauguration Centre de Valorisation de Saint-Aunès
9426	14211G	ELUS_LOCAUX	2018-04-26 12:00:00	2018-04-26 14:00:00	Déjeuner avec un Maire
9427	14211G	COLL_TER	2018-04-26 18:00:00	2018-04-26 20:00:00	Conseil de Métropole
9428	14211G	ELUS_LOCAUX	2018-05-02 12:00:00	2018-05-02 14:00:00	\N
9429	14211G	CEREMONIE	2018-05-08 09:30:00	2018-05-08 13:00:00	Cérémonies du 8 mai à Montpellier et à Castelnau-le-Lez
9430	14211G	ORG_POL	2018-05-15 11:00:00	2018-05-15 12:00:00	Groupe Les Républicains
9435	14211G	ORG_POL	2018-05-29 11:00:00	2018-05-29 12:00:00	Groupe Les Républicains
9432	14211G	COLL_TER	2018-05-17 19:00:00	2018-05-17 20:30:00	Inauguration à Poilhes
9433	14211G	ELUS_LOCAUX	2018-05-17 12:00:00	2018-05-17 14:00:00	\N
9434	14211G	ORG_POL	2018-05-22 11:00:00	2018-05-22 12:00:00	Groupe Les Républicains
9530	04042C	DEPL_PRES_GVT	2018-06-25 16:00:00	2018-06-25 00:00:00	Visite au Saint-Siège avec le Président de la République
9531	04042C	DEPL_PRES_GVT	2018-06-26 00:00:00	2018-06-26 22:15:00	Visite du Saint-Siège avec le Président de la République
9532	08010L	ORG_POL	2018-06-26 11:00:00	2018-06-26 12:30:00	Groupe LR du sénat
9662	14211G	ORG_POL	2018-07-03 11:00:00	2018-07-03 12:00:00	Groupe Les Républicains
9534	08010L	ACC_DEPL_INTER	2018-06-26 09:30:00	2018-06-26 10:45:00	Ambassadeur de France au Botswana
9661	14211G	ORG_POL	2018-06-26 11:00:00	2018-06-26 12:00:00	Groupe Les Républicains
9672	14211G	ELUS_LOCAUX	2018-07-12 13:00:00	2018-07-12 14:30:00	\N
9664	14211G	ELUS_LOCAUX	2018-06-27 08:30:00	2018-06-27 09:30:00	\N
9665	14211G	ELUS_LOCAUX	2018-06-27 20:30:00	2018-06-27 21:30:00	\N
9666	14211G	CEREMONIE	2018-06-28 11:00:00	2018-06-28 12:30:00	Inauguration Castel Viel de Dio et Valquières
9667	14211G	CEREMONIE	2018-06-28 18:30:00	2018-06-28 20:00:00	Inauguration Arènes Lunel-Viel
9668	14211G	REU_TRAV_PARL	2018-07-04 08:30:00	2018-07-04 09:30:00	Club des Ambassadeurs du MAEE
9669	14211G	CEREMONIE	2018-07-05 18:00:00	2018-07-05 19:30:00	Inauguration nouvelle Gendarmerie Servian
9670	14211G	ORG_POL	2018-07-10 11:00:00	2018-07-10 11:30:00	Groupe Les Républicains
9671	14211G	CEREMONIE	2018-07-10 11:30:00	2018-07-10 12:30:00	Remise des Mariannes d'Or
9673	04042C	ORG_POL	2018-07-10 19:00:00	2018-07-10 20:00:00	\N
9674	04042C	ACC_DEPL_INTER	2018-07-11 18:30:00	2018-07-11 19:00:00	Départ du représentant de Taipei
9679	04042C	ACC_DEPL_INTER	2018-07-12 13:00:00	2018-07-12 14:30:00	Entretien avec le Président de la Conférence des Imams
9676	04042C	REU_TRAV_PARL	2018-07-11 19:00:00	2018-07-11 21:30:00	Avec le Président du Sénat
9677	04042C	COLLOQUE	2018-07-12 12:00:00	2018-07-12 13:00:00	Comment réenchanter l'audiovisuel public à l'heure du numérique ?
9678	04042C	ACC_VISIT	2018-07-12 11:40:00	2018-07-12 12:00:00	Interview sur le rapport d'information sur les négociations en vue du retrait du Royaume-Uni de l'Union européenne
9680	04042C	ACC_DEPL_INTER	2018-07-12 19:00:00	2018-07-12 20:00:00	Départ de l'Ambassadeur de Suisse
9681	04042C	COLL_TER	2018-07-13 08:45:00	2018-07-13 10:45:00	Réunion du bureau du Syndicat des Eaux d'Ile-de-France
9682	04042C	CEREMONIE	2018-07-13 00:00:00	2018-07-13 00:00:00	Cérémonie de la Traditionnelle prise d'armes par la légion étrangère présidée par le Président du Sénat 
9683	04042C	CEREMONIE	2018-07-13 11:00:00	2018-07-13 13:00:00	Cérémonie de la Traditionnelle prise d'armes par la légion étrangère présidée par le Président du Sénat 
9684	04042C	CEREMONIE	2018-07-13 18:00:00	2018-07-13 19:30:00	En l'honneur des unités participant aux cérémonies de la Fête nationale en présence du Président de la République au Ministère des armées
9716	08048B	ORG_POL	2018-07-03 11:00:00	2018-07-03 12:00:00	Groupe LR du Sénat
9717	08048B	ORG_POL	2018-06-19 11:00:00	2018-06-19 12:00:00	Réunion hebdomadaire du Groupe LR du Sénat
9743	01024M	REU_GVT	2018-07-25 15:00:00	2018-07-25 16:00:00	Entretien avec la Garde des Sceaux
10033	08010L	REU_TRAV_PARL	2018-10-09 17:30:00	2018-10-09 21:00:00	séminaire Budgétaire
10171	04086Q	COLL_TER	2018-10-25 09:00:00	2018-10-25 10:30:00	Réunion de travail avec le conseiller du Maire de Paris pour la MGP
10172	04086Q	ACC_DEPL_INTER	2018-10-25 11:00:00	2018-10-25 12:30:00	Accueil d'une délégation Libyenne en remplacement de G. Larcher
10173	04086Q	REU_TRAV_PARL	2018-10-25 16:00:00	2018-10-25 18:00:00	Réunion de travail pour le PLF 2019
10174	04086Q	ACC_DEPL_INTER	2018-10-26 11:00:00	2018-10-26 12:30:00	Accueil du Vice-Premier Minsitre Vietnamien Trinh Dinh Dung
10181	08010L	CEREMONIE	2018-10-30 10:15:00	2018-10-30 11:00:00	Ambassade des Etats-Unis
10182	08010L	ORG_POL	2018-10-30 11:00:00	2018-10-30 12:30:00	Groupe LR du sénat
10183	08010L	ACC_VISIT	2018-10-30 15:00:00	2018-10-30 16:45:00	Congressman Orrin Hatch
10184	04042C	ACC_VISIT	2018-10-24 18:30:00	2018-10-24 19:30:00	Entretien avec le Président de l'AFD
10185	04042C	ACC_DEPL_INTER	2018-10-24 19:30:00	2018-10-24 21:30:00	Réception Nanaval Group
10186	04042C	COLL_TER	2018-10-29 15:00:00	2018-10-29 17:30:00	Réunion  du bureau de la Métropole du Grand Paris
10187	04042C	ACC_DEPL_INTER	2018-10-29 18:30:00	2018-10-29 20:30:00	Réception à l'occasion du 95ème anniversaire de la proclamation de la République de Turquie
10188	04042C	ORG_POL	2018-10-30 11:00:00	2018-10-30 12:30:00	\N
10189	04042C	ACC_DEPL_INTER	2018-10-30 20:00:00	2018-10-30 21:00:00	Réception à l'occasion de la Fête de l'armée roumaine
10190	04042C	REU_TRAV_PARL	2018-10-31 08:00:00	2018-10-31 09:00:00	Réunion des Présidents de Commission
10215	04043D	COLL_TER	2018-10-30 00:00:00	2018-10-30 00:00:00	inauguration de l'exposition « L' Armistice, 11 novembre 1918 : un document, une histoire »
10221	14211G	DEPL_PRES_GVT	2018-11-06 09:45:00	2018-11-06 12:00:00	Jean-Baptiste LEMOYNE au Congrès de la Fédération de l¿Hôtellerie de Plein Air
10222	14211G	CEREMONIE	2018-11-07 17:00:00	2018-11-07 18:00:00	Gendarmerie - Sainte Geneviève à Montpellier
10229	04042C	ORG_POL	2018-11-06 11:00:00	2018-11-06 12:30:00	\N
10225	08048B	REU_TRAV_PARL	2018-11-08 00:00:00	2018-11-08 00:00:00	Audition budgétaire pour la mission  Anciens combattants: Direction du Service national et de la jeunesse
10227	08010L	DEPL_PRES_GVT	2018-11-07 15:00:00	2018-11-07 23:30:00	visite et cérémonies présidentielles dans l'Aisne
10228	04042C	REU_TRAV_PARL	2018-11-06 10:00:00	2018-11-06 11:00:00	Réunion de direction
11108	08009T	DEPL_PRES_GVT	2019-03-14 00:01:00	2019-03-14 23:59:00	\N
10230	04042C	ACC_DEPL_INTER	2018-11-06 13:00:00	2018-11-06 15:00:00	Déjeuner de travail avec l'Ambassadeur de slovénie et des Ambassadeurs
10231	04042C	REU_TRAV_PARL	2018-11-06 16:00:00	2018-11-06 19:00:00	Réunion de l'AP-OTAN Sénat-Assemblée nationale
10232	04042C	REU_TRAV_PARL	2018-11-07 08:30:00	2018-11-07 09:30:00	Réunion du bureau de la Commission des Affaires étrangères, de la Défense et des Forces armées
10233	04042C	ACC_DEPL_INTER	2018-11-07 12:00:00	2018-11-07 14:00:00	Entretien avec la Président Gérard Larcher et le Président du Sénat de Côte d'Ivoire
10234	04042C	ACC_DEPL_INTER	2018-11-07 15:30:00	2018-11-07 16:30:00	Entretien avec l'Ambassadeur de Chypre
10235	04042C	ACC_VISIT	2018-11-07 16:45:00	2018-11-07 17:45:00	Réunion avec un élu
10236	04042C	CEREMONIE	2018-11-07 19:00:00	2018-11-07 20:00:00	Remise d'une Légion d'Honneur
10237	04042C	REU_TRAV_PARL	2018-11-07 20:00:00	2018-11-07 20:30:00	Conférence des Présidents
10238	04043D	ACC_VISIT	2018-11-07 14:00:00	2018-11-07 16:00:00	Visite du Sénat du Conseil Municipal des Jeunes de Périgny-sur-Yerres
10523	04043D	CEREMONIE	2019-01-09 19:45:00	2019-01-09 22:00:00	voeux de Maison-Alfort
10524	04043D	CEREMONIE	2019-01-08 16:30:00	2019-01-08 17:30:00	Voeux Service Historique de la Défense à Vincennes
10602	04042C	REU_TRAV_PARL	2018-12-18 13:00:00	2018-12-18 14:30:00	Rencontres des Présidents des commission du Sénat avec le Président du Sénat
10603	04042C	REU_TRAV_PARL	2018-12-18 18:00:00	2018-12-18 19:00:00	Rencontre avec le Président de la Commission des affaires européennes
10604	04042C	ORG_POL	2018-12-18 19:30:00	2018-12-18 21:30:00	\N
10605	04042C	ACC_DEPL_INTER	2018-12-19 08:00:00	2018-12-19 08:30:00	Entretien avec un ancien ambassadeur
10609	04042C	COLL_TER	2018-12-20 10:30:00	2018-12-20 13:30:00	Réunion du Comité du SEDIF
10607	04042C	REU_TRAV_PARL	2018-12-19 13:00:00	2018-12-19 14:30:00	Réunion avec les sénateurs de la Commission des Affaires étrangères, de la Défense et des Forces armées
10608	04042C	ELUS_LOCAUX	2018-12-19 20:30:00	2018-12-19 22:00:00	Conseil municipal de Saint-Maurice
10770	04086Q	ACC_DEPL_INTER	2019-01-29 12:00:00	2019-01-29 14:00:00	Déjeuner en l'honneur de la délégation du parlement du Québec
10611	04042C	REU_GVT	2018-12-20 15:30:00	2018-12-20 16:30:00	ontre avec le Ministre auprès du Premier ministre, chargé des Relations avec le Parlement
10612	04042C	COLL_TER	2018-12-20 17:30:00	2018-12-20 18:30:00	Entretien avec la Présidente de la Région d'Ile-de-France
10614	04042C	CEREMONIE	2019-01-07 18:30:00	2019-01-07 20:30:00	Cérémonie des Voeux de Charenton-le-Pont
10762	08010L	REU_TRAV_PARL	2019-01-30 09:00:00	2019-01-30 10:00:00	Unesco 
10767	04086Q	ACC_DEPL_INTER	2019-01-23 19:00:00	2019-01-23 22:00:00	Diner officiel pour la visite du Président d'Israël Reuven Rivlin 
10769	04086Q	ACC_DEPL_INTER	2019-01-29 09:30:00	2019-01-29 10:30:00	Audience à la présidence du Sénat de F. Paradis, président du parlement du Québec
10931	08009T	ORG_POL	2019-02-05 11:00:00	2019-02-05 12:30:00	\N
10904	08048B	REU_TRAV_PARL	2019-02-05 19:30:00	2019-02-05 20:30:00	Cités millénaires à l'Institut du Monde arabe
10906	08009T	REU_TRAV_PARL	2019-01-08 11:30:00	2019-01-08 12:30:00	\N
10932	08009T	REU_GVT	2019-02-05 13:00:00	2019-02-05 14:30:00	\N
10933	08009T	REU_TRAV_PARL	2019-02-06 11:30:00	2019-02-06 12:30:00	\N
10934	08009T	REU_TRAV_PARL	2019-02-12 10:00:00	2019-02-12 10:30:00	\N
10940	08009T	REU_TRAV_PARL	2019-02-12 18:00:00	2019-02-12 19:00:00	\N
10936	08009T	ELUS_LOCAUX	2019-02-12 12:30:00	2019-02-12 14:30:00	\N
10937	08009T	COLL_TER	2019-02-12 16:00:00	2019-02-12 17:00:00	\N
10938	08009T	ORG_POL	2019-02-12 10:30:00	2019-02-12 12:30:00	\N
10939	08009T	REU_TRAV_PARL	2019-02-12 17:00:00	2019-02-12 18:00:00	\N
10941	08009T	REU_TRAV_PARL	2019-02-13 14:30:00	2019-02-13 16:00:00	\N
10942	08009T	REU_GVT	2019-02-14 09:00:00	2019-02-14 11:00:00	\N
10943	08009T	REU_TRAV_PARL	2019-02-14 11:15:00	2019-02-14 12:15:00	\N
11003	08010L	ORG_POL	2019-03-05 11:00:00	2019-03-05 12:30:00	Groupe LR du sénat
11081	14211G	REU_GVT	2019-01-16 17:30:00	2019-01-16 18:30:00	\N
11092	14211G	CEREMONIE	2019-01-24 18:30:00	2019-01-24 19:30:00	Voeux de la Communauté de Communes du Clermontais
11083	14211G	CEREMONIE	2019-01-10 19:30:00	2019-01-10 20:30:00	Remise des insignes d'Officier de la Légion d'Honneur à Monique ROUX 
11091	14211G	CEREMONIE	2019-01-17 19:30:00	2019-01-17 20:30:00	Voeux de l'Agglomération Béziers Méditerranée
11088	14211G	CEREMONIE	2019-01-03 18:30:00	2019-01-03 19:30:00	Voeux Poussan
11086	14211G	CEREMONIE	2019-01-08 19:00:00	2019-01-08 20:00:00	Voeux Pignan
11087	14211G	CEREMONIE	2019-01-08 11:00:00	2019-01-08 12:30:00	Remise des insignes de Chevalier de la Légion d'Honneur à Guylaine LANG CHEYMOL
11089	14211G	CEREMONIE	2019-01-09 18:30:00	2019-01-09 19:30:00	Voeux Saint Nazaire de Pézan
11090	14211G	CEREMONIE	2019-01-10 18:30:00	2019-01-10 19:30:00	Voeux Castelnau-le-Lez
11101	08010L	ORG_POL	2019-03-12 11:00:00	2019-03-12 12:00:00	Groupe LR du sénat
11102	08010L	ACC_VISIT	2019-03-12 12:00:00	2019-03-12 13:00:00	\N
11341	08048B	REU_TRAV_PARL	2019-03-27 15:00:00	2019-03-27 16:00:00	rdv avec Krys Group sur les enjeux de l'accès aux soins visuels et auditifs
11356	14211G	ACC_VISIT	2019-04-03 11:30:00	2019-04-03 12:30:00	CMJ de la commune de SAUSSINES
11345	08048B	COLL_TER	2019-04-04 10:30:00	2019-04-04 11:30:00	Audition pour une mission de l'IGA, de l'IGPN et de l'IGGN sur le fonctionnement de la Préfecture de police des Bouches-du-Rhône, la mise en oeuvre de la politique de sécurité intérieure et la dualité de représentation de l'Etat
11352	01025N	REU_TRAV_PARL	2019-03-27 14:00:00	2019-03-27 14:30:00	Entretien avec Dir. Relations Ext. et DD ORANDGINA SUNTORY
11353	01025N	REU_TRAV_PARL	2019-04-03 12:30:00	2019-04-03 14:00:00	Entretien avec CGB
11357	14211G	REU_GVT	2019-04-04 10:00:00	2019-04-04 11:00:00	\N
11358	14211G	REU_GVT	2019-04-04 14:30:00	2019-04-04 15:00:00	\N
11359	04042C	ORG_POL	2019-04-04 08:30:00	2019-04-04 09:30:00	\N
11360	04042C	REU_TRAV_PARL	2019-04-04 10:00:00	2019-04-04 12:00:00	\N
11361	04042C	ACC_VISIT	2019-04-04 13:00:00	2019-04-04 14:15:00	Entretien avec le Président de Nexter
11362	04042C	REU_TRAV_PARL	2019-04-04 14:30:00	2019-04-04 15:30:00	\N
11363	04042C	ACC_VISIT	2019-04-04 16:15:00	2019-04-04 17:15:00	Entretien avec le President de la A-NSE
11364	04042C	ACC_VISIT	2019-04-04 17:15:00	2019-04-04 18:15:00	Entretien avec une élue du Val-de-Marne
11365	04042C	ACC_DEPL_INTER	2019-04-04 19:30:00	2019-04-04 20:30:00	Inauguration de Mahdi Qotbi - Poète des signes
11366	04018C	ELUS_LOCAUX	2019-04-04 19:00:00	2019-04-04 21:00:00	\N
11367	04018C	REU_TRAV_PARL	2019-04-03 15:30:00	2019-04-03 17:30:00	\N
11368	04018C	REU_TRAV_PARL	2019-04-09 11:00:00	2019-04-09 12:30:00	\N
11369	04018C	REU_TRAV_PARL	2019-04-02 11:00:00	2019-04-02 12:30:00	\N
11372	04018C	ORGEXTPAR	2019-04-11 09:00:00	2019-04-11 12:00:00	CRPA
11374	04018C	REU_TRAV_PARL	2019-03-12 11:00:00	2019-03-12 12:30:00	\N
11373	04018C	REU_TRAV_PARL	2019-03-05 11:00:00	2019-03-05 12:20:00	\N
11375	04018C	REU_TRAV_PARL	2019-03-19 11:00:00	2019-03-19 12:30:00	\N
11421	01058X	REU_TRAV_PARL	2019-04-11 08:00:00	2019-04-11 10:00:00	avec l'administrateur général et le Haut Commissaire du CEA
11422	04086Q	REU_TRAV_PARL	2019-04-03 14:00:00	2019-04-03 15:30:00	Réunion de travail sur la taxe foncière pour les opérateurs de construction
11423	04086Q	DEPL_PRES_GVT	2019-04-04 00:00:00	2019-04-04 00:00:00	Déplacement à Doha pour l'UIP 
11424	04086Q	ACC_DEPL_INTER	2019-04-12 10:30:00	2019-04-12 11:30:00	Accueil à la présidence du Vice-premier ministre du Qatar, Son Excellence Sheikh Mohammed bin Abdulrahman bin Jassim Al Thani
11442	04043D	COLL_TER	2019-04-17 12:45:00	2019-04-17 16:30:00	Visite du centre de l'IRSN de Fontenay-aux-Roses
11445	04086Q	REU_TRAV_PARL	2019-04-12 15:30:00	2019-04-12 19:00:00	Rendez-vous de travail pour ses activités parlementaires 
11524	14133K	DEPL_PRES_GVT	2019-04-26 09:30:00	2019-04-26 22:00:00	déplacement au Pakistan du groupe d'amitié France-Pakistan du Sénat
11525	14133K	DEPL_PRES_GVT	2019-04-25 09:30:00	2019-04-25 22:00:00	déplacement au Pakistan du groupe d'amitié France-Pakistan du Sénat
11526	14133K	DEPL_PRES_GVT	2019-04-24 09:30:00	2019-04-24 22:00:00	déplacement au Pakistan du groupe d'amitié France-Pakistan du Sénat
11527	04042C	ACC_VISIT	2019-05-06 12:30:00	2019-05-06 14:30:00	Reunions des Premiers adjoints de Saint-Maurice
11528	04042C	ACC_DEPL_INTER	2019-05-06 20:00:00	2019-05-06 21:30:00	Rencontre avec le Chef d'état-major des armées
11529	04042C	REU_TRAV_PARL	2019-05-07 10:00:00	2019-05-07 11:00:00	Réunion de direction
11530	04042C	ORG_POL	2019-05-07 11:00:00	2019-05-07 12:00:00	\N
11531	04042C	ACC_VISIT	2019-05-07 12:00:00	2019-05-07 12:30:00	Entretien avec un élu
11532	04042C	ACC_VISIT	2019-05-07 12:30:00	2019-05-07 14:00:00	Rencontre avec un Maire du Val-de-Marne
11533	04042C	ACC_DEPL_INTER	2019-05-07 15:30:00	2019-05-07 16:30:00	Entretien avec le Ministre des Affaires étrangères de Chypre et d'une délégation chypriote
11534	04042C	ACC_DEPL_INTER	2019-05-07 18:00:00	2019-05-07 18:45:00	Réception à l'occasion de la Fête nationale à l'Ambassade de Pologne
11544	19766L	DEPL_PRES_GVT	2019-04-30 08:00:00	2019-04-30 20:00:00	Déplacemennt Hong-Kong
11541	08010L	ORG_POL	2019-05-07 11:00:00	2019-05-07 13:00:00	Groupe LR du sénat
11542	04042C	CEREMONIE	2019-05-08 10:30:00	2019-05-08 13:30:00	Cérémonie du 8 mai 1945 à Saint-Maurice
11543	19766L	DEPL_PRES_GVT	2019-05-01 08:00:00	2019-05-01 20:00:00	Déplacement HONG-KONG
11545	19766L	DEPL_PRES_GVT	2019-05-02 08:00:00	2019-05-02 20:00:00	Déplacement Hong-Kong
11546	19766L	DEPL_PRES_GVT	2019-05-03 08:00:00	2019-05-03 20:00:00	Déplacement Hong-Kong
11547	19766L	DEPL_PRES_GVT	2019-05-06 08:00:00	2019-05-06 20:00:00	Déplacement Pékin
11548	19766L	DEPL_PRES_GVT	2019-05-07 08:00:00	2019-05-07 20:00:00	Déplacement Pékin
11549	19766L	DEPL_PRES_GVT	2019-05-08 08:00:00	2019-05-08 20:00:00	Déplacement à Oulan Bator
11550	19766L	DEPL_PRES_GVT	2019-04-12 08:00:00	2019-04-12 20:00:00	Déplacement Tunisie
10744	04018C	ELUS_LOCAUX	2019-01-16 19:00:00	2019-01-16 21:00:00	Cérémonie voeux
10745	04018C	ELUS_LOCAUX	2019-01-17 19:00:00	2019-01-17 21:00:00	Cérémonie voeux
10746	04018C	ELUS_LOCAUX	2019-01-23 18:30:00	2019-01-23 20:30:00	céremonie voeux
10747	04018C	CEREMONIE	2019-01-24 17:30:00	2019-01-24 19:30:00	\N
10748	04018C	ELUS_LOCAUX	2019-01-30 18:00:00	2019-01-30 20:00:00	Cérémonie voeux
10749	04018C	ELUS_LOCAUX	2019-01-31 19:00:00	2019-01-31 21:00:00	Cérémonie voeux
10750	04018C	ORG_POL	2019-02-06 19:00:00	2019-02-06 21:00:00	\N
10751	04018C	ELUS_LOCAUX	2019-02-07 19:00:00	2019-02-07 21:00:00	\N
10783	08010L	REU_TRAV_PARL	2019-01-31 13:30:00	2019-01-31 14:30:00	collectivités territoriales et ruralités
10824	04042C	REU_TRAV_PARL	2019-02-05 11:00:00	2019-02-05 12:00:00	Audition avec rapporteur de la Défense européenne
10803	04086Q	DEL_ACT_PAR	2019-02-05 21:30:00	2019-02-05 23:30:00	Présence en séance de l'AN pour assister à la présentation du rapport CEC sur la Seine-Saint-Denis
10823	04042C	REU_TRAV_PARL	2019-02-05 10:00:00	2019-02-05 11:00:00	Réunion de direction
10825	04042C	COLL_TER	2019-02-05 13:00:00	2019-02-05 14:15:00	Rencontre avec OTV Veolia Water technologies 
10826	04042C	ACC_DEPL_INTER	2019-02-05 15:30:00	2019-02-05 16:30:00	Entretien avec l'Ambassadrice de Macédoine 
10827	04042C	ACC_VISIT	2019-02-05 18:00:00	2019-02-05 19:00:00	Rendez-vous avec un élu
10828	04042C	DEPL_PRES_GVT	2019-02-06 14:15:00	2019-02-06 17:30:00	Visite SAFRAN avec Madame la Ministre des armées
10829	04042C	COLLOQUE	2019-02-06 18:00:00	2019-02-06 19:00:00	Conférence au secours des femmes yézidies et des minorités déplacées au Kurdistan
10830	04042C	COLL_TER	2019-02-06 19:30:00	2019-02-06 21:00:00	Cérémonie des Voeux de Madame Valérie PECRESSE
10831	04042C	ACC_VISIT	2019-02-07 13:00:00	2019-02-07 14:15:00	Rencontre avec un député du Val-de-Marne
10832	04042C	ACC_VISIT	2019-02-07 15:00:00	2019-02-07 16:00:00	Rencontre avec un ancien sénateur
10833	04042C	REU_TRAV_PARL	2019-02-07 16:00:00	2019-02-07 17:00:00	Réunion de travail OP/OTAN
10834	04042C	COLL_TER	2019-02-08 09:00:00	2019-02-08 12:00:00	Seance du Conseil de la Métropole
10835	04042C	ACC_DEPL_INTER	2019-02-08 13:00:00	2019-02-08 14:00:00	Rencontre avec L'ambassadrice d'Italie en France
10836	04042C	ACC_VISIT	2019-02-08 15:00:00	2019-02-08 16:00:00	RDV avec un élu
10866	04086Q	ORG_POL	2019-02-12 11:00:00	2019-02-12 12:30:00	Réunion du groupe LR
10861	01025N	ELUS_LOCAUX	2019-02-13 08:00:00	2019-02-13 09:30:00	Mobilités - J.Rottner Président Région Grand Est
10862	01025N	REU_TRAV_PARL	2019-02-13 14:30:00	2019-02-13 16:00:00	PJL Mobilités
10867	04086Q	REU_TRAV_PARL	2019-02-13 08:30:00	2019-02-13 09:00:00	Réunion Vice-présidence 
10868	04086Q	CEREMONIE	2019-02-13 18:30:00	2019-02-13 19:30:00	Cérémonie de remise de décoration
10869	04086Q	COLL_TER	2019-02-14 17:30:00	2019-02-14 19:00:00	Conseil d'administration ADIL
10870	04086Q	COLL_TER	2019-02-15 14:00:00	2019-02-15 19:00:00	Réunion Seine-Saint-Denis
10872	04086Q	COLL_TER	2019-02-08 09:00:00	2019-02-08 19:00:00	Réunion Seine-Saint-Denis
10874	04086Q	ORG_POL	2019-02-19 11:00:00	2019-02-19 12:30:00	Réunion du groupe LR
10875	04086Q	DEL_ACT_PAR	2019-02-19 18:30:00	2019-02-19 20:00:00	Manifestation contre l'antisémitisme
10877	04042C	REU_TRAV_PARL	2019-02-20 08:30:00	2019-02-20 09:30:00	Réunion du bureau de la Commission des Affaires étrangères de la défense et des Forces armées
10878	04042C	ACC_DEPL_INTER	2019-02-20 13:00:00	2019-02-20 14:30:00	Réception avec Monsieur l'Ambassadeur de Turquie
10879	04042C	ACC_DEPL_INTER	2019-02-20 15:00:00	2019-02-20 16:00:00	Entretien avec l'Ambassadeur du Mexique en France
10880	04042C	REU_TRAV_PARL	2019-02-20 16:30:00	2019-02-20 17:30:00	Réunion de Direction
10881	04042C	REU_TRAV_PARL	2019-02-20 19:30:00	2019-02-20 20:30:00	Conférence des Présidents du Sénat
10882	04042C	ELUS_LOCAUX	2019-02-20 21:00:00	2019-02-20 22:30:00	Conseil Municipal de Saint-Maurice
10883	04043D	ORG_POL	2019-02-19 11:00:00	2019-02-19 12:30:00	Réunion du Groupe Les Républicains
10884	04042C	ACC_DEPL_INTER	2019-02-21 12:30:00	2019-02-21 13:00:00	Réception à l'Ambassade d'Estonie à l'occasion du 101ème anniversaire de la Répubique d'Estonie
10885	04042C	COLL_TER	2019-02-21 13:15:00	2019-02-21 14:30:00	Rencontre avec André Santini autour de son livre Maire Célibataire
10887	04042C	ELUS_LOCAUX	2019-02-21 20:00:00	2019-02-21 22:00:00	Rencontre avec les élus du Conseil municipal de Saint-Mandé
10961	04043D	CEREMONIE	2019-02-22 15:30:00	2019-02-22 17:00:00	inauguration de l'école Mireille DARC-Limeil-Brévannes
11107	08009T	DEPL_PRES_GVT	2019-03-13 00:01:00	2019-03-13 23:59:00	\N
11109	08009T	ORG_POL	2019-03-05 11:00:00	2019-03-05 12:30:00	\N
11110	08009T	REU_TRAV_PARL	2019-03-05 14:30:00	2019-03-05 15:30:00	\N
11111	08009T	REU_TRAV_PARL	2019-03-05 15:30:00	2019-03-05 17:00:00	\N
11112	08009T	ELUS_LOCAUX	2019-03-06 12:30:00	2019-03-06 14:30:00	\N
11166	04086Q	REU_TRAV_PARL	2019-03-13 14:00:00	2019-03-13 15:00:00	Réunion de travail pour le prochain bureau du Sénat 
11167	04086Q	ELUS_LOCAUX	2019-03-15 08:30:00	2019-03-15 10:00:00	Réunion en préfecture pour la rentrée 2019-2020
11168	04086Q	REU_TRAV_PARL	2019-03-15 10:00:00	2019-03-15 11:30:00	Réunion en préfecture pour la mise en place de groupes de travail pour la Seine-Saint-Denis sur les sujets : Santé, justice, éducation, sécurité et attractivité des postes pour les agents publics. 
11169	04086Q	COLL_TER	2019-03-15 14:00:00	2019-03-15 16:30:00	Réunion Seine-Saint-Denis
11170	04086Q	ACC_DEPL_INTER	2019-03-19 12:30:00	2019-03-19 14:30:00	Accueil aux côtés de G. LARCHER du président du Bundesrat Daniel Gunther  
11385	04042C	ACC_VISIT	2019-04-08 11:00:00	2019-04-08 11:45:00	Rendez-Vous avec un administré du Val-de-Marne à la Mairie de Saint-Maurice
11386	04042C	CEREMONIE	2019-04-08 12:00:00	2019-04-08 12:00:00	Cérémonie en hommage à deux employés de la Mairie de Saint-Maurice 
11387	04042C	CEREMONIE	2019-04-08 16:30:00	2019-04-08 17:30:00	Hommage national du Médecin des Armées Marc LAYCURAS aux Invalides
11388	04042C	ORG_POL	2019-04-08 19:30:00	2019-04-08 21:00:00	Réunion des Républicains à Joinville-le-Pont
11461	04042C	ACC_VISIT	2019-04-19 10:00:00	2019-04-19 11:30:00	Visite guidée des Cm2 de Saint-Maurice
11462	04042C	REU_GVT	2019-04-19 15:00:00	2019-04-19 16:00:00	Entretien avec Madame la Secrétaire d'Etat aux Affaires européennes
11551	19766L	DEPL_PRES_GVT	2019-04-15 08:00:00	2019-04-15 20:00:00	Déplacement Tunisie
11552	19766L	DEPL_PRES_GVT	2019-04-16 08:00:00	2019-04-16 20:00:00	Déplacement Tunisie
11553	19766L	DEPL_PRES_GVT	2019-04-22 08:00:00	2019-04-22 20:00:00	Déplacement Egypte
11554	19766L	DEPL_PRES_GVT	2019-04-23 08:00:00	2019-04-23 20:00:00	Déplacement Egypte
11590	08009T	REU_TRAV_PARL	2019-03-19 08:30:00	2019-03-19 09:30:00	\N
11563	04018C	ACC_DEPL_INTER	2019-05-14 17:00:00	2019-05-14 18:00:00	Mgr Joseph Absi
11581	04086Q	COLL_TER	2019-04-29 10:30:00	2019-04-29 12:30:00	Accueil du nouveau préfet de Seine-Saint-Denis, Georges-François Leclerc
11582	04086Q	REU_TRAV_PARL	2019-04-30 16:00:00	2019-04-30 16:45:00	Réunion de travail groupe LR 
11591	08009T	REU_TRAV_PARL	2019-03-19 09:30:00	2019-03-19 10:00:00	\N
11592	08009T	ORG_POL	2019-03-19 11:00:00	2019-03-19 12:30:00	\N
11593	08009T	ACC_DEPL_INTER	2019-03-19 12:20:00	2019-03-19 14:30:00	\N
11594	08009T	REU_GVT	2019-03-20 08:00:00	2019-03-20 09:00:00	\N
11595	08009T	ELUS_LOCAUX	2019-03-20 12:30:00	2019-03-20 14:30:00	\N
11596	08009T	ORG_POL	2019-03-26 11:00:00	2019-03-26 12:30:00	\N
11597	08009T	ACC_DEPL_INTER	2019-03-26 15:50:00	2019-03-26 16:50:00	\N
11598	08009T	ORG_POL	2019-04-02 11:00:00	2019-04-02 12:30:00	\N
11599	08009T	REU_TRAV_PARL	2019-04-02 17:30:00	2019-04-02 18:30:00	\N
11600	08009T	REU_TRAV_PARL	2019-04-02 18:30:00	2019-04-02 19:30:00	\N
11601	08009T	REU_TRAV_PARL	2019-04-03 09:00:00	2019-04-03 10:00:00	\N
11602	08009T	ELUS_LOCAUX	2019-04-03 12:30:00	2019-04-03 14:00:00	\N
11603	08009T	REU_TRAV_PARL	2019-04-03 16:00:00	2019-04-03 16:30:00	\N
11604	08009T	REU_TRAV_PARL	2019-04-03 19:00:00	2019-04-03 20:00:00	\N
11605	08009T	REU_TRAV_PARL	2019-04-09 12:30:00	2019-04-09 14:00:00	\N
11606	08009T	COLL_TER	2019-04-09 16:00:00	2019-04-09 17:00:00	\N
11607	08009T	REU_TRAV_PARL	2019-04-09 17:00:00	2019-04-09 18:00:00	\N
11608	08009T	REU_GVT	2019-04-09 21:00:00	2019-04-09 22:30:00	\N
11609	08009T	REU_TRAV_PARL	2019-04-10 08:30:00	2019-04-10 09:30:00	\N
11610	08009T	REU_TRAV_PARL	2019-04-10 10:00:00	2019-04-10 11:00:00	\N
11611	08009T	REU_TRAV_PARL	2019-04-10 12:30:00	2019-04-10 14:00:00	\N
11612	08009T	REU_GVT	2019-04-11 09:00:00	2019-04-11 10:30:00	\N
11613	08009T	REU_GVT	2019-04-15 08:30:00	2019-04-15 09:30:00	\N
11614	08009T	REU_GVT	2019-04-23 08:30:00	2019-04-23 09:30:00	\N
11615	08009T	REU_TRAV_PARL	2019-04-30 10:30:00	2019-04-30 11:00:00	\N
11616	08009T	ORG_POL	2019-04-30 11:00:00	2019-04-30 12:30:00	\N
11617	08009T	REU_TRAV_PARL	2019-04-30 15:00:00	2019-04-30 16:00:00	\N
11618	08009T	REU_TRAV_PARL	2019-04-30 16:00:00	2019-04-30 16:30:00	\N
11619	08009T	ORG_POL	2019-04-30 20:30:00	2019-04-30 22:30:00	\N
11620	08009T	COLL_TER	2019-05-02 11:00:00	2019-05-02 12:00:00	\N
11621	08009T	REU_TRAV_PARL	2019-05-02 12:30:00	2019-05-02 14:00:00	\N
10628	04042C	DEPL_PRES_GVT	2019-01-14 00:00:00	2019-01-14 00:00:00	Déplacement en Irak et en Jordanie avec le Ministre de l'Europe et des Affaires étrangères
10641	08010L	REU_TRAV_PARL	2019-01-16 15:30:00	2019-01-16 17:00:00	Délégation territoriale/Grand Paris
10642	04042C	REU_TRAV_PARL	2019-01-16 08:00:00	2019-01-16 09:00:00	Réunion des présidents de commission
10643	04042C	ELUS_LOCAUX	2019-01-16 12:00:00	2019-01-16 13:00:00	Réception des voeux aux anciens combattants à Charenton-le-Pont
10644	04042C	CEREMONIE	2019-01-16 13:30:00	2019-01-16 14:30:00	Cérémonie des voeuxdu GICAT
10645	04042C	CEREMONIE	2019-01-16 18:00:00	2019-01-16 19:00:00	Présentation des voeux du Cercle Eugène Delacroix
10646	04042C	ELUS_LOCAUX	2019-01-16 19:30:00	2019-01-16 21:00:00	Réunion des Républicains à Saint-Maurice
10647	04042C	CEREMONIE	2019-01-17 19:30:00	2019-01-17 20:30:00	Cérémonie des Voeux à Noiseau
10648	08010L	REU_TRAV_PARL	2019-01-17 08:30:00	2019-01-17 09:30:00	Bureau Délégation Territoriale 
10660	04042C	CEREMONIE	2019-01-18 18:30:00	2019-01-18 19:30:00	Cérémonie d'Ormesson-sur-Marne
10650	04043D	ACC_VISIT	2019-01-14 10:00:00	2019-01-14 12:00:00	visite de l'Association pour le Rayonnement Economique et Culturel de l'Est Parisien
10651	04043D	CEREMONIE	2019-01-14 19:30:00	2019-01-14 22:00:00	Voeux de Thiais
10652	04043D	ORG_POL	2019-01-15 10:00:00	2019-01-15 12:30:00	Séminaire Groupe des Républicains
10659	04042C	COLL_TER	2019-01-18 08:45:00	2019-01-18 12:00:00	Réunion du bureau du SEDIF
10654	04043D	CEREMONIE	2019-01-15 18:30:00	2019-01-15 20:00:00	cérémonie des v¿ux du Préfet 2019 aux personnalités du département
10655	04043D	REU_TRAV_PARL	2019-01-17 09:00:00	2019-01-17 11:00:00	OPECST
10657	04043D	CEREMONIE	2019-01-17 16:30:00	2019-01-17 17:30:00	voeux de l'hôpital Begin
10658	04043D	REU_TRAV_PARL	2019-01-17 14:00:00	2019-01-17 15:00:00	RV avec la Directrice de l'Agence de Développement de la RATP Val-de-Marne 
10661	04042C	CEREMONIE	2019-01-18 19:30:00	2019-01-18 20:30:00	Cérémonie des Voeux de Sucy-en-Brie
10681	04043D	CEREMONIE	2019-01-17 20:00:00	2019-01-17 21:30:00	Voeux de Noiseau
10682	04043D	CEREMONIE	2019-01-18 20:00:00	2019-01-18 22:00:00	Voeux d'Ormesson
10742	04018C	ELUS_LOCAUX	2019-01-15 19:30:00	2019-01-15 21:30:00	Cérémonie voeux
10764	04086Q	REU_TRAV_PARL	2019-01-15 14:30:00	2019-01-15 16:00:00	RDV de travail commission des finances 
10761	08010L	ORG_POL	2019-01-29 11:00:00	2019-01-29 12:30:00	Groupe LR du Sénat
10763	04086Q	ORG_POL	2019-01-15 11:00:00	2019-01-15 12:00:00	Groupe LR séminaire de rentrée 
10765	04086Q	REU_TRAV_PARL	2019-01-16 14:00:00	2019-01-16 16:00:00	Réunion de travail avec le directeur des relations internationales du Sénat 
10768	04086Q	ACC_DEPL_INTER	2019-01-24 09:00:00	2019-01-24 11:00:00	Inauguration au Quai d'Orsay d'une exposition en compagnie du Président d'Israël 
10781	04043D	CEREMONIE	2019-01-25 19:30:00	2019-01-25 21:00:00	Voeux de Rungis
10821	08010L	ELUS_LOCAUX	2019-02-07 10:00:00	2019-02-07 13:00:00	Inauguration Parc Ailette 
10822	04042C	COLL_TER	2019-02-04 12:30:00	2019-02-04 14:15:00	Rencontre avec le Préfet du Val-de-Marne
10901	08048B	REU_TRAV_PARL	2019-02-20 08:30:00	2019-02-20 09:30:00	Echange avec le Président de la Fondation Charles de Gaulle
10905	08048B	REU_TRAV_PARL	2019-01-31 08:30:00	2019-01-31 09:30:00	Réunion sur la situation de la psychiatrie en France
10903	08048B	CEREMONIE	2019-02-19 19:00:00	2019-02-19 20:30:00	Grand Rassemblement contre l'antisémitisme Place de la République à Paris
10907	08048B	ORG_POL	2019-02-20 15:30:00	2019-02-20 16:30:00	\N
10908	08009T	REU_TRAV_PARL	2019-01-09 10:00:00	2019-01-09 11:00:00	\N
10909	08009T	REU_TRAV_PARL	2019-01-09 11:00:00	2019-01-09 12:00:00	\N
10910	08009T	REU_TRAV_PARL	2019-01-09 13:00:00	2019-01-09 14:30:00	\N
10911	08009T	REU_TRAV_PARL	2019-01-15 08:00:00	2019-01-15 09:00:00	\N
10912	08009T	REU_TRAV_PARL	2019-01-15 09:00:00	2019-01-15 10:00:00	\N
10913	08009T	ORG_POL	2019-01-15 11:00:00	2019-01-15 12:30:00	\N
10914	08009T	DEPL_PRES_GVT	2019-01-15 15:00:00	2019-01-15 17:30:00	\N
10915	08009T	REU_TRAV_PARL	2019-01-16 08:30:00	2019-01-16 09:30:00	\N
10916	08009T	REU_TRAV_PARL	2019-01-16 12:30:00	2019-01-16 14:30:00	\N
10917	08009T	REU_TRAV_PARL	2019-01-16 14:30:00	2019-01-16 15:30:00	\N
10918	08009T	REU_TRAV_PARL	2019-01-16 16:30:00	2019-01-16 17:30:00	\N
10919	08009T	ORG_POL	2019-01-22 11:00:00	2019-01-22 12:30:00	\N
10920	08009T	COLL_TER	2019-01-22 14:30:00	2019-01-22 16:30:00	\N
10921	08009T	CEREMONIE	2019-01-22 19:00:00	2019-01-22 20:00:00	\N
10922	08009T	REU_TRAV_PARL	2019-01-23 08:30:00	2019-01-23 09:30:00	\N
10923	08009T	REU_TRAV_PARL	2019-01-23 16:00:00	2019-01-23 17:00:00	\N
10924	08009T	REU_TRAV_PARL	2019-01-23 17:00:00	2019-01-23 18:00:00	\N
10925	08009T	REU_GVT	2019-01-24 10:30:00	2019-01-24 12:00:00	\N
10926	08009T	REU_TRAV_PARL	2019-01-29 09:00:00	2019-01-29 10:00:00	\N
10927	08009T	REU_GVT	2019-01-29 14:00:00	2019-01-29 16:00:00	\N
10928	08009T	REU_TRAV_PARL	2019-01-29 18:30:00	2019-01-29 19:30:00	\N
10929	08009T	REU_TRAV_PARL	2019-01-30 09:00:00	2019-01-30 10:00:00	\N
10930	08009T	REU_GVT	2019-01-30 14:30:00	2019-01-30 15:30:00	\N
11041	08048B	REU_TRAV_PARL	2019-03-06 00:00:00	2019-03-06 00:00:00	Interview sur la Matinale de Public Sénat sur le logement indigne
11106	08009T	DEPL_PRES_GVT	2019-03-12 00:01:00	2019-03-12 23:59:00	\N
11104	08010L	REU_TRAV_PARL	2019-03-13 12:00:00	2019-03-13 13:00:00	IGP
11105	08010L	REU_TRAV_PARL	2019-03-13 13:30:00	2019-03-13 14:30:00	Betteraves/PAC
11113	08009T	REU_TRAV_PARL	2019-03-07 10:00:00	2019-03-07 11:30:00	\N
11114	08009T	ELUS_LOCAUX	2019-03-07 12:30:00	2019-03-07 13:30:00	\N
11180	04042C	ELUS_LOCAUX	2019-03-22 09:30:00	2019-03-22 10:30:00	Rencontre avec des élus du Val-de-Marne à la Mairie de Maisons-Alfort
11181	04042C	REU_TRAV_PARL	2019-03-21 16:15:00	2019-03-21 17:15:00	\N
11202	04043D	ORG_POL	2019-03-14 20:00:00	2019-03-14 22:00:00	Soirée des Têtes de liste des européennes
11203	04043D	CEREMONIE	2019-03-15 11:30:00	2019-03-15 13:00:00	visite du Centre de commandement unifié du RER A
11204	04043D	CEREMONIE	2019-03-18 08:00:00	2019-03-18 12:00:00	Présentation du Campus spatial de l'UPEC
11205	04043D	REU_TRAV_PARL	2019-03-19 11:00:00	2019-03-19 12:00:00	réunion de groupe
11221	04042C	ACC_VISIT	2019-03-25 08:40:00	2019-03-25 08:50:00	Interview sur l'actualité par Public Sénat
11222	04042C	ACC_VISIT	2019-03-25 13:00:00	2019-03-25 14:15:00	Entretien pour un projet du Val-de-Marne
11223	04042C	ACC_DEPL_INTER	2019-03-25 18:30:00	2019-03-25 19:15:00	Réception à l'occasion de la Fête nationale du Pakistan
11224	04042C	ACC_DEPL_INTER	2019-03-25 20:00:00	2019-03-25 23:00:00	Dîner d'Etat à l'invitation du Président de la République pour la venue du Président de la République Populaire de Chine
11228	04042C	ACC_VISIT	2019-03-26 13:00:00	2019-03-26 14:15:00	Entretien avec une journaliste des Echos
11226	04042C	ORG_POL	2019-03-26 10:00:00	2019-03-26 11:00:00	Réunion du Bureau du Groupe Les Républicains
11227	04042C	ORG_POL	2019-03-26 11:00:00	2019-03-26 12:30:00	Réunion du Groupe Les Républicains
11229	04042C	REU_TRAV_PARL	2019-03-26 14:45:00	2019-03-26 15:30:00	Réunion de Direction
11230	04042C	ACC_DEPL_INTER	2019-03-26 15:30:00	2019-03-26 16:30:00	Entretien avec le Président du Sénat et le Président de la République Populaire de Chine
11231	04042C	ORG_POL	2019-03-26 19:00:00	2019-03-26 21:30:00	Réunion avec les candidats aux élections européeennes des Républicains
11381	04043D	ELUS_LOCAUX	2019-04-01 18:00:00	2019-04-01 20:00:00	Réunion Lycée Guillaume Budé de Limeil Brévannes
11382	04043D	ORG_POL	2019-04-02 11:00:00	2019-04-02 12:30:00	réunion de groupe Les Républicains
11383	04043D	REU_TRAV_PARL	2019-04-04 10:30:00	2019-04-04 11:30:00	Réunion du bureau de la Commission des affaires économiques
11384	04043D	REU_TRAV_PARL	2019-04-04 14:00:00	2019-04-04 15:00:00	auditions
11401	04018C	ELUS_LOCAUX	2019-04-09 18:00:00	2019-04-09 19:30:00	\N
11402	04042C	ORG_POL	2019-04-09 10:30:00	2019-04-09 12:00:00	\N
11403	04042C	ACC_DEPL_INTER	2019-04-09 15:00:00	2019-04-09 16:00:00	Entretien avec une délégation de la Commission des Affaires étrangères du Koweït 
11404	04042C	REU_TRAV_PARL	2019-04-09 16:15:00	2019-04-09 17:15:00	Entretien avec le directeur de la législation et du contrôle
11405	04042C	REU_TRAV_PARL	2019-04-09 17:15:00	2019-04-09 18:30:00	Réunion de Direction
11406	04042C	REU_TRAV_PARL	2019-04-09 19:30:00	2019-04-09 20:30:00	Conférence des Présidents
11463	04042C	ACC_VISIT	2019-04-19 17:00:00	2019-04-19 18:00:00	Entretien au Sénat
11481	04042C	ACC_DEPL_INTER	2019-05-02 20:00:00	2019-05-02 22:00:00	Réception avec le Premier ministre Irakoien au Ministère de l'Europe et des Affaires étrangères
11555	19766L	DEPL_PRES_GVT	2019-04-24 08:00:00	2019-04-24 20:00:00	Déplacement Egypte
11556	19766L	DEPL_PRES_GVT	2019-04-25 08:00:00	2019-04-25 20:00:00	Déplacement Egypte
11557	19766L	DEPL_PRES_GVT	2019-04-26 08:00:00	2019-04-26 20:00:00	Déplacement Egypte
11626	04042C	REU_GVT	2019-05-14 16:30:00	2019-05-14 17:00:00	Entretien avec le Minsitre des Affaires étrangère et de l'Europe
11641	08010L	CEREMONIE	2019-05-14 10:00:00	2019-05-14 12:30:00	Hommage aux Invalides
11642	08010L	REU_TRAV_PARL	2019-05-14 12:30:00	2019-05-14 14:30:00	Caisse des Dépôts
10721	08010L	CEREMONIE	2019-01-22 19:00:00	2019-01-22 20:30:00	voeux du Président du sénat
10782	04043D	CEREMONIE	2019-01-24 20:00:00	2019-01-24 22:00:00	voeux de Joinville-le-Pont
10723	08010L	ACC_VISIT	2019-01-23 11:30:00	2019-01-23 12:30:00	Formation élus locaux
10854	04042C	COLL_TER	2019-02-15 08:45:00	2019-02-15 10:00:00	Réunion du bureau du Syndicat des Eaux d'Ile-de-France
10801	08010L	ORG_POL	2019-02-05 11:00:00	2019-02-05 12:30:00	Groupe LR du Sénat
10855	04042C	CEREMONIE	2019-02-15 10:30:00	2019-02-15 11:30:00	Cérémonie en hommage aux militaires de la gendarmerie décédés en 2018 à l'Hôtel National des Invalides
10856	04042C	REU_TRAV_PARL	2019-02-15 11:30:00	2019-02-15 12:30:00	Réunion de Direction
10857	04042C	COLL_TER	2019-02-15 12:45:00	2019-02-15 13:45:00	Réunion de travail
10858	04042C	CEREMONIE	2019-02-15 14:30:00	2019-02-15 16:00:00	Cérémonie en hommage aux militaires de la gendarmerie décédés en 2018 avec le Préfet du Val-de-Marne au Fort de Charenton-le-Pont
10986	04086Q	DEL_ACT_PAR	2019-02-28 08:30:00	2019-02-28 14:00:00	Déplacement en Seine-Saint-Denis sur le thème de l'habitat insalubre ou dangereux. 
10983	04086Q	DEPL_PRES_GVT	2019-02-20 19:00:00	2019-02-20 23:30:00	Dîner du CRIF aux côtés du président de la République
10984	04086Q	COLL_TER	2019-02-21 20:00:00	2019-02-21 22:00:00	Réunion Seine-Saint-Denis
11021	08010L	REU_TRAV_PARL	2019-03-06 08:30:00	2019-03-06 09:30:00	Réforme des institutions
11121	08010L	ACC_VISIT	2019-03-14 15:00:00	2019-03-14 16:00:00	\N
11158	08010L	REU_TRAV_PARL	2019-03-20 11:00:00	2019-03-20 12:00:00	Avoirs corruption internationale
11156	08010L	REU_TRAV_PARL	2019-03-19 15:30:00	2019-03-19 16:30:00	Avoirs corruption internationale
11157	08010L	REU_TRAV_PARL	2019-03-20 09:30:00	2019-03-20 10:30:00	Avoirs corruption internationale
11171	04086Q	REU_TRAV_PARL	2019-03-20 13:45:00	2019-03-20 14:30:00	Rendez-vous de travail Logement
11444	04043D	ACC_VISIT	2019-04-18 11:30:00	2019-04-18 12:30:00	Acceuil d'un étudiant pour discuter de la politique spatiale française et européenne
11173	04042C	ACC_DEPL_INTER	2019-03-19 19:00:00	2019-03-19 20:00:00	Visite des exposition de la fondation Louis Vuitton
11174	04042C	ACC_VISIT	2019-03-20 13:00:00	2019-03-20 14:30:00	Rencontre avec des élus du Val-de-Marne
11175	04042C	ACC_DEPL_INTER	2019-03-20 08:00:00	2019-03-20 09:30:00	Rencontre avec le GIA FRance Russie de l'Ambassadeur de la Fédération de Russie
11176	04042C	REU_TRAV_PARL	2019-03-21 13:00:00	2019-03-21 14:30:00	Rencontre avec le Chef d'état-major de la Marine nationale
11177	04042C	ACC_DEPL_INTER	2019-03-21 18:30:00	2019-03-21 19:30:00	Entretien avec le Président de la commission des Affaires étrangères du Vénézuela
11241	01058X	REU_TRAV_PARL	2019-03-27 17:00:00	2019-03-27 19:00:00	Séminaire sur les Kurdes
11441	04043D	ACC_VISIT	2019-04-15 10:40:00	2019-04-15 12:00:00	visite du Sénat du Lycée Hector Berlioz
11443	04043D	ACC_VISIT	2019-04-18 10:30:00	2019-04-18 11:30:00	Acceuil d'une étudiante de Science-po Lille pour discuter des femmes en politique 
11446	04086Q	COLL_TER	2019-04-15 16:30:00	2019-04-15 19:00:00	Réunion Seine-Saint-Denis
11447	04086Q	ACC_DEPL_INTER	2019-04-16 15:00:00	2019-04-16 16:30:00	Accueil de la famille royale de Roumanie
11501	08010L	ORG_POL	2019-04-30 11:00:00	2019-04-30 12:30:00	Groupe LR du sénat
11502	08010L	ACC_VISIT	2019-05-02 13:30:00	2019-05-02 15:00:00	\N
11566	04018C	REU_TRAV_PARL	2019-05-14 18:30:00	2019-05-14 19:30:00	\N
11742	04018C	ORGEXTPAR	2019-05-23 14:00:00	2019-05-23 17:30:00	CSSPP
11523	14133K	DEPL_PRES_GVT	2019-04-23 14:00:00	2019-04-23 22:00:00	déplacement au Pakistan du groupe d'amitié France-Pakistan du Sénat
11565	04018C	REU_TRAV_PARL	2019-05-16 09:00:00	2019-05-16 12:30:00	auditions pjl Notre Dame de Paris
11567	04042C	ACC_DEPL_INTER	2019-05-13 13:00:00	2019-05-13 14:30:00	Rencontre avec le Président du Sénat du Chef d'état-major de la Marine nationale
11568	04042C	CEREMONIE	2019-05-13 19:00:00	2019-05-13 21:30:00	Réception à la Présidence du Sénat des Leaders pour la Paix
11584	04086Q	ELUS_LOCAUX	2019-05-07 09:00:00	2019-05-07 12:30:00	Colloque "Habiter demain" à Noisy-le-Grand 
11570	04042C	CEREMONIE	2019-05-14 11:00:00	2019-05-14 12:30:00	Cérémonie aux Invalides : Hommage national aux soldats Cédric de Pierrepont et Alain Bertoncello
11583	04086Q	REU_GVT	2019-05-06 09:00:00	2019-05-06 12:30:00	Réunion à Matignon dans le cadre de la mobilisation pour l'emploi et la transition
11623	08009T	REU_TRAV_PARL	2019-05-07 10:00:00	2019-05-07 11:00:00	\N
11586	04086Q	ACC_DEPL_INTER	2019-05-07 14:00:00	2019-05-07 15:30:00	Entretien à la présidence du Sénat avec Mme Aliza Bin Noun, ambassadrice d'Israël en France 
11587	04086Q	REU_TRAV_PARL	2019-05-09 14:00:00	2019-05-09 16:30:00	Audition fédération des OPH
11589	04086Q	REU_TRAV_PARL	2019-05-13 07:00:00	2019-05-13 21:30:00	Déplacement à Londres pour son rapport sur le logement
11622	08009T	REU_TRAV_PARL	2019-05-07 08:30:00	2019-05-07 09:00:00	\N
11624	08009T	ORG_POL	2019-05-07 11:00:00	2019-05-07 12:30:00	\N
11625	08009T	ELUS_LOCAUX	2019-05-07 12:30:00	2019-05-07 14:00:00	\N
11627	04042C	ACC_VISIT	2019-05-14 17:20:00	2019-05-14 17:30:00	Interview Public Sénat
11628	04042C	ACC_DEPL_INTER	2019-05-14 18:00:00	2019-05-14 19:00:00	Entretien avec le Président du Sénat du Patriarche d'Antioche des melkites
11629	04042C	REU_TRAV_PARL	2019-05-14 19:30:00	2019-05-14 20:30:00	Réunion de la Conférence des Présidents de Commission
11643	01025N	REU_TRAV_PARL	2019-05-14 22:30:00	2019-05-14 00:30:00	Séance plénière - PJL Ecole de la confiance
11644	01025N	REU_TRAV_PARL	2019-05-07 14:00:00	2019-05-07 14:30:00	GNIS
11645	01025N	REU_TRAV_PARL	2019-04-30 12:30:00	2019-04-30 14:30:00	Adaptation loi Notre
11646	04042C	REU_TRAV_PARL	2019-05-15 08:00:00	2019-05-15 09:00:00	Réunion des Présidents de Commission
11647	04042C	REU_TRAV_PARL	2019-05-15 13:15:00	2019-05-15 14:30:00	Rencontre avec le Président du Sénat et les Présidents de commission
11648	04042C	ORG_POL	2019-05-15 19:30:00	2019-05-15 21:30:00	Meeting pour les Elections europeennnes au Palais des Congrès
11661	04043D	REU_TRAV_PARL	2019-05-14 13:45:00	2019-05-14 14:30:00	réunion de groupe
11662	04043D	ELUS_LOCAUX	2019-05-14 20:00:00	2019-05-14 22:00:00	café politique "Les Républicains"
11663	04043D	REU_TRAV_PARL	2019-05-15 17:00:00	2019-05-15 18:00:00	Délégation à l'outre-mer
11664	04042C	REU_TRAV_PARL	2019-05-16 16:15:00	2019-05-16 17:00:00	Réunion GIA France-Maroc
11665	04042C	REU_TRAV_PARL	2019-05-16 17:00:00	2019-05-16 18:00:00	\N
11666	04042C	ACC_VISIT	2019-05-16 18:15:00	2019-05-16 18:30:00	Interview d'une télévision étrangère
11667	04042C	ELUS_LOCAUX	2019-05-16 20:00:00	2019-05-16 22:00:00	Rencontre avec les élus du Conseil municipal d'Ormesson-sur-Marne
11668	04042C	COLL_TER	2019-05-17 08:45:00	2019-05-17 12:00:00	Réunion du bureau du SEDIF
11681	04042C	DEPL_PRES_GVT	2019-05-07 19:00:00	2019-05-07 20:00:00	Réunion avec des élus du Val-de-Marna pour une protections phoniques sur l'autoroute A4/A86
11682	04042C	REU_TRAV_PARL	2019-05-21 10:00:00	2019-05-21 11:00:00	\N
11683	04042C	ORG_POL	2019-05-21 11:00:00	2019-05-21 12:30:00	\N
11684	08010L	REU_TRAV_PARL	2019-05-21 10:00:00	2019-05-21 13:00:00	Entreprises Publiques Locales (EPL) 
11703	08010L	ORGEXTPAR	2019-05-22 10:00:00	2019-05-22 13:00:00	CADES
11705	04042C	ACC_DEPL_INTER	2019-05-22 13:00:00	2019-05-22 14:30:00	Rencontre  avec le Représentant permanent du Kurdistan 
11704	08010L	ACC_VISIT	2019-05-22 18:00:00	2019-05-22 20:00:00	\N
10595	04042C	COLL_TER	2018-12-12 13:00:00	2018-12-12 14:30:00	Rencontre avec le Directeur général de Veolia Eau France
11706	04042C	ACC_DEPL_INTER	2019-05-22 15:00:00	2019-05-22 16:00:00	Réunion de travail avec le Président de la Commission des Affaires étrangères d'Arménie
11707	04042C	ACC_VISIT	2019-05-22 18:45:00	2019-05-22 19:00:00	Interview Public Senat
11708	04042C	ACC_DEPL_INTER	2019-05-22 19:15:00	2019-05-22 21:00:00	Célébration des 71 ans de l'Etat d'Israël avec Madame l'Ambassadeur 
11709	04086Q	REU_TRAV_PARL	2019-05-14 12:00:00	2019-05-14 14:00:00	Déjeuner de travail à la caisse des dépôts et consignations. 
11741	04018C	REU_TRAV_PARL	2019-05-23 09:00:00	2019-05-23 10:30:00	\N
11715	04043D	ACC_VISIT	2019-05-20 14:30:00	2019-05-20 16:00:00	rencontre avec Bluebird Bio
11712	04043D	ACC_VISIT	2019-05-22 15:30:00	2019-05-22 16:00:00	visite du conseil municipal des jeunes de Saint-Mandé
11713	04043D	ELUS_LOCAUX	2019-05-22 12:45:00	2019-05-22 14:00:00	rencontre avec un maire du Val-de-Marne
11714	04043D	ACC_VISIT	2019-05-22 16:15:00	2019-05-22 17:00:00	RV avec le groupe NOVARTIS
11721	08010L	REU_TRAV_PARL	2019-05-23 14:30:00	2019-05-23 16:00:00	\N
11744	04018C	ORG_POL	2019-05-28 11:00:00	2019-05-28 12:30:00	\N
11761	08010L	ORG_POL	2019-05-28 11:00:00	2019-05-28 12:30:00	Groupe LR du Sénat
11762	08010L	REU_TRAV_PARL	2019-05-28 12:45:00	2019-05-28 14:00:00	Conseil Natioanl des Barreaux
11763	08010L	DEL_ACT_PAR	2019-05-28 17:45:00	2019-05-28 19:30:00	Staffeurs Congrés Américian 
10541	04042C	ACC_DEPL_INTER	2018-11-19 20:00:00	2018-11-19 21:30:00	Réception à l'Ambassade d'Italie
10542	04042C	ORG_POL	2018-11-20 10:30:00	2018-11-20 12:30:00	\N
10543	04042C	ELUS_LOCAUX	2018-11-20 12:15:00	2018-11-20 12:45:00	Dicours du Président du Sénat pour l'inauguration du Congrès des Maires
10544	04042C	REU_TRAV_PARL	2018-11-20 16:30:00	2018-11-20 17:30:00	Réunion de direction
10545	04042C	REU_TRAV_PARL	2018-11-20 19:30:00	2018-11-20 20:30:00	Réunion de la Conférence des Présidents
10546	04042C	ACC_VISIT	2018-11-21 12:00:00	2018-11-21 14:00:00	Rencontre avec le Président de Veolia
10547	04042C	ACC_DEPL_INTER	2018-11-21 15:00:00	2018-11-21 16:00:00	Entretien avec le Président du Sénat du Président du Gouvernement Afghan
10548	04042C	ACC_VISIT	2018-11-21 17:00:00	2018-11-21 18:00:00	Entretien Expertise France
10549	04042C	ACC_DEPL_INTER	2018-11-21 18:00:00	2018-11-21 18:45:00	Cérémonie des 60 ans de la direction des applications militaires du CEA, présidée par la Ministre des armées
10550	04042C	COLL_TER	2018-11-21 19:00:00	2018-11-21 19:45:00	Rencontre avec la Présidente de la Région d'Ile-de-France à l'occasion du Salon des Maires
10551	04042C	REU_TRAV_PARL	2018-11-21 20:00:00	2018-11-21 22:00:00	Dîner de travail préparation du colloque de la DPR
10555	04042C	ELUS_LOCAUX	2018-11-22 19:30:00	2018-11-22 21:00:00	Rencontre avec des élus pour le Salon des Maires
10553	04042C	ORG_POL	2018-11-22 08:00:00	2018-11-22 09:00:00	Bureau du Comité départemental du Val-de-Marne
10554	04042C	REU_GVT	2018-11-22 17:15:00	2018-11-22 18:15:00	Réunion avec le Ministre de l'Europe et des Affaires étrangères
10556	04042C	REU_TRAV_PARL	2018-11-26 09:00:00	2018-11-26 09:30:00	Réunion de la Conférence des Présidents
10557	04042C	DEPL_PRES_GVT	2018-11-26 10:00:00	2018-11-26 00:00:00	Déplacement à Lyon - Forum sur les confluences franco-chinoises
10561	04042C	ACC_VISIT	2018-11-28 15:00:00	2018-11-28 16:00:00	Entretien Chef d'entreprise
10559	04042C	DEPL_PRES_GVT	2018-11-27 08:00:00	2018-11-27 13:00:00	Déplacement à Lyon - Forum sur les confluences franco-chinoises
10560	04042C	REU_GVT	2018-11-27 18:00:00	2018-11-27 19:00:00	Réunion avec la Ministre de la Jusctice
10562	04042C	ACC_DEPL_INTER	2018-11-28 17:00:00	2018-11-28 18:00:00	Soirée en avant-première du 40 ème salon des vins 
10563	04042C	ACC_DEPL_INTER	2018-11-28 18:30:00	2018-11-28 19:30:00	Réception du 47ème anniversaire des Emirats Arabes-Unis
10564	04042C	REU_TRAV_PARL	2018-11-30 12:30:00	2018-11-30 14:00:00	Rencontre du Chef d'état-major de l'armée de l'air
10565	04042C	ACC_DEPL_INTER	2018-11-30 18:45:00	2018-11-30 19:45:00	Entretien avec la Vice-Présidente du Gouvernement de la Macédoine
10566	04042C	ACC_DEPL_INTER	2018-12-03 12:00:00	2018-12-03 13:00:00	Entretien avec le Président du Sénat du Maréchal polonais
10567	04042C	ACC_DEPL_INTER	2018-12-03 18:30:00	2018-12-03 21:00:00	Débat de lancement du Cercle de Suffren
10568	04042C	ORG_POL	2018-12-04 11:00:00	2018-12-04 12:30:00	\N
10569	04042C	ELUS_LOCAUX	2018-12-04 13:00:00	2018-12-04 14:00:00	Rencontre avec le Maire de Saint-Maurice
10570	04042C	ACC_DEPL_INTER	2018-12-04 18:00:00	2018-12-04 22:00:00	Reception à l'Ambassade de Suède pour la Sainte-Lucie
10571	04042C	ACC_DEPL_INTER	2018-12-05 12:00:00	2018-12-05 14:00:00	Réception à l'occasion de la Fête nationale de la Finlande
10572	04042C	ACC_VISIT	2018-12-05 15:00:00	2018-12-05 16:00:00	Entretien avec le Président de l'IRIS
10573	04042C	ACC_DEPL_INTER	2018-12-05 18:30:00	2018-12-05 19:00:00	Réception à l'occasion de la journée nationale du Qatar
10574	04042C	ACC_DEPL_INTER	2018-12-05 20:00:00	2018-12-05 22:00:00	Réception autour de l'Ambassadrice d'Italie
10575	04042C	ACC_VISIT	2018-12-06 10:45:00	2018-12-06 11:45:00	Entretien avec le nouveau Président de l'Académie de Marine
10576	04042C	ACC_DEPL_INTER	2018-12-06 12:00:00	2018-12-06 14:00:00	Entretien avec le Président du Sénat du Premier ministre Palestinien 
10577	04042C	ACC_VISIT	2018-12-06 16:00:00	2018-12-06 17:00:00	Entretien avec un général
10578	04042C	ACC_DEPL_INTER	2018-12-06 17:00:00	2018-12-06 18:00:00	Entretien avec le représentant du Gouvernement régional du Kurdistan
10579	04042C	ACC_DEPL_INTER	2018-12-07 11:45:00	2018-12-07 12:45:00	Entretien avec la Ministre de la Défense de la Géorgie
10580	04042C	ACC_DEPL_INTER	2018-12-07 13:00:00	2018-12-07 14:15:00	Rencontre avec l'Ambassadeur de Slovaquie
10581	04042C	CEREMONIE	2018-12-07 19:00:00	2018-12-07 22:00:00	Soirée du Téléthon à Saint-Maurice
10582	04042C	COLLOQUE	2018-12-10 09:30:00	2018-12-10 13:00:00	Colloque Hydrodiplomatie et changement climatique pour la paix en Mésopotamie
10583	04042C	ACC_VISIT	2018-12-10 13:00:00	2018-12-10 14:00:00	Rencontre avec un maire du Val-de-Marne
10587	04042C	REU_TRAV_PARL	2018-12-11 10:00:00	2018-12-11 11:00:00	Remise du Rapport du nouveau Président du HCECM
10585	04042C	COLLOQUE	2018-12-10 18:00:00	2018-12-10 18:20:00	Clôture du Colloque Hydrodiplomatie et changement climatique pour la paix en Mésopotamie - Intervention du Président Christian Cambonn
10586	04042C	COLL_TER	2018-12-10 15:30:00	2018-12-10 17:15:00	Réunion de la commission des Relations internationales et Solidarités du SEDIF
10591	04042C	REU_TRAV_PARL	2018-12-11 16:00:00	2018-12-11 16:30:00	Entretien avec un sénateur
10589	04042C	ORG_POL	2018-12-11 11:00:00	2018-12-11 12:00:00	\N
10590	04042C	ELUS_LOCAUX	2018-12-11 12:30:00	2018-12-11 14:00:00	Déjeuner de Noël des anciens de Saint-Maurice
10592	04042C	ACC_VISIT	2018-12-11 16:30:00	2018-12-11 17:30:00	Entretien avec le directeur de l'IHEDN
10599	04042C	ACC_DEPL_INTER	2018-12-13 18:30:00	2018-12-13 19:30:00	Réception à l'Ambassade des Etats-Unis à l'occasion des Fêtes de fin d'année
10594	04042C	REU_TRAV_PARL	2018-12-12 08:30:00	2018-12-12 09:30:00	Rencontre d'une délégation de l'Afghanistan
10597	04042C	REU_TRAV_PARL	2018-12-13 13:00:00	2018-12-13 14:30:00	Rencontre avec un Amiral
10598	04042C	ACC_VISIT	2018-12-13 16:15:00	2018-12-13 17:15:00	Rencontre avec un Chef d'Entreprise
10600	04042C	ELUS_LOCAUX	2018-12-13 20:00:00	2018-12-13 22:00:00	Rencontre avec des élus de Maisons-Alfort
10601	04042C	COLL_TER	2018-12-14 08:45:00	2018-12-14 12:00:00	Réunion du bureau du SEDIF
10615	04042C	REU_TRAV_PARL	2019-01-08 16:50:00	2019-01-08 17:50:00	Réunion de Direction
10616	04042C	CEREMONIE	2019-01-08 19:30:00	2019-01-08 21:30:00	Cérémonie des Voeux de Saint-Maurice
10620	04042C	ACC_DEPL_INTER	2019-01-10 09:00:00	2019-01-10 12:00:00	Forum de Paris à l'Unesco Intervention du Président Christian Cambon sur les nouvelles routes de la soie
10618	04042C	ACC_DEPL_INTER	2019-01-09 18:30:00	2019-01-09 19:30:00	Forum de Paris - Réception les nouvelles routes de la soie
10619	04042C	CEREMONIE	2019-01-09 19:50:00	2019-01-09 21:30:00	Cérémonie des Voeux de Maisons-Alfort
10621	04042C	REU_TRAV_PARL	2019-01-10 13:00:00	2019-01-10 14:30:00	Rencontre avec des sénateurs français et étrangers
10622	04042C	ACC_VISIT	2019-01-10 15:00:00	2019-01-10 16:00:00	Entretien avec un dignitaire
10623	04042C	REU_TRAV_PARL	2019-01-10 20:30:00	2019-01-10 22:00:00	Rencontre avec le général des armées
10624	04042C	CEREMONIE	2019-01-11 19:00:00	2019-01-11 20:00:00	Cérémonie des Voeux à Perigny-sur-Yerres
10625	04042C	CEREMONIE	2019-01-11 20:30:00	2019-01-11 21:30:00	Cérémonie des Voeux à Ablon-sur-Seine
10629	04042C	DEPL_PRES_GVT	2019-01-15 00:00:00	2019-01-15 20:35:00	Déplacement en Irak et en Jordanie avec le Ministre de l'Europe et des Affaires étrangères
10631	08010L	DEL_ACT_PAR	2019-01-15 09:00:00	2019-01-15 11:00:00	Ecole Nationale de la Magistrature
10724	08010L	ACC_VISIT	2019-01-23 15:30:00	2019-01-23 17:00:00	Education Jeunesse Aisne
10632	08010L	ORG_POL	2019-01-15 11:00:00	2019-01-15 14:30:00	Séminaire LR Sénat
11004	04018C	COLL_TER	2019-03-13 17:00:00	2019-03-13 18:30:00	\N
11001	14041T	DEPL_PRES_GVT	2019-02-13 10:30:00	2019-02-13 20:00:00	réunion Présidents des Parlements des pays membres de l'Union pour la méditerranée
11002	14041T	ELUS_LOCAUX	2019-01-24 09:00:00	2019-01-24 18:00:00	déplacement à Genève
11005	04018C	ACC_VISIT	2019-03-19 16:00:00	2019-03-19 18:00:00	Forum métiers aéronautiques
11006	04018C	ELUS_LOCAUX	2019-03-28 10:00:00	2019-03-28 15:00:00	ADAMY
11007	04043D	ACC_VISIT	2019-02-26 15:00:00	2019-02-26 16:30:00	Réunion avec Arnaud LUCAUSSY - Secretaire Général de TDF
11022	08010L	REU_TRAV_PARL	2019-03-07 14:00:00	2019-03-07 14:30:00	commission des finances 
11023	08010L	ACC_VISIT	2019-03-07 14:30:00	2019-03-07 15:00:00	Lycée Agricole de Crézancy
11024	04086Q	REU_TRAV_PARL	2019-03-04 18:00:00	2019-03-04 20:00:00	Réunion à Matignon au sujet de recrudescence d'incidents envers les parlementaires
11025	04086Q	ORG_POL	2019-03-05 11:00:00	2019-03-05 12:30:00	Réunion du groupe LR
10842	04042C	CEREMONIE	2019-02-13 18:30:00	2019-02-13 19:30:00	Cérémonie de remise des insignes de la Légion d'honneur au Secrétaire génral du Sénat par le Président du Sénat
10706	04043D	CEREMONIE	2019-01-21 19:00:00	2019-01-21 20:30:00	Voeux d'Île-de-France Mobilités
10841	04042C	ACC_VISIT	2019-02-13 12:45:00	2019-02-13 14:30:00	Entretien avec des élus du Val-de-Marne
10843	04042C	COLLOQUE	2019-02-13 18:00:00	2019-02-13 18:30:00	Clôture atelier de la Gendarmerie nationale au Sénat
10844	04043D	ORG_POL	2019-02-12 11:00:00	2019-02-12 12:30:00	Réunion du groupe Les Républicains
10845	04043D	CEREMONIE	2019-02-13 19:30:00	2019-02-13 20:30:00	Remise des insignes de Chevalier de la Légion d¿honneur à Nathalie Kosciusko-Morizet 
10849	04042C	DEL_ACT_PAR	2019-02-13 20:00:00	2019-02-13 22:00:00	Réception du GIA FRance-Maroc à l'Ambassade du Maroc
10850	04042C	DEPL_PRES_GVT	2019-02-14 09:00:00	2019-02-14 15:00:00	Déplacement au siège de la DGSE avec le Président du Sénat
10851	04042C	ACC_VISIT	2019-02-14 16:00:00	2019-02-14 17:00:00	Entretien avec le sous-préfet de Nogent-sur-Marne
10852	04042C	ACC_DEPL_INTER	2019-02-14 17:00:00	2019-02-14 18:00:00	Entretien avec le Président du Sénat du Premier ministre tunisien
10853	04042C	ACC_DEPL_INTER	2019-02-14 18:00:00	2019-02-14 19:00:00	Visite exposition de l'Institut du Monde Arabe avec le Président du Sénat et le Premier ministre tunisien
10863	08010L	ORG_POL	2019-02-19 11:00:00	2019-02-19 12:30:00	Groupe LR du sénat
10864	08010L	REU_TRAV_PARL	2019-02-19 18:00:00	2019-02-19 19:00:00	Amendes pénales 
10865	04086Q	REU_TRAV_PARL	2019-02-07 14:00:00	2019-02-07 15:30:00	Réunion de travail - commission des finances
10871	04086Q	COLL_TER	2019-02-11 01:00:00	2019-02-11 18:00:00	Réunion Seine-Saint-Denis
10873	04086Q	COLL_TER	2019-02-18 16:00:00	2019-02-18 18:00:00	Réunion Seine-Saint-Denis
10876	04042C	CEREMONIE	2019-02-19 19:30:00	2019-02-19 20:30:00	Remise d'insignes de Chavalier de la Légion d'Honneur à un ancien sénateur à la Présidence du Sénat
10888	04043D	REU_TRAV_PARL	2019-02-20 17:00:00	2019-02-20 18:30:00	Assemblée Générale de l'AGAS
10982	04086Q	REU_TRAV_PARL	2019-02-20 17:00:00	2019-02-20 18:30:00	Réunion de travail avec la commission des Aff. Eco sur le baromètre banlieue. Mise en place de nouveaux indicateurs permettant de mieux évaluer la situation des quartiers
10985	04086Q	ACC_DEPL_INTER	2019-02-26 07:45:00	2019-02-26 08:45:00	Accueil aux côtés de G. LARCHER du président de l'Irak B. SALIH 
11026	04086Q	REU_TRAV_PARL	2019-03-06 08:30:00	2019-03-06 10:00:00	Petit déjeuner de travail sur les propositions de réforme constitutionnelle organisé par R. Karoutchi 
11027	04086Q	REU_TRAV_PARL	2019-03-06 14:00:00	2019-03-06 14:30:00	Réunion de travail groupe LR
11031	04086Q	DEL_ACT_PAR	2019-03-08 00:00:00	2019-03-08 12:30:00	Déplacement à Aix-en-Provence pour une conférence sur la Fiscalité locale
11029	04086Q	ORG_POL	2019-03-06 17:00:00	2019-03-06 20:00:00	Séminaire de l'Amicale Gaulliste 
11030	04086Q	DEL_ACT_PAR	2019-03-07 11:00:00	2019-03-07 23:30:00	Déplacement à Aix-en-Provence pour une conférence sur la Fiscalité locale
11032	04042C	REU_TRAV_PARL	2019-03-05 10:00:00	2019-03-05 11:00:00	Réunion de Direction
11033	04042C	ORG_POL	2019-03-05 11:00:00	2019-03-05 12:30:00	\N
11037	04042C	REU_TRAV_PARL	2019-03-07 08:15:00	2019-03-07 09:30:00	Groupe d'Amitié France-Italie
11035	04042C	ACC_VISIT	2019-03-05 13:00:00	2019-03-05 14:30:00	Rencontre avec un Maire du Val-de-Marne
11036	04042C	ACC_DEPL_INTER	2019-03-06 19:30:00	2019-03-06 22:00:00	soirée-débat organisée pour célébrer les 55 ans des relations diplomatiques franco-chinoises
11038	04042C	ACC_DEPL_INTER	2019-03-07 12:00:00	2019-03-07 12:45:00	Réception à l'Ambassade de Bulgarie à l'occasion de la Fête nationale
11039	04042C	ACC_DEPL_INTER	2019-03-07 13:00:00	2019-03-07 14:00:00	Rencontre avec l'Ambassadeur du Qatar
11040	08048B	ACC_VISIT	2019-03-05 16:30:00	2019-03-05 17:00:00	Visite du Sénat par les élèves de l'Ecole du Roucas Blanc de Marseille
11042	08048B	ORG_POL	2019-03-06 17:00:00	2019-03-06 20:00:00	Commission nationale des investitures
11141	01058X	REU_TRAV_PARL	2019-03-14 09:30:00	2019-03-14 13:00:00	Conseil d'administration de l'ANDRA
11142	08010L	REU_TRAV_PARL	2019-03-19 11:00:00	2019-03-19 12:30:00	Groupe LR du sénat
11143	08010L	ACC_DEPL_INTER	2019-03-19 09:30:00	2019-03-19 11:00:00	Délégation du Bundesrat
11144	08010L	ACC_DEPL_INTER	2019-03-19 12:30:00	2019-03-19 14:30:00	\N
11145	04042C	COLL_TER	2019-03-15 08:45:00	2019-03-15 11:30:00	Réunion du Syndicat des Eaux d'Ile-de-France
11146	04042C	ACC_DEPL_INTER	2019-03-15 12:30:00	2019-03-15 13:30:00	Réception à l'Ambassade d'Irlande à l'occasion de la Saint-Patrick
11147	04042C	ACC_VISIT	2019-03-15 14:30:00	2019-03-15 16:00:00	Visite guidée de deux classes de la commune de Saint-Maurice
11148	04042C	ACC_VISIT	2019-03-18 10:00:00	2019-03-18 11:30:00	Rendez-vous avec des administrés du Val-de-Marne à la Mairie de Saint-Maurice
11149	04042C	REU_TRAV_PARL	2019-03-18 12:30:00	2019-03-18 14:30:00	Rencontre avec un élu du Val-de-Marne
11150	04042C	REU_TRAV_PARL	2019-03-18 15:00:00	2019-03-18 16:30:00	Réunion de direction
11151	04042C	ACC_DEPL_INTER	2019-03-19 10:00:00	2019-03-19 11:00:00	Entretien avec le Président du Sénat du Président du Bundesrat
11152	04042C	CEREMONIE	2019-03-19 12:30:00	2019-03-19 14:30:00	Reception de la delegation du Bundesrat à la Présidence du Sénat et signature commune entre le Bundesrat et le Sénat
11153	04042C	ACC_VISIT	2019-03-19 15:00:00	2019-03-19 16:00:00	Visite de de 33 officiers du CHEM
11154	04042C	REU_TRAV_PARL	2019-03-19 16:15:00	2019-03-19 17:00:00	Réunion d'organisation
11155	04042C	REU_TRAV_PARL	2019-03-19 17:00:00	2019-03-19 18:00:00	Entretien avec le contrôleur général des armées
11159	01025N	REU_TRAV_PARL	2019-03-06 12:30:00	2019-03-06 13:30:00	Adaptation loi Notre
11160	01025N	REU_TRAV_PARL	2019-03-07 08:30:00	2019-03-07 10:00:00	Audition groupe Métiers d'Art
11161	01025N	REU_TRAV_PARL	2019-03-07 12:30:00	2019-03-07 14:00:00	Journée droits des femmes autour de Natacha Polony
11162	01025N	REU_TRAV_PARL	2019-03-12 11:15:00	2019-03-12 12:00:00	Audition Commission Affaires sociales
11163	01025N	REU_TRAV_PARL	2019-03-13 10:00:00	2019-03-13 11:00:00	Audition Roger Genat (ANSES)
11232	08010L	ORG_POL	2019-03-26 11:00:00	2019-03-26 12:30:00	Groupe LR du sénat
11165	01025N	ACC_VISIT	2019-03-19 10:30:00	2019-03-19 11:15:00	Conseil municipal d'Omey
11201	04043D	REU_TRAV_PARL	2019-03-14 09:00:00	2019-03-14 11:00:00	Réunion OPECST
11233	08010L	REU_TRAV_PARL	2019-03-26 12:30:00	2019-03-26 13:00:00	Corruption transnationale 
11237	14211G	CEREMONIE	2019-03-21 18:00:00	2019-03-21 19:00:00	Inauguration à Jacou
11235	08010L	ACC_DEPL_INTER	2019-03-26 14:30:00	2019-03-26 16:00:00	Master ENA Franco-Allemand
11236	14211G	ORG_POL	2019-03-27 12:30:00	2019-03-27 14:00:00	\N
11238	14211G	CEREMONIE	2019-03-21 19:00:00	2019-03-21 20:00:00	Vernissage à Saint-Drézéry
11239	14211G	CEREMONIE	2019-03-14 17:30:00	2019-03-14 19:00:00	MEDEF Hérault
11261	04043D	CEREMONIE	2019-03-26 11:00:00	2019-03-26 12:15:00	inauguration du pont de Nogent
11262	08010L	ORG_POL	2019-04-02 11:00:00	2019-04-02 13:00:00	Groupe LR du sénat + audition Bellamy
11263	04043D	ACC_VISIT	2019-03-27 14:30:00	2019-03-27 15:00:00	Visite d'Ormesson
11273	04086Q	REU_TRAV_PARL	2019-03-27 13:45:00	2019-03-27 14:30:00	Rendez-vous de travail Logement
11265	04043D	ACC_VISIT	2019-03-28 10:15:00	2019-03-28 12:00:00	visite d'une délégation de l'hôpital Bégin et de l'hôpital BWK de Berlin 
11266	04086Q	REU_TRAV_PARL	2019-03-21 14:00:00	2019-03-21 15:30:00	Rendez-vous de travail 
11267	04086Q	COLL_TER	2019-03-22 08:30:00	2019-03-22 10:00:00	Reunion Habitat MGP 
11268	04086Q	COLLOQUE	2019-03-25 09:00:00	2019-03-25 16:30:00	Colloque de la fondation France-Israël sur le handicap 
11269	04086Q	ORG_POL	2019-03-26 11:00:00	2019-03-26 12:30:00	Réunion du groupe LR
11270	04086Q	ORG_POL	2019-03-26 10:00:00	2019-03-26 11:00:00	Bureau du groupe LR
11271	04086Q	ACC_DEPL_INTER	2019-03-26 15:30:00	2019-03-26 16:30:00	Audience aux côtés de G. Larcher du Président de la République Populaire de Chine Xi Jinping
11272	08010L	REU_TRAV_PARL	2019-04-02 16:00:00	2019-04-02 17:00:00	PPL corruption transnationale 
11274	04086Q	ACC_DEPL_INTER	2019-04-02 07:00:00	2019-04-02 08:00:00	Audience aux côtés de G. Larcher de la Présidente du parlement vietnamien Mme. Nguyen Thi Kim Ngan 
11275	04086Q	DEPL_PRES_GVT	2019-04-02 09:00:00	2019-04-02 23:30:00	Déplacement à Toulouse pour les assises de la coopération franco-vietnamienne
11276	19766L	REU_TRAV_PARL	2018-09-11 09:00:00	2018-09-11 18:00:00	Séminaire de rentrée LR
11277	19766L	DEPL_PRES_GVT	2018-09-13 09:00:00	2018-09-13 20:00:00	OKLAHOMA
11278	19766L	DEPL_PRES_GVT	2018-09-14 09:00:00	2018-09-14 20:00:00	HOUSTON
10701	19737F	DEL_ACT_PAR	2019-01-17 09:45:00	2019-01-17 12:00:00	Conseil National de la Transition Ecologique
10702	08010L	REU_TRAV_PARL	2019-01-22 08:30:00	2019-01-22 09:30:00	PJL PACTE/ EPL
10727	04042C	ACC_DEPL_INTER	2019-01-21 18:30:00	2019-01-21 20:00:00	Cérémonie des Voeux de la Ministre des armées
10704	08010L	ORG_POL	2019-01-22 11:00:00	2019-01-22 12:30:00	Groupe LR du sénat
10728	04042C	ORG_POL	2019-01-22 11:00:00	2019-01-22 12:30:00	\N
10729	04042C	ACC_VISIT	2019-01-22 18:00:00	2019-01-22 18:30:00	Entretien avec des élus du Val-de-Marne
10730	04042C	CEREMONIE	2019-01-22 19:00:00	2019-01-22 19:30:00	Cérémonie desVoeux de la Métropole du Grand Paris
10731	04042C	CEREMONIE	2019-01-22 19:30:00	2019-01-22 20:30:00	Cérémonie des Voeux du Président du Sénat
10732	04042C	REU_TRAV_PARL	2019-01-22 21:00:00	2019-01-22 22:00:00	Emission France-Info "Le traité d'Aix-La-Chapelle et le Grand Débat national
10733	04042C	ACC_DEPL_INTER	2019-01-23 18:30:00	2019-01-23 19:30:00	Réception à l'occasion du Nouvel An à l'Ambassade du Canada
10734	04042C	ACC_DEPL_INTER	2019-01-23 20:00:00	2019-01-23 22:00:00	Dîner d'Etat au Palais de l'Elysée à l'occasion des 70 ans des relations diplomatiques entre laz France et Israël
10740	08010L	REU_TRAV_PARL	2019-01-23 16:30:00	2019-01-23 17:30:00	collectivités territoriales
10736	04043D	CEREMONIE	2019-01-24 11:30:00	2019-01-24 12:00:00	Cérémonie des voeux de l'Institut le Val Mandé
10804	04018C	ORG_POL	2019-02-12 00:00:00	2019-02-12 00:00:00	\N
10738	04043D	CEREMONIE	2019-01-23 20:15:00	2019-01-23 22:00:00	Voeux de Limeil-Brévannes
10739	04043D	CEREMONIE	2019-01-24 12:15:00	2019-01-24 13:00:00	cérémonie des voeux des hopitaux de Saint-Maurice
11063	14211G	REU_GVT	2019-02-26 17:30:00	2019-02-26 18:30:00	\N
10806	04043D	REU_TRAV_PARL	2019-02-05 12:30:00	2019-02-05 14:00:00	déjeuner de la Commission des affaires Economiques
10807	04043D	DEL_ACT_PAR	2019-02-06 08:30:00	2019-02-06 10:00:00	réunion « OPECST-Académie des sciences-Académie nationale de médecine » 
10808	04043D	REU_TRAV_PARL	2019-02-07 00:00:00	2019-02-07 00:00:00	réunion OPECST
11061	14211G	ELUS_LOCAUX	2019-02-27 09:00:00	2019-02-27 10:30:00	\N
10847	04043D	REU_TRAV_PARL	2019-02-14 09:30:00	2019-02-14 11:30:00	Office parlementaire d'évaluation des choix scientifiques et technologiques 
10848	04043D	ACC_DEPL_INTER	2019-02-14 08:15:00	2019-02-14 09:30:00	Réunion du groupe d'amitié France-Vanuatu et Iles du Pacifique
11062	14211G	DEPL_PRES_GVT	2019-02-26 11:00:00	2019-02-26 16:00:00	Salon de l'Agriculture
11064	14211G	COLL_TER	2019-02-21 18:00:00	2019-02-21 20:00:00	Conseil de Métropole
11065	14211G	ORG_POL	2019-03-05 11:00:00	2019-03-05 12:00:00	Groupe Les Républicains
11066	14211G	ORG_POL	2019-02-19 11:00:00	2019-02-19 12:00:00	Groupe Les Républicains
11067	14211G	ORG_POL	2019-02-12 11:00:00	2019-02-12 12:00:00	Groupe Les Républicains
11068	14211G	REU_GVT	2019-02-05 17:30:00	2019-02-05 18:30:00	Ministère de la transition écologique et solidaire
11069	14211G	ORG_POL	2019-02-05 11:00:00	2019-02-05 12:00:00	Groupe Les Républicains
11070	14211G	COLL_TER	2019-01-31 18:00:00	2019-01-31 21:00:00	Conseil de Métropole
11074	14211G	ORG_POL	2019-01-29 11:00:00	2019-01-29 12:00:00	Groupe Les Républicains
11072	14211G	ELUS_LOCAUX	2019-01-31 14:30:00	2019-01-31 18:00:00	\N
11073	14211G	CEREMONIE	2019-01-29 18:30:00	2019-01-29 19:30:00	Nouvel An Chinois
11075	14211G	CEREMONIE	2019-01-24 15:00:00	2019-01-24 16:30:00	Audience Solennelle de rentrée du Tribunal de Grande Instance de Béziers
11179	14211G	ORG_POL	2019-03-19 11:00:00	2019-03-19 12:00:00	Groupe Les Républicains
11077	14211G	CEREMONIE	2019-01-23 18:30:00	2019-01-23 19:30:00	Inauguration à Assas
11078	14211G	ORG_POL	2019-01-22 11:00:00	2019-01-22 12:00:00	Groupe Les Républicains
11242	08010L	COLLOQUE	2019-03-28 11:00:00	2019-03-28 12:30:00	Journée des Entreprises 
11080	14211G	ORG_POL	2019-01-15 10:00:00	2019-01-15 13:00:00	Groupe Les Républicains
11178	14211G	ORG_POL	2019-03-12 11:00:00	2019-03-12 12:00:00	Groupe Les Républicains
11279	19766L	DEPL_PRES_GVT	2018-09-17 09:00:00	2018-09-17 20:00:00	NOUVELLE ORLEANS
11280	19766L	DEPL_PRES_GVT	2018-09-18 09:00:00	2018-09-18 20:00:00	NOUVELLE ORLEANS
11281	19766L	DEPL_PRES_GVT	2018-09-19 09:00:00	2018-09-19 20:00:00	NOUVELLE ORLEANS
11282	19766L	DEPL_PRES_GVT	2018-09-20 09:00:00	2018-09-20 20:00:00	HOUSTON
11283	19766L	DEPL_PRES_GVT	2018-09-21 09:00:00	2018-09-21 20:00:00	HOUSTON
11284	19766L	ELUS_LOCAUX	2018-10-01 09:00:00	2018-10-01 20:00:00	Semaine de l'AFE
11285	19766L	ELUS_LOCAUX	2018-10-02 09:00:00	2018-10-02 20:00:00	Semaine de l'AFE
11286	19766L	ELUS_LOCAUX	2018-10-03 09:00:00	2018-10-03 19:00:00	Semaine de l'AFE
11287	19766L	REU_TRAV_PARL	2019-03-26 16:00:00	2019-03-26 20:00:00	Séminaire équipe
11288	19766L	REU_TRAV_PARL	2019-03-27 09:00:00	2019-03-27 20:00:00	Séminaire de travail équipe
11289	19766L	REU_TRAV_PARL	2019-03-28 09:00:00	2019-03-28 22:00:00	Séminaire de travail - Toulon
11290	19766L	ELUS_LOCAUX	2019-03-11 10:00:00	2019-03-11 18:00:00	Semaine de l'Assemblée des Français de l'Etranger
11296	19766L	DEPL_PRES_GVT	2019-02-27 08:00:00	2019-02-27 20:00:00	Déplacement ROME
11292	19766L	ELUS_LOCAUX	2019-03-13 10:00:00	2019-03-13 18:00:00	Semaine de l'Assemblée des Français de l'Etranger
11293	19766L	ELUS_LOCAUX	2019-03-14 10:00:00	2019-03-14 19:00:00	Semaine de l'Assemblée des Français de l'Etranger
11294	19766L	ELUS_LOCAUX	2019-03-12 10:00:00	2019-03-12 12:00:00	Semaine de l'Assemblée des Français de l'Etranger
11295	19766L	DEPL_PRES_GVT	2019-02-26 10:00:00	2019-02-26 20:00:00	Déplacement ROME
11297	19766L	DEPL_PRES_GVT	2019-02-28 08:00:00	2019-02-28 19:00:00	Déplacement MILAN
11301	19766L	DEPL_PRES_GVT	2019-02-22 14:00:00	2019-02-22 19:00:00	Déplacement Paray-le-Monial
11299	19766L	ORG_POL	2019-02-18 12:30:00	2019-02-18 14:00:00	Entretien avec Nicolas Sarkozy
11300	19766L	DEPL_PRES_GVT	2019-02-15 10:00:00	2019-02-15 20:00:00	Déplacement VIENNE
11302	19766L	DEPL_PRES_GVT	2019-01-29 09:00:00	2019-01-29 20:00:00	Déplacement BRUXELLES
11303	19766L	DEPL_PRES_GVT	2019-01-30 09:00:00	2019-01-30 20:00:00	Déplacement BRUXELLES
11304	19766L	REU_TRAV_PARL	2019-01-14 08:00:00	2019-01-14 20:00:00	Déplacement NANTES
11305	19766L	REU_TRAV_PARL	2019-01-15 08:00:00	2019-01-15 20:00:00	Déplacement NANTES
11306	19766L	DEPL_PRES_GVT	2019-01-07 10:00:00	2019-01-07 20:00:00	Déplacement LIBAN
11307	19766L	DEPL_PRES_GVT	2019-01-08 08:00:00	2019-01-08 20:00:00	Déplacement LIBAN
11308	19766L	DEPL_PRES_GVT	2019-01-09 08:00:00	2019-01-09 20:00:00	Déplacement LIBAN
11309	19766L	DEPL_PRES_GVT	2019-01-10 08:00:00	2019-01-10 20:00:00	Déplacement LIBAN
11310	19766L	DEPL_PRES_GVT	2019-01-11 08:00:00	2019-01-11 20:00:00	Déplacement LIBAN
11311	19766L	DEPL_PRES_GVT	2018-12-13 17:00:00	2018-12-13 20:00:00	Déplacement EGYPTE
11312	19766L	REU_TRAV_PARL	2018-12-10 09:00:00	2018-12-10 19:00:00	CFE
11313	19766L	REU_TRAV_PARL	2018-12-11 09:00:00	2018-12-11 19:00:00	Réunion CFE
11318	04042C	ACC_VISIT	2019-04-01 11:30:00	2019-04-01 12:30:00	Entretien avec un ancien élu du Val-de-Marne
11315	14133K	CEREMONIE	2019-03-22 14:30:00	2019-03-22 18:00:00	Séminaire Interarmées des Grandes Écoles Militaires 2019 à l¿École militaire 
11316	14133K	ACC_DEPL_INTER	2019-03-25 12:30:00	2019-03-25 18:00:00	séminaire franco-chinois sur la gouvernance mondiale au ministère des affaires étrangères
11317	14133K	ELUS_LOCAUX	2019-04-02 12:30:00	2019-04-02 13:30:00	\N
11319	04042C	ACC_DEPL_INTER	2019-04-01 15:00:00	2019-04-01 16:00:00	Entretien avec la nouvelle ambassadrice de la République d'Arménie
11320	04042C	ACC_VISIT	2019-04-01 16:15:00	2019-04-01 17:15:00	Entretien avec une ancien députée de Seine-et-Marne
11321	04042C	ACC_VISIT	2019-04-01 19:00:00	2019-04-01 20:00:00	Rencontre avec l'Académie de Marine
11322	04042C	ACC_DEPL_INTER	2019-04-02 07:45:00	2019-04-02 08:45:00	Entretien avec le Président du Sénat de la Présidente de l'Assemblée nationale du Vietnam
11323	04042C	ORG_POL	2019-04-02 11:00:00	2019-04-02 12:30:00	Réunion du Groupe Les Républicains
11324	04042C	REU_TRAV_PARL	2019-04-02 18:00:00	2019-04-02 19:00:00	Entretien avec le Président du CNCTR
11325	04042C	REU_TRAV_PARL	2019-04-02 19:15:00	2019-04-02 20:15:00	Audition du Président Christian Cambon sur la PPR Règlement du Sénat - Contrôle de l'apllication et de l'évaluation des lois
11326	04042C	REU_TRAV_PARL	2019-04-01 17:15:00	2019-04-01 18:15:00	Réunion de direction
11348	01025N	REU_TRAV_PARL	2019-03-27 08:00:00	2019-03-27 09:00:00	Rencontre Pascal PERRINEAU - Garant du Grand Débat national
11344	08048B	REU_TRAV_PARL	2019-04-04 08:30:00	2019-04-04 10:30:00	Auditions des Ministres M. LECORNU et Mme WARGON sur la méthodologie du Grand débat national
11346	01025N	REU_TRAV_PARL	2019-03-21 14:00:00	2019-03-21 15:00:00	PJL Ecole de la confiance
11347	01025N	REU_TRAV_PARL	2019-03-26 10:30:00	2019-03-26 11:30:00	PJL Alsace
11355	14211G	ACC_VISIT	2019-04-03 10:00:00	2019-04-03 11:30:00	CMJ de la commune de SAINT-ANDRE-DE-SANGONIS
11957	04018C	ACC_DEPL_INTER	2019-06-26 10:00:00	2019-06-26 12:00:00	Versailles
11958	04018C	ORGEXTPAR	2019-07-02 09:30:00	2019-07-02 12:30:00	Haut-Conseil aux Musées de France
11960	04042C	CEREMONIE	2019-06-12 14:30:00	2019-06-12 14:45:00	Inauguration de la Statue d'un sculpteur roumain par le Président du Sénat
11961	04042C	ACC_VISIT	2019-06-19 16:00:00	2019-06-19 17:00:00	Visite guidée du Conseil municipal des enfants d'Ablon-sur-Seine
11962	04042C	ACC_DEPL_INTER	2019-06-19 17:00:00	2019-06-19 18:00:00	Entretien avec une délégation du Parlement de Chypre
11963	04042C	ACC_DEPL_INTER	2019-06-19 19:00:00	2019-06-19 20:00:00	Réception à l'Ambassade de Suisse à l'occasion de la réouverture des salons
11964	04042C	ELUS_LOCAUX	2019-06-19 20:30:00	2019-06-19 22:00:00	Réunion militante à Saint-Maurice
11965	04042C	REU_GVT	2019-06-20 08:30:00	2019-06-20 09:30:00	Entretien avec la Ministre des armées
11966	04042C	REU_TRAV_PARL	2019-06-20 10:30:00	2019-06-20 12:00:00	Réunion de la Délégation Parlemantaire au Renseignement
12005	08009T	REU_TRAV_PARL	2019-05-16 10:30:00	2019-05-16 11:00:00	\N
12006	08009T	REU_TRAV_PARL	2019-05-16 16:00:00	2019-05-16 17:00:00	\N
12007	08009T	ORG_POL	2019-05-21 11:00:00	2019-05-21 12:30:00	\N
12008	08009T	REU_TRAV_PARL	2019-05-21 12:30:00	2019-05-21 14:00:00	\N
12009	08009T	REU_TRAV_PARL	2019-05-22 15:00:00	2019-05-22 16:00:00	\N
12010	08009T	REU_TRAV_PARL	2019-05-22 16:00:00	2019-05-22 16:30:00	\N
12011	08009T	REU_TRAV_PARL	2019-05-22 17:30:00	2019-05-22 18:00:00	\N
12012	08009T	REU_TRAV_PARL	2019-05-22 18:00:00	2019-05-22 19:00:00	\N
12013	08009T	REU_TRAV_PARL	2019-05-23 09:30:00	2019-05-23 15:00:00	\N
12014	08009T	ORG_POL	2019-05-28 11:00:00	2019-05-28 12:30:00	\N
12015	08009T	REU_GVT	2019-05-28 13:00:00	2019-05-28 14:30:00	\N
12016	08009T	REU_TRAV_PARL	2019-06-04 10:00:00	2019-06-04 11:00:00	\N
12017	08009T	ORG_POL	2019-06-04 11:00:00	2019-06-04 12:30:00	\N
12018	08009T	REU_TRAV_PARL	2019-06-04 17:00:00	2019-06-04 18:00:00	\N
12019	08009T	ELUS_LOCAUX	2019-06-05 12:30:00	2019-06-05 14:30:00	\N
12025	08009T	REU_TRAV_PARL	2019-06-19 12:45:00	2019-06-19 14:00:00	\N
12026	08009T	REU_TRAV_PARL	2019-06-19 15:30:00	2019-06-19 16:30:00	\N
12027	08009T	REU_TRAV_PARL	2019-06-20 13:00:00	2019-06-20 17:30:00	\N
12048	04086Q	ACC_DEPL_INTER	2019-06-12 12:00:00	2019-06-12 14:30:00	Déjeuner de travail avec le Président du Sénat de Roumanie
12049	04086Q	ACC_DEPL_INTER	2019-06-12 17:30:00	2019-06-12 18:30:00	Réception de la délégation Roumaine 
12054	04086Q	ACC_DEPL_INTER	2019-06-14 08:30:00	2019-06-14 12:30:00	Sénats d'Europe, Séance Plénière 
12055	04086Q	ACC_DEPL_INTER	2019-06-14 13:30:00	2019-06-14 14:30:00	Déjeuner de travail / Sénats d'Europe 
12056	04086Q	ACC_DEPL_INTER	2019-06-14 14:30:00	2019-06-14 19:00:00	Sénats d'Europe, Séance Plénière 
12057	04086Q	ACC_DEPL_INTER	2019-06-14 20:00:00	2019-06-14 22:30:00	Diner officiel des Sénats d'Europe 
12058	04086Q	DEPL_PRES_GVT	2019-06-21 00:00:00	2019-06-21 00:00:00	Déplacement en Tunisie
12059	04086Q	ORG_POL	2019-06-25 11:00:00	2019-06-25 12:30:00	Réunion du groupe LR
12060	08048B	ACC_VISIT	2019-06-26 00:00:00	2019-06-26 00:00:00	Visite du Sénat par la classe de 3ème du Collège St Joseph de la Madeleine de Marseille
12105	01025N	REU_TRAV_PARL	2019-06-26 14:30:00	2019-06-26 17:00:00	Séance plénière - PPL Clarifier diverses dispositions du droit électoral
12106	01025N	ORG_POL	2019-06-26 08:30:00	2019-06-26 09:15:00	Femmes Parlementaires du Centre
12107	01025N	REU_TRAV_PARL	2019-06-25 14:00:00	2019-06-25 14:30:00	Maison des Eaux minérales naturelles
12108	01025N	REU_TRAV_PARL	2019-06-20 09:00:00	2019-06-20 14:30:00	Conseil d'Etat
12109	08010L	ORG_POL	2019-07-02 11:00:00	2019-07-02 12:03:00	Groupe LR du Sénat
12483	04042C	ACC_VISIT	2019-09-24 17:45:00	2019-09-24 18:45:00	Rencontre avec le Bureau National Interprofessionnel du Cognac
12481	04042C	ORG_POL	2019-09-24 11:00:00	2019-09-24 12:30:00	Réunion du bureau du Groupe LR du Sénat
12482	04042C	ACC_DEPL_INTER	2019-09-24 15:30:00	2019-09-24 16:30:00	Rencontre avec une délégation du Parlement roumain
12543	04042C	ACC_VISIT	2019-09-30 16:00:00	2019-09-30 16:45:00	Entretien avec un administré
12541	04042C	CEREMONIE	2019-09-30 12:00:00	2019-09-30 13:30:00	Hommage à Monsieur Jacques CHIRAC, ancien Président de la République à l'Eglise Saint-Sulpice
12542	04042C	CEREMONIE	2019-09-30 15:00:00	2019-09-30 15:15:00	Moment de recueillement pour Monsieur Jacques CHIRAC, ancien Président de la République à la Présidence du Sénat
12544	04042C	ACC_VISIT	2019-09-30 16:45:00	2019-09-30 17:15:00	Entretien avec un élu local
12545	04042C	REU_TRAV_PARL	2019-09-30 17:15:00	2019-09-30 18:15:00	Réunion de direction
12561	04043D	ORG_POL	2019-09-16 10:00:00	2019-09-16 18:00:00	Séminaire de rentrée LR à Avignon
12562	04043D	DEPL_PRES_GVT	2019-09-17 12:30:00	2019-09-17 13:30:00	Déjeuner avec le Directeur Général de Monaco Telecom
12563	04043D	DEPL_PRES_GVT	2019-09-17 13:30:00	2019-09-17 16:00:00	Visite du Data Center de Monaco Telecom
12564	04043D	DEPL_PRES_GVT	2019-09-18 12:00:00	2019-09-18 16:00:00	Visite des laboratoires de PSL
12565	04043D	DEPL_PRES_GVT	2019-09-23 15:30:00	2019-09-23 17:00:00	Visite de Livi : centre de téléconsultation
12566	04043D	ACC_DEPL_INTER	2019-09-23 19:00:00	2019-09-23 22:00:00	Déjeuner diplomatique avec l'ambassadeur d'Indonésie
12567	04043D	ORG_POL	2019-09-24 11:00:00	2019-09-24 12:30:00	Réunion de groupe
12568	04043D	ACC_VISIT	2019-09-30 09:45:00	2019-09-30 11:00:00	Acceuil d'élèves du collège Janus Korczak
12569	04043D	ORG_POL	2019-10-01 11:00:00	2019-10-01 12:00:00	Réunion de groupe
12570	04043D	ORG_POL	2019-09-24 18:00:00	2019-09-24 20:00:00	\N
12761	01025N	REU_TRAV_PARL	2019-10-08 14:30:00	2019-10-08 15:15:00	audition Coop de France
13156	04042C	CEREMONIE	2019-11-11 15:15:00	2019-11-11 18:00:00	Inauguration du Monument aux Morts pour la France en Opérations Extérieures en Présence du Président de la République au Parc André Citroën à Paris
12763	04042C	REU_TRAV_PARL	2019-10-15 13:00:00	2019-10-15 14:30:00	Rencontres des parlementaires franciliens à l'Assemblée nationale
12764	04042C	REU_TRAV_PARL	2019-10-15 17:00:00	2019-10-15 17:30:00	Interview sur le rapport Brexit
12765	04042C	ACC_DEPL_INTER	2019-10-15 18:30:00	2019-10-15 19:00:00	Cérémonie de remise des Prix de l'Organisation Internationale de la Vigne et du Vin à l'Ambassade du Chili
12766	04042C	REU_GVT	2019-10-15 20:30:00	2019-10-15 22:30:00	Réception de la Secrétaire d'Etat des armées à l'occasion de la venue en France du Haut-Commissaire aux anciens résidtants et anciens membres de l'Armée de Libération
12767	04043D	ORG_POL	2019-10-15 11:00:00	2019-10-15 12:30:00	Réunion de groupe
12768	04043D	ORG_POL	2019-10-08 11:00:00	2019-10-08 12:00:00	Réunion de groupe
12769	04043D	ACC_DEPL_INTER	2019-10-09 18:30:00	2019-10-09 20:00:00	Entretien avec l¿ambassadeur d¿Indonesie en France
12770	04043D	COLL_TER	2019-10-15 14:30:00	2019-10-15 15:30:00	Acceuil du sous-secrétaire général de la préfécture du Val-de-Marne
12771	04042C	REU_TRAV_PARL	2019-10-03 08:30:00	2019-10-03 09:30:00	Rencontre du Groupe Interparlementaire d'Amitié France-Israël et l'Ambassadrice d'Israël en France
12772	04042C	REU_TRAV_PARL	2019-10-03 09:30:00	2019-10-03 11:00:00	Réunion de la Délégation Parlementaire au Renseignement
12773	04042C	REU_TRAV_PARL	2019-10-10 09:15:00	2019-10-10 11:00:00	Déplacement de la Délégation Parlementaire au Renseignement
13155	04042C	ACC_DEPL_INTER	2019-11-07 20:00:00	2019-11-07 22:00:00	Réception de l'Ambassadeur des Emirats Arabes Unis
13157	04042C	CEREMONIE	2019-11-11 12:30:00	2019-11-11 14:30:00	Rencontre avec les anciens combattants de Saint-Maurice
13264	14041T	ELUS_LOCAUX	2019-10-30 09:00:00	2019-10-30 22:00:00	déplacement à l'étranger
13262	14041T	ELUS_LOCAUX	2019-11-21 09:00:00	2019-11-21 22:00:00	déplacement à l'étranger
13263	14041T	ELUS_LOCAUX	2019-11-07 09:00:00	2019-11-07 22:00:00	déplacement à l'étranger
12948	08009T	REU_TRAV_PARL	2019-09-11 15:30:00	2019-09-11 16:30:00	\N
13265	14041T	ELUS_LOCAUX	2019-10-31 09:00:00	2019-10-31 22:00:00	déplacement à l'étranger
13266	14041T	ELUS_LOCAUX	2019-10-08 09:00:00	2019-10-08 22:00:00	déplacement à l'étranger
13267	14041T	ELUS_LOCAUX	2019-10-09 00:00:00	2019-10-09 00:00:00	déplacement à l'étranger
13269	14041T	ELUS_LOCAUX	2019-11-26 09:00:00	2019-11-26 22:00:00	déplacement à l'étranger
13321	04042C	ACC_VISIT	2019-11-28 08:20:00	2019-11-28 08:30:00	Interview Beur FM
13322	04042C	ELUS_LOCAUX	2019-11-28 19:30:00	2019-11-28 20:30:00	Réunion de lancement de Campagne à Ivry-sur-Seine
13326	04042C	ACC_DEPL_INTER	2019-11-29 16:00:00	2019-11-29 17:00:00	Entretien avec le Vice-ministre pour les Affaires européennes du Venezuela
13324	04042C	ELUS_LOCAUX	2019-11-28 20:45:00	2019-11-28 22:00:00	Réunion avec des élus du Val-de-Marne
13325	04042C	ACC_DEPL_INTER	2019-11-29 15:00:00	2019-11-29 16:00:00	Entretien avec le Président de la Commission des Affaires étrangères du Parlement de la République d'Estonie
13327	04043D	ORG_POL	2019-10-21 08:30:00	2019-10-21 10:00:00	Bureau départemental
13328	04043D	ORG_POL	2019-10-22 11:00:00	2019-10-22 12:30:00	Réunion de groupe
11781	04043D	ELUS_LOCAUX	2019-05-27 13:00:00	2019-05-27 14:30:00	\N
11804	08010L	ORG_POL	2019-06-04 11:00:00	2019-06-04 12:30:00	Groupe LR du Sénat
11783	04043D	REU_TRAV_PARL	2019-05-27 11:00:00	2019-05-27 13:00:00	auditions proposition de loi "5G"
11784	04043D	REU_TRAV_PARL	2019-05-29 08:30:00	2019-05-29 09:30:00	\N
11886	04043D	REU_TRAV_PARL	2019-06-11 12:45:00	2019-06-11 14:00:00	déjeuner Google avec le DG de Google France, Sébastien Missoffe, sur le thème "Numérique au service de l'emploi" 
11884	04043D	ELUS_LOCAUX	2019-06-04 14:30:00	2019-06-04 15:30:00	réunion avec le Préfet du Val-de-Marne (thème :  l'extension des capacités scolaires de la commune d'Ablon-sur-Seine)
11885	04043D	ORG_POL	2019-06-06 14:00:00	2019-06-06 15:00:00	Réunion du groupe "Les Républicains"
11887	04043D	REU_TRAV_PARL	2019-06-12 12:45:00	2019-06-12 14:00:00	déjeuner Eric Lombard, Directeur général de la Caisse des dépôts et consignations +  les membres du Bureau de la commission des affaires économiques 
11888	04043D	REU_TRAV_PARL	2019-06-12 16:00:00	2019-06-12 17:30:00	\N
11889	04043D	DEPL_PRES_GVT	2019-06-12 17:00:00	2019-06-12 18:30:00	Visite SFR Altice
11901	04042C	ACC_DEPL_INTER	2019-06-11 08:30:00	2019-06-11 09:30:00	Rencontre avec un ministre marocain et l'Ambassadeur du Maroc en France
11902	04042C	ACC_VISIT	2019-06-11 10:00:00	2019-06-11 11:00:00	>Entretien avec un élu
11903	04042C	ORG_POL	2019-06-11 11:00:00	2019-06-11 12:00:00	Réunion du Groupe Les Républicains
11904	04042C	ACC_DEPL_INTER	2019-06-11 13:00:00	2019-06-11 14:00:00	Entretien avec l'Ambassadeur de Chypre en France
11908	04042C	ACC_DEPL_INTER	2019-06-12 11:50:00	2019-06-12 14:15:00	Entretien avec le Président du Sénat du Président du Sénat de Roumanie
11981	04042C	ACC_DEPL_INTER	2019-06-21 12:45:00	2019-06-21 14:30:00	Salon du Bourget - Réception en presence du Premier ministre
11907	04042C	CEREMONIE	2019-06-11 19:15:00	2019-06-11 20:15:00	Inauguration du Multi-accueil Simone Veil à Charenton-le-Pont
11983	04042C	REU_GVT	2019-06-20 17:00:00	2019-06-20 18:00:00	Rencontre avec le Directeur de Cabinet du Ministre de l'Europe et des Affaires étrangères
11910	04042C	ACC_DEPL_INTER	2019-06-12 15:50:00	2019-06-12 16:20:00	Entretien avec la Présidente de la Commission des Affaires étrangères du Kosovo
11911	04042C	ORG_POL	2019-06-12 16:30:00	2019-06-12 17:00:00	Réunion du Groupe Les Républicains
11912	04042C	CEREMONIE	2019-06-12 20:00:00	2019-06-12 21:30:00	Soirée anniversaire des 40 ans du GICAT avec Madame la Ministre des armées
11913	04042C	ACC_DEPL_INTER	2019-06-13 07:50:00	2019-06-13 09:00:00	Entretien avec le Président du Sénat du Président du Sénat de Côte d'Ivoire
11914	04042C	ACC_DEPL_INTER	2019-06-13 12:50:00	2019-06-13 14:45:00	Rencontre avec le Président du Sénat du President du Bundesrat et le President du Sénat de Pologne
11915	04042C	ACC_DEPL_INTER	2019-06-13 15:00:00	2019-06-13 15:45:00	Entretien avec le Président du Sénat du Président du Sénat du Cameroun
11916	04042C	ACC_DEPL_INTER	2019-06-13 16:00:00	2019-06-13 16:45:00	Entretien avec le Président du Sénat du Président du Sénat de la République du Congo-Brazaville
11917	04042C	ACC_DEPL_INTER	2019-06-13 17:00:00	2019-06-13 17:45:00	Entretien avec le Président du Sénat du Président du Sénat du Président par intérim du Conseil de la Nation d'Algérie
11918	04042C	ACC_DEPL_INTER	2019-06-13 18:00:00	2019-06-13 18:40:00	Entretien avec le Président du Sénat du Président du Sénat du Kenya
11919	04042C	ACC_DEPL_INTER	2019-06-13 19:00:00	2019-06-13 19:30:00	Réception à l'Ambassade britannique à l'occasion de l'anniversaire de sa Majesté la Reine Elisabeth II
11920	04042C	DEPL_PRES_GVT	2019-06-13 19:30:00	2019-06-13 20:15:00	Reception a l'occasion du Salon de l'Aéronautique et de l'Espace 
11921	04042C	ACC_DEPL_INTER	2019-06-13 20:20:00	2019-06-13 22:00:00	Rencontre avec le Président du Senat de Madame la Présidente du Sénat italien
11982	04042C	ACC_DEPL_INTER	2019-06-20 16:00:00	2019-06-20 17:00:00	Entretien avec l'Ambassadeur de la République bolivarienne du Venezuela
11923	04042C	ORG_POL	2019-06-06 14:00:00	2019-06-06 15:00:00	\N
11924	04042C	ACC_VISIT	2019-06-06 16:00:00	2019-06-06 16:05:00	Interview Public Senat
11925	04042C	ELUS_LOCAUX	2019-06-06 16:45:00	2019-06-06 17:45:00	\N
11926	04042C	ELUS_LOCAUX	2019-06-06 20:00:00	2019-06-06 22:00:00	Rencontre avec des élus du Val-de-Marne
12061	08010L	CEREMONIE	2019-06-26 11:30:00	2019-06-26 12:30:00	Fête nationale Américaine 
12062	08010L	REU_TRAV_PARL	2019-06-26 16:00:00	2019-06-26 16:30:00	GIA F/RFA
12081	04042C	REU_TRAV_PARL	2019-06-26 08:30:00	2019-06-26 09:30:00	Réunion de trvail du GIA France-Maroc
12082	04042C	ACC_DEPL_INTER	2019-06-26 18:00:00	2019-06-26 19:00:00	Rencontre avec le Président du Sénat des auditeurs de l'IHEDN
12083	04042C	CEREMONIE	2019-06-26 19:30:00	2019-06-26 20:30:00	Réception pour les 70 ans de Chez Françoise
12084	04042C	DEPL_PRES_GVT	2019-06-27 00:00:00	2019-06-27 00:00:00	Mission officielle à Chypre
12085	04042C	DEPL_PRES_GVT	2019-06-28 00:00:00	2019-06-28 00:00:00	Mission officielle à Chypre
12088	04042C	COLLOQUE	2019-06-26 12:30:00	2019-06-26 13:30:00	Rencontre avec Hadja Idrissa BAH, Présidente du Parlement des Enfants de Guinée et Présidente du Club des Jeunes Filles Leader de Guinée
12174	04043D	ORG_POL	2019-07-09 19:30:00	2019-07-09 21:00:00	CNI
12241	01025N	REU_TRAV_PARL	2019-07-09 08:30:00	2019-07-09 14:00:00	séminaire de travail groupe Union centriste
12175	14041T	ELUS_LOCAUX	2019-06-19 09:00:00	2019-06-19 18:00:00	déplacement à Madrid
12682	04042C	ACC_VISIT	2019-10-07 07:00:00	2019-10-07 07:30:00	Direct RMC Jean-Jacques BOURDIN
12177	14041T	ELUS_LOCAUX	2019-06-18 14:00:00	2019-06-18 22:00:00	déplacement à Madrid
12181	01058X	REU_TRAV_PARL	2019-07-09 00:00:00	2019-07-09 00:00:00	Groupe de suivi négociations commerciales
12683	04042C	ACC_VISIT	2019-10-07 11:50:00	2019-10-07 12:30:00	Direct France Info TV
12681	04042C	ACC_VISIT	2019-10-07 05:10:00	2019-10-07 05:30:00	Interview France Info
12684	04042C	ACC_VISIT	2019-10-07 12:30:00	2019-10-07 13:00:00	Enregistrement plateau de France Infi TV
12685	04042C	ACC_VISIT	2019-10-07 13:00:00	2019-10-07 13:15:00	Interviex téléphonique Le Figaro
12686	04042C	ACC_VISIT	2019-10-07 15:30:00	2019-10-07 15:45:00	Interview M6
12687	04042C	ACC_VISIT	2019-10-07 15:45:00	2019-10-07 16:00:00	Interview téphonique Europe 1
12688	04042C	REU_TRAV_PARL	2019-10-07 16:00:00	2019-10-07 17:00:00	Réunion de direction
12689	04042C	ACC_VISIT	2019-10-07 17:10:00	2019-10-07 17:30:00	Interview en Duplex BFM Story
12691	04042C	ACC_VISIT	2019-10-07 18:00:00	2019-10-07 18:30:00	Interview Public Sénat
12692	04042C	ACC_VISIT	2019-10-07 18:45:00	2019-10-07 19:00:00	Interviw téléphonique RTL
12693	04042C	ACC_VISIT	2019-10-08 08:20:00	2019-10-08 08:30:00	Direct interview BFM TV
12694	04042C	REU_TRAV_PARL	2019-10-08 08:30:00	2019-10-08 10:00:00	Audition par la Délégation Parlementaire au Renseignement du Minitre de l'Intérieur
12695	04042C	CEREMONIE	2019-10-08 10:30:00	2019-10-08 12:30:00	Hommage aux 4 victimes de l'attaque à la Préfecture de Police de Paris en présence du Président de la République
12696	04042C	ACC_VISIT	2019-10-08 13:00:00	2019-10-08 14:15:00	\N
12697	04042C	ACC_VISIT	2019-10-08 15:00:00	2019-10-08 15:30:00	Interview ITW Al Arabia
12701	04042C	ACC_VISIT	2019-10-08 16:45:00	2019-10-08 17:00:00	Interview téléphonique Libération
12699	04042C	ACC_VISIT	2019-10-08 16:40:00	2019-10-08 16:45:00	 Interview Public Sénat
12700	04042C	ACC_VISIT	2019-10-08 15:30:00	2019-10-08 16:30:00	Entretien Directeur de Tracfin
12702	04042C	ACC_VISIT	2019-10-08 20:30:00	2019-10-08 21:15:00	Emission LCI
12703	04042C	ACC_VISIT	2019-10-08 22:00:00	2019-10-08 22:15:00	Emission BFM TV
12704	04042C	REU_TRAV_PARL	2019-10-09 17:30:00	2019-10-09 18:30:00	Réunion AP/OTAN
12774	04042C	CEREMONIE	2019-10-15 11:00:00	2019-10-15 12:00:00	Cérémonie militaire d'adieu aux armes du Directeur de la Gendarmerie nationale
12782	08010L	ORG_POL	2019-10-15 11:00:00	2019-10-15 13:00:00	Groupe LR du Sénat
12784	04042C	REU_TRAV_PARL	2019-10-16 08:00:00	2019-10-16 09:00:00	Réunion des Présidents des commissions du Sénat 
12785	04042C	ACC_VISIT	2019-10-16 14:30:00	2019-10-16 15:00:00	Conférence de presse sur la Turquie
12786	04042C	ACC_DEPL_INTER	2019-10-16 16:00:00	2019-10-16 17:00:00	Rencontre avec une Délégation de députés arméniens
12787	04042C	ACC_VISIT	2019-10-16 18:00:00	2019-10-16 18:30:00	Interview Public Sénat
12861	04042C	ORG_POL	2019-10-21 08:30:00	2019-10-21 10:00:00	Réunion de bureau du Comité départemental LR94
11881	04043D	DEPL_PRES_GVT	2019-06-03 09:30:00	2019-06-03 12:30:00	visite de L'Oréal-Chevilly-Larue
11882	04043D	REU_TRAV_PARL	2019-06-03 15:30:00	2019-06-03 17:00:00	Auditions PPL 5G
11967	08010L	ACC_VISIT	2019-06-20 12:30:00	2019-06-20 15:00:00	Elus du Saint-quentinois
12001	08009T	REU_TRAV_PARL	2019-05-14 09:30:00	2019-05-14 10:00:00	\N
12002	08009T	REU_TRAV_PARL	2019-05-14 10:00:00	2019-05-14 11:00:00	\N
12003	08009T	COLL_TER	2019-05-14 14:00:00	2019-05-14 16:00:00	\N
12004	08009T	REU_TRAV_PARL	2019-05-14 18:30:00	2019-05-14 19:30:00	\N
12020	08009T	ORG_POL	2019-06-12 17:00:00	2019-06-12 18:00:00	\N
12021	08009T	REU_TRAV_PARL	2019-06-13 08:30:00	2019-06-13 09:30:00	\N
12022	08009T	ACC_DEPL_INTER	2019-06-13 17:50:00	2019-06-13 18:45:00	\N
12023	08009T	REU_TRAV_PARL	2019-06-18 09:00:00	2019-06-18 10:00:00	\N
12024	08009T	ORG_POL	2019-06-18 11:00:00	2019-06-18 12:30:00	\N
12137	04042C	ACC_VISIT	2019-07-05 08:40:00	2019-07-05 09:00:00	Emission Public Sénat
12138	04042C	COLL_TER	2019-07-05 09:00:00	2019-07-05 11:30:00	Réuion du bureau du Syndicat des Eaux d'Ile-de-France
12221	04043D	REU_TRAV_PARL	2019-07-11 10:00:00	2019-07-11 11:30:00	Audition de Sabine Atlouai
12140	04042C	REU_TRAV_PARL	2019-07-05 11:45:00	2019-07-05 12:30:00	Entretien avec le Chef d'état-major des armées et le président de la commission de Défense nationale et des Forces armées de l'Assemblée Nationale pour le lancement des Universités d'Eté de Défense
12141	04042C	CEREMONIE	2019-07-05 12:30:00	2019-07-05 14:30:00	Lancement des Universités d'Eté de la Défense
12222	04043D	DEPL_PRES_GVT	2019-07-11 14:30:00	2019-07-11 16:30:00	Visite d'une entreprise dans le Val-de-Marne
12223	04043D	ACC_VISIT	2019-07-15 15:00:00	2019-07-15 16:15:00	médecin chef de l¿hôpital militaire de Bégin
12261	08010L	ORG_POL	2019-07-23 11:00:00	2019-07-23 13:00:00	Groupe LR du Sénat
12262	04086Q	ORG_POL	2019-07-16 11:00:00	2019-07-16 12:30:00	Réunion du groupe LR
12263	04086Q	ACC_DEPL_INTER	2019-07-16 12:30:00	2019-07-16 14:00:00	Réception en remerciement de la participation aux Sénats d'Europe 
12264	04086Q	DEL_ACT_PAR	2019-07-17 16:00:00	2019-07-17 18:00:00	Rendez-vous de travail 
12265	04086Q	ORG_POL	2019-07-23 11:00:00	2019-07-23 12:30:00	Réunion du groupe LR
12266	04043D	ELUS_LOCAUX	2019-07-11 00:00:00	2019-07-11 00:00:00	Inauguration officielle de l'Installation Terminal Embranché de Villiers-sur-Marne 
12267	04043D	ORG_POL	2019-07-16 11:00:00	2019-07-16 12:30:00	Réunion de groupe LR
12268	04043D	ORG_POL	2019-07-16 13:00:00	2019-07-16 14:30:00	Déjeuner de groupe LR
12269	04043D	ACC_VISIT	2019-07-16 14:30:00	2019-07-16 15:30:00	Réunion avec le DG Île-de-France SFR/Altice
12270	04043D	ORGEXTPAR	2019-07-17 20:00:00	2019-07-17 22:00:00	Diner avec la présidente d'Air France
12271	04043D	ACC_VISIT	2019-07-19 14:00:00	2019-07-19 15:30:00	les aînés de Villeneuve-le-Roi
12272	04043D	ACC_VISIT	2019-07-22 15:00:00	2019-07-22 16:00:00	Bernard Gobitz président de la FNAUT
12345	04042C	REU_TRAV_PARL	2019-08-28 12:30:00	2019-08-28 14:00:00	Rencontre avec le nouveau chef d'état-major de l'armée de terre
12342	04042C	ACC_VISIT	2019-08-27 15:00:00	2019-08-27 16:00:00	Entretien avec un élu du Val-de-Marne
12343	04042C	ACC_DEPL_INTER	2019-08-27 20:30:00	2019-08-27 22:30:00	Conférence des Ambassadeurs et des Ambassadrices : réception de Madame la Ministre des armées
12344	04042C	ACC_DEPL_INTER	2019-08-27 11:00:00	2019-08-27 13:30:00	Conférence des Ambassadeurs et des Ambassadrices : Allocution du Président de la République
12346	04042C	ACC_DEPL_INTER	2019-08-28 18:00:00	2019-08-28 19:00:00	Conférence des Ambassadeurs et des Ambassadrices : Allocution du Premier ministre
12421	04042C	COLL_TER	2019-09-11 13:00:00	2019-09-11 14:15:00	rencontre avec le Président du Syndicat des Eaux d'Ile-de-France
12422	04042C	ACC_DEPL_INTER	2019-09-11 16:30:00	2019-09-11 17:30:00	Entretien avec L'Ambassadrice de Grèce en France
12423	04042C	ACC_DEPL_INTER	2019-09-11 17:30:00	2019-09-11 18:30:00	Entretien avec l'Ambassadeur de la République Bolivarienne du Venezuela en France
12424	04042C	REU_TRAV_PARL	2019-09-11 19:30:00	2019-09-11 22:00:00	Débat La Defense de l'Europe face au choc des titans 
12521	01058X	REU_TRAV_PARL	2019-09-25 17:00:00	2019-09-25 18:00:00	Groupe de suivi CETA
12522	01058X	REU_TRAV_PARL	2019-09-26 08:30:00	2019-09-26 09:30:00	Groupe de suivi CETA
12523	01058X	REU_TRAV_PARL	2019-09-24 15:45:00	2019-09-24 16:45:00	Décentralisation
12524	04042C	ORG_POL	2019-09-24 21:00:00	2019-09-24 22:30:00	Réunion des adhérents du Val-de-Marne en présence du Président L.R du Groupe LR de l'Assemblée nationale
12525	04042C	ACC_DEPL_INTER	2019-09-25 10:00:00	2019-09-25 11:00:00	Entretien avec le Secrétaire Général de la lignue islamique mondiale
12526	04042C	ACC_DEPL_INTER	2019-09-25 11:00:00	2019-09-25 12:00:00	Entretien avec l'Ambassadeur de la Libye en France
12527	04042C	REU_TRAV_PARL	2019-09-25 12:00:00	2019-09-25 13:00:00	Entretien avec un Conseiller diplomatique du Sénat
12528	04042C	REU_GVT	2019-09-25 17:00:00	2019-09-25 18:15:00	Réunion de travail avec la Ministre des armées
12529	04042C	ACC_DEPL_INTER	2019-09-25 19:00:00	2019-09-25 20:30:00	Réception à l'occasion du 70ème anniversaire de la Fondation de la République populaire de Chine et prise de fonction du nouvel Ambassadeur
12530	04042C	ACC_VISIT	2019-09-26 17:30:00	2019-09-26 18:00:00	Interview Public Sénat
12531	04042C	ELUS_LOCAUX	2019-09-26 20:30:00	2019-09-26 22:30:00	Réunion du Conseil municipal de Saint-Maurice
12788	01058X	REU_TRAV_PARL	2019-10-10 09:30:00	2019-10-10 13:30:00	Conseil d'administration de l'ANDRA
12862	04042C	ACC_VISIT	2019-10-21 11:00:00	2019-10-21 11:40:00	Interview Public Sénat
12863	04042C	ACC_DEPL_INTER	2019-10-21 13:00:00	2019-10-21 14:15:00	Rencontre avec Madame l'Ambassadrice de Suède
12864	04042C	ACC_DEPL_INTER	2019-10-21 15:30:00	2019-10-21 16:30:00	Entretien avec Monsieur l'Ambassadeur de Grande Bretagne
12865	04042C	REU_TRAV_PARL	2019-10-21 17:30:00	2019-10-21 18:30:00	Réunion de direction
12866	04042C	ACC_DEPL_INTER	2019-10-21 20:00:00	2019-10-21 22:30:00	Rencontre avec Monsieur l'Ambassadeur d'Australie
12867	04042C	ORG_POL	2019-10-22 10:00:00	2019-10-22 11:00:00	Réunion du bureau du Groupe L.R au Sénat
12868	04042C	ORG_POL	2019-10-22 11:00:00	2019-10-22 12:00:00	Réunion du Groupe L.R au Sénat
12869	04042C	ACC_DEPL_INTER	2019-10-22 12:30:00	2019-10-22 14:00:00	Rencontre avec Madame l'Ambassadrice du Canada à l'occasion des élections générales canadiennes
12870	04042C	ACC_DEPL_INTER	2019-10-22 14:45:00	2019-10-22 15:30:00	Entretien avec le Commandant suprême allié Transformation de l'OTAN
12871	04042C	CEREMONIE	2019-10-22 19:00:00	2019-10-22 20:00:00	Cérémonie de remise des insignes d'Officier dans l'Ordre National du Mérite à Madame l'Ambassadrice de France en Allemagne
12872	04018C	ELUS_LOCAUX	2019-10-29 14:00:00	2019-10-29 16:00:00	\N
13001	08010L	REU_TRAV_PARL	2019-10-30 16:30:00	2019-10-30 17:30:00	PLF 2020 art add 27 
12882	08010L	ORG_POL	2019-10-22 11:00:00	2019-10-22 12:30:00	Groupe LR du Sénat
13003	04018C	REU_TRAV_PARL	2019-10-30 17:30:00	2019-10-30 19:30:00	Auditions PLF Patrimoine
12884	04042C	ACC_VISIT	2019-10-23 13:00:00	2019-10-23 14:15:00	Entretien avec un élu
13064	04042C	ACC_VISIT	2019-11-07 17:00:00	2019-11-07 18:00:00	Entretien avec la Sous-préfète chargée de la politique de la ville
13084	04042C	DEPL_PRES_GVT	2019-11-11 10:30:00	2019-11-11 12:00:00	Cérémonie du 101ème anniversaire de l'armistice du 11 novembre 1918 à l'Arc de Triomphe en Présence du Président de la République
12901	08010L	REU_TRAV_PARL	2019-10-23 16:30:00	2019-10-23 17:30:00	Prévention Routière
13002	04018C	REU_TRAV_PARL	2019-10-30 08:00:00	2019-10-30 09:00:00	\N
13004	04018C	ELUS_LOCAUX	2019-11-06 20:00:00	2019-11-06 22:00:00	\N
13063	04042C	REU_TRAV_PARL	2019-11-07 16:00:00	2019-11-07 17:00:00	Réunion de Direction
13066	04042C	CEREMONIE	2019-11-07 18:30:00	2019-11-07 19:30:00	Cérémonie de remise des insignes de Chevalier dans l'Ordre national de la Légion d'honneur au Président du Conseil constitutionnel et ancien Premier ministre
13087	04042C	ORG_POL	2019-11-12 11:00:00	2019-11-12 12:00:00	Réunion de Groupe des Républicains au Sénat
11764	04042C	ACC_DEPL_INTER	2019-05-27 17:15:00	2019-05-27 18:15:00	Entretien avec une delegation de députés taïwanais
11768	04042C	REU_TRAV_PARL	2019-05-28 09:30:00	2019-05-28 10:15:00	Réunion de direction
11766	01025N	REU_TRAV_PARL	2019-05-22 14:00:00	2019-05-22 15:30:00	Audition Café LEGAL
11767	04042C	ACC_VISIT	2019-05-27 18:15:00	2019-05-27 19:15:00	Rendez-vous avec un élu
11769	04042C	REU_TRAV_PARL	2019-05-28 10:15:00	2019-05-28 11:00:00	Entretien avec la Secrétaire Générale de la SGDSN
11770	04042C	ORG_POL	2019-05-28 11:00:00	2019-05-28 12:30:00	Réunion du bureau du Groupe
11771	04042C	REU_TRAV_PARL	2019-05-28 13:00:00	2019-05-28 14:15:00	Groupe Interparlementaire d'Amitié France-Maroc
11772	04042C	ACC_DEPL_INTER	2019-05-24 16:00:00	2019-05-24 17:00:00	Visite de courtoisie du nouveau Consul général de France à Casablanca
11773	04042C	ACC_DEPL_INTER	2019-05-24 17:00:00	2019-05-24 18:00:00	Entretien avec le Vice-président de l'Assemblée parlementaire du Conseil de l'Europe
11865	04086Q	REU_TRAV_PARL	2019-05-15 13:15:00	2019-05-15 14:00:00	Reunion de travail 
11866	04086Q	CEREMONIE	2019-06-05 19:00:00	2019-06-05 21:00:00	Remise de l'ONM à Vincent TALVAS 
11803	08010L	REU_TRAV_PARL	2019-06-04 09:00:00	2019-06-04 11:00:00	Séminaire décentralisation
11867	04086Q	REU_TRAV_PARL	2019-06-06 16:00:00	2019-06-06 16:30:00	Reunion de travail pour le bureau du Sénat
12213	04042C	ACC_DEPL_INTER	2019-07-11 19:00:00	2019-07-11 20:00:00	Réception en l'honneur du Président de la Région Kurdistan-Irak à la Représentation du Gouvernement du Kurdistan-Irak en France 
12214	04042C	ACC_DEPL_INTER	2019-07-11 20:00:00	2019-07-11 21:00:00	Reception de l'Armée Suisse à l'occasion de la Fête Fédérale
12301	08009T	REU_TRAV_PARL	2019-06-25 17:45:00	2019-06-25 18:30:00	\N
12302	08009T	REU_GVT	2019-06-25 20:30:00	2019-06-25 22:00:00	\N
12303	08009T	REU_GVT	2019-06-26 19:00:00	2019-06-26 20:30:00	\N
12304	08009T	REU_TRAV_PARL	2019-06-26 15:30:00	2019-06-26 16:30:00	\N
12601	04042C	ACC_DEPL_INTER	2019-10-02 18:30:00	2019-10-02 19:00:00	Réception de S.E. l'Ambassadeur d'Allemagne et du Ministre Président adjoint à l'occasion de la journée de l'unité allemande
12602	04042C	ACC_DEPL_INTER	2019-10-02 19:15:00	2019-10-02 20:00:00	Réception à l'occasion d'une rencontre Sénat et Assemblée des français de l'étranger et Union interparlementaire
12603	04042C	ACC_DEPL_INTER	2019-10-02 20:30:00	2019-10-02 22:30:00	Rencontre avec l'Ambassadeur de la Hongrie
12809	04086Q	ACC_DEPL_INTER	2019-09-24 18:15:00	2019-09-24 19:30:00	Rencontre d'une délégation de parlementaires roumains
12807	04086Q	REU_TRAV_PARL	2019-09-17 14:00:00	2019-09-17 15:30:00	Réunion de travail adjoints aux affaires internationales 
12808	04086Q	REU_TRAV_PARL	2019-09-18 18:00:00	2019-09-18 20:00:00	AG de l'UIP
12810	04086Q	REU_TRAV_PARL	2019-09-25 08:30:00	2019-09-25 09:30:00	Réunion de travail avec Benoit Apparu 
12821	04086Q	ORG_POL	2019-10-08 11:00:00	2019-10-08 12:30:00	Réunion du groupe LR
12822	04086Q	COLL_TER	2019-10-11 08:30:00	2019-10-11 12:30:00	Conseil de Métropole à la MGP
12823	04042C	ACC_DEPL_INTER	2019-10-17 08:45:00	2019-10-17 09:45:00	Conférence du Club des Ambassadeurs avec Madame l'Ambassadrice de France en Russie
12824	04042C	DEPL_PRES_GVT	2019-10-17 18:45:00	2019-10-17 00:00:00	Mission officielle Marocaine
12921	08010L	ORG_POL	2019-10-29 11:00:00	2019-10-29 12:30:00	Groupe LR du Sénat
12942	08009T	REU_TRAV_PARL	2019-08-29 14:30:00	2019-08-29 15:30:00	\N
12943	08009T	REU_TRAV_PARL	2019-08-27 18:00:00	2019-08-27 19:00:00	\N
12944	08009T	REU_TRAV_PARL	2019-09-10 10:00:00	2019-09-10 11:00:00	\N
12945	08009T	REU_TRAV_PARL	2019-09-10 14:00:00	2019-09-10 15:00:00	\N
12946	08009T	REU_TRAV_PARL	2019-09-11 10:00:00	2019-09-11 11:00:00	\N
12947	08009T	REU_TRAV_PARL	2019-09-11 15:00:00	2019-09-11 15:30:00	\N
12949	08009T	REU_TRAV_PARL	2019-09-17 14:00:00	2019-09-17 15:00:00	\N
12950	08009T	REU_TRAV_PARL	2019-09-18 09:00:00	2019-09-18 10:30:00	\N
12951	08009T	REU_TRAV_PARL	2019-09-18 17:30:00	2019-09-18 18:00:00	\N
12952	08009T	REU_TRAV_PARL	2019-09-18 18:00:00	2019-09-18 19:30:00	\N
12953	08009T	REU_GVT	2019-09-18 19:30:00	2019-09-18 21:00:00	\N
12954	08009T	REU_TRAV_PARL	2019-09-24 08:30:00	2019-09-24 09:30:00	\N
12955	08009T	REU_TRAV_PARL	2019-09-24 10:00:00	2019-09-24 11:00:00	\N
12956	08009T	ORG_POL	2019-09-24 11:00:00	2019-09-24 12:30:00	\N
12957	08009T	ELUS_LOCAUX	2019-09-24 12:30:00	2019-09-24 14:00:00	\N
12958	08009T	REU_GVT	2019-09-24 14:00:00	2019-09-24 15:00:00	\N
12959	08009T	ORG_POL	2019-09-25 08:30:00	2019-09-25 09:30:00	\N
12960	08009T	REU_TRAV_PARL	2019-09-25 13:00:00	2019-09-25 14:30:00	\N
12961	08009T	REU_TRAV_PARL	2019-09-26 11:00:00	2019-09-26 12:00:00	\N
12962	08009T	ORG_POL	2019-10-01 10:00:00	2019-10-01 12:30:00	\N
12963	08009T	REU_GVT	2019-10-01 17:30:00	2019-10-01 18:30:00	\N
12964	08009T	REU_TRAV_PARL	2019-10-08 08:00:00	2019-10-08 09:00:00	\N
12965	08009T	ORG_POL	2019-10-08 11:00:00	2019-10-08 12:30:00	\N
12966	08009T	REU_TRAV_PARL	2019-10-09 08:00:00	2019-10-09 09:00:00	\N
12967	08009T	REU_TRAV_PARL	2019-10-09 10:50:00	2019-10-09 12:00:00	\N
12968	08009T	REU_TRAV_PARL	2019-10-09 12:00:00	2019-10-09 12:30:00	\N
12969	08009T	REU_TRAV_PARL	2019-10-09 14:00:00	2019-10-09 14:30:00	\N
12970	08009T	REU_GVT	2019-10-10 09:30:00	2019-10-10 10:30:00	\N
12971	08009T	ORG_POL	2019-10-15 11:00:00	2019-10-15 12:30:00	\N
12972	08009T	ORG_POL	2019-10-15 12:30:00	2019-10-15 14:00:00	\N
12977	08009T	REU_TRAV_PARL	2019-10-16 14:30:00	2019-10-16 15:30:00	\N
12979	08009T	ORGEXTPAR	2019-10-16 18:00:00	2019-10-16 20:00:00	\N
12975	08009T	REU_TRAV_PARL	2019-10-10 10:30:00	2019-10-10 11:30:00	\N
12976	08009T	REU_TRAV_PARL	2019-10-10 11:30:00	2019-10-10 12:30:00	\N
12978	08009T	REU_TRAV_PARL	2019-10-16 17:00:00	2019-10-16 18:00:00	\N
12980	08009T	ORG_POL	2019-10-22 11:00:00	2019-10-22 12:30:00	\N
12981	04042C	ACC_DEPL_INTER	2019-10-29 18:30:00	2019-10-29 19:15:00	Réception du Président du Sénat à l'occasion de la candidature de la France au Conseil Exécutif de l'UNESCO en présence de Madame l'Ambassadrice déléguée permanente auprès de l'UNESCO
12982	04042C	ACC_DEPL_INTER	2019-10-29 19:30:00	2019-10-29 20:30:00	Réception de l'Ambassadeur de Turquie en France à l'occasion du 96ème anniversaire de la proclamation de la République
12983	04042C	REU_TRAV_PARL	2019-10-30 14:00:00	2019-10-30 15:00:00	Réunion de direction
12984	04042C	ACC_DEPL_INTER	2019-10-30 12:45:00	2019-10-30 13:45:00	Rencontre avec l'Ambassadeur de Chypre en France
12985	04086Q	COLLOQUE	2019-10-21 14:00:00	2019-10-21 17:00:00	Colloque sur le logement social et la décentralisation
12991	04086Q	ORG_POL	2019-10-29 11:00:00	2019-10-29 12:30:00	Réunion du groupe LR
12992	04086Q	ORG_POL	2019-10-22 11:00:00	2019-10-22 12:30:00	Réunion du groupe LR
12993	04086Q	ORG_POL	2019-10-29 13:15:00	2019-10-29 14:30:00	Rendez-vous de LR
13041	08010L	ORG_POL	2019-11-05 11:00:00	2019-11-05 12:30:00	Groupe LR du Sénat
13090	04042C	ACC_DEPL_INTER	2019-11-12 18:30:00	2019-11-12 19:30:00	Entretien avec le Président du  Sénat du Président du Comité international de la Croix-Rouge 
13144	04086Q	REU_TRAV_PARL	2019-11-12 09:00:00	2019-11-12 10:00:00	Audition Rapport Logement 
13044	04042C	REU_TRAV_PARL	2019-11-06 12:30:00	2019-11-06 13:45:00	Rencontre avec l'Inspecteur général des armées
13045	04042C	ACC_DEPL_INTER	2019-11-06 18:00:00	2019-11-06 19:00:00	Entretien avec le Directeur général de la CCI Franco-Russe
13088	04042C	CEREMONIE	2019-11-12 12:15:00	2019-11-12 12:30:00	Cérémonie en hommage aux Sénateurs et fonctionnaires morts pour la France au Sénat
13089	04042C	REU_TRAV_PARL	2019-11-12 17:30:00	2019-11-12 18:15:00	Entretien avec deux senateurs
13160	04042C	DEPL_PRES_GVT	2019-10-24 00:00:00	2019-10-24 00:00:00	Conference des Présidents des parlements de l'UE avec le Président du Sénat 
13143	04086Q	COLL_TER	2019-11-08 15:00:00	2019-11-08 16:30:00	Réunion Seine-Saint-Denis
13145	04086Q	ORG_POL	2019-11-12 11:00:00	2019-11-12 12:30:00	Réunion du groupe LR
13146	04086Q	REU_TRAV_PARL	2019-11-12 13:45:00	2019-11-12 14:30:00	Réunion Budget LR
13161	04042C	DEPL_PRES_GVT	2019-10-25 00:00:00	2019-10-25 00:00:00	Conference des Présidents des parlements de l'UE avec le Président du Sénat
13148	04086Q	CEREMONIE	2019-11-14 10:30:00	2019-11-14 11:30:00	Représentation de G. Larcher à la messe en mémoire des fonctionnaires de police morts pendant le service. 
13159	04042C	ACC_VISIT	2019-11-08 09:40:00	2019-11-08 11:10:00	Visite guidée des élèves de CM2 de Choisy-le-Roi
13162	04042C	ACC_DEPL_INTER	2019-11-13 17:00:00	2019-11-13 18:00:00	Entretien avec le Président des Affaires étrangères de la Douma
13281	08010L	ORG_POL	2019-11-26 11:00:00	2019-11-26 12:30:00	Groupe LR du Sénat
13282	04042C	REU_TRAV_PARL	2019-11-26 10:00:00	2019-11-26 11:00:00	Réunion de travail à la Présidence du Sénat
13283	04042C	ORG_POL	2019-11-26 11:00:00	2019-11-26 12:00:00	Réunion de Groupe des L.R au Sénat
13287	04042C	ACC_VISIT	2019-11-26 18:00:00	2019-11-26 18:20:00	Interview RTL
13285	04042C	ACC_VISIT	2019-11-26 14:45:00	2019-11-26 15:15:00	Interview LCI/TF1
13286	04042C	ACC_VISIT	2019-11-26 13:30:00	2019-11-26 14:00:00	Interview France Info
11841	08010L	ACC_VISIT	2019-06-06 11:00:00	2019-06-06 15:00:00	maires du sud de l'Aisne
11959	04018C	ORGEXTPAR	2019-07-04 10:00:00	2019-07-04 17:00:00	Commission supérieure des sites, perspectives et paysages
12041	08010L	ORG_POL	2019-06-25 00:00:00	2019-06-25 00:00:00	Groupe LR du Sénat
12042	04042C	ELUS_LOCAUX	2019-06-24 18:30:00	2019-06-24 19:30:00	Réunion Intergroupe à la Mairie de Saint-Maurice
12043	04042C	ELUS_LOCAUX	2019-06-24 20:30:00	2019-06-24 22:30:00	Conseil Muicipal de Saint-Maurice
12044	04042C	ORG_POL	2019-06-25 11:00:00	2019-06-25 12:30:00	Réunion du Groupe Les Républicains
12045	04042C	REU_TRAV_PARL	2019-06-25 15:30:00	2019-06-25 16:45:00	Réunion de Direction
12046	04042C	ACC_DEPL_INTER	2019-06-25 19:00:00	2019-06-25 19:30:00	Réception à l'occasion de la fin de mission de l'Ambassadeur de la République populaire de Chine
12047	04042C	CEREMONIE	2019-06-25 19:30:00	2019-06-25 00:00:00	Soirée à l'occasion de la réouverture du Théatre impérial du Château de Fontainebleau
12050	04086Q	ACC_DEPL_INTER	2019-06-13 07:30:00	2019-06-13 09:00:00	Sénat d'Europe : Petit déjeuner Côte d'Ivoire
12051	04086Q	ACC_DEPL_INTER	2019-06-13 12:30:00	2019-06-13 14:30:00	Déjeuner de travail avec le président du Bundesrat et le Maréchal du Sénat de Pologne / Sénats d'Europe
12052	04086Q	ACC_DEPL_INTER	2019-06-13 19:00:00	2019-06-13 20:00:00	Réception pour les Sénats d'Europe 
12053	04086Q	ACC_DEPL_INTER	2019-06-13 20:30:00	2019-06-13 22:30:00	Diner avec la présidente du Sénat italien 
12101	04043D	COLL_TER	2019-06-27 09:00:00	2019-06-27 11:00:00	visite de l'école de chiens guides d'aveugles du Val-de-Marne
12102	04043D	ACC_VISIT	2019-06-27 17:00:00	2019-06-27 19:00:00	Visite du Groupe Entr'elles
12103	04043D	ORGEXTPAR	2019-06-28 09:00:00	2019-06-28 11:00:00	Conseil de Surveillance des Hôpitaux de Saint-Maurice
12242	01025N	ACC_VISIT	2019-07-17 14:00:00	2019-07-17 14:30:00	Jeunes Sapeurs-Pompiers de Ste-Ménehould
12104	04043D	ACC_VISIT	2019-07-01 14:00:00	2019-07-01 15:00:00	Deniz POY-directeur de mission à la direction des relations territoriales à la Société du Grand Paris 
12162	04043D	ORG_POL	2019-07-08 19:00:00	2019-07-08 21:00:00	Comité départemental Les Républicains du Val-de-Marne
12166	04043D	REU_TRAV_PARL	2019-07-02 17:00:00	2019-07-02 18:00:00	Réunion du groupe d'amitié France Indonésie
12167	04043D	REU_TRAV_PARL	2019-07-03 15:30:00	2019-07-03 17:00:00	Groupe d'amitié France-Etats Unis
12381	04042C	REU_TRAV_PARL	2019-09-05 15:00:00	2019-09-05 15:45:00	Entretien avec un sénateur
12382	04042C	REU_GVT	2019-09-05 17:15:00	2019-09-05 18:15:00	Entretien avec le Ministre de l'Europe et des Affaires étrangères
12383	04042C	ACC_VISIT	2019-09-06 09:40:00	2019-09-06 11:30:00	Visite guidée de jeunes issus des associations de Villejuif
12581	04042C	CEREMONIE	2019-09-30 18:30:00	2019-09-30 19:30:00	Vernissage de l'Exposition Raymond DEPARDON au Musée du service de santé des armées en présence de la secrétaire d'état auprès de la Minsitre des armées
12582	04042C	ORG_POL	2019-10-01 11:00:00	2019-10-01 12:30:00	Réunion de groupe des Républicains
12583	04042C	REU_TRAV_PARL	2019-10-01 13:00:00	2019-10-01 14:30:00	Réunion de trvail avec le Président LR du Sénat et les présidents des commissions
12584	04042C	ACC_DEPL_INTER	2019-10-01 15:30:00	2019-10-01 16:30:00	Entretien avec l'Ambassadeur de Cuba en France
12585	04042C	ELUS_LOCAUX	2019-10-01 16:30:00	2019-10-01 18:00:00	Entretiens avec des élus du Val-de-Marne
12586	08010L	ORG_POL	2019-09-24 11:00:00	2019-09-24 13:00:00	Groupe LR du Sénat + F. Baroin
12587	08010L	CEREMONIE	2019-09-24 19:00:00	2019-09-24 21:00:00	GIA France-Roumanie
12588	08010L	REU_TRAV_PARL	2019-09-25 14:00:00	2019-09-25 15:00:00	PLF 2020/ Justice
12589	08010L	REU_TRAV_PARL	2019-09-26 09:30:00	2019-09-26 11:30:00	\N
12590	08010L	COLL_TER	2019-09-26 14:30:00	2019-09-26 16:00:00	EPHAD Crépy
12591	08010L	ORG_POL	2019-10-01 11:00:00	2019-10-01 13:00:00	Groupe LR du Sénat + M. BARNIER
12592	08010L	ACC_VISIT	2019-10-01 16:30:00	2019-10-01 17:00:00	etudiants de Paris-Dauphine
13023	04042C	ACC_DEPL_INTER	2019-10-23 17:30:00	2019-10-23 18:30:00	Antretien avec l'Ambassadeur de la République populaire de Chine
13021	04042C	ACC_VISIT	2019-10-07 17:30:00	2019-10-07 17:45:00	Interview téléphonique Radio Classique
13022	04042C	ACC_DEPL_INTER	2019-10-23 16:15:00	2019-10-23 17:15:00	Entretien avec une délégation de parlementaires saoudiens
13202	04042C	ORG_POL	2019-11-19 11:00:00	2019-11-19 12:00:00	Réunion de Groupe des L.R au Sénat
13025	04042C	ELUS_LOCAUX	2019-11-04 16:30:00	2019-11-04 17:30:00	Inauguration des travaux du CCAS de Saint-Maurice
13026	04042C	ACC_DEPL_INTER	2019-11-04 18:30:00	2019-11-04 20:30:00	Réception à l'occasion de la Fête de l'Unité Nationale et des Armées italiennes à l'Ambassade d'Italie
13205	04042C	REU_TRAV_PARL	2019-11-19 16:15:00	2019-11-19 16:45:00	Réunion de Direction
13203	04042C	REU_GVT	2019-11-19 08:00:00	2019-11-19 09:00:00	Réunion de travail avec le Ministre de l'Europe et des affaires étrangères
13204	04042C	ACC_VISIT	2019-11-19 13:00:00	2019-11-19 14:30:00	Rencontre Val-de-Marne
13288	04042C	CEREMONIE	2019-11-26 18:30:00	2019-11-26 19:30:00	Ravivage de la Flamme sous l'Arc de Triomphe en soutien à nos militaires et leurs proches
13301	04042C	ACC_VISIT	2019-11-27 07:30:00	2019-11-27 08:00:00	Interview RFI en direct
13302	04042C	ACC_VISIT	2019-11-27 08:20:00	2019-11-27 09:00:00	Interview Emission LCI
13303	04042C	ACC_VISIT	2019-11-27 16:30:00	2019-11-27 17:00:00	Interview Public Sénat
13329	04043D	COLL_TER	2019-10-25 10:00:00	2019-10-25 11:00:00	Commission départementale des valeurs locatives
13330	04043D	ORG_POL	2019-10-29 11:00:00	2019-10-29 12:00:00	Réunion de groupe
13331	04043D	ORG_POL	2019-10-29 18:00:00	2019-10-29 20:00:00	CNI LR
13332	04043D	ORG_POL	2019-11-05 11:00:00	2019-11-05 12:00:00	Réunion de groupe
13333	04043D	ACC_DEPL_INTER	2019-11-06 08:30:00	2019-11-06 10:00:00	Petit-Déjeuner groupe d'amitié France-Etats Unis
13334	04043D	ACC_VISIT	2019-11-06 16:00:00	2019-11-06 17:30:00	CMJ de Marollesen brie
13335	04043D	ORG_POL	2019-11-06 18:00:00	2019-11-06 20:00:00	CNI LR
13336	04043D	ORG_POL	2019-11-12 18:00:00	2019-11-12 19:30:00	CNI LR
13337	04043D	ACC_VISIT	2019-11-12 19:30:00	2019-11-12 22:00:00	Diner des élus de Vincennes
13338	04043D	DEPL_PRES_GVT	2019-11-14 09:00:00	2019-11-14 11:30:00	Visite d'une entreprise du Val-de-Marne
13339	04043D	ORG_POL	2019-11-19 11:00:00	2019-11-19 12:00:00	Réunion de groupe
13340	04043D	ORG_POL	2019-11-20 19:30:00	2019-11-20 21:00:00	Comité départemental
13344	04043D	ORG_POL	2019-11-26 18:00:00	2019-11-26 20:00:00	CNI LR
13342	04043D	COLL_TER	2019-11-22 10:00:00	2019-11-22 11:00:00	Préfecture du Val de Marne - Réunion relative à la police de sécurité du quotidien
13343	04043D	ORG_POL	2019-11-26 11:00:00	2019-11-26 12:30:00	Réunion de groupe
13345	04043D	ORG_POL	2019-11-27 17:30:00	2019-11-27 19:00:00	CNI LR
13346	04043D	ORG_POL	2019-11-28 13:00:00	2019-11-28 14:30:00	Déjeuner politique
13381	04018C	REU_GVT	2019-12-04 18:30:00	2019-12-04 20:30:00	Ministère Culture
13382	04018C	ELUS_LOCAUX	2019-12-05 20:30:00	2019-12-05 22:30:00	pjl engagement & proximité
13434	04042C	CEREMONIE	2019-12-12 19:30:00	2019-12-12 20:30:00	Cérémonie de remise des insignes de la Légion d'Honneur au Ministère de l'Europe et des Affaires étrangères 
13482	08010L	REU_TRAV_PARL	2019-12-18 11:00:00	2019-12-18 13:00:00	Commission des finances 
13484	04042C	REU_TRAV_PARL	2019-12-18 16:30:00	2019-12-18 17:30:00	ENtretien avec la Présidente de la Commission de la Défense de l'Assemblée nationale
13483	08010L	REU_TRAV_PARL	2019-12-18 13:00:00	2019-12-18 14:30:00	délégation territoriale 
13444	08010L	ELUS_LOCAUX	2019-12-12 18:00:00	2019-12-12 19:30:00	Conseil Communautaire
13528	04042C	ORG_POL	2020-01-07 11:00:00	2020-01-07 12:30:00	Réunion de Groupe des L.R
13486	04042C	ACC_VISIT	2019-12-18 11:45:00	2019-12-18 12:30:00	Visite guidée du Conseil municipal des Jeunes de Thiais
13501	04086Q	ORG_POL	2019-12-17 11:00:00	2019-12-17 12:30:00	Réunion du groupe LR
13502	04086Q	ACC_DEPL_INTER	2019-12-17 12:30:00	2019-12-17 14:00:00	Déjeuner de travail avec le groupe d'amitié France-Jordanie
13503	04086Q	REU_TRAV_PARL	2019-12-18 13:00:00	2019-12-18 14:00:00	Déjeuner de travail avec la délégation aux collectivités territoriales
13521	08010L	ORG_POL	2020-01-07 11:00:00	2020-01-07 12:30:00	Groupe LR du Sénat
13526	04042C	ACC_DEPL_INTER	2019-12-18 17:30:00	2019-12-18 18:30:00	Entretien avec Monsieur l'Ambassadeur de la Libye 
13525	08010L	REU_GVT	2020-01-07 18:00:00	2020-01-07 20:00:00	Ministre Cohésion Territoires / PJL 3D
13527	04042C	CEREMONIE	2020-01-06 19:30:00	2020-01-06 20:30:00	Cérémonie des Voeux de Charenton-le-Pont
13529	04042C	ACC_DEPL_INTER	2020-01-07 13:00:00	2020-01-07 14:15:00	Rencontre avec l'Ambassadeur de la République populaire de Chine
13530	04042C	CEREMONIE	2020-01-07 18:30:00	2020-01-07 19:30:00	Cérémonie des Voeux du Président de l'Hôtel du Département du Val-de-Marne
11868	04086Q	REU_TRAV_PARL	2019-06-11 13:15:00	2019-06-11 14:15:00	Rendez-vous de travail pour ses activités parlementaires 
12305	08009T	REU_TRAV_PARL	2019-06-25 14:00:00	2019-06-25 15:00:00	\N
12306	08009T	REU_TRAV_PARL	2019-06-27 11:30:00	2019-06-27 12:30:00	\N
12307	08009T	REU_GVT	2019-07-09 08:00:00	2019-07-09 09:00:00	\N
12308	08009T	REU_TRAV_PARL	2019-07-09 10:30:00	2019-07-09 11:30:00	\N
12309	08009T	ORG_POL	2019-07-09 11:30:00	2019-07-09 13:00:00	\N
12310	08009T	REU_GVT	2019-07-09 13:00:00	2019-07-09 14:30:00	\N
12311	08009T	REU_TRAV_PARL	2019-07-09 15:45:00	2019-07-09 16:45:00	\N
12312	08009T	REU_TRAV_PARL	2019-07-09 17:45:00	2019-07-09 18:15:00	\N
12313	08009T	REU_TRAV_PARL	2019-07-09 19:00:00	2019-07-09 20:00:00	\N
12314	08009T	REU_GVT	2019-07-09 20:00:00	2019-07-09 21:30:00	\N
12315	08009T	REU_TRAV_PARL	2019-07-10 11:30:00	2019-07-10 12:30:00	\N
12316	08009T	ELUS_LOCAUX	2019-07-10 12:30:00	2019-07-10 14:00:00	\N
12317	08009T	REU_TRAV_PARL	2019-07-10 15:00:00	2019-07-10 16:00:00	\N
12318	08009T	REU_TRAV_PARL	2019-07-10 19:30:00	2019-07-10 21:00:00	\N
12319	08009T	REU_TRAV_PARL	2019-07-11 11:00:00	2019-07-11 12:00:00	\N
12320	08009T	REU_TRAV_PARL	2019-07-11 13:00:00	2019-07-11 14:30:00	\N
12321	08009T	REU_GVT	2019-07-24 09:00:00	2019-07-24 10:00:00	\N
12322	08009T	REU_TRAV_PARL	2019-07-24 10:00:00	2019-07-24 11:00:00	\N
12323	08009T	REU_TRAV_PARL	2019-07-24 12:30:00	2019-07-24 13:00:00	\N
12324	08009T	REU_TRAV_PARL	2019-07-24 15:00:00	2019-07-24 16:00:00	\N
12401	04042C	ACC_DEPL_INTER	2019-09-09 18:30:00	2019-09-09 20:30:00	Réception à l'occasion de la Fête Nationale de la République de Macédoine en présence du Ministre des Affaires étrangères
12405	04042C	ACC_VISIT	2019-09-10 18:00:00	2019-09-10 18:30:00	Interview du Journal du Parlement
12403	04042C	DEPL_PRES_GVT	2019-09-10 14:00:00	2019-09-10 15:15:00	Visite Ateliers sans Frontières du Président de la Répubique à Bonneuil-sur-Marne
12404	04042C	ACC_DEPL_INTER	2019-09-10 17:00:00	2019-09-10 18:00:00	Entretien avec le 1er Vice-président du Comité pour les Relations internationales de la Fédération de Russie
12406	04042C	REU_TRAV_PARL	2019-09-10 19:00:00	2019-09-10 20:00:00	Reunion avec le Président des Républicains de l'Assemblée nationale
12407	04042C	ACC_DEPL_INTER	2019-09-10 20:30:00	2019-09-10 22:30:00	Dîner officiel avec le Premier ministre malien au Ministère des l'Europe et des Affaires étrangères
12643	04043D	ACC_VISIT	2019-10-07 14:00:00	2019-10-07 15:00:00	rendez-vous avec la responsable de la RATP du Val-de-Marne
13028	01025N	REU_TRAV_PARL	2019-10-30 16:30:00	2019-10-30 18:30:00	Audition rapporteur PLF 2020
12644	04043D	COLL_TER	2019-10-07 10:00:00	2019-10-07 12:00:00	Réunion avec le Préfet du Val-de-Marne concernant la direction l'accueil des migrants
12661	08010L	ORG_POL	2019-10-08 11:30:00	2019-10-08 13:00:00	Groupe LR du Sénat
12802	04086Q	REU_TRAV_PARL	2019-09-10 12:00:00	2019-09-10 14:00:00	Déjeuner de travail Action Logement 
12722	04042C	ACC_DEPL_INTER	2019-10-10 11:45:00	2019-10-10 13:20:00	Rencontre avec le Ministre de la Défense de la Grèce
12723	04042C	ACC_DEPL_INTER	2019-10-10 13:30:00	2019-10-10 14:30:00	Clôture du Forum culturel franco-chinois en présence du Vice-président de l'Assemblée nationale de la République populaire de Chine au Ministère de l'Europe et des Affaires étrangères
12724	04042C	ACC_VISIT	2019-10-10 15:15:00	2019-10-10 15:30:00	Interview Public Sénat
12725	04042C	ACC_DEPL_INTER	2019-10-10 15:30:00	2019-10-10 16:30:00	Rencontre avec le ministre en charge des Affaires politiques de l'Ambassade du Japon
12726	04042C	ACC_VISIT	2019-10-10 16:30:00	2019-10-10 17:30:00	Entretien sur la réserve opérationnelle citoyenne
12727	04042C	COLL_TER	2019-10-10 18:00:00	2019-10-10 20:00:00	Convention Nationale France Territoire
12801	04086Q	COLLOQUE	2019-09-09 09:00:00	2019-09-09 12:30:00	Colloque sur le mécénat 
12803	04086Q	REU_TRAV_PARL	2019-09-11 14:00:00	2019-09-11 16:30:00	FFB, réunion sur l'investissement immobilier locatif neuf
12805	04086Q	REU_TRAV_PARL	2019-09-12 11:00:00	2019-09-12 12:30:00	Audition de Philippe DALLIER par la commission des lois sur le PJL engagement et proximité
12806	04086Q	ORG_POL	2019-09-16 00:00:00	2019-09-16 19:00:00	Journées parlementaires LR dimanche et lundi 
12811	04086Q	COLLOQUE	2019-09-25 13:45:00	2019-09-25 14:30:00	Congrès USH
12812	04086Q	COLL_TER	2019-09-25 16:30:00	2019-09-25 18:30:00	MGP, commission Habitat et Logement 
12813	04086Q	CEREMONIE	2019-09-25 19:00:00	2019-09-25 22:00:00	Réception Anniversaire de la République populaire de Chine 
12814	04086Q	ORG_POL	2019-09-26 09:00:00	2019-09-26 11:30:00	Réunion de travail LR
12815	04086Q	CEREMONIE	2019-09-30 11:00:00	2019-09-30 13:00:00	Hommage à Jacques Chirac à l'église Saint-Sulpice
12816	04086Q	ACC_DEPL_INTER	2019-10-02 08:30:00	2019-10-02 09:00:00	Prise de contact avec le nouveau ministre plénipotentiaire d'Israël Daniel Saada 
12817	04086Q	ACC_DEPL_INTER	2019-10-02 12:00:00	2019-10-02 14:00:00	Déjeuner de travail avec Mme Boisvert, délégué générale du Québec sur les enjeux communs entre le Québec et la France
12818	04086Q	REU_TRAV_PARL	2019-10-03 08:30:00	2019-10-03 10:00:00	Petit-déjeuner de travail du GIA France-Israël avec Mme l'ambassadrice d'Israël
12819	04086Q	ORG_POL	2019-10-07 15:00:00	2019-10-07 19:00:00	Réunion du groupe LR pour le budget à l'Assemblée Nationale 
12820	04086Q	ORG_POL	2019-10-01 11:00:00	2019-10-01 12:30:00	Réunion du groupe LR
13027	08010L	REU_TRAV_PARL	2019-11-05 08:30:00	2019-11-05 10:00:00	LR / PLF 2020
13029	04042C	REU_TRAV_PARL	2019-11-05 10:00:00	2019-11-05 11:00:00	Réunion des commissaires L.R de la Commission des Affaires étrangères, de la Défense et des Forces armées
13030	04042C	ORG_POL	2019-11-05 11:00:00	2019-11-05 12:30:00	Réunion deu Groupe L.R du Sénat
13035	04042C	ACC_VISIT	2019-11-05 17:30:00	2019-11-05 18:15:00	Interview Public Sénat sur le Brexit 
13032	04042C	REU_TRAV_PARL	2019-11-05 15:30:00	2019-11-05 16:30:00	Entretien avec le Directeur général du Groupe ADP
13033	04042C	ACC_DEPL_INTER	2019-11-05 13:00:00	2019-11-05 14:15:00	Rencontre avec le Conseiller pour les affaires religieuse du Ministère de l'Europe et des Affaires étrangères
13034	04042C	REU_TRAV_PARL	2019-11-05 16:30:00	2019-11-05 17:30:00	Entretien avec le Directeur des affaires politique et de sécurité du Ministère de l'Europe et des Affaires étrangères
13361	01025N	REU_TRAV_PARL	2019-11-06 08:00:00	2019-11-06 10:00:00	Rencontre FNSEA
13181	04042C	DEPL_PRES_GVT	2019-11-18 00:00:00	2019-11-18 00:00:00	Déplacement aux côtés du Premier ministre pour le Forum Paix et Sécurité et pour soutenir nos forces armées au Sénégal
13362	01025N	REU_TRAV_PARL	2019-11-20 13:30:00	2019-11-20 14:00:00	Fédération Entreprises de la Propreté
13363	01025N	ACC_VISIT	2019-11-26 13:45:00	2019-11-26 14:30:00	Entretien étudiant Normale Sup
13364	01025N	CEREMONIE	2019-11-26 14:30:00	2019-11-26 15:00:00	Hommage aux militaires morts au Mali
13365	01025N	REU_TRAV_PARL	2019-11-26 15:00:00	2019-11-26 16:30:00	PLF Agriculture / ppl suicides des agriculteurs
13366	01025N	REU_TRAV_PARL	2019-11-26 17:00:00	2019-11-26 18:00:00	Affaires éco/groupe UC
13367	01025N	REU_TRAV_PARL	2019-11-26 18:00:00	2019-11-26 20:00:00	Séance
13383	04018C	REU_TRAV_PARL	2019-12-10 17:15:00	2019-12-10 18:15:00	\N
13384	08010L	ORG_POL	2019-12-03 11:00:00	2019-12-03 12:30:00	Groupe LR du Sénat
13461	08010L	CEREMONIE	2019-12-11 18:30:00	2019-12-11 20:00:00	Ambassade des Etats-Unis
13462	08010L	ORG_POL	2019-12-17 11:00:00	2019-12-17 12:30:00	Groupe LR du Sénat + Damien ABAD
13463	08010L	ORG_POL	2019-12-10 11:00:00	2019-12-10 13:00:00	Groupe LR du Sénat + Jean LEONETTI : PJL Bioéthique
13464	01025N	REU_TRAV_PARL	2019-12-04 13:30:00	2019-12-04 14:30:00	IFAW - Protection des animaux sauvages
13465	01025N	REU_TRAV_PARL	2019-12-10 09:30:00	2019-12-10 11:00:00	Audition FNSAFER
13466	04042C	ELUS_LOCAUX	2019-12-16 13:00:00	2019-12-16 14:15:00	Rencontre avec un élu du Val-de-Marne
13467	04042C	ACC_DEPL_INTER	2019-12-16 17:00:00	2019-12-16 18:30:00	Réception à l'Ambassade de Chine à l'occasion du 20ème anniversaire de la rétrocession de Macao à la Chine
13468	04042C	ACC_DEPL_INTER	2019-12-16 18:50:00	2019-12-16 21:15:00	Entretien avec le Président du Sénat du Président du Sénat de la Jordanie
13472	04042C	ORG_POL	2019-12-17 11:00:00	2019-12-17 12:00:00	Réunion de Gropue des L.R du Sénat
13473	04042C	REU_TRAV_PARL	2019-12-17 19:30:00	2019-12-17 20:30:00	Forum prospective Défense
13471	04042C	REU_TRAV_PARL	2019-12-17 12:30:00	2019-12-17 14:30:00	Rencontre de la Grande Chancellerie de la Légion d'Honneur avec les membres de Sénateurs de la Commission des Affaires étrangères, de la Défense et des Forces armées
13474	04042C	CEREMONIE	2019-12-17 21:00:00	2019-12-17 23:30:00	Cérémonie des  Voeux du Syndicat des Eaux d'Ile-de-France
11861	08010L	ORG_POL	2019-06-11 11:00:00	2019-06-11 12:30:00	Groupe LR du Sénat
11862	08010L	REU_TRAV_PARL	2019-06-11 12:30:00	2019-06-11 14:00:00	Délégation territoriale 
11863	01025N	REU_TRAV_PARL	2019-06-06 14:00:00	2019-06-06 15:00:00	Coop de France - Luzerne et Plan Protéines 2020
11864	01025N	REU_TRAV_PARL	2019-06-11 14:00:00	2019-06-11 15:00:00	Rencontre Fédération Plasturgie
11955	01025N	REU_TRAV_PARL	2019-06-18 13:45:00	2019-06-18 14:30:00	Ass. Chimie du Végétal
11956	01025N	ELUS_LOCAUX	2019-06-11 09:00:00	2019-06-11 10:30:00	Maison de l'Emploi - Epernay
12124	08010L	REU_TRAV_PARL	2019-07-04 10:00:00	2019-07-04 12:00:00	DGFiP
12161	04086Q	ORG_POL	2019-07-09 11:00:00	2019-07-09 12:30:00	Réunion du groupe LR
12163	04043D	ORG_POL	2019-06-04 11:00:00	2019-06-04 12:30:00	Réunion de groupe LR
12164	04043D	ORG_POL	2019-07-02 11:00:00	2019-07-02 12:30:00	Réunion de groupe LR
12165	04043D	ORG_POL	2019-07-09 11:00:00	2019-07-09 12:30:00	Réunion de groupe LR
12441	04042C	DEPL_PRES_GVT	2019-09-12 00:00:00	2019-09-12 00:00:00	Universités d'été de la Défense à Bourges/Avord
12225	01025N	REU_TRAV_PARL	2019-07-09 15:15:00	2019-07-09 16:45:00	groupe de suivi des négociations commerciales
12281	04043D	ORG_POL	2019-07-23 11:00:00	2019-07-23 12:30:00	Réunion de groupe 
12442	04042C	DEPL_PRES_GVT	2019-09-13 00:00:00	2019-09-13 00:00:00	Universités d'été de la Défense à Bourges/Avord
12443	04042C	ORG_POL	2019-09-16 09:00:00	2019-09-16 15:00:00	Seninaire de rentrée des Républicains
12468	08010L	REU_TRAV_PARL	2019-09-10 09:00:00	2019-09-10 14:00:00	CA de la Fedération EPL
12469	08010L	REU_TRAV_PARL	2019-09-11 12:00:00	2019-09-11 14:30:00	ADCF/ PJL proximité
12470	08010L	REU_TRAV_PARL	2019-09-11 15:30:00	2019-09-11 17:00:00	Délégation Territoriale/ AMF/
12471	08010L	REU_TRAV_PARL	2019-09-12 09:30:00	2019-09-12 11:30:00	Delegation territoriale et CNEM
12472	08010L	REU_TRAV_PARL	2019-09-12 18:30:00	2019-09-12 19:30:00	France Etats-Unis
12623	04042C	ELUS_LOCAUX	2019-10-03 13:00:00	2019-10-03 14:15:00	Rencontre avec des élus du Val-de-Marne
12624	04042C	CEREMONIE	2019-10-03 20:00:00	2019-10-03 21:00:00	Cérémonie de remise des insignes dans l'Ordre de la Légion d'Honneur à une ancienne sénatrice 
12625	04042C	COLL_TER	2019-10-04 08:45:00	2019-10-04 10:45:00	Réunion du bureau du Syndicat des Eaux d'Ile-de-France
12626	04042C	ACC_DEPL_INTER	2019-10-04 11:00:00	2019-10-04 12:00:00	Entretien avec une délégation de généraux et de colonels du Vietnam
12627	04042C	ACC_DEPL_INTER	2019-10-04 12:30:00	2019-10-04 14:00:00	Rencontre avec Madame l'Ambassadrice du Canada
12628	04018C	COLL_TER	2019-10-16 08:30:00	2019-10-16 17:30:00	Universités des Maires des Yvelines
12629	04018C	ELUS_LOCAUX	2019-10-24 11:00:00	2019-10-24 15:00:00	\N
12941	08010L	REU_TRAV_PARL	2019-10-29 15:00:00	2019-10-29 17:00:00	commission finances 
12986	04086Q	ACC_DEPL_INTER	2019-10-25 11:45:00	2019-10-25 01:45:00	Accueil Délégation vietnamienne
12987	04086Q	REU_TRAV_PARL	2019-10-25 16:30:00	2019-10-25 17:30:00	Réunion de travail bureau du préfet de Seine-Saint-Denis
12994	04086Q	ORG_POL	2019-10-30 11:30:00	2019-10-30 12:30:00	Rendez-vous de travail LR 
12989	04086Q	REU_TRAV_PARL	2019-10-29 10:00:00	2019-10-29 11:30:00	Rendez-vous de travail pour le PLF
12990	04086Q	REU_TRAV_PARL	2019-10-29 12:45:00	2019-10-29 13:00:00	Rendez-vous de travail préparatoire à la séance 
13101	08010L	ORG_POL	2019-11-12 11:00:00	2019-11-12 12:30:00	Groupe LR du Sénat
13102	08010L	ACC_DEPL_INTER	2019-11-12 19:00:00	2019-11-12 20:30:00	GIA France-Maroc
13221	08010L	ORG_POL	2019-11-19 11:00:00	2019-11-19 13:00:00	Groupe LR du Sénat
13223	08010L	ELUS_LOCAUX	2019-11-20 11:30:00	2019-11-20 15:00:00	Maires de l'Aisne / Congrès AMF
13105	04042C	ACC_VISIT	2019-11-13 18:00:00	2019-11-13 19:00:00	Entretien avec le Medecin général de l'Hôpital d'instruction des armées Bégin
13122	04042C	ACC_DEPL_INTER	2019-11-14 10:00:00	2019-11-14 11:00:00	Entretien avec le Président du Sénat et le Président du Conseil Fédéral Autrichien
13107	04042C	ELUS_LOCAUX	2019-11-13 20:30:00	2019-11-13 23:00:00	Traditionnelle rencontre des communautés juives du Val-de-Marne
13121	04042C	REU_GVT	2019-11-14 08:30:00	2019-11-14 09:30:00	Rencontre avec la Ministre des armées sur les relations entre la France et l'Allemagne
13123	04042C	COLL_TER	2019-11-14 12:30:00	2019-11-14 14:00:00	Les rencontres du Club des Grands Services d'Etat du monde
13124	04042C	ACC_DEPL_INTER	2019-11-14 18:30:00	2019-11-14 19:30:00	Cérémonie de remise des insignes de la Croix de Chevalier de l'Ordre du Mérite de Hongrie a un député du Val-de-Marne
13125	04042C	ACC_DEPL_INTER	2019-11-14 20:00:00	2019-11-14 20:30:00	Réception de bienfaisance au profit des blessés et familles de militaires
13242	04042C	REU_TRAV_PARL	2019-11-20 16:45:00	2019-11-20 18:00:00	Rencontre avec le Directeur général de l'Agence Française de Développement
13241	04042C	ELUS_LOCAUX	2019-11-20 12:30:00	2019-11-20 14:45:00	Rencontres au 102ème Congrès des maires à la Porte de Versailles
13243	04042C	ELUS_LOCAUX	2019-11-20 19:30:00	2019-11-20 21:00:00	Réunion des Républicains à Saint-Maurice
13261	04086Q	REU_TRAV_PARL	2019-11-20 14:00:00	2019-11-20 15:00:00	Rendez-vous de travail pour la préparation du bureau du Sénat
13268	14041T	ELUS_LOCAUX	2019-10-10 09:00:00	2019-10-10 22:00:00	déplacement à l'étranger
13401	04042C	ACC_VISIT	2019-12-02 10:10:00	2019-12-02 11:10:00	Plateau Cnews Morandini Live
13402	04042C	CEREMONIE	2019-12-02 15:00:00	2019-12-02 17:00:00	Cérémonie d'hommage aux treize miltaires morts pour a France au Mali
13403	04042C	ACC_VISIT	2019-12-02 18:30:00	2019-12-02 18:40:00	Interviex Public Sénat
13404	04042C	ORG_POL	2019-12-03 11:00:00	2019-12-03 12:00:00	Réunion de Groupe des L.R au Sénat
13405	04042C	ACC_VISIT	2019-12-03 07:15:00	2019-12-03 08:00:00	Plateau Public Sénat
13406	04042C	ELUS_LOCAUX	2019-12-03 09:30:00	2019-12-03 10:30:00	Présentation de la 1ère rame du Tram 9 à Orly
13407	04042C	ACC_DEPL_INTER	2019-12-03 19:30:00	2019-12-03 20:30:00	Exposition Degas au Musée d'Orsay
13408	04042C	REU_TRAV_PARL	2019-12-04 12:00:00	2019-12-04 12:20:00	Entretien avec un Sénateur de la Commission des Affaires étrangères, de la défense et des Forces armées
13409	04042C	ACC_VISIT	2019-12-04 15:30:00	2019-12-04 16:30:00	Entretien avec le Préfet du Val-de-Marne
13410	04042C	ACC_DEPL_INTER	2019-12-04 18:00:00	2019-12-04 19:00:00	Rencontre avec le Premier ministre, Président de la Fondation Prospective et Innovation 
13411	04086Q	COLLOQUE	2019-11-25 20:00:00	2019-11-25 21:30:00	Diner-débat Wizo
13412	04086Q	COLLOQUE	2019-11-26 20:00:00	2019-11-26 21:30:00	Diner-débat avec Hubert Védrine - Amicale Gaulliste 
13413	04086Q	REU_TRAV_PARL	2019-11-27 16:15:00	2019-11-27 16:45:00	Réunion de travail relative aux activités internationales
13414	04086Q	CEREMONIE	2019-12-02 14:00:00	2019-12-02 16:30:00	Hommage aux soldats morts au Mali 
13415	04086Q	REU_TRAV_PARL	2019-12-02 13:15:00	2019-12-02 14:00:00	Mission cohésion des territoires
13416	04042C	ACC_DEPL_INTER	2019-12-04 19:20:00	2019-12-04 20:30:00	Réception à l'occasion de la journée Nationale du Qatar
13417	04042C	ACC_DEPL_INTER	2019-12-04 21:15:00	2019-12-04 22:30:00	Rencontre avec l'Ambassadeur du Royaume-Uni
13418	04042C	CEREMONIE	2019-12-06 00:00:00	2019-12-06 00:00:00	Cérémonie religieuse obsèque d'un des treize militaire mort pour la France au Mali
13421	04086Q	REU_TRAV_PARL	2019-12-11 19:00:00	2019-12-11 20:00:00	Conférence des présidents 
13422	04086Q	CEREMONIE	2019-12-12 20:00:00	2019-12-12 22:00:00	Diner d'accueil de la délégation marocaine dans le cadre du Forum Franco-Marocain 
13423	04086Q	CEREMONIE	2019-12-13 09:00:00	2019-12-13 22:00:00	Forum Franco-Marocain 
13424	04042C	ORG_POL	2019-12-10 11:00:00	2019-12-10 12:00:00	Réunion de Groupe des L.R au Sénat
13425	04042C	ELUS_LOCAUX	2019-12-10 12:30:00	2019-12-10 14:00:00	Réception de Noël des Seniors de Saint-Maurice
13426	04042C	ACC_VISIT	2019-12-10 16:00:00	2019-12-10 16:15:00	Interview Public Sénat
13427	04042C	REU_TRAV_PARL	2019-12-10 16:15:00	2019-12-10 17:15:00	Réunion de Direction
13428	04042C	ACC_DEPL_INTER	2019-12-10 18:00:00	2019-12-10 19:00:00	Entretien avec un Sénateur de la Pologne
13429	04042C	REU_TRAV_PARL	2019-12-10 20:00:00	2019-12-10 21:30:00	Réception à la Présidence du Sénat
13430	04042C	ACC_VISIT	2019-12-11 15:30:00	2019-12-11 17:00:00	Visite guidée du Conseil Municipal des Jeunes de Villeneuve-le-Roi
13431	04042C	ACC_VISIT	2019-12-11 16:30:00	2019-12-11 17:15:00	Entretien avec le Directeur de l'IHEDN
13432	04042C	ACC_DEPL_INTER	2019-12-11 17:15:00	2019-12-11 18:15:00	Entretien avec le Chef de la Délégation de l'Assemblée de la République de Macédoine
13433	04042C	ACC_DEPL_INTER	2019-12-11 18:30:00	2019-12-11 20:30:00	Réception à l'Ambassade des Etats-Unis à l'occasion des Fêtes de fin d'année
11821	04042C	ACC_DEPL_INTER	2019-06-03 18:30:00	2019-06-03 21:00:00	Recpetion à l'Ambassade d'Italie à l'occasion de la Fête nationale
11822	04042C	ORG_POL	2019-06-04 09:00:00	2019-06-04 12:30:00	Séminaire et réunion du Groupe
11823	04042C	ACC_DEPL_INTER	2019-06-04 12:30:00	2019-06-04 14:15:00	Réception à la Présidence du Sénat à l'occasion des semaines de l'Amérique latine et des Caraïbes
11824	04042C	REU_TRAV_PARL	2019-06-04 14:30:00	2019-06-04 15:30:00	Réunion de Direction
11825	04042C	ACC_DEPL_INTER	2019-06-04 17:00:00	2019-06-04 18:00:00	Entretien avec l'Ambassadeur du Chili en France
11826	04042C	CEREMONIE	2019-06-04 18:00:00	2019-06-04 19:00:00	Intronisation à la Confrérie du Brie de Melun
11827	04042C	ACC_DEPL_INTER	2019-06-05 12:30:00	2019-06-05 14:15:00	Entretien avec l'Ambassadeur de Chine en France
11828	04042C	ELUS_LOCAUX	2019-06-05 18:30:00	2019-06-05 21:00:00	Visite des studios de Bry-sur-Marne
11941	04043D	DEPL_PRES_GVT	2019-06-13 14:00:00	2019-06-13 16:00:00	visite de StaffMe-Le Kremlin-Bicêtre
11942	04042C	REU_TRAV_PARL	2019-06-06 09:45:00	2019-06-06 12:45:00	Réunion de la Délégation parlementaire au renseignement
11943	04042C	ELUS_LOCAUX	2019-06-17 08:30:00	2019-06-17 10:00:00	Réunion Les Républicains à Maisons-Alfort
11944	04042C	ACC_DEPL_INTER	2019-06-17 14:00:00	2019-06-17 15:00:00	Salon du Bourget : Discours d'inauguration du Salon de Madame la Minstre des armées
11945	04042C	ACC_DEPL_INTER	2019-06-17 17:00:00	2019-06-17 18:00:00	Entretien avec le Ministre de la Défense de Singapour
11946	04042C	ACC_VISIT	2019-06-17 18:00:00	2019-06-17 18:45:00	Réunion de la Fondation Saint Cyr
11947	04042C	ACC_DEPL_INTER	2019-06-17 19:00:00	2019-06-17 20:00:00	Entretien avec le Président du Sénat du Président de la Républiqeu de l'Ukraine
11948	04042C	ACC_DEPL_INTER	2019-06-17 20:15:00	2019-06-17 21:15:00	Réception pour l'ouverture du 53ème Salon international de l'Aéronautique
11949	04042C	ACC_DEPL_INTER	2019-06-14 09:00:00	2019-06-14 22:00:00	Journée de l'Assemblée des Sénats d'Europe au Sénat - Entretiens avec le Président de la Chambre des Lords britannique
11950	04042C	REU_TRAV_PARL	2019-06-18 09:30:00	2019-06-18 10:15:00	Réunion de Direction
11951	04042C	ACC_VISIT	2019-06-18 10:15:00	2019-06-18 11:00:00	Tournage d'une télévision marocaine
11952	04042C	ORG_POL	2019-06-18 11:00:00	2019-06-18 12:30:00	Réunion du Groupe Les Républicains
11953	04042C	CEREMONIE	2019-06-18 18:30:00	2019-06-18 19:30:00	Baptème du Square de la Liberté à l'occasion de la commémoration de l'appel du Général de Gaulle à l'Haÿ-les-Roses
11954	04042C	ACC_DEPL_INTER	2019-06-18 20:00:00	2019-06-18 22:00:00	Réception de la Ministre des armées à l'occasion du 53ème Salon International de l'Aéronautique et de l'Espace
12122	08010L	ACC_VISIT	2019-07-03 16:30:00	2019-07-03 18:00:00	France Etats-Unis
12123	08010L	REU_TRAV_PARL	2019-07-03 15:30:00	2019-07-03 16:30:00	GIA France-Etats-Unis 
12125	04042C	REU_TRAV_PARL	2019-07-02 10:00:00	2019-07-02 11:00:00	Réunion de Direction
12126	04042C	ORG_POL	2019-07-02 11:00:00	2019-07-02 12:00:00	Réunion du Groupe Les Républicains
12130	04042C	REU_TRAV_PARL	2019-07-02 16:15:00	2019-07-02 17:15:00	Réunion de travail avec le Directeur Général d'Expertise France
12128	04042C	ACC_DEPL_INTER	2019-07-02 13:00:00	2019-07-02 14:30:00	Rencontre avec Monsieur l'Ambassadeur de la République Islamique d'Afghanistan
12132	04042C	REU_TRAV_PARL	2019-07-03 08:30:00	2019-07-03 09:30:00	Réunion du bureau de la Commission des Affaires étrangères, de la Défense et des Forces armées
12131	04042C	CEREMONIE	2019-07-02 20:30:00	2019-07-02 21:30:00	Cérémonie d'hommage à Saint-Maurice
12133	04042C	ACC_VISIT	2019-07-03 13:00:00	2019-07-03 14:15:00	Rencontre avec un élu des Hauts-de-Seine
12134	04042C	ACC_VISIT	2019-07-03 16:30:00	2019-07-03 16:45:00	Interview de Public Sénat
12135	04042C	ACC_VISIT	2019-07-03 16:45:00	2019-07-03 17:00:00	Interview de Al-Arabiya
12136	04042C	ACC_DEPL_INTER	2019-07-03 18:00:00	2019-07-03 19:00:00	Réception à l'Ambassade du Canada sur le thème du nouveau Fonds Egalité
12169	04042C	CEREMONIE	2019-07-08 11:30:00	2019-07-08 14:00:00	Pose de la première pierre d'un immeuble à Saint-Maurice
12170	04042C	ORG_POL	2019-07-08 19:30:00	2019-07-08 20:30:00	Audition devant la Commission Nationale d'Investiture
12202	04042C	ORG_POL	2019-07-09 19:30:00	2019-07-09 20:30:00	\N
12172	08010L	ORG_POL	2019-07-09 11:00:00	2019-07-09 13:00:00	Groupe LR du Sénat
12178	14041T	ELUS_LOCAUX	2019-04-09 09:00:00	2019-04-09 19:00:00	déplacement à Singapour
12179	14041T	ELUS_LOCAUX	2019-04-10 09:00:00	2019-04-10 19:00:00	déplacement à Singapour
12180	14041T	ELUS_LOCAUX	2019-04-11 09:00:00	2019-04-11 19:00:00	déplacement à Singapour
12182	14041T	ELUS_LOCAUX	2019-04-30 09:00:00	2019-04-30 19:00:00	déplacement à Singapour
12183	14041T	ELUS_LOCAUX	2019-05-02 09:00:00	2019-05-02 19:00:00	déplacement à Singapour
12184	04043D	REU_TRAV_PARL	2019-07-10 12:30:00	2019-07-10 14:30:00	Déjeuner avec le Président de la FEP
12204	04042C	ACC_DEPL_INTER	2019-07-10 13:00:00	2019-07-10 14:30:00	Echanges avec S.E. Monsieur l'Ambassadeur d'Australie
12203	04042C	REU_TRAV_PARL	2019-07-09 20:30:00	2019-07-09 21:30:00	Rencontre avec les Sénateurs Les Républicains
12205	04042C	ACC_VISIT	2019-07-10 15:30:00	2019-07-10 16:00:00	Entretien sur les relations internationales
12206	04042C	ACC_VISIT	2019-07-10 16:00:00	2019-07-10 17:00:00	Entretien sur le Burkina Faso
12207	04042C	REU_TRAV_PARL	2019-07-10 20:15:00	2019-07-10 21:30:00	Débat avec le Chef d'état-major de la marine
12211	04042C	CEREMONIE	2019-07-11 18:00:00	2019-07-11 19:00:00	Adieux aux armes du Chef d'état-major de l'armée de terre 
12209	04042C	ACC_DEPL_INTER	2019-07-11 13:00:00	2019-07-11 14:15:00	Rencontre avec des sénateurs et S.E. Monsieur l'Ambassadeur de Turquie
12210	04042C	ACC_VISIT	2019-07-11 16:00:00	2019-07-11 17:00:00	Entretien avec un élu du Val-de-Marne
12362	04042C	REU_TRAV_PARL	2019-08-29 16:00:00	2019-08-29 17:00:00	Réunion de direction
12224	01058X	REU_TRAV_PARL	2019-06-26 14:30:00	2019-06-26 15:30:00	groupe de suivi sur les négociations commerciales
12361	04042C	ACC_DEPL_INTER	2019-08-29 13:30:00	2019-08-29 14:30:00	Conférence des Ambassadeurs et des Ambassadrices : Discours du Ministre de l'Europe et des Affaires étrangères
12363	04042C	ACC_DEPL_INTER	2019-08-29 17:00:00	2019-08-29 18:00:00	Entretien avec S.E. Madame l'Ambassadrice de France au Maroc
12461	08010L	REU_TRAV_PARL	2019-09-17 17:00:00	2019-09-17 18:00:00	Association Américains Accidentels 
12462	08010L	REU_TRAV_PARL	2019-09-17 15:00:00	2019-09-17 17:00:00	\N
12463	08010L	REU_TRAV_PARL	2019-09-18 14:00:00	2019-09-18 15:00:00	Identification des enterrés sous X
12464	08010L	REU_TRAV_PARL	2019-09-19 14:00:00	2019-09-19 17:00:00	\N
12467	08010L	REU_TRAV_PARL	2019-09-19 17:30:00	2019-09-19 19:30:00	France Etats-Unis
12622	08010L	REU_TRAV_PARL	2019-10-03 19:30:00	2019-10-03 21:00:00	France/Etas-Unis 
12621	08010L	ACC_VISIT	2019-10-03 15:00:00	2019-10-03 17:30:00	Maires du Grand Laonnaois 
12633	04018C	REU_TRAV_PARL	2019-10-03 08:30:00	2019-10-03 10:00:00	Groupe Métiers d'Art
12631	04018C	ORG_POL	2019-10-01 20:00:00	2019-10-01 22:00:00	\N
12632	04018C	CEREMONIE	2019-10-01 18:00:00	2019-10-01 18:30:00	Inauguration quartier des Chantiers
12634	04018C	ORG_POL	2019-10-03 20:00:00	2019-10-03 22:00:00	\N
12841	08010L	REU_TRAV_PARL	2019-10-17 09:00:00	2019-10-17 10:30:00	réunion de cabinet
13062	08010L	ACC_DEPL_INTER	2019-11-05 12:30:00	2019-11-05 14:00:00	GIA France Etats-Unis Fondation Saint Omer Valeurs Transatlantiques 
12843	04042C	DEPL_PRES_GVT	2019-10-18 00:00:00	2019-10-18 00:00:00	Mission officielle marocaine
13061	08010L	ACC_DEPL_INTER	2019-11-06 00:00:00	2019-11-06 00:00:00	GIA France-Etats-Unis MEDEF, Impact sur entreprises françaises des relations entre les EU et Chine et Iran 
13141	04086Q	REU_TRAV_PARL	2019-11-07 09:00:00	2019-11-07 12:30:00	Bureau du Sénat
13142	04086Q	ELUS_LOCAUX	2019-11-08 13:00:00	2019-11-08 14:30:00	Déjeuner de travail avec le Préfet 
13149	04086Q	COLL_TER	2019-11-14 12:30:00	2019-11-14 14:00:00	Déjeuner de travail avec Patrick Ollier sur le Scot Métropolitain 
13150	04042C	COLL_TER	2019-11-15 13:00:00	2019-11-15 14:30:00	Les rencontres du Club des Grands Services d'Etat du Monde
13151	04042C	COLL_TER	2019-11-14 20:45:00	2019-11-14 22:30:00	Les rencontres du Club des Grands Services d'Etat du monde
13152	04042C	COLL_TER	2019-11-15 18:00:00	2019-11-15 18:15:00	Discours de clôture des rencontres du Club des Grands Services d'Etat du monde
13153	04042C	COLL_TER	2019-11-15 20:30:00	2019-11-15 20:45:00	Clôture des rencontres du Club des Grands Services d'Etat du monde
13154	04042C	CEREMONIE	2019-11-15 21:00:00	2019-11-15 23:00:00	Inauguration officielle du 1er Festival du Bien Manger Rungis au Grand Palais
13601	04042C	CEREMONIE	2020-01-09 19:30:00	2020-01-09 20:30:00	Cérémonie de recueillement et d'hommage aux victimes de l'attentat de l'Hyper Cacher
13602	04042C	CEREMONIE	2020-01-09 20:45:00	2020-01-09 22:00:00	Cérémonie des Voeux de Joinville-le-Pont
13609	04042C	ELUS_LOCAUX	2020-01-13 11:30:00	2020-01-13 12:30:00	Entretien avec des élus du Val-de-Marne
13607	04042C	ACC_VISIT	2020-01-10 14:20:00	2020-01-10 16:00:00	Visite guidée des élèves de Terminale du Lycée Marcelin Berthelot de Saint-Maur-des-Fossés
13608	04042C	CEREMONIE	2020-01-10 19:00:00	2020-01-10 21:00:00	Cérémonie des Voeux d'Ablon-sur-Seine
13610	04042C	CEREMONIE	2020-01-13 19:30:00	2020-01-13 21:30:00	Cérémonie des Voeux de Thiais
13611	04042C	ACC_VISIT	2020-01-14 07:15:00	2020-01-14 08:00:00	Interview La Matinale de Public Sénat
13622	04043D	ORG_POL	2020-01-08 11:00:00	2020-01-08 12:30:00	CNI
13613	04042C	ORG_POL	2020-01-14 11:00:00	2020-01-14 12:00:00	Réuion de Groupe des L.R du Sénat
13623	04043D	CEREMONIE	2020-01-08 19:00:00	2020-01-08 22:00:00	Cérémonie des voeux de la mairie de Maisons-Alfort
13615	04042C	ACC_VISIT	2020-01-14 15:30:00	2020-01-14 16:30:00	Entretien avec le Sous-préfet de Nogent-sur-Marne
13624	04043D	CEREMONIE	2020-01-09 19:30:00	2020-01-09 22:30:00	Cérémonie des voeux de la Mairie de Joinville
13625	04043D	CEREMONIE	2020-01-10 18:30:00	2020-01-10 20:30:00	Cérémonie des voeux de la mairie d'Ablon-sur-Seine
13626	04043D	CEREMONIE	2020-01-13 19:30:00	2020-01-13 21:00:00	Cérémonie des Voeux de la mairie de Thais
13643	04086Q	ORG_POL	2020-01-14 11:00:00	2020-01-14 12:30:00	Réunion du groupe LR
13649	04042C	CEREMONIE	2020-01-15 18:00:00	2020-01-15 19:30:00	Inauguration de la Galerie d'Appolon au Musée du Louvre
13645	04086Q	CEREMONIE	2020-01-14 19:00:00	2020-01-14 21:00:00	Voeux de Gérard Larcher 
13646	04086Q	REU_TRAV_PARL	2020-01-16 09:30:00	2020-01-16 11:30:00	Table ronde de la délégation des collectivités territoriales 
13647	04042C	CEREMONIE	2020-01-15 12:45:00	2020-01-15 14:30:00	Cérémonie des Voeux du GICAT
13648	04042C	ACC_DEPL_INTER	2020-01-15 16:30:00	2020-01-15 17:30:00	Entretien avec Madame l'Ambassdrice de la Serbie en France
13650	04042C	CEREMONIE	2020-01-15 20:00:00	2020-01-15 22:00:00	Cérémonie des Voeux d'Ormesson-sur-Marne
13782	04018C	CEREMONIE	2020-01-28 09:30:00	2020-01-28 11:00:00	\N
13761	04043D	ACC_VISIT	2020-01-27 18:30:00	2020-01-27 21:30:00	Réception de la ville d'Orly
13663	08010L	ELUS_LOCAUX	2020-01-16 19:00:00	2020-01-16 20:30:00	Voeux de la CC Chauny Tergnier La Fère
13666	08010L	ELUS_LOCAUX	2020-01-16 17:30:00	2020-01-16 19:00:00	Voeux CC Thiérache Sambre et Oise
13781	08010L	REU_TRAV_PARL	2020-01-28 18:00:00	2020-01-28 19:00:00	GIA France-Etats-Unis
13787	04018C	ELUS_LOCAUX	2020-02-06 20:00:00	2020-02-06 22:00:00	\N
13861	08010L	REU_TRAV_PARL	2020-02-05 16:30:00	2020-02-05 18:00:00	Batonniers des Hauts de France 
13863	04042C	REU_TRAV_PARL	2020-02-04 08:30:00	2020-02-04 09:30:00	Entretien avec le Président du Sénat
13864	04042C	ACC_VISIT	2020-02-04 10:00:00	2020-02-04 11:00:00	Entretien avec le Directeur des Affaires publiques de Total S.A
13865	04042C	ORG_POL	2020-02-04 11:00:00	2020-02-04 12:15:00	Réunion du Groupe L.R du Sénat
13866	04042C	ACC_VISIT	2020-02-04 13:00:00	2020-02-04 14:00:00	Entretien avec le Directeur Général Eau France
13867	04042C	REU_TRAV_PARL	2020-02-05 13:00:00	2020-02-05 14:30:00	Rencontre avec le Chef d'état-major de la Marine
13868	04042C	REU_TRAV_PARL	2020-02-05 18:00:00	2020-02-05 18:30:00	Entretian avec le Président du Sénat
13869	04042C	CEREMONIE	2020-02-05 18:30:00	2020-02-05 19:30:00	Remise des insignes de la Légion d'Honneur à un ancien sénateur par le Président du Sénat
13946	04042C	ACC_DEPL_INTER	2020-02-19 18:00:00	2020-02-19 19:00:00	Entretien avec l'Ambassadeur d'Afghanistan
13942	08010L	REU_TRAV_PARL	2020-02-19 13:30:00	2020-02-19 15:00:00	UE post-Brexit 
14105	11103C	REU_GVT	2020-03-04 18:00:00	2020-03-04 19:00:00	\N
14107	11103C	ORG_POL	2020-03-03 11:00:00	2020-03-03 12:30:00	LR du Sénat
13945	08010L	ACC_VISIT	2020-02-20 12:00:00	2020-02-20 13:00:00	industriel Aisne
13947	04042C	ACC_DEPL_INTER	2020-02-19 20:15:00	2020-02-19 22:30:00	Rencontre avec l'Ambassadeur d'Allemagne à l'occasion de la venue en France de la ministre déférale de la Défense
13948	04042C	REU_TRAV_PARL	2020-02-20 09:30:00	2020-02-20 10:30:00	Réunion de la Délégation parlementaire au Renseignement
13949	04042C	CEREMONIE	2020-02-20 11:15:00	2020-02-20 12:15:00	Signature d'un contrat avec la ministre des armées en presence de la ministre fédérale allemande de la Défense et du Secrétaire d'Etat Espagnol de la Défense
13950	04042C	REU_TRAV_PARL	2020-02-20 13:00:00	2020-02-20 14:15:00	Rencontre avec le major Général des armées
13951	04042C	ACC_DEPL_INTER	2020-02-20 15:30:00	2020-02-20 16:30:00	Entretien avec le Représentant en France du Gouvernement du Kurdistan Irak
14110	11103C	ORG_POL	2020-01-28 11:00:00	2020-01-28 12:30:00	LR du Sénat
14108	11103C	ORG_POL	2020-02-18 11:00:00	2020-02-18 12:30:00	LR du Sénat
14114	11103C	ORG_POL	2020-01-07 11:00:00	2020-01-07 12:30:00	LR du Sénat
14115	11103C	ORG_POL	2019-12-17 11:00:00	2019-12-17 12:30:00	LR du Sénat
14116	11103C	ORG_POL	2019-12-10 11:00:00	2019-12-10 12:30:00	LR du Sénat
14120	11103C	ORG_POL	2019-11-19 11:00:00	2019-11-19 12:30:00	LR du Sénat
14121	11103C	ORG_POL	2019-11-12 11:00:00	2019-11-12 12:30:00	LR du Sénat
14123	11103C	ORG_POL	2019-11-05 12:30:00	2019-11-05 13:30:00	Fédération LR du Loiret
14124	11103C	ORG_POL	2019-10-29 11:00:00	2019-10-29 12:30:00	LR du Sénat
14125	11103C	ORG_POL	2019-10-29 18:30:00	2019-10-29 19:30:00	LR
14126	11103C	ORG_POL	2019-10-15 11:00:00	2019-10-15 12:30:00	LR du Sénat
14127	11103C	ORG_POL	2019-10-08 11:00:00	2019-10-08 12:30:00	LR du Sénat
14128	11103C	ORG_POL	2019-10-01 11:00:00	2019-10-01 12:30:00	LR du Sénat
14129	11103C	ORG_POL	2019-09-24 11:00:00	2019-09-24 12:30:00	LR du Sénat
14130	04086Q	ORG_POL	2020-03-03 11:00:00	2020-03-03 12:30:00	Réunion du groupe LR
14131	04086Q	REU_TRAV_PARL	2020-03-03 10:00:00	2020-03-03 11:00:00	RDV de travail avec Mme MORO, ambassadrice chargée des relations extérieurs des collectivités locales 
14134	04086Q	ACC_DEPL_INTER	2020-03-04 12:30:00	2020-03-04 14:00:00	Déjeuner conférence avec l'ambassadrice du Québec sur le thème des relations franco-québecois
14135	04086Q	ACC_DEPL_INTER	2020-03-04 16:00:00	2020-03-04 16:30:00	Réunion avec le nouveau consul de France à Jérusalem
14161	04042C	ACC_DEPL_INTER	2020-03-03 13:00:00	2020-03-03 14:30:00	Rencontre avec le Ministre conseiller de l'Ambassade des Etats-Unis en France
14162	04042C	REU_TRAV_PARL	2020-03-03 16:30:00	2020-03-03 17:00:00	Entretien avec un Sénateur
14163	04042C	REU_TRAV_PARL	2020-03-03 17:00:00	2020-03-03 18:00:00	Réunion de direction
14164	04042C	ACC_DEPL_INTER	2020-03-04 13:00:00	2020-03-04 14:15:00	Rencontre avec le Consul général de France en Israël
14165	04042C	ELUS_LOCAUX	2020-03-04 20:00:00	2020-03-04 22:00:00	Réunion publique à Valenton
14166	04042C	ACC_DEPL_INTER	2020-03-05 18:20:00	2020-03-05 19:30:00	Entretien avec le Président du Sénat et le Vice-premier ministre et Ministre des Affaires étrangères du Qatar
14167	04042C	ACC_VISIT	2020-03-05 19:30:00	2020-03-05 21:30:00	Projection débat et rencontre citoyenne avec des lycéens et des étudiants
14168	04042C	COLL_TER	2020-03-06 08:45:00	2020-03-06 12:00:00	Réunion de bureau du Syndicat des Eaux d'Ile-de-France
14441	08010L	REU_TRAV_PARL	2020-05-27 18:30:00	2020-05-27 20:00:00	Sénatoriales 2020
14722	04042C	ELUS_LOCAUX	2020-07-03 11:15:00	2020-07-03 12:15:00	Réunion Urbanisme à la Mairie de Saint-Maurice
14171	04042C	ACC_VISIT	2020-03-06 15:00:00	2020-03-06 16:00:00	Entretien avec le Président de MBDA
14172	04042C	ELUS_LOCAUX	2020-03-06 18:00:00	2020-03-06 19:00:00	Réunion publique à Saint-Mandé
14723	04042C	COLL_TER	2020-07-03 13:00:00	2020-07-03 14:15:00	Rencontre avec le Président de la Métropole du Grand Paris
14664	08010L	REU_TRAV_PARL	2020-07-01 17:00:00	2020-07-01 18:00:00	CE Radicalisation 
14721	04042C	COLL_TER	2020-07-03 08:45:00	2020-07-03 10:45:00	Réunion du bureau du Syndicat des Eaux d'Ile-de-France
14821	04086Q	REU_TRAV_PARL	2020-06-10 08:00:00	2020-06-10 10:00:00	Groupe de travail pjl décentralisation 
14822	04086Q	COLLOQUE	2020-06-15 00:00:00	2020-06-15 00:00:00	Invité à un Table ronde avec des professionnels du logement social
14823	04086Q	REU_TRAV_PARL	2020-06-17 08:00:00	2020-06-17 10:00:00	Groupe de travail pjl décentralisation 
14827	04086Q	ORG_POL	2020-07-07 11:00:00	2020-07-07 12:30:00	Réunion du groupe LR
14829	04086Q	ORG_POL	2020-06-16 11:00:00	2020-06-16 12:30:00	Réunion du groupe LR
14832	04086Q	REU_TRAV_PARL	2020-07-07 12:30:00	2020-07-07 14:00:00	Déjeuner de travail avec la délégation aux collectivités territoriales
14833	04086Q	ACC_DEPL_INTER	2020-07-08 08:30:00	2020-07-08 09:30:00	Rencontre du groupe France-Israël avec les représentants de l'ambassade d'Israël
13698	04018C	ELUS_LOCAUX	2020-01-08 19:00:00	2020-01-08 20:30:00	Cérémonie de voeux
13582	08010L	ELUS_LOCAUX	2020-01-09 09:00:00	2020-01-09 11:30:00	USAA Laon Marle
13583	08010L	ELUS_LOCAUX	2020-01-09 18:00:00	2020-01-09 20:00:00	Voeux  Ville de Laon
13699	04018C	ELUS_LOCAUX	2020-01-09 19:00:00	2020-01-09 21:00:00	Cérémonie de voeux
13700	04018C	ELUS_LOCAUX	2020-01-15 19:00:00	2020-01-15 21:00:00	Cérémonie de voeux
13841	04043D	ORG_POL	2020-01-28 11:00:00	2020-01-28 12:30:00	Réunion de groupe
13845	04043D	ACC_VISIT	2020-01-30 18:30:00	2020-01-30 21:30:00	Réception d'un groupe d'Ivry-sur-Seine et du Kremlin-Bicêtre
13843	04043D	COLL_TER	2020-01-29 13:00:00	2020-01-29 14:30:00	Réception du sous-préfet de nogent sur marne
13844	04043D	ACC_VISIT	2020-01-30 12:30:00	2020-01-30 14:00:00	Réception des Aéroports de Paris
13846	04043D	ORG_POL	2020-02-04 11:00:00	2020-02-04 12:30:00	Réunion de groupe
13847	08010L	REU_TRAV_PARL	2020-02-04 10:00:00	2020-02-04 11:00:00	Député Bellamy et Sénaterice Deromédi /américains accidentels/visas de travail EU
13848	08010L	ORG_POL	2020-02-04 11:00:00	2020-02-04 12:30:00	Groupe LR du Sénat
13876	01058X	REU_TRAV_PARL	2020-01-29 08:00:00	2020-01-29 09:30:00	Ambassadrice du Canada en France - CETA
13872	01058X	CEREMONIE	2020-01-28 18:30:00	2020-01-28 20:00:00	Voeux Sarre-Région Grand Est
13873	01058X	DEPL_PRES_GVT	2020-01-23 08:00:00	2020-01-23 15:00:00	Visite Ministre Transition écologique et solidaire E. BORNE en Haute-Marne 
13874	01058X	REU_TRAV_PARL	2020-01-28 16:00:00	2020-01-28 17:00:00	Groupe Amitié Australie - Iles du Pacifique - Changement climatique
13902	01025N	REU_TRAV_PARL	2020-01-15 08:30:00	2020-01-15 09:30:00	PJL Bioéthique (UC)
13901	01025N	REU_TRAV_PARL	2020-01-08 08:00:00	2020-01-08 09:00:00	Groupe UC
13903	01025N	REU_TRAV_PARL	2020-01-15 13:00:00	2020-01-15 14:00:00	Comité national Conchyliculture
13904	01025N	COLLOQUE	2020-02-06 09:00:00	2020-02-06 13:00:00	Acier et construction
13905	04042C	CEREMONIE	2020-02-07 18:30:00	2020-02-07 20:00:00	Cérémonie de remise des insignes de l'Ordre National de la Légion d'Honneur au Président de l'Automobile Club de France 
13906	04042C	ACC_DEPL_INTER	2020-02-11 18:00:00	2020-02-11 19:30:00	Réception de l'Ambassadeur de la République Islamique d'Iran à l'occasion de la Fête nationale
13921	08010L	ORG_POL	2020-02-18 11:00:00	2020-02-18 12:30:00	Groupe LR du Sénat + C. JACOB
14481	08010L	REU_TRAV_PARL	2020-06-03 10:00:00	2020-06-03 12:00:00	Réunion de cabinet
13923	08010L	REU_TRAV_PARL	2020-02-19 16:30:00	2020-02-19 17:30:00	FedEPL /Del. territoriale/PJL 3D
13961	04086Q	ORG_POL	2020-02-18 11:00:00	2020-02-18 12:30:00	Réunion du groupe LR
14202	08010L	REU_TRAV_PARL	2020-03-26 11:00:00	2020-03-26 12:30:00	commission des finances
14261	08010L	ORG_POL	2020-04-28 10:30:00	2020-04-28 12:00:00	Vidéoconfrence Groupe LR du Sénat
14482	08010L	REU_TRAV_PARL	2020-06-03 15:00:00	2020-06-03 16:30:00	Réunion CDPPT
14621	08010L	REU_TRAV_PARL	2020-06-24 09:30:00	2020-06-24 11:30:00	Commission des finances
14622	08010L	COLL_TER	2020-06-25 18:00:00	2020-06-25 20:00:00	Communauté d'Agglomératrion de Laon 
14623	01025N	REU_TRAV_PARL	2020-03-31 20:30:00	2020-03-31 22:00:00	FDSEA 51
14624	01025N	REU_TRAV_PARL	2020-04-23 11:00:00	2020-04-23 12:30:00	Audition Christiane Lambert - Présidente FNSEA - GT détresse agriculteurs
14625	01025N	REU_TRAV_PARL	2020-06-05 08:30:00	2020-06-05 10:00:00	Echanges FDSEA 51
14626	01025N	REU_TRAV_PARL	2020-06-12 10:00:00	2020-06-12 12:00:00	Echanges Préfète de Région Grand Est
14627	01025N	REU_TRAV_PARL	2020-06-23 13:30:00	2020-06-23 14:30:00	Audition CCMSA
14801	04042C	ACC_DEPL_INTER	2020-07-13 11:00:00	2020-07-13 12:00:00	Entretien avec l'Ambassadeur du Maroc en France
14802	04042C	ACC_DEPL_INTER	2020-07-13 13:00:00	2020-07-13 14:15:00	Rencontre avec un général de brigade aérienne de l'Ambassade de Grande-Bretagne
14803	04042C	ACC_VISIT	2020-07-13 15:00:00	2020-07-13 16:00:00	Entretien avec le Maire de Mennecy
14804	04042C	ACC_DEPL_INTER	2020-07-13 16:00:00	2020-07-13 17:00:00	Entretien avec l'Ambassadeur de Palestine en France
14805	04042C	REU_TRAV_PARL	2020-07-13 17:00:00	2020-07-13 18:00:00	Visite de courtoisie de l'Inspecteur général des armées - Gendarmerie
14806	04042C	ACC_DEPL_INTER	2020-07-13 18:15:00	2020-07-13 20:00:00	Réception au Ministère des armées en l'honneur des unités participant aux cérémonies de la Fête nationale en présence du Président de la République
14810	04042C	ACC_DEPL_INTER	2020-07-14 20:00:00	2020-07-14 22:30:00	Rencontre avec l'Ambassadeur d'Australie en France à l'occasion de son départ
14904	04086Q	REU_TRAV_PARL	2020-09-08 09:30:00	2020-09-08 11:00:00	Audition de la mission d'information sur la Guyane Française 
14809	04042C	ACC_DEPL_INTER	2020-07-14 10:45:00	2020-07-14 12:00:00	Cérémonie du 14 juillet place de la Concorde
14824	04086Q	REU_TRAV_PARL	2020-06-24 08:00:00	2020-06-24 09:00:00	Groupe de travail pjl décentralisation 
14825	04086Q	REU_TRAV_PARL	2020-06-17 14:00:00	2020-06-17 15:30:00	Conférence des présidents 
14826	04086Q	ORG_POL	2020-06-30 11:00:00	2020-06-30 12:30:00	Réunion du groupe LR
14828	04086Q	ORG_POL	2020-06-09 11:00:00	2020-06-09 12:30:00	Réunion du groupe LR
14830	04086Q	ORG_POL	2020-06-23 11:00:00	2020-06-23 12:30:00	Réunion du groupe LR
14831	04086Q	REU_TRAV_PARL	2020-07-07 08:30:00	2020-07-07 10:00:00	Rendez-vous de travail au groupe LR 
14834	04086Q	COLL_TER	2020-07-09 09:00:00	2020-07-09 12:30:00	Conseil de Métropole d'installation à la MGP
14883	11103C	ORG_POL	2020-07-21 11:00:00	2020-07-21 12:30:00	LR du Sénat
14901	04086Q	REU_TRAV_PARL	2020-09-09 15:00:00	2020-09-09 17:00:00	Réunion du bureau du Sénat 
14979	04086Q	COLL_TER	2020-09-21 14:00:00	2020-09-21 15:30:00	Rencontre avec le président du TGI de Bobigny
14980	04086Q	REU_TRAV_PARL	2020-09-22 17:30:00	2020-09-22 18:30:00	Rendez-vous de travail  en visio-conférence avec Emmanuelle Wargon, ministre du Logement
14982	04086Q	REU_TRAV_PARL	2020-09-23 20:00:00	2020-09-23 22:00:00	Réunion de travail autour de Valérie Pécresse sur les sujets de la Région
14983	04086Q	ORG_POL	2020-09-30 10:30:00	2020-09-30 12:30:00	Réunion du groupe LR
15161	08010L	REU_TRAV_PARL	2020-10-15 11:00:00	2020-10-15 12:00:00	Com finances / justice
15162	11103C	ORG_POL	2020-10-06 11:00:00	2020-10-06 12:30:00	LR du Sénat
15263	08010L	CEREMONIE	2020-10-27 14:30:00	2020-10-27 15:15:00	Eloge funèbre C.Giudicelli
15261	04042C	ACC_DEPL_INTER	2020-10-27 13:00:00	2020-10-27 14:30:00	Rencontre avec un ancien ministre et chef de l'opposition du Mali avec des sénateurs
15262	04042C	ACC_DEPL_INTER	2020-10-27 16:30:00	2020-10-27 17:30:00	Entretien avec le Président du Sénat du Premier Ministre de Roumanie et deux de ses Ministres
15265	08010L	REU_TRAV_PARL	2020-10-27 17:00:00	2020-10-27 18:00:00	Bureau délégation territoriale 
15266	08010L	REU_TRAV_PARL	2020-10-28 16:00:00	2020-10-28 17:00:00	Fédération des EPL
15281	08010L	ORG_POL	2020-10-29 08:30:00	2020-10-29 10:00:00	Groupe LR sénat 
15282	08010L	REU_TRAV_PARL	2020-10-29 10:00:00	2020-10-29 11:00:00	Com.Finances LR
15283	08010L	ORG_POL	2020-10-29 13:45:00	2020-10-29 14:30:00	Groupe LR 
15326	04086Q	ORG_POL	2020-10-29 08:30:00	2020-10-29 09:00:00	Réunion exceptionnelle du groupe LR 
15327	04086Q	ORG_POL	2020-10-29 13:30:00	2020-10-29 14:00:00	Réunion exceptionnelle du groupe LR 
15328	04086Q	ORG_POL	2020-11-03 11:00:00	2020-11-03 12:30:00	Réunion du groupe LR
15329	11103C	ORG_POL	2020-11-03 11:00:00	2020-11-03 12:30:00	LR du Sénat
15362	04042C	ELUS_LOCAUX	2020-11-06 10:45:00	2020-11-06 12:30:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
15342	08010L	REU_TRAV_PARL	2020-11-05 15:30:00	2020-11-05 18:00:00	PLFSS 2021
15343	08010L	REU_TRAV_PARL	2020-11-05 14:30:00	2020-11-05 15:30:00	Vote électronique
15363	04042C	REU_TRAV_PARL	2020-11-04 16:30:00	2020-11-04 17:00:00	Entrtien avec le Président du Haut Comité d'Evaluation de la condition militaire
15364	04042C	ACC_VISIT	2020-11-04 17:45:00	2020-11-04 18:30:00	Interview Elections américaines Public Senat
15365	04042C	DEPL_PRES_GVT	2020-11-09 00:00:00	2020-11-09 00:00:00	Mission au Caire et à Rabat avec le Ministre de l'Europe et des Affaires étrangères
15369	04042C	REU_TRAV_PARL	2020-11-10 15:30:00	2020-11-10 16:30:00	Réunion de Direction
15367	04042C	ORG_POL	2020-11-10 11:00:00	2020-11-10 12:00:00	Réunion de Groupe des L.R au Sénat
15368	04042C	CEREMONIE	2020-11-10 12:30:00	2020-11-10 13:00:00	Hommage au Général de Gaulle devant sa statue
15401	04086Q	ORG_POL	2020-11-10 11:00:00	2020-11-10 12:30:00	Réunion du groupe LR
15402	04086Q	REU_TRAV_PARL	2020-11-09 18:00:00	2020-11-09 18:30:00	Réunion commissaires LR Finances
15421	04042C	CEREMONIE	2020-11-12 14:30:00	2020-11-12 15:00:00	Cérémonie traditionnelle d'hommage aux Sénateurs et fonctionnaires du Sénat morts pour la France
13541	08009T	REU_GVT	2019-10-22 20:00:00	2019-10-22 22:00:00	\N
13542	08009T	REU_TRAV_PARL	2019-10-23 14:30:00	2019-10-23 15:30:00	\N
13543	08009T	REU_TRAV_PARL	2019-10-23 17:00:00	2019-10-23 18:00:00	\N
13544	08009T	REU_TRAV_PARL	2019-11-05 08:00:00	2019-11-05 09:00:00	\N
13545	08009T	REU_TRAV_PARL	2019-11-05 09:30:00	2019-11-05 10:30:00	\N
13546	08009T	REU_TRAV_PARL	2019-11-05 10:30:00	2019-11-05 11:00:00	\N
13550	08009T	REU_GVT	2019-11-05 15:40:00	2019-11-05 16:40:00	\N
13548	08009T	ORG_POL	2019-11-05 11:00:00	2019-11-05 12:30:00	\N
13549	08009T	REU_TRAV_PARL	2019-11-05 12:45:00	2019-11-05 14:00:00	\N
13551	08009T	REU_TRAV_PARL	2019-11-05 17:00:00	2019-11-05 17:30:00	\N
13552	08009T	REU_TRAV_PARL	2019-11-05 17:30:00	2019-11-05 18:00:00	\N
13553	08009T	REU_TRAV_PARL	2019-11-05 18:30:00	2019-11-05 19:30:00	\N
13554	08009T	REU_TRAV_PARL	2019-11-06 08:00:00	2019-11-06 09:00:00	\N
13555	08009T	REU_TRAV_PARL	2019-11-06 15:30:00	2019-11-06 16:30:00	\N
13556	08009T	ORG_POL	2019-11-12 11:00:00	2019-11-12 12:30:00	\N
13557	08009T	REU_TRAV_PARL	2019-11-12 16:30:00	2019-11-12 17:30:00	\N
13558	08009T	REU_TRAV_PARL	2019-11-13 08:00:00	2019-11-13 09:30:00	\N
13559	08009T	REU_GVT	2019-11-20 08:30:00	2019-11-20 10:00:00	\N
13560	08009T	ORG_POL	2019-11-26 11:00:00	2019-11-26 12:30:00	\N
13561	08009T	REU_TRAV_PARL	2019-11-28 14:30:00	2019-11-28 15:30:00	\N
13562	08009T	ORG_POL	2019-12-03 11:00:00	2019-12-03 12:30:00	\N
13563	08009T	REU_TRAV_PARL	2019-12-04 11:00:00	2019-12-04 12:00:00	\N
13564	08009T	ELUS_LOCAUX	2019-12-12 13:00:00	2019-12-12 14:00:00	\N
13565	08009T	REU_TRAV_PARL	2019-12-12 15:30:00	2019-12-12 16:30:00	\N
13566	08009T	ORG_POL	2019-12-17 11:00:00	2019-12-17 12:30:00	\N
13567	08009T	ACC_DEPL_INTER	2019-12-17 12:30:00	2019-12-17 14:00:00	\N
13568	08009T	REU_TRAV_PARL	2019-12-17 14:00:00	2019-12-17 15:00:00	\N
13569	08009T	ACC_DEPL_INTER	2019-12-17 16:15:00	2019-12-17 17:15:00	\N
13570	08009T	REU_TRAV_PARL	2019-12-17 17:30:00	2019-12-17 18:30:00	\N
13571	08009T	REU_TRAV_PARL	2019-12-19 13:00:00	2019-12-19 14:00:00	\N
13572	08009T	REU_TRAV_PARL	2019-12-19 14:30:00	2019-12-19 15:30:00	\N
13573	08009T	REU_TRAV_PARL	2020-01-07 09:30:00	2020-01-07 10:00:00	\N
13574	08009T	ORG_POL	2020-01-07 11:00:00	2020-01-07 12:30:00	\N
13575	08009T	REU_TRAV_PARL	2020-01-07 14:30:00	2020-01-07 15:30:00	\N
13576	08009T	REU_TRAV_PARL	2020-01-08 08:30:00	2020-01-08 09:30:00	\N
13577	08009T	REU_TRAV_PARL	2020-01-09 10:00:00	2020-01-09 11:00:00	\N
13681	04042C	REU_TRAV_PARL	2020-01-16 09:30:00	2020-01-16 12:30:00	Réunion de la Délégation Parlementaire au Renseignement
13682	04042C	DEPL_PRES_GVT	2020-01-16 13:00:00	2020-01-16 23:00:00	Voeux aux armées du Président de la République à Orléans
13683	04042C	COLL_TER	2020-01-17 08:45:00	2020-01-17 12:30:00	Réunion de bureau du Syndicat des Eaux d'Ile-de-France
13684	04042C	ACC_DEPL_INTER	2020-01-17 15:00:00	2020-01-17 16:00:00	Entretien avec l'Ambassadeur d'Algérie en France
13685	04042C	CEREMONIE	2020-01-17 19:00:00	2020-01-17 19:45:00	Cérémonie des Voeux à Périgny-sur-Yerres
13686	04042C	CEREMONIE	2020-01-17 20:15:00	2020-01-17 22:15:00	Cérémonie des Voeux à Sucy-en-Brie
13687	04042C	COLLOQUE	2020-01-20 17:00:00	2020-01-20 17:30:00	Intervention du Président Christian Cambon pour les conclusions du Colloque sur le thème de l'Hydrodiplomatie
13688	04042C	ACC_VISIT	2020-01-20 17:30:00	2020-01-20 18:00:00	Interview Public Sénat
13689	04042C	ORG_POL	2020-01-21 11:00:00	2020-01-21 11:30:00	Réunion de GRoupe des L.R au Sénat
13696	04042C	CEREMONIE	2020-01-21 19:00:00	2020-01-21 20:00:00	Cérémonie des Voeux du chef d'état-major de la Marine
13691	04042C	REU_TRAV_PARL	2020-01-21 15:00:00	2020-01-21 16:00:00	Réunion de Direction
13694	04042C	CEREMONIE	2020-01-21 12:00:00	2020-01-21 13:15:00	Cérémonie des Voeux au monde combattant de Madame la Secrétaire d'Etat auprès de la Ministre des armées à l'Hôtel National des Invalides
13693	04042C	ACC_DEPL_INTER	2020-01-21 16:00:00	2020-01-21 17:00:00	Entretien avec Madame l'Ambassadrice de l'Equateur en France
13695	04042C	ACC_DEPL_INTER	2020-01-21 17:00:00	2020-01-21 18:00:00	Entretien avec la Présidente de la Fondation First Alliance
13697	04042C	ORG_POL	2020-01-21 20:15:00	2020-01-21 22:00:00	Rencontre avec les Experts des Forums Thématiques des L.R
13701	04018C	ELUS_LOCAUX	2020-01-16 19:00:00	2020-01-16 21:00:00	Cérémonie de voeux
13788	04018C	ORGEXTPAR	2020-03-19 09:30:00	2020-03-19 17:30:00	Commission supérieure sites perspectives et paysages
13703	04018C	ORGEXTPAR	2020-01-23 09:30:00	2020-01-23 17:00:00	Commission supérieure sites perspectives et paysages
13785	04018C	ELUS_LOCAUX	2020-02-04 20:00:00	2020-02-04 23:00:00	\N
13786	04018C	CEREMONIE	2020-02-05 18:30:00	2020-02-05 21:30:00	\N
13706	04018C	ORGEXTPAR	2020-01-30 14:00:00	2020-01-30 18:00:00	Haut Conseil aux Musées de France
13762	08010L	ORG_POL	2020-01-28 11:00:00	2020-01-28 12:30:00	Groupe LR du Sénat
13784	04018C	ELUS_LOCAUX	2020-01-28 19:30:00	2020-01-28 21:00:00	\N
13881	04086Q	ORG_POL	2020-02-04 11:00:00	2020-02-04 12:30:00	Réunion du groupe LR
13983	04042C	COLL_TER	2020-02-24 19:00:00	2020-02-24 20:30:00	Réunion du Conseil de Territoire
13984	04042C	ACC_VISIT	2020-02-25 09:00:00	2020-02-25 10:00:00	Entretien avec des directeurs de Safran Group
13985	04042C	ORG_POL	2020-02-25 11:00:00	2020-02-25 12:15:00	Réunion du Groupe L.R du Sénat
13986	04042C	ACC_DEPL_INTER	2020-02-25 12:30:00	2020-02-25 14:30:00	Réception à l'Ambassade d'Estonie à l'occasion du 102ème anniversaire de la République d'Estonie
14021	04042C	ACC_DEPL_INTER	2020-02-26 12:30:00	2020-02-26 14:30:00	Réception à l'Ambassade du Koweït à l'occasion du 59ème anniversaire de l'Indépendance et le 29ème anniversaire de la libération de l'Etat du Koweït
14023	04086Q	REU_TRAV_PARL	2020-02-26 08:30:00	2020-02-26 09:30:00	Réunion de travail décentralisation 
14101	08010L	REU_TRAV_PARL	2020-03-03 16:00:00	2020-03-03 18:00:00	Justice / Mission Controle ENAP
14111	11103C	REU_TRAV_PARL	2020-01-22 08:30:00	2020-01-22 09:30:00	Rapport Dégâts de gibier
14103	11103C	ORG_POL	2020-03-04 08:00:00	2020-03-04 09:00:00	Amicale gaulliste
14104	11103C	ORGEXTPAR	2020-03-03 14:00:00	2020-03-03 18:30:00	Office Français de la Biodiversité
14109	11103C	ORG_POL	2020-02-04 11:00:00	2020-02-04 12:30:00	LR du Sénat
14112	11103C	ORG_POL	2020-01-14 11:00:00	2020-01-14 12:30:00	LR du Sénat
14113	11103C	CEREMONIE	2020-01-14 18:30:00	2020-01-14 19:30:00	Voeux du Président du Sénat
14117	11103C	CEREMONIE	2019-12-10 20:00:00	2019-12-10 21:00:00	\N
14118	11103C	ORG_POL	2019-12-03 11:00:00	2019-12-03 12:30:00	LR du Sénat
14119	11103C	ORG_POL	2019-11-26 11:00:00	2019-11-26 12:30:00	LR du Sénat
14122	11103C	ORG_POL	2019-11-05 11:00:00	2019-11-05 12:30:00	LR du Sénat
14132	04086Q	REU_TRAV_PARL	2020-03-03 13:30:00	2020-03-03 14:30:00	AG du groupe d'Amitié France-Allemagne
14341	08010L	ORG_POL	2020-05-12 10:30:00	2020-05-12 12:00:00	Groupe LR du Sénat 
14221	08010L	REU_GVT	2020-04-14 10:00:00	2020-04-14 11:00:00	Comité COVID Préfecture
14222	08010L	REU_TRAV_PARL	2020-04-14 11:00:00	2020-04-14 12:30:00	Groupe LR du Sénat
14501	08010L	REU_TRAV_PARL	2020-06-04 17:00:00	2020-06-04 18:30:00	démarchage téléphonique
14561	04042C	ORG_POL	2020-06-02 11:00:00	2020-06-02 12:00:00	Réunion du Groupe L.R en Visioconférence
14562	04042C	DEL_ACT_PAR	2020-06-02 16:00:00	2020-06-02 17:00:00	Webinaire de l'AP/OTAN en Visioconférence
14563	04042C	ACC_VISIT	2020-06-03 16:30:00	2020-06-03 16:45:00	Interview Public Sénat
14564	04042C	REU_TRAV_PARL	2020-06-03 16:45:00	2020-06-03 17:45:00	\N
14565	04042C	ACC_DEPL_INTER	2020-06-03 20:00:00	2020-06-03 22:30:00	Reception à l'Ambassade de Suède
14566	04042C	COLL_TER	2020-06-04 10:00:00	2020-06-04 12:00:00	Réunion de bureau du Syndicat des Eaux d'Ile-de-France en Visioconférence
14567	04042C	ELUS_LOCAUX	2020-06-05 10:30:00	2020-06-05 12:00:00	Réunion Urbanisme à la Mairie de Saint-Maurice
14568	04042C	ACC_DEPL_INTER	2020-06-08 15:00:00	2020-06-08 16:00:00	Entretien avec le Président du Sénat et L'ambassadeur de la Federation de Russie
14569	04042C	COLL_TER	2020-06-08 19:00:00	2020-06-08 20:30:00	Réunion du Conseil de territoire du Val-de-Marne
14570	04042C	ORG_POL	2020-06-09 11:00:00	2020-06-09 12:30:00	Réunion du bureau du Groupe des LR en Visioconférence
14571	04042C	REU_TRAV_PARL	2020-06-11 11:45:00	2020-06-11 12:45:00	Réunion de Direction
14572	04042C	ACC_DEPL_INTER	2020-06-11 13:00:00	2020-06-11 14:15:00	Réception à l'Ambassade de la Fédération de Russie à l'occasion de la Fête nationale
14573	04042C	ELUS_LOCAUX	2020-06-12 10:00:00	2020-06-12 12:30:00	Réunion Urbanisme à la Mairie de Saint-Maurice
14574	04042C	COLL_TER	2020-06-15 15:00:00	2020-06-15 17:00:00	Réunion relations internationales et solidarité du Syndicat des Eaux d'Ile-de-France
14575	04042C	ELUS_LOCAUX	2020-06-15 19:00:00	2020-06-15 21:00:00	Conseil municipal de Saint-Maurice
14576	04042C	ORG_POL	2020-06-16 11:00:00	2020-06-16 12:00:00	Réunion du bureau du Groupe L.R en Visioconférence
14582	04042C	ACC_VISIT	2020-06-17 18:45:00	2020-06-17 19:45:00	Entretien avec le Directeur de la Stratégie d'Airbus
14578	04042C	REU_TRAV_PARL	2020-06-16 15:30:00	2020-06-16 16:30:00	Entretien téléphonique avec le Chef d'état major de la marine
14581	08010L	REU_TRAV_PARL	2020-06-23 11:00:00	2020-06-23 13:00:00	Groupe LR du Sénat Visio
14583	04042C	REU_TRAV_PARL	2020-06-17 14:00:00	2020-06-17 15:00:00	Conférence des Présidents
13641	04086Q	REU_TRAV_PARL	2020-01-08 14:30:00	2020-01-08 15:00:00	Rendez-vous de travail commission des finances
13642	04086Q	ORG_POL	2020-01-07 11:00:00	2020-01-07 12:30:00	Réunion du groupe LR
13862	04042C	ACC_VISIT	2020-02-03 10:00:00	2020-02-03 11:30:00	Visite guidée d'une classe de Terminale de Créteil
13882	04086Q	REU_TRAV_PARL	2020-02-06 17:00:00	2020-02-06 18:00:00	Audition dans le cadre de son rapport sur le logement
13883	04042C	ACC_DEPL_INTER	2020-02-06 20:00:00	2020-02-06 22:00:00	Rencontre avec l'Ambassadrice de Suède et le Président du parti modéré
13884	04042C	COLL_TER	2020-02-07 08:45:00	2020-02-07 12:30:00	Réunion du bureau du Syndicat des Eaux d'Ile-de-France
14301	08010L	REU_TRAV_PARL	2020-04-30 09:30:00	2020-04-30 11:00:00	Visioconférence Délégation Territoriale
14302	08010L	REU_TRAV_PARL	2020-04-30 10:00:00	2020-04-30 13:00:00	CA virtuel FED EPL
14584	04042C	ELUS_LOCAUX	2020-06-19 19:00:00	2020-06-19 21:00:00	Soirée de remerciements aux élus de Limeil-Brévannes
14462	08010L	REU_TRAV_PARL	2020-06-02 10:00:00	2020-06-02 11:00:00	visio Bureau FedEPL
14463	08010L	ORG_POL	2020-06-02 10:30:00	2020-06-02 12:30:00	Groupe LR du Sénat Visio
14585	04042C	REU_TRAV_PARL	2020-06-11 18:00:00	2020-06-11 18:30:00	Entretien téléphonique avec le Président Directeur Général du GIFAS
14586	04042C	ACC_DEPL_INTER	2020-06-22 20:00:00	2020-06-22 22:30:00	Dîner officiel du Président de la République en l'honneur du Président de la République de la Tunisie
14587	08010L	REU_TRAV_PARL	2020-06-23 14:30:00	2020-06-23 16:30:00	Comité stratégique de la Fed-EPL
14882	11103C	REU_TRAV_PARL	2020-07-21 18:00:00	2020-07-21 19:00:00	Assemblée nationale : Mission d'information sur les moyens de juguler les entraves et obstructions opposées à l'exercice de certaines activités légales
14741	08010L	ORG_POL	2020-07-07 11:00:00	2020-07-07 13:00:00	Groupe LR du Sénat
14742	08010L	REU_TRAV_PARL	2020-07-07 13:00:00	2020-07-07 14:30:00	Délégation aux Collectivités territotiales 
14861	08010L	ORG_POL	2020-07-21 11:00:00	2020-07-21 13:00:00	Groupe LR du Sénat
15022	04042C	REU_TRAV_PARL	2020-10-01 10:00:00	2020-10-01 10:30:00	Rendez-vous avec un sénateur
14941	04042C	COLL_TER	2020-09-14 19:00:00	2020-09-14 21:00:00	Réunion du Conseil du territoire
15021	04042C	ORG_POL	2020-09-30 10:30:00	2020-09-30 12:30:00	Réunion de Groupe des L.R au Sénat
15023	04042C	ACC_VISIT	2020-10-01 12:30:00	2020-10-01 14:30:00	Rencontre avec un élu du Val-de-Marne
15024	04042C	REU_TRAV_PARL	2020-10-01 20:00:00	2020-10-01 22:15:00	Rencontre avec le chef-d'état major d'armée aérienne
15025	04042C	COLL_TER	2020-10-02 08:45:00	2020-10-02 12:00:00	Réunion du bureau du SEDIF
15026	04042C	REU_TRAV_PARL	2020-10-02 12:30:00	2020-10-02 13:45:00	Rencontre avec le chef d'état-major de la marine
15041	08010L	ORG_POL	2020-10-06 11:00:00	2020-10-06 12:30:00	Groupe LR du Sénat
15061	04042C	ELUS_LOCAUX	2020-10-05 10:00:00	2020-10-05 10:30:00	Réunion avec le Maire de Saint-Maurice
15062	04042C	ELUS_LOCAUX	2020-10-05 10:30:00	2020-10-05 12:15:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
15063	04042C	ACC_DEPL_INTER	2020-10-05 13:00:00	2020-10-05 14:15:00	Rencontre avec la nouvelle Ambassadrice de Grèce
15064	04042C	ACC_DEPL_INTER	2020-10-05 15:30:00	2020-10-05 16:30:00	Entretien avec l'Ambassadrice d'Arménie
15065	04042C	ORG_POL	2020-10-05 17:30:00	2020-10-05 22:30:00	Réunion de Groupe les Républicains au Sénat
15066	04042C	REU_GVT	2020-10-06 08:30:00	2020-10-06 09:30:00	Réunion sur le Brexit avec le Secrétaire d'état chargé des Affaires européennes
15067	04042C	ORG_POL	2020-10-06 11:00:00	2020-10-06 12:30:00	Réunion de Groupe des L.R au Sénat
15068	04042C	ELUS_LOCAUX	2020-10-06 13:00:00	2020-10-06 14:30:00	Rencontre avec un élu du Val-de-Marne
15069	04042C	REU_TRAV_PARL	2020-10-06 18:00:00	2020-10-06 18:30:00	Réunion inaugurale des Présidents de Commission, du Rapporteur général et des référents de Commission
15070	04042C	ORG_POL	2020-10-07 11:00:00	2020-10-07 12:00:00	Réunion des membres Les Républicains
15071	04042C	COLL_TER	2020-10-07 14:00:00	2020-10-07 15:30:00	Réunion de travail avec les hôpitaux de Saint-Maurice
15142	08010L	REU_TRAV_PARL	2020-10-15 14:00:00	2020-10-15 17:00:00	Cabinet du sénat
14902	04086Q	ELUS_LOCAUX	2020-09-10 11:00:00	2020-09-10 12:30:00	Rendez-vous de travail avec un élu local
15081	04042C	REU_TRAV_PARL	2020-10-08 08:00:00	2020-10-08 14:00:00	Déplacement à Versailles Satory - Présentation des capacités de l'armée de terre
15082	04042C	ACC_VISIT	2020-10-08 14:30:00	2020-10-08 15:30:00	Interview documentaire Public Senat
15083	04042C	ELUS_LOCAUX	2020-10-09 11:00:00	2020-10-09 12:30:00	Commission administrative générale finances et urbanisme à la Mairie de Saint-Maurice
15084	04042C	ACC_VISIT	2020-10-09 14:45:00	2020-10-09 15:00:00	Interview Public Sénat
15085	04042C	ACC_VISIT	2020-10-09 15:00:00	2020-10-09 15:15:00	Interview RFI
15101	08010L	ORG_POL	2020-10-13 11:00:00	2020-10-13 13:00:00	Groupe LR du Sénat
15187	04042C	ACC_VISIT	2020-10-16 07:15:00	2020-10-16 08:00:00	Emission Public Sénat
15181	11103C	ORG_POL	2020-10-20 11:00:00	2020-10-20 12:30:00	LR du Sénat
15302	08010L	REU_TRAV_PARL	2020-11-03 17:00:00	2020-11-03 18:30:00	Cabinet du sénat
15188	04042C	REU_TRAV_PARL	2020-10-16 15:30:00	2020-10-16 16:30:00	Reunion de travail avec des Conseillers parlementaires
15192	04042C	REU_TRAV_PARL	2020-10-16 16:45:00	2020-10-16 17:45:00	Réunion de Direction
15190	04042C	ELUS_LOCAUX	2020-10-16 19:00:00	2020-10-16 22:00:00	Rencontre avec des élus du Val-de-Marne
15191	04042C	ACC_VISIT	2020-10-16 16:35:00	2020-10-16 16:45:00	Interview TV5 Monde
15193	04042C	ACC_DEPL_INTER	2020-10-19 18:30:00	2020-10-19 19:30:00	Entretien avec le Président du Sénat du Premier Ministre irakien
15194	04042C	ORG_POL	2020-10-20 11:00:00	2020-10-20 12:30:00	Réunion de Groupe les Républicains au Sénat
15195	04042C	ELUS_LOCAUX	2020-10-20 15:00:00	2020-10-20 16:00:00	Visioconference avec le Président de l'Association Elus Solidaires 94
15196	04042C	ELUS_LOCAUX	2020-10-21 13:00:00	2020-10-21 14:30:00	Rencontre avec un élu du Val-de-Marne
15197	04042C	ACC_DEPL_INTER	2020-10-21 15:30:00	2020-10-21 16:30:00	Entretien avec le Vice-président du Sénat de Côte d'Ivoire
15301	08010L	ORG_POL	2020-11-03 11:00:00	2020-11-03 13:00:00	Groupe LR du Sénat
15303	04042C	ACC_DEPL_INTER	2020-10-29 13:00:00	2020-10-29 14:15:00	Rencontre avec l'Ambassadrice de l'Arménie en France
15304	04042C	ACC_DEPL_INTER	2020-10-30 15:00:00	2020-10-30 16:00:00	Visite de courtoisie du nouvel Ambassadeur d'Allemagne en France
15305	04042C	REU_TRAV_PARL	2020-10-30 16:00:00	2020-10-30 17:00:00	Rendez-Vous téléphonique 
15306	04042C	COLL_TER	2020-11-02 18:00:00	2020-11-02 19:00:00	Audiconférence avec le Préfet du Val-de-Marne sur la situation épidémique et à la mise en place des nouvelles mesures
15307	04042C	REU_GVT	2020-11-03 09:00:00	2020-11-03 10:15:00	Présentation du cadrage stratégique aux présidents des commissions
15308	04042C	REU_TRAV_PARL	2020-11-03 10:30:00	2020-11-03 11:00:00	Entretien avec le Secrétaire général du Sénat
15309	04042C	ORG_POL	2020-11-03 11:00:00	2020-11-03 12:30:00	Réunion de Groupe des L.R au Sénat
15310	04042C	ACC_VISIT	2020-11-03 12:30:00	2020-11-03 12:45:00	Interview Public Sénat
15311	04042C	REU_TRAV_PARL	2020-11-03 14:00:00	2020-11-03 14:30:00	Entretien téléphonique avec un député
15312	04042C	ACC_DEPL_INTER	2020-11-03 15:30:00	2020-11-03 16:30:00	Visite de courtoisie du nouvel Ambassadeur de Chypre en France
15313	04042C	ACC_VISIT	2020-11-03 16:30:00	2020-11-03 17:30:00	Entretien avec un responsable de France 24
15314	04042C	ORG_POL	2020-11-04 08:00:00	2020-11-04 09:00:00	Réunion de préparation du Projet de Loi de Finance
15321	04086Q	REU_TRAV_PARL	2020-10-27 17:00:00	2020-10-27 18:00:00	Bureau de la délégation aux collectivités territoriales 
15322	04086Q	ORG_POL	2020-10-27 11:00:00	2020-10-27 12:30:00	Réunion du groupe LR
15323	04086Q	ORG_POL	2020-10-20 11:00:00	2020-10-20 12:30:00	Réunion du groupe LR
15382	11103C	ORG_POL	2020-11-10 11:00:00	2020-11-10 12:30:00	LR du Sénat
15325	04086Q	ORG_POL	2020-10-27 13:00:00	2020-10-27 14:00:00	Déjeuner de travail des responsables et parlementaires LR
15381	08010L	REU_TRAV_PARL	2020-11-12 08:09:00	2020-11-12 09:00:00	Medef
15422	04042C	ACC_DEPL_INTER	2020-11-12 16:30:00	2020-11-12 17:30:00	Entretien avec l'Ambassadrice d'Arménie en France
15423	04042C	ACC_DEPL_INTER	2020-11-12 17:30:00	2020-11-12 18:30:00	Visioconférence avec le Président de la Commission de la Défense et des Affaires étrangères du Parlement Grec
15424	04042C	DEPL_PRES_GVT	2020-11-13 08:00:00	2020-11-13 20:00:00	Déplacement à Bourges et à Lorient avec la Ministre des armées
15425	04042C	ELUS_LOCAUX	2020-11-16 10:30:00	2020-11-16 12:30:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
15426	04042C	ACC_DEPL_INTER	2020-11-16 15:00:00	2020-11-16 16:00:00	Entretien avec l'Ambassadeur de Turquie en France
13531	04042C	ACC_VISIT	2020-01-07 09:40:00	2020-01-07 11:00:00	Visite guidée des élèves du Lycée de Charenton-le-Pont
13532	04042C	ACC_DEPL_INTER	2020-01-07 12:15:00	2020-01-07 12:45:00	Entretien avec le Commissaire européen au Commerce
13533	04042C	REU_TRAV_PARL	2020-01-07 15:00:00	2020-01-07 16:00:00	Réunion de Direction
13534	04042C	CEREMONIE	2020-01-07 20:00:00	2020-01-07 21:00:00	Cérémonie des Voeux de Saint-Maurice
13535	04042C	REU_GVT	2020-01-08 08:30:00	2020-01-08 09:30:00	Entretien avec Madame la Ministre des Armées
13536	04042C	ACC_VISIT	2020-01-08 16:30:00	2020-01-08 17:30:00	Entretien avec le Directeur de la Gendarmerie nationale
13537	04042C	CEREMONIE	2020-01-08 19:00:00	2020-01-08 20:00:00	Cérémonie des Voeux de Maisons-Alfort
13667	08010L	ELUS_LOCAUX	2020-01-16 10:30:00	2020-01-16 12:00:00	Inauguration "Les Décideurs" Soissons
13981	04042C	ACC_DEPL_INTER	2020-02-21 17:00:00	2020-02-21 18:00:00	Entretien avec l'Ambassadeur d'Australie en France
13982	04042C	REU_TRAV_PARL	2020-02-21 18:00:00	2020-02-21 19:00:00	Réunion de direction
14022	04086Q	ORG_POL	2020-02-25 11:00:00	2020-02-25 12:30:00	Réunion du groupe LR
14024	04086Q	REU_TRAV_PARL	2020-02-26 16:30:00	2020-02-26 17:30:00	Reunion de travail sur le financement du grand Paris Express
14081	08010L	ORG_POL	2020-03-03 11:00:00	2020-03-03 12:30:00	Groupe LR du Sénat
14082	08010L	CEREMONIE	2020-03-03 12:30:00	2020-03-03 14:15:00	GIA France Etats-Unis / Ambassade
14241	08010L	ORG_POL	2020-04-21 11:30:00	2020-04-21 13:00:00	Groupe LR du senat
14521	08010L	ORG_POL	2020-06-09 10:30:00	2020-06-09 13:00:00	Groupe LR du Sénat Visio
14541	08010L	REU_TRAV_PARL	2020-06-16 10:30:00	2020-06-16 11:00:00	Commission des finances 
14522	08010L	REU_TRAV_PARL	2020-06-09 14:30:00	2020-06-09 16:00:00	Décentralisation 
14245	08010L	REU_TRAV_PARL	2020-04-23 09:30:00	2020-04-23 10:30:00	Délégation collectivités territoriales 
14281	08010L	ELUS_LOCAUX	2020-04-29 15:00:00	2020-04-29 17:00:00	Bureau Union des Maires de l'Aisne
14363	08010L	REU_TRAV_PARL	2020-05-14 11:00:00	2020-05-14 13:00:00	Cabinet du sénat
14322	08010L	ORG_POL	2020-05-05 10:30:00	2020-05-05 12:00:00	Groupe LR du sénat 
14361	08010L	REU_TRAV_PARL	2020-05-12 14:30:00	2020-05-12 17:00:00	Cabinet du sénat
14362	08010L	REU_TRAV_PARL	2020-05-14 09:00:00	2020-05-14 10:30:00	Bureau de la Délégation territoriale 
14542	08010L	ORG_POL	2020-06-16 11:00:00	2020-06-16 12:30:00	Groupe LR du Sénat Visio
14641	08010L	ORG_POL	2020-06-30 11:00:00	2020-06-30 12:30:00	Groupe LR du Sénat
14049	08009T	REU_TRAV_PARL	2020-01-15 10:00:00	2020-01-15 11:00:00	\N
14903	04086Q	ELUS_LOCAUX	2020-09-10 12:30:00	2020-09-10 14:00:00	Déjeuner de travail avec un élu local
14905	04086Q	REU_TRAV_PARL	2020-09-15 09:00:00	2020-09-15 10:00:00	Audition de la mission d'information sur la Guyane Française 
14906	04086Q	REU_TRAV_PARL	2020-09-15 11:00:00	2020-09-15 12:30:00	Présentation su rapport sur le trafic de stupéfiant en Guyane Française
14907	04086Q	ELUS_LOCAUX	2020-09-15 12:30:00	2020-09-15 14:00:00	Déjeuner de travail avec un élu local
15361	08010L	ORG_POL	2020-11-10 11:00:00	2020-11-10 12:30:00	Groupe LR du Sénat 
15201	04042C	CEREMONIE	2020-10-21 19:00:00	2020-10-21 20:30:00	Hommage national à Samuel PATY dans la Cour de la Sorbonne
15284	11103C	ORG_POL	2020-10-27 11:00:00	2020-10-27 12:30:00	LR du Sénat
15427	04042C	ACC_DEPL_INTER	2020-11-16 16:30:00	2020-11-16 17:30:00	Entretien avec le Président du Sénat de l'Ambassadrice d'Arménie en France
15441	08010L	ORG_POL	2020-11-17 11:00:00	2020-11-17 12:30:00	Groupe LR du Sénat
15442	04042C	CEREMONIE	2020-11-17 10:15:00	2020-11-17 12:00:00	Hommage au pilote Sébastien BOTTA
15443	04042C	REU_TRAV_PARL	2020-11-17 13:00:00	2020-11-17 14:30:00	Rencontre avec le Président du Sénat et les Présidents de commission
15444	11103C	ORG_POL	2020-11-17 11:00:00	2020-11-17 12:30:00	LR du Sénat
15461	04042C	COLL_TER	2020-11-16 18:30:00	2020-11-16 20:00:00	Commission d'installation Développemnt économique Emploi de l'Intercommunalité Paris Est Marne & Bois
15462	04042C	ACC_VISIT	2020-11-18 15:00:00	2020-11-18 16:00:00	Entretien avec un Sénateur honoraire et un Journaliste d'Africa Intelligence
15463	04042C	REU_TRAV_PARL	2020-11-18 16:30:00	2020-11-18 17:30:00	Entretien avec le Président du GICAT
15464	04042C	REU_TRAV_PARL	2020-11-18 17:30:00	2020-11-18 18:30:00	Entretien avec un sénateur 
15465	04042C	REU_TRAV_PARL	2020-11-18 14:45:00	2020-11-18 15:00:00	Entretien avec deux Sénateurs
15481	04042C	DEPL_PRES_GVT	2020-11-19 11:00:00	2020-11-19 17:00:00	Déplacement avec Madame la Ministre des armées pour une visite de Dassault aviation à Seclin
15482	04042C	ACC_DEPL_INTER	2020-11-20 09:30:00	2020-11-20 10:00:00	Entretien telephonique avec l'Ambassadeur d'Allemagne en France
15483	04042C	ACC_DEPL_INTER	2020-11-20 10:30:00	2020-11-20 11:30:00	Entretien avec l'Ambassadeur du Maroc en France
15484	04042C	ACC_VISIT	2020-11-20 11:30:00	2020-11-20 12:30:00	Réunion avec des élus pour le Syndicat des eaux d'Ile-de-France
15485	04042C	ACC_DEPL_INTER	2020-11-20 16:30:00	2020-11-20 17:30:00	Entetien avec un ancien Ambassadeur 
15501	08010L	ORG_POL	2020-11-24 11:00:00	2020-11-24 12:30:00	Groupe LR Senat
15502	20152B	ELUS_LOCAUX	2020-11-03 19:00:00	2020-11-03 20:30:00	\N
15503	20152B	CEREMONIE	2020-11-11 11:00:00	2020-11-11 12:00:00	\N
15504	20152B	CEREMONIE	2020-11-11 16:45:00	2020-11-11 17:30:00	\N
15522	04043D	REU_TRAV_PARL	2020-11-24 17:00:00	2020-11-24 18:30:00	Conseil d'administration de l'AGAS
15506	20152B	ELUS_LOCAUX	2020-11-25 18:00:00	2020-11-25 20:00:00	\N
15507	20152B	ELUS_LOCAUX	2020-11-18 18:00:00	2020-11-18 20:00:00	\N
15521	11103C	ORG_POL	2020-11-24 11:00:00	2020-11-24 12:30:00	Groupe LR du Sénat
15523	04042C	ELUS_LOCAUX	2020-11-23 11:00:00	2020-11-23 12:15:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
15524	04042C	COLL_TER	2020-11-24 10:00:00	2020-11-24 11:00:00	Visioconference du Syndicat des Eaux d'Ile-de-France
15525	04042C	ORG_POL	2020-11-24 11:00:00	2020-11-24 12:30:00	Réunion de Groupe des L.R au Sénat
15526	04042C	REU_TRAV_PARL	2020-11-24 18:30:00	2020-11-24 19:00:00	Entretien avec un Sénateur
15527	04042C	REU_TRAV_PARL	2020-11-25 12:30:00	2020-11-25 13:30:00	Réunion des Présidents de commission , le Rapporteur général et les référents de commission
15528	04042C	ACC_VISIT	2020-11-25 14:45:00	2020-11-25 15:00:00	Interview Public Sénat
15541	04086Q	REU_TRAV_PARL	2020-11-12 12:30:00	2020-11-12 14:00:00	Déjeuner de travail avec l'USH
15542	04086Q	REU_TRAV_PARL	2020-11-13 15:50:00	2020-11-13 17:00:00	Audition dans le cadre de son rapport sur le logement - ANAH
15543	04086Q	REU_TRAV_PARL	2020-11-18 12:00:00	2020-11-18 14:00:00	Rendez-vous de travail pour le PLF
15544	04086Q	REU_TRAV_PARL	2020-11-24 08:00:00	2020-11-24 09:00:00	Rendez-vous de travail à la présidence du Sénat
15545	04086Q	REU_TRAV_PARL	2020-11-24 09:30:00	2020-11-24 10:30:00	Rendez-vous de travail le cabinet de M. Wargon pour le PLF
15546	04086Q	ORG_POL	2020-11-24 11:00:00	2020-11-24 12:30:00	Réunion du groupe LR
15547	04086Q	ORG_POL	2020-11-17 11:00:00	2020-11-17 12:30:00	Réunion du groupe LR
15548	04086Q	REU_TRAV_PARL	2020-11-25 16:30:00	2020-11-25 18:00:00	Réunion de travail pour la DCT pour le rapport sur la Gouvernance du Grand Paris
15583	20024T	COLL_TER	2020-11-19 08:30:00	2020-11-19 14:00:00	DOB - DEPARTEMENT DE LA VIENNE
15562	20024T	CEREMONIE	2020-11-11 12:15:00	2020-11-11 12:30:00	MONTS-SUR-GUESNES
15581	20024T	CEREMONIE	2020-11-11 11:15:00	2020-11-11 11:30:00	LOUDUN
15582	20024T	COLL_TER	2020-11-19 20:15:00	2020-11-19 23:45:00	CONSEIL MUNICIPAL DE MONTS-SUR-GUESNES
15584	04042C	REU_TRAV_PARL	2020-11-27 11:00:00	2020-11-27 11:30:00	Entretien avec le Secrétaire général du Sénat
15585	04042C	COLL_TER	2020-11-27 18:00:00	2020-11-27 19:00:00	Visioconférence avec tous les Maires et les parlementaires et la Présidente de la Région Ile-de-France
15586	04042C	ACC_VISIT	2020-11-25 14:45:00	2020-11-25 15:00:00	Interview Public Sénat
15587	04042C	ACC_DEPL_INTER	2020-11-27 16:00:00	2020-11-27 17:00:00	Entretien téléphonique avec l'Amssadeur de France en Italie
15588	04042C	REU_TRAV_PARL	2020-11-30 11:00:00	2020-11-30 12:00:00	Visioconférence avec l'Institut Montaigne
15589	04042C	ACC_DEPL_INTER	2020-11-30 15:30:00	2020-11-30 16:30:00	Entretien avec le Président du Sénat et l'Ambassadeur de Turquie en France
15590	04042C	ACC_DEPL_INTER	2020-12-01 10:00:00	2020-12-01 11:00:00	Entretien avec l'Ambassadeur de Taïwan en France
15591	04042C	ORG_POL	2020-12-01 11:00:00	2020-12-01 12:30:00	Réunion de Groupe des L.R au Sénat
15592	04042C	REU_TRAV_PARL	2020-11-30 17:00:00	2020-11-30 17:30:00	Entretien avec un Sénateur 
15593	04042C	ACC_VISIT	2020-11-30 17:30:00	2020-11-30 18:00:00	Interview téléphonque Radio Marocaine MEDI
13721	08010L	REU_TRAV_PARL	2020-01-21 09:30:00	2020-01-21 14:00:00	CA Fédération des EPL
13722	08010L	REU_TRAV_PARL	2020-01-21 14:30:00	2020-01-21 15:00:00	Bureau de la Commission dEnquète 
13723	04042C	CEREMONIE	2020-01-22 12:30:00	2020-01-22 14:30:00	Cérémonie des Voeux aux anciens combattants de Charenton-le-Pont
13724	04042C	CEREMONIE	2020-01-22 19:30:00	2020-01-22 20:30:00	Cérémonie des Voeux de Madame la Minsitre des armées
13725	04042C	CEREMONIE	2020-01-22 21:00:00	2020-01-22 22:30:00	Cérémonie des Voeux de Limeil-Brévannes
13962	04086Q	DEL_ACT_PAR	2020-02-19 08:00:00	2020-02-19 09:30:00	Petit-déjeuner débat de l'amicale Gaulliste sur la Nouvelle Calédonie
14045	08009T	ORG_POL	2020-01-14 11:00:00	2020-01-14 12:30:00	\N
14042	08009T	REU_TRAV_PARL	2020-01-14 10:30:00	2020-01-14 11:00:00	\N
14043	08009T	REU_TRAV_PARL	2020-01-14 10:00:00	2020-01-14 10:30:00	\N
14047	08009T	REU_TRAV_PARL	2020-01-14 15:30:00	2020-01-14 16:30:00	\N
14046	08009T	ORG_POL	2020-01-14 12:30:00	2020-01-14 14:30:00	\N
14048	08009T	REU_TRAV_PARL	2020-01-15 08:30:00	2020-01-15 09:30:00	\N
14050	08009T	REU_TRAV_PARL	2020-01-16 08:00:00	2020-01-16 09:00:00	\N
14051	08009T	REU_TRAV_PARL	2020-01-16 09:00:00	2020-01-16 10:00:00	\N
14055	08009T	REU_TRAV_PARL	2020-01-22 14:30:00	2020-01-22 15:30:00	\N
14053	08009T	REU_TRAV_PARL	2020-01-21 18:30:00	2020-01-21 19:30:00	\N
14054	08009T	REU_TRAV_PARL	2020-01-22 08:30:00	2020-01-22 09:30:00	\N
14056	08009T	REU_TRAV_PARL	2020-01-28 09:00:00	2020-01-28 10:00:00	\N
14057	08009T	REU_TRAV_PARL	2020-01-28 14:45:00	2020-01-28 16:00:00	\N
14058	08009T	REU_TRAV_PARL	2020-02-04 15:30:00	2020-02-04 16:30:00	\N
14059	08009T	REU_TRAV_PARL	2020-02-04 18:30:00	2020-02-04 19:30:00	\N
14060	08009T	REU_GVT	2020-02-04 20:30:00	2020-02-04 22:00:00	\N
14061	08009T	REU_TRAV_PARL	2020-02-05 16:30:00	2020-02-05 17:30:00	\N
14062	08009T	REU_TRAV_PARL	2020-02-06 07:00:00	2020-02-06 18:30:00	\N
14063	08009T	ORG_POL	2020-02-25 11:10:00	2020-02-25 12:30:00	\N
14064	08009T	REU_TRAV_PARL	2020-02-25 17:30:00	2020-02-25 18:30:00	\N
14065	08009T	REU_TRAV_PARL	2020-02-26 10:30:00	2020-02-26 11:30:00	\N
14066	08009T	REU_TRAV_PARL	2020-02-26 12:15:00	2020-02-26 13:45:00	\N
14067	08009T	REU_TRAV_PARL	2020-02-27 09:00:00	2020-02-27 12:00:00	\N
14068	04042C	DEPL_PRES_GVT	2020-02-24 14:00:00	2020-02-24 17:00:00	Déplacement avec le Président du Sénat à la DGSI
14069	04042C	REU_TRAV_PARL	2020-02-26 16:15:00	2020-02-26 17:45:00	Audition de la Délégation Parlementaire au Renseignement 
14070	04042C	ACC_VISIT	2020-02-27 10:00:00	2020-02-27 11:00:00	Entretien avec un journaliste de Challenge
14071	04042C	REU_TRAV_PARL	2020-02-27 11:00:00	2020-02-27 12:00:00	Réunion de Direction
14072	04042C	ACC_DEPL_INTER	2020-02-27 12:00:00	2020-02-27 13:00:00	Entretien avec le Vice-ministre des affaires étrangères de Georgie
14073	04042C	ELUS_LOCAUX	2020-02-28 10:30:00	2020-02-28 12:00:00	Réunion avec le Maire de Saint-Maurice
14074	04042C	ACC_DEPL_INTER	2020-02-28 13:00:00	2020-02-28 14:15:00	Rencontre avec le Ministre des Affaires étrangères du Liban
14075	04042C	REU_TRAV_PARL	2020-02-28 15:30:00	2020-02-28 16:00:00	Entretien avec le Président du Sénat
14141	04018C	REU_TRAV_PARL	2020-03-17 14:30:00	2020-03-17 16:00:00	Mission Restitution Oeuvre d'art
14181	08010L	ORG_POL	2020-03-31 11:00:00	2020-03-31 12:30:00	Visioconférence Groupe LR Senatt
14182	08010L	REU_TRAV_PARL	2020-04-01 10:00:00	2020-04-01 11:00:00	Centre pénitentiaire de Laon
14183	08010L	ORG_POL	2020-04-07 11:00:00	2020-04-07 12:30:00	Visioconférence Groupe LR du sénat 
14381	08010L	ORG_POL	2020-05-19 10:30:00	2020-05-19 12:30:00	Groupe LR du Sénat 
14601	11103C	ORGEXTPAR	2020-06-11 09:30:00	2020-06-11 12:30:00	Office Français de la Biodiversité
14683	11103C	ORG_POL	2020-04-21 11:00:00	2020-04-21 12:30:00	LR du Sénat
14684	11103C	ORG_POL	2020-04-28 11:00:00	2020-04-28 12:30:00	LR du Sénat
14685	11103C	ORG_POL	2020-05-05 11:00:00	2020-05-05 12:30:00	LR du Sénat
14692	11103C	ORG_POL	2020-06-23 11:00:00	2020-06-23 12:30:00	LR du Sénat
14921	04042C	CEREMONIE	2020-09-01 00:00:00	2020-09-01 00:00:00	Déplacement à Toulon sur le Porte-avions Charles de Gaulle : Cérémonie militaire présidée par Madame la Ministre des armées pour la passation de fonction du chef d'état-major de la marine
14794	04043D	REU_TRAV_PARL	2020-06-10 09:30:00	2020-06-10 11:30:00	Commission des Affaires Economiques
14795	04043D	CEREMONIE	2020-06-18 18:00:00	2020-06-18 19:00:00	Cérémonie de l'appel du 18 Juin a Vincennes
14922	04042C	CEREMONIE	2020-09-03 16:00:00	2020-09-03 17:00:00	Inauguration des locaux Digital Lab à Saint-Maurice
14923	04042C	ELUS_LOCAUX	2020-09-07 11:00:00	2020-09-07 12:30:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
14924	04042C	REU_TRAV_PARL	2020-09-07 13:00:00	2020-09-07 14:15:00	Rencontre avec un sénateur des Hauts-de-Seine 
14925	04042C	REU_TRAV_PARL	2020-09-08 10:45:00	2020-09-08 11:45:00	Réunion de Direction
14926	04042C	COLL_TER	2020-09-08 11:45:00	2020-09-08 12:45:00	Entretien avec un directeur du SEDIF
14932	04042C	ELUS_LOCAUX	2020-09-15 16:00:00	2020-09-15 17:30:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
14930	04042C	REU_TRAV_PARL	2020-09-09 15:00:00	2020-09-09 16:00:00	Visioconférence AP/OTAN
14929	04042C	DEPL_PRES_GVT	2020-09-10 11:00:00	2020-09-10 12:30:00	Inauguration par Madame la Ministre déléguée chargée de la Mémoire et des Anciens combattants de l'exposition "Obéïr, désobéïr, commander. De Gaulle. Une carrière militaire 1910-1952 au Fort de Vincennes
14931	04042C	REU_TRAV_PARL	2020-09-10 17:30:00	2020-09-10 18:30:00	Visioconférence AP/OTAN
14933	04042C	REU_TRAV_PARL	2020-09-16 15:00:00	2020-09-16 16:00:00	Visioconférence AP/OTAN
14937	04042C	COLL_TER	2020-09-17 08:30:00	2020-09-17 11:00:00	Réunion du bureau du SEDIF
14935	04042C	CEREMONIE	2020-09-17 11:30:00	2020-09-17 12:30:00	Honneur funèbre militaire De Monsieur Edgard TUPET-THOME à l'Hôtel national des Invalides présidé par Monsieur le Premier ministre
14936	04042C	REU_TRAV_PARL	2020-09-17 15:00:00	2020-09-17 16:00:00	Visioconférence AP/OTAN
14961	04042C	ELUS_LOCAUX	2020-09-22 12:30:00	2020-09-22 14:30:00	Rencontre avec un élu du Val-de-Marne
14962	04042C	ACC_VISIT	2020-09-22 14:30:00	2020-09-22 15:00:00	Interview d'une journaliste russe
14963	04042C	ELUS_LOCAUX	2020-09-22 19:30:00	2020-09-22 21:30:00	Soirée de rentrée annuelle des Jeunes Républicains à Valenton
14964	04042C	REU_TRAV_PARL	2020-09-23 11:30:00	2020-09-23 12:30:00	Réunion de travail de la Délégation parlementaire au Renseignement
14965	04042C	ELUS_LOCAUX	2020-09-23 00:00:00	2020-09-23 00:00:00	Rencontre avec des élus du Val-de-Marne
14966	04042C	REU_TRAV_PARL	2020-09-23 14:45:00	2020-09-23 15:00:00	Entretien avec un sénateur
14967	04042C	ACC_DEPL_INTER	2020-09-23 15:00:00	2020-09-23 16:00:00	Entretien avec le Représentant en France du Gouvernement Régional du Kurdistan
14968	04042C	ACC_DEPL_INTER	2020-09-23 16:00:00	2020-09-23 17:00:00	Entretien avec l'Ambassadeur de Chypre en France
14969	04042C	COLL_TER	2020-09-23 20:00:00	2020-09-23 22:00:00	Réunion de travail sur l'actualité francilienne au Conseil Régional d'Ile-de-France
14970	04042C	ELUS_LOCAUX	2020-09-24 11:00:00	2020-09-24 12:30:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
14971	04042C	ELUS_LOCAUX	2020-09-24 12:30:00	2020-09-24 14:15:00	Rencontre avec un ancien élu du Val-de-Marne
14972	04042C	COLL_TER	2020-09-24 14:30:00	2020-09-24 16:30:00	Comité d'installation du Syndicat des Eaux d'Ile-de-France
14973	04042C	COLL_TER	2020-09-25 09:00:00	2020-09-25 12:00:00	Séance plénière de la Métropole du Grand Paris
14974	04042C	ELUS_LOCAUX	2020-09-28 11:00:00	2020-09-28 12:00:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
14975	04042C	REU_TRAV_PARL	2020-09-28 15:15:00	2020-09-28 16:30:00	Réunion de Direction
14976	04042C	COLL_TER	2020-09-28 20:00:00	2020-09-28 22:30:00	Rencontre officielle du Grand Paris
14977	04042C	REU_TRAV_PARL	2020-09-29 12:30:00	2020-09-29 14:30:00	Rencontre avec le chef d'état-major de l'armée de terre
14978	04042C	ORG_POL	2020-09-29 10:30:00	2020-09-29 12:30:00	Réunion de Groupe des L.R au Sénat
14981	04086Q	ELUS_LOCAUX	2020-09-23 13:00:00	2020-09-23 14:30:00	Déjeuner de travail avec un élu local
15005	08010L	REU_TRAV_PARL	2020-09-30 19:00:00	2020-09-30 20:00:00	fin session finances 
15003	08010L	REU_TRAV_PARL	2020-09-29 10:30:00	2020-09-29 13:00:00	Cabinet du sénat
15127	04042C	ELUS_LOCAUX	2020-10-12 11:30:00	2020-10-12 12:30:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
15006	08010L	REU_TRAV_PARL	2020-10-01 10:00:00	2020-10-01 13:00:00	Réunion de cabinet
15122	08010L	REU_TRAV_PARL	2020-10-14 08:00:00	2020-10-14 09:30:00	Com finances / PLF 2021
15123	08010L	REU_TRAV_PARL	2020-10-14 10:00:00	2020-10-14 11:30:00	Cabinet du sénat
15124	08010L	COLL_TER	2020-10-14 18:00:00	2020-10-14 20:00:00	Conseil Communautaire Agglo de Laon
15126	04042C	ELUS_LOCAUX	2020-10-12 11:00:00	2020-10-12 11:30:00	Rencontre avec un élu du Val-de-Marne
13616	08010L	ORG_POL	2020-01-14 11:00:00	2020-01-14 12:30:00	Groupe LR du Sénat
13617	08010L	REU_TRAV_PARL	2020-01-14 14:30:00	2020-01-14 15:30:00	Commission des finances
13741	04043D	ORG_POL	2020-01-15 11:00:00	2020-01-15 12:30:00	CNI
13621	08010L	CEREMONIE	2020-01-14 19:00:00	2020-01-14 20:00:00	Voeux Président du Sénat 
13627	04043D	CEREMONIE	2020-01-14 18:00:00	2020-01-14 20:00:00	Cérémonie des voeux du préfet du Val-de-Marne
13742	04043D	CEREMONIE	2020-01-15 19:00:00	2020-01-15 21:00:00	Cérémonie des voeux d'Ormesson-sur-Marne
13743	04043D	CEREMONIE	2020-01-16 19:00:00	2020-01-16 21:00:00	Cérémonie des voeux de Noiseau
13744	04043D	CEREMONIE	2020-01-17 19:00:00	2020-01-17 21:00:00	Cérémonie des voeux de Périgny-sur-Yerres
13745	04043D	ORG_POL	2020-01-21 11:00:00	2020-01-21 12:00:00	Réunion de groupe
13746	04043D	CEREMONIE	2020-01-22 20:00:00	2020-01-22 22:00:00	Cérémonie des voeux de Limeil-Brévannes
13747	04043D	CEREMONIE	2020-01-24 19:00:00	2020-01-24 21:00:00	Cérémonie des voeux de Rungis
13801	08010L	CEREMONIE	2020-01-29 18:00:00	2020-01-29 20:00:00	Voeux Sous-préfecture Chateau-Thierry
13821	04086Q	ORG_POL	2020-01-21 11:00:00	2020-01-21 12:30:00	Réunion du groupe LR
13822	04086Q	ORG_POL	2020-01-28 11:00:00	2020-01-28 12:30:00	Réunion du groupe LR
13823	04086Q	COLLOQUE	2020-01-30 17:30:00	2020-01-30 21:30:00	Projection du Film Quai d'Orsay avec des Lycéens de Seine-Saint-Denis 
13824	08010L	ELUS_LOCAUX	2020-01-30 18:00:00	2020-01-30 20:00:00	Voeux  Crecy sur Serre
13825	08010L	ELUS_LOCAUX	2020-01-23 17:00:00	2020-01-23 18:30:00	Voeux FFB Aisne
13826	08010L	ELUS_LOCAUX	2020-01-23 18:30:00	2020-01-23 20:00:00	Voeux de la CC Thiérache Centre
13827	04042C	CEREMONIE	2020-01-23 19:30:00	2020-01-23 22:00:00	Cérémonie des Voeux de Veolia
13831	04042C	ACC_DEPL_INTER	2020-01-24 18:00:00	2020-01-24 19:00:00	Entretien avec le Président du Sénat du Président par interim du Vénézuela
13829	04042C	ACC_VISIT	2020-01-24 15:30:00	2020-01-24 16:30:00	Enregistrement interview pour le Syndicat des Eaux d'Ile-de-France
14001	04018C	REU_TRAV_PARL	2020-03-03 13:00:00	2020-03-03 14:30:00	\N
13832	04042C	CEREMONIE	2020-01-24 20:00:00	2020-01-24 22:00:00	Cérémonie des Voeux de Rungis
13877	01058X	REU_TRAV_PARL	2020-01-16 10:00:00	2020-01-16 12:00:00	\N
13878	08010L	REU_TRAV_PARL	2020-02-06 14:30:00	2020-02-06 18:00:00	\N
14201	08010L	REU_TRAV_PARL	2020-03-26 14:30:00	2020-03-26 21:00:00	Séance publique PLFR 2020
14401	08010L	ORG_POL	2020-05-26 10:30:00	2020-05-26 11:30:00	Groupe LR du Sénat
14421	08010L	REU_TRAV_PARL	2020-05-26 14:30:00	2020-05-26 16:00:00	ÇA de l¿UMA
14681	11103C	ORG_POL	2020-03-24 11:00:00	2020-03-24 12:30:00	LR du Sénat
14682	11103C	ORG_POL	2020-04-07 11:00:00	2020-04-07 12:30:00	LR du Sénat
14686	11103C	ORG_POL	2020-05-12 11:00:00	2020-05-12 12:30:00	LR du Sénat
14687	11103C	ORG_POL	2020-05-19 11:00:00	2020-05-19 12:30:00	LR du Sénat
14688	11103C	ORG_POL	2020-05-26 11:00:00	2020-05-26 12:30:00	LR du Sénat
14689	11103C	ORG_POL	2020-06-02 11:00:00	2020-06-02 12:30:00	LR du Sénat
14690	11103C	ORG_POL	2020-06-09 11:00:00	2020-06-09 12:30:00	LR du Sénat
14691	11103C	ORG_POL	2020-06-16 11:00:00	2020-06-16 12:30:00	LR du Sénat
14693	11103C	ORG_POL	2020-06-30 11:00:00	2020-06-30 12:30:00	LR du Sénat
14694	11103C	ORGEXTPAR	2020-07-02 14:00:00	2020-07-02 19:00:00	Office Français de la Biodiversité
14695	04042C	ORG_POL	2020-06-30 11:00:00	2020-06-30 12:00:00	Réunion de Groupe des L.R
14696	04042C	ORG_POL	2020-06-30 16:30:00	2020-06-30 17:30:00	Entretien avec le Président des L.R
14697	04042C	REU_TRAV_PARL	2020-06-30 18:00:00	2020-06-30 19:00:00	Réunion de Direction
14698	04042C	ACC_DEPL_INTER	2020-06-30 20:00:00	2020-06-30 22:00:00	Rencontre à l'Ambassade d'Italie à l'occasion du départ de l'Ambassadrice de Suèdee 
14699	04042C	ACC_DEPL_INTER	2020-07-01 13:00:00	2020-07-01 14:15:00	Entretien avec l'Ambassadrice d'Arménie en France
14700	04042C	ACC_VISIT	2020-07-01 14:45:00	2020-07-01 15:00:00	Interview Public Sénat sur l'audition de la Turquie
14701	04042C	ACC_DEPL_INTER	2020-07-01 17:00:00	2020-07-01 18:15:00	Entretien avec Madame l'Ambassadrice d'Israël en France
14702	04042C	ACC_DEPL_INTER	2020-07-01 18:30:00	2020-07-01 20:30:00	Récpetion à l'occasion du départ de Madame l'Ambrassadrice de Suède 
14703	04042C	COLL_TER	2020-07-02 08:30:00	2020-07-02 10:30:00	Rencontre avec le Directeur général d'Eau France
14724	04042C	ELUS_LOCAUX	2020-07-03 18:30:00	2020-07-03 19:30:00	Election du Maire de Vileneuve-Saint-Georges
14781	04042C	REU_TRAV_PARL	2020-07-06 17:00:00	2020-07-06 17:30:00	Entretien téléphonique avec le Chef d'état-major de la marine
14782	04042C	ORG_POL	2020-07-07 11:00:00	2020-07-07 12:30:00	Réunion de Groupe L.R
14783	04042C	ACC_DEPL_INTER	2020-07-07 13:00:00	2020-07-07 14:15:00	Rencontre avec l'Ambassadeur de Chypre en France
14784	04042C	ACC_VISIT	2020-07-07 15:00:00	2020-07-07 15:15:00	Interview Chaîne El Arabia
14785	04042C	ACC_VISIT	2020-07-07 16:00:00	2020-07-07 17:00:00	Entretien avec un Préfet
14786	04042C	REU_TRAV_PARL	2020-07-07 17:00:00	2020-07-07 17:30:00	Visite de courtoisie du Secrétaire général du Sénat
14787	04042C	COLL_TER	2020-07-07 18:00:00	2020-07-07 19:30:00	Réunion Métropole du Grand Paris
14788	04042C	REU_TRAV_PARL	2020-07-08 14:15:00	2020-07-08 15:00:00	Visioconférence Otan/Turquie
14789	04042C	COLL_TER	2020-07-09 09:00:00	2020-07-09 18:00:00	Conseil d'installation de la Métropole du Grand Paris
14790	04042C	COLL_TER	2020-07-09 19:00:00	2020-07-09 22:00:00	Conseil de Territoire
14791	04042C	ELUS_LOCAUX	2020-07-10 11:00:00	2020-07-10 12:00:00	Réunion urbanisme à la Mairie de Saint-Maurice
14792	04042C	REU_TRAV_PARL	2020-07-10 16:20:00	2020-07-10 17:00:00	Interview RT sur le rapport France-Russie
14793	04043D	COLL_TER	2020-04-10 11:00:00	2020-04-10 12:00:00	Visioconférence avec le préfet et l'ARS du Val-de-Marne
14796	04043D	COLL_TER	2020-06-26 10:30:00	2020-06-26 12:00:00	Réunion Parlementaire avec le préfet du Val-de-Marne
14797	04043D	REU_TRAV_PARL	2020-07-09 09:30:00	2020-07-09 11:30:00	OPECST
14835	04086Q	CEREMONIE	2020-07-14 09:00:00	2020-07-14 14:00:00	Cérémonie du 14 juillet avec la délégation sénatoriale
14842	04042C	ELUS_LOCAUX	2020-07-16 20:30:00	2020-07-16 22:30:00	Conseil municipal de Saint-Maurice
16721	04042C	DEPL_PRES_GVT	2021-04-26 00:00:00	2021-04-26 12:00:00	Déplacement en Arménie avec le Président du Sénat
16298	11103C	ORG_POL	2021-02-16 11:00:00	2021-02-16 12:30:00	LR du Sénat 
14840	04042C	COLL_TER	2020-07-16 13:00:00	2020-07-16 14:15:00	Reunion de travail avec la Directrice de la Communication et des Relations internationales Reunion de travail avec la Directrice de la Communication et des Relations internationales de Veolia
14841	04042C	COLL_TER	2020-07-16 16:15:00	2020-07-16 17:15:00	Réunion de travail avec le Directeur général adjoint du Syndicat des Eaux d'Ile-de-France
15001	08010L	ORG_POL	2020-09-30 10:30:00	2020-09-30 13:00:00	Groupe LR du Sénat
15128	04042C	ELUS_LOCAUX	2020-10-12 15:00:00	2020-10-12 16:00:00	Signature officielle du Contrat d'aménagement régional entre la Région Ile-de-France et la commune de Valenton
15129	04042C	REU_TRAV_PARL	2020-10-12 19:15:00	2020-10-12 19:30:00	Interview Public Sénat
15130	04042C	ORG_POL	2020-10-13 11:00:00	2020-10-13 12:30:00	Réunion de Groupe des L.R au Sénat
15131	04042C	ACC_VISIT	2020-10-13 13:00:00	2020-10-13 14:15:00	Rencontre avec un élu du Val-de-Marne
15132	04042C	CEREMONIE	2020-10-13 14:30:00	2020-10-13 15:00:00	Hommage à Christian Poncelet, ancien Président du Sénat
15133	04042C	REU_TRAV_PARL	2020-10-13 15:30:00	2020-10-13 17:00:00	Réunion de bureau de la Commission des Affaires étrangères, de la Défense et des Forces armées
15134	04042C	COLL_TER	2020-10-13 19:00:00	2020-10-13 21:00:00	CRéunion du Conseil de Territoire
15164	04043D	ACC_DEPL_INTER	2020-10-13 14:00:00	2020-10-13 15:00:00	Accueil du nouvel ambassadeur de France en Australie
15182	08010L	REU_TRAV_PARL	2020-10-20 10:00:00	2020-10-20 11:00:00	Cabinet
15183	08010L	ORG_POL	2020-10-20 11:00:00	2020-10-20 12:30:00	Groupe LR sénat 
15184	08010L	REU_TRAV_PARL	2020-10-20 16:00:00	2020-10-20 17:00:00	F/USA
15185	08010L	REU_TRAV_PARL	2020-10-20 17:00:00	2020-10-20 18:30:00	Finances/Justice
15202	04086Q	REU_GVT	2020-10-15 10:00:00	2020-10-15 11:30:00	Déjeuner de travail au cabinet d'Emmanuelle Wargon, ministre du Logement 
15203	04086Q	ACC_DEPL_INTER	2020-10-19 11:00:00	2020-10-19 14:00:00	UIP Visio, réunion du groupe des Douze Plus
15204	04086Q	REU_TRAV_PARL	2020-10-22 09:00:00	2020-10-22 10:00:00	Réunion constitutive de la délégation des collectivités territoriales
15221	04042C	ACC_DEPL_INTER	2020-10-22 16:30:00	2020-10-22 17:30:00	Entretien avec l'Ambassadeur du Danemark en France
15222	04042C	REU_TRAV_PARL	2020-10-22 18:00:00	2020-10-22 19:30:00	Réunion de travail avec le Président du Sénat
15241	08010L	ORG_POL	2020-10-27 11:00:00	2020-10-27 12:30:00	Groupe LR du Sénat
15242	04042C	ORG_POL	2020-10-27 11:00:00	2020-10-27 12:30:00	Réunion de Groupe des L.R au Sénat
15225	08010L	REU_TRAV_PARL	2020-10-22 18:30:00	2020-10-22 20:00:00	Ministère Commerce extérieur /USA
15681	11103C	ORG_POL	2020-12-01 11:00:00	2020-12-01 12:30:00	Groupe LR du Sénat
15761	11103C	ORG_POL	2020-12-08 11:00:00	2020-12-08 12:30:00	LR du Sénat
16102	04042C	ACC_VISIT	2021-01-27 15:00:00	2021-01-27 15:15:00	Interview Chaîne de télévision Dubaï al Arabiya
16061	11103C	ORG_POL	2021-01-26 11:00:00	2021-01-26 12:30:00	LR du Sénat 
16101	04042C	REU_GVT	2021-01-28 14:00:00	2021-01-28 15:30:00	Rendez-vous au Ministère de l'Intérieur avec les Maires de Valenton et de Villeneuve-Saint-Georges
16103	04042C	ACC_VISIT	2021-01-27 15:30:00	2021-01-27 16:30:00	Visite de courtoisie de la nouvelle Sous-préfète du Val-de-Marne
16104	04042C	ACC_DEPL_INTER	2021-01-27 16:30:00	2021-01-27 17:30:00	Visite de courtoisie du nouvel Ambassadeur de l'Afghanistan en France
16105	04042C	COLL_TER	2021-01-27 19:00:00	2021-01-27 20:30:00	Réunion de la commission Urbanisme, Aménagement, Habitat et Politique de Paris Est Marne & Bois
16410	14147R	REU_TRAV_PARL	2021-02-25 14:30:00	2021-02-25 17:30:00	Commission nationale consultative des droits de l'Homme - Entreprises et droits de l'Homme
16111	20152B	REU_TRAV_PARL	2021-01-27 16:30:00	2021-01-27 18:30:00	Groupe ruralité
16409	14147R	REU_TRAV_PARL	2021-02-24 00:00:00	2021-02-24 00:00:00	Commission nationale consultative des droits de l'Homme - Rapport sur la lutte contre le racisme, l'antisémitisme et la xénophobie
16411	14147R	REU_TRAV_PARL	2021-03-09 00:00:00	2021-03-09 00:00:00	Commission nationale consultative des droits de l'Homme - Réunion sur l'exploitation sexuelle des mineurs
16464	04042C	COLL_TER	2021-03-22 08:30:00	2021-03-22 12:00:00	Réunion du Club des Grands Services Zone Europe-Afrique-Asie Pacifique du Syndicat des Eaux d'Ile-de-France
16465	04042C	COLL_TER	2021-03-22 14:30:00	2021-03-22 18:00:00	Réunion du Club des Grands Services Zone Europe-Amérique du Syndicat des Eaux d'Ile-de-France
16466	01058X	REU_TRAV_PARL	2021-03-10 16:30:00	2021-03-10 17:30:00	Évaluation du plan national de gestion des matières et déchets radioactifs (PNGMDR)
16467	01058X	REU_TRAV_PARL	2021-03-10 17:30:00	2021-03-10 18:30:00	réunion préparatoire comité de haut niveau
16468	01058X	REU_TRAV_PARL	2021-03-16 11:00:00	2021-03-16 13:00:00	CHN 
16474	11103C	ORG_POL	2021-03-23 11:00:00	2021-03-23 12:30:00	LR du Sénat 
16475	11103C	ORG_POL	2021-03-24 14:00:00	2021-03-24 15:00:00	Groupe de travail LR sur le loup
16476	04086Q	DEL_ACT_PAR	2021-03-15 14:00:00	2021-03-15 15:30:00	RDV de travail CCI bobigny
16477	04086Q	ORG_POL	2021-03-16 11:00:00	2021-03-16 12:30:00	Réunion du groupe LR
16478	04086Q	REU_TRAV_PARL	2021-03-16 14:00:00	2021-03-16 15:30:00	Réunion de travail, rapport PPL Fonds Souverains
16479	04086Q	ORG_POL	2021-03-23 11:00:00	2021-03-23 12:30:00	Réunion du groupe LR
16482	08010L	ORGEXTPAR	2021-03-24 17:30:00	2021-03-24 18:30:00	UIP
16561	04042C	REU_TRAV_PARL	2021-03-30 14:30:00	2021-03-30 15:00:00	Rendez-vous téléphonique avec une Sénatrice
16626	04042C	ORG_POL	2021-04-13 10:00:00	2021-04-13 12:30:00	Réunion du bureau de Groupe des sénateurs LR du Sénat
16627	04042C	ACC_VISIT	2021-04-13 14:30:00	2021-04-13 15:30:00	Visite de courtoisie de Madame la Préfète du Val-de-Marne
16643	11066Q	COLL_TER	2021-04-08 18:30:00	2021-04-08 19:30:00	Point de situation Covid-19 en Loire-Atlantique
16641	11066Q	ORGEXTPAR	2021-04-06 16:30:00	2021-04-06 17:30:00	Réunion plénière de la Commission Nationale de Contrôle des Techniques de Renseignement
16630	11103C	ORG_POL	2021-04-13 10:00:00	2021-04-13 11:00:00	LR du Sénat 
16631	11103C	REU_GVT	2021-04-13 11:00:00	2021-04-13 12:00:00	Bérengère Abba, Secrétaire d'État auprès de la ministre de la Transition écologique, chargée de la Biodiversité
16644	11066Q	REU_TRAV_PARL	2021-04-12 11:30:00	2021-04-12 12:30:00	Réunion de groupe
16645	11066Q	REU_TRAV_PARL	2021-04-13 10:00:00	2021-04-13 12:00:00	Réunion de groupe
16650	11066Q	ORGEXTPAR	2021-04-14 15:30:00	2021-04-14 16:30:00	Réunion plénière de la Commission Nationale de Contrôle des Techniques de Renseignement
16651	11066Q	COLL_TER	2021-04-15 18:30:00	2021-04-15 19:30:00	Point de situation Covid-19 en Loire-Atlantique
16652	04042C	ORG_POL	2021-04-16 11:00:00	2021-04-16 12:00:00	Visiocnférence du Forum L.R "Le Rôle de la France dans l'Europe et dans le Monde - Audition d'un ancien Ambassadeur de la Fédération de Russie en France
16653	04042C	REU_GVT	2021-04-19 11:45:00	2021-04-19 13:00:00	Visioconférence avec la Ministre déléguée en charge du logement et des Maires du Val-de-Marne
16654	04042C	ORG_POL	2021-04-19 18:30:00	2021-04-19 19:30:00	Visioconférence du bureau des L.R 94
16289	04043D	REU_TRAV_PARL	2021-02-01 16:00:00	2021-02-01 17:30:00	OPECST
16722	04042C	REU_GVT	2021-04-27 18:00:00	2021-04-27 19:00:00	Réunion de travail avec le Garde des Sceaux, Ministre de la Justice
16723	04042C	REU_TRAV_PARL	2021-04-28 11:00:00	2021-04-28 12:00:00	Réunion de travail avec le Président de la Commission des Affaires étrangères de l'Assemblée nationale
16738	04086Q	ORG_POL	2021-05-04 11:00:00	2021-05-04 12:30:00	Réunion du groupe LR
16785	11103C	ORG_POL	2021-05-11 11:00:00	2021-05-11 12:30:00	LR du Sénat
16881	08010L	REU_TRAV_PARL	2021-05-19 13:30:00	2021-05-19 16:00:00	Police/Sécurité 
16882	08010L	REU_TRAV_PARL	2021-05-20 10:00:00	2021-05-20 14:00:00	Bureau FedEPL
16941	08010L	REU_TRAV_PARL	2021-05-27 16:00:00	2021-05-27 17:30:00	PJL 4D SEM 
16942	04042C	CEREMONIE	2021-05-27 12:30:00	2021-05-27 14:30:00	Lancement des semaines de l'Amérique latine et des Caraïbes par le Président du Sénat
16943	04042C	COLL_TER	2021-05-27 09:00:00	2021-05-27 12:00:00	Comité du Syndicat des Eaux d'Il-de-France
16944	04086Q	ORG_POL	2021-05-11 11:00:00	2021-05-11 12:30:00	Réunion du groupe LR
16946	04086Q	DEL_ACT_PAR	2021-05-25 11:00:00	2021-05-25 12:30:00	Réunion du groupe LR
16948	04086Q	ACC_DEPL_INTER	2021-05-20 18:00:00	2021-05-20 20:00:00	UIP réunion de préparation de la 142e assemblée générale
16981	01058X	REU_TRAV_PARL	2021-05-28 00:00:00	2021-05-28 00:00:00	GA France-Vanuatu et Iles du Pacifique - Entretien sur Zoom avec Guillaume Lemoine, ambassadeur en Papouasie-Nouvelle-Guinée
16982	01058X	REU_TRAV_PARL	2021-05-28 14:30:00	2021-05-28 15:25:00	RDV Monsieur DEN HEIJER, Soius-Préfet et Secrétaire général
16983	01058X	REU_TRAV_PARL	2021-05-28 15:30:00	2021-05-28 17:30:00	Conférence Santé Centre et Sud Haute-Marne
17005	08010L	ORG_POL	2021-06-01 10:30:00	2021-06-01 12:30:00	Groupe LR du Sénat
17021	11103C	ORG_POL	2021-06-01 10:30:00	2021-06-01 12:30:00	LR du Sénat
17050	04042C	REU_GVT	2021-06-07 19:30:00	2021-06-07 20:15:00	Entretien avec le Minsitre de l'Europe et des Affaires étrangères
17048	04042C	COLL_TER	2021-06-07 15:00:00	2021-06-07 17:00:00	réunion de la Commission Relations Internationales et Solidarité du Syndicat des Eaux d'Ile-de-France
17049	04042C	CEREMONIE	2021-06-07 18:00:00	2021-06-07 19:00:00	Remise de décoration au Directeur de l'Ecole Nationale de Kinésithérapie et de Rééducation de Saint-Maurice
17051	08010L	ORG_POL	2021-06-08 11:00:00	2021-06-08 13:00:00	Groupe LR du Sénat
17054	04042C	REU_TRAV_PARL	2021-06-08 10:15:00	2021-06-08 10:30:00	Entretien téléphonique avec le Directeur de l'IHEDN
17055	04042C	ACC_VISIT	2021-06-08 10:30:00	2021-06-08 11:00:00	Interview téléphonique avec un correspondant du magazine Jeune Afrique
17056	04042C	ACC_DEPL_INTER	2021-06-08 12:30:00	2021-06-08 14:00:00	Rencontre avec le Représentant du Gouvernement Régional du Kurdistan-Irak en France
17060	04042C	ACC_VISIT	2021-06-09 07:20:00	2021-06-09 08:00:00	Emission La Matinale de Public Sénat
17058	04042C	REU_TRAV_PARL	2021-06-08 20:00:00	2021-06-08 20:30:00	Entretien téléphonique avec un député du Parlement européen
17059	04042C	REU_TRAV_PARL	2021-06-08 18:30:00	2021-06-08 18:45:00	Entretien téléphonique avec un élu
17061	04042C	CEREMONIE	2021-06-09 14:30:00	2021-06-09 16:00:00	Cérémonie en hommage au Premier adjoint de Joinville-Le-Pont
17062	04042C	REU_TRAV_PARL	2021-06-09 16:30:00	2021-06-09 17:30:00	Entretien avec un élu
17063	04042C	REU_TRAV_PARL	2021-06-09 17:30:00	2021-06-09 19:00:00	Entretien avec le Président de la Commission des Affaires étrangères de l'Assemblée nationale
17064	04042C	ELUS_LOCAUX	2021-06-10 12:30:00	2021-06-10 14:15:00	Rencontres avec des élus du Val-de-Marne
17065	04042C	ELUS_LOCAUX	2021-06-10 14:30:00	2021-06-10 15:30:00	Visite d'une entreprise du Val-de-Marne avec des élus
17066	04042C	ORG_POL	2021-06-10 20:30:00	2021-06-10 22:00:00	Meeting de la Présidente du Conseil régional d'Ile-de-France à Maisons-Alfort
17081	04042C	CEREMONIE	2021-06-11 10:30:00	2021-06-11 12:30:00	cérémonie d'adieu aux armes du Général Majour des Armées  
15889	04042C	ELUS_LOCAUX	2020-12-18 10:15:00	2020-12-18 11:45:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
15601	08010L	ORG_POL	2020-12-01 11:00:00	2020-12-01 12:30:00	Groupe LR du Sénat + X Bellamy
15662	04042C	COLL_TER	2020-12-03 18:00:00	2020-12-03 19:00:00	Reunion des travail avec un directeur du SEDIF
15661	04042C	ACC_VISIT	2020-12-03 15:20:00	2020-12-03 16:00:00	Interview Public Sénat
15663	04042C	COLL_TER	2020-12-02 19:00:00	2020-12-02 21:00:00	Conference intercommunale des Maires dediée au PLUi suivie de la commission urbanisme, aménagement habitat et politique de ville
15664	04042C	ACC_VISIT	2020-12-04 10:00:00	2020-12-04 11:00:00	Tournage vidéo de la DGA
15665	04042C	ACC_DEPL_INTER	2020-12-04 11:00:00	2020-12-04 12:00:00	Visite de courtoisie de l'Ambassadeur d'Inde en France
15666	04042C	ACC_VISIT	2020-12-04 12:00:00	2020-12-04 12:30:00	Entretien avec le Président-Directeur général de Public Senat
15667	04042C	ELUS_LOCAUX	2020-12-04 14:00:00	2020-12-04 15:00:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
15668	04042C	REU_TRAV_PARL	2020-12-04 17:30:00	2020-12-04 18:00:00	Entretien telephonique avec le Rapporteur général de l'Assemblée nationale
15887	04042C	COLL_TER	2020-12-17 09:00:00	2020-12-17 12:30:00	Réunion de bureau et de Comité du Syndicat des Eaux d'Ile-de-France
15888	04042C	ACC_VISIT	2020-12-17 13:00:00	2020-12-17 14:00:00	Entretien avec un Maire du Val-de-Marne
15890	04042C	ACC_DEPL_INTER	2020-12-18 16:00:00	2020-12-18 17:00:00	Entretien avec Madame l'Ambassadrice d'Australie
15897	20024T	ELUS_LOCAUX	2020-12-10 20:30:00	2020-12-10 22:00:00	Conseil Municipal de Pindray
15893	20024T	ELUS_LOCAUX	2020-12-07 10:00:00	2020-12-07 11:00:00	Echanges avec Rita NORESKAL, Maire de Marigny-Chemereau 
15896	20024T	COLL_TER	2020-12-14 09:30:00	2020-12-14 17:00:00	Session budgétaire 2021 - Département de la Vienne
15898	20024T	REU_TRAV_PARL	2020-12-07 12:00:00	2020-12-07 14:00:00	avec les députés, sénateurs et Président du Département de la Vienne
16106	04042C	COLL_TER	2021-01-28 09:30:00	2021-01-28 13:00:00	Réunion du Comité du Syndicat des Eaux d'Ile-de-France
16107	04042C	ACC_VISIT	2021-01-28 17:00:00	2021-01-28 18:00:00	Entretien avec le Directeur général du pôle résidentiel de Sefricime
16108	04042C	REU_GVT	2021-01-28 19:30:00	2021-01-28 20:30:00	Entretien avec le Ministre de l'Europe et des Affaires étrangères
16109	04042C	ELUS_LOCAUX	2021-01-29 10:00:00	2021-01-29 11:00:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
16281	08010L	REU_TRAV_PARL	2021-02-16 10:00:00	2021-02-16 11:00:00	Cabinet du sénat
16282	08010L	ORG_POL	2021-02-16 11:00:00	2021-02-16 12:30:00	Groupe LR du Sénat
16283	04043D	COLL_TER	2021-01-08 09:30:00	2021-01-08 11:00:00	Audioconférence des parlementaires avec le Préfet sur la situation sanitaire
16284	04043D	ELUS_LOCAUX	2021-01-12 14:00:00	2021-01-12 15:00:00	\N
16285	04043D	COLL_TER	2021-01-18 09:00:00	2021-01-18 12:00:00	Visite du centre de vaccination de Vincennes / Saint-Mandé
16286	04043D	ACC_VISIT	2021-01-20 14:00:00	2021-01-20 15:00:00	\N
16287	04043D	COLL_TER	2021-01-21 18:00:00	2021-01-21 20:00:00	Conférence de presse sur le plan anti-bruit d'Orly
16288	04043D	COLL_TER	2021-01-22 09:00:00	2021-01-22 11:00:00	Audioconférence des parlementaires avec le Préfet sur la situation sanitaire
16309	04042C	ACC_DEPL_INTER	2021-02-17 13:00:00	2021-02-17 14:15:00	Rencontre avec le nouvel Ambassadeur de Suède en France
16332	04042C	ELUS_LOCAUX	2021-02-15 17:30:00	2021-02-15 18:30:00	Réunion avec des élus du Val-de-Marne
16314	04086Q	REU_TRAV_PARL	2021-02-03 00:00:00	2021-02-03 00:00:00	Audition DCT Rapport Grand Paris - Jean-Philippe GAUTRAIS
16316	04086Q	REU_TRAV_PARL	2021-02-09 10:00:00	2021-02-09 11:00:00	Réunion des commissaires LR des Finances 
16327	04042C	REU_TRAV_PARL	2021-02-03 13:00:00	2021-02-03 14:15:00	Réunion de travail avec un élu du Val-de-Marne
16330	04042C	ELUS_LOCAUX	2021-02-18 09:00:00	2021-02-18 10:00:00	Rendez-vous avec un élu du Val-de-Marne
16329	04042C	ELUS_LOCAUX	2021-02-11 10:30:00	2021-02-11 11:30:00	Rendez-vous avec un élu du Val-de-Marne
16331	04042C	ACC_VISIT	2021-02-18 15:00:00	2021-02-18 15:30:00	RDV téléphonique avec un journaliste de La Lettre A
16333	04042C	COLL_TER	2021-02-22 14:30:00	2021-02-22 15:30:00	Audioconférence avec le Sous-préfet du Val-de-Marne et le Directeur de l'ARS du Val-de-Marne
16334	04042C	ACC_DEPL_INTER	2021-02-23 10:00:00	2021-02-23 10:30:00	Rendez-vous téléphonique avec le Conseiller culturel et Directeur de l'Institut français d'Autriche 
16339	08010L	ORGEXTPAR	2021-03-02 09:30:00	2021-03-02 15:00:00	Cour de Justice de la République
16340	04086Q	REU_TRAV_PARL	2021-03-02 09:00:00	2021-03-02 11:00:00	Audition Samu Social et Fondation Abbé Pierre - Rapport Logement 
16341	04086Q	ORG_POL	2021-03-02 11:00:00	2021-03-02 12:30:00	Réunion du groupe LR
16344	11103C	ORG_POL	2021-03-02 11:00:00	2021-03-02 12:30:00	LR du Sénat 
16345	04042C	REU_TRAV_PARL	2021-03-03 13:00:00	2021-03-03 14:30:00	Réunion Franco-Russe
16346	04042C	ACC_DEPL_INTER	2021-03-03 15:30:00	2021-03-03 16:30:00	Entretien avec le Conseiller spécial du Président de la République de Djibouti
16350	01058X	REU_TRAV_PARL	2021-03-03 16:30:00	2021-03-03 18:00:00	Évaluation du plan national de gestion des matières et déchets radioactifs (PNGMDR)
16348	04042C	DEPL_PRES_GVT	2021-03-04 14:00:00	2021-03-04 15:30:00	Visite avec la Ministre des armées de l'Usine DNA Script dans le Val-de-Marne
16349	04042C	ELUS_LOCAUX	2021-03-04 19:00:00	2021-03-04 21:00:00	Conseil municipal de Saint-Maurice
16486	04042C	COLL_TER	2021-03-25 09:30:00	2021-03-25 13:00:00	Réunion du Comité du Syndicat des Eaux d'Ile-de-France
16487	04042C	REU_TRAV_PARL	2021-03-25 16:15:00	2021-03-25 17:15:00	Réunion de Direction
16485	04042C	REU_TRAV_PARL	2021-03-24 14:30:00	2021-03-24 15:00:00	Rendez-vous avec un Sénateur
16488	04042C	ELUS_LOCAUX	2021-03-25 18:00:00	2021-03-25 19:00:00	Réunion avec des élus du Val-de-Marne
16489	04042C	ACC_DEPL_INTER	2021-03-26 09:50:00	2021-03-26 11:00:00	Entretien avec le Président du Sénat et le Premier Ministre de l'Afghanistan
16490	04042C	ELUS_LOCAUX	2021-03-26 12:30:00	2021-03-26 13:30:00	Rencontre avec un elu du Val-de-Marne
16491	04042C	REU_TRAV_PARL	2021-03-26 18:00:00	2021-03-26 18:30:00	Entretien avec le Premier president de la Cour des comptes
16495	04042C	REU_TRAV_PARL	2021-03-26 16:00:00	2021-03-26 17:00:00	Rendez-vous avec le Directeur de cabinet du Président du Sénat
16493	04042C	ELUS_LOCAUX	2021-03-26 18:30:00	2021-03-26 19:30:00	Visioconference Réunion du bureau politique élargi
16494	04042C	ELUS_LOCAUX	2021-03-25 15:00:00	2021-03-25 16:00:00	Rencontre avec des élus
16562	11103C	ORG_POL	2021-03-30 11:00:00	2021-03-30 12:30:00	LR du Sénat 
16603	11103C	ORG_POL	2021-04-06 11:00:00	2021-04-06 12:30:00	LR du Sénat 
16604	04042C	ORG_POL	2021-04-06 11:00:00	2021-04-06 12:00:00	Réunion de Groupe des Sénateurs L.R du Sénat
16605	04042C	COLL_TER	2021-04-06 19:00:00	2021-04-06 20:30:00	Réunion du Conseil de territoire de Paris Est Marne & Bois
16606	04042C	REU_TRAV_PARL	2021-04-06 12:30:00	2021-04-06 14:00:00	Rencontre avec le Président d'Airbus Helicopters
16621	04042C	ELUS_LOCAUX	2021-04-12 11:30:00	2021-04-12 12:30:00	Rendez-vous Urabnisme à la Mairie de Saint-Maurice
16622	04042C	COLL_TER	2021-04-12 13:00:00	2021-04-12 14:15:00	Rencontre avec le Président du Syndicat des Eaux d'Ile-de-France et des élus
16623	04042C	REU_TRAV_PARL	2021-04-12 15:00:00	2021-04-12 16:00:00	Réunion de Direction
16624	04042C	ACC_DEPL_INTER	2021-04-09 15:20:00	2021-04-09 16:30:00	Rencontre avec le Président du Sénat et le Président de la République du Togo
16681	04042C	DEPL_PRES_GVT	2021-04-23 00:00:00	2021-04-23 00:00:00	Déplacement en Arménie avec le Président du Sénat
16765	08010L	REU_TRAV_PARL	2021-05-11 10:00:00	2021-05-11 11:00:00	Cabinet du Sénat
16766	08010L	ORG_POL	2021-05-11 11:00:00	2021-05-11 12:30:00	Groupe LR du Sénat
16801	04043D	REU_TRAV_PARL	2021-05-07 11:30:00	2021-05-07 12:00:00	Entretien de la CAS avec Elisabeth Borne
16768	04042C	REU_TRAV_PARL	2021-05-10 18:45:00	2021-05-10 19:45:00	Entretien avec le Secrétaire général de la défense et de la sécurité nationale
16769	04042C	ACC_DEPL_INTER	2021-05-11 12:30:00	2021-05-11 14:00:00	Entretien avec l'Ambassadeur de Suisse en France
16802	04043D	ORG_POL	2021-05-04 18:30:00	2021-05-04 20:00:00	CNI des Républicains
16904	08010L	ORG_POL	2021-05-25 10:30:00	2021-05-25 12:30:00	Groupe LR du Sénat
17052	11103C	ORG_POL	2021-06-08 11:00:00	2021-06-08 12:30:00	LR du Sénat
17053	11103C	REU_TRAV_PARL	2021-06-08 16:30:00	2021-06-08 17:30:00	Réglementation cynégétique
15595	14133K	COLL_TER	2020-11-09 19:30:00	2020-11-09 20:30:00	visio-conférence Préfet du Calvados-Parlementaires-collectivités locales - gestion de la pandémie
15716	14133K	COLL_TER	2020-12-07 16:00:00	2020-12-07 18:00:00	visio conférence avec lycéens sur Sénat et Cyber sécurité
15708	14133K	COLL_TER	2020-12-07 09:00:00	2020-12-07 11:00:00	Rencontre avec les élèves du Collège Dumont d'Urville de Condé-en-Normandie
15717	14133K	ELUS_LOCAUX	2020-10-12 19:30:00	2020-10-12 20:30:00	Audio conférence avec le Préfet du Calvados - suivi de la crise sanitaire
15718	14133K	COLL_TER	2020-10-12 10:00:00	2020-10-12 11:00:00	Rendez-vous sociaux et économiques permanence parlementaire dans le Calvados
15719	14133K	ORG_POL	2020-10-13 11:00:00	2020-10-13 12:30:00	Réunion du Groupe LR Sénat
15720	14133K	REU_TRAV_PARL	2020-10-13 15:30:00	2020-10-13 16:30:00	Réunion Bureau de la Commission des affaires étrangères
15721	14133K	DEPL_PRES_GVT	2020-10-15 05:00:00	2020-10-15 08:30:00	Visite ministérielle à Port-en-Bessin
15722	14133K	ELUS_LOCAUX	2020-10-15 14:00:00	2020-10-15 15:00:00	Audio conférence avec le Préfet du Calvados - suivi de la crise sanitaire
15723	14133K	COLL_TER	2020-10-16 10:00:00	2020-10-16 12:00:00	Rendez-vous sociaux et économiques permanence parlementaire dans le Calvados
15726	14133K	REU_TRAV_PARL	2020-10-16 14:30:00	2020-10-16 16:30:00	Visio Réunion du Bureau de l'AP-OSCE
15728	14133K	ORG_POL	2020-10-20 11:00:00	2020-10-20 12:30:00	Réunion du Groupe LR Sénat
15727	14133K	ELUS_LOCAUX	2020-10-19 19:30:00	2020-10-19 20:30:00	Audio conférence avec le Préfet du Calvados - suivi de la crise sanitaire
15729	14133K	ELUS_LOCAUX	2020-10-26 19:30:00	2020-10-26 20:30:00	Audio conférence avec le Préfet du Calvados - suivi de la crise sanitaire
15730	14133K	ORG_POL	2020-10-27 11:00:00	2020-10-27 12:30:00	Réunion du Groupe LR Sénat
15731	14133K	COLL_TER	2020-11-02 11:00:00	2020-11-02 12:00:00	Visite lycée Condé-en-Normandie
15732	14133K	ORG_POL	2020-11-03 11:00:00	2020-11-03 12:30:00	Réunion du Groupe LR Sénat
15733	14133K	REU_TRAV_PARL	2020-11-03 16:00:00	2020-11-03 17:30:00	Auditions P144
15734	14133K	REU_TRAV_PARL	2020-11-05 08:30:00	2020-11-05 10:00:00	Visio commission des affaires européennes
15735	14133K	COLL_TER	2020-11-05 16:00:00	2020-11-05 17:30:00	Rendez-vous sociaux et économiques permanence parlementaire dans le Calvados
15736	14133K	COLL_TER	2020-11-06 10:00:00	2020-11-06 11:30:00	Rendez-vous sociaux et économiques permanence parlementaire dans le Calvados
15737	14133K	CEREMONIE	2020-11-09 10:00:00	2020-11-09 10:30:00	50e anniversaire décès Général de Gaulle à Caen
15738	14133K	ELUS_LOCAUX	2020-11-09 11:30:00	2020-11-09 12:30:00	Réunion Région Normandie
15739	14133K	CEREMONIE	2020-11-09 14:30:00	2020-11-09 15:15:00	50e anniversaire décès Général de Gaulle - Bayeux
15740	14133K	CEREMONIE	2020-11-09 17:30:00	2020-11-09 18:15:00	50e anniversaire décès Général de Gaulle à Vire
15741	14133K	ORG_POL	2020-11-10 11:00:00	2020-11-10 12:30:00	Réunion du Groupe LR Sénat
15742	14133K	CEREMONIE	2020-11-11 10:30:00	2020-11-11 11:00:00	Commémoration armistice 1918 - Condé-en-Normandie
15743	14133K	COLL_TER	2020-11-12 17:00:00	2020-11-12 18:00:00	Rendez-vous sociaux et économiques permanence parlementaire dans le Calvados
15744	14133K	COLL_TER	2020-11-13 09:30:00	2020-11-13 12:30:00	Rendez-vous sociaux et économiques permanence parlementaire dans le Calvados
15745	14133K	CEREMONIE	2020-11-16 11:00:00	2020-11-16 12:00:00	Installation du Sous-préfet de Lisieux
15746	14133K	COLL_TER	2020-11-16 15:00:00	2020-11-16 16:00:00	Rdv Services de l'Etat
15747	14133K	COLL_TER	2020-11-16 19:30:00	2020-11-16 20:30:00	Audio conférence Préfet du Calvados-suivi de la crise sanitaire
15861	11103C	ORG_POL	2020-12-15 11:00:00	2020-12-15 12:30:00	LR du Sénat 
15883	14133K	REU_TRAV_PARL	2020-12-16 11:30:00	2020-12-16 12:30:00	Directrice commission affaires européennes
15884	14133K	REU_TRAV_PARL	2020-12-17 14:30:00	2020-12-17 16:30:00	Chef d'Etat-Major de la Marine
15865	04086Q	REU_TRAV_PARL	2020-12-08 16:15:00	2020-12-08 17:00:00	Réunion de travail pour la DCT pour le rapport sur la Gouvernance du Grand Paris
15866	04086Q	COLLOQUE	2020-12-09 13:15:00	2020-12-09 15:00:00	Débat sur Youtube sur le logement
15867	04086Q	COLL_TER	2020-12-10 16:30:00	2020-12-10 18:00:00	Assemblée Générale de l'ADIL
15869	04086Q	REU_TRAV_PARL	2020-12-15 14:00:00	2020-12-15 15:30:00	Rendez-vous de travail pour la Commission des finances
15882	14133K	REU_TRAV_PARL	2020-12-16 10:30:00	2020-12-16 11:30:00	directeur commission affaires étrangères
15885	14133K	ACC_DEPL_INTER	2020-12-15 17:30:00	2020-12-15 19:00:00	\N
15961	08010L	REU_TRAV_PARL	2021-01-13 16:30:00	2021-01-13 19:00:00	Cabinet du sénat
16082	04086Q	ELUS_LOCAUX	2021-01-26 12:30:00	2021-01-26 14:00:00	Déjeuner de travail avec des élus locaux
15895	20024T	COLL_TER	2020-12-18 09:30:00	2020-12-18 17:00:00	Session budgétaire 2021 - Département de la Vienne
15962	11103C	ORG_POL	2021-01-12 11:00:00	2021-01-12 12:30:00	Groupe LR du Sénat
16083	04086Q	REU_TRAV_PARL	2021-01-28 16:00:00	2021-01-28 17:00:00	Audition DCT Rapport Grand Paris, Jean-Didier Berger
16419	11066Q	REU_TRAV_PARL	2021-03-01 11:30:00	2021-03-01 12:30:00	Réunion de groupe
16182	08010L	REU_TRAV_PARL	2021-02-09 10:00:00	2021-02-09 11:00:00	Commission des Finances
16183	08010L	ORG_POL	2021-02-09 11:00:00	2021-02-09 12:30:00	Groupe LR du Sénat
16412	11103C	ORG_POL	2021-03-16 11:00:00	2021-03-16 12:30:00	LR du Sénat 
16420	11066Q	ACC_VISIT	2021-03-01 15:00:00	2021-03-01 16:00:00	Entretien avec le commandant de la Marine à Nantes et Saint-Nazaire
16421	11066Q	REU_TRAV_PARL	2021-03-02 10:00:00	2021-03-02 12:30:00	Réunion de groupe
16589	11066Q	REU_TRAV_PARL	2021-03-16 10:00:00	2021-03-16 12:30:00	Réunion de groupe
16533	20024T	ELUS_LOCAUX	2021-03-15 18:00:00	2021-03-15 19:00:00	Conseil Municipal de Dangé-Saint-Romain
16588	11066Q	ORGEXTPAR	2021-03-16 16:30:00	2021-03-16 17:30:00	Réunion plénière de la Commission Nationale de Contrôle des Techniques de Renseignement
16590	11066Q	REU_TRAV_PARL	2021-03-24 16:30:00	2021-03-24 17:30:00	Réunion sur le programme budgétaire 144
16732	11103C	DEPL_PRES_GVT	2021-04-30 15:30:00	2021-04-30 16:30:00	Rencontre avec la Préfète
16602	08010L	ORG_POL	2021-04-06 11:00:00	2021-04-06 12:30:00	Groupe LR du sénat 
16625	08010L	ORG_POL	2021-04-13 11:00:00	2021-04-13 12:30:00	Groupe LR du Sénat 
16733	11103C	ELUS_LOCAUX	2021-04-23 15:00:00	2021-04-23 16:00:00	Maire de Sully sur Loire
16734	11103C	ORG_POL	2021-05-04 11:00:00	2021-05-04 12:30:00	LR du Sénat 
16735	04042C	REU_TRAV_PARL	2021-05-04 15:00:00	2021-05-04 16:00:00	Réunion de trvail avec le Directeur général de l'AFD
16736	04042C	ACC_DEPL_INTER	2021-05-05 14:45:00	2021-05-05 15:00:00	Entretien téléphonique avec l'Ambassadeur de Chine en France
16737	04042C	ACC_VISIT	2021-05-05 16:25:00	2021-05-05 16:45:00	Interview Public Sénat
16739	04042C	ORG_POL	2021-05-06 19:00:00	2021-05-06 20:30:00	Visioconference Meeting de la Présidente du Conseil régional d'Ile-de-France
16740	04042C	COLL_TER	2021-05-07 08:45:00	2021-05-07 10:45:00	Réunion du Bureau du Syndicat d'Ile-de-France
16741	04042C	ACC_DEPL_INTER	2021-05-07 12:00:00	2021-05-07 13:00:00	Entretien avec le Vice-minsitre des Affaires étrangères de Géorgie
16804	04043D	ORG_POL	2021-04-27 10:00:00	2021-04-27 12:00:00	CNI des Républicains
16743	04042C	ELUS_LOCAUX	2021-05-07 15:00:00	2021-05-07 16:00:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
16744	04042C	REU_GVT	2021-05-07 17:00:00	2021-05-07 18:00:00	Réunion avec le Minsitre de l'Europe et des Affaires étrangères
16803	04043D	ORG_POL	2021-05-03 14:00:00	2021-05-03 16:00:00	CNI des Républicains
16805	04043D	ELUS_LOCAUX	2021-04-19 11:45:00	2021-04-19 12:30:00	Entretien avec Emmanuelle Wargon et les maires du Val-de-Marne
16806	04043D	ORG_POL	2021-04-19 18:30:00	2021-04-19 20:00:00	Bureau départemental LR
16807	04043D	COLL_TER	2021-04-15 18:00:00	2021-04-15 20:00:00	Entretien avec le Préfet et l'ARS du Val-de-Marne
16821	14147R	REU_TRAV_PARL	2021-05-11 17:00:00	2021-05-11 18:00:00	Groupe de Liaison Chrétiens d'Orient
16862	11103C	ORG_POL	2021-05-18 11:00:00	2021-05-18 12:30:00	Groupe LR du Sénat
16901	04042C	ACC_DEPL_INTER	2021-05-21 14:30:00	2021-05-21 15:30:00	Entretien avec l'Ambassadeur d'Israël en France
16902	04042C	REU_GVT	2021-05-21 16:00:00	2021-05-21 17:00:00	Entretien avec le Chef de cabinet militaire du Premier Ministre 
16903	04042C	ORG_POL	2021-05-25 10:30:00	2021-05-25 12:00:00	Réunion de Groupe Les Républicains au Sénat
17001	04042C	REU_TRAV_PARL	2021-05-31 11:00:00	2021-05-31 12:30:00	Réunion de Direction
17002	04042C	COLL_TER	2021-05-31 19:00:00	2021-05-31 20:30:00	Visioconférence Commission Environnement, Eau, Assainissement de l'intercommunalité Paris Est Marne&Bois
17003	04042C	ORG_POL	2021-06-01 10:30:00	2021-06-01 12:00:00	Réunion de Groupe des Sénateurs L.R au Sénat
16382	04042C	REU_TRAV_PARL	2021-03-09 15:00:00	2021-03-09 16:00:00	Réunion de Direction
16162	11103C	ORG_POL	2021-02-02 11:00:00	2021-02-02 12:30:00	LR du Sénat 
16383	04042C	REU_TRAV_PARL	2021-03-10 12:30:00	2021-03-10 14:00:00	Rencontre des Présidents de Commission, du Rapporteur général et référents de Commission
16206	04042C	ORG_POL	2021-02-09 11:00:00	2021-02-09 12:30:00	Réunion de Groupe des L.R au Sénat
16313	04086Q	ORG_POL	2021-02-16 11:00:00	2021-02-16 12:30:00	Réunion du groupe LR
16317	04086Q	REU_TRAV_PARL	2021-02-17 14:00:00	2021-02-17 15:00:00	Réunion de travail pour la DCT pour le rapport sur la Gouvernance du Grand Paris
16312	04086Q	ORG_POL	2021-02-09 11:00:00	2021-02-09 12:30:00	Réunion du groupe LR
16315	04086Q	REU_TRAV_PARL	2021-02-03 00:00:00	2021-02-03 00:00:00	Audition DCT Rapport Grand Paris - Préfet Michel CADOT
16381	04042C	ORG_POL	2021-03-09 11:00:00	2021-03-09 12:30:00	Réunion de Groupe des Républicains au Sénat
16402	04042C	ELUS_LOCAUX	2021-03-15 10:00:00	2021-03-15 12:00:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
16385	04042C	REU_TRAV_PARL	2021-03-10 14:30:00	2021-03-10 15:00:00	Réunion de travail GIA France-Maroc
16386	11103C	ORG_POL	2021-03-09 11:00:00	2021-03-09 12:30:00	LR du Sénat 
16387	04042C	REU_TRAV_PARL	2021-03-10 16:30:00	2021-03-10 17:30:00	Entretien avec le Directeur de l'IHEDN et la Présidente du Conseil d'Administration
16469	08010L	ORG_POL	2021-03-23 11:00:00	2021-03-23 12:30:00	Groupe LR du Sénat
16403	04042C	ELUS_LOCAUX	2021-03-15 12:30:00	2021-03-15 14:30:00	Rencontre avec des élus au Conseil régional d'Ile-de-France
16470	08010L	REU_TRAV_PARL	2021-03-23 15:00:00	2021-03-23 16:30:00	Com. Finances /DGACG
16471	04042C	ORG_POL	2021-03-23 11:00:00	2021-03-23 12:00:00	Réunion de Groupe des Républicains au Sénat
16472	04042C	ACC_DEPL_INTER	2021-03-23 12:30:00	2021-03-23 14:15:00	Rencontre avec l'Ambassadrice d'Arménie en France
16473	04042C	REU_TRAV_PARL	2021-03-23 17:30:00	2021-03-23 18:30:00	Entretien avec un député
16529	08010L	REU_TRAV_PARL	2021-03-30 10:00:00	2021-03-30 11:00:00	Cabinet du sénat 
16530	08010L	ORG_POL	2021-03-30 11:00:00	2021-03-30 12:30:00	Groupe LR du sénat 
16531	20024T	COLL_TER	2021-03-18 09:30:00	2021-03-18 12:00:00	Session au Conseil Départemental de la Vienne
16532	20024T	COLL_TER	2021-03-18 20:15:00	2021-03-18 23:00:00	Conseil Municipal de Monts-sur-Guesnes
16534	20024T	ELUS_LOCAUX	2021-03-08 09:30:00	2021-03-08 12:00:00	Echanges avec les élues du canton de Loudun
16535	20024T	ELUS_LOCAUX	2021-03-08 14:00:00	2021-03-08 15:00:00	Maire de Pouant
16536	20024T	ELUS_LOCAUX	2021-03-01 18:30:00	2021-03-01 19:30:00	Conseil Municipal de Thuré
16537	20024T	ELUS_LOCAUX	2021-03-01 19:45:00	2021-03-01 20:45:00	Conseil Municipal d'Orches
16538	20024T	ELUS_LOCAUX	2021-03-04 18:30:00	2021-03-04 19:30:00	Conseil Municipal de Brux
16539	04042C	ELUS_LOCAUX	2021-03-29 11:00:00	2021-03-29 12:00:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
16540	04042C	ORG_POL	2021-03-29 18:30:00	2021-03-29 19:30:00	Visiconférence du comité départemental des LR94
16546	04042C	REU_TRAV_PARL	2021-03-30 15:00:00	2021-03-30 16:00:00	Rencontre virtuelle du Club Rheanon sur les questions de défense franco-allemandes
16582	11066Q	REU_TRAV_PARL	2021-03-29 11:30:00	2021-03-29 12:30:00	Réunion de groupe
16545	04042C	ORG_POL	2021-03-30 11:00:00	2021-03-30 12:30:00	Réunion de Groupe des L.R au Sénat
16544	04042C	REU_TRAV_PARL	2021-03-30 18:00:00	2021-03-30 19:00:00	Visioconférence du Groupe de travail pour l'élaboration du Manifeste Patriotes et Européens
16581	11103C	REU_GVT	2021-04-01 00:00:00	2021-04-01 00:00:00	Julien Denormandie, Ministre de l¿Agriculture et de l¿Alimentation
16583	11066Q	COLL_TER	2021-03-29 14:30:00	2021-03-29 16:30:00	Instance de concertation parc éolien en mer de Saint-Nazaire
16584	11066Q	REU_TRAV_PARL	2021-03-30 10:00:00	2021-03-30 12:30:00	Réunion de groupe
16585	11066Q	ORGEXTPAR	2021-03-30 16:30:00	2021-03-30 17:30:00	Réunion plénière de la Commission Nationale de Contrôle des Techniques de Renseignement
16586	11066Q	REU_TRAV_PARL	2021-03-31 21:00:00	2021-03-31 22:00:00	Réunion de groupe
16587	11066Q	COLL_TER	2021-04-01 18:30:00	2021-04-01 19:30:00	Point de situation Covid-19 en Loire-Atlantique
16655	01058X	REU_TRAV_PARL	2021-04-13 14:30:00	2021-04-13 16:45:00	 Groupe de travail Drones
16656	01058X	REU_TRAV_PARL	2021-04-13 17:00:00	2021-04-13 17:30:00	Entretien téléphonique ANDRA
16660	01058X	ORG_POL	2021-04-13 11:00:00	2021-04-13 12:30:00	Réunion de Groupe des Sénateurs L.R du Sénat
16658	01058X	ELUS_LOCAUX	2021-04-01 17:00:00	2021-04-01 18:00:00	Audio avec le Préfet et les élus locaux situation sanitaire
16659	01058X	REU_TRAV_PARL	2021-04-12 15:00:00	2021-04-12 16:30:00	Réunion DETR
16841	04042C	CEREMONIE	2021-05-18 10:20:00	2021-05-18 11:20:00	Cérémonie du 70ème anniversaire du début de la participation du bataillon français de l'ONU à la guerre de Corée
16842	04042C	ORG_POL	2021-05-18 11:30:00	2021-05-18 12:30:00	Réunion du Groupe Les Républicains au Sénat
16843	04042C	ACC_DEPL_INTER	2021-05-18 16:30:00	2021-05-18 17:30:00	Entretien avec un Ancien Ministre des Affaires étrangères du Mali
16844	04042C	ACC_DEPL_INTER	2021-05-18 17:30:00	2021-05-18 18:30:00	Entretien avec l'Ambassadrice d'Arménie en France
16921	04042C	ACC_DEPL_INTER	2021-05-25 12:15:00	2021-05-25 13:15:00	Entretien avec un ancien Ambassadeur de la Fédération de Russie
16922	04042C	REU_TRAV_PARL	2021-05-26 12:30:00	2021-05-26 14:00:00	Rencontre avec les Présidents de commission
16923	04042C	ACC_DEPL_INTER	2021-05-26 16:30:00	2021-05-26 17:30:00	Entretien avec le conseiller diplomatique de la Première Vice-présidente d'Azerbaïdjan
16924	04042C	ORG_POL	2021-05-26 18:00:00	2021-05-26 19:00:00	Visioconférence avec la Présidente du Conseil régionale d'Ile-de-France
16945	04086Q	ORG_POL	2021-05-18 11:00:00	2021-05-18 12:30:00	Réunion du groupe LR
16947	04086Q	ACC_DEPL_INTER	2021-05-17 13:00:00	2021-05-17 15:00:00	UIP, Comité directeur des 12+
16949	04086Q	ACC_DEPL_INTER	2021-05-21 12:30:00	2021-05-21 16:30:00	UIP, Assemblée générale du groupe des 12+
16950	04086Q	ACC_DEPL_INTER	2021-05-24 14:00:00	2021-05-24 17:30:00	UIP, Conseil directeur 
16951	04086Q	ACC_DEPL_INTER	2021-05-25 14:00:00	2021-05-25 17:00:00	UIP, Conseil directeur 
16961	01058X	ORG_POL	2021-05-25 10:30:00	2021-05-25 12:30:00	Réunion de Groupe Les Républicains au Sénat
16962	01058X	ORG_POL	2021-05-18 11:00:00	2021-05-18 12:30:00	Réunion de Groupe Les Républicains au Sénat
17104	08010L	REU_TRAV_PARL	2021-06-16 08:00:00	2021-06-16 09:00:00	PLFR 2021
16964	01058X	REU_TRAV_PARL	2021-05-28 00:00:00	2021-05-28 00:00:00	Sous-Préfet de Langres
17004	04042C	REU_TRAV_PARL	2021-06-01 12:15:00	2021-06-01 12:30:00	Entretien avec un Sénateur
17023	11103C	REU_TRAV_PARL	2021-06-01 20:00:00	2021-06-01 21:00:00	Association cynégétique
17082	04042C	DEPL_PRES_GVT	2021-06-11 18:30:00	2021-06-11 00:00:00	Déplacement en Estonie avec des entretiens au Parlement et visite du 12ème régiment des cuirassiers
17083	04042C	DEPL_PRES_GVT	2021-06-14 00:00:00	2021-06-14 00:00:00	Déplacement en Estonie avec des entretiens au Parlement et visite du 12ème régiment des cuirassiers
17084	01058X	REU_TRAV_PARL	2021-06-10 00:00:00	2021-06-10 00:00:00	Évaluation du plan national de gestion des matières et déchets radioactifs (PNGMDR) Audition de Franck CHEVET
17088	04042C	ORG_POL	2021-06-15 11:00:00	2021-06-15 12:00:00	Réunion de Groupe des Sénateurs L.R du Sénat
17086	08010L	ORG_POL	2021-06-15 11:00:00	2021-06-15 13:00:00	Groupe LR du Sénat
17087	04042C	ELUS_LOCAUX	2021-06-15 08:30:00	2021-06-15 10:00:00	Distribution de tracts à la Gare RER de Fontenay-sous-Bois
17089	04042C	ACC_DEPL_INTER	2021-06-15 13:00:00	2021-06-15 14:15:00	Rencontre avec l'Ambassadeur de la Corée en France
17090	04042C	ACC_DEPL_INTER	2021-06-15 15:30:00	2021-06-15 16:30:00	Entretien avec l'Ambassadrice de Serbie en France
17093	04042C	ACC_DEPL_INTER	2021-06-15 16:30:00	2021-06-15 16:45:00	Entrtien téléphonique avec l'Ambassadeur de France en Grèce
17102	01058X	ORG_POL	2021-06-01 11:00:00	2021-06-01 12:30:00	Réunion de Groupe Les Républicains au Sénat
17101	11103C	ORG_POL	2021-06-15 11:00:00	2021-06-15 12:30:00	LR du Sénat
17103	01058X	ORG_POL	2021-06-08 11:00:00	2021-06-08 12:30:00	Réunion de Groupe Les Républicains au Sénat
17106	08010L	REU_TRAV_PARL	2021-06-16 18:00:00	2021-06-16 19:00:00	PJL 4D
17107	04042C	ACC_DEPL_INTER	2021-06-16 13:00:00	2021-06-16 14:15:00	Rencontre avec l'Ambassadeur d'Italie en France et le Secrétaire d'Etat au Ministère italien des Affaires étrangères et de la coopération
17109	04042C	ACC_DEPL_INTER	2021-06-16 14:45:00	2021-06-16 15:15:00	Entretien avec le Secrétaire d'Etat au Ministère italien des Affaires étrangères et de la coopération
15941	04042C	REU_TRAV_PARL	2020-12-22 11:00:00	2020-12-22 12:00:00	Réunion de Direction
15822	08010L	ORG_POL	2020-12-15 11:00:00	2020-12-15 12:30:00	Groupe LR du Sénat
15948	04042C	ACC_DEPL_INTER	2021-01-12 15:15:00	2021-01-12 15:30:00	Salut de la délégation libyenne en Séance publique
15943	04042C	ELUS_LOCAUX	2020-12-22 19:00:00	2020-12-22 20:00:00	Visioconférence sur le Loi SRU
15944	04042C	COLL_TER	2020-12-22 18:00:00	2020-12-22 19:00:00	Visioconférences du Territoire Grand Paris Sud Est Avenir
15946	04042C	ACC_DEPL_INTER	2021-01-12 10:00:00	2021-01-12 12:00:00	Entretien avec le Président de la Commission des Affaires étrangères de la Libye
15947	04042C	ACC_DEPL_INTER	2021-01-12 13:15:00	2021-01-12 15:00:00	Accueil et rencontre avec la Délégation de la Commission des Affaires étrangères de la Libye
15949	04042C	ACC_DEPL_INTER	2021-01-12 15:30:00	2021-01-12 16:30:00	Entretien avec l'Ambassadeur de Taïwan en France et un ancien Premier Ministre
16001	08010L	ORG_POL	2021-01-19 11:00:00	2021-01-19 12:30:00	Groupe LR du Sénat
16081	04086Q	ORG_POL	2021-01-26 11:00:00	2021-01-26 12:30:00	Réunion du groupe LR
16121	08010L	ORG_POL	2021-02-02 10:30:00	2021-02-02 12:30:00	Groupe LR du Sénat + M. BARNIER
16141	04042C	REU_TRAV_PARL	2021-02-01 18:00:00	2021-02-01 19:00:00	Visioconférence de la Fondation Robert Schuman sur le thème de L'Union européenne, un acteur mondial
16142	04042C	ORG_POL	2021-02-02 11:00:00	2021-02-02 12:30:00	Réunion de groupe en présence du Négociateur en chef de l'Union européenne 
16143	04042C	REU_TRAV_PARL	2021-02-02 13:00:00	2021-02-02 14:30:00	Rencontre avec le Négociateur en chef de l'Union européenne
16144	04042C	ACC_DEPL_INTER	2021-02-02 16:45:00	2021-02-02 17:30:00	Visite de courtoisie du nouvel Ambassadeur du Brésil en France
16145	04042C	REU_TRAV_PARL	2021-02-02 17:30:00	2021-02-02 18:30:00	Réunion de Direction
16146	04042C	COLL_TER	2021-02-02 19:00:00	2021-02-02 20:30:00	Réunion du Conseil de Territoire de Paris Est & Bois
16147	01058X	REU_TRAV_PARL	2021-01-20 15:00:00	2021-01-20 16:00:00	\N
16148	01058X	REU_TRAV_PARL	2021-02-03 14:00:00	2021-02-03 15:30:00	Évaluation du plan national de gestion des matières et déchets radioactifs (PNGMDR) 
16149	01058X	REU_TRAV_PARL	2021-01-27 14:00:00	2021-01-27 15:00:00	Évaluation du plan national de gestion des matières et déchets radioactifs (PNGMDR) 
16150	01058X	DEPL_PRES_GVT	2020-12-11 10:00:00	2020-12-11 12:00:00	Déplacement E. WARGON - Mardor
16221	14133K	COLL_TER	2020-12-22 16:00:00	2020-12-22 17:00:00	Rencontre association d'entraide
16222	14133K	COLL_TER	2020-12-23 10:00:00	2020-12-23 12:00:00	rdv permanence parlementaire
16223	14133K	COLL_TER	2021-01-04 14:00:00	2021-01-04 18:00:00	visite territoire Calvados - Colleville-Isigny
16224	14133K	COLL_TER	2021-01-05 10:00:00	2021-01-05 12:00:00	visite territoire Calvados - St-Pierre-la-V
16225	14133K	DEPL_PRES_GVT	2021-01-05 13:45:00	2021-01-05 16:00:00	Visite ministérielle Ouistreham
16226	14133K	DEPL_PRES_GVT	2021-01-07 09:30:00	2021-01-07 11:30:00	Visite ministérielle à Port-en-Bessin
16227	14133K	COLL_TER	2021-01-07 14:00:00	2021-01-07 18:00:00	visite territoire Calvados - Orbec
16230	14133K	COLL_TER	2021-01-13 10:30:00	2021-01-13 11:30:00	visite territoire Calvados - Vire Normandie
16232	14133K	COLL_TER	2021-01-14 14:30:00	2021-01-14 16:00:00	visite territoire Calvados - Pont-d'Ouilly
16231	14133K	COLL_TER	2021-01-14 10:00:00	2021-01-14 11:30:00	visite territoire Calvados - Deauville-Saint Gatien
16233	14133K	ELUS_LOCAUX	2021-01-15 11:00:00	2021-01-15 12:30:00	visite territoire Calvados - Saint-Gatien
16234	14133K	COLL_TER	2021-01-15 14:30:00	2021-01-15 18:00:00	visite territoire Calvados - Villers-sur-Mer
16235	14133K	ELUS_LOCAUX	2021-01-18 10:00:00	2021-01-18 11:30:00	rdv permanence parlementaire
16236	14133K	COLL_TER	2021-01-18 14:30:00	2021-01-18 18:00:00	visite territoire Calvados - Saint-Pierre-en-Auge
16237	14133K	ELUS_LOCAUX	2021-01-18 19:30:00	2021-01-18 20:30:00	Audio conférence avec le Préfet du Calvados - suivi de la crise sanitaire
16241	14133K	COLL_TER	2021-01-21 14:00:00	2021-01-21 18:00:00	Visite territoire Calvados - Caen et Ryes
16239	14133K	ORG_POL	2021-01-19 11:00:00	2021-01-19 12:30:00	Réunion du Groupe LR Sénat
16243	14133K	ELUS_LOCAUX	2021-01-22 15:30:00	2021-01-22 16:45:00	réunion élus - Cléville (14)
16242	14133K	ELUS_LOCAUX	2021-01-22 14:00:00	2021-01-22 15:00:00	rencontre Chambre d'Agriculture du Calvados
16244	14133K	ELUS_LOCAUX	2021-01-25 10:00:00	2021-01-25 12:00:00	rdv élus - permanence parlementaire
16245	14133K	ELUS_LOCAUX	2021-01-25 14:30:00	2021-01-25 17:00:00	rdv acteurs économiques - permanence parlementaire
16246	14133K	ORG_POL	2021-01-26 11:00:00	2021-01-26 12:30:00	Réunion du Groupe LR Sénat
16247	14133K	COLL_TER	2021-01-28 11:00:00	2021-01-28 12:00:00	Visite territoire Calvados - entreprise Condé/N.
16248	14133K	COLL_TER	2021-01-28 15:30:00	2021-01-28 16:30:00	Visite territoire Calvados - entreprise Condé/N.
16249	14133K	ELUS_LOCAUX	2021-01-29 09:30:00	2021-01-29 12:00:00	rdv permanence parlementaire - projets économiques
16250	14133K	DEPL_PRES_GVT	2021-01-29 14:00:00	2021-01-29 17:00:00	visite ministérielle à CAEN
16251	14133K	COLL_TER	2021-02-01 09:30:00	2021-02-01 12:30:00	visite territoire Calvados - Saint-Rémy-sur-Orne
16252	14133K	COLL_TER	2021-02-01 14:00:00	2021-02-01 18:00:00	visite territoire Calvados - Les Monts-d'Aunay
16253	14133K	ELUS_LOCAUX	2021-02-01 19:30:00	2021-02-01 20:30:00	Audio conférence avec le Préfet du Calvados - suivi de la crise sanitaire
16254	14133K	ORG_POL	2021-02-02 11:00:00	2021-02-02 12:30:00	Réunion du Groupe LR Sénat
16290	04043D	REU_TRAV_PARL	2021-02-03 13:30:00	2021-02-03 14:30:00	Réunion du groupe d'études - Français établis hors de France
16291	04043D	REU_TRAV_PARL	2021-02-04 12:30:00	2021-02-04 14:00:00	OPECST - Réunion travail préparatoire
16292	04043D	ORG_POL	2021-02-09 11:00:00	2021-02-09 12:30:00	Réunion de groupe
16293	04043D	ORG_POL	2021-02-09 18:00:00	2021-02-09 20:00:00	Bureau départemental LR
16030	04086Q	ORG_POL	2021-01-19 11:00:00	2021-01-19 12:30:00	Réunion du groupe LR
16294	04043D	ACC_VISIT	2021-02-10 14:30:00	2021-02-10 15:00:00	Participation à un travail étudiant sur Caspr-Cas9
16295	04043D	ACC_VISIT	2021-02-12 11:30:00	2021-02-12 13:00:00	Visite d'une entreprise à Marolles-en-Brie
16296	04043D	ACC_VISIT	2021-02-12 14:00:00	2021-02-12 15:00:00	Rendez vous avec des experts
16297	04043D	DEPL_PRES_GVT	2021-02-15 11:30:00	2021-02-15 13:00:00	Visite d'une entreprise à Chennevières-sur-Marne
16388	08010L	REU_TRAV_PARL	2021-03-10 14:30:00	2021-03-10 17:30:00	Cabinet du sénat
16337	04042C	ELUS_LOCAUX	2021-03-01 11:30:00	2021-03-01 12:30:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
16338	04042C	ORG_POL	2021-03-02 11:00:00	2021-03-02 12:30:00	Réunion de Groupe des L.R au Sénat
16390	04086Q	ELUS_LOCAUX	2021-03-09 14:00:00	2021-03-09 15:00:00	Rendez-vous de travail avec des élus locaux de Seine-Saint-Denis
16389	04086Q	ORG_POL	2021-03-09 11:00:00	2021-03-09 12:30:00	Réunion du groupe LR
16404	08010L	ORG_POL	2021-03-16 10:30:00	2021-03-16 12:30:00	Groupe LR du Sénat + G. KEPEL
16405	04042C	ACC_VISIT	2021-03-16 10:00:00	2021-03-16 11:00:00	Visite de courtoisie du Directeur de cabinet de la Préfète du Val-de-Marne
16406	04042C	ORG_POL	2021-03-16 11:00:00	2021-03-16 12:00:00	Réunion de Groupe des Républicains au Sénat
16407	04042C	ELUS_LOCAUX	2021-03-16 13:00:00	2021-03-16 14:15:00	Rencontre avec un élu du Val-de-Marne
16408	04042C	REU_TRAV_PARL	2021-03-16 18:00:00	2021-03-16 20:00:00	Réunion de lancement des préparatifs du semestre de la Présidence française de l'Union européenne avec le Président du Sénat
16620	08010L	ACC_VISIT	2021-04-07 18:00:00	2021-04-07 19:00:00	Fédération EPL
16662	04042C	ACC_VISIT	2021-04-22 12:00:00	2021-04-22 13:00:00	Entretien avec un journaliste de Valeurs Actuelles
16761	04042C	COLL_TER	2021-05-10 08:30:00	2021-05-10 09:30:00	Entretien avec un élu
16762	04042C	ACC_VISIT	2021-05-10 12:00:00	2021-05-10 13:00:00	Entretien avec un élu
16763	04042C	ACC_DEPL_INTER	2021-05-10 15:00:00	2021-05-10 16:00:00	Visioconférence avec le Président de la Commission des Affaires étrangères du Parlement estonien
16764	04042C	REU_TRAV_PARL	2021-05-10 16:30:00	2021-05-10 17:30:00	Réunion de Direction
16863	04042C	ACC_DEPL_INTER	2021-05-19 09:00:00	2021-05-19 09:30:00	Entretien téléphonique avec l'Ambassadeur de France en Russie
16864	04042C	ELUS_LOCAUX	2021-05-19 12:30:00	2021-05-19 13:45:00	Entretien avec un élu
16865	04042C	ELUS_LOCAUX	2021-05-19 18:00:00	2021-05-19 19:00:00	Entretien avec un élu
17006	04042C	ACC_DEPL_INTER	2021-06-01 15:50:00	2021-06-01 16:45:00	Entretien avec le Président du Sénat et le Premier Ministre de la République d'Arménie
17041	04042C	ACC_DEPL_INTER	2021-06-02 09:00:00	2021-06-02 00:00:00	Déplacement au Forum International de Saint Pétersbourg
15642	08010L	DEL_ACT_PAR	2020-12-03 11:00:00	2020-12-03 12:30:00	Cour de Justice de la République 
15645	20152B	REU_TRAV_PARL	2020-12-09 11:30:00	2020-12-09 12:30:00	Groupe amitié France Italie
15901	14133K	COLL_TER	2020-12-18 10:30:00	2020-12-18 12:30:00	Visite associations humanitaires et médico-sociales - Pays d'Auge
15902	14133K	ELUS_LOCAUX	2020-12-21 15:00:00	2020-12-21 18:00:00	Rendez-vous élus locaux - permanence parlementaire
15903	14133K	COLL_TER	2020-12-14 09:30:00	2020-12-14 11:30:00	Rendez-vous sociaux et économiques permanence parlementaire dans le Calvados
15904	14133K	COLL_TER	2020-12-14 14:30:00	2020-12-14 15:30:00	Visite Délégation départementale du Secours Populaire - Caen
16423	11066Q	REU_TRAV_PARL	2021-03-04 14:30:00	2021-03-04 15:30:00	Réunion de groupe
16022	04042C	CEREMONIE	2021-01-21 09:30:00	2021-01-21 10:30:00	Voeux aux armées de la Ministre des armées à Balard
16023	04042C	ACC_DEPL_INTER	2021-01-21 11:30:00	2021-01-21 12:15:00	Entretien avec l'Ambassadeur du Royaume d'Arabie Saoudite
16024	04042C	ACC_VISIT	2021-01-21 12:15:00	2021-01-21 12:30:00	Enterview téléphonique avec un journaliste du journal La Croix
16028	04086Q	REU_TRAV_PARL	2021-01-13 15:00:00	2021-01-13 17:00:00	Audition. DCT rapport Grand Paris 
16031	04086Q	REU_TRAV_PARL	2021-01-20 15:00:00	2021-01-20 17:00:00	UIP, séance d'information sur la réforme du Conseil de sécurité de l'ONU
16032	04086Q	REU_TRAV_PARL	2021-01-21 11:00:00	2021-01-21 12:30:00	Audition DCT Rapport Grand Paris
16033	04086Q	REU_TRAV_PARL	2021-01-21 14:00:00	2021-01-21 15:30:00	Audition DCT Rapport Grand Paris
16418	14147R	REU_TRAV_PARL	2021-03-18 09:30:00	2021-03-18 13:00:00	Commission nationale consultatives des droits de l'Homme - Réunion sur l'exploitation sexuelle des mineurs
16035	04086Q	REU_TRAV_PARL	2021-01-21 16:30:00	2021-01-21 17:30:00	Audition du président de l'Anah, dans le cadre de son rapport sur le logement
16424	11066Q	COLL_TER	2021-03-05 18:00:00	2021-03-05 19:00:00	Point de situation Covid-19 en Loire-Atlantique
16425	11066Q	REU_TRAV_PARL	2021-03-08 11:30:00	2021-03-08 12:30:00	Réunion de groupe
16429	11066Q	REU_TRAV_PARL	2021-03-09 15:00:00	2021-03-09 16:00:00	Entretien de préparation de travail CNCTR
16431	11066Q	REU_TRAV_PARL	2021-03-09 17:00:00	2021-03-09 19:00:00	Audition de François Hollande sur l'opération Barkhane-évolution de la situation au Mali et au Sahel
16515	11066Q	ACC_VISIT	2021-02-05 16:30:00	2021-02-05 17:30:00	Réunion en permanence sur les Chantiers de l'Atlantique
16432	11066Q	ORGEXTPAR	2021-03-11 09:00:00	2021-03-11 10:30:00	Réunion plénière de la Commission Nationale de Contrôle des Techniques de Renseignement
16433	11066Q	COLL_TER	2021-03-11 18:30:00	2021-03-11 19:30:00	Point de situation Covid-19 en Loire-Atlantique
16434	11066Q	ORGEXTPAR	2021-03-02 16:30:00	2021-03-02 17:30:00	Réunion plénière de la Commission Nationale de Contrôle des Techniques de Renseignement
16435	11066Q	REU_TRAV_PARL	2021-03-15 11:30:00	2021-03-15 12:30:00	Réunion de groupe
16436	11066Q	COLL_TER	2021-03-15 15:00:00	2021-03-15 16:00:00	Entretien avec la Maire de Batz sur Mer
16614	04086Q	ELUS_LOCAUX	2021-03-29 09:00:00	2021-03-29 10:00:00	Réunion avec des élus de Seine-Saint-Denis
16438	11066Q	CEREMONIE	2021-03-19 11:00:00	2021-03-19 11:30:00	Journée nationale du souvenir et du recueillement à la mémoire des victimes civiles et militaires de la guerre d'Algérie et des combats en Tunisie et au Maroc
16439	11066Q	COLL_TER	2021-03-19 15:30:00	2021-03-19 17:00:00	Commission des élus de la Dotation d'Equipement des Territoires Ruraux (DETR)
16440	11066Q	COLL_TER	2021-03-19 18:30:00	2021-03-19 19:30:00	Point de situation Covid-19 en Loire-Atlantique
16441	11066Q	REU_TRAV_PARL	2021-03-02 00:00:00	2021-03-02 00:00:00	\N
16480	04086Q	REU_TRAV_PARL	2021-03-23 16:30:00	2021-03-23 17:00:00	Réunion de travail, rapport PPL Fonds Souverains
16481	04086Q	ACC_DEPL_INTER	2021-03-24 17:30:00	2021-03-24 18:30:00	UIP, Assemblée générale du groupe Français
16632	08010L	REU_TRAV_PARL	2021-04-15 16:00:00	2021-04-15 17:00:00	Présidence du Sénat / EPL
16507	11066Q	COLL_TER	2021-03-25 18:30:00	2021-03-25 19:30:00	Point de situation Covid-19 en Loire-Atlantique
16615	04086Q	REU_GVT	2021-04-06 10:00:00	2021-04-06 11:00:00	Réunion avec Amélie de Montchalin, Ministre de la transformation et de la fonction publique
16513	11066Q	REU_TRAV_PARL	2021-02-02 10:00:00	2021-02-02 12:30:00	Réunion de groupe
17134	08010L	REU_TRAV_PARL	2021-06-24 11:30:00	2021-06-24 12:30:00	Justice
16516	11066Q	COLL_TER	2021-02-05 18:30:00	2021-02-05 19:30:00	Point de situation Covid-19 en Loire-Atlantique
16517	11066Q	REU_TRAV_PARL	2021-02-08 11:30:00	2021-02-08 12:30:00	Réunion de groupe
16518	11066Q	COLL_TER	2021-02-08 14:00:00	2021-02-08 16:00:00	Comiété départemental France Relance
16519	11066Q	REU_TRAV_PARL	2021-02-09 10:30:00	2021-02-09 12:30:00	Réunion de groupe
16520	11066Q	ORGEXTPAR	2021-02-10 09:15:00	2021-02-10 12:00:00	Réunion CNCTR
16522	11066Q	REU_TRAV_PARL	2021-02-12 13:30:00	2021-02-12 14:30:00	\N
16523	11066Q	REU_TRAV_PARL	2021-02-15 11:30:00	2021-02-15 12:30:00	Réunion de groupe
16524	11066Q	REU_TRAV_PARL	2021-02-16 10:00:00	2021-02-16 12:30:00	Réunion de groupe
16525	11066Q	ORGEXTPAR	2021-02-16 16:30:00	2021-02-16 17:30:00	Réunion plénière de la Commission Nationale de Contrôle des Techniques de Renseignement
16563	04042C	ACC_DEPL_INTER	2021-03-31 13:00:00	2021-03-31 14:15:00	Rencontre avec l'Ambassadrice d'Italie en France
16527	11066Q	ELUS_LOCAUX	2021-02-17 14:15:00	2021-02-17 15:00:00	\N
16528	11066Q	ORGEXTPAR	2021-02-17 17:00:00	2021-02-17 18:00:00	Réunion CNCTR
16564	04042C	COLL_TER	2021-03-30 19:00:00	2021-03-30 20:30:00	Reunion de la commission Urbanisme Aménagement et Habitat de l'Etablissement Public Territorial  Paris Est Marne & Bois
16565	04042C	ELUS_LOCAUX	2021-03-31 19:00:00	2021-03-31 20:30:00	Conseil municipal de Saint-Maurice
16566	04042C	REU_TRAV_PARL	2021-04-01 08:00:00	2021-04-01 08:45:00	Entretien avec le Président du Sénat et le Chef d'état-major des armées
16567	04042C	ORG_POL	2021-04-01 08:45:00	2021-04-01 10:15:00	Réunion de Groupe exceptionnelle des L.R du Sénat
16568	04042C	REU_TRAV_PARL	2021-04-01 18:00:00	2021-04-01 19:00:00	Entretien avec le Président-directeur général de Naval Group
16569	04042C	REU_TRAV_PARL	2021-04-01 17:00:00	2021-04-01 18:00:00	Réunion de travail avec des Sénateur
16617	04086Q	ELUS_LOCAUX	2021-04-06 17:30:00	2021-04-06 19:00:00	Réunion avec des élus de Seine-Saint-Denis
16618	04086Q	ELUS_LOCAUX	2021-04-07 17:00:00	2021-04-07 19:00:00	Réunion avec des élus de Seine-Saint-Denis
16633	04042C	ACC_DEPL_INTER	2021-04-14 15:00:00	2021-04-14 16:00:00	Visite de courtoisie de l'Ambassadeur de Hongrie en France
16634	04042C	ACC_VISIT	2021-04-14 17:00:00	2021-04-14 18:00:00	Emission Twitch de Public Sénat
16642	11066Q	ORGEXTPAR	2021-04-07 15:00:00	2021-04-07 16:30:00	Réunion plénière de la Commission Nationale de Contrôle des Techniques de Renseignement
16646	11066Q	REU_TRAV_PARL	2021-04-13 13:30:00	2021-04-13 14:00:00	Réunion de groupe
16647	11066Q	ORGEXTPAR	2021-04-13 16:30:00	2021-04-13 17:30:00	Réunion plénière de la Commission Nationale de Contrôle des Techniques de Renseignement
16648	11066Q	REU_TRAV_PARL	2021-04-13 15:00:00	2021-04-13 16:00:00	Préparation DPR
16649	11066Q	REU_GVT	2021-04-14 12:00:00	2021-04-14 13:00:00	Réunion avec le Ministère de l'Économie sur les Chantiers de l'Atlantique
16661	04042C	ACC_DEPL_INTER	2021-04-21 14:30:00	2021-04-21 15:15:00	Entretien avec le Ministre de la Défense britannique à l'Ambassade britannique
16701	08010L	ORG_POL	2021-04-27 10:30:00	2021-04-27 11:30:00	CNI LR 
16726	08010L	REU_TRAV_PARL	2021-05-04 10:00:00	2021-05-04 11:00:00	cabinet du sénat
16728	04042C	ELUS_LOCAUX	2021-05-03 10:30:00	2021-05-03 12:30:00	Rendez-vous Urbanisme à la Mairie de Saint Maurice
16727	08010L	ORG_POL	2021-05-04 11:00:00	2021-05-04 12:30:00	Groupe LR du Sénat
16729	04042C	ORG_POL	2021-05-03 15:20:00	2021-05-03 16:20:00	Audition de la CNI pour les élections régionales
16730	04042C	ORG_POL	2021-05-04 11:00:00	2021-05-04 12:30:00	Réunion de Groupe Les L.R au Sénat
16731	04042C	REU_TRAV_PARL	2021-05-04 12:30:00	2021-05-04 13:00:00	Entretien avec un Sénateur
16861	08010L	ORG_POL	2021-05-18 11:00:00	2021-05-18 12:30:00	Groupe LR du Sénat 
17043	04042C	ACC_DEPL_INTER	2021-06-03 00:00:00	2021-06-03 00:00:00	Déplacement au Forum International de Saint Pétersbourg
17044	04042C	ACC_DEPL_INTER	2021-06-04 00:00:00	2021-06-04 00:00:00	Déplacement au Forum International de Saint Pétersbourg
17046	04042C	REU_GVT	2021-06-07 11:00:00	2021-06-07 11:30:00	Entretien téléphoniqque avec la Ministre des armées
15641	08010L	REU_TRAV_PARL	2020-12-02 09:00:00	2020-12-02 11:00:00	Com. Finances / PLF 2021
15643	20152B	REU_TRAV_PARL	2020-12-08 14:00:00	2020-12-08 14:30:00	Groupe ruralité
15644	20152B	REU_TRAV_PARL	2020-12-03 10:45:00	2020-12-03 11:15:00	\N
15922	08010L	ORG_POL	2021-01-12 11:00:00	2021-01-12 12:30:00	Groupe LR du Sénat
15702	14133K	COLL_TER	2020-11-30 14:30:00	2020-11-30 15:30:00	visite entreprise industrielle dans le Calvados
15703	14133K	ELUS_LOCAUX	2020-11-30 17:00:00	2020-11-30 18:00:00	rendez-vous Conseil départemental du Calvados
15749	14133K	ELUS_LOCAUX	2020-11-20 14:30:00	2020-11-20 16:30:00	Réunion DETR 14 - Préfecture Caen
15705	14133K	COLL_TER	2020-12-04 09:15:00	2020-12-04 11:45:00	Rendez-vous sociaux et économiques permanence parlementaire dans le Calvados
15706	14133K	ELUS_LOCAUX	2020-12-04 14:30:00	2020-12-04 15:00:00	Rendez-vous élus locaux dans le Calvados
15707	14133K	COLL_TER	2020-12-04 15:30:00	2020-12-04 16:30:00	Visite entreprise Bassin virois avec élus régionaux
15711	14133K	ELUS_LOCAUX	2020-11-02 19:30:00	2020-11-02 20:30:00	Audio conférence avec le Préfet du Calvados - suivi de la crise sanitaire
15712	14133K	ORG_POL	2020-10-05 17:30:00	2020-10-05 19:30:00	Réunion du Groupe LR Sénat
15713	14133K	ORG_POL	2020-12-01 11:00:00	2020-12-01 12:30:00	Réunion du Groupe LR Sénat
15714	14133K	ORG_POL	2020-10-06 11:00:00	2020-10-06 12:30:00	Réunion du Groupe LR Sénat
15715	14133K	DEPL_PRES_GVT	2020-10-08 16:00:00	2020-10-08 17:30:00	Inauguration du Tribunal judiciaire de Lisieux en présence du Garde des Sceaux
15748	14133K	ORG_POL	2020-11-17 11:00:00	2020-11-17 12:30:00	Réunion du Groupe LR Sénat
15750	14133K	COLL_TER	2020-11-23 09:30:00	2020-11-23 12:00:00	Rendez-vous sociaux et économiques permanence parlementaire dans le Calvados
15751	14133K	COLL_TER	2020-11-23 16:00:00	2020-11-23 17:00:00	Rdv personnels médico-sociaux Graye-sur-Mer
15752	14133K	ELUS_LOCAUX	2020-11-23 19:30:00	2020-11-23 20:30:00	Audio conférence avec le Préfet du Calvados - suivi de la crise sanitaire
15753	14133K	COLL_TER	2020-11-26 15:00:00	2020-11-26 17:00:00	rencontre Croix Rouge Calvados - suivi de la crise sociale
15754	14133K	COLL_TER	2020-11-27 09:30:00	2020-11-27 12:00:00	Rendez-vous sociaux et économiques permanence parlementaire dans le Calvados
15755	14133K	ELUS_LOCAUX	2020-11-27 16:00:00	2020-11-27 17:30:00	Comité départemental du Plan de Relance
15756	14133K	ELUS_LOCAUX	2020-11-30 09:00:00	2020-11-30 12:30:00	Assemblée générale de l'Union amicale des maires du Calvados
15757	08010L	ORG_POL	2020-12-08 11:00:00	2020-12-08 12:30:00	Groupe LR du Sénat + C. JACOB
16025	11103C	REU_TRAV_PARL	2021-01-20 08:00:00	2021-01-20 09:00:00	Groupe Chasse et Pêche
15921	08010L	REU_TRAV_PARL	2021-01-12 10:00:00	2021-01-12 11:00:00	Cabinet du sénat
16026	11103C	REU_TRAV_PARL	2021-01-20 09:00:00	2021-01-20 11:30:00	Commission des affaires sociales
16027	11103C	REU_TRAV_PARL	2021-01-20 15:00:00	2021-01-20 16:00:00	Question d'actualité au gouvernement
16029	04086Q	ORG_POL	2021-01-12 11:00:00	2021-01-12 12:30:00	Réunion du groupe LR
16322	04042C	REU_TRAV_PARL	2021-02-03 17:30:00	2021-02-03 18:30:00	Réunion avec la Direction d'Airbus en Visioconference
16164	04042C	ACC_DEPL_INTER	2021-02-03 15:00:00	2021-02-03 15:30:00	Forum transaltlantique AP-OTAN en Visioconférence
16323	04042C	ACC_VISIT	2021-02-09 07:15:00	2021-02-09 08:00:00	Emission La Matinale de Public Sénat
16335	01058X	REU_TRAV_PARL	2021-02-23 19:30:00	2021-02-23 21:30:00	19h30 - Réunion Commission consultative de suivi des essais nucléaires
16167	04042C	REU_TRAV_PARL	2021-02-04 08:00:00	2021-02-04 09:30:00	Entretien avec le Chef d'état-major de la Marine
16168	04042C	REU_TRAV_PARL	2021-02-04 10:30:00	2021-02-04 10:45:00	Entretien téléphonique avec le Président de la Commission des Affaires étrangères de l'Assemblée nationale
16169	04042C	REU_GVT	2021-02-04 15:00:00	2021-02-04 16:00:00	Entretien avec le Ministre des Outre-mer
16170	04042C	ACC_DEPL_INTER	2021-02-04 17:00:00	2021-02-04 17:20:00	Entretien téléphonique avec L'Ambassadeur de Djibouti en France
16171	04042C	ACC_DEPL_INTER	2021-02-04 17:30:00	2021-02-04 18:30:00	Entretien avec le Président du Senat et la Présidente de la République de Moldavie
16201	04042C	ELUS_LOCAUX	2021-02-08 11:00:00	2021-02-08 12:00:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
16202	04042C	ELUS_LOCAUX	2021-02-08 14:00:00	2021-02-08 15:00:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
16203	04042C	ACC_DEPL_INTER	2021-02-08 17:00:00	2021-02-08 17:15:00	Entretien téléphonique avec l'Ambassadeur de France en Italie
16208	11103C	ORG_POL	2021-02-09 11:00:00	2021-02-09 12:30:00	LR du Sénat 
16343	08010L	ORGEXTPAR	2021-03-04 10:30:00	2021-03-04 13:00:00	Cour de Justice de la République 
16361	04042C	REU_TRAV_PARL	2021-03-05 09:00:00	2021-03-05 09:45:00	Audioconférence avec la Secrétaire générale aux Affaires européennes et le Président de la Commission des Affaires européennes du Sénat
16324	04042C	ACC_VISIT	2021-02-09 09:00:00	2021-02-09 09:15:00	Interview Emission de Radio Notre-Dame
16362	04042C	ELUS_LOCAUX	2021-03-05 10:00:00	2021-03-05 12:00:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
16391	08010L	REU_TRAV_PARL	2021-03-11 14:30:00	2021-03-11 17:00:00	\N
16364	04042C	ACC_VISIT	2021-03-05 15:30:00	2021-03-05 16:30:00	Entrtien avec le Directeur général d'Expertise France
16365	04042C	ACC_DEPL_INTER	2021-03-05 16:30:00	2021-03-05 17:30:00	Entretien avec l'Ambassadeur de la Bulgarie en France
16366	04042C	ACC_DEPL_INTER	2021-03-05 13:00:00	2021-03-05 14:15:00	Rencontre avec l'Ambassadeur du Japon en France
16367	04042C	ELUS_LOCAUX	2021-03-05 18:30:00	2021-03-05 19:30:00	Rendez-vous avec des élus du Val-de-Marne
16392	04042C	ACC_DEPL_INTER	2021-03-11 13:00:00	2021-03-11 14:15:00	Rencontre avec l'Ambassadrice d'Italie en France
16393	04042C	ACC_DEPL_INTER	2021-03-11 16:50:00	2021-03-11 18:00:00	Entretien avec le Président du Sénat et le Vice-premier ministre de Pologne
16394	04042C	ELUS_LOCAUX	2021-03-11 18:15:00	2021-03-11 19:15:00	Rendez-vous avec un élu du Val-de-Marne
16395	04042C	DEPL_PRES_GVT	2021-03-12 09:00:00	2021-03-12 19:00:00	Déplacement officiel avec le Président de la République et la Ministre des armées au Centre d'entraînement du 4ème Régiment Etranger à Saint-Gaudéric
16504	11066Q	ORGEXTPAR	2021-03-23 16:30:00	2021-03-23 17:30:00	Réunion CNCTR
16502	11066Q	REU_TRAV_PARL	2021-03-22 11:30:00	2021-03-22 12:30:00	Réunion de groupe
16503	11066Q	REU_TRAV_PARL	2021-03-23 10:00:00	2021-03-23 12:30:00	Réunion de groupe
16505	11066Q	REU_TRAV_PARL	2021-03-23 18:00:00	2021-03-23 19:00:00	Groupe de travail
16508	11066Q	COLL_TER	2021-03-09 16:00:00	2021-03-09 17:00:00	Réunion de lancement de l'étude de zone pour évaluer l'état environnemental sur la CARENE
16509	11066Q	COLL_TER	2021-03-04 18:30:00	2021-03-04 19:30:00	Point de situation Covid-19 en Loire-Atlantique
16511	11066Q	REU_TRAV_PARL	2021-02-01 11:30:00	2021-02-01 12:30:00	Réunion de groupe
16512	11066Q	ACC_VISIT	2021-02-01 14:30:00	2021-02-01 15:30:00	Réunion en permanence sur les Chantiers de l'Atlantique
16514	11066Q	ORGEXTPAR	2021-02-04 09:00:00	2021-02-04 11:00:00	Réunion plénière de la Commission Nationale de Contrôle des Techniques de Renseignement
16521	11066Q	COLL_TER	2021-02-11 18:30:00	2021-02-11 19:30:00	Point de situation Covid-19 en Loire-Atlantique
16607	08010L	CEREMONIE	2021-04-08 16:00:00	2021-04-08 17:00:00	400 ans La Fontaine Chatreau-Thierry 
16608	08010L	COLL_TER	2021-04-08 18:00:00	2021-04-08 20:00:00	Conseil d'agglomération Laon
16609	04042C	COLL_TER	2021-04-07 14:30:00	2021-04-07 15:00:00	Visioconférence du Conseil de la Métropole du Grand Paris
16610	04042C	REU_GVT	2021-04-08 11:30:00	2021-04-08 12:30:00	Visioconférence sur le PJL développement solidaire et à la lutte contre les inégalités avec le ministère de l'Europe et des Affaires étrangères
16611	04042C	COLL_TER	2021-04-08 18:00:00	2021-04-08 19:00:00	Visioconférence réunion de travail des élections régionales
16612	04042C	COLL_TER	2021-04-09 08:45:00	2021-04-09 11:00:00	Réunion du bureau du Syndicat des Eaux d'Ile-de-France
16613	04086Q	ORG_POL	2021-03-30 11:00:00	2021-03-30 12:30:00	Réunion du groupe LR
16619	01058X	REU_TRAV_PARL	2021-03-31 16:30:00	2021-03-31 17:30:00	Évaluation du plan national de gestion des matières et déchets radioactifs (PNGMDR)Évaluation du plan national de gestion des matières et déchets radioactifs (PNGMDR)
16782	08010L	REU_TRAV_PARL	2021-05-12 13:30:00	2021-05-12 14:00:00	Com lois
15621	04042C	COLL_TER	2020-12-01 14:30:00	2020-12-01 16:00:00	Conseil Métropolitain
15622	04042C	ACC_DEPL_INTER	2020-12-01 16:30:00	2020-12-01 17:30:00	Intervention auprès des élèves officiers de l'Ecole Militaire
15623	04042C	ACC_DEPL_INTER	2020-12-02 13:00:00	2020-12-02 14:30:00	Rencontre avec l'Ambassadeur du Chili en France et le Ministre des Affaires étrangères du Chili
15624	04042C	CEREMONIE	2020-12-02 15:00:00	2020-12-02 16:00:00	Cérémonie du 150ème anniversaire de la bataille de Champigny-sur-Marne
15783	14133K	COLL_TER	2020-11-23 17:15:00	2020-11-23 18:30:00	rencontre avec un ostréiculteur de Courseulles-sur-Mer - crise Covid
15784	04042C	ELUS_LOCAUX	2020-12-07 10:30:00	2020-12-07 13:00:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
15785	04042C	COLL_TER	2020-12-07 15:00:00	2020-12-07 16:00:00	Visioconférence du Syndicat des Eaux d'Ile-de-France
15786	04042C	ELUS_LOCAUX	2020-12-07 18:30:00	2020-12-07 19:30:00	Visioconférence du Pré conseil municipal de Saint-Maurice
15787	04042C	ACC_VISIT	2020-12-08 10:00:00	2020-12-08 11:00:00	Entretien avec le Président général de Seine Ouest
15788	04042C	ORG_POL	2020-12-08 11:00:00	2020-12-08 12:00:00	Réunion de Groupe des L.R au Sénat
15789	04042C	ACC_DEPL_INTER	2020-12-08 12:30:00	2020-12-08 13:30:00	Entretien avec le Représentant du Gouvernement régional du Kurdistan-Irak
15790	04042C	REU_TRAV_PARL	2020-12-08 14:00:00	2020-12-08 14:30:00	Réunion avec un Président de commission du Sénat et une Présidente de commission de l'Assemblée nationale
15791	04042C	ACC_DEPL_INTER	2020-12-08 18:50:00	2020-12-08 20:00:00	Entretien avec le Président du Sénat et Président de la République Arabe d'Egypte
15792	04042C	ACC_DEPL_INTER	2020-12-08 20:00:00	2020-12-08 22:00:00	Dîner de visite d'Etat à la Présidence du Sénat à l'occasion de la venue du Président de la République arabe d'Egypte
15793	04042C	ACC_DEPL_INTER	2020-12-09 08:30:00	2020-12-09 09:30:00	Entretien avec le Président du Sénat et le Ministre des Affaires étrangères d'Arménie
15794	04042C	ORG_POL	2020-12-09 19:00:00	2020-12-09 20:00:00	Visioconférence du bureau politique élargi les Républicains du Val-de-Marne
15795	04042C	REU_TRAV_PARL	2020-12-10 12:30:00	2020-12-10 14:30:00	Rencontre avec le Président de Dassault
15796	04042C	ELUS_LOCAUX	2020-12-10 18:00:00	2020-12-10 19:00:00	Réunion de présentation du secteur psychiatrie des Hôpitaux de Saint-Maurice
15797	04042C	ELUS_LOCAUX	2020-12-10 19:00:00	2020-12-10 21:00:00	Conseil municipal de Saint-Maurice
15801	08010L	REU_TRAV_PARL	2020-12-10 10:00:00	2020-12-10 12:00:00	Cabinet du sénat 
15802	08010L	COLL_TER	2020-12-10 18:00:00	2020-12-10 20:00:00	Agglomération de Laon
15983	04042C	DEPL_PRES_GVT	2021-01-19 10:30:00	2021-01-19 20:20:00	Voeux aux armées du Président de la République à Brest 
15864	04086Q	COLL_TER	2020-12-08 10:00:00	2020-12-08 11:00:00	Réunion du comité régional de l'Habitat et de l'Hébergement 
15868	04086Q	REU_TRAV_PARL	2020-12-15 11:00:00	2020-12-15 12:30:00	Réunion du groupe LR
15870	04086Q	ELUS_LOCAUX	2020-12-15 17:00:00	2020-12-15 18:30:00	Préfecture comite de suivi pour le Plan de relance dans le 93
15982	04042C	ELUS_LOCAUX	2021-01-18 10:30:00	2021-01-18 12:30:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
15984	04042C	COLL_TER	2021-01-15 08:45:00	2021-01-15 11:00:00	Réunion du bureau du SEDIF
15985	04042C	ELUS_LOCAUX	2021-01-15 11:30:00	2021-01-15 12:30:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
15986	04042C	ELUS_LOCAUX	2021-01-15 14:00:00	2021-01-15 15:00:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
15987	04042C	REU_TRAV_PARL	2021-01-13 13:00:00	2021-01-13 14:00:00	Rencontre avec le Président du Sénat et les Présidents de commission
15988	04042C	ACC_DEPL_INTER	2021-01-12 18:30:00	2021-01-12 19:30:00	Entretien avec le Président du Sénat et le Président de la Commission des Affaires étrangères de Libye
15989	04042C	ACC_DEPL_INTER	2021-01-12 19:30:00	2021-01-12 21:00:00	Réception du Président du Sénat à l'occasion de la visite en France du Président de la Commission des Affaires étrangères de la Libye
16002	11103C	ORG_POL	2021-01-19 11:00:00	2021-01-19 12:30:00	LR du Sénat 
16041	04042C	REU_TRAV_PARL	2021-01-21 15:00:00	2021-01-21 16:00:00	Entretien avec le Directeur général de Safran
16042	04042C	REU_TRAV_PARL	2021-01-21 16:15:00	2021-01-21 16:45:00	Rendez-vous téléphonique avec un Sénateur
16043	04042C	ELUS_LOCAUX	2021-01-21 17:00:00	2021-01-21 19:00:00	Conférence de presse sur les nuisances sonores d'Orly en Présence de la Présidente de la Région d'Ile-de-France et du Président de la Métropole du Grand Paris
16044	04042C	COLL_TER	2021-01-25 08:30:00	2021-01-25 10:00:00	Réunion de travail avec le Président de Veolia
16045	04042C	ACC_DEPL_INTER	2021-01-25 11:00:00	2021-01-25 12:00:00	Entretien avec l'Ambassadrice de la Grèce en France
16046	04042C	ELUS_LOCAUX	2021-01-25 15:00:00	2021-01-25 16:00:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
16047	04042C	REU_GVT	2021-01-25 19:00:00	2021-01-25 20:30:00	Réunion avec le Ministre de l'Europe et des Affaires étrangères
16048	04042C	ORG_POL	2021-01-26 11:00:00	2021-01-26 12:30:00	Réunion de Groupe des L.R au Sénat
16049	04042C	REU_TRAV_PARL	2021-01-26 15:00:00	2021-01-26 16:00:00	Entretien avec le Président de Civipol
16050	04042C	REU_TRAV_PARL	2021-01-26 16:00:00	2021-01-26 16:30:00	Entretien avec le Président du GIA France-Allemagne
16051	04042C	REU_TRAV_PARL	2021-01-26 16:30:00	2021-01-26 17:30:00	Réunion de Direction
16052	04042C	REU_TRAV_PARL	2021-01-26 12:30:00	2021-01-26 13:00:00	Entretien avec un Sénateur
16053	08010L	ORG_POL	2021-01-26 11:00:00	2021-01-26 12:30:00	Groupe LR de Sénat 
16255	14133K	REU_TRAV_PARL	2021-02-02 14:00:00	2021-02-02 14:45:00	Groupe d'amitié France-Pakistan
16259	14133K	REU_TRAV_PARL	2021-02-05 15:00:00	2021-02-05 16:30:00	rencontre Préfet maritime de la Mer du Nord et de la Manche - Cherbourg
16257	14133K	REU_TRAV_PARL	2021-02-04 08:30:00	2021-02-04 10:00:00	réunion CEM Armée de Terre
16258	14133K	ORG_POL	2021-02-05 10:00:00	2021-02-05 12:00:00	rdv permanence parlementaire
16260	14133K	ORG_POL	2021-02-08 10:00:00	2021-02-08 12:00:00	rdv permanence parlementaire
16261	14133K	ELUS_LOCAUX	2021-02-08 19:30:00	2021-02-08 20:30:00	Audio conférence avec le Préfet du Calvados - suivi de la crise sanitaire
16262	14133K	ORG_POL	2021-02-09 11:00:00	2021-02-09 12:30:00	Réunion du Groupe LR Sénat
16263	04042C	ORG_POL	2021-02-09 18:00:00	2021-02-09 19:00:00	Visioconférence du bureau politique élargi des L.R du Val-de-Marne
16268	04042C	ACC_DEPL_INTER	2021-02-11 12:35:00	2021-02-11 14:15:00	Rencontre avec le Président de Djibouti et sa Délégation à la Présidence du Sénat
16415	04042C	ACC_DEPL_INTER	2021-03-18 11:30:00	2021-03-18 12:30:00	Entretien avec l'Ambassadeur de la République Islamique d'Iran en France
16269	04042C	ACC_VISIT	2021-02-11 15:30:00	2021-02-11 16:30:00	Rendez-vous Urbanisme
16270	04042C	ACC_VISIT	2021-02-11 16:30:00	2021-02-11 17:00:00	Interview video S&D Magazine
16303	04042C	ACC_VISIT	2021-02-16 10:00:00	2021-02-16 11:00:00	Visioconférence de l'AJD sur la Revue Stratégique
16304	04042C	ORG_POL	2021-02-16 11:00:00	2021-02-16 12:30:00	Réunion de Groupe des L.R au Sénat
16305	04042C	ACC_DEPL_INTER	2021-02-16 13:00:00	2021-02-16 14:15:00	Rencontre avec l'Ambassadeur du Brésil
16306	04042C	REU_TRAV_PARL	2021-02-16 15:30:00	2021-02-16 16:30:00	Réunion du Groupe de liaison avec les Chrétiens, les minorités au Moyen-Orient et les Kurdes 
16307	04042C	ACC_VISIT	2021-02-16 16:30:00	2021-02-16 17:30:00	Rendez-vous avec un Maire-adjoint
16308	08010L	REU_TRAV_PARL	2021-02-16 14:30:00	2021-02-16 15:30:00	Commission des Finances
16413	08010L	ACC_VISIT	2021-03-18 10:00:00	2021-03-18 10:45:00	Rdv sur le DATA
16414	04042C	ACC_DEPL_INTER	2021-03-18 10:30:00	2021-03-18 11:30:00	Visioconférence avec le Président du Sénat et la Présidente du Sénat roumain
16416	04042C	REU_TRAV_PARL	2021-03-18 12:30:00	2021-03-18 13:30:00	Reunion de travail 
16417	04042C	ELUS_LOCAUX	2021-03-18 17:30:00	2021-03-18 18:30:00	Rendez-vous avec un élu du Val-de-Marne
16461	04042C	ELUS_LOCAUX	2021-03-19 11:00:00	2021-03-19 12:30:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
16462	04042C	CEREMONIE	2021-03-19 14:45:00	2021-03-19 15:45:00	Représention du Président du Sénat àCérémonie à l'occasion de la journée du souvenir et du recueillement de la guerre d'Algérie et des combats du Maroc et de la Tunisie 
16463	04042C	CEREMONIE	2021-03-19 16:40:00	2021-03-19 17:30:00	Représentation du Président du Sénat à la Cérémonie du ravivage de la Flamme à l'occasion de la journée du souvenir à la mémoire des victimes civiles et militaires de la guerre d'Algérie
17130	08010L	REU_TRAV_PARL	2021-06-23 14:00:00	2021-06-23 15:00:00	PJL programmation militaire 
17131	08010L	ACC_DEPL_INTER	2021-06-23 15:00:00	2021-06-23 15:30:00	Délégation de Corée du Sud
17132	11103C	ORG_POL	2021-06-22 11:00:00	2021-06-22 12:30:00	Groupe LR du Sénat
17223	20024T	ELUS_LOCAUX	2021-07-02 10:00:00	2021-07-02 12:00:00	Assemblée Générale de l'Association des Maires de la Vienne
17135	04042C	ACC_DEPL_INTER	2021-06-23 10:50:00	2021-06-23 12:00:00	Entretien avec le Président du Sénat et le Président du Conseil des Représentants irakien
17136	04042C	REU_TRAV_PARL	2021-06-23 12:00:00	2021-06-23 12:30:00	Réunion de Direction
17137	04042C	REU_TRAV_PARL	2021-06-23 14:00:00	2021-06-23 14:30:00	Conférence des Présidents
17138	04042C	ORG_POL	2021-06-23 14:30:00	2021-06-23 15:00:00	Réunion exceptionnelle des sénateurs du Groupe L.R du Sénat
17139	04042C	ACC_DEPL_INTER	2021-06-23 15:00:00	2021-06-23 16:00:00	Entretien avec une délégation coréenne
17140	04042C	COLL_TER	2021-06-24 10:00:00	2021-06-24 12:30:00	Réunion du Comité du Syndicat des Eaux d'Ile-de-France
17141	04042C	ACC_DEPL_INTER	2021-06-24 13:00:00	2021-06-24 14:15:00	Entretien avec l'Ambassadrice de Grèce en France
17142	04042C	ACC_VISIT	2021-06-24 18:00:00	2021-06-24 18:30:00	Plateau Emission Public Sénat
17143	04042C	ORG_POL	2021-06-24 20:00:00	2021-06-24 22:00:00	Grand Meeting de la Présidente du Conseil régional d'Ile-de-France
17221	20024T	COLL_TER	2021-07-01 09:30:00	2021-07-01 12:00:00	Election Président du Département de la Vienne
17222	20024T	COLL_TER	2021-06-28 20:15:00	2021-06-28 23:00:00	Conseil Municipal de Monts-sur-Guesnes
17224	20024T	ELUS_LOCAUX	2021-07-08 20:30:00	2021-07-08 22:00:00	Conseil Municipal de Mouterre-Silly
17232	04042C	ORG_POL	2021-07-06 11:00:00	2021-07-06 12:30:00	Réunion de Groupe des sénateurs LR du sénat
17233	04042C	REU_TRAV_PARL	2021-07-06 15:00:00	2021-07-06 15:45:00	Entretetien avec le Président du comité de déontologie parlementaire du Sénat
17234	04042C	ACC_DEPL_INTER	2021-07-06 15:45:00	2021-07-06 17:00:00	Entretien avec le Président du Sénat et le Président de la République italienne
17235	04042C	REU_GVT	2021-07-06 19:00:00	2021-07-06 20:00:00	Entretien avec le Premier ministre
17236	04042C	ORG_POL	2021-07-06 20:15:00	2021-07-06 21:30:00	Rencontres avec les sénateurs du Groupe LR au Sénat
17490	11103C	ORG_POL	2021-07-20 11:00:00	2021-07-20 12:30:00	LR du Sénat
17238	04042C	ACC_DEPL_INTER	2021-07-07 12:15:00	2021-07-07 13:15:00	Entretien avec le Président du Comité de la sécurité nationale et de la défense du Parlement lituanien et l'Ambassadeur de Lituanie en France
17239	04042C	REU_TRAV_PARL	2021-07-07 19:00:00	2021-07-07 20:30:00	rencontre Assemblée général du GICAT
17494	04042C	ACC_DEPL_INTER	2021-07-20 13:00:00	2021-07-20 14:15:00	Rencontre avec l'Ambassadeur de la République Fédérale d'Allemagne en France
17492	04042C	REU_TRAV_PARL	2021-07-20 10:45:00	2021-07-20 11:00:00	Entretien avec le Président du Comité de déontologie parlementaire du Sénat
17493	04042C	ORG_POL	2021-07-20 11:00:00	2021-07-20 12:30:00	Réunion de Groupe des sénateurs L.R du Sénat
17495	04042C	ACC_DEPL_INTER	2021-07-20 20:00:00	2021-07-20 22:30:00	Rencontre avec les membres du bureau du groupe Interparlementaire d'Amitié France Maroc et l'Ambassadeur du Royaume du Maroc en France
17496	04042C	REU_GVT	2021-07-21 12:45:00	2021-07-21 14:15:00	Rencontre au Ministère de l'Europe et des Affaires étrangères 
17497	04042C	CEREMONIE	2021-07-21 16:00:00	2021-07-21 17:30:00	cérémonie d'adieu aux armes du Chef d'état-major des armées
17498	04042C	REU_TRAV_PARL	2021-07-21 19:00:00	2021-07-21 21:30:00	Rencontre avec les Sénateurs et le Président du Sénat
17499	04042C	REU_GVT	2021-07-19 15:00:00	2021-07-19 16:00:00	Entretien avec la Ministre des armées
17567	08010L	DEL_ACT_PAR	2021-09-07 17:30:00	2021-09-07 19:00:00	AG du  Groupe français de l¿UIP (visio)
17622	08010L	ORG_POL	2021-09-28 11:00:00	2021-09-28 13:00:00	Groupe LR du Sénat
17626	04042C	ACC_VISIT	2021-09-28 08:00:00	2021-09-28 09:00:00	Rencontre avec le Président de la CCI du Val-de-Marne
17624	04042C	REU_TRAV_PARL	2021-09-27 12:30:00	2021-09-27 14:30:00	Rencontre avec le Chef d'état-major de l'armée de Terre
17628	04042C	ACC_DEPL_INTER	2021-09-28 10:45:00	2021-09-28 11:00:00	Entretien téléphonique avec le Président de la délégation allemande à l'AP/OTAN
17627	04042C	REU_TRAV_PARL	2021-09-28 10:00:00	2021-09-28 10:45:00	Entretien avec le Président du Haut Comité d'évaluation de la condition militaire 
17629	04042C	ORG_POL	2021-09-28 11:00:00	2021-09-28 12:30:00	Réunion de Groupe des Sénateurs L.R du Sénat
17630	04042C	REU_TRAV_PARL	2021-09-28 13:00:00	2021-09-28 14:30:00	Réunion de travail avec les Présidents des commissions du Sénat
17631	04042C	REU_TRAV_PARL	2021-09-28 15:30:00	2021-09-28 16:30:00	Réunion des Commissaires L.R du Sénat
17632	04042C	COLL_TER	2021-09-28 18:30:00	2021-09-28 20:00:00	Réunion de la commission urbanisme aménagement habitat et politique de la ville
17633	04042C	REU_TRAV_PARL	2021-09-29 13:00:00	2021-09-29 14:15:00	Rencontre avec les Présidents des commissions
17634	04042C	ACC_VISIT	2021-09-29 14:55:00	2021-09-29 15:15:00	Interview Public Sénat
17635	04042C	CEREMONIE	2021-09-29 16:30:00	2021-09-29 18:00:00	Hommage national à l'Hôtel National des Invalides
17636	04042C	ACC_DEPL_INTER	2021-09-30 13:00:00	2021-09-30 14:30:00	Rencontre avec l'Ambassadeur de Chine en France
17637	04042C	ACC_DEPL_INTER	2021-09-30 17:30:00	2021-09-30 19:00:00	Intervention au Webinaire de la Fondation Prospective et Innovationn
17638	04042C	COLL_TER	2021-10-01 08:45:00	2021-10-01 11:00:00	Réunion du bureau du Syndicat des Eaux d'Ile-de-France
17642	11103C	ORG_POL	2021-10-05 10:30:00	2021-10-05 12:30:00	LR du Sénat 
17643	08010L	CEREMONIE	2021-10-06 18:00:00	2021-10-06 20:00:00	Journée Unité Allemande
17722	11066Q	REU_TRAV_PARL	2021-07-13 15:45:00	2021-07-13 16:45:00	\N
17695	04042C	ACC_VISIT	2021-10-14 14:45:00	2021-10-14 15:00:00	Interview Public Sénat
17721	11066Q	ACC_VISIT	2021-07-13 14:30:00	2021-07-13 15:30:00	Entretien avec des membres de la Cour des Comptes sur les Chantiers de l'Atlantique
17723	11066Q	CEREMONIE	2021-07-13 18:30:00	2021-07-13 19:30:00	Réception en l'honneur des unités participant aux cérémonies de la fête nationale
17725	11066Q	ACC_VISIT	2021-07-12 09:00:00	2021-07-12 17:00:00	Permanence
17726	11066Q	ACC_VISIT	2021-07-19 09:00:00	2021-07-19 17:00:00	Permanence
17727	11066Q	REU_TRAV_PARL	2021-07-19 11:30:00	2021-07-19 12:30:00	Réunion de groupe
17728	11066Q	REU_TRAV_PARL	2021-07-19 15:00:00	2021-07-19 16:00:00	Réunion de groupe
17732	11066Q	ACC_VISIT	2021-07-16 09:00:00	2021-07-16 17:00:00	Permanence
17733	11066Q	ORGEXTPAR	2021-07-22 11:00:00	2021-07-22 13:00:00	Réunion plénière de la Commission Nationale de Contrôle des Techniques de Renseignement
17734	11066Q	ACC_VISIT	2021-07-23 09:00:00	2021-07-23 17:00:00	Permanence
17738	11066Q	ACC_VISIT	2021-08-23 09:00:00	2021-08-23 17:00:00	Permanence
17736	11066Q	COLL_TER	2021-07-29 18:30:00	2021-07-29 19:30:00	Point hebdomadaire sur la situation sanitaire du département
17763	11066Q	ACC_VISIT	2021-09-27 10:30:00	2021-09-27 11:30:00	Entretien avec des représentants syndicaux de la Centrale de Cordemais à propos de l'abandon du projet Ecocombust
17756	11066Q	ACC_VISIT	2021-09-20 09:00:00	2021-09-20 17:00:00	Permanence
17758	11066Q	ORGEXTPAR	2021-09-23 11:30:00	2021-09-23 15:00:00	Réunion plénière de la Commission Nationale de Contrôle des Techniques de Renseignement
17761	11066Q	ACC_VISIT	2021-09-24 09:00:00	2021-09-24 17:00:00	Permanence
17762	11066Q	ACC_VISIT	2021-09-27 09:00:00	2021-09-27 17:00:00	Permanence
17764	11066Q	REU_TRAV_PARL	2021-09-27 11:30:00	2021-09-27 12:30:00	Réunion de groupe
17765	11066Q	REU_TRAV_PARL	2021-09-28 14:30:00	2021-09-28 15:30:00	Réunion de préparation du Rapport budgétaire (programme 144) Budget de la Défense PLF 2022
17766	11066Q	ACC_VISIT	2021-10-01 09:00:00	2021-10-01 17:00:00	Permanence
17767	11066Q	ACC_VISIT	2021-10-04 09:00:00	2021-10-04 17:00:00	Permanence
17768	11066Q	REU_TRAV_PARL	2021-10-04 11:30:00	2021-10-04 12:30:00	Réunion de groupe
17769	11066Q	ACC_VISIT	2021-10-05 09:00:00	2021-10-05 17:00:00	Permanence
17770	11066Q	ACC_VISIT	2021-10-08 09:00:00	2021-10-08 11:00:00	Permanence
17771	11066Q	ELUS_LOCAUX	2021-10-08 12:30:00	2021-10-08 14:30:00	Réunion de travail avec le Préfet et les Sénateurs du Département
17772	11066Q	ACC_VISIT	2021-10-08 15:30:00	2021-10-08 17:00:00	Permanence
17812	04042C	COLL_TER	2021-10-22 09:30:00	2021-10-22 13:00:00	Conseil de Surveillance des Hôpitaux de Saint-Maurice
17813	04042C	ACC_DEPL_INTER	2021-10-22 17:30:00	2021-10-22 18:30:00	Entretien avec une délégation Coréenne
17110	04042C	ACC_DEPL_INTER	2021-06-16 18:00:00	2021-06-16 19:00:00	Rencontre avec l'Ambassadeur du Mexique en France à l'occasion de sa fin de mission en France
17111	04042C	ACC_VISIT	2021-06-16 19:30:00	2021-06-16 20:00:00	Emission Ca vous regarde sur LCP
17112	04042C	REU_GVT	2021-06-17 08:00:00	2021-06-17 09:00:00	Réunion de travail avec la Ministre des armées
17562	04042C	ACC_DEPL_INTER	2021-09-06 15:00:00	2021-09-06 16:00:00	Entretien avec l'Ambassadeur d'Afghanistan en France
17182	01058X	REU_TRAV_PARL	2021-06-30 00:00:00	2021-06-30 00:00:00	Auditions pour le PJL autorisant la ratification du Protocole d¿amendement à la Convention pour la protection des personnes à l¿égard du traitement automatisé des données à caractère personnel.
17183	01058X	ORG_POL	2021-06-29 11:00:00	2021-06-29 12:30:00	Réunion de Groupe Les Républicains au Sénat
17184	01058X	ORG_POL	2021-05-04 11:00:00	2021-05-04 12:30:00	Réunion de Groupe Les Républicains au Sénat
17561	04042C	ELUS_LOCAUX	2021-09-06 11:00:00	2021-09-06 12:00:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
17563	04042C	ELUS_LOCAUX	2021-09-06 13:00:00	2021-09-06 14:15:00	Rencontre avec des élus du Val-de-Marne
17564	04042C	ELUS_LOCAUX	2021-09-06 17:30:00	2021-09-06 18:30:00	Entretien avec des élus du Val-de-Marne
17601	11103C	ORG_POL	2021-09-21 11:00:00	2021-09-21 12:30:00	LR du Sénat 
17605	04042C	ORG_POL	2021-09-16 11:00:00	2021-09-16 00:00:00	Journées parlementaires à Vannes
17609	04042C	ACC_DEPL_INTER	2021-09-20 17:00:00	2021-09-20 17:30:00	Entretien téléphonique avec l'Ambassadeur d'Allemagne en France
17607	04042C	ORG_POL	2021-09-17 00:00:00	2021-09-17 00:00:00	Journées parlementaires à Vannes
17608	04042C	ELUS_LOCAUX	2021-09-20 11:30:00	2021-09-20 12:30:00	Rendez-vous Urabanisme à la Mairie de Saint-Maurice
17610	04042C	CEREMONIE	2021-09-20 18:00:00	2021-09-20 19:00:00	Cérémonie des médaillés olympiques à Champigny-sur-Marne
17611	04042C	ELUS_LOCAUX	2021-09-20 20:00:00	2021-09-20 22:00:00	Rencontre avec des élus du Val-de-Marne
17612	04042C	ACC_DEPL_INTER	2021-09-21 08:00:00	2021-09-21 00:00:00	Déplacement en Suisse
17616	04042C	ACC_DEPL_INTER	2021-09-23 19:00:00	2021-09-23 21:00:00	Rencontre avec l'Ambassadeur de Malte à l'aoccasion de la Fête nationale
17614	04042C	ACC_DEPL_INTER	2021-09-22 00:00:00	2021-09-22 20:00:00	Déplacement en Suisse
17615	04042C	REU_GVT	2021-09-23 15:30:00	2021-09-23 16:30:00	Entretien avec la Ministre des armées
17617	08010L	REU_TRAV_PARL	2021-09-23 09:00:00	2021-09-23 19:00:00	Déplacement à AGEN / ENAP
17684	04042C	ORG_POL	2021-10-12 10:30:00	2021-10-12 12:30:00	Réunion de Groupe des Sénateurs L.R du sénat
17685	04042C	REU_TRAV_PARL	2021-10-12 14:45:00	2021-10-12 15:00:00	Entretien avec le Chef d'état-major des Armées
17686	04042C	ELUS_LOCAUX	2021-10-12 18:00:00	2021-10-12 18:30:00	Entretien téléphonique avec un élu du Val-de-Marne
17687	04042C	ACC_VISIT	2021-10-13 13:00:00	2021-10-13 14:00:00	Entretien avec un élu du Val-de-Marne
17688	04042C	ACC_VISIT	2021-10-13 14:45:00	2021-10-13 15:00:00	Accueil de la visite guidée su Conseil Municipal des Enfants de Choisy-le-Roi
17689	04042C	ACC_DEPL_INTER	2021-10-13 17:20:00	2021-10-13 18:30:00	Entretien avec le Président du Sénat et le Président de la République du Tadjikistan
17690	04042C	CEREMONIE	2021-10-13 19:00:00	2021-10-13 20:00:00	Remise de décoration par le Président du Sénat à un membre honoraire du Parlement
17691	04042C	COLL_TER	2021-10-14 10:00:00	2021-10-14 14:30:00	Réunion du Comité du Syndicat des Eaux d'Ile-de-France
17692	04042C	ACC_DEPL_INTER	2021-10-14 15:00:00	2021-10-14 16:00:00	Entretien avec le Président Les Républicains du Sénat et une délégation de parlementaires allemands
17774	11066Q	ORGEXTPAR	2021-10-11 14:30:00	2021-10-11 16:00:00	Commission des élus de la Dotation d'Équipement des Territoires Ruraux (DETR)
17694	04042C	ACC_DEPL_INTER	2021-10-14 17:00:00	2021-10-14 18:00:00	Entretien avec l'Ambassadrice du Royaume-Uni en France
17773	11066Q	ACC_VISIT	2021-10-11 09:00:00	2021-10-11 12:30:00	Permanence
17775	11066Q	REU_TRAV_PARL	2021-10-12 10:00:00	2021-10-12 12:30:00	Réunion de groupe
17778	11066Q	ACC_VISIT	2021-10-18 09:00:00	2021-10-18 17:00:00	Permanence
17779	11066Q	ELUS_LOCAUX	2021-10-15 09:00:00	2021-10-15 12:30:00	Assemblée Générale des Maires et adjoints de l'arrondissement de Châteaubriant
17780	11066Q	ACC_VISIT	2021-10-15 14:00:00	2021-10-15 17:00:00	Permanence
17781	11066Q	REU_TRAV_PARL	2021-10-18 11:30:00	2021-10-18 12:30:00	Réunion de groupe
17782	11066Q	REU_TRAV_PARL	2021-10-19 17:00:00	2021-10-19 18:00:00	Audition avis budgétaire P144 pour le budget 2022 de la Défense
17783	11066Q	ACC_VISIT	2021-10-21 14:00:00	2021-10-21 17:00:00	Permanence
17816	04042C	CEREMONIE	2021-10-21 18:00:00	2021-10-21 20:00:00	Remise de décoration à un ancien memebre du Parlement
17803	08010L	ORG_POL	2021-10-26 11:00:00	2021-10-26 13:00:00	Groupe LR du Sénat + Barnier
17804	08010L	REU_TRAV_PARL	2021-10-26 14:00:00	2021-10-26 15:00:00	DCT audition AMRF
17814	04042C	ELUS_LOCAUX	2021-10-21 13:00:00	2021-10-21 14:15:00	Rencontre avec un élu  du Val-de-Marne
17815	04042C	ACC_DEPL_INTER	2021-10-21 16:30:00	2021-10-21 17:30:00	Entretien avec l'Ambassadeur du Koweït en France
17817	04042C	ELUS_LOCAUX	2021-10-25 13:00:00	2021-10-25 14:30:00	Rencontre avec des élus du Val-de-Marne
17818	04042C	ELUS_LOCAUX	2021-10-26 08:30:00	2021-10-26 09:30:00	Réunion de travail avec la Présidente de la Région d'Ile-de-France
17819	04042C	ORG_POL	2021-10-26 10:30:00	2021-10-26 13:00:00	Réunion de Groupe des Sénateurs L.R au Sénat
17820	04042C	ELUS_LOCAUX	2021-10-26 13:00:00	2021-10-26 14:00:00	Rencontre avec un élu du Val-de-Marne
17824	04042C	REU_GVT	2021-10-27 16:30:00	2021-10-27 17:30:00	Entretien avec un conseiller parlementaire et un général
17822	04042C	ORG_POL	2021-10-26 19:30:00	2021-10-26 21:30:00	Réunion publique des L.R dans le Val-de-Marne
17823	04042C	ACC_VISIT	2021-10-27 14:50:00	2021-10-27 15:00:00	Interview Public Sénat
17825	04042C	ACC_VISIT	2021-10-27 17:30:00	2021-10-27 18:00:00	Interview TV de Dubaï
17826	04042C	CEREMONIE	2021-10-27 18:30:00	2021-10-27 20:00:00	Remise des insignes d'Officier de l'Ordre des Arts et Métiers à une ancienne Ambassadrice de Suède en France
17827	04042C	COLL_TER	2021-10-28 09:00:00	2021-10-28 13:00:00	Colloque sur le programme de coopération internationale Solidarité Eau du Syndicat des Eaux d'Ile-de-France
17828	04042C	CEREMONIE	2021-10-28 18:00:00	2021-10-28 19:15:00	Cérémonie à l'occasion du bicentenaire de la refondation de l'Académie de marine
17829	04042C	REU_GVT	2021-10-28 19:45:00	2021-10-28 20:45:00	Entretien avec le Ministre de l'Europe et des Affaires étrangères
17830	04042C	REU_TRAV_PARL	2021-10-29 11:30:00	2021-10-29 20:30:00	Visite dans l'armée avec la Sénatrice d'Indre-et-Loire à Tours
17843	08010L	ORG_POL	2021-11-03 12:00:00	2021-11-03 13:30:00	Permanence X. BERTRAND
17876	04042C	ELUS_LOCAUX	2021-11-02 18:00:00	2021-11-02 18:30:00	Entretien téléphonique avec un élu du Val-de-Marne
17872	08010L	REU_TRAV_PARL	2021-11-09 09:30:00	2021-11-09 10:30:00	PLF 2022
17873	08010L	ORG_POL	2021-11-09 10:30:00	2021-11-09 12:30:00	Groupe LR du Sénat
17874	04042C	ORG_POL	2021-11-02 10:30:00	2021-11-02 12:30:00	Réunion de Groupe des Sénateurs L.R au Sénat
17875	04042C	ELUS_LOCAUX	2021-11-02 15:00:00	2021-11-02 16:00:00	Réunion avec des élus du Val-de-Marne
17877	04042C	ELUS_LOCAUX	2021-11-04 14:30:00	2021-11-04 16:30:00	Réunion avec des élus du Val-de-Marne
17881	04042C	ELUS_LOCAUX	2021-11-08 11:00:00	2021-11-08 12:00:00	Pose d'une première pierre dans le Val-de-Marne
17879	04042C	ELUS_LOCAUX	2021-11-05 09:30:00	2021-11-05 10:30:00	Rendez-Vous avec un élu du Val-de-Marne 
17880	04042C	ELUS_LOCAUX	2021-11-05 10:30:00	2021-11-05 11:30:00	Rendez-vous avec un élu du Val-de-Marne
17882	04042C	ELUS_LOCAUX	2021-11-08 13:00:00	2021-11-08 14:15:00	Rencontre avec des élus du Val-de-Marne
17883	04042C	ACC_DEPL_INTER	2021-11-08 16:15:00	2021-11-08 17:15:00	Entretien avec le Ministre de la défense Nationale de la République de Lituanie
17884	04042C	ELUS_LOCAUX	2021-11-08 19:00:00	2021-11-08 21:30:00	Rencontre avec des élus du Val-de-Marne à l'Assemblée nationale
17885	04042C	ORG_POL	2021-11-09 10:30:00	2021-11-09 12:30:00	Réunion de Groupe des Sénateurs L.R du Sénat
17886	04042C	REU_TRAV_PARL	2021-11-09 15:00:00	2021-11-09 16:00:00	Entretien avec le Président du Sénat et le Président du Conseil départemental du Val-de-Marne
17887	04042C	ACC_VISIT	2021-11-09 16:30:00	2021-11-09 17:30:00	Entretien avec une journaliste du Journal Le Monde
17888	04042C	ACC_DEPL_INTER	2021-11-09 17:40:00	2021-11-09 18:10:00	Entretien télephonique avec l'Ambassadrice de France en Italie
17113	04042C	REU_GVT	2021-06-16 16:30:00	2021-06-16 17:00:00	Entretien avec le Ministre de l'Europe et des Affaires étrangères
17114	04042C	ACC_VISIT	2021-06-18 14:30:00	2021-06-18 15:45:00	Intervention au 1er Forum Stratégique de l'IHEDN
17115	04042C	CEREMONIE	2021-06-18 18:30:00	2021-06-18 19:20:00	Ravivage de la Flamme sous l'Arc de Triomphe à l'occasion de la journée nationale commémorative de l'Appel historique du Général De Gaulle
17185	11103C	DEL_ACT_PAR	2021-07-01 10:00:00	2021-07-01 11:00:00	Prix de la mémoire et du civisme André Maginot à Gien
17481	04042C	CEREMONIE	2021-07-14 07:45:00	2021-07-14 08:30:00	Honneur militaire au Sénat
17482	04042C	CEREMONIE	2021-07-14 10:00:00	2021-07-14 12:00:00	Cérémonie du 14 juillet aux Champs-Elysées
17583	08010L	REU_TRAV_PARL	2021-09-14 11:00:00	2021-09-14 12:00:00	Institution judiciaire/avocats
17521	04042C	DEPL_PRES_GVT	2021-08-27 00:00:00	2021-08-27 00:00:00	Mission en Irak avec le Président de la République
17566	04042C	CEREMONIE	2021-09-07 20:00:00	2021-09-07 21:30:00	Cérémonie à l'occasion de la nomination du Commandant Suprême Allié de la Transformation à Norfolk
17724	11066Q	CEREMONIE	2021-07-14 10:00:00	2021-07-14 12:00:00	Cérémonie de la Fête nationale 
17584	08010L	ORG_POL	2021-09-14 12:00:00	2021-09-14 13:00:00	AFE
17719	01058X	REU_TRAV_PARL	2021-10-08 09:00:00	2021-10-08 10:30:00	Visite de l'école d'Andelot avec le Recteur d'Académie de Reims
17720	01058X	REU_TRAV_PARL	2021-10-15 10:00:00	2021-10-15 12:00:00	Rencontre avec les acteurs de la filière laitière FDPL
17729	11066Q	REU_TRAV_PARL	2021-07-20 10:00:00	2021-07-20 12:30:00	Réunion de groupe
17730	11066Q	ACC_VISIT	2021-07-20 14:30:00	2021-07-20 15:30:00	Entretien avec Mme Béatrice Guillaumin
17731	11066Q	REU_GVT	2021-07-20 16:15:00	2021-07-20 17:15:00	Entretien avec le conseiller interministériel en charge des restructurations d'entreprises et la conseillère de la Ministre déléguée chargée de l'Industrie sur MAN Energy Solutions
17739	11066Q	ACC_VISIT	2021-08-24 09:00:00	2021-08-24 17:00:00	Permanence
17740	08010L	COLLOQUE	2021-10-21 12:00:00	2021-10-21 14:00:00	Journée des Entreprises
17741	11066Q	ACC_VISIT	2021-08-24 11:00:00	2021-08-24 12:30:00	Visite du nouveau site d'Emmaüs Saint-Nazaire
17742	11066Q	ACC_VISIT	2021-08-25 09:00:00	2021-08-25 17:00:00	Permanence
17743	11066Q	ACC_VISIT	2021-08-25 12:30:00	2021-08-25 14:30:00	Rencontre avec la présidente de la fédération départementale du Secours Populaire Français et du président du SPF de Saint-Nazaire
17744	11066Q	ACC_VISIT	2021-08-27 09:00:00	2021-08-27 17:00:00	Permanence
17745	11066Q	ACC_VISIT	2021-08-30 09:00:00	2021-08-30 17:00:00	Permanence
17746	11066Q	ACC_VISIT	2021-09-02 09:00:00	2021-09-02 17:00:00	Permanence
17747	11066Q	ACC_VISIT	2021-09-03 09:00:00	2021-09-03 17:00:00	Permanence
17748	11066Q	ACC_VISIT	2021-09-06 09:00:00	2021-09-06 17:00:00	Permanence
17749	11066Q	ACC_VISIT	2021-09-07 09:00:00	2021-09-07 17:00:00	Permanence
17750	11066Q	COLL_TER	2021-09-07 18:00:00	2021-09-07 20:00:00	Soirée de rentrée de la CRENE autour du thème de la transition écologique: l'industrie nazairienne au coeur de l'innovation
17751	11066Q	ACC_VISIT	2021-09-10 09:00:00	2021-09-10 17:00:00	Permanence
17752	11066Q	ACC_VISIT	2021-09-13 09:00:00	2021-09-13 17:00:00	Permanence
17753	11066Q	REU_TRAV_PARL	2021-09-14 10:00:00	2021-09-14 12:30:00	Réunion de groupe
17754	11066Q	ACC_VISIT	2021-09-14 16:30:00	2021-09-14 17:30:00	Entretien avec l'association LINKEE suite à l'étude sur les ressorts de la précarité étudiante
17755	11066Q	ACC_VISIT	2021-09-16 09:00:00	2021-09-16 17:00:00	Permanence
17757	11066Q	REU_TRAV_PARL	2021-09-21 10:00:00	2021-09-21 12:30:00	Réunion de groupe
17759	11066Q	REU_TRAV_PARL	2021-09-23 15:30:00	2021-09-23 17:00:00	Présentation aux rapporteurs de la Commission des Affaires étrangères et de la Défense du budget de la Défense (PLF 2022) par Mme Françoise Parly Ministre des Armées
17760	11066Q	ACC_VISIT	2021-09-17 09:00:00	2021-09-17 17:00:00	Permanence
17805	11103C	ORG_POL	2021-10-26 11:00:00	2021-10-26 12:30:00	LR du Sénat 
17922	04042C	ORG_POL	2021-11-10 20:30:00	2021-11-10 23:00:00	Meeting Les Républicains
17921	04042C	ELUS_LOCAUX	2021-11-10 19:45:00	2021-11-10 20:30:00	Rendez-vous avec un élu du Val-de-Marne
17808	08010L	REU_TRAV_PARL	2021-10-21 17:00:00	2021-10-21 18:00:00	Justice/services judiciaires
17809	08010L	REU_TRAV_PARL	2021-10-28 12:00:00	2021-10-28 14:00:00	Bureau de la DCT
17923	04042C	CEREMONIE	2021-11-11 10:45:00	2021-11-11 12:30:00	Commémoration de l'Armistice du 11 novembre 1918 à Champigny-sur-Marne
17841	08010L	ORG_POL	2021-11-02 10:30:00	2021-11-02 11:30:00	Groupe LR du Sénat
17842	08010L	REU_TRAV_PARL	2021-11-02 11:30:00	2021-11-02 12:30:00	Com. des Finances / Justice
17847	01025N	REU_TRAV_PARL	2021-11-03 08:00:00	2021-11-03 09:30:00	audition FNSEA - PLF/PLFSS 2022
17848	01025N	REU_TRAV_PARL	2021-10-20 00:00:00	2021-10-20 00:00:00	audition MSA - PLF/PLFSS 2022
17849	01025N	REU_TRAV_PARL	2021-10-19 16:00:00	2021-10-19 18:30:00	préparation budgétaire
17850	01025N	ACC_VISIT	2021-10-14 11:00:00	2021-10-14 18:00:00	Accueil ANEV VITEFF - Epernay
17851	01025N	REU_TRAV_PARL	2021-10-12 12:30:00	2021-10-12 14:00:00	Bureau Relations internationales
17891	11103C	ORG_POL	2021-11-09 11:00:00	2021-11-09 12:30:00	LR du Sénat 
17924	04042C	CEREMONIE	2021-11-11 13:00:00	2021-11-11 15:00:00	Rencontre avec les Anciens combattants de Saint-Maurice
17893	08010L	REU_TRAV_PARL	2021-11-10 18:00:00	2021-11-10 19:00:00	DCT, Audition ADF
17894	08010L	REU_TRAV_PARL	2021-11-09 15:00:00	2021-11-09 16:00:00	DCT, Audition ANCT
17925	04042C	ACC_DEPL_INTER	2021-11-12 09:50:00	2021-11-12 11:00:00	Entretien avec le Président du sénat et le Ministre des Affaires étrangères de Palestine
17929	04042C	ELUS_LOCAUX	2021-11-15 11:00:00	2021-11-15 12:00:00	Pose de la 1ère pierre d'un immeuble à Saint-Maurice
17927	04042C	ACC_DEPL_INTER	2021-11-12 18:30:00	2021-11-12 19:30:00	Rencontre à l'occasion de la Fête nationale de l'indépendance de la Pologne 
17928	04042C	ORG_POL	2021-11-12 20:00:00	2021-11-12 22:30:00	Meeting Les Républicains
17933	04042C	REU_GVT	2021-11-15 17:30:00	2021-11-15 19:00:00	Réunion de travail au Ministère de l'Intérieur
17931	04042C	ACC_DEPL_INTER	2021-11-15 12:30:00	2021-11-15 13:15:00	Rencontre avec l'Ambassadeur de Belgique à l'occasion de la Fête du Roi
17932	04042C	ACC_DEPL_INTER	2021-11-15 13:30:00	2021-11-15 15:00:00	Rencontre avec l'Ambassadrice d'Arménie en France
17934	04042C	REU_TRAV_PARL	2021-11-16 08:00:00	2021-11-16 09:00:00	Réunion de travail avec le Président du Sénat et le Chef d'état-major des armées
17935	04042C	ORG_POL	2021-11-16 10:30:00	2021-11-16 12:30:00	Réunion de Groupe des sénateurs L.R du Sénat
17936	04042C	ACC_VISIT	2021-11-16 13:00:00	2021-11-16 14:15:00	Rencontre avec un élu du Val-de-Marne
17937	04042C	ACC_DEPL_INTER	2021-11-16 17:00:00	2021-11-16 18:00:00	Entretien avec l'Ambassadeur de la République tchèque en France
17938	04042C	ACC_DEPL_INTER	2021-11-16 19:00:00	2021-11-16 20:00:00	Rencontre à l'occasion de la fin de mission du Général de division de l'armée suisse
17939	04042C	ACC_DEPL_INTER	2021-11-17 12:00:00	2021-11-17 13:00:00	Entretien avec un sénateur égyptien
17940	04042C	ACC_VISIT	2021-11-17 13:00:00	2021-11-17 14:30:00	Rencontre avec des élus du Val-de-Marne
17941	04042C	REU_GVT	2021-11-17 17:00:00	2021-11-17 18:00:00	Réunion de travail à la Présidence de la République
17942	04042C	ELUS_LOCAUX	2021-11-18 11:30:00	2021-11-18 15:00:00	Rencontre avec des élus du Val-de-Marne
17943	04042C	ACC_DEPL_INTER	2021-11-18 19:00:00	2021-11-18 21:00:00	Rencontre avec l'Ambassadeur de Russie en France
17984	14133K	REU_TRAV_PARL	2021-09-08 14:30:00	2021-09-08 17:30:00	RDV individuels en permanence dans le département
17982	14133K	REU_TRAV_PARL	2021-09-06 10:00:00	2021-09-06 12:30:00	rdv individuels permanence parlementaire 14
17983	14133K	REU_TRAV_PARL	2021-09-06 14:30:00	2021-09-06 15:30:00	rdv individuels permanence parlementaire 14
17985	14133K	ELUS_LOCAUX	2021-09-09 12:00:00	2021-09-09 14:30:00	Déjeuner élus Vire Normandie
17986	14133K	REU_TRAV_PARL	2021-09-10 14:30:00	2021-09-10 16:30:00	Réunion Bureau AP-OSCE - visioconférence
18000	14133K	REU_TRAV_PARL	2021-09-22 13:00:00	2021-09-22 14:30:00	Déjeuner de travail - personnel diplomatique
18001	14133K	REU_TRAV_PARL	2021-09-23 12:30:00	2021-09-23 14:30:00	Déjeuner de travail - Loi de programmation militaire
18002	14133K	REU_TRAV_PARL	2021-09-23 15:30:00	2021-09-23 16:30:00	Présentation du budget de la Défense PLF 2022 par Madame Parly
18003	14133K	REU_TRAV_PARL	2021-09-24 09:30:00	2021-09-24 12:00:00	RDV individuels en permanence dans le département
18004	14133K	REU_TRAV_PARL	2021-09-24 16:30:00	2021-09-24 17:30:00	Rendez-vous sociaux et économiques permanence parlementaire dans le Calvados
17144	04042C	COLL_TER	2021-06-25 09:30:00	2021-06-25 14:00:00	Conseil de surveillance des Hôpitaux de Saint-Maurice
17145	04042C	REU_TRAV_PARL	2021-06-25 15:00:00	2021-06-25 17:00:00	Visisoconférence spéciale Les principaux résultats du sommet 2021 de l'OTAN
17146	04042C	ACC_DEPL_INTER	2021-06-25 18:45:00	2021-06-25 21:00:00	Entretien avec le Président du Sénat et son homologue polonais
17201	08010L	ORG_POL	2021-07-06 11:00:00	2021-07-06 12:30:00	Groupe LR du Sénat
17523	04042C	ACC_DEPL_INTER	2021-08-30 20:30:00	2021-08-30 22:30:00	Rencontre avec avec les Ambassadeurs de France en poste en Europe et la Ministre des armées sur le thème de l'Europe de la défense
17226	20024T	COLL_TER	2021-07-22 09:00:00	2021-07-22 12:00:00	Commission Permanente - Département de la Vienne
17227	11103C	ORG_POL	2021-07-06 11:00:00	2021-07-06 12:30:00	LR du Sénat
17228	08010L	REU_TRAV_PARL	2021-07-06 19:00:00	2021-07-06 20:00:00	\N
17342	11066Q	REU_TRAV_PARL	2021-04-05 11:30:00	2021-04-05 12:30:00	Réunion de groupe
17230	08010L	CEREMONIE	2021-07-07 11:00:00	2021-07-07 12:30:00	GIA France - Etats-Unis Lafayette 
17231	08010L	REU_TRAV_PARL	2021-07-07 12:30:00	2021-07-07 13:00:00	commission des financesx 
17343	11066Q	REU_TRAV_PARL	2021-04-06 10:00:00	2021-04-06 12:30:00	\N
17344	11066Q	ACC_VISIT	2021-04-02 09:00:00	2021-04-02 17:00:00	Permanence
17345	11066Q	ACC_VISIT	2021-04-09 09:00:00	2021-04-09 17:00:00	Permanence
17346	11066Q	ACC_VISIT	2021-03-29 09:00:00	2021-03-29 17:00:00	Permanence
17349	11066Q	ACC_VISIT	2021-04-19 09:00:00	2021-04-19 17:00:00	Permanence
17350	11066Q	REU_TRAV_PARL	2021-04-19 11:30:00	2021-04-19 12:30:00	Réunion de groupe
17366	11066Q	REU_TRAV_PARL	2021-05-18 10:30:00	2021-05-18 12:30:00	Réunion de groupe
17356	11066Q	ORGEXTPAR	2021-04-30 15:00:00	2021-04-30 16:30:00	Réunion plénière de la Commission Nationale de Contrôle des Techniques de Renseignement
17363	11066Q	REU_TRAV_PARL	2021-05-11 10:45:00	2021-05-11 12:30:00	Réunion de groupe
17373	11066Q	ACC_VISIT	2021-05-28 09:00:00	2021-05-28 17:00:00	Permanence
17374	11066Q	ACC_VISIT	2021-05-31 09:00:00	2021-05-31 17:00:00	Permanence
17375	11066Q	REU_TRAV_PARL	2021-05-31 11:30:00	2021-05-31 12:30:00	Réunion de groupe
17378	11066Q	ORGEXTPAR	2021-06-03 09:20:00	2021-06-03 11:30:00	Réunion plénière de la Commission Nationale de Contrôle des Techniques de Renseignement
17380	11066Q	ACC_VISIT	2021-06-07 09:00:00	2021-06-07 17:00:00	Permanence
17381	11066Q	REU_TRAV_PARL	2021-06-07 11:30:00	2021-06-07 12:30:00	Réunion de groupe
17385	11066Q	REU_TRAV_PARL	2021-06-09 14:30:00	2021-06-09 15:00:00	\N
17386	11066Q	REU_TRAV_PARL	2021-06-09 16:30:00	2021-06-09 17:30:00	\N
17387	11066Q	ACC_VISIT	2021-06-11 09:00:00	2021-06-11 17:00:00	Permanence
17388	11066Q	ACC_VISIT	2021-06-14 09:00:00	2021-06-14 17:00:00	Permanence
17389	11066Q	REU_TRAV_PARL	2021-06-14 11:30:00	2021-06-14 12:30:00	Réunion de groupe
17390	11066Q	REU_TRAV_PARL	2021-06-15 10:00:00	2021-06-15 12:30:00	Réunion de groupe
17391	11066Q	REU_TRAV_PARL	2021-06-15 16:00:00	2021-06-15 17:00:00	\N
17392	11066Q	REU_TRAV_PARL	2021-06-16 10:00:00	2021-06-16 11:00:00	Réunion avec Gérard Larcher dans le cadre de la CNCTR
17393	11066Q	REU_TRAV_PARL	2021-06-16 14:00:00	2021-06-16 15:00:00	Réunion de préparation de la discussion du projet de Loi relatif à la prévention du terrorisme et au renseignement
17394	11066Q	ACC_VISIT	2021-06-18 09:00:00	2021-06-18 17:00:00	Përmanence
17395	11066Q	CEREMONIE	2021-06-18 11:00:00	2021-06-18 12:00:00	Cérémonie de la Journée nationale commémorative de l'Appel du Général de Gaulle le 18 juin 1940 à Saint-Nazaire
17396	14133K	COLL_TER	2021-04-20 14:30:00	2021-04-20 18:00:00	Visite territoire Calvados - Vire
17397	11066Q	ACC_VISIT	2021-06-21 09:00:00	2021-06-21 17:00:00	Permanence
17398	11066Q	REU_TRAV_PARL	2021-06-21 11:30:00	2021-06-21 12:30:00	Réunion de groupe
17399	11066Q	REU_TRAV_PARL	2021-06-22 10:00:00	2021-06-22 12:30:00	Réunion de groupe
17400	14133K	COLL_TER	2021-04-29 15:00:00	2021-04-29 16:30:00	Dispositif régional aides aux clubs de haut niveau - Le Hom
17401	11066Q	REU_TRAV_PARL	2021-06-22 14:30:00	2021-06-22 15:00:00	Réunion de groupe
17432	14133K	ORG_POL	2021-03-16 11:00:00	2021-03-16 12:30:00	Réunion du Groupe LR Sénat
17433	14133K	COLL_TER	2021-03-15 09:30:00	2021-03-15 12:00:00	rdv permanence parlementaire
17434	14133K	ELUS_LOCAUX	2021-03-15 14:30:00	2021-03-15 15:30:00	rdv élus de Poussy-la-Campagne
17435	14133K	COLL_TER	2021-03-15 16:00:00	2021-03-15 17:00:00	rencontre avec les étudiants UNI de CAEN
17486	20024T	COLL_TER	2021-07-15 20:15:00	2021-07-15 23:00:00	Conseil Municipal de Monts-sur-Guesnes
17437	14133K	REU_TRAV_PARL	2021-03-22 19:30:00	2021-03-22 20:30:00	Audio conférence avec le Préfet du Calvados - suivi de la crise sanitaire
17438	14133K	REU_TRAV_PARL	2021-03-29 19:30:00	2021-03-29 20:30:00	Audio conférence avec le Préfet du Calvados - suivi de la crise sanitaire
17439	14133K	COLL_TER	2021-03-12 10:00:00	2021-03-12 11:30:00	visite industrielle - services de l'Etat - Condé-en-Normandie
17440	14133K	ORG_POL	2021-03-12 14:30:00	2021-03-12 15:30:00	rdv élus 14 - instances LR
17441	14133K	DEL_ACT_PAR	2021-03-11 13:00:00	2021-03-11 14:00:00	Réunion AP OSCE
17442	14133K	COLL_TER	2021-03-11 14:30:00	2021-03-11 18:00:00	Visite territoire Calvados - Balleroy
17443	14133K	COLL_TER	2021-03-11 10:00:00	2021-03-11 11:30:00	rdv permanence parlementaire
17444	14133K	ORG_POL	2021-03-09 11:00:00	2021-03-09 12:30:00	Réunion du Groupe LR Sénat
17445	14133K	DEL_ACT_PAR	2021-03-08 11:00:00	2021-03-08 12:30:00	AP-OSCE - visio conférence table ronde entre les pays riverains et la coopération culturelle de la région Méditerranéenne
17446	14133K	COLL_TER	2021-03-08 16:00:00	2021-03-08 17:00:00	rdv permanence parlementaire
17487	20024T	CEREMONIE	2021-07-14 12:00:00	2021-07-14 13:00:00	14 Juillet- Monts-sur-Guesnes
17488	20024T	CEREMONIE	2021-07-14 17:30:00	2021-07-14 18:00:00	14 Juillet - Chalais
17489	20024T	COLL_TER	2021-07-19 09:00:00	2021-07-19 11:00:00	Session d'ouverture - Département de la Vienne
17542	04042C	ACC_DEPL_INTER	2021-09-02 18:00:00	2021-09-02 20:00:00	Rencontre avec l'Ambassadeur du Pakistan en France
17456	14133K	REU_TRAV_PARL	2021-04-12 19:30:00	2021-04-12 20:30:00	Audio conférence avec le Préfet du Calvados - suivi de la crise sanitaire
17661	08010L	ORG_POL	2021-10-12 10:30:00	2021-10-12 13:00:00	Groupe LR du Sénat + XB
17543	04042C	REU_TRAV_PARL	2021-09-02 16:00:00	2021-09-02 17:15:00	Réunion de Direction
17544	04042C	ELUS_LOCAUX	2021-09-03 10:30:00	2021-09-03 12:00:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
17545	04042C	ACC_DEPL_INTER	2021-09-02 17:30:00	2021-09-02 17:45:00	Entretien téléphonique avec le Représentant du Gouvernement Régional du Kurdistan-Irak en France
17901	08010L	ORG_POL	2021-11-16 10:30:00	2021-11-16 12:00:00	Groupe LR du Sénat + V. Pécresse
17702	08010L	REU_TRAV_PARL	2021-10-19 17:00:00	2021-10-19 18:00:00	DCT Audition DGCL
17701	08010L	ORG_POL	2021-10-19 10:30:00	2021-10-19 12:30:00	Groupe LR du Sénat
17703	04042C	ELUS_LOCAUX	2021-10-15 13:00:00	2021-10-15 14:15:00	Rencontre avec des élus du Val-de-Marne
17704	04042C	COLL_TER	2021-10-15 14:30:00	2021-10-15 17:30:00	Conseil de la Métropole du Grand Paris
17705	04042C	ACC_VISIT	2021-10-15 18:00:00	2021-10-15 19:00:00	Interview Radio France
17961	14133K	DEPL_PRES_GVT	2021-08-18 11:00:00	2021-08-18 12:30:00	accueil dans le Calvados de M. A. Taquet, secrétaire d'Etat chargé de l'enfance - Cabourg
17962	14133K	CEREMONIE	2021-08-23 09:30:00	2021-08-23 12:30:00	Commémoration de la Libération - Pays d'Auge sud
17963	14133K	ELUS_LOCAUX	2021-08-23 13:00:00	2021-08-23 14:30:00	Déjeuner maire du Pays d'Auge
17964	14133K	ELUS_LOCAUX	2021-08-23 14:30:00	2021-08-23 15:30:00	RDV Maire de Blangy le Château
17965	14133K	COLL_TER	2021-08-23 16:00:00	2021-08-23 17:30:00	Visite économique - Livarot
17966	14133K	CEREMONIE	2021-08-23 18:30:00	2021-08-23 19:30:00	Commémoration de la Libération de Lisieux
17967	14133K	CEREMONIE	2021-08-24 10:00:00	2021-08-24 11:00:00	Commémoration de la Libération - Saint-Arnout-Touques
17968	14133K	CEREMONIE	2021-08-24 11:15:00	2021-08-24 12:00:00	Commémoration de la Libération - Trouville-sur-Mer
17969	14133K	ELUS_LOCAUX	2021-08-24 12:30:00	2021-08-24 14:00:00	Réunion avec les élus de Trouville sur Mer
17970	14133K	COLL_TER	2021-08-27 10:00:00	2021-08-27 12:00:00	Visite Mémorial britannique Ver-sur-Mer - Réunion avec le Souvenir Français
17974	14133K	COLL_TER	2021-08-30 14:30:00	2021-08-30 17:00:00	Visite de territoire - Pont d'Ouilly
17972	14133K	ELUS_LOCAUX	2021-08-27 14:00:00	2021-08-27 15:00:00	RdV avec M. le Maire de Ver-sur-Mer
17973	14133K	REU_TRAV_PARL	2021-08-30 10:00:00	2021-08-30 12:00:00	RDV individuels en permanence dans le département
17975	14133K	CEREMONIE	2021-08-30 17:15:00	2021-08-30 18:00:00	Cérémonie pour le départ d'une personnalité locale
17976	14133K	COLL_TER	2021-08-31 12:00:00	2021-08-31 14:30:00	Déjeuner Dirigeant Région Normandie
17977	14133K	ELUS_LOCAUX	2021-09-02 12:00:00	2021-09-02 14:00:00	Déjeuner élus régionaux
17171	01058X	REU_TRAV_PARL	2021-06-24 15:00:00	2021-06-24 18:00:00	CMP développement Solidaire
17172	01058X	ORG_POL	2021-06-15 11:00:00	2021-06-15 12:30:00	Réunion de Groupe Les Républicains au Sénat
17173	01058X	ORG_POL	2021-06-22 11:00:00	2021-06-22 12:30:00	Réunion de Groupe Les Républicains au Sénat
17174	01058X	REU_TRAV_PARL	2021-06-11 00:00:00	2021-06-11 00:00:00	Réunion Visio Dr Tedongmo CHHM / Mme Rousselle FO santé
17175	11103C	ORG_POL	2021-06-29 11:00:00	2021-06-29 12:30:00	LR du Sénat
17240	14133K	COLL_TER	2021-02-15 09:30:00	2021-02-15 11:30:00	rdv permanence parlementaire
17241	14133K	DEPL_PRES_GVT	2021-02-15 14:30:00	2021-02-15 17:30:00	Visite ministérielle - Madame Jacqueline Gourault - Saint-Pierre-en-Auge et Lisieux
17362	11066Q	REU_TRAV_PARL	2021-05-10 11:30:00	2021-05-10 12:30:00	Réunion de groupe
17242	14133K	COLL_TER	2021-02-15 19:00:00	2021-02-15 21:00:00	Visite Territoire - maraude Croix Rouge Caen
17243	14133K	CEREMONIE	2021-02-16 10:50:00	2021-02-16 11:30:00	Hommage aux militaires de la Gendarmerie Nationale décédés dans leurs fonctions en 2020 - CAEN
17244	14133K	ORG_POL	2021-02-17 08:30:00	2021-02-17 10:30:00	CNI Les Républicains - Paris
17245	14133K	REU_TRAV_PARL	2021-02-17 12:30:00	2021-02-17 13:00:00	rdv Groupe LR
17249	04042C	ACC_DEPL_INTER	2021-07-08 10:00:00	2021-07-08 11:00:00	Visioconférence avec le Président de la Commission des Affaires étrangères et européennes du Sénat de Pologne
17247	14133K	COLL_TER	2021-02-18 14:30:00	2021-02-18 17:30:00	Visite de territoire - Souleuvre-en-Bocage
17248	08010L	REU_TRAV_PARL	2021-07-08 12:15:00	2021-07-08 13:45:00	Bureau de la DCT
17250	04042C	ACC_VISIT	2021-07-08 11:30:00	2021-07-08 13:45:00	Rencontre avec des élus du Val-de-Marne
17251	04042C	REU_TRAV_PARL	2021-07-08 14:00:00	2021-07-08 15:00:00	Réunion de travail sur la Présidence Française de l'Union européenne
17252	04042C	ACC_DEPL_INTER	2021-07-08 16:00:00	2021-07-08 17:00:00	Entretien avec la chargée d'affaire en pied de la République bolivarienne du Vénézuela en France
17253	04042C	ACC_VISIT	2021-07-08 17:00:00	2021-07-08 17:30:00	Entretien téléphonque avec un rédacteur en chef adjoint
17254	04042C	ELUS_LOCAUX	2021-07-08 20:00:00	2021-07-08 21:30:00	Séance solennelle du Conseil municipal de Maisons-Alfort
17484	08010L	ORG_POL	2021-07-20 11:00:00	2021-07-20 12:00:00	Groupe LR du Sénat
17565	08010L	ORG_POL	2021-09-07 11:00:00	2021-09-07 13:00:00	Groupe LR du Sénat
17568	08010L	REU_TRAV_PARL	2021-09-09 10:00:00	2021-09-09 12:30:00	CA de la FedEPL
17569	04042C	REU_TRAV_PARL	2021-09-08 16:30:00	2021-09-08 17:30:00	entretien avec un Conseiller diplomatique
17570	04042C	ACC_DEPL_INTER	2021-09-08 18:30:00	2021-09-08 20:00:00	Rencontre avec le Général de Brigade aérienne de l'Ambassade Britannique en France
17571	04042C	ELUS_LOCAUX	2021-09-09 13:00:00	2021-09-09 14:15:00	Rencontre avec un élu du Val-de-Marne
17572	04042C	REU_TRAV_PARL	2021-09-09 16:00:00	2021-09-09 17:00:00	Réunion de Direction
17590	04042C	ELUS_LOCAUX	2021-09-16 08:00:00	2021-09-16 09:00:00	Réunion avec des élus du Val-de-Marne
17621	11103C	ORG_POL	2021-09-28 11:00:00	2021-09-28 12:30:00	LR du Sénat 
17706	04042C	ACC_DEPL_INTER	2021-10-18 00:00:00	2021-10-18 00:00:00	Mission en Pologne avec une délégation de sénateurs français à l'invistation du Président de la Commission des Affaires étrangères polonais
17707	04042C	ACC_DEPL_INTER	2021-10-19 00:00:00	2021-10-19 19:00:00	Mission en Pologne avec une délégation de sénateurs français à l'invistation du Président de la Commission des Affaires étrangères polonais
17708	04042C	ACC_DEPL_INTER	2021-10-20 13:00:00	2021-10-20 14:15:00	Rencontre avec l'Ambassadeur d'Iran en France
17709	04042C	ACC_VISIT	2021-10-20 14:55:00	2021-10-20 15:00:00	Interview Public Sénat
17710	01058X	ORG_POL	2021-09-21 11:00:00	2021-09-21 12:30:00	Réunion de Groupe Les Républicains au Sénat
17711	01058X	ORG_POL	2021-09-28 11:00:00	2021-09-28 12:30:00	Réunion de Groupe Les Républicains au Sénat
17712	01058X	ORG_POL	2021-10-05 10:30:00	2021-10-05 12:30:00	Réunion de Groupe Les Républicains au Sénat
17713	01058X	ORG_POL	2021-10-12 10:30:00	2021-10-12 12:30:00	Réunion de Groupe Les Républicains au Sénat
17714	01058X	DEPL_PRES_GVT	2021-10-18 08:00:00	2021-10-18 20:00:00	 Visite en Pologne d¿une délégation  de la commission des Affaires étrangères, de la Défense et des Forces armées du Sénat
17715	01058X	DEPL_PRES_GVT	2021-10-19 08:00:00	2021-10-19 16:00:00	 Visite en Pologne d¿une délégation  de la commission des Affaires étrangères, de la Défense et des Forces armées du Sénat 
17716	01058X	ORG_POL	2021-09-16 08:00:00	2021-09-16 19:00:00	Séminaire Groupe LR Sénat
17717	01058X	ORG_POL	2021-09-17 08:00:00	2021-09-17 18:00:00	Séminaire Groupe LR Sénat
17718	01058X	CEREMONIE	2021-09-10 14:30:00	2021-09-10 16:00:00	Inauguration EHPAD de Manois
17776	11066Q	ORGEXTPAR	2021-10-14 09:00:00	2021-10-14 10:30:00	Réunion plénière de la Commission Nationale de Contrôle des Techniques de Renseignement
17845	08010L	DEPL_PRES_GVT	2021-11-04 09:30:00	2021-11-04 12:30:00	Ministre DARMANIN Chézy sur Marne
17846	08010L	REU_TRAV_PARL	2021-11-04 14:30:00	2021-11-04 16:30:00	Collaborateurs
17852	01025N	ACC_DEPL_INTER	2021-09-30 08:30:00	2021-09-30 10:30:00	GIA France-Ukraine
17861	11066Q	ACC_VISIT	2021-10-22 09:00:00	2021-10-22 17:00:00	Permanence
17862	11066Q	ACC_VISIT	2021-10-25 09:00:00	2021-10-25 17:00:00	Permanence
17863	11066Q	ACC_VISIT	2021-10-26 09:00:00	2021-10-26 17:00:00	Permanence
17864	11066Q	ACC_VISIT	2021-10-28 09:00:00	2021-10-28 17:00:00	Permanence
17865	11066Q	ACC_VISIT	2021-10-29 09:00:00	2021-10-29 17:00:00	Permanence
17866	11066Q	ORGEXTPAR	2021-11-04 14:30:00	2021-11-04 16:00:00	Réunion plénière de la Commission Nationale de Contrôle des Techniques de Renseignement
17867	11066Q	ACC_VISIT	2021-11-05 09:00:00	2021-11-05 17:00:00	Permanence
17868	11066Q	ACC_VISIT	2021-11-05 15:00:00	2021-11-05 16:00:00	Entretien avec les associations du Comité d'Orientation stratégique de l'étude de zone de la CARENE
17869	11066Q	ELUS_LOCAUX	2021-11-08 10:30:00	2021-11-08 11:30:00	Rencontre avec le Maire d'Asserac concernant l'invasion d'algues vertes sur les plages. 
17870	11066Q	COLL_TER	2021-11-08 14:00:00	2021-11-08 16:00:00	Réunion du Comité d'Orientation stratégique de l'Étude de zone de la CARENE
17871	11066Q	ACC_VISIT	2021-11-08 16:00:00	2021-11-08 17:00:00	Permanence
17978	14133K	ELUS_LOCAUX	2021-09-02 14:30:00	2021-09-02 16:30:00	Visite de territoire - Soignolles
17979	14133K	REU_TRAV_PARL	2021-09-02 17:00:00	2021-09-02 18:30:00	Réunion avec le DDSP 14 - Caen
17980	14133K	ORG_POL	2021-09-02 19:00:00	2021-09-02 20:00:00	Réunion Bureau LR14 - CAEN
17987	14133K	REU_TRAV_PARL	2021-09-13 09:30:00	2021-09-13 10:30:00	RDV individuels en permanence dans le département
17988	14133K	REU_TRAV_PARL	2021-09-13 11:15:00	2021-09-13 12:00:00	Visite de rentrée - Collège
17989	14133K	REU_TRAV_PARL	2021-09-13 14:00:00	2021-09-13 15:00:00	Visite de rentrée - lycée
17990	14133K	REU_TRAV_PARL	2021-09-13 15:30:00	2021-09-13 17:30:00	Visite territoire Calvados - entreprise Condé/N.
17991	14133K	ELUS_LOCAUX	2021-09-14 12:00:00	2021-09-14 15:00:00	Réunion élus départementaux - Pays d'Auge
17992	14133K	ELUS_LOCAUX	2021-09-15 10:30:00	2021-09-15 12:00:00	Réunion avec élus Vire-Normandie - Roullours
17993	14133K	REU_TRAV_PARL	2021-09-15 12:30:00	2021-09-15 16:00:00	Visite économique - hippodrome Vire Normandie
17994	14133K	ELUS_LOCAUX	2021-09-15 16:30:00	2021-09-15 18:00:00	Réunion de travail - maire de Campagnolles
17995	14133K	REU_TRAV_PARL	2021-09-16 12:30:00	2021-09-16 20:30:00	Rentrée - journées parlementaires Groupe LR Sénat - Vannes
17996	14133K	REU_TRAV_PARL	2021-09-17 09:30:00	2021-09-17 18:30:00	Rentrée - journées parlementaires Groupe LR Sénat - Vannes
17997	14133K	REU_TRAV_PARL	2021-09-21 12:00:00	2021-09-21 14:30:00	rdv presse - Bessin
18007	14133K	ORG_POL	2021-09-28 11:00:00	2021-09-28 12:30:00	Réunion du Groupe LR Sénat
17999	14133K	COLL_TER	2021-09-21 15:00:00	2021-09-21 16:30:00	60e anniversaire du Cimetière militaire allemand de La Cambe
18005	14133K	ELUS_LOCAUX	2021-09-27 09:00:00	2021-09-27 14:30:00	Assemblée générale de l'Union amicale des maires du Calvados
18006	14133K	REU_TRAV_PARL	2021-09-27 16:00:00	2021-09-27 17:00:00	Rdv presse régionale
18008	14133K	REU_TRAV_PARL	2021-09-28 13:00:00	2021-09-28 14:30:00	Rencontres pour l'Innovation
18009	14133K	REU_TRAV_PARL	2021-09-29 08:30:00	2021-09-29 09:30:00	Réunion du Bureau de la Commission des Affaires étrangères
18010	14133K	REU_TRAV_PARL	2021-09-30 00:00:00	2021-09-30 00:00:00	Petit-déjeuner débat sur la Chine - Yacht Club de France
18011	14133K	DEPL_PRES_GVT	2021-09-30 14:30:00	2021-09-30 16:30:00	Accueil à Caen de Mme G. Darrieussecq - visite de l'ONACVG
18012	14133K	REU_TRAV_PARL	2021-10-01 11:30:00	2021-10-01 15:30:00	Réunion artistes plasticiens normands
17177	04086Q	DEL_ACT_PAR	2021-06-18 09:00:00	2021-06-18 10:00:00	Intervention école, classe de CM1 aux Pavillions-sous-bois
17186	04042C	REU_TRAV_PARL	2021-06-30 16:30:00	2021-06-30 17:00:00	Entretien avec un Général et un Colonel
17187	04042C	ACC_DEPL_INTER	2021-06-30 17:30:00	2021-06-30 18:30:00	Rencontre avec l'Ambassadeur du Portugal en France
17188	04042C	COLL_TER	2021-07-01 10:00:00	2021-07-01 12:00:00	Séance d'installation du Conseil départemental du Val-de-Marne
17189	04042C	COLL_TER	2021-07-02 08:45:00	2021-07-02 11:30:00	Réunion du Bureau du Syndicat d'Ile-de-France
17190	04042C	COLL_TER	2021-07-02 12:30:00	2021-07-02 13:00:00	Entretien téléphonique avec la Directrice académique du Val-de-Marne
17191	04042C	ELUS_LOCAUX	2021-06-30 19:00:00	2021-06-30 21:00:00	Conseil municipal de Saint-Maurice
17263	14133K	COLL_TER	2021-07-08 11:15:00	2021-07-08 12:15:00	rdv responsables territoriaux Calvados
17265	14133K	COLL_TER	2021-07-09 09:15:00	2021-07-09 10:15:00	rdv responsables territoriaux - sécurité
17264	14133K	ELUS_LOCAUX	2021-07-08 14:30:00	2021-07-08 18:00:00	Visite territoire Calvados - Verson
17266	14133K	ELUS_LOCAUX	2021-07-09 16:15:00	2021-07-09 17:15:00	rdv maire du Calvados
17271	14133K	ELUS_LOCAUX	2021-07-02 10:00:00	2021-07-02 12:30:00	réunion avec les élus de St-Martin-de-Bienfaite-La Cressonnière
17268	14133K	REU_TRAV_PARL	2021-07-06 09:30:00	2021-07-06 20:30:00	session annuelle AP OSCE - Vienne
17269	14133K	REU_TRAV_PARL	2021-07-05 09:30:00	2021-07-05 20:30:00	session annuelle AP OSCE - Vienne
17270	14133K	COLL_TER	2021-07-02 14:30:00	2021-07-02 18:00:00	Visite territoire Calvados - Valorbiquet
17272	14133K	ELUS_LOCAUX	2021-07-02 12:45:00	2021-07-02 14:15:00	rdv avec élus du canton de Livarot
17282	14133K	ORG_POL	2021-06-23 14:30:00	2021-06-23 21:00:00	Elections régionales Normandie
17283	14133K	COLL_TER	2021-06-18 09:30:00	2021-06-18 12:30:00	Visite territoire Calvados - Bayeux
17284	14133K	ORG_POL	2021-06-17 18:30:00	2021-06-17 21:00:00	Elections régionales Normandie
17295	14133K	CEREMONIE	2021-06-07 17:30:00	2021-06-07 18:00:00	Hommage personnel aux victimes civiles du 6 juin 1944 à Condé-en-Normandie
17292	14133K	ELUS_LOCAUX	2021-06-11 14:30:00	2021-06-11 17:00:00	Conférence des parlementaires - UAMC 14
17293	14133K	REU_TRAV_PARL	2021-06-11 17:15:00	2021-06-11 18:30:00	Réunion de groupe PPE - AP OSCE
17294	14133K	COLL_TER	2021-06-07 14:30:00	2021-06-07 16:30:00	Visite territoire Calvados - entreprise Clécy
17296	14133K	ELUS_LOCAUX	2021-06-04 14:00:00	2021-06-04 16:00:00	Réunion commission DETR - Préfecture du Calvados
17297	14133K	ORG_POL	2021-06-01 10:30:00	2021-06-01 12:30:00	Réunion du Groupe LR Sénat
17298	14133K	COLL_TER	2021-05-31 10:00:00	2021-05-31 11:00:00	rdv permanence parlementaire
17299	14133K	REU_TRAV_PARL	2021-05-31 12:30:00	2021-05-31 14:00:00	rdv services de l'Etat - Calvados
17300	14133K	COLL_TER	2021-05-31 16:00:00	2021-05-31 17:00:00	rdv permanence parlementaire
17301	14133K	COLL_TER	2021-05-28 14:30:00	2021-05-28 15:30:00	Opération de promotion industrielle - PME entreprise Calvados-Manche
17302	14133K	COLL_TER	2021-05-28 09:30:00	2021-05-28 11:30:00	rdv permanence parlementaire
17303	14133K	COLL_TER	2021-05-27 14:30:00	2021-05-27 17:30:00	Visite territoire Calvados - Potigny
17304	14133K	ORG_POL	2021-05-25 11:00:00	2021-05-25 12:30:00	Réunion du Groupe LR Sénat
17305	14133K	COLL_TER	2021-05-21 09:15:00	2021-05-21 10:00:00	rdv permanence parlementaire
17306	14133K	ELUS_LOCAUX	2021-05-21 11:30:00	2021-05-21 12:30:00	rdv élus de Vauville-en-Auge
17307	14133K	COLL_TER	2021-05-21 14:30:00	2021-05-21 17:30:00	Visite territoire Calvados - Vauville-St-Pierre-Azif
17308	14133K	ORG_POL	2021-05-21 18:45:00	2021-05-21 20:30:00	Elections régionales Normandie
17309	14133K	ORG_POL	2021-05-18 11:00:00	2021-05-18 12:30:00	Réunion du Groupe LR Sénat
17310	14133K	REU_TRAV_PARL	2021-05-18 12:30:00	2021-05-18 14:00:00	Réunion sénateurs LR
17311	14133K	REU_TRAV_PARL	2021-05-18 18:15:00	2021-05-18 19:30:00	Rdv thématique économique et juridique
17312	14133K	COLL_TER	2021-05-17 14:30:00	2021-05-17 18:00:00	Visite territoire Calvados - Villers-Bocage
17313	14133K	ORG_POL	2021-05-11 11:00:00	2021-05-11 12:30:00	Réunion du Groupe LR Sénat
17314	14133K	CEREMONIE	2021-05-10 09:30:00	2021-05-10 10:30:00	Journée nationale des mémoires de la traite, de l'esclavage et de leurs abolitions - Bayeux
17315	14133K	COLL_TER	2021-05-10 11:30:00	2021-05-10 12:30:00	rdv permanence parlementaire
17316	14133K	COLL_TER	2021-05-10 17:00:00	2021-05-10 18:00:00	rdv permanence parlementaire
17317	14133K	COLL_TER	2021-05-07 09:30:00	2021-05-07 10:30:00	Inauguration Itinéraire chevauchée du Pays d'Auge à la Seine - Orbec
17318	14133K	COLL_TER	2021-05-07 11:30:00	2021-05-07 12:30:00	Inauguration Centre de Santé de Lisieux
17319	14133K	ELUS_LOCAUX	2021-05-07 14:00:00	2021-05-07 15:00:00	Rdv maire Ouilly-du-Houlley
17320	14133K	COLL_TER	2021-05-06 14:00:00	2021-05-06 16:30:00	Rendez-vous sociaux et économiques permanence parlementaire dans le Calvados
17321	14133K	ORG_POL	2021-05-04 11:00:00	2021-05-04 12:30:00	Réunion du Groupe LR Sénat
17322	14133K	REU_TRAV_PARL	2021-05-04 13:00:00	2021-05-04 14:00:00	Réunion sénateurs LR
17323	14133K	ORG_POL	2021-05-04 18:30:00	2021-05-04 20:00:00	CNI Les Républicains - Paris
17324	14133K	ORG_POL	2021-05-03 14:00:00	2021-05-03 15:30:00	CNI Les Républicains - Paris
17341	11066Q	REU_TRAV_PARL	2021-07-05 11:30:00	2021-07-05 12:30:00	Réunion de groupe
17347	11066Q	ACC_VISIT	2021-04-12 09:00:00	2021-04-12 17:00:00	Permanence
17348	11066Q	ACC_VISIT	2021-04-16 09:00:00	2021-04-16 17:00:00	Permanence
17351	11066Q	ACC_VISIT	2021-04-26 09:00:00	2021-04-26 17:00:00	Permanence
17352	11066Q	REU_TRAV_PARL	2021-04-26 11:30:00	2021-04-26 12:30:00	Réunion de groupe
17359	11066Q	REU_TRAV_PARL	2021-05-04 10:00:00	2021-05-04 12:30:00	\N
17354	11066Q	COLL_TER	2021-04-28 15:00:00	2021-04-28 17:30:00	Comité d'Orientation stratégique de suivi de l'étude de zone sur le secteur de la CARENE
17357	11066Q	ACC_VISIT	2021-05-03 09:00:00	2021-05-03 17:00:00	Permanence
17358	11066Q	REU_TRAV_PARL	2021-05-03 11:30:00	2021-05-03 12:30:00	Réunion de groupe
17360	11066Q	ACC_VISIT	2021-05-07 09:00:00	2021-05-07 17:00:00	Permanence
17361	11066Q	ACC_VISIT	2021-05-10 09:00:00	2021-05-10 17:00:00	Permanence
17364	11066Q	ACC_VISIT	2021-05-17 09:00:00	2021-05-17 17:00:00	Permanence
17365	11066Q	REU_TRAV_PARL	2021-05-17 11:30:00	2021-05-17 12:30:00	Réunion de groupe
17367	11066Q	ACC_VISIT	2021-05-21 09:00:00	2021-05-21 17:00:00	Permanence
17368	11066Q	CEREMONIE	2021-05-21 10:30:00	2021-05-21 11:30:00	Cérémonie du 173ème anniversaire de l'abolition de l'esclavage et de la traite négrière, et du 20ème anniversaire de la Loi Taubira
17369	11066Q	ACC_VISIT	2021-05-21 14:30:00	2021-05-21 15:30:00	Entretien avec le collectif Stop aux cancers de nos enfants
17370	11066Q	REU_TRAV_PARL	2021-05-25 10:00:00	2021-05-25 12:30:00	Réunion de groupe
17371	11066Q	ORGEXTPAR	2021-05-25 14:20:00	2021-05-25 16:00:00	Entretien au siège de la CNCTR
17372	11066Q	ORGEXTPAR	2021-05-25 16:30:00	2021-05-25 17:30:00	Réunion plénière de la Commission Nationale de Contrôle des Techniques de Renseignement
17376	11066Q	REU_TRAV_PARL	2021-06-01 10:00:00	2021-06-01 12:30:00	Réunion de groupe
17377	11066Q	REU_TRAV_PARL	2021-06-01 16:00:00	2021-06-01 17:00:00	Entretien à propos du projet de loi relative à la prévention du terrorisme et au renseignement
17379	11066Q	ACC_VISIT	2021-06-04 09:00:00	2021-06-04 17:00:00	Permanence
17382	11066Q	REU_TRAV_PARL	2021-06-08 10:00:00	2021-06-08 12:30:00	Réunion de groupe
17383	11066Q	REU_TRAV_PARL	2021-06-09 09:30:00	2021-06-09 10:00:00	\N
17404	14133K	ELUS_LOCAUX	2021-04-28 15:30:00	2021-04-28 16:30:00	Signature convention petites villes de demain - Pré Bocage Intercom
17402	14133K	ORG_POL	2021-04-29 18:00:00	2021-04-29 20:00:00	Réunion du groupe PPE - AP-OSCE - Visioconférence
17403	11066Q	ACC_VISIT	2021-06-25 09:00:00	2021-06-25 17:00:00	Permanence
17405	11066Q	ACC_VISIT	2021-06-28 09:00:00	2021-06-28 17:00:00	Permanence
17406	14133K	ELUS_LOCAUX	2021-04-28 16:30:00	2021-04-28 17:00:00	Inauguration Maison France Services - Les Monts d'Aunay
17407	11066Q	REU_TRAV_PARL	2021-06-28 11:30:00	2021-06-28 12:30:00	Réunion de groupe
17408	14133K	ORG_POL	2021-04-27 10:00:00	2021-04-27 12:30:00	Commission Nationale d'Investiture Les Républicains
17409	14133K	COLL_TER	2021-04-26 17:00:00	2021-04-26 18:30:00	rdv permanence parlementaire
17410	14133K	ORG_POL	2021-04-13 11:00:00	2021-04-13 12:30:00	Réunion du Groupe LR Sénat
17411	14133K	COLL_TER	2021-04-12 14:00:00	2021-04-12 18:00:00	Visite de territoire - Asnelles-Douvres
17412	14133K	COLL_TER	2021-04-08 15:00:00	2021-04-08 17:00:00	Visite terrain - DDSP Calvados
17413	11066Q	REU_TRAV_PARL	2021-06-29 10:00:00	2021-06-29 12:30:00	Réunion de groupe
17414	11066Q	ACC_VISIT	2021-07-02 09:00:00	2021-07-02 17:00:00	Permanence
17415	11066Q	ACC_VISIT	2021-07-05 09:00:00	2021-07-05 17:00:00	Permanence
17121	04042C	ACC_VISIT	2021-06-21 17:00:00	2021-06-21 17:30:00	Interview téléphonique France Inter
17122	08010L	ORG_POL	2021-06-22 11:00:00	2021-06-22 13:00:00	Groupe LR du Sénat
17123	08010L	REU_TRAV_PARL	2021-06-22 15:00:00	2021-06-22 16:00:00	PJL 4D
17124	04042C	REU_TRAV_PARL	2021-06-22 08:30:00	2021-06-22 09:30:00	Réunion de travail sur la Loi de programmation militaire avec le Président du Sénat
17125	04042C	REU_TRAV_PARL	2021-06-22 10:00:00	2021-06-22 11:00:00	Réunion de Direction
17126	04042C	ORG_POL	2021-06-22 11:00:00	2021-06-22 12:30:00	Réunion de Groupe des Sénateurs L.R du Sénat
17127	04042C	ACC_VISIT	2021-06-22 12:30:00	2021-06-22 12:45:00	Interview Public Sénat
17128	04042C	ACC_VISIT	2021-06-22 15:30:00	2021-06-22 16:30:00	Entretien avec un journaliste
17129	04042C	REU_GVT	2021-06-22 20:30:00	2021-06-22 22:30:00	Réunion de travail avec le Ministre de l'Europe et des Affaires étrangères
17161	08010L	REU_TRAV_PARL	2021-06-29 09:00:00	2021-06-29 10:00:00	PLFR 2021
17162	08010L	ORG_POL	2021-06-29 11:00:00	2021-06-29 13:00:00	Groupe LR du Sénat
17163	04042C	REU_TRAV_PARL	2021-06-28 13:00:00	2021-06-28 13:30:00	Entretien téléphonique avec le Président d'Airbus Helicopters
17164	04042C	ORG_POL	2021-06-29 11:00:00	2021-06-29 12:00:00	Réunion de Groupe des Sénateurs L.R du sénat
17165	04042C	REU_TRAV_PARL	2021-06-29 13:00:00	2021-06-29 14:15:00	Rencontre avec des Sénateurs
17166	04042C	REU_TRAV_PARL	2021-06-29 15:30:00	2021-06-29 16:00:00	Entretien avec des Sénateurs
17167	04042C	ACC_DEPL_INTER	2021-06-29 16:00:00	2021-06-29 17:00:00	Entretien avec l'Ambassadeur du Royaume du Maroc en France
17168	04042C	ELUS_LOCAUX	2021-06-29 18:00:00	2021-06-29 18:45:00	Rencontre avec des élus
17169	04042C	COLL_TER	2021-06-29 19:00:00	2021-06-29 21:00:00	Conseil de territoire
17170	04042C	COLL_TER	2021-06-28 18:30:00	2021-06-28 20:00:00	Commission urbanisme, aménagement, habitat et politique
17176	04086Q	REU_TRAV_PARL	2021-06-01 12:30:00	2021-06-01 14:00:00	Réunion de travail avec Bruno Retailleau
17273	14133K	ORG_POL	2021-06-29 11:00:00	2021-06-29 12:30:00	Réunion du Groupe LR Sénat
17274	14133K	REU_TRAV_PARL	2021-06-29 13:00:00	2021-06-29 14:30:00	réunion du Bureau de la Commission des affaires étrangères
17275	14133K	REU_TRAV_PARL	2021-06-29 15:00:00	2021-06-29 16:30:00	Conseil d'administration Expertise France
17276	14133K	COLL_TER	2021-06-28 09:15:00	2021-06-28 11:15:00	RDV permanence parlementaire  : citoyens et services de l'Etat
17277	14133K	COLL_TER	2021-06-28 14:30:00	2021-06-28 17:30:00	rdv permanence parlementaire : citoyens et associations
17278	14133K	ORG_POL	2021-06-28 18:30:00	2021-06-28 20:00:00	réunion Groupe PPE - AP-OSCE
17279	14133K	ORG_POL	2021-06-25 10:00:00	2021-06-25 12:30:00	Elections régionales Normandie
17280	14133K	COLL_TER	2021-06-25 16:00:00	2021-06-25 18:00:00	rdv permanence parlementaire
17281	14133K	REU_TRAV_PARL	2021-06-24 15:00:00	2021-06-24 18:30:00	Commission Mixte Paritaire - Projet de loi de programmation relatif au développement solidaire et à la lutte contre les inégalités mondiales
17285	14133K	ORG_POL	2021-06-16 13:00:00	2021-06-16 14:00:00	Réunion sénateurs LR
17286	14133K	ORG_POL	2021-06-15 11:00:00	2021-06-15 12:30:00	Réunion du Groupe LR Sénat
17287	14133K	CEREMONIE	2021-06-14 09:30:00	2021-06-14 10:30:00	Fidélité Gaulliste - Courseulles-sur-Mer
17288	14133K	REU_TRAV_PARL	2021-06-14 11:00:00	2021-06-14 12:00:00	Rdv local services de l'Etat
17289	14133K	CEREMONIE	2021-06-14 14:00:00	2021-06-14 16:30:00	Hommage au Général de Gaulle - Bayeux
17290	14133K	ELUS_LOCAUX	2021-06-14 16:45:00	2021-06-14 17:30:00	Rdv élus - Asnelles
17416	14133K	REU_TRAV_PARL	2021-03-30 11:00:00	2021-03-30 12:30:00	Réunion du Groupe LR Sénat
17417	14133K	COLL_TER	2021-03-29 09:30:00	2021-03-29 12:00:00	rdv permanence parlementaire
17418	14133K	COLL_TER	2021-03-29 14:30:00	2021-03-29 16:30:00	rdv permanence parlementaire
17419	11066Q	REU_TRAV_PARL	2021-07-09 09:30:00	2021-07-09 10:15:00	Commission mixte paritaire sur le Projet de loi relatif à la prévention des actes de terrorisme et au renseignement
17420	11066Q	ACC_VISIT	2021-07-09 15:30:00	2021-07-09 17:00:00	Permanence
17422	14133K	COLL_TER	2021-03-26 09:30:00	2021-03-26 12:30:00	Visite territoire Calvados - Dozulé
17423	14133K	COLL_TER	2021-03-26 14:30:00	2021-03-26 17:30:00	Visite territoire Calvados - Merville-Franceville
17424	14133K	ORG_POL	2021-03-24 09:30:00	2021-03-24 12:00:00	Commission Nationale d'Investiture Les Républicains
17425	14133K	ORG_POL	2021-03-23 11:00:00	2021-03-23 12:30:00	Réunion du Groupe LR Sénat
17426	14133K	CEREMONIE	2021-03-19 09:30:00	2021-03-19 10:15:00	Cérémonie commémorative 19 mars 1962 - Condé-en-Normandie
17427	14133K	CEREMONIE	2021-03-19 11:30:00	2021-03-19 12:15:00	Cérémonie commémorative 19 mars 1962 - Caen
17428	14133K	COLL_TER	2021-03-19 13:30:00	2021-03-19 17:30:00	Visite territoire Calvados - Le Molay-Littry
17429	14133K	COLL_TER	2021-03-18 14:00:00	2021-03-18 17:30:00	rdv permanence parlementaire
17430	14133K	ORG_POL	2021-03-17 09:30:00	2021-03-17 11:00:00	Commission Nationale d'Investiture Les Républicains
17431	14133K	ORG_POL	2021-03-17 12:00:00	2021-03-17 12:30:00	Rdv sénateur LR
17450	14133K	COLL_TER	2021-02-26 09:30:00	2021-02-26 12:30:00	Visite territoire Calvados - Saint Martin de Fontenay
17451	14133K	COLL_TER	2021-02-25 09:30:00	2021-02-25 10:30:00	rdv permanence parlementaire
17452	14133K	COLL_TER	2021-02-23 10:00:00	2021-02-23 11:30:00	rdv permanence parlementaire
17453	14133K	COLL_TER	2021-02-23 14:00:00	2021-02-23 18:00:00	Visite territoire Calvados - Thue et Mue
17459	04042C	COLL_TER	2021-07-12 12:30:00	2021-07-12 13:30:00	Réunion de travail du Syndicat des Eaux d'Ile-de-France
17457	04042C	ACC_DEPL_INTER	2021-07-09 16:00:00	2021-07-09 17:00:00	Entretien avec l'Ambassadeur de Malte en France
17461	04042C	ELUS_LOCAUX	2021-07-13 10:15:00	2021-07-13 10:45:00	Entretien avec un élu
17460	04042C	ACC_DEPL_INTER	2021-07-13 08:30:00	2021-07-13 09:30:00	entretien avec l'Ambassadeur du Royaume-Uni en France
17462	04042C	CEREMONIE	2021-07-13 11:00:00	2021-07-13 12:45:00	Cérémonie militaire - prise d'armes de la Légion étrangère présidée par le Président du Sénat
17463	04042C	ACC_DEPL_INTER	2021-07-13 13:15:00	2021-07-13 14:30:00	Rencontre avec l'Ambassadeur de Belgique en France
17464	04042C	ACC_DEPL_INTER	2021-07-13 16:00:00	2021-07-13 17:00:00	Entretien avec l'Ambassadeur du Liban en France
17465	04042C	CEREMONIE	2021-07-13 18:30:00	2021-07-13 19:30:00	Rencontre en l'honneur des unités participant aux cérémonies de la Fête nationale avec la Ministre des armées
17466	08010L	ORG_POL	2021-07-13 11:00:00	2021-07-13 13:00:00	Groupe LR du Sénat
17485	08010L	CEREMONIE	2021-07-20 19:00:00	2021-07-20 21:00:00	GIA France-Maroc
17501	04042C	CEREMONIE	2021-08-26 19:30:00	2021-08-26 20:30:00	Commémoration du 77ème anniversaire de la libération de Bry-sur-Marne
17644	04042C	DEPL_PRES_GVT	2021-10-01 14:45:00	2021-10-01 00:00:00	Déplacement à Dubaï avec le Minsitre de l'Europe et des Affaires étrangères
17602	08010L	ORG_POL	2021-09-21 11:00:00	2021-09-21 12:30:00	Groupe LR du Sénat
17588	08010L	ORG_POL	2021-09-16 10:00:00	2021-09-16 17:00:00	Séminaire sénateurs LR
17589	08010L	REU_TRAV_PARL	2021-09-16 17:00:00	2021-09-16 19:00:00	CEVIPOF
17603	08010L	REU_TRAV_PARL	2021-09-21 13:00:00	2021-09-21 14:30:00	Fédération du bâtiment 
17641	08010L	ORG_POL	2021-10-05 10:30:00	2021-10-05 13:00:00	Groupe LR du Sénat 
17645	04042C	ELUS_LOCAUX	2021-10-04 10:00:00	2021-10-04 11:45:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
17646	04042C	REU_TRAV_PARL	2021-10-04 12:30:00	2021-10-04 14:30:00	Rencontre avec le Chef d'état-major de l'armée de l'air et de l'espace
17650	04042C	ACC_VISIT	2021-10-05 13:00:00	2021-10-05 14:15:00	Rencontre avec des élus du Val-de-Marne
17648	04042C	REU_TRAV_PARL	2021-10-05 10:00:00	2021-10-05 11:30:00	Réunion de travail avec le Chef d'état-major de la marine
17649	04042C	ORG_POL	2021-10-05 11:45:00	2021-10-05 12:30:00	Réunion de Groupe des Sénateurs L.R du Sénat
17651	04042C	COLL_TER	2021-10-05 19:00:00	2021-10-05 21:00:00	Conseil de Territoire
17652	04042C	ACC_DEPL_INTER	2021-10-06 19:00:00	2021-10-06 20:30:00	Rencontre avec l'Ambassadeur d'Allemagne en France à l'occasion de la journée de l'unité allemande
17653	04042C	ACC_VISIT	2021-10-06 14:45:00	2021-10-06 15:00:00	Visite guidée du Conseil municipal des Jeunes de Périgny-sur-Yerres
17654	04042C	ACC_DEPL_INTER	2021-10-07 16:00:00	2021-10-07 17:15:00	Entretien avec le Minsitre de la Défense de la République slovaque
17655	04042C	ACC_VISIT	2021-10-07 17:30:00	2021-10-07 18:30:00	Entretien avec un élu du Val-de-Marne
17681	04042C	CEREMONIE	2021-10-11 17:30:00	2021-10-11 18:15:00	Dédicace du livre du Président Nicolas Sarkozy
18049	08010L	REU_TRAV_PARL	2021-11-24 17:00:00	2021-11-24 18:00:00	DCT Risque inondation
18050	08010L	REU_TRAV_PARL	2021-11-24 18:00:00	2021-11-24 19:00:00	DCT Risque sismique
18063	04042C	ACC_DEPL_INTER	2021-11-25 12:00:00	2021-11-25 13:00:00	Entretien avec le Président du sénat et le Président du Bundesrat
18052	04042C	ACC_DEPL_INTER	2021-11-24 09:50:00	2021-11-24 11:00:00	Entretien avec le Président du Sénat et les Présidents de Parlement des Pays Baltes
18053	04042C	REU_TRAV_PARL	2021-11-24 13:00:00	2021-11-24 14:15:00	Rencontre avec les Présidents des Commissions, Référents de Commission, et Rapporteur général du Sénat
18054	04042C	ACC_VISIT	2021-11-24 14:00:00	2021-11-24 15:00:00	Visite guidée du Conseil Municipal des Enfants d'une commune du Val-de-Marne
18055	04042C	REU_GVT	2021-11-24 16:15:00	2021-11-24 16:45:00	Entretien avec la Ministre déléguée auprès de la ministre des Armées, chargée de la Mémoire et des Anciens combattants
18056	04042C	ACC_DEPL_INTER	2021-11-24 16:45:00	2021-11-24 17:45:00	Entretien avec une délégation de Députés libyens
18057	04042C	CEREMONIE	2021-11-24 18:30:00	2021-11-24 19:30:00	Cérémonie en l'honneur du du Commandant militaire du Palais du Luxembourg
18058	04042C	ACC_DEPL_INTER	2021-11-25 11:00:00	2021-11-25 11:45:00	Entretien avec le Représentant du Gouvernement régional du Kurdistan
18059	04042C	ACC_VISIT	2021-11-19 12:00:00	2021-11-19 14:00:00	Rencontre avec des élus du Val-de-Marne
18272	01058X	REU_TRAV_PARL	2021-11-15 15:15:00	2021-11-15 16:00:00	ADMR de Haute-Marne
18061	04042C	ACC_DEPL_INTER	2021-11-22 19:00:00	2021-11-22 20:00:00	Entretien avec le Président du Sénat et le Président du Parlement d'Arménie
18062	04042C	ACC_DEPL_INTER	2021-11-22 20:00:00	2021-11-22 22:00:00	Dîner de travail avec le Président du Sénat et le Président du Parlement d'Arménie
18064	04042C	ACC_DEPL_INTER	2021-11-25 13:00:00	2021-11-25 14:30:00	Déjeuner de travail avec le Président du Sénat et le Président du Bundesrat
18065	04042C	ACC_DEPL_INTER	2021-11-25 15:00:00	2021-11-25 16:00:00	Entretien avec le Président de la Commission de la Défense et Sécurité du Conseil National de Slovaquie
18066	04042C	ACC_DEPL_INTER	2021-11-25 16:00:00	2021-11-25 17:00:00	Entretien avec l'Ambassadrice d'Iraël en France et la Présidente du GIA Israël-France à la Knesset
18067	04042C	ACC_DEPL_INTER	2021-11-25 17:30:00	2021-11-25 18:30:00	Entretien avec le Nonce apostolique du Saint-Siège en France
18068	04042C	ACC_DEPL_INTER	2021-11-25 18:30:00	2021-11-25 19:30:00	Rencontre avec l'Ambassadrice de l'Etat des Emirats Arabes Unis en France à l'occasion du 50ème anniversaire de l'Etat des Emirats Arabes Unis
18069	04042C	CEREMONIE	2021-11-25 19:30:00	2021-11-25 20:30:00	Rencontre annuelle avec les juges consulaires et les auxiliaires de justice
18129	08010L	REU_TRAV_PARL	2021-12-08 17:30:00	2021-12-08 18:30:00	CMP catastrophes naturelles 
18271	01058X	REU_TRAV_PARL	2021-11-29 17:30:00	2021-11-29 18:30:00	Visio Préfet : Situation sanitaire dans le département
18273	11103C	REU_TRAV_PARL	2022-01-18 17:00:00	2022-01-18 18:00:00	Rv ANCGE
18315	04042C	ORG_POL	2022-01-26 18:00:00	2022-01-26 19:00:00	Réunion avec la Présidente de la Région d'Ile-de-France
18316	04042C	ACC_DEPL_INTER	2022-01-27 10:00:00	2022-01-27 11:00:00	Entretien avec le Ministre des Affaires étrangères de la R.I. d'Afghanistan
18317	04042C	ACC_DEPL_INTER	2022-01-27 11:00:00	2022-01-27 12:00:00	Entretien avec l'Ambassadrice d'Israël en France
18318	04042C	REU_TRAV_PARL	2022-01-27 12:00:00	2022-01-27 13:00:00	Réunion de Direction
18319	04042C	COLL_TER	2022-01-28 15:30:00	2022-01-28 16:30:00	Réunion avec la Préfète du Val-de-Marne
18378	11066Q	ACC_VISIT	2021-12-13 09:00:00	2021-12-13 17:00:00	Accueil Permanence
18379	11066Q	REU_TRAV_PARL	2021-12-13 11:30:00	2021-12-13 12:30:00	Réunion de groupe CAED
18380	11066Q	ACC_VISIT	2021-12-16 09:00:00	2021-12-16 17:00:00	Permanence
18381	11066Q	ACC_VISIT	2021-12-16 10:30:00	2021-12-16 11:45:00	Visite EHPAD de Trignac
18382	11066Q	ACC_VISIT	2021-12-17 09:00:00	2021-12-17 17:00:00	Permanence
18390	11066Q	REU_TRAV_PARL	2022-01-04 10:30:00	2022-01-04 12:30:00	Réunion de groupe
18384	11066Q	ACC_VISIT	2022-01-03 09:00:00	2022-01-03 17:00:00	Permanence
18385	11066Q	REU_TRAV_PARL	2022-01-03 11:30:00	2022-01-03 12:30:00	Réunion de groupe CAED
18396	11066Q	ACC_VISIT	2022-01-24 09:00:00	2022-01-24 17:00:00	Accueil Permanence
18397	11066Q	ACC_VISIT	2022-01-17 09:00:00	2022-01-17 17:00:00	Accueil Permanence
18398	11066Q	REU_TRAV_PARL	2022-01-17 11:30:00	2022-01-17 12:30:00	Réunion de groupe CAED
18399	11066Q	REU_TRAV_PARL	2022-01-18 10:30:00	2022-01-18 13:00:00	Réunion de groupe
18400	11066Q	ACC_VISIT	2022-01-20 14:00:00	2022-01-20 17:00:00	Accueil Permanence
18401	11066Q	ACC_VISIT	2022-01-21 09:00:00	2022-01-21 17:00:00	Accueil Permanence
18402	11066Q	REU_TRAV_PARL	2022-01-24 11:30:00	2022-01-24 12:30:00	Réunion de groupe CAED
18405	11066Q	ACC_VISIT	2022-01-31 09:00:00	2022-01-31 17:00:00	Accueil Permanence
18408	11066Q	REU_TRAV_PARL	2022-02-01 11:00:00	2022-02-01 12:30:00	Réunion de groupe
18409	11066Q	REU_TRAV_PARL	2022-02-01 18:00:00	2022-02-01 19:00:00	Réunion de groupe
18415	11066Q	ACC_VISIT	2022-02-04 14:30:00	2022-02-04 15:30:00	Entretien avec les représentantes du projet pour l'accompagnement de la fin de vie sur Saint-Nazaire
18416	11066Q	ACC_VISIT	2022-02-07 09:00:00	2022-02-07 17:00:00	Accueil Permanence
18417	11066Q	REU_TRAV_PARL	2022-02-07 11:30:00	2022-02-07 12:30:00	Réunion de groupe CAED
18418	11066Q	REU_TRAV_PARL	2022-02-08 11:00:00	2022-02-08 12:30:00	Réunion de groupe
18419	11066Q	REU_TRAV_PARL	2022-02-09 13:00:00	2022-02-09 14:15:00	Rencontre du groupe avec le Président du Sénat
18420	11066Q	ACC_VISIT	2022-02-09 14:30:00	2022-02-09 15:00:00	Accueil visiteurs Sénat
18421	04042C	ACC_VISIT	2022-02-07 07:15:00	2022-02-07 08:00:00	Emission Bonjour Chez Vous de Public Sénat
18502	14133K	ORG_POL	2021-12-06 08:00:00	2021-12-06 08:30:00	Matinale France Bleu Normandie
18503	14133K	REU_TRAV_PARL	2021-12-06 15:30:00	2021-12-06 16:30:00	rdv permanence parlementaire
18504	14133K	ORG_POL	2021-12-03 20:00:00	2021-12-03 21:00:00	Bureau LR 14
18505	14133K	ORG_POL	2021-11-30 11:00:00	2021-11-30 12:30:00	Réunion du Groupe LR Sénat
18506	14133K	REU_TRAV_PARL	2021-11-26 14:30:00	2021-11-26 16:00:00	rdv permanence parlementaire
18507	14133K	CEREMONIE	2021-11-25 16:00:00	2021-11-25 17:30:00	Cérémonie de la Sainte-Geneviève-Gendarmerie du Calvados-Caen
18513	14133K	REU_TRAV_PARL	2021-11-16 14:00:00	2021-11-16 16:30:00	Visite de l'ONERA-Palaiseau
18512	14133K	ORG_POL	2021-11-16 17:30:00	2021-11-16 19:00:00	CNI Les Républicains - Paris
18510	14133K	ORG_POL	2021-11-16 11:00:00	2021-11-16 12:30:00	Réunion du Groupe LR Sénat
18514	14133K	REU_TRAV_PARL	2021-11-19 09:30:00	2021-11-19 12:00:00	rdv permanence parlementaire
18515	04042C	ELUS_LOCAUX	2022-02-11 19:00:00	2022-02-11 21:30:00	Visite du palais du Luxembourg d'un Conseil municipal du Val-de-Marne
18516	04042C	REU_TRAV_PARL	2022-02-10 15:00:00	2022-02-10 17:00:00	Entretien avec des auditeurs du Centre des Hautes Etudes Militaires
18517	04042C	ACC_DEPL_INTER	2022-02-14 10:30:00	2022-02-14 11:30:00	Entretien avec le Ministre de la Défense de Corée
18524	04042C	COLL_TER	2022-02-15 14:30:00	2022-02-15 17:30:00	Conseil de la Métropole du Grand Paris
18519	04042C	CEREMONIE	2022-02-14 15:00:00	2022-02-14 16:00:00	Cérémonie de signature du Plan Ambition Logement au Ministère des Armées
18520	04042C	ACC_VISIT	2022-02-14 18:45:00	2022-02-14 19:00:00	Interview d'un journaliste de La Lettre A
18521	04042C	ACC_DEPL_INTER	2022-02-14 20:00:00	2022-02-14 22:00:00	Entretien avec l'Ambassadeur de la République Tunisienne en France
18522	04042C	ACC_DEPL_INTER	2022-02-14 12:00:00	2022-02-14 13:00:00	Visite de courtoisie du nouvel Ambassadeur de Cuba en France
18523	04042C	ELUS_LOCAUX	2022-02-15 19:00:00	2022-02-15 21:30:00	Visite du palais du Luxembourg d'un Conseil municipal du Val-de-Marne
18525	04042C	ELUS_LOCAUX	2022-02-15 18:15:00	2022-02-15 19:00:00	Entretien avec un élu du Val-de-Marne
18526	04042C	ELUS_LOCAUX	2022-02-16 19:30:00	2022-02-16 21:30:00	Conseil municipal de Saint-Maurice
18527	04042C	ACC_DEPL_INTER	2022-02-16 13:00:00	2022-02-16 14:15:00	Rencontre avec le Représentant régionale du Kurdistan-Irak et le Président de la Commission des Affaires étrangères de l'Assemblée nationale
18528	04042C	REU_GVT	2022-02-16 16:15:00	2022-02-16 16:30:00	Entretien avec le Président du Sénat et le Premier ministre
18641	04042C	CEREMONIE	2022-03-11 15:15:00	2022-03-11 17:00:00	Cérémonie à l¿occasion de la journée nationale d¿hommage aux victimes du terrorisme
18643	04042C	CEREMONIE	2022-03-14 09:30:00	2022-03-14 11:00:00	Allocution du chef d¿état-major des Armées à l'occasion du sémaire du SIGEM
18013	14133K	REU_TRAV_PARL	2021-10-04 10:00:00	2021-10-04 12:30:00	RDV individuels en permanence dans le département
18017	14133K	REU_TRAV_PARL	2021-10-07 14:30:00	2021-10-07 16:30:00	visite territoire - vie associative - Condé-en-Normandie
18015	14133K	REU_TRAV_PARL	2021-10-05 12:00:00	2021-10-05 14:00:00	déjeuner de travail - PPR Birmanie
18030	14133K	ORG_POL	2021-10-19 11:00:00	2021-10-19 12:30:00	Réunion du Groupe LR Sénat
18018	14133K	COLL_TER	2021-10-07 18:00:00	2021-10-07 19:30:00	Vernissage exposition Myanmar - Prix Bayeux 2021
18031	14133K	REU_TRAV_PARL	2021-10-20 13:00:00	2021-10-20 15:00:00	Déjeuner de travail - Ambassade Turquie
18032	14133K	ORG_POL	2021-10-21 19:30:00	2021-10-21 22:00:00	réunion comité LR 6e circonscription du Calvados
18033	14133K	COLL_TER	2021-11-05 14:30:00	2021-11-05 16:00:00	Réunion commission DETR - Préfecture du Calvados
18034	14133K	REU_TRAV_PARL	2021-11-08 10:00:00	2021-11-08 11:30:00	visite rentrée collège - enseignement privé
18035	14133K	REU_TRAV_PARL	2021-11-08 11:30:00	2021-11-08 12:30:00	rdv individuel permanence parlementaire
18036	14133K	REU_TRAV_PARL	2021-11-08 14:15:00	2021-11-08 15:00:00	rdv presse régionale
18037	14133K	REU_TRAV_PARL	2021-11-08 15:45:00	2021-11-08 17:30:00	Rendez-vous sociaux et économiques permanence parlementaire dans le Calvados
18221	08010L	REU_TRAV_PARL	2022-01-04 11:00:00	2022-01-04 12:30:00	Groupe LR - Sénat
18222	08010L	ORGEXTPAR	2022-01-05 11:00:00	2022-01-05 12:30:00	Réunion visio Chambre nationale commissaires justice (CNCJ)
18361	01058X	ORG_POL	2022-01-25 11:00:00	2022-01-25 12:30:00	Réunion de Groupe Les Républicains au Sénat
18224	08010L	REU_TRAV_PARL	2022-01-06 00:00:00	2022-01-06 00:00:00	Délégation collectivités territoriales - Auditions Min Intérieur, ATOS et Syndicat Seine Yvelines
18362	01058X	ORG_POL	2022-02-01 10:30:00	2022-02-01 13:00:00	Réunion de Groupe Les Républicains au Sénat
18363	01058X	ORG_POL	2022-02-08 11:00:00	2022-02-08 13:00:00	Réunion de Groupe Les Républicains au Sénat
18364	01058X	REU_TRAV_PARL	2022-02-08 09:30:00	2022-02-08 11:00:00	OPECST : Projet PNGMDR 
18365	08010L	COLL_TER	2022-01-10 13:00:00	2022-01-10 14:00:00	Appel téléphonique Directeur académique Aisne
18366	08010L	ELUS_LOCAUX	2022-01-10 14:30:00	2022-01-10 16:30:00	Réunion Maires sur PPL Matériel agricole
18367	08010L	COLL_TER	2022-01-10 18:00:00	2022-01-10 20:00:00	Réunion commandant de gendarmerie Aisne
18368	08010L	ELUS_LOCAUX	2022-01-14 14:00:00	2022-01-14 16:00:00	Rencontre maires de l'AIsne
18369	08010L	COLL_TER	2022-01-17 14:00:00	2022-01-17 16:00:00	2e réunion groupement de gendarmerie
18370	08010L	ELUS_LOCAUX	2022-01-17 18:00:00	2022-01-17 19:00:00	Réunion sur inondations Sud de l'Aisne
18371	08010L	ORG_POL	2022-01-18 11:00:00	2022-01-18 12:30:00	Groupe LR - Sénat
18422	04042C	COLL_TER	2022-02-07 11:30:00	2022-02-07 14:30:00	Rencontre avec le Président du Groupe Valophis pour la présentation des réalisations et des projets
18423	04042C	ELUS_LOCAUX	2022-02-07 15:15:00	2022-02-07 17:30:00	Visite de terrain avec le Maire de Champigny-sur-Marne concernant les projets de logements
18424	04042C	COLL_TER	2022-02-07 19:00:00	2022-02-07 21:00:00	Réunion du Conseil de Territoire
18425	04042C	ORG_POL	2022-02-08 11:00:00	2022-02-08 12:00:00	Réunion de Groupe des Sénateurs LR du sénat
18426	04042C	CEREMONIE	2022-02-08 12:15:00	2022-02-08 13:00:00	Inauguration de l'exposition Traversées d'Europe sur les grilles du jardin du Luxembourg aux côtés du Président du Sénat
18430	04042C	ACC_DEPL_INTER	2022-02-08 20:15:00	2022-02-08 22:15:00	Dîner officiel du Conseil des Organisations Arméniennes de France
18428	04042C	ACC_VISIT	2022-02-08 13:15:00	2022-02-08 14:15:00	Rencontre avec un élu du Val-de-Marne
18429	04042C	ELUS_LOCAUX	2022-02-08 18:45:00	2022-02-08 19:45:00	Pose de la 1ère pierre du commissariat de police de Maisons-Alfort et signature de la convention à la construction du nouveau commissariat
18431	04042C	ACC_DEPL_INTER	2022-02-09 13:00:00	2022-02-09 14:15:00	Rencontre avec l'Ambassadeur de Corée et France et des Sénateurs de la Commission des Affaires étrangères, de la Défense et des Forces armées
18432	04042C	ACC_VISIT	2022-02-09 16:30:00	2022-02-09 17:00:00	Entretien avec la Présidente de l'Institut Français
18433	04042C	REU_TRAV_PARL	2022-02-09 17:00:00	2022-02-09 18:00:00	Réunion de direction
18434	04042C	ACC_VISIT	2022-02-09 19:00:00	2022-02-09 21:30:00	Visite du palais du Luxembourg d'un Conseil municipal du Val-de-Marne
18435	04042C	ACC_VISIT	2022-02-10 13:00:00	2022-02-10 14:15:00	Rencontre avec des élus du Val-de-Marne
18436	04042C	COLL_TER	2022-02-11 08:45:00	2022-02-11 11:00:00	Réunion du bureau du Syndicat des Eaux d'Ile-de-France
18437	04042C	REU_TRAV_PARL	2022-02-11 11:00:00	2022-02-11 12:00:00	Remise du Rapport du Haut Comité d'Evaluation de la Condition Militaire par son Président
18441	11103C	ORG_POL	2022-02-15 11:00:00	2022-02-15 12:30:00	LR du Sénat
18541	04042C	ACC_DEPL_INTER	2022-02-21 11:30:00	2022-02-21 12:30:00	Entretien avec l'Ambassadrice d'Israël en France
18542	04042C	ELUS_LOCAUX	2022-02-21 13:00:00	2022-02-21 14:45:00	rencontre avec un Député européen
18543	04042C	ACC_VISIT	2022-02-21 14:30:00	2022-02-21 14:50:00	Interview téléphonique Public Sénat
18544	04042C	REU_TRAV_PARL	2022-02-21 15:00:00	2022-02-21 15:30:00	Entretien avec le Commandant militaire du palais du Luxembourg
18545	04042C	ACC_VISIT	2022-02-21 15:30:00	2022-02-21 16:30:00	Entretien avec un élu du Val-de-Marne
18644	04042C	ACC_VISIT	2022-03-15 10:00:00	2022-03-15 11:00:00	 Secrétaire Général et Vice-Président de la Fondation Lyautey
18645	04042C	ACC_VISIT	2022-03-15 07:00:00	2022-03-15 07:30:00	Emission de la matinale de rfi Direct
18646	04042C	ORG_POL	2022-03-15 11:00:00	2022-03-15 13:00:00	Réunion de Groupe des Sénateurs LR du sénat
18647	04042C	ORG_POL	2022-03-15 13:00:00	2022-03-15 14:30:00	Rencontre des Sénateurs Les Républicains
18705	11066Q	ACC_VISIT	2022-02-11 09:00:00	2022-02-11 17:00:00	Accueil Permanence
18717	11066Q	ACC_VISIT	2022-03-04 09:00:00	2022-03-04 17:00:00	Accueil Permanence
18724	11066Q	ACC_VISIT	2022-03-07 09:00:00	2022-03-07 15:00:00	Accueil Permanence
18708	11066Q	ACC_VISIT	2022-02-21 09:00:00	2022-02-21 17:00:00	Accueil Permanence
18709	11066Q	REU_TRAV_PARL	2022-02-22 11:00:00	2022-02-22 12:00:00	Réunion de groupe
18710	11066Q	REU_TRAV_PARL	2022-02-22 16:00:00	2022-02-22 17:30:00	Entretien de préparation DPR
18711	11066Q	ACC_VISIT	2022-02-23 12:30:00	2022-02-23 15:00:00	Accueil de la Présidente de la Fédération de Loire-Atlantique du Secours Populaire et du Président de la section de Saint-Nazaire du Secours Populaire
18716	11066Q	ORGEXTPAR	2022-03-03 09:00:00	2022-03-03 11:30:00	CNCTR
18731	11066Q	ACC_VISIT	2022-03-15 10:30:00	2022-03-15 12:00:00	Visite de la Maison d'arrêt de Nantes
18732	11066Q	ACC_VISIT	2022-03-15 14:30:00	2022-03-15 15:30:00	Visite des atelier du centre de détention de Nantes
18740	04042C	ACC_VISIT	2022-03-23 18:00:00	2022-03-23 18:40:00	Emission Public Sénat
18741	04042C	REU_TRAV_PARL	2022-03-24 08:15:00	2022-03-24 09:15:00	Entretien avec le Chef d'état-major des Armées
18742	04042C	COLL_TER	2022-03-24 09:30:00	2022-03-24 11:30:00	Réunion du Syndicat des Eaux d'Ile-de-France
18743	11103C	ORGEXTPAR	2022-03-22 09:00:00	2022-03-22 12:00:00	AG Fédération nationale des chasseurs
18744	04042C	ELUS_LOCAUX	2022-03-24 13:00:00	2022-03-24 14:30:00	Rencontre avec un élu du Val-de-Marne
18745	11066Q	REU_TRAV_PARL	2022-03-02 09:00:00	2022-03-02 17:00:00	Préparation réunion CNCTR
18746	11066Q	ACC_VISIT	2022-03-11 09:00:00	2022-03-11 17:00:00	Accueil permanence
18747	11066Q	ACC_VISIT	2022-02-28 09:00:00	2022-02-28 17:00:00	Accueil Permanence et visite sur le Département
18748	11066Q	ACC_VISIT	2022-03-08 09:00:00	2022-03-08 17:00:00	Accueil Permanence et visite sur le Département
18749	11066Q	ACC_VISIT	2022-03-09 09:00:00	2022-03-09 17:00:00	Accueil Permanence et visite sur le Département
18750	11066Q	ACC_VISIT	2022-03-10 09:00:00	2022-03-10 17:00:00	Accueil Permanence et visite sur le Département
18751	11066Q	ACC_VISIT	2022-03-14 09:00:00	2022-03-14 17:00:00	Accueil Permanence et visite sur le Département
18752	11066Q	ACC_VISIT	2022-03-17 09:00:00	2022-03-17 17:00:00	Accueil Permanence et visite sur le Département
18753	11066Q	ACC_VISIT	2022-03-18 09:00:00	2022-03-18 17:00:00	Accueil Permanence et visite sur le Département
19084	04042C	ELUS_LOCAUX	2022-06-02 13:00:00	2022-06-02 14:30:00	Rencontre avec un élu du Val-de-Marne
18754	04042C	ACC_DEPL_INTER	2022-03-24 15:00:00	2022-03-24 16:00:00	Entretien avec une délégation conduite par le Premier vice-ministre des Relations extérieures de la République de Cuba
18755	11066Q	ACC_VISIT	2022-03-21 09:00:00	2022-03-21 17:00:00	Accueil Permanence et visite sur le Département
18756	04042C	ACC_VISIT	2022-03-24 16:00:00	2022-03-24 16:15:00	Entretien téléphonique avec un journaliste de Valeurs actuelles
18081	08010L	REU_TRAV_PARL	2021-11-30 10:30:00	2021-11-30 11:45:00	Groupe LR du Sénat
18263	01058X	ORG_POL	2022-01-11 11:00:00	2022-01-11 13:00:00	Réunion de Groupe Les Républicains au Sénat
18083	08010L	CEREMONIE	2021-11-30 16:00:00	2021-11-30 19:30:00	Panthéonisation BAKER
18084	01058X	DEPL_PRES_GVT	2021-11-24 08:00:00	2021-11-24 18:00:00	 Déplacement à Stockholm avec l'OPECST pour un rapport sur le PNGMDR
18085	01058X	DEPL_PRES_GVT	2021-11-25 08:00:00	2021-11-25 19:00:00	Déplacement à Stockholm avec l'OPECST pour un rapport sur le PNGMDR
18086	01058X	DEPL_PRES_GVT	2021-11-26 08:00:00	2021-11-26 18:00:00	Déplacement à Stockholm avec l'OPECST pour un rapport sur le PNGMDR
18087	01058X	ORG_POL	2021-11-02 10:30:00	2021-11-02 12:30:00	Réunion de Groupe Les Républicains au Sénat
18088	01058X	CEREMONIE	2021-11-09 00:00:00	2021-11-09 00:00:00	Cérémonie Colombey-les-Deux-Eglises
18089	01058X	ORG_POL	2021-11-16 00:00:00	2021-11-16 00:00:00	Réunion de Groupe Les Républicains au Sénat
18090	01058X	ORG_POL	2021-11-23 10:30:00	2021-11-23 12:30:00	Réunion de Groupe Les Républicains au Sénat
18091	01058X	REU_TRAV_PARL	2021-11-15 14:30:00	2021-11-15 15:15:00	Général Laurent Gérin Ecole de gendarmerie
18261	01058X	ORG_POL	2021-12-14 11:00:00	2021-12-14 13:00:00	Réunion de Groupe Les Républicains au Sénat
18262	01058X	ORG_POL	2022-01-04 11:00:00	2022-01-04 13:00:00	Réunion de Groupe Les Républicains au Sénat
18264	01058X	ORG_POL	2022-01-18 11:00:00	2022-01-18 13:00:00	Réunion de Groupe Les Républicains au Sénat
18265	01058X	REU_TRAV_PARL	2022-01-18 14:30:00	2022-01-18 17:00:00	OPECST : Projet PNGMDR ; Audition CNE2 
18266	01058X	REU_TRAV_PARL	2022-01-17 14:30:00	2022-01-17 15:30:00	Réunion avec le Colonel LUZET
18267	01058X	REU_TRAV_PARL	2022-01-17 00:00:00	2022-01-17 00:00:00	Réunion avec le Commissaire GARNIER
18268	01058X	CEREMONIE	2021-12-17 11:00:00	2021-12-17 12:30:00	Cérémonie honorariat M. JACOTIN Michel, commune de Vicq
18269	01058X	REU_TRAV_PARL	2021-12-13 10:30:00	2021-12-13 12:00:00	Visioconférence avec l'ARS : situation Covid 19, Ségur de la santé
18270	01058X	REU_TRAV_PARL	2021-12-13 14:30:00	2021-12-13 16:00:00	Conférence santé Centre et Sud Haute-Marne
18587	04042C	ORG_POL	2022-02-22 11:00:00	2022-02-22 12:30:00	Réunion de Groupe des Sénateurs LR du sénat
18588	04042C	ACC_VISIT	2022-02-22 18:45:00	2022-02-22 19:30:00	Emission Public Sénat
18589	04042C	ELUS_LOCAUX	2022-02-22 20:00:00	2022-02-22 22:00:00	Rencontre des Mécènes et du comité de soutien du Monument national dans le Val-de-Marne
18590	04042C	ACC_DEPL_INTER	2022-02-23 11:30:00	2022-02-23 12:30:00	Entretien avec le Ministre des Affaires étrangères de Chypre
18591	04042C	CEREMONIE	2022-02-23 13:00:00	2022-02-23 14:30:00	Remise de la cravate de Commandeur de l'Ordre National de la République italienne par l'Ambassadrice d'Italie en France 
18592	04042C	ACC_VISIT	2022-02-23 16:20:00	2022-02-23 16:30:00	Interview Public Sénat
18593	04042C	REU_GVT	2022-02-23 19:30:00	2022-02-23 21:00:00	Rencontre des parlementaires et du Premier ministre
18757	11066Q	ACC_VISIT	2022-03-24 14:00:00	2022-03-24 17:00:00	Accueil Permanence
18841	11103C	CEREMONIE	2022-03-25 20:00:00	2022-03-25 21:00:00	Remise Mérite agricole à Thierry SIMONNEAU
18861	04042C	REU_TRAV_PARL	2022-04-04 10:30:00	2022-04-04 11:00:00	Entretien téléphonique avec un sénateur
18862	04042C	ELUS_LOCAUX	2022-04-04 13:00:00	2022-04-04 14:15:00	Rencontre avec un élu du Val-de-Marne
18863	04042C	COLL_TER	2022-04-04 14:30:00	2022-04-04 17:00:00	Conseil de la Métropole du Grand Paris
18864	04042C	ELUS_LOCAUX	2022-04-04 18:30:00	2022-04-04 20:30:00	Réunion d'un comité de pilotage à Saint-Maurice
18865	08010L	COLL_TER	2022-04-04 18:00:00	2022-04-04 20:30:00	Conseil municipal Laon
18869	08010L	COLL_TER	2022-04-07 18:00:00	2022-04-07 20:00:00	Conseil communautaire Agglo Laon
18867	08010L	COLL_TER	2022-04-05 14:00:00	2022-04-05 17:00:00	Visite et conseil d'évaluation du centre pénitentiaire de Château-Thierry
18868	08010L	COLL_TER	2022-04-05 18:00:00	2022-04-05 19:30:00	Réunion situation BTP Aisne
18913	04042C	COLL_TER	2022-04-22 09:30:00	2022-04-22 13:00:00	Conseil de surveillance des Hôpitaux de Saint-Maurice
18942	08010L	ORGEXTPAR	2022-04-14 10:00:00	2022-04-14 12:00:00	Conseil d'administration FEPL
18961	04042C	ACC_VISIT	2022-05-05 08:00:00	2022-05-05 08:30:00	Emission Europe 1
18962	04042C	ACC_DEPL_INTER	2022-05-05 08:45:00	2022-05-05 10:00:00	Entetien avec le Président du Sénat et l'Ambassadeur d'Ukraine en France
18963	04042C	ACC_VISIT	2022-05-05 15:00:00	2022-05-05 15:30:00	Entretien téléphonique avec un élu du Val-de-Marne
19001	04042C	ELUS_LOCAUX	2022-05-16 10:00:00	2022-05-16 12:00:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
18965	04042C	ACC_DEPL_INTER	2022-05-09 16:00:00	2022-05-09 17:00:00	Entretien avec le Vice-premier ministre chargé des affaires européennes de la Macédoine du Nord et l'Ambassadrice de la Macédoine du Nord
18966	04042C	ACC_DEPL_INTER	2022-05-09 15:00:00	2022-05-09 16:00:00	Entretien avec le Vice-Premier Ministre de la Politique étrangère, de lntégration européenne et de la Coopération régionaleMinistre des Affaires étrangères du Monténégro et l'Ambassadeur du Monténégro en France
19002	04042C	ELUS_LOCAUX	2022-05-16 13:00:00	2022-05-16 14:30:00	Rencontre avec des élus du Val-de-Marne
19003	04042C	ACC_VISIT	2022-05-12 12:15:00	2022-05-12 12:30:00	Interview téléphonique d'un journaliste de RFI
19041	04042C	ACC_DEPL_INTER	2022-05-20 12:30:00	2022-05-20 13:00:00	Entretien téléphonique avec l'Ambassadeur envoyé spécial pour la diplomatie publique en Afrique
19042	04042C	ACC_DEPL_INTER	2022-05-20 13:50:00	2022-05-20 14:10:00	Signature du registre de condoléances suite au décès du Président de l'Etat des Emirats Arabes à l'Ambassade
19043	04042C	CEREMONIE	2022-05-20 18:45:00	2022-05-20 20:00:00	Passation de pouvoir au Ministère des Armées
19044	04042C	ELUS_LOCAUX	2022-05-23 10:00:00	2022-05-23 12:00:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
19045	04042C	ACC_VISIT	2022-05-23 12:30:00	2022-05-23 13:00:00	Interview téléphonique avec une journaliste de la Radio RCF
19046	04042C	ELUS_LOCAUX	2022-05-23 15:30:00	2022-05-23 18:00:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
19047	04042C	ORG_POL	2022-05-23 19:30:00	2022-05-23 21:00:00	Réunion publique dans le cadre des législatives à Saint-Maurice
19081	04042C	ACC_DEPL_INTER	2022-06-01 15:30:00	2022-06-01 16:45:00	Entretien avec le Représentant spécial pour les Affaires européennes du Gouvernement chinois
19082	04042C	ACC_DEPL_INTER	2022-06-01 18:30:00	2022-06-01 20:30:00	Célébration du jubilé de la Reine Elisabeth à l'Ambassade britannique
19083	04042C	ACC_VISIT	2022-06-02 09:30:00	2022-06-02 10:10:00	Emmission TV5 Monde - Face aux territoires
19085	04042C	ACC_DEPL_INTER	2022-06-02 16:00:00	2022-06-02 17:00:00	Entretien avec l'Ambassadrice de la République Bolivarienne du Venezuela en France
19086	04042C	ELUS_LOCAUX	2022-05-30 18:30:00	2022-05-30 20:00:00	Inauguration du nouvel espace coworking à Saint-Maurice
19087	04042C	ACC_DEPL_INTER	2022-06-02 18:30:00	2022-06-02 21:00:00	Rencontre avec l'Ambassadrice d'Italie en France à l'occasion de la Fête Nationale
19112	04042C	ACC_DEPL_INTER	2022-06-07 19:30:00	2022-06-07 21:00:00	Soirée à l'Unesco pour commémorer le 30ème anniversaire de l'adhésion de l'Arménie au sein de l'Organisation des Nations Unies
19113	04042C	ACC_DEPL_INTER	2022-06-08 17:30:00	2022-06-08 18:30:00	Entretien avec l'Ambassadeur de Corée en France
19114	04042C	COLL_TER	2022-05-12 09:30:00	2022-05-12 11:30:00	Réunion de travail du Syndicat des Eaux d'Ile-de-France
19115	04042C	COLL_TER	2022-06-09 09:30:00	2022-06-09 11:30:00	Réunion de travail du Syndicat des Eaux d'Ile-de-France
19116	04042C	ACC_DEPL_INTER	2022-06-09 12:30:00	2022-06-09 14:30:00	Rencontre avec l'Ambassadeur de Suède en France à l'occasion de la Fête Nationale
19117	04042C	ACC_VISIT	2022-06-09 15:00:00	2022-06-09 16:00:00	Entretien avec des élus du Val-de-Marne
19118	04042C	ACC_DEPL_INTER	2022-06-09 16:30:00	2022-06-09 17:30:00	Entretien avec le Président du Sénat et l'Émissaire spécial pour l¿Europe du Président de la République de Corée
19121	04042C	COLL_TER	2022-06-10 10:00:00	2022-06-10 11:30:00	Réunion de la Commission Relations internationales et Solidarité du Syndicat des Eaux d'Ile-de-France
19122	04042C	ACC_VISIT	2022-06-10 13:00:00	2022-06-10 14:15:00	Rencontre avec un élu du Val-de-Marne
18302	04042C	ELUS_LOCAUX	2022-01-21 11:00:00	2022-01-21 12:30:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
18303	04042C	COLL_TER	2022-01-24 14:00:00	2022-01-24 17:30:00	Conseil de la Métropole du Grand Paris
18304	04042C	ACC_VISIT	2022-01-24 17:30:00	2022-01-24 19:00:00	Webinaire : Un an de Présidence Biden : et après ?
18305	04042C	ORG_POL	2022-01-25 11:00:00	2022-01-25 12:30:00	Réunion de Groupe des Sénateurs LR du Sénat
18306	04042C	ACC_DEPL_INTER	2022-01-25 19:30:00	2022-01-25 21:30:00	Rencontre à l'Ambassade britannique pour célébrer la vie du poëte écossais Robert Burns
18307	04042C	REU_TRAV_PARL	2022-01-26 13:00:00	2022-01-26 14:15:00	Rencontre avec les Présidents des Commissions, le Rapporteur général et les référents des Commissions
18308	04042C	ACC_VISIT	2022-01-26 14:15:00	2022-01-26 15:00:00	accueil du Conseil municipal des Enfants et du Conseil municipal des Jeunes d'une commune du Val-de-Marne
18309	04042C	ACC_VISIT	2022-01-26 16:20:00	2022-01-26 16:30:00	Interview Public Sénat
18310	04042C	ELUS_LOCAUX	2022-01-07 13:00:00	2022-01-07 14:15:00	Rencontre avec un élu  du Val-de-Marne
18311	04042C	ACC_DEPL_INTER	2021-12-08 16:30:00	2021-12-08 17:30:00	Entretien avec une délégation de députés de la Grande Assemblée nationale de Turquie
18321	04042C	ORG_POL	2022-02-01 10:30:00	2022-02-01 11:30:00	Réunion de Groupe des Sénateurs L.R du sénat
18322	04042C	COLL_TER	2022-02-01 11:30:00	2022-02-01 12:30:00	Visioconférence sur la situation du crack avec le Préfet de la Région d'Ile-de-France
18323	08010L	COLL_TER	2022-01-07 17:00:00	2022-01-07 19:00:00	Réunion Coulonges-Cohan sur le dossier inondations
18621	01025N	COLL_TER	2022-01-28 14:00:00	2022-01-28 18:00:00	Commission Départementale de Coopération Intercommunale
18681	04042C	ELUS_LOCAUX	2022-03-21 13:00:00	2022-03-21 14:30:00	Rencontre avec un élu du Val-de-Marne
18682	04042C	ACC_DEPL_INTER	2022-03-21 15:30:00	2022-03-21 16:30:00	Entretien avec le Président de la République de Finlande
18701	04042C	ACC_VISIT	2022-03-23 13:00:00	2022-03-23 14:00:00	Emission Cnews
18702	04042C	REU_GVT	2022-03-23 16:15:00	2022-03-23 17:15:00	Réunion du Comité de liaison Ukraine avec le Premier ministre
18703	04042C	ACC_VISIT	2022-03-23 14:50:00	2022-03-23 15:00:00	Interview Public Sénat
18758	04042C	REU_TRAV_PARL	2022-03-24 16:15:00	2022-03-24 16:30:00	Entretien téléphonique avec un sénateur
18712	11066Q	ACC_VISIT	2022-02-25 09:00:00	2022-02-25 17:00:00	Accueil Permanence
18759	11066Q	ACC_VISIT	2022-03-25 09:00:00	2022-03-25 17:00:00	Accueil Permanence et visite sur le Département
18714	11066Q	REU_TRAV_PARL	2022-03-01 11:00:00	2022-03-01 12:00:00	Réunion de groupe
18719	11066Q	ACC_VISIT	2022-03-04 11:30:00	2022-03-04 12:30:00	Audioconférence avec le Préfet sur le partage des premiers éléments d'organisation de l'accueil des réfugiés ukrainiens
18727	11066Q	ELUS_LOCAUX	2022-03-11 10:00:00	2022-03-11 12:30:00	Réunion du Comité d'Orientation Stratégique de l'étude de zone sur la surmortalité prématurée constatée dans la région de Saint-Nazaire
18720	11066Q	CEREMONIE	2022-03-04 18:30:00	2022-03-04 19:30:00	Rassemblement en soutien à l'Ukraine
18722	11066Q	REU_TRAV_PARL	2022-03-07 10:30:00	2022-03-07 11:30:00	Entretien en audioconférence avec la Mission relative aux conditions de réalisation des stages de survie
18723	11066Q	ACC_VISIT	2022-03-07 15:00:00	2022-03-07 16:00:00	Entretien avec le délégué syndical CGT de la raffinerie de Donges
18725	11066Q	REU_TRAV_PARL	2022-03-08 14:00:00	2022-03-08 15:30:00	Réunion de groupe
18726	11066Q	COLL_TER	2022-03-10 18:30:00	2022-03-10 19:00:00	Audio conférence avec le Préfet: point sur le Covid 19
18760	04042C	REU_TRAV_PARL	2022-03-25 10:30:00	2022-03-25 11:00:00	Entretien avec un industriel de l'armement
18761	04042C	ACC_DEPL_INTER	2022-03-25 11:00:00	2022-03-25 12:00:00	Entretien avec l'Ambassadrice du Royaume-Uni
18762	04042C	ELUS_LOCAUX	2022-03-25 12:30:00	2022-03-25 14:30:00	Rencontre avec des élus du Val-de-Marne
18733	11066Q	ACC_VISIT	2022-03-16 09:00:00	2022-03-16 17:00:00	Accueil Permanence
18781	04042C	ACC_DEPL_INTER	2022-03-29 10:00:00	2022-03-29 11:00:00	Entretien avec l'Ambassadrice de Moldavie en France
18782	04042C	ORG_POL	2022-03-29 11:00:00	2022-03-29 12:30:00	Réunion de Groupe des sénateurs L.R du sénat
18783	04042C	ACC_DEPL_INTER	2022-03-29 13:00:00	2022-03-29 14:30:00	Rencontre avec les Ambassadeurs en France de l'Argentine, du Brésil, d'Uruguay, de Colombie, du Mexique et de l'Equateur
18737	11066Q	ACC_VISIT	2022-03-22 10:00:00	2022-03-22 12:00:00	Intervention sur la guerre en Ukraine lors de l'Assemblée extraordinaire du Syndicat Retraités CFDT de Saint-Nazaire
18738	11066Q	REU_TRAV_PARL	2022-03-22 14:00:00	2022-03-22 15:00:00	Réunion de groupe
18739	11066Q	ORGEXTPAR	2022-03-23 16:15:00	2022-03-23 18:00:00	CNCTR
18842	11103C	REU_TRAV_PARL	2022-03-29 12:30:00	2022-03-29 13:00:00	Comité central de la Sologne - PPL Engrillagements 
18881	04042C	ELUS_LOCAUX	2022-04-11 11:30:00	2022-04-11 12:30:00	Rendez-vous avec un élu du Val-de-Marne
18882	04042C	ORG_POL	2022-04-11 16:00:00	2022-04-11 18:00:00	Réunion de Groupe des sénateurs L.R du sénat
18922	04042C	ACC_DEPL_INTER	2022-04-22 20:00:00	2022-04-22 22:00:00	Rencontre avec l'Ambassadeur du Royaume du Maroc en France
18884	04042C	REU_TRAV_PARL	2022-04-12 15:00:00	2022-04-12 16:00:00	Réunion de travail pour l'organisation d'un colloque géopolitique
18921	04042C	COLL_TER	2022-04-22 18:00:00	2022-04-22 19:00:00	Réunion de travail du Syndicat des Eaux d'Ile-de-France
18256	04042C	REU_TRAV_PARL	2022-01-11 12:10:00	2022-01-11 13:10:00	Réunion de Direction
18923	04042C	ORG_POL	2022-04-25 19:30:00	2022-04-25 21:30:00	Réunion de travail d'un séminaire des sénateurs L.R du Sénat
18941	08010L	CEREMONIE	2022-04-08 18:00:00	2022-04-08 20:00:00	Match basket Saint-Quentin (SQBB)
18943	08010L	DEPL_PRES_GVT	2022-04-26 13:00:00	2022-04-26 18:00:00	Mission d'études GIA France-USA
18967	04042C	ORG_POL	2022-05-10 11:00:00	2022-05-10 12:45:00	Réunion de Groupe des sénateurs L.R du sénat
19024	04042C	ACC_DEPL_INTER	2022-05-10 18:00:00	2022-05-10 19:00:00	Rencontre avec l'Ambassadeur d'Allemagne en France à l'occasion de la Journée de l'Europe
19036	04042C	ACC_DEPL_INTER	2022-05-18 19:00:00	2022-05-18 19:45:00	Rencontre avec l'Ambassadeur de Corée en France  pour honorer le patrimoine gastronomique des temples bouddhistes coréens
19026	04042C	ACC_VISIT	2022-05-11 13:00:00	2022-05-11 14:00:00	Emission Cnews
19021	04042C	ACC_VISIT	2022-05-10 13:00:00	2022-05-10 14:30:00	Rencontre avec un élu du Val-de-Marne
19023	04042C	ACC_DEPL_INTER	2022-05-10 17:00:00	2022-05-10 18:00:00	Entretien avec une délégation d'experts ukrainiens
19027	04042C	ACC_DEPL_INTER	2022-05-11 16:45:00	2022-05-11 17:30:00	Entretien avec l'Ambassadeur de Corée en France
19028	04042C	ORG_POL	2022-05-11 19:00:00	2022-05-11 20:30:00	Inauguration d'une permanence parlementaire dans le Val-de-Marne
19029	04042C	ACC_VISIT	2022-05-11 17:45:00	2022-05-11 18:00:00	Interview des Républicains
19030	04042C	REU_TRAV_PARL	2022-05-17 13:00:00	2022-05-17 14:15:00	Entretien avec le Chef d'état-major de la Marine
19031	04042C	REU_TRAV_PARL	2022-05-17 15:00:00	2022-05-17 16:00:00	Entretien avec un sénateur
19032	04042C	ACC_DEPL_INTER	2022-05-17 16:00:00	2022-05-17 17:00:00	Entretien avec les Ambassadeurs de la Finlande et de la Suède en France
19033	04042C	REU_TRAV_PARL	2022-05-17 17:00:00	2022-05-17 18:00:00	Entretien avec le Secrétaire général de la Défense et de la Sécurité nationale
19034	04042C	ORG_POL	2022-05-17 19:00:00	2022-05-17 20:00:00	Réunion publique dans le cadre des élections législatives dans le Val-de-Marne
19035	04042C	ORG_POL	2022-05-10 20:00:00	2022-05-10 22:30:00	Réunion publique dans le cadre des élections législatives dans le Val-de-Marne
19037	04042C	ACC_DEPL_INTER	2022-05-18 20:00:00	2022-05-18 21:30:00	Rencontre avec l'Ambassadeur du Danemark en France à une exposition du peintre Jesper Christiansen à l'occasion de la Fête du Printemps
19038	04042C	ACC_VISIT	2022-05-18 09:30:00	2022-05-18 10:30:00	Visite à l'équipe de l'école de coiffure Elysées-Marboeuf à Joinville-le-Pont pour une séquence de coiffure de réfugiés ukrainiens
19039	04042C	ACC_DEPL_INTER	2022-05-18 13:15:00	2022-05-18 14:15:00	Rencontre avec l'Attaché de défense de l'Ambassade de la Corée en France
19048	04042C	ACC_DEPL_INTER	2022-05-24 10:30:00	2022-05-24 12:30:00	Intervention à une Conférence-débat sur le thème de la coopération globale Franco-belge à l'Ambassade de Belgique en France
19049	04042C	ORG_POL	2022-05-24 13:00:00	2022-05-24 14:30:00	Rencontre des sénateurs du groupe les Républicains du Sénat
18019	14133K	ELUS_LOCAUX	2021-10-08 09:30:00	2021-10-08 12:30:00	Visite territoire Calvados - Honfleur
18020	14133K	ELUS_LOCAUX	2021-10-08 13:00:00	2021-10-08 17:30:00	Visite de territoire Calvados - Trouville sur Mer
18021	14133K	ELUS_LOCAUX	2021-10-08 18:00:00	2021-10-08 19:00:00	cérémonie remise de médailles à Vauville
18022	14133K	ORG_POL	2021-10-08 19:30:00	2021-10-08 20:30:00	rentrée politique de N. Porte, députée 3e circo du Calvados
18023	14133K	ELUS_LOCAUX	2021-10-11 09:30:00	2021-10-11 15:30:00	Visite territoire Calvados - Ifs
18024	14133K	REU_TRAV_PARL	2021-10-11 16:30:00	2021-10-11 17:30:00	rdv téléphonique - services de l'Etat
18028	14133K	DEPL_PRES_GVT	2021-10-18 13:30:00	2021-10-18 16:30:00	Visite territoire Calvados - May sur Orne
18026	14133K	REU_TRAV_PARL	2021-10-15 12:00:00	2021-10-15 14:30:00	conférence sur le rapport parlementaire - puissance chinoise en Europe - Caen
18027	14133K	REU_TRAV_PARL	2021-10-18 09:30:00	2021-10-18 11:00:00	rdv individuels permanence parlementaire
18029	14133K	COLL_TER	2021-10-18 16:30:00	2021-10-18 17:30:00	Cérémonie et AG Comité Juno Canada
18038	14133K	ORG_POL	2021-11-09 10:30:00	2021-11-09 12:30:00	Réunion du Groupe LR Sénat
18039	14133K	CEREMONIE	2021-11-11 11:00:00	2021-11-11 12:00:00	Commémoration armistice 1918 - Condé-en-Normandie
18040	14133K	COLL_TER	2021-11-15 09:30:00	2021-11-15 12:30:00	Visite territoire Calvados - Rots
18041	14133K	ELUS_LOCAUX	2021-11-15 12:30:00	2021-11-15 14:00:00	Déjeuner élus régionaux
18042	14133K	ELUS_LOCAUX	2021-11-15 14:15:00	2021-11-15 15:45:00	rdv maire de Frénouville
18043	14133K	REU_TRAV_PARL	2021-11-15 16:00:00	2021-11-15 17:00:00	Rencontre avec les représentants de l'UNI Caen
18044	14133K	ELUS_LOCAUX	2021-11-17 19:30:00	2021-11-17 21:00:00	réception des maires du Calvados au Sénat
18045	14133K	REU_TRAV_PARL	2021-11-22 12:00:00	2021-11-22 14:30:00	conférence sur le rapport parlementaire - puissance chinoise en Europe - ACF Paris
18046	08010L	ORG_POL	2021-11-23 10:30:00	2021-11-23 11:30:00	Groupe LR du Sénat + E.Ciotti
18047	08010L	ACC_VISIT	2021-11-23 11:30:00	2021-11-23 12:30:00	GIA France - Etats-Unis
18161	08010L	ORG_POL	2021-12-14 11:00:00	2021-12-14 12:30:00	Groupe LR du Sénat
18162	08010L	REU_TRAV_PARL	2021-12-09 09:00:00	2021-12-09 10:00:00	DCT
18163	08010L	REU_TRAV_PARL	2021-12-14 14:30:00	2021-12-14 15:30:00	DCT Risque Incendie
18164	08010L	REU_TRAV_PARL	2021-12-14 15:30:00	2021-12-14 16:30:00	DCT Financements et projets 
18165	08010L	REU_TRAV_PARL	2021-12-14 16:30:00	2021-12-14 17:15:00	DCT expérience pyrénéenne 
18241	04042C	REU_TRAV_PARL	2022-01-04 10:00:00	2022-01-04 11:00:00	Réunion Présidence Française de l'Union Européenne 
18242	04042C	ORG_POL	2022-01-04 11:00:00	2022-01-04 12:30:00	Réunion de Groupe des Sénateurs LR du Sénat
18243	04042C	ACC_VISIT	2022-01-04 13:00:00	2022-01-04 14:15:00	Rencontre avec un élu du Val-de-Marne
18244	04042C	ORG_POL	2022-01-04 18:30:00	2022-01-04 19:30:00	Inauguration du QG de Campagne de la Présidente de la Région Ile-de-France
18245	04042C	REU_TRAV_PARL	2022-01-05 08:00:00	2022-01-05 09:00:00	Rencontre avec les Présidents des Commissions, le Rapporteur général et les référents des Commissions
18246	04042C	ACC_DEPL_INTER	2022-01-05 16:30:00	2022-01-05 16:50:00	Entretien avec l'Ambassadeur de Corée en France
18247	04042C	REU_TRAV_PARL	2022-01-05 18:30:00	2022-01-05 19:30:00	Conférence des Présidents
18248	04042C	REU_TRAV_PARL	2022-01-06 13:00:00	2022-01-06 14:15:00	Réunion de travail avec le Président du Sénat et le Président de la Commission des Affaires européennes
18249	04042C	ACC_DEPL_INTER	2022-01-06 16:00:00	2022-01-06 17:00:00	Visioconférence du passage de relais de la Présidence de l'Union Européenne avec les Présidents des Chambres slovènes et françaises
18250	04042C	ACC_DEPL_INTER	2022-01-07 15:45:00	2022-01-07 17:00:00	Entretien avec le collège des Commissaires européens 
18251	04042C	ACC_DEPL_INTER	2022-01-07 17:10:00	2022-01-07 18:10:00	Entretien avec la Présidente de la Commission européenne et le Président du Sénat
18252	04042C	ELUS_LOCAUX	2022-01-10 11:00:00	2022-01-10 12:30:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
18254	04042C	ORG_POL	2022-01-11 09:00:00	2022-01-11 10:00:00	Réunion des groupes de travail thématiques parlementaires
18255	04042C	ORG_POL	2022-01-11 11:00:00	2022-01-11 12:00:00	Réunion de groupe des Sénateurs LR du Sénat
18561	11103C	ORG_POL	2022-02-22 11:00:00	2022-02-22 12:30:00	LR du Sénat
18562	04043D	ORG_POL	2022-01-25 11:00:00	2022-01-25 13:00:00	Réunion groupe LR
18563	04043D	REU_TRAV_PARL	2022-01-27 12:00:00	2022-01-27 12:30:00	Réunion préparation auditions chlordécone
18564	04043D	REU_TRAV_PARL	2022-01-28 09:15:00	2022-01-28 10:00:00	Réunion avec Mme Catherine Deroche
18565	04043D	ORG_POL	2022-02-01 10:30:00	2022-02-01 12:30:00	Réunion groupe LR
18667	04042C	REU_TRAV_PARL	2022-03-17 17:00:00	2022-03-17 18:00:00	Réunion de Direction
18567	04043D	ORG_POL	2022-02-01 17:30:00	2022-02-01 19:30:00	Commission Nationale d'Investiture
18568	04043D	ELUS_LOCAUX	2022-02-02 00:00:00	2022-02-02 00:00:00	Réception des élus de l¿Hay-les-Roses
18569	04043D	REU_TRAV_PARL	2022-02-07 09:30:00	2022-02-07 10:30:00	Visio valeurs locatives
18570	04043D	ACC_DEPL_INTER	2022-02-07 13:00:00	2022-02-07 14:00:00	Déjeuner ambassadeur papouasie nouvelle guinée
18571	04043D	COLL_TER	2022-02-08 11:00:00	2022-02-08 14:00:00	Visite Collège Triolet à Champigny + déjeuner avec le VP du VdM Nicolas Tryzna
18572	04043D	ACC_DEPL_INTER	2022-02-09 13:00:00	2022-02-09 14:00:00	Déjeuner Ambassade de Corée
18573	04043D	ACC_VISIT	2022-02-10 18:30:00	2022-02-10 22:30:00	Reception des entrepreneurs du plateau Briard
18574	04043D	ORG_POL	2022-02-15 11:00:00	2022-02-15 13:00:00	Réunion groupe LR
18668	04042C	ELUS_LOCAUX	2022-03-17 20:00:00	2022-03-17 22:00:00	Rencontre avec des élus du Val-de-Marne
18576	04043D	ORG_POL	2022-02-15 17:30:00	2022-02-15 19:00:00	Commission Nationale d¿Investiture
18577	04043D	REU_TRAV_PARL	2022-02-15 00:00:00	2022-02-15 00:00:00	Aquarium de Paris
18578	04043D	REU_TRAV_PARL	2022-02-17 14:30:00	2022-02-17 15:30:00	Commission affaires sociales
18579	04043D	COLL_TER	2022-02-18 11:15:00	2022-02-18 16:15:00	Visite Santé publique France à Saint-Maurice
18580	04043D	REU_TRAV_PARL	2022-02-21 15:30:00	2022-02-21 16:30:00	Groupe interparlementaire amitié France- Pays Bas
18581	04043D	REU_TRAV_PARL	2022-02-22 09:00:00	2022-02-22 10:00:00	Commission des affaires sociales
18582	04043D	ELUS_LOCAUX	2022-02-22 10:00:00	2022-02-22 13:30:00	Séminaire d'immersion - Hippodrome de Vincennes
18669	04042C	ELUS_LOCAUX	2022-03-17 13:00:00	2022-03-17 14:15:00	Rencontre avec un élu du Val-de-Marne
18584	04043D	ORG_POL	2022-02-22 17:30:00	2022-02-22 19:00:00	Commission Nationale d'Investiture
18670	04042C	ELUS_LOCAUX	2022-03-18 09:30:00	2022-03-18 10:30:00	Entretien avec un élu du Val-de-Marne
18586	04043D	ACC_DEPL_INTER	2022-02-23 13:00:00	2022-02-23 14:00:00	Déjeuner Ambassade d'Italie
18671	04042C	ELUS_LOCAUX	2022-03-18 10:30:00	2022-03-18 11:30:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
18672	04042C	ELUS_LOCAUX	2022-03-18 12:30:00	2022-03-18 14:45:00	Rencontre avec des parlementaires franciliens et le Président de la CCI Paris Ile-de-France
18673	04042C	ACC_VISIT	2022-03-18 15:00:00	2022-03-18 15:40:00	Emission France Info
18674	04042C	ELUS_LOCAUX	2022-03-18 19:00:00	2022-03-18 20:00:00	Vernissage du 17ème Salon de Bry-sur-Marne
18805	08010L	DEL_ACT_PAR	2022-02-03 09:45:00	2022-02-03 11:30:00	DCT Table ronde revitalisation centres bourgs
18807	08010L	ELUS_LOCAUX	2022-02-07 10:00:00	2022-02-07 12:30:00	Rencontre maires du Chaunois
18809	08010L	COLL_TER	2022-02-11 10:00:00	2022-02-11 12:30:00	Réunion Préfecture Cartographie de l'éolien dans les HDF
18810	08010L	COLL_TER	2022-02-21 10:00:00	2022-02-21 12:30:00	Commission DETR Préfecture 
18811	08010L	COLL_TER	2022-02-21 18:00:00	2022-02-21 19:30:00	Conseil municipal Laon
18812	08010L	COLL_TER	2022-02-24 18:00:00	2022-02-24 20:00:00	Conseil communautaire Agglo Laon
18813	08010L	COLL_TER	2022-02-25 09:00:00	2022-02-25 10:00:00	Conseil d'administration OPAL Aisne
18814	08010L	COLL_TER	2022-02-25 10:00:00	2022-02-25 11:00:00	Rencontre agriculteurs de l'Aisne
18815	08010L	COLL_TER	2022-02-25 11:00:00	2022-02-25 12:30:00	Bureau de l'Union des Maires
18820	08010L	COLL_TER	2022-03-07 18:00:00	2022-03-07 20:00:00	Bureau municipal Laon
18821	08010L	COLL_TER	2022-03-07 16:00:00	2022-03-07 17:30:00	Réunion d'urgence Préfecture - Situation en Ukraine
18822	08010L	ACC_VISIT	2022-03-08 09:00:00	2022-03-08 17:00:00	Journée des femmes maires
18825	08010L	ORG_POL	2022-03-18 18:00:00	2022-03-18 20:00:00	Réunion LR Présidentielles
18826	08010L	COLL_TER	2022-03-25 09:30:00	2022-03-25 11:00:00	Commission départementale valeurs locatives
18101	08010L	ORG_POL	2021-12-07 00:00:00	2021-12-07 00:00:00	Groupe LR Sénat et AN + V PECRESSE 
18102	04042C	ELUS_LOCAUX	2021-10-15 19:00:00	2021-10-15 22:00:00	Rencontre avec des élus du Val-de-Marne
18103	08010L	ORG_POL	2021-12-08 11:00:00	2021-12-08 12:00:00	commission investiture  LR
18201	04042C	CEREMONIE	2021-12-15 12:30:00	2021-12-15 14:00:00	Inauguration du Marché de Noël de Valenton
18202	04042C	DEPL_PRES_GVT	2021-12-15 17:45:00	2021-12-15 00:00:00	Déplacement en Lituanie avec le Président du Sénat
18203	04042C	DEPL_PRES_GVT	2021-12-16 00:00:00	2021-12-16 00:00:00	Déplacement en Lituanie avec le Président du Sénat
18204	04042C	DEPL_PRES_GVT	2021-12-17 00:00:00	2021-12-17 00:00:00	Déplacement en Lituanie avec le Président du Sénat
18225	08010L	ORG_POL	2022-01-06 19:00:00	2022-01-06 20:30:00	\N
18490	14133K	REU_TRAV_PARL	2021-12-16 10:00:00	2021-12-16 11:30:00	rdv permanence parlementaire
18491	14133K	ORG_POL	2021-12-14 11:00:00	2021-12-14 12:30:00	Réunion du Groupe LR Sénat
18492	14133K	ORG_POL	2021-12-14 17:30:00	2021-12-14 19:00:00	CNI Les Républicains - Paris
18602	04042C	ORG_POL	2022-03-01 17:00:00	2022-03-01 18:30:00	Réunion de Groupe des Sénateurs LR du sénat
18494	14133K	CEREMONIE	2021-12-13 11:00:00	2021-12-13 12:00:00	Remise officielle du Drapeau - Ass Retraités de la Police Nationale - CAEN
18495	14133K	REU_TRAV_PARL	2021-12-13 15:30:00	2021-12-13 18:00:00	rdv permanence parlementaire
18601	04042C	REU_TRAV_PARL	2022-02-28 17:30:00	2022-02-28 19:00:00	Réunion de direction
18661	04042C	ACC_VISIT	2022-03-15 16:00:00	2022-03-15 17:00:00	Entretien avec des élus du Val-de-Marne
18662	04042C	ORG_POL	2022-03-15 17:30:00	2022-03-15 18:30:00	 Réunion du groupe politique Action extérieure de la France 
18803	08010L	ELUS_LOCAUX	2022-01-28 14:30:00	2022-01-28 16:30:00	RDV conseiller régional
18664	04042C	ELUS_LOCAUX	2022-03-16 13:00:00	2022-03-16 14:30:00	Rencontre avec des élus du Val-de-Marne
18665	04042C	ACC_DEPL_INTER	2022-03-16 18:30:00	2022-03-16 20:00:00	Rencontre avec l'Ambassadeur de Hongrie en l'honneur de la Fête Nationale de Hongrie
18666	04042C	ELUS_LOCAUX	2022-03-16 20:30:00	2022-03-16 22:00:00	soirée-débat des élus à l'évêché du Val-de-Marne
18801	08010L	ELUS_LOCAUX	2022-01-24 14:00:00	2022-01-24 16:00:00	Réunion Maires Matériel agricole
18802	08010L	ORGEXTPAR	2022-01-28 10:00:00	2022-01-28 12:00:00	Réunion Mission locale pour l'emploi Laonnois
18804	08010L	CEREMONIE	2022-01-31 15:00:00	2022-01-31 16:30:00	Audience de rentrée TJ Laon
18806	08010L	ORG_POL	2022-02-04 16:30:00	2022-02-04 19:30:00	Réunion LR Présidentielles
18808	08010L	REU_TRAV_PARL	2022-02-07 14:00:00	2022-02-07 16:00:00	Séance préparation table ronde Syndicats pénitentiaires
18816	08010L	ORG_POL	2022-02-25 18:00:00	2022-02-25 20:00:00	Réunion LR Présidentielles
18817	08010L	COLL_TER	2022-02-28 10:00:00	2022-02-28 12:00:00	Rencontre directeur CH Laon
18818	08010L	CEREMONIE	2022-03-01 10:00:00	2022-03-01 13:00:00	Salon de l'agriculture
18819	08010L	CEREMONIE	2022-03-04 17:00:00	2022-03-04 19:00:00	Inauguration Château Louis d'Orléans La Ferté Milon
18823	08010L	COLL_TER	2022-03-11 10:00:00	2022-03-11 12:00:00	Session Chambre d'agriculture
18824	08010L	ACC_VISIT	2022-03-17 14:00:00	2022-03-17 17:00:00	Présentation du Sénat à une association laonnoise
18827	08010L	COLL_TER	2022-03-25 11:00:00	2022-03-25 13:00:00	Visite Unité de soins psychiatriques Prémontré
18828	08010L	COLL_TER	2022-03-28 17:00:00	2022-03-28 19:00:00	Comité Ukraine Préfecture
18829	08010L	ACC_VISIT	2022-03-29 10:00:00	2022-03-29 12:00:00	Rencontre Justice - 1ère Présidente CA Amiens
18830	08010L	CEREMONIE	2022-04-01 17:00:00	2022-04-01 19:00:00	Inauguration Eglise rénovée Vauxrezis
18901	04042C	ELUS_LOCAUX	2022-04-19 13:00:00	2022-04-19 14:30:00	Rencontre avec un élu du Val-de-Marne
18902	04042C	ELUS_LOCAUX	2022-04-20 11:00:00	2022-04-20 12:30:00	Présentation d'un projet dans le Val-de-Marne
18903	04042C	ELUS_LOCAUX	2022-04-20 13:00:00	2022-04-20 14:30:00	Rencontre avec des élus du-Val-de-Marne
18904	04042C	CEREMONIE	2022-04-20 16:00:00	2022-04-20 17:30:00	Cérémonie à l'occasion de lajournée nationale de la Commémoration du 107ème anniversaire du génocide des arméniens de 1915
18905	04042C	ELUS_LOCAUX	2022-04-20 18:00:00	2022-04-20 19:00:00	Réunion avec des élus de Saint-Maurice
18906	04042C	ELUS_LOCAUX	2022-04-20 19:00:00	2022-04-20 21:00:00	Conseil municipal de Saint-Maurice
18907	04042C	CEREMONIE	2022-04-21 11:30:00	2022-04-21 12:30:00	 Cérémonie à l'occasion de la journée du souvenir des victimes de la déportation
18908	04042C	ELUS_LOCAUX	2022-04-13 19:15:00	2022-04-13 22:00:00	Soiré-débat de la Fondation Prospective et Innovation
18909	04042C	COLL_TER	2022-04-14 09:30:00	2022-04-14 11:30:00	Réunion du Syndicat des Eaux d'Ile-de-France
18910	04042C	ACC_DEPL_INTER	2022-04-14 13:00:00	2022-04-14 14:30:00	Rencontre avec Président Commission sécurité nationale et défense du Parlement lituanien et l'Ambassadeur de Lituanie en France
18911	04042C	ACC_VISIT	2022-04-14 18:30:00	2022-04-14 18:45:00	Interview Public Sénat
18912	04042C	COLL_TER	2022-04-15 08:45:00	2022-04-15 11:30:00	Réunion du bureau du Syndicat des Eaux d'Ile-de-France
19050	04042C	ACC_DEPL_INTER	2022-05-24 19:00:00	2022-05-24 21:30:00	Réception à l'occasion du 74ème anniversaire de l'Etat d'Israël 
19061	11103C	ORG_POL	2022-05-24 11:00:00	2022-05-24 12:30:00	Groupe LR du Sénat
19101	04042C	ELUS_LOCAUX	2022-06-01 13:00:00	2022-06-01 14:30:00	Rencontre avec un élu du Val-de-Marne
19102	04042C	COLL_TER	2022-06-03 08:45:00	2022-06-03 11:00:00	Réunion du bureau du Syndicat des Eaux d'Ile-de-France
19103	04042C	ACC_VISIT	2022-06-03 16:30:00	2022-06-03 16:45:00	Interview téléphonique Public Sénat
19124	04042C	ACC_DEPL_INTER	2022-06-10 16:00:00	2022-06-10 17:00:00	Entretien avec le Représent du Gouvernement du Kurdistan-Irak en France
18987	04042C	ACC_VISIT	2022-05-12 12:30:00	2022-05-12 14:00:00	Rencontre avec un élu du Val-de-Marne
18988	04042C	ACC_VISIT	2022-05-12 16:15:00	2022-05-12 17:00:00	Visite guidée de l'Association Itinéraires et Rencontres de Créteil
18989	04042C	REU_TRAV_PARL	2022-05-12 18:00:00	2022-05-12 19:00:00	Entretien avec le Chef d'état-major de l'Armée de Terre
19104	04042C	ELUS_LOCAUX	2022-06-03 17:00:00	2022-06-03 18:00:00	Entretien avec un élu du Val-de-Marne
18991	04042C	ELUS_LOCAUX	2022-05-13 08:45:00	2022-05-13 09:45:00	Réunion du bureau du Syndicat des Eaux d'Ile-de-France
18992	04042C	ACC_VISIT	2022-05-13 10:15:00	2022-05-13 12:30:00	Intervention au Colloque du Collège des Ingénieurs
18993	04042C	ACC_DEPL_INTER	2022-05-13 15:00:00	2022-05-13 16:00:00	Entretien avec l'Ambassadeur de Roumanie en France
19105	04042C	ACC_VISIT	2022-06-07 10:00:00	2022-06-07 11:30:00	Intervention au Paris Air Forum
19106	04042C	ACC_DEPL_INTER	2022-06-07 12:15:00	2022-06-07 14:00:00	Célébration de la 9ème édition des Semaines de l¿Amérique latine et des Caraïbes
19110	04042C	ACC_DEPL_INTER	2022-06-07 18:30:00	2022-06-07 19:00:00	Conférence de Presse du Président du Sénat et du Président de la Rada ukrainienne
19108	04042C	REU_GVT	2022-06-07 15:00:00	2022-06-07 16:00:00	Entretien avec le Ministre délégué auprès de la Première ministre, chargé des Relations avec le Parlement et de la Vie démocratique
19109	04042C	ACC_DEPL_INTER	2022-06-07 16:50:00	2022-06-07 18:10:00	Entretien avec le Président du Sénat et le Président de la Rada ukrainienne
19111	04042C	ELUS_LOCAUX	2022-06-08 13:00:00	2022-06-08 14:15:00	Rencontre avec un élu du Val-de-Marne
19123	04042C	ACC_DEPL_INTER	2022-06-10 14:30:00	2022-06-10 15:30:00	Entretien avec le Ministre en charge des Affaires étrangères et de l'Intégration européenne de Moldavie
19125	04042C	ELUS_LOCAUX	2022-06-10 19:00:00	2022-06-10 21:30:00	Réunion publiques dans le cadre des législatives dans le Val-de-Marne
19126	04042C	ELUS_LOCAUX	2022-06-13 10:30:00	2022-06-13 12:00:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
19127	04042C	ELUS_LOCAUX	2022-06-13 13:00:00	2022-06-13 14:30:00	Rencontre avec un élu du Val-de-Marne
19128	04042C	REU_GVT	2022-06-13 20:00:00	2022-06-13 20:45:00	Réception à l'occasion du mondial de défense et de la sécurité au Ministère des Armées
19129	04042C	ACC_DEPL_INTER	2022-06-13 21:00:00	2022-06-13 22:00:00	Réczption de Monsieur l'Ambassadeur d'Allemagne en France à l'occasion du Salon Eurosatory 2022
19130	04042C	ACC_DEPL_INTER	2022-06-14 11:00:00	2022-06-14 12:00:00	Entretien avec le Ministre de la Défense de Serbie
19131	04042C	REU_TRAV_PARL	2022-06-14 12:15:00	2022-06-14 13:00:00	Réunion de travail avec le Secrétaire général du Sénat
19132	11066Q	ACC_VISIT	2022-03-28 09:00:00	2022-03-28 17:00:00	Accueil permanence
18048	11103C	ORG_POL	2021-11-23 10:30:00	2021-11-23 12:30:00	LR du Sénat 
18104	04042C	ELUS_LOCAUX	2021-10-11 19:00:00	2021-10-11 22:00:00	Rencontre avec des élus du Val-de-Marne
18105	04042C	ELUS_LOCAUX	2021-10-22 19:00:00	2021-10-22 22:00:00	Rencontre avec des élus du Val-de-Marne
18106	04042C	ELUS_LOCAUX	2021-11-29 19:00:00	2021-11-29 22:00:00	Rencontre avec des élus du Val-de-Marne
18107	04042C	ELUS_LOCAUX	2021-11-19 19:00:00	2021-11-19 22:00:00	Rencontre avec des élus du Val-de-Marne
18108	04042C	ELUS_LOCAUX	2021-12-06 19:00:00	2021-12-06 22:00:00	Rencontre avec des élus du Val-de-Marne
18109	04042C	ACC_DEPL_INTER	2021-12-06 08:45:00	2021-12-06 10:00:00	Conférence du Club des Ambassadeurs
18110	04042C	ELUS_LOCAUX	2021-12-06 11:00:00	2021-12-06 12:00:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
18111	04042C	ACC_DEPL_INTER	2021-12-06 13:00:00	2021-12-06 14:15:00	Rencontre avec l'Ambassadeur de Roumanie en France
18488	14133K	ELUS_LOCAUX	2021-12-17 14:30:00	2021-12-17 16:30:00	Conférence des parlementaires UAMC - Caen
18112	04042C	ACC_DEPL_INTER	2021-12-07 09:30:00	2021-12-07 10:30:00	Rencontre avec le Président de la Commission des Affaires étrangères et de l'Union européenne
18113	04042C	ORG_POL	2021-12-07 10:30:00	2021-12-07 11:30:00	Réunion de Groupe des Sénateurs L.R du Sénat
18114	04042C	ORG_POL	2021-12-07 12:00:00	2021-12-07 12:45:00	Rencontre avec des Parlementaires 
18115	04042C	ACC_VISIT	2021-12-07 13:00:00	2021-12-07 14:15:00	Rencontre avec un Rédacteur en chef adjoint
18116	04042C	ACC_DEPL_INTER	2021-12-07 15:00:00	2021-12-07 16:00:00	Entretien avec l'Ambassadrice d'Australie en France
18117	04042C	ACC_DEPL_INTER	2021-12-07 16:15:00	2021-12-07 17:40:00	Entretien avec la Présidente de la Commission Défense de Roumanie et une délégation de Sénateurs
18118	04042C	REU_TRAV_PARL	2021-12-08 09:00:00	2021-12-08 09:30:00	Entretien avec le Président du Sénat et le directeur exécutif de Frontex
18119	04042C	ACC_VISIT	2021-12-08 12:00:00	2021-12-08 12:30:00	Entretien avec un élu du Val-de-Marne
18120	04042C	ELUS_LOCAUX	2021-12-08 13:00:00	2021-12-08 14:15:00	Rencontre avec des élus du Val-de-Marne
18121	04042C	ACC_VISIT	2021-12-08 14:55:00	2021-12-08 15:00:00	Interview Public Sénat
18125	04042C	ACC_VISIT	2021-11-26 15:00:00	2021-11-26 15:30:00	Interview d'une télévision marocaine
18123	04042C	REU_GVT	2021-11-26 11:00:00	2021-11-26 12:30:00	Réunion de travail avec le Cabinbet du Ministre de l'Europe et des Affaires étrangères
18124	04042C	REU_GVT	2021-11-26 13:00:00	2021-11-26 14:15:00	Rencontre avec l'Ambassadrice de Grèce en France
18126	04042C	ACC_VISIT	2021-11-26 15:45:00	2021-11-26 16:45:00	Entretien avec une délégation sur la la Kabylie
18313	08010L	REU_TRAV_PARL	2022-01-12 09:30:00	2022-01-12 11:30:00	Commission des finances - Audition sur inflation / Communication du Pdt Raynal
18128	04042C	CEREMONIE	2021-11-26 18:00:00	2021-11-26 21:00:00	 Inauguration du 11ème Salon de l'artisanat et des métiers d'art
18312	08010L	ORG_POL	2022-01-11 11:00:00	2022-01-11 12:30:00	Groupe LR - Sénat
18314	08010L	REU_TRAV_PARL	2022-01-12 16:30:00	2022-01-12 18:00:00	Commission finances - Audition BCE + ACPR
18372	08010L	REU_TRAV_PARL	2022-01-20 00:00:00	2022-01-20 00:00:00	DCT Rapport Numérique et territoires 
18373	08010L	COLL_TER	2022-01-21 10:00:00	2022-01-21 12:00:00	Conseil d'administration OPAL Aisne
18374	08010L	ELUS_LOCAUX	2022-01-21 13:30:00	2022-01-21 15:00:00	Réunion Tiers lieu la Rotonde Laon
18375	08010L	COLL_TER	2022-01-24 18:00:00	2022-01-24 20:00:00	Bureau municipal Laon
18376	08010L	ACC_VISIT	2022-01-27 16:30:00	2022-01-27 18:00:00	Entretien Association Prévention routière
18377	08010L	CEREMONIE	2022-01-31 11:00:00	2022-01-31 12:30:00	Inauguration gymnase Saint-Quentin
18442	14133K	COLL_TER	2022-02-10 11:00:00	2022-02-10 12:00:00	Rdv élus - Pays d'Auge
18443	14133K	ELUS_LOCAUX	2022-02-10 12:30:00	2022-02-10 14:00:00	Déjeuner de travail élus Pays d'Auge
18444	14133K	COLL_TER	2022-02-10 14:30:00	2022-02-10 16:30:00	Visite territoire Calvados - Blangy-le-Château
18445	14133K	REU_TRAV_PARL	2022-02-11 10:30:00	2022-02-11 11:30:00	RDV DASEN 14
18446	14133K	REU_TRAV_PARL	2022-02-11 14:00:00	2022-02-11 15:00:00	RDV permanence parlementaire
18447	14133K	REU_TRAV_PARL	2022-02-11 15:30:00	2022-02-11 17:30:00	Visite thématique agricole Suisse Normande
18448	14133K	ORG_POL	2022-02-11 19:00:00	2022-02-11 20:30:00	Réunion publique élection présidentielle 2022
18449	14133K	REU_TRAV_PARL	2022-02-07 10:00:00	2022-02-07 12:00:00	rdv permanence parlementaire
18450	14133K	REU_TRAV_PARL	2022-02-07 14:30:00	2022-02-07 16:30:00	rdv permanence parlementaire
18451	14133K	ORG_POL	2022-02-08 18:00:00	2022-02-08 19:30:00	CNI Les Républicains - Paris
18452	14133K	REU_TRAV_PARL	2022-02-04 16:00:00	2022-02-04 17:30:00	rdv visite Centre équestre 14
18453	14133K	ELUS_LOCAUX	2022-02-03 12:30:00	2022-02-03 14:30:00	déjeuner de travail élus Côte de nacre
18454	14133K	ORG_POL	2022-02-03 19:00:00	2022-02-03 20:30:00	réunion publique élection présidentielle 2022
18455	14133K	COLL_TER	2022-01-31 10:00:00	2022-01-31 11:30:00	rdv Maire de Périgny 14
18456	14133K	REU_TRAV_PARL	2022-01-31 14:30:00	2022-01-31 16:30:00	Visite au Commandant de la Gendarmerie du Calvados
18457	14133K	ORG_POL	2022-01-31 18:45:00	2022-01-31 20:15:00	Point de campagne présidentielle - visio Paris siège LR
18458	14133K	ORG_POL	2022-02-01 17:30:00	2022-02-01 19:30:00	CNI Les Républicains - Paris
18459	14133K	ORG_POL	2022-02-01 10:30:00	2022-02-01 12:00:00	Réunion du Groupe LR Sénat
18460	14133K	REU_TRAV_PARL	2022-02-02 08:00:00	2022-02-02 09:00:00	Petit-déjeuner affaires étrangères - Birmanie
18461	14133K	ORG_POL	2022-02-02 19:00:00	2022-02-02 20:30:00	réunion comité de soutien Pécresse-Calvados Caen
18462	14133K	ORG_POL	2022-01-27 19:00:00	2022-01-27 20:30:00	Réunion politique autour de Valérie Pécresse - présidentielle 2022
18463	14133K	ORG_POL	2022-01-26 20:00:00	2022-01-26 21:00:00	Réunion du Groupe LR Sénat
18464	14133K	ORG_POL	2022-01-25 11:00:00	2022-01-25 12:30:00	Réunion du Groupe LR Sénat
18465	14133K	ORG_POL	2022-01-24 15:30:00	2022-01-24 18:00:00	Visite X Bertrand - Calvados - Lisieux
18466	14133K	ORG_POL	2022-01-24 18:30:00	2022-01-24 20:00:00	Réunion publique élection présidentielle - Dozulé
18467	14133K	REU_TRAV_PARL	2022-01-24 09:30:00	2022-01-24 11:00:00	rdv permanence parlementaire
18468	14133K	REU_TRAV_PARL	2022-01-21 09:15:00	2022-01-21 11:30:00	rdv permanence parlementaire
18469	14133K	ELUS_LOCAUX	2022-01-21 14:30:00	2022-01-21 15:30:00	rdv Président Interco Vallées de l'Orne et de l'Odon
18470	14133K	REU_TRAV_PARL	2022-01-21 16:15:00	2022-01-21 17:45:00	Visite territoire - Région Normandie - Saint-Pierre-Azif
18471	14133K	ELUS_LOCAUX	2022-01-20 11:00:00	2022-01-20 12:00:00	rdv Maire d'Evrecy - 14
18472	14133K	ELUS_LOCAUX	2022-01-20 12:30:00	2022-01-20 14:00:00	rdv Maire de Campagnolles / VP Région Normandie
18476	14133K	REU_TRAV_PARL	2022-01-14 10:30:00	2022-01-14 12:30:00	rdv permanence parlementaire
18474	14133K	ORG_POL	2022-01-18 17:30:00	2022-01-18 19:30:00	CNI Les Républicains - Paris
18475	14133K	REU_TRAV_PARL	2022-01-17 09:30:00	2022-01-17 11:00:00	rdv permanence parlementaire
18480	14133K	ELUS_LOCAUX	2022-01-13 09:30:00	2022-01-13 12:00:00	rdv élus locaux 14 - permanence parlementaire
18478	14133K	COLL_TER	2022-01-14 14:00:00	2022-01-14 16:00:00	Visite dispositif Région Normandie - Les Isles Bardel
18479	14133K	ORG_POL	2022-01-14 18:30:00	2022-01-14 19:30:00	Lancement comité de soutien Calvados Pécresse 2022 - Caen
18481	14133K	REU_TRAV_PARL	2022-01-13 14:00:00	2022-01-13 15:30:00	rdv permanence parlementaire
18482	14133K	ORG_POL	2022-01-12 10:30:00	2022-01-12 12:00:00	Groupe de travail M. Barnier-Présidentielle Pécresse 2022
18483	14133K	ORG_POL	2022-01-11 11:00:00	2022-01-11 12:30:00	Réunion du Groupe LR Sénat
18484	14133K	REU_TRAV_PARL	2022-01-10 09:30:00	2022-01-10 11:00:00	rdv permanence parlementaire
18485	14133K	REU_TRAV_PARL	2022-01-10 12:00:00	2022-01-10 14:30:00	Réunion chambre des Notaires du Calvados Caen
18486	14133K	ORG_POL	2022-01-04 11:00:00	2022-01-04 12:30:00	Réunion du Groupe LR Sénat
18487	14133K	REU_TRAV_PARL	2021-12-17 08:00:00	2021-12-17 10:00:00	Conférence sur la puissance chinoise en Europe - Vire
18489	14133K	COLL_TER	2021-12-17 17:00:00	2021-12-17 18:00:00	Visite équipement culturel Verson
18496	14133K	DEPL_PRES_GVT	2021-12-10 14:30:00	2021-12-10 16:30:00	Visite Mme Elisabeth BORNE - Condé-en-Normandie
18497	14133K	REU_TRAV_PARL	2021-12-09 19:00:00	2021-12-09 21:00:00	Conférence sur la puissance chinoise en Europe - Rouen
18498	14133K	ORG_POL	2021-12-08 11:00:00	2021-12-08 12:00:00	CNI Les Républicains - Paris
18499	14133K	REU_TRAV_PARL	2021-12-08 12:30:00	2021-12-08 14:00:00	Résidence de l'EM Marine Nationale
18500	14133K	ORG_POL	2021-12-07 18:00:00	2021-12-07 20:00:00	CNI Les Républicains - Paris
18501	14133K	ORG_POL	2021-12-07 10:30:00	2021-12-07 11:30:00	Réunion du Groupe LR Sénat
18130	11066Q	CEREMONIE	2021-11-11 10:50:00	2021-11-11 12:00:00	Cérémonie en hommage aux Morts pour la France (103ème anniversaire de l'armistice du 11 novembre 1918)
18131	11066Q	ACC_VISIT	2021-11-12 09:00:00	2021-11-12 17:00:00	Permanence
18132	11066Q	ACC_VISIT	2021-11-15 09:00:00	2021-11-15 17:00:00	Permanence
18133	11066Q	REU_TRAV_PARL	2021-11-15 11:30:00	2021-11-15 12:00:00	Réunion de groupe
18134	11066Q	REU_TRAV_PARL	2021-11-16 10:30:00	2021-11-16 12:30:00	Réunion de groupe
18135	11066Q	ACC_VISIT	2021-11-16 12:30:00	2021-11-16 14:00:00	Déjeuners des Maires de Loire-Atlantique dans le cadre du Congrès des Maires
18136	11066Q	ACC_VISIT	2021-11-19 09:00:00	2021-11-19 17:00:00	Permanence
18137	11066Q	ACC_VISIT	2021-11-19 10:15:00	2021-11-19 11:15:00	Rencontre avec Monsieur Lepeix sur la réhjabilitation des fusillés pour l'exemplie de la Première Guerre mondiale
18138	11066Q	ACC_VISIT	2021-11-19 14:30:00	2021-11-19 15:30:00	Entretien sur la France et le régime semi-présidentiel
18139	01058X	ORG_POL	2021-11-30 10:30:00	2021-11-30 12:30:00	Réunion de Groupe Les Républicains au Sénat
18140	01058X	ORG_POL	2021-12-07 10:30:00	2021-12-07 11:30:00	Réunion de Groupe Les Républicains au Sénat
18141	11066Q	ACC_VISIT	2021-11-22 09:00:00	2021-11-22 17:00:00	Permanence
18142	11066Q	REU_TRAV_PARL	2021-11-22 11:30:00	2021-11-22 12:30:00	Réunion de groupe
18143	01058X	ELUS_LOCAUX	2021-10-29 10:00:00	2021-10-29 14:00:00	 Assemblée Génnérale anciens Maires de Haute-Marne
18144	11066Q	REU_TRAV_PARL	2021-11-23 10:30:00	2021-11-23 13:00:00	Réunion de groupe
18145	11066Q	ACC_VISIT	2021-11-25 13:30:00	2021-11-25 17:00:00	Permanence
18146	01058X	CEREMONIE	2021-12-06 00:00:00	2021-12-06 00:00:00	 Inauguration Maison de l'agriculture à Chaumont
18147	11066Q	COLL_TER	2021-11-25 18:30:00	2021-11-25 19:00:00	Audio conférence: Point Covid en Loire-Atlantique
18148	11066Q	COLL_TER	2021-11-26 11:00:00	2021-11-26 12:00:00	Entretien avec le commissaire régional délégué aux restructurations d'entreprises
18149	11066Q	CEREMONIE	2021-11-26 12:30:00	2021-11-26 14:00:00	Inauguration des locaux du Secours populaire français de Loire-Atlantique avec le bénévoles
18150	11066Q	ACC_VISIT	2021-11-26 15:00:00	2021-11-26 17:00:00	Permanence
18151	11066Q	ACC_VISIT	2021-11-29 09:00:00	2021-11-29 17:00:00	Permanence
18152	11066Q	REU_TRAV_PARL	2021-11-29 11:30:00	2021-11-29 12:00:00	Réunion de groupe
18153	11066Q	ACC_VISIT	2021-12-03 09:00:00	2021-12-03 17:00:00	Permanence
18154	11066Q	ACC_VISIT	2021-12-03 15:00:00	2021-12-03 16:00:00	Entretien avec le commandant de la compagnie de gendarmerie maritime de Lorient
18155	11066Q	ACC_VISIT	2021-12-06 09:00:00	2021-12-06 17:00:00	Permanence
18156	11066Q	REU_TRAV_PARL	2021-12-07 10:30:00	2021-12-07 13:00:00	Réunion de groupe
18157	11066Q	ORGEXTPAR	2021-12-07 00:00:00	2021-12-07 00:00:00	Entretien préparation CNCTR
18158	11066Q	ACC_VISIT	2021-12-10 09:00:00	2021-12-10 17:00:00	Permanence
18181	04042C	ACC_DEPL_INTER	2021-12-08 18:30:00	2021-12-08 19:30:00	Rencontre avec l'Ambassadeur du Qatar à l'occasion de la journée nationale du 50ème anniversaire de l'accession au pouvoir de Sheikh Jassin bin Mohamed bin Thani, Fondateur de l'Etat du Qatar
18182	04042C	DEPL_PRES_GVT	2021-12-09 00:00:00	2021-12-09 00:00:00	Déplacement en Grèce avec le Président du Sénat
18183	04042C	DEPL_PRES_GVT	2021-12-10 00:00:00	2021-12-10 00:00:00	Déplacement en Grèce avec le Président du Sénat
18184	04042C	ACC_VISIT	2021-12-13 07:15:00	2021-12-13 08:00:00	Emission La Matinale de Public Sénat
18185	04042C	ORG_POL	2021-12-13 08:45:00	2021-12-13 09:40:00	Réunion du bureau politique des L.R du Val-de-Marne
18186	04042C	ELUS_LOCAUX	2021-12-13 10:00:00	2021-12-13 11:00:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
18187	04042C	COLL_TER	2021-12-13 16:00:00	2021-12-13 17:30:00	éunion de la  Commission Relations Internationales et Solidarité du Syndicat des Eaux d'Ile-de-France
18188	04042C	ORG_POL	2021-12-14 11:00:00	2021-12-14 12:30:00	Réunion de Groupe des Sénateurs L.R au Sénat
18189	04042C	ACC_VISIT	2021-12-14 15:30:00	2021-12-14 16:30:00	Entretien avec un élu du Val-de-Marne
18190	04042C	REU_TRAV_PARL	2021-12-14 13:00:00	2021-12-14 14:15:00	Réunion de la Commission des Affaires étrangères, de la Défense et des Forces armées
18191	04042C	ORG_POL	2021-12-14 19:00:00	2021-12-14 20:00:00	Réunion de la Commission Nationale d'Investitures Les Républicains
18281	04042C	ACC_DEPL_INTER	2022-01-12 07:50:00	2022-01-12 09:00:00	Entretien avec le Président du Sénat et le Président du Parlement Serbe
18282	04042C	ELUS_LOCAUX	2022-01-12 13:00:00	2022-01-12 14:15:00	Entretien avec des élus du Val-de-Marne
18283	04042C	REU_TRAV_PARL	2022-01-12 17:00:00	2022-01-12 18:00:00	Conférence des Présidents
18287	04042C	ELUS_LOCAUX	2022-01-14 11:00:00	2022-01-14 14:15:00	Rencontre avec un élu du Val-de-Marne
18285	04042C	CEREMONIE	2022-01-13 19:30:00	2022-01-13 21:30:00	Rencontre officielle à l'occasion de la Présidence française du Conseil de l'Union européenne
18286	04042C	COLL_TER	2022-01-14 08:45:00	2022-01-14 11:00:00	Réunion du bureau du Syndicat des Eaux d'Ile-de-France
18288	04042C	REU_TRAV_PARL	2022-01-14 15:00:00	2022-01-14 16:30:00	Entretien avec le Président du Groupe Renault et un Maire du Val-de-Marne
18289	04042C	ACC_VISIT	2022-01-17 16:30:00	2022-01-17 17:30:00	Entretien avec une Délégation ONG sur le Contrôle des exportations d'armement
18290	04042C	CEREMONIE	2022-01-17 18:30:00	2022-01-17 19:30:00	Cérémonie du Ravivage de la Flamme à l'occasion du 80ème anniversaire du Bureau central du renseignement et d'action et 40 ème anniversaire de la DGSE
18291	04042C	ORG_POL	2022-01-18 11:00:00	2022-01-18 12:30:00	Réunion de groupe des Sénateurs LR du Sénat
18292	04042C	ACC_VISIT	2022-01-18 15:00:00	2022-01-18 16:00:00	Entretien avec le Président d'un CAF du Val-de-Marne
18293	04042C	ACC_VISIT	2022-01-18 16:00:00	2022-01-18 17:00:00	Entretien avec le Délégué général de la FNAM
18294	04042C	REU_TRAV_PARL	2022-01-18 17:00:00	2022-01-18 18:00:00	Réunion de Direction
18295	04042C	ACC_VISIT	2022-01-18 18:30:00	2022-01-18 19:00:00	Rendez-vous téléphonique avec la Préfète du Val-de-Marne
18296	04042C	ELUS_LOCAUX	2022-01-20 13:00:00	2022-01-20 14:15:00	Rencontre avec des élus du Val-de-Marne
18297	04042C	ACC_DEPL_INTER	2022-01-20 15:00:00	2022-01-20 16:00:00	Entretien avec le nouvel Ambassadeur du Royaume du Maroc en France
18298	04042C	CEREMONIE	2022-01-20 17:45:00	2022-01-20 19:30:00	Discours de rentrée de la Minsitre des armées
18341	04042C	ACC_DEPL_INTER	2022-02-01 14:30:00	2022-02-01 16:00:00	Visioconférence de la commission permanente de l'AP/OTAN
18342	04042C	REU_TRAV_PARL	2022-02-02 12:30:00	2022-02-02 13:00:00	Réunion des commissaires L.R
18343	04042C	ACC_VISIT	2022-02-02 16:40:00	2022-02-02 17:50:00	Interview Public Sénat
18344	04042C	ACC_VISIT	2022-02-02 17:00:00	2022-02-02 17:15:00	Interview téléphonique La dépêche du midi
18345	04042C	COLL_TER	2022-02-02 18:00:00	2022-02-02 19:00:00	Réunion avec la Présidente de la Région d'Ile-de-France
18386	11066Q	ACC_VISIT	2022-01-07 09:00:00	2022-01-07 17:00:00	Permanence
18387	11066Q	ACC_VISIT	2022-01-10 09:00:00	2022-01-10 17:00:00	Permanence
18388	11066Q	REU_TRAV_PARL	2022-01-10 11:30:00	2022-01-10 12:30:00	Réunion de groupe CAED
18389	11066Q	REU_TRAV_PARL	2021-12-14 10:30:00	2021-12-14 12:30:00	Réunion de groupe
18391	11066Q	REU_TRAV_PARL	2022-01-11 10:30:00	2022-01-11 12:30:00	Réunion de groupe
18392	11066Q	ORGEXTPAR	2022-01-13 09:00:00	2022-01-13 12:00:00	CNCTR
18393	11066Q	ACC_VISIT	2022-01-14 09:00:00	2022-01-14 17:00:00	Accueil Permanence
18394	11066Q	ACC_VISIT	2022-01-14 14:30:00	2022-01-14 15:30:00	Entretien avec le Groupement Loire-Atlantique de la Gendarmerie 
18395	11066Q	ACC_VISIT	2022-01-14 15:30:00	2022-01-14 16:30:00	Entretien avec le Commissaire divisionnaire de Saint-Nazaire
18403	11066Q	ACC_VISIT	2022-01-27 15:00:00	2022-01-27 17:00:00	Accueil Permanence
18404	11066Q	ACC_VISIT	2022-01-28 09:00:00	2022-01-28 17:00:00	Accueil Permanence
18406	11066Q	REU_TRAV_PARL	2022-01-31 11:30:00	2022-01-31 12:30:00	Réunion de groupe CAED
18407	11066Q	ORGEXTPAR	2022-01-31 16:00:00	2022-01-31 17:30:00	Réunion de la Commission des élus de la Dotation d'Équipement des Territoires ruraux (DETR)
18410	11066Q	REU_TRAV_PARL	2022-02-02 13:30:00	2022-02-02 14:30:00	Réunion de groupe CAED
18411	11066Q	ORGEXTPAR	2022-02-02 14:30:00	2022-02-02 16:00:00	CNCTR
18412	11066Q	DEPL_PRES_GVT	2022-02-03 15:00:00	2022-02-03 16:00:00	Déplacement officiel d'Olivier Véran à Saint-Nazaire
18413	11066Q	ACC_VISIT	2022-02-04 09:00:00	2022-02-04 17:00:00	Accueil Permanence
18414	11066Q	COLL_TER	2022-02-04 09:30:00	2022-02-04 12:00:00	Réunion du Comité d'Orientation stratégique de l'Étude de zone de la CARENE
19210	04042C	CEREMONIE	2022-06-22 11:30:00	2022-06-22 12:30:00	Cérémonie de commémoration du début de la Guerre de Corée
19211	04042C	ACC_VISIT	2022-06-22 12:45:00	2022-06-22 13:45:00	Rencontre avec un élu du Val-de-Marne
19212	04042C	COLL_TER	2022-06-22 14:00:00	2022-06-22 15:30:00	Réunion de travail du Syndicat des Eaux d'Ile-de-France
19213	04042C	ACC_DEPL_INTER	2022-06-22 16:00:00	2022-06-22 17:00:00	Entretien avec l'Ambassadrice d'Australie en France
19214	04042C	ACC_DEPL_INTER	2022-06-22 18:30:00	2022-06-22 19:30:00	Réception annuelle de l'Attaché de Défense de la Suisse en France
19215	04042C	ACC_DEPL_INTER	2022-06-22 19:45:00	2022-06-22 21:00:00	Rencontre annuelle de soutien aux journalistes de défense
19291	04042C	REU_TRAV_PARL	2022-07-19 10:00:00	2022-07-19 11:00:00	Réunion communication
19292	04042C	ELUS_LOCAUX	2022-07-19 13:00:00	2022-07-19 14:15:00	Rencontre avec un élu du Val-de-Marne
19293	04042C	REU_TRAV_PARL	2022-07-19 18:00:00	2022-07-19 18:45:00	Conférence des Présidents
19294	04042C	ACC_DEPL_INTER	2022-07-19 19:00:00	2022-07-19 20:30:00	Rencontre de la Délégation française PPE
19311	01025N	REU_TRAV_PARL	2022-07-13 14:00:00	2022-07-13 15:00:00	INTEFEL - fruits et légumes frais
19381	04042C	CEREMONIE	2022-09-14 09:30:00	2022-09-14 12:30:00	Visite avec G. Larcher Visite de Gustave Roussy Cancer Campus Grand Paris avec le Président du Sénat
19382	04042C	ACC_VISIT	2022-09-14 13:00:00	2022-09-14 14:30:00	Rencontre avec des élus du Val-de-Marne
19383	04042C	REU_TRAV_PARL	2022-09-14 16:00:00	2022-09-14 17:00:00	réunion de Direction
19384	04042C	ACC_VISIT	2022-09-14 17:00:00	2022-09-14 18:00:00	Entretien avec un journaliste de Public Sénat
19501	04042C	ACC_DEPL_INTER	2022-09-22 09:50:00	2022-09-22 11:00:00	Entretien avec le Président du Sénat et le Président de l'Assemblée nationale de Côte-d'Ivoire
19502	04042C	CEREMONIE	2022-09-22 11:30:00	2022-09-22 12:30:00	Inauguration de la Fontaine Médicis au Jardin du Palais du Luxembourg
19503	04042C	ACC_DEPL_INTER	2022-09-22 18:30:00	2022-09-22 20:30:00	Rencontre avec l'Ambassadeur du Royaume d'Arabie Saoudite en France à l'occasion de la Fête nationale 
19504	04042C	ACC_DEPL_INTER	2022-09-23 12:30:00	2022-09-23 14:00:00	Rencontre avec l'Ambassadeur de Malte en France à l'occasion de la Fête nationale
19505	04042C	CEREMONIE	2022-09-23 14:00:00	2022-09-23 16:00:00	Inauguration du nouveau site du Groupe Safran dans le Val-de-Marne
19506	04042C	ACC_VISIT	2022-09-23 09:30:00	2022-09-23 10:30:00	Entretien avec le Chef d'état-major de l'Armée de l'Air et de l'Espace
19507	04042C	ACC_VISIT	2022-09-23 10:30:00	2022-09-23 11:30:00	En tretien avec un ancien Premier ministre
19508	04042C	REU_TRAV_PARL	2022-09-26 12:30:00	2022-09-26 14:00:00	Rencontre avec le Chef d'état-major de la Marine
19509	04042C	ACC_DEPL_INTER	2022-09-26 15:00:00	2022-09-26 16:00:00	Entretien avec l'Ambassadeur d'Irak en France
19510	04042C	ACC_DEPL_INTER	2022-09-26 18:00:00	2022-09-26 20:00:00	Rencontre avec l'Ambassadeur de Chypre en France à l'occasion du 62ème anniversaire de l'Indépendance de la République de Chypre
19511	04042C	ORG_POL	2022-09-27 11:00:00	2022-09-27 12:00:00	Réunion de Groupe des sénateurs LR du Sénat  
19512	04042C	ACC_VISIT	2022-09-27 12:00:00	2022-09-27 14:30:00	Rencontre avec des élus de Val-de-Marne
19513	04042C	ACC_VISIT	2022-09-27 17:00:00	2022-09-27 18:00:00	Entretien avec le Président de Trenitalia France
19514	04042C	ACC_DEPL_INTER	2022-09-27 18:20:00	2022-09-27 21:30:00	Rencontre avec le Président du Sénat et son homologue du Sénat egyptien
19515	04042C	ACC_DEPL_INTER	2022-09-28 12:30:00	2022-09-28 13:30:00	Entretien avec  le Représentant spécial sud-coréen pour la Paix et les Affaires de sécurité dans la péninsule coréenne
19516	04042C	REU_TRAV_PARL	2022-09-20 08:30:00	2022-09-20 09:30:00	Réunion du GIA France-Italie
19517	04042C	ACC_VISIT	2022-09-20 10:00:00	2022-09-20 11:00:00	Entretien avec un élu du Val-de-Marne
19518	04042C	REU_TRAV_PARL	2022-09-20 13:00:00	2022-09-20 14:15:00	Rencontre avec les Présidents et Référents de commissions, Rapporteur général 
19519	04042C	ACC_DEPL_INTER	2022-09-20 15:00:00	2022-09-20 16:00:00	Entretien avec l'Ambassadeur de Turquie en France
19520	04042C	REU_GVT	2022-09-20 17:30:00	2022-09-20 18:30:00	Entretien avec la Ministre de la Transition énergétique
19521	04042C	COLLOQUE	2022-09-20 19:00:00	2022-09-20 21:00:00	Présentation de l'ouvrage Haut Karabakh : le Livre noir
19522	04042C	ACC_VISIT	2022-09-21 16:00:00	2022-09-21 17:00:00	Entretien avec des élus du Val-de-Marne
19523	04042C	ACC_DEPL_INTER	2022-09-21 18:50:00	2022-09-21 21:30:00	Rencontre avec le Président du Sénat et son homologue du Sénat de Jordanie
19654	14133K	REU_TRAV_PARL	2022-07-12 16:00:00	2022-07-12 17:00:00	Rdv autorité Gendarmerie Nationale
19655	14133K	CEREMONIE	2022-07-13 11:00:00	2022-07-13 12:00:00	Cérémonie Légion Etrangère - Prise d'Armes
19656	14133K	CEREMONIE	2022-08-17 17:30:00	2022-08-17 18:30:00	Commémoration Libération Condé-en-Normandie
19673	14133K	REU_TRAV_PARL	2022-08-25 14:00:00	2022-08-25 16:00:00	meeting of the Group of Friends of the ¿Call for Action ¿ Helsinki +50 Process
19674	14133K	REU_TRAV_PARL	2022-08-25 17:00:00	2022-08-25 18:00:00	rdv individuels permanence parlementaire
19675	14133K	REU_TRAV_PARL	2022-08-26 10:00:00	2022-08-26 11:30:00	rdv individuels permanence parlementaire
19676	14133K	REU_TRAV_PARL	2022-08-26 14:30:00	2022-08-26 15:00:00	point presse départementale
19677	14133K	REU_TRAV_PARL	2022-08-26 15:00:00	2022-08-26 16:30:00	Vision avec la présidence de l'AP-OSCE
19678	14133K	REU_TRAV_PARL	2022-08-29 10:00:00	2022-08-29 12:00:00	rdv individuels permanence parlementaire
19679	14133K	REU_TRAV_PARL	2022-08-29 16:30:00	2022-08-29 17:30:00	rdv individuels permanence parlementaire
19680	14133K	CEREMONIE	2022-08-30 10:00:00	2022-08-30 12:00:00	Cérémonie inhumation élu départemental
19681	14133K	ELUS_LOCAUX	2022-08-30 12:30:00	2022-08-30 14:00:00	Réunion élus Région Normandie
19682	14133K	REU_TRAV_PARL	2022-08-30 14:30:00	2022-08-30 16:30:00	Réunion de travail et Visite Centre de recherche Cyclhade CAEN
19683	14133K	REU_TRAV_PARL	2022-09-01 10:00:00	2022-09-01 12:00:00	Réunion de travail Sotraban et visite site économique - Bayeux
19684	14133K	ORG_POL	2022-09-01 18:00:00	2022-09-01 19:30:00	Réunion du Groupe LR Sénat
19685	14133K	COLL_TER	2022-09-02 09:30:00	2022-09-02 11:30:00	Restitution programme POPSU - Caumont-sur-Aure
19686	14133K	ORG_POL	2022-09-06 09:00:00	2022-09-06 09:45:00	RDV Groupe LR
19687	14133K	REU_TRAV_PARL	2022-09-06 10:00:00	2022-09-06 11:00:00	Réunion de travail délégation AP-OSCE
19688	14133K	REU_TRAV_PARL	2022-09-06 11:30:00	2022-09-06 12:30:00	Rdv Commandement Réserve Gendarmerie Nationale
19693	14133K	REU_TRAV_PARL	2022-09-08 10:00:00	2022-09-08 11:30:00	Réunion de travail Banque alimentaire du Calvados - Bretteville-sur-Odon
19690	14133K	COLL_TER	2022-09-07 15:00:00	2022-09-07 16:30:00	Visite dispositif Région Normandie - Deauville
19691	14133K	COLL_TER	2022-09-07 10:30:00	2022-09-07 12:30:00	Visite dispositif Région Normandie - Falaise
19692	14133K	REU_TRAV_PARL	2022-09-08 09:30:00	2022-09-08 10:00:00	Visite site circuits courts - Bretteville-sur-Odon
19694	14133K	ELUS_LOCAUX	2022-09-08 12:30:00	2022-09-08 14:00:00	Réunion de travail - élus Région Normandie
19695	14133K	COLL_TER	2022-09-08 14:00:00	2022-09-08 15:00:00	Visite dispositif Région Normandie - Lion-sur-Mer
19696	14133K	COLL_TER	2022-09-08 15:30:00	2022-09-08 16:30:00	Visite dispositif Région Normandie - Douvres-la-Délivrande
19697	14133K	REU_TRAV_PARL	2022-09-09 09:00:00	2022-09-09 10:00:00	Rdv autorité préfectorale Calvados
19698	14133K	REU_TRAV_PARL	2022-09-09 10:15:00	2022-09-09 11:30:00	rdv individuels permanence parlementaire
19699	14133K	CEREMONIE	2022-09-09 15:00:00	2022-09-09 17:00:00	Audience solennelle installation Tribunal judiciaire de Caen
19700	14133K	REU_TRAV_PARL	2022-09-12 10:30:00	2022-09-12 11:30:00	Point rentrée scolaire - Collège public Calvados
19701	14133K	REU_TRAV_PARL	2022-09-12 14:00:00	2022-09-12 15:00:00	Point rentrée scolaire - Collège privé Calvados
19702	14133K	REU_TRAV_PARL	2022-09-12 15:30:00	2022-09-12 16:30:00	Point rentrée scolaire - Lycée enseignement général et professionnel Calvados
19703	14133K	ORG_POL	2022-09-15 17:00:00	2022-09-15 22:00:00	Séminaire de rentrée - Groupe parlementaire
19704	14133K	ORG_POL	2022-09-16 08:00:00	2022-09-16 10:00:00	Séminaire de rentrée - Groupe parlementaire
19705	14133K	ORG_POL	2022-09-19 09:30:00	2022-09-19 10:30:00	Réunion de travail - 6e circo LR du Calvados
19706	14133K	REU_TRAV_PARL	2022-09-19 15:00:00	2022-09-19 16:00:00	rdv individuels permanence parlementaire
19707	14133K	REU_TRAV_PARL	2022-09-21 16:00:00	2022-09-21 17:00:00	rdv ambassade - affaires étrangères
19710	14133K	REU_TRAV_PARL	2022-09-27 10:00:00	2022-09-27 15:00:00	Réunion de travail Fidélité Gaulliste Calvados
19721	04042C	REU_TRAV_PARL	2022-10-04 15:00:00	2022-10-04 15:30:00	Entretien avec le Président des Républicains du Sénat
19722	04042C	REU_TRAV_PARL	2022-10-04 15:30:00	2022-10-04 16:30:00	Entretien avec un sénateur
19723	04042C	CEREMONIE	2022-10-04 19:00:00	2022-10-04 20:00:00	Cérémonie de remise des insignes de Chevalier de l'Ordre National du Mérite au Directeur-adjoint de SNCF Voyageurs
19724	04042C	REU_TRAV_PARL	2022-10-05 08:30:00	2022-10-05 09:30:00	Réunion du bureau de la Commission des Affaires étrangères, de la Défense et des Forces armées
19741	04042C	REU_GVT	2022-10-05 16:20:00	2022-10-05 16:45:00	Entretien avec le Secrétaire d'Etat chargé de la Mer
19742	04042C	COLL_TER	2022-10-05 17:00:00	2022-10-05 18:00:00	Réunion avec la Présidente du Conseil régional d'Ile-de-France
19747	04042C	ACC_DEPL_INTER	2022-10-06 15:20:00	2022-10-06 16:30:00	Entretien avec le Président du Sénat et une opposante biélorusse
19744	04042C	REU_TRAV_PARL	2022-10-05 18:30:00	2022-10-05 19:30:00	Conférence des Présidents du Sénat
19745	04042C	ACC_DEPL_INTER	2022-10-05 19:45:00	2022-10-05 20:30:00	Rencontre avec l'Ambassadeur d'Allemagne en France à l'occasion de la journée de l'unité allemande
19746	04042C	ACC_DEPL_INTER	2022-10-05 20:45:00	2022-10-05 13:00:00	Evénement annuel de rentrée du GICAT
19748	04042C	ACC_VISIT	2022-10-06 17:00:00	2022-10-06 18:00:00	Rencontre avec un élu du Val-de-Marne
19749	04042C	COLL_TER	2022-10-06 18:30:00	2022-10-06 20:30:00	Réunion de la Commission urbanisme, aménagement, habitat et politique de la ville du Val-de-Marne
19750	04042C	COLL_TER	2022-10-07 08:45:00	2022-10-07 11:00:00	Réunion du bureau du Syndicat des Eaux d'Ile-de-France
19754	04042C	REU_TRAV_PARL	2022-10-07 15:30:00	2022-10-07 16:30:00	Réunion de travail avec le Gouvernement
19752	04042C	REU_TRAV_PARL	2022-10-07 12:00:00	2022-10-07 13:00:00	Réunion de direction
19753	04042C	ACC_DEPL_INTER	2022-10-07 13:00:00	2022-10-07 14:15:00	Rencontre avec le Président du Groupe d'Amitié Maroc-France
19755	04042C	ACC_DEPL_INTER	2022-10-07 16:30:00	2022-10-07 17:30:00	Entretien avec l'Ambassadeur de Pologne en France
19756	04042C	CEREMONIE	2022-10-07 18:30:00	2022-10-07 19:30:00	Inauguration d'un nouveau gymnase à Bry-sur-Marne
19757	04042C	ELUS_LOCAUX	2022-10-10 13:00:00	2022-10-10 15:00:00	Rencontres avec des élus du Val-de-Marne
19758	04042C	ACC_DEPL_INTER	2022-10-10 15:00:00	2022-10-10 15:30:00	Entretien avec la Présidente  de la délégation française de l'AP/OTAN
19759	04042C	COLL_TER	2022-10-10 19:00:00	2022-10-10 21:00:00	Réunion du Conseil de Territoire
19763	04042C	REU_TRAV_PARL	2022-10-11 08:30:00	2022-10-11 09:30:00	Entretien avec un directeur général de l'Industrie de l'armement
19764	04042C	CEREMONIE	2022-10-11 10:00:00	2022-10-11 12:00:00	Cérémonie du 40ème anniversaire de la DGSE en présence du Ministre des Armées
19768	04042C	ACC_VISIT	2022-10-12 10:00:00	2022-10-12 11:00:00	Entretien avec un journaliste spécialisé dans les questions militaires, stratégiques et internationales
19766	04042C	ACC_DEPL_INTER	2022-10-11 20:30:00	2022-10-11 22:00:00	Entretien avec l'Ambassadrice de Moldavie en France
19767	04042C	ACC_DEPL_INTER	2022-10-11 19:45:00	2022-10-11 20:15:00	Rencontre avec l'Ambassadeur d'Espagne en France à l'occasion de la Fête nationale
19769	04042C	ACC_DEPL_INTER	2022-10-12 11:00:00	2022-10-12 12:00:00	Entretien avec la future Ambassadrice de France en Hongrie
19770	04042C	ACC_DEPL_INTER	2022-10-12 13:00:00	2022-10-12 14:30:00	Rencontre avec l'Ambassadeur du Brésil en France et des sénateurs
19771	04042C	ACC_VISIT	2022-10-12 19:00:00	2022-10-12 22:30:00	Visite du palais du Luxembourg d'un Conseil municipal du Val-de-Marne
19772	04042C	COLL_TER	2022-10-13 10:00:00	2022-10-13 14:00:00	Réunion du Comité du Syndicat des Eaux d'Ile-de-France
19773	04042C	ACC_VISIT	2022-10-13 09:15:00	2022-10-13 09:30:00	Interview téléphonique Public Sénat
19774	04042C	ORG_POL	2022-10-13 19:30:00	2022-10-13 21:00:00	Réunion de rentrée politique dans le Val-de-Marne
19775	04042C	ACC_DEPL_INTER	2022-10-13 09:00:00	2022-10-13 10:00:00	Séminaire stratégique franco-polonais
19801	04042C	ORG_POL	2022-10-24 18:45:00	2022-10-24 19:30:00	Réunion politique avec le Président des L.R du Sénat dans le Val-de-Marne
19802	04042C	ACC_DEPL_INTER	2022-10-24 20:00:00	2022-10-24 21:30:00	Rencontre avec le Président du Sénat et le Président du Sénat ivoirien
19803	04042C	ACC_DEPL_INTER	2022-10-21 14:30:00	2022-10-21 15:30:00	Entretien avec la Ministre des Affaires étrangères centrafricaine
19804	04042C	ACC_DEPL_INTER	2022-10-25 10:00:00	2022-10-25 11:00:00	Entretien avec l'Ambassadeur de Chypre en France
19805	04042C	ORG_POL	2022-10-25 11:00:00	2022-10-25 11:45:00	Réunion de Groupe des sénateurs LR du Sénat
19806	04042C	ACC_DEPL_INTER	2022-10-25 12:15:00	2022-10-25 12:45:00	Rencontre avec l'Ambassadeur de la République tchèque à l'occasion de la Fête nationale
19807	04042C	ACC_DEPL_INTER	2022-10-25 13:00:00	2022-10-25 14:30:00	Rencontre avec l'Ambassadeur de Turquie en France et des sénateurs membres de la Commission des Affaires étrangères, de la Défense et des Forces armées
19808	04042C	ACC_DEPL_INTER	2022-10-25 15:30:00	2022-10-25 16:00:00	Entretien avec le Représentant du Gouvernement régional du Kurdistan-Irak
19809	04042C	REU_GVT	2022-10-25 17:30:00	2022-10-25 18:30:00	Réunion de travail avec le Ministre des Armées
19810	04042C	REU_GVT	2022-10-25 20:00:00	2022-10-25 21:30:00	Réunion de travail avec la Ministre de l'Europe et des Affaires étrangères et les sénateurs membres de la Commission des Affaires étrangères, de la Défense et des Forces armées
19811	04043D	DEL_ACT_PAR	2022-09-12 08:00:00	2022-09-12 20:00:00	Déplacement - Groupe d'amitié
19812	01025N	REU_TRAV_PARL	2022-10-26 08:00:00	2022-10-26 09:00:00	Rencontre FNSEA
19813	01025N	REU_TRAV_PARL	2022-10-25 13:30:00	2022-10-25 14:30:00	audition Légumes de France
19814	01025N	REU_TRAV_PARL	2022-10-19 08:00:00	2022-10-19 10:00:00	rencontre MSA
19815	01025N	ACC_DEPL_INTER	2022-10-18 09:30:00	2022-10-18 11:00:00	audition Etienne de Poncins - groupe France-Ukraine
19816	01025N	ORG_POL	2022-10-18 19:00:00	2022-10-18 21:30:00	Bureau UDI
19817	01025N	REU_TRAV_PARL	2022-10-12 13:30:00	2022-10-12 15:00:00	Audition Open Agrifood
19818	01025N	DEPL_PRES_GVT	2022-10-27 16:00:00	2022-10-27 18:30:00	Visite ministérielle Marc Fesneau Ministre de l'Agriculture à Matougues
19821	11103C	ORG_POL	2022-11-02 14:00:00	2022-11-02 15:00:00	Groupe LR du Sénat
19841	04042C	ACC_DEPL_INTER	2022-10-27 12:00:00	2022-10-27 13:00:00	Entretien avec le Président du Sénat et l'Ambassadeur du Royaume du Maroc en France
19842	04042C	DEPL_PRES_GVT	2022-10-27 21:00:00	2022-10-27 00:00:00	Visite officielle en Corée 
19843	04042C	DEPL_PRES_GVT	2022-10-28 00:00:00	2022-10-28 00:00:00	Visite officielle en Corée
19844	04042C	DEPL_PRES_GVT	2022-10-31 00:00:00	2022-10-31 00:00:00	Visite officielle en Corée
19848	04042C	ACC_DEPL_INTER	2022-11-02 19:30:00	2022-11-02 20:30:00	Rencontre avec l'Ambassadeur de Norvège en France à l'occasion de la visite en France de la Commission des Affaires étrangères et de la Défense du Parlement norvégien
19846	04042C	DEPL_PRES_GVT	2022-11-01 00:00:00	2022-11-01 18:30:00	Visite officielle en Corée
19847	04042C	REU_TRAV_PARL	2022-11-02 18:00:00	2022-11-02 19:00:00	Conférence des Présidents
19849	04042C	ACC_VISIT	2022-11-03 13:30:00	2022-11-03 14:45:00	Emission Un monde en doc Public Sénat
19850	04042C	COLL_TER	2022-11-03 15:30:00	2022-11-03 16:30:00	Entretien avec le Préfet de la Région Ile-de-France
19851	04042C	REU_TRAV_PARL	2022-11-03 17:00:00	2022-11-03 18:00:00	Réunion de travail parlementaire
19852	04042C	ACC_DEPL_INTER	2022-11-03 19:30:00	2022-11-03 21:30:00	Rencontre avec l'Ambassadeur d'Irak en France
19861	04042C	ACC_VISIT	2022-11-07 19:00:00	2022-11-07 22:00:00	Visite du palais du Luxembourg d'un Conseil municipal du Val-de-Marne
19862	04042C	ELUS_LOCAUX	2022-11-07 10:45:00	2022-11-07 12:00:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
19863	04042C	ACC_VISIT	2022-11-07 17:15:00	2022-11-07 18:00:00	Entretien avec la Rédactrice en chef Financial Times
19864	04042C	ACC_VISIT	2022-11-07 18:00:00	2022-11-07 18:45:00	Entretien avec un élu du val-de-Marne
19865	04042C	ACC_VISIT	2022-11-04 07:15:00	2022-11-04 08:00:00	Emission Bienvenue Chez vous de Public Sénat
19866	04042C	ACC_VISIT	2022-11-04 08:30:00	2022-11-04 09:30:00	Interview télévisée de JTBC, télévision coréenne
19133	11066Q	CEREMONIE	2022-03-28 11:00:00	2022-03-28 12:30:00	Cérémonie du 80ème anniversaire du raid des commandos britanniques sur Saint-Nazaire (Opération Chariot)
19134	11066Q	DEPL_PRES_GVT	2022-03-31 14:00:00	2022-03-31 16:00:00	Réunion à Naval Group sur les innovations dans le domaine de la défense navale
19139	11066Q	ORGEXTPAR	2022-04-07 09:00:00	2022-04-07 12:00:00	Réunion Plénière de la Commission nationale des Techniques de Renseignement
19140	11066Q	ELUS_LOCAUX	2022-04-07 18:00:00	2022-04-07 19:00:00	Visoconférence de la préfecture de Loire-Atlantique sur l'accueil des réfugiés ukrainiens
19142	11066Q	ACC_VISIT	2022-04-11 09:00:00	2022-04-11 17:00:00	Accueil Permanence
19143	11066Q	REU_TRAV_PARL	2022-04-12 10:30:00	2022-04-12 11:30:00	Réunion de groupe
19144	11066Q	ACC_VISIT	2022-04-13 09:00:00	2022-04-13 12:00:00	Accueil Permanence
19145	11066Q	ACC_VISIT	2022-04-14 09:00:00	2022-04-14 17:00:00	Accueil Permanence
19146	11066Q	ACC_VISIT	2022-04-15 09:00:00	2022-04-15 17:00:00	Accueil Permanence
19147	11066Q	ACC_VISIT	2022-04-18 09:00:00	2022-04-18 17:00:00	Accueil Permanence
19148	11066Q	ACC_VISIT	2022-04-19 09:00:00	2022-04-19 17:00:00	Accueil Permanence
19149	11066Q	ACC_VISIT	2022-04-20 09:00:00	2022-04-20 17:00:00	Accueil Permanence
19150	11066Q	ACC_VISIT	2022-04-21 09:00:00	2022-04-21 17:00:00	Accueil Permanence
19151	11066Q	ACC_VISIT	2022-04-22 09:00:00	2022-04-22 17:00:00	Accueil Permanence
19152	11066Q	CEREMONIE	2022-04-22 11:00:00	2022-04-22 12:30:00	Commémoration de la Journée nationale du souvenir des victimes et des héros de la Déportation
19153	11066Q	ACC_VISIT	2022-04-25 09:00:00	2022-04-25 17:00:00	Accueil Permanence
19154	11066Q	REU_TRAV_PARL	2022-04-26 10:30:00	2022-04-26 11:30:00	Réunion de groupe
19164	11066Q	ACC_VISIT	2022-05-09 09:00:00	2022-05-09 12:30:00	Accueil Permanence
19165	11066Q	ACC_VISIT	2022-05-09 15:30:00	2022-05-09 17:00:00	Accueil Permanence
19166	11066Q	ACC_VISIT	2022-05-11 09:00:00	2022-05-11 17:00:00	Accueil Permanence
19167	11066Q	ACC_VISIT	2022-05-12 11:00:00	2022-05-12 14:30:00	Déplacement dans le Pays de Retz pour rencontrer les membres du Collectif Stop aux cancers de nos enfants
19168	11066Q	ACC_VISIT	2022-05-12 15:00:00	2022-05-12 17:00:00	Accueil Permanence
19169	11066Q	ACC_VISIT	2022-05-13 09:00:00	2022-05-13 12:30:00	Accueil Permanence
19170	11066Q	ACC_VISIT	2022-05-13 16:00:00	2022-05-13 17:00:00	Accueil Permanence
19171	11066Q	ACC_VISIT	2022-05-16 09:00:00	2022-05-16 17:00:00	Accueil Permanence
19172	11066Q	ACC_VISIT	2022-05-17 09:00:00	2022-05-17 17:00:00	Accueil Permanence
19175	11066Q	REU_TRAV_PARL	2022-05-24 10:30:00	2022-05-24 11:30:00	Réunion de groupe
19176	11066Q	ACC_VISIT	2022-05-25 09:00:00	2022-05-25 17:00:00	Accueil Permanence
19181	11066Q	ACC_VISIT	2022-06-03 09:00:00	2022-06-03 17:00:00	Accueil Permanence
19182	11066Q	ACC_VISIT	2022-06-07 09:00:00	2022-06-07 17:00:00	Accueil Permanence
19184	11066Q	ACC_VISIT	2022-06-10 09:00:00	2022-06-10 17:00:00	Accueil Permanence
19186	11066Q	ACC_VISIT	2022-06-14 09:00:00	2022-06-14 12:00:00	Accueil Permanence
19187	11066Q	ACC_VISIT	2022-06-14 17:30:00	2022-06-14 18:30:00	Entretien avec Mme Laurence Huc, chercheuse en toxicologie à propos du foyer de cancers pédiatrique dans le Pays de Retz
19188	04042C	ACC_VISIT	2022-06-16 13:00:00	2022-06-16 14:30:00	Rencontre avec un élu du Val-de-Marne
19189	04042C	ACC_VISIT	2022-06-16 15:00:00	2022-06-16 16:00:00	Entretien avec un élu du Val-de-Marne
19190	04042C	ACC_DEPL_INTER	2022-06-16 16:00:00	2022-06-16 17:00:00	Entretien avec l'Ambassadrice de Géorgie en France
19221	04042C	COLL_TER	2022-06-23 10:00:00	2022-06-23 12:30:00	Réunion du Comité du Syndicat des Eaux d'Ile-de-France
19222	04042C	ACC_DEPL_INTER	2022-06-23 13:00:00	2022-06-23 14:30:00	Rencontre avec la Présidente de la Commission des Affaires étrangères du Sénat italien
19223	04042C	ACC_DEPL_INTER	2022-06-23 16:00:00	2022-06-23 17:00:00	Entretien avec l'Ambassadeur du Danemark en France
19224	04042C	ACC_VISIT	2022-06-23 17:00:00	2022-06-23 18:00:00	entretien avec un élu du Val-de-Marne
19225	04042C	COLL_TER	2022-06-23 18:30:00	2022-06-23 20:00:00	Réunion de la Commission Environnement, Eau et Assainissement de Paris Est Marne & Bois
19226	04042C	ELUS_LOCAUX	2022-06-24 13:00:00	2022-06-24 14:30:00	Rencontre avec des élus du Val-de-Marne
19295	04042C	ACC_DEPL_INTER	2022-07-20 10:00:00	2022-07-20 10:45:00	Entretien avec l'Ambassadeur du Liban en France
19296	04042C	REU_TRAV_PARL	2022-07-20 19:30:00	2022-07-20 20:15:00	Rencontre avec le Président du Sénat et les sénateurs à l'occasion de la fin de session
19297	04042C	REU_GVT	2022-07-20 20:30:00	2022-07-20 22:00:00	Rencontre avec la Secrétaire d'Etat auprès de la ministre de l¿Europe et des Affaires étrangères, chargée du Développement, de la Francophonie et des Partenariats internationaux
19298	04042C	ACC_VISIT	2022-07-21 10:15:00	2022-07-21 10:45:00	Interview Acteurs Publics
19299	04042C	ACC_VISIT	2022-07-21 10:45:00	2022-07-21 11:00:00	Interview Public Sénat
19321	04042C	ELUS_LOCAUX	2022-07-27 13:00:00	2022-07-27 14:15:00	Rencontre avec des élus du Val-de-Marne
19322	04042C	REU_GVT	2022-07-28 14:45:00	2022-07-28 16:00:00	Entretien avec le ministre chargé des Relations avec le Parlement
19525	14133K	COLL_TER	2022-02-21 10:30:00	2022-02-21 12:00:00	rdv permanence parlementaire
19526	14133K	COLL_TER	2022-02-21 14:30:00	2022-02-21 16:30:00	rdv permanence parlementaire
19527	14133K	ORG_POL	2022-02-22 11:00:00	2022-02-22 12:30:00	Réunion du Groupe LR Sénat
19576	14133K	REU_TRAV_PARL	2022-04-05 10:00:00	2022-04-05 16:30:00	Visite Président JF Rapin dans le Calvados - thématique Transmanche et pêche - Ouistreham - Caen - Trouville-sur-Mer
19529	14133K	ORG_POL	2022-02-22 17:30:00	2022-02-22 19:00:00	CNI Les Républicains - Paris
19530	14133K	ACC_VISIT	2022-02-22 13:00:00	2022-02-22 15:00:00	Accueil au Sénat délégation Réserve citoyenne du Calvados-Présentation des missions
19577	14133K	ORG_POL	2022-04-05 18:30:00	2022-04-05 20:00:00	Réunion électorale - LR 14 - CAEN
19603	14133K	ELUS_LOCAUX	2022-05-06 09:30:00	2022-05-06 15:00:00	AG Union amicale des maires du Calvados - Honfleur
19604	14133K	REU_TRAV_PARL	2022-05-09 16:15:00	2022-05-09 17:30:00	Rdv autorité préfectorale Calvados
19605	14133K	ORG_POL	2022-05-10 11:00:00	2022-05-10 12:30:00	Réunion du Groupe LR Sénat
19606	14133K	REU_TRAV_PARL	2022-05-12 09:30:00	2022-05-12 10:00:00	Rdv téléphonique autorité préfectorale
19607	14133K	REU_TRAV_PARL	2022-05-12 15:30:00	2022-05-12 16:30:00	Rdv autorité locale
19608	14133K	REU_TRAV_PARL	2022-05-12 17:00:00	2022-05-12 18:00:00	Visio AP OSCE - Présidence
19609	14133K	REU_TRAV_PARL	2022-05-13 09:15:00	2022-05-13 11:30:00	rencontre et échanges avec élèves Collège Calvados
19610	14133K	REU_TRAV_PARL	2022-05-16 10:30:00	2022-05-16 11:30:00	Rendez-vous responsables  économiques permanence parlementaire dans le Calvados
19611	14133K	ELUS_LOCAUX	2022-05-16 14:45:00	2022-05-16 15:30:00	Rencontre élus Suisse Normande
19612	14133K	ELUS_LOCAUX	2022-05-16 16:30:00	2022-05-16 17:00:00	rdv Maire Calvados
19613	14133K	ORG_POL	2022-05-17 18:30:00	2022-05-17 20:00:00	lancement campagne électorale 3e circo du Calvados
19614	14133K	REU_TRAV_PARL	2022-05-18 14:30:00	2022-05-18 15:30:00	rdv individuels permanence parlementaire
19615	14133K	REU_TRAV_PARL	2022-05-18 17:30:00	2022-05-18 19:00:00	Visio - Bureau  AP OSCE -
19616	14133K	REU_TRAV_PARL	2022-05-19 09:30:00	2022-05-19 22:00:00	Accueil dans le Calvados de SE J. Galiev, ambassadeur du Kazakhstan en France - visites économiques et institutionnelles
19617	14133K	REU_TRAV_PARL	2022-05-20 09:00:00	2022-05-20 17:30:00	2e jour - visite dans le Calvados de SE J. Galiev, ambassadeur du Kazakhstan en France - visites économiques et institutionnelles
19618	14133K	REU_TRAV_PARL	2022-05-25 16:30:00	2022-05-25 17:30:00	Visio - AP OSCE - délégation française
19619	14133K	ELUS_LOCAUX	2022-06-02 16:15:00	2022-06-02 18:00:00	Visite du Président Larcher dans le Calvados - Courseulles-sur-Mer
19620	14133K	ORG_POL	2022-06-02 18:30:00	2022-06-02 20:00:00	réunion électorale - Courseulles sur Mer
19621	14133K	CEREMONIE	2022-06-03 10:00:00	2022-06-03 12:00:00	Cérémonie des enfants DDay 2022 - Courseulles sur Mer
19622	14133K	CEREMONIE	2022-06-07 11:00:00	2022-06-07 12:30:00	Commémoration Libération de Bayeux
19623	14133K	CEREMONIE	2022-06-07 14:30:00	2022-06-07 17:00:00	Commémoration Bataille de Normandie - CAEN
19624	14133K	CEREMONIE	2022-06-07 18:15:00	2022-06-07 18:45:00	Commémoration Bataille de Normandie - Bretteville l'Orgueilleuse
19625	14133K	CEREMONIE	2022-06-08 09:45:00	2022-06-08 10:30:00	Commémoration Morts pour la France en Indochine - Trouville-sur-Mer
19626	14133K	CEREMONIE	2022-06-08 11:00:00	2022-06-08 12:00:00	Commémoration Morts pour la France en Indochine - Villers-sur-Mer
19261	11103C	ORG_POL	2022-07-12 11:00:00	2022-07-12 12:30:00	Groupe LR du Sénat
19424	11066Q	REU_TRAV_PARL	2022-07-05 10:30:00	2022-07-05 12:30:00	Réunion de groupe
19262	04042C	ELUS_LOCAUX	2022-07-12 18:00:00	2022-07-12 19:00:00	Premier jury du concours du Capitole à Saint-Maurice
19263	04042C	REU_TRAV_PARL	2022-07-12 19:30:00	2022-07-12 20:00:00	Rencontre avec les sénateurs Les Républicains
19264	04042C	ELUS_LOCAUX	2022-07-12 20:15:00	2022-07-12 22:00:00	Rencontre avec des élus du Val-de-Marne
19341	04042C	ORG_POL	2022-08-02 11:00:00	2022-08-02 12:30:00	Réunion de Groupe des sénateurs L.R du sénat
19627	14133K	ELUS_LOCAUX	2022-06-08 14:30:00	2022-06-08 17:45:00	Rdv maires du Calvados
19343	04042C	ACC_VISIT	2022-08-03 12:30:00	2022-08-03 14:00:00	Rencontre avec un élu du Val-de-Marne
19344	04042C	REU_GVT	2022-08-04 13:30:00	2022-08-04 15:30:00	Réunion du Comité de liaison avec la Première ministre
19628	14133K	ORG_POL	2022-06-08 18:00:00	2022-06-08 20:30:00	Réunion électorale - 4e circo du Calvados
19629	14133K	REU_TRAV_PARL	2022-06-09 09:30:00	2022-06-09 10:30:00	rdv individuels permanence parlementaire
19630	14133K	REU_TRAV_PARL	2022-06-09 15:00:00	2022-06-09 16:00:00	Rdv téléphonique - GIA Pakistan
19631	14133K	REU_TRAV_PARL	2022-06-09 16:15:00	2022-06-09 17:30:00	rdv individuels permanence parlementaire
19632	14133K	REU_TRAV_PARL	2022-06-09 17:30:00	2022-06-09 18:00:00	Rdv téléphonique - AP OSCE - Règlement
19633	14133K	REU_TRAV_PARL	2022-06-10 14:00:00	2022-06-10 16:00:00	Visio conférence - AP-OSCE - Les Routes de la Soie - 
19634	14133K	CEREMONIE	2022-06-14 10:30:00	2022-06-14 14:30:00	Cérémonie et réunion de travail avec Fidélité Gaulliste - Graye-sur-Mer
19635	14133K	REU_TRAV_PARL	2022-06-16 15:00:00	2022-06-16 16:00:00	rdv individuels permanence parlementaire
19636	14133K	ORG_POL	2022-06-16 20:00:00	2022-06-16 21:30:00	réunion électorale - Le Hom
19637	14133K	REU_TRAV_PARL	2022-06-17 09:15:00	2022-06-17 10:00:00	rdv individuels permanence parlementaire
19638	14133K	COLL_TER	2022-06-17 10:00:00	2022-06-17 11:30:00	AG Fnaca Calvados
19639	14133K	ELUS_LOCAUX	2022-06-17 14:30:00	2022-06-17 15:30:00	rdv permanence parlementaire
19640	14133K	ORG_POL	2022-06-21 11:00:00	2022-06-21 14:30:00	Réunion du Groupe LR Sénat
19641	14133K	REU_TRAV_PARL	2022-06-22 08:30:00	2022-06-22 09:30:00	Petit déjeuner de travail délégation française AP OSCE au Sénat
19642	14133K	REU_TRAV_PARL	2022-06-22 12:15:00	2022-06-22 14:00:00	\N
19643	14133K	ORG_POL	2022-06-22 18:00:00	2022-06-22 19:30:00	Visio - AP OSCE - groupe PPE
19657	14133K	COLL_TER	2022-08-18 14:30:00	2022-08-18 17:00:00	Visite territoire Bernières-sur-Mer
19658	14133K	COLL_TER	2022-08-19 10:00:00	2022-08-19 12:00:00	Visite territoire - Trévières - Association et élus
19659	14133K	REU_TRAV_PARL	2022-08-19 15:00:00	2022-08-19 16:30:00	rdv individuels permanence parlementaire
19660	14133K	CEREMONIE	2022-08-22 09:30:00	2022-08-22 10:30:00	Commémoration Libération Auberville
19661	14133K	CEREMONIE	2022-08-22 11:00:00	2022-08-22 12:00:00	Commémoration de la Libération - Villers-sur-Mer
19662	14133K	ELUS_LOCAUX	2022-08-22 12:30:00	2022-08-22 14:00:00	Réunion de travail - Elus Côte Fleurie
19663	14133K	CEREMONIE	2022-08-22 14:30:00	2022-08-22 15:30:00	Commémoration Libération Deauville
19664	14133K	CEREMONIE	2022-08-23 09:30:00	2022-08-23 10:30:00	Commémoration Libération Tourgéville
19665	14133K	CEREMONIE	2022-08-23 10:30:00	2022-08-23 11:00:00	Commémoration Libération Blonville-sur-Mer
19666	14133K	CEREMONIE	2022-08-23 11:30:00	2022-08-23 12:30:00	Commémoration Libération Bénerville-sur-Mer
19667	14133K	REU_TRAV_PARL	2022-08-23 15:30:00	2022-08-23 16:30:00	Visite site agricole - Pays d'Auge
19668	14133K	CEREMONIE	2022-08-23 18:00:00	2022-08-23 20:00:00	Commémoration Libération Saint-Désir et Lisieux
19669	14133K	CEREMONIE	2022-08-24 09:30:00	2022-08-24 10:30:00	Commémoration Libération Trouville-sur-Mer
19670	14133K	CEREMONIE	2022-08-24 11:00:00	2022-08-24 12:00:00	Commémoration Touques-Saint-Arnoult
19671	14133K	ELUS_LOCAUX	2022-08-24 12:30:00	2022-08-24 14:30:00	Réunion de travail élus de Pont-l'Evêque
19672	14133K	CEREMONIE	2022-08-24 15:00:00	2022-08-24 16:30:00	Commémoration Libération de Pont-l'Evêque
19708	14133K	ELUS_LOCAUX	2022-09-26 15:30:00	2022-09-26 17:00:00	Réunion de travail - élus Fontaine-le-Pin
19709	14133K	CEREMONIE	2022-09-26 18:00:00	2022-09-26 20:00:00	Remise insignes de la Légion d'Honneur au Président de l'UAMC - Merville-Franceville
19781	04042C	ACC_DEPL_INTER	2022-10-14 09:00:00	2022-10-14 10:00:00	Séminaire stratégique franco-polonais
19782	04042C	REU_TRAV_PARL	2022-10-14 11:30:00	2022-10-14 23:30:00	Déplacement en Bretagne pour une cérémonie patriotique et une inauguration
19783	04042C	REU_GVT	2022-10-17 10:30:00	2022-10-17 11:15:00	Ministre délégué en charge du commerce extérieur, de l'attractivité et des Français de l¿étranger
19784	04042C	REU_TRAV_PARL	2022-10-17 11:30:00	2022-10-17 12:30:00	Réunion de Coordination
19785	04042C	ACC_DEPL_INTER	2022-10-17 13:00:00	2022-10-17 14:30:00	Entretien avec l'Ambassadrice d'Arménie en France
19786	04042C	ACC_DEPL_INTER	2022-10-17 15:30:00	2022-10-17 16:30:00	Entretien avec la Ministre déléguée des affaires étrangères du Pakistan
19787	04042C	ACC_VISIT	2022-10-17 17:00:00	2022-10-17 17:30:00	Entretien avec un journaliste de TV5 Monde
19788	04042C	CEREMONIE	2022-10-17 18:00:00	2022-10-17 19:30:00	Cérémonie de remise du Prix Valéry Giscard d'Estaing 2022
19789	04042C	REU_GVT	2022-10-17 20:30:00	2022-10-17 22:30:00	Réunion de travail avec Secrétaire d'état chargée de la Jeunesse et du Service national universel
19790	04042C	ORG_POL	2022-10-18 11:00:00	2022-10-18 12:30:00	Réunion de Groupe des sénateurs LR du Sénat
19791	04042C	REU_TRAV_PARL	2022-10-18 15:45:00	2022-10-18 16:15:00	Réunion de Direction
19792	04042C	ACC_DEPL_INTER	2022-10-18 16:20:00	2022-10-18 17:30:00	Entretien avec le Président du Sénat et la Présidente du sénat de la Roumanie
19793	04042C	ACC_DEPL_INTER	2022-10-18 18:30:00	2022-10-18 19:00:00	Rencontre avec l'Ambassadeur de Corée à l'occasion de la Fête nationale
19794	04042C	ORG_POL	2022-10-18 19:15:00	2022-10-18 19:45:00	Rencontre avec des parlementaires à l'occasion de la rentrée de la session parlementaire
19795	04042C	REU_TRAV_PARL	2022-10-18 20:00:00	2022-10-18 21:00:00	Soirée à l'occasion de l'ouverture du Salon Euronaval
19796	04042C	REU_TRAV_PARL	2022-10-19 13:00:00	2022-10-19 14:30:00	Rencontres des Présidents, des Référents de commission, et du Rapporteur Général
19797	04042C	ACC_DEPL_INTER	2022-10-19 16:30:00	2022-10-19 17:30:00	Entretien avec l'Ambassadeur de Corée en France
19798	04042C	ACC_DEPL_INTER	2022-10-19 18:30:00	2022-10-19 19:30:00	Rencontre avec l'Ambassadrice d'Arménie en France à l'occasion de la Fête nationale
19867	04042C	ACC_DEPL_INTER	2022-11-04 10:00:00	2022-11-04 11:00:00	Entretien avec l'Ambassadeur de Grèce en France
19868	04042C	ACC_DEPL_INTER	2022-11-04 11:00:00	2022-11-04 12:00:00	Entretien avec l'ancien Consul de France à Casablanca
19869	04042C	ELUS_LOCAUX	2022-11-04 13:00:00	2022-11-04 14:15:00	Rencontre avec des élus du Val-de-Marne
19873	01025N	REU_TRAV_PARL	2022-11-02 13:30:00	2022-11-02 15:00:00	préparation PLFSS - groupe UC
19871	04042C	REU_TRAV_PARL	2022-11-08 08:30:00	2022-11-08 09:30:00	Entretien avec le Gou
19872	04042C	ACC_DEPL_INTER	2022-11-08 10:00:00	2022-11-08 11:00:00	Entretien avec l'Ambassadeur du Canada en France 
19881	01058X	REU_TRAV_PARL	2022-10-25 14:00:00	2022-10-25 15:00:00	Audition rapporteur - Commission des affaires étrangères - PLF pour 2023 - P. 151
19882	01058X	ORG_POL	2022-10-04 11:00:00	2022-10-04 13:00:00	Réunion de Groupe Les Républicains au Sénat
19883	01058X	ORG_POL	2022-10-11 11:00:00	2022-10-11 13:00:00	Réunion de Groupe Les Républicains au Sénat
19884	01058X	ORG_POL	2022-10-18 11:00:00	2022-10-18 13:00:00	Réunion de Groupe Les Républicains au Sénat
19885	01058X	ORG_POL	2022-10-25 11:00:00	2022-10-25 13:00:00	Réunion de Groupe Les Républicains au Sénat
19886	01058X	CEREMONIE	2022-11-09 09:30:00	2022-11-09 14:00:00	Commémoration du 52ème anniversaire de la mort du Général de Gaulle à Colombey-les-Deux-Eglises
19887	01058X	ELUS_LOCAUX	2022-10-13 10:00:00	2022-10-13 12:30:00	Réunion à Champsevraine avec les élus locaux et le chef Laurennt PETIT
19901	04042C	CEREMONIE	2022-11-10 08:00:00	2022-11-10 19:00:00	Journée du souvenir à Verdun avec la Secrétaire d'Etat aux Anciens combattants
19902	04042C	ELUS_LOCAUX	2022-11-10 20:00:00	2022-11-10 22:00:00	Rencontre avec des Elus du Val-de-Marne
19921	04042C	ACC_DEPL_INTER	2022-11-09 19:30:00	2022-11-09 20:15:00	Rencontre avec l'Ambassadeur de Pologne à l'occasion de la Fête nationale
19922	04042C	CEREMONIE	2022-11-09 20:45:00	2022-11-09 13:00:00	Soirée républicaine du CCJ 94
19201	04042C	ORG_POL	2022-06-21 11:00:00	2022-06-21 13:00:00	Réunion de Groupe des sénateurs L.R du sénat
19202	04042C	ORG_POL	2022-06-21 13:00:00	2022-06-21 14:30:00	Rencontre des sénateurs du groupe les Républicains du Sénat
19203	04042C	ACC_DEPL_INTER	2022-06-21 15:30:00	2022-06-21 16:30:00	Entretien avec l'Ambassadrice de Bosnie-Herzégovine en France
19204	04042C	ACC_DEPL_INTER	2022-06-21 16:30:00	2022-06-21 17:30:00	Entretien avec l'Ambassadrice de la Grèce en France
19205	04042C	ACC_VISIT	2022-06-21 17:30:00	2022-06-21 18:30:00	Rencontre avec des élus du Val-de-Marne
19206	04042C	REU_GVT	2022-06-21 19:00:00	2022-06-21 20:00:00	Concert de quatre formations musicales millitaires à l'occasion de la Fête de la musique au Ministère des Armées
19209	04042C	ACC_DEPL_INTER	2022-06-21 20:00:00	2022-06-21 21:30:00	Rencontre avec l'Ambassadrice, Cheffe de mission de la Palestine en France
19301	04042C	ORG_POL	2022-07-26 11:00:00	2022-07-26 12:30:00	Réunion de Groupe des sénateurs L.R du sénat
19300	04042C	ACC_DEPL_INTER	2022-07-21 15:00:00	2022-07-21 16:00:00	Entretien avec le Conseiller culturel du Président des Emirats Arabes Unis
19302	04042C	REU_TRAV_PARL	2022-07-26 13:00:00	2022-07-26 14:30:00	Rencontre avec les Présidents de commission du Sénat
19303	04042C	ACC_DEPL_INTER	2022-07-26 15:00:00	2022-07-26 16:00:00	Entretien avec l'Ambassadeur d'Ukraine en France
19304	04042C	REU_TRAV_PARL	2022-07-26 18:00:00	2022-07-26 19:00:00	Conférence des Présidents
19305	04042C	ACC_VISIT	2022-07-27 11:00:00	2022-07-27 12:00:00	Rencontre avec un élu du Val-de-Marne
19363	04042C	CEREMONIE	2022-09-01 17:00:00	2022-09-01 18:00:00	Inauguration du Village Internaional de la Gastronomie
19307	01025N	REU_TRAV_PARL	2022-06-28 08:30:00	2022-06-28 15:00:00	séminaire groupe Union centriste
19308	01025N	ACC_DEPL_INTER	2022-06-29 08:30:00	2022-06-29 09:30:00	groupe France-Ukraine
19310	01025N	REU_TRAV_PARL	2022-07-06 16:30:00	2022-07-06 18:00:00	groupe Union centriste
19362	04042C	ACC_VISIT	2022-09-01 15:00:00	2022-09-01 16:00:00	Entretien avec le Directeur général de l'Agence Française de Développement
19364	04042C	ORG_POL	2022-09-01 18:00:00	2022-09-01 19:00:00	Réunion de Groupe des sénateurs LR du Sénat en visioconférence
19365	04042C	ACC_DEPL_INTER	2022-09-02 08:00:00	2022-09-02 08:30:00	Allocution de la Ministre de l'Europe et des Affaires étrangères à la Conférence des Ambassadrices et des Ambassadeurs 2022
19366	04042C	ACC_DEPL_INTER	2022-09-02 11:00:00	2022-09-02 12:00:00	Entretien avec l'Ambassadeur du Royaume du Maroc
19370	04042C	REU_TRAV_PARL	2022-09-08 15:00:00	2022-09-08 16:00:00	Entretien avec le Président de la Commission de la Défense nationale et des Forces armées
19368	04042C	ACC_DEPL_INTER	2022-09-02 18:45:00	2022-09-02 20:45:00	Allocution de la Première ministre à la Conférence des Ambassadrices et des Ambassadeurs 2022
19369	04042C	ACC_DEPL_INTER	2022-09-08 11:45:00	2022-09-08 14:00:00	Entretien avec le Président du Sénat et le Président de la Knesset
19371	04042C	ACC_VISIT	2022-09-08 17:30:00	2022-09-08 18:00:00	Entretien télephonique avec le directeur général de la filiale chargée du développement international de SNCF Gares & Connexions.
19372	04042C	COLL_TER	2022-09-09 08:45:00	2022-09-09 11:00:00	Réunion du bureau du Syndicat des Eaux d'Ile-de-France
19373	04042C	REU_TRAV_PARL	2022-09-09 18:30:00	2022-09-09 19:30:00	Rencontre avec le délégué général pour l'armement à l'occasion de son départ
19374	04042C	REU_GVT	2022-09-12 13:00:00	2022-09-12 13:30:00	Entretien téléphonique avec la Secrétaire d'Etat chargée du Développement, de la Francophonie et des Partenariats internationaux
19385	04042C	ELUS_LOCAUX	2022-09-15 11:45:00	2022-09-15 14:00:00	Représentation du Président du Sénat à l'Université des Mairies du Val-de-Marne
19386	04042C	ORG_POL	2022-09-15 18:00:00	2022-09-15 23:00:00	Séminaire Les Républicains à Biarritz
19387	04042C	ACC_DEPL_INTER	2022-09-16 13:00:00	2022-09-16 14:15:00	Entretien avec le Président de la Commission de la Défense de Finlande et des députés finlandais
19388	04042C	CEREMONIE	2022-09-16 18:00:00	2022-09-16 20:00:00	Inauguration de l'exposition 80 ans du BCRA et 40 ans de la DGSE, un double anniversaire pour le service secret français à l'Hôtel National des Invalides
19389	04042C	ELUS_LOCAUX	2022-09-19 14:30:00	2022-09-19 15:30:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
19390	04042C	ELUS_LOCAUX	2022-09-19 15:30:00	2022-09-19 16:30:00	Entretien avec un élu du Val-de-Marne
19401	11066Q	ACC_VISIT	2022-06-16 09:00:00	2022-06-16 17:00:00	Accueil Permanence
19402	11066Q	CEREMONIE	2022-06-17 08:50:00	2022-06-17 10:00:00	Cérémonie commémorant le 82ème anniversaire du naufrage Lancastria à Saint-Nazaire
19404	11066Q	ACC_VISIT	2022-06-20 09:00:00	2022-06-20 17:00:00	Accueil Permanence
19405	11066Q	ACC_VISIT	2022-06-21 09:00:00	2022-06-21 17:00:00	Accueil Permanence
19406	11066Q	ACC_VISIT	2022-06-22 09:00:00	2022-06-22 17:00:00	Accueil Permanence
19411	11066Q	CEREMONIE	2022-06-24 11:00:00	2022-06-24 12:00:00	Cérémonie du départ en mer de la sous-station du Parc éolien en Mer de Fécamp
19412	11066Q	ACC_VISIT	2022-06-27 09:00:00	2022-06-27 17:00:00	Accueil Permanence
19413	11066Q	REU_TRAV_PARL	2022-06-28 10:30:00	2022-06-28 12:30:00	Réunion de groupe
19414	11066Q	REU_TRAV_PARL	2022-06-28 15:00:00	2022-06-28 16:00:00	Réunion de travail parlementaire
19415	11066Q	REU_TRAV_PARL	2022-06-29 10:00:00	2022-06-29 11:00:00	Entretien avec M. Lasvignes Président de la CNCTR
19416	11066Q	ACC_VISIT	2022-06-30 09:00:00	2022-06-30 15:00:00	Accueil Permanence
19417	11066Q	COLL_TER	2022-06-30 15:00:00	2022-06-30 17:00:00	Assemblée générale annuelle de l'Association Emmaüs 44 Saint-Nazaire
19420	11066Q	ACC_VISIT	2022-07-04 09:00:00	2022-07-04 15:00:00	Accueil Permanence
19422	11066Q	ACC_VISIT	2022-07-04 15:00:00	2022-07-04 16:00:00	Entretien avec le Directeur et le Délégué régionaux des relations avec les collectivités locales de l'opérateur Orange
19423	11066Q	ACC_VISIT	2022-07-04 16:00:00	2022-07-04 17:00:00	Accueil Permanence
19425	11066Q	ORGEXTPAR	2022-07-05 15:00:00	2022-07-05 16:00:00	Entretien CNCTR
19426	11066Q	REU_TRAV_PARL	2022-07-06 14:15:00	2022-07-06 14:45:00	Entretien avec le Président du Sénat
19427	11066Q	ACC_VISIT	2022-07-07 14:00:00	2022-07-07 17:00:00	Accueil Permanence
19428	11066Q	ACC_VISIT	2022-07-08 09:00:00	2022-07-08 10:00:00	Accueil Permanence
19429	11066Q	COLL_TER	2022-07-08 10:00:00	2022-07-08 12:30:00	Réunion du Comité d'Orientation stratégique de l'étude de zone de surmortalité de l'agglomération nazairienne
19430	11066Q	ACC_VISIT	2022-07-08 14:00:00	2022-07-08 17:00:00	Accueil Permanence
19431	11066Q	ACC_VISIT	2022-07-11 09:00:00	2022-07-11 11:30:00	Accueil Permanence
19432	11066Q	REU_TRAV_PARL	2022-07-11 11:30:00	2022-07-11 12:30:00	Réunion du Groupe socialiste de la Commission des affaires étrangères
19433	11066Q	ACC_VISIT	2022-07-11 14:00:00	2022-07-11 17:00:00	Accueil Permanence
19434	11066Q	REU_TRAV_PARL	2022-07-12 10:30:00	2022-07-12 12:30:00	Réunion de groupe
19435	11066Q	ACC_VISIT	2022-07-15 09:00:00	2022-07-15 17:00:00	Accueil Permanence
19436	11066Q	ACC_VISIT	2022-07-18 09:00:00	2022-07-18 17:00:00	Accueil Permanence
19440	11066Q	ACC_VISIT	2022-07-25 09:00:00	2022-07-25 17:00:00	Accueil Permanence
19441	11066Q	REU_TRAV_PARL	2022-07-26 10:30:00	2022-07-26 12:30:00	Réunion de groupe
19442	11066Q	ACC_VISIT	2022-07-29 09:00:00	2022-07-29 17:00:00	Accueil Permanence
19443	11066Q	ACC_VISIT	2022-08-01 09:00:00	2022-08-01 17:00:00	Accueil Permanence
19444	11066Q	REU_TRAV_PARL	2022-08-02 10:30:00	2022-08-02 12:30:00	Réunion de groupe
19449	11066Q	ACC_VISIT	2022-08-23 09:00:00	2022-08-23 17:00:00	Accueil Permanence
19453	11066Q	ACC_VISIT	2022-08-29 09:00:00	2022-08-29 17:00:00	Accueil Permanence
19454	11066Q	ORG_POL	2022-08-30 09:00:00	2022-08-30 17:00:00	Accueil Permanence
19455	11066Q	ACC_VISIT	2022-08-31 09:00:00	2022-08-31 17:00:00	Accueil Permanence
19461	11066Q	ACC_VISIT	2022-09-05 09:00:00	2022-09-05 17:00:00	Accueil Permanence
19464	11066Q	ORGEXTPAR	2022-09-08 09:00:00	2022-09-08 12:30:00	Réunion Plénière de la Commission nationale des Techniques de Renseignement
19470	11066Q	ACC_VISIT	2022-09-16 09:00:00	2022-09-16 17:00:00	Accueil Permanence
19471	11066Q	ACC_VISIT	2022-09-19 09:00:00	2022-09-19 12:30:00	Accueil Permanence
19475	11066Q	REU_TRAV_PARL	2022-09-21 09:00:00	2022-09-21 10:00:00	Réunion des membres socialistes de la Commission des Affaires étrangères, de la Défense et des Forces armées
19241	04042C	COLL_TER	2022-07-04 09:30:00	2022-07-04 10:30:00	Réunion de travail du Syndicat des Eaux d'Ile-de-France
19242	04042C	ELUS_LOCAUX	2022-07-04 11:00:00	2022-07-04 12:00:00	Pose de la 1ère pierre de la Résidence Dôme des bords de Marne à Champigny-sur-Marne
19243	04042C	ACC_VISIT	2022-07-04 13:00:00	2022-07-04 14:15:00	Rencontre avec des élus du Val-de-Marne
19244	04042C	ACC_VISIT	2022-07-04 16:00:00	2022-07-04 17:00:00	Entretien avec un élu du Val-de-Marne
19245	04042C	ACC_VISIT	2022-07-04 17:00:00	2022-07-04 17:30:00	Remise d'un tableau 
19246	04042C	ACC_DEPL_INTER	2022-07-04 17:30:00	2022-07-04 18:30:00	entretien avec une délégation du Gouvernement du Kurdistan-Irak
19247	04042C	ELUS_LOCAUX	2022-07-04 19:00:00	2022-07-04 22:00:00	Visite du palais du Luxembourg d'un Conseil municipal du Val-de-Marne
19248	04042C	ORG_POL	2022-07-05 11:00:00	2022-07-05 12:30:00	Réunion de Groupe des sénateurs L.R du sénat
19249	04042C	ACC_DEPL_INTER	2022-07-05 12:45:00	2022-07-05 14:30:00	Rencontre avec l'Ambassadrice d'Italie en France
19250	04042C	ACC_DEPL_INTER	2022-07-05 17:00:00	2022-07-05 18:00:00	Entretien avec l'Ambassadeur du Koweït en France
19251	04042C	COLL_TER	2022-07-05 19:00:00	2022-07-05 20:00:00	Réunion du Conseil de Territoire
19252	04042C	ACC_DEPL_INTER	2022-07-05 20:30:00	2022-07-05 22:00:00	Rencontre avec l'Ambassadeur d'Argentine en France
19253	04042C	ACC_DEPL_INTER	2022-07-05 18:30:00	2022-07-05 20:00:00	Réception à l'Ambassade britanique à l'occasion de l'arrivée d'un général de brigade et un adieu aux armes
19254	04042C	ORG_POL	2022-07-05 17:00:00	2022-07-05 18:00:00	Réunion avec le Président du Groupe L.R au Sénat
19255	04042C	ELUS_LOCAUX	2022-07-11 11:00:00	2022-07-11 12:00:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
19256	04042C	REU_TRAV_PARL	2022-07-11 15:00:00	2022-07-11 16:30:00	Réunion de direction
19257	04042C	ACC_VISIT	2022-07-11 16:30:00	2022-07-11 17:00:00	Accueil de l'Ecole Militaire de Saint-Cyr
19258	04042C	ACC_DEPL_INTER	2022-07-11 17:00:00	2022-07-11 18:00:00	Entrtien avec l'Ambassadrice, Représentante permanente de la France auprès de l'Unesco
19259	04042C	ORG_POL	2022-07-12 11:00:00	2022-07-12 12:30:00	Réunion de Groupe des sénateurs L.R du sénat
19284	04042C	CEREMONIE	2022-07-13 16:15:00	2022-07-13 17:00:00	Cérémonie des blessés de guerre à la Présidence du Sénat
19282	04042C	CEREMONIE	2022-07-13 11:15:00	2022-07-13 13:00:00	Cérémonie militaire de la Légion étrangère dans les Jardins du Luxembourg
19283	04042C	ORG_POL	2022-07-13 13:15:00	2022-07-13 14:30:00	Rencontre avec  les Présidents et Référents de commissions, le Rapporteur général et le Vice-président du groupe
19285	04042C	ACC_VISIT	2022-07-13 17:15:00	2022-07-13 18:15:00	Interview Emission C'est dans l'Air
19286	04042C	CEREMONIE	2022-07-13 18:30:00	2022-07-13 20:30:00	Réception en l'honneur des unités participant aux cérémonies de la Fête nationale au Ministère des Armées
19287	04042C	CEREMONIE	2022-07-14 08:30:00	2022-07-14 12:30:00	Cérémonie du 14 juillet aux Champs-Elysées
19288	04042C	ACC_DEPL_INTER	2022-07-18 15:20:00	2022-07-18 16:30:00	Entretien avec le Président du Sénat et le Président des Emirats Arabes Unis
19289	04042C	ACC_DEPL_INTER	2022-07-18 20:45:00	2022-07-18 23:30:00	Dîner officiel au Château de Versailles à l'occasion de la visite d'état du Président des Emirats Arabes Unis
19290	11103C	ORG_POL	2022-07-19 11:00:00	2022-07-19 12:30:00	LR du Sénat
19403	11066Q	ACC_VISIT	2022-06-17 10:00:00	2022-06-17 17:00:00	Accueil Permanence
19407	11066Q	ACC_VISIT	2022-06-23 09:00:00	2022-06-23 17:00:00	Accueil Permanence
19408	11066Q	ACC_VISIT	2022-06-24 09:00:00	2022-06-24 11:00:00	Accueil Permanence
19437	11066Q	REU_TRAV_PARL	2022-07-19 10:30:00	2022-07-19 12:30:00	Réunion de groupe
19410	11066Q	ACC_VISIT	2022-06-24 14:00:00	2022-06-24 17:00:00	Accueil Permanence
19418	11066Q	ELUS_LOCAUX	2022-07-01 10:00:00	2022-07-01 12:30:00	Assemblée générale de l'association des Maires et Présidents d'intercommunalités de Loire-Atlantique
19419	11066Q	ACC_VISIT	2022-07-01 14:00:00	2022-07-01 17:00:00	Accueil Permanence
19438	11066Q	ORGEXTPAR	2022-07-21 09:00:00	2022-07-21 12:00:00	Réunion Plénière de la Commission nationale des Techniques de Renseignement
19439	11066Q	ACC_VISIT	2022-07-22 09:00:00	2022-07-22 17:00:00	Accueil Permanence
19445	11066Q	ACC_VISIT	2022-08-03 09:00:00	2022-08-03 17:00:00	Accueil Permanence
19446	11066Q	ACC_VISIT	2022-08-04 09:00:00	2022-08-04 17:00:00	Accueil Permanence
19447	11066Q	ACC_VISIT	2022-08-05 09:00:00	2022-08-05 17:00:00	Accueil Permanence
19448	11066Q	ACC_VISIT	2022-08-22 09:00:00	2022-08-22 17:00:00	Accueil Permanence
19450	11066Q	ACC_VISIT	2022-08-24 09:00:00	2022-08-24 17:00:00	Accueil Permanence
19451	11066Q	ACC_VISIT	2022-08-25 09:00:00	2022-08-25 17:00:00	Accueil Permanence
19452	11066Q	ACC_VISIT	2022-08-26 09:00:00	2022-08-26 17:00:00	Accueil Permanence
19456	11066Q	ACC_VISIT	2022-09-01 09:00:00	2022-09-01 17:00:00	Accueil Permanence
19457	11066Q	ACC_VISIT	2022-09-02 09:00:00	2022-09-02 10:00:00	Rencontre avec le collectif urgence sociale Saint-Nazaire
19458	11066Q	ACC_VISIT	2022-09-02 10:00:00	2022-09-02 12:30:00	Accueil Permanence
19459	11066Q	ACC_VISIT	2022-09-02 14:00:00	2022-09-02 15:00:00	Accueil Permanence
19460	11066Q	CEREMONIE	2022-09-02 15:30:00	2022-09-02 16:30:00	Cérémonie de prise de fonction des nouveaux personnels de Police au commissariat de Saint-Nazaire
19462	11066Q	ACC_VISIT	2022-09-06 09:00:00	2022-09-06 17:00:00	Accueil Permanence
19463	11066Q	ACC_VISIT	2022-09-07 09:00:00	2022-09-07 13:00:00	Accueil Permanence
19465	11066Q	CEREMONIE	2022-09-09 10:00:00	2022-09-09 11:00:00	Journée de sensibilisation aux cancers de l'enfant "Septembre en Or" organisée par le collectif Stop aux cancers de nos enfants à Port Saint Père
19466	11066Q	ACC_VISIT	2022-09-09 14:00:00	2022-09-09 17:00:00	Accueil Permanence
19467	11066Q	ACC_VISIT	2022-09-12 09:00:00	2022-09-12 17:00:00	Accueil Permanence
19468	11066Q	REU_TRAV_PARL	2022-09-14 09:30:00	2022-09-14 10:30:00	Réunion de préparation
19469	11066Q	ACC_VISIT	2022-09-15 14:00:00	2022-09-15 17:00:00	Réunion de groupe
19472	11066Q	ACC_VISIT	2022-09-19 14:30:00	2022-09-19 15:30:00	Entretien avec le Directeur du Pôle Formation de la SNSM
19473	11066Q	ACC_VISIT	2022-09-19 15:30:00	2022-09-19 17:00:00	Accueil Permanence
19474	11066Q	REU_TRAV_PARL	2022-09-20 18:30:00	2022-09-20 19:30:00	Point sur le Programme 144 du Projet de Loi de Finances
19476	11066Q	DEPL_PRES_GVT	2022-09-22 09:00:00	2022-09-22 15:00:00	Déplacement du Président de la République à Saint-Nazaire : visite du parc éolien en mer 
19477	11066Q	ACC_VISIT	2022-09-22 15:00:00	2022-09-22 17:00:00	Accueil Permanence
19478	11066Q	ACC_VISIT	2022-09-23 09:00:00	2022-09-23 11:15:00	Accueil Permanence
19479	11066Q	ELUS_LOCAUX	2022-09-23 12:30:00	2022-09-23 14:30:00	Réunion des Sénateurs et Sénatrices avec le Préfet de Loire-Atlantique
19480	11066Q	ACC_VISIT	2022-09-23 15:30:00	2022-09-23 17:00:00	Accueil Permanence
19481	11066Q	ACC_VISIT	2022-09-26 09:30:00	2022-09-26 12:30:00	Accueil Permanence
19482	11066Q	ACC_VISIT	2022-09-26 14:00:00	2022-09-26 15:00:00	Accueil Permanence
19483	11066Q	ACC_VISIT	2022-09-26 15:00:00	2022-09-26 16:00:00	Entretien avec le nouveau Commandant de la compagnie départementale de gendarmerie de Saint-Nazaire
19484	11066Q	ACC_VISIT	2022-09-26 16:00:00	2022-09-26 17:00:00	Accueil Permanence
19524	14133K	REU_TRAV_PARL	2022-02-15 14:00:00	2022-02-15 15:30:00	rdv affaires étrangères - Birmanie
19531	14133K	DEPL_PRES_GVT	2022-02-25 14:30:00	2022-02-25 15:30:00	visio - hémicycle - déclaration du Président de la République
19532	14133K	COLL_TER	2022-02-25 09:30:00	2022-02-25 10:30:00	rdv individuels permanence parlementaire
19533	14133K	ORG_POL	2022-02-25 10:30:00	2022-02-25 12:00:00	Visio-Groupe PPE-AP-OSCE
19534	14133K	COLL_TER	2022-02-25 18:00:00	2022-02-25 19:30:00	Assemblée générale Souvenir Français 14
19535	14133K	COLL_TER	2022-02-28 14:00:00	2022-02-28 16:30:00	rdv permanence parlementaire
19536	14133K	ORG_POL	2022-03-01 17:00:00	2022-03-01 18:30:00	Réunion du Groupe LR Sénat
19537	14133K	ELUS_LOCAUX	2022-03-02 14:30:00	2022-03-02 16:30:00	rdv permanence parlementaire
19538	14133K	ELUS_LOCAUX	2022-03-03 11:00:00	2022-03-03 18:00:00	rdv élus locaux - déplacement dans le Bessin
19539	14133K	ELUS_LOCAUX	2022-03-07 09:30:00	2022-03-07 12:00:00	Réunion et visite de territoire - Grainville-Langannerie
19540	14133K	COLL_TER	2022-03-07 14:30:00	2022-03-07 17:00:00	Rdv responsables territoriaux - permanence parlementaire
19541	14133K	COLL_TER	2022-03-08 11:00:00	2022-03-08 12:30:00	Déplacement Mairie de Pont-d'Ouilly
19542	14133K	REU_TRAV_PARL	2022-03-08 14:30:00	2022-03-08 16:30:00	rdv permanence parlementaire
19543	14133K	CEREMONIE	2022-03-09 10:30:00	2022-03-09 11:30:00	Cérémonie patriotique - Ver-sur-Mer
19135	11066Q	ACC_VISIT	2022-03-31 09:00:00	2022-03-31 12:00:00	Accueil Permanence et visite sur le Département
19136	11066Q	ACC_VISIT	2022-04-01 09:00:00	2022-04-01 17:00:00	Accueil Permanence
19137	11066Q	ACC_VISIT	2022-04-04 09:00:00	2022-04-04 17:00:00	Accueil Permanence
19138	11066Q	ACC_VISIT	2022-04-05 09:00:00	2022-04-05 17:00:00	Accueil Permanence
19141	11066Q	ACC_VISIT	2022-04-08 09:00:00	2022-04-08 17:00:00	Accueil Permanence
19155	11066Q	ACC_VISIT	2022-04-27 14:00:00	2022-04-27 17:00:00	Accueil Permanence
19156	11066Q	ACC_VISIT	2022-04-28 09:00:00	2022-04-28 17:00:00	Accueil Permanence
19157	11066Q	ACC_VISIT	2022-04-29 09:00:00	2022-04-29 17:00:00	Accueil Permanence
19158	11066Q	CEREMONIE	2022-04-29 11:00:00	2022-04-29 12:30:00	Cérémonie de mise à flot du bâtiment ravitailleurs de forces Jacques Chevalier
19159	11066Q	ACC_VISIT	2022-05-02 09:00:00	2022-05-02 17:00:00	Accueil Permanence
19160	11066Q	ACC_VISIT	2022-05-03 09:00:00	2022-05-03 17:00:00	Accueil Permanence
19161	11066Q	ORGEXTPAR	2022-05-05 09:00:00	2022-05-05 12:00:00	Réunion Plénière de la Commission nationale des Techniques de Renseignement
19162	11066Q	ACC_VISIT	2022-05-06 09:00:00	2022-05-06 17:00:00	Accueil Permanence
19163	11066Q	CEREMONIE	2022-05-06 11:00:00	2022-05-06 12:00:00	Dévoilement de la plaque Ambroise Croizat
19173	11066Q	ACC_VISIT	2022-05-18 09:00:00	2022-05-18 17:00:00	Accueil Permanence
19174	11066Q	ACC_VISIT	2022-05-23 09:00:00	2022-05-23 17:00:00	Accueil Permanence
19177	11066Q	ACC_VISIT	2022-05-30 09:00:00	2022-05-30 17:00:00	Accueil Permanence
19178	11066Q	ACC_VISIT	2022-05-31 09:00:00	2022-05-31 12:30:00	Accueil Permanence
19179	11066Q	ACC_VISIT	2022-05-31 16:00:00	2022-05-31 17:00:00	Accueil Permanence
19180	11066Q	ACC_VISIT	2022-06-02 09:00:00	2022-06-02 17:00:00	Accueil Permanence
19183	11066Q	ACC_VISIT	2022-06-09 14:00:00	2022-06-09 17:00:00	Accueil Permanence
19185	11066Q	ACC_VISIT	2022-06-13 09:00:00	2022-06-13 17:00:00	Accueil Permanence
19191	04042C	ACC_VISIT	2022-06-16 18:00:00	2022-06-16 18:15:00	Entretien téléphonique avec la Secrétaire générale de la Préfecrure du Val-de-Marne
19192	04042C	ACC_DEPL_INTER	2022-06-17 11:00:00	2022-06-17 12:30:00	Entretien avec le Secrétaire général de l'Assemblée nationale du pouvoir populaire de Cuba
19544	14133K	CEREMONIE	2022-03-09 15:00:00	2022-03-09 16:00:00	Remise de fanion - Académie des Cadets de la Défense de Normandie - Caen
19545	14133K	COLL_TER	2022-03-09 17:00:00	2022-03-09 18:00:00	rdv permanence parlementaire
19546	14133K	COLL_TER	2022-03-10 09:30:00	2022-03-10 14:00:00	Visite territoire Calvados - Evrecy
19547	14133K	COLL_TER	2022-03-10 16:00:00	2022-03-10 17:30:00	rdv permanence parlementaire
19548	14133K	CEREMONIE	2022-03-11 11:00:00	2022-03-11 12:00:00	Cérémonie départementale Hommage aux victimes du terrorisme - Caen
19549	14133K	ELUS_LOCAUX	2022-03-11 12:30:00	2022-03-11 14:00:00	réunion de travail UAMC
19554	14133K	ACC_VISIT	2022-03-15 14:15:00	2022-03-15 15:00:00	Accueil des jeunes officiers du SIGEM au Sénat
19551	14133K	DEL_ACT_PAR	2022-03-11 15:30:00	2022-03-11 16:30:00	Extraordinary OSCE PA Standing Committee 
19552	14133K	REU_TRAV_PARL	2022-03-14 14:30:00	2022-03-14 17:00:00	Rendez-vous sociaux et économiques permanence parlementaire dans le Calvados
19553	14133K	ORG_POL	2022-03-15 11:00:00	2022-03-15 14:00:00	Réunion du Groupe LR Sénat
19555	14133K	REU_TRAV_PARL	2022-03-18 10:30:00	2022-03-18 11:30:00	Rendez-vous sociaux et économiques permanence parlementaire dans le Calvados
19559	14133K	ELUS_LOCAUX	2022-03-21 12:00:00	2022-03-21 14:30:00	Visite Président Larcher dans le Calvados - réunion élus à Caen
19557	04042C	ACC_DEPL_INTER	2022-09-28 00:00:00	2022-09-28 00:00:00	Mission diplomatique au Kurdistan irakien
19558	04042C	ACC_DEPL_INTER	2022-09-29 00:00:00	2022-09-29 00:00:00	Mission diplomatique au Kurdistan irakien
19560	04042C	ACC_DEPL_INTER	2022-09-30 00:00:00	2022-09-30 00:00:00	Mission diplomatique au Kurdistan irakien
19569	04042C	REU_TRAV_PARL	2022-10-04 08:00:00	2022-10-04 09:00:00	Entretien avec le Chef d'état-major de l'Armée de Terre
19562	14133K	ELUS_LOCAUX	2022-03-21 15:00:00	2022-03-21 16:30:00	Visite Président Larcher dans le Calvados - réunion élus à Saint-Pierre-en-Auge
19563	14133K	ELUS_LOCAUX	2022-03-21 17:00:00	2022-03-21 18:00:00	Visite du Président Larcher dans le Calvados - Dozulé
19564	14133K	ORG_POL	2022-03-21 19:00:00	2022-03-21 20:30:00	Réunion politique - campagne électorale - Bayeux
19565	14133K	REU_TRAV_PARL	2022-03-22 15:30:00	2022-03-22 17:00:00	rdv permanence parlementaire
19566	04042C	ACC_VISIT	2022-10-03 19:00:00	2022-10-03 22:30:00	Visite du palais du Luxembourg d'un Conseil municipal du Val-de-Marne
19571	04042C	ORG_POL	2022-10-04 11:00:00	2022-10-04 12:30:00	Réunion de Groupe des sénateurs LR du Sénat
19568	04042C	ORG_POL	2022-10-03 11:00:00	2022-10-03 12:30:00	Réunion de Groupe des sénateurs LR du Sénat
19570	14133K	REU_TRAV_PARL	2022-03-24 14:30:00	2022-03-24 17:30:00	Visite site industriel normand agroalimentaire
19572	04042C	ACC_VISIT	2022-10-04 13:00:00	2022-10-04 14:30:00	Rencontre avec un élu du Val-de-Marne
19573	14133K	REU_TRAV_PARL	2022-03-25 09:30:00	2022-03-25 12:00:00	Rendez-vous individuels - permanence parlementaire dans le Calvados
19574	14133K	COLL_TER	2022-03-31 12:30:00	2022-03-31 14:30:00	Réunion de travail Région Normandie Caen
19575	14133K	ELUS_LOCAUX	2022-03-31 14:30:00	2022-03-31 15:30:00	RDV élus régionaux - Caen
19578	14133K	CEREMONIE	2022-04-08 13:00:00	2022-04-08 14:00:00	Cérémonie patriotique - Valdallière
19579	14133K	COLL_TER	2022-04-08 14:30:00	2022-04-08 17:30:00	Visite territoire Calvados - Laize-Clinchamps
19580	14133K	CEREMONIE	2022-04-21 10:00:00	2022-04-21 11:00:00	Cérémonie patriotique - Caen
19581	14133K	CEREMONIE	2022-04-22 10:00:00	2022-04-22 12:00:00	Cérémonie patriotique - Montchamp-Valdallière
19582	14133K	REU_TRAV_PARL	2022-04-22 14:30:00	2022-04-22 16:30:00	rdv individuels permanence parlementaire
19586	14133K	REU_TRAV_PARL	2022-04-26 16:00:00	2022-04-26 17:00:00	Réunion thématique Défense - Sénat
19589	14133K	ORG_POL	2022-04-27 18:00:00	2022-04-27 19:30:00	Visio-AP OSCE -Réunion Groupe PPE
19585	14133K	REU_TRAV_PARL	2022-04-26 14:45:00	2022-04-26 15:15:00	Interview presse départementale
19587	14133K	REU_TRAV_PARL	2022-04-26 13:00:00	2022-04-26 14:30:00	Réunion thématique Défense - Sénat
19588	14133K	ORG_POL	2022-04-27 09:30:00	2022-04-27 15:30:00	Séminaire du Groupe LR - Paris
19590	14133K	REU_TRAV_PARL	2022-04-28 11:00:00	2022-04-28 12:00:00	Réunion thématique OSCE
19591	14133K	REU_TRAV_PARL	2022-04-28 13:00:00	2022-04-28 14:30:00	Préparation déplacement de SE l'ambassadeur du Kazakhstan dans le Calvados
19592	14133K	REU_TRAV_PARL	2022-04-28 15:30:00	2022-04-28 16:00:00	Interview presse départementale Calvados
19593	14133K	REU_TRAV_PARL	2022-04-28 16:00:00	2022-04-28 17:00:00	réunion Visio - RP Israélien
19594	14133K	REU_TRAV_PARL	2022-04-29 09:30:00	2022-04-29 11:30:00	Rendez-vous sociaux et économiques permanence parlementaire dans le Calvados
19595	14133K	REU_TRAV_PARL	2022-04-29 14:30:00	2022-04-29 17:00:00	Rendez-vous sociaux et économiques permanence parlementaire dans le Calvados
19596	14133K	ORG_POL	2022-05-03 14:30:00	2022-05-03 16:30:00	CNI Les Républicains - Paris
19600	14133K	COLL_TER	2022-05-05 10:00:00	2022-05-05 11:30:00	Inauguration Pôle touristique Vallées de l'Orne et de l'Oudon-Calvados
19598	14133K	REU_TRAV_PARL	2022-05-04 12:00:00	2022-05-04 14:00:00	Visio - AP OSCE - thématique Routes de la Soie
19599	14133K	ORG_POL	2022-05-04 19:00:00	2022-05-04 20:30:00	Réunion LR 14 - 6e circo
19601	14133K	REU_TRAV_PARL	2022-05-05 14:30:00	2022-05-05 15:45:00	rdv permanence parlementaire
19602	14133K	ELUS_LOCAUX	2022-05-05 16:00:00	2022-05-05 17:30:00	Réunion conseil municipal des enfants de Pont-d'Ouilly - Calvados
19644	14133K	COLL_TER	2022-06-23 10:30:00	2022-06-23 12:30:00	Inauguration AGRIGAZ - Vire Normandie
19645	14133K	ELUS_LOCAUX	2022-06-23 14:30:00	2022-06-23 15:30:00	rdv maires du Calavdos
19646	14133K	COLL_TER	2022-06-24 09:30:00	2022-06-24 12:00:00	rdv individuels permanence parlementaire et cérémonie locale - Condé-en-Normandie
19647	14133K	REU_TRAV_PARL	2022-06-27 14:30:00	2022-06-27 16:30:00	Rdv acteurs économiques - Calvados
19648	14133K	REU_TRAV_PARL	2022-06-28 16:00:00	2022-06-28 19:00:00	Animation Conférence activités Sénat - Affaires étrangères et Routes de la Soie - Caen
19649	14133K	REU_TRAV_PARL	2022-06-29 10:00:00	2022-06-29 11:00:00	Rdv acteurs économiques - Calvados
19650	14133K	REU_TRAV_PARL	2022-06-30 15:30:00	2022-06-30 16:30:00	Rdv acteurs économiques - Calvados
19651	14133K	COLL_TER	2022-07-01 12:00:00	2022-07-01 14:30:00	Rencontre délégation chinoise - CAEN
19652	14133K	REU_TRAV_PARL	2022-07-01 15:30:00	2022-07-01 16:30:00	rdv individuels permanence parlementaire
19653	14133K	ORG_POL	2022-07-12 11:00:00	2022-07-12 12:30:00	Réunion du Groupe LR Sénat
20322	04043D	CEREMONIE	2022-05-18 12:00:00	2022-05-18 14:00:00	Inauguration - Maison de l'Indonésie
20284	04043D	REU_TRAV_PARL	2023-01-20 00:00:00	2023-01-20 00:00:00	Visite d'entreprise - PHAGOS
20285	04043D	COLL_TER	2023-01-20 20:00:00	2023-01-20 21:00:00	Cérémonie des voeux - Rungis
20323	04043D	ACC_DEPL_INTER	2022-05-04 19:00:00	2022-05-04 21:30:00	Dîner Ambassadeur de Corée en France
20324	04043D	ORG_POL	2022-05-03 14:30:00	2022-05-03 15:30:00	Commission Nationale d'Investiture
20701	04042C	ACC_VISIT	2023-04-12 13:00:00	2023-04-12 14:00:00	Rencontre avec un élu du Val-de-Marne
20702	04042C	ACC_VISIT	2023-04-12 16:30:00	2023-04-12 17:30:00	Entretien avec une conseillère du secrétaire général de la garde nationale 
20703	04042C	REU_TRAV_PARL	2023-04-12 17:30:00	2023-04-12 18:30:00	Réunion de coordination
20704	04042C	ACC_VISIT	2023-04-12 19:30:00	2023-04-12 19:45:00	Entretien téléphonique avec un Préfet
20705	04042C	ACC_VISIT	2023-04-13 11:15:00	2023-04-13 11:20:00	Interview Public Sénat
20709	04042C	ACC_DEPL_INTER	2023-04-13 15:00:00	2023-04-13 16:00:00	Entretien avec l'Ambassadeur du Bénin en France
20707	04042C	ACC_VISIT	2023-04-13 13:00:00	2023-04-13 14:30:00	Entretien avec un député
20708	04042C	ACC_DEPL_INTER	2023-04-13 11:30:00	2023-04-13 12:30:00	Entretien avec la Chargée d'Affaires de l'Ambassade de la République bolivarienne du Venezuela en France
20713	04042C	ACC_VISIT	2023-04-14 11:30:00	2023-04-14 12:30:00	Entretien avec un Préfet
20711	04042C	ACC_DEPL_INTER	2023-04-13 16:00:00	2023-04-13 17:00:00	Entretien avec l'Ambassadeur du Portugal en France
20712	04042C	COLL_TER	2023-04-14 08:45:00	2023-04-14 11:00:00	Réunion du bureau du Syndicat des Eaux d'Ile-de-France
20714	04042C	ACC_DEPL_INTER	2023-04-14 15:15:00	2023-04-14 16:30:00	Entretien avec une délégation de députés de Taïwan
20715	04042C	ACC_DEPL_INTER	2023-04-14 16:30:00	2023-04-14 17:30:00	Entretien avec l'Ambassadeur du Japon en France
20716	04042C	ACC_VISIT	2023-04-13 12:30:00	2023-04-13 13:00:00	Entretien téléphonique avec un élu du Val-de-Marne
20721	11066Q	REU_TRAV_PARL	2023-02-14 10:00:00	2023-02-14 12:00:00	Réunion de groupe
20722	11066Q	ORGEXTPAR	2023-02-14 16:30:00	2023-02-14 17:30:00	CNCTR
20734	11066Q	ACC_VISIT	2023-03-03 09:00:00	2023-03-03 12:30:00	Accueil Permanence
20735	11066Q	ACC_VISIT	2023-03-03 14:00:00	2023-03-03 17:00:00	Accueil Permanence
20738	11066Q	ACC_VISIT	2023-03-09 14:00:00	2023-03-09 17:30:00	Accueil Permanence
20739	11066Q	ACC_VISIT	2023-03-10 09:00:00	2023-03-10 12:30:00	Accueil Permanence
20740	11066Q	ACC_VISIT	2023-03-10 14:00:00	2023-03-10 17:30:00	Accueil Permanence
20741	11066Q	ACC_VISIT	2023-03-13 09:00:00	2023-03-13 12:30:00	Accueil Permanence
20743	11066Q	ACC_VISIT	2023-03-16 09:00:00	2023-03-16 12:30:00	Accueil Permanence
20744	11066Q	ACC_VISIT	2023-03-16 14:00:00	2023-03-16 17:30:00	Accueil Permanence
20745	11066Q	ACC_VISIT	2023-03-17 09:00:00	2023-03-17 12:30:00	Accueil Permanence
20746	11066Q	ACC_VISIT	2023-03-17 14:00:00	2023-03-17 17:30:00	Accueil Permanence
20750	11066Q	ACC_VISIT	2023-03-23 14:00:00	2023-03-23 17:30:00	Accueil Permanence
20763	11066Q	ACC_VISIT	2023-04-03 14:00:00	2023-04-03 16:30:00	Accueil Permanence
20764	11066Q	REU_TRAV_PARL	2023-04-04 09:00:00	2023-04-04 09:30:00	Assemblée générale statutaire du groupe socialiste
20765	11066Q	ACC_VISIT	2023-04-05 11:30:00	2023-04-05 13:30:00	Accueil de la classe de 3ème Défense et Sécurité globale du collège Pierre Norange de Saint-Nazaire
20770	11066Q	REU_GVT	2023-04-11 17:00:00	2023-04-11 18:00:00	Rencontre au Ministère de la Santé et de la Prévention à propos du foyer de cancers pédiatriques en Pays-de-Retz avec la porte-parole du collectif Stop aux Cancers de nos Enfants et Laurence Huc, toxicologue
20771	11066Q	REU_TRAV_PARL	2023-04-12 20:30:00	2023-04-12 21:30:00	Réunion de groupe
20772	11066Q	ACC_VISIT	2023-04-13 14:00:00	2023-04-13 17:30:00	Accueil Permanence
20801	04042C	ACC_DEPL_INTER	2023-04-26 12:30:00	2023-04-26 14:30:00	Rencontre avec le Nonce Apostolique en France
20802	04042C	ELUS_LOCAUX	2023-04-26 18:00:00	2023-04-26 19:00:00	Entretien avec un élu du Val-de-Marne
20803	04042C	ACC_VISIT	2023-04-27 15:00:00	2023-04-27 16:00:00	Interview téléphonique avec la Rédactrice en chef adjointe du Journal du Grand Paris
20804	04042C	ELUS_LOCAUX	2023-04-27 17:00:00	2023-04-27 18:00:00	Réunion avec des élus du Val-de-Marne
20805	04042C	ACC_DEPL_INTER	2023-04-28 13:00:00	2023-04-28 14:30:00	Rencontre avec l'Ambassadeur du Portugal en France
20806	04042C	ELUS_LOCAUX	2023-05-03 11:30:00	2023-05-03 12:30:00	Réunion avec des élus du Val-de-Marne
20807	04042C	ACC_VISIT	2023-05-03 13:00:00	2023-05-03 14:15:00	Entretien avec des élus du Val-de-Marne
20808	04042C	DEPL_PRES_GVT	2023-05-04 07:00:00	2023-05-04 19:30:00	Visite des bases militaires aux côtés du Ministre des Armées
20809	04042C	CEREMONIE	2023-05-08 10:00:00	2023-05-08 10:45:00	Cérémonie du 78ème anniversaire de la Victoire du 8 mai 1945 à Maisons-Alfort
20810	04042C	CEREMONIE	2023-05-08 11:00:00	2023-05-08 11:45:00	Cérémonie du 78ème anniversaire de la Victoire du 8 mai 1945 à Bry-sur-Marne
20811	04042C	CEREMONIE	2023-05-08 12:00:00	2023-05-08 12:45:00	Cérémonie du 78ème anniversaire de la Victoire du 8 mai 1945 à Chennevières-sur-Marne
20812	04042C	CEREMONIE	2023-05-08 13:00:00	2023-05-08 14:30:00	Rencontre en l'honneur des Anciens combattants de Saint-Maurice
20813	04042C	CEREMONIE	2023-05-08 17:45:00	2023-05-08 18:15:00	Cérémonie du 78ème anniversaire de la Victoire du 8 mai 1945 du Conseil départemental du Val-de-Marne
20814	04042C	CEREMONIE	2023-05-08 18:30:00	2023-05-08 19:15:00	Cérémonie du 78ème anniversaire de la Victoire du 8 mai 1945 à Valenton
20815	04042C	ORG_POL	2023-05-09 11:00:00	2023-05-09 12:30:00	Réunion de Groupe des sénateurs LR du Sénat
20816	04042C	ACC_DEPL_INTER	2023-05-09 13:00:00	2023-05-09 14:30:00	Rencontre avec l'Ambassadeur de Tunisie en France
20827	11066Q	CEREMONIE	2023-05-08 11:00:00	2023-05-08 12:30:00	Cérémonie commémorant le 78ème anniversaire de la Victoire du 08 mai 1945 à Saint-Nazaire
20828	11066Q	REU_TRAV_PARL	2023-05-09 11:30:00	2023-05-09 12:30:00	Assemblée générale statutaire du groupe socialiste
20829	11066Q	REU_TRAV_PARL	2023-05-09 15:00:00	2023-05-09 16:30:00	\N
20830	11066Q	REU_TRAV_PARL	2023-05-10 08:30:00	2023-05-10 09:30:00	Réunion du Groupe socialiste de la Commission des affaires étrangères
20890	14133K	ELUS_LOCAUX	2023-03-24 12:00:00	2023-03-24 16:30:00	Visite et réunion de travail - élus de Verson (Calvados)
20901	14133K	CEREMONIE	2023-03-09 11:00:00	2023-03-09 12:00:00	cérémonie commémorative 9 mars 1945 - CAEN
20902	14133K	CEREMONIE	2023-03-09 15:00:00	2023-03-09 16:30:00	AG SLMH Caen
20903	14133K	ORG_POL	2023-03-09 19:00:00	2023-03-09 21:00:00	comité LR 6e circonscription
20904	14133K	ELUS_LOCAUX	2023-02-13 10:00:00	2023-02-13 12:30:00	rdv individuels permanence parlementaire
20905	14133K	ELUS_LOCAUX	2023-02-13 15:00:00	2023-02-13 17:30:00	réunions de travail  élus en Suisse Normande (2)
20906	14133K	REU_TRAV_PARL	2023-02-16 11:00:00	2023-02-16 12:30:00	Conférence-débat - auditeurs IHEDN 230e session - Caen
20907	14133K	CEREMONIE	2023-02-16 15:00:00	2023-02-16 16:00:00	Hommage aux héros de la Gendarmerie - CAEN
20908	14133K	ELUS_LOCAUX	2023-02-17 11:00:00	2023-02-17 12:00:00	rdv élus locaux permanence parlementaire
20909	14133K	ELUS_LOCAUX	2023-02-17 14:15:00	2023-02-17 16:15:00	visite de territoire - Vassy
20910	14133K	ELUS_LOCAUX	2023-03-06 09:30:00	2023-03-06 12:30:00	rdv individuels permanence parlementaire
20911	14133K	ELUS_LOCAUX	2023-03-06 14:30:00	2023-03-06 16:30:00	rdv individuels permanence parlementaire
20912	14133K	ORG_POL	2023-03-06 17:00:00	2023-03-06 18:30:00	réunion comité local LR
21201	04043D	ORGEXTPAR	2023-06-15 09:00:00	2023-06-15 15:00:00	Salon Vivatech 
20913	14133K	ELUS_LOCAUX	2023-02-06 09:30:00	2023-02-06 12:30:00	rdv individuels permanence parlementaire
20914	14133K	ELUS_LOCAUX	2023-02-06 14:30:00	2023-02-06 16:30:00	rdv individuels permanence parlementaire
20915	14133K	ORG_POL	2023-02-06 17:00:00	2023-02-06 18:30:00	réunion comité local LR
20916	14133K	ORG_POL	2023-02-09 09:30:00	2023-02-09 14:30:00	Séminaire Groupe LR
20917	14133K	REU_TRAV_PARL	2023-02-10 10:00:00	2023-02-10 11:30:00	Rdv acteurs économiques - Calvados
20918	14133K	ORG_POL	2023-01-30 09:30:00	2023-01-30 11:00:00	Réunion comité LR 6e circo 14
20919	14133K	REU_TRAV_PARL	2023-01-30 17:00:00	2023-01-30 18:30:00	Rdv acteurs économiques - Calvados
20924	01025N	REU_TRAV_PARL	2023-05-17 12:00:00	2023-05-17 14:30:00	entretien journaliste - agriculteurs en situation de détresse
20926	01025N	REU_TRAV_PARL	2023-05-23 20:00:00	2023-05-23 22:00:00	FNSAFER
20979	04042C	ACC_DEPL_INTER	2023-05-25 19:00:00	2023-05-25 20:00:00	Rencontre avec l'Ambassadeur d'Argentine en France à l'occasion de la Fête nationale
19941	04042C	ACC_VISIT	2022-11-17 08:50:00	2022-11-17 10:15:00	Emission TV5 Monde
19942	04042C	ACC_DEPL_INTER	2022-11-17 11:00:00	2022-11-17 12:00:00	Entretien avec l'Ambassadeur d'Arabie Saoudite en France
19943	04042C	ACC_DEPL_INTER	2022-11-17 12:30:00	2022-11-17 13:30:00	Rencontre avec l'Ambassadeur d'Allemagne en France à l'occasion du 67ème anniversaire de la Fondation des Forces allemandes
19944	04042C	COLL_TER	2022-11-17 14:00:00	2022-11-17 15:00:00	Réunion départementale du SDRIF-Environnemental
19945	04042C	ORG_POL	2022-11-22 11:00:00	2022-11-22 12:30:00	Réunion de Groupe des sénateurs LR du Sénat
19946	04042C	ACC_DEPL_INTER	2022-11-22 13:00:00	2022-11-22 14:30:00	Rencontre avec l'Ambassadeur du Brésil en France
19947	04042C	ACC_DEPL_INTER	2022-11-22 15:00:00	2022-11-22 15:45:00	Entretien avec la Ministre de l'Intérieur de la République de Moldavie
19948	04042C	ACC_VISIT	2022-11-22 16:15:00	2022-11-22 17:00:00	Interview Figaro Live
19949	04042C	ORG_POL	2022-11-22 19:30:00	2022-11-22 21:00:00	Réunion publique dans le Val-de-Marne
19950	04042C	REU_TRAV_PARL	2022-11-23 09:15:00	2022-11-23 10:00:00	Réunion des commissaires L.R du Sénat
19951	04042C	ACC_VISIT	2022-11-23 12:00:00	2022-11-23 14:30:00	Congrès des Maires
19952	04042C	REU_TRAV_PARL	2022-11-23 16:30:00	2022-11-23 17:30:00	Réunion avec des Sénateures du Groupe Interparlementaire d'Amitié France-Maroc
19953	04042C	ACC_VISIT	2022-11-23 17:30:00	2022-11-23 18:00:00	Entretien avec le Président-directeur général de Public Sénat
19954	04042C	REU_TRAV_PARL	2022-11-23 18:00:00	2022-11-23 19:00:00	Réunion de Direction
19955	04042C	ACC_VISIT	2022-11-23 19:00:00	2022-11-23 21:30:00	Rencontre avec des élus du Val-de-Marne
19956	04042C	DEPL_PRES_GVT	2022-11-24 09:00:00	2022-11-24 00:00:00	Déplacement officielle en Serbie aux côtés du Président du Sénat
19957	04042C	DEPL_PRES_GVT	2022-11-25 00:00:00	2022-11-25 00:00:00	Déplacement officielle en Serbie aux côtés du Président du Sénat
19961	04042C	ELUS_LOCAUX	2022-11-28 10:00:00	2022-11-28 12:30:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
19962	04042C	COLL_TER	2022-11-28 13:00:00	2022-11-28 14:30:00	Rencontre avec des élus du Val-de-Marne
20023	04042C	REU_TRAV_PARL	2022-12-06 18:00:00	2022-12-06 19:00:00	Entretien avec le Président du Sénat et le Ministre des Armées
20021	04042C	ORG_POL	2022-12-06 11:00:00	2022-12-06 12:00:00	Réunion de Groupe des sénateurs LR du Sénat
20022	04042C	ACC_DEPL_INTER	2022-12-06 12:30:00	2022-12-06 14:00:00	Rencontre avec l'Ambassadeur de Finlande à l'occasion de la Fête nationale
20182	04042C	REU_TRAV_PARL	2023-01-10 13:00:00	2023-01-10 14:30:00	Rencontre avec des anciens élèves de l'Ecole Polytechnique
20025	04042C	CEREMONIE	2022-12-06 19:30:00	2022-12-06 21:30:00	Cité de la Gastronomie dans le Val-de-Marne
20029	04042C	DEPL_PRES_GVT	2022-12-08 00:00:00	2022-12-08 00:00:00	Déplacement officiel au Vietnam aux côtés du Président du Sénat
20028	04042C	DEPL_PRES_GVT	2022-12-07 13:00:00	2022-12-07 00:00:00	Déplacement officiel au Vietnam aux côtés du Président du Sénat
20181	04042C	ORG_POL	2023-01-10 11:00:00	2023-01-10 12:30:00	Réunion de Groupe des sénateurs LR du Sénat
20183	04042C	REU_TRAV_PARL	2023-01-10 15:30:00	2023-01-10 16:30:00	Entretien avec 2 sénateurs
20184	04042C	ELUS_LOCAUX	2023-01-10 16:30:00	2023-01-10 17:30:00	Entretien avec un élu du Val-de-Marne
20185	04042C	ACC_DEPL_INTER	2023-01-10 18:00:00	2023-01-10 19:30:00	Réception d'ouverture de la Présidence suédoise du Conseil de l'Union européenne
20186	04042C	REU_TRAV_PARL	2023-01-11 13:00:00	2023-01-11 14:00:00	Réunion avec les Présidents de Commission, le Rapporteur général et référents de Commission
20187	04042C	ELUS_LOCAUX	2023-01-11 15:00:00	2023-01-11 17:00:00	Inauguration du Poste de police municipale et CSU de Choisy-le-Roi
20188	04042C	ELUS_LOCAUX	2023-01-11 17:30:00	2023-01-11 18:30:00	Entretien avec deux élus du Val-de-Marne
20189	04042C	CEREMONIE	2023-01-11 19:00:00	2023-01-11 21:00:00	Cérémonie des Voeux de la Région Ile-de-France
20190	04042C	ELUS_LOCAUX	2023-01-12 12:30:00	2023-01-12 14:00:00	Rencontre avec un élu du Val-de-Marne
20191	04042C	ACC_DEPL_INTER	2023-01-12 15:15:00	2023-01-12 16:15:00	Visioconférence avec le Président de la Rada
20192	04042C	ACC_VISIT	2023-01-12 18:45:00	2023-01-12 19:00:00	Emission Sens Public - Public Sénat
20196	04042C	ELUS_LOCAUX	2023-01-13 13:00:00	2023-01-13 14:30:00	Rencontre avec des élus du Val-de-Marne
20194	04042C	REU_GVT	2023-01-13 09:00:00	2023-01-13 11:30:00	Réunion avec la Ministre déléguée des Collectivités territoriales et la Préfète du Val-de-Marne et des élus du Val-de-Marne
20195	04042C	CEREMONIE	2023-01-13 12:00:00	2023-01-13 12:45:00	Cérémonie des voeux du Syndicat des Eaux d'Ile-de-France
20197	04042C	REU_TRAV_PARL	2023-01-13 15:00:00	2023-01-13 16:00:00	Rencontre avec un général de corps d'armée
20198	04042C	ELUS_LOCAUX	2023-01-13 16:00:00	2023-01-13 17:00:00	Rencontre avec un élu du Val-de-Marne
20199	04042C	CEREMONIE	2023-01-13 19:30:00	2023-01-13 21:00:00	Cérémonie des voeux à Périgny-sur-Yerres
20200	04042C	ELUS_LOCAUX	2023-01-16 10:30:00	2023-01-16 12:00:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
20201	04042C	ELUS_LOCAUX	2023-01-16 13:00:00	2023-01-16 14:30:00	Rencontre avec des élus du Val-de-Marne
20202	04042C	ELUS_LOCAUX	2023-01-16 15:00:00	2023-01-16 16:00:00	Entretien avec un élu du Val-de-Marne
20203	04042C	ORG_POL	2023-01-17 11:00:00	2023-01-17 12:30:00	Réunion de Groupe des sénateurs LR du Sénat
20204	04042C	REU_TRAV_PARL	2023-01-17 08:00:00	2023-01-17 09:00:00	Entretien avec le Chef d'état-major des armées
20205	04042C	CEREMONIE	2023-01-17 12:30:00	2023-01-17 14:00:00	Cérémonie des Voeux à l'Assemblée nationale
20206	04042C	ELUS_LOCAUX	2023-01-17 15:00:00	2023-01-17 16:00:00	Entretien avec un élu du Val-de-Marne
20207	04042C	ACC_VISIT	2023-01-17 16:00:00	2023-01-17 17:00:00	Entretien avec le Président du Cercle Eugène Delacroix
20208	04042C	REU_TRAV_PARL	2023-01-17 17:00:00	2023-01-17 18:00:00	Réunion de Direction
20209	04042C	ACC_DEPL_INTER	2023-01-17 18:45:00	2023-01-17 21:00:00	Concert Hommage à Ennio Morricone à l'Ambassade d'Italie
20210	04042C	REU_GVT	2023-01-18 16:15:00	2023-01-18 16:30:00	Entretien avec le Ministre des armées
20211	04042C	CEREMONIE	2023-01-18 19:00:00	2023-01-18 21:00:00	Cérémonie des voeux du GICAT
20325	04043D	ORG_POL	2022-04-27 10:30:00	2022-04-27 15:30:00	Séminaire - Groupe Les Républicains
20326	04043D	ORGEXTPAR	2022-11-22 17:30:00	2022-11-22 18:30:00	Conseil de surveillance - Ministère de l'Agriculture
20328	04042C	ACC_DEPL_INTER	2023-02-01 20:00:00	2023-02-01 21:30:00	Rencontre avec l'Ambassadrice d'Italie en France à l'occasion de l'entrée en vigueur du Traité Quirinal
20329	04042C	ACC_VISIT	2023-02-02 07:45:00	2023-02-02 08:30:00	Emission Public Sénat
20331	04042C	ACC_DEPL_INTER	2023-02-02 17:00:00	2023-02-02 18:00:00	Entretien avec l'Ambassadeur du Chili en France
20332	04042C	ACC_DEPL_INTER	2023-02-02 18:00:00	2023-02-02 19:00:00	Réunion de travail avec des ambassadeurs
20333	04042C	ACC_DEPL_INTER	2023-02-02 19:30:00	2023-02-02 20:30:00	Rencontre avec l'Ambassadeur d'Argentine en France en l'honneur des musiciens de l'académie de l'Opéra de Paris
20341	04043D	ACC_VISIT	2023-02-08 18:15:00	2023-02-08 19:15:00	Visite du Sénat - Club Entreprendre en Plateau Briard
20342	11066Q	REU_TRAV_PARL	2022-12-13 15:00:00	2022-12-13 16:30:00	\N
20343	11066Q	ACC_VISIT	2022-12-13 17:00:00	2022-12-13 18:00:00	Entretien avec Monsieur Thibaut Guilluy, Haut Commissaire à l'Emploi et à l'Engagement
20344	11066Q	ACC_VISIT	2022-12-15 14:00:00	2022-12-15 17:00:00	Accueil Permanence
20345	11066Q	COLL_TER	2022-12-16 09:30:00	2022-12-16 12:00:00	Réunion du Comité d'Orientation stratégique de l'étude de zone de surmortalité de l'agglomération nazairienne
20346	11066Q	ACC_VISIT	2022-12-16 14:00:00	2022-12-16 17:00:00	Accueil Permanence
20347	11066Q	ACC_VISIT	2023-01-09 09:00:00	2023-01-09 12:30:00	Accueil Permanence
20348	11066Q	ACC_VISIT	2023-01-09 14:00:00	2023-01-09 17:00:00	Accueil Permanence
20349	11066Q	ACC_VISIT	2023-01-02 09:00:00	2023-01-02 12:30:00	Accueil Permanence
20350	11066Q	ACC_VISIT	2023-01-02 14:00:00	2023-01-02 17:00:00	Accueil Permanence
20351	11066Q	ACC_VISIT	2023-01-03 09:00:00	2023-01-03 12:30:00	Accueil Permanence
20352	11066Q	ACC_VISIT	2023-01-03 14:00:00	2023-01-03 17:00:00	Accueil Permanence
20353	11066Q	ACC_VISIT	2023-01-04 09:00:00	2023-01-04 12:30:00	Accueil Permanence
20354	11066Q	ACC_VISIT	2023-01-04 14:00:00	2023-01-04 17:00:00	Accueil Permanence
20072	11066Q	ACC_VISIT	2022-11-04 09:00:00	2022-11-04 17:00:00	Accueil Permanence
20073	11066Q	ACC_VISIT	2022-11-07 09:00:00	2022-11-07 16:00:00	Accueil Permanence
20074	11066Q	ACC_VISIT	2022-11-07 16:00:00	2022-11-07 17:00:00	Entretien sur la proposition de Loi sur les déserts médicaux
20082	11066Q	ACC_VISIT	2022-11-23 11:00:00	2022-11-23 15:00:00	Accueil de la porte-parole du Collectif Stop aux cancers de nos enfants
20083	11066Q	ORGEXTPAR	2022-11-23 17:00:00	2022-11-23 18:30:00	Réunion collégiale de la Commission nationale de Contrôle des Techniques de Renseignement
20084	11066Q	ACC_VISIT	2022-11-24 14:00:00	2022-11-24 17:00:00	Accueil Permanence
20085	11066Q	ACC_VISIT	2022-11-25 09:00:00	2022-11-25 17:00:00	Accueil Permanence
20086	11066Q	ACC_VISIT	2022-11-28 09:00:00	2022-11-28 17:00:00	Accueil Permanence
20101	04042C	ACC_DEPL_INTER	2022-12-12 19:30:00	2022-12-12 20:30:00	Inauguration de l'exposition « Leçons de démocratie. Cent ans de dialogue entre la France et la Lituanie » consacrée au centenaire des relations bilatérales entre la Lituanie et la France à l'Ambassade de Lituanie
20102	04042C	ORG_POL	2022-12-13 11:00:00	2022-12-13 12:00:00	Réunion de Groupe des sénateurs LR du Sénat
20103	04042C	ACC_DEPL_INTER	2022-12-13 13:00:00	2022-12-13 14:15:00	Rencontre avec le Président du Sénat et la Présidnte du Parlement lituanien
20104	04042C	ACC_VISIT	2022-12-13 15:00:00	2022-12-13 16:00:00	Entretien avec le Procureur de la République du Val-de-Marne
20105	04042C	ACC_DEPL_INTER	2022-12-13 16:00:00	2022-12-13 17:00:00	Entretien avec l'Ambassadrice du Kazakhstan en France
20106	04042C	ACC_DEPL_INTER	2022-12-13 17:00:00	2022-12-13 18:00:00	Entretien avec l'Ambassadeur de la République du Kosovo en France
20107	04042C	ACC_DEPL_INTER	2022-12-13 18:00:00	2022-12-13 19:00:00	Entretien avec le Vice-président de l'Assemblée nationale de la République d'Arménie
20108	04042C	REU_TRAV_PARL	2022-12-13 20:00:00	2022-12-13 21:30:00	Rencontre avec les sénateurs LR du Sénat
20109	04042C	ACC_VISIT	2022-12-14 14:45:00	2022-12-14 15:00:00	Interview Public Sénat
20141	04043D	REU_TRAV_PARL	2022-12-12 00:00:00	2022-12-12 00:00:00	Colloque chlordécone - Guedeloupe
20142	04043D	REU_TRAV_PARL	2022-12-13 00:00:00	2022-12-13 00:00:00	Colloque chlordécone - Guadeloupe
20143	04043D	REU_TRAV_PARL	2022-12-14 00:00:00	2022-12-14 00:00:00	Colloque chlordécone - Guadeloupe
20144	04043D	REU_TRAV_PARL	2022-12-15 00:00:00	2022-12-15 00:00:00	Colloque chlordécone - Guadeloupe
20355	11066Q	CEREMONIE	2023-01-04 18:30:00	2023-01-04 20:00:00	Voeux de la Ville de Saint-Nazaire
20356	11066Q	ACC_VISIT	2023-01-05 09:00:00	2023-01-05 11:00:00	Accueil Permanence
20357	11066Q	ACC_VISIT	2023-01-05 11:00:00	2023-01-05 12:30:00	Entretien avec la Présidente départementale du Secours populaire
20358	11066Q	ACC_VISIT	2023-01-05 14:00:00	2023-01-05 17:00:00	Accueil Permanence
20359	11066Q	CEREMONIE	2023-01-05 18:30:00	2023-01-05 20:00:00	Voeux de la Ville de Nantes
20360	11066Q	ACC_VISIT	2023-01-06 09:00:00	2023-01-06 12:30:00	Accueil Permanence
20361	11066Q	ACC_VISIT	2023-01-06 14:00:00	2023-01-06 17:00:00	Accueil Permanence
20362	11066Q	ACC_VISIT	2023-01-12 09:00:00	2023-01-12 12:30:00	Accueil Permanence
20363	11066Q	ACC_VISIT	2023-01-12 14:00:00	2023-01-12 17:00:00	Accueil Permanence
20364	11066Q	ACC_VISIT	2023-01-13 09:00:00	2023-01-13 12:30:00	Accueil Permanence
20365	11066Q	ACC_VISIT	2023-01-13 14:00:00	2023-01-13 17:00:00	Accueil Permanence
20366	11066Q	ACC_VISIT	2023-01-16 09:00:00	2023-01-16 12:30:00	Accueil Permanence
20367	11066Q	ACC_VISIT	2023-01-16 14:00:00	2023-01-16 17:00:00	Accueil Permanence
20370	11066Q	REU_TRAV_PARL	2023-01-18 08:30:00	2023-01-18 09:30:00	Réunion du Groupe socialiste de la Commission des affaires étrangères
20371	11066Q	ACC_VISIT	2023-01-19 09:00:00	2023-01-19 12:30:00	Accueil Permanence
20372	11066Q	ACC_VISIT	2023-01-19 14:00:00	2023-01-19 17:00:00	Accueil Permanence
20373	11066Q	ACC_VISIT	2023-01-20 09:00:00	2023-01-20 12:30:00	Accueil Permanence
20374	11066Q	ACC_VISIT	2023-01-20 14:00:00	2023-01-20 17:00:00	Accueil Permanence
20375	11066Q	ACC_VISIT	2023-01-23 09:00:00	2023-01-23 12:30:00	Accueil Permanence
20376	11066Q	ACC_VISIT	2023-01-23 14:00:00	2023-01-23 17:00:00	Accueil Permanence
20377	11066Q	ORGEXTPAR	2023-01-25 17:00:00	2023-01-25 18:00:00	Réunion collégiale de la Commission nationale de Contrôle des Techniques de Renseignement
20378	11066Q	ACC_VISIT	2023-01-26 09:00:00	2023-01-26 12:30:00	Accueil Permanence
20379	11066Q	ACC_VISIT	2023-01-26 14:00:00	2023-01-26 17:00:00	Accueil Permanence
20380	11066Q	ACC_VISIT	2023-01-27 09:00:00	2023-01-27 10:00:00	Accueil Permanence
20381	11066Q	CEREMONIE	2023-01-27 11:30:00	2023-01-27 12:30:00	Voeux du Préfet de Région à Nantes
20382	11066Q	COLL_TER	2023-01-27 13:30:00	2023-01-27 15:30:00	Commission des élus pour la Dotation Equipement Territoires ruraux
20383	11066Q	ACC_VISIT	2023-01-30 09:00:00	2023-01-30 12:30:00	Accueil Permanence
20384	11066Q	ACC_VISIT	2023-01-30 14:00:00	2023-01-30 15:00:00	Accueil Permanence
20385	11066Q	CEREMONIE	2023-01-30 15:00:00	2023-01-30 16:00:00	Audience solennelle de rentrée du Tribunnal judiciaire de Saint-Nazaire
20386	11066Q	REU_TRAV_PARL	2023-01-31 10:00:00	2023-01-31 12:00:00	Réunion de groupe
20387	11066Q	REU_TRAV_PARL	2023-02-01 08:30:00	2023-02-01 09:30:00	Réunion du Groupe socialiste de la Commission des affaires étrangères
20388	11066Q	ACC_VISIT	2023-02-03 09:00:00	2023-02-03 12:30:00	Accueil Permanence
20389	11066Q	ACC_VISIT	2023-02-03 14:00:00	2023-02-03 17:00:00	Accueil Permanence
20390	11066Q	ACC_VISIT	2023-02-06 09:00:00	2023-02-06 12:00:00	Accueil Permanence
20391	11066Q	REU_GVT	2023-02-06 12:00:00	2023-02-06 12:30:00	Entretien avec les conseiller du Ministre délégué en charge de l'Industrie à propos de l'entreprise RFS
20392	11066Q	ACC_VISIT	2023-02-06 14:00:00	2023-02-06 17:00:00	Accueil Permanence
20393	11066Q	ORGEXTPAR	2023-02-08 17:00:00	2023-02-08 18:00:00	Réunion collégiale de la Commission nationale de Contrôle des Techniques de Renseignement
20398	11066Q	ACC_VISIT	2023-02-13 09:00:00	2023-02-13 11:00:00	Accueil Permanence
20399	11066Q	ACC_VISIT	2023-02-13 11:00:00	2023-02-13 12:30:00	Entretien avec le secrétaire national adjoint du SNPJ-CFDT sur le projet de réforme des retraites
20400	11066Q	ACC_VISIT	2023-02-13 14:00:00	2023-02-13 17:00:00	Accueil Permanence
20401	04043D	CEREMONIE	2022-11-09 18:00:00	2022-11-09 18:30:00	Cérémonie De Gaulle - Saint-Mandé
20402	04043D	CEREMONIE	2022-11-09 18:30:00	2022-11-09 19:00:00	Cérémonie De Gaulle - Vincennes
20403	04043D	REU_TRAV_PARL	2022-10-27 14:30:00	2022-10-27 15:30:00	RDV lutte contre le tabagisme 
20404	04043D	ACC_VISIT	2022-10-27 16:30:00	2022-10-27 17:30:00	RDV SGP Police 94 - Syndicat de Police
20405	04043D	REU_TRAV_PARL	2022-10-07 10:00:00	2022-10-07 12:00:00	Séminaire Sc. Po - "Le risque de l'antibiorésistance"
20406	04043D	CEREMONIE	2022-08-30 11:00:00	2022-08-30 12:00:00	Cérémonie militaire - départ Directeur des hôpitaux des armées
20643	04042C	REU_GVT	2023-03-22 18:00:00	2023-03-22 21:00:00	Comité de liaison relatif à la situation en Ukraine à Matignon
20442	04043D	COLL_TER	2022-05-13 11:00:00	2022-05-13 12:00:00	Inauguration des supports de sensibilisation des joinvillais à la préservation de la Marne
20443	04043D	REU_TRAV_PARL	2022-05-02 08:15:00	2022-05-02 08:20:00	Interview France Bleu - Pièces d'identité
20444	01025N	REU_TRAV_PARL	2023-02-07 19:00:00	2023-02-07 21:30:00	Task force fruits et légumes frais
20445	01025N	REU_TRAV_PARL	2023-02-15 13:45:00	2023-02-15 15:00:00	retraites Groupe UC
20641	04042C	REU_TRAV_PARL	2023-03-22 12:30:00	2023-03-22 14:00:00	Rencontre avec les Présidents de Commission, le Rapporteur général et référents de Commission
20642	04042C	ACC_DEPL_INTER	2023-03-22 14:00:00	2023-03-22 15:00:00	Entretien avec le Président de la Commission des Affaires étrangères de Roumanie
20644	04042C	ELUS_LOCAUX	2023-03-23 10:30:00	2023-03-23 11:30:00	Entretien avec un élu du Val-de-Marne
20648	04042C	ORG_POL	2023-03-28 11:00:00	2023-03-28 12:30:00	Réunion de groupe des sénateurs L.R
20646	04042C	CEREMONIE	2023-03-24 11:00:00	2023-03-24 12:00:00	Cérémonie en hommage au Colonel Beltrame à l'Haÿ-les-Roses
20647	04042C	REU_GVT	2023-03-28 13:00:00	2023-03-28 14:30:00	Rencontre avec la Secrétaire d¿Etat chargée du développement, de la francophonie et des partenariats internationaux
20649	04042C	ACC_VISIT	2023-03-28 15:00:00	2023-03-28 16:00:00	Entretien avec des élus du Val-de-Marne
20650	04042C	REU_TRAV_PARL	2023-03-28 16:00:00	2023-03-28 17:00:00	Entretien avec des sénateurs
20651	04042C	CEREMONIE	2023-03-28 19:00:00	2023-03-28 20:00:00	Cérémonie de remise des insignes de Chevalier de la Légion d'Honneur
20652	04042C	ACC_DEPL_INTER	2023-03-29 13:00:00	2023-03-29 14:30:00	Rencontre avec l'Ambassadeur de Suède en France
20041	11066Q	ACC_VISIT	2022-09-29 14:00:00	2022-09-29 17:00:00	Accueil Permanence
20042	11066Q	ACC_VISIT	2022-09-30 09:00:00	2022-09-30 17:00:00	Accueil Permanence
20043	11066Q	ACC_VISIT	2022-10-03 09:00:00	2022-10-03 17:00:00	Accueil Permanence
20044	11066Q	ACC_VISIT	2022-10-04 09:00:00	2022-10-04 14:00:00	Accueil Permanence
20045	11066Q	ORGEXTPAR	2022-10-05 17:00:00	2022-10-05 18:30:00	Réunion collégiale de la Commission nationale de Contrôle des Techniques de Renseignement
20046	11066Q	ACC_VISIT	2022-10-06 14:00:00	2022-10-06 17:00:00	Accueil Permanence
20047	11066Q	ACC_VISIT	2022-10-07 09:00:00	2022-10-07 17:00:00	Accueil Permanence
20048	11066Q	ACC_VISIT	2022-10-10 09:00:00	2022-10-10 17:00:00	Accueil Permanence
20049	11066Q	ACC_VISIT	2022-10-14 09:00:00	2022-10-14 17:00:00	Accueil Permanence
20075	11066Q	ORGEXTPAR	2022-11-09 17:00:00	2022-11-09 18:30:00	Réunion collégiale de la Commission nationale de Contrôle des Techniques de Renseignement
20076	11066Q	CEREMONIE	2022-11-11 11:00:00	2022-11-11 12:30:00	Cérémonie en hommage des morts pour la France à l'occasion du 104ème anniversaire de l'armistice du 11 novembre 1918
20077	11066Q	ACC_VISIT	2022-11-14 09:00:00	2022-11-14 17:00:00	Accueil Permanence
20078	11066Q	ORGEXTPAR	2022-11-16 17:00:00	2022-11-16 18:30:00	Réunion collégiale de la Commission nationale de Contrôle des Techniques de Renseignement
20079	11066Q	ACC_VISIT	2022-11-18 09:00:00	2022-11-18 17:00:00	Accueil Permanence
20080	11066Q	ACC_VISIT	2022-11-21 09:00:00	2022-11-21 17:00:00	Accueil Permanence
20081	11066Q	ACC_VISIT	2022-11-22 12:30:00	2022-11-22 14:00:00	Rencontre avec les Maires de Loire-Atlantique dans le cadre du Congrès des Maires
20087	11066Q	REU_TRAV_PARL	2022-11-29 14:30:00	2022-11-29 15:30:00	\N
20088	11066Q	ORGEXTPAR	2022-12-01 09:00:00	2022-12-01 11:30:00	Réunion Plénière de la Commission nationale des Techniques de Renseignement
20089	11066Q	ACC_VISIT	2022-12-02 09:00:00	2022-12-02 17:00:00	Accueil Permanence
20090	11066Q	ACC_VISIT	2022-12-02 10:00:00	2022-12-02 11:00:00	Entretien avec le Général Le Gentil, Commandant en second de la Région de gendarmerie des Pays de la Loire, et du groupement de Loire-Atlantique
20091	11066Q	ACC_VISIT	2022-12-05 09:00:00	2022-12-05 17:00:00	Accueil Permanence
20092	11066Q	ORGEXTPAR	2022-12-07 17:00:00	2022-12-07 18:30:00	Réunion collégiale de la Commission nationale de Contrôle des Techniques de Renseignement
20093	11066Q	ACC_VISIT	2022-12-09 09:00:00	2022-12-09 17:00:00	Accueil Permanence
20094	11066Q	ACC_VISIT	2022-12-12 09:00:00	2022-12-12 17:00:00	Accueil Permanence
20225	04042C	REU_TRAV_PARL	2023-01-24 13:00:00	2023-01-24 14:30:00	Rencontre avec la Présidente de l'Assemblée nationale
20226	04042C	ACC_DEPL_INTER	2023-01-24 19:30:00	2023-01-24 21:30:00	Rencontre avec l'Ambassadrice du Royaume-Uni à l'occasion du Burns Night Supper
20261	04042C	CEREMONIE	2023-01-25 17:00:00	2023-01-25 18:00:00	Remise de décoration de l'Ordre du Mérite par l'Ambassadeur d'Ukraine en France
20262	04042C	REU_TRAV_PARL	2023-01-26 16:00:00	2023-01-26 17:00:00	Entretien avec un Conseiller parlemenatire
20263	04042C	ACC_DEPL_INTER	2023-01-26 18:30:00	2023-01-26 19:30:00	Rencontre avec l'Ambassadeur d'Inde en France à l'occasion du jour de la République d'Inde
20264	04042C	CEREMONIE	2023-01-26 20:00:00	2023-01-26 21:00:00	Cérémonie des Voeux à Chennevières-sur-Marne
20265	04042C	ELUS_LOCAUX	2023-01-27 13:00:00	2023-01-27 14:15:00	Rencontre avec des élus du Val-de-Marne
20266	04042C	ACC_DEPL_INTER	2023-01-27 15:30:00	2023-01-27 16:30:00	Entretien avec l'Ambassadrice d'Azerbaïdjan en France
20267	04042C	COLL_TER	2023-01-27 17:30:00	2023-01-27 18:30:00	Entretien avec la Présidente de la Région d'Ile-de-France
20268	04042C	CEREMONIE	2023-01-27 19:30:00	2023-01-27 20:30:00	Cérémonie des Voeux à Villecresnes
20269	04042C	CEREMONIE	2023-01-30 10:30:00	2023-01-30 12:00:00	Audience solennelle de rentrée au Tribunal Judiciaire de Créteil
20270	04042C	COLL_TER	2023-01-30 12:30:00	2023-01-30 14:00:00	Réunion de travail avec la Préfète du Val-de-Marne
20271	04042C	ORG_POL	2023-01-31 11:00:00	2023-01-31 12:30:00	Réunion de Groupe des sénateurs LR du Sénat
20272	04042C	ACC_DEPL_INTER	2023-01-31 16:00:00	2023-01-31 17:00:00	Entretien avec l'Ambassadrice d'Islande en France
20273	04042C	REU_TRAV_PARL	2023-01-31 17:00:00	2023-01-31 18:00:00	Réunion de Direction
20274	04042C	REU_TRAV_PARL	2023-01-31 20:00:00	2023-01-31 21:30:00	Rencontre avec les Présidents de Commission, le Rapporteur général et référents de Commission
20275	04042C	ACC_DEPL_INTER	2023-01-31 19:00:00	2023-01-31 19:45:00	Rencontre avec l'Ambassadeur de Cuba en France à l'occasion de la Fête Nationale et du 65ème anniversaire de la Révolution cubaine
20301	04043D	COLLOQUE	2023-02-06 14:00:00	2023-02-06 16:00:00	Assemblée générale - CIFCH
20302	04043D	CEREMONIE	2023-01-27 12:15:00	2023-01-27 14:00:00	Voeux - Hôpital Saint-Camille
20481	04042C	ELUS_LOCAUX	2023-02-16 12:45:00	2023-02-16 14:00:00	Rencontre avec un élu du Val-de-Marne
20482	04042C	CEREMONIE	2023-02-16 15:00:00	2023-02-16 16:30:00	Hommage national aux héros de la gendarmerie à Maisons-Alfort
20483	04042C	ACC_VISIT	2023-02-16 17:00:00	2023-02-16 18:00:00	Entretien avec 2 administrateurs du CIDAN
20306	04043D	COLL_TER	2022-12-06 19:00:00	2022-12-06 20:00:00	Cité de la gastronomie - 94
20307	04043D	REU_TRAV_PARL	2022-12-09 00:00:00	2022-12-09 00:00:00	Visite aux Dunes - Société Générale
20308	04043D	ACC_VISIT	2022-12-07 16:30:00	2022-12-07 18:00:00	RDV FIVAPE - cigarette électronique
20484	04042C	ACC_VISIT	2023-02-16 19:00:00	2023-02-16 22:00:00	Visite du Palais du Luxembourg d'un Conseil municipal du Val-de-Marne
20310	04043D	ACC_VISIT	2022-10-20 10:00:00	2022-10-20 11:00:00	RDV Huaweï
20311	04043D	ACC_VISIT	2022-10-18 16:30:00	2022-10-18 17:30:00	Réunion nouvel ambassadeur - Vanuatu
20485	04042C	ELUS_LOCAUX	2023-02-17 10:30:00	2023-02-17 11:30:00	Réunion de travail avec des élus du Val-de-Marne
20486	04042C	DEPL_PRES_GVT	2023-02-17 12:30:00	2023-02-17 19:00:00	Visite du Président du Sénat dans le Val-de-Marne
20487	04042C	ACC_VISIT	2023-02-17 19:00:00	2023-02-17 22:00:00	Visite du Palais du Luxembourg d'un Conseil municipal du Val-de-Marne
20488	04042C	ELUS_LOCAUX	2023-02-27 13:00:00	2023-02-27 14:15:00	Rencontre avec un élu du Val-de-Marne
20489	04042C	REU_GVT	2023-02-27 17:00:00	2023-02-27 18:00:00	Discours du Président de la République sur le partenariat avec l'Afrique
20490	04042C	CEREMONIE	2023-02-27 18:30:00	2023-02-27 22:00:00	Soirée annuelle du Club de la Table française
20491	04042C	ORG_POL	2023-02-28 10:30:00	2023-02-28 12:30:00	Réunion de Groupe des sénateurs LR du Sénat
20492	04042C	ELUS_LOCAUX	2023-02-28 13:00:00	2023-02-28 14:15:00	Rencontre avec un élu du Val-de-Marne
20493	04042C	ACC_VISIT	2023-02-28 15:00:00	2023-02-28 16:00:00	Entretien avec le Secrétaire général de la Préfecture du Val-de-MArne
20494	04042C	REU_TRAV_PARL	2023-03-01 11:15:00	2023-03-01 12:15:00	Entretien avec un sénateur
20495	04042C	ELUS_LOCAUX	2023-03-01 12:30:00	2023-03-01 14:00:00	Rencontre avec des élus du Val-de-Marne
20496	04042C	ACC_VISIT	2023-03-01 16:30:00	2023-03-01 17:30:00	Entretien avec le Coordinateur National du Renseignement et de la Lutte contre le Terrorisme
20541	04043D	REU_TRAV_PARL	2023-03-10 10:00:00	2023-03-10 12:00:00	Visite de Cenexi - Fontenay-sous-Bois
20581	04042C	CEREMONIE	2023-03-17 10:00:00	2023-03-17 11:30:00	Pose de la 1ère pierre du bâtiment de recherche biomédicale à l'Université Paris-Est Créteil
20582	04042C	ACC_DEPL_INTER	2023-03-17 12:00:00	2023-03-17 13:30:00	Entretien avec des parlementaires de Côte d'Ivoire
20583	04042C	ELUS_LOCAUX	2023-03-17 17:30:00	2023-03-17 18:30:00	entretien avec un élu du Val-de-Marne
20584	04042C	CEREMONIE	2023-03-17 19:00:00	2023-03-17 20:00:00	Vernissage du 18ème salon de Bry
20585	04042C	ACC_VISIT	2023-03-20 11:30:00	2023-03-20 12:30:00	Rendez-vous à la Mairie de Saint-Maurice
20586	04042C	ACC_DEPL_INTER	2023-03-20 13:00:00	2023-03-20 14:15:00	Rencontre avec l'Ambassadeur de Grèce en France à l'occasion de la Fête Nationale de la Grèce
20587	04042C	REU_TRAV_PARL	2023-03-20 15:00:00	2023-03-20 16:00:00	Entretien avec le Chef d'état-major de l'armée de Terre
20588	04042C	REU_TRAV_PARL	2023-03-21 08:45:00	2023-03-21 09:45:00	Intervention au Cercle National des Armées
20589	04042C	ORG_POL	2023-03-21 10:15:00	2023-03-21 11:00:00	Réunion du bureau du groupe des séanteurs L.R 
20590	04042C	ORG_POL	2023-03-21 11:00:00	2023-03-21 12:00:00	Réunion de groupe des sénateurs L.R
20591	04042C	ACC_VISIT	2023-03-21 13:15:00	2023-03-21 14:15:00	Rencontre avec un élu du Val-de-Marne
20592	04042C	ACC_VISIT	2023-03-21 15:30:00	2023-03-21 16:30:00	Entretien avec le Président-directeur général du CNES
19981	11103C	REU_GVT	2022-11-30 15:00:00	2022-11-30 16:00:00	avec Bérangère Couillard, secrétaire d'Etat chargée de l'écologie
20368	11066Q	CEREMONIE	2023-01-17 19:00:00	2023-01-17 20:00:00	Voeux du Président du Sénat
20396	11066Q	ACC_VISIT	2023-02-10 14:00:00	2023-02-10 15:30:00	Accueil Permanence
20394	11066Q	ACC_VISIT	2023-02-09 14:00:00	2023-02-09 17:00:00	Accueil Permanence
20395	11066Q	ACC_VISIT	2023-02-10 09:00:00	2023-02-10 12:30:00	Accueil Permanence
20397	11066Q	ACC_VISIT	2023-02-10 15:30:00	2023-02-10 16:30:00	Entretien avec les représentants du personnel du l'entreprise RFS
20593	04042C	ACC_DEPL_INTER	2023-03-21 16:30:00	2023-03-21 17:30:00	Entretien avec le Représentant de Taïwan en France
20601	04043D	ORG_POL	2023-03-28 18:00:00	2023-03-28 19:00:00	Réunion Les Républicains Outre-Mer - Chlordécone
20595	04042C	ACC_DEPL_INTER	2023-03-21 17:30:00	2023-03-21 18:30:00	Entretien avec l'envoyé spécial du Président de la République d'Azerbaïdjan
20596	04042C	ACC_DEPL_INTER	2023-03-21 19:00:00	2023-03-21 20:30:00	Rencontre avec l'Ambassadeur de Tunisie en France à l'occasion du 67ème anniversaire de l'Indépendance de la Tunisie
20621	01025N	REU_TRAV_PARL	2023-03-20 14:00:00	2023-03-20 15:00:00	Echanges avec un éco-organisme
20622	01025N	REU_TRAV_PARL	2023-03-22 14:00:00	2023-03-22 15:00:00	Audition d'une entreprise de santé humaines et végétale
20653	04042C	REU_TRAV_PARL	2023-03-29 16:30:00	2023-03-29 17:30:00	Entretien avec un sénateur
20654	04042C	ACC_VISIT	2023-03-29 18:00:00	2023-03-29 19:00:00	Entretien avec des élus du Val-de-Marne
20655	04042C	ACC_VISIT	2023-03-29 20:00:00	2023-03-29 21:30:00	Rencontre avec des élus
20661	04042C	ELUS_LOCAUX	2023-03-30 15:30:00	2023-03-30 16:30:00	Entretien avec un élu du Val-de-Marne
20662	04042C	CEREMONIE	2023-03-30 17:00:00	2023-03-30 18:30:00	Inauguration du service insertion et accompagnement vers l'emploi à Valenton
20663	04042C	ELUS_LOCAUX	2023-03-31 10:30:00	2023-03-31 13:00:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
20664	04042C	CEREMONIE	2023-03-31 17:00:00	2023-03-31 18:30:00	Inauguration exposition d'artisanat d'art à Ormesson-sur-Marne
20660	04042C	ELUS_LOCAUX	2023-03-30 08:30:00	2023-03-30 10:30:00	Réunion avec des élus du Val-de-Marne
20665	04042C	ELUS_LOCAUX	2023-03-31 20:30:00	2023-03-31 22:30:00	Conseil municipal de Saint-Maurice
20666	04043D	ACC_VISIT	2023-03-30 14:30:00	2023-03-30 15:30:00	Réunion étudiants Sc. Po - Rapport Chlordécone
20667	04042C	ACC_DEPL_INTER	2023-04-03 00:00:00	2023-04-03 00:00:00	Déplacement au Laos avec le SEDIF
20668	04042C	ACC_DEPL_INTER	2023-04-04 00:00:00	2023-04-04 00:00:00	Déplacement au Laos avec le SEDIF
20669	04042C	ACC_DEPL_INTER	2023-04-05 00:00:00	2023-04-05 00:00:00	Déplacement au Laos avec le SEDIF
20681	04042C	ELUS_LOCAUX	2023-04-06 10:30:00	2023-04-06 12:30:00	Réunion avec des élus du Val-de-Marne
20682	04042C	ELUS_LOCAUX	2023-04-06 15:00:00	2023-04-06 17:00:00	Réunion avec des élus du Val-de-Marne
20683	04042C	ELUS_LOCAUX	2023-04-07 13:00:00	2023-04-07 14:15:00	Rencontre avec des élus du Val-de-Marne
20684	04042C	DEPL_PRES_GVT	2023-04-11 07:00:00	2023-04-11 00:00:00	Visite officiel d'état au Royaume des Pays-Bas
20723	11066Q	COLLOQUE	2023-02-15 18:00:00	2023-02-15 19:30:00	Les rencontres du Grand Continent au Sénat
20724	11066Q	ORGEXTPAR	2023-02-16 11:30:00	2023-02-16 12:30:00	Réunion Commission nationale de Contrôle des Techniques de Renseignement
20725	11066Q	ACC_VISIT	2023-02-17 09:00:00	2023-02-17 12:30:00	Accueil Permanence
20726	11066Q	ACC_VISIT	2023-02-17 14:00:00	2023-02-17 15:30:00	Accueil Permanence
20727	11066Q	ACC_VISIT	2023-02-17 15:30:00	2023-02-17 16:30:00	Visite protocolaire du nouveau Préfet de Région des Pays-de-la-Loire et de Loire-Atlantique
20728	11066Q	ACC_VISIT	2023-02-17 16:30:00	2023-02-17 17:30:00	Accueil Permanence
20729	11066Q	ACC_VISIT	2023-02-27 09:00:00	2023-02-27 12:30:00	Accueil Permanence
20730	11066Q	ACC_VISIT	2023-02-27 14:00:00	2023-02-27 17:30:00	Accueil Permanence
20731	11066Q	REU_TRAV_PARL	2023-02-28 10:00:00	2023-02-28 12:00:00	Réunion de groupe
20732	11066Q	ORGEXTPAR	2023-03-01 17:00:00	2023-03-01 18:00:00	Réunion collégiale de la Commission nationale de Contrôle des Techniques de Renseignement
20733	11066Q	ORGEXTPAR	2023-03-02 09:00:00	2023-03-02 11:30:00	Réunion Plénière de la Commission nationale des Techniques de Renseignement
20736	11066Q	REU_TRAV_PARL	2023-03-07 11:00:00	2023-03-07 12:30:00	Réunion de groupe
20737	11066Q	REU_TRAV_PARL	2023-03-08 12:30:00	2023-03-08 13:30:00	Réunion de groupe
20742	11066Q	REU_TRAV_PARL	2023-03-14 10:00:00	2023-03-14 12:00:00	Réunion de groupe
20747	11066Q	ACC_VISIT	2023-03-20 09:00:00	2023-03-20 12:30:00	Accueil Permanence
20748	11066Q	ACC_VISIT	2023-03-20 14:00:00	2023-03-20 17:30:00	Accueil Permanence
20749	11066Q	ACC_VISIT	2023-03-23 09:00:00	2023-03-23 12:30:00	Accueil Permanence
20751	11066Q	ACC_VISIT	2023-03-24 09:00:00	2023-03-24 12:30:00	Accueil Permanence
20752	11066Q	ACC_VISIT	2023-03-24 14:00:00	2023-03-24 17:30:00	Accueil Permanence
20753	11066Q	ACC_VISIT	2023-03-27 09:00:00	2023-03-27 12:30:00	Accueil Permanence
20754	11066Q	ACC_VISIT	2023-03-27 14:00:00	2023-03-27 17:30:00	Accueil Permanence
20755	11066Q	ACC_VISIT	2023-03-28 10:00:00	2023-03-28 12:00:00	Accueil Permanence
20756	11066Q	REU_TRAV_PARL	2023-03-29 08:30:00	2023-03-29 09:15:00	Réunion du Groupe socialiste de la Commission des affaires étrangères
20757	11066Q	ACC_VISIT	2023-03-30 09:00:00	2023-03-30 12:30:00	Accueil Permanence
20758	11066Q	ACC_VISIT	2023-03-30 14:00:00	2023-03-30 17:30:00	Accueil Permanence
20759	11066Q	ACC_VISIT	2023-03-31 09:00:00	2023-03-31 12:30:00	Accueil Permanence
20760	11066Q	ACC_VISIT	2023-03-31 14:00:00	2023-03-31 17:30:00	Accueil Permanence
20761	11066Q	ACC_VISIT	2023-04-03 09:00:00	2023-04-03 11:30:00	Accueil Permanence
20762	11066Q	ACC_VISIT	2023-04-03 11:30:00	2023-04-03 12:30:00	Entretien avec la porte-parole du collectif Stop aux Cancers de nos Enfants
20766	11066Q	ORGEXTPAR	2023-04-05 17:00:00	2023-04-05 18:30:00	Réunion collégiale de la Commission nationale de Contrôle des Techniques de Renseignement
20767	11066Q	ORGEXTPAR	2023-04-06 09:00:00	2023-04-06 11:00:00	Réunion Plénière de la Commission nationale des Techniques de Renseignement
20768	11066Q	ACC_VISIT	2023-04-07 09:00:00	2023-04-07 12:30:00	Accueil Permanence
20769	11066Q	ACC_VISIT	2023-04-07 14:00:00	2023-04-07 17:30:00	Accueil Permanence
20773	11066Q	ACC_VISIT	2023-04-14 09:00:00	2023-04-14 12:30:00	Accueil Permanence
20774	11066Q	ACC_VISIT	2023-04-14 14:00:00	2023-04-14 17:30:00	Accueil Permanence
20781	04042C	REU_TRAV_PARL	2023-05-02 09:00:00	2023-05-02 10:00:00	Entretien avec le Minsitre des Armées
20782	04042C	ORG_POL	2023-05-02 11:00:00	2023-05-02 12:30:00	Réunion de Groupe des sénateurs LR du Sénat
20783	04042C	ACC_VISIT	2023-05-02 12:30:00	2023-05-02 12:45:00	Interview téléphonique avec la Rédactrice en chef adjointe du Journal du Grand Paris
20784	04042C	ORG_POL	2023-05-02 13:00:00	2023-05-02 14:30:00	Rencontre avec des sénateurs L.R
20785	04042C	ACC_DEPL_INTER	2023-05-02 15:00:00	2023-05-02 16:00:00	Entretien avec l'Ambassadeur du Royaume des Pays-Bas
20786	04042C	COLL_TER	2023-05-02 17:00:00	2023-05-02 18:00:00	Entretien avec la Présidente de la région d'Ile-de-France
20787	04042C	ACC_DEPL_INTER	2023-05-02 19:30:00	2023-05-02 21:00:00	Rencontre avec l'Ambassadeur de la Pologne en France  à l'occasion de la visite de la délégation du Sénat de la République de Pologne
20847	04042C	CEREMONIE	2023-05-12 11:00:00	2023-05-12 11:45:00	Cérémonie de commémoration des 80 ans de la recréation du régiment  à SABRATHA
20843	04042C	ELUS_LOCAUX	2023-05-10 13:00:00	2023-05-10 14:30:00	Rencontre avec des élus du Val-de-Marne
20841	04042C	ELUS_LOCAUX	2023-05-09 18:00:00	2023-05-09 19:30:00	Mobilisation d'élus au Ministère de la Transition écologiquepour demander le plafonnement des aéroports de Roissy, du Bourget, et d¿Orly, dans la lignée d¿Amsterdam et de Francfort
20844	04042C	ACC_DEPL_INTER	2023-05-10 08:30:00	2023-05-10 09:30:00	Entretien avec le Responsable de l¿opposition aux Comores
20845	04042C	ACC_DEPL_INTER	2023-05-11 19:30:00	2023-05-11 22:30:00	Rencontre avec l'Ambassadrice du Royaume-Uni en France pour célébrer couronnement de Sa Majesté le Roi Charles III Sa Majesté la Reine Camilla
20846	04042C	COLL_TER	2023-05-12 08:45:00	2023-05-12 10:45:00	Réunion du bureau du Syndicat des Eaux d'Ile-de-France
20848	04042C	ACC_DEPL_INTER	2023-05-12 12:00:00	2023-05-12 13:00:00	Entretien avec le Président du Comité des A.E du Milli Majlis de la République d¿Azerbaïdjan 
20849	04042C	ELUS_LOCAUX	2023-05-12 15:30:00	2023-05-12 16:30:00	Réunion avec la Préfète du Val-de-Marne et du Préfet à l'égalité des chances du Val-de-Marne
20850	04042C	ELUS_LOCAUX	2023-05-12 17:00:00	2023-05-12 18:00:00	Entretien avec des élus du Val-de-Marne
20161	04042C	CEREMONIE	2023-01-04 14:15:00	2023-01-04 17:00:00	Cérémonie de prise d'armes et remise de décorations par le Ministre des armées
20162	04042C	CEREMONIE	2023-01-04 19:00:00	2023-01-04 21:00:00	Cérémonie des Voeux à Maisons-Alfort
20163	04042C	REU_TRAV_PARL	2023-01-05 11:00:00	2023-01-05 12:00:00	Entretien avec le Conseiller spécial du Président du Sénat
20164	04042C	ELUS_LOCAUX	2023-01-05 12:00:00	2023-01-05 13:00:00	Entretien avec un élu du Val-de-Marne
20165	04042C	CEREMONIE	2023-01-05 19:00:00	2023-01-05 21:00:00	Cérémonie des voeux de l'Evêque de Créteil
20166	04042C	ELUS_LOCAUX	2023-01-09 13:00:00	2023-01-09 14:30:00	Rencontre avec un élu du Val-de-Marne
20167	04042C	CEREMONIE	2023-01-09 19:00:00	2023-01-09 21:00:00	Cérémonie des voeux de Thiais
20408	04042C	REU_GVT	2023-02-02 10:00:00	2023-02-02 14:00:00	Réunion du Comité consultatif des Etats Généraux de la diplomatie
20409	04042C	ACC_VISIT	2023-02-03 12:30:00	2023-02-03 13:45:00	Rencontre avec un élu du Val-de-Marne
20410	04042C	ACC_VISIT	2023-02-03 12:00:00	2023-02-03 12:30:00	Rencontre avec des lycéens du Val-de-Marne
20411	04042C	COLL_TER	2023-02-03 15:00:00	2023-02-03 16:30:00	Réunion du Syndicat des Eaux d'Ile-de-France
20412	04042C	ELUS_LOCAUX	2023-02-03 17:00:00	2023-02-03 18:30:00	Réunion avec des élus du Val-de-Marne
20413	04042C	ACC_VISIT	2023-02-03 19:00:00	2023-02-03 22:00:00	Visite du palais du Luxembourg d'un Conseil municipal du Val-de-Marne
20414	04042C	ORG_POL	2023-02-06 08:00:00	2023-02-06 09:30:00	Réunion du bureau départemental du Val-de-Marne
20415	04042C	COLL_TER	2023-02-06 09:30:00	2023-02-06 11:00:00	Réunion du Syndicat des Eaux d'Ile-de-France
20416	04042C	COLL_TER	2023-02-06 14:00:00	2023-02-06 16:00:00	Réunion du Syndicat d'Ile-de-France
20417	04042C	ORG_POL	2023-02-07 11:00:00	2023-02-07 12:30:00	Réunion de Groupe des sénateurs LR du Sénat
20418	04042C	ELUS_LOCAUX	2023-02-07 19:00:00	2023-02-07 21:00:00	Réunion du Conseil de Territoire
20419	04042C	ACC_DEPL_INTER	2023-02-08 12:00:00	2023-02-08 13:00:00	Rencontre avec le Président du Sénat et le Président du Parlement de Finlande
20420	04042C	REU_TRAV_PARL	2023-02-08 14:30:00	2023-02-08 15:00:00	Entretien avec un sénateur
20421	04042C	ACC_VISIT	2023-02-08 16:20:00	2023-02-08 17:20:00	Entretien avec des élus du Val-de-Marne
20422	04042C	ORG_POL	2023-02-09 08:30:00	2023-02-09 15:00:00	Séminaire du Groupe LR du Sénat
20423	04042C	ACC_VISIT	2023-02-09 18:30:00	2023-02-09 19:15:00	Emission Public Sénat
20424	04042C	COLL_TER	2023-02-10 08:45:00	2023-02-10 11:00:00	Réunion du bureau du Syndicat des Eaux d'Ile-de-France
20425	04042C	ACC_VISIT	2023-02-10 13:00:00	2023-02-10 14:15:00	Rencontre avec des élus du Val-de-Marne
20426	04042C	CEREMONIE	2023-02-10 18:00:00	2023-02-10 19:00:00	Vernissage de l'exposition du futur Espace éducatif et culturel à Valenton
20427	04042C	REU_GVT	2023-02-13 13:00:00	2023-02-13 14:15:00	Entretien avec le Ministre des armées
20428	04042C	REU_GVT	2023-02-13 20:00:00	2023-02-13 20:45:00	Rencontre avec la Secrétaire d¿Etat chargée des Anciens combattants et de la Mémoire
20429	04042C	CEREMONIE	2023-02-13 21:00:00	2023-02-13 23:00:00	37ème soirée du CRIF
20430	04042C	REU_TRAV_PARL	2023-02-14 14:30:00	2023-02-14 15:30:00	Entretien avec un sénateur
20431	04042C	ACC_VISIT	2023-02-14 15:30:00	2023-02-14 16:30:00	Entretien avec un élu du Val-de-Marne
20432	04042C	ACC_DEPL_INTER	2023-02-14 16:45:00	2023-02-14 17:15:00	Entretien avec le Ministre des affaires étrangères et du commerce extérieur de la Hongrie
20433	04042C	REU_TRAV_PARL	2023-02-14 17:30:00	2023-02-14 18:00:00	Réunion du groupe de liaison de réflexion, de vigilance et de solidarité avec les Chrétiens d'Orient, les minorités au Moyen-Orient et les Kurdes
20434	04042C	ACC_DEPL_INTER	2023-02-14 18:30:00	2023-02-14 20:30:00	Première rencontre du Salon de Weimar
20435	04042C	ACC_DEPL_INTER	2023-02-15 13:00:00	2023-02-15 14:15:00	Rencontre avec un Consul de France
20436	04042C	REU_TRAV_PARL	2023-02-15 17:15:00	2023-02-15 18:00:00	Réunion de travail avec le Président du Sénat
20437	04042C	COLLOQUE	2023-02-15 18:00:00	2023-02-15 20:00:00	Colloque le Grand Continent
20438	04043D	REU_TRAV_PARL	2023-01-19 09:30:00	2023-01-19 11:00:00	Réunion directrice régionale Pacifique AFD
20439	04043D	ACC_DEPL_INTER	2022-06-27 17:00:00	2022-06-27 18:00:00	Rencontre - Gouverneure Nouvelle-Galles-du-Sud
20440	04043D	COLL_TER	2022-06-23 11:45:00	2022-06-23 12:45:00	Inauguration de la nouvelle entrée du siège de Santé Publique France - Saint-Maurice
20441	04043D	REU_TRAV_PARL	2022-06-15 15:00:00	2022-06-15 15:30:00	Visioconférence - Unigrains (NBT)
20463	04043D	COLL_TER	2022-11-24 10:00:00	2022-11-24 12:00:00	Démonstration de taser - L'Haÿ-les-Roses
20523	04042C	ORG_POL	2023-03-07 11:00:00	2023-03-07 12:30:00	Réunion de Groupe des sénateurs LR du Sénat
20465	04043D	REU_TRAV_PARL	2022-04-26 16:30:00	2022-04-26 17:00:00	Interview BFM Paris - Pièces d'identité
20470	04043D	CEREMONIE	2022-08-29 11:00:00	2022-08-29 12:00:00	Cérémonie de départ Médecin-Général Duverger - Hôpital Bégin
20474	04043D	ORG_POL	2022-05-17 19:00:00	2022-05-17 20:00:00	Réunion de soutien campagne de Vincent Jeanbrun - Elections législatives Val-de-Marne
20473	04043D	CEREMONIE	2022-05-12 18:00:00	2022-05-12 20:00:00	Cérémonie - remise de l'Ordre National du Mérite à Pierre Trefouret
20521	04042C	ELUS_LOCAUX	2023-03-06 10:30:00	2023-03-06 12:00:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
20522	04042C	ACC_VISIT	2023-03-06 13:00:00	2023-03-06 14:15:00	Rencontre avec un élu du Val-de-Marne
20524	04042C	ACC_DEPL_INTER	2023-03-07 13:00:00	2023-03-07 15:00:00	Rencontre avec le groupe des Ambassadeurs Latino-américains
20528	04042C	ACC_VISIT	2023-03-07 20:00:00	2023-03-07 21:30:00	Rencontre avec un élu du Val-de-Marne
20526	04042C	ACC_DEPL_INTER	2023-03-07 15:30:00	2023-03-07 16:30:00	Entretien avec le chargé d'affaires a.i. de l'Ambassade de Chine en France
20527	04042C	ACC_DEPL_INTER	2023-03-07 16:30:00	2023-03-07 17:30:00	Entretien avec le Président du CRIF
20529	04042C	REU_TRAV_PARL	2023-03-08 11:45:00	2023-03-08 12:45:00	Conférence des Présidents
20530	04042C	ACC_VISIT	2023-03-08 16:30:00	2023-03-08 17:30:00	entretien avec un élu du Val-de-Marne
20531	04042C	ACC_VISIT	2023-03-08 17:30:00	2023-03-08 18:30:00	Entretien avec un élu du Val-de-Marne
20532	04042C	ELUS_LOCAUX	2023-03-09 12:30:00	2023-03-09 14:30:00	Rencontre avec des élus du Val-de-Marne
20821	11066Q	REU_TRAV_PARL	2023-05-02 15:00:00	2023-05-02 17:30:00	\N
20822	11066Q	REU_TRAV_PARL	2023-05-03 08:30:00	2023-05-03 09:30:00	Réunion du Groupe socialiste de la Commission des affaires étrangères
20823	11066Q	COLLOQUE	2023-05-03 18:00:00	2023-05-03 19:30:00	2ème rencontre du Grand Continent au Sénat sur le thème : "La démocratie européenne face aux crises : Quel rôle pour les parlements ?" 
20824	11066Q	ORGEXTPAR	2023-05-04 09:00:00	2023-05-04 12:00:00	Réunion Plénière de la Commission nationale des Techniques de Renseignement
20825	11066Q	ACC_VISIT	2023-05-05 09:00:00	2023-05-05 12:00:00	Accueil Permanence
20826	11066Q	ACC_VISIT	2023-05-05 14:00:00	2023-05-05 17:00:00	Accueil Permanence
20851	04042C	ELUS_LOCAUX	2023-05-12 19:30:00	2023-05-12 20:30:00	Rencontre avec des élus du Val-de-Marne
20852	04042C	ACC_VISIT	2023-05-15 08:00:00	2023-05-15 08:25:00	Emission Public Sénat
20853	04042C	REU_TRAV_PARL	2023-05-15 10:30:00	2023-05-15 11:30:00	entretien avec le Chef d'état-major de la Marine
20854	04042C	ELUS_LOCAUX	2023-05-15 16:00:00	2023-05-15 17:00:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
20855	04042C	ELUS_LOCAUX	2023-05-15 20:00:00	2023-05-15 22:00:00	Rencontre républicaine à la Mosquée de Créteil
20856	04042C	ORG_POL	2023-05-16 11:00:00	2023-05-16 12:30:00	Réunion de Groupe des sénateurs LR du Sénat
20857	04042C	ACC_VISIT	2023-05-16 17:00:00	2023-05-16 18:00:00	Entretien avec le Président de la Métropole du Grand Paris
20858	04042C	ACC_DEPL_INTER	2023-05-16 15:35:00	2023-05-16 16:45:00	Entretien avec le Président du Sénat et le le Président de l'Assemblée de la République du Portugal
20859	04042C	ACC_VISIT	2023-05-16 18:30:00	2023-05-16 19:30:00	Entretien avec un élu du Val-de-Marne
20920	01025N	REU_TRAV_PARL	2023-05-02 14:00:00	2023-05-02 15:00:00	Ass. Producteurs Fruits/légumes-Porcs-Lairt
20921	01025N	REU_TRAV_PARL	2023-05-03 08:00:00	2023-05-03 09:30:00	Union des Semenciers
20922	01025N	REU_TRAV_PARL	2023-05-11 11:00:00	2023-05-11 12:00:00	SODIAAL
20923	01025N	CEREMONIE	2023-05-16 14:00:00	2023-05-16 16:00:00	Garde républicaine
20927	01025N	REU_TRAV_PARL	2023-04-05 14:00:00	2023-04-05 15:00:00	\N
20941	11066Q	ACC_VISIT	2023-05-12 09:00:00	2023-05-12 12:30:00	Accueil Permanence
20942	11066Q	ACC_VISIT	2023-05-12 14:00:00	2023-05-12 17:00:00	Accueil Permanence
20943	11066Q	ACC_VISIT	2023-05-15 09:00:00	2023-05-15 12:30:00	Accueil Permanence
20212	04042C	COLL_TER	2023-01-19 14:30:00	2023-01-19 16:00:00	Réunion du Syndicat des Eaux d'Ile-de-France
20213	04042C	ELUS_LOCAUX	2023-01-19 19:00:00	2023-01-19 19:45:00	Réunion sur la future prison à Noiseau
20214	04042C	ELUS_LOCAUX	2023-01-19 20:15:00	2023-01-19 21:30:00	Réunion à la Mairie de Saint-Maurice
20215	04042C	DEPL_PRES_GVT	2023-01-20 07:00:00	2023-01-20 18:00:00	Visite avec le Président de la République aux forces armées de la BA 118 Mont-de-Marsan
20216	04042C	CEREMONIE	2023-01-20 20:15:00	2023-01-20 22:00:00	Cérémonie des Voeux à Rungis
20217	01025N	REU_TRAV_PARL	2023-01-10 13:30:00	2023-01-10 14:30:00	\N
20218	04042C	ELUS_LOCAUX	2023-01-23 11:00:00	2023-01-23 12:00:00	Réunion urbanisme à la Mairie de Saint-Maurice
20219	01025N	REU_TRAV_PARL	2023-01-11 11:30:00	2023-01-11 12:45:00	Audition Cérémé - Nucléaire
20220	04042C	CEREMONIE	2023-01-23 20:00:00	2023-01-23 22:30:00	Soirée d'exception dans le cadre du lancement du film de la Marine nationale "Au coeur de la Marine"
20224	01025N	CEREMONIE	2023-01-17 19:00:00	2023-01-17 20:00:00	Voeux du Président Larcher
20222	01025N	ACC_DEPL_INTER	2023-01-11 14:00:00	2023-01-11 15:00:00	association Gabon
20223	04042C	ORG_POL	2023-01-24 11:00:00	2023-01-24 12:00:00	Réunion de Groupe des sénateurs LR du Sénat
20241	01025N	REU_TRAV_PARL	2023-01-25 14:00:00	2023-01-25 15:00:00	ALK
20503	04043D	REU_TRAV_PARL	2023-03-03 14:00:00	2023-03-03 15:00:00	Conférence de presse - Présentation du rapport sur la Chlordécone dans les Antilles OPECST
20505	04042C	CEREMONIE	2023-03-02 17:00:00	2023-03-02 18:30:00	Vernissage de l'exposition Giovanni Bellini
20504	04042C	ACC_VISIT	2023-03-02 14:00:00	2023-03-02 16:00:00	Visite du Centre de formation d'apprentis Sport Business Academy à Créteil
20506	04042C	REU_TRAV_PARL	2023-03-02 20:00:00	2023-03-02 21:30:00	Rencontre avec le Président de la Commision des Affaires étrangères de l'Assemblée nationale
20507	04042C	ACC_VISIT	2023-03-03 11:00:00	2023-03-03 12:30:00	Rendez-vous à la Mairie de Saint-Maurice
20511	04042C	ACC_VISIT	2023-03-03 20:00:00	2023-03-03 21:30:00	Rencontre avec l'Evêque aux armées
20509	04042C	ACC_VISIT	2023-03-03 13:00:00	2023-03-03 14:15:00	Rencontre avec un élu du Val-de-Marne
20510	04042C	ELUS_LOCAUX	2023-03-03 15:00:00	2023-03-03 16:30:00	Entretien avec un élu du Val-de-Marne
20561	04042C	DEPL_PRES_GVT	2023-03-09 16:30:00	2023-03-09 18:00:00	Déplacement du Ministre délégué chargé de la Ville à Valenton
20562	04042C	CEREMONIE	2023-03-09 18:30:00	2023-03-09 19:30:00	Inauguration de l'Exposition d'artistes de Vilnuis à l'occasion de la Fête Nationale de Lituanie
20563	04042C	ACC_DEPL_INTER	2023-03-10 15:00:00	2023-03-10 16:00:00	Entretien avec l'Ambassadeur de France au Maroc
20564	04042C	ACC_DEPL_INTER	2023-03-10 20:00:00	2023-03-10 21:00:00	Rencontre avec la Ministre chargée du développement, francophonie et partenariats internationaux et la Première Ministre de la Barbade
20565	04042C	DEPL_PRES_GVT	2023-03-13 09:45:00	2023-03-13 11:30:00	Déplacement de la Première ministre et du Garde des Sceaux à Vincennes
20566	04042C	ACC_DEPL_INTER	2023-03-13 15:00:00	2023-03-13 16:00:00	entretien avec le chef du département des opérations de paix de l¿ONU
20567	04042C	ELUS_LOCAUX	2023-03-13 20:30:00	2023-03-13 22:30:00	Conseil municipal de Saint-Maurice
20568	04042C	ELUS_LOCAUX	2023-03-14 11:00:00	2023-03-14 12:30:00	Forum emploi de Villeneuve-Saint-Georges
20569	04042C	CEREMONIE	2023-03-14 18:00:00	2023-03-14 20:00:00	Remise de décoration à un ancien commissaire de police du Val-de-Marne
20570	04042C	REU_GVT	2023-03-16 10:45:00	2023-03-16 12:30:00	Remise du rapport final des Etats Généraux de la Diplomatie
20571	04042C	ACC_VISIT	2023-03-16 18:00:00	2023-03-16 18:45:00	Emission le Temps du débat de France Culture
20861	14133K	ELUS_LOCAUX	2023-05-16 10:30:00	2023-05-16 12:00:00	rdv permanence parlementaire Calvados
20862	14133K	REU_TRAV_PARL	2023-05-16 15:00:00	2023-05-16 16:00:00	Visio - affaires étrangères et défense
20863	14133K	REU_TRAV_PARL	2023-05-15 09:30:00	2023-05-15 16:30:00	accueil mission d'information sénat dans le Calvados
20865	14133K	REU_TRAV_PARL	2023-05-09 17:00:00	2023-05-09 17:30:00	Rdv présidence du Sénat
20871	14133K	REU_TRAV_PARL	2023-05-05 13:30:00	2023-05-05 15:00:00	conférence-débat avec élèves Collège SC - 14110
20879	14133K	ORG_POL	2023-04-11 11:00:00	2023-04-11 12:30:00	Réunion du Groupe LR Sénat
20883	14133K	ELUS_LOCAUX	2023-04-07 10:00:00	2023-04-07 12:00:00	Réunion Commission DETR du Calvados - Préfecture Caen
20884	14133K	ELUS_LOCAUX	2023-04-07 12:30:00	2023-04-07 14:00:00	Déjeuner de travail élus locaux Calvados
20887	14133K	COLL_TER	2023-03-30 15:00:00	2023-03-30 17:30:00	rdv individuels permanence parlementaire
20891	14133K	COLL_TER	2023-03-13 09:30:00	2023-03-13 10:45:00	Visite dispositif Région Normandie - Cormolain (Calvados)
20892	14133K	ELUS_LOCAUX	2023-03-13 11:00:00	2023-03-13 12:30:00	rdv Maire de Cormolain
20893	14133K	CEREMONIE	2023-03-13 13:00:00	2023-03-13 14:00:00	Inauguration exposition Mairie de Trévières
20894	14133K	COLL_TER	2023-03-13 14:15:00	2023-03-13 15:00:00	Visite dispositif Région Normandie - Carcagny
20895	14133K	ELUS_LOCAUX	2023-03-13 00:00:00	2023-03-13 00:00:00	Réunion de travail - municipalité d'Ellon
20896	14133K	ELUS_LOCAUX	2023-03-13 15:15:00	2023-03-13 16:30:00	Réunion de travail - Mairie d'Ellon
20897	14133K	COLL_TER	2023-03-13 16:45:00	2023-03-13 18:00:00	Visite et réunion de travail site Zoo de Jurques
20944	11066Q	ACC_VISIT	2023-05-15 14:00:00	2023-05-15 17:00:00	Accueil Permanence
20945	11066Q	REU_TRAV_PARL	2023-05-16 10:00:00	2023-05-16 12:00:00	Réunion de groupe
20946	11066Q	REU_TRAV_PARL	2023-05-16 15:00:00	2023-05-16 16:30:00	Réunion de travail parlementaire
20947	11066Q	ACC_VISIT	2023-05-16 19:00:00	2023-05-16 23:30:00	Maraude avec la protection civile
20948	11066Q	ORGEXTPAR	2023-05-17 15:00:00	2023-05-17 16:30:00	Réunion Plénière de la Commission nationale des Techniques de Renseignement
20949	11066Q	ACC_VISIT	2023-05-22 09:00:00	2023-05-22 12:30:00	Accueil Permanence
20950	11066Q	ACC_VISIT	2023-05-22 14:00:00	2023-05-22 17:00:00	Accueil Permanence
20951	11066Q	REU_TRAV_PARL	2023-05-24 08:00:00	2023-05-24 09:30:00	Réunion du Groupe socialiste de la Commission des affaires étrangères
20952	11066Q	ORGEXTPAR	2023-05-24 17:00:00	2023-05-24 18:00:00	Réunion collégiale de la Commission nationale de Contrôle des Techniques de Renseignement
20953	04043D	REU_TRAV_PARL	2023-05-25 09:30:00	2023-05-25 11:00:00	Colloque Assemblée nationale - Puffs
20961	04042C	REU_TRAV_PARL	2023-05-17 12:00:00	2023-05-17 12:45:00	Entretien avec le Président du Sénat
20962	04042C	ELUS_LOCAUX	2023-05-17 13:00:00	2023-05-17 14:00:00	Rencontre avec un élu du Val-de-Marne
20963	04042C	ACC_VISIT	2023-05-17 14:50:00	2023-05-17 15:00:00	Interview Public Sénat
20964	04042C	ACC_VISIT	2023-05-22 15:00:00	2023-05-22 16:00:00	Entretien avec un élu du Val-de-Marne
20965	04042C	ACC_DEPL_INTER	2023-05-22 18:00:00	2023-05-22 19:00:00	Rencontre avec l'Ambassadeur du Cameroun en France à l'occasion de la Fête nationale
20966	04042C	ACC_VISIT	2023-05-22 19:30:00	2023-05-22 20:30:00	Soirée Rungis, capitale de la Gastronomie
20967	04042C	ORG_POL	2023-05-23 11:00:00	2023-05-23 12:30:00	Réunion de Groupe des sénateurs LR du Sénat
20968	04042C	ELUS_LOCAUX	2023-05-23 08:30:00	2023-05-23 09:30:00	Réunion avec des élus du Val-de-Marne
20969	04042C	REU_TRAV_PARL	2023-05-23 17:00:00	2023-05-23 18:00:00	Entretien avec le Président des LR du Sénat
20970	04042C	REU_TRAV_PARL	2023-05-23 18:00:00	2023-05-23 18:30:00	Commission des investitures
20971	04042C	ACC_DEPL_INTER	2023-05-23 18:45:00	2023-05-23 19:15:00	Rencontre avec l'Ambassadeur d'Equateur en France à l'occasion de la Fête nationale et du bicentenaire de l'indépendance
20972	04042C	ACC_DEPL_INTER	2023-05-23 19:30:00	2023-05-23 20:30:00	Rencontre avec l'Ambassadeur de Turquie en France à l'occasion de la semaine de la cuisine turque
20973	04042C	CEREMONIE	2023-05-24 12:00:00	2023-05-24 13:00:00	Célébration des semaines de l'Amérique latine et des Caraïbes
20974	04042C	ACC_VISIT	2023-05-24 13:00:00	2023-05-24 15:00:00	Rencontre avec des élus du Val-de-Marne
20975	04042C	ELUS_LOCAUX	2023-05-25 11:00:00	2023-05-25 12:00:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
20976	04042C	ELUS_LOCAUX	2023-05-25 12:00:00	2023-05-25 13:30:00	Rencontre avec un élu du Val-de-Marne
20977	04042C	CEREMONIE	2023-05-25 14:00:00	2023-05-25 15:00:00	 Cérémonie de dévoilement des plaques commémoratives en hommage aux enfants juifs Saint-Mandéens déportés entre 1942 et 1944
20978	04042C	ACC_DEPL_INTER	2023-05-25 17:00:00	2023-05-25 18:00:00	Entretien avec l'Ambassadeur du Kosovo en France
19923	04042C	ACC_VISIT	2022-11-15 19:00:00	2022-11-15 22:00:00	Visite du Palais du Luxembourg d'un Conseil municipal du Val-de-Marne
19924	04042C	CEREMONIE	2022-11-11 10:30:00	2022-11-11 12:00:00	Cérémonie du 11 novembre à Saint-Maurice et Charenton-le-Pont
19925	04042C	ACC_DEPL_INTER	2022-11-11 12:30:00	2022-11-11 14:00:00	Rencontre avec le Président du Sénat et la Présidente de la République de Hongrie
19926	04042C	CEREMONIE	2022-11-11 17:45:00	2022-11-11 18:45:00	Cérémonie départementale commémorant le 104è anniversaire de l'Armistice de la Première Guerre Mondiale
19927	04042C	ELUS_LOCAUX	2022-11-14 10:00:00	2022-11-14 12:00:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
19928	04042C	ELUS_LOCAUX	2022-11-14 13:00:00	2022-11-14 14:30:00	Rencontre avec un élu du Val-de-Marne
19929	04042C	ORG_POL	2022-11-14 19:00:00	2022-11-14 21:00:00	Animation d'un débat dans le Val-de-Marne
19930	04042C	ACC_VISIT	2022-11-15 10:00:00	2022-11-15 11:00:00	Entretien avec une association spécialisée dans les domaines de l'Aéronotique , du spatial et de la Défense
19931	04042C	ORG_POL	2022-11-15 11:00:00	2022-11-15 12:00:00	Réunion de Groupe des sénateurs LR du Sénat
19932	04042C	ACC_DEPL_INTER	2022-11-15 12:30:00	2022-11-15 13:00:00	Rencontre avec l'Ambassadeur de Belgique en France à l'occasion de la Fête nationale
19933	04042C	ACC_DEPL_INTER	2022-11-15 13:30:00	2022-11-15 15:00:00	Rencontre avec l'Ambassadeur d'Argentine en France et du Vice-ministre des Affaires étrangères d'Argentine à l'occasion de sa venue en France
19934	04042C	REU_TRAV_PARL	2022-11-16 08:30:00	2022-11-16 09:30:00	Réunion du bureau de la Commission des Affaires étrangères, de la Défense et des Forces armées
19935	04042C	REU_TRAV_PARL	2022-11-16 13:00:00	2022-11-16 14:00:00	Rencontres des Présidents, des Référents de commission, et du Rapporteur Général
19936	04042C	ACC_VISIT	2022-11-16 16:30:00	2022-11-16 17:30:00	Rencontre avec un syndicat de Police du Val-de-Marne
19937	04042C	ACC_VISIT	2022-11-16 17:30:00	2022-11-16 18:30:00	Réunion avec des élus du Val-de-Marne
19964	04042C	ACC_DEPL_INTER	2022-11-28 18:30:00	2022-11-28 19:30:00	Célébration de la Fête nationale écossaise
19965	04042C	ORG_POL	2022-11-28 20:00:00	2022-11-28 22:00:00	Réunion publique dans le Val-de-Marne
19966	04042C	ORG_POL	2022-11-29 11:00:00	2022-11-29 12:15:00	Réunion de Groupe des sénateurs LR du Sénat
20001	04042C	DEPL_PRES_GVT	2022-11-29 16:00:00	2022-11-29 00:00:00	Visite officielle d'Etat aux côtés du Président de la République à Washington
20002	04042C	DEPL_PRES_GVT	2022-11-30 00:00:00	2022-11-30 00:00:00	Visite officielle d'Etat aux côtés du Président de la République à Washington
20003	04042C	DEPL_PRES_GVT	2022-12-01 00:00:00	2022-12-01 00:00:00	Visite officielle d'Etat aux côtés du Président de la République à Washington
20004	04042C	DEPL_PRES_GVT	2022-12-02 00:00:00	2022-12-02 00:00:00	Visite officielle d'Etat aux côtés du Président de la République à Washington
20050	11066Q	ACC_VISIT	2022-10-17 09:00:00	2022-10-17 17:00:00	Accueil Permanence
20051	11066Q	ORGEXTPAR	2022-10-19 17:00:00	2022-10-19 18:30:00	Réunion collégiale de la Commission nationale de Contrôle des Techniques de Renseignement
20052	11066Q	ACC_VISIT	2022-10-20 14:00:00	2022-10-20 17:00:00	Accueil Permanence
20053	11066Q	ACC_VISIT	2022-10-21 09:00:00	2022-10-21 10:00:00	Accueil Permanence
21281	11066Q	ACC_VISIT	2023-06-22 14:00:00	2023-06-22 17:30:00	Accueil Permanence
20054	11066Q	COLL_TER	2022-10-21 10:30:00	2022-10-21 12:30:00	Congrès national des Parcs naturels régionaux
20055	11066Q	ACC_VISIT	2022-10-21 14:00:00	2022-10-21 17:00:00	Accueil Permanence
20056	11066Q	ACC_VISIT	2022-10-24 09:00:00	2022-10-24 13:30:00	Accueil Permanence
20057	11066Q	CEREMONIE	2022-10-24 14:00:00	2022-10-24 15:00:00	Inauguration du Contournement ferroviaire des sites industriels de Donges
20058	11066Q	ACC_VISIT	2022-10-24 15:30:00	2022-10-24 17:00:00	Accueil Permanence
20059	11066Q	REU_TRAV_PARL	2022-10-25 15:00:00	2022-10-25 16:00:00	\N
20060	11066Q	ACC_VISIT	2022-10-27 09:00:00	2022-10-27 17:00:00	Accueil Permanence
20061	11066Q	ACC_VISIT	2022-10-28 09:00:00	2022-10-28 17:00:00	Accueil Permanence
20062	11066Q	ACC_VISIT	2022-10-31 09:00:00	2022-10-31 17:00:00	Accueil Permanence
20063	11066Q	ORGEXTPAR	2022-11-02 17:00:00	2022-11-02 18:30:00	Réunion collégiale de la Commission nationale de Contrôle des Techniques de Renseignement
20064	11066Q	ORGEXTPAR	2022-11-03 09:00:00	2022-11-03 12:00:00	Réunion Plénière de la Commission nationale des Techniques de Renseignement
20065	04042C	DEPL_PRES_GVT	2022-12-09 00:00:00	2022-12-09 00:00:00	Déplacement officiel au Vietnam aux côtés du Président du Sénat
20066	04042C	COLL_TER	2022-12-12 11:00:00	2022-12-12 12:30:00	Réunion de la commission Relations Internationales et Solidarité du Syndicat des Eaux d'Ile-de-France
20067	04042C	ELUS_LOCAUX	2022-12-12 13:00:00	2022-12-12 14:30:00	Rencontre avec des Elus du Val-de-Marne
20068	04042C	ACC_DEPL_INTER	2022-12-12 15:00:00	2022-12-12 16:00:00	Entretien avec le Président des Affaires étrangères du Parlement hongrois
20069	04042C	ACC_VISIT	2022-12-12 16:00:00	2022-12-12 17:00:00	Entretien avec un général de l'armée française
20070	04042C	ACC_VISIT	2022-12-12 17:00:00	2022-12-12 18:00:00	En tretien avec unb directeur général
20071	04042C	REU_TRAV_PARL	2022-12-12 18:00:00	2022-12-12 19:00:00	Réunion de coordination
20121	04042C	ACC_DEPL_INTER	2022-12-19 10:00:00	2022-12-19 11:00:00	Entretien avec l'Ambassadeur de Corée en France
20281	04043D	COLL_TER	2023-01-27 19:00:00	2023-01-27 20:00:00	Cérémonie des voeux - Villecresnes
20282	04043D	COLL_TER	2023-01-25 19:30:00	2023-01-25 20:30:00	Cérémonie des voeux - Limeil-Brévannes
20461	04043D	ORG_POL	2022-10-24 18:45:00	2022-10-24 19:45:00	Réunion publique campagne Les Républicains - Bruno Retailleau Maisons-Alfort
20462	04043D	REU_TRAV_PARL	2022-09-01 10:30:00	2022-09-01 12:00:00	Visite de SAFRAN Electrical & Power - Créteil
20466	04043D	REU_TRAV_PARL	2022-11-24 14:30:00	2022-11-24 16:00:00	Visite de la SEMHACH - Villejuif
20467	04043D	DEPL_PRES_GVT	2023-02-17 12:45:00	2023-02-17 19:00:00	Visite de Gérard Larcher - Val-de-Marne
20468	04043D	ACC_DEPL_INTER	2022-10-11 12:00:00	2022-10-11 14:00:00	Déjeuner groupe d'amitié France-Etats-Unis - Ambassadrice des Etats-Unis
20477	04043D	ACC_VISIT	2022-04-04 18:30:00	2022-04-04 23:00:00	Visite du Sénat - élus locaux Le Perreux-sur-Marne
20475	04043D	REU_TRAV_PARL	2022-04-21 14:30:00	2022-04-21 17:00:00	Visite d'Inventec - Bry-sur-Marne
20864	14133K	ORG_POL	2023-05-09 11:00:00	2023-05-09 12:30:00	Réunion du Groupe LR Sénat
20478	04043D	ACC_VISIT	2022-06-08 18:30:00	2022-06-08 23:00:00	Visite du Sénat - élus locaux Noiseau
20866	14133K	REU_TRAV_PARL	2023-05-11 10:00:00	2023-05-11 12:00:00	rdv individuels permanence parlementaire Calvados
20867	14133K	ORG_POL	2023-05-11 12:30:00	2023-05-11 14:00:00	Déjeuner de travail LR
20868	14133K	COLL_TER	2023-05-11 15:00:00	2023-05-11 16:30:00	Visite AFPA Ifs (14) avec le Président de Région
20869	14133K	CEREMONIE	2023-05-11 18:30:00	2023-05-11 19:30:00	Départ du Sous-préfet de Bayeux
20870	14133K	ELUS_LOCAUX	2023-05-12 14:00:00	2023-05-12 16:00:00	réunion collège départemental FDVA Calvados - Préfecture 
20872	14133K	REU_TRAV_PARL	2023-04-17 12:30:00	2023-04-17 14:00:00	Déjeuner de travail avec le Préfet du Calvados
20873	14133K	ELUS_LOCAUX	2023-04-17 14:30:00	2023-04-17 17:00:00	réunion de travail élus de Bény-sur-Mer et Reviers (Calvados)
20874	14133K	COLL_TER	2023-04-18 11:00:00	2023-04-18 12:30:00	Inauguration PSLA Caumont-sur-Aure (Calvados)
20875	14133K	REU_TRAV_PARL	2023-04-18 15:45:00	2023-04-18 17:00:00	visio Rule Commitee AP OSCE
20876	14133K	COLL_TER	2023-04-19 10:00:00	2023-04-19 12:00:00	Visite dispositif Région Normandie - Moult Chicheboville (Calvados)
20877	14133K	ELUS_LOCAUX	2023-04-19 12:30:00	2023-04-19 14:00:00	Déjeuner de travail élus locaux Calvados
20878	14133K	COLL_TER	2023-04-19 14:30:00	2023-04-19 16:30:00	Réunion de travail - Villers-sur-Mer (paléontologie)
20880	14133K	ACC_VISIT	2023-04-13 16:00:00	2023-04-13 17:00:00	accueil élèves collège DU 14110
20881	14133K	ELUS_LOCAUX	2023-04-03 09:30:00	2023-04-03 15:00:00	AG Union amicale des maires du Calvados - CAEN
20882	14133K	ORG_POL	2023-04-04 11:00:00	2023-04-04 12:30:00	Réunion du Groupe LR Sénat
20886	14133K	REU_TRAV_PARL	2023-03-29 08:00:00	2023-03-29 12:00:00	Défense - suite déplacement exercice ORION
20888	14133K	COLL_TER	2023-03-20 14:00:00	2023-03-20 17:30:00	Rendez-vous sociaux et économiques permanence parlementaire dans le Calvados
20889	14133K	ORG_POL	2023-03-21 11:00:00	2023-03-21 12:30:00	Réunion du Groupe LR Sénat
21007	11066Q	ACC_VISIT	2023-06-01 15:00:00	2023-06-01 17:00:00	Accueil Permanence
21008	11066Q	ACC_VISIT	2023-06-02 09:00:00	2023-06-02 12:30:00	Accueil Permanence
21009	11066Q	ACC_VISIT	2023-06-02 14:00:00	2023-06-02 17:00:00	Accueil Permanence
21383	04042C	REU_TRAV_PARL	2023-07-13 14:30:00	2023-07-13 15:30:00	Entretien avec le Président de la Commission des Lois du Sénat
21122	04042C	REU_TRAV_PARL	2023-06-01 17:00:00	2023-06-01 18:00:00	Entretien avec un sénateur
21123	04042C	ACC_DEPL_INTER	2023-06-01 18:30:00	2023-06-01 19:15:00	Rencontre avec l'Ambassadrice d'Italie en France à l'occasion de la Fête nationale
21124	04042C	ELUS_LOCAUX	2023-06-01 19:30:00	2023-06-01 22:30:00	Rencontre avec des élus du Val-de-Marne
21381	04042C	CEREMONIE	2023-07-13 11:50:00	2023-07-13 12:30:00	Cérémonie de prise d'armes de la Légion étrangères
21382	04042C	CEREMONIE	2023-07-13 14:00:00	2023-07-13 14:30:00	Rencontre avec le Président du Sénat et les endeuillés
21384	04042C	ACC_DEPL_INTER	2023-07-13 15:50:00	2023-07-13 17:00:00	Entretien avec le Président du Sénat et le Premier ministre de la République d'Inde
21385	04042C	REU_GVT	2023-07-13 19:30:00	2023-07-13 20:30:00	Rencontre avec le Ministre des armées à l'occasion de la Fête nationale
21386	04042C	CEREMONIE	2023-07-14 10:00:00	2023-07-14 12:00:00	Cérémonie du 14 juillet en présence du Président de la République
21387	04042C	ACC_VISIT	2023-07-14 18:00:00	2023-07-14 18:30:00	Emission Europe 1
21388	04042C	ACC_DEPL_INTER	2023-07-14 20:30:00	2023-07-14 22:30:00	Rencontre officielle d'Etat avec le Président de la République à l'occasion de la visite en France du Premier ministre de la République d'Inde
21389	04042C	ELUS_LOCAUX	2023-07-17 19:30:00	2023-07-17 21:30:00	Rencontre avec des élus du Val-de-Marne
21390	04042C	ACC_DEPL_INTER	2023-07-18 14:50:00	2023-07-18 16:00:00	Entretien avec le Président du Sénat et la Présidente du Sénat d'Ouzbékistank
21391	04042C	ACC_DEPL_INTER	2023-07-18 20:00:00	2023-07-18 22:00:00	Rencontre avec l'Ambassadeur de Pologne en France à l'occasion de la fin de mission de l'Ambassadeur de Turquie en France
21461	11066Q	ACC_VISIT	2023-07-05 12:30:00	2023-07-05 15:00:00	Visite du Sénat du Boxing club de Saint-Nazaire
21462	11066Q	ORGEXTPAR	2023-07-05 17:00:00	2023-07-05 18:00:00	Réunion collégiale de la Commission nationale de Contrôle des Techniques de Renseignement
21469	11066Q	REU_TRAV_PARL	2023-07-11 10:00:00	2023-07-11 12:00:00	Réunion de groupe
21470	11066Q	REU_TRAV_PARL	2023-07-11 12:30:00	2023-07-11 14:00:00	Réunion du Groupe socialiste de la Commission des affaires étrangères suite sur le projet de loi LPM
21475	11066Q	ACC_VISIT	2023-07-18 09:00:00	2023-07-18 12:30:00	Accueil Permanence
21476	11066Q	ACC_VISIT	2023-07-18 14:00:00	2023-07-18 17:00:00	Accueil Permanence
21477	11066Q	ACC_VISIT	2023-07-19 09:00:00	2023-07-19 12:30:00	Accueil Permanence
21478	11066Q	ACC_VISIT	2023-07-19 14:00:00	2023-07-19 17:00:00	Accueil Permanence
21479	11066Q	ACC_VISIT	2023-07-20 09:00:00	2023-07-20 14:00:00	Accueil Permanence
21480	11066Q	ACC_VISIT	2023-07-20 14:00:00	2023-07-20 17:00:00	Accueil Permanence
21642	21064G	REU_TRAV_PARL	2023-11-07 13:30:00	2023-11-07 14:30:00	réunion UC - PLFSS
21643	21064G	REU_TRAV_PARL	2023-11-08 08:00:00	2023-11-08 08:30:00	FNSEA - PLFSS
21644	21064G	REU_TRAV_PARL	2023-11-15 00:00:00	2023-11-15 00:00:00	La parole aux entrepreneurs
21645	21064G	CEREMONIE	2023-11-15 18:30:00	2023-11-15 19:30:00	Ravivage Flamme Arc de Triomphe
21646	21064G	REU_TRAV_PARL	2023-11-16 13:00:00	2023-11-16 15:30:00	Alliance franco-danoise de santé - Ambassade du Danemark
21647	21064G	CEREMONIE	2023-10-10 09:00:00	2023-10-10 12:00:00	Inauguration VITEFF Epernay
21648	21064G	REU_GVT	2023-10-10 20:30:00	2023-10-10 22:00:00	Première Ministre 
21649	21064G	REU_TRAV_PARL	2023-10-18 08:00:00	2023-10-18 08:30:00	audition MSA - PLFSS
21650	21064G	REU_TRAV_PARL	2023-10-25 13:00:00	2023-10-25 15:00:00	UNCCAS
21661	04042C	ELUS_LOCAUX	2023-11-13 11:00:00	2023-11-13 13:00:00	Rendez-vous urbanisme à la Mairie de Saint-Maurice
21662	04042C	ORG_POL	2023-11-14 10:30:00	2023-11-14 12:30:00	Réunion de groupe des sénateurs les Républicains
21663	04042C	ACC_DEPL_INTER	2023-11-15 17:00:00	2023-11-15 18:00:00	Entretien avec l'Ambassadrice de Roumanie en France
21664	04042C	COLL_TER	2023-11-16 10:00:00	2023-11-16 13:00:00	Comité du Syndicat des Eaux d'Ile-de-France
21665	04042C	ACC_DEPL_INTER	2023-11-17 13:00:00	2023-11-17 14:30:00	Entretien avec l'Ambassadeur du Japon en France
21666	04042C	ACC_DEPL_INTER	2023-11-21 13:00:00	2023-11-21 14:00:00	Rencontre avec l'Ambassadeur d'Allemagne en France à l¿occasion du 68ème anniversaire de la Fondation des Forces armées
21667	04042C	ORG_POL	2023-11-21 10:30:00	2023-11-21 12:30:00	Réunion de groupe des sénateurs les Républicains
21668	04042C	ACC_DEPL_INTER	2023-11-22 16:30:00	2023-11-22 17:30:00	Rencontre avec des diplomates
21681	04042C	ELUS_LOCAUX	2023-11-20 12:00:00	2023-11-20 17:00:00	Rencontre avec les maires des Outre-Mer dans le cadre du Congrès des maires
21682	04042C	ACC_DEPL_INTER	2023-11-20 18:00:00	2023-11-20 19:00:00	Entretien avec des diplomates
21683	04042C	ACC_DEPL_INTER	2023-11-20 20:00:00	2023-11-20 22:00:00	Rencontre avec un ancien diplomate 
21684	04042C	REU_TRAV_PARL	2023-11-21 19:00:00	2023-11-21 20:00:00	Projection du film sur les massacres du 7 octobre en Israël
21685	04042C	ACC_DEPL_INTER	2023-11-21 20:15:00	2023-11-21 21:15:00	Rencontre avec l'Ambassadeur d'Argentine en France et l'Ambassadeur d'Equateur en France
21686	04042C	ELUS_LOCAUX	2023-11-22 12:00:00	2023-11-22 14:00:00	Salon des Maires et des Collectivités Locales
21687	04042C	ACC_VISIT	2023-11-22 18:45:00	2023-11-22 19:30:00	Emission Public Sénat de Thomas Hugues
21688	04042C	ACC_DEPL_INTER	2023-11-23 16:00:00	2023-11-23 17:00:00	Entretien avec l'Ambassadeur de France du Royaume du Maroc
21689	04042C	CEREMONIE	2023-11-24 18:30:00	2023-11-24 20:00:00	Inauguration du 13ème Salon de l'artisanat et métiers d'art de Nogent-sur-Marne
21690	04042C	ELUS_LOCAUX	2023-11-27 11:30:00	2023-11-27 12:30:00	Rendez-vous urbanisme à la Mairie de Saint-Maurice
21691	04042C	DEPL_PRES_GVT	2023-11-28 09:15:00	2023-11-28 10:45:00	Déplacement du Ministre délégué chargé des Transports au Centre d'exploitation de maintenance de la ligne 15 Sud de Champigny-sur-Marne à l'occasion du 1er roulage du Grand Paris Express
21692	04042C	ORG_POL	2023-11-28 11:15:00	2023-11-28 12:30:00	Réunion de groupe des sénateurs les Républicains
21693	04042C	ACC_DEPL_INTER	2023-11-28 18:00:00	2023-11-28 19:00:00	Rencontre avec l'Ambassadrice de Roumanie en France
21704	21064G	ACC_VISIT	2023-11-22 13:30:00	2023-11-22 15:00:00	Maires de la Marne
21702	21064G	REU_TRAV_PARL	2023-11-21 13:30:00	2023-11-21 14:30:00	audition CSRD
21703	21064G	ACC_VISIT	2023-11-21 18:30:00	2023-11-21 22:00:00	Maires de la Marne
21705	21064G	REU_GVT	2023-11-22 17:30:00	2023-11-22 22:00:00	Intervention Congrès des Maires - Décarbonation des industries - Ministère de l'Industrie
21706	21064G	REU_TRAV_PARL	2023-11-28 12:30:00	2023-11-28 14:30:00	Décarbonation des entreprises
21707	21064G	REU_TRAV_PARL	2023-11-28 00:00:00	2023-11-28 00:00:00	audition CSRD
21708	21064G	REU_TRAV_PARL	2023-11-29 13:30:00	2023-11-29 15:00:00	audition CSRD
21709	21064G	REU_TRAV_PARL	2023-12-05 13:00:00	2023-12-05 15:00:00	Gérard Larcher
21710	21064G	REU_TRAV_PARL	2023-12-06 08:00:00	2023-12-06 09:00:00	audition ppl recours garde alternée
21711	21064G	REU_TRAV_PARL	2023-12-06 16:30:00	2023-12-06 19:30:00	audition CSRD
21712	04042C	ELUS_LOCAUX	2023-11-29 16:30:00	2023-11-29 17:30:00	Rencontre avec des élus du Val-de-Marne
21713	04042C	REU_TRAV_PARL	2023-11-29 20:00:00	2023-11-29 21:30:00	Rencontre avec des sénateurs 
21714	04042C	ACC_DEPL_INTER	2023-11-30 18:30:00	2023-11-30 19:30:00	Rencontre avec l'Ambassadrice du Royaume-Uni à l'occasion de la Fête nationale écossaise 
21715	04042C	ACC_DEPL_INTER	2023-12-04 10:00:00	2023-12-04 11:00:00	Entretien avec le Président du Sénat thaïlandais
21716	04042C	ORG_POL	2023-12-05 10:30:00	2023-12-05 12:30:00	Réunion de groupe des sénateurs les Républicains
21717	04042C	ELUS_LOCAUX	2023-12-05 13:00:00	2023-12-05 14:15:00	Rencontre avec un élu du Val-de-Marne
21718	04042C	REU_TRAV_PARL	2023-12-06 16:30:00	2023-12-06 17:30:00	Réunion délégation Outre-Mer
21719	04042C	REU_TRAV_PARL	2023-12-06 14:15:00	2023-12-06 15:15:00	Assemblée générale reconstitutive du groupe d'amitié France-Maroc
21721	21064G	REU_TRAV_PARL	2023-12-07 15:00:00	2023-12-07 18:00:00	Assemblée Générale CGB
21722	21064G	REU_TRAV_PARL	2023-12-12 17:00:00	2023-12-12 18:30:00	audition CSRD
21723	21064G	REU_TRAV_PARL	2023-12-13 08:00:00	2023-12-13 09:00:00	audition ppl recours garde alternée
21724	21064G	REU_TRAV_PARL	2023-12-13 14:00:00	2023-12-13 15:00:00	audition CSRD
21181	04042C	ELUS_LOCAUX	2023-06-12 12:30:00	2023-06-12 14:30:00	Rencontre avec des élus du Val-de-Marne
21185	04042C	ACC_VISIT	2023-06-13 08:00:00	2023-06-13 08:30:00	Emission RFI
21183	04042C	REU_TRAV_PARL	2023-06-13 13:00:00	2023-06-13 14:00:00	Réunion de travail avec un sénateur
21184	04042C	ORG_POL	2023-06-13 11:00:00	2023-06-13 12:30:00	Réunion de Groupe des sénateurs LR du Sénat
21725	04042C	COLL_TER	2023-12-11 15:00:00	2023-12-11 16:30:00	Réunion du Syndicat des Eaux d'Ile-de-France
21726	04042C	ELUS_LOCAUX	2023-12-12 12:30:00	2023-12-12 14:00:00	Rencontre avec les seniors de Saint-Maurice
21727	04042C	ORG_POL	2023-12-12 10:30:00	2023-12-12 11:30:00	Réunion de groupe des sénateurs les Républicains
21728	04042C	ACC_DEPL_INTER	2023-12-12 18:30:00	2023-12-12 20:00:00	Rencontre avec l'Ambassadrice des Etats-Unis en France
21729	04042C	ACC_DEPL_INTER	2023-12-13 19:30:00	2023-12-13 21:30:00	Rencontre avec l'Ambassadrice du Royaume-Uni en France
21730	04042C	ELUS_LOCAUX	2023-12-13 13:00:00	2023-12-13 14:30:00	Rencontre avec des élus du Val-de-Marne
21731	04042C	COLL_TER	2023-12-14 15:00:00	2023-12-14 17:30:00	Conseil de surveillance des Hôpitaux de Saint-Maurice
21741	21064G	REU_TRAV_PARL	2023-12-14 16:00:00	2023-12-14 18:00:00	Copil Accès aux soins des patients ALD sans médecin traitant
21742	21064G	REU_TRAV_PARL	2023-12-19 10:30:00	2023-12-19 11:00:00	réunion UC - CAS
21743	21064G	REU_TRAV_PARL	2023-12-19 11:00:00	2023-12-19 13:00:00	groupe UC
21761	04042C	CEREMONIE	2024-01-08 15:00:00	2024-01-08 16:30:00	Prise d'armes et remise de décorations par le Ministre des Armées
21745	21064G	REU_TRAV_PARL	2023-12-20 13:15:00	2023-12-20 14:00:00	audition ppl troubles neuro-développement
21746	21064G	REU_TRAV_PARL	2023-12-20 11:45:00	2023-12-20 12:15:00	groupe France-Canada
21747	21064G	REU_TRAV_PARL	2023-12-21 13:00:00	2023-12-21 15:00:00	réunion Chambre d'Agriculture de la Marne
21762	04042C	CEREMONIE	2024-01-08 19:30:00	2024-01-08 21:30:00	Cérémonie des voeux de Charenton-le-Pont
21763	04042C	ACC_DEPL_INTER	2024-01-09 16:00:00	2024-01-09 18:00:00	Remise de distinction par l'Ambassadeur de la Hongrie en France
21764	04042C	CEREMONIE	2024-01-09 19:00:00	2024-01-09 21:00:00	Cérémonie des voeux de Saint-Maurice
21765	04042C	CEREMONIE	2024-01-10 19:00:00	2024-01-10 21:00:00	Cérémonie des voeux de Maisons-Alfort
21766	04042C	CEREMONIE	2024-01-11 16:00:00	2024-01-11 17:30:00	Cérémonie des voeux de la Préfète du Val-de-Marne
21767	04042C	CEREMONIE	2024-01-11 19:00:00	2024-01-11 21:00:00	Cérémonie des voeux de Joinville-le-Pont
21768	04042C	CEREMONIE	2024-01-12 19:00:00	2024-01-12 20:00:00	Cérémonie des voeux de Choisy-le-Roi
21769	04042C	CEREMONIE	2024-01-12 20:00:00	2024-01-12 21:00:00	Cérémonie des voeux d'Ablon-sur-Seine
21770	04042C	CEREMONIE	2024-01-12 21:00:00	2024-01-12 22:00:00	Cérémonie des voeux de Périgny-sur-Yerres
21771	04042C	CEREMONIE	2024-01-15 19:00:00	2024-01-15 21:00:00	Cérémonie des voeux de Thiais
21772	04042C	ORG_POL	2024-01-16 10:30:00	2024-01-16 12:30:00	Réunion de groupe des sénateurs LR du Sénat
21773	04042C	ELUS_LOCAUX	2024-01-16 12:00:00	2024-01-16 13:00:00	Rencontre avec la Vice-présidente du Conseil régional d'Ile-de-France
21774	04042C	CEREMONIE	2024-01-16 13:30:00	2024-01-16 14:30:00	Présentation des voeux de la Présidente de l'Assemblée nationale
21775	04042C	ACC_DEPL_INTER	2024-01-16 15:00:00	2024-01-16 16:00:00	Rencontre avec un ancien Ambassadeur de France
21776	04042C	REU_TRAV_PARL	2024-01-16 18:00:00	2024-01-16 19:00:00	Assemblée générale du GIA France-Arménie
21777	04042C	CEREMONIE	2024-01-16 19:00:00	2024-01-16 20:00:00	Présentation des voeux du Président du Sénat
21778	04042C	CEREMONIE	2024-01-16 20:30:00	2024-01-16 22:00:00	Cérémonie des voeux de l'Hay-les-Roses
21779	04042C	REU_TRAV_PARL	2024-01-17 08:30:00	2024-01-17 09:30:00	Réunion des Commissaires L.R de la Commission des Affaires étrangères, de la Défense et des Forces armées
21780	04042C	ACC_DEPL_INTER	2024-01-17 18:00:00	2024-01-17 19:00:00	Remise de distinction par la Présidente de l'Assemblée nationale de la République de Chypre
21781	04042C	ACC_DEPL_INTER	2024-01-17 19:30:00	2024-01-17 20:30:00	Rencontre avec l'Ambassadeur d'Argentine en France
21801	21064G	REU_TRAV_PARL	2024-01-10 08:30:00	2024-01-10 09:30:00	audition CSRD
21802	21064G	REU_TRAV_PARL	2024-01-16 13:30:00	2024-01-16 18:30:00	audition CSRD
21803	21064G	CEREMONIE	2024-01-16 00:00:00	2024-01-16 00:00:00	Voeux Gérard Larcher
21804	21064G	COLL_TER	2024-01-18 09:00:00	2024-01-18 20:30:00	dans le département
21805	21064G	REU_TRAV_PARL	2024-01-23 13:00:00	2024-01-23 14:00:00	arbitrages CSRD
21806	21064G	REU_GVT	2024-01-23 16:00:00	2024-01-23 17:00:00	Catherine Vautrin, Ministre du Travail, des Solidarités et de la Santé
21807	21064G	REU_TRAV_PARL	2024-01-24 13:45:00	2024-01-24 14:45:00	audition CSRD
21821	04042C	CEREMONIE	2024-01-18 19:00:00	2024-01-18 20:00:00	Cérémonie des Voeux à Mandres-Les-Roses
21822	04042C	CEREMONIE	2024-01-18 20:30:00	2024-01-18 21:30:00	Cérémonie des voeux à Noiseau
21823	04042C	COLL_TER	2024-01-19 08:45:00	2024-01-19 11:00:00	Réunion du bureau du Syndicat des Eaux d'Ile-de-France
21824	04042C	ACC_DEPL_INTER	2024-01-19 15:00:00	2024-01-19 16:00:00	Entretien avec une délégation coréenne
21825	04042C	CEREMONIE	2024-01-19 19:30:00	2024-01-19 21:30:00	Cérémonie des Voeux à Rungis
21826	04042C	CEREMONIE	2024-01-22 18:00:00	2024-01-22 19:00:00	Présentation des Voeux de l'Institut Gustave Roussy à Villejuif
21827	04042C	ACC_DEPL_INTER	2024-01-22 20:00:00	2024-01-22 22:00:00	Rencontre avec un diplomate
21828	04042C	ELUS_LOCAUX	2024-01-22 13:00:00	2024-01-22 14:15:00	Rencontre avec un élu du Val-de-Marne
21829	04042C	ORG_POL	2024-01-23 10:30:00	2024-01-23 12:30:00	Réunion de groupe des sénateurs les Républicains
21830	04042C	ACC_DEPL_INTER	2024-01-23 19:30:00	2024-01-23 21:30:00	Rencontre avec l'Ambassadrice d
21831	04042C	ACC_DEPL_INTER	2024-01-23 19:30:00	2024-01-23 21:30:00	Rencontre avec l'Ambassadrice du Royaume-Uni en France
21832	04042C	ELUS_LOCAUX	2024-01-24 16:30:00	2024-01-24 17:30:00	Entretien avec un élu du Val-de-Marne
21833	04042C	ACC_DEPL_INTER	2024-01-24 13:00:00	2024-01-24 14:00:00	Rencontre avec l'Ambassadrice de Moldavie en France
21834	04042C	CEREMONIE	2024-01-24 19:30:00	2024-01-24 21:30:00	Cérémonie des Voeux de Limeil-Brévannes
21835	04042C	COLL_TER	2024-01-25 10:00:00	2024-01-25 12:00:00	Comité du Syndicat des Eaux d'Ile-de-France
21836	04042C	CEREMONIE	2024-01-25 18:30:00	2024-01-25 20:00:00	Présentation des Voeux du Cercle Mixte de la Gendarmerie
21837	04042C	CEREMONIE	2024-01-26 19:00:00	2024-01-26 20:00:00	Cérémonie des Voeux à Villecresnes
21838	04042C	CEREMONIE	2024-01-26 20:30:00	2024-01-26 22:30:00	Concert inaugural du grand orgue rénové de Saint-Maur-des-Fossés
21839	04042C	ELUS_LOCAUX	2024-02-05 12:30:00	2024-02-05 13:30:00	Rencontre avec un élu du Val-de-Marne
21840	04042C	CEREMONIE	2024-02-05 14:30:00	2024-02-05 16:30:00	Audience solennelle de rentrée du Tribunal Judiciaire de Créteil
21841	04042C	ORG_POL	2024-02-06 10:30:00	2024-02-06 12:30:00	Réunion de groupe des sénateurs les Républicains
21861	04042C	CEREMONIE	2024-02-06 19:30:00	2024-02-06 21:30:00	Rencontre du Club des Ailes pour l'Avenir
21862	04042C	ACC_DEPL_INTER	2024-02-08 13:00:00	2024-02-08 14:30:00	Rencontre avec l'Ambassadeur de Turquie en France
21882	04042C	ORG_POL	2024-02-13 10:30:00	2024-02-13 12:30:00	Réunion de groupe des sénateurs les Républicains
21864	04042C	DEPL_PRES_GVT	2024-02-09 09:15:00	2024-02-09 14:45:00	Déplacement dans le Val-de-Marne de la Présidente de l'Assemblée nationale
21881	04042C	ELUS_LOCAUX	2024-02-12 11:30:00	2024-02-12 12:30:00	Entretien avec un élu du Val-de-Marne
21883	04042C	ACC_DEPL_INTER	2024-02-13 19:00:00	2024-02-13 21:00:00	Rencontre avec l'Ambassadrice d'Arménie en France
21901	04042C	ELUS_LOCAUX	2024-02-26 12:30:00	2024-02-26 14:00:00	Rencontre avec la Préfète du Val-de-Marne
21885	04042C	REU_GVT	2024-02-14 16:30:00	2024-02-14 17:30:00	Entretien avec la secrétaire d¿Etat chargée du développement et des partenariats internationaux
21886	04042C	ELUS_LOCAUX	2024-02-14 12:30:00	2024-02-14 14:00:00	Rencontre avec des élus du Val-de-Marne
21902	04042C	ORG_POL	2024-02-27 10:30:00	2024-02-27 12:30:00	Réunion de groupe des sénateurs les Républicains
21903	04042C	REU_TRAV_PARL	2024-02-27 13:00:00	2024-02-27 14:30:00	Rencontre avec le Grand Chancelier de la Légion d'Honneur
21904	04042C	CEREMONIE	2024-02-26 18:30:00	2024-02-26 22:00:00	Cérémonie à l'occasion de la 60ème édition du Salon International de l'Agriculture
21905	04042C	ACC_VISIT	2024-02-16 13:45:00	2024-02-16 14:30:00	Emission Extra Local de Public Sénat
21921	21064G	REU_TRAV_PARL	2024-01-30 13:15:00	2024-01-30 14:00:00	audition Hervé Lapie - FNSEA avec groupe UC
20981	04042C	ACC_DEPL_INTER	2023-05-31 08:30:00	2023-05-31 09:30:00	Entretien avec le Ministre des Affaires étrangères et de la Migration et des Tunisiens à l'étranger
20982	01025N	REU_TRAV_PARL	2023-05-23 12:30:00	2023-05-23 14:00:00	rencontre Président Sénat et commissaires UC Aff Eco et DevDur
21042	14133K	REU_TRAV_PARL	2023-01-20 09:00:00	2023-01-20 11:30:00	Conférence-Débat rôle du Sénat - Collège Calvados
21043	14133K	DEL_ACT_PAR	2023-01-20 15:00:00	2023-01-20 16:00:00	Réunion du Bureau de l'AP-OSCE - Visio
21044	14133K	COLL_TER	2023-01-20 16:15:00	2023-01-20 17:30:00	rdv individuels permanence parlementaire
21045	14133K	COLL_TER	2023-01-19 14:30:00	2023-01-19 16:30:00	rdv individuels permanence parlementaire
21046	14133K	ELUS_LOCAUX	2023-01-16 11:00:00	2023-01-16 12:00:00	rdv permanence parlementaire
21047	14133K	ELUS_LOCAUX	2023-01-16 15:45:00	2023-01-16 16:45:00	rdv permanence parlementaire
21048	14133K	CEREMONIE	2023-01-13 10:30:00	2023-01-13 12:30:00	Audience solennelle de début d'année- Cour d'Appel de Caen
21049	14133K	REU_TRAV_PARL	2023-01-13 12:45:00	2023-01-13 14:00:00	rdv presse départementale
21050	14133K	REU_TRAV_PARL	2023-01-13 14:00:00	2023-01-13 16:00:00	Visite du centre des avocats de Caen et réunion d 'échanges
21051	14133K	REU_TRAV_PARL	2023-01-09 12:00:00	2023-01-09 14:30:00	Déjeuner de travail avec le Préfet du Calvados
21054	14133K	COLL_TER	2023-01-05 10:00:00	2023-01-05 11:30:00	réunion élus et artisans à Pont d'Ouilly
21055	14133K	REU_TRAV_PARL	2022-12-23 10:00:00	2022-12-23 11:30:00	rdv individuels permanence parlementaire
21056	14133K	REU_TRAV_PARL	2022-12-22 16:15:00	2022-12-22 17:00:00	rdv permanence parlementaire
21060	14133K	ELUS_LOCAUX	2022-12-16 09:30:00	2022-12-16 11:00:00	Réunion comité de cohésion territoriale - Préfecture Caen
21058	14133K	REU_TRAV_PARL	2022-12-20 10:00:00	2022-12-20 12:00:00	rdv permanence parlementaire
21059	14133K	REU_TRAV_PARL	2022-12-20 14:30:00	2022-12-20 16:30:00	visite site industriel
21061	14133K	ORG_POL	2022-12-13 11:00:00	2022-12-13 12:30:00	Réunion du Groupe LR Sénat
21062	14133K	REU_TRAV_PARL	2022-12-12 16:00:00	2022-12-12 18:00:00	rdv individuels permanence parlementaire
21063	14133K	CEREMONIE	2022-12-09 11:30:00	2022-12-09 12:30:00	Inauguration statues C Quiesse - Caen
21064	14133K	ELUS_LOCAUX	2022-12-09 14:30:00	2022-12-09 16:30:00	Conférence des parlementaires - UAMC CAEN
21065	14133K	REU_TRAV_PARL	2022-12-08 10:00:00	2022-12-08 11:00:00	rdv individuels permanence parlementaire
21066	14133K	ORG_POL	2022-12-06 11:00:00	2022-12-06 12:30:00	Réunion du Groupe LR Sénat
21067	14133K	REU_TRAV_PARL	2022-12-06 17:00:00	2022-12-06 18:00:00	rdv Délégation Birmanie
21068	14133K	REU_TRAV_PARL	2022-12-01 15:00:00	2022-12-01 16:30:00	rencontre responsables départementaux de la FDSEA 14
21071	14133K	ACC_VISIT	2022-11-29 10:20:00	2022-11-29 11:00:00	accueil Groupe UPEC
21073	14133K	REU_TRAV_PARL	2022-11-28 14:30:00	2022-11-28 16:00:00	rdv permanence parlementaire
21072	14133K	ORG_POL	2022-11-29 11:00:00	2022-11-29 12:30:00	\N
21074	14133K	REU_TRAV_PARL	2022-11-18 12:00:00	2022-11-18 14:00:00	déjeuner de travail avec IHEDN AR3
21075	14133K	REU_TRAV_PARL	2022-11-18 15:30:00	2022-11-18 18:00:00	rdv individuels permanence parlementaire
21076	14133K	CEREMONIE	2022-11-15 18:45:00	2022-11-15 20:00:00	AG Amicale Gaulliste du Sénat
21077	14133K	ORG_POL	2022-11-15 11:00:00	2022-11-15 12:30:00	Réunion du Groupe LR Sénat
21081	14133K	ORG_POL	2022-11-08 18:00:00	2022-11-08 20:30:00	Réunion LR 14 avec le Président Retailleau - CAEN
21082	14133K	COLL_TER	2022-11-07 09:30:00	2022-11-07 11:30:00	Réunion de travail - municipalité de Saint-Martin-de-Fontenay (Calvados)
21083	14133K	COLL_TER	2022-11-07 14:30:00	2022-11-07 17:30:00	Visite de territoire Caumont-sur-Aure
21084	14133K	ORG_POL	2022-10-28 09:30:00	2022-10-28 11:00:00	Réunion Comité LR 6e circo
21085	14133K	ACC_VISIT	2022-10-27 10:00:00	2022-10-27 11:00:00	accueil délégation des Comores
21086	14133K	REU_TRAV_PARL	2022-10-27 17:00:00	2022-10-27 18:00:00	Rdv acteurs économiques - permanence parlementaire
21090	14133K	REU_TRAV_PARL	2022-10-24 15:00:00	2022-10-24 16:30:00	visite entreprise éphémère de réinsertion - Condé-en-Normandie (Calvados)
21088	14133K	ORG_POL	2022-10-25 11:00:00	2022-10-25 12:30:00	Réunion du Groupe LR Sénat
21089	14133K	REU_TRAV_PARL	2022-10-25 17:30:00	2022-10-25 19:00:00	Revue nationale stratégique - Ministère des armées
21091	14133K	REU_TRAV_PARL	2022-10-21 09:30:00	2022-10-21 11:00:00	Rendez-vous sociaux et économiques permanence parlementaire dans le Calvados
21092	14133K	REU_TRAV_PARL	2022-10-18 15:00:00	2022-10-18 16:00:00	AP OSCE Comitee Rule
21093	14133K	REU_TRAV_PARL	2022-10-17 10:00:00	2022-10-17 12:00:00	Rendez-vous sociaux et économiques permanence parlementaire dans le Calvados
21094	14133K	REU_TRAV_PARL	2022-10-17 12:30:00	2022-10-17 14:00:00	Déjeuner de travail - parlementaire Calvados
21095	14133K	REU_TRAV_PARL	2022-10-17 15:30:00	2022-10-17 18:30:00	Rendez-vous sociaux et économiques permanence parlementaire dans le Calvados
21096	14133K	REU_TRAV_PARL	2022-10-14 10:00:00	2022-10-14 11:30:00	rdv individuels permanence parlementaire
21097	14133K	CEREMONIE	2022-10-14 15:00:00	2022-10-14 16:30:00	inhumation personnalité locale - Calvados
21098	14133K	REU_TRAV_PARL	2022-10-13 15:00:00	2022-10-13 16:00:00	Rendez-vous sociaux et économiques permanence parlementaire dans le Calvados
21099	14133K	REU_TRAV_PARL	2022-10-13 16:30:00	2022-10-13 17:00:00	rdv réunion de travail visio Présidence AP OSCE
21100	14133K	REU_TRAV_PARL	2022-10-10 12:30:00	2022-10-10 14:30:00	Déjeuner de travail avec le Préfet du Calvados
21101	14133K	ORG_POL	2022-10-04 11:00:00	2022-10-04 12:30:00	Réunion du Groupe LR Sénat
21102	14133K	DEL_ACT_PAR	2022-10-05 14:00:00	2022-10-05 16:00:00	réunion délégation parlementaire française à l'AP-OSCE - Assemblée nationale
21103	14133K	REU_TRAV_PARL	2022-10-06 11:00:00	2022-10-06 12:00:00	Rendez-vous sociaux et économiques permanence parlementaire dans le Calvados
21104	14133K	REU_TRAV_PARL	2022-10-06 15:00:00	2022-10-06 16:30:00	Rendez-vous sociaux et économiques permanence parlementaire dans le Calvados
21105	14133K	REU_TRAV_PARL	2022-10-07 12:00:00	2022-10-07 14:00:00	Déjeuner de travail élus régionaux
21106	14133K	REU_TRAV_PARL	2022-10-07 15:00:00	2022-10-07 16:30:00	rdv responsables départementaux - permanence parlementaire
21294	04042C	ACC_DEPL_INTER	2023-06-29 18:30:00	2023-06-29 19:30:00	Rencontre avec le Nonce Apostolique de France à l'occasion du 10ème anniversaire de l'élection du Pape François
21295	04042C	ACC_VISIT	2023-06-29 07:45:00	2023-06-29 08:20:00	Emission Public Sénat
21296	04042C	ELUS_LOCAUX	2023-07-03 10:30:00	2023-07-03 11:30:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
21297	04042C	ELUS_LOCAUX	2023-07-03 12:00:00	2023-07-03 13:00:00	Rassemblement des élus et des citoyens à l'Hôtel de Ville de Valenton
21298	04042C	ELUS_LOCAUX	2023-07-03 15:00:00	2023-07-03 16:30:00	Rassemblement et Marche des élus et des Citoyens à L'Haÿ-les-Roses
21299	04042C	COLL_TER	2023-07-03 19:00:00	2023-07-03 19:30:00	Conseil de Territoire
21300	04042C	REU_GVT	2023-07-03 20:00:00	2023-07-03 21:30:00	Réunion de travail avec la Ministre de l'Europe et des Affaires étrangères et le Président de la Commission des Afaires étrangères de l'Assemblée nationale
21301	04042C	ORG_POL	2023-07-04 11:00:00	2023-07-04 12:30:00	Réunion de Groupe des sénateurs LR du Sénat
21302	04042C	REU_TRAV_PARL	2023-07-04 15:45:00	2023-07-04 17:00:00	Entretien avec le Président des LR du Sénat
21303	04042C	ACC_DEPL_INTER	2023-07-04 17:00:00	2023-07-04 18:00:00	Entretien avec un parlementaire de la République Démocratique du Congo
21304	04042C	ACC_VISIT	2023-07-04 18:00:00	2023-07-04 19:00:00	Entretien avec un Collectif d'agriculteurs du Val-de-Marne
21305	04042C	REU_TRAV_PARL	2023-07-04 19:30:00	2023-07-04 20:30:00	Rencontre avec le Président du Sénat à l'occasion de la fin de session
21306	04042C	ACC_DEPL_INTER	2023-07-05 12:15:00	2023-07-05 13:15:00	Entretien avec le Président du Sénat et la Présidente du Conseil national de Monaco
21307	04042C	ACC_VISIT	2023-07-05 13:15:00	2023-07-05 14:30:00	Rencontre avec des élus du Val-de-Marne
21308	04042C	CEREMONIE	2023-07-05 17:00:00	2023-07-05 19:00:00	Prise d'armes d'étés présidée par le Ministre des Armées
21309	04042C	ACC_DEPL_INTER	2023-07-05 19:30:00	2023-07-05 20:30:00	Soirée à l'occasion des  35 ans d'Image 7
21401	04042C	ACC_DEPL_INTER	2023-07-20 11:05:00	2023-07-20 12:15:00	Entretien avec le Président du Sénat et le Président de l'Assemblée nationale de la République du Kosovo
21403	04042C	ACC_VISIT	2023-07-20 13:00:00	2023-07-20 14:15:00	Rencontre avec un élu du Val-de-Marne
21125	04042C	CEREMONIE	2023-06-02 14:00:00	2023-06-02 15:00:00	Pose de la première pierre de la Mission Locale de Maisons-Alfort
21126	04042C	CEREMONIE	2023-06-02 18:00:00	2023-06-02 19:00:00	Vernissage du Salon des Arts de Saint-Maurice
21127	04042C	REU_TRAV_PARL	2023-06-01 15:30:00	2023-06-01 16:30:00	Entretien avec le chef du cabinet militaire de la Première ministre
21128	04042C	ELUS_LOCAUX	2023-06-05 12:30:00	2023-06-05 14:30:00	Rencontre avec des élus du Val-de-Marne
21132	04042C	ACC_DEPL_INTER	2023-06-06 08:20:00	2023-06-06 09:30:00	Entretien avec le Président du Sénat et le Ministre des Affaires étrangères vietnamien
21130	04042C	ACC_DEPL_INTER	2023-06-05 15:00:00	2023-06-05 16:00:00	Entretien avec le Président de la Commission des Affaires étrangères du Sénat roumain
21131	04042C	ELUS_LOCAUX	2023-06-05 18:30:00	2023-06-05 20:30:00	Réunion avec des élus du Val-de-Marne
21133	04042C	ACC_VISIT	2023-06-06 10:00:00	2023-06-06 11:00:00	Entretien avec un élu du Val-de-Marne
21134	04042C	ORG_POL	2023-06-06 11:00:00	2023-06-06 12:30:00	Réunion de Groupe des sénateurs LR du Sénat
21135	04042C	ACC_VISIT	2023-06-06 13:00:00	2023-06-06 14:00:00	Rencontre avec un élu du Val-de-Marne
21136	04042C	REU_TRAV_PARL	2023-06-06 14:30:00	2023-06-06 15:30:00	Réunion avec le Président du Sénat
21137	04042C	REU_TRAV_PARL	2023-06-06 16:00:00	2023-06-06 17:00:00	Entretien avec le Président des LR du Sénat
21141	04042C	ACC_DEPL_INTER	2023-06-07 08:30:00	2023-06-07 09:30:00	Entretien avec le Ministre des Affaires étrangères de Hongrie
21139	04042C	ACC_VISIT	2023-06-06 17:00:00	2023-06-06 17:45:00	Entretien avec un élu du Val-de-Marne
21140	04042C	CEREMONIE	2023-06-06 18:30:00	2023-06-06 20:30:00	Cérémonie de signature de la Charte de jumelage entre Chennevières-sur-Marne et Izium en Ukraine
21142	04042C	ACC_DEPL_INTER	2023-06-07 13:20:00	2023-06-07 14:45:00	Entretien avec l'Ambassadrice d'Arménie en France
21143	04042C	ELUS_LOCAUX	2023-06-08 09:00:00	2023-06-08 10:00:00	Réunion avec des élus du Val-de-Marne
21144	04042C	ELUS_LOCAUX	2023-06-08 13:00:00	2023-06-08 14:30:00	Rencontre avec des élus du Val-de-Marne
21145	04042C	ACC_DEPL_INTER	2023-06-08 15:30:00	2023-06-08 16:30:00	Entretien avec un député du Parlement d'Azerbaïdjan
21146	04042C	ACC_DEPL_INTER	2023-06-08 16:30:00	2023-06-08 17:30:00	Entretien avec le Président de la Commission des Affaires étrangères et le Président de la Commission des Affaires économiques du Parlement géorgien
21262	04042C	CEREMONIE	2023-06-22 10:30:00	2023-06-22 12:30:00	Cérémonie Dévoilement du prototype de la cabine du 1er téléphérique d¿Île-de-France à Limeil-Brévannes
21148	04042C	COLL_TER	2023-06-09 08:45:00	2023-06-09 10:45:00	Réunion du bureau du Syndicat des Eaux d'Ile-de-France
21149	04042C	ACC_VISIT	2023-06-09 11:00:00	2023-06-09 12:00:00	Entretien avec un élu du Val-de-Marne
21150	04042C	ELUS_LOCAUX	2023-06-09 18:30:00	2023-06-09 21:30:00	Conseil municipal de Saint-Maurice
21161	11066Q	ACC_VISIT	2023-06-05 09:00:00	2023-06-05 12:30:00	Accueil Permanence
21162	11066Q	ACC_VISIT	2023-06-05 14:00:00	2023-06-05 17:00:00	Accueil Permanence
21163	11066Q	ACC_VISIT	2023-06-05 17:00:00	2023-06-05 17:30:00	Entretien téléphonique avec le directeur de cabinet de la Première Ministre
21164	11066Q	REU_TRAV_PARL	2023-06-06 14:30:00	2023-06-06 15:30:00	Réunion du Groupe socialiste de la Commission des affaires étrangères
21165	11066Q	COLL_TER	2023-06-09 09:30:00	2023-06-09 12:00:00	Réunion du Comité d'Orientation stratégique de l'étude de zone de surmortalité de l'agglomération nazairienne
21166	11066Q	ACC_VISIT	2023-06-09 14:30:00	2023-06-09 17:00:00	Accueil Permanence
21167	11066Q	ACC_VISIT	2023-06-12 09:00:00	2023-06-12 12:30:00	Accueil Permanence
21168	11066Q	ACC_VISIT	2023-06-12 14:00:00	2023-06-12 17:00:00	Accueil Permanence
21261	04042C	REU_TRAV_PARL	2023-06-21 16:30:00	2023-06-21 17:30:00	Entretien avec un Chef de cabinet militaire
21263	04042C	ACC_VISIT	2023-06-22 13:00:00	2023-06-22 14:15:00	Rencontre avec un élu du Val-de-Marne
21264	04042C	CEREMONIE	2023-06-22 19:00:00	2023-06-22 19:30:00	Vernissage de l'exposition sur Robert-André Vivien à l'occasion des 100 ans de sa naissance à Saint-Mandé
21265	04042C	ACC_DEPL_INTER	2023-06-22 20:30:00	2023-06-22 22:00:00	Rencontre avec l'Ambassadeur de Grèce en France à l'occasion de la Fête annuelle du Cercle de l'Union Interalliée
21266	04042C	ACC_VISIT	2023-06-23 08:40:00	2023-06-23 12:00:00	Visite du Salon du Bourget 2023 avec la Première ministre
21267	04042C	ACC_VISIT	2023-06-23 13:00:00	2023-06-23 14:30:00	Rencontre avec des élus du Val-de-Marne
21268	04042C	ACC_DEPL_INTER	2023-06-23 14:45:00	2023-06-23 16:00:00	Entretien avec le Président du Sénat et le Premier ministre chinois
21269	04042C	ACC_VISIT	2023-06-23 16:30:00	2023-06-23 17:30:00	Entretien avec deux élus du Val-de-Marne
21270	04042C	ACC_VISIT	2023-06-23 17:30:00	2023-06-23 18:00:00	Entretien téléphonique avec un journaliste du Monde Jérusalem
21271	04042C	ELUS_LOCAUX	2023-06-26 08:30:00	2023-06-26 09:30:00	Rencontre avec des élus du Val-de-Marne
21272	04042C	ACC_VISIT	2023-06-26 12:30:00	2023-06-26 14:00:00	Rencontre avec des élus du Val-de-Marne
21273	04042C	COLL_TER	2023-06-26 15:00:00	2023-06-26 16:30:00	Commission Solidarité Eau du Syndicat des Eaux d'Ile-de-France
21274	04042C	ACC_VISIT	2023-06-26 11:00:00	2023-06-26 12:00:00	Emission de Radio Notre-Dame
21275	04042C	ACC_VISIT	2023-06-26 18:45:00	2023-06-26 19:30:00	Emission Sens Public - Public Sénat
21276	04042C	REU_TRAV_PARL	2023-06-26 17:00:00	2023-06-26 18:30:00	Examen des amendements de la loi de programmation militaire 2024-2030
21277	04042C	ORG_POL	2023-06-27 11:00:00	2023-06-27 12:30:00	Réunion de Groupe des sénateurs LR du Sénat
21278	04042C	ACC_VISIT	2023-06-27 13:00:00	2023-06-27 14:00:00	Rencontre avec un élu du Val-de-Marne
21290	11066Q	ACC_VISIT	2023-07-03 09:00:00	2023-07-03 12:30:00	Accueil Permanence
21291	11066Q	ACC_VISIT	2023-07-03 14:00:00	2023-07-03 15:00:00	Accueil Permanence
21292	11066Q	REU_TRAV_PARL	2023-07-03 15:00:00	2023-07-03 15:30:00	Visio conférence avec le Haut Commissaire à l'Emploi et à l'Engagement des entreprises autour des sujets liés à France Travail
21293	11066Q	ACC_VISIT	2023-07-03 15:30:00	2023-07-03 17:00:00	Accueil Permanence
21321	14133K	REU_TRAV_PARL	2023-06-13 16:00:00	2023-06-13 19:00:00	Déplacement groupe d'études "agriculture et alimentation" - évènement openfield de Milly-la-Forêt
21322	14133K	ORG_POL	2023-06-13 11:00:00	2023-06-13 12:30:00	Réunion du Groupe LR Sénat
21323	14133K	REU_TRAV_PARL	2023-06-14 08:00:00	2023-06-14 09:00:00	petit déjeuner de travail - avenir de la commune
21335	14133K	COLL_TER	2023-06-26 12:30:00	2023-06-26 14:00:00	Déjeuner de travail avec le Préfet du Calvados
21325	14133K	REU_TRAV_PARL	2023-06-15 11:00:00	2023-06-15 14:30:00	Visite site industriel secteur de la Défense
21326	14133K	CEREMONIE	2023-06-16 09:30:00	2023-06-16 11:00:00	Cérémonie Fidélité Gaulliste - Courseulles-sur-Mer
21327	14133K	CEREMONIE	2023-06-16 13:30:00	2023-06-16 15:30:00	Commémoration hommage au Général de Gaulle - Bayeux
21328	14133K	REU_TRAV_PARL	2023-06-19 10:00:00	2023-06-19 11:00:00	rdv individuels permanence parlementaire
21329	14133K	ORG_POL	2023-06-19 12:45:00	2023-06-19 14:00:00	déjeuner de travail LR 14
21330	14133K	CEREMONIE	2023-06-19 15:00:00	2023-06-19 16:00:00	Remise des Prix - Concours des Cidres de Normandie - Feuguerolles-Bully
21333	14133K	ELUS_LOCAUX	2023-06-23 14:30:00	2023-06-23 16:30:00	Conférence des parlementaires - UAMC CAEN
21334	14133K	ELUS_LOCAUX	2023-06-26 10:00:00	2023-06-26 11:30:00	Commission départementale DETR - CAEN
21336	14133K	REU_TRAV_PARL	2023-06-26 15:30:00	2023-06-26 16:30:00	rdv individuels permanence parlementaire
21337	14133K	ORG_POL	2023-06-27 08:00:00	2023-06-27 08:50:00	CNI Les Républicains - Paris
21338	14133K	ORG_POL	2023-06-27 11:00:00	2023-06-27 12:30:00	Réunion du Groupe LR Sénat
21339	14133K	ORG_POL	2023-06-27 12:45:00	2023-06-27 13:45:00	Déjeuner de travail LR
21345	14133K	ORG_POL	2023-07-04 08:00:00	2023-07-04 10:00:00	CNI Les Républicains - Paris
21346	14133K	ORG_POL	2023-07-04 11:00:00	2023-07-04 12:30:00	Réunion du Groupe LR Sénat
21347	14133K	REU_TRAV_PARL	2023-07-04 13:00:00	2023-07-04 14:30:00	avec groupe d'amitié France-Monaco
21348	14133K	CEREMONIE	2023-07-05 17:00:00	2023-07-05 18:00:00	Cérémonie Prise d'Armes d'Eté - Les Invalides
21349	14133K	DEPL_PRES_GVT	2023-07-06 09:30:00	2023-07-06 13:00:00	Visite Première Ministre à Lisieux
21350	14133K	REU_TRAV_PARL	2023-07-06 16:00:00	2023-07-06 18:00:00	rdv individuels permanence parlementaire
21351	14133K	DEPL_PRES_GVT	2023-07-07 12:00:00	2023-07-07 13:00:00	Hommage national à Léon Gautier - Ouistreham
21041	14133K	REU_TRAV_PARL	2023-01-27 14:30:00	2023-01-27 16:30:00	Conférence rapports parlementaires sur la Chine devant l'ANMONM
21052	14133K	REU_TRAV_PARL	2023-01-03 10:00:00	2023-01-03 11:30:00	rdv individuels permanence parlementaire
21053	14133K	REU_TRAV_PARL	2023-01-03 14:30:00	2023-01-03 16:30:00	rdv individuels permanence parlementaire
21078	14133K	COLL_TER	2022-11-14 10:00:00	2022-11-14 11:30:00	Dispositif pêche - Région Normandie - Port-en-Bessin
21079	14133K	ELUS_LOCAUX	2022-11-14 14:30:00	2022-11-14 16:00:00	Commission départementale DETR - Préfecture de Caen
21080	14133K	CEREMONIE	2022-11-11 10:45:00	2022-11-11 11:30:00	Commémoration armistice 1918 - Calvados
21107	14133K	REU_TRAV_PARL	2023-05-22 10:30:00	2023-05-22 12:00:00	Rendez-vous sociaux et économiques permanence parlementaire dans le Calvados
21108	14133K	ORG_POL	2023-05-23 11:00:00	2023-05-23 12:30:00	Réunion du Groupe LR Sénat
21109	14133K	ORG_POL	2023-05-23 17:00:00	2023-05-23 18:00:00	Réunion de travail LPM - Groupe LR
21110	14133K	COLL_TER	2023-05-25 10:30:00	2023-05-25 16:30:00	Visites filière équine - Pays d'Auge - Calvados
21111	14133K	ELUS_LOCAUX	2023-05-25 12:30:00	2023-05-25 14:00:00	déjeuner de travail élus Commune de Vauville (14)
21112	14133K	REU_TRAV_PARL	2023-05-25 19:30:00	2023-05-25 22:30:00	Conférence rapports parlementaires sur la Chine - CAEN
21113	14133K	REU_TRAV_PARL	2023-05-26 11:00:00	2023-05-26 15:00:00	Réunion et déjeuner de travail - filière culturelle
21114	14133K	ORG_POL	2023-05-30 11:00:00	2023-05-30 12:30:00	Réunion du Groupe LR Sénat
21115	14133K	ACC_VISIT	2023-05-30 12:00:00	2023-05-30 12:45:00	accueil collège Vire-Normandie
21116	14133K	REU_TRAV_PARL	2023-06-01 08:00:00	2023-06-01 18:00:00	Déplacement Industrie défense - Allemagne
21117	14133K	REU_TRAV_PARL	2023-06-02 08:00:00	2023-06-02 18:00:00	Déplacement Industrie défense - Allemagne - suite
21118	14133K	CEREMONIE	2023-06-05 14:30:00	2023-06-05 16:30:00	Commémoration 79e anniversaire Débarquement - La Cambe (Calvados)
21119	14133K	CEREMONIE	2023-06-05 18:00:00	2023-06-05 19:30:00	Commémoration 79e anniversaire Débarquement - Hermanville-sur-Mer ( Calvados)(Calvados)
21120	14133K	ORG_POL	2023-06-06 11:00:00	2023-06-06 12:30:00	Réunion du Groupe LR Sénat
21352	14133K	CEREMONIE	2023-07-07 15:30:00	2023-07-07 17:00:00	Inhumation de M. Léon Gautier - commando Kieffer - Ouistreham
21360	04043D	ORG_POL	2023-07-04 08:00:00	2023-07-04 10:00:00	Commission nationale d'investiture - Les Républicains
21357	04043D	ORGEXTPAR	2023-07-06 09:00:00	2023-07-06 12:00:00	40 ans - OPECST
21358	04043D	REU_TRAV_PARL	2023-07-06 15:00:00	2023-07-06 18:00:00	Colloque Ambassade des Etats-Unis - NBT
21359	04043D	ORGEXTPAR	2023-07-05 15:00:00	2023-07-05 18:00:00	40 ans OPECST - Assemblée nationale
21361	04043D	REU_TRAV_PARL	2023-07-04 17:00:00	2023-07-04 18:00:00	Réunion Conseiller Océanie Elysée - Iles-du-Pacifique
21362	04043D	ORGEXTPAR	2023-06-22 09:30:00	2023-06-22 13:00:00	Salon international de l'aéronautique et de l'espace - Le Bourget
21363	04043D	ORG_POL	2023-06-20 18:30:00	2023-06-20 20:00:00	Commission nationale d'investiture - Les Républicains
21364	04043D	ACC_VISIT	2023-05-24 09:40:00	2023-05-24 11:30:00	Visite du Sénat - CMJ Le Perreux-sur-Marne
21365	04043D	REU_GVT	2023-04-03 14:30:00	2023-04-03 15:30:00	Réunion ministre des Outre-Mer - Chlordécone
21366	04042C	ELUS_LOCAUX	2023-07-06 08:30:00	2023-07-06 09:30:00	Réunion avec des élus du Val-de-Marne
21367	04042C	ELUS_LOCAUX	2023-07-06 13:00:00	2023-07-06 14:30:00	Rencontre avec des élus du Val-de-Marne
21368	04042C	ACC_DEPL_INTER	2023-07-06 18:00:00	2023-07-06 20:00:00	Rencontre avec l'Ambassadrice britannique à l'occasion du 75ème anniversaire de Sa Majesté le Roi Charles III
21369	04042C	ACC_DEPL_INTER	2023-07-10 20:00:00	2023-07-10 21:30:00	Rencontre avec l'Ambassadeur d'Allemagne en France à l'occasion de sa fin de mission en France
21370	04042C	ACC_DEPL_INTER	2023-07-11 11:00:00	2023-07-11 13:30:00	Réunion de travail avec le Président du Sénat et le Président de l'Assemblée nationale de la République d'Arménie
21371	04042C	ACC_VISIT	2023-07-11 14:30:00	2023-07-11 14:45:00	Interview téléphonique MEDI1TV
21372	04042C	REU_TRAV_PARL	2023-07-11 18:00:00	2023-07-11 19:00:00	Conférence des Présidents
21373	04042C	ACC_VISIT	2023-07-11 20:00:00	2023-07-11 22:00:00	Rencontre avec des élus du Val-de-Marne
21374	04042C	ACC_DEPL_INTER	2023-07-12 19:30:00	2023-07-12 21:30:00	Rencontre avec l'Ambassadrice de la république d'Arménie en France à l'occasion de la visite du Président de l'Assemblée nationale de la République d'Arménie
21375	04042C	REU_TRAV_PARL	2023-07-13 09:30:00	2023-07-13 10:30:00	entretien avec le Président du Sénat
21404	04042C	ACC_DEPL_INTER	2023-07-21 12:30:00	2023-07-21 14:00:00	Rencontre avec l'Ambassadeur de Belgique en France à l'occasion de la Fête nationale
21405	04042C	CEREMONIE	2023-07-21 16:30:00	2023-07-21 17:30:00	Cérémonie de remise des diplômes des Directeurs de cabinet 
21441	04042C	ACC_DEPL_INTER	2023-08-30 12:30:00	2023-08-30 14:30:00	Rencontre avec l'Ambassadeur de Turquie en France à l'occasion de la Fête de la Victoire
21442	04042C	DEPL_PRES_GVT	2023-08-31 06:15:00	2023-08-31 16:20:00	Cérémonie militaire présidée par le Ministre des Armées à Toulon
21443	04042C	CEREMONIE	2023-09-04 19:00:00	2023-09-04 20:00:00	Cérémonie à l'occasion de la visite du Maire d'Akko en Israël
21444	04042C	REU_TRAV_PARL	2023-09-07 11:00:00	2023-09-07 12:00:00	Remise du 17ème rapport du HCECM
21445	04042C	COLL_TER	2023-09-07 08:15:00	2023-09-07 10:00:00	Réunion de travail avec le Syndicat des Eaux d'Ile-de-France
21446	04042C	ELUS_LOCAUX	2023-09-11 10:30:00	2023-09-11 12:30:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
21463	11066Q	ACC_VISIT	2023-07-06 14:00:00	2023-07-06 17:00:00	Accueil Permanence
21464	11066Q	ACC_VISIT	2023-07-07 09:00:00	2023-07-07 10:00:00	Accueil Permanence
21465	11066Q	COLL_TER	2023-07-07 10:00:00	2023-07-07 11:00:00	Entretien téléphonique avec SPF à propos de l'étude de zone sur l'agglomération de Saint-Nazaire
21466	11066Q	ACC_VISIT	2023-07-07 11:00:00	2023-07-07 12:30:00	Accueil Permanence
21467	11066Q	ACC_VISIT	2023-07-07 14:00:00	2023-07-07 17:00:00	Accueil Permanence
21468	11066Q	REU_TRAV_PARL	2023-07-10 09:00:00	2023-07-10 10:00:00	Réunion du Groupe socialiste de la Commission des affaires étrangères sur le projet de loi LPM
21471	11066Q	ACC_VISIT	2023-07-13 09:00:00	2023-07-13 12:30:00	Accueil Permanence
21472	11066Q	ACC_VISIT	2023-07-13 14:00:00	2023-07-13 17:00:00	Accueil Permanence
21473	11066Q	ACC_VISIT	2023-07-17 09:00:00	2023-07-17 12:30:00	Accueil Permanence
21474	11066Q	ACC_VISIT	2023-07-17 14:00:00	2023-07-17 17:30:00	Accueil Permanence
21481	04042C	ACC_DEPL_INTER	2023-09-12 12:00:00	2023-09-12 13:30:00	rencontre avec l'Ambassadeur de Pologne en France à l'occasion de la Fête des Forces armées polonaises
21482	04042C	COLL_TER	2023-09-15 08:45:00	2023-09-15 10:30:00	Réunion du bureau du Syndicat des Eaux d'Ile-de-France
21483	04042C	CEREMONIE	2023-09-15 11:00:00	2023-09-15 14:30:00	Visite du domaine d'ormesson-sur-Marne à l'occasion des arts décoratifs du Japon Ancien
21484	04042C	ELUS_LOCAUX	2023-09-18 11:00:00	2023-09-18 12:00:00	Rendez-vous Urbanisme à la Mairie de Saint-Maurice
21485	04042C	CEREMONIE	2023-09-20 14:00:00	2023-09-20 15:00:00	Cérémonie à l'Arc de Triomphe à l'occasion de la visite officielle du Roi Charles III
21486	04042C	DEPL_PRES_GVT	2023-09-20 19:30:00	2023-09-20 23:00:00	visite officielle du Roi Charles III
21487	04042C	CEREMONIE	2023-09-21 10:40:00	2023-09-21 11:30:00	Allocution de sa Majesté le Roi Charles III, Roi du Royaume-Uni de Grande Bretagne et d'Irlande du Nord au Sénat
21488	04042C	ORG_POL	2023-09-27 10:30:00	2023-09-27 12:30:00	Réunion de groupe des Sénateurs Les Républicains
21489	04042C	ORG_POL	2023-09-27 13:00:00	2023-09-27 14:30:00	Rencontre avec les Sénateurs Les Républicains
21490	04042C	ELUS_LOCAUX	2023-09-28 20:30:00	2023-09-28 22:30:00	Conseil municipal de Saint-Maurice
21501	14133K	REU_TRAV_PARL	2023-08-17 14:30:00	2023-08-17 15:30:00	Rdv acteurs institutionnels - Calvados
21502	14133K	CEREMONIE	2023-08-17 17:30:00	2023-08-17 18:30:00	Commémoration Libération Bataille de Normandie - Condé-sur-Noireau
21503	14133K	CEREMONIE	2023-08-21 11:00:00	2023-08-21 12:30:00	Prise de fonction du nouveau Préfet du Calvados - CAEN
21504	14133K	REU_TRAV_PARL	2023-08-21 14:30:00	2023-08-21 15:30:00	Rdv acteurs institutionnels - Calvados
21505	14133K	CEREMONIE	2023-08-21 17:00:00	2023-08-21 17:45:00	cérémonie commémorative Libération de DOZULE
21506	14133K	CEREMONIE	2023-08-21 19:00:00	2023-08-21 20:30:00	cérémonie commémorative Libération - HOULGATE
21021	04042C	ORG_POL	2023-05-30 11:00:00	2023-05-30 12:30:00	Réunion de Groupe des sénateurs LR du Sénat
21022	04042C	ACC_VISIT	2023-05-30 19:00:00	2023-05-30 21:00:00	Réunion avec des élus du Val-de-Marne
21023	04042C	REU_TRAV_PARL	2023-05-31 13:10:00	2023-05-31 14:15:00	Rencontre avec les Présidents de Commission, le Rapporteur général et référents de Commission
21024	04042C	ACC_VISIT	2023-06-01 11:00:00	2023-06-01 14:00:00	Rancontre avec des Majors de la Gendarmerie à Maisons-Alfort
21186	14133K	REU_TRAV_PARL	2023-06-08 10:00:00	2023-06-08 15:00:00	Déplacement Industrie Défense
21187	14133K	ELUS_LOCAUX	2023-06-09 10:00:00	2023-06-09 11:30:00	Réunion de travail - municipalité de Les Monts-d'Aunay
21188	14133K	REU_TRAV_PARL	2023-06-09 14:30:00	2023-06-09 16:30:00	rdv individuels permanence parlementaire
21332	14133K	ORG_POL	2023-06-20 18:30:00	2023-06-20 20:00:00	CNI Les Républicains - Paris
21190	14133K	REU_TRAV_PARL	2023-06-12 10:00:00	2023-06-12 11:30:00	rdv individuels permanence parlementaire
21191	14133K	REU_TRAV_PARL	2023-06-12 16:00:00	2023-06-12 17:00:00	rdv individuels permanence parlementaire
21192	14133K	CEREMONIE	2023-06-12 18:30:00	2023-06-12 19:30:00	79e anniversaire bombardements de 1944 - Aunay-sur-Odon
21282	11066Q	CEREMONIE	2023-06-22 17:50:00	2023-06-22 19:00:00	Cérémonie de mise à l'honneur des élèves méritants du Collège Pierre Norange
21283	11066Q	ACC_VISIT	2023-06-23 09:00:00	2023-06-23 12:30:00	Accueil Permanence
21284	11066Q	ACC_VISIT	2023-06-23 14:00:00	2023-06-23 17:00:00	Accueil Permanence
21285	11066Q	ACC_VISIT	2023-06-26 09:00:00	2023-06-26 11:30:00	Accueil Permanence
21286	11066Q	REU_TRAV_PARL	2023-06-26 11:30:00	2023-06-26 12:30:00	Réunion du Groupe socialiste de la Commission des affaires étrangères
21287	11066Q	ACC_VISIT	2023-06-26 14:00:00	2023-06-26 17:00:00	Accueil Permanence
21288	11066Q	REU_TRAV_PARL	2023-06-27 11:10:00	2023-06-27 12:00:00	Réunion de groupe
21289	11066Q	ACC_VISIT	2023-06-30 14:00:00	2023-06-30 17:00:00	Accueil Permanence
21331	14133K	ORG_POL	2023-06-20 11:00:00	2023-06-20 12:30:00	Réunion du Groupe LR Sénat
21340	14133K	ACC_VISIT	2023-06-28 11:30:00	2023-06-28 12:30:00	Rencontre et échanges avec délégation IHEDN AR3 au Sénat
21341	14133K	REU_TRAV_PARL	2023-06-29 10:00:00	2023-06-29 12:30:00	Réunion de travail - ajustements LPM
21342	14133K	REU_TRAV_PARL	2023-06-30 15:00:00	2023-06-30 16:00:00	rdv individuels permanence parlementaire
21343	14133K	CEREMONIE	2023-07-03 12:00:00	2023-07-03 12:30:00	Temps de soutien AMF - Cérémonie à VIRE
21344	14133K	ELUS_LOCAUX	2023-07-03 15:30:00	2023-07-03 16:00:00	RDV téléphoniques maires du Calvados
21353	14133K	ORG_POL	2023-07-11 08:30:00	2023-07-11 10:30:00	CNI Les Républicains - Paris
21354	14133K	ORG_POL	2023-07-11 11:00:00	2023-07-11 12:30:00	Réunion du Groupe LR Sénat
21355	14133K	ACC_DEPL_INTER	2023-07-11 13:00:00	2023-07-11 14:30:00	Déjeuner de Travail Ambassade du Canada - Relation commerciale France-Canada
21421	04042C	ACC_DEPL_INTER	2022-09-01 11:00:00	2022-09-01 13:00:00	Discours du Président de la République à la Conférence des Ambassadrices et des Ambassadeurs 2022
21508	14133K	CEREMONIE	2023-08-22 11:00:00	2023-08-22 12:00:00	  cérémonie commémorative Libération - VILLERS SUR MER
21426	04042C	ACC_DEPL_INTER	2023-08-28 10:15:00	2023-08-28 12:00:00	Discours du Président de la République à la Conférence des Ambassadrices et des Ambassadeurs 2023
21424	04042C	ACC_DEPL_INTER	2023-08-29 11:00:00	2023-08-29 11:45:00	Entretien avec l'Attaché de défense de l'Ambassade d'Allemagne en France
21425	04042C	ACC_DEPL_INTER	2023-08-29 09:00:00	2023-08-29 10:30:00	Allocution de la Ministre de l'Europe et des Affaires étrangères à la Conférence des Ambassadrices et des Ambassadeurs 2023
21428	04042C	ACC_DEPL_INTER	2023-08-29 11:45:00	2023-08-29 12:45:00	Entretien avec l'Ambassadrice de Serbie en France
21507	14133K	CEREMONIE	2023-08-22 09:30:00	2023-08-22 10:15:00	  cérémonie commémorative Libération - AUBERVILLE  
21509	14133K	ELUS_LOCAUX	2023-08-22 12:30:00	2023-08-22 14:00:00	déjeuner de travail élus de la Côte fleurie
21510	14133K	CEREMONIE	2023-08-22 15:00:00	2023-08-22 17:00:00	  cérémonie commémorative Libération - DEAUVILLE  
21511	14133K	ELUS_LOCAUX	2023-08-22 00:00:00	2023-08-22 00:00:00	réunion de travail élus régionaux - Pays d'Auge
21515	14133K	CEREMONIE	2023-08-23 10:30:00	2023-08-23 11:15:00	cérémonie commémorative Libération - BLONVILLE SUR MER
21516	14133K	CEREMONIE	2023-08-23 11:30:00	2023-08-23 12:15:00	cérémonie commémorative Libération - BENERVILLE SUR MER
21514	14133K	CEREMONIE	2023-08-23 09:30:00	2023-08-23 10:15:00	cérémonie commémorative Libération - TOURGEVILLE
21517	14133K	ELUS_LOCAUX	2023-08-23 12:45:00	2023-08-23 14:15:00	déjeuner de travail élus Côte Fleurie
21518	14133K	CEREMONIE	2023-08-23 15:30:00	2023-08-23 16:15:00	cérémonie commémorative Libération - CORDEBUGLE
21519	14133K	CEREMONIE	2023-08-23 16:30:00	2023-08-23 17:30:00	cérémonie commémorative Libération - COURTONNE LES DEUX EGLISES
21520	14133K	CEREMONIE	2023-08-23 18:15:00	2023-08-23 18:45:00	cérémonie commémorative Libération - SAINT DESIR DE LISIEUX
21521	14133K	CEREMONIE	2023-08-23 19:00:00	2023-08-23 20:30:00	cérémonies commémoratives Libération - LISIEUX
21522	14133K	CEREMONIE	2023-08-24 10:00:00	2023-08-24 11:00:00	cérémonie commémorative Libération - TROUVILLE SUR MER
21523	14133K	CEREMONIE	2023-08-24 11:15:00	2023-08-24 12:00:00	cérémonie commémorative Libération - SAINT ARNOULT-TOUQUES
21524	14133K	ELUS_LOCAUX	2023-08-24 12:45:00	2023-08-24 14:30:00	Déjeuner de travail avec élus Pays d'Auge
21525	14133K	CEREMONIE	2023-08-24 15:00:00	2023-08-24 16:30:00	cérémonie commémorative Libération - PONT L'EVEQUE
21526	14133K	REU_TRAV_PARL	2023-08-29 17:45:00	2023-08-29 19:00:00	Rdv acteurs institutionnels - Calvados
21527	14133K	CEREMONIE	2023-08-31 06:00:00	2023-08-31 17:30:00	Cérémonie passation de fonction CEM Marine - TOULON
21528	14133K	REU_TRAV_PARL	2023-09-01 10:00:00	2023-09-01 11:00:00	Rdv acteurs économiques - Permanence parlementaire 14
21529	14133K	CEREMONIE	2023-09-05 16:00:00	2023-09-05 17:30:00	Hommage au Sergent Nicolas Mazier - Base aérienne 123 Orléans
21530	14133K	CEREMONIE	2023-09-06 17:30:00	2023-09-06 18:30:00	Prise d¿armes donnée à l¿occasion de l'adieu aux armes du général d'armée aérienne Eric AUTELLET, major général des Armées 
21531	14133K	ELUS_LOCAUX	2023-09-07 12:00:00	2023-09-07 14:30:00	Déjeuner de travail élus régionaux
21532	14133K	REU_TRAV_PARL	2023-09-07 14:45:00	2023-09-07 16:00:00	Rdv acteurs économiques - Croissanville - filière équine
21533	14133K	REU_TRAV_PARL	2023-09-08 12:30:00	2023-09-08 14:30:00	Déjeuner de travail - élus de la Côte Fleurie
21534	14133K	COLL_TER	2023-09-08 17:30:00	2023-09-08 19:00:00	Vernissage exposition de peinture - VIRE NORMANDIE
21535	14133K	REU_TRAV_PARL	2023-09-11 10:00:00	2023-09-11 10:45:00	Visite suite rentrée scolaire - Collège public 14110
21536	14133K	REU_TRAV_PARL	2023-09-11 11:00:00	2023-09-11 11:45:00	Visite suite rentrée scolaire - Lycée GTP 14110
21537	14133K	REU_TRAV_PARL	2023-09-11 14:30:00	2023-09-11 16:30:00	rdv individuels permanence parlementaire
21538	14133K	ELUS_LOCAUX	2023-09-12 14:30:00	2023-09-12 16:00:00	RDV Maire d'Ellon - mairie d'Ellon
21539	14133K	REU_TRAV_PARL	2023-09-13 19:00:00	2023-09-13 20:30:00	Réunion de travail préparatoire à la visite ALFUSCO LORIENT
21540	14133K	REU_TRAV_PARL	2023-09-14 08:00:00	2023-09-14 16:30:00	Défense - Marine nationale - visite ALFUSCO LORIENT
21541	14133K	REU_TRAV_PARL	2023-09-15 15:00:00	2023-09-15 16:00:00	Rdv acteurs institutionnels - Calvados
21542	14133K	REU_TRAV_PARL	2023-09-15 16:15:00	2023-09-15 17:00:00	Rdv rentrée scolaire - école et collège privés 14110
21543	14133K	REU_TRAV_PARL	2023-09-18 16:00:00	2023-09-18 19:00:00	Réunion Amicale des maires du Calvados - ZAN - CABOURG
21544	14133K	REU_TRAV_PARL	2023-09-18 20:00:00	2023-09-18 22:00:00	Dîner de travail Amicale des Maires - Sénateurs
21545	14133K	REU_TRAV_PARL	2023-09-19 15:30:00	2023-09-19 17:30:00	Groupe de travail interne "sécurité civile"
21546	14133K	REU_TRAV_PARL	2023-09-19 18:15:00	2023-09-19 19:30:00	PUBLIC SENAT - participation à l'émission Sens Public - Chine
21547	14133K	REU_TRAV_PARL	2023-09-20 08:30:00	2023-09-20 12:30:00	VISITE DRM CREIL
21548	14133K	CEREMONIE	2023-09-21 10:00:00	2023-09-21 12:30:00	Accueil du Roi Charles III au Sénat
21549	14133K	REU_TRAV_PARL	2023-09-22 10:30:00	2023-09-22 11:45:00	rdv presse départementale - affaires étrangères et défense
21550	14133K	REU_TRAV_PARL	2023-09-22 00:00:00	2023-09-22 00:00:00	Visite STARNAV - Bretteville-sur-Odon
21001	11066Q	ACC_VISIT	2023-05-25 08:00:00	2023-05-25 12:30:00	Accueil Permanence
21002	11066Q	ACC_VISIT	2023-05-25 14:00:00	2023-05-25 17:00:00	Accueil Permanence
21006	11066Q	ORGEXTPAR	2023-06-01 09:00:00	2023-06-01 11:30:00	Réunion Plénière de la Commission nationale des Techniques de Renseignement
21004	11066Q	ACC_VISIT	2023-05-26 09:00:00	2023-05-26 12:30:00	Accueil Permanence
21005	11066Q	ACC_VISIT	2023-05-26 14:00:00	2023-05-26 17:00:00	Accueil Permanence
21202	11066Q	REU_TRAV_PARL	2023-06-14 16:30:00	2023-06-14 18:00:00	Réunion du Groupe socialiste de la Commission des affaires étrangères
21203	11066Q	ACC_VISIT	2023-06-15 09:00:00	2023-06-15 12:30:00	Accueil Permanence
21204	11066Q	ACC_VISIT	2023-06-15 14:00:00	2023-06-15 17:00:00	Accueil Permanence
21209	11066Q	ACC_VISIT	2023-06-19 14:00:00	2023-06-19 17:00:00	Accueil Permanence
21206	11066Q	ACC_VISIT	2023-06-16 14:00:00	2023-06-16 17:00:00	Accueil Permanence
21207	11066Q	ACC_VISIT	2023-06-16 09:00:00	2023-06-16 12:30:00	Accueil Permanence
21208	11066Q	ACC_VISIT	2023-06-19 09:00:00	2023-06-19 12:30:00	Accueil Permanence
21221	04042C	ACC_DEPL_INTER	2023-06-08 18:30:00	2023-06-08 19:30:00	Rencontre avec l'Ambassadeur du Portugal en France à l'occasion de la Fête nationale
21225	04042C	REU_TRAV_PARL	2023-06-14 08:00:00	2023-06-14 09:00:00	Réunion mission d'information sur l'avenir du Maire et de la commune de France
21223	04042C	REU_TRAV_PARL	2023-06-13 13:00:00	2023-06-13 14:00:00	Rencontre avec un sénateur
21224	04042C	ACC_DEPL_INTER	2023-06-13 17:45:00	2023-06-13 20:00:00	Rencontre dans le cadre de la série Ambassadeurs d'Asia Society France
21226	04042C	REU_TRAV_PARL	2023-06-14 18:00:00	2023-06-14 19:00:00	Conférence des Présidents
21227	04042C	ACC_DEPL_INTER	2023-06-14 19:30:00	2023-06-14 20:30:00	Rencontre avec le représentant de Taïwan en France à l'occasion de la venue de la Ministre des Affaires économiques de Taïwan
21228	04042C	ACC_DEPL_INTER	2023-06-15 09:00:00	2023-06-15 14:30:00	 Matinée d'échanges avec des parlementaires baltes, du groupe de Visegrad, de Finlande, Roumanie et Bulgarie
21232	04042C	ACC_DEPL_INTER	2023-06-19 15:00:00	2023-06-19 16:00:00	Entretien avec le Ministre de la Défense d'Arménie 
21230	04042C	REU_TRAV_PARL	2023-06-16 14:30:00	2023-06-16 15:30:00	Table ronde Paris Air Forum 2023
21234	04042C	REU_TRAV_PARL	2023-06-19 13:00:00	2023-06-19 14:00:00	Rencontre avec un député
21233	04042C	CEREMONIE	2023-06-19 20:30:00	2023-06-19 21:30:00	Rencontre avec le Président de la République et le Ministre des Armées à l'occasion de la 54ème édition du Salon International du Bourget 2023
21235	04042C	ORG_POL	2023-06-20 11:00:00	2023-06-20 12:30:00	Réunion de Groupe des sénateurs LR du Sénat
21236	04042C	REU_TRAV_PARL	2023-06-20 12:30:00	2023-06-20 14:00:00	Rencontre avec des sénateurs
21237	04042C	REU_GVT	2023-06-20 16:00:00	2023-06-20 17:00:00	Entretien avec le Ministre des Armées
21238	04042C	ACC_DEPL_INTER	2023-06-20 18:30:00	2023-06-20 19:15:00	Rencontre avec l'Ambassadeur de Suède en France à l'occasion de la clôture de la présidence suédoise de l'UE et de la Fête nationale
21242	04042C	ACC_VISIT	2023-06-07 17:30:00	2023-06-07 18:30:00	Entretien avec une journaliste du Wall Street Journal
21251	04042C	CEREMONIE	2023-06-20 20:30:00	2023-06-20 21:30:00	Rencontre avec le Président-directeur général de Thales à l'occasion du Salon International de l'aéronautique et de l'Espace
21241	04042C	REU_TRAV_PARL	2023-06-21 13:00:00	2023-06-21 14:00:00	Rencontre avec les Présidents de Commission, le Rapporteur général et référents de Commission
21243	04042C	CEREMONIE	2023-06-07 19:00:00	2023-06-07 20:00:00	Soirée annuelle des journalistes de Défense
21244	04042C	ACC_VISIT	2023-06-21 17:30:00	2023-06-21 18:30:00	Entretien avec une journaliste du Wall Street Journal
21248	04042C	ACC_DEPL_INTER	2023-06-15 18:30:00	2023-06-15 19:30:00	Rencontre avec le Président de MBDA à l'occasion du Salon International de l'aéronautique et de l'Espace
21249	04042C	ACC_DEPL_INTER	2023-06-15 20:00:00	2023-06-15 21:30:00	Rencontre avec le Président-directeur général du Groupe ADP à l'occasion de la 10ème édition de Paris Air Forum
21247	04042C	ACC_DEPL_INTER	2023-06-21 19:00:00	2023-06-21 21:00:00	Soirée annuelle des journalistes de Défense
21250	04042C	CEREMONIE	2023-06-20 19:30:00	2023-06-20 20:15:00	Rencontre avec le Ministre des Armées à l'occasion de la 54ème édition du Salon International de l'Aéronautique et de l'Espace
21551	14133K	REU_TRAV_PARL	2023-09-25 15:00:00	2023-09-25 16:00:00	Rdv acteurs institutionnels - Calvados
21552	14133K	COLL_TER	2023-09-25 16:15:00	2023-09-25 17:45:00	Pose première pierre - gendarmerie de Condé-en-Normandie
21553	14133K	REU_TRAV_PARL	2023-09-26 10:00:00	2023-09-26 12:00:00	rdv individuels permanence parlementaire
21554	14133K	ORG_POL	2023-09-27 10:30:00	2023-09-27 12:30:00	Réunion du Groupe LR Sénat
21555	14133K	ORG_POL	2023-09-27 16:30:00	2023-09-27 18:00:00	Réunion du Groupe LR Sénat
21556	14133K	REU_TRAV_PARL	2023-10-03 10:30:00	2023-10-03 12:30:00	Réunion du Groupe LR Sénat
21557	14133K	REU_TRAV_PARL	2023-10-03 14:30:00	2023-10-03 16:30:00	Réunion du Groupe LR Sénat
21561	04042C	ORG_POL	2023-10-10 10:30:00	2023-10-10 12:30:00	Réunion de groupe des Sénateurs Les Républicains
21562	04042C	COLL_TER	2023-10-10 16:30:00	2023-10-10 17:30:00	Réunion de travail avec le Préfet de la Région d'Ile-de-France
21563	04042C	REU_TRAV_PARL	2023-10-10 17:30:00	2023-10-10 18:30:00	Réunion avec les commissaires les Républicains de la Commission des Affaires étrangères, de la Défense et des Forces armées
21564	04042C	ORG_POL	2023-10-03 10:30:00	2023-10-03 12:30:00	Réunion de groupe des Sénateurs Les Républicains
21565	04042C	ORG_POL	2023-10-03 13:00:00	2023-10-03 14:00:00	Rencontre avec les sénateurs les Républicain
21566	04042C	ORG_POL	2023-10-03 14:30:00	2023-10-03 16:00:00	Réunion de groupe des Sénateurs Les Républicains 
21567	04042C	CEREMONIE	2023-10-04 11:00:00	2023-10-04 12:30:00	Cérémonie de célébration à l'occasion du 65ème anniversaire de la Constitution
21581	04042C	COLLOQUE	2023-10-11 11:30:00	2023-10-11 14:30:00	Intervention au Colloque Maroc-Europe à l'Institut du Monde arabe
21582	04042C	ACC_DEPL_INTER	2023-10-11 19:30:00	2023-10-11 22:00:00	Rencontre avec l'Ambassadrice d'Italie en France
21586	04042C	COLL_TER	2023-10-13 08:45:00	2023-10-13 11:30:00	Réunion du bureau du Syndicat des Eaux d'Ile-de-France
21584	04042C	CEREMONIE	2023-10-12 20:30:00	2023-10-12 23:00:00	Dîner officiel d'Etat du Président de la République à l'occasion de la visite du Président de la Mongolie
21585	04042C	COLL_TER	2023-10-12 14:30:00	2023-10-12 17:30:00	Conseil de la Métropole du Grand Paris
21587	04042C	CEREMONIE	2023-10-17 09:30:00	2023-10-17 10:30:00	Inauguration de la résidence d'hébergement d'urgence à Valenton
21591	04042C	ELUS_LOCAUX	2023-10-18 19:00:00	2023-10-18 21:00:00	Conseil de Territoire
21589	04042C	ACC_DEPL_INTER	2023-10-17 19:00:00	2023-10-17 19:30:00	Rencontre avec l' Ambassadeur de Géorgie en France à l'occasion du 30e anniversaire du rétablissement mission diplomatique en France 
21590	04042C	CEREMONIE	2023-10-17 20:15:00	2023-10-17 22:30:00	Dîner républicain annuel CCJ94 en présence du Ministre de l'Intérieur et des Outre-Mer
21592	04042C	REU_TRAV_PARL	2023-10-23 15:00:00	2023-10-23 16:00:00	Rencontre avec l'Association des anciens commissaires de la Marine
21593	04042C	ACC_DEPL_INTER	2023-10-23 19:00:00	2023-10-23 21:00:00	Rencontre avec L'Ambassadrice d'Italie en France à l'occasion de la remise de la décoration de Chevalier de l¿Ordre du Mérite de la République Italienne d'un sénateur
21594	04042C	COLL_TER	2023-10-25 20:00:00	2023-10-25 22:00:00	Réunion de travail avec la Présidente de la Région d'Ile-de-France
21601	04042C	ORG_POL	2023-10-31 10:30:00	2023-10-31 12:00:00	Réunion de groupe des Sénateurs Les Républicains
21602	04042C	REU_TRAV_PARL	2023-10-31 12:00:00	2023-10-31 13:00:00	Entretien avec le Président du Sénat
21621	04042C	ACC_VISIT	2023-11-06 11:00:00	2023-11-06 12:00:00	Echange avec des élèves de Terminale de Joinville-le-Pont
21622	04042C	ORG_POL	2023-11-07 10:30:00	2023-11-07 12:30:00	Réunion de groupe des Sénateurs Les Républicains
21623	04042C	REU_TRAV_PARL	2023-11-08 08:30:00	2023-11-08 09:30:00	Réunion avec les commissaires les Républicains de la Commission des Affaires étrangères, de la Défense et des Forces armées
21624	04042C	ACC_DEPL_INTER	2023-11-09 11:15:00	2023-11-09 12:15:00	Entretien avec la Présidente de Bosnie-Herzégovine
21641	21064G	REU_TRAV_PARL	2023-10-31 13:30:00	2023-10-31 14:30:00	RDV Mutualité française
21941	04042C	REU_TRAV_PARL	2024-02-28 12:30:00	2024-02-28 13:45:00	Rencontre avec un Questeur du Sénat
21942	04042C	REU_TRAV_PARL	2024-02-29 11:30:00	2024-02-29 12:30:00	Entretien avec le Président du Sénat
21943	04042C	ACC_VISIT	2024-02-29 13:00:00	2024-02-29 14:15:00	Rencontre avec un élu du Val-de-Marne
21944	04042C	ACC_DEPL_INTER	2024-02-29 19:00:00	2024-02-29 20:00:00	Rencontre avec l'Ambassadeur du Koweït en France
21945	04042C	ACC_DEPL_INTER	2024-03-04 00:00:00	2024-03-04 00:00:00	Rencontre avec l'Ambassadrice de Moldavie en France
21961	04042C	REU_TRAV_PARL	2024-03-04 15:30:00	2024-03-04 19:00:00	Congrès de Versailles
21962	04042C	REU_TRAV_PARL	2024-03-05 13:00:00	2024-03-05 14:30:00	Rencontre avec le Gouverneur militaire de Paris
21963	04042C	ORG_POL	2024-03-05 10:30:00	2024-03-05 12:30:00	Réunion de groupe des sénateurs les Républicains
21964	04042C	ACC_DEPL_INTER	2024-03-05 16:00:00	2024-03-05 17:00:00	Entretien avec le Président du Sénat et l'Ambassadrice du Royaume du Maroc en France
21965	04042C	REU_TRAV_PARL	2024-03-06 08:30:00	2024-03-06 09:30:00	Réunion des Commissiares Les Républicains du Sénat
21966	04042C	ACC_VISIT	2024-03-06 12:30:00	2024-03-06 14:00:00	Rencontre avec un élu du Val-de-Marne
21967	04042C	ELUS_LOCAUX	2024-03-06 18:30:00	2024-03-06 20:00:00	Réunion avec des élus du Val-de-Marne
21968	04042C	ELUS_LOCAUX	2024-03-06 20:30:00	2024-03-06 22:30:00	Conseil Municipal de Saint-Maurice
21969	04042C	REU_GVT	2024-03-07 17:00:00	2024-03-07 18:00:00	Entretien Ministère de la Transition écologique et de la Cohésion des territoires 
21970	04042C	COLL_TER	2024-03-08 08:45:00	2024-03-08 11:00:00	Réunion du bureau du Syndicat des Eaux d'Ile-de-France
21971	04042C	ELUS_LOCAUX	2024-03-11 11:30:00	2024-03-11 12:30:00	Entretien avec un élu du Val-de-Marne
21972	04042C	REU_GVT	2024-03-11 14:00:00	2024-03-11 18:00:00	Assises de la diplomatie parlementaire et de la coopération décentralisée
21973	04042C	ORG_POL	2024-03-12 10:30:00	2024-03-12 12:30:00	Réunion de groupe des sénateurs les Républicains
21974	04042C	ACC_DEPL_INTER	2024-03-12 14:00:00	2024-03-12 14:45:00	Entretien avec le Représentant le Gouvernement régional du Kurdistan d'Irak en France
21975	04042C	ACC_DEPL_INTER	2024-03-12 16:30:00	2024-03-12 17:30:00	Entretien avec l'Ambassadeur du Canada en France
21976	04042C	ORG_POL	2024-03-12 20:00:00	2024-03-12 21:00:00	Inauguration du siège Les Républicains
21977	04042C	ACC_VISIT	2024-03-13 12:00:00	2024-03-13 12:15:00	Interview Public Sénat
21978	04042C	ACC_DEPL_INTER	2024-03-13 13:00:00	2024-03-13 14:15:00	Rencontre avec l'Ambassadrice d'Arménie en France
21979	04042C	ACC_VISIT	2024-03-14 07:30:00	2024-03-14 08:00:00	Emission Public Sénat
21980	04042C	CEREMONIE	2024-03-14 19:00:00	2024-03-14 21:00:00	Cérémonie 25e anniversaire de l'adhésion de la Pologne à l'OTAN
21981	04042C	REU_TRAV_PARL	2024-03-14 11:00:00	2024-03-14 12:00:00	Réunion de travail avec des Sénateurs et des Députés
21982	04042C	ELUS_LOCAUX	2024-03-15 08:15:00	2024-03-15 09:45:00	Réunion avec des élus du Val-de-Marne
21983	04042C	CEREMONIE	2024-03-15 11:00:00	2024-03-15 12:30:00	Visite pastorale de l'Evêque de Créteil dans le Val-de-Marne
21984	04042C	CEREMONIE	2024-03-15 13:00:00	2024-03-15 14:15:00	Inauguration de la Salle Vasco de Gama à Valenton
21985	04042C	CEREMONIE	2024-03-15 19:00:00	2024-03-15 20:30:00	Vernissage du 19ème salon de Bry-sur-Marne
22061	04042C	COLL_TER	2024-04-09 14:30:00	2024-04-09 16:00:00	Conseil de la Métropole du Grand Paris
22062	04042C	ORG_POL	2024-04-09 10:30:00	2024-04-09 12:30:00	Réunion de groupe des sénateurs les Républicains
22063	04042C	ACC_VISIT	2024-04-09 16:30:00	2024-04-09 17:30:00	Entretien avec la Préfète déléguée pour l'égalité des chances du Val-de-Marne
22064	04042C	CEREMONIE	2024-04-09 18:00:00	2024-04-09 20:00:00	Inauguration de l'Académie de santé des armées
22065	04042C	REU_TRAV_PARL	2024-04-10 08:30:00	2024-04-10 09:30:00	AUdition du GIA France-Chypre de l'Envoyé spécial pour les balkans occidentaux
22066	04042C	ACC_VISIT	2024-04-10 11:00:00	2024-04-10 12:00:00	Entretien avec un journaliste de la revue l'Hémicycle
22067	04042C	ACC_VISIT	2024-04-10 13:00:00	2024-04-10 14:15:00	Rencontre avec un élu du Val-de-Marne
22068	04042C	ACC_VISIT	2024-04-11 13:00:00	2024-04-11 14:30:00	Rencontre avec un élu du Val-de-Marne
22069	04042C	REU_TRAV_PARL	2024-04-11 17:30:00	2024-04-11 18:30:00	Réunion de travail avec un Sénateur
22041	21064G	COLLOQUE	2024-03-12 16:00:00	2024-03-12 18:00:00	Plateforme RSE - Directive CSRD
22042	04042C	ACC_VISIT	2024-04-03 13:00:00	2024-04-03 14:15:00	Rencontre avec un élu du Val-de-Marne
22043	04042C	ACC_DEPL_INTER	2024-04-04 13:00:00	2024-04-04 16:00:00	Réunion de travail avec les membres du GIA France-Italie et une délégation italienne
22044	04042C	ACC_DEPL_INTER	2024-04-04 19:30:00	2024-04-04 22:30:00	Rencontre avec l'Ambassadrice britannique en France à l'occasion du 120ème anniversaire de l'Entente Cordiale 
22045	04042C	COLL_TER	2024-04-05 08:45:00	2024-04-05 11:30:00	Réunion du bureau du Syndicat des Eaux d'Ile-de-France
21922	21064G	REU_TRAV_PARL	2024-01-31 12:30:00	2024-01-31 14:30:00	Plénière Délégation aux entreprises - Foncier économique
21926	21064G	COLL_TER	2024-02-08 12:30:00	2024-02-08 14:30:00	réunion de travail Sous-Préfet de Reims
21928	21064G	REU_TRAV_PARL	2024-02-13 09:30:00	2024-02-13 10:30:00	groupe de travail ZAN
21934	21064G	REU_TRAV_PARL	2024-02-27 12:00:00	2024-02-27 18:30:00	déplacement Salon de l'Agriculture
21935	21064G	REU_TRAV_PARL	2024-02-29 10:00:00	2024-02-29 18:30:00	déplacement Salon de l'Agriculture
22001	04042C	ACC_DEPL_INTER	2024-03-18 10:00:00	2024-03-18 11:30:00	Entretien téléphonique avec l'Ambassadeur de Turquie en France
22002	04042C	ELUS_LOCAUX	2024-03-18 19:30:00	2024-03-18 21:30:00	Réunion publique dans le cadre du projet de construction d¿un centre pénitentiaire dans le Val-de-Marne
22003	04042C	REU_TRAV_PARL	2024-03-19 13:00:00	2024-03-19 14:00:00	Entretien avec le Président de la Commission des Affaires étrangères de l'Assemblée nationale
22005	04042C	ELUS_LOCAUX	2024-03-20 13:00:00	2024-03-20 14:15:00	Rencontre avec un élu du Val-de-Marne
21923	21064G	REU_TRAV_PARL	2024-02-01 08:30:00	2024-02-01 11:00:00	inflation normative et pouvoir d'action des élus
21924	21064G	REU_TRAV_PARL	2024-02-06 08:00:00	2024-02-06 13:00:00	séminaire UC
21925	21064G	REU_GVT	2024-02-06 20:00:00	2024-02-06 22:00:00	Ministère du Travail
21927	21064G	COLL_TER	2024-02-08 18:30:00	2024-02-08 20:30:00	mécénat Ville de Reims
21929	21064G	REU_TRAV_PARL	2024-02-14 08:00:00	2024-02-14 09:00:00	Délégation aux entreprises - Parole aux entrepreneurs - Circul'Egg
21930	21064G	REU_TRAV_PARL	2024-02-14 17:30:00	2024-02-14 19:00:00	ppl statut de l'élu
21931	21064G	DEPL_PRES_GVT	2024-02-15 09:00:00	2024-02-15 14:30:00	Visite officielle Premier Ministre à Janvilliers (51)
21932	21064G	REU_TRAV_PARL	2024-02-27 09:30:00	2024-02-27 10:30:00	groupe de travail ZAN
21933	21064G	REU_TRAV_PARL	2024-02-27 10:30:00	2024-02-27 11:00:00	groupe UC
22021	04042C	ELUS_LOCAUX	2024-03-25 19:00:00	2024-03-25 21:00:00	Réunion de travail à la Mairie de Saint-Maurice
22022	04042C	ORG_POL	2024-03-26 10:30:00	2024-03-26 12:30:00	Réunion de groupe des sénateurs les Républicains
22023	04042C	ELUS_LOCAUX	2024-03-26 09:45:00	2024-03-26 10:30:00	Entretien avec des élus du Val-de-Marne
22024	04042C	REU_GVT	2024-03-26 11:30:00	2024-03-26 12:30:00	Conférence de presse du Ministre des Armées
22025	04042C	ELUS_LOCAUX	2024-03-27 11:30:00	2024-03-27 12:30:00	Rencontre avec un élu du Val-de-Marne
22026	04042C	ACC_DEPL_INTER	2024-03-27 16:30:00	2024-03-27 17:30:00	Entretien avec l'Ambassadrice de Serbie en France
22027	04042C	REU_GVT	2024-03-28 10:30:00	2024-03-28 12:00:00	Réunion d'échange au Ministère de l'Europe et des Affaires étrangères
22028	04042C	ACC_DEPL_INTER	2024-03-28 18:00:00	2024-03-28 20:00:00	Rencontre avec l'Ambassadeur du Japon en France à l'occasion du 64ème anniversaire de Sa majesté l'Empereur 
22029	04042C	ORG_POL	2024-04-02 10:30:00	2024-04-02 12:30:00	Réunion de groupe des sénateurs les Républicains
\.


--
-- Data for Name: activites_liees; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY activites_liees (gauche, droite) FROM stdin;
21352	21414
21414	21352
22569	22637
22637	22569
24344	29841
29841	24344
35751	36104
35751	36276
36104	35751
36104	36276
36276	35751
36276	36104
70572	71118
70572	71290
71118	70572
71118	71290
71290	70572
71290	71118
124782	124860
124782	125334
124860	124782
124860	125334
125334	124782
125334	124860
267060	267403
267403	267060
361687	362033
362033	361687
397570	397993
397993	397570
449606	450711
450711	449606
477837	479182
479070	481297
479182	477837
481297	479070
483244	483370
483370	483244
494295	495010
495010	494295
522155	522157
522157	522155
530831	531319
531319	530831
536270	536609
536609	536270
537784	537910
537910	537784
542826	544620
544620	542826
551161	551284
551284	551161
554639	554640
554640	554639
565256	566018
566018	565256
579464	579467
579464	580767
579467	579464
580767	579464
584518	587936
584518	588229
584518	588526
585578	585653
585653	585578
587936	584518
587936	588229
587936	588526
588229	584518
588229	587936
588229	588526
588526	584518
588526	587936
588526	588229
594084	595341
594084	595344
594909	595504
594914	595510
595200	598580
595328	595359
595341	594084
595341	595344
595344	594084
595344	595341
595359	595328
595489	595717
595504	594909
595510	594914
595717	595489
598580	595200
601134	601135
601135	601134
608661	608709
608709	608661
610536	613274
610541	610669
610669	610541
611995	613386
612404	612794
612404	613070
612404	613320
612404	613385
612794	612404
612794	613070
612794	613320
612794	613385
613070	612404
613070	612794
613070	613320
613070	613385
613274	610536
613320	612404
613320	612794
613320	613070
613320	613385
613385	612404
613385	612794
613385	613070
613385	613320
613386	611995
618357	618365
618365	618357
633733	633936
633936	633733
635313	635632
635313	635772
635632	635313
635632	635772
635772	635313
635772	635632
638463	638464
638464	638463
638807	638990
638990	638807
639968	640058
640058	639968
643392	643445
643445	643392
644004	644154
644005	644312
644006	644155
644154	644004
644155	644006
644312	644005
644374	644569
644422	644571
644424	644613
644569	644374
644571	644422
644613	644424
645004	645090
645090	645004
647519	647960
647959	649725
647960	647519
649725	647959
655465	655496
655496	655465
655678	655859
655859	655678
663456	664672
664672	663456
669572	670085
670032	670033
670033	670032
670085	669572
680766	681087
681087	680766
686707	686745
686745	686707
688765	688767
688767	688765
690710	690785
690710	690791
690785	690710
690785	690791
690791	690710
690791	690785
694877	695162
695162	694877
703637	703668
703668	703637
703671	703688
703671	703963
703688	703671
703688	703962
703962	703688
703963	703671
704350	704780
704780	704350
730645	730646
730646	730645
734694	734696
734696	734694
747231	748003
748003	747231
748426	749958
749958	748426
755843	756189
756189	755843
765176	768245
768245	765176
773849	775971
775971	773849
777020	779282
779282	777020
786182	787249
786182	788696
787120	787205
787205	787120
787249	786182
787249	788696
788696	786182
788696	787249
793996	794754
794694	794752
794752	794694
794754	793996
804085	804380
804380	804085
\.


--
-- Data for Name: actpro; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY actpro (actprocod, actprolib, actpronumtri, syscredat, sysmajdat) FROM stdin;
NEANT	NEANT	\N	\N	\N
10	Professions agricoles	10	\N	\N
21	Chefs d'entreprises	21	\N	\N
22	Commercants	22	\N	\N
23	Négociants	23	\N	\N
24	Artisans	24	\N	\N
29	Retraités	29	\N	\N
31	Ingénieurs	31	\N	\N
32	Cadres divers	32	\N	\N
33	Employés	33	\N	\N
34	Ouvriers	34	\N	\N
35	Permanents politiques	35	\N	\N
39	Retraités	39	\N	\N
41	Professeurs	41	\N	\N
42	Médecins	42	\N	\N
43	Chirurgiens	43	\N	\N
44	Pharmaciens	44	\N	\N
45	Dentistes	45	\N	\N
46	Vétérinaires	46	\N	\N
47	Autres professions médicales	47	\N	\N
49	Retraités	49	\N	\N
51	Avocats	51	\N	\N
52	Officiers ministeriels	52	\N	\N
53	Autres  professions  libérales	53	\N	\N
54	Journalistes	54	\N	\N
55	Publicistes	55	\N	\N
56	Magistrats	56	\N	\N
57	Autres professions libérales	57	\N	\N
59	Retraités	59	\N	\N
61	Enseignement supérieur	61	\N	\N
62	Enseignement secondaire	62	\N	\N
63	Enseignement primaire	63	\N	\N
64	Autres  catégories	64	\N	\N
69	Retraités	69	\N	\N
71	Hauts Fonctionnaires	71	\N	\N
72	Cadres moyens	72	\N	\N
73	Autres  catégories	73	\N	\N
74	Militaires	74	\N	\N
79	Retraités	79	\N	\N
80	Sans professions déclarée	80	\N	\N
81	Autres activités professionnelles	81	\N	\N
\.


--
-- Data for Name: adresse; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY adresse (adrid, poiconid, typbistercod, typvoicod, adrcmp, adrcmp2, adrnumvoi, adrnomvoi, adrcom, adrcodpos, adrburdis, adrcdxcod, adrcdxlib, adrnumtri, syscredat, sysmajdat) FROM stdin;
31	830	NEANT	NEANT	\N	\N	Résidence Clémenceau	125, boulevard Aristide Briand	\N	85000	La Roche-sur-Yon	\N	\N	1	2014-10-27 10:51:29	2014-10-27 10:52:22
53	866	NEANT	AUCUN	Immeuble Sébastopol - 12 ème étage	3 Quai Kléber 	\N	\N	Strasbourg 	67000	\N	\N	\N	1	2015-07-01 11:28:26	2018-06-01 16:49:08
62	885	NEANT	RUE	\N	\N	12	rue Georges Clemenceau	Nantes	44000	\N	\N	\N	1	2015-07-17 12:04:40	2015-07-17 12:24:48
80	925	NEANT	NEANT	\N	\N	\N	1, rue du Prieuré	\N	\N	35410 Châteaugiron	\N	\N	1	2016-11-10 11:54:25	2017-09-21 14:34:12
79	923	NEANT	NEANT	\N	\N	\N	14 Place de la Halle	\N	\N	55000 Bar Le Duc	\N	\N	1	2016-07-05 16:30:26	2018-03-30 10:36:12
109	1100	NEANT	AVE	BP 55116	\N	4	de Contades	\N	49051	ANGERS CEDEX	2	\N	1	2017-10-25 10:08:57	2017-10-25 10:11:18
113	1106	NEANT	AUCUN	\N	\N	\N	11 bis rue de Cognac	\N	\N	17490 Beauvais sur Matha	\N	\N	1	2017-11-14 09:23:39	2017-11-14 09:24:10
120	1115	NEANT	AUCUN	\N	\N	\N	21 rue le Déan	\N	\N	29000 QUIMPER	\N	\N	1	2017-11-16 16:21:53	2017-11-29 10:40:39
121	1116	NEANT	RUE	\N	\N	22 G	rue grange du chapitre	Mansle	16230	\N	\N	\N	1	2017-11-16 00:00:00	2024-01-30 00:00:00
122	1117	NEANT	AUCUN	CS 92004	\N	\N	8 rue Joseph Cugnot	\N	\N	 38307 Bourgoin-Jallieu Cedex 	\N	\N	1	2017-11-16 19:49:41	2017-11-16 19:50:11
233	1425	NEANT	AVE	\N	\N	124 	Victor Hugo	Tulle	19000	\N	\N	\N	1	\N	\N
124	1119	NEANT	AUCUN	\N	\N	\N	18 rue Inkermann 	\N	\N	BP1233 59013 Lille Cedex	\N	\N	1	2017-11-16 19:53:55	2017-11-16 19:54:54
271	1526	NEANT	RUE	\N	\N	15	de Vaugirard	PARIS CEDEX 06	75291	\N	\N	\N	\N	2023-12-05 00:00:00	\N
127	1122	NEANT	AUCUN	\N	\N	 4	rue Charles Gros	10000 Troyes	\N	\N	\N	\N	1	2017-11-23 17:10:25	2018-06-04 15:57:31
171	1152	NEANT	PLACE	\N	\N	13	place de la Victoire	59200 Tourcoing	\N	\N	\N	\N	1	2018-01-25 10:13:07	2018-01-25 10:13:32
139	1145	NEANT	AUCUN	\N	\N	\N	23 rue du Cardinal Donnet	42220 Bourg-Argental	\N	\N	\N	\N	1	2017-12-20 09:42:29	2017-12-20 09:43:20
173	1198	NEANT	AUCUN	Place Pey Berland	\N	\N	Hôtel de Ville	Bordeaux Cedex	33045	\N	\N	\N	1	2018-01-30 15:58:52	2018-01-30 16:02:59
184	1222	NEANT	AUCUN	\N	\N	2	rue du saumon	67000 Strasbourg	\N	\N	\N	\N	1	2018-06-06 16:33:20	2018-06-06 19:18:37
188	1233	NEANT	RUE	\N	\N	3	rue Gabriel Péri	38000 Grenoble	\N	\N	\N	\N	1	\N	\N
194	1246	NEANT	RUE	\N	\N	1	Rue du Pont Notre-Dame	Mende	48000	\N	\N	\N	1	\N	\N
214	1381	NEANT	AUCUN	1 place du 8 mai 1945	\N	\N	Espace Louis Aragon	\N	\N	24000 Périgueux	\N	\N	1	\N	\N
230	1416	NEANT	AUCUN	\N	\N	6	cours Gay-Lussac	LIMOGES	87000	\N	\N	\N	1	\N	\N
264	1510	NEANT	RUE	\N	\N	15	rue de Vaugirard	Paris	75291	\N	06	\N	1	\N	2023-11-21 00:00:00
35	834	NEANT	NEANT	\N	\N	11	Grand Rue	\N	30660	Gallargues le Montueux	\N	\N	1	2014-11-13 17:05:31	2014-11-13 17:06:03
21	812	BIS	RUE	\N	\N	42	rue Carnot	\N	69190	Saint-Fons	\N	\N	1	2014-10-13 10:50:42	2014-10-13 11:02:25
36	835	NEANT	NEANT	\N	\N	4	rue Paul Pioda	\N	01003	Bourg-en-Bresse	\N	\N	1	2014-11-13 17:32:27	2014-11-13 17:33:01
215	1382	NEANT	AUCUN	\N	\N	49	rue Gambetta	70500 Jussey	\N	\N	\N	\N	1	\N	\N
50	863	NEANT	NEANT	Place Maurice Segonds	\N	\N	Mairie de Bailleul-sur-Thérain	Bailleul-sur-Thérain	60930	\N	\N	\N	1	2015-06-30 13:03:06	2015-06-30 13:05:38
51	864	NEANT	RUE	\N	\N	42	de la 1ère armée	\N	67000	Strasbourg	\N	\N	1	2015-06-30 15:25:52	2015-06-30 15:27:43
54	867	NEANT	NEANT	\N	\N	\N	6 rue du Poids de l'huile	\N	\N	31000 Toulouse	\N	\N	1	2015-07-02 12:32:48	2015-07-02 12:33:48
108	1098	NEANT	RUE	\N	\N	18	d'Inkermann	LILLE	59000	\N	\N	\N	1	2017-10-11 10:22:11	2017-10-11 10:26:17
59	880	NEANT	AVE	\N	\N	15	avenue d'Orluc	\N	19300	Egletons	\N	\N	1	2015-07-13 15:38:19	2015-07-13 15:39:20
58	879	NEANT	RUE	\N	\N	48	rue du docteur Bardon	\N	19100	Brive	\N	\N	1	2015-07-13 15:35:03	2015-07-13 15:36:07
60	882	NEANT	RUE	SYANE	\N	27	rue de la Paix	\N	74000	Annecy	\N	\N	1	2015-07-13 15:42:23	2015-07-13 15:43:01
61	883	NEANT	NEANT	\N	\N	70	Les Combes	\N	23500	Felletin	\N	\N	1	2015-07-13 15:44:18	2015-07-13 15:44:52
68	903	NEANT	PLACE	\N	\N	1	Beauvau	\N	75008	Paris	\N	\N	1	2015-09-24 13:14:19	2015-09-24 13:15:09
76	918	NEANT	AUCUN	\N	\N	12	rue Paul et Louise Pioda	01000 BOURG EN BRESSE	\N	\N	\N	\N	1	2016-05-19 14:36:32	2018-03-21 12:06:25
115	1109	NEANT	AUCUN	\N	Résidence Destenay	\N	3 passage Bruzaud-Grille	\N	\N	65000 TARBES	\N	\N	1	2017-11-14 17:59:46	2017-11-14 18:00:10
107	1097	NEANT	AUCUN	\N	\N	\N	CAP CONCORDE, 26 rue du Prado	34170 CASTELNAU-LE-LEZ	\N	\N	\N	\N	1	2017-10-09 17:26:58	2017-11-30 18:39:01
116	1110	NEANT	AUCUN	\N	\N	\N	129 avenue du Docteur Edouard Castéra	\N	BP 60	40700 HAGETMAU	\N	\N	1	2017-11-14 18:03:16	2017-11-14 18:03:50
117	1111	NEANT	AUCUN	\N	Allée des Prés Rouets	\N	Zone artisanale des Lats 	\N	\N	69510 MESSIMY	\N	\N	1	2017-11-14 18:36:55	2017-11-14 18:37:19
118	1112	NEANT	AUCUN	\N	\N	\N	30 rue Voltaire	\N	\N	08000 CHARLEVILLE MEZIERES	\N	\N	1	2017-11-14 18:41:30	2017-11-14 18:41:46
119	1114	NEANT	AUCUN	\N	\N	\N	1 rue Paul-Louis Courier	\N	\N	360000 CHÂTEAUROUX	\N	\N	1	2017-11-16 11:48:47	2017-11-16 11:49:18
248	1472	NEANT	AUCUN	\N	\N	17	rue Charles de Gaulle	\N	25410	Saint-Vit	\N	\N	1	\N	\N
130	1126	NEANT	AUCUN	\N	\N	\N	4 place Charles de Gaulle	29600 Morlaix	\N	\N	\N	\N	1	2017-11-27 17:02:04	2017-12-06 17:01:48
131	1128	NEANT	BLVD	\N	\N	65	boulevard Ledru-Rollin	\N	03000	Moulins	\N	\N	1	2017-11-27 18:18:52	2017-11-27 18:23:05
140	1147	NEANT	RUE	\N	\N	18 B	Arthur Delobelle	Athies	62223	\N	\N	\N	1	2017-12-20 09:49:07	2017-12-20 09:50:08
153	1167	BIS	RUE	\N	\N	47	Gambetta	\N	47400	Tonneins	\N	\N	1	2017-12-21 13:54:29	2017-12-21 13:58:52
272	1527	NEANT	RUE	\N	\N	15	de Vaugirard	PARIS CEDEX 06	75291	\N	\N	\N	\N	2023-12-05 00:00:00	\N
156	1171	NEANT	AUCUN	\N	\N	34	Boulevard du Pont-Rouge	15000 AURILLAC	\N	\N	\N	\N	1	2017-12-21 15:43:51	2017-12-21 15:44:54
158	1172	NEANT	PLACE	\N	\N	32	Jean Jaurès	\N	81000	ALBI	\N	\N	1	2017-12-21 15:51:41	2017-12-21 15:52:21
185	1223	NEANT	RUE	BP 346	\N	17	rue Marcel Aymé	39100 Dole	\N	\N	\N	\N	1	2018-06-11 09:35:41	2018-06-11 09:36:27
190	1237	NEANT	PLACE	\N	\N	33	Général De Gaulle	Rouen	76000	\N	\N	\N	1	\N	\N
191	1236	BIS	RUE	\N	\N	60	des Martyrs de la Résistance	Bolbec	76210	\N	\N	\N	1	\N	\N
193	1	NEANT	RUE	Casier de la Poste	\N	15	rue de Vaugirard	\N	75291	Paris	\N	Cedex 06	1	2013-12-10 10:15:02	\N
196	1253	NEANT	RUE	\N	\N	66	rue Centrale	13013 Marseille	\N	\N	\N	\N	1	\N	\N
216	1383	NEANT	AUCUN	\N	\N	\N	4 rue Georges Clemenceau	\N	\N	90000 Belfort	\N	\N	1	\N	\N
222	1399	NEANT	RUE	\N	\N	2	Michelet	Montauban	82000	\N	\N	\N	1	\N	\N
224	1401	NEANT	AUCUN	\N	\N	\N	32 cours Tourny	\N	\N	24000 Périgueux	\N	\N	1	\N	\N
225	1402	NEANT	AUCUN	\N	\N	\N	7 rue du grand four	\N	\N	02270 Crécy-sur-Serre	\N	\N	1	\N	\N
228	1377	NEANT	AUCUN	\N	\N	\N	9 rue du Général Leclerc	\N	\N	89100 Sens	\N	\N	1	\N	\N
237	1428	NEANT	BLVD	\N	\N	10	 Boulevard Clémenceau	GUINGAMP	22200	\N	\N	\N	1	\N	\N
238	1430	NEANT	AVE	\N	\N	48	Nationale	ARNAGE	72230	\N	\N	\N	1	\N	\N
239	1433	NEANT	NEANT	Résidence Nord	\N	10	Avenue Georges Corneau	\N	08000	Charleville-Mezieres	\N	\N	1	\N	\N
240	1252	NEANT	AVE	\N	\N	28	de Douaumont	\N	55100	Verdun	\N	\N	1	\N	\N
274	1486	NEANT	RUE	\N	\N	15	de Vaugirard	PARIS CEDEX 06	75291	\N	\N	\N	\N	2023-12-05 00:00:00	\N
289	1545	NEANT	RUE	\N	\N	26	rue du Mail	Mortagne-au-Perche	61400	\N	\N	\N	\N	2024-02-19 00:00:00	\N
293	1549	NEANT	RUE	\N	\N	15	rue de Vaugirard	PARIS Cedex 06	75291	\N	\N	\N	\N	2024-02-21 00:00:00	\N
32	831	NEANT	NEANT	\N	\N	2 Grand Rue	BP 60216	\N	57282	Maizières Les Metz Cedex	\N	\N	1	2014-10-27 15:59:23	2014-10-27 16:00:16
33	832	NEANT	NEANT	\N	\N	114 avenue	de la République	\N	44600	Saint Nazaire	\N	\N	1	2014-10-28 16:28:52	2014-10-28 16:29:25
38	839	NEANT	NEANT	\N	\N	8	quai de la Fontaine	\N	30000	Nîmes	\N	\N	1	2014-12-23 10:51:38	2014-12-23 10:52:07
42	849	NEANT	RUE	\N	\N	19	rue du Gouvernement	Saint-Quentin	02100	\N	\N	\N	1	2015-04-16 10:43:56	2015-04-16 10:45:34
43	850	NEANT	AUCUN	\N	\N	\N	1 rue de Berga	Résidence des 3 Vallées	09400	Tarascon sur Ariège	\N	\N	1	2015-04-16 12:45:00	2017-12-21 10:25:43
48	861	NEANT	RUE	\N	\N	13	Boucton Favréaux	\N	51420	Witry-lès-Reims	\N	\N	1	2015-06-30 10:17:57	2017-10-25 11:17:26
52	865	NEANT	RUE	BP 55116	\N	15	rue voltaire	 	49051	ANGERS	\N	CEDEX 2	1	2015-06-30 16:27:14	2015-06-30 16:30:34
72	911	NEANT	RUE	\N	\N	10	rue Jules Ferry	53 000	Laval	\N	\N	\N	1	2015-10-19 16:58:33	2015-10-19 16:59:48
65	888	NEANT	NEANT	\N	\N	41	avenue Gioffredo	Nice	06000	\N	\N	\N	1	2015-07-21 13:52:37	2017-07-10 15:22:26
71	910	NEANT	NEANT	\N	\N	\N	15 avenue Edouard Droz	\N	\N	25000 Besançon	\N	\N	1	2015-10-12 14:44:14	2015-10-12 14:44:46
73	913	NEANT	NEANT	\N	\N	\N	2 rue Zizim	\N	\N	23400 Bourganeuf	\N	\N	1	2015-12-21 17:54:55	2015-12-21 17:58:35
87	943	NEANT	PLACE	\N	\N	13	Vendôme	\N	75001	Paris	\N	\N	1	2017-05-18 16:52:54	2017-05-18 16:54:09
88	944	NEANT	RUE	\N	\N	14	Saint-Dominique	\N	75700	Paris	\N	\N	1	2017-05-18 16:56:49	2017-05-18 17:02:20
89	945	NEANT	QUAI	\N	\N	37	d'Orsay	\N	75351	Paris	\N	Cedex 07	1	2017-05-18 17:02:57	2017-05-18 17:04:57
90	946	NEANT	RUE	\N	Hôtel de Castries	72	de Varenne	\N	75007	Paris	\N	\N	1	2017-05-18 17:11:59	2017-05-18 17:14:18
91	947	NEANT	AVE	\N	\N	14	Duquesne	\N	75350	Paris	\N	\N	1	2017-05-18 17:14:45	2017-05-18 17:16:28
92	948	NEANT	RUE	\N	\N	182	Saint Honoré	\N	75001	Paris	\N	\N	1	2017-05-18 17:16:55	2017-05-18 17:21:45
93	949	NEANT	RUE	\N	\N	139	de Bercy	\N	75012	Paris	\N	\N	1	2017-05-18 17:22:08	2017-05-18 17:24:03
94	950	NEANT	RUE	\N	\N	127 	de Grenelle	\N	75007	Paris	\N	\N	1	2017-05-18 17:24:24	2017-05-18 17:25:45
95	951	NEANT	RUE	\N	\N	110 	de Grenelle	\N	75007	Paris	\N	\N	1	2017-05-18 17:26:05	2017-05-18 17:40:49
96	952	NEANT	RUE	\N	Hôtel de Villeroy	78	de Varenne	\N	75007	Paris	\N	\N	1	2017-05-18 17:41:11	2017-05-18 17:50:38
101	957	NEANT	RUE	\N	\N	40	du Bac	\N	75700	Paris	\N	\N	1	2017-06-19 17:55:27	2017-06-19 17:56:04
102	966	NEANT	QUAI	\N	\N	37	d'Orsay	\N	75007	Paris	\N	\N	1	2017-06-19 17:56:31	2017-06-19 17:57:31
103	967	NEANT	RUE	Hôtel Rothelin-Charolais	\N	101	de Grenelle	\N	75007	Paris	\N	\N	1	2017-06-19 17:58:19	2017-06-19 17:59:07
104	969	NEANT	RUE	\N	\N	55	Saint-Dominique	\N	75007	Paris	\N	\N	1	2017-06-19 18:00:49	2017-06-19 18:02:32
105	970	NEANT	AVE	\N	\N	14	Duquesne	\N	75007	Paris	\N	\N	1	2017-06-19 18:02:52	2017-06-19 18:03:49
106	971	NEANT	RUE	\N	\N	35	Saint-Dominique	\N	75700	Paris	\N	\N	1	2017-06-19 18:04:15	2017-06-19 18:05:01
150	1161	NEANT	AVE	\N	\N	4	du Maréchal Foch	\N	31280	DRÉMIL-LAFAGE	\N	\N	1	2017-12-21 10:26:25	2017-12-21 10:29:08
160	1174	NEANT	RUE	3 rue des Trois Croix	\N	\N	\N	\N	\N	Laval	\N	53000	1	2017-12-21 17:34:51	2017-12-21 17:41:59
161	1175	NEANT	AUCUN	\N	\N	3	rue Carnot	69500	\N	BRON	\N	\N	1	2017-12-21 21:22:54	2018-01-05 10:07:42
168	1185	BIS	RUE	\N	\N	11	du 14 juillet	\N	58200	Cosne Cours sur Loire	\N	\N	1	2018-01-10 20:38:10	2018-03-09 10:41:26
169	1189	NEANT	RUE	\N	\N	4	Blaise Pascal	Rouen	76100	\N	\N	\N	1	2018-01-16 13:00:28	2018-01-16 13:01:20
172	1195	NEANT	RUE	\N	\N	1	Arnault Daniel	Ribérac	24600	Nouvelle ville	\N	\N	1	2018-01-29 13:59:47	2018-01-29 14:02:51
174	1199	NEANT	RUE	\N	\N	964	rue Alphonse Gourju	Apprieu	38140	\N	\N	\N	1	2018-01-30 19:36:47	2018-01-30 19:45:04
175	1206	NEANT	AUCUN	des Arquebusiers	\N	\N	6 rue	\N	67000	Strasbourg	\N	\N	1	2018-02-06 12:54:46	2018-02-06 12:57:48
181	1212	NEANT	BLVD	\N	\N	16	boulevard d'Alger	72200 La Flèche	\N	\N	\N	\N	1	2018-03-28 10:02:40	2018-03-28 10:06:42
177	1207	NEANT	AUCUN	\N	\N	6	passage Saint-Tropez	\N	56000	Vannes	\N	\N	1	2018-02-16 11:10:07	2018-02-16 11:12:39
198	1256	NEANT	AUCUN	\N	\N	31	rue Barnave	BP 90210	\N	26500 Bourg-Les-Valence	\N	\N	1	\N	\N
186	1229	NEANT	AUCUN	1er étage	\N	66	rue de la gare	62300 Lens	\N	\N	\N	\N	1	\N	\N
241	1442	NEANT	AUCUN	\N	\N	32	route de Pont-Audemer	\N	27260	ÉPAIGNES	\N	\N	1	\N	\N
195	1251	NEANT	AUCUN	\N	\N	\N	16 place de l'Hôtel de Ville	\N	\N	74800 La Roche sur Foron	\N	\N	1	\N	\N
202	1359	NEANT	AUCUN	\N	\N	\N	Place de la Libération	\N	\N	32000 Auch	\N	\N	1	\N	\N
205	1365	NEANT	AUCUN	\N	\N	46	boulevard Edgar Quinet	79200 Parthenay	\N	\N	\N	\N	1	\N	\N
206	1366	NEANT	RUE	\N	\N	4 	Pradier	\N	30000	Nîmes	\N	\N	1	\N	\N
245	1454	NEANT	RUE	\N	\N	1	rue du Pont Notre-Dame	\N	48000	Mende	\N	\N	1	\N	\N
208	1368	BIS	RUE	\N	\N	 7	Ferdinand Dreyfus	\N	78120	Rambouillet	\N	\N	1	\N	\N
209	1369	NEANT	AUCUN	\N	\N	123	route nationale	\N	80370	Bernaville	\N	\N	1	\N	\N
246	1456	NEANT	RUE	Hôtel de Matignon	\N	57	de Varenne	\N	75700	Paris	\N	\N	1	\N	\N
218	1387	NEANT	AUCUN	\N	\N	\N	22 boulevard du Midi	\N	\N	31350 Boulogne-sur-Gesse	\N	\N	1	\N	\N
223	1400	NEANT	AUCUN	\N	\N	\N	16 bis rue du Jardin des Plantes	\N	\N	50300 Avranches	\N	\N	1	\N	\N
229	1415	NEANT	RUE	\N	\N	14	de la République	MOUCHARD	39330	\N	\N	\N	1	\N	\N
26	824	NEANT	NEANT	Immeuble "Le Lumière"	\N	4	Rue Général Delestraint	\N	01000	Bourg-en-Bresse	\N	\N	1	2014-10-23 14:39:24	2016-09-19 15:07:51
243	1446	NEANT	AUCUN	\N	\N	11 	cours du Jeu du Mail	\N	09500	Mirepoix	\N	\N	1	\N	\N
28	826	NEANT	NEANT	\N	\N	2 rue	Lemoine-Lenoir	\N	36000	Châteauroux	\N	\N	1	2014-10-23 17:13:28	2014-10-23 17:14:30
37	836	NEANT	NEANT	1, route d'Alençon	\N	\N	Le Vicariat	\N	72170	Saint-Marceau	\N	\N	1	2014-12-04 23:17:34	2014-12-04 23:18:11
40	845	NEANT	PLACE	\N	\N	2	place des Allobroges	\N	74300	Cluses	\N	\N	1	2015-02-20 16:51:10	2017-10-10 18:40:43
46	844	NEANT	PLACE	\N	\N	19	des Etudes	AVIGNON	84000	AVIGNON	\N	\N	1	2015-05-22 11:38:17	2017-10-10 13:33:23
47	857	NEANT	RUE	bat A	\N	28	Velouterie	AVIGNON	84000	AVIGNON	\N	\N	1	2015-05-22 11:44:20	2017-10-10 13:32:04
182	1213	NEANT	RUE	\N	\N	2	des anciennes tanneries	10000 Troyes	\N	\N	\N	\N	1	2018-04-04 14:09:50	2018-04-04 14:10:33
63	886	NEANT	NEANT	\N	\N	227	boulevard Gambetta	Villefranche	69400	\N	\N	\N	1	2015-07-17 16:07:48	2015-07-17 16:08:49
66	889	NEANT	NEANT	\N	\N	\N	7 place Jacques Félix	\N	08000	Charleville-Mézières	\N	\N	1	2015-07-29 10:37:31	2015-07-29 10:42:13
67	892	NEANT	PLACE	\N	\N	\N	Place Etienne Régnier	La Chaussée Saint-Victor	41260	\N	\N	\N	1	2015-09-08 14:04:26	2016-05-26 17:30:28
85	941	NEANT	RUE	Hôtel de Matignon	\N	57	de Varenne	\N	75700	Paris	\N	\N	1	2017-05-18 10:34:37	2017-06-19 17:59:53
86	942	NEANT	BLVD	\N	Hôtel de Roquelaure	246	Saint-Germain	\N	75007	Paris	\N	\N	1	2017-05-18 10:40:25	2017-05-18 16:51:44
134	1004	NEANT	AUCUN	\N	\N	\N	24 avenue de la Résistance	\N	\N	77500 CHELLES	\N	\N	1	2017-12-19 17:38:19	2018-01-09 10:11:02
137	1144	NEANT	AUCUN	\N	\N	19	Traverse Soutoviale	VINSOBRES	26110	\N	\N	\N	1	2017-12-20 09:02:59	2017-12-20 09:05:47
143	1	NEANT	PLACE	\N	\N	13	de la Victoire	\N	59200	Tourcoing	\N	\N	1	2013-12-10 10:15:02	2017-12-20 10:48:45
151	1165	NEANT	AUCUN	\N	\N	1	 rue Laënnec	29100 Douarnenez	\N	\N	\N	\N	1	2017-12-21 10:42:48	2017-12-21 10:47:15
167	1183	NEANT	AUCUN	\N	\N	\N	BP 14	\N	\N	15300  Murat 	\N	\N	1	2018-01-08 19:04:56	2018-01-09 10:37:51
178	1211	NEANT	RUE	\N	\N	10A	rue Georges Teissier	\N	42000	SAINT ETIENNE	\N	\N	1	2018-02-20 14:07:49	2018-02-20 14:12:40
204	1364	NEANT	PLACE	\N	\N	10	Thiers	Pont à Mousson	54700	\N	\N	\N	1	\N	\N
242	1444	NEANT	RUE	\N	\N	\N	11 rue Abbé Bessou	\N	12000	RODEZ	\N	\N	1	\N	\N
211	1373	NEANT	AUCUN	\N	\N	3 	rue Marc Sangnier	\N	35200	Rennes	\N	\N	1	\N	\N
212	1378	NEANT	RUE	\N	\N	33	Urbain IV	TROYES	\N	TROYES	\N	\N	1	\N	\N
236	1367	NEANT	AUCUN	\N	\N	\N	65 boulevard Ledru Rollin 	\N	\N	03000 Moulins	\N	\N	1	\N	\N
244	1451	NEANT	RUE	\N	\N	24	Sadi Carnot	\N	59350	SAINT-ANDRÉ	\N	\N	1	\N	\N
249	1475	NEANT	AUCUN	\N	\N	6	place de l'Ancien Foirail	\N	32000	AUCH	\N	\N	1	\N	\N
285	1532	NEANT	RUE	\N	\N	159	Allée du Château	Satolas-et-Bonce	38290	\N	\N	\N	\N	2024-01-23 00:00:00	2024-01-23 00:00:00
287	1542	NEANT	RUE	\N	\N	10	rue Grande des Fabriques	PERPIGNAN	66000	\N	\N	\N	1	\N	2024-02-07 00:00:00
288	1543	NEANT	RUE	\N	\N	15	rue de Vaugirard	PARIS CEDEX 06	75291	\N	\N	\N	\N	2024-02-07 00:00:00	\N
16	16	NEANT	NEANT	\N	\N	8	place de la Gare	\N	68000	COLMAR	\N	\N	1	2013-12-10 10:15:02	\N
10	10	NEANT	PLACE	BP 40 015	\N	\N	de la Rode	\N	46600	MARTEL	\N	\N	1	2013-12-10 10:15:02	\N
11	11	NEANT	NEANT	1er étage, escalier B	\N	28	rue Lormand	\N	64100	Bayonne	\N	\N	1	2013-12-10 10:15:02	\N
265	1522	NEANT	RUE	\N	\N	15	de Vaugirard	PARIS CEDEX 06	75291	\N	\N	\N	\N	2023-12-04 00:00:00	2023-12-04 00:00:00
24	819	NEANT	RUE	\N	\N	7	rue Voltaire	\N	38000	Grenoble	\N	\N	1	2014-10-23 13:24:27	2014-10-23 13:25:42
14	14	NEANT	AUCUN	\N	\N	\N	58, avenue du Président Kennedy	68000 Mulhouse	\N	\N	\N	\N	1	2013-12-10 10:15:02	\N
29	827	NEANT	NEANT	\N	\N	18 rue	Poirier Chanin	\N	71240	Sennecey-le-Grand	\N	\N	1	2014-10-24 16:37:02	2015-06-29 09:59:36
30	828	NEANT	AUCUN	\N	\N	\N	BP 35	\N	72800	Le Lude	\N	\N	1	2014-10-24 16:44:05	2017-11-08 16:00:31
34	833	NEANT	NEANT	\N	\N	6	place Auguste Génie	\N	60160	Montataire	\N	\N	1	2014-11-03 11:39:11	2014-11-03 11:39:40
39	843	NEANT	NEANT	\N	\N	\N	20, rue de la République	\N	84240	La Tour d'Aigues	\N	\N	1	2015-01-27 11:56:21	2015-01-27 11:56:58
45	856	NEANT	RUE	\N	\N	10	rue Thomann	Strasbourg	67000	\N	\N	\N	1	2015-05-19 14:13:04	2015-05-19 14:14:26
49	862	NEANT	NEANT	73, rue Carnot	\N	\N	"Le Carillon Bleu"	\N	0500 	GAP	\N	\N	1	2015-06-30 11:54:47	2015-06-30 11:55:29
70	908	NEANT	NEANT	\N	\N	\N	34 rue Bersot	\N	25000	Besançon	\N	\N	1	2015-10-08 16:19:54	2015-10-08 16:20:30
75	917	NEANT	RUE	\N	\N	1	rue Lazare Carnot	38000 Grenoble	\N	\N	\N	\N	1	2016-04-08 09:38:25	2016-04-08 09:43:05
77	921	NEANT	NEANT	\N	\N	\N	5 rue de la Guerlande	\N	\N	71880 Châtenoy-le-Royal	\N	\N	1	2016-06-30 09:53:39	2016-06-30 09:54:25
81	929	NEANT	RUE	\N	\N	66	rue de la Gare	Lens	62300	BP 256	\N	\N	1	2016-11-22 15:37:19	2016-11-22 15:41:32
97	953	NEANT	RUE	\N	\N	139	de Bercy	\N	75572	Paris cedex 12	\N	\N	1	2017-05-19 15:55:00	2017-05-23 11:13:01
98	954	NEANT	RUE	\N	\N	1	Descartes	\N	75231	Paris cedex 05	\N	\N	1	2017-05-23 11:13:49	2017-05-23 11:15:32
99	955	NEANT	RUE	\N	\N	27	Oudinot	\N	75007	Paris	\N	\N	1	2017-05-23 11:17:03	2017-05-23 11:17:25
100	956	NEANT	AVE	\N	\N	95	de France	\N	75013	Paris	\N	\N	1	2017-05-23 11:17:39	2017-05-23 11:18:20
111	1103	NEANT	AUCUN	\N	\N	\N	BP 60	REVEL	31250	\N	\N	\N	1	2017-11-08 16:07:54	2017-11-08 16:08:34
112	1104	NEANT	AUCUN	BP 90060	\N	\N	51 boulevard de Saintonge	\N	17130	Montendre	\N	\N	1	2017-11-08 16:18:58	2017-11-08 16:20:24
114	1107	NEANT	AUCUN	\N	\N	\N	1 place de l'étoile	\N	\N	38000 GRENOBLE 	\N	\N	1	2017-11-14 10:28:27	2017-11-14 10:29:31
132	1129	NEANT	AUCUN	\N	BP 7 11 47	\N	4 Place Jean Jaurès	\N	\N	TOURS 37011 Cedex 1	\N	\N	1	2017-11-28 15:06:17	\N
135	1140	NEANT	NEANT	\N	\N	7	Allée des Paons	Woippy	\N	\N	\N	\N	1	2017-12-19 18:01:52	2017-12-19 18:05:00
141	1149	NEANT	RUE	\N	\N	8	Antoine Arnaud	\N	63200	Riom	\N	\N	1	2017-12-20 10:07:58	2017-12-20 10:09:55
142	1148	NEANT	AUCUN	\N	\N	2	rue Marcet	\N	54190	Villerupt	\N	\N	1	2017-12-20 10:10:20	2017-12-20 10:10:46
145	1154	NEANT	RUE	\N	\N	17	Jules Ferry	Laval	53000	\N	\N	\N	1	2017-12-20 00:00:00	2023-11-14 00:00:00
146	1155	NEANT	RUE	\N	\N	47	Adolphe Cadéot	\N	32500	Fleurance	\N	\N	1	2017-12-20 16:53:42	2017-12-20 16:56:09
147	1157	NEANT	RUE	\N	\N	60	Racine	Villeurbanne	69100	\N	\N	\N	1	2017-12-21 10:12:16	2017-12-21 10:14:26
159	1173	BIS	RUE	\N	\N	4 	Bourdaloue	Nimes	30900	\N	\N	\N	1	2017-12-21 16:07:06	2017-12-21 16:09:52
266	1524	NEANT	RUE	\N	\N	15	de Vaugirard	PARIS CEDEX 6	75291	\N	\N	\N	\N	2023-12-04 00:00:00	\N
164	1179	BIS	RUE	BP 240 	\N	16	du Jardin des Plantes	AVRANCHES Cedex	50302	\N	\N	\N	1	2017-12-22 11:19:11	2017-12-22 11:22:03
179	1133	NEANT	RUE	\N	\N	2	de l'Egalité	Auxerre	89000	\N	\N	\N	1	2018-03-09 12:06:11	2018-03-09 12:06:46
180	1214	NEANT	AUCUN	1025 rue Henri Becquerel	\N	\N	10 Parc Club du Millénaire	\N	\N	34000 Montpellier	\N	\N	1	2018-03-14 16:42:10	2018-03-14 16:42:53
192	1238	NEANT	RUE	\N	\N	110	rue des pêcheurs	\N	40130	CAPBRETON	\N	\N	1	\N	\N
197	1096	NEANT	NEANT	ROUTE DE NEREE	\N	1	RUE MAURICE FLORY	LES ABYMES	97139	Nouvelle ville	\N	\N	1	\N	\N
203	1361	NEANT	AUCUN	Boulevard Bouyala d'Arnaud 	\N	\N	Mairie des 11-12 arrondissements	Marseille	13012	\N	\N	\N	1	\N	\N
226	1403	NEANT	AUCUN	\N	\N	\N	114 rue San Lucar	\N	\N	30900 Nîmes	\N	\N	1	\N	\N
232	1422	NEANT	AUCUN	\N	\N	4	ruelle des Pelletiers	Strasbourg	67000	\N	\N	\N	1	\N	\N
235	1427	NEANT	AVE	\N	\N	101	avenue Foch	Le Havre	76600	\N	\N	\N	1	\N	2024-03-05 00:00:00
268	1525	NEANT	RUE	\N	\N	15	de Vaugirard	PARIS CEDEX 06	75291	\N	\N	\N	\N	2023-12-04 00:00:00	\N
275	1528	NEANT	RUE	\N	\N	19	rue Capron	Valenciennes	59300	\N	\N	\N	1	\N	\N
286	1539	NEANT	QUAI	Lamennais	\N	21	Nouvelle adresse	RENNES	35000	Nouvelle ville	\N	\N	1	\N	\N
\.


--
-- Data for Name: asster; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY asster (asstercod, assterlib, assterlic, assternumtri, assterurlcmp, syscredat, sysmajdat, assterart) FROM stdin;
CALEDONIE	Territoire de Nouvelle Calédonie	Nouvelle Calédonie	2	\N	\N	\N	du 
CORSE	Assemblée Territoriale de Corse	Corse	1	\N	\N	\N	de l'
POLYNESIE	Gouvernement de Polynésie Française	Polynésie Française	3	\N	\N	\N	du 
AUTRE	Autre assemblée territoriale	Autre	4	\N	\N	\N	d'une 
\.


--
-- Data for Name: bur; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY bur (burcod, burlib, burlic, burnumtri, burlil, burlibhon, burlicfem, burlibfem, burlilfem, burlicplu, burlibplu, burlilplu, burlibhonfem, burlibhonplu, syscredat, sysmajdat, burlicfemplu, burlibfemplu, burlilfemplu) FROM stdin;
AUCUNSEN	\N	Sénateur	5	Sénateur	\N	Sénateur	\N	Sénatrice	Sénateurs	\N	Sénateurs	\N	\N	\N	\N	Sénateurs	\N	Sénateurs
PDTSEN	Président du Sénat	Président	1	Président du Sénat	Président honoraire du Sénat	Présidente	Présidente du Sénat	Présidente du Sénat	Présidents	Présidents du Sénat	Présidents du Sénat	Présidente honoraire du Sénat	Présidents honoraires du Sénat	\N	\N	Présidentes	Présidentes du Sénat	Présidentes du Sénat
QUESTESEN	Questeur du Sénat	Questeur	3	Questeur du Sénat	Questeur honoraire du Sénat	Questeure	Questeure du Sénat	Questeure du Sénat	Questeurs	Questeurs du Sénat	Questeurs du Sénat	Questeure honoraire du Sénat	Questeurs honoraires du Sénat	\N	\N	Questeurs	Questeurs du Sénat	Questeures du Sénat
SECRETSEN	Secrétaire du Sénat	Secrétaire	4	Secrétaire du Sénat	Secrétaire honoraire du Sénat	Secrétaire	Secrétaire du Sénat	Secrétaire du Sénat	Secrétaires	Secrétaires du Sénat	Secrétaires du Sénat	Secrétaire honoraire du Sénat	Secrétaires honoraires du Sénat	\N	\N	Secrétaires	Secrétaires du Sénat	Secrétaires du Sénat
VICPDTSEN	Vice-président du Sénat	Vice-président	2	Vice-président du Sénat	Vice-président honoraire du Sénat	Vice-présidente	Vice-présidente du Sénat	Vice-présidente du Sénat	Vice-présidents	Vice-présidents du Sénat	Vice-présidents du Sénat	Vice-présidente honoraire du Sénat	Vice-présidents honoraires du Sénat	\N	\N	Vice-présidentes	Vice-présidentes du Sénat	Vice-présidentes du Sénat
\.


--
-- Data for Name: categorie_activite; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY categorie_activite (catactcod, catactlic, catactlib, pleniere, catactlibtap, publiee_jo) FROM stdin;
PLEIN_NON_JO	Plénière non publiée au JO	Plénière non publiée au journal officielle	1	\N	0
PEC_NON_MML	PEC	Procédure d'examen en commission	1	\N	1
AUTRE_NON_PLENIERE	Autre (non plénière)	Autre réunion non plénière	0	\N	0
DEPLACEMENT	Déplacement	Déplacement (ne valant pas nécessairement dérogation)	0	\N	0
ALLOCUTION	Allocution	Allocution ou messages divers	1	Allocution	1
AUDRAP	Audition Rapporteur	Audition rapporteur	0	Audition rapporteur	0
DECL_GVT	Décl. du Gvt	Déclaration du Gouvernement	1	Déclaration du Gouvernement	1
ELOGE_FUNEBRE	Éloge funèbre	Éloge funèbre	1	Éloge funèbre	1
HOMMAGE	Hommage	Hommage	1	Hommage	1
GROUPE_TRAVAIL	Groupe de travail	Groupe de travail	0	Groupe de travail	0
RECEPTION	Réception	Réception	1	Réception	1
CONGRES	Congrès	Congrès du Parlement	1	Congrès du Parlement	1
ALLOC_FIN_SESS	Clôture session	Clôture de session	1	Clôture de session	1
MESS_PRESIDENT	Message PR	Message du Président de la République	1	Message du Président de la République	1
RAPPORT_CDC	Rapport CDC	Dépôt du rapport annuel de la Cour des Comptes	1	Dépôt du rapport annuel de la Cour des Comptes	1
DEBAT	Débat	Débat	1	Débat	1
QO	QO	Questions orales	1	Questions orales	1
QOD	QOAD	Question orale avec débat	1	Question orale avec débat	1
QAG	QAG	Questions d'actualité au gouvernement	1	Questions d'actualité au gouvernement	1
EXPLI_VOTE_SCRUSOL	Explications de vote	Explications de vote sur l'ensemble	1	Explications de vote sur l'ensemble	1
SCRUSOL	Scrutin solennel	Scrutin solennel	1	Scrutin solennel	1
CONTROLE	Contrôle	Réunion de contrôle	1	\N	1
AUTRE	Autre plénière	Autre plénière	1	\N	1
AUCUNE	Aucune	Aucune catégorie	1	\N	1
OUV_SESSION	Ouv. session	Ouverture de session	1	Ouverture de session	1
EXAMEN	Examen	Examen	1	\N	1
PLENIERE	Plénière	Réunion plénière	1	\N	1
\.


--
-- Data for Name: com; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY com (typorgcod, orgcod, orgnumtri, orgdatcre, orgdatfin, orgnumtie, temvalcod, evelic, evelib, evelil, orgart, comlilmin, orgurlsim, orgurlcmp, comlibameli, comcodameli, divcod, syscredat, sysmajdat) FROM stdin;
COMSPE	RECHERCHE	1	2005-11-23 00:00:00	2006-03-17 00:00:00	\N	ANCIEN	Recherche	Commission spéciale sur la recherche	COMMISSION SPÉCIALE SUR LE PROJET DE LOI RELATIF À LA RECHERCHE	de la 	Commission spéciale sur le projet de loi relatif à la recherche	/commission/spec/Recherche/Index.html	\N	Commission spéciale sur la recherche	RECH	999	\N	\N
COMENQ	IMMIGRATION	\N	2005-11-03 00:00:00	2006-05-02 00:00:00	\N	ANCIEN	Immigration	Commission d'enquête sur l'immigration clandestine	COMMISSION D'ENQUÊTE SUR L'IMMIGRATION CLANDESTINE	de la	Commission d'enquête sur l'immigration clandestine	/commission/enquete/Immigration/Index.html	\N	Commission d'enquête sur l'immigration clandestine	\N	999	\N	2014-04-07 11:11:43
CMP	20051104N31	\N	2005-11-04 00:00:00	2005-11-11 00:00:00	\N	ANCIEN	\N	récidive des infractions pénales	\N	de la	proposition de loi relative au traitement de la récidive des infractions pénales	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20051118N32	\N	2005-11-18 00:00:00	2005-11-25 00:00:00	\N	ANCIEN	\N	financement de la sécurité sociale pour 2006	\N	du	projet de loi de financement de la sécurité sociale pour 2006	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20050705N28	\N	2005-07-05 00:00:00	2005-07-12 00:00:00	\N	ANCIEN	\N	modernisation de l'économie	\N	du	projet de loi pour la confiance et la modernisation de l'économie	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20051130N33	\N	2005-11-30 00:00:00	2005-12-07 00:00:00	\N	ANCIEN	\N	loi d'orientation agricole	\N	du	projet de loi d'orientation agricole	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20051215N34	\N	2005-12-15 00:00:00	2005-12-22 00:00:00	\N	ANCIEN	\N	sécurité et développement des transports	\N	du	projet de loi relatif à la sécurité et au développement des transports	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20051213N35	\N	2005-12-13 00:00:00	2005-12-20 00:00:00	\N	ANCIEN	\N	loi de finances pour 2006	\N	du	projet de loi de finances pour 2006	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20051215N36	\N	2005-12-15 00:00:00	2005-12-22 00:00:00	\N	ANCIEN	\N	lutte contre le terrorisme	\N	du	projet de loi relatif à la lutte contre le terrorisme et portant dispositions diverses relatives à la sécurité et aux contrôles frontaliers	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20051220N37	\N	2005-12-20 00:00:00	2005-12-27 00:00:00	\N	ANCIEN	\N	loi de finances rectificative pour 2005	\N	du	projet de loi de finances rectificative pour 2005	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
MISINFCOM	BANLIEUES	\N	2005-12-22 00:00:00	2006-11-06 00:00:00	\N	ANCIEN	MCI BANLIEUES	Mission commune d'information "Banlieues"	MISSION COMMUNE D'INFORMATION SUR LE BILAN ET LES PERSPECTIVES D'AVENIR DES POLITIQUES CONDUITES ENVERS LES QUARTIERS EN DIFFICULTÉ DEPUIS UNE QUINZAINE D'ANNÉES	de la	Mission commune d'information sur le bilan et les perspectives d'avenir des politiques conduites envers les quartiers en difficulté depuis une quinzaine d'années	/commission/missions/Banlieues/index.html	\N	Mission commune d'information "Banlieues"	\N	999	\N	2014-04-07 09:57:57
CMP	20060119N38	\N	2006-01-19 00:00:00	2006-01-26 00:00:00	\N	ANCIEN	\N	égalité salariale entre les hommes et les femmes	\N	du	projet de loi relatif à l'égalité salariale entre les femmes et les hommes	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20060119N39	\N	2006-01-26 00:00:00	2006-02-02 00:00:00	\N	ANCIEN	\N	retour à l'emploi et sur les droits et les devoirs des bénéf	\N	du	projet de loi pour le retour à l'emploi et sur les droits et les devoirs des bénéficiaires de minima sociaux	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20060119N40	\N	2006-02-08 00:00:00	2006-02-15 00:00:00	\N	ANCIEN	\N	parcs nationaux et parcs naturels marins	\N	du	projet de loi relatif aux parcs nationaux et aux parcs naturels marins	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20060119N41	\N	2006-01-23 00:00:00	2006-01-30 00:00:00	\N	ANCIEN	\N	dispositions relatives au tourisme	\N	du	projet de loi portant diverses dispositions relatives au tourisme	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20060119N42	\N	2006-02-28 00:00:00	2006-03-07 00:00:00	\N	ANCIEN	\N	violences au sein du couple ou commises contre les mineurs	\N	de la	proposition de loi renforçant la prévention et la répression des violences au sein du couple ou commises contre les mineurs	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20060119N43	\N	2006-03-05 00:00:00	2006-03-12 00:00:00	\N	ANCIEN	\N	égalité des chances	\N	du	projet de loi pour l'égalité des chances	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20060307N44	\N	2006-03-07 00:00:00	2006-03-14 00:00:00	\N	ANCIEN	\N	programme pour la recherche	\N	du	projet de loi de programme pour la recherche	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20060405N45	\N	2006-04-05 00:00:00	2006-04-11 00:00:00	\N	ANCIEN	\N	protection des locataires en cas de vente d'un immeuble	\N	de la	proposition de loi relative au droit de préemption et à la protection des locataires en cas de vente d'un immeuble	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
MISINFCOM	DECISION ECO	\N	2006-06-15 00:00:00	2007-06-27 00:00:00	\N	ANCIEN	MCI "décision économique"	Mission commune d'information "décision économique"	MISSION COMMUNE D'INFORMATION "CENTRE DE DÉCISION ÉCONOMIQUE ET ATTRACTIVITÉ DU TERRITOIRE NATIONAL"	de la 	Mission commune d'information "Centre de décision économique et attractivité du territoire national"	/commission/missions/Decisioneconomique/index.html	\N	Mission commune d'information "décision économique"	\N	999	\N	2015-01-14 10:39:25
CMP	20060608N46	\N	2006-06-08 00:00:00	2006-06-21 00:00:00	\N	ANCIEN	\N	engagement national pour le logement	\N	du	projet de loi portant engagement national pour le logement	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20060616N47	\N	2006-06-16 00:00:00	2006-06-21 00:00:00	\N	ANCIEN	\N	projet de loi relatif à l'immigration et à l'intégration	\N	du	projet de loi relatif à l'immigration et à l'intégration	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20060615N48	\N	2006-06-15 00:00:00	2006-06-22 00:00:00	\N	ANCIEN	\N	projet de loi relatif au droit d'auteur	\N	du	projet de loi relatif au droit d'auteur et aux droits voisins dans la société de l'information	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	2007CMP1	\N	2007-01-25 00:00:00	2007-01-30 00:00:00	\N	ANCIEN	\N	dispositions statutaires relatives à l'outre-mer	\N	du	projet de loi organique portant dispositions statutaires et institutionnelles relatives à l'outre-mer et du projet de loi portant dispositions statutaires et institutionnelles relatives à l'outre-mer	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	2007CMP5	\N	2007-02-12 00:00:00	2007-02-16 00:00:00	\N	ANCIEN	\N	équilibre de la procédure pénale	\N	du	projet de loi tendant à renforcer l'équilibre de la procédure pénale	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	2007CMP7	\N	2007-02-14 00:00:00	2007-02-20 00:00:00	\N	ANCIEN	\N	prévention de la délinquance	\N	du	projet de loi relatif à la prévention de la délinquance	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	2007CMP10	\N	2007-07-26 00:00:00	2007-07-31 00:00:00	\N	ANCIEN	\N	libertés et responsabilités des universités	\N	du	projet de loi relatif aux libertés et responsabilités des universités	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	2007CMP11	\N	2007-07-27 00:00:00	2007-07-31 00:00:00	\N	ANCIEN	\N	travail, emploi et pouvoir d'achat	\N	du	projet de loi en faveur du travail, de l'emploi et du pouvoir d'achat	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20061030N49	\N	2006-10-30 00:00:00	2006-11-06 00:00:00	\N	ANCIEN	\N	secteur de l'énergie	\N	du	projet de loi relatif au secteur de l'énergie	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20061117N51	\N	2006-11-17 00:00:00	2006-11-21 00:00:00	\N	ANCIEN	\N	financement de la sécurité sociale pour 2007	\N	du	projet de loi de financement de la sécurité sociale pour 2007	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20061214N52	\N	2006-12-12 00:00:00	2006-12-14 00:00:00	\N	ANCIEN	\N	projet de loi de finances pour 2007	\N	du	projet de loi de finances pour 2007	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	2007CMP13	\N	2007-10-11 00:00:00	2007-10-16 00:00:00	\N	ANCIEN	\N	projet de loi relatif à la maîtrise de l'immigration, à l'intégration et à l'asile	\N	du	projet de loi relatif à la maîtrise de l'immigration, à l'intégration et à l'asile	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	2007CMP16	\N	2007-12-14 00:00:00	2007-12-18 00:00:00	\N	ANCIEN	\N	développement de la concurrence au service des consommateurs	\N	du	projet de loi pour le développement de la concurrence au service des consommateurs	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	2009CMP9	\N	2009-07-01 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	gendarmerie nationale	\N	du 	projet de loi relatif à la gendarmerie nationale	\N	\N	\N	\N	999	\N	\N
CMP	2008CMP2	\N	2008-01-24 00:00:00	2008-01-30 00:00:00	\N	ANCIEN	\N	réforme de l'organisation du service public de l'emploi	\N	du	projet de loi relatif à la réforme de l'organisation du service public de l'emploi	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	2008CMP8	\N	2008-07-02 00:00:00	2008-07-08 00:00:00	\N	ANCIEN	\N	responsabilité environnementale	\N	du	projet de loi relatif à la responsabilité environnementale et à diverses dispositions d'adaptation au droit communautaire dans le domaine de l'environnement	\N	\N	\N	\N	999	\N	2016-09-15 16:40:05
CMP	2008CMP9	\N	2008-07-10 00:00:00	2008-07-17 00:00:00	\N	ANCIEN	\N	modernisation de l'économie	\N	du	projet de loi de modernisation de l'économie	\N	\N	\N	\N	999	\N	2016-09-15 16:40:05
CMP	2009CMP13	\N	2009-09-15 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	propriété littéraire et artistique sur internet	\N	du 	projet de loi relatif à la protection pénale de la propriété littéraire et artistique sur internet	\N	\N	\N	\N	999	\N	\N
CMP	2007CMP9	\N	2007-07-19 00:00:00	2007-07-24 00:00:00	\N	ANCIEN	\N	lutte contre la récidive des majeurs et des mineurs	\N	du	projet de loi renforçant la lutte contre la récidive des majeurs et des mineurs	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	2007CMP12	\N	2007-07-31 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	continuité du service public dans les transports terrestres 	\N	du	projet de loi sur le dialogue social et  la continuité du service public dans les transports terrestres réguliers de voyageurs	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
COMSPE	ECONOMIE	1	2008-06-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	Modernisation de l'économie	Commission spéciale sur la modernisation de l'économie	COMMISSION SPÉCIALE SUR LE PROJET DE LOI DE MODERNISATION DE L'ÉCONOMIE	de la	Commission spéciale sur le projet de loi de modernisation de l'économie	/commission/spec/LME/index.html	\N	Commission spéciale modernisation de l'économie	LME	999	\N	2014-04-07 11:23:22
CMP	2008CMP10	\N	2008-07-09 00:00:00	2008-07-22 00:00:00	\N	ANCIEN	\N	règlement des comptes et rapport de gestion pour 2007	\N	du	projet de loi de règlement des comptes et rapport de gestion pour 2007	\N	\N	\N	\N	999	\N	2016-09-15 16:40:05
CMP	2008CMP14	\N	2008-10-29 00:00:00	2008-11-04 00:00:00	\N	ANCIEN	\N	Revenu de solidarité active et politiques d'insertion	\N	du	projet de loi généralisant le revenu de solidarité active et réformant les politiques d'insertion	\N	\N	\N	\N	999	\N	2016-09-15 16:40:05
CMP	2008CMP15	\N	2008-10-29 00:00:00	2008-11-04 00:00:00	\N	ANCIEN	\N	Revenus du travail	\N	du	projet de loi en faveur des revenus du travail	\N	\N	\N	\N	999	\N	2016-09-15 16:40:05
CMP	2008CMP19	\N	2008-12-19 00:00:00	2008-12-20 00:00:00	\N	ANCIEN	\N	PJL de finances rectificative pour 2008	\N	du	projet de loi de finances rectificative pour 2008	\N	\N	\N	\N	999	\N	2016-09-15 16:40:05
CMP	2009CMP1	\N	2009-01-21 00:00:00	2009-01-28 00:00:00	\N	ANCIEN	\N	Communication audiovisuelle et service public de la télévisi	\N	du	projet de loi relatif à la communication audiovisuelle et au nouveau service public de la télévision	\N	\N	\N	\N	999	\N	2016-09-15 16:40:05
COM	AFCL	5	1899-12-31 00:50:39	\N	\N	ACTIF	AFCL	Culture	COMMISSION DE LA CULTURE, DE L'ÉDUCATION, DE LA COMMUNICATION ET DU SPORT	de la 	commission de la culture, de l'éducation, de la communication et du sport	/commission/cult/index.html	\N	commission de la culture	CULT	151	\N	2024-01-18 00:00:00
COM	ECON	100	1900-01-01 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	ECON	Économie	COMMISSION DE L'ÉCONOMIE, DU DÉVELOPPEMENT DURABLE ET DE L'AMÉNAGEMENT DU TERRITOIRE	de la 	commission de l'économie, du développement durable et de l'aménagement du territoire	/commission/eco/index.html	\N	commission de l'économie	ECON	152	\N	2013-11-27 14:35:33
COM	ETRD	2	1900-01-01 00:00:00	\N	\N	ACTIF	ETRD	Affaires étrangères	COMMISSION DES AFFAIRES ÉTRANGÈRES, DE LA DÉFENSE ET DES FORCES ARMÉES	de la 	commission des affaires étrangères, de la défense et des forces armées	/commission/etr/index.html	\N	commission des affaires étrangères	ETRD	153	\N	2013-11-27 14:35:32
COM	FINC	6	1900-01-01 00:00:00	\N	\N	ACTIF	FINC	Finances	COMMISSION DES FINANCES	de la	commission des finances	/commission/fin/index.html	\N	commission des finances	FINC	155	\N	2013-11-27 14:35:34
COM	LOIS	7	1900-01-01 00:00:00	\N	\N	ACTIF	LOIS	Lois	COMMISSION DES LOIS CONSTITUTIONNELLES, DE LÉGISLATION, DU SUFFRAGE UNIVERSEL, DU RÈGLEMENT ET D'ADMINISTRATION GÉNÉRALE	de la 	commission des lois constitutionnelles, de législation, du suffrage universel, du Règlement et d'administration générale	/commission/loi/index.html	\N	commission des lois	LOIS	156	\N	2013-11-27 14:35:34
COM	NEANT	10	1900-01-01 00:00:00	\N	\N	ACTIF	Aucune	                     	Aucune  (Président du Sénat)	d'	Aucune  (Président du Sénat)	\N	\N	Aucune (Président du Sénat)	NEANT	999	\N	2014-10-01 09:50:56
COM	SOCI	3	1900-01-01 00:00:00	\N	\N	ACTIF	SOCI	Affaires sociales	COMMISSION DES AFFAIRES SOCIALES	de la 	commission des affaires sociales	/commission/soc/index.html 	\N	commission des affaires sociales	ASOC	154	\N	2013-11-27 14:35:33
COMSPE	CORSE	1	2001-06-19 00:00:00	2001-11-19 00:00:00	\N	ANCIEN	Corse	Commission spéciale sur  la Corse	COMMISSION SPECIALE SUR LE PROJET DE LOI RELATIF A LA CORSE	de la 	commission spéciale sur le projet de loi relatif à la Corse	\N	\N	Commission spéciale sur  la Corse	CORSE	999	\N	\N
COMSPEAPU	COMSPEAPU	1	1900-01-01 00:00:00	\N	\N	ACTIF	Commission spéciale chargée du contrôle des comptes	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne 	COMMISSION SPÉCIALE CHARGÉE DU CONTRÔLE DES COMPTES ET DE L'ÉVALUATION INTERNE	de la	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne 	/listes/comspeapu.html	\N	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne 	\N	999	\N	2014-02-21 14:21:05
COMENQ	DROGUE	1	2002-12-12 00:00:00	2003-05-27 00:00:00	\N	ANCIEN	Drogues illicites	politique nationale de lutte contre les drogues illicites	COMMISSION D'ENQUÊTE SUR LA POLITIQUE NATIONALE DE LUTTE CONTRE LES DROGUES ILLICITES	de la	commission d'enquête sur la politique nationale de lutte contre les drogues illicites	\N	\N	\N	\N	999	\N	2014-02-21 14:21:05
COMENQ	HANDICAPES	1	2002-12-12 00:00:00	2003-06-04 00:00:00	\N	ANCIEN	Personnes handicapées	maltraitance envers les personnes handicapées	COMMISSION D'ENQUÊTE SUR LA MALTRAITANCE ENVERS LES PERSONNES HANDICAPÉES ACCUEILLIES EN INSTITUTION ET LES MOYENS DE LA PRÉVENIR	de la	commission d'enquête sur la maltraitance envers les personnes handicapées accueillies en institution et les moyens de la prévenir	\N	\N	\N	\N	999	\N	2014-04-07 11:23:22
CMP	2011CMP11	\N	2011-04-06 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	simplification du droit	\N	de la 	proposition de loi de simplification et damélioration de la qualité du droit	\N	\N	\N	\N	999	\N	\N
CMP	2011CMP12	\N	2011-06-28 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	participation des citoyens au jugement des mineurs	\N	du 	projet de loi sur la participation des citoyens au fonctionnement de la justice pénale et le jugement des mineurs 	\N	\N	\N	\N	999	\N	\N
CMP	2011CMP13	\N	2011-06-27 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	loi de finances rectificative pour 2011	\N	du 	projet de loi de finances rectificative pour 2011.	\N	\N	\N	\N	999	\N	\N
CMP	2011CMP14	\N	2011-06-29 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	collectivités régies par l'art. 73 de la Constitution	\N	du 	projet de loi organique relatif aux collectivités régies par larticle 73 de la Constitution.	\N	\N	\N	\N	999	\N	\N
CMP	2011CMP15	\N	2011-06-30 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	collectivités territoriales de Guyane et de Martinique	\N	du 	projet de loi relatif aux collectivités territoriales de Guyane et de Martinique.	\N	\N	\N	\N	999	\N	\N
CMP	2011CMP16	\N	2011-07-01 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	fonctionnement des institutions de la Polynésie française	\N	du 	projet de loi organique relatif au fonctionnement des institutions de la Polynésie française.	\N	\N	\N	\N	999	\N	\N
CMP	2011CMP17	\N	2011-07-01 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	développement de lalternance et la sécuritsation des parcours professionnels	\N	de la 	proposition de loi pour le développement de lalternance et la sécurisation des parcours professionnels.	\N	\N	\N	\N	999	\N	\N
CMP	2011CMP18	\N	2011-07-05 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	répartition des contentieux et à lallègement de certaines procédures juridictionnelles 	\N	du 	projet de loi relatif à la répartition des contentieux et à lallègement de certaines procédures juridictionnelles 	\N	\N	\N	\N	999	\N	\N
CMP	2011CMP19	\N	2011-07-06 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	financement rectificative de la sécurité sociale pour 2011 	\N	du 	Projet de loi de financement rectificative de la sécurité sociale pour 2011 	\N	\N	\N	\N	999	\N	\N
CMP	2011CMP20	\N	2011-07-08 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	réforme de lhôpital 	\N	de la 	proposition de loi modifiant certaines dispositions de la loi n° 2009-879 du 21 juillet 2009 portant réforme de lhôpital 	\N	\N	\N	\N	999	\N	\N
CMP	2011CMP21	\N	2011-10-20 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	loi de finances rectificative pour 2011	\N	du 	projet de loi de finances rectificative pour 2011	\N	\N	\N	\N	999	\N	\N
CMP	2011CMP22	\N	2011-11-02 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	mineurs délinquants	\N	de la 	proposition de loi visant à instaurer un service citoyen pour les mineurs délinquants	\N	\N	\N	\N	999	\N	\N
CMP	2011CMP23	\N	2011-11-07 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	sécurité sanitaire du médicament	\N	du 	projet de loi relatif au renforcement de la sécurité sanitaire du médicament et des produits de santé 	\N	\N	\N	\N	999	\N	\N
CMP	2011CMP24	\N	2011-11-14 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	financement de la sécurité sociale pour 2012	\N	du 	projet de loi de financement de la sécurité sociale pour 2012	\N	\N	\N	\N	999	\N	\N
COMAPLEG	COMAPLEG	1	2011-11-30 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	Application des lois	Commission sénatoriale pour le contrôle de l'application des lois	COMMISSION SENATORIALE POUR LE CONTROLE DE L'APPLICATION DES LOIS	de la 	Commission sénatoriale pour le contrôle de l'application des lois	/commission/capl/index.html	\N	Commission sénatoriale pour le contrôle de l'application des lois	\N	999	\N	2014-11-19 17:50:38
CMP	2011CMP25	\N	2011-12-08 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	loi de finances pour 2012	\N	du 	projet de loi de finances pour 2012	\N	\N	\N	\N	999	\N	\N
CMP	2011CMP26	\N	2011-12-19 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	loi de finances rectifative pour 2011 	\N	du 	projet de loi de finances rectifative pour 2011 	\N	\N	\N	\N	999	\N	\N
CMP	20040415N5	\N	2004-04-15 00:00:00	2004-04-22 00:00:00	\N	ANCIEN	\N	Divorce	\N	du	projet de loi relatif au divorce	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20040512N6	\N	2004-05-12 00:00:00	2004-05-19 00:00:00	\N	ANCIEN	\N	Communications électroniques et services de communication au	\N	du	projet de loi relatif aux communications électroniques et aux services de communication audiovisuelle	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20040526N7	\N	2004-05-26 00:00:00	2004-06-02 00:00:00	\N	ANCIEN	\N	solidarité pour l'autonomie des personnes âgées et des personnes handicapées	\N	du	projet de loi relatif à la solidarité pour l'autonomie des personnes âgées et des personnes handicapées	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	2009CMP8	\N	2009-06-10 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	réforme de l'hôpital	\N	du 	projet de loi portant réforme de l'hôpital et relatif aux patients, à la santé et aux territoires	\N	\N	\N	\N	999	\N	\N
CMP	2010CMP10	\N	2010-07-06 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	modernisation de l'agriculture et de la pêche	\N	du 	projet de loi de modernisation de l'agriculture et de la pêche	\N	\N	\N	\N	999	\N	\N
CMP	2010CMP11	\N	2010-09-28 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	démocratie sociale	\N	du 	projet de loi complétant les dispositions relatives à la démocratie sociale issues de la loi n° 2008-789 du 20 août 2008	\N	\N	\N	\N	999	\N	\N
CMP	2010CMP14	\N	2010-10-22 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	réforme des retraites	\N	du 	projet de loi portant réforme des retraites	\N	\N	\N	\N	999	\N	\N
MISINFCOM	TOXICOMANIE	1	2010-10-20 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	TOXICOMANIE	Mission commune d'information sur les toxicomanies	MISSION COMMUNE D'INFORMATION SUR LES TOXICOMANIES	de la 	Mission commune d'information sur les toxicomanies	/commission/missions/toxicomanie/index.html	\N	Mission commune d'information sur les toxicomanies	\N	999	\N	\N
MISINFCOM	SYSTEMESCO  	1	2010-11-17 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	SYSTEME SCOLAIRE	Mission commune d'information sur l'organisation territoriale du système scolaire	MISSION COMMUNE D'INFORMATION SUR L'ORGANISATION TERRITORIALE DU SYSTÈME SCOLAIRE ET SUR L'ÉVALUATION DES EXPÉRIMENTATIONS LOCALES EN MATIÈRE D'ÉDUCATION	de la	Mission commune d'information sur l'organisation territoriale du système scolaire et sur l'évaluation des expérimentations locales en matière d'éducation	/commission/missions/systeme_scolaire/index.html	\N	Mission commune d'information sur l'organisation territoriale du système scolaire	\N	999	\N	2014-04-07 15:43:10
CMP	20061115N50	\N	2006-11-23 00:00:00	2006-11-28 00:00:00	\N	ANCIEN	\N	participation et actionnariat salarié	\N	du	projet de loi pour le développement de la participation et de l'actionnariat salarié	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	2007CMP2	\N	2007-01-25 00:00:00	2007-01-31 00:00:00	\N	ANCIEN	\N	adaptation au droit communautaire dans le domaine du médicament	\N	du	projet de loi portant diverses dispositions d'adaptation au droit communautaire dans le domaine du médicament	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	2010CMP15	\N	2010-11-18 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	financement de la sécurité sociale pour 2011	\N	du 	projet de loi de financement de la sécurité sociale pour 2011	\N	\N	\N	\N	999	\N	\N
MISINFCOM	POLEEMPLOI	1	2011-02-02 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	POLE EMPLOI	Mission commune d'information relative à Pôle Emploi	MISSION COMMUNE D'INFORMATION RELATIVE A POLE EMPLOI	de la 	Mission commune d'information relative à Pôle Emploi	/commission/missions/pole_emploi/index.html	\N	Mission commune d'information relative à Pôle Emploi	\N	999	\N	\N
CMP	2010CMP16	\N	2010-12-07 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	programmation des finances publiques pour les années 2011 à 2014	\N	du 	projet de loi de programmation des finances publiques pour les années 2011 à 2014	\N	\N	\N	\N	999	\N	\N
CMP	2009CMP2	\N	2009-01-26 00:00:00	2009-02-02 00:00:00	\N	ANCIEN	\N	PJL de finances rectificative pour 2009	\N	du 	projet de loi de finances rectificative pour 2009	\N	\N	\N	\N	999	\N	2016-09-15 16:40:05
MISINFCOM	RGPP	1	2011-01-11 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	RGPP	Mission commune d'information sur la RGPP	MISSION COMMUNE D'INFORMATION SUR LES CONSÉQUENCES DE LA RÉVISION GÉNÉRALE DES POLITIQUES PUBLIQUES POUR LES COLLECTIVITÉS TERRITORIALES ET LES SERVICES PUBLICS LOCAUX	de la	Mission commune d'information sur les conséquences de la révision générale des politiques publiques pour les collectivités territoriales et les services publics locaux	/commission/missions/rgpp/index.html	\N	Mission commune d'information sur la RGPP	\N	999	\N	2014-04-07 11:35:22
CMP	2010CMP20	\N	2010-12-17 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	adaptation de la législation au droit communautaire	\N	de la 	proposition de loi portant diverses dispositions d'adaptation de la législation au droit communautaire	\N	\N	\N	\N	999	\N	\N
CMP	2010CMP5	\N	2010-05-20 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	Grand Paris	\N	du 	projet de loi reatif au Grand Paris	\N	\N	\N	\N	999	\N	\N
COMSPE	SURENDETTEME	1	2009-04-29 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	Crédit à la consommation	Commission spéciale sur le crédit à la consommation	COMMISSION SPECIALE SUR LE CREDIT A LA CONSOMMATION	de la	Commission spéciale sur le crédit à la consommation	/commission/spec/Credit_consommation/index.html	\N	Commission spéciale sur le crédit à la consommation	CONSO	999	\N	2014-02-14 10:10:22
CMP	2011CMP1	\N	2011-01-19 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	performance de la sécurité intérieure	\N	du 	projet de loi dorientation et de programmation pour la performance de la sécurité intérieure	\N	\N	\N	\N	999	\N	\N
CMP	2010CMP6	\N	2010-06-02 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	application de l'article 65 de la Constitution	\N	du 	projet de loi organique relatif à l'application de l'article 65 de la Constitution	\N	\N	\N	\N	999	\N	\N
CMP	2011CMP5	\N	2011-02-10 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	défenseur des droits	\N	du 	projet de loi organique relatif au défenseur des droits	\N	\N	\N	\N	999	\N	\N
COMSPE	SERVICE	1	2007-07-05 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	Service minimum	Commission spéciale sur le service minimum	COMMISSION SPECIALE SUR LE PROJET DE LOI RELATIF AU SERVICE MINIMUM	de la	Commission spéciale sur le projet de loi relatif au service minimum	/commission/spec/servicepublic/index.html	\N	Commission spéciale	SPEC	999	\N	2014-04-07 11:23:22
CMP	2007CMP15	\N	2007-12-11 00:00:00	2007-12-13 00:00:00	\N	ANCIEN	\N	Projet de loi de finances pour 2008	\N	du	projet de loi de finances pour 2008	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	2008CMP3	\N	2008-01-31 00:00:00	2008-02-04 00:00:00	\N	ANCIEN	\N	Projet de loi relatif à la rétention de sûreté	\N	du	Projet de loi relatif à la rétention de sûreté et à la déclaration d'irresponsabilité pénale pour cause de trouble mental	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	2009CMP10	\N	2009-07-07 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	fonction publique	\N	du 	projet de loi relatif à la mobilité et aux parcours professionnels dans la fonction publique	\N	\N	\N	\N	999	\N	\N
CMP	2009CMP11	\N	2009-07-08 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	Grenelle de l'environnement	\N	du 	projet de loi de programmation relatif à la mise en oeuvre du Grenelle de l'environnement	\N	\N	\N	\N	999	\N	\N
CMP	2010CMP13	\N	2010-10-19 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	gestion de la dette sociale	\N	du 	projet de loi organique relatif à la gestion de la dette sociale	\N	\N	\N	\N	999	\N	\N
CMP	2010CMP17	\N	2010-12-08 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	PJL finances pour 2011	\N	du 	projet de loi finances pour 2011	\N	\N	\N	\N	999	\N	\N
CMP	2009CMP23	\N	2009-12-22 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	La Poste et activités postables	\N	du 	projet de loi relatif à l'entreprise publique La Poste et aux activités postales	\N	\N	\N	\N	999	\N	\N
CMP	2010CMP8	\N	2010-06-02 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	rénovation du dialogue social et diverses dispositions relatives à la fonction publique	\N	du 	projet de loi relatif à la rénovation du dialogue social et comportant diverses dispositions relatives à la fonction publique	\N	\N	\N	\N	999	\N	\N
CMP	2010CMP18	\N	2010-12-16 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	PLF rectificative pour 2010	\N	du 	projet de loi de finances rectifcative pour 2010	\N	\N	\N	\N	999	\N	\N
CMP	2007CMP14	\N	2007-11-16 00:00:00	2007-11-20 00:00:00	\N	ANCIEN	\N	Projet de loi de financement de la sécurité sociale pour 2008	\N	du	projet de loi de financement de la sécurité sociale pour 2008	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	2008CMP1	\N	2008-01-24 00:00:00	2008-01-29 00:00:00	\N	ANCIEN	\N	pouvoir d'achat	\N	du	projet de loi pour le pouvoir d'achat	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	2008CMP4	\N	2008-04-16 00:00:00	2008-05-13 00:00:00	\N	ANCIEN	\N	Lutte contre les discriminations	\N	du	projet de loi portant diverses dispositions d'adaptation au droit communautaire dans le domaine de la lutte contre les discriminations	\N	\N	\N	\N	999	\N	2016-09-15 16:40:05
CMP	2008CMP7	\N	2008-06-03 00:00:00	2008-06-10 00:00:00	\N	ANCIEN	\N	Lutte contre le trafic de produits dopants	\N	du	projet de loi relatif à la lutte contre le trafic de produits dopants	\N	\N	\N	\N	999	\N	2016-09-15 16:40:05
CMP	2009CMP19	\N	2009-11-16 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	financement de la sécurité sociale pour 2010	\N	du 	projet de loi de financement de la sécurité sociale pour 2010	\N	\N	\N	\N	999	\N	\N
CMP	2009CMP22	\N	2009-12-17 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	loi de finances rectificative pour 2009	\N	du 	projet de loi de finances rectificative pour 2009	\N	\N	\N	\N	999	\N	\N
CMP	2010CMP19	\N	2010-12-17 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	PPL relative aux adaptations de la législation au droit de l'Union européenne	\N	de la 	proposition de loi portant diverses dispositions d'adaptation de la législation au droit de l'Union européenne	\N	\N	\N	\N	999	\N	\N
CMP	2011CMP3	\N	2011-02-10 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	législation au droit de lUnion européenne en matière de santé, de travail et de communications électroniques 	\N	du 	projet de loi portant diverses dispositions dadaptation de la législation au droit de lUnion européenne en matière de santé, de travail et de communications électroniques 	\N	\N	\N	\N	999	\N	\N
CMP	2009CMP16	\N	2009-09-29 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	orientation et formation professionnelle tout au long de la vie	\N	du 	projet de loi relatif à l'orientation et à la formation professionnelle tout au long de la vie	\N	\N	\N	\N	999	\N	\N
CMP	2011CMP2	\N	2011-01-25 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	recherches impliquant la personne humaine	\N	de la 	proposition de loi relative aux recherches impliquant la personne humaine	\N	\N	\N	\N	999	\N	\N
CMP	2008CMP6	\N	2008-05-21 00:00:00	2008-06-03 00:00:00	\N	ANCIEN	\N	Modernisation du marché du travail	\N	du	projet de loi relatif à la modernisation du marché du travail	\N	\N	\N	\N	999	\N	2016-09-15 16:40:05
CMP	2008CMP17	\N	2008-11-13 00:00:00	2009-01-27 00:00:00	\N	ANCIEN	\N	Finances publiques pour les années 2009 à 2012	\N	du	projet de loi de programmation des finances publiques pour les années 2009 à 2012	\N	\N	\N	\N	999	\N	2016-09-15 16:40:05
CMP	2010CMP3	\N	2010-03-31 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	application de l'alinéa 5 de l'art. 13 de la Constitution	\N	des 	projets de loi (organique et ordinaire) relatifs à l'application de l'alinéa 5 de l'article 13 de la Constitution.	\N	\N	\N	\N	999	\N	\N
CMP	2010CMP4	\N	2010-04-08 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	entrepreneur individuel à responsabilité limitée	\N	du 	projet de loi relatif à l'entrepreneur individuel à responsabilité limitée	\N	\N	\N	\N	999	\N	\N
CMP	2010CMP12	\N	2010-10-06 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	collectivités territoriales	\N	du 	projet de loi de réforme des collectivités territoriales	\N	\N	\N	\N	999	\N	\N
CMP	20040709N10	\N	2004-07-09 00:00:00	2004-07-16 00:00:00	\N	ANCIEN	\N	politique de santé publique	\N	du	projet de loi relatif à la politique de santé publique	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
MISINFCOM	MEDIATOR	1	2011-01-11 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	MEDIATOR	Mission commune d'information sur le Médiator	MEDIATOR : EVALUATION ET CONTROLE DES MEDICAMENTS	de la	Mediator : évaluation et contrôle des médicaments	/commission/missions/mediator/index.html	\N	Mission commune d'information sur le Médiator	\N	999	\N	2014-04-07 15:43:10
CMP	2011CMP4	\N	2011-02-10 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	défenseur des droits	\N	du 	projet de loi relatif au défenseur des droits	\N	\N	\N	\N	999	\N	\N
CMP	20061214N53	\N	2006-12-14 00:00:00	2006-12-19 00:00:00	\N	ANCIEN	\N	projet de loi sur l'eau et les milieux aquatiques	\N	du	projet de loi sur l'eau et les milieux aquatiques	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20061219N54	\N	2006-12-19 00:00:00	2006-12-20 00:00:00	\N	ANCIEN	\N	projet de loi de finances rectificative pour 2006	\N	du	projet de loi de finances rectificative pour 2006	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	2008CMP11	\N	2008-07-17 00:00:00	2008-07-22 00:00:00	\N	ANCIEN	\N	droit d'accueil pour les élèves des écoles maternelles	\N	du	projet de loi instituant un droit d'accueil pour les élèves des écoles maternelles et élémentaires publiques pendant le temps scolaire obligatoire	\N	\N	\N	\N	999	\N	2016-09-15 16:40:05
CMP	2008CMP12	\N	2008-07-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	droits et devoirs des demandeurs d'emploi	\N	du	projet de loi relatif aux droits et devoirs des demandeurs d'emploi	\N	\N	\N	\N	999	\N	2016-09-15 16:40:05
CMP	2008CMP13	\N	2008-07-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	rénovation de la démocratie sociale et temps de travail	\N	du	projet de loi portant rénovation de la démocratie sociale et réforme du temps de travail	\N	\N	\N	\N	999	\N	2016-09-15 16:40:05
CMP	2009CMP17	\N	2009-10-07 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	transports	\N	du 	projet de loi relatif à l'organisation et à la régulation des transports ferroviaires et guidés et portant diverses dispositions relatives aux transports	\N	\N	\N	\N	999	\N	\N
MISINFCOM	OUTREMER	1	2009-03-05 00:00:00	2009-07-07 00:00:00	\N	ANCIEN	MCI OUTRE MER	Mission commune d'information "Outre-mer"	MISSION COMMUNE D'INFORMATION SUR LA SITUATION DES DEPARTEMENTS D'OUTRE-MER	de la	Mission commune d'information sur la situation des départements d'outre-mer	/commission/missions/outre_mer/index.html	\N	Mission commune d'information "Outre-mer"	\N	999	\N	2014-02-19 17:47:45
MISINFCOM	DEPENDANCE	0	2007-12-05 00:00:00	2011-01-25 00:00:00	\N	ANCIEN	MCI DEPENDANCE	Mission commune d'information "Dépendance"	MISSION COMMUNE D'INFORMATION SUR LA PRISE EN CHARGE DE LA DEPENDANCE ET LA CREATION DU CINQUIEME RISQUE	de la	Mission commune d'information sur la prise en charge de la dépendance et la création du cinquième risque	/commission/missions/Dependance/index.html	\N	Mission commune d'information "Dépendance"	\N	999	\N	2014-04-07 15:43:10
MISINFCOM	ELECTRICITE	\N	2007-01-10 00:00:00	2007-07-04 00:00:00	\N	ANCIEN	MCI ELECTRICITE	Mission commune d'information "Electricité"	MISSION COMMUNE D'INFORMATION SUR LA SÉCURITÉ D'APPROVISIONNEMENT ÉLECTRIQUE DE LA FRANCE ET LES MOYENS DE LA PRÉSERVER	de la 	Mission commune d'information sur la sécurité d'approvisionnement électrique de la France et les moyens de la préserver	/commission/missions/Electricite/index.html	\N	Mission commune d'information "Electricité"	\N	999	\N	2015-01-14 10:40:17
CMP	20030128N1	\N	2003-01-28 00:00:00	2003-02-04 00:00:00	\N	ANCIEN	\N	Sécurité intérieure	\N	du	projet de loi pour la sécurité intérieure	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20030515N2	\N	2003-05-15 00:00:00	2003-05-22 00:00:00	\N	ANCIEN	\N	Urbanisme, habitat et construction	\N	du	projet de loi portant diverses dispositions relatives à l'urbanisme, à l'habitat et à la construction	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	2008CMP18	\N	2008-12-09 00:00:00	2008-12-15 00:00:00	\N	ANCIEN	\N	PJL de finances pour 2009	\N	du 	projet de loi de finances pour 2009	\N	\N	\N	\N	999	\N	2016-09-15 16:40:05
COMSPE	INITIATIVE	2	2003-02-12 00:00:00	2003-07-21 00:00:00	\N	ANCIEN	INITIATIVE ÉCONOMIQUE	COMMISSION SPÉCIALE "INITIATIVE ÉCONOMIQUE"	COMMISSION SPÉCIALE CHARGÉE D'EXAMINER LE PROJET DE LOI POUR L'INITIATIVE ÉCONOMIQUE	de la	commission spéciale chargée d'examiner le projet de loi pour l'initiative économique	\N	\N	Commission spéciale	INIT	999	\N	2014-02-19 17:47:45
CMP	20030612N3	\N	2003-06-12 00:00:00	2003-06-19 00:00:00	\N	ANCIEN	\N	outre-mer	\N	du	projet de loi de programme pour l'outre-mer	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20030618N4	\N	2003-06-18 00:00:00	2003-06-25 00:00:00	\N	ANCIEN	\N	initiative économique	\N	du	projet de loi pour l'initiative économique	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20030715N6	\N	2003-07-15 00:00:00	2003-07-22 00:00:00	\N	ANCIEN	\N	prévention des risques technologiques et naturels	\N	du	projet de loi relatif à la prévention des risques technologiques et naturels et à la réparation des dommages	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20030626N5	\N	2003-06-26 00:00:00	2003-07-03 00:00:00	\N	ANCIEN	\N	archéologie préventive	\N	du	projet de loi modifiant la loi n° 2001-44 du 17 janvier 2001 relative à l'archéologie préventive	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20030718N7	\N	2003-07-18 00:00:00	2003-07-25 00:00:00	\N	ANCIEN	\N	Réforme des retraites	\N	du	projet de loi portant réforme des retraites	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20030723N8	\N	2003-07-23 00:00:00	2003-07-30 00:00:00	\N	ANCIEN	\N	programmation pour la ville	\N	du	projet de loi d'orientation et de programmation pour la ville et la rénovation urbaine	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
MISINFCOM	MCI	0	2003-10-08 00:00:00	2004-02-03 00:00:00	\N	ANCIEN	Canicule	Mission commune d'information "Canicule"	MISSION COMMUNE D'INFORMATION " LA FRANCE ET LES FRANÇAIS FACE À LA CANICULE : LES LEÇONS D'UNE CRISE "	de la	mission commune d'information "La France et les Français face à la canicule : les leçons d'une crise"	\N	\N	\N	\N	999	\N	2014-04-07 11:23:22
CMP	20031016N9	\N	2003-10-16 00:00:00	2003-10-23 00:00:00	\N	ANCIEN	\N	maîtrise de l'immigration	\N	du	projet de loi relatif à la maîtrise de l'immigration et au séjour des étrangers en France	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20031119N10	\N	2003-11-19 00:00:00	2003-11-26 00:00:00	\N	ANCIEN	\N	financement sécurité sociale pour 2004	\N	du	projet de loi de financement de la sécurité sociale pour 2004	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20031209N11	\N	2003-12-09 00:00:00	2003-12-16 00:00:00	\N	ANCIEN	\N	Projet de loi de finances pour 2004	\N	du	projet de loi de finances pour 2004	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20031217N12	\N	2003-12-16 00:00:00	2003-12-23 00:00:00	\N	ANCIEN	\N	Projet de loi de finances rectificative pour 2003	\N	du	projet de loi de finances rectificative pour 2003	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20040115N1	\N	2004-01-15 00:00:00	2004-01-22 00:00:00	\N	ANCIEN	\N	Polynésie française	\N	du	projet de loi organique portant statut d'autonomie de la Polynésie française et du projet de loi complétant le statut d'autonomie de la Polynésie française	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20040211N3	\N	2004-02-11 00:00:00	2004-02-18 00:00:00	\N	ANCIEN	\N	Formation professionnelle et dialogue social	\N	du	projet de loi relatif à la formation professionnelle tout au long de la vie et au dialogue social	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20040413N4	\N	2004-04-13 00:00:00	2004-04-20 00:00:00	\N	ANCIEN	\N	Economie numérique	\N	du	projet de loi pour la confiance dans l'économie numérique	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20040609N8	\N	2004-06-09 00:00:00	2004-06-16 00:00:00	\N	ANCIEN	\N	Bioéthique	\N	du	projet de loi relatif à la bioéthique	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20040708N9	\N	2004-07-08 00:00:00	2004-07-15 00:00:00	\N	ANCIEN	\N	EDF-GDF	\N	du	projet de loi relatif au service public de l'électricité et du gaz et aux entreprises électriques et gazières	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20040715N11	\N	2004-07-15 00:00:00	2004-07-22 00:00:00	\N	ANCIEN	\N	soutien à la consommation et à l'investissement	\N	du	projet de loi pour le soutien à la consommation et à l'investissement	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20040727N12	\N	2004-07-27 00:00:00	2004-08-03 00:00:00	\N	ANCIEN	\N	assurance maladie	\N	du	projet de loi relatif à l'assurance maladie	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20040727N13	\N	2004-07-27 00:00:00	2004-08-03 00:00:00	\N	ANCIEN	\N	modernisation de la sécurité civile	\N	du	projet de loi de modernisation de la sécurité civile	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20040727N14	\N	2004-07-27 00:00:00	2004-08-03 00:00:00	\N	ANCIEN	\N	libertés et responsabilités locales	\N	du	projet de loi relatif aux libertés et responsabilités locales	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20041118N15	\N	2004-11-18 00:00:00	2004-11-25 00:00:00	\N	ANCIEN	\N	sécurité sociale	\N	du	projet de loi de financement de la sécurité sociale pour 2005	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20040712N16	\N	2004-12-07 00:00:00	2004-12-14 00:00:00	\N	ANCIEN	\N	programmation pour la cohésion sociale	\N	du	projet de loi de programmation pour la cohésion sociale	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20041214N17	\N	2004-12-14 00:00:00	2004-12-21 00:00:00	\N	ANCIEN	\N	loi de finances pour 2005	\N	du	projet de loi de finances pour 2005	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20041221N18	\N	2004-12-20 00:00:00	2004-12-27 00:00:00	\N	ANCIEN	\N	loi de finances rectificative pour 2004	\N	du	projet de loi de finances rectificative pour 2004	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20041022N19	\N	2004-10-20 00:00:00	2004-10-27 00:00:00	\N	ANCIEN	\N	Simplification du droit	\N	du	projet de loi de simplification du droit	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
MISINFCOM	AMIANTE	\N	2005-02-02 00:00:00	2005-10-20 00:00:00	\N	ANCIEN	MCI AMIANTE	Mission commune d'information "Amiante"	MISSION COMMUNE D'INFORMATION SUR LE BILAN ET LES CONSÉQUENCES DE LA CONTAMINATION PAR L'AMIANTE	de la	Mission commune d'information sur le bilan et les conséquences de la contamination par l'amiante	/commission/missions/amiante/index.html	\N	Mission commune d'information "Amiante"	\N	999	\N	2014-04-07 09:57:57
CMP	20050119N20	\N	2005-01-19 00:00:00	2005-01-26 00:00:00	\N	ANCIEN	\N	égalité des droits et des chances, la participation et la citoyenneté des personnes handicapées	\N	du	projet de loi pour l'égalité des droits et des chances, la participation et la citoyenneté des personnes handicapées	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20050127N21	\N	2005-01-27 00:00:00	2005-02-03 00:00:00	\N	ANCIEN	\N	développement des territoires ruraux	\N	du	projet de loi relatif au développement des territoires ruraux	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20050319N22	\N	2005-03-19 00:00:00	2005-03-26 00:00:00	\N	ANCIEN	\N	Avenir de l'école	\N	du	projet de loi d'orientation pour l'avenir de l'école	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20050503N23	\N	2005-05-03 00:00:00	2005-05-10 00:00:00	\N	ANCIEN	\N	Régulation des activités postales	\N	du	projet de loi relatif à la régulation des activités postales	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20050504N24	\N	2005-05-04 00:00:00	2005-05-11 00:00:00	\N	ANCIEN	\N	Assistants maternels et assistants familiaux	\N	du	projet de loi relatif aux assistants maternels et aux assistants familiaux	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20050511N25	\N	2005-05-11 00:00:00	2005-05-18 00:00:00	\N	ANCIEN	\N	énergie	\N	du	projet de loi d'orientation sur l'énergie	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20050630N27	\N	2005-06-30 00:00:00	2005-07-07 00:00:00	\N	ANCIEN	\N	sauvegarde des entreprises	\N	du	projet de loi de sauvegarde des entreprises	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20050707N29	\N	2005-07-07 00:00:00	2005-07-14 00:00:00	\N	ANCIEN	\N	mesures d'urgence pour l'emploi	\N	du	projet de loi habilitant le Gouvernement à prendre, par ordonnances, des mesures d'urgence pour l'emploi	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20050707N30	\N	2005-07-07 00:00:00	2005-07-14 00:00:00	\N	ANCIEN	\N	petites et moyennes entreprises	\N	du	projet de loi en faveur des petites et moyennes entreprises	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	20050629N26	\N	2005-06-29 00:00:00	2005-07-06 00:00:00	\N	ANCIEN	\N	cohésion sociale	\N	du	projet de loi relatif au développement des services à la personne et portant diverses mesures en faveur de la cohésion sociale	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	2013CMP11	\N	2013-07-12 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	Règlement et approbation des comptes de lannée 	\N	du	projet de loi de règlement et dapprobation des comptes de lannée 	\N	\N	\N	\N	999	\N	\N
CMP	2013CMP12	\N	2013-07-12 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	Adaptation dans le domaine de la justice en application du droit de lUnion européenne et des engagements de la France	\N	du	projet de loi portant diverses dispositions dadaptation dans le domaine de la justice en application du droit de lUnion européenne et des engagements internationaux de la France 	\N	\N	\N	\N	999	\N	\N
CMP	2013CMP15	\N	2013-07-18 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	Lutte contre la fraude fiscale et la grande délinquance économique 	\N	du	projet de loi relatif à la lutte contre la fraude fiscale et la grande délinquance économique 	\N	\N	\N	\N	999	\N	\N
CMP	2013CMP16	\N	2013-07-18 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	Procureur de la République financier	\N	du	projet de loi organique relatif au procureur de la République financier	\N	\N	\N	\N	999	\N	\N
MISINFCOM	FORMATION	\N	2007-01-10 00:00:00	2007-07-11 00:00:00	\N	ANCIEN	MCI FORMATION	Mission commune d'information "Formation professionnelle"	MISSION COMMUNE D'INFORMATION SUR LE FONCTIONNEMENT DES DISPOSITIFS DE FORMATION PROFESSIONNELLE	de la 	Mission commune d'information sur le fonctionnement des dispositifs de formation professionnelle	/commission/missions/Formation/index.html	\N	Mission commune d'information "Formation professionnelle"	\N	999	\N	2015-01-14 10:41:26
CMP	2007CMP3	\N	2007-02-01 00:00:00	2007-02-13 00:00:00	\N	ANCIEN	\N	modernisation de la diffusion audiovisuelle et à la télévisi	\N	du	projet de loi relatif à la modernisation de la diffusion audiovisuelle et à la télévision du futur	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	2007CMP4	\N	2007-02-07 00:00:00	2007-02-16 00:00:00	\N	ANCIEN	\N	recrutement, formation et responsabilité des magistrats	\N	du	projet de loi organique relatif au recrutement, à la formation et à la responsabilité des magistrats	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	2007CMP6	\N	2007-02-15 00:00:00	2007-02-20 00:00:00	\N	ANCIEN	\N	réforme de la protection juridique des majeurs	\N	du	projet de loi portant réforme de la protection juridique des majeurs	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	2007CMP8	\N	2007-02-20 00:00:00	2007-02-22 00:00:00	\N	ANCIEN	\N	diverses mesures en faveur de la cohésion sociale	\N	du	projet de loi instituant le droit au logement opposable et portant diverses mesures en faveur de la cohésion sociale	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	2007CMP17	\N	2007-12-18 00:00:00	2007-12-19 00:00:00	\N	ANCIEN	\N	projet de loi de finances rectificative pour 2007	\N	du	projet de loi de finances rectificative pour 2007	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	2008CMP5	\N	2008-05-14 00:00:00	2008-05-14 00:00:00	\N	ANCIEN	\N	Organismes génétiquement modifiés	\N	du	projet de loi relatif aux organismes génétiquement modifiés	\N	\N	\N	\N	999	\N	2016-09-15 16:40:05
CMP	2009CMP5	\N	2009-04-02 00:00:00	2009-04-09 00:00:00	\N	ANCIEN	\N	PJL de finances rectificative pour 2009	\N	du	deuxième projet de loi de finances rectificative pour 2009	\N	\N	\N	\N	999	\N	2016-09-15 16:40:05
CMP	2010CMP9	\N	2010-07-06 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	PJL relatif à l'action extérieure de l'Etat	\N	du 	projet de loi relatif à l'action extérieure de l'Etat	\N	\N	\N	\N	999	\N	\N
CMP	2011CMP6	\N	2011-03-31 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	prix du livre numérique	\N	de la 	proposition de loi relative au prix du livre numérique 	\N	\N	\N	\N	999	\N	\N
MISINFCOM	JEUNES	1	2009-03-11 00:00:00	2009-10-08 00:00:00	\N	ANCIEN	Politique en faveur des jeunes	Mission commune d'information sur la politique en faveur des jeunes	MISSION COMMUNE D'INFORMATION SUR LA POLITIQUE EN FAVEUR DES JEUNES	de la	Mission commune d'information sur la politique en faveur des jeunes	/commission/missions/jeunes/index.html	\N	Mission commune d'information sur la politique en faveur des jeunes	\N	999	\N	2014-04-07 11:11:43
COMSPE	FORMATIONPRO	1	2009-07-07 00:00:00	2009-10-14 00:00:00	\N	ANCIEN	Formation professionnelle	Commission spéciale sur l'orientation et la formation professionnelle tout au long de la vie	COMMISSION SPÉCIALE SUR L'ORIENTATION ET LA FORMATION PROFESSIONNELLE TOUT AU LONG DE LA VIE	de la 	Commission spéciale sur l'orientation et la formation professionnelle tout au long de la vie	/commission/spec/formation_professionnelle/index.html	\N	Commission spéciale sur l'orientation et la formation professionnelle tout au long de la vie	PROF	999	\N	2014-04-07 11:23:22
MISINFCOM	PAUVRETE	\N	2008-01-10 00:00:00	2008-07-07 00:00:00	\N	ANCIEN	MCI PAUVRETE	Mission commune d'information "Pauvreté"	MISSION COMMUNE D'INFORMATION SUR LES POLITIQUES DE LUTTE CONTRE LA PAUVRETÉ ET L'EXCLUSION	de la 	Mission commune d'information sur les politiques de lutte contre la pauvreté et l'exclusion	/commission/missions/Pauvrete/index.html	\N	Mission commune d'information "Pauvreté"	\N	999	\N	\N
CMP	2009CMP14	\N	2009-09-29 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	projet de loi pénitentiaire	\N	du 	projet de loi pénitentiaire	\N	\N	\N	\N	999	\N	\N
CMP	2009CMP15	\N	2009-09-29 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	évolution de la situation des ouvriers des parcs et ateliers	\N	du 	projet de loi relatif au transfert aux départements des parcs de l'équipement et à l'évolution de la situation des ouvriers des parcs et ateliers	\N	\N	\N	\N	999	\N	\N
CMP	2009CMP18	\N	2009-11-06 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	Victimes des essais nucléaires	\N	du 	projet de loi relatif à la reconnaissance et à l'indemnisation des victimes des essais nucléaires français	\N	\N	\N	\N	999	\N	\N
CMP	2009CMP20	\N	2009-12-08 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	projet de loi de finances pour 2010	\N	du 	projet de loi de finances pour 2010	\N	\N	\N	\N	999	\N	\N
COMEUR	AFEU	1	2008-10-08 00:00:00	\N	\N	ACTIF	AFEU	Affaires européennes	COMMISSION DES AFFAIRES EUROPÉENNES	de la 	commission des affaires européennes	/europe/broch.html	\N	commission des affaires européennes	AFEU	999	\N	\N
MISCOM	COLLECTIVITE	0	2008-10-15 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	Mission collectivités	Mission temporaire collectivités territoriales	MISSION TEMPORAIRE SUR L'ORGANISATION ET L'EVOLUTION DES COLLECTIVITÉS TERRITORIALES	de la	Mission temporaire sur l'organisation et l'évolution des collectivités territoriales	/mission_temporaire_coll_ter/index.html	\N	Mission temporaire collectivités territoriales	\N	999	\N	2014-04-07 15:43:10
CMP	2008CMP16	\N	2008-11-20 00:00:00	2008-11-25 00:00:00	\N	ANCIEN	\N	financement de la sécurité sociale pour 2009	\N	du	projet de loi de financement de la sécurité sociale pour 2009	\N	\N	\N	\N	999	\N	2016-09-15 16:40:05
CMP	2009CMP3	\N	2009-02-27 00:00:00	2009-02-27 00:00:00	\N	ANCIEN	\N	projet de loi pour l'accélération des programmes de construc	\N	du	projet de loi pour l'accélération des programmes de construction et d'investissement publics et privés	\N	\N	\N	\N	999	\N	2016-09-15 16:40:05
CMP	2009CMP4	\N	2009-02-11 00:00:00	2009-02-17 00:00:00	\N	ANCIEN	\N	mobilisation pour le logement et lutte contre l'exclusion	\N	du	projet de loi de mobilisation pour le logement et lutte contre l'exclusion	\N	\N	\N	\N	999	\N	2016-09-15 16:40:05
CMP	2009CMP7	\N	2009-04-28 00:00:00	2009-05-05 00:00:00	\N	ANCIEN	\N	développement économique des outre-mer	\N	du	projet de loi pour le développement économique des outre-mer	\N	\N	\N	\N	999	\N	2016-09-15 16:40:05
MISINFCOM	DECHETS	\N	2009-10-14 00:00:00	2010-06-28 00:00:00	\N	ANCIEN	MCI Dechets	MCI sur le traitement des déchets	MISSION COMMUNE D'INFORMATION SUR LE TRAITEMENT DES DECHETS	de la	Mission commune d'information sur le traitement des déchets	/commission/missions/dechets/index.html	\N	Misson commune d'information sur le traitement des déchets	\N	999	\N	2015-01-14 10:42:06
CMP	2009CMP21	\N	2009-12-17 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	PPL visant à rendre obligatoire l'installation de détecteurs de fumée dans tous les lieux d'habitation	\N	de la 	proposition de loi visant à rendre obligatoire l'installation de détecteurs de fumée dans tous les lieux d'habitation	\N	\N	\N	\N	999	\N	\N
COMSPE	GRANDPARIS	1	2009-12-09 00:00:00	2011-04-08 00:00:00	\N	ANCIEN	GRAND PARIS	Commission spéciale sur le Grand Paris	COMMISSION SPÉCIALE SUR LE GRAND PARIS	de la 	Commission spéciale sur le Grand Paris	/commission/spec/grand_paris/index.html	\N	Commission spéciale sur le Grand Paris	PARIS	999	\N	2014-04-07 09:57:57
COMENQ	GRIPPEA	\N	2010-02-17 00:00:00	2010-08-05 00:00:00	\N	ANCIEN	GRIPPE A	Commission d'enquête sur le rôle des firmes pharmaceutiques dans la gestion par le Gouvernement de la grippe A (H1N1)v	COMMISSION D'ENQUÊTE SUR LE RÔLE DES FIRMES PHARMACEUTIQUES DANS LA GESTION PAR LE GOUVERNEMENT DE LA GRIPPE A (H1N1)v	de la 	Commission d'enquête sur le rôle des firmes pharmaceutiques dans la gestion par le Gouvernement de la grippe A (H1N1)v	/commission/enquete/Grippe/index.html	\N	Commission d'enquête sur le rôle des firmes pharmaceutiques dans la gestion par le Gouvernement de la grippe A (H1N1)v	\N	999	\N	\N
CMP	2010CMP1	\N	2010-02-16 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	loi de finances rectificative pour 2010	\N	du 	projet de loi de finances rectificative pour 2010	\N	\N	\N	\N	999	\N	\N
CMP	2010CMP2	\N	2010-02-18 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	risque de récidive criminelle	\N	du 	projet de loi tendant à amoindrir le risque de récidive criminelle et portant diverses dispositions de procédure pénale	\N	\N	\N	\N	999	\N	\N
MISINFCOM	XYNTHIA	\N	2010-03-30 00:00:00	2010-07-09 00:00:00	\N	ANCIEN	Tempête Xynthia	Mission commune d'information sur les conséquences de la tempête Xynthia	MISSION COMMUNE D'INFORMATION SUR LES CONSÉQUENCES DE LA TEMPÊTE XYNTHIA	de la	Mission commune d'information sur les conséquences de la tempête Xynthia	/commission/missions/xynthia/index.html	\N	Mission commune d'information sur les conséquences de la tempête Xynthia	\N	999	\N	2014-04-07 15:43:10
CMP	2009CMP6	\N	2009-04-02 00:00:00	2009-04-07 00:00:00	\N	ANCIEN	\N	diffusion et  protection de la création sur internet	\N	du	projet de loi favorisant la diffusion et la protection de la création sur internet	\N	\N	\N	\N	999	\N	2016-09-15 16:40:05
CMP	2009CMP12	\N	2009-07-21 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	Nouvelle-Calédonie et Mayotte	\N	du 	projet de loi organique relatif à l'évolution institutionnelle de la Nouvelle-Calédonie et de Mayotte et du projet de loi relatif à l'évolution institutionnelle de la Nouvelle-Calédonie et portant ratification d'ordonnances 	\N	\N	\N	\N	999	\N	\N
MISINFCOM	DESINDUSTRI	1	2010-04-28 00:00:00	2011-04-05 00:00:00	\N	ANCIEN	DESINDUSTRIALISATION DES TERRITOIRES	Mission commune d'information sur la désindustrialisation des territoires	MISSION COMMUNE D'INFORMATION SUR LA DÉSINDUSTRIALISATION DES TERRITOIRES	de la	Mission commune d'information sur la désindustrialisation des territoires	/commission/missions/desindustrialisation/index.html	\N	Mission commune d'information sur la désindustrialisation des territoires	\N	999	\N	2014-04-07 11:33:04
CMP	2010CMP7	\N	2010-05-26 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	engagement national pour l'environnement	\N	du 	projet de loi portant engagement national pour l'environnement	\N	\N	\N	\N	999	\N	\N
CMP	2011CMP7	\N	2011-04-27 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	immigration, intégration et nationalité	\N	du 	projet de loi relatif à l'immigration, à l'intégration et à la nationalité	\N	\N	\N	\N	999	\N	\N
CMP	2011CMP8	\N	2011-06-14 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	fracturation hydraulique 	\N	de la 	Proposition de loi visant à interdire lexploration et lexploitation des mines dhydrocarbures liquides ou gazeux par fracturation hydraulique 	\N	\N	\N	\N	999	\N	\N
CMP	2011CMP9	\N	2011-06-14 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	bioéthique	\N	du 	projet de loi relatif à la bioéthique 	\N	\N	\N	\N	999	\N	\N
CMP	2011CMP10	\N	2011-06-21 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	ventes de meubles aux enchères publiques	\N	de la 	proposition de loi de libéralisation des ventes volontaires de meubles aux enchêres publiques	\N	\N	\N	\N	999	\N	\N
MISINFCOM	TAXEPRO	\N	2011-06-28 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	Taxe professionnelle	Suppression de la taxe professionnelle et son remplacement par la contribution économique territoriale	MISSION COMMUNE D'INFORMATION SUR LES CONSÉQUENCES POUR LES COLLECTIVITÉS TERRITORIALES, L'ETAT ET LES ENTREPRISES DE LA SUPPRESSION DE LA TAXE PROFESSIONNELLE ET DE SON REMPLACEMENT PAR LA CONTRIBUTION ÉCONOMIQUE TERRITORIALE	de la	Mission commune d'information sur les conséquences pour les collectivités territoriales, l'Etat et les entreprises de la suppression de la taxe professionnelle et de son remplacement par la contribution économique territoriale	/commission/missions/taxe_professionnelle/index.html	\N	Suppression de la taxe professionnelle et son remplacement par la contribution économique territoriale	\N	999	\N	2014-04-07 15:43:10
CMP	2012CMP1	\N	2011-12-21 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	protection de l'identité	\N	de la 	proposition de loi relative à la protection de l'identité	\N	\N	\N	\N	999	\N	\N
CMP	2012CMP18	\N	2012-11-06 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	programmation et gouvernance des finances publiques 	\N	du	projet de loi organique relatif à la programmation et à la gouvernance des finances publiques 	\N	\N	\N	\N	999	\N	\N
CMP	2012CMP22	\N	2012-11-27 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	programmation des finances publiques pour les années 2012 à 2017 	\N	du	projet de loi de programmation des finances publiques pour les années 2012 à 2017 	\N	\N	\N	\N	999	\N	\N
CMP	2012CMP23	\N	2012-11-29 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	loi de finances pour 2013	\N	du	projet de loi de finances pour 2013	\N	\N	\N	\N	999	\N	\N
MISINFCOM	DECE	\N	2013-04-23 00:00:00	2013-10-09 00:00:00	\N	ANCIEN	MCI Organisation décentralisée 	Mission commune d'information sur l'avenir de l'organisation décentralisée de la République	MISSION COMMUNE D'INFORMATION SUR L'AVENIR DE L'ORGANISATION DÉCENTRALISÉE DE LA RÉPUBLIQUE	de la	Mission commune d'information sur l'avenir de l'organisation décentralisée de la République	/commission/missions/organisation_decentralisee_de_la_republique/index.html	\N	Mission commune d'information sur l'avenir de l'organisation décentralisée de la République	\N	999	\N	2014-04-14 14:34:35
CMP	2012CMP4	\N	2012-01-12 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	simplification du droit et à lallègement des démarches administratives 	\N	de la 	proposition de loi relative à la simplification du droit et à lallègement des démarches administratives 	\N	\N	\N	\N	999	\N	\N
CMP	2013CMP5	\N	2013-04-10 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	Iinfrastructures et services de transports 	\N	du	projet de loi portant diverses dispositions en matière dinfrastructures et de services de transports 	\N	\N	\N	\N	999	\N	\N
CMP	2012CMP2	\N	2011-12-21 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	statut de la magistrature	\N	du 	projet de loi organique portant diverses dispositions relatives au statut de la magistrature	\N	\N	\N	\N	999	\N	\N
CMP	2012CMP12	\N	2012-02-28 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	mobilisation du foncier en faveur du logement	\N	du 	projet de loi de mobilisation du foncier en faveur du logement	\N	\N	\N	\N	999	\N	\N
CMP	2012CMP13	\N	2012-07-24 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	harcèlement sexuel	\N	du	projet de loi relatif au harcèlement sexuel	\N	\N	\N	\N	999	\N	\N
COMENQ	DOPAGE	\N	2013-02-26 00:00:00	2013-07-19 00:00:00	\N	ANCIEN	Commission d'enquête sur le dopage	Commission d'enquête sur l'efficacité de la lutte contre le dopage	COMMISSION D'ENQUÊTE SUR L'EFFICACITÉ DE LA LUTTE CONTRE LE DOPAGE	de la	Commission d'enquête sur l'efficacité de la lutte contre le dopage	/commission/enquete/dopage/index.html	\N	Commission d'enquête sur l'efficacité de la lutte contre le dopage	\N	999	\N	2015-01-14 10:45:36
CMP	2012CMP5	\N	2012-01-25 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	commémoration du 11 novembre	\N	du 	projet de loi fixant au 11 novembre la commémoration de tous les morts pour la France	\N	\N	\N	\N	999	\N	\N
CMP	2012CMP6	\N	2012-01-25 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	exploitation numérique des livres indisponibles du XXe siècle 	\N	de la 	proposition de loi relative à lexploitation numérique des livres indisponibles du XXe siècle	\N	\N	\N	\N	999	\N	\N
CMP	2012CMP7	\N	2012-01-26 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	réforme des ports doutre-mer 	\N	du 	projet de loi portant réforme des ports doutre-mer relevant de lEtat et diverses dispositions dadaptation de la législation au droit de lUnion européenne dans le domaine des transports 	\N	\N	\N	\N	999	\N	\N
CMP	2012CMP14	\N	2012-07-26 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	loi de finances rectificative pour 2012	\N	du 	projet de loi de finances rectificative pour 2012	\N	\N	\N	\N	999	\N	\N
MISINFCOM	PESTICIDES	\N	2012-02-15 00:00:00	2013-01-08 00:00:00	\N	ANCIEN	Mission commune d'information portant sur les pesticides	Mission commune d'information portant sur les pesticides	MISSION COMMUNE D'INFORMATION PORTANT SUR LES PESTICIDES ET LEUR IMPACT SUR L'ENVIRONNEMENT ET LA SANTÉ	de la	Mission commune d'information portant sur les pesticides et leur impact sur l'environnement et la santé	/commission/missions/pesticides/index.html	\N	Mission commune d'information portant sur les pesticides et leur impact sur l'environnement et la santé	\N	999	\N	2015-01-14 10:44:55
CMP	2012CMP8	\N	2012-02-08 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	mise en uvre de la loi n° 2009-1436 du 24 novembre 2009 pénitentiaire	\N	du 	projet de loi de programmation relatif aux moyens nécessaires à la mise en uvre de la loi n° 2009-1436 du 24 novembre 2009 pénitentiaire 	\N	\N	\N	\N	999	\N	\N
COMENQ	BANQ	\N	2013-04-23 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	CE sur le rôle des banques et acteurs financiers	Commission d'enquête sur le rôle des banques et acteurs financiers dans l'évasion des ressources financières	COMMISSION D'ENQUÊTE SUR LE RÔLE DES BANQUES ET ACTEURS FINANCIERS DANS L'ÉVASION DES RESSOURCES FINANCIÈRES EN SES CONSÉQUENCES FISCALES ET SUR LES ÉQUILIBRES ÉCONOMIQUES AINSI QUE SUR L'EFFICACITÉ DU DISPOSITIF LÉGISLATIF, JURIDIQUE ET ADMINISTRATIF DESTINÉ À LA COMBATTRE	de la	Commission d'enquête sur le rôle des banques et acteurs financiers dans l'évasion des ressources financières en ses conséquences fiscales et sur les équilibres économiques ainsi que sur l'efficacité du dispositif législatif, juridique et administratif destiné à la combattre	/commission/enquete/role_des_banques_et_acteurs_financiers_dans_levasion_des_ressources_financieres/index.html	\N	Commission d'enquête sur le rôle des banques et acteurs financiers dans l'évasion des ressources financières	\N	999	\N	2015-01-14 10:44:21
COM	CAE	1	2012-02-21 00:00:00	\N	\N	ACTIF	CAE	Affaires économiques	COMMISSION DES AFFAIRES ÉCONOMIQUES	de la 	commission des affaires économiques	/commission/affaires_economiques/index.html	\N	commission des affaires économiques	AFFECO	152	\N	2014-01-31 14:44:16
COMENQ	SECTES	\N	2012-10-02 00:00:00	2013-06-11 00:00:00	\N	ANCIEN	Commission d'enquête sur les sectes	Commission d'enquête sur l'influence des mouvements à caractère sectaire dans le domaine de la santé	COMMISSION D'ENQUÊTE SUR L'INFLUENCE DES MOUVEMENTS À CARACTÈRE SECTAIRE DANS LE DOMAINE DE LA SANTÉ 	de la	Commission d'enquête sur l'influence des mouvements à caractère sectaire dans le domaine de la santé	/commission/enquete/sectes/index.html	\N	Commission d'enquête sur l'influence des mouvements à caractère sectaire dans le domaine de la santé	\N	999	\N	2015-01-14 10:45:25
CMP	2012CMP15	\N	2012-09-26 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	création d'emplois d'avenir	\N	du	projet de loi portant création d'emplois d'avenir	\N	\N	\N	\N	999	\N	\N
MISINFCOM	ACTION	\N	2013-03-13 00:00:00	2013-10-30 00:00:00	\N	ANCIEN	Mission commune d'information recherche pour développement	Mission commune d'information sur l'action extérieure de la France en matière de recherche pour le développement	MISSION COMMUNE D'INFORMATION SUR L'ACTION EXTÉRIEURE DE LA FRANCE EN MATIÈRE DE RECHERCHE POUR LE DÉVELOPPEMENT	de la 	Mission commune d'information sur l'action extérieure de la France en matière de recherche pour le développement	/commission/missions/recherche_et_developpement/index.html	\N	Mission commune d'information sur l'action extérieure de la France en matière de recherche pour le développement	\N	999	\N	2014-11-18 15:43:02
COMENQ	COUTELEC	\N	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	Commission d'enquête sur le coût réel de l'électricité	Commission d'enquête sur le coût réel de l'électricité	COMMISSION D'ENQUÊTE SUR LE COÛT RÉEL DE L'ÉLECTRICITÉ AFIN D'EN DÉTERMINER L'IMPUTATION AUX DIFFÉRENTS AGENTS ÉCONOMIQUES	de la	Commission d'enquête sur le coût réel de l'électricité afin d'en déterminer l'imputation aux différents agents économiques	/commission/enquete/cout_electricite/index.html	\N	Commission d'enquête sur le coût réel de l'électricité	\N	999	\N	2015-01-14 10:45:11
CMP	2012CMP21	\N	2012-11-29 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	sécurité et lutte contre le terrorime	\N	du	projet de loi relatif à la sécurité et à la lutte contre le terrorime	\N	\N	\N	\N	999	\N	\N
MISINFCOM	AGENCES	\N	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	MCI Agences de notation	MCI sur le fonctionnement, la méthodologie et la crédibilité des agences de notation	MISSION COMMUNE D'INFORMATION SUR LE FONCTIONNEMENT, LA MÉTHODOLOGIE ET LA CRÉDIBILITÉ DES AGENCES DE NOTATION	de la	Mission commune d'information sur le fonctionnement, la méthodologie et la crédibilité des agences de notation	/commission/missions/agences_notation/index.html	\N	Mission commune d'information sur le fonctionnement, la méthodologie et la crédibilité des agences de notation	\N	999	\N	2013-12-16 10:13:16
MISINFCOM	IMPLANTS	\N	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	MCI Dispositifs médicaux implantables	Mission commune d'information portant sur les dispositifs médicaux implantables et les interventions à visée esthétique	MISSION COMMUNE D'INFORMATION PORTANT SUR LES DISPOSITIFS MÉDICAUX IMPLANTABLES ET LES INTERVENTIONS À VISÉE ESTHÉTIQUE	de la 	Mission commune d'information portant sur les dispositifs médicaux implantables et les interventions à visée esthétique	/commission/missions/implants/index.html	\N	Mission commune d'information portant sur les dispositifs médicaux implantables et les interventions à visée esthétique	\N	999	\N	2013-12-16 10:00:00
MISINFCOM	INONDATIONS	\N	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	MCI Inondations dans le sud est	MCI Inondations dans le sud-est de la France	MISSION COMMUNE D'INFORMATION SUR LES INONDATIONS QUI SE SONT PRODUITES DANS LE VAR, ET PLUS LARGEMENT, DANS LE SUD-EST DE LA FRANCE AU MOIS DE NOVEMBRE 2011	de la	Mission commune d'information sur les inondations qui se sont produites dans le Var, et plus largement, dans le sud-est de la France au mois de novembre 2011	/commission/missions/inondations/index.html	\N	Mission commune d'information sur les inondations qui se sont produites dans le Var, et plus largement, dans le sud-est 	\N	999	\N	2014-04-07 15:43:10
CMP	2012CMP11	\N	2012-02-22 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	loi de finances rectificative pour 2012 	\N	du 	projet de loi de finances rectificative pour 2012 	\N	\N	\N	\N	999	\N	\N
MISINFCOM	VIANDE	\N	2013-03-13 00:00:00	2013-07-19 00:00:00	\N	ANCIEN	Mission commune d'information sur la filière viande	Mission commune d'information sur la filière viande en France et en Europe : élevage, abattage et distribution	MISSION COMMUNE D'INFORMATION SUR LA FILIÈRE VIANDE EN FRANCE ET EN EUROPE : ÉLEVAGE, ABATTAGE ET DISTRIBUTION	de la	Mission commune d'information sur la filière viande en France et en Europe : élevage, abattage et distribution	/commission/missions/filiere_viande/index.html	\N	Mission commune d'information sur la filière viande en France et en Europe : élevage, abattage et distribution	\N	999	\N	2015-01-14 10:46:55
CMP	2013CMP4	\N	2013-04-04 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	réforme de la biologie médicale	\N	de la 	proposition de loi portant réforme de la biologie médicale.	\N	\N	\N	\N	999	\N	\N
COMENQ	EVASION	\N	2012-02-01 00:00:00	2012-07-17 00:00:00	\N	ANCIEN	Evasion des capitaux et des actifs	Commission d'enquête sur l'évasion des capitaux et des actifs hors de France et ses incidences fiscales	COMMISSION D'ENQUÊTE SUR L'ÉVASION DES CAPITAUX ET DES ACTIFS HORS DE FRANCE ET SES INCIDENCES FISCALES	de la 	Commission d'enquête sur l'évasion des capitaux et des actifs hors de France et ses incidences fiscales	/commission/enquete/evasionfiscale/index.html	\N	Commission d'enquête sur l'évasion des capitaux et des actifs hors de France et ses incidences fiscales	\N	999	\N	2015-01-14 10:43:03
CMP	2012CMP10	\N	2012-02-15 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	information des passagers dans les entreprises de transport aérien 	\N	de la 	proposition de loi relative à lorganisation du service et à linformation des passagers dans les entreprises de transport aérien de passagers 	\N	\N	\N	\N	999	\N	\N
CMP	2012CMP17	\N	2012-10-23 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	régulation économique outre-mer 	\N	du	projet de loi relatif à la régulation économique outre-mer et portant diverses dispositions relatives à l'outre-mer	\N	\N	\N	\N	999	\N	\N
CMP	2013CMP1	\N	2013-02-06 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	création du contrat de génération 	\N	du	projet de loi portant création du contrat de génération 	\N	\N	\N	\N	999	\N	\N
CMP	2013CMP3	\N	2013-04-02 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	élection des conseillers municipaux, des conseillers communautaires et des conseillers départementaux 	\N	du	projet de loi organique relatif  à lélection des conseillers municipaux, des conseillers communautaires et des conseillers départementaux 	\N	\N	\N	\N	999	\N	\N
CMP	2012CMP20	\N	2012-11-28 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	mise en uvre du principe de participation du public défini à larticle 7 de la charte de lenvironnement.	\N	du	projet de loi relatif à la mise en uvre du principe de participation du public défini à larticle 7 de la charte de lenvironnement 	\N	\N	\N	\N	999	\N	\N
CMP	2013CMP2	\N	2013-04-02 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	élection des conseillers départementaux, des conseillers municipaux et des conseillers communautaires	\N	du	projet de loi relatif  à lélection des conseillers départementaux, des conseillers municipaux et des conseillers communautaires, et modifiant le calendrier électoral 	\N	\N	\N	\N	999	\N	\N
CMP	2013CMP25	\N	2013-10-16 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	Application de larticle 11 de la Constitution 	\N	du	projet de loi portant application de larticle 11 de la Constitution 	\N	\N	\N	\N	999	\N	\N
COM	CDD	4	2012-02-21 00:00:00	\N	\N	ACTIF	CDD	Développement durable	COMMISSION DE L'AMÉNAGEMENT DU TERRITOIRE ET DU DÉVELOPPEMENT DURABLE	de la 	commission de l'aménagement du territoire et du développement durable	/commission/dvpt_durable/index.html	\N	commission de l'aménagement du territoire et du développement durable	DEVDUR	158	\N	2015-09-11 10:46:47
CMP	2012CMP9	\N	2012-02-15 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	agents contractuels dans le fonction publique	\N	du 	projet de loi relatif à l'accès à l'emploi titulaire et à l'amélioration des conditions d'emploi des agents contractuels dans la fonction publique, à la lutte contre les discriminations et portant diverses dispositions relatives à la fonction publique.	\N	\N	\N	\N	999	\N	\N
CMP	2011CMP27	\N	2011-12-19 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	convention entre la France et Panama en vue déviter les doubles impositions et de prévenir lévasion et la fraude fisca	\N	du 	projet de loi autorisant lapprobation de la convention entre la France et Panama en vue déviter les doubles impositions et de prévenir lévasion et la fraude fiscale 	\N	\N	\N	\N	999	\N	\N
CMP	2012CMP3	\N	2012-01-12 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	dépenses de campagne de lélection présidentielle 	\N	du 	projet de loi organique relatif au remboursement des dépenses de campagne de lélection présidentielle	\N	\N	\N	\N	999	\N	\N
CMP	2012CMP16	\N	2012-10-01 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	logement social	\N	du	projet de loi relatif à la mobilisation du foncier public en faveur du logement et au renforcement des obligations de production de logement social 	\N	\N	\N	\N	999	\N	\N
CMP	2012CMP24	\N	2012-12-13 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	création de la Banque publique dinvestissement 	\N	du	projet de loi relatif à la création de la Banque publique dinvestissement 	\N	\N	\N	\N	999	\N	\N
CMP	2012CMP25	\N	2012-12-13 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	droit au séjour et délit daide au séjour irrégulier pour en exclure les actions humanitaires 	\N	du	projet de loi relatif à la retenue pour vérification du droit au séjour et modifiant le délit daide au séjour irrégulier pour en exclure les actions humanitaires et désintéressées 	\N	\N	\N	\N	999	\N	\N
CMP	2012CMP26	\N	2012-12-15 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	loi de finances rectificative pour 2012	\N	du	projet de loi de finances rectificative pour 2012	\N	\N	\N	\N	999	\N	\N
CMP	2012CMP27	\N	2012-12-18 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	transition vers un système énergétique sobre 	\N	de la	proposition de loi visant à préparer la transition vers un système énergétique sobre 	\N	\N	\N	\N	999	\N	\N
CMP	2012CMP19	\N	2012-11-20 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	financement de la sécurité sociale pour 2013 	\N	du	projet de loi de financement de la sécurité sociale pour 2013 	\N	\N	\N	\N	999	\N	\N
MISINFCOM	SPORTS	1	2013-10-02 00:00:00	2014-05-01 00:00:00	\N	ANCIEN	MCI Sport professionnel et collectivités territoriales	Mission commune d'information sur le sport professionnel et les collectivités territoriales	MISSION COMMUNE D'INFORMATION SUR LE SPORT PROFESSIONNEL ET LES COLLECTIVITÉS TERRITORIALES	de la 	Mission commune d'information sur le sport professionnel et les collectivités territoriales	/commission/missions/sport_professionnel_et_collectivites_territoriales/index.html	\N	Mission commune d'information sur le sport professionnel et les collectivités territoriales	\N	999	\N	2015-01-14 10:47:15
CMP	2013CMP6	\N	2013-04-17 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	Sécurisation de lemploi 	\N	du	projet de loi relatif à la sécurisation de lemploi 	\N	\N	\N	\N	999	\N	\N
CMP	2013CMP7	\N	2013-05-16 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	Représentation des Français hors de France 	\N	du	projet de loi relatif à la représentation des Français hors de France 	\N	\N	\N	\N	999	\N	\N
CMP	2013CMP8	\N	2013-06-05 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	Droit de lUnion européenne dans le domaine du développement	\N	du	projet de loi portant diverses dispositions dadaptation au droit de lUnion européenne dans le domaine du développement durable 	\N	\N	\N	\N	999	\N	\N
CMP	2013CMP9	\N	2013-06-21 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	Enseignement supérieur et recherche 	\N	du	projet de loi relatif à lenseignement supérieur et à la recherche 	\N	\N	\N	\N	999	\N	\N
CMP	2013CMP10	\N	2013-07-04 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	Séparation et  régulation des activités bancaires 	\N	du	projet de loi de séparation et de régulation des activités bancaires 	\N	\N	\N	\N	999	\N	\N
CMP	2013CMP13	\N	2013-07-12 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	Transparence de la vie publique (loi organique)	\N	du	projet de loi organique relatif à la transparence de la vie publique 	\N	\N	\N	\N	999	\N	\N
CMP	2013CMP14	\N	2013-07-12 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	Ttransparence de la vie publique (loi ordinaire)	\N	du	projet de loi relatif à la transparence de la vie publique 	\N	\N	\N	\N	999	\N	\N
CMP	2013CMP17	\N	2013-09-13 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	Protection des personnes faisant lobjet de soins psychiatriques et aux modalités de leur prise en charge	\N	de la	Proposition de loi visant à modifier certaines dispositions issues de la loi n° 2011-803 du 5 juillet 2011 relative aux droits et à la protection des personnes faisant lobjet de soins psychiatriques et aux modalités de leur prise en charge 	\N	\N	\N	\N	999	\N	\N
MISINFCOM	RYTHMES	1	2013-10-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	MCI sur la réforme des rythmes scolaires	Mission commune d'information sur la réforme des rythmes scolaires	MISSION COMMUNE D'INFORMATION SUR LA REFORME DES RYTHMES SCOLAIRES	de la	Mission commune d'information sur la réforme des rythmes scolaires	/commission/missions/reforme_des_rythmes_scolaires/index.html	\N	Mission commune d'information sur la réforme des rythmes scolaires	\N	999	2013-10-15 17:59:07	2015-01-14 10:47:34
CMP	2013CMP18	\N	2013-10-03 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	Cumul de fonctions exécutives locales avec le mandat de représentant au Parlement européen	\N	du	projet de loi organique interdisant le cumul de fonctions exécutives locales avec le mandat de représentant au Parlement européen 	\N	\N	\N	\N	999	\N	\N
CMP	2013CMP20	\N	2013-10-03 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	Actualisation de la loi organique n° 99-209 du 19 mars 1999 relative à la Nouvelle-Calédonie 	\N	du	projet de loi organique portant actualisation de la loi organique n° 99-209 du 19 mars 1999 relative à la Nouvelle-Calédonie 	\N	\N	\N	\N	999	\N	\N
CMP	2013CMP21	\N	2013-10-03 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	Diverses dispositions relatives aux outre-mer 	\N	du	projet de loi portant diverses dispositions relatives aux outre-mer 	\N	\N	\N	\N	999	\N	\N
CMP	2013CMP22	\N	2013-10-03 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	Habilitation au Gouvernement à simplifier les résultats entre ladministration et les citoyens	\N	du	projet de loi habilitant le Gouvernement à simplifier les résultats entre ladministration et les citoyens	\N	\N	\N	\N	999	\N	\N
CMP	2013CMP23	\N	2013-10-03 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	Indépendance de laudiovisuel public (loi organique)	\N	du	projet de loi organique relatif à lindépendance de laudiovisuel public 	\N	\N	\N	\N	999	\N	\N
CMP	2013CMP19	\N	2013-10-03 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	Cumul fonctions exécutives locales avec le mandat de député et de sénateur (limitant une seule fn exécutive locale) 	\N	du	projet de loi organique interdisant le cumul de fonctions exécutives locales avec le mandat de député et limitant à une seule fonction exécutive locale le cumul avec le mandat de sénateur	\N	\N	\N	\N	999	\N	\N
CMP	2013CMP247	\N	2013-10-03 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	Indépendance de laudiovisuel public 	\N	du	projet de loi relatif à lindépendance de laudiovisuel public 	\N	\N	\N	\N	999	\N	\N
MISINFCOM	GOUVERNANCE	1	2013-11-19 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	MCI sur la gouvernance de l'internet	Mission commune d'information sur la gouvernance de l'internet	MISSION COMMUNE D'INFORMATION SUR LE NOUVEAU RÔLE ET LA NOUVELLE STRATÉGIE POUR L'UNION EUROPÉENNE DANS LA GOUVERNANCE DE L'INTERNET	de la 	Mission commune d'information sur le nouveau rôle et la nouvelle stratégie pour l'Union européenne dans la gouvernance de l'internet	/commission/missions/nouveau_role_et_nouvelle_strategie_pour_lunion_europeenne_dans_la_gouvernance_mondiale_de_linternet/index.html	\N	Mission commune d'information sur le nouveau rôle et la nouvelle stratégie pour l'UE dans la gouvernance de l'internet	\N	999	2013-11-19 18:29:05	2015-01-14 10:47:51
CMP	2013CMP28	\N	2013-11-18 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	financement de la sécurité sociale pour 2014	\N	du	projet de loi de financement de la sécurité sociale pour 2014	\N	\N	\N	\N	999	\N	\N
CMP	2013CMP31	\N	2013-12-09 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	loi de finances rectificative pour 2013.	\N	du	projet de loi de finances rectificative pour 2013.	\N	\N	\N	\N	999	\N	\N
MISINFCOM	COTISATIONS	\N	2014-02-25 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	MCI impact emploi des exonérations	MCI sur la réalité de l'impact sur l'emploi des exonérations de cotisations sociales accordées aux entreprises	MISSION COMMUNE D'INFORMATION RELATIVE À LA RÉALITÉ DE L'IMPACT SUR L'EMPLOI DES EXONÉRATIONS DE COTISATIONS SOCIALES ACCORDÉES AUX ENTREPRISES	de la	Mission commune d'information relative à la réalité de l'impact sur l'emploi des exonérations de cotisations sociales accordées aux entreprises	/commission/missions/impact_sur_lemploi_des_exonerations_de_cotisations_sociales_accordees_aux_entreprises/index.html	\N	MCI relative à la réalité de l'impact sur l'emploi des exonérations de cotisations sociales accordées aux entreprises	\N	999	2014-02-25 16:08:46	2015-01-14 10:48:40
COMENQ	DJIHAD	1	2014-10-14 00:00:00	2015-05-12 00:00:00	\N	ANCIEN	CE sur la lutte contre les réseaux djihadistes	CE organisation et moyens de la lutte contre les réseaux djihadistes en France et en Europe	COMMISSION D'ENQUÊTE SUR L'ORGANISATION ET LES MOYENS DE LA LUTTE CONTRE LES RÉSEAUX DJIHADISTES EN FRANCE ET EN EUROPE	de la	commission d'enquête sur l'organisation et les moyens de la lutte contre les réseaux djihadistes en France et en Europe	/commission/enquete/reseaux_djihadistes.html	\N	Commission d'enquête sur organisation et moyens de la lutte contre les réseaux djihadistes en France et en Europe	\N	999	2014-10-14 17:35:41	2017-03-21 11:16:53
CMP	2014CMP7	\N	2014-04-30 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	transposition de directive, information dans le cadre des procédures pénales	\N	du	projet de loi portant transposition de la directive 2012/13/CE du Parlement européen et du Conseil du 22 mai 2012 relative au droit à linformation dans le cadre des procédures pénales 	\N	\N	\N	\N	999	\N	\N
CMP	2014CMP18	\N	2014-07-10 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	économie sociale et solidaire 	\N	du	projet de loi relatif à léconomie sociale et solidaire 	\N	\N	\N	\N	999	\N	\N
CMP	2014CMP21	\N	2014-07-10 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	nomination des dirigeants de la SNCF 	\N	de la	proposition de loi organique relative à la nomination des dirigeants de la SNCF 	\N	\N	\N	\N	999	\N	\N
COMSPE	CROISSANCE	9	2015-01-15 00:00:00	2015-12-08 00:00:00	\N	ANCIEN	CS croissance et activité	Commission spéciale sur le projet de loi pour la croissance, l'activité et l'égalité des chances économiques	COMMISSION SPÉCIALE SUR LE PROJET DE LOI POUR LA CROISSANCE, L'ACTIVITE ET L'EGALITE DES CHANCES ECONOMIQUES	de la	Commission spéciale sur le projet de loi pour la croissance, l'activité et l'égalité des chances économiques	/commission/spec/croissance_et_activite/index.html	\N	Commission spéciale sur le projet de loi pour la croissance, l'activité et l'égalité des chances économiques	CROISS	999	2015-01-09 11:33:39	2016-04-28 11:35:21
CMP	2014CMP23	\N	2014-07-16 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	loi de financement rectificative de la sécurité sociale pour 2014 	\N	du	projet de loi de financement rectificative de la sécurité sociale pour 2014 	\N	\N	\N	\N	999	\N	\N
CMP	2014CMP24	\N	2014-07-18 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	agriculture, alimentation et foret 	\N	du	projet de loi davenir pour lagriculture, lalimentation et la foret 	\N	\N	\N	\N	999	\N	\N
CMP	2014CMP25	\N	2014-10-16 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	lutte contre le terrorisme 	\N	du	projet de loi renforçant les dispositions relatives à la lutte contre le terrorisme 	\N	\N	\N	\N	999	\N	\N
CMP	2015CMP1	\N	2015-01-14 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	Convention France - Andorre pour la prévention de l'évasion et de la fraude fiscale	\N	du	projet de loi autorisant lapprobation de la convention entre le Gouvernement de la République française et le Gouvernement de la Principauté dAndorre en vue déviter les doubles impositions et de prevenir lévasion et la fraude fiscales en matières dim	\N	\N	\N	\N	999	\N	\N
CMP	2015CMP2	\N	2015-01-14 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	Droit de lUnion européenne dans les domaines de la propriété littérale et artistique et du patrimoine culturel	\N	du	projet de loi portant diverses dispositions dadaptation au droit de lUnion européenne dans les domaines de la propriété littérale et artistique et du patrimoine culturel	\N	\N	\N	\N	999	\N	\N
COMSENCOMMU	CSCECON	1	1958-07-08 00:00:00	1961-03-18 00:00:00	\N	ANCIEN	affaires économiques	affaires économiques	AFFAIRES ÉCONOMIQUES	des 	commission des affaires économiques	\N	\N	\N	\N	999	2015-02-10 14:18:52	\N
COMSENCOMMU	CSCFINPLAN	2	1958-07-08 00:00:00	1961-03-18 00:00:00	\N	ANCIEN	affaires financières et plan	affaires financières et plan	AFFAIRES FINANCIÈRES ET PLAN	des 	commission des affaires financières et plan	\N	\N	\N	\N	999	2015-02-10 14:18:52	\N
COMSENCOMMU	CSCCMPTE	3	1958-07-08 00:00:00	1961-03-18 00:00:00	\N	ANCIEN	comptabilité	comptabilité	COMPTABILITÉ	de la 	commission de la comptabilité	\N	\N	\N	\N	999	2015-02-10 14:18:52	\N
COMSENCOMMU	CSCAFCL	4	1958-07-08 00:00:00	1961-03-18 00:00:00	\N	ANCIEN	enseignement supérieur et relations culturelles	enseignement supérieur et relations culturelles	ENSEIGNEMENT SUPÉRIEUR ET RELATIONS CULTURELLES	de l' 	commission de l' enseignement supérieur et relations culturelles	\N	\N	\N	\N	999	2015-02-10 14:18:52	\N
COMSENCOMMU	CSCLOIS	5	1958-07-08 00:00:00	1961-03-18 00:00:00	\N	ANCIEN	législation	législation	LÉGISLATION	de la 	commission de la législation	\N	\N	\N	\N	999	2015-02-10 14:18:52	\N
COMSENCOMMU	CSCRECEVA	6	1958-07-08 00:00:00	1961-03-18 00:00:00	\N	ANCIEN	recevabilité	recevabilité	RECEVABILITÉ	de la 	commission de la recevabilité	\N	\N	\N	\N	999	2015-02-10 14:18:52	\N
COMSENCOMMU	CSCRGLT	7	1958-07-08 00:00:00	1961-03-18 00:00:00	\N	ANCIEN	règlement	règlement	RÈGLEMENT	du 	commission du règlement	\N	\N	\N	\N	999	2015-02-10 14:18:52	\N
CMP	2015CMP9	\N	2015-06-03 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	Faciliter linscription sur les listes électorales 	\N	de la	proposition de loi tendant à faciliter linscription sur les listes électorales 	\N	\N	\N	\N	999	\N	\N
COMSENCOMMU	CSCRELINT	8	1958-07-08 00:00:00	1961-03-18 00:00:00	\N	ANCIEN	traités, accords internationaux et Défense commune	traités, accords internationaux et Défense commune	TRAITÉS, ACCORDS INTERNATIONAUX ET DÉFENSE COMMUNE	des 	commission des traités, accords internationaux et Défense commune	\N	\N	\N	\N	999	2015-02-10 14:18:52	\N
COMSENCOMMU	CSCTRATEL	9	1958-07-08 00:00:00	1961-03-18 00:00:00	\N	ANCIEN	transports et télécommunications	transports et télécommunications	TRANSPORTS ET TÉLÉCOMMUNICATIONS	des 	commission des transports et télécommunications	\N	\N	\N	\N	999	2015-02-10 14:18:52	\N
CMP	2013CMP26	\N	2013-10-22 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	Application de larticle 11 de la Constitution (loi organique)	\N	du	projet de loi organique portant application de larticle 11 de la Constitution 	\N	\N	\N	\N	999	\N	\N
CMP	2013CMP29	\N	2013-11-29 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	loi de finances pour 2014 	\N	du 	projet de loi de finances pour 2014	\N	\N	\N	\N	999	\N	\N
COMENQ	ECOMOUV	1	2013-12-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	CE sur la mise en oeuvre de l'écotaxe poids lourds	Commission d'enquête sur la mise en oeuvre de l'écotaxe poids lourds	COMMISSION D'ENQUÊTE SUR LES MODALITÉS DU MONTAGE JURIDIQUE ET FINANCIER ET L'ENVIRONNEMENT DU CONTRAT RETENU IN FINE POUR LA MISE EN OEUVRE DE L'ÉCOTAXE POIDS LOURDS	de la	Commission d'enquête sur les modalités du montage juridique et financier et l'environnement du contrat retenu in fine pour la mise en oeuvre de l'écotaxe poids lourds	/commission/enquete/contrat_ecomouv/index.html	\N	Commission d'enquête sur la mise en oeuvre de l'écotaxe poids lourds	\N	999	2013-12-10 14:51:43	2015-01-14 10:48:22
MISINFCOM	DOCUMENTSADM	1	2013-12-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	MCI sur l'accès aux documents administratifs	MCI sur l'accès aux documents administratifs et aux données publiques	MISSION COMMUNE D'INFORMATION SUR L'ACCÈS AUX DOCUMENTS ADMINISTRATIFS ET AUX DONNÉES PUBLIQUES	de la	Mission commune d'information sur l'accès aux documents administratifs et aux données publiques	/commission/missions/acces_aux_documents_administratifs_et_aux_donnees_publiques/index.html	\N	Mission commune d'information sur l'accès aux documents administratifs et aux données publiques	\N	999	2013-12-10 15:02:04	2015-01-14 10:48:11
CMP	2013CMP30	\N	2013-12-16 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	modernisation de laction publique territoriale et d'affirmation des métropoles 	\N	du	projet de loi de modernisation de laction publique territoriale et daffirmation des métropoles 	\N	\N	\N	\N	999	\N	\N
COMSPE	PROSTITUTION	0	2014-01-22 00:00:00	2016-04-13 00:00:00	\N	ANCIEN	CS sur la lutte contre le système prostitutionnel	Commission spéciale sur la lutte contre le système prostitutionnel	COMMISSION SPÉCIALE SUR LA LUTTE CONTRE LE SYSTÈME PROSTITUTIONNEL	de la	commission spéciale sur la lutte contre le système prostitutionnel	/commission/spec/lutte_contre_le_systeme_prostitutionnel/index.html	\N	Commission spéciale sur la lutte contre le système prostitutionnel	PROST	999	2014-01-21 15:22:39	2017-03-21 11:13:21
COMSPE	REGIONS	8	2014-06-18 00:00:00	2015-01-17 00:00:00	\N	ANCIEN	CS Délimitation des régions	Commission spéciale Délimitation des régions, élections régionales et départementales et calendrier électoral	COMMISSION SPÉCIALE CHARGÉE D'EXAMINER LE PROJET DE LOI RELATIF À LA DÉLIMITATION DES RÉGIONS, AUX ÉLECTIONS RÉGIONALES ET DÉPARTEMENTALES ET MODIFIANT LE CALENDRIER ÉLECTORAL	de la	Commission spéciale chargée d'examiner le projet de loi relatif à la délimitation des régions, aux élections régionales et départementales et modifiant le calendrier électoral	/commission/spec/delimitation_des_regions/index.html	\N	Commission spéciale Délimitation des régions, élections régionales et départementales et calendrier électoral	REGIONS	999	2014-06-18 21:46:50	2015-04-09 17:09:45
COMENQ	CREDITIMPOT	\N	2014-12-10 00:00:00	2015-06-09 00:00:00	\N	ANCIEN	CE réalité du détournement du crédit impôt recherche	CE réalité du détournement du crédit impôt recherche	COMMISSION D'ENQUÊTE SUR LA RÉALITÉ DU DÉTOURNEMENT DU CRÉDIT D'IMPÔT RECHERCHE DE SON OBJET ET DE SES INCIDENCES SUR LA SITUATION DE L'EMPLOI ET DE LA RECHERCHE DANS NOTRE PAYS	de la	Commission d'enquête sur la réalité du détournement du crédit d'impôt recherche de son objet et de ses incidences sur la situation de l'emploi et de la recherche dans notre pays	/commission/enquete/detournement_du_credit_dimpot_recherche.html	\N	Commission d'enquête sur la réalité du détournement du crédit d'impôt recherche	\N	999	2014-12-16 17:24:56	2016-04-28 11:34:40
CMP	2014CMP3	\N	2014-01-29 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	consommation	\N	du	projet de loi relatif à la consommation	\N	\N	\N	\N	999	\N	\N
CMP	2014CMP6	\N	2014-02-17 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	formation professionnelle, emploi, democratie sociale	\N	du	projet de loi relatif à la formation professionnelle, à l'emploi et à la democratie sociale	\N	\N	\N	\N	999	\N	\N
CMP	2014CMP10	\N	2014-05-12 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	comptes bancaires inactifs et contrats dassurance-vie en déshérence	\N	de la	proposition de loi relative aux comptes bancaires inactifs et aux contrats dassurance-vie en déshérence	\N	\N	\N	\N	999	\N	\N
CMP	2014CMP17	\N	2014-07-08 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	loi de  finances rectificative pour 2014	\N	du	projet de loi de finances rectificative pour 2014	\N	\N	\N	\N	999	\N	\N
CMP	2014CMP16	\N	2014-07-02 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	individualisation des peines et prévention de la récidive 	\N	du	projet de loi relatif à lindividualisation des peines et à la prévention de la récidive 	\N	\N	\N	\N	999	\N	\N
CMP	2014CMP22	\N	2014-07-16 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	règlement du budget et approbation des comptes de l'année 2013	\N	du	projet de loi de règlement du budget et d'approbation des comptes de l'année 2013	\N	\N	\N	\N	999	\N	2016-06-23 15:56:24
CMP	2014CMP26	\N	2014-10-14 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	financement de la sécurité sociale pour 2015 	\N	du	projet de loi de financement de la sécurité sociale pour 2015 	\N	\N	\N	\N	999	\N	\N
CMP	2014CMP27	\N	2014-10-19 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	simplification de la vie des entreprise et  simplification et de clarification du droit et des procédures administrative	\N	du	projet de loi relatif à la simplification de la vie des entreprise et portant diverses dispositions de simplification et de clarification du droit et des procédures administratives 	\N	\N	\N	\N	999	\N	\N
CMP	2014CMP28	\N	2014-11-19 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	délimitation des régions, élections régionales et départementales 	\N	du	projet de loi relatif à la délimitation des régions, aux élections régionales et départementales et modifiant le calendrier électoral 	\N	\N	\N	\N	999	\N	\N
CMP	2014CMP31	\N	2014-12-06 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	loi de finances pour 2015	\N	du	projet de loi de finances pour 2015	\N	\N	\N	\N	999	\N	\N
MISINFCOM	COMMANDE	1	2015-04-08 00:00:00	2015-10-14 00:00:00	\N	ANCIEN	MCI Commande publique	Mission commune d'information sur la commande publique	MISSION COMMUNE D'INFORMATION SUR LA COMMANDE PUBLIQUE	de la	Mission commune d'information sur la commande publique	/commission/missions/commande_publique.html	\N	Mission commune d'information sur la commande publique	\N	999	2015-04-09 17:32:45	2016-05-03 09:48:35
CMP	2015CMP10	\N	2015-06-03 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	réforme du droit dasile 	\N	du	projet de loi relatif à la réforme du droit dasile 	\N	\N	\N	\N	999	\N	\N
COMENQ	EDUCATION	\N	2015-01-22 00:00:00	2015-10-12 00:00:00	\N	ANCIEN	CE Service public de l'éducation	CE Service public de l'éducation	COMMISSION D'ENQUÊTE SUR LE FONCTIONNEMENT DU SERVICE PUBLIC DE L'ÉDUCATION, SUR LA PERTE DE REPÈRES RÉPUBLICAINS QUE RÉVÈLE LA VIE DANS LES ÉTABLISSEMENTS SCOLAIRES ET SUR LES DIFFICULTÉS RENCONTRÉES PAR LES ENSEIGNANTS DANS L'EXERCICE DE LEUR PROFESSION	de la	Commission d'enquête sur le fonctionnement du service public de l'éducation, sur la perte de repères républicains que révèle la vie dans les établissements scolaires et sur les difficultés rencontrées par les enseignants dans l'exercice de leur profession	/commission/enquete/fonctionnement_du_service_public_de_leducation.html	\N	Commission d'enquête sur le fonctionnement du service public de l'éducation	\N	999	2015-01-27 16:31:47	2016-04-28 11:35:48
CMP	2015CMP7	\N	2015-03-04 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	faciliter lexercice, par les élus locaux, de leur mandat 	\N	de la	proposition de loi visant à faciliter lexercice, par les élus locaux, de leur mandat 	\N	\N	\N	\N	999	\N	\N
CMP	2013CMP27	\N	2013-11-05 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	Avenir et  justice du système de retraites 	\N	de	projet de loi garantissant lavenir et la justice du système de retraites 	\N	\N	\N	\N	999	\N	\N
CMP	2014CMP1	\N	2014-01-29 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	ville et cohésion urbaine	\N	du 	projet de loi de programmation pour la ville et la cohésion urbaine	\N	\N	\N	\N	999	\N	\N
CMP	2014CMP2	\N	2014-02-03 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	économie réelle	\N	de la	proposition de loi visant à reconquérir l'économie réelle	\N	\N	\N	\N	999	\N	\N
CMP	2014CMP4	\N	2014-02-05 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	accès au logement et urbanisme rénové	\N	du	projet de loi pour l'accès au logement et un urbanisme rénové	\N	\N	\N	\N	999	\N	\N
CMP	2014CPM5	\N	2014-02-10 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	géolocalisation	\N	du	projet de loi relatif à la géolocalisation	\N	\N	\N	\N	999	\N	\N
CMP	2014CMP8	\N	2014-04-30 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	 modernisation et  simplification du droit dans les domaines de la justice et des affaires intérieures 	\N	du	projet de loi relatif à la modernisation et à la simplification du droit et des procédures dans les domaines de la justice et des affaires intérieures  	\N	\N	\N	\N	999	\N	\N
CMP	2014CMP9	\N	2014-05-14 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	artisanat, commerce et très petites entreprises 	\N	du	projet de loi relatif à lartisanat, au commerce et aux très petites entreprises 	\N	\N	\N	\N	999	\N	\N
CMP	2014CMP11	\N	2014-05-20 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	protection des navires 	\N	du	projet de loi relatif aux activités privées de protection des navires 	\N	\N	\N	\N	999	\N	\N
CMP	2014CMP13	\N	2014-05-26 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	détachements de travailleurs et concurrence déloyale 	\N	de la	proposition de loi visant à lutter contre les fraudes et les abus constatés lors des détachements de travailleurs et la concurrence déloyale 	\N	\N	\N	\N	999	\N	\N
CMP	2014CMP14	\N	2014-05-28 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	politique de développement et solidarité internationale 	\N	du	projet de loi dorientation et de programmation relative à la politique de développement et de solidarité internationale 	\N	\N	\N	\N	999	\N	\N
CMP	2014CMP12	\N	2014-05-26 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	encadrement des stages et amélioration du statut des stagiaires 	\N	de la	proposition de loi tendant au développement, à lencadrement des stages et à lamélioration du statut des stagiaires 	\N	\N	\N	\N	999	\N	\N
CMP	2014CMP15	\N	2014-06-11 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	accessibilité des établissements recevant du public pour les personnes handicapées	\N	du	projet de loi habilitant le Gouvernement à adopter des mesures législatives pour la mise en accessibilité des établissements recevant du public, des transports publics, des bâtiments dhabitation et de la voirie pour les personnes handicapées 	\N	\N	\N	\N	999	\N	\N
CMP	2014CMP19	\N	2014-07-10 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	égalité entre les femmes et les hommes 	\N	du	projet de loi pour légalité entre les femmes et les hommes 	\N	\N	\N	\N	999	\N	\N
CMP	2014CMP20	\N	2014-07-10 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	réforme ferroviaire 	\N	de	projet de loi portant réforme ferroviaire 	\N	\N	\N	\N	999	\N	\N
CMP	2014CMP29	\N	2014-11-20 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	programmation des finances publiques pour 2014 à 2017 	\N	du	projet de loi de programmation des finances publiques pour 2014 à 2017 	\N	\N	\N	\N	999	\N	\N
CMP	2014CMP30	\N	2014-11-20 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	législation au droit de lUnion européenne en matière économique et financière 	\N	du	projet de loi portant diverses dispositions dadaptation de la législation au droit de lUnion européenne en matière économique et financière 	\N	\N	\N	\N	999	\N	\N
CMP	2014CMP32	\N	2014-12-12 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	loi de finances rectificative pour 2014	\N	du	projet de loi de finances rectificative pour 2014	\N	\N	\N	\N	999	\N	\N
CMP	2015CMP3	\N	2015-01-22 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	Amélioration du régime de la commune nouvelle, pour des communes fortes et vivantes	\N	de la	proposition de loi relativeà 	\N	\N	\N	\N	999	\N	\N
COMENQ	POLLUTION	\N	2015-02-18 00:00:00	2015-07-15 00:00:00	\N	ANCIEN	CE Coût économique et financier de la pollution de l'air	Commission d'enquête sur le coût économique et financier de la pollution de l'air	COMMISSION D'ENQUÊTE SUR LE COÛT ÉCONOMIQUE ET FINANCIER DE LA POLLUTION DE L'AIR	de la	Commission d'enquête sur le coût économique et financier de la pollution de l'air	/commission/enquete/cout_economique_et_financier_de_la_pollution_de_lair.html	\N	Commission d'enquête sur le coût économique et financier de la pollution de l'air	\N	999	2015-02-17 15:27:17	2016-04-28 11:37:05
CMP	2015CMP4	\N	2015-02-11 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	modernisation du secteur de la presse 	\N	de la	proposition de loi portant diverses dispositions tendant à la modernisation du secteur de la presse 	\N	\N	\N	\N	999	\N	\N
CMP	2015CMP5	\N	2015-03-03 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	transition énergétique pour la croissance verte 	\N	du	projet de loi relatif à la transition énergétique pour la croissance verte 	\N	\N	\N	\N	999	\N	\N
CMP	2015CMP6	\N	2015-03-04 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	transformation de luniversité des Antilles et de la Guyane en université des Antilles	\N	du	projet de loi portant transformation de luniversité des Antilles et de la Guyane en université des Antilles, ratifiant diverses ordonnances relatives à lenseignement supérieur et à la recherche et portant diverses dispositions relatives à lenseignement	\N	\N	\N	\N	999	\N	\N
COMENQ	AUTORITES	1	2015-04-08 00:00:00	2016-02-28 00:00:00	\N	ANCIEN	CE Autorités administratives indépendantes	Commission d'enquête sur les autorités administratives indépendantes	COMMISSION D'ENQUÊTE SUR LE BILAN ET LE CONTRÔLE DE LA CRÉATION, DE L'ORGANISATION, DE L'ACTIVITÉ ET DE LA GESTION DES AUTORITÉS ADMINISTRATIVES INDÉPENDANTES	de la	commission d'enquête sur le bilan et le contrôle de la création, de l'organisation, de l'activité et de la gestion des autorités administratives indépendantes	/commission/enquete/autorites_administratives_independantes.html	\N	Commission d'enquête sur les autorités administratives indépendantes	\N	999	2015-04-09 17:14:55	2017-03-21 11:16:19
CMP	2015CMP8	\N	2015-05-06 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	croissance, activité, chances économiques	\N	du	projet de loi pour la croissance, lactivité et légalité des chances économiques 	\N	\N	\N	\N	999	\N	\N
CMP	2015CMP11	\N	2015-06-09 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	modification de la loi n° 2004-639 du 2 juillet 2014 relative à loctroi de mer	\N	du	projet de loi modifiant le loi n° 2004-639 du 2 juillet 2014 relative à loctroi de mer	\N	\N	\N	\N	999	\N	\N
CMP	2015CMP12	\N	2015-06-10 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	renseignement	\N	du	projet de loi relatif au renseignement	\N	\N	\N	\N	999	\N	\N
CMP	2015CMP13	\N	2015-06-25 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	dialogue social et emploi 	\N	du	projet de loi relatif au dialogue social et à lemploi 	\N	\N	\N	\N	999	\N	\N
MISINFCOM	ISLAM	999	2015-12-14 00:00:00	2016-07-10 00:00:00	\N	ANCIEN	MI organisation, place et financement de l'islam en France	Mission d'information sur l'organisation, la place et le financement de l'islam en France et de ses lieux de culte	MISSION D'INFORMATION SUR L'ORGANISATION, LA PLACE ET LE FINANCEMENT DE L'ISLAM EN FRANCE ET DE SES LIEUX DE CULTE	de la	mission d'information sur l'organisation, la place et le financement de l'islam en France et de ses lieux de culte	/commission/missions/islam_en_france/index.html	\N	Mission d'information sur l'organisation, la place et le financement de l'Islam en France et de ses lieux de culte	ORG_ISLAM	999	2015-12-14 16:09:22	2017-03-21 11:21:07
CMP	2015CMP22	\N	2015-10-28 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	surveillance des communications électroniques internationales	\N	de la	proposition de loi relative aux mesures de surveillance des communications électroniques internationales	\N	\N	\N	\N	999	\N	2016-02-23 11:42:21
CMP	BLEUE	999	2016-04-01 00:00:00	2016-04-06 00:00:00	\N	ANCIEN	BLEUE	économie bleue	BLEUE	de l'	économie bleue	/commission/nouv/index.html	\N	BLEUE	BLEUE	999	2016-04-01 10:41:53	2017-05-31 17:58:06
CMP	JUSTICE	999	2016-06-15 00:00:00	2016-06-22 00:00:00	\N	ANCIEN	JUSTICE	Modernisation de la justice du XXI siècle	JUSTICE	de la	Modernisation de la justice du XXI siècle	/commission/nouv/index.html	\N	JUSTICE	JUSTICE	999	2016-06-15 15:03:36	2017-04-21 11:46:45
CMP	MAGISTRATURE	999	2016-06-15 00:00:00	2016-06-22 00:00:00	\N	ANCIEN	MAGISTRATURE	Obligation déontologie, recrutement des magistrats	MAGISTRATURE	de la	Obligation déontologie, recrutement des magistrats	/commission/nouv/index.html	\N	MAGISTRATURE	MAGISTRATURE	999	2016-06-15 15:20:50	2017-04-21 11:46:45
CMP	ELECTORALE	999	2016-06-30 00:00:00	2016-07-12 00:00:00	\N	ANCIEN	ELECTORALE	Modalités d'inscription sur les listes électorales	ELECTORALE	de la	Modalités d'inscription sur les listes électorales	/commission/nouv/index.html	\N	ELECTORALE	ELECTORALE	999	2016-06-30 15:34:13	2017-04-21 11:58:37
CMP	TRANSPARENCE	999	2016-07-13 00:00:00	2016-09-14 00:00:00	\N	ANCIEN	TRANSPARENCE	Transparence et modernisation de la vie économique	TRANSPARENCE	de la	\N	/commission/nouv/index.html	\N	TRANSPARENCE	TRANSPARENCE	999	2016-07-13 16:22:02	2017-04-21 14:49:38
CMP	PLFSS2017	999	2016-11-16 00:00:00	2016-11-24 00:00:00	\N	ANCIEN	PLFSS2017	projet de loi de financement de la sécurité sociale pour 2017	PLFSS2017	de la	projet de loi de financement de la sécurité sociale pour 2017	/commission/nouv/index.html	\N	PLFSS2017	PLFSS2017	999	2016-11-17 10:37:19	2017-05-31 17:58:00
COMENQ	SCHENGEN	999	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	CE Avenir espace Schengen	CE Frontières européennes, contrôle des flux des personnes et des marchandises en Europe et avenir de l'espace Schengen	COMMISSION D'ENQUÊTE SUR LES FRONTIÈRES EUROPÉENNES, LE CONTRÔLE DES FLUX DES PERSONNES ET DES MARCHANDISES EN EUROPE ET L'AVENIR DE L'ESPACE SCHENGEN	de la	commission d'enquête sur les frontières européennes, le contrôle des flux des personnes et des marchandises en Europe et l'avenir de l'espace Schengen	/commission/enquete/frontieres_europeennes.html	\N	CE Frontières européennes, contrôle des flux des personnes et des marchandises en Europe et avenir de l'espace Schengen	SCHENGEN	999	2016-11-21 17:12:31	2017-06-12 11:06:52
CMP	IVG	999	2017-01-18 00:00:00	2017-01-25 00:00:00	\N	ANCIEN	IVG	proposition de loi realtive à l'extension du délit d'entrave à l'interruption volontaire de grossesse	IVG	de la	proposition de loi relative à l'extension du délit d'entrave à l'interruption volontaire de grossesse	/commission/nouv/index.html	\N	IVG	IVG	999	2017-01-23 14:30:28	2018-02-28 15:14:34
CMP	PARIS	999	2017-12-01 00:00:00	2017-12-07 00:00:00	\N	ANCIEN	PARIS	projet de loi ratifiant l'ordonnance portant création de l'établissement public Paris La Défense	PARIS	du	projet de loi ratifiant l'ordonnance portant création de l'établissement public Paris La Défense	/commission/nouv/index.html	\N	PARIS	PARIS	999	2017-12-01 16:39:53	2018-02-28 15:07:37
COMENQ	FORCES	999	2018-01-17 00:00:00	2018-06-30 00:00:00	\N	ANCIEN	CE Etat des forces de sécurité intérieure	CE Etat des forces de sécurité intérieure	COMMISSION D'ENQUÊTE SUR L'ÉTAT DES FORCES DE SÉCURITÉ INTÉRIEURE	de la	commission d'enquête sur l'état des forces de sécurité intérieure	/commission/enquete/forces_de_securite_interieure/index.html	\N	Commission d'enquête Etat des forces de sécurité intérieure	FORCES	999	2018-01-16 14:39:56	2018-02-01 15:33:01
COMSPE	ETAT	999	2018-01-17 00:00:00	2018-01-30 00:00:00	\N	ANCIEN	GT Etat au service d'une société de confiance	GT Etat au service d'une société de confiance	GROUPE DE TRAVAIL PRÉFIGURANT LA COMMISSION SPÉCIALE SUR LE PROJET DE LOI POUR UN ÉTAT AU SERVICE D'UNE SOCIÉTÉ DE CONFIANCE	du	groupe de travail préfigurant la commission spéciale sur le projet de loi pour un état au service d'une société de confiance	/commission/spec/societe_de_confiance/index.html	\N	Groupe de travail pour un Etat au service d'une société de confiance	ETAT	999	2018-01-16 14:51:43	2018-02-02 10:19:21
MISINFCOM	MINEURSENF	999	2018-03-14 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	MI sur la réinsertion des mineurs enfermés	Mission d'information sur la réinsertion des mineurs enfermés	Mission d'information sur la réinsertion des mineurs enfermés	de la	Mission d'information sur la réinsertion des mineurs enfermés	/commission/missions/mineurs_enfermes/index.html	\N	MI sur la réinsertion des mineurs enfermés	MINEURSENF	999	2018-03-13 16:24:21	2018-04-30 10:22:23
CMP	EFFICACITE	999	2018-03-14 00:00:00	2018-03-14 00:00:00	\N	ANCIEN	EFFICACITE	projet de loi pour un Etat au service d'une société de confiance	EFFICACITE	du	projet de loi pour un Etat au service d'une société de confiance	/commission/nouv/index.html	\N	EFFICACITE	EFFICACITE	999	2018-03-21 14:02:52	2018-05-22 16:40:21
CMP	EAU	999	2018-04-18 00:00:00	2018-05-18 00:00:00	\N	ANCIEN	EAU	proposition de loi relative à la mise en oeuvre du transfert des compétences eau et assainissement	EAU	de la	proposition de loi relative à la mise en oeuvre du transfert des compétences eau et assainissement aux communautés de communes et aux communautés d'agglomération	/commission/nouv/index.html	\N	EAU	EAU	999	2018-05-22 16:40:45	2018-06-07 17:11:04
CMP	DOUA	999	2023-06-28 00:00:00	2023-06-29 00:00:00	\N	ANCIEN	DOUA	PJL Douane	DOUA	du	PJL visant à donner à la douane les moyens de faire face aux nouvelles menaces	/commission/nouv/index.html	\N	DOUA	DOUA	999	\N	\N
CMP	SECRET	999	2018-05-22 00:00:00	2018-05-25 00:00:00	\N	ANCIEN	SECRET	proposition de loi relative à la protection du secret des affaires	SECRET	de la	proposition de loi relative à la protection du secret des affaires	/commission/nouv/index.html	\N	SECRET	SECRET	999	2018-05-22 16:45:23	2018-06-07 17:10:53
MISINFCOM	PENURIE	999	2018-06-27 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	Mission d'information sur la pénurie de médicaments	Mission d'information sur la pénurie de médicaments et de vaccins	MISSION D'INFORMATION SUR LA PÉNURIE DE MÉDICAMENTS ET DE VACCINS	de la	Mission d'information sur la pénurie de médicaments et de vaccins	/commission/nouv/index.html	\N	Mission d'information sur la pénurie de médicaments	PENURIE	999	\N	\N
COMSPE	RETRAIT	999	2018-10-10 00:00:00	2019-01-19 00:00:00	\N	ANCIEN	CS préparation du retrait du Royaume-Uni de l'UE	CS habilitant le Gouvernement à prendre les mesures de préparation du retrait du Royaume-Uni de l'Union européenne	COMMISSION SPECIALE SUR LE PROJET DE LOI HABILITANT LE GOUVERNEMENT À PRENDRE PAR ORDONNANCE LES MESURES DE PRÉPARATION DU RETRAIT DU ROYAUME-UNI DE L'UNION EUROPÉENNE	de la	commission spéciale sur le projet de loi habilitant le Gouvernement à prendre par ordonnance les mesures de préparation du retrait du Royaume-Uni de l'Union européenne	/commission/spec/brexit.html	\N	CS préparation du retrait du Royaume-Uni de l'UE	RETRAIT	999	\N	\N
COMSPE	SURTRANSPO	999	2018-10-10 00:00:00	2018-11-12 00:00:00	\N	ANCIEN	CS suppression surtranspositions directives droit français	CS portant suppression des surtranspositions des directives en droit français	COMMISSION SPECIALE PORTANT SUPPRESSION DES SURTRANSPOSITIONS DES DIRECTIVES EN DROIT FRANÇAIS	de la	commission spéciale sur le projet de loi portant suppression des surtranspositions des directives en droit français	/commission/spec/surtranspositions.html	\N	CS suppression surtranspositions directives droit français	SURTRANSPO	999	\N	\N
CMP	ZEROCHOMAGE	999	2016-01-27 00:00:00	2016-02-03 00:00:00	\N	ANCIEN	ZEROCHOMAGE	Expérimentation territoriale visant à résorber chômage de longue durée	ZEROCHOMAGE	de la	Expérimentation territoriale visant à résorber chômage de longue durée	/commission/nouv/index.html	\N	ZEROCHOMAGE	ZEROCHOMAGE	999	2016-02-23 14:38:11	2017-05-31 17:58:00
CMP	FINDEVIE	999	2015-12-17 00:00:00	2016-01-20 00:00:00	\N	ANCIEN	FINDEVIE	Nouveaux droits personnes malades en fin de vie	FINDEVIE	de la	Nouveaux droits personnes malades en fin de vie	/commission/nouv/index.html	\N	FINDEVIE	FINDEVIE	999	2016-02-23 14:46:21	2017-05-31 17:58:01
CMP	PROTECTION	999	2015-12-17 00:00:00	2016-01-13 00:00:00	\N	ANCIEN	PROTECTION	Protection de l'enfant	PROTECTION	de la	Protection de l'enfant	/commission/nouv/index.html	\N	PROTECTION	PROTECTION	999	2016-02-23 14:50:53	2017-05-31 17:58:04
CMP	MINEURS	999	2016-03-02 00:00:00	2016-03-22 00:00:00	\N	ANCIEN	MINEURS	protection des mineurs	MINEURS	de la	protection des mineurs	/commission/nouv/index.html	\N	MINEURS	MINEURS	999	2016-03-11 10:48:31	2017-04-21 11:58:37
CMP	DEONTOLOGIE	999	2016-03-02 00:00:00	2016-03-29 00:00:00	\N	ANCIEN	DEONTOLOGIE	déontologie et droits et obligations des fonctionnaires	DEONTOLOGIE	de la	déontologie et droits et obligations des fonctionnaires	/commission/nouv/index.html	\N	DEONTOLOGIE	DEONTOLOGIE	999	2016-03-11 14:18:24	2017-04-21 11:46:45
MISINFCOM	TURQUIE	999	2016-04-27 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	MI Accord UE/Turquie	Mission d'information sur l'accord de mars 2016 entre l'Union européenne et la Turquie relatif à la crise des réfugiés	Mission d'information sur la position de la France à l'égard de l'accord de mars 2016 entre l'Union européenne et la Turquie relatif à la crise des réfugiés et sur les conditions de mise en oeuvre de cet accord	de la	mission d'information sur la position de la France à l'égard de l'accord de mars 2016 entre l'Union européenne et la Turquie relatif à la crise des réfugiés et sur les conditions de mise en oeuvre de cet accord	/commission/missions/accord_ue_turquie/index.html	\N	mission d'information sur l'accord UE/Turquie relatif à la crise des réfugiés	TURQUIE	999	2016-04-27 15:03:19	2017-06-12 11:08:26
COMENQ	CHOMAGE	999	2016-04-27 00:00:00	2016-10-04 00:00:00	\N	ANCIEN	commission d'enquête sur les chiffres du chômage	CE sur les chiffres du chômage	COMMISSION ENQUETE SUR LES CHIFFRES DU CHÔMAGE EN FRANCE ET DANS LES PAYS DE L'UNION EUROPÉENNE AINSI QUE SUR L'IMPACT DES RÉFORMES MISES EN PLACE PAR CES PAYS POUR FAIRE BAISSER LE CHÔMAGE	de la	commission d'enquête sur les chiffres du chômage en France et dans les pays de l'Union européenne ainsi que sur l'impact des réformes mises en place par ces pays pour faire baisser le chômage	/commission/enquete/chiffres_du_chomage.html	\N	commission d'enquête sur les chiffres du chômage en France et dans les pays de l'Union européenne	CHOMAGE	999	2016-04-27 14:47:50	2017-06-12 11:08:12
CMP	REGLEMENT	999	2016-07-08 00:00:00	2016-07-12 00:00:00	\N	ANCIEN	REGLEMENT	Règlement du budget et approbation des comptes de l'année 2015	REGLEMENT	de la	Règlement du budget et approbation des comptes de l'année 2015	/commission/nouv/index.html	\N	REGLEMENT	REGLEMENT	999	2016-07-08 11:17:53	2017-05-31 17:58:02
CMP	CDGEXPRESS	999	2016-11-23 00:00:00	2016-12-01 00:00:00	\N	ANCIEN	CDGEXPRESS	liaison ferroviaire entre Paris et l'aéroport Paris-Charles de Gaulle	CDGEXPRESS	de la	liaison ferroviaire entre Paris et l'aéroport Paris-Charles de Gaulle	/commission/nouv/index.html	\N	CDGEXPRESS	CDGEXPRESS	999	2016-11-24 11:54:36	2017-05-31 17:57:59
CMP	VTC	999	2016-11-23 00:00:00	2016-12-01 00:00:00	\N	ANCIEN	VTC	régulation, responsabilisation et simplification dans le secteur du transport public particulier de personnes	VTC	de la	régulation, responsabilisation et simplification dans le secteur du transport public particulier de personnes	/commission/nouv/index.html	\N	VTC	VTC	999	2016-11-24 11:58:00	2017-05-31 17:57:59
CMP	ACCAPAREMENT	999	2017-02-08 00:00:00	2017-02-09 00:00:00	\N	ANCIEN	ACCAPAREMENT	proposition de loi relative à la lutte contre l'accaparement des terres agricoles et développement du biocontrôle	ACCAPAREMENT	de la	proposition de loi relative à la lutte contre l'accaparement des terres agricoles et développement du biocontrôle	/commission/nouv/index.html	\N	ACCAPAREMENT	ACCAPAREMENT	999	2017-02-09 10:39:30	2018-02-28 15:10:14
CMP	PRESCRIPTION	999	2017-01-25 00:00:00	2017-02-14 00:00:00	\N	ANCIEN	PRESCRIPTION	proposition de loi portant réforme de la prescription en matière pénale	PRESCRIPTION	de la	proposition de loi portant réforme de la prescription en matière pénale	/commission/nouv/index.html	\N	PRESCRIPTION	PRESCRIPTION	999	2017-02-14 16:17:31	2018-02-28 15:10:21
CMP	COLLCORSE	999	2017-01-25 00:00:00	2017-02-14 00:00:00	\N	ANCIEN	COLLCORSE	projet de loi ratifiant les ordonnances relatives à la collectivité de Corse	COLLCORSE	du	projet de loi ratifiant les ordonnances relatives à la collectivité de Corse	/commission/nouv/index.html	\N	COLLCORSE	COLLCORSE	999	2017-02-14 17:56:10	2018-02-28 15:11:20
CMP	SECURITEPUBL	999	2017-01-25 00:00:00	2017-02-14 00:00:00	\N	ANCIEN	SECURITEPUBL	projet de loi relatif à la sécurité publique	SECURITEPUBL	du	projet de loi relatif à la sécurité publique	/commission/nouv/index.html	\N	SECURITEPUBL	SECURITEPUBL	999	2017-02-14 18:00:01	2018-02-28 15:12:05
CMP	CONTRATS	999	2018-02-22 00:00:00	2018-03-14 00:00:00	\N	ANCIEN	CONTRATS	projet de loi portant réforme du droit des contrats, du régime général et de la preuve des obligations	CONTRATS	du	projet de loi portant réforme du droit des contrats, du régime général et de la preuve des obligations	/commission/nouv/index.html	\N	CONTRATS	CONTRATS	999	2018-02-22 10:58:00	2018-03-21 14:02:21
COMSPE	ENTREPRISES	999	2018-10-10 00:00:00	2019-05-22 00:00:00	\N	ANCIEN	CS croissance et transformation des entreprises  	CS croissance et la transformation des entreprises	COMMISSION SPECIALE SUR LE PROJET DE LOI RELATIF A LA CROISSANCE ET LA TRANSFORMATION DES ENTREPRISES	de la	commission spéciale sur le projet de loi relatif à la croissance et la transformation des entreprises	/commission/spec/pacte.html	\N	CS croissance et transformation des entreprises  	ENTREPRISES	999	\N	\N
CMP	PLFR2018	999	2018-11-19 00:00:00	2018-11-21 00:00:00	\N	ANCIEN	PLFR2018	projet de loi de finances rectificative pour 2018	PLFR2018	du	projet de loi de finances rectificative pour 2018	/commission/nouv/index.html	\N	PLFR2018	PLFR2018	999	\N	\N
CMP	PLFSS2019	999	2018-11-15 00:00:00	2018-11-21 00:00:00	\N	ANCIEN	PLFSS2019	projet de loi de financement de la sécurité sociale pour 2019	PLFSS2019	du	projet de loi de financement de la sécurité sociale pour 2019	/commission/nouv/index.html	\N	PLFSS2019	PLFSS2019	999	\N	\N
MISINFCOM	SIDERURGIE	999	2019-01-30 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	MI sur les enjeux de la filière sidérurgique	MI sur les enjeux de la filière sidérurgique	MISSION D'INFORMATION SUR LES ENJEUX DE LA FILIÈRE SIDÉRURGIQUE DANS LA FRANCE DU XXIÈ SIÈCLE : OPPORTUNITÉ DE CROISSANCE ET DE DÉVELOPPEMENT	de la	Mission d'information sur les enjeux de la filière sidérurgique dans la France du XXIè siècle : opportunité de croissance et de développement	/commission/missions/filiere_siderurgie.html	\N	MI sur les enjeux de la filière sidérurgique	SIDERURGIE	999	\N	\N
CMP	2015CMP14	\N	2015-06-17 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	adaptation de la procédure pénale au droit de lUnion européenne	\N	du	projet de loi portant adaptation de la procédure pénale au droit de lUnion européenne	\N	\N	\N	\N	999	\N	\N
CMP	2015CMP15	\N	2015-06-25 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	 nouvelle organisation territoriale de la République 	\N	du	projet de loi portant nouvelle organisation territoriale de la République 	\N	\N	\N	\N	999	\N	\N
CMP	2015CMP23	\N	2015-10-26 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	consolider et clarifier lorganisation de la manutention dans les ports maritimes	\N	de la	proposition de loi tendant à consolider et clarifier lorganisation de la manutention dans les ports maritimes	\N	\N	\N	\N	999	\N	2016-02-23 11:51:24
CMP	2015CMP24	\N	2015-11-05 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	adaptation au droit de lUnion européenne dans le domaine de la prévention	\N	du	projet de loi portant diverses dispositions dadaptation au droit de lUnion européenne dans le domaine de la prévention des risques 	\N	\N	\N	\N	999	\N	2016-02-23 11:46:45
CMP	2015CMP28	\N	2015-11-12 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	financement de la sécurité sociale pour 2016 	\N	du	projet de loi de financement de la sécurité sociale pour 2016 	\N	\N	\N	\N	999	\N	2016-02-23 11:47:37
CMP	ELECTION	999	2016-03-02 00:00:00	2016-03-15 00:00:00	\N	ANCIEN	ELECTION	modernisation des règles applicables à l'élection présidentielle	ELECTION	de la	modernisation des règles applicables à l'élection présidentielle	/commission/nouv/index.html	\N	ELECTION	ELECTION	999	2016-03-11 10:05:03	2017-04-21 11:46:45
CMP	CRIME	999	2016-04-27 00:00:00	2016-05-12 00:00:00	\N	ANCIEN	CRIME	crime organisé	CRIME	de la	Projet de loi renforçant la lutte contre le crime organisé, le terrorisme et leur financement et améliorant l'efficacité et les garanties de la procédure pénale	/commission/nouv/index.html	\N	CRIME	CRIME	999	2016-05-06 10:14:16	2017-04-21 11:58:37
CMP	BIODIVERSITE	999	2016-05-17 00:00:00	2016-05-25 00:00:00	\N	ANCIEN	BIODIVERSITE	Reconquête de la biodiversité 	BIODIVERSITE	de la	Commission mixte paritaire sur le PJL "reconquête de la biodiversité"	/commission/nouv/index.html	\N	BIODIVERSITE	BIODIVERSITE	999	2016-05-18 08:49:42	2017-05-18 16:52:54
CMP	ARCHITECTURE	999	2016-06-08 00:00:00	2016-06-15 00:00:00	\N	ANCIEN	ARCHITECTURE	Liberté de la création, architecture et patrimoine	ARCHITECTURE	de la	Liberté de la création, architecture et patrimoine	/commission/nouv/index.html	\N	ARCHITECTURE	ARCHITECTURE	999	2016-06-08 17:34:52	2017-05-31 17:58:02
CMP	MEDIAS	999	2016-06-08 00:00:00	2016-06-14 00:00:00	\N	ANCIEN	MEDIAS	Liberté, indépendance et pluralisme des médias	MEDIAS	de la	Proposition de loi visant à renforcer la liberté, indépendance et pluralisme des médias	/commission/nouv/index.html	\N	MEDIAS	MEDIAS	999	2016-06-08 17:39:27	2017-04-21 11:46:45
CMP	TRAVAIL	999	2016-06-23 00:00:00	2016-06-28 00:00:00	\N	ANCIEN	TRAVAIL	Instituer de nouvelles libertés et de nouvelles protections pour les entreprises et les actif-ve-s	TRAVAIL	de la	Instituer de nouvelles libertés et de nouvelles protections pour les entreprises et les actif-ve-s	/commission/nouv/index.html	\N	TRAVAIL	TRAVAIL	999	2016-06-24 20:14:05	2017-05-31 17:58:00
CMP	ENERGIE	999	2017-01-26 00:00:00	2017-02-07 00:00:00	\N	ANCIEN	ENERGIE	projet de loi ratifiant les ordonnances relatives à l'autoconsommation d'électricité et énergies renouvelables	ENERGIE	du	projet de loi ratifiant les ordonnances relatives à l'autoconsommation d'électricité et énergies renouvelables	/commission/nouv/index.html	\N	ENERGIE	ENERGIE	999	2017-01-31 14:14:19	2018-02-28 15:13:45
CMP	OUTRE_MER	999	2017-01-31 00:00:00	2017-02-07 00:00:00	\N	ANCIEN	OUTRE_MER	Egalité réelle outre-mer et autres dispositions en matière sociale et économique	OUTRE_MER	du	projet de loi de programmation relatif à l'égalité réelle outre-mer et autres dispositions en matière sociale et économique	/commission/nouv/index.html	\N	OUTRE_MER	OUTRE_MER	999	2017-01-31 14:38:24	2018-02-28 15:13:01
CMP	DIALOGUE	999	2017-07-26 00:00:00	2017-08-01 00:00:00	\N	ANCIEN	DIALOGUE	projet de loi d'habilitation à prendre par ordonnances les mesures pour le renforcement du dialogue social	DIALOGUE	du	projet de loi d'habilitation à prendre par ordonnances les mesures pour le renforcement du dialogue social	/commission/nouv/index.html	\N	DIALOGUE	DIALOGUE	999	2017-07-27 11:16:08	2017-08-03 12:18:38
CMP	CONFIANCE	999	2017-07-26 00:00:00	2017-08-02 00:00:00	\N	ANCIEN	CONFIANCE	projet de loi et projet de loi organique rétablissant la confiance dans l'action publique	CONFIANCE	du	projet de loi et projet de loi organique rétablissant la confiance dans l'action publique	/commission/nouv/index.html	\N	CONFIANCE	CONFIANCE	999	2017-07-27 11:27:41	2017-08-03 12:18:47
CMP	MARCHE	999	2018-04-18 00:00:00	2018-04-19 00:00:00	\N	ANCIEN	MARCHE	projet de loi ratifiant l'ordonnance concernant les services de paiement dans le marché intérieur	MARCHE	du	projet de loi ratifiant l'ordonnance portant transposition de la directive concernant les services de paiement dans le marché intérieur	/commission/nouv/index.html	\N	MARCHE	MARCHE	999	2018-04-18 11:40:23	2018-05-22 16:39:12
CMP	EUROPEEN	999	2018-04-17 00:00:00	2018-04-20 00:00:00	\N	ANCIEN	EUROPEEN	projet de loi relatif à l'élection des représentants au Parlement européen	EUROPEEN	du	projet de loi relatif à l'élection des représentants au Parlement européen	/commission/nouv/index.html	\N	EUROPEEN	EUROPEEN	999	2018-04-18 11:48:35	2018-05-22 16:39:37
MISINFCOM	CLIMATIQUE	999	2019-01-16 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	mission d'information sur la gestion des risques climatiques	mission d'information sur la gestion des risques climatiques	MISSION D'INFORMATION PORTANT SUR LA GESTION DES RISQUES CLIMATIQUES ET L'EVOLUTION DE NOS REGIMES D'INDEMNISATION	de la	Mission d'information portant sur la gestion des risques climatiques et l'évolution de nos régimes d'indemnisation	/commission/missions/risques_climatiques_et_indemnisation.html	\N	MI sur l'indemnisation des risques climatiques	CLIMATIQUE	999	\N	\N
MISINFCOM	TRANSPORTS	999	2019-03-06 00:00:00	2019-09-27 00:00:00	\N	ANCIEN	MI Gratuité des transports collectifs	MI Gratuité des transports collectifs	MISSION D'INFORMATION « GRATUITÉ DES TRANSPORTS COLLECTIFS : FAUSSE BONNE IDÉE OU RÉVOLUTION ÉCOLOGIQUE ET SOCIALE DES MOBILITÉS ? »	de la	mission d'information  « Gratuité des transports collectifs : fausse bonne idée ou révolution écologique et sociale des mobilités ? »	/commission/missions/mission_dinformation_sur_la_gratuite_des_transports_collectifs.html	\N	MI Gratuité des transports collectifs	TRANSPORTS	999	\N	\N
CMP	ANCT	999	2019-03-20 00:00:00	2019-04-04 00:00:00	\N	ANCIEN	ANCT	proposition de loi portant creation d'une Agence nationale de la cohésion des territoires	ANCT	de la	proposition de loi portant creation d'une Agence nationale de la cohésion des territoires	/commission/nouv/index.html	\N	ANCT	ANCT	999	\N	\N
CMP	ANCTORG	999	2019-03-20 00:00:00	2019-04-04 00:00:00	\N	ANCIEN	ANCTORG	proposition de loi organique relative à la nomination du directeur général de l'ANCT	ANCTORG	de la 	proposition de loi organique relative à la nomination du directeur général de l'ANCT	/commission/nouv/index.html	\N	ANCTORG	ANCTORG	999	\N	\N
CMP	2015CMP19	\N	2015-09-08 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	dividende numérique et  poursuite de la modernisation de la télévision numérique terrestre	\N	de la 	proposition de loi relative au deuxième dividende numérique et à la poursuite de la modernisation de la télévision numérique terrestre 	\N	\N	\N	\N	999	\N	\N
CMP	2015CMP20	\N	2015-09-16 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	actualisation du droit des outre-mer 	\N	du	projet de loi dactualisation du droit des outre-mer 	\N	\N	\N	\N	999	\N	\N
CMP	2015CMP26	\N	2015-11-05 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	maitrise de limmigration 	\N	du	projet de loi portant diverses dispositions relatives à la maitrise de limmigration 	\N	\N	\N	\N	999	\N	2016-02-23 11:49:38
MISINFCOM	REVENU	1	2016-05-18 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	MI Revenu de base en France	Mission d'information sur un revenu de base en France	MISSION D'INFORMATION SUR L'INTÉRÊT ET LES FORMES POSSIBLES DE MISE EN PLACE D'UN REVENU DE BASE EN FRANCE	de la	Mission d'information sur l'intérêt et les formes possibles de mise en place d'un revenu de base en France	/commission/missions/revenu_de_base_en_france/index.html	\N	Mission d'information sur un revenu de base en France	REVENU	999	2016-05-17 16:41:21	2017-06-12 11:07:55
CMP	REPUBLIQUE	999	2016-06-01 00:00:00	2016-06-29 00:00:00	\N	ANCIEN	REPUBLIQUE	République numérique	REPUBLIQUE	de la	République numérique	/commission/nouv/index.html	\N	REPUBLIQUE	REPUBLIQUE	999	2016-06-02 11:03:43	2017-04-21 11:58:37
COMENQ	ATTEINTES	999	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	CE Compensation des atteintes à la biodiversité 	Commission d'enquête sur les atteintes à la biodiversité sur grands projets d'infrastructures	COMMISSION D'ENQUÊTE SUR LA RÉALITÉ DES MESURES DE COMPENSATION DES ATTEINTES À LA BIODIVERSITÉ ENGAGÉES SUR DES GRANDS PROJETS D'INFRASTRUCTURES, INTÉGRANT LES MESURES D'ANTICIPATION, LES ÉTUDES PRÉALABLES, LES CONDITIONS DE RÉALISATION ET LEUR SUIVI	de la	commission d'enquête sur la réalité des mesures de compensation des atteintes à la biodiversité engagées sur des grands projets d'infrastructures, intégrant les mesures d'anticipation, les études préalables, les conditions de réalisation et leur suivi	/commission/enquete/atteintes_a_la_biodiversite.html	\N	CE Atteintes à la biodiversité sur grands projets d'infrastructures	ATTEINTES	999	2016-11-21 17:25:15	2017-06-12 11:06:58
MISINFCOM	DEMOCRATIE	999	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	MI Démocratie	Mission d'information Démocratie représentative, participative, paritaire	MISSION D'INFORMATION SUR LA DÉMOCRATIE REPRÉSENTATIVE, DÉMOCRATIE PARTICIPATIVE, DÉMOCRATIE PARITAIRE : COMMENT DÉCIDER AVEC EFFICACITÉ ET LÉGITIMITÉ EN FRANCE EN 2017	de la	mission d'information sur la démocratie représentative, la démocratie participative, la démocratie paritaire : comment décider avec efficacité et légitimité en France en 2017	/commission/missions/democratie/index.html	\N	MI Démocratie représentative, participative, paritaire	DEMOCRATIE	999	2016-11-21 17:36:38	2017-06-12 11:07:06
MISINFCOM	PSYCHIATRIE	999	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	MI sur la situation de la psychiatrie des mineurs en France	Mission d'information sur la situation de la psychiatrie des mineurs en France	MISSION D'INFORMATION SUR LA SITUATION DE LA PSYCHIATRIE DES MINEURS EN FRANCE	de la	mission d'information sur la situation de la psychiatrie des mineurs en France	/commission/missions/psychiatrie_des_mineurs/index.html	\N	Mission d'information sur la situation de la psychiatrie des mineurs en France	PSYCHIATRIE	999	2016-11-21 17:41:24	2017-06-12 11:07:11
CMP	TERRORISME	999	2017-10-05 00:00:00	2017-10-10 00:00:00	\N	ANCIEN	TERRORISME	projet de loi renforçant la sécurité intérieure et la lutte contre le terrorisme	TERRORISME	du	projet de loi renforçant la sécurité intérieure et la lutte contre le terrorisme	/commission/nouv/index.html	\N	TERRORISME	TERRORISME	999	2017-10-09 17:28:33	2018-02-28 15:08:01
CMP	PLF2018	999	2017-12-07 00:00:00	2017-12-13 00:00:00	\N	ANCIEN	PLF2018	projet de loi de finances pour 2018	PLF2018	du	projet de loi de finances pour 2018	/commission/nouv/index.html	\N	PLF2018	PLF2018	999	2017-12-08 15:33:56	2018-02-28 15:07:11
CMP	PLFP2018	999	2017-12-07 00:00:00	2017-12-14 00:00:00	\N	ANCIEN	PLFP2018	projet de loi de programmation des finances publiques pour les années 2018 à 2022	PLFP2018	du	projet de loi de programmation des finances publiques pour les années 2018 à 2022	/commission/nouv/index.html	\N	PLFP2018	PLFP2018	999	2017-12-08 15:37:29	2018-02-28 15:06:17
COMSPE	SOCIETE	999	2018-01-31 00:00:00	2018-08-10 00:00:00	\N	ANCIEN	CS Etat au service d'une société de confiance	CS Etat au service d'une société de confiance	COMMISSION SPECIALE SUR LE PROJET DE LOI POUR UN ETAT AU SERVICE D'UNE SOCIETE DE CONFIANCE	de la	commission spéciale sur le projet de loi pour un Etat au service d'une société de confiance	/commission/spec/societe_de_confiance/accueil.html	\N	CS Etat au service d'une société de confiance	SOCIETE	999	2018-02-02 09:30:28	2018-02-02 09:35:35
CMP	EGALIM	999	2018-07-03 00:00:00	2018-07-11 00:00:00	\N	ANCIEN	EGALIM	projet de loi pour une alimentation saine, durable et accessible à tous	EGALIM	du	projet de loi pour l'équilibre des relations commerciales dans le secteur agricole et alimentaire et une alimentation saine, durable et accessible à tous	/commission/nouv/index.html	\N	EGALIM	EGALIM	999	\N	\N
CMP	VIOLENCES	999	2018-07-10 00:00:00	2018-07-24 00:00:00	\N	ANCIEN	VIOLENCES	projet de loi renforçant la lutte contre les violences sexuelles et sexistes	VIOLENCES	du	projet de loi renforçant la lutte contre les violences sexuelles et sexistes	/commission/nouv/index.html	\N	VIOLENCES	VIOLENCES	999	\N	\N
CMP	INFORMATION	999	2018-09-25 00:00:00	2018-09-27 00:00:00	\N	ANCIEN	INFORMATION	proposition de loi organique relative à la lutte contre la manipulation de l'information	INFORMATION	de la	proposition de loi organique relative à la lutte contre la manipulation de l'information	/commission/nouv/index.html	\N	INFORMATION	INFORMATION	999	\N	\N
CMP	FRAUDE	999	2018-10-02 00:00:00	2018-10-05 00:00:00	\N	ANCIEN	FRAUDE	projet de loi relatif à la lutte contre la fraude	FRAUDE	du	projet de loi relatif à la lutte contre la fraude	/commission/nouv/index.html	\N	FRAUDE	FRAUDE	999	\N	\N
CMP	CROISSENTRE	999	2019-02-12 00:00:00	2019-02-21 00:00:00	\N	ANCIEN	CROISSENTRE	projet de loi relatif à la croissance et la transformation des entreprises	CROISSENTRE	du	projet de loi relatif à la croissance et la transformation des entreprises	/commission/nouv/index.html	\N	CROISSENTRE	CROISSENTRE	999	\N	\N
COMENQ	SOUVERAINETE	999	2019-04-10 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	Commission d'enquête sur la souveraineté numérique	Commission d'enquête sur la souveraineté numérique	COMMISSION D'ENQUÊTE SUR LA SOUVERAINETÉ NUMÉRIQUE	de la	Commission d'enquête sur la souveraineté numérique	/commission/enquete/souverainete_numerique.html	\N	Commission d'enquête sur la souveraineté numérique	SOUVERAINETE	999	\N	\N
MISINFCOM	AERIEN	999	2019-04-30 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	MI Transports aériens et aménagement des territoires	MI Transports aériens et aménagement des territoires	MISSION D'INFORMATION "TRANSPORTS AÉRIENS ET AMÉNAGEMENT DES TERRITOIRES"	de la	Mission d'information "Transports aériens et aménagement des territoires"	/commission/missions/transports_aeriens_et_amenagement_des_territoires.html	\N	MI Transports aériens et aménagement des territoires	AERIEN	999	\N	\N
MISINFCOM	TELEPHONE	999	2016-06-22 00:00:00	2016-09-30 00:00:00	\N	ANCIEN	MI téléphones mobiles	Mission d'information sur l'inventaire et devenir des matériaux et composants des téléphones mobiles	MISSION D'INFORMATION SUR L'INVENTAIRE ET LE DEVENIR DES MATERIAUX ET COMPOSANTS DES TELEPHONES MOBILES	de la	Mission d'information sur l'inventaire et le devenir des matériaux et composants des téléphones mobiles	/commission/missions/materiaux_et_composants_des_telephones_mobiles/index.html	\N	Mission d'information sur l'inventaire et devenir des matériaux et composants des téléphones mobiles	TELEPHONE	999	2016-06-22 16:38:58	2016-10-07 09:16:23
COMSPE	CITOYENNETE	999	2016-06-22 00:00:00	2016-07-07 00:00:00	\N	ANCIEN	GT Egalité et citoyenneté	Groupe de travail préfigurant commission spéciale Egalité et citoyenneté	GT PREFIGURANT COMMISSION SPECIALE EGALITE ET CITOYENNETE	de la	groupe de travail préfigurant commission spéciale "égalité et citoyenneté"	/commission/nouv/index.html	\N	Groupe de travail préfigurant commission spéciale Egalité et citoyenneté	PLEC	999	2016-06-22 16:05:02	2017-03-23 10:41:04
CMP	20040123N2	\N	2004-01-23 00:00:00	2004-01-30 00:00:00	\N	ANCIEN	\N	Evolutions de la criminalité	\N	du	projet de loi portant adaptation de la justice aux évolutions de la criminalité	\N	\N	\N	\N	999	\N	2016-09-15 16:40:06
CMP	VIGILANCE	999	2016-10-19 00:00:00	2016-11-02 00:00:00	\N	ANCIEN	VIGILANCE	Devoir de vigilance des sociétés mères et des entreprises donneuses d'ordre	VIGILANCE	de la	Devoir de vigilance des sociétés mères et des entreprises donneuses d'ordre	/commission/nouv/index.html	\N	VIGILANCE	VIGILANCE	999	2016-10-20 17:03:10	2017-04-21 11:58:37
CMP	PLFR2016	999	2016-12-16 00:00:00	2016-12-19 00:00:00	\N	ANCIEN	PLFR2016	Projet de loi de finances rectificative pour 2016	PLFR2016	de la	Projet de loi de finances rectificative pour 2016	/commission/nouv/index.html	\N	PLFR2016	PLFR2016	999	2016-12-16 17:10:53	2017-05-31 17:58:08
CMP	CONSOMMATION	999	2017-01-12 00:00:00	2017-01-18 00:00:00	\N	ANCIEN	CONSOMMATION	PJL Ratification de deux ordonnances relatives à la consommation	CONSOMMATION	du	projet de loi ratifiant les ordonnances n° 2016-301 du 14 mars 2016 relative à la partie législative du code de la consommation et n° 2016-351 du 25 mars 2016  sur les contrats de crédit aux consommateurs relatifs aux biens immobiliers à usage d'habitation et simplifiant le dispositif de mise en oeuvre des obligations en matière de conformité et de sécurité des produits et services	/commission/nouv/index.html	\N	CONSOMMATION	CONSOMMATION	999	2017-01-13 10:56:43	2018-02-28 15:16:27
CMP	ANSM	999	2017-01-12 00:00:00	2017-01-18 00:00:00	\N	ANCIEN	ANSM	PJL Simplification procédures mises en oeuvre par l'Agence nationale de sécurité du médicament et des produits de santé	ANSM	du	projet de loi de simplification procédures mises en oeuvre par l'Agence nationale de sécurité du médicament et des produits de santé	/commission/nouv/index.html	\N	ANSM	ANSM	999	2017-01-13 11:04:35	2018-02-28 15:17:35
CMP	ANSP	999	2017-01-12 00:00:00	2017-01-18 00:00:00	\N	ANCIEN	ANSP	projet de loi portant création Agence nationale de santé publique	ANSP	du	projet de loi portant création de l'Agence nationale de santé publique	/commission/nouv/index.html	\N	ANSP	ANSP	999	2017-01-13 11:14:23	2018-02-28 15:18:28
CMP	ENVIRONNEMEN	999	2017-11-08 00:00:00	2017-12-21 00:00:00	\N	ANCIEN	ENVIRONNEMEN	projet de loi ratifiant les ordonnances relatives à l'évaluation environnementale	ENVIRONNEMEN	du	projet de loi ratifiant les ordonnances relatives à la modification des règles applicables à l'évaluation environnementale des projets, plans et programmes et portant réforme des procédures destinées à assurer l'information et la participation du public à l'élaboration de certaines décisions susceptibles d'avoir une incidence sur l'environnement	/commission/nouv/index.html	\N	ENVIRONNEMEN	ENVIRONNEMEN	999	2017-11-08 14:19:10	2017-12-21 10:15:39
CMP	PAFP	999	2023-06-28 00:00:00	2023-06-29 00:00:00	\N	ANCIEN	PAFP	PPL Parité fonction publique	PAFP	de la	PPL visant à renforcer l'accès des femmes aux responsabilités dans la fonction publique	/commission/nouv/index.html	\N	PAFP	PAFP	999	\N	\N
CMP	PLFSS2018	999	2017-11-20 00:00:00	2017-11-23 00:00:00	\N	ANCIEN	PLFSS2018	projet de loi de financement de la sécurité sociale pour 2018	PLFSS2018	du	projet de loi de financement de la sécurité sociale pour 2018	/commission/nouv/index.html	\N	PLFSS2018	PLFSS2018	999	2017-11-20 10:41:29	2017-12-07 10:05:36
COMENQ	CHUTE	999	2018-02-07 00:00:00	2018-07-07 00:00:00	\N	ANCIEN	CE Moyens de l'Etat après chute Etat islamique	CE Moyens de l'Etat après chute Etat islamique	COMMISSION D'ENQUÊTE SUR L'ORGANISATION ET LES MOYENS DES SERVICES DE L'ETAT POUR FAIRE FACE À L'ÉVOLUTION DE LA MENACE TERRORISTE APRÈS LA CHUTE DE L'ETAT ISLAMIQUE	de la	Commission d'enquête sur l'organisation et les moyens des services de l'Etat pour faire face à l'évolution de la menace terroriste après la chute de l'Etat islamique	/commission/nouv/index.html	\N	CE Moyens de l'Etat après chute Etat islamique	\N	999	2018-02-06 16:26:47	2018-02-16 12:03:28
CMP	POLYNESIE	999	2018-06-28 00:00:00	2018-07-05 00:00:00	\N	ANCIEN	POLYNESIE	projet de loi sur les sanctions en matière de concurrence en Polynésie française	POLYNESIE	du	projet de loi ratifiant l'ordonnance n° 2017-157 du 9 février 2017 étendant et adaptation à la Polynésie française certaines dispositions du livre IV du code de commerce relatives aux contrôles et aux sanctions en matière de concurrence	/commission/nouv/index.html	\N	POLYNESIE	POLYNESIE	999	\N	\N
CMP	ASILE	999	2018-06-28 00:00:00	2018-07-05 00:00:00	\N	ANCIEN	ASILE	projet de loi Asile et immigration	ASILE	du	projet de loi pour une immigration maîtrisée, un droit d'asile effectif et une intégration réussie	/commission/nouv/index.html	\N	ASILE	ASILE	999	\N	\N
CMP	MANIPULATION	999	2018-09-25 00:00:00	2018-09-27 00:00:00	\N	ANCIEN	MANIPULATION	proposition de loi relative à la lutte contre la manipulation de l'information	MANIPULATION	de la 	proposition de loi relative à la lutte contre la manipulation de l'information	/commission/nouv/index.html	\N	MANIPULATION	MANIPULATION	999	\N	\N
MISINFCOM	INFRACTIONS	999	2018-10-31 00:00:00	2019-05-31 00:00:00	\N	ANCIEN	MCI répression infractions sexuelles sur mineurs	MCI répression infractions sexuelles sur mineurs	MISSION COMMUNE D'INFORMATION SUR LES POLITIQUES PUBLIQUES DE PRÉVENTION, DE DÉTECTION, D'ORGANISATION DES SIGNALEMENTS ET DE RÉPRESSION DES INFRACTIONS SEXUELLES SUSCEPTIBLES D'ÊTRE COMMISES PAR DES PERSONNES EN CONTACT AVEC DES MINEURS DANS LE CADRE DE L'EXERCICE DE LEUR MÉTIER OU DE LEURS FONCTIONS	de la	Mission commune d'information sur les politiques publiques de prévention, de détection, d'organisation des signalements et de répression des infractions sexuelles susceptibles d'être commises par des personnes en contact avec des mineurs dans le cadre de l'exercice de leur métier ou de leurs fonctions	/commission/missions/infractions_sexuelles_commises_sur_mineurs.html	\N	MCI répression infractions sexuelles sur mineurs	INFRACTIONS	999	\N	\N
CMP	PLF2019	999	2018-12-07 00:00:00	2018-12-12 00:00:00	\N	ANCIEN	PLF2019	projet de loi de finances pour 2019	PLF2019	du	projet de loi de finances pour 2019	/commission/nouv/index.html	\N	PLF2019	PLF2019	999	\N	\N
CMP	2015CMP16	\N	2015-07-09 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	règlement du budget et approbation des comptes de lannée 2014 	\N	du	projet de loi de règlement du budget et dapprobation des comptes de lannée 2014 	\N	\N	\N	\N	999	\N	\N
CMP	2015CMP18	\N	2015-07-08 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	accessibilité des établissements recevant du public, des bâtiments pour les personnes handicapées 	\N	du	projet de loi ratifiant l'ordonnance du 26 septembre 2014 relative à la mise en accessibilité des établissements recevant du public, des transports publics, des bâtiments d'habitation et de la voirie pour les personnes handicapées et visant à favoriser l'	\N	\N	\N	\N	999	\N	\N
CMP	2015CMP21	\N	2015-10-08 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	santé 	\N	du	projet de loi relatif à la santé 	\N	\N	\N	\N	999	\N	2016-02-23 11:41:15
CMP	2015CMP29	\N	2015-11-05 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	dématérialisation du journal officiel de la République française 	\N	de la	proposition de loi portant dématérialisation du journal officiel de la République française 	\N	\N	\N	\N	999	\N	2016-02-23 11:49:17
CMP	2015CMP30	\N	2015-11-24 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	adaptation de la société au vieillissement	\N	du	projet de loi relatif à ladaptation de la société au vieillissement	\N	\N	\N	\N	999	\N	2016-02-23 11:50:06
CMP	2015CMP31	\N	2015-11-19 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	loi de finances pour 2016 	\N	du	projet de loi de finances pour 2016 	\N	\N	\N	\N	999	\N	2016-02-23 11:50:28
CMP	2015CMP32	\N	2015-12-09 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	finances rectificative pour 2015	\N	du	projet de loi de finances rectificative pour 2015	\N	\N	\N	\N	999	\N	2016-02-23 11:50:47
CMP	SECURITE	999	2016-02-04 00:00:00	2016-02-11 00:00:00	\N	ANCIEN	SECURITE	sécurité dans transports de voyageurs	SECURITE	de la	Sécurité dans transports de voyageurs	/commission/nouv/index.html	\N	SECURITE	SECURITE	999	2016-02-23 13:29:43	2017-04-21 11:58:37
CMP	CCI	999	2016-02-04 00:00:00	2016-02-11 00:00:00	\N	ANCIEN	CCI	Chambres de commerce et d'industrie et chambres des métiers et de l'artisanat	CCI	de la	Chambres de commerce et d'industrie et chambres des métiers et de l'artisanat	/commission/nouv/index.html	\N	CCI	CCI	999	2016-02-23 13:50:36	2017-05-31 17:58:03
CMP	ABUS	999	2016-05-12 00:00:00	2016-05-17 00:00:00	\N	ANCIEN	ABUS	Abus de marché	ABUS	de la	Commission mixte paritaire réformant le système de répression des abus de marché	/commission/nouv/index.html	\N	ABUS	ABUS	999	2016-05-12 13:49:18	2017-05-31 17:58:02
CMP	URGENCE	999	2016-07-20 00:00:00	2016-07-20 00:00:00	\N	ANCIEN	URGENCE	Prorogation de l'état d'urgence	URGENCE	de la	\N	/commission/nouv/index.html	\N	URGENCE	URGENCE	999	2016-07-20 19:30:07	2017-04-21 11:58:37
MISINFCOM	BREXIT	999	2016-07-13 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	GS Retrait du Royaume-Uni et la refondation de l'UE	GS Retrait du Royaume-Uni et la refondation de l'UE	GROUPE DE SUIVI SUR LE RETRAIT DU ROYAUME-UNI ET REFONDATION DE L'UNION EUROPEENNE	du	groupe de suivi sur le retrait du Royaume-Uni et la refondation de l'Union européenne	/commission/groupe_de_travail_brexit.html	\N	GS Retrait du Royaume-Uni et la refondation de l'UE	BREXIT	999	2016-10-07 09:04:29	2017-06-12 11:07:15
CMP	PLEC	999	2016-10-18 00:00:00	2016-10-25 00:00:00	\N	ANCIEN	PLEC	Egalité et citoyenneté	PLEC	de la	Egalité et citoyenneté	/commission/nouv/index.html	\N	PLEC	PLEC	999	2016-10-19 10:52:39	2017-05-31 17:58:01
CMP	STATUT	999	2016-12-15 00:00:00	2016-12-21 00:00:00	\N	ANCIEN	STATUT	Statut de Paris et aménagement métropolitain	STATUT	de la	Statut de Paris et aménagement métropolitain	/commission/nouv/index.html	\N	STATUT	STATUT	999	2016-12-16 10:37:09	2017-04-21 12:03:19
CMP	MONTAGNE	999	2016-12-13 00:00:00	2016-12-19 00:00:00	\N	ANCIEN	MONTAGNE	Modernisation, développement et protection des territoires de montagne	MONTAGNE	de la	Modernisation, développement et protection des territoires de montagne	/commission/nouv/index.html	\N	MONTAGNE	MONTAGNE	999	2016-12-16 10:40:45	2017-05-31 17:57:59
CMP	PLFR2017	999	2017-11-09 00:00:00	2017-11-10 00:00:00	\N	ANCIEN	PLFR2017	projet de loi de finances rectificative pour 2017	PLFR2017	du	projet de loi de finances rectificative pour 2017	/commission/nouv/index.html	\N	PLFR2017	PLFR2017	999	2017-11-09 18:37:27	2017-11-20 10:47:06
CMP	HYDROCARBURE	999	2017-11-15 00:00:00	2017-11-22 00:00:00	\N	ANCIEN	HYDROCARBURE	projet de loi mettant fin à la recherche ainsi qu'à l'exploitation des hydrocarbures	HYDROCARBURE	du	projet de loi mettant fin à la recherche ainsi qu'à l'exploitation des hydrocarbures et portant diverses dispositions relatives à l'énergie et à l'environnement	/commission/nouv/index.html	\N	HYDROCARBURE	HYDROCARBURE	999	2017-11-16 10:14:33	2017-12-07 10:05:16
MISINFCOM	ALSTOM	999	2017-11-22 00:00:00	2018-06-06 00:00:00	\N	ANCIEN	MI Alstom et stratégie industrielle du pays	Mission d'information sur Alstom et la stratégie industrielle du pays	MISSION D'INFORMATION SUR ALSTOM ET LA STRATEGIE INDUSTRIELLE DU PAYS	de la	mission d'information sur Alstom et la strategie industrielle du pays	/commission/missions/alstom_et_la_strategie_industrielle_du_pays/index.html	\N	MI Alstom et stratégie industrielle du pays	ALSTOM	999	2017-11-21 15:41:03	2018-02-01 15:41:39
CMP	ORDRE	999	2017-12-01 00:00:00	2017-12-06 00:00:00	\N	ANCIEN	ORDRE	projet de loi ratifiant ordonnance relative au fonctionnement des ordres des professions de santé	ORDRE	du	projet de loi ratifiant l'ordonnance relative à l'adaptation des dispositions législatives relatives au fonctionnement des ordres des professions de santé	/commission/nouv/index.html	\N	ORDRE	ORDRE	999	2017-12-01 11:39:52	2017-12-07 10:05:56
CMP	PLFR2017_2	999	2017-12-18 00:00:00	2017-12-19 00:00:00	\N	ANCIEN	PLFR2017_2	projet de loi de finances rectificative pour 2017_2	projet de loi de finances rectificative pour 2017	du	projet de loi de finances rectificative pour 2017	/commission/nouv/index.html	\N	PLFR2017_2	PLFR2017_2	999	2017-12-18 09:19:27	2018-02-28 15:03:57
CMP	GEMAPI	999	2017-12-19 00:00:00	2017-12-21 00:00:00	\N	ANCIEN	GEMAPI	PPL exercice des compétences des collectivités territoriales dans le domaine de la gestion des milieux aquatiques	GEMAPI	de la	proposition de loi relative à l'exercice des compétences des collectivités territoriales dans le domaine de la gestion des milieux aquatiques et de la prévention des inondations	/commission/nouv/index.html	\N	GEMAPI	GEMAPI	999	2017-12-20 10:07:04	2017-12-21 10:18:39
CMP	DDADUE	999	2018-01-31 00:00:00	2018-02-06 00:00:00	\N	ANCIEN	DDADUE	Projet de loi portant diverses dispositions d'adaptation au droit de l'UE dans le domaine de la sécurité	DDADUE	du	projet de loi portant diverses dispositions d'adaptation au droit de l'Union européenne dans le domaine de la sécurité	/commission/nouv/index.html	\N	DDADUE	DDADUE	999	2018-02-06 12:16:14	2018-02-28 15:05:34
MISINFCOM	HERBE	999	2018-04-11 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	MI sur le développement de l'herboristerie	Mission d'information sur le développement de l'herboristerie	MISSION D'INFORMATION SUR LE DÉVELOPPEMENT DE L'HERBORISTERIE ET DES PLANTES MÉDICINALES, DES FILIÈRES ET MÉTIERS D'AVENIR	de la	Mission d'information sur le développement de l'herboristerie et des plantes médicinales, des filières et métiers d'avenir	/commission/missions/herboristerie_et_plantes_medicinales.html	\N	MI sur le développement de l'herboristerie	HERBE	999	2018-04-10 15:58:09	2018-04-30 10:22:04
CMP	2015CMP17	\N	2015-07-08 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	 programmation militaire pour les années 2015-2019 	\N	du	projet de loi actualisant la programmation militaire pour les années 2015-2019 et portant diverses dispositions concernant la défense 	\N	\N	\N	\N	999	\N	\N
CMP	2015CMP25	\N	2015-10-15 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	renforcer la lutte contre le système prostitutionnel et accompagner les personnes prostituées	\N	de la	proposition de loi visant à renforcer la lutte contre le système prostitutionnel et à accompagner les personnes prostituées 	\N	\N	\N	\N	999	\N	2016-02-23 11:48:18
CMP	2015CMP27	\N	2015-11-05 00:00:00	2016-07-01 00:00:00	\N	ANCIEN	\N	gratuité et modalités de la réutilisation des informations du secteur public 	\N	du	projet de loi relatif à la gratuité et aux modalités de la réutilisation des informations du secteur public 	\N	\N	\N	\N	999	\N	2016-02-23 11:48:49
CMP	PLF2017	999	2016-11-29 00:00:00	2016-12-14 00:00:00	\N	ANCIEN	PLF2017	projet de loi de finances pour 2017	PLF2017	de la	projet de loi de finances pour 2017	/commission/nouv/index.html	\N	PLF2017	PLF2017	999	2016-11-30 12:07:49	2017-05-31 17:58:08
CMP	PHYSICIEN	999	2017-12-01 00:00:00	2017-12-06 00:00:00	\N	ANCIEN	PHYSICIEN	projet de loi ratifiant l'ordonnance relative à la profession de physicien médical	PHYSICIEN	du	projet de loi ratifiant l'ordonnance relative à la profession de physicien médical et l'ordonnance relative à la reconnaissance des qualifications professionnelles dans le domaine de la santé	/commission/nouv/index.html	\N	PHYSICIEN	PHYSICIEN	999	2017-12-01 11:29:30	2017-12-07 10:05:49
COMSPE	EGALITE	999	2016-07-07 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	CS Egalité et citoyenneté	Commission spéciale chargée d'examiner le projet de loi « Egalité et citoyenneté »	COMMISSION SPÉCIALE CHARGÉE D¿EXAMINER LE PROJET DE LOI « ÉGALITÉ ET CITOYENNETÉ »	de la	commission spéciale chargée d'examiner le projet de loi « Égalité et citoyenneté »	/commission/spec/egalite_et_citoyennete/index.html	\N	Commission spéciale chargée d'examiner le projet de loi « Egalité et citoyenneté »	PLEC	999	2016-07-07 17:19:19	2017-06-12 11:07:18
CMP	SOCIAL	999	2018-01-24 00:00:00	2018-02-01 00:00:00	\N	ANCIEN	SOCIAL	projet de loi ratifiant ordonnances renforcement dialogue social	SOCIAL	du	projet de loi ratifiant ordonnances renforcement dialogue social	/commission/nouv/index.html	\N	SOCIAL	SOCIAL	999	2018-01-24 17:40:48	2018-02-06 12:25:06
CMP	ORIENTATION	999	2018-02-07 00:00:00	2018-02-14 00:00:00	\N	ANCIEN	ORIENTATION	Projet de loi relatif à l'orientation et à la réussite des étudiants	ORIENTATION	du	Projet de loi relatif à l'orientation et à la réussite des étudiants	/commission/nouv/index.html	\N	ORIENTATION	ORIENTATION	999	2018-02-14 10:46:02	2018-02-16 09:34:55
CMP	JO2024	999	2018-02-07 00:00:00	2018-02-21 00:00:00	\N	ANCIEN	JO2024	projet de loi relatif à l'organisation des jeux olympiques et paralympiques de 2024	JO2024	du	projet de loi relatif à l'organisation des jeux olympiques et paralympiques de 2024	/commission/nouv/index.html	\N	JO2024	JO2024	999	2018-02-14 10:51:40	2018-02-22 10:57:50
MISINFCOM	BREXIT2	999	2017-11-08 00:00:00	2020-01-30 00:00:00	\N	ANCIEN	GS retrait du Royaume-Uni et refondation de l'UE	Groupe de suivi sur le retrait du Royaume-Uni et la refondation de l'Union européenne	GROUPE DE SUIVI SUR LE RETRAIT DU ROYAUME-UNI ET LA REFONDATION DE L'UNION EUROPÉENNE 2	du	Groupe de suivi sur le retrait du Royaume-Uni et la refondation de l'Union européenne 2	/commission/groupe_de_travail_brexit.html	\N	BREXIT2	BREXIT2	999	2018-03-12 15:54:12	2018-03-12 16:04:06
CMP	DONNEES	999	2018-03-29 00:00:00	2018-04-08 00:00:00	\N	ANCIEN	DONNEES	projet de loi relatif à la protection des données personnelles	DONNEES	du	projet de loi relatif à la protection des données personnelles	/commission/nouv/index.html	\N	DONNEES	DONNEES	999	2018-03-29 17:20:25	2018-05-22 16:40:01
COMENQ	HAUTE	999	2018-04-11 00:00:00	2018-10-07 00:00:00	\N	ANCIEN	CE sur les mutations de la Haute fonction publique	CE sur les mutations de la Haute fonction publique et leurs conséquences	COMMISSION D'ENQUÊTE SUR LES MUTATIONS DE LA HAUTE FONCTION PUBLIQUE ET LEURS CONSÉQUENCES SUR LE FONCTIONNEMENT DES INSTITUTIONS DE LA RÉPUBLIQUE	de la	Commission d'enquête sur les mutations de la Haute fonction publique et leurs conséquences sur le fonctionnement des institutions de la République	/commission/enquete/haute_fonction_publique.html	\N	CE sur les mutations de la Haute fonction publique	HAUTE	999	2018-04-10 16:08:57	2018-04-30 10:21:09
CMP	PACTE	999	2018-06-07 00:00:00	2018-06-12 00:00:00	\N	ANCIEN	PACTE	projet de loi pour un nouveau pacte ferroviaire	PACTE	du	projet de loi pour un nouveau pacte ferroviaire	/commission/nouv/index.html	\N	PACTE	PACTE	999	2018-06-07 17:06:31	2018-06-07 17:09:51
CMP	LPM	999	2018-06-19 00:00:00	2018-06-20 00:00:00	\N	ANCIEN	\N	projet de loi relatif à la programmation militaire pour les années 2019-2025	\N	du	projet de loi relatif à la programmation militaire pour les années 2019-2025 et portant diverses dispositions intéressant la défense	/commission/nouv/index.html	\N	\N	LPM	999	\N	\N
CMP	OEP	999	2018-06-19 00:00:00	2018-07-04 00:00:00	\N	ANCIEN	OEP	proposition de loi visant à garantir la présence des parlementaires dans certains OEP	OEP	de la	proposition de loi visant à garantir la présence des parlementaires dans certains organismes extérieurs au Parlement et à simplifier les modalités de leur nomination	/commission/nouv/index.html	\N	OEP	OEP	999	\N	\N
CMP	AVENIR	999	2018-07-12 00:00:00	2018-07-17 00:00:00	\N	ANCIEN	AVENIR	projet de loi pour la liberté de choisir son avenir professionnel	AVENIR	du	projet de loi pour la liberté de choisir son avenir professionnel	/commission/nouv/index.html	\N	AVENIR	AVENIR	999	\N	\N
CMP	PORTABLE	999	2018-07-16 00:00:00	2018-07-19 00:00:00	\N	ANCIEN	PORTABLE	proposition de loi relative à l'encadrement de l'usage du téléphone portable dans les écoles et les collèges	PORTABLE	de la	proposition de loi relative à l'encadrement de l'usage du téléphone portable dans les écoles et les collèges	/commission/nouv/index.html	\N	PORTABLE	PORTABLE	999	\N	\N
CMP	ELAN	999	2018-07-19 00:00:00	2018-09-12 00:00:00	\N	ANCIEN	ELAN	projet de loi portant évolution du logement, de l'aménagement et du numérique	ELAN	du	projet de loi portant évolution du logement, de l'aménagement et du numérique	/commission/nouv/index.html	\N	ELAN	ELAN	999	\N	\N
CMP	REFORME	999	2018-11-26 00:00:00	2018-12-14 00:00:00	\N	ANCIEN	REFORME	projet de loi de programmation 2018-2022 et de réforme pour la justice	REFORME	du	projet de loi de programmation 2018-2022 et de réforme pour la justice	/commission/nouv/index.html	\N	REFORME	REFORME	999	\N	\N
CMP	JURIDICTIONS	999	2018-11-26 00:00:00	2018-12-14 00:00:00	\N	ANCIEN	JURIDICTIONS	projet de loi organique relatif au renforcement de l'organisation des juridictions	JURIDICTIONS	du	projet de loi organique relatif au renforcement de l'organisation des juridictions	/commission/nouv/index.html	\N	JURIDICTIONS	JURIDICTIONS	999	\N	\N
CMP	ORDONNANCES	999	2018-12-12 00:00:00	2018-12-18 00:00:00	\N	ANCIEN	\N	projet de loi habilitant le Gouvernement à prendre par ordonnance mesures préparation retrait Royaume-Uni de l'UE	\N	du	projet de loi habilitant le Gouvernement à prendre par ordonnance mesures préparation retrait Royaume-Uni de l'UE	/commission/nouv/index.html	\N	\N	ORDONNANCES	999	\N	\N
CMP	CRISE	999	2020-05-27 00:00:00	2020-06-03 00:00:00	\N	ANCIEN	CRISE	projet de loi relatif à diverses dispositions liées à la crise sanitaire	CRISE	du	projet de loi relatif à diverses dispositions liées à la crise sanitaire	/commission/nouv/index.html	\N	CRISE	CRISE	999	\N	\N
CMP	ELECTIONS	999	2020-06-10 00:00:00	2020-06-16 00:00:00	\N	ANCIEN	ELECTIONS	projet de loi report du 2nd tour des élections municipales	ELECTIONS	du	projet de loi report du 2nd tour des élections municipales	/commission/nouv/index.html	\N	ELECTIONS	ELECTIONS	999	\N	\N
CMP	APPROBATION	999	2020-07-08 00:00:00	2020-07-10 00:00:00	\N	ANCIEN	APPROBATION	projet de loi de règlement du budget et d'approbation des comptes de l'année 2019	APPROBATION	du	projet de loi de règlement du budget et d'approbation des comptes de l'année 2019	/commission/nouv/index.html	\N	APPROBATION	APPROBATION	999	\N	\N
CMP	CMPASAP	999	2020-10-20 00:00:00	2020-10-22 00:00:00	\N	ANCIEN	CMPASAP	projet de loi d'accélération et de simplification de l'action publique	CMPASAP	du	projet de loi d'accélération et de simplification de l'action publique	/commission/nouv/index.html	\N	CMPASAP	CMPASAP	999	\N	\N
MISINFCOM	UBER	999	2021-06-17 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	MI Uberisation	MI Uberisation	MISSION D'INFORMATION SUR LE THÈME : "UBERISATION DE LA SOCIÉTÉ : QUEL IMPACT DES PLATEFORMES NUMÉRIQUES SUR LES MÉTIERS ET L'EMPLOI ?"	\N	Mission d'information sur le thème : "Uberisation de la société : quel impact des plateformes numériques sur les métiers et l'emploi ?"	/commission/missions/uberisation_de_la_societe.html	\N	UBER	UBER	999	\N	\N
COMENQ	PENMEDIC	999	2023-01-24 00:00:00	\N	\N	ACTIF	PENMEDIC	PENMEDIC	PENMEDIC	\N	\N	/commission/nouv/index.html	\N	PENMEDIC	PENMEDIC	999	\N	\N
CMP	NUCLEAIRE	999	2023-05-04 00:00:00	2023-05-05 00:00:00	\N	ANCIEN	NUCLEAIRE	PJL Nucléaire	NUCLEAIRE	du	PJL construction nouvelles installations nucléaires à proximité sites nucléaires existants et fonctionnement installations existantes	/commission/nouv/index.html	\N	NUCLEAIRE	NUCLEAIRE	999	\N	\N
COMSPE	ESNU	999	2023-06-01 00:00:00	\N	\N	ACTIF	CS numérique	CS numérique	COMMISSION SPÉCIALE SUR LE PROJET DE LOI VISANT À SÉCURISER ET RÉGULER L'ESPACE NUMÉRIQUE	de la	commission spéciale sur le projet de loi visant à sécuriser et réguler l'espace numérique	/travaux-parlementaires/structures-temporaires/commissions-speciales/commission-speciale-sur-le-projet-de-loi-visant-a-securiser-et-reguler-lespace-numerique.html	\N	CS numérique	ESNU	999	\N	\N
CMP	PLPM	999	2023-07-10 00:00:00	2023-07-10 00:00:00	\N	ANCIEN	PLPM	LPM 2024-2030	PLPM	de la	PJL relatif à la programmation militaire pour les années 2024 à 2030 et portant diverses dispositions intéressant la défense	/commission/nouv/index.html	\N	PLPM	PLPM	999	\N	\N
CMP	PZAN	999	2023-07-06 00:00:00	2023-07-07 00:00:00	\N	ANCIEN	PZAN	PPL ZAN	PZAN	de la 	PPL visant à renforcer l'accompagnement des élus locaux dans la mise en ¿uvre de la lutte contre l'artificialisation des sols	/commission/nouv/index.html	\N	PZAN	PZAN	999	\N	\N
CMP	PCMF	999	2023-06-28 00:00:00	2023-06-29 00:00:00	\N	ANCIEN	PCMF	PJL CMF DDOM	PCMF	du	PJL ratifiant les ordonnances relatives à la partie législative du livre VII du code monétaire et financier et portant diverses dispositions relatives à l¿outre-mer	/commission/nouv/index.html	\N	PCMF	PCMF	999	\N	\N
CMP	EHAI	999	2023-06-20 00:00:00	2023-06-21 00:00:00	\N	ANCIEN	EHAI	PPL Majorité numérique	EHAI	de la	PPL visant à instaurer une majorité numérique et à lutter contre la haine en ligne	/commission/nouv/index.html	\N	EHAI	EHAI	999	\N	\N
CMP	INCE	999	2023-06-19 00:00:00	2023-06-20 00:00:00	\N	ANCIEN	INCE	PPL Risque incendie	INCE	de la	PPL visant à renforcer la prévention et la lutte contre l'intensification et l'extension du risque incendie	/commission/nouv/index.html	\N	INCE	INCE	999	\N	\N
CMP	SPOL	999	2023-07-04 00:00:00	2023-07-06 00:00:00	\N	ANCIEN	SPOL	PJL Restitution de biens culturels	SPOL	du	PJL relatif à la restitution des biens culturels ayant fait l¿objet de spoliations dans le contexte des persécutions antisémites perpétrées entre 1933 et 1945	/commission/nouv/index.html	\N	SPOL	SPOL	999	\N	\N
CMP	ACCI	999	2023-07-06 00:00:00	2023-07-06 00:00:00	\N	ANCIEN	ACCI	PPL Protection des familles	ACCI	de la	PPL visant à renforcer la protection des familles d'enfants atteints d'une maladie ou d'un handicap ou victimes d'un accident d'une particulière gravité	/commission/nouv/index.html	\N	ACCI	ACCI	999	\N	\N
CMP	RENO	999	2023-03-09 00:00:00	2023-03-10 00:00:00	\N	ANCIEN	RENO	PPL Rénovation énergétique	RENO	de la	PPL visant à ouvrir le tiers financement à l¿État, à ses établissements publics et aux collectivités territoriales pour favoriser les travaux de rénovation énergétique	/commission/nouv/index.html	\N	RENO	RENO	999	\N	\N
CMP	DADU	999	2023-02-09 00:00:00	2023-02-10 00:00:00	\N	ANCIEN	DADU	PJL DDADUE	DADU	du	PJL ortant diverses dispositions d'adaptation au droit de l'Union européenne dans les domaines de l¿économie, de la santé, du travail, des transports et de l¿agriculture	/commission/nouv/index.html	\N	DADU	DADU	999	\N	\N
CMP	PENR	999	2023-01-24 00:00:00	2023-01-25 00:00:00	\N	ANCIEN	PENR	PJL Energies renouvelables	PENR	du	PJL relatif à l¿accélération de la production d¿énergies renouvelables	/commission/nouv/index.html	\N	PENR	PENR	999	\N	\N
CMP	FIPU	999	2022-12-15 00:00:00	2022-12-16 00:00:00	\N	ANCIEN	FIPU	PJL Finances publiques 2023-2027	FIPU	du	PJL de programmation des finances publiques pour les années 2023 à 2027	/commission/nouv/index.html	\N	FIPU	FIPU	999	\N	\N
CMP	PLF23	999	2022-12-06 00:00:00	2022-12-07 00:00:00	\N	ANCIEN	PLF23	PLF 2023	PLF23	du	PJL de finances pour 2023	/commission/nouv/index.html	\N	PLF23	PLF23	999	\N	\N
CMP	OPMI	999	2022-12-01 00:00:00	2022-12-02 00:00:00	\N	ANCIEN	OPMI	PJLOPMI	OPMI	du	PJL d¿orientation et de programmation du ministère de l¿intérieur	/commission/nouv/index.html	\N	OPMI	OPMI	999	\N	\N
CMP	PLFR22	999	2022-11-22 00:00:00	2022-11-23 00:00:00	\N	ANCIEN	PLFR22	PLFR 2022	PLFR22	du	PJL de finances rectificative pour 2022	/commission/nouv/index.html	\N	PLFR22	PLFR22	999	\N	\N
CMP	EMPLOI	999	2022-11-09 00:00:00	2022-11-10 00:00:00	\N	ANCIEN	EMPLOI	PJL Plein emploi	EMPLOI	du	PJL portant mesures d¿urgence relatives au fonctionnement du marché du travail en vue du plein emploi	/commission/nouv/index.html	\N	EMPLOI	EMPLOI	999	\N	\N
CMP	PLFSS2023	999	2022-11-15 00:00:00	2022-11-16 00:00:00	\N	ANCIEN	PLFSS2023	PLFSS 2023	PLFSS2023	du	PJL de financement de la sécurité sociale pour 2023	/commission/nouv/index.html	\N	PLFSS2023	PLFSS2023	999	\N	\N
CMP	JUST	999	2023-10-05 00:00:00	2023-10-06 00:00:00	\N	ANCIEN	JUST	PJL Justice	JUST	de la	Projet de loi d¿orientation et de programmation du ministère de la justice 2023-2027	/commission/nouv/index.html	\N	JUST	JUST	999	\N	\N
CMP	INDUS	999	2023-10-09 00:00:00	2023-10-10 00:00:00	\N	ANCIEN	INDUS	PJL Industrie verte	INDUS	de la	Projet de loi relatif à l'industrie verte	/commission/nouv/index.html	\N	INDUS	INDUS	999	\N	\N
CMP	EMPLO	999	2023-10-20 00:00:00	2023-10-21 00:00:00	\N	ANCIEN	EMPLO	PJL Plein emploi	EMPLO	de la	projet de loi pour le plein emploi	/commission/nouv/index.html	\N	EMPLO	EMPLO	999	\N	\N
CMP	SANTE	999	2019-05-02 00:00:00	2019-05-16 00:00:00	\N	ANCIEN	SANTE	proposition de loi relative au droit de résiliation sans frais de contrats de complémentaire santé	SANTE	de la 	proposition de loi relative au droit de résiliation sans frais de contrats de complémentaire santé	/commission/nouv/index.html	\N	SANTE	SANTE	999	\N	\N
CMP	PROXIMITE	999	2019-11-28 00:00:00	2019-12-12 00:00:00	\N	ANCIEN	PROXIMITE	projet de loi relatif à l'engagement dans la vie locale et à la proximité de l'action publique	PROXIMITE	du	projet de loi relatif à l'engagement dans la vie locale et à la proximité de l'action publique	/commission/nouv/index.html	\N	PROXIMITE	PROXIMITE	999	\N	\N
CMP	GASPILLE	999	2019-12-18 00:00:00	2020-01-09 00:00:00	\N	ANCIEN	GASPILLE	projet de loi relatif à la lutte contre le gaspillage et à l'économie circulaire	GASPILLE	du	projet de loi relatif à la lutte contre le gaspillage et à l'économie circulaire	/commission/nouv/index.html	\N	GASPILLE	GASPILLE	999	\N	\N
COMSPE	ASAP	999	2020-02-06 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	CS ASAP	CS ASAP	COMMISSION SPÉCIALE CHARGÉE D'EXAMINER LE PROJET DE LOI D'ACCÉLÉRATION ET DE SIMPLIFICATION DE L'ACTION PUBLIQUE	de la 	Commission spéciale chargée d'examiner le projet de loi d'accélération et de simplification de l'action publique	/commission/spec/acceleration_et_simplification_de_laction_publique.html	\N	CS ASAP	ASAP	999	\N	\N
CMP	ELECTPDR	999	2021-03-02 00:00:00	2021-03-05 00:00:00	\N	ANCIEN	ELECTPDR	PJLO Élection du Président de la République	ELECTPDR	du	PJLO portant diverses mesures relatives à l¿élection du Président de la République	/commission/nouv/index.html	\N	ELECTPDR	ELECTPDR	999	\N	\N
CMP	COURTAGE	999	2021-03-10 00:00:00	2021-03-15 00:00:00	\N	ANCIEN	COURTAGE	PPL Réforme du courtage de l'assurance et du courtage en opérations de banque et en services de paiement	COURTAGE	de la	proposition de loi relative à la réforme du courtage de l'assurance et du courtage en opérations de banque et en services de paiement	/commission/nouv/index.html	\N	COURTAGE	COURTAGE	999	\N	\N
CMP	SYSANTE	999	2021-03-02 00:00:00	2021-03-05 00:00:00	\N	ANCIEN	SYSANTE	PPL Améliorer le système de santé par la confiance et la simplification	SYSANTE	de la	proposition de loi visant à améliorer le système de santé par la confiance et la simplification	/commission/nouv/index.html	\N	SYSANTE	SYSANTE	999	\N	\N
CMP	JUSTIPEN	999	2021-03-04 00:00:00	2021-03-09 00:00:00	\N	ANCIEN	JUSTIPEN	PPL améliorant l'efficacité de la justice de proximité et de la réponse pénale	JUSTIPEN	de la	proposition de loi améliorant l'efficacité de la justice de proximité et de la réponse pénale	/commission/nouv/index.html	\N	JUSTIPEN	JUSTIPEN	999	\N	\N
CMP	EAUPOTAB	999	2021-03-23 00:00:00	2021-03-25 00:00:00	\N	ANCIEN	EAUPOTAB	PPL Services publics d'eau potable et d'assainissement en Guadeloupe	EAUPOTAB	de la	proposition de loi rénovant la gouvernance des services publics d'eau potable et d'assainissement en Guadeloupe	/commission/nouv/index.html	\N	EAUPOTAB	EAUPOTAB	999	\N	\N
CMP	DETENTIO	999	2021-03-23 00:00:00	2021-03-25 00:00:00	\N	ANCIEN	DETENTIO	PPL tendant à garantir le droit au respect de la dignité en détention	DETENTIO	de la	proposition de loi tendant à garantir le droit au respect de la dignité en détention	/commission/nouv/index.html	\N	DETENTIO	DETENTIO	999	\N	\N
MISINFCOM	HARCEL	999	2021-05-12 00:00:00	2021-09-22 00:00:00	\N	ANCIEN	MI Harcèlement scolaire	MI Harcèlement scolaire	MISSION D'INFORMATION SUR LE HARCÈLEMENT SCOLAIRE ET LE CYBERHARCÈLEMENT	\N	Mission d'information sur le harcèlement scolaire et le cyberharcèlement	/commission/missions/harcelement_scolaire_et_cyberharcelement.html	\N	HARCEL	HARCEL	999	\N	\N
CMP	PJLO	999	2023-10-05 00:00:00	2023-10-06 00:00:00	\N	ANCIEN	PJLO	PJLO Justice	PJLO	de la	PJLO relatif à l'ouverture, la modernisation et la responsabilité du corps judiciaire	/commission/nouv/index.html	\N	PJLO	PJLO	999	\N	\N
CMP	SEPA	999	2021-05-12 00:00:00	2021-05-13 00:00:00	\N	ANCIEN	SEPA	PJL confortant les principes de la République et de lutte contre le séparatisme	SEPA	du	projet de loi confortant les principes de la République et de lutte contre le séparatisme	/commission/nouv/index.html	\N	SEPA	SEPA	999	\N	\N
CMP	CRIS	999	2021-05-20 00:00:00	2021-05-21 00:00:00	\N	ANCIEN	CRIS	PJL Gestion de la sortie de crise sanitaire	CRIS	du	projet de loi relatif à la gestion de la sortie de crise sanitaire	/commission/nouv/index.html	\N	CRIS	CRIS	999	\N	\N
CMP	CLIM	999	2021-07-12 00:00:00	2021-07-13 00:00:00	\N	ANCIEN	CLIM	PJL Lutte contre le dérèglement climatique et renforcement de la résilience face à ses effets	CLIM	du	projet de loi portant lutte contre le dérèglement climatique et renforcement de la résilience face à ses effets	/commission/nouv/index.html	\N	CLIM	CLIM	999	\N	\N
CMP	FR21	999	2021-07-05 00:00:00	2021-07-05 00:00:00	\N	ANCIEN	FR21	PLFR 2021	FR21	du	projet de loi de finances rectificative pour 2021	/commission/nouv/index.html	\N	FR21	FR21	999	\N	\N
CMP	OA13	999	2021-07-01 00:00:00	2021-07-02 00:00:00	\N	ANCIEN	OA13	PJLO article 13 de la Constitution	OA13	du	projet de loi organique modifiant la loi organique n° 2010-837 du 23 juillet 2010 relative à l¿application du cinquième alinéa de l¿article 13 de la Constitution	/commission/nouv/index.html	\N	OA13	OA13	999	\N	\N
CMP	OECU	999	2021-07-01 00:00:00	2021-07-02 00:00:00	\N	ANCIEN	OECU	PJL Régulation et protection oeuvres culturelles	OECU	du	projet de loi relatif à la régulation et à la protection de l¿accès aux ¿uvres culturelles à l¿ère numérique	/commission/nouv/index.html	\N	OECU	OECU	999	\N	\N
CMP	INEG	999	2021-06-24 00:00:00	2021-06-25 00:00:00	\N	ANCIEN	INEG	PJL de programmation développement solidaire et lutte contre les inégalités mondiales	INEG	du	projet de loi de programmation relatif au développement solidaire et à la lutte contre les inégalités mondiales	/commission/nouv/index.html	\N	INEG	INEG	999	\N	\N
COMENQ	NARCO	999	2023-11-08 00:00:00	\N	\N	ACTIF	CE Narcotrafic	CE Narcotrafic	COMMISSION D'ENQUÊTE SUR L'IMPACT DU NARCOTRAFIC EN FRANCE ET LES MESURES À PRENDRE POUR Y REMÉDIER	\N	commission d'enquête sur l'impact du narcotrafic en France et les mesures à prendre pour y remédier	/travaux-parlementaires/structures-temporaires/commissions-denquete/commission-denquete-sur-limpact-du-narcotrafic-en-france-et-les-mesures-a-prendre-pour-y-remedier.html	\N	CE Narcotrafic	NARCO	999	\N	\N
CMP	PLFSS	999	2023-11-17 00:00:00	2023-11-18 00:00:00	\N	ANCIEN	PLFSS	PLFSS	PLFSS	du	projet de loi de financement de la sécurité sociale pour 2024	/commission/nouv/index.html	\N	PLFSS	PLFSS	999	\N	\N
CMP	PLFFG	999	\N	2023-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	/commission/nouv/index.html	\N	\N	PLFFG	999	\N	\N
CMP	IMMI	999	2023-12-18 00:00:00	2023-12-19 00:00:00	\N	ANCIEN	IMMI	PJL Immigration	IMMI	du	projet de loi pour contrôler l'immigration, améliorer l'intégration	/commission/nouv/index.html	\N	IMMI	IMMI	999	\N	\N
CMP	PLF2024	999	2023-12-12 00:00:00	2023-12-12 00:00:00	\N	ANCIEN	PLF2024	PLF 2024	PLF2024	du	projet de loi de finances pour 2024	/commission/nouv/index.html	\N	PLF2024	PLF2024	999	\N	\N
CMP	RATP	999	2023-12-06 00:00:00	2023-12-07 00:00:00	\N	ANCIEN	RATP	PPL RATP	RATP	de la	proposition de loi relative à l'ouverture à la concurrence du réseau de bus francilien de la RATP	/commission/nouv/index.html	\N	RATP	RATP	999	\N	\N
CMP	CLIMAT	999	2019-07-17 00:00:00	2019-07-26 00:00:00	\N	ANCIEN	CLIMAT	projet de loi relatif à l'énergie et au climat	CLIMAT	du	projet de loi relatif à l'énergie et au climat	/commission/nouv/index.html	\N	CLIMAT	CLIMAT	999	\N	\N
CMP	AGENCESPORT	999	2019-07-17 00:00:00	2019-07-24 00:00:00	\N	ANCIEN	AGENCESPORT	PJL Création agence nationale du sport et JO 2024	AGENCESPORT	du	projet de loi relatif à la création de l'Agence nationale du sport et diverses dispositions relatives à l'organisation des jeux Olympiques et Paralympiques 2024	/commission/nouv/index.html	\N	AGENCESPORT	AGENCESPORT	999	\N	\N
CMP	PLF2020	999	2019-12-06 00:00:00	2019-12-12 00:00:00	\N	ANCIEN	PLF2020	projet de loi de finances pour 2020	PLF2020	du	projet de loi de finances pour 2020	/commission/nouv/index.html	\N	PLF2020	PLF2020	999	\N	\N
CMP	CONJUGALE	999	2020-06-24 00:00:00	2020-06-26 00:00:00	\N	ANCIEN	CONJUGALE	proposition de loi visant à protéger les victimes de violences conjugales	CONJUGALE	de la 	proposition de loi visant à protéger les victimes de violences conjugales	/commission/nouv/index.html	\N	CONJUGALE	CONJUGALE	999	\N	\N
CMP	RECHERCH	999	2020-11-09 00:00:00	2020-11-11 00:00:00	\N	ANCIEN	RECHERCH	projet de loi de programmation de la recherche de 2021 à 2030	RECHERCH	du	projet de loi de programmation de la recherche pour les années 2021 à 2030 et portant diverses dispositions relatives à la recherche et à l'enseignement supérieur	/commission/nouv/index.html	\N	RECHERCH	RECHERCH	999	\N	\N
COMSPE	CZAN	999	2023-02-01 00:00:00	\N	\N	ACTIF	CS Zéro artificialisation nette	CS Zéro artificialisation nette	COMMISSION SPÉCIALE SUR LA PROPOSITION DE LOI VISANT À FACILITER LA MISE EN OEUVRE DES OBJECTIFS DE « ZÉRO ARTIFICIALISATION NETTE » AU COEUR DES TERRITOIRES	de la	commission spéciale sur la proposition de loi visant à faciliter la mise en oeuvre des objectifs de « zéro artificialisation nette » au coeur des territoires	/commission/spec/cs_ppl_zero_artificialisation_nette.html	\N	CS Zéro artificialisation nette	CZAN	999	\N	\N
COMSPE	CINC	999	2023-02-01 00:00:00	\N	\N	ACTIF	CS Risque incendie	CS Risque incendie	COMMISSION SPÉCIALE SUR LA PROPOSITION DE LOI VISANT À RENFORCER LA PRÉVENTION ET LA LUTTE CONTRE L'INTENSIFICATION ET L'EXTENSION DU RISQUE INCENDIE	de la	commission spéciale sur la proposition de loi visant à renforcer la prévention et la lutte contre l'intensification et l'extension du risque incendie	/commission/spec/cs_ppl_lutte_contre_le_risque_incendie.html	\N	CS Risque incendie	CINC	999	\N	\N
CMP	FAMILLE	999	2019-11-21 00:00:00	2019-11-28 00:00:00	\N	ANCIEN	FAMILLE	proposition de loi visant à agir contre les violences au sein de la famille	FAMILLE	de la	proposition de loi visant à agir contre les violences au sein de la famille	/commission/nouv/index.html	\N	FAMILLE	FAMILLE	999	\N	\N
COMENQ	TIKTO	999	2023-03-01 00:00:00	\N	\N	ACTIF	CE Tiktok	CE Tiktok	COMMISSION D'ENQUÊTE SUR L'UTILISATION DU RÉSEAU SOCIAL TIKTOK, SON EXPLOITATION DES DONNÉES, SA STRATÉGIE D'INFLUENCE	\N	commission d'enquête sur l'utilisation du réseau social tiktok, son exploitation des données, sa stratégie d'influence	/travaux-parlementaires/structures-temporaires/commissions-denquete/commission-denquete-sur-lutilisation-du-reseau-social-tiktok-son-exploitation-des-donnees-sa-strategie-dinfluence.html	\N	CE Tiktok	TIKTO	999	\N	\N
CMP	PAPIER	999	2023-03-30 00:00:00	2023-03-31 00:00:00	\N	ANCIEN	PAPIER	PPL portant fusion des filières à responsabilité élargie des producteurs d¿emballages ménagers et de papier 	PAPIER	de la	proposition de loi portant fusion des filières à responsabilité élargie des producteurs d¿emballages ménagers et des producteurs de papier	/commission/nouv/index.html	\N	PAPIER	PAPIER	999	\N	\N
CMP	CONSO	999	2023-10-31 00:00:00	2023-11-01 00:00:00	\N	ANCIEN	CONSO	PJL grande consommation	CONSO	du	projet de loi portant mesures d'urgence pour lutter contre l¿inflation concernant les produits de grande consommation	/commission/nouv/index.html	\N	CONSO	CONSO	999	\N	\N
COMENQ	TOTA	999	2023-12-14 00:00:00	\N	\N	ACTIF	CE Obligations de TotalEnergies	CE Obligations de TotalEnergies	COMMISSION D'ENQUÊTE SUR « LES MOYENS MOBILISÉS ET MOBILISABLES PAR L'ÉTAT POUR ASSURER LA PRISE EN COMPTE ET LE RESPECT PAR LE GROUPE TOTALENERGIES DES OBLIGATIONS CLIMATIQUES ET DES ORIENTATIONS DE LA POLITIQUE ÉTRANGÈRE DE LA FRANCE »	\N	Commission d'enquête sur « les moyens mobilisés et mobilisables par l'État pour assurer la prise en compte et le respect par le groupe TotalEnergies des obligations climatiques et des orientations de la politique étrangère de la France »	/travaux-parlementaires/structures-temporaires/commissions-denquete/commission-denquete-sur-limpact-du-narcotrafic-en-france-et-les-mesures-a-prendre-pour-y-remedier.html	\N	CE Obligations de TotalEnergies	TOTA	999	\N	\N
CMP	PLFFG23	999	2023-11-21 00:00:00	2023-11-22 00:00:00	\N	ANCIEN	PLFFG23	PLFFG23	PLFFG23	du	projet de loi de finances de fin de gestion pour 2023	/commission/nouv/index.html	\N	PLFFG23	PLFFG23	999	\N	\N
CMP	SECR	999	2023-12-13 00:00:00	2023-12-13 00:00:00	\N	ANCIEN	SECR	PPL Secrétaire de mairie	SECR	de la	proposition de loi visant à revaloriser le métier de secrétaire de mairie	/commission/nouv/index.html	\N	SECR	SECR	999	\N	\N
CMP	RESTHUM	999	2023-12-06 00:00:00	2023-12-07 00:00:00	\N	ANCIEN	RESTHUM	PPL Restitution des restes humains	RESTHUM	de la	proposition de loi relative à la restitution des restes humains appartenant aux collections publiques	/commission/nouv/index.html	\N	RESTHUM	RESTHUM	999	\N	\N
CMP	SOINS	999	2023-12-07 00:00:00	2023-12-08 00:00:00	\N	ANCIEN	SOINS	PPL Accès aux soins	SOINS	de la	proposition de loi relative visant à améliorer l'accès aux soins par l¿engagement territorial des professionnels	/commission/nouv/index.html	\N	SOINS	SOINS	999	\N	\N
COMENQ	ELEC	999	2024-01-17 00:00:00	\N	\N	ACTIF	CE Electricité	CE Electricité	COMMISSION D'ENQUÊTE PORTANT SUR LA PRODUCTION, LA CONSOMMATION ET LE PRIX DE L'ÉLECTRICITÉ AUX HORIZONS 2035 ET 2050	\N	commission d'enquête portant sur la production, la consommation et le prix de l'électricité aux horizons 2035 et 2050	/travaux-parlementaires/structures-temporaires/commissions-denquete/commission-denquete-portant-sur-la-production-la-consommation-et-le-prix-de-lelectricite-aux-horizons-2035-et-2050.html	\N	ELEC	ELEC	999	\N	\N
COMENQ	COPRO	999	2024-02-01 00:00:00	\N	\N	ACTIF	CE Paupérisation des copropriétés	CE Paupérisation des copropriétés	COMMISSION D'ENQUÊTE SUR LA PAUPÉRISATION DES COPROPRIÉTÉS IMMOBILIÈRES	de la	commission d'enquête sur la paupérisation des copropriétés immobilières	/travaux-parlementaires/structures-temporaires/commissions-denquete/pauperisation-des-coproprietes-immobilieres.html	\N	CE Paupérisation des copropriétés	COPRO	999	\N	\N
COMENQ	INFLU	999	2024-02-01 00:00:00	\N	\N	ACTIF	CE Influences étrangères	CE Influences étrangères	COMMISSION D'ENQUÊTE SUR LES POLITIQUES PUBLIQUES FACE AUX OPÉRATIONS D'INFLUENCES ÉTRANGÈRES VISANT NOTRE VIE DÉMOCRATIQUE, NOTRE ÉCONOMIE ET LES INTÉRÊTS DE LA FRANCE SUR LE TERRITOIRE NATIONAL ET À L'ÉTRANGER AFIN DE DOTER NOTRE LÉGISLATION ET NOS PRATIQUES DE MOYENS D'ENTRAVES EFFICIENTS POUR CONTRECARRER LES ACTIONS HOSTILES À NOTRE SOUVERAINETÉ	de la 	commission d'enquête sur les politiques publiques face aux opérations d'influences étrangères visant notre vie démocratique, notre économie et les intérêts de la France sur le territoire national et à l'étranger afin de doter notre législation et nos pratiques de moyens d'entraves efficients pour contrecarrer les actions hostiles à notre souveraineté	/travaux-parlementaires/structures-temporaires/commissions-denquete/commission-denquete-sur-les-politiques-publiques-face-aux-operations-dinfluences-etrangeres.html	\N	CE Influences étrangères	INFLU	999	\N	\N
CMP	MUSIQUE	999	2019-07-24 00:00:00	2019-09-14 00:00:00	\N	ANCIEN	MUSIQUE	proposition de loi relative à la création d'un Centre national de la musique	MUSIQUE	de la 	proposition de loi relative à la création d'un Centre national de la musique	/commission/nouv/index.html	\N	MUSIQUE	MUSIQUE	999	\N	\N
CMP	PRESSE	999	2019-07-24 00:00:00	2019-09-25 00:00:00	\N	ANCIEN	PRESSE	projet de loi relatif à la modernisation de la distribution de la presse	PRESSE	du	projet de loi relatif à la modernisation de la distribution de la presse	/commission/nouv/index.html	\N	PRESSE	PRESSE	999	\N	\N
COMENQ	RADICALI	999	2019-11-14 00:00:00	2020-07-07 00:00:00	\N	ANCIEN	CE combattre la radicalisation islamiste	CE combattre la radicalisation islamiste	COMMISSION D'ENQUÊTE SUR LE DÉVELOPPEMENT DE LA RADICALISATION ISLAMISTE ET LES MOYENS DE LE COMBATTRE	de la	Commission d'enquête sur le développement de la radicalisation islamiste et les moyens de le combattre	/commission/enquete/radicalisation_islamiste.html	\N	CE combattre la radicalisation	RADICALI	999	\N	\N
CMP	PLFR2019	999	2019-11-15 00:00:00	2019-11-20 00:00:00	\N	ANCIEN	PLFR2019	projet de loi de finances rectificative pour 2019	PLFR2019	du	projet de loi de finances rectificative pour 2019	/commission/nouv/index.html	\N	PLFR2019	PLFR2019	999	\N	\N
CMP	PJLO13	999	2020-01-28 00:00:00	2020-02-05 00:00:00	\N	ANCIEN	PJLO13	PJLO modifiant la loi organique relative à l'application du cinquième alinéa de l'article 13 de la Constitution	PJLO13	du	PJLO modifiant la loi organique relative à l'application du cinquième alinéa de l'article 13 de la Constitution	/commission/nouv/index.html	\N	PJLO13	PJLO13	999	\N	\N
CMP	HADOPI	999	2020-01-28 00:00:00	2020-02-05 00:00:00	\N	ANCIEN	HADOPI	PJL modifiant article 13 de la Constitution et prorogeant mandat membres HADOPI	HADOPI	du	PJL modifiant article 13 de la Constitution et prorogeant mandat membres HADOPI	/commission/nouv/index.html	\N	HADOPI	HADOPI	999	\N	\N
CMP	HAINE	999	2019-12-18 00:00:00	2020-01-09 00:00:00	\N	ANCIEN	HAINE	proposition de loi visant à lutter contre les contenus haineux sur internet	HAINE	de la	proposition de loi visant à lutter contre les contenus haineux sur internet	/commission/nouv/index.html	\N	HAINE	HAINE	999	\N	\N
CMP	DEMARCHAGE	999	2020-06-24 00:00:00	2020-07-02 00:00:00	\N	ANCIEN	DEMARCHAGE	proposition de loi visant à encadrer le démarchage téléphonique et à lutter contre les appels frauduleux	DEMARCHAGE	de la	proposition de loi visant à encadrer le démarchage téléphonique et à lutter contre les appels frauduleux	/commission/nouv/index.html	\N	DEMARCHAGE	DEMARCHAGE	999	\N	\N
CMP	CHEQUEVAC	999	2020-06-24 00:00:00	2020-07-03 00:00:00	\N	ANCIEN	CHEQUEVAC	projet de loi permettant le don de congés payés sous forme de chèques-vacances aux membres du secteur médico-social 	CHEQUEVAC	du	projet de loi permettant le don de congés payés sous forme de chèques-vacances aux membres du secteur médico-social en reconnaissance de leur action durant l'épidémie de Covid-19	/commission/nouv/index.html	\N	CHEQUEVAC	CHEQUEVAC	999	\N	\N
CMP	DETTESOCIALE	999	2020-07-01 00:00:00	2020-07-09 00:00:00	\N	ANCIEN	DETTESOCIALE	projet de loi relatif à la dette sociale et à l'autonomie	DETTESOCIALE	du	projet de loi relatif à la dette sociale et à l'autonomie	/commission/nouv/index.html	\N	DETTESOCIALE	DETTESOCIALE	999	\N	\N
CMP	AUTONOMIE	999	2020-07-01 00:00:00	2020-07-09 00:00:00	\N	ANCIEN	AUTONOMIE	projet de loi organique relatif à la dette sociale et à l'autonomie	AUTONOMIE	du	projet de loi organique relatif à la dette sociale et à l'autonomie	/commission/nouv/index.html	\N	AUTONOMIE	AUTONOMIE	999	\N	\N
CMP	CSE	999	2020-10-30 00:00:00	2020-11-02 00:00:00	\N	ANCIEN	\N	PJL Prorogation de l'état d'urgence sanitaire et portant diverses dispositions de gestion de la crise sanitaire	\N	du	projet de loi de prorogation de l'état d'urgence sanitaire et portant diverses dispositions de gestion de la crise sanitaire	/commission/nouv/index.html	\N	\N	CSE	999	\N	\N
CMP	CESE	999	2020-10-30 00:00:00	2020-11-02 00:00:00	\N	ANCIEN	CESE	projet de loi organique relatif au conseil économique, social et environnemental	CESE	du	projet de loi organique relatif au conseil économique, social et environnemental	/commission/nouv/index.html	\N	CESE	CESE	999	\N	\N
CMP	PHYT	999	2020-10-29 00:00:00	2020-11-02 00:00:00	\N	ANCIEN	PHYT	PJL produits phytopharmaceutiques en cas de danger sanitaire pour les betteraves sucrières	PHYT	du	projet de loi relatif aux conditions de mise sur le marché de certains produits phytopharmaceutiques en cas de danger sanitaire pour les betteraves sucrières	/commission/nouv/index.html	\N	PHYT	PHYT	999	\N	\N
MISINFCOM	ENSAGRIC	999	2021-02-03 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	MI Enseignement agricole	MI Enseignement agricole	MISSION D'INFORMATION SUR L'ENSEIGNEMENT AGRICOLE, OUTIL INDISPENSABLE AU COEUR DES ENJEUX DE NOS FILIÈRES AGRICOLES ET ALIMENTAIRES	de la	mission d'information sur l'enseignement agricole, outil indispensable au coeur des enjeux de nos filières agricoles et alimentaires	/commission/missions/enseignement_agricole_outil_indispensable_au_coeur_des_enjeux_de_nos_filieres_agricoles_et_alimentaires.html	\N	MI Enseignement agricole	ENSAGRIC	999	\N	\N
MISINFCOM	BIOCARBU	999	2023-01-17 00:00:00	\N	\N	ACTIF	MI Biocarburants	MI Biocarburants	MISSION D'INFORMATION SUR LE THÈME : « LE DÉVELOPPEMENT D'UNE FILIÈRE DE BIOCARBURANTS, CARBURANTS SYNTHÉTIQUES DURABLES ET HYDROGÈNE VERT »	de la	Mission d'information sur le thème : « Le développement d'une filière de biocarburants, carburants synthétiques durables et hydrogène vert »	/travaux-parlementaires/structures-temporaires/missions-dinformation-communes/mission-dinformation-sur-le-developpement-dune-filiere-de-biocarburants-carburants-synthetiques-durables-et-hydrogene-vert.html	\N	MI Biocarburants	BIOCARBU	999	\N	\N
MISINFCOM	LOCA	999	2023-02-15 00:00:00	\N	\N	ACTIF	MI Finances locales	MI Finances locales	MISSION D'INFORMATION SUR " L'IMPACT DES DÉCISIONS RÉGLEMENTAIRES ET BUDGÉTAIRES DE L'ÉTAT SUR L'ÉQUILIBRE FINANCIER DES COLLECTIVITÉS LOCALES "	de la	mission d'information sur "l'impact des décisions réglementaires et budgétaires de l'Etat sur l'équilibre financier des collectivités locales"	/travaux-parlementaires/structures-temporaires/missions-dinformation-communes/mission-dinformation-sur-limpact-des-decisions-reglementaires-et-budgetaires-de-letat-sur-lequilibre-financier-des-collectivites-locales.html	\N	MI Finances locales	LOCA	999	\N	\N
CMP	LOCATIF	999	2023-06-05 00:00:00	2023-06-06 00:00:00	\N	ANCIEN	LOCATIF	PPL Indices locatifs	LOCATIF	de la 	PPL maintenant provisoirement un dispositif de plafonnement de revalorisation de la variation annuelle des indices locatifs	/commission/nouv/index.html	\N	LOCATIF	LOCATIF	999	\N	\N
COMSPE	DDADUE23	999	2023-10-30 00:00:00	\N	\N	ACTIF	CS DDADUE	CS sur le projet de loi portant diverses dispositions d'adaptation au droit de l'Union européenne	COMMISSION SPÉCIALE SUR LE PROJET DE LOI PORTANT DIVERSES DISPOSITIONS D'ADAPTATION AU DROIT DE L'UNION EUROPÉENNE	de la	commission spéciale sur le projet de loi portant diverses dispositions d'adaptation au droit de l'Union européenne	/travaux-parlementaires/structures-temporaires/commissions-speciales/projet-de-loi-portant-diverses-dispositions-dadaptation-au-droit-de-lunion-europeenne-en-matiere-deconomie-de-finances-de-transition-ecologique-de-droit-penal-de-droit-social-et-en-matiere-agricole.html	\N	CS DDADUE	DDADUE23	999	\N	\N
CMP	PARTAGE	999	2023-11-15 00:00:00	2023-11-16 00:00:00	\N	ANCIEN	PARTAGE	PJL Partage de la valeur	PARTAGE	du	projet de loi portant transposition de l'accord national interprofessionnel relatif au partage de la valeur au sein de l'entreprise	/commission/nouv/index.html	\N	PARTAGE	PARTAGE	999	\N	\N
CMP	ECOLE	999	2019-06-05 00:00:00	2019-06-14 00:00:00	\N	ANCIEN	ECOLE	projet de loi pour une école de la confiance	ECOLE	du	projet de loi pour une école de la confiance	/commission/nouv/index.html	\N	ECOLE	ECOLE	999	\N	\N
CMP	SYSTEME	999	2019-06-05 00:00:00	2019-06-20 00:00:00	\N	ANCIEN	SYSTEME	projet de loi relatif à l'organisation et à la transformation du système de santé	SYSTEME	du	projet de loi relatif à l'organisation et à la transformation du système de santé	/commission/nouv/index.html	\N	SYSTEME	SYSTEME	999	\N	\N
CMP	MOBILITES	999	2019-07-03 00:00:00	2019-07-11 00:00:00	\N	ANCIEN	MOBILITES	projet de loi d'orientation des mobilités	MOBILITES	du	projet de loi d'orientation des mobilités	/commission/nouv/index.html	\N	MOBILITES	MOBILITES	999	\N	\N
CMP	ALSACE	999	2019-07-03 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	ALSACE	projet de loi relatif aux compétences de la Collectivité européenne d'Alsace	ALSACE	du	projet de loi relatif aux compétences de la Collectivité européenne d'Alsace	/commission/nouv/index.html	\N	ALSACE	ALSACE	999	\N	\N
CMP	PLFSS2020	999	2019-11-14 00:00:00	2019-11-20 00:00:00	\N	ANCIEN	PLFSS2020	projet de loi de financement de la sécurité sociale pour 2020	PLFSS2020	du	projet de loi de financement de la sécurité sociale pour 2020	/commission/nouv/index.html	\N	PLFSS2020	PLFSS2020	999	\N	\N
CMP	IFAM	999	2024-02-15 00:00:00	2024-02-16 00:00:00	\N	ANCIEN	IFAM	PPL Violences intrafamiliales	IFAM	de la	proposition de loi visant à mieux protéger et accompagner les enfants victimes et covictimes de violences intrafamiliales	/commission/nouv/index.html	\N	IFAM	IFAM	999	\N	\N
MISINFCOM	GUYANE	999	2020-05-13 00:00:00	2020-09-15 00:00:00	\N	ANCIEN	MI Trafic de stupéfiants en provenance de Guyane	MI Trafic de stupéfiants en provenance de Guyane	MISSION D'INFORMATION SUR LE TRAFIC DE STUPÉFIANTS EN PROVENANCE DE GUYANE	de la	Mission d'information sur le trafic de stupéfiants en provenance de Guyane	/commission/missions/trafic_de_stupefiants_en_provenance_de_guyane.html	\N	MI Trafic de stupéfiants en provenance de Guyane	GUYANE	999	\N	\N
CMP	DDADUEF	999	2020-10-22 00:00:00	2020-10-23 00:00:00	\N	ANCIEN	DDADUEF	PJL portant diverses dispositions d'adaptation au droit de l'UE en matière économique et financière	DDADUEF	du	projet de loi portant diverses dispositions d'adaptation au droit de l'Union européenne en matière économique et financière	/commission/nouv/index.html	\N	DDADUEF	DDADUEF	999	\N	\N
COMENQ	PANDEMIE	999	2020-07-01 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	CE Évaluation des politiques publiques face aux pandémies	CE Évaluation des politiques publiques face aux pandémies	COMMISSION D'ENQUÊTE POUR L'ÉVALUATION DES POLITIQUES PUBLIQUES FACE AUX GRANDES PANDÉMIES À LA LUMIÈRE DE LA CRISE SANITAIRE DE LA COVID-19 ET DE SA GESTION	de la	commission d'enquête pour l'évaluation des politiques publiques face aux grandes pandémies à la lumière de la crise sanitaire de la covid-19 et de sa gestion	/commission/enquete/gestion_de_la_crise_sanitaire.html	\N	CE Évaluation des politiques publiques face aux pandémies	PANDEMIE	999	\N	\N
CMP	CSI	999	2020-10-22 00:00:00	2020-10-23 00:00:00	\N	ANCIEN	CSI	PJL Code de la sécurité intérieure	CSI	du	projet de loi relatif à la prorogation des chapitres VI à X du titre II du livre II et de l'article L. 851-3 du code de la sécurité intérieure	/commission/nouv/index.html	\N	CSI	CSI	999	\N	\N
MISINFCOM	PAUP	999	2021-01-13 00:00:00	2021-09-15 00:00:00	\N	ANCIEN	MI Lutte contre la précarisation et la paupérisation	MI Lutte contre la précarisation et la paupérisation	MISSION D'INFORMATION SUR L'ÉVOLUTION ET LA LUTTE CONTRE LA PRÉCARISATION ET LA PAUPÉRISATION D'UNE PARTIE DES FRANÇAIS	de la	mission d'information sur l'évolution et la lutte contre la précarisation et la paupérisation d'une partie des français	/commission/missions/lutte_contre_la_precarisation_et_la_pauperisation_dune_partie_des_francais.html	\N	MI Lutte contre la précarisation et la paupérisation	PAUP	999	\N	\N
CMP	PARQUETEURO	999	2020-12-15 00:00:00	2020-12-16 00:00:00	\N	ANCIEN	PARQUETEURO	PJL Parquet européen, justice environnementale et justice pénale spécialisée	PARQUETEURO	du	projet de loi relatif au Parquet européen, à la justice environnementale et à la justice pénale spécialisée	/commission/nouv/index.html	\N	PARQUETEURO	PARQUETEURO	999	\N	\N
CMP	URGSAN	999	2021-01-28 00:00:00	2021-01-29 00:00:00	\N	ANCIEN	URGSAN	projet de loi prorogeant l'état d'urgence sanitaire	URGSAN	du	projet de loi prorogeant l'état d'urgence sanitaire	/commission/nouv/index.html	\N	URGSAN	URGSAN	999	\N	\N
CMP	JUSTMINEURS	999	2021-02-04 00:00:00	2021-02-05 00:00:00	\N	ANCIEN	JUSTMINEURS	PJL Code de la justice pénale des mineurs	JUSTMINEURS	du	projet de loi ratifiant l'ordonnance n° 2019-950 du 11 septembre 2019 portant partie législative du code de la justice pénale des mineurs	/commission/nouv/index.html	\N	JUSTMINEURS	JUSTMINEURS	999	\N	\N
CMP	BIOETHIQ	999	2021-02-17 00:00:00	2021-02-19 00:00:00	\N	ANCIEN	BIOETHIQ	projet de loi relatif à la bioéthique	BIOETHIQ	du	projet de loi relatif à la bioéthique	/commission/nouv/index.html	\N	BIOETHIQ	BIOETHIQ	999	\N	\N
CMP	REPORT	999	2021-02-11 00:00:00	2021-02-15 00:00:00	\N	ANCIEN	REPORT	PJL Report des conseils départementaux, régionaux et assemblées de Corse, Guyane et Martinique	REPORT	du	PJL portant report du renouvellement général des conseils départementaux, des conseils régionaux et des assemblées de Corse, de Guyane et de Martinique	/commission/nouv/index.html	\N	REPORT	REPORT	999	\N	\N
MISINFCOM	INFLUENCES	999	2021-06-24 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	MI Influences étatiques	MI Influences étatiques	MISSION D'INFORMATION SUR LE THÈME : « LES INFLUENCES ÉTATIQUES EXTRA-EUROPÉENNES DANS LE MONDE UNIVERSITAIRE ET ACADÉMIQUE FRANÇAIS ET LEURS INCIDENCES »	de la	mission d'information sur le thème : « les influences étatiques extra-européennes dans le monde universitaire et académique français et leurs incidences »	/commission/missions/influences_etatiques_extra_europeennes.html	\N	MI Influences étatiques	INFLUENCES	999	\N	\N
CMP	ENFA	999	2023-06-01 00:00:00	2023-06-02 00:00:00	\N	ANCIEN	ENFA	PPL Droit à l'image des enfants	ENFA	de la	visant à garantir le respect du droit à l¿image des enfants	/commission/nouv/index.html	\N	ENFA	ENFA	999	\N	\N
CMP	INFL	999	2023-05-25 00:00:00	2023-05-26 00:00:00	\N	ANCIEN	INFL	PPL Influenceurs	INFL	de la	PPL visant à encadrer l¿influence commerciale et à lutter contre les dérives des influenceurs sur les réseaux sociaux	/commission/nouv/index.html	\N	INFL	INFL	999	\N	\N
CMP	INTE	999	2023-05-04 00:00:00	2023-05-05 00:00:00	\N	ANCIEN	INTE	PPL Interruption spontanée de grossesse	INTE	de la	PPL visant à favoriser l¿accompagnement des couples confrontés à une interruption spontanée de grossesse	/commission/nouv/index.html	\N	INTE	INTE	999	\N	\N
CMP	JOPA	999	2023-04-04 00:00:00	2023-04-05 00:00:00	\N	ANCIEN	JOPA	PJL Jeux Olympiques et Paralympiques 2024	JOPA	du	PJL relatif aux jeux Olympiques et Paralympiques de 2024 et portant diverses autres dispositions	/commission/nouv/index.html	\N	JOPA	JOPA	999	\N	\N
CMP	SOIN	999	2023-04-06 00:00:00	2023-04-07 00:00:00	\N	ANCIEN	SOIN	PPL Accès aux soins	SOIN	de la	PPL portant amélioration de l'accès aux soins par la confiance aux professionnels de santé	/commission/nouv/index.html	\N	SOIN	SOIN	999	\N	\N
CMP	SER	999	2023-11-07 00:00:00	2023-11-08 00:00:00	\N	ANCIEN	SER	PPL SER	SER	de la	proposition de loi relative aux services express régionaux métropolitains	/commission/nouv/index.html	\N	SER	SER	999	\N	\N
CMP	GAFA	999	2019-06-05 00:00:00	2019-06-27 00:00:00	\N	ANCIEN	GAFA	projet de loi portant création d'une taxe sur les services numériques	GAFA	du	projet de loi portant création d'une taxe sur les services numériques et modification de la trajectoire de baisse de l'impôt sur les sociétés	/commission/nouv/index.html	\N	GAFA	GAFA	999	\N	\N
CMP	OFBC	999	2019-05-22 00:00:00	2019-06-26 00:00:00	\N	ANCIEN	OFBC	projet de loi portant création de l'OFBC	OFBC	du	projet de loi portant création de l'Office français de la biodiversité et de la chasse	/commission/nouv/index.html	\N	OFBC	OFBC	999	\N	\N
CMP	ARTICLE13	999	2019-05-22 00:00:00	2019-06-26 00:00:00	\N	ANCIEN	ARTICLE13	projet de loi portant organique relative à l'application de l'article 13 de la Constitution	ARTICLE13	du	projet de loi organique relative à l'application du cinquième alinéa de l'article 13 de la Constitution	/commission/nouv/index.html	\N	ARTICLE13	ARTICLE13	999	\N	\N
CMP	FONCTION	999	2019-06-20 00:00:00	2019-07-04 00:00:00	\N	ANCIEN	FONCTION	projet de loi de transformation de la fonction publique	FONCTION	du	projet de loi de transformation de la fonction publique	/commission/nouv/index.html	\N	FONCTION	FONCTION	999	\N	\N
CMP	RADIO	999	2019-06-26 00:00:00	2019-07-04 00:00:00	\N	ANCIEN	RADIO	proposition de loi visant à préserver les intérêts dans le cadre de l'exploitation des réseaux radioélectriques mobiles	RADIO	de la	proposition de loi visant à préserver les intérêts de la défense et de la sécurité nationale de la France dans le cadre de l'exploitation des réseaux radioélectriques mobiles	/commission/nouv/index.html	\N	RADIO	RADIO	999	\N	\N
MISINFCOM	MARITIME	999	2019-06-25 00:00:00	2019-10-22 00:00:00	\N	ANCIEN	MCI relative au sauvetage en mer	MCI relative au sauvetage en mer	MISSION COMMUNE D'INFORMATION RELATIVE AU SAUVETAGE EN MER	de la	Mission commune d'information relative au sauvetage en mer	/commission/missions/securite_maritime.html	\N	MCI relative au sauvetage en mer	MARITIME	999	\N	\N
COMSPE	BIOETHIQUE	999	2019-10-16 00:00:00	2021-08-02 00:00:00	\N	ANCIEN	Commission spéciale sur la bioéthique	Commission spéciale sur la bioéthique	COMMISSION SPECIALE SUR LE PROJET DE LOI RELATIF A LA BIOETHIQUE	de la	Commission spéciale sur le projet de loi relatif à la bioéthique	/commission/spec/bioethique.html	\N	Commission spéciale sur la bioéthique	BIOETHIQUE	999	\N	\N
COMENQ	LUBRIZOL	999	2019-10-16 00:00:00	2020-06-02 00:00:00	\N	ANCIEN	Commission d'enquête sur l'incendie de l'usine Lubrizol	Commission d'enquête sur l'incendie de l'usine Lubrizol	COMMISSION D'ENQUÊTE CHARGÉE D'ÉVALUER LA GESTION DES CONSÉQUENCES DE L'INCENDIE DE L'USINE LUBRIZOL	de la	Commission d'enquête chargée d'évaluer la gestion des conséquences de l'incendie de l'usine Lubrizol	/commission/enquete/incendie_de_lusine_lubrizol.html	\N	Commission d'enquête sur l'incendie de l'usine Lubrizol	LUBRIZOL	999	\N	\N
COMENQ	AUTOROUT	999	2020-01-29 00:00:00	2020-09-16 00:00:00	\N	ANCIEN	CE sur l'évolution des concessions autoroutières	CE sur l'évolution des concessions autoroutières	COMMISSION D'ENQUÊTE SUR LE CONTRÔLE, LA RÉGULATION ET L'ÉVOLUTION DES CONCESSIONS AUTOROUTIÈRES	\N	Commission d'enquête sur le contrôle, la régulation et l'évolution des concessions autoroutières	/commission/enquete/concessions_autoroutieres.html	\N	CE sur l'évolution des concessions autoroutières	AUTOROUT	999	\N	\N
MISINFCOM	DEPARTEMENT	999	2020-02-19 00:00:00	2020-09-15 00:00:00	\N	ANCIEN	MI Compétences des départements	MI Compétences des départements	MISSION D'INFORMATION « QUEL RÔLE, QUELLE PLACE, QUELLES COMPÉTENCES DES DÉPARTEMENTS DANS LES RÉGIONS FUSIONNÉES AUJOURD'HUI ET DEMAIN ? »	de la	Mission d'information « Quel rôle, quelle place, quelles compétences des départements dans les régions fusionnées aujourd'hui et demain ? »	/commission/missions/competences_des_departements_dans_les_regions_fusionnees.html	\N	MI Compétences des départements	DEPARTEMENT	999	\N	\N
MISINFCOM	FEDERATION	999	2020-03-04 00:00:00	2020-09-08 00:00:00	\N	ANCIEN	MI Fonctionnement fédérations sportives	MI Fonctionnement fédérations sportives	MISSION D'INFORMATION SUR LE FONCTIONNEMENT ET L'ORGANISATION DES FÉDÉRATIONS SPORTIVES	de la 	Mission d'information sur le fonctionnement et l'organisation des fédérations sportives	/commission/missions/fonctionnement_des_federations_sportives.html	\N	MI Fonctionnement fédérations sportives	FEDERATION	999	\N	\N
MISINFCOM	CONF	999	2021-01-13 00:00:00	2021-11-18 00:00:00	\N	ANCIEN	MCI Effets des mesures en matière de confinement	MCI Effets des mesures en matière de confinement	MISSION COMMUNE D'INFORMATION CHARGÉE D'ÉVALUER LES EFFETS DES MESURES PRISES OU ENVISAGÉES EN MATIÈRE DE CONFINEMENT OU DE RESTRICTIONS D'ACTIVITÉS	de la	mission commune d'information chargée d'évaluer les effets des mesures prises ou envisagées en matière de confinement ou de restrictions d'activités	/commission/missions/evaluations_des_mesures_en_matiere_de_confinement.html	\N	MCI Effets des mesures en matière de confinement	CONF	999	\N	\N
MISINFCOM	EGALCHAN	999	2021-02-03 00:00:00	2021-09-23 00:00:00	\N	ANCIEN	MI Égalité des chances	MI Égalité des chances	MISSION D'INFORMATION SUR LA POLITIQUE EN FAVEUR DE L'ÉGALITÉ DES CHANCES ET DE L'ÉMANCIPATION DE LA JEUNESSE	de la	mission d'information sur la politique en faveur de l'égalité des chances et de l'émancipation de la jeunesse	/commission/missions/politique_en_faveur_de_legalite_des_chances_et_de_lemancipation_de_la_jeunesse.html	\N	MI Égalité des chances	EGALCHAN	999	\N	\N
CMP	SEGL	999	2021-03-29 00:00:00	2021-04-02 00:00:00	\N	ANCIEN	SEGL	PPL Sécurité globale	SEGL	de la	proposition de loi pour un nouveau pacte de sécurité respectueux des libertés	/commission/nouv/index.html	\N	SEGL	SEGL	999	\N	\N
CMP	PPLEGALIM	999	2021-10-04 00:00:00	2021-10-05 00:00:00	\N	ANCIEN	PPLEGALIM	Proposition de loi visant à protéger la rémunération des agriculteurs	PPLEGALIM	de la	Proposition de loi visant à protéger la rémunération des agriculteurs	/commission/nouv/index.html	\N	PPLEGALIM	PPLEGALIM	999	\N	\N
CMP	PPLPOMPIERS	999	2021-10-07 00:00:00	2021-10-08 00:00:00	\N	ANCIEN	PPLPOMPIERS	Proposition de loi sapeurs pompiers	PPLPOMPIERS	de la	Proposition de loi visant à consolider notre modèle de sécurité civile et valoriser le volontariat des sapeurs pompiers et les sapeurs pompiers professionnels 	/commission/nouv/index.html	\N	PPLPOMPIERS	PPLPOMPIERS	999	\N	\N
MISINFCOM	CULTURE	999	2021-11-18 00:00:00	2022-06-07 00:00:00	\N	ANCIEN	MI Culture citoyenne	MI Culture citoyenne	MISSION D'INFORMATION SUR LE THÈME : " COMMENT REDYNAMISER LA CULTURE CITOYENNE ?"	de la	mission d'information sur le thème : " comment redynamiser la culture citoyenne ?"	/commission/missions/2021_culture_citoyenne.html	\N	MI Culture citoyenne	CULTURE	999	\N	\N
MISINFCOM	SECUECO	999	2021-11-18 00:00:00	2022-03-30 00:00:00	\N	ANCIEN	MI Sécurité sociale écologique	MI Sécurité sociale écologique	MISSION D'INFORMATION SUR LE THÈME " PROTÉGER ET ACCOMPAGNER LES INDIVIDUS EN CONSTRUISANT LA SÉCURITÉ SOCIALE ÉCOLOGIQUE DU XXIÈME SIÈCLE "	de la	mission d'information sur le thème " Protéger et accompagner les individus en construisant la sécurité sociale écologique du XXIème siècle "	/commission/missions/2021_securite_sociale_ecologique_du_xxieme_siecle.html	\N	MI Sécurité sociale écologique	SECUECO	999	\N	\N
CMP	POLYNESIE2	999	2019-04-30 00:00:00	2019-05-08 00:00:00	\N	ANCIEN	POLYNESIE2	projet de loi organique portant modification du statut d'autonomie de la Polynésie française	POLYNESIE2	du	projet de loi organique portant modification du statut d'autonomie de la Polynésie française	/commission/nouv/index.html	\N	POLYNESIE2	POLYNESIE2	999	\N	\N
CMP	POLYNESIE3	999	2019-04-30 00:00:00	2019-05-08 00:00:00	\N	ANCIEN	POLYNESIE3	projet de loi portant diverses dispositions institutionnelles en Polynésie française	POLYNESIE3	du	projet de loi portant diverses dispositions institutionnelles en Polynésie française	/commission/nouv/index.html	\N	POLYNESIE3	POLYNESIE3	999	\N	\N
CMP	SECT	999	2024-02-27 00:00:00	2024-02-28 00:00:00	\N	ANCIEN	SECT	PPL Protection des élus	SECT	de la	proposition de loi renforçant la sécurité et la protection des maires et des élus locaux	/commission/nouv/index.html	\N	SECT	SECT	999	\N	\N
MISINFCOM	FONDS	999	2019-05-22 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	MI sous-utilisation fonds européens en France	MI sous-utilisation fonds européens en France	MISSION D'INFORMATION SUR LA SOUS-UTILISATION CHRONIQUE DES FONDS EUROPÉENS EN FRANCE	de la 	Mission d'information sur la sous-utilisation chronique des fonds européens en France	/commission/missions/sous_utilisation_des_fonds_europeens.html	\N	MI sous-utilisation fonds européens en France	FONDS	999	\N	\N
CMP	COMPTES2018	999	2019-07-11 00:00:00	2019-07-17 00:00:00	\N	ANCIEN	COMPTES2018	projet de loi de règlement du budget et d'approbation des comptes pour l'année 2018	COMPTES2018	du 	projet de loi de règlement du budget et d'approbation des comptes pour l'année 2018	/commission/nouv/index.html	\N	COMPTES2018	COMPTES2018	999	\N	\N
COMENQ	SOLS	999	2020-02-05 00:00:00	2020-09-08 00:00:00	\N	ANCIEN	CE Pollution des sols	CE Pollution des sols	COMMISSION D'ENQUÊTE SUR LES PROBLÈMES SANITAIRES ET ÉCOLOGIQUES LIÉS AUX POLLUTIONS DES SOLS QUI ONT ACCUEILLI DES ACTIVITÉS INDUSTRIELLES OU MINIÈRES ET SUR LES POLITIQUES PUBLIQUES ET INDUSTRIELLES DE RÉHABILITATION DE CES SOLS	de la	Commission d'enquête sur les problèmes sanitaires et écologiques liés aux pollutions des sols qui ont accueilli des activités industrielles ou minières et sur les politiques publiques et industrielles de réhabilitation de ces sols	/commission/enquete/pollution_des_sols.html	\N	CE Pollution des sols	SOLS	999	\N	\N
CMP	SORTIE	999	2020-06-22 00:00:00	2020-06-26 00:00:00	\N	ANCIEN	SORTIE	projet de loi organisant la sortie de l'état d'urgence sanitaire	SORTIE	du	projet de loi organisant la sortie de l'état d'urgence sanitaire	/commission/nouv/index.html	\N	SORTIE	SORTIE	999	\N	\N
CMP	BIENCULT	999	2020-11-19 00:00:00	2020-11-20 00:00:00	\N	ANCIEN	BIENCULT	PJL Restitution biens culturels Bénin Sénégal	BIENCULT	du	projet de loi relatif au retour de biens culturels à la République du Bénin et à la République du Sénégal	/commission/nouv/index.html	\N	BIENCULT	BIENCULT	999	\N	\N
CMP	PLFSS21	999	2020-11-12 00:00:00	2020-11-20 00:00:00	\N	ANCIEN	PLFSS21	PLFSS pour 2021	PLFSS21	du	projet de loi de financement de la sécurité sociale pour 2021	/commission/nouv/index.html	\N	PLFSS21	PLFSS21	999	\N	\N
CMP	PLFR420	999	2020-11-17 00:00:00	2020-12-18 00:00:00	\N	ANCIEN	PLFR420	PLFR4 pour 2020	PLFR420	du	projet de loi de finances rectificative pour 2020 (4)	/commission/nouv/index.html	\N	PLFR420	PLFR420	999	\N	\N
CMP	PLF2021	999	2020-12-09 00:00:00	2020-12-10 00:00:00	\N	ANCIEN	PLF2021	PLF pour 2021	PLF2021	du	projet de loi de finances pour 2021	/commission/nouv/index.html	\N	PLF2021	PLF2021	999	\N	\N
CMP	PJLOELEC	999	2020-12-10 00:00:00	2020-12-11 00:00:00	\N	ANCIEN	PJLOELEC	projet de loi organique relatif aux délais d'organisation des élections législatives et sénatoriales	PJLOELEC	du	projet de loi organique relatif aux délais d'organisation des élections législatives et sénatoriales	/commission/nouv/index.html	\N	PJLOELEC	PJLOELEC	999	\N	\N
CMP	PJLELEC	999	2020-12-10 00:00:00	2020-12-11 00:00:00	\N	ANCIEN	PJLELEC	PJL Délais d'organisation des élections municipales partielles et des élections des membres des commissions syndicales	PJLELEC	du	projet de loi relatif aux délais d'organisation des élections municipales partielles et des élections des membres des commissions syndicales	/commission/nouv/index.html	\N	PJLELEC	PJLELEC	999	\N	\N
COMENQ	CABINETS	999	2021-11-18 00:00:00	2022-03-16 00:00:00	\N	ANCIEN	CE Cabinets de conseil	CE Cabinets de conseil	COMMISSION D'ENQUÊTE SUR L'INFLUENCE CROISSANTE DES CABINETS DE CONSEIL PRIVÉS SUR LES POLITIQUES PUBLIQUES	de la	commission d'enquête sur l'influence croissante des cabinets de conseil privés sur les politiques publiques	/commission/enquete/2021_influence_des_cabinets_de_conseil_prives.html	\N	CE Cabinets de conseil	CABINETS	999	\N	\N
COMENQ	MEDIA	999	2021-11-18 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	CE Concentration dans les médias	CE Concentration dans les médias	COMMISSION D'ENQUÊTE " AFIN DE METTRE EN LUMIÈRE LES PROCESSUS AYANT PERMIS OU POUVANT ABOUTIR À UNE CONCENTRATION DANS LES MÉDIAS EN FRANCE, ET D'ÉVALUER L'IMPACT DE CETTE CONCENTRATION SUR LA DÉMOCRATIE"	de la	commission d'enquête " afin de mettre en lumière les processus ayant permis ou pouvant aboutir à une concentration dans les médias en France, et d'évaluer l'impact de cette concentration sur la démocratie "	/commission/enquete/2021_concentration_des_medias_en_france.html	\N	CE Concentration dans les médias	MEDIA	999	\N	\N
COMENQ	HOPITAL	999	2021-12-01 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	CE Hôpital	CE Hôpital	COMMISSION D'ENQUÊTE SUR LA SITUATION DE L'HÔPITAL  ET LE SYSTÈME DE SANTÉ EN FRANCE	de la	commission d'enquête sur la situation de l'hôpital  et le système de santé en France	/commission/enquete/2021_sante_et_hopital.html	\N	CE Hôpital	HOPITAL	999	\N	\N
MISINFCOM	JUDI	999	2021-12-01 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	MI Judiciarisation	MI Judiciarisation	MISSION D'INFORMATION SUR LE THÈME : « LA JUDICIARISATION DE LA VIE PUBLIQUE : UNE CHANCE POUR L'ÉTAT DE DROIT ? UNE MISE EN QUESTION DE LA DÉMOCRATIE REPRÉSENTATIVE ? QUELLES CONSÉQUENCES SUR LA MANIÈRE DE PRODUIRE DES NORMES ET LEUR HIÉRARCHIE ? »	de la	mission d'information sur le thème : « La judiciarisation de la vie publique : une chance pour l'État de droit ? Une mise en question de la démocratie représentative ? Quelles conséquences sur la manière de produire des normes et leur hiérarchie ? »	/commission/missions/2021_judiciarisation_de_la_vie_publique.html	\N	MI Judiciarisation	JUDI	999	\N	\N
MISINFCOM	FONDSMER	999	2021-12-09 00:00:00	2022-06-21 00:00:00	\N	ANCIEN	MI Fonds marins	MI Fonds marins	MISSION D'INFORMATION SUR « L'EXPLORATION, LA PROTECTION ET L'EXPLOITATION DES FONDS MARINS : QUELLE STRATÉGIE POUR LA FRANCE ? »	de la	Mission d'information sur « L'exploration, la protection et l'exploitation des fonds marins : quelle stratégie pour la France ? »	/commission/missions/2021_fonds_marins.html	\N	MI Fonds marins	FONDSMER	999	\N	\N
MISINFCOM	RECHINNO	999	2021-12-09 00:00:00	2022-06-08 00:00:00	\N	ANCIEN	MI Excellence de la recherche/innovation	MI Excellence de la recherche/innovation	MISSION D'INFORMATION SUR LE THÈME « EXCELLENCE DE LA RECHERCHE/INNOVATION, PÉNURIE DE CHAMPIONS INDUSTRIELS : CHERCHEZ L'ERREUR FRANÇAISE »	de la	mission d'information sur le thème « Excellence de la recherche/innovation, pénurie de champions industriels : cherchez l'erreur française »	/commission/missions/2021_recherche_innovation_industrie.html	\N	MI Excellence de la recherche/innovation	RECHINNO	999	\N	\N
CMP	NOTREDAME	999	2019-05-28 00:00:00	2019-06-05 00:00:00	\N	ANCIEN	NOTREDAME	projet de loi pour la conservation et la restauration de Notre-Dame de Paris	NOTREDAME	du	projet de loi pour la conservation et la restauration de la cathédrale Notre-Dame de Paris et instituant une souscription nationale à cet effet	/commission/nouv/index.html	\N	NOTREDAME	NOTREDAME	999	\N	\N
MISINFCOM	ILLECTRONISM	999	2020-03-04 00:00:00	2020-09-17 00:00:00	\N	ANCIEN	MI Illectronisme et inclusion numérique	MI Illectronisme et inclusion numérique	MISSION D'INFORMATION SUR LA LUTTE CONTRE L'ILLECTRONISME ET INCLUSION NUMÉRIQUE	de la	Mission d'information sur la lutte contre l'illectronisme et inclusion numérique	/commission/missions/lutte_contre_lillectronisme.html	\N	MI Illectronisme et inclusion numérique	ILLECTRONISM	999	\N	\N
CMP	COVID19	999	2020-03-19 00:00:00	2020-03-23 00:00:00	\N	ANCIEN	COVID19	projet de loi d'urgence pour faire face à l'épidémie de Covid-19	COVID19	du	projet de loi d'urgence pour faire face à l'épidémie de Covid-19	/commission/nouv/index.html	\N	COVID19	COVID19	999	\N	\N
CMP	PLFR2	999	2020-04-21 00:00:00	2020-04-24 00:00:00	\N	ANCIEN	PLFR2	deuxième projet de loi de finances rectificative pour 2020	PLFR2	du	deuxième projet de loi de finances rectificative pour 2020	/commission/nouv/index.html	\N	PLFR2	PLFR2	999	\N	\N
CMP	SANITAIRE	999	2020-05-04 00:00:00	2020-05-10 00:00:00	\N	ANCIEN	SANITAIRE	projet de loi prorogeant l'état d'urgence sanitaire et complétant ses dispositions	SANITAIRE	du	projet de loi prorogeant l'état d'urgence sanitaire et complétant ses dispositions	/commission/nouv/index.html	\N	SANITAIRE	SANITAIRE	999	\N	\N
CMP	PLFR3	999	2020-07-17 00:00:00	2020-07-23 00:00:00	\N	ANCIEN	PLFR3	troisième projet de loi de finances rectificative pour 2020	PLFR3	du	troisième projet de loi de finances rectificative pour 2020	/commission/nouv/index.html	\N	PLFR3	PLFR3	999	\N	\N
CMP	SURETE	999	2020-07-21 00:00:00	2020-07-23 00:00:00	\N	ANCIEN	SURETE	PPL instaurant des mesures de sûreté à l'encontre des auteurs d'infractions terroristes	SURETE	de la	PPL instaurant des mesures de sûreté à l'encontre des auteurs d'infractions terroristes	/commission/nouv/index.html	\N	SURETE	SURETE	999	\N	\N
CMP	EMPL	999	2020-10-28 00:00:00	2020-10-29 00:00:00	\N	ANCIEN	EMPL	 PPL Inclusion dans l'emploi - Territoires zéro chômeur de longue durée	EMPL	de la	proposition de loi relative au renforcement de l'inclusion dans l'emploi par l'activité économique et à l'expérimentation « territoires zéro chômeur de longue durée »	/commission/nouv/index.html	\N	EMPL	EMPL	999	\N	\N
MISINFCOM	METHANIS	999	2021-02-17 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	MI Méthanisation	MI Méthanisation	MISSION D'INFORMATION INTITULÉE : « LA MÉTHANISATION DANS LE MIX ÉNERGÉTIQUE : ENJEUX ET IMPACTS »	de la	Mission d'information intitulée : « La méthanisation dans le mix énergétique : enjeux et impacts »	/commission/missions/la_methanisation_dans_le_mix_energetique_enjeux_et_impacts.html	\N	MI Méthanisation	METHANIS	999	\N	\N
MISINFCOM	VIETUDIA	999	2021-02-17 00:00:00	2021-07-06 00:00:00	\N	ANCIEN	MI Conditions de la vie étudiante	MI Conditions de la vie étudiante	MISSION D'INFORMATION RELATIVE AUX CONDITIONS DE LA VIE ÉTUDIANTE EN FRANCE	de la	Mission d'information relative aux conditions de la vie étudiante en France	/commission/missions/conditions_de_la_vie_etudiante_en_france.html	\N	MI Conditions de la vie étudiante	VIETUDIA	999	\N	\N
COMENQ	MEDIC	999	2023-01-19 00:00:00	\N	\N	ACTIF	CE Pénurie de médicaments	CE Pénurie de médicaments	COMMISSION D'ENQUÊTE SUR LA PÉNURIE DE MÉDICAMENTS ET LES CHOIX DE L'INDUSTRIE PHARMACEUTIQUE FRANÇAISE	de la	Commission d'enquête sur la pénurie de médicaments et les choix de l'industrie pharmaceutique française	/travaux-parlementaires/structures-temporaires/commissions-denquete/2022-2023-ce-penurie-de-medicaments.html	\N	CE Pénurie de médicaments	MEDIC	999	\N	\N
COMENQ	RENOV	999	2023-01-17 00:00:00	\N	\N	ACTIF	CE Rénovation énergétique	CE Rénovation énergétique	COMMISSION D'ENQUÊTE SUR L'EFFICACITÉ DES POLITIQUES PUBLIQUES EN MATIÈRE DE RÉNOVATION ÉNERGÉTIQUE	\N	Commission d'enquête sur l'efficacité des politiques publiques en matière de rénovation énergétique	/commission/enquete/2023_renovation_energetique.html	\N	CE Rénovation énergétique	RENOV	999	\N	\N
MISINFCOM	AVENCOMM	999	2023-01-24 00:00:00	\N	\N	ACTIF	MI Commune et maire	MI Commune et maire	MISSION D'INFORMATION SUR L'AVENIR DE LA COMMUNE ET DU MAIRE EN FRANCE	de la	Mission d'information sur l'avenir de la commune et du maire en France	/travaux-parlementaires/structures-temporaires/missions-dinformation-communes/mission-dinformation-sur-lavenir-de-la-commune-et-du-maire-en-france.html	\N	MI Commune et maire	AVENCOMM	999	\N	\N
MISINFCOM	GEAU	999	2023-02-01 00:00:00	\N	\N	ACTIF	MI Gestion de l'eau	MI Gestion de l'eau	MISSION D'INFORMATION SUR LE THÈME : « GESTION DURABLE DE L'EAU : L'URGENCE D'AGIR POUR NOS USAGES, NOS TERRITOIRES ET NOTRE ENVIRONNEMENT »	de la	mission d'information sur le thème : « gestion durable de l'eau : l'urgence d'agir pour nos usages, nos territoires et notre environnement »	/commission/missions/2023_mi_gestion_eau.html	\N	MI Gestion de l'eau	GEAU	999	\N	\N
MISINFCOM	BATI	999	2023-02-01 00:00:00	\N	\N	ACTIF	MI Bâti scolaire	MI Bâti scolaire	MISSION D'INFORMATION SUR LE THÈME : « LE BÂTI SCOLAIRE À L'ÉPREUVE DE LA TRANSITION ÉCOLOGIQUE »	de la	mission d'information sur le thème : « le bâti scolaire à l'épreuve de la transition écologique »	/commission/missions/2023_mi_bati_scolaire.html	\N	MI Bâti scolaire	BATI	999	\N	\N
MISINFCOM	BREXIT3	999	2020-01-31 00:00:00	\N	\N	ACTIF	GS Nouvelle relation euro-britannique	Groupe de suivi de la nouvelle relation euro-britannique	GROUPE DE SUIVI DE LA NOUVELLE RELATION EURO-BRITANNIQUE	du	Groupe de suivi de la nouvelle relation euro-britannique	/travaux-parlementaires/structures-temporaires/groupe-de-suivi-de-la-nouvelle-relation-euro-britannique.html	\N	BREXIT3	BREXIT3	999	\N	\N
CMP	RETRAITES	999	2023-03-15 00:00:00	2023-03-16 00:00:00	\N	ANCIEN	RETRAITES	Projet de loi de financement rectificative  de la sécurité sociale pour 2023	RETRAITES	du	projet de loi de financement rectificative  de la sécurité sociale pour 2023	/commission/nouv/index.html	\N	RETRAITES	RETRAITES	999	\N	\N
CMP	RELCOM	999	2023-03-15 00:00:00	2023-03-16 00:00:00	\N	ANCIEN	RELCOM	Proposition de loi tendant à renforcer l'équilibre dans les relations commerciales entre fournisseurs et distributeurs	RELCOM	de la	Proposition de loi tendant à renforcer l'équilibre dans les relations commerciales entre fournisseurs et distributeurs	/commission/nouv/index.html	\N	RELCOM	RELCOM	999	\N	\N
CMP	CRIM	999	2024-04-10 00:00:00	\N	\N	ACTIF	CRIM	PPL Confiscation avoirs criminels	CRIM	de la	proposition de loi améliorant l'efficacité des dispositifs de saisie et de confiscation des avoirs criminels	/commission/nouv/index.html	\N	CRIM	CRIM	999	\N	\N
CMP	DERI	999	2024-03-07 00:00:00	2024-03-08 00:00:00	\N	ANCIEN	DERI	PJL Dérives sectaires	DERI	du	projet de loi visant à lutter contre les dérives sectaires	/commission/nouv/index.html	\N	DERI	DERI	999	\N	\N
CMP	AGE	999	2024-03-12 00:00:00	2024-03-13 00:00:00	\N	ANCIEN	AGE	PPL Grand âge 	AGE	de la	proposition de loi portant diverses mesures relatives au grand âge et à l'autonomie	/commission/nouv/index.html	\N	AGE	AGE	999	\N	\N
CMP	HABI	999	2024-03-14 00:00:00	2024-03-15 00:00:00	\N	ANCIEN	HABI	PJL Rénovation habitat	HABI	du	projet de loi relatif à l'accélération et à la simplification de la rénovation de l'habitat dégradé et des grandes opérations 	/commission/nouv/index.html	\N	HABI	HABI	999	\N	\N
CMP	DDAD	999	2023-12-19 00:00:00	2024-04-05 00:00:00	\N	ANCIEN	DDAD	PJL DDADUE	DDAD	du	projet de loi portant diverses dispositions d'adaptation au droit de l'Union européenne en matière d'économie, de finances, de transition écologique, de droit pénal, de droit social et en matière agricole 	/commission/nouv/index.html	\N	DDAD	DDAD	999	\N	\N
CMP	TEST	999	2024-04-03 00:00:00	2024-04-10 00:00:00	\N	ANCIEN	TEST	PPL Discriminations tests individuels	TEST	de la	proposition de loi visant à lutter  contre les discriminations par la pratique de tests individuels et statistiques	/commission/nouv/index.html	\N	TEST	TEST	999	\N	\N
MISINFCOM	PERI	999	2024-02-28 00:00:00	\N	\N	ACTIF	MI Périnatalité	MI Périnatalité	MISSION D'INFORMATION SUR LE THÈME : « L'AVENIR DE LA SANTÉ PÉRINATALE ET SON ORGANISATION TERRITORIALE »	de la	mission d'information sur le thème : « L'avenir de la santé périnatale et son organisation territoriale »	/travaux-parlementaires/structures-temporaires/missions-dinformation-communes/mission-dinformation-sur-lavenir-de-la-sante-perinatale-et-son-organisation-territoriale.html	\N	MI Périnatalité	PERI	999	\N	\N
MISINFCOM	ARCH	999	2024-02-28 00:00:00	\N	\N	ACTIF	MI Architectes Bâtiments de France	MI Architectes Bâtiments de France	MISSION D'INFORMATION SUR « ARCHITECTES DES BÂTIMENTS DE FRANCE : PÉRIMÈTRE ET COMPÉTENCES »	de la	mission d'information sur « Architectes des Bâtiments de France : périmètre et compétences »	/commission/nouv/index.html	\N	MI Architectes Bâtiments de France	ARCH	999	\N	\N
CMP	NUCL	999	2024-03-07 00:00:00	2024-04-04 00:00:00	\N	ANCIEN	NUCL	PJL Sûreté nucléaire	NUCL	du	Projet de loi relatif à l¿organisation de la gouvernance de la sûreté nucléaire et de la radioprotection pour répondre au défi de la relance de la filière nucléaire	/commission/nouv/index.html	\N	NUCL	NUCL	999	\N	\N
CMP	ARTI	999	2024-03-07 00:00:00	2024-04-04 00:00:00	\N	ANCIEN	ARTI	PJLO Article 13	ARTI	du	Projet de loi organique modifiant la loi organique n° 2010-837 du 23 juillet 2010 relative à l'application du cinquième alinéa de l'article 13 de la Constitution	/commission/nouv/index.html	\N	ARTI	ARTI	999	\N	\N
MISINFCOM	COMP	999	2024-02-15 00:00:00	\N	\N	ACTIF	MI Complémentaires santé	MI Complémentaires santé	MISSION D'INFORMATION SUR « LES COMPLÉMENTAIRES SANTÉ, MUTUELLES : L'IMPACT SUR LE POUVOIR D'ACHAT DES FRANÇAIS »	de la	mission d'information sur le thème : « Complémentaires santé, mutuelles : l'impact sur le pouvoir d'achat des Français »	/travaux-parlementaires/structures-temporaires/missions-dinformation-communes/mission-dinformation-sur-les-complementaires-sante-mutuelles-limpact-sur-le-pouvoir-dachat-des-francais.html	\N	MI Complémentaires santé	COMP	999	\N	\N
CMP	ASSO	999	2024-03-22 00:00:00	2024-03-28 00:00:00	\N	ANCIEN	ASSO	PPL Engagement bénévole	ASSO	de la	proposition de loi visant à soutenir l'engagement bénévole et simplifier la vie associative	/commission/nouv/index.html	\N	ASSO	ASSO	999	\N	\N
CMP	CIVI	999	2024-03-22 00:00:00	2024-03-27 00:00:00	\N	ANCIEN	CIVI	PPL Droit responsabilité civile	CIVI	de la	proposition de loi visant à adapter le droit  de la responsabilité civile aux enjeux actuels	/commission/nouv/index.html	\N	CIVI	CIVI	999	\N	\N
CMP	VAPO	999	2024-03-20 00:00:00	2024-03-21 00:00:00	\N	ANCIEN	VAPO	PPL Vapotage	VAPO	de la 	proposition de loi visant à interdire les dispositifs électroniques de vapotage à usage unique	/commission/nouv/index.html	\N	VAPO	VAPO	999	\N	\N
CMP	NUME	999	2024-03-20 00:00:00	2024-03-27 00:00:00	\N	ANCIEN	NUME	PJL Espace numérique	NUME	du	projet de loi visant à sécuriser  et réguler l'espace numérique 	/commission/nouv/index.html	\N	NUME	NUME	999	\N	\N
\.


--
-- Data for Name: csp; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY csp (cspcod, catprocod, cspfamcod, csplib, cspnumtri, syscredat, sysmajdat) FROM stdin;
11	10	1	Agriculteur sur petite exploitation	1	\N	\N
12	10	1	Agriculteur sur moyenne exploitation	2	\N	\N
13	10	1	Agriculteur sur grande exploitation	3	\N	\N
21	24	2	Artisan	4	\N	\N
22	22	2	Commerçant et assimilé	5	\N	\N
23	21	2	Chef d'entreprise de 10 salariés ou plus	6	\N	\N
31	57	5	Profession libérale	7	\N	\N
33	71	7	Cadre de la fonction publique	8	\N	\N
34	61	6	Professeur, profession scientifique	9	\N	\N
35	81	9	Profession de l'information, des arts et des spectacles	10	\N	\N
37	32	3	Cadre administratif et commercial d'entreprise	11	\N	\N
38	31	3	Ingénieur et cadre technique d'entreprise	12	\N	\N
42	63	6	Professeur des écoles, instituteur et assimilé	13	\N	\N
43	47	4	Profession intermédiaire de la santé et du travail social	14	\N	\N
44	81	9	Clergé, religieux	15	\N	\N
45	72	7	Profession intermédiaire administrative de la fonction publique	16	\N	\N
46	32	3	Profession intermédiaire administrative et commerciale des entreprises	17	\N	\N
47	32	3	Technicien	18	\N	\N
48	32	3	Contremaître, agent de maîtrise	19	\N	\N
52	73	7	Employé civil et agent de service de la fonction publique	20	\N	\N
53	74	7	Policier et militaire	21	\N	\N
54	33	3	Employé administratif d'entreprise	22	\N	\N
55	33	3	Employé de commerce	23	\N	\N
56	81	9	Personnel des services directs aux particuliers	24	\N	\N
62	34	3	Ouvrier qualifié de type industriel	25	\N	\N
63	34	3	Ouvrier qualifié de type artisanal	26	\N	\N
64	24	2	Chauffeur	27	\N	\N
65	34	3	Ouvrier qualifié de la manutention, du magasinage et du transport	28	\N	\N
67	34	3	Ouvrier non qualifié de type industriel	29	\N	\N
68	34	3	Ouvrier non qualifié de type artisanal	30	\N	\N
69	10	1	Ouvrier agricole	31	\N	\N
71	10	1	Ancien agriculteur exploitant	32	\N	\N
72	29	2	Ancien artisan, commerçant, chef d'entreprise	33	\N	\N
74	39	3	Ancien cadre	34	\N	\N
75	39	3	Ancienne profession intermédiaire	35	\N	\N
77	39	3	Ancien employé	36	\N	\N
78	39	3	Ancien ouvrier	37	\N	\N
81	80	8	Chômeur n'ayant jamais travaillé	38	\N	\N
83	74	7	Militaire du contingent	39	\N	\N
84	80	8	Elève, étudiant	40	\N	\N
85	80	8	Personne diverse sans activité professionnelle de moins de 60 ans (sauf retraité)	41	\N	\N
86	80	8	Personne diverse sans activité professionnelle de 60 ans et plus (sauf retraité)	42	\N	\N
\.


--
-- Data for Name: delega; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY delega (typorgcod, orgcod, orgnumtri, orgdatcre, orgdatfin, orgnumtie, temvalcod, evelic, evelib, evelil, orgart, orgurlsim, orgurlcmp, orgregjur, orgmoddes, orgmemdep, syscredat, sysmajdat) FROM stdin;
AUTRES	SFAPF	17	1900-01-01 00:00:00	\N	\N	ACTIF	Section française de l'APF	Section française de l'Assemblée parlementaire de la francophonie	Section française de l'Assemblée parlementaire de la francophonie (A.P.F.)	de la	\N	\N	\N	\N	NON	\N	2013-12-18 11:57:27
AUTRES	UIP	18	1900-01-01 00:00:00	\N	\N	ACTIF	Union Interparlementaire	Groupe français de l'Union Interparlementaire (U.I.P.)	Groupe français de l'Union Interparlementaire (U.I.P.)	du	\N	\N	\N	\N	NON	\N	2013-12-18 11:57:27
AUTRES	OTAN	16	1900-01-01 00:00:00	\N	\N	ACTIF	délégation parlementaire Otan	Délégation française à l'Assemblée parlementaire de l'OTAN	Délégation française à l'Assemblée parlementaire de l'OTAN	de la	\N	\N	\N	\N	NON	\N	2013-12-18 11:57:27
COMITE	COMITEDEONTO	11	2009-12-16 00:00:00	\N	\N	ACTIF	Comité de déontologie	Comité de déontologie parlementaire du Sénat	Comité de déontologie parlementaire du Sénat	du 	\N	\N	\N	\N	NON	\N	\N
DELEGA	205	8	1900-01-01 00:00:00	2009-06-25 00:00:00	\N	ANCIEN	Planification	Délégation pour la planification	Délégation pour la planification	de la 	/commission/planification/index.html	\N	Loi n° 82.653 du 29 juillet 1982	\N	NON	\N	2014-02-21 11:14:03
DELEGA	RENSEIGNEMEN	7	2007-10-10 00:00:00	\N	\N	ACTIF	Renseignement	Délégation parlementaire au renseignement 	Délégation parlementaire au renseignement 	de la	/commission/renseignement/index.html	http://www.assemblee-nationale.fr/qui/xml/organe.asp?id_organe=/14/tribun/xml/xml/organes/402232.xml	LOI n° 2007-1443 du 9 octobre 2007 	\N	OUI	\N	2015-03-31 09:48:19
MECSS	MECSS	1	2006-01-25 00:00:00	\N	\N	ACTIF	MECSS	Mission d'évaluation et de contrôle de la sécurité sociale	Mission d'évaluation et de contrôle de la sécurité sociale	de la 	/commission/soc/MECSS.html	\N	\N	\N	NON	\N	\N
DELEGA	202	8	1900-01-01 00:00:00	2008-10-07 00:00:00	\N	ANCIEN	Union Européenne              	Délégation pour l'Union européenne	Délégation pour l'Union européenne	de la 	/europe/index.html	\N	Loi n° 79.564 du 6 juillet 1979	\N	NON	\N	2014-02-21 11:14:03
DELEGA	203	8	1900-01-01 00:00:00	2009-06-25 00:00:00	\N	ANCIEN	Problèmes démographiques	Délégation parlementaire pour les problèmes démographiques	Délégation parlementaire pour les problèmes démographiques	de la 	\N	http://www.assemblee-nationale.fr/controle/index.asp	\N	\N	OUI	\N	2014-02-21 11:14:03
OFFICE	206	8	1900-01-01 00:00:00	\N	\N	ACTIF	OPECST	Office parlementaire d'évaluation des choix scientifiques et technologiques	Office parlementaire d'évaluation des choix scientifiques et technologiques	de l'	/opecst/index.html	http://www.assemblee-nationale.fr/qui/xml/organe.asp?id_organe=/14/tribun/xml/xml/organes/273589.xml	Loi n° 83.609 du 8 juillet 1983	\N	OUI	\N	2013-12-18 11:57:27
OFFICE	207	50	1900-01-01 00:00:00	2000-12-31 00:00:00	\N	ANCIEN	Politiques publiques	Office parlementaire d'évaluation des politiques publiques	Office parlementaire d'évaluation des politiques publiques	de l'	\N	\N	\N	\N	OUI	\N	2014-02-21 11:14:03
OFFICE	208	8	1900-01-01 00:00:00	2009-06-25 00:00:00	\N	ANCIEN	Législation	Office parlementaire d'évaluation de la législation	Office parlementaire d'évaluation de la législation	de l'	/commission/legislation/index.html	http://www.assemblee-nationale.fr/controle/index.asp	Loi n° 96.516 du 14 juin 1996	\N	OUI	\N	2014-02-21 11:14:03
CSCE	CSCE	15	1900-01-01 00:00:00	\N	\N	ACTIF	Org. sécurite coop. Europe	Délégation française à l'Assemblée parlementaire de l'Organisation pour la Sécurité et la Coopération en Europe (O.S.C.E	Délégation française à l'Assemblée parlementaire de l'Organisation pour la Sécurité et la Coopération en Europe (O.S.C.E.)	de la 	\N	\N	\N	\N	NON	\N	2013-12-18 11:57:26
DELEGA	210	8	1999-06-25 00:00:00	2009-06-25 00:00:00	\N	ANCIEN	Territoire	Délégation à l'aménagement et au développement durable du territoire	Délégation à l'aménagement et au développement durable du territoire	de la 	/commission/amenagement/index.html	\N	Loi n° 99.533 du 25 juin 1999	\N	NON	\N	2014-02-21 11:14:03
DELEGA	211	3	1999-07-12 00:00:00	\N	\N	ACTIF	Droits des femmes	Délégation aux droits des femmes et à l'égalité des chances entre les hommes et les femmes	Délégation aux droits des femmes et à l'égalité des chances entre les hommes et les femmes	de la 	/commission/femmes/index.html	\N	Loi n° 99.585 du 12 juillet 1999	\N	NON	\N	\N
OFFICE	SANTE	9	2002-12-20 00:00:00	2009-06-25 00:00:00	\N	ANCIEN	Politiques de santé	Office parlementaire d'évaluation des politiques de santé	Office parlementaire d'évaluation des politiques de santé	de l'	/commission/sante/index.html	http://www.assemblee-nationale.fr/controle/index.asp	Loi n° 2002.1487 du 20 décembre 2002	\N	OUI	\N	2014-02-21 11:14:03
OBS	ODD	10	1900-01-01 00:00:00	2009-06-25 00:00:00	\N	ANCIEN	Observatoire décentralisation	Observatoire de la Décentralisation	Observatoire de la Décentralisation	de l'	/observatoire_decentralisation/index.html	\N	(Chapitre XVII bis de l'Instruction générale du Bureau, issu de l'Arrêté n°2004-273 du 14 décembre 2004)	\N	NON	\N	2014-02-21 11:14:03
CONEUR	CONEUR	13	1900-01-01 00:00:00	2014-01-01 00:00:00	\N	ANCIEN	Conseil de l'Europe	Assemblée parlementaire du Conseil de l'Europe	Assemblée parlementaire du Conseil de l'Europe	de l'	/europe/assemblee_conseil_europe/index.html	\N	\N	\N	NON	\N	2015-10-09 10:20:17
CONEUR	UEO	14	1900-01-01 00:00:00	\N	\N	ACTIF	Union de l'Europe occidentale	Assemblée de l'Union de l'Europe occidentale	Assemblée de l'Union de l'Europe occidentale	de l'	/europe/assemblee_conseil_europe/index.html	\N	\N	\N	NON	\N	2013-12-18 11:57:26
CONEUR	DELCONEUR	12	1900-01-01 00:00:00	\N	\N	ACTIF	Déléga. fra. Ass. parl. Conseil de l'Europe	Délégation française à l'Assemblée parlementaire du Conseil de l'Europe	Délégation française à l'Assemblée parlementaire du Conseil de l'Europe	de la 	/europe/assemblee_conseil_europe/index.html	\N	\N	\N	NON	\N	2013-12-18 11:57:27
DELEGA	PROS	6	2009-04-07 00:00:00	\N	\N	ACTIF	Délégation sénatoriale à la prospective	Délégation sénatoriale à la prospective	Délégation sénatoriale à la prospective	de la 	/commission/prospective/index.html	\N	\N	\N	NON	\N	2013-12-18 11:57:27
DELEGA	COLTER	2	2009-04-07 00:00:00	\N	\N	ACTIF	Collectivités territoriales	Délégation sénatoriale aux collectivités territoriales et à la décentralisation	Délégation sénatoriale aux collectivités territoriales et à la décentralisation	de la 	/commission/decentralisation/index.html	\N	\N	\N	NON	\N	2017-06-02 11:50:35
DELEGA	DSOM	5	2011-11-30 00:00:00	\N	\N	ACTIF	Outre-mer	Délégation sénatoriale aux outre-mer	Délégation sénatoriale aux outre-mer	de la 	/commission/outre_mer/index.html	\N	\N	\N	NON	\N	2017-06-01 14:48:12
AUTRES	APUPM	53	2010-01-01 00:00:00	\N	\N	ACTIF	Ass. parl. de l'Union pour la Méditerranée	Assemblée parlementaire de l'Union pour la Méditerranée	Assemblée parlementaire de l'Union pour la Méditerranée	de l'	\N	\N	\N	\N	OUI	2015-08-25 14:05:33	\N
DELEGA	ENTREPRISES	4	2014-11-26 00:00:00	\N	\N	ACTIF	Délégation sénatoriale aux entreprises	Délégation sénatoriale aux entreprises	Délégation sénatoriale aux entreprises	de la	/commission/entreprises/index.html	\N	\N	\N	NON	2014-11-26 13:16:03	2015-01-08 17:32:37
AUTRES	APM	51	2005-01-01 00:00:00	\N	\N	ACTIF	Ass. parl. de la Méditerranée	Assemblée parlementaire de la Méditerranée	Assemblée parlementaire de la Méditerranée	de l'	\N	\N	\N	\N	NON	2015-08-25 14:05:26	\N
AUTRES	ACMN	52	2002-11-28 00:00:00	\N	\N	ACTIF	Ass. parlem. de la Mer noire	Assemblée parlementaire de la coopération économique de la Mer noire	Assemblée parlementaire de la coopération économique de la Mer noire	de l'	\N	\N	\N	\N	NON	2015-08-25 14:05:29	\N
DELEGA	COSAC	\N	1989-01-01 00:00:00	\N	\N	ACTIF	COSAC	Conférence des organes spécialisés dans les affaires communautaires	Conférence des organes spécialisés dans les affaires communautaires	de la 	\N	\N	\N	\N	NON	2015-09-22 18:25:56	2015-09-22 18:28:17
DELEGA	CVFS	\N	2002-01-01 00:00:00	\N	\N	ACTIF	Commission de vérification des fonds spéciaux	Commission de vérification des fonds spéciaux	Commission de vérification des fonds spéciaux	de la 	\N	\N	\N	\N	OUI	\N	\N
\.


--
-- Data for Name: design; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY design (designcod, moddescod, temvalcod, orgcod, evelic, evelib, evelil, eveobs, designnumtri, syscredat, sysmajdat) FROM stdin;
PDTSEN	PDTSEN	ACTIF	NEANT	Président du Sénat	Président du Sénat	Président du Sénat	\N	1	\N	\N
SENCOMAFCL	SENCOM	ACTIF	AFCL	Sénat (culture)	Sénat sur proposition de la commission de la culture	Sénat sur proposition de la commission de la culture	\N	14	\N	\N
SENCOMECON	SENCOM	ANCIEN	CAE	Sénat (économie)	Sénat sur proposition de la commission de l'économie	Sénat sur proposition de la commission de l'économie	\N	10	\N	\N
SENCOMETRD	SENCOM	ACTIF	ETRD	Sénat (affaires étrangères)	Sénat sur proposition de la commission des affaires étrangères	Sénat sur proposition de la commission des affaires étrangères	\N	12	\N	\N
SENCOMSOCI	SENCOM	ACTIF	SOCI	Sénat (affaires sociales)	Sénat sur proposition de la commission des affaires sociales	Sénat sur proposition de la commission des affaires sociales	\N	13	\N	\N
SENCOMFINC	SENCOM	ACTIF	FINC	Sénat (finances)	Sénat sur proposition de la commission des finances	Sénat sur proposition de la commission des finances	\N	16	\N	\N
SENCOMLOIS	SENCOM	ACTIF	LOIS	Sénat (lois)	Sénat sur proposition de la commission des lois	Sénat sur proposition de la commission des lois	\N	17	\N	\N
COMAFCL	COM	ACTIF	AFCL	Commission culture	Commission de la culture	Commission de la culture	\N	24	\N	\N
COMECON	COM	ANCIEN	CAE	Commission économie	Commission de l'économie	Commission de l'économie	\N	20	\N	\N
COMETRD	COM	ACTIF	ETRD	Commission affaires étrangères	Commission des affaires étrangères	Commission des affaires étrangères	\N	22	\N	\N
COMSOCI	COM	ACTIF	SOCI	Commission affaires sociales	Commission des affaires sociales	Commission des affaires sociales	\N	23	\N	\N
COMFINC	COM	ACTIF	FINC	Commission finances	Commission des finances	Commission des finances	\N	26	\N	\N
COMLOIS	COM	ACTIF	LOIS	Commission des lois	Commission des lois	Commission des lois	\N	27	\N	\N
MEMBREDRT	MEMBREDRT	ACTIF	NEANT	Membres de droit	Membres de droit	Membres de droit	\N	31	\N	\N
SCRUTIN	SCRUTIN	ACTIF	NEANT	Sénat par scrutin secret	Sénat par scrutin secret	Sénat par scrutin secret	\N	30	\N	\N
SENCOMAFEU	SENCOM	ACTIF	AFEU	Sénat (affaires européennes)	Sénat sur proposition de la commission des affaires européennes	Sénat sur proposition de la commission des affaires européennes	\N	18	\N	\N
COMAFEU	COM	ACTIF	AFEU	Commission des affaires européennes	Commission des affaires européennes	Commission des affaires européennes	\N	28	\N	\N
SENAT	SENAT	ACTIF	NEANT	Sénat	Sénat	Sénat	\N	30	\N	\N
PDTOPECST	OPECST	ACTIF	NEANT	Président de l'OPECST	Président de l'Office parlementaire d'évaluation des choix scientifiques et technologiques	Président de l'Office parlementaire d'évaluation des choix scientifiques et technologiques	\N	2	\N	\N
SENOPECST	OPECST	ACTIF	NEANT	Sénat (OPECST)	Sénat sur proposition de l'Office parlementaire d'évaluation des choix scientifiques et technologiques	Sénat sur proposition de l'Office parlementaire d'évaluation des choix scientifiques et technologiques	\N	3	\N	\N
OPECST	OPECST	ACTIF	NEANT	OPECST	Office parlementaire d'évaluation des choix scientifiques et technologiques	Office parlementaire d'évaluation des choix scientifiques et technologiques	\N	4	\N	\N
SENCOMCAE	SENCOM	ACTIF	CAE	Sénat (affaires économiques)	Sénat sur proposition de la commission des affaires économiques	Sénat sur proposition de la commission des affaires économiques	\N	11	\N	\N
SENCOMCDD	SENCOM	ACTIF	CDD	Sénat (aménagement du territoire)	Sénat sur proposition de la commission de l'aménagement du territoire	Sénat sur proposition de la commission de l'aménagement du territoire	\N	15	\N	\N
COMCAE	COM	ACTIF	CAE	Commission des affaires économiques	Commission des affaires économiques	Commission des affaires économiques	\N	21	\N	\N
COMCDD	COM	ACTIF	CDD	Commission aménagement du territoire	Commission de l'aménagement du territoire	Commission de l'aménagement du territoire	\N	25	\N	\N
PQPDTSEN	PQPDTSEN	ACTIF	NEANT	Président du Sénat	Président du Sénat	Nomination d'une personnalité qualifiée par le Président du Sénat	\N	70	\N	\N
PQPDTSENLOIS	PQPDTSEN	ACTIF	LOIS	Président du Sénat, avis commission des lois	Président du Sénat, après avis de la commission des lois	Nomination d'une personnalité qualifiée par le Président du Sénat après avis de la commission des lois	\N	71	\N	\N
PQPDTSENAFCL	PQPDTSEN	ACTIF	AFCL	Président du Sénat, avis culture	Président du Sénat, après avis de la commission de la culture	Nomination d'une personnalité qualifiée par le Président du Sénat après avis de la commission de la culture	\N	72	\N	\N
PQPDTSENFINC	PQPDTSEN	ACTIF	FINC	Président du Sénat, avis finances	Président du Sénat, après avis du Président et du Rapporteur général de la commission des finances	Nomination d'une personnalité qualifiée par le Président du Sénat après avis du Président et du Rapporteur général de la commission des finances	\N	73	\N	\N
PQPDTSENSOCI	PQPDTSEN	ACTIF	SOCI	Président du Sénat, avis affaires sociales	Président du Sénat, après avis de la commission des affaires sociales	Nomination d'une personnalité qualifiée par le Président du Sénat après avis de la commission des affaire sociales	\N	74	\N	\N
NOMART13CAE	PRART13	ACTIF	CAE	Article 13 de la constitution (affaires économiques)	Président de la République, après avis de la commission des affaires économiques (art. 13 de la constitution)	Président de la République, après avis de la commission des affaires économiques, conformément à l'alinéa 5 de l'article 13 de la constitution	\N	40	\N	\N
NOMART13ETRD	PRART13	ACTIF	ETRD	Article 13 de la constitution (affaires étrangères)	Président de la République, après audition par la com. des affaires étrangères (art. 13 de la constitution)	Président de la République, après audition par la commission des affaires étrangères, conformément à l'alinéa 5 de l'article 13 de la constitution	\N	41	\N	\N
NOMART13SOCI	PRART13	ACTIF	SOCI	Article 13 de la constitution (affaires sociales)	Président de la République, après audition par la commission des affaires sociales (art. 13 de la constitution)	Président de la République, après audition par la commission des affaires sociales, conformément à l'alinéa 5 de l'article 13 de la constitution	\N	42	\N	\N
NOMART13AFCL	PRART13	ACTIF	AFCL	Article 13 de la constitution (culture)	Président de la République, après audition par la commission de la culture (art. 13 de la constitution)	Président de la République, après audition par la commission de la culture, conformément à l'alinéa 5 de l'article 13 de la constitution	\N	43	\N	\N
NOMART13CDD	PRART13	ACTIF	CDD	Article 13 de la constitution (aménagement du territoire)	Président de la République, après audition par la com. de l'aménagement du territoire (art. 13 de la constitution)	Président de la République, après audition par la commission de l'aménagement du territoire, conformément à l'alinéa 5 de l'article 13 de la constitution	\N	44	\N	\N
NOMART13FINC	PRART13	ACTIF	FINC	Article 13 de la constitution (finances)	Président de la République, après audition par la commission des finances (art. 13 alinéa 5 de la constitution)	Président de la République, après audition par la commission des finances, conformément à l'alinéa 5 de l'article 13 de la constitution	\N	45	\N	\N
NOMART13LOIS	PRART13	ACTIF	LOIS	Article 13 de la constitution (lois)	Président de la République, après audition par la commission des lois (art. 13 alinéa 5 de la constitution)	Président de la République, après audition par la commission des lois, conformément à l'alinéa 5 de l'article 13 de la constitution	\N	46	\N	\N
AUDITCAE	AUDITION	ACTIF	CAE	PR, audition affaires économiques	Président de la République, après audition par la commission des affaires économiques	Président de la République, après audition par la commission des affaires économiques	\N	60	\N	\N
AUDITETRD	AUDITION	ACTIF	ETRD	PR, audition affaires étrangères	Président de la République, après audition par la commission des affaires étrangères	Président de la République, après audition par la commission des affaires étrangères	\N	61	\N	\N
AUDITSOCI	AUDITION	ACTIF	SOCI	PR, audition affaires sociales	Président de la République, après audition par la commission des affaires sociales	Président de la République, après audition par la commission des affaires sociales	\N	62	\N	\N
AUDITAFCL	AUDITION	ACTIF	AFCL	PR, audition culture	Président de la République, après audition par la commission de la culture	Président de la République, après audition par la commission de la culture	\N	63	\N	\N
AUDITCDD	AUDITION	ACTIF	CDD	PR, audition aménagement du territoire	Président de la République, après audition par la commission de l'aménagement du territoire	Président de la République, après audition par la commission de l'aménagement du territoire	\N	64	\N	\N
AUDITFINC	AUDITION	ACTIF	FINC	PR, audition finances	Président de la République, après audition par la commission des finances	Président de la République, après audition par la commission des finances	\N	65	\N	\N
AUDITLOIS	AUDITION	ACTIF	LOIS	PR, audition lois	Président de la République, après audition par la commission des lois	Président de la République, après audition par la commission des lois	\N	66	\N	\N
SENART13CAE	PSENART13	ACTIF	CAE	Président du Sénat, avis affaires économiques	Président du Sénat, après avis de la commission des affaires économiques	Président du Sénat, après avis de la commission des affaires économiques (procédure analogue à celle prévue à l'alinéa 5 de l'article 13 de la constitution)	\N	50	\N	\N
SENART13ETRD	PSENART13	ACTIF	ETRD	Président du Sénat, avis affaires étrangères	Président du Sénat, après avis de la commission des affaires étrangères	Président du Sénat, après avis de la commission des affaires étrangères (procédure analogue à celle prévue à l'alinéa 5 de l'article 13 de la constitution)	\N	51	\N	\N
SENART13SOCI	PSENART13	ACTIF	SOCI	Président du Sénat, avis affaires sociales	Président du Sénat, après avis de la commission des affaires sociales	Président du Sénat, après avis de la commission des affaires sociales (procédure analogue à celle prévue à l'alinéa 5 de l'article 13 de la constitution)	\N	52	\N	\N
SENART13AFCL	PSENART13	ACTIF	AFCL	Président du Sénat, avis culture	Président du Sénat, après avis de la commission de la culture	Président du Sénat, après avis de la commission de la culture (procédure analogue à celle prévue à l'alinéa 5 de l'article 13 de la constitution)	\N	53	\N	\N
SENART13CDD	PSENART13	ACTIF	CDD	Président du Sénat, avis aménagement du territoire	Président du Sénat, après avis de la commission de l'aménagement du territoire	Président du Sénat, après avis de la commission de l'aménagement du territoire (procédure analogue à celle prévue à l'alinéa 5 de l'article 13 de la constitution)	\N	54	\N	\N
SENART13FINC	PSENART13	ACTIF	FINC	Président du Sénat, avis commission des finances	Président du Sénat, après avis de la commission des finances	Président du Sénat, après avis de la commission des finances (procédure analogue à celle prévue à l'alinéa 5 de l'article 13 de la constitution)	\N	55	\N	\N
SENART13LOIS	PSENART13	ACTIF	LOIS	Président du Sénat, avis commission des lois	Président du Sénat, après avis de la commission des lois	Président du Sénat, après avis de la commission des lois (procédure analogue à celle prévue à l'alinéa 5 de l'article 13 de la constitution)	\N	56	\N	\N
\.


--
-- Data for Name: designoep; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY designoep (designcod, temvalcod, orgcod, evelic, evelib, evelil, designoepnumtri, designoepnbrtit, designoepnbrsup, designoepdatdeb, designoepdatfin, designoepid, syscredat, sysmajdat, fonmemextparcod, fontemrem, fonremlil, incompat) FROM stdin;
SENCOMFINC	ACTIF	66	\N	\N	\N	\N	\N	\N	\N	\N	154	\N	\N	MEMBRE	NON	\N	\N
COMFINC	ACTIF	69	\N	\N	\N	\N	2	2	\N	\N	155	\N	\N	MEMBRE	NON	\N	\N
SENCOMFINC	ACTIF	2	\N	\N	\N	\N	\N	\N	\N	\N	156	\N	\N	MEMBRE	NON	\N	\N
SENCOMFINC	ACTIF	9	\N	\N	\N	\N	1	\N	\N	\N	157	\N	\N	MEMBRE	NON	\N	\N
SENCOMFINC	ANCIEN	13	\N	\N	\N	\N	2	0	\N	2018-08-02 00:00:00	158	\N	\N	MEMBRE	NON	\N	\N
SENCOMFINC	ACTIF	21	\N	\N	\N	\N	\N	\N	\N	\N	159	\N	\N	MEMBRE	NON	\N	\N
SENCOMFINC	ACTIF	132	\N	\N	\N	\N	\N	\N	\N	\N	160	\N	\N	MEMBRE	NON	\N	\N
SENCOMFINC	ACTIF	141	\N	\N	\N	\N	1	0	\N	\N	161	\N	\N	MEMBRE	NON	\N	\N
SENCOMFINC	ANCIEN	147	\N	\N	\N	\N	1	0	\N	2018-08-02 00:00:00	163	\N	\N	MEMBRE	NON	\N	\N
SENCOMFINC	ACTIF	84	\N	\N	\N	\N	\N	\N	\N	\N	164	\N	\N	MEMBRE	NON	\N	\N
SENCOMFINC	ACTIF	89	\N	\N	\N	\N	\N	\N	\N	\N	165	\N	\N	MEMBRE	NON	\N	\N
SENCOMFINC	ACTIF	119	\N	\N	\N	\N	\N	\N	\N	\N	166	\N	\N	MEMBRE	NON	\N	\N
SENCOMFINC	ACTIF	217	\N	\N	\N	\N	\N	\N	\N	\N	167	\N	\N	MEMBRE	NON	\N	\N
SENCOMFINC	ACTIF	194	\N	\N	\N	\N	1	0	\N	2019-02-12 00:00:00	168	\N	2019-02-26 15:28:56	MEMBRE	NON	\N	\N
SENCOMFINC	ACTIF	193	\N	\N	\N	\N	1	1	\N	\N	169	\N	\N	MEMBRE	NON	\N	\N
SENCOMFINC	ACTIF	173	\N	\N	\N	\N	\N	\N	\N	\N	171	\N	\N	MEMBRE	NON	\N	\N
SENCOMFINC	ANCIEN	187	\N	\N	\N	\N	1	0	\N	2018-08-03 00:00:00	173	\N	\N	MEMBRE	NON	\N	\N
SENCOMFINC	ACTIF	50bis	\N	\N	\N	\N	\N	\N	\N	\N	174	\N	\N	MEMBRE	NON	\N	\N
SENCOMFINC	ACTIF	38	\N	\N	\N	\N	\N	\N	\N	\N	175	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	112	\N	\N	\N	\N	7	0	\N	\N	176	\N	2018-09-21 10:15:23	MEMBRE	NON	\N	\N
SENCOMFINC	ACTIF	135 bis	\N	\N	\N	\N	\N	\N	\N	\N	177	\N	\N	MEMBRE	NON	\N	\N
SENCOMLOIS	ANCIEN	29	\N	\N	\N	\N	1	1	\N	2018-08-02 00:00:00	178	\N	\N	MEMBRE	NON	\N	\N
SENCOMLOIS	ANCIEN	34	\N	\N	\N	\N	1	1	\N	2018-08-02 00:00:00	179	\N	\N	MEMBRE	NON	\N	\N
SENCOMLOIS	ACTIF	66	\N	\N	\N	\N	\N	\N	\N	\N	180	\N	\N	MEMBRE	NON	\N	\N
SENCOMLOIS	ACTIF	3	\N	\N	\N	\N	2	0	\N	\N	181	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	4	\N	\N	\N	\N	1	0	\N	\N	182	\N	\N	MEMBRE	NON	\N	\N
SENCOMLOIS	ACTIF	141	\N	\N	\N	\N	1	0	\N	\N	183	\N	\N	MEMBRE	NON	\N	\N
SENCOMLOIS	ANCIEN	95	\N	\N	\N	\N	1	0	\N	2018-08-02 00:00:00	184	\N	\N	MEMBRE	NON	\N	\N
SENCOMLOIS	ACTIF	96	\N	\N	\N	\N	1	\N	\N	\N	185	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ANCIEN	109	\N	\N	\N	\N	1	1	\N	2018-08-02 00:00:00	186	\N	\N	MEMBRE	NON	\N	\N
SENCOMLOIS	ACTIF	215	\N	\N	\N	\N	\N	\N	\N	\N	187	\N	\N	MEMBRE	NON	\N	\N
SENCOMLOIS	ANCIEN	196	\N	\N	\N	\N	2	0	\N	2020-08-02 00:00:00	188	\N	\N	MEMBRE	NON	\N	\N
SENCOMLOIS	ACTIF	166	\N	\N	\N	\N	\N	\N	\N	\N	189	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ANCIEN	169	\N	\N	\N	\N	1	0	\N	2015-01-01 00:00:00	190	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ANCIEN	172	\N	\N	\N	\N	1	0	\N	2015-01-01 00:00:00	191	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ANCIEN	176	\N	\N	\N	\N	1	0	\N	2015-01-01 00:00:00	192	\N	\N	MEMBRE	NON	\N	\N
COMCAE	ACTIF	179	\N	\N	\N	\N	1	0	\N	\N	193	\N	2014-07-11 11:49:06	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	609	\N	\N	\N	\N	1	0	2007-02-08 00:00:00	\N	194	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	245	\N	\N	\N	\N	2	0	\N	\N	195	\N	2019-02-25 11:35:20	MEMBRE	NON	\N	\N
SENCOMFINC	ACTIF	87	\N	\N	\N	\N	\N	\N	\N	\N	196	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	260	\N	\N	\N	1	1	0	\N	\N	197	\N	2017-04-11 14:03:11	MEMBRE	NON	\N	\N
SENCOMCDD	ACTIF	261	\N	\N	\N	\N	1	0	\N	2019-02-12 00:00:00	198	\N	2019-02-26 11:26:42	MEMBRE	NON	\N	\N
SENCOMCAE	ACTIF	240	\N	\N	\N	\N	2	0	\N	\N	199	\N	\N	MEMBRE	NON	\N	\N
SENCOMCAE	ANCIEN	243	\N	\N	\N	\N	2	0	\N	2018-08-02 00:00:00	200	\N	\N	MEMBRE	NON	\N	\N
SENCOMAFCL	ACTIF	240	\N	\N	\N	\N	2	\N	\N	\N	201	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	248	\N	\N	\N	\N	1	\N	\N	\N	202	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	265	\N	\N	\N	1	1	\N	\N	\N	203	\N	2017-04-11 14:11:59	MEMBRE	NON	\N	\N
MEMBREDRT	ACTIF	607	\N	\N	\N	\N	\N	\N	\N	\N	9	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	149	\N	\N	\N	\N	3	\N	\N	\N	22	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	229	\N	\N	\N	\N	\N	\N	\N	\N	34	\N	\N	MEMBRE	NON	\N	\N
SENCOMAFCL	ACTIF	93	\N	\N	\N	\N	\N	\N	\N	\N	83	\N	\N	MEMBRE	NON	\N	\N
SENCOMCAE	ACTIF	110	\N	\N	\N	\N	\N	\N	\N	\N	105	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	176	\N	\N	\N	\N	2	0	\N	\N	118	\N	\N	MEMBRE	NON	\N	\N
SENCOMSOCI	ACTIF	50	\N	\N	\N	\N	1	\N	\N	2019-02-12 00:00:00	128	\N	2019-02-26 12:26:06	MEMBRE	NON	\N	\N
SENCOMSOCI	ANCIEN	190	\N	\N	\N	\N	1	0	\N	2019-07-08 00:00:00	138	\N	\N	MEMBRE	NON	\N	\N
SENCOMLOIS	ANCIEN	246	\N	\N	\N	\N	1	0	2009-03-11 00:00:00	2018-08-02 00:00:00	204	\N	\N	MEMBRE	NON	\N	\N
SENCOMAFCL	ACTIF	138	\N	\N	\N	\N	1	2	\N	2019-02-12 00:00:00	205	\N	2019-02-26 15:44:27	MEMBRE	NON	\N	\N
SENCOMCDD	ACTIF	141	\N	\N	\N	\N	3	0	\N	\N	206	\N	\N	MEMBRE	NON	\N	\N
SENCOMFINC	ACTIF	36	\N	\N	\N	\N	1	0	\N	\N	151	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	275	\N	\N	\N	\N	2	1	\N	\N	321	\N	\N	MEMBRE	NON	\N	\N
SENCOMFINC	ANCIEN	164	\N	\N	\N	\N	2	0	\N	2018-08-04 00:00:00	170	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	180	\N	\N	\N	\N	2	0	\N	\N	144	\N	\N	MEMBRE	NON	\N	\N
COMAFCL	ACTIF	249	\N	\N	\N	\N	1	1	\N	\N	207	\N	2014-07-11 11:33:23	MEMBRE	NON	\N	\N
SENCOMFINC	ACTIF	143	\N	\N	\N	\N	1	\N	\N	\N	162	\N	\N	MEMBRE	NON	\N	\N
SENCOMFINC	ACTIF	178	\N	\N	\N	\N	\N	\N	\N	\N	172	\N	\N	MEMBRE	NON	\N	\N
PDTOPECST	ANCIEN	610	\N	\N	\N	\N	1	1	\N	2018-08-02 00:00:00	208	\N	\N	MEMBRE	NON	\N	\N
COMAFCL	ANCIEN	273	\N	\N	\N	\N	1	0	\N	2018-08-02 00:00:00	209	\N	\N	MEMBRE	NON	\N	\N
COMETRD	ACTIF	273	\N	\N	\N	\N	2	0	\N	\N	210	\N	\N	MEMBRE	NON	\N	\N
SENCOMAFCL	ANCIEN	274	\N	\N	\N	\N	1	0	\N	2019-11-26 00:00:00	211	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	146	\N	\N	\N	\N	2	\N	\N	\N	212	\N	\N	MEMBRE	NON	\N	\N
SENCOMFINC	ACTIF	111	\N	\N	\N	\N	\N	\N	\N	\N	213	\N	\N	MEMBRE	NON	\N	\N
SENCOMFINC	ANCIEN	189	\N	\N	\N	\N	1	0	\N	2018-08-02 00:00:00	214	\N	\N	MEMBRE	NON	\N	\N
SENCOMFINC	ACTIF	209	\N	\N	\N	\N	1	\N	\N	\N	215	\N	\N	MEMBRE	NON	\N	\N
SENCOMFINC	ACTIF	166	\N	\N	\N	\N	\N	\N	\N	\N	216	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ANCIEN	180	\N	\N	\N	\N	1	0	\N	2015-01-01 00:00:00	217	\N	\N	MEMBRE	NON	\N	\N
SENCOMFINC	ACTIF	17	\N	\N	\N	\N	1	\N	\N	\N	218	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ANCIEN	108	\N	\N	\N	\N	0	1	\N	2015-01-01 00:00:00	219	\N	\N	MEMBRE	NON	\N	\N
SENCOMFINC	ACTIF	162	\N	\N	\N	\N	1	\N	\N	\N	220	\N	\N	MEMBRE	NON	\N	\N
SENCOMLOIS	ANCIEN	42	\N	\N	\N	\N	1	0	\N	2019-12-31 00:00:00	221	\N	\N	MEMBRE	NON	\N	\N
SENCOMLOIS	ACTIF	70	\N	\N	\N	\N	\N	\N	\N	\N	222	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	238	\N	\N	\N	\N	2	0	\N	\N	223	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	33	\N	\N	\N	\N	\N	\N	\N	\N	224	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	44	\N	\N	\N	\N	1	\N	\N	\N	225	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	11	\N	\N	\N	\N	\N	\N	\N	\N	226	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	121	\N	\N	\N	\N	2	\N	\N	\N	227	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	123	\N	\N	\N	\N	2	\N	\N	\N	228	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	131	\N	\N	\N	\N	\N	\N	\N	\N	229	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	137	\N	\N	\N	\N	2	0	\N	\N	230	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	145	\N	\N	\N	\N	\N	\N	\N	\N	231	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	148	\N	\N	\N	\N	3	\N	\N	\N	232	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	150	\N	\N	\N	\N	3	\N	\N	\N	233	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	86	\N	\N	\N	\N	1	0	\N	\N	234	\N	2014-07-11 11:57:25	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	98	\N	\N	\N	\N	5	\N	\N	\N	235	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	113	\N	\N	\N	\N	\N	\N	\N	\N	236	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	213	\N	\N	\N	\N	2	\N	\N	\N	237	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	218	\N	\N	\N	\N	1	\N	\N	\N	238	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	221	\N	\N	\N	\N	1	\N	\N	\N	239	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	227	\N	\N	\N	\N	4	\N	\N	\N	240	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	228	\N	\N	\N	\N	3	\N	\N	\N	241	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	195	\N	\N	\N	\N	3	3	\N	\N	242	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	203	\N	\N	\N	\N	2	\N	\N	\N	243	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	202	\N	\N	\N	\N	1	\N	\N	\N	244	\N	2019-02-25 17:01:29	MEMBRE	NON	\N	\N
SENCOMAFCL	ACTIF	100	\N	\N	\N	\N	\N	\N	\N	\N	245	\N	\N	MEMBRE	NON	\N	\N
SENCOMAFCL	ACTIF	103	\N	\N	\N	\N	\N	\N	\N	\N	246	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	244	\N	\N	\N	\N	2	\N	\N	\N	247	\N	\N	MEMBRE	NON	\N	\N
SENCOMCDD	ACTIF	231	\N	\N	\N	\N	1	0	\N	\N	703	\N	\N	MEMBRE	NON	\N	\N
SENCOMAFCL	ACTIF	208	\N	\N	\N	\N	1	0	\N	\N	249	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ANCIEN	169	\N	\N	\N	\N	1	0	\N	2015-01-01 00:00:00	250	\N	\N	MEMBRE	NON	\N	\N
SENCOMAFCL	ANCIEN	186	\N	\N	\N	\N	1	1	\N	2018-08-03 00:00:00	251	\N	\N	MEMBRE	NON	\N	\N
SENCOMCAE	ACTIF	25	\N	\N	\N	\N	\N	\N	\N	\N	252	\N	\N	MEMBRE	NON	\N	\N
SENCOMCAE	ACTIF	37	\N	\N	\N	\N	2	0	\N	2020-09-30 00:00:00	253	\N	\N	MEMBRE	NON	\N	\N
SENCOMCDD	ANCIEN	72	\N	\N	\N	\N	2	0	\N	2018-08-04 00:00:00	254	\N	\N	MEMBRE	NON	\N	\N
SENCOMCAE	ACTIF	1	\N	\N	\N	\N	\N	\N	\N	\N	255	\N	\N	MEMBRE	NON	\N	\N
SENCOMCAE	ACTIF	16	\N	\N	\N	\N	1	0	\N	\N	256	\N	\N	MEMBRE	NON	\N	\N
SENCOMCAE	ACTIF	132	\N	\N	\N	\N	\N	\N	\N	\N	257	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	81	\N	\N	\N	\N	1	1	\N	\N	258	\N	2019-02-25 18:41:21	MEMBRE	NON	\N	\N
SENCOMCAE	ACTIF	91	\N	\N	\N	\N	1	\N	\N	\N	259	\N	\N	MEMBRE	NON	\N	\N
SENCOMCAE	ACTIF	116	\N	\N	\N	\N	\N	\N	\N	\N	260	\N	\N	MEMBRE	NON	\N	\N
SENCOMCAE	ACTIF	223	\N	\N	\N	\N	\N	\N	\N	\N	261	\N	\N	MEMBRE	NON	\N	\N
SENCOMCAE	ACTIF	155	\N	\N	\N	\N	1	0	\N	\N	262	\N	\N	MEMBRE	NON	\N	\N
SENCOMCAE	ACTIF	192	\N	\N	\N	\N	1	0	\N	\N	108	\N	\N	MEMBRE	NON	\N	\N
SENCOMETRD	ACTIF	17	\N	\N	\N	\N	1	\N	\N	\N	264	\N	\N	MEMBRE	NON	\N	\N
COMSOCI	ACTIF	53	\N	\N	\N	\N	1	\N	\N	\N	265	\N	\N	MEMBRE	NON	\N	\N
SENCOMSOCI	ACTIF	66	\N	\N	\N	\N	\N	\N	\N	\N	266	\N	\N	MEMBRE	NON	\N	\N
COMSOCI	ANCIEN	124	\N	\N	\N	\N	1	1	\N	2018-08-02 00:00:00	267	\N	\N	MEMBRE	NON	\N	\N
COMSOCI	ACTIF	76	\N	\N	\N	\N	1	0	\N	\N	268	\N	2014-07-11 16:09:32	MEMBRE	NON	\N	\N
SENCOMSOCI	ACTIF	247	\N	\N	\N	\N	2	0	2009-03-26 00:00:00	\N	269	\N	\N	MEMBRE	NON	\N	\N
SENCOMSOCI	ACTIF	256	\N	\N	\N	1	1	0	\N	\N	270	\N	2017-04-11 14:02:35	MEMBRE	NON	\N	\N
SENCOMFINC	ACTIF	254	\N	\N	\N	\N	1	\N	\N	\N	271	\N	\N	MEMBRE	NON	\N	\N
SENCOMCAE	ACTIF	252	\N	\N	\N	\N	1	0	\N	\N	272	\N	\N	MEMBRE	NON	\N	\N
SENCOMCAE	ANCIEN	251	\N	\N	\N	\N	1	0	\N	2018-08-02 00:00:00	273	\N	\N	MEMBRE	NON	\N	\N
COMAFCL	ACTIF	250	\N	\N	\N	\N	1	\N	\N	\N	274	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	264	\N	\N	\N	1	2	\N	\N	\N	275	\N	2017-04-11 14:11:52	MEMBRE	NON	\N	\N
SENCOMSOCI	ACTIF	267	\N	\N	\N	1	1	1	\N	\N	276	\N	2017-04-11 14:12:12	MEMBRE	NON	\N	\N
SENCOMAFCL	ACTIF	242	\N	\N	\N	\N	1	1	2008-02-07 00:00:00	\N	277	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	253	\N	\N	\N	\N	1	0	\N	\N	278	\N	\N	MEMBRE	NON	\N	\N
SENCOMCAE	ACTIF	268	\N	\N	\N	1	1	1	\N	\N	279	\N	2017-04-11 14:12:18	MEMBRE	NON	\N	\N
SENCOMCAE	ACTIF	271	\N	\N	\N	\N	1	0	\N	\N	280	\N	\N	MEMBRE	NON	\N	\N
SENCOMSOCI	ANCIEN	270	\N	\N	\N	1	2	2	\N	2018-08-02 00:00:00	281	\N	\N	MEMBRE	NON	\N	\N
SENCOMCAE	ANCIEN	270	\N	\N	\N	4	1	1	\N	2018-08-02 00:00:00	282	\N	\N	MEMBRE	NON	\N	\N
SENCOMFINC	ANCIEN	270	\N	\N	\N	2	2	2	\N	2018-08-02 00:00:00	283	\N	\N	MEMBRE	NON	\N	\N
SENCOMLOIS	ANCIEN	270	\N	\N	\N	3	2	2	\N	2018-08-02 00:00:00	284	\N	\N	MEMBRE	NON	\N	\N
SENCOMAFCL	ANCIEN	270	\N	\N	\N	6	1	1	\N	2018-08-02 00:00:00	285	\N	\N	MEMBRE	NON	\N	\N
SENCOMAFEU	ANCIEN	270	\N	\N	\N	7	1	1	\N	2018-08-02 00:00:00	286	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	266	\N	\N	\N	1	1	\N	\N	\N	287	\N	2017-04-11 14:12:07	MEMBRE	NON	\N	\N
SENCOMLOIS	ACTIF	235	\N	\N	\N	\N	1	1	\N	\N	288	\N	\N	MEMBRE	NON	\N	\N
SENCOMCAE	ANCIEN	233	\N	\N	\N	\N	1	0	\N	2018-08-02 00:00:00	289	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	255	\N	\N	\N	\N	1	0	\N	\N	290	\N	2019-02-25 11:29:36	MEMBRE	NON	\N	\N
SENCOMCAE	ACTIF	257	\N	\N	\N	\N	2	0	\N	\N	291	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	269	\N	\N	\N	\N	1	\N	\N	\N	292	\N	\N	MEMBRE	NON	\N	\N
SENCOMSOCI	ACTIF	232	\N	\N	\N	\N	1	1	\N	\N	293	\N	\N	MEMBRE	NON	\N	\N
SENCOMCAE	ACTIF	24	\N	\N	\N	\N	2	2	\N	2019-02-12 00:00:00	294	\N	2019-02-26 11:44:53	MEMBRE	NON	\N	\N
SENCOMCDD	ACTIF	230	\N	\N	\N	\N	1	0	\N	\N	296	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	237	\N	\N	\N	\N	2	\N	\N	\N	297	\N	\N	MEMBRE	NON	\N	\N
SENCOMCDD	ACTIF	263	\N	\N	\N	\N	1	0	\N	\N	298	\N	\N	MEMBRE	NON	\N	\N
SENCOMETRD	ANCIEN	272	\N	\N	\N	1	1	0	\N	2018-08-02 00:00:00	299	\N	\N	MEMBRE	NON	\N	\N
SENCOMSOCI	ANCIEN	272	\N	\N	\N	2	1	0	\N	2018-08-02 00:00:00	300	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	239	\N	\N	\N	\N	1	\N	\N	\N	301	\N	2019-02-25 16:52:34	MEMBRE	NON	\N	\N
SENCOMLOIS	ACTIF	241	\N	\N	\N	\N	1	\N	\N	\N	302	\N	\N	MEMBRE	NON	\N	\N
SENCOMCAE	ANCIEN	258	\N	\N	\N	1	1	1	\N	2018-08-02 00:00:00	303	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	259	\N	\N	\N	\N	4	0	\N	\N	304	\N	\N	MEMBRE	NON	\N	\N
SENCOMCDD	ANCIEN	161	\N	\N	\N	\N	1	0	\N	2018-08-02 00:00:00	722	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	262	\N	\N	\N	1	1	0	\N	\N	305	\N	2017-04-11 14:11:43	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	281	\N	\N	\N	\N	1	\N	\N	\N	442	\N	\N	MEMBRE	NON	\N	\N
COMETRD	ACTIF	279	\N	\N	\N	\N	1	\N	\N	\N	462	\N	\N	MEMBRE	NON	\N	\N
COMLOIS	ACTIF	279	\N	\N	\N	\N	1	\N	\N	\N	463	\N	2014-07-11 16:00:01	MEMBRE	NON	\N	\N
SENCOMETRD	ACTIF	280	\N	\N	\N	\N	1	\N	\N	\N	464	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	289	\N	\N	\N	1	1	0	\N	\N	561	\N	2017-04-11 14:28:10	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	288	\N	\N	\N	\N	2	0	\N	\N	581	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	291	\N	\N	\N	\N	1	\N	\N	\N	622	\N	2019-02-26 12:09:47	MEMBRE	NON	\N	\N
SENCOMCDD	ACTIF	181	\N	\N	\N	\N	1	0	\N	\N	723	\N	\N	MEMBRE	NON	\N	\N
SENCOMCDD	ANCIEN	233	\N	\N	\N	\N	1	0	\N	2018-08-02 00:00:00	724	\N	\N	MEMBRE	NON	\N	\N
SENCOMCDD	ANCIEN	270	\N	\N	\N	5	1	1	\N	2018-08-02 00:00:00	726	\N	\N	MEMBRE	NON	\N	\N
SENCOMCDD	ANCIEN	287	\N	\N	\N	\N	0	1	\N	2018-08-02 00:00:00	727	\N	\N	MEMBRE	NON	\N	\N
SENCOMETRD	ANCIEN	126	\N	\N	\N	\N	1	1	\N	2018-08-02 00:00:00	782	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	297	\N	\N	\N	\N	1	0	\N	\N	821	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	298	\N	\N	\N	\N	1	\N	\N	\N	822	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	299	\N	\N	\N	\N	3	\N	\N	\N	823	\N	\N	MEMBRE	NON	\N	\N
MEMBREDRT	ACTIF	301	\N	\N	\N	\N	1	\N	\N	\N	841	\N	\N	MEMBRE	NON	\N	\N
SENCOMAFCL	ACTIF	302	\N	\N	\N	\N	1	0	\N	\N	881	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	306	\N	\N	\N	\N	2	\N	\N	\N	981	\N	\N	MEMBRE	NON	\N	\N
SENCOMAFCL	ANCIEN	276	\N	\N	\N	\N	1	0	\N	2018-08-02 00:00:00	363	\N	\N	MEMBRE	NON	\N	\N
COMAFCL	ACTIF	278	\N	\N	\N	\N	2	\N	\N	\N	382	\N	\N	MEMBRE	NON	\N	\N
SENCOMFINC	ACTIF	296	\N	\N	\N	\N	1	1	\N	2019-02-12 00:00:00	761	\N	2019-02-26 15:15:05	MEMBRE	NON	\N	\N
SENCOMFINC	ACTIF	277	\N	\N	\N	\N	1	\N	\N	\N	381	\N	\N	MEMBRE	NON	\N	\N
SENCOMCDD	ANCIEN	295	\N	\N	\N	\N	2	2	\N	2019-02-12 00:00:00	742	\N	\N	MEMBRE	NON	\N	\N
SENCOMSOCI	ACTIF	296	\N	\N	\N	\N	1	1	\N	2019-02-12 00:00:00	743	\N	2019-02-26 15:17:16	MEMBRE	NON	\N	\N
SENCOMCDD	ANCIEN	282	\N	\N	\N	\N	1	1	\N	2018-08-02 00:00:00	481	\N	\N	MEMBRE	NON	\N	\N
SENCOMLOIS	ANCIEN	282	\N	\N	\N	\N	1	1	\N	2018-08-02 00:00:00	482	\N	\N	MEMBRE	NON	\N	\N
SENCOMCDD	ACTIF	284	\N	\N	\N	\N	1	0	\N	\N	501	\N	\N	MEMBRE	NON	\N	\N
SENCOMAFCL	ANCIEN	283	\N	\N	\N	\N	1	0	\N	2018-08-02 00:00:00	541	\N	\N	MEMBRE	NON	\N	\N
SENCOMCAE	ANCIEN	287	\N	\N	\N	\N	1	0	\N	2018-08-02 00:00:00	542	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	293	\N	\N	\N	\N	1	1	\N	\N	661	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	301	\N	\N	\N	\N	2	0	\N	\N	801	\N	\N	MEMBRE	NON	\N	\N
COMAFCL	ACTIF	300	\N	\N	\N	\N	1	0	\N	\N	802	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	303	\N	\N	\N	\N	2	0	\N	\N	921	\N	\N	MEMBRE	NON	\N	\N
COMAFCL	ANCIEN	292	\N	\N	\N	\N	1	0	\N	2018-08-03 00:00:00	641	\N	\N	MEMBRE	NON	\N	\N
COMETRD	ACTIF	292	\N	\N	\N	\N	2	0	\N	\N	642	\N	\N	MEMBRE	NON	\N	\N
SENCOMCDD	ANCIEN	95	\N	\N	\N	\N	2	0	\N	2018-08-02 00:00:00	709	\N	\N	MEMBRE	NON	\N	\N
SENCOMCAE	ANCIEN	285	\N	\N	\N	285	1	0	\N	2018-08-03 00:00:00	522	\N	\N	MEMBRE	NON	\N	\N
SENCOMLOIS	ACTIF	286	\N	\N	\N	1	2	0	\N	\N	523	\N	2017-04-11 14:27:59	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	305	\N	\N	\N	\N	1	\N	2012-12-06 00:00:00	\N	961	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	314	\N	\N	\N	\N	3	\N	\N	\N	1021	2013-08-27 10:40:48	2018-11-28 12:36:25	MEMBRE	NON	\N	\N
COMAFCL	ACTIF	313	\N	\N	\N	\N	3	\N	\N	\N	1022	2013-08-27 10:48:12	2013-10-18 09:46:41	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	307	\N	\N	\N	\N	2	\N	\N	\N	1023	2013-08-27 11:32:57	2014-08-01 11:10:53	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	309	\N	\N	\N	\N	1	\N	\N	\N	1024	2013-08-27 11:42:49	2019-02-26 10:06:33	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	308	\N	\N	\N	\N	1	1	\N	\N	1026	2013-08-27 11:56:17	\N	MEMBRE	NON	\N	\N
SENCOMLOIS	ANCIEN	310	\N	\N	\N	\N	1	1	\N	2018-08-02 00:00:00	1027	\N	\N	MEMBRE	NON	\N	\N
SENCOMCAE	ACTIF	311	\N	\N	\N	\N	1	1	\N	\N	1028	2013-08-27 12:00:41	\N	MEMBRE	NON	\N	\N
SENCOMCDD	ACTIF	311	\N	\N	\N	\N	1	1	\N	\N	1029	2013-08-27 12:00:53	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	312	\N	\N	\N	\N	1	0	\N	\N	1030	\N	\N	MEMBRE	NON	\N	\N
SENCOMAFCL	ANCIEN	115	\N	\N	\N	\N	1	0	\N	2018-08-03 00:00:00	401	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	234	\N	\N	\N	\N	2	\N	\N	\N	421	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	236	\N	\N	\N	\N	2	\N	\N	\N	422	\N	2019-02-25 18:13:12	MEMBRE	NON	\N	\N
SENCOMCDD	ACTIF	294	\N	\N	\N	\N	1	1	\N	\N	681	\N	\N	MEMBRE	NON	\N	\N
SCRUTIN	ACTIF	611	\N	\N	\N	\N	\N	\N	\N	\N	1	\N	\N	MEMBRE	NON	\N	\N
SCRUTIN	ACTIF	612	\N	\N	\N	\N	6	6	\N	\N	2	\N	\N	MEMBRE	NON	\N	\N
MEMBREDRT	ACTIF	608	\N	\N	\N	\N	4	\N	\N	\N	3	\N	\N	MEMBRE	NON	\N	\N
MEMBREDRT	ACTIF	604	\N	\N	\N	\N	\N	\N	\N	\N	4	\N	\N	MEMBRE	NON	\N	\N
MEMBREDRT	ACTIF	602	\N	\N	\N	\N	\N	\N	\N	\N	5	\N	\N	MEMBRE	NON	\N	\N
MEMBREDRT	ACTIF	603	\N	\N	\N	\N	\N	\N	\N	\N	6	\N	\N	MEMBRE	NON	\N	\N
MEMBREDRT	ACTIF	605	\N	\N	\N	\N	1	\N	\N	\N	7	\N	\N	MEMBRE	NON	\N	\N
MEMBREDRT	ACTIF	606	\N	\N	\N	\N	1	\N	\N	\N	8	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	30	\N	\N	\N	\N	1	0	\N	\N	11	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	35	\N	\N	\N	\N	\N	\N	\N	\N	12	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	64	\N	\N	\N	\N	1	1	\N	\N	13	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	18	\N	\N	\N	\N	\N	\N	\N	\N	14	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	22	\N	\N	\N	\N	1	1	\N	\N	15	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	122	\N	\N	\N	\N	\N	\N	\N	\N	16	\N	\N	MEMBRE	NON	\N	\N
SENCOMSOCI	ANCIEN	127	\N	\N	\N	\N	1	1	\N	2013-12-16 00:00:00	17	\N	2017-04-04 16:15:50	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	129	\N	\N	\N	\N	\N	\N	\N	\N	18	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	136	\N	\N	\N	\N	1	1	\N	\N	19	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	139	\N	\N	\N	\N	\N	\N	\N	\N	20	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	140	\N	\N	\N	\N	3	0	\N	\N	21	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	151	\N	\N	\N	\N	3	\N	\N	\N	23	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	152	\N	\N	\N	\N	1	\N	\N	\N	24	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	90	\N	\N	\N	\N	\N	\N	\N	\N	25	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	107	\N	\N	\N	\N	1	0	\N	\N	26	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	114	\N	\N	\N	\N	\N	\N	\N	\N	27	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	118	\N	\N	\N	\N	1	0	\N	\N	28	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	216	\N	\N	\N	\N	\N	\N	\N	\N	29	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	219	\N	\N	\N	\N	5	\N	\N	\N	30	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	220	\N	\N	\N	\N	3	\N	\N	\N	31	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	224	\N	\N	\N	\N	2	\N	\N	\N	32	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	225	\N	\N	\N	\N	4	\N	\N	\N	33	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	191	\N	\N	\N	\N	\N	\N	\N	\N	35	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ANCIEN	201	\N	\N	\N	\N	1	1	\N	2021-09-30 00:00:00	36	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	200	\N	\N	\N	\N	1	0	\N	\N	37	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ANCIEN	204	\N	\N	\N	\N	1	1	\N	2019-08-03 00:00:00	38	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	205	\N	\N	\N	\N	1	0	\N	\N	39	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	210	\N	\N	\N	\N	1	1	\N	\N	40	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	211	\N	\N	\N	\N	2	2	\N	\N	41	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	165	\N	\N	\N	\N	2	\N	\N	\N	42	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	168	\N	\N	\N	\N	1	0	\N	\N	43	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	174	\N	\N	\N	\N	\N	\N	\N	\N	44	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	175	\N	\N	\N	\N	1	0	\N	\N	45	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	177	\N	\N	\N	\N	3	0	\N	\N	46	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	182	\N	\N	\N	\N	\N	\N	\N	\N	47	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	183	\N	\N	\N	\N	\N	\N	\N	\N	48	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	188	\N	\N	\N	\N	2	0	\N	\N	49	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	153	\N	\N	\N	\N	2	\N	\N	\N	50	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	156	\N	\N	\N	\N	1	\N	\N	\N	51	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	157	\N	\N	\N	\N	1	\N	\N	\N	52	\N	2019-02-25 16:44:51	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	158	\N	\N	\N	\N	1	\N	\N	\N	53	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	78	\N	\N	\N	\N	\N	\N	\N	\N	54	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	142	\N	\N	\N	\N	\N	\N	\N	\N	55	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	154	\N	\N	\N	\N	\N	\N	\N	\N	56	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	32	\N	\N	\N	\N	\N	\N	\N	\N	57	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	67	\N	\N	\N	\N	4	\N	\N	\N	58	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	159	\N	\N	\N	\N	\N	\N	\N	\N	59	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	160	\N	\N	\N	\N	2	\N	\N	\N	60	\N	\N	MEMBRE	NON	\N	\N
SENCOMSOCI	ACTIF	88	\N	\N	\N	\N	1	0	\N	\N	61	\N	\N	MEMBRE	NON	\N	\N
SENCOMAFCL	ANCIEN	222	\N	\N	\N	\N	1	0	\N	2018-08-02 00:00:00	62	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	199	\N	\N	\N	\N	3	0	\N	\N	63	\N	\N	MEMBRE	NON	\N	\N
SENCOMSOCI	ACTIF	209	\N	\N	\N	\N	2	\N	\N	\N	64	\N	\N	MEMBRE	NON	\N	\N
SENCOMSOCI	ACTIF	170	\N	\N	\N	\N	1	0	\N	\N	65	\N	\N	MEMBRE	NON	\N	\N
SENCOMSOCI	ACTIF	50bis	\N	\N	\N	\N	\N	\N	\N	\N	66	\N	\N	MEMBRE	NON	\N	\N
SENCOMFINC	ACTIF	3	\N	\N	\N	\N	1	0	\N	\N	67	\N	\N	MEMBRE	NON	\N	\N
SENCOMFINC	ANCIEN	126	\N	\N	\N	\N	1	1	\N	2018-08-02 00:00:00	68	\N	\N	MEMBRE	NON	\N	\N
SENCOMFINC	ACTIF	135	\N	\N	\N	\N	\N	\N	\N	\N	69	\N	\N	MEMBRE	NON	\N	\N
SENCOMFINC	ACTIF	144	\N	\N	\N	\N	1	\N	\N	\N	70	\N	\N	MEMBRE	NON	\N	\N
SENCOMAFCL	ANCIEN	29	\N	\N	\N	\N	1	1	\N	2018-08-02 00:00:00	71	\N	\N	MEMBRE	NON	\N	\N
SENCOMAFCL	ANCIEN	42	\N	\N	\N	\N	1	0	\N	2019-12-31 00:00:00	72	\N	\N	MEMBRE	NON	\N	\N
SENCOMAFCL	ANCIEN	49	\N	\N	\N	\N	1	0	\N	2019-06-01 00:00:00	73	\N	\N	MEMBRE	NON	\N	\N
SENCOMAFCL	ACTIF	52	\N	\N	\N	\N	2	2	\N	\N	74	\N	\N	MEMBRE	NON	\N	\N
SENCOMAFCL	ANCIEN	72	\N	\N	\N	\N	2	0	\N	2018-08-04 00:00:00	75	\N	\N	MEMBRE	NON	\N	\N
SENCOMAFCL	ACTIF	56	\N	\N	\N	\N	\N	\N	\N	\N	76	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	23	\N	\N	\N	\N	2	\N	\N	\N	77	\N	\N	MEMBRE	NON	\N	\N
SENCOMAFCL	ACTIF	125	\N	\N	\N	\N	\N	\N	\N	\N	78	\N	\N	MEMBRE	NON	\N	\N
SENCOMAFCL	ACTIF	133	\N	\N	\N	\N	\N	\N	\N	\N	79	\N	\N	MEMBRE	NON	\N	\N
SENCOMAFCL	ACTIF	134	\N	\N	\N	\N	\N	\N	\N	\N	80	\N	\N	MEMBRE	NON	\N	\N
SENCOMAFCL	ACTIF	84	\N	\N	\N	\N	\N	\N	\N	\N	81	\N	\N	MEMBRE	NON	\N	\N
SENCOMAFCL	ACTIF	89	\N	\N	\N	\N	\N	\N	\N	\N	82	\N	\N	MEMBRE	NON	\N	\N
SENCOMAFCL	ANCIEN	99	\N	\N	\N	\N	1	0	\N	2022-12-31 00:00:00	84	\N	\N	MEMBRE	NON	\N	\N
SENCOMAFCL	ACTIF	101	\N	\N	\N	\N	\N	\N	\N	\N	85	\N	\N	MEMBRE	NON	\N	\N
SENCOMAFCL	ACTIF	102	\N	\N	\N	\N	\N	\N	\N	\N	86	\N	\N	MEMBRE	NON	\N	\N
SENCOMAFCL	ANCIEN	104	\N	\N	\N	\N	1	1	\N	2018-08-03 00:00:00	87	\N	\N	MEMBRE	NON	\N	\N
SENCOMAFCL	ACTIF	198	\N	\N	\N	\N	1	1	\N	\N	88	\N	\N	MEMBRE	NON	\N	\N
SENCOMAFCL	ANCIEN	167	\N	\N	\N	\N	1	0	\N	2018-08-02 00:00:00	89	\N	\N	MEMBRE	NON	\N	\N
SENCOMAFCL	ACTIF	171	\N	\N	\N	\N	\N	\N	\N	\N	90	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	172	\N	\N	\N	\N	3	0	\N	\N	91	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	108	\N	\N	\N	\N	1	1	\N	\N	92	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	379	\N	\N	\N	\N	1	\N	\N	\N	1881	2019-02-25 16:39:24	\N	MEMBRE	NON	\N	\N
SENCOMCDD	ANCIEN	29	\N	\N	\N	\N	1	1	\N	2018-08-02 00:00:00	94	\N	\N	MEMBRE	NON	\N	\N
SENAT	ACTIF	39	\N	\N	\N	\N	1	\N	\N	\N	95	\N	\N	MEMBRE	NON	\N	\N
SENCOMCAE	ACTIF	43	\N	\N	\N	\N	1	\N	\N	\N	96	\N	\N	MEMBRE	NON	\N	\N
SENCOMCAE	ACTIF	74	\N	\N	\N	\N	1	0	\N	\N	97	\N	\N	MEMBRE	NON	\N	\N
SENCOMCDD	ACTIF	75	\N	\N	\N	\N	2	2	\N	\N	98	\N	\N	MEMBRE	NON	\N	\N
SENCOMCAE	ACTIF	2	\N	\N	\N	\N	\N	\N	\N	\N	99	\N	\N	MEMBRE	NON	\N	\N
SENCOMCAE	ACTIF	20	\N	\N	\N	\N	3	0	\N	\N	100	\N	\N	MEMBRE	NON	\N	\N
SENCOMCDD	ANCIEN	120	\N	\N	\N	\N	1	0	\N	2018-08-03 00:00:00	101	\N	\N	MEMBRE	NON	\N	\N
SENCOMCAE	ACTIF	135	\N	\N	\N	\N	\N	\N	\N	\N	102	\N	\N	MEMBRE	NON	\N	\N
SENCOMCAE	ACTIF	82	\N	\N	\N	\N	\N	\N	\N	\N	103	\N	\N	MEMBRE	NON	\N	\N
SENCOMCAE	ANCIEN	95	\N	\N	\N	\N	2	0	\N	2018-08-02 00:00:00	104	\N	\N	MEMBRE	NON	\N	\N
SENCOMCAE	ACTIF	217	\N	\N	\N	\N	\N	\N	\N	\N	106	\N	\N	MEMBRE	NON	\N	\N
SENCOMCDD	ANCIEN	189	\N	\N	\N	\N	1	0	\N	2018-08-02 00:00:00	107	\N	\N	MEMBRE	NON	\N	\N
SENCOMCAE	ACTIF	193	\N	\N	\N	\N	1	1	\N	\N	109	\N	\N	MEMBRE	NON	\N	\N
SENCOMCAE	ACTIF	197	\N	\N	\N	\N	1	\N	\N	\N	110	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	206	\N	\N	\N	\N	1	0	\N	\N	111	\N	\N	MEMBRE	NON	\N	\N
SENCOMCAE	ACTIF	207	\N	\N	\N	\N	1	0	\N	\N	112	\N	\N	MEMBRE	NON	\N	\N
SENCOMCAE	ACTIF	163	\N	\N	\N	\N	1	0	\N	\N	113	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	169	\N	\N	\N	\N	4	0	\N	\N	114	\N	\N	MEMBRE	NON	\N	\N
SENCOMCAE	ACTIF	94	\N	\N	\N	\N	\N	\N	\N	\N	115	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ANCIEN	172	\N	\N	\N	\N	1	0	\N	2015-01-01 00:00:00	116	\N	\N	MEMBRE	NON	\N	\N
SENCOMCAE	ACTIF	173	\N	\N	\N	\N	\N	\N	\N	\N	117	\N	\N	MEMBRE	NON	\N	\N
SENCOMCAE	ACTIF	181	\N	\N	\N	\N	1	0	\N	\N	119	\N	\N	MEMBRE	NON	\N	\N
SENCOMCAE	ACTIF	184	\N	\N	\N	\N	\N	\N	\N	\N	120	\N	\N	MEMBRE	NON	\N	\N
SENCOMCDD	ACTIF	185	\N	\N	\N	\N	1	1	\N	\N	121	\N	\N	MEMBRE	NON	\N	\N
SENCOMCAE	ACTIF	38	\N	\N	\N	\N	\N	\N	\N	\N	122	\N	\N	MEMBRE	NON	\N	\N
SENCOMCAE	ANCIEN	73	\N	\N	\N	\N	1	0	\N	2018-08-02 00:00:00	123	\N	\N	MEMBRE	NON	\N	\N
SENCOMCAE	ANCIEN	161	\N	\N	\N	\N	1	0	\N	2018-08-02 00:00:00	124	\N	\N	MEMBRE	NON	\N	\N
SENCOMCAE	ACTIF	135 bis	\N	\N	\N	\N	\N	\N	\N	\N	125	\N	\N	MEMBRE	NON	\N	\N
SENCOMETRD	ANCIEN	115	\N	\N	\N	\N	1	0	\N	2018-08-03 00:00:00	126	\N	\N	MEMBRE	NON	\N	\N
SENCOMSOCI	ACTIF	43	\N	\N	\N	\N	1	\N	\N	\N	127	\N	\N	MEMBRE	NON	\N	\N
COMSOCI	ACTIF	65	\N	\N	\N	\N	1	\N	\N	\N	129	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	8	\N	\N	\N	\N	1	\N	\N	\N	130	\N	\N	MEMBRE	NON	\N	\N
SENCOMSOCI	ANCIEN	12	\N	\N	\N	\N	1	1	\N	2013-06-04 00:00:00	131	\N	2017-04-04 15:04:24	MEMBRE	NON	\N	\N
SENCOMSOCI	ACTIF	16	\N	\N	\N	\N	1	0	\N	\N	132	\N	\N	MEMBRE	NON	\N	\N
SENCOMSOCI	ANCIEN	128	\N	\N	\N	\N	2	0	\N	2018-08-02 00:00:00	133	\N	\N	MEMBRE	NON	\N	\N
SENCOMSOCI	ANCIEN	147	\N	\N	\N	\N	1	0	\N	2018-08-02 00:00:00	134	\N	\N	MEMBRE	NON	\N	\N
SENCOMSOCI	ACTIF	77	\N	\N	\N	\N	2	0	\N	\N	135	\N	\N	MEMBRE	NON	\N	\N
SENCOMSOCI	ANCIEN	95	\N	\N	\N	\N	1	0	\N	2015-01-01 00:00:00	136	\N	\N	MEMBRE	NON	\N	\N
SENCOMSOCI	ANCIEN	214	\N	\N	\N	\N	1	1	\N	2018-08-02 00:00:00	137	\N	\N	MEMBRE	NON	\N	\N
SENCOMSOCI	ACTIF	194	\N	\N	\N	\N	2	0	\N	2019-02-12 00:00:00	139	\N	2019-02-26 15:28:50	MEMBRE	NON	\N	\N
SENCOMSOCI	ACTIF	207	\N	\N	\N	\N	0	1	\N	\N	140	\N	\N	MEMBRE	NON	\N	\N
SENCOMSOCI	ANCIEN	212	\N	\N	\N	\N	1	0	\N	2018-08-02 00:00:00	141	\N	\N	MEMBRE	NON	\N	\N
SENCOMSOCI	ANCIEN	164	\N	\N	\N	\N	2	0	\N	2018-08-04 00:00:00	142	\N	\N	MEMBRE	NON	\N	\N
SENCOMSOCI	ACTIF	178	\N	\N	\N	\N	\N	\N	\N	\N	143	\N	\N	MEMBRE	NON	\N	\N
SENCOMSOCI	ACTIF	46	\N	\N	\N	\N	1	\N	\N	2019-02-12 00:00:00	145	\N	2019-02-26 11:53:03	MEMBRE	NON	\N	\N
SENCOMSOCI	ACTIF	97	\N	\N	\N	\N	1	1	\N	\N	146	\N	\N	MEMBRE	NON	\N	\N
SENCOMSOCI	ACTIF	130	\N	\N	\N	\N	\N	\N	\N	\N	147	\N	\N	MEMBRE	NON	\N	\N
SENCOMSOCI	ACTIF	162	\N	\N	\N	\N	2	\N	\N	\N	148	\N	\N	MEMBRE	NON	\N	\N
SENCOMFINC	ACTIF	31	\N	\N	\N	\N	1	\N	\N	\N	149	\N	\N	MEMBRE	NON	\N	\N
SENCOMFINC	ANCIEN	34	\N	\N	\N	\N	1	1	\N	2018-08-02 00:00:00	150	\N	\N	MEMBRE	NON	\N	\N
SENCOMFINC	ANCIEN	49	\N	\N	\N	\N	1	0	\N	2019-06-01 00:00:00	152	\N	\N	MEMBRE	NON	\N	\N
SENCOMFINC	ACTIF	50	\N	\N	\N	\N	1	\N	\N	2019-02-12 00:00:00	153	\N	2019-02-26 12:26:33	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	378	\N	\N	\N	\N	1	1	\N	\N	1882	2019-02-25 18:35:25	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	388	\N	\N	\N	\N	158	0	\N	\N	1921	\N	\N	MEMBRE	NON	\N	\N
NOMART13CAE	ACTIF	10001	\N	\N	\N	\N	1	0	\N	\N	1961	\N	\N	PDG	NON	\N	\N
PDTSEN	ACTIF	49	\N	\N	\N	\N	2	0	2019-06-02 00:00:00	\N	2001	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	390	\N	\N	\N	\N	1	0	\N	\N	2002	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	190	\N	\N	\N	\N	1	0	\N	\N	2021	\N	\N	MEMBRE	NON	\N	\N
NOMART13CDD	ACTIF	10003	\N	\N	\N	\N	1	0	2019-09-01 00:00:00	\N	2061	\N	\N	PDG	NON	\N	\N
NOMART13CDD	ACTIF	10004	\N	\N	\N	\N	1	0	2019-06-01 00:00:00	\N	2062	\N	\N	PDTCA	NON	\N	\N
NOMART13CDD	ANCIEN	332	\N	\N	\N	\N	1	0	2019-09-01 00:00:00	2020-12-01 00:00:00	2081	\N	\N	PDTDIR	NON	\N	\N
NOMART13FINC	ACTIF	10005	\N	\N	\N	\N	1	0	2019-06-01 00:00:00	\N	2101	\N	\N	PDG	NON	\N	\N
NOMART13CDD	ACTIF	10006	\N	\N	\N	\N	1	0	2019-04-30 00:00:00	\N	2141	\N	\N	PDG	NON	\N	\N
NOMART13LOIS	ACTIF	10007	\N	\N	\N	\N	1	0	2019-02-13 00:00:00	\N	2142	\N	\N	MEMBRE	NON	\N	\N
PQPDTSENLOIS	ACTIF	10007	\N	\N	\N	\N	1	0	2019-02-13 00:00:00	\N	2143	\N	\N	MEMBRE	NON	\N	\N
PQPDTSEN	ACTIF	DSBP-0001	\N	\N	\N	\N	1	0	2019-12-04 00:00:00	2025-12-03 00:00:00	2201	\N	\N	MEMBRE	NON	\N	\N
NOMART13CAE	ACTIF	10009	\N	\N	\N	\N	1	0	2019-12-23 00:00:00	\N	2341	\N	\N	PDTCA	NON	\N	\N
NOMART13LOIS	ACTIF	42	\N	\N	\N	\N	1	0	2020-01-01 00:00:00	\N	2381	\N	\N	PDT	NON	\N	\N
NOMART13SOCI	ACTIF	30	\N	\N	\N	\N	1	0	2018-12-01 00:00:00	\N	2441	\N	\N	PDT	NON	\N	\N
AUDITSOCI	ACTIF	10015	\N	\N	\N	\N	1	0	2020-02-01 00:00:00	\N	2501	\N	\N	DG	NON	\N	\N
AUDITSOCI	ANCIEN	10017	\N	\N	\N	\N	1	0	2019-05-01 00:00:00	2022-09-01 00:00:00	2581	\N	\N	MEMBRE	NON	\N	\N
AUDITSOCI	ACTIF	389	\N	\N	\N	\N	1	0	2019-07-01 00:00:00	\N	2582	\N	\N	DG	NON	\N	\N
NOMART13CAE	ACTIF	10020	\N	\N	\N	\N	1	0	2018-06-01 00:00:00	\N	2641	\N	\N	PDTDIR	NON	\N	\N
NOMART13CAE	ACTIF	10021	\N	\N	\N	\N	1	0	2018-04-01 00:00:00	\N	2661	\N	\N	ADMINGENE	NON	\N	\N
PDTSEN	ACTIF	359	\N	\N	\N	\N	2	0	2020-02-21 00:00:00	\N	2701	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	358	\N	\N	\N	\N	1	0	2020-02-22 00:00:00	\N	2702	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	395	\N	\N	\N	\N	2	0	2020-05-25 00:00:00	\N	2721	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	320	\N	\N	\N	\N	2	2	2020-01-01 00:00:00	\N	2761	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	13	\N	\N	\N	\N	2	0	2018-08-03 00:00:00	\N	2841	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	29	\N	\N	\N	\N	3	3	2018-08-03 00:00:00	\N	2842	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	73	\N	\N	\N	\N	1	0	2018-08-03 00:00:00	\N	2843	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	34	\N	\N	\N	\N	2	2	2018-08-03 00:00:00	\N	2844	\N	\N	MEMBRE	NON	\N	\N
COMSOCI	ACTIF	124	\N	\N	\N	\N	1	0	2018-08-03 00:00:00	\N	2861	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	126	\N	\N	\N	\N	2	0	2018-08-03 00:00:00	\N	2862	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	128	\N	\N	\N	\N	2	0	2018-08-03 00:00:00	\N	2863	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	147	\N	\N	\N	\N	2	0	2018-08-03 00:00:00	\N	2864	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	189	\N	\N	\N	\N	2	0	2018-08-03 00:00:00	\N	2901	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	196	\N	\N	\N	\N	2	0	2018-08-03 00:00:00	\N	2902	\N	\N	MEMBRE	NON	\N	\N
SENCOMSOCI	ANCIEN	199	\N	\N	\N	\N	4	0	\N	2018-08-02 00:00:00	2903	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	329	\N	\N	\N	\N	1	0	2020-02-02 00:00:00	\N	2961	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	342	\N	\N	\N	\N	2	0	2018-08-03 00:00:00	\N	2962	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	344	\N	\N	\N	\N	1	0	2018-08-03 00:00:00	\N	2963	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	346	\N	\N	\N	\N	1	0	2018-08-03 00:00:00	\N	2964	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	362	\N	\N	\N	\N	1	1	2018-08-03 00:00:00	\N	2965	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	104	\N	\N	\N	\N	1	0	2018-08-04 00:00:00	\N	3021	\N	\N	MEMBRE	NON	\N	\N
SENCOMETRD	ANCIEN	318	\N	\N	\N	\N	2	2	\N	2019-02-12 00:00:00	1081	\N	\N	MEMBRE	NON	\N	\N
SENCOMCDD	ANCIEN	304	\N	\N	\N	\N	1	0	\N	2019-02-12 00:00:00	1121	\N	\N	MEMBRE	NON	\N	\N
SENCOMCAE	ANCIEN	304	\N	\N	\N	\N	1	0	\N	2019-02-12 00:00:00	1122	\N	\N	MEMBRE	NON	\N	\N
SENCOMAFCL	ANCIEN	304	\N	\N	\N	\N	0	1	\N	2019-02-12 00:00:00	1123	\N	\N	MEMBRE	NON	\N	\N
SENCOMFINC	ANCIEN	304	\N	\N	\N	\N	0	1	\N	2019-02-12 00:00:00	1124	\N	\N	MEMBRE	NON	\N	\N
COMAFCL	ACTIF	319	\N	\N	\N	\N	4	\N	\N	\N	1141	2014-02-12 12:00:58	\N	MEMBRE	NON	\N	\N
SENCOMFINC	ANCIEN	320	\N	\N	\N	\N	1	0	\N	2019-12-31 00:00:00	1161	\N	\N	MEMBRE	NON	\N	\N
SENCOMLOIS	ANCIEN	320	\N	\N	\N	\N	1	0	\N	2019-12-31 00:00:00	1162	\N	\N	MEMBRE	NON	\N	\N
SENCOMFINC	ANCIEN	320	\N	\N	\N	\N	0	1	\N	2019-12-31 00:00:00	1163	\N	\N	MEMBRE	NON	\N	\N
SENCOMLOIS	ANCIEN	320	\N	\N	\N	\N	0	1	\N	2019-12-31 00:00:00	1164	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	321	\N	\N	\N	\N	2	2	\N	\N	1165	2014-07-11 10:39:02	2014-07-11 16:21:48	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	315	\N	\N	\N	\N	2	2	\N	\N	1166	2014-07-11 10:59:28	2014-09-24 18:08:40	MEMBRE	NON	\N	\N
SENCOMAFCL	ANCIEN	290	\N	\N	\N	\N	1	1	\N	2018-08-02 00:00:00	1167	\N	\N	MEMBRE	NON	\N	\N
COMFINC	ACTIF	322	\N	\N	\N	\N	1	0	\N	\N	1168	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	324	\N	\N	\N	\N	1	0	\N	\N	1201	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	325	\N	\N	\N	\N	1	1	\N	\N	1221	2014-10-13 16:10:04	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	326	\N	\N	\N	\N	1	\N	\N	\N	1241	2014-10-17 08:45:10	\N	MEMBRE	NON	\N	\N
COMETRD	ANCIEN	328	\N	\N	\N	\N	1	1	\N	2018-08-03 00:00:00	1261	\N	\N	MEMBRE	NON	\N	\N
COMLOIS	ANCIEN	328	\N	\N	\N	\N	1	1	\N	2018-08-03 00:00:00	1262	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	327	\N	\N	\N	\N	2	2	\N	\N	1281	2015-01-21 14:20:16	2017-04-04 16:39:21	MEMBRE	NON	\N	\N
SENCOMCAE	ANCIEN	329	\N	\N	\N	\N	1	0	\N	2020-02-01 00:00:00	1301	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	332	\N	\N	\N	\N	1	\N	\N	\N	1341	2015-03-16 17:11:01	2017-10-02 17:46:10	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	335	\N	\N	\N	\N	1	\N	\N	\N	1401	2015-04-17 10:58:01	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	336	\N	\N	\N	\N	2	\N	\N	\N	1421	2015-05-06 19:05:43	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	337	\N	\N	\N	\N	1	\N	\N	\N	1441	2015-05-27 10:27:43	\N	MEMBRE	NON	\N	\N
SENCOMSOCI	ACTIF	338	\N	\N	\N	\N	1	1	\N	\N	1442	2015-05-27 10:37:19	2015-05-28 14:56:43	MEMBRE	NON	\N	\N
SENCOMCAE	ACTIF	338	\N	\N	\N	\N	1	1	\N	\N	1443	2015-05-27 10:37:26	2015-05-28 14:56:35	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	339	\N	\N	\N	\N	2	\N	\N	\N	1461	2015-06-12 10:49:38	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	340	\N	\N	\N	\N	1	\N	\N	\N	1521	2015-09-29 17:26:38	2019-02-26 11:40:50	MEMBRE	NON	\N	\N
SENCOMCAE	ANCIEN	344	\N	\N	\N	\N	1	0	\N	2018-08-02 00:00:00	1541	\N	\N	MEMBRE	NON	\N	\N
SENCOMCDD	ANCIEN	344	\N	\N	\N	\N	0	1	\N	2018-08-02 00:00:00	1542	\N	\N	MEMBRE	NON	\N	\N
SENCOMCAE	ANCIEN	346	\N	\N	\N	\N	1	0	\N	2018-08-02 00:00:00	1561	\N	\N	MEMBRE	NON	\N	\N
SENCOMCDD	ACTIF	355	\N	\N	\N	\N	2	\N	\N	\N	1601	2016-11-04 19:09:56	\N	MEMBRE	NON	\N	\N
PDTSEN	ANCIEN	12	\N	\N	\N	\N	1	1	2013-06-05 00:00:00	2015-01-01 00:00:00	1621	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ANCIEN	127	\N	\N	\N	\N	1	1	2013-12-17 00:00:00	2018-08-02 00:00:00	1641	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	343	\N	\N	\N	\N	1	\N	\N	\N	1642	2017-04-04 16:41:59	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	345	\N	\N	\N	\N	1	\N	\N	\N	1643	2017-04-04 16:43:42	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	347	\N	\N	\N	\N	1	\N	\N	\N	1644	2017-04-04 16:45:05	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	348	\N	\N	\N	\N	1	\N	\N	\N	1645	2017-04-04 16:45:34	\N	MEMBRE	NON	\N	\N
SENCOMCAE	ANCIEN	349	\N	\N	\N	\N	1	0	\N	2019-11-01 00:00:00	1646	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	350	\N	\N	\N	\N	1	\N	\N	\N	1647	2017-04-04 16:46:17	\N	MEMBRE	NON	\N	\N
SENCOMLOIS	ACTIF	351	\N	\N	\N	\N	1	1	\N	\N	1648	2017-04-04 16:46:35	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	353	\N	\N	\N	\N	1	1	\N	\N	1649	2017-04-04 16:47:50	2017-04-04 16:48:04	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	354	\N	\N	\N	\N	2	0	\N	\N	1650	2017-04-04 16:49:51	2017-04-04 16:50:29	MEMBRE	NON	\N	\N
SENCOMCDD	ANCIEN	358	\N	\N	\N	\N	1	0	\N	2020-02-21 00:00:00	1651	\N	\N	MEMBRE	NON	\N	\N
SENCOMCDD	ANCIEN	359	\N	\N	\N	\N	2	0	\N	2020-02-21 00:00:00	1652	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	357	\N	\N	\N	\N	158	0	\N	\N	1653	\N	\N	MEMBRE	NON	\N	\N
COMAFCL	ACTIF	331	\N	\N	\N	\N	1	\N	\N	\N	1661	2017-04-10 11:16:42	2017-06-07 17:13:50	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	375	\N	\N	\N	\N	1	\N	\N	\N	1681	2017-06-13 11:46:53	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	376	\N	\N	\N	\N	1	\N	\N	\N	1682	2017-06-13 11:48:19	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	377	\N	\N	\N	\N	1	\N	\N	\N	1683	2017-06-13 11:51:19	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	380	\N	\N	\N	\N	2	\N	\N	\N	1761	2017-09-12 11:04:29	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	361	\N	\N	\N	\N	2	\N	\N	\N	1781	2017-09-19 10:53:43	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	383	\N	\N	\N	\N	94	\N	\N	\N	1841	2018-03-26 10:12:49	\N	MEMBRE	NON	\N	\N
OPECST	ACTIF	2000	\N	\N	\N	\N	1	\N	\N	\N	1861	2018-11-29 10:39:01	\N	MEMBRE	NON	\N	\N
AUDITSOCI	ACTIF	299	\N	\N	\N	\N	1	0	\N	\N	1981	\N	\N	PDT	NON	\N	\N
PDTSEN	ACTIF	349	\N	\N	\N	\N	1	0	2019-11-02 00:00:00	\N	2181	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	389	\N	\N	\N	\N	1	1	2019-05-15 00:00:00	\N	2182	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	392	\N	\N	\N	\N	2	0	2019-09-16 00:00:00	\N	2183	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	393	\N	\N	\N	\N	2	2	2019-10-17 00:00:00	\N	2184	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	394	\N	\N	\N	\N	2	0	2019-10-21 00:00:00	\N	2187	\N	\N	MEMBRE	NON	\N	\N
COMAFCL	ACTIF	274	\N	\N	\N	\N	1	0	2019-11-27 00:00:00	\N	2221	\N	\N	MEMBRE	NON	\N	\N
NOMART13CDD	ACTIF	394	\N	\N	\N	\N	1	0	2019-10-10 00:00:00	\N	2241	\N	\N	DG	NON	\N	\N
NOMART13CAE	ACTIF	10008	\N	\N	\N	\N	1	0	2019-12-01 00:00:00	\N	2261	\N	\N	DG	NON	\N	\N
PDTSEN	ACTIF	37	\N	\N	\N	\N	2	0	2020-01-01 00:00:00	\N	2281	\N	\N	MEMBRE	NON	\N	\N
NOMART13LOIS	ACTIF	10010	\N	\N	\N	\N	1	0	2020-01-15 00:00:00	\N	2361	\N	\N	PDT	NON	\N	\N
NOMART13AFCL	ACTIF	10011	\N	\N	\N	\N	1	0	2019-01-01 00:00:00	\N	2401	\N	\N	PDT	NON	\N	\N
NOMART13AFCL	ACTIF	10012	\N	\N	\N	\N	1	0	2018-11-01 00:00:00	\N	2421	\N	\N	PDT	NON	\N	\N
NOMART13LOIS	ACTIF	10014	\N	\N	\N	\N	1	0	2018-12-01 00:00:00	\N	2481	\N	\N	MEMBRE	NON	\N	\N
PQPDTSENLOIS	ACTIF	10014	\N	\N	\N	\N	1	0	2018-12-01 00:00:00	\N	2482	\N	\N	MEMBRE	NON	\N	\N
AUDITSOCI	ACTIF	199	\N	\N	\N	\N	1	0	2019-09-01 00:00:00	\N	2521	\N	\N	DG	NON	\N	\N
AUDITSOCI	ACTIF	10016	\N	\N	\N	\N	1	0	2019-01-01 00:00:00	\N	2561	\N	\N	DG	NON	\N	\N
NOMART13CDD	ACTIF	10022	\N	\N	\N	\N	1	0	2018-03-01 00:00:00	\N	2681	\N	\N	PDT	NON	\N	\N
PQPDTSENLOIS	ACTIF	10010	\N	\N	\N	\N	1	0	\N	\N	2741	\N	\N	MEMBRE	OUI	Voir l'arrêté du 27 février 2020 	N¿ayant pas exercé depuis au moins 3 ans de fonctions de membre du gouvernement, de mandat parlementaire ou de fonctions énumérées au I de l¿article 11 (parlementaire européen, président de conseil régional, général, maire d¿une commune de plus de 20 000 h, conseiller régional, départemental, adjoint au maire d¿une commune de plus de 100 000 h, VP d¿un EPCI de plus de 100 000 h, lorsque ces personnes sont titulaires d¿une délégation de signature, de membres de cabinets ministériels, de collaborateurs du Président de la République ou des Présidents de l¿AN ou du Sénat, membres d¿une AAI ou toute autre personne exerçant une fonction à la décision du gouvernement nommée en conseil des ministres.
PQPDTSEN	ACTIF	13	\N	\N	\N	\N	1	0	\N	\N	2742	\N	\N	MEMBRE	OUI	Règlement intérieur (article 60) 	\N
PDTSEN	ACTIF	164	\N	\N	\N	\N	4	0	2018-08-05 00:00:00	\N	2781	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	72	\N	\N	\N	\N	2	0	2018-08-05 00:00:00	\N	2782	\N	\N	MEMBRE	NON	\N	\N
COMETRD	ANCIEN	328	\N	\N	\N	\N	2	0	2018-08-04 00:00:00	2022-01-11 00:00:00	3001	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	120	\N	\N	\N	\N	1	0	2018-08-04 00:00:00	\N	3022	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	115	\N	\N	\N	\N	2	0	2018-08-04 00:00:00	\N	3041	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	285	\N	\N	\N	\N	1	0	2018-08-04 00:00:00	\N	3042	\N	\N	MEMBRE	NON	\N	\N
PQPDTSEN	ACTIF	DSPB-007	\N	\N	\N	\N	1	0	2020-11-20 00:00:00	2026-07-21 00:00:00	3061	\N	\N	MEMBRE	OUI	350 euros par séance	déclaration d¿intérêts et obligation de « déport » subséquente.
NOMART13FINC	ACTIF	DSPB-005	\N	\N	\N	\N	1	0	2020-04-01 00:00:00	\N	3121	\N	\N	PDTCOL	NON	\N	\N
NOMART13CDD	ACTIF	332	\N	\N	\N	\N	1	0	2020-11-01 00:00:00	\N	3122	\N	\N	PDG	NON	\N	\N
NOMART13LOIS	ACTIF	22	\N	\N	\N	\N	1	0	2020-07-01 00:00:00	\N	3141	\N	\N	PDT	NON	\N	\N
NOMART13AFCL	ACTIF	331	\N	\N	\N	\N	1	0	2020-11-01 00:00:00	\N	3142	\N	\N	PDT	NON	\N	\N
NOMART13SOCI	ACTIF	299	\N	\N	\N	\N	1	0	2020-11-01 00:00:00	\N	3143	\N	\N	DG	NON	\N	\N
NOMART13LOIS	ACTIF	DSPB-007	\N	\N	\N	\N	1	0	2020-07-01 00:00:00	\N	3144	\N	\N	MEMBRE	NON	\N	\N
NOMART13LOIS	ACTIF	10024	\N	\N	\N	\N	1	0	2020-06-01 00:00:00	\N	3145	\N	\N	PDT	NON	\N	\N
NOMART13SOCI	ACTIF	10025	\N	\N	\N	\N	1	0	2020-12-01 00:00:00	\N	3146	\N	\N	DG	NON	\N	\N
NOMART13CAE	ACTIF	10026	\N	\N	\N	\N	1	0	2020-07-01 00:00:00	\N	3147	\N	\N	PDT	NON	\N	\N
NOMART13LOIS	ACTIF	10027	\N	\N	\N	\N	1	0	2020-10-01 00:00:00	\N	3148	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	109	\N	\N	\N	\N	1	0	2018-08-03 00:00:00	\N	3161	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	127	\N	\N	\N	\N	1	0	2018-08-03 00:00:00	\N	3181	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	397	\N	\N	\N	\N	4	0	2020-12-14 00:00:00	\N	3221	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	398	\N	\N	\N	\N	3	0	2021-01-18 00:00:00	\N	3241	\N	\N	MEMBRE	NON	\N	\N
COMAFCL	ACTIF	316	\N	\N	\N	\N	2	\N	\N	\N	1061	2013-11-13 10:59:25	2014-08-01 11:28:03	MEMBRE	NON	\N	\N
COMAFCL	ACTIF	317	\N	\N	\N	\N	2	0	\N	\N	1101	\N	\N	MEMBRE	NON	\N	\N
COMCAE	ACTIF	317	\N	\N	\N	\N	2	\N	\N	\N	1102	2013-12-30 09:13:01	2014-11-13 17:16:35	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	323	\N	\N	\N	\N	1	\N	\N	\N	1181	2014-07-21 18:29:02	2014-08-01 11:12:44	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	330	\N	\N	\N	\N	1	\N	\N	\N	1321	2015-03-13 16:08:57	2019-02-25 17:52:45	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	333	\N	\N	\N	\N	2	\N	\N	\N	1361	2015-03-17 16:39:12	2019-02-26 10:11:37	MEMBRE	NON	\N	\N
SENCOMCAE	ANCIEN	334	\N	\N	\N	\N	1	0	\N	2018-08-02 00:00:00	1381	\N	\N	MEMBRE	NON	\N	\N
COMAFCL	ACTIF	341	\N	\N	\N	\N	1	\N	\N	\N	1481	2015-07-06 15:28:28	2015-07-06 17:54:38	MEMBRE	NON	\N	\N
SENCOMLOIS	ANCIEN	342	\N	\N	\N	\N	1	0	\N	2018-08-02 00:00:00	1501	\N	\N	MEMBRE	NON	\N	\N
SENCOMETRD	ANCIEN	342	\N	\N	\N	\N	1	0	\N	2018-08-02 00:00:00	1502	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	352	\N	\N	\N	\N	2	\N	\N	\N	1581	2016-10-27 11:14:22	\N	MEMBRE	NON	\N	\N
SENCOMAFCL	ANCIEN	362	\N	\N	\N	\N	1	1	\N	2018-08-02 00:00:00	1721	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	356	\N	\N	\N	\N	1	\N	\N	\N	1801	2017-10-09 11:02:37	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	382	\N	\N	\N	\N	3	\N	\N	\N	1821	2017-11-30 15:12:45	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	12	\N	\N	\N	\N	1	\N	2019-02-12 00:00:00	\N	1883	2019-02-26 10:18:00	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	318	\N	\N	\N	\N	2	\N	2019-02-13 00:00:00	\N	1884	2019-02-26 10:31:02	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	304	\N	\N	\N	\N	2	\N	2019-02-13 00:00:00	\N	1885	2019-02-26 10:42:12	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	360	\N	\N	\N	\N	1	\N	\N	\N	1886	2019-02-26 11:05:52	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	261	\N	\N	\N	\N	1	\N	2019-02-13 00:00:00	\N	1887	2019-02-26 11:10:02	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	24	\N	\N	\N	\N	3	\N	2019-02-13 00:00:00	\N	1888	2019-02-26 11:43:25	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	46	\N	\N	\N	\N	1	\N	2019-02-13 00:00:00	\N	1889	2019-02-26 11:51:48	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	50	\N	\N	\N	\N	2	\N	2019-02-13 00:00:00	\N	1890	2019-02-26 12:25:38	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	295	\N	\N	\N	\N	2	\N	2019-02-13 00:00:00	\N	1891	2019-02-26 14:53:03	2019-02-26 14:53:31	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	296	\N	\N	\N	\N	2	\N	2019-02-13 00:00:00	\N	1892	2019-02-26 15:14:48	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	194	\N	\N	\N	\N	3	\N	2019-02-13 00:00:00	\N	1893	2019-02-26 15:28:56	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	138	\N	\N	\N	\N	1	1	2019-02-13 00:00:00	\N	1894	2019-02-26 15:41:44	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	386	\N	\N	\N	\N	1	\N	\N	\N	1895	2019-02-26 15:55:05	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	381	\N	\N	\N	\N	1	\N	\N	\N	1896	2019-02-26 16:02:32	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	387	\N	\N	\N	\N	1	\N	\N	\N	1897	2019-02-26 16:13:56	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	384	\N	\N	\N	\N	1	\N	\N	\N	1898	2019-02-26 16:18:36	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	385	\N	\N	\N	\N	1	\N	\N	\N	1899	2019-02-26 16:20:42	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	204	\N	\N	\N	\N	1	\N	2019-08-04 00:00:00	\N	1901	2019-03-15 17:27:05	\N	MEMBRE	NON	\N	\N
NOMART13LOIS	ACTIF	196	\N	\N	\N	\N	1	0	\N	\N	1941	\N	\N	DG	NON	\N	\N
NOMART13CDD	ACTIF	10002	\N	\N	\N	\N	1	0	2019-06-25 00:00:00	\N	2041	\N	\N	PDG	NON	\N	\N
NOMART13ETRD	ACTIF	126	\N	\N	\N	\N	1	0	2019-05-01 00:00:00	\N	2121	\N	\N	DG	NON	\N	\N
COMAFCL	ACTIF	391	\N	\N	\N	\N	2	0	2019-09-06 00:00:00	\N	2161	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	42	\N	\N	\N	\N	2	0	2020-01-01 00:00:00	\N	2301	\N	\N	MEMBRE	NON	\N	\N
NOMART13CDD	ACTIF	393	\N	\N	\N	\N	1	0	2019-12-01 00:00:00	\N	2321	\N	\N	DG	NON	\N	\N
PQPDTSEN	ACTIF	DSBP-0001	\N	\N	\N	\N	1	0	2019-12-04 00:00:00	2025-12-03 00:00:00	2322	\N	\N	MEMBRE	NON	\N	\N
PQPDTSEN	ACTIF	DSBP-0001	\N	\N	\N	\N	1	0	2019-12-04 00:00:00	2025-12-03 00:00:00	2323	\N	\N	MEMBRE	NON	\N	\N
PQPDTSEN	ACTIF	DSPB-002	\N	\N	\N	\N	1	0	\N	\N	2324	\N	\N	MEMBRE	NON	\N	elle ne peut être  membre du Conseil d'État, magistrat des tribunaux administratifs et des cours administratives d'appel, ou exercer un mandat parlementaire
PQPDTSENLOIS	ACTIF	10013	\N	\N	\N	\N	1	0	2019-01-23 00:00:00	\N	2461	\N	\N	MEMBRE	NON	\N	\N
PQPDTSEN	ACTIF	DSPB-003	\N	\N	\N	\N	1	0	\N	\N	2326	\N	\N	MEMBRE	OUI	une rémunération forfaitaire fixée à 850 euros	Incompatibilité avec le statut de salarié ou la détention d'un mandat dans une personne soumise au contrôle de l'Autorité (article L. 612-10)
AUDITSOCI	ACTIF	10015	\N	\N	\N	\N	1	0	2018-10-01 00:00:00	\N	2541	\N	\N	PDTCA	NON	\N	\N
AUDITCDD	ACTIF	379	\N	\N	\N	\N	1	0	2018-10-01 00:00:00	\N	2542	\N	\N	PDTCA	NON	\N	\N
NOMART13CAE	ACTIF	10018	\N	\N	\N	\N	1	0	2018-09-01 00:00:00	\N	2601	\N	\N	PDT	NON	\N	\N
NOMART13LOIS	ACTIF	10019	\N	\N	\N	\N	1	0	2018-07-01 00:00:00	\N	2621	\N	\N	MEDIA	NON	\N	\N
PQPDTSEN	ACTIF	DSPB-004	\N	\N	\N	\N	1	0	\N	\N	2743	\N	\N	MEMBRE	OUI	arrêté du 13 avril 2017 (article 1er)	\N
PQPDTSEN	ACTIF	DSPB-005	\N	\N	\N	\N	1	0	\N	\N	2744	\N	\N	MEMBRE	OUI	Arrêté du 27 février 2020 (article 4)	Le mandat de membre de l'Autorité nationale des jeux est incompatible avec toute autre fonction exercée dans le cadre d'une activité économique ou financière en relation avec le secteur des jeux d'argent et de hasard.
AUDITSOCI	ACTIF	10023	\N	\N	\N	\N	1	0	2020-07-01 00:00:00	\N	2801	\N	\N	PDTCA	NON	\N	\N
PDTSEN	ACTIF	374	\N	\N	\N	\N	1	1	\N	\N	2821	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	161	\N	\N	\N	\N	2	0	2020-08-03 00:00:00	\N	2881	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	212	\N	\N	\N	\N	1	0	2018-08-03 00:00:00	\N	2921	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	214	\N	\N	\N	\N	1	1	2018-08-03 00:00:00	\N	2922	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	222	\N	\N	\N	\N	1	0	2018-08-03 00:00:00	\N	2923	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	233	\N	\N	\N	\N	2	0	2018-08-03 00:00:00	\N	2924	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	243	\N	\N	\N	\N	2	0	2018-08-03 00:00:00	\N	2925	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	246	\N	\N	\N	\N	1	0	2018-08-03 00:00:00	\N	2926	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	251	\N	\N	\N	\N	1	0	2018-08-03 00:00:00	\N	2927	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	258	\N	\N	\N	\N	1	0	2018-08-03 00:00:00	\N	2928	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	270	\N	\N	\N	\N	10	10	2018-08-03 00:00:00	\N	2929	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	272	\N	\N	\N	\N	2	0	2018-08-03 00:00:00	\N	2930	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	276	\N	\N	\N	\N	1	0	2018-08-03 00:00:00	\N	2931	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	282	\N	\N	\N	\N	2	0	2018-08-03 00:00:00	\N	2932	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	283	\N	\N	\N	\N	1	0	2018-08-03 00:00:00	\N	2933	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	287	\N	\N	\N	\N	1	0	2018-08-03 00:00:00	\N	2934	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	290	\N	\N	\N	\N	1	0	2018-08-03 00:00:00	\N	2935	\N	\N	MEMBRE	NON	\N	\N
PQPDTSEN	ACTIF	DSPB-006	\N	\N	\N	\N	1	0	\N	\N	2941	\N	\N	MEMBRE	OUI	Indemnité de 98,67 ¿ bruts par séance pour les simples membres du Comité (135,29 ¿ pour les Présidents de section), à raison en moyenne d¿une séance par mois. Le nombre maximum de séances pouvant donner lieu à rémunération est fixé à 70 par an.	\N
PQPDTSENAFCL	ACTIF	391	\N	\N	\N	\N	1	0	\N	\N	2942	\N	\N	MEMBRE	OUI	Indemnité de 150 ¿ par séance pour les membres du Conseil. Le nombre maximum de séances pouvant donner lieu à rémunération est fixé à 50 par an.	\N
PDTSEN	ACTIF	310	\N	\N	\N	\N	1	1	\N	\N	2943	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	610	\N	\N	\N	\N	1	0	2018-08-03 00:00:00	\N	2981	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	373	\N	\N	\N	\N	1	1	2016-12-01 00:00:00	\N	2982	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	372	\N	\N	\N	\N	1	1	2016-12-01 00:00:00	\N	2983	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	371	\N	\N	\N	\N	1	1	2016-12-01 00:00:00	\N	2984	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	370	\N	\N	\N	\N	1	1	2016-12-01 00:00:00	\N	2985	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	369	\N	\N	\N	\N	1	1	2016-12-01 00:00:00	\N	2986	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	368	\N	\N	\N	\N	2	0	2016-12-28 00:00:00	\N	2987	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	367	\N	\N	\N	\N	2	0	2016-12-28 00:00:00	\N	2988	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	366	\N	\N	\N	\N	2	0	2016-12-28 00:00:00	\N	2989	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	365	\N	\N	\N	\N	2	0	2016-12-28 00:00:00	\N	2990	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	364	\N	\N	\N	\N	2	0	2016-12-28 00:00:00	\N	2991	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	363	\N	\N	\N	\N	2	0	2018-10-30 00:00:00	\N	2992	\N	\N	MEMBRE	NON	\N	\N
COMLOIS	ACTIF	95	\N	\N	\N	\N	1	0	2018-08-03 00:00:00	\N	3081	\N	\N	MEMBRE	NON	\N	\N
COMAFCL	ACTIF	167	\N	\N	\N	\N	1	0	2018-08-03 00:00:00	\N	3082	\N	\N	MEMBRE	NON	\N	\N
COMCDD	ACTIF	95	\N	\N	\N	\N	2	0	2018-08-03 00:00:00	\N	3101	\N	\N	MEMBRE	NON	\N	\N
COMCAE	ACTIF	95	\N	\N	\N	\N	2	0	2018-08-03 00:00:00	\N	3102	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	186	\N	\N	\N	\N	1	0	2018-08-04 00:00:00	\N	3201	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	187	\N	\N	\N	\N	1	0	2018-08-04 00:00:00	\N	3202	\N	\N	MEMBRE	NON	\N	\N
PQPDTSENAFCL	ACTIF	10011	\N	\N	\N	\N	1	0	\N	\N	3261	\N	\N	MEMBRE	OUI	Arrêté du 27 février 2020 (annexe) : Le montant annuel de l¿indemnité de fonction allouée aux membres du Conseil supérieur de l¿audiovisuel, est fixé à 60 000 euros. 	\N
PDTSEN	ACTIF	396	\N	\N	\N	\N	2	0	2021-01-01 00:00:00	\N	3361	\N	\N	MEMBRE	NON	\N	\N
NOMART13CDD	ACTIF	323	\N	\N	\N	\N	1	0	2021-05-01 00:00:00	\N	3401	\N	\N	PDTCA	NON	\N	\N
AUDITSOCI	ACTIF	361	\N	\N	\N	\N	1	0	\N	\N	3463	\N	\N	DG	NON	\N	\N
PDTSEN	ACTIF	201	\N	\N	\N	\N	1	0	2021-10-01 00:00:00	\N	3502	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	406	\N	\N	\N	\N	1	0	2022-03-22 00:00:00	\N	3661	\N	\N	MEMBRE	NON	\N	\N
NOMART13FINC	ACTIF	13	\N	\N	\N	\N	1	0	2017-11-16 00:00:00	\N	3683	\N	\N	DG	NON	\N	\N
NOMART13FINC	ACTIF	306	\N	\N	\N	\N	1	0	2018-01-20 00:00:00	\N	3684	\N	\N	DG	NON	\N	\N
NOMART13SOCI	ACTIF	10017	\N	\N	\N	\N	1	0	2022-09-01 00:00:00	\N	3761	\N	\N	DG	NON	\N	\N
NOMART13LOIS	ACTIF	10013	\N	\N	\N	\N	1	0	2017-01-01 00:00:00	\N	3841	\N	\N	PDT	NON	\N	\N
PDTSEN	ACTIF	411	\N	\N	\N	\N	2	0	2023-11-29 00:00:00	\N	3921	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	399	\N	\N	\N	\N	3	0	2021-02-01 00:00:00	\N	3341	\N	\N	MEMBRE	NON	\N	\N
PQPDTSEN	ACTIF	236	\N	\N	\N	\N	1	0	\N	\N	3701	\N	\N	MEMBRE	NON	\N	\N
COMAFCL	ACTIF	99	\N	\N	\N	\N	1	0	2023-01-01 00:00:00	\N	3861	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	410	\N	\N	\N	\N	1	0	2023-05-01 00:00:00	\N	3881	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	409	\N	\N	\N	\N	3	0	2022-09-01 00:00:00	\N	3882	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	400	\N	\N	\N	\N	1	1	2021-09-23 00:00:00	\N	3501	\N	\N	MEMBRE	NON	\N	\N
NOMART13LOIS	ACTIF	342	\N	\N	\N	\N	1	0	2021-09-01 00:00:00	\N	3561	\N	\N	PDT	NON	\N	\N
PDTSEN	ACTIF	403	\N	\N	\N	\N	1	0	2021-12-13 00:00:00	\N	3623	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	404	\N	\N	\N	\N	2	0	2022-01-06 00:00:00	\N	3624	\N	\N	MEMBRE	NON	\N	\N
NOMART13FINC	ACTIF	10035	\N	\N	\N	\N	1	0	2022-10-01 00:00:00	\N	3802	\N	\N	PDT	NON	\N	\N
NOMART13FINC	ACTIF	10029	\N	\N	\N	\N	1	0	2009-01-22 00:00:00	\N	3441	\N	\N	PDT	NON	\N	\N
NOMART13CAE	ACTIF	10031	\N	\N	\N	\N	1	0	2021-01-01 00:00:00	\N	3444	\N	\N	PDTCA	NON	\N	\N
AUDITCDD	ACTIF	288	\N	\N	\N	\N	1	0	2021-01-01 00:00:00	\N	3461	\N	\N	PDTDIR	NON	\N	 
AUDITFINC	ACTIF	DSPB-003	\N	\N	\N	\N	1	0	2020-01-01 00:00:00	\N	3462	\N	\N	VICEPRESIDENT	NON	\N	\N
NOMART13CAE	ACTIF	387	\N	\N	\N	\N	1	0	2021-10-28 00:00:00	\N	3601	\N	\N	DG	NON	\N	\N
NOMART13LOIS	ACTIF	343	\N	\N	\N	\N	1	0	2021-12-17 00:00:00	\N	3625	\N	\N	DG	NON	\N	\N
NOMART13AFCL	ACTIF	10033	\N	\N	\N	\N	1	0	2022-01-01 00:00:00	\N	3641	\N	\N	PDT	NON	\N	\N
PDTSEN	ACTIF	328	\N	\N	\N	\N	2	0	2022-01-12 00:00:00	\N	3662	\N	\N	MEMBRE	NON	\N	\N
NOMART13CAE	ACTIF	DSPB-014	\N	\N	\N	\N	1	0	2022-07-01 00:00:00	\N	3741	\N	\N	PDTCOL	NON	\N	\N
NOMART13CDD	ACTIF	10036	\N	\N	\N	\N	1	0	2016-01-01 00:00:00	\N	3821	\N	\N	PDT	NON	\N	\N
PDTSEN	ACTIF	334	\N	\N	\N	\N	1	0	2018-08-03 00:00:00	\N	3301	\N	\N	MEMBRE	NON	\N	\N
PDTSEN	ACTIF	22	\N	\N	\N	\N	1	1	2021-10-04 00:00:00	\N	3541	\N	\N	MEMBRE	NON	\N	\N
NOMART13FINC	ACTIF	DSPB-008	\N	\N	\N	\N	1	0	2021-10-21 00:00:00	\N	3562	\N	\N	GOUV	NON	\N	\N
AUDITSOCI	ACTIF	199	\N	\N	\N	\N	1	0	2021-07-01 00:00:00	\N	3581	\N	\N	PDTCA	NON	\N	\N
NOMART13ETRD	ACTIF	158	\N	\N	\N	\N	1	0	2017-01-01 00:00:00	\N	3822	\N	\N	PDT	NON	\N	\N
PQPDTSEN	ACTIF	DSPB-008	\N	\N	\N	\N	1	0	2021-02-05 00:00:00	\N	3281	\N	\N	MEMBRE	OUI	Indemnité par réunion fixée par le conseil général dans la limite du cinquième de la moyenne de la rémunération mensuelle la plus haute attachée au grade de conseiller d¿État.	\N
PQPDTSEN	ACTIF	DSPB-010	\N	\N	\N	\N	1	0	2021-02-23 00:00:00	\N	3321	\N	\N	MEMBRE	OUI	Arrete du 16 novembre 2005 (article 2) Le montant unitaire de la vacation est fixe a 350 euros 	La qualite de membre de la commission consultative aeroportuaire est incompatible avec l'exercice de toute activite professionnelle ou privee donnant a son titulaire un interet direct ou indirect vis-a-vis d'exploitants d'aerodromes ou de transporteurs aeriens
PQPDTSEN	ACTIF	10018	\N	\N	\N	\N	1	0	\N	\N	3381	\N	\N	MEMBRE	OUI	arrêté du 27 février 2020 (annexe)	Article L. 592-3 Incompatibilité avec toute activité professionnelle, mandat électif ou tout autre emploi public.
PQPDTSEN	ACTIF	DSPB-013	\N	\N	\N	\N	1	0	\N	\N	3503	\N	\N	MEMBRE	OUI	135 euros / séance + éventuellement remboursement des frais de déplacement 	personnalité désignée en dehors des membres du Sénat
NOMART13CDD	ACTIF	120	\N	\N	\N	\N	1	0	2018-02-23 00:00:00	\N	3681	\N	\N	PDTCA	NON	\N	\N
PQPDTSEN	ACTIF	DSPB-014	\N	\N	\N	\N	1	0	2021-11-02 00:00:00	2027-11-01 00:00:00	3505	\N	\N	MEMBRE	OUI	Pour la participation effective à une séance du comité ou de la commission : 250 euros.	Incompatibilités : avec tout mandat électif communal, départemental, régional ou européen et avec la détention, directe ou indirecte, d'intérêts dans une entreprise du secteur de l'énergie + incompatibilités applicables aux membres des AAI 
PDTSEN	ACTIF	22	\N	\N	\N	\N	1	1	2021-10-04 00:00:00	2026-06-01 00:00:00	3521	\N	\N	MEMBRE	NON	\N	Incompatibilités applicables aux membres des AAI 
NOMART13CDD	ACTIF	152	\N	\N	\N	\N	1	0	2018-02-23 00:00:00	\N	3682	\N	\N	PDT	NON	\N	\N
PQPDTSEN	ACTIF	DSPB-015	\N	\N	\N	\N	1	0	2022-04-30 00:00:00	2026-04-30 00:00:00	3702	\N	\N	MEMBRE	NON	\N	\N
NOMART13CDD	ACTIF	2000	\N	\N	\N	\N	1	0	2014-01-01 00:00:00	\N	3823	\N	\N	DG	NON	\N	\N
PDTSEN	ACTIF	412	\N	\N	\N	\N	2	0	2024-02-15 00:00:00	\N	3901	\N	\N	MEMBRE	NON	\N	\N
PQPDTSEN	ACTIF	DSPB-009	\N	\N	\N	\N	1	0	\N	\N	3282	\N	\N	MEMBRE	NON	\N	n'exerce pas de mandat électif
PQPDTSEN	ACTIF	DSPB-011	\N	\N	\N	\N	1	0	\N	\N	3342	\N	\N	MEMBRE	OUI	La commission se réunit en moyenne tous les quinze jours, à raison de deux séances par jour. Montant de la vacation : - autres personnes ou fonctionnaires retraités : 160 euros par demi-journée.	Incompatibilité avec « toute fonction exercée dans le cadre d¿une activité économique ou financière en relation avec le secteur du commerce » (art. L. 751-7)
PQPDTSEN	ACTIF	DSPB-012	\N	\N	\N	\N	1	0	\N	\N	3484	\N	\N	MEMBRE	NON	\N	\N
NOMART13CAE	ACTIF	10028	\N	\N	\N	\N	1	0	2021-01-01 00:00:00	\N	3421	\N	\N	PDT	NON	\N	\N
PDTSEN	ACTIF	408	\N	\N	\N	\N	18	0	2022-06-10 00:00:00	\N	3721	\N	\N	MEMBRE	NON	\N	\N
NOMART13FINC	ACTIF	10030	\N	\N	\N	\N	1	0	2003-08-01 00:00:00	\N	3442	\N	\N	PDT	NON	\N	\N
NOMART13CDD	ACTIF	379	\N	\N	\N	\N	1	0	2021-03-01 00:00:00	\N	3443	\N	\N	DG	NON	\N	\N
PDTSEN	ACTIF	401	\N	\N	\N	\N	162	82	2021-10-01 00:00:00	\N	3621	\N	\N	MEMBRE	NON	\N	\N
NOMART13CAE	ACTIF	10032	\N	\N	\N	\N	1	0	2022-01-13 00:00:00	2027-01-13 00:00:00	3622	\N	\N	PDT	NON	\N	\N
NOMART13SOCI	ACTIF	10034	\N	\N	\N	\N	1	0	2017-10-13 00:00:00	\N	3685	\N	\N	PDT	NON	\N	\N
OPECST	ACTIF	2006	\N	\N	\N	\N	1	0	2022-10-01 00:00:00	\N	3781	\N	\N	MEMBRE	NON	\N	\N
\.


--
-- Data for Name: designorg; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY designorg (designcod, temvalcod, evelic, evelib, evelil, eveobs, designnumtri, designlib, designlic, designlil, designlibfem, designlicfem, designlilfem, syscredat, sysmajdat) FROM stdin;
MEMBRE	ACTIF	Membres	Membres	Membres	\N	1	Membre	Membre	Membre	Membre	Membre	Membre	\N	\N
TITULAIRE	ACTIF	Membres titulaires	Membres titulaires	Membres titulaires	\N	2	Membre titulaire	Membre titulaire	Membre titulaire	Membre titulaire	Membre titulaire	Membre titulaire	\N	\N
SUPPLEANT	ACTIF	Membres suppléants	Membres suppléants	Membres suppléants	\N	3	Membre suppléant	Membre suppléant	Membre suppléant	Membre suppléante	Membre suppléante	Membre suppléante	\N	\N
MEMBREDRT	ACTIF	Membres de droit	Membres de droit	Membres de droit	\N	4	Membre de droit	Membre de droit	Membre de droit	Membre de droit	Membre de droit	Membre de droit	\N	\N
MEMBREDRTCOM	ACTIF	Membres de droit, commissions	Membres de droit, représentants des commissions permanentes	Membres de droit, représentants des commissions permanentes	\N	5	Membre de droit, représentant des commissions permanentes	Membre de droit, commissions	Membres de droit, représentant des commissions permanentes	Membre de droit, représentante des commissions permanentes	Membre de droit, commissions	Membre de droit, représentante des commissions permanentes	\N	\N
MEMBREGRPPOL	ACTIF	Membres désignés par les groupes	Membres désignés par les groupes	Membres désignés par les groupes	\N	6	Membre désigné par les groupes	Membre désigné par les groupes	Membre désigné par les groupes	Membre désignée par les groupes	Membre désignée par les groupes	Membre désignée par les groupes	\N	\N
\.


--
-- Data for Name: dpt; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY dpt (dptnum, dptcod, dptlib, dptnbrsen, dptmodscrsen, dptser, regcod, dptnumtri, dptlic, dptart, dptlibtri, temvalcod, evelic, evelib, evelil, dptser2004, dptcmt, dptdatdeb, dptdatfin, dpturlcmp, syscredat, sysmajdat) FROM stdin;
580	58	Nièvre	2	SM	B	24	580	Nièvre	de la 	Nièvre	ACTIF	Nièvre	Nièvre	Nièvre	1	\N	1959-04-28 00:00:00	\N	http://www.cg58.fr/	\N	\N
660	66	Pyrénées-Orientales	2	SM	B	29	660	Pyrénées-Orientales	des 	Pyrénées Orientales	ACTIF	Pyrénées-Oriental.	Pyrénées-Orientales	Pyrénées-Orientales	1	\N	1959-04-28 00:00:00	\N	http://www.cg66.fr/	\N	\N
770	77	Seine-et-Marne	6	RP	C	10	770	Seine-et-Marne	de la 	Seine-Marne	ACTIF	Seine-et-Marne	Seine-et-Marne	Seine-et-Marne	1	\N	1959-04-28 00:00:00	\N	http://www.cg77.fr/	\N	\N
820	82	Tarn-et-Garonne	2	SM	C	29	820	Tarn-et-Garonne	du 	Tarn-et-Garonne	ACTIF	Tarn-et-Garonne	Tarn-et-Garonne	Tarn-et-Garonne	2	\N	1959-04-28 00:00:00	\N	http://www.cg82.fr/	\N	\N
890	89	Yonne	2	SM	C	24	890	Yonne	de l'	Yonne	ACTIF	Yonne	Yonne	Yonne	2	\N	1959-04-28 00:00:00	\N	http://www.lyonne.com/	\N	\N
973	973	Guyane	2	SM	A	51	972	Guyane	de la 	Guyane	ACTIF	Guyane	Guyane	Guyane	2	\N	1959-04-28 00:00:00	\N	\N	\N	\N
974	974	La Réunion	4	RP	B	53	974	La Réunion	de 	La Réunion	ACTIF	La Réunion	La Réunion	La Réunion	1	\N	1959-04-28 00:00:00	\N	http://www.cg974.fr/	\N	\N
983	987	Polynésie française	2	SM	A	61	983	Polynésie française	de la 	Polynésie française	ACTIF	Polynésie française	Polynésie française	Polynésie française	2	\N	1959-04-28 00:00:00	\N	\N	\N	\N
995	975	Saint-Pierre-et-Miquelon	1	SM	C	71	981	Saint-Pierre-et-Miquelon	de 	Saint-Pierre-et-Miquelon	ACTIF	Saint-Pierre-Miquelon	Saint-Pierre-et-Miquelon	Saint-Pierre-et-Miquelon	1	\N	1959-04-28 00:00:00	\N	http://www.cg975.fr	\N	\N
998	998	Français établis hors de France (Série B)	\N	RP	B	90	999	Français établis hors de France	représentant les 	Français établis hors de France	ANCIEN	Hors de France B	Français établis hors de France (Série B)	Français établis hors de France (Série B)	1	\N	1959-04-28 00:00:00	2010-09-30 00:00:00	\N	\N	\N
260	26	Drôme	3	RP	A	30	260	Drôme	de la 	Drôme	ACTIF	Drôme	Drôme	Drôme	2	\N	1959-04-28 00:00:00	\N	http://www.cg26.fr/	\N	\N
335	92	Hauts-de-Seine	7	RP	C	10	920	Hauts-de-Seine	des 	Hauts-de-Seine	ACTIF	Hauts-de-Seine	Hauts-de-Seine	Hauts-de-Seine	1	\N	1968-01-01 00:00:00	\N	http://www.cg92.fr/	\N	\N
530	53	Mayenne	2	SM	B	18	530	Mayenne	de la 	Mayenne	ACTIF	Mayenne	Mayenne	Mayenne	1	\N	1959-04-28 00:00:00	\N	http://www.cg53.fr/	\N	\N
650	65	Hautes-Pyrénées	2	SM	B	29	650	Hautes-Pyrénées	des 	Pyrénées Hautes	ACTIF	Hautes-Pyrénées	Hautes-Pyrénées	Hautes-Pyrénées	1	\N	1959-04-28 00:00:00	\N	http://www.cg65.fr/	\N	\N
800	80	Somme	3	RP	C	26	800	Somme	de la 	Somme	ACTIF	Somme	Somme	Somme	2	\N	1959-04-28 00:00:00	\N	http://www.cg80.fr/	\N	\N
50	05	Hautes-Alpes	1	SM	A	21	50	Hautes-Alpes	des 	Alpes Hautes	ACTIF	Hautes-Alpes	Hautes-Alpes	Hautes-Alpes	2	\N	1959-04-28 00:00:00	\N	http://www.cg05.fr	\N	\N
310	31	Haute-Garonne	5	RP	A	29	310	Haute-Garonne	de la 	Garonne Haute	ACTIF	Haute-Garonne	Haute-Garonne	Haute-Garonne	2	\N	1959-04-28 00:00:00	\N	http://www.cg31.fr/	\N	\N
640	64	Pyrénées-Atlantiques	3	RP	B	28	640	Pyrénées-Atlantiques	des 	Pyrénées Atlantiques	ACTIF	Pyrénées-Atlantiq.	Pyrénées-Atlantiques	Pyrénées-Atlantiques	1	\N	1969-10-10 00:00:00	\N	http://www.cg64.fr/	\N	\N
125	90	Territoire de Belfort	1	SM	A	24	900	Territoire de Belfort	du 	Belfort	ACTIF	Belfort	Territoire de Belfort	Territoire de Belfort	2	\N	1959-04-28 00:00:00	\N	http://www.cg90.fr/	\N	\N
200	2A	Corse-du-Sud	1	SM	A	8	204	Corse-du-Sud	de la 	Corse duSud	ACTIF	Corse-du-Sud	Corse-du-Sud	Corse-du-Sud	2	\N	1975-05-15 00:00:00	\N	\N	\N	\N
9999	9999	indéterminé	\N	NEANT	X	93	9999	indéterminé	\N	indéterminé	ANCIEN	indéterminé	indéterminé	indéterminé	\N	\N	1959-04-28 00:00:00	1959-04-28 00:00:00	\N	\N	\N
1000	44	Loire-Inférieure	\N	NEANT	B	18	445	Loire-Inférieure	de la	Loire-Inférieure	ANCIEN	Loire-Inférieure	Loire-Inférieure av. mar 1957	Loire-Inférieure devenue Loire-Atlantique (09/03/1957)	\N	\N	\N	1957-03-09 00:00:00	http://www.cg44.fr/	\N	\N
1004	64	Basses-Pyrénées	\N	NEANT	B	2	645	Basses-Pyrénées	des 	Pyrénées Basses	ANCIEN	Basses-Pyrénées	Basses-Pyrénées av. oct 1969	Basses-Pyrénées devenues Pyrénées-Atlantiques (10/10/1969)	\N	\N	1959-04-28 00:00:00	1969-10-10 00:00:00	http://www.cg64.fr/	\N	\N
1002	20	Corse	\N	NEANT	A	8	200	Corse	de la	Corse	ANCIEN	Corse	Corse av. mai 1975	Corse devenue Haute Corse et Corse-du-Sud (15/05/1975)	\N	\N	1959-04-28 00:00:00	1975-05-15 00:00:00	\N	\N	\N
1029	75	Seine	\N	NEANT	C	10	750	Seine	de la 	Seine	ANCIEN	Seine	Seine av. jan 1968	Seine devenue Paris, Hauts-de-Seine, Seine-Saint-Denis,Val-de-Marne (01/01/1968)	\N	\N	1959-04-28 00:00:00	1968-01-01 00:00:00	\N	\N	\N
1032	76	Seine-Inférieure	\N	NEANT	C	17	755	Seine-Inférieure	de la 	Seine-Inférieure	ANCIEN	Seine-Inférieure	Seine-Inférieure av. jan 1955	Seine-Inférieure devenue Seine-Maritime (18/01/1955)	\N	\N	\N	1955-01-18 00:00:00	http://www.cg76.fr/	\N	\N
1011	04	Basses-Alpes	\N	NEANT	A	21	45	Basses-Alpes	des 	Alpes Basses	ANCIEN	Basses-Alpes	Basses-Alpes av. avr 1969	Basses-Alpes devenues Alpes de Haute-Provence (13/04/1969)	\N	\N	1959-04-28 00:00:00	1969-04-13 00:00:00	http://www.cg04.fr/	\N	\N
1020	78	Seine-et-Oise	\N	NEANT	C	10	780	Seine-et-Oise	de la	Seine-Oise	ANCIEN	Seine-et-Oise	Seine-et-Oise av. jan 1968	Seine-et-Oise devenue Hauts-de-Seine, Val-de-Marne, Seine-Saint-Denis, Val d'Oise, Yvelines, Essonne (01/01/1968)	\N	\N	1959-04-28 00:00:00	1968-01-01 00:00:00	http://www.yvelines.fr	\N	\N
1047	1047	Territoire des afars et des Issas	\N	NEANT	X	72	997	Territoire des afars et des Issas	du 	Territoire des afar et des Issas	ANCIEN	Territoire des afars et des Issas	Territoire des afars et des Issas (ap. mars 1977)	Territoire des afar et des issas (après le 19 mars 1977)	\N	\N	1967-03-19 00:00:00	1977-03-19 00:00:00	\N	\N	\N
790	79	Deux-Sèvres	2	SM	C	28	790	Deux-Sèvres	des 	Sèvres	ACTIF	Deux-Sèvres	Deux-Sèvres	Deux-Sèvres	2	\N	1959-04-28 00:00:00	\N	\N	\N	\N
100	10	Aube	2	SM	A	27	100	Aube	de l'	Aube	ACTIF	Aube	Aube	Aube	2	\N	1959-04-28 00:00:00	\N	http://www.cg-aube.com/	\N	\N
340	34	Hérault	4	RP	A	29	340	Hérault	de l'	Hérault	ACTIF	Hérault	Hérault	Hérault	2	\N	1959-04-28 00:00:00	\N	http://www.cg34.fr/	\N	\N
824	94	Val-de-Marne	6	RP	C	10	940	Val-de-Marne	du 	Val-de-Marne	ACTIF	Val-de-Marne	Val-de-Marne	Val-de-Marne	1	\N	1968-01-01 00:00:00	\N	\N	\N	\N
270	27	Eure	3	RP	A	25	270	Eure	de l'	Eure	ACTIF	Eure	Eure	Eure	2	\N	1959-04-28 00:00:00	\N	http://www.cg27.fr/	\N	\N
710	71	Saône-et-Loire	3	RP	C	24	710	Saône-et-Loire	de la 	Saône-et-Loire	ACTIF	Saône-et-Loire	Saône-et-Loire	Saône-et-Loire	2	\N	1959-04-28 00:00:00	\N	http://www.cg71.com	\N	\N
205	2B	Haute-Corse	1	SM	A	8	205	Haute-Corse	de la 	Corse Haute	ACTIF	Haute-Corse	Haute-Corse	Haute-Corse	2	\N	1975-05-15 00:00:00	\N	\N	\N	\N
720	72	Sarthe	3	RP	C	18	720	Sarthe	de la 	Sarthe	ACTIF	Sarthe	Sarthe	Sarthe	2	\N	1959-04-28 00:00:00	\N	http://www.cg72.fr/	\N	\N
860	86	Vienne	2	SM	C	28	860	Vienne	de la 	Vienne	ACTIF	Vienne	Vienne	Vienne	2	\N	1959-04-28 00:00:00	\N	http://www.cg86.fr/	\N	\N
220	22	Côtes-d'Armor	3	RP	A	5	220	Côtes-d'Armor	des 	Côtes d'Armor	ACTIF	Côtes-d'Armor	Côtes-d'Armor	Côtes-d'Armor	2	\N	1990-02-27 00:00:00	\N	http://www.cg22.fr/	\N	\N
999	999	Français établis hors de France (Série C)	\N	RP	C	90	999	Français établis hors de France	représentant les 	Français établis hors de France	ANCIEN	Hors de France C	Français établis hors de France (Série C)	Français établis hors de France (Série C)	2	\N	1959-04-28 00:00:00	2004-09-30 00:00:00	\N	\N	\N
9715	978	Saint-Martin	1	SM	A	55	978	Saint-Martin	de 	Saintmartin	ACTIF	St-Martin	Saint-Martin	Saint-Martin	2	\N	2008-10-01 00:00:00	\N	\N	\N	\N
1051	998	Français établis hors de France (Série C 1)	\N	RP	C	90	999	Français établis hors de France	représentant les 	Français établis hors de France	ANCIEN	Hors de France C 1	Français établis hors de France (Série C 1)	Français établis hors de France (Série C 1)	1	\N	2004-10-01 00:00:00	2010-09-30 00:00:00	\N	\N	\N
1052	997	Français établis hors de France (Série C 2)	\N	RP	C	90	999	Français établis hors de France	représentant les 	Français établis hors de France	ANCIEN	Hors de France C 2	Français établis hors de France (Série C 2)	Français établis hors de France (Série C 2)	2	\N	2004-10-01 00:00:00	2014-09-30 00:00:00	\N	\N	\N
9713	977	Saint-Barthélemy	1	SM	A	54	977	Saint-Barthélemy	de 	Saintbarthélemy	ACTIF	St-Barthélemy	Saint-Barthélemy	Saint-Barthélemy	2	\N	2008-10-01 00:00:00	\N	\N	\N	\N
250	25	Doubs	3	RP	A	24	250	Doubs	du 	Doubs	ACTIF	Doubs	Doubs	Doubs	2	\N	1959-04-28 00:00:00	\N	Http://www.cg25.fr/ 	\N	\N
80	08	Ardennes	2	SM	A	27	80	Ardennes	des 	Ardennes	ACTIF	Ardennes	Ardennes	Ardennes	2	\N	1959-04-28 00:00:00	\N	\N	\N	\N
630	63	Puy-de-Dôme	3	RP	B	30	630	Puy-de-Dôme	du 	Puy-de-Dôme	ACTIF	Puy-de-Dôme	Puy-de-Dôme	Puy-de-Dôme	1	\N	1959-04-28 00:00:00	\N	http://www.cg63.fr/	\N	\N
350	35	Ille-et-Vilaine	4	RP	A	5	350	Ille-et-Vilaine	d'	Ille-et-Vilaine	ACTIF	Ille-et-Vilaine	Ille-et-Vilaine	Ille-et-Vilaine	2	\N	1959-04-28 00:00:00	\N	http://www.cg35.fr/	\N	\N
1026	22	Côtes-du-Nord	\N	NEANT	A	5	225	Côtes-du-Nord	des 	Cotes du Nord	ANCIEN	Côtes du Nord	Côtes du Nord av. fev 1990	Côtes du Nord devenues Côtes d'Armor (27/02/1990)	\N	\N	1959-04-28 00:00:00	1990-02-27 00:00:00	http://www.cg22.fr/	\N	\N
740	74	Haute-Savoie	3	RP	C	30	740	Haute-Savoie	de la 	Savoie Haute	ACTIF	Haute-Savoie	Haute-Savoie	Haute-Savoie	2	\N	1959-04-28 00:00:00	\N	http://www.cg74.fr/	\N	\N
70	07	Ardèche	2	SM	A	30	70	Ardèche	de l'	Ardèche	ACTIF	Ardèche	Ardèche	Ardèche	2	\N	1959-04-28 00:00:00	\N	http://www.cg07.fr/	\N	\N
240	24	Dordogne	2	SM	A	28	240	Dordogne	de la 	Dordogne	ACTIF	Dordogne	Dordogne	Dordogne	2	\N	1959-04-28 00:00:00	\N	http://www.cg24.fr/	\N	\N
390	39	Jura	2	SM	B	24	390	Jura	du 	Jura	ACTIF	Jura	Jura	Jura	1	\N	1959-04-28 00:00:00	\N	http://www.cg39.fr/	\N	\N
610	61	Orne	2	SM	B	25	610	Orne	de l'	Orne	ACTIF	Orne	Orne	Orne	1	\N	1959-04-28 00:00:00	\N	http://www.cg61.fr/	\N	\N
60	06	Alpes-Maritimes	5	RP	A	21	60	Alpes-Maritimes	des 	Alpes Maritimes	ACTIF	Alpes-Maritimes	Alpes-Maritimes	Alpes-Maritimes	2	\N	1959-04-28 00:00:00	\N	http://www.cg06.fr/	\N	\N
90	09	Ariège	1	SM	A	29	90	Ariège	de l'	Ariège	ACTIF	Ariège	Ariège	Ariège	2	\N	1959-04-28 00:00:00	\N	\N	\N	\N
110	11	Aude	2	SM	A	29	110	Aude	de l'	Aude	ACTIF	Aude	Aude	Aude	2	\N	1959-04-28 00:00:00	\N	http://www.cg11.fr/	\N	\N
150	15	Cantal	2	SM	A	30	150	Cantal	du 	Cantal	ACTIF	Cantal	Cantal	Cantal	2	\N	1959-04-28 00:00:00	\N	\N	\N	\N
160	16	Charente	2	SM	A	28	160	Charente	de la 	Charente	ACTIF	Charente	Charente	Charente	2	\N	1959-04-28 00:00:00	\N	\N	\N	\N
180	18	Cher	2	SM	A	23	180	Cher	du 	Cher	ACTIF	Cher	Cher	Cher	2	\N	1959-04-28 00:00:00	\N	http://www.cg18.fr/	\N	\N
190	19	Corrèze	2	SM	A	28	190	Corrèze	de la 	Corrèze	ACTIF	Corrèze	Corrèze	Corrèze	2	\N	1959-04-28 00:00:00	\N	http://www.cg19.fr/	\N	\N
210	21	Côte-d'Or	3	RP	A	24	210	Côte-d'Or	de la 	Côte-d'Or	ACTIF	Côte-d'Or	Côte-d'Or	Côte-d'Or	2	\N	1959-04-28 00:00:00	\N	http://www.cg21.fr/	\N	\N
230	23	Creuse	2	SM	A	28	230	Creuse	de la 	Creuse	ACTIF	Creuse	Creuse	Creuse	2	\N	1959-04-28 00:00:00	\N	http://www.cg23.fr/	\N	\N
265	91	Essonne	5	RP	C	10	910	Essonne	de l'	Essonne	ACTIF	Essonne	Essonne	Essonne	1	\N	1968-01-01 00:00:00	\N	http://www.essonne.fr	\N	\N
300	30	Gard	3	RP	A	29	300	Gard	du 	Gard	ACTIF	Gard	Gard	Gard	2	\N	1959-04-28 00:00:00	\N	http://www.cg30.fr/	\N	\N
320	32	Gers	2	SM	A	29	320	Gers	du 	Gers	ACTIF	Gers	Gers	Gers	2	\N	1959-04-28 00:00:00	\N	http://www.cg32.fr/	\N	\N
330	33	Gironde	6	RP	A	28	330	Gironde	de la 	Gironde	ACTIF	Gironde	Gironde	Gironde	2	\N	1959-04-28 00:00:00	\N	http://www.cg33.fr/	\N	\N
360	36	Indre	2	SM	A	23	360	Indre	de l'	Indre	ACTIF	Indre	Indre	Indre	2	\N	1959-04-28 00:00:00	\N	http://www.cg36.fr/	\N	\N
400	40	Landes	2	SM	B	28	400	Landes	des 	Landes	ACTIF	Landes	Landes	Landes	1	\N	1959-04-28 00:00:00	\N	http://www.cg40.fr/	\N	\N
420	42	Loire	4	RP	B	30	420	Loire	de la 	Loire	ACTIF	Loire	Loire	Loire	1	\N	1959-04-28 00:00:00	\N	http://www.cg42.fr/	\N	\N
450	45	Loiret	3	RP	B	23	450	Loiret	du 	Loiret	ACTIF	Loiret	Loiret	Loiret	1	\N	1959-04-28 00:00:00	\N	http://www.loiret.com/	\N	\N
460	46	Lot	2	SM	B	29	460	Lot	du 	Lot	ACTIF	Lot	Lot	Lot	1	\N	1959-04-28 00:00:00	\N	http://www.cg46.fr/	\N	\N
480	48	Lozère	1	SM	B	29	480	Lozère	de la 	Lozère	ACTIF	Lozère	Lozère	Lozère	1	\N	1959-04-28 00:00:00	\N	\N	\N	\N
997	997	Français établis hors de France (Série A)	\N	RP	A	90	999	Français établis hors de France	représentant les 	Français établis hors de France	ANCIEN	Hors de France A	Français établis hors de France (Série A)	Français établis hors de France (Série A)	2	\N	1959-04-28 00:00:00	2014-09-30 00:00:00	\N	\N	\N
20	02	Aisne	3	RP	A	26	20	Aisne	de l'	Aisne	ACTIF	Aisne	Aisne	Aisne	2	\N	1959-04-28 00:00:00	\N	http://www.cg02.fr/	\N	\N
290	29	Finistère	4	RP	A	5	290	Finistère	du 	Finistère	ACTIF	Finistère	Finistère	Finistère	2	\N	1959-04-28 00:00:00	\N	http://www.cg29.fr/	\N	\N
370	37	Indre-et-Loire	3	RP	B	23	370	Indre-et-Loire	d'	Indre-et-Loire	ACTIF	Indre-et-Loire	Indre-et-Loire	Indre-et-Loire	1	\N	1959-04-28 00:00:00	\N	http://www.cg37.fr/	\N	\N
430	43	Haute-Loire	2	SM	B	30	430	Haute-Loire	de la 	Loire Haute	ACTIF	Haute-Loire	Haute-Loire	Haute-Loire	1	\N	1959-04-28 00:00:00	\N	http://www.cg43.fr/	\N	\N
560	56	Morbihan	3	RP	B	5	560	Morbihan	du 	Morbihan	ACTIF	Morbihan	Morbihan	Morbihan	1	\N	1959-04-28 00:00:00	\N	http://www.cg56.fr/	\N	\N
620	62	Pas-de-Calais	7	RP	B	26	620	Pas-de-Calais	du 	Pas-de-Calais	ACTIF	Pas-de-Calais	Pas-de-Calais	Pas-de-Calais	1	\N	1959-04-28 00:00:00	\N	http://www.cg62.fr/	\N	\N
690	69	Rhône	7	RP	C	30	690	Rhône	du 	Rhône	ACTIF	Rhône	Rhône	Rhône	2	\N	1959-04-28 00:00:00	\N	http://www.rhone.fr	\N	\N
760	76	Seine-Maritime	6	RP	C	25	760	Seine-Maritime	de la 	Seine-Maritime	ACTIF	Seine-Maritime	Seine-Maritime	Seine-Maritime	2	\N	1955-01-18 00:00:00	\N	http://www.cg76.fr/	\N	\N
120	12	Aveyron	2	SM	A	29	120	Aveyron	de l'	Aveyron	ACTIF	Aveyron	Aveyron	Aveyron	2	\N	1959-04-28 00:00:00	\N	http://www.cg12.fr/	\N	\N
140	14	Calvados	3	RP	A	25	140	Calvados	du 	Calvados	ACTIF	Calvados	Calvados	Calvados	2	\N	1959-04-28 00:00:00	\N	http://www.calvados.fr	\N	\N
870	87	Haute-Vienne	2	SM	C	28	870	Haute-Vienne	de la 	Vienne Haute	ACTIF	Haute-Vienne	Haute-Vienne	Haute-Vienne	2	\N	1959-04-28 00:00:00	\N	http://www.cg87.fr/	\N	\N
410	41	Loir-et-Cher	2	SM	B	23	410	Loir-et-Cher	de 	Loir et Cher	ACTIF	Loir-et-Cher	Loir-et-Cher	Loir-et-Cher	1	\N	1959-04-28 00:00:00	\N	\N	\N	\N
1053	998	Français établis hors de France (Série 1)	6	RP	X	90	999	Français établis hors de France	représentant les 	Français établis hors de France	ACTIF	Hors de France (Série 1)	Français établis hors de France (Série 1)	Français établis hors de France (Série 1)	1	\N	2011-10-01 00:00:00	\N	\N	\N	\N
1054	997	Français établis hors de France (Série 2)	6	RP	X	90	999	Français établis hors de France	représentant les 	Français établis hors de France	ACTIF	Hors de France (Série 2)	Français établis hors de France (Série 2)	Français établis hors de France (Série 2)	2	\N	2014-10-01 00:00:00	\N	\N	\N	\N
1036	1030	Oran	1	NEANT	X	91	1015	Oran	d'	Oran	ANCIEN	Oran	Oran	Oran	\N	\N	1946-12-08 00:00:00	1959-04-26 00:00:00	\N	\N	\N
1031	1031	Sénégal	1	NEANT	Z	91	1000	Sénégal	du 	Sénégal	ANCIEN	Sénégal	Sénégal	Sénégal	\N	\N	1946-12-08 00:00:00	1959-04-26 00:00:00	\N	\N	\N
1034	1034	représentant les Français résidant à l'étranger	1	NEANT	Z	91	1051	Français à l'étranger	 	Français à l'étranger	ANCIEN	Français à l'étranger	représentant les Français résidant à l'étranger	représentant les Français résidant à l'étranger	\N	\N	1946-12-08 00:00:00	1959-04-26 00:00:00	\N	\N	\N
1050	1050	élu(e) par l'Assemblée Nationale	1	NEANT	Z	91	1055	Assemblée Nationale	\N	Assemblée Nationale	ANCIEN	Assemblée Nationale	élu(e) par l'Assemblée Nationale	élu(e) par l'Assemblée Nationale	\N	\N	1946-12-08 00:00:00	1959-04-26 00:00:00	\N	\N	\N
1001	1001	Gabon	1	NEANT	Z	91	1000	Gabon	du	Gabon	ANCIEN	Gabon	Gabon	Gabon	\N	\N	1946-12-08 00:00:00	1959-04-26 00:00:00	\N	\N	\N
1003	1003	Guinée	1	NEANT	Z	91	1000	Guinée	de la	Guinée	ANCIEN	Guinée	Guinée	Guinée	\N	\N	1946-12-08 00:00:00	1959-04-26 00:00:00	\N	\N	\N
1005	1005	Haute-Volta	1	NEANT	Z	91	1000	Haute-Volta	de la	Haute-Volta	ANCIEN	Haute-Volta	Haute-Volta	Haute-Volta	\N	\N	1946-12-08 00:00:00	1959-04-26 00:00:00	\N	\N	\N
1006	1006	Cameroun	1	NEANT	Z	91	1000	Cameroun	du	Cameroun	ANCIEN	Cameroun	Cameroun	Cameroun	\N	\N	1946-12-08 00:00:00	1959-04-26 00:00:00	\N	\N	\N
1007	1007	Soudan	1	NEANT	Z	91	1000	Soudan	du 	Soudan	ANCIEN	Soudan	Soudan	Soudan	\N	\N	1946-12-08 00:00:00	1959-04-26 00:00:00	\N	\N	\N
1008	1008	Ets Français de l'Inde	1	NEANT	Z	91	1000	Ets Français de l'Inde	des 	Ets Français de l'Inde	ANCIEN	Ets Français de l'Inde	Ets Français de l'Inde	Ets Français de l'Inde	\N	\N	1946-12-08 00:00:00	1959-04-26 00:00:00	\N	\N	\N
1009	1009	Madagascar	1	NEANT	Z	91	1000	Madagascar	de	Madagascar	ANCIEN	Madagascar	Madagascar	Madagascar	\N	\N	1946-12-08 00:00:00	1959-04-26 00:00:00	\N	\N	\N
1010	1010	Moyen-Congo	1	NEANT	Z	91	1000	Moyen-Congo	du	Moyen-Congo	ANCIEN	Moyen-Congo	Moyen-Congo	Moyen-Congo	\N	\N	1946-12-08 00:00:00	1959-04-26 00:00:00	\N	\N	\N
1013	1013	Côte d'Ivoire	1	NEANT	Z	91	1000	Côte d'Ivoire	de la	Côte d'Ivoire	ANCIEN	Côte d'Ivoire	Côte d'Ivoire	Côte d'Ivoire	\N	\N	1946-12-08 00:00:00	1959-04-26 00:00:00	\N	\N	\N
1014	1014	Oubangui-Chari	1	NEANT	Z	91	1000	Oubangui-Chari	d'	Oubangui-Chari	ANCIEN	Oubangui-Chari	Oubangui-Chari	Oubangui-Chari	\N	\N	1946-12-08 00:00:00	1959-04-26 00:00:00	\N	\N	\N
1015	1015	Niger	1	NEANT	Z	91	1000	Niger	du 	Niger	ANCIEN	Niger	Niger	Niger	\N	\N	1946-12-08 00:00:00	1959-04-26 00:00:00	\N	\N	\N
1016	1016	Dahomey	1	NEANT	Z	91	1000	Dahomey	du	Dahomey	ANCIEN	Dahomey	Dahomey	Dahomey	\N	\N	1946-12-08 00:00:00	1959-04-26 00:00:00	\N	\N	\N
1017	1017	Océanie	1	NEANT	Z	91	1000	Océanie	de l'	Océanie	ANCIEN	Océanie	Océanie	Océanie	\N	\N	1946-12-08 00:00:00	1959-04-26 00:00:00	\N	\N	\N
1019	1019	représentant les Français résidant au Maroc	1	NEANT	Z	91	1052	Maroc	 	Maroc	ANCIEN	Maroc	représentant les Français résidant au Maroc	représentant les Français résidant au Maroc	\N	\N	1946-12-08 00:00:00	1959-04-26 00:00:00	\N	\N	\N
1022	1022	représentant les Français résidant en Indochine	1	NEANT	Z	91	1053	Indochine	 	Indochine	ANCIEN	Indochine	représentant les Français résidant en Indochine	représentant les Français résidant en Indochine	\N	\N	1946-12-08 00:00:00	1959-04-26 00:00:00	\N	\N	\N
1023	1023	représentant les Français résidant en Tunisie	1	NEANT	Z	91	1054	Tunisie	 	Tunisie	ANCIEN	Tunisie	représentant les Français résidant en Tunisie	représentant les Français résidant en Tunisie	\N	\N	1946-12-08 00:00:00	1959-04-26 00:00:00	\N	\N	\N
1024	1024	Tchad	1	NEANT	Z	91	1000	Tchad	du 	Tchad	ANCIEN	Tchad	Tchad	Tchad	\N	\N	1946-12-08 00:00:00	1959-04-26 00:00:00	\N	\N	\N
1027	1027	Togo	1	NEANT	Z	91	1000	Togo	du 	Togo	ANCIEN	Togo	Togo	Togo	\N	\N	1946-12-08 00:00:00	1959-04-26 00:00:00	\N	\N	\N
1028	1028	Mauritanie	1	NEANT	Z	91	1000	Mauritanie	de la	Mauritanie	ANCIEN	Mauritanie	Mauritanie	Mauritanie	\N	\N	1946-12-08 00:00:00	1959-04-26 00:00:00	\N	\N	\N
1035	17	Charente-Inférieure	1	NEANT	Z	20	170	Charente -Inférieure	de la 	Charente -Inférieure	ANCIEN	Charente -Inférieure	Charente-Inférieure	Charente-Inférieure	\N	\N	1875-12-09 00:00:00	1945-12-31 00:00:00	\N	\N	\N
1037	1021	Algérie (Alger)	1	NEANT	Z	92	1000	Algérie(Alger)	d'	Algérie(Alger)	ANCIEN	Algérie (Alger)	Algérie (Alger)	Algérie (Alger)	\N	\N	1875-12-09 00:00:00	1945-12-31 00:00:00	\N	\N	\N
1038	1030	Algérie (Oran)	1	NEANT	Z	92	1000	Algérie(Oran)	d'	Algérie(Oran)	ANCIEN	Algérie (Oran)	Algérie (Oran)	Algérie (Oran)	\N	\N	1875-12-09 00:00:00	1945-12-31 00:00:00	\N	\N	\N
1039	1033	Algérie (Constantine)	1	NEANT	Z	92	1000	Algérie(Constantine)	d'	Algérie(Constantine)	ANCIEN	Algérie (Constantine)	Algérie (Constantine)	Algérie (Constantine)	\N	\N	1875-12-09 00:00:00	1945-12-31 00:00:00	\N	\N	\N
9998	9998	inamovible	1	NEANT	Z	92	9998	inamovibles	\N	inamovibles	ANCIEN	inamovibles	inamovible	inamovible	\N	\N	1875-12-09 00:00:00	1945-12-31 00:00:00	\N	\N	\N
30	03	Allier	2	SM	A	30	30	Allier	de l'	Allier	ACTIF	Allier	Allier	Allier	2	\N	1959-04-28 00:00:00	\N	http://www.cg03.fr/	\N	\N
490	49	Maine-et-Loire	4	RP	B	18	490	Maine-et-Loire	de 	Maine-et-Loire	ACTIF	Maine-et-Loire	Maine-et-Loire	Maine-et-Loire	1	\N	1959-04-28 00:00:00	\N	http://www.cg49.fr/	\N	2017-09-08 23:17:19
540	54	Meurthe-et-Moselle	4	RP	B	27	540	Meurthe-et-Moselle	de la 	Meurthe-et-Moselle	ACTIF	Meurthe-et-Moselle	Meurthe-et-Moselle	Meurthe-et-Moselle	1	\N	1959-04-28 00:00:00	\N	http://www.cg54.fr/	\N	\N
550	55	Meuse	2	SM	B	27	550	Meuse	de la 	Meuse	ACTIF	Meuse	Meuse	Meuse	1	\N	1959-04-28 00:00:00	\N	http://www.cg55.fr/	\N	\N
590	59	Nord	11	RP	B	26	590	Nord	du 	Nord	ACTIF	Nord	Nord	Nord	1	\N	1959-04-28 00:00:00	\N	http://www.cg59.fr/	\N	\N
600	60	Oise	4	RP	B	26	600	Oise	de l'	Oise	ACTIF	Oise	Oise	Oise	1	\N	1959-04-28 00:00:00	\N	http://www.cg60.fr/	\N	2017-09-08 23:17:19
615	75	Paris	12	RP	C	10	615	Paris	de 	Paris	ACTIF	Paris	Paris	Paris	1	\N	1968-01-01 00:00:00	\N	\N	\N	\N
670	67	Bas-Rhin	5	RP	C	27	670	Bas-Rhin	du 	Rhin Bas	ACTIF	Bas-Rhin	Bas-Rhin	Bas-Rhin	2	\N	1959-04-28 00:00:00	\N	http://www.cg67.fr/	\N	\N
680	68	Haut-Rhin	4	RP	C	27	680	Haut-Rhin	du 	Rhin Haut	ACTIF	Haut-Rhin	Haut-Rhin	Haut-Rhin	2	\N	1959-04-28 00:00:00	\N	http://www.cg68.fr/	\N	\N
700	70	Haute-Saône	2	SM	C	24	700	Haute-Saône	de la 	Saône Haute	ACTIF	Haute-Saône	Haute-Saône	Haute-Saône	2	\N	1959-04-28 00:00:00	\N	http://www.cg70.fr/	\N	\N
775	93	Seine-Saint-Denis	6	RP	C	10	930	Seine-Saint-Denis	de la 	Seine-Saint-Denis	ACTIF	Seine-Saint-Denis	Seine-Saint-Denis	Seine-Saint-Denis	1	\N	1968-01-01 00:00:00	\N	http://www.cg93.fr/	\N	\N
810	81	Tarn	2	SM	C	29	810	Tarn	du 	Tarn	ACTIF	Tarn	Tarn	Tarn	2	\N	1959-04-28 00:00:00	\N	http://www.cg81.fr/	\N	\N
828	95	Val-d'Oise	5	RP	C	10	950	Val-d'Oise	du 	Val-d'Oise	ACTIF	Val-d'Oise	Val-d'Oise	Val-d'Oise	1	\N	1968-01-01 00:00:00	\N	http://www.cg95.fr/	\N	\N
830	83	Var	4	RP	C	21	830	Var	du 	Var	ACTIF	Var	Var	Var	2	\N	1959-04-28 00:00:00	\N	http://www.cg83.fr/	\N	\N
840	84	Vaucluse	3	RP	C	21	840	Vaucluse	du 	Vaucluse	ACTIF	Vaucluse	Vaucluse	Vaucluse	2	\N	1959-04-28 00:00:00	\N	http://www.vaucluse.fr/	\N	2024-04-09 18:43:17
850	85	Vendée	3	RP	C	18	850	Vendée	de la 	Vendée	ACTIF	Vendée	Vendée	Vendée	2	\N	1959-04-28 00:00:00	\N	http://www.cg85.fr/	\N	\N
880	88	Vosges	2	SM	C	27	880	Vosges	des 	Vosges	ACTIF	Vosges	Vosges	Vosges	2	\N	1959-04-28 00:00:00	\N	http://www.cg88.fr/	\N	\N
895	78	Yvelines	6	RP	C	10	895	Yvelines	des 	Yvelines	ACTIF	Yvelines	Yvelines	Yvelines	1	\N	1968-01-01 00:00:00	\N	http://www.yvelines.fr	\N	\N
971	971	Guadeloupe	3	RP	C	50	971	Guadeloupe	de la 	Guadeloupe	ACTIF	Guadeloupe	Guadeloupe	Guadeloupe	1	\N	1959-04-28 00:00:00	\N	http://www.cg971.fr	\N	\N
972	972	Martinique	2	SM	C	52	973	Martinique	de la 	Martinique	ACTIF	Martinique	Martinique	Martinique	1	\N	1959-04-28 00:00:00	\N	http://www.cg972.fr/	\N	\N
982	988	Nouvelle-Calédonie	2	SM	B	60	990	Nouvelle-Calédonie	de la 	Nouvelle-Calédonie	ACTIF	Nouvelle-Calédonie	Nouvelle-Calédonie	Nouvelle-Calédonie	1	\N	1959-04-28 00:00:00	\N	\N	\N	\N
984	986	Iles Wallis et Futuna	1	SM	A	62	982	Iles Wallis et Futuna	des 	Wallis et Futuna	ACTIF	Iles Wallis et Futuna	Iles Wallis et Futuna	Iles Wallis et Futuna	2	\N	1959-04-28 00:00:00	\N	\N	\N	\N
990	976	Mayotte	2	SM	C	70	976	Mayotte	de 	Mayotte	ACTIF	Mayotte	Mayotte	Mayotte	1	\N	1959-04-28 00:00:00	\N	\N	\N	\N
500	50	Manche	3	RP	B	25	500	Manche	de la 	Manche	ACTIF	Manche	Manche	Manche	1	\N	1959-04-28 00:00:00	\N	\N	\N	\N
570	57	Moselle	5	RP	B	27	570	Moselle	de la 	Moselle	ACTIF	Moselle	Moselle	Moselle	1	\N	1959-04-28 00:00:00	\N	http://www.cg57.fr/	\N	\N
730	73	Savoie	2	SM	C	30	730	Savoie	de la 	Savoie	ACTIF	Savoie	Savoie	Savoie	2	\N	1959-04-28 00:00:00	\N	http://www.cg73.fr/	\N	2017-09-11 15:34:40
1021	1021	Alger	\N	NEANT	X	40	1000	Alger	d'	Alger	ANCIEN	Alger	Alger	Alger	\N	\N	1959-04-28 00:00:00	1962-07-03 00:00:00	\N	\N	\N
1040	1040	Tizi-Ouzou	\N	NEANT	X	40	1005	Tizi-Ouzou	de 	Tizi-Ouzou	ANCIEN	Tizi-Ouzou	Tizi-Ouzou	Tizi-Ouzou	\N	\N	1959-04-28 00:00:00	1962-07-03 00:00:00	\N	\N	\N
1041	1041	Saoura	\N	NEANT	X	40	1040	Saoura	de 	Saoura	ANCIEN	Saoura	Saoura	Saoura	\N	\N	1959-04-28 00:00:00	1962-07-03 00:00:00	\N	\N	\N
1042	1042	Bône	\N	NEANT	X	40	1035	Bône	de 	Bône	ANCIEN	Bône	Bône	Bône	\N	\N	1959-04-28 00:00:00	1962-07-03 00:00:00	\N	\N	\N
1043	1043	Orléansville-Médéa	\N	NEANT	X	40	1010	Orléansville-Médéa	de 	Orléansville-Médéa	ANCIEN	Orléansville-Médéa	Orléansville-Médéa	Orléansville-Médéa	\N	\N	1959-04-28 00:00:00	1962-07-03 00:00:00	\N	\N	\N
1044	1044	Mostaganem-Tiaret	\N	NEANT	X	40	1020	Mostaganem-Tiaret	de 	Mostaganem-Tiaret	ANCIEN	Mostaganem-Tiaret	Mostaganem-Tiaret	Mostaganem-Tiaret	\N	\N	1959-04-28 00:00:00	1962-07-03 00:00:00	\N	\N	\N
1045	1045	Setif-Batna	\N	NEANT	X	40	1030	Setif-Batna	de 	Setif-Batna	ANCIEN	Setif-Batna	Setif-Batna	Setif-Batna	\N	\N	1959-04-28 00:00:00	1962-07-03 00:00:00	\N	\N	\N
1025	976	Comores	\N	NEANT	X	63	995	Comores	des	Comores	ANCIEN	Comores	Comores	Comores	\N	\N	1959-04-28 00:00:00	1975-07-06 00:00:00	\N	\N	\N
1012	1012	Côte française des Somalis	\N	NEANT	X	72	996	Côte française des Somalis	de la 	Côte française des Somalis	ANCIEN	Somalis	Côte française des Somalis av. mars 1967	Côte française des Somalis devenue Territoire des Afar et des Issas le 19 mars 1967	\N	\N	1959-04-28 00:00:00	1967-03-19 00:00:00	\N	\N	\N
1030	1030	Oran-Tlemcen	\N	NEANT	X	40	1015	Oran-Tlemcen	d'	Oran-Tlemcen	ANCIEN	Oran-Tlemcen	Oran-Tlemcen	Oran-Tlemcen	\N	\N	1959-04-28 00:00:00	1962-07-03 00:00:00	\N	\N	\N
1033	1033	Constantine	\N	NEANT	X	40	1025	Constantine	de 	Constantine	ANCIEN	Constantine	Constantine	Constantine	\N	\N	1959-04-28 00:00:00	1962-07-03 00:00:00	\N	\N	\N
1046	1046	Oasis	\N	NEANT	X	40	1045	Oasis	d'	Oasis	ANCIEN	Oasis	Oasis	Oasis	\N	\N	1959-04-28 00:00:00	1962-07-03 00:00:00	\N	\N	\N
380	38	Isère	5	RP	B	30	380	Isère	de l'	Isère	ACTIF	Isère	Isère	Isère	1	\N	1959-04-28 00:00:00	\N	http://www.cg38.fr/	\N	\N
510	51	Marne	3	RP	B	27	510	Marne	de la 	Marne	ACTIF	Marne	Marne	Marne	1	\N	1959-04-28 00:00:00	\N	\N	\N	\N
10	01	Ain	3	RP	A	30	10	Ain	de l'	Ain	ACTIF	Ain	Ain	Ain	2	\N	1959-04-28 00:00:00	\N	http://www.cg01.fr/	\N	\N
470	47	Lot-et-Garonne	2	SM	B	28	470	Lot-et-Garonne	de 	Lot-et-Garonne	ACTIF	Lot-et-Garonne	Lot-et-Garonne	Lot-et-Garonne	1	\N	1959-04-28 00:00:00	\N	http://www.lot-et-garonne.fr	\N	\N
40	04	Alpes de Haute-Provence	1	SM	A	21	40	Alpes de Haute-Provence	des 	Alpes de Haute-Provence	ACTIF	Alpes Haute-Provence	Alpes de Haute-Provence	Alpes de Haute-Provence	2	\N	1969-04-13 00:00:00	\N	http://www.cg04.fr/	\N	\N
130	13	Bouches-du-Rhône	8	RP	A	21	130	Bouches-du-Rhône	des 	Bouches-du-Rhône	ACTIF	Bouches-du-Rhône	Bouches-du-Rhône	Bouches-du-Rhône	2	\N	1959-04-28 00:00:00	\N	http://www.cg13.fr/	\N	\N
170	17	Charente-Maritime	3	RP	A	28	170	Charente-Maritime	de la 	Charente-Maritime	ACTIF	Charente-Maritime	Charente-Maritime	Charente-Maritime	2	\N	1959-04-28 00:00:00	\N	\N	\N	\N
280	28	Eure-et-Loir	3	RP	A	23	280	Eure-et-Loir	d'	Eure-et-Loir	ACTIF	Eure-et-Loir	Eure-et-Loir	Eure-et-Loir	2	\N	1959-04-28 00:00:00	\N	http://www.cg28.fr/	\N	\N
440	44	Loire-Atlantique	5	RP	B	18	440	Loire-Atlantique	de la 	Loire-Atlantique	ACTIF	Loire-Atlantique	Loire-Atlantique	Loire-Atlantique	1	\N	1957-03-09 00:00:00	\N	http://www.cg44.fr/	\N	\N
520	52	Haute-Marne	2	SM	B	27	520	Haute-Marne	de la 	Marne Haute	ACTIF	Haute-Marne	Haute-Marne	Haute-Marne	1	\N	1959-04-28 00:00:00	\N	http://www.haute-marne.org/	\N	\N
1055	1055	Français établis hors de France	\N	NEANT	X	90	999	Français établis hors de France	représentant les 	Français établis hors de France	ANCIEN	Français établis hors de France	Français établis hors de France	Français établis hors de France	\N	\N	\N	1962-07-03 00:00:00	\N	2015-02-10 11:15:17	\N
1056	1056	Alger, des Oasis et de la Saoura	\N	NEANT	X	90	999	Alger, des Oasis et de la Saoura	d' 	Alger, des Oasis et de la Saoura	ANCIEN	Alger, des Oasis et de la Saoura	Alger, des Oasis et de la Saoura	Alger, des Oasis et de la Saoura	\N	\N	\N	1962-07-03 00:00:00	\N	2015-02-10 11:15:17	\N
535	535	Meurthe	\N	NEANT	X	13	535	Meurthe	de la 	Meurthe	ANCIEN	Meurthe	Meurthe	Meurthe	\N	\N	1790-01-27 00:00:00	1871-05-18 00:00:00	\N	2014-02-26 11:21:02	\N
9900	99	Étranger	\N	NEANT	X	ETRG	999	Étranger	de l' 	Étranger	ANCIEN	Étranger	Étranger	Étranger	\N	\N	1950-01-01 00:00:00	2014-01-01 00:00:00	\N	2014-02-26 11:21:19	\N
\.


--
-- Data for Name: dptele; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY dptele (dptnum, dptelenbrsie, dpteleid, typelecod, validcod, valid2cod, participaidt1, participaidt2, syscredat, sysmajdat, eleid, dptelenbrsiepvr, dptelecmt) FROM stdin;
205	1	398	SM	NODATA	NODATA	\N	\N	\N	\N	13	1	\N
250	3	402	SM	NODATA	NODATA	\N	\N	\N	\N	13	3	\N
270	3	405	SM	NODATA	NODATA	\N	\N	\N	\N	13	3	\N
290	4	407	RP	NODATA	NODATA	\N	\N	\N	\N	13	4	\N
335	7	411	RP	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
350	4	413	RP	NODATA	NODATA	\N	\N	\N	\N	13	4	\N
380	3	416	RP	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
410	2	418	SM	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
450	2	422	SM	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
470	2	424	SM	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
490	3	426	SM	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
530	2	429	SM	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
580	2	434	SM	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
615	12	437	RP	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
640	3	440	SM	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
710	3	446	SM	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
740	3	449	SM	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
775	6	452	RP	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
820	2	455	SM	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
830	3	458	RP	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
850	3	460	SM	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
870	2	462	SM	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
890	2	464	SM	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
971	2	466	SM	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
974	2	469	SM	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
983	1	471	SM	NODATA	NODATA	\N	\N	\N	\N	13	1	\N
997	2	475	RP	NODATA	NODATA	\N	\N	\N	\N	13	2	\N
999	2	477	RP	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
10	2	479	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
40	1	482	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
80	2	486	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
200	1	489	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
400	2	491	SM	NODATA	NODATA	\N	\N	\N	\N	14	2	\N
800	2	495	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
125	1	498	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
140	3	500	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
160	2	502	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
230	2	508	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
250	3	510	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
280	2	514	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
340	3	520	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
360	2	522	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
390	2	525	SM	NODATA	NODATA	\N	\N	\N	\N	14	2	\N
440	5	529	RP	NODATA	NODATA	\N	\N	\N	\N	14	5	\N
997	2	532	RP	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
999	2	534	RP	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
1004	3	536	NEANT	NODATA	NODATA	\N	\N	\N	\N	9	3	\N
1012	1	538	NEANT	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
1025	1	540	NEANT	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
1029	13	542	NEANT	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
60	3	547	RP	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
80	2	549	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
300	2	552	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
500	3	554	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
110	2	558	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
130	5	561	RP	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
150	2	563	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
190	2	567	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
230	2	569	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
250	2	571	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
270	2	574	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
330	4	579	RP	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
340	3	581	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
370	2	584	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
420	4	588	RP	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
470	2	593	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
510	3	596	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
540	3	599	RP	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
610	2	605	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
620	6	607	RP	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
650	2	609	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
670	4	611	RP	NODATA	NODATA	\N	\N	\N	\N	17	4	\N
690	5	613	RP	NODATA	NODATA	\N	\N	\N	\N	17	5	\N
730	2	616	SM	NODATA	NODATA	\N	\N	\N	\N	17	2	\N
760	5	618	RP	NODATA	NODATA	\N	\N	\N	\N	17	5	\N
775	5	620	RP	NODATA	NODATA	\N	\N	\N	\N	17	5	\N
824	5	624	RP	NODATA	NODATA	\N	\N	\N	\N	17	5	\N
830	3	626	RP	NODATA	NODATA	\N	\N	\N	\N	17	3	\N
860	2	629	SM	NODATA	NODATA	\N	\N	\N	\N	17	2	\N
880	2	631	SM	NODATA	NODATA	\N	\N	\N	\N	17	2	\N
972	2	635	SM	NODATA	NODATA	\N	\N	\N	\N	17	2	\N
974	2	637	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
984	1	640	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
999	2	644	RP	NODATA	NODATA	\N	\N	\N	\N	17	2	\N
1004	3	646	NEANT	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
1012	1	648	NEANT	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
10	2	651	SM	NODATA	NODATA	\N	\N	\N	\N	10	2	\N
60	3	656	RP	NODATA	NODATA	\N	\N	\N	\N	10	3	\N
90	1	659	SM	NODATA	NODATA	\N	\N	\N	\N	10	1	\N
500	3	663	SM	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
800	3	666	SM	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
140	3	671	SM	NODATA	NODATA	\N	\N	\N	\N	10	3	\N
170	3	674	SM	NODATA	NODATA	\N	\N	\N	\N	10	3	\N
230	2	678	SM	NODATA	NODATA	\N	\N	\N	\N	10	2	\N
270	2	683	SM	NODATA	NODATA	\N	\N	\N	\N	10	2	\N
290	4	685	RP	NODATA	NODATA	\N	\N	\N	\N	10	4	\N
320	2	687	SM	NODATA	NODATA	\N	\N	\N	\N	10	2	\N
335	7	689	RP	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
360	2	692	SM	NODATA	NODATA	\N	\N	\N	\N	10	2	\N
380	3	694	RP	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
410	2	696	SM	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
430	2	698	SM	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
470	2	702	SM	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
510	3	705	SM	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
530	2	707	SM	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
550	2	709	SM	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
590	9	713	RP	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
620	6	716	RP	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
640	2	718	SM	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
660	2	720	SM	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
710	3	724	SM	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
740	2	727	SM	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
770	3	729	RP	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
824	5	734	RP	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
840	2	737	SM	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
860	2	739	SM	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
895	4	743	RP	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
983	1	749	SM	NODATA	NODATA	\N	\N	\N	\N	10	1	\N
995	1	751	SM	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
999	2	754	RP	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
1025	1	758	NEANT	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
20	3	761	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
40	1	763	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
60	3	765	RP	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
80	2	767	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
300	2	770	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
500	3	772	SM	NODATA	NODATA	\N	\N	\N	\N	11	3	\N
120	2	777	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
130	5	779	RP	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
150	2	781	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
170	3	783	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
230	2	787	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
260	2	790	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
270	2	792	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
290	4	794	RP	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
335	7	798	RP	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
1054	6	3227	RP	NODATA	NODATA	\N	\N	\N	2014-09-28 18:47:32	19	6	\N
490	4	3228	RP	NODATA	NODATA	\N	\N	\N	\N	19	0	\N
540	4	3229	RP	NODATA	NODATA	\N	\N	\N	\N	19	0	\N
550	2	3230	SM	NODATA	NODATA	\N	\N	\N	\N	19	0	\N
590	11	3231	RP	NODATA	NODATA	\N	\N	\N	\N	19	0	\N
600	4	3232	RP	NODATA	NODATA	\N	\N	\N	\N	19	0	\N
615	12	3233	RP	NODATA	NODATA	\N	\N	\N	\N	19	0	\N
670	5	3234	RP	NODATA	NODATA	\N	\N	\N	2014-09-28 17:33:09	19	5	\N
680	4	3235	RP	NODATA	NODATA	\N	\N	\N	2014-09-28 17:15:28	19	4	\N
700	2	3236	SM	NODATA	NODATA	\N	\N	\N	2014-09-28 13:41:59	19	2	\N
775	6	3237	RP	NODATA	NODATA	\N	\N	\N	\N	19	0	\N
810	2	3238	SM	NODATA	NODATA	\N	\N	\N	2014-09-28 19:15:03	19	2	\N
828	5	3239	RP	NODATA	NODATA	\N	\N	\N	\N	19	0	\N
830	4	3240	RP	NODATA	NODATA	\N	\N	\N	2014-09-28 18:05:03	19	4	\N
840	3	3241	RP	NODATA	NODATA	\N	\N	\N	2014-09-28 17:39:50	19	3	\N
850	3	3242	RP	NODATA	NODATA	\N	\N	\N	2014-09-28 16:43:38	19	3	\N
880	2	3243	SM	NODATA	NODATA	\N	\N	\N	2014-09-28 18:55:30	19	2	\N
895	6	3244	RP	NODATA	NODATA	\N	\N	\N	\N	19	0	\N
971	3	3245	RP	NODATA	NODATA	\N	\N	\N	\N	19	0	\N
972	2	3246	SM	NODATA	NODATA	\N	\N	\N	\N	19	0	\N
982	2	3247	SM	NODATA	NODATA	\N	\N	\N	\N	19	0	\N
984	1	3248	SM	NODATA	NODATA	\N	\N	\N	2014-09-28 08:43:35	19	1	\N
990	2	3249	SM	NODATA	NODATA	\N	\N	\N	\N	19	0	\N
500	3	3250	RP	NODATA	NODATA	\N	\N	\N	\N	19	0	\N
570	5	3251	RP	NODATA	NODATA	\N	\N	\N	\N	19	0	\N
730	2	3252	SM	NODATA	NODATA	\N	\N	\N	2014-09-28 19:30:19	19	2	\N
380	5	3253	RP	NODATA	NODATA	\N	\N	\N	\N	19	0	\N
510	3	3254	RP	NODATA	NODATA	\N	\N	\N	\N	19	0	\N
10	3	3255	RP	NODATA	NODATA	\N	\N	\N	2014-09-28 17:28:26	19	3	\N
470	2	3256	SM	NODATA	NODATA	\N	\N	\N	\N	19	0	\N
30	2	3257	SM	NODATA	NODATA	\N	\N	\N	2014-09-28 18:35:42	19	2	\N
40	1	3258	SM	NODATA	NODATA	\N	\N	\N	2014-09-28 19:13:06	19	1	\N
130	8	3259	RP	NODATA	NODATA	\N	\N	\N	2014-09-28 17:58:17	19	8	\N
170	3	3260	RP	NODATA	NODATA	\N	\N	\N	2014-09-28 17:11:25	19	3	à la suite de la démission le 21 avril 2014 de M. Michel DOUBLET
280	3	3261	RP	NODATA	NODATA	\N	\N	\N	2014-09-28 17:14:05	19	3	\N
440	5	3262	RP	NODATA	NODATA	\N	\N	\N	\N	19	0	\N
520	2	3263	SM	NODATA	NODATA	\N	\N	\N	\N	19	0	\N
360	2	801	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
380	3	803	RP	NODATA	NODATA	\N	\N	\N	\N	11	3	\N
440	4	808	RP	NODATA	NODATA	\N	\N	\N	\N	11	4	\N
470	2	811	SM	NODATA	NODATA	\N	\N	\N	\N	11	2	\N
520	2	815	SM	NODATA	NODATA	\N	\N	\N	\N	11	2	\N
550	2	818	SM	NODATA	NODATA	\N	\N	\N	\N	11	2	\N
610	2	823	SM	NODATA	NODATA	\N	\N	\N	\N	11	2	\N
630	3	826	SM	NODATA	NODATA	\N	\N	\N	\N	11	3	\N
670	4	830	RP	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
690	5	832	RP	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
730	2	835	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
760	5	837	RP	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
775	5	839	RP	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
810	2	841	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
824	5	843	RP	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
830	3	845	RP	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
860	2	848	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
895	4	852	RP	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
972	2	854	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
974	2	856	SM	NODATA	NODATA	\N	\N	\N	\N	11	2	\N
984	1	859	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
999	2	863	RP	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
1012	1	865	NEANT	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
1026	3	867	NEANT	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
50	1	872	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
70	2	874	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
90	1	876	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
400	2	879	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
110	2	884	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
130	5	887	RP	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
170	3	891	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
240	2	896	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
265	5	899	RP	NODATA	NODATA	\N	\N	\N	\N	12	5	\N
290	4	902	RP	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
335	7	906	RP	NODATA	NODATA	\N	\N	\N	\N	12	7	\N
430	2	151	SM	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
998	2	201	RP	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
1011	1	205	NEANT	NODATA	NODATA	\N	\N	\N	\N	8	1	\N
1026	3	209	NEANT	NODATA	NODATA	\N	\N	\N	\N	8	3	\N
30	2	213	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
80	2	217	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
400	2	221	SM	NODATA	NODATA	\N	\N	\N	\N	9	2	\N
700	2	224	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
125	1	228	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
680	3	279	RP	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
840	2	291	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
880	2	295	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
983	1	303	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
982	1	360	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
995	1	364	SM	NODATA	NODATA	\N	\N	\N	\N	12	1	\N
550	2	431	SM	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
590	9	435	RP	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
670	4	443	RP	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
770	4	451	RP	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
170	3	503	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
260	2	511	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
290	4	515	RP	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
335	7	519	RP	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
370	3	523	SM	NODATA	NODATA	\N	\N	\N	\N	14	3	\N
420	4	527	RP	NODATA	NODATA	\N	\N	\N	\N	14	4	\N
320	2	578	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
350	3	582	RP	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
390	2	586	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
440	4	590	RP	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
480	1	594	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
40	1	654	SM	NODATA	NODATA	\N	\N	\N	\N	10	1	\N
80	2	658	SM	NODATA	NODATA	\N	\N	\N	\N	10	2	\N
700	2	665	SM	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
160	2	673	SM	NODATA	NODATA	\N	\N	\N	\N	10	2	\N
210	2	677	SM	NODATA	NODATA	\N	\N	\N	\N	10	2	\N
870	2	740	SM	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
971	2	744	SM	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
997	2	752	RP	NODATA	NODATA	\N	\N	\N	\N	10	2	\N
410	2	805	SM	NODATA	NODATA	\N	\N	\N	\N	11	2	\N
450	2	809	SM	NODATA	NODATA	\N	\N	\N	\N	11	2	\N
460	2	910	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
480	1	912	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
510	3	914	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
530	2	916	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
550	2	918	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
580	2	921	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
610	2	923	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
620	7	925	RP	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
660	2	929	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
690	7	932	RP	NODATA	NODATA	\N	\N	\N	\N	6	7	\N
720	3	934	SM	NODATA	NODATA	\N	\N	\N	\N	6	3	\N
770	6	938	RP	NODATA	NODATA	\N	\N	\N	\N	6	6	\N
790	2	940	SM	NODATA	NODATA	\N	\N	\N	\N	6	2	\N
824	6	943	RP	NODATA	NODATA	\N	\N	\N	\N	6	6	\N
830	4	945	RP	NODATA	NODATA	\N	\N	\N	\N	6	4	\N
870	2	949	SM	NODATA	NODATA	\N	\N	\N	\N	6	2	\N
890	2	951	SM	NODATA	NODATA	\N	\N	\N	\N	6	2	\N
971	3	953	SM	NODATA	NODATA	\N	\N	\N	\N	6	3	\N
974	3	956	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
997	4	962	RP	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
1051	2	964	RP	NODATA	NODATA	\N	\N	\N	\N	6	2	\N
20	3	967	SM	NODATA	NODATA	\N	\N	\N	\N	1	3	\N
90	1	974	SM	NODATA	NODATA	\N	\N	\N	\N	1	1	\N
200	1	976	SM	NODATA	NODATA	\N	\N	\N	\N	1	1	\N
600	3	980	SM	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
110	2	983	SM	NODATA	NODATA	\N	\N	\N	\N	1	2	\N
130	8	986	RP	NODATA	NODATA	\N	\N	\N	\N	1	8	\N
150	2	988	SM	NODATA	NODATA	\N	\N	\N	\N	1	2	\N
170	3	990	SM	NODATA	NODATA	\N	\N	\N	\N	1	3	\N
190	2	992	SM	NODATA	NODATA	\N	\N	\N	\N	1	2	\N
220	3	995	SM	NODATA	NODATA	\N	\N	\N	\N	1	3	\N
240	2	997	SM	NODATA	NODATA	\N	\N	\N	\N	1	2	\N
260	3	999	SM	NODATA	NODATA	\N	\N	\N	\N	1	3	\N
270	3	1001	SM	NODATA	NODATA	\N	\N	\N	\N	1	3	\N
330	6	1006	RP	NODATA	NODATA	\N	\N	\N	\N	1	6	\N
340	4	1008	SM	NODATA	NODATA	\N	\N	\N	\N	1	4	\N
360	2	1010	SM	NODATA	NODATA	\N	\N	\N	\N	1	2	\N
380	4	1012	RP	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
430	2	1016	SM	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
460	2	1019	SM	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
480	1	1021	SM	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
510	3	1023	SM	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
550	2	1027	SM	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
580	2	1030	SM	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
610	2	1032	SM	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
650	2	1037	SM	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
680	4	1040	RP	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
730	2	1044	SM	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
760	6	1046	RP	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
824	6	1052	RP	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
830	4	1054	RP	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
860	2	1057	SM	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
895	6	1061	RP	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
973	2	1064	SM	NODATA	NODATA	\N	\N	\N	\N	1	2	\N
982	1	1066	SM	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
984	1	1068	SM	NODATA	NODATA	\N	\N	\N	\N	1	1	\N
995	1	1070	SM	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
998	4	1072	RP	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
200	1	1077	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
20	3	1079	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
40	1	1081	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
997	4	3264	RP	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
530	2	3266	SM	NODATA	NODATA	\N	\N	2014-08-22 00:00:00	2014-09-28 12:34:20	21	1	à la suite de la démission le 30 juin 2014 de M. Jean ARTHUIS
580	2	3286	SM	CELINT	CELINT	530	742	\N	2017-09-24 19:31:54	22	2	\N
660	2	3287	SM	CELINT	CELINT	529	731	\N	2017-09-24 18:49:56	22	2	\N
770	6	3288	RP	CELINT	NODATA	694	\N	\N	2017-09-24 17:18:03	22	6	\N
140	3	3223	RP	NODATA	NODATA	\N	\N	\N	2014-09-28 16:43:37	19	3	\N
9713	1	3446	SM	SEANCE	NODATA	801	\N	2020-09-08 17:49:24	\N	24	1	\N
250	3	3447	RP	SEANCE	NODATA	823	\N	2020-09-08 17:49:24	\N	24	3	\N
974	4	3292	RP	CELINT	NODATA	629	\N	\N	2017-09-24 16:24:50	22	4	\N
80	2	3448	SM	SEANCE	SEANCE	784	817	2020-09-08 17:49:24	\N	24	2	\N
995	1	3294	SM	CELINT	CELINT	609	750	\N	2017-09-25 10:56:48	22	1	\N
350	4	3449	RP	SEANCE	NODATA	834	\N	2020-09-08 17:49:24	\N	24	4	\N
335	7	3296	RP	CELINT	NODATA	740	\N	\N	2017-09-24 19:25:10	22	7	\N
530	2	3297	SM	CELINT	CELINT	509	730	\N	2017-09-24 18:44:44	22	2	\N
650	2	3298	SM	CELINT	CELINT	349	712	\N	2017-09-24 18:27:44	22	2	\N
740	3	3450	RP	SEANCE	NODATA	833	\N	2020-09-08 17:49:24	\N	24	3	\N
640	3	3302	RP	CELINT	NODATA	669	\N	\N	2017-09-24 16:45:26	22	3	\N
824	6	3308	RP	CELINT	NODATA	703	\N	\N	2017-09-24 17:55:12	22	6	\N
60	5	1083	RP	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
200	1	1088	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
400	2	1090	SM	NODATA	NODATA	\N	\N	\N	\N	18	2	\N
600	4	1092	RP	NODATA	NODATA	\N	\N	\N	\N	18	4	\N
125	1	1097	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
140	3	1099	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
160	2	1101	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
190	2	1104	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
230	2	1108	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
260	3	1111	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
280	3	1114	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
330	6	1118	RP	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
370	3	1123	SM	NODATA	NODATA	\N	\N	\N	\N	18	3	\N
410	2	1126	SM	NODATA	NODATA	\N	\N	\N	\N	18	2	\N
430	2	1128	SM	NODATA	NODATA	\N	\N	\N	\N	18	2	\N
460	2	1131	SM	NODATA	NODATA	\N	\N	\N	\N	18	2	\N
510	3	1135	SM	NODATA	NODATA	\N	\N	\N	\N	18	3	\N
530	2	1137	SM	NODATA	NODATA	\N	\N	\N	\N	18	2	\N
550	2	1139	SM	NODATA	NODATA	\N	\N	\N	\N	18	2	\N
570	5	1141	RP	NODATA	NODATA	\N	\N	\N	\N	18	5	\N
590	11	1143	RP	NODATA	NODATA	\N	\N	\N	\N	18	11	\N
620	7	1146	RP	NODATA	NODATA	\N	\N	\N	\N	18	7	\N
640	3	1148	SM	NODATA	NODATA	\N	\N	\N	\N	18	3	\N
660	2	1150	SM	NODATA	NODATA	\N	\N	\N	\N	18	2	\N
680	4	1152	RP	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
710	3	1154	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
730	2	1156	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
770	6	1159	RP	NODATA	NODATA	\N	\N	\N	\N	18	6	\N
790	2	1161	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
820	2	1163	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
828	5	1165	RP	NODATA	NODATA	\N	\N	\N	\N	18	5	\N
840	3	1167	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
870	2	1170	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
890	2	1172	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
971	3	1174	SM	NODATA	NODATA	\N	\N	\N	\N	18	3	\N
982	2	1178	SM	NODATA	NODATA	\N	\N	\N	\N	18	2	\N
990	2	1181	SM	NODATA	NODATA	\N	\N	\N	\N	18	2	\N
9715	1	1188	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
470	2	1191	SM	NODATA	NODATA	\N	\N	\N	\N	14	2	\N
490	3	1193	SM	NODATA	NODATA	\N	\N	\N	\N	14	3	\N
570	5	1200	RP	NODATA	NODATA	\N	\N	\N	\N	14	5	\N
610	2	1203	SM	NODATA	NODATA	\N	\N	\N	\N	14	2	\N
620	7	1205	RP	NODATA	NODATA	\N	\N	\N	\N	14	7	\N
710	3	1213	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
730	2	1215	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
760	6	1217	RP	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
775	6	1219	RP	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
810	2	1221	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
824	6	1223	RP	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
840	2	1226	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
880	2	1230	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
895	5	1232	RP	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
972	2	1234	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
982	1	1237	SM	NODATA	NODATA	\N	\N	\N	\N	14	1	\N
995	1	1241	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
998	4	1243	RP	NODATA	NODATA	\N	\N	\N	\N	14	4	\N
1026	3	1245	NEANT	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
30	2	1248	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
70	2	1252	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
90	1	1254	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
300	3	1257	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
800	3	1262	SM	NODATA	NODATA	\N	\N	\N	\N	15	3	\N
125	1	1265	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
160	2	1269	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
190	2	1272	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
250	3	1277	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
270	3	1280	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
320	2	1284	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
335	7	1286	RP	NODATA	NODATA	\N	\N	\N	\N	15	7	\N
350	4	1288	RP	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
380	4	1291	RP	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
410	2	1293	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
430	2	1295	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
450	3	1297	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
470	2	1299	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
510	3	1302	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
530	2	1304	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
550	2	1306	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
590	11	1310	RP	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
620	7	1313	RP	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
640	3	1315	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
680	3	1319	RP	NODATA	NODATA	\N	\N	\N	\N	15	3	\N
710	3	1321	SM	NODATA	NODATA	\N	\N	\N	\N	15	3	\N
730	2	1323	SM	NODATA	NODATA	\N	\N	\N	\N	15	2	\N
770	4	1326	RP	NODATA	NODATA	\N	\N	\N	\N	15	4	\N
820	2	1330	SM	NODATA	NODATA	\N	\N	\N	\N	15	2	\N
828	4	1332	RP	NODATA	NODATA	\N	\N	\N	\N	15	4	\N
840	2	1334	SM	NODATA	NODATA	\N	\N	\N	\N	15	2	\N
870	2	1337	SM	NODATA	NODATA	\N	\N	\N	\N	15	2	\N
972	2	1342	SM	NODATA	NODATA	\N	\N	\N	\N	15	2	\N
982	1	1345	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
990	1	1348	SM	NODATA	NODATA	\N	\N	\N	\N	15	1	\N
10	2	1354	SM	NODATA	NODATA	\N	\N	\N	\N	16	2	\N
40	1	1357	SM	NODATA	NODATA	\N	\N	\N	\N	16	1	\N
70	2	1360	SM	NODATA	NODATA	\N	\N	\N	\N	16	2	\N
100	2	1363	SM	NODATA	NODATA	\N	\N	\N	\N	16	2	\N
400	2	1366	SM	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
600	3	1368	SM	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
800	3	1370	SM	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
120	2	1372	SM	NODATA	NODATA	\N	\N	\N	\N	16	2	\N
130	7	1374	RP	NODATA	NODATA	\N	\N	\N	\N	16	7	\N
160	2	1377	SM	NODATA	NODATA	\N	\N	\N	\N	16	2	\N
180	2	1379	SM	NODATA	NODATA	\N	\N	\N	\N	16	2	\N
205	1	1381	SM	NODATA	NODATA	\N	\N	\N	\N	16	1	\N
240	2	1385	SM	NODATA	NODATA	\N	\N	\N	\N	16	2	\N
265	5	1388	RP	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
280	2	1390	SM	NODATA	NODATA	\N	\N	\N	\N	16	2	\N
330	5	1394	RP	NODATA	NODATA	\N	\N	\N	\N	16	5	\N
340	3	1396	SM	NODATA	NODATA	\N	\N	\N	\N	16	3	\N
370	3	1399	SM	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
390	2	1401	SM	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
440	5	1405	RP	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
460	2	1407	SM	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
490	3	1410	SM	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
520	2	1412	SM	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
570	5	1417	RP	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
610	2	1420	SM	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
630	3	1423	SM	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
690	7	1429	RP	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
730	2	1432	SM	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
770	4	1435	RP	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
810	2	1438	SM	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
828	4	1441	RP	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
840	2	1443	SM	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
860	2	1445	SM	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
880	2	1447	SM	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
895	5	1449	RP	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
973	1	1452	SM	NODATA	NODATA	\N	\N	\N	\N	16	1	\N
982	1	1454	SM	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
995	1	1458	SM	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
998	4	1460	RP	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
10	2	1462	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
40	1	1465	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
80	2	1469	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
200	1	1472	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
400	2	1474	SM	NODATA	NODATA	\N	\N	\N	\N	2	2	\N
70	2	3451	SM	SEANCE	NODATA	785	\N	2020-09-08 17:49:24	\N	24	2	\N
240	2	3452	SM	SEANCE	SEANCE	790	811	2020-09-08 17:49:24	\N	24	2	\N
60	5	3453	RP	SEANCE	NODATA	846	\N	2020-09-08 17:49:24	\N	24	5	\N
90	1	3454	SM	SEANCE	NODATA	776	\N	2020-09-08 17:49:24	\N	24	1	\N
110	2	3455	SM	SEANCE	NODATA	798	\N	2020-09-08 17:49:24	\N	24	2	\N
150	2	3456	SM	SEANCE	SEANCE	781	810	2020-09-08 17:49:24	\N	24	2	\N
160	2	3457	SM	SEANCE	SEANCE	789	807	2020-09-08 17:49:24	\N	24	2	\N
180	2	3458	SM	SEANCE	NODATA	791	\N	2020-09-08 17:49:24	\N	24	2	\N
630	3	3319	RP	CELINT	NODATA	709	\N	\N	2017-09-24 18:20:09	22	3	\N
190	2	3459	SM	SEANCE	NODATA	782	\N	2020-09-08 17:49:24	\N	24	2	\N
210	3	3460	RP	SEANCE	NODATA	828	\N	2020-09-08 17:49:24	\N	24	3	\N
230	2	3461	SM	SEANCE	SEANCE	796	822	2020-09-08 17:49:24	\N	24	2	\N
300	3	3462	RP	SEANCE	NODATA	832	\N	2020-09-08 17:49:24	\N	24	3	\N
390	2	3324	SM	CELINT	CELINT	549	741	\N	2017-09-24 19:26:20	22	2	\N
610	2	3325	SM	CELINT	CELINT	589	738	\N	2017-09-24 19:17:41	22	2	\N
320	2	3463	SM	SEANCE	SEANCE	788	806	2020-09-08 17:49:24	\N	24	2	\N
330	6	3464	RP	SEANCE	NODATA	847	\N	2020-09-08 17:49:24	\N	24	6	\N
360	2	3465	SM	SEANCE	SEANCE	779	808	2020-09-08 17:49:24	\N	24	2	\N
20	3	3466	RP	SEANCE	NODATA	843	\N	2020-09-08 17:49:24	\N	24	3	\N
265	5	3335	RP	CELINT	NODATA	704	\N	\N	2017-09-24 18:05:40	22	5	\N
800	3	1478	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
125	1	1481	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
140	3	1483	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
170	3	1486	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
220	3	1491	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
250	3	1494	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
280	2	1498	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
335	7	1503	RP	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
350	4	1505	RP	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
380	4	1508	RP	NODATA	NODATA	\N	\N	\N	\N	2	4	\N
430	2	1512	SM	NODATA	NODATA	\N	\N	\N	\N	2	2	\N
450	3	1514	SM	NODATA	NODATA	\N	\N	\N	\N	2	3	\N
470	2	1516	SM	NODATA	NODATA	\N	\N	\N	\N	2	2	\N
490	3	1518	SM	NODATA	NODATA	\N	\N	\N	\N	2	3	\N
520	2	1520	SM	NODATA	NODATA	\N	\N	\N	\N	2	2	\N
540	4	1522	RP	NODATA	NODATA	\N	\N	\N	\N	2	4	\N
570	5	1525	RP	NODATA	NODATA	\N	\N	\N	\N	2	5	\N
590	11	1527	RP	NODATA	NODATA	\N	\N	\N	\N	2	11	\N
615	12	1529	RP	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
650	2	1533	SM	NODATA	NODATA	\N	\N	\N	\N	2	2	\N
680	3	1536	RP	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
710	3	1538	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
760	6	1542	RP	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
775	6	1544	RP	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
820	2	1547	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
828	4	1549	RP	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
860	2	1553	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
880	2	1555	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
895	5	1557	RP	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
973	1	1560	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
995	1	1566	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
998	4	1568	RP	NODATA	NODATA	\N	\N	\N	\N	2	4	\N
20	3	1571	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
90	1	1578	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
200	1	1580	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
600	3	1584	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
110	2	1587	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
130	7	1590	RP	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
150	2	1592	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
170	3	1594	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
190	2	1596	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
220	3	1599	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
240	2	1601	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
260	2	1603	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
270	3	1605	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
330	5	1610	RP	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
340	3	1612	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
360	2	1614	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
380	4	1616	RP	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
430	2	1620	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
460	2	1623	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
480	1	1625	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
510	3	1627	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
550	2	1631	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
580	2	1634	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
610	2	1636	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
650	2	1641	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
680	3	1644	RP	NODATA	NODATA	\N	\N	\N	\N	3	3	\N
730	2	1648	SM	NODATA	NODATA	\N	\N	\N	\N	3	2	\N
760	6	1650	RP	NODATA	NODATA	\N	\N	\N	\N	3	6	\N
824	6	1656	RP	NODATA	NODATA	\N	\N	\N	\N	3	6	\N
830	3	1658	RP	NODATA	NODATA	\N	\N	\N	\N	3	3	\N
860	2	1661	SM	NODATA	NODATA	\N	\N	\N	\N	3	2	\N
895	5	1665	RP	NODATA	NODATA	\N	\N	\N	\N	3	5	\N
973	1	1668	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
982	1	1670	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
984	1	1672	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
995	1	1674	SM	NODATA	NODATA	\N	\N	\N	\N	3	1	\N
998	4	1676	RP	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
20	3	1679	SM	NODATA	NODATA	\N	\N	\N	\N	4	3	\N
40	1	1681	SM	NODATA	NODATA	\N	\N	\N	\N	4	1	\N
80	2	1685	SM	NODATA	NODATA	\N	\N	\N	\N	4	2	\N
200	1	1688	SM	NODATA	NODATA	\N	\N	\N	\N	4	1	\N
400	2	1690	SM	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
800	3	1694	SM	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
125	1	1697	SM	NODATA	NODATA	\N	\N	\N	\N	4	1	\N
140	3	1699	SM	NODATA	NODATA	\N	\N	\N	\N	4	3	\N
160	2	1701	SM	NODATA	NODATA	\N	\N	\N	\N	4	2	\N
205	1	1705	SM	NODATA	NODATA	\N	\N	\N	\N	4	1	\N
230	2	1708	SM	NODATA	NODATA	\N	\N	\N	\N	4	2	\N
250	3	1710	SM	NODATA	NODATA	\N	\N	\N	\N	4	3	\N
265	5	1712	RP	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
330	5	1718	RP	NODATA	NODATA	\N	\N	\N	\N	4	5	\N
360	2	1722	SM	NODATA	NODATA	\N	\N	\N	\N	4	2	\N
380	4	1724	RP	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
450	3	1730	SM	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
470	2	1732	SM	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
510	3	1735	SM	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
550	2	1739	SM	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
570	5	1741	RP	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
590	11	1743	RP	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
615	12	1745	RP	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
630	3	1747	SM	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
650	2	1749	SM	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
680	3	1752	RP	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
710	3	1754	SM	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
730	2	1756	SM	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
775	6	1760	RP	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
820	2	1763	SM	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
828	4	1765	RP	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
860	2	1769	SM	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
880	2	1771	SM	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
971	2	1774	SM	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
973	1	1776	SM	NODATA	NODATA	\N	\N	\N	\N	4	1	\N
984	1	1780	SM	NODATA	NODATA	\N	\N	\N	\N	4	1	\N
995	1	1782	SM	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
998	4	1784	RP	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
20	3	1787	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
80	2	1793	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
100	2	1795	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
700	2	1800	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
130	7	1805	RP	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
160	2	1808	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
205	1	1812	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
220	3	1814	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
250	3	1817	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
265	5	1819	RP	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
280	2	1821	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
310	4	1823	RP	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
335	7	1826	RP	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
350	4	1828	RP	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
370	3	1830	SM	NODATA	NODATA	\N	\N	\N	\N	5	3	\N
390	2	1832	SM	NODATA	NODATA	\N	\N	\N	\N	5	2	\N
450	3	1837	SM	NODATA	NODATA	\N	\N	\N	\N	5	3	\N
470	2	1839	SM	NODATA	NODATA	\N	\N	\N	\N	5	2	\N
490	3	1841	SM	NODATA	NODATA	\N	\N	\N	\N	5	3	\N
520	2	1843	SM	NODATA	NODATA	\N	\N	\N	\N	5	2	\N
560	3	1847	SM	NODATA	NODATA	\N	\N	\N	\N	5	3	\N
590	11	1850	RP	NODATA	NODATA	\N	\N	\N	\N	5	11	\N
615	12	1852	RP	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
630	3	1854	SM	NODATA	NODATA	\N	\N	\N	\N	5	3	\N
670	4	1858	RP	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
710	3	1861	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
730	2	1863	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
790	2	1868	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
824	6	1871	RP	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
290	4	3467	RP	SEANCE	NODATA	838	\N	2020-09-08 17:49:24	\N	24	4	\N
690	7	3468	RP	SEANCE	NODATA	845	\N	2020-09-08 17:49:24	\N	24	7	\N
760	6	3469	RP	SEANCE	NODATA	848	\N	2020-09-08 17:49:24	\N	24	6	\N
120	2	3470	SM	SEANCE	NODATA	799	\N	2020-09-08 17:49:24	\N	24	2	\N
140	3	3471	RP	SEANCE	NODATA	813	\N	2020-09-08 17:49:24	\N	24	3	\N
870	2	3472	SM	SEANCE	SEANCE	792	829	2020-09-08 17:49:24	\N	24	2	\N
1054	6	3473	RP	NODATA	NODATA	\N	\N	2020-09-08 17:49:24	\N	24	6	\N
670	5	3474	RP	SEANCE	NODATA	836	\N	2020-09-08 17:49:24	\N	24	5	\N
680	4	3475	RP	SEANCE	NODATA	844	\N	2020-09-08 17:49:24	\N	24	4	\N
700	2	3476	SM	SEANCE	SEANCE	786	816	2020-09-08 17:49:24	\N	24	2	\N
810	2	3477	SM	SEANCE	SEANCE	794	827	2020-09-08 17:49:24	\N	24	2	\N
830	4	3478	RP	SEANCE	NODATA	826	\N	2020-09-08 17:49:24	\N	24	4	\N
840	3	3479	RP	SEANCE	NODATA	830	\N	2020-09-08 17:49:24	\N	24	3	\N
850	3	3480	RP	SEANCE	NODATA	831	\N	2020-09-08 17:49:24	\N	24	3	\N
880	2	3481	SM	SEANCE	SEANCE	795	812	2020-09-08 17:49:24	\N	24	2	\N
984	1	3482	SM	SEANCE	SEANCE	769	775	2020-09-08 17:49:24	\N	24	1	\N
730	2	3483	SM	SEANCE	SEANCE	797	818	2020-09-08 17:49:24	\N	24	2	\N
10	3	3484	RP	SEANCE	NODATA	835	\N	2020-09-08 17:49:24	\N	24	3	\N
30	2	3485	SM	SEANCE	NODATA	777	\N	2020-09-08 17:49:24	\N	24	2	\N
40	1	3486	SM	SEANCE	NODATA	778	\N	2020-09-08 17:49:24	\N	24	1	\N
850	3	1875	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
870	2	1877	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
973	1	1883	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
982	1	1885	SM	NODATA	NODATA	\N	\N	\N	\N	5	1	\N
20	3	2	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
50	1	4	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
80	2	7	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
100	2	9	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
500	3	12	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
700	2	14	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
110	2	16	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
130	5	19	RP	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
170	3	23	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
190	2	25	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
240	2	28	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
280	2	32	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
310	3	34	RP	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
340	3	37	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
360	2	39	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
410	2	43	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
440	4	46	RP	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
460	1	48	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
520	2	53	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
540	3	55	RP	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
560	3	57	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
580	2	59	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
630	3	64	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
670	4	67	RP	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
690	5	69	RP	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
790	2	76	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
820	2	78	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
840	2	80	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
870	2	83	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
890	2	85	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
971	2	87	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
973	1	89	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
983	1	92	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
1002	2	96	NEANT	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
1012	1	99	NEANT	NODATA	NODATA	\N	\N	\N	\N	7	1	\N
1021	1	101	NEANT	NODATA	NODATA	\N	\N	\N	\N	7	1	\N
1026	3	103	NEANT	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
20	3	107	SM	NODATA	NODATA	\N	\N	\N	\N	8	3	\N
60	3	110	RP	NODATA	NODATA	\N	\N	\N	\N	8	3	\N
80	2	112	SM	NODATA	NODATA	\N	\N	\N	\N	8	2	\N
100	2	114	SM	NODATA	NODATA	\N	\N	\N	\N	8	2	\N
700	2	119	SM	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
110	2	121	SM	NODATA	NODATA	\N	\N	\N	\N	8	2	\N
125	1	123	SM	NODATA	NODATA	\N	\N	\N	\N	8	1	\N
170	3	128	SM	NODATA	NODATA	\N	\N	\N	\N	8	3	\N
190	2	130	SM	NODATA	NODATA	\N	\N	\N	\N	8	2	\N
240	2	133	SM	NODATA	NODATA	\N	\N	\N	\N	8	2	\N
270	3	136	SM	NODATA	NODATA	\N	\N	\N	\N	8	3	\N
335	1	142	RP	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
360	2	145	SM	NODATA	NODATA	\N	\N	\N	\N	8	2	\N
390	1	148	SM	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
420	5	150	RP	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
460	1	154	SM	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
480	1	156	SM	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
510	3	158	SM	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
530	2	160	SM	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
560	3	163	SM	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
580	2	165	SM	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
610	2	167	SM	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
650	2	171	SM	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
670	4	173	RP	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
710	3	176	SM	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
760	5	180	RP	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
790	2	182	SM	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
820	2	184	SM	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
850	2	187	SM	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
890	2	191	SM	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
971	2	193	SM	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
973	1	195	SM	NODATA	NODATA	\N	\N	\N	\N	8	1	\N
983	1	198	SM	NODATA	NODATA	\N	\N	\N	\N	8	1	\N
1002	2	203	NEANT	NODATA	NODATA	\N	\N	\N	\N	8	2	\N
1012	1	206	NEANT	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
1025	1	208	NEANT	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
60	3	215	RP	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
90	1	218	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
300	2	220	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
800	3	225	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
140	3	230	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
160	2	232	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
180	2	234	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
210	2	236	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
250	3	239	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
270	2	241	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
290	4	243	RP	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
320	2	245	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
350	3	249	RP	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
380	3	252	RP	NODATA	NODATA	\N	\N	\N	\N	9	3	\N
410	2	254	SM	NODATA	NODATA	\N	\N	\N	\N	9	2	\N
430	2	256	SM	NODATA	NODATA	\N	\N	\N	\N	9	2	\N
470	2	260	SM	NODATA	NODATA	\N	\N	\N	\N	9	2	\N
510	3	263	SM	NODATA	NODATA	\N	\N	\N	\N	9	3	\N
530	2	265	SM	NODATA	NODATA	\N	\N	\N	\N	9	2	\N
550	2	267	SM	NODATA	NODATA	\N	\N	\N	\N	9	2	\N
590	9	271	RP	NODATA	NODATA	\N	\N	\N	\N	9	9	\N
620	6	274	RP	NODATA	NODATA	\N	\N	\N	\N	9	6	\N
650	2	276	SM	NODATA	NODATA	\N	\N	\N	\N	9	2	\N
710	3	281	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
740	2	284	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
770	3	286	RP	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
830	3	290	RP	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
890	2	296	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
971	2	298	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
974	2	301	SM	NODATA	NODATA	\N	\N	\N	\N	9	2	\N
370	2	305	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
410	2	308	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
430	2	310	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
450	2	312	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
470	2	314	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
490	3	316	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
530	2	319	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
550	2	321	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
590	9	325	RP	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
615	12	327	RP	NODATA	NODATA	\N	\N	\N	\N	12	12	\N
640	3	330	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
660	2	332	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
710	3	336	SM	NODATA	NODATA	\N	\N	\N	\N	12	3	\N
730	2	338	SM	NODATA	NODATA	\N	\N	\N	\N	12	2	\N
760	6	340	RP	NODATA	NODATA	\N	\N	\N	\N	12	6	\N
790	2	343	SM	NODATA	NODATA	\N	\N	\N	\N	12	2	\N
828	4	347	RP	NODATA	NODATA	\N	\N	\N	\N	12	4	\N
840	2	349	SM	NODATA	NODATA	\N	\N	\N	\N	12	2	\N
860	2	351	SM	NODATA	NODATA	\N	\N	\N	\N	12	2	\N
972	2	357	SM	NODATA	NODATA	\N	\N	\N	\N	12	2	\N
974	2	359	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
984	1	362	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
997	2	365	RP	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
10	2	371	SM	NODATA	NODATA	\N	\N	\N	\N	13	2	\N
40	1	374	SM	NODATA	NODATA	\N	\N	\N	\N	13	1	\N
70	2	377	SM	NODATA	NODATA	\N	\N	\N	\N	13	2	\N
100	2	380	SM	NODATA	NODATA	\N	\N	\N	\N	13	2	\N
400	2	383	SM	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
600	3	385	SM	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
800	2	387	SM	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
983	2	3158	SM	NODATA	NODATA	\N	\N	2014-09-16 00:00:00	2014-09-29 09:09:53	19	2	à la suite de la déchéance de plein droit de sa qualité de membre du Sénat le 16 septembre 2014 de M. Gaston FLOSSE
130	8	3487	RP	SEANCE	NODATA	839	\N	2020-09-08 17:49:24	\N	24	8	\N
170	3	3488	RP	SEANCE	NODATA	821	\N	2020-09-08 17:49:24	\N	24	3	\N
280	3	3489	RP	SEANCE	NODATA	824	\N	2020-09-08 17:49:24	\N	24	3	\N
120	2	389	SM	NODATA	NODATA	\N	\N	\N	\N	13	2	\N
130	7	391	RP	NODATA	NODATA	\N	\N	\N	\N	13	7	\N
160	2	394	SM	NODATA	NODATA	\N	\N	\N	\N	13	2	\N
180	2	396	SM	NODATA	NODATA	\N	\N	\N	\N	13	2	\N
260	2	30	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
380	3	41	RP	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
480	1	50	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
615	4	62	RP	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
740	2	73	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
998	1	94	RP	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
1030	1	105	NEANT	NODATA	NODATA	\N	\N	\N	\N	7	1	\N
500	3	117	SM	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
140	3	125	SM	NODATA	NODATA	\N	\N	\N	\N	8	3	\N
290	4	138	RP	NODATA	NODATA	\N	\N	\N	\N	8	4	\N
620	6	169	RP	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
730	2	178	SM	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
870	2	189	SM	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
995	1	200	SM	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
10	2	211	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
120	2	227	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
335	1	247	RP	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
450	2	258	SM	NODATA	NODATA	\N	\N	\N	\N	9	2	\N
570	4	269	RP	NODATA	NODATA	\N	\N	\N	\N	9	4	\N
670	4	278	RP	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
860	2	293	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
570	4	323	RP	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
680	3	334	RP	NODATA	NODATA	\N	\N	\N	\N	12	3	\N
820	2	345	SM	NODATA	NODATA	\N	\N	\N	\N	12	2	\N
890	2	354	SM	NODATA	NODATA	\N	\N	\N	\N	12	2	\N
1012	1	369	NEANT	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
230	2	400	SM	NODATA	NODATA	\N	\N	\N	\N	13	2	\N
320	2	409	SM	NODATA	NODATA	\N	\N	\N	\N	13	2	\N
430	2	420	SM	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
560	3	432	SM	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
680	3	444	RP	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
990	1	473	SM	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
60	4	484	RP	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
600	3	493	SM	NODATA	NODATA	\N	\N	\N	\N	14	3	\N
190	2	505	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
320	2	517	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
30	2	545	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
700	2	556	SM	NODATA	NODATA	\N	\N	\N	\N	17	2	\N
170	3	565	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
580	2	1849	SM	NODATA	NODATA	\N	\N	\N	\N	5	2	\N
610	2	1851	SM	NODATA	NODATA	\N	\N	\N	\N	5	2	\N
620	7	1853	RP	NODATA	NODATA	\N	\N	\N	\N	5	7	\N
640	3	1855	SM	NODATA	NODATA	\N	\N	\N	\N	5	3	\N
660	2	1857	SM	NODATA	NODATA	\N	\N	\N	\N	5	2	\N
680	3	1859	RP	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
690	7	1860	RP	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
720	3	1862	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
740	3	1864	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
775	6	1867	RP	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
810	2	1869	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
828	4	1872	RP	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
830	3	1873	RP	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
860	2	1876	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
890	2	1879	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
971	2	1881	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
974	3	1884	SM	NODATA	NODATA	\N	\N	\N	\N	5	3	\N
984	1	1887	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
995	1	1889	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
999	4	1892	RP	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
20	3	1894	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
40	1	1896	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
60	4	1898	RP	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
70	2	1899	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
90	1	1901	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
200	1	1903	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
400	2	1905	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
600	3	1907	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
700	2	1908	SM	NODATA	NODATA	\N	\N	\N	\N	6	2	\N
110	2	1910	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
125	1	1912	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
140	3	1914	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
160	2	1916	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
180	2	1918	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
190	2	1919	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
210	3	1921	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
230	2	1923	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
250	3	1925	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
265	5	1927	RP	NODATA	NODATA	\N	\N	\N	\N	6	5	\N
280	2	1929	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
290	4	1930	RP	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
320	2	1932	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
335	7	1934	RP	NODATA	NODATA	\N	\N	\N	\N	6	7	\N
350	4	1936	RP	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
370	3	1938	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
390	2	1940	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
420	4	1942	RP	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
430	2	1943	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
650	2	65	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
210	2	131	SM	NODATA	NODATA	\N	\N	\N	\N	8	2	\N
310	3	139	RP	NODATA	NODATA	\N	\N	\N	\N	8	3	\N
110	2	1263	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
230	2	1275	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
310	4	1283	RP	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
984	1	1347	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
20	3	1355	SM	NODATA	NODATA	\N	\N	\N	\N	16	3	\N
580	2	1418	SM	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
660	2	1426	SM	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
160	2	1485	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
700	2	1585	SM	NODATA	NODATA	\N	\N	\N	\N	3	2	\N
670	4	1643	RP	NODATA	NODATA	\N	\N	\N	\N	3	4	\N
770	4	1651	RP	NODATA	NODATA	\N	\N	\N	\N	3	4	\N
880	2	1663	SM	NODATA	NODATA	\N	\N	\N	\N	3	2	\N
320	2	1717	SM	NODATA	NODATA	\N	\N	\N	\N	4	2	\N
440	5	1729	RP	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
530	2	1737	SM	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
300	3	1796	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
983	1	1886	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
982	1	957	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
40	1	969	SM	NODATA	NODATA	\N	\N	\N	\N	1	1	\N
300	3	977	SM	NODATA	NODATA	\N	\N	\N	\N	1	3	\N
630	3	1035	SM	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
720	3	1043	SM	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
840	3	1055	SM	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
240	2	1109	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
350	4	1121	RP	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
290	4	576	RP	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
450	2	591	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
580	2	603	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
810	2	622	SM	NODATA	NODATA	\N	\N	\N	\N	17	2	\N
895	4	633	RP	NODATA	NODATA	\N	\N	\N	\N	17	4	\N
997	2	642	RP	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
30	2	653	SM	NODATA	NODATA	\N	\N	\N	\N	10	2	\N
120	2	668	SM	NODATA	NODATA	\N	\N	\N	\N	10	2	\N
250	2	680	SM	NODATA	NODATA	\N	\N	\N	\N	10	2	\N
450	2	700	SM	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
570	4	711	RP	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
680	3	722	RP	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
790	2	731	SM	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
973	1	746	SM	NODATA	NODATA	\N	\N	\N	\N	10	1	\N
700	2	774	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
190	2	785	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
320	2	796	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
420	4	806	RP	NODATA	NODATA	\N	\N	\N	\N	11	4	\N
973	2	3156	SM	NODATA	NODATA	\N	\N	\N	2014-09-29 09:07:52	19	2	\N
570	4	820	RP	NODATA	NODATA	\N	\N	\N	\N	11	4	\N
880	2	850	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
997	2	861	RP	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
30	2	870	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
700	2	882	SM	NODATA	NODATA	\N	\N	\N	\N	12	2	\N
210	2	894	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
350	3	908	RP	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
730	2	283	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
20	3	372	SM	NODATA	NODATA	\N	\N	\N	\N	13	3	\N
530	2	598	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
810	2	732	SM	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
640	3	927	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
740	3	936	SM	NODATA	NODATA	\N	\N	\N	\N	6	3	\N
850	3	947	SM	NODATA	NODATA	\N	\N	\N	\N	6	3	\N
984	1	959	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
60	5	971	RP	NODATA	NODATA	\N	\N	\N	\N	1	5	\N
290	4	1003	RP	NODATA	NODATA	\N	\N	\N	\N	1	4	\N
410	2	1014	SM	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
530	2	1025	SM	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
620	7	1034	RP	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
790	2	1049	SM	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
1052	2	1074	RP	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
90	1	1086	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
110	2	1095	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
210	3	1106	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
340	4	1120	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
973	2	1176	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
540	4	1197	RP	NODATA	NODATA	\N	\N	\N	\N	14	4	\N
650	2	1208	SM	NODATA	NODATA	\N	\N	\N	\N	14	2	\N
860	2	1228	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
984	1	1239	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
50	1	1250	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
600	3	1260	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
210	3	1274	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
570	5	1308	RP	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
660	2	1317	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
790	2	1328	SM	NODATA	NODATA	\N	\N	\N	\N	15	2	\N
895	5	1340	RP	NODATA	NODATA	\N	\N	\N	\N	15	5	\N
999	4	1352	RP	NODATA	NODATA	\N	\N	\N	\N	15	4	\N
220	3	1383	SM	NODATA	NODATA	\N	\N	\N	\N	16	3	\N
310	4	1392	RP	NODATA	NODATA	\N	\N	\N	\N	16	4	\N
420	4	1403	RP	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
550	2	1415	SM	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
670	4	1427	RP	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
984	1	1456	SM	NODATA	NODATA	\N	\N	\N	\N	16	1	\N
60	4	1467	RP	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
600	3	1476	SM	NODATA	NODATA	\N	\N	\N	\N	2	3	\N
190	2	1488	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
310	4	1500	RP	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
630	3	1531	SM	NODATA	NODATA	\N	\N	\N	\N	2	3	\N
730	2	1540	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
840	2	1551	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
983	1	1563	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
60	4	1575	RP	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
290	4	1607	RP	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
410	2	1618	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
530	2	1629	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
620	7	1638	RP	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
790	2	1653	SM	NODATA	NODATA	\N	\N	\N	\N	3	2	\N
60	4	1683	RP	NODATA	NODATA	\N	\N	\N	\N	4	4	\N
600	3	1692	SM	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
180	2	1703	SM	NODATA	NODATA	\N	\N	\N	\N	4	2	\N
290	4	1715	RP	NODATA	NODATA	\N	\N	\N	\N	4	4	\N
420	4	1727	RP	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
760	6	1758	RP	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
840	2	1767	SM	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
982	1	1778	SM	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
50	1	1790	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
110	2	1802	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
420	4	1834	RP	NODATA	NODATA	\N	\N	\N	\N	5	4	\N
540	4	1845	RP	NODATA	NODATA	\N	\N	\N	\N	5	4	\N
650	2	1856	SM	NODATA	NODATA	\N	\N	\N	\N	5	2	\N
760	6	1865	RP	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
895	5	1880	RP	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
500	3	1906	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
170	3	1917	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
270	3	1928	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
360	2	1937	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
770	3	75	RP	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
998	4	1351	RP	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
10	2	543	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
300	3	1581	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
270	3	1713	SM	NODATA	NODATA	\N	\N	\N	\N	4	3	\N
880	2	1878	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
70	2	6	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
120	2	17	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
330	4	905	RP	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
670	5	1039	RP	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
9713	1	1187	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
450	3	1189	SM	NODATA	NODATA	\N	\N	\N	\N	14	3	\N
480	1	1192	SM	NODATA	NODATA	\N	\N	\N	\N	14	1	\N
520	2	1195	SM	NODATA	NODATA	\N	\N	\N	\N	14	2	\N
530	2	1196	SM	NODATA	NODATA	\N	\N	\N	\N	14	2	\N
560	3	1199	SM	NODATA	NODATA	\N	\N	\N	\N	14	3	\N
580	2	1201	SM	NODATA	NODATA	\N	\N	\N	\N	14	2	\N
615	12	1204	RP	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
640	3	1207	SM	NODATA	NODATA	\N	\N	\N	\N	14	3	\N
660	2	1209	SM	NODATA	NODATA	\N	\N	\N	\N	14	2	\N
680	3	1211	RP	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
690	7	1212	RP	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
720	3	1214	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
740	3	1216	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
770	4	1218	RP	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
790	2	1220	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
820	2	1222	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
828	4	1224	RP	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
830	3	1225	RP	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
850	3	1227	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
870	2	1229	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
890	2	1231	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
170	3	1809	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
180	2	1810	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
210	3	1813	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
240	2	1816	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
260	2	1818	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
270	3	1820	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
290	4	1822	RP	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
320	2	1824	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
330	5	1825	RP	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
340	3	1827	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
360	2	1829	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
380	4	1831	RP	NODATA	NODATA	\N	\N	\N	\N	5	4	\N
410	2	1833	SM	NODATA	NODATA	\N	\N	\N	\N	5	2	\N
430	2	1835	SM	NODATA	NODATA	\N	\N	\N	\N	5	2	\N
440	5	1836	RP	NODATA	NODATA	\N	\N	\N	\N	5	5	\N
460	2	1838	SM	NODATA	NODATA	\N	\N	\N	\N	5	2	\N
480	1	1840	SM	NODATA	NODATA	\N	\N	\N	\N	5	1	\N
510	3	1842	SM	NODATA	NODATA	\N	\N	\N	\N	5	3	\N
530	2	1844	SM	NODATA	NODATA	\N	\N	\N	\N	5	2	\N
550	2	1846	SM	NODATA	NODATA	\N	\N	\N	\N	5	2	\N
570	5	1848	RP	NODATA	NODATA	\N	\N	\N	\N	5	5	\N
971	2	1233	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
973	1	1235	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
974	3	1236	SM	NODATA	NODATA	\N	\N	\N	\N	14	3	\N
983	1	1238	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
1052	2	3265	RP	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
990	1	1240	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
997	2	1242	RP	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
999	2	1244	RP	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
10	2	1246	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
20	3	1247	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
40	1	1249	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
60	4	1251	RP	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
80	2	1253	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
100	2	1255	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
200	1	1256	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
400	2	1258	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
700	2	1261	SM	NODATA	NODATA	\N	\N	\N	\N	15	2	\N
120	2	1264	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
130	7	1266	RP	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
150	2	1268	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
170	3	1270	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
205	1	1273	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
240	2	1276	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
260	2	1278	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
280	2	1281	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
290	4	1282	RP	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
330	5	1285	RP	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
340	3	1287	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
360	2	1289	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
370	3	1290	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
390	2	1292	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
420	4	1294	RP	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
440	5	1296	RP	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
460	2	1298	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
480	1	1300	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
490	3	1301	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
520	2	1303	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
540	4	1305	RP	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
560	3	1307	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
580	2	1309	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
610	2	1311	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
615	12	1312	RP	NODATA	NODATA	\N	\N	\N	\N	15	12	\N
630	3	1314	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
650	2	1316	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
670	4	1318	RP	NODATA	NODATA	\N	\N	\N	\N	15	4	\N
690	7	1320	RP	NODATA	NODATA	\N	\N	\N	\N	15	7	\N
720	3	1322	SM	NODATA	NODATA	\N	\N	\N	\N	15	3	\N
740	3	1324	SM	NODATA	NODATA	\N	\N	\N	\N	15	3	\N
760	6	1325	RP	NODATA	NODATA	\N	\N	\N	\N	15	6	\N
775	6	1327	RP	NODATA	NODATA	\N	\N	\N	\N	15	6	\N
810	2	1329	SM	NODATA	NODATA	\N	\N	\N	\N	15	2	\N
824	6	1331	RP	NODATA	NODATA	\N	\N	\N	\N	15	6	\N
830	3	1333	RP	NODATA	NODATA	\N	\N	\N	\N	15	3	\N
850	3	1335	SM	NODATA	NODATA	\N	\N	\N	\N	15	3	\N
860	2	1336	SM	NODATA	NODATA	\N	\N	\N	\N	15	2	\N
880	2	1338	SM	NODATA	NODATA	\N	\N	\N	\N	15	2	\N
971	2	1341	SM	NODATA	NODATA	\N	\N	\N	\N	15	2	\N
974	3	1344	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
983	1	1346	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
995	1	1349	SM	NODATA	NODATA	\N	\N	\N	\N	15	1	\N
997	2	1350	RP	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
1026	3	1353	NEANT	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
30	2	1356	SM	NODATA	NODATA	\N	\N	\N	\N	16	2	\N
50	1	1358	SM	NODATA	NODATA	\N	\N	\N	\N	16	1	\N
80	2	1361	SM	NODATA	NODATA	\N	\N	\N	\N	16	2	\N
90	1	1362	SM	NODATA	NODATA	\N	\N	\N	\N	16	1	\N
200	1	1364	SM	NODATA	NODATA	\N	\N	\N	\N	16	1	\N
300	3	1365	SM	NODATA	NODATA	\N	\N	\N	\N	16	3	\N
500	3	1367	SM	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
700	2	1369	SM	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
110	2	1371	SM	NODATA	NODATA	\N	\N	\N	\N	16	2	\N
125	1	1373	SM	NODATA	NODATA	\N	\N	\N	\N	16	1	\N
140	3	1375	SM	NODATA	NODATA	\N	\N	\N	\N	16	3	\N
150	2	1376	SM	NODATA	NODATA	\N	\N	\N	\N	16	2	\N
170	3	1378	SM	NODATA	NODATA	\N	\N	\N	\N	16	3	\N
190	2	1380	SM	NODATA	NODATA	\N	\N	\N	\N	16	2	\N
210	3	1382	SM	NODATA	NODATA	\N	\N	\N	\N	16	3	\N
230	2	1384	SM	NODATA	NODATA	\N	\N	\N	\N	16	2	\N
250	3	1386	SM	NODATA	NODATA	\N	\N	\N	\N	16	3	\N
260	2	1387	SM	NODATA	NODATA	\N	\N	\N	\N	16	2	\N
270	3	1389	SM	NODATA	NODATA	\N	\N	\N	\N	16	3	\N
290	4	1391	RP	NODATA	NODATA	\N	\N	\N	\N	16	4	\N
320	2	1393	SM	NODATA	NODATA	\N	\N	\N	\N	16	2	\N
335	7	1395	RP	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
350	4	1397	RP	NODATA	NODATA	\N	\N	\N	\N	16	4	\N
360	2	1398	SM	NODATA	NODATA	\N	\N	\N	\N	16	2	\N
380	4	1400	RP	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
410	2	1402	SM	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
430	2	1404	SM	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
450	3	1406	SM	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
470	2	1408	SM	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
480	1	1409	SM	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
510	3	1411	SM	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
530	2	1413	SM	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
560	3	1416	SM	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
590	11	1419	RP	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
615	12	1421	RP	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
640	3	1424	SM	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
650	2	1425	SM	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
680	3	1428	RP	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
720	3	1431	SM	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
740	3	1433	SM	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
775	6	1436	RP	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
790	2	1437	SM	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
820	2	1439	SM	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
824	6	1440	RP	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
830	3	1442	RP	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
850	3	1444	SM	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
870	2	1446	SM	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
890	2	1448	SM	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
971	2	1450	SM	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
972	2	1451	SM	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
974	3	1453	SM	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
983	1	1455	SM	NODATA	NODATA	\N	\N	\N	\N	16	1	\N
990	1	1457	SM	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
997	4	1459	RP	NODATA	NODATA	\N	\N	\N	\N	16	4	\N
999	4	1461	RP	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
20	3	1463	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
30	2	1464	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
50	1	1466	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
70	2	1468	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
90	1	1470	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
100	2	1471	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
300	3	1473	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
500	3	1475	SM	NODATA	NODATA	\N	\N	\N	\N	2	3	\N
700	2	1477	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
110	2	1479	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
120	2	1480	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
130	7	1482	RP	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
150	2	1484	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
180	2	1487	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
210	3	1490	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
230	2	1492	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
260	2	1495	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
265	5	1496	RP	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
290	4	1499	RP	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
320	2	1501	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
340	3	1504	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
370	3	1507	SM	NODATA	NODATA	\N	\N	\N	\N	2	3	\N
390	2	1509	SM	NODATA	NODATA	\N	\N	\N	\N	2	2	\N
420	4	1511	RP	NODATA	NODATA	\N	\N	\N	\N	2	4	\N
440	5	1513	RP	NODATA	NODATA	\N	\N	\N	\N	2	5	\N
400	2	3340	SM	CELINT	CELINT	409	729	\N	2017-09-24 18:41:37	22	2	\N
420	4	3341	RP	CELINT	NODATA	710	\N	\N	2017-09-24 18:23:21	22	4	\N
450	3	3342	RP	CELINT	NODATA	697	\N	\N	2017-09-24 17:28:55	22	3	\N
460	2	3343	SM	CELINT	CELINT	569	735	\N	2017-09-24 19:05:36	22	2	\N
480	1	3344	SM	CELINT	CELINT	329	733	\N	2017-09-24 18:52:13	22	1	\N
370	3	3347	RP	CELINT	NODATA	690	\N	\N	2017-09-24 17:06:55	22	3	\N
430	2	3348	SM	CELINT	NODATA	369	\N	\N	2017-09-24 12:57:08	22	2	\N
560	3	3349	RP	CELINT	NODATA	692	\N	\N	2017-09-24 17:14:26	22	3	\N
620	7	3350	RP	CELINT	NODATA	700	\N	\N	2017-09-24 17:42:25	22	7	\N
410	2	3356	SM	CELINT	CELINT	449	736	\N	2017-09-24 19:14:36	22	2	\N
1053	6	3357	RP	CELINT	NODATA	734	\N	\N	2017-09-24 18:59:59	22	6	\N
490	4	3359	RP	CELINT	NODATA	691	\N	\N	2017-09-24 17:09:24	22	4	\N
540	4	3360	RP	CELINT	NODATA	695	\N	\N	2017-09-24 17:19:42	22	4	\N
550	2	3361	SM	CELINT	CELINT	430	737	\N	2017-09-24 19:16:18	22	2	\N
590	11	3362	RP	CELINT	NODATA	707	\N	\N	2017-09-24 18:16:51	22	11	\N
600	4	3363	RP	CELINT	NODATA	698	\N	\N	2017-09-24 17:29:37	22	4	\N
615	12	3364	RP	CELINT	NODATA	701	\N	\N	2017-09-24 17:47:26	22	12	\N
775	6	3368	RP	CELINT	NODATA	705	\N	\N	2017-09-24 18:07:56	22	6	\N
460	2	1515	SM	NODATA	NODATA	\N	\N	\N	\N	2	2	\N
480	1	1517	SM	NODATA	NODATA	\N	\N	\N	\N	2	1	\N
510	3	1519	SM	NODATA	NODATA	\N	\N	\N	\N	2	3	\N
530	2	1521	SM	NODATA	NODATA	\N	\N	\N	\N	2	2	\N
550	2	1523	SM	NODATA	NODATA	\N	\N	\N	\N	2	2	\N
990	1	1888	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
998	4	1891	RP	NODATA	NODATA	\N	\N	\N	\N	5	4	\N
10	2	1893	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
30	2	1895	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
50	1	1897	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
80	2	1900	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
100	2	1902	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
300	3	1904	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
800	3	1909	SM	NODATA	NODATA	\N	\N	\N	\N	6	3	\N
120	2	1911	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
130	7	1913	RP	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
150	2	1915	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
205	1	1920	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
220	3	1922	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
240	2	1924	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
260	2	1926	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
310	4	1931	RP	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
330	5	1933	RP	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
340	3	1935	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
380	4	1939	RP	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
410	2	1941	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
440	5	1944	RP	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
710	3	70	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
260	2	135	SM	NODATA	NODATA	\N	\N	\N	\N	8	2	\N
340	3	143	SM	NODATA	NODATA	\N	\N	\N	\N	8	3	\N
380	3	147	RP	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
350	4	1009	RP	NODATA	NODATA	\N	\N	\N	\N	1	4	\N
370	3	1011	SM	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
390	2	1013	SM	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
420	4	1015	RP	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
440	5	1017	RP	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
450	3	1018	SM	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
470	2	1020	SM	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
490	3	1022	SM	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
520	2	1024	SM	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
540	4	1026	RP	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
560	3	1028	SM	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
570	5	1029	RP	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
590	11	1031	RP	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
615	12	1033	RP	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
640	3	1036	SM	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
660	2	1038	SM	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
690	7	1041	RP	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
710	3	1042	SM	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
740	3	1045	SM	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
775	6	1048	RP	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
810	2	1050	SM	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
828	5	1053	RP	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
850	3	1056	SM	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
870	2	1058	SM	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
890	2	1060	SM	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
971	3	1062	SM	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
972	2	1063	SM	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
974	3	1065	SM	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
983	2	1067	SM	NODATA	NODATA	\N	\N	\N	\N	1	2	\N
990	2	1069	SM	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
997	4	1071	RP	NODATA	NODATA	\N	\N	\N	\N	1	4	\N
1051	2	1073	RP	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
9713	1	1075	SM	NODATA	NODATA	\N	\N	\N	\N	1	1	\N
9715	1	1076	SM	NODATA	NODATA	\N	\N	\N	\N	1	1	\N
10	3	1078	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
30	2	1080	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
50	1	1082	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
70	2	1084	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
80	2	1085	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
100	2	1087	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
300	3	1089	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
500	3	1091	SM	NODATA	NODATA	\N	\N	\N	\N	18	3	\N
700	2	1093	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
800	3	1094	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
120	2	1096	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
130	8	1098	RP	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
150	2	1100	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
170	3	1102	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
180	2	1103	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
205	1	1105	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
220	3	1107	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
250	3	1110	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
265	5	1112	RP	NODATA	NODATA	\N	\N	\N	\N	18	5	\N
290	4	1115	RP	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
310	5	1116	RP	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
335	7	1119	RP	NODATA	NODATA	\N	\N	\N	\N	18	7	\N
360	2	1122	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
380	5	1124	RP	NODATA	NODATA	\N	\N	\N	\N	18	5	\N
420	4	1127	RP	NODATA	NODATA	\N	\N	\N	\N	18	4	\N
450	3	1130	SM	NODATA	NODATA	\N	\N	\N	\N	18	3	\N
470	2	1132	SM	NODATA	NODATA	\N	\N	\N	\N	18	2	\N
490	4	1134	RP	NODATA	NODATA	\N	\N	\N	\N	18	4	\N
520	2	1136	SM	NODATA	NODATA	\N	\N	\N	\N	18	2	\N
540	4	1138	RP	NODATA	NODATA	\N	\N	\N	\N	18	4	\N
560	3	1140	SM	NODATA	NODATA	\N	\N	\N	\N	18	3	\N
580	2	1142	SM	NODATA	NODATA	\N	\N	\N	\N	18	2	\N
100	2	551	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
400	2	553	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
600	3	555	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
800	3	557	SM	NODATA	NODATA	\N	\N	\N	\N	17	3	\N
120	2	559	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
125	1	560	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
140	3	562	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
160	2	564	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
180	2	566	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
210	2	568	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
240	2	570	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
260	2	572	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
265	3	573	RP	NODATA	NODATA	\N	\N	\N	\N	17	3	\N
280	2	575	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
310	3	577	RP	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
335	7	580	RP	NODATA	NODATA	\N	\N	\N	\N	17	7	\N
360	2	583	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
380	3	585	RP	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
410	2	587	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
430	2	589	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
460	1	592	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
490	3	595	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
520	2	597	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
550	2	600	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
560	3	601	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
590	9	604	RP	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
615	12	606	RP	NODATA	NODATA	\N	\N	\N	\N	17	12	\N
630	3	608	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
660	2	610	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
680	3	612	RP	NODATA	NODATA	\N	\N	\N	\N	17	3	\N
710	3	614	SM	NODATA	NODATA	\N	\N	\N	\N	17	3	\N
720	3	615	SM	NODATA	NODATA	\N	\N	\N	\N	17	3	\N
740	2	617	SM	NODATA	NODATA	\N	\N	\N	\N	17	2	\N
770	3	619	RP	NODATA	NODATA	\N	\N	\N	\N	17	3	\N
790	2	621	SM	NODATA	NODATA	\N	\N	\N	\N	17	2	\N
820	2	623	SM	NODATA	NODATA	\N	\N	\N	\N	17	2	\N
828	3	625	RP	NODATA	NODATA	\N	\N	\N	\N	17	3	\N
840	2	627	SM	NODATA	NODATA	\N	\N	\N	\N	17	2	\N
850	2	628	SM	NODATA	NODATA	\N	\N	\N	\N	17	2	\N
730	2	3406	SM	CELINT	CELINT	469	732	2017-08-18 12:50:46	2017-09-24 18:51:50	23	1	depuis le 1er juin 2017 à la suite de la démission de M. Michel BOUVARD
828	5	3370	RP	CELINT	NODATA	693	\N	\N	2017-09-24 17:15:14	22	5	\N
70	2	766	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
895	6	3375	RP	CELINT	NODATA	708	\N	\N	2017-09-24 18:17:56	22	6	\N
971	3	3376	RP	CELINT	NODATA	749	\N	\N	2017-09-25 10:54:33	22	3	\N
972	2	3377	SM	CELINT	CELINT	751	752	\N	2017-09-25 11:00:40	22	2	\N
982	2	3378	SM	CELINT	NODATA	309	\N	\N	2017-09-24 10:41:27	22	2	\N
990	2	3380	SM	CELINT	CELINT	429	706	\N	2017-09-24 18:16:33	22	2	\N
500	3	3381	RP	CELINT	NODATA	649	\N	\N	2017-09-24 16:43:42	22	3	\N
570	5	3382	RP	CELINT	NODATA	702	\N	\N	2017-09-24 17:48:20	22	5	\N
380	5	3384	RP	CELINT	NODATA	699	\N	\N	2017-09-24 17:35:13	22	5	\N
510	3	3385	RP	CELINT	NODATA	696	\N	\N	2017-09-24 17:25:22	22	3	\N
470	2	3387	SM	CELINT	CELINT	489	739	\N	2017-09-24 19:19:07	22	2	\N
440	5	3393	RP	CELINT	NODATA	689	\N	\N	2017-09-24 17:04:01	22	5	\N
520	2	3394	SM	CELINT	CELINT	389	711	\N	2017-09-24 18:26:00	22	2	\N
870	2	630	SM	NODATA	NODATA	\N	\N	\N	\N	17	2	\N
890	2	632	SM	NODATA	NODATA	\N	\N	\N	\N	17	2	\N
971	2	634	SM	NODATA	NODATA	\N	\N	\N	\N	17	2	\N
973	1	636	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
982	1	638	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
983	1	639	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
995	1	641	SM	NODATA	NODATA	\N	\N	\N	\N	17	1	\N
998	2	643	RP	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
1002	2	645	NEANT	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
1011	1	647	NEANT	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
1025	1	649	NEANT	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
1026	3	650	NEANT	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
20	2	652	SM	NODATA	NODATA	\N	\N	\N	\N	10	2	\N
50	1	655	SM	NODATA	NODATA	\N	\N	\N	\N	10	1	\N
70	2	657	SM	NODATA	NODATA	\N	\N	\N	\N	10	2	\N
100	2	660	SM	NODATA	NODATA	\N	\N	\N	\N	10	2	\N
300	2	661	SM	NODATA	NODATA	\N	\N	\N	\N	10	2	\N
600	3	664	SM	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
110	2	667	SM	NODATA	NODATA	\N	\N	\N	\N	10	2	\N
130	5	670	RP	NODATA	NODATA	\N	\N	\N	\N	10	5	\N
150	2	672	SM	NODATA	NODATA	\N	\N	\N	\N	10	2	\N
180	2	675	SM	NODATA	NODATA	\N	\N	\N	\N	10	2	\N
190	2	676	SM	NODATA	NODATA	\N	\N	\N	\N	10	2	\N
240	2	679	SM	NODATA	NODATA	\N	\N	\N	\N	10	2	\N
265	3	682	RP	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
280	2	684	SM	NODATA	NODATA	\N	\N	\N	\N	10	2	\N
310	3	686	RP	NODATA	NODATA	\N	\N	\N	\N	10	3	\N
330	4	688	RP	NODATA	NODATA	\N	\N	\N	\N	10	4	\N
340	3	690	SM	NODATA	NODATA	\N	\N	\N	\N	10	3	\N
350	3	691	RP	NODATA	NODATA	\N	\N	\N	\N	10	3	\N
370	2	693	SM	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
390	2	695	SM	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
420	4	697	RP	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
440	4	699	RP	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
460	1	701	SM	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
480	1	703	SM	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
490	3	704	SM	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
520	2	706	SM	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
540	3	708	RP	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
560	3	710	SM	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
580	2	712	SM	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
610	2	714	SM	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
615	12	715	RP	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
630	3	717	SM	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
650	2	719	SM	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
670	4	721	RP	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
690	5	723	RP	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
720	3	725	SM	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
730	2	726	SM	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
760	5	728	RP	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
775	5	730	RP	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
820	2	733	SM	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
828	3	735	RP	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
850	2	738	SM	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
880	2	741	SM	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
890	2	742	SM	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
972	2	745	SM	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
974	2	747	SM	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
984	1	750	SM	NODATA	NODATA	\N	\N	\N	\N	10	1	\N
998	2	753	RP	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
1002	2	755	NEANT	NODATA	NODATA	\N	\N	\N	\N	10	2	\N
1012	1	757	NEANT	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
1026	3	759	NEANT	NODATA	NODATA	\N	\N	\N	\N	10	3	\N
10	2	760	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
30	2	762	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
50	1	764	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
90	1	768	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
100	2	769	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
400	2	771	SM	NODATA	NODATA	\N	\N	\N	\N	11	2	\N
600	3	773	SM	NODATA	NODATA	\N	\N	\N	\N	11	3	\N
800	3	775	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
110	1	776	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
125	1	778	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
140	3	780	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
160	2	782	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
180	2	784	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
210	2	786	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
240	2	788	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
250	2	789	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
265	3	791	RP	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
280	2	793	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
310	3	795	RP	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
330	4	797	RP	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
340	3	799	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
350	3	800	RP	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
370	2	802	SM	NODATA	NODATA	\N	\N	\N	\N	11	2	\N
390	2	804	SM	NODATA	NODATA	\N	\N	\N	\N	11	2	\N
430	2	807	SM	NODATA	NODATA	\N	\N	\N	\N	11	2	\N
460	1	810	SM	NODATA	NODATA	\N	\N	\N	\N	11	1	\N
480	1	812	SM	NODATA	NODATA	\N	\N	\N	\N	11	1	\N
510	3	814	SM	NODATA	NODATA	\N	\N	\N	\N	11	3	\N
530	2	816	SM	NODATA	NODATA	\N	\N	\N	\N	11	2	\N
560	3	819	SM	NODATA	NODATA	\N	\N	\N	\N	11	3	\N
590	9	822	RP	NODATA	NODATA	\N	\N	\N	\N	11	9	\N
615	12	824	RP	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
640	3	827	SM	NODATA	NODATA	\N	\N	\N	\N	11	3	\N
650	2	828	SM	NODATA	NODATA	\N	\N	\N	\N	11	2	\N
680	3	831	RP	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
710	3	833	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
720	3	834	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
740	2	836	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
770	3	838	RP	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
790	2	840	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
820	2	842	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
828	3	844	RP	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
840	2	846	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
850	2	847	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
870	2	849	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
890	2	851	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
971	2	853	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
973	1	855	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
982	1	857	SM	NODATA	NODATA	\N	\N	\N	\N	11	1	\N
983	1	858	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
995	1	860	SM	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
998	2	862	RP	NODATA	NODATA	\N	\N	\N	\N	11	2	\N
1002	2	864	NEANT	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
1025	1	866	NEANT	NODATA	NODATA	\N	\N	\N	\N	11	0	\N
10	2	868	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
20	3	869	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
40	1	871	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
60	3	873	RP	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
80	2	875	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
100	2	877	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
300	2	878	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
500	3	880	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
800	2	883	SM	NODATA	NODATA	\N	\N	\N	\N	12	2	\N
125	1	886	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
140	3	888	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
160	2	890	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
180	2	892	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
230	2	895	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
260	2	898	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
270	2	900	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
310	3	903	RP	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
320	2	904	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
340	3	907	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
790	2	287	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
972	2	299	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
971	2	356	SM	NODATA	NODATA	\N	\N	\N	\N	12	2	\N
1002	2	368	NEANT	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
60	4	376	RP	NODATA	NODATA	\N	\N	\N	\N	13	4	\N
630	3	439	SM	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
720	3	447	SM	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
210	3	507	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
570	4	602	RP	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
400	2	662	SM	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
125	1	669	SM	NODATA	NODATA	\N	\N	\N	\N	10	1	\N
260	2	681	SM	NODATA	NODATA	\N	\N	\N	\N	10	2	\N
830	3	736	RP	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
982	1	748	SM	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
1004	1	756	NEANT	NODATA	NODATA	\N	\N	\N	\N	10	0	\N
490	3	813	SM	NODATA	NODATA	\N	\N	\N	\N	11	3	\N
450	3	909	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
470	2	911	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
490	3	913	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
520	2	915	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
540	4	917	RP	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
560	3	919	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
570	5	920	RP	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
590	11	922	RP	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
615	12	924	RP	NODATA	NODATA	\N	\N	\N	\N	6	12	\N
630	3	926	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
650	2	928	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
670	5	930	RP	NODATA	NODATA	\N	\N	\N	\N	6	5	\N
680	4	931	RP	NODATA	NODATA	\N	\N	\N	\N	6	4	\N
710	3	933	SM	NODATA	NODATA	\N	\N	\N	\N	6	3	\N
730	2	935	SM	NODATA	NODATA	\N	\N	\N	\N	6	2	\N
760	6	937	RP	NODATA	NODATA	\N	\N	\N	\N	6	6	\N
775	6	939	RP	NODATA	NODATA	\N	\N	\N	\N	6	6	\N
810	2	941	SM	NODATA	NODATA	\N	\N	\N	\N	6	2	\N
820	2	942	SM	NODATA	NODATA	\N	\N	\N	\N	6	2	\N
828	5	944	RP	NODATA	NODATA	\N	\N	\N	\N	6	5	\N
840	3	946	SM	NODATA	NODATA	\N	\N	\N	\N	6	3	\N
860	2	948	SM	NODATA	NODATA	\N	\N	\N	\N	6	2	\N
880	2	950	SM	NODATA	NODATA	\N	\N	\N	\N	6	2	\N
895	6	952	RP	NODATA	NODATA	\N	\N	\N	\N	6	6	\N
972	2	954	SM	NODATA	NODATA	\N	\N	\N	\N	6	2	\N
973	1	955	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
983	1	958	SM	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
990	2	960	SM	NODATA	NODATA	\N	\N	\N	\N	6	2	\N
998	4	963	RP	NODATA	NODATA	\N	\N	\N	\N	6	0	\N
10	3	966	SM	NODATA	NODATA	\N	\N	\N	\N	1	3	\N
30	2	968	SM	NODATA	NODATA	\N	\N	\N	\N	1	2	\N
50	1	970	SM	NODATA	NODATA	\N	\N	\N	\N	1	1	\N
70	2	972	SM	NODATA	NODATA	\N	\N	\N	\N	1	2	\N
100	2	975	SM	NODATA	NODATA	\N	\N	\N	\N	1	2	\N
400	2	978	SM	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
500	3	979	SM	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
800	3	982	SM	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
125	1	985	SM	NODATA	NODATA	\N	\N	\N	\N	1	1	\N
140	3	987	SM	NODATA	NODATA	\N	\N	\N	\N	1	3	\N
160	2	989	SM	NODATA	NODATA	\N	\N	\N	\N	1	2	\N
180	2	991	SM	NODATA	NODATA	\N	\N	\N	\N	1	2	\N
205	1	993	SM	NODATA	NODATA	\N	\N	\N	\N	1	1	\N
210	3	994	SM	NODATA	NODATA	\N	\N	\N	\N	1	3	\N
230	2	996	SM	NODATA	NODATA	\N	\N	\N	\N	1	2	\N
250	3	998	SM	NODATA	NODATA	\N	\N	\N	\N	1	3	\N
265	5	1000	RP	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
280	3	1002	SM	NODATA	NODATA	\N	\N	\N	\N	1	3	\N
310	5	1004	RP	NODATA	NODATA	\N	\N	\N	\N	1	5	\N
320	2	1005	SM	NODATA	NODATA	\N	\N	\N	\N	1	2	\N
335	7	1007	RP	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
390	2	1125	SM	NODATA	NODATA	\N	\N	\N	\N	18	2	\N
440	5	1129	RP	NODATA	NODATA	\N	\N	\N	\N	18	5	\N
480	1	1133	SM	NODATA	NODATA	\N	\N	\N	\N	18	1	\N
460	2	1190	SM	NODATA	NODATA	\N	\N	\N	\N	14	2	\N
510	3	1194	SM	NODATA	NODATA	\N	\N	\N	\N	14	3	\N
550	2	1198	SM	NODATA	NODATA	\N	\N	\N	\N	14	2	\N
590	11	1202	RP	NODATA	NODATA	\N	\N	\N	\N	14	11	\N
630	3	1206	SM	NODATA	NODATA	\N	\N	\N	\N	14	3	\N
670	4	1210	RP	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
500	3	1259	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
140	3	1267	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
180	2	1271	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
265	5	1279	RP	NODATA	NODATA	\N	\N	\N	\N	15	5	\N
890	2	1339	SM	NODATA	NODATA	\N	\N	\N	\N	15	2	\N
973	1	1343	SM	NODATA	NODATA	\N	\N	\N	\N	15	0	\N
60	4	1359	RP	NODATA	NODATA	\N	\N	\N	\N	16	4	\N
540	4	1414	RP	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
620	7	1422	RP	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
710	3	1430	SM	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
760	6	1434	RP	NODATA	NODATA	\N	\N	\N	\N	16	0	\N
205	1	1489	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
205	1	506	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
240	2	509	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
265	5	512	RP	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
270	3	513	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
310	4	516	RP	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
330	5	518	RP	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
350	4	521	RP	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
380	4	524	RP	NODATA	NODATA	\N	\N	\N	\N	14	4	\N
410	2	526	SM	NODATA	NODATA	\N	\N	\N	\N	14	2	\N
430	2	528	SM	NODATA	NODATA	\N	\N	\N	\N	14	2	\N
984	1	530	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
995	1	531	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
998	2	533	RP	NODATA	NODATA	\N	\N	\N	\N	9	2	\N
1002	2	535	NEANT	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
1011	1	537	NEANT	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
1020	10	539	NEANT	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
1026	3	541	NEANT	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
20	3	544	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
50	1	546	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
70	2	548	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
90	1	550	SM	NODATA	NODATA	\N	\N	\N	\N	17	0	\N
1053	6	1945	RP	NODATA	NODATA	\N	\N	\N	\N	18	6	\N
240	2	1493	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
270	3	1497	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
330	5	1502	RP	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
360	2	1506	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
410	2	1510	SM	NODATA	NODATA	\N	\N	\N	\N	2	2	\N
974	3	1561	SM	NODATA	NODATA	\N	\N	\N	\N	2	3	\N
990	1	1565	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
999	4	1569	RP	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
40	1	1573	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
80	2	1577	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
120	2	1588	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
630	3	1639	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
720	3	1647	SM	NODATA	NODATA	\N	\N	\N	\N	3	3	\N
820	2	1655	SM	NODATA	NODATA	\N	\N	\N	\N	3	2	\N
840	2	1659	SM	NODATA	NODATA	\N	\N	\N	\N	3	2	\N
350	4	1721	RP	NODATA	NODATA	\N	\N	\N	\N	4	4	\N
390	2	1725	SM	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
480	1	1733	SM	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
30	2	1788	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
70	2	1792	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
600	3	1799	SM	NODATA	NODATA	\N	\N	\N	\N	5	3	\N
120	2	1803	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
150	2	1807	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
190	2	1811	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
230	2	1815	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
770	4	1866	RP	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
250	3	3185	RP	NODATA	NODATA	\N	\N	\N	2014-09-28 17:23:09	19	3	\N
820	2	1870	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
840	2	1874	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
972	2	1882	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
997	4	1890	RP	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
10	2	1	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
30	2	3	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
60	3	5	RP	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
90	1	8	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
300	2	10	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
400	2	11	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
600	3	13	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
800	3	15	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
125	1	18	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
140	3	20	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
160	2	22	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
180	2	24	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
210	2	26	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
230	2	27	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
250	3	29	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
270	2	31	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
290	4	33	RP	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
320	2	35	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
330	4	36	RP	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
350	3	38	RP	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
370	2	40	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
390	1	42	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
420	5	44	RP	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
430	2	45	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
450	2	47	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
470	2	49	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
490	3	51	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
510	3	52	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
530	2	54	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
550	2	56	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
570	4	58	RP	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
590	9	60	RP	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
610	2	61	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
620	6	63	RP	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
660	2	66	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
680	3	68	RP	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
720	3	71	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
730	2	72	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
760	5	74	RP	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
810	2	77	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
830	3	79	RP	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
850	2	81	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
860	2	82	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
880	2	84	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
895	2	86	RP	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
972	2	88	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
974	2	90	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
982	1	91	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
995	1	93	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
999	1	95	RP	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
1004	3	97	NEANT	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
1011	1	98	NEANT	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
1020	9	100	NEANT	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
1025	1	102	NEANT	NODATA	NODATA	\N	\N	\N	\N	7	1	\N
1029	15	104	NEANT	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
10	2	106	SM	NODATA	NODATA	\N	\N	\N	\N	8	2	\N
30	2	108	SM	NODATA	NODATA	\N	\N	\N	\N	8	2	\N
50	1	109	SM	NODATA	NODATA	\N	\N	\N	\N	8	1	\N
70	2	111	SM	NODATA	NODATA	\N	\N	\N	\N	8	2	\N
90	1	113	SM	NODATA	NODATA	\N	\N	\N	\N	8	1	\N
300	2	115	SM	NODATA	NODATA	\N	\N	\N	\N	8	2	\N
400	2	116	SM	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
600	3	118	SM	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
800	3	120	SM	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
120	2	122	SM	NODATA	NODATA	\N	\N	\N	\N	8	2	\N
130	5	124	RP	NODATA	NODATA	\N	\N	\N	\N	8	5	\N
150	2	126	SM	NODATA	NODATA	\N	\N	\N	\N	8	2	\N
160	2	127	SM	NODATA	NODATA	\N	\N	\N	\N	8	2	\N
180	2	129	SM	NODATA	NODATA	\N	\N	\N	\N	8	2	\N
230	2	132	SM	NODATA	NODATA	\N	\N	\N	\N	8	2	\N
250	3	134	SM	NODATA	NODATA	\N	\N	\N	\N	8	3	\N
280	2	137	SM	NODATA	NODATA	\N	\N	\N	\N	8	2	\N
320	2	140	SM	NODATA	NODATA	\N	\N	\N	\N	8	2	\N
330	4	141	RP	NODATA	NODATA	\N	\N	\N	\N	8	4	\N
350	3	144	RP	NODATA	NODATA	\N	\N	\N	\N	8	3	\N
370	2	146	SM	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
410	2	149	SM	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
440	4	152	RP	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
450	2	153	SM	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
470	2	155	SM	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
490	3	157	SM	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
520	2	159	SM	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
540	3	161	RP	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
550	2	162	SM	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
570	4	164	RP	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
590	9	166	RP	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
615	4	168	RP	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
630	3	170	SM	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
660	2	172	SM	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
680	3	174	RP	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
690	5	175	RP	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
720	3	177	SM	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
740	2	179	SM	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
770	3	181	RP	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
810	2	183	SM	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
830	3	185	RP	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
840	2	186	SM	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
860	2	188	SM	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
880	2	190	SM	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
895	2	192	RP	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
972	2	194	SM	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
974	2	196	SM	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
982	1	197	SM	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
984	1	199	SM	NODATA	NODATA	\N	\N	\N	\N	8	1	\N
999	2	202	RP	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
1004	3	204	NEANT	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
1020	9	207	NEANT	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
1029	14	210	NEANT	NODATA	NODATA	\N	\N	\N	\N	8	0	\N
20	3	212	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
50	1	214	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
70	2	216	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
100	2	219	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
500	3	222	SM	NODATA	NODATA	\N	\N	\N	\N	9	3	\N
600	3	223	SM	NODATA	NODATA	\N	\N	\N	\N	9	3	\N
110	2	226	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
130	5	229	RP	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
150	2	231	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
170	3	233	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
190	2	235	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
230	2	237	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
240	2	238	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
260	2	240	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
280	2	242	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
310	3	244	RP	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
330	4	246	RP	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
340	3	248	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
360	2	250	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
370	2	251	SM	NODATA	NODATA	\N	\N	\N	\N	9	2	\N
390	1	253	SM	NODATA	NODATA	\N	\N	\N	\N	9	1	\N
420	4	255	RP	NODATA	NODATA	\N	\N	\N	\N	9	4	\N
440	4	257	RP	NODATA	NODATA	\N	\N	\N	\N	9	4	\N
460	1	259	SM	NODATA	NODATA	\N	\N	\N	\N	9	1	\N
480	1	261	SM	NODATA	NODATA	\N	\N	\N	\N	9	1	\N
740	3	3189	RP	NODATA	NODATA	\N	\N	\N	2014-09-28 17:41:20	19	3	\N
70	2	3190	SM	NODATA	NODATA	\N	\N	\N	2014-09-28 19:21:31	19	2	\N
240	2	3191	SM	NODATA	NODATA	\N	\N	\N	2014-09-28 18:43:05	19	2	\N
390	2	3192	SM	NODATA	NODATA	\N	\N	\N	\N	19	0	\N
610	2	3193	SM	NODATA	NODATA	\N	\N	\N	\N	19	0	\N
60	5	3194	RP	NODATA	NODATA	\N	\N	\N	2014-09-28 17:59:42	19	5	\N
90	1	3195	SM	NODATA	NODATA	\N	\N	\N	2014-09-28 12:56:15	19	1	\N
110	2	3196	SM	NODATA	NODATA	\N	\N	\N	2014-09-28 13:34:32	19	2	\N
150	2	3197	SM	NODATA	NODATA	\N	\N	\N	2014-09-28 13:02:23	19	2	\N
160	2	3198	SM	NODATA	NODATA	\N	\N	\N	2014-09-28 18:59:52	19	2	\N
180	2	3199	SM	NODATA	NODATA	\N	\N	\N	2014-09-28 12:35:11	19	2	\N
190	2	3200	SM	NODATA	NODATA	\N	\N	\N	2014-09-28 18:34:06	19	2	\N
210	3	3201	RP	NODATA	NODATA	\N	\N	\N	2014-09-28 17:00:53	19	3	\N
230	2	3202	SM	NODATA	NODATA	\N	\N	\N	2014-09-28 18:47:22	19	2	\N
265	5	3203	RP	NODATA	NODATA	\N	\N	\N	\N	19	0	\N
300	3	3204	RP	NODATA	NODATA	\N	\N	\N	2014-09-28 17:10:39	19	3	\N
320	2	3205	SM	NODATA	NODATA	\N	\N	\N	2014-09-28 19:13:02	19	2	\N
330	6	3206	RP	NODATA	NODATA	\N	\N	\N	2014-09-28 18:15:19	19	6	\N
360	2	3207	SM	NODATA	NODATA	\N	\N	\N	2014-09-28 19:27:45	19	2	\N
400	2	3208	SM	NODATA	NODATA	\N	\N	\N	\N	19	0	\N
420	4	3209	RP	NODATA	NODATA	\N	\N	\N	\N	19	0	\N
450	3	3210	RP	NODATA	NODATA	\N	\N	\N	\N	19	0	\N
460	2	3211	SM	NODATA	NODATA	\N	\N	\N	\N	19	0	\N
480	1	3212	SM	NODATA	NODATA	\N	\N	\N	\N	19	0	\N
20	3	3214	RP	NODATA	NODATA	\N	\N	\N	2014-09-28 17:18:57	19	3	\N
290	4	3215	RP	NODATA	NODATA	\N	\N	\N	2014-09-28 17:08:51	19	4	\N
370	3	3216	RP	NODATA	NODATA	\N	\N	\N	\N	19	0	\N
430	2	3217	SM	NODATA	NODATA	\N	\N	\N	\N	19	0	\N
560	3	3218	RP	NODATA	NODATA	\N	\N	\N	\N	19	0	\N
620	7	3219	RP	NODATA	NODATA	\N	\N	\N	\N	19	0	\N
690	7	3220	RP	NODATA	NODATA	\N	\N	\N	2014-09-28 17:16:53	19	7	\N
760	6	3221	RP	NODATA	NODATA	\N	\N	\N	2014-09-28 18:02:39	19	6	\N
120	2	3222	SM	NODATA	NODATA	\N	\N	\N	2014-09-28 19:05:10	19	2	\N
870	2	3224	SM	NODATA	NODATA	\N	\N	\N	2014-09-28 19:23:22	19	2	\N
410	2	3225	SM	NODATA	NODATA	\N	\N	\N	\N	19	0	\N
1053	6	3226	RP	NODATA	NODATA	\N	\N	\N	\N	19	0	\N
490	3	262	SM	NODATA	NODATA	\N	\N	\N	\N	9	3	\N
520	2	264	SM	NODATA	NODATA	\N	\N	\N	\N	9	2	\N
540	3	266	RP	NODATA	NODATA	\N	\N	\N	\N	9	3	\N
560	3	268	SM	NODATA	NODATA	\N	\N	\N	\N	9	3	\N
580	2	270	SM	NODATA	NODATA	\N	\N	\N	\N	9	2	\N
610	2	272	SM	NODATA	NODATA	\N	\N	\N	\N	9	2	\N
615	4	273	RP	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
630	3	275	SM	NODATA	NODATA	\N	\N	\N	\N	9	3	\N
660	2	277	SM	NODATA	NODATA	\N	\N	\N	\N	9	2	\N
690	5	280	RP	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
720	3	282	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
760	5	285	RP	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
810	2	288	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
820	2	289	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
850	2	292	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
870	2	294	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
895	2	297	RP	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
973	1	300	SM	NODATA	NODATA	\N	\N	\N	\N	9	0	\N
982	1	302	SM	NODATA	NODATA	\N	\N	\N	\N	9	1	\N
360	2	304	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
380	3	306	RP	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
390	2	307	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
420	4	309	RP	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
440	4	311	RP	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
460	1	313	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
480	1	315	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
510	3	317	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
520	2	318	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
540	3	320	RP	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
560	3	322	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
580	2	324	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
610	2	326	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
620	6	328	RP	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
630	3	329	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
650	2	331	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
670	4	333	RP	NODATA	NODATA	\N	\N	\N	\N	12	4	\N
690	7	335	RP	NODATA	NODATA	\N	\N	\N	\N	12	7	\N
720	3	337	SM	NODATA	NODATA	\N	\N	\N	\N	12	3	\N
740	3	339	SM	NODATA	NODATA	\N	\N	\N	\N	12	3	\N
770	4	341	RP	NODATA	NODATA	\N	\N	\N	\N	12	4	\N
775	6	342	RP	NODATA	NODATA	\N	\N	\N	\N	12	6	\N
810	2	344	SM	NODATA	NODATA	\N	\N	\N	\N	12	2	\N
824	6	346	RP	NODATA	NODATA	\N	\N	\N	\N	12	6	\N
830	3	348	RP	NODATA	NODATA	\N	\N	\N	\N	12	3	\N
850	3	350	SM	NODATA	NODATA	\N	\N	\N	\N	12	3	\N
870	2	352	SM	NODATA	NODATA	\N	\N	\N	\N	12	2	\N
880	2	353	SM	NODATA	NODATA	\N	\N	\N	\N	12	2	\N
895	5	355	RP	NODATA	NODATA	\N	\N	\N	\N	12	5	\N
973	1	358	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
983	1	361	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
990	1	363	SM	NODATA	NODATA	\N	\N	\N	\N	12	1	\N
998	2	366	RP	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
999	2	367	RP	NODATA	NODATA	\N	\N	\N	\N	12	2	\N
1026	3	370	NEANT	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
30	2	373	SM	NODATA	NODATA	\N	\N	\N	\N	13	2	\N
50	1	375	SM	NODATA	NODATA	\N	\N	\N	\N	13	1	\N
80	2	378	SM	NODATA	NODATA	\N	\N	\N	\N	13	2	\N
90	1	379	SM	NODATA	NODATA	\N	\N	\N	\N	13	1	\N
200	1	381	SM	NODATA	NODATA	\N	\N	\N	\N	13	1	\N
300	3	382	SM	NODATA	NODATA	\N	\N	\N	\N	13	3	\N
500	3	384	SM	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
700	2	386	SM	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
110	2	388	SM	NODATA	NODATA	\N	\N	\N	\N	13	2	\N
125	1	390	SM	NODATA	NODATA	\N	\N	\N	\N	13	1	\N
140	3	392	SM	NODATA	NODATA	\N	\N	\N	\N	13	3	\N
150	2	393	SM	NODATA	NODATA	\N	\N	\N	\N	13	2	\N
170	3	395	SM	NODATA	NODATA	\N	\N	\N	\N	13	3	\N
190	2	397	SM	NODATA	NODATA	\N	\N	\N	\N	13	2	\N
210	3	399	SM	NODATA	NODATA	\N	\N	\N	\N	13	3	\N
240	2	401	SM	NODATA	NODATA	\N	\N	\N	\N	13	2	\N
260	2	403	SM	NODATA	NODATA	\N	\N	\N	\N	13	2	\N
265	5	404	RP	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
280	2	406	SM	NODATA	NODATA	\N	\N	\N	\N	13	2	\N
310	4	408	RP	NODATA	NODATA	\N	\N	\N	\N	13	4	\N
330	5	410	RP	NODATA	NODATA	\N	\N	\N	\N	13	5	\N
340	3	412	SM	NODATA	NODATA	\N	\N	\N	\N	13	3	\N
360	2	414	SM	NODATA	NODATA	\N	\N	\N	\N	13	2	\N
370	2	415	SM	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
390	2	417	SM	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
420	4	419	RP	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
440	4	421	RP	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
460	1	423	SM	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
480	1	425	SM	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
510	3	427	SM	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
520	2	428	SM	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
540	3	430	RP	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
570	4	433	RP	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
610	2	436	SM	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
620	6	438	RP	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
650	2	441	SM	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
660	2	442	SM	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
690	7	445	RP	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
730	2	448	SM	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
760	6	450	RP	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
790	2	453	SM	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
810	2	454	SM	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
824	6	456	RP	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
828	4	457	RP	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
840	2	459	SM	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
860	2	461	SM	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
880	2	463	SM	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
895	5	465	RP	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
972	2	467	SM	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
973	1	468	SM	NODATA	NODATA	\N	\N	\N	\N	13	1	\N
982	1	470	SM	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
984	1	472	SM	NODATA	NODATA	\N	\N	\N	\N	13	1	\N
995	1	474	SM	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
998	2	476	RP	NODATA	NODATA	\N	\N	\N	\N	13	0	\N
1026	3	478	NEANT	NODATA	NODATA	\N	\N	\N	\N	13	3	\N
20	3	480	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
30	2	481	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
50	1	483	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
70	2	485	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
90	1	487	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
100	2	488	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
300	3	490	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
500	3	492	SM	NODATA	NODATA	\N	\N	\N	\N	14	3	\N
700	2	494	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
110	2	496	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
120	2	497	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
130	7	499	RP	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
150	2	501	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
180	2	504	SM	NODATA	NODATA	\N	\N	\N	\N	14	0	\N
540	3	817	RP	NODATA	NODATA	\N	\N	\N	\N	11	3	\N
580	2	821	SM	NODATA	NODATA	\N	\N	\N	\N	11	2	\N
620	6	825	RP	NODATA	NODATA	\N	\N	\N	\N	11	6	\N
660	2	829	SM	NODATA	NODATA	\N	\N	\N	\N	11	2	\N
600	3	881	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
120	2	885	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
150	2	889	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
190	2	893	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
250	2	897	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
280	2	901	SM	NODATA	NODATA	\N	\N	\N	\N	12	0	\N
995	1	961	SM	NODATA	NODATA	\N	\N	\N	\N	6	1	\N
1052	2	965	RP	NODATA	NODATA	\N	\N	\N	\N	6	2	\N
80	2	973	SM	NODATA	NODATA	\N	\N	\N	\N	1	2	\N
820	2	3426	SM	SEANCE	SEANCE	787	815	2020-09-08 17:49:24	\N	24	2	\N
890	2	3427	SM	SEANCE	SEANCE	780	809	2020-09-08 17:49:24	\N	24	2	\N
973	2	3428	SM	SEANCE	SEANCE	803	869	2020-09-08 17:49:24	\N	24	2	\N
983	2	3429	SM	SEANCE	NODATA	871	\N	2020-09-08 17:49:24	\N	24	2	\N
260	3	3430	RP	SEANCE	NODATA	819	\N	2020-09-08 17:49:24	\N	24	3	\N
800	3	3431	RP	SEANCE	NODATA	820	\N	2020-09-08 17:49:24	\N	24	3	\N
50	1	3432	SM	SEANCE	SEANCE	772	804	2020-09-08 17:49:24	\N	24	1	\N
310	5	3433	RP	SEANCE	NODATA	849	\N	2020-09-08 17:49:24	\N	24	5	\N
125	1	3434	SM	SEANCE	NODATA	773	\N	2020-09-08 17:49:24	\N	24	1	\N
200	1	3435	SM	SEANCE	NODATA	771	\N	2020-09-08 17:49:24	\N	24	1	\N
790	2	3436	SM	SEANCE	SEANCE	774	805	2020-09-08 17:49:24	\N	24	2	\N
100	2	3437	SM	SEANCE	SEANCE	793	814	2020-09-08 17:49:24	\N	24	2	\N
340	4	3438	RP	SEANCE	NODATA	840	\N	2020-09-08 17:49:24	\N	24	4	\N
270	3	3439	RP	SEANCE	NODATA	841	\N	2020-09-08 17:49:24	\N	24	3	\N
710	3	3440	RP	SEANCE	NODATA	842	\N	2020-09-08 17:49:24	\N	24	3	\N
205	1	3441	SM	SEANCE	SEANCE	770	802	2020-09-08 17:49:24	\N	24	1	\N
720	3	3442	RP	SEANCE	NODATA	825	\N	2020-09-08 17:49:24	\N	24	3	\N
860	2	3443	SM	SEANCE	NODATA	783	\N	2020-09-08 17:49:24	\N	24	2	\N
220	3	3444	RP	SEANCE	NODATA	837	\N	2020-09-08 17:49:24	\N	24	3	\N
9715	1	3445	SM	SEANCE	SEANCE	800	870	2020-09-08 17:49:24	\N	24	1	\N
700	2	981	SM	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
120	2	984	SM	NODATA	NODATA	\N	\N	\N	\N	1	2	\N
770	6	1047	RP	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
820	2	1051	SM	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
880	2	1059	SM	NODATA	NODATA	\N	\N	\N	\N	1	0	\N
270	3	1113	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
320	2	1117	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
150	2	21	SM	NODATA	NODATA	\N	\N	\N	\N	7	0	\N
560	3	1524	SM	NODATA	NODATA	\N	\N	\N	\N	2	3	\N
580	2	1526	SM	NODATA	NODATA	\N	\N	\N	\N	2	2	\N
610	2	1528	SM	NODATA	NODATA	\N	\N	\N	\N	2	2	\N
620	7	1530	RP	NODATA	NODATA	\N	\N	\N	\N	2	7	\N
640	3	1532	SM	NODATA	NODATA	\N	\N	\N	\N	2	3	\N
660	2	1534	SM	NODATA	NODATA	\N	\N	\N	\N	2	2	\N
670	4	1535	RP	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
690	7	1537	RP	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
720	3	1539	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
740	3	1541	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
770	4	1543	RP	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
790	2	1545	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
810	2	1546	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
824	6	1548	RP	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
830	3	1550	RP	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
850	3	1552	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
870	2	1554	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
890	2	1556	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
971	2	1558	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
972	2	1559	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
982	1	1562	SM	NODATA	NODATA	\N	\N	\N	\N	2	1	\N
984	1	1564	SM	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
997	4	1567	RP	NODATA	NODATA	\N	\N	\N	\N	2	0	\N
10	2	1570	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
30	2	1572	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
50	1	1574	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
70	2	1576	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
100	2	1579	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
400	2	1582	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
500	3	1583	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
800	3	1586	SM	NODATA	NODATA	\N	\N	\N	\N	3	3	\N
125	1	1589	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
140	3	1591	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
160	2	1593	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
180	2	1595	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
205	1	1597	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
210	3	1598	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
230	2	1600	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
250	3	1602	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
265	5	1604	RP	NODATA	NODATA	\N	\N	\N	\N	3	5	\N
280	2	1606	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
310	4	1608	RP	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
320	2	1609	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
335	7	1611	RP	NODATA	NODATA	\N	\N	\N	\N	3	7	\N
350	4	1613	RP	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
370	3	1615	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
390	2	1617	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
420	4	1619	RP	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
440	5	1621	RP	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
450	3	1622	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
470	2	1624	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
490	3	1626	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
520	2	1628	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
540	4	1630	RP	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
560	3	1632	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
570	5	1633	RP	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
590	11	1635	RP	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
615	12	1637	RP	NODATA	NODATA	\N	\N	\N	\N	3	12	\N
640	3	1640	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
660	2	1642	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
690	7	1645	RP	NODATA	NODATA	\N	\N	\N	\N	3	7	\N
710	3	1646	SM	NODATA	NODATA	\N	\N	\N	\N	3	3	\N
740	3	1649	SM	NODATA	NODATA	\N	\N	\N	\N	3	3	\N
775	6	1652	RP	NODATA	NODATA	\N	\N	\N	\N	3	6	\N
810	2	1654	SM	NODATA	NODATA	\N	\N	\N	\N	3	2	\N
828	4	1657	RP	NODATA	NODATA	\N	\N	\N	\N	3	4	\N
850	3	1660	SM	NODATA	NODATA	\N	\N	\N	\N	3	3	\N
870	2	1662	SM	NODATA	NODATA	\N	\N	\N	\N	3	2	\N
890	2	1664	SM	NODATA	NODATA	\N	\N	\N	\N	3	2	\N
971	2	1666	SM	NODATA	NODATA	\N	\N	\N	\N	3	2	\N
972	2	1667	SM	NODATA	NODATA	\N	\N	\N	\N	3	2	\N
974	3	1669	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
983	1	1671	SM	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
990	1	1673	SM	NODATA	NODATA	\N	\N	\N	\N	3	1	\N
997	4	1675	RP	NODATA	NODATA	\N	\N	\N	\N	3	0	\N
999	4	1677	RP	NODATA	NODATA	\N	\N	\N	\N	3	4	\N
10	2	1678	SM	NODATA	NODATA	\N	\N	\N	\N	4	2	\N
30	2	1680	SM	NODATA	NODATA	\N	\N	\N	\N	4	2	\N
50	1	1682	SM	NODATA	NODATA	\N	\N	\N	\N	4	1	\N
70	2	1684	SM	NODATA	NODATA	\N	\N	\N	\N	4	2	\N
90	1	1686	SM	NODATA	NODATA	\N	\N	\N	\N	4	1	\N
100	2	1687	SM	NODATA	NODATA	\N	\N	\N	\N	4	2	\N
300	3	1689	SM	NODATA	NODATA	\N	\N	\N	\N	4	3	\N
500	3	1691	SM	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
700	2	1693	SM	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
110	2	1695	SM	NODATA	NODATA	\N	\N	\N	\N	4	2	\N
120	2	1696	SM	NODATA	NODATA	\N	\N	\N	\N	4	2	\N
130	7	1698	RP	NODATA	NODATA	\N	\N	\N	\N	4	7	\N
150	2	1700	SM	NODATA	NODATA	\N	\N	\N	\N	4	2	\N
170	3	1702	SM	NODATA	NODATA	\N	\N	\N	\N	4	3	\N
190	2	1704	SM	NODATA	NODATA	\N	\N	\N	\N	4	2	\N
210	3	1706	SM	NODATA	NODATA	\N	\N	\N	\N	4	3	\N
220	3	1707	SM	NODATA	NODATA	\N	\N	\N	\N	4	3	\N
240	2	1709	SM	NODATA	NODATA	\N	\N	\N	\N	4	2	\N
260	2	1711	SM	NODATA	NODATA	\N	\N	\N	\N	4	2	\N
280	2	1714	SM	NODATA	NODATA	\N	\N	\N	\N	4	2	\N
310	4	1716	RP	NODATA	NODATA	\N	\N	\N	\N	4	4	\N
335	7	1719	RP	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
340	3	1720	SM	NODATA	NODATA	\N	\N	\N	\N	4	3	\N
370	3	1723	SM	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
410	2	1726	SM	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
430	2	1728	SM	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
460	2	1731	SM	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
490	3	1734	SM	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
520	2	1736	SM	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
540	4	1738	RP	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
560	3	1740	SM	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
580	2	1742	SM	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
610	2	1744	SM	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
620	7	1746	RP	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
640	3	1748	SM	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
660	2	1750	SM	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
670	4	1751	RP	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
690	7	1753	RP	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
720	3	1755	SM	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
740	3	1757	SM	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
770	4	1759	RP	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
790	2	1761	SM	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
810	2	1762	SM	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
824	6	1764	RP	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
830	3	1766	RP	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
850	3	1768	SM	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
870	2	1770	SM	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
890	2	1772	SM	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
895	5	1773	RP	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
972	2	1775	SM	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
974	3	1777	SM	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
983	1	1779	SM	NODATA	NODATA	\N	\N	\N	\N	4	1	\N
580	2	3151	SM	NODATA	NODATA	\N	\N	\N	\N	19	0	\N
660	2	3152	SM	NODATA	NODATA	\N	\N	\N	\N	19	0	\N
770	6	3153	RP	NODATA	NODATA	\N	\N	\N	\N	19	0	\N
820	2	3154	SM	NODATA	NODATA	\N	\N	\N	2014-09-28 19:10:42	19	2	\N
890	2	3155	SM	NODATA	NODATA	\N	\N	\N	2014-09-28 19:03:11	19	2	\N
974	4	3157	RP	NODATA	NODATA	\N	\N	\N	\N	19	0	\N
995	1	3159	SM	NODATA	NODATA	\N	\N	\N	\N	19	0	\N
260	3	3161	RP	NODATA	NODATA	\N	\N	\N	2014-09-28 16:52:26	19	3	\N
335	7	3162	RP	NODATA	NODATA	\N	\N	\N	\N	19	0	\N
530	2	3163	SM	NODATA	NODATA	\N	\N	\N	\N	19	0	\N
650	2	3164	SM	NODATA	NODATA	\N	\N	\N	\N	19	0	\N
800	3	3165	RP	NODATA	NODATA	\N	\N	\N	2014-09-28 17:10:41	19	3	\N
50	1	3166	SM	NODATA	NODATA	\N	\N	\N	2014-09-28 19:46:04	19	1	\N
310	5	3167	RP	NODATA	NODATA	\N	\N	\N	2014-09-28 17:28:29	19	5	\N
640	3	3168	RP	NODATA	NODATA	\N	\N	\N	\N	19	0	\N
125	1	3169	SM	NODATA	NODATA	\N	\N	\N	2014-09-28 12:34:46	19	1	\N
200	1	3170	SM	NODATA	NODATA	\N	\N	\N	2014-09-28 12:09:44	19	1	\N
790	2	3171	SM	NODATA	NODATA	\N	\N	\N	2014-09-28 19:08:42	19	2	\N
100	2	3172	SM	NODATA	NODATA	\N	\N	\N	2014-09-28 13:17:10	19	2	\N
340	4	3173	RP	NODATA	NODATA	\N	\N	\N	2014-09-28 17:04:29	19	4	\N
824	6	3174	RP	NODATA	NODATA	\N	\N	\N	\N	19	0	\N
270	3	3175	RP	NODATA	NODATA	\N	\N	\N	2014-09-28 18:20:48	19	3	\N
710	3	3176	RP	NODATA	NODATA	\N	\N	\N	2014-09-28 18:58:20	19	3	\N
205	1	3177	SM	NODATA	NODATA	\N	\N	\N	2014-09-28 19:00:51	19	1	\N
720	3	3178	RP	NODATA	NODATA	\N	\N	\N	2014-09-28 17:01:43	19	3	\N
860	2	3179	SM	NODATA	NODATA	\N	\N	\N	2014-09-28 12:59:56	19	2	\N
220	3	3180	RP	NODATA	NODATA	\N	\N	\N	2014-09-28 17:42:31	19	3	\N
9715	1	3181	SM	NODATA	NODATA	\N	\N	\N	2014-09-29 09:05:49	19	1	à la suite de la démission le 31 décembre 2013 de M. Louis-Constant FLEMING
9713	1	3184	SM	NODATA	NODATA	\N	\N	\N	2014-09-28 17:08:20	19	1	\N
80	2	3186	SM	NODATA	NODATA	\N	\N	\N	2014-09-28 13:06:20	19	2	\N
630	3	3187	RP	NODATA	NODATA	\N	\N	\N	\N	19	0	\N
350	4	3188	RP	NODATA	NODATA	\N	\N	\N	2014-09-28 17:35:20	19	4	\N
990	1	1781	SM	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
997	4	1783	RP	NODATA	NODATA	\N	\N	\N	\N	4	4	\N
999	4	1785	RP	NODATA	NODATA	\N	\N	\N	\N	4	0	\N
10	2	1786	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
40	1	1789	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
60	4	1791	RP	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
90	1	1794	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
400	2	1797	SM	NODATA	NODATA	\N	\N	\N	\N	5	2	\N
500	3	1798	SM	NODATA	NODATA	\N	\N	\N	\N	5	3	\N
800	3	1801	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
125	1	1804	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
140	3	1806	SM	NODATA	NODATA	\N	\N	\N	\N	5	0	\N
610	2	1144	SM	NODATA	NODATA	\N	\N	\N	\N	18	2	\N
615	12	1145	RP	NODATA	NODATA	\N	\N	\N	\N	18	12	\N
630	3	1147	SM	NODATA	NODATA	\N	\N	\N	\N	18	3	\N
650	2	1149	SM	NODATA	NODATA	\N	\N	\N	\N	18	2	\N
670	5	1151	RP	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
690	7	1153	RP	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
720	3	1155	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
740	3	1157	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
760	6	1158	RP	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
775	6	1160	RP	NODATA	NODATA	\N	\N	\N	\N	18	6	\N
810	2	1162	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
824	6	1164	RP	NODATA	NODATA	\N	\N	\N	\N	18	6	\N
830	4	1166	RP	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
850	3	1168	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
860	2	1169	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
880	2	1171	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
895	6	1173	RP	NODATA	NODATA	\N	\N	\N	\N	18	6	\N
972	2	1175	SM	NODATA	NODATA	\N	\N	\N	\N	18	2	\N
974	4	1177	RP	NODATA	NODATA	\N	\N	\N	\N	18	4	\N
983	2	1179	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
984	1	1180	SM	NODATA	NODATA	\N	\N	\N	\N	18	0	\N
995	1	1182	SM	NODATA	NODATA	\N	\N	\N	\N	18	1	\N
\.


--
-- Data for Name: dpttypman; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY dpttypman (dptnum, typmancod, dpttypmanid) FROM stdin;
300	SENAT	113
330	SENAT	115
320	SENAT4R	166
350	SENAT4R	169
370	SENAT4R	171
400	SENAT4R	174
420	SENAT4R	176
440	SENAT4R	178
470	SENAT4R	181
490	SENAT4R	183
520	SENAT4R	186
540	SENAT4R	188
570	SENAT4R	191
590	SENAT4R	193
615	SENAT4R	196
630	SENAT4R	198
670	SENAT4R	201
700	SENAT4R	204
720	SENAT4R	206
740	SENAT4R	208
790	SENAT4R	211
810	SENAT4R	213
840	SENAT4R	216
860	SENAT4R	218
890	SENAT4R	221
100	SENAT3R	273
120	SENAT3R	275
140	SENAT3R	278
160	SENAT3R	280
210	SENAT3R	283
240	SENAT3R	285
270	SENAT3R	288
290	SENAT3R	290
320	SENAT3R	293
340	SENAT3R	295
370	SENAT3R	298
400	SENAT3R	301
420	SENAT3R	303
450	SENAT3R	305
480	SENAT3R	308
500	SENAT3R	310
530	SENAT3R	313
550	SENAT3R	315
580	SENAT3R	318
600	SENAT3R	320
620	SENAT3R	322
490	SENAT	1
540	SENAT	2
550	SENAT	3
590	SENAT	4
600	SENAT	5
615	SENAT	6
670	SENAT	7
680	SENAT	8
700	SENAT	9
775	SENAT	10
810	SENAT	11
828	SENAT	12
830	SENAT	13
840	SENAT	14
850	SENAT	15
880	SENAT	16
895	SENAT	17
971	SENAT	18
972	SENAT	19
982	SENAT	20
984	SENAT	21
990	SENAT	22
500	SENAT	23
570	SENAT	24
730	SENAT	25
1021	SENAT	26
1040	SENAT	27
1041	SENAT	28
1042	SENAT	29
1043	SENAT	30
1044	SENAT	31
1045	SENAT	32
1025	SENAT	33
1012	SENAT	34
1030	SENAT	35
1033	SENAT	36
1046	SENAT	37
380	SENAT	38
510	SENAT	39
10	SENAT	40
470	SENAT	41
30	SENAT	42
40	SENAT	43
130	SENAT	44
170	SENAT	45
280	SENAT	46
440	SENAT	47
520	SENAT	48
580	SENAT	49
660	SENAT	50
770	SENAT	51
820	SENAT	52
890	SENAT	53
973	SENAT	54
974	SENAT	55
983	SENAT	56
995	SENAT	57
998	SENAT	58
260	SENAT	59
335	SENAT	60
530	SENAT	61
650	SENAT	62
800	SENAT	63
50	SENAT	64
310	SENAT	65
640	SENAT	66
125	SENAT	67
9999	SENAT	69
1004	SENAT	71
1029	SENAT	73
1011	SENAT	75
1020	SENAT	76
790	SENAT	78
340	SENAT	80
270	SENAT	82
205	SENAT	84
720	SENAT	85
220	SENAT	87
9715	SENAT	89
1052	SENAT	91
9713	SENAT	92
80	SENAT	94
350	SENAT	96
740	SENAT	98
70	SENAT	99
390	SENAT	101
60	SENAT	103
150	SENAT	106
180	SENAT	108
210	SENAT	110
265	SENAT	112
320	SENAT	114
360	SENAT	116
400	SENAT	117
420	SENAT	118
450	SENAT	119
460	SENAT	120
480	SENAT	121
997	SENAT	122
20	SENAT	123
290	SENAT	124
370	SENAT	125
430	SENAT	126
560	SENAT	127
620	SENAT	128
690	SENAT	129
760	SENAT	130
120	SENAT	131
140	SENAT	132
870	SENAT	133
410	SENAT	134
1053	SENAT	135
1054	SENAT	136
10	SENAT4R	137
20	SENAT4R	138
30	SENAT4R	139
50	SENAT4R	140
60	SENAT4R	141
70	SENAT4R	142
80	SENAT4R	143
90	SENAT4R	144
100	SENAT4R	145
110	SENAT4R	146
120	SENAT4R	147
125	SENAT4R	148
130	SENAT4R	149
140	SENAT4R	150
150	SENAT4R	151
160	SENAT4R	152
170	SENAT4R	153
180	SENAT4R	154
190	SENAT4R	155
210	SENAT4R	156
230	SENAT4R	157
240	SENAT4R	158
250	SENAT4R	159
260	SENAT4R	160
270	SENAT4R	161
280	SENAT4R	162
290	SENAT4R	163
300	SENAT4R	164
310	SENAT4R	165
330	SENAT4R	167
340	SENAT4R	168
360	SENAT4R	170
380	SENAT4R	172
390	SENAT4R	173
410	SENAT4R	175
430	SENAT4R	177
450	SENAT4R	179
460	SENAT4R	180
480	SENAT4R	182
500	SENAT4R	184
510	SENAT4R	185
530	SENAT4R	187
550	SENAT4R	189
560	SENAT4R	190
580	SENAT4R	192
600	SENAT4R	194
610	SENAT4R	195
620	SENAT4R	197
650	SENAT4R	199
660	SENAT4R	200
680	SENAT4R	202
690	SENAT4R	203
710	SENAT4R	205
730	SENAT4R	207
760	SENAT4R	209
770	SENAT4R	210
800	SENAT4R	212
820	SENAT4R	214
830	SENAT4R	215
850	SENAT4R	217
870	SENAT4R	219
880	SENAT4R	220
971	SENAT4R	222
972	SENAT4R	223
973	SENAT4R	224
974	SENAT4R	225
982	SENAT4R	226
983	SENAT4R	227
995	SENAT4R	228
1000	SENAT4R	229
1001	SENAT4R	230
1002	SENAT4R	231
1003	SENAT4R	232
1004	SENAT4R	233
1005	SENAT4R	234
1006	SENAT4R	235
1007	SENAT4R	236
1008	SENAT4R	237
1009	SENAT4R	238
1010	SENAT4R	239
1011	SENAT4R	240
1012	SENAT4R	241
1013	SENAT4R	242
1014	SENAT4R	243
1015	SENAT4R	244
1016	SENAT4R	245
1017	SENAT4R	246
1019	SENAT4R	247
1020	SENAT4R	248
1021	SENAT4R	249
1022	SENAT4R	250
1023	SENAT4R	251
1024	SENAT4R	252
1025	SENAT4R	253
1026	SENAT4R	254
1027	SENAT4R	255
1028	SENAT4R	256
1029	SENAT4R	257
1031	SENAT4R	258
1032	SENAT4R	259
1033	SENAT4R	260
1034	SENAT4R	261
1036	SENAT4R	262
1050	SENAT4R	263
9999	SENAT4R	264
10	SENAT3R	265
20	SENAT3R	266
30	SENAT3R	267
50	SENAT3R	268
60	SENAT3R	269
70	SENAT3R	270
80	SENAT3R	271
90	SENAT3R	272
110	SENAT3R	274
125	SENAT3R	276
130	SENAT3R	277
150	SENAT3R	279
180	SENAT3R	281
190	SENAT3R	282
230	SENAT3R	284
250	SENAT3R	286
260	SENAT3R	287
280	SENAT3R	289
300	SENAT3R	291
310	SENAT3R	292
330	SENAT3R	294
350	SENAT3R	296
360	SENAT3R	297
380	SENAT3R	299
390	SENAT3R	300
410	SENAT3R	302
430	SENAT3R	304
460	SENAT3R	306
470	SENAT3R	307
490	SENAT3R	309
510	SENAT3R	311
520	SENAT3R	312
540	SENAT3R	314
560	SENAT3R	316
570	SENAT3R	317
590	SENAT3R	319
610	SENAT3R	321
630	SENAT3R	323
650	SENAT3R	324
660	SENAT3R	325
670	SENAT3R	326
680	SENAT3R	327
690	SENAT3R	328
700	SENAT3R	329
710	SENAT3R	330
720	SENAT3R	331
730	SENAT3R	332
740	SENAT3R	333
770	SENAT3R	334
790	SENAT3R	335
800	SENAT3R	336
810	SENAT3R	337
820	SENAT3R	338
830	SENAT3R	339
840	SENAT3R	340
850	SENAT3R	341
860	SENAT3R	342
870	SENAT3R	343
880	SENAT3R	344
890	SENAT3R	345
971	SENAT3R	346
972	SENAT3R	347
974	SENAT3R	348
995	SENAT3R	349
1000	SENAT3R	350
1002	SENAT3R	351
1004	SENAT3R	352
1008	SENAT3R	353
1011	SENAT3R	354
1020	SENAT3R	355
1026	SENAT3R	356
1029	SENAT3R	357
1032	SENAT3R	358
1035	SENAT3R	359
1037	SENAT3R	360
1038	SENAT3R	361
1039	SENAT3R	362
9998	SENAT3R	363
9999	SENAT3R	364
200	SENAT	68
1000	SENAT	70
1002	SENAT	72
1032	SENAT	74
1047	SENAT	77
100	SENAT	79
824	SENAT	81
710	SENAT	83
860	SENAT	86
999	SENAT	88
1051	SENAT	90
250	SENAT	93
630	SENAT	95
1026	SENAT	97
240	SENAT	100
610	SENAT	102
90	SENAT	104
110	SENAT	105
160	SENAT	107
190	SENAT	109
230	SENAT	111
100	SENAT2E	381
120	SENAT2E	382
140	SENAT2E	383
160	SENAT2E	384
210	SENAT2E	385
240	SENAT2E	386
270	SENAT2E	387
290	SENAT2E	388
320	SENAT2E	389
340	SENAT2E	390
370	SENAT2E	391
400	SENAT2E	392
420	SENAT2E	393
450	SENAT2E	394
480	SENAT2E	395
500	SENAT2E	396
530	SENAT2E	397
550	SENAT2E	398
580	SENAT2E	399
600	SENAT2E	400
620	SENAT2E	401
10	SENAT2E	402
20	SENAT2E	403
30	SENAT2E	404
50	SENAT2E	405
60	SENAT2E	406
70	SENAT2E	407
80	SENAT2E	408
90	SENAT2E	409
110	SENAT2E	410
125	SENAT2E	411
130	SENAT2E	412
150	SENAT2E	413
180	SENAT2E	414
190	SENAT2E	415
230	SENAT2E	416
250	SENAT2E	417
260	SENAT2E	418
280	SENAT2E	419
300	SENAT2E	420
310	SENAT2E	421
330	SENAT2E	422
350	SENAT2E	423
360	SENAT2E	424
380	SENAT2E	425
390	SENAT2E	426
410	SENAT2E	427
430	SENAT2E	428
460	SENAT2E	429
470	SENAT2E	430
490	SENAT2E	431
510	SENAT2E	432
520	SENAT2E	433
540	SENAT2E	434
560	SENAT2E	435
570	SENAT2E	436
590	SENAT2E	437
610	SENAT2E	438
630	SENAT2E	439
650	SENAT2E	440
660	SENAT2E	441
670	SENAT2E	442
680	SENAT2E	443
690	SENAT2E	444
700	SENAT2E	445
710	SENAT2E	446
720	SENAT2E	447
730	SENAT2E	448
740	SENAT2E	449
770	SENAT2E	450
790	SENAT2E	451
800	SENAT2E	452
810	SENAT2E	453
820	SENAT2E	454
830	SENAT2E	455
840	SENAT2E	456
850	SENAT2E	457
860	SENAT2E	458
870	SENAT2E	459
880	SENAT2E	460
890	SENAT2E	461
971	SENAT2E	462
972	SENAT2E	463
974	SENAT2E	464
995	SENAT2E	465
1000	SENAT2E	466
1002	SENAT2E	467
1004	SENAT2E	468
1008	SENAT2E	469
1011	SENAT2E	470
1020	SENAT2E	471
1026	SENAT2E	472
1029	SENAT2E	473
1032	SENAT2E	474
1035	SENAT2E	475
1037	SENAT2E	476
1038	SENAT2E	477
1039	SENAT2E	478
9998	SENAT2E	479
9999	SENAT2E	480
535	SENAT2E	481
9900	SENAT	482
\.


--
-- Data for Name: ele; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY ele (typmancod, eleann, eledat, eledatdeb, eledatfinpre, eleser, elelic, elelib, elelil, syscredat, sysmajdat, eleid, elepar) FROM stdin;
SENAT	2008	2008-09-21 00:00:00	2008-10-01 00:00:00	2008-09-30 00:00:00	A	Renouvellement 2008	Renouvellement du 21 Septembre 2008	Renouvellement du 21 Septembre 2008 (Série A)	\N	\N	1	NON
SENAT	1992	1992-09-27 00:00:00	1992-10-02 00:00:00	1992-10-01 00:00:00	B	Renouvellement 1992 	Renouvellement triennal du 27 Septembre 1992	Renouvellement triennal du 27 Septembre 1992 (série B)	\N	\N	2	NON
SENAT	1995	1995-09-24 00:00:00	1995-10-02 00:00:00	1995-10-01 00:00:00	C	Renouvellement 1995	Renouvellement triennal du 24 Septembre 1995	Renouvellement triennal du 24 Septembre 1995 (Série C)	\N	\N	3	NON
SENAT	1998	1998-09-27 00:00:00	1998-10-01 00:00:00	1998-09-30 00:00:00	A	Renouvellement 1998	Renouvellement triennal du 27 Septembre 1998	Renouvellement triennal du 27 Septembre 1998 (Série A)	\N	\N	4	NON
SENAT	2001	2001-09-23 00:00:00	2001-10-01 00:00:00	2001-09-30 00:00:00	B	Renouvellement 2001	Renouvellement triennal du 23 Septembre 2001	Renouvellement triennal du 23 Septembre 2001 (Série B)	\N	\N	5	NON
SENAT	2004	2004-09-26 00:00:00	2004-10-01 00:00:00	2004-09-30 00:00:00	C	Renouvellement 2004	Renouvellement triennal du 26 Septembre 2004	Renouvellement triennal du 26 Septembre 2004 (Série C)	\N	\N	6	NON
SENAT	1959	1959-04-26 00:00:00	1959-04-28 00:00:00	1959-04-27 00:00:00	X	Constitution de 1959	Constitution du 26 Avril 1959	Constitution du 26 Avril 1959	\N	\N	7	NON
SENAT	1962	1962-09-23 00:00:00	1962-10-02 00:00:00	1962-10-01 00:00:00	A	Renouvellement 1962	Renouvellement triennal du 26 Septembre 1962	Renouvellement triennal du 26 Septembre 1962 (Série A)	\N	\N	8	NON
SENAT	1965	1965-09-26 00:00:00	1965-10-02 00:00:00	1965-10-01 00:00:00	B	Renouvellement 1965	Renouvellement triennal du 26 septembre 1965	Renouvellement triennal du 26 septembre 1965 (Série B)	\N	\N	9	NON
SENAT	1971	1971-09-26 00:00:00	1971-10-02 00:00:00	1971-10-01 00:00:00	A	Renouvellement 1971	Renouvellement triennal du 26 septembre 1971	Renouvellement triennal du 26 septembre 1971 (Série A)	\N	\N	10	NON
SENAT	1974	1974-09-22 00:00:00	1974-10-02 00:00:00	1974-10-01 00:00:00	B	Renouvellement 1974	Renouvellement triennal du 22 septembre 1974	Renouvellement triennal du 22 septembre 1974 (Série B)	\N	\N	11	NON
SENAT	1977	1977-09-25 00:00:00	1977-10-03 00:00:00	1977-10-02 00:00:00	C	Renouvellement 1977	Renouvellement triennal du 25 septembre 1977	Renouvellement triennal du 25 septembre 1977 (Série C)	\N	\N	12	NON
SENAT	1980	1980-09-28 00:00:00	1980-10-02 00:00:00	1980-10-01 00:00:00	A	Renouvellement 1980	Renouvellement triennal du 28 septembre 1980	Renouvellement triennal du 28 septembre 1980 (Série A)	\N	\N	13	NON
SENAT	1983	1983-09-25 00:00:00	1983-10-03 00:00:00	1983-10-02 00:00:00	B	Renouvellement 1983	Renouvellement triennal du 25 septembre 1983	Renouvellement triennal du 25 septembre 1983 (Série B)	\N	\N	14	NON
SENAT	1986	1986-09-28 00:00:00	1986-10-02 00:00:00	1986-10-01 00:00:00	C	Renouvellement 1986	Renouvellement triennal du 28 septembre 1986	Renouvellement triennal du 28 septembre 1986 (Série C)	\N	\N	15	NON
SENAT	1989	1989-09-24 00:00:00	1989-10-02 00:00:00	1989-10-01 00:00:00	A	Renouvellement 1989	Renouvellement triennal du 24 septembre 1989	Renouvellement triennal du 24 septembre 1989 (Série A)	\N	\N	16	NON
SENAT	1968	1968-09-22 00:00:00	1968-10-02 00:00:00	1968-10-01 00:00:00	C	Renouvellement 1968	Renouvellement triennal du 22 septembre 1968	Renouvellement triennal du 22 septembre 1968 (Série C)	\N	\N	17	NON
SENAT	2011	2011-09-25 00:00:00	2011-10-01 00:00:00	2011-09-30 00:00:00	1	Renouvellement 2011	Renouvellement du 25 Septembre 2011	Renouvellement du 25 Septembre 2011 (Série 1)	\N	\N	18	NON
SENAT	2014	2014-09-28 00:00:00	2014-09-28 00:00:00	\N	1	Partielles renouvellement 2014	Élections partielles coïncidant avec le renouvellement de 2014	Circonscriptions de la série 1 faisant l'objet d'une élection partielle dont la date coïncide avec le renouvellement de 2014	2014-08-22 00:00:00	\N	21	OUI
SENAT	2020	2020-09-27 00:00:00	2020-10-01 00:00:00	2020-09-30 00:00:00	2	Renouvellement 2020	Renouvellement de Septembre 2020	Renouvellement de Septembre 2020 (Série 2)	2019-11-21 00:00:00	\N	24	NON
SENAT	2017	2017-09-24 00:00:00	2017-10-02 00:00:00	2017-10-01 00:00:00	1	Renouvellement 2017	Renouvellement de Septembre 2017	Renouvellement de Septembre 2014 (Série 1)	2016-06-16 00:00:00	\N	22	NON
SENAT	2014	2014-09-28 00:00:00	2014-10-01 00:00:00	2014-09-30 00:00:00	2	Renouvellement 2014	Renouvellement de Septembre 2014	Renouvellement de Septembre 2014 (Série 2)	\N	\N	19	NON
SENAT	2017	2017-09-24 00:00:00	2017-09-25 00:00:00	\N	2	Partielles renouvellement 2017	Élections partielles coïncidant avec le renouvellement de 2017	Circonscriptions de la série 2 faisant l'objet d'une élection partielle dont la date coïncide avec le renouvellement de 2017	2017-08-18 12:45:37	\N	23	OUI
\.


--
-- Data for Name: elucan; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY elucan (eluid, eludatdeb, eludatelu, eludatfin, temvalcod, evelic, evelib, evelil, eveobs, eluanndeb, eluannfin, elunbrhab, typmancod, dptnum, senmat, canart, eludatcum, syscredat, sysmajdat) FROM stdin;
5097	\N	\N	2004-03-28 00:00:00	ANCIEN	\N	Chartres Sud-Ouest	\N	\N	1992	2004	\N	CANTON	280	98023Q	de 	\N	\N	\N
5102	1985-03-17 00:00:00	\N	2004-03-28 00:00:00	ANCIEN	\N	Cérilly	\N	\N	1985	2004	\N	CANTON	30	98024R	de 	\N	\N	\N
5112	\N	\N	2004-03-21 00:00:00	ANCIEN	\N	Saint-Flour Sud	\N	\N	1992	2004	\N	CANTON	150	98027U	de 	\N	\N	\N
5114	1992-03-22 00:00:00	\N	1998-11-27 00:00:00	ANCIEN	\N	Le Russey	\N	\N	\N	1988	\N	CANTON	250	98028V	de 	\N	\N	\N
5133	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Gimont	\N	\N	1982	2001	\N	CANTON	320	98032R	de 	\N	\N	\N
5136	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Aignan	\N	\N	1988	2001	\N	CANTON	320	98033S	d'	\N	\N	\N
5140	1973-09-30 00:00:00	\N	2004-03-28 00:00:00	ANCIEN	\N	Le Vigan	\N	\N	1973	2004	\N	CANTON	300	98034T	de 	\N	\N	\N
5146	\N	\N	2004-03-28 00:00:00	ANCIEN	\N	Brayne	\N	\N	1958	2004	\N	CANTON	20	66002K	de 	\N	\N	\N
5150	\N	\N	2004-03-28 00:00:00	ANCIEN	\N	Antraigues sur volane	\N	\N	1979	2004	\N	CANTON	70	98037W	d'	\N	\N	\N
5172	1988-09-27 00:00:00	\N	2003-08-28 00:00:00	ANCIEN	\N	La Guerche-de-Bretagne	\N	\N	1988	2003	\N	CANTON	350	98043U	de 	\N	\N	\N
5169	1998-03-22 00:00:00	\N	2004-03-27 00:00:00	ANCIEN	\N	Bayeux	\N	\N	\N	\N	\N	CANTON	140	98042T	de 	\N	\N	\N
5174	\N	\N	2004-03-28 00:00:00	ANCIEN	\N	Fougères Sud	\N	\N	1985	2004	\N	CANTON	350	98044V	de 	\N	\N	\N
5177	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Dol-de-Bretagne	\N	\N	1988	2001	\N	CANTON	350	98045W	de 	\N	\N	\N
5190	1988-10-03 00:00:00	\N	2001-03-11 00:00:00	ANCIEN	\N	Ploudiry	\N	\N	1988	2001	\N	CANTON	290	98046X	de 	\N	\N	\N
5202	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Quillebeuf-sur-Seine	\N	\N	1981	2001	\N	CANTON	270	98050T	de 	\N	\N	\N
5206	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Quimperlé	\N	\N	\N	2001	\N	CANTON	290	98051U	de 	\N	\N	\N
5210	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Ribérac	\N	\N	\N	2001	\N	CANTON	240	98029W	de 	\N	\N	\N
5237	\N	\N	2018-04-27 00:00:00	ANCIEN	\N	Brive centre	\N	\N	1992	1998	\N	CANTON	190	98007Q	de 	\N	\N	2018-04-30 14:05:27
5241	\N	\N	\N	ANCIEN	\N	Nice	\N	\N	1993	1997	\N	CANTON	60	98040R	de 	\N	\N	\N
5273	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Pampelonne	\N	\N	1988	2001	\N	CANTON	810	98054X	de 	\N	\N	\N
5816	\N	\N	\N	ANCIEN	\N	Steenvoorde	\N	\N	1992	1998	\N	CANTON	590	83013L	\N	\N	\N	\N
5817	\N	\N	\N	ANCIEN	\N	Steenvoorde	\N	\N	1970	1992	\N	CANTON	590	83013L	\N	\N	\N	\N
5821	\N	\N	2024-03-13 00:00:00	ANCIEN	\N	Lille-Centre	\N	canton de Lille-Centre	1982	1999	\N	CANTON	590	99001N	\N	\N	\N	\N
5834	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Les Echelles	\N	\N	1982	2001	\N	CANTON	730	95067Q	\N	\N	\N	\N
5858	\N	\N	\N	ANCIEN	\N	Saint-Chéron	\N	\N	1982	2001	\N	CANTON	265	93007T	\N	\N	\N	\N
5864	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Gennevilliers-sud	\N	\N	1994	2001	\N	CANTON	335	00002B	\N	\N	\N	\N
5871	1985-03-17 00:00:00	\N	1998-03-15 00:00:00	ANCIEN	\N	Chateauroux-Ouest	\N	\N	1985	1998	\N	CANTON	360	89020L	\N	\N	\N	\N
5876	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Metz 4	\N	\N	\N	2001	\N	CANTON	570	00004D	\N	\N	\N	\N
5888	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Brunoy	\N	\N	1985	2001	\N	CANTON	265	01001E	\N	\N	\N	\N
6006	2001-03-11 00:00:00	\N	2008-03-16 00:00:00	ANCIEN	\N	Rignac	\N	\N	2001	2008	\N	CANTON	120	80035E	\N	\N	\N	\N
6007	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Thônes	\N	\N	2001	\N	\N	CANTON	740	95005A	\N	\N	\N	\N
6009	2001-03-11 00:00:00	\N	2008-03-21 00:00:00	ANCIEN	\N	Chéroy	\N	\N	2001	2008	\N	CANTON	890	86044G	\N	\N	\N	\N
6015	2001-03-11 00:00:00	\N	2020-02-21 00:00:00	ANCIEN	\N	Châteldon	\N	\N	2001	\N	\N	CANTON	630	81015E	\N	\N	\N	\N
6263	2001-03-11 00:00:00	\N	2011-10-27 00:00:00	ANCIEN	\N	Pampelonne	\N	\N	2001	2011	\N	CANTON	810	98054X	\N	\N	\N	\N
6266	2001-03-11 00:00:00	\N	2004-04-01 00:00:00	ANCIEN	\N	Châlus	\N	\N	2001	2004	\N	CANTON	870	95055L	\N	\N	\N	\N
6267	2001-03-18 00:00:00	\N	\N	ACTIF	\N	Paris	\N	\N	2001	\N	\N	CANTON	615	95058P	\N	\N	\N	\N
6275	2001-03-11 00:00:00	\N	\N	ANCIEN	\N	Besse-sur-Issole	\N	\N	2001	2002	\N	CANTON	830	95031C	\N	\N	\N	\N
6277	\N	\N	\N	ANCIEN	\N	Guillaumes	\N	\N	\N	2001	\N	CANTON	60	88012G	\N	\N	\N	\N
6281	2001-03-11 00:00:00	\N	2008-03-21 00:00:00	ANCIEN	\N	Hallencourt	\N	\N	2001	\N	\N	CANTON	800	95047L	\N	\N	\N	\N
6283	2001-03-18 00:00:00	\N	2001-03-27 00:00:00	ANCIEN	\N	Saint-Amand-Montrond	\N	\N	2001	2001	\N	CANTON	180	89045V	\N	\N	\N	\N
6284	2001-03-18 00:00:00	\N	2004-03-28 00:00:00	ANCIEN	\N	Wasselonne	\N	\N	2001	2004	\N	CANTON	670	91002E	\N	\N	\N	\N
6285	2001-03-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	2001	\N	\N	CANTON	615	95022B	\N	\N	\N	\N
6291	2001-03-23 00:00:00	\N	\N	ACTIF	\N	Paris (16ème arrondissement)	\N	\N	2001	\N	\N	CANTON	615	01004H	\N	\N	\N	\N
6292	2001-03-18 00:00:00	\N	2004-04-01 00:00:00	ANCIEN	\N	Sennecey-le-Grand	\N	\N	2001	2004	\N	CANTON	710	95030B	\N	\N	\N	\N
6299	2001-03-18 00:00:00	\N	2018-05-17 00:00:00	ANCIEN	\N	Contres	\N	\N	2001	\N	\N	CANTON	410	86005Y	\N	\N	\N	2018-05-23 11:13:25
6301	\N	\N	\N	ANCIEN	\N	Bourges II	\N	\N	1994	1995	\N	CANTON	180	98025S	\N	\N	\N	\N
6348	2001-03-23 00:00:00	\N	2006-01-21 00:00:00	ANCIEN	\N	Vertou	\N	\N	2001	2006	\N	CANTON	440	83025Q	\N	\N	\N	\N
6390	\N	\N	2011-03-27 00:00:00	ANCIEN	\N	Conflans-en-Jarnisy	\N	\N	\N	2011	\N	CANTON	540	01015L	\N	\N	\N	\N
6034	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Lessay	\N	\N	2001	\N	\N	CANTON	500	82002D	\N	\N	\N	\N
6055	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Le Marin	\N	\N	2001	\N	\N	CANTON	972	86021Y	\N	\N	\N	\N
6064	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Erstein	\N	\N	2001	\N	\N	CANTON	670	95036H	\N	\N	\N	\N
6065	2001-03-11 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Vaison-la-Romaine	\N	\N	2001	\N	\N	CANTON	840	95037J	\N	\N	\N	\N
1459	\N	\N	2004-03-28 00:00:00	ANCIEN	\N	Rebais	\N	\N	1992	2004	\N	CANTON	770	77033C	de 	\N	\N	\N
1474	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Saint-Hilaire-des-Loges	\N	\N	\N	2001	\N	CANTON	850	87002A	de 	\N	\N	\N
6085	2001-03-11 00:00:00	\N	2008-03-21 00:00:00	ANCIEN	\N	Monesties	\N	\N	2001	\N	\N	CANTON	810	95052H	\N	\N	\N	\N
6087	2001-03-11 00:00:00	\N	2008-03-21 00:00:00	ANCIEN	\N	La Petite Pierre	\N	\N	2001	2008	\N	CANTON	670	92005M	\N	\N	\N	\N
6089	2001-03-11 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Méry-sur-Seine	\N	\N	2001	\N	\N	CANTON	100	89017R	\N	\N	\N	\N
6090	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Saint-Béat	\N	\N	2001	\N	\N	CANTON	310	98011L	\N	\N	\N	\N
6091	2001-03-11 00:00:00	\N	\N	ANCIEN	\N	Tende	\N	\N	2001	2008	\N	CANTON	60	84004P	\N	\N	\N	\N
6095	2001-03-11 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Ribérac	\N	\N	2001	\N	\N	CANTON	240	98029W	\N	\N	\N	\N
6102	2001-03-11 00:00:00	\N	2022-08-18 00:00:00	ANCIEN	\N	Saint-Porchaire	\N	\N	2001	\N	\N	CANTON	170	89014N	\N	\N	\N	\N
6105	2001-03-11 00:00:00	\N	\N	ANCIEN	\N	Cambremer	\N	\N	2001	2004	\N	CANTON	140	89007P	\N	\N	\N	\N
6121	2001-03-11 00:00:00	\N	2008-03-21 00:00:00	ANCIEN	\N	Quimperlé	\N	\N	2001	\N	\N	CANTON	290	98051U	\N	\N	\N	\N
6125	2001-03-11 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Ploudiry	\N	\N	2001	\N	\N	CANTON	290	98046X	\N	\N	\N	\N
6128	2001-03-11 00:00:00	\N	2005-02-20 00:00:00	ANCIEN	\N	Borgo	\N	\N	2001	2005	\N	CANTON	205	98008R	\N	\N	\N	\N
6132	2001-03-11 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Quillebeuf-sur-Seine	\N	\N	2001	\N	\N	CANTON	270	98050T	\N	\N	\N	\N
6137	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Carbonne	\N	\N	2001	\N	\N	CANTON	310	80039J	\N	\N	\N	\N
6146	2001-03-11 00:00:00	\N	2008-03-21 00:00:00	ANCIEN	\N	Saint-Céré	\N	\N	2001	\N	\N	CANTON	460	88004G	\N	\N	\N	\N
1429	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Bapaume	\N	\N	\N	2001	\N	CANTON	620	92017R	de 	\N	\N	\N
6153	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Norrent-Fontès	\N	\N	2001	\N	\N	CANTON	620	92027T	\N	\N	\N	\N
1423	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Paris	\N	\N	\N	2001	\N	CANTON	615	95026F	de 	\N	\N	\N
6163	2001-03-11 00:00:00	\N	2020-09-11 00:00:00	ANCIEN	\N	Remiremont	\N	\N	2001	\N	\N	CANTON	880	77058M	\N	\N	\N	\N
6183	2001-03-11 00:00:00	\N	2008-03-21 00:00:00	ANCIEN	\N	Saignes	\N	\N	2001	\N	\N	CANTON	150	89010J	\N	\N	\N	\N
6187	2001-03-11 00:00:00	\N	2008-03-21 00:00:00	ANCIEN	\N	Aignan	\N	\N	2001	2008	\N	CANTON	320	98033S	\N	\N	\N	\N
6193	2001-03-11 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Marseille Les grands Carmes	\N	\N	2001	\N	\N	CANTON	130	98022P	\N	\N	\N	\N
6226	2001-03-18 00:00:00	\N	\N	ACTIF	\N	Toulouse VI	\N	\N	2001	\N	\N	CANTON	310	98010K	\N	\N	\N	\N
6228	2001-03-18 00:00:00	\N	2008-03-21 00:00:00	ANCIEN	\N	Tulle-Campagne-Sud	\N	\N	2001	\N	\N	CANTON	190	80031A	\N	\N	\N	\N
6229	2001-03-18 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Gimont	\N	\N	2001	\N	\N	CANTON	320	98032R	\N	\N	\N	\N
6230	2001-03-18 00:00:00	\N	\N	ACTIF	\N	Grenoble 2ème canton	\N	\N	2001	\N	\N	CANTON	380	83028T	\N	\N	\N	\N
6231	2001-03-18 00:00:00	\N	2016-03-15 00:00:00	ANCIEN	\N	Meylan	\N	\N	2001	2016	\N	CANTON	380	83020K	\N	\N	\N	\N
6232	2001-03-18 00:00:00	\N	2008-03-21 00:00:00	ANCIEN	\N	Vorey	\N	\N	2001	\N	\N	CANTON	430	78006D	\N	\N	\N	\N
6233	2001-03-18 00:00:00	\N	\N	ACTIF	\N	Metz 4	\N	\N	2001	\N	\N	CANTON	570	00004D	\N	\N	\N	\N
6234	2001-03-18 00:00:00	\N	2008-03-21 00:00:00	ANCIEN	\N	Vénissieux-Sud	\N	\N	2001	\N	\N	CANTON	690	95032D	\N	\N	\N	\N
6235	2001-03-18 00:00:00	\N	2008-03-21 00:00:00	ANCIEN	\N	Les Echelles	\N	\N	2001	\N	\N	CANTON	730	95067Q	\N	\N	\N	\N
6236	2001-03-18 00:00:00	\N	2020-03-21 00:00:00	ANCIEN	\N	Noirmoutier-en-l'île	\N	\N	2001	\N	\N	CANTON	850	86041D	\N	\N	\N	\N
6238	\N	\N	\N	ANCIEN	\N	Garges-les-Gonesse-Est	\N	\N	1985	1995	\N	CANTON	828	95051G	\N	\N	\N	\N
12914	\N	\N	2015-03-29 00:00:00	ANCIEN	\N	Guînes	\N	\N	1998	\N	\N	CANTON	620	13002U	\N	\N	\N	\N
1339	\N	\N	2001-03-22 00:00:00	ANCIEN	\N	Saint-Trivier-de-Courtes	\N	\N	1979	2001	\N	CANTON	10	89016Q	de 	\N	\N	\N
1340	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Oyonnax-Sud	\N	\N	\N	2001	\N	CANTON	10	89027T	d'	\N	\N	\N
1341	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Oulchy-le-Château	\N	\N	\N	2001	\N	CANTON	20	78003A	d'	\N	\N	\N
1342	\N	\N	\N	ANCIEN	\N	Marcillat-en-Combraille	\N	\N	1973	1982	\N	CANTON	30	89018S	de 	\N	\N	\N
1344	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Tende	\N	\N	\N	2001	\N	CANTON	60	84004P	de 	\N	\N	\N
1345	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Serrières	\N	\N	\N	2001	\N	CANTON	70	80045G	de 	\N	\N	\N
1347	1982-03-11 00:00:00	\N	2001-03-11 00:00:00	ANCIEN	\N	Méry-sur-Seine	\N	\N	1982	2001	\N	CANTON	100	89017R	de 	\N	\N	\N
1348	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Essoyes	\N	\N	1976	2001	\N	CANTON	100	94003T	des 	\N	\N	\N
1349	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Narbonne-Ouest	\N	\N	\N	2001	\N	CANTON	110	80013X	de 	\N	\N	\N
1350	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Séverac-le-Château	\N	\N	1994	2001	\N	CANTON	120	89041R	de 	\N	\N	\N
1351	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Rignac	\N	\N	\N	2001	\N	CANTON	120	80035E	de 	\N	\N	\N
1352	\N	\N	\N	ACTIF	\N	Ryes	\N	\N	\N	\N	\N	CANTON	140	70001N	de 	\N	\N	\N
1353	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Cambremer	\N	\N	\N	2001	\N	CANTON	140	89007P	de 	\N	\N	\N
1354	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Saignes	\N	\N	1988	2001	\N	CANTON	150	89010J	de 	\N	\N	\N
1355	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Blanzac	\N	\N	1982	2001	\N	CANTON	160	96008H	de 	\N	\N	\N
1356	1970-03-15 00:00:00	\N	\N	ANCIEN	\N	Jonzac	\N	\N	1970	2008	\N	CANTON	170	89013M	de 	\N	\N	\N
1357	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Saint-Porchaire	\N	\N	\N	2001	\N	CANTON	170	89014N	de 	\N	\N	\N
1358	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Saint-Amand-Montrond	\N	\N	1992	2001	\N	CANTON	180	89045V	de 	\N	\N	\N
1359	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Tulle-Campagne-Sud	\N	\N	\N	2001	\N	CANTON	190	80031A	de 	\N	\N	\N
1360	\N	\N	2021-12-17 00:00:00	ANCIEN	\N	Lévie	\N	\N	\N	\N	\N	CANTON	200	94002S	de 	\N	\N	\N
1361	\N	\N	\N	ACTIF	\N	Sagrodi-Santa-Giula	\N	\N	\N	\N	\N	CANTON	205	97002F	de 	\N	\N	\N
1362	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Liernais	\N	\N	\N	2001	\N	CANTON	210	98003L	de 	\N	\N	\N
1363	\N	\N	2004-03-28 00:00:00	ANCIEN	\N	Fontaine-lès-Dijon	\N	\N	\N	2004	\N	CANTON	210	89037V	de 	\N	\N	\N
1364	\N	\N	2023-04-05 00:00:00	ANCIEN	\N	Ploufragan	\N	\N	\N	\N	\N	CANTON	220	97010F	de 	\N	\N	\N
1365	\N	\N	2021-02-12 00:00:00	ANCIEN	\N	Saint-Vaury	\N	\N	\N	\N	\N	CANTON	230	81010Y	de 	\N	\N	\N
1366	\N	\N	\N	ACTIF	\N	Bellegarde-en-Marche	\N	\N	\N	\N	\N	CANTON	230	73006G	de 	\N	\N	\N
1368	\N	\N	2004-03-28 00:00:00	ANCIEN	\N	Rémuzat	\N	\N	1979	2004	\N	CANTON	260	89015P	de 	\N	\N	\N
10285	\N	\N	\N	ACTIF	\N	Cleres	\N	\N	\N	\N	\N	CANTON	760	000561	\N	\N	\N	\N
10286	\N	\N	1999-08-16 00:00:00	ANCIEN	\N	\N	\N	\N	\N	1999	\N	CANTON	420	58342G	\N	\N	\N	\N
10287	\N	\N	1997-11-17 00:00:00	ANCIEN	\N	Saint-Héand	\N	\N	\N	1997	\N	CANTON	420	88011F	\N	\N	\N	\N
10288	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	CANTON	310	000323	\N	\N	\N	\N
10289	\N	\N	2002-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2002	\N	CANTON	60	59717X	\N	\N	\N	\N
10290	\N	\N	2018-08-04 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	CANTON	170	58914W	\N	\N	\N	\N
10291	\N	\N	2001-10-30 00:00:00	ANCIEN	\N	Noirétable	\N	\N	\N	2001	\N	CANTON	420	59236K	\N	\N	\N	\N
10292	\N	\N	2004-08-18 00:00:00	ANCIEN	\N	Rémalard	\N	\N	\N	2004	\N	CANTON	610	59240F	\N	\N	\N	\N
10293	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	CANTON	615	000488	\N	\N	\N	\N
10294	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	CANTON	60	000393	\N	\N	\N	\N
10295	\N	\N	2007-05-17 00:00:00	ANCIEN	\N	Cruseilles	\N	\N	\N	2007	\N	CANTON	740	59553V	\N	\N	\N	\N
10296	\N	\N	2009-08-08 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2009	\N	CANTON	380	58335H	\N	\N	\N	\N
10297	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	CANTON	995	59619W	\N	\N	\N	\N
10298	\N	\N	\N	ACTIF	\N	Saint-Didier-en-Velay	\N	\N	\N	\N	\N	CANTON	430	96002B	\N	\N	\N	\N
10299	\N	\N	2007-05-21 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2007	\N	CANTON	280	58916Y	\N	\N	\N	\N
10300	\N	\N	\N	ACTIF	\N	Sauve	\N	\N	\N	\N	\N	CANTON	300	88010E	\N	\N	\N	\N
10301	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	CANTON	510	000202	\N	\N	\N	\N
10302	\N	\N	2018-01-17 00:00:00	ANCIEN	\N	Dunkerque Est	\N	\N	\N	\N	\N	CANTON	590	59244K	\N	\N	\N	2018-02-01 13:23:37
10303	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	CANTON	60	000104	\N	\N	\N	\N
10304	\N	\N	2016-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2016	\N	CANTON	170	58938F	\N	\N	\N	\N
10305	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	CANTON	60	000125	\N	\N	\N	\N
10306	\N	\N	1985-05-26 00:00:00	ANCIEN	\N	\N	\N	\N	\N	1985	\N	CANTON	480	000443	\N	\N	\N	\N
10307	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	CANTON	670	000505	\N	\N	\N	\N
10308	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	CANTON	828	000564	\N	\N	\N	\N
10309	\N	\N	2005-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2005	\N	CANTON	490	58336J	\N	\N	\N	\N
10310	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	CANTON	335	58662V	\N	\N	\N	\N
10311	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	CANTON	770	000440	\N	\N	\N	\N
10312	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	CANTON	830	000279	\N	\N	\N	\N
10313	\N	\N	1996-07-09 00:00:00	ANCIEN	\N	Grandpré	\N	\N	\N	1996	\N	CANTON	80	89005M	\N	\N	\N	\N
10314	\N	\N	2009-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2009	\N	CANTON	615	59560U	\N	\N	\N	\N
10315	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	CANTON	820	000592	\N	\N	\N	\N
10316	\N	\N	2019-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	CANTON	973	58950B	\N	\N	\N	\N
10317	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	CANTON	80	000312	\N	\N	\N	\N
10318	\N	\N	2016-10-05 00:00:00	ANCIEN	\N	Quettehou	\N	\N	\N	2016	\N	CANTON	500	59249Q	\N	\N	\N	\N
10319	\N	\N	2006-05-18 00:00:00	ANCIEN	\N	Brioux-sur-Boutonne	\N	\N	\N	2006	\N	CANTON	790	59561V	\N	\N	\N	\N
10320	\N	\N	2000-01-11 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2000	\N	CANTON	335	58808V	\N	\N	\N	\N
10321	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	CANTON	530	000190	\N	\N	\N	\N
10322	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	CANTON	590	000377	\N	\N	\N	\N
1346	\N	\N	2001-09-04 00:00:00	ANCIEN	\N	Les Cabannes	\N	\N	\N	2001	\N	CANTON	90	80004W	de 	\N	\N	\N
10564	2001-03-18 00:00:00	\N	\N	ACTIF	\N	Paris	\N	\N	2001	\N	\N	CANTON	615	00001A	\N	\N	\N	\N
10566	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Paris	\N	\N	\N	2001	\N	CANTON	615	86025D	\N	\N	\N	\N
10575	\N	\N	\N	ANCIEN	\N	Paris	\N	\N	1983	1989	\N	CANTON	615	00001A	\N	\N	\N	\N
10588	\N	\N	\N	ANCIEN	\N	Bièvres	\N	\N	\N	2001	\N	CANTON	265	03004R	\N	\N	\N	\N
1410	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Vigneulles-lès-Hattonchâtel	\N	\N	\N	2001	\N	CANTON	550	74022L	de 	\N	\N	\N
1411	\N	\N	2001-03-18 00:00:00	ANCIEN	\N	Le Palais	\N	\N	\N	2001	\N	CANTON	560	83016P	de 	\N	\N	\N
1412	\N	\N	2000-04-28 00:00:00	ANCIEN	\N	Dieuze	\N	\N	\N	2000	\N	CANTON	570	83037U	de 	\N	\N	\N
12516	2003-03-23 00:00:00	\N	2011-11-30 00:00:00	ANCIEN	\N	Le Bourget	\N	\N	\N	\N	\N	CANTON	775	11053K	\N	\N	\N	\N
1414	\N	\N	\N	ACTIF	\N	Nevers-est	\N	\N	\N	\N	\N	CANTON	580	92016Q	de 	\N	\N	\N
1415	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Château-Chinon	\N	\N	\N	2001	\N	CANTON	580	86053H	de 	\N	\N	\N
1416	\N	\N	\N	ACTIF	\N	Douai-Sud	\N	\N	\N	\N	\N	CANTON	590	97006K	de 	\N	\N	\N
1417	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Merville	\N	\N	\N	2001	\N	CANTON	590	92023P	de 	\N	\N	\N
1418	\N	\N	1999-10-16 00:00:00	ANCIEN	\N	Steenvoorde	\N	\N	1998	1999	\N	CANTON	590	83013L	de 	\N	\N	\N
1421	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Paris	\N	\N	\N	2001	\N	CANTON	615	95056M	de 	\N	\N	\N
1424	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2001	\N	CANTON	615	95022B	de 	\N	\N	\N
1425	\N	\N	\N	ANCIEN	\N	\N	\N	\N	\N	2001	\N	CANTON	615	77009C	de 	\N	\N	\N
1426	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2001	\N	CANTON	615	77013X	de 	\N	\N	\N
1427	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	CANTON	615	95018F	de 	\N	\N	\N
10650	2004-04-01 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Meung-sur-Loire	\N	\N	2004	\N	\N	CANTON	450	01027Q	\N	\N	\N	\N
10652	2004-04-01 00:00:00	\N	\N	ACTIF	\N	Montrevault	\N	\N	2004	\N	\N	CANTON	490	01017N	\N	\N	\N	\N
12792	2004-04-01 00:00:00	\N	2014-03-30 00:00:00	ANCIEN	\N	Angers Nord-Ouest	\N	\N	\N	\N	\N	CANTON	490	11030C	\N	\N	\N	2014-10-02 10:07:56
12794	1994-03-01 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Sully-sur-Loire	\N	\N	\N	\N	\N	CANTON	450	11103C	\N	\N	\N	\N
12797	2008-03-01 00:00:00	\N	2012-09-01 00:00:00	ANCIEN	\N	Grenoble 4	\N	\N	2008	2012	\N	CANTON	380	11042G	\N	\N	\N	\N
12821	1988-10-03 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Lumbres	\N	\N	\N	\N	\N	CANTON	620	11059R	\N	\N	\N	\N
10762	\N	\N	2015-03-29 00:00:00	ANCIEN	\N	Mortagne-sur-Sèvre	\N	\N	1988	\N	\N	CANTON	850	04033B	\N	\N	\N	\N
10660	2004-03-28 00:00:00	\N	2023-10-21 00:00:00	ANCIEN	\N	Wasselonne	\N	\N	2004	\N	\N	CANTON	670	91002E	\N	\N	\N	\N
10661	2004-03-28 00:00:00	\N	2011-03-27 00:00:00	ANCIEN	\N	Sierentz	\N	\N	2004	2011	\N	CANTON	680	95045J	\N	\N	\N	\N
10662	2004-04-01 00:00:00	\N	2015-02-16 00:00:00	ANCIEN	\N	Thizy	\N	\N	\N	\N	\N	CANTON	690	95049N	\N	\N	\N	2015-03-12 10:24:15
10663	2004-04-01 00:00:00	\N	2011-03-27 00:00:00	ANCIEN	\N	Sennecey-le-Grand	\N	\N	2004	2011	\N	CANTON	710	95030B	\N	\N	\N	\N
10664	2004-04-01 00:00:00	\N	2011-03-27 00:00:00	ANCIEN	\N	Montfort-le-Gesnois	\N	\N	2004	2011	\N	CANTON	720	95019G	\N	\N	\N	\N
10665	2004-04-01 00:00:00	\N	2011-03-31 00:00:00	ANCIEN	\N	Tuffé	\N	\N	2004	2011	\N	CANTON	720	77043E	\N	\N	\N	\N
10666	2004-04-01 00:00:00	\N	\N	ACTIF	\N	Valence-d'Agen 	\N	\N	2004	\N	\N	CANTON	820	86010V	\N	\N	\N	\N
12824	2004-01-01 00:00:00	\N	\N	ACTIF	\N	Cambrin	\N	\N	\N	\N	\N	CANTON	620	11062L	\N	\N	\N	\N
10669	\N	\N	2008-11-12 00:00:00	ANCIEN	\N	Marignane	\N	\N	1979	2008	\N	CANTON	130	98020M	\N	\N	\N	\N
5041	1994-03-27 00:00:00	\N	2001-03-11 00:00:00	ANCIEN	\N	Saint-Béat	\N	\N	1994	2001	\N	CANTON	310	98011L	de 	\N	\N	\N
10682	\N	\N	1998-03-14 00:00:00	ANCIEN	\N	Marcillat-en-Combraille	\N	\N	1982	1998	\N	CANTON	30	89018S	\N	\N	\N	\N
10683	1998-03-15 00:00:00	\N	\N	ACTIF	\N	Marcillat-en-Combraille	\N	\N	1998	\N	\N	CANTON	30	89018S	\N	\N	\N	\N
10689	1977-09-11 00:00:00	\N	1992-03-29 00:00:00	ANCIEN	\N	Sarcelles-Est	\N	\N	1977	1992	\N	CANTON	828	79004F	\N	\N	\N	\N
10697	\N	\N	2021-03-25 00:00:00	ANCIEN	\N	La Vallée du Sausseron	\N	\N	1976	\N	\N	CANTON	828	04016A	\N	\N	\N	\N
10718	\N	\N	\N	ANCIEN	\N	Marseille XII	\N	\N	1982	1988	\N	CANTON	130	89029V	\N	\N	\N	\N
10739	\N	\N	2022-10-17 00:00:00	ANCIEN	\N	Saint-Brieuc	\N	\N	1982	1989	\N	CANTON	220	89040Q	\N	\N	\N	\N
10767	\N	\N	\N	ANCIEN	\N	Sablé-sur-Sarthe	\N	\N	1981	1998	\N	CANTON	720	02009S	\N	\N	\N	\N
10792	\N	\N	\N	ANCIEN	\N	Villiers sur Marne	\N	\N	1982	1988	\N	CANTON	824	04037F	\N	\N	\N	\N
10800	1982-03-21 00:00:00	\N	\N	ANCIEN	\N	Mulhouse-Nord	\N	\N	1982	1989	\N	CANTON	680	04040A	\N	\N	\N	\N
10801	\N	\N	\N	ANCIEN	\N	Mulhouse-Nord	\N	\N	1994	1997	\N	CANTON	680	04040A	\N	\N	\N	\N
10808	1998-03-22 00:00:00	\N	2004-10-01 00:00:00	ANCIEN	\N	La Valette-du-Var	\N	\N	1998	2004	\N	CANTON	830	04041B	\N	\N	\N	\N
10811	1992-03-29 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Callas	\N	\N	1992	\N	\N	CANTON	830	04038G	\N	\N	\N	\N
10842	2001-03-18 00:00:00	\N	2004-11-15 00:00:00	ANCIEN	\N	Gleizé	\N	\N	2001	2004	\N	CANTON	690	04049K	\N	\N	\N	\N
10849	\N	\N	2008-03-21 00:00:00	ANCIEN	\N	Limonest	\N	\N	1994	\N	\N	CANTON	690	04051D	\N	\N	\N	\N
10856	1998-03-21 00:00:00	\N	2004-03-21 00:00:00	ANCIEN	\N	Massy-Ouest	\N	\N	1998	2004	\N	CANTON	265	86039K	\N	\N	\N	\N
10887	1992-03-29 00:00:00	\N	\N	ANCIEN	\N	Strasbourg - VIII	\N	\N	1992	2001	\N	CANTON	670	04061F	\N	\N	\N	\N
10909	2004-03-28 00:00:00	\N	\N	ACTIF	\N	Dieppe-Est	\N	\N	2004	\N	\N	CANTON	760	04068N	\N	\N	\N	\N
11092	1992-03-29 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Signy-le-Petit	\N	\N	1992	\N	\N	CANTON	80	04097T	\N	\N	\N	\N
10925	\N	\N	\N	ACTIF	\N	Paris	\N	\N	1983	\N	\N	CANTON	615	04072J	\N	\N	\N	\N
10929	\N	\N	\N	ACTIF	\N	Saint-Fargeau	\N	\N	1982	\N	\N	CANTON	890	04073K	\N	\N	\N	\N
10936	\N	\N	2008-03-21 00:00:00	ANCIEN	\N	Villiers-le-Bel	\N	\N	1994	\N	\N	CANTON	828	04076N	\N	\N	\N	\N
10940	\N	\N	\N	ANCIEN	\N	3ème arrondissement	\N	\N	1983	2001	\N	CANTON	615	04075M	\N	\N	\N	\N
10977	1998-03-22 00:00:00	\N	2004-03-21 00:00:00	ANCIEN	\N	Dole Nord-Est	\N	\N	1998	2004	\N	CANTON	390	04082L	\N	\N	\N	\N
10980	1987-04-12 00:00:00	\N	2008-03-21 00:00:00	ANCIEN	\N	Saint-Gilles-Croix-de-Vie	\N	\N	1987	\N	\N	CANTON	850	04083M	\N	\N	\N	\N
10987	1992-03-29 00:00:00	\N	2011-03-27 00:00:00	ANCIEN	\N	Héricourt-Ouest	\N	\N	1992	\N	\N	CANTON	700	04084N	\N	\N	\N	\N
10991	\N	\N	\N	ANCIEN	\N	Labruguière	\N	\N	1979	1998	\N	CANTON	810	04087R	\N	\N	\N	\N
10996	1985-03-17 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Xertigny	\N	\N	1985	\N	\N	CANTON	880	04088S	\N	\N	\N	\N
11003	\N	\N	2015-03-29 00:00:00	ANCIEN	\N	Ailly-le-Haut-Clocher	\N	\N	1998	\N	\N	CANTON	800	04089T	\N	\N	\N	\N
11005	1998-03-22 00:00:00	\N	\N	ACTIF	\N	Chambéry-Nord	\N	\N	1998	\N	\N	CANTON	730	04090L	\N	\N	\N	\N
11011	\N	\N	\N	ANCIEN	\N	Cuiseaux	\N	\N	1970	2004	\N	CANTON	710	04091M	\N	\N	\N	\N
11016	1985-03-17 00:00:00	\N	\N	ANCIEN	\N	Bédarrides	\N	\N	1985	2001	\N	CANTON	840	04092N	\N	\N	\N	\N
12767	2004-03-21 00:00:00	\N	2011-11-30 00:00:00	ANCIEN	\N	Pointe-Noire	\N	\N	\N	2011	\N	CANTON	971	11113E	\N	\N	\N	\N
12763	2001-03-11 00:00:00	\N	\N	ANCIEN	\N	Saint-Louis-de-Marie-Galante	\N	\N	\N	2011	\N	CANTON	971	11114F	\N	\N	\N	2013-09-23 10:45:42
11096	1985-03-17 00:00:00	\N	\N	ACTIF	\N	Vouillé	\N	\N	1985	\N	\N	CANTON	860	04098U	\N	\N	\N	\N
11100	1985-03-17 00:00:00	\N	\N	ACTIF	\N	Mamers	\N	\N	1985	\N	\N	CANTON	720	04099V	\N	\N	\N	\N
11114	\N	\N	\N	ANCIEN	\N	Istres	\N	\N	1982	1988	\N	CANTON	130	04101V	\N	\N	\N	\N
11117	\N	\N	1992-10-07 00:00:00	ANCIEN	\N	Salon-de-Provence	\N	\N	1982	1992	\N	CANTON	130	89042S	\N	\N	\N	\N
11135	\N	\N	\N	ANCIEN	\N	Aix IV	\N	\N	\N	1998	\N	CANTON	130	98015Q	\N	\N	\N	\N
11155	\N	\N	2005-08-27 00:00:00	ANCIEN	\N	Bastia VI	\N	\N	1994	2005	\N	CANTON	205	05011Y	\N	\N	\N	\N
11157	1973-09-30 00:00:00	\N	2023-10-03 00:00:00	ANCIEN	\N	Bordeaux-IV	\N	\N	1973	1989	\N	CANTON	330	80046H	\N	\N	\N	\N
11170	\N	\N	2015-03-29 00:00:00	ANCIEN	\N	Lury-sur-Arnon	\N	\N	1994	\N	\N	CANTON	180	05012A	\N	\N	\N	\N
11202	\N	\N	2011-03-31 00:00:00	ANCIEN	\N	de Lagrasse	\N	\N	1988	2011	\N	CANTON	110	06005F	\N	\N	\N	\N
11211	\N	\N	\N	ACTIF	\N	de Ploubalay	\N	\N	1973	\N	\N	CANTON	220	06006G	\N	\N	\N	\N
11232	\N	\N	\N	ANCIEN	\N	Gap Nord-Est	\N	\N	1982	1989	\N	CANTON	50	07003H	\N	\N	\N	\N
11295	\N	\N	2015-03-29 00:00:00	ANCIEN	\N	d'Aigurande	\N	\N	1992	\N	\N	CANTON	360	07032N	\N	\N	\N	\N
11308	1998-03-15 00:00:00	\N	\N	ANCIEN	\N	Mehun-sur-Yèvre	\N	\N	1998	2007	\N	CANTON	180	07034Q	\N	\N	\N	\N
11322	2008-03-10 00:00:00	\N	2008-10-08 00:00:00	ANCIEN	\N	Bastia VI	\N	\N	2008	\N	\N	CANTON	205	05011Y	\N	\N	\N	\N
11371	1976-03-14 00:00:00	\N	1988-10-02 00:00:00	ANCIEN	\N	Toulon-IV	\N	\N	1976	1988	\N	CANTON	830	86049M	\N	\N	\N	\N
11401	1985-05-17 00:00:00	\N	1998-03-15 00:00:00	ANCIEN	\N	Saint-Etienne-Sud-Est III	\N	\N	1985	1998	\N	CANTON	420	01039U	\N	\N	\N	\N
11444	\N	\N	2021-09-09 00:00:00	ANCIEN	\N	Saint-Claude-Gourbeyre 	\N	\N	1982	1992	\N	CANTON	971	95050F	\N	\N	\N	\N
11466	1998-03-22 00:00:00	\N	\N	ACTIF	\N	Valdoie	\N	\N	1998	\N	\N	CANTON	125	08008S	\N	\N	\N	\N
11491	\N	\N	2009-10-10 00:00:00	ANCIEN	\N	Bernay-Ouest	\N	\N	2004	2009	\N	CANTON	270	08009T	\N	\N	\N	\N
11502	1998-03-22 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Orgères-en-Beauce	\N	\N	\N	\N	\N	CANTON	280	08011M	\N	\N	\N	\N
11509	1994-10-09 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Bourganeuf	\N	\N	1994	\N	\N	CANTON	230	08012N	\N	\N	\N	\N
11522	1992-03-29 00:00:00	\N	2011-03-20 00:00:00	ANCIEN	\N	Bourbriac	\N	\N	1992	2011	\N	CANTON	220	08014Q	\N	\N	\N	\N
11529	1993-12-19 00:00:00	\N	2011-03-31 00:00:00	ANCIEN	\N	Pons	\N	\N	\N	\N	\N	CANTON	170	08015R	\N	\N	\N	2014-05-12 16:31:09
11546	1998-03-13 00:00:00	\N	2007-07-15 00:00:00	ANCIEN	\N	Saint-Barthélémy	\N	\N	1998	2007	\N	CANTON	971	08019V	\N	\N	\N	\N
11568	\N	\N	\N	ANCIEN	\N	Saint-Martin I	\N	\N	2004	2007	\N	CANTON	971	08023R	\N	\N	\N	\N
11585	\N	\N	\N	ANCIEN	\N	Rennes II	\N	\N	1973	1982	\N	CANTON	350	08027V	\N	\N	\N	\N
11602	1992-03-29 00:00:00	\N	2020-05-11 00:00:00	ANCIEN	\N	Allauch	\N	\N	1992	2008	\N	CANTON	130	08029X	\N	\N	\N	\N
11607	\N	\N	\N	ACTIF	\N	Toulouse-VII	\N	\N	1998	\N	\N	CANTON	310	08033T	\N	\N	\N	\N
11617	\N	\N	2011-03-28 00:00:00	ANCIEN	\N	Villefranche-sur-Mer	\N	\N	1985	2011	\N	CANTON	60	08036W	\N	\N	\N	\N
11633	2004-03-28 00:00:00	\N	\N	ANCIEN	\N	Grasse-Nord	\N	\N	2004	2008	\N	CANTON	60	08039A	\N	\N	\N	\N
11638	1989-03-01 00:00:00	\N	1998-03-01 00:00:00	ANCIEN	\N	Grasse-Sud	\N	\N	1989	1998	\N	CANTON	60	08039A	\N	\N	\N	\N
11643	\N	\N	2015-03-29 00:00:00	ANCIEN	\N	Menton-Est	\N	\N	1998	\N	\N	CANTON	60	08041T	\N	\N	\N	\N
11291	2004-03-28 00:00:00	\N	\N	ACTIF	\N	Putanges-Pont-Ecrepin	\N	changement de canton le 15/02/09.	2004	\N	\N	CANTON	610	92029V	\N	\N	\N	\N
11534	\N	\N	2015-03-29 00:00:00	ANCIEN	\N	Bourg-de-Péage	\N	\N	1998	\N	\N	CANTON	260	08016S	\N	\N	\N	\N
11652	1998-03-01 00:00:00	\N	\N	ANCIEN	\N	Cagnes-sur-Mer-Centre	\N	\N	1998	2008	\N	CANTON	60	08042U	\N	\N	\N	\N
11655	\N	\N	2015-03-29 00:00:00	ANCIEN	\N	Quimper II - Ergué-Gabéric - Ergué-Armel	\N	\N	2001	\N	\N	CANTON	290	08043V	\N	\N	\N	\N
11667	\N	\N	2011-03-27 00:00:00	ANCIEN	\N	Argentat	\N	\N	1993	\N	\N	CANTON	190	08046Y	\N	\N	\N	\N
11672	\N	\N	2009-01-11 00:00:00	ANCIEN	\N	Douarnenez	\N	\N	2001	2009	\N	CANTON	290	08047A	\N	\N	\N	\N
11684	\N	\N	\N	ANCIEN	\N	Fleurance	\N	\N	1998	2001	\N	CANTON	320	08049C	\N	\N	\N	\N
11685	\N	\N	\N	ANCIEN	\N	Egleton	\N	\N	1994	2005	\N	CANTON	190	08050U	\N	\N	\N	\N
11692	\N	\N	2015-03-29 00:00:00	ANCIEN	\N	Marle	\N	\N	1985	\N	\N	CANTON	20	08052W	\N	\N	\N	\N
11693	\N	\N	2008-10-28 00:00:00	ANCIEN	\N	Aurillac IV	\N	\N	1994	\N	\N	CANTON	150	08051V	\N	\N	\N	\N
11715	\N	\N	2009-03-29 00:00:00	ANCIEN	\N	Privas	\N	\N	1998	2009	\N	CANTON	70	08057C	\N	\N	\N	\N
11718	\N	\N	2015-03-29 00:00:00	ANCIEN	\N	Montbron	\N	\N	1992	\N	\N	CANTON	160	08058D	\N	\N	\N	\N
11729	\N	\N	2015-03-29 00:00:00	ANCIEN	\N	Mansle	\N	\N	2008	\N	\N	CANTON	160	08060W	\N	\N	\N	\N
11735	\N	\N	\N	ANCIEN	\N	Châteauroux-Centre	\N	\N	2001	2008	\N	CANTON	360	08062Y	\N	\N	\N	\N
11741	1981-09-12 00:00:00	\N	\N	ACTIF	\N	Lédignan	\N	\N	1981	\N	\N	CANTON	300	08063A	\N	\N	\N	\N
11745	2008-03-09 00:00:00	\N	\N	ACTIF	\N	Rignac	\N	\N	2008	\N	\N	CANTON	120	08064B	\N	\N	\N	\N
11747	\N	\N	\N	ANCIEN	\N	Pouilly-en-Auxois	\N	\N	1976	2008	\N	CANTON	210	08061X	\N	\N	\N	\N
11750	\N	\N	2008-11-23 00:00:00	ANCIEN	\N	Nîmes I	\N	\N	1988	\N	\N	CANTON	300	08065C	\N	\N	\N	\N
11753	\N	\N	\N	ANCIEN	\N	Saint-Affrique	\N	\N	1998	2001	\N	CANTON	120	08066D	\N	\N	\N	\N
11766	\N	\N	\N	ACTIF	\N	Besançon ouest	\N	\N	1998	\N	\N	CANTON	250	08067E	\N	\N	\N	\N
11195	1996-01-22 00:00:00	\N	\N	ACTIF	\N	Saint-Chinian	\N	\N	1996	\N	\N	CANTON	340	06004E	\N	\N	\N	\N
11319	2008-03-21 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	La Motte Servolex	\N	\N	2008	\N	\N	CANTON	730	95067Q	\N	\N	\N	\N
11366	2008-03-23 00:00:00	\N	2015-02-25 00:00:00	ANCIEN	\N	Tende	\N	\N	2008	2015	\N	CANTON	60	84004P	\N	\N	\N	\N
11777	\N	\N	\N	ANCIEN	\N	Grancey-le-ChÃ¢teau-Neuvelle	\N	\N	1998	2014	\N	CANTON	210	08069G	\N	\N	\N	2015-01-27 10:18:19
10232	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	CANTON	400	000184	\N	\N	\N	\N
11781	\N	\N	2008-10-24 00:00:00	ANCIEN	\N	Dijon-V	\N	BQ du 27/10/08 : demission pour cumul de mandats	1998	2008	\N	CANTON	210	08070Y	\N	\N	\N	\N
11797	\N	\N	\N	ANCIEN	\N	Mana	\N	\N	1985	1998	\N	CANTON	973	08073C	\N	\N	\N	\N
11806	\N	\N	\N	ANCIEN	\N	Miribel	\N	\N	1998	2008	\N	CANTON	10	08059E	\N	\N	\N	\N
11808	2004-07-09 00:00:00	\N	2008-03-16 00:00:00	ANCIEN	\N	Montluçon-Sud	\N	\N	2004	2008	\N	CANTON	30	08054Y	\N	\N	\N	\N
11814	1998-03-15 00:00:00	\N	2011-03-27 00:00:00	ANCIEN	\N	Saint-Malo (Sud)	\N	\N	\N	2011	\N	CANTON	350	08037X	\N	\N	\N	\N
11880	\N	\N	2023-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	1985	1988	\N	CANTON	140	98041S	\N	\N	\N	\N
11883	\N	\N	\N	ANCIEN	\N	\N	\N	\N	1973	1989	\N	CANTON	335	77019E	\N	\N	\N	\N
11900	\N	\N	2019-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	1994	1995	\N	CANTON	740	95015C	\N	\N	\N	\N
11902	\N	\N	\N	ANCIEN	\N	\N	\N	\N	1985	1993	\N	CANTON	640	92013M	\N	\N	\N	\N
11907	\N	\N	\N	ANCIEN	\N	\N	\N	\N	1976	1982	\N	CANTON	824	97004H	\N	\N	\N	\N
12777	2004-03-28 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Carnières	\N	\N	\N	\N	\N	CANTON	590	11036J	\N	\N	\N	\N
11911	\N	\N	2009-09-09 00:00:00	ANCIEN	\N	\N	\N	\N	1973	2009	\N	CANTON	230	80024B	\N	\N	\N	\N
11914	\N	\N	2022-08-20 00:00:00	ANCIEN	\N	\N	\N	\N	1982	2008	\N	CANTON	775	95046K	\N	\N	\N	\N
11917	\N	\N	\N	ANCIEN	\N	\N	\N	\N	1967	1973	\N	CANTON	590	92037V	\N	\N	\N	\N
11649	2004-04-01 00:00:00	\N	\N	ANCIEN	\N	Berre-sur-l'Etang	\N	\N	2004	2008	\N	CANTON	130	08040S	\N	\N	\N	\N
11663	\N	\N	2011-03-27 00:00:00	ANCIEN	\N	Lanmeur	\N	\N	1995	2011	\N	CANTON	290	08045X	\N	\N	\N	\N
11272	1998-03-20 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Tourteron	\N	\N	1998	\N	\N	CANTON	80	07029T	de	\N	\N	2017-11-14 10:37:31
11277	\N	\N	\N	ANCIEN	\N	de Béziers IV	\N	\N	1983	1996	\N	CANTON	340	07030L	\N	\N	\N	\N
11363	\N	\N	\N	ANCIEN	\N	Fréjus	\N	\N	1998	2008	\N	CANTON	830	08007R	\N	\N	\N	\N
11702	1988-10-02 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Bourg-en-Bresse-Est	\N	\N	1988	\N	\N	CANTON	10	08053X	\N	\N	\N	\N
11852	\N	\N	\N	ANCIEN	\N	Canzals	\N	\N	1965	2004	\N	CANTON	460	08074D	\N	\N	\N	\N
11889	\N	\N	\N	ANCIEN	\N	\N	\N	\N	1973	1998	\N	CANTON	410	92022N	\N	\N	\N	\N
11893	\N	\N	\N	ANCIEN	\N	\N	\N	\N	1992	1998	\N	CANTON	850	95021A	\N	\N	\N	\N
11897	\N	\N	\N	ANCIEN	\N	\N	\N	\N	1992	1998	\N	CANTON	820	88008L	\N	\N	\N	\N
11929	\N	\N	\N	ANCIEN	\N	\N	\N	\N	1982	1998	\N	CANTON	560	83050R	\N	\N	\N	\N
11932	\N	\N	2021-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	1988	1994	\N	CANTON	824	04039H	\N	\N	\N	\N
11971	1994-03-27 00:00:00	\N	\N	ACTIF	\N	Villefranche-sur-Saône	\N	\N	\N	\N	\N	CANTON	690	09010Q	\N	\N	\N	\N
11974	\N	\N	\N	ACTIF	\N	Vézelay	\N	\N	1992	\N	\N	CANTON	890	09011R	\N	\N	\N	\N
12075	\N	\N	\N	ACTIF	\N	Montmédy	\N	\N	2008	\N	\N	CANTON	550	11003M	de	\N	\N	2017-09-20 16:44:46
6397	\N	\N	2004-04-01 00:00:00	ANCIEN	\N	Montrevault	\N	\N	\N	2004	\N	CANTON	490	01017N	\N	\N	\N	\N
6398	\N	\N	2004-04-01 00:00:00	ANCIEN	\N	Angers Sud	\N	\N	1979	2004	\N	CANTON	490	01018P	\N	\N	\N	\N
12554	\N	\N	\N	ANCIEN	\N	Mortagne	\N	\N	1982	1993	\N	CANTON	610	11100Y	\N	\N	\N	\N
6410	\N	\N	\N	ACTIF	\N	Clermont	\N	\N	1982	\N	\N	CANTON	600	01023L	\N	\N	\N	\N
12780	1985-03-01 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Martel	\N	\N	\N	\N	\N	CANTON	460	11012A	\N	\N	\N	\N
12784	1979-03-15 00:00:00	\N	2011-10-30 00:00:00	ANCIEN	\N	Cergy-Sud Eragny	\N	\N	\N	\N	\N	CANTON	828	11089X	\N	\N	\N	\N
6423	\N	\N	2004-04-01 00:00:00	ANCIEN	\N	Meung-sur-Loire	\N	\N	1982	2004	\N	CANTON	450	01027Q	\N	\N	\N	\N
6435	\N	\N	2008-03-21 00:00:00	ANCIEN	\N	Saint-Amant-Tallende	\N	\N	1987	\N	\N	CANTON	630	01030K	\N	\N	\N	\N
12785	2008-03-01 00:00:00	\N	2011-10-01 00:00:00	ANCIEN	\N	Canton Nord d'Alfortville	\N	\N	\N	\N	\N	CANTON	824	11032E	\N	\N	\N	\N
6448	\N	\N	2004-03-21 00:00:00	ANCIEN	\N	Rouvroy	\N	\N	1985	2004	\N	CANTON	620	01035Q	\N	\N	\N	\N
6457	\N	\N	2016-12-10 00:00:00	ANCIEN	\N	Feurs	\N	\N	1979	2002	\N	CANTON	420	01037S	\N	\N	\N	2016-12-12 16:10:14
6499	\N	\N	2004-03-28 00:00:00	ANCIEN	\N	Monflanquin	\N	\N	1985	2004	\N	CANTON	470	01050P	\N	\N	\N	\N
6510	\N	\N	2004-03-28 00:00:00	ANCIEN	\N	Nantes	\N	\N	1979	2004	\N	CANTON	440	01054T	\N	\N	\N	\N
12577	1976-03-14 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Thèze	\N	\N	1976	\N	\N	CANTON	640	11112D	\N	\N	\N	\N
12580	1982-03-14 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Bidache	\N	\N	\N	\N	\N	CANTON	640	11111C	\N	\N	\N	\N
6555	\N	\N	2001-12-08 00:00:00	ANCIEN	\N	Saint Herblain Est	\N	\N	1982	2001	\N	CANTON	440	01053S	\N	\N	\N	\N
6567	\N	\N	\N	ANCIEN	\N	Ingré	\N	\N	1982	2001	\N	CANTON	450	01029S	\N	\N	\N	\N
6568	\N	\N	2001-12-08 00:00:00	ANCIEN	\N	Saint-André 3	\N	\N	1998	2001	\N	CANTON	974	01010F	\N	\N	\N	\N
6579	\N	\N	\N	ANCIEN	\N	Chinon	\N	\N	1976	2001	\N	CANTON	370	01012H	\N	\N	\N	\N
6595	1976-03-14 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Vigy	\N	\N	1976	\N	\N	CANTON	570	01060R	\N	\N	\N	\N
6625	1973-09-30 00:00:00	\N	\N	ANCIEN	\N	Vienne-nord	\N	\N	1973	1988	\N	CANTON	380	01020H	\N	\N	\N	\N
6637	\N	\N	\N	ANCIEN	\N	Strasbourg-Meinau	\N	\N	\N	1998	\N	CANTON	670	77029G	\N	\N	\N	\N
6644	\N	\N	2001-10-15 00:00:00	ANCIEN	\N	Bonneval	\N	\N	1988	2001	\N	CANTON	280	01064V	\N	\N	\N	\N
6650	1973-09-30 00:00:00	\N	2020-03-16 00:00:00	ANCIEN	\N	Deux-Sévi	\N	\N	1973	\N	\N	CANTON	200	01065W	\N	\N	\N	\N
6749	1998-03-22 00:00:00	\N	2022-05-07 00:00:00	ANCIEN	\N	Beaumont du Périgord	\N	\N	1998	\N	\N	CANTON	240	02005N	\N	\N	\N	\N
6751	\N	\N	2015-03-29 00:00:00	ANCIEN	\N	Chauvigny	\N	\N	1979	\N	\N	CANTON	860	02002K	\N	\N	\N	\N
6772	\N	\N	2008-03-26 00:00:00	ANCIEN	\N	\N	\N	\N	1989	2008	\N	CANTON	700	02007Q	\N	\N	\N	\N
12790	1990-10-01 00:00:00	\N	2011-12-31 00:00:00	ANCIEN	\N	Domène	\N	\N	1990	2011	\N	CANTON	380	11043H	\N	\N	\N	\N
6791	\N	\N	\N	ACTIF	\N	Rioz	\N	\N	1994	\N	\N	CANTON	700	03001N	\N	\N	\N	\N
10218	\N	\N	2010-10-31 00:00:00	ANCIEN	\N	La Fresnaye-sur-Chédouet	\N	\N	\N	2010	\N	CANTON	720	59533R	\N	\N	\N	\N
10219	\N	\N	2016-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2016	\N	CANTON	660	58343H	\N	\N	\N	\N
10220	\N	\N	2005-09-22 00:00:00	ANCIEN	\N	Carrouges	\N	\N	\N	2005	\N	CANTON	610	59215E	\N	\N	\N	\N
10221	\N	\N	2013-05-21 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2013	\N	CANTON	110	58613L	\N	\N	\N	\N
10222	\N	\N	\N	ACTIF	\N	Pont-Saint-Esprit	\N	\N	\N	\N	\N	CANTON	300	59721T	\N	\N	\N	\N
10223	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	CANTON	410	000460	\N	\N	\N	\N
10224	\N	\N	2021-04-21 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	CANTON	290	58819Y	\N	\N	\N	\N
10225	\N	\N	2020-02-13 00:00:00	ANCIEN	\N	Jumeaux	\N	\N	\N	\N	\N	CANTON	630	59217G	\N	\N	\N	\N
10226	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	CANTON	974	000541	\N	\N	\N	\N
10227	\N	\N	2018-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	CANTON	300	59309K	\N	\N	\N	\N
10228	\N	\N	2014-06-01 00:00:00	ANCIEN	\N	Orange Est	\N	\N	\N	2014	\N	CANTON	840	59566B	\N	\N	\N	\N
10229	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	CANTON	580	000353	\N	\N	\N	\N
10230	\N	\N	2004-09-29 00:00:00	ANCIEN	\N	La Ravoire	\N	\N	\N	2004	\N	CANTON	730	59567C	\N	\N	\N	\N
10231	\N	\N	\N	ACTIF	\N	Bordeaux (1er canton)	\N	\N	\N	\N	\N	CANTON	330	000634	\N	\N	\N	\N
10233	\N	\N	2001-10-18 00:00:00	ANCIEN	\N	Boëge	\N	\N	\N	2001	\N	CANTON	740	59568D	\N	\N	\N	\N
10234	\N	\N	\N	ACTIF	\N	Saint-Denis 2	\N	\N	\N	\N	\N	CANTON	974	92014N	\N	\N	\N	\N
10235	\N	\N	2017-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2017	\N	CANTON	310	58951C	\N	\N	\N	\N
10236	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	CANTON	330	000399	\N	\N	\N	\N
10237	\N	\N	1989-09-17 00:00:00	ANCIEN	\N	\N	\N	\N	\N	1989	\N	CANTON	390	000474	\N	\N	\N	\N
10238	\N	\N	2006-03-09 00:00:00	ANCIEN	\N	Cuq-Toulza	\N	\N	\N	2006	\N	CANTON	810	59523P	\N	\N	\N	\N
10239	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	CANTON	330	58946F	\N	\N	\N	\N
10240	\N	\N	2002-06-02 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2002	\N	CANTON	615	59524Q	\N	\N	\N	\N
10241	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	CANTON	850	000538	\N	\N	\N	\N
10242	\N	\N	2012-02-02 00:00:00	ANCIEN	\N	Envermeu	\N	\N	\N	2012	\N	CANTON	760	59526S	\N	\N	\N	\N
10243	\N	\N	\N	ACTIF	\N	Le Bleymard	\N	\N	\N	\N	\N	CANTON	480	000510	\N	\N	\N	\N
10244	\N	\N	2001-01-05 00:00:00	ANCIEN	\N	Saint-Chely-d'Aubrac	\N	\N	\N	2001	\N	CANTON	120	59601L	\N	\N	\N	\N
10245	\N	\N	\N	ACTIF	\N	Brioude Nord	\N	\N	\N	\N	\N	CANTON	430	83022M	\N	\N	\N	\N
10246	\N	\N	2006-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2006	\N	CANTON	430	58349P	\N	\N	\N	\N
10247	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	CANTON	615	59527T	\N	\N	\N	\N
10248	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	CANTON	615	000501	\N	\N	\N	\N
10249	\N	\N	1998-12-12 00:00:00	ANCIEN	\N	Guines	\N	\N	\N	1998	\N	CANTON	620	59223E	\N	\N	\N	\N
10250	\N	\N	\N	ACTIF	\N	Toulouse (14ème canton)	\N	\N	\N	\N	\N	CANTON	310	89011K	\N	\N	\N	\N
10251	\N	\N	2007-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2007	\N	CANTON	971	58649Y	\N	\N	\N	\N
10252	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	CANTON	620	000524	\N	\N	\N	\N
10253	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	CANTON	140	000331	\N	\N	\N	\N
10254	\N	\N	2018-05-21 00:00:00	ANCIEN	\N	Le Horps	\N	\N	\N	\N	\N	CANTON	530	86001U	\N	\N	\N	2018-05-23 11:11:23
10255	\N	\N	2000-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2000	\N	CANTON	50	58943C	\N	\N	\N	\N
10256	\N	\N	2019-03-26 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	CANTON	420	58330C	\N	\N	\N	\N
10257	\N	\N	2012-12-07 00:00:00	ANCIEN	\N	Saint-Palais	\N	\N	\N	2012	\N	CANTON	640	59227J	\N	\N	\N	\N
10258	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	CANTON	810	000647	\N	\N	\N	\N
10259	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	CANTON	620	000122	\N	\N	\N	\N
10260	\N	\N	2004-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2004	\N	CANTON	310	58942B	\N	\N	\N	\N
10261	\N	\N	2003-11-13 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	CANTON	380	58351H	\N	\N	\N	\N
10262	\N	\N	2011-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2011	\N	CANTON	340	58934B	\N	\N	\N	\N
10263	\N	\N	2014-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2014	\N	CANTON	460	58818X	\N	\N	\N	\N
10264	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	CANTON	760	000177	\N	\N	\N	\N
10265	\N	\N	\N	ACTIF	\N	Bourg-lès-Valence	\N	\N	\N	\N	\N	CANTON	260	80020W	\N	\N	\N	\N
10266	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	CANTON	490	000319	\N	\N	\N	\N
10267	\N	\N	2009-06-01 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2009	\N	CANTON	690	58656X	\N	\N	\N	\N
10268	\N	\N	1997-03-07 00:00:00	ANCIEN	\N	Venaco	\N	\N	\N	1997	\N	CANTON	205	62001R	\N	\N	\N	\N
10269	\N	\N	2020-02-04 00:00:00	ANCIEN	\N	Hazebrouck Nord	\N	\N	\N	\N	\N	CANTON	590	59230D	\N	\N	\N	\N
10270	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	CANTON	860	58816V	\N	\N	\N	\N
10271	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	CANTON	390	000370	\N	\N	\N	\N
10272	\N	\N	2007-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2007	\N	CANTON	270	58949J	\N	\N	\N	\N
10273	\N	\N	2008-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2008	\N	CANTON	440	58332E	\N	\N	\N	\N
10274	\N	\N	1983-12-27 00:00:00	ANCIEN	\N	\N	\N	\N	\N	1983	\N	CANTON	620	000185	\N	\N	\N	\N
10275	\N	\N	1999-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	\N	1999	\N	CANTON	830	000630	\N	\N	\N	\N
10276	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	CANTON	670	000516	\N	\N	\N	\N
10277	\N	\N	2013-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2013	\N	CANTON	350	58945E	\N	\N	\N	\N
10278	\N	\N	2002-03-07 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2002	\N	CANTON	120	58948H	\N	\N	\N	\N
10279	\N	\N	\N	ACTIF	\N	Rouen (2ème canton)	\N	\N	\N	\N	\N	CANTON	760	000442	\N	\N	\N	\N
10280	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	CANTON	710	000248	\N	\N	\N	\N
10281	\N	\N	\N	ACTIF	\N	Callac	\N	\N	\N	\N	\N	CANTON	220	89033R	\N	\N	\N	\N
10282	\N	\N	2023-04-26 00:00:00	ANCIEN	\N	Case-Pilote-Bellefontaine	\N	\N	\N	\N	\N	CANTON	972	59546W	\N	\N	\N	\N
10283	\N	\N	2010-09-13 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2010	\N	CANTON	290	58925A	\N	\N	\N	\N
10284	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	CANTON	660	000611	\N	\N	\N	\N
12079	\N	\N	2011-03-27 00:00:00	ANCIEN	\N	Criquetot-l'Esneval	\N	\N	2004	2011	\N	CANTON	760	95062K	\N	\N	\N	\N
1396	\N	\N	2004-03-28 00:00:00	ANCIEN	\N	Saint-Bonnet-le-Château	\N	\N	\N	2004	\N	CANTON	420	97011G	de 	\N	\N	\N
1400	\N	\N	2004-04-01 00:00:00	ANCIEN	\N	Cahors-sud	\N	\N	1998	2004	\N	CANTON	460	92039X	de 	\N	\N	\N
1406	1985-03-17 00:00:00	\N	2011-03-27 00:00:00	ANCIEN	\N	Le Teilleul	\N	\N	1985	2011	\N	CANTON	500	96004D	de 	\N	\N	\N
1408	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Château-Gontier Ouest	\N	\N	1976	2001	\N	CANTON	530	83011J	de 	\N	\N	\N
1434	1985-03-17 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Saint-Laurent-de-Neste	\N	\N	1985	\N	\N	CANTON	650	92020L	de 	\N	\N	\N
1460	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Château-Landon	\N	\N	1982	2001	\N	CANTON	770	95039L	de 	\N	\N	\N
1480	\N	\N	2001-03-18 00:00:00	ANCIEN	\N	Le Pecq	\N	\N	\N	2001	\N	CANTON	895	95035G	de 	\N	\N	\N
5873	\N	\N	2004-03-28 00:00:00	ANCIEN	\N	Etrechy	\N	\N	\N	2004	\N	CANTON	265	00003C	\N	\N	\N	\N
6363	\N	\N	2001-09-30 00:00:00	ANCIEN	\N	Blois 1	\N	\N	1998	2001	\N	CANTON	410	01007L	\N	\N	\N	\N
6371	1985-03-10 00:00:00	\N	2004-04-01 00:00:00	ANCIEN	\N	Clairvaux-les-Lacs	\N	\N	1985	2004	\N	CANTON	390	01008M	\N	\N	\N	\N
6303	2001-03-18 00:00:00	\N	2004-03-28 00:00:00	ANCIEN	\N	Le Pecq	\N	\N	2001	2004	\N	CANTON	895	95035G	\N	\N	\N	\N
6189	1979-03-25 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Mauléon-Barousse	\N	\N	1979	\N	\N	CANTON	650	01003G	\N	\N	\N	\N
6227	2001-03-18 00:00:00	\N	2001-12-08 00:00:00	ANCIEN	\N	Compiègne Nord	\N	\N	2001	2001	\N	CANTON	600	92035T	\N	\N	\N	\N
6254	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Château-Gontier Ouest	\N	\N	2001	\N	\N	CANTON	530	83011J	\N	\N	\N	\N
10554	\N	\N	\N	ANCIEN	\N	\N	\N	\N	1982	1985	\N	CANTON	500	01011G	\N	\N	\N	\N
10565	2001-03-18 00:00:00	\N	2008-03-16 00:00:00	ANCIEN	\N	Paris	\N	\N	2001	2008	\N	CANTON	615	95011X	\N	\N	\N	\N
1370	\N	\N	\N	ANCIEN	\N	Massy-ouest	\N	\N	1985	1992	\N	CANTON	265	86039K	de 	\N	\N	\N
1371	\N	\N	2004-03-28 00:00:00	ANCIEN	\N	Bernay-Ouest	\N	\N	\N	2004	\N	CANTON	270	89022N	de 	\N	\N	\N
1372	\N	\N	2012-01-13 00:00:00	ANCIEN	\N	Lyons-la-Forêt	\N	\N	\N	2012	\N	CANTON	270	81014D	de 	\N	\N	\N
1373	\N	\N	2001-10-14 00:00:00	ANCIEN	\N	Chateauneuf	\N	\N	\N	2001	\N	CANTON	280	89009R	de 	\N	\N	\N
1374	\N	\N	2010-12-20 00:00:00	ANCIEN	\N	Senonches	\N	\N	\N	2010	\N	CANTON	280	89031P	de 	\N	\N	\N
1375	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Quimper 3ème canton	\N	\N	\N	2001	\N	CANTON	290	86006A	de 	\N	\N	\N
1376	\N	\N	2010-08-11 00:00:00	ANCIEN	\N	Plouzévédé	\N	\N	\N	2010	\N	CANTON	290	89034S	de 	\N	\N	\N
1377	\N	\N	2014-09-07 00:00:00	ANCIEN	\N	Valleraugue	\N	\N	\N	2014	\N	CANTON	300	92046W	de 	\N	\N	\N
1378	\N	\N	2004-03-28 00:00:00	ANCIEN	\N	Bessèges	\N	\N	\N	2004	\N	CANTON	300	80040B	de 	\N	\N	\N
1379	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Carbonne	\N	\N	\N	2001	\N	CANTON	310	80039J	de 	\N	\N	\N
1380	\N	\N	2002-11-11 00:00:00	ANCIEN	\N	Lectoure	\N	\N	\N	2002	\N	CANTON	320	89008Q	de 	\N	\N	\N
1381	\N	\N	2011-03-27 00:00:00	ANCIEN	\N	Pujols-sur-Dordogne	\N	\N	\N	2011	\N	CANTON	330	90003B	de 	\N	\N	\N
1382	\N	\N	2004-03-21 00:00:00	ANCIEN	\N	Carbon-Blanc	\N	\N	1998	2004	\N	CANTON	330	80027E	de 	\N	\N	\N
1383	\N	\N	2004-03-21 00:00:00	ANCIEN	\N	Monségur	\N	\N	\N	2004	\N	CANTON	330	89025R	de 	\N	\N	\N
1384	\N	\N	\N	ACTIF	\N	Nanterre-sud-ouest	\N	\N	\N	\N	\N	CANTON	335	97003G	de 	\N	\N	\N
1385	1996-09-22 00:00:00	\N	2004-03-28 00:00:00	ANCIEN	\N	Chaville	\N	\N	1996	2004	\N	CANTON	335	95007C	de 	\N	\N	\N
1386	\N	\N	\N	ANCIEN	\N	Neuilly-sur-Seine-Nord	\N	\N	\N	2004	\N	CANTON	335	77053G	de 	\N	\N	\N
1388	\N	\N	2004-03-28 00:00:00	ANCIEN	\N	Clermont-l'Hérault	\N	\N	\N	2004	\N	CANTON	340	80048K	de 	\N	\N	\N
1389	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Levroux	\N	\N	\N	2001	\N	CANTON	360	89030N	de 	\N	\N	\N
1390	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Château-Renault	\N	\N	\N	2001	\N	CANTON	370	83026R	de 	\N	\N	\N
1391	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Chambray-lès-Tours	\N	\N	\N	2001	\N	CANTON	370	92012L	de 	\N	\N	\N
1392	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Meylan	\N	\N	\N	2001	\N	CANTON	380	83020K	de 	\N	\N	\N
1393	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Grenoble 2ème canton	\N	\N	\N	2001	\N	CANTON	380	83028T	de 	\N	\N	\N
1394	\N	\N	2004-04-28 00:00:00	ANCIEN	\N	Villard-de-Lans	\N	\N	\N	2004	\N	CANTON	380	83031N	de 	\N	\N	\N
1395	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Contres	\N	\N	\N	2001	\N	CANTON	410	86005Y	de 	\N	\N	\N
12531	1994-03-27 00:00:00	\N	2001-03-17 00:00:00	ANCIEN	\N	Yerres	\N	\N	\N	\N	\N	CANTON	265	11068S	\N	\N	\N	\N
1397	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Vorey	\N	\N	\N	2001	\N	CANTON	430	78006D	de 	\N	\N	\N
1398	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Vertou	\N	\N	\N	2001	\N	CANTON	440	83025Q	de 	\N	\N	\N
1399	\N	\N	\N	ACTIF	\N	La Baule	\N	\N	\N	\N	\N	CANTON	440	92032Q	de 	\N	\N	\N
12520	\N	\N	2015-03-03 00:00:00	ANCIEN	\N	Raincy	\N	\N	1997	\N	\N	CANTON	775	11051H	\N	\N	\N	2015-03-03 10:32:39
1401	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Saint-Céré	\N	\N	\N	2001	\N	CANTON	460	88004G	de 	\N	\N	\N
1402	\N	\N	2004-03-28 00:00:00	ANCIEN	\N	Duras	\N	\N	\N	2004	\N	CANTON	470	83033Q	de 	\N	\N	\N
1403	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Francescas	\N	\N	\N	2001	\N	CANTON	470	81001X	de 	\N	\N	\N
1404	\N	\N	2013-01-23 00:00:00	ANCIEN	\N	Durtal	\N	\N	\N	2013	\N	CANTON	490	83038V	de 	\N	\N	\N
12525	1992-03-29 00:00:00	\N	1998-03-01 00:00:00	ANCIEN	\N	Massy-Ouest	\N	\N	\N	1998	\N	CANTON	265	11070L	\N	\N	\N	\N
1407	\N	\N	2023-05-14 00:00:00	ANCIEN	\N	Ville-en-Tardenois	\N	\N	\N	\N	\N	CANTON	510	83056X	de 	\N	\N	\N
12550	1985-03-17 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Sézanne	\N	\N	\N	\N	\N	CANTON	510	11097X	\N	\N	\N	\N
1409	1979-03-22 00:00:00	\N	2004-03-28 00:00:00	ANCIEN	\N	Nancy-Sud	\N	\N	1979	2004	\N	CANTON	540	92007P	de 	\N	\N	\N
12539	2001-03-18 00:00:00	\N	2014-01-01 00:00:00	ANCIEN	\N	Evry-Nord	\N	\N	\N	\N	\N	CANTON	265	11068S	d'	\N	\N	2014-10-20 12:17:16
1430	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Auchel	\N	\N	\N	2001	\N	CANTON	620	84003N	d'	\N	\N	\N
1431	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Norrent-Fontès	\N	\N	\N	2001	\N	CANTON	620	92027T	de 	\N	\N	\N
1432	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Châteldon	\N	\N	\N	2001	\N	CANTON	630	81015E	de 	\N	\N	\N
1433	\N	\N	\N	ACTIF	\N	Aramits	\N	\N	\N	\N	\N	CANTON	640	92006N	d'	\N	\N	\N
1435	\N	\N	2013-08-01 00:00:00	ANCIEN	\N	Saint-Laurent-de-la-Salanque	\N	\N	\N	2013	\N	CANTON	660	92036U	de 	\N	\N	\N
1436	\N	\N	2004-03-28 00:00:00	ANCIEN	\N	Sournia	\N	\N	\N	2004	\N	CANTON	660	92011K	de 	\N	\N	\N
1437	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Erstein	\N	\N	\N	2001	\N	CANTON	670	95036H	d'	\N	\N	\N
1438	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	La Petite Pierre	\N	\N	\N	2001	\N	CANTON	670	92005M	de 	\N	\N	\N
1439	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Wasselonne	\N	\N	\N	2001	\N	CANTON	670	91002E	de 	\N	\N	\N
1440	\N	\N	2004-03-28 00:00:00	ANCIEN	\N	Sierentz	\N	\N	\N	2004	\N	CANTON	680	95045J	de 	\N	\N	\N
1441	\N	\N	2004-03-28 00:00:00	ANCIEN	\N	Saint-Laurent-de-Chamousset	\N	\N	1973	2004	\N	CANTON	690	86047K	de 	\N	\N	\N
1442	\N	\N	2004-04-01 00:00:00	ANCIEN	\N	Thizy	\N	\N	1990	2004	\N	CANTON	690	95049N	de 	\N	\N	\N
1443	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Vénissieux-Sud	\N	\N	\N	2001	\N	CANTON	690	95032D	de 	\N	\N	\N
1444	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Pesmes	\N	\N	\N	2001	\N	CANTON	700	95040D	de 	\N	\N	\N
1445	1992-03-30 00:00:00	\N	2002-07-08 00:00:00	ANCIEN	\N	Vesoul-Ouest	\N	\N	\N	\N	\N	CANTON	700	95041E	de 	\N	\N	2014-09-28 15:35:27
1446	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Sennecey-le-Grand	\N	\N	\N	2001	\N	CANTON	710	95030B	de 	\N	\N	\N
1447	\N	\N	2004-03-28 00:00:00	ANCIEN	\N	Issy-l'Evêque	\N	\N	\N	2004	\N	CANTON	710	86043F	d'	\N	\N	\N
1448	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Matour	\N	\N	\N	2001	\N	CANTON	710	95020Y	de 	\N	\N	\N
1449	\N	\N	2004-03-28 00:00:00	ANCIEN	\N	Le Grand Lucé	\N	\N	\N	2004	\N	CANTON	720	77012W	de 	\N	\N	\N
1450	\N	\N	2004-04-01 00:00:00	ANCIEN	\N	Tuffé	\N	\N	1998	2004	\N	CANTON	720	77043E	de 	\N	\N	\N
1451	\N	\N	2004-04-01 00:00:00	ANCIEN	\N	Montfort-le-Gesnois	\N	\N	\N	2004	\N	CANTON	720	95019G	de 	\N	\N	\N
1452	\N	\N	1999-09-16 00:00:00	ANCIEN	\N	Bourg-Saint-Maurice	\N	\N	\N	\N	\N	CANTON	730	95008D	de 	\N	\N	\N
1453	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Montmélian	\N	\N	\N	2001	\N	CANTON	730	77060F	de 	\N	\N	\N
1454	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Thônes	\N	\N	\N	2001	\N	CANTON	740	95005A	de 	\N	\N	\N
1455	2004-03-28 00:00:00	\N	\N	ACTIF	\N	Bellencombre	\N	\N	2004	\N	\N	CANTON	760	95014B	de 	\N	\N	\N
1457	\N	\N	2000-04-01 00:00:00	ANCIEN	\N	Grand-Couronne	\N	\N	1985	2000	\N	CANTON	760	95003X	de 	\N	\N	\N
1458	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Le Havre 6ème canton	\N	\N	1994	2001	\N	CANTON	760	95034F	de 	\N	\N	\N
1461	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Neuilly-plaisance	\N	\N	1982	2001	\N	CANTON	775	95024D	de 	\N	\N	\N
1462	\N	\N	2004-03-28 00:00:00	ANCIEN	\N	Ménigoute	\N	\N	\N	2004	\N	CANTON	790	95028H	de 	\N	\N	\N
1463	\N	\N	\N	ACTIF	\N	Albert	\N	\N	1973	\N	\N	CANTON	800	95023C	d'	\N	\N	\N
1464	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Hallencourt	\N	\N	\N	2001	\N	CANTON	800	95047L	d'	\N	\N	\N
1465	\N	\N	1998-11-02 00:00:00	ANCIEN	\N	Dourgne	\N	\N	\N	1998	\N	CANTON	810	95048M	de 	\N	\N	\N
1466	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Monesties	\N	\N	\N	2001	\N	CANTON	810	95052H	de 	\N	\N	\N
1467	1985-03-17 00:00:00	\N	2004-04-01 00:00:00	ANCIEN	\N	Valence-d'Agen 	\N	\N	1985	2004	\N	CANTON	820	86010V	de 	\N	\N	\N
1468	\N	\N	2004-03-28 00:00:00	ANCIEN	\N	Choisy-le-Roi	\N	\N	\N	2004	\N	CANTON	824	77044F	de 	\N	\N	\N
1469	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	St Leu-la-Forêt	\N	\N	\N	2001	\N	CANTON	828	95042F	de 	\N	\N	\N
1470	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Besse-sur-Issole	\N	\N	\N	2001	\N	CANTON	830	95031C	de 	\N	\N	\N
1472	1982-03-21 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Avignon-Ouest	\N	\N	1982	\N	\N	CANTON	840	87003B	d'	\N	\N	\N
1473	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Noirmoutier-en-l'île	\N	\N	\N	2001	\N	CANTON	850	86041D	de 	\N	\N	\N
1475	\N	\N	2004-04-01 00:00:00	ANCIEN	\N	Loudun	\N	\N	1977	2004	\N	CANTON	860	68036E	de 	\N	\N	\N
1476	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Châlus	\N	\N	1982	2001	\N	CANTON	870	95055L	de 	\N	\N	\N
1477	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Remiremont	\N	\N	1976	2001	\N	CANTON	880	77058M	de 	\N	\N	\N
1478	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Auxerre-Est	\N	\N	\N	2001	\N	CANTON	890	95033E	d'	\N	\N	\N
1479	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Chéroy	\N	\N	1992	2001	\N	CANTON	890	86044G	de 	\N	\N	\N
1481	\N	\N	2004-03-28 00:00:00	ANCIEN	\N	Petit-Bourg	\N	\N	\N	2004	\N	CANTON	971	95043G	de 	\N	\N	\N
1482	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Le Marin	\N	\N	\N	2001	\N	CANTON	972	86021Y	de 	\N	\N	\N
1484	\N	\N	\N	ANCIEN	\N	Saint-Pierre	\N	\N	\N	2000	\N	CANTON	995	95061J	de 	\N	\N	\N
5010	1998-03-22 00:00:00	\N	2001-04-10 00:00:00	ANCIEN	\N	Lavelanet	\N	\N	1998	2001	\N	CANTON	90	98006P	de 	\N	\N	\N
5014	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Borgo	\N	\N	1988	2001	\N	CANTON	205	98008R	de 	\N	\N	\N
5031	\N	\N	1998-10-12 00:00:00	ANCIEN	\N	Clermont-Ferrand-Est	\N	\N	1988	1988	\N	CANTON	630	98009S	de 	\N	\N	\N
5034	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Toulouse VI	\N	\N	1982	2001	\N	CANTON	310	98010K	de 	\N	\N	\N
5045	\N	\N	2004-03-28 00:00:00	ANCIEN	\N	La Roche-Derrien	\N	\N	1979	2004	\N	CANTON	220	98012M	de 	\N	\N	\N
5051	1980-10-26 00:00:00	\N	2001-03-23 00:00:00	ANCIEN	\N	Pacy-sur-Eure	\N	\N	1980	2001	\N	CANTON	270	98013N	de 	\N	\N	\N
5059	\N	\N	2004-03-28 00:00:00	ANCIEN	\N	Surgères	\N	\N	1973	2004	\N	CANTON	170	98014P	de 	\N	\N	\N
5076	1992-03-29 00:00:00	\N	2004-03-21 00:00:00	ANCIEN	\N	Chateauneuf -Côte bleue	\N	\N	1992	2004	\N	CANTON	130	98020M	de 	\N	\N	\N
5082	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Saint-Vivien-de-Médoc	\N	\N	1988	2001	\N	CANTON	330	98021N	de 	\N	\N	\N
5089	1982-03-14 00:00:00	\N	2001-03-11 00:00:00	ANCIEN	\N	Marseille III	\N	\N	\N	2001	\N	CANTON	130	98022P	de 	\N	\N	\N
1413	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Hayange	\N	\N	\N	2001	\N	CANTON	570	96007G	de 	\N	\N	\N
10651	2004-04-01 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Cahors-sud	\N	\N	\N	\N	\N	CANTON	460	92039X	\N	\N	\N	2014-04-08 16:01:00
12509	\N	\N	\N	ANCIEN	\N	Montoir de Bretagne	\N	\N	1982	1994	\N	CANTON	440	11066Q	\N	\N	\N	\N
12490	1994-03-27 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Champigny-sur-Marne-Ouest	\N	\N	\N	\N	\N	CANTON	824	11034G	\N	\N	\N	\N
12505	2011-04-01 00:00:00	\N	2011-07-31 00:00:00	ANCIEN	\N	Woippy	\N	\N	2011	2011	\N	CANTON	570	11049P	\N	\N	\N	\N
12545	1975-01-19 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Fay-sur-Lignon	\N	\N	\N	\N	\N	CANTON	430	11093T	\N	\N	\N	2014-07-16 16:12:46
12561	2001-03-11 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Seyches	\N	\N	\N	\N	\N	CANTON	470	11095V	\N	\N	\N	\N
10653	2004-04-01 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Châtillon-sur-Marne	\N	\N	2004	\N	\N	CANTON	510	01025N	\N	\N	\N	\N
10654	2004-04-01 00:00:00	\N	2011-03-27 00:00:00	ANCIEN	\N	Prauthoy	\N	\N	2004	2011	\N	CANTON	520	01057W	\N	\N	\N	\N
10655	2004-04-01 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Vic-sur-Seille	\N	\N	2004	\N	\N	CANTON	570	01061S	\N	\N	\N	\N
10657	2004-03-28 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Clermont-Ferrand Nord-ouest	\N	\N	2004	\N	\N	CANTON	630	01031L	\N	\N	\N	\N
10667	2004-03-28 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Etrechy	\N	\N	2004	\N	\N	CANTON	265	00003C	\N	\N	\N	\N
10668	\N	\N	\N	ANCIEN	\N	Clermont-Ferrand Nord-ouest	\N	\N	1989	1992	\N	CANTON	630	01031L	\N	\N	\N	\N
10838	\N	\N	2004-10-26 00:00:00	ANCIEN	\N	Crécy-la-Chapelle	\N	\N	1992	2004	\N	CANTON	770	04048J	\N	\N	\N	\N
10867	\N	\N	2004-10-20 00:00:00	ANCIEN	\N	Corbeil-Essonnes-Est	\N	\N	1998	\N	\N	CANTON	265	04055H	\N	\N	\N	\N
10956	\N	\N	1998-01-13 00:00:00	ANCIEN	\N	Cormeilles-en-Parisis	\N	\N	1988	1998	\N	CANTON	828	04078Q	\N	\N	\N	\N
10965	\N	\N	\N	ACTIF	\N	Paris	\N	\N	1998	\N	\N	CANTON	615	04080J	\N	\N	\N	2017-06-29 15:55:31
10988	1998-03-22 00:00:00	\N	2004-10-25 00:00:00	ANCIEN	\N	Pavillons-sous-Bois	\N	\N	1998	2004	\N	CANTON	775	04086Q	\N	\N	\N	\N
11026	1988-03-06 00:00:00	\N	2004-10-26 00:00:00	ANCIEN	\N	du Diamant	\N	\N	1988	2004	\N	CANTON	972	04094Q	\N	\N	\N	\N
11030	\N	\N	2015-03-29 00:00:00	ANCIEN	\N	Gosier 1	\N	\N	1994	\N	\N	CANTON	971	04095R	\N	\N	\N	\N
11058	\N	\N	2015-03-29 00:00:00	ANCIEN	\N	Vincennes-Ouest	\N	\N	\N	\N	\N	CANTON	824	04043D	\N	\N	\N	\N
11121	\N	\N	\N	ANCIEN	\N	Laval Sud-ouest	\N	\N	1992	1998	\N	CANTON	530	01047U	\N	\N	\N	\N
11249	1988-10-02 00:00:00	\N	2007-07-15 00:00:00	ANCIEN	\N	Garches	\N	\N	1988	\N	\N	CANTON	335	07024N	\N	\N	\N	\N
11910	\N	\N	\N	ANCIEN	\N	\N	\N	\N	1976	1982	\N	CANTON	590	92031P	\N	\N	\N	\N
11919	\N	\N	\N	ANCIEN	\N	\N	\N	\N	1988	1998	\N	CANTON	540	92040Q	\N	\N	\N	\N
11926	\N	\N	\N	ANCIEN	\N	\N	\N	\N	1998	1994	\N	CANTON	540	01014K	\N	\N	\N	\N
6413	\N	\N	2001-12-05 00:00:00	ANCIEN	\N	Bourgogne	\N	\N	\N	2001	\N	CANTON	510	01024M	\N	\N	\N	\N
6416	\N	\N	2004-04-01 00:00:00	ANCIEN	\N	Châtillon-sur-Marne	\N	\N	1992	2004	\N	CANTON	510	01025N	\N	\N	\N	\N
6439	1998-03-22 00:00:00	\N	2004-03-28 00:00:00	ANCIEN	\N	Clermont-Ferrand Nord-ouest	\N	\N	1998	2004	\N	CANTON	630	01031L	\N	\N	\N	\N
6486	2001-03-18 00:00:00	\N	2001-11-30 00:00:00	ANCIEN	\N	Fresnes-en-Woeuvre	\N	\N	2001	2001	\N	CANTON	550	01048V	\N	\N	\N	\N
6515	\N	\N	2004-04-01 00:00:00	ANCIEN	\N	Saint-Gildas-des-Bois	\N	\N	1994	\N	\N	CANTON	440	01056V	\N	\N	\N	2015-01-21 17:55:08
6520	2001-03-18 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Saint-Blin	\N	\N	2001	\N	\N	CANTON	520	01058X	\N	\N	\N	\N
6522	1982-03-21 00:00:00	\N	2001-12-08 00:00:00	ANCIEN	\N	Saint-Pierre-des-Corps	\N	\N	1982	2001	\N	CANTON	370	01013J	\N	\N	\N	\N
6534	\N	\N	2004-04-01 00:00:00	ANCIEN	\N	Vic-sur-Seille	\N	\N	1979	2004	\N	CANTON	570	01061S	\N	\N	\N	\N
6541	\N	\N	2004-04-01 00:00:00	ANCIEN	\N	Saint-Paulien	\N	\N	1979	2004	\N	CANTON	430	01052R	\N	\N	\N	\N
6558	\N	\N	\N	ANCIEN	\N	Marcq-en-Baroeul	\N	\N	1988	2014	\N	CANTON	590	01042P	\N	\N	\N	2015-01-21 17:52:18
6597	\N	\N	2004-04-01 00:00:00	ANCIEN	\N	Prauthoy	\N	\N	1992	2004	\N	CANTON	520	01057W	\N	\N	\N	\N
6773	2002-10-20 00:00:00	\N	2008-03-21 00:00:00	ANCIEN	\N	Lille-centre	\N	\N	\N	\N	\N	CANTON	590	92044U	\N	\N	\N	\N
10647	2004-04-01 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Clairvaux-les-Lacs	\N	\N	2004	\N	\N	CANTON	390	01008M	\N	\N	\N	\N
10648	2004-03-28 00:00:00	\N	\N	ANCIEN	\N	Saint-Bonnet-le-Château	\N	\N	2004	2010	\N	CANTON	420	97011G	\N	\N	\N	\N
10629	2004-03-28 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Bayeux	\N	\N	2004	\N	\N	CANTON	140	98042T	\N	\N	\N	\N
10630	2004-03-28 00:00:00	\N	2011-03-27 00:00:00	ANCIEN	\N	Cambremer	\N	\N	\N	2011	\N	CANTON	140	89007P	\N	\N	\N	\N
10631	2004-03-21 00:00:00	\N	\N	ANCIEN	\N	Saint-Flour Sud	\N	\N	\N	2008	\N	CANTON	150	98027U	\N	\N	\N	\N
10633	2004-03-21 00:00:00	\N	\N	ACTIF	\N	Mirebeau-sur-Bèze	\N	\N	2004	\N	\N	CANTON	210	98048A	\N	\N	\N	\N
10640	2004-03-21 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Carbon-Blanc	\N	\N	2004	\N	\N	CANTON	330	80027E	\N	\N	\N	\N
10641	2004-03-21 00:00:00	\N	\N	ACTIF	\N	Monségur	\N	\N	2004	\N	\N	CANTON	330	89025R	\N	\N	\N	\N
10642	2004-03-21 00:00:00	\N	\N	ACTIF	\N	Montpellier 9ème canton	\N	\N	2004	\N	\N	CANTON	340	89043T	\N	\N	\N	\N
1387	\N	\N	2004-03-21 00:00:00	ANCIEN	\N	Montpellier 9ème canton	\N	\N	\N	2004	\N	CANTON	340	89043T	de 	\N	\N	\N
10649	2004-04-01 00:00:00	\N	\N	ACTIF	\N	Saint-Paulien	\N	\N	2004	\N	\N	CANTON	430	01052R	\N	\N	\N	\N
1483	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Fort-de-France 10ème canton	\N	\N	1992	2001	\N	CANTON	972	95044H	de 	\N	\N	\N
10881	\N	\N	2020-06-28 00:00:00	ANCIEN	\N	Paris	\N	\N	2001	\N	\N	CANTON	615	04059M	\N	\N	\N	2017-06-29 15:53:53
10897	\N	\N	\N	ACTIF	\N	Paris	\N	\N	2001	\N	\N	CANTON	615	04066L	\N	\N	\N	2017-06-29 15:55:53
10911	\N	\N	2006-03-01 00:00:00	ANCIEN	\N	Paris	\N	\N	2001	2006	\N	CANTON	615	04067M	\N	\N	\N	\N
10961	1989-03-19 00:00:00	\N	\N	ACTIF	\N	Paris	\N	\N	\N	\N	\N	CANTON	615	04079R	\N	\N	\N	2017-06-29 15:55:07
6546	\N	\N	2004-03-28 00:00:00	ANCIEN	\N	Heyrieux	\N	\N	1973	2004	\N	CANTON	380	01019Q	\N	\N	\N	\N
10646	2004-03-28 00:00:00	\N	2011-03-27 00:00:00	ANCIEN	\N	Heyrieux	\N	\N	2004	\N	\N	CANTON	380	01019Q	\N	\N	\N	\N
10623	2001-03-11 00:00:00	\N	2004-03-27 00:00:00	ANCIEN	\N	Château-Landon	\N	\N	2001	2004	\N	CANTON	770	95039L	\N	\N	\N	\N
10624	2004-03-28 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Château-Landon	\N	\N	2004	\N	\N	CANTON	770	95039L	\N	\N	\N	\N
10626	2004-04-01 00:00:00	\N	2014-03-30 00:00:00	ANCIEN	\N	Saint-Gildas-des-Bois	\N	\N	\N	\N	\N	CANTON	440	01056V	\N	\N	\N	2015-01-21 18:03:22
12762	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	CANTON	971	04096S	\N	\N	\N	\N
6073	2001-03-23 00:00:00	\N	2011-03-29 00:00:00	ANCIEN	\N	Fort-de-France 10ème canton	\N	\N	2001	2011	\N	CANTON	972	95044H	\N	\N	\N	\N
1369	\N	\N	1999-09-24 00:00:00	ANCIEN	\N	Mennecy	\N	\N	\N	\N	\N	CANTON	265	95027G	de 	\N	\N	\N
1420	\N	\N	2015-03-29 00:00:00	ANCIEN	\N	Froissy	\N	\N	\N	\N	\N	CANTON	600	92045V	de 	\N	\N	\N
10674	1985-03-17 00:00:00	\N	\N	ANCIEN	\N	Châtillon	\N	\N	1985	1993	\N	CANTON	335	93005R	\N	\N	\N	\N
10703	1994-03-28 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Versailles-Nord	\N	\N	\N	\N	\N	CANTON	895	04018C	\N	\N	\N	2017-09-24 18:52:38
10722	1985-03-17 00:00:00	\N	\N	ANCIEN	\N	Montlouis-sur-Loire	\N	\N	1985	1998	\N	CANTON	370	92030N	\N	\N	\N	\N
11034	\N	\N	\N	ANCIEN	\N	Abymes - 4	\N	\N	1994	1997	\N	CANTON	971	04096S	\N	\N	\N	\N
6406	\N	\N	2011-03-31 00:00:00	ANCIEN	\N	Pluvigner	\N	\N	1979	2011	\N	CANTON	560	01021J	\N	\N	\N	\N
6600	\N	\N	2008-03-21 00:00:00	ANCIEN	\N	Montmédy	\N	\N	1976	\N	\N	CANTON	550	01049W	\N	\N	\N	\N
6624	\N	\N	\N	ANCIEN	\N	Montigny-les-Metz	\N	\N	1979	1985	\N	CANTON	570	83042R	\N	\N	\N	\N
6632	\N	\N	\N	ANCIEN	\N	Perpignan 1	\N	\N	1992	1998	\N	CANTON	660	01006K	\N	\N	\N	\N
1428	\N	\N	2001-10-18 00:00:00	ANCIEN	\N	Desvres	\N	\N	\N	2001	\N	CANTON	620	92043T	de 	\N	\N	\N
12078	2011-03-30 00:00:00	\N	\N	ACTIF	\N	Fort-de France 10ème canton	\N	\N	2011	\N	\N	CANTON	972	95044H	\N	\N	\N	\N
6302	2001-03-18 00:00:00	\N	2004-03-21 00:00:00	ANCIEN	\N	Le Quesnoy-Est	\N	\N	2001	2004	\N	CANTON	590	92042S	\N	\N	\N	\N
1419	\N	\N	2001-04-02 00:00:00	ANCIEN	\N	Le Quesnoy-Est	\N	\N	\N	2001	\N	CANTON	590	92042S	de 	\N	\N	\N
10656	2004-03-21 00:00:00	\N	2008-03-21 00:00:00	ANCIEN	\N	Le Quesnoy-Est	\N	\N	2004	\N	\N	CANTON	590	92042S	\N	\N	\N	\N
12814	2001-03-01 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Nantes II	\N	\N	\N	\N	\N	CANTON	440	11067R	\N	\N	\N	\N
11129	\N	\N	\N	ANCIEN	\N	Saint-Pierre I	\N	\N	1999	2001	\N	CANTON	974	05001W	\N	\N	\N	\N
6493	2001-03-18 00:00:00	\N	2008-03-21 00:00:00	ANCIEN	\N	Aire-sur-la-Lys	\N	\N	2001	2008	\N	CANTON	620	01033N	\N	\N	\N	\N
12787	1979-01-01 00:00:00	\N	1988-01-01 00:00:00	ANCIEN	\N	Massy	\N	\N	\N	\N	\N	CANTON	265	11077T	\N	\N	\N	\N
12816	1998-03-01 00:00:00	\N	2012-01-25 00:00:00	ANCIEN	\N	Dax Nord	\N	\N	\N	\N	\N	CANTON	400	11014C	\N	\N	\N	\N
12828	2001-12-01 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Rouvroy	\N	\N	\N	\N	\N	CANTON	620	11063M	\N	\N	\N	\N
12830	2008-03-16 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Saint-Pois	\N	\N	\N	\N	\N	CANTON	500	05008E	\N	\N	\N	\N
12832	1992-03-29 00:00:00	\N	2014-06-24 00:00:00	ANCIEN	\N	Tullins	\N	\N	\N	\N	\N	CANTON	380	11041F	\N	\N	\N	2017-09-04 14:15:24
12834	1993-01-01 00:00:00	\N	2001-12-31 00:00:00	ANCIEN	\N	Sainte-Rose	\N	\N	\N	\N	\N	CANTON	974	11025F	\N	\N	\N	\N
12504	1988-10-02 00:00:00	\N	\N	ANCIEN	\N	Bayon	\N	\N	\N	1994	\N	CANTON	540	01014K	\N	\N	\N	\N
12492	1998-05-17 00:00:00	\N	2012-11-02 00:00:00	ANCIEN	\N	Nancy-Ouest	\N	\N	1998	\N	\N	CANTON	540	11048N	\N	\N	\N	\N
12521	1996-06-16 00:00:00	\N	2011-11-23 00:00:00	ANCIEN	\N	Nantes X	\N	\N	\N	\N	\N	CANTON	440	11064N	\N	\N	\N	\N
12524	\N	\N	2015-03-29 00:00:00	ANCIEN	\N	Noisiel	\N	\N	1995	\N	\N	CANTON	770	11074Q	\N	\N	\N	\N
12543	1985-03-17 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Pierrefitte-sur-Aire	\N	\N	\N	\N	\N	CANTON	550	11082Q	\N	\N	\N	\N
12549	1998-03-01 00:00:00	\N	2011-10-01 00:00:00	ANCIEN	\N	Conflans-Sainte-Honorine	\N	\N	\N	\N	\N	CANTON	895	11096W	\N	\N	\N	\N
12839	1998-03-01 00:00:00	\N	2010-03-31 00:00:00	ANCIEN	\N	Le François 2	\N	\N	\N	\N	\N	CANTON	972	11109J	\N	\N	\N	\N
12789	1994-03-27 00:00:00	\N	2012-01-25 00:00:00	ANCIEN	\N	Millas	\N	\N	\N	\N	\N	CANTON	660	11018G	\N	\N	\N	\N
12852	\N	\N	\N	ANCIEN	\N	\N	\N	\N	2007	2008	\N	CANTON	974	11020A	\N	\N	\N	\N
10595	\N	\N	\N	ANCIEN	\N	Versailles-Ouest	\N	\N	1988	1992	\N	CANTON	895	95004Y	\N	\N	\N	\N
10596	\N	\N	\N	ANCIEN	\N	Montigny-le Bretonneux	\N	\N	1992	1995	\N	CANTON	895	95004Y	\N	\N	\N	\N
10597	\N	\N	1973-09-13 00:00:00	ANCIEN	\N	Piana	\N	\N	1962	1973	\N	CANTON	200	01065W	\N	\N	\N	\N
10615	2004-03-21 00:00:00	\N	2019-07-18 00:00:00	ANCIEN	\N	Puteaux	\N	\N	2004	\N	\N	CANTON	335	95016D	\N	\N	\N	\N
10616	2004-03-28 00:00:00	\N	2008-03-21 00:00:00	ANCIEN	\N	Séverac-le-Château	\N	\N	2004	\N	\N	CANTON	120	89041R	\N	\N	\N	\N
10617	2004-03-28 00:00:00	\N	\N	ACTIF	\N	Auxerre-Est	\N	\N	2004	\N	\N	CANTON	890	95033E	\N	\N	\N	\N
1367	\N	\N	2004-03-28 00:00:00	ANCIEN	\N	Vercel-Villedieu-le-Camp	\N	\N	1979	2004	\N	CANTON	250	88009M	de 	\N	\N	\N
10620	2001-03-23 00:00:00	\N	2004-03-21 00:00:00	ANCIEN	\N	Saint-Trivier-de-Courtes	\N	\N	2001	2004	\N	CANTON	10	89016Q	\N	\N	\N	\N
10619	2004-03-21 00:00:00	\N	2015-05-03 00:00:00	ANCIEN	\N	Saint-Trivier-de-Courtes	\N	\N	\N	2015	\N	CANTON	10	89016Q	\N	\N	\N	\N
1456	1973-09-30 00:00:00	\N	2001-03-22 00:00:00	ANCIEN	\N	Criquetot-l'Esneval	\N	\N	1973	2001	\N	CANTON	760	95062K	de 	\N	\N	\N
10621	2001-03-23 00:00:00	\N	2004-03-27 00:00:00	ANCIEN	\N	Criquetot-l'Esneval	\N	\N	2001	2004	\N	CANTON	760	95062K	\N	\N	\N	\N
10622	2004-03-28 00:00:00	\N	2011-03-27 00:00:00	ANCIEN	\N	Criquetot-l'Esneval	\N	\N	2004	2011	\N	CANTON	760	95062K	\N	\N	\N	\N
10625	2004-04-01 00:00:00	\N	\N	ACTIF	\N	Châlus	\N	\N	2004	\N	\N	CANTON	870	95055L	\N	\N	\N	\N
10627	2004-04-01 00:00:00	\N	2014-04-01 00:00:00	ANCIEN	\N	Cérilly	\N	\N	\N	\N	\N	CANTON	30	98024R	\N	\N	\N	2014-05-26 14:24:58
10628	2004-03-28 00:00:00	\N	2011-03-27 00:00:00	ANCIEN	\N	Antraigues sur volane	\N	\N	2004	\N	\N	CANTON	70	98037W	\N	\N	\N	\N
12468	2000-03-01 00:00:00	\N	2006-02-28 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	CANTON	995	11023D	\N	\N	\N	\N
12557	2001-03-18 00:00:00	\N	2014-02-13 00:00:00	ANCIEN	\N	Elven	\N	\N	\N	\N	\N	CANTON	560	11099A	\N	\N	\N	2014-02-14 11:20:08
12569	1992-03-29 00:00:00	\N	2011-10-01 00:00:00	ANCIEN	\N	Romorantin-Lanthenay-Nord	\N	\N	\N	\N	\N	CANTON	410	11106F	\N	\N	\N	\N
12570	1982-03-21 00:00:00	\N	2014-04-30 00:00:00	ANCIEN	\N	Vertaizon	\N	\N	\N	\N	\N	CANTON	630	11105E	\N	\N	\N	2014-06-10 15:11:32
12768	2004-03-01 00:00:00	\N	2012-02-29 00:00:00	ANCIEN	\N	Meudon	\N	\N	\N	\N	\N	CANTON	335	11085T	\N	\N	\N	\N
12769	1988-09-01 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Nivillers	\N	\N	\N	\N	\N	CANTON	600	11046L	\N	\N	\N	\N
12773	\N	\N	2015-03-29 00:00:00	ANCIEN	\N	Bondy Sud-Est	\N	\N	\N	\N	\N	CANTON	775	11054L	\N	\N	\N	\N
12775	2004-01-01 00:00:00	\N	2020-06-28 00:00:00	ANCIEN	\N	Paris	\N	\N	\N	\N	\N	CANTON	615	11080N	\N	\N	\N	2017-06-16 16:15:22
12923	\N	\N	\N	ACTIF	\N	Grésy-sur-Isère	\N	\N	1992	\N	\N	CANTON	730	12038D	\N	\N	2013-08-19 14:51:46	\N
12931	\N	\N	\N	ACTIF	\N	Eu	\N	\N	2008	\N	\N	CANTON	760	13005X	\N	\N	2013-10-01 15:37:24	\N
13828	\N	\N	2015-03-29 00:00:00	ANCIEN	\N	Cayenne Nord-Est	\N	\N	1985	\N	\N	CANTON	973	14039A	de	\N	2014-09-17 11:57:48	2014-09-17 11:58:38
13787	2008-03-16 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Perpignan VIII	\N	\N	\N	\N	\N	CANTON	660	14018U	\N	\N	2014-08-27 16:38:52	2014-08-27 17:38:13
13836	\N	\N	2015-03-29 00:00:00	ANCIEN	\N	Saint-Aignan-sur-Roë	\N	\N	2011	\N	\N	CANTON	530	14042U	de	\N	2014-09-17 12:10:13	2014-09-17 12:13:50
50874	2015-03-30 00:00:00	\N	2018-03-01 00:00:00	ANCIEN	\N	Pilat	\N	\N	\N	\N	\N	DEPART	420	19415P	du	\N	2017-09-19 18:44:26	2017-09-24 21:51:18
13996	2001-04-02 00:00:00	\N	2014-12-15 00:00:00	ANCIEN	\N	Dinan	\N	\N	\N	\N	\N	CANTON	220	14157T	de	\N	2014-09-18 17:34:41	2015-01-14 10:05:04
14113	\N	\N	2014-10-26 00:00:00	ANCIEN	\N	Saulieu	\N	\N	1994	\N	\N	CANTON	210	14205J	de	\N	2014-09-28 17:06:37	2014-10-23 12:07:35
14314	1998-03-22 00:00:00	1998-03-22 00:00:00	2015-03-29 00:00:00	ANCIEN	\N	La Javie	\N	\N	\N	\N	\N	CANTON	40	14107H	de 	\N	2014-09-28 19:58:42	2014-09-28 20:00:10
14351	\N	\N	\N	ANCIEN	\N	Beaucourt	\N	\N	1998	2011	\N	CANTON	820	14069U	de	\N	2014-09-30 11:22:43	2014-09-30 11:23:54
15146	2015-03-30 00:00:00	2015-03-29 00:00:00	2015-07-31 00:00:00	ANCIEN	\N	Vaison la Romaine	\N	\N	\N	\N	\N	DEPART	840	95037J	de	\N	2015-03-31 15:00:28	2015-10-21 12:20:36
15147	2015-03-30 00:00:00	2015-03-29 00:00:00	\N	ACTIF	\N	Chauvigny	\N	\N	\N	\N	\N	DEPART	860	02002K	de	\N	2015-03-31 15:01:34	2015-03-31 15:02:07
15148	2015-03-30 00:00:00	2015-03-29 00:00:00	2021-06-15 00:00:00	ANCIEN	\N	Gâtinais en Bourgogne	\N	\N	\N	\N	\N	DEPART	890	14037X	de	\N	2015-03-31 15:02:49	2015-03-31 15:03:44
15151	2015-03-30 00:00:00	2015-03-29 00:00:00	\N	ACTIF	\N	Clamart	\N	\N	\N	\N	\N	DEPART	335	04081K	de	\N	2015-03-31 15:04:24	2015-04-15 17:39:26
15152	2015-03-30 00:00:00	2015-03-29 00:00:00	\N	ACTIF	\N	Le Gosier	\N	\N	\N	\N	\N	DEPART	971	04095R	de 	\N	2015-03-31 15:05:38	2015-03-31 15:14:45
15153	2015-03-30 00:00:00	2015-03-29 00:00:00	\N	ACTIF	\N	Champigny sur Marne-1	\N	\N	\N	\N	\N	DEPART	824	11034G	de	\N	2015-03-31 15:06:02	2015-04-03 10:43:49
15156	2015-03-30 00:00:00	2015-03-29 00:00:00	\N	ACTIF	\N	Bourbon-l'Archambault	\N	\N	\N	\N	\N	DEPART	30	98024R	du 	\N	2015-03-31 15:09:27	2017-11-16 16:40:38
15158	2015-03-30 00:00:00	2015-03-29 00:00:00	\N	ACTIF	\N	Seyne	\N	\N	\N	\N	\N	DEPART	40	14107H	de 	\N	2015-03-31 15:10:55	2015-03-31 15:15:24
15161	2015-03-30 00:00:00	2015-03-29 00:00:00	2020-09-24 00:00:00	ANCIEN	\N	Menton	\N	\N	\N	\N	\N	DEPART	60	08041T	de 	\N	2015-03-31 15:11:37	2015-04-15 17:29:34
15162	2015-03-30 00:00:00	2015-03-29 00:00:00	2015-12-02 00:00:00	ANCIEN	\N	Nice 3	\N	\N	\N	\N	\N	DEPART	60	14187A	de	\N	2015-03-31 15:12:28	2015-12-04 12:27:44
15165	2015-03-30 00:00:00	2015-03-29 00:00:00	\N	ACTIF	\N	Rocroi	\N	\N	\N	\N	\N	DEPART	80	04097T	de 	\N	2015-03-31 15:13:08	2017-11-09 10:28:10
15166	2015-03-30 00:00:00	2015-03-29 00:00:00	2017-05-10 00:00:00	ANCIEN	\N	Creney-prÃ¨s-Troyes	\N	\N	\N	\N	\N	DEPART	100	89017R	de 	\N	2015-03-31 15:13:46	2017-07-03 14:36:07
15207	2015-06-12 00:00:00	\N	2021-06-26 00:00:00	ANCIEN	\N	Caen-4	\N	\N	\N	\N	\N	DEPART	140	14281W	\N	\N	2015-06-12 15:46:33	2015-06-15 10:53:16
15542	2015-03-29 00:00:00	\N	\N	ACTIF	\N	Bailleul	\N	\N	\N	\N	\N	DEPART	590	07028S	\N	\N	2017-06-07 15:29:40	2017-06-07 15:48:30
50809	2015-04-02 00:00:00	2015-03-29 00:00:00	2021-06-27 00:00:00	ANCIEN	\N	Clermont	\N	\N	\N	\N	\N	DEPART	600	11115U	de	\N	2017-09-19 15:38:13	2017-09-19 15:41:33
50839	2015-03-29 00:00:00	2015-03-29 00:00:00	\N	ACTIF	\N	Château-Chinon	\N	\N	\N	\N	\N	DEPART	580	19531S	de	\N	2017-09-19 17:09:29	2017-12-04 18:36:27
50866	2011-03-27 00:00:00	2011-03-27 00:00:00	\N	ACTIF	\N	 Serris-Crécy-la-Chapelle	\N	\N	\N	\N	\N	DEPART	770	19543W	de	\N	2017-09-19 18:13:05	2017-11-09 17:53:21
50875	1992-03-22 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Pilat	\N	\N	\N	\N	\N	CANTON	420	19415P	du	\N	2017-09-19 18:44:27	2017-09-24 21:51:13
50945	2015-03-29 00:00:00	\N	\N	ACTIF	\N	Maringues	\N	\N	\N	\N	\N	DEPART	630	19387D	de	\N	2017-09-20 16:13:19	2018-01-24 11:12:11
51437	1988-02-02 00:00:00	\N	2001-03-17 00:00:00	ANCIEN	\N	Plouay	\N	\N	\N	\N	\N	CANTON	560	16685X	de	\N	2017-09-27 11:31:26	2017-09-27 11:33:21
52116	2015-04-15 00:00:00	\N	\N	ACTIF	\N	Antibes Juan-les-Pins	\N	\N	\N	\N	\N	DEPART	60	20138D	\N	\N	\N	\N
52118	2011-03-15 00:00:00	\N	\N	ACTIF	\N	N° 20	\N	\N	\N	\N	\N	CANTON	830	20078J	\N	\N	\N	\N
52120	2004-03-15 00:00:00	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	DEPART	830	20074E	\N	\N	\N	\N
52124	2015-03-15 00:00:00	\N	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	DEPART	710	20120S	\N	\N	\N	\N
52129	2017-10-15 00:00:00	\N	2020-10-26 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPART	280	20068G	\N	\N	\N	\N
52184	2015-03-15 00:00:00	2015-03-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	DEPART	700	20054A	\N	\N	\N	\N
52210	2001-03-15 00:00:00	2001-03-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	DEPART	800	20062A	\N	\N	\N	\N
52277	2015-03-15 00:00:00	\N	2020-12-31 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPART	670	20096L	\N	\N	\N	\N
52284	2011-03-15 00:00:00	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	DEPART	170	20064C	\N	\N	\N	\N
52418	2001-03-15 00:00:00	\N	2015-03-15 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	CANTON	860	20024T	\N	\N	\N	\N
52412	2021-06-20 00:00:00	\N	\N	ACTIF	\N	Vallée des Gaves	\N	\N	\N	\N	\N	DEPART	650	19629C	de la 	\N	\N	\N
53904	1399-12-24 00:50:39	1399-12-24 00:50:39	1404-12-23 00:50:39	ANCIEN	\N	\N	\N	\N	\N	\N	\N	CANTON	995	21032X	de 	\N	\N	\N
53508	1499-12-31 00:50:39	1499-12-31 00:50:39	1599-11-06 00:50:39	ANCIEN	\N	42	\N	\N	\N	\N	0	DEPART	420	21070E	de la	\N	\N	2023-09-26 16:03:59
53653	1599-01-09 00:50:39	1599-01-09 00:50:39	2024-03-04 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	0	DEPART	570	21081H	de la	\N	\N	2023-09-27 15:43:49
13873	\N	\N	2015-01-01 00:00:00	ANCIEN	\N	Bron	\N	\N	2001	\N	\N	CANTON	690	14081Q	de	\N	2014-09-17 18:12:01	2015-01-14 12:12:46
13877	1979-03-25 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Albi-Nord-Est	\N	\N	\N	\N	\N	CANTON	810	14085U	d'	\N	2014-09-18 10:08:08	2014-09-29 15:39:05
12936	2004-01-01 00:00:00	2004-01-01 00:00:00	2015-03-29 00:00:00	ANCIEN	\N	Elbeuf	\N	\N	\N	\N	\N	CANTON	760	14001X	d'	\N	2014-01-02 11:09:46	2014-09-29 10:23:30
13880	2011-03-21 00:00:00	2011-03-21 00:00:00	2014-10-01 00:00:00	ANCIEN	\N	Meyzieu	\N	\N	\N	\N	\N	CANTON	690	14087W	de	\N	2014-09-18 10:46:41	2014-11-19 16:50:35
51606	2015-03-29 00:00:00	\N	\N	ACTIF	\N	Ceton	\N	\N	\N	\N	\N	DEPART	610	19762G	de	\N	\N	\N
14000	1988-10-03 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Mazières-en-Gâtine	\N	\N	\N	\N	\N	CANTON	790	14119M	de	\N	2014-09-19 10:44:25	2015-01-19 14:19:39
13952	1992-03-29 00:00:00	\N	2014-12-27 00:00:00	ANCIEN	\N	Saint-Bonnet-en-Champsaur	\N	\N	\N	\N	\N	CANTON	50	14129P	de	\N	2014-09-18 12:25:11	2014-12-29 15:40:09
51043	2015-03-29 00:00:00	2015-03-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	Lille-3	\N	\N	\N	\N	\N	DEPART	590	19637C	de	\N	2017-09-22 15:35:39	2017-11-09 12:50:14
51067	\N	\N	2015-03-14 00:00:00	ANCIEN	\N	Châteaurenard	\N	\N	\N	\N	\N	CANTON	130	14115H	de	\N	2017-09-24 11:46:56	2017-09-24 11:48:14
14039	2011-03-31 00:00:00	2011-03-31 00:00:00	2015-03-29 00:00:00	ANCIEN	\N	Tallano-Scopamene	\N	\N	\N	\N	\N	CANTON	200	14191V	de	\N	2014-09-28 12:11:19	2014-09-28 12:13:02
14303	2008-03-16 00:00:00	2008-03-16 00:00:00	2013-07-01 00:00:00	ANCIEN	\N	Auch-Sud-Ouest	\N	\N	\N	\N	\N	CANTON	320	14257W	d'	\N	2014-09-28 19:28:14	2014-09-28 19:30:20
14321	\N	\N	\N	ANCIEN	\N	Saint-Martin 2	\N	\N	1998	2010	\N	CANTON	971	14261S	de	\N	2014-09-29 09:22:30	2014-09-29 09:23:29
50823	2014-06-23 00:00:00	2015-06-29 00:00:00	\N	ACTIF	\N	Noeux-les-Mines	\N	\N	\N	\N	\N	DEPART	620	19525U	de	\N	2017-09-19 16:32:29	2017-09-24 19:23:59
51373	2002-03-27 00:00:00	2002-03-27 00:00:00	2002-10-25 00:00:00	ANCIEN	\N	Vieux-Habitants	\N	\N	\N	\N	\N	CANTON	971	12016W	de	\N	2017-09-25 11:33:55	2017-09-25 11:37:10
51370	2004-03-28 00:00:00	\N	2010-03-27 00:00:00	ANCIEN	\N	Fort-de-France-VI	\N	\N	\N	\N	\N	CANTON	972	19295A	de	\N	2017-09-25 11:23:37	2017-09-25 11:25:30
51376	2008-03-16 00:00:00	2008-03-16 00:00:00	2020-03-31 00:00:00	ANCIEN	\N	Paris	\N	\N	\N	\N	\N	CANTON	615	19643A	de	\N	2017-09-25 11:55:33	2017-09-25 17:01:58
53432	1500-01-01 00:00:00	1500-01-01 00:00:00	\N	ACTIF	\N	PARIS 75015	\N	\N	1500	\N	0	CANTON	\N	21091K	de	\N	\N	2023-10-09 12:25:54
51379	2008-03-16 00:00:00	2008-03-16 00:00:00	2020-06-27 00:00:00	ANCIEN	\N	Paris	\N	\N	\N	\N	\N	CANTON	615	19651A	\N	\N	2017-09-25 12:09:48	2017-09-25 12:11:13
51380	2001-03-18 00:00:00	2001-03-18 00:00:00	2020-03-15 00:00:00	ANCIEN	\N	Paris	\N	\N	\N	\N	\N	CANTON	615	19649G	\N	\N	2017-09-25 15:49:16	2017-09-25 15:50:29
51400	2015-04-02 00:00:00	2015-04-02 00:00:00	2021-06-26 00:00:00	ANCIEN	\N	l'Isle-Adam	\N	\N	\N	\N	\N	DEPART	828	19667J	de	\N	2017-09-26 11:14:49	2017-11-08 15:47:59
51401	1998-03-22 00:00:00	1998-03-22 00:00:00	2015-04-01 00:00:00	ANCIEN	\N	Beaumont-sur-Oise	\N	\N	\N	\N	\N	CANTON	828	19667J	de	\N	2017-09-26 11:16:46	2017-09-26 11:19:46
51406	2008-03-16 00:00:00	2008-03-16 00:00:00	2015-12-13 00:00:00	ANCIEN	\N	Hénin-Carvin	\N	\N	\N	\N	\N	CANTON	620	19527W	d'	\N	2017-09-26 16:51:31	2017-09-26 16:55:12
51412	2004-03-28 00:00:00	\N	2015-03-28 00:00:00	ANCIEN	\N	Maringues	\N	\N	\N	\N	\N	CANTON	630	19387D	de	\N	2017-09-26 17:33:00	2017-09-26 17:34:06
51416	2008-03-16 00:00:00	\N	2015-03-28 00:00:00	ANCIEN	\N	Cherbourg Nord-Ouest	\N	\N	\N	\N	\N	CANTON	500	19333N	de	\N	2017-09-26 17:49:49	2017-09-26 17:50:45
51458	1985-03-17 00:00:00	1985-03-17 00:00:00	1998-03-21 00:00:00	ANCIEN	\N	Talence	\N	\N	\N	\N	\N	CANTON	330	19721W	de	\N	2017-10-01 09:47:47	2017-10-01 09:50:06
51471	2015-03-30 00:00:00	2015-03-30 00:00:00	2017-10-15 00:00:00	ANCIEN	\N	La Flèche	\N	\N	\N	\N	\N	DEPART	720	19727D	de	\N	2017-10-01 10:58:31	2018-04-18 15:14:26
51470	2012-06-21 00:00:00	2012-06-21 00:00:00	2015-03-29 00:00:00	ANCIEN	\N	La Flèche	\N	\N	\N	\N	\N	CANTON	720	19727D	de	\N	2017-10-01 10:56:32	2017-10-01 10:58:26
51474	1999-01-31 00:00:00	1999-01-31 00:00:00	2004-04-15 00:00:00	ANCIEN	\N	Mandelieu-la-Napoule	\N	\N	\N	\N	\N	CANTON	60	19729F	de	\N	2017-10-01 11:05:16	2017-10-01 11:06:57
51475	2015-03-29 00:00:00	2015-03-29 00:00:00	2017-11-01 00:00:00	ANCIEN	\N	Mandelieu-la-Napoule	\N	\N	\N	\N	\N	DEPART	60	19729F	de	\N	2017-10-01 11:07:01	2017-12-12 17:15:13
51479	2015-03-29 00:00:00	2015-03-29 00:00:00	\N	ACTIF	\N	Mauguio	\N	\N	\N	\N	\N	DEPART	340	08020N	de	\N	2017-10-01 11:35:30	2017-10-01 11:37:52
51482	2015-03-30 00:00:00	2015-03-30 00:00:00	\N	ACTIF	\N	Villeneuve-lès-Avignon	\N	\N	\N	\N	\N	DEPART	300	19733B	de	\N	2017-10-01 11:43:44	2017-10-01 11:44:42
51485	2011-03-27 00:00:00	2011-03-27 00:00:00	2014-12-15 00:00:00	ANCIEN	\N	Caen 1	\N	\N	\N	\N	\N	CANTON	140	19735D	de	\N	2017-10-01 11:50:17	2017-10-02 14:55:34
51528	2011-03-27 00:00:00	2011-03-27 00:00:00	2015-03-29 00:00:00	ANCIEN	\N	Senlis	\N	\N	\N	\N	\N	CANTON	600	19741B	de	\N	2017-11-24 22:03:36	2017-11-24 22:06:51
51529	2015-03-30 00:00:00	2015-03-30 00:00:00	\N	ACTIF	\N	Senlis	\N	\N	\N	\N	\N	DEPART	600	19741B	de	\N	2017-11-24 22:06:57	2017-11-24 22:10:10
51532	2014-06-25 00:00:00	2014-06-25 00:00:00	\N	ACTIF	\N	Tullins	\N	\N	\N	\N	\N	DEPART	380	11041F	de	\N	2017-12-01 09:50:43	2017-12-01 09:53:02
51534	1992-03-29 00:00:00	1992-03-29 00:00:00	2015-03-28 00:00:00	ANCIEN	\N	Montsauche-les-Settons	\N	\N	\N	\N	\N	CANTON	580	19531S	de	\N	2017-12-04 18:26:50	2017-12-04 18:41:49
51559	2001-03-18 00:00:00	2001-03-18 00:00:00	2015-03-29 00:00:00	ANCIEN	\N	Abymes-2	\N	\N	\N	\N	\N	CANTON	971	19301E	des	\N	2018-01-02 10:47:12	2018-01-02 10:50:07
52156	2005-06-15 00:00:00	\N	2012-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	DEPART	220	18193Q	des	\N	\N	\N
51724	1993-12-01 00:00:00	1993-12-01 00:00:00	2015-04-01 00:00:00	ANCIEN	\N	Clères	\N	\N	\N	\N	\N	CANTON	760	19826F	de	\N	\N	\N
52109	2008-03-15 00:00:00	\N	\N	ACTIF	\N	Cavaillon	\N	\N	\N	\N	\N	DEPART	840	20086J	\N	\N	\N	\N
52383	2021-07-06 00:00:00	2021-06-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	DEPART	430	14267Y	\N	\N	\N	\N
52409	2015-04-15 00:00:00	2015-04-15 00:00:00	2021-06-20 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPART	130	20248J	\N	\N	\N	\N
52415	2021-07-01 00:00:00	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	DEPART	490	19545Y	\N	\N	\N	\N
53122	2004-03-15 00:00:00	2004-03-15 00:00:00	2016-01-15 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPART	824	20914V	du 	\N	\N	\N
53433	1500-01-01 00:00:00	1500-01-01 00:00:00	1600-01-01 00:00:00	ANCIEN	\N	PARIS 75015	\N	\N	1500	1600	0	CANTON	\N	21091K	de	\N	\N	2023-10-09 12:25:54
53477	1500-01-01 00:00:00	1499-12-31 00:50:39	1600-01-01 00:00:00	ANCIEN	\N	59	\N	\N	1500	1600	0	CANTON	590	15197G	du	\N	\N	2023-09-26 15:52:27
53752	1499-12-31 00:50:39	1499-12-31 00:50:39	\N	ACTIF	\N	51	\N	\N	\N	\N	0	DEPART	510	21063F	de la	\N	\N	2023-09-28 17:13:36
50858	1998-03-22 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Montrichard	\N	\N	\N	\N	\N	CANTON	410	19511N	de	\N	2017-09-19 17:54:00	2017-09-26 18:00:39
13825	2011-03-01 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Chéroy	\N	\N	\N	\N	\N	CANTON	890	14037X	de	\N	2014-09-17 11:36:29	2014-09-29 17:18:14
14340	1998-04-02 00:00:00	1998-04-02 00:00:00	2015-03-06 00:00:00	ANCIEN	\N	Tournefeuille	\N	\N	\N	\N	\N	CANTON	310	14225N	de	\N	2014-09-29 15:21:37	2015-03-10 16:41:01
13850	\N	\N	2015-03-29 00:00:00	ANCIEN	\N	Villers-Bocage	\N	\N	2008	\N	\N	CANTON	800	14063N	de	\N	2014-09-17 17:28:25	2014-09-17 17:30:22
50860	2015-03-30 00:00:00	\N	2021-06-15 00:00:00	ANCIEN	\N	Montrichard	\N	\N	\N	\N	\N	DEPART	410	19511N	de	\N	2017-09-19 17:56:00	2017-09-24 20:31:47
50883	2008-03-16 00:00:00	2008-03-16 00:00:00	2015-03-28 00:00:00	ANCIEN	\N	Olivet	\N	\N	\N	\N	\N	CANTON	450	19421M	d'	\N	2017-09-20 10:54:10	2017-09-24 18:07:11
50884	2015-03-29 00:00:00	2015-03-29 00:00:00	\N	ACTIF	\N	Olivet	\N	\N	\N	\N	\N	DEPART	450	19421M	d'	\N	2017-09-20 10:54:12	2017-12-04 18:39:46
14011	1976-03-15 00:00:00	\N	2001-03-18 00:00:00	ANCIEN	\N	Ballon	\N	\N	\N	\N	\N	CANTON	720	14167V	de	\N	2014-09-22 10:56:56	2014-09-22 10:57:35
14014	\N	\N	2014-10-01 00:00:00	ANCIEN	\N	Le Lude	\N	\N	2011	\N	\N	CANTON	720	14169X	de	\N	2014-09-22 11:05:59	2014-10-24 11:13:27
14018	2008-04-01 00:00:00	2008-04-01 00:00:00	2015-03-29 00:00:00	ANCIEN	\N	Bonnétable	\N	\N	\N	\N	\N	CANTON	720	14173T	de	\N	2014-09-22 11:18:47	2014-09-30 15:42:30
14020	1982-03-31 00:00:00	1991-03-31 00:00:00	2015-03-29 00:00:00	ANCIEN	\N	Chambéry-Est	\N	\N	\N	\N	\N	CANTON	730	14175V	de	\N	2014-09-22 14:35:11	2014-09-29 13:56:32
14057	\N	2011-01-01 00:00:00	2015-03-29 00:00:00	ANCIEN	\N	Tarascon-sur-Ariège	\N	\N	2011	\N	\N	CANTON	90	14197C	de	\N	2014-09-28 12:58:45	2014-09-28 12:59:16
14124	2003-07-06 00:00:00	2003-07-06 00:00:00	2015-01-01 00:00:00	ANCIEN	\N	Servian	\N	\N	\N	\N	\N	CANTON	340	14207L	de 	\N	2014-09-28 17:08:33	2015-01-14 10:35:02
14074	\N	2001-03-12 00:00:00	2015-03-29 00:00:00	ANCIEN	\N	Beaucourt	\N	\N	2001	\N	\N	CANTON	125	14193X	de	\N	2014-09-28 15:30:18	2014-09-30 10:45:41
14143	2008-04-01 00:00:00	2008-04-01 00:00:00	2014-10-01 00:00:00	ANCIEN	\N	Sète-I	\N	\N	\N	\N	\N	CANTON	340	14209N	de 	\N	2014-09-28 17:18:16	2014-11-18 10:11:11
14249	2011-03-01 00:00:00	2011-03-01 00:00:00	2015-03-29 00:00:00	ANCIEN	\N	Nice 14 ème	\N	\N	\N	\N	\N	CANTON	60	14187A	\N	\N	2014-09-28 18:18:34	2014-10-08 14:41:59
15143	2015-03-30 00:00:00	2015-03-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	Albi-4	\N	\N	\N	\N	\N	DEPART	810	14085U	d'	\N	2015-03-31 14:54:17	2017-09-27 14:38:48
15244	2004-03-21 00:00:00	2004-03-21 00:00:00	2015-03-28 00:00:00	ANCIEN	\N	Rebais	\N	\N	\N	\N	\N	CANTON	770	14329V	\N	\N	2015-10-12 12:16:34	2015-10-12 12:18:14
15534	2015-04-02 00:00:00	\N	\N	ACTIF	\N	Neste-Aure-Louron	\N	\N	\N	\N	\N	DEPART	650	14365A	de	\N	2017-05-17 11:39:41	2017-05-17 11:45:08
50916	2015-03-29 00:00:00	\N	2017-10-16 00:00:00	ANCIEN	\N	Cère-et-Ségala	\N	\N	\N	\N	\N	DEPART	460	19503N	\N	\N	2017-09-20 12:13:56	2017-09-20 12:14:17
51314	2008-03-16 00:00:00	\N	2015-03-28 00:00:00	ANCIEN	\N	Néronde	\N	\N	\N	\N	\N	CANTON	420	19413M	de	\N	2017-09-24 19:42:53	2017-09-24 19:44:04
51331	2004-03-28 00:00:00	\N	2015-03-28 00:00:00	ANCIEN	\N	Hagetmau	\N	\N	\N	\N	\N	CANTON	400	17779H	de	\N	2017-09-24 20:06:06	2017-09-24 20:07:15
51332	2015-03-29 00:00:00	2015-03-29 00:00:00	\N	ACTIF	\N	Chalosse Tursan	\N	\N	\N	\N	\N	DEPART	400	17779H	de	\N	2017-09-24 20:07:41	2017-12-22 16:30:45
51337	1992-03-29 00:00:00	2008-03-16 00:00:00	2015-03-28 00:00:00	ANCIEN	\N	Plessis-Robinson	\N	\N	\N	\N	\N	CANTON	335	17637T	du	\N	2017-09-24 20:25:09	2017-10-05 14:57:55
51450	1992-03-29 00:00:00	1992-03-29 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	Sainte-Marie	\N	\N	\N	\N	\N	CANTON	974	19583F	de	\N	2017-09-28 11:18:01	2017-09-28 11:31:51
51353	2015-03-29 00:00:00	2015-03-29 00:00:00	2021-06-30 00:00:00	ANCIEN	\N	Lille-5	\N	\N	\N	\N	\N	DEPART	590	14021P	de	\N	2017-09-24 20:54:10	2017-09-24 20:54:45
51354	2008-03-16 00:00:00	2008-03-16 00:00:00	2015-03-29 00:00:00	ANCIEN	\N	Tourcoing-Sud	\N	\N	\N	\N	\N	CANTON	590	19581D	de	\N	2017-09-24 20:56:26	2017-09-24 20:57:42
51355	2001-03-18 00:00:00	2001-03-18 00:00:00	2015-03-29 00:00:00	ANCIEN	\N	Lille-Ouest	\N	\N	\N	\N	\N	CANTON	590	19569H	de	\N	2017-09-24 21:05:04	2017-09-24 21:06:12
51510	2012-06-21 00:00:00	2012-06-21 00:00:00	2015-03-28 00:00:00	ANCIEN	\N	Aurillac 1	d'Aurillac 1	\N	\N	\N	\N	CANTON	150	19253P	d'	\N	2017-11-09 13:08:06	2017-11-09 13:12:07
51511	2015-03-29 00:00:00	2015-03-29 00:00:00	\N	ACTIF	\N	Aurillac 3	d'Aurillac 3	\N	\N	\N	\N	DEPART	150	19253P	d'	\N	2017-11-09 13:12:12	2017-11-09 13:14:08
52030	2001-03-15 00:00:00	2015-03-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	DEPART	160	20042V	\N	\N	\N	\N
52048	1992-03-15 00:00:00	1992-03-15 00:00:00	1998-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	DEPART	320	20040T	\N	\N	\N	\N
52052	2015-03-15 00:00:00	2015-03-15 00:00:00	2020-10-15 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	DEPART	70	20026V	\N	\N	\N	\N
52068	2001-10-02 00:00:00	\N	2015-03-15 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPART	60	20136B	\N	\N	\N	\N
52075	1991-03-15 00:00:00	\N	2015-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	DEPART	30	20020P	\N	\N	\N	\N
52174	2004-03-15 00:00:00	2004-03-15 00:00:00	\N	ACTIF	\N	Uzès	\N	\N	\N	\N	\N	DEPART	300	20088L	du	\N	\N	\N
52182	2001-03-15 00:00:00	2001-03-15 00:00:00	2021-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	DEPART	220	20104S	des	\N	\N	\N
52199	1998-03-15 00:00:00	1998-03-15 00:00:00	2014-08-15 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPART	130	12028B	des	\N	\N	\N
52257	2011-03-15 00:00:00	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	DEPART	240	20028X	\N	\N	\N	\N
52273	2015-04-15 00:00:00	2015-03-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	DEPART	20	20122U	de l'	\N	\N	\N
52307	\N	\N	\N	ANCIEN	\N	Vabre	\N	\N	1994	2008	\N	CANTON	810	17023S	de	\N	\N	\N
52311	\N	\N	\N	ACTIF	\N	\N	\N	\N	2015	\N	\N	DEPART	180	19798U	du	\N	\N	\N
52405	2021-06-27 00:00:00	\N	\N	ACTIF	\N	Torcy	\N	\N	\N	\N	\N	DEPART	\N	19675J	\N	\N	\N	\N
52406	2021-06-27 00:00:00	\N	\N	ACTIF	\N	Valenciennes	\N	\N	\N	\N	\N	DEPART	590	01043Q	de	\N	\N	\N
52437	2015-04-01 00:00:00	2015-04-01 00:00:00	2016-01-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPART	775	20252E	\N	\N	\N	\N
53177	2021-06-01 00:00:00	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	DEPART	\N	19671E	\N	\N	\N	\N
53641	1600-01-09 00:50:39	1600-01-09 00:50:39	1699-11-06 00:50:39	ANCIEN	\N	47	\N	\N	\N	\N	0	CANTON	470	21040X	du	\N	\N	2023-09-27 11:45:45
53643	1500-01-01 00:00:00	1500-01-01 00:00:00	1600-01-01 00:00:00	ANCIEN	\N	47	\N	\N	1500	1600	0	CANTON	470	21040X	du	\N	\N	2023-09-27 11:45:45
53891	2023-10-06 00:00:00	\N	2023-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	DEPART	450	21057H	du 	\N	\N	\N
53950	2024-03-04 00:00:00	2024-03-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	DEPART	570	21081H	de la	\N	\N	\N
13895	\N	\N	\N	ANCIEN	\N	Albi Sud	\N	\N	1985	1995	\N	CANTON	810	14089Y	d'	\N	2014-09-18 11:13:41	2014-09-18 11:14:16
13896	\N	\N	\N	ANCIEN	\N	Albi Est	\N	\N	1998	2008	\N	CANTON	810	14089Y	d'	\N	2014-09-18 11:15:41	2014-09-18 11:16:09
13910	\N	\N	2015-03-29 00:00:00	ANCIEN	\N	Oisemont	\N	\N	1980	\N	\N	CANTON	800	14093U	d'	\N	2014-09-18 11:42:48	2014-09-18 11:59:40
13924	\N	\N	2015-03-29 00:00:00	ANCIEN	\N	Saint-Geniez-d'Olt	\N	\N	1994	\N	\N	CANTON	120	14103D	de	\N	2014-09-18 11:55:09	2014-09-18 11:55:56
13934	\N	\N	2015-03-29 00:00:00	ANCIEN	\N	Saint-Rome-de-Tarn	\N	\N	1994	\N	\N	CANTON	120	14111D	de	\N	2014-09-18 12:01:26	2014-09-18 12:01:58
13958	\N	\N	\N	ANCIEN	\N	Condé-sur-Noireau	\N	\N	2011	2014	\N	CANTON	140	14133K	de	\N	2014-09-18 14:42:02	2014-11-27 17:54:32
13965	\N	\N	2015-01-01 00:00:00	ANCIEN	\N	Mézidon-Canon	\N	\N	2001	\N	\N	CANTON	140	14137P	de	\N	2014-09-18 14:47:11	2015-01-14 21:33:35
50814	2016-03-01 00:00:00	2015-03-29 00:00:00	2021-06-26 00:00:00	ANCIEN	\N	Loches	\N	\N	\N	\N	\N	DEPART	370	19441R	de	\N	2017-09-19 16:05:10	2018-03-28 18:07:45
50819	2001-03-19 00:00:00	2001-03-18 00:00:00	2008-04-01 00:00:00	ANCIEN	\N	Tours-Centre-1	\N	\N	\N	\N	\N	CANTON	370	19515S	de	\N	2017-09-19 16:18:59	2017-09-24 17:46:56
14053	1980-04-01 00:00:00	1980-04-01 00:00:00	2015-01-01 00:00:00	ANCIEN	\N	Treignac	\N	\N	\N	\N	\N	CANTON	190	14195A	de	\N	2014-09-28 12:55:04	2015-01-13 12:04:23
14077	1982-03-01 00:00:00	1982-03-01 00:00:00	2015-03-29 00:00:00	ANCIEN	\N	Vescovato	\N	\N	\N	\N	\N	CANTON	205	14201E	de	\N	2014-09-28 15:44:18	2014-09-30 16:24:27
14080	1988-04-01 00:00:00	1988-04-01 00:00:00	2015-03-29 00:00:00	ANCIEN	\N	Coucouron	\N	\N	\N	\N	\N	CANTON	70	14199E	\N	\N	2014-09-28 15:54:58	2014-09-28 15:56:47
14243	2011-03-14 00:00:00	2011-03-14 00:00:00	2015-01-01 00:00:00	ANCIEN	\N	Pennes-Mirabeau	\N	\N	\N	\N	\N	CANTON	130	14239U	des	\N	2014-09-28 18:06:10	2015-01-13 12:06:02
14333	1998-03-15 00:00:00	2013-01-01 00:00:00	2014-10-01 00:00:00	ANCIEN	\N	Montendre	\N	\N	\N	\N	\N	CANTON	170	14159V	de	\N	2014-09-29 11:28:51	2014-10-23 12:11:18
14343	\N	\N	2014-10-01 00:00:00	ANCIEN	\N	Tain-l'Hermitage	\N	\N	2011	\N	\N	CANTON	260	14105F	de	\N	2014-09-30 09:50:25	2014-10-22 17:21:11
14354	1998-03-01 00:00:00	\N	2004-03-01 00:00:00	ANCIEN	\N	Boulogne-sur-Gesse	\N	\N	\N	\N	\N	CANTON	310	14221J	de	\N	2014-09-30 11:53:27	2014-09-30 11:55:18
15137	2004-03-28 00:00:00	2004-03-28 00:00:00	2011-03-20 00:00:00	ANCIEN	\N	Aubervilliers-Est	\N	\N	\N	\N	\N	CANTON	775	14269B	d'	\N	2015-03-04 14:36:24	2015-03-04 14:39:23
15154	2015-03-30 00:00:00	2015-03-29 00:00:00	2021-06-27 00:00:00	ANCIEN	\N	Dormans-Paysages de Champagne	\N	\N	\N	\N	\N	DEPART	510	01025N	de	\N	2015-03-31 15:07:21	2017-11-13 09:23:31
15159	2015-03-30 00:00:00	2015-03-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	Sézanne-Brie et Champagne	\N	\N	\N	\N	\N	DEPART	510	11097X	de	\N	2015-03-31 15:11:13	2017-11-14 11:56:53
15164	2015-03-30 00:00:00	2015-03-29 00:00:00	2020-12-07 00:00:00	ANCIEN	\N	Poissons	\N	\N	\N	\N	\N	DEPART	520	01058X	de 	\N	2015-03-31 15:13:03	2015-03-31 15:13:35
15168	2015-03-30 00:00:00	2015-03-29 00:00:00	\N	ACTIF	\N	Cossé-le-Vivien	\N	\N	\N	\N	\N	DEPART	530	14042U	de	\N	2015-03-31 15:15:46	2015-04-15 17:41:43
15169	2015-03-30 00:00:00	2015-03-29 00:00:00	2021-06-15 00:00:00	ANCIEN	\N	Le Pays Messin	\N	\N	\N	\N	\N	DEPART	570	01060R	de	\N	2015-03-31 15:17:26	2015-03-31 15:17:53
15170	2015-03-30 00:00:00	2015-03-29 00:00:00	\N	ACTIF	\N	Lille-2	\N	\N	\N	\N	\N	DEPART	590	01042P	de	\N	2015-03-31 15:19:05	2015-03-31 15:19:28
15171	2015-03-30 00:00:00	2015-03-29 00:00:00	\N	ACTIF	\N	Lumbres	\N	\N	\N	\N	\N	DEPART	620	11059R	de	\N	2015-03-31 15:20:38	2015-03-31 15:21:07
15182	2015-03-30 00:00:00	2015-03-29 00:00:00	\N	ACTIF	\N	Boixe-et-Manslois	\N	\N	\N	\N	\N	DEPART	160	08060W	de	\N	2015-03-31 17:09:47	2015-03-31 17:10:38
15183	2015-03-30 00:00:00	2015-03-29 00:00:00	\N	ACTIF	\N	Val de Tardoire	\N	\N	\N	\N	\N	DEPART	160	08058D	du	\N	2015-03-31 17:11:11	2015-03-31 17:11:54
15184	2015-03-30 00:00:00	2015-03-29 00:00:00	\N	ACTIF	\N	Matha	\N	\N	\N	\N	\N	DEPART	170	14213J	de	\N	2015-03-31 17:12:06	2017-11-13 18:55:49
50825	2015-03-30 00:00:00	2015-03-29 00:00:00	2021-07-01 00:00:00	ANCIEN	\N	Champagnole	\N	\N	\N	\N	\N	DEPART	390	19479G	de	\N	2017-09-19 16:35:25	2018-03-29 00:01:33
50843	2015-12-13 00:00:00	2015-12-13 00:00:00	\N	ACTIF	\N	Arbois	\N	\N	\N	\N	\N	DEPART	390	19467C	d'	\N	2017-09-19 17:20:53	2017-12-04 21:45:32
51131	1998-03-22 00:00:00	1998-03-22 00:00:00	2015-03-29 00:00:00	ANCIEN	\N	Biarritz-Ouest	\N	\N	\N	\N	\N	CANTON	640	19621T	de	\N	2017-09-24 17:23:40	2017-09-24 17:29:16
51493	2001-03-18 00:00:00	2001-03-18 00:00:00	2008-03-16 00:00:00	ANCIEN	\N	Dardilly	\N	\N	\N	\N	\N	CANTON	690	19737F	de	\N	2017-10-02 11:15:19	2017-10-02 11:20:17
51246	2004-03-28 00:00:00	2004-03-28 00:00:00	2015-03-29 00:00:00	ANCIEN	\N	Thiaucourt-Regniéville	\N	\N	\N	\N	\N	CANTON	540	19551W	de	\N	2017-09-24 18:28:11	2017-09-24 18:36:06
51253	2015-03-29 00:00:00	2015-03-29 00:00:00	\N	ACTIF	\N	Beauvais-2	\N	\N	\N	\N	\N	DEPART	600	19677L	de	\N	2017-09-24 18:39:55	2017-09-24 18:42:14
51297	2002-06-09 00:00:00	2002-06-09 00:00:00	2014-06-22 00:00:00	ANCIEN	\N	Barlin	\N	\N	\N	\N	\N	CANTON	620	19525U	de	\N	2017-09-24 19:20:04	2017-09-26 17:35:07
51323	2001-03-11 00:00:00	2001-03-11 00:00:00	2015-03-28 00:00:00	ANCIEN	\N	Courrières	\N	\N	\N	\N	\N	CANTON	620	19681G	de	\N	2017-09-24 19:57:24	2017-09-24 19:59:06
51994	2015-03-15 00:00:00	2015-03-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	DEPART	120	20032T	de l'	\N	\N	\N
51780	2015-04-01 00:00:00	\N	2020-09-02 00:00:00	ANCIEN	\N	La Ciotat	\N	\N	\N	\N	\N	DEPART	130	19966S	\N	\N	\N	\N
51998	2004-03-15 00:00:00	\N	2008-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	DEPART	120	20032T	de l'	\N	\N	\N
51999	2004-03-15 00:00:00	2004-03-15 00:00:00	2021-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	DEPART	870	20080C	de la	\N	\N	\N
52010	2015-03-15 00:00:00	2015-03-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	DEPART	240	20046A	de la	\N	\N	\N
52016	2011-03-15 00:00:00	2015-03-15 00:00:00	2021-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	DEPART	300	20090E	du	\N	\N	\N
52084	2015-04-15 00:00:00	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	DEPART	270	19265T	\N	\N	\N	\N
52087	2015-03-15 00:00:00	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	DEPART	860	20024T	\N	\N	\N	\N
52090	2015-03-15 00:00:00	\N	\N	ACTIF	\N	 	\N	\N	\N	\N	\N	DEPART	360	20022R	\N	\N	\N	\N
52219	2011-03-15 00:00:00	\N	2015-03-15 00:00:00	ANCIEN	\N	Tuchan	\N	\N	\N	\N	\N	DEPART	110	20030R	de	\N	\N	\N
52225	2001-03-15 00:00:00	2015-03-15 00:00:00	2020-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	DEPART	760	20144B	\N	\N	\N	\N
52233	2015-03-15 00:00:00	2015-03-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	DEPART	680	20124W	\N	\N	\N	\N
52234	1994-05-15 00:00:00	2015-04-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	DEPART	790	20038A	\N	\N	\N	\N
52237	2015-03-15 00:00:00	2015-03-15 00:00:00	2021-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	DEPART	810	17023S	du	\N	\N	\N
52331	2015-03-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	DEPART	890	20174H	\N	\N	\N	\N
53559	1499-12-31 00:50:39	1499-12-31 00:50:39	2023-11-01 00:00:00	ANCIEN	\N	77	\N	\N	\N	\N	0	DEPART	770	21075K	de la	\N	\N	2023-09-26 16:32:10
53549	1499-12-31 00:50:39	1499-12-31 00:50:39	1599-11-06 00:50:39	ANCIEN	\N	37	\N	\N	\N	\N	0	DEPART	370	21055F	de l'	\N	\N	2023-09-26 16:31:05
53946	1500-01-01 00:00:00	1500-01-01 00:00:00	\N	ACTIF	\N	86	\N	\N	1500	\N	0	CANTON	860	21125C	de la	\N	\N	2024-03-26 16:47:52
53577	1500-01-01 00:00:00	1500-01-01 00:00:00	1600-01-01 00:00:00	ANCIEN	\N	62	\N	\N	1500	1600	0	CANTON	620	21069M	du	\N	\N	2023-09-26 17:13:49
53620	1499-12-31 00:50:39	1499-12-31 00:50:39	1515-10-27 00:50:39	ANCIEN	\N	38	\N	\N	\N	\N	0	CANTON	380	21080G	de l'	\N	\N	2023-09-27 11:25:46
53885	2023-11-02 00:00:00	\N	\N	ACTIF	\N	52	\N	\N	\N	\N	\N	DEPART	520	21039F	de la	\N	\N	\N
53660	1499-12-31 00:50:39	1499-12-31 00:50:39	\N	ACTIF	\N	39	\N	\N	\N	\N	0	DEPART	390	21047F	du	\N	\N	2023-09-27 15:47:41
13847	2008-03-21 00:00:00	2008-04-01 00:00:00	2015-04-02 00:00:00	ANCIEN	\N	Woerth	\N	\N	\N	\N	\N	CANTON	670	14061L	de	\N	2014-09-17 17:23:08	2014-09-29 16:10:55
15157	2015-03-30 00:00:00	2015-03-29 00:00:00	\N	ACTIF	\N	Perpignan-6	\N	\N	\N	\N	\N	DEPART	660	14018U	de	\N	2015-03-31 15:09:49	2015-04-03 10:37:22
15155	2015-03-30 00:00:00	2015-03-29 00:00:00	\N	ACTIF	\N	Pays de Bidache, Amikuze et Ostibarre	\N	\N	\N	\N	\N	DEPART	640	11111C	du	\N	2015-03-31 15:07:52	2015-04-03 10:35:07
15160	2015-03-30 00:00:00	2015-03-29 00:00:00	\N	ACTIF	\N	Chambéry-2	\N	\N	\N	\N	\N	DEPART	730	14175V	de	\N	2015-03-31 15:11:23	2015-04-15 17:43:09
15163	2015-03-30 00:00:00	2015-03-29 00:00:00	\N	ACTIF	\N	Elbeuf	\N	\N	\N	\N	\N	DEPART	760	14001X	de	\N	2015-03-31 15:12:53	2015-03-31 15:17:51
15167	2015-03-30 00:00:00	2015-03-29 00:00:00	\N	ACTIF	\N	Champs-sur-marne	\N	\N	\N	\N	\N	DEPART	770	11074Q	de	\N	2015-03-31 15:13:56	2015-03-31 15:15:28
15174	2015-03-30 00:00:00	2015-03-29 00:00:00	2017-12-31 00:00:00	ANCIEN	\N	Bavella	\N	\N	\N	\N	\N	DEPART	200	14191V	de	\N	2015-03-31 16:55:02	2015-04-15 17:38:30
15175	2015-03-30 00:00:00	2015-03-29 00:00:00	\N	ACTIF	\N	Bourganeuf	\N	\N	\N	\N	\N	DEPART	230	08012N	de	\N	2015-03-31 16:58:16	2015-03-31 16:59:38
15176	2015-03-30 00:00:00	2015-03-29 00:00:00	2021-06-26 00:00:00	ANCIEN	\N	Guéret-2	\N	\N	\N	\N	\N	DEPART	230	14121F	de	\N	2015-03-31 17:01:37	2015-03-31 17:02:42
15178	2015-03-30 00:00:00	2015-03-29 00:00:00	2021-06-15 00:00:00	ANCIEN	\N	Voves	\N	\N	\N	\N	\N	DEPART	280	08011M	de	\N	2015-03-31 17:04:14	2015-04-03 11:09:39
15180	2015-03-30 00:00:00	2015-03-29 00:00:00	2016-11-17 00:00:00	ANCIEN	\N	Neuvy-Saint-Sépulchre	\N	\N	\N	\N	\N	DEPART	360	07032N	de	\N	2015-03-31 17:07:12	2016-11-18 12:37:49
15181	2015-03-30 00:00:00	2015-03-29 00:00:00	\N	ACTIF	\N	Les Coteaux de Guyenne	\N	\N	\N	\N	\N	DEPART	470	11095V	des	\N	2015-03-31 17:09:39	2015-03-31 17:12:24
15185	2015-12-06 00:00:00	2015-03-29 00:00:00	\N	ACTIF	\N	Villedieu-Les-Poêles	\N	\N	\N	\N	\N	DEPART	500	05008E	de	\N	2015-03-31 17:14:18	2016-02-16 09:52:42
15186	2015-03-30 00:00:00	2015-03-29 00:00:00	\N	ACTIF	\N	Bayeux	\N	\N	\N	\N	\N	DEPART	140	98042T	de 	\N	2015-03-31 17:46:01	2015-04-03 11:29:48
15237	2015-03-22 00:00:00	2015-03-22 00:00:00	2021-06-26 00:00:00	ANCIEN	\N	Murat	\N	\N	\N	\N	\N	DEPART	150	14327T	\N	\N	2015-09-07 16:26:28	2018-01-08 20:09:40
15236	1998-03-15 00:00:00	\N	2015-03-21 00:00:00	ANCIEN	\N	Murat	\N	\N	\N	\N	\N	CANTON	150	14327T	\N	\N	2015-09-07 16:19:52	2015-09-07 16:42:40
15241	2015-09-28 00:00:00	2015-09-28 00:00:00	2018-05-28 00:00:00	ANCIEN	\N	Corbeil-Essonnes	\N	\N	\N	\N	\N	DEPART	265	04055H	de	\N	2015-10-06 11:07:21	2018-05-30 15:10:56
15519	2008-03-16 00:00:00	2008-03-16 00:00:00	2014-03-16 00:00:00	ANCIEN	\N	Boulogne-Billancourt	\N	\N	\N	\N	\N	CANTON	335	14363X	de	\N	2017-01-10 16:35:29	2017-01-10 16:46:32
50922	2015-03-29 00:00:00	2015-03-29 00:00:00	\N	ACTIF	\N	Hennebont	\N	\N	\N	\N	\N	DEPART	560	19447X	d'	\N	2017-09-20 14:34:26	2017-11-28 14:47:06
50938	2015-03-29 00:00:00	2015-03-29 00:00:00	\N	ACTIF	\N	Orcines	\N	\N	\N	\N	\N	DEPART	630	19383Y	d'	\N	2017-09-20 15:47:34	2017-09-24 19:44:56
50979	2015-03-29 00:00:00	2015-03-30 00:00:00	2021-06-27 00:00:00	ANCIEN	\N	Lille-1	\N	\N	\N	\N	\N	DEPART	590	19569H	de	\N	2017-09-21 17:47:03	2017-12-20 19:07:04
50992	2015-04-02 00:00:00	2015-03-29 00:00:00	\N	ACTIF	\N	Mouy	\N	\N	\N	\N	\N	DEPART	600	19573D	de	\N	2017-09-21 18:31:09	2017-11-16 14:58:09
50994	2015-03-29 00:00:00	2015-03-29 00:00:00	\N	ACTIF	\N	Albertville 1	\N	\N	\N	\N	\N	DEPART	730	19575F	d'	\N	2017-09-21 18:46:54	2017-09-21 18:48:06
50996	2015-03-18 00:00:00	2015-03-18 00:00:00	\N	ACTIF	\N	Saint-Denis-2	\N	\N	\N	\N	\N	DEPART	974	19577H	de	\N	2017-09-22 10:05:21	2018-01-08 16:14:56
51014	1998-03-22 00:00:00	1998-03-22 00:00:00	2004-03-28 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	CANTON	830	15447F	\N	\N	2017-09-22 11:05:23	2017-09-22 11:06:15
51017	2015-03-29 00:00:00	\N	\N	ACTIF	\N	Bagneux	\N	\N	\N	\N	\N	DEPART	335	19593H	de	\N	2017-09-22 11:18:09	2017-09-27 11:09:01
51035	1994-03-27 00:00:00	1994-03-27 00:00:00	2015-03-29 00:00:00	ANCIEN	\N	Sauveterre-de-Béarn	\N	\N	\N	\N	\N	CANTON	640	19619A	de	\N	2017-09-22 13:56:26	2017-09-24 17:44:24
51040	2015-03-29 00:00:00	2015-03-30 00:00:00	\N	ACTIF	\N	Biarritz	\N	\N	\N	\N	\N	DEPART	640	19621T	de	\N	2017-09-22 14:05:02	2017-11-17 11:07:18
51315	2015-03-29 00:00:00	2015-03-29 00:00:00	\N	ACTIF	\N	Sarrebourg	\N	\N	\N	\N	\N	DEPART	570	19685L	de	\N	2017-09-24 19:44:00	2017-09-27 11:53:55
51328	2015-03-29 00:00:00	2015-03-29 00:00:00	\N	ACTIF	\N	Perpignan 2	\N	\N	\N	\N	\N	DEPART	660	19703U	de	\N	2017-09-24 20:02:49	2017-10-02 16:13:29
51382	2001-03-27 00:00:00	2001-03-27 00:00:00	2015-12-12 00:00:00	ANCIEN	\N	Tonneins	\N	\N	\N	\N	\N	CANTON	470	19369B	de	\N	2017-09-25 16:48:00	2017-09-25 16:50:39
51525	2015-04-02 00:00:00	2015-04-02 00:00:00	\N	ACTIF	\N	Saint-Quentin-2	\N	\N	\N	\N	\N	DEPART	20	14026U	de	\N	2017-11-22 19:46:35	2017-11-22 19:48:23
51618	2011-03-27 00:00:00	2011-03-27 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	Villeurbanne	\N	\N	\N	\N	\N	DEPART	690	19251M	de	\N	\N	\N
53472	1499-12-31 00:50:39	1499-12-31 00:50:39	\N	ACTIF	\N	54	\N	\N	\N	\N	0	DEPART	540	21049H	de la	\N	\N	2023-09-26 15:47:16
51668	2015-03-29 00:00:00	2015-03-29 00:00:00	\N	ACTIF	\N	Diois	\N	\N	\N	\N	\N	DEPART	260	19782L	du	\N	\N	\N
51666	2004-03-28 00:00:00	2004-03-28 00:00:00	2015-03-28 00:00:00	ANCIEN	\N	Luc-en-Diois	\N	\N	\N	\N	\N	CANTON	260	19782L	de	\N	\N	\N
51712	2015-04-02 00:00:00	2015-03-31 00:00:00	\N	ACTIF	\N	Bois-Guillaume	\N	\N	\N	\N	\N	DEPART	760	19826F	de	\N	\N	\N
51693	2008-03-16 00:00:00	2008-03-16 00:00:00	\N	ACTIF	\N	Landes de Graves	\N	\N	\N	\N	\N	DEPART	330	19820Y	Les	\N	\N	\N
52078	1998-03-15 00:00:00	\N	2015-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	DEPART	50	14189C	des	\N	\N	\N
52082	2004-03-15 00:00:00	\N	2011-03-15 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPART	830	20076G	\N	\N	\N	\N
52140	2008-03-15 00:00:00	\N	2015-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	DEPART	830	20072C	\N	\N	\N	\N
52145	2001-03-15 00:00:00	2015-03-15 00:00:00	\N	ACTIF	\N	Saint Vit	\N	\N	\N	\N	\N	DEPART	250	20066E	du	\N	\N	\N
52151	2015-03-15 00:00:00	2015-03-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	DEPART	80	20056C	des	\N	\N	\N
52286	1994-06-15 00:00:00	\N	2021-06-26 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPART	690	20132W	\N	\N	\N	\N
52292	2011-03-15 00:00:00	\N	2014-12-15 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPART	690	20130U	\N	\N	\N	\N
53468	2000-01-09 00:00:00	1499-12-31 00:50:39	2023-11-06 00:00:00	ANCIEN	\N	46	\N	\N	\N	\N	0	DEPART	460	21041Y	du	\N	\N	2023-10-09 08:47:39
53481	1500-01-01 00:00:00	1500-01-01 00:00:00	\N	ACTIF	\N	91	\N	\N	1500	\N	0	CANTON	265	21059K	de l'	\N	\N	2023-09-26 15:53:35
53483	1500-01-01 00:00:00	1500-01-01 00:00:00	1600-01-01 00:00:00	ANCIEN	\N	91	\N	\N	1500	1600	0	CANTON	265	21059K	de l'	\N	\N	2023-09-26 15:53:35
53599	1499-12-23 00:50:39	\N	1599-01-01 00:50:39	ANCIEN	\N	\N	\N	\N	\N	\N	\N	DEPART	972	21096Q	\N	\N	\N	\N
53890	2023-01-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	DEPART	550	21042A	de la 	\N	\N	\N
53907	2023-10-01 00:00:00	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	DEPART	450	21058J	du 	\N	\N	\N
53726	1500-01-01 00:00:00	1500-01-01 00:00:00	1600-01-01 00:00:00	ANCIEN	\N	67	\N	\N	1500	1600	0	CANTON	670	21043B	du	\N	\N	2023-09-28 17:11:12
53727	1500-01-01 00:00:00	1500-01-01 00:00:00	\N	ACTIF	\N	49	\N	\N	1500	\N	0	CANTON	490	21048G	du	\N	\N	2023-09-28 17:11:40
53729	1500-01-01 00:00:00	1500-01-01 00:00:00	1600-01-01 00:00:00	ANCIEN	\N	49	\N	\N	1500	1600	0	CANTON	490	21048G	du	\N	\N	2023-09-28 17:11:40
53735	1500-01-01 00:00:00	1499-12-31 00:50:39	\N	ACTIF	\N	49	\N	\N	1500	\N	0	CANTON	490	21046E	du	\N	\N	2023-09-28 17:12:21
53741	1500-01-01 00:00:00	1500-01-01 00:00:00	1600-01-01 00:00:00	ANCIEN	\N	41	\N	\N	1500	1600	0	CANTON	410	21052C	du	\N	\N	2023-09-28 17:12:40
53823	1500-01-01 00:00:00	1499-12-31 00:50:39	1600-01-01 00:00:00	ANCIEN	\N	41	\N	\N	1500	1600	0	CANTON	410	21053D	du	\N	\N	2023-10-02 11:26:41
13796	1988-10-03 00:00:00	1988-10-03 00:00:00	2015-03-29 00:00:00	ANCIEN	\N	Limoges-Beaupuy	\N	\N	\N	\N	\N	CANTON	870	14028W	de	\N	2014-09-16 11:31:07	2014-09-16 11:36:09
13814	2011-03-20 00:00:00	\N	2015-01-02 00:00:00	ANCIEN	\N	Limoges-Couzeix	\N	\N	\N	\N	\N	CANTON	870	14034U	de	\N	2014-09-16 17:04:10	2015-01-28 16:03:09
13878	\N	\N	2014-10-13 00:00:00	ANCIEN	\N	Plogastel Saint Germain	\N	\N	1992	\N	\N	CANTON	290	14083S	de	\N	2014-09-18 10:14:03	2014-11-28 18:57:42
50969	2015-03-29 00:00:00	\N	2021-06-26 00:00:00	ANCIEN	\N	Grand-Lemps	\N	\N	\N	\N	\N	DEPART	380	19349W	du	\N	2017-09-21 17:20:27	2017-09-24 18:20:23
13946	\N	\N	2015-03-29 00:00:00	ANCIEN	\N	Guéret-sud-ouest	Guéret-sud-ouest	\N	2013	\N	\N	CANTON	230	14121F	de	\N	2014-09-18 12:12:57	2014-09-18 12:14:58
13948	2001-04-01 00:00:00	2001-04-01 00:00:00	2008-03-30 00:00:00	ANCIEN	\N	Besançon-est	\N	\N	\N	\N	\N	CANTON	250	14123H	de	\N	2014-09-18 12:16:03	2014-11-18 18:15:12
15173	2015-03-30 00:00:00	2015-03-29 00:00:00	2021-06-27 00:00:00	ANCIEN	\N	Raspes et Lévezou	\N	\N	\N	\N	\N	DEPART	120	14111D	de	\N	2015-03-31 16:45:20	2015-04-15 17:32:00
14134	\N	\N	2015-03-29 00:00:00	ANCIEN	\N	Matha	\N	\N	2014	\N	\N	CANTON	170	14213J	de	\N	2014-09-28 17:14:10	2014-09-28 18:23:32
14168	1989-01-01 00:00:00	1989-01-01 00:00:00	2012-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	CANTON	340	14211G	\N	\N	2014-09-28 17:31:51	2014-09-29 16:54:37
14198	\N	\N	2014-10-01 00:00:00	ANCIEN	\N	Ornans	\N	\N	2014	\N	\N	CANTON	250	14219Q	d'	\N	2014-09-28 17:48:40	2014-10-09 14:17:15
14315	\N	1973-12-01 00:00:00	2015-03-29 00:00:00	ANCIEN	\N	Hédé	\N	\N	1973	\N	\N	CANTON	350	14227Q	de 	\N	2014-09-28 21:14:57	2014-09-28 21:16:51
14260	2004-03-01 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Brive-la-Gaillarde-Nord-Est	\N	\N	\N	\N	\N	CANTON	190	14253S	de	\N	2014-09-28 18:39:15	2014-10-01 13:38:56
15172	2015-03-30 00:00:00	2015-03-29 00:00:00	\N	ACTIF	\N	Lot et Palanges	\N	\N	\N	\N	\N	DEPART	120	14103D	de	\N	2015-03-31 16:42:06	2017-09-27 16:52:51
15177	2015-03-30 00:00:00	2015-03-29 00:00:00	2021-06-26 00:00:00	ANCIEN	\N	Marseille-2	\N	\N	\N	\N	\N	DEPART	130	98022P	de	\N	2015-03-31 17:03:18	2015-03-31 17:04:06
50986	2015-12-13 00:00:00	2015-12-13 00:00:00	2017-10-20 00:00:00	ANCIEN	\N	Est-Agenais	\N	\N	\N	\N	\N	DEPART	470	19367Y	du	\N	2017-09-21 17:55:02	2018-05-30 15:40:25
50987	2015-12-13 00:00:00	2015-12-13 00:00:00	2018-01-31 00:00:00	ANCIEN	\N	Tonneins	\N	\N	\N	\N	\N	DEPART	470	19369B	de	\N	2017-09-21 17:56:14	2018-02-26 11:09:21
51005	2015-03-29 00:00:00	2015-03-29 00:00:00	2017-11-30 00:00:00	ANCIEN	\N	Faches-Thumesnil	\N	\N	\N	\N	\N	DEPART	590	19585H	de	\N	2017-09-22 10:34:07	2017-09-24 19:58:41
51408	2006-11-26 00:00:00	2006-11-26 00:00:00	2008-03-15 00:00:00	ANCIEN	\N	Calais Nord-Ouest	\N	\N	\N	\N	\N	CANTON	620	19521Q	de	\N	2017-09-26 17:05:03	2017-09-27 11:29:41
51022	2015-03-29 00:00:00	2015-03-29 00:00:00	2021-06-27 00:00:00	ANCIEN	\N	Lille-4	\N	\N	\N	\N	\N	DEPART	590	19599P	de	\N	2017-09-22 11:41:12	2017-09-24 20:26:41
51083	1992-03-22 00:00:00	1992-03-22 00:00:00	2015-03-28 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	CANTON	974	19659J	\N	\N	2017-09-24 16:41:10	2017-09-24 16:43:03
51092	2015-03-29 00:00:00	2015-03-29 00:00:00	2017-12-22 00:00:00	ANCIEN	\N	Saint-Pierre 1	\N	\N	\N	\N	\N	DEPART	974	19657G	\N	\N	2017-09-24 16:56:43	2018-02-06 12:22:22
51109	2001-03-18 00:00:00	2001-03-18 00:00:00	2015-03-17 00:00:00	ANCIEN	\N	Saint-Denis-2	\N	\N	\N	\N	\N	CANTON	974	19577H	de	\N	2017-09-24 17:12:29	2017-09-24 17:43:46
51137	1994-03-27 00:00:00	1994-03-27 00:00:00	2002-10-13 00:00:00	ANCIEN	\N	Croisic	\N	\N	\N	\N	\N	CANTON	440	17583W	du	\N	2017-09-24 17:26:48	2017-09-24 17:30:07
51148	2001-03-18 00:00:00	2001-03-18 00:00:00	2015-03-28 00:00:00	ANCIEN	\N	Loches	\N	\N	\N	\N	\N	CANTON	370	19441R	de	\N	2017-09-24 17:33:20	2017-09-24 17:40:27
51188	2015-03-29 00:00:00	2015-03-29 00:00:00	\N	ACTIF	\N	Chinon	\N	\N	\N	\N	\N	DEPART	370	19443T	de	\N	2017-09-24 17:49:15	2017-09-24 17:51:10
51189	2015-03-29 00:00:00	2015-03-29 00:00:00	2017-10-18 00:00:00	ANCIEN	\N	Domont	\N	\N	\N	\N	\N	DEPART	828	19671E	de	\N	2017-09-24 17:50:19	2018-02-09 09:57:29
51212	2011-03-27 00:00:00	2011-03-27 00:00:00	2015-03-28 00:00:00	ANCIEN	\N	Monestier-de-Clermont	\N	\N	\N	\N	\N	CANTON	380	19679N	de	\N	2017-09-24 18:09:00	2017-09-27 15:22:02
51213	2015-03-29 00:00:00	2015-03-29 00:00:00	\N	ACTIF	\N	Monestier-de-Clermont	\N	\N	\N	\N	\N	DEPART	380	19679N	de	\N	2017-09-24 18:11:34	2017-11-14 10:33:13
51239	1998-03-22 00:00:00	\N	2015-03-28 00:00:00	ANCIEN	\N	Grand-Lemps	\N	\N	\N	\N	\N	CANTON	380	19349W	du	\N	2017-09-24 18:20:26	2017-09-24 18:22:33
51277	1998-03-22 00:00:00	\N	2015-03-28 00:00:00	ANCIEN	\N	Ivry-sur-Seine-Est	\N	\N	\N	\N	\N	CANTON	824	19687N	d'	\N	2017-09-24 19:03:37	2017-09-24 19:05:10
51279	2015-03-29 00:00:00	2015-03-29 00:00:00	2021-06-26 00:00:00	ANCIEN	\N	Ivry-sur-Seine-Est	\N	\N	\N	\N	\N	DEPART	824	19687N	d'	\N	2017-09-24 19:05:54	2017-09-24 19:06:26
51285	2015-03-29 00:00:00	2015-03-29 00:00:00	2021-06-26 00:00:00	ANCIEN	\N	Montigny-le-Bretonneux	\N	\N	\N	\N	\N	DEPART	895	19699S	de	\N	2017-09-24 19:15:08	2017-09-27 11:32:00
51311	1994-03-27 00:00:00	1994-03-27 00:00:00	2015-03-29 00:00:00	ANCIEN	\N	Bourbourg	\N	\N	\N	\N	\N	CANTON	590	17589D	de	\N	2017-09-24 19:33:19	2017-09-24 19:34:30
51289	2015-03-29 00:00:00	2015-03-29 00:00:00	\N	ACTIF	\N	Gif-sur-Yvette	\N	\N	\N	\N	\N	DEPART	265	19693L	de	\N	2017-09-24 19:16:56	2017-09-24 19:17:24
51316	1994-03-27 00:00:00	1994-03-27 00:00:00	2015-03-28 00:00:00	ANCIEN	\N	Orcines	\N	\N	\N	\N	\N	CANTON	630	19383Y	d'	\N	2017-09-24 19:45:05	2017-09-24 19:48:26
51335	2011-03-27 00:00:00	\N	2015-03-29 00:00:00	ANCIEN	\N	Lille-Est	\N	\N	\N	\N	\N	CANTON	590	19637C	de	\N	2017-09-24 20:18:24	2017-09-24 20:19:35
51321	2008-03-16 00:00:00	2008-03-16 00:00:00	2015-03-28 00:00:00	ANCIEN	\N	Séclin-Nord	\N	\N	\N	\N	\N	CANTON	590	19585H	de	\N	2017-09-24 19:55:11	2017-09-26 11:13:41
51339	2008-03-16 00:00:00	2008-03-16 00:00:00	2015-03-29 00:00:00	ANCIEN	\N	Lille-Centre	\N	\N	\N	\N	\N	CANTON	590	19599P	de	\N	2017-09-24 20:26:46	2017-09-24 20:29:24
51352	1998-03-22 00:00:00	1998-03-22 00:00:00	2014-09-22 00:00:00	ANCIEN	\N	Lille-Sud-Ouest	\N	\N	\N	\N	\N	CANTON	590	14021P	de	\N	2017-09-24 20:45:59	2017-09-24 20:51:43
51494	2015-03-29 00:00:00	2015-03-29 00:00:00	2017-10-24 00:00:00	ANCIEN	\N	Caen 1	\N	\N	\N	\N	\N	DEPART	140	19735D	de	\N	2017-10-02 14:59:41	2017-10-25 16:36:25
51495	2004-03-28 00:00:00	2004-03-28 00:00:00	2015-03-28 00:00:00	ANCIEN	\N	Perpignan 2	\N	\N	\N	\N	\N	CANTON	660	19703U	de	\N	2017-10-02 16:07:43	2017-10-02 16:12:15
52169	2015-03-15 00:00:00	2015-03-15 00:00:00	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	DEPART	310	17965H	de la	\N	\N	\N
52413	2021-06-27 00:00:00	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	DEPART	125	14193X	\N	\N	\N	\N
52414	2021-06-27 00:00:00	\N	\N	ACTIF	\N	Anzin	\N	\N	\N	\N	\N	DEPART	590	19565D	d'	\N	\N	\N
53882	2023-11-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	DEPART	380	21080G	de l'	\N	\N	\N
53397	2023-01-09 00:00:00	1499-12-31 00:50:39	2023-11-06 00:00:00	ANCIEN	\N	974	\N	\N	\N	\N	0	DEPART	974	21035B	de	\N	\N	2023-10-05 13:33:27
53518	1500-01-01 00:00:00	1500-01-01 00:00:00	1600-01-01 00:00:00	ANCIEN	\N	44	\N	\N	1500	1600	0	CANTON	440	21066J	de la	\N	\N	2023-10-09 12:25:54
53523	1499-12-31 00:50:39	1499-12-31 00:50:39	1515-11-03 00:50:39	ANCIEN	\N	42	\N	\N	\N	\N	0	DEPART	420	21068L	de la	\N	\N	2023-10-05 09:31:17
53888	2023-10-27 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	DEPART	420	21068L	de la	\N	\N	\N
53542	1500-01-01 00:00:00	1499-12-31 00:50:39	\N	ACTIF	\N	37	\N	\N	1500	\N	0	CANTON	370	21054E	de l'	\N	\N	2023-09-26 16:27:42
53543	1500-01-01 00:00:00	1500-01-01 00:00:00	1600-01-01 00:00:00	ANCIEN	\N	37	\N	\N	1500	1600	0	CANTON	370	21054E	de l'	\N	\N	2023-09-26 16:27:42
53569	1499-12-31 00:50:39	1499-12-31 00:50:39	1515-10-23 00:50:39	ANCIEN	\N	52	\N	\N	\N	\N	0	CANTON	520	21039F	de la	\N	\N	2023-09-26 16:44:47
53610	1500-01-01 00:00:00	1500-01-01 00:00:00	1600-01-01 00:00:00	ANCIEN	\N	67	\N	\N	1500	1600	0	CANTON	670	21043B	du	\N	\N	2023-09-26 18:16:19
53614	1500-01-01 00:00:00	1500-01-01 00:00:00	\N	ACTIF	\N	49	\N	\N	1500	\N	0	CANTON	490	21048G	du	\N	\N	2023-09-27 09:52:12
53616	1500-01-01 00:00:00	1500-01-01 00:00:00	1600-01-01 00:00:00	ANCIEN	\N	49	\N	\N	1500	1600	0	CANTON	490	21048G	du	\N	\N	2023-09-27 09:52:12
53908	2023-11-13 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	DEPART	370	21055F	d'	\N	\N	\N
\.


--
-- Data for Name: eludep; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY eludep (eluid, eludatdeb, depcod, eludatelu, eludatfin, temvalcod, evelic, evelib, evelil, eveobs, eluanndeb, eluannfin, elunbrhab, typmancod, senmat, eludatcum, syscredat, sysmajdat, id_organe_assnat, circo) FROM stdin;
10383	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	1946	1948	\N	DEPUTE	000713	\N	\N	\N	\N	\N
10384	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	\N	1958	\N	DEPUTE	000681	\N	\N	\N	\N	\N
10385	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	1936	1942	\N	DEPUTE	000699	\N	\N	\N	\N	\N
10386	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	\N	1955	\N	DEPUTE	000215	\N	\N	\N	\N	\N
10387	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	\N	1968	\N	DEPUTE	000057	\N	\N	\N	\N	\N
10397	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	\N	1946	\N	DEPUTE	000035	\N	\N	\N	\N	\N
10398	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	1945	1958	\N	DEPUTE	57432D	\N	\N	\N	\N	\N
10403	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	\N	1958	\N	DEPUTE	56601X	\N	\N	\N	\N	\N
10404	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	1945	1958	\N	DEPUTE	000131	\N	\N	\N	\N	\N
10406	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	1946	1951	\N	DEPUTE	000700	\N	\N	\N	\N	\N
10407	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	1945	1946	\N	DEPUTE	000114	\N	\N	\N	\N	\N
10408	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	1951	1955	\N	DEPUTE	000062	\N	\N	\N	\N	\N
10409	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	\N	1973	\N	DEPUTE	000216	\N	\N	\N	\N	\N
10410	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	1946	1951	\N	DEPUTE	000459	\N	\N	\N	\N	\N
10411	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	1951	1958	\N	DEPUTE	000721	\N	\N	\N	\N	\N
10412	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	Ancien député de la IIIème République	\N	1958	\N	DEPUTE	000092	\N	\N	\N	\N	\N
10413	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	1951	1955	\N	DEPUTE	000162	\N	\N	\N	\N	\N
10415	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	\N	1958	\N	DEPUTE	000185	\N	\N	\N	\N	\N
10417	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	1946	1955	\N	DEPUTE	000348	\N	\N	\N	\N	\N
10420	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	1951	1955	\N	DEPUTE	000303	\N	\N	\N	\N	\N
10423	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	\N	1958	\N	DEPUTE	000325	\N	\N	\N	\N	\N
43770	1981-07-02 00:00:00	VEME	\N	1984-08-24 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	04040A	\N	2017-07-25 10:43:41	\N	44309	680
10425	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	1956	1958	\N	DEPUTE	57830P	\N	\N	\N	\N	\N
10426	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	1952	1955	\N	DEPUTE	57130R	\N	\N	\N	\N	\N
10427	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	\N	1978	\N	DEPUTE	000124	\N	\N	\N	\N	\N
10429	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	1951	1958	\N	DEPUTE	000223	\N	\N	\N	\N	\N
10430	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	\N	1958	\N	DEPUTE	59715V	\N	\N	\N	\N	\N
43771	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	04040A	\N	2017-07-25 10:43:41	\N	44310	680
10432	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	\N	1958	\N	DEPUTE	000746	\N	\N	\N	\N	\N
43772	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	04040A	\N	2017-07-25 10:43:41	\N	44311	680
10439	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	\N	1958	\N	DEPUTE	000356	\N	\N	\N	\N	\N
43773	1997-06-01 00:00:00	VEME	\N	2002-06-18 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	04040A	\N	2017-07-25 10:43:41	\N	44313	680
10440	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	\N	1958	\N	DEPUTE	000379	\N	\N	\N	\N	\N
10441	\N	IIIEME	\N	\N	ANCIEN	\N	\N	\N	Député sous la 3ème République	1932	1946	\N	DEPUTE	000677	\N	\N	\N	\N	\N
10443	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	1945	1958	\N	DEPUTE	57135W	\N	\N	\N	\N	\N
10445	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	1951	1958	\N	DEPUTE	000691	\N	\N	\N	\N	\N
10446	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	1945	1958	\N	DEPUTE	000027	\N	\N	\N	\N	\N
10447	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	Ancien député 3ème République	\N	1947	\N	DEPUTE	000736	\N	\N	\N	\N	\N
10457	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	1951	1955	\N	DEPUTE	000142	\N	\N	\N	\N	\N
10456	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	1945	1958	\N	DEPUTE	000158	\N	\N	\N	\N	\N
10460	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	1945	1946	\N	DEPUTE	000044	\N	\N	\N	\N	\N
10465	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	1945	1958	\N	DEPUTE	56829S	\N	\N	\N	\N	\N
10466	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	1945	1951	\N	DEPUTE	000251	\N	\N	\N	\N	\N
10471	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	\N	1958	\N	DEPUTE	000268	\N	\N	\N	\N	\N
10479	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	1946	1951	\N	DEPUTE	58355M	\N	\N	\N	\N	\N
10482	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	1951	1955	\N	DEPUTE	000322	\N	\N	\N	\N	\N
10486	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	\N	1958	\N	DEPUTE	58328J	\N	\N	\N	\N	\N
10489	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	\N	1946	\N	DEPUTE	000696	\N	\N	\N	\N	\N
10490	\N	IIIEME	\N	\N	ANCIEN	\N	\N	\N	\N	\N	1940	\N	DEPUTE	000681	\N	\N	\N	\N	\N
10491	\N	IIIEME	\N	\N	ANCIEN	\N	\N	\N	\N	1936	1942	\N	DEPUTE	000080	\N	\N	\N	\N	\N
10493	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	\N	1958	\N	DEPUTE	000025	\N	\N	\N	\N	\N
10498	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	1946	1946	\N	DEPUTE	000677	\N	\N	\N	\N	\N
10499	\N	IIIEME	\N	\N	ANCIEN	\N	\N	\N	\N	1936	1942	\N	DEPUTE	000705	\N	\N	\N	\N	\N
10500	\N	IIIEME	\N	\N	ANCIEN	\N	\N	\N	\N	\N	1940	\N	DEPUTE	000736	\N	\N	\N	\N	\N
10501	\N	IIIEME	\N	\N	ANCIEN	\N	\N	\N	\N	1936	1942	\N	DEPUTE	000174	\N	\N	\N	\N	\N
10502	\N	IIIEME	\N	\N	ANCIEN	\N	\N	\N	\N	1936	1942	\N	DEPUTE	000704	\N	\N	\N	\N	\N
10503	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	1951	1958	\N	DEPUTE	000078	\N	\N	\N	\N	\N
10504	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	1951	1955	\N	DEPUTE	000770	\N	\N	\N	\N	\N
10505	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	1951	1958	\N	DEPUTE	000354	\N	\N	\N	\N	\N
10506	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	1945	1946	\N	DEPUTE	000117	\N	\N	\N	\N	\N
44271	1981-07-02 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	02007Q	\N	2017-07-25 10:43:57	\N	44309	700
44272	1986-04-02 00:00:00	VEME	\N	1986-04-02 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	02007Q	\N	2017-07-25 10:43:58	\N	44310	700
44273	1988-06-06 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	02007Q	\N	2017-07-25 10:43:58	\N	44311	700
44274	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	02007Q	\N	2017-07-25 10:43:58	\N	44312	700
44275	1997-06-01 00:00:00	VEME	\N	2002-06-18 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	02007Q	\N	2017-07-25 10:43:58	\N	44313	700
1673	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	1951	1956	\N	DEPUTE	71017B	\N	\N	\N	\N	\N
1674	1956-01-02 00:00:00	IVEME	\N	1958-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	1956	1958	\N	DEPUTE	83016P	\N	\N	2016-12-08 15:02:20	\N	\N
44278	1981-07-02 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	59583C	\N	2017-07-25 10:43:58	\N	44309	690
44288	1971-12-05 00:00:00	VEME	\N	1973-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	07003H	\N	2017-07-25 10:43:58	\N	44306	50
44289	1973-04-02 00:00:00	VEME	\N	1977-05-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	07003H	\N	2017-07-25 10:43:58	\N	44307	50
44290	1978-04-03 00:00:00	VEME	\N	1978-10-12 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	07003H	\N	2017-07-25 10:43:58	\N	44308	50
44291	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	07003H	\N	2017-07-25 10:43:58	\N	44310	50
44292	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	89020L	\N	2017-07-25 10:43:58	\N	44310	360
44296	1981-07-02 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11068S	\N	2017-07-25 10:43:59	\N	44309	265
44297	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11068S	\N	2017-07-25 10:43:59	\N	44310	265
44298	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11068S	\N	2017-07-25 10:43:59	\N	44311	265
44299	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11068S	\N	2017-07-25 10:43:59	\N	44312	265
44321	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	59721T	\N	2017-07-25 10:43:59	\N	44312	300
44328	1981-07-02 00:00:00	VEME	\N	1984-08-24 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	86010V	\N	2017-07-25 10:43:59	\N	44309	820
44329	1978-04-03 00:00:00	VEME	\N	1981-05-22 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	86010V	\N	2017-07-25 10:43:59	\N	44308	820
44330	1988-06-06 00:00:00	VEME	\N	1988-07-28 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	86010V	\N	2017-07-25 10:43:59	\N	44311	820
12857	1956-01-02 00:00:00	IVEME	\N	1958-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	DEPUTE	96003C	\N	\N	\N	\N	\N
44351	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	04091M	\N	2017-07-25 10:44:00	\N	44310	710
44352	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	04091M	\N	2017-07-25 10:44:00	\N	44312	710
44353	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	04091M	\N	2017-07-25 10:44:00	\N	44311	710
44356	1978-04-03 00:00:00	VEME	\N	1978-05-06 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	58819Y	\N	2017-07-25 10:44:00	\N	44308	290
44357	1967-05-08 00:00:00	VEME	\N	1968-05-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	58819Y	\N	2017-07-25 10:44:00	\N	44305	290
44358	1969-07-23 00:00:00	VEME	\N	1973-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	58819Y	\N	2017-07-25 10:44:00	\N	44306	290
44359	1973-04-02 00:00:00	VEME	\N	1977-05-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	58819Y	\N	2017-07-25 10:44:00	\N	44307	290
44360	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	58819Y	\N	2017-07-25 10:44:00	\N	44310	290
9673	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	1956	1958	\N	DEPUTE	59213C	\N	\N	\N	\N	\N
9674	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	\N	1958	\N	DEPUTE	59522N	\N	\N	\N	\N	\N
9675	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	1946	1958	\N	DEPUTE	58619S	\N	\N	\N	\N	\N
9676	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	\N	1958	\N	DEPUTE	59571X	\N	\N	\N	\N	\N
9677	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	\N	1958	\N	DEPUTE	000197	\N	\N	\N	\N	\N
9678	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	1951	1958	\N	DEPUTE	58818X	\N	\N	\N	\N	\N
9679	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	1956	1958	\N	DEPUTE	62001R	\N	\N	\N	\N	\N
9680	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	1956	1958	\N	DEPUTE	000107	\N	\N	\N	\N	\N
9681	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	\N	1958	\N	DEPUTE	000442	\N	\N	\N	\N	\N
9682	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	1946	1958	\N	DEPUTE	000206	\N	\N	\N	\N	\N
9683	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	\N	1958	\N	DEPUTE	59550S	\N	\N	\N	\N	\N
9684	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	1945	1951	\N	DEPUTE	59236K	\N	\N	\N	\N	\N
9685	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	1945	1958	\N	DEPUTE	74044S	\N	\N	\N	\N	\N
9686	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	1956	1958	\N	DEPUTE	55510R	\N	\N	\N	\N	\N
10382	\N	IVEME	\N	\N	ANCIEN	\N	\N	\N	\N	1945	1958	\N	DEPUTE	000683	\N	\N	\N	\N	\N
51498	1973-03-11 00:00:00	VEME	\N	1981-05-22 00:00:00	ANCIEN	\N	\N	\N	\N	1973	1981	\N	DEPUTE	59527T	\N	2017-10-10 12:05:01	\N	\N	\N
44467	1981-07-02 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	99002P	\N	2017-07-25 10:44:04	\N	44309	690
44468	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	99002P	\N	2017-07-25 10:44:04	\N	44310	690
44499	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98023Q	\N	2017-07-25 10:44:05	\N	44312	280
44521	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	07030L	\N	2017-07-25 10:44:06	\N	44312	340
44554	1981-07-02 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	59529V	\N	2017-07-25 10:44:07	\N	44309	615
43811	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	14089Y	\N	2017-07-25 10:43:42	\N	44312	810
43816	1978-04-02 00:00:00	VEME	\N	1978-05-05 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	83016P	\N	2017-07-25 10:43:43	\N	44308	560
43817	1981-07-02 00:00:00	VEME	\N	1983-09-26 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	83016P	\N	2017-07-25 10:43:43	\N	44309	560
43867	1973-04-02 00:00:00	VEME	\N	1978-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01065W	\N	2017-07-25 10:43:45	\N	44307	1002
43868	1981-07-02 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01065W	\N	2017-07-25 10:43:45	\N	44309	200
43869	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01065W	\N	2017-07-25 10:43:45	\N	44310	200
43886	1985-05-23 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	04087R	\N	2017-07-25 10:43:45	\N	44309	810
43887	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	04087R	\N	2017-07-25 10:43:45	\N	44311	810
43922	1991-06-17 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	97009N	\N	2017-07-25 10:43:47	\N	44311	828
43944	1978-04-03 00:00:00	VEME	\N	1981-05-22 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	59520L	\N	2017-07-25 10:43:48	\N	44308	830
43945	1986-04-02 00:00:00	VEME	\N	1986-09-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	59520L	\N	2017-07-25 10:43:48	\N	44310	830
43961	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98020M	\N	2017-07-25 10:43:48	\N	44311	130
43962	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98020M	\N	2017-07-25 10:43:48	\N	44312	130
43963	1997-06-01 00:00:00	VEME	\N	1998-08-10 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98020M	\N	2017-07-25 10:43:48	\N	44313	130
44017	1981-07-02 00:00:00	VEME	\N	1981-07-23 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	83012K	\N	2017-07-25 10:43:50	\N	44309	440
44018	1988-07-29 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	00001A	\N	2017-07-25 10:43:50	\N	44311	615
44019	2012-06-17 00:00:00	VEME	\N	2012-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	00001A	\N	2017-07-25 10:43:50	\N	384266	615
44103	1978-04-03 00:00:00	VEME	\N	1981-05-22 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01046T	\N	2017-07-25 10:43:52	\N	44308	390
44104	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01046T	\N	2017-07-25 10:43:52	\N	44310	390
44105	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01046T	\N	2017-07-25 10:43:52	\N	44312	390
44119	1981-07-02 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95008D	\N	2017-07-25 10:43:52	\N	44309	730
44120	1978-04-03 00:00:00	VEME	\N	1981-05-22 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95008D	\N	2017-07-25 10:43:52	\N	44308	730
44121	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95008D	\N	2017-07-25 10:43:52	\N	44310	730
44122	1988-06-06 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95008D	\N	2017-07-25 10:43:52	\N	44311	730
44123	1993-04-02 00:00:00	VEME	\N	1993-05-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95008D	\N	2017-07-25 10:43:52	\N	44312	730
44124	1993-04-02 00:00:00	VEME	\N	1995-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	05004A	\N	2017-07-25 10:43:52	2017-08-11 11:32:28	44312	100
44125	1997-06-01 00:00:00	VEME	\N	2002-06-18 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	05004A	\N	2017-07-25 10:43:52	2017-08-10 10:56:00	44313	100
44126	2002-06-19 00:00:00	VEME	\N	2005-07-02 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	05004A	\N	2017-07-25 10:43:52	2017-08-10 10:56:00	230434	100
44127	2007-06-20 00:00:00	VEME	\N	2010-04-23 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	05004A	\N	2017-07-25 10:43:52	2017-08-07 03:42:29	384266	100
44128	2012-06-17 00:00:00	VEME	\N	2012-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	05004A	\N	2017-07-25 10:43:52	2017-08-07 03:42:29	384266	100
44129	2012-06-20 00:00:00	VEME	\N	2014-09-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	05004A	\N	2017-07-25 10:43:52	\N	644420	100
44215	1967-04-03 00:00:00	VEME	\N	1968-05-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000400	\N	2017-07-25 10:43:55	\N	44305	\N
44216	1968-07-11 00:00:00	VEME	\N	1969-07-22 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000400	\N	2017-07-25 10:43:55	\N	44306	335
44217	1973-04-02 00:00:00	VEME	\N	1978-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000400	\N	2017-07-25 10:43:55	\N	44307	20
44218	1981-07-02 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000400	\N	2017-07-25 10:43:55	\N	44309	335
44219	1978-04-03 00:00:00	VEME	\N	1981-05-22 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000400	\N	2017-07-25 10:43:55	\N	44308	335
44220	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000400	\N	2017-07-25 10:43:55	\N	44310	335
44221	1988-06-06 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000400	\N	2017-07-25 10:43:55	\N	44311	335
44222	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000400	\N	2017-07-25 10:43:55	\N	44312	335
44223	1997-06-01 00:00:00	VEME	\N	2002-06-18 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000400	\N	2017-07-25 10:43:55	\N	44313	335
44235	1973-05-08 00:00:00	VEME	\N	1976-11-13 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	80007A	\N	2017-07-25 10:43:56	\N	44307	190
44251	1981-07-02 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	59309K	\N	2017-07-25 10:43:57	\N	44309	300
44252	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	59309K	\N	2017-07-25 10:43:57	\N	44311	300
43707	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	14093U	\N	2017-07-25 10:43:39	\N	44312	800
43708	2002-06-19 00:00:00	VEME	\N	2007-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	14093U	\N	2017-07-25 10:43:39	\N	230434	800
43709	2007-06-20 00:00:00	VEME	\N	2012-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	14093U	\N	2017-07-25 10:43:39	\N	384266	800
43710	1997-06-01 00:00:00	VEME	\N	2002-06-18 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95010W	\N	2017-07-25 10:43:39	\N	44313	824
43737	1978-04-03 00:00:00	VEME	\N	1981-05-22 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01005J	\N	2017-07-25 10:43:40	\N	44308	480
43738	1973-04-02 00:00:00	VEME	\N	1977-05-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01005J	\N	2017-07-25 10:43:40	\N	44307	480
43739	1981-07-02 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01005J	\N	2017-07-25 10:43:40	\N	44309	480
43740	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01005J	\N	2017-07-25 10:43:40	2017-08-09 03:42:20	44310	480
43741	1988-06-06 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01005J	\N	2017-07-25 10:43:40	\N	44311	480
43742	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01005J	\N	2017-07-25 10:43:40	\N	44312	480
43743	1997-05-25 00:00:00	VEME	\N	2001-09-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01005J	\N	2017-07-25 10:43:40	\N	44313	480
49900	2007-06-20 00:00:00	VEME	\N	2012-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	14123H	\N	2017-07-25 10:46:55	\N	384266	250
49929	2012-07-22 00:00:00	VEME	\N	2014-12-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	17965H	\N	2017-07-25 10:46:56	\N	644420	310
50002	2012-06-20 00:00:00	VEME	\N	2017-06-20 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	18083K	\N	2017-07-25 10:46:59	\N	644420	530
50030	2012-06-20 00:00:00	VEME	\N	2017-06-20 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	18127E	\N	2017-07-25 10:47:01	\N	644420	590
50076	2012-06-20 00:00:00	VEME	\N	2017-06-20 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	18193Q	\N	2017-07-25 10:47:02	\N	644420	220
50085	2012-06-20 00:00:00	VEME	\N	2017-06-20 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	18207D	\N	2017-07-25 10:47:03	\N	644420	590
50099	2012-06-20 00:00:00	VEME	\N	2013-02-15 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	18231D	\N	2017-07-25 10:47:03	\N	644420	\N
50203	2013-08-03 00:00:00	VEME	\N	2014-05-02 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	14257W	\N	2017-07-25 10:47:08	\N	644420	320
50204	2017-06-21 00:00:00	VEME	\N	2022-06-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	12039E	\N	2017-07-25 10:47:08	\N	717460	120
50213	2016-04-25 00:00:00	VEME	\N	2017-06-20 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	18395Y	\N	2017-07-25 10:47:08	\N	644420	440
50557	2017-06-21 00:00:00	VEME	\N	2018-02-02 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	19057M	\N	2017-07-25 10:47:23	2018-02-06 03:44:56	717460	\N
50583	2017-06-21 00:00:00	VEME	\N	2022-06-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	19111A	\N	2017-07-25 10:47:25	\N	717460	335
50668	2012-06-20 00:00:00	VEME	\N	2017-06-20 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	18003S	\N	2017-07-25 10:47:28	\N	644420	840
50669	2017-06-21 00:00:00	VEME	\N	2022-06-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	18003S	\N	2017-07-25 10:47:28	\N	717460	840
50708	2007-06-20 00:00:00	VEME	\N	2012-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	17737W	\N	2017-07-25 10:47:30	\N	384266	130
50709	2012-06-20 00:00:00	VEME	\N	2017-06-20 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	17737W	\N	2017-07-25 10:47:30	2017-08-10 10:58:10	644420	130
50710	2017-06-21 00:00:00	VEME	\N	2020-09-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	17737W	\N	2017-07-25 10:47:30	\N	717460	130
52821	2022-06-22 00:00:00	VEME	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	19689Q	\N	\N	\N	791932	824
47338	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	59717X	\N	2017-07-25 10:45:32	\N	44312	60
47339	1967-04-03 00:00:00	VEME	\N	1968-05-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01020H	\N	2017-07-25 10:45:32	\N	44305	380
47340	1973-04-02 00:00:00	VEME	\N	1978-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01020H	\N	2017-07-25 10:45:32	\N	44307	380
47341	1981-07-02 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01020H	\N	2017-07-25 10:45:32	2017-08-10 10:56:59	44309	380
47343	1978-04-03 00:00:00	VEME	\N	1981-05-22 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01020H	\N	2017-07-25 10:45:32	\N	44308	380
47344	1988-06-13 00:00:00	VEME	\N	1990-11-02 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01020H	\N	2017-07-25 10:45:32	\N	44311	380
47345	1997-06-01 00:00:00	VEME	\N	2001-09-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01020H	\N	2017-07-25 10:45:32	\N	44313	380
47370	1981-07-02 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	92038W	\N	2017-07-25 10:45:33	\N	44309	570
47371	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	92038W	\N	2017-07-25 10:45:33	\N	44310	570
47372	1988-06-13 00:00:00	VEME	\N	1992-10-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	92038W	\N	2017-07-25 10:45:33	\N	44311	570
47419	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01014K	\N	2017-07-25 10:45:35	\N	44311	540
47434	1994-11-27 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	04033B	\N	2017-07-25 10:45:36	\N	44312	850
47436	1978-04-03 00:00:00	VEME	\N	1981-05-22 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95062K	\N	2017-07-25 10:45:36	\N	44308	760
47437	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95062K	\N	2017-07-25 10:45:36	\N	44310	760
47438	1993-04-02 00:00:00	VEME	\N	1995-09-24 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95062K	\N	2017-07-25 10:45:36	\N	44312	760
47472	1981-07-25 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95065N	\N	2017-07-25 10:45:37	\N	44309	824
47473	1988-03-10 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95065N	\N	2017-07-25 10:45:37	\N	44310	824
47474	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95065N	\N	2017-07-25 10:45:37	\N	44311	824
47475	1997-06-01 00:00:00	VEME	\N	2002-06-18 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95065N	\N	2017-07-25 10:45:37	\N	44313	824
47476	2002-06-19 00:00:00	VEME	\N	2007-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95065N	\N	2017-07-25 10:45:37	2017-08-10 10:57:02	230434	824
47477	2007-06-20 00:00:00	VEME	\N	2012-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95065N	\N	2017-07-25 10:45:37	2017-08-10 10:57:02	384266	824
47478	2012-06-20 00:00:00	VEME	\N	2017-06-20 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95065N	\N	2017-07-25 10:45:37	\N	644420	824
47488	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	16431B	\N	2017-07-25 10:45:37	\N	44312	300
47489	2002-06-19 00:00:00	VEME	\N	2007-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	16431B	\N	2017-07-25 10:45:37	\N	230434	300
47490	2007-06-20 00:00:00	VEME	\N	2012-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	16431B	\N	2017-07-25 10:45:37	\N	384266	300
46354	1981-07-02 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	59509R	\N	2017-07-25 10:45:02	\N	44309	830
46363	2004-01-14 00:00:00	VEME	\N	2007-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11062L	\N	2017-07-25 10:45:03	\N	230434	620
46364	2007-06-20 00:00:00	VEME	\N	2011-09-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11062L	\N	2017-07-25 10:45:03	\N	384266	620
46365	1978-04-03 00:00:00	VEME	\N	1981-05-22 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	59305F	\N	2017-07-25 10:45:03	\N	44308	760
46366	1967-04-03 00:00:00	VEME	\N	1968-05-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	59305F	\N	2017-07-25 10:45:03	\N	44305	760
46367	1968-07-11 00:00:00	VEME	\N	1973-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	59305F	\N	2017-07-25 10:45:03	\N	44306	760
46368	1973-04-02 00:00:00	VEME	\N	1978-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	59305F	\N	2017-07-25 10:45:03	\N	44307	760
46369	1981-07-02 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	59305F	\N	2017-07-25 10:45:03	\N	44309	760
46370	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	59305F	\N	2017-07-25 10:45:03	\N	44311	760
46400	1986-04-02 00:00:00	VEME	\N	1986-04-02 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95050F	\N	2017-07-25 10:45:04	\N	44310	\N
46401	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95050F	\N	2017-07-25 10:45:04	\N	44311	\N
46402	1993-04-02 00:00:00	VEME	\N	1993-05-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95050F	\N	2017-07-25 10:45:04	\N	44312	\N
46410	1981-07-02 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	04084N	\N	2017-07-25 10:45:05	\N	44309	700
46411	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	04084N	\N	2017-07-25 10:45:05	2017-08-10 10:56:43	44310	700
46412	1988-06-06 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	04084N	\N	2017-07-25 10:45:05	\N	44311	700
46413	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	04084N	\N	2017-07-25 10:45:05	\N	44312	700
46414	1997-06-01 00:00:00	VEME	\N	2002-06-18 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	04084N	\N	2017-07-25 10:45:05	\N	44313	700
46424	1967-04-03 00:00:00	VEME	\N	1967-05-07 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000025	\N	2017-07-25 10:45:05	\N	44305	290
46425	1968-07-11 00:00:00	VEME	\N	1969-07-22 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000025	\N	2017-07-25 10:45:05	\N	44306	290
46463	1974-07-26 00:00:00	VEME	\N	1977-05-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	59552U	\N	2017-07-25 10:45:06	\N	44307	615
46464	1981-07-02 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	59552U	\N	2017-07-25 10:45:06	\N	44309	615
46465	1986-04-02 00:00:00	VEME	\N	1986-09-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	59552U	\N	2017-07-25 10:45:07	\N	44310	828
46466	1978-04-03 00:00:00	VEME	\N	1981-05-22 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	59552U	\N	2017-07-25 10:45:07	\N	44308	615
46493	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98032R	\N	2017-07-25 10:45:08	\N	44310	320
46494	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98032R	\N	2017-07-25 10:45:08	\N	44312	320
46515	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	14119M	\N	2017-07-25 10:45:08	\N	44312	790
46516	1997-06-01 00:00:00	VEME	\N	2002-06-18 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	14119M	\N	2017-07-25 10:45:08	\N	44313	790
46517	2002-06-19 00:00:00	VEME	\N	2007-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	14119M	\N	2017-07-25 10:45:08	\N	230434	790
46518	2007-06-20 00:00:00	VEME	\N	2012-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	14119M	\N	2017-07-25 10:45:08	\N	384266	790
46536	1997-06-01 00:00:00	VEME	\N	2002-06-18 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	04078Q	\N	2017-07-25 10:45:08	\N	44313	828
46538	1973-04-02 00:00:00	VEME	\N	1978-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	92027T	\N	2017-07-25 10:45:09	\N	44307	620
46539	1981-07-02 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	92027T	\N	2017-07-25 10:45:09	\N	44309	620
46540	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	92027T	\N	2017-07-25 10:45:09	\N	44310	620
46541	1978-04-03 00:00:00	VEME	\N	1981-05-22 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	92027T	\N	2017-07-25 10:45:09	\N	44308	620
46542	1988-06-06 00:00:00	VEME	\N	1992-10-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	92027T	\N	2017-07-25 10:45:09	\N	44311	620
46561	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95039L	\N	2017-07-25 10:45:09	\N	44310	770
46562	1993-04-02 00:00:00	VEME	\N	1995-09-24 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95039L	\N	2017-07-25 10:45:09	\N	44312	770
46563	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95039L	\N	2017-07-25 10:45:09	\N	44311	770
46634	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000630	\N	2017-07-25 10:45:11	\N	44310	830
46635	1996-03-17 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000630	\N	2017-07-25 10:45:11	\N	44312	830
46636	1997-06-01 00:00:00	VEME	\N	1999-07-22 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000630	\N	2017-07-25 10:45:11	\N	44313	830
46656	1958-12-09 00:00:00	VEME	\N	1962-10-04 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	59539X	\N	2017-07-25 10:45:11	\N	44303	\N
46657	1962-12-06 00:00:00	VEME	\N	1967-04-02 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	59539X	\N	2017-07-25 10:45:11	\N	44304	710
46658	1967-04-03 00:00:00	VEME	\N	1968-05-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	59539X	\N	2017-07-25 10:45:11	\N	44305	710
46659	1968-07-11 00:00:00	VEME	\N	1973-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	59539X	\N	2017-07-25 10:45:11	\N	44306	710
46660	1973-04-03 00:00:00	VEME	\N	1974-06-28 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	59539X	\N	2017-07-25 10:45:11	\N	44307	710
46661	1986-04-02 00:00:00	VEME	\N	1986-09-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	59539X	\N	2017-07-25 10:45:12	\N	44310	710
46662	1978-04-03 00:00:00	VEME	\N	1981-05-22 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	59539X	\N	2017-07-25 10:45:12	\N	44308	710
46670	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	04037F	\N	2017-07-25 10:45:12	\N	44310	824
46671	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	04037F	\N	2017-07-25 10:45:12	\N	44312	824
46672	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	04037F	\N	2017-07-25 10:45:12	\N	44311	824
46673	1997-06-01 00:00:00	VEME	\N	2002-06-18 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	04037F	\N	2017-07-25 10:45:12	\N	44313	824
46685	1973-04-02 00:00:00	VEME	\N	1978-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	06006G	\N	2017-07-25 10:45:13	\N	44307	1026
46686	1981-07-02 00:00:00	VEME	\N	1985-12-16 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	06006G	\N	2017-07-25 10:45:13	\N	44309	1026
46687	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	06006G	\N	2017-07-25 10:45:13	\N	44310	1026
46688	1988-06-06 00:00:00	VEME	\N	1992-05-04 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	06006G	\N	2017-07-25 10:45:13	\N	44311	1026
46689	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	06006G	\N	2017-07-25 10:45:13	\N	44312	220
46690	1997-06-01 00:00:00	VEME	\N	1997-07-04 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	06006G	\N	2017-07-25 10:45:13	\N	44313	220
46692	1981-07-02 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98034T	\N	2017-07-25 10:45:13	\N	44309	300
46693	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98034T	\N	2017-07-25 10:45:13	\N	44310	300
46694	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98034T	\N	2017-07-25 10:45:13	\N	44311	300
46700	2002-06-19 00:00:00	VEME	\N	2007-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95041E	\N	2017-07-25 10:45:13	\N	230434	700
46701	2007-06-20 00:00:00	VEME	\N	2008-04-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95041E	\N	2017-07-25 10:45:13	2017-08-10 10:56:48	384266	700
46702	2010-08-05 00:00:00	VEME	\N	2012-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95041E	\N	2017-07-25 10:45:13	2017-08-10 10:56:48	384266	700
46781	1967-04-03 00:00:00	VEME	\N	1968-05-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01032M	\N	2017-07-25 10:45:16	\N	44305	1004
46782	1973-04-02 00:00:00	VEME	\N	1978-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01032M	\N	2017-07-25 10:45:16	\N	44307	640
46783	1981-07-02 00:00:00	VEME	\N	1981-07-23 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01032M	\N	2017-07-25 10:45:16	\N	44309	640
46784	1978-04-03 00:00:00	VEME	\N	1981-05-22 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01032M	\N	2017-07-25 10:45:16	\N	44308	640
46785	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01032M	\N	2017-07-25 10:45:16	\N	44310	640
46786	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01032M	\N	2017-07-25 10:45:16	\N	44311	640
46787	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01032M	\N	2017-07-25 10:45:16	\N	44312	640
46788	1997-06-01 00:00:00	VEME	\N	2001-09-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01032M	\N	2017-07-25 10:45:16	\N	44313	640
46793	1981-07-25 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11112D	\N	2017-07-25 10:45:17	\N	44309	640
46810	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95042F	\N	2017-07-25 10:45:17	\N	44310	828
46811	1988-06-13 00:00:00	VEME	\N	1992-04-04 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95042F	\N	2017-07-25 10:45:17	\N	44311	828
46858	1993-05-02 00:00:00	VEME	\N	1995-05-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95030B	\N	2017-07-25 10:45:18	\N	44312	710
46864	1981-07-02 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	86025D	\N	2017-07-25 10:45:18	\N	44309	615
46873	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01026P	\N	2017-07-25 10:45:19	\N	44312	510
46874	1997-06-01 00:00:00	VEME	\N	2001-09-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01026P	\N	2017-07-25 10:45:19	\N	44313	510
46910	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95031C	\N	2017-07-25 10:45:19	\N	44311	830
46911	1993-04-02 00:00:00	VEME	\N	1995-09-24 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95031C	\N	2017-07-25 10:45:19	2017-08-10 10:56:52	44312	830
46928	1978-04-02 00:00:00	VEME	\N	1980-09-28 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000197	\N	2017-07-25 10:45:20	\N	44308	250
46929	1981-07-02 00:00:00	VEME	\N	1983-09-26 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	58818X	\N	2017-07-25 10:45:20	\N	44309	460
46930	1958-12-09 00:00:00	VEME	\N	1962-10-04 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	58818X	\N	2017-07-25 10:45:20	\N	44303	\N
46931	1962-12-06 00:00:00	VEME	\N	1967-04-02 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	58818X	\N	2017-07-25 10:45:20	\N	44304	460
46932	1967-04-03 00:00:00	VEME	\N	1968-05-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	58818X	\N	2017-07-25 10:45:20	\N	44305	460
46933	1968-07-11 00:00:00	VEME	\N	1973-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	58818X	\N	2017-07-25 10:45:20	\N	44306	460
46934	1973-04-02 00:00:00	VEME	\N	1978-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	58818X	\N	2017-07-25 10:45:20	\N	44307	460
46935	1978-04-03 00:00:00	VEME	\N	1981-05-22 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	58818X	\N	2017-07-25 10:45:20	\N	44308	460
46992	1997-06-01 00:00:00	VEME	\N	2002-06-18 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	89033R	\N	2017-07-25 10:45:21	\N	44313	220
46999	1988-06-13 00:00:00	VEME	\N	1992-05-02 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11077T	\N	2017-07-25 10:45:22	\N	44311	265
47031	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95044H	\N	2017-07-25 10:45:23	\N	44311	\N
47042	1986-04-02 00:00:00	VEME	\N	1986-04-02 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01048V	\N	2017-07-25 10:45:23	\N	44310	550
47043	1978-04-03 00:00:00	VEME	\N	1981-05-22 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01048V	\N	2017-07-25 10:45:23	\N	44308	550
47044	1993-04-02 00:00:00	VEME	\N	1993-05-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01048V	\N	2017-07-25 10:45:23	\N	44312	550
47045	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01048V	\N	2017-07-25 10:45:23	\N	44311	550
47052	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11106F	\N	2017-07-25 10:45:23	\N	44311	410
47082	1978-04-02 00:00:00	VEME	\N	1980-09-28 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	80027E	\N	2017-07-25 10:45:25	\N	44308	330
47083	1981-07-02 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95046K	\N	2017-07-25 10:45:25	\N	44309	775
47084	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95046K	\N	2017-07-25 10:45:25	\N	44310	775
47085	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95046K	\N	2017-07-25 10:45:25	\N	44311	775
47094	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	14251Q	\N	2017-07-25 10:45:25	\N	44312	30
47118	1978-04-03 00:00:00	VEME	\N	1980-09-28 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	80028F	\N	2017-07-25 10:45:26	\N	44308	240
47122	1958-12-09 00:00:00	VEME	\N	1962-06-16 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	59715V	\N	2017-07-25 10:45:26	\N	44303	\N
47123	1962-12-06 00:00:00	VEME	\N	1963-01-07 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	59715V	\N	2017-07-25 10:45:26	\N	44304	560
47124	1967-04-03 00:00:00	VEME	\N	1967-05-07 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	59715V	\N	2017-07-25 10:45:26	\N	44305	560
47125	1968-07-11 00:00:00	VEME	\N	1968-08-12 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	59715V	\N	2017-07-25 10:45:26	\N	44306	560
47126	1973-04-02 00:00:00	VEME	\N	1973-05-05 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	59715V	\N	2017-07-25 10:45:26	\N	44307	560
47127	1981-07-02 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	59715V	\N	2017-07-25 10:45:27	\N	44309	560
47128	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	59715V	\N	2017-07-25 10:45:27	\N	44310	560
47129	1988-06-06 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	59715V	\N	2017-07-25 10:45:27	\N	44311	560
47130	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	59715V	\N	2017-07-25 10:45:27	\N	44312	560
47153	1981-07-02 00:00:00	VEME	\N	1984-04-25 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000498	\N	2017-07-25 10:45:27	\N	44309	615
47161	2000-04-28 00:00:00	VEME	\N	2002-06-18 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	14001X	\N	2017-07-25 10:45:27	\N	44313	760
47196	1997-06-01 00:00:00	VEME	\N	2002-06-18 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	04096S	\N	2017-07-25 10:45:28	\N	44313	\N
47231	1981-07-25 00:00:00	VEME	\N	1986-03-16 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95003X	\N	2017-07-25 10:45:29	\N	44309	760
47232	1978-04-03 00:00:00	VEME	\N	1981-05-22 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01060R	\N	2017-07-25 10:45:29	\N	44308	570
47233	1981-07-02 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01060R	\N	2017-07-25 10:45:29	\N	44309	570
47234	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01060R	\N	2017-07-25 10:45:29	\N	44310	570
47235	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01060R	\N	2017-07-25 10:45:29	\N	44311	570
47236	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01060R	\N	2017-07-25 10:45:29	\N	44312	570
47237	1997-06-01 00:00:00	VEME	\N	1997-12-16 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01060R	\N	2017-07-25 10:45:29	\N	44313	570
47279	1978-04-03 00:00:00	VEME	\N	1981-05-22 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	92037V	\N	2017-07-25 10:45:30	\N	44308	590
47280	1973-04-02 00:00:00	VEME	\N	1978-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	92037V	\N	2017-07-25 10:45:30	\N	44307	590
47281	1981-07-02 00:00:00	VEME	\N	1981-07-22 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	92037V	\N	2017-07-25 10:45:30	\N	44309	590
47282	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	92037V	\N	2017-07-25 10:45:30	\N	44310	590
47283	1988-06-13 00:00:00	VEME	\N	1992-10-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	92037V	\N	2017-07-25 10:45:30	\N	44311	590
47319	2017-06-21 00:00:00	VEME	\N	2022-06-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	86039K	\N	2017-07-25 10:45:31	\N	717460	130
47336	1993-05-24 00:00:00	VEME	\N	1995-09-24 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95049N	\N	2017-07-25 10:45:32	\N	44312	690
47337	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	59717X	\N	2017-07-25 10:45:32	\N	44311	60
46180	1981-07-02 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	89029V	\N	2017-07-25 10:44:58	\N	44309	130
46181	1978-04-03 00:00:00	VEME	\N	1981-05-22 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	89029V	\N	2017-07-25 10:44:58	\N	44308	130
46182	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	89029V	\N	2017-07-25 10:44:58	\N	44310	130
46183	1988-06-13 00:00:00	VEME	\N	1989-10-02 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	89029V	\N	2017-07-25 10:44:58	\N	44311	130
46200	1993-05-02 00:00:00	VEME	\N	1995-06-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	04072J	\N	2017-07-25 10:44:58	\N	44312	615
46201	2007-06-20 00:00:00	VEME	\N	2012-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	04072J	\N	2017-07-25 10:44:58	\N	384266	615
46202	2012-06-20 00:00:00	VEME	\N	2017-06-20 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	04072J	\N	2017-07-25 10:44:58	\N	644420	615
46206	1973-04-02 00:00:00	VEME	\N	1978-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	92024Q	\N	2017-07-25 10:44:58	\N	44307	610
46207	1981-07-02 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	92024Q	\N	2017-07-25 10:44:58	\N	44309	610
46208	1978-04-03 00:00:00	VEME	\N	1981-05-22 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	92024Q	\N	2017-07-25 10:44:58	\N	44308	610
46209	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	92024Q	\N	2017-07-25 10:44:58	\N	44310	610
46210	1988-06-06 00:00:00	VEME	\N	1992-10-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	92024Q	\N	2017-07-25 10:44:58	\N	44311	610
46217	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	59230D	\N	2017-07-25 10:44:59	\N	44312	590
46262	2002-06-19 00:00:00	VEME	\N	2007-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11049P	\N	2017-07-25 10:45:00	\N	230434	570
46263	2007-06-20 00:00:00	VEME	\N	2011-09-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11049P	\N	2017-07-25 10:45:00	\N	384266	570
46264	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11049P	\N	2017-07-25 10:45:00	2017-08-11 11:33:15	44312	570
46296	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95027G	\N	2017-07-25 10:45:00	\N	44310	265
46297	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95027G	\N	2017-07-25 10:45:01	\N	44311	265
46298	1993-04-02 00:00:00	VEME	\N	1995-09-24 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95027G	\N	2017-07-25 10:45:01	\N	44312	265
45133	1998-09-27 00:00:00	VEME	\N	2002-06-18 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	15197G	\N	2017-07-25 10:44:25	\N	44313	590
45140	1968-07-11 00:00:00	VEME	\N	1971-12-04 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	58943C	\N	2017-07-25 10:44:25	\N	44306	50
45145	1988-07-29 00:00:00	VEME	\N	1991-08-09 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	92019T	\N	2017-07-25 10:44:26	\N	44311	440
45158	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01027Q	\N	2017-07-25 10:44:26	\N	44311	450
45159	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01027Q	\N	2017-07-25 10:44:26	\N	44312	450
45160	1997-06-01 00:00:00	VEME	\N	2001-09-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01027Q	\N	2017-07-25 10:44:26	\N	44313	450
45165	1973-04-02 00:00:00	VEME	\N	1977-05-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95026F	\N	2017-07-25 10:44:27	\N	44307	615
45166	1967-04-03 00:00:00	VEME	\N	1968-05-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95026F	\N	2017-07-25 10:44:27	\N	44305	1029
45167	1968-07-11 00:00:00	VEME	\N	1973-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95026F	\N	2017-07-25 10:44:27	\N	44306	615
45168	1982-01-17 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95026F	\N	2017-07-25 10:44:27	\N	44309	615
45169	1978-04-03 00:00:00	VEME	\N	1978-05-06 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95026F	\N	2017-07-25 10:44:27	\N	44308	615
45170	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95026F	\N	2017-07-25 10:44:27	\N	44310	615
45171	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95026F	\N	2017-07-25 10:44:27	\N	44311	615
45229	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	14167V	\N	2017-07-25 10:44:29	\N	44311	720
45230	1997-06-01 00:00:00	VEME	\N	2002-06-18 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	14167V	\N	2017-07-25 10:44:29	\N	44313	720
45231	1993-05-03 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01051Q	\N	2017-07-25 10:44:29	\N	44312	580
45232	1997-06-01 00:00:00	VEME	\N	2001-09-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01051Q	\N	2017-07-25 10:44:29	\N	44313	580
45258	1997-06-01 00:00:00	VEME	\N	2002-06-18 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11018G	\N	2017-07-25 10:44:29	\N	44313	660
45278	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	14175V	\N	2017-07-25 10:44:30	\N	44312	730
45279	1997-06-01 00:00:00	VEME	\N	2002-06-18 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	14175V	\N	2017-07-25 10:44:30	\N	44313	730
45280	2002-06-19 00:00:00	VEME	\N	2007-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	14175V	\N	2017-07-25 10:44:30	2017-08-10 10:56:23	230434	730
45281	2007-06-20 00:00:00	VEME	\N	2012-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	14175V	\N	2017-07-25 10:44:30	2017-08-10 10:56:23	384266	730
45309	1977-01-11 00:00:00	VEME	\N	1978-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98014P	\N	2017-07-25 10:44:30	\N	44307	170
45310	1981-07-02 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98014P	\N	2017-07-25 10:44:30	\N	44309	170
45311	1978-04-03 00:00:00	VEME	\N	1981-05-22 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98014P	\N	2017-07-25 10:44:30	\N	44308	170
45312	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98014P	\N	2017-07-25 10:44:30	\N	44310	170
45313	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98014P	\N	2017-07-25 10:44:30	\N	44312	170
45314	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98014P	\N	2017-07-25 10:44:30	\N	44311	170
45340	1973-04-03 00:00:00	VEME	\N	1973-05-05 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	89032Q	\N	2017-07-25 10:44:31	2017-08-10 03:42:53	44307	240
45341	1974-10-06 00:00:00	VEME	\N	1978-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	89032Q	\N	2017-07-25 10:44:31	2017-08-10 03:42:53	44307	240
45342	1962-12-06 00:00:00	VEME	\N	1967-04-02 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	89032Q	\N	2017-07-25 10:44:31	\N	44304	240
45343	1967-04-02 00:00:00	VEME	\N	1967-05-07 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	89032Q	\N	2017-07-25 10:44:31	\N	44305	240
45344	1968-07-11 00:00:00	VEME	\N	1968-08-12 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	89032Q	\N	2017-07-25 10:44:31	\N	44306	240
45345	1978-04-03 00:00:00	VEME	\N	1981-05-22 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	89032Q	\N	2017-07-25 10:44:31	\N	44308	240
45346	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	89032Q	\N	2017-07-25 10:44:31	\N	44310	240
45419	1981-07-02 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	86031B	\N	2017-07-25 10:44:33	\N	44309	690
45445	1981-07-02 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000310	\N	2017-07-25 10:44:35	\N	44309	615
45461	1993-05-02 00:00:00	VEME	\N	1995-07-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95038K	\N	2017-07-25 10:44:35	\N	44312	740
45484	1981-07-02 00:00:00	VEME	\N	1981-07-23 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	08027V	\N	2017-07-25 10:44:36	\N	44309	350
45485	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	08027V	\N	2017-07-25 10:44:36	\N	44310	350
45486	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	08027V	\N	2017-07-25 10:44:36	\N	44311	350
45487	1997-06-01 00:00:00	VEME	\N	2002-06-18 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	08027V	\N	2017-07-25 10:44:36	\N	44313	350
45545	1997-06-01 00:00:00	VEME	\N	2002-06-18 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11061K	\N	2017-07-25 10:44:38	\N	44313	620
45546	2002-06-19 00:00:00	VEME	\N	2007-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11061K	\N	2017-07-25 10:44:38	\N	230434	620
45547	2007-06-20 00:00:00	VEME	\N	2011-09-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11061K	\N	2017-07-25 10:44:38	2017-08-10 10:56:28	384266	620
45575	1997-06-01 00:00:00	VEME	\N	1999-08-29 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11089X	\N	2017-07-25 10:44:39	\N	44313	828
45576	2002-06-19 00:00:00	VEME	\N	2007-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	15447F	\N	2017-07-25 10:44:39	\N	230434	830
45577	2007-06-20 00:00:00	VEME	\N	2012-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	15447F	\N	2017-07-25 10:44:39	\N	384266	830
45578	2012-06-20 00:00:00	VEME	\N	2017-06-20 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	15447F	\N	2017-07-25 10:44:39	\N	644420	830
45589	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000599	\N	2017-07-25 10:44:39	\N	44311	824
45590	1993-04-02 00:00:00	VEME	\N	1993-05-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000599	\N	2017-07-25 10:44:39	2017-08-10 03:42:58	44312	824
45591	1995-06-25 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000599	\N	2017-07-25 10:44:39	2017-08-10 03:42:58	44312	824
45592	1997-06-01 00:00:00	VEME	\N	2002-06-18 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000599	\N	2017-07-25 10:44:39	\N	44313	824
52568	2022-06-22 00:00:00	VEME	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	12039E	\N	\N	\N	791932	120
45657	2002-06-19 00:00:00	VEME	\N	2007-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11015D	\N	2017-07-25 10:44:41	\N	230434	580
45658	1997-06-01 00:00:00	VEME	\N	2002-06-18 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11015D	\N	2017-07-25 10:44:41	\N	44313	580
45659	2007-06-20 00:00:00	VEME	\N	2011-09-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11015D	\N	2017-07-25 10:44:41	\N	384266	580
45743	1976-09-28 00:00:00	VEME	\N	1978-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	90003B	\N	2017-07-25 10:44:44	\N	44307	330
45744	1978-05-06 00:00:00	VEME	\N	1981-05-22 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	90003B	\N	2017-07-25 10:44:44	\N	44308	330
45745	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	90003B	\N	2017-07-25 10:44:44	\N	44310	330
45835	1988-07-29 00:00:00	VEME	\N	1992-10-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	92016Q	\N	2017-07-25 10:44:47	\N	44311	580
45839	1978-04-03 00:00:00	VEME	\N	1979-08-04 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000572	\N	2017-07-25 10:44:47	\N	44308	840
45840	1986-04-02 00:00:00	VEME	\N	1986-09-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000572	\N	2017-07-25 10:44:47	\N	44310	840
45854	1981-07-02 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95018F	\N	2017-07-25 10:44:48	\N	44309	615
45855	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95018F	\N	2017-07-25 10:44:48	\N	44310	615
45856	1988-06-13 00:00:00	VEME	\N	1993-03-25 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95018F	\N	2017-07-25 10:44:48	\N	44311	615
45857	2002-06-19 00:00:00	VEME	\N	2007-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95018F	\N	2017-07-25 10:44:48	\N	230434	615
45858	1999-12-06 00:00:00	VEME	\N	2002-06-18 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95018F	\N	2017-07-25 10:44:48	\N	44313	615
45899	1973-04-02 00:00:00	VEME	\N	1978-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	02053W	\N	2017-07-25 10:44:49	\N	44307	125
45900	1981-07-02 00:00:00	VEME	\N	1981-07-23 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	02053W	\N	2017-07-25 10:44:49	\N	44309	125
45901	1978-04-03 00:00:00	VEME	\N	1981-05-22 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	02053W	\N	2017-07-25 10:44:49	\N	44308	125
45902	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	02053W	\N	2017-07-25 10:44:49	\N	44310	125
45903	1988-06-06 00:00:00	VEME	\N	1988-07-28 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	02053W	\N	2017-07-25 10:44:49	2017-08-10 03:43:04	44311	125
45904	1991-06-10 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	02053W	\N	2017-07-25 10:44:49	2017-08-10 03:43:04	44311	125
45905	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	02053W	\N	2017-07-25 10:44:49	\N	44312	125
45906	1997-06-01 00:00:00	VEME	\N	1997-07-04 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	02053W	\N	2017-07-25 10:44:49	2017-08-10 10:56:35	44313	125
45907	2000-10-22 00:00:00	VEME	\N	2002-06-18 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	02053W	\N	2017-07-25 10:44:49	2017-08-10 10:56:35	44313	125
45931	1995-09-24 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11107G	\N	2017-07-25 10:44:50	\N	44312	370
45932	1997-06-01 00:00:00	VEME	\N	2002-06-18 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11107G	\N	2017-07-25 10:44:50	\N	44313	370
45934	1981-07-02 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	02009S	\N	2017-07-25 10:44:50	\N	44309	720
45935	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	02009S	\N	2017-07-25 10:44:50	\N	44310	720
45936	1988-06-06 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	02009S	\N	2017-07-25 10:44:50	\N	44311	720
45937	1993-04-02 00:00:00	VEME	\N	1993-05-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	02009S	\N	2017-07-25 10:44:50	\N	44312	720
45938	2002-06-19 00:00:00	VEME	\N	2002-07-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	02009S	\N	2017-07-25 10:44:50	\N	230434	720
45939	1997-06-01 00:00:00	VEME	\N	2002-06-07 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	02009S	\N	2017-07-25 10:44:50	\N	44313	720
45940	2007-06-20 00:00:00	VEME	\N	2007-07-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	02009S	\N	2017-07-25 10:44:50	\N	384266	720
45941	2012-06-20 00:00:00	VEME	\N	2017-06-20 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	02009S	\N	2017-07-25 10:44:50	\N	644420	615
45960	1978-04-03 00:00:00	VEME	\N	1981-05-22 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98052V	\N	2017-07-25 10:44:51	\N	44308	\N
45961	1981-07-02 00:00:00	VEME	\N	1982-06-17 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98052V	\N	2017-07-25 10:44:51	\N	44309	\N
45962	1986-04-02 00:00:00	VEME	\N	1986-04-02 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98052V	\N	2017-07-25 10:44:51	\N	44310	\N
45963	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98052V	\N	2017-07-25 10:44:51	\N	44312	\N
45990	1981-07-22 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000449	\N	2017-07-25 10:44:51	\N	44309	760
45991	1986-09-30 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000449	\N	2017-07-25 10:44:51	\N	44310	760
46026	1988-07-29 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95033E	\N	2017-07-25 10:44:52	\N	44311	890
46057	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98047Y	\N	2017-07-25 10:44:53	\N	44310	350
46058	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98047Y	\N	2017-07-25 10:44:53	\N	44311	350
46059	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98047Y	\N	2017-07-25 10:44:53	\N	44312	350
46062	1996-11-27 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11010L	\N	2017-07-25 10:44:54	\N	44312	\N
46063	2002-06-19 00:00:00	VEME	\N	2007-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11010L	\N	2017-07-25 10:44:54	\N	230434	\N
46064	1997-06-01 00:00:00	VEME	\N	2002-06-18 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11010L	\N	2017-07-25 10:44:54	\N	44313	\N
46065	2007-06-20 00:00:00	VEME	\N	2011-09-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11010L	\N	2017-07-25 10:44:54	\N	384266	\N
46082	1988-07-29 00:00:00	VEME	\N	1988-11-08 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000533	\N	2017-07-25 10:44:54	\N	44311	775
46100	1978-04-03 00:00:00	VEME	\N	1978-05-05 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000455	\N	2017-07-25 10:44:55	\N	44308	100
46101	1968-07-11 00:00:00	VEME	\N	1968-08-12 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000455	\N	2017-07-25 10:44:55	\N	44306	100
46102	1973-04-02 00:00:00	VEME	\N	1973-05-05 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000455	\N	2017-07-25 10:44:55	\N	44307	100
46103	1981-07-02 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000455	\N	2017-07-25 10:44:55	\N	44309	100
46104	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000455	\N	2017-07-25 10:44:55	\N	44310	100
46105	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000455	\N	2017-07-25 10:44:55	\N	44311	100
46106	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000455	\N	2017-07-25 10:44:55	\N	44312	100
46107	1997-06-01 00:00:00	VEME	\N	2002-06-18 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000455	\N	2017-07-25 10:44:55	\N	44313	100
46140	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98041S	\N	2017-07-25 10:44:56	\N	44311	140
46141	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98041S	\N	2017-07-25 10:44:57	\N	44312	140
49703	2017-03-22 00:00:00	VEME	\N	2017-03-29 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	17779H	\N	2017-07-25 10:46:48	2018-01-23 09:26:47	644420	400
49759	2017-06-21 00:00:00	VEME	\N	2022-06-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	09011R	\N	2017-07-25 10:46:50	\N	717460	890
49773	2017-06-21 00:00:00	VEME	\N	2020-06-23 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11032E	\N	2017-07-25 10:46:50	2017-08-10 10:57:44	717460	824
49788	2012-06-20 00:00:00	VEME	\N	2012-07-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	12028B	\N	2017-07-25 10:46:51	2017-08-08 03:44:40	644420	130
49789	2014-05-03 00:00:00	VEME	\N	2017-06-20 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	12028B	\N	2017-07-25 10:46:51	2017-08-08 03:44:40	644420	130
49799	2010-06-11 00:00:00	VEME	\N	2011-09-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11090Q	\N	2017-07-25 10:46:51	\N	384266	895
49808	2007-06-20 00:00:00	VEME	\N	2012-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	21032X	\N	2017-07-25 10:46:52	2023-11-20 15:31:50	384266	\N
49809	2012-06-20 00:00:00	VEME	\N	2014-05-09 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	21032X	\N	2017-07-25 10:46:52	2023-11-20 15:31:50	644420	\N
49810	2014-06-30 00:00:00	VEME	\N	2014-07-29 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	21032X	\N	2017-07-25 10:46:52	2023-11-20 15:31:50	644420	\N
49811	2017-06-21 00:00:00	VEME	\N	2017-07-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	21032X	\N	2017-07-25 10:46:52	2023-11-20 15:31:50	717460	\N
48703	1978-04-02 00:00:00	VEME	\N	1980-09-28 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	80045G	\N	2017-07-25 10:46:17	\N	44308	70
48704	1981-07-02 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	08061X	\N	2017-07-25 10:46:17	\N	44309	210
48705	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	08061X	\N	2017-07-25 10:46:17	\N	44310	210
48706	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	08061X	\N	2017-07-25 10:46:17	\N	44311	210
48707	1997-06-01 00:00:00	VEME	\N	2000-11-18 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	08061X	\N	2017-07-25 10:46:17	\N	44313	210
48728	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95053J	\N	2017-07-25 10:46:18	\N	44310	265
48729	1993-04-02 00:00:00	VEME	\N	1995-09-24 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95053J	\N	2017-07-25 10:46:18	\N	44312	265
48730	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95053J	\N	2017-07-25 10:46:18	\N	44311	265
48736	1981-07-02 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	59579G	\N	2017-07-25 10:46:18	\N	44309	\N
48737	1986-04-02 00:00:00	VEME	\N	1986-10-02 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	59579G	\N	2017-07-25 10:46:18	\N	44310	\N
48776	1997-06-01 00:00:00	VEME	\N	2002-06-18 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	14028W	\N	2017-07-25 10:46:19	2017-08-10 10:57:24	44313	870
48777	2002-06-19 00:00:00	VEME	\N	2007-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	14028W	\N	2017-07-25 10:46:19	2017-08-10 10:57:24	230434	870
48778	2007-06-20 00:00:00	VEME	\N	2012-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	14028W	\N	2017-07-25 10:46:19	2017-08-10 03:43:54	384266	870
48816	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98040R	\N	2017-07-25 10:46:20	\N	44310	60
48817	1997-06-01 00:00:00	VEME	\N	1998-09-27 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98040R	\N	2017-07-25 10:46:20	\N	44313	60
48818	1978-04-03 00:00:00	VEME	\N	1978-05-05 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95054K	\N	2017-07-25 10:46:20	\N	44308	770
48819	1958-12-09 00:00:00	VEME	\N	1962-05-15 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95054K	\N	2017-07-25 10:46:20	\N	44303	\N
48820	1962-12-06 00:00:00	VEME	\N	1963-01-08 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95054K	\N	2017-07-25 10:46:20	\N	44304	770
48821	1967-04-03 00:00:00	VEME	\N	1967-05-07 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95054K	\N	2017-07-25 10:46:20	\N	44305	770
48822	1968-07-11 00:00:00	VEME	\N	1973-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95054K	\N	2017-07-25 10:46:20	\N	44306	770
48823	1973-04-02 00:00:00	VEME	\N	1973-05-05 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95054K	\N	2017-07-25 10:46:20	\N	44307	770
48824	1982-01-18 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95054K	\N	2017-07-25 10:46:20	\N	44309	770
48825	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95054K	\N	2017-07-25 10:46:20	\N	44310	770
48826	1993-04-02 00:00:00	VEME	\N	1995-09-24 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95054K	\N	2017-07-25 10:46:20	\N	44312	770
48827	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95054K	\N	2017-07-25 10:46:20	\N	44311	770
48831	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95055L	\N	2017-07-25 10:46:20	\N	44311	870
48849	2002-06-19 00:00:00	VEME	\N	2007-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	14135M	\N	2017-07-25 10:46:21	\N	230434	700
48850	2007-06-20 00:00:00	VEME	\N	2012-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	14135M	\N	2017-07-25 10:46:21	\N	384266	700
48913	2002-06-19 00:00:00	VEME	\N	2007-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	17229F	\N	2017-07-25 10:46:24	\N	230434	800
48914	2007-06-20 00:00:00	VEME	\N	2012-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	17229F	\N	2017-07-25 10:46:24	\N	384266	800
48915	2012-06-20 00:00:00	VEME	\N	2017-06-20 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	17229F	\N	2017-07-25 10:46:24	\N	644420	800
48916	2017-06-21 00:00:00	VEME	\N	2020-09-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	17229F	\N	2017-07-25 10:46:24	\N	717460	800
48974	2002-06-19 00:00:00	VEME	\N	2007-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	08022Q	\N	2017-07-25 10:46:26	\N	230434	330
48975	2007-06-20 00:00:00	VEME	\N	2008-10-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	08022Q	\N	2017-07-25 10:46:26	\N	384266	330
49062	2004-05-01 00:00:00	VEME	\N	2007-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	14026U	\N	2017-07-25 10:46:28	\N	230434	20
49063	2007-07-20 00:00:00	VEME	\N	2009-02-15 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	14026U	\N	2017-07-25 10:46:28	2017-08-10 10:57:30	384266	20
49064	2010-12-15 00:00:00	VEME	\N	2012-06-16 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	14026U	\N	2017-07-25 10:46:28	2017-08-10 10:57:30	384266	20
49085	2002-06-19 00:00:00	VEME	\N	2007-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	17367Q	\N	2017-07-25 10:46:29	\N	230434	10
49086	2007-06-20 00:00:00	VEME	\N	2012-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	17367Q	\N	2017-07-25 10:46:29	\N	384266	10
49087	2012-06-20 00:00:00	VEME	\N	2016-03-10 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	17367Q	\N	2017-07-25 10:46:29	\N	644420	10
49133	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98012M	\N	2017-07-25 10:46:31	\N	44311	1026
49178	1997-06-01 00:00:00	VEME	\N	2002-06-18 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11041F	\N	2017-07-25 10:46:32	\N	44313	380
49179	2002-06-19 00:00:00	VEME	\N	2007-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11041F	\N	2017-07-25 10:46:32	\N	230434	380
49180	2007-06-20 00:00:00	VEME	\N	2011-09-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11041F	\N	2017-07-25 10:46:33	\N	384266	380
49208	1986-04-02 00:00:00	VEME	\N	1987-10-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	96003C	\N	2017-07-25 10:46:33	\N	44310	\N
49209	1993-04-02 00:00:00	VEME	\N	1996-04-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	96003C	\N	2017-07-25 10:46:33	\N	44312	\N
49219	1978-04-02 00:00:00	VEME	\N	1980-09-28 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	58913V	\N	2017-07-25 10:46:34	\N	44308	10
49223	2007-06-20 00:00:00	VEME	\N	2012-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	89043T	\N	2017-07-25 10:46:34	\N	384266	340
49256	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01010F	\N	2017-07-25 10:46:35	\N	44310	\N
49257	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01010F	\N	2017-07-25 10:46:35	\N	44312	\N
49258	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01010F	\N	2017-07-25 10:46:35	\N	44311	\N
49287	1997-06-01 00:00:00	VEME	\N	1997-07-04 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	04082L	\N	2017-07-25 10:46:35	\N	44313	390
49299	1981-07-02 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	59308J	\N	2017-07-25 10:46:35	\N	44309	620
49300	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	59308J	\N	2017-07-25 10:46:35	\N	44310	620
49301	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	59308J	\N	2017-07-25 10:46:35	\N	44311	620
52514	2022-06-22 00:00:00	VEME	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	09011R	\N	\N	\N	791932	890
49376	2000-03-20 00:00:00	VEME	\N	2002-06-18 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11059R	\N	2017-07-25 10:46:37	\N	44313	620
49377	2002-06-19 00:00:00	VEME	\N	2007-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11059R	\N	2017-07-25 10:46:37	\N	230434	620
49378	2007-06-20 00:00:00	VEME	\N	2011-09-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11059R	\N	2017-07-25 10:46:37	\N	384266	620
49379	2007-06-20 00:00:00	VEME	\N	2012-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	00002B	\N	2017-07-25 10:46:38	\N	384266	335
49444	2002-07-19 00:00:00	VEME	\N	2007-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	08048B	\N	2017-07-25 10:46:40	\N	230434	130
49446	2007-06-20 00:00:00	VEME	\N	2012-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	04068N	\N	2017-07-25 10:46:40	\N	384266	760
49447	2012-06-20 00:00:00	VEME	\N	2015-08-27 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	04068N	\N	2017-07-25 10:46:40	\N	644420	760
49458	2002-06-19 00:00:00	VEME	\N	2007-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	17583W	\N	2017-07-25 10:46:41	\N	230434	440
49459	2007-06-20 00:00:00	VEME	\N	2012-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	17583W	\N	2017-07-25 10:46:41	\N	384266	440
49460	2012-06-20 00:00:00	VEME	\N	2017-06-20 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	17583W	\N	2017-07-25 10:46:41	\N	644420	440
49461	2012-06-20 00:00:00	VEME	\N	2017-06-20 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	14299H	\N	2017-07-25 10:46:41	\N	644420	450
49462	2017-06-21 00:00:00	VEME	\N	2022-06-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	14299H	\N	2017-07-25 10:46:41	\N	717460	450
49465	2002-06-19 00:00:00	VEME	\N	2007-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	17589D	\N	2017-07-25 10:46:41	\N	230434	590
49466	2007-06-20 00:00:00	VEME	\N	2012-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	17589D	\N	2017-07-25 10:46:41	\N	384266	590
49467	2012-06-20 00:00:00	VEME	\N	2017-06-20 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	17589D	\N	2017-07-25 10:46:41	\N	644420	590
49478	2010-11-13 00:00:00	VEME	\N	2011-09-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11022C	\N	2017-07-25 10:46:41	\N	384266	\N
49521	2002-06-19 00:00:00	VEME	\N	2007-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	17637T	\N	2017-07-25 10:46:42	\N	230434	335
49522	2007-06-20 00:00:00	VEME	\N	2007-11-29 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	17637T	\N	2017-07-25 10:46:42	\N	384266	335
49532	2002-06-19 00:00:00	VEME	\N	2007-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	14211G	\N	2017-07-25 10:46:43	\N	230434	340
49533	2007-06-20 00:00:00	VEME	\N	2012-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	14211G	\N	2017-07-25 10:46:43	\N	384266	340
49571	2002-06-19 00:00:00	VEME	\N	2007-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	12016W	\N	2017-07-25 10:46:44	\N	230434	\N
49572	2007-06-20 00:00:00	VEME	\N	2012-06-16 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	12016W	\N	2017-07-25 10:46:44	\N	384266	\N
49573	2012-06-20 00:00:00	VEME	\N	2012-07-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	12016W	\N	2017-07-25 10:46:44	2017-08-10 03:44:10	644420	\N
49574	2014-05-03 00:00:00	VEME	\N	2017-06-20 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	12016W	\N	2017-07-25 10:46:44	2017-08-10 03:44:10	644420	\N
49601	2002-06-19 00:00:00	VEME	\N	2007-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11115U	\N	2017-07-25 10:46:45	2017-08-10 03:44:11	230434	600
49602	2007-06-20 00:00:00	VEME	\N	2011-10-28 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11115U	\N	2017-07-25 10:46:45	2017-08-10 10:57:40	384266	600
49603	2012-06-20 00:00:00	VEME	\N	2017-06-20 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11115U	\N	2017-07-25 10:46:45	\N	644420	600
49604	2012-06-17 00:00:00	VEME	\N	2012-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11115U	\N	2017-07-25 10:46:45	2017-08-09 03:44:26	384266	600
49651	2007-06-20 00:00:00	VEME	\N	2010-11-13 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	14017T	\N	2017-07-25 10:46:46	\N	384266	\N
48564	2002-06-19 00:00:00	VEME	\N	2007-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	17023S	\N	2017-07-25 10:46:12	\N	230434	810
48565	2007-06-20 00:00:00	VEME	\N	2012-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	17023S	\N	2017-07-25 10:46:12	\N	384266	810
48566	2012-06-20 00:00:00	VEME	\N	2017-06-20 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	17023S	\N	2017-07-25 10:46:12	\N	644420	810
48567	2017-06-21 00:00:00	VEME	\N	2020-09-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	17023S	\N	2017-07-25 10:46:12	\N	717460	810
48603	1981-07-02 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01028R	\N	2017-07-25 10:46:13	\N	44309	450
48604	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01028R	\N	2017-07-25 10:46:13	\N	44310	450
48605	1988-06-13 00:00:00	VEME	\N	1991-06-17 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01028R	\N	2017-07-25 10:46:13	\N	44311	450
48621	1997-06-01 00:00:00	VEME	\N	2000-04-27 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	04056J	\N	2017-07-25 10:46:14	\N	44313	895
48630	1978-04-03 00:00:00	VEME	\N	1981-05-22 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	89009R	\N	2017-07-25 10:46:15	\N	44308	280
48631	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	89009R	\N	2017-07-25 10:46:15	\N	44310	280
48632	1988-06-13 00:00:00	VEME	\N	1989-10-02 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	89009R	\N	2017-07-25 10:46:15	\N	44311	280
47590	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01019Q	\N	2017-07-25 10:45:40	\N	44312	380
47626	2008-02-04 00:00:00	VEME	\N	2012-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	93005R	\N	2017-07-25 10:45:41	\N	384266	335
47643	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	59307H	\N	2017-07-25 10:45:42	\N	44311	250
47663	1983-04-25 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	92043T	\N	2017-07-25 10:45:42	\N	44309	620
47679	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	04101V	\N	2017-07-25 10:45:43	\N	44310	130
47694	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01050P	\N	2017-07-25 10:45:44	\N	44312	470
47697	1968-07-11 00:00:00	VEME	\N	1973-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	89005M	\N	2017-07-25 10:45:44	\N	44306	80
47698	1973-04-02 00:00:00	VEME	\N	1977-05-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	89005M	\N	2017-07-25 10:45:44	\N	44307	80
47699	1978-04-03 00:00:00	VEME	\N	1981-05-22 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	89005M	\N	2017-07-25 10:45:44	\N	44308	80
47700	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	89005M	\N	2017-07-25 10:45:44	\N	44310	80
47724	1981-07-02 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95063L	\N	2017-07-25 10:45:46	\N	44309	828
47725	1978-04-03 00:00:00	VEME	\N	1981-05-22 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95063L	\N	2017-07-25 10:45:46	\N	44308	828
47726	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95063L	\N	2017-07-25 10:45:46	2017-08-10 03:43:36	44310	828
47727	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95063L	\N	2017-07-25 10:45:46	\N	44311	828
47739	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98039Y	\N	2017-07-25 10:45:46	\N	44312	160
47825	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95043G	\N	2017-07-25 10:45:49	\N	44311	\N
47849	1981-07-02 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	59542S	\N	2017-07-25 10:45:50	\N	44309	895
47923	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	16685X	\N	2017-07-25 10:45:52	\N	44312	560
47924	1997-06-01 00:00:00	VEME	\N	2002-06-18 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	16685X	\N	2017-07-25 10:45:52	\N	44313	560
47925	2002-06-19 00:00:00	VEME	\N	2007-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	16685X	\N	2017-07-25 10:45:52	\N	230434	560
47926	2007-06-20 00:00:00	VEME	\N	2012-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	16685X	\N	2017-07-25 10:45:52	\N	384266	560
47929	1973-04-02 00:00:00	VEME	\N	1978-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98051U	\N	2017-07-25 10:45:52	\N	44307	290
47930	1981-07-02 00:00:00	VEME	\N	1981-07-23 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98051U	\N	2017-07-25 10:45:52	2017-08-10 10:57:09	44309	290
47931	1983-05-09 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98051U	\N	2017-07-25 10:45:52	2017-08-10 10:57:09	44309	290
47932	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98051U	\N	2017-07-25 10:45:52	\N	44310	290
47933	1978-04-03 00:00:00	VEME	\N	1981-05-22 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98051U	\N	2017-07-25 10:45:52	\N	44308	290
47934	1988-06-06 00:00:00	VEME	\N	1988-07-28 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98051U	\N	2017-07-25 10:45:52	\N	44311	290
47935	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98051U	\N	2017-07-25 10:45:52	\N	44312	290
47936	1997-06-01 00:00:00	VEME	\N	1997-07-04 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98051U	\N	2017-07-25 10:45:52	\N	44313	290
47945	1997-07-05 00:00:00	VEME	\N	2001-02-12 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	04076N	\N	2017-07-25 10:45:53	\N	44313	828
47946	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	07025P	\N	2017-07-25 10:45:53	\N	44312	760
47947	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	07025P	\N	2017-07-25 10:45:53	\N	44311	760
47948	1997-06-01 00:00:00	VEME	\N	2002-06-18 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	07025P	\N	2017-07-25 10:45:53	\N	44313	760
47957	1973-04-02 00:00:00	VEME	\N	1974-06-28 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000442	\N	2017-07-25 10:45:53	\N	44307	760
47958	1986-04-02 00:00:00	VEME	\N	1986-09-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000442	\N	2017-07-25 10:45:53	\N	44310	760
47984	1973-04-02 00:00:00	VEME	\N	1977-05-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	92031P	\N	2017-07-25 10:45:54	\N	44307	590
47985	1978-04-03 00:00:00	VEME	\N	1978-05-06 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	92031P	\N	2017-07-25 10:45:54	\N	44308	590
47986	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	92031P	\N	2017-07-25 10:45:54	\N	44310	590
51774	1981-07-02 00:00:00	VEME	\N	1981-07-23 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	83008P	\N	\N	\N	44309	650
47994	1981-07-02 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	80024B	\N	2017-07-25 10:45:55	\N	44309	230
47995	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	80024B	\N	2017-07-25 10:45:55	\N	44310	230
47996	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	80024B	\N	2017-07-25 10:45:55	\N	44311	230
48021	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11100Y	\N	2017-07-25 10:45:56	\N	44312	610
48022	1997-06-01 00:00:00	VEME	\N	2002-06-18 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11100Y	\N	2017-07-25 10:45:56	\N	44313	610
48023	2002-06-19 00:00:00	VEME	\N	2007-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11100Y	\N	2017-07-25 10:45:56	\N	230434	610
48024	2007-06-20 00:00:00	VEME	\N	2011-09-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11100Y	\N	2017-07-25 10:45:56	\N	384266	610
48048	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98025S	\N	2017-07-25 10:45:57	\N	44312	180
48053	1981-07-02 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	89036U	\N	2017-07-25 10:45:57	\N	44309	130
48058	1968-07-11 00:00:00	VEME	\N	1971-10-08 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000307	\N	2017-07-25 10:45:57	\N	44306	260
48078	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98021N	\N	2017-07-25 10:45:58	\N	44312	330
48107	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98050T	\N	2017-07-25 10:45:58	\N	44310	270
48108	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98050T	\N	2017-07-25 10:45:58	2017-08-10 10:57:13	44312	270
48109	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98050T	\N	2017-07-25 10:45:58	\N	44311	270
48110	1997-06-01 00:00:00	VEME	\N	1998-09-27 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98050T	\N	2017-07-25 10:45:58	\N	44313	270
48157	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	16813M	\N	2017-07-25 10:46:00	\N	44312	590
48178	1978-04-03 00:00:00	VEME	\N	1981-05-22 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000639	\N	2017-07-25 10:46:00	\N	44308	430
48179	1981-07-02 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000639	\N	2017-07-25 10:46:00	\N	44309	430
48180	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000639	\N	2017-07-25 10:46:00	\N	44310	430
48181	1988-06-06 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000639	\N	2017-07-25 10:46:00	\N	44311	430
48182	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000639	\N	2017-07-25 10:46:00	2017-08-10 10:57:14	44312	430
48183	1997-06-01 00:00:00	VEME	\N	2002-06-18 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000639	\N	2017-07-25 10:46:00	\N	44313	430
48184	2002-06-19 00:00:00	VEME	\N	2007-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000639	\N	2017-07-25 10:46:00	2017-08-10 10:57:14	230434	430
48185	2007-06-20 00:00:00	VEME	\N	2012-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000639	\N	2017-07-25 10:46:00	\N	384266	430
48218	1986-04-02 00:00:00	VEME	\N	1986-10-02 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	74041P	\N	2017-07-25 10:46:02	\N	44310	630
48225	1981-07-02 00:00:00	VEME	\N	1981-07-23 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95060H	\N	2017-07-25 10:46:02	\N	44309	775
48231	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	77060F	\N	2017-07-25 10:46:02	\N	44311	730
48234	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98033S	\N	2017-07-25 10:46:02	\N	44312	320
51582	2018-04-23 00:00:00	VEME	\N	2021-09-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	19057M	\N	2018-04-26 03:44:45	\N	717460	\N
48258	1969-10-26 00:00:00	VEME	\N	1973-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95064M	\N	2017-07-25 10:46:03	\N	44306	895
48259	1981-07-02 00:00:00	VEME	\N	1981-07-23 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95064M	\N	2017-07-25 10:46:03	\N	44309	895
48260	1978-04-03 00:00:00	VEME	\N	1981-05-22 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95064M	\N	2017-07-25 10:46:03	\N	44308	895
48261	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95064M	\N	2017-07-25 10:46:03	\N	44310	895
48262	1988-06-13 00:00:00	VEME	\N	1988-07-23 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95064M	\N	2017-07-25 10:46:03	\N	44311	895
52460	2022-06-21 00:00:00	VEME	\N	2022-06-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	21032X	\N	\N	2023-11-20 15:31:50	717460	\N
48313	1997-06-01 00:00:00	VEME	\N	2002-06-18 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11046L	\N	2017-07-25 10:46:05	\N	44313	600
48332	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98007Q	\N	2017-07-25 10:46:06	\N	44312	190
48369	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11105E	\N	2017-07-25 10:46:07	\N	44311	630
48370	1997-06-01 00:00:00	VEME	\N	2002-06-18 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11105E	\N	2017-07-25 10:46:07	\N	44313	630
48371	2002-06-19 00:00:00	VEME	\N	2007-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11105E	\N	2017-07-25 10:46:07	\N	230434	630
48372	2007-06-20 00:00:00	VEME	\N	2011-09-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11105E	\N	2017-07-25 10:46:07	2017-08-10 10:57:17	384266	630
48489	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01054T	\N	2017-07-25 10:46:09	2017-08-10 10:57:19	44310	440
48490	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01054T	\N	2017-07-25 10:46:09	2017-08-10 10:57:19	44312	440
48491	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01054T	\N	2017-07-25 10:46:09	\N	44311	440
48508	2007-06-20 00:00:00	VEME	\N	2012-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	14111D	\N	2017-07-25 10:46:10	\N	384266	120
48509	2012-06-20 00:00:00	VEME	\N	2014-09-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	14111D	\N	2017-07-25 10:46:10	\N	644420	120
50777	1981-07-02 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	DEPUTE	86027F	\N	2017-08-18 12:16:34	\N	\N	\N
50778	1997-06-12 00:00:00	VEME	\N	2002-06-24 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	DEPUTE	86027F	\N	2017-08-18 12:16:58	\N	\N	\N
50779	2002-06-25 00:00:00	VEME	\N	2007-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	DEPUTE	86027F	\N	2017-08-18 12:17:14	\N	\N	\N
50780	2007-06-26 00:00:00	VEME	\N	2012-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	DEPUTE	86027F	\N	2017-08-18 12:17:34	\N	\N	\N
50781	2012-06-26 00:00:00	VEME	\N	2017-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	DEPUTE	86027F	\N	2017-08-18 12:17:52	\N	\N	\N
44611	1997-06-01 00:00:00	VEME	\N	2002-06-18 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	04053F	\N	2017-07-25 10:44:09	\N	44313	770
44625	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98048A	\N	2017-07-25 10:44:09	\N	44312	210
44626	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98048A	\N	2017-07-25 10:44:09	\N	44311	210
44627	1997-06-01 00:00:00	VEME	\N	1998-09-27 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	98048A	\N	2017-07-25 10:44:09	\N	44313	210
44979	1988-06-13 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11088W	\N	2017-07-25 10:44:20	\N	44311	828
44980	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11088W	\N	2017-07-25 10:44:20	\N	44312	828
44981	1997-06-01 00:00:00	VEME	\N	2002-06-18 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11088W	\N	2017-07-25 10:44:20	\N	44313	828
44982	2002-06-19 00:00:00	VEME	\N	2007-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11088W	\N	2017-07-25 10:44:20	\N	230434	828
44983	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11035H	\N	2017-07-25 10:44:20	\N	44310	590
44984	1988-06-13 00:00:00	VEME	\N	1988-07-28 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11035H	\N	2017-07-25 10:44:20	\N	44311	590
44985	2002-06-19 00:00:00	VEME	\N	2007-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11035H	\N	2017-07-25 10:44:20	\N	230434	590
44986	1997-06-01 00:00:00	VEME	\N	1998-07-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11035H	\N	2017-07-25 10:44:20	\N	44313	590
44978	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11088W	\N	2017-07-25 10:44:20	\N	44310	828
44987	2007-06-20 00:00:00	VEME	\N	2011-09-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11035H	\N	2017-07-25 10:44:20	\N	384266	590
44993	1981-07-02 00:00:00	VEME	\N	1981-07-23 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	59226H	\N	2017-07-25 10:44:20	\N	44309	620
44994	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	92017R	\N	2017-07-25 10:44:20	\N	44310	620
45021	1986-04-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95024D	\N	2017-07-25 10:44:21	\N	44310	775
45022	1993-04-02 00:00:00	VEME	\N	1995-09-24 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95024D	\N	2017-07-25 10:44:21	\N	44312	775
50762	1981-07-02 00:00:00	VEME	\N	1988-05-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01020H	\N	2017-08-11 16:47:04	\N	44310	380
44819	1993-05-02 00:00:00	VEME	\N	1995-07-17 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95016D	\N	2017-07-25 10:44:15	\N	44312	335
44874	1992-02-03 00:00:00	VEME	\N	1993-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	04008A	\N	2017-07-25 10:44:18	\N	44311	590
44875	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	04008A	\N	2017-07-25 10:44:18	\N	44312	590
44876	2002-06-19 00:00:00	VEME	\N	2004-04-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	04008A	\N	2017-07-25 10:44:18	2017-08-10 10:56:17	230434	590
44877	1997-06-01 00:00:00	VEME	\N	2002-06-18 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	04008A	\N	2017-07-25 10:44:18	\N	44313	590
44878	2005-09-19 00:00:00	VEME	\N	2007-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	04008A	\N	2017-07-25 10:44:18	2017-08-10 10:56:17	230434	590
44879	2007-06-20 00:00:00	VEME	\N	2010-04-23 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	04008A	\N	2017-07-25 10:44:18	2017-08-10 10:56:17	384266	590
44880	2010-12-14 00:00:00	VEME	\N	2012-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	04008A	\N	2017-07-25 10:44:18	2017-08-10 10:56:17	384266	590
44881	2012-06-20 00:00:00	VEME	\N	2017-06-20 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	04008A	\N	2017-07-25 10:44:18	\N	644420	590
44885	1997-06-01 00:00:00	VEME	\N	2001-09-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	01012H	\N	2017-07-25 10:44:18	\N	44313	370
44925	1962-12-06 00:00:00	VEME	\N	1967-04-02 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000250	\N	2017-07-25 10:44:19	\N	44304	130
44926	1967-04-03 00:00:00	VEME	\N	1968-05-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000250	\N	2017-07-25 10:44:19	\N	44305	130
44927	1968-07-11 00:00:00	VEME	\N	1973-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000250	\N	2017-07-25 10:44:19	\N	44306	130
44928	1973-04-02 00:00:00	VEME	\N	1978-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000250	\N	2017-07-25 10:44:19	\N	44307	130
44929	1981-07-02 00:00:00	VEME	\N	1981-07-23 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000250	\N	2017-07-25 10:44:19	\N	44309	130
44930	1978-04-03 00:00:00	VEME	\N	1981-05-22 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000250	\N	2017-07-25 10:44:19	\N	44308	130
44931	1986-04-02 00:00:00	VEME	\N	1986-05-07 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	000250	\N	2017-07-25 10:44:19	\N	44310	130
44968	1981-07-02 00:00:00	VEME	\N	1986-04-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	95022B	\N	2017-07-25 10:44:20	\N	44309	615
50776	1978-04-03 00:00:00	VEME	\N	1981-05-22 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	DEPUTE	86027F	\N	2017-08-18 12:16:11	\N	\N	\N
44697	1993-04-02 00:00:00	VEME	\N	1997-04-21 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11101A	\N	2017-07-25 10:44:11	\N	44312	660
44698	2002-06-19 00:00:00	VEME	\N	2007-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11101A	\N	2017-07-25 10:44:11	\N	230434	660
44699	2007-06-20 00:00:00	VEME	\N	2011-09-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	11101A	\N	2017-07-25 10:44:11	\N	384266	660
44721	1997-06-01 00:00:00	VEME	\N	2002-06-18 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	14085U	\N	2017-07-25 10:44:12	\N	44313	810
44722	2002-06-19 00:00:00	VEME	\N	2007-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	14085U	\N	2017-07-25 10:44:12	\N	230434	810
44723	2007-06-20 00:00:00	VEME	\N	2012-06-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	14085U	\N	2017-07-25 10:44:12	\N	384266	810
53905	2000-01-01 00:00:00	\N	\N	2005-01-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	DEPUTE	21032X	\N	\N	2023-11-20 15:31:50	\N	\N
\.


--
-- Data for Name: eludiv; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY eludiv (eluid, eludatdeb, eludatelu, eludatfin, temvalcod, evelic, evelib, evelil, eveobs, eluanndeb, eluannfin, elunbrhab, typmancod, senmat, eludatcum, eludivurlcmp, eludivart, syscredat, sysmajdat) FROM stdin;
6318	2001-05-23 00:00:00	\N	2008-04-08 00:00:00	ANCIEN	\N	Vice-président de l'Association des maires de grandes villes	Vice-président de l'Association des maires de grandes villes de France	BQ 25/05/2001	2001	\N	\N	DIVERS	77019E	\N	\N	\N	\N	\N
5885	1980-11-07 00:00:00	\N	2008-07-04 00:00:00	ANCIEN	\N	Comité de bassin Adour-Garonne	Président d'honneur du Comité de bassin Adour-Garonne	\N	1980	2008	\N	AUTFONLOC	83033Q	\N	\N	\N	\N	\N
5889	\N	\N	\N	ANCIEN	\N	Syndicat intercommunal du Lac d'Annecy	Président du Syndicat intercommunal du Lac d'Annecy	\N	2000	2008	\N	AUTFONLOC	95038K	\N	\N	\N	\N	\N
5891	\N	\N	\N	ANCIEN	\N	\N	Vice-président de l'Association des Maires de France	\N	\N	2008	\N	DIVERS	95038K	\N	\N	\N	\N	\N
5899	\N	\N	\N	ANCIEN	\N	SIVOM Vallée de l'Yerres et des Sénarts	Président du SIVOM Vallée de l'Yerres et des Sénarts	fin de mandat : mail assistante du 02/09/2008	1983	2008	\N	AUTFONLOC	01001E	\N	\N	\N	\N	\N
6280	\N	\N	2001-04-09 00:00:00	ANCIEN	\N	Syndicat de la région de Flines A Guenan	Président du Syndicat de la région de Flines A Guenan	\N	\N	2001	\N	INTERCOM	97006K	\N	\N	du 	\N	\N
6282	\N	\N	2023-07-11 00:00:00	ANCIEN	\N	Communauté de communes de la région d'Hallencourt	Président de la Communauté de communes de la région d'Hallencourt	\N	\N	2008	\N	INTERCOM	95047L	\N	\N	de la 	\N	\N
6293	\N	\N	\N	ACTIF	\N	Communauté de communes de Saint Laurent de Chamousset	Président de la communauté de communes de Saint Laurent de Chamousset	\N	1996	\N	\N	INTERCOM	86047K	\N	\N	de la 	\N	\N
6304	\N	\N	\N	ACTIF	\N	Union des maires de l'Essonne	Président de l'Union des maires de l'Essonne	\N	1999	\N	\N	AUTFONLOC	01001E	\N	\N	\N	\N	\N
6306	2001-04-20 00:00:00	\N	2014-12-31 00:00:00	ANCIEN	\N	Communauté urbaine du Grand Lyon	Président de la Communauté urbaine du Grand Lyon	\N	\N	\N	1191792	INTERCOM	99002P	\N	\N	de la 	\N	2015-01-16 09:46:13
6307	2001-04-20 00:00:00	\N	\N	ACTIF	\N	Communauté de l'agglomération de Clermont-Ferrand	Président de la communauté de l'agglomération de Clermont-Ferrand	\N	2001	\N	\N	INTERCOM	98009S	\N	\N	de la 	\N	\N
6308	\N	\N	2008-04-12 00:00:00	ANCIEN	\N	Communauté de l'agglomération du Pays de Montbéliard	Président de la Communauté de l'agglomération du Pays de Montbéliard	avant le 20/04/2001 : District urbain du Pays de Montbéliard	1989	2008	\N	INTERCOM	80041C	\N	\N	de la 	\N	\N
6309	\N	\N	\N	ANCIEN	\N	Assemblée des départements de France	Président de l'Assemblée des départements de France	\N	1989	2004	\N	AUTFONLOC	80035E	\N	\N	\N	\N	\N
6311	\N	\N	\N	ANCIEN	\N	Vice-président du Comité des régions d'Europe	Vice-président du Comité des régions d'Europe	\N	1997	2002	\N	DIVERS	80035E	\N	\N	\N	\N	\N
11411	2006-01-01 00:00:00	\N	2008-04-17 00:00:00	ANCIEN	\N	Communauté de communes du Pays de Pont-Château - Saint-Gildas-des-Bois	Président de la Communauté de communes du Pays de Pont-Château - Saint-Gildas-des-Bois	\N	2006	2008	\N	INTERCOM	01056V	\N	\N	de la 	\N	\N
6313	\N	\N	\N	ANCIEN	\N	Communauté de communes de Saint-Claude	Président de la communauté de communes de Saint-Claude	\N	1992	1995	\N	INTERCOM	01002F	\N	\N	de la 	\N	\N
6315	\N	\N	2017-05-15 00:00:00	ANCIEN	\N	Communauté de communes de la Vallée de la Barousse	Vice-Président de la Communauté de communes de la Vallée de la Barousse	\N	\N	\N	3001	INTERCOM	01003G	\N	\N	de la 	\N	2017-05-16 15:18:13
6319	2001-05-23 00:00:00	\N	\N	ACTIF	\N	Vice-président de l'Association des maires de grandes villes	Vice-président de l'Association des maires de grandes villes	BQ 25/05/2001	2001	\N	\N	DIVERS	98009S	\N	\N	\N	\N	\N
6320	2001-06-08 00:00:00	\N	\N	ACTIF	\N	Président de l'Office public d'HLM de Paris-OPAC	Président de l'Office public d'HLM de Paris-OPAC	BQ 11/06/2001	2001	\N	\N	DIVERS	01004H	\N	\N	\N	\N	\N
6321	\N	\N	2004-06-29 00:00:00	ANCIEN	\N	Président du comité des finances locales	Président du comité des finances locales	BQ 29/06/2001; BQ 30/06/2004	1980	2004	\N	DIVERS	77019E	\N	\N	\N	\N	\N
5892	\N	\N	2008-12-29 00:00:00	ANCIEN	\N	, syndicat d'électrification et d'équipement de la Lozère	Conseillère, syndicat d'électrification et d'équipement de la Lozère	\N	\N	2008	\N	INTERCOM	94004U	\N	\N	du 	\N	\N
6325	\N	\N	2020-05-14 00:00:00	ANCIEN	\N	Membre du Conseil économique et social	Membre du Conseil économique et social	\N	\N	1983	\N	DIVERS	83054V	\N	\N	\N	\N	\N
6326	\N	\N	2002-02-03 00:00:00	ANCIEN	\N	Membre du parlement européen	Membre du parlement européen	\N	\N	2002	\N	DIVERS	65017N	\N	\N	\N	\N	\N
6327	\N	\N	1989-07-24 00:00:00	ANCIEN	\N	Membre du parlement européen	Membre du parlement européen	\N	\N	1989	\N	DIVERS	92021M	\N	\N	\N	\N	\N
12071	\N	\N	2002-11-11 00:00:00	ANCIEN	\N	Syndicat d'adduction d'eau	Président du syndicat d'adduction d'eau	\N	\N	2002	25000	INTERCOM	89008Q	\N	\N	du 	\N	\N
6329	\N	\N	\N	ACTIF	\N	Président du syndicat départemental d'élimination déchets	Président du syndicat départemental d'élimination des déchets	Moniteur environnement juin 2001	\N	\N	\N	DIVERS	92039X	\N	\N	\N	\N	\N
6330	\N	\N	\N	ACTIF	\N	Président du Conseil supérieur de l'aviation marchande	Président du Conseil supérieur de l'aviation marchande	BQ 18/07/2001	2001	\N	\N	DIVERS	82002D	\N	\N	\N	\N	\N
6331	\N	\N	\N	ANCIEN	\N	Communauté d'agglomération de Bayonne-Anglet-Biarritz	Président de la Communauté d'agglomération de Bayonne-Anglet-Biarritz	\N	\N	2008	117910	INTERCOM	92013M	\N	\N	de la 	\N	\N
1794	\N	\N	\N	ACTIF	\N	Communauté d'agglomération de Mantes-en-Yvelines	Président de la Communauté d'agglomération de Mantes-en-Yvelines	\N	\N	\N	82095	INTERCOM	95013A	\N	\N	de la 	\N	\N
6332	\N	\N	2008-03-16 00:00:00	ANCIEN	\N	De Quimper Communauté	Président de Quimper Communauté	\N	\N	2008	87165	INTERCOM	86006A	\N	\N	de la 	\N	\N
6333	\N	\N	\N	ACTIF	\N	Communauté d'agglomération Haut Val de Marne	Président de la communauté d'agglomération Haut Val de Marne	\N	\N	\N	100696	INTERCOM	95057N	\N	\N	de la 	\N	\N
6334	\N	\N	\N	ACTIF	\N	Président de l'Association nationale des maires des stations	Président de l'Association nationale des maires des stations classées et communes touristiques	AFP 10/07/01	2001	\N	\N	DIVERS	92013M	\N	\N	\N	\N	\N
6336	\N	\N	2023-10-28 00:00:00	ANCIEN	\N	SIVOM de l'agglomération de Mulhouse	Président du SIVOM de l'agglomération de Mulhouse	\N	\N	\N	\N	INTERCOM	95029J	\N	\N	de l' 	\N	\N
1760	\N	\N	2020-11-24 00:00:00	ANCIEN	\N	Syndicat intercommunal de l'électricité et du gaz de l'Eure	Président du syndicat intercommunal de l'électricité et du gaz de l'Eure	\N	\N	\N	540000	INTERCOM	83004K	\N	\N	du 	\N	\N
12905	\N	\N	\N	ACTIF	\N	Assemblée parlementaire de l'OTAN	Membre de la commission Sécurité Défense de l'Assemblée parlementaire de l'OTAN	\N	\N	\N	\N	DIVERS	01014K	\N	\N	\N	\N	\N
6523	\N	\N	\N	ACTIF	\N	Communauté d'agglomération de Tours Plus	Vice-présidente de la Communauté d'agglomération de Tours Plus	\N	\N	\N	\N	INTERCOM	01013J	\N	\N	de la 	\N	\N
6524	\N	\N	2014-10-01 00:00:00	ANCIEN	\N	communauté d'agglomération d'Angers Loire Métropole 	Vice-président d'Angers Loire Métropole Communauté d'agglomération	\N	2001	\N	\N	INTERCOM	01016M	\N	\N	de la 	\N	2014-10-27 11:56:59
6539	1995-12-21 00:00:00	\N	2008-04-14 00:00:00	ANCIEN	\N	Communauté d'agglomération de Saint-Etienne-Métropole	Président de la Communauté d'agglomération de Saint-Etienne-Métropole	\N	1995	2008	\N	INTERCOM	01039U	\N	\N	de la 	\N	\N
6562	\N	\N	2001-10-19 00:00:00	ANCIEN	\N	Communauté d'agglomération de Laval	Premier Vice-président de la Communauté d'agglomération de Laval	\N	1993	2001	\N	INTERCOM	01047U	\N	\N	de la 	\N	\N
12863	\N	\N	\N	ACTIF	\N	Communauté de communes de la vallée du Jauron	\N	\N	2008	\N	\N	INTERCOM	11105E	\N	\N	de la 	\N	\N
6593	2001-01-01 00:00:00	\N	2006-01-01 00:00:00	ANCIEN	\N	Communauté de communes du canton de Saint-Gildas-des-Bois	Président de la Communauté de communes du canton de Saint-Gildas-des-Bois	les CC du Pays de Pontchâteau et du canton de Sant-Gildas-des-Bois ont fusionné le 1er janvier 2006	2001	2006	3050	INTERCOM	01056V	\N	\N	de la 	\N	\N
6594	\N	\N	2014-09-22 00:00:00	ANCIEN	\N	Communauté de communes du Pays des Lacs	Président de la Communauté de communes du Pays des lacs	\N	\N	\N	5480	INTERCOM	01008M	\N	\N	de la 	\N	2014-09-23 17:58:39
6599	\N	\N	2023-07-27 00:00:00	ANCIEN	\N	Communauté de communes des Cheires	Président de la Communauté de communes des Cheires	\N	2000	2008	9650	INTERCOM	01030K	\N	\N	de la 	\N	\N
6601	\N	\N	\N	ACTIF	\N	Communauté de communes du Pays de Montmédy	Président de la Communauté de communes du Pays de Montmédy	\N	1999	\N	\N	INTERCOM	01049W	\N	\N	de la 	\N	\N
15515	2016-12-16 00:00:00	\N	\N	ACTIF	Président de commision au Ceser d'Île de France	Président de la commision agriculture, environnement et ruralité du Ceser d'Île de France	Président de la commision agriculture, environnement et ruralité du Conseil économique et social régional d'Île de France	\N	\N	\N	\N	DIVERS	14357A	\N	\N	\N	2016-12-16 11:54:02	2016-12-16 11:57:13
6604	\N	\N	\N	ANCIEN	\N	Communauté de communes du canton de Bergues	Vice-présidente de la Communauté de communes du canton de Bergues	\N	\N	2008	\N	INTERCOM	01045S	\N	\N	de la 	\N	\N
6606	2001-12-21 00:00:00	\N	\N	ACTIF	\N	Communauté d'agglomération de Blois - Agglopolys	Première vice-présidente de la Communauté d'agglomération de Blois - Agglopolys	\N	\N	\N	72000	INTERCOM	01007L	\N	\N	de la 	\N	\N
6607	2002-12-31 00:00:00	\N	\N	ACTIF	\N	Communauté d'agglomération de Nevers	Président de la Communauté d'agglomération de Nevers	\N	2002	\N	70000	INTERCOM	01051Q	\N	\N	de la 	\N	\N
6609	\N	\N	2001-12-01 00:00:00	ANCIEN	\N	Communauté urbaine de Cherbourg	Vice-président de la Communauté urbaine de Cherbourg	\N	\N	2001	\N	INTERCOM	01011G	\N	\N	de la 	\N	\N
6616	\N	\N	\N	ACTIF	\N	Président de la chambre d'agriculture de Haute-Loire	Président de la chambre d'agriculture de Haute-Loire	\N	\N	\N	\N	DIVERS	01052R	\N	\N	\N	\N	\N
6617	2000-11-07 00:00:00	\N	\N	ACTIF	\N	Communauté d'agglomération Perpignan-Méditerranée	Président de la Communauté d'agglomération Perpignan-Méditerranée	\N	2000	\N	135000	INTERCOM	01006K	\N	\N	de la 	\N	\N
6618	2001-05-23 00:00:00	\N	\N	ACTIF	\N	Premier vice-président de l'association AMGVF 	Premier vice-président de l'association des maires de grandes villes de France	\N	2001	\N	\N	DIVERS	01006K	\N	\N	\N	\N	\N
6620	1996-09-01 00:00:00	\N	2001-07-31 00:00:00	ANCIEN	\N	Membre du Conseil économique et social	Membre de section du Conseil économique et social	\N	1996	2001	\N	DIVERS	01052R	\N	\N	\N	\N	\N
1749	\N	\N	2000-06-19 00:00:00	ANCIEN	\N	District urbain d'Oyonnax	Président du District urbain d'Oyonnax	\N	1983	2000	32519	INTERCOM	89027T	\N	\N	du 	\N	\N
1750	\N	\N	2017-04-04 00:00:00	ANCIEN	\N	Communauté de communes des Duyes et Bléone	Président de la communauté de communes des Duyes et Bléone	\N	\N	2017	2500	INTERCOM	80043E	\N	\N	de la 	\N	\N
1751	\N	\N	2001-03-25 00:00:00	ANCIEN	\N	Syndicat intercommunal de Valberg	Président du Syndicat intercommunal de Valberg	\N	\N	2001	1948	AUTFONLOC	88012G	\N	\N	\N	\N	\N
1754	\N	\N	\N	ACTIF	\N	Communauté de communes de la Haute-Saintonge	Président de la Communauté de communes de la Haute-Saintonge	\N	1992	\N	54248	INTERCOM	89013M	\N	\N	de la 	\N	\N
1755	\N	\N	2022-08-18 00:00:00	ANCIEN	\N	Communauté de communes Charente-Arnoult-Coeur de Saintonge	Président de la Communauté de communes Charente-Arnoult-Coeur de Saintonge	avant 02/09/1998 : Communauté de communes de Saint-Porchaire	1993	2001	11000	INTERCOM	89014N	\N	\N	de la 	\N	\N
1756	\N	\N	2008-03-10 00:00:00	ANCIEN	\N	District de l'agglomération dijonnaise	Président du district de l'agglomération dijonnaise	\N	\N	2008	231193	INTERCOM	80025C	\N	\N	de l' 	\N	\N
5233	\N	\N	\N	ACTIF	\N	Communauté de communes du Pays de Saint-Flour	Président de la Communauté de communes du Pays de Saint-Flour	\N	1994	\N	29999	INTERCOM	98027U	\N	http://www.cc-paysdesaintflour.fr/	de la 	\N	\N
1759	\N	\N	\N	ACTIF	\N	Syndicat départemental d'énergies de la Drôme	Président du Syndicat départemental d'énergies de la Drôme	\N	1991	\N	349506	AUTFONLOC	89015P	\N	\N	\N	\N	\N
1761	\N	\N	2010-12-20 00:00:00	ANCIEN	\N	Syndicat électrique du Perche	Président du syndicat électrique du Perche	\N	\N	2010	38000	INTERCOM	89031P	\N	\N	du 	\N	\N
1762	\N	\N	2002-11-11 00:00:00	ANCIEN	\N	SIVOM	Président du SIVOM	\N	\N	2002	25000	INTERCOM	89008Q	\N	\N	du 	\N	\N
1763	\N	\N	2010-01-13 00:00:00	ANCIEN	\N	SIVOM de Levroux	Président du SIVOM de Levroux	\N	\N	2010	\N	AUTFONLOC	89030N	\N	\N	\N	\N	\N
1764	\N	\N	\N	ANCIEN	\N	Communauté de communes des Collines du Perche	Président de la Communauté de communes des Collines du Perche	\N	\N	2001	\N	INTERCOM	92022N	\N	\N	de la 	\N	\N
1765	\N	\N	2014-04-14 00:00:00	ANCIEN	\N	\N	Président du syndicat intercommunal d'électricité de la Loire	\N	\N	2014	\N	AUTFONLOC	83044T	\N	\N	\N	\N	\N
1767	\N	\N	2019-12-20 00:00:00	ANCIEN	\N	District de Nantes  	Vice-président du District de Nantes  	le district de Nantes est devenu Nantes Métropole Communauté urbaine le 1er janvier 2001	\N	2001	\N	INTERCOM	83012K	\N	\N	du 	\N	\N
1768	\N	\N	\N	ANCIEN	\N	Communauté de communes de Catus	Président de la Communauté de communes de Catus	\N	\N	2004	4500	INTERCOM	92039X	\N	\N	de la 	\N	\N
10451	2002-10-31 00:00:00	\N	2003-11-04 00:00:00	ANCIEN	\N	Communauté d'agglomération du Drouais	Président de la Communauté d'agglomération du Drouais	\N	\N	2003	52000	INTERCOM	86031B	\N	\N	de la 	\N	\N
10452	2001-12-31 00:00:00	\N	2008-04-18 00:00:00	ANCIEN	\N	Communauté d'agglomération Nice-Côte d'Azur	Président de la Communauté d'agglomération Nice-Côte d'Azur	\N	\N	2008	490000	INTERCOM	98040R	\N	\N	de la 	\N	\N
10454	2002-02-08 00:00:00	\N	\N	ACTIF	\N	Communauté d'agglomération Toulon Provence Méditerranée	Président de la Communauté d'agglomération Toulon Provence Méditerranée	\N	2002	\N	392000	INTERCOM	95031C	\N	\N	de la 	\N	\N
10462	2003-04-17 00:00:00	\N	\N	ACTIF	\N	Conseil national des politiques de lutte contre la pauvreté 	Président du Conseil national des politiques de lutte contre la pauvreté et l'exclusion sociale	bulletin quotidien 17 avril 2003	\N	\N	\N	DIVERS	89041R	\N	\N	\N	\N	\N
10463	2003-04-01 00:00:00	\N	\N	ACTIF	\N	Président association Seine Nord Europe	Président de l'association Seine Nord Europe	revue de presse intranet Sénat, 05 mai 2003 	\N	\N	\N	DIVERS	92035T	\N	\N	\N	\N	\N
10519	2003-05-22 00:00:00	\N	2024-01-10 00:00:00	ANCIEN	\N	Membre du conseil national du développement durable	Membre du conseil national du développement durable	BQ 23/05/2003	2003	\N	\N	DIVERS	98051U	\N	\N	\N	\N	\N
10520	2003-05-22 00:00:00	\N	\N	ANCIEN	\N	Membre du conseil national du développement durable	Membre du conseil national du développement durable	BQ 23/05/2003	2003	2011	\N	DIVERS	01048V	\N	\N	\N	\N	\N
1753	\N	\N	2016-05-01 00:00:00	ANCIEN	\N	District du Grand Caen	Président du district du Grand Caen	\N	\N	2016	190338	INTERCOM	71018C	\N	\N	du 	\N	\N
10529	2003-06-10 00:00:00	\N	2004-04-28 00:00:00	ANCIEN	\N	Président de l'association des régions de France	Président de l'association des régions de France	Président du 11/07/2002 au 25/03/2003 également.	2003	2004	\N	DIVERS	01048V	\N	\N	\N	\N	\N
10530	1981-05-10 00:00:00	\N	1995-05-07 00:00:00	ANCIEN	\N	\N	Président de la République	\N	\N	\N	\N	ETAT	000379	\N	\N	\N	\N	\N
52314	2008-01-01 00:00:00	\N	\N	ANCIEN	\N	communauté de communes Du Dunois	\N	\N	\N	2018	\N	INTERCOM	19798U	\N	\N	de la	\N	\N
10539	\N	\N	\N	ANCIEN	\N	Communauté de communes du canton de Pipriac	Vice-président de la Communauté de communes du canton de Pipriac	\N	\N	2008	\N	INTERCOM	03002P	\N	\N	de la 	\N	\N
10559	2002-10-25 00:00:00	\N	2003-10-24 00:00:00	ANCIEN	\N	Président de l'Association des présidents de CU de France	Président de l'Association des présidents de communautés urbaines de France	Remarque assistant de M. Gaudin 4/05/04 sur fin mandat	2002	2003	\N	DIVERS	89029V	\N	\N	\N	\N	\N
5218	\N	\N	\N	ANCIEN	\N	Communauté de communes de Surgères	Président de la Communauté de communes de Surgères	demande de modification 28/10/2003: "ancien président"	1994	2003	29999	INTERCOM	98014P	\N	\N	de la 	\N	\N
10560	\N	\N	\N	ANCIEN	\N	Président office départemental HLM de la Charente Maritime	Président de l'office départemental HLM de la Charente-Maritime	demande de modification 31/10/2003	\N	2004	\N	DIVERS	98014P	\N	\N	\N	\N	\N
10561	\N	\N	\N	ACTIF	\N	Vice président sous com. de commission defense OTAN	Vice-président de la sous-commission sur la coopération transatlantique de la commission de la défense de l'Assemblée parlementaire de l'OTAN	demande de modification 31/10/2003; nouvelle demande le 24/11/2003	\N	\N	\N	DIVERS	98014P	\N	\N	\N	\N	\N
10571	\N	\N	2010-12-17 00:00:00	ANCIEN	\N	Conseil de développement de la Communauté Urbaine de Lyon	Président délégué du Conseil de développement de la Communauté Urbaine de Lyon	toutes ces informations: BQ 6/11/2003	\N	2010	\N	INTERCOM	03003Q	\N	\N	de la 	\N	\N
10573	\N	\N	\N	ANCIEN	\N	Président délégué du comité régional du tourisme IDF	Président-délégué du comité régional du tourisme d'Ile-de-France	\N	\N	2003	\N	DIVERS	95056M	\N	\N	\N	\N	\N
5214	2002-11-12 00:00:00	\N	2008-04-11 00:00:00	ANCIEN	\N	Communauté d'agglomération des Portes de l'Eure	Président de la Communauté d'agglomération des Portes de l'Eure	\N	2002	2008	55000	INTERCOM	98013N	\N	\N	de la 	\N	\N
12069	\N	\N	\N	ACTIF	\N	Membre d'honneur de l'association Avenir Transport	Membre d'honneur de l'association Avenir Transport	\N	\N	\N	\N	DIVERS	04045F	\N	\N	\N	\N	\N
5220	\N	\N	\N	ANCIEN	\N	SIVOM du canton de Mirebeau-sur-Bèze	Président du SIVOM du canton de Mirebeau-sur-Bèze	\N	1977	2005	29997	AUTFONLOC	98048A	\N	\N	\N	\N	\N
5222	1997-01-19 00:00:00	\N	\N	ANCIEN	\N	District de l'agglomération périgourdine	Président du district de l'agglomération périgourdine	\N	\N	1999	29999	INTERCOM	98031Q	\N	\N	de l' 	\N	\N
5225	1993-11-22 00:00:00	\N	1999-12-31 00:00:00	ANCIEN	\N	Communauté de communes Bayeux Intercom	Président de la Communauté de communes Bayeux Intercom	\N	1993	1999	29999	INTERCOM	98042T	\N	\N	de la 	\N	\N
10590	\N	\N	2016-11-03 00:00:00	ANCIEN	\N	Syndicat intercommunal de protection de la Vallée de la Bièvre	Président du Syndicat intercommunal de protection de la Vallée de la Bièvre	\N	\N	2016	\N	INTERCOM	03004R	\N	\N	du 	\N	\N
10593	2014-04-01 00:00:00	\N	\N	ACTIF	\N	Syndicat mixte du Lac des sapins	Président du Syndicat mixte du Lac des sapins	\N	\N	\N	\N	AUTFONLOC	95049N	\N	\N	\N	\N	2014-10-15 18:16:03
10602	\N	\N	\N	ANCIEN	\N	Président de l'office HLM de la Moselle	Président de l'office HLM de la Moselle	presse ed 17/3/04; fin : mél de therese labonne,assistante bertho audifax	1992	2004	\N	DIVERS	01060R	\N	\N	\N	\N	\N
10604	\N	\N	\N	ANCIEN	\N	Président du Syndicat mixte du Nord-Métropole Lorraine	Président du Syndicat mixte du Nord-Métropole Lorraine	\N	1976	1986	\N	DIVERS	01060R	\N	\N	\N	\N	\N
10675	\N	\N	\N	ACTIF	\N	Association Maires des Hauts de Seine	Secrétaire général de l'Association des Maires des Hauts-de-Seine	demande expres de M. Schosteck 14/04/2004	\N	\N	\N	DIVERS	93005R	\N	\N	\N	\N	\N
10677	\N	\N	2024-02-09 00:00:00	ANCIEN	\N	Psdt Cour conciliation et arbitrage OSCE	Président de la Cour de conciliation et d'arbitrage de l'OSCE	\N	1995	\N	\N	DIVERS	95006B	\N	\N	\N	\N	\N
10686	\N	\N	2007-06-21 00:00:00	ANCIEN	\N	District de l'agglomération de Nancy	Vice-président du district de l'agglomération de Nancy	Fiche presse-ed 28/04/2004	1983	2007	\N	INTERCOM	92007P	\N	\N	de l' 	\N	\N
10704	\N	\N	2008-03-16 00:00:00	ANCIEN	\N	Syndicat intercommunal de protection du site de Val-Suzon	Président fondateur du Syndicat intercommunal de protection du site de Val-Suzon	\N	\N	2008	\N	AUTFONLOC	89037V	\N	\N	\N	\N	\N
10706	\N	\N	\N	ACTIF	\N	Association régionale des Pays d'Auvergne	Président fondateur de l'Association régionale des Pays d'Auvergne	\N	\N	\N	\N	DIVERS	89018S	\N	\N	\N	\N	\N
10711	\N	\N	\N	ANCIEN	\N	Communauté de communes du Pays de Châteaulin et du Porzay	Vice-Présidente de la Communauté de communes du Pays de Châteaulin et du Porzay	\N	1995	2008	\N	INTERCOM	98049B	\N	\N	de la 	\N	\N
10713	\N	\N	2008-04-17 00:00:00	ANCIEN	\N	Marseille-Provence-Métropole Communauté urbaine	Conseiller, Marseille-Provence-Métropole Communauté urbaine	\N	2001	2008	\N	INTERCOM	98016R	\N	\N	de la 	\N	\N
10716	1994-01-01 00:00:00	\N	2016-12-31 00:00:00	ANCIEN	\N	Communauté de communes de la Plaine de Bourgogne	Président de la Communauté de communes de la Plaine de Bourgogne	\N	\N	\N	\N	INTERCOM	01024M	\N	\N	de la 	\N	2017-04-21 15:12:03
10717	\N	\N	2015-12-31 00:00:00	ANCIEN	\N	Communauté d'agglomération de Rouen	Vice-Président de la Communauté d'agglomération de Rouen	\N	2001	\N	\N	INTERCOM	98053W	\N	\N	de la 	\N	2016-07-07 13:26:22
10721	\N	\N	\N	ACTIF	\N	Communauté d'agglomération de la Plaine centrale du Val-de-Marne	Vice-président de la Communauté d'agglomération de la Plaine centrale du Val-de-Marne	\N	2001	\N	\N	INTERCOM	97004H	\N	\N	de la 	\N	\N
10725	\N	\N	\N	ANCIEN	\N	Communauté des communes de Landerneau - Daoulas 	Président de la Communauté des communes de Landerneau - Daoulas 	\N	\N	1999	\N	INTERCOM	98046X	\N	\N	de la 	\N	\N
10731	\N	\N	\N	ANCIEN	\N	Psdt Association des maires des grandes villes de France	Président de l'Association des maires des grandes villes de France	\N	1998	2001	\N	DIVERS	01028R	\N	\N	\N	\N	\N
10732	\N	\N	2007-12-16 00:00:00	ANCIEN	\N	Communauté de communes du Coeur de France	Président de la Communauté de communes du Coeur de France	\N	2000	2007	\N	INTERCOM	89045V	\N	\N	de la 	\N	\N
10733	\N	\N	\N	ANCIEN	\N	Communauté de communes du Moncoutantais "Terre de Sèvre"	Président de la Communauté de communes du Moncoutantais "Terre de Sèvre"	\N	\N	2004	\N	INTERCOM	95009E	\N	\N	de la 	\N	\N
10735	\N	\N	2016-12-10 00:00:00	ANCIEN	\N	Vice-président de l'Association des maires de France	Vice-président de l'Association des maires de France	\N	1988	\N	\N	DIVERS	01037S	\N	\N	\N	\N	2016-12-12 16:10:14
10737	\N	\N	\N	ANCIEN	\N	Syndicat intercommunal à vocations multiples du Pays de Sierentz	Président du Syndicat intercommunal à vocations multiples du Pays de Sierentz	\N	1983	2001	\N	INTERCOM	95045J	\N	\N	du 	\N	\N
10740	1991-12-27 00:00:00	\N	2022-10-17 00:00:00	ANCIEN	\N	Communauté d'agglomération de Saint-Brieuc	Président de la Communauté d'agglomération de Saint-Brieuc	avant le 29/10/1999, président du district du Pays de Saint-Brieuc	1991	2001	\N	INTERCOM	89040Q	\N	\N	de la 	\N	\N
10745	2004-07-01 00:00:00	\N	2007-09-19 00:00:00	ANCIEN	\N	Président de l'Agence nationale de Rénovation urbaine	Président de l'Agence nationale de rénovation urbaine (ANRU)	Demande assistant parlementaire	2004	2007	\N	DIVERS	01006K	\N	\N	\N	\N	\N
10746	\N	\N	\N	ANCIEN	\N	Président de l'intergroupe parlementaire de l'Outre-mer	Président de l'intergroupe parlementaire de l'Outre-mer	point transmis par assistant parlementaire de M Loueckhote, juillet 2004 - courriel Alexandrine Rota 27 novembre 2007	\N	2007	\N	DIVERS	92033R	\N	\N	\N	\N	\N
10747	\N	\N	\N	ACTIF	\N	Président du Conseil national de l'air	Président du Conseil national de l'air	courriel assistante parlementaire 02 août 2004	2004	\N	\N	DIVERS	92005M	\N	\N	\N	\N	\N
10773	\N	\N	\N	ACTIF	\N	Communauté de communes de Sablé-sur-Sarthe	Président de la Communauté de communes de Sablé-sur-Sarthe	\N	2001	\N	\N	INTERCOM	02009S	\N	\N	de la 	\N	\N
10822	\N	\N	\N	ANCIEN	\N	Communauté de communes de la Porte du Sundgau	Vice-présidente de la Communauté de communes de la Porte du Sundgau	\N	2001	2008	\N	INTERCOM	04044E	\N	\N	de la 	\N	\N
11402	2008-03-09 00:00:00	\N	\N	ACTIF	\N	Communauté d'agglomération de Laval	Conseiller, Communauté d'agglomération de Laval	\N	\N	\N	\N	INTERCOM	01047U	\N	\N	de la 	\N	2014-10-23 10:57:45
10891	2001-03-18 00:00:00	\N	2008-04-18 00:00:00	ANCIEN	\N	Communauté urbaine de Strasbourg	Présidente déléguée de la Communauté urbaine de Strasbourg	\N	2001	2008	\N	INTERCOM	04061F	\N	\N	de la 	\N	\N
11009	\N	\N	2016-12-31 00:00:00	ANCIEN	\N	Communauté de communes du Haut-Clocher	Président de la Communauté de communes du Haut-Clocher	\N	1995	\N	\N	INTERCOM	04089T	\N	\N	de la 	\N	\N
11019	\N	\N	2017-01-01 00:00:00	ANCIEN	\N	Communauté de communes des Pays du Rhône et d'Ouvèze	Président de la Communauté de communes des Pays du Rhône et d'Ouvèze	\N	1993	\N	\N	INTERCOM	04092N	\N	http://www.ccpro.fr 	de la 	\N	\N
11038	\N	\N	2014-12-31 00:00:00	ANCIEN	\N	Communauté urbaine du Grand Lyon	Conseiller, Communauté urbaine du Grand Lyon	\N	1995	\N	\N	INTERCOM	04047H	\N	\N	de la 	\N	2015-01-16 09:47:00
11041	\N	\N	\N	ACTIF	\N	Communauté d'agglomération du Haut-Val-de-Marne	Vice-président de la Communauté d'agglomération du Haut-Val-de-Marne	\N	2001	\N	100000	INTERCOM	04037F	\N	\N	de la 	\N	\N
11042	\N	\N	\N	ANCIEN	\N	Communauté de communes de Charenton-le-Pont - Saint-Maurice	Président de la Communauté de communes de Charenton-le-Pont - Saint-Maurice	\N	2004	2006	45000	INTERCOM	04042C	\N	\N	de la 	\N	\N
11043	2001-05-23 00:00:00	\N	\N	ANCIEN	\N	Psdt association maires de grandes villes de France	Président de l'association des maires des grandes villes de France	\N	2001	2007	\N	DIVERS	04040A	\N	\N	\N	\N	\N
11045	\N	\N	\N	ACTIF	\N	Premier vice-président délégué de l'Association des maires r	Premier vice-président délégué de l'Association des maires ruraux de France	\N	\N	\N	\N	DIVERS	04038G	\N	\N	\N	\N	\N
11054	\N	\N	\N	ANCIEN	\N	Assemblée des Français de l'étranger	Première vice-présidente de l'Assemblée des Français de l'étranger	\N	\N	2004	\N	DIVERS	04035D	\N	\N	\N	\N	\N
11055	\N	\N	2005-03-31 00:00:00	ANCIEN	\N	Communauté d'agglomération de Mulhouse Sud Alsace	Président de la Communauté d'agglomération de Mulhouse Sud Alsace	Mail internaute 18/04/05	2001	2005	\N	INTERCOM	04040A	\N	\N	de la 	\N	\N
11056	\N	\N	2014-06-17 00:00:00	ANCIEN	\N	Syndicat intercommunal du Grand-Morin	Président du Syndicat intercommunal du Grand-Morin	\N	1995	\N	\N	AUTFONLOC	04048J	\N	\N	\N	\N	2014-07-17 10:33:24
11059	\N	\N	\N	ANCIEN	\N	Communauté d'agglomération dracénoise	Vice-président de la Communauté d'agglomération dracénoise	\N	1982	2008	\N	INTERCOM	04038G	\N	\N	de la 	\N	\N
12528	2001-03-18 00:00:00	\N	2017-10-18 00:00:00	ANCIEN	\N	Communauté d'agglomération Europ'Essonne	\N	\N	\N	\N	\N	INTERCOM	11070L	\N	\N	de la 	\N	2017-10-19 14:51:43
11062	\N	\N	\N	ANCIEN	\N	Communauté urbaine de Strasbourg	Président de la Communauté urbaine de Strasbourg	\N	1997	2001	450000	INTERCOM	04065K	\N	\N	de la 	\N	\N
11066	\N	\N	2014-04-01 00:00:00	ANCIEN	\N	Communauté d'agglomération Melun - Val-de-Seine	Conseillère, Communauté d'agglomération Melun - Val-de-Seine	\N	2001	\N	\N	INTERCOM	04057K	\N	\N	de la 	\N	2014-05-28 14:52:14
11085	\N	\N	\N	ANCIEN	\N	 communauté d'agglomération rouennaise	Conseillère, Communauté d'agglomération rouennaise	\N	2001	2008	\N	INTERCOM	04070G	\N	\N	de la 	\N	2016-06-02 17:07:13
11071	\N	\N	2004-12-23 00:00:00	ANCIEN	\N	Communauté d'agglomération Chambéry-Métropole	Président de la Communauté d'agglomération Chambéry-Métropole	\N	2001	2004	2004	INTERCOM	04090L	\N	\N	de la 	\N	\N
11072	\N	\N	2004-12-21 00:00:00	ANCIEN	\N	Vice-président de l'Assemblée des communautés de France	Vice-président de l'Assemblée des communautés de France	\N	2001	2004	\N	DIVERS	04090L	\N	\N	\N	\N	\N
11074	\N	\N	\N	ACTIF	\N	Vice-présidente de l'Association des maires ruraux	Vice-présidente de l'Association des maires ruraux	\N	\N	\N	\N	DIVERS	04069P	\N	\N	\N	\N	\N
11075	\N	\N	2008-03-16 00:00:00	ANCIEN	\N	Communauté de communes du canton de Cuiseaux	Président de la Communauté de communes du canton de Cuiseaux	\N	1991	2008	7000	INTERCOM	04091M	\N	\N	de la 	\N	\N
12538	2008-03-01 00:00:00	\N	2016-01-18 00:00:00	ANCIEN	\N	communauté d'agglomération Grand Paris Seine Ouest	\N	\N	\N	\N	\N	INTERCOM	11085T	\N	\N	de la	\N	2016-01-19 17:59:20
12564	2003-01-01 00:00:00	\N	2020-03-15 00:00:00	ANCIEN	\N	Communauté d'agglomération de Perpignan Méditerranée	\N	\N	\N	\N	\N	INTERCOM	11101A	\N	\N	de la 	\N	2017-11-10 15:58:02
11080	\N	\N	2008-04-08 00:00:00	ANCIEN	\N	Communauté d'agglomération Toulon-Provence-Méditerrannée	Vice-présidente de la Communauté d'agglomération Toulon-Provence-Méditerrannée	\N	2002	\N	\N	INTERCOM	04041B	\N	\N	de la 	\N	\N
11081	\N	\N	\N	ANCIEN	\N	Communauté d'agglomération de Villefranche-sur-Saône	Vice-présidente de la Communauté d'agglomération de Villefranche-sur-Saône	\N	1989	2015	\N	INTERCOM	04049K	\N	\N	de la 	\N	2015-07-17 16:49:23
11082	2001-04-11 00:00:00	\N	2008-04-10 00:00:00	ANCIEN	\N	Communauté de communes de Benfeld et environs	Présidente de la Communauté de communes de Benfeld et environs	\N	2001	2008	\N	INTERCOM	04069P	\N	\N	de la 	\N	\N
11084	2001-05-30 00:00:00	\N	2008-05-02 00:00:00	ANCIEN	\N	Syndicat mixte intercommunal de l'aménagement de Mayotte	Président du Syndicat mixte intercommunal de l'aménagement de Mayotte	\N	2001	2008	160000	AUTFONLOC	04062G	\N	\N	\N	\N	\N
11098	\N	\N	\N	ACTIF	\N	Communauté de communes du Pays vouglaisien	Président de la Communauté de communes du Pays vouglaisien	\N	2001	\N	14000	INTERCOM	04098U	\N	\N	de la 	\N	\N
11088	\N	\N	2018-05-24 00:00:00	ANCIEN	\N	CCI Mayotte	Président de la chambre de commerce de Mayotte	\N	\N	\N	\N	DIVERS	04064J	\N	\N	\N	\N	2018-05-30 17:03:14
11102	1995-01-24 00:00:00	\N	2014-04-01 00:00:00	ANCIEN	\N	Communauté de communes du Saosnois	Président de la Communauté de communes du Saosnois	\N	\N	\N	13516	INTERCOM	04099V	\N	\N	de la 	\N	2014-04-08 15:32:02
11107	\N	\N	\N	ANCIEN	\N	1er Vice-Président de l'UGCF	1er Vice-Président de l'Union des Conseillers Généraux de France	demande de son assistante le 3/11/2004	\N	2015	\N	DIVERS	87003B	\N	\N	\N	\N	2017-11-09 15:25:26
11108	2003-02-01 00:00:00	\N	2004-12-31 00:00:00	ANCIEN	\N	Communauté d'agglomération du Grand Avignon	Conseiller, Communauté d'agglomération du Grand Avignon	demande assistante 3/11/2004	2003	2004	\N	INTERCOM	87003B	\N	\N	de la 	\N	\N
11109	\N	\N	2008-04-17 00:00:00	ANCIEN	\N	Communauté urbaine de Strasbourg	Conseiller, Communauté urbaine de Strasbourg	\N	2001	2008	\N	INTERCOM	04065K	\N	\N	de la 	\N	\N
11110	2002-12-21 00:00:00	\N	2008-04-12 00:00:00	ANCIEN	\N	Communauté de communes du Pays d'Auray	Président de la Communauté de communes du Pays d'Auray	\N	2002	2008	\N	INTERCOM	01021J	\N	\N	de la 	\N	\N
11116	\N	\N	\N	ANCIEN	\N	Syndicat d'agglomérations nouvelles Ouest-Provence	Président du Syndicat d'agglomérations nouvelles Ouest-Provence	\N	1977	1998	\N	INTERCOM	04101V	\N	\N	de l' 	\N	\N
11118	\N	\N	2008-04-10 00:00:00	ANCIEN	\N	Communauté de communes du Mirebellois	Premier vice-président de la Communauté de communes du Mirebellois	\N	2003	2008	\N	INTERCOM	98048A	\N	\N	de la 	\N	\N
11119	\N	\N	\N	ACTIF	\N	Mbre du CA de la Société des autoroutes Paris-Rhin-Rhône	Membre du Conseil d'administration de la Société des autoroutes Paris-Rhin-Rhône	demande 26/01/05 de son assistante	\N	\N	\N	DIVERS	98048A	\N	\N	\N	\N	\N
11120	\N	\N	\N	ANCIEN	\N	Premier vice-président de l'Association des Départements de 	Premier vice-président de l'Association des Départements de France	\N	\N	2008	\N	DIVERS	98048A	\N	\N	\N	\N	\N
11122	\N	\N	2014-06-17 00:00:00	ANCIEN	\N	Président de l'Union départementale des maires de S&Marne	Président de l'Union départementale des maires de Seine et Marne	\N	\N	\N	\N	DIVERS	04048J	\N	\N	\N	\N	2014-07-17 10:33:05
11137	\N	\N	2014-04-24 00:00:00	ANCIEN	\N	Secrétaire général parlementaire de l'APF	Secrétaire général parlementaire de l'Assemblée parlementaire de la francophonie	\N	\N	\N	0	DIVERS	92031P	\N	\N	\N	\N	2014-04-25 14:14:25
10376	\N	\N	\N	ACTIF	\N	Sivom	Président du sivom	\N	\N	\N	\N	INTERCOM	000586	\N	\N	du 	\N	\N
11139	2005-04-01 00:00:00	\N	\N	ANCIEN	\N	Communauté d'agglomération de Mulhouse Sud Alsace	Vice-Président de la Communauté d'agglomération de Mulhouse Sud Alsace	\N	2005	2009	\N	INTERCOM	04040A	\N	\N	de la 	\N	\N
11140	\N	\N	\N	ANCIEN	\N	Président de l'association des maires de la Martinique	Président de l'association des maires de la Martinique	mail CG Martinique 29/04/2005	\N	2010	\N	DIVERS	04094Q	\N	\N	\N	\N	\N
11141	\N	\N	\N	ANCIEN	\N	Président de l'Epareca	Président de l'Etablissement public national d'aménagement et de restructuration des espaces commerciaux et artisanaux (EPARECA)	demande de l'assistant du sénateur	\N	2007	\N	DIVERS	01006K	\N	\N	\N	\N	\N
11143	\N	\N	\N	ANCIEN	\N	Administrateur de la SNCF	Administrateur de la SNCF	demande de M. Haenel 26/05/05	\N	2008	\N	DIVERS	86030A	\N	\N	\N	\N	\N
11144	\N	\N	\N	ANCIEN	\N	Mbre titulaire Cvt° pr élab. Charte droits fondamentaux	Membre titulaire de la Convention chargée de l'élaboration de la Charte droits fondamentaux de l'Union européenne	demande M. Haenel 26/05/05	\N	2004	\N	DIVERS	86030A	\N	\N	\N	\N	\N
11145	\N	\N	\N	ANCIEN	\N	Membre titulaire de la Convention sur l'avenir de l'Europe	Membre titulaire de la Convention sur l'avenir de l'Europe	demande de M. Haenel le 26/05/05	\N	2004	\N	DIVERS	86030A	\N	\N	\N	\N	\N
11148	\N	\N	2008-04-17 00:00:00	ANCIEN	\N	D'honneur de la Communauté de communes du canton d'Oulchy-le-Château	Président d'honneur de la Communauté de communes du canton d'Oulchy-le-Château	remarque assistante 08/06/05	1994	2008	\N	INTERCOM	78003A	\N	\N	de la 	\N	\N
6622	\N	\N	2015-04-07 00:00:00	ANCIEN	\N	Communauté d'agglomération d'Hénin-Carvin	Vice-président de la Communauté d'agglomération d'Hénin-Carvin	\N	\N	2015	\N	INTERCOM	01035Q	\N	\N	de la 	\N	\N
6627	2001-01-01 00:00:00	\N	2006-05-16 00:00:00	ANCIEN	\N	Communauté d'agglomération de Pau	Président de la Communauté d'agglomération de Pau	\N	2001	2006	145000	INTERCOM	01032M	\N	\N	de la 	\N	\N
6633	\N	\N	\N	ANCIEN	\N	Directeur général de l'établissement public d'aménagement de	Directeur général de l'établissement public d'aménagement de Saint-Quentin en Yvelines	\N	1988	1993	\N	DIVERS	01006K	\N	\N	\N	\N	\N
6635	\N	\N	2009-01-07 00:00:00	ANCIEN	\N	Communauté de communes de Sumène-Artense	Président de la Communauté de communes de Sumène-Artense	\N	\N	2009	\N	INTERCOM	89010J	\N	\N	de la 	\N	\N
6636	\N	\N	\N	ACTIF	\N	Communauté de communes d'Ackerland	Président de la Communauté de communes d'Ackerland	\N	\N	\N	\N	INTERCOM	77029G	\N	\N	de la 	\N	\N
6638	\N	\N	\N	ACTIF	\N	Président de l'association des maires du Bas-Rhin	Président de l'association des maires du Bas-Rhin	\N	1983	\N	\N	DIVERS	77029G	\N	\N	\N	\N	\N
6639	\N	\N	\N	ACTIF	\N	Président de l'association des maires de France	Président de l'association des maires de France	\N	\N	\N	\N	DIVERS	77029G	\N	\N	\N	\N	\N
6645	\N	\N	\N	ANCIEN	\N	Délégué au Conseil supérieur des Français de l'étranger	Délégué au Conseil supérieur des Français de l'étranger	\N	1983	2000	\N	DIVERS	01063U	\N	\N	\N	\N	\N
6648	\N	\N	2017-11-02 00:00:00	ANCIEN	\N	Président de l'Association des Maires de la Marne (AMM)	Président de l'Association des Maires de la Marne (AMM)	Mail assistant 1er aout 2005	\N	\N	\N	DIVERS	01024M	\N	\N	\N	\N	2017-11-08 15:54:08
6655	\N	\N	2014-04-04 00:00:00	ANCIEN	\N	Président de l'OPAC Sarthe Habitat	Président de l'OPAC Sarthe Habitat	\N	\N	\N	0	DIVERS	95019G	\N	\N	\N	\N	2014-04-08 09:32:57
1769	\N	\N	2008-09-24 00:00:00	ANCIEN	\N	SIVOM cantonal de Saint-Céré	Président du SIVOM cantonal de Saint-Céré	Sivom dissout le 31/12/2007	1983	2008	7300	AUTFONLOC	88004G	\N	\N	\N	\N	\N
1770	\N	\N	2009-12-08 00:00:00	ANCIEN	\N	Communauté de communes de Montrevault	Président de la Communauté de communes de Montrevault	\N	\N	2009	15000	INTERCOM	83035S	\N	\N	de la 	\N	\N
1772	\N	\N	\N	ANCIEN	\N	Communauté de communes du canton de Lessay	Président de la Communauté de communes du canton de Lessay	\N	\N	2005	\N	INTERCOM	82002D	\N	\N	de la 	\N	\N
1773	\N	\N	2015-01-01 00:00:00	ANCIEN	\N	Communauté de communes de la Sélune	Vice-Président de la Communauté de communes de la Sélune	\N	\N	\N	\N	INTERCOM	96004D	\N	\N	de la 	\N	2015-02-27 10:25:21
1774	\N	\N	2001-01-26 00:00:00	ANCIEN	\N	\N	Président du Syndicat de bassin Ernée-Chailland	\N	\N	2001	18000	AUTFONLOC	74008N	\N	\N	\N	\N	\N
1777	\N	\N	\N	ACTIF	\N	Communauté d'agglomération de Cambrai	Vice-président de la Communauté d'agglomération de Cambrai	\N	\N	\N	54508	INTERCOM	92031P	\N	\N	de la 	\N	\N
1778	\N	\N	2008-04-02 00:00:00	ANCIEN	\N	De Lille-Métropole Communauté urbaine	Président de Lille-Métropole Communauté urbaine	\N	\N	\N	1102760	INTERCOM	92037V	\N	\N	de la 	\N	\N
1780	\N	\N	\N	ACTIF	\N	\N	Président du Sivom de Bapaume	\N	\N	\N	22000	AUTFONLOC	92017R	\N	\N	\N	\N	\N
1781	\N	\N	\N	ANCIEN	\N	SIVOM du Pays d'Erstein	Président du SIVOM du Pays d'Erstein	\N	\N	2001	18000	AUTFONLOC	95036H	\N	\N	\N	\N	\N
1782	\N	\N	2023-10-21 00:00:00	ANCIEN	\N	Communauté de Communes des Coteaux de la Mossig	Président de la Communauté de Communes des Coteaux de la Mossig	\N	\N	\N	7088	INTERCOM	91002E	\N	\N	de la 	\N	\N
1784	1995-05-28 00:00:00	\N	2014-03-23 00:00:00	ANCIEN	\N	communauté de communes de l'agglomération de Vesoul	conseiller communautaire de la communauté de communes de l'agglomération de Vesoul	\N	\N	\N	\N	INTERCOM	95041E	\N	\N	du 	\N	2014-09-18 11:08:10
1785	\N	\N	2008-03-16 00:00:00	ANCIEN	\N	Communauté de communes entre Saône et Grosne	Président de la Communauté de communes entre Saône et Grosne	\N	\N	2008	7500	INTERCOM	95030B	\N	\N	de la 	\N	\N
1786	\N	\N	\N	ANCIEN	\N	Communauté de communes Matour et sa région	Président de la Communauté de communes Matour et sa région	\N	1993	2001	3000	INTERCOM	95020Y	\N	\N	de la 	\N	\N
1787	\N	\N	\N	ACTIF	\N	Communauté de communes de Lucé	Président de la Communauté de communes de Lucé	\N	\N	\N	5050	INTERCOM	77012W	\N	\N	de la 	\N	\N
1788	\N	\N	2019-03-18 00:00:00	ANCIEN	\N	Communauté de communes du Pays des Brières et du Gesnois	Président de la Communauté de communes du Pays des Brières et du Gesnois	\N	1993	2001	18000	INTERCOM	95019G	\N	\N	de la 	\N	\N
1790	\N	\N	\N	ANCIEN	\N	Communauté de communes des Vallées de Thônes	Président de la Communauté de communes des Vallées de Thônes	avant 1993 : président du SIVOM des Vallées de Thônes	1989	2001	11000	INTERCOM	95005A	\N	\N	de la 	\N	\N
1792	\N	\N	\N	ACTIF	\N	Communauté de communes des Deux-Rives	Président de la Communauté de communes des Deux-Rives	\N	\N	\N	29999	INTERCOM	86010V	\N	\N	de la 	\N	\N
1793	\N	\N	2009-04-11 00:00:00	ANCIEN	\N	Communauté de Communes du SISEL	Président de la Communauté de Communes du SISEL	\N	\N	2009	25000	INTERCOM	68036E	\N	\N	de la 	\N	\N
1795	\N	\N	2010-07-25 00:00:00	ANCIEN	\N	\N	Président du syndicat d'aduction d'eau *Rhône-Aygues-Ouvèze*	\N	\N	2010	\N	AUTFONLOC	86042E	\N	\N	\N	\N	\N
5016	\N	\N	1999-02-06 00:00:00	ANCIEN	\N	Président Chambre de commerce et d'industrie de la haute Cor	Président de la Chambre de commerce et d'industrie de la haute Corse et de Bastia	suite à décision 98-171 du C.C en date du 28/01-1999 (incompatibilité)	1986	\N	\N	DIVERS	98008R	\N	\N	\N	\N	\N
5226	\N	\N	2008-03-16 00:00:00	ANCIEN	\N	Communauté de communes du Pays de Dol-de-Bretagne 	Président de la Communauté de communes du Pays de Dol-de-Bretagne 	\N	\N	2008	29999	INTERCOM	98045W	\N	\N	de la 	\N	\N
5234	\N	\N	2003-08-28 00:00:00	ANCIEN	\N	Communauté de communes du pays guerchais	Président de la communauté de communes du pays guerchais	\N	1994	2003	29999	INTERCOM	98043U	\N	\N	de la 	\N	\N
5239	\N	\N	2020-03-31 00:00:00	ANCIEN	\N	Président du SIVOM de la Marana	Président du SIVOM de la Marana	\N	1989	\N	29999	AUTFONLOC	98008R	\N	\N	\N	\N	\N
5243	\N	\N	\N	ACTIF	\N	Communauté de communes de la Pointe du Médoc	Président  de la Communauté de communes de la Pointe du Médoc	\N	1993	\N	29999	INTERCOM	98021N	\N	\N	de la 	\N	\N
5245	\N	\N	2006-06-29 00:00:00	ANCIEN	\N	Communauté de communes du centre Tregor	Président de la Communauté de communes du centre Tregor	\N	1996	2006	29999	INTERCOM	98012M	\N	\N	de la 	\N	\N
5262	\N	\N	2009-09-09 00:00:00	ANCIEN	\N	Communauté de communes de Guéret - Saint-Vaury	Président de la Communauté de communes de Guéret - Saint-Vaury	District du Pays de Guéret-Saint-Vaury avant 1998	1993	2009	29999	INTERCOM	80024B	\N	\N	de la 	\N	\N
5264	\N	\N	2001-04-20 00:00:00	ANCIEN	\N	Communauté de l'agglomération de Clermont-Ferrand	Président de la communauté de l'agglomération de Clermont-Ferrand	\N	1996	2001	271509	INTERCOM	98009S	\N	\N	de la 	\N	\N
5265	\N	\N	2000-09-15 00:00:00	ANCIEN	\N	Communauté de communes Marseille-Provence-Métropole	Président de la Communauté de communes Marseille-Provence-Métropole	\N	\N	2000	30001	INTERCOM	89029V	\N	\N	de la 	\N	\N
12896	\N	\N	\N	ACTIF	\N	Membre de la commission nationale des monuments historiques	Membre de la commission nationale des monuments historiques	\N	2011	\N	\N	DIVERS	04042C	\N	\N	\N	\N	\N
11410	2008-04-17 00:00:00	\N	\N	ACTIF	\N	Communauté de communes du Pays de Pont-Château - Saint-Gildas-des-Bois	Premier vice-président de la Communauté de communes du Pays de Pont-Château - Saint-Gildas-des-Bois	\N	2008	\N	\N	INTERCOM	01056V	\N	\N	de la 	\N	\N
5811	1998-12-10 00:00:00	\N	1998-06-10 00:00:00	ANCIEN	\N	Parlementaire en Mission	Parlementaire en Mission auprès du Secrétaire à l'Outre-Mer 	Préparation de la loi d'orientation sur l'Outre-Mer	1998	1998	\N	DIVERS	95044H	\N	\N	\N	\N	\N
5268	\N	\N	1999-06-11 00:00:00	ANCIEN	\N	Communauté de communes du Pays Viganais	Président de la Communauté de communes du Pays Viganais	\N	1993	\N	\N	INTERCOM	98034T	\N	\N	de la 	\N	\N
5275	\N	\N	2011-10-27 00:00:00	ANCIEN	\N	Président du sivom de Pampelonne	Président du sivom de Pampelonne	\N	\N	2011	29999	AUTFONLOC	98054X	\N	\N	\N	\N	\N
5276	\N	\N	2011-12-20 00:00:00	ANCIEN	\N	Syndicat intercom. pour l'aménagement du Bassin de l'Aixette	Président du Syndicat intercommunal pour l'aménagement du Bassin de l'Aixette	\N	\N	\N	29999	AUTFONLOC	90004C	\N	\N	\N	\N	\N
5277	\N	\N	2011-10-27 00:00:00	ANCIEN	\N	Communauté de communes du Segala	Vice-président de la communauté de communes du Segala	\N	\N	2011	29999	INTERCOM	98054X	\N	\N	de la 	\N	\N
5278	\N	\N	\N	ACTIF	\N	Président du syndicat mixte de transports en commun	Président du syndicat mixte de transports en commun	\N	\N	\N	\N	AUTFONLOC	98009S	\N	\N	\N	\N	\N
5279	\N	\N	\N	ANCIEN	\N	Pays d'Aunis	Président du Pays d'Aunis	demande de modification 28/10/2003: "ancien président"; Modif le 31/10	\N	2003	30001	AUTFONLOC	98014P	\N	\N	\N	\N	\N
5280	1995-07-05 00:00:00	\N	2008-04-11 00:00:00	ANCIEN	\N	Communauté de communes Arguenon-Hunaudaye	Vice-président de la Communauté de communes Arguenon-Hunaudaye	\N	1995	2008	29999	INTERCOM	98038X	\N	\N	de la 	\N	\N
5813	\N	\N	2002-06-27 00:00:00	ANCIEN	\N	Président de l'association des maires de France	Président de l'association des maires de France	Réelection pour la 4ème fois le 21 novembre 2001, élu pour 3 ans	\N	2002	\N	DIVERS	92017R	\N	\N	\N	\N	\N
5815	1999-09-17 00:00:00	\N	\N	ACTIF	\N	Commissaire européen	Commissaire européen	\N	1999	\N	\N	DIVERS	95008D	\N	\N	\N	\N	\N
5823	\N	\N	2024-03-13 00:00:00	ANCIEN	\N	Conseiller communautaire de Lille	Conseiller communautaire de Lille	\N	1992	1995	\N	AUTFONLOC	99001N	\N	\N	\N	\N	\N
5837	\N	\N	2001-04-20 00:00:00	ANCIEN	\N	Communauté urbaine du Grand Lyon	Vice-président de la Communauté urbaine du Grand Lyon	\N	\N	2001	\N	INTERCOM	99002P	\N	\N	de la 	\N	\N
5879	2000-09-15 00:00:00	\N	2008-04-17 00:00:00	ANCIEN	\N	Marseille-Provence-Métropole Communauté urbaine	Président de Marseille-Provence-Métropole Communauté urbaine	\N	2000	2008	1005477	INTERCOM	89029V	\N	\N	de 	\N	\N
1789	\N	\N	\N	ANCIEN	\N	Syndicat mixte départemental d'eau et d'assainissement	Vice-président du Syndicat mixte départemental d'eau et d'assainissement	\N	\N	2008	\N	AUTFONLOC	95038K	\N	\N	\N	\N	\N
5881	\N	\N	\N	ACTIF	\N	Communauté d'agglomération périgourdine	Président de la communauté d'agglomération périgourdine	\N	1999	\N	59066	INTERCOM	98031Q	\N	\N	de la 	\N	\N
5883	\N	\N	2009-05-28 00:00:00	ANCIEN	\N	Président du pays "Beauce Gâtinais en Phitiverais"	Président du pays "Beauce Gâtinais en Phitiverais"	\N	1996	2009	\N	AUTFONLOC	83043S	\N	\N	\N	\N	\N
11598	\N	\N	\N	ACTIF	\N	Membre du Comité d'orientation du centre d'études	Membre du Comité d'orientation du centre d'études sur les réseaux, les transports, l'urbanisme et les constructions publiques	\N	\N	\N	\N	DIVERS	08027V	\N	\N	\N	\N	\N
11612	\N	\N	\N	ANCIEN	\N	Membre du Haut conseil de la population et de la famille	Membre du Haut conseil de la population et de la famille	\N	2004	2007	\N	DIVERS	08034U	\N	\N	\N	\N	\N
11613	\N	\N	\N	ACTIF	\N	Administrateur du fonds d'action et de soutien pour l'intég	Administrateur du fonds d'action et de soutien pour l'intégration et la lutte contre les discriminations	\N	2005	\N	\N	DIVERS	08034U	\N	\N	\N	\N	\N
11637	\N	\N	\N	ACTIF	\N	Président du Mouvement républicain et citoyen	Président du Mouvement républicain et citoyen	\N	\N	\N	\N	DIVERS	02053W	\N	\N	\N	\N	\N
11305	\N	\N	2022-05-13 00:00:00	ANCIEN	\N	Assoc nationale pour l'étude de la neige et des avalanches	Président de l'Association nationale pour l'étude de la neige et des avalanches	bq 12/12/2007	2007	\N	\N	DIVERS	83031N	\N	\N	\N	\N	\N
11475	\N	\N	\N	ACTIF	\N	Pdt du GART	Président du Groupement des autorités responsables des transports	\N	2008	\N	\N	DIVERS	04065K	\N	\N	\N	\N	\N
11640	\N	\N	\N	ACTIF	\N	Président d'honneur de l'association pour le tgv Rhin - Rhôn	Président d'honneur de l'association pour le tgv Rhin - Rhône Méditerranée	\N	\N	\N	\N	DIVERS	02053W	\N	\N	\N	\N	\N
11658	\N	\N	2008-03-01 00:00:00	ANCIEN	\N	Communauté d'agglomération de Quimper-Communauté	Conseiller, Communauté d'agglomération de Quimper-Communauté	\N	1999	2008	\N	INTERCOM	08043V	\N	\N	de la 	\N	\N
11868	1985-04-01 00:00:00	\N	\N	ACTIF	\N	Président de la mission Locale Est Etang de Berre 	Président de la mission Locale Est Etang de Berre 	\N	1985	\N	\N	AUTFONLOC	08040S	\N	\N	\N	\N	\N
53887	1515-10-31 00:50:39	\N	\N	ACTIF	\N	métropole européenne de Lille	\N	\N	\N	\N	\N	INTERCOM	18207D	\N	\N	de la	\N	\N
11674	\N	\N	2020-06-28 00:00:00	ANCIEN	\N	Communauté de communes du Pays de Douarnenez	Vice-président de la Communauté de communes du Pays de Douarnenez	\N	2008	\N	\N	INTERCOM	08047A	\N	\N	de la 	\N	2014-10-09 12:18:50
11697	2001-04-01 00:00:00	\N	\N	ACTIF	\N	Communauté d'agglomération du Bassin d'Aurillac	Président de la Communauté d'agglomération du Bassin d'Aurillac	\N	\N	\N	\N	INTERCOM	08051V	\N	\N	de la 	\N	\N
11921	\N	\N	2020-01-01 00:00:00	ANCIEN	\N	Communauté de communes de l'ouest guyanais	Conseiller, Communauté de communes de l'ouest guyanais	\N	2008	\N	\N	INTERCOM	08073C	\N	\N	de la 	\N	\N
11942	\N	\N	\N	ACTIF	\N	Vice-président de l'Association des maires de France	Vice-président de l'Association des maires de France	\N	\N	\N	\N	DIVERS	98027U	\N	\N	\N	\N	\N
11943	\N	\N	\N	ACTIF	\N	Président de l'association des maires du Cantal	Président de l'Association des maires du Cantal	\N	\N	\N	\N	DIVERS	98027U	\N	\N	\N	\N	\N
11235	2007-01-16 00:00:00	\N	\N	ACTIF	\N	Membre correspondant de l'Académie nationale de Médecine	Membre correspondant de l'Académie nationale de Médecine	courriel assistante 18 avril 2007	2007	\N	\N	DIVERS	04075M	\N	\N	\N	\N	\N
11239	\N	\N	\N	ACTIF	\N	Syndicat mixte du Bassin de vie d'Avignon	Président du Syndicat mixte du Bassin de vie d'Avignon	courriel de l'assistant de M. Milon, le 19 avril 2007	\N	\N	\N	AUTFONLOC	04092N	\N	\N	\N	\N	\N
11755	\N	\N	\N	ACTIF	\N	Communauté d'agglomération de Nîmes-Métropole	Président de la Communauté d'agglomération de Nîmes-Métropole	\N	2002	\N	\N	INTERCOM	08065C	\N	\N	de la 	\N	2014-10-10 16:00:59
11757	\N	\N	\N	ANCIEN	\N	Administrateur de l'école nationale supérieure des technique	Administrateur de l'école nationale supérieure des techniques industrielles et des mines d'Alès	\N	\N	2008	\N	DIVERS	08065C	\N	\N	\N	\N	\N
11758	\N	\N	2014-10-01 00:00:00	ANCIEN	\N	Président du Conseil d'orientation du forum pour la gestion 	Président du Conseil d'orientation du forum pour la gestion des villes et des collectivités territoriales	\N	2007	\N	\N	DIVERS	08065C	\N	\N	\N	\N	2014-10-10 16:01:52
11759	\N	\N	\N	ANCIEN	\N	Administrateur du Centre national pour le développement du s	Administrateur du Centre national pour le développement du sport	\N	2006	2008	\N	DIVERS	08065C	\N	\N	\N	\N	\N
11771	\N	\N	\N	ACTIF	\N	Président de l'Agence nationale pour l'information sur le lo	Président de l'Agence nationale pour l'information sur le logement	\N	2004	\N	\N	DIVERS	08067E	\N	\N	\N	\N	\N
11772	\N	\N	\N	ACTIF	\N	Membre du Conseil national de la formation des élus locaux	Membre du Conseil national de la formation des élus locaux	\N	2005	\N	\N	DIVERS	08067E	\N	\N	\N	\N	\N
11375	2008-04-16 00:00:00	\N	2014-04-01 00:00:00	ANCIEN	\N	Communauté de communes des Trois Frontières	Vice-présidente de la Communauté de communes des Trois Frontières	mail de l'assitante (Yannick Tschanz) du 18/06/2008	\N	\N	\N	INTERCOM	04045F	\N	\N	de la 	\N	2014-05-14 09:38:05
11468	\N	\N	\N	ACTIF	\N	Commission du fonds national pour l'archéologie	Membre de la Commission du fonds national pour l'archéologie préventive	\N	2005	\N	\N	DIVERS	08008S	\N	\N	\N	\N	\N
11469	\N	\N	\N	ANCIEN	\N	Communauté d'agglomération belfortaine	Conseiller, Communauté d'agglomération belfortaine	\N	\N	2008	\N	INTERCOM	08008S	\N	\N	de la 	\N	\N
11785	\N	\N	\N	ACTIF	\N	Membre de la Commission d'information auprès de l'installati	Membre de la Commission d'information auprès de l'installation nucléaire de base secrète du CEA / Valduc	\N	\N	\N	\N	DIVERS	08069G	\N	\N	\N	\N	\N
11471	\N	\N	\N	ACTIF	\N	Syndicat mixte de l'Aire Urbaine	Président du Syndicat mixte de l'Aire Urbaine	\N	\N	\N	\N	AUTFONLOC	08008S	\N	\N	\N	\N	\N
11801	2001-03-01 00:00:00	\N	2008-03-01 00:00:00	ANCIEN	\N	Communauté de communes de Ventadour	Vice-présidente de la Communauté de communes de Ventadour	\N	2001	2008	\N	INTERCOM	08050U	\N	\N	de la 	\N	\N
11834	\N	\N	\N	ANCIEN	\N	Communauté d'agglomeration belfortaine	Président de la Communauté d'agglomeration belfortaine	président du district de l'agglomeration berfortaine  (1977-2000) puis de la CA	1977	2008	\N	INTERCOM	02053W	\N	\N	de la 	\N	\N
11782	\N	\N	\N	ACTIF	\N	Membre du Comité d'orientation du centre d'études sur les ré	Membre du Comité d'orientation du centre d'études sur les réseaux, les transports, l'urbanisme et les constructions publiques	\N	2001	\N	\N	DIVERS	08069G	\N	\N	\N	\N	\N
11833	\N	\N	\N	ANCIEN	\N	Communauté des communes du Saint-Affricain	Président de la communauté des communes du Saint-Affricain	\N	2001	2008	\N	INTERCOM	08066D	\N	\N	de la 	\N	\N
11839	\N	\N	\N	ANCIEN	\N	Association des Petites Villes de Fance	Membre du Bureau de l'Association des petites villes de France	\N	\N	2008	\N	DIVERS	08032S	\N	\N	\N	\N	\N
11836	\N	\N	2016-03-01 00:00:00	ANCIEN	\N	Syndicat Intercommunal à vocation unique de la Basse vallée 	Vice-président du SIVU de la Basse vallée de l'Ain	\N	\N	\N	\N	AUTFONLOC	08056B	\N	\N	\N	\N	\N
11837	\N	\N	\N	ACTIF	\N	Association des maires ruraux de l'Ain	Vice-présidente de l'Association des maires ruraux de l'Ain	\N	\N	\N	\N	DIVERS	08056B	\N	\N	\N	\N	2014-11-05 15:36:46
11840	\N	\N	2017-10-01 00:00:00	ANCIEN	\N	Morlaix Communauté	Morlaix Communauté	\N	2001	\N	\N	INTERCOM	08045X	\N	\N	de 	\N	2017-11-15 10:19:53
11869	\N	\N	\N	ACTIF	\N	Vice-Président du syndicat mixte des Transports de l'Est de 	Vice-Président du syndicat mixte des Transports de l'Est de l'Etang de Berre 	\N	1991	\N	\N	AUTFONLOC	08040S	\N	\N	\N	\N	\N
11944	\N	\N	\N	ACTIF	\N	Membre du comité de Bassin Adour Garonne	Membre du comité de Bassin Adour Garonne	\N	\N	\N	\N	DIVERS	98027U	\N	\N	\N	\N	\N
11875	\N	\N	\N	ACTIF	\N	Communauté d'Agglomération du Pays de Laon	Président de la Communauté de communes du Laonnois	\N	\N	\N	0	INTERCOM	08010L	\N	\N	de la 	\N	2017-10-16 10:23:51
11945	\N	\N	\N	ACTIF	\N	Membre de la commission permanente du comité de Massif 	Membre de la commission permanente du comité de Massif - Massif central	\N	\N	\N	\N	DIVERS	98027U	\N	\N	\N	\N	\N
11946	\N	\N	\N	ACTIF	\N	Membre du Conseil national de la Montagne	Membre du Conseil national de la Montagne	\N	\N	\N	\N	DIVERS	98027U	\N	\N	\N	\N	\N
11947	\N	\N	\N	ACTIF	\N	Membre du comité directeur de l'Association française AFCCRE	Membre du Comité directeur de l'Association française du Conseil des communes et des régions d'Europe 	\N	\N	\N	\N	DIVERS	98027U	\N	\N	\N	\N	\N
11362	2000-01-01 00:00:00	\N	2008-04-10 00:00:00	ANCIEN	\N	Communauté d'agglomération Fréjus - Saint-Raphaël	Président de la Communauté d'agglomération Fréjus - Saint-Raphaël	\N	2000	2008	\N	INTERCOM	08007R	\N	\N	de la 	\N	\N
11845	\N	\N	\N	ACTIF	\N	Président de la Fondation Res Publica, reconnue d'utilité pu	Président de la Fondation Res Publica, reconnue d'utilité publique	\N	\N	\N	\N	DIVERS	02053W	\N	\N	\N	\N	\N
11886	\N	\N	2022-05-13 00:00:00	ANCIEN	\N	Communauté de Communes du Massif du Vercors	Président de la Communauté de Communes du Massif du Vercors	\N	1993	2000	\N	INTERCOM	83031N	\N	\N	de la 	\N	\N
11938	\N	\N	2017-10-23 00:00:00	ANCIEN	\N	Président du SIEL 42	Président du Syndicat Intercommunal d'énergies de la Loire	Courrier questure du 8 janvier 2009	\N	\N	\N	AUTFONLOC	97011G	\N	\N	\N	\N	2017-11-09 10:45:28
11939	\N	\N	\N	ACTIF	\N	Union des Communes rurales de la Loire	Président de l'Union des Communes rurales de la Loire	Courrier questure du 8 janvier 2009	\N	\N	\N	AUTFONLOC	97011G	\N	\N	\N	\N	\N
11949	\N	\N	\N	ACTIF	\N	Membre du bureau de l'Association des petites Villes de Fran	Membre du bureau de l'Association des petites villes de France 	\N	\N	\N	\N	DIVERS	98027U	\N	\N	\N	\N	\N
11950	\N	\N	\N	ACTIF	\N	Membre titulaire du Comité des finances locales	Membre titulaire du Comité des finances locales	\N	\N	\N	\N	DIVERS	98027U	\N	\N	\N	\N	\N
11951	\N	\N	\N	ANCIEN	\N	Président de l'Association Nationale des Elus de Montagne	Président de l'Association nationale des élus de Montagne	\N	\N	2008	\N	DIVERS	98027U	\N	\N	\N	\N	\N
11952	2009-03-01 00:00:00	\N	\N	ACTIF	\N	Vice-Présidente de l'AGAS	Vice-Présidente de l'Association pour la gestion des assistants de sénateurs (AGAS)	\N	2009	\N	\N	DIVERS	01031L	\N	\N	\N	\N	\N
11960	2009-01-01 00:00:00	\N	\N	ACTIF	\N	PDG de la SEMEXVAL	PDG de la SEMEXVAL (Société d'économie mixte locale d'expansion de La Valette)	Mail de l'assistant du 28/05/2009	2009	\N	\N	DIVERS	04041B	\N	\N	\N	\N	\N
11149	\N	\N	2021-09-28 00:00:00	ANCIEN	\N	Président de l'Union des maires de l'Aisne	Président de l'Union des maires de l'Aisne	remarque assistante 08/06/05	\N	\N	\N	DIVERS	78003A	\N	\N	\N	\N	\N
11150	\N	\N	2021-09-28 00:00:00	ANCIEN	\N	Président du Sivom d'Hartennes	Président du Sivom d'Hartennes	remarque assistante 08/06/05	\N	\N	\N	DIVERS	78003A	\N	\N	\N	\N	\N
11151	\N	\N	2021-09-28 00:00:00	ANCIEN	\N	Président du Haut comité français pour la défense civile	Président du Haut comité français pour la défense civile	remarque assistante 08/06/05	\N	\N	\N	DIVERS	78003A	\N	\N	\N	\N	\N
11156	1995-07-24 00:00:00	\N	2008-03-21 00:00:00	ANCIEN	\N	Communauté urbaine de Bordeaux	Vice-président de la Communauté urbaine de Bordeaux	demande de Mme Kady le 12/07/2005	1995	2008	\N	INTERCOM	80046H	\N	\N	de la 	\N	\N
11158	\N	\N	\N	ACTIF	\N	Président du Cercle Français de l'Eau	Président du Cercle Français de l'Eau	Mail assistante 22/07/05	2004	\N	\N	DIVERS	82002D	\N	\N	\N	\N	\N
11159	\N	\N	\N	ANCIEN	\N	Président (fondateur) du parc naturel régional des marais 	Président (fondateur) du parc naturel régional des marais du Cotentin et du Bessin	Mail assistante 22/07/05	1990	1998	\N	DIVERS	82002D	\N	\N	\N	\N	\N
11160	\N	\N	\N	ANCIEN	\N	Président fondateur de l'ANEZH	Président (fondateur) de l'ANEZH (Association nationale des élus des zones humides) 	Mail assistante 22/07/05	\N	2003	\N	DIVERS	82002D	\N	\N	\N	\N	\N
11167	\N	\N	\N	ANCIEN	\N	Président de la fédération des Industries ferroviaires (FIF)	Président de la fédération des Industries ferroviaires (FIF)	\N	2005	2007	\N	DIVERS	04040A	\N	\N	\N	\N	\N
11172	\N	\N	2008-03-31 00:00:00	ANCIEN	\N	Syndicat mixte du Pays de Vierzon	Président du Syndicat mixte du Pays de Vierzon	\N	1997	2008	\N	AUTFONLOC	05012A	\N	\N	\N	\N	\N
11280	2002-01-15 00:00:00	\N	2008-04-18 00:00:00	ANCIEN	\N	Communauté de communes de Cambremer	Président de la Communauté de communes de Cambremer	courriel d'un internaute : 05/09/2007	2002	2008	\N	INTERCOM	89007P	\N	\N	de la 	\N	\N
11535	\N	\N	2015-09-04 00:00:00	ANCIEN	\N	Membre du bureau de l'Assemblée des départements de France 	Membre du bureau de l'Assemblée des départements de France	\N	2004	\N	\N	DIVERS	08016S	\N	\N	\N	\N	2015-09-07 15:49:38
11838	\N	\N	\N	ACTIF	\N	Membre du conseil de surveillance du CHU de Toulouse	Membre du conseil de surveillance du CHU de Toulouse	\N	\N	\N	\N	AUTFONLOC	08033T	\N	\N	\N	\N	\N
11857	\N	\N	\N	ANCIEN	\N	Communauté de communes de l'ouest guyanais	Président de la Communauté de communes de l'ouest guyanais	\N	1994	2001	\N	INTERCOM	08073C	\N	\N	de la 	\N	\N
11858	\N	\N	\N	ANCIEN	\N	Vice-président du Parc naturel régional de Guyane	Vice-président du Parc naturel régional de Guyane	\N	1996	2001	\N	DIVERS	08073C	\N	\N	\N	\N	\N
11867	\N	\N	\N	ACTIF	\N	Agglopole Provence	Premier Vice-Président de l'Agglopole Provence	\N	2002	\N	\N	INTERCOM	08040S	\N	\N	de l'	\N	\N
11874	\N	\N	\N	ANCIEN	\N	Président de la chambre de commerce et industrie de l'Indre	Président de la chambre de commerce et industrie de l'Indre	\N	1997	2001	\N	DIVERS	08062Y	\N	\N	\N	\N	\N
12900	\N	\N	2015-09-08 00:00:00	ANCIEN	\N	Conseil national de la culture scientifique et technique	Membre du Conseil national de la culture scientifique, technique et industrielle	\N	2012	\N	\N	DIVERS	04043D	\N	\N	\N	\N	2015-09-09 10:28:38
11915	\N	\N	\N	ANCIEN	\N	Communauté de communes du Parisis	Vice-présidente de la communauté de communes du Parisis	\N	\N	2008	\N	INTERCOM	04100U	\N	\N	de la 	\N	\N
11934	\N	\N	\N	ANCIEN	\N	Président de l'Association des Maires et élus du Tarn	Président de l'Association des Maires et élus du Tarn	\N	\N	2007	\N	DIVERS	95052H	\N	\N	\N	\N	\N
11870	\N	\N	\N	ACTIF	\N	Airfobep (Association agréée pour la surveillance de la qualité de l'air Etang de Berre Ouest des Bouches du Rhône)	Président de l'Airfobep (Association agréée pour la surveillance de la qualité de l'air Etang de Berre Ouest des Bouches du Rhône)	\N	1998	\N	\N	INTERCOM	08040S	\N	\N	de l'	\N	\N
11871	\N	\N	\N	ACTIF	\N	Groupement d'intérêt public pour la réhabilitation de l'étang de Berre	Président du Groupement d'intérêt public pour la réhabilitation de l'étang de Berre	\N	2000	\N	\N	INTERCOM	08040S	\N	\N	du 	\N	\N
11872	\N	\N	\N	ACTIF	\N	Syndicat d'aménagement du Bassin de l'arc	Président du Syndicat d'aménagement du Bassin de l'arc	\N	2001	\N	\N	INTERCOM	08040S	\N	\N	du 	\N	\N
11873	\N	\N	\N	ANCIEN	\N	Multi pôle Étang de Berre	Président du Multi pôle Étang de Berre	\N	1992	2002	\N	INTERCOM	08040S	\N	\N	du	\N	\N
11876	\N	\N	2016-07-04 00:00:00	ANCIEN	\N	Président du Syndicat Mixte	Président du Syndicat Mixte de Préfiguration du Parc Naturel Régional des Pré-Alpes d'Azur	Mail assistant	\N	\N	\N	AUTFONLOC	08038Y	\N	\N	\N	\N	2016-07-11 16:55:07
11877	\N	\N	\N	ANCIEN	\N	Agence Régionale d'Équipement et d'Aménagement	Président Directeur général de l'Agence régionale d'équipement et d'aménagement	Mail assistant	\N	2009	\N	AUTFONLOC	08038Y	\N	\N	\N	\N	\N
11935	\N	\N	\N	ACTIF	\N	Pdt du Syndicat départemental de traitement des déchets	Président du Syndicat départemental de traitement des déchets (TRIFYL) et production d'énergies renouvelables	\N	\N	\N	\N	DIVERS	95052H	\N	\N	\N	\N	\N
11941	\N	\N	\N	ACTIF	\N	Président d'ODIT France, Observation, Développement Ingénier	Président d'ODIT (Observation, Développement Ingénierie Touristique) France	courriel assistant parlementaire 13/02/2009	\N	\N	\N	DIVERS	95009E	\N	\N	\N	\N	\N
11197	\N	\N	\N	ANCIEN	\N	Co-Président de l' A.N.E.V. 	Co-Président de l' A.N.E.V.  (Association Nationale des Elus de la Vigne et du Vin)	Mail assistant du 1 août 2006	2006	2013	0	DIVERS	80013X	\N	\N	\N	\N	2014-02-04 10:14:19
11198	\N	\N	\N	ACTIF	\N	Agglomération de la région de Compiègne	Président de l'Agglomération de la région de Compiègne	Mail assistant du 02/08/06	2005	\N	\N	INTERCOM	92035T	\N	\N	de l'	\N	\N
11199	1996-05-09 00:00:00	\N	\N	ACTIF	\N	Syndicat mixte de la Vallée de l'Oise	Président du Syndicat mixte de la Vallée de l'Oise	Mail assistant du 02/08/06	1996	\N	\N	AUTFONLOC	92035T	\N	\N	\N	\N	\N
11243	\N	\N	2020-06-25 00:00:00	ANCIEN	\N	Communauté d'agglomération havraise	Vice-président de la Communauté d'agglomération havraise	demande assistante M. Gélard, juin 2007	\N	\N	\N	INTERCOM	95034F	\N	\N	de la 	\N	\N
11937	2008-12-11 00:00:00	\N	\N	ACTIF	\N	Président de l'Union sociale pour l'habitat	Président de l'Union sociale pour l'habitat	\N	\N	\N	\N	DIVERS	04090L	\N	\N	\N	\N	\N
11953	2008-06-13 00:00:00	\N	2015-01-01 00:00:00	ANCIEN	\N	Pays de la Baie du Mont Saint-Michel	Président du pays de la Baie du Mont Saint-Michel	\N	\N	\N	\N	INTERCOM	96004D	\N	\N	du 	\N	2015-02-27 10:25:40
11977	\N	\N	\N	ACTIF	\N	Communauté de communes du Vézelien	Président de la communauté de communes du Vézelien	\N	2009	\N	\N	INTERCOM	09011R	\N	\N	de la 	\N	\N
11962	\N	\N	\N	ANCIEN	\N	Membre du Haut Conseil des Biotechnologies	Membre du Haut Conseil des Biotechnologies	\N	2000	2010	\N	DIVERS	08016S	\N	\N	\N	\N	\N
12052	2008-03-15 00:00:00	\N	2016-01-12 00:00:00	ANCIEN	\N	Communauté d'agglomération de Valenciennes Métropole	Présidente de la Communauté d'agglomération de Valenciennes Métropole	\N	2008	\N	\N	INTERCOM	01043Q	\N	\N	de la 	\N	2016-06-02 17:15:13
11978	\N	\N	\N	ANCIEN	\N	Sivom de Vézelay	Président du sivom de Vézelay	\N	\N	2009	\N	INTERCOM	09011R	\N	\N	du 	\N	\N
11843	2008-04-21 00:00:00	\N	2015-12-31 00:00:00	ANCIEN	\N	Communauté urbaine Marseille Provence Metropole	Conseiller, Communauté urbaine Marseille Provence Metropole	\N	\N	\N	\N	INTERCOM	08048B	\N	\N	de la 	\N	2016-07-08 10:49:09
11844	\N	\N	\N	ANCIEN	\N	Vice-présidente de l'Assemblée des Français de l'étranger	Vice-présidente de l'Assemblée des Français de l'étranger	Mail de la sénatrice le 20/01/2009	2006	2009	\N	DIVERS	08017T	\N	\N	\N	\N	\N
11954	\N	\N	\N	ACTIF	\N	Président de la société d'économie alpestre de Haute-Savoie	Président de la société d'économie alpestre de la Haute-Savoie (SEA 74)	\N	\N	\N	\N	AUTFONLOC	95005A	\N	\N	\N	\N	\N
11955	\N	\N	\N	ACTIF	\N	Pdt du syndicat d'électricité des énergies et d'équipement 	Président du syndicat des énergies et de l'aménagement numérique de la Haute-Savoie (SYANE)	Mai assistant du 16/072010	\N	\N	\N	AUTFONLOC	95005A	\N	\N	\N	\N	\N
11956	\N	\N	\N	ACTIF	\N	Pdt syndicat intercomunal d'électricité vallée de Thones	Président du syndicat intercommunal d'électricité de la vallée de Thones (SIEVT)	\N	\N	\N	\N	AUTFONLOC	95005A	\N	\N	\N	\N	\N
11957	\N	\N	2014-04-01 00:00:00	ANCIEN	\N	Vice-Président de la CNIL	Vice-Président de la Commission nationale de l'informatique et des libertés (CNIL)	\N	\N	\N	0	DIVERS	95005A	\N	\N	\N	\N	2014-04-17 14:19:42
11959	\N	\N	\N	ACTIF	\N	Vice-pdt fédération nationale des collectivités concédantes	Vice-président de la Fédération nationale des collectivités concédantes et régies	\N	\N	\N	\N	DIVERS	95005A	\N	\N	\N	\N	\N
12840	2008-09-01 00:00:00	\N	2014-10-01 00:00:00	ANCIEN	\N	Assemblée des français de l'étranger	Vice-président de l'Assemblée des français de l'étranger	\N	\N	\N	\N	DIVERS	11026G	\N	\N	\N	\N	2014-10-23 12:12:01
12348	\N	\N	2015-12-31 00:00:00	ANCIEN	\N	Communauté urbaine de Nantes Métropole	\N	\N	2001	\N	\N	INTERCOM	11065P	\N	\N	de la 	\N	2016-07-08 11:07:50
12841	1994-06-01 00:00:00	\N	2008-08-31 00:00:00	ANCIEN	\N	Assemblée des français de l'étranger	Membre de l'Assemblée des français de l'étranger	\N	\N	\N	\N	DIVERS	11026G	\N	\N	\N	\N	\N
12825	2002-01-01 00:00:00	\N	\N	ACTIF	\N	Communauté d'agglomération de l'Artois	\N	\N	\N	\N	\N	INTERCOM	11062L	\N	\N	de la	\N	\N
12144	2011-04-10 00:00:00	\N	\N	ACTIF	\N	communauté de communes du Bassin de Mortagne-au-Perche	\N	\N	2001	\N	\N	INTERCOM	11100Y	\N	\N	de la	\N	\N
12191	1997-01-01 00:00:00	\N	2012-02-26 00:00:00	ANCIEN	\N	Communauté de communes du pays du Martel	\N	\N	\N	\N	\N	INTERCOM	11012A	\N	\N	de la	\N	\N
12849	\N	\N	2014-04-01 00:00:00	ANCIEN	\N	Communauté d'agglomération du Nord Basse-Terre	\N	\N	2011	\N	0	INTERCOM	11113E	\N	\N	de la 	\N	2014-04-09 22:37:10
12850	2001-03-18 00:00:00	\N	\N	ACTIF	\N	Communauté de communes de Marie-Galante	de la Communauté de communes de Marie-Galante	\N	\N	\N	\N	INTERCOM	11114F	\N	\N	de la 	\N	2014-11-10 12:13:04
12851	2001-03-01 00:00:00	\N	\N	ACTIF	\N	Communauté intercommunale des villes solidaires	\N	\N	\N	\N	\N	INTERCOM	11020A	\N	\N	de la 	\N	\N
12876	\N	\N	2019-08-19 00:00:00	ANCIEN	\N	Secrétaire Général de l'AVICCA	Secrétaire Général de l'AVICCA (Association des villes et collectivités pour les communications électroniques et l'audiovisuel)	\N	2011	\N	\N	DIVERS	01061S	\N	\N	\N	\N	\N
12419	2009-05-01 00:00:00	\N	\N	ACTIF	\N	Élu de l'Assemblée de la Province Sud	Élu de l'Assemblée de la Province Sud de Nouvelle-Calédonie	\N	\N	\N	\N	DIVERS	11010L	\N	\N	\N	\N	\N
12507	2002-01-01 00:00:00	\N	\N	ACTIF	\N	Communauté d'agglomération de Metz-Métropole	\N	\N	\N	\N	\N	INTERCOM	11049P	\N	\N	de la	\N	2018-05-30 09:32:22
12770	\N	\N	2012-01-01 00:00:00	ANCIEN	\N	Communauté d'agglomération de Clichy Montfermeil	\N	\N	2001	2012	\N	INTERCOM	11051H	\N	\N	de la 	\N	\N
12772	\N	\N	\N	ANCIEN	\N	Syndicat d'Agglomération Nouvelle Marne-La-Vallée Val-Maubuée	\N	\N	1989	2011	\N	INTERCOM	11074Q	\N	\N	du 	\N	\N
12774	2010-01-01 00:00:00	\N	2011-10-13 00:00:00	ANCIEN	\N	Est ensemble	\N	\N	\N	\N	\N	INTERCOM	11054L	\N	\N	d'	\N	\N
12788	2001-03-18 00:00:00	\N	2015-04-01 00:00:00	ANCIEN	\N	Communauté d'agglomération de Pau Pyrénées	\N	\N	\N	\N	\N	INTERCOM	11110B	\N	\N	de la 	\N	2017-05-23 10:35:10
12800	2008-03-21 00:00:00	\N	\N	ANCIEN	\N	Communauté d'agglomération de Versailles Grand Parc	\N	\N	\N	2014	\N	INTERCOM	11091R	\N	\N	de la 	\N	2014-11-18 16:30:44
12801	1995-03-01 00:00:00	\N	2022-02-03 00:00:00	ANCIEN	\N	Communauté de communes de Thèze	\N	\N	\N	\N	\N	INTERCOM	11112D	\N	\N	de la 	\N	\N
12804	2000-03-01 00:00:00	\N	2014-04-08 00:00:00	ANCIEN	\N	Communauté d'agglomération Tours Plus	\N	\N	\N	\N	0	INTERCOM	11108H	\N	\N	de la	\N	2015-04-08 15:32:59
12806	1989-03-01 00:00:00	\N	2001-03-01 00:00:00	ANCIEN	\N	Clermont Communauté	\N	\N	\N	\N	\N	INTERCOM	11104D	\N	\N	de	\N	\N
12812	2001-03-18 00:00:00	\N	2016-06-30 00:00:00	ANCIEN	\N	Communauté urbaine du Grand Nancy	\N	\N	\N	\N	\N	INTERCOM	11048N	\N	\N	de la	\N	2016-07-08 11:06:50
12815	2001-03-18 00:00:00	\N	\N	ANCIEN	\N	Communauté urbaine de Nantes	\N	\N	\N	2008	\N	INTERCOM	11067R	\N	\N	de la	\N	\N
12829	2001-06-01 00:00:00	\N	\N	ANCIEN	\N	Communauté d'agglomération Hénin-Carvin	\N	\N	\N	2011	\N	INTERCOM	11063M	\N	\N	de la 	\N	\N
12871	2011-11-14 00:00:00	\N	2016-04-27 00:00:00	ANCIEN	\N	Président de l'Observatoire interministériel de l'accessibi	Président de l'Observatoire interministériel de l'accessibilité et de la conception universelle	\N	2011	\N	\N	DIVERS	05008E	\N	\N	\N	\N	2016-05-03 16:59:01
11451	\N	\N	\N	ACTIF	\N	Communauté d'agglomération du Val-d'Yerres	Vice-président de la Communauté d'agglomération du Val-d'Yerres	chargées des affaires culturelles puis des finances (mail assistante 04/09/2008)	2002	\N	\N	INTERCOM	01001E	\N	\N	de la 	\N	\N
11985	2009-01-01 00:00:00	\N	\N	ACTIF	\N	représentant de l'ADF à la CNASA	Représentant de l'Assemblée des départements de France à la Caisse nationale de solidarité pour l'autonomie	mail de l'assistante du 1er septembre 2009	2009	\N	\N	DIVERS	08052W	\N	\N	\N	\N	\N
11986	\N	\N	\N	ACTIF	\N	Représentant de l' ADF au conseil national de l'évaluation s	Représentant de l'Assemblée des départements de France au Conseil national de l'évaluation sociale et médico-sociale	\N	2009	\N	\N	DIVERS	08052W	\N	\N	\N	\N	\N
11990	\N	\N	2009-12-07 00:00:00	ANCIEN	\N	Communauté de communes d'Aubusson-Felletin	Vice-Présidente de la communauté de communes d'Aubusson-Felletin	Fiche accueil sénateur du 16/09/09. Mail de l'adjoint de Mme Nicoux le 7/12/2009	2009	2009	\N	INTERCOM	09012S	\N	\N	de la 	\N	\N
12031	\N	\N	\N	ACTIF	\N	Communauté de communes de la Brie Nangissienne	Conseiller,  communauté de communes de la Brie Nangissienne	\N	2010	\N	\N	INTERCOM	04054G	\N	\N	de la 	\N	\N
12035	\N	\N	\N	ACTIF	\N	 Elus de la Montagne (ANEM)	Membre du Comité de l'Association Nationale des Elus de la Montagne (ANEM)	Mail assistant du 16/07/2010	2010	\N	\N	DIVERS	95005A	\N	\N	\N	\N	\N
12070	\N	\N	2002-11-11 00:00:00	ANCIEN	\N	Syndicat intercommunal de développement économique de la Lomagne	Président du syndicat intercommunal de développement économique de la Lomagne	\N	\N	2002	25000	INTERCOM	89008Q	\N	\N	du 	\N	\N
12067	\N	\N	\N	ACTIF	\N	Syndicat Intercommunal d'Electricité des Yvelines Nord-Est	Conseiller, Syndicat Intercommunal d'Electricité des Yvelines Nord-Est	\N	2011	\N	\N	AUTFONLOC	11001K	\N	\N	\N	\N	\N
12068	\N	\N	\N	ACTIF	\N	Syndicat d'énergie des Yvelines	Deuxième vice-présidente du syndicat d'énergie des Yvelines,	\N	2011	\N	\N	AUTFONLOC	11001K	\N	\N	\N	\N	\N
12030	\N	\N	\N	ACTIF	\N	Communauté de communes du pays de Charlieu	Première vice-Présidente de la communauté de communes du pays de Charlieu	\N	2008	\N	\N	INTERCOM	10005K	\N	\N	de la 	\N	\N
12044	\N	\N	2014-06-11 00:00:00	ANCIEN	\N	Président du Forum Français pour la Sécurité Urbaine	Président du Forum Français pour la Sécurité Urbaine	Mail de l'assistant du 21/10/2010	2010	2014	\N	DIVERS	01053S	\N	\N	\N	\N	\N
12019	\N	\N	2020-03-16 00:00:00	ANCIEN	\N	Premier vice Président du conservatoire du littoral 	Premier vice Président du conservatoire du littoral 	\N	2010	\N	\N	DIVERS	01065W	\N	\N	\N	\N	\N
12020	\N	\N	2020-03-16 00:00:00	ANCIEN	\N	Président du Conseil des rivages de la Corse	Président du Conseil des rivages de la Corse	\N	2010	\N	\N	DIVERS	01065W	\N	\N	\N	\N	\N
11991	\N	\N	\N	ACTIF	\N	Section française de l'Assemblée parlementaire	Membre du bureau de la Section française de l'Assemblée parlementaire de la francophonie (A.P.F.)	Mail du 17/09/09	\N	\N	\N	DIVERS	08017T	\N	\N	\N	\N	\N
1771	\N	\N	2013-07-14 00:00:00	ANCIEN	\N	District urbain de Saumur	Président du district urbain de Saumur	\N	\N	2013	35466	INTERCOM	92026S	\N	\N	du 	\N	\N
6656	\N	\N	2014-04-04 00:00:00	ANCIEN	\N	Président de la Société d'équipemt et de const° de la Sarthe	Président de la Société d'équipement et de construction de la Sarthe SECOS	\N	\N	\N	0	DIVERS	95019G	\N	\N	\N	\N	2014-04-08 09:33:02
6657	\N	\N	2012-07-07 00:00:00	ANCIEN	\N	Conseiller du commerce extérieur de la France	Conseiller du commerce extérieur de la France	\N	\N	2012	\N	DIVERS	89023P	\N	\N	\N	\N	\N
6660	\N	\N	\N	ACTIF	\N	Membre de la fédération de l'énergie du Pas-de-Calais	Membre de la fédération départementale de l'énergie du Pas-de-Calais	\N	\N	\N	\N	DIVERS	92043T	\N	\N	\N	\N	\N
6661	\N	\N	\N	ANCIEN	\N	Président de l'association des maires du Pas-de-Calais	Président de l'association des maires du Pas-de-Calais	\N	\N	2004	\N	DIVERS	92043T	\N	\N	\N	\N	\N
6662	\N	\N	\N	ACTIF	\N	Communauté de communes du Pays de la faience de Desvres	Vice-président de la Communauté de communes du Pays de la faience de Desvres	\N	\N	\N	\N	INTERCOM	92043T	\N	\N	de la 	\N	\N
6667	\N	\N	2003-01-01 00:00:00	ANCIEN	\N	SEML fonds régional de garantie Nord-Pas-de-Calais	Président de la SEML fonds régional de garantie Nord-Pas-de-Calais	\N	\N	2003	\N	AUTFONLOC	02001J	\N	\N	\N	\N	\N
6735	\N	\N	2002-03-22 00:00:00	ANCIEN	\N	Président de l'association interrégionale du Grand Est	président de l'association interrégionale du Grand Est	\N	2000	2002	\N	DIVERS	01026P	\N	\N	\N	\N	\N
6736	\N	\N	\N	ANCIEN	\N	Vice-président de l'Association des Départements de France	Vice-président de l'Association des Départements de France	\N	\N	2009	\N	DIVERS	92005M	\N	\N	\N	\N	\N
6737	\N	\N	\N	ANCIEN	\N	Psdt de la Com° Europe de l'Associat° des Dépt de France	Président de la commission Europe de l'Association des Départements de France	\N	\N	2004	\N	DIVERS	92005M	\N	\N	\N	\N	\N
6738	\N	\N	\N	ANCIEN	\N	Psdt de la dél° fr du comité des régions de l'Un° européenne	Président de la délégation française du comité des régions de l'Union européenne	\N	2002	2004	\N	DIVERS	92005M	\N	\N	\N	\N	\N
6754	\N	\N	2014-04-01 00:00:00	ANCIEN	\N	Communauté de communes du Pays de Saint-Bonnet-le-Château 	Président de la Communauté de communes du Pays de Saint-Bonnet-le-Château 	\N	\N	\N	\N	INTERCOM	97011G	\N	\N	de la 	\N	2014-07-09 15:07:00
6755	2002-05-03 00:00:00	\N	2016-11-12 00:00:00	ANCIEN	\N	Observatoire national des changements climatiques	Président de l'Observatoire national sur les effets du réchauffement climatique en France métropolitaine et dans les départements et territoires d'outre-mer	\N	2002	\N	\N	DIVERS	96003C	\N	\N	\N	\N	2016-11-14 11:07:47
6763	\N	\N	2019-07-13 00:00:00	ANCIEN	\N	Communauté de communes de la vallée du Gapeau	Président de la communauté de communes de la vallée du Gapeau	\N	\N	\N	\N	INTERCOM	02006P	\N	\N	de la 	\N	\N
6764	\N	\N	\N	ACTIF	\N	\N	Président de la caisse nationale de retraite des agents des collectivités locales CNRACL (depuis le 12/02/90 et réélu en avril 2002)	\N	\N	\N	\N	DIVERS	98030P	\N	\N	\N	\N	\N
6774	\N	\N	\N	ANCIEN	\N	Président de l'AGAS	Président de l'Association pour la gestion des assistants de sénateurs  (AGAS)	\N	\N	2004	\N	DIVERS	97009N	\N	\N	\N	\N	\N
6776	2002-12-01 00:00:00	\N	\N	ANCIEN	\N	Présidence du Haut Conseil de la coopération internationale	Présidence du Haut Conseil de la coopération internationale	\N	2002	2005	\N	DIVERS	66002K	\N	\N	\N	\N	\N
6780	\N	\N	\N	ANCIEN	\N	Chef d'état indéterminé	Chef d'état indéterminé pour les grouvernements indéterminés	ne pas supprimer cet enregistrement	\N	1981	\N	ETAT	000800	\N	\N	\N	\N	\N
6786	2003-01-27 00:00:00	\N	2020-09-11 00:00:00	ANCIEN	\N	Membre de l'Académie des Sciences morales et politiques	Membre de l'Académie des Sciences morales et politiques	BQ du 28/01/2003	2003	\N	\N	DIVERS	77058M	\N	\N	\N	\N	\N
6787	\N	\N	\N	ACTIF	\N	Membre conseil national d'insertion par activité économique	Membre du conseil national d'insertion par l'activité économique	\N	\N	\N	\N	DIVERS	89041R	\N	\N	\N	\N	\N
6793	\N	\N	2014-03-30 00:00:00	ANCIEN	\N	CommunautÃ© de communes du Pays Riolais	Président de la Communauté de communes du Pays Riolais	\N	1999	\N	0	INTERCOM	03001N	\N	\N	de la 	\N	2014-04-07 11:29:00
9759	2003-03-18 00:00:00	\N	\N	ACTIF	\N	Président de l'Adiflor                                      	Président de l'Association pour la diffusion internationale francophone de livres, ouvrages et revues (Adiflor)	BQ 19/03/03	2003	\N	\N	DIVERS	01041N	\N	\N	\N	\N	\N
9761	\N	\N	\N	ACTIF	\N	Conseiller du président international du Forum 	Conseiller du président international du Forum francophone des affaires	BQ 19/03/03	\N	\N	\N	DIVERS	01041N	\N	\N	\N	\N	\N
9762	\N	\N	2003-03-18 00:00:00	ANCIEN	\N	Président de l'Adiflor	Président de l'Association pour la diffusion internationale francophone de livres, ouvrages et revues	BQ  19/03/03	1997	2003	\N	DIVERS	92024Q	\N	\N	\N	\N	\N
11236	\N	\N	2014-04-01 00:00:00	ANCIEN	\N	Pays d'Angers	Président du Pays d'Angers	demande formulée par le sénateur par courriel le 4 avril 2007	\N	\N	\N	AUTFONLOC	01016M	\N	\N	\N	\N	2014-09-08 11:55:48
10373	\N	\N	2013-06-10 00:00:00	ANCIEN	\N	Communauté urbaine	Vice-président de la communauté urbaine	\N	\N	2013	210000	INTERCOM	79002D	\N	\N	de la 	\N	\N
10374	\N	\N	2003-03-31 00:00:00	ANCIEN	\N	Syndicat mixte d'urbanisme et d'aménagement des pays de Houdan et de Montfort lamaury	Président du syndicat mixte d'urbanisme et d'aménagement des pays de Houdan et de Montfort lamaury	\N	\N	2003	58592	INTERCOM	59570W	\N	\N	du 	\N	\N
10375	\N	\N	2016-03-03 00:00:00	ANCIEN	\N	District de l'agglomération de Périgueux	Président du district de l'agglomération de Périgueux	\N	\N	2016	60000	INTERCOM	89032Q	\N	\N	de l' 	\N	\N
10377	1977-01-01 00:00:00	\N	\N	ACTIF	\N	Communauté d'agglomération de Cergy-Pontoise	\N	\N	\N	\N	173000	INTERCOM	95063L	\N	\N	de la 	\N	\N
10392	\N	\N	2022-05-07 00:00:00	ANCIEN	\N	Communauté de communes du Pays Beaumontois	Vice-président de la Communauté de communes du Pays Beaumontois	secrétariat 05 53 27 65 15	2001	\N	\N	INTERCOM	02005N	\N	\N	de la 	\N	\N
10393	\N	\N	2022-05-07 00:00:00	ANCIEN	\N	Communauté de communes du Pays Beaumontois	Président de la Communauté de communes du Pays Beaumontois	\N	1995	2001	\N	INTERCOM	02005N	\N	\N	de la 	\N	\N
10394	\N	\N	2022-05-07 00:00:00	ANCIEN	\N	Président du CDJA de la Dordogne	Président du CDJA de la Dordogne, de la FDSEA et de la chambre d'agriculture de Dordogne	\N	\N	1997	\N	DIVERS	02005N	\N	\N	\N	\N	\N
10395	\N	\N	2022-05-07 00:00:00	ANCIEN	\N	Président de la caisse régionale du CrA de Charente-Périgord	Président de la caisse régionale du Crédit agricole de Charente-Périgord	\N	\N	2002	\N	DIVERS	02005N	\N	\N	\N	\N	\N
10449	2001-10-31 00:00:00	\N	\N	ACTIF	\N	Communauté d'agglomération de Bourges	Président de la Communauté d'agglomération de Bourges	\N	\N	\N	100000	INTERCOM	98025S	\N	\N	de la 	\N	\N
10448	2003-04-28 00:00:00	\N	\N	ACTIF	\N	Association régionale des Sem d'Ile de France	Président de l'Association régionale des sociétés d'économie mixte d'Ile de France	bulletin quotidien, 29 avril 2003	2003	\N	\N	DIVERS	93005R	\N	\N	\N	\N	\N
10450	2001-12-28 00:00:00	\N	2018-04-27 00:00:00	ANCIEN	\N	Communauté d'agglomération de Brive	Président de la Communauté d'agglomération de Brive	\N	2001	2008	75000	INTERCOM	98007Q	\N	\N	de la 	\N	2018-04-30 14:05:27
11296	\N	\N	2016-11-17 00:00:00	ANCIEN	\N	Vice-Président du service départemental d'incendie et de secours	Vice-Président du service départemental d'incendie et de secours	\N	\N	\N	\N	DIVERS	07032N	\N	\N	\N	\N	2016-11-18 12:37:49
11298	\N	\N	2016-11-17 00:00:00	ANCIEN	\N	Syndicat mixte de l'aéroport de Châteauroux	Président du Syndicat mixte de l'aéroport Marcel-Dassault de Châteauroux-Déols	\N	\N	2008	\N	AUTFONLOC	07032N	\N	\N	\N	\N	2016-11-18 12:37:49
11299	\N	\N	2016-11-17 00:00:00	ANCIEN	\N	Syndicat intercommunal de l'assainissement	Président du Syndicat intercommunal de gestion de l'assainissement autonome dans l'Indre	\N	\N	\N	\N	AUTFONLOC	07032N	\N	\N	\N	\N	2016-11-18 12:37:49
11415	2008-04-11 00:00:00	\N	\N	ACTIF	\N	Communauté de communes Arguenon-Hunaudaye	Conseiller, Communauté de communes Arguenon-Hunaudaye	\N	2008	\N	\N	INTERCOM	98038X	\N	\N	de la 	\N	\N
11443	\N	\N	2023-10-03 00:00:00	ANCIEN	\N	Ambassadeur itinérant en Asie	Ambassadeur itinérant en Asie	bulletin quotidien, 13/08/2008	2008	\N	\N	DIVERS	80046H	\N	\N	\N	\N	\N
11832	2008-04-17 00:00:00	\N	2015-12-31 00:00:00	ANCIEN	\N	Marseille-Provence-Métropole Communauté urbaine	Vice-présidente de Marseille-Provence-Métropole Communauté urbaine	\N	\N	\N	\N	INTERCOM	08035V	\N	\N	de 	\N	2016-06-23 10:58:56
11671	\N	\N	2014-02-13 00:00:00	ANCIEN	\N	Communauté de communes du Pays d'Argentat	Président de la Communauté de communes du Pays d'Argentat	\N	1989	2010	\N	INTERCOM	08046Y	\N	\N	de la 	\N	2014-02-14 10:05:07
11696	\N	\N	2014-04-01 00:00:00	ANCIEN	\N	Communauté de communes du Pays de la Serre	Président de la Communauté de communes du Pays de la Serre	Mail assistant 09/10	1986	\N	0	INTERCOM	08052W	\N	\N	de la 	\N	2014-04-09 10:57:27
11831	\N	\N	\N	ACTIF	\N	Association départementale des maires de la Côte-d'Or	Président de l'Association départementale des maires de la Côte-d'Or	\N	\N	\N	\N	AUTFONLOC	08070Y	\N	\N	\N	\N	\N
11698	2009-01-01 00:00:00	\N	\N	ACTIF	\N	Membre du bureau de l'Assemblée des départements de France	Président de la commission des affaires sociales et familiales de l'Association des départements de France	mail de l'assistante du 1er septembre 2009	2009	\N	\N	DIVERS	08052W	\N	\N	\N	\N	\N
11709	\N	\N	\N	ACTIF	\N	Communauté d'agglomération périgourdine	Président de la Communauté d'agglomération périgourdine	\N	2001	\N	\N	INTERCOM	08055A	\N	\N	de la 	\N	\N
11767	\N	\N	\N	ACTIF	\N	Voies navigables de France	Administrateur des Voies navigables de France, président de la commission territoriale	\N	1998	\N	\N	DIVERS	08061X	\N	\N	\N	\N	\N
11769	\N	\N	\N	ACTIF	\N	Conseil national de la chasse et de la faune sauvage	Membre du Conseil national de la chasse et de la faune sauvage	\N	1999	\N	\N	DIVERS	08061X	\N	\N	\N	\N	\N
11846	\N	\N	\N	ANCIEN	\N	Président du Service Départemental d'Incendie et de Secours 	Président du Service Départemental d'Incendie et de Secours de l'Ain 	\N	1997	2008	\N	AUTFONLOC	08059E	\N	\N	\N	\N	\N
11847	\N	\N	2008-10-24 00:00:00	ANCIEN	\N	Communauté de communes de la région de Pons	Président de la Communauté de communes de la région de Pons	\N	\N	\N	\N	INTERCOM	08015R	\N	\N	de la 	\N	\N
11861	2001-06-01 00:00:00	\N	\N	ACTIF	\N	syndicat departemental d'alimentation en eau potable	Président du syndicat départemental d'alimentation en eau potable	\N	2001	\N	\N	AUTFONLOC	08014Q	\N	\N	\N	\N	\N
11865	2001-04-01 00:00:00	\N	2004-03-31 00:00:00	ANCIEN	\N	Communauté d'agglomération de Montpellier	Vice-président de la Communauté d'agglomération de Montpellier	\N	2001	2004	\N	INTERCOM	08021P	\N	\N	de la 	\N	\N
11866	2008-03-09 00:00:00	\N	\N	ACTIF	\N	Communauté de communes de Privas-Rhônes-Vallées	Premier Vice-Président de la Communauté de communes de Privas-Rhônes-Vallées	\N	2008	\N	\N	INTERCOM	08057C	\N	\N	de la 	\N	\N
12024	2010-01-01 00:00:00	\N	\N	ACTIF	\N	Syctom	Vice-président du syndicat intercommunal de traitement des ordures ménagères de l'agglomération parisienne (Syctom)	Mél de l'assistant le 15/04/2010	\N	\N	\N	AUTFONLOC	07024N	\N	\N	\N	\N	\N
12022	2010-01-01 00:00:00	\N	2015-12-31 00:00:00	ANCIEN	\N	Communauté d'agglomération du Coeur-de-Seine	Président de la Communauté d'agglomération du Coeur-de-Seine	Mél de l'assistant le 15/04/2010	\N	\N	\N	INTERCOM	07024N	\N	\N	de la 	\N	2016-06-23 16:25:38
11384	\N	\N	2021-07-07 00:00:00	ANCIEN	\N	Directeur puis Pdt Ecole Ntle Supérieure des Mines de Paris	Directeur puis Président de l'Ecole nationale supérieure des Mines de Paris	\N	\N	1995	\N	DIVERS	85003S	\N	\N	\N	\N	\N
11387	\N	\N	2021-07-07 00:00:00	ANCIEN	\N	Membre du CA de la société France 5	Membre du Conseil d'administration de la société France 5	\N	\N	\N	\N	DIVERS	85003S	\N	\N	\N	\N	\N
11388	\N	\N	2021-07-07 00:00:00	ANCIEN	\N	Pdt Association Franco-Allemande Science et technologie	Président de l'Association Franco-Allemande de la science et de la technologie	\N	\N	\N	\N	DIVERS	85003S	\N	\N	\N	\N	\N
11389	\N	\N	2021-07-07 00:00:00	ANCIEN	\N	Président Fondateur de la Fondation Sophia Antipolis	Président Fondateur de la Fondation Sophia Antipolis	\N	\N	\N	\N	DIVERS	85003S	\N	\N	\N	\N	\N
11390	\N	\N	2021-07-07 00:00:00	ANCIEN	\N	Pdt Fondateur Association Internationale des Parcs scient	Président fondateur de l'Association internationale des parcs scientifiques	\N	\N	\N	\N	DIVERS	85003S	\N	\N	\N	\N	\N
11391	\N	\N	2021-07-07 00:00:00	ANCIEN	\N	Membre de l'Académie suédoise des sciences de l'ingénieur	Membre de l'Académie suédoise des sciences de l'ingénieur	\N	\N	\N	\N	DIVERS	85003S	\N	\N	\N	\N	\N
11424	\N	\N	\N	ACTIF	\N	Communauté de communes Auzances - Bellegarde	Vice-président de la Communauté de communes Auzances - Bellegarde	\N	\N	\N	\N	INTERCOM	73006G	\N	\N	de la 	\N	\N
12023	2010-01-01 00:00:00	\N	\N	ACTIF	\N	Syelom	Président du syndicat mixte des Hauts-de-Seine pour l'élimination des ordures ménagères (Syelom)	Mél de l'assistant le 15/04/2010	\N	\N	\N	AUTFONLOC	07024N	\N	\N	\N	\N	\N
11403	\N	\N	\N	ACTIF	\N	Communauté d'agglomération de Bayonne-Anglet-Biarritz	Premier vice-président de la Communauté d'agglomération de Bayonne-Anglet-Biarritz	\N	2008	\N	\N	INTERCOM	92013M	\N	\N	de la 	\N	\N
11404	\N	\N	2014-04-01 00:00:00	ANCIEN	\N	Communauté d'agglomération dracénoise	Conseiller, Communauté d'agglomération dracénoise	\N	2008	\N	0	INTERCOM	04038G	\N	\N	de la 	\N	2014-04-08 15:57:42
11405	2008-04-10 00:00:00	\N	\N	ACTIF	\N	Communauté d'agglomération Fréjus - Saint-Raphaël	Premier vice-président de la Communauté d'agglomération Fréjus - Saint-Raphaël	\N	2008	\N	\N	INTERCOM	08007R	\N	\N	de la 	\N	\N
11406	2008-04-10 00:00:00	\N	\N	ACTIF	\N	Communauté de communes du Mirebellois	Président de la Communauté de communes du Mirebellois	\N	2008	\N	\N	INTERCOM	98048A	\N	\N	de la 	\N	\N
11407	2008-04-17 00:00:00	\N	2015-12-31 00:00:00	ANCIEN	\N	Marseille-Provence-Métropole Communauté urbaine	Vice-président de Marseille-Provence-Métropole Communauté urbaine	\N	2008	\N	\N	INTERCOM	89029V	\N	\N	de 	\N	2016-06-20 16:21:10
11408	\N	\N	\N	ACTIF	\N	Communauté de communes du canton de Bergues	Conseillère, Communauté de communes du canton de Bergues	\N	2008	\N	\N	INTERCOM	01045S	\N	\N	de la 	\N	\N
11425	2006-01-01 00:00:00	\N	2009-01-01 00:00:00	ANCIEN	\N	Communauté de communes du Parisis	Vice-président de la Communauté de communes du Parisis	\N	2006	2009	\N	INTERCOM	04078Q	\N	\N	de la 	\N	\N
11426	\N	\N	\N	ACTIF	\N	Communauté d'agglomération de Bayonne-Anglet-Biarritz	Conseillère, Communauté d'agglomération de Bayonne-Anglet-Biarritz	\N	2008	\N	\N	INTERCOM	06001B	\N	\N	de la 	\N	\N
11175	\N	\N	2017-09-30 00:00:00	ANCIEN	\N	Communauté de communes des Vals de Cher et d'Arnon	Président de la Communauté de communes des Vals de Cher et d'Arnon	\N	2000	\N	\N	INTERCOM	05012A	\N	\N	de la 	\N	2018-02-01 14:16:39
11177	\N	\N	2013-06-12 00:00:00	ANCIEN	\N	Agence de financement des infrastructures de transport de Fr	Président de l'Agence de financement des infrastructures de transport de France 	\N	2005	\N	\N	DIVERS	01048V	\N	\N	\N	\N	2013-06-13 10:33:20
11179	\N	\N	\N	ACTIF	\N	Communauté de communes de Saint-Laurent-de-Neste	Présidente de la Communauté de communes de Saint-Laurent-de-Neste	\N	\N	\N	\N	INTERCOM	92020L	\N	\N	de la 	\N	\N
11180	2005-03-16 00:00:00	\N	\N	ACTIF	\N	Conseil d'orientation de la MIVILUDES	Membre du conseil d'orientation de la mission interministérielle de vigilance et de lutte contre les dérives sectaires (MIVILUDES)	Mail de l'assistant parlementaire du 08/11/05	2005	\N	\N	DIVERS	90004C	\N	\N	\N	\N	\N
11182	\N	\N	2009-03-01 00:00:00	ANCIEN	\N	Présidente de l'AGAS	Présidente de l'Association pour la gestion des assistants de sénateurs  (AGAS)	\N	2005	2009	\N	DIVERS	01031L	\N	\N	\N	\N	\N
11183	\N	\N	\N	ACTIF	\N	Mbre du CA de la Société prof. des Papiers de Presse	Membre du Conseil d'administration de la Société professionnelle des Papiers de Presse	mail 07/12 de son assistante	\N	\N	\N	DIVERS	98048A	\N	\N	\N	\N	\N
11185	2005-05-27 00:00:00	\N	\N	ACTIF	\N	Président de la Commission nationale consultative des gens d	Président de la Commission nationale consultative des gens du voyage	demande assistante 09/01/2006	2005	\N	\N	DIVERS	95038K	\N	\N	\N	\N	\N
11186	\N	\N	2006-07-08 00:00:00	ANCIEN	\N	Membre du Conseil d'orientation de la Fondation du Patrimoin	Membre du Conseil d'orientation de la Fondation du Patrimoine	demande assistante 27/04/2006 	\N	2006	\N	DIVERS	80048K	\N	\N	\N	\N	\N
11187	\N	\N	2006-07-08 00:00:00	ANCIEN	\N	Membre de la Commission aide sélective CNC	Membre de la Commission d'aide sélective à la création et à la modernisation des salles du CNC	\N	\N	2006	\N	DIVERS	80048K	\N	\N	\N	\N	\N
11190	\N	\N	2021-09-28 00:00:00	ANCIEN	\N	Membre du Conseil Immobilier de l'Etat	Membre du Conseil Immobilier de l'Etat	mail assistante 15/06/2006	\N	\N	\N	DIVERS	78003A	\N	\N	\N	\N	\N
11191	\N	\N	2021-09-28 00:00:00	ANCIEN	\N	Membre du Comité de Sélection des Spécialistes en Valeur	Membre du Comité de Sélection des Spécialistes en Valeur du Trésor	\N	\N	\N	\N	DIVERS	78003A	\N	\N	\N	\N	\N
11192	\N	\N	\N	ACTIF	\N	Membre du Conseil national de l'insertion par l'activité éco	Membre du Conseil national de l'insertion par l'activité économique	\N	\N	\N	\N	DIVERS	04081K	\N	\N	\N	\N	\N
11309	\N	\N	2015-12-31 00:00:00	ANCIEN	\N	Communauté de communes de Charenton-le-Pont - Saint-Maurice	Premier vice-président de la Communauté de communes de Charenton-le-Pont - Saint-Maurice	\N	2006	\N	\N	INTERCOM	04042C	\N	\N	de la 	\N	2016-06-23 15:54:54
11463	\N	\N	2017-10-24 00:00:00	ANCIEN	\N	Communauté de communes de Quillebeuf-sur-Seine	Vice-président de la Communauté de communes de Quillebeuf-sur-Seine	\N	\N	\N	\N	INTERCOM	98050T	\N	\N	de la 	\N	2017-11-09 17:58:29
11467	\N	\N	\N	ACTIF	\N	Observatoire national de la sécurité et de l'acc	Membre de l'Observatoire national de la sécurité et de l'accessibilité des établissements d'enseignement	\N	2005	\N	\N	DIVERS	08008S	\N	\N	\N	\N	\N
12076	\N	\N	2014-03-31 00:00:00	ANCIEN	\N	Président de l'Agence de Développement Economique "Alsace In	Président de l'Agence de Développement Economique "Alsace International"	Mail de l'assistant du 29 mars 2011	2011	\N	\N	DIVERS	10015M	\N	\N	\N	\N	2018-02-12 15:09:54
11738	\N	\N	2014-10-01 00:00:00	ANCIEN	\N	Communauté d'agglomération Castelroussine	Président de la Communauté d'agglomération Castelroussine	\N	\N	\N	\N	INTERCOM	08062Y	\N	\N	de la 	\N	2014-10-10 15:51:10
11254	\N	\N	\N	ANCIEN	\N	Membre du Conseil économique et social	Membre du Conseil économique et social	\N	1984	1988	\N	DIVERS	07025P	\N	\N	\N	\N	\N
11255	\N	\N	\N	ANCIEN	\N	Membre du Conseil national de l'enseignement agricole	Membre du Conseil national de l'enseignement agricole	\N	1999	2006	\N	DIVERS	07025P	\N	\N	\N	\N	\N
11259	\N	\N	\N	ANCIEN	\N	Communauté de communes de Saint-Saëns - Porte-de-Bray	Président de la Communauté de communes de Saint-Saëns - Porte-de-Bray	\N	1993	2006	\N	INTERCOM	07025P	\N	\N	de la 	\N	\N
11260	\N	\N	\N	ANCIEN	\N	Vice-président délégué de l'Association régions de France	Vice-président délégué de l'Association des régions de France	\N	2000	2002	\N	DIVERS	07025P	\N	\N	\N	\N	\N
11261	\N	\N	\N	ACTIF	\N	Membre du Comité des régions de l'Union européenne	Membre du Comité des régions de l'Union européenne	\N	2002	\N	\N	DIVERS	07025P	\N	\N	\N	\N	\N
11312	\N	\N	2008-04-21 00:00:00	ANCIEN	\N	Président de l'Association des Maires de l'Indre	Président de l'Association des Maires de l'Indre	courriel de l'assistant de M. Gerbaud, le 20/02/2008 + mail de fin le 22/04/08	\N	2008	\N	DIVERS	89030N	\N	\N	\N	\N	\N
11313	\N	\N	2010-01-13 00:00:00	ANCIEN	\N	Membre du Comité directeur de l'Union des aéroports français	Membre du Comité directeur de l'Union des aéroports français 	courriel de l'assistant de M. Gerbaud, le 20/02/2008	\N	2010	\N	DIVERS	89030N	\N	\N	\N	\N	\N
11364	2008-04-18 00:00:00	\N	2015-12-31 00:00:00	ANCIEN	\N	Communauté urbaine de Strasbourg	Conseillère, Communauté urbaine de Strasbourg	\N	\N	\N	\N	INTERCOM	04061F	\N	\N	de la 	\N	2016-07-08 11:10:58
11365	2008-04-18 00:00:00	\N	\N	ACTIF	\N	Communauté urbaine de Strasbourg	Premier Vice-président de la Communauté urbaine de Strasbourg	\N	2008	\N	\N	INTERCOM	04065K	\N	http://www.strasbourg.eu/accueil	de la 	\N	\N
11380	2000-06-19 00:00:00	\N	2001-03-11 00:00:00	ANCIEN	\N	Communauté de commune d'Oyonnax	Président de la Communauté de commune d'Oyonnax	\N	2000	2001	\N	INTERCOM	89027T	\N	\N	de la 	\N	\N
11416	2004-11-04 00:00:00	\N	\N	ACTIF	\N	Communauté d'agglomération Mâconnais - Val-de-Saône	Conseiller, Communauté d'agglomération Mâconnais - Val-de-Saône	\N	2004	\N	\N	INTERCOM	95020Y	\N	\N	de la 	\N	\N
11417	2008-04-17 00:00:00	\N	2009-05-25 00:00:00	ANCIEN	\N	Marseille-Provence-Métropole Communauté urbaine	Conseiller, Marseille-Provence-Métropole Communauté urbaine	\N	2008	2009	\N	INTERCOM	98022P	\N	\N	de la 	\N	\N
11418	\N	\N	\N	ACTIF	\N	Communauté d'agglomération de Rouen	Vice-président de la Communauté d'agglomération de Rouen	\N	2001	\N	\N	INTERCOM	95003X	\N	\N	de la 	\N	\N
11419	\N	\N	\N	ACTIF	\N	Communauté d'agglomération Arc-de-Seine	Vice-président de la Communauté d'agglomération Arc-de-Seine	\N	\N	\N	\N	INTERCOM	95007C	\N	\N	de la 	\N	\N
11420	2008-04-11 00:00:00	\N	2018-05-28 00:00:00	ANCIEN	\N	communauté d'agglomération Seine-Essonne	Président de la Communauté d'agglomération Seine-Essonne	\N	2008	2009	\N	INTERCOM	04055H	\N	\N	de la 	\N	2018-05-30 15:10:56
11421	\N	\N	\N	ACTIF	\N	Communauté de communes du Pays Yonnais	Vice-président de la Communauté de communes du Pays Yonnais	\N	2001	\N	\N	INTERCOM	95021A	\N	\N	de la 	\N	\N
11422	\N	\N	2021-09-09 00:00:00	ANCIEN	\N	Communauté de communes du Sud-Basse-Terre	Présidente de la Communauté de communes du Sud-Basse-Terre	\N	\N	\N	\N	INTERCOM	95050F	\N	\N	de la 	\N	\N
11423	\N	\N	2022-11-21 00:00:00	ANCIEN	\N	Communauté d'agglomération de Bastia	Vice-président de la Communauté d'agglomération de Bastia	\N	\N	\N	\N	INTERCOM	05011Y	\N	\N	de la 	\N	\N
12910	\N	\N	\N	ACTIF	\N	communauté d'Agglomération d'Agen	\N	\N	2013	\N	\N	INTERCOM	11094U	\N	\N	de la 	\N	\N
12911	\N	\N	\N	ACTIF	\N	pays de l'Agenais	\N	\N	2013	\N	\N	INTERCOM	11094U	\N	\N	du 	\N	\N
11433	\N	\N	\N	ACTIF	\N	Communauté de communes Castillon - Pujols	Président de la Communauté de communes Castillon - Pujols	\N	2003	\N	\N	INTERCOM	90003B	\N	\N	de la 	\N	\N
11428	\N	\N	2014-04-01 00:00:00	ANCIEN	\N	Chartres Métropole	Conseiller, Communauté de communes du Val-de-l'Eure	\N	2008	\N	0	INTERCOM	98023Q	\N	\N	de 	\N	2014-04-08 16:05:02
11429	2002-01-01 00:00:00	\N	\N	ACTIF	\N	Communauté de communes du Pays de Limours	Conseiller communautaire du Pays de Limours	\N	2002	\N	\N	INTERCOM	04050C	\N	\N	de la 	\N	2016-03-11 18:13:18
11431	2014-01-01 00:00:00	\N	\N	ACTIF	\N	Communauté de communes Flandre intérieure	Conseillère de la Communauté de communes Flandre intérieure	\N	\N	\N	\N	INTERCOM	07028S	\N	\N	de la 	\N	2017-06-07 15:50:35
11432	2008-04-10 00:00:00	\N	2015-04-28 00:00:00	ANCIEN	\N	Communauté de communes du Pays de Tronçais	Président de la Communauté de communes du Pays de Tronçais	\N	\N	\N	\N	INTERCOM	98024R	\N	\N	de la 	\N	2017-11-16 16:39:43
11434	\N	\N	\N	ACTIF	\N	Communauté de communes de Cernay et environs	Conseiller, Communauté de communes de Cernay et environs	\N	2001	\N	\N	INTERCOM	07027R	\N	\N	de la 	\N	\N
11435	\N	\N	2016-12-31 00:00:00	ANCIEN	\N	Communauté de communes des Vallées de la Brèche et de la Noye	Président de la Communauté de communes des Vallées de la Brèche et de la Noye	\N	1992	\N	\N	INTERCOM	92045V	\N	\N	de la 	\N	2017-04-21 11:59:14
11436	2008-04-10 00:00:00	\N	\N	ACTIF	\N	Communauté de communes de Benfeld et environs	Conseillère, Communauté de communes de Benfeld et environs	\N	2008	\N	\N	INTERCOM	04069P	\N	\N	de la 	\N	\N
11437	\N	\N	\N	ANCIEN	\N	Communaupole de Lens-Liévin	Vice-présidente de la Communaupole de Lens-Liévin	\N	2001	2008	\N	INTERCOM	01036R	\N	\N	de la 	\N	\N
11439	\N	\N	\N	ACTIF	\N	Communauté de communes de Haute-Charente	Conseiller, Communauté de communes de Haute-Charente	\N	1997	\N	\N	INTERCOM	98039Y	\N	\N	de la 	\N	\N
11440	2008-04-08 00:00:00	\N	\N	ACTIF	\N	Communauté d'agglomération Val Parisis	Vice-président de la Communauté d'agglomération Val-et-Forêt	\N	\N	\N	\N	INTERCOM	04074L	\N	\N	de la 	\N	2017-04-21 11:42:19
11441	2001-04-05 00:00:00	\N	2008-04-08 00:00:00	ANCIEN	\N	Communauté d'agglomération Val-et-Forêt	Président de la Communauté d'agglomération Val-et-Forêt	avant le 30/09/2003 : Communauté de communes Val-et-Forêt	2001	2008	\N	INTERCOM	04074L	\N	\N	de la 	\N	\N
11442	\N	\N	2016-02-01 00:00:00	ANCIEN	\N	Syndicat intercommunal de Valence Major (SIVOM)	Conseiller, Syndicat intercommunal de Valence Major	\N	2001	2016	\N	AUTFONLOC	96006F	\N	\N	\N	\N	\N
11445	2008-04-10 00:00:00	\N	\N	ANCIEN	\N	Communauté de communes du Sillon Mosellan	Président de la Communauté de communes du Sillon Mosellan	Mail assistant du 28/08/08	\N	2014	\N	INTERCOM	01062T	\N	\N	de la 	\N	2014-11-20 12:31:34
11473	\N	\N	\N	ACTIF	\N	Territoire Habitat	Président de Territoire Habitat	\N	2004	\N	\N	AUTFONLOC	08008S	\N	\N	\N	\N	\N
11474	\N	\N	\N	ACTIF	\N	SDIS 90	Président du Service départemental d'incendie et de secours (SDIS) du Territoire de Belfort	\N	2004	\N	\N	AUTFONLOC	08008S	\N	\N	\N	\N	\N
11515	\N	\N	\N	ANCIEN	\N	SIVOM de Bourgneuf-de-Royère	Vice-président du SIVOM de Bourgneuf-de-Royère	\N	\N	2008	\N	AUTFONLOC	08012N	\N	\N	\N	\N	\N
11625	2008-04-17 00:00:00	\N	2020-05-11 00:00:00	ANCIEN	\N	Communauté urbaine Marseille-Provence-Métropole	Vice-président de la  Communauté urbaine Marseille-Provence-Métropole	\N	2008	\N	\N	INTERCOM	08029X	\N	\N	de la 	\N	\N
11666	2008-04-01 00:00:00	\N	2016-12-31 00:00:00	ANCIEN	\N	Communauté d'agglomération du Pays d'Aix	Vice-présidente de la Communauté d'agglomération du Pays d'Aix	\N	\N	\N	\N	INTERCOM	08044W	\N	\N	de la 	\N	2017-11-30 16:57:04
11703	\N	\N	\N	ANCIEN	\N	Communauté de communes du Bassin de vie de Bourg-en-Bresse	Conseiller, Communauté de communes du Bassin de vie de Bourg-en-Bresse	\N	1992	1995	\N	INTERCOM	08053X	\N	\N	de la 	\N	\N
11196	\N	\N	\N	ACTIF	\N	Communauté de communes du Saint-Chinianais	Vice-président de la Communauté de communes du Saint-Chinianais	\N	1995	\N	\N	INTERCOM	06004E	\N	\N	de la 	\N	\N
11237	\N	\N	\N	ANCIEN	\N	SIVOM du canton de Rémuzat	Président du SIVOM du canton de Rémuzat	courriel de M Besson (11 avril 2007)	\N	2007	\N	AUTFONLOC	89015P	\N	\N	\N	\N	\N
11238	\N	\N	\N	ACTIF	\N	Comité régional de tourisme de Rhône-Alpes	Président du Comité régional de tourisme de Rhône-Alpes	courriel de M. Besson (14 octobre 2011)	2011	\N	\N	AUTFONLOC	89015P	\N	\N	\N	\N	\N
11263	\N	\N	\N	ANCIEN	\N	Vice Président du Syndicat Mixte d'Aménagement des Baronnies	Vice Président du Syndicat Mixte d'Aménagement des Baronnies Provençales	Courriel du 16 juillet 2007	2007	2010	\N	AUTFONLOC	89015P	\N	\N	\N	\N	\N
11268	\N	\N	2008-04-18 00:00:00	ANCIEN	\N	Communauté de communes rurales des Monts de Flandres	Présidente de la Communauté de communes rurales des Monts de Flandres	\N	\N	2008	\N	INTERCOM	07028S	\N	\N	de la 	\N	\N
11348	2008-04-08 00:00:00	\N	\N	ACTIF	\N	Communauté d'agglomération Toulon-Provence-Méditerrannée	Première vice-présidente de la Communauté d'agglomération Toulon-Provence-Méditerrannée	Mail assistant	2008	\N	\N	INTERCOM	04041B	\N	\N	de la 	\N	\N
11713	\N	\N	\N	ANCIEN	\N	Communauté de communes Bugey-Vallée de l'Ain	Vice-présidente de la Communauté de communes Bugey-Vallée de l'Ain	\N	2008	2021	\N	INTERCOM	08056B	\N	\N	de la 	\N	\N
11784	\N	\N	\N	ACTIF	\N	Communauté d'agglomération du Grand Dijon	Président de la Communauté d'agglomération du Grand Dijon	\N	2001	\N	\N	INTERCOM	08070Y	\N	\N	de la 	\N	\N
11842	\N	\N	2020-09-24 00:00:00	ANCIEN	\N	Communauté d'agglomération de la Riviera	Vice-présidente de la Communauté d'agglomération de la Riviera	e renouvellement	2001	2009	\N	INTERCOM	08041T	\N	\N	de la 	\N	\N
11809	2008-07-01 00:00:00	\N	2013-02-06 00:00:00	ANCIEN	\N	Communauté urbaine Nice-Côte d'Azur	Vice-Président de la Communauté urbaine Nice-Côte d'Azur	\N	2008	2013	\N	INTERCOM	08036W	\N	\N	de la 	\N	\N
11810	\N	\N	\N	ANCIEN	\N	Communauté de communes autour de Lédignan	Présidente de la Communauté de communes autour de Lédignan	\N	2002	2012	\N	INTERCOM	08063A	\N	\N	de la 	\N	\N
11812	\N	\N	2010-12-31 00:00:00	ANCIEN	\N	SIVOM de l'Etang de l'Or	Présidente du SIVOM de l'Etang de l'Or	\N	2001	\N	\N	AUTFONLOC	08020N	\N	\N	\N	\N	\N
11813	\N	\N	\N	ACTIF	\N	Communauté d'agglomération Vitré-Communauté	Vice-présidente de la Communauté d'agglomération Vitré-Communauté	\N	\N	\N	\N	INTERCOM	08032S	\N	\N	de la 	\N	\N
11819	\N	\N	\N	ACTIF	\N	Régie départementale des transports de la Haute-Garonne	Président de la Régie départementale des transports de la Haute-Garonne	\N	\N	\N	\N	AUTFONLOC	08033T	\N	\N	\N	\N	\N
11821	2008-03-09 00:00:00	\N	\N	ACTIF	\N	Contrat global de développement de la Vallée Eyrieux	Vice-Président du contrat global de développement de la Vallée de l'Eyrieux, de l'Ouvèze et du Plateau de Vernoux	\N	2008	\N	\N	AUTFONLOC	08057C	\N	\N	\N	\N	\N
11822	\N	\N	\N	ANCIEN	\N	Service départemental d'incendie et de secours du Finistère	Président du Service départemental d'incendie et de secours du Finistère	\N	\N	2009	\N	AUTFONLOC	08045X	\N	\N	\N	\N	\N
11288	\N	\N	2008-03-17 00:00:00	ANCIEN	\N	Communauté de communes de Bernay et des environs	Président de la Communauté de communes de Bernay et des environs	courriel DGS 05/11/07	\N	2008	\N	INTERCOM	89022N	\N	\N	de la 	\N	\N
11367	\N	\N	\N	ANCIEN	\N	Communauté de communes des Monts de Châlus	Président de la Communauté de communes des Monts de Châlus	courriel assistant 26 mai 2008	\N	2008	\N	INTERCOM	95055L	\N	\N	de la 	\N	\N
11794	\N	\N	\N	ANCIEN	\N	\N	Président du Conseil d'administration de l'établissement public d'aménagement en Guyane	Mail du 3 juin 2010	1998	2010	\N	DIVERS	08072B	\N	\N	\N	\N	\N
11823	\N	\N	2014-04-01 00:00:00	ANCIEN	\N	SIVOM de Grancey-le-Château	Président du SIVOM de Grancey-le-Château	\N	\N	\N	\N	AUTFONLOC	08069G	\N	\N	\N	\N	2015-01-27 11:22:36
11824	\N	\N	2014-04-01 00:00:00	ANCIEN	\N	Pays Seine-et-Tilles	Président du Pays Seine-et-Tilles	\N	\N	\N	\N	AUTFONLOC	08069G	\N	\N	\N	\N	2015-01-27 11:22:19
11825	\N	\N	\N	ACTIF	\N	Pôle touristique du Pays de Grasse	Président du Pôle touristique du Pays de Grasse	\N	1990	\N	\N	AUTFONLOC	08039A	\N	\N	\N	\N	\N
11826	2007-07-15 00:00:00	\N	2017-05-01 00:00:00	ANCIEN	\N	Conseil territorial de Saint-Barthélémy	Responsable des affaires portuaires et sportives du Conseil territorial de Saint-Barthélémy	\N	2007	\N	\N	AUTFONLOC	08019V	\N	\N	\N	\N	2017-05-15 11:23:19
11457	\N	\N	\N	ACTIF	\N	Communauté de communes du canton de Saint-Béat	Conseiller, Communauté de communes du canton de Saint-Béat	\N	2001	\N	\N	INTERCOM	98011L	\N	\N	de la 	\N	\N
11828	1985-04-01 00:00:00	\N	1990-03-31 00:00:00	ANCIEN	\N	Foyers ruraux de l'Hérault	Président des Foyers ruraux de l'Hérault	\N	1985	1990	\N	AUTFONLOC	08021P	\N	\N	\N	\N	\N
11829	\N	\N	\N	ACTIF	\N	Agence d'urbanisme des Alpes-Maritimes	Président de l'Agence d'urbanisme des Alpes-Maritimes	\N	2004	\N	\N	AUTFONLOC	08042U	\N	\N	\N	\N	\N
11215	2006-10-20 00:00:00	\N	2023-11-25 00:00:00	ANCIEN	\N	Président de l'association des communautés urbaines de Franc	Président de l'association des communautés urbaines de France	BQ 12 octobre 2006	2006	\N	\N	DIVERS	99002P	\N	\N	\N	\N	\N
11593	\N	\N	\N	ACTIF	\N	Communauté de communes Lauragais-Revel-Sorézois	Président de la Communauté de communes Lauragais-Revel-Sorézois	\N	1993	\N	\N	INTERCOM	08028W	\N	\N	de la 	\N	\N
11830	\N	\N	\N	ACTIF	\N	Agence des déplacements et de l'aménagement des Alpes-Mariti	Président de l'agence des déplacements et de l'aménagement des Alpes-Maritimes	\N	\N	\N	\N	AUTFONLOC	08042U	\N	\N	\N	\N	\N
11573	2001-03-01 00:00:00	\N	2014-04-01 00:00:00	ANCIEN	\N	Communauté urbaine de Bordeaux	Vice-présidente de la Communauté urbaine de Bordeaux	\N	\N	\N	0	INTERCOM	08024S	\N	\N	de la 	\N	2014-04-08 15:53:41
11619	\N	\N	2013-02-06 00:00:00	ANCIEN	\N	SIVOM de Villefranche-sur-Mer	Président du SIVOM de Villefranche-sur-Mer	\N	1989	2013	\N	AUTFONLOC	08036W	\N	\N	\N	\N	\N
11624	2014-03-01 00:00:00	\N	2019-12-01 00:00:00	ANCIEN	\N	Communauté d'Agglomération Sophia Antipolis	Vice-Président de la Communauté d'Agglomération Sophia Antipolis	en charge de l'aménagement du territoire et du développement économique	\N	\N	\N	INTERCOM	08038Y	\N	\N	de la 	\N	\N
11626	\N	\N	\N	ANCIEN	\N	Syndicat mixte de Sophia-Antipolis	Vice-Président du Syndicat Mixte de Sophia Antipolis	\N	\N	2019	\N	AUTFONLOC	08038Y	\N	\N	\N	\N	\N
11636	\N	\N	\N	ANCIEN	\N	Communauté d'agglomération Pôle Azur Provence	Président de la Communauté d'agglomération Pôle Azur Provence	\N	2002	2014	0	INTERCOM	08039A	\N	\N	de la 	\N	2014-04-09 10:49:09
11657	2002-01-01 00:00:00	\N	2015-12-31 00:00:00	ANCIEN	\N	métropole Nice-Côte d'Azur	Premier vice-président de la Communauté urbaine Nice-Côte d'Azur	\N	\N	\N	\N	INTERCOM	08042U	\N	\N	de la 	\N	2016-07-08 11:09:05
11965	\N	\N	2011-03-30 00:00:00	ANCIEN	\N	Vice-président de l'Assemblée des départements de France	Vice-président de l'Assemblée des départements de France	demande du sénateur, 24.06.2009	\N	\N	\N	DIVERS	01061S	\N	\N	\N	\N	\N
11204	\N	\N	\N	ACTIF	\N	Membre de la commission énergie au Centre d'Analyse Stratégi	Membre de la Commission Energie au Centre d'Analyse Stratégique	Mail assistant du 1 aout 2006	2006	\N	\N	DIVERS	80013X	\N	\N	\N	\N	\N
11287	2005-01-01 00:00:00	\N	\N	ANCIEN	\N	Communauté d'agglomération du Coeur-de-Seine	Vice-président de la Communauté d'agglomération du Coeur-de-Seine	\N	\N	2010	\N	INTERCOM	07024N	\N	\N	de la 	\N	\N
11374	\N	\N	\N	ANCIEN	\N	Président de la République par intérim	Président de la République par intérim	\N	\N	1974	\N	ETAT	000211	\N	\N	\N	\N	\N
1752	\N	\N	\N	ANCIEN	\N	District du Pays Salonais	Président du District du Pays Salonais	intégré depuis le 01/01/2002 dans la Communauté d'agglomération de Salon-Étang de Berre-Durance - Agglopôle Provence	1989	2001	62000	INTERCOM	89042S	\N	\N	du 	\N	\N
11414	\N	\N	2016-12-31 00:00:00	ANCIEN	\N	Communauté de communes de la Porte du Sundgau	Vice-présidente de la Communauté de communes de la Porte du Sundgau	\N	2008	\N	\N	INTERCOM	04044E	\N	\N	de la 	\N	2017-04-21 14:36:15
1783	\N	\N	\N	ANCIEN	\N	Communauté de communes du Pays d'Amplepuis-Thizy	Président de la Communauté de communes du Pays d'Amplepuis-Thizy	\N	1994	2001	20000	INTERCOM	95049N	\N	\N	de la 	\N	\N
11854	\N	\N	\N	ACTIF	\N	Président du SYMICTOM du Pays de Gourdon	Président du SYMICTOM du Pays de Gourdon	\N	\N	\N	\N	AUTFONLOC	08074D	\N	\N	\N	\N	\N
11817	\N	\N	\N	ANCIEN	\N	Communauté de communes Auxois-Sud	Président de la Communauté de communes Auxois-Sud	\N	1997	2004	\N	INTERCOM	08061X	\N	\N	de la 	\N	\N
11853	\N	\N	\N	ANCIEN	\N	Communauté de communes Sud-Bouriane	Président de la Communauté de communes Sud-Bouriane	\N	\N	2008	\N	INTERCOM	08074D	\N	\N	de la 	\N	\N
11216	\N	\N	2005-12-21 00:00:00	ANCIEN	\N	Communauté de communes de l'Emblavez	Président de la Communauté de communes de l'Emblavez	assistant 13/12/2006 ; avant le 28/12/1995, président du Sivom de l'Emblavez-Retournac-Vorey	1989	2005	10778	INTERCOM	78006D	\N	\N	de la 	\N	\N
11802	2008-04-17 00:00:00	\N	2016-03-21 00:00:00	ANCIEN	\N	Communauté de communes de Bernay et des environs	Président de la communauté de communes de Bernay et des environs	\N	\N	\N	\N	INTERCOM	08009T	\N	\N	de la 	\N	2016-06-02 15:56:44
11803	\N	\N	\N	ACTIF	\N	Communauté d'agglomération du Bassin d'Arcachon-Sud 	Présidente de la Communauté d'agglomération du Bassin d'Arcachon-Sud 	\N	\N	\N	\N	INTERCOM	08022Q	\N	\N	de la 	\N	2014-10-13 14:23:03
11804	\N	\N	\N	ACTIF	\N	Syndicat du Bassin d'Arcachon	Première vice-présidente du Syndicat du Bassin d'Arcachon	\N	\N	\N	\N	AUTFONLOC	08022Q	\N	\N	\N	\N	\N
11885	\N	\N	\N	ANCIEN	\N	Communauté urbaine de Lyon	Conseiller, communauté urbaine de Lyon	\N	\N	1996	\N	INTERCOM	95032D	\N	\N	de la 	\N	\N
11936	\N	\N	\N	ACTIF	\N	Communauté de communes du Gâtinais 	Président de la Communauté de communes du Gâtinais 	\N	\N	\N	\N	INTERCOM	86044G	\N	\N	de la 	\N	\N
11940	\N	\N	2014-11-26 00:00:00	ANCIEN	\N	Vice-Présidente de l'Association des Maires de France	Vice-Présidente de l'Association des Maires de France (Présidente de la commission Intercommunalité)	mail du 4/02/09 de l'assistante	2008	\N	\N	DIVERS	01007L	\N	\N	\N	\N	2014-11-28 19:32:55
12901	\N	\N	2015-09-08 00:00:00	ANCIEN	\N	Commission de la présence postale du Val-de-Marne	Présidente de la Commission départementale de la présence postale territoriale du Val-de-Marne	\N	2012	\N	\N	DIVERS	04043D	\N	\N	\N	\N	2015-09-09 10:28:45
12909	\N	\N	\N	ACTIF	\N	Comité des Prix de Revient  des fabrications d'Armement	Membre du Comité des Prix de Revient  des fabrications d'Armement	\N	2013	\N	\N	DIVERS	01014K	\N	\N	\N	\N	\N
10574	\N	\N	\N	ACTIF	\N	Membre du Haut comité français pour la défense civile	Membre du Haut Comité Français pour la Défense Civile	\N	2003	\N	\N	DIVERS	95056M	\N	\N	\N	\N	\N
10576	2003-12-12 00:00:00	\N	2020-03-21 00:00:00	ANCIEN	\N	Président du Comité national de l'eau	Président du Comité national de l'eau	Bulletin quotidien 12/12/03	2003	1991	\N	DIVERS	86041D	\N	\N	\N	\N	\N
10577	2003-12-10 00:00:00	\N	2023-10-12 00:00:00	ANCIEN	\N	Psdt de la commission des centres culturels de rencontre	Président de la commission nationale des centres culturels de rencontre	BQ 10/12/2003	2003	\N	\N	DIVERS	98041S	\N	\N	\N	\N	\N
10579	2003-01-08 00:00:00	\N	2008-04-08 00:00:00	ANCIEN	\N	Communauté d'agglomération du Val-de-Seine	Président de la Communauté d'agglomération du Val-de-Seine	BQ 9/1/03	2003	\N	\N	INTERCOM	77019E	\N	\N	de la 	\N	\N
10580	\N	\N	2014-06-11 00:00:00	ANCIEN	\N	Nantes-Métropole Communauté urbaine	Vice-président de Nantes-Métropole Communauté urbaine	Rectification erreur 20/1/04: confusion charles et gisèle gautier	\N	2014	\N	INTERCOM	01053S	\N	\N	de 	\N	\N
11251	\N	\N	\N	ANCIEN	\N	Président EPAD	Président du conseil d'administration de l'Etablissement public pour l'aménagement de la région dite "de la Défense"	Président EPAD	2006	2007	\N	DIVERS	07024N	\N	\N	\N	\N	\N
10589	\N	\N	2008-03-16 00:00:00	ANCIEN	\N	Communauté de communes de Sumène-Artense	Conseiller, Communauté de communes de Sumène-Artense	\N	2004	2008	\N	INTERCOM	89010J	\N	\N	de la 	\N	\N
11217	\N	\N	\N	ACTIF	\N	Membre du Comité des régions d'Europe	Membre du Comité des régions d'Europe	\N	1997	\N	\N	DIVERS	80035E	\N	\N	\N	\N	\N
11250	\N	\N	\N	ACTIF	\N	Président de l'Association des maires des Hauts-de-Seine	Président de l'Association des maires des Hauts-de-Seine	Président de l'Association des maires des Hauts-de-Seine	1999	\N	\N	DIVERS	07024N	\N	\N	\N	\N	\N
11427	2003-12-12 00:00:00	\N	2016-10-10 00:00:00	ANCIEN	\N	Communauté de communes Plaines et Forêts d'Yvelines	Conseiller, Communauté de communes Plaines et Forêts d'Yvelines	\N	\N	\N	\N	INTERCOM	86034E	\N	\N	de la 	\N	2016-10-25 11:46:32
11453	\N	\N	2015-01-15 00:00:00	ANCIEN	\N	Communauté de communes d'Artagnan-en-Fézensac	Vice-président de la Communauté de communes d'Artagnan-en-Fézensac	\N	2004	2015	\N	INTERCOM	98033S	\N	\N	de la 	\N	\N
11454	2008-04-11 00:00:00	\N	\N	ACTIF	\N	Communauté de communes de Rivière-Chinon-Saint-Benoist-la-Forêt	Conseiller, Communauté de communes de Rivière-Chinon-Saint-Benoist-la-Forêt	\N	2008	\N	\N	INTERCOM	01012H	\N	\N	de la 	\N	\N
11455	\N	\N	2008-04-11 00:00:00	ANCIEN	\N	Communauté de communes de Rivière-Chinon-Saint-Benoist-la-Forêt	Vice-président de la Communauté de communes de Rivière-Chinon-Saint-Benoist-la-Forêt	 	2001	2008	\N	INTERCOM	01012H	\N	\N	de la 	\N	\N
11458	\N	\N	2014-04-01 00:00:00	ANCIEN	\N	Communauté de communes du Jarnisy	Vice-présidente de la Communauté de communes du Jarnisy	\N	2008	\N	0	INTERCOM	01015L	\N	\N	de la 	\N	2014-04-09 22:41:18
11459	\N	\N	\N	ANCIEN	\N	Communauté de communes du Jarnisy	Conseillère, Communauté de communes du Jarnisy	\N	2001	2008	\N	INTERCOM	01015L	\N	\N	de la 	\N	\N
11460	\N	\N	2014-10-01 00:00:00	ANCIEN	\N	Communauté de communes du Châtillonnais	Conseillère, Communauté de communes du Châtillonnais	\N	1997	\N	\N	INTERCOM	01025N	\N	\N	de la 	\N	2014-10-30 11:26:59
11461	\N	\N	\N	ANCIEN	\N	Communauté de communes du Châtillonnais	Vice-présidente de la Communauté de communes du Châtillonnais	\N	1995	1997	\N	INTERCOM	01025N	\N	\N	de la 	\N	\N
11800	\N	\N	2017-09-30 00:00:00	ANCIEN	\N	Communauté d'agglomération Vitré-Communauté	Vice-Président de la Communauté d'agglomération Vitré-Communauté	\N	2001	\N	\N	INTERCOM	08034U	\N	\N	de la 	\N	2018-01-23 19:00:07
11274	\N	\N	2017-06-20 00:00:00	ANCIEN	\N	Communauté de communes des Crêtes préardennaises	Vice-président de la Communauté de communes des Crêtes préardennaises	\N	2001	\N	\N	INTERCOM	07029T	\N	\N	de la 	\N	2017-11-14 10:36:49
11279	\N	\N	2014-04-01 00:00:00	ANCIEN	\N	Communauté d'agglomération Béziers-Méditerranée	Président de la Communauté d'agglomération Béziers-Méditerranée	\N	\N	\N	0	INTERCOM	07030L	\N	\N	de la 	\N	2014-04-08 16:10:32
11933	\N	\N	2023-07-11 00:00:00	ANCIEN	\N	Président de l'Association des maires de la Somme	Président de l'Association des maires de la Somme	\N	\N	\N	\N	DIVERS	95047L	\N	\N	\N	\N	\N
11506	\N	\N	2016-12-31 00:00:00	ANCIEN	\N	Communauté de communes de la Beauce d'Orgères	Président de la Communauté de communes de la Beauce d'Orgères	\N	2001	\N	\N	INTERCOM	08011M	\N	\N	de la 	\N	2017-12-04 18:31:58
11507	\N	\N	\N	ACTIF	\N	Membre de l'Assemblée des départements de France	Membre de l'Assemblée des départements de France	\N	2001	\N	\N	DIVERS	08011M	\N	\N	\N	\N	\N
11966	2009-01-01 00:00:00	\N	\N	ACTIF	\N	Membre de l'observatoire national de la présence postale	Membre de l'observatoire national de la présence postale	\N	2009	\N	\N	DIVERS	98037W	\N	\N	\N	\N	\N
11969	\N	\N	2021-06-01 00:00:00	ANCIEN	\N	Membre de l'assemblée parlementaire de l'OTAN	Présidente de la commission sur la dimension civile de la sécurité au sein de l'Assemblée parlementaire de l'OTAN	\N	2009	\N	\N	DIVERS	04035D	\N	\N	\N	\N	2018-02-20 20:10:50
11520	\N	\N	2010-03-15 00:00:00	ANCIEN	\N	Membre suppléant du Conseil national de la formation profess	Membre suppléant du Conseil national de la formation professionnelle tout au long de la vie	\N	\N	2010	\N	DIVERS	08013P	\N	\N	\N	\N	\N
11542	\N	\N	2008-10-01 00:00:00	ANCIEN	\N	Membre de l'Assemblée des Français de l'étranger	Membre de l'Assemblée des Français de l'étranger	\N	1994	2008	\N	DIVERS	08018U	\N	\N	\N	\N	\N
11543	\N	\N	\N	ANCIEN	\N	Membre du Conseil national de l'aide juridique	Membre du Conseil national de l'aide juridique	\N	\N	2008	\N	DIVERS	08018U	\N	\N	\N	\N	\N
11862	\N	\N	\N	ACTIF	\N	Communauté d'agglomération de Montluçon	Vice-présidente de la Communauté d'agglomération de Montluçon	\N	2001	\N	\N	INTERCOM	08054Y	\N	\N	de la 	\N	\N
11863	2002-03-01 00:00:00	\N	\N	ACTIF	\N	Communauté d'agglomération du Pays de Montbéliard	Vice-président de la Communauté d'agglomération du Pays de Montbéliard	\N	\N	\N	\N	INTERCOM	08068F	\N	\N	de la 	\N	2018-02-01 19:42:37
11595	\N	\N	\N	ANCIEN	\N	Communauté d'agglomération Rennes-Métropole	Président de la Communauté d'agglomération Rennes-Métropole	\N	1989	2008	\N	INTERCOM	08027V	\N	\N	de la 	\N	\N
11597	\N	\N	\N	ANCIEN	\N	Président de l'institut des villes	Président de l'institut des villes	\N	2001	2007	\N	DIVERS	08027V	\N	\N	\N	\N	\N
12917	\N	\N	\N	ACTIF	\N	\N	Vice-président de l'Assemblée parlementaire de l'OSCE (Organisation pour la Sécurité et la Coopération en Europe) ; président de la délégation française	\N	\N	\N	\N	DIVERS	11105E	\N	\N	\N	2013-06-17 16:11:17	2013-06-17 16:35:44
12920	\N	\N	\N	ACTIF	\N	communauté de communes du Centre Haut-Rhin	\N	\N	2001	\N	\N	INTERCOM	13003V	\N	\N	de la	2013-07-01 09:39:59	\N
12060	2010-01-01 00:00:00	\N	2017-10-07 00:00:00	ANCIEN	\N	Communauté d'agglomération du Pays de l'Or	Vice-présidente de la Communauté de Communes du Pays de l'Or	\N	\N	\N	\N	INTERCOM	08020N	\N	\N	de la 	\N	2017-12-18 16:00:16
12051	2009-12-16 00:00:00	\N	2020-06-28 00:00:00	ANCIEN	\N	Communauté Mulhouse Alsace Agglomération	Président de la communauté Mulhouse Alsace Agglomération	\N	\N	\N	0	INTERCOM	04040A	\N	http://www.mulhouse-alsace.fr	de la 	\N	2017-11-14 11:17:37
11995	2009-10-19 00:00:00	\N	\N	ACTIF	\N	gouverneur du Conseil mondial de l'eau	Gouverneur du Conseil mondial de l'eau	bq 19/10/09	\N	\N	\N	DIVERS	82002D	\N	\N	\N	\N	\N
11979	1989-03-25 00:00:00	\N	2003-03-25 00:00:00	ANCIEN	\N	Communauté d'agglomération de Villefranche	Vice-président de la communauté d'agglomération de Villefranche	\N	1989	2003	\N	INTERCOM	09010Q	\N	\N	de la 	\N	\N
12021	\N	\N	\N	ACTIF	\N	Présidente de l'Observatoire interministériel de l'accessibi	Présidente de l'Observatoire interministériel de l'accessibilité et de la conception universelle	\N	2010	\N	\N	DIVERS	01045S	\N	\N	\N	\N	\N
12025	\N	\N	\N	ACTIF	\N	Président Association des villes marraines des forces armées	Président de l'association des villes marraines des forces armées	\N	2010	\N	\N	DIVERS	07024N	\N	\N	\N	\N	\N
12026	\N	\N	\N	ACTIF	\N	Solidarité Défense	Administrateur de Solidarité Défense	Mail assistant du 10/04/2010	2010	\N	\N	DIVERS	07024N	\N	\N	\N	\N	\N
12027	\N	\N	\N	ACTIF	\N	IHEDN	Vice-président de l'association régionale Paris Ouest de l'IHEDN	Mail assistant du 10/04/2010	2010	\N	\N	DIVERS	07024N	\N	\N	\N	\N	\N
12034	2010-06-16 00:00:00	\N	\N	ACTIF	\N	Président de la MCI départements outre-mer - comité de suivi	Président de la Mission commune d'information sur la situation des départements d'Outre-mer - Comité de suivi	demande de S. Larcher 16/6/2010	2010	\N	\N	DIVERS	04094Q	\N	http://www.senat.fr/commission/missions/Comite_suivi/index.html	\N	\N	\N
11984	\N	\N	\N	ANCIEN	\N	Président de la commission Environnement de l'ADF	Président de la commission Environnement de l'Association des Départements de France	\N	\N	2009	\N	DIVERS	92005M	\N	\N	\N	\N	\N
12032	\N	\N	\N	ACTIF	\N	président du conseil d'administration	Président du conseil d'administration de la SIMKO (société immobilière de Kourou)	Mail du 3 juin 2010	2010	\N	\N	DIVERS	08072B	\N	\N	\N	\N	\N
12033	\N	\N	\N	ACTIF	\N	président du conseil d'administration	Président du conseil d'administration du CIASKISSE ( Centre Intercommunal d'Actions Sociales de Kourou, Iracoubo, Sinnamary et Saint-Elie)	Mail du 3 juin 2010	2010	\N	\N	DIVERS	08072B	\N	\N	\N	\N	\N
5880	\N	\N	2014-03-28 00:00:00	ANCIEN	\N	Communauté d'agglomération de Saint-Quentin	Président de la Communauté d'agglomération de Saint-Quentin	avant le 17/12/1999 : Président du District de Saint-Quentin	1995	\N	78137	INTERCOM	98036V	\N	\N	de la 	\N	2014-04-07 09:53:01
6598	\N	\N	2010-12-31 00:00:00	ANCIEN	\N	Communauté de communes de Prauthoy-en-Montsaugeonnais	Président de la Communauté de communes de Prauthoy-en-Montsaugeonnais	\N	\N	\N	3250	INTERCOM	01057W	\N	\N	de la 	\N	2018-02-22 16:09:03
1776	\N	\N	2024-01-05 00:00:00	ANCIEN	\N	District de l'agglomération messine	Président du district de l'agglomération messine	\N	\N	\N	173000	INTERCOM	74042Q	\N	\N	de l' 	\N	\N
1791	\N	\N	\N	ANCIEN	\N	Communauté de communes du Segala-Carmausin	Président de la Communauté de communes du Segala-Carmausin	\N	1993	1998	10742	INTERCOM	95052H	\N	\N	de la 	\N	\N
12000	\N	\N	\N	ACTIF	\N	Syndicat intercommunal d'assainissement et de restauration des cours d'eau	Vice-présidente du syndicat intercommunal d'assainissement et de restauration des cours d'eau	\N	1995	\N	\N	INTERCOM	10001F	\N	\N	du 	\N	\N
12001	\N	\N	\N	ANCIEN	\N	Communauté de communes du Val d'Essonne	Vice-présidente de la communauté de communes du Val d'Essonne	\N	2001	2008	\N	INTERCOM	10001F	\N	\N	de la 	\N	\N
11992	\N	\N	\N	ACTIF	\N	Pdt du comité d'orientation du Plan urbanisme construction 	Président du comité d'orientation du Plan urbanisme construction architecture	bq 17-9-09	2009	\N	\N	DIVERS	95013A	\N	\N	\N	\N	\N
12002	\N	\N	\N	ANCIEN	\N	Communauté d'agglomération Metz-Métropole	Délégué à la communauté d'agglomération Metz-Métropole	Mél assistant du 22/01/2010	2000	2014	\N	INTERCOM	01060R	\N	\N	de la 	\N	2014-10-16 18:30:27
12003	\N	\N	2016-12-30 00:00:00	ANCIEN	\N	Président du SIVOM des cantons de Vigy et Montigny-Nord 	Président du SIVOM des cantons de Vigy et Montigny-Nord 	Mél assistant du 22/01/2010	\N	\N	\N	AUTFONLOC	01060R	\N	\N	\N	\N	2017-01-31 11:46:34
12004	\N	\N	\N	ANCIEN	\N	Délégué au Syndicat Mixte du SCOT de l'agglomération messine	Délégué au Syndicat Mixte du SCOT de l'agglomération messine	\N	2000	2014	\N	AUTFONLOC	01060R	\N	\N	\N	\N	2014-10-16 18:31:37
12056	\N	\N	\N	ANCIEN	\N	Conseil communautaire de Strasbourg (COS)	Conseiller, Conseil communautaire de Strasbourg (COS)	\N	\N	2011	\N	INTERCOM	10015M	\N	\N	du 	\N	\N
12237	2001-03-18 00:00:00	\N	2014-04-01 00:00:00	ANCIEN	\N	Communauté d'Agglomération du Grand Dax	\N	\N	\N	\N	0	INTERCOM	11014C	\N	\N	de la	\N	2014-04-08 15:55:06
12253	2001-03-18 00:00:00	\N	\N	ACTIF	\N	Communauté d'agglomération du Beauvaisis	\N	\N	\N	\N	\N	INTERCOM	11044J	\N	\N	de la 	\N	\N
12573	2005-06-01 00:00:00	\N	\N	ACTIF	\N	Communauté de communes du Romorantinais et du Monestois	\N	\N	\N	\N	\N	INTERCOM	11106F	\N	\N	de la	\N	\N
12904	\N	\N	2017-10-02 00:00:00	ANCIEN	\N	Président de l'Union des Maires de l'Aisne	Président de l'Union des Maires de l'Aisne	\N	2013	\N	\N	DIVERS	08010L	\N	\N	\N	\N	2017-12-13 11:24:48
12284	\N	\N	2014-04-01 00:00:00	ANCIEN	\N	Val-de-Garonne Agglomération	\N	\N	2008	\N	0	INTERCOM	11095V	\N	\N	de 	\N	2014-04-08 11:46:06
11967	\N	\N	\N	ACTIF	\N	Membre du gouvernement de la Nouvelle-Calédonie	Membre du gouvernement de la Nouvelle-Calédonie chargé de la fonction publique, de la simplification administrative et de la qualité des services publics et du schéma d'aménagement et de développement de la Nouvelle Calédonie NC-2025	\N	2009	\N	\N	DIVERS	92033R	\N	\N	\N	\N	\N
11205	\N	\N	\N	ACTIF	\N	Président de la Commission Nationale d'Evaluation de la Loi 	Président de la Commission Nationale d'Evaluation de la Loi de Programme pour l'Outre-mer	Mail de l'assistant du 05/09/06	\N	\N	\N	DIVERS	92033R	\N	\N	\N	\N	\N
11290	2006-09-28 00:00:00	\N	2008-04-04 00:00:00	ANCIEN	\N	Communauté urbaine d'Alençon	Président de la Communauté urbaine d'Alençon	précédemment président entre 1989 et novembre 2004 (mail assistant du 19/11/2007)	2006	2008	46961	INTERCOM	92029V	\N	\N	de la 	\N	\N
11446	\N	\N	\N	ANCIEN	\N	De Nantes-Métropole Communauté urbaine	Vice-présidente de Nantes-Métropole Communauté urbaine	\N	2001	2003	\N	INTERCOM	01055U	\N	\N	de la 	\N	\N
11447	2008-04-16 00:00:00	\N	\N	ACTIF	\N	Communauté de communes Aubrac-Lot-Causse	Président de la Communauté de communes Aubrac-Lot-Causse	\N	2008	\N	\N	INTERCOM	01005J	\N	\N	de la 	\N	\N
11448	2002-12-18 00:00:00	\N	\N	ACTIF	\N	Communauté de communes du Bonnevalais	Président de la Communauté de communes du Bonnevalais	\N	2002	\N	\N	INTERCOM	01064V	\N	\N	de la 	\N	\N
11449	\N	\N	\N	ACTIF	\N	Communauté de communes d'Arrats-Gimone	Conseiller, Communauté de communes d'Arrats-Gimone	\N	2000	\N	\N	INTERCOM	98032R	\N	\N	de la 	\N	\N
11450	1999-12-31 00:00:00	\N	\N	ANCIEN	\N	Communauté de communes Bayeux Intercom	Conseiller, Communauté de communes Bayeux Intercom	\N	1999	2008	\N	INTERCOM	98042T	\N	\N	de la 	\N	\N
12836	2001-03-15 00:00:00	\N	2015-12-31 00:00:00	ANCIEN	\N	Communauté de communes Seine Mauldre	\N	\N	\N	\N	\N	INTERCOM	11090Q	\N	\N	de 	\N	2016-10-06 14:57:36
12083	\N	\N	\N	ANCIEN	\N	Conseil supérieur des Français de l'étranger	Conseiller élu au Conseil supérieur des Français de l'étranger pour le Royaume-Uni et la République d'Irlande	\N	1988	2004	\N	DIVERS	04035D	\N	\N	\N	\N	\N
12881	\N	\N	2017-10-23 00:00:00	ANCIEN	\N	Président de la Fédération départementale d'énergies	Président de la Fédération départementale d'énergies du Lot 	\N	\N	\N	\N	DIVERS	11012A	\N	\N	\N	\N	2017-11-09 11:53:17
12080	1995-03-01 00:00:00	\N	\N	ACTIF	\N	\N	Président du centre de gestion de la fonction publique territoriale de la Meuse	\N	1995	\N	\N	DIVERS	11003M	\N	\N	\N	\N	\N
12081	2008-03-01 00:00:00	\N	\N	ACTIF	\N	\N	Président du syndicat mixte d'aménagement de la base aérienne de Marville	\N	2008	\N	\N	DIVERS	11003M	\N	\N	\N	\N	\N
12846	2001-05-01 00:00:00	\N	2004-05-31 00:00:00	ANCIEN	\N	Président du gouvernement de la Nouvelle-Calédonie	\N	\N	\N	\N	\N	DIVERS	11010L	\N	\N	\N	\N	\N
12847	1995-05-01 00:00:00	\N	1996-06-01 00:00:00	ANCIEN	\N	Président du Congrès de la Nouvelle-Calédonie	\N	\N	\N	\N	\N	DIVERS	11010L	\N	\N	\N	\N	\N
12848	2007-09-01 00:00:00	\N	2009-05-01 00:00:00	ANCIEN	\N	Président du Congrès de la Nouvelle-Calédonie	\N	\N	\N	\N	\N	DIVERS	11010L	\N	\N	\N	\N	\N
12173	\N	\N	\N	ANCIEN	\N	agglomération Val-et-Forêt	\N	\N	2003	2008	\N	INTERCOM	11088W	\N	\N	de l'	\N	\N
12482	2001-01-01 00:00:00	\N	2016-07-01 00:00:00	ANCIEN	\N	Communauté urbaine de Nantes, Nantes Métropole	\N	\N	\N	\N	\N	INTERCOM	11064N	\N	\N	de la 	\N	2016-07-08 10:22:38
12215	2001-04-01 00:00:00	\N	\N	ACTIF	\N	Communauté d'agglomération de Cergy-Pontoise	\N	\N	\N	\N	\N	INTERCOM	11089X	\N	\N	de la	\N	\N
12501	1989-04-01 00:00:00	\N	2014-03-17 00:00:00	ANCIEN	\N	Communauté urbaine Lille Métropole 	\N	\N	\N	\N	\N	INTERCOM	11037K	\N	\N	de la 	\N	2015-02-17 15:46:00
12518	2006-12-20 00:00:00	\N	2015-12-31 00:00:00	ANCIEN	\N	Communauté d'agglomération de l'aéroport du Bourget	\N	\N	\N	\N	0	INTERCOM	11053K	\N	\N	de la 	\N	2016-07-08 10:52:42
12793	\N	\N	\N	ACTIF	\N	Communauté d'agglomération du Cap Calaisis	\N	\N	\N	\N	\N	INTERCOM	11060J	\N	\N	de la	\N	\N
12795	1983-03-01 00:00:00	\N	2014-10-01 00:00:00	ANCIEN	\N	Syndicat intercommunal à vocation multiple du canton de Sully-sur-Loire	\N	\N	\N	\N	\N	INTERCOM	11103C	\N	\N	du 	\N	2014-10-22 17:27:15
12798	1995-06-18 00:00:00	\N	\N	ACTIF	\N	Communauté d'agglomération Grenoble-Alpes Métropole	\N	\N	\N	\N	\N	INTERCOM	11042G	\N	\N	de la 	\N	\N
12826	2001-03-01 00:00:00	\N	2014-03-24 00:00:00	ANCIEN	\N	Vannes Agglomération 	\N	\N	\N	\N	\N	INTERCOM	11099A	\N	\N	de	\N	2014-10-27 11:54:19
6494	\N	\N	\N	ACTIF	\N	Communauté urbaine d'Arras	Président de la Communauté urbaine d'Arras	\N	1998	\N	90500	INTERCOM	01034P	\N	\N	de la 	\N	\N
11061	\N	\N	2014-03-30 00:00:00	ANCIEN	\N	Président de la société d'aménagement de la ville de Paris	Président de la société d'économie mixte d'aménagement de la ville de Paris	\N	1995	\N	\N	DIVERS	04079R	\N	\N	\N	\N	2014-06-10 16:43:54
6647	2001-03-18 00:00:00	\N	2014-04-01 00:00:00	ANCIEN	\N	Lille-Métropole Communauté urbaine	Vice-présidente de Lille-Métropole Communauté urbaine	\N	\N	\N	0	INTERCOM	92018S	\N	\N	de  	\N	2014-04-09 22:21:42
11462	2008-04-18 00:00:00	\N	\N	ACTIF	\N	Communauté de communes du Quercitain	Premier vice-président de la Communauté de communes du Quercitain	\N	2008	\N	\N	INTERCOM	92042S	\N	\N	de la 	\N	\N
12047	\N	\N	\N	ANCIEN	\N	Communauté d'agglomération d'Angers	Vice-présidente de la communauté d'agglomération d'Angers	\N	2001	2008	\N	INTERCOM	10006L	\N	\N	de la 	\N	\N
12820	2008-04-17 00:00:00	\N	\N	ACTIF	\N	Communauté d'agglomération Saint-Étienne Métropole	\N	\N	\N	\N	\N	INTERCOM	11057P	\N	\N	de la	\N	\N
12864	\N	\N	\N	ACTIF	\N	Membre du conseil consultatif des TAAF	Membre du conseil consultatif des terres australes et antarctiques françaises (TAAF)	\N	2010	\N	\N	DIVERS	01063U	\N	\N	\N	\N	\N
12865	\N	\N	\N	ACTIF	\N	Membre de droit de l'Assemblée des Français de l'étranger	\N	\N	2010	\N	\N	DIVERS	01063U	\N	\N	\N	\N	\N
12866	\N	\N	2010-10-25 00:00:00	ANCIEN	\N	Vice-Président du Syndicat mixte des Baronnies provençales	\N	courriel de M. Besson (14 octobre 2011)	2008	2010	\N	DIVERS	89015P	\N	\N	\N	\N	\N
12831	1995-06-18 00:00:00	\N	2015-12-31 00:00:00	ANCIEN	\N	Communauté urbaine de Lille Métropole	\N	\N	\N	\N	\N	INTERCOM	11040E	\N	\N	de la 	\N	2016-07-08 11:05:02
12203	1994-04-30 00:00:00	\N	2004-04-30 00:00:00	ANCIEN	\N	Communauté de communes du Pays de Mézenc	\N	\N	1994	2004	\N	INTERCOM	11093T	\N	\N	de	\N	\N
12322	1997-01-01 00:00:00	\N	2014-04-01 00:00:00	ANCIEN	\N	Communauté de communes rurales du Beauvaisis	\N	\N	\N	\N	0	INTERCOM	11046L	\N	\N	de la	\N	2014-04-28 11:49:37
12357	\N	\N	2014-04-07 00:00:00	ANCIEN	\N	Communauté urbaine de Dunkerque	\N	\N	\N	\N	0	INTERCOM	11035H	\N	\N	de la 	\N	2014-04-23 13:53:52
12776	2001-01-01 00:00:00	\N	2013-12-02 00:00:00	ANCIEN	\N	Communauté de communes du coeur de Pévèle	\N	\N	\N	\N	\N	INTERCOM	11039M	\N	\N	de la 	\N	2014-10-22 17:34:07
12781	\N	\N	\N	ANCIEN	\N	Communauté de communes du canton de Laplume-en-Bruilhois	\N	\N	1983	2012	\N	INTERCOM	11094U	\N	\N	de la 	\N	\N
12782	2010-01-01 00:00:00	\N	\N	ACTIF	\N	Communauté d'agglomération Est ensemble	\N	\N	\N	\N	\N	INTERCOM	11055M	\N	\N	de la 	\N	\N
12786	2008-03-16 00:00:00	\N	2015-12-31 00:00:00	ANCIEN	\N	Communauté d'agglomération Plaine centrale du Val-de-Marne	\N	\N	\N	\N	\N	INTERCOM	11032E	\N	\N	de la 	\N	2016-07-08 10:52:22
12877	\N	\N	\N	ANCIEN	\N	Secrétaire général de la présidence de la République	Secrétaire général de la présidence de la République	\N	\N	2010	\N	DIVERS	05008E	\N	\N	\N	\N	\N
12878	\N	\N	\N	ANCIEN	\N	ANSES	Président de l'Agence nationale de sécurité alimentaire, de l'alimentation, de l'environnement et du travail (ANSES)	\N	\N	2010	\N	DIVERS	05008E	\N	\N	\N	\N	\N
12879	\N	\N	\N	ANCIEN	\N	OFII	Président de l'Office français de l'immigration et de l'intégration (OFII)	\N	\N	2010	\N	DIVERS	05008E	\N	\N	\N	\N	\N
12880	\N	\N	\N	ANCIEN	\N	Conseiller d'État	Conseiller d'État	\N	\N	2010	\N	DIVERS	05008E	\N	\N	\N	\N	\N
12944	2014-01-29 00:00:00	\N	\N	ACTIF	Membre de l'Assemblée parlementaire de la Méditerranée	Membre de l'Assemblée parlementaire de la Méditerranée	Membre de l'Assemblée parlementaire de la Méditerranée	\N	\N	\N	0	DIVERS	07030L	\N	\N	\N	2014-01-30 11:28:08	2014-01-30 12:26:14
12946	\N	\N	\N	ACTIF	\N	Président du Conseil national de l'information géographique	Président du Conseil national de l'information géographique	\N	2014	\N	\N	DIVERS	80013X	\N	\N	\N	2014-02-04 18:08:51	\N
14411	2014-04-25 00:00:00	\N	2017-10-22 00:00:00	ANCIEN	\N	de la Communauté de communes du Pays de Montfaucon	de la Communauté de communes du Pays de Montfaucon	\N	\N	\N	\N	INTERCOM	14267Y	\N	\N	\N	2015-01-26 16:22:02	2017-11-13 10:10:31
12941	1993-01-01 00:00:00	\N	2014-06-01 00:00:00	ANCIEN	de la communauté de l'agglomération Rouen Elbeuf	de la communauté de l'agglomération Rouen Elbeuf Austreberthe	de la communauté de l'agglomération Rouen Elbeuf Austreberthe	\N	\N	\N	0	INTERCOM	14001X	\N	\N	\N	2014-01-02 11:15:32	2014-10-01 09:35:51
12945	2014-02-04 00:00:00	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	DIVERS	80013X	\N	\N	\N	2014-02-04 17:59:43	\N
13925	\N	\N	\N	ANCIEN	\N	de la Communauté de communes des Pays d'Olt et d'Aubrac	\N	\N	1999	2010	\N	INTERCOM	14103D	\N	\N	\N	2014-09-18 11:56:15	2014-09-29 15:56:23
13773	\N	\N	2019-01-13 00:00:00	ANCIEN	\N	Communauté des communes de la Haute Saintonge	Vice-président de la Communauté des communes de la Haute Saintonge	\N	2011	\N	\N	INTERCOM	08015R	\N	\N	de la	2014-05-12 16:31:54	2017-10-04 16:01:27
14375	2014-04-15 00:00:00	\N	\N	ACTIF	\N	de la Communauté de communes du bassin ludois	de la Communauté de communes du bassin ludois	\N	\N	\N	\N	INTERCOM	14169X	\N	\N	\N	2014-10-01 13:48:09	2017-11-08 17:50:45
14376	\N	\N	2020-06-28 00:00:00	ANCIEN	\N	de la Communauté d'agglomération de Besançon	de la Communauté d'agglomération de Besançon	\N	2014	\N	\N	INTERCOM	14123H	\N	\N	\N	2014-10-02 10:36:19	2014-10-02 10:43:49
14381	2014-10-15 00:00:00	\N	\N	ACTIF	\N	de la Communauté d'agglomération de l'Ouest Rhodanien 	de la Communauté d'agglomération de l'Ouest Rhodanien 	\N	\N	\N	\N	INTERCOM	95049N	\N	\N	\N	2014-10-15 18:14:57	2017-04-21 11:24:52
14713	\N	\N	\N	ACTIF	ancien mandat	député des deux Assemblées nationales constituantes	député des deux Assemblées nationales constituantes	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	000131	\N	\N	\N	2015-02-10 14:17:41	\N
14714	\N	\N	\N	ACTIF	ancien mandat	député de l'Assemblée nationale française	député de l'Assemblée nationale française	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	000131	\N	\N	\N	2015-02-10 14:17:41	\N
14726	\N	\N	\N	ACTIF	ancien mandat	député des deux Assemblées nationales constituantes	député des deux Assemblées nationales constituantes	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	000216	\N	\N	\N	2015-02-10 14:17:41	\N
14727	\N	\N	\N	ACTIF	ancien mandat	député de l'Assemblée nationale française	député de l'Assemblée nationale française	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	000216	\N	\N	\N	2015-02-10 14:17:41	\N
13812	\N	\N	\N	ACTIF	\N	Conseiller au Conseil économique, social et environnemental	\N	\N	2014	\N	\N	DIVERS	14033T	\N	\N	\N	2014-09-16 16:57:31	2014-09-16 16:59:16
13815	\N	\N	\N	ANCIEN	\N	de la communauté de communes l'Aurence et Glane développement	\N	\N	2008	2013	\N	INTERCOM	14034U	\N	\N	\N	2014-09-16 17:06:40	2014-10-01 11:16:11
14199	2014-09-28 00:00:00	\N	\N	ACTIF	\N	Toulouse Métropole	Toulouse Métropole	\N	\N	\N	\N	INTERCOM	14223L	\N	\N	de	2014-09-28 17:50:47	2016-07-07 13:31:12
14309	2014-04-25 00:00:00	\N	\N	ACTIF	\N	de la Communauté de Communes Rhône Crussol	de la Communauté de Communes Rhône Crussol	\N	\N	\N	\N	INTERCOM	14259Y	\N	\N	\N	2014-09-28 19:32:50	2018-01-23 18:53:13
13960	\N	\N	2018-01-18 00:00:00	ANCIEN	\N	de la Communauté de communes du Pays de Condé et de la Druance	\N	\N	2014	\N	\N	INTERCOM	14133K	\N	\N	\N	2014-09-18 14:43:56	2018-01-24 12:48:16
14323	2007-07-08 00:00:00	\N	2017-09-30 00:00:00	ANCIEN	Conseil territorial de Saint-Martin	Premier vice-président du Conseil territorial de Saint-Martin	Premier vice-président du Conseil territorial de Saint-Martin	\N	\N	\N	\N	AUTFONLOC	14261S	\N	\N	\N	2014-09-29 09:25:21	2017-11-14 19:10:06
14325	\N	\N	\N	ACTIF	\N	Conseillère de l'assemblée de la Polynésie française	Conseillère de l'assemblée de la Polynésie française	\N	2004	\N	\N	AUTFONLOC	14044W	\N	\N	\N	2014-09-29 09:39:42	2014-09-29 09:41:13
14327	2014-09-29 00:00:00	\N	2017-10-09 00:00:00	ANCIEN	\N	Communauté de communes du Pays de Tarascon	Communauté de communes du Pays de Tarascon	\N	\N	\N	\N	INTERCOM	14197C	\N	\N	de la	2014-09-29 09:58:34	2017-11-30 15:11:12
14328	2013-01-01 00:00:00	\N	2014-01-01 00:00:00	ANCIEN	Conseiller à l'Assemblée des Français de l'étranger	Conseiller à l'Assemblée des Français de l'étranger	Conseiller à l'Assemblée des Français de l'étranger	\N	\N	\N	\N	DIVERS	14041T	\N	\N	\N	2014-09-29 10:46:08	2015-02-27 10:30:48
14336	2008-05-02 00:00:00	\N	\N	ACTIF	Président du SCOTERS	Président du SCOTERS	Président du SCOTERS	\N	\N	\N	\N	DIVERS	14065Q	\N	\N	\N	2014-09-29 12:03:14	2014-10-03 18:22:41
14352	2014-04-01 00:00:00	\N	2014-10-01 00:00:00	ANCIEN	\N	de la Communauté d'agglomération du grand Guéret	de la Communauté d'agglomération du grand Guéret	\N	\N	\N	\N	INTERCOM	14121F	\N	\N	\N	2014-09-30 11:34:38	2014-11-20 17:59:31
14341	1989-04-15 00:00:00	\N	2015-04-02 00:00:00	ANCIEN	\N	de la Communauté de communes de Sauer-Pechelbronn	de la Communauté de communes de Sauer-Pechelbronn	\N	\N	\N	\N	INTERCOM	14061L	\N	\N	\N	2014-09-29 16:11:02	2014-09-29 16:16:31
14345	2001-04-01 00:00:00	\N	\N	ACTIF	\N	de la Communauté de communes du Pays de Châteaugiron	de la Communauté de communes du Pays de Châteaugiron	\N	\N	\N	\N	INTERCOM	14231L	\N	\N	\N	2014-09-30 10:39:21	2017-12-01 14:50:08
14353	2010-03-01 00:00:00	\N	2014-03-17 00:00:00	ANCIEN	\N	de la Communauté de communes de Haute-Bléone	de la Communauté de communes de Haute-Bléone	\N	\N	\N	\N	INTERCOM	14107H	\N	\N	\N	2014-09-30 11:49:18	2014-09-30 11:50:41
14357	\N	\N	2015-12-31 00:00:00	ANCIEN	\N	de la Communauté d'agglomération du pays d'Aix	de la Communauté d'agglomération du pays d'Aix	\N	2008	\N	\N	INTERCOM	14241N	\N	\N	\N	2014-09-30 14:34:53	2016-06-23 11:40:49
14387	2014-10-20 00:00:00	\N	\N	ACTIF	\N	Représentant pour le Sénat à l'Assemblée parlementaire de l'Union pour la Méditerranée (Ap-UpM)	Représentant pour le Sénat à l'Assemblée parlementaire de l'Union pour la Méditerranée (Ap-UpM)	\N	\N	\N	\N	DIVERS	14209N	\N	\N	\N	2014-11-18 17:30:09	2014-11-18 17:34:53
14388	2014-11-01 00:00:00	\N	\N	ACTIF	\N	Membre du comité des régions d'Europe	Membre du comité des régions d'Europe	\N	\N	\N	\N	DIVERS	14209N	\N	\N	\N	2014-11-18 17:35:01	2014-11-18 17:35:17
14389	2014-11-20 00:00:00	\N	2020-05-27 00:00:00	ANCIEN	\N	de Rives de Moselle	de Rives de Moselle	de Rives de Moselle	\N	\N	\N	INTERCOM	01062T	\N	\N	\N	2014-11-20 12:28:37	2014-11-20 12:38:04
14394	2014-01-01 00:00:00	\N	\N	ACTIF	\N	de la Communauté de communes Rives de Moselle	de la Communauté de communes Rives de Moselle	\N	\N	\N	\N	INTERCOM	14263U	\N	\N	\N	2014-12-18 16:33:05	2014-12-18 16:33:58
14414	2015-01-27 00:00:00	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	DIVERS	08069G	\N	\N	\N	2015-01-27 11:17:43	\N
13966	\N	\N	2015-01-01 00:00:00	ANCIEN	\N	de la Communauté de communes de la Vallée d'Auge	\N	\N	2001	\N	\N	INTERCOM	14137P	\N	\N	\N	2014-09-18 14:49:46	2015-01-14 21:33:49
14175	\N	\N	2015-12-31 00:00:00	ANCIEN	\N	de Montpellier Agglomération	de Montpellier Agglomération	\N	2002	\N	\N	INTERCOM	14211G	\N	\N	\N	2014-09-28 17:34:37	2017-12-04 18:53:04
14226	\N	\N	2014-10-01 00:00:00	ANCIEN	\N	de la communauté de communes Arve et Saleve	de la communauté de communes Arve et Saleve	\N	2008	\N	\N	INTERCOM	14237S	\N	\N	\N	2014-09-28 18:00:02	2014-12-04 15:57:37
14236	\N	\N	\N	ACTIF	\N	de la Communauté de communes Vézère Monédières	\N	\N	2014	\N	\N	INTERCOM	14195A	\N	\N	\N	2014-09-28 18:03:02	2014-09-29 15:58:23
14286	2014-03-17 00:00:00	\N	\N	ACTIF	\N	de la Communauté d'agglomération Vichy Val d'Allier	de la Communauté d'agglomération Vichy Val d'Allier	\N	\N	\N	\N	INTERCOM	14251Q	\N	\N	\N	2014-09-28 19:02:39	2017-11-27 20:09:56
14754	\N	\N	1984-09-04 00:00:00	ANCIEN	ancien mandat	conseiller de l'Union française	conseiller de l'Union française	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	1984	\N	DIVERSCOMMU	000273	\N	\N	\N	2015-02-10 14:17:41	\N
14757	\N	\N	\N	ACTIF	mandat actuel	député de l'Assemblée nationale française	député de l'Assemblée nationale française	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	59539X	\N	\N	\N	2015-02-10 14:17:41	\N
13754	2014-04-09 00:00:00	2014-04-09 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	Communauté de communes de Feurs-en-Forez	\N	\N	\N	\N	0	INTERCOM	01037S	\N	\N	\N	2014-04-09 10:38:41	2016-12-12 16:10:14
51747	2020-01-16 00:00:00	\N	\N	ACTIF	Ambassadrice de France mobilités	Nouveau	Ambassadrice de France mobilités	\N	\N	\N	\N	DIVERS	19737F	\N	\N	\N	\N	\N
13759	2014-04-01 00:00:00	\N	2015-12-31 00:00:00	ANCIEN	\N	de la communauté d'agglomération Rouen-Elbeuf-Austreberthe	de la communauté d'agglomération Rouen-Elbeuf-Austreberthe	\N	\N	\N	0	INTERCOM	04070G	\N	\N	\N	2014-04-29 18:20:49	2016-09-08 10:21:46
13856	2008-04-01 00:00:00	\N	2015-12-31 00:00:00	ANCIEN	\N	de la Communauté urbaine de Strasbourg	de la Communauté urbaine de Strasbourg	\N	\N	\N	\N	INTERCOM	14065Q	\N	\N	\N	2014-09-17 17:35:54	2016-07-07 13:28:20
13860	2014-04-03 00:00:00	\N	2021-07-22 00:00:00	ANCIEN	\N	de la Communauté de communes de la Basse-Zorn	de la Communauté de communes de la Basse-Zorn	\N	\N	\N	\N	INTERCOM	14073Q	\N	\N	\N	2014-09-17 17:42:03	2017-11-15 14:06:31
13881	2014-03-17 00:00:00	\N	2014-12-31 00:00:00	ANCIEN	\N	du Grand Lyon	du Grand Lyon	\N	\N	\N	\N	INTERCOM	14087W	\N	\N	\N	2014-09-18 10:48:08	2015-01-16 09:48:29
13951	\N	\N	2014-12-27 00:00:00	ANCIEN	\N	de la Communauté de communes de Saint Bonnet	de la Communauté de communes de Saint Bonnet	\N	1989	\N	\N	INTERCOM	14129P	\N	\N	\N	2014-09-18 12:24:08	2014-12-29 15:40:09
14311	\N	\N	2018-12-17 00:00:00	ANCIEN	\N	de la communauté d'agglomération de l'Albigeois	\N	\N	2005	\N	\N	INTERCOM	14089Y	\N	\N	\N	2014-09-28 19:34:38	2017-09-26 14:28:51
14338	\N	\N	2013-01-01 00:00:00	ANCIEN	Président du Conseil supérieur du service public ferroviaire	Président du Conseil supérieur du service public ferroviaire	Président du Conseil supérieur du service public ferroviaire	\N	\N	\N	\N	DIVERS	14175V	\N	\N	\N	2014-09-29 14:04:22	2014-09-29 14:08:20
14339	2007-07-01 00:00:00	\N	2012-06-30 00:00:00	ANCIEN	\N	Pdt de la commission de surveillance de la CDC	Président de la commission de surveillance de la CDC	\N	\N	\N	\N	DIVERS	14175V	\N	\N	\N	2014-09-29 14:07:18	2014-09-29 14:10:57
14346	2014-01-01 00:00:00	\N	2021-01-28 00:00:00	ANCIEN	\N	de la Communauté d'agglomération du bocage bressuirais	de la Communauté d'agglomération du bocage bressuirais	\N	\N	\N	\N	INTERCOM	14071N	\N	\N	\N	2014-09-30 10:40:44	2014-09-30 10:43:09
14808	\N	\N	\N	ACTIF	ancien mandat	député de l'Assemblée nationale française	député de l'Assemblée nationale française	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	57130R	\N	\N	\N	2015-02-10 14:17:41	\N
14349	\N	\N	\N	ACTIF	\N	de la Communauté de communes de la Muse et des raspes du Tarn	de la Communauté de communes de la Muse et des raspes du Tarn	\N	2014	\N	\N	INTERCOM	14111D	\N	\N	\N	2014-09-30 10:51:56	2014-09-30 10:53:27
14350	\N	\N	\N	ACTIF	\N	de la Communauté de communes du Quercy caussadais	de la Communauté de communes du Quercy caussadais	\N	2008	\N	\N	INTERCOM	14069U	\N	\N	\N	2014-09-30 11:21:34	2017-11-09 10:23:43
14355	\N	\N	\N	ACTIF	\N	Métropole Nice Côte d'Azur	\N	\N	2003	\N	\N	INTERCOM	14187A	\N	\N	de la	2014-09-30 11:56:58	2016-07-07 13:23:37
14356	2001-03-01 00:00:00	\N	2015-12-31 00:00:00	ANCIEN	\N	de la Communauté d'agglomération du Pays d'Aix	de la Communauté d'agglomération du Pays d'Aix	\N	\N	\N	\N	INTERCOM	14239U	\N	\N	\N	2014-09-30 14:34:17	2016-07-08 10:35:42
14382	\N	\N	\N	ACTIF	Membre de la Commission de la Coopération de la Moselle	Membre de la Commission départementale de la Coopération intercommunale de la Moselle (CDCI)	Membre de la Commission départementale de la Coopération intercommunale de la Moselle (CDCI)	\N	2014	\N	\N	AUTFONLOC	01060R	\N	\N	\N	2014-10-16 18:32:11	2014-10-16 18:39:30
14818	\N	\N	\N	ACTIF	ancien mandat	membre de l'Assemblée de l'Union française	membre de l'Assemblée de l'Union française	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	000425	\N	\N	\N	2015-02-10 14:17:41	\N
13784	2006-01-25 00:00:00	\N	\N	ANCIEN	\N	de la communauté de communes du Sud	\N	\N	\N	2014	0	INTERCOM	14017T	\N	\N	\N	2014-06-25 16:08:17	2014-10-22 17:53:57
13845	2014-04-18 00:00:00	\N	2014-12-31 00:00:00	ANCIEN	\N	de la Communauté de communes Rhôny Vistre Vidourle	de la Communauté de communes Rhôny Vistre Vidourle	\N	\N	\N	\N	INTERCOM	14059S	\N	\N	\N	2014-09-17 17:09:01	2015-12-17 14:29:08
13894	\N	\N	2020-07-04 00:00:00	ANCIEN	\N	communauté de communes du Haut-Pays Bigouden	de la communauté de communes du Haut-Pays Bigouden	\N	2013	\N	\N	INTERCOM	14083S	\N	\N	de la	2014-09-18 11:13:15	2017-10-04 17:04:06
14024	2014-04-25 00:00:00	\N	2020-11-01 00:00:00	ANCIEN	\N	de la communauté de communes Cluses Arve et Montagnes	de la communauté de communes Cluses Arve et Montagnes	\N	\N	\N	\N	INTERCOM	14179A	\N	\N	\N	2014-09-22 15:11:41	2018-01-18 15:28:42
14241	\N	\N	2016-12-31 00:00:00	ANCIEN	\N	de Lamballe communauté	de Lamballe communauté	\N	2014	\N	\N	INTERCOM	14235Q	\N	\N	\N	2014-09-28 18:04:38	2017-01-20 15:39:27
14329	\N	\N	2020-06-28 00:00:00	ANCIEN	\N	de la communauté de communes Haute-Saintonge	de la communauté de communes Haute-Saintonge	\N	\N	\N	\N	INTERCOM	14159V	\N	\N	\N	2014-09-29 10:49:41	2017-11-08 16:27:44
14330	2014-09-29 00:00:00	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	DIVERS	14159V	\N	\N	\N	2014-09-29 11:11:59	\N
14331	2014-09-29 00:00:00	\N	2017-05-01 00:00:00	ANCIEN	Vice-Présidente du CNCCEF	Vice-Présidente du Comité National des Conseillers du Commerce extérieur de la France	Vice-Présidente du Comité National des Conseillers du Commerce extérieur de la France (CNCCEF)	\N	\N	\N	\N	DIVERS	14041T	\N	\N	\N	2014-09-29 11:12:01	2017-05-22 16:18:24
14335	2008-09-07 00:00:00	\N	2014-07-16 00:00:00	ANCIEN	\N	Président du centre de gestion de la fonction publique territoriale	Président du centre de gestion de la fonction publique territoriale	\N	\N	\N	\N	DIVERS	11074Q	\N	\N	\N	2014-09-29 11:48:25	2014-09-29 11:49:43
14384	\N	\N	\N	ANCIEN	Conseillère de l'Assemblée des Français de l'Etranger	Conseillère de l'Assemblée des Français de l'Etranger	Conseillère de l'Assemblée des Français de l'Etranger	\N	1997	2011	\N	DIVERS	11027H	\N	\N	\N	2014-10-23 10:50:08	2014-10-23 10:50:52
14386	2014-10-01 00:00:00	\N	\N	ACTIF	\N	du Grand Évreux Agglomération	du Grand Évreux Agglomération	\N	\N	\N	\N	INTERCOM	14249W	\N	\N	\N	2014-10-23 15:53:37	2018-06-06 17:02:44
14774	\N	\N	\N	ACTIF	ancien mandat	député de l'Assemblée nationale française	député de l'Assemblée nationale française	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	000348	\N	\N	\N	2015-02-10 14:17:41	\N
14778	\N	\N	\N	ACTIF	ancien mandat	membre de l'Assemblée de l'Union française	membre de l'Assemblée de l'Union française	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	000072	\N	\N	\N	2015-02-10 14:17:41	\N
14788	\N	\N	\N	ACTIF	mandat actuel	député de l'Assemblée nationale française	député de l'Assemblée nationale française	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	000107	\N	\N	\N	2015-02-10 14:17:41	\N
14789	\N	\N	\N	ACTIF	ancien mandat	membre de l'Assemblée de l'Union française	membre de l'Assemblée de l'Union française	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	000107	\N	\N	\N	2015-02-10 14:17:41	\N
51752	2020-06-28 00:00:00	\N	\N	ACTIF	\N	de la Communauté de communes Vézère Monédières Millesources	\N	\N	\N	\N	\N	INTERCOM	14195A	\N	\N	\N	\N	\N
13806	2014-03-15 00:00:00	\N	2020-03-31 00:00:00	ANCIEN	\N	de la communauté de communes des Olonnes	de la communauté de communes des Olonnes	\N	\N	\N	\N	INTERCOM	14030Q	\N	\N	\N	2014-09-16 15:17:43	2017-10-09 11:57:36
13757	2014-04-29 00:00:00	\N	2016-12-31 00:00:00	ANCIEN	\N	de l'Intercommunalité du Bassin de Villedieu 	\N	\N	\N	\N	0	INTERCOM	05008E	\N	\N	\N	2014-04-29 11:16:37	2017-04-21 14:45:14
50816	2017-01-01 00:00:00	\N	2017-10-15 00:00:00	ANCIEN	\N	communauté de communes Loches Sud Touraine	de la communauté de communes Loches Sud Touraine	\N	\N	\N	\N	INTERCOM	19441R	\N	\N	de la	2017-09-19 16:11:59	2018-03-28 18:15:57
14012	2014-03-17 00:00:00	\N	2018-05-31 00:00:00	ANCIEN	\N	de Le Mans Métropole	de Le Mans Métropole	\N	\N	\N	\N	INTERCOM	14167V	\N	\N	\N	2014-09-22 10:58:25	2018-06-04 11:44:26
14026	2014-03-17 00:00:00	\N	2015-12-31 00:00:00	ANCIEN	\N	de la communauté d'agglomération Rouen-Elbeuf-Austreberthe	de la communauté d'agglomération Rouen-Elbeuf-Austreberthe	\N	\N	\N	\N	INTERCOM	14051J	\N	\N	\N	2014-09-22 15:37:53	2016-07-07 13:25:27
14028	2014-03-17 00:00:00	\N	\N	ACTIF	\N	de la Communauté urbaine le Havre Seine Métropole	de la Communauté urbaine le Havre Seine Métropole	\N	\N	\N	\N	INTERCOM	14053L	\N	\N	\N	2014-09-22 15:44:27	2014-09-29 15:58:45
13779	2014-06-04 00:00:00	\N	\N	ACTIF	Président de Paris Habitat - OPH	Président de Paris Habitat - OPH	Président de Paris Habitat - OPH	\N	\N	\N	0	DIVERS	04079R	\N	\N	\N	2014-06-11 18:05:31	2014-06-12 10:13:06
13874	\N	\N	2014-12-31 00:00:00	ANCIEN	\N	du Grand Lyon	du Grand Lyon	\N	2002	\N	\N	INTERCOM	14081Q	\N	\N	\N	2014-09-17 18:15:12	2016-07-08 11:05:45
14070	\N	\N	\N	ACTIF	\N	de la communauté d'agglomération de Troyes	de la communauté d'agglomération de Troyes	\N	2001	\N	\N	INTERCOM	05004A	\N	\N	\N	2014-09-28 15:27:54	2014-09-28 15:31:18
14075	2014-03-17 00:00:00	\N	2021-07-15 00:00:00	ANCIEN	\N	de la communauté de communes du Sud Territoire	de la communauté de communes du Sud Territoire	\N	\N	\N	\N	INTERCOM	14193X	\N	\N	\N	2014-09-28 15:33:43	2017-11-10 18:14:08
14144	2014-04-30 00:00:00	\N	\N	ACTIF	\N	de la Communauté d'agglomération du Bassin de Thau	\N	\N	\N	\N	\N	INTERCOM	14209N	\N	\N	\N	2014-09-28 17:20:24	2014-09-28 18:20:54
14148	2014-04-24 00:00:00	\N	\N	ACTIF	\N	de l'agglomération du Pays de Dreux	de l'agglomération du Pays de Dreux	\N	\N	\N	\N	INTERCOM	14217N	\N	\N	\N	2014-09-28 17:23:25	2018-01-23 19:21:58
14189	\N	\N	2014-10-01 00:00:00	ANCIEN	\N	de la communauté de communes du Pays d'Ornans	de la communauté de communes du Pays d'Ornans	\N	2014	\N	\N	INTERCOM	14219Q	\N	\N	\N	2014-09-28 17:46:23	2014-10-09 14:22:36
14180	2014-03-17 00:00:00	\N	2015-12-31 00:00:00	ANCIEN	\N	de la communauté urbaine Toulouse Métropole	\N	\N	\N	\N	\N	INTERCOM	14225N	\N	\N	\N	2014-09-28 17:36:31	2016-07-08 11:14:02
14295	2014-09-28 00:00:00	\N	2017-07-15 00:00:00	ANCIEN	\N	Communauté de communes du Gâtinais en Bourgogne	Communauté de communes du Gâtinais en Bourgogne	\N	\N	\N	\N	INTERCOM	14037X	\N	\N	de la	2014-09-28 19:10:00	2014-09-29 16:03:44
14307	\N	\N	\N	ACTIF	\N	de la communauté d'agglomération du Grand Auch	de la communauté d'agglomération du Grand Auch	\N	2001	\N	\N	INTERCOM	14257W	\N	\N	\N	2014-09-28 19:32:01	2017-11-09 10:29:01
14366	\N	\N	2015-12-31 00:00:00	ANCIEN	\N	de Rennes métropoles	\N	\N	2008	\N	\N	INTERCOM	14229S	\N	\N	\N	2014-09-30 16:15:58	2016-07-08 11:09:32
14372	2014-09-30 00:00:00	\N	2020-06-15 00:00:00	ANCIEN	\N	de la Communauté de communes de Saulieu	de la Communauté de communes de Saulieu	\N	\N	\N	\N	INTERCOM	14205J	\N	\N	\N	2014-09-30 17:04:28	2017-11-09 11:10:09
14369	2006-06-18 00:00:00	\N	2015-03-31 00:00:00	ANCIEN	Conseiller à l'Assemblée des Français de l'étranger	Conseiller à l'Assemblée des Français de l'étranger	Conseiller à l'Assemblée des Français de l'étranger	\N	\N	\N	\N	DIVERS	14255U	\N	\N	\N	2014-09-30 16:28:57	2016-07-04 18:50:07
14373	\N	\N	2017-01-02 00:00:00	ANCIEN	\N	de Dinan communauté	de Dinan communauté	\N	\N	\N	\N	INTERCOM	14157T	\N	\N	\N	2014-09-30 18:01:33	2017-09-20 16:50:51
14374	2014-04-15 00:00:00	\N	2015-04-15 00:00:00	ANCIEN	\N	de la Communauté d'agglomération Limoges Métropole	de la Communauté d'agglomération Limoges Métropole	\N	\N	\N	\N	INTERCOM	14034U	\N	\N	\N	2014-10-01 10:00:35	2015-06-16 17:34:20
14385	2014-10-01 00:00:00	\N	\N	ACTIF	\N	Président de la Fédération des entreprises publiques locales	Président de la Fédération des entreprises publiques locales	\N	\N	\N	\N	DIVERS	11042G	\N	\N	\N	2014-10-23 15:13:41	2014-10-23 15:14:08
14791	\N	\N	\N	ACTIF	mandat actuel	député de l'Assemblée nationale française	député de l'Assemblée nationale française	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	86035F	\N	\N	\N	2015-02-10 14:17:41	\N
14792	\N	\N	\N	ACTIF	ancien mandat	membre de l'Assemblée de l'Union française	membre de l'Assemblée de l'Union française	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	86035F	\N	\N	\N	2015-02-10 14:17:41	\N
14793	\N	\N	\N	ACTIF	mandat actuel	député de l'Assemblée nationale française	député de l'Assemblée nationale française	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	59542S	\N	\N	\N	2015-02-10 14:17:41	\N
14797	\N	\N	\N	ACTIF	ancien mandat	député de l'Assemblée nationale française	député de l'Assemblée nationale française	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	000442	\N	\N	\N	2015-02-10 14:17:41	\N
14801	\N	\N	\N	ACTIF	mandat actuel	député de l'Assemblée nationale française	député de l'Assemblée nationale française	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	000206	\N	\N	\N	2015-02-10 14:17:41	\N
14802	\N	\N	\N	ACTIF	ancien mandat	membre de la Chambre des députés	membre de la Chambre des députés	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	000206	\N	\N	\N	2015-02-10 14:17:41	\N
14803	\N	\N	\N	ACTIF	ancien mandat	délégué à l'Assemblée consultative provisoire	délégué à l'Assemblée consultative provisoire	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	000206	\N	\N	\N	2015-02-10 14:17:41	\N
14804	\N	\N	\N	ACTIF	ancien mandat	député des deux Assemblées nationales constituantes	député des deux Assemblées nationales constituantes	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	000206	\N	\N	\N	2015-02-10 14:17:41	\N
14805	\N	\N	\N	ACTIF	ancien mandat	député de l'Assemblée nationale française	député de l'Assemblée nationale française	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	000206	\N	\N	\N	2015-02-10 14:17:41	\N
15011	\N	\N	\N	ACTIF	ancien mandat	député de l'Assemblée nationale française	député de l'Assemblée nationale française	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	000284	\N	\N	\N	2015-02-10 14:17:41	\N
15012	\N	\N	\N	ACTIF	ancien mandat	membre de l'Assemblée de l'Union française	membre de l'Assemblée de l'Union française	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	000145	\N	\N	\N	2015-02-10 14:17:41	\N
15014	\N	\N	\N	ACTIF	ancien mandat	député des deux Assemblées nationales constituantes	député des deux Assemblées nationales constituantes	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	000736	\N	\N	\N	2015-02-10 14:17:41	\N
15038	\N	\N	\N	ACTIF	mandat actuel	député de l'Assemblée nationale française	député de l'Assemblée nationale française	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	000307	\N	\N	\N	2015-02-10 14:17:41	\N
51754	2020-05-18 00:00:00	\N	\N	ACTIF	\N	Communauté d'agglomération Cap Excellence	\N	\N	\N	\N	\N	INTERCOM	19301E	\N	\N	de la	\N	\N
15070	\N	\N	\N	ACTIF	ancien mandat	membre de l'Assemblée de l'Union française	membre de l'Assemblée de l'Union française	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	000278	\N	\N	\N	2015-02-10 14:17:41	\N
15071	\N	\N	\N	ACTIF	mandat actuel	député de l'Assemblée nationale française	député de l'Assemblée nationale française	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	74044S	\N	\N	\N	2015-02-10 14:17:41	\N
14851	\N	\N	\N	ACTIF	ancien mandat	délégué à l'Assemblée consultative provisoire	délégué à l'Assemblée consultative provisoire	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	000400	\N	\N	\N	2015-02-10 14:17:41	\N
14852	\N	\N	\N	ACTIF	ancien mandat	député des deux Assemblées nationales constituantes	député des deux Assemblées nationales constituantes	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	000400	\N	\N	\N	2015-02-10 14:17:41	\N
14858	\N	\N	\N	ACTIF	mandat actuel	député de l'Assemblée nationale française	député de l'Assemblée nationale française	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	59522N	\N	\N	\N	2015-02-10 14:17:41	\N
14859	\N	\N	\N	ACTIF	ancien mandat	député de l'Assemblée nationale française	député de l'Assemblée nationale française	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	59522N	\N	\N	\N	2015-02-10 14:17:41	\N
51756	2020-06-28 00:00:00	\N	2023-10-06 00:00:00	ANCIEN	\N	Communauté d'agglomération du Nord Grande-Terre 	\N	\N	\N	\N	\N	INTERCOM	19715Y	\N	\N	de la	\N	\N
14890	\N	\N	\N	ACTIF	mandat actuel	député de l'Assemblée nationale française	député de l'Assemblée nationale française	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	000326	\N	\N	\N	2015-02-10 14:17:41	\N
14896	\N	\N	\N	ACTIF	ancien mandat	député des deux Assemblées nationales constituantes	député des deux Assemblées nationales constituantes	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	000061	\N	\N	\N	2015-02-10 14:17:41	\N
14902	\N	\N	\N	ACTIF	ancien mandat	député de l'Assemblée nationale française	député de l'Assemblée nationale française	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	57434F	\N	\N	\N	2015-02-10 14:17:41	\N
14903	\N	\N	\N	ACTIF	ancien mandat	délégué à l'Assemblée consultative provisoire	délégué à l'Assemblée consultative provisoire	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	000235	\N	\N	\N	2015-02-10 14:17:41	\N
14904	\N	\N	\N	ACTIF	ancien mandat	député des deux Assemblées nationales constituantes	député des deux Assemblées nationales constituantes	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	000235	\N	\N	\N	2015-02-10 14:17:41	\N
51556	1999-01-01 00:00:00	\N	2016-12-31 00:00:00	ANCIEN	\N	Communauté de communes du sud-ouest du Calaisis	Communauté de communes du sud-ouest du Calaisis	\N	\N	\N	\N	INTERCOM	19521Q	\N	\N	de la	2017-12-21 14:15:56	2017-12-21 14:20:23
14925	\N	\N	\N	ACTIF	mandat actuel	député de l'Assemblée nationale française	député de l'Assemblée nationale française	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	59530N	\N	\N	\N	2015-02-10 14:17:41	\N
14931	\N	\N	\N	ACTIF	ancien mandat	député des deux Assemblées nationales constituantes	député des deux Assemblées nationales constituantes	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	000250	\N	\N	\N	2015-02-10 14:17:41	\N
14932	\N	\N	\N	ACTIF	ancien mandat	membre de l'Assemblée de l'Union française	membre de l'Assemblée de l'Union française	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	000685	\N	\N	\N	2015-02-10 14:17:41	\N
14944	\N	\N	\N	ACTIF	mandat actuel	député de l'Assemblée nationale française	député de l'Assemblée nationale française	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	65017N	\N	\N	\N	2015-02-10 14:17:41	\N
14965	\N	\N	\N	ACTIF	ancien mandat	député de la deuxième Assemblée nationale constituante	député de la deuxième Assemblée nationale constituante	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	000713	\N	\N	\N	2015-02-10 14:17:41	\N
14966	\N	\N	\N	ACTIF	ancien mandat	député de l'Assemblée nationale française	député de l'Assemblée nationale française	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	000713	\N	\N	\N	2015-02-10 14:17:41	\N
14974	\N	\N	\N	ACTIF	ancien mandat	député de l'Assemblée nationale française	député de l'Assemblée nationale française	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	000197	\N	\N	\N	2015-02-10 14:17:41	\N
14984	\N	\N	\N	ACTIF	ancien mandat	député des deux Assemblées nationales constituantes	député des deux Assemblées nationales constituantes	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	000746	\N	\N	\N	2015-02-10 14:17:41	\N
14985	\N	\N	\N	ACTIF	ancien mandat	député de l'Assemblée nationale française	député de l'Assemblée nationale française	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	000746	\N	\N	\N	2015-02-10 14:17:41	\N
14987	\N	\N	\N	ACTIF	ancien mandat	membre de la Chambre des députés	membre de la Chambre des députés	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	000080	\N	\N	\N	2015-02-10 14:17:41	\N
14988	\N	\N	\N	ACTIF	ancien mandat	député des deux Assemblées nationales constituantes	député des deux Assemblées nationales constituantes	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	000129	\N	\N	\N	2015-02-10 14:17:41	\N
14989	\N	\N	\N	ACTIF	ancien mandat	député de l'Assemblée nationale française	député de l'Assemblée nationale française	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	000129	\N	\N	\N	2015-02-10 14:17:41	\N
14992	\N	\N	\N	ACTIF	ancien mandat	député de l'Assemblée nationale française	député de l'Assemblée nationale française	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	000379	\N	\N	\N	2015-02-10 14:17:41	\N
15000	\N	\N	\N	ACTIF	ancien mandat	membre de la Chambre des députés	membre de la Chambre des députés	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	000677	\N	\N	\N	2015-02-10 14:17:41	\N
15001	\N	\N	\N	ACTIF	ancien mandat	député de la deuxième Assemblée nationale constituante	député de la deuxième Assemblée nationale constituante	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	000677	\N	\N	\N	2015-02-10 14:17:41	\N
15005	\N	\N	\N	ACTIF	ancien mandat	député des deux Assemblées nationales constituantes	député des deux Assemblées nationales constituantes	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	59236K	\N	\N	\N	2015-02-10 14:17:41	\N
15007	\N	\N	\N	ACTIF	ancien mandat	membre de la Chambre des députés	membre de la Chambre des députés	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	000705	\N	\N	\N	2015-02-10 14:17:41	\N
15008	\N	\N	\N	ACTIF	ancien mandat	député des deux Assemblées nationales constituantes	député des deux Assemblées nationales constituantes	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	57135W	\N	\N	\N	2015-02-10 14:17:41	\N
15009	\N	\N	\N	ACTIF	ancien mandat	député de l'Assemblée nationale française	député de l'Assemblée nationale française	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	57135W	\N	\N	\N	2015-02-10 14:17:41	\N
15072	\N	\N	\N	ACTIF	ancien mandat	délégué à l'Assemblée consultative provisoire	délégué à l'Assemblée consultative provisoire	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	74044S	\N	\N	\N	2015-02-10 14:17:41	\N
15073	\N	\N	\N	ACTIF	ancien mandat	député des deux Assemblées nationales constituantes	député des deux Assemblées nationales constituantes	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	74044S	\N	\N	\N	2015-02-10 14:17:41	\N
15074	\N	\N	\N	ACTIF	ancien mandat	député de l'Assemblée nationale française	député de l'Assemblée nationale française	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	74044S	\N	\N	\N	2015-02-10 14:17:41	\N
15101	\N	\N	\N	ACTIF	ancien mandat	député de la première Assemblée nationale constituante	député de la première Assemblée nationale constituante	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	000251	\N	\N	\N	2015-02-10 14:17:41	\N
15102	\N	\N	\N	ACTIF	ancien mandat	député de l'Assemblée nationale française	député de l'Assemblée nationale française	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	000251	\N	\N	\N	2015-02-10 14:17:41	\N
15104	\N	\N	\N	ACTIF	mandat actuel	député de l'Assemblée nationale française	député de l'Assemblée nationale française	Mandat Sénat de la Communauté créé par script à partir de la table EXTSENCOM_MANDAT	\N	\N	\N	DIVERSCOMMU	000417	\N	\N	\N	2015-02-10 14:17:41	\N
51557	2017-01-01 00:00:00	\N	2017-10-12 00:00:00	ANCIEN	\N	Grand Calais Terres et Mers	Grand Calais Terres et Mers	\N	\N	\N	\N	INTERCOM	19521Q	\N	\N	du	2017-12-21 14:20:26	2017-12-21 14:23:42
15138	2015-04-01 00:00:00	\N	\N	ACTIF	\N	de Plaine commune	de Plaine commune	\N	\N	\N	\N	INTERCOM	14269B	\N	\N	\N	2015-03-10 16:13:22	2015-03-10 16:18:45
15336	2016-11-23 00:00:00	\N	2017-10-24 00:00:00	ANCIEN	Présidente du Centre de Gestion de la FPT du Rhône	Présidente du Centre de Gestion de la Fonction Publique Territoriale du Rhône	Présidente du Centre de Gestion de la Fonction Publique Territoriale du Rhône	\N	\N	\N	\N	DIVERS	14215L	\N	\N	\N	2016-11-23 10:35:29	2017-11-10 15:28:33
15522	2017-01-01 00:00:00	\N	2017-10-30 00:00:00	ANCIEN	\N	de Saint-Louis Agglomération	Vice-présidente de la communauté d'agglomération de Saint-Louis Agglomération	\N	\N	\N	\N	INTERCOM	04044E	\N	\N	\N	2017-04-21 14:36:18	2017-11-06 16:29:34
50820	2014-04-24 00:00:00	\N	2017-03-19 00:00:00	ANCIEN	\N	Tours Métropole Val de Loire	Tours Métropole Val de Loire	\N	\N	\N	\N	INTERCOM	19515S	\N	\N	de	2017-09-19 16:22:31	2017-11-21 18:36:47
15540	2017-05-23 00:00:00	\N	\N	ACTIF	Présidente de l'Alliance Française de Singapour	Présidente de l'Alliance Française de Singapour	Présidente de l'Alliance Française de Singapour	\N	\N	\N	\N	DIVERS	14041T	\N	\N	\N	2017-05-23 15:48:22	2017-11-09 09:51:53
50841	2014-03-23 00:00:00	\N	2017-10-10 00:00:00	ANCIEN	\N	de la communauté de communes Arbois Poligny Salins Coeur du Jura	de la communauté de communes Arbois Poligny Salins Coeur du Jura	\N	\N	\N	\N	INTERCOM	19467C	\N	\N	\N	2017-09-19 17:17:00	2017-12-04 21:52:55
51700	2008-03-01 00:00:00	\N	2020-03-03 00:00:00	ANCIEN	\N	de la Communauté de commune Coeur de Lozère	Communauté de communes Coeur de Lozère	\N	\N	\N	\N	INTERCOM	11081P	\N	\N	\N	\N	\N
51318	2017-01-01 00:00:00	\N	2017-10-31 00:00:00	ANCIEN	\N	communauté de communes "Dômes Sancy Artense"	de la communauté de communes "Dômes Sancy Artense"	\N	\N	\N	\N	INTERCOM	19383Y	\N	\N	de la	2017-09-24 19:48:38	2017-09-27 10:41:33
51333	2002-11-28 00:00:00	\N	2016-12-31 00:00:00	ANCIEN	\N	communauté de communes de la région d'Albertville	de la communauté de communes de la région d'Albertville	\N	\N	\N	\N	INTERCOM	19575F	\N	\N	de la	2017-09-24 20:11:51	2017-09-26 16:49:26
51439	2008-03-16 00:00:00	\N	2014-03-29 00:00:00	ANCIEN	\N	communauté d'agglomération du pays de Lorient	de la communauté d'agglomération du pays de Lorient	\N	\N	\N	\N	INTERCOM	19447X	\N	\N	de la	2017-09-27 14:33:39	2017-09-27 14:34:29
51441	2014-03-30 00:00:00	\N	2017-10-23 00:00:00	ANCIEN	\N	communauté de communes Chinon, Vienne et Loire	de la communauté de communes Chinon, Vienne et Loire	\N	\N	\N	\N	INTERCOM	19443T	\N	\N	de la	2017-09-27 14:53:58	2017-11-20 14:37:12
51442	2014-03-30 00:00:00	\N	2015-12-31 00:00:00	ANCIEN	\N	communauté d'agglomération de Grand Paris Seine Ouest	de la communauté d'agglomération de Grand Paris Seine Ouest	\N	\N	\N	\N	INTERCOM	19711U	\N	\N	de la	2017-09-27 15:38:19	2017-09-27 15:39:24
51443	2016-01-01 00:00:00	\N	\N	ACTIF	\N	de l'Établissement public territorial Grand Paris Seine Ouest	de l'Établissement public territorial Grand Paris Seine Ouest	\N	\N	\N	\N	INTERCOM	19711U	\N	\N	\N	2017-09-27 15:42:25	2017-09-27 15:42:46
51508	2017-11-08 00:00:00	\N	2020-06-28 00:00:00	ANCIEN	\N	communauté de communes du Pays de Luxeuil	de la communauté de communes du Pays de Luxeuil	\N	\N	\N	\N	INTERCOM	14135M	\N	\N	de la	2017-11-09 12:14:21	2017-11-09 12:20:42
51516	2017-07-11 00:00:00	\N	\N	ACTIF	\N	Président du Groupe pour l'Espace des élus français	Président du Groupe pour l'Espace des élus français	\N	\N	\N	\N	DIVERS	04040A	\N	\N	\N	2017-11-14 11:24:28	2017-11-14 11:27:39
51519	2014-05-01 00:00:00	\N	2017-10-04 00:00:00	ANCIEN	\N	Syndicat d'assainissement d'Onnaing, Vicq, Quarouble (SOVIQUA)	Présidente du Syndicat d'assainissement d'Onnaing, Vicq, Quarouble (SOVIQUA)	\N	\N	\N	\N	AUTFONLOC	19565D	\N	\N	\N	2017-11-16 18:53:06	2017-11-16 18:54:06
51533	2017-01-01 00:00:00	\N	\N	ACTIF	\N	territorial de Grand Paris - Grand Est	territorial de Grand Paris - Grand Est	\N	\N	\N	\N	INTERCOM	04086Q	\N	\N	\N	2017-12-04 17:03:33	2017-12-04 17:33:18
51541	2014-03-30 00:00:00	\N	\N	ACTIF	\N	Agglomération Provence Verte	Agglomération Provence Verte	\N	\N	\N	\N	INTERCOM	14029X	\N	\N	de l'	2017-12-07 10:13:56	2017-12-07 10:19:13
51567	2016-05-01 00:00:00	\N	2019-01-01 00:00:00	ANCIEN	\N	Président de l'Agence d'Attractivité de l'Alsace	Président de l'Agence d'Attractivité de l'Alsace	\N	\N	\N	\N	DIVERS	10015M	\N	\N	\N	2018-02-12 15:09:56	2018-02-12 15:11:03
51569	2011-01-01 00:00:00	\N	2020-06-30 00:00:00	ANCIEN	\N	Communauté de communes d'Auberive, Vingeanne et Montsaugeonnais	Communauté de communes d'Auberive, Vingeanne et Montsaugeonnais	\N	\N	\N	\N	INTERCOM	01057W	\N	\N	de la	2018-02-22 16:06:32	2018-02-22 16:20:03
51574	2003-01-01 00:00:00	\N	2017-10-31 00:00:00	ANCIEN	Président du Syndicat Mixte d'Electricité du Doubs (SYDED)	Président du Syndicat Mixte d'Electricité du Doubs (SYDED)	Président du Syndicat Mixte d'Electricité du Doubs (SYDED)	\N	\N	\N	\N	DIVERS	14219Q	\N	\N	\N	2018-03-28 12:51:59	2018-03-28 12:53:39
51620	2010-10-12 00:00:00	\N	2017-09-29 00:00:00	ANCIEN	\N	\N	Président de la Ségapal	\N	\N	\N	\N	AUTFONLOC	19251M	\N	\N	\N	\N	\N
51621	2008-05-15 00:00:00	\N	2014-05-16 00:00:00	ANCIEN	\N	\N	Vice-président du SIGERLy	\N	\N	\N	\N	AUTFONLOC	19251M	\N	\N	\N	\N	\N
51622	2016-01-26 00:00:00	\N	2017-10-02 00:00:00	ANCIEN	\N	\N	Vice-président du SIGERLy	\N	\N	\N	\N	AUTFONLOC	19251M	\N	\N	\N	\N	\N
51633	2012-11-14 00:00:00	\N	\N	ANCIEN	\N	Communauté de communes Cluses-Arve et Montagnes	Communauté de communes Cluses-Arve et Montagnes	\N	\N	2018	\N	INTERCOM	19768N	\N	\N	de la	\N	\N
51672	2001-04-01 00:00:00	\N	2017-10-06 00:00:00	ANCIEN	\N	communauté de communes de Vie-et-Boulogne	communauté de communes de Vie-et-Boulogne	\N	\N	\N	\N	INTERCOM	14031R	\N	\N	\N	\N	\N
51723	2017-01-26 00:00:00	\N	2019-09-30 00:00:00	ANCIEN	\N	communauté de communes Inter-Caux-Vexin	communauté de communes Inter-Caux-Vexin	\N	\N	\N	\N	INTERCOM	19826F	\N	\N	de la	\N	\N
51721	2002-01-01 00:00:00	\N	2016-12-31 00:00:00	ANCIEN	\N	communauté de communes des Portes Nord-Ouest de Rouen	communauté de communes des Portes Nord-Ouest de Rouen	\N	\N	\N	\N	INTERCOM	19826F	\N	\N	de la	\N	\N
52034	2018-01-15 00:00:00	\N	2020-10-15 00:00:00	ANCIEN	\N	Membre du Conseil économique, social et environnemental régional	Membre du Conseil économique, social et environnemental régional	\N	\N	\N	\N	DIVERS	20060X	\N	\N	\N	\N	\N
51741	2017-09-22 00:00:00	\N	\N	ACTIF	Maire honoraire des Pennes-Mirabeau	Nouveau	Maire honoraire des Pennes-Mirabeau	\N	\N	\N	\N	DIVERS	14239U	\N	\N	\N	\N	\N
52029	1992-03-15 00:00:00	\N	2020-10-15 00:00:00	ANCIEN	\N	Communauté de communes du Rouillacais	Communauté de communes du Rouillacais	\N	\N	\N	\N	INTERCOM	20042V	\N	\N	de la	\N	\N
52037	2014-03-15 00:00:00	\N	\N	ACTIF	\N	Communauté urbaine Le Mans Métropole	Communauté urbaine Le Mans Métropole	\N	\N	\N	\N	INTERCOM	20070A	\N	\N	de la 	\N	\N
52042	2002-03-15 00:00:00	\N	\N	ACTIF	\N	Communauté de communes du pays du coquelicot	Communauté de communes du pays du coquelicot	\N	\N	\N	\N	INTERCOM	17229F	\N	\N	de la	\N	\N
52064	2020-03-15 00:00:00	\N	2020-10-15 00:00:00	ANCIEN	\N	Vice-Président du Conseil de Territoire du Pays Salonais	Vice-Président du Conseil de Territoire du Pays Salonais	\N	\N	\N	\N	AUTFONLOC	20108W	\N	\N	\N	\N	\N
52047	2001-06-15 00:00:00	\N	2020-10-15 00:00:00	ANCIEN	Président du Syndicat d'énergie du Gers	Président du Syndicat d'énergie du Gers	Président du Syndicat d'énergie du Gers	\N	\N	\N	\N	DIVERS	20040T	\N	\N	\N	\N	\N
52061	2016-01-15 00:00:00	\N	\N	ACTIF	\N	Métropole d'Aix-Marseille-Provence	Métropole d'Aix-Marseille-Provence	\N	\N	\N	\N	INTERCOM	20108W	\N	\N	de la	\N	\N
52071	2017-04-15 00:00:00	\N	2020-07-15 00:00:00	ANCIEN	\N	Communauté de Communes Commentry Montmarault Néris Communauté	Communauté de Communes Commentry Montmarault Néris Communauté	\N	\N	\N	\N	INTERCOM	20020P	\N	\N	de la	\N	\N
52072	2000-04-15 00:00:00	\N	2016-03-15 00:00:00	ANCIEN	\N	Communauté de Communes de la Région de Montmarault	Communauté de Communes de la Région de Montmarault	\N	\N	\N	\N	INTERCOM	20020P	\N	\N	de la 	\N	\N
15238	1999-03-01 00:00:00	\N	2016-12-31 00:00:00	ANCIEN	\N	de la communauté de communes du pays de Murat	\N	\N	\N	\N	\N	INTERCOM	14327T	\N	\N	\N	2015-09-11 17:59:58	2018-01-08 20:14:56
51378	2014-03-16 00:00:00	2014-03-16 00:00:00	2021-06-01 00:00:00	ANCIEN	\N	de la communauté d'agglomération Val Parisis	de la communauté d'agglomération Val Parisis	\N	\N	\N	\N	INTERCOM	19671E	\N	\N	\N	2017-09-25 12:05:48	2018-02-09 09:55:13
51513	2017-01-01 00:00:00	\N	2020-06-28 00:00:00	ANCIEN	\N	communauté de communes Pyrénées-Vallées des Gaves	de la communauté de communes Pyrénées-Vallées des Gaves	\N	\N	\N	\N	INTERCOM	19629C	\N	\N	de la	2017-11-13 18:34:43	2017-11-13 18:39:15
51403	2014-04-02 00:00:00	\N	2021-07-20 00:00:00	ANCIEN	\N	communauté urbaine Angers Loire Métropole	de la communauté urbaine Angers Loire Métropole	\N	\N	\N	\N	INTERCOM	19545Y	\N	\N	de la	2017-09-26 14:35:17	2018-05-30 10:18:09
51499	2017-10-19 00:00:00	\N	\N	ACTIF	\N	communauté d'agglomération de Paris-Saclay	\N	\N	\N	\N	\N	INTERCOM	11070L	\N	\N	de la 	2017-10-19 14:51:48	2017-10-19 14:53:06
51547	2005-12-21 00:00:00	\N	2020-06-27 00:00:00	ANCIEN	\N	Communauté de communes Forêts, Lacs, Terres en Champagne	de la Communauté de communes Forêts, Lacs, Terres en Champagne	\N	\N	\N	\N	INTERCOM	19745F	\N	\N	de la	2017-12-18 14:35:36	2017-12-18 14:37:16
51552	2008-03-17 00:00:00	\N	2016-12-31 00:00:00	ANCIEN	\N	Communauté de communes du Montmorillonnais	Communauté de communes du Montmorillonnais	\N	\N	\N	\N	INTERCOM	19747H	\N	\N	de la	2017-12-18 14:55:18	2017-12-18 14:56:31
51553	2017-01-01 00:00:00	\N	\N	ACTIF	\N	Communauté de communes Vienne et Gartempe	Communauté de communes Vienne et Gartempe	\N	\N	\N	\N	INTERCOM	19747H	\N	\N	de la	2017-12-18 14:56:35	2018-02-13 14:50:09
51740	2020-06-29 00:00:00	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	DIVERS	19729F	\N	\N	\N	\N	\N
52115	2020-03-15 00:00:00	\N	2020-10-26 00:00:00	ANCIEN	\N	Communauté d'agglomération Sophia Antipolis	Communauté d'agglomération Sophia Antipolis	\N	\N	\N	\N	INTERCOM	20138D	\N	\N	de la	\N	\N
52093	2010-06-15 00:00:00	\N	2019-12-15 00:00:00	ANCIEN	\N	Vice-Présidente du Syndicat intercommunal des eaux Ain - Suran - Revermont	Vice-Présidente du Syndicat intercommunal des eaux Ain - Suran - Revermont	\N	\N	\N	\N	DIVERS	20094J	\N	\N	\N	\N	\N
51993	2020-03-15 00:00:00	\N	2023-11-01 00:00:00	ANCIEN	\N	Communauté de communes Comtal Lot et Truyère	Communauté de communes Comtal Lot et Truyère	\N	\N	\N	\N	INTERCOM	20032T	\N	\N	de la	\N	\N
51995	2000-12-15 00:00:00	\N	2014-02-15 00:00:00	ANCIEN	\N	Communauté de communes du canton d'Estaing	\N	\N	\N	\N	\N	INTERCOM	20032T	\N	\N	de la	\N	\N
51996	2018-01-15 00:00:00	\N	2020-03-15 00:00:00	ANCIEN	\N	Communauté de communes Comtal Lot et Truyère	\N	\N	\N	\N	\N	INTERCOM	20032T	\N	\N	de la	\N	\N
51997	2014-03-15 00:00:00	\N	2017-12-15 00:00:00	ANCIEN	\N	Communauté de communes Espalion-Estaing	\N	\N	\N	\N	\N	INTERCOM	20032T	\N	\N	de la	\N	\N
52003	2003-01-15 00:00:00	\N	2020-06-15 00:00:00	ANCIEN	\N	Communauté urbaine Limoges Métropole	\N	\N	\N	\N	\N	INTERCOM	20080C	\N	\N	de la	\N	\N
52005	2014-04-15 00:00:00	\N	\N	ACTIF	\N	Communauté d'Agglomération du Centre Littoral de Guyane	Communauté d'Agglomération du Centre Littoral de Guyane	\N	\N	\N	\N	INTERCOM	20146D	\N	\N	de la	\N	\N
52121	2008-03-15 00:00:00	\N	2020-10-23 00:00:00	ANCIEN	\N	Communauté d'agglomération Var Estérel Méditerranée	Communauté d'agglomération Var Estérel Méditerranée	\N	\N	\N	\N	INTERCOM	20074E	\N	\N	de la	\N	\N
52015	2008-03-15 00:00:00	\N	2020-10-26 00:00:00	ANCIEN	\N	Nîmes Métropole	Nîmes Métropole	\N	\N	\N	\N	INTERCOM	20090E	\N	\N	de	\N	\N
52125	2017-01-15 00:00:00	\N	\N	ACTIF	\N	Communauté de communes Le Grand Charolais	Communauté de communes Le Grand Charolais	\N	\N	\N	\N	INTERCOM	20120S	\N	\N	de la	\N	\N
52128	2001-03-15 00:00:00	\N	\N	ACTIF	\N	Chartres Métropole	Chartres Métropole	\N	\N	\N	\N	INTERCOM	20068G	\N	\N	de	\N	\N
52136	2014-03-15 00:00:00	\N	\N	ACTIF	\N	Métropole Nice Côte d'Azur	Métropole Nice Côte d'Azur	\N	\N	\N	\N	INTERCOM	20140W	\N	\N	de la	\N	\N
52138	2020-06-15 00:00:00	\N	\N	ACTIF	\N	Communauté d'Agglomération de la Provence Verte	Communauté d'Agglomération de la Provence Verte	\N	\N	\N	\N	INTERCOM	20072C	\N	\N	de la	\N	\N
52139	2008-03-15 00:00:00	\N	2017-03-15 00:00:00	ANCIEN	\N	Communauté de communes du Val d'Issole	Communauté de communes du Val d'Issole	\N	\N	\N	\N	INTERCOM	20072C	\N	\N	de la	\N	\N
52142	2014-03-15 00:00:00	\N	\N	ACTIF	\N	Communauté de communes du Pays des Abers	Communauté de communes du Pays des Abers	\N	\N	\N	\N	INTERCOM	20106U	\N	\N	de la	\N	\N
52144	2020-03-15 00:00:00	\N	2020-10-26 00:00:00	ANCIEN	\N	Grand Besançon Métropole	\N	\N	\N	\N	\N	INTERCOM	20066E	\N	\N	du	\N	\N
52150	2014-04-15 00:00:00	\N	2020-10-15 00:00:00	ANCIEN	\N	Ardenne Métropole	Ardenne Métropole	\N	\N	\N	\N	INTERCOM	20056C	\N	\N	d'	\N	\N
52153	2008-03-15 00:00:00	\N	\N	ACTIF	\N	Guingamp-Paimpol Agglomération	Guingamp-Paimpol Agglomération	\N	\N	\N	\N	INTERCOM	18193Q	\N	\N	de	\N	\N
52154	2002-01-15 00:00:00	\N	2008-03-15 00:00:00	ANCIEN	\N	Communauté de Communes de Guingamp	Communauté de Communes de Guingamp	\N	\N	\N	\N	INTERCOM	18193Q	\N	\N	de la	\N	\N
52155	2002-01-15 00:00:00	\N	2012-06-15 00:00:00	ANCIEN	\N	Vice-Présidente du Syndicat mixte de traitement des ordures ménagères (SMITRED)	\N	\N	\N	\N	\N	DIVERS	18193Q	\N	\N	\N	\N	\N
52158	2008-03-15 00:00:00	\N	2020-06-15 00:00:00	ANCIEN	\N	Grand Montauban	\N	\N	\N	\N	\N	INTERCOM	20052X	\N	\N	du	\N	\N
52159	2008-03-15 00:00:00	\N	2020-06-15 00:00:00	ANCIEN	\N	Vice-Président du Syndicat Mixte de Traitement des Ordures Ménagères et Autres Déchets (SIRTOMAD)	\N	\N	\N	\N	\N	DIVERS	20052X	\N	\N	\N	\N	\N
52160	2008-03-15 00:00:00	\N	2020-06-15 00:00:00	ANCIEN	\N	Président du schéma de cohérence territoriale (SCoT) de Montauban	\N	\N	\N	\N	\N	DIVERS	20052X	\N	\N	\N	\N	\N
52161	1998-01-15 00:00:00	\N	2020-10-26 00:00:00	ANCIEN	\N	Président du Syndicat de Valorisation et d'Élimination des Déchets (SIVED)	Président du Syndicat de Valorisation et d'Élimination des Déchets (SIVED)	\N	\N	\N	\N	DIVERS	20072C	\N	\N	\N	\N	\N
52163	2001-09-15 00:00:00	\N	\N	ACTIF	\N	Communauté de communes du pays de Mirepoix	\N	\N	\N	\N	\N	INTERCOM	20018V	\N	\N	de la	\N	\N
52165	2017-01-15 00:00:00	2020-06-15 00:00:00	2020-10-15 00:00:00	ANCIEN	\N	Communauté de communes Pasquale Paoli	\N	\N	\N	\N	\N	INTERCOM	20036X	\N	\N	de la	\N	\N
52168	2017-07-15 00:00:00	2017-07-15 00:00:00	2020-10-15 00:00:00	ANCIEN	Vice-Présidente de Haute Garonne Numérique	Vice-Présidente de Haute Garonne Numérique	Vice-Présidente de Haute Garonne Numérique	\N	\N	\N	\N	DIVERS	17965H	\N	\N	\N	\N	\N
52171	2014-03-15 00:00:00	2008-03-15 00:00:00	2020-10-20 00:00:00	ANCIEN	\N	Communauté de communes de Briance Sud Haute-Vienne	\N	\N	\N	\N	\N	INTERCOM	20082E	\N	\N	de la	\N	\N
52181	2001-05-15 00:00:00	\N	2009-05-15 00:00:00	ANCIEN	\N	Communauté d'agglomération de Saint-Brieuc	\N	\N	\N	\N	\N	INTERCOM	20104S	\N	\N	de la	\N	\N
52183	2014-03-15 00:00:00	\N	2021-07-15 00:00:00	ANCIEN	\N	Communauté de Communes des Hauts du Val de Saône	\N	\N	\N	\N	\N	INTERCOM	20054A	\N	\N	de la	\N	\N
52188	2018-05-15 00:00:00	\N	\N	ACTIF	\N	Membre de l'Assemblée de la Polynésie française	Membre de l'Assemblée de la Polynésie française	\N	\N	\N	\N	DIVERS	20150Y	\N	\N	\N	\N	\N
52190	2013-05-15 00:00:00	\N	2015-05-15 00:00:00	ANCIEN	\N	Membre de l'Assemblée de la Polynésie française	Membre de l'Assemblée de la Polynésie française	\N	\N	\N	\N	DIVERS	20150Y	\N	\N	\N	\N	\N
52197	2008-02-15 00:00:00	\N	2009-02-15 00:00:00	ANCIEN	\N	Membre de l'Assemblée de la Polynésie française	Membre de l'Assemblée de la Polynésie française	\N	\N	\N	\N	DIVERS	20150Y	\N	\N	\N	\N	\N
52204	2020-06-15 00:00:00	\N	2022-02-01 00:00:00	ANCIEN	\N	Communauté d'Agglomération du Bassin d'Aurillac (CABA)	\N	\N	\N	\N	\N	INTERCOM	20044X	\N	\N	de la	\N	\N
52206	2018-10-15 00:00:00	2020-06-15 00:00:00	\N	ACTIF	\N	Eurométropole de Strasbourg	\N	\N	\N	\N	\N	INTERCOM	20098N	\N	\N	de l'	\N	\N
52212	2001-04-15 00:00:00	\N	2017-03-15 00:00:00	ANCIEN	\N	Communauté de communes du Bernavillois	\N	\N	\N	\N	\N	INTERCOM	20062A	\N	\N	de la	\N	\N
52213	2017-01-15 00:00:00	\N	2020-06-15 00:00:00	ANCIEN	\N	Communauté de communes du Territoire Nord Picardie	\N	\N	\N	\N	\N	INTERCOM	20062A	\N	\N	de la	\N	\N
52218	2008-03-15 00:00:00	\N	2016-12-15 00:00:00	ANCIEN	\N	Communauté de communes des Corbières	Communauté de communes des Corbières	\N	\N	\N	\N	INTERCOM	20030R	\N	\N	\N	\N	\N
52220	\N	\N	\N	ANCIEN	\N	Président délégué de l'agence de développement touristique Aude Pays Cathare	Président délégué de l'agence de développement touristique Aude Pays Cathare	\N	2014	2020	\N	DIVERS	20030R	\N	\N	\N	\N	\N
52221	\N	\N	\N	ANCIEN	\N	Vice-Président du Syndicat Mixte de Préfiguration du Parc naturel régional Corbières-Fenouillèdes	Vice-Président du Syndicat Mixte de Préfiguration du Parc naturel régional Corbières-Fenouillèdes	\N	2015	2020	\N	DIVERS	20030R	\N	\N	\N	\N	\N
52222	\N	\N	\N	ANCIEN	\N	Vice-Président du Syndicat Mixte de l'Opération Grand Site de la Cité de Carcassonne	Vice-Président du Syndicat Mixte de l'Opération Grand Site de la Cité de Carcassonne	\N	2015	2020	\N	DIVERS	20030R	\N	\N	\N	\N	\N
15208	2015-06-12 00:00:00	\N	\N	ACTIF	\N	à la communauté d'agglomération du Grand Chalon	à la communauté d'agglomération du Grand Chalon	\N	\N	\N	\N	INTERCOM	14147R	\N	\N	\N	2015-06-12 15:49:53	2017-11-07 16:18:31
15246	2015-10-07 00:00:00	\N	2021-04-08 00:00:00	ANCIEN	Membre du Conseil stratégique de la Recherche	Membre du Conseil stratégique de la Recherche	Membre du Conseil stratégique de la Recherche	\N	\N	\N	\N	DIVERS	11068S	\N	\N	\N	2015-10-12 18:02:41	2015-10-12 18:05:03
15247	2015-10-27 00:00:00	\N	2017-10-01 00:00:00	ANCIEN	Co-président de la Cité internationale de la tapisserie	Co-président de la Cité internationale de la tapisserie d'Aubusson	Co-président de la Cité internationale de la tapisserie d'Aubusson	\N	\N	\N	\N	DIVERS	08012N	\N	\N	\N	2015-10-27 12:11:43	2017-11-09 12:06:14
15281	2001-03-18 00:00:00	\N	2016-01-29 00:00:00	ANCIEN	\N	de la Communauté de communes mer et terres d'Opale	de la Communauté de communes mer et terres d'Opale	\N	\N	\N	\N	INTERCOM	14331P	\N	\N	\N	2016-01-13 11:47:53	2016-02-19 14:37:58
15285	2016-03-18 00:00:00	\N	2016-11-17 00:00:00	ANCIEN	Président du syndicat mixte Réseau d'initiative publique 36	Président du syndicat mixte Réseau d'initiative publique 36	Président du syndicat mixte Réseau d'initiative publique 36	\N	\N	\N	\N	AUTFONLOC	07032N	\N	\N	\N	2016-03-18 09:48:05	2016-11-18 12:37:49
15286	2016-03-18 00:00:00	\N	2016-11-17 00:00:00	ANCIEN	Président de l'EPD Blanche de Fontarce	Président de l'Établissement public départemental Blanche de Fontarce	Président de l'Établissement public départemental Blanche de Fontarce	\N	\N	\N	\N	AUTFONLOC	07032N	\N	\N	\N	2016-03-18 09:52:19	2016-11-18 12:37:49
15332	2016-01-01 00:00:00	\N	\N	ACTIF	\N	de la Communauté urbaine Grand Paris Seine et Oise	\N	\N	\N	\N	\N	INTERCOM	11090Q	\N	\N	\N	2016-10-06 14:54:52	2018-02-13 12:39:28
51077	2014-04-29 00:00:00	\N	2016-12-31 00:00:00	ANCIEN	\N	communauté de communes de la Vallée de Saint-Savin	de la communauté de communes de la Vallée de Saint-Savin	\N	\N	\N	\N	INTERCOM	19629C	\N	\N	de la 	2017-09-24 14:12:14	2017-11-13 18:34:35
51155	2014-03-16 00:00:00	\N	2018-04-16 00:00:00	ANCIEN	\N	communauté urbaine Angers Loire métropole	de la communauté urbaine Angers Loire métropole	\N	\N	\N	\N	INTERCOM	19533U	\N	\N	de la	2017-09-24 17:37:00	2018-04-26 14:58:46
51249	2001-03-18 00:00:00	\N	\N	ACTIF	\N	de la communauté de communes du Pays de Bray	de la communauté de communes du Pays de Bray	\N	\N	\N	\N	INTERCOM	19677L	\N	\N	\N	2017-09-24 18:36:15	2017-09-24 18:38:01
51319	2008-03-23 00:00:00	\N	\N	ACTIF	\N	communauté d'agglomération Hénin-Carvin	de la communauté d'agglomération Hénin-Carvin	\N	\N	\N	\N	INTERCOM	19681G	\N	\N	de la	2017-09-24 19:50:05	2017-11-13 11:28:07
51425	2017-01-01 00:00:00	\N	\N	ACTIF	\N	communauté de communes de Forez-Est	de la communauté de communes de Forez-Est	\N	\N	\N	\N	INTERCOM	19413M	\N	\N	de la	2017-09-27 10:17:46	2018-03-08 15:26:35
51426	2014-03-23 00:00:00	\N	2017-10-21 00:00:00	ANCIEN	\N	agglomération d'Agen	de l'agglomération d'Agen	\N	\N	\N	\N	INTERCOM	19367Y	\N	\N	de l'	2017-09-27 10:19:38	2018-05-30 16:21:08
51427	2008-03-16 00:00:00	\N	2016-12-31 00:00:00	ANCIEN	\N	communauté de communes de Balbigny	de la communauté de communes de Balbigny	\N	\N	\N	\N	INTERCOM	19413M	\N	\N	de la	2017-09-27 10:20:03	2017-09-27 10:21:28
51430	2017-01-01 00:00:00	\N	2017-10-31 00:00:00	ANCIEN	\N	communauté de communes Loire, Vignobles et Nohain	de la communauté de communes Loire, Vignobles et Nohain	\N	\N	\N	\N	INTERCOM	19713W	\N	\N	de la	2017-09-27 10:27:25	2018-01-12 14:43:48
51431	2014-03-30 00:00:00	\N	2016-12-31 00:00:00	ANCIEN	\N	communauté de communes Loire et Nohain	de la communauté de communes Loire et Nohain	\N	\N	\N	\N	INTERCOM	19713W	\N	\N	de la	2017-09-27 10:31:30	2017-09-27 10:33:55
51432	2015-01-01 00:00:00	\N	\N	ACTIF	\N	communauté de communes Causses et Vallée de la Dordogne	de la communauté de communes Causses et Vallée de la Dordogne	\N	\N	\N	\N	INTERCOM	19503N	\N	\N	de la	2017-09-27 10:59:26	2017-09-27 10:59:58
51434	2004-01-01 00:00:00	\N	2020-07-09 00:00:00	ANCIEN	\N	Portes de France-Thionville	de la communauté d'agglomération Portes de France-Thionville	\N	\N	\N	\N	INTERCOM	19335Q	\N	\N	de	2017-09-27 11:14:03	2017-12-06 14:25:04
51435	2014-01-01 00:00:00	\N	2020-06-28 00:00:00	ANCIEN	\N	Lorient Agglomération	de Lorient Agglomération	\N	\N	\N	\N	INTERCOM	16685X	\N	\N	de	2017-09-27 11:29:02	2017-09-27 11:29:45
51436	1997-01-01 00:00:00	\N	2013-12-31 00:00:00	ANCIEN	\N	communauté de communes de la région de Plouay	de la communauté de communes de la région de Plouay	\N	\N	\N	\N	INTERCOM	16685X	\N	\N	de la	2017-09-27 11:29:04	2017-09-27 11:30:55
51438	2014-01-01 00:00:00	\N	\N	ACTIF	\N	Sarrebourg - Moselle Sud	de la communauté de communes de Sarrebourg - Moselle Sud	\N	\N	\N	\N	INTERCOM	19685L	\N	\N	de	2017-09-27 11:55:33	2017-09-27 11:55:54
51448	2009-05-10 00:00:00	\N	2019-06-30 00:00:00	ANCIEN	Conseiller provincial du Nord Nouvelle-Calédonie	Conseiller provincial du Nord Nouvelle-Calédonie	Conseiller provincial du Nord Nouvelle-Calédonie	\N	\N	\N	\N	DIVERS	19319Q	\N	\N	\N	2017-09-28 10:59:00	2017-09-28 11:05:30
51449	2015-12-14 00:00:00	\N	2017-12-30 00:00:00	ANCIEN	\N	communauté d'agglomération du nord de la Réunion	de la communauté d'agglomération du nord de la Réunion	\N	\N	\N	\N	INTERCOM	19583F	\N	\N	de la	2017-09-28 11:15:17	2018-01-08 17:38:39
51451	2014-03-23 00:00:00	\N	2021-07-21 00:00:00	ANCIEN	\N	communauté d'agglomération de Valenciennes Métropole	de la communauté d'agglomération de Valenciennes Métropole	\N	\N	\N	\N	INTERCOM	19565D	\N	\N	de la 	2017-09-29 10:02:25	2017-09-29 10:04:18
51523	2014-03-30 00:00:00	\N	2020-03-15 00:00:00	ANCIEN	\N	Communauté de communes Coeur et Coteaux du Comminges	\N	\N	\N	\N	\N	INTERCOM	14221J	\N	\N	de la	2017-11-22 10:23:06	2017-11-22 10:29:00
51568	2018-02-13 00:00:00	\N	\N	ACTIF	Membre du comité syndical - SIMER	Membre du comité syndical - SIMER	Membre du comité syndical - SIMER	\N	\N	\N	\N	DIVERS	19747H	\N	\N	\N	2018-02-13 14:51:51	2018-02-13 14:54:58
51539	2001-03-25 00:00:00	\N	\N	ACTIF	Membre du bureau du SYTRAL	Membre du bureau du Syndicat Mixte des Transports pour le Rhône et l'Agglomération Lyonnaise	Membre du bureau du Syndicat Mixte des Transports pour le Rhône et l'Agglomération Lyonnaise	\N	\N	\N	\N	AUTFONLOC	19737F	\N	\N	\N	2017-12-06 14:39:16	2017-12-06 15:03:47
51576	2015-01-08 00:00:00	\N	2017-10-24 00:00:00	ANCIEN	Présidente du Pôle d'Équilibre Territorial et Rural PLVG	Présidente du Pôle d'Équilibre Territorial et Rural PLVG	Présidente du Pôle d'Équilibre Territorial et Rural PLVG	\N	\N	\N	\N	DIVERS	19629C	\N	\N	\N	2018-03-29 20:04:40	2018-03-29 20:10:59
51577	2017-01-11 00:00:00	\N	\N	ACTIF	Déléguée au PETR du Pays de Lourdes et des Vallées des Gaves	Déléguée au Pôle d'Équilibre Territorial et Rural (PETR) du Pays de Lourdes et des Vallées des Gaves	Déléguée au Pôle d'Équilibre Territorial et Rural (PETR) du Pays de Lourdes et des Vallées des Gaves	\N	\N	\N	\N	DIVERS	19629C	\N	\N	\N	2018-03-29 20:11:08	2018-03-29 20:13:44
51580	2008-03-31 00:00:00	\N	2017-11-16 00:00:00	ANCIEN	Président de l'association des maires de l'Indre-et-Loire	Président de l'association des maires de l'Indre-et-Loire	Président de l'association des maires de l'Indre-et-Loire	\N	\N	\N	\N	DIVERS	19441R	\N	\N	\N	2018-04-09 19:14:00	2018-04-09 19:15:26
51594	2008-03-16 00:00:00	\N	2018-06-21 00:00:00	ANCIEN	\N	Communauté d'agglomération Caux-Seine	Communauté d'agglomération Caux-Seine	\N	\N	\N	\N	INTERCOM	19758L	\N	\N	de la	2018-06-04 13:58:53	2018-06-04 14:00:15
51696	2019-09-12 00:00:00	\N	\N	ACTIF	Auditrice  du CHEID	Auditrice de la session 2019-2020 du collège des hautes-études de l'institut diplomatique	Auditrice de la session 2019-2020 du collège des hautes-études de l'institut diplomatique	\N	\N	\N	\N	DIVERS	19443T	\N	\N	\N	\N	\N
51636	2017-01-02 00:00:00	\N	\N	ACTIF	\N	Communauté de communes les Sorgues du Comtat	Communauté de communes les Sorgues du Comtat	\N	\N	\N	\N	INTERCOM	04092N	\N	\N	de la	\N	\N
51639	2017-01-01 00:00:00	\N	\N	ACTIF	\N	Communauté territoriale du Pays d'Aix	Communauté territoriale du Pays d'Aix	\N	\N	\N	\N	INTERCOM	08044W	\N	\N	de la	\N	\N
51706	\N	\N	\N	ACTIF	Association des maires de France (Ain)	Association des maires de France (Ain)	Rapporteur général de l'association des maires de l'Ain	\N	\N	\N	\N	DIVERS	08056B	\N	\N	\N	\N	\N
51746	2020-07-07 00:00:00	\N	\N	ACTIF	Membre du comité interministériel du tourisme	Membre du comité interministériel du tourisme	Membre du comité interministériel du tourisme	\N	\N	\N	\N	DIVERS	19515S	\N	\N	\N	\N	\N
51759	2020-07-15 00:00:00	\N	\N	ACTIF	\N	\N	Maire honoraire de Lazer	\N	\N	\N	\N	DIVERS	14265W	\N	\N	\N	\N	\N
52085	2020-03-15 00:00:00	\N	\N	ACTIF	\N	Seine Normandie Agglomération	Seine Normandie Agglomération	\N	\N	\N	\N	INTERCOM	19265T	\N	\N	de	\N	\N
52088	2020-07-15 00:00:00	\N	\N	ACTIF	\N	Communauté de communes du pays Loudunais	Communauté de communes du pays Loudunais	\N	\N	\N	\N	INTERCOM	20024T	\N	\N	de la	\N	\N
15283	2016-01-19 00:00:00	\N	\N	ACTIF	\N	de l'Établissement public territorial Grand Paris Seine Ouest	de l'Établissement public territorial Grand Paris Seine Ouest	\N	\N	\N	\N	INTERCOM	11085T	\N	\N	\N	2016-01-19 17:59:23	2017-11-10 18:19:59
15521	2017-01-01 00:00:00	\N	\N	ACTIF	\N	de la communauté de communes de l'Oise Picardie	Conseiller de la communauté de communes de l'Oise Picardie	\N	\N	\N	\N	INTERCOM	92045V	\N	\N	\N	2017-04-21 11:59:28	2017-04-21 12:03:19
15523	2017-01-01 00:00:00	\N	2020-06-28 00:00:00	ANCIEN	\N	de la communauté de communes Villedieu Intercom	\N	\N	\N	\N	\N	INTERCOM	05008E	\N	\N	\N	2017-04-21 14:45:25	2017-11-06 16:26:25
15524	2014-04-24 00:00:00	\N	2015-12-31 00:00:00	ANCIEN	\N	de la communauté d'agglomération Angers Loire Métropole	\N	\N	\N	\N	\N	INTERCOM	11030C	\N	\N	\N	2017-04-21 14:56:18	2017-04-21 15:03:44
15525	2016-01-01 00:00:00	\N	\N	ACTIF	\N	de la communauté urbaine Angers Loire Métropole	\N	\N	\N	\N	\N	INTERCOM	11030C	\N	\N	\N	2017-04-21 15:00:16	2017-04-21 15:03:49
15526	2017-01-01 00:00:00	\N	2020-07-10 00:00:00	ANCIEN	\N	de la communauté urbaine du Grand Reims	\N	\N	\N	\N	\N	INTERCOM	01024M	\N	\N	\N	2017-04-21 15:12:05	2017-04-21 15:12:59
51146	2003-01-01 00:00:00	\N	2014-03-30 00:00:00	ANCIEN	\N	Cap Atlantique	communuaté d'agglomération Cap Atlantique	\N	\N	\N	\N	INTERCOM	17583W	\N	\N	\N	2017-09-24 17:30:36	2017-09-24 17:34:35
51214	2001-03-18 00:00:00	\N	2015-12-31 00:00:00	ANCIEN	\N	communauté de communes du canton de Monestier de Clermont	communauté de communes du canton de Monestier de Clermont	\N	\N	\N	\N	INTERCOM	19679N	\N	\N	de la	2017-09-24 18:13:18	2017-11-17 09:46:33
51215	2016-01-01 00:00:00	\N	2020-06-28 00:00:00	ANCIEN	\N	communauté de communes du Trièves	de la communauté de communes du Trièves	\N	\N	\N	\N	INTERCOM	19679N	\N	\N	de la	2017-09-24 18:14:34	2017-11-17 09:25:59
51251	2017-01-01 00:00:00	\N	2017-10-09 00:00:00	ANCIEN	\N	communauté de communes Mad et Moselle	communauté de communes Mad et Moselle	\N	\N	\N	\N	INTERCOM	19551W	\N	\N	de la 	2017-09-24 18:37:37	2017-09-24 18:41:31
51445	2014-03-30 00:00:00	\N	2017-10-20 00:00:00	ANCIEN	\N	communauté intercommunale des Villes solidaires	de la communauté intercommunale des Villes solidaires	\N	\N	\N	\N	INTERCOM	19659J	\N	\N	de la	2017-09-27 17:25:29	2017-11-10 10:35:21
51295	2008-03-16 00:00:00	\N	2015-12-31 00:00:00	ANCIEN	\N	de la Communauté d'agglomération du Val d'Orge	de la Communauté d'agglomération du Val d'Orge	\N	\N	\N	\N	INTERCOM	19289C	\N	\N	\N	2017-09-24 19:19:45	2018-01-16 09:52:29
51296	2016-01-01 00:00:00	\N	2022-02-02 00:00:00	ANCIEN	\N	de Coeur d'Essonne Agglomération	de Coeur d'Essonne Agglomération	\N	\N	\N	\N	INTERCOM	19289C	\N	\N	\N	2017-09-24 19:19:47	2018-01-16 09:51:13
51390	2014-03-23 00:00:00	\N	\N	ACTIF	\N	de la communauté de communes du pays de Limours	de la communauté de communes du pays de Limours	\N	\N	\N	\N	INTERCOM	19399H	\N	\N	\N	2017-09-25 17:44:35	2018-01-12 15:11:04
51467	2014-01-01 00:00:00	\N	2017-10-02 00:00:00	ANCIEN	\N	Communauté de commune du sud Gironde	de la Communauté de commune du sud Gironde	\N	\N	\N	\N	INTERCOM	19725B	\N	\N	de la	2017-10-01 10:48:48	2017-11-15 10:01:18
51486	2017-01-01 00:00:00	\N	\N	ACTIF	\N	Communauté urbaine de Caen La Mer	de la Communauté urbaine de Caen La Mer	\N	\N	\N	\N	INTERCOM	19735D	\N	\N	de la	2017-10-01 11:51:51	2017-10-01 11:53:35
51502	2014-03-30 00:00:00	\N	\N	ACTIF	\N	communauté de communes du Grand Chambord	de la communauté de communes du Grand Chambord	\N	\N	\N	\N	INTERCOM	19739H	\N	\N	de la	2017-11-03 11:00:02	2018-01-10 18:59:14
51507	2017-10-02 00:00:00	\N	\N	ACTIF	\N	Châteauroux Métropole	de Châteauroux Métropole	\N	\N	\N	\N	INTERCOM	14355X	\N	\N	de	2017-11-08 17:01:03	2017-11-08 17:02:41
51512	2008-04-01 00:00:00	\N	2012-01-01 00:00:00	ANCIEN	Président du projet de parc naturel du golfe du Morbihan	Président du projet de parc naturel du golfe du Morbihan	Président du projet de parc naturel du golfe du Morbihan	\N	\N	\N	\N	DIVERS	11099A	\N	\N	\N	2017-11-13 10:39:50	2017-11-13 14:45:10
51518	2014-04-01 00:00:00	\N	2017-10-01 00:00:00	ANCIEN	\N	Syndicat mixte Autolib' Vélib' Métropole	Présidente du Syndicat mixte Autolib' Vélib' Métropole	\N	\N	\N	\N	AUTFONLOC	19649G	\N	\N	\N	2017-11-16 16:02:36	2017-11-16 16:10:54
51530	2017-01-01 00:00:00	\N	2017-12-21 00:00:00	ANCIEN	\N	communauté de communes Senlis Sud Oise	de la communauté de communes Senlis Sud Oise	\N	\N	\N	\N	INTERCOM	19741B	\N	\N	de la	2017-11-24 22:10:27	2018-05-30 09:20:01
51575	2014-01-08 00:00:00	\N	2014-12-31 00:00:00	ANCIEN	Présidente du Pays de Lourdes et des Vallées des Gaves	Présidente du Pays de Lourdes et des Vallées des Gaves (PLVG)	Présidente du Pays de Lourdes et des Vallées des Gaves (PLVG)	\N	\N	\N	\N	DIVERS	19629C	\N	\N	\N	2018-03-29 18:16:50	2018-03-29 20:04:34
51628	2014-03-30 00:00:00	\N	\N	ACTIF	\N	la communauté d'agglomération de Saint-Germain Boucles-de-Seine	la communauté d'agglomération de Saint-Germain Boucles-de-Seine	\N	\N	\N	\N	INTERCOM	19701S	\N	\N	de	\N	\N
51586	2017-12-29 00:00:00	\N	\N	ACTIF	Saint-Maurice	Maire honoraire	Maire honoraire de Saint-Maurice	\N	\N	\N	\N	AUTFONLOC	04042C	\N	\N	de	2018-05-17 19:37:56	2018-05-17 19:39:07
51631	2017-01-01 00:00:00	\N	\N	ACTIF	\N	Communauté de communes Ponthieu-Marquenterre	Communauté de communes Ponthieu-Marquenterre	\N	\N	\N	\N	INTERCOM	04089T	\N	\N	de la	\N	\N
51641	2018-10-23 00:00:00	\N	2023-09-01 00:00:00	ANCIEN	Observatoire national de la présence postale	Observatoire national de la présence postale	Président de l'Observatoire national de la présence postale	\N	\N	\N	\N	DIVERS	14038Y	\N	\N	\N	\N	\N
51656	2001-11-29 00:00:00	\N	2016-12-31 00:00:00	ANCIEN	\N	Communauté de communes du Val Drouette	\N	\N	\N	\N	\N	INTERCOM	19794Q	\N	\N	de la	\N	\N
51695	2017-01-01 00:00:00	\N	2019-09-26 00:00:00	ANCIEN	\N	Convergence Garonne	\N	\N	\N	\N	\N	INTERCOM	19820Y	\N	\N	\N	\N	\N
51742	2018-01-24 00:00:00	\N	\N	ACTIF	Maire honoraire de Mandelieu-la-Napoule	Nouveau	Maire honoraire de Mandelieu-la-Napoule	\N	\N	\N	\N	DIVERS	19729F	\N	\N	\N	\N	\N
51748	2017-10-25 00:00:00	\N	\N	ACTIF	Administrateur du Centre de Gestion de la FPT du Rhône	Administrateur du Centre de Gestion de la Fonction Publique Territoriale du Rhône	Administrateur du Centre de Gestion de la Fonction Publique Territoriale du Rhône	\N	\N	\N	\N	DIVERS	14215L	\N	\N	\N	\N	\N
52020	2014-03-15 00:00:00	\N	\N	ACTIF	\N	Communauté de communes Coeur d'Yvelines	Communauté de communes Coeur d'Yvelines	\N	\N	\N	\N	INTERCOM	20152B	\N	\N	de la 	\N	\N
52077	2020-05-15 00:00:00	\N	\N	ACTIF	\N	communauté d'agglomération Gap-Tallard-Durance	communauté d'agglomération Gap-Tallard-Durance	\N	\N	\N	\N	INTERCOM	14189C	\N	\N	de la	\N	\N
52074	1993-03-15 00:00:00	\N	1999-03-15 00:00:00	ANCIEN	\N	Syndicat Intercommunal d'Aménagement et de Développement de la Région de Montmarault	Syndicat Intercommunal d'Aménagement et de Développement de la Région de Montmarault	\N	\N	\N	\N	INTERCOM	20020P	\N	\N	du	\N	\N
52080	2020-06-15 00:00:00	\N	2020-10-20 00:00:00	ANCIEN	\N	Communauté de communes Lacs et Gorges du Verdon	Communauté de communes Lacs et Gorges du Verdon	\N	\N	\N	\N	INTERCOM	20076G	\N	\N	de la	\N	\N
52094	2019-01-15 00:00:00	\N	2020-10-27 00:00:00	ANCIEN	\N	Vice-Présidente du syndicat des eaux Bresse Suran Revermont	Vice-Présidente du syndicat des eaux Bresse Suran Revermont	\N	\N	\N	\N	DIVERS	20094J	\N	\N	\N	\N	\N
52095	2020-07-15 00:00:00	\N	\N	ACTIF	\N	Communauté d'agglomération du Bassin de Bourg-en-Bresse	Communauté d'agglomération du Bassin de Bourg-en-Bresse	\N	\N	\N	\N	INTERCOM	20094J	\N	\N	de la	\N	\N
52101	1995-04-15 00:00:00	\N	2008-04-15 00:00:00	ANCIEN	\N	Communauté de communes du Clermontais	Communauté de communes du Clermontais	\N	\N	\N	\N	INTERCOM	20116W	\N	\N	de la	\N	\N
52102	2014-07-15 00:00:00	\N	2020-10-15 00:00:00	ANCIEN	\N	Président du Centre de Gestion de la Fonction Publique Territoriale de l'Hérault	Président du Centre de Gestion de la Fonction Publique Territoriale de l'Hérault	\N	\N	\N	\N	DIVERS	20116W	\N	\N	\N	\N	\N
52106	1996-01-15 00:00:00	\N	2019-01-15 00:00:00	ANCIEN	\N	Communauté de communes du Pays de Gex	Communauté de communes du Pays de Gex	\N	\N	\N	\N	INTERCOM	17367Q	\N	\N	\N	\N	\N
52108	2020-06-15 00:00:00	\N	2020-10-26 00:00:00	ANCIEN	\N	Communauté d'agglomération Luberon Monts de Vaucluse	Communauté d'agglomération Luberon Monts de Vaucluse	\N	\N	\N	\N	INTERCOM	20086J	\N	\N	de la	\N	\N
52110	2020-03-15 00:00:00	\N	2020-10-26 00:00:00	ANCIEN	\N	Président de l'OPHLM Vallis Habitat 	Président de l'OPHLM Vallis Habitat 	\N	\N	\N	\N	DIVERS	20086J	\N	\N	\N	\N	\N
52111	2001-06-15 00:00:00	\N	2008-06-15 00:00:00	ANCIEN	\N	Communauté d'agglomération Provence Luberon Durance	Communauté d'agglomération Provence Luberon Durance	\N	\N	\N	\N	INTERCOM	20086J	\N	\N	de la	\N	\N
15190	2014-03-17 00:00:00	\N	2017-01-01 00:00:00	ANCIEN	\N	de la communauté de communes du pays de Bourgueil	Communauté de communes du pays de Bourgueil	\N	\N	\N	\N	INTERCOM	14271U	\N	\N	\N	2015-04-08 10:58:04	2017-05-15 11:03:47
15210	2015-06-16 00:00:00	\N	2015-07-24 00:00:00	ANCIEN	\N	 de la communauté d'agglomération Caen la Mer	 de la communauté d'agglomération Caen la Mer	\N	\N	\N	\N	INTERCOM	14281W	\N	\N	\N	2015-06-16 17:38:18	2015-07-27 15:34:54
15245	2010-12-02 00:00:00	\N	\N	ACTIF	\N	de la communauté de communes de La Brie des Morin	\N	\N	\N	\N	\N	INTERCOM	14329V	\N	\N	\N	2015-10-12 12:18:33	2017-11-08 16:02:02
15527	2016-01-11 00:00:00	\N	\N	ACTIF	\N	de la communauté d'agglomération Val Parisis	\N	\N	\N	\N	\N	INTERCOM	11088W	\N	\N	\N	2017-04-21 15:52:28	2017-04-21 15:54:53
15536	\N	\N	2016-12-31 00:00:00	ANCIEN	\N	de la Communauté de Communes de la Vallée du Louron	de la Communauté de Communes de la Vallée du Louron	\N	2014	\N	\N	INTERCOM	14365A	\N	\N	\N	2017-05-17 11:47:07	2017-05-17 11:49:51
15539	2017-05-01 00:00:00	\N	\N	ACTIF	\N	Président de la commission chargée de l'action de l'Observatoire sur les effets du réchauffement climatique	Président de la commission spéciale chargée de l'orientation de l'action de l'Observatoire national sur les effets du réchauffement climatique au sein du Conseil national de la transition écologique (CNTE)	\N	\N	\N	\N	DIVERS	11065P	\N	\N	\N	2017-05-18 16:37:31	2017-05-18 17:27:45
50740	2017-07-27 00:00:00	\N	\N	ACTIF	Représentant spécial auprès de l'OSCE	Représentant spécial pour les affaires méditerranéennes de l'Assemblée parlementaire de l'OSCE	Représentant spécial pour les affaires méditerranéennes de l'Assemblée parlementaire de l'OSCE	\N	\N	\N	\N	DIVERS	14133K	\N	\N	\N	2017-07-27 17:36:15	2017-07-27 17:36:55
51282	2014-03-30 00:00:00	\N	2017-09-30 00:00:00	ANCIEN	\N	de la communauté d'agglomération Saint-Quentin-en-Yvelines	\N	\N	\N	\N	\N	INTERCOM	19699S	\N	\N	\N	2017-09-24 19:13:36	2017-11-13 19:55:02
51308	2008-03-16 00:00:00	\N	\N	ACTIF	\N	Communauté de communes du Dourdannais en Hurepoix	Communauté de communes du Dourdannais en Hurepoix	\N	\N	\N	\N	INTERCOM	19691J	\N	\N	de la	2017-09-24 19:27:04	2017-11-08 10:01:25
51317	1995-03-01 00:00:00	\N	2008-03-16 00:00:00	ANCIEN	\N	des Monts du Pilat	de la Communauté de communes des Monts du Pilat	\N	\N	\N	\N	INTERCOM	19415P	\N	\N	\N	2017-09-24 19:47:40	2017-09-24 19:49:07
51324	2014-03-30 00:00:00	\N	2020-06-28 00:00:00	ANCIEN	\N	communauté de communes Maremne Adour Côte-Sud	de la communauté de communes de Maremne Adour Côte-Sud	\N	\N	\N	\N	INTERCOM	19489J	\N	\N	de la	2017-09-24 19:58:22	2017-11-08 17:42:30
51340	2008-03-16 00:00:00	\N	2015-12-31 00:00:00	ANCIEN	\N	communauté d'agglomération des Hauts-de-Bièvre	de la communauté d'agglomération des Hauts-de-Bièvre	\N	\N	\N	\N	INTERCOM	17637T	\N	\N	de la	2017-09-24 20:28:29	2017-10-05 15:05:00
51350	2009-01-01 00:00:00	\N	2015-12-31 00:00:00	ANCIEN	\N	de la Communauté d'agglomération du Mont-Valérien	de la Communauté d'agglomération du Mont-Valérien	\N	\N	\N	\N	INTERCOM	19591F	\N	\N	\N	2017-09-24 20:37:33	2017-09-24 20:38:34
51393	2014-03-23 00:00:00	\N	2017-10-24 00:00:00	ANCIEN	\N	Val d'Europe agglomération	de Val d'Europe agglomération	\N	\N	\N	\N	INTERCOM	19543W	\N	\N	de 	2017-09-26 10:00:35	2017-11-09 17:54:11
51396	2014-03-23 00:00:00	\N	2020-06-28 00:00:00	ANCIEN	\N	d'Angers Loire Métropole	d'Angers Loire Métropole	\N	\N	\N	\N	INTERCOM	19549D	\N	\N	\N	2017-09-26 10:52:59	2018-05-15 14:53:46
51397	2001-03-18 00:00:00	\N	2008-03-16 00:00:00	ANCIEN	\N	 Pays de Thelle	du Pays de Thelle	\N	\N	\N	\N	INTERCOM	19573D	\N	\N	du	2017-09-26 10:54:41	2017-09-26 10:59:06
51514	\N	\N	2017-09-16 00:00:00	ANCIEN	\N	communauté de communes de la Lomagne Gersoises	communauté de communes de la Lomagne Gersoises	\N	\N	\N	\N	INTERCOM	08049C	\N	\N	de la	2017-11-14 09:41:17	2017-11-14 09:42:36
51404	2008-03-16 00:00:00	\N	2020-06-28 00:00:00	ANCIEN	\N	communauté d'agglomération Hénin-Carvin	de la communauté d'agglomération Hénin-Carvin	\N	\N	\N	\N	INTERCOM	19527W	\N	\N	de la	2017-09-26 16:46:14	2017-09-26 16:50:47
51405	2017-09-26 00:00:00	\N	2017-10-24 00:00:00	ANCIEN	\N	communauté d'agglomération Arlysère	de la communauté d'agglomération Arlysère	\N	\N	\N	\N	INTERCOM	19575F	\N	\N	de la	2017-09-26 16:47:58	2017-12-12 14:06:18
51410	2017-01-01 00:00:00	\N	2017-10-02 00:00:00	ANCIEN	\N	de Plaine Limagne	de la communauté de communes Plaine Limagne	\N	\N	\N	\N	INTERCOM	19387D	\N	\N	\N	2017-09-26 17:31:54	2018-01-24 11:12:39
51413	2008-03-23 00:00:00	\N	2014-04-01 00:00:00	ANCIEN	\N	communauté d'agglomération d'Angers Loire métropole	de la communauté d'agglomération d'Angers Loire métropole	\N	\N	\N	\N	INTERCOM	19545Y	\N	\N	de la	2017-09-26 17:39:49	2017-09-26 17:40:39
51414	2001-03-18 00:00:00	\N	2015-12-13 00:00:00	ANCIEN	\N	agglomération Orléans-Val de Loire	de l'agglomération Orléans-Val de Loire	\N	\N	\N	\N	INTERCOM	19421M	\N	\N	de l'	2017-09-26 17:41:05	2017-09-26 17:43:09
51415	2017-01-01 00:00:00	\N	2020-06-28 00:00:00	ANCIEN	\N	communauté d'agglomération du Cotentin	de la communauté d'agglomération du Cotentin	\N	\N	\N	\N	INTERCOM	19333N	\N	\N	de la	2017-09-26 17:46:17	2018-05-30 09:26:27
51418	2012-06-23 00:00:00	\N	2015-12-31 00:00:00	ANCIEN	\N	communauté urbaine de Cherbourg	de la communauté urbaine de Cherbourg	\N	\N	\N	\N	INTERCOM	19333N	\N	\N	de la	2017-09-26 17:53:15	2017-09-26 17:54:16
51420	2014-01-01 00:00:00	\N	2017-10-26 00:00:00	ANCIEN	\N	communauté de communes Val-de-Cher-Controis	de la communauté de communes Val-de-Cher-Controis	\N	\N	\N	\N	INTERCOM	19511N	\N	\N	de la	2017-09-26 18:03:20	2017-11-06 12:01:49
51421	2004-01-01 00:00:00	\N	2016-12-31 00:00:00	ANCIEN	\N	communauté de communes des Grands Lacs du Morvan	de la communauté de communes des Grands Lacs du Morvan	\N	\N	\N	\N	INTERCOM	19531S	\N	\N	de la	2017-09-26 18:11:28	2017-09-26 18:12:14
51422	2017-01-01 00:00:00	\N	2018-01-01 00:00:00	ANCIEN	\N	communauté de communes Morvan Sommets et Grands Lacs	de la communauté de communes Morvan Sommets et Grands Lacs	\N	\N	\N	\N	INTERCOM	19531S	\N	\N	de la	2017-09-26 18:11:31	2018-01-02 10:56:44
51423	1995-12-29 00:00:00	\N	2016-12-30 00:00:00	ANCIEN	\N	communauté de communes Loches Développement	de la communauté de communes Loches Développement	\N	\N	\N	\N	INTERCOM	19441R	\N	\N	de la	2017-09-26 18:19:55	2017-09-26 18:23:30
51452	2014-10-13 00:00:00	\N	\N	ANCIEN	Conseiller à l'Assemblée des Français de l'Etranger	Conseiller à l'Assemblée des Français de l'Etranger	Conseiller à l'Assemblée des Français de l'Etranger	\N	\N	2017	\N	DIVERS	19709B	\N	\N	\N	2017-09-29 10:52:29	2017-09-29 10:53:41
51491	2014-03-23 00:00:00	\N	2020-10-15 00:00:00	ANCIEN	\N	communauté d'agglomération Cannes Pays de Lérins	de la communauté d'agglomération Cannes Pays de Lérins	\N	\N	\N	\N	INTERCOM	19729F	\N	\N	de la	2017-10-02 10:36:52	2017-12-12 17:14:34
51492	2017-10-02 00:00:00	\N	\N	ACTIF	\N	communauté de communes du Sud Gironde	de la communauté de communes du Sud Gironde	\N	\N	\N	\N	INTERCOM	19723Y	\N	\N	de la 	2017-10-02 10:44:52	2017-10-02 10:45:32
51520	2017-10-25 00:00:00	\N	\N	ACTIF	\N	Agglomération du Puy-en-Velay	Agglomération du Puy-en-Velay	\N	\N	\N	\N	INTERCOM	19507S	\N	\N	de l'	2017-11-20 11:19:03	2017-11-20 11:19:29
51535	1973-01-01 00:00:00	\N	2014-04-01 00:00:00	ANCIEN	Président de la CC du Canton de Criquetot l'Esneval	Président de la Communauté de Communes du Canton de Criquetot l'Esneval	Président de la Communauté de Communes du Canton de Criquetot l'Esneval	\N	\N	\N	\N	AUTFONLOC	95062K	\N	\N	de	2017-12-05 10:26:51	2017-12-05 10:40:47
51536	1987-01-01 00:00:00	\N	2017-10-31 00:00:00	ANCIEN	Président du SIDESA	Président du Syndicat Interdépartemental De l'Eau Seine Aval (SIDESA)	Président du Syndicat Interdépartemental De l'Eau Seine Aval (SIDESA)	\N	\N	\N	\N	AUTFONLOC	95062K	\N	\N	du	2017-12-05 10:33:19	2017-12-05 10:39:37
51537	1973-01-01 00:00:00	\N	2017-10-31 00:00:00	ANCIEN	Président du SIAEPA	Président du Syndicat Intercommunal d'Alimentation en Eau Potable et Assainissement de Criquetot l'Esneval (SIAEPA)	Président du Syndicat Intercommunal d'Alimentation en Eau Potable et Assainissement de Criquetot l'Esneval (SIAEPA)	\N	\N	\N	\N	AUTFONLOC	95062K	\N	\N	du	2017-12-05 10:35:46	2017-12-05 10:39:08
51560	2017-01-01 00:00:00	\N	2020-06-28 00:00:00	ANCIEN	\N	communauté de communes Hautes Terres Communauté	communauté de communes Hautes Terres Communauté	\N	\N	\N	\N	INTERCOM	14327T	\N	\N	de la	2018-01-08 20:14:32	2018-01-08 20:19:40
51607	2008-03-16 00:00:00	\N	2018-07-12 00:00:00	ANCIEN	\N	Collines du Perche normand	Collines du Perche normand	\N	\N	\N	\N	INTERCOM	19762G	\N	\N	des	\N	\N
51654	2017-01-12 00:00:00	\N	\N	ACTIF	\N	Communauté de communes des Portes Euréliennes d'Île-de-France	Communauté de communes des Portes Euréliennes d'Île-de-France	\N	\N	\N	\N	INTERCOM	19794Q	\N	\N	de la	\N	\N
52289	2001-03-15 00:00:00	\N	2008-12-15 00:00:00	ANCIEN	\N	Communauté de communes Beaujolais Val de Saône	Communauté de communes Beaujolais Val de Saône	\N	\N	\N	\N	INTERCOM	20132W	\N	\N	de la	\N	\N
52290	2009-01-15 00:00:00	\N	2020-07-15 00:00:00	ANCIEN	\N	Communauté de communes Saône Beaujolais	Communauté de communes Saône Beaujolais	\N	\N	\N	\N	INTERCOM	20132W	\N	\N	de la	\N	\N
52359	2017-01-01 00:00:00	\N	\N	ACTIF	\N	Communauté de communes Coutances mer et bocage	Communauté de communes Coutances mer et bocage	\N	\N	\N	\N	INTERCOM	20180F	\N	\N	de la 	\N	\N
52360	2008-04-01 00:00:00	\N	2016-12-31 00:00:00	ANCIEN	\N	Communauté de communes de Saint-Malo-de-la-Lande	\N	\N	\N	\N	\N	INTERCOM	20180F	\N	\N	de la	\N	\N
53884	2023-11-07 00:00:00	\N	\N	ACTIF	\N	communauté urbaine du Grand Reims	\N	\N	\N	\N	\N	INTERCOM	21064G	\N	\N	de la	\N	\N
53625	1499-12-31 00:50:39	1500-01-01 00:00:00	2023-11-01 00:00:00	ANCIEN	\N	Communauté de communes Damvillers Spincourt	\N	\N	\N	\N	0	INTERCOM	21042A	\N	\N	de la	\N	\N
53509	1499-12-31 00:50:39	1500-01-01 00:00:00	1599-11-06 00:50:39	ANCIEN	\N	communauté d'agglomération Loire Forez 	communauté d'agglomération Loire Forez 	\N	\N	\N	0	INTERCOM	21070E	\N	\N	de la	\N	2023-09-26 16:04:02
53527	1499-12-31 00:50:39	1500-01-01 00:00:00	2023-11-01 00:00:00	ANCIEN	\N	Saint-Étienne Métropole	Saint-Étienne Métropole	\N	\N	\N	0	INTERCOM	21068L	\N	\N	de	\N	2023-09-26 16:12:44
53582	1499-12-31 00:50:39	1500-01-01 00:00:00	1515-10-27 00:50:39	ANCIEN	\N	communauté urbaine du Grand Reims	\N	\N	\N	\N	0	INTERCOM	21064G	\N	\N	de la	\N	2023-09-26 17:18:31
53591	1499-12-31 00:50:39	1500-01-01 00:00:00	1515-10-23 00:50:39	ANCIEN	\N	métropole européenne de Lille	métropole européenne de Lille	\N	\N	\N	0	INTERCOM	18207D	\N	\N	de la	\N	2023-09-26 17:42:19
53600	1499-12-23 00:50:39	\N	\N	ACTIF	Syndicat mixte d'électricité de Martinique	Délégué au sein du syndicat mixte d'électricité de Martinique	Délégué au sein du syndicat mixte d'électricité de Martinique	\N	\N	\N	\N	DIVERS	21096Q	\N	\N	\N	\N	\N
53623	1499-12-31 00:50:39	1499-12-31 00:50:39	1515-10-27 00:50:39	ANCIEN	\N	communauté d'agglomération Porte de l'Isère	communauté d'agglomération Porte de l'Isère	\N	\N	\N	\N	INTERCOM	21080G	\N	\N	de la	\N	2023-09-27 11:25:49
53655	1499-12-31 00:50:39	1500-01-01 00:00:00	2024-03-04 00:00:00	ANCIEN	\N	eurométrole de Metz	eurométrole de Metz	\N	\N	\N	0	INTERCOM	21081H	\N	\N	de l'	\N	2023-09-27 15:43:51
53629	1499-12-31 00:50:39	1500-01-01 00:00:00	1599-12-31 00:50:39	ANCIEN	\N	Communauté de communes Damvillers Spincourt	\N	\N	\N	\N	0	INTERCOM	21042A	\N	\N	de la	\N	\N
52365	2001-06-01 00:00:00	\N	2004-12-01 00:00:00	ANCIEN	Président de l'association des maires du Loiret	Président de l'association des maires du Loiret	Président de l'association des maires du Loiret	\N	\N	\N	\N	DIVERS	11103C	\N	\N	\N	\N	\N
52434	2014-05-15 00:00:00	\N	2021-09-26 00:00:00	ANCIEN	Membre du Conseil consulaire	Membre du Conseil consulaire	Membre du Conseil consulaire	\N	\N	\N	\N	DIVERS	20264J	\N	\N	\N	\N	\N
52435	2014-06-15 00:00:00	\N	2021-10-01 00:00:00	ANCIEN	Membre de l'Assemblée des Français de l'étranger	Membre de l'Assemblée des Français de l'étranger	Membre de l'Assemblée des Français de l'étranger	\N	\N	\N	\N	DIVERS	20264J	\N	\N	\N	\N	\N
52266	2008-05-15 00:00:00	\N	2014-04-15 00:00:00	ANCIEN	Vice-Président du Parc Naturel Régional de Chartreuse	Vice-Président du Parc Naturel Régional de Chartreuse	Vice-Président du Parc Naturel Régional de Chartreuse	\N	\N	\N	\N	DIVERS	20058E	\N	\N	\N	\N	\N
52456	1994-09-15 00:00:00	\N	1997-09-15 00:00:00	ANCIEN	Membre du Conseil économique et social	Membre du Conseil économique et social	Membre du Conseil économique et social	\N	\N	\N	\N	DIVERS	08061X	\N	\N	\N	\N	\N
52330	2001-03-15 00:00:00	\N	2020-11-15 00:00:00	ANCIEN	\N	Communauté de Communes de l'agglomération Migennoise	\N	\N	\N	\N	\N	INTERCOM	20174H	\N	\N	de la	\N	\N
52332	2020-06-15 00:00:00	\N	\N	ACTIF	\N	Métropole d'Aix-Marseille-Provence	\N	\N	\N	\N	\N	INTERCOM	17737W	\N	\N	de la	\N	\N
52333	2016-01-01 00:00:00	\N	\N	ACTIF	\N	Métropole d'Aix-Marseille-Provence	\N	\N	\N	\N	\N	INTERCOM	14055N	\N	\N	de la	\N	\N
52334	2015-01-01 00:00:00	\N	\N	ACTIF	\N	Bordeaux Métropole	\N	\N	\N	\N	\N	INTERCOM	19721W	\N	\N	de	\N	\N
52335	2015-01-01 00:00:00	\N	\N	ACTIF	\N	Bordeaux Métropole	\N	\N	\N	\N	\N	INTERCOM	19719D	\N	\N	de	\N	\N
52336	2016-01-01 00:00:00	\N	\N	ACTIF	\N	Grenoble-Alpes Métropole	\N	\N	\N	\N	\N	INTERCOM	11043H	\N	\N	de	\N	\N
52337	2016-01-01 00:00:00	\N	\N	ACTIF	\N	Métropole européenne de Lille	\N	\N	\N	\N	\N	INTERCOM	11040E	\N	\N	de la	\N	\N
52338	2014-04-07 00:00:00	\N	\N	ACTIF	\N	Métropole européenne de Lille	\N	\N	\N	\N	\N	INTERCOM	04008A	\N	\N	de la	\N	\N
52339	\N	\N	\N	ACTIF	\N	Métropole européenne de Lille	\N	\N	2016	\N	\N	INTERCOM	19581D	\N	\N	de la	\N	\N
52340	2016-01-01 00:00:00	\N	2021-02-01 00:00:00	ANCIEN	\N	Montpellier Méditerranée Métropole	\N	\N	\N	\N	\N	INTERCOM	14211G	\N	\N	de	\N	\N
52341	2016-07-01 00:00:00	\N	2021-07-19 00:00:00	ANCIEN	\N	Métropole du Grand Nancy	\N	\N	\N	\N	\N	INTERCOM	11048N	\N	\N	de la	\N	\N
53406	1499-12-31 00:50:39	1500-01-01 00:00:00	\N	ACTIF	\N	Établissement public territorial Plaine Commune	\N	\N	\N	\N	0	INTERCOM	21077M	\N	\N	de l'	\N	2023-09-26 12:10:30
53410	1499-12-31 00:50:39	1500-01-01 00:00:00	\N	ACTIF	\N	métropole du Grand Paris	métropole du Grand Paris	\N	\N	\N	0	INTERCOM	21090J	\N	\N	de la	\N	2023-09-26 12:12:07
53505	1499-12-31 00:50:39	1500-01-01 00:00:00	2023-12-01 00:00:00	ANCIEN	\N	communauté d'agglomération Plaine Vallée	communauté d'agglomération Plaine Vallée	\N	\N	\N	0	INTERCOM	21086N	\N	\N	de la	\N	2023-09-26 16:01:37
53555	1499-12-31 00:50:39	1499-12-31 00:50:39	2023-11-01 00:00:00	ANCIEN	\N	Tours Métropole Val de Loire	Tours Métropole Val de Loire	\N	\N	\N	0	INTERCOM	21055F	\N	\N	de	\N	2023-09-26 16:31:08
53556	1499-12-31 00:50:39	1499-12-31 00:50:39	1599-12-31 00:50:39	ANCIEN	\N	communauté d'agglomération Tour(s) Plus	communauté d'agglomération Tour(s) Plus	\N	\N	\N	0	INTERCOM	21055F	\N	\N	de la	\N	2023-09-26 16:31:08
53557	1499-12-31 00:50:39	1499-12-31 00:50:39	1599-12-31 00:50:39	ANCIEN	\N	communauté d'agglomération Tour(s) Plus	communauté d'agglomération Tour(s) Plus	\N	\N	\N	0	INTERCOM	21055F	\N	\N	de la	\N	2023-09-26 16:31:08
53866	1499-12-31 00:50:39	\N	1599-11-06 00:50:39	ANCIEN	\N	communauté intercommunale Réunion Est	communauté intercommunale Réunion Est	\N	\N	\N	\N	INTERCOM	21033Y	\N	\N	de la	\N	\N
52350	\N	\N	\N	ACTIF	\N	Vice-président de commission à la métropole Aix-Marseille-Provence	Vice-président de commission à la métropole Aix-Marseille-Provence	\N	2020	\N	\N	AUTFONLOC	20108W	\N	\N	\N	\N	\N
52351	\N	\N	\N	ANCIEN	\N	Président de l'association des maires du Haut-Rhin	Président de l'association des maires du Haut-Rhin	\N	2018	2021	\N	AUTFONLOC	20126Y	\N	\N	\N	\N	\N
52352	\N	\N	\N	ACTIF	\N	Membre du conseil d'administration de l'association nationale des élus de la vigne et du vin	Membre du conseil d'administration de l'association nationale des élus de la vigne et du vin	\N	2020	\N	\N	DIVERS	20126Y	\N	\N	\N	\N	\N
52411	\N	\N	\N	ACTIF	\N	Membre du comité du Syndicat d'Électricité et de Gaz du Rhin (SEGR)	Membre du comité du Syndicat d'Électricité et de Gaz du Rhin (SEGR)	\N	2021	\N	\N	DIVERS	20126Y	\N	\N	\N	\N	\N
52432	2011-01-01 00:00:00	\N	2021-10-01 00:00:00	ANCIEN	Membre du Conseil économique, social et environnemental	Membre du Conseil économique, social et environnemental	Membre du Conseil économique, social et environnemental	\N	\N	\N	\N	DIVERS	11085T	\N	\N	\N	\N	\N
52402	2014-03-15 00:00:00	\N	2021-07-14 00:00:00	ANCIEN	\N	Communauté de communes Sarrebourg Moselle Sud	Communauté de communes Sarrebourg Moselle Sud	\N	\N	\N	\N	INTERCOM	19954N	\N	\N	de la 	\N	\N
52433	2007-11-01 00:00:00	\N	2008-11-01 00:00:00	ANCIEN	\N	Membre du Conseil économique, social et environnemental régional	Membre du Conseil économique, social et environnemental régional	\N	\N	\N	\N	DIVERS	19719D	\N	\N	\N	\N	\N
53445	1499-12-31 00:50:39	1500-01-01 00:00:00	\N	ACTIF	\N	métropole du Grand Paris	métropole du Grand Paris	\N	\N	\N	0	INTERCOM	21072G	\N	\N	de la	\N	2023-09-26 15:26:18
53650	1499-12-31 00:50:39	1499-12-31 00:50:39	\N	ACTIF	\N	communauté de communes de Petite-Terre	communauté de communes de Petite-Terre	\N	\N	\N	0	INTERCOM	19331L	\N	\N	de la	\N	2023-09-27 11:56:56
53376	1499-12-31 00:50:39	1500-01-01 00:00:00	1515-10-23 00:50:39	ANCIEN	\N	Communauté d'agglomération Roissy Pays de France	\N	\N	\N	\N	0	INTERCOM	21084L	\N	\N	de la	\N	\N
53377	1499-12-31 00:50:39	1500-01-01 00:00:00	1599-12-31 00:50:39	ANCIEN	\N	parking d'intérêt régional (PIR)	\N	\N	\N	\N	0	INTERCOM	21084L	\N	\N	du	\N	\N
53878	1499-12-23 00:50:39	\N	1504-12-22 00:50:39	ANCIEN	\N	communauté de communes de Tallard-Barcillonnette 	communauté de communes de Tallard-Barcillonnette 	\N	\N	\N	\N	INTERCOM	14189C	\N	\N	de la 	\N	\N
53879	2023-11-02 00:00:00	\N	\N	ACTIF	\N	Communauté d'agglomération Roissy Pays de France	\N	\N	\N	\N	\N	INTERCOM	21084L	\N	\N	de la	\N	\N
53912	2023-11-28 00:00:00	\N	\N	ACTIF	\N	communauté de communes Causses et Vallée de la Dordogne	communauté de communes Causses et Vallée de la Dordogne	\N	\N	\N	\N	INTERCOM	21041Y	\N	\N	de la	\N	\N
53916	2023-11-06 00:00:00	\N	2023-11-27 00:00:00	ANCIEN	Président de l'association des maires	Président de l'association des maires	Président de l'association des maires	\N	\N	\N	\N	DIVERS	21033Y	\N	\N	\N	\N	\N
53815	1499-12-31 00:50:39	1500-01-01 00:00:00	1599-12-31 00:50:39	ANCIEN	\N	centre de gestion de la fonction publique territoriale du Jura 	centre de gestion de la fonction publique territoriale du Jura 	\N	\N	\N	0	INTERCOM	21047F	\N	\N	du	\N	2023-10-02 10:57:54
53816	1499-12-31 00:50:39	1500-01-01 00:00:00	1599-12-31 00:50:39	ANCIEN	\N	centre d'incendie et de secours du Jura 	centre d'incendie et de secours du Jura 	\N	\N	\N	0	INTERCOM	21047F	\N	\N	du	\N	2023-10-02 10:57:54
53817	1499-12-31 00:50:39	1500-01-01 00:00:00	1599-12-31 00:50:39	ANCIEN	\N	SCIC HLM La Maison Pour Tous	SCIC HLM La Maison Pour Tous	\N	\N	\N	0	INTERCOM	21047F	\N	\N	de la	\N	2023-10-02 10:57:54
53378	1499-12-31 00:50:39	1500-01-01 00:00:00	1599-12-31 00:50:39	ANCIEN	\N	Syndicat Fosses Marly (SIFOMA)	\N	\N	\N	\N	0	INTERCOM	21084L	\N	\N	du	\N	\N
52224	2001-03-15 00:00:00	2020-07-15 00:00:00	2020-09-15 00:00:00	ANCIEN	\N	Inter Caux Vexin	\N	\N	\N	\N	\N	INTERCOM	20144B	\N	\N	d'	\N	\N
52227	2014-06-15 00:00:00	\N	2020-09-15 00:00:00	ANCIEN	\N	Président du Syndicat départemental énergie	Président du Syndicat départemental énergie	\N	\N	\N	\N	DIVERS	20144B	\N	\N	\N	\N	\N
52228	2001-06-15 00:00:00	\N	2014-06-15 00:00:00	ANCIEN	\N	Président du Syndicat d'électricité de la région de Buchy	Président du Syndicat d'électricité de la région de Buchy	\N	\N	\N	\N	DIVERS	20144B	\N	\N	\N	\N	\N
52229	1995-06-15 00:00:00	\N	2018-01-15 00:00:00	ANCIEN	\N	Communauté de communes du Moulin d'Écalles	\N	\N	\N	\N	\N	INTERCOM	20144B	\N	\N	\N	\N	\N
52230	2001-06-15 00:00:00	\N	2020-09-15 00:00:00	ANCIEN	\N	Président du Syndicat Intercommunal à Vocation Scolaire (SIVOS) collège Francis Yard	Président du Syndicat Intercommunal à Vocation Scolaire (SIVOS) collège Francis Yard	\N	\N	\N	\N	DIVERS	20144B	\N	\N	\N	\N	\N
52231	2014-06-15 00:00:00	\N	2020-06-15 00:00:00	ANCIEN	\N	Vice-Président du Syndicat d'eau de Sigy en Bray	Vice-Président du Syndicat d'eau de Sigy en Bray	\N	\N	\N	\N	DIVERS	20144B	\N	\N	\N	\N	\N
52260	2014-03-15 00:00:00	2020-03-15 00:00:00	2020-10-15 00:00:00	ANCIEN	\N	Communauté de Communes Coeur de Chartreuse	Communauté de Communes Coeur de Chartreuse	\N	\N	\N	\N	INTERCOM	20058E	\N	\N	de la	\N	\N
53520	1499-12-23 00:50:39	1500-01-01 00:00:00	1599-12-31 00:50:39	ANCIEN	\N	communauté d'agglomération de la Région de Saint-Nazaire	communauté d'agglomération de la Région de Saint-Nazaire	\N	\N	\N	0	INTERCOM	21066J	\N	\N	de la	\N	2023-09-26 16:11:40
52301	2020-11-01 00:00:00	\N	\N	ACTIF	\N	Président de l'association des communes forestières de la Haute-Savoie	Président de l'association des communes forestières de la Haute-Savoie	\N	\N	\N	\N	AUTFONLOC	14179A	\N	\N	\N	\N	\N
52302	\N	\N	\N	ANCIEN	\N	communauté de communes de la Porte des Vosges Méridionales 	communauté de communes de la Porte des Vosges Méridionales 	\N	2017	2020	\N	INTERCOM	20048C	\N	\N	de la	\N	\N
52321	2008-04-15 00:00:00	\N	2020-10-15 00:00:00	ANCIEN	\N	Communauté de communes du Clermontais	Communauté de communes du Clermontais	\N	\N	\N	\N	INTERCOM	20116W	\N	\N	de la	\N	\N
52322	\N	\N	\N	ANCIEN	\N	Président fondateur de l'association des maires ruraux de l'Hérault	Président fondateur de l'association des maires ruraux de l'Hérault	\N	1995	2012	\N	DIVERS	20116W	\N	\N	\N	\N	\N
52324	2015-01-01 00:00:00	\N	2020-01-01 00:00:00	ANCIEN	\N	Président du centre de formation des maires et élus locaux de l'Hérault 	Président du centre de formation des maires et élus locaux de l'Hérault 	\N	\N	\N	\N	DIVERS	20116W	\N	\N	\N	\N	\N
52325	2016-01-01 00:00:00	\N	2020-01-01 00:00:00	ANCIEN	\N	Délégué régional du centre national de la fonction publique territoriale Languedoc Roussillon	Délégué régional du centre national de la fonction publique territoriale Languedoc Roussillon	\N	\N	\N	\N	DIVERS	20116W	\N	\N	\N	\N	\N
52326	2014-01-01 00:00:00	\N	2020-01-01 00:00:00	ANCIEN	\N	Rapporteur général de la commission départementale de coopération intercommunale de l'Hérault	Rapporteur général de la commission départementale de coopération intercommunale de l'Hérault	\N	\N	\N	\N	DIVERS	20116W	\N	\N	\N	\N	\N
52327	2019-01-01 00:00:00	\N	2020-01-01 00:00:00	ANCIEN	\N	Présidente du conseil d'administration de l'agence territoriale de l'environnement de Saint-Barthélemy	Présidente du conseil d'administration de l'agence territoriale de l'environnement de Saint-Barthélemy	\N	\N	\N	\N	DIVERS	20034V	\N	\N	\N	\N	\N
52371	2020-06-02 00:00:00	\N	2021-06-01 00:00:00	ANCIEN	Président de l'association des maires de l'Allier	Président de l'association des maires de l'Allier	Président de l'association des maires de l'Allier	\N	\N	\N	\N	DIVERS	20020P	\N	\N	\N	\N	\N
52450	2022-01-01 00:00:00	\N	\N	ACTIF	Président de l'ANEFE	Président de l'association nationale des établissements français de l'étranger (ANEFE)	Président de l'association nationale des établissements français de l'étranger (ANEFE)	\N	\N	\N	\N	DIVERS	14255U	\N	\N	\N	\N	\N
53153	2022-11-01 00:00:00	\N	\N	ACTIF	Association des Maires Ruraux de la Haute-Savoie	Association des Maires Ruraux de la Haute-Savoie	Secrétaire de l'Association des Maires Ruraux de la Haute-Savoie	\N	\N	\N	\N	DIVERS	19768N	\N	\N	\N	\N	\N
53416	1500-01-01 00:00:00	1500-01-01 00:00:00	\N	ACTIF	\N	communauté d'agglomération Sarreguemines Confluences	communauté d'agglomération Sarreguemines Confluences	\N	\N	\N	0	INTERCOM	21082J	\N	\N	de la	\N	\N
53573	1499-12-31 00:50:39	1499-12-31 00:50:39	2023-11-02 00:00:00	ANCIEN	\N	communauté d'agglomération de Chaumont	communauté d'agglomération de Chaumont	\N	\N	\N	0	INTERCOM	21039F	\N	\N	de la	\N	2023-09-26 16:44:49
53708	1499-12-31 00:50:39	1500-01-01 00:00:00	\N	ACTIF	\N	Grand Paris Sud Est Avenir	Grand Paris Sud Est Avenir	\N	\N	\N	0	INTERCOM	21073H	\N	\N	de	\N	2023-09-28 16:52:20
52278	2020-03-15 00:00:00	\N	2021-01-04 00:00:00	ANCIEN	\N	Communauté de communes du canton d'Erstein	Communauté de communes du canton d'Erstein	\N	\N	\N	\N	INTERCOM	20096L	\N	\N	de la	\N	\N
52280	2020-07-15 00:00:00	\N	2020-10-26 00:00:00	ANCIEN	\N	Communauté de communes du Vexin Normand	Communauté de communes du Vexin Normand	\N	\N	\N	\N	INTERCOM	20118Y	\N	\N	de la 	\N	\N
52282	2008-04-15 00:00:00	\N	2020-10-26 00:00:00	ANCIEN	\N	Communauté de communes du Bassin de Marennes	Communauté de communes du Bassin de Marennes	\N	\N	\N	\N	INTERCOM	20064C	\N	\N	de la	\N	\N
52312	\N	\N	\N	ANCIEN	\N	Présidente du Service départementale d'incendie et de secours du Cher	Présidente du Service départementale d'incendie et de secours du Cher	\N	2015	2016	\N	DIVERS	19798U	\N	\N	\N	\N	\N
52316	2014-01-01 00:00:00	\N	2020-01-01 00:00:00	ANCIEN	Vice-président de l'association des maires de France	Vice-président de l'association des maires de France	Vice-président de l'association des maires de France	\N	\N	\N	\N	DIVERS	20116W	\N	\N	\N	\N	\N
52317	2012-01-01 00:00:00	\N	2020-01-01 00:00:00	ANCIEN	Président de l'association des maires de l'Hérault	Président de l'association des maires de l'Hérault	Président de l'association des maires de l'Hérault	\N	\N	\N	\N	DIVERS	20116W	\N	\N	\N	\N	\N
52318	2008-01-01 00:00:00	\N	2020-01-01 00:00:00	ANCIEN	Membre du comité des finances locales	Membre du comité des finances locales	Membre du comité des finances locales	\N	\N	\N	\N	DIVERS	20116W	\N	\N	\N	\N	\N
52319	2008-01-01 00:00:00	\N	2020-01-01 00:00:00	ANCIEN	Membre du conseil national d'évaluation des normes	Membre du conseil national d'évaluation des normes	Membre du conseil national d'évaluation des normes	\N	\N	\N	\N	DIVERS	20116W	\N	\N	\N	\N	\N
52369	2021-05-25 00:00:00	\N	\N	ACTIF	Auditrice « politique de défense » 72e session de l'IHEDN	Auditrice « politique de défense » 72e session de l'IHEDN	Auditrice « politique de défense » 72e session de l'IHEDN	\N	\N	\N	\N	DIVERS	19701S	\N	\N	\N	\N	\N
52370	2021-05-25 00:00:00	\N	\N	ACTIF	Colonel (RC)	Nouveau	Colonel (RC)	\N	\N	\N	\N	DIVERS	19701S	\N	\N	Colonel (RC)	\N	\N
52378	2021-06-21 00:00:00	\N	\N	ACTIF	\N	Présidente de l'Assemblée parlementaire de l'OTAN	Présidente de l'Assemblée parlementaire de l'OTAN	\N	\N	\N	\N	DIVERS	04035D	\N	\N	\N	\N	\N
52440	2016-12-15 00:00:00	\N	2020-03-15 00:00:00	ANCIEN	\N	établissement public territorial Paris Terres d'Envol	établissement public territorial Paris Terres d'Envol	\N	\N	\N	\N	INTERCOM	20252E	\N	\N	de l'	\N	\N
52441	2014-03-15 00:00:00	\N	\N	ACTIF	\N	syndicat d'équipement et d'aménagement des pays de France et de l'Aulnoye	syndicat d'équipement et d'aménagement des pays de France et de l'Aulnoye	\N	\N	\N	\N	INTERCOM	20252E	\N	\N	du	\N	\N
53374	1499-12-31 00:50:39	1500-01-01 00:00:00	\N	ACTIF	\N	communauté d'agglomération de la Porte du Hainaut	communauté d'agglomération de la Porte du Hainaut	\N	\N	\N	0	INTERCOM	21085M	\N	\N	de la	\N	2023-09-26 10:36:09
53403	1499-12-23 00:50:39	1500-01-01 00:00:00	\N	ACTIF	\N	Clermont Auvergne métropole	\N	\N	\N	\N	0	INTERCOM	21045D	\N	\N	de	\N	2023-09-26 12:03:52
53755	1499-12-31 00:50:39	1500-01-01 00:00:00	1599-11-06 00:50:39	ANCIEN	\N	communauté d'agglomération du Pays Nord Martinique	\N	\N	\N	\N	0	INTERCOM	21096Q	\N	\N	de la	\N	\N
53587	1600-01-09 00:50:39	1499-12-31 00:50:39	1699-11-06 00:50:39	ANCIEN	\N	communauté de communes des Lisières de l'Oise	\N	\N	\N	\N	0	INTERCOM	21061D	\N	\N	de la	\N	2023-09-26 17:34:23
53588	1499-12-31 00:50:39	1499-12-31 00:50:39	1599-12-31 00:50:39	ANCIEN	\N	communauté de communes des Lisières de l'Oise	\N	\N	\N	\N	0	INTERCOM	21061D	\N	\N	de la	\N	2023-09-26 17:34:23
53756	1499-12-31 00:50:39	1500-01-01 00:00:00	1599-12-31 00:50:39	ANCIEN	\N	Conseil général de la Martinique	\N	\N	\N	\N	0	INTERCOM	21096Q	\N	\N	du	\N	\N
53638	1499-12-31 00:50:39	1499-12-31 00:50:39	2023-11-01 00:00:00	ANCIEN	\N	communauté de communes des Terres du Val de Loire	communauté de communes des Terres du Val de Loire	\N	\N	\N	\N	INTERCOM	21058J	\N	\N	de la	\N	2023-09-27 11:38:57
53645	1499-12-31 00:50:39	1500-01-01 00:00:00	\N	ACTIF	\N	communauté de communes du Confluent et des coteaux de Prayssas	communauté de communes du Confluent et des coteaux de Prayssas	\N	\N	\N	0	INTERCOM	21040X	\N	\N	de la	\N	2023-09-27 11:45:48
53894	2023-11-06 00:00:00	\N	\N	ACTIF	\N	communauté de communes des Lisières de l'Oise	\N	\N	\N	\N	\N	INTERCOM	21061D	\N	\N	de la	\N	\N
53669	1499-12-31 00:50:39	1500-01-01 00:00:00	1599-11-06 00:50:39	ANCIEN	\N	communauté de communes Causses et Vallée de la Dordogne	communauté de communes Causses et Vallée de la Dordogne	\N	\N	\N	0	INTERCOM	21041Y	\N	\N	de la	\N	2023-09-27 16:48:17
53701	2023-01-01 00:00:00	\N	\N	ACTIF	Membre du Conseil consulaire	\N	Membre du Conseil consulaire	\N	\N	\N	\N	DIVERS	21037D	\N	\N	\N	\N	\N
53702	1499-12-23 00:50:39	\N	1599-01-09 00:50:39	ANCIEN	Membre de l'Assemblée des Français de l'étranger	Membre de l'Assemblée des Français de l'étranger	Membre de l'Assemblée des Français de l'étranger	\N	\N	\N	\N	DIVERS	21037D	\N	\N	\N	\N	\N
53733	1499-12-31 00:50:39	1500-01-01 00:00:00	1599-12-31 00:50:39	ANCIEN	\N	Golfe du Morbihan - Vannes Agglomération	Golfe du Morbihan - Vannes Agglomération	\N	\N	\N	0	INTERCOM	21050A	\N	\N	de	\N	2023-09-28 17:12:01
53435	1499-12-31 00:50:39	1500-01-01 00:00:00	\N	ACTIF	\N	établissement public territorial Boucle Nord de Seine 	\N	\N	\N	\N	0	INTERCOM	21071F	\N	\N	de l'	\N	\N
53757	1499-12-31 00:50:39	1500-01-01 00:00:00	1599-12-31 00:50:39	ANCIEN	\N	Syndicat mixte d'électricité de la Martinique	\N	\N	\N	\N	0	INTERCOM	21096Q	\N	\N	du	\N	\N
53897	2023-11-06 00:00:00	\N	\N	ACTIF	\N	communauté d'agglomération Melun Val de Seine 	\N	\N	\N	\N	\N	INTERCOM	21076L	\N	\N	de la	\N	\N
53774	1499-12-31 00:50:39	1500-01-01 00:00:00	\N	ACTIF	\N	communauté d'agglomération de Lens-Liévin	\N	\N	\N	\N	0	INTERCOM	21067K	\N	\N	de la	\N	2023-10-02 00:22:26
52294	2020-03-15 00:00:00	\N	2020-10-15 00:00:00	ANCIEN	\N	Président du Pôle d'Equilibre Territorial et Rural de l'Ariège	Président du Pôle d'Equilibre Territorial et Rural de l'Ariège	\N	\N	\N	\N	DIVERS	20018V	\N	\N	\N	\N	\N
52295	2014-10-23 00:00:00	\N	2020-10-15 00:00:00	ANCIEN	\N	Président du Centre de Gestion de la Fonction Publique Territoriale de l'Allier	Président du Centre de Gestion de la Fonction Publique Territoriale de l'Allier	\N	\N	\N	\N	DIVERS	20020P	\N	\N	\N	\N	\N
52344	2015-12-14 00:00:00	\N	2020-03-31 00:00:00	ANCIEN	\N	Métropole du Grand Paris	\N	\N	\N	\N	\N	INTERCOM	19643A	\N	\N	de la	\N	\N
52345	2016-01-01 00:00:00	\N	\N	ACTIF	\N	Métropole du Grand Paris	\N	\N	\N	\N	\N	INTERCOM	04042C	\N	\N	de la	\N	\N
52346	2016-01-01 00:00:00	\N	\N	ACTIF	\N	Métropole du Grand Paris	\N	\N	\N	\N	\N	INTERCOM	04086Q	\N	\N	de la	\N	\N
52347	2016-01-01 00:00:00	\N	\N	ACTIF	\N	Métropole du Grand Paris	\N	\N	\N	\N	\N	INTERCOM	19711U	\N	\N	de la	\N	\N
52348	2016-01-01 00:00:00	\N	2020-06-15 00:00:00	ANCIEN	\N	Métropole du Grand Paris	Métropole du Grand Paris	\N	\N	\N	\N	INTERCOM	11085T	\N	\N	de la	\N	\N
52349	2016-01-01 00:00:00	\N	\N	ACTIF	\N	Métropole du Grand Paris	\N	\N	\N	\N	\N	INTERCOM	17637T	\N	\N	de la	\N	\N
52444	2008-03-15 00:00:00	\N	2014-03-15 00:00:00	ANCIEN	\N	communauté d'agglomération de l'Artois	communauté d'agglomération de l'Artois	\N	\N	\N	\N	INTERCOM	20286Q	\N	\N	de la 	\N	\N
52445	2020-03-15 00:00:00	\N	2021-12-31 00:00:00	ANCIEN	\N	communauté d'agglomération Béthune Bruay Artois Lys Romane	communauté d'agglomération Béthune Bruay Artois Lys Romane	\N	\N	\N	\N	INTERCOM	20286Q	\N	\N	de la	\N	\N
53501	1499-12-31 00:50:39	1500-01-01 00:00:00	1599-12-31 00:50:39	ANCIEN	\N	syndicat mixte du Pays Loire Nature	syndicat mixte du Pays Loire Nature	\N	\N	\N	0	INTERCOM	21056G	\N	\N	du	\N	2023-09-26 15:57:00
53155	2021-01-11 00:00:00	\N	\N	ACTIF	\N	Président du conseil chargé du suivi de la recherche d'alternatives aux néonicotinoïdes	Président du conseil chargé du suivi de la recherche d'alternatives aux néonicotinoïdes	\N	\N	\N	\N	DIVERS	19441R	\N	\N	\N	\N	\N
53424	1499-12-31 00:50:39	1500-01-01 00:00:00	\N	ACTIF	\N	communauté d'agglomération du Grand Cahors	\N	\N	\N	\N	0	INTERCOM	21031W	\N	\N	de la	\N	2023-09-26 12:35:03
53428	1499-12-31 00:50:39	1500-01-01 00:00:00	\N	ACTIF	\N	Communauté urbaine du Grand Reims	\N	\N	\N	\N	0	INTERCOM	21065H	\N	\N	de la	\N	2023-09-26 12:35:51
53449	1499-12-31 00:50:39	1500-01-01 00:00:00	1599-11-06 00:50:39	ANCIEN	\N	communauté d'agglomération Golfe du Morbihan-Vannes Agglomération	\N	\N	\N	\N	0	INTERCOM	21051B	\N	\N	de la	\N	2023-09-26 15:30:53
53465	2020-01-01 00:00:00	\N	\N	ACTIF	\N	métropole du Grand Paris	métropole du Grand Paris	\N	\N	\N	\N	INTERCOM	21091K	\N	\N	de la	\N	\N
53502	1499-12-31 00:50:39	\N	\N	ACTIF	Vice-président du centre de gestion d'Indre-et-Loire	Vice-président du centre de gestion de la fonction publique territoriale d'Indre-et-Loire	Vice-président du centre de gestion de la fonction publique territoriale d'Indre-et-Loire	\N	\N	\N	\N	DIVERS	21056G	\N	\N	\N	\N	\N
53545	1499-12-31 00:50:39	1500-01-01 00:00:00	\N	ACTIF	\N	Autour de Chenonceaux - communauté de communes Bléré-Val-de-Cher	Autour de Chenonceaux - communauté de communes Bléré-Val-de-Cher	\N	\N	\N	0	INTERCOM	21054E	\N	\N	d'	\N	2023-09-26 16:27:45
53546	1499-12-31 00:50:39	1500-01-01 00:00:00	1599-12-31 00:50:39	ANCIEN	\N	Autour de Chenonceaux - communauté de communes Bléré-Val-de-Cher	Autour de Chenonceaux - communauté de communes Bléré-Val-de-Cher	\N	\N	\N	0	INTERCOM	21054E	\N	\N	d'	\N	2023-09-26 16:27:45
53821	1499-12-31 00:50:39	1500-01-01 00:00:00	1599-12-31 00:50:39	ANCIEN	\N	communauté de communes du Perche et Haut Vendômois	communauté de communes du Perche et Haut Vendômois	\N	\N	\N	0	INTERCOM	21053D	\N	\N	de la 	\N	2023-10-02 10:59:01
53838	1499-12-31 00:50:39	1500-01-01 00:00:00	2023-11-01 00:00:00	ANCIEN	\N	communauté de communes du Pays de Mormal	\N	\N	1500	\N	0	INTERCOM	21083K	\N	\N	de la	\N	2023-10-02 16:50:01
53839	1499-12-31 00:50:39	1500-01-01 00:00:00	1599-12-31 00:50:39	ANCIEN	\N	syndicat mixte du parc naturel régional de l'Avesnois	\N	\N	1500	1600	0	INTERCOM	21083K	\N	\N	du	\N	2023-10-02 16:50:01
53840	1499-12-31 00:50:39	1500-01-01 00:00:00	1599-12-31 00:50:39	ANCIEN	\N	syndicat d'électricité de l'arrondissement d'Avesnes (SEAA)	\N	\N	\N	\N	0	INTERCOM	21083K	\N	\N	du	\N	2023-10-02 16:50:01
52243	2017-09-15 00:00:00	\N	2021-07-28 00:00:00	ANCIEN	\N	Mulhouse Alsace Agglomération (M2A)	Mulhouse Alsace Agglomération (M2A)	\N	\N	\N	\N	INTERCOM	20128B	\N	\N	de	\N	\N
52247	2003-03-15 00:00:00	\N	2020-10-15 00:00:00	ANCIEN	\N	Colmar Agglomération	Colmar Agglomération	\N	\N	\N	\N	INTERCOM	20126Y	\N	\N	de	\N	\N
52248	2020-10-15 00:00:00	\N	\N	ANCIEN	\N	Vice-Président du Syndicat d'Électricité et du Gaz du Rhin (SEGR)	Vice-Président du Syndicat d'Électricité et du Gaz du Rhin (SEGR)	\N	\N	2021	\N	DIVERS	20126Y	\N	\N	\N	\N	\N
52249	2020-10-15 00:00:00	\N	\N	ANCIEN	\N	Vice-Président du Syndicat Intercommunal de Traitement des Déchets de Colmar et Environs (SIDTCE) 	Vice-Président du Syndicat Intercommunal de Traitement des Déchets de Colmar et Environs (SIDTCE) 	\N	\N	2021	\N	DIVERS	20126Y	\N	\N	\N	\N	\N
52254	2017-03-15 00:00:00	\N	\N	ACTIF	\N	Administrateur au Conseil d'Administration de la Banque de Wallis et Futuna	Administrateur au Conseil d'Administration de la Banque de Wallis et Futuna	\N	\N	\N	\N	DIVERS	20016T	\N	\N	\N	\N	\N
52256	2014-04-15 00:00:00	\N	2020-10-26 00:00:00	ANCIEN	\N	Communauté de communes des Bastides Dordogne-Périgord	Communauté de communes des Bastides Dordogne-Périgord	\N	\N	\N	\N	INTERCOM	20028X	\N	\N	de la	\N	\N
52258	2020-10-15 00:00:00	\N	2020-10-26 00:00:00	ANCIEN	\N	Président du Conseil d'administration du Syndicat Départemental d'Incendie et de Secours 	Président du Conseil d'administration du Syndicat Départemental d'Incendie et de Secours	\N	\N	\N	\N	DIVERS	20028X	\N	\N	\N	\N	\N
52268	2008-04-15 00:00:00	\N	2014-07-15 00:00:00	ANCIEN	Membre du Syndicat mixte de l'Avant Pays Savoyard	Membre du Syndicat mixte de l'Avant Pays Savoyard	Membre du Syndicat mixte de l'Avant Pays Savoyard	\N	\N	\N	\N	DIVERS	20058E	\N	\N	\N	\N	\N
52269	\N	\N	\N	ACTIF	Conseiller syndical du Parc Naturel Régional de Chartreuse	Conseiller syndical du Parc Naturel Régional de Chartreuse	Conseiller syndical du Parc Naturel Régional de Chartreuse	\N	2020	\N	\N	DIVERS	20058E	\N	\N	\N	\N	\N
52386	\N	\N	\N	ACTIF	Présidente du Comité de massif du Jura	Présidente du Comité de massif du Jura	Présidente du Comité de massif du Jura	\N	2020	\N	\N	DIVERS	19479G	\N	\N	\N	\N	\N
52272	2014-04-15 00:00:00	\N	2020-10-15 00:00:00	ANCIEN	\N	Pays de la Serre	Pays de la Serre	\N	\N	\N	\N	INTERCOM	20122U	\N	\N	de	\N	\N
52274	2018-04-01 00:00:00	\N	2020-10-15 00:00:00	ANCIEN	Président du Service d'Incendie et de Secours de l'Aisne	Président du Service d'Incendie et de Secours de l'Aisne	Président du Service d'Incendie et de Secours de l'Aisne	\N	\N	\N	\N	DIVERS	20122U	\N	\N	\N	\N	\N
52275	\N	\N	\N	ACTIF	Président de l'Union des Maires de l'Aisne	Président de l'Union des Maires de l'Aisne	Président de l'Union des Maires de l'Aisne	\N	2020	\N	\N	DIVERS	20122U	\N	\N	\N	\N	\N
52304	2008-03-15 00:00:00	\N	\N	ACTIF	\N	Nantes Métropole	\N	\N	\N	\N	\N	INTERCOM	20172F	\N	\N	de	\N	\N
52308	2020-09-30 00:00:00	\N	2020-10-01 00:00:00	ANCIEN	\N	Communauté des Communes Vals et Plateaux des Monts de Lacaune	Communauté des Communes Vals et Plateaux des Monts de Lacaune	\N	\N	\N	\N	INTERCOM	17023S	\N	\N	de la	\N	\N
52309	2015-06-15 00:00:00	\N	2020-10-15 00:00:00	ANCIEN	Présidente du conseil d'administration du SDIS 31	Présidente du conseil d'administration du SDIS 31	Présidente du conseil d'administration du SDIS 31	\N	\N	\N	\N	DIVERS	17965H	\N	\N	\N	\N	\N
52357	2020-12-01 00:00:00	\N	\N	ACTIF	Membre du conseil d'administration de Public Sénat	Membre du conseil d'administration de Public Sénat	Membre du conseil d'administration de Public Sénat	\N	\N	\N	\N	DIVERS	04059M	\N	\N	\N	\N	\N
53157	2020-01-15 00:00:00	\N	\N	ACTIF	\N	Communauté de communes des Pays du Sel et du Vermois	Communauté de communes des Pays du Sel et du Vermois	\N	\N	\N	\N	INTERCOM	20980G	\N	\N	de la	\N	\N
53158	2021-01-15 00:00:00	\N	2022-12-31 00:00:00	ANCIEN	Vice-Présidente de l'Agence locale de l'énergie et du climat	Vice-Présidente de l'Agence locale de l'énergie et du climat	Vice-Présidente de l'Agence locale de l'énergie et du climat	\N	\N	\N	\N	DIVERS	20980G	\N	\N	\N	\N	\N
53915	1499-12-23 00:50:39	\N	2023-11-27 00:00:00	ANCIEN	Service départemental d'incendie et de secours de La Réunion	Président du service départemental d'incendie et de secours de La Réunion	Président du service départemental d'incendie et de secours de La Réunion	\N	\N	\N	\N	DIVERS	21033Y	\N	\N	\N	\N	\N
53441	1499-12-23 00:50:39	1500-01-01 00:00:00	\N	ACTIF	\N	Orléans métropole 	\N	\N	\N	\N	0	INTERCOM	21057H	\N	\N	d'	\N	2023-09-26 15:22:04
53454	1499-12-31 00:50:39	1500-01-01 00:00:00	1515-10-27 00:50:39	ANCIEN	\N	métropole du Grand Paris	\N	\N	\N	\N	0	INTERCOM	21094N	\N	\N	de la	\N	2023-09-26 15:37:39
53457	1499-12-31 00:50:39	1500-01-01 00:00:00	1515-10-27 00:50:39	ANCIEN	\N	Nantes Métropole 	\N	\N	\N	\N	0	INTERCOM	18395Y	\N	\N	de	\N	2023-09-26 15:38:56
53498	1499-12-23 00:50:39	1500-01-01 00:00:00	\N	ACTIF	\N	communauté d'agglomération du Cotentin	\N	\N	\N	\N	0	INTERCOM	21062E	\N	\N	de la	\N	2023-09-26 15:57:00
53566	1499-12-31 00:50:39	1499-12-31 00:50:39	1599-12-31 00:50:39	ANCIEN	\N	syndicat mixte du département de l'Oise 	syndicat mixte du département de l'Oise 	\N	\N	\N	0	INTERCOM	21060C	\N	\N	du	\N	2023-09-26 16:41:48
53798	1499-12-31 00:50:39	1499-12-31 00:50:39	1599-12-31 00:50:39	ANCIEN	\N	syndicat mixte du parc naturel régional des Vosges du Nord	syndicat mixte du parc naturel régional des Vosges du Nord	\N	\N	\N	0	INTERCOM	21082J	\N	\N	du	\N	2023-10-02 10:50:17
53565	1499-12-31 00:50:39	1499-12-31 00:50:39	\N	ACTIF	\N	communauté d'agglomération Creil Sud Oise	communauté d'agglomération Creil Sud Oise	\N	\N	\N	0	INTERCOM	21060C	\N	\N	de la	\N	2023-09-26 16:41:48
53604	1499-12-31 00:50:39	1499-12-31 00:50:39	\N	ACTIF	\N	établissement public territorial Paris Ouest La Défense	\N	\N	\N	\N	\N	INTERCOM	19111A	\N	\N	de l'	\N	2023-09-26 18:11:45
53662	1499-12-31 00:50:39	1500-01-01 00:00:00	2024-03-25 00:00:00	ANCIEN	\N	communauté de communes Champagnole Nozeroy Jura	communauté de communes Champagnole Nozeroy Jura	\N	\N	\N	0	INTERCOM	21047F	\N	\N	de la	\N	2023-09-27 15:47:44
53663	1499-12-31 00:50:39	1500-01-01 00:00:00	1599-12-31 00:50:39	ANCIEN	\N	communauté de communes Champagnole Nozeroy Jura	communauté de communes Champagnole Nozeroy Jura	\N	\N	\N	0	INTERCOM	21047F	\N	\N	de la	\N	2023-09-27 15:47:44
53803	1499-12-31 00:50:39	1500-01-01 00:00:00	\N	ACTIF	\N	métropole du Grand Paris	métropole du Grand Paris	\N	\N	\N	0	INTERCOM	21088Q	\N	\N	de la	\N	2023-10-02 10:55:34
52300	2020-11-01 00:00:00	\N	\N	ACTIF	\N	Président délégué de l'association des petites villes de France	Président délégué de l'association des petites villes de France	\N	\N	\N	\N	DIVERS	14179A	\N	\N	\N	\N	\N
52354	\N	\N	\N	ANCIEN	Président des Maires ruraux du Var	Président des Maires ruraux du Var	Président des Maires ruraux du Var	\N	2017	2020	\N	DIVERS	20072C	\N	\N	\N	\N	\N
53152	2022-11-01 00:00:00	\N	\N	ACTIF	Association Nationale des Élus de la Montagne (ANEM)	Association Nationale des Élus de la Montagne (ANEM)	Membre du Comité Directeur de l'Association Nationale des Élus de la Montagne (ANEM)	\N	\N	\N	\N	DIVERS	19768N	\N	\N	\N	\N	\N
53396	1499-12-31 00:50:39	1500-01-01 00:00:00	2023-11-06 00:00:00	ANCIEN	\N	Communauté intercommunale du Nord de La Réunion	\N	\N	\N	\N	0	INTERCOM	21035B	\N	\N	de la	\N	\N
53390	1499-12-31 00:50:39	1500-01-01 00:00:00	2023-10-19 00:00:00	ANCIEN	\N	communauté de communes des Paysages de la Champagne	\N	\N	\N	\N	0	INTERCOM	21063F	\N	\N	de la	\N	\N
53689	1499-12-31 00:50:39	1500-01-01 00:00:00	\N	ACTIF	\N	communauté de communes Val de Cher Controis	\N	\N	\N	\N	0	INTERCOM	21052C	\N	\N	de la	\N	\N
53421	1499-12-31 00:50:39	1499-12-31 00:50:39	1599-11-06 00:50:39	ANCIEN	\N	communauté d'agglomération Melun Val de Seine 	communauté d'agglomération Melun Val de Seine 	\N	\N	\N	1	INTERCOM	21076L	\N	\N	de la	\N	2023-09-26 12:21:15
53478	1499-12-31 00:50:39	1500-01-01 00:00:00	1515-10-25 00:50:39	ANCIEN	\N	communauté urbaine de Dunkerque	communauté urbaine de Dunkerque	\N	\N	\N	0	INTERCOM	15197G	\N	\N	de la	\N	2023-09-26 15:52:29
53486	1499-12-31 00:50:39	1500-01-01 00:00:00	1599-12-31 00:50:39	ANCIEN	\N	communauté d'agglomération Paris-Saclay	communauté d'agglomération Paris-Saclay	\N	\N	\N	0	INTERCOM	21059K	\N	\N	de la	\N	2023-09-26 15:53:38
53539	1499-12-31 00:50:39	1499-12-31 00:50:39	2023-11-01 00:00:00	ANCIEN	\N	communauté de communes des Hauts de Flandre	communauté de communes des Hauts de Flandre	\N	\N	\N	0	INTERCOM	21087P	\N	\N	de la	\N	2023-09-26 16:22:23
53578	1499-12-31 00:50:39	1500-01-01 00:00:00	\N	ACTIF	\N	communauté d'agglomération Hénin-Carvin	\N	\N	\N	\N	0	INTERCOM	21069M	\N	\N	de la	\N	2023-09-26 17:13:52
53496	1499-12-23 00:50:39	1500-01-01 00:00:00	1599-12-31 00:50:39	ANCIEN	\N	communauté de communes Touraine Nord-Ouest	communauté de communes Touraine Nord-Ouest	\N	\N	\N	0	INTERCOM	21056G	\N	\N	de la	\N	2023-09-26 15:56:57
53692	1499-12-31 00:50:39	1500-01-01 00:00:00	1599-12-31 00:50:39	ANCIEN	\N	communauté de communes Val de Cher Controis	\N	\N	\N	\N	0	INTERCOM	21052C	\N	\N	de la	\N	\N
53532	1499-12-31 00:50:39	1499-12-31 00:50:39	1515-10-24 00:50:39	ANCIEN	\N	métropole du Grand Paris	métropole du Grand Paris	\N	\N	\N	0	INTERCOM	21092L	\N	\N	de la	\N	2023-09-26 16:13:46
53945	1500-01-01 00:00:00	1500-01-01 00:00:00	\N	ACTIF	\N	Communauté de communes du pays Loudunais	\N	\N	1500	\N	0	INTERCOM	21125C	\N	\N	de la	\N	\N
\.


--
-- Data for Name: elueur; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY elueur (eluid, eludatdeb, eludatelu, eludatfin, nationcod, temvalcod, evelic, evelib, evelil, eveobs, eluanndeb, eluannfin, elunbrhab, typmancod, senmat, eludatcum, syscredat, sysmajdat) FROM stdin;
11210	1979-07-17 00:00:00	\N	1981-07-15 00:00:00	XXXXX	ANCIEN	\N	\N	Député européen	\N	1979	1981	\N	EUROPE	06006G	\N	\N	\N
11369	1979-06-07 00:00:00	\N	1983-06-10 00:00:00	XXXXX	ANCIEN	\N	Député au Parlement européen	Député européen	\N	1979	1983	\N	EUROPE	83047W	\N	\N	\N
11681	2004-01-01 00:00:00	\N	2008-09-30 00:00:00	XXXXX	ANCIEN	\N	Député au Parlement européen vice-pdte de la commission	Députée européenne	\N	2004	2008	\N	EUROPE	08050U	\N	\N	\N
5804	1984-07-24 00:00:00	\N	1986-03-19 00:00:00	XXXXX	ANCIEN	\N	Parlementaire européen	Député européen	\N	1984	1986	\N	EUROPE	98052V	\N	\N	\N
5808	1989-11-04 00:00:00	\N	1993-04-16 00:00:00	XXXXX	ANCIEN	\N	Parlementaire Européen	Député européen	\N	1989	1992	\N	EUROPE	98032R	\N	\N	\N
5809	1999-07-20 00:00:00	\N	2004-07-19 00:00:00	XXXXX	ANCIEN	\N	Député au Parlement Européen	Député européen	\N	1999	2004	\N	EUROPE	77053G	\N	\N	\N
5824	\N	\N	2024-03-13 00:00:00	XXXXX	ANCIEN	\N	Député au Parlement européen	Député européen	\N	1994	1999	\N	EUROPE	99001N	\N	\N	\N
5845	1997-10-06 00:00:00	\N	1999-12-17 00:00:00	XXXXX	ANCIEN	\N	\N	Député européen	BQ 5/03/2003	1997	2000	\N	EUROPE	99004R	\N	\N	\N
6591	1984-07-24 00:00:00	\N	1986-03-19 00:00:00	XXXXX	ANCIEN	\N	Parlementaire européen	Député européen	\N	1984	1986	\N	EUROPE	01048V	\N	\N	\N
6654	1981-09-04 00:00:00	\N	1984-06-17 00:00:00	XXXXX	ANCIEN	\N	Député européen	Député européen	\N	1981	1984	\N	EUROPE	01065W	\N	\N	\N
6669	1992-04-02 00:00:00	\N	1994-07-18 00:00:00	XXXXX	ANCIEN	\N	Membre du Parlement européen	Député européen	\N	1992	1994	\N	EUROPE	02001J	\N	\N	\N
10892	1999-06-13 00:00:00	\N	2004-06-13 00:00:00	XXXXX	ANCIEN	\N	Député au Parlement européen	Députée européenne	\N	1999	2004	\N	EUROPE	04063H	\N	\N	\N
10942	1994-06-12 00:00:00	\N	2004-06-13 00:00:00	XXXXX	ANCIEN	\N	Ancien député au Parlement européen	Députée européenne	\N	1994	2004	\N	EUROPE	04075M	\N	\N	\N
10959	1999-06-13 00:00:00	\N	2000-08-01 00:00:00	XXXXX	ANCIEN	\N	Député au Parlement européen	Député européen	\N	1999	2000	\N	EUROPE	04078Q	\N	\N	\N
10973	1991-11-13 00:00:00	\N	1991-12-10 00:00:00	XXXXX	ANCIEN	\N	Député au Parlement européen	Députée européenne	\N	1989	1991	\N	EUROPE	04082L	\N	\N	\N
11064	2002-06-17 00:00:00	\N	2002-07-02 00:00:00	XXXXX	ANCIEN	\N	Député au Parlement européen	Députée européenne	\N	2002	2002	\N	EUROPE	04061F	\N	\N	\N
9671	\N	\N	1998-03-25 00:00:00	XXXXX	ANCIEN	\N	\N	Députée européenne	\N	\N	1998	\N	EUROPE	000465	\N	\N	\N
9672	\N	\N	\N	XXXXX	ANCIEN	\N	\N	Député européen	\N	\N	1989	\N	EUROPE	59527T	\N	\N	\N
10524	\N	\N	\N	XXXXX	ACTIF	\N	\N	Député européen	\N	\N	\N	\N	EUROPE	000379	\N	\N	\N
11228	1984-07-24 00:00:00	\N	1986-12-04 00:00:00	XXXXX	ANCIEN	\N	Député européen	Député européen	\N	1984	1986	\N	EUROPE	07003H	\N	\N	\N
11229	1989-07-25 00:00:00	\N	1999-07-19 00:00:00	XXXXX	ANCIEN	\N	Député européen	Député européen	\N	1989	1999	\N	EUROPE	07003H	\N	\N	\N
11557	\N	\N	2008-09-30 00:00:00	XXXXX	ANCIEN	\N	Député européen	Député européen	\N	2004	2008	\N	EUROPE	08021P	\N	\N	\N
11968	2009-07-14 00:00:00	\N	\N	XXXXX	ACTIF	\N	Député européen	Député européen	\N	\N	\N	\N	EUROPE	86039K	\N	\N	\N
11922	1979-07-17 00:00:00	\N	1980-09-30 00:00:00	XXXXX	ANCIEN	\N	Député européen	Député européen	\N	1979	1980	\N	EUROPE	77058M	\N	\N	\N
11923	1989-07-25 00:00:00	\N	1995-05-18 00:00:00	XXXXX	ANCIEN	\N	Député au Parlement  européen	Député européen	\N	1989	1995	\N	EUROPE	95059Q	\N	\N	\N
12280	2009-06-07 00:00:00	\N	2011-01-01 00:00:00	XXXXX	ANCIEN	\N	Député au Parlement européen	Député européen	\N	2009	2011	\N	EUROPE	11030C	\N	\N	\N
11379	1993-03-31 00:00:00	\N	1994-07-18 00:00:00	XXXXX	ANCIEN	\N	Député européen	Député européen	\N	1993	1994	\N	EUROPE	01034P	\N	\N	\N
6495	1986-03-20 00:00:00	\N	1989-07-24 00:00:00	XXXXX	ANCIEN	\N	Député européen	Député européen	\N	1986	1989	\N	EUROPE	01034P	\N	\N	\N
12097	1997-06-06 00:00:00	\N	2001-03-27 00:00:00	XXXXX	ANCIEN	\N	Députée européenne	\N	laisser le libellé long vide	\N	\N	\N	EUROPE	11077T	\N	\N	\N
12098	1984-07-24 00:00:00	\N	1988-06-25 00:00:00	XXXXX	ANCIEN	\N	Vice-Présidente du Parlement européen	Vice-Présidente du Parlement européen	Vice-Présidente du Parlement européen	\N	\N	\N	EUROPE	11077T	\N	\N	\N
12099	2004-04-20 00:00:00	\N	2009-07-13 00:00:00	\N	ANCIEN	\N	Députée européenne	\N	laisser le libellé long vide	\N	\N	\N	EUROPE	11077T	\N	\N	\N
12377	2004-06-13 00:00:00	\N	2009-06-07 00:00:00	XXXXX	ANCIEN	\N	Député européen	Député européen	\N	\N	\N	\N	EUROPE	11066Q	\N	\N	\N
12783	1992-07-01 00:00:00	\N	1994-07-01 00:00:00	XXXXX	ANCIEN	\N	Députée européenne	Députée européenne	\N	\N	\N	\N	EUROPE	11055M	\N	\N	\N
13886	2009-06-07 00:00:00	\N	2010-12-14 00:00:00	\N	ANCIEN	\N	Député européen	Député européen	\N	\N	\N	\N	EUROPE	14026U	\N	2014-09-18 11:01:31	2017-11-23 17:23:54
52193	1996-07-15 00:00:00	1996-07-15 00:00:00	2009-07-15 00:00:00	\N	ANCIEN	\N	Député européen	\N	\N	\N	\N	\N	EUROPE	12028B	\N	\N	\N
14285	1989-07-25 00:00:00	\N	1993-04-16 00:00:00	\N	ANCIEN	\N	Député européen	Député européen	Député européen	1989	1993	\N	EUROPE	14251Q	\N	2014-09-28 19:01:23	2014-10-17 16:28:22
15520	1994-07-19 00:00:00	\N	1999-07-20 00:00:00	\N	ANCIEN	\N	Députée européenne	\N	\N	\N	\N	\N	EUROPE	14363X	\N	2017-02-07 16:25:19	2017-02-07 16:27:56
53464	2019-09-26 00:00:00	\N	2023-10-01 00:00:00	\N	ANCIEN	\N	Député européen	\N	\N	\N	\N	\N	EUROPE	21091K	\N	\N	\N
52180	2009-05-15 00:00:00	2009-05-15 00:00:00	2019-05-15 00:00:00	\N	ANCIEN	\N	Député européen	\N	\N	\N	\N	\N	EUROPE	20104S	\N	\N	\N
53473	1499-12-31 00:50:39	1499-12-31 00:50:39	2023-10-01 00:00:00	XXXXX	ANCIEN	\N	Député européen	\N	\N	1500	\N	0	EUROPE	21093M	\N	\N	2023-09-26 15:49:14
\.


--
-- Data for Name: elureg; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY elureg (eluid, eludatdeb, regcod, eludatelu, eludatfin, temvalcod, evelic, evelib, evelil, eveobs, eluanndeb, eluannfin, elunbrhab, typmancod, senmat, eludatcum, syscredat, sysmajdat) FROM stdin;
11706	1998-03-15 00:00:00	22	\N	2004-03-21 00:00:00	ANCIEN	\N	\N	\N	\N	1998	2004	\N	REGION	08053X	\N	\N	\N
11786	\N	4	\N	\N	ANCIEN	\N	\N	\N	\N	1994	2001	\N	REGION	08070Y	\N	\N	\N
11849	\N	50	\N	\N	ANCIEN	\N	\N	\N	\N	1986	1992	\N	REGION	08023R	\N	\N	\N
11859	\N	11	\N	\N	ANCIEN	\N	\N	\N	\N	\N	2008	\N	REGION	08063A	\N	\N	\N
11899	\N	2	\N	\N	ANCIEN	\N	\N	\N	\N	1992	1998	\N	REGION	83021L	\N	\N	\N
11901	\N	17	\N	\N	ANCIEN	\N	\N	\N	\N	1986	1989	\N	REGION	89022N	\N	\N	\N
11989	\N	12	\N	\N	ANCIEN	\N	\N	\N	\N	2004	2010	\N	REGION	09012S	\N	\N	\N
12042	\N	50	\N	\N	ACTIF	\N	\N	\N	\N	2010	\N	\N	REGION	04096S	\N	\N	\N
10372	\N	\N	\N	2011-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2011	\N	\N	59307H	\N	\N	\N
11230	2002-10-01 00:00:00	21	\N	\N	ANCIEN	\N	\N	\N	\N	2002	2010	\N	REGION	07003H	\N	\N	\N
11752	2004-04-02 00:00:00	4	\N	2015-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	REGION	08061X	\N	\N	2015-12-15 14:56:16
12013	2010-03-22 00:00:00	1	\N	\N	ACTIF	\N	\N	\N	\N	2010	\N	\N	REGION	92005M	\N	\N	\N
12014	2010-03-22 00:00:00	16	\N	2015-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	REGION	01011G	\N	\N	2015-12-15 15:01:45
12015	2010-03-22 00:00:00	17	\N	2014-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	0	REGION	04070G	\N	\N	2014-04-29 18:18:15
12054	\N	1	\N	2015-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	1998	\N	\N	REGION	10015M	\N	\N	2015-12-15 15:18:37
11220	\N	15	\N	2010-03-21 00:00:00	ANCIEN	\N	\N	\N	\N	2003	2010	\N	REGION	07001F	\N	\N	\N
11368	\N	10	\N	\N	ANCIEN	\N	\N	\N	\N	1986	1986	\N	REGION	77053G	\N	\N	\N
11381	1986-03-16 00:00:00	21	\N	\N	ANCIEN	\N	\N	\N	\N	1986	1988	\N	REGION	87003B	\N	\N	\N
11382	1992-03-12 00:00:00	21	\N	\N	ANCIEN	\N	\N	\N	\N	1992	1992	\N	REGION	87003B	\N	\N	\N
11517	\N	12	\N	\N	ANCIEN	\N	\N	\N	\N	1986	2008	\N	REGION	08012N	\N	\N	\N
11587	\N	14	\N	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	1992	2008	\N	REGION	08028W	\N	\N	\N
11622	\N	21	\N	\N	ANCIEN	\N	\N	\N	\N	1998	2008	\N	REGION	08038Y	\N	\N	\N
11647	\N	21	\N	2020-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	1998	2001	\N	REGION	08041T	\N	\N	\N
11686	\N	12	\N	\N	ANCIEN	\N	\N	\N	\N	1986	2001	\N	REGION	08050U	\N	\N	\N
11727	\N	20	\N	\N	ANCIEN	\N	\N	\N	\N	1998	2008	\N	REGION	08060W	\N	\N	\N
11756	\N	14	\N	2008-10-15 00:00:00	ANCIEN	\N	\N	\N	\N	1998	2008	\N	REGION	08066D	\N	\N	\N
11774	\N	9	\N	\N	ANCIEN	\N	\N	\N	\N	1992	2008	\N	REGION	08068F	\N	\N	\N
11792	2004-03-01 00:00:00	51	\N	\N	ANCIEN	\N	\N	\N	\N	2004	2008	\N	REGION	08072B	\N	\N	\N
12017	2010-03-21 00:00:00	16	\N	\N	ACTIF	\N	\N	\N	\N	2010	\N	\N	REGION	82002D	\N	\N	\N
1485	\N	21	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	REGION	89039X	\N	\N	\N
1486	\N	3	\N	1999-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	\N	1999	\N	REGION	89038W	\N	\N	\N
1487	\N	2	\N	2004-03-28 00:00:00	ANCIEN	\N	\N	\N	\N	1973	2004	\N	REGION	80046H	\N	\N	\N
1488	\N	2	\N	2010-03-21 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2010	\N	REGION	92015P	\N	\N	\N
1489	\N	18	\N	2009-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2009	\N	REGION	83035S	\N	\N	\N
1490	\N	7	\N	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	\N	1973	\N	REGION	74011H	\N	\N	\N
1491	\N	5	\N	2004-03-30 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2004	\N	REGION	83050R	\N	\N	\N
1492	\N	15	\N	2001-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	1992	2001	\N	REGION	92031P	\N	\N	\N
1493	\N	15	\N	2004-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2004	\N	REGION	85002R	\N	\N	\N
1494	\N	15	\N	\N	ANCIEN	\N	\N	\N	\N	1983	2001	\N	REGION	92044U	\N	\N	\N
1495	\N	16	\N	2004-03-28 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2004	\N	REGION	92024Q	\N	\N	\N
1496	\N	15	\N	2015-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	REGION	83047W	\N	\N	2015-12-15 14:57:21
1497	\N	1	\N	2015-08-10 00:00:00	ANCIEN	\N	\N	\N	\N	1992	2015	\N	REGION	86030A	\N	\N	\N
1498	\N	22	\N	2013-06-03 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	0	REGION	95015C	\N	\N	2014-03-19 17:57:05
1499	\N	20	\N	2004-03-28 00:00:00	ANCIEN	\N	\N	\N	\N	1995	2004	\N	REGION	95009E	\N	\N	\N
1500	1988-12-19 00:00:00	20	\N	2002-05-08 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	REGION	95059Q	\N	\N	2016-09-16 14:45:54
1501	\N	13	\N	2004-03-28 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2004	\N	REGION	95012Y	\N	\N	\N
1502	\N	50	\N	2004-04-02 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2004	\N	REGION	95050F	\N	\N	\N
1503	\N	51	\N	2017-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	REGION	89035T	\N	\N	2018-01-08 09:00:07
1504	\N	53	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	REGION	98002K	\N	\N	\N
1505	\N	53	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	REGION	95002W	\N	\N	\N
1506	\N	53	\N	2016-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	1983	\N	\N	REGION	96003C	\N	\N	2016-11-14 11:07:47
5090	\N	21	\N	1998-10-22 00:00:00	ANCIEN	\N	\N	\N	\N	1992	1998	\N	REGION	98022P	\N	\N	\N
5108	\N	3	\N	\N	ACTIF	\N	\N	\N	\N	1976	\N	\N	REGION	98026T	\N	\N	\N
5115	\N	9	\N	2004-04-02 00:00:00	ANCIEN	\N	\N	\N	\N	1986	2004	\N	REGION	98028V	\N	\N	\N
5137	\N	14	\N	1998-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	1998	\N	\N	REGION	98033S	\N	\N	\N
5144	1986-03-16 00:00:00	19	\N	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	1986	\N	\N	REGION	98036V	\N	\N	\N
5157	\N	20	\N	\N	ACTIF	\N	\N	\N	\N	1986	\N	\N	REGION	98039Y	\N	\N	\N
5166	\N	16	\N	2004-04-02 00:00:00	ANCIEN	\N	\N	\N	\N	1986	2004	\N	REGION	98041S	\N	\N	\N
5199	\N	5	\N	\N	ANCIEN	\N	\N	\N	\N	1998	1998	\N	REGION	98049B	\N	\N	\N
5223	\N	21	\N	\N	ANCIEN	\N	\N	\N	\N	1988	1992	\N	REGION	98030P	\N	\N	\N
5224	\N	21	\N	\N	ANCIEN	\N	\N	\N	\N	1973	1986	\N	REGION	98030P	\N	\N	\N
5232	\N	17	\N	2004-03-28 00:00:00	ANCIEN	\N	\N	\N	\N	1992	2004	\N	REGION	98053W	\N	\N	\N
5238	\N	8	\N	2020-03-31 00:00:00	ANCIEN	\N	\N	\N	\N	1984	1998	\N	REGION	98008R	\N	\N	\N
5242	\N	21	\N	\N	ANCIEN	\N	\N	\N	\N	1993	1997	\N	REGION	98040R	\N	\N	\N
5266	\N	21	\N	\N	ANCIEN	\N	\N	\N	\N	1979	1998	\N	REGION	89029V	\N	\N	\N
5820	\N	15	\N	2024-03-13 00:00:00	ANCIEN	\N	\N	\N	\N	1998	\N	\N	REGION	99001N	\N	\N	\N
5830	\N	7	\N	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2004	\N	REGION	96005E	\N	\N	\N
5844	\N	10	\N	\N	ANCIEN	\N	\N	\N	\N	1992	1998	\N	REGION	99004R	\N	\N	\N
5827	\N	15	\N	2024-03-13 00:00:00	ANCIEN	\N	\N	\N	\N	1986	1992	\N	REGION	99001N	\N	\N	\N
5852	1986-03-16 00:00:00	10	\N	1992-03-22 00:00:00	ANCIEN	\N	\N	\N	\N	1986	1992	\N	REGION	00001A	\N	\N	\N
5870	\N	6	\N	2007-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	1983	2007	\N	REGION	89020L	\N	\N	\N
5877	\N	13	\N	\N	ANCIEN	\N	\N	\N	\N	\N	1998	\N	REGION	00004D	\N	\N	\N
5882	\N	6	\N	2009-05-28 00:00:00	ANCIEN	\N	\N	\N	\N	1992	2009	\N	REGION	83043S	\N	\N	\N
5890	\N	22	\N	\N	ANCIEN	\N	\N	\N	\N	1992	1998	\N	REGION	95038K	\N	\N	\N
5898	\N	9	\N	\N	ANCIEN	\N	\N	\N	\N	1992	1998	\N	REGION	01002F	\N	\N	\N
6195	\N	14	\N	2001-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	1982	2001	\N	REGION	01003G	\N	\N	\N
6239	\N	10	\N	\N	ANCIEN	\N	\N	\N	\N	1992	1995	\N	REGION	95051G	\N	\N	\N
6278	\N	4	\N	\N	ANCIEN	\N	\N	\N	\N	1984	1993	\N	REGION	92016Q	\N	\N	\N
6300	\N	6	\N	\N	ANCIEN	\N	\N	\N	\N	1992	1994	\N	REGION	98025S	\N	\N	\N
6335	1998-03-15 00:00:00	22	\N	2023-11-25 00:00:00	ANCIEN	\N	\N	\N	\N	1992	1999	\N	REGION	99002P	\N	\N	\N
6357	\N	11	\N	2004-04-02 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2004	\N	REGION	01005J	\N	\N	\N
6418	\N	7	\N	2004-04-02 00:00:00	ANCIEN	\N	\N	\N	\N	1998	2004	\N	REGION	01026P	\N	\N	\N
6474	\N	15	\N	2001-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	1998	2001	\N	REGION	01043Q	\N	\N	\N
6487	\N	13	\N	2004-04-02 00:00:00	ANCIEN	\N	\N	\N	\N	1992	2004	\N	REGION	01048V	\N	\N	\N
6496	\N	5	\N	\N	ANCIEN	\N	\N	\N	\N	1998	2010	\N	REGION	01022K	\N	\N	\N
6516	1992-03-22 00:00:00	3	\N	1998-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	1992	1998	\N	REGION	01031L	\N	\N	\N
6521	\N	7	\N	2001-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	1998	2001	\N	REGION	01058X	\N	\N	\N
6538	1998-03-15 00:00:00	22	\N	2001-10-15 00:00:00	ANCIEN	\N	\N	\N	\N	1998	2001	\N	REGION	01039U	\N	\N	\N
6542	\N	5	\N	\N	ANCIEN	\N	\N	\N	\N	1984	2001	\N	REGION	01021J	\N	\N	\N
6543	\N	3	\N	\N	ANCIEN	\N	\N	\N	\N	1983	1988	\N	REGION	01052R	\N	\N	\N
6550	1992-03-01 00:00:00	22	\N	1992-08-01 00:00:00	ANCIEN	\N	\N	\N	\N	1992	1992	\N	REGION	01020H	\N	\N	\N
6560	\N	18	\N	\N	ANCIEN	\N	\N	\N	\N	1998	2008	\N	REGION	01047U	\N	\N	\N
6563	\N	9	\N	\N	ANCIEN	\N	\N	\N	\N	1983	1986	\N	REGION	01046T	\N	\N	\N
6569	\N	53	\N	\N	ANCIEN	\N	\N	\N	\N	1985	1988	\N	REGION	01010F	\N	\N	\N
6573	\N	13	\N	\N	ANCIEN	\N	\N	\N	\N	1986	2002	\N	REGION	01014K	\N	\N	\N
6582	1986-03-16 00:00:00	9	\N	\N	ANCIEN	\N	\N	\N	\N	1986	2001	\N	REGION	01008M	\N	\N	\N
6584	\N	16	\N	2004-03-28 00:00:00	ANCIEN	\N	\N	\N	\N	1986	2004	\N	REGION	01011G	\N	\N	\N
6586	\N	13	\N	2015-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	1983	\N	\N	REGION	83042R	\N	\N	2015-12-15 12:00:52
6589	\N	13	\N	2001-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	1998	2001	\N	REGION	01062T	\N	\N	\N
6596	\N	13	\N	\N	ANCIEN	\N	\N	\N	\N	1998	2002	\N	REGION	01060R	\N	\N	\N
6612	\N	6	\N	\N	ANCIEN	\N	\N	\N	\N	1985	1997	\N	REGION	01012H	\N	\N	\N
6614	\N	13	\N	2019-08-19 00:00:00	ANCIEN	\N	\N	\N	\N	1986	2002	\N	REGION	01061S	\N	\N	\N
6658	1982-08-01 00:00:00	8	\N	2001-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	1982	2001	\N	REGION	01065W	\N	\N	\N
6623	\N	18	\N	2001-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	1992	2001	\N	REGION	01055U	\N	\N	\N
6626	\N	22	\N	\N	ANCIEN	\N	\N	\N	\N	1973	1986	\N	REGION	01020H	\N	\N	\N
6628	\N	2	\N	2006-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	1979	2006	\N	REGION	01032M	\N	\N	\N
6663	\N	6	\N	\N	ANCIEN	\N	\N	\N	\N	1992	2001	\N	REGION	01007L	\N	\N	\N
6666	\N	15	\N	2004-03-28 00:00:00	ANCIEN	\N	\N	\N	\N	1977	2004	\N	REGION	02001J	\N	\N	\N
6750	\N	1	\N	\N	ANCIEN	\N	\N	\N	\N	1985	1992	\N	REGION	92005M	\N	\N	\N
6753	\N	20	\N	\N	ANCIEN	\N	\N	\N	\N	1986	1998	\N	REGION	02002K	\N	\N	\N
6792	\N	9	\N	\N	ANCIEN	\N	\N	\N	\N	1998	2001	\N	REGION	03001N	\N	\N	\N
10348	\N	\N	\N	2021-04-21 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	\N	58819Y	\N	\N	\N
10349	\N	\N	\N	2018-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	\N	59309K	\N	\N	\N
10350	\N	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	\N	58619S	\N	\N	\N
10351	\N	\N	\N	2017-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2017	\N	\N	58951C	\N	\N	\N
10352	\N	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	\N	58946F	\N	\N	\N
10353	\N	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	\N	000272	\N	\N	\N
10354	\N	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	\N	59222D	\N	\N	\N
10355	\N	\N	\N	2007-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2007	\N	\N	58649Y	\N	\N	\N
10356	\N	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	\N	000621	\N	\N	\N
10357	\N	\N	\N	2004-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2004	\N	\N	59531P	\N	\N	\N
10358	\N	\N	\N	2017-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2017	\N	\N	57714L	\N	\N	\N
10359	\N	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	\N	000197	\N	\N	\N
10360	\N	\N	\N	2001-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2001	\N	\N	59521M	\N	\N	\N
10361	\N	\N	\N	2013-03-13 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2013	\N	\N	58944D	\N	\N	\N
10362	\N	\N	\N	2011-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2011	\N	\N	000599	\N	\N	\N
10363	\N	\N	\N	2021-04-17 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	\N	59536U	\N	\N	\N
10364	\N	\N	\N	2010-09-13 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2010	\N	\N	58925A	\N	\N	\N
10365	\N	\N	\N	2000-12-28 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2000	\N	\N	59549A	\N	\N	\N
10366	\N	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	\N	000514	\N	\N	\N
10367	\N	\N	\N	1996-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	\N	1996	\N	\N	000470	\N	\N	\N
10368	\N	\N	\N	2016-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2016	\N	\N	58938F	\N	\N	\N
10369	\N	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	\N	000505	\N	\N	\N
11213	\N	5	\N	\N	ANCIEN	\N	\N	\N	\N	1973	1986	\N	REGION	06006G	\N	\N	\N
11275	\N	11	\N	\N	ANCIEN	\N	\N	\N	\N	1998	2008	\N	REGION	07030L	\N	\N	\N
11518	2004-03-28 00:00:00	5	\N	2010-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2010	\N	REGION	08013P	\N	\N	\N
11552	2004-04-02 00:00:00	11	\N	\N	ANCIEN	\N	\N	\N	\N	2004	2008	\N	REGION	08020N	\N	\N	\N
11555	\N	11	\N	\N	ACTIF	\N	\N	\N	\N	1998	\N	\N	REGION	08021P	\N	\N	2015-12-15 15:06:54
11592	\N	5	\N	\N	ANCIEN	\N	\N	\N	\N	1986	1988	\N	REGION	08027V	\N	\N	\N
11611	\N	5	\N	2015-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	1998	\N	\N	REGION	08034U	\N	\N	2015-12-15 15:04:14
11635	\N	9	\N	\N	ANCIEN	\N	\N	\N	\N	1981	1982	\N	REGION	02053W	\N	\N	\N
11680	\N	14	\N	2008-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	1998	2008	\N	REGION	08049C	\N	\N	\N
11751	\N	11	\N	\N	ANCIEN	\N	\N	\N	\N	1986	2002	\N	REGION	08065C	\N	\N	\N
11856	\N	5	\N	\N	ANCIEN	\N	\N	\N	\N	1986	1992	\N	REGION	08037X	\N	\N	\N
11879	\N	10	\N	\N	ANCIEN	\N	\N	\N	\N	\N	2004	\N	REGION	59312E	\N	\N	\N
11908	\N	16	\N	\N	ANCIEN	\N	\N	\N	\N	1986	1989	\N	REGION	92029V	\N	\N	\N
11905	\N	10	\N	\N	ANCIEN	\N	\N	\N	\N	1983	1986	\N	REGION	95039L	\N	\N	\N
11913	\N	2	\N	2019-08-27 00:00:00	ANCIEN	\N	\N	\N	\N	1981	1985	\N	REGION	80027E	\N	\N	\N
11916	\N	15	\N	\N	ANCIEN	\N	\N	\N	\N	1974	1981	\N	REGION	92037V	\N	\N	\N
11918	\N	22	\N	\N	ANCIEN	\N	\N	\N	\N	1992	1993	\N	REGION	95049N	\N	\N	\N
11493	\N	19	\N	\N	ANCIEN	\N	\N	\N	\N	2004	2008	\N	REGION	08010L	\N	\N	\N
11532	\N	22	\N	\N	ANCIEN	\N	\N	\N	\N	1992	1998	\N	REGION	08016S	\N	\N	\N
11881	\N	2	\N	\N	ANCIEN	\N	\N	\N	\N	\N	1992	\N	REGION	83033Q	\N	\N	\N
11882	\N	10	\N	\N	ANCIEN	\N	\N	\N	\N	1976	1995	\N	REGION	77019E	\N	\N	\N
12838	2010-03-01 00:00:00	52	\N	2011-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	REGION	11109J	\N	\N	\N
12278	2004-03-01 00:00:00	15	\N	2015-12-13 00:00:00	ANCIEN	\N	Conseiller régional	\N	\N	\N	\N	\N	REGION	11061K	\N	\N	2015-12-15 14:58:55
12835	2010-03-01 00:00:00	10	\N	2015-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	REGION	09001P	\N	\N	2015-12-15 15:11:05
12248	2010-03-21 00:00:00	18	\N	2011-10-25 00:00:00	ANCIEN	\N	CONSEILLER REGIONAL	\N	\N	2010	\N	\N	REGION	11030C	\N	\N	\N
12339	2010-03-21 00:00:00	15	\N	\N	ANCIEN	\N	Vice-Président du Conseil Régional	\N	\N	\N	2013	\N	REGION	11036J	\N	\N	2013-04-05 18:17:14
12347	\N	22	\N	2015-12-13 00:00:00	ANCIEN	\N	Conseiller régional	\N	\N	2004	\N	\N	REGION	11056N	\N	\N	2015-12-15 15:04:38
12082	1992-03-01 00:00:00	13	\N	1998-02-28 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	REGION	11003M	\N	\N	\N
12551	1986-03-16 00:00:00	7	\N	2004-03-21 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	REGION	11097X	\N	\N	\N
12563	1992-03-23 00:00:00	11	\N	2003-02-24 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	REGION	11101A	\N	\N	\N
12578	\N	2	\N	2022-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	1981	2010	\N	REGION	11112D	\N	\N	\N
12581	1986-03-16 00:00:00	2	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	REGION	11111C	\N	\N	2015-12-15 15:03:54
12503	1992-03-22 00:00:00	15	\N	2011-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	REGION	11037K	\N	\N	\N
12406	2004-03-28 00:00:00	10	\N	2015-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	REGION	11031D	\N	\N	2015-12-15 14:57:59
12417	1983-01-01 00:00:00	3	\N	1985-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	\N	1985	\N	REGION	11105E	\N	\N	\N
12791	1998-03-16 00:00:00	15	\N	2001-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	REGION	11035H	\N	\N	\N
12853	1998-03-15 00:00:00	11	\N	2020-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2013	\N	REGION	11081P	\N	\N	2013-06-21 10:59:33
12575	1998-03-15 00:00:00	3	\N	2010-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	REGION	11104D	\N	\N	\N
12584	2004-03-28 00:00:00	2	\N	2010-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	REGION	11110B	\N	\N	\N
12766	1998-03-15 00:00:00	50	\N	\N	ANCIEN	\N	\N	\N	\N	\N	2004	\N	REGION	11113E	\N	\N	\N
12803	1998-03-01 00:00:00	6	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	REGION	11108H	\N	\N	\N
12810	1992-06-01 00:00:00	6	\N	1995-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	REGION	11107G	\N	\N	\N
12833	1986-03-15 00:00:00	22	\N	1997-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	REGION	11041F	\N	\N	\N
12108	\N	10	\N	\N	ANCIEN	\N	Conseiller régional	\N	\N	2004	2012	\N	REGION	11084S	\N	\N	\N
12924	\N	22	\N	\N	ANCIEN	\N	\N	\N	\N	1998	2008	\N	REGION	12038D	\N	2013-08-19 14:52:51	\N
12926	2010-03-21 00:00:00	10	\N	2015-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	REGION	12041X	\N	2013-08-19 18:01:23	2015-12-15 15:03:55
11884	\N	22	\N	\N	ANCIEN	\N	\N	\N	\N	1986	1988	\N	REGION	95032D	\N	\N	\N
11303	1998-03-15 00:00:00	10	\N	2004-03-21 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2004	\N	REGION	07033P	\N	\N	\N
12016	2010-03-21 00:00:00	11	\N	\N	ANCIEN	\N	\N	\N	\N	2010	2013	\N	REGION	07030L	\N	\N	2013-06-21 11:02:22
12018	2010-03-21 00:00:00	21	\N	\N	ANCIEN	\N	\N	\N	\N	2010	2010	\N	REGION	08007R	\N	\N	\N
12066	\N	10	\N	\N	ANCIEN	\N	\N	\N	\N	2004	2010	\N	REGION	11001K	\N	\N	\N
11928	\N	17	\N	2021-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	1992	1993	\N	REGION	95062K	\N	\N	\N
11930	\N	15	\N	\N	ANCIEN	\N	\N	\N	\N	1988	1992	\N	REGION	92043T	\N	\N	\N
11931	\N	19	\N	\N	ANCIEN	\N	\N	\N	\N	1986	1992	\N	REGION	92045V	\N	\N	\N
12100	2004-04-28 00:00:00	15	\N	2010-03-21 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	REGION	11077T	\N	\N	\N
12106	2004-03-21 00:00:00	10	\N	2015-12-13 00:00:00	ANCIEN	\N	Conseiller régional	\N	\N	\N	\N	\N	REGION	11069T	\N	\N	2015-12-15 15:08:49
12135	1986-03-01 00:00:00	16	\N	2011-04-01 00:00:00	ANCIEN	\N	Conseiller Régional	\N	\N	1986	2001	\N	REGION	11100Y	\N	\N	\N
12376	\N	18	\N	\N	ANCIEN	\N	\N	\N	\N	1986	2011	\N	REGION	11066Q	\N	\N	\N
12383	1998-03-15 00:00:00	19	\N	2015-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	REGION	11045K	\N	\N	2017-10-09 17:59:39
12343	2004-03-01 00:00:00	15	\N	2011-11-14 00:00:00	ANCIEN	\N	Conseiller régional	\N	\N	\N	\N	\N	REGION	11060J	\N	\N	\N
12381	1998-03-15 00:00:00	15	\N	\N	ANCIEN	\N	\N	\N	\N	\N	2011	\N	REGION	11039M	\N	\N	2013-04-10 17:20:41
10730	\N	22	\N	\N	ANCIEN	\N	\N	\N	\N	1974	1979	\N	REGION	01019Q	\N	\N	\N
10962	1986-03-16 00:00:00	10	\N	2004-03-21 00:00:00	ANCIEN	\N	\N	\N	\N	1986	2004	\N	REGION	04079R	\N	\N	\N
12041	2004-03-28 00:00:00	18	\N	2021-07-01 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	REGION	10006L	\N	\N	\N
6446	\N	15	\N	2001-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	1986	2001	\N	REGION	01034P	\N	\N	\N
6476	\N	15	\N	2001-10-22 00:00:00	ANCIEN	\N	\N	\N	\N	1992	2001	\N	REGION	01044R	\N	\N	\N
6545	\N	22	\N	\N	ANCIEN	\N	\N	\N	\N	1986	1993	\N	REGION	01019Q	\N	\N	\N
12400	1986-03-16 00:00:00	14	\N	\N	ANCIEN	\N	\N	\N	\N	\N	2001	\N	REGION	11012A	\N	\N	\N
12435	2004-03-28 00:00:00	11	\N	2014-08-26 00:00:00	ANCIEN	\N	\N	\N	\N	2004	\N	\N	REGION	11018G	\N	\N	2014-08-27 16:33:37
12861	2002-03-01 00:00:00	19	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	REGION	11044J	\N	\N	\N
12460	1998-03-15 00:00:00	53	\N	2004-03-21 00:00:00	ANCIEN	\N	\N	\N	\N	1998	2004	\N	REGION	11025F	\N	\N	\N
12493	2004-03-28 00:00:00	10	\N	2004-03-31 00:00:00	ANCIEN	\N	\N	\N	\N	\N	2004	\N	REGION	11034G	\N	\N	\N
12885	\N	6	\N	\N	ANCIEN	\N	\N	\N	\N	1981	1986	\N	REGION	01028R	\N	\N	\N
12506	\N	13	\N	\N	ANCIEN	\N	\N	\N	\N	1992	2002	\N	REGION	11049P	\N	\N	\N
12513	2004-03-28 00:00:00	22	\N	2010-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	REGION	11057P	\N	\N	\N
12534	\N	10	\N	\N	ANCIEN	\N	\N	\N	\N	1993	2004	\N	REGION	11085T	\N	\N	\N
10370	\N	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	\N	58662V	\N	\N	\N
10371	\N	\N	\N	1998-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	\N	1998	\N	\N	74044S	\N	\N	\N
10552	\N	3	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	REGION	000639	\N	\N	\N
10572	\N	10	\N	\N	ANCIEN	\N	\N	\N	\N	1992	1996	\N	REGION	95056M	\N	\N	\N
10606	\N	2	\N	\N	ANCIEN	\N	\N	\N	\N	1992	1993	\N	REGION	98021N	\N	\N	\N
10607	2004-03-28 00:00:00	10	\N	\N	ACTIF	\N	\N	\N	\N	2004	\N	\N	REGION	95004Y	\N	\N	\N
10608	2004-03-28 00:00:00	8	\N	2004-03-28 00:00:00	ANCIEN	\N	\N	\N	\N	2004	2004	\N	REGION	01065W	\N	\N	\N
10609	2004-03-28 00:00:00	22	\N	2010-03-21 00:00:00	ANCIEN	\N	\N	\N	\N	2004	2010	\N	REGION	89015P	\N	\N	\N
10611	2004-03-28 00:00:00	6	\N	\N	ANCIEN	\N	\N	\N	\N	2004	2004	\N	REGION	01007L	\N	\N	\N
10612	2004-03-28 00:00:00	15	\N	2010-06-22 00:00:00	ANCIEN	\N	\N	\N	\N	2004	2010	\N	REGION	01043Q	\N	\N	\N
10613	2004-03-28 00:00:00	14	\N	\N	ANCIEN	\N	\N	\N	\N	2004	2004	\N	REGION	98033S	\N	\N	\N
10614	2004-03-28 00:00:00	6	\N	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	2004	2007	\N	REGION	89045V	\N	\N	\N
10634	2004-04-02 00:00:00	50	\N	2021-09-09 00:00:00	ANCIEN	\N	\N	\N	\N	2004	2005	\N	REGION	95050F	\N	\N	\N
10635	2004-04-02 00:00:00	13	\N	\N	ANCIEN	\N	\N	\N	\N	2004	2010	\N	REGION	01048V	\N	\N	\N
10636	2004-04-02 00:00:00	11	\N	2010-03-21 00:00:00	ANCIEN	\N	\N	\N	\N	2004	2010	\N	REGION	01005J	\N	\N	\N
10637	2004-04-02 00:00:00	9	\N	2010-03-21 00:00:00	ANCIEN	\N	\N	\N	\N	2004	2010	\N	REGION	98028V	\N	\N	\N
10638	2004-04-02 00:00:00	16	\N	2004-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	2004	2004	\N	REGION	98041S	\N	\N	\N
10639	2004-04-02 00:00:00	7	\N	2010-03-21 00:00:00	ANCIEN	\N	\N	\N	\N	2004	2010	\N	REGION	01026P	\N	\N	\N
10670	\N	21	\N	1986-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	1982	1986	\N	REGION	98020M	\N	\N	\N
10671	\N	18	\N	1986-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	1983	1986	\N	REGION	83012K	\N	\N	\N
10673	1986-03-16 00:00:00	10	\N	1992-03-21 00:00:00	ANCIEN	\N	\N	\N	\N	1986	1992	\N	REGION	93005R	\N	\N	\N
10678	1992-03-22 00:00:00	10	\N	\N	ANCIEN	\N	\N	\N	\N	1992	1996	\N	REGION	95007C	\N	\N	\N
10684	1986-03-16 00:00:00	13	\N	1992-06-22 00:00:00	ANCIEN	\N	\N	\N	\N	1986	1992	\N	REGION	92007P	\N	\N	\N
10691	\N	14	\N	1998-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	1992	1998	\N	REGION	98006P	\N	\N	\N
10693	\N	20	\N	\N	ANCIEN	\N	\N	\N	\N	1985	1989	\N	REGION	89013M	\N	\N	\N
10694	1986-03-16 00:00:00	14	\N	1992-03-22 00:00:00	ANCIEN	\N	\N	\N	\N	1986	1992	\N	REGION	89019T	\N	\N	\N
10705	\N	4	\N	\N	ANCIEN	\N	\N	\N	\N	1986	1989	\N	REGION	89037V	\N	\N	\N
10709	\N	22	\N	\N	ANCIEN	\N	\N	\N	\N	1986	1989	\N	REGION	89015P	\N	\N	\N
10710	\N	7	\N	\N	ANCIEN	\N	\N	\N	\N	1992	1998	\N	REGION	71003U	\N	\N	\N
10715	\N	19	\N	\N	ANCIEN	\N	\N	\N	\N	1976	1979	\N	REGION	95023C	\N	\N	\N
10719	\N	11	\N	\N	ANCIEN	\N	\N	\N	\N	1981	1986	\N	REGION	98034T	\N	\N	\N
10720	\N	10	\N	\N	ANCIEN	\N	\N	\N	\N	1986	1998	\N	REGION	97004H	\N	\N	\N
10723	1983-10-11 00:00:00	6	\N	1985-03-22 00:00:00	ANCIEN	\N	\N	\N	\N	1983	1985	\N	REGION	92030N	\N	\N	\N
10724	1986-03-16 00:00:00	6	\N	\N	ANCIEN	\N	\N	\N	\N	1986	1992	\N	REGION	92030N	\N	\N	\N
10726	\N	17	\N	\N	ANCIEN	\N	\N	\N	\N	1978	1992	\N	REGION	95003X	\N	\N	\N
10727	\N	14	\N	\N	ANCIEN	\N	\N	\N	\N	1986	1992	\N	REGION	92039X	\N	\N	\N
10728	\N	20	\N	2009-04-11 00:00:00	ANCIEN	\N	\N	\N	\N	1973	2009	\N	REGION	68036E	\N	\N	\N
10736	\N	7	\N	2022-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	1983	1992	\N	REGION	94003T	\N	\N	\N
10738	\N	5	\N	2022-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	1976	1988	\N	REGION	89040Q	\N	\N	\N
10760	1998-03-15 00:00:00	18	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N	REGION	04033B	\N	\N	2015-12-15 15:08:26
10810	1986-03-16 00:00:00	10	\N	\N	ANCIEN	\N	\N	\N	\N	1986	2004	\N	REGION	04042C	\N	\N	\N
10772	\N	18	\N	\N	ACTIF	\N	\N	\N	\N	1998	\N	\N	REGION	02009S	\N	\N	\N
10819	2004-03-28 00:00:00	1	\N	\N	ANCIEN	\N	\N	\N	\N	2004	2005	\N	REGION	04044E	\N	\N	\N
10829	\N	22	\N	\N	ANCIEN	\N	\N	\N	\N	1992	2009	\N	REGION	04046G	\N	\N	\N
10851	1998-03-15 00:00:00	10	\N	2004-03-21 00:00:00	ANCIEN	\N	\N	\N	\N	1998	2004	\N	REGION	04052E	\N	\N	\N
10854	1986-03-16 00:00:00	10	\N	1992-03-22 00:00:00	ANCIEN	\N	\N	\N	\N	1986	1992	\N	REGION	04053F	\N	\N	\N
10868	\N	10	\N	2018-05-28 00:00:00	ANCIEN	\N	\N	\N	\N	1986	1995	\N	REGION	04055H	\N	\N	2018-05-30 15:10:56
10888	1998-03-15 00:00:00	1	\N	2004-03-21 00:00:00	ANCIEN	\N	\N	\N	\N	1998	2004	\N	REGION	04061F	\N	\N	\N
10905	\N	1	\N	\N	ANCIEN	\N	\N	\N	\N	\N	2004	\N	REGION	04065K	\N	\N	\N
10908	2004-03-28 00:00:00	17	\N	\N	ANCIEN	\N	\N	\N	\N	2004	2005	\N	REGION	04068N	\N	\N	\N
10913	2004-03-28 00:00:00	17	\N	2004-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	2004	2004	\N	REGION	04070G	\N	\N	\N
10920	1992-03-22 00:00:00	10	\N	2004-03-21 00:00:00	ANCIEN	\N	\N	\N	\N	1992	2004	\N	REGION	04071H	\N	\N	\N
10927	\N	10	\N	\N	ANCIEN	\N	\N	\N	\N	1998	2004	\N	REGION	04072J	\N	\N	\N
10939	\N	10	\N	\N	ANCIEN	\N	\N	\N	\N	1992	1994	\N	REGION	04076N	\N	\N	\N
10943	1992-03-22 00:00:00	10	\N	1998-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	1992	1998	\N	REGION	04075M	\N	\N	\N
10954	\N	10	\N	\N	ANCIEN	\N	\N	\N	\N	1983	1988	\N	REGION	04078Q	\N	\N	\N
10957	\N	10	\N	\N	ANCIEN	\N	\N	\N	\N	1992	1994	\N	REGION	04078Q	\N	\N	\N
10974	1992-03-22 00:00:00	9	\N	\N	ANCIEN	\N	\N	\N	\N	1992	1994	\N	REGION	04082L	\N	\N	\N
10990	\N	14	\N	2010-03-21 00:00:00	ANCIEN	\N	\N	\N	\N	1998	2010	\N	REGION	04087R	\N	\N	\N
11020	1998-03-15 00:00:00	21	\N	\N	ANCIEN	\N	\N	\N	\N	1998	2001	\N	REGION	04092N	\N	\N	\N
11032	\N	50	\N	\N	ANCIEN	\N	\N	\N	\N	1998	2001	\N	REGION	04095R	\N	\N	\N
11040	\N	10	\N	\N	ANCIEN	\N	\N	\N	\N	2004	2005	\N	REGION	04081K	\N	\N	\N
11044	\N	1	\N	\N	ANCIEN	\N	\N	\N	\N	1981	1984	\N	REGION	04040A	\N	\N	\N
11105	1998-03-15 00:00:00	10	\N	2004-03-21 00:00:00	ANCIEN	\N	\N	\N	\N	1998	2004	\N	REGION	04100U	\N	\N	\N
11136	\N	21	\N	\N	ANCIEN	\N	\N	\N	\N	1982	1989	\N	REGION	98015Q	\N	\N	\N
11152	\N	19	\N	2021-09-28 00:00:00	ANCIEN	\N	\N	\N	\N	1985	1988	\N	REGION	78003A	\N	\N	\N
11171	\N	6	\N	\N	ANCIEN	\N	\N	\N	\N	1998	2001	\N	REGION	05012A	\N	\N	\N
11257	\N	17	\N	\N	ACTIF	\N	\N	\N	\N	1986	\N	\N	REGION	07025P	\N	\N	\N
11350	\N	14	\N	2008-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	1985	2008	\N	REGION	88004G	\N	\N	\N
11372	\N	21	\N	\N	ANCIEN	\N	\N	\N	\N	1978	1982	\N	REGION	86049M	\N	\N	\N
11569	\N	2	\N	\N	ANCIEN	\N	\N	\N	\N	1986	2004	\N	REGION	08022Q	\N	\N	\N
11574	1998-03-01 00:00:00	2	\N	\N	ANCIEN	\N	\N	\N	\N	1998	2008	\N	REGION	08024S	\N	\N	\N
11578	\N	2	\N	\N	ANCIEN	\N	\N	\N	\N	1992	2008	\N	REGION	08025T	\N	\N	\N
11620	2004-03-28 00:00:00	21	\N	2010-03-21 00:00:00	ANCIEN	\N	\N	\N	\N	2004	2010	\N	REGION	08035V	\N	\N	\N
11628	\N	21	\N	2020-05-11 00:00:00	ANCIEN	\N	\N	\N	\N	\N	1998	\N	REGION	08029X	\N	\N	\N
11651	1992-04-01 00:00:00	21	\N	2004-03-31 00:00:00	ANCIEN	\N	\N	\N	\N	1992	2004	\N	REGION	08040S	\N	\N	\N
13766	2014-05-05 00:00:00	4	2010-03-28 00:00:00	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	0	REGION	14012N	\N	2014-05-05 10:34:45	2014-05-05 10:35:42
13772	\N	22	\N	2015-12-13 00:00:00	ANCIEN	\N	Nouveau	\N	\N	2010	\N	0	REGION	14014Q	\N	2014-05-09 11:39:55	2015-12-15 15:03:27
13788	2010-03-21 00:00:00	11	\N	\N	ANCIEN	\N	Nouveau	\N	\N	\N	2011	\N	REGION	14018U	\N	2014-08-27 16:43:33	2014-09-03 13:49:31
13829	\N	51	\N	\N	ANCIEN	\N	Nouveau	\N	\N	1983	2010	\N	REGION	14039A	\N	2014-09-17 11:58:45	2014-09-17 12:00:05
13835	\N	18	\N	2015-01-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	2008	\N	\N	REGION	14042U	\N	2014-09-17 12:09:06	2015-01-13 12:02:36
13858	1998-03-15 00:00:00	1	\N	2010-10-06 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	14065Q	\N	2014-09-17 17:38:08	2014-09-17 17:39:10
13861	\N	20	\N	2014-10-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	2014	\N	\N	REGION	14071N	\N	2014-09-17 17:44:11	2014-12-04 18:03:32
13964	\N	9	\N	\N	ANCIEN	\N	\N	\N	\N	1992	2008	\N	REGION	14135M	\N	2014-09-18 14:46:47	2014-09-29 17:20:45
14015	\N	18	\N	2014-10-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	2010	\N	\N	REGION	14169X	\N	2014-09-22 11:08:01	2014-10-24 11:13:40
14248	\N	21	\N	\N	ANCIEN	\N	Nouveau	\N	\N	2004	2010	\N	REGION	14187A	\N	2014-09-28 18:17:33	2014-09-30 11:59:01
14310	2010-03-15 00:00:00	22	\N	2015-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	REGION	14259Y	\N	2014-09-28 19:34:19	2015-10-21 16:33:22
14313	2010-03-21 00:00:00	21	\N	2015-02-02 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	14107H	\N	2014-09-28 19:57:58	2015-02-11 15:51:11
14326	\N	22	2000-01-01 00:00:00	\N	ANCIEN	\N	Nouveau	\N	\N	2000	2001	\N	REGION	14081Q	\N	2014-09-29 09:50:46	2014-09-29 09:54:52
52096	2015-12-15 00:00:00	30	\N	2021-06-26 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	20094J	\N	\N	\N
14362	\N	18	\N	2018-05-31 00:00:00	ANCIEN	\N	Nouveau	\N	\N	1986	1988	\N	REGION	14167V	\N	2014-09-30 16:11:40	2018-06-04 11:44:26
14380	1992-03-23 00:00:00	11	\N	1998-03-13 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	REGION	14211G	\N	2014-10-07 16:26:20	2017-10-03 11:53:23
14393	1998-03-15 00:00:00	13	\N	2014-12-22 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	14263U	\N	2014-12-18 16:31:05	2015-03-10 15:52:25
15255	2015-12-14 00:00:00	27	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	REGION	92040Q	\N	2015-12-15 14:56:57	2015-12-15 14:57:18
15254	2015-12-14 00:00:00	27	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	REGION	83042R	\N	2015-12-15 14:52:36	2015-12-15 14:55:33
15206	\N	16	\N	\N	ANCIEN	\N	Nouveau	\N	\N	\N	2015	\N	REGION	14281W	\N	2015-06-12 15:43:33	2015-06-15 10:44:02
15256	2015-12-14 00:00:00	27	\N	2021-06-27 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	10015M	\N	2015-12-15 14:57:58	2015-12-15 14:59:22
15261	2015-12-14 00:00:00	30	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	REGION	14014Q	\N	2015-12-15 15:03:31	2015-12-15 15:03:52
15258	2015-12-14 00:00:00	28	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	REGION	11110B	\N	2015-12-15 15:00:44	2015-12-15 15:01:01
15259	2015-12-14 00:00:00	30	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	REGION	08056B	\N	2015-12-15 15:01:40	2015-12-15 15:01:57
15260	2015-12-14 00:00:00	30	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	REGION	14237S	\N	2015-12-15 15:02:29	2015-12-15 15:02:49
15262	2015-12-14 00:00:00	30	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	REGION	11056N	\N	2015-12-15 15:04:41	2015-12-15 15:05:00
15263	2015-12-14 00:00:00	24	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	REGION	95041E	\N	2015-12-15 15:05:34	2015-12-15 15:05:50
15264	2015-12-14 00:00:00	24	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	REGION	14151M	\N	2015-12-15 15:06:43	2015-12-15 15:06:57
15266	2015-12-14 00:00:00	23	\N	2017-09-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	98023Q	\N	2015-12-15 15:07:34	2017-10-26 15:45:53
15268	2015-12-14 00:00:00	10	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	REGION	11069T	\N	2015-12-15 15:08:51	2015-12-15 15:09:21
15274	2015-12-15 00:00:00	10	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	REGION	09001P	\N	2015-12-15 15:11:22	2015-12-15 15:11:36
15271	2015-12-14 00:00:00	10	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	REGION	14329V	\N	2015-12-15 15:09:59	2015-12-15 15:10:23
15276	2015-12-14 00:00:00	27	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	REGION	14033T	\N	2015-12-15 15:45:15	2015-12-15 15:45:32
15280	2016-01-01 00:00:00	26	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	REGION	14331P	\N	2016-01-12 09:53:01	2016-01-12 09:54:24
15331	2014-02-21 00:00:00	20	\N	2015-12-13 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	95059Q	\N	2016-09-16 14:42:41	2016-09-16 14:44:26
50963	2015-12-13 00:00:00	10	\N	2017-10-18 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	19399H	\N	2017-09-20 17:12:27	2018-01-12 14:57:42
50998	1998-03-15 00:00:00	53	\N	2017-12-18 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	19577H	\N	2017-09-22 10:09:33	2018-02-01 20:39:45
51000	2010-03-21 00:00:00	53	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	REGION	19583F	\N	2017-09-22 10:17:55	2018-01-08 17:21:22
51197	2010-03-21 00:00:00	10	2010-03-21 00:00:00	2017-10-31 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	19675J	\N	2017-09-24 17:55:21	2018-05-30 09:51:13
51326	2015-12-13 00:00:00	28	\N	2017-10-15 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	19489J	\N	2017-09-24 19:59:20	2017-11-08 17:43:33
51356	1992-03-22 00:00:00	15	\N	2001-03-29 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	19569H	\N	2017-09-24 21:06:47	2017-09-24 21:07:49
51360	1998-03-16 00:00:00	11	\N	2002-07-04 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	16431B	\N	2017-09-25 10:11:22	2017-09-25 10:12:17
51419	2010-03-21 00:00:00	14	\N	2015-12-13 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	19631V	\N	2017-09-26 17:55:51	2017-09-26 17:58:53
51394	2011-03-21 00:00:00	19	\N	2015-12-13 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	19573D	\N	2017-09-26 10:43:56	2017-09-26 10:44:53
51455	2015-12-13 00:00:00	2	\N	2017-10-31 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	19719D	\N	2017-10-01 09:29:45	2017-12-14 09:55:45
51429	2010-03-21 00:00:00	2	\N	2015-12-13 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	19367Y	\N	2017-09-27 10:21:32	2017-09-27 10:22:04
51554	2015-12-13 00:00:00	24	\N	2018-01-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	19749K	\N	2017-12-18 14:57:51	2018-05-17 11:35:14
51555	2010-03-30 00:00:00	4	\N	2015-12-12 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	19749K	\N	2017-12-18 14:59:30	2017-12-18 15:16:09
52032	2015-12-15 00:00:00	29	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	REGION	20114U	\N	\N	\N
52039	2004-03-15 00:00:00	28	\N	2015-12-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	20142Y	\N	\N	\N
52043	1992-03-15 00:00:00	19	\N	2002-06-14 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	17229F	\N	\N	\N
52049	2015-03-15 00:00:00	5	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	REGION	20102Q	\N	\N	\N
52065	2015-12-15 00:00:00	21	\N	2021-07-26 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	20136B	\N	\N	\N
52081	2015-12-15 00:00:00	21	\N	2021-06-26 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	20076G	\N	\N	\N
52126	1998-03-15 00:00:00	4	\N	2004-03-15 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	20120S	\N	\N	\N
52131	1993-03-15 00:00:00	23	\N	2015-12-15 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	20068G	\N	\N	\N
52201	2010-03-15 00:00:00	21	\N	2013-02-15 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	12028B	\N	\N	\N
52207	2016-01-15 00:00:00	27	2016-01-15 00:00:00	2020-10-15 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	20098N	\N	\N	\N
52209	2014-05-15 00:00:00	1	\N	2016-01-15 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	20098N	\N	\N	\N
52305	2015-12-15 00:00:00	18	2015-12-15 00:00:00	2020-11-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	20172F	\N	\N	\N
52306	\N	14	\N	\N	ANCIEN	\N	Nouveau	\N	\N	1998	2002	\N	REGION	17023S	\N	\N	\N
52387	2021-07-02 00:00:00	27	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	REGION	19954N	\N	\N	\N
52390	2021-06-26 00:00:00	10	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	REGION	19651A	\N	\N	\N
52403	2021-06-27 00:00:00	24	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	REGION	14123H	\N	\N	\N
52404	2021-06-27 00:00:00	27	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	REGION	20128B	\N	\N	\N
52419	2021-06-27 00:00:00	30	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	REGION	20044X	\N	\N	\N
52438	2015-12-15 00:00:00	10	\N	2021-03-15 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	20252E	\N	\N	\N
53159	2021-06-27 00:00:00	10	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	REGION	19669L	\N	\N	\N
53179	2021-06-15 00:00:00	27	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	REGION	01060R	\N	\N	\N
53384	1500-01-01 00:00:00	5	1500-01-01 00:00:00	1600-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	1500	1600	0	REGION	21050A	\N	\N	2023-09-26 11:05:44
12949	2010-03-21 00:00:00	12	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	0	REGION	14002L	\N	2014-02-14 17:37:54	2014-02-14 17:39:25
13782	2010-03-26 00:00:00	53	2010-03-26 00:00:00	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	0	REGION	14017T	\N	2014-06-25 16:05:28	2016-01-04 10:59:38
13801	\N	12	\N	\N	ANCIEN	\N	Nouveau	\N	\N	1992	1997	\N	REGION	14028W	\N	2014-09-16 11:42:57	2014-09-16 11:43:44
13811	\N	13	\N	2015-12-13 00:00:00	ANCIEN	\N	Nouveau	\N	\N	2014	\N	\N	REGION	14033T	\N	2014-09-16 16:55:20	2015-12-15 14:59:51
50895	2015-12-13 00:00:00	50	\N	2020-06-18 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	19301E	\N	2017-09-20 11:29:28	2018-01-02 10:46:46
13891	2010-03-22 00:00:00	9	\N	2010-07-13 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	95041E	\N	2014-09-18 11:09:38	2014-09-18 11:10:09
13870	2010-03-21 00:00:00	1	\N	2014-11-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	14079W	\N	2014-09-17 18:07:50	2014-11-03 14:16:46
13897	\N	14	\N	\N	ANCIEN	\N	Nouveau	\N	\N	1986	1993	\N	REGION	14089Y	\N	2014-09-18 11:16:31	2014-09-18 11:16:56
13922	\N	14	\N	\N	ANCIEN	\N	Nouveau	\N	\N	2010	2014	\N	REGION	14103D	\N	2014-09-18 11:54:38	2015-01-14 15:53:42
13926	1986-03-17 00:00:00	19	\N	2004-04-13 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	14093U	\N	2014-09-18 11:57:24	2014-09-18 12:07:39
50896	2015-12-13 00:00:00	27	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	REGION	19553Y	\N	2017-09-20 11:29:38	2018-01-25 15:20:53
13937	\N	14	\N	\N	ANCIEN	\N	Nouveau	\N	\N	2004	2007	\N	REGION	14111D	\N	2014-09-18 12:03:56	2014-09-18 12:04:13
13986	2010-03-21 00:00:00	4	2010-03-21 00:00:00	2015-12-13 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	14151M	\N	2014-09-18 15:54:57	2015-12-15 15:06:40
13985	2004-03-01 00:00:00	4	\N	2010-03-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	14147R	\N	2014-09-18 15:52:19	2015-06-24 10:24:37
13987	\N	9	\N	\N	ANCIEN	\N	Nouveau	\N	\N	2004	2014	\N	REGION	14123H	\N	2014-09-18 16:21:01	2015-01-15 15:06:19
50901	2004-03-29 00:00:00	50	\N	2015-12-18 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	12016W	\N	2017-09-20 11:44:53	2017-09-28 18:17:52
14081	\N	22	\N	\N	ANCIEN	\N	Nouveau	\N	\N	2004	2008	\N	REGION	14199E	\N	2014-09-28 16:02:07	2014-09-30 09:46:39
15192	1998-03-15 00:00:00	15	\N	2015-04-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	14273W	\N	2015-04-22 16:51:41	2015-06-04 10:13:01
14245	2010-03-01 00:00:00	21	\N	2017-10-24 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	14055N	\N	2014-09-28 18:13:18	2017-11-09 15:33:55
14247	\N	21	\N	\N	ANCIEN	\N	Nouveau	\N	\N	2014	2014	\N	REGION	14247U	\N	2014-09-28 18:16:03	2015-01-14 16:29:29
14265	1992-03-01 00:00:00	12	\N	2004-03-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	14253S	\N	2014-09-28 18:44:28	2014-10-01 13:37:27
14255	2011-09-28 00:00:00	17	\N	2014-10-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	14249W	\N	2014-09-28 18:27:56	2014-10-23 15:52:34
14365	\N	5	\N	2014-10-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	2010	\N	\N	REGION	14229S	\N	2014-09-30 16:15:08	2014-10-24 11:58:19
14289	2004-03-17 00:00:00	3	2004-03-17 00:00:00	2014-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	REGION	14251Q	\N	2014-09-28 19:04:05	2014-12-01 23:23:42
15253	2015-12-13 00:00:00	53	\N	2016-06-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	11020A	\N	2015-12-15 14:51:56	2016-09-23 12:10:12
15265	2015-12-14 00:00:00	21	2015-12-13 00:00:00	2016-06-15 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	08044W	\N	2015-12-15 15:06:54	2015-12-15 15:07:21
15272	2015-12-14 00:00:00	25	2015-12-13 00:00:00	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	REGION	08009T	\N	2015-12-15 15:10:00	2015-12-15 15:10:20
15269	2015-12-14 00:00:00	25	2015-12-13 00:00:00	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	REGION	04070G	\N	2015-12-15 15:09:27	2015-12-15 15:09:45
15273	2015-12-14 00:00:00	26	2015-12-13 00:00:00	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	REGION	11060J	\N	2015-12-15 15:10:43	2015-12-15 15:11:00
15275	2015-12-14 00:00:00	26	2015-12-13 00:00:00	2016-01-04 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	REGION	01043Q	\N	2015-12-15 15:11:31	2016-06-02 17:13:55
15292	2016-01-04 00:00:00	26	\N	2021-06-26 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	01043Q	\N	2016-06-02 17:06:56	2018-06-08 14:56:35
51002	2015-12-13 00:00:00	26	\N	2017-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	REGION	19581D	\N	2017-09-22 10:20:55	2017-09-24 19:48:14
51052	1998-03-15 00:00:00	10	\N	2015-12-13 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	19649G	\N	2017-09-22 18:28:32	2017-09-25 16:00:49
51057	2015-12-13 00:00:00	10	\N	2017-10-18 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	07033P	\N	2017-09-22 18:44:27	2017-10-19 10:38:53
51091	2015-12-13 00:00:00	53	\N	2021-06-26 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	19659J	\N	2017-09-24 16:45:37	2017-09-24 16:46:14
51110	2015-03-21 00:00:00	53	\N	2015-12-13 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	19657G	\N	2017-09-24 17:12:45	2017-09-24 17:13:06
51136	1998-03-15 00:00:00	2	\N	2001-05-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	19621T	\N	2017-09-24 17:25:43	2017-09-24 17:26:48
51157	2004-03-28 00:00:00	28	\N	2021-06-26 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	19619A	\N	2017-09-24 17:41:22	2017-09-24 17:48:55
51166	2004-03-28 00:00:00	10	\N	2017-09-30 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	19673G	\N	2017-09-24 17:44:05	2017-11-10 10:26:35
51264	2010-03-21 00:00:00	19	2010-03-21 00:00:00	2010-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	REGION	11115U	\N	2017-09-24 18:53:23	2017-09-24 18:55:09
51198	2015-12-13 00:00:00	10	\N	2017-10-19 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	19669L	\N	2017-09-24 17:56:12	2017-09-24 17:56:26
51265	2004-03-28 00:00:00	10	\N	2017-10-23 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	19611R	\N	2017-09-24 18:53:32	2018-02-09 10:00:56
51341	1998-03-15 00:00:00	15	1998-03-15 00:00:00	2008-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	REGION	19599P	\N	2017-09-24 20:30:35	2017-09-24 20:37:55
51276	2015-12-13 00:00:00	10	\N	2017-10-18 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	19689Q	\N	2017-09-24 19:00:27	2018-02-07 16:05:10
51372	2010-03-26 00:00:00	52	2010-03-21 00:00:00	2015-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	\N	REGION	19295A	\N	2017-09-25 11:25:53	2017-09-25 11:27:30
51346	2004-04-28 00:00:00	9	\N	2015-12-13 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	19479G	\N	2017-09-24 20:34:00	2017-10-04 10:18:51
51407	2015-12-13 00:00:00	26	\N	2021-12-07 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	19521Q	\N	2017-09-26 16:59:32	2017-09-26 17:00:21
51411	2015-12-13 00:00:00	18	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	REGION	17583W	\N	2017-09-26 17:32:06	2017-12-05 14:07:47
51460	1985-03-17 00:00:00	2	\N	1993-09-29 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	19721W	\N	2017-10-01 09:52:21	2017-10-01 09:53:04
51466	2015-12-13 00:00:00	2	\N	2021-06-27 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	19725B	\N	2017-10-01 10:47:19	2017-10-01 10:47:59
51595	2015-12-13 00:00:00	25	\N	2021-06-27 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	19758L	\N	2018-06-04 14:00:43	2018-06-04 14:01:34
51609	2004-03-28 00:00:00	15	\N	2015-12-13 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	19760E	\N	\N	\N
52105	2015-12-15 00:00:00	30	\N	2020-10-26 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	17367Q	\N	\N	\N
52216	2015-12-15 00:00:00	29	\N	2021-06-26 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	20030R	\N	\N	\N
52236	2004-03-15 00:00:00	1	\N	2015-12-15 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	20100N	\N	\N	\N
52239	1992-03-15 00:00:00	22	\N	2002-05-15 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	17367Q	\N	\N	\N
52261	2018-09-15 00:00:00	30	2015-12-15 00:00:00	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	REGION	20058E	\N	\N	\N
52384	2021-06-27 00:00:00	26	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	REGION	11115U	\N	\N	\N
52416	2021-07-02 00:00:00	27	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	REGION	14073Q	\N	\N	\N
52421	2021-07-02 00:00:00	27	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	REGION	11048N	\N	\N	\N
52446	2022-01-07 00:00:00	\N	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	REGION	20286Q	\N	\N	\N
52447	2015-12-15 00:00:00	26	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	REGION	20286Q	\N	\N	\N
53150	2021-06-27 00:00:00	30	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	REGION	19768N	\N	\N	\N
53409	1500-01-01 00:00:00	10	1500-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	1500	\N	0	REGION	21090J	\N	\N	2023-09-26 12:12:04
53420	1499-12-31 00:50:39	10	1500-01-01 00:00:00	2023-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	0	REGION	21076L	\N	\N	2023-09-26 12:21:13
53427	1500-01-01 00:00:00	27	1500-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	1500	\N	0	REGION	21065H	\N	\N	2023-09-26 12:35:49
53444	1499-12-31 00:50:39	10	1499-12-31 00:50:39	1599-11-06 00:50:39	ANCIEN	\N	\N	\N	\N	\N	\N	0	REGION	21072G	\N	\N	2023-09-26 15:26:16
53448	1500-01-01 00:00:00	5	1500-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	1500	\N	0	REGION	21051B	\N	\N	2023-09-26 15:30:51
53450	1500-01-01 00:00:00	53	1499-12-31 00:50:39	\N	ACTIF	\N	\N	\N	\N	1500	\N	0	REGION	21034A	\N	\N	2023-09-26 15:35:17
53453	1500-01-01 00:00:00	10	1500-01-01 00:00:00	1600-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	1500	1600	0	REGION	21094N	\N	\N	2023-09-26 15:37:37
53768	1500-01-01 00:00:00	23	1500-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	1500	\N	0	REGION	21056G	\N	\N	2023-09-29 18:45:15
53576	1499-12-31 00:50:39	26	1500-01-01 00:00:00	1599-11-06 00:50:39	ANCIEN	\N	\N	\N	\N	\N	\N	0	REGION	21069M	\N	\N	2023-09-26 17:13:50
53648	1500-01-01 00:00:00	10	1500-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	1500	\N	0	REGION	21074J	\N	\N	2023-09-27 11:48:50
53715	1500-01-01 00:00:00	27	1500-01-01 00:00:00	1600-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	0	REGION	21042A	\N	\N	2023-10-04 17:24:56
53881	2023-11-04 00:00:00	26	\N	\N	ACTIF	\N	Nouveau	\N	\N	\N	\N	\N	REGION	15197G	\N	\N	\N
53613	1500-01-01 00:00:00	10	1500-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	1500	\N	0	REGION	21074J	\N	\N	2023-09-27 09:25:11
53633	2023-09-27 00:00:00	27	\N	2023-11-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	21042A	\N	\N	\N
53732	1500-01-01 00:00:00	5	1500-01-01 00:00:00	1600-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	1500	1600	0	REGION	21050A	\N	\N	2023-09-28 17:11:59
53460	2015-09-26 00:00:00	10	\N	2019-01-01 00:00:00	ANCIEN	\N	Nouveau	\N	\N	\N	\N	\N	REGION	21091K	\N	\N	\N
53563	1499-12-31 00:50:39	26	1500-01-01 00:00:00	1599-11-06 00:50:39	ANCIEN	\N	\N	\N	\N	\N	\N	0	REGION	21060C	\N	\N	2023-09-26 16:41:46
53677	1500-01-01 00:00:00	10	1500-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	1500	\N	0	REGION	21071F	\N	\N	2023-09-28 11:32:24
53470	1499-12-31 00:50:39	29	1500-01-01 00:00:00	1599-12-31 00:50:39	ANCIEN	\N	\N	\N	\N	\N	\N	0	REGION	21041Y	\N	\N	2023-10-09 08:47:39
53799	1499-12-31 00:50:39	10	1500-01-01 00:00:00	2024-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	\N	\N	0	REGION	21079P	\N	\N	2023-10-02 10:53:25
53794	1500-01-01 00:00:00	27	1500-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	1500	\N	0	REGION	21082J	\N	\N	2023-10-09 12:26:43
53829	1499-12-31 00:50:39	26	1500-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	\N	\N	0	REGION	21083K	\N	\N	2023-10-02 16:49:59
53476	1499-12-31 00:50:39	26	1500-01-01 00:00:00	1515-10-25 00:50:39	ANCIEN	\N	\N	\N	\N	\N	\N	0	REGION	15197G	\N	\N	2023-09-26 15:52:27
53538	1500-01-01 00:00:00	26	1500-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	1500	\N	0	REGION	21087P	\N	\N	2023-09-26 16:22:21
53781	1500-01-01 00:00:00	13	1500-01-01 00:00:00	1600-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	1500	1600	0	REGION	21082J	\N	\N	2023-10-09 12:26:43
\.


--
-- Data for Name: elusen; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY elusen (eluid, dptnum, eludatdeb, eludatelu, eludatfin, etadebmancod, etafinmancod, temvalcod, evelic, evelib, evelil, eluanndeb, eluannfin, typmancod, senmat, eludatcum, turelucod, syscredat, sysmajdat) FROM stdin;
536	250	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	80041C	\N	NR	\N	\N
537	40	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	80043E	\N	NR	\N	\N
451	335	1988-05-11 00:00:00	\N	1993-04-29 00:00:00	REMPLACE	CESMEMGVT	ANCIEN	\N	\N	En remplacement de M. Emile Tricon, démissionnaire	\N	\N	SENAT	77053G	\N	RP	\N	\N
454	265	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-02-12 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	2004	SENAT	95053J	\N	RP	\N	\N
455	999	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	86042E	\N	RP	\N	\N
456	999	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	86042E	\N	RP	\N	\N
457	10	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	89016Q	\N	NR	\N	\N
458	620	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	83047W	\N	RP	\N	\N
459	620	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	83047W	\N	RP	\N	\N
460	310	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	80033C	\N	RP	\N	\N
461	310	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	80033C	\N	RP	\N	\N
462	770	1995-10-02 00:00:00	1995-09-24 00:00:00	1999-11-27 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	1999	SENAT	95054K	\N	RP	\N	\N
463	870	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95055L	\N	NR	\N	\N
464	130	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	89036U	\N	RP	\N	\N
465	260	1996-09-04 00:00:00	\N	1998-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de Gérard Gaud, décédé	\N	\N	SENAT	96006F	\N	NR	\N	\N
466	615	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	95056M	\N	RP	\N	\N
467	270	1983-05-06 00:00:00	\N	1989-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. René TOMASINI, décédé	\N	\N	SENAT	83004K	\N	NR	\N	\N
468	270	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	83004K	\N	NR	\N	\N
469	824	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	95057N	\N	RP	\N	\N
470	420	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	92041R	\N	RP	\N	\N
471	880	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	77058M	\N	NR	\N	\N
472	880	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	77058M	\N	NR	\N	\N
473	880	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	77058M	\N	NR	\N	\N
474	250	1988-03-31 00:00:00	\N	1989-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Edgar FAURE, décédé	\N	\N	SENAT	88002E	\N	NR	\N	\N
475	250	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	REN1	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	88002E	\N	NR	\N	\N
476	710	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	86043F	\N	NR	\N	\N
477	710	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	86043F	\N	NR	\N	\N
478	615	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	95058P	\N	RP	\N	\N
479	570	1996-09-10 00:00:00	\N	2001-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de Charles Metzinger, décédé	\N	\N	SENAT	96007G	\N	RP	\N	\N
480	120	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	80035E	\N	NR	\N	\N
481	120	1989-10-02 00:00:00	1989-09-24 00:00:00	1993-04-29 00:00:00	REN1	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	80035E	1993-03-29 00:00:00	NR	\N	2016-12-14 15:27:17
483	120	1996-01-07 00:00:00	\N	1998-09-30 00:00:00	REELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	80035E	\N	NR	\N	\N
484	860	1995-10-02 00:00:00	1995-09-24 00:00:00	1995-10-31 00:00:00	ELECTION	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	95059Q	\N	NR	\N	\N
486	860	1997-09-21 00:00:00	\N	2002-06-06 00:00:00	ELECTION	CESPREMIN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95059Q	\N	NR	\N	\N
487	890	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	86044G	\N	NR	\N	\N
488	890	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	86044G	\N	NR	\N	\N
491	570	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	74042Q	\N	RP	\N	\N
492	570	1983-10-03 00:00:00	1983-09-25 00:00:00	1988-07-27 00:00:00	REN1	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	74042Q	1988-06-23 00:00:00	RP	\N	2016-12-14 15:27:37
410	130	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	78010Y	\N	RP	\N	\N
411	460	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	92039X	\N	NR	\N	\N
412	850	1987-02-27 00:00:00	\N	1995-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Louis CAIVEAU, décédé	\N	\N	SENAT	87002A	\N	NR	\N	\N
413	850	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	87002A	\N	NR	\N	\N
414	860	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-04-29 00:00:00	ELECTION	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	68036E	\N	NR	\N	\N
416	860	1977-09-02 00:00:00	1977-09-02 00:00:00	1977-11-01 00:00:00	ELECTION	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	68036E	\N	NR	\N	\N
418	860	1981-09-19 00:00:00	1981-09-19 00:00:00	1986-04-19 00:00:00	ELECTION	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	68036E	\N	NR	\N	\N
420	860	1986-10-02 00:00:00	1986-09-28 00:00:00	1986-11-01 00:00:00	ELECTION	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	68036E	\N	NR	\N	\N
422	860	1988-09-04 00:00:00	1988-09-04 00:00:00	1995-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	68036E	\N	NR	\N	\N
423	860	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	68036E	\N	NR	\N	\N
424	230	1973-06-27 00:00:00	\N	1980-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Paul PAULY, décédé	\N	\N	SENAT	73006G	\N	NR	\N	\N
425	230	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	REN	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	73006G	\N	NR	\N	\N
426	230	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	73006G	\N	NR	\N	\N
427	205	1997-03-08 00:00:00	\N	1998-09-30 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. François Giacobbi, décédé.	\N	\N	SENAT	97002F	\N	NR	\N	\N
428	190	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	80031A	\N	NR	\N	\N
429	190	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	80031A	\N	NR	\N	\N
430	540	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	92040Q	\N	RP	\N	\N
431	420	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	83046V	\N	RP	\N	\N
432	420	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	REN1	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	83046V	\N	RP	\N	\N
433	828	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-04-30 00:00:00	ELECTION	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	95051G	2004-03-31 00:00:00	RP	\N	\N
434	999	1974-10-02 00:00:00	1974-10-02 00:00:00	1977-10-02 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	74032N	\N	RP	\N	\N
435	999	1977-10-03 00:00:00	1977-10-03 00:00:00	1986-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	74032N	\N	RP	\N	\N
436	999	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	74032N	\N	RP	\N	\N
437	999	1995-10-02 00:00:00	1995-09-24 00:00:00	2001-10-10 00:00:00	REN3	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	74032N	\N	RP	\N	\N
438	670	1991-11-04 00:00:00	\N	1995-09-23 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Paul Kauss, décédé	\N	\N	SENAT	91002E	\N	RP	\N	\N
439	670	1995-10-02 00:00:00	1995-09-24 00:00:00	1995-12-16 00:00:00	REN1	ANNCC	ANCIEN	\N	\N	\N	\N	\N	SENAT	91002E	\N	RP	\N	\N
441	670	1996-02-11 00:00:00	\N	2004-09-30 00:00:00	REELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	91002E	\N	RP	\N	\N
442	973	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	89035T	\N	NR	\N	\N
443	850	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	86041D	\N	NR	\N	\N
444	850	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	REN1	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	86041D	\N	NR	\N	\N
445	760	1988-07-14 00:00:00	\N	1995-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. André DUROMEA, élu député	\N	\N	SENAT	88006J	\N	RP	\N	\N
446	760	1995-10-02 00:00:00	1995-09-24 00:00:00	1998-10-02 00:00:00	REN1	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	88006J	\N	RP	\N	\N
409	130	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	78010Y	\N	RP	\N	\N
363	265	1986-09-28 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	86037H	\N	RP	\N	\N
364	265	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	REN1	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	86037H	\N	RP	\N	\N
365	680	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	95045J	\N	RP	\N	\N
366	982	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	92033R	\N	NR	\N	\N
367	720	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	77043E	\N	NR	\N	\N
368	720	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	77043E	\N	NR	\N	\N
369	720	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	77043E	\N	NR	\N	\N
370	824	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	77044F	\N	RP	\N	\N
371	824	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	77044F	\N	RP	\N	\N
372	824	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	77044F	\N	RP	\N	\N
373	510	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	83040P	\N	NR	\N	\N
374	510	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	83040P	\N	NR	\N	\N
375	350	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	80026D	\N	RP	\N	\N
376	350	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	80026D	\N	RP	\N	\N
377	330	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	80027E	\N	RP	\N	\N
378	330	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	80027E	\N	RP	\N	\N
379	775	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95046K	\N	RP	\N	\N
380	450	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	74028S	\N	NR	\N	\N
381	450	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	74028S	\N	NR	\N	\N
382	450	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	74028S	\N	NR	\N	\N
383	998	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	92034S	\N	RP	\N	\N
384	240	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	80028F	\N	NR	\N	\N
385	240	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	80028F	\N	NR	\N	\N
386	600	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	92035T	\N	NR	\N	\N
387	660	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	92036U	\N	NR	\N	\N
388	800	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95047L	\N	NR	\N	\N
389	760	1995-07-06 00:00:00	\N	1995-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M.Tony Larue, décédé	\N	\N	SENAT	95003X	\N	RP	\N	\N
390	760	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95003X	\N	RP	\N	\N
1936	510	1976-03-19 00:00:00	\N	1983-10-02 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Jean COLLERY, décédé	\N	\N	SENAT	59214D	\N	NR	\N	\N
1937	510	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59214D	\N	NR	\N	\N
1939	830	1972-12-06 00:00:00	\N	1977-10-02 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. Edouard Le Bellegou, décédé	\N	\N	SENAT	57716N	\N	RP	\N	\N
1941	610	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59215E	\N	NR	\N	\N
1942	610	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59215E	\N	NR	\N	\N
1943	610	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	REN2	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	59215E	\N	NR	\N	\N
1945	130	1974-01-01 00:00:00	\N	1980-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Roger DELAGNES	\N	\N	SENAT	000376	\N	RP	\N	\N
1946	130	1980-10-02 00:00:00	1980-09-28 00:00:00	1983-05-10 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000376	\N	RP	\N	\N
51100	440	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	11065P	\N	RP	2017-09-24 00:00:00	\N
51105	490	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	10006L	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
1952	999	1955-06-28 00:00:00	\N	1959-05-05 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000037	\N	RP	\N	\N
1953	999	1959-05-05 00:00:00	1959-05-05 00:00:00	1968-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000037	\N	RP	\N	\N
1954	999	1968-10-02 00:00:00	1968-10-02 00:00:00	1974-03-11 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000037	\N	RP	\N	\N
1956	830	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59520L	\N	RP	\N	\N
51106	490	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19545Y	\N	RP	2017-09-24 00:00:00	\N
1959	30	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000012	\N	NR	\N	\N
1960	30	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-03-06 00:00:00	REN2	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000012	\N	NR	\N	\N
1963	1011	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000146	\N	NR	\N	\N
1964	1011	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000146	\N	NR	\N	\N
1965	1011	1962-10-02 00:00:00	1962-09-23 00:00:00	1969-08-22 00:00:00	REN3	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000146	\N	NR	\N	\N
1967	50	1968-10-25 00:00:00	\N	1971-10-01 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. Ludovic TRON, décédé	\N	\N	SENAT	000051	\N	NR	\N	\N
283	840	1996-06-23 00:00:00	\N	2004-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95037J	\N	NR	\N	\N
284	500	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-23 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	92025R	\N	NR	\N	\N
285	990	1977-10-02 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	77028F	\N	NR	\N	\N
286	990	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	77028F	\N	NR	\N	\N
287	990	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	77028F	\N	NR	\N	\N
288	740	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95038K	\N	NR	\N	\N
289	550	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	74022L	\N	NR	\N	\N
290	550	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	74022L	\N	NR	\N	\N
291	550	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	74022L	\N	NR	\N	\N
292	570	1997-07-05 00:00:00	\N	2001-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Jean-Pierre Masseret nommé membre du Gouvernement	\N	\N	SENAT	97008M	\N	RP	\N	\N
293	670	1977-10-02 00:00:00	1977-09-25 00:00:00	1978-05-05 00:00:00	ELECTION	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	77029G	1978-04-03 00:00:00	RP	\N	2016-12-14 15:21:47
295	670	1981-10-02 00:00:00	1981-09-27 00:00:00	1986-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	77029G	\N	RP	\N	\N
296	670	1986-10-02 00:00:00	1986-09-28 00:00:00	1993-04-29 00:00:00	REN	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	77029G	1993-03-29 00:00:00	RP	\N	2016-12-14 15:21:55
298	670	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	77029G	\N	RP	\N	\N
299	490	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	83035S	\N	NR	\N	\N
300	490	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	83035S	\N	NR	\N	\N
301	70	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	80021X	\N	NR	\N	\N
11481	110	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	80013X	\N	SM1	\N	2014-09-28 13:32:35
302	70	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	80021X	\N	NR	\N	\N
303	490	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	92026S	\N	NR	\N	\N
304	620	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-23 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	92027T	\N	RP	\N	\N
305	540	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	83036T	\N	RP	\N	\N
306	540	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	REN1	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	83036T	\N	RP	\N	\N
307	570	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	83037U	\N	RP	\N	\N
308	570	1992-10-02 00:00:00	1992-09-27 00:00:00	2000-04-28 00:00:00	REN1	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	83037U	\N	RP	\N	\N
309	770	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95039L	\N	RP	\N	\N
310	390	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	74024N	\N	NR	\N	\N
311	390	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	74024N	\N	NR	\N	\N
312	390	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-02-07 00:00:00	REN2	DECEDE	ANCIEN	\N	\N	\N	\N	2001	SENAT	74024N	\N	NR	\N	\N
313	490	1983-10-02 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	83038V	\N	NR	\N	\N
314	490	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	REN1	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	83038V	\N	NR	\N	\N
315	700	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	95040D	\N	NR	\N	\N
317	390	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	REN1	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	89004L	\N	NR	\N	\N
556	510	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	83056X	\N	NR	\N	\N
557	510	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	83056X	\N	NR	\N	\N
558	974	1996-04-15 00:00:00	\N	2001-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	96003C	\N	NR	\N	\N
559	340	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	89043T	\N	NR	\N	\N
560	340	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	80048K	\N	NR	\N	\N
561	340	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	80048K	\N	NR	\N	\N
562	130	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	89044U	\N	RP	\N	\N
563	999	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	86050E	\N	RP	\N	\N
564	999	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	86050E	\N	RP	\N	\N
565	180	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	89045V	\N	NR	\N	\N
566	760	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-07-19 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95066P	\N	RP	\N	\N
538	40	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	80043E	\N	NR	\N	\N
494	570	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	74042Q	\N	RP	\N	\N
495	1026	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	80036F	\N	NR	\N	\N
496	1026	1989-10-02 00:00:00	\N	1998-09-30 00:00:00	REN1	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	80036F	\N	NR	\N	\N
497	590	1985-04-02 00:00:00	\N	1992-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Gérard EHLERS, démissionnaire	\N	\N	SENAT	85002R	\N	RP	\N	\N
498	590	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	85002R	\N	RP	\N	\N
267	430	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	78006D	\N	NR	\N	\N
268	280	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	89031P	\N	NR	\N	\N
269	670	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95036H	\N	RP	\N	\N
270	210	1998-02-26 00:00:00	\N	1998-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Bernard BARBIER, décédé	\N	\N	SENAT	98003L	\N	NR	\N	\N
271	250	1988-09-04 00:00:00	\N	1989-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M.Robert Schwint élu député	\N	\N	SENAT	88009M	\N	NR	\N	\N
272	250	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	88009M	\N	NR	\N	\N
184	520	1981-07-26 00:00:00	1981-07-26 00:00:00	1983-10-02 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	81007E	\N	NR	\N	\N
185	520	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	81007E	\N	NR	\N	\N
186	520	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	81007E	\N	NR	\N	\N
187	870	1990-10-02 00:00:00	1990-09-30 00:00:00	1995-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	90004C	\N	NR	\N	\N
188	870	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	90004C	\N	NR	\N	\N
189	800	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	95023C	\N	NR	\N	\N
190	775	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95024D	\N	RP	\N	\N
229	240	1997-01-13 00:00:00	\N	1998-09-30 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. Yves GUENA, nommé membre du Conseil Constitutionnel	\N	\N	SENAT	97001E	\N	NR	\N	\N
191	800	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95025E	\N	NR	\N	\N
192	220	1997-09-07 00:00:00	\N	1998-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	97010F	\N	NR	\N	\N
193	590	1997-07-03 00:00:00	\N	2001-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Jacques BIALSKI, démissionnaire	\N	\N	SENAT	97007L	\N	RP	\N	\N
194	380	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	83028T	\N	RP	\N	\N
195	380	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	REN1	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	83028T	\N	RP	\N	\N
196	972	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	86021Y	\N	NR	\N	\N
197	972	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	REN1	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	86021Y	\N	NR	\N	\N
198	440	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	92019T	\N	RP	\N	\N
199	590	1965-09-26 00:00:00	1965-09-26 00:00:00	1974-09-21 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	65017N	\N	RP	\N	\N
201	590	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	65017N	\N	RP	\N	\N
202	590	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	REN1	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	65017N	\N	RP	\N	\N
203	615	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	95026F	\N	RP	\N	\N
204	170	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	89014N	\N	NR	\N	\N
205	125	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	80017C	\N	NR	\N	\N
206	125	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	80017C	\N	NR	\N	\N
208	840	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	87003B	\N	NR	\N	\N
209	335	1997-06-13 00:00:00	\N	2000-03-28 00:00:00	REMPLACE	CESMEMGVT	ANCIEN	\N	\N	En remplacement de Mme Jacqueline Fraysse-Cazalis, élue député. 	\N	\N	SENAT	97003G	\N	RP	\N	\N
210	265	1995-10-02 00:00:00	1995-09-24 00:00:00	2001-01-16 00:00:00	ELECTION	DECCC	ANCIEN	\N	\N	\N	\N	\N	SENAT	95027G	\N	RP	\N	\N
211	790	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95028H	\N	NR	\N	\N
212	140	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	89007P	\N	NR	\N	\N
214	999	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	90002A	\N	RP	\N	\N
215	650	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	92020L	\N	NR	\N	\N
216	330	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	89025R	\N	RP	\N	\N
217	330	1993-08-28 00:00:00	\N	1998-09-30 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. BOEUF, décédé	\N	\N	SENAT	93006S	\N	RP	\N	\N
218	680	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	95029J	\N	RP	\N	\N
219	350	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	89026S	\N	RP	\N	\N
220	10	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	89027T	\N	NR	\N	\N
221	710	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95030B	\N	NR	\N	\N
222	615	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	86025D	\N	RP	\N	\N
223	615	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	86025D	\N	RP	\N	\N
224	830	1995-10-02 00:00:00	1995-09-24 00:00:00	2002-07-17 00:00:00	ELECTION	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	95031C	\N	RP	\N	\N
225	620	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	92021M	\N	RP	\N	\N
226	410	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	92022N	\N	NR	\N	\N
227	380	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	83031N	\N	RP	\N	\N
228	380	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	83031N	\N	RP	\N	\N
183	340	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	80015A	\N	NR	\N	\N
139	615	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	77013X	\N	RP	\N	\N
140	615	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	77013X	\N	RP	\N	\N
141	615	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	77013X	\N	RP	\N	\N
142	230	1981-09-27 00:00:00	1981-09-27 00:00:00	1989-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	81010Y	\N	NR	\N	\N
143	230	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	81010Y	\N	NR	\N	\N
144	720	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95019G	\N	NR	\N	\N
145	824	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	86018E	\N	RP	\N	\N
146	824	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	86018E	\N	RP	\N	\N
147	30	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	71009B	\N	NR	\N	\N
148	30	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	REN	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	71009B	\N	NR	\N	\N
149	30	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	71009B	\N	NR	\N	\N
150	270	1981-09-30 00:00:00	\N	1989-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Gustave HEON, décédé	\N	\N	SENAT	81014D	\N	NR	\N	\N
151	270	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	81014D	\N	NR	\N	\N
152	820	1988-07-31 00:00:00	1988-07-31 00:00:00	1995-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	88008L	\N	NR	\N	\N
153	820	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	88008L	\N	NR	\N	\N
154	440	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	83023N	\N	RP	\N	\N
155	440	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	83023N	\N	RP	\N	\N
156	110	1974-12-08 00:00:00	1974-12-08 00:00:00	1980-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	74050Q	\N	NR	\N	\N
157	110	1980-10-02 00:00:00	1980-09-28 00:00:00	1981-07-22 00:00:00	REN1	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	74050Q	\N	NR	\N	\N
159	110	1986-10-02 00:00:00	1986-09-28 00:00:00	1989-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	74050Q	\N	NR	\N	\N
160	110	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	74050Q	\N	NR	\N	\N
161	110	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	80013X	\N	NR	\N	\N
162	110	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	80013X	\N	NR	\N	\N
163	710	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95020Y	\N	NR	\N	\N
164	998	1974-10-02 00:00:00	1974-10-02 00:00:00	1983-10-02 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	74019R	\N	RP	\N	\N
165	998	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-09-26 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	74019R	\N	RP	\N	\N
166	998	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	74019R	\N	RP	\N	\N
167	850	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95021A	\N	NR	\N	\N
168	350	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	80014Y	\N	RP	\N	\N
169	350	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	80014Y	\N	RP	\N	\N
170	775	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	77017C	\N	RP	\N	\N
171	775	1986-10-02 00:00:00	1986-09-28 00:00:00	1991-05-16 00:00:00	REN	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	77017C	\N	RP	\N	\N
173	775	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	77017C	\N	RP	\N	\N
174	620	1986-08-01 00:00:00	\N	1992-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Henri ELBY, décédé	\N	\N	SENAT	86004X	\N	RP	\N	\N
175	620	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	86004X	\N	RP	\N	\N
176	440	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	83025Q	\N	RP	\N	\N
177	440	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	83025Q	\N	RP	\N	\N
178	370	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	83026R	\N	NR	\N	\N
179	370	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	REN1	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	83026R	\N	NR	\N	\N
180	615	1995-10-02 00:00:00	1995-09-24 00:00:00	2001-03-27 00:00:00	ELECTION	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	95022B	\N	RP	\N	\N
181	620	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	92017R	\N	RP	\N	\N
182	340	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	80015A	\N	NR	\N	\N
138	720	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	77012W	\N	NR	\N	\N
94	140	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	70001N	\N	NR	\N	\N
95	140	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	REN3	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	70001N	\N	NR	\N	\N
96	460	1988-06-13 00:00:00	\N	1992-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Maurice FAURE, nommé membre du Gouvernement	\N	\N	SENAT	88004G	\N	NR	\N	\N
97	460	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	88004G	\N	NR	\N	\N
98	380	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	83018R	\N	RP	\N	\N
1969	335	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	58614M	\N	RP	\N	\N
1971	615	1972-09-15 00:00:00	\N	1977-10-02 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Albert CHAVANAC, décédé	\N	\N	SENAT	000098	\N	RP	\N	\N
1973	190	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-09-22 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000292	\N	NR	\N	\N
1974	190	1962-10-02 00:00:00	1962-09-23 00:00:00	1968-01-06 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	1962	SENAT	000292	\N	NR	\N	\N
1977	895	1974-06-29 00:00:00	\N	1977-10-02 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. Jacques SOUFFLET, nommé membre du Gouvernement	\N	\N	SENAT	57741P	\N	RP	\N	\N
1979	1026	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000016	\N	NR	\N	\N
1921	973	1978-06-10 00:00:00	\N	1980-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Léopold HEDER, décédé	\N	\N	SENAT	000448	\N	NR	\N	\N
1924	720	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59533R	\N	NR	\N	\N
1925	720	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59533R	\N	NR	\N	\N
539	280	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	89009R	\N	NR	\N	\N
540	824	1997-06-13 00:00:00	\N	2004-09-30 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. Claude Billard, élu député	\N	\N	SENAT	97005J	\N	RP	\N	\N
1927	660	1982-10-23 00:00:00	\N	1983-10-02 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Léon Jean GREGORY, décédé	\N	\N	SENAT	58343H	\N	NR	\N	\N
1929	660	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	59213C	\N	NR	\N	\N
1931	615	1976-02-17 00:00:00	\N	1977-10-02 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Jean LEGARET, décédé	\N	\N	SENAT	57773X	\N	RP	\N	\N
1933	340	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000087	\N	NR	\N	\N
541	70	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	80045G	\N	NR	\N	\N
542	70	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	80045G	\N	NR	\N	\N
543	690	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	86047K	\N	RP	\N	\N
544	690	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	86047K	\N	RP	\N	\N
545	830	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	86049M	\N	RP	\N	\N
546	830	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	86049M	\N	RP	\N	\N
547	984	1998-04-06 00:00:00	\N	1998-09-30 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. Sosefo Makapé Papilio, décédé	\N	\N	SENAT	98004M	\N	NR	\N	\N
548	590	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	92044U	\N	RP	\N	\N
549	615	1993-04-18 00:00:00	\N	1995-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	93003P	\N	RP	\N	\N
550	615	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	93003P	\N	RP	\N	\N
551	330	1980-10-02 00:00:00	1980-09-28 00:00:00	1987-02-19 00:00:00	ELECTION	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	80046H	1987-01-20 00:00:00	RP	\N	2016-12-14 15:31:25
553	330	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	80046H	\N	RP	\N	\N
554	130	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	89042S	\N	RP	\N	\N
11478	205	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	05011Y	\N	SM1	\N	2014-09-28 13:47:05
555	600	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	92045V	\N	NR	\N	\N
499	995	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	95061J	\N	NR	\N	\N
500	760	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95062K	\N	RP	\N	\N
501	210	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	89037V	\N	NR	\N	\N
502	670	1992-09-28 00:00:00	1992-09-27 00:00:00	1995-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	92005M	\N	RP	\N	\N
503	670	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	92005M	\N	RP	\N	\N
504	150	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	89038W	\N	NR	\N	\N
505	730	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	77060F	\N	NR	\N	\N
507	730	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	77060F	\N	NR	\N	\N
508	265	1988-05-14 00:00:00	\N	1995-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M.Jean COLIN, démissionnaire	\N	\N	SENAT	88003F	\N	RP	\N	\N
509	265	1995-10-02 00:00:00	1995-09-24 00:00:00	2000-03-18 00:00:00	REN1	DECEDE	ANCIEN	\N	\N	\N	\N	2000	SENAT	88003F	\N	RP	\N	\N
510	130	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	89039X	\N	RP	\N	\N
512	560	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	83050R	\N	NR	\N	\N
513	560	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	83050R	\N	NR	\N	\N
514	310	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	80039J	\N	RP	\N	\N
515	310	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	80039J	\N	RP	\N	\N
516	300	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	80040B	\N	NR	\N	\N
517	300	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	80040B	\N	NR	\N	\N
518	550	1983-09-25 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	83052T	\N	NR	\N	\N
519	550	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	83052T	\N	NR	\N	\N
520	1026	1989-10-02 00:00:00	\N	1998-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	89040Q	\N	NR	\N	\N
521	335	1993-05-01 00:00:00	\N	1995-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Charles PASQUA, nommé membre du Gouvernement	\N	\N	SENAT	93005R	\N	RP	\N	\N
522	335	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	REN1	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	93005R	\N	RP	\N	\N
523	120	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	89041R	\N	NR	\N	\N
524	620	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	92043T	\N	RP	\N	\N
525	690	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	77066M	\N	RP	\N	\N
526	690	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	77066M	\N	RP	\N	\N
527	690	1995-10-02 00:00:00	1995-09-24 00:00:00	1999-11-01 00:00:00	REN2	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	77066M	\N	RP	\N	\N
528	580	1986-12-18 00:00:00	\N	1992-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Noël BERRIER, décédé	\N	\N	SENAT	86053H	\N	NR	\N	\N
529	580	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	86053H	\N	NR	\N	\N
530	470	1981-01-04 00:00:00	\N	1983-10-02 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Jacques BORDENEUVE, décédé	\N	\N	SENAT	81001X	\N	NR	\N	\N
531	470	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	81001X	\N	NR	\N	\N
532	470	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	81001X	\N	NR	\N	\N
533	600	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	83054V	\N	NR	\N	\N
534	600	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	83054V	\N	NR	\N	\N
535	250	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	80041C	\N	NR	\N	\N
2306	998	1959-05-05 00:00:00	1959-05-05 00:00:00	1965-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000003	\N	RP	\N	\N
11360	830	2008-04-19 00:00:00	\N	2010-12-13 00:00:00	REMPLACE	CESMAN	ANCIEN	\N	\N	En remplacement de M. Hubert Falco, nommé membre du Gouvernement	\N	\N	SENAT	08007R	\N	RP	\N	\N
2307	998	1965-10-02 00:00:00	1965-10-02 00:00:00	1974-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000003	\N	RP	\N	\N
2310	775	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	59569E	\N	RP	\N	\N
2312	320	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	58936D	\N	NR	\N	\N
2314	775	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000350	\N	RP	\N	\N
2317	895	1985-09-02 00:00:00	\N	1986-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Jacques TOUTAIN, décédé	\N	\N	SENAT	59570W	\N	RP	\N	\N
2318	895	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN1	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	59570W	\N	RP	\N	\N
2320	280	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000327	\N	NR	\N	\N
2321	280	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000327	\N	NR	\N	\N
2325	480	1985-05-28 00:00:00	\N	1992-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Jules ROUJON, décédé	\N	\N	SENAT	000510	\N	NR	\N	\N
2326	480	1992-10-02 00:00:00	1992-09-27 00:00:00	1994-09-09 00:00:00	REN1	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000510	\N	NR	\N	\N
2328	310	1971-10-02 00:00:00	1971-09-26 00:00:00	1974-07-09 00:00:00	ELECTION	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	58202U	\N	RP	\N	\N
2330	120	1993-05-01 00:00:00	\N	1995-11-09 00:00:00	REMPLACE	DEM	ANCIEN	\N	\N	En remplacement de M. Jean Puech, nommé membre du Gouvernement	\N	\N	SENAT	59601L	\N	NR	\N	\N
2332	265	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	58657Y	\N	RP	\N	\N
2334	890	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59571X	\N	NR	\N	\N
2335	890	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN1	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	59571X	\N	NR	\N	\N
2337	690	1968-10-02 00:00:00	1968-09-22 00:00:00	1974-08-26 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000111	\N	RP	\N	\N
2339	430	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	83022M	\N	NR	\N	\N
2340	430	1992-10-02 00:00:00	1992-09-27 00:00:00	1996-01-24 00:00:00	REN1	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	83022M	\N	NR	\N	\N
2344	190	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000061	\N	NR	\N	\N
2345	190	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000061	\N	NR	\N	\N
2346	190	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000061	\N	NR	\N	\N
2347	190	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	REN	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000061	\N	NR	\N	\N
2351	630	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000038	\N	NR	\N	\N
2352	630	1965-10-02 00:00:00	1965-09-26 00:00:00	1967-03-08 00:00:00	REN2	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000038	\N	NR	\N	\N
2354	450	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000191	\N	NR	\N	\N
2355	450	1959-04-28 00:00:00	\N	1965-08-19 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000191	\N	NR	\N	\N
318	700	1995-10-02 00:00:00	1995-09-24 00:00:00	2002-06-18 00:00:00	ELECTION	CESDEPUTE	ANCIEN	\N	\N	\N	\N	\N	SENAT	95041E	\N	NR	\N	\N
273	997	1969-03-21 00:00:00	\N	1971-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Henri LONGCHAMBON, décédé	\N	\N	SENAT	69001W	\N	RP	\N	\N
230	690	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95032D	\N	RP	\N	\N
231	80	1996-07-09 00:00:00	\N	1998-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Jacques Sourdille décédé	\N	\N	SENAT	96005E	\N	NR	\N	\N
232	335	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	77019E	\N	RP	\N	\N
233	335	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	77019E	\N	RP	\N	\N
234	335	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	77019E	\N	RP	\N	\N
235	420	1997-11-19 00:00:00	\N	2001-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. François Mathieu, décédé	\N	1968	SENAT	97011G	\N	RP	\N	\N
236	590	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	92023P	\N	RP	\N	\N
237	890	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	95033E	\N	NR	\N	\N
239	770	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	83003J	\N	RP	\N	\N
240	770	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	83003J	\N	RP	\N	\N
241	470	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	83033Q	\N	NR	\N	\N
242	470	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	83033Q	\N	NR	\N	\N
243	100	1994-07-16 00:00:00	\N	1998-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Bernard LAURENT, décédé	\N	\N	SENAT	94003T	\N	NR	\N	\N
1984	125	1971-10-02 00:00:00	1971-09-26 00:00:00	1971-11-02 00:00:00	ELECTION	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	000490	\N	NR	\N	\N
1987	590	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000339	\N	RP	\N	\N
1988	590	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000339	\N	RP	\N	\N
1989	590	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000339	\N	RP	\N	\N
1990	590	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	REN3	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000339	\N	RP	\N	\N
1993	830	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000115	\N	RP	\N	\N
1994	830	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000115	\N	RP	\N	\N
1997	971	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	59564Y	\N	NR	\N	\N
1999	210	1979-07-06 00:00:00	\N	1980-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. André PICARD, décédé	\N	\N	SENAT	79005G	\N	NR	\N	\N
2000	210	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	79005G	\N	NR	\N	\N
2001	210	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-02-25 00:00:00	REN2	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	79005G	\N	NR	\N	\N
2003	580	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000282	\N	NR	\N	\N
2006	620	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58109Y	\N	RP	\N	\N
2007	620	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58109Y	\N	RP	\N	\N
2008	620	1965-10-02 00:00:00	1965-09-26 00:00:00	1973-04-01 00:00:00	REN2	CESDEPUTE	ANCIEN	\N	\N	\N	\N	\N	SENAT	58109Y	\N	RP	\N	\N
2010	1029	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000002	\N	NR	\N	\N
2011	335	1968-10-02 00:00:00	1968-09-22 00:00:00	1975-11-08 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000002	\N	RP	\N	\N
2013	999	1986-10-02 00:00:00	1986-09-28 00:00:00	1990-04-11 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000529	\N	RP	\N	\N
2015	630	1967-03-09 00:00:00	\N	1974-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Michel CHAMPLEBOUX, décédé	\N	\N	SENAT	000277	\N	NR	\N	\N
2016	630	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000277	\N	NR	\N	\N
2019	110	1981-07-24 00:00:00	\N	1986-07-16 00:00:00	REMPLACE	DEM	ANCIEN	\N	\N	En remplacement de M. Raymond COURRIERE,  nommé membre du Gouvernement	\N	\N	SENAT	58613L	\N	NR	\N	\N
2021	330	1977-10-05 00:00:00	\N	1980-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Max MONICHON, décédé	\N	\N	SENAT	000032	\N	RP	\N	\N
2024	1029	1959-04-28 00:00:00	1959-04-26 00:00:00	1967-04-03 00:00:00	ELECTION	CESDEPUTE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000400	\N	NR	\N	\N
2026	300	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59721T	\N	NR	\N	\N
2027	300	1989-10-02 00:00:00	1989-09-24 00:00:00	1992-10-14 00:00:00	REN	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	59721T	1992-10-02 00:00:00	NR	\N	2016-12-14 15:17:35
2029	998	1983-10-03 00:00:00	1983-10-03 00:00:00	1992-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000663	\N	RP	\N	\N
2031	1029	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000116	\N	NR	\N	\N
2032	615	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000116	\N	RP	\N	\N
2035	410	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000460	\N	NR	\N	\N
2036	410	1983-10-03 00:00:00	1983-09-25 00:00:00	1986-09-09 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000460	\N	NR	\N	\N
2038	290	1980-10-02 00:00:00	1980-09-28 00:00:00	1986-04-02 00:00:00	ELECTION	CESDEPUTE	ANCIEN	\N	\N	\N	\N	\N	SENAT	58819Y	\N	RP	\N	\N
2040	650	1959-04-28 00:00:00	1959-04-26 00:00:00	1960-10-23 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000054	\N	NR	\N	\N
2042	630	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59217G	\N	NR	\N	\N
2044	630	1988-07-29 00:00:00	\N	1992-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Michel CHARASSE, nommé membre du Gouvernement	\N	\N	SENAT	59217G	\N	NR	\N	\N
2046	974	1983-10-03 00:00:00	1983-09-25 00:00:00	1987-02-02 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000541	\N	NR	\N	\N
2048	360	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000321	\N	NR	\N	\N
2475	1029	1959-04-28 00:00:00	\N	1968-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000173	\N	NR	\N	\N
2476	775	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000173	\N	RP	\N	\N
2479	615	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59529V	\N	RP	\N	\N
2481	997	1971-10-02 00:00:00	1971-10-02 00:00:00	1980-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	71011U	\N	RP	\N	\N
2482	997	1980-10-02 00:00:00	1980-10-02 00:00:00	1989-10-01 00:00:00	REN	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	71011U	\N	RP	\N	\N
2483	997	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-01-19 00:00:00	REN2	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	71011U	\N	RP	\N	\N
2485	850	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59530N	\N	NR	\N	\N
2486	850	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59530N	\N	NR	\N	\N
2488	971	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	58649Y	\N	NR	\N	\N
2490	770	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000397	\N	RP	\N	\N
2491	770	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000397	\N	RP	\N	\N
2492	770	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000397	\N	RP	\N	\N
2493	770	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-03-03 00:00:00	REN3	CESMEMCC	ANCIEN	\N	\N	\N	\N	\N	SENAT	000397	\N	RP	\N	\N
51060	982	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN	NONREELU	ANCIEN	\N	Nouveau	\N	\N	2023	\N	11010L	\N	SM1	2017-09-24 00:00:00	\N
2497	1029	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000416	\N	NR	\N	\N
2498	335	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000416	\N	RP	\N	\N
2501	620	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000524	\N	RP	\N	\N
2502	620	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000524	\N	RP	\N	\N
2503	620	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-01-06 00:00:00	REN2	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000524	\N	RP	\N	\N
2505	660	1987-12-03 00:00:00	\N	1992-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M.Guy MALE, décédé	\N	\N	SENAT	000438	\N	NR	\N	\N
2508	100	1978-11-14 00:00:00	\N	1980-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Henri TERRE, décédé	\N	\N	SENAT	58019X	\N	NR	\N	\N
51061	982	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19319Q	\N	SM1	2017-09-24 00:00:00	\N
51107	490	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19549D	\N	RP	2017-09-24 00:00:00	\N
2512	130	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	57826T	\N	RP	\N	\N
2513	130	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	57826T	\N	RP	\N	\N
2514	130	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	57826T	\N	RP	\N	\N
2515	130	1971-10-02 00:00:00	1971-09-26 00:00:00	1978-10-01 00:00:00	REN	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	57826T	\N	RP	\N	\N
2517	615	1977-10-03 00:00:00	1977-09-25 00:00:00	1979-05-28 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000360	\N	RP	\N	\N
2519	590	1973-09-10 00:00:00	\N	1974-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Emile DUBOIS	\N	\N	SENAT	000031	\N	RP	\N	\N
2520	590	1974-10-02 00:00:00	1974-09-22 00:00:00	1979-04-01 00:00:00	REN	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	000031	\N	RP	\N	\N
2523	590	1969-01-12 00:00:00	\N	1974-03-16 00:00:00	REMPLACE	DEM	ANCIEN	\N	\N	En remplacement de M. Alfred Dehé, décédé	\N	\N	SENAT	000194	\N	RP	\N	\N
2526	130	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000250	\N	RP	\N	\N
2527	130	1962-10-02 00:00:00	1962-09-23 00:00:00	1962-12-13 00:00:00	REN	CESDEPUTE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000250	\N	RP	\N	\N
2530	20	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000245	\N	NR	\N	\N
11484	270	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	98050T	\N	SM1	\N	2014-09-28 18:19:47
2531	20	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000245	\N	NR	\N	\N
2532	20	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN2	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000245	\N	NR	\N	\N
2535	130	1962-12-13 00:00:00	\N	1971-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Gaston DEFERRE	\N	\N	SENAT	000066	\N	RP	\N	\N
2536	130	1971-10-02 00:00:00	1971-09-26 00:00:00	1974-01-01 00:00:00	REN	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	000066	\N	RP	\N	\N
51108	490	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19533U	\N	RP	2017-09-24 00:00:00	\N
2540	530	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000199	\N	NR	\N	\N
2541	530	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN2	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000199	\N	NR	\N	\N
2544	620	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59226H	\N	RP	\N	\N
2546	810	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	59572Y	\N	NR	\N	\N
2548	240	1980-10-02 00:00:00	1980-09-28 00:00:00	1988-02-05 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000621	\N	NR	\N	\N
51111	560	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	16685X	\N	RP	2017-09-24 00:00:00	\N
51112	560	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	11099A	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
2552	690	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000188	\N	RP	\N	\N
2553	690	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000188	\N	RP	\N	\N
2554	690	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000188	\N	RP	\N	\N
2561	1029	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000180	\N	NR	\N	\N
2562	1029	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000180	\N	NR	\N	\N
2564	710	1982-03-21 00:00:00	\N	1986-10-01 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. Marcel MATHY, décédé	\N	\N	SENAT	58670V	\N	NR	\N	\N
2567	140	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000331	\N	NR	\N	\N
2568	140	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000331	\N	NR	\N	\N
2569	140	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000331	\N	NR	\N	\N
2570	140	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	REN	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000331	\N	NR	\N	\N
2571	140	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000331	\N	NR	\N	\N
2574	590	1974-03-16 00:00:00	\N	1974-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Roger DEBLOCK, démissionnaire	\N	\N	SENAT	58367R	\N	RP	\N	\N
2575	590	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	58367R	\N	RP	\N	\N
2577	530	1986-04-21 00:00:00	\N	1988-05-31 00:00:00	REMPLACE	DEM	ANCIEN	\N	\N	En remplacement de M. Jean ARTHUIS, nommé membre du Gouvernement	\N	\N	SENAT	86001U	\N	NR	\N	\N
2579	530	1995-06-19 00:00:00	\N	1997-06-30 00:00:00	REMPLACE	DEM	ANCIEN	\N	\N	En remplacement de M. Jean ARTHUIS, nommé membre du Gouvernement	\N	\N	SENAT	86001U	\N	NR	\N	\N
2581	420	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000084	\N	RP	\N	\N
2582	420	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000084	\N	RP	\N	\N
2585	20	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	58043X	\N	NR	\N	\N
2587	50	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58943C	\N	NR	\N	\N
2588	50	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	58943C	\N	NR	\N	\N
2592	570	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000220	\N	RP	\N	\N
2593	570	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000220	\N	RP	\N	\N
2594	570	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	REN	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000220	\N	RP	\N	\N
2597	420	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	58330C	\N	RP	\N	\N
2599	590	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000322	\N	RP	\N	\N
2600	590	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000322	\N	RP	\N	\N
2601	590	1965-10-02 00:00:00	1965-09-26 00:00:00	1973-09-09 00:00:00	REN2	DECEDE	ANCIEN	\N	\N	\N	\N	1973	SENAT	000322	\N	RP	\N	\N
2603	600	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000203	\N	NR	\N	\N
2604	600	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000203	\N	NR	\N	\N
2605	600	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000203	\N	NR	\N	\N
2608	640	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	59227J	\N	NR	\N	\N
2611	210	1948-11-07 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000105	\N	NR	\N	\N
2612	210	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000105	\N	NR	\N	\N
2614	210	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000105	\N	NR	\N	\N
2617	840	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000164	\N	NR	\N	\N
2622	170	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000011	\N	NR	\N	\N
2623	170	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000011	\N	NR	\N	\N
2624	170	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000011	\N	NR	\N	\N
2625	170	1971-10-02 00:00:00	1971-09-26 00:00:00	1973-03-05 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000011	\N	NR	\N	\N
2627	160	1979-12-08 00:00:00	\N	1980-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Guy PASCAUD, décédé	\N	\N	SENAT	000009	\N	NR	\N	\N
2630	730	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59531P	\N	NR	\N	\N
2632	790	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	59573A	\N	NR	\N	\N
2634	620	1978-10-01 00:00:00	\N	1983-10-02 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Léandre LETOQUART, démissionnaire	\N	\N	SENAT	58420D	\N	RP	\N	\N
2635	620	1983-10-03 00:00:00	1983-09-25 00:00:00	1984-10-02 00:00:00	REN	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	58420D	\N	RP	\N	\N
2637	420	1965-10-02 00:00:00	1965-09-26 00:00:00	1967-04-03 00:00:00	ELECTION	CESDEPUTE	ANCIEN	\N	\N	\N	\N	\N	SENAT	57714L	\N	RP	\N	2016-12-14 15:20:29
2639	420	1983-10-03 00:00:00	1983-09-25 00:00:00	1988-06-12 00:00:00	ELECTION	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	57714L	1988-05-12 00:00:00	RP	\N	2016-12-14 15:20:34
2642	180	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000041	\N	NR	\N	\N
2643	180	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000041	\N	NR	\N	\N
2644	180	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000041	\N	NR	\N	\N
2645	180	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	REN	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000041	\N	NR	\N	\N
2646	180	1980-10-02 00:00:00	1980-09-28 00:00:00	1983-03-28 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000041	\N	NR	\N	\N
2648	850	1959-06-29 00:00:00	\N	1968-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Henri ROCHEREAU	\N	\N	SENAT	000255	\N	NR	\N	\N
2649	850	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	REN	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000255	\N	NR	\N	\N
2655	850	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58643S	\N	NR	\N	\N
2656	850	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	58643S	\N	NR	\N	\N
2658	830	1978-10-06 00:00:00	\N	1981-06-21 00:00:00	REMPLACE	CESDEPUTE	ANCIEN	\N	\N	En remplacement de M. Jean-Jacques PERRON, décédé	\N	\N	SENAT	59509R	\N	RP	\N	\N
2662	620	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000122	\N	RP	\N	\N
2663	620	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000122	\N	RP	\N	\N
2664	620	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	REN	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000122	\N	RP	\N	\N
2665	620	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000122	\N	RP	\N	\N
2668	760	1986-10-02 00:00:00	1986-09-28 00:00:00	1988-07-13 00:00:00	ELECTION	CESDEPUTE	ANCIEN	\N	\N	\N	\N	1988	SENAT	59305F	\N	RP	\N	\N
2670	580	1974-10-02 00:00:00	1974-09-22 00:00:00	1975-12-29 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000106	\N	NR	\N	\N
99	380	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	83018R	\N	RP	\N	\N
100	450	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	74015M	\N	NR	\N	\N
101	450	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	74015M	\N	NR	\N	\N
102	450	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	74015M	\N	NR	\N	\N
103	20	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	71006X	\N	NR	\N	\N
104	20	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	71006X	\N	NR	\N	\N
105	20	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	71006X	\N	NR	\N	\N
106	880	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	95012Y	\N	NR	\N	\N
107	895	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95013A	\N	RP	\N	\N
108	997	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	89023P	\N	RP	\N	\N
109	380	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	83020K	\N	RP	\N	\N
110	380	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	83020K	\N	RP	\N	\N
111	615	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-09-27 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	77009C	\N	RP	\N	\N
112	615	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	77009C	\N	RP	\N	\N
113	615	1995-10-02 00:00:00	1995-09-24 00:00:00	2002-09-30 00:00:00	REN2	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	77009C	\N	RP	\N	\N
114	775	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	86014A	\N	RP	\N	\N
115	775	1995-10-02 00:00:00	1995-09-24 00:00:00	2002-12-10 00:00:00	REN1	DECEDE	ANCIEN	\N	\N	\N	\N	2002	SENAT	86014A	\N	RP	\N	\N
116	130	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	89024Q	\N	RP	\N	\N
118	998	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-09-26 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	77002U	\N	RP	\N	\N
120	740	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95015C	\N	NR	\N	\N
121	400	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	92015P	\N	NR	\N	\N
122	320	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	89008Q	\N	NR	\N	\N
124	640	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	83021L	\N	NR	\N	\N
125	640	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	83021L	\N	NR	\N	\N
126	335	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	95016D	\N	RP	\N	\N
127	998	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	92008Q	\N	RP	\N	\N
128	330	1990-06-15 00:00:00	\N	1998-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Jean-François Pintat, décédé	\N	\N	SENAT	90003B	\N	RP	\N	\N
129	690	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	95017E	\N	RP	\N	\N
130	630	1981-10-28 00:00:00	\N	1983-10-02 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Roger QUILLIOT, nommé membre du Gouvernement	\N	\N	SENAT	81015E	\N	NR	\N	\N
12891	550	2012-06-17 00:00:00	\N	2017-10-01 00:00:00	REPRISE	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	01048V	\N	NR	\N	2017-09-24 19:16:18
131	630	1983-10-03 00:00:00	1983-09-25 00:00:00	1988-07-27 00:00:00	REN1	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	81015E	1988-06-23 00:00:00	NR	\N	2016-12-14 15:18:35
133	630	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	81015E	\N	NR	\N	\N
134	580	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	92016Q	\N	NR	\N	\N
135	615	1995-10-02 00:00:00	1995-09-24 00:00:00	2000-01-27 00:00:00	ELECTION	CESDEPUTE	ANCIEN	\N	\N	\N	\N	\N	SENAT	95018F	\N	RP	\N	\N
136	720	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	77012W	\N	NR	\N	\N
137	720	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	77012W	\N	NR	\N	\N
45	828	1979-06-12 00:00:00	\N	1986-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Fernand CHATELAIN, décédé	\N	\N	SENAT	79004F	\N	RP	\N	\N
1	650	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	83008P	\N	NR	\N	\N
3	895	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95004Y	\N	RP	\N	\N
11482	110	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	06005F	\N	SM1	\N	2014-09-28 13:32:35
391	450	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	83043S	\N	NR	\N	\N
392	450	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	83043S	\N	NR	\N	\N
393	690	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	77047J	\N	RP	\N	\N
394	690	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	77047J	\N	RP	\N	\N
395	690	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	77047J	\N	RP	\N	\N
396	590	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	92037V	\N	RP	\N	\N
397	810	1995-10-02 00:00:00	1995-09-24 00:00:00	1998-11-02 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	1998	SENAT	95048M	\N	NR	\N	\N
398	265	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	86039K	\N	RP	\N	\N
399	265	1995-10-02 00:00:00	1995-09-24 00:00:00	2000-04-27 00:00:00	REN1	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	86039K	2000-03-27 00:00:00	RP	\N	2016-12-14 15:24:14
400	290	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	89034S	\N	RP	\N	\N
401	420	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	83044T	\N	RP	\N	\N
402	420	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	83044T	\N	RP	\N	\N
403	690	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95049N	\N	RP	\N	\N
404	971	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95050F	\N	NR	\N	\N
405	983	1977-01-11 00:00:00	\N	1980-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Pouvanaa OOPA TETUAAPUA, décédé	\N	\N	SENAT	77001T	\N	NR	\N	\N
406	983	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	77001T	\N	NR	\N	\N
407	983	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	77001T	\N	NR	\N	\N
361	210	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-09-23 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	80025C	\N	NR	\N	\N
362	210	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	80025C	\N	NR	\N	\N
320	615	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	77046H	\N	RP	\N	\N
321	615	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	77046H	\N	RP	\N	\N
322	400	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	83039W	\N	NR	\N	\N
323	400	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	83039W	\N	NR	\N	\N
324	828	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	95042F	\N	RP	\N	\N
325	60	1985-05-14 00:00:00	\N	1989-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Francis PALMERO, décédé	\N	\N	SENAT	85003S	\N	RP	\N	\N
326	60	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	85003S	\N	RP	\N	\N
327	130	1995-12-08 00:00:00	\N	1998-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Jean-Claude GAUDIN, membre du gouvernement	\N	\N	SENAT	95068R	\N	RP	\N	\N
329	610	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	92029V	\N	NR	\N	\N
330	824	1988-10-04 00:00:00	\N	1995-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Michel GIRAUD élu député	\N	\N	SENAT	88013H	\N	RP	\N	\N
331	824	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	88013H	\N	RP	\N	\N
332	770	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	77033C	\N	RP	\N	\N
333	770	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	77033C	\N	RP	\N	\N
334	770	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	77033C	\N	RP	\N	\N
335	895	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	86034E	\N	RP	\N	\N
336	895	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-04-30 00:00:00	REN1	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	86034E	2004-03-31 00:00:00	RP	\N	\N
337	971	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	95043G	\N	NR	\N	\N
338	974	1995-07-02 00:00:00	\N	2001-09-23 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. Paul MOREAU, décédé	\N	\N	SENAT	95002W	\N	NR	\N	\N
339	830	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	86035F	\N	RP	\N	\N
340	830	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	86035F	\N	RP	\N	\N
341	560	1981-09-20 00:00:00	1981-09-20 00:00:00	1983-09-24 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	81011A	\N	NR	\N	\N
342	560	1983-10-02 00:00:00	1983-09-25 00:00:00	1992-09-26 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	81011A	\N	NR	\N	\N
343	560	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	81011A	\N	NR	\N	\N
344	500	1982-04-04 00:00:00	\N	1983-10-02 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Auguste Cousin, décédé	\N	\N	SENAT	82002D	\N	NR	\N	\N
345	500	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	82002D	\N	NR	\N	\N
346	500	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	82002D	\N	NR	\N	\N
347	290	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-09-27 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	71024A	\N	RP	\N	\N
348	290	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-09-23 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	71024A	\N	RP	\N	\N
349	290	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	71024A	\N	RP	\N	\N
350	370	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	92030N	\N	NR	\N	\N
11479	40	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	98030P	\N	SM1	\N	2014-09-28 13:19:48
11480	90	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	98006P	\N	SM1	\N	2014-09-28 12:54:15
12892	890	2012-06-17 00:00:00	\N	2014-09-30 00:00:00	REPRISE	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	86044G	\N	NR	\N	2014-09-28 18:58:25
12893	690	2012-06-17 00:00:00	\N	2014-04-22 00:00:00	REPRISE	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	95049N	\N	NR	\N	2014-05-14 18:17:27
351	590	1997-06-20 00:00:00	\N	2001-09-30 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de Mme Michelle Demessine, nommée membre du Gouvernement	\N	\N	SENAT	97006K	\N	RP	\N	\N
352	590	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	92031P	\N	RP	\N	\N
354	440	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	92032Q	\N	RP	\N	\N
355	50	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	89006N	\N	NR	\N	\N
359	20	1989-11-02 00:00:00	\N	1998-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Jacques PELLETIER nommé membre du Gouvernement	\N	\N	SENAT	88005H	\N	NR	\N	\N
360	972	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95044H	\N	NR	\N	\N
319	615	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	77046H	\N	RP	\N	\N
274	997	1971-10-02 00:00:00	1971-10-02 00:00:00	1980-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	69001W	\N	RP	\N	\N
275	997	1980-10-02 00:00:00	1980-10-02 00:00:00	1989-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	69001W	\N	RP	\N	\N
276	997	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	REN3	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	69001W	\N	RP	\N	\N
277	680	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	86030A	\N	RP	\N	\N
278	680	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	86030A	\N	RP	\N	\N
279	690	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	86031B	\N	RP	\N	\N
280	690	1995-10-02 00:00:00	1995-09-24 00:00:00	2003-11-04 00:00:00	REN1	DECEDE	ANCIEN	\N	\N	\N	\N	2003	SENAT	86031B	\N	RP	\N	\N
281	840	1995-10-02 00:00:00	1995-09-24 00:00:00	1996-05-02 00:00:00	ELECTION	ANNCC	ANCIEN	\N	\N	\N	\N	\N	SENAT	95037J	\N	NR	\N	\N
2176	860	1958-06-08 00:00:00	1958-06-08 00:00:00	1959-04-27 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000374	\N	NR	\N	\N
2177	860	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000374	\N	NR	\N	\N
2178	860	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000374	\N	NR	\N	\N
2179	860	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	REN3	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000374	\N	NR	\N	\N
2182	400	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000184	\N	NR	\N	\N
2183	400	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000184	\N	NR	\N	\N
51096	440	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	11064N	\N	RP	2017-09-24 00:00:00	\N
51097	440	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	11066Q	\N	RP	2017-09-24 00:00:00	\N
2188	600	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59219J	\N	NR	\N	\N
2189	600	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59219J	\N	NR	\N	\N
2190	600	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	REN	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59219J	\N	NR	\N	\N
2191	600	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	REN	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59219J	\N	NR	\N	\N
2192	600	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59219J	\N	NR	\N	\N
2194	650	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000295	\N	NR	\N	\N
2197	615	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000545	\N	RP	\N	\N
2198	615	1986-10-02 00:00:00	1986-09-28 00:00:00	1990-11-29 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000545	\N	RP	\N	\N
51098	440	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	11067R	\N	RP	2017-09-24 00:00:00	\N
51099	440	2017-10-02 00:00:00	2017-09-24 00:00:00	2020-10-31 00:00:00	ELECTION	DEM	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	17583W	\N	RP	2017-09-24 17:04:01	\N
2202	570	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59220B	\N	RP	\N	\N
2203	570	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59220B	\N	RP	\N	\N
2204	570	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	REN	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	59220B	\N	RP	\N	\N
2206	570	1988-07-29 00:00:00	\N	1992-10-01 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. Jean-Marie RAUSCH, nommé membre du Gouvernement	\N	\N	SENAT	59220B	\N	RP	\N	\N
2209	770	1959-04-28 00:00:00	\N	1959-07-14 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	1959	SENAT	000140	\N	RP	\N	\N
2211	430	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000391	\N	NR	\N	\N
2212	430	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000391	\N	NR	\N	\N
2215	740	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59568D	\N	NR	\N	\N
2216	740	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	59568D	\N	NR	\N	\N
2218	974	1992-10-02 00:00:00	1992-09-27 00:00:00	1996-01-20 00:00:00	ELECTION	DECCC	ANCIEN	\N	\N	\N	\N	\N	SENAT	92014N	\N	NR	\N	\N
2220	310	1988-07-29 00:00:00	\N	1989-10-01 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. André MERIC, nommé membre du Gouvernement	\N	\N	SENAT	58951C	\N	RP	\N	\N
2222	330	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000399	\N	RP	\N	\N
2224	330	1987-02-21 00:00:00	\N	1989-10-01 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. Jacques VALADE, nommé ministre	\N	\N	SENAT	000399	\N	RP	\N	\N
2227	390	1983-10-03 00:00:00	1983-09-25 00:00:00	1989-09-17 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000474	\N	NR	\N	\N
2229	10	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000039	\N	NR	\N	\N
2230	10	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000039	\N	NR	\N	\N
2233	240	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000020	\N	NR	\N	\N
2234	240	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000020	\N	NR	\N	\N
2235	240	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000020	\N	NR	\N	\N
2236	240	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	REN3	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000020	\N	NR	\N	\N
2239	810	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59523P	\N	NR	\N	\N
2240	810	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59523P	\N	NR	\N	\N
2241	810	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59523P	\N	NR	\N	\N
2243	265	1975-11-01 00:00:00	\N	1977-09-25 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Louis LAMY, démissionnaire	\N	\N	SENAT	000365	\N	RP	\N	\N
2246	340	1968-10-02 00:00:00	1968-09-22 00:00:00	1971-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000574	\N	NR	\N	\N
2247	340	1971-10-02 00:00:00	1971-09-26 00:00:00	1976-09-27 00:00:00	REN	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	000574	\N	NR	\N	\N
2250	770	1968-10-02 00:00:00	1968-09-22 00:00:00	1976-03-02 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000018	\N	RP	\N	\N
11530	260	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	08016S	\N	SM1	\N	2014-09-28 16:50:17
2252	330	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58946F	\N	RP	\N	\N
2253	330	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58946F	\N	RP	\N	\N
2254	330	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58946F	\N	RP	\N	\N
2255	330	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	REN3	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	58946F	\N	RP	\N	\N
80	570	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	74013K	\N	RP	\N	\N
11541	997	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	08018U	\N	RP	\N	2014-09-28 18:46:14
81	570	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	74013K	\N	RP	\N	\N
82	560	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	83016P	\N	NR	\N	\N
83	560	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	83016P	\N	NR	\N	\N
84	630	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	83017Q	\N	NR	\N	\N
85	630	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	83017Q	\N	NR	\N	\N
86	370	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	92012L	\N	NR	\N	\N
87	640	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	92013M	\N	NR	\N	\N
88	615	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95011X	\N	RP	\N	\N
89	270	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	89022N	\N	NR	\N	\N
90	350	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	80011V	\N	RP	\N	\N
91	350	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	80011V	\N	RP	\N	\N
92	140	1970-09-06 00:00:00	\N	1971-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Jean-Marie LOUVEL, décédé	\N	\N	SENAT	70001N	\N	NR	\N	\N
93	140	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	70001N	\N	NR	\N	\N
1980	1026	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000016	\N	NR	\N	\N
1981	1026	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000016	\N	NR	\N	\N
2257	720	1963-11-22 00:00:00	\N	1968-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. François de NICOLAY, décédé	\N	\N	SENAT	000053	\N	NR	\N	\N
2262	1029	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000035	\N	NR	\N	\N
2263	1029	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	REN3	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000035	\N	NR	\N	\N
2267	690	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000049	\N	RP	\N	\N
2268	690	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000049	\N	RP	\N	\N
2272	410	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	57432D	\N	NR	\N	\N
2274	650	1960-10-24 00:00:00	\N	1965-10-01 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. Antoine BEGUERE, décédé	\N	\N	SENAT	000150	\N	NR	\N	\N
2277	615	1991-02-10 00:00:00	\N	1995-09-24 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59524Q	\N	RP	\N	\N
2279	570	1983-07-29 00:00:00	\N	1983-10-02 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. René JAGER, décédé	\N	\N	SENAT	58366Q	\N	RP	\N	\N
2280	470	1967-06-11 00:00:00	\N	1974-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Jacques BORDENEUVE, élu député	\N	\N	SENAT	58411C	\N	NR	\N	\N
22	440	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	83012K	\N	RP	\N	\N
23	90	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	80004W	\N	NR	\N	\N
24	90	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	80004W	\N	NR	\N	\N
25	335	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95006B	\N	RP	\N	\N
26	335	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95007C	\N	RP	\N	\N
27	60	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	89046W	\N	RP	\N	\N
29	60	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	84004P	\N	RP	\N	\N
30	530	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	74008N	\N	NR	\N	\N
31	530	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	74008N	\N	NR	\N	\N
32	530	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-01-26 00:00:00	REN2	DECEDE	ANCIEN	\N	\N	\N	\N	2001	SENAT	74008N	\N	NR	\N	\N
33	480	1994-09-10 00:00:00	\N	2001-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M.Joseph CAUPERT, décédé	\N	\N	SENAT	94004U	\N	NR	\N	\N
34	730	1995-10-02 00:00:00	1995-09-24 00:00:00	1995-10-31 00:00:00	ELECTION	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	95008D	\N	NR	\N	\N
36	730	1997-09-21 00:00:00	\N	1999-09-23 00:00:00	ELECTION	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	95008D	\N	NR	\N	\N
37	30	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	89018S	\N	NR	\N	\N
38	590	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	83013L	\N	RP	\N	\N
40	590	1998-02-10 00:00:00	\N	1999-10-16 00:00:00	REMPLACE	DECEDE	ANCIEN	\N	\N	En remplacement de M. Maurice Schumann décédé	\N	1999	SENAT	83013L	\N	RP	\N	\N
41	540	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	92007P	\N	RP	\N	\N
42	820	1986-10-02 00:00:00	1986-09-28 00:00:00	1988-06-16 00:00:00	ELECTION	CESDEPUTE	ANCIEN	\N	\N	\N	\N	\N	SENAT	86010V	\N	NR	\N	\N
44	820	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	86010V	\N	NR	\N	\N
46	828	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	79004F	\N	RP	\N	\N
47	828	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	79004F	\N	RP	\N	\N
48	620	1984-10-03 00:00:00	\N	1992-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Raymond DUMONT, démissionnaire	\N	\N	SENAT	84003N	\N	RP	\N	\N
49	620	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	84003N	\N	RP	\N	\N
50	790	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95009E	\N	NR	\N	\N
51	190	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	80007A	\N	NR	\N	\N
52	190	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	80007A	\N	NR	\N	\N
53	895	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-09-23 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	86011W	\N	RP	\N	\N
55	895	1997-11-19 00:00:00	\N	2004-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Michel Rocard, démissionnaire	\N	\N	SENAT	86011W	\N	RP	\N	\N
56	170	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	89013M	\N	NR	\N	\N
57	520	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	1973	SENAT	74011H	\N	NR	\N	\N
58	520	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	1973	SENAT	74011H	\N	NR	\N	\N
59	520	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	1973	SENAT	74011H	\N	NR	\N	\N
60	310	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	89019T	\N	RP	\N	\N
61	540	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	92009R	\N	RP	\N	\N
62	510	1992-09-27 00:00:00	\N	2001-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	92010J	\N	NR	\N	\N
63	360	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	89020L	\N	NR	\N	\N
64	150	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	89010J	\N	NR	\N	\N
65	260	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	89015P	\N	NR	\N	\N
66	997	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	89021M	\N	RP	\N	\N
68	775	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	78007E	\N	RP	\N	\N
69	775	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	78007E	\N	RP	\N	\N
70	410	1986-09-10 00:00:00	1986-09-10 00:00:00	1992-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Charles BEAUPETIT, décédé	\N	\N	SENAT	86005Y	\N	NR	\N	\N
71	410	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	REN1	NONREELU	ANCIEN	\N	\N	\N	\N	1992	SENAT	86005Y	\N	NR	\N	\N
72	500	1996-07-07 00:00:00	1996-07-07 00:00:00	2001-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	96004D	\N	NR	\N	2017-06-16 16:06:38
73	170	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	89012L	\N	NR	\N	\N
74	660	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	92011K	\N	NR	\N	\N
75	80	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	71003U	\N	NR	\N	\N
76	80	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	71003U	\N	NR	\N	\N
77	80	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	71003U	\N	NR	\N	\N
78	760	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	95014B	\N	RP	\N	\N
79	570	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	74013K	\N	RP	\N	\N
244	320	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	89028U	\N	NR	\N	\N
245	997	1998-01-20 00:00:00	\N	1998-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Pierre CROZE, décédé	\N	\N	SENAT	98001J	\N	RP	\N	\N
246	615	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	86028G	\N	RP	\N	\N
247	615	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	86028G	\N	RP	\N	\N
248	760	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95034F	\N	RP	\N	\N
249	180	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	71017B	\N	NR	\N	\N
250	180	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	71017B	\N	NR	\N	\N
251	180	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	71017B	\N	NR	\N	\N
252	290	1986-10-02 00:00:00	1986-09-28 00:00:00	1989-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	86006A	\N	RP	\N	\N
253	290	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	86006A	\N	RP	\N	\N
254	360	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	89030N	\N	NR	\N	\N
256	60	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	88012G	\N	RP	\N	\N
257	140	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	71018C	\N	NR	\N	\N
258	140	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	71018C	\N	NR	\N	\N
259	140	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	REN2	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	71018C	\N	NR	\N	\N
260	20	1978-05-07 00:00:00	\N	1980-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Jacques PELLETIER, nommé membre du Gouvernement	\N	\N	SENAT	78003A	\N	NR	\N	\N
261	20	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	78003A	\N	NR	\N	\N
262	20	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	78003A	\N	NR	\N	\N
263	610	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	92024Q	\N	NR	\N	\N
264	895	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95035G	\N	RP	\N	\N
265	430	1978-06-11 00:00:00	1978-06-11 00:00:00	1983-10-02 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	78006D	\N	NR	\N	\N
266	430	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	78006D	\N	NR	\N	\N
2049	360	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000321	\N	NR	\N	\N
2054	340	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000047	\N	NR	\N	\N
2055	340	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000047	\N	NR	\N	\N
2056	340	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000047	\N	NR	\N	\N
2058	300	1986-06-24 00:00:00	\N	1988-06-24 00:00:00	REMPLACE	CESDEPUTE	ANCIEN	\N	\N	En remplacement de M. Edgar TAILHADES, décédé le 23 juin 1986	\N	\N	SENAT	59309K	\N	NR	\N	\N
2060	580	1963-02-24 00:00:00	1963-02-24 00:00:00	1965-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58302X	\N	NR	\N	\N
2061	580	1965-10-02 00:00:00	1965-09-26 00:00:00	1967-04-03 00:00:00	REN	CESDEPUTE	ANCIEN	\N	\N	\N	\N	\N	SENAT	58302X	\N	NR	\N	\N
2063	895	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000553	\N	RP	\N	\N
2066	840	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	59566B	\N	NR	\N	\N
2068	1020	1967-04-03 00:00:00	\N	1968-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Pierre METAYER, député	\N	\N	SENAT	000285	\N	NR	\N	\N
2069	895	1968-10-02 00:00:00	1968-09-22 00:00:00	1973-09-26 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000285	\N	RP	\N	\N
2071	690	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59583C	\N	RP	\N	\N
2073	971	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000340	\N	NR	\N	\N
2074	971	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	REN	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000340	\N	NR	\N	\N
2077	580	1975-12-30 00:00:00	\N	1983-10-02 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Fernand DUSSERT, décédé	\N	\N	SENAT	000353	\N	NR	\N	\N
2078	580	1983-10-03 00:00:00	1983-09-25 00:00:00	1986-12-18 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000353	\N	NR	\N	\N
2081	590	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000113	\N	RP	\N	\N
2082	590	1959-04-28 00:00:00	1959-04-26 00:00:00	1961-09-19 00:00:00	REN2	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000113	\N	RP	\N	\N
2084	360	1982-11-19 00:00:00	\N	1989-10-01 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. René TOUZET, décédé	\N	\N	SENAT	58911T	\N	NR	\N	\N
2086	997	1955-06-28 00:00:00	\N	1959-04-27 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000036	\N	RP	\N	\N
2087	997	1959-05-05 00:00:00	1959-05-05 00:00:00	1962-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000036	\N	RP	\N	\N
2088	997	1962-10-04 00:00:00	1962-10-04 00:00:00	1971-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000036	\N	RP	\N	\N
2091	760	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59522N	\N	RP	\N	\N
2092	760	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59522N	\N	RP	\N	\N
2094	590	1979-04-01 00:00:00	\N	1983-10-02 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. René DEBESSON, démissionnaire	\N	\N	SENAT	79002D	\N	RP	\N	\N
2095	590	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	79002D	\N	RP	\N	\N
2096	590	1992-10-02 00:00:00	1992-09-27 00:00:00	1997-07-02 00:00:00	REN2	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	79002D	\N	RP	\N	\N
2098	824	1995-10-02 00:00:00	1995-09-24 00:00:00	1997-06-12 00:00:00	ELECTION	CESDEPUTE	ANCIEN	\N	\N	\N	\N	\N	SENAT	95010W	\N	RP	\N	\N
2101	650	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	58328J	\N	NR	\N	\N
2103	10	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000083	\N	NR	\N	\N
2104	10	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000083	\N	NR	\N	\N
2105	10	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000083	\N	NR	\N	\N
2106	10	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	REN3	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000083	\N	NR	\N	\N
2109	730	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59567C	\N	NR	\N	\N
2110	730	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59567C	\N	NR	\N	\N
2111	730	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN2	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	59567C	\N	NR	\N	\N
2113	420	1967-06-11 00:00:00	1967-06-11 00:00:00	1974-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	57426F	\N	RP	\N	\N
2115	20	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000165	\N	NR	\N	\N
2116	20	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000165	\N	NR	\N	\N
2117	20	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-02-25 00:00:00	REN2	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000165	\N	NR	\N	\N
2119	330	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000634	\N	RP	\N	\N
2120	330	1989-10-02 00:00:00	1989-09-24 00:00:00	1993-08-27 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000634	\N	RP	\N	\N
2122	540	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59218H	\N	RP	\N	\N
2123	540	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59218H	\N	RP	\N	\N
2125	520	1961-09-24 00:00:00	\N	1965-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Edgar PISANI, nommé ministre	\N	\N	SENAT	000176	\N	NR	\N	\N
2126	520	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	REN	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000176	\N	NR	\N	\N
2129	170	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	58920U	\N	NR	\N	\N
2131	130	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	58921V	\N	RP	\N	\N
2133	1020	1959-04-28 00:00:00	\N	1968-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58619S	\N	NR	\N	\N
2134	895	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58619S	\N	RP	\N	\N
11483	180	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	05012A	\N	SM1	\N	2014-09-28 12:31:22
2135	895	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	58619S	\N	RP	\N	\N
2137	310	1974-07-09 00:00:00	\N	1980-10-01 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. Marcel CAVAILLE, nommé membre du Gouvernement	\N	\N	SENAT	58041V	\N	RP	\N	\N
2139	480	1959-04-28 00:00:00	\N	1965-09-25 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000160	\N	NR	\N	\N
2140	480	1965-10-02 00:00:00	1965-09-26 00:00:00	1973-06-25 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000160	\N	NR	\N	\N
2143	470	1959-04-28 00:00:00	\N	1965-09-25 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	1959	SENAT	000198	\N	NR	\N	\N
2144	470	1965-10-02 00:00:00	\N	1967-04-03 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	1959	SENAT	000198	\N	NR	\N	\N
2146	470	1974-09-22 00:00:00	\N	1981-01-03 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	1959	SENAT	000198	\N	NR	\N	\N
2148	120	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000099	\N	NR	\N	\N
2153	740	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58654V	\N	NR	\N	\N
2154	740	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	58654V	\N	NR	\N	\N
2156	1029	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000081	\N	NR	\N	\N
2158	1029	1962-11-01 00:00:00	\N	1968-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Roger GARAUDY	\N	\N	SENAT	000081	\N	NR	\N	\N
2159	615	1968-10-02 00:00:00	1968-09-22 00:00:00	1969-06-25 00:00:00	REN	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	000081	\N	RP	\N	\N
2162	615	1969-06-26 00:00:00	\N	1977-10-02 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Georges BOSSUS, démissionnaire	\N	\N	SENAT	58620K	\N	RP	\N	\N
2163	615	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	58620K	\N	RP	\N	\N
2167	125	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000328	\N	NR	\N	\N
2168	125	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000328	\N	NR	\N	\N
2169	125	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN3	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000328	\N	NR	\N	\N
2172	620	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000316	\N	RP	\N	\N
2173	620	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN2	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000316	\N	RP	\N	\N
2304	590	1983-10-03 00:00:00	1983-09-25 00:00:00	1990-01-14 00:00:00	REN2	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000326	\N	RP	\N	\N
3088	820	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	REELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000219	\N	NR	\N	\N
3089	820	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-09-25 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000219	\N	NR	\N	\N
3092	1004	1969-07-23 00:00:00	\N	1974-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000204	\N	NR	\N	\N
3095	760	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-09-28 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000107	\N	RP	\N	\N
3096	760	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-07-05 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000107	\N	RP	\N	\N
3098	870	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-09-24 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59541R	\N	NR	\N	\N
3099	870	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-09-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59541R	\N	NR	\N	\N
3100	870	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59541R	\N	NR	\N	\N
3102	120	1956-07-22 00:00:00	\N	1959-04-27 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	57129Y	\N	NR	\N	\N
3103	120	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	57129Y	\N	NR	\N	\N
3104	120	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN2	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	57129Y	\N	NR	\N	\N
3106	100	1981-11-23 00:00:00	\N	1989-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Pierre LABONDE, décédé	\N	\N	SENAT	000456	\N	NR	\N	\N
3107	100	1989-10-02 00:00:00	1989-09-24 00:00:00	1994-07-15 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000456	\N	NR	\N	\N
3110	390	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000042	\N	NR	\N	\N
3111	390	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-09-22 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000042	\N	NR	\N	\N
3114	895	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-09-24 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59542S	\N	RP	\N	\N
3116	740	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000133	\N	NR	\N	\N
3117	740	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000133	\N	NR	\N	\N
3118	740	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000133	\N	NR	\N	\N
3121	120	1980-11-19 00:00:00	\N	1989-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de Albert SIRGUE, décédé	\N	\N	SENAT	58948H	\N	NR	\N	\N
3124	830	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-09-21 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000093	\N	RP	\N	\N
3125	830	1968-10-02 00:00:00	1968-09-22 00:00:00	1972-12-05 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000093	\N	RP	\N	\N
3127	830	1981-09-27 00:00:00	\N	1986-10-01 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. Guy DURBEC, député	\N	\N	SENAT	58626R	\N	RP	\N	\N
3129	1026	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	58924Y	\N	NR	\N	\N
3131	560	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-01-30 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000170	\N	NR	\N	\N
3133	335	1977-10-03 00:00:00	1977-09-25 00:00:00	1981-07-23 00:00:00	ELECTION	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	58652T	1981-06-22 00:00:00	RP	\N	2016-12-14 15:23:15
3137	760	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	REN2	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000014	\N	RP	\N	\N
3140	760	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-09-21 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000442	\N	RP	\N	\N
3141	760	1968-10-02 00:00:00	1968-09-22 00:00:00	1973-03-11 00:00:00	REN	CESDEPUTE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000442	\N	RP	\N	\N
2734	420	1959-01-08 00:00:00	\N	1963-02-23 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000043	\N	RP	\N	\N
2735	420	1963-02-24 00:00:00	1963-02-24 00:00:00	1965-10-01 00:00:00	REELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000043	\N	RP	\N	\N
2740	1029	1962-05-16 00:00:00	\N	1968-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000046	\N	NR	\N	\N
2741	335	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000046	\N	RP	\N	\N
2744	300	1976-07-12 00:00:00	\N	1980-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de Mme Suzanne CREMIEUX, décédée	\N	\N	SENAT	58021R	\N	NR	\N	\N
2746	335	1976-01-12 00:00:00	\N	1977-10-02 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. André FOSSET, nommé membre du Gouvernement	\N	\N	SENAT	000388	\N	RP	\N	\N
2749	370	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000451	\N	NR	\N	\N
2750	370	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000451	\N	NR	\N	\N
2751	370	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000451	\N	NR	\N	\N
2754	760	1993-02-23 00:00:00	\N	1995-09-24 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Jean LECANUET, décédé	\N	\N	SENAT	000449	\N	RP	\N	\N
2757	1029	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59521M	\N	NR	\N	\N
2758	1029	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59521M	\N	NR	\N	\N
2759	335	1968-10-02 00:00:00	1968-09-22 00:00:00	1976-01-12 00:00:00	REN2	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	59521M	\N	RP	\N	\N
2389	620	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000195	\N	RP	\N	\N
2390	620	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000195	\N	RP	\N	\N
2391	620	1965-10-02 00:00:00	1965-09-26 00:00:00	1967-04-03 00:00:00	REN	CESDEPUTE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000195	\N	RP	\N	\N
2393	620	1974-10-02 00:00:00	1974-09-22 00:00:00	1981-04-23 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000195	\N	RP	\N	\N
2395	490	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59222D	\N	NR	\N	\N
2396	490	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	REN	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	59222D	\N	NR	\N	\N
2398	130	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58923X	\N	RP	\N	\N
2399	130	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	58923X	\N	RP	\N	\N
2404	995	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	56819Q	\N	NR	\N	\N
2405	995	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	REN	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	56819Q	\N	NR	\N	\N
2408	340	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000060	\N	NR	\N	\N
2409	340	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000060	\N	NR	\N	\N
2410	340	1962-10-02 00:00:00	1962-09-23 00:00:00	1967-08-03 00:00:00	REN3	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000060	\N	NR	\N	\N
2412	1029	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000058	\N	NR	\N	\N
2413	615	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000058	\N	RP	\N	\N
2416	290	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000235	\N	RP	\N	\N
2417	290	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000235	\N	RP	\N	\N
2418	290	1971-10-02 00:00:00	1971-09-26 00:00:00	1978-08-29 00:00:00	REN2	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000235	\N	RP	\N	\N
2420	265	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58805S	\N	RP	\N	\N
2421	265	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58805S	\N	RP	\N	\N
2422	265	1986-10-02 00:00:00	1986-09-28 00:00:00	1988-05-13 00:00:00	REN2	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	58805S	\N	RP	\N	\N
2424	510	1970-08-20 00:00:00	\N	1974-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Roger MENU, décédé	\N	\N	SENAT	000494	\N	NR	\N	\N
2425	510	1974-10-02 00:00:00	1974-09-22 00:00:00	1976-03-18 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000494	\N	NR	\N	\N
2427	615	1980-10-04 00:00:00	\N	1986-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Jean-Louis Vigier, démissionnaire	\N	\N	SENAT	000501	\N	RP	\N	\N
2429	615	1993-06-20 00:00:00	\N	1994-09-27 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000501	\N	RP	\N	\N
2432	620	1974-07-09 00:00:00	\N	1974-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Roger Poudonson, nommé membre du Gouvernement	\N	\N	SENAT	59223E	\N	RP	\N	\N
2434	620	1981-10-10 00:00:00	\N	1983-10-02 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Baudoin de HAUTECLOCQUE, décédé	\N	\N	SENAT	59223E	\N	RP	\N	\N
2435	620	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	REN	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	59223E	\N	RP	\N	\N
2437	690	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59528U	\N	RP	\N	\N
2438	690	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59528U	\N	RP	\N	\N
2439	690	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59528U	\N	RP	\N	\N
2441	460	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000196	\N	NR	\N	\N
2444	983	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	57710G	\N	NR	\N	\N
2445	983	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	REN	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	57710G	\N	NR	\N	\N
2446	310	1989-10-02 00:00:00	1989-09-24 00:00:00	1996-01-12 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	89011K	\N	RP	\N	\N
2448	500	1952-12-21 00:00:00	\N	1959-04-27 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Joseph Lecacheux, décédé.	\N	\N	SENAT	000073	\N	NR	\N	\N
2449	500	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000073	\N	NR	\N	\N
2450	500	1965-10-02 00:00:00	1965-09-26 00:00:00	1968-06-16 00:00:00	REN2	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000073	\N	NR	\N	\N
2452	460	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59224F	\N	NR	\N	\N
2454	190	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000192	\N	NR	\N	\N
51064	830	2017-09-23 00:00:00	\N	2020-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	Nouveau	en remplacement de Mme Christiane Hummel, démissionnaire de son mandat	\N	\N	SENAT	14029X	\N	NR	2017-09-24 11:13:08	2017-09-24 11:38:12
2461	110	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000205	\N	NR	\N	\N
2462	110	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000205	\N	NR	\N	\N
2463	110	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000205	\N	NR	\N	\N
2464	110	1971-10-02 00:00:00	1971-09-26 00:00:00	1974-09-20 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	1974	SENAT	000205	\N	NR	\N	\N
2467	880	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000359	\N	NR	\N	\N
2468	880	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000359	\N	NR	\N	\N
2469	880	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	REN3	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000359	\N	NR	\N	\N
2472	500	1979-01-11 00:00:00	\N	1982-01-10 00:00:00	REMPLACE	DECEDE	ANCIEN	\N	\N	En remplacement de M. Michel YVER, décédé.	\N	\N	SENAT	000089	\N	NR	\N	\N
2474	1029	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000173	\N	NR	\N	\N
2904	270	1989-01-31 00:00:00	\N	1989-10-01 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. Modeste LEGOUEZ, décédé	\N	\N	SENAT	58949J	\N	NR	\N	\N
2906	973	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000224	\N	NR	\N	\N
2909	440	1965-03-03 00:00:00	\N	1965-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Albert BOUCHER, décédé	\N	\N	SENAT	58332E	\N	RP	\N	\N
2910	440	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58332E	\N	RP	\N	\N
2911	440	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	58332E	\N	RP	\N	\N
2913	580	1977-12-22 00:00:00	1977-12-22 00:00:00	1983-10-02 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Pierre PETIT, décédé	\N	\N	SENAT	59233G	\N	NR	\N	\N
2914	580	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59233G	\N	NR	\N	\N
2916	890	1959-07-03 00:00:00	\N	1968-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Philippe de RAINCOURT, décédé	\N	\N	SENAT	58625Q	\N	NR	\N	\N
2917	890	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58625Q	\N	NR	\N	\N
2918	890	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	58625Q	\N	NR	\N	\N
2920	110	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000216	\N	NR	\N	\N
2921	110	1962-10-02 00:00:00	1962-09-23 00:00:00	1967-04-03 00:00:00	REN	CESDEPUTE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000216	\N	NR	\N	\N
2924	290	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000459	\N	RP	\N	\N
2927	615	1989-05-19 00:00:00	\N	1995-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Dominique PADO, décédé	\N	\N	SENAT	59538W	\N	RP	\N	\N
2929	1029	1959-04-28 00:00:00	\N	1968-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000092	\N	NR	\N	\N
2930	615	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000092	\N	RP	\N	\N
11558	330	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	98021N	\N	RP	\N	2014-09-28 17:53:13
2933	350	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000271	\N	RP	\N	\N
2934	350	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-07-22 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000271	\N	RP	\N	\N
2936	820	1977-10-03 00:00:00	1977-09-25 00:00:00	1978-08-27 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000602	\N	NR	\N	\N
2938	670	1978-05-07 00:00:00	\N	1981-07-28 00:00:00	REMPLACE	DEM	ANCIEN	\N	\N	En remplacement de M. Daniel HOEFFEL, nommé membre du Gouvernement	\N	\N	SENAT	58115W	\N	RP	\N	\N
2940	670	1993-05-01 00:00:00	\N	1995-09-24 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Daniel HOEFFEL, nommé membre du Gouvernement	\N	\N	SENAT	58115W	\N	RP	\N	\N
2942	290	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000218	\N	RP	\N	\N
2943	290	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000218	\N	RP	\N	\N
2946	620	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000186	\N	RP	\N	\N
2947	620	1974-10-02 00:00:00	1974-09-22 00:00:00	1981-10-09 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000186	\N	RP	\N	\N
2949	615	1986-10-02 00:00:00	1986-09-28 00:00:00	1993-01-18 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000310	\N	RP	\N	\N
2951	973	1971-10-02 00:00:00	1971-09-26 00:00:00	1978-06-09 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000406	\N	NR	\N	\N
2953	620	1967-04-03 00:00:00	\N	1974-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Bernard CHOCHOY, député	\N	\N	SENAT	000185	\N	RP	\N	\N
2955	250	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000110	\N	NR	\N	\N
2956	250	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000110	\N	NR	\N	\N
2957	250	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000110	\N	NR	\N	\N
2960	270	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000243	\N	NR	\N	\N
2961	270	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000243	\N	NR	\N	\N
2962	270	1980-10-02 00:00:00	1980-09-28 00:00:00	1981-09-29 00:00:00	REN2	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000243	\N	NR	\N	\N
2964	895	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	58644T	\N	RP	\N	\N
2966	60	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000040	\N	RP	\N	\N
2967	60	1962-10-02 00:00:00	1962-09-23 00:00:00	1966-02-10 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000040	\N	RP	\N	\N
2969	974	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000273	\N	NR	\N	\N
2970	974	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000273	\N	NR	\N	\N
3586	340	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000208	\N	NR	\N	\N
2704	1002	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000057	\N	NR	\N	\N
2707	340	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	58934B	\N	NR	\N	\N
2709	570	1960-05-10 00:00:00	\N	1965-10-01 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. René SCHWARTZ, décédé	\N	\N	SENAT	000380	\N	RP	\N	\N
2711	390	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000197	\N	NR	\N	\N
2712	390	1965-10-02 00:00:00	1965-09-26 00:00:00	1966-02-08 00:00:00	REN	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	000197	\N	NR	\N	\N
2714	250	1980-10-02 00:00:00	1980-09-28 00:00:00	1988-03-30 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000197	\N	NR	\N	\N
2716	460	1983-10-03 00:00:00	1983-09-25 00:00:00	1988-06-12 00:00:00	ELECTION	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	58818X	\N	NR	\N	\N
2718	740	1966-03-10 00:00:00	\N	1968-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Jean CLERC, décédé	\N	\N	SENAT	57613G	\N	NR	\N	\N
2720	760	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000177	\N	RP	\N	\N
2721	760	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000177	\N	RP	\N	\N
2724	290	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	56905M	\N	RP	\N	\N
2725	1002	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000135	\N	NR	\N	\N
2727	1002	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000135	\N	NR	\N	\N
2728	1002	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000135	\N	NR	\N	\N
11477	200	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	01065W	\N	SM1	\N	2014-09-28 12:09:44
3143	760	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-04-02 00:00:00	ELECTION	CESDEPUTE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000442	\N	RP	\N	\N
3145	760	1986-10-02 00:00:00	1986-09-28 00:00:00	1993-02-22 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000442	\N	RP	\N	\N
3147	130	1983-05-11 00:00:00	\N	1989-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Antoine ANDRIEUX, décédé	\N	\N	SENAT	58941A	\N	RP	\N	\N
3150	710	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000248	\N	NR	\N	\N
3153	824	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59543T	\N	RP	\N	\N
3154	824	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59543T	\N	RP	\N	\N
3156	775	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-09-24 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000280	\N	RP	\N	\N
3157	775	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000280	\N	RP	\N	\N
3160	615	1968-10-02 00:00:00	1968-09-22 00:00:00	1976-02-16 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000325	\N	RP	\N	\N
3162	270	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-09-22 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000201	\N	NR	\N	\N
3163	270	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-09-25 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000201	\N	NR	\N	\N
3164	270	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-09-27 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000201	\N	NR	\N	\N
2357	840	1986-10-02 00:00:00	1986-09-28 00:00:00	1987-09-30 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000572	\N	NR	\N	\N
2359	828	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000439	\N	RP	\N	\N
2360	828	1977-10-03 00:00:00	1977-09-25 00:00:00	1979-06-11 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000439	\N	RP	\N	\N
2362	440	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59221C	\N	RP	\N	\N
2363	440	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59221C	\N	RP	\N	\N
2364	440	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59221C	\N	RP	\N	\N
2366	1020	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000272	\N	NR	\N	\N
2367	828	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000272	\N	RP	\N	\N
2368	828	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000272	\N	RP	\N	\N
2371	615	1968-10-02 00:00:00	1968-09-22 00:00:00	1972-09-14 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000222	\N	RP	\N	\N
2373	420	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-12-13 00:00:00	ELECTION	CESDEPUTE	ANCIEN	\N	\N	\N	\N	\N	SENAT	58113U	\N	RP	\N	\N
2375	430	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	58349P	\N	NR	\N	\N
2377	982	1974-10-14 00:00:00	\N	1983-10-02 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. Henri Lafleur, décédé	\N	\N	SENAT	58419L	\N	NR	\N	\N
2381	540	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	57434F	\N	RP	\N	\N
2382	540	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	REN	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	57434F	\N	RP	\N	\N
2384	615	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59527T	\N	RP	\N	\N
2787	1029	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-31 00:00:00	ELECTION	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	56601X	\N	NR	\N	\N
2789	775	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59534S	\N	RP	\N	\N
2790	775	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59534S	\N	RP	\N	\N
2792	800	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000131	\N	NR	\N	\N
2793	800	1968-10-02 00:00:00	1968-09-22 00:00:00	1972-12-10 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000131	\N	NR	\N	\N
2795	971	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58641Q	\N	NR	\N	\N
2796	971	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	58641Q	\N	NR	\N	\N
2798	260	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	80020W	\N	NR	\N	\N
2799	260	1989-10-02 00:00:00	1989-09-24 00:00:00	1996-09-03 00:00:00	REN1	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	80020W	\N	NR	\N	\N
2801	130	1989-10-02 00:00:00	1989-09-24 00:00:00	1995-12-07 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	89029V	\N	RP	\N	\N
2803	830	1977-10-03 00:00:00	1977-09-25 00:00:00	1978-01-02 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000306	\N	RP	\N	\N
2805	824	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000536	\N	RP	\N	\N
2808	630	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000137	\N	NR	\N	\N
2811	760	1994-02-06 00:00:00	\N	1995-09-24 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59535T	\N	RP	\N	\N
2813	490	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000319	\N	NR	\N	\N
2814	490	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	REN	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000319	\N	NR	\N	\N
2819	840	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000114	\N	NR	\N	\N
2820	840	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000114	\N	NR	\N	\N
2821	840	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	REN	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000114	\N	NR	\N	\N
2822	840	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000114	\N	NR	\N	\N
2825	690	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	58656X	\N	RP	\N	\N
2827	1002	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	62001R	\N	NR	\N	\N
2828	1002	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	REN	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	62001R	\N	NR	\N	\N
2829	205	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	62001R	\N	NR	\N	\N
2830	205	1989-10-02 00:00:00	1989-09-24 00:00:00	1997-03-07 00:00:00	REN3	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	62001R	\N	NR	\N	\N
2832	824	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000599	\N	RP	\N	\N
2833	824	1986-10-02 00:00:00	1986-09-28 00:00:00	1988-10-03 00:00:00	REN	CESDEPUTE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000599	\N	RP	\N	\N
2837	615	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000309	\N	RP	\N	\N
2840	680	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59536U	\N	RP	\N	\N
2841	680	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59536U	\N	RP	\N	\N
2843	615	1979-05-29 00:00:00	\N	1986-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Georges DAYAN, décédé	\N	\N	SENAT	58631N	\N	RP	\N	\N
2845	740	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	59575C	\N	NR	\N	\N
2847	560	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000062	\N	NR	\N	\N
2848	560	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000062	\N	NR	\N	\N
2849	560	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	REN2	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000062	\N	NR	\N	\N
2852	30	1970-11-24 00:00:00	\N	1971-10-01 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. Roger BESSON, décédé	\N	\N	SENAT	000210	\N	NR	\N	\N
2855	590	1990-01-15 00:00:00	\N	1992-09-27 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Pierre CAROUS, décédé	\N	\N	SENAT	59230D	\N	RP	\N	\N
11487	20	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	98036V	\N	SM1	\N	2014-09-28 17:15:42
2857	400	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59231E	\N	NR	\N	\N
2859	775	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58673Y	\N	RP	\N	\N
2860	775	1977-10-03 00:00:00	1977-09-25 00:00:00	1978-07-23 00:00:00	REN	CESDEPUTE	ANCIEN	\N	\N	\N	\N	\N	SENAT	58673Y	\N	RP	\N	\N
2862	170	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000097	\N	NR	\N	\N
2863	170	1962-09-23 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000097	\N	NR	\N	\N
2864	170	1971-10-02 00:00:00	1971-09-26 00:00:00	1978-05-08 00:00:00	REN2	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000097	\N	NR	\N	\N
2868	390	1966-02-09 00:00:00	\N	1974-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Edgar FAURE, nommé ministre	\N	\N	SENAT	000370	\N	NR	\N	\N
2869	390	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000370	\N	NR	\N	\N
2875	540	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	57445J	\N	RP	\N	\N
2876	540	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	57445J	\N	RP	\N	\N
2877	540	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	57445J	\N	RP	\N	\N
2879	335	1986-04-21 00:00:00	\N	1986-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Charles PASQUA nommé membre du Gouvernement	\N	\N	SENAT	59537V	\N	RP	\N	\N
2880	335	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59537V	\N	RP	\N	\N
11488	20	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	08010L	\N	SM1	\N	2014-09-28 17:15:42
2884	660	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000226	\N	NR	\N	\N
2885	660	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000226	\N	NR	\N	\N
2886	660	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	REN	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000226	\N	NR	\N	\N
2887	660	1974-10-02 00:00:00	1974-09-22 00:00:00	1982-10-22 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000226	\N	NR	\N	\N
2889	590	1977-10-01 00:00:00	\N	1983-10-02 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Victor PROVO, démissionnaire	\N	\N	SENAT	59232F	\N	RP	\N	\N
2890	590	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59232F	\N	RP	\N	\N
2892	895	1973-09-27 00:00:00	\N	1977-10-02 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Aimé BERGEAL, décédé	\N	\N	SENAT	000551	\N	RP	\N	\N
2893	895	1977-10-03 00:00:00	1977-09-25 00:00:00	1985-03-11 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000551	\N	RP	\N	\N
2896	998	1955-06-28 00:00:00	\N	1959-05-05 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000067	\N	RP	\N	\N
2897	998	1959-05-05 00:00:00	1959-05-05 00:00:00	1965-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000067	\N	RP	\N	\N
2898	998	1965-10-02 00:00:00	1965-10-02 00:00:00	1974-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000067	\N	RP	\N	\N
2899	998	1974-10-02 00:00:00	1974-10-02 00:00:00	1977-03-04 00:00:00	REN	CESMEMCC	ANCIEN	\N	\N	\N	\N	\N	SENAT	000067	\N	RP	\N	\N
2902	240	1989-10-02 00:00:00	1989-09-24 00:00:00	1997-01-12 00:00:00	ELECTION	CESMEMCC	ANCIEN	\N	\N	\N	\N	\N	SENAT	89032Q	\N	NR	\N	\N
3352	310	1980-10-02 00:00:00	1980-09-28 00:00:00	1988-07-29 00:00:00	REN	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	000323	\N	RP	\N	\N
3355	60	1980-10-02 00:00:00	1980-09-28 00:00:00	1988-06-24 00:00:00	ELECTION	CESDEPUTE	ANCIEN	\N	\N	\N	\N	\N	SENAT	59717X	\N	RP	\N	\N
3357	828	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000050	\N	RP	\N	\N
3360	570	1992-10-02 00:00:00	1992-09-27 00:00:00	1996-09-10 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	92038W	\N	RP	\N	\N
3362	150	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000102	\N	NR	\N	\N
3366	1029	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000025	\N	NR	\N	\N
3370	335	1981-07-24 00:00:00	\N	1986-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Anicet LE PORS, membre du Gouvernement	\N	\N	SENAT	58635S	\N	RP	\N	\N
3372	895	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000356	\N	RP	\N	\N
3375	770	1976-03-03 00:00:00	\N	1977-10-02 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. Pierre BRUN, décédé	\N	\N	SENAT	58003P	\N	RP	\N	\N
3377	30	1962-03-06 00:00:00	\N	1962-10-01 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. Fernand AUBERGER, décédé	\N	\N	SENAT	000065	\N	NR	\N	\N
3381	400	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000070	\N	NR	\N	\N
3382	400	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000070	\N	NR	\N	\N
3383	400	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	REN	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000070	\N	NR	\N	\N
3384	400	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000070	\N	NR	\N	\N
3387	700	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59551T	\N	NR	\N	\N
3388	700	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59551T	\N	NR	\N	\N
3389	700	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59551T	\N	NR	\N	\N
3391	828	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59552U	\N	RP	\N	\N
3393	380	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000103	\N	RP	\N	\N
3394	380	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000103	\N	RP	\N	\N
3395	380	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000103	\N	RP	\N	\N
3396	380	1974-10-02 00:00:00	1974-09-22 00:00:00	1981-08-29 00:00:00	REN3	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000103	\N	RP	\N	\N
3398	580	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-12-13 00:00:00	ELECTION	CESDEPUTE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000379	\N	NR	\N	\N
3400	170	1973-03-06 00:00:00	\N	1980-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. André DULIN, décédé	\N	\N	SENAT	58914W	\N	NR	\N	\N
3401	170	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	REN	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	58914W	\N	NR	\N	\N
3405	70	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000069	\N	NR	\N	\N
3406	70	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000069	\N	NR	\N	\N
3407	70	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000069	\N	NR	\N	\N
11476	984	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	98005N	\N	SM1	\N	2014-09-28 09:33:54
3412	330	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000033	\N	RP	\N	\N
3413	330	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000033	\N	RP	\N	\N
3414	330	1971-10-02 00:00:00	1971-09-26 00:00:00	1977-10-05 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000033	\N	RP	\N	\N
3417	810	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000022	\N	NR	\N	\N
3418	810	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	REN2	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000022	\N	NR	\N	\N
3421	420	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59236K	\N	RP	\N	\N
3422	420	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59236K	\N	RP	\N	\N
3423	420	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59236K	\N	RP	\N	\N
3424	420	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59236K	\N	RP	\N	\N
3425	420	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	REN	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	59236K	\N	RP	\N	\N
3427	290	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	57135W	\N	RP	\N	\N
3428	290	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	57135W	\N	RP	\N	\N
3430	530	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000209	\N	NR	\N	\N
3435	630	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000088	\N	NR	\N	\N
3436	630	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	REN3	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000088	\N	NR	\N	\N
3439	20	1971-02-26 00:00:00	\N	1971-10-01 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. René BLONDELLE, décédé	\N	\N	SENAT	000290	\N	NR	\N	\N
3441	170	1978-05-09 00:00:00	\N	1980-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Lucien GRAND, décédé	\N	\N	SENAT	58026W	\N	NR	\N	\N
3443	974	1987-02-03 00:00:00	\N	1992-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Paul BENARD, décédé	\N	\N	SENAT	000597	\N	NR	\N	\N
3444	974	1992-10-02 00:00:00	1992-09-27 00:00:00	1995-07-01 00:00:00	REN1	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000597	\N	NR	\N	\N
3446	370	1975-07-23 00:00:00	\N	1983-10-02 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Raymond VILLATTE, décédé	\N	\N	SENAT	000100	\N	NR	\N	\N
3449	440	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000027	\N	RP	\N	\N
3450	440	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000027	\N	RP	\N	\N
3453	800	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000586	\N	NR	\N	\N
3454	800	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000586	\N	NR	\N	\N
3458	999	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000145	\N	RP	\N	\N
3459	999	1959-05-05 00:00:00	1959-05-05 00:00:00	1968-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000145	\N	RP	\N	\N
3460	999	1968-10-02 00:00:00	1968-10-02 00:00:00	1971-08-10 00:00:00	REN3	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000145	\N	RP	\N	\N
3462	590	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000242	\N	RP	\N	\N
3465	590	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59237L	\N	RP	\N	\N
3467	640	1980-07-29 00:00:00	\N	1983-10-02 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Michel LABEGUERIE, décédé	\N	\N	SENAT	000528	\N	NR	\N	\N
3468	640	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	REN	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000528	\N	NR	\N	\N
3473	1020	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000187	\N	NR	\N	\N
3474	1020	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000187	\N	NR	\N	\N
11485	270	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	REN2	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	89022N	\N	SM1	\N	2014-09-28 18:19:47
2674	590	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000134	\N	RP	\N	\N
2675	590	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000134	\N	RP	\N	\N
2676	590	1965-10-02 00:00:00	1965-09-26 00:00:00	1967-05-11 00:00:00	REN	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	000134	\N	RP	\N	\N
2679	972	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000082	\N	NR	\N	\N
2682	760	1969-09-13 00:00:00	\N	1977-10-02 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Léon ROGE	\N	\N	SENAT	58630M	\N	RP	\N	\N
2683	760	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	58630M	\N	RP	\N	\N
2685	824	1975-05-01 00:00:00	\N	1977-10-02 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Louis TALAMONI, décédé	\N	\N	SENAT	57721K	\N	RP	\N	\N
2687	310	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58942B	\N	RP	\N	\N
2688	310	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	58942B	\N	RP	\N	\N
2690	590	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58502E	\N	RP	\N	\N
2691	590	1983-10-03 00:00:00	1983-09-25 00:00:00	1985-04-02 00:00:00	REN	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	58502E	\N	RP	\N	\N
2693	620	1983-10-03 00:00:00	1983-09-25 00:00:00	1986-07-31 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000411	\N	RP	\N	\N
2695	1004	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000215	\N	NR	\N	\N
2696	1004	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000215	\N	NR	\N	\N
2697	1004	1965-10-02 00:00:00	1965-09-26 00:00:00	1971-01-17 00:00:00	REN2	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000215	\N	NR	\N	\N
2699	380	1981-08-29 00:00:00	\N	1983-10-02 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. Paul MISTRAL, décédé	\N	\N	SENAT	58351H	\N	RP	\N	\N
2701	490	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000056	\N	NR	\N	\N
4	100	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	89017R	\N	NR	\N	\N
5	160	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	80002U	\N	NR	\N	\N
6	160	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	80002U	\N	NR	\N	\N
7	590	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	83010H	\N	RP	\N	\N
8	590	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	83010H	\N	RP	\N	\N
9	640	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	92006N	\N	NR	\N	\N
10	740	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95005A	\N	NR	\N	\N
11	828	1997-07-05 00:00:00	\N	2004-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Alain Richard nommé membre du Gouvernement	\N	\N	SENAT	97009N	\N	RP	\N	\N
12	160	1996-09-29 00:00:00	\N	1998-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	96008H	\N	NR	\N	\N
13	530	1983-10-03 00:00:00	1983-09-25 00:00:00	1986-04-19 00:00:00	ELECTION	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	83011J	1986-03-20 00:00:00	NR	\N	2016-12-13 15:17:17
15	530	1988-10-03 00:00:00	1988-07-24 00:00:00	1992-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	83011J	\N	NR	\N	\N
16	530	1992-10-02 00:00:00	1992-09-27 00:00:00	1995-06-17 00:00:00	REN1	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	83011J	1995-05-18 00:00:00	NR	\N	2017-03-13 10:23:05
18	530	1997-09-21 00:00:00	\N	2001-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	83011J	\N	NR	\N	\N
19	290	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	80003V	\N	RP	\N	\N
20	290	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-09-30 00:00:00	REN1	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	80003V	\N	RP	\N	\N
21	440	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	83012K	\N	RP	\N	\N
2281	470	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	REN	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	58411C	\N	NR	\N	\N
2283	850	1981-09-10 00:00:00	\N	1986-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Lionel de TINGUY du POUET, décédé	\N	\N	SENAT	000538	\N	NR	\N	\N
2284	850	1986-10-02 00:00:00	1986-09-28 00:00:00	1987-02-27 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000538	\N	NR	\N	\N
2286	824	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59525R	\N	RP	\N	\N
2287	824	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59525R	\N	RP	\N	\N
2288	824	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59525R	\N	RP	\N	\N
2292	130	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000076	\N	RP	\N	\N
2293	130	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000076	\N	RP	\N	\N
2294	130	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000076	\N	RP	\N	\N
2297	760	1973-04-02 00:00:00	\N	1977-10-02 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. Jean LECANUET, élu député	\N	\N	SENAT	59526S	\N	RP	\N	\N
2299	760	1986-04-02 00:00:00	\N	1986-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Jean LECANUET, élu député	\N	\N	SENAT	59526S	\N	RP	\N	\N
2300	760	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59526S	\N	RP	\N	\N
2302	590	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000326	\N	RP	\N	\N
2303	590	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000326	\N	RP	\N	\N
2973	770	1977-10-03 00:00:00	1977-09-25 00:00:00	1983-04-18 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000308	\N	RP	\N	\N
2975	570	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000207	\N	RP	\N	\N
2976	570	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000207	\N	RP	\N	\N
2977	570	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-07-28 00:00:00	REN2	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000207	\N	RP	\N	\N
2979	830	1978-01-03 00:00:00	\N	1986-04-02 00:00:00	REMPLACE	CESDEPUTE	ANCIEN	\N	\N	En remplacement de M. Pierre Gaudin, décédé	\N	\N	SENAT	000630	\N	RP	\N	\N
2981	380	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	58348N	\N	RP	\N	\N
2983	710	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59539X	\N	NR	\N	\N
2985	40	1969-08-23 00:00:00	\N	1971-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Emile AUBERT	\N	\N	SENAT	000171	\N	NR	\N	\N
2986	40	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-09-28 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000171	\N	NR	\N	\N
2989	820	1978-08-28 00:00:00	\N	1986-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Marceau HAMECHER, décédé	\N	\N	SENAT	58650R	\N	NR	\N	\N
2991	70	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	58039C	\N	NR	\N	\N
2994	500	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58303Y	\N	NR	\N	\N
2995	500	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58303Y	\N	NR	\N	\N
2996	500	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58303Y	\N	NR	\N	\N
2997	500	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-03-03 00:00:00	REN	CESMEMCC	ANCIEN	\N	\N	\N	\N	\N	SENAT	58303Y	\N	NR	\N	\N
2999	670	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59540Q	\N	RP	\N	\N
3000	670	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59540Q	\N	RP	\N	\N
3001	670	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59540Q	\N	RP	\N	\N
3002	670	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN3	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59540Q	\N	RP	\N	\N
3004	260	1968-10-30 00:00:00	\N	1971-10-01 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. Marius MOUTET, décédé	\N	\N	SENAT	000225	\N	NR	\N	\N
3007	670	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000348	\N	RP	\N	\N
3008	670	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000348	\N	RP	\N	\N
3011	670	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000516	\N	RP	\N	\N
3012	670	1986-10-02 00:00:00	1986-09-28 00:00:00	1991-11-03 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000516	\N	RP	\N	\N
3014	670	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000149	\N	RP	\N	\N
3017	670	1976-05-06 00:00:00	\N	1977-10-02 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Michel KISTLER, décédé	\N	\N	SENAT	000213	\N	RP	\N	\N
3021	1029	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000124	\N	NR	\N	\N
3022	1029	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-12-06 00:00:00	REN2	CESDEPUTE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000124	\N	NR	\N	\N
3025	350	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58945E	\N	RP	\N	\N
3026	350	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	58945E	\N	RP	\N	\N
3030	730	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000068	\N	NR	\N	\N
3031	730	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	REN3	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000068	\N	NR	\N	\N
3034	280	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000072	\N	NR	\N	\N
3035	280	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN1	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000072	\N	NR	\N	\N
3038	10	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	58913V	\N	NR	\N	\N
3040	640	1974-10-02 00:00:00	1974-09-22 00:00:00	1980-07-28 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000458	\N	NR	\N	\N
3042	100	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000237	\N	NR	\N	\N
3043	100	1980-10-02 00:00:00	1980-09-28 00:00:00	1981-11-22 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000237	\N	NR	\N	\N
3046	820	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000231	\N	NR	\N	\N
3047	820	1959-04-28 00:00:00	\N	1968-09-22 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000231	\N	NR	\N	\N
3048	820	1968-10-02 00:00:00	1968-09-22 00:00:00	1975-07-29 00:00:00	REN3	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000231	\N	NR	\N	\N
3052	430	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	57449N	\N	NR	\N	\N
2761	335	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59521M	\N	RP	\N	\N
2762	335	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59521M	\N	RP	\N	\N
2763	775	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	59574B	\N	RP	\N	\N
11549	340	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	REN1	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	07030L	\N	SM2	\N	2014-09-28 17:03:41
2765	440	1973-12-14 00:00:00	\N	1974-10-01 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. Maurice SAMBRON, décédé	\N	\N	SENAT	000296	\N	RP	\N	\N
2767	130	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58944D	\N	RP	\N	\N
2768	130	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	58944D	\N	RP	\N	\N
2770	335	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	86027F	\N	RP	\N	\N
2771	335	1995-10-02 00:00:00	1995-09-24 00:00:00	1997-06-12 00:00:00	REN1	CESDEPUTE	ANCIEN	\N	\N	\N	\N	\N	SENAT	86027F	\N	RP	\N	\N
2774	350	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000139	\N	RP	\N	\N
2777	775	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000533	\N	RP	\N	\N
2779	775	1991-06-18 00:00:00	\N	1995-09-24 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Marcel DEBARGE, nommé secrétaire d'Etat	\N	\N	SENAT	000533	\N	RP	\N	\N
2781	620	1992-01-07 00:00:00	\N	1992-09-27 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Michel DARRAS, décédé	\N	\N	SENAT	59229L	\N	RP	\N	\N
2783	100	1980-10-02 00:00:00	1980-09-28 00:00:00	1980-11-01 00:00:00	ELECTION	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	000455	\N	NR	\N	\N
2785	265	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	58668C	\N	RP	\N	\N
3053	430	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	REN3	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	57449N	\N	NR	\N	\N
3055	160	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	80022Y	\N	NR	\N	\N
3056	160	1989-10-02 00:00:00	1989-09-24 00:00:00	1996-07-13 00:00:00	REN1	DECCC	ANCIEN	\N	\N	\N	\N	\N	SENAT	80022Y	\N	NR	\N	\N
3065	982	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000063	\N	NR	\N	\N
3066	982	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000063	\N	NR	\N	\N
3067	982	1974-10-02 00:00:00	1974-09-22 00:00:00	1974-10-13 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000063	\N	NR	\N	\N
3069	615	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	57728S	\N	RP	\N	\N
3071	974	1992-10-02 00:00:00	1992-09-27 00:00:00	1998-02-16 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	92028U	\N	NR	\N	\N
3073	710	1959-04-28 00:00:00	1959-04-26 00:00:00	1967-04-03 00:00:00	ELECTION	CESDEPUTE	ANCIEN	\N	\N	\N	\N	\N	SENAT	56812H	\N	NR	\N	\N
3078	870	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000230	\N	NR	\N	\N
3079	870	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000230	\N	NR	\N	\N
51068	650	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19629C	\N	SM1	2017-09-24 00:00:00	\N
3084	1029	1967-04-18 00:00:00	1967-04-18 00:00:00	1968-09-22 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Bernard LAFAY, député	\N	\N	SENAT	000303	\N	NR	\N	\N
51113	560	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19447X	\N	RP	2017-09-24 00:00:00	\N
4004	971	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000301	\N	NR	\N	\N
4007	320	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58036Y	\N	NR	\N	\N
4008	320	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	REN	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	58036Y	\N	NR	\N	\N
4010	895	1985-03-12 00:00:00	\N	1985-09-01 00:00:00	REMPLACE	DECEDE	ANCIEN	\N	\N	En remplacement de Mme Brigitte GROS, décédée	\N	\N	SENAT	000595	\N	RP	\N	\N
4012	360	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000405	\N	NR	\N	\N
11504	230	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	08012N	\N	SM1	\N	2014-09-28 18:44:07
3622	770	1992-02-24 00:00:00	\N	1995-09-24 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M.Paul Séramy, décédé.	\N	\N	SENAT	59554W	\N	RP	\N	\N
51236	630	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	11104D	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
51237	630	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19387D	\N	RP	2017-09-24 00:00:00	\N
3627	260	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000307	\N	NR	\N	\N
3628	260	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000307	\N	NR	\N	\N
3631	420	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	58341F	\N	RP	\N	\N
51238	630	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19383Y	\N	RP	2017-09-24 00:00:00	\N
12674	630	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	11105E	\N	SM2	\N	2017-09-24 18:20:10
3635	710	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000143	\N	NR	\N	\N
3636	710	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000143	\N	NR	\N	\N
3637	710	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000143	\N	NR	\N	\N
3640	330	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000514	\N	RP	\N	\N
3641	330	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	REN	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000514	\N	RP	\N	\N
3642	330	1989-10-02 00:00:00	1989-09-24 00:00:00	1990-06-14 00:00:00	REN2	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000514	\N	RP	\N	\N
51244	520	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	01058X	\N	SM2	2017-09-24 00:00:00	2017-09-24 00:00:00
51256	530	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	18083K	\N	SM2	2017-09-24 00:00:00	\N
51261	730	2017-09-25 00:00:00	2017-09-24 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	19575F	\N	SM2	2017-09-24 18:51:50	\N
3647	690	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000052	\N	RP	\N	\N
11510	240	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	98029W	\N	SM1	\N	2014-09-28 18:40:55
3648	690	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	REN	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000052	\N	RP	\N	\N
3649	690	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000052	\N	RP	\N	\N
3652	890	1968-10-02 00:00:00	1968-09-22 00:00:00	1973-03-11 00:00:00	ELECTION	CESDEPUTE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000543	\N	NR	\N	\N
51270	1053	2017-10-02 00:00:00	2017-09-24 00:00:00	2018-07-27 00:00:00	ELECTION	ANNCC	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	19707Y	\N	RP	2017-09-24 18:59:59	\N
3656	520	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	57321W	\N	NR	\N	\N
3657	520	1959-04-28 00:00:00	1959-04-26 00:00:00	1961-09-24 00:00:00	REN2	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	57321W	\N	NR	\N	\N
3659	520	1974-10-02 00:00:00	1974-09-22 00:00:00	1981-05-26 00:00:00	ELECTION	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	57321W	\N	NR	\N	\N
3661	995	1981-09-20 00:00:00	1981-09-20 00:00:00	1986-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Albert PEN, élu député.	\N	\N	SENAT	59619W	\N	NR	\N	\N
3663	430	1996-01-25 00:00:00	\N	1998-02-02 00:00:00	REMPLACE	DECEDE	ANCIEN	\N	\N	En remplacement de M. Jean-Paul CHAMBRIARD décédé	\N	\N	SENAT	96002B	\N	NR	\N	\N
51271	1053	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19709B	\N	RP	2017-09-24 00:00:00	\N
3667	1020	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000211	\N	NR	\N	\N
3668	1020	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000211	\N	NR	\N	\N
3669	824	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000211	\N	RP	\N	\N
3670	824	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	REN	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000211	\N	RP	\N	\N
3671	824	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000211	\N	RP	\N	\N
3674	720	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000178	\N	NR	\N	\N
3677	280	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	58916Y	\N	NR	\N	\N
3679	540	1961-08-23 00:00:00	\N	1965-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Raymond PINCHARD, décédé.	\N	\N	SENAT	000108	\N	RP	\N	\N
3682	828	1989-01-10 00:00:00	\N	1995-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Pierre SALVI, décédé.	\N	\N	SENAT	59556Y	\N	RP	\N	\N
3685	1000	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	56522A	\N	NR	\N	\N
3686	440	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN2	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	56522A	\N	RP	\N	\N
3688	335	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000476	\N	RP	\N	\N
3689	335	1986-10-02 00:00:00	1986-09-28 00:00:00	1992-03-20 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000476	\N	RP	\N	\N
3691	983	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000141	\N	NR	\N	\N
3694	350	1971-07-23 00:00:00	\N	1971-10-01 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. Roger Du Halgouet, décédé.	\N	\N	SENAT	000156	\N	RP	\N	\N
3699	620	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-07-09 00:00:00	ELECTION	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	59242H	\N	RP	\N	\N
3701	620	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59242H	\N	RP	\N	\N
3702	620	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59242H	\N	RP	\N	\N
3704	540	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000470	\N	RP	\N	\N
3705	540	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000470	\N	RP	\N	\N
3707	300	1988-09-04 00:00:00	1988-09-04 00:00:00	1989-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	88010E	\N	NR	\N	\N
11526	170	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-04-24 00:00:00	REN2	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	89014N	\N	SM1	\N	2014-05-12 18:06:27
3708	300	1989-10-02 00:00:00	1989-09-24 00:00:00	1997-09-11 00:00:00	REN1	DECCC	ANCIEN	\N	\N	\N	\N	\N	SENAT	88010E	\N	NR	\N	\N
3710	510	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000202	\N	NR	\N	\N
3713	290	1978-08-30 00:00:00	\N	1980-10-01 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. André COLIN, décédé.	\N	\N	SENAT	000275	\N	RP	\N	\N
3716	430	1974-10-02 00:00:00	1974-09-22 00:00:00	1978-03-12 00:00:00	ELECTION	CESDEPUTE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000639	\N	NR	\N	\N
3718	590	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	59244K	\N	RP	\N	\N
3720	590	1974-10-02 00:00:00	1974-09-22 00:00:00	1977-09-30 00:00:00	ELECTION	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	000085	\N	RP	\N	\N
3723	30	1972-05-09 00:00:00	\N	1980-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Jean NEGRE, décédé	\N	\N	SENAT	58918B	\N	NR	\N	\N
3724	30	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	58918B	\N	NR	\N	\N
51074	660	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN1	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	11101A	\N	SM1	2017-09-24 00:00:00	2017-09-24 00:00:00
51076	610	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	07004J	\N	SM1	2017-09-24 00:00:00	2017-09-24 00:00:00
51272	1053	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	11027H	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
3730	974	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	59245L	\N	NR	\N	\N
51273	1053	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN	NONREELU	ANCIEN	\N	Nouveau	\N	\N	2023	\N	11026G	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
3733	130	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58926B	\N	RP	\N	\N
3734	130	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58926B	\N	RP	\N	\N
3735	130	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58926B	\N	RP	\N	\N
3736	130	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	58926B	\N	RP	\N	\N
3738	130	1966-03-11 00:00:00	\N	1971-10-01 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. Vincent DELPUECH, décédé	\N	\N	SENAT	000007	\N	RP	\N	\N
3741	60	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000104	\N	RP	\N	\N
3742	60	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000104	\N	RP	\N	\N
3743	60	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000104	\N	RP	\N	\N
3744	60	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000104	\N	RP	\N	\N
3745	60	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000104	\N	RP	\N	\N
3748	974	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000293	\N	NR	\N	\N
3749	974	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000293	\N	NR	\N	\N
3750	974	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000293	\N	NR	\N	\N
3751	974	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	REN3	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000293	\N	NR	\N	\N
3754	800	1972-12-11 00:00:00	\N	1976-12-15 00:00:00	REMPLACE	DECEDE	ANCIEN	\N	\N	En remplacement de M. Pierre GARET, décédé	\N	\N	SENAT	000077	\N	NR	\N	\N
3756	70	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000158	\N	NR	\N	\N
3757	70	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000158	\N	NR	\N	\N
3758	70	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	REN2	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000158	\N	NR	\N	\N
3761	828	1995-10-02 00:00:00	1995-09-24 00:00:00	1997-07-04 00:00:00	ELECTION	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	95063L	\N	RP	\N	\N
3764	170	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	58938F	\N	NR	\N	\N
3766	680	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000142	\N	RP	\N	\N
3767	680	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	REN	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000142	\N	RP	\N	\N
3770	860	1977-05-03 00:00:00	\N	1977-10-02 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. René MONORY, nommé membre du Gouvernement	\N	\N	SENAT	77003V	\N	NR	\N	\N
3772	860	1977-11-03 00:00:00	\N	1981-05-20 00:00:00	REMPLACE	DEM	ANCIEN	\N	\N	En remplacement de M. René MONORY, nommé membre du Gouvernement	\N	\N	SENAT	77003V	\N	NR	\N	\N
3774	860	1986-04-20 00:00:00	\N	1986-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. René MONORY, nommé membre du Gouvernement	\N	\N	SENAT	77003V	\N	NR	\N	\N
3775	860	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	77003V	\N	NR	\N	\N
3777	860	1995-11-02 00:00:00	\N	1997-06-30 00:00:00	REMPLACE	DEM	ANCIEN	\N	\N	En remplacement de M. Jean-Pierre Raffarin, nommé membre du Gouvernement	\N	\N	SENAT	77003V	\N	NR	\N	\N
3779	150	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	58919C	\N	NR	\N	\N
3781	60	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000125	\N	RP	\N	\N
3782	60	1980-10-02 00:00:00	1980-09-28 00:00:00	1984-12-25 00:00:00	REN1	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000125	\N	RP	\N	\N
3784	895	1995-10-02 00:00:00	1995-09-24 00:00:00	1997-11-18 00:00:00	ELECTION	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	95064M	\N	RP	\N	\N
3787	1002	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-09-23 00:00:00	REN	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000281	\N	NR	\N	\N
3792	850	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	56305S	\N	NR	\N	\N
11497	320	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	98032R	\N	SM1	\N	2014-09-28 19:07:43
10933	615	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	04075M	\N	RP	\N	\N
10935	828	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	04076N	\N	RP	\N	\N
10945	335	2004-10-01 00:00:00	2004-09-26 00:00:00	2007-06-24 00:00:00	REN1	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	99004R	\N	RP	\N	\N
10946	335	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	2011	SENAT	95006B	\N	RP	\N	\N
10947	335	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	REN1	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	95007C	\N	RP	\N	\N
6399	380	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	01019Q	\N	RP	\N	\N
5128	240	1998-10-01 00:00:00	1998-09-27 00:00:00	2002-06-07 00:00:00	ELECTION	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	98031Q	2002-05-07 00:00:00	NR	\N	2016-12-14 15:19:07
10949	335	2004-10-01 00:00:00	2004-09-26 00:00:00	2007-06-28 00:00:00	REN1	CESDEPUTE	ANCIEN	\N	\N	\N	\N	\N	SENAT	00002B	\N	RP	\N	\N
10951	335	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	REN3	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	77019E	\N	RP	\N	\N
10950	828	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04078Q	\N	RP	\N	\N
10953	335	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	77053G	\N	RP	\N	\N
10963	615	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04080J	\N	RP	\N	\N
10966	335	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04081K	\N	RP	\N	\N
10967	775	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	95046K	\N	RP	\N	\N
5158	80	1998-10-01 00:00:00	1998-09-27 00:00:00	2004-10-18 00:00:00	REN1	DECEDE	ANCIEN	\N	\N	\N	\N	2004	SENAT	96005E	\N	NR	\N	\N
10968	775	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	95060H	\N	RP	\N	\N
10969	775	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	95024D	\N	RP	\N	\N
10970	775	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	04082L	\N	RP	\N	\N
10976	720	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	95019G	\N	NR	\N	2014-09-28 16:59:41
10978	850	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	04083M	\N	NR	\N	2014-09-28 16:40:50
10982	700	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	04084N	\N	NR	\N	2014-09-28 13:40:33
5170	350	1998-10-01 00:00:00	1998-09-27 00:00:00	2003-08-28 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	2003	SENAT	98043U	\N	RP	\N	\N
10981	775	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04085P	\N	RP	\N	\N
10984	775	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04086Q	\N	RP	\N	\N
10989	810	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	04087R	\N	NR	\N	2014-09-28 13:39:21
10994	880	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04088S	\N	NR	\N	2014-09-28 18:47:01
10997	800	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	95025E	\N	NR	\N	2014-09-28 17:09:16
10998	800	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	95047L	\N	NR	\N	2014-09-28 17:09:16
10999	790	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	95009E	\N	NR	\N	2014-09-28 12:56:42
11000	790	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	95028H	\N	NR	\N	2014-09-28 12:56:41
11001	800	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04089T	\N	NR	\N	2014-09-28 17:09:16
11002	730	2004-10-01 00:00:00	2004-09-26 00:00:00	2012-07-21 00:00:00	ELECTION	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	04090L	2012-06-21 00:00:00	NR	\N	2016-12-14 15:29:09
11004	710	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95020Y	\N	NR	\N	2014-09-28 17:55:37
11007	710	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	04091M	\N	NR	\N	2014-09-28 17:55:37
11013	840	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95037J	\N	NR	\N	2014-09-28 17:35:38
11014	840	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	REN2	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	87003B	\N	NR	\N	2015-02-13 11:02:16
11015	840	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04092N	\N	NR	\N	2014-09-28 17:35:38
11017	972	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	REN1	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	95044H	\N	NR	\N	\N
11021	971	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	95050F	\N	NR	\N	\N
11022	995	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	04093P	\N	NR	\N	\N
5230	760	1998-10-03 00:00:00	\N	2004-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Robert Pagès, démissionnaire	\N	\N	SENAT	98053W	\N	RP	\N	\N
5269	810	1998-11-03 00:00:00	\N	2004-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Georges Mazars, décédé	\N	\N	SENAT	98054X	\N	NR	\N	\N
12610	590	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	92018S	\N	RP	\N	2017-09-24 18:16:52
5302	1000	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000703	\N	NR	\N	\N
5303	440	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000703	\N	RP	\N	\N
51229	895	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	11090Q	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
51230	895	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	86034E	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
5308	100	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000724	\N	NR	\N	\N
5309	100	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000724	\N	NR	\N	\N
5311	100	1962-10-02 00:00:00	1962-09-23 00:00:00	1967-10-17 00:00:00	REN5	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000724	\N	NR	\N	\N
51231	895	2017-10-02 00:00:00	2017-09-24 00:00:00	2020-09-30 00:00:00	ELECTION	DEM	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	04018C	\N	RP	2017-09-24 18:17:55	\N
5314	140	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000689	\N	NR	\N	\N
5315	140	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000689	\N	NR	\N	\N
5316	140	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN3	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000689	\N	NR	\N	\N
51232	895	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19697Q	\N	RP	2017-09-24 00:00:00	\N
5320	720	1952-05-18 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000757	\N	NR	\N	\N
5321	720	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	REN2	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000757	\N	NR	\N	\N
51233	895	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19699S	\N	RP	2017-09-24 00:00:00	\N
51234	895	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19701S	\N	RP	2017-09-24 00:00:00	\N
12597	895	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	11096W	\N	RP	\N	2017-09-24 18:17:56
5327	650	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000733	\N	NR	\N	\N
5328	650	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN4	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000733	\N	NR	\N	\N
11486	270	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	08009T	\N	SM1	\N	2014-09-28 18:19:47
5329	650	1965-10-02 00:00:00	1965-09-26 00:00:00	1966-12-22 00:00:00	REN5	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000733	\N	NR	\N	\N
5331	410	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000731	\N	NR	\N	\N
5332	410	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000731	\N	NR	\N	\N
5333	410	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	REN2	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000731	\N	NR	\N	\N
12732	895	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	11091R	\N	RP	\N	2017-09-24 18:17:56
51240	420	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19415P	\N	RP	2017-09-24 00:00:00	\N
5338	1020	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000701	\N	NR	\N	\N
5339	1020	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000701	\N	NR	\N	\N
5340	824	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	REN4	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000701	\N	RP	\N	\N
51241	420	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN3	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	97011G	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
51242	420	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19413M	\N	RP	2017-09-24 00:00:00	\N
5347	380	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000711	\N	RP	\N	\N
5348	380	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000711	\N	RP	\N	\N
5351	30	1962-10-02 00:00:00	1962-09-23 00:00:00	1970-11-23 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000682	\N	NR	\N	\N
51243	420	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	11056N	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
51245	650	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19631V	\N	SM2	2017-09-24 00:00:00	\N
5355	410	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000761	\N	NR	\N	\N
51254	400	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	17779H	\N	SM2	2017-09-24 00:00:00	\N
51255	400	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19489J	\N	SM2	2017-09-24 00:00:00	\N
5359	120	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000696	\N	NR	\N	\N
5360	120	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000696	\N	NR	\N	\N
5361	120	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN4	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000696	\N	NR	\N	\N
5364	440	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-03-02 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000718	\N	RP	\N	\N
5366	810	1974-10-20 00:00:00	\N	1977-10-02 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Fernand Verdeille, décédé	\N	\N	SENAT	000690	\N	NR	\N	\N
5369	270	1957-11-17 00:00:00	\N	1959-04-27 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000756	\N	NR	\N	\N
5370	270	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-11-23 00:00:00	REN	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000756	\N	NR	\N	\N
5375	550	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000760	\N	NR	\N	\N
5376	550	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000760	\N	NR	\N	\N
5377	550	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	REN4	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000760	\N	NR	\N	\N
5380	340	1976-09-28 00:00:00	\N	1979-09-03 00:00:00	REMPLACE	DECEDE	ANCIEN	\N	\N	En remplacement de M. Pierre BROUSSE, nommé membre du Gouvernement	\N	\N	SENAT	000735	\N	NR	\N	\N
5384	800	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000755	\N	NR	\N	\N
5385	800	1959-04-28 00:00:00	1959-04-26 00:00:00	1966-05-26 00:00:00	REN3	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000755	\N	NR	\N	\N
5389	80	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000722	\N	NR	\N	\N
5390	80	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000722	\N	NR	\N	\N
5391	80	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN4	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000722	\N	NR	\N	\N
5396	720	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000723	\N	NR	\N	\N
5397	720	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	REN3	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000723	\N	NR	\N	\N
3475	265	1968-10-02 00:00:00	1968-09-22 00:00:00	1975-11-01 00:00:00	REN	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	000187	\N	RP	\N	\N
3478	600	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000126	\N	NR	\N	\N
3479	600	1974-09-26 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000126	\N	NR	\N	\N
3480	600	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000126	\N	NR	\N	\N
3485	590	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000079	\N	RP	\N	\N
3486	590	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000079	\N	RP	\N	\N
3487	590	1965-10-02 00:00:00	1965-09-26 00:00:00	1967-04-03 00:00:00	REN	CESDEPUTE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000079	\N	RP	\N	\N
3490	90	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000352	\N	NR	\N	\N
3491	90	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000352	\N	NR	\N	\N
3492	90	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000352	\N	NR	\N	\N
3493	90	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	REN3	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000352	\N	NR	\N	\N
3496	30	1971-10-02 00:00:00	1971-09-26 00:00:00	1972-05-08 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000166	\N	NR	\N	\N
3498	720	1959-04-28 00:00:00	1959-04-26 00:00:00	1963-11-21 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000428	\N	NR	\N	\N
3500	265	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	58636T	\N	RP	\N	\N
3502	350	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000096	\N	RP	\N	\N
3503	350	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000096	\N	RP	\N	\N
3506	680	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000119	\N	RP	\N	\N
3509	610	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59240F	\N	NR	\N	\N
3510	610	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	REN	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	59240F	\N	NR	\N	\N
3512	265	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	58645U	\N	RP	\N	\N
3514	983	1971-10-02 00:00:00	1971-09-26 00:00:00	1977-01-10 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000019	\N	NR	\N	\N
3516	200	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000419	\N	NR	\N	\N
3517	200	1989-10-02 00:00:00	1989-09-24 00:00:00	1994-02-19 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000419	\N	NR	\N	\N
3519	290	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000437	\N	RP	\N	\N
3522	1029	1967-04-03 00:00:00	\N	1968-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Jacques BAUMEL, élu député	\N	\N	SENAT	000488	\N	NR	\N	\N
3523	615	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000488	\N	RP	\N	\N
3524	615	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000488	\N	RP	\N	\N
3525	615	1986-10-02 00:00:00	1986-09-28 00:00:00	1989-05-18 00:00:00	REN3	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000488	\N	RP	\N	\N
3527	890	1973-06-03 00:00:00	1973-06-03 00:00:00	1977-10-02 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. Jacques Piot, élu député.	\N	\N	SENAT	000254	\N	NR	\N	\N
3530	60	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000393	\N	RP	\N	\N
3531	60	1980-10-02 00:00:00	1980-09-28 00:00:00	1985-05-13 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000393	\N	RP	\N	\N
3533	660	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000412	\N	NR	\N	\N
3534	660	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000412	\N	NR	\N	\N
3535	660	1974-10-02 00:00:00	1974-09-22 00:00:00	1981-02-19 00:00:00	REN2	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000412	\N	NR	\N	\N
3537	335	1975-11-09 00:00:00	\N	1977-10-02 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. Edmond Barrachin, décédé.	\N	\N	SENAT	57761T	\N	RP	\N	\N
3539	615	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000521	\N	RP	\N	\N
3543	160	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000109	\N	NR	\N	\N
3544	160	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000109	\N	NR	\N	\N
3545	160	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000109	\N	NR	\N	\N
3546	160	1971-10-02 00:00:00	1971-09-26 00:00:00	1979-12-07 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000109	\N	NR	\N	\N
3549	100	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000182	\N	NR	\N	\N
3550	100	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000182	\N	NR	\N	\N
3551	100	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN3	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000182	\N	NR	\N	\N
3554	600	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000112	\N	NR	\N	\N
3559	230	1955-06-19 00:00:00	\N	1962-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000048	\N	NR	\N	\N
3560	230	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000048	\N	NR	\N	\N
3561	230	1971-10-02 00:00:00	1971-09-26 00:00:00	1973-06-27 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000048	\N	NR	\N	\N
3563	740	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59553V	\N	NR	\N	\N
3564	740	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59553V	\N	NR	\N	\N
3566	770	1995-03-04 00:00:00	\N	1995-09-23 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. Etienne DAILLY, nommé membre du Conseil constitutionnel	\N	\N	SENAT	59578F	\N	RP	\N	\N
3568	20	1966-06-26 00:00:00	1966-06-26 00:00:00	1971-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	66002K	\N	NR	\N	\N
3569	20	1971-10-03 00:00:00	1971-09-26 00:00:00	1978-05-06 00:00:00	REN	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	66002K	\N	NR	\N	\N
3571	20	1980-09-28 00:00:00	1980-09-28 00:00:00	1988-06-12 00:00:00	ELECTION	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	66002K	\N	NR	\N	\N
3575	995	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59579G	\N	NR	\N	\N
3576	995	1977-10-03 00:00:00	1977-09-25 00:00:00	1981-06-21 00:00:00	REN1	CESDEPUTE	ANCIEN	\N	\N	\N	\N	\N	SENAT	59579G	\N	NR	\N	\N
3578	995	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	59579G	\N	NR	\N	\N
3581	450	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000008	\N	NR	\N	\N
3799	820	1984-03-21 00:00:00	\N	1986-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Pierre TAJAN, décédé	\N	\N	SENAT	59558B	\N	NR	\N	\N
3800	820	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59558B	\N	NR	\N	\N
3802	520	1972-11-28 00:00:00	1972-11-28 00:00:00	1974-10-01 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. Pierre René MATHEY, décédé	\N	\N	SENAT	000174	\N	NR	\N	\N
3806	230	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000128	\N	NR	\N	\N
3807	230	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000128	\N	NR	\N	\N
3808	230	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000128	\N	NR	\N	\N
3811	615	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59312E	\N	RP	\N	\N
3812	615	1986-10-02 00:00:00	1986-09-28 00:00:00	1993-04-30 00:00:00	REN	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	59312E	1993-03-29 00:00:00	RP	\N	2016-12-14 15:30:04
3814	999	1971-08-11 00:00:00	\N	1974-02-04 00:00:00	REMPLACE	DECEDE	ANCIEN	\N	\N	En remplacement de M. Léon MOTAIS DE NARBONNE, décédé	\N	\N	SENAT	000172	\N	RP	\N	\N
3816	824	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	58638V	\N	RP	\N	\N
3820	60	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000044	\N	RP	\N	\N
3821	60	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000044	\N	RP	\N	\N
3822	60	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000044	\N	RP	\N	\N
3825	240	1988-02-06 00:00:00	\N	1989-10-01 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M Lucien DELMAS, décédé	\N	\N	SENAT	58929E	\N	NR	\N	\N
3827	30	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	57146A	\N	NR	\N	\N
3828	30	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	57146A	\N	NR	\N	\N
3830	480	1973-06-26 00:00:00	\N	1974-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Georges BONNET, décédé	\N	\N	SENAT	000443	\N	NR	\N	\N
3831	480	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000443	\N	NR	\N	\N
3832	480	1983-10-03 00:00:00	1983-09-25 00:00:00	1985-05-26 00:00:00	REN2	DECEDE	ANCIEN	\N	\N	\N	\N	1985	SENAT	000443	\N	NR	\N	\N
3834	824	1995-10-02 00:00:00	1995-09-24 00:00:00	1997-10-15 00:00:00	ELECTION	CESDEPUTE	ANCIEN	\N	\N	\N	\N	\N	SENAT	95065N	\N	RP	\N	\N
3837	998	1983-10-03 00:00:00	1983-10-03 00:00:00	1992-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000214	\N	RP	\N	\N
3839	670	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000505	\N	RP	\N	\N
3840	670	1986-10-02 00:00:00	1986-09-28 00:00:00	1992-03-05 00:00:00	REN	CESMEMCC	ANCIEN	\N	\N	\N	\N	\N	SENAT	000505	\N	RP	\N	\N
3843	10	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58928D	\N	NR	\N	\N
3844	10	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	58928D	\N	NR	\N	\N
3846	640	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-05-31 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000453	\N	NR	\N	\N
3848	828	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000564	\N	RP	\N	\N
3849	828	1986-10-02 00:00:00	1986-09-28 00:00:00	1989-01-09 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000564	\N	RP	\N	\N
3851	615	1976-02-13 00:00:00	\N	1977-10-02 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Pierre-Christian TAITTINGER	\N	\N	SENAT	57752S	\N	RP	\N	\N
3853	490	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58336J	\N	NR	\N	\N
3854	490	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	58336J	\N	NR	\N	\N
3856	800	1973-11-17 00:00:00	\N	1977-10-02 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Pierre MAILLE, décédé	\N	\N	SENAT	57738U	\N	NR	\N	\N
3858	680	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59559C	\N	RP	\N	\N
3859	680	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59559C	\N	RP	\N	\N
3860	680	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59559C	\N	RP	\N	\N
3864	550	1958-05-18 00:00:00	\N	1959-04-27 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000278	\N	NR	\N	\N
3865	550	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000278	\N	NR	\N	\N
3866	550	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	REN	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000278	\N	NR	\N	\N
3867	550	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000278	\N	NR	\N	\N
3870	335	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58662V	\N	RP	\N	\N
3871	335	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	58662V	\N	RP	\N	\N
3873	570	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58352J	\N	RP	\N	\N
3982	410	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59248P	\N	NR	\N	\N
3984	80	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000312	\N	NR	\N	\N
3985	80	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000312	\N	NR	\N	\N
3986	80	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000312	\N	NR	\N	\N
11503	230	2008-10-01 00:00:00	2008-09-21 00:00:00	2009-09-09 00:00:00	REN1	DECEDE	ANCIEN	\N	\N	\N	\N	2009	SENAT	80024B	\N	SM1	\N	\N
3987	80	1980-10-02 00:00:00	1980-09-28 00:00:00	1984-03-06 00:00:00	REN3	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000312	\N	NR	\N	\N
3991	1004	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000251	\N	NR	\N	\N
3992	1004	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000251	\N	NR	\N	\N
3993	1004	1965-10-02 00:00:00	1965-09-26 00:00:00	1969-07-22 00:00:00	REN	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	000251	\N	NR	\N	\N
3996	850	1977-10-03 00:00:00	1977-09-25 00:00:00	1981-09-09 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000268	\N	NR	\N	\N
3998	500	1983-03-04 00:00:00	\N	1983-10-02 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Léon JOZEAU-MARIGNE, nommé membre du Conseil Constitutionnel	\N	\N	SENAT	83001G	\N	NR	\N	\N
3999	500	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	83001G	\N	NR	\N	\N
4000	500	1992-10-02 00:00:00	\N	1996-05-15 00:00:00	REN2	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	83001G	\N	NR	\N	\N
4002	270	1980-10-02 00:00:00	1980-09-28 00:00:00	1983-05-05 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000417	\N	NR	\N	\N
11499	70	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	98037W	\N	SM1	\N	2014-09-28 14:31:42
3874	570	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	58352J	\N	RP	\N	\N
3876	590	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	74044S	\N	RP	\N	\N
3877	590	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	74044S	\N	RP	\N	\N
3878	590	1992-10-02 00:00:00	1992-09-27 00:00:00	1998-02-09 00:00:00	REN2	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	74044S	\N	RP	\N	\N
3883	570	1959-04-28 00:00:00	1959-04-26 00:00:00	1960-05-09 00:00:00	REN3	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000147	\N	RP	\N	\N
3885	250	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59307H	\N	NR	\N	\N
3886	250	1980-10-02 00:00:00	1980-09-28 00:00:00	1988-06-24 00:00:00	REN	CESDEPUTE	ANCIEN	\N	\N	\N	\N	\N	SENAT	59307H	\N	NR	\N	\N
3888	335	1992-03-21 00:00:00	\N	1995-09-24 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. Robert PONTILLON, décédé	\N	\N	SENAT	59581A	\N	RP	\N	\N
3890	320	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58933A	\N	NR	\N	\N
3891	320	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58933A	\N	NR	\N	\N
3892	320	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58933A	\N	NR	\N	\N
3893	320	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58933A	\N	NR	\N	\N
3894	320	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	58933A	\N	NR	\N	\N
3896	770	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000440	\N	RP	\N	\N
3897	770	1986-10-02 00:00:00	1986-09-28 00:00:00	1992-02-23 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000440	\N	RP	\N	\N
3899	310	1971-08-02 00:00:00	\N	1971-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Charles SURAN	\N	\N	SENAT	000168	\N	RP	\N	\N
3901	640	1971-01-18 00:00:00	\N	1974-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Jean ERRECART, décédé	\N	\N	SENAT	000101	\N	NR	\N	\N
3904	180	1983-03-29 00:00:00	\N	1989-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Charles DURAND, décédé	\N	\N	SENAT	000369	\N	NR	\N	\N
3907	265	1986-10-02 00:00:00	1986-09-28 00:00:00	1993-11-06 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000373	\N	RP	\N	\N
3909	120	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000364	\N	NR	\N	\N
3910	120	1980-10-02 00:00:00	1980-09-28 00:00:00	1980-11-18 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000364	\N	NR	\N	\N
3915	830	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000279	\N	RP	\N	\N
3916	830	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	REN	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000279	\N	RP	\N	\N
3917	830	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	REN	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000279	\N	RP	\N	\N
3918	830	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000279	\N	RP	\N	\N
3921	210	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000452	\N	NR	\N	\N
3922	210	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000452	\N	NR	\N	\N
3925	510	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000123	\N	NR	\N	\N
3926	510	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000123	\N	NR	\N	\N
3929	1020	1959-04-28 00:00:00	\N	1968-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000298	\N	NR	\N	\N
3930	895	1968-10-02 00:00:00	1968-09-22 00:00:00	1974-06-28 00:00:00	REN	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	000298	\N	RP	\N	\N
3933	570	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	59247N	\N	RP	\N	\N
3935	110	1968-09-24 00:00:00	\N	1971-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Jules FIL, décédé	\N	\N	SENAT	000334	\N	NR	\N	\N
3937	80	1989-10-02 00:00:00	1989-09-24 00:00:00	1996-07-09 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	89005M	\N	NR	\N	\N
3939	810	1977-10-03 00:00:00	1977-09-25 00:00:00	1983-08-20 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000330	\N	NR	\N	\N
3941	620	1981-06-22 00:00:00	\N	1983-10-02 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Marcel Wacheux, élu député	\N	\N	SENAT	000287	\N	RP	\N	\N
3943	680	1965-10-02 00:00:00	1965-09-26 00:00:00	1966-10-14 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000499	\N	RP	\N	\N
3945	310	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000120	\N	RP	\N	\N
3946	310	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000120	\N	RP	\N	\N
3947	310	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-08-01 00:00:00	REN2	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000120	\N	RP	\N	\N
3950	300	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000095	\N	NR	\N	\N
3951	300	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000095	\N	NR	\N	\N
3952	300	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000095	\N	NR	\N	\N
3953	300	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	REN	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000095	\N	NR	\N	\N
3954	300	1980-10-02 00:00:00	1980-09-28 00:00:00	1986-06-23 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000095	\N	NR	\N	\N
5426	300	1971-10-02 00:00:00	1971-09-26 00:00:00	1976-07-11 00:00:00	REN2	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000769	\N	NR	\N	\N
3956	615	1968-10-02 00:00:00	1968-09-22 00:00:00	1976-02-12 00:00:00	ELECTION	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	59560U	\N	RP	\N	\N
3958	615	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59560U	\N	RP	\N	\N
3959	615	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59560U	\N	RP	\N	\N
3961	820	1975-09-28 00:00:00	1975-09-28 00:00:00	1977-10-02 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000592	\N	NR	\N	\N
3962	820	1977-10-03 00:00:00	1977-09-25 00:00:00	1984-03-20 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000592	\N	NR	\N	\N
3966	1020	1963-02-01 00:00:00	\N	1968-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Waldeck L'HUILLIER, élu député	\N	\N	SENAT	000302	\N	NR	\N	\N
3967	824	1968-10-02 00:00:00	1968-09-22 00:00:00	1975-04-30 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000302	\N	RP	\N	\N
3971	973	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	58950B	\N	NR	\N	\N
3973	100	1968-10-02 00:00:00	1968-09-22 00:00:00	1971-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000006	\N	NR	\N	\N
3974	100	1971-10-02 00:00:00	1971-09-26 00:00:00	1978-10-13 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	1978	SENAT	000006	\N	NR	\N	\N
3976	760	1965-12-18 00:00:00	\N	1968-10-01 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M Henri Paumelle, décédé	\N	\N	SENAT	000118	\N	RP	\N	\N
3979	1029	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	56829S	\N	NR	\N	\N
3981	410	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59248P	\N	NR	\N	\N
3194	620	1973-04-02 00:00:00	\N	1974-09-21 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Jean BARDOL, élu député	\N	\N	SENAT	57830P	\N	RP	\N	\N
3195	620	1974-10-02 00:00:00	1974-09-22 00:00:00	1978-10-01 00:00:00	REN	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	57830P	\N	RP	\N	\N
3198	280	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-09-22 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	57130R	\N	NR	\N	\N
3199	280	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN2	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	57130R	\N	NR	\N	\N
3201	1026	1989-10-02 00:00:00	\N	1997-06-12 00:00:00	ELECTION	CESDEPUTE	ANCIEN	\N	\N	\N	\N	\N	SENAT	89033R	\N	NR	\N	\N
3204	580	1967-06-11 00:00:00	1967-06-11 00:00:00	1974-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000005	\N	NR	\N	\N
51258	660	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19703U	\N	SM2	2017-09-24 00:00:00	\N
3208	590	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000200	\N	RP	\N	\N
3209	590	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000200	\N	RP	\N	\N
3210	590	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	REN3	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000200	\N	RP	\N	\N
3213	972	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-09-27 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59546W	\N	NR	\N	\N
3214	972	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59546W	\N	NR	\N	\N
3216	290	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58925A	\N	RP	\N	\N
3217	290	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	REN	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	58925A	\N	RP	\N	\N
51262	480	2017-10-02 00:00:00	2017-09-24 00:00:00	2020-03-03 00:00:00	REN	DECEDE	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	11081P	\N	SM2	2017-09-24 18:52:13	2017-09-24 18:54:30
3220	997	1955-06-28 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000017	\N	RP	\N	\N
3221	997	1959-05-05 00:00:00	1959-05-05 00:00:00	1962-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000017	\N	RP	\N	\N
3222	997	1962-10-04 00:00:00	1962-10-04 00:00:00	1969-03-20 00:00:00	REN3	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000017	\N	RP	\N	\N
3224	870	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-09-27 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000351	\N	NR	\N	\N
3225	870	1986-10-02 00:00:00	1986-09-28 00:00:00	1990-08-11 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000351	\N	NR	\N	\N
3227	971	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59547X	\N	NR	\N	\N
3229	140	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000015	\N	NR	\N	\N
3230	140	1962-10-02 00:00:00	1962-09-23 00:00:00	1970-06-13 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000015	\N	NR	\N	\N
3232	700	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59548Y	\N	NR	\N	\N
3233	700	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59548Y	\N	NR	\N	\N
3235	720	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000004	\N	NR	\N	\N
3238	710	1971-10-29 00:00:00	\N	1977-10-02 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Marcel LEGROS, décédé	\N	\N	SENAT	59549A	\N	NR	\N	\N
3239	710	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59549A	\N	NR	\N	\N
3240	710	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59549A	\N	NR	\N	\N
3242	895	1977-10-03 00:00:00	1977-09-25 00:00:00	1982-08-15 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000633	\N	RP	\N	\N
3244	650	1966-12-23 00:00:00	\N	1974-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Paul BARATGIN, décédé	\N	\N	SENAT	000223	\N	NR	\N	\N
3247	800	1966-07-17 00:00:00	1966-07-17 00:00:00	1968-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000518	\N	NR	\N	\N
3248	800	1968-10-02 00:00:00	1968-09-22 00:00:00	1973-11-16 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000518	\N	NR	\N	\N
3250	660	1981-02-20 00:00:00	\N	1983-10-02 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Gaston PAMS, décédé.	\N	\N	SENAT	000059	\N	NR	\N	\N
3253	150	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58947G	\N	NR	\N	\N
3254	150	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	58947G	\N	NR	\N	\N
3256	660	1983-10-03 00:00:00	1983-09-25 00:00:00	1987-12-03 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000611	\N	NR	\N	\N
3258	560	1974-10-02 00:00:00	1974-09-22 00:00:00	1981-06-21 00:00:00	ELECTION	CESDEPUTE	ANCIEN	\N	\N	\N	\N	\N	SENAT	59715V	\N	NR	\N	\N
51269	1053	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19705W	\N	RP	2017-09-24 00:00:00	\N
3261	160	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000236	\N	NR	\N	\N
3262	160	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000236	\N	NR	\N	\N
3263	160	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000236	\N	NR	\N	\N
11501	150	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	98027U	\N	SM1	\N	2014-09-28 13:01:25
3264	160	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	REN	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000236	\N	NR	\N	\N
3267	265	1993-11-07 00:00:00	\N	1995-09-24 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. Jean Simonin, décédé	\N	\N	SENAT	93007T	\N	RP	\N	\N
3269	1029	1959-05-29 00:00:00	\N	1962-05-15 00:00:00	REMPLACE	CESMEMGVT	ANCIEN	\N	\N	En remplacement de M. Edmond MICHELET, ministre	\N	\N	SENAT	000498	\N	NR	\N	\N
3272	972	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	57749X	\N	NR	\N	\N
3273	972	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	57749X	\N	NR	\N	\N
3275	730	1974-05-23 00:00:00	\N	1977-10-02 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de Jean-Baptiste MATHIAS, décédé	\N	\N	SENAT	000227	\N	NR	\N	\N
3278	775	1975-04-26 00:00:00	\N	1977-10-02 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Jacques DUCLOS, décédé	\N	\N	SENAT	58633Q	\N	RP	\N	\N
3279	775	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	58633Q	\N	RP	\N	\N
3281	760	1993-03-03 00:00:00	\N	1993-11-07 00:00:00	REMPLACE	DECEDE	ANCIEN	\N	\N	En remplacement de M. Geoffroy de MONTALEMBERT, décédé	\N	\N	SENAT	000561	\N	RP	\N	\N
3283	540	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59235J	\N	RP	\N	\N
3284	540	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59235J	\N	RP	\N	\N
3286	420	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58342G	\N	RP	\N	\N
3287	420	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58342G	\N	RP	\N	\N
3288	420	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	58342G	\N	RP	\N	\N
3290	540	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	57456M	\N	RP	\N	\N
11525	170	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	89013M	\N	SM1	\N	2014-09-28 17:05:42
3292	895	1982-08-16 00:00:00	\N	1986-10-01 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de Philippe MACHEFER, décédé	\N	\N	SENAT	58621L	\N	RP	\N	\N
3294	1026	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000136	\N	NR	\N	\N
3300	570	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	83042R	\N	RP	\N	\N
3301	570	1992-10-02 00:00:00	1992-09-27 00:00:00	1997-07-04 00:00:00	REN1	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	83042R	\N	RP	\N	\N
3304	80	1984-03-07 00:00:00	\N	1989-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. René TINANT, décédé	\N	\N	SENAT	58939G	\N	NR	\N	\N
3308	860	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000080	\N	NR	\N	\N
3309	860	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	REN3	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000080	\N	NR	\N	\N
3312	730	1968-10-02 00:00:00	1968-09-22 00:00:00	1974-05-22 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000314	\N	NR	\N	\N
3314	420	1988-09-04 00:00:00	1988-09-04 00:00:00	1992-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	88011F	\N	RP	\N	\N
3315	420	1992-10-02 00:00:00	1992-09-27 00:00:00	1997-11-17 00:00:00	REN1	DECEDE	ANCIEN	\N	\N	\N	\N	1997	SENAT	88011F	\N	RP	\N	\N
3317	710	1967-06-11 00:00:00	1967-06-11 00:00:00	1968-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000269	\N	NR	\N	\N
3318	710	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000269	\N	NR	\N	\N
3319	710	1977-10-03 00:00:00	1977-09-25 00:00:00	1982-03-20 00:00:00	REN2	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000269	\N	NR	\N	\N
3321	130	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000502	\N	RP	\N	\N
3324	335	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59550S	\N	RP	\N	\N
3325	335	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59550S	\N	RP	\N	\N
3326	335	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59550S	\N	RP	\N	\N
3328	720	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000179	\N	NR	\N	\N
3332	790	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000355	\N	NR	\N	\N
3333	790	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000355	\N	NR	\N	\N
3334	790	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000355	\N	NR	\N	\N
3335	790	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000355	\N	NR	\N	\N
3340	510	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000233	\N	NR	\N	\N
3341	510	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000233	\N	NR	\N	\N
3342	510	1965-10-02 00:00:00	1965-09-26 00:00:00	1970-08-19 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000233	\N	NR	\N	\N
3344	690	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000337	\N	RP	\N	\N
3348	310	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000323	\N	RP	\N	\N
3349	310	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000323	\N	RP	\N	\N
3350	310	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000323	\N	RP	\N	\N
3351	310	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	REN	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000323	\N	RP	\N	\N
3793	850	1959-04-28 00:00:00	1959-04-26 00:00:00	1959-06-28 00:00:00	REN	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	56305S	\N	NR	\N	\N
3795	895	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59557A	\N	RP	\N	\N
3797	760	1968-10-02 00:00:00	1968-09-22 00:00:00	1969-09-12 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000537	\N	RP	\N	\N
5412	1026	1959-04-28 00:00:00	\N	1962-09-22 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	1955	SENAT	000763	\N	NR	\N	\N
5413	1026	1962-10-02 00:00:00	\N	1971-10-01 00:00:00	REN3	NONREP	ANCIEN	\N	\N	\N	\N	1955	SENAT	000763	\N	NR	\N	\N
11494	100	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	89017R	\N	SM1	\N	2014-09-28 13:16:32
5419	790	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000702	\N	NR	\N	\N
5420	790	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000702	\N	NR	\N	\N
5421	790	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	REN3	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000702	\N	NR	\N	\N
5424	300	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000769	\N	NR	\N	\N
5425	300	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000769	\N	NR	\N	\N
5428	590	1961-09-20 00:00:00	\N	1965-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Marcel BERTRAND	\N	\N	SENAT	000683	\N	RP	\N	\N
5429	590	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000683	\N	RP	\N	\N
5434	630	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000709	\N	NR	\N	\N
5435	630	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN3	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000709	\N	NR	\N	\N
5438	590	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000744	\N	RP	\N	\N
5439	590	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000744	\N	RP	\N	\N
5440	590	1965-10-02 00:00:00	1965-09-26 00:00:00	1969-01-11 00:00:00	REN2	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000744	\N	RP	\N	\N
5442	130	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000685	\N	RP	\N	\N
5443	130	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000685	\N	RP	\N	\N
5444	130	1962-10-02 00:00:00	1962-09-23 00:00:00	1966-03-09 00:00:00	REN2	DECEDE	ANCIEN	\N	\N	\N	\N	1966	SENAT	000685	\N	RP	\N	\N
5446	370	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000728	\N	NR	\N	\N
5450	1000	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000713	\N	NR	\N	\N
5451	440	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN2	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000713	\N	RP	\N	\N
5454	1029	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000681	\N	NR	\N	\N
5455	775	1968-10-02 00:00:00	1968-09-22 00:00:00	1975-04-25 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000681	\N	RP	\N	\N
5457	380	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000687	\N	RP	\N	\N
5458	380	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000687	\N	RP	\N	\N
5459	380	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000687	\N	RP	\N	\N
5462	590	1959-05-05 00:00:00	\N	1965-10-01 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. Maurice WALKER, décédé	\N	\N	SENAT	000764	\N	RP	\N	\N
3165	270	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-01-30 00:00:00	REN3	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000201	\N	NR	\N	\N
3167	440	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-09-24 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000531	\N	RP	\N	\N
3168	440	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000531	\N	RP	\N	\N
3171	230	1980-10-02 00:00:00	1980-09-28 00:00:00	1981-06-21 00:00:00	ELECTION	CESDEPUTE	ANCIEN	\N	\N	\N	\N	\N	SENAT	80024B	\N	NR	\N	\N
3174	800	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-09-27 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000206	\N	NR	\N	\N
3175	800	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000206	\N	NR	\N	\N
3179	510	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-09-25 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000144	\N	NR	\N	\N
3180	510	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-09-21 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000144	\N	NR	\N	\N
3181	510	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000144	\N	NR	\N	\N
3184	1026	1959-04-28 00:00:00	\N	1962-09-22 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000320	\N	NR	\N	\N
3185	1026	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-09-25 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000320	\N	NR	\N	\N
3186	1026	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-09-27 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000320	\N	NR	\N	\N
3187	1026	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	REN3	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000320	\N	NR	\N	\N
3191	800	1977-09-25 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59545V	\N	NR	\N	\N
3192	800	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59545V	\N	NR	\N	\N
10777	870	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	90004C	\N	NR	\N	2014-09-28 13:21:47
10779	870	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	95055L	\N	NR	\N	2014-09-28 13:21:47
3608	580	1974-10-02 00:00:00	1974-09-22 00:00:00	1977-12-21 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000434	\N	NR	\N	\N
3610	650	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59241G	\N	NR	\N	\N
3611	650	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	REN	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	59241G	\N	NR	\N	\N
3613	870	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000023	\N	NR	\N	\N
3617	150	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000030	\N	NR	\N	\N
3618	150	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000030	\N	NR	\N	\N
3619	150	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN3	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000030	\N	NR	\N	\N
4013	360	1980-10-02 00:00:00	1980-09-28 00:00:00	1982-11-18 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000405	\N	NR	\N	\N
4015	500	1968-06-17 00:00:00	\N	1974-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Henri CORNAT, décédé	\N	\N	SENAT	59249Q	\N	NR	\N	\N
4016	500	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59249Q	\N	NR	\N	\N
4017	500	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59249Q	\N	NR	\N	\N
4019	790	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59561V	\N	NR	\N	\N
4020	790	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59561V	\N	NR	\N	\N
4022	335	1986-10-02 00:00:00	1986-09-28 00:00:00	1988-05-10 00:00:00	ELECTION	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	58808V	\N	RP	\N	\N
4024	50	1957-10-27 00:00:00	\N	1959-04-27 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000094	\N	NR	\N	\N
4025	50	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000094	\N	NR	\N	\N
4026	50	1962-10-02 00:00:00	1962-09-23 00:00:00	1968-10-24 00:00:00	REN2	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000094	\N	NR	\N	\N
4028	982	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	59250H	\N	NR	\N	\N
4030	530	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000190	\N	NR	\N	\N
4031	530	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000190	\N	NR	\N	\N
4034	972	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000311	\N	NR	\N	\N
4037	690	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	55510R	\N	RP	\N	\N
4039	690	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	55510R	\N	RP	\N	\N
3599	380	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	58335H	\N	RP	\N	\N
4041	690	1974-08-27 00:00:00	\N	1977-10-02 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Léon CHAMBARETAUD, dédédé	\N	\N	SENAT	59582B	\N	RP	\N	\N
4042	690	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59582B	\N	RP	\N	\N
4043	690	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN2	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	59582B	\N	RP	\N	\N
4048	620	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000074	\N	RP	\N	\N
4049	620	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000074	\N	RP	\N	\N
4052	590	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000377	\N	RP	\N	\N
4055	370	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000078	\N	NR	\N	\N
4056	370	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000078	\N	NR	\N	\N
4063	810	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	REN	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000154	\N	NR	\N	\N
4064	810	1968-10-02 00:00:00	1968-09-22 00:00:00	1974-10-19 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000154	\N	NR	\N	\N
4066	260	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58048D	\N	NR	\N	\N
4067	260	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58048D	\N	NR	\N	\N
4068	260	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	58048D	\N	NR	\N	\N
4070	730	1995-11-02 00:00:00	\N	1997-06-30 00:00:00	REMPLACE	DEM	ANCIEN	\N	\N	En remplacement de M. Michel Barnier, nommé membre du Gouvernement	\N	\N	SENAT	95067Q	\N	NR	\N	\N
4072	1029	1959-04-28 00:00:00	\N	1968-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000354	\N	NR	\N	\N
4073	615	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000354	\N	RP	\N	\N
4074	615	1977-10-03 00:00:00	1977-09-25 00:00:00	1980-10-03 00:00:00	REN2	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	000354	\N	RP	\N	\N
4077	973	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000259	\N	NR	\N	\N
4080	180	1970-10-25 00:00:00	\N	1971-10-01 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. Eugène Jamain, décédé	\N	\N	SENAT	000055	\N	NR	\N	\N
4083	370	1974-10-02 00:00:00	1974-09-22 00:00:00	1975-07-21 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000283	\N	NR	\N	\N
4085	974	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59251J	\N	NR	\N	\N
4086	974	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	REN	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	59251J	\N	NR	\N	\N
4088	590	1967-05-12 00:00:00	\N	1974-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Adolphe DUTOIT, démissionnaire	\N	\N	SENAT	59252K	\N	RP	\N	\N
4089	590	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59252K	\N	RP	\N	\N
4090	590	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59252K	\N	RP	\N	\N
4092	280	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000117	\N	NR	\N	\N
4094	265	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59562W	\N	RP	\N	\N
4096	880	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59563X	\N	NR	\N	\N
4097	880	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59563X	\N	NR	\N	\N
4099	370	1983-10-03 00:00:00	1983-09-25 00:00:00	1992-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	59253L	\N	NR	\N	\N
51080	974	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19577H	\N	RP	2017-09-24 00:00:00	\N
51081	974	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19583F	\N	RP	2017-09-24 00:00:00	\N
4104	690	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000246	\N	RP	\N	\N
4105	690	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	REN	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000246	\N	RP	\N	\N
4106	690	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	REN	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000246	\N	RP	\N	\N
51085	500	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	05008E	\N	RP	2017-09-24 00:00:00	\N
4111	670	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000148	\N	RP	\N	\N
4112	670	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000148	\N	RP	\N	\N
4115	620	1981-04-23 00:00:00	\N	1981-06-21 00:00:00	REMPLACE	CESDEPUTE	ANCIEN	\N	\N	En remplacement de M. Bernard CHOCHOY, décédé	\N	\N	SENAT	59308J	\N	RP	\N	\N
4117	800	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000239	\N	NR	\N	\N
4118	800	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000239	\N	NR	\N	\N
4121	999	1977-10-03 00:00:00	1977-10-03 00:00:00	1986-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	58647W	\N	RP	\N	\N
51086	500	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19333N	\N	RP	2017-09-24 00:00:00	\N
4124	500	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000169	\N	NR	\N	\N
4125	500	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000169	\N	NR	\N	\N
4126	500	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000169	\N	NR	\N	\N
4127	500	1974-10-02 00:00:00	1974-09-22 00:00:00	1979-01-10 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000169	\N	NR	\N	\N
11495	280	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	98023Q	\N	SM1	\N	2014-09-28 17:12:41
4130	560	1958-06-18 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58355M	\N	NR	\N	\N
4131	560	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58355M	\N	NR	\N	\N
4132	560	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58355M	\N	NR	\N	\N
4133	560	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	58355M	\N	NR	\N	\N
4135	680	1966-10-15 00:00:00	\N	1968-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Charles STOESSEL (décédé)	\N	\N	SENAT	58655W	\N	RP	\N	\N
4136	680	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58655W	\N	RP	\N	\N
4137	680	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	REN2	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	58655W	\N	RP	\N	\N
3367	1029	1959-04-28 00:00:00	1959-04-26 00:00:00	1959-05-28 00:00:00	REN2	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	000025	\N	NR	\N	\N
3573	20	1989-10-02 00:00:00	1989-09-24 00:00:00	1989-11-01 00:00:00	ELECTION	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	66002K	\N	NR	\N	\N
10814	830	2004-10-01 00:00:00	2004-09-26 00:00:00	2008-04-18 00:00:00	ELECTION	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	95031C	\N	RP	\N	\N
10815	824	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04043D	\N	RP	\N	\N
5013	205	1998-10-01 00:00:00	1998-09-27 00:00:00	2005-03-19 00:00:00	ELECTION	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	98008R	\N	NR	\N	\N
10816	680	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04044E	\N	RP	\N	2014-09-28 17:14:21
10844	690	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	04051D	\N	RP	\N	2014-09-28 17:07:41
10847	770	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	04052E	\N	RP	\N	\N
10820	680	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04045F	\N	RP	\N	2014-09-28 17:14:21
10823	690	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	99002P	\N	RP	\N	2014-09-28 17:07:41
10824	690	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	REN1	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	95032D	\N	RP	\N	2014-09-28 17:07:41
10825	690	2004-10-01 00:00:00	2004-09-26 00:00:00	2009-07-23 00:00:00	REN2	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	95049N	\N	RP	\N	\N
10828	690	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	04046G	\N	RP	\N	2014-09-28 17:07:41
5167	140	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	98042T	\N	NR	\N	\N
5173	350	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	98044V	\N	RP	\N	\N
5175	350	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	98045W	\N	RP	\N	\N
5178	260	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	89015P	\N	NR	\N	\N
5179	290	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	86006A	\N	RP	\N	\N
5180	60	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	88012G	\N	RP	\N	\N
5181	210	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	98003L	\N	NR	\N	\N
5182	260	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	96006F	\N	NR	\N	\N
5183	210	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	89037V	\N	NR	\N	\N
5185	70	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	80045G	\N	NR	\N	\N
5186	340	1998-10-01 00:00:00	1998-09-27 00:00:00	2007-06-28 00:00:00	REN1	CESDEPUTE	ANCIEN	\N	\N	\N	\N	\N	SENAT	89043T	\N	NR	\N	\N
5187	340	1998-10-01 00:00:00	1998-09-27 00:00:00	2006-07-08 00:00:00	REN2	DECEDE	ANCIEN	\N	\N	\N	\N	2006	SENAT	80048K	\N	NR	\N	\N
5188	290	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	98046X	\N	RP	\N	\N
5191	350	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	98047Y	\N	RP	\N	\N
5193	210	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	98048A	\N	NR	\N	\N
5197	290	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	98049B	\N	RP	\N	\N
5200	270	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	2002	SENAT	98050T	\N	NR	\N	\N
5204	290	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	98051U	\N	RP	\N	\N
5207	230	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	REN3	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	73006G	\N	NR	\N	\N
5208	20	1998-10-01 00:00:00	1998-09-27 00:00:00	2007-09-03 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	66002K	\N	NR	\N	\N
5209	340	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	REN2	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	80015A	\N	NR	\N	\N
5213	983	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	98052V	\N	NR	\N	\N
6352	982	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	92033R	\N	NR	\N	\N
6353	650	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	92020L	\N	NR	\N	\N
6354	650	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	01003G	\N	NR	\N	\N
6355	480	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	01005J	\N	NR	\N	\N
6359	660	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	01006K	\N	NR	\N	\N
6361	410	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	01007L	\N	NR	\N	\N
6362	400	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	83039W	\N	NR	\N	\N
6364	400	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	92015P	\N	NR	\N	\N
6365	530	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	83011J	\N	NR	\N	\N
6366	460	2001-10-01 00:00:00	2001-09-23 00:00:00	2008-09-24 00:00:00	REN2	DECEDE	ANCIEN	\N	\N	\N	\N	2008	SENAT	88004G	\N	NR	\N	\N
6367	460	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	92039X	\N	NR	\N	\N
6370	390	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	01008M	\N	NR	\N	\N
6374	974	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	01009N	\N	NR	\N	\N
6375	974	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	01010F	\N	NR	\N	\N
6377	500	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	REN3	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	82002D	\N	NR	\N	\N
6378	500	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	96004D	\N	NR	\N	\N
6379	500	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	01011G	\N	NR	\N	\N
6380	370	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	REN1	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	92030N	\N	NR	\N	\N
6381	370	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	01012H	\N	NR	\N	\N
6384	370	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	01013J	\N	NR	\N	\N
5466	350	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000720	\N	RP	\N	\N
5467	350	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000720	\N	RP	\N	\N
5468	350	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000720	\N	RP	\N	\N
5469	350	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	REN4	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000720	\N	RP	\N	\N
51087	500	2017-10-02 00:00:00	2017-09-24 00:00:00	2020-11-30 00:00:00	REN3	DEM	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	96004D	\N	RP	2017-09-24 16:43:41	\N
3587	340	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000208	\N	NR	\N	\N
3588	340	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000208	\N	NR	\N	\N
3591	615	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	58628T	\N	RP	\N	\N
3593	470	1971-12-01 00:00:00	\N	1974-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Etienne RESTAT, décédé.	\N	\N	SENAT	000161	\N	NR	\N	\N
3596	828	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	59580Y	\N	RP	\N	\N
3597	828	1986-10-02 00:00:00	1986-09-28 00:00:00	1995-10-01 00:00:00	REN1	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	59580Y	\N	RP	\N	\N
3601	830	1977-10-03 00:00:00	1977-09-25 00:00:00	1978-10-05 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000643	\N	RP	\N	\N
3603	1004	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000138	\N	NR	\N	\N
3604	1004	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000138	\N	NR	\N	\N
3605	640	1974-10-02 00:00:00	1974-09-22 00:00:00	1983-10-02 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000138	\N	NR	\N	\N
6743	610	2002-06-08 00:00:00	\N	2004-06-01 00:00:00	REMPLACE	DEM	ANCIEN	\N	\N	En remplacement de M. Alain Lambert, nommé membre du Gouvernement	\N	\N	SENAT	02004M	\N	NR	\N	\N
6761	830	2002-07-18 00:00:00	\N	2004-09-30 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. Hubert Falco, nommé membre du Gouvernement	\N	\N	SENAT	02006P	\N	RP	\N	\N
6765	700	2002-10-01 00:00:00	2002-09-29 00:00:00	2002-12-19 00:00:00	ELECTION	ANNCC	ANCIEN	\N	\N	\N	\N	\N	SENAT	02007Q	\N	NR	\N	\N
6768	615	2002-10-01 00:00:00	\N	2004-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Michel Caldaguès , démissionnaire	\N	\N	SENAT	59312E	\N	RP	\N	\N
6775	890	1959-04-28 00:00:00	1959-04-26 00:00:00	1959-07-02 00:00:00	REN3	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000212	\N	NR	\N	\N
6777	775	2002-12-11 00:00:00	\N	2004-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Robert Calméjane, décédé.	\N	\N	SENAT	59569E	\N	RP	\N	\N
6779	650	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000295	\N	NR	\N	\N
511	200	1994-02-20 00:00:00	\N	1998-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Charles ORNANO, décédé	\N	\N	SENAT	94002S	\N	NR	\N	\N
453	974	1998-02-17 00:00:00	\N	2001-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Pierre LAGOURGUE, décédé	\N	\N	SENAT	98002K	\N	NR	\N	\N
449	335	1995-10-02 00:00:00	1995-09-24 00:00:00	1999-12-16 00:00:00	ELECTION	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	77053G	\N	RP	\N	\N
408	130	1978-10-01 00:00:00	\N	1980-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Léon DAVID, démissionnaire	\N	\N	SENAT	78010Y	\N	RP	\N	\N
12819	974	2011-10-01 00:00:00	2011-09-25 00:00:00	2016-11-12 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	96003C	\N	RP	\N	2016-11-14 11:08:04
328	824	1997-10-15 00:00:00	\N	2004-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. René Rouquet, élu député le 01-06-1997 (recours rejeté le 14-10-1997)	\N	\N	SENAT	97004H	\N	RP	\N	\N
353	310	1996-01-13 00:00:00	\N	1998-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Claude CORNAC, décédé	\N	\N	SENAT	96001A	\N	RP	\N	\N
316	390	1989-09-18 00:00:00	\N	1992-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Pierre BRANTUS, décédé	\N	\N	SENAT	89004L	\N	NR	\N	\N
238	770	1983-04-19 00:00:00	\N	1986-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Marc JACQUET, décédé	\N	\N	SENAT	83003J	\N	RP	\N	\N
207	840	1987-10-01 00:00:00	\N	1995-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Maurice CHARRETIER, décédé	\N	\N	SENAT	87003B	\N	NR	\N	\N
213	999	1990-04-12 00:00:00	\N	1995-09-23 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Jean BARRAS, décédé	\N	\N	SENAT	90002A	\N	RP	\N	\N
10537	350	2003-08-29 00:00:00	\N	2008-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Patrick Lassourd, décédé	\N	\N	SENAT	03002P	\N	RP	\N	\N
117	998	1977-03-04 00:00:00	\N	1983-10-02 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Louis GROS, nommé membre du Conseil Constitutionnel	\N	\N	SENAT	77002U	\N	RP	\N	\N
28	60	1984-12-26 00:00:00	\N	1989-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Victor ROBINI, décédé	\N	\N	SENAT	84004P	\N	RP	\N	\N
67	775	1978-07-24 00:00:00	\N	1986-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de Mme Marie-Thérèse GOUTMANN, élue député	\N	\N	SENAT	78007E	\N	RP	\N	\N
5867	265	2000-04-28 00:00:00	\N	2004-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Jean-Luc Mélenchon, nommé membre du Gouvernement 	\N	\N	SENAT	00003C	\N	RP	\N	\N
6788	700	2003-02-09 00:00:00	2003-02-09 00:00:00	2004-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Christian Bergelin, dont l'élection avait été invalidée	\N	\N	SENAT	03001N	\N	NR	\N	\N
9480	1025	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000425	\N	NR	\N	\N
9481	1025	1968-10-02 00:00:00	1968-09-22 00:00:00	1973-01-09 00:00:00	REN	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	000425	\N	NR	\N	\N
9484	1040	1959-05-31 00:00:00	1959-05-31 00:00:00	1962-07-04 00:00:00	ELECTION	CESMANORD	ANCIEN	\N	\N	\N	\N	\N	SENAT	57316A	\N	NR	\N	\N
9486	1021	1959-05-31 00:00:00	1959-05-31 00:00:00	1962-07-04 00:00:00	ELECTION	CESMANORD	ANCIEN	\N	\N	\N	\N	\N	SENAT	000346	\N	NR	\N	\N
9489	1041	1959-05-24 00:00:00	1959-05-24 00:00:00	1962-07-04 00:00:00	ELECTION	CESMANORD	ANCIEN	\N	\N	\N	\N	\N	SENAT	000260	\N	NR	\N	\N
9495	1030	1959-05-31 00:00:00	1959-05-31 00:00:00	1962-07-04 00:00:00	ELECTION	CESMANORD	ANCIEN	\N	\N	\N	\N	\N	SENAT	000013	\N	NR	\N	\N
11496	280	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	REN1	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	01064V	\N	SM1	\N	2014-09-28 17:12:41
11559	330	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	90003B	\N	RP	\N	2014-09-28 17:53:13
5513	760	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000732	\N	RP	\N	\N
5514	760	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	REN3	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000732	\N	RP	\N	\N
5517	180	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000680	\N	NR	\N	\N
5518	180	1962-10-02 00:00:00	1962-09-23 00:00:00	1970-10-24 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000680	\N	NR	\N	\N
12626	500	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	96004D	\N	SM2	\N	2017-09-24 16:43:42
51088	640	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	11110B	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
5522	680	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000737	\N	RP	\N	\N
5523	680	1959-04-28 00:00:00	1959-04-26 00:00:00	1964-08-07 00:00:00	REN3	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000737	\N	RP	\N	\N
5525	670	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000727	\N	RP	\N	\N
5526	670	1968-10-02 00:00:00	1968-09-22 00:00:00	1976-05-05 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000727	\N	RP	\N	\N
5528	240	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000686	\N	NR	\N	\N
5531	770	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000758	\N	RP	\N	\N
5532	770	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000758	\N	RP	\N	\N
5535	560	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000706	\N	NR	\N	\N
5536	560	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000706	\N	NR	\N	\N
51089	640	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19619A	\N	RP	2017-09-24 00:00:00	\N
51090	640	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19621T	\N	RP	2017-09-24 00:00:00	\N
5541	530	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN2	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000679	\N	NR	\N	\N
12649	640	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	11112D	\N	SM2	\N	2017-09-24 16:45:26
5545	710	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-09-21 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000693	\N	NR	\N	\N
5546	710	1968-10-02 00:00:00	1968-09-22 00:00:00	1971-10-28 00:00:00	REN2	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000693	\N	NR	\N	\N
12716	440	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	11064N	\N	RP	\N	2017-09-24 17:04:02
12715	440	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	01056V	\N	RP	\N	2017-09-24 17:04:02
5550	610	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000707	\N	NR	\N	\N
5551	610	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN3	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000707	\N	NR	\N	\N
5554	770	1959-07-16 00:00:00	\N	1968-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. André Boutemy, décédé	\N	\N	SENAT	000710	\N	RP	\N	\N
5556	320	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-09-23 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	1979	SENAT	000708	\N	NR	\N	\N
5557	984	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000762	\N	NR	\N	\N
12613	490	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	11029K	\N	RP	\N	2017-09-24 17:09:24
5561	700	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-09-22 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	1956	SENAT	000746	\N	NR	\N	\N
12622	560	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	11098Y	\N	SM2	\N	2017-09-24 17:14:26
12724	770	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04057K	\N	RP	\N	2017-09-24 17:18:03
12645	450	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	01027Q	\N	SM2	\N	2017-09-24 17:28:55
5567	1029	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	REN3	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000738	\N	NR	\N	\N
12703	620	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	11063M	\N	RP	\N	2017-09-24 17:42:26
5571	520	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000771	\N	NR	\N	\N
5572	520	1965-10-02 00:00:00	1965-09-26 00:00:00	1972-11-27 00:00:00	REN2	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000771	\N	NR	\N	\N
12902	615	2012-09-20 00:00:00	\N	2017-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement Mme Nicole Borvo Cohen-Seat, démissionnaire	\N	\N	SENAT	12041X	\N	NR	\N	2017-09-24 17:47:27
5575	850	1952-05-18 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000767	\N	NR	\N	\N
5576	850	1959-04-28 00:00:00	1959-04-26 00:00:00	1963-01-22 00:00:00	REN2	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000767	\N	NR	\N	\N
5578	310	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000751	\N	RP	\N	\N
5579	310	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000751	\N	RP	\N	\N
5581	615	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000671	\N	RP	\N	\N
12735	615	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	04067M	\N	RP	\N	2017-09-24 17:47:27
12602	570	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	11049P	\N	RP	\N	2017-09-24 17:48:21
5586	460	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000677	\N	NR	\N	\N
5587	460	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000677	\N	NR	\N	\N
5588	460	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-03-05 00:00:00	REN4	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	000677	\N	NR	\N	\N
12744	824	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	11034G	\N	RP	\N	2017-09-24 17:55:12
12592	265	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN2	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	00003C	\N	RP	\N	2017-09-24 18:05:40
12666	990	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	11071M	\N	SM2	\N	2017-09-24 18:16:33
5594	760	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000705	\N	RP	\N	\N
5595	760	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	REN4	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000705	\N	RP	\N	\N
5596	760	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	REN5	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000705	\N	RP	\N	\N
5597	760	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-10-01 00:00:00	REN6	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000705	\N	RP	\N	\N
5598	760	1986-10-02 00:00:00	1986-09-28 00:00:00	1993-03-02 00:00:00	REN7	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000705	\N	RP	\N	\N
5600	360	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000691	\N	NR	\N	\N
5601	360	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000691	\N	NR	\N	\N
12605	590	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	11039M	\N	RP	\N	2017-09-24 18:16:52
5607	260	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000736	\N	NR	\N	\N
5608	260	1962-10-02 00:00:00	1962-09-23 00:00:00	1968-10-29 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000736	\N	NR	\N	\N
5612	880	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000688	\N	NR	\N	\N
5613	880	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	REN3	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000688	\N	NR	\N	\N
5619	760	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000725	\N	RP	\N	\N
5620	760	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-12-17 00:00:00	REN4	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000725	\N	RP	\N	\N
5622	330	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000748	\N	RP	\N	\N
5623	330	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	REN	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000748	\N	RP	\N	\N
5624	330	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN2	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000748	\N	RP	\N	\N
5629	840	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000734	\N	NR	\N	\N
5630	840	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000734	\N	NR	\N	\N
5631	840	1968-10-02 00:00:00	1968-09-22 00:00:00	1972-10-19 00:00:00	REN4	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000734	\N	NR	\N	\N
5633	610	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000714	\N	NR	\N	\N
5634	610	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000714	\N	NR	\N	\N
5639	150	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000694	\N	NR	\N	\N
5640	150	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000694	\N	NR	\N	\N
5641	150	1962-10-02 00:00:00	1962-09-23 00:00:00	1968-09-19 00:00:00	REN4	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000694	\N	NR	\N	\N
5645	1029	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000739	\N	NR	\N	\N
5646	1029	1959-04-28 00:00:00	\N	1968-10-01 00:00:00	REN3	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000739	\N	NR	\N	\N
5649	210	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000747	\N	NR	\N	\N
5650	210	1971-10-02 00:00:00	1971-09-26 00:00:00	1979-07-05 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000747	\N	NR	\N	\N
5653	540	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000730	\N	RP	\N	\N
5654	540	1959-04-28 00:00:00	1959-04-26 00:00:00	1961-08-22 00:00:00	REN2	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000730	\N	RP	\N	\N
5659	890	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000698	\N	NR	\N	\N
5660	890	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	REN4	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000698	\N	NR	\N	\N
5665	330	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	1941	SENAT	000672	\N	RP	\N	\N
5666	330	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	1941	SENAT	000672	\N	RP	\N	\N
5667	330	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN2	NONREELU	ANCIEN	\N	\N	\N	\N	1941	SENAT	000672	\N	RP	\N	\N
5670	250	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000772	\N	NR	\N	\N
5671	250	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000772	\N	NR	\N	\N
5674	700	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000741	\N	NR	\N	\N
5675	700	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000741	\N	NR	\N	\N
5676	700	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000741	\N	NR	\N	\N
5679	1020	1967-05-16 00:00:00	\N	1968-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Jacques RICHARD, élu député.	\N	\N	SENAT	000752	\N	NR	\N	\N
5680	265	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000752	\N	RP	\N	\N
5684	490	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	REN	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000743	\N	NR	\N	\N
5685	490	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000743	\N	NR	\N	\N
11168	180	2005-09-19 00:00:00	2005-09-18 00:00:00	2008-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	05012A	\N	NR	\N	\N
10922	828	2004-10-01 00:00:00	2004-09-26 00:00:00	2004-11-01 00:00:00	ELECTION	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	95051G	2004-10-28 00:00:00	RP	\N	\N
11174	860	2005-09-19 00:00:00	2005-09-18 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95059Q	\N	NR	\N	2014-09-28 12:56:40
11188	640	2006-05-17 00:00:00	\N	2011-09-30 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. André Labarrère, décédé	\N	\N	SENAT	06001B	\N	NR	\N	\N
489	775	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95060H	\N	RP	\N	\N
2802	130	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	89029V	\N	RP	\N	\N
5004	984	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	98005N	\N	NR	\N	\N
5005	90	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	98006P	\N	NR	\N	\N
5006	190	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	98007Q	\N	NR	\N	\N
5012	190	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	80031A	\N	NR	\N	\N
5018	120	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	89041R	\N	NR	\N	\N
5019	125	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-07 00:00:00	REN2	DECEDE	ANCIEN	\N	\N	\N	\N	2008	SENAT	80017C	\N	NR	\N	\N
5020	120	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	80035E	\N	NR	\N	\N
5022	180	1998-10-01 00:00:00	1998-09-27 00:00:00	2007-12-16 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	2007	SENAT	89045V	\N	NR	\N	\N
5023	10	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	89016Q	\N	NR	\N	\N
5024	10	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	89027T	\N	NR	\N	\N
5025	250	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	88009M	\N	NR	\N	\N
5027	100	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	89017R	\N	NR	\N	\N
5032	100	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	94003T	\N	NR	\N	\N
11095	860	2004-11-02 00:00:00	\N	2005-06-28 00:00:00	REMPLACE	DEM	ANCIEN	\N	\N	En remplacement de M. Jean-Pierre Raffarin, nommé Premier ministre	\N	\N	SENAT	04098U	\N	NR	\N	\N
5033	310	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	98010K	\N	RP	\N	\N
5035	310	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	89019T	\N	RP	\N	\N
11099	720	2004-11-02 00:00:00	\N	2005-06-27 00:00:00	REMPLACE	DEM	ANCIEN	\N	\N	En remplacement de M. François Fillon, nommé membre du Gouvernement	\N	\N	SENAT	04099V	\N	NR	\N	\N
5036	310	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	80039J	\N	RP	\N	\N
5037	110	1998-10-01 00:00:00	1998-09-27 00:00:00	2006-08-11 00:00:00	REN3	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	74050Q	\N	NR	\N	\N
5038	110	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	80013X	\N	NR	\N	\N
5039	310	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	98011L	\N	RP	\N	\N
5042	60	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	84004P	\N	RP	\N	\N
5043	220	1998-10-01 00:00:00	1998-09-27 00:00:00	2006-06-29 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	2006	SENAT	98012M	\N	NR	\N	\N
5047	270	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	89022N	\N	NR	\N	\N
5048	160	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	REN1	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	96008H	\N	NR	\N	\N
5049	270	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	98013N	\N	NR	\N	\N
5052	170	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	89014N	\N	NR	\N	\N
5056	170	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	98014P	\N	NR	\N	\N
5060	130	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	98015Q	\N	RP	\N	\N
11184	1040	1961-11-13 00:00:00	\N	1962-07-04 00:00:00	ELECTION	CESMANORD	ANCIEN	\N	\N	\N	\N	1997	SENAT	05015D	\N	NR	\N	\N
5055	170	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	89013M	\N	NR	\N	\N
5064	130	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	98016R	\N	RP	\N	\N
5066	130	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	98017S	\N	RP	\N	\N
5070	997	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	98018T	\N	RP	\N	\N
5071	997	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	89023P	\N	RP	\N	\N
5072	330	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	80027E	\N	RP	\N	\N
5073	997	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	98019U	\N	RP	\N	\N
5078	330	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	80046H	\N	RP	\N	\N
5079	330	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	90003B	\N	RP	\N	\N
5080	330	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	98021N	\N	RP	\N	\N
5083	330	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	89025R	\N	RP	\N	\N
5084	997	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	89021M	\N	RP	\N	\N
5086	130	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	89042S	\N	RP	\N	\N
5091	973	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	REN1	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	89035T	\N	NR	\N	\N
5093	50	1998-10-01 00:00:00	1998-09-27 00:00:00	2007-01-25 00:00:00	REN1	DECEDE	ANCIEN	\N	\N	\N	\N	2007	SENAT	89006N	\N	NR	\N	\N
5095	280	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	98023Q	\N	NR	\N	\N
12734	615	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	04077P	\N	RP	\N	2017-09-24 17:47:27
5401	730	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000715	\N	NR	\N	\N
5402	730	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000715	\N	NR	\N	\N
12619	470	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	11094U	\N	SM2	\N	2017-09-24 13:25:54
12618	470	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	11095V	\N	SM2	\N	2017-09-24 13:25:54
5407	740	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000726	\N	NR	\N	\N
5408	740	1959-04-28 00:00:00	1959-04-26 00:00:00	1966-03-09 00:00:00	REN3	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000726	\N	NR	\N	\N
10831	690	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04047H	\N	RP	\N	2014-09-28 17:07:41
5028	630	1998-09-28 00:00:00	1998-09-27 00:00:00	2001-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	98009S	\N	NR	\N	\N
10832	770	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95039L	\N	RP	\N	\N
10834	265	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	REN1	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	01001E	\N	RP	\N	\N
10835	265	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	00003C	\N	RP	\N	\N
10836	770	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04048J	\N	RP	\N	\N
10837	690	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04049K	\N	RP	\N	2014-09-28 17:07:41
10843	265	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	04050C	\N	RP	\N	\N
10852	770	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04053F	\N	RP	\N	\N
10857	895	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-01-23 00:00:00	REN1	CESMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95004Y	\N	RP	\N	\N
10858	895	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95035G	\N	RP	\N	\N
10860	895	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	95013A	\N	RP	\N	\N
10861	770	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04054G	\N	RP	\N	\N
10862	265	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04055H	\N	RP	\N	\N
10864	895	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04056J	\N	RP	\N	\N
10865	770	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04057K	\N	RP	\N	\N
10871	615	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95011X	\N	RP	\N	\N
10872	615	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	REN1	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	59312E	\N	RP	\N	\N
10873	895	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	04058L	\N	RP	\N	\N
10876	895	2004-10-01 00:00:00	2004-09-26 00:00:00	2007-09-30 00:00:00	ELECTION	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	04060E	\N	RP	\N	\N
10883	990	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	04062G	\N	NR	\N	\N
10884	615	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	04063H	\N	RP	\N	\N
10890	990	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	04064J	\N	NR	\N	\N
5074	130	1998-10-01 00:00:00	1998-09-27 00:00:00	2004-12-23 00:00:00	ELECTION	DECCC	ANCIEN	\N	\N	\N	\N	\N	SENAT	98020M	\N	RP	\N	\N
12818	615	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	09001P	\N	RP	\N	2017-09-24 17:47:27
10900	760	2004-10-01 00:00:00	2004-09-26 00:00:00	2013-12-31 00:00:00	REN2	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	95003X	\N	RP	\N	2014-01-02 09:46:56
10901	760	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	98053W	\N	RP	\N	2014-09-28 18:00:57
10903	760	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95062K	\N	RP	\N	2014-09-28 18:00:57
10904	760	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	95034F	\N	RP	\N	2014-09-28 18:00:58
10906	760	2004-10-01 00:00:00	2004-09-26 00:00:00	2007-06-28 00:00:00	ELECTION	CESDEPUTE	ANCIEN	\N	\N	\N	\N	\N	SENAT	04068N	\N	RP	\N	\N
10907	265	2004-10-01 00:00:00	2004-09-26 00:00:00	2010-01-07 00:00:00	ELECTION	CESDEPUTEEUR	ANCIEN	\N	\N	Elu député européen	\N	2010	SENAT	86039K	\N	RP	\N	\N
5092	200	1998-10-01 00:00:00	1998-09-27 00:00:00	2001-09-20 00:00:00	REN1	DECCC	ANCIEN	\N	\N	\N	\N	\N	SENAT	94002S	\N	NR	\N	\N
10912	760	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04070G	\N	RP	\N	2014-09-28 18:00:57
5094	280	1998-10-01 00:00:00	1998-09-27 00:00:00	2001-10-14 00:00:00	REN1	DECEDE	ANCIEN	\N	\N	\N	\N	2001	SENAT	89009R	\N	NR	\N	\N
10914	615	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04071H	\N	RP	\N	\N
5105	180	1998-10-01 00:00:00	1998-09-27 00:00:00	2004-04-30 00:00:00	ELECTION	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	98025S	2004-03-31 00:00:00	NR	\N	\N
5106	430	1998-10-01 00:00:00	1998-09-27 00:00:00	2001-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	98026T	\N	NR	\N	\N
10921	615	2004-10-01 00:00:00	2004-09-26 00:00:00	2007-11-29 00:00:00	ELECTION	CESDEPUTE	ANCIEN	\N	\N	\N	\N	\N	SENAT	04072J	\N	RP	\N	\N
10923	890	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	04073K	\N	NR	\N	2014-09-28 18:58:25
10926	828	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	97009N	\N	RP	\N	\N
10928	828	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04074L	\N	RP	\N	\N
5689	470	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000750	\N	NR	\N	\N
5690	470	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000750	\N	NR	\N	\N
5691	470	1965-10-02 00:00:00	1965-09-26 00:00:00	1971-11-30 00:00:00	REN3	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000750	\N	NR	\N	\N
5695	360	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000704	\N	NR	\N	\N
5696	360	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000704	\N	NR	\N	\N
5697	360	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN4	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000704	\N	NR	\N	\N
5704	850	1963-01-23 00:00:00	\N	1968-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Jacques de MAUPEOU, décédé	\N	\N	SENAT	000754	\N	NR	\N	\N
5707	20	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000768	\N	NR	\N	\N
5708	20	1962-10-02 00:00:00	1962-09-23 00:00:00	1966-04-24 00:00:00	REN	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000768	\N	NR	\N	\N
5710	440	1965-10-02 00:00:00	1965-09-26 00:00:00	1973-12-13 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000749	\N	RP	\N	\N
5712	999	1974-03-12 00:00:00	\N	1977-10-02 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. André ARMENGAUD, décédé	\N	\N	SENAT	000673	\N	RP	\N	\N
5715	240	1959-04-28 00:00:00	1959-04-26 00:00:00	1959-07-23 00:00:00	ELECTION	ANNCC	ANCIEN	\N	\N	\N	\N	\N	SENAT	000716	\N	NR	\N	\N
5717	240	1959-10-04 00:00:00	1959-10-04 00:00:00	1962-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000716	\N	NR	\N	\N
10778	610	2004-09-26 00:00:00	2004-09-26 00:00:00	2010-10-18 00:00:00	ELECTION	CESMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	92029V	\N	NR	\N	\N
10780	710	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95030B	\N	NR	\N	2014-09-28 18:58:21
10781	730	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95067Q	\N	NR	\N	2014-09-28 19:29:38
10782	1052	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	01063U	\N	RP	\N	2014-09-29 15:42:44
10784	1051	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04035D	\N	RP	\N	\N
10785	1051	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04036E	\N	RP	\N	\N
10786	824	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	97004H	\N	RP	\N	\N
10787	824	2004-10-01 00:00:00	2004-09-26 00:00:00	2007-09-18 00:00:00	REN3	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	77044F	\N	RP	\N	\N
10788	830	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	86049M	\N	RP	\N	2014-09-28 18:03:38
10790	824	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	04037F	\N	RP	\N	\N
10791	830	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04038G	\N	RP	\N	2014-09-28 18:03:38
10796	824	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	04039H	\N	RP	\N	\N
10797	680	2004-10-01 00:00:00	2004-09-26 00:00:00	2010-03-06 00:00:00	REN2	CESMEMCC	ANCIEN	\N	\N	\N	\N	\N	SENAT	86030A	\N	RP	\N	\N
10798	680	2004-10-01 00:00:00	2004-09-26 00:00:00	2007-07-19 00:00:00	ELECTION	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	04040A	2007-06-19 00:00:00	RP	\N	\N
6631	999	2001-10-10 00:00:00	\N	2004-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Paul d'Ornano, démissionnaire	\N	\N	SENAT	01063U	\N	RP	\N	\N
10805	830	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04041B	\N	RP	\N	2014-09-28 18:03:38
10806	824	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04042C	\N	RP	\N	\N
5718	240	1962-09-23 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000716	\N	NR	\N	\N
12671	610	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	07004J	\N	SM2	\N	2017-09-24 13:57:40
5722	972	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000692	\N	NR	\N	\N
5723	972	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-03-27 00:00:00	REN2	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000692	\N	NR	\N	\N
51102	370	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19443T	\N	RP	2017-09-24 00:00:00	\N
51103	370	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19441R	\N	RP	2017-09-24 00:00:00	\N
5727	620	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000717	\N	RP	\N	\N
5728	620	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN3	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000717	\N	RP	\N	\N
5731	150	1968-09-20 00:00:00	\N	1971-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M.Hector PESCHAUD, décédé	\N	\N	SENAT	000674	\N	NR	\N	\N
5734	670	1992-03-06 00:00:00	\N	1992-04-06 00:00:00	REMPLACE	DECEDE	ANCIEN	\N	\N	En remplacement de M. Marcel RUDLOFF, nommé membre du Conseil constitutionnel	\N	\N	SENAT	000667	\N	RP	\N	\N
51104	370	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19515S	\N	RP	2017-09-24 00:00:00	\N
12684	828	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95063L	\N	RP	\N	2017-09-24 17:15:15
5740	170	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000770	\N	NR	\N	\N
5741	170	1962-10-02 00:00:00	1962-09-23 00:00:00	1971-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000770	\N	NR	\N	\N
5742	170	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000770	\N	NR	\N	\N
5745	210	1957-10-06 00:00:00	\N	1959-04-27 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Bénigne FOURNIER	\N	\N	SENAT	000676	\N	NR	\N	\N
5746	210	1959-04-28 00:00:00	1959-04-26 00:00:00	1962-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000676	\N	NR	\N	\N
5749	800	1966-05-27 00:00:00	\N	1966-06-02 00:00:00	REMPLACE	DEM	ANCIEN	\N	\N	En remplacement de M. Omer CAPELLE, décédé	\N	\N	SENAT	000668	\N	NR	\N	\N
12616	540	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	01014K	\N	RP	\N	2017-09-24 17:19:42
5752	490	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000669	\N	NR	\N	\N
5753	490	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000669	\N	NR	\N	\N
12694	600	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	11044J	\N	RP	\N	2017-09-24 17:29:37
12720	380	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	01059Y	\N	RP	\N	2017-09-24 17:35:15
5759	590	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000740	\N	RP	\N	\N
5760	590	1959-04-28 00:00:00	\N	1959-04-29 00:00:00	REN4	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000740	\N	RP	\N	\N
5765	680	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	REN3	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000729	\N	RP	\N	\N
5818	590	1999-10-17 00:00:00	\N	2001-09-30 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. Jean-Paul Bataille, décédé	\N	\N	SENAT	99001N	\N	RP	\N	\N
5831	690	1999-11-02 00:00:00	\N	2004-09-30 00:00:00	REMPLACE	FININCOMPAT	ANCIEN	\N	\N	En remplacement de M. Franck Sérusclat, démissionnaire	\N	\N	SENAT	99002P	\N	RP	\N	\N
5832	730	1999-11-14 00:00:00	1999-11-14 00:00:00	2004-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95067Q	\N	NR	\N	\N
5839	770	1999-11-28 00:00:00	\N	2004-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Alain Peyrefitte, décédé	\N	\N	SENAT	99003Q	\N	RP	\N	\N
5842	335	1999-12-17 00:00:00	\N	2004-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Charles Pasqua, démissionnaire	\N	\N	SENAT	99004R	\N	RP	\N	\N
5847	615	2000-01-28 00:00:00	\N	2004-09-30 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. Charzat, élu député	\N	\N	SENAT	00001A	\N	RP	\N	\N
5854	265	2000-03-19 00:00:00	\N	2004-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Jean-Jacques Robert, décédé	\N	\N	SENAT	93007T	\N	RP	\N	\N
5855	335	2000-03-29 00:00:00	\N	2004-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Michel Duffour, nommé membre du Gouvernement	\N	\N	SENAT	00002B	\N	RP	\N	\N
5868	570	2000-04-29 00:00:00	\N	2001-09-30 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. Roger Husson, décédé	\N	\N	SENAT	00004D	\N	RP	\N	\N
5886	265	2001-01-17 00:00:00	\N	2004-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Xavier Dugoin, déchu de son mandat	\N	\N	SENAT	01001E	\N	RP	\N	\N
5901	650	2001-03-03 00:00:00	\N	2001-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. François Abadie, décédé	\N	\N	SENAT	01003G	\N	NR	\N	\N
6288	615	2001-03-28 00:00:00	\N	2004-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Bertrand Delanoë, démissionnaire	\N	\N	SENAT	01004H	\N	RP	\N	\N
6369	610	2001-10-01 00:00:00	2001-09-23 00:00:00	2002-06-07 00:00:00	REN1	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	92029V	2002-05-07 00:00:00	NR	\N	2016-12-14 15:22:28
6373	974	2001-10-01 00:00:00	2001-09-23 00:00:00	2004-07-19 00:00:00	REN1	CESDEPUTEEUR	ANCIEN	\N	\N	\N	\N	\N	SENAT	96003C	2004-07-19 00:00:00	NR	\N	\N
6427	620	2001-10-01 00:00:00	2001-09-23 00:00:00	2002-06-07 00:00:00	REN1	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	92017R	2002-05-07 00:00:00	RP	\N	2016-12-14 15:19:28
119	998	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	77002U	\N	RP	\N	\N
6465	590	2001-10-01 00:00:00	2001-09-23 00:00:00	2002-01-19 00:00:00	REN1	DECEDE	ANCIEN	\N	\N	\N	\N	2002	SENAT	97007L	\N	RP	\N	\N
6741	620	2002-06-08 00:00:00	\N	2011-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Jean-Paul Delevoye, nommé membre du gouvernement	\N	\N	SENAT	02003L	\N	RP	\N	\N
6744	240	2002-06-08 00:00:00	\N	2008-09-30 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. Xavier Darcos, nommé membre du Gouvernement	\N	\N	SENAT	02005N	\N	NR	\N	\N
10751	700	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	03001N	\N	NR	\N	2014-09-28 13:40:33
10753	820	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	REN1	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	86010V	\N	NR	\N	2014-09-28 19:03:04
10754	820	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	88008L	\N	NR	\N	2014-09-28 13:44:13
10755	850	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	95021A	\N	NR	\N	2014-09-28 16:40:50
10756	740	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	REN1	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	95005A	\N	NR	\N	2014-09-28 17:40:23
10757	740	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95015C	\N	NR	\N	2014-09-28 17:40:23
10758	740	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	95038K	\N	NR	\N	2014-09-28 17:40:23
10759	850	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04033B	\N	NR	\N	2014-09-28 16:40:50
10764	720	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	REN3	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	77043E	\N	NR	\N	2014-09-28 16:59:41
10770	810	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	95052H	\N	NR	\N	2014-09-28 13:39:20
10771	860	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	02002K	\N	NR	\N	2014-09-28 12:56:40
10774	880	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	REN3	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	77058M	\N	NR	\N	2014-09-28 12:52:10
10776	890	2004-10-01 00:00:00	2004-09-26 00:00:00	2009-07-23 00:00:00	REN2	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	86044G	\N	NR	\N	\N
11173	720	2005-09-19 00:00:00	2005-09-18 00:00:00	2007-06-17 00:00:00	ELECTION	CESPREMIN	ANCIEN	\N	\N	\N	\N	\N	SENAT	02009S	\N	NR	\N	\N
5026	250	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	80041C	\N	NR	\N	\N
5087	130	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	98022P	\N	RP	\N	\N
5126	230	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	80024B	\N	NR	\N	\N
5159	80	1998-10-01 00:00:00	1998-09-27 00:00:00	2007-07-04 00:00:00	REN3	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	71003U	\N	NR	\N	\N
5184	220	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	89040Q	\N	NR	\N	\N
12048	680	2010-12-14 00:00:00	2010-12-14 00:00:00	2014-09-30 00:00:00	REPRISE	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04040A	\N	RP	\N	2018-01-11 12:43:40
12049	830	2010-12-14 00:00:00	2010-12-14 00:00:00	2014-09-30 00:00:00	REPRISE	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95031C	\N	RP	\N	2014-09-28 18:03:38
12050	590	2010-12-14 00:00:00	\N	2011-09-30 00:00:00	REPRISE	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	01043Q	\N	RP	\N	\N
6509	440	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	01054T	\N	RP	\N	\N
6511	440	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	01055U	\N	RP	\N	\N
6514	440	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	01056V	\N	RP	\N	\N
6517	520	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	01057W	\N	NR	\N	\N
6519	520	2001-09-23 00:00:00	\N	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	01058X	\N	NR	\N	\N
6528	570	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	96007G	\N	RP	\N	\N
6529	580	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	01051Q	\N	NR	\N	\N
6530	570	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	REELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	83042R	\N	RP	\N	\N
6531	570	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	01060R	\N	RP	\N	\N
6533	570	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	01061S	\N	RP	\N	\N
6535	570	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	01062T	\N	RP	\N	\N
6641	280	2001-10-15 00:00:00	\N	2008-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Martial Taugourdeau, décédé	\N	\N	SENAT	01064V	\N	NR	\N	\N
6649	200	2001-12-02 00:00:00	2001-12-02 00:00:00	2008-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	01065W	\N	NR	\N	\N
6664	590	2002-01-20 00:00:00	\N	2011-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de Mme Dinah Derycke, décédée	\N	\N	SENAT	02001J	\N	RP	\N	\N
11998	265	2010-01-08 00:00:00	2010-01-08 00:00:00	2011-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	en remplacement de M. Jean-Luc Mélenchon, élu député européen	\N	\N	SENAT	10001F	\N	RP	\N	\N
11850	460	2008-10-02 00:00:00	2008-09-25 00:00:00	2011-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	08074D	\N	NR	\N	\N
11311	450	1965-08-20 00:00:00	\N	1965-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Maurice Charpentier, décédé	\N	\N	SENAT	08001K	\N	NR	\N	\N
11200	110	2006-08-12 00:00:00	\N	2008-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de Raymond Courrière, décédé	\N	\N	SENAT	06005F	\N	NR	\N	\N
11282	824	2007-09-19 00:00:00	\N	2011-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de Mme Hélène Luc, démissionnaire	\N	\N	SENAT	97005J	\N	RP	\N	\N
11247	335	2007-06-25 00:00:00	\N	2009-07-23 00:00:00	REMPLACE	REPEXE	ANCIEN	\N	\N	En remplacement de M. Roger Karoutchi, nommé membre du Gouvernement	\N	\N	SENAT	07024N	\N	RP	\N	\N
12007	680	2010-03-07 00:00:00	2010-03-07 00:00:00	2013-06-27 00:00:00	REMPLACE	DECEDE	ANCIEN	\N	\N	en remplacement de M. Hubert Haenel, nommé membre du Conseil constitutionnel	\N	2013	SENAT	95045J	\N	RP	\N	2013-06-28 17:49:40
12572	770	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	11074Q	\N	RP	\N	2017-09-24 17:18:03
12590	972	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	04094Q	\N	NR	\N	2017-09-25 10:58:49
12614	540	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	92040Q	\N	RP	\N	2017-09-24 17:19:42
12615	540	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	11048N	\N	RP	\N	2017-09-24 17:19:42
12620	550	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	11082Q	\N	SM2	\N	2017-09-24 19:16:18
6469	590	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	REN2	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	85002R	\N	RP	\N	\N
12623	560	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	11099A	\N	SM2	\N	2017-09-24 17:14:26
12624	480	2011-10-01 00:00:00	2011-09-25 00:00:00	2011-12-22 00:00:00	ELECTION	ANNCC	ANCIEN	\N	\N	\N	\N	\N	SENAT	11081P	\N	SM2	\N	\N
12625	500	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	01011G	\N	SM2	\N	2017-09-24 16:43:42
12627	500	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	05008E	\N	SM2	\N	2017-09-24 16:43:42
12870	550	2011-11-02 00:00:00	\N	2012-06-16 00:00:00	REMPLACE	REPEXE	ANCIEN	\N	\N	en remplacement de M. Gérard Longuet, ministre, dont le mandat a cessé	\N	\N	SENAT	11003M	\N	NR	\N	\N
12897	730	2012-07-22 00:00:00	\N	2014-05-02 00:00:00	REMPLACE	REPEXE	ANCIEN	\N	\N	en remplacement de M. Thierry Repentin, nommé membre du Gouvernement	\N	\N	SENAT	12038D	\N	NR	\N	2014-11-10 16:09:27
12630	510	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	11097X	\N	SM2	\N	2017-09-24 17:25:22
12898	120	2012-07-22 00:00:00	\N	2014-05-02 00:00:00	REMPLACE	REPEXE	ANCIEN	\N	\N	en remplacement de Mme Anne-Marie Escoffier, nommée membre du Gouvernement	\N	\N	SENAT	12039E	\N	NR	\N	2014-11-10 16:42:40
12632	520	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	01058X	\N	SM2	\N	2017-09-24 18:26:00
12633	530	2011-10-01 00:00:00	2011-09-25 00:00:00	2014-06-30 00:00:00	REN2	DEMDEPUTEEUR	ANCIEN	\N	\N	\N	\N	\N	SENAT	83011J	\N	SM2	\N	2014-07-01 09:25:11
12634	530	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	01047U	\N	SM2	\N	2017-09-24 13:29:42
12899	1053	2012-07-22 00:00:00	\N	2014-05-02 00:00:00	REMPLACE	REPEXE	ANCIEN	\N	\N	en remplacement de Mme Hélène Conway-Mouret, nommée membre du Gouvernement	\N	\N	SENAT	12040W	\N	NR	\N	2014-11-10 16:41:47
12636	390	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	01008M	\N	SM2	\N	2017-09-24 13:44:49
12637	390	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	01046T	\N	SM2	\N	2017-09-24 13:44:49
12642	430	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	11093T	\N	SM2	\N	2017-09-24 12:57:09
12643	430	2011-10-01 00:00:00	2011-09-25 00:00:00	2014-11-03 00:00:00	REN1	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	01052R	\N	SM2	\N	2014-11-04 11:22:47
12646	450	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	11103C	\N	SM2	\N	2017-09-24 17:28:55
12913	620	2013-03-01 00:00:00	\N	2017-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	en remplacement de Mme Odette Duriez, démissionnaire	\N	\N	SENAT	13002U	\N	NR	\N	2017-09-24 17:42:26
12651	370	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	11107G	\N	SM2	\N	2017-09-24 17:06:55
12652	370	2011-10-01 00:00:00	2011-09-25 00:00:00	2015-04-07 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	11108H	\N	SM2	\N	2015-04-08 15:33:42
12653	370	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	01013J	\N	SM2	\N	2017-09-24 17:06:55
12654	640	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	11111C	\N	SM2	\N	2017-09-24 16:45:26
12655	640	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	11110B	\N	SM2	\N	2017-09-24 16:45:26
12657	650	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	92020L	\N	SM2	\N	2017-09-24 12:39:59
12659	660	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	11101A	\N	SM2	\N	2017-09-24 13:42:05
12660	971	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	04095R	\N	SM1	\N	2017-09-25 10:54:33
12661	971	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	11114F	\N	SM2	\N	2017-09-25 10:54:33
12662	971	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	11113E	\N	SM2	\N	2017-09-25 10:54:33
6444	620	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	01034P	\N	RP	\N	\N
6475	590	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	01044R	\N	RP	\N	\N
6526	380	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	01059Y	\N	RP	\N	\N
10875	615	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04059M	\N	RP	\N	\N
10894	615	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04066L	\N	RP	\N	\N
10902	615	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04067M	\N	RP	\N	\N
10948	615	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04077P	\N	RP	\N	\N
10955	615	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04079R	\N	RP	\N	\N
11128	974	2005-02-24 00:00:00	\N	2011-09-30 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. Paul Vergès, élu député au Parlement européen	\N	\N	SENAT	05001W	\N	NR	\N	\N
12039	490	2010-10-12 00:00:00	\N	2011-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	en remplacement de M. Christian Gaudin, nommé préfet	\N	\N	SENAT	10006L	\N	NR	\N	\N
2557	590	1992-10-02 00:00:00	1992-09-27 00:00:00	1997-06-19 00:00:00	ELECTION	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	92018S	\N	RP	\N	\N
6472	590	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	REELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	92018S	\N	RP	\N	\N
490	590	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	92042S	\N	RP	\N	\N
6468	590	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	REN1	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	92042S	\N	RP	\N	\N
12667	990	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	11072N	\N	SM2	\N	2017-09-24 18:16:33
12672	610	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	11100Y	\N	SM2	\N	2017-09-24 13:57:40
12673	630	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	01031L	\N	SM2	\N	2017-09-24 18:20:10
12675	630	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	11104D	\N	SM2	\N	2017-09-24 18:20:10
12676	1053	2011-10-01 00:00:00	2011-09-25 00:00:00	2012-07-21 00:00:00	ELECTION	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	11027H	\N	RP	\N	\N
12677	1053	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	11026G	\N	RP	\N	2017-09-24 18:59:59
12679	1053	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	04036E	\N	RP	\N	2017-09-24 18:59:59
12682	828	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	04074L	\N	RP	\N	2017-09-24 17:15:15
12683	828	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	11088W	\N	RP	\N	2017-09-24 17:15:15
12685	828	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	11089X	\N	RP	\N	2017-09-24 17:15:15
12686	828	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	04078Q	\N	RP	\N	2017-09-24 17:15:15
12687	974	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	11020A	\N	RP	\N	2017-09-24 16:24:51
12688	974	2011-10-01 00:00:00	2011-09-25 00:00:00	2014-06-30 00:00:00	ELECTION	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	11022C	\N	RP	\N	2014-07-01 10:40:12
12690	974	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	11025F	\N	RP	\N	2017-09-24 16:24:51
12692	615	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04071H	\N	RP	\N	2017-09-24 17:47:27
12693	600	2011-10-01 00:00:00	2011-09-25 00:00:00	2015-01-07 00:00:00	REN2	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	92035T	\N	RP	\N	2015-01-08 17:14:28
12695	600	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	11046L	\N	RP	\N	2017-09-24 17:29:37
12696	600	2011-10-01 00:00:00	\N	2014-05-11 00:00:00	ELECTION	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	11045K	2014-04-10 00:00:00	RP	\N	2017-04-24 17:52:17
12697	620	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN3	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	83047W	\N	RP	\N	2017-09-24 17:42:26
12698	620	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	11061K	\N	RP	\N	2017-09-24 17:42:25
12699	620	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	11059R	\N	RP	\N	2017-09-24 17:42:26
12700	620	2011-10-01 00:00:00	2011-09-25 00:00:00	2013-02-28 00:00:00	ELECTION	DEM	ANCIEN	\N	\N	\N	\N	2013	SENAT	11062L	\N	RP	\N	\N
12701	620	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	01034P	\N	RP	\N	2017-09-24 17:42:26
12702	620	2011-10-01 00:00:00	2011-09-25 00:00:00	2016-01-11 00:00:00	ELECTION	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	11060J	\N	RP	\N	2016-01-11 17:34:09
12704	590	2011-10-01 00:00:00	2011-09-25 00:00:00	2015-04-21 00:00:00	REN1	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	01042P	\N	RP	\N	2015-04-21 17:16:17
12705	590	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	01043Q	\N	RP	\N	2017-09-24 18:16:52
12706	420	2011-10-01 00:00:00	2011-09-25 00:00:00	2016-12-10 00:00:00	REN1	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	01037S	\N	RP	\N	2016-12-12 16:10:15
12707	420	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	11056N	\N	RP	\N	2017-09-24 18:23:22
12710	490	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	10006L	\N	RP	\N	2017-09-24 17:09:24
12711	420	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	97011G	\N	RP	\N	2017-09-24 18:23:22
12712	440	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	11066Q	\N	RP	\N	2017-09-24 17:04:02
12713	440	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	11067R	\N	RP	\N	2017-09-24 17:04:02
12714	440	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	11065P	\N	RP	\N	2017-09-24 17:04:02
12717	380	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	01019Q	\N	RP	\N	2017-09-24 17:35:15
12718	380	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	11043H	\N	RP	\N	2017-09-24 17:35:15
12719	380	2011-10-01 00:00:00	2011-09-25 00:00:00	2014-05-11 00:00:00	ELECTION	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	11041F	2014-04-10 00:00:00	RP	\N	2017-04-24 17:52:47
12722	615	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	04080J	\N	RP	\N	2017-09-24 17:47:27
12725	770	2011-10-01 00:00:00	2011-09-25 00:00:00	2016-11-30 00:00:00	REN1	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	04048J	\N	RP	\N	2016-12-01 10:36:51
12727	770	2011-10-01 00:00:00	2011-09-25 00:00:00	2012-06-16 00:00:00	REN1	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	04053F	2012-05-16 00:00:00	RP	\N	\N
12728	770	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	04054G	\N	RP	\N	2017-09-24 17:18:03
12729	895	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	86034E	\N	RP	\N	2017-09-24 18:17:56
12731	895	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	95035G	\N	RP	\N	2017-09-24 18:17:56
12733	615	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	04066L	\N	RP	\N	2017-09-24 17:47:28
12736	615	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	11077T	\N	RP	\N	2017-09-24 17:47:27
12737	615	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	04079R	\N	RP	\N	2017-09-24 17:47:27
12739	615	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04059M	\N	RP	\N	2017-09-24 17:47:27
12740	615	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	11076S	\N	RP	\N	2017-09-24 17:47:28
12741	615	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	11080N	\N	RP	\N	2017-09-24 17:47:27
12742	824	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-07-28 00:00:00	ELECTION	CESDEPUTE	ANCIEN	\N	\N	\N	\N	\N	SENAT	11032E	\N	RP	\N	2017-08-03 11:38:41
12743	824	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	11031D	\N	RP	\N	2017-09-24 17:55:12
12745	824	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	11033F	\N	RP	\N	2017-09-24 17:47:27
12746	775	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	11054L	\N	RP	\N	2017-09-24 18:07:56
12747	775	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	11055M	\N	RP	\N	2017-09-24 18:07:57
12748	775	2011-10-01 00:00:00	2011-09-25 00:00:00	2015-03-03 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	11051H	\N	RP	\N	2015-03-03 10:16:55
12749	775	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	11053K	\N	RP	\N	2017-09-24 18:07:57
12750	775	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04085P	\N	RP	\N	2017-09-24 18:07:56
12751	775	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04086Q	\N	RP	\N	2017-09-24 18:07:56
12752	824	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04042C	\N	RP	\N	2017-09-24 17:55:12
12753	824	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04043D	\N	RP	\N	2017-09-24 17:55:12
12754	335	2011-10-01 00:00:00	2011-09-25 00:00:00	2016-12-31 00:00:00	REN1	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	07024N	\N	RP	\N	2017-01-03 11:09:24
12755	335	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	11084S	\N	RP	\N	2017-09-24 19:25:10
12756	335	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	07026Q	\N	RP	\N	2017-09-24 19:25:10
12757	335	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	11083R	\N	RP	\N	2017-09-24 19:25:10
12758	335	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	11085T	\N	RP	\N	2017-09-24 19:25:10
12759	335	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	99004R	\N	RP	\N	2017-09-24 19:25:10
12760	335	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	04081K	\N	RP	\N	2017-09-24 19:25:10
12895	770	2012-06-17 00:00:00	\N	2014-05-02 00:00:00	REMPLACE	REPEXE	ANCIEN	\N	\N	en remplacement de Mme Nicole Bricq, nommée membre du Gouvernement	\N	\N	SENAT	12035A	\N	NR	\N	2017-08-07 17:25:35
12903	580	2012-12-03 00:00:00	2012-12-02 00:00:00	2017-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	12042Y	\N	SM1	\N	2017-09-24 19:31:54
12907	60	2013-02-07 00:00:00	\N	2014-09-30 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	remplace M. René Vestri, décédé	\N	\N	SENAT	13001T	\N	NR	\N	2014-09-28 17:58:04
12918	680	2013-06-28 00:00:00	\N	2014-09-30 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. Jean-Louis Lorrain, décédé	\N	\N	SENAT	13003V	\N	NR	2013-07-01 09:35:52	2014-09-28 17:14:21
12929	760	2013-10-01 00:00:00	\N	2014-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	en remplacement de M. Alain Le Vern, démissionnaire	\N	\N	SENAT	13005X	\N	NR	2013-10-01 15:26:13	2014-09-28 18:00:58
5099	30	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	89018S	\N	NR	\N	\N
5100	30	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	98024R	\N	NR	\N	\N
5109	150	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	98027U	\N	NR	\N	\N
5113	250	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	98028V	\N	NR	\N	\N
5117	240	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	98029W	\N	NR	\N	\N
5118	360	1998-10-01 00:00:00	1998-09-27 00:00:00	2007-11-21 00:00:00	REN1	DECEDE	ANCIEN	\N	\N	\N	\N	2007	SENAT	89020L	\N	NR	\N	\N
5119	150	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	89010J	\N	NR	\N	\N
5120	360	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	89030N	\N	NR	\N	\N
5121	20	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	REN3	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	78003A	\N	NR	\N	\N
5122	300	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	80040B	\N	NR	\N	\N
5125	40	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	98030P	\N	NR	\N	\N
5131	320	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	98032R	\N	NR	\N	\N
5134	320	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	98033S	\N	NR	\N	\N
5138	300	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	98034T	\N	NR	\N	\N
5141	300	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	98035U	\N	NR	\N	\N
5142	20	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	98036V	\N	NR	\N	\N
5148	70	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	98037W	\N	NR	\N	\N
5151	220	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	98038X	\N	NR	\N	\N
5153	160	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	98039Y	\N	NR	\N	\N
5161	140	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	89007P	\N	NR	\N	\N
5162	60	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	REN2	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	85003S	\N	RP	\N	\N
5163	60	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	98040R	\N	RP	\N	\N
5164	140	1998-10-01 00:00:00	1998-09-27 00:00:00	2008-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	98041S	\N	NR	\N	\N
9492	1030	1959-05-31 00:00:00	1959-05-31 00:00:00	1962-07-04 00:00:00	ELECTION	CESMANORD	ANCIEN	\N	\N	\N	\N	\N	SENAT	000091	\N	NR	\N	\N
9500	1042	1959-05-31 00:00:00	1959-05-31 00:00:00	1962-07-04 00:00:00	ELECTION	CESMANORD	ANCIEN	\N	\N	\N	\N	\N	SENAT	57701F	\N	NR	\N	\N
9507	1043	1959-05-31 00:00:00	1959-05-31 00:00:00	1962-07-04 00:00:00	ELECTION	CESMANORD	ANCIEN	\N	\N	\N	\N	\N	SENAT	000665	\N	NR	\N	\N
9521	1044	1961-07-19 00:00:00	\N	1962-07-04 00:00:00	REMPLACE	CESMANORD	ANCIEN	\N	\N	En remplacement de M. Benaissa SASSI	\N	\N	SENAT	000257	\N	NR	\N	\N
11498	280	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	08011M	\N	SM1	\N	2014-09-28 17:12:41
9538	1045	1959-05-31 00:00:00	1959-05-31 00:00:00	1962-07-04 00:00:00	ELECTION	CESMANORD	ANCIEN	\N	\N	\N	\N	\N	SENAT	56531B	\N	NR	\N	\N
9557	1040	1959-05-31 00:00:00	1959-05-31 00:00:00	1962-07-04 00:00:00	ELECTION	CESMANORD	ANCIEN	\N	\N	\N	\N	\N	SENAT	56406W	\N	NR	\N	\N
9565	1043	1959-05-31 00:00:00	1959-05-31 00:00:00	1962-07-04 00:00:00	ELECTION	CESMANORD	ANCIEN	\N	\N	\N	\N	\N	SENAT	000132	\N	NR	\N	\N
9748	1044	1959-05-31 00:00:00	1959-05-31 00:00:00	1962-07-04 00:00:00	ELECTION	CESMANORD	ANCIEN	\N	\N	\N	\N	\N	SENAT	56405V	\N	NR	\N	\N
9749	984	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	71031Y	\N	NR	\N	\N
9750	984	1980-10-02 00:00:00	1980-09-28 00:00:00	1989-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	71031Y	\N	NR	\N	\N
9751	984	1989-10-02 00:00:00	1989-09-24 00:00:00	1998-04-05 00:00:00	REN2	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	71031Y	\N	NR	\N	\N
9752	630	1974-10-02 00:00:00	1974-09-22 00:00:00	1981-07-23 00:00:00	ELECTION	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	74041P	\N	NR	\N	\N
9753	630	1981-09-27 00:00:00	1981-09-27 00:00:00	1981-10-27 00:00:00	ELECTION	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	74041P	\N	NR	\N	\N
9754	630	1983-10-03 00:00:00	1983-09-25 00:00:00	1986-04-02 00:00:00	ELECTION	CESDEPUTE	ANCIEN	\N	\N	\N	\N	\N	SENAT	74041P	\N	NR	\N	\N
9755	630	1986-10-02 00:00:00	1986-09-28 00:00:00	1992-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	74041P	\N	NR	\N	\N
9756	630	1992-09-27 00:00:00	\N	1998-07-14 00:00:00	REN1	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	74041P	\N	NR	\N	\N
9757	1012	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	58515K	\N	NR	\N	\N
9758	1012	1974-10-02 00:00:00	1974-09-22 00:00:00	1980-06-30 00:00:00	REN	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	58515K	\N	NR	\N	\N
255	60	1988-09-11 00:00:00	1988-09-11 00:00:00	1989-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	88012G	\N	RP	\N	\N
1948	615	1994-09-28 00:00:00	\N	1995-09-24 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. François COLLET, décédé	\N	\N	SENAT	000465	\N	RP	\N	\N
2652	810	1983-08-21 00:00:00	\N	1986-10-01 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. Georges SPENALE, décédé	\N	\N	SENAT	000647	\N	NR	\N	\N
123	300	1992-12-21 00:00:00	1992-12-20 00:00:00	1998-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Gilbert Baumet, nommé membre du Gouvernement	\N	\N	SENAT	92046W	\N	NR	\N	\N
2457	190	1968-01-07 00:00:00	\N	1971-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Marcel Audy, décédé.	\N	\N	SENAT	000121	\N	NR	\N	\N
2271	410	1961-10-04 00:00:00	\N	1965-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	suite au décès de M. Jacques BOISROND le 3 octobre 1961	\N	\N	SENAT	57432D	\N	NR	\N	\N
5893	390	2001-02-08 00:00:00	\N	2001-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Pierre JEAMBRUN, décédé	\N	\N	SENAT	01002F	\N	NR	\N	\N
356	20	1988-06-13 00:00:00	\N	1989-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Jacques PELLETIER, nommé membre du Gouvernement	\N	\N	SENAT	88005H	\N	NR	\N	\N
3697	100	1980-11-02 00:00:00	\N	1989-10-01 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. Roger GALLEY, démissionnaire.	\N	\N	SENAT	58917A	\N	NR	\N	\N
3297	60	1966-02-11 00:00:00	\N	1971-10-01 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. Emile HUGUES, décédé	\N	\N	SENAT	000332	\N	RP	\N	\N
447	335	1977-10-03 00:00:00	1977-09-25 00:00:00	1986-04-19 00:00:00	ELECTION	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	77053G	\N	RP	\N	\N
10508	450	1959-04-28 00:00:00	\N	1965-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000008	\N	NR	\N	\N
10510	450	1965-10-02 00:00:00	\N	1974-10-01 00:00:00	REN3	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000008	\N	NR	\N	\N
10518	971	1968-10-02 00:00:00	1968-09-22 00:00:00	1977-10-02 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000684	\N	NR	\N	\N
10521	470	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000198	\N	NR	\N	\N
10536	410	1959-04-28 00:00:00	\N	1961-10-03 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	1959	SENAT	000761	\N	NR	\N	\N
10535	1029	1959-04-28 00:00:00	1959-04-26 00:00:00	1967-04-18 00:00:00	ELECTION	DEM	ANCIEN	\N	\N	\N	\N	1958	SENAT	000086	\N	NR	\N	\N
10569	690	2003-11-05 00:00:00	\N	2004-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Emmanuel Hamel, décédé	\N	\N	SENAT	03003Q	\N	RP	\N	\N
10558	770	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000140	\N	RP	\N	\N
10582	110	1971-10-02 00:00:00	1971-09-26 00:00:00	1980-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000334	\N	NR	\N	\N
6740	860	2002-06-07 00:00:00	\N	2004-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Jean-Pierre Raffarin, nommé Premier ministre	\N	\N	SENAT	02002K	\N	NR	\N	\N
2	650	1992-10-02 00:00:00	1992-09-27 00:00:00	2001-03-02 00:00:00	REN1	DECEDE	ANCIEN	\N	\N	\N	\N	2001	SENAT	83008P	\N	NR	\N	\N
2866	860	1986-11-02 00:00:00	\N	1988-07-01 00:00:00	REMPLACE	DEM	ANCIEN	\N	\N	En remplacement de M. René MONORY, nommé membre du Gouvernement	\N	\N	SENAT	58816V	\N	NR	\N	\N
3969	125	1971-11-03 00:00:00	\N	1980-10-01 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. Jean Bailly, nommé membre du Gouvernement	\N	\N	SENAT	58508L	\N	NR	\N	\N
11761	260	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	96006F	\N	SM2	\N	2014-09-28 16:50:17
11770	250	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	08068F	\N	SM2	\N	2014-09-28 17:22:11
12011	220	2010-03-16 00:00:00	\N	2014-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	en remplacement de Jacqueline Chevé, décédée	\N	\N	SENAT	10003H	\N	NR	\N	2014-09-28 17:38:26
12045	510	2010-11-03 00:00:00	\N	2011-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	en remplacement de M. Jean-Claude Etienne, devenu membre du Conseil économique, social et environnemental	\N	\N	SENAT	10007M	\N	NR	\N	\N
11293	360	2007-11-22 00:00:00	\N	2008-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de Daniel Bernardet, décédé	\N	\N	SENAT	07032N	\N	NR	\N	\N
11225	50	2007-01-26 00:00:00	2007-01-26 00:00:00	2008-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Marcel Lesbros, décédé	\N	\N	SENAT	07003H	\N	NR	\N	\N
11233	610	2007-02-26 00:00:00	\N	2011-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	en remplacement de M. Daniel Goulet, décédé	\N	\N	SENAT	07004J	\N	NR	\N	2017-06-14 09:57:53
12061	895	2011-01-23 00:00:00	2011-01-23 00:00:00	2011-09-30 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	en remplacement de M. Nicolas About, devenu membre du Conseil supérieur de l'audiovisuel	\N	\N	SENAT	11001K	\N	RP	\N	\N
12073	550	2011-03-28 00:00:00	\N	2011-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	en remplacement de M. Gérard Longuet, nommé membre du Gouvernement	\N	\N	SENAT	11003M	\N	NR	\N	\N
12028	420	2010-04-17 00:00:00	\N	2011-09-30 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	en remplacement de M. Michel Thiollière dont le mandat a cessé	\N	\N	SENAT	10005K	\N	RP	\N	\N
11252	760	2007-06-29 00:00:00	\N	2013-09-30 00:00:00	REMPLACE	DEM	ANCIEN	\N	\N	En remplacement de Mme Sandrine Hurel, élue députée	\N	\N	SENAT	07025P	\N	RP	\N	2013-10-01 15:11:11
11262	335	2007-06-29 00:00:00	\N	2011-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Roland Muzeau, élu député	\N	\N	SENAT	07026Q	\N	RP	\N	\N
10586	265	2004-02-13 00:00:00	\N	2004-09-30 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. Michel Pelchat, décédé	\N	\N	SENAT	03004R	\N	RP	\N	\N
10695	828	2004-05-01 00:00:00	\N	2004-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de Mme Nelly Olin, nommée membre du Gouvernement	\N	\N	SENAT	04016A	\N	RP	\N	\N
10699	180	2004-05-01 00:00:00	\N	2005-06-30 00:00:00	REMPLACE	DEM	ANCIEN	\N	\N	En remplacement de M. Serge Lepeltier, nommé membre du Gouvernement	\N	\N	SENAT	04017B	2005-06-30 00:00:00	NR	\N	\N
10702	895	2004-05-01 00:00:00	\N	2004-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Gérard Larcher, nommé membre du Gouvernement	\N	\N	SENAT	04018C	\N	RP	\N	\N
10748	390	1959-04-28 00:00:00	\N	1965-09-25 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000042	\N	NR	\N	\N
10765	720	2004-10-01 00:00:00	2004-09-26 00:00:00	2004-11-01 00:00:00	ELECTION	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	02009S	\N	NR	\N	\N
452	810	1995-10-02 00:00:00	1995-09-24 00:00:00	2004-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95052H	\N	NR	\N	\N
11514	220	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	98038X	\N	SM1	\N	2014-09-28 17:38:26
11516	220	2008-10-01 00:00:00	2008-09-21 00:00:00	2010-03-15 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	2010	SENAT	08013P	\N	SM1	\N	\N
10775	860	2004-10-01 00:00:00	2004-09-26 00:00:00	2004-11-01 00:00:00	ELECTION	CESPREMIN	ANCIEN	\N	\N	\N	\N	\N	SENAT	95059Q	\N	NR	\N	\N
10878	670	2004-10-01 00:00:00	2004-09-26 00:00:00	2004-11-26 00:00:00	REN2	ANNCC	ANCIEN	\N	\N	\N	\N	\N	SENAT	92005M	\N	RP	\N	\N
10879	670	2004-10-01 00:00:00	2004-09-26 00:00:00	2004-11-26 00:00:00	REN1	ANNCC	ANCIEN	\N	\N	\N	\N	\N	SENAT	95036H	\N	RP	\N	\N
10882	670	2004-10-01 00:00:00	2004-09-26 00:00:00	2004-11-26 00:00:00	ELECTION	ANNCC	ANCIEN	\N	\N	\N	\N	\N	SENAT	04061F	\N	RP	\N	\N
11091	80	2004-10-19 00:00:00	\N	2008-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de M. Hilaire Flandre, décédé	\N	\N	SENAT	04097T	\N	NR	\N	\N
11025	972	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04094Q	\N	NR	\N	\N
11029	971	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04095R	\N	NR	\N	\N
10893	670	2004-10-01 00:00:00	2004-09-26 00:00:00	2004-11-26 00:00:00	ELECTION	ANNCC	ANCIEN	\N	\N	\N	\N	\N	SENAT	04065K	\N	RP	\N	\N
11033	971	2004-10-01 00:00:00	2004-09-26 00:00:00	2011-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	04096S	\N	NR	\N	\N
11103	828	2004-11-02 00:00:00	\N	2011-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de Mme Nelly Olin, nommée membre du Gouvernement	\N	\N	SENAT	04100U	\N	RP	\N	\N
11112	130	2004-12-24 00:00:00	\N	2008-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Henri d'Attilio, déchu de son mandat	\N	\N	SENAT	04101V	\N	RP	\N	\N
11123	670	2005-02-21 00:00:00	2005-02-20 00:00:00	2010-12-14 00:00:00	ELECTION	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	92005M	2010-11-14 00:00:00	RP	\N	\N
11124	670	2005-02-20 00:00:00	2005-02-20 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04061F	\N	RP	\N	2014-09-28 17:31:42
11125	670	2005-02-21 00:00:00	2005-02-20 00:00:00	2014-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	04065K	\N	RP	\N	2014-09-28 17:31:42
11126	670	2005-02-21 00:00:00	2005-02-20 00:00:00	2014-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	04069P	\N	RP	\N	2014-09-28 17:31:41
11127	670	2005-02-21 00:00:00	2005-02-20 00:00:00	2014-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	95036H	\N	RP	\N	2014-09-28 17:31:42
6443	620	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	01033N	\N	RP	\N	\N
11153	205	2005-06-19 00:00:00	2005-06-19 00:00:00	2008-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	05011Y	\N	NR	\N	\N
10916	670	2004-10-01 00:00:00	2004-09-26 00:00:00	2004-11-26 00:00:00	ELECTION	ANNCC	ANCIEN	\N	\N	\N	\N	\N	SENAT	04069P	\N	RP	\N	\N
11521	220	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	08014Q	\N	SM1	\N	2014-09-28 17:38:26
11218	620	2007-01-03 00:00:00	2007-01-03 00:00:00	2011-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de Mme Maryse Roger-Coupin, démissionnaire	\N	\N	SENAT	07001F	\N	RP	\N	\N
11221	620	2007-01-02 00:00:00	\N	2007-01-03 00:00:00	REMPLACE	DEM	ANCIEN	\N	\N	En remplacement de M. Yves Coquelle, démissionnaire	\N	\N	SENAT	07002G	\N	RP	\N	\N
11245	540	2007-06-22 00:00:00	\N	2011-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Jacques Baudot, décédé	\N	\N	SENAT	07023M	\N	RP	\N	\N
11773	210	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	08069G	\N	SM2	\N	2014-09-28 16:54:10
11980	335	2009-07-24 00:00:00	\N	2009-07-28 00:00:00	REPRISE	CESMAN	ANCIEN	\N	\N	En remplacement de M. Jacques Gautier	\N	\N	SENAT	99004R	\N	RP	\N	\N
11987	230	2009-09-10 00:00:00	2009-09-10 00:00:00	2014-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de André Lejeune, décédé	\N	\N	SENAT	09012S	\N	NR	\N	2014-09-28 13:09:05
12053	670	2010-12-15 00:00:00	2010-12-15 00:00:00	2014-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	en remplacement de M. Philippe RICHERT, nommé membre du Gouvernement	\N	\N	SENAT	10015M	\N	RP	\N	2014-09-28 17:31:42
11193	340	2006-07-09 00:00:00	\N	2008-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de Marcel Vidal, décédé	\N	\N	SENAT	06004E	\N	NR	\N	\N
11264	680	2007-07-20 00:00:00	2007-07-20 00:00:00	2010-12-13 00:00:00	REMPLACE	CESMAN	ANCIEN	\N	\N	En remplacement de M. Jean-Marie Bockel, nommé membre du Gouvernement	\N	\N	SENAT	07027R	\N	RP	\N	\N
11266	590	2007-07-20 00:00:00	\N	2010-12-13 00:00:00	REMPLACE	CESMAN	ANCIEN	\N	\N	En remplacement de Mme Valérie Létard, nommée membre du Gouvernement	\N	\N	SENAT	07028S	\N	RP	\N	\N
11306	180	2007-12-17 00:00:00	\N	2008-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de Serge Vinçon, décédé	\N	\N	SENAT	07034Q	2007-12-17 00:00:00	NR	\N	\N
11537	997	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	98018T	\N	RP	\N	2014-09-28 18:46:14
11538	997	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	98019U	\N	RP	\N	2014-09-29 13:43:44
11539	997	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	08017T	\N	RP	\N	2014-09-28 18:46:14
11544	9713	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	08019V	\N	SM2	\N	2014-09-28 17:03:07
11561	330	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	80027E	\N	RP	\N	2014-09-28 17:53:13
11564	330	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	08022Q	\N	RP	\N	2014-09-28 17:53:13
11571	330	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	08024S	\N	RP	\N	2014-09-28 17:53:13
11575	330	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	08025T	\N	RP	\N	2014-09-28 17:53:13
11580	310	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	98011L	\N	RP	\N	2014-09-28 17:27:35
11581	310	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	98010K	\N	RP	\N	2014-09-28 17:27:35
11584	310	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	08028W	\N	RP	\N	2014-09-28 17:27:35
11601	310	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	08031R	\N	RP	\N	2014-09-28 17:27:35
11604	310	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	08033T	\N	RP	\N	2014-09-28 17:27:35
11614	60	2008-10-01 00:00:00	2008-09-21 00:00:00	2013-02-06 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	08036W	\N	RP	\N	\N
11621	60	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	08038Y	\N	RP	\N	2014-09-28 17:58:05
11629	60	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	08039A	\N	RP	\N	2014-09-28 17:58:05
11642	60	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	08041T	\N	RP	\N	2014-09-28 17:58:05
11648	60	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	08042U	\N	RP	\N	2014-09-28 17:58:05
11661	50	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	07003H	\N	SM2	\N	2014-09-28 12:21:28
11664	190	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-02-13 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	08046Y	\N	SM2	\N	2014-02-14 10:20:23
11679	190	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	08050U	\N	SM2	\N	2014-09-28 12:44:31
11687	100	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	94003T	\N	SM2	\N	2014-09-28 13:16:32
11689	20	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	08052W	\N	SM2	\N	2014-09-28 17:15:42
11701	180	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	07034Q	\N	SM2	\N	2014-09-28 12:31:22
11705	240	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	08055A	\N	SM2	\N	2014-09-28 18:40:55
11714	160	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	08058D	\N	SM2	\N	2014-09-28 18:57:56
11725	160	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	08060W	\N	SM2	\N	2014-09-28 13:04:50
11731	360	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	07032N	\N	SM2	\N	2014-09-28 12:51:56
11733	360	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	08062Y	\N	SM2	\N	2014-09-28 19:26:58
11742	120	2008-10-01 00:00:00	2008-09-21 00:00:00	2012-07-21 00:00:00	ELECTION	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	08064B	2012-06-21 00:00:00	SM2	\N	2016-12-14 15:21:07
11748	120	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	08066D	\N	SM2	\N	2014-09-28 19:03:23
11760	260	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	89015P	\N	SM2	\N	2014-09-28 16:50:17
6429	620	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	REN1	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	92043T	\N	RP	\N	\N
6431	450	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	01028R	\N	NR	\N	\N
6432	420	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	1968	SENAT	97011G	\N	RP	\N	\N
6433	450	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	01029S	\N	NR	\N	\N
6436	630	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	01030K	\N	NR	\N	\N
6437	630	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	01031L	\N	NR	\N	\N
6440	640	2001-10-01 00:00:00	2001-09-23 00:00:00	2006-05-16 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	2006	SENAT	01032M	\N	NR	\N	\N
12566	895	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	11090Q	\N	RP	\N	2017-09-24 18:17:56
6449	620	2001-10-01 00:00:00	2001-09-23 00:00:00	2007-01-01 00:00:00	ELECTION	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	01035Q	\N	RP	\N	\N
6450	620	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	01036R	\N	RP	\N	\N
6453	998	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	77002U	\N	RP	\N	\N
6454	998	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	92008Q	\N	RP	\N	\N
6455	420	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	01037S	\N	RP	\N	\N
6458	420	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	01038T	\N	RP	\N	\N
6459	510	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	01024M	\N	NR	\N	\N
6460	420	2001-10-01 00:00:00	2001-09-23 00:00:00	2010-04-16 00:00:00	ELECTION	CESMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	01039U	\N	RP	\N	\N
6462	998	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	01040M	\N	RP	\N	\N
6463	490	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	01018P	\N	NR	\N	\N
6464	998	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	01041N	\N	RP	\N	\N
6466	590	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	92031P	\N	RP	\N	\N
6467	590	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	92037V	\N	RP	\N	\N
12423	982	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	11011M	\N	SM1	\N	2017-09-24 10:41:28
6470	590	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	92044U	\N	RP	\N	\N
6471	590	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	01042P	\N	RP	\N	\N
6473	590	2001-10-01 00:00:00	2001-09-23 00:00:00	2007-07-19 00:00:00	ELECTION	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	01043Q	2007-06-19 00:00:00	RP	\N	\N
6477	590	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	01045S	\N	RP	\N	\N
6479	660	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	92011K	\N	NR	\N	\N
6480	470	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	83033Q	\N	NR	\N	\N
6481	390	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	01046T	\N	NR	\N	\N
6483	530	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	01047U	\N	NR	\N	\N
6485	550	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-03-27 00:00:00	ELECTION	DEMMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	01048V	\N	NR	\N	\N
6488	550	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	01049W	\N	NR	\N	\N
6490	610	2001-10-01 00:00:00	2001-09-23 00:00:00	2007-02-25 00:00:00	REN1	DECEDE	ANCIEN	\N	\N	\N	\N	2007	SENAT	92024Q	\N	NR	\N	\N
6497	470	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	01050P	\N	NR	\N	\N
6502	430	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	01052R	\N	NR	\N	\N
6503	440	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	83012K	\N	RP	\N	\N
6504	430	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	REN3	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	78006D	\N	NR	\N	\N
6505	410	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-01-23 00:00:00	REN1	CESMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	92022N	\N	NR	\N	\N
6506	580	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	86053H	\N	NR	\N	\N
12405	982	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	11010L	\N	SM1	\N	2017-09-24 10:41:28
6507	440	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	01053S	\N	RP	\N	\N
5475	450	1965-10-02 00:00:00	1965-09-26 00:00:00	1974-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000719	\N	NR	\N	\N
5478	110	1967-06-11 00:00:00	1967-06-11 00:00:00	1968-09-23 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000678	\N	NR	\N	\N
5480	400	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000697	\N	NR	\N	\N
5481	400	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000697	\N	NR	\N	\N
5487	1029	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	REN	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000766	\N	NR	\N	\N
5493	580	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN3	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000675	\N	NR	\N	\N
5494	580	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN4	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	000675	\N	NR	\N	\N
5497	1029	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000753	\N	NR	\N	\N
51008	830	2017-09-22 00:00:00	\N	2020-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	Nouveau	en remplacement de M. Hubert Falco, démissionnaire.	\N	\N	SENAT	15447F	\N	NR	2017-09-22 10:59:04	2017-09-22 11:03:28
5501	490	1955-06-19 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000700	\N	NR	\N	\N
5502	490	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000700	\N	NR	\N	\N
5505	840	1972-10-20 00:00:00	\N	1977-10-02 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Marcel PELLENC, décédé	\N	\N	SENAT	000765	\N	NR	\N	\N
5508	590	1967-04-03 00:00:00	\N	1974-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. Charles NAVEAU, député	\N	\N	SENAT	000721	\N	RP	\N	\N
51078	974	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19657G	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
5512	760	1958-06-08 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000732	\N	RP	\N	\N
9498	1040	1959-05-31 00:00:00	1959-05-31 00:00:00	1962-07-04 00:00:00	ELECTION	CESMANORD	ANCIEN	\N	\N	\N	\N	\N	SENAT	000234	\N	NR	\N	\N
9502	1040	1959-05-31 00:00:00	1959-05-31 00:00:00	1961-11-12 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	1961	SENAT	000021	\N	NR	\N	\N
9505	1043	1959-05-31 00:00:00	1959-05-31 00:00:00	1962-07-04 00:00:00	ELECTION	CESMANORD	ANCIEN	\N	\N	\N	\N	\N	SENAT	000064	\N	NR	\N	\N
51079	974	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19659J	\N	RP	2017-09-24 00:00:00	\N
9511	1033	1952-05-18 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000759	\N	NR	\N	\N
9512	1033	1959-05-31 00:00:00	1959-05-31 00:00:00	1959-08-28 00:00:00	REN2	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000759	\N	NR	\N	\N
9514	1033	1959-05-31 00:00:00	1959-05-31 00:00:00	1962-07-04 00:00:00	ELECTION	CESMANORD	ANCIEN	\N	\N	\N	\N	\N	SENAT	56326X	\N	NR	\N	\N
9516	1033	1959-08-29 00:00:00	\N	1962-07-04 00:00:00	REMPLACE	CESMANORD	ANCIEN	\N	\N	En remplacement de M. Chérif BENHABYLES	\N	\N	SENAT	000028	\N	NR	\N	\N
9518	1042	1959-05-31 00:00:00	1959-05-31 00:00:00	1962-07-04 00:00:00	ELECTION	CESMANORD	ANCIEN	\N	\N	\N	\N	\N	SENAT	000010	\N	NR	\N	\N
9523	1045	1959-05-31 00:00:00	1959-05-31 00:00:00	1962-07-04 00:00:00	ELECTION	CESMANORD	ANCIEN	\N	\N	\N	\N	\N	SENAT	000511	\N	NR	\N	\N
9527	1030	1952-05-18 00:00:00	\N	1959-04-27 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000699	\N	NR	\N	\N
9528	1030	1959-05-31 00:00:00	1959-05-31 00:00:00	1962-07-04 00:00:00	REN2	CESMANORD	ANCIEN	\N	\N	\N	\N	\N	SENAT	000699	\N	NR	\N	\N
9531	1044	1961-02-22 00:00:00	\N	1962-07-04 00:00:00	REMPLACE	CESMANORD	ANCIEN	\N	\N	En remplacement de M. Fernand MALE	\N	\N	SENAT	000075	\N	NR	\N	\N
9535	1030	1958-06-08 00:00:00	\N	1959-05-31 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000071	\N	NR	\N	\N
9536	1030	1959-05-31 00:00:00	1959-05-31 00:00:00	1962-07-04 00:00:00	REN2	CESMANORD	ANCIEN	\N	\N	\N	\N	\N	SENAT	000071	\N	NR	\N	\N
9540	1030	1959-05-31 00:00:00	1959-05-31 00:00:00	1962-07-04 00:00:00	ELECTION	CESMANORD	ANCIEN	\N	\N	\N	\N	\N	SENAT	000162	\N	NR	\N	\N
9543	1025	1973-04-08 00:00:00	1973-04-08 00:00:00	1975-11-06 00:00:00	ELECTION	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	000403	\N	NR	\N	\N
9545	1012	1959-04-28 00:00:00	1959-04-26 00:00:00	1965-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	57208W	\N	NR	\N	\N
9549	1020	1959-04-28 00:00:00	1959-04-26 00:00:00	1968-09-22 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	000153	\N	NR	\N	\N
9552	1033	1959-05-31 00:00:00	1959-05-31 00:00:00	1962-07-04 00:00:00	ELECTION	CESMANORD	ANCIEN	\N	\N	\N	\N	\N	SENAT	000670	\N	NR	\N	\N
9555	1044	1959-05-31 00:00:00	1959-05-31 00:00:00	1961-02-21 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000742	\N	NR	\N	\N
9559	1046	1959-05-24 00:00:00	1959-05-24 00:00:00	1962-07-04 00:00:00	ELECTION	CESMANORD	ANCIEN	\N	\N	\N	\N	\N	SENAT	000001	\N	NR	\N	\N
9561	1020	1959-04-28 00:00:00	1959-04-26 00:00:00	1967-04-03 00:00:00	ELECTION	CESDEPUTE	ANCIEN	\N	\N	\N	\N	\N	SENAT	000129	\N	NR	\N	\N
9563	1045	1959-05-31 00:00:00	1959-05-31 00:00:00	1962-07-04 00:00:00	ELECTION	CESMANORD	ANCIEN	\N	\N	\N	\N	\N	SENAT	000034	\N	NR	\N	\N
9567	1033	1959-05-31 00:00:00	1959-05-31 00:00:00	1962-07-04 00:00:00	ELECTION	CESMANORD	ANCIEN	\N	\N	\N	\N	\N	SENAT	000284	\N	NR	\N	\N
9570	1043	1959-05-31 00:00:00	1959-05-31 00:00:00	1962-07-04 00:00:00	ELECTION	CESMANORD	ANCIEN	\N	\N	\N	\N	\N	SENAT	000024	\N	NR	\N	\N
11464	125	2008-09-08 00:00:00	2008-09-08 00:00:00	2008-09-30 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M. Dreyfus-Schmidt, décédé	\N	\N	SENAT	08008S	\N	NR	\N	\N
9572	1021	1959-05-31 00:00:00	1959-05-31 00:00:00	1962-07-04 00:00:00	ELECTION	CESMANORD	ANCIEN	\N	\N	\N	\N	\N	SENAT	000712	\N	NR	\N	\N
9575	1042	1959-05-31 00:00:00	1959-05-31 00:00:00	1962-07-04 00:00:00	ELECTION	CESMANORD	ANCIEN	\N	\N	\N	\N	\N	SENAT	000026	\N	NR	\N	\N
9578	1021	1959-05-31 00:00:00	1959-05-31 00:00:00	1962-07-04 00:00:00	ELECTION	CESMANORD	ANCIEN	\N	\N	\N	\N	\N	SENAT	000090	\N	NR	\N	\N
9581	1020	1959-04-28 00:00:00	1959-04-26 00:00:00	1967-05-16 00:00:00	ELECTION	CESDEPUTE	ANCIEN	\N	\N	\N	\N	\N	SENAT	57310T	\N	NR	\N	\N
9583	1045	1959-05-31 00:00:00	1959-05-31 00:00:00	1962-07-04 00:00:00	ELECTION	CESMANORD	ANCIEN	\N	\N	\N	\N	\N	SENAT	000305	\N	NR	\N	\N
9585	1044	1959-05-31 00:00:00	1959-05-31 00:00:00	1961-07-18 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	1961	SENAT	000300	\N	NR	\N	\N
9587	1021	1955-06-19 00:00:00	\N	1959-05-31 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	000745	\N	NR	\N	\N
9588	1021	1959-05-31 00:00:00	1959-05-31 00:00:00	1962-07-04 00:00:00	REN	CESMANORD	ANCIEN	\N	\N	\N	\N	\N	SENAT	000745	\N	NR	\N	\N
9591	1045	1959-05-31 00:00:00	1959-05-31 00:00:00	1962-07-04 00:00:00	ELECTION	CESMANORD	ANCIEN	\N	\N	\N	\N	\N	SENAT	000029	\N	NR	\N	\N
12436	580	2011-10-01 00:00:00	2011-09-25 00:00:00	2012-09-30 00:00:00	REN1	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	01051Q	\N	SM1	\N	\N
12437	400	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	92015P	\N	SM1	\N	2017-09-24 13:14:55
12438	510	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	01024M	\N	SM1	\N	2017-09-24 17:25:22
12439	510	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	01025N	\N	SM1	\N	2017-09-24 17:25:23
12440	650	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-05-15 00:00:00	REN2	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	01003G	\N	SM1	\N	2017-05-16 15:18:13
12441	410	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-07-21 00:00:00	REN1	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	01007L	\N	SM1	\N	2017-07-24 09:56:25
12442	520	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	01057W	\N	SM1	\N	2017-09-24 13:02:55
12443	560	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	01022K	\N	SM1	\N	2017-09-24 17:14:26
12444	460	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	92039X	\N	SM1	\N	2017-09-24 13:47:46
12445	450	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	01028R	\N	SM1	\N	2017-09-24 17:28:55
12446	550	2011-10-01 00:00:00	2011-09-25 00:00:00	2011-11-01 00:00:00	REN1	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	01048V	\N	SM1	\N	2017-09-24 19:17:07
12447	660	2011-10-01 00:00:00	2011-09-25 00:00:00	2014-08-26 00:00:00	ELECTION	DECEDE	ANCIEN	\N	\N	\N	\N	\N	SENAT	11018G	\N	SM1	\N	2014-08-27 16:33:37
12452	580	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	11015D	\N	SM1	\N	2017-09-24 13:42:35
12454	400	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	11014C	\N	SM1	\N	2017-09-24 13:14:55
12455	460	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	11012A	\N	SM1	\N	2017-09-24 13:47:46
12470	995	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	11023D	\N	SM1	\N	2017-09-25 10:56:48
12510	490	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	11030C	\N	RP	\N	2017-09-24 17:09:24
12514	380	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	11042G	\N	RP	\N	2017-09-24 17:35:15
12517	420	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	11057P	\N	RP	\N	2017-09-24 18:23:22
12591	265	2011-10-01 00:00:00	2011-09-25 00:00:00	2016-03-11 00:00:00	ELECTION	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	11069T	2016-02-11 00:00:00	RP	\N	2016-12-14 15:25:33
12593	265	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	04055H	\N	RP	\N	2017-09-24 18:05:41
12594	265	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	11070L	\N	RP	\N	2017-09-24 18:05:40
12596	895	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	04056J	\N	RP	\N	2017-09-24 18:17:56
12598	570	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	01060R	\N	RP	\N	2017-09-24 17:48:21
12599	570	2011-10-01 00:00:00	2011-09-25 00:00:00	2014-12-21 00:00:00	REN1	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	01062T	2014-11-22 00:00:00	RP	\N	2017-04-24 17:51:43
12600	570	2011-10-01 00:00:00	2011-09-25 00:00:00	2014-08-31 00:00:00	REN2	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	96007G	\N	RP	\N	2014-09-01 10:21:13
12601	570	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	01061S	\N	RP	\N	2017-09-24 17:48:21
12603	590	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	11035H	\N	RP	\N	2017-09-24 18:16:52
12604	590	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	11036J	\N	RP	\N	2017-09-24 18:16:52
12607	590	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	11037K	\N	RP	\N	2017-09-24 18:16:52
12608	590	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	92031P	\N	RP	\N	2017-09-24 18:16:52
12609	590	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	11040E	\N	RP	\N	2017-09-24 18:16:52
12611	590	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN2	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	92044U	\N	RP	\N	2017-09-24 18:16:52
12612	490	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	01016M	\N	RP	\N	2017-09-24 17:09:24
12888	480	2012-03-19 00:00:00	2012-03-18 00:00:00	2017-10-01 00:00:00	REELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	11081P	\N	SM2	\N	2017-09-24 18:52:13
6385	540	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	92040Q	\N	RP	\N	\N
6387	540	2001-10-01 00:00:00	2001-09-23 00:00:00	2007-06-21 00:00:00	REN1	DECEDE	ANCIEN	\N	\N	\N	\N	2007	SENAT	92007P	\N	RP	\N	\N
6388	540	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	01014K	\N	RP	\N	\N
6389	540	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	01015L	\N	RP	\N	\N
6392	380	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	83031N	\N	RP	\N	\N
6393	490	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	01016M	\N	NR	\N	\N
6394	560	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	83050R	\N	NR	\N	\N
6395	490	2001-10-01 00:00:00	2001-09-23 00:00:00	2010-10-11 00:00:00	ELECTION	CESMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	01017N	\N	NR	\N	\N
6400	380	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	01020H	\N	RP	\N	\N
6402	600	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	REN1	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	92045V	\N	NR	\N	\N
6403	600	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	92035T	\N	NR	\N	\N
6404	560	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	01021J	\N	NR	\N	\N
6407	560	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	01022K	\N	NR	\N	\N
6411	600	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	01023L	\N	NR	\N	\N
6414	510	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	01025N	\N	NR	\N	\N
6417	510	2001-10-01 00:00:00	2001-09-23 00:00:00	2010-11-02 00:00:00	ELECTION	CESMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	01026P	\N	NR	\N	\N
6419	630	2001-10-01 00:00:00	2001-09-23 00:00:00	2010-03-06 00:00:00	REN1	CESMEMCC	ANCIEN	\N	\N	\N	\N	\N	SENAT	81015E	\N	NR	\N	\N
6421	450	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	01027Q	\N	NR	\N	\N
6425	640	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	83021L	\N	NR	\N	\N
6426	640	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	92013M	\N	NR	\N	\N
6428	620	2001-10-01 00:00:00	2001-09-23 00:00:00	2011-09-30 00:00:00	REN2	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	83047W	\N	RP	\N	\N
11527	170	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	08015R	\N	SM1	\N	2014-09-28 17:05:42
11576	130	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	98022P	\N	RP	\N	2014-09-28 17:52:18
11577	130	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	89029V	\N	RP	\N	2014-09-28 17:52:18
11582	130	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	08026U	\N	RP	\N	2014-09-28 17:58:17
11596	130	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	08029X	\N	RP	\N	2014-09-28 17:58:17
11631	130	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	08040S	\N	RP	\N	2014-09-28 17:52:18
11654	130	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	08044W	\N	RP	\N	2014-09-28 17:55:59
11690	80	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04097T	\N	SM2	\N	2014-09-28 12:51:09
11691	80	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	07029T	\N	SM2	\N	2014-09-28 12:51:09
11699	10	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	08053X	\N	SM2	\N	2014-09-28 17:27:29
11710	10	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	08056B	\N	SM2	\N	2014-09-28 17:27:29
11719	10	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	08059E	\N	SM2	\N	2014-09-28 17:27:29
11726	210	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	08061X	\N	SM2	\N	2014-09-28 16:54:10
11775	210	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-05-02 00:00:00	ELECTION	CESMEMGVT	ANCIEN	\N	\N	\N	\N	\N	SENAT	08070Y	2014-04-02 00:00:00	SM2	\N	2016-12-14 15:28:20
11983	335	2009-07-29 00:00:00	\N	2011-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	en remplacement de M. Roger Karoutchi	\N	\N	SENAT	07024N	\N	RP	\N	\N
11208	220	2006-09-25 00:00:00	2006-09-24 00:00:00	2008-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	06006G	\N	NR	\N	\N
11270	80	2007-08-27 00:00:00	2007-08-26 00:00:00	2008-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	07029T	\N	NR	\N	\N
11271	340	2007-08-27 00:00:00	2007-08-26 00:00:00	2008-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	07030L	\N	NR	\N	\N
11789	983	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-16 00:00:00	REN1	DECCC	ANCIEN	\N	\N	\N	\N	\N	SENAT	98052V	\N	SM2	\N	2014-09-17 09:41:14
11791	973	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	08072B	\N	SM2	\N	2014-09-29 09:05:47
11795	973	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	08073C	\N	SM2	\N	2014-09-28 17:44:43
11970	690	2009-07-24 00:00:00	\N	2012-06-16 00:00:00	REMPLACE	REPEXE	ANCIEN	\N	\N	En remplacement de M. Michel Mercier, nommé membre du Gouvernement	\N	\N	SENAT	09010Q	\N	RP	\N	\N
14219	60	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	08038Y	\N	RP	2014-09-28 17:58:04	2014-09-28 20:24:10
11973	890	2009-07-24 00:00:00	\N	2012-06-16 00:00:00	REMPLACE	REPEXE	ANCIEN	\N	\N	En remplacement de M. Henri de Raincourt, nommé membre du Gouvernement	\N	\N	SENAT	09011R	\N	NR	\N	\N
12006	630	2010-03-07 00:00:00	\N	2011-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	en remplacement de M. Michel Charasse, nommé membre du Conseil constitutionnel	\N	\N	SENAT	98009S	\N	NR	\N	\N
11300	615	2007-11-30 00:00:00	\N	2011-09-30 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	En remplacement de M Philippe Goujon, élu député	\N	\N	SENAT	07033P	\N	RP	\N	\N
11242	720	2007-06-18 00:00:00	\N	2014-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	\N	En remplacement de M. François Fillon, nommé Premier ministre	\N	\N	SENAT	04099V	\N	NR	\N	2014-09-28 16:59:41
11550	340	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	REN1	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	06004E	\N	SM2	\N	2014-09-28 17:03:42
11551	340	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	08020N	\N	SM2	\N	2014-09-28 17:03:42
11554	340	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	08021P	\N	SM2	\N	2014-09-28 17:03:42
11565	9715	2008-10-01 00:00:00	2008-09-21 00:00:00	2013-12-31 00:00:00	ELECTION	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	08023R	\N	SM2	\N	2014-01-02 09:46:17
11583	350	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	08027V	\N	RP	\N	2014-09-28 17:34:16
11644	290	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	98046X	\N	RP	\N	2014-09-28 17:00:59
11603	350	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	08032S	\N	RP	\N	2014-09-28 17:34:16
11606	350	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	08034U	\N	RP	\N	2014-09-28 17:34:16
11615	350	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	08037X	\N	RP	\N	2014-09-28 17:34:16
11627	125	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	02053W	\N	SM2	\N	2014-09-28 12:32:23
11650	290	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	08043V	\N	RP	\N	2014-09-28 17:00:59
11660	290	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	08045X	\N	RP	\N	2014-09-28 17:00:59
11668	290	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	08047A	\N	RP	\N	2014-09-28 17:00:59
11678	320	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	08049C	\N	SM2	\N	2014-09-28 19:07:43
11688	150	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	08051V	\N	SM2	\N	2014-09-28 13:01:25
11700	30	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	98024R	\N	SM2	\N	2014-09-28 18:32:20
11704	30	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	08054Y	\N	SM2	\N	2014-09-28 12:39:09
11711	70	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	08057C	\N	SM2	\N	2014-09-28 14:31:42
11728	140	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	98041S	\N	SM2	\N	2014-09-28 16:42:05
11730	140	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	89007P	\N	SM2	\N	2014-09-28 16:42:05
11732	140	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	98042T	\N	SM2	\N	2014-09-28 16:42:05
11737	300	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	98035U	\N	SM2	\N	2014-09-28 17:07:07
11739	300	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	08063A	\N	SM2	\N	2014-09-28 17:07:07
11746	300	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	08065C	\N	SM2	\N	2014-09-28 17:07:07
11763	250	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	98028V	\N	SM2	\N	2014-09-28 17:22:11
11765	250	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	08067E	\N	SM2	\N	2014-09-28 17:22:11
11286	895	2007-10-01 00:00:00	\N	2011-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	\N	En remplacement de Mme Adeline Gousseau, démissionnaire	\N	\N	SENAT	86034E	\N	RP	\N	\N
10783	1052	2004-10-01 00:00:00	2004-09-26 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04034C	\N	RP	\N	2014-09-28 18:46:14
14176	840	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	95037J	\N	RP	2014-09-28 17:35:38	2014-09-28 20:37:50
14177	840	2014-10-01 00:00:00	2014-09-28 00:00:00	2015-02-12 00:00:00	ELECTION	ANNCC	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14233N	\N	RP	2014-09-28 17:35:38	2015-02-12 15:05:28
14178	840	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	04092N	\N	RP	2014-09-28 17:35:38	2014-09-28 20:38:12
14181	220	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14235Q	\N	RP	2014-09-28 17:38:25	\N
14182	220	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14157T	\N	RP	2014-09-28 17:38:25	\N
14183	220	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	08014Q	\N	RP	2014-09-28 17:38:25	2014-09-28 20:28:11
14188	973	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	08073C	\N	SM1	2014-09-28 17:44:43	2014-09-28 20:41:53
14261	240	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	98029W	\N	SM2	2014-09-28 18:40:55	2014-09-28 20:29:31
14262	240	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	08055A	\N	SM2	2014-09-28 18:40:55	2014-09-28 20:29:07
14263	230	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	08012N	\N	SM2	2014-09-28 18:44:07	2014-09-28 20:28:44
14264	230	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14121F	\N	SM2	2014-09-28 18:44:07	\N
14268	1054	2014-10-01 00:00:00	2014-09-28 00:00:00	2021-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14255U	\N	RP	2014-09-28 18:46:12	\N
14275	880	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14033T	\N	SM2	2014-09-28 18:47:01	\N
11610	130	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	08035V	\N	RP	\N	2014-09-28 17:52:18
11675	130	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	08048B	\N	RP	\N	2014-09-28 17:52:18
14209	330	2014-10-01 00:00:00	2014-09-28 00:00:00	2019-08-27 00:00:00	REN4	DECEDE	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	80027E	\N	RP	2014-09-28 17:53:13	\N
14210	330	2014-10-01 00:00:00	2014-09-28 00:00:00	2017-09-30 00:00:00	REN	DEM	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	08025T	\N	RP	2014-09-28 17:53:13	2017-10-01 10:17:18
14211	330	2014-10-01 00:00:00	2014-09-28 00:00:00	2017-09-30 00:00:00	REN	DEM	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	08022Q	\N	RP	2014-09-28 17:53:13	2017-10-01 09:41:22
14212	330	2014-10-01 00:00:00	2014-09-28 00:00:00	2017-09-30 00:00:00	REN3	DEM	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	90003B	\N	RP	2014-09-28 17:53:13	2017-10-01 10:01:39
14213	330	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	NONREELU	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	08024S	\N	RP	2014-09-28 17:53:13	\N
14214	330	2014-10-01 00:00:00	2014-09-28 00:00:00	2017-09-30 00:00:00	REN2	DEM	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	98021N	\N	RP	2014-09-28 17:53:13	2017-10-01 09:22:37
14220	60	2014-10-01 00:00:00	2014-09-28 00:00:00	2017-09-30 00:00:00	REN	DEM	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	08042U	\N	RP	2014-09-28 17:58:04	2017-10-01 10:20:50
14221	60	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14187A	\N	RP	2014-09-28 17:58:04	\N
14222	60	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-24 00:00:00	REN	DECEDE	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	08041T	\N	RP	2014-09-28 17:58:04	2014-09-28 20:24:38
14223	60	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	08039A	\N	RP	2014-09-28 17:58:04	2014-09-28 20:25:00
14229	760	2014-10-01 00:00:00	2014-09-28 00:00:00	2018-05-31 00:00:00	REN2	DEM	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	98053W	\N	RP	2014-09-28 18:00:57	2018-05-31 10:52:17
14230	760	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	04070G	\N	RP	2014-09-28 18:00:57	2014-09-28 20:35:49
14231	760	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14051J	\N	RP	2014-09-28 18:00:57	\N
14232	760	2014-10-01 00:00:00	2014-09-28 00:00:00	2019-09-30 00:00:00	REN2	DEM	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	95062K	\N	RP	2014-09-28 18:00:57	2014-09-28 20:36:12
14233	760	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14053L	\N	RP	2014-09-28 18:00:57	\N
14234	760	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14001X	\N	RP	2014-09-28 18:00:57	2014-09-28 20:35:33
14269	1054	2014-10-01 00:00:00	2014-09-28 00:00:00	2021-09-30 00:00:00	REN	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	08018U	\N	RP	2014-09-28 18:46:12	2014-09-28 20:25:23
14237	830	2014-10-01 00:00:00	2014-09-28 00:00:00	2017-09-22 00:00:00	REN	DEM	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	04041B	\N	RP	2014-09-28 18:03:38	2017-09-24 11:09:53
14238	830	2014-10-01 00:00:00	2014-09-28 00:00:00	2017-09-30 00:00:00	ELECTION	DEM	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14247U	\N	RP	2014-09-28 18:03:38	2017-10-01 10:25:16
14239	830	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN1	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	04038G	\N	RP	2014-09-28 18:03:38	2014-09-28 20:36:44
14240	830	2014-10-01 00:00:00	2014-09-28 00:00:00	2017-09-21 00:00:00	REN	DEM	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	95031C	\N	RP	2014-09-28 18:03:38	2017-09-22 10:42:23
14256	30	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	98024R	\N	SM2	2014-09-28 18:32:19	\N
14257	30	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14251Q	\N	SM2	2014-09-28 18:32:19	\N
14258	190	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14253S	\N	SM2	2014-09-28 18:32:41	\N
14270	1054	2014-10-01 00:00:00	2014-09-28 00:00:00	2021-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	98018T	\N	RP	2014-09-28 18:46:12	2014-09-28 20:26:32
14271	1054	2014-10-01 00:00:00	2014-09-28 00:00:00	2021-09-30 00:00:00	REN	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	08017T	\N	RP	2014-09-28 18:46:12	2014-09-28 20:25:41
14272	1054	2014-10-01 00:00:00	2014-09-28 00:00:00	2021-09-30 00:00:00	REN	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	04034C	\N	RP	2014-09-28 18:46:12	2014-09-28 20:24:03
14273	1054	2014-10-01 00:00:00	2014-09-28 00:00:00	2021-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14041T	\N	RP	2014-09-28 18:46:12	\N
14274	880	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	04088S	\N	SM2	2014-09-28 18:47:00	2014-09-28 20:38:32
14278	160	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	08058D	\N	SM2	2014-09-28 18:57:56	\N
14279	710	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	95030B	\N	RP	2014-09-28 18:58:20	2014-09-28 20:33:18
14280	710	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14151M	\N	RP	2014-09-28 18:58:20	\N
14284	205	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14201E	\N	SM2	2014-09-28 18:59:41	\N
14288	120	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14111D	\N	SM2	2014-09-28 19:03:23	\N
12947	190	2014-02-14 00:00:00	\N	2014-09-30 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	Nouveau	remplace René Teulade, décédé	\N	\N	SENAT	14002L	\N	NR	2014-02-14 15:15:52	2014-09-28 18:32:43
14054	860	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	02002K	\N	SM1	2014-09-28 12:56:40	2014-09-28 14:13:33
14045	530	2014-09-29 00:00:00	2014-09-28 00:00:00	2017-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14042U	\N	SM1	2014-09-28 12:34:20	2017-09-24 13:29:42
14050	360	2014-10-01 00:00:00	2014-09-28 00:00:00	2016-11-17 00:00:00	REN	DECEDE	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	07032N	\N	SM1	2014-09-28 12:51:56	2016-11-18 12:37:49
14055	860	2014-10-01 00:00:00	2014-09-28 00:00:00	2017-10-04 00:00:00	REN	DEM	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	95059Q	\N	SM1	2014-09-28 12:56:40	2017-10-05 09:39:38
14058	150	2014-10-01 00:00:00	2014-09-28 00:00:00	2017-06-17 00:00:00	REN	CESMEMGVT	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	08051V	\N	SM1	2014-09-28 13:01:25	2017-06-19 12:20:59
14059	150	2014-10-01 00:00:00	2014-09-28 00:00:00	2015-06-11 00:00:00	REN	DEMCC	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	98027U	\N	SM1	2014-09-28 13:01:25	2015-06-15 12:03:05
14060	160	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	08060W	\N	SM1	2014-09-28 13:04:50	\N
14068	820	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	88008L	\N	SM1	2014-09-28 13:44:13	2014-09-28 16:08:04
15278	620	2016-01-12 00:00:00	\N	2017-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	Nouveau	en remplacement de Mme Natacha Bouchart, démissionnaire de son mandat de sénateur	\N	\N	SENAT	14331P	\N	NR	2016-01-12 09:45:37	2017-09-24 17:42:26
14410	430	2015-01-26 00:00:00	2015-01-25 00:00:00	2017-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14267Y	\N	NR	2015-01-26 16:17:48	2017-09-24 12:57:09
15134	840	2015-02-13 00:00:00	\N	2020-09-30 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	Nouveau	en remplacement de Mme Geneviève Jean, dont l'élection a été annulée par le Conseil constitutionnel	\N	\N	SENAT	87003B	\N	NR	2015-02-12 15:04:38	2015-02-13 10:25:19
22523	265	2017-06-18 00:00:00	\N	2017-10-01 00:00:00	REPRISE	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	11069T	\N	NR	2017-06-19 15:51:10	2017-09-24 18:05:41
22526	600	2017-06-18 00:00:00	\N	2017-10-01 00:00:00	REPRISE	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	11045K	\N	NR	2017-06-19 15:58:23	2017-09-24 17:29:37
43666	590	2017-07-04 00:00:00	\N	2017-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	Nouveau	remplace Mme Marie-Christine BLANDIN, démissionnaire de son mandat	\N	\N	SENAT	18127E	\N	NR	2017-07-04 15:35:17	2017-09-24 18:16:52
43669	890	2017-07-22 00:00:00	\N	2020-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	Nouveau	en remplacement de M. Jean-Baptiste Lemoyne, devenu membre du Gouvernement	\N	\N	SENAT	19269X	\N	NR	2017-07-24 10:01:14	2017-07-24 16:35:04
51119	770	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19675J	\N	RP	2017-09-24 00:00:00	\N
51120	770	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	14329V	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
51121	770	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19543W	\N	RP	2017-09-24 00:00:00	\N
51122	770	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	14357A	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
51123	770	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	11074Q	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
51124	770	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	04057K	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
51138	450	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	01028R	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
51139	450	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19421M	\N	RP	2017-09-24 00:00:00	\N
51140	450	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN1	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	11103C	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
51158	620	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	14331P	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
51159	620	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19527W	\N	RP	2017-09-24 00:00:00	\N
51160	620	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	01034P	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
51161	620	2017-10-02 00:00:00	2017-09-24 00:00:00	2021-12-07 00:00:00	ELECTION	DECEDE	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	19521Q	\N	RP	2017-09-24 17:42:25	\N
51162	620	2017-10-02 00:00:00	2017-09-24 00:00:00	2018-06-30 00:00:00	REN	DEM	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	11063M	\N	RP	2017-09-24 17:42:25	2017-09-24 17:44:24
51163	620	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19525U	\N	RP	2017-09-24 00:00:00	\N
51164	620	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19681G	\N	RP	2017-09-24 00:00:00	\N
51169	615	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	04059M	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
51170	615	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19649G	\N	RP	2017-09-24 00:00:00	\N
51171	615	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	07033P	\N	RP	2017-09-24 00:00:00	\N
51172	615	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REELECTION	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	11033F	\N	RP	2017-09-24 00:00:00	2017-09-26 00:00:00
51173	615	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	12041X	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
51174	615	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19651A	\N	RP	2017-09-24 00:00:00	\N
51175	615	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	04071H	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
51176	615	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19643A	\N	RP	2017-09-24 00:00:00	\N
51177	615	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19683J	\N	RP	2017-09-24 00:00:00	\N
51178	615	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN1	NONREELU	ANCIEN	\N	Nouveau	\N	\N	2023	\N	11080N	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
51179	615	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19647E	\N	RP	2017-09-24 00:00:00	\N
51180	615	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	11077T	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
51191	824	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	04042C	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
51192	824	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19687N	\N	RP	2017-09-24 00:00:00	\N
51193	824	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	11031D	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
51194	824	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19611R	\N	RP	2017-09-24 00:00:00	\N
51195	824	2017-10-02 00:00:00	2017-09-24 00:00:00	2022-07-03 00:00:00	ELECTION	DEM	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	19689Q	\N	RP	2017-09-24 17:55:12	\N
51196	824	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	04043D	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
51200	265	2017-10-02 00:00:00	2017-09-24 00:00:00	2022-02-02 00:00:00	ELECTION	DECEDE	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	19289C	\N	RP	2017-09-24 18:05:40	\N
51201	265	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	11070L	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
51202	265	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19691J	\N	RP	2017-09-24 00:00:00	\N
51203	265	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19399H	\N	RP	2017-09-24 00:00:00	\N
51204	265	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19693L	\N	RP	2017-09-24 00:00:00	\N
51216	990	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	11072N	\N	SM2	2017-09-24 00:00:00	2017-09-24 00:00:00
51217	990	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19329S	\N	SM2	2017-09-24 00:00:00	\N
51287	550	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	01048V	\N	SM2	2017-09-24 00:00:00	2017-09-24 00:00:00
51288	550	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19563B	\N	SM2	2017-09-24 00:00:00	\N
51293	470	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19369B	\N	SM2	2017-09-24 00:00:00	\N
51294	470	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19367Y	\N	SM2	2017-09-24 00:00:00	\N
51298	335	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN1	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	11083R	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
14087	140	2014-10-01 00:00:00	2014-09-28 00:00:00	2015-06-11 00:00:00	ELECTION	DEMCC	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14137P	\N	RP	2014-09-28 16:42:03	2015-06-15 12:02:02
14042	180	2014-10-01 00:00:00	2014-09-28 00:00:00	2019-03-03 00:00:00	REN	CESMEMCC	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	07034Q	\N	SM1	2014-09-28 12:31:21	\N
14043	180	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	05012A	\N	SM1	2014-09-28 12:31:21	\N
14086	140	2014-10-01 00:00:00	2014-09-28 00:00:00	2017-09-30 00:00:00	REN	DEM	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	98042T	\N	RP	2014-09-28 16:42:03	2017-10-01 10:39:22
14088	140	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14133K	\N	RP	2014-09-28 16:42:03	\N
14089	260	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14105F	\N	RP	2014-09-28 16:49:55	\N
14090	260	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14109K	\N	RP	2014-09-28 16:49:55	\N
14091	260	2014-10-01 00:00:00	2014-09-28 00:00:00	2018-11-16 00:00:00	REN	CESMEMGVT	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	08016S	\N	RP	2014-09-28 16:49:55	\N
14390	570	2014-12-22 00:00:00	\N	2017-06-17 00:00:00	REMPLACE	REPEXE	ANCIEN	\N	Nouveau	en remplacement de M. Jean-Marc Todeschini, devenu membre du Gouvernement	\N	\N	SENAT	14263U	\N	NR	2014-12-18 16:18:16	2017-06-19 16:04:13
15135	775	2015-03-04 00:00:00	\N	2017-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	Nouveau	en remplacement de Claude Dilain, décédé	\N	\N	SENAT	14269B	\N	NR	2015-03-04 14:32:20	2017-09-24 18:07:57
15194	983	2015-05-04 00:00:00	2015-05-03 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14275Y	\N	NR	2015-05-04 10:27:12	\N
15195	983	2015-05-04 00:00:00	2015-05-03 00:00:00	2020-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14277B	\N	NR	2015-05-04 10:29:04	\N
15232	320	2015-09-07 00:00:00	2015-09-06 00:00:00	2020-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	08049C	\N	NR	2015-09-07 16:07:43	\N
15233	150	2015-09-07 00:00:00	2015-09-06 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14327T	\N	NR	2015-09-07 16:16:32	2015-09-07 16:24:18
15284	265	2016-03-12 00:00:00	\N	2017-06-17 00:00:00	REMPLACE	REPEXE	ANCIEN	\N	Nouveau	en remplacement de M. Jean-Vincent Placé, nommé membre du gouvernement	\N	\N	SENAT	04050C	\N	NR	2016-03-11 18:10:19	2017-06-19 16:03:48
15333	974	2016-11-13 00:00:00	\N	2017-10-01 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	Nouveau	En remplacement de M. Paul Vergès, décédé	\N	\N	SENAT	05001W	\N	NR	2016-11-14 18:40:41	2017-09-24 16:24:51
15337	770	2016-12-01 00:00:00	\N	2017-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	Nouveau	en remplacement de Michel Houel, décédé	\N	\N	SENAT	14357A	\N	NR	2016-12-01 10:39:20	2017-09-24 17:18:03
15528	650	2017-05-16 00:00:00	\N	2017-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	Nouveau	en remplacement de François Fortassin, décédé	\N	\N	SENAT	14365A	\N	NR	2017-05-16 16:19:32	2017-09-24 12:39:59
51114	828	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19667J	\N	RP	2017-09-24 00:00:00	\N
51115	828	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19669L	\N	RP	2017-09-24 00:00:00	\N
51116	828	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19671E	\N	RP	2017-09-24 00:00:00	\N
51117	828	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN1	NONREELU	ANCIEN	\N	Nouveau	\N	\N	2023	\N	95063L	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
51118	828	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19673G	\N	RP	2017-09-24 00:00:00	\N
51126	540	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19551W	\N	RP	2017-09-24 00:00:00	\N
51127	540	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19553Y	\N	RP	2017-09-24 00:00:00	\N
51128	540	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	11048N	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
51129	540	2017-10-02 00:00:00	2017-09-24 00:00:00	2022-12-31 00:00:00	REN3	DEM	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	92040Q	\N	RP	2017-09-24 17:19:41	2017-09-24 20:08:22
51133	510	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	01024M	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
51134	510	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN1	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	11097X	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
51135	510	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	01025N	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
51142	600	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19573D	\N	RP	2017-09-24 00:00:00	\N
51143	600	2017-10-02 00:00:00	2017-09-24 00:00:00	2017-11-24 00:00:00	ELECTION	DEM	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	19677L	\N	RP	2017-09-24 17:29:36	2017-11-24 23:59:34
51144	600	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	11115U	\N	RP	2017-09-24 00:00:00	\N
51145	600	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	11045K	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
51150	380	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	11043H	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
51151	380	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19349W	\N	RP	2017-09-24 00:00:00	\N
51152	380	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN1	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	11041F	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
51153	380	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19679N	\N	RP	2017-09-24 00:00:00	\N
51154	380	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19347U	\N	RP	2017-09-24 00:00:00	\N
51183	570	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19335Q	\N	RP	2017-09-24 00:00:00	\N
51184	570	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	01060R	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
51185	570	2017-10-02 00:00:00	2017-09-24 00:00:00	2020-07-13 00:00:00	REN	DEM	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	11049P	\N	RP	2017-09-24 17:48:20	2017-09-24 17:53:22
51186	570	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19685L	\N	RP	2017-09-24 00:00:00	\N
51187	570	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	01062T	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
51205	775	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	04085P	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
51206	775	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	11054L	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
51207	775	2017-10-02 00:00:00	2017-09-24 00:00:00	2021-07-27 00:00:00	REN2	DEM	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	04086Q	\N	RP	2017-09-24 18:07:56	2017-09-24 18:10:07
51208	775	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19695N	\N	RP	2017-09-24 00:00:00	\N
51209	775	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	11053K	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
51210	775	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19663E	\N	RP	2017-09-24 00:00:00	\N
51218	590	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	14021P	\N	RP	2017-09-24 00:00:00	\N
51219	590	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19637C	\N	RP	2017-09-24 00:00:00	\N
51220	590	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	11040E	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
51221	590	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19599P	\N	RP	2017-09-24 00:00:00	\N
51222	590	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	Nouveau	\N	\N	2023	\N	17589D	\N	RP	2017-09-24 00:00:00	\N
51223	590	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19581D	\N	RP	2017-09-24 00:00:00	\N
51224	590	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19569H	\N	RP	2017-09-24 00:00:00	\N
51225	590	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19565D	\N	RP	2017-09-24 00:00:00	\N
51226	590	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19585H	\N	RP	2017-09-24 00:00:00	\N
51227	590	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	04008A	\N	RP	2017-09-24 00:00:00	\N
51228	590	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	01043Q	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
51274	1053	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	04035D	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
12678	1053	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	01041N	\N	RP	\N	2017-09-24 18:59:59
13762	730	2014-05-03 00:00:00	\N	2014-09-30 00:00:00	REPRISE	NONREELU	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	04090L	\N	NR	2014-05-05 10:31:01	2014-09-28 19:29:39
13764	120	2014-05-03 00:00:00	\N	2014-09-30 00:00:00	REPRISE	NONREELU	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	08064B	\N	NR	2014-05-05 10:32:08	2014-09-28 19:03:23
13785	660	2014-08-27 00:00:00	\N	2017-10-01 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	Nouveau	remplace M. Christian Bourquin, décédé	\N	\N	SENAT	14018U	\N	NR	2014-08-27 16:32:46	2017-09-24 18:49:56
14399	600	2015-01-08 00:00:00	\N	2017-10-01 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	92045V	\N	NR	2015-01-09 15:16:59	2017-09-24 17:29:37
15517	335	2017-01-01 00:00:00	\N	2017-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	Nouveau	en remplacement de M. Jacques Gautier, démissionnaire de son mandat	\N	\N	SENAT	14363X	\N	NR	2017-01-03 11:10:58	2017-09-24 19:25:10
12606	590	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-07-03 00:00:00	REN1	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	01044R	\N	RP	\N	2017-07-04 15:08:09
50743	770	2017-08-07 00:00:00	\N	2017-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	Nouveau	en remplacement de Nicole Bricq, décédée le 6 août 2017	\N	\N	SENAT	12035A	\N	NR	2017-08-07 17:15:07	2017-09-24 17:18:03
12680	1053	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN4	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	77002U	\N	RP	\N	2017-09-24 18:59:59
51278	460	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19503N	\N	SM2	2017-09-24 00:00:00	\N
51284	410	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19511N	\N	SM2	2017-09-24 00:00:00	\N
12640	410	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	11106F	\N	SM2	\N	2017-09-24 19:14:37
51291	610	2017-10-02 00:00:00	2017-09-24 00:00:00	2018-04-13 00:00:00	ELECTION	ANNCC	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	19483C	\N	SM2	2017-09-24 19:17:41	2018-04-13 17:54:29
51299	335	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	11085T	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
51306	390	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19479G	\N	SM2	2017-09-24 00:00:00	\N
51307	390	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19467C	\N	SM2	2017-09-24 00:00:00	\N
12664	972	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	11109J	\N	SM1	\N	2017-09-25 11:00:40
51358	300	2017-09-25 00:00:00	\N	2017-09-30 00:00:00	REMPLACE	DEM	ANCIEN	\N	Nouveau	en remplacement de M. Jean-Paul Fournier, démissionnaire de son mandat 	\N	\N	SENAT	16431B	\N	NR	2017-09-25 10:03:31	2017-10-01 10:37:45
51651	690	2018-12-06 00:00:00	\N	2020-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	Nouveau	en remplacement de M. Gérard Collomb, en application de l'article LO 151 du code électoral	\N	\N	SENAT	19251M	\N	NR	\N	\N
51685	340	2019-07-01 00:00:00	\N	2020-09-30 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	19812Y	\N	NR	\N	\N
51697	760	2019-10-01 00:00:00	\N	2020-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	Nouveau	en remplacement de M. Charles Revet, démissionnaire	\N	\N	SENAT	19826F	\N	NR	\N	\N
51709	480	2020-03-04 00:00:00	\N	2023-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	Nouveau	en remplacement de M. Alain Bertrand décédé le 3 mars 2020	\N	2023	\N	19866P	\N	NR	\N	\N
51730	300	2020-06-18 00:00:00	\N	2020-09-30 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	Nouveau	en remplacement de Mme Pascale Bories, démissionnaire de son mandat	\N	\N	SENAT	19914E	\N	NR	\N	\N
51737	720	2020-06-26 00:00:00	\N	2020-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	Nouveau	en remplacement de M. Christophe Chaudun, démissionnaire	\N	\N	SENAT	19926J	\N	NR	\N	\N
51739	70	2020-06-28 00:00:00	\N	2020-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	Nouveau	en remplacement de M. Jacques Genest, dont le mandat a pris fin de plein droit	\N	\N	SENAT	19930E	\N	NR	\N	\N
51772	130	2020-08-03 00:00:00	\N	2020-09-30 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	Nouveau	en remplacement de M. Michel Amiel, démissionnaire de son mandat 	\N	\N	SENAT	19958S	\N	NR	\N	\N
51819	60	2020-09-25 00:00:00	\N	2020-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	Nouveau	en remplacement de Mme Colette Giudicelli, décédée le 24 septembre 2020	\N	\N	SENAT	20014R	\N	NR	\N	\N
51794	260	2020-08-08 00:00:00	\N	2020-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	Nouveau	en remplacement de M. Didier Guillaume, démissionnaire de son mandat	\N	\N	SENAT	19782L	\N	NR	\N	\N
51820	200	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14191V	\N	SM1	\N	\N
51823	984	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20016T	\N	SM2	\N	\N
51825	30	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14251Q	\N	SM1	\N	\N
51826	30	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20020P	\N	SM1	\N	\N
51827	40	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14107H	\N	SM1	\N	\N
51829	890	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	19749K	\N	SM1	\N	\N
51831	190	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14195A	\N	SM1	\N	\N
51832	190	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14253S	\N	SM1	\N	\N
51837	700	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	95041E	\N	SM1	\N	\N
51839	160	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN2	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	08060W	\N	SM1	\N	\N
51840	240	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20028X	\N	SM1	\N	\N
51843	810	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14089Y	\N	SM1	\N	\N
51844	880	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14033T	\N	SM1	\N	\N
51845	230	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN2	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	08012N	\N	SM1	\N	\N
51846	100	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	19745F	\N	SM1	\N	\N
51847	110	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14097Y	\N	SM1	\N	\N
51848	110	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20030R	\N	SM1	\N	\N
51849	120	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14111D	\N	SM1	\N	\N
51850	120	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20032T	\N	SM1	\N	\N
51852	205	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20036X	\N	SM2	\N	\N
51854	50	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14189C	\N	SM2	\N	\N
51855	790	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20038A	\N	SM2	\N	\N
51857	160	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20042V	\N	SM2	\N	\N
51858	360	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14355X	\N	SM2	\N	\N
51859	890	2020-10-01 00:00:00	2020-09-27 00:00:00	2020-11-01 00:00:00	REELECTION	FINMEMGVT	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14037X	\N	SM2	\N	\N
51861	240	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20046A	\N	SM2	\N	\N
51862	880	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20048C	\N	SM2	\N	\N
51866	100	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20050V	\N	SM2	\N	\N
51867	820	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14069U	\N	SM2	\N	\N
51868	820	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20052X	\N	SM2	\N	\N
51869	700	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20054A	\N	SM2	\N	\N
51870	80	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20056C	\N	SM2	\N	\N
51871	80	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN2	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	07029T	\N	SM2	\N	\N
51872	730	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	19575F	\N	SM2	\N	\N
51873	730	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20058E	\N	SM2	\N	\N
51874	260	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14105F	\N	RP	\N	\N
51875	260	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14109K	\N	RP	\N	\N
51876	260	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	19782L	\N	RP	\N	\N
51877	800	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20060X	\N	RP	\N	\N
51878	800	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20062A	\N	RP	\N	\N
51879	800	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	17229F	\N	RP	\N	\N
14037	984	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	NONREELU	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	98005N	\N	SM1	2014-09-28 09:33:54	\N
14083	850	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14030Q	\N	RP	2014-09-28 16:40:49	\N
14084	850	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14031R	\N	RP	2014-09-28 16:40:49	\N
14085	850	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	04033B	\N	RP	2014-09-28 16:40:49	\N
14094	210	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	08061X	\N	RP	2014-09-28 16:54:08	\N
14095	210	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14205J	\N	RP	2014-09-28 16:54:08	\N
14096	210	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	08069G	\N	RP	2014-09-28 16:54:08	\N
14100	290	2014-10-01 00:00:00	2014-09-28 00:00:00	2017-09-24 00:00:00	REN	DEM	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	98046X	\N	RP	2014-09-28 17:00:59	2017-09-25 09:56:00
14101	290	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	08043V	\N	RP	2014-09-28 17:00:59	\N
14102	290	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14083S	\N	RP	2014-09-28 17:00:59	\N
14103	290	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	08047A	\N	RP	2014-09-28 17:00:59	\N
14105	340	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14207L	\N	RP	2014-09-28 17:03:41	\N
14106	340	2014-10-01 00:00:00	2014-09-28 00:00:00	2019-06-30 00:00:00	REN	DEM	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	08021P	\N	RP	2014-09-28 17:03:41	\N
14107	340	2014-10-01 00:00:00	2014-09-28 00:00:00	2017-09-30 00:00:00	ELECTION	DEM	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14209N	\N	RP	2014-09-28 17:03:41	2017-10-01 10:34:22
14108	340	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14211G	\N	RP	2014-09-28 17:03:41	\N
14114	300	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14059S	\N	RP	2014-09-28 17:07:07	\N
14115	300	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	98035U	\N	RP	2014-09-28 17:07:07	\N
14116	300	2014-10-01 00:00:00	2014-09-28 00:00:00	2017-09-24 00:00:00	REN	DEM	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	08065C	\N	RP	2014-09-28 17:07:07	2017-09-25 09:57:52
14125	800	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14093U	\N	RP	2014-09-28 17:09:16	\N
14126	800	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14063N	\N	RP	2014-09-28 17:09:16	\N
14127	800	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	04089T	\N	RP	2014-09-28 17:09:16	\N
14290	790	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14071N	\N	SM2	2014-09-28 19:05:58	\N
14291	790	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14119M	\N	SM2	2014-09-28 19:05:58	\N
14292	320	2014-10-01 00:00:00	2014-09-28 00:00:00	2015-06-11 00:00:00	REN2	DEMCC	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	98032R	\N	SM2	2014-09-28 19:07:43	2015-06-15 12:02:31
14293	320	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14257W	\N	SM2	2014-09-28 19:07:43	\N
14298	870	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14034U	\N	SM2	2014-09-28 19:19:39	\N
14299	870	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14028W	\N	SM2	2014-09-28 19:19:39	\N
14304	730	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN2	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	95067Q	\N	SM2	2014-09-28 19:29:38	2014-09-28 20:34:18
14305	730	2014-10-01 00:00:00	2014-09-28 00:00:00	2017-06-01 00:00:00	ELECTION	DEM	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14175V	\N	SM2	2014-09-28 19:29:38	2017-06-02 10:02:56
15202	140	2015-06-12 00:00:00	\N	2020-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	Nouveau	en remplacement de M. François Aubey, déclaré démissionnaire d'office de son mandat par le Conseil constitutionnel	\N	\N	SENAT	14281W	\N	NR	2015-06-12 15:35:57	2015-06-15 10:36:46
51072	410	2017-10-02 00:00:00	2017-09-24 00:00:00	2017-11-02 00:00:00	REELECTION	FINMEMGVT	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	01007L	\N	SM1	2017-09-24 13:20:36	2017-11-03 10:47:39
51069	430	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	14267Y	\N	SM1	2017-09-24 00:00:00	2017-09-24 00:00:00
51070	430	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19507S	\N	SM1	2017-09-24 00:00:00	\N
51071	520	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN2	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	01057W	\N	SM1	2017-09-24 00:00:00	2017-09-24 00:00:00
51073	530	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	14042U	\N	SM1	2017-09-24 00:00:00	2017-09-24 00:00:00
51075	460	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	11012A	\N	SM1	2017-09-24 00:00:00	2017-09-24 00:00:00
51300	335	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	Nouveau	\N	\N	2023	\N	17637T	\N	RP	2017-09-24 00:00:00	\N
51301	335	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19711U	\N	RP	2017-09-24 00:00:00	\N
51302	335	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19591F	\N	RP	2017-09-24 00:00:00	\N
51303	335	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN2	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	99004R	\N	RP	2017-09-24 00:00:00	2017-09-24 00:00:00
51304	335	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19593H	\N	RP	2017-09-24 00:00:00	\N
51309	580	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19531S	\N	SM2	2017-09-24 00:00:00	\N
51310	580	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19713W	\N	SM2	2017-09-24 00:00:00	\N
51357	290	2017-09-25 00:00:00	\N	2020-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	Nouveau	en remplacement de M. François Marc, démissionnaire de son mandat	\N	\N	SENAT	08045X	\N	NR	2017-09-25 09:57:06	2017-09-25 09:58:17
51453	330	2017-10-01 00:00:00	\N	2020-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	Nouveau	en remplacement de M. Xavier Pintat, démissionnaire de son mandat	\N	\N	SENAT	19719D	\N	NR	2017-10-01 09:26:48	2017-10-01 09:27:42
51545	100	2017-12-18 00:00:00	2017-12-17 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	19745F	\N	NR	2017-12-18 14:31:40	\N
51548	860	2017-12-18 00:00:00	2017-12-17 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	19747H	\N	NR	2017-12-18 14:43:34	\N
51549	890	2017-12-18 00:00:00	2017-12-17 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	19749K	\N	NR	2017-12-18 14:52:08	\N
51734	720	2020-06-25 00:00:00	\N	2020-06-25 00:00:00	REMPLACE	DEM	ANCIEN	\N	Nouveau	en remplacement de Mme Nadine Grelet-Certenais, dont le mandat a pris fin de plein droit	\N	\N	SENAT	19920C	\N	NR	\N	\N
51750	570	2020-07-14 00:00:00	\N	2023-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	Nouveau	en remplacement de M. François Grosdidier, démissionnaire de son mandat	\N	2023	\N	19954N	\N	NR	\N	\N
51783	130	2020-08-04 00:00:00	\N	2020-09-30 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	Nouveau	en remplacement de Mme Samia Ghali, dont le mandat a pris fin de plein droit	\N	\N	SENAT	19968U	\N	NR	\N	\N
51791	260	2020-08-07 00:00:00	\N	2020-08-07 00:00:00	REPRISE	DEM	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	08016S	\N	NR	\N	\N
51821	125	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14193X	\N	SM1	\N	\N
51822	790	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14071N	\N	SM1	\N	\N
51824	90	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20018V	\N	SM1	\N	\N
51828	360	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20022R	\N	SM1	\N	\N
51830	150	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14327T	\N	SM1	\N	\N
51833	860	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20024T	\N	SM1	\N	\N
51834	860	2020-10-01 00:00:00	2020-09-27 00:00:00	2023-12-31 00:00:00	REN	DEM	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19747H	\N	SM1	\N	\N
51835	70	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14259Y	\N	SM1	\N	\N
51836	70	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20026V	\N	SM1	\N	\N
51838	320	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14257W	\N	SM1	\N	\N
51841	180	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN2	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	05012A	\N	SM1	\N	\N
51842	180	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	19798U	\N	SM1	\N	\N
51853	973	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN2	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	08073C	\N	SM1	\N	\N
51856	320	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20040T	\N	SM2	\N	\N
12933	760	2014-01-01 00:00:00	\N	2014-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	Nouveau	en remplacement de M. Marc Massion	\N	\N	SENAT	14001X	\N	NR	2014-01-02 11:03:59	2014-09-28 21:53:58
13755	690	2014-04-22 00:00:00	\N	2014-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	Nouveau	en remplacement de M. Michel Mercier, démissionnaire	\N	\N	SENAT	09010Q	\N	NR	2014-04-23 09:57:24	2014-09-28 17:07:41
13760	210	2014-05-03 00:00:00	\N	2014-09-30 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	Nouveau	en remplacement de M. François Rebsamen, nommé membre du Gouvernement	\N	\N	SENAT	14012N	\N	NR	2014-05-05 10:30:19	2014-09-28 16:54:10
14098	720	2014-10-01 00:00:00	2014-09-28 00:00:00	2017-09-30 00:00:00	ELECTION	DEM	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14167V	\N	RP	2014-09-28 16:59:40	2017-10-01 10:18:28
13780	974	2014-07-01 00:00:00	\N	2017-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	Nouveau	en remplacement de Mme Jacqueline Farreyrol, démissionnaire	\N	\N	SENAT	14017T	\N	NR	2014-06-25 15:52:44	2017-09-24 16:24:51
14097	720	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14173T	\N	RP	2014-09-28 16:59:40	\N
14099	720	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14169X	\N	RP	2014-09-28 16:59:40	\N
14104	9713	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	08019V	\N	SM1	2014-09-28 17:03:07	\N
14110	170	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14213J	\N	RP	2014-09-28 17:05:42	\N
14111	170	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14159V	\N	RP	2014-09-28 17:05:42	\N
14112	170	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	08015R	\N	RP	2014-09-28 17:05:42	\N
14117	690	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14087W	\N	RP	2014-09-28 17:07:40	\N
14118	690	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	04049K	\N	RP	2014-09-28 17:07:40	\N
14119	690	2014-10-01 00:00:00	2014-09-28 00:00:00	2017-09-30 00:00:00	REELECTION	DEM	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	95049N	\N	RP	2014-09-28 17:07:40	2017-10-01 10:42:05
14120	690	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14081Q	\N	RP	2014-09-28 17:07:40	\N
14121	690	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14215L	\N	RP	2014-09-28 17:07:40	\N
14122	690	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	04047H	\N	RP	2014-09-28 17:07:40	\N
14123	690	2014-10-01 00:00:00	2014-09-28 00:00:00	2017-06-17 00:00:00	REN	CESMEMGVT	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	99002P	\N	RP	2014-09-28 17:07:40	2017-06-19 12:20:21
14129	280	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14217N	\N	RP	2014-09-28 17:12:40	\N
14130	280	2014-10-01 00:00:00	2014-09-28 00:00:00	2018-12-30 00:00:00	REN	DEM	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	98023Q	\N	RP	2014-09-28 17:12:40	\N
53318	775	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	20252E	\N	NR	\N	\N
14131	280	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	08011M	\N	RP	2014-09-28 17:12:40	\N
14139	20	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	08052W	\N	RP	2014-09-28 17:15:41	\N
14140	20	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	08010L	\N	RP	2014-09-28 17:15:41	\N
14141	20	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14026U	\N	RP	2014-09-28 17:15:41	\N
14152	10	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14038Y	\N	RP	2014-09-28 17:27:28	\N
14153	10	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	08053X	\N	RP	2014-09-28 17:27:28	\N
14154	10	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	08056B	\N	RP	2014-09-28 17:27:28	\N
14282	890	2014-10-01 00:00:00	2014-09-28 00:00:00	2017-07-22 00:00:00	ELECTION	CESMEMGVT	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14037X	\N	SM2	2014-09-28 18:58:25	2017-07-24 09:58:00
14281	890	2014-10-01 00:00:00	2014-09-28 00:00:00	2017-09-30 00:00:00	REN	DEM	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	86044G	\N	SM2	2014-09-28 18:58:25	2017-10-01 10:32:58
14287	820	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14069U	\N	SM2	2014-09-28 19:03:03	\N
14294	40	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14107H	\N	SM2	2014-09-28 19:09:43	\N
14296	810	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14085U	\N	SM2	2014-09-28 19:13:08	\N
14297	810	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14089Y	\N	SM2	2014-09-28 19:13:08	\N
14300	70	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14259Y	\N	SM2	2014-09-28 19:20:16	\N
14302	360	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	08062Y	\N	SM2	2014-09-28 19:26:58	2014-09-28 20:40:31
14312	50	2014-10-01 00:00:00	2014-09-28 00:00:00	2014-12-27 00:00:00	ELECTION	DECEDE	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14129P	\N	SM2	2014-09-28 19:45:29	2014-12-29 15:40:09
15334	360	2016-11-18 00:00:00	\N	2020-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	Nouveau	en remplacement de M. Louis Pinton, décédé	\N	\N	SENAT	14355X	\N	NR	2016-11-18 12:45:10	2016-11-18 14:27:33
15457	420	2016-12-11 00:00:00	\N	2017-10-01 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	Nouveau	en remplacement de Jean-Claude Frécon, décédé	\N	\N	SENAT	14361V	\N	NR	2016-12-12 15:59:30	2017-09-24 18:23:22
15541	590	2017-06-05 00:00:00	\N	2017-06-14 00:00:00	REMPLACE	DEM	ANCIEN	\N	Nouveau	en remplacement de M. Patrick Masclet, décédé	\N	\N	SENAT	07028S	\N	NR	2017-06-07 15:17:54	2017-06-19 16:13:09
22527	690	2017-06-18 00:00:00	\N	2018-11-03 00:00:00	REMPLACE	REPEXE	ANCIEN	\N	Nouveau	en remplacement de M. Gérard Collomb, nommé membre du gouvernement	\N	\N	SENAT	19251M	\N	NR	2017-06-19 16:45:46	2017-06-19 16:47:28
50741	824	2017-07-29 00:00:00	\N	2017-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	Nouveau	remplace M. Luc Carvounas, élu député	\N	\N	SENAT	19285X	\N	NR	2017-07-31 12:02:13	2017-09-24 17:55:12
51063	130	2017-09-23 00:00:00	\N	2020-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	Nouveau	en remplacement de M. Jean-Claude Gaudin, démissionnaire de son mandat	\N	\N	SENAT	14115H	\N	NR	2017-09-24 11:11:57	2017-09-24 11:37:09
51361	971	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19301E	\N	RP	2017-09-25 00:00:00	\N
51362	971	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19715Y	\N	RP	2017-09-25 00:00:00	\N
51363	971	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	12016W	\N	RP	2017-09-25 00:00:00	\N
51364	995	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19717B	\N	SM2	2017-09-25 00:00:00	\N
51365	972	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19295A	\N	SM2	2017-09-25 00:00:00	\N
51366	972	2017-10-02 00:00:00	2017-09-24 00:00:00	2023-10-01 00:00:00	REN	NONREP	ANCIEN	\N	Nouveau	\N	\N	2023	\N	11109J	\N	SM2	2017-09-25 00:00:00	\N
51526	600	2017-11-25 00:00:00	\N	2023-10-01 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	Nouveau	en remplacement de Mme Nadège Lefebvre, démissionnaire de son mandat	\N	2023	\N	19741B	\N	NR	2017-11-24 00:00:00	2017-11-24 00:00:00
51591	760	2018-06-01 00:00:00	\N	2020-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	Nouveau	en remplacement de M. Thierry Foucaud, démissionnaire	\N	\N	SENAT	19758L	\N	NR	2018-05-31 11:00:21	2018-05-31 11:05:28
51596	620	2018-07-01 00:00:00	\N	2023-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	Nouveau	en remplacement de M. Dominique Watrin, démissionnaire	\N	2023	\N	19760E	\N	NR	\N	\N
51599	610	2018-07-02 00:00:00	2018-07-01 00:00:00	2023-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	Nouveau	\N	\N	2023	\N	19762G	\N	NR	\N	\N
51658	150	2019-03-04 00:00:00	\N	2020-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	Nouveau	en remplacement de M. Jacques Mézard, nommé membre du Conseil Constitutionnel	\N	\N	SENAT	19253P	\N	NR	\N	\N
51659	180	2019-03-04 00:00:00	\N	2020-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	Nouveau	en remplacement de M. François Pillet, nommé membre du Conseil Constitutionnel	\N	\N	SENAT	19798U	\N	NR	\N	\N
51851	9713	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20034V	\N	SM1	\N	\N
51860	150	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20044X	\N	SM2	\N	\N
51863	140	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14281W	\N	RP	\N	\N
51864	140	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	19735D	\N	RP	\N	\N
51865	140	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14133K	\N	RP	\N	\N
51880	170	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20064C	\N	RP	\N	\N
13763	1053	2014-05-03 00:00:00	\N	2017-10-01 00:00:00	REPRISE	FINMAN	ANCIEN	\N	Retour de Gouvernement	\N	\N	\N	SENAT	11027H	\N	NR	2014-05-05 10:32:04	2017-09-24 18:59:59
13761	770	2014-05-03 00:00:00	\N	2017-08-06 00:00:00	REPRISE	DECEDE	ANCIEN	\N	Retour de Gouvernement	\N	\N	\N	SENAT	04053F	\N	NR	2014-05-05 10:30:45	2017-08-07 16:31:39
13769	600	2014-05-10 00:00:00	\N	2017-06-17 00:00:00	REMPLACE	REPEXE	ANCIEN	\N	Nouveau	en remplacement de Mme Laurence Rossignol, nommée membre du gouvernement	\N	\N	SENAT	14013P	\N	NR	2014-05-09 11:29:04	2017-06-19 16:06:01
13790	570	2014-09-01 00:00:00	\N	2017-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	Nouveau	en remplacement de Mme Gisèle Printz, démissionnaire	\N	\N	SENAT	83042R	\N	NR	2014-09-01 10:22:08	2017-09-24 17:48:21
13771	380	2014-05-10 00:00:00	\N	2017-06-17 00:00:00	REMPLACE	REPEXE	ANCIEN	\N	Nouveau	en remplacement de M. André Vallini, nommé membre du gouvernement	\N	\N	SENAT	14014Q	\N	NR	2014-05-09 11:37:36	2017-06-19 16:06:51
14066	700	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14135M	\N	SM1	2014-09-28 13:40:32	\N
14067	700	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	95041E	\N	SM1	2014-09-28 13:40:32	2014-09-28 15:29:45
14250	270	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	08009T	\N	RP	2014-09-28 18:19:47	2014-09-28 20:29:56
14251	270	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN2	NONREELU	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	98050T	\N	RP	2014-09-28 18:19:47	2014-09-28 20:30:31
14252	270	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14249W	\N	RP	2014-09-28 18:19:47	\N
15188	370	2015-04-08 00:00:00	\N	2017-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	Nouveau	en remplacement de Jean Germain, décédé	\N	\N	SENAT	14271U	\N	NR	2015-04-07 17:15:52	2017-09-24 17:13:19
51456	330	2017-10-01 00:00:00	\N	2020-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	Nouveau	en remplacement de Mme Marie-Hélène Des Esgaulx, démissionnaire de son mandat	\N	\N	SENAT	19721W	\N	NR	2017-10-01 09:45:12	2017-10-01 09:59:41
51462	330	2017-10-01 00:00:00	\N	2020-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	Nouveau	en remplacement de M. Gérard César, démissionnaire de son mandat	\N	\N	SENAT	19723Y	\N	NR	2017-10-01 10:06:58	2017-10-01 10:08:11
51464	330	2017-10-01 00:00:00	\N	2020-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	Nouveau	en remplacement de M. Alain Anziani, démissionnaire de son mandat	\N	\N	SENAT	19725B	\N	NR	2017-10-01 10:44:23	2017-10-01 10:45:11
51468	720	2017-10-01 00:00:00	\N	2020-06-24 00:00:00	REMPLACE	FININCOMPAT	ANCIEN	\N	Nouveau	en remplacement de M. Jean-Claude Boulard, démissionnaire de son mandat	\N	\N	SENAT	19727D	\N	NR	2017-10-01 10:54:01	2017-10-01 10:54:34
51472	60	2017-10-01 00:00:00	\N	2020-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	Nouveau	en remplacement de M. Louis Nègre, démissionnaire de son mandat	\N	\N	SENAT	19729F	\N	NR	2017-10-01 11:03:20	2017-10-01 11:05:09
51476	830	2017-10-01 00:00:00	\N	2020-09-30 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	Nouveau	en remplacement de M. David Rachline, démissionnaire de son mandat	\N	\N	SENAT	19731Y	\N	NR	2017-10-01 11:13:13	2017-10-01 11:13:46
51478	340	2017-10-01 00:00:00	\N	2020-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	Nouveau	en remplacement de M. François Commeinhes, démissionnaire de son mandat	\N	\N	SENAT	08020N	\N	NR	2017-10-01 11:33:45	2017-10-01 11:34:55
51480	300	2017-10-01 00:00:00	\N	2020-06-17 00:00:00	REMPLACE	DEM	ANCIEN	\N	Nouveau	en remplacement de M. Max Roustan, démissionnaire de son mandat	\N	\N	SENAT	19733B	\N	NR	2017-10-01 11:41:24	2017-10-01 11:41:58
51483	140	2017-10-01 00:00:00	\N	2020-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	Nouveau	en remplacement de M. Jean-Léonce Dupont, démissionnaire de son mandat	\N	\N	SENAT	19735D	\N	NR	2017-10-01 11:48:00	2017-10-01 11:49:00
51487	690	2017-10-01 00:00:00	\N	2020-09-30 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	Nouveau	en remplacement de M. Michel Mercier, démissionnaire de son mandat	\N	\N	SENAT	19737F	\N	NR	2017-10-01 11:57:14	2017-10-01 11:58:55
51500	410	2017-11-03 00:00:00	\N	2023-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	Nouveau	en remplacement de Mme Jacqueline Gourault, membre du Gouvernement	\N	2023	\N	19739H	\N	NR	2017-11-03 00:00:00	2017-11-03 00:00:00
12681	1053	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	FINMAN	ANCIEN	\N	\N	\N	\N	\N	SENAT	04035D	\N	RP	\N	2017-09-24 18:59:59
12617	540	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	REN1	NONREP	ANCIEN	\N	\N	\N	\N	\N	SENAT	01015L	\N	RP	\N	2017-09-24 17:19:42
12723	770	2011-10-01 00:00:00	2011-09-25 00:00:00	2015-10-11 00:00:00	REN2	CESMEMCC	ANCIEN	\N	\N	\N	\N	\N	SENAT	95039L	\N	RP	\N	2015-10-13 14:06:52
12595	265	2011-10-01 00:00:00	2011-09-25 00:00:00	2017-10-01 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	11068S	\N	RP	\N	2017-09-24 18:05:41
51642	690	2018-11-04 00:00:00	\N	2018-12-05 00:00:00	REPRISE	CESMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	99002P	\N	NR	\N	\N
51779	130	2020-08-03 00:00:00	\N	2020-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	Nouveau	en remplacement de Mme Sophie Joissains, démissionnaire de son mandat	\N	\N	SENAT	19966S	\N	NR	\N	\N
51691	330	2019-08-28 00:00:00	\N	2020-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	Nouveau	en remplacement de M. Philippe Madrelle décédé le 27 août 2019	\N	\N	SENAT	19820Y	\N	NR	\N	\N
51684	670	2019-06-24 00:00:00	2019-06-24 00:00:00	2020-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	04069P	\N	NR	\N	\N
51729	250	2020-06-16 00:00:00	\N	2020-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	Nouveau	En remplacement de M. Martial Bourquin, démissionnaire.	\N	\N	SENAT	19912C	\N	NR	\N	\N
51881	170	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN2	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	08015R	\N	RP	\N	\N
51882	170	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14213J	\N	RP	\N	\N
51883	230	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14121F	\N	SM2	\N	\N
51884	250	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14219Q	\N	RP	\N	\N
51885	250	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14123H	\N	RP	\N	\N
51886	250	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20066E	\N	RP	\N	\N
51887	280	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20068G	\N	RP	\N	\N
51888	280	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN2	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	08011M	\N	RP	\N	\N
51889	280	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14217N	\N	RP	\N	\N
51890	720	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14169X	\N	RP	\N	\N
51891	720	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14173T	\N	RP	\N	\N
51892	720	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20070A	\N	RP	\N	\N
51893	830	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20072C	\N	RP	\N	\N
51894	830	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20074E	\N	RP	\N	\N
51895	830	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20076G	\N	RP	\N	\N
51896	830	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20078J	\N	RP	\N	\N
51897	810	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	17023S	\N	SM2	\N	\N
51898	210	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN2	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	08061X	\N	RP	\N	\N
51899	210	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14205J	\N	RP	\N	\N
51900	210	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN2	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	08069G	\N	RP	\N	\N
51901	870	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20080C	\N	SM2	\N	\N
51902	870	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20082E	\N	SM2	\N	\N
51903	840	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20084G	\N	RP	\N	\N
51904	840	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN2	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	04092N	\N	RP	\N	\N
51905	840	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20086J	\N	RP	\N	\N
51906	850	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14031R	\N	RP	\N	\N
51907	850	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14030Q	\N	RP	\N	\N
51908	850	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN2	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	04033B	\N	RP	\N	\N
51909	300	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20088L	\N	RP	\N	\N
14038	200	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14191V	\N	SM1	2014-09-28 12:09:44	\N
14044	125	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14193X	\N	SM1	2014-09-28 12:32:22	\N
14046	190	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14195A	\N	SM1	2014-09-28 12:44:31	\N
14047	80	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	07029T	\N	SM1	2014-09-28 12:51:09	\N
14048	80	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	NONREELU	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	04097T	\N	SM1	2014-09-28 12:51:09	2014-09-28 13:35:53
14052	90	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14197C	\N	SM1	2014-09-28 12:54:15	\N
14061	120	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14103D	\N	SM1	2014-09-28 13:06:30	\N
14062	100	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	89017R	\N	SM1	2014-09-28 13:16:32	\N
14063	100	2014-10-01 00:00:00	2014-09-28 00:00:00	2017-09-30 00:00:00	ELECTION	DEM	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	05004A	\N	SM1	2014-09-28 13:16:32	2017-10-01 10:22:23
14064	110	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	80013X	\N	SM1	2014-09-28 13:32:34	\N
14065	110	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14097Y	\N	SM1	2014-09-28 13:32:34	\N
14069	70	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-06-27 00:00:00	ELECTION	FININCOMPAT	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14199E	\N	SM1	2014-09-28 14:31:41	\N
14135	680	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	04045F	\N	RP	2014-09-28 17:14:20	\N
14136	680	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	04040A	\N	RP	2014-09-28 17:14:20	2018-01-12 11:43:00
14137	680	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14079W	\N	RP	2014-09-28 17:14:20	\N
14138	680	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	04044E	\N	RP	2014-09-28 17:14:20	\N
14145	250	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14219Q	\N	RP	2014-09-28 17:22:10	\N
14146	250	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-06-15 00:00:00	REN	DEM	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	08068F	\N	RP	2014-09-28 17:22:10	\N
14147	250	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14123H	\N	RP	2014-09-28 17:22:10	\N
14155	310	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14221J	\N	RP	2014-09-28 17:27:34	\N
14156	310	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14223L	\N	RP	2014-09-28 17:27:34	\N
14157	310	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14225N	\N	RP	2014-09-28 17:27:34	\N
14158	310	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	NONREELU	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	08031R	\N	RP	2014-09-28 17:27:34	\N
14159	310	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	08028W	\N	RP	2014-09-28 17:27:34	\N
14163	670	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14073Q	\N	RP	2014-09-28 17:31:41	\N
14164	670	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	10015M	\N	RP	2014-09-28 17:31:41	2014-09-28 20:41:17
14165	670	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14065Q	\N	RP	2014-09-28 17:31:41	\N
14166	670	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14061L	\N	RP	2014-09-28 17:31:41	\N
14167	670	2014-10-01 00:00:00	2014-09-28 00:00:00	2019-06-23 00:00:00	REN	DEM	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	04061F	\N	RP	2014-09-28 17:31:41	2014-09-28 20:40:56
14170	350	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14227Q	\N	RP	2014-09-28 17:34:15	\N
14171	350	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14229S	\N	RP	2014-09-28 17:34:15	\N
14172	350	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	08034U	\N	RP	2014-09-28 17:34:15	2014-09-28 20:39:39
14173	350	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14231L	\N	RP	2014-09-28 17:34:15	\N
14184	740	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14237S	\N	RP	2014-09-28 17:40:23	\N
14185	740	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14179A	\N	RP	2014-09-28 17:40:23	\N
14186	740	2014-10-01 00:00:00	2014-09-28 00:00:00	2018-08-06 00:00:00	REN2	DEM	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	95015C	\N	RP	2014-09-28 17:40:23	2014-09-28 20:34:42
14200	130	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-08-03 00:00:00	REN	FININCOMPAT	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	08035V	\N	RP	2014-09-28 17:52:17	2014-09-28 20:26:18
14201	130	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-08-02 00:00:00	ELECTION	DEM	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14239U	\N	RP	2014-09-28 17:52:17	\N
14202	130	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14241N	\N	RP	2014-09-28 17:52:17	\N
14203	130	2014-10-01 00:00:00	2014-09-28 00:00:00	2017-09-22 00:00:00	REN2	DEM	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	89029V	\N	RP	2014-09-28 17:52:17	2017-09-24 11:09:53
14204	130	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN2	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	98022P	\N	RP	2014-09-28 17:52:17	2014-09-28 20:26:49
14205	130	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-08-02 00:00:00	REN	DEM	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	08044W	\N	RP	2014-09-28 17:52:17	2014-09-28 20:27:08
14206	130	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14055N	\N	RP	2014-09-28 17:52:17	\N
14207	130	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	REN	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	08048B	\N	RP	2014-09-28 17:52:17	2014-09-28 20:26:35
14317	9715	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14261S	\N	SM2	2014-09-29 09:03:10	\N
14318	973	2014-10-01 00:00:00	2014-09-28 00:00:00	2020-09-30 00:00:00	ELECTION	NONREP	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14039A	\N	SM2	2014-09-29 09:05:47	\N
14217	710	2014-10-01 00:00:00	2014-09-28 00:00:00	2015-06-11 00:00:00	REN2	DEMCC	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	95020Y	\N	RP	2014-09-28 17:55:37	2015-06-15 12:02:49
14319	983	2014-10-01 00:00:00	2014-09-28 00:00:00	2015-02-06 00:00:00	ELECTION	ANNCC	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14043V	\N	SM1	2014-09-29 09:08:32	2015-02-06 14:31:29
14320	983	2014-10-01 00:00:00	2014-09-28 00:00:00	2015-02-06 00:00:00	ELECTION	ANNCC	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	14044W	\N	SM1	2014-09-29 09:08:32	2015-02-06 14:33:40
11790	983	2008-10-01 00:00:00	2008-09-21 00:00:00	2014-09-30 00:00:00	ELECTION	NONREELU	ANCIEN	\N	\N	\N	\N	\N	SENAT	08071A	\N	SM2	\N	2014-09-29 09:08:32
14396	50	2014-12-28 00:00:00	\N	2020-09-30 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	\N	en remplacement de M. Jean-Yves Dusserre, décédé	\N	\N	SENAT	14265W	\N	NR	2014-12-29 15:45:40	2015-01-02 11:41:50
15191	590	2015-04-22 00:00:00	\N	2017-06-04 00:00:00	REMPLACE	DECEDE	ANCIEN	\N	Nouveau	en remplacement de M. Jean-René Lecerf, démissionnaire	\N	\N	SENAT	14273W	\N	NR	2015-04-22 16:49:30	2017-06-07 09:38:00
15205	710	2015-06-12 00:00:00	\N	2020-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	Nouveau	en remplacement de M. Jean-Patrick Courtois, déclaré démissionnaire d'office de son mandat par le Conseil constitutionnel	\N	\N	SENAT	14147R	\N	NR	2015-06-12 15:40:17	2015-06-15 10:37:00
15242	770	2015-10-12 00:00:00	\N	2017-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	Nouveau	en remplacement de M. Jean-Jacques Hyest, nommé membre du Conseil Constitutionnel	\N	\N	SENAT	14329V	\N	NR	2015-10-12 09:41:57	2017-09-24 17:18:03
22524	380	2017-06-18 00:00:00	\N	2017-10-01 00:00:00	REPRISE	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	11041F	\N	NR	2017-06-19 15:52:41	2017-09-24 17:35:15
22525	570	2017-06-18 00:00:00	\N	2017-10-01 00:00:00	REPRISE	FINMAN	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	01062T	\N	NR	2017-06-19 15:56:02	2017-09-24 17:48:21
22528	150	2017-06-18 00:00:00	\N	2018-11-16 00:00:00	REMPLACE	REPEXE	ANCIEN	\N	Nouveau	en remplacement de M. Jacques Mézard, nommé membre du Gouvernement	\N	\N	SENAT	19253P	\N	NR	2017-06-19 16:48:14	2017-06-19 16:54:29
51629	1053	2018-07-28 00:00:00	\N	2023-10-01 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	Nouveau	en remplacement de M. Jean-Pierre Bansard, dont l'élection a été annulée par le Conseil constitutionnel	\N	2023	\N	19766L	\N	NR	\N	\N
22530	590	2017-06-15 00:00:00	\N	2017-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	Nouveau	en remplacement de Mme Béatrice Descamps, démissionnaire	\N	\N	SENAT	16813M	\N	NR	2017-06-19 17:55:47	2017-09-24 18:16:52
51630	740	2018-08-07 00:00:00	\N	2020-09-30 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	Nouveau	en remplacement de M. Jean-Claude Carle, démissionnaire	\N	\N	SENAT	19768N	\N	NR	\N	\N
51643	150	2018-11-17 00:00:00	\N	2019-03-03 00:00:00	REPRISE	CESMEMCC	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	08051V	\N	NR	\N	\N
51644	260	2018-11-17 00:00:00	\N	2020-08-06 00:00:00	REMPLACE	REPEXE	ANCIEN	\N	Nouveau	en remplacement de M. Didier Guillaume, membre du Gouvernement	\N	\N	SENAT	19782L	\N	NR	\N	\N
51652	280	2018-12-31 00:00:00	\N	2020-09-30 00:00:00	REMPLACE	NONREP	ANCIEN	\N	Nouveau	en remplacement de M. Gérard Cornu, démissionnaire de son mandat	\N	\N	SENAT	19794Q	\N	NR	\N	\N
51971	330	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	19725B	\N	RP	\N	\N
51972	330	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	19719D	\N	RP	\N	\N
51973	330	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	19820Y	\N	RP	\N	\N
51974	330	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	19723Y	\N	RP	\N	\N
51975	330	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20142Y	\N	RP	\N	\N
51976	330	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	19721W	\N	RP	\N	\N
51983	310	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14225N	\N	RP	\N	\N
51984	310	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN2	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	08028W	\N	RP	\N	\N
51985	310	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	17965H	\N	RP	\N	\N
51986	310	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14221J	\N	RP	\N	\N
51987	310	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14223L	\N	RP	\N	\N
52458	890	2022-06-21 00:00:00	\N	\N	REPRISE	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14037X	\N	NR	\N	\N
53115	824	2022-07-04 00:00:00	\N	2023-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	Nouveau	en remplacement de Mme Taillé-Polian, démissionnaire de son mandat	\N	2023	\N	20914V	\N	NR	\N	\N
53202	430	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN2	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	14267Y	\N	NR	\N	\N
53203	430	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19507S	\N	NR	\N	\N
52017	895	2020-10-01 00:00:00	\N	2023-10-01 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	Nouveau	Remplace M. Alain Schmitz, démissionnaire	\N	2023	\N	20152B	\N	NR	\N	\N
52356	500	2020-12-04 00:00:00	\N	2023-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	Nouveau	En remplacement de M. Alain Sévêque, démissionnaire de son mandat	\N	2023	\N	20180F	\N	NR	\N	\N
52442	620	2021-12-08 00:00:00	\N	2023-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	Nouveau	en remplacement de Catherine Fournier, décédée le 7 décembre 2021	\N	2023	\N	20286Q	\N	NR	\N	\N
53224	1053	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19705W	\N	NR	\N	\N
53225	1053	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN2	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	11027H	\N	NR	\N	\N
53226	1053	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19709B	\N	NR	\N	\N
53227	1053	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21037D	\N	NR	\N	\N
53228	1053	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21038E	\N	NR	\N	\N
53229	520	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN3	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	01058X	\N	NR	\N	\N
53247	490	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21048G	\N	NR	\N	\N
53252	560	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19447X	\N	NR	\N	\N
53253	560	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21050A	\N	NR	\N	\N
53254	560	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21051B	\N	NR	\N	\N
53255	410	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21052C	\N	NR	\N	\N
53256	410	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21053D	\N	NR	\N	\N
53257	370	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21054E	\N	NR	\N	\N
53258	370	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21055F	\N	NR	\N	\N
53302	824	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19687N	\N	NR	\N	\N
53303	824	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19611R	\N	NR	\N	\N
53304	335	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN3	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	99004R	\N	NR	\N	\N
53305	824	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN3	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	04042C	\N	NR	\N	\N
53306	335	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19711U	\N	NR	\N	\N
53307	335	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19593H	\N	NR	\N	\N
53308	824	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21072G	\N	NR	\N	\N
53309	824	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21073H	\N	NR	\N	\N
53310	770	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21074J	\N	NR	\N	\N
53311	770	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN2	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	14329V	\N	NR	\N	\N
53312	770	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN2	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	14357A	\N	NR	\N	\N
53313	770	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN2	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	11074Q	\N	NR	\N	\N
53314	770	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21075K	\N	NR	\N	\N
53315	770	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21076L	\N	NR	\N	\N
53316	775	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	18231D	\N	NR	\N	\N
53317	775	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21077M	\N	NR	\N	\N
53319	775	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21078N	\N	NR	\N	\N
53320	775	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19695N	\N	NR	\N	\N
53321	775	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN2	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	11053K	\N	NR	\N	\N
53342	590	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19565D	\N	NR	\N	\N
53343	590	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21083K	\N	NR	\N	\N
53344	590	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	04008A	\N	NR	\N	\N
53345	590	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	15197G	\N	NR	\N	\N
53346	828	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19667J	\N	NR	\N	\N
53347	828	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19673G	\N	NR	\N	\N
53348	828	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19669L	\N	NR	\N	\N
53351	590	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21085M	\N	NR	\N	\N
53352	828	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21086N	\N	NR	\N	\N
53354	590	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19585H	\N	NR	\N	\N
53362	615	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21092L	\N	NR	\N	\N
53363	615	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21093M	\N	NR	\N	\N
53364	615	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19683J	\N	NR	\N	\N
53365	615	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21094N	\N	NR	\N	\N
53366	615	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21095P	\N	NR	\N	\N
53942	860	2024-03-18 00:00:00	2024-03-17 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	\N	21125C	\N	SM2	\N	\N
52296	440	2020-11-01 00:00:00	\N	2023-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	Nouveau	en remplacement de M. Christophe Priou, démissionnaire de son mandat 	\N	2023	\N	20172F	\N	NR	\N	\N
52417	775	2021-07-28 00:00:00	\N	2023-10-01 00:00:00	REMPLACE	FINMAN	ANCIEN	\N	Nouveau	en remplacement de M. Philippe Dallier, démissionnaire de son mandat	\N	2023	\N	20252E	\N	NR	\N	\N
53154	540	2023-01-01 00:00:00	\N	2023-10-01 00:00:00	REMPLACE	NONREP	ANCIEN	\N	Nouveau	en remplacement de M. Philippe Nachbar, démissionnaire de son mandat	\N	2023	\N	20980G	\N	NR	\N	\N
53355	615	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21088Q	\N	NR	\N	\N
53356	615	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21089R	\N	NR	\N	\N
53357	615	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21090J	\N	NR	\N	\N
53358	615	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19649G	\N	NR	\N	\N
53359	615	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19647E	\N	NR	\N	\N
53360	615	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	07033P	\N	NR	\N	\N
53361	615	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21091K	\N	NR	\N	\N
51922	670	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN2	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	10015M	\N	RP	\N	\N
51923	670	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20096L	\N	RP	\N	\N
51924	670	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14073Q	\N	RP	\N	\N
51925	670	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20098N	\N	RP	\N	\N
51926	670	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20100N	\N	RP	\N	\N
51942	340	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14211G	\N	RP	\N	\N
51943	340	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20114U	\N	RP	\N	\N
51944	340	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20116W	\N	RP	\N	\N
51945	340	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14207L	\N	RP	\N	\N
51952	20	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN2	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	08010L	\N	RP	\N	\N
51953	20	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20122U	\N	RP	\N	\N
51954	20	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14026U	\N	RP	\N	\N
51966	60	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20136B	\N	RP	\N	\N
51967	60	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14187A	\N	RP	\N	\N
51968	60	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20138D	\N	RP	\N	\N
51969	60	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	19729F	\N	RP	\N	\N
51970	60	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20140W	\N	RP	\N	\N
51988	973	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20146D	\N	SM2	\N	\N
51989	9715	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20148F	\N	SM2	\N	\N
51990	983	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14275Y	\N	SM1	\N	\N
51991	983	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20150Y	\N	SM1	\N	\N
52453	265	2022-02-03 00:00:00	\N	2023-10-01 00:00:00	REMPLACE	NONREELU	ANCIEN	\N	Nouveau	en remplacement d'Olivier Léonhardt, décédé le 2 février 2022	\N	2023	\N	20298U	\N	NR	\N	\N
12738	615	2011-10-01 00:00:00	2011-09-25 00:00:00	2012-09-19 00:00:00	REN2	DEM	ANCIEN	\N	\N	\N	\N	\N	SENAT	95011X	\N	RP	\N	\N
53200	982	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21029D	\N	NR	\N	\N
53201	982	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21030V	\N	NR	\N	\N
53211	550	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19563B	\N	NR	\N	\N
53212	460	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21031W	\N	NR	\N	\N
53213	390	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19479G	\N	NR	\N	\N
53222	974	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21035B	\N	NR	\N	\N
53237	580	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19531S	\N	NR	\N	\N
53263	450	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21057H	\N	NR	\N	\N
53264	450	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21058J	\N	NR	\N	\N
53265	450	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19421M	\N	NR	\N	\N
53266	265	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19399H	\N	NR	\N	\N
53267	265	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN2	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	11070L	\N	NR	\N	\N
53268	265	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19691J	\N	NR	\N	\N
53269	265	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19693L	\N	NR	\N	\N
53270	265	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21059K	\N	NR	\N	\N
53272	600	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21060C	\N	NR	\N	\N
53273	600	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19573D	\N	NR	\N	\N
53274	600	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21061D	\N	NR	\N	\N
53275	500	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN2	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	05008E	\N	NR	\N	\N
53276	500	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	20180F	\N	NR	\N	\N
53277	500	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21062E	\N	NR	\N	\N
53279	510	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21064G	\N	NR	\N	\N
53280	510	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21065H	\N	NR	\N	\N
53349	590	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19569H	\N	NR	\N	\N
53350	828	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21084L	\N	NR	\N	\N
53353	590	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21087P	\N	NR	\N	\N
51912	740	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14179A	\N	RP	\N	\N
51913	740	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	19768N	\N	RP	\N	\N
51914	740	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14237S	\N	RP	\N	\N
51919	10	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14038Y	\N	RP	\N	\N
51920	10	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20094J	\N	RP	\N	\N
51921	10	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN2	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	08056B	\N	RP	\N	\N
51927	220	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20102Q	\N	RP	\N	\N
51928	220	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	18193Q	\N	RP	\N	\N
51929	220	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20104S	\N	RP	\N	\N
51930	290	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14083S	\N	RP	\N	\N
51931	290	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20106U	\N	RP	\N	\N
51932	290	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	08045X	\N	RP	\N	\N
51933	290	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN2	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	08047A	\N	RP	\N	\N
51946	270	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN2	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	08009T	\N	RP	\N	\N
51947	270	2020-10-01 00:00:00	2020-09-27 00:00:00	2020-11-01 00:00:00	ELECTION	FINMEMGVT	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	19265T	\N	RP	\N	\N
51948	270	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20118Y	\N	RP	\N	\N
51955	680	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20124W	\N	RP	\N	\N
51956	680	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN2	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	04045F	\N	RP	\N	\N
51957	680	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20126Y	\N	RP	\N	\N
51958	680	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20128B	\N	RP	\N	\N
52297	890	2020-11-02 00:00:00	\N	2022-06-20 00:00:00	REMPLACE	REPEXE	ANCIEN	\N	Nouveau	en remplacement de M. Jean-Baptiste Lemoyne, membre du Gouvernement	\N	\N	SENAT	20174H	\N	NR	\N	\N
52298	270	2020-11-02 00:00:00	\N	\N	REMPLACE	ACTIF	ACTIF	\N	Nouveau	en remplacement de M. Sébastien Lecornu, membre du Gouvernement	\N	\N	SENAT	14249W	\N	NR	\N	\N
52426	1054	2021-10-01 00:00:00	2021-09-26 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	08018U	\N	NR	\N	\N
52425	1054	2021-10-01 00:00:00	2021-09-26 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14255U	\N	NR	\N	\N
52427	1054	2021-10-01 00:00:00	2021-09-26 00:00:00	\N	REELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	19707Y	\N	NR	\N	\N
52428	1054	2021-10-01 00:00:00	2021-09-26 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	19057M	\N	NR	\N	\N
52429	1054	2021-10-01 00:00:00	2021-09-26 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20264J	\N	NR	\N	\N
52430	1054	2021-10-01 00:00:00	2021-09-26 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20266L	\N	NR	\N	\N
53259	370	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21056G	\N	NR	\N	\N
53260	640	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19619A	\N	NR	\N	\N
53261	640	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19621T	\N	NR	\N	\N
53262	640	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN2	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	11110B	\N	NR	\N	\N
53326	895	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19699S	\N	NR	\N	\N
53327	895	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21079P	\N	NR	\N	\N
53329	380	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19347U	\N	NR	\N	\N
53369	971	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19301E	\N	NR	\N	\N
53370	971	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21097R	\N	NR	\N	\N
53943	130	2024-03-21 00:00:00	\N	\N	REMPLACE	ACTIF	ACTIF	\N	\N	En remplacement de M. Jean-Noël GUÉRINI, démissionnaire	\N	\N	\N	14241N	\N	NR	\N	\N
53219	974	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19657G	\N	NR	\N	\N
53220	974	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	2029	\N	21033Y	\N	NR	\N	\N
53221	974	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21034A	\N	NR	\N	\N
53223	1053	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21036C	\N	NR	\N	\N
53230	520	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21039F	\N	NR	\N	\N
53231	470	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19367Y	\N	NR	\N	\N
53232	470	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21040X	\N	NR	\N	\N
53233	460	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21041Y	\N	NR	\N	\N
53236	610	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21043B	\N	NR	\N	\N
53238	660	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21044C	\N	NR	\N	\N
53239	660	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19703U	\N	NR	\N	\N
53243	490	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19533U	\N	NR	\N	\N
53244	490	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19545Y	\N	NR	\N	\N
53245	490	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21046E	\N	NR	\N	\N
53246	390	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21047F	\N	NR	\N	\N
53248	540	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN2	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	11048N	\N	NR	\N	\N
53249	540	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19553Y	\N	NR	\N	\N
53250	540	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19551W	\N	NR	\N	\N
53251	540	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21049H	\N	NR	\N	\N
53271	600	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	11115U	\N	NR	\N	\N
53278	510	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21063F	\N	NR	\N	\N
53281	440	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	18395Y	\N	NR	\N	\N
53282	440	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN2	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	11065P	\N	NR	\N	\N
53283	440	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	20172F	\N	NR	\N	\N
53284	440	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21066J	\N	NR	\N	\N
53285	440	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN2	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	11064N	\N	NR	\N	\N
53292	620	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN2	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	14331P	\N	NR	\N	\N
53293	420	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21068L	\N	NR	\N	\N
53294	620	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21069M	\N	NR	\N	\N
53295	620	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN2	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	01034P	\N	NR	\N	\N
53296	420	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21070E	\N	NR	\N	\N
53297	335	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21071F	\N	NR	\N	\N
53298	335	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19111A	\N	NR	\N	\N
53299	335	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN2	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	11085T	\N	NR	\N	\N
53300	824	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	11045K	\N	NR	\N	\N
53301	335	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19591F	\N	NR	\N	\N
53322	895	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19697Q	\N	NR	\N	\N
53334	570	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19335Q	\N	NR	\N	\N
53335	570	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19954N	\N	NR	\N	\N
53336	570	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21081H	\N	NR	\N	\N
53337	570	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21082J	\N	NR	\N	\N
53338	570	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19685L	\N	NR	\N	\N
53339	590	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	14021P	\N	NR	\N	\N
53340	590	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	18207D	\N	NR	\N	\N
53341	590	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN2	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	11040E	\N	NR	\N	\N
52353	500	2020-12-01 00:00:00	\N	2020-12-01 00:00:00	REMPLACE	DEM	ANCIEN	\N	Nouveau	en remplacement de M. Jean Bizet, démissionnaire de son mandat	\N	\N	SENAT	20176K	\N	NR	\N	\N
52355	500	2020-12-02 00:00:00	\N	2020-12-03 00:00:00	REMPLACE	DEM	ANCIEN	\N	Nouveau	en remplacement de Mme Valérie Blandin, démissionnaire de son mandat	\N	\N	SENAT	20178M	\N	NR	\N	\N
52381	130	2021-07-06 00:00:00	\N	\N	REMPLACE	ACTIF	ACTIF	\N	Nouveau	en remplacement de M. Patrick Boré, décédé le 5 juillet 2021	\N	\N	SENAT	20248J	\N	NR	\N	\N
53204	650	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19631V	\N	NR	\N	\N
53205	650	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19629C	\N	NR	\N	\N
53206	480	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19866P	\N	NR	\N	\N
53215	580	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19713W	\N	NR	\N	\N
53217	990	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN2	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	11072N	\N	NR	\N	\N
53218	990	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19331L	\N	NR	\N	\N
53328	972	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19295A	\N	NR	\N	\N
53330	380	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN2	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	11043H	\N	NR	\N	\N
53331	380	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19679N	\N	NR	\N	\N
53332	380	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21080G	\N	NR	\N	\N
53333	380	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19349W	\N	NR	\N	\N
53367	972	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21096Q	\N	NR	\N	\N
53368	971	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	12016W	\N	NR	\N	\N
51910	300	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20090E	\N	RP	\N	\N
51911	300	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14059S	\N	RP	\N	\N
51915	350	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN2	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	08034U	\N	RP	\N	\N
51916	350	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14229S	\N	RP	\N	\N
51917	350	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14231L	\N	RP	\N	\N
51918	350	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20092G	\N	RP	\N	\N
51934	130	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	17737W	\N	RP	\N	\N
51935	130	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20108W	\N	RP	\N	\N
51936	130	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14055N	\N	RP	\N	\N
51937	130	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20110Q	\N	RP	\N	\N
51938	130	2020-10-01 00:00:00	2020-09-27 00:00:00	2024-03-20 00:00:00	REN3	DEM	ANCIEN	\N	Nouveau	\N	\N	2024	\N	98022P	\N	RP	\N	\N
51939	130	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20112S	\N	RP	\N	\N
51940	130	2020-10-01 00:00:00	2020-09-27 00:00:00	2021-07-05 00:00:00	REN	DECEDE	ANCIEN	\N	Nouveau	\N	\N	\N	SENAT	19966S	\N	RP	\N	\N
51941	130	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	12028B	\N	RP	\N	\N
51949	710	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14151M	\N	RP	\N	\N
51950	710	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20120S	\N	RP	\N	\N
51951	710	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14147R	\N	RP	\N	\N
51959	690	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20130U	\N	RP	\N	\N
51960	690	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	17367Q	\N	RP	\N	\N
51961	690	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20132W	\N	RP	\N	\N
51962	690	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14215L	\N	RP	\N	\N
51963	690	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	19251M	\N	RP	\N	\N
51964	690	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20134Y	\N	RP	\N	\N
51965	690	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN2	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	04047H	\N	RP	\N	\N
51977	760	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	20144B	\N	RP	\N	\N
51978	760	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14053L	\N	RP	\N	\N
51979	760	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN2	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	04070G	\N	RP	\N	\N
51980	760	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	19758L	\N	RP	\N	\N
51981	760	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	19826F	\N	RP	\N	\N
51982	760	2020-10-01 00:00:00	2020-09-27 00:00:00	\N	REN2	ACTIF	ACTIF	\N	Nouveau	\N	\N	\N	SENAT	14001X	\N	RP	\N	\N
53207	400	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19489J	\N	NR	\N	\N
53208	400	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	17779H	\N	NR	\N	\N
53216	995	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21032X	\N	NR	\N	\N
53210	530	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN2	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	14042U	\N	NR	\N	\N
53214	610	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN3	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	07004J	\N	NR	\N	\N
53234	550	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21042A	\N	NR	\N	\N
53235	530	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	18083K	\N	NR	\N	\N
53240	630	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19383Y	\N	NR	\N	\N
53241	630	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19387D	\N	NR	\N	\N
53242	630	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21045D	\N	NR	\N	\N
53286	620	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19760E	\N	NR	\N	\N
53287	620	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19681G	\N	NR	\N	\N
53288	620	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	ELECTION	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	21067K	\N	NR	\N	\N
53289	420	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19413M	\N	NR	\N	\N
53290	620	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	20286Q	\N	NR	\N	\N
53291	420	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN2	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	11056N	\N	NR	\N	\N
53323	895	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN4	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	86034E	\N	NR	\N	\N
53324	895	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN2	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	11090Q	\N	NR	\N	\N
53325	895	2023-10-02 00:00:00	2023-09-24 00:00:00	\N	REN1	ACTIF	ACTIF	\N	\N	\N	\N	\N	SENAT	19701S	\N	NR	\N	\N
\.


--
-- Data for Name: eluter; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY eluter (eluid, asstercod, typmancod, temvalcod, evelic, evelib, evelil, eveobs, eludatdeb, eluanndeb, eludatelu, eludatfin, eluannfin, elunbrhab, senmat, eludatcum, syscredat, sysmajdat) FROM stdin;
12921	\N	ASSTER	ACTIF	\N	Représentant à l'Assemblée de la Polynésie française	Représentant à l'Assemblée de la Polynésie française	\N	\N	2013	\N	\N	\N	\N	08071A	\N	2013-07-22 14:09:42	\N
11547	\N	ASSTER	ANCIEN	\N	Vice-pdt de la collectivité d'outre-mer de Saint-Barthélémy	Vice-président de la collectivité d'outre-mer de Saint-Barthélémy	\N	2007-07-15 00:00:00	2007	\N	2017-05-01 00:00:00	\N	\N	08019V	\N	\N	2017-05-15 11:23:04
5805	POLYNESIE	ASSTER	ANCIEN	\N	Président du Gouvernement de la Polynésie Française	Président du Gouvernement de la Polynésie Française	\N	\N	1984	\N	\N	1987	\N	98052V	\N	\N	\N
5806	POLYNESIE	ASSTER	ANCIEN	\N	Président du Gouvernement de la Polynésie Française	Président du Gouvernement de la Polynésie Française	\N	\N	1991	\N	2004-06-14 00:00:00	2004	\N	98052V	\N	\N	\N
5807	CALEDONIE	ASSTER	ANCIEN	\N	Président du Congrès de la Nouvelle-Calédonie	Président du Congrès de la Nouvelle-Calédonie 	de 1989 à 1995 puis de 1998 à 2004	\N	1983	\N	\N	2004	\N	92033R	\N	\N	\N
5810	CORSE	ASSTER	ANCIEN	\N	Assemblée territoriale de Corse	Assemblée territoriale de Corse	\N	\N	\N	\N	2020-03-31 00:00:00	1998	\N	98008R	\N	\N	\N
11377	POLYNESIE	ASSTER	ANCIEN	\N	Président de la Polynésie Française	Président de la Polynésie Française	\N	2013-05-17 00:00:00	\N	\N	2014-09-05 00:00:00	\N	\N	98052V	\N	\N	2013-07-11 14:47:48
11378	POLYNESIE	ASSTER	ANCIEN	\N	Président de la Polynésie Française	Président de la Polynésie Française	\N	2008-02-23 00:00:00	2008	\N	2008-04-15 00:00:00	2008	\N	98052V	\N	\N	\N
11570	\N	ASSTER	ANCIEN	\N	Président de la Collectivité d'outre-mer de Saint-Martin	Président de la Collectivité d'outre-mer de Saint-Martin	\N	2007-07-15 00:00:00	2007	\N	2008-07-15 00:00:00	2008	\N	08023R	\N	\N	\N
11912	CALEDONIE	ASSTER	ANCIEN	\N	Président de la région des Iles Loyautés	Président de la région des Iles Loyautés	Demande de LMG	\N	1988	\N	\N	1989	\N	92033R	\N	\N	\N
51062	CALEDONIE	ASSTER	ANCIEN	\N	Président du Congrès de la Nouvelle-Calédonie	Président du Congrès de la Nouvelle-Calédonie	\N	2012-08-29 00:00:00	\N	\N	2013-08-08 00:00:00	\N	\N	19319Q	\N	2017-09-24 10:49:22	2017-09-24 10:50:44
15199	POLYNESIE	ASSTER	ANCIEN	\N	Représentante à l'Assemblée de la Polynésie Française	Représentante à l'Assemblée de la Polynésie Française	\N	2014-05-01 00:00:00	\N	\N	2015-04-30 00:00:00	\N	\N	14275Y	\N	2015-05-11 18:46:34	2015-05-11 18:49:20
15201	POLYNESIE	ASSTER	ANCIEN	\N	vice-président du gouvernement de la Polynésie française	Vice-président du gouvernement de la Polynésie française	\N	2013-05-01 00:00:00	\N	\N	2017-01-14 00:00:00	\N	\N	14277B	\N	2015-05-11 19:34:50	2015-05-26 11:14:48
52397	AUTRE	ASSTER	ACTIF	\N	Membre de la collectivité européenne d'Alsace	Membre de la collectivité européenne d'Alsace	\N	2021-06-27 00:00:00	\N	\N	\N	\N	\N	20096L	\N	\N	\N
50797	AUTRE	ASSTER	ACTIF	\N	Conseillère à l'Assemblée territoriale de Martinique	Conseillère à l'Assemblée territoriale de Martinique	\N	2015-10-01 00:00:00	\N	2015-10-01 00:00:00	\N	\N	\N	19295A	\N	2017-09-15 14:43:39	2017-09-26 18:09:26
15289	AUTRE	ASSTER	ANCIEN	\N	Président du PETR du Pays de Langres	Président du PETR du Pays de Langres	\N	2016-01-11 00:00:00	\N	2016-01-11 00:00:00	2018-01-01 00:00:00	\N	\N	01057W	\N	2016-04-18 18:03:01	2016-04-21 15:14:08
52396	AUTRE	ASSTER	ANCIEN	\N	Membre de la collectivité européenne d'Alsace	Membre de la collectivité européenne d'Alsace	\N	2021-01-01 00:00:00	\N	\N	2021-06-26 00:00:00	\N	\N	20096L	\N	\N	\N
51368	AUTRE	ASSTER	ANCIEN	Président du conseil territorial de Saint-Pierre-et-Miquelon	Président du conseil territorial de Saint-Pierre-et-Miquelon	Président du conseil territorial de Saint-Pierre-et-Miquelon	\N	2006-03-31 00:00:00	\N	2006-03-31 00:00:00	2017-10-22 00:00:00	\N	\N	19717B	\N	2017-09-25 11:11:52	2017-11-08 16:42:19
51506	AUTRE	ASSTER	ACTIF	\N	Conseiller territorial de Saint-Pierre-et-Miquelon	Conseiller territorial de Saint-Pierre-et-Miquelon	\N	2017-10-23 00:00:00	\N	2017-10-23 00:00:00	\N	\N	\N	19717B	\N	2017-11-08 16:34:48	2017-11-08 16:42:38
51674	POLYNESIE	ASSTER	ANCIEN	\N	Première vice-présidente de l'Assemblée de la Polynésie Française	Première vice-présidente de l'Assemblée de la Polynésie Française	\N	2015-05-01 00:00:00	\N	\N	2017-09-30 00:00:00	\N	\N	14275Y	\N	\N	\N
51675	POLYNESIE	ASSTER	ACTIF	\N	Représentante à l'Assemblée de la Polynésie Française	Représentante à l'Assemblée de la Polynésie Française	\N	2017-10-01 00:00:00	\N	\N	\N	\N	\N	14275Y	\N	\N	\N
51702	POLYNESIE	ASSTER	ACTIF	\N	Membre de l'Assemblée de Polynésie française	Membre de l'Assemblée de Polynésie française	\N	2017-01-15 00:00:00	\N	\N	\N	\N	\N	14277B	\N	\N	\N
52069	AUTRE	ASSTER	ANCIEN	\N	Vice-Présidente du Conseil territorial de Saint-Martin	Vice-Présidente du Conseil territorial de Saint-Martin	\N	2017-03-15 00:00:00	\N	\N	2020-10-15 00:00:00	\N	\N	20148F	\N	\N	\N
52146	AUTRE	ASSTER	ANCIEN	Vice-Présidente du Conseil territorial de Saint-Barthélemy	Vice-Présidente du Conseil territorial de Saint-Barthélemy	Vice-Présidente du Conseil territorial de Saint-Barthélemy	\N	2017-03-15 00:00:00	\N	2015-07-15 00:00:00	2020-10-15 00:00:00	\N	\N	20034V	\N	\N	\N
52007	AUTRE	ASSTER	ANCIEN	\N	Membre de l'Assemblée de Guyane	Membre de l'Assemblée de Guyane	\N	2015-12-15 00:00:00	\N	2015-12-15 00:00:00	\N	2016	\N	20146D	\N	\N	\N
52166	CORSE	ASSTER	ANCIEN	\N	Membre de l'Assemblée de Corse	Membre de l'Assemblée de Corse	\N	2017-12-15 00:00:00	\N	\N	2020-10-15 00:00:00	\N	\N	20036X	\N	\N	\N
52191	POLYNESIE	ASSTER	ANCIEN	\N	Membre du Gouvernement de la Polynésie française	Membre du Gouvernement de la Polynésie française	\N	2003-11-15 00:00:00	\N	\N	2004-04-15 00:00:00	\N	\N	20150Y	\N	\N	\N
52187	POLYNESIE	ASSTER	ANCIEN	\N	Vice-Président du Gouvernement de la Polynésie française	Vice-Président du Gouvernement de la Polynésie française	\N	2017-01-15 00:00:00	\N	\N	2020-09-15 00:00:00	\N	\N	20150Y	\N	\N	\N
52189	POLYNESIE	ASSTER	ANCIEN	\N	Membre du Gouvernement de la Polynésie française	Membre du Gouvernement de la Polynésie française	\N	2015-05-15 00:00:00	\N	\N	2017-01-15 00:00:00	\N	\N	20150Y	\N	\N	\N
52192	POLYNESIE	ASSTER	ANCIEN	\N	Membre du Gouvernement de la Polynésie française	Membre du Gouvernement de la Polynésie française	\N	2004-10-15 00:00:00	\N	\N	2005-02-15 00:00:00	\N	\N	20150Y	\N	\N	\N
52194	POLYNESIE	ASSTER	ANCIEN	\N	Membre du Gouvernement de la Polynésie française	Membre du Gouvernement de la Polynésie française	\N	2006-07-15 00:00:00	\N	\N	2007-07-15 00:00:00	\N	\N	20150Y	\N	\N	\N
52195	POLYNESIE	ASSTER	ANCIEN	\N	Membre du Gouvernement de la Polynésie française	Membre du Gouvernement de la Polynésie française	\N	2008-03-15 00:00:00	\N	\N	2008-04-15 00:00:00	\N	\N	20150Y	\N	\N	\N
52198	POLYNESIE	ASSTER	ANCIEN	\N	Membre du Gouvernement de la Polynésie française	Membre du Gouvernement de la Polynésie française	\N	2009-02-15 00:00:00	\N	\N	2009-11-15 00:00:00	\N	\N	20150Y	\N	\N	\N
52200	POLYNESIE	ASSTER	ANCIEN	\N	Membre du Gouvernement de la Polynésie française	Membre du Gouvernement de la Polynésie française	\N	2009-11-15 00:00:00	\N	\N	2011-03-15 00:00:00	\N	\N	20150Y	\N	\N	\N
52250	AUTRE	ASSTER	ANCIEN	\N	Vice-Président de l'Assemblée territoriale des Îles Wallis et Futuna	Vice-Président de l'Assemblée territoriale des Îles Wallis et Futuna	\N	2012-03-15 00:00:00	\N	\N	2012-12-15 00:00:00	\N	11600	20016T	\N	\N	\N
52251	AUTRE	ASSTER	ANCIEN	\N	Vice-Président de l'Assemblée territoriale des Îles Wallis et Futuna	Vice-Président de l'Assemblée territoriale des Îles Wallis et Futuna	\N	2013-12-15 00:00:00	\N	\N	2014-12-15 00:00:00	\N	11600	20016T	\N	\N	\N
52252	AUTRE	ASSTER	ANCIEN	\N	Président de l'Assemblée territoriale des Îles Wallis et Futuna	Président de l'Assemblée territoriale des Îles Wallis et Futuna	\N	2014-12-15 00:00:00	\N	\N	2017-03-15 00:00:00	\N	11600	20016T	\N	\N	\N
52253	AUTRE	ASSTER	ACTIF	\N	Membre de l'Assemblée territoriale des Îles Wallis et Futuna	Membre de l'Assemblée territoriale des Îles Wallis et Futuna	\N	2017-03-15 00:00:00	\N	\N	\N	\N	11600	20016T	\N	\N	\N
52310	AUTRE	ASSTER	ACTIF	\N	Conseillère territoriale de Saint-Martin	Conseillère territoriale de Saint-Martin	\N	2020-10-16 00:00:00	\N	\N	\N	\N	\N	20148F	\N	\N	\N
53764	AUTRE	ASSTER	ANCIEN	\N	Conseillère territoriale de Saint-Pierre-et-Miquelon	Conseillère territoriale de Saint-Pierre-et-Miquelon	\N	2006-01-01 00:00:00	2006	1499-12-31 00:50:39	2016-12-31 00:00:00	2016	0	21032X	\N	\N	2023-11-20 16:16:15
\.


--
-- Data for Name: elutit; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY elutit (eluid, titeluid, titelecod, titeludatdeb, titeluanndeb, titeludatfin, titeluannfin, temvalcod, evelic, evelib, evelil, titeluhon, syscredat, sysmajdat) FROM stdin;
1345	1345	PDTGEN	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1348	1348	VICPDTGEN	\N	1976	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1349	1349	VICPDTGEN	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1350	1350	VICPDTGEN	\N	1998	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1351	1351	PDTGEN	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1352	1352	VICPDTGEN	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
1353	1353	VICPDTGEN	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1354	1354	PDTGEN	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1355	1355	CONSGENE	\N	1998	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1357	1357	VICPDTGEN	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1358	1358	PDTGEN	1998-03-11 00:00:00	1998	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1360	1360	VICPDTGEN	\N	\N	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1361	1361	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
1363	1363	VICPDTGEN	\N	\N	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1364	1364	VICPDTGEN	\N	\N	2023-04-05 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
1365	1365	CONSGENE	\N	\N	2021-02-12 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
1366	1366	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
1367	1367	PDTGEN	\N	1982	1999-06-07 00:00:00	1999	ANCIEN	\N	\N	\N	NON	\N	\N
1369	1369	CONSGENE	\N	\N	1999-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
1370	1370	VICPDTGEN	\N	\N	\N	1992	ANCIEN	\N	\N	\N	NON	\N	\N
1373	1373	PDTGEN	\N	\N	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1374	1374	VICPDTGEN	\N	\N	2010-12-20 00:00:00	2010	ANCIEN	\N	\N	\N	NON	\N	\N
1376	1376	CONSGENE	\N	\N	2010-08-11 00:00:00	2010	ANCIEN	\N	\N	\N	NON	\N	\N
1377	1377	VICPDTGEN	\N	\N	2014-09-07 00:00:00	2014	ANCIEN	\N	\N	\N	NON	\N	\N
1378	1378	CONSGENE	\N	\N	2004-03-28 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
1379	1379	CONSGENE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1382	1382	PDTGEN	\N	\N	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1384	1384	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
1386	1386	PDTGEN	\N	\N	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
1387	1387	PDTGEN	\N	\N	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1388	1388	CONSGENE	\N	\N	2004-03-28 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
1391	1391	VICPDTGEN	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1392	1392	CONSGENE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1393	1393	CONSGENE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1394	1394	CONSGENE	\N	\N	2004-04-28 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
1395	1395	CONSGENE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1396	1396	VICPDTGEN	\N	\N	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1397	1397	VICPDTGEN	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1399	1399	VICPDTGEN	\N	\N	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1402	1402	PDTGEN	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1403	1403	CONSGENE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1404	1404	VICPDTGEN	\N	\N	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1405	1405	PDTGEN	\N	1998	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1408	1408	CONSGENE	\N	1976	\N	1982	ANCIEN	\N	\N	\N	NON	\N	\N
1409	1409	CONSGENE	1979-03-22 00:00:00	1979	\N	1982	ANCIEN	\N	\N	\N	NON	\N	\N
1411	1411	CONSGENE	\N	\N	2001-03-18 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1412	1412	CONSGENE	\N	\N	2000-04-28 00:00:00	2000	ANCIEN	\N	\N	\N	NON	\N	\N
1413	1413	CONSGENE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1415	1415	CONSGENE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1416	1416	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
1418	1418	CONSGENE	\N	1998	1999-10-16 00:00:00	1999	ANCIEN	\N	\N	\N	NON	\N	\N
1420	1420	CONSGENE	\N	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
1423	1423	CONSGENEPARI	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1424	1424	CONSGENEPARI	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1425	1425	CONSGENEPARI	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1427	1427	CONSGENEPARI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
1429	1429	CONSGENE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1430	1430	CONSGENE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1431	1431	PDTGEN	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1432	1432	VICPDTGEN	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1435	1435	CONSGENE	\N	\N	2013-08-01 00:00:00	2013	ANCIEN	\N	\N	\N	NON	\N	\N
1436	1436	CONSGENE	\N	\N	2004-03-28 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
1437	1437	CONSGENE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1438	1438	PDTGEN	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1440	1440	VICPDTGEN	\N	1985	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1443	1443	CONSGENE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1444	1444	VICPDTGEN	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1446	1446	VICPDTGEN	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1719	1719	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
1721	1721	DEPUTE	1993-05-24 00:00:00	1993	1995-09-24 00:00:00	1995	ANCIEN	\N	\N	\N	NON	\N	2017-06-15 10:50:26
1722	1722	DEPUTE	1993-05-02 00:00:00	1993	1995-05-19 00:00:00	1995	ANCIEN	\N	\N	\N	NON	\N	2017-06-15 10:50:09
1725	1725	DEPUTE	1988-06-12 00:00:00	1988	1993-04-01 00:00:00	1993	ANCIEN	\N	\N	\N	NON	\N	2016-12-12 14:45:14
1727	1727	DEPUTE	1993-03-28 00:00:00	1993	1995-09-24 00:00:00	1995	ANCIEN	\N	\N	\N	NON	\N	\N
1728	1728	DEPUTE	1981-07-24 00:00:00	1981	1986-04-01 00:00:00	1986	ANCIEN	\N	\N	\N	NON	\N	2016-12-13 10:34:34
1730	1730	DEPUTE	1986-03-16 00:00:00	1986	1988-05-14 00:00:00	1988	ANCIEN	\N	\N	\N	NON	\N	2016-12-12 14:34:00
1731	1731	DEPUTE	1986-04-01 00:00:00	1986	1988-05-14 00:00:00	1988	ANCIEN	\N	\N	\N	NON	\N	2016-12-08 14:27:04
1733	1733	DEPUTE	1973-03-04 00:00:00	1973	1978-04-02 00:00:00	1978	ANCIEN	\N	\N	\N	NON	\N	2016-12-13 09:50:51
1737	1737	DEPUTE	1986-03-16 00:00:00	1986	1988-05-14 00:00:00	1988	ANCIEN	\N	\N	\N	NON	\N	2016-12-09 14:31:06
1740	1740	DEPUTE	1988-06-12 00:00:00	1988	1993-04-01 00:00:00	1993	ANCIEN	\N	\N	\N	NON	\N	\N
1743	1743	DEPUTE	1988-07-29 00:00:00	1988	1993-04-01 00:00:00	1993	ANCIEN	\N	\N	\N	NON	\N	2017-06-15 10:49:40
1744	1744	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
1746	1746	DEPUTE	1988-06-12 00:00:00	1988	1993-04-01 00:00:00	1993	ANCIEN	\N	\N	\N	NON	\N	2016-12-09 14:28:59
1747	1747	DEPUTE	1988-06-16 00:00:00	1988	1993-04-01 00:00:00	1993	ANCIEN	\N	\N	\N	NON	\N	\N
5002	2001	CONSREG	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
5010	2004	CONSGENE	1998-03-22 00:00:00	1998	2001-04-10 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5014	2006	CONSGENE	\N	1988	\N	1992	ANCIEN	\N	\N	\N	NON	\N	\N
5015	2007	CONSREG	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
5014	2009	PDTGEN	\N	1992	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
5030	2011	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
5031	2012	CONSGENE	\N	\N	\N	1988	ANCIEN	\N	\N	\N	NON	\N	\N
5034	2013	VICPDTGEN	\N	1992	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
5045	2017	VICPDTGEN	\N	\N	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5046	2018	DEPUTE	\N	1988	\N	1993	ANCIEN	\N	\N	\N	NON	\N	\N
5050	2019	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5058	2021	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	OUI	\N	\N
5061	2023	MAIRE	\N	1989	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5062	2025	MAIRE	\N	1995	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5063	2027	DEPUTE	1978-03-19 00:00:00	\N	1989-09-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2016-12-12 12:10:09
5065	2028	CONSMUNI	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5069	2029	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5077	2033	DEPUTE	1988-06-12 00:00:00	1988	1998-08-10 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
5081	2034	MAIRE	1990-07-14 00:00:00	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5082	2035	CONSGENE	\N	1988	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5088	2037	CONSMUNI	\N	1977	\N	1983	ANCIEN	\N	\N	\N	NON	\N	\N
5089	2038	PDTGEN	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5090	2040	CONSREG	\N	1992	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
5098	2043	DEPUTE	1993-03-28 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2016-12-12 12:02:26
5101	2044	MAIRE	\N	1995	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5103	2046	MAIRE	\N	1995	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5107	2048	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
5108	2049	VICPDTREG	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
5114	2051	CONSGENE	1992-03-22 00:00:00	\N	1998-03-14 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
5116	2053	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5123	2055	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5124	2056	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5127	2057	MAIRE	\N	\N	1998-11-28 00:00:00	1998	ANCIEN	\N	\N	\N	NON	\N	\N
5130	2059	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
5133	2061	CONSGENE	\N	1982	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5135	2062	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5136	2063	CONSGENE	\N	1988	\N	1992	ANCIEN	\N	\N	\N	NON	\N	\N
5139	2065	MAIRE	\N	1977	1999-06-11 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
5140	2066	PDTGEN	\N	1994	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5143	2067	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5144	2068	CONSREG	1986-03-16 00:00:00	1986	1992-03-21 00:00:00	1992	ANCIEN	\N	\N	\N	NON	\N	\N
5146	2070	CONSGENE	\N	1958	\N	1964	ANCIEN	\N	\N	\N	NON	\N	\N
5149	2071	CONSMUNI	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5150	2072	PDTGEN	\N	\N	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5152	2073	MAIREADJOINT	\N	1983	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5157	2077	VICPDTREG	\N	1986	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
5156	2076	DEPUTE	1993-03-28 00:00:00	1993	1997-04-21 00:00:00	1997	ANCIEN	\N	\N	\N	NON	\N	\N
5162	2078	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5165	2080	CONSMUNI	\N	1995	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5166	2081	PDTREG	\N	\N	2004-04-02 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
5168	2082	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5171	2084	MAIRE	1989-03-17 00:00:00	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5172	2085	VICPDTGEN	\N	\N	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5174	2086	VICPDTGEN	\N	1988	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5176	2087	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5177	2088	VICPDTGEN	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5189	2089	MAIRE	1983-03-20 00:00:00	1983	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5195	2094	PDTGEN	\N	1985	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5192	2092	DEPUTE	1986-03-16 00:00:00	1986	1988-05-14 00:00:00	1988	ANCIEN	\N	\N	\N	NON	\N	2016-12-09 11:21:33
5194	2093	MAIREADJOINT	\N	1977	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5196	2095	DEPUTE	1988-06-12 00:00:00	1988	1993-04-01 00:00:00	1993	ANCIEN	\N	\N	\N	NON	\N	2016-12-08 17:07:16
5198	2096	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5199	2097	CONSREG	\N	\N	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
5201	2098	MAIRE	\N	1977	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5202	2099	VICPDTGEN	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5203	2100	DEPUTE	1986-03-16 00:00:00	\N	1998-09-28 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2016-12-12 12:17:23
5205	2101	CONSMUNI	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5206	2102	VICPDTGEN	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5210	2103	PDTGEN	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5212	2105	MAIRE	\N	\N	2000-03-10 00:00:00	2000	ANCIEN	\N	\N	\N	NON	\N	\N
5211	2104	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
5216	2106	MAIRE	\N	1983	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
5217	2107	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
5219	2108	DEPUTE	1977-01-11 00:00:00	1977	1978-04-01 00:00:00	1978	ANCIEN	\N	\N	\N	NON	\N	2017-06-15 10:49:15
5223	2110	VICPDTREG	\N	1988	\N	1992	ANCIEN	\N	\N	\N	NON	\N	\N
5224	2111	CONSREG	\N	1973	\N	1986	ANCIEN	\N	\N	\N	NON	\N	\N
646	646	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5227	2112	DEPUTE	1988-06-12 00:00:00	1988	1993-04-01 00:00:00	1993	ANCIEN	\N	\N	\N	NON	\N	2016-12-09 11:21:53
5229	2114	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
5114	2118	CONSGENE	1998-03-15 00:00:00	\N	1998-11-27 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
5232	2117	CONSREG	\N	1992	2004-03-28 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
5235	2119	DEPUTE	1986-03-16 00:00:00	1986	1988-05-14 00:00:00	1988	ANCIEN	\N	\N	\N	NON	\N	2016-12-13 10:40:12
5237	2121	VICPDTGEN	\N	1992	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
5014	2124	CONSGENE	\N	1998	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5146	2126	PDTGEN	\N	1964	\N	1979	ANCIEN	\N	\N	\N	NON	\N	\N
5146	2127	CONSGENE	\N	1979	2004-03-28 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
5241	2129	CONSGENE	\N	1993	\N	1997	ANCIEN	\N	\N	\N	NON	\N	\N
5242	2130	CONSREG	\N	1993	\N	1997	ANCIEN	\N	\N	\N	NON	\N	\N
5163	2128	DEPUTE	1986-03-16 00:00:00	1986	1988-05-14 00:00:00	1988	ANCIEN	\N	\N	\N	NON	\N	2016-12-09 15:56:55
5244	2131	DEPUTE	\N	1993	\N	1997	ANCIEN	\N	\N	\N	NON	\N	\N
5136	2132	PDTGEN	\N	1992	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
5246	2134	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
5247	2135	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
5248	2136	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
5249	2137	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
5251	2139	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
5252	2140	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
5255	2142	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
5256	2143	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
5257	2144	DEPUTE	1978-03-12 00:00:00	1978	1981-05-22 00:00:00	1981	ANCIEN	\N	\N	\N	NON	\N	2016-12-08 19:24:00
5260	2150	CONSMUNI	\N	1959	\N	1983	ANCIEN	\N	\N	\N	NON	\N	\N
5261	2151	DEPUTE	\N	1981	\N	1993	ANCIEN	\N	\N	\N	NON	\N	\N
5266	2154	PDTREG	\N	1986	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
5263	2153	DEPUTE	1981-06-21 00:00:00	1981	1986-04-01 00:00:00	1986	ANCIEN	\N	\N	\N	NON	\N	2016-12-09 14:35:00
5090	2156	VICPDTREG	\N	1998	1998-10-22 00:00:00	1998	ANCIEN	\N	\N	\N	NON	\N	\N
5270	2158	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
5127	2159	CONSMUNI	1998-11-28 00:00:00	1998	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5273	2160	VICPDTGEN	\N	1988	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5274	2161	CONSMUNI	\N	1989	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5088	2162	MAIRESEC	\N	1995	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5281	2163	CONSMUNI	1999-03-20 00:00:00	1999	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1367	2165	VICPDTGEN	1999-06-07 00:00:00	1999	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
701	701	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
702	702	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
705	705	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
708	708	MAIREADJOINT	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
710	710	MAIREARR	\N	\N	2000-04-17 00:00:00	2000	ANCIEN	\N	\N	\N	NON	\N	\N
713	713	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
714	714	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
717	717	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
719	719	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
720	720	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
722	722	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
727	727	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
728	728	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
730	730	MAIRE	\N	1977	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
731	731	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
733	733	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
734	734	CONSMUNI	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
736	736	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
737	737	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
738	738	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
741	741	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
742	742	CONSMUNI	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
743	743	MAIRE	\N	1983	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
745	745	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
746	746	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
747	747	CONSMUNI	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
749	749	MAIREADJOINT	\N	\N	2011-02-23 00:00:00	2011	ANCIEN	\N	\N	\N	NON	\N	\N
751	751	CONSMUNI	\N	\N	1999-11-27 00:00:00	1999	ANCIEN	\N	\N	\N	NON	\N	\N
752	752	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
753	753	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
756	756	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
757	757	CONSMUNI	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
759	759	MAIRE	\N	1983	2002-12-10 00:00:00	2002	ANCIEN	\N	\N	\N	NON	\N	\N
761	761	MAIRE	\N	1983	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
762	762	MAIREADJOINT	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
764	764	MAIRE	\N	\N	1998-11-02 00:00:00	1998	ANCIEN	\N	\N	\N	NON	\N	\N
765	765	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
767	767	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
768	768	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
769	769	MAIREADJOINT	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
774	774	MAIRE	\N	1983	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6096	2403	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6097	2404	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6098	2405	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6100	2406	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6101	2407	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6102	2409	CONSGENE	2001-03-11 00:00:00	2001	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
597	597	CONSMUNI	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6104	2410	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6107	2413	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6112	2416	MAIRE	2001-03-11 00:00:00	2001	2010-01-13 00:00:00	2010	ANCIEN	\N	\N	\N	NON	\N	\N
6113	2417	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6114	2418	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6116	2419	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-18 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
589	589	CONSMUNI	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6118	2421	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-24 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6119	2422	CONSMUNI	2001-03-11 00:00:00	2001	2009-09-09 00:00:00	2009	ANCIEN	\N	\N	\N	NON	\N	\N
6120	2423	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6121	2424	CONSGENE	2001-03-11 00:00:00	2001	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6122	2425	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6125	2427	CONSGENE	2001-03-11 00:00:00	2001	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6126	2428	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
622	622	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6128	2430	CONSGENE	2001-03-11 00:00:00	2001	2005-02-20 00:00:00	2005	ANCIEN	\N	\N	\N	NON	\N	\N
6130	2432	CONSMUNI	2001-03-11 00:00:00	2001	2008-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6131	2433	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6132	2434	CONSGENE	2001-03-11 00:00:00	2001	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
617	617	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5154	2074	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6134	2436	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6135	2437	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6136	2438	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6137	2439	CONSGENE	2001-03-11 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
620	620	MAIRE	\N	1983	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6138	2440	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6139	2441	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-24 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6140	2442	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6142	2444	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6143	2445	CONSMUNI	2001-03-11 00:00:00	2001	\N	2005	ANCIEN	\N	\N	\N	NON	\N	\N
612	612	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6144	2446	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
683	683	CONSMUNI	\N	1971	\N	1983	ANCIEN	\N	\N	\N	NON	\N	\N
6145	2447	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1401	1401	VICPDTGEN	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6147	2449	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
718	718	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
669	669	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6149	2450	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6150	2451	CONSMUNI	2001-03-11 00:00:00	2001	2002-01-19 00:00:00	2002	ANCIEN	\N	\N	\N	NON	\N	\N
670	670	MAIREADJOINT	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
721	721	CONSMUNI	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6151	2452	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6152	2453	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
691	691	CONSMUNI	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6153	2454	CONSGENE	2001-03-11 00:00:00	2001	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6154	2455	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
12914	13094	VICPDTGEN	\N	1998	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
659	659	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
661	661	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
662	662	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
663	663	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
665	665	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
666	666	CONSMUNI	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
667	667	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
671	671	CONSMUNI	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
674	674	MAIRE	\N	1971	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
676	676	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
677	677	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
678	678	CONSMUNI	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
680	680	MAIRE	\N	1971	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
681	681	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
682	682	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
686	686	MAIRE	\N	1965	2000-10-27 00:00:00	2000	ANCIEN	\N	\N	\N	NON	\N	\N
688	688	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
689	689	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
690	690	CONSMUNI	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
693	693	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
694	694	CONSMUNI	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
695	695	CONSMUNI	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
697	697	MAIRE	\N	1995	2001-03-10 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	2014-10-09 10:33:51
698	698	MAIRE	\N	\N	1999-10-16 00:00:00	1999	ANCIEN	\N	\N	\N	NON	\N	\N
699	699	CONSMUNI	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
700	700	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1487	1487	PDTREG	1992-03-22 00:00:00	1992	1998-03-15 00:00:00	1998	ANCIEN	\N	\N	\N	NON	\N	\N
1492	1492	CONSREG	\N	1992	2001-12-08 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1498	1498	CONSREG	\N	\N	2013-06-03 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-03-19 17:57:05
1503	1503	CONSREG	\N	\N	2017-12-18 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2018-01-08 09:00:07
1505	1505	CONSREG	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
1491	1491	PDTREG	\N	\N	2004-03-30 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
1506	1506	CONSREG	\N	1983	\N	1991	ANCIEN	\N	\N	\N	NON	\N	\N
6195	2534	CONSREG	\N	1982	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6196	2535	CONSPARI	2001-03-18 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6197	2536	CONSPARI	2001-03-18 00:00:00	2001	2008-03-16 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6198	2537	CONSMUNI	2001-03-18 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6199	2538	CONSPARI	2001-03-18 00:00:00	2001	2001-03-25 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6200	2540	CONSPARI	2001-03-18 00:00:00	2001	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6201	2541	CONSMUNI	2001-03-18 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6202	2542	CONSMUNI	2001-03-18 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6203	2543	CONSMUNI	2001-03-18 00:00:00	2001	2001-03-25 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6205	2544	CONSMUNI	2001-03-18 00:00:00	2001	2001-03-25 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6206	2545	CONSMUNI	2001-03-18 00:00:00	2001	2008-03-21 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6208	2547	CONSMUNI	2001-03-18 00:00:00	2001	2001-03-25 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6209	2548	CONSMUNI	2001-03-18 00:00:00	2001	2001-03-25 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6210	2549	CONSMUNI	2001-03-18 00:00:00	2001	2001-03-25 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6211	2550	CONSMUNI	2001-03-18 00:00:00	2001	2001-03-25 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6212	2551	CONSMUNI	2001-03-18 00:00:00	2001	2001-03-25 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6213	2552	CONSMUNI	2001-03-18 00:00:00	2001	2001-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6214	2553	CONSMUNI	2001-03-18 00:00:00	2001	2006-04-29 00:00:00	2006	ANCIEN	\N	\N	\N	NON	\N	\N
6215	2554	CONSMUNI	2001-03-18 00:00:00	2001	2008-03-21 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6216	2555	CONSMUNI	2001-03-18 00:00:00	2001	2001-03-25 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6217	2556	CONSMUNI	2001-03-18 00:00:00	2001	2001-03-25 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6218	2557	CONSMUNI	2001-03-18 00:00:00	2001	2001-03-25 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6219	2558	CONSMUNI	2001-03-18 00:00:00	2001	2001-03-25 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6220	2559	CONSMUNI	2001-03-18 00:00:00	2001	2001-03-24 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6221	2560	CONSMUNI	2001-03-18 00:00:00	2001	2001-03-25 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6222	2561	CONSMUNI	2001-03-18 00:00:00	2001	2008-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6223	2562	CONSMUNI	2001-03-18 00:00:00	2001	2001-03-25 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6224	2563	CONSMUNI	2001-03-18 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6225	2564	CONSGENE	2001-03-18 00:00:00	2001	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6226	2565	CONSGENE	2001-03-18 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6227	2566	CONSGENE	2001-03-18 00:00:00	2001	2001-12-08 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6228	2567	CONSGENE	2001-03-18 00:00:00	2001	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6229	2568	CONSGENE	2001-03-18 00:00:00	2001	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6230	2569	CONSGENE	2001-03-18 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6231	2570	CONSGENE	2001-03-18 00:00:00	2001	2016-03-15 00:00:00	2016	ANCIEN	\N	\N	\N	NON	\N	\N
6232	2571	CONSGENE	2001-03-18 00:00:00	2001	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6233	2572	CONSGENE	2001-03-18 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6234	2573	CONSGENE	2001-03-18 00:00:00	2001	2008-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6235	2574	CONSGENE	2001-03-18 00:00:00	2001	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6236	2575	CONSGENE	2001-03-18 00:00:00	2001	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6081	2577	MAIRE	2001-03-17 00:00:00	2001	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6238	2579	CONSGENE	\N	1985	\N	1993	ANCIEN	\N	\N	\N	NON	\N	\N
6238	2580	VICPDTGEN	\N	1993	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
6239	2581	CONSREG	\N	1992	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
6071	2583	MAIRE	2001-03-18 00:00:00	2001	2012-01-14 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-09-18 10:55:15
6241	2584	CONSMUNI	2001-03-18 00:00:00	2001	2009-12-18 00:00:00	2009	ANCIEN	\N	\N	\N	NON	\N	\N
6242	2585	CONSMUNI	2001-03-18 00:00:00	2001	2004-02-12 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6243	2586	CONSMUNI	2001-03-18 00:00:00	2001	2001-03-25 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6244	2587	CONSMUNI	2001-03-18 00:00:00	2001	2001-03-25 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6010	2588	MAIRE	2001-03-17 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6000	2589	MAIRE	2001-03-17 00:00:00	2001	2010-10-04 00:00:00	2010	ANCIEN	\N	\N	\N	NON	\N	\N
6026	2590	MAIRE	2001-03-17 00:00:00	2001	2008-03-21 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6145	2591	MAIRE	2001-03-17 00:00:00	2001	2014-03-24 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2015-02-27 10:24:52
6049	2592	MAIRE	2001-03-17 00:00:00	2001	2008-03-14 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6051	2593	MAIRE	2001-03-17 00:00:00	2001	2004-04-22 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6096	2594	MAIRE	2001-03-17 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6097	2595	MAIRE	2001-03-17 00:00:00	2001	2014-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-08 16:04:50
6098	2596	MAIRE	2001-03-17 00:00:00	2001	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6149	2597	MAIRE	2001-03-17 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6054	2598	MAIRE	2001-03-17 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6103	2599	MAIRE	2001-03-17 00:00:00	2001	2022-08-18 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6057	2600	MAIRE	2001-03-17 00:00:00	2001	2023-10-28 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6060	2602	MAIRE	2001-03-17 00:00:00	2001	2019-03-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6062	2606	MAIRE	2001-03-17 00:00:00	2001	2013-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6152	2607	MAIRE	2001-03-17 00:00:00	2001	2020-08-26 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6019	2608	MAIRE	2001-03-17 00:00:00	2001	2019-09-16 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6072	2610	MAIRE	2001-03-17 00:00:00	2001	2014-03-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-07 11:30:22
6117	2611	MAIRE	2001-03-17 00:00:00	2001	2003-08-28 00:00:00	2003	ANCIEN	\N	\N	\N	NON	\N	\N
6120	2613	MAIRE	2001-03-17 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6037	2614	MAIRE	2001-03-17 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6078	2615	MAIRE	2001-03-17 00:00:00	2001	2014-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-07 10:19:45
6086	2618	MAIRE	2001-03-17 00:00:00	2001	2001-03-25 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6134	2619	MAIRE	2001-03-17 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6135	2620	MAIRE	2001-03-17 00:00:00	2001	2015-01-15 00:00:00	2015	ANCIEN	\N	\N	\N	NON	\N	\N
6041	2623	MAIRE	2001-03-17 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6144	2624	MAIRE	2001-03-17 00:00:00	2001	2007-12-16 00:00:00	2007	ANCIEN	\N	\N	\N	NON	\N	\N
6042	2625	MAIRE	2001-03-17 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6093	2628	MAIRE	2001-03-17 00:00:00	2001	2008-03-16 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6046	2629	MAIRE	2001-03-17 00:00:00	2001	2008-03-17 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6047	2631	MAIRE	2001-03-17 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6053	2632	MAIRE	2001-03-17 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6013	2634	MAIRE	2001-03-17 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6101	2635	MAIRE	2001-03-17 00:00:00	2001	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6056	2636	MAIRE	2001-03-17 00:00:00	2001	2008-03-16 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6067	2638	MAIRE	2001-03-17 00:00:00	2001	2008-03-21 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6068	2639	MAIRE	2001-03-17 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6018	2640	MAIRE	2001-03-17 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6116	2642	MAIRE	2001-03-18 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6021	2643	MAIRE	2001-03-17 00:00:00	2001	\N	2002	ANCIEN	\N	\N	\N	NON	\N	\N
6028	2644	MAIRE	2001-03-17 00:00:00	2001	2022-10-18 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6044	2646	MAIRE	2001-03-17 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6246	2648	MAIRE	2001-03-17 00:00:00	2001	2008-03-17 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11315	11225	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6050	2651	MAIRE	2001-03-17 00:00:00	2001	2008-03-17 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6014	2652	MAIRE	2001-03-17 00:00:00	2001	2020-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6147	2653	MAIRE	2001-03-17 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6022	2323	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6022	2655	MAIRE	2001-03-17 00:00:00	2001	2008-11-12 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6164	2656	MAIRE	2001-03-17 00:00:00	2001	2008-03-17 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6160	2657	MAIRE	2001-03-17 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6184	2658	MAIRE	2001-03-17 00:00:00	2001	2008-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6108	2659	MAIRE	2001-03-17 00:00:00	2001	2008-03-16 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6247	2660	CONSMUNI	2001-03-18 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6020	2661	MAIRE	2001-03-17 00:00:00	2001	2008-03-21 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6122	2662	MAIRE	1976-03-17 00:00:00	1976	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6077	2663	MAIRE	2001-03-17 00:00:00	2001	2022-08-20 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6079	2664	MAIRE	2001-03-17 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6155	2665	MAIRE	2001-03-17 00:00:00	2001	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6127	2666	MAIRE	2001-03-17 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6084	2667	MAIRE	2001-03-17 00:00:00	2001	2008-03-16 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6248	2668	MAIREADJOINT	2001-03-11 00:00:00	2001	2010-07-25 00:00:00	2010	ANCIEN	\N	\N	\N	NON	\N	\N
6249	2669	CONSMUNI	2001-03-18 00:00:00	2001	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6250	2670	CONSMUNI	2001-03-18 00:00:00	2001	2001-03-25 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6251	2671	CONSMUNI	2001-03-18 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6180	2675	MAIRE	2001-03-17 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6038	2674	MAIRE	2001-03-17 00:00:00	2001	2001-06-01 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6252	2676	CONSMUNI	2001-03-11 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6157	2677	MAIRE	2001-03-17 00:00:00	2001	\N	2005	ANCIEN	\N	\N	\N	NON	\N	\N
6158	2679	MAIRE	2001-03-17 00:00:00	2001	2008-03-16 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6027	2328	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6027	2681	MAIRE	2001-03-17 00:00:00	2001	2003-01-27 00:00:00	2003	ANCIEN	\N	\N	\N	NON	\N	\N
6100	2682	MAIRE	2001-03-17 00:00:00	2001	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6104	2683	MAIRE	2001-03-17 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6107	2684	MAIRE	2001-03-17 00:00:00	2001	2001-07-01 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6114	2685	MAIRE	2001-03-17 00:00:00	2001	2021-09-28 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6186	2686	MAIRE	2001-03-17 00:00:00	2001	2008-03-16 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6118	2688	MAIREADJOINT	2001-03-24 00:00:00	2001	2008-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6126	2689	MAIRE	2001-03-17 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6129	2431	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6129	2690	MAIRE	2001-03-17 00:00:00	2001	2007-09-03 00:00:00	2007	ANCIEN	\N	\N	\N	NON	\N	\N
6131	2692	MAIRE	2001-03-17 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6168	2693	MAIRE	2001-03-17 00:00:00	2001	2014-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-09 17:05:22
6133	2694	MAIRE	2001-03-17 00:00:00	2001	2008-03-16 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6136	2695	MAIRE	2001-03-17 00:00:00	2001	2021-12-17 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6138	2696	MAIRE	2001-03-17 00:00:00	2001	2008-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6188	2697	MAIRE	2001-03-17 00:00:00	2001	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6008	2698	MAIRE	2001-03-17 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6154	2699	MAIRE	2001-03-17 00:00:00	2001	2013-01-23 00:00:00	2013	ANCIEN	\N	\N	\N	NON	\N	\N
6173	2700	MAIRE	2001-03-17 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6040	2701	MAIRE	2001-03-17 00:00:00	2001	2014-06-08 00:00:00	2014	ANCIEN	\N	\N	\N	NON	\N	\N
6043	2702	MAIRE	2001-03-17 00:00:00	2001	2004-10-04 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6159	2703	MAIRE	2001-03-17 00:00:00	2001	2008-03-21 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6058	2356	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6058	2704	MAIRE	2001-03-17 00:00:00	2001	2008-03-16 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6059	2705	MAIRE	2001-03-17 00:00:00	2001	2014-03-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-09 10:37:37
6074	2371	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6074	2706	MAIRE	2001-03-17 00:00:00	2001	2020-12-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6076	2707	MAIRE	2001-03-17 00:00:00	2001	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6254	2709	CONSGENE	2001-03-11 00:00:00	2001	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6256	2710	CONSMUNI	2001-03-18 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6258	2711	CONSMUNI	2001-03-11 00:00:00	2001	2009-04-11 00:00:00	2009	ANCIEN	\N	\N	\N	NON	\N	\N
6259	2713	CONSMUNI	2001-03-18 00:00:00	2001	2021-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6274	2736	CONSMUNI	2001-03-18 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6272	2734	CONSMUNI	2001-03-11 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6261	2716	CONSGENE	2001-03-18 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6262	2717	CONSGENE	2001-03-18 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6109	2719	MAIRE	2001-03-17 00:00:00	2001	2008-03-16 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6263	2721	CONSGENE	2001-03-11 00:00:00	2001	2011-10-27 00:00:00	2011	ANCIEN	\N	\N	\N	NON	\N	\N
6264	2722	CONSMUNI	2001-03-18 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6265	2725	CONSMUNI	2001-03-11 00:00:00	2001	2020-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6266	2726	CONSGENE	2001-03-11 00:00:00	2001	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6267	2727	CONSGENEPARI	2001-03-18 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6268	2728	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6139	2730	MAIRE	2001-03-24 00:00:00	2001	2006-06-29 00:00:00	2006	ANCIEN	\N	\N	\N	NON	\N	\N
6270	2731	CONSMUNI	2001-03-18 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6271	2732	CONSMUNI	2001-03-11 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6220	2737	MAIRE	2001-03-24 00:00:00	2001	2003-03-29 00:00:00	2003	ANCIEN	\N	\N	\N	NON	\N	\N
6065	2738	PDTGEN	2001-03-23 00:00:00	2001	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6254	2739	PDTGEN	2001-03-23 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6034	2740	PDTGEN	2001-03-23 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6034	2335	VICPDTGEN	\N	1988	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
5195	2742	PDTGEN	2001-03-23 00:00:00	2001	2008-03-20 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6266	2743	PDTGEN	2001-03-23 00:00:00	2001	2004-04-01 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6024	2746	PDTGEN	2001-03-23 00:00:00	2001	2008-03-20 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6275	2747	CONSGENE	2001-03-11 00:00:00	2001	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6275	2748	PDTGEN	2001-03-23 00:00:00	2001	\N	2002	ANCIEN	\N	\N	\N	NON	\N	\N
1467	2749	PDTGEN	2001-03-23 00:00:00	2001	2004-04-01 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
5102	2751	PDTGEN	2001-03-23 00:00:00	2001	2004-03-28 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
775	775	MAIREADJOINT	\N	1992	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
776	776	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
779	779	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
780	780	MAIRE	\N	\N	2000-05-24 00:00:00	2000	ANCIEN	\N	\N	\N	NON	\N	\N
781	781	MAIRE	\N	\N	1999-03-20 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
783	783	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
786	786	MAIREADJOINT	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
787	787	MAIRE	\N	1977	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
791	791	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
792	792	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
794	794	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
797	797	CONSMUNI	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
798	798	CONSMUNI	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
799	799	CONSMUNI	\N	1983	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
800	800	MAIREADJOINT	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
582	582	MAIREADJOINT	1983-03-13 00:00:00	1983	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
583	583	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
584	584	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
585	585	MAIRE	\N	1971	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
587	587	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
588	588	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
590	590	CONSMUNI	\N	\N	2001-10-15 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
592	592	MAIRE	\N	\N	2001-09-04 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
593	593	MAIRE	\N	1977	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
594	594	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
596	596	MAIRE	\N	1977	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
600	600	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
601	601	MAIRE	\N	\N	2000-06-21 00:00:00	2000	ANCIEN	\N	\N	\N	NON	\N	\N
602	602	MAIRE	\N	\N	2016-05-01 00:00:00	2016	ANCIEN	\N	\N	\N	NON	\N	\N
604	604	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
605	605	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
607	607	MAIRE	\N	1979	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
609	609	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
611	611	CONSMUNI	\N	\N	2008-11-27 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
613	613	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
615	615	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
616	616	MAIRE	2008-03-16 00:00:00	2008	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
619	619	MAIREADJOINT	\N	\N	2023-04-05 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
621	621	MAIRE	\N	\N	2021-02-12 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
624	624	MAIRE	\N	1977	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
625	625	MAIRE	\N	\N	2010-02-27 00:00:00	2010	ANCIEN	\N	\N	\N	NON	\N	\N
627	627	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
628	628	MAIRE	\N	\N	2000-12-13 00:00:00	2000	ANCIEN	\N	\N	\N	NON	\N	\N
629	629	CONSMUNI	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
631	631	CONSMUNI	\N	\N	2000-03-18 00:00:00	2000	ANCIEN	\N	\N	\N	NON	\N	\N
632	632	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
633	633	MAIRE	\N	\N	2012-01-13 00:00:00	2012	ANCIEN	\N	\N	\N	NON	\N	\N
635	635	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
636	636	MAIRE	\N	\N	2010-12-20 00:00:00	2010	ANCIEN	\N	\N	\N	NON	\N	\N
638	638	CONSMUNI	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
639	639	MAIRE	\N	\N	2010-08-11 00:00:00	2010	ANCIEN	\N	\N	\N	NON	\N	\N
641	641	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
642	642	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
644	644	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
645	645	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
648	648	CONSMUNI	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
649	649	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
650	650	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
652	652	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
653	653	CONSMUNI	\N	1983	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
654	654	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
656	656	CONSMUNI	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
657	657	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
658	658	CONSMUNI	\N	\N	2016-08-19 00:00:00	2016	ANCIEN	\N	\N	\N	NON	\N	\N
1502	1502	PDTREG	\N	\N	2004-04-02 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
1486	1486	VICPDTREG	\N	\N	1999-02-17 00:00:00	1999	ANCIEN	\N	\N	\N	NON	\N	\N
1488	1488	VICPDTREG	\N	\N	2010-03-21 00:00:00	2010	ANCIEN	\N	\N	\N	NON	\N	\N
1493	1493	VICPDTREG	\N	\N	2004-04-01 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
1496	1496	VICPDTREG	\N	\N	2001-04-13 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
1489	1489	VICPDTREG	\N	\N	2009-12-08 00:00:00	2009	ANCIEN	\N	\N	\N	NON	\N	\N
1673	1673	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
1674	1674	DEPUTE	1956-01-02 00:00:00	1956	1958-12-08 00:00:00	1958	ANCIEN	\N	\N	\N	NON	\N	2016-12-08 15:02:51
14025	49337	CONSMUNI	2017-04-08 00:00:00	\N	2020-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-10 17:08:20	2017-08-10 17:09:01
50788	50081	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-09 03:43:56	\N
50789	50082	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-09 03:44:04	\N
1680	1680	DEPUTE	\N	\N	\N	1976	ANCIEN	\N	\N	\N	NON	\N	\N
1682	1682	DEPUTE	1986-03-16 00:00:00	1986	1988-05-14 00:00:00	1988	ANCIEN	\N	\N	\N	NON	\N	2016-12-08 18:15:38
1683	1683	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
1684	1684	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
1686	1686	DEPUTE	1968-11-13 00:00:00	1968	1980-09-28 00:00:00	1980	ANCIEN	\N	\N	\N	NON	\N	\N
50790	50083	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-09 03:44:04	\N
1689	1689	DEPUTE	1993-05-02 00:00:00	1993	1995-07-17 00:00:00	1995	ANCIEN	\N	\N	\N	NON	\N	2017-06-15 10:48:58
1692	1692	DEPUTE	1986-03-16 00:00:00	1986	1988-05-14 00:00:00	1988	ANCIEN	\N	\N	\N	NON	\N	\N
1702	1702	DEPUTE	1958-12-09 00:00:00	1958	1962-10-09 00:00:00	1962	ANCIEN	\N	\N	\N	NON	\N	2016-12-08 15:04:22
1703	1703	DEPUTE	1988-07-29 00:00:00	1988	1992-10-01 00:00:00	1992	ANCIEN	\N	\N	\N	NON	\N	2017-06-15 10:49:33
1705	1705	DEPUTE	1973-03-11 00:00:00	\N	1977-05-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2016-12-13 10:50:12
1706	1706	DEPUTE	1986-03-16 00:00:00	1986	1992-10-01 00:00:00	1992	ANCIEN	\N	\N	\N	NON	\N	\N
1708	1708	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
1709	1709	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
1713	1713	DEPUTE	\N	2002	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
1715	1715	DEPUTE	1986-03-16 00:00:00	1986	1988-05-14 00:00:00	1988	ANCIEN	\N	\N	\N	NON	\N	2016-12-08 18:14:23
1718	1718	DEPUTE	\N	1973	\N	1981	ANCIEN	\N	\N	\N	NON	\N	\N
1450	1450	PDTGEN	\N	1998	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1451	1451	VICPDTGEN	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1453	1453	CONSGENE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1454	1454	PREVICPDTGEN	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1455	1455	CONSGENE	2004-03-28 00:00:00	2004	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
1458	1458	CONSGENE	\N	1994	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1459	1459	PDTGEN	\N	\N	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1461	1461	CONSGENE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1462	1462	PDTGEN	\N	\N	2000-07-12 00:00:00	2000	ANCIEN	\N	\N	\N	NON	\N	\N
1463	1463	PDTGEN	1988-10-07 00:00:00	1988	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1464	1464	VICPDTGEN	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1466	1466	CONSGENE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1468	1468	CONSGENE	\N	\N	2004-03-28 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
1469	1469	CONSGENE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1472	1472	CONSGENE	1982-03-21 00:00:00	1982	\N	1992	ANCIEN	\N	\N	\N	NON	\N	\N
1473	1473	VICPDTGEN	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1474	1474	CONSGENE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1475	1475	PDTGEN	\N	1977	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1476	1476	PDTGEN	\N	1982	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1478	1478	VICPDTGEN	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1479	1479	PDTGEN	\N	1992	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1480	1480	VICPDTGEN	\N	\N	2001-03-18 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1482	1482	CONSGENE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1483	1483	PDTGEN	\N	1992	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1484	1484	CONSGENE	\N	\N	\N	2000	ANCIEN	\N	\N	\N	NON	\N	\N
1448	1448	VICPDTGEN	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1339	1339	PDTGEN	\N	1992	2001-03-22 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1340	1340	VICPDTGEN	1985-03-17 00:00:00	1985	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1341	1341	PDTGEN	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1342	1342	CONSGENE	\N	1973	\N	1982	ANCIEN	\N	\N	\N	NON	\N	\N
1343	1343	VICPDTGEN	\N	1990	2001-03-18 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1344	1344	CONSGENE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
10538	3626	CONSMUNI	\N	1977	\N	1983	ANCIEN	\N	\N	\N	NON	\N	\N
10538	3627	MAIREADJOINT	\N	1983	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
10538	3628	MAIRE	1995-06-16 00:00:00	1995	2008-03-18 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
10550	10542	CONSMUNI	\N	1977	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10551	10544	MAIRE	\N	1977	2006-04-29 00:00:00	2006	ANCIEN	\N	\N	\N	NON	\N	\N
10552	10547	VICPDTREG	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10552	10548	CONSREG	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10553	10549	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10554	10550	CONSGENE	\N	1982	\N	1985	ANCIEN	\N	\N	\N	NON	\N	\N
10555	10551	CONSMUNI	\N	1983	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
10556	10552	CONSGENE	\N	1961	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
703	703	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
712	712	MAIREARR	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
716	716	CONSMUNI	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
725	725	CONSMUNI	\N	1995	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
729	729	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	OUI	\N	\N
735	735	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
740	740	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
744	744	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
748	748	MAIREADJOINT	\N	1977	2000-03-30 00:00:00	2000	ANCIEN	\N	\N	\N	NON	\N	\N
755	755	MAIRE	\N	1983	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
760	760	MAIRE	\N	1977	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
766	766	MAIRE	\N	1977	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
777	777	MAIREADJOINT	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
785	785	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
790	790	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
796	796	MAIREADJOINT	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
581	581	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
586	586	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
591	591	MAIRE	\N	\N	1998-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
595	595	MAIRE	\N	1995	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
598	598	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
603	603	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
606	606	MAIRE	\N	\N	1999-02-17 00:00:00	1999	ANCIEN	\N	\N	\N	NON	\N	\N
610	610	CONSMUNI	\N	\N	2007-07-17 00:00:00	2007	ANCIEN	\N	\N	\N	NON	\N	\N
614	614	MAIRE	\N	\N	2003-11-19 00:00:00	2003	ANCIEN	\N	\N	\N	NON	\N	\N
618	618	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
623	623	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
626	626	MAIRE	2001-03-18 00:00:00	\N	2008-03-21 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
630	630	CONSMUNI	\N	1983	\N	1989	ANCIEN	\N	\N	\N	NON	\N	\N
634	634	MAIRE	\N	\N	2020-11-24 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
637	637	MAIRE	\N	\N	2014-02-21 00:00:00	2014	ANCIEN	\N	\N	\N	NON	\N	\N
640	640	MAIRE	\N	\N	2014-09-07 00:00:00	2014	ANCIEN	\N	\N	\N	NON	\N	\N
643	643	MAIRE	\N	\N	2002-11-11 00:00:00	2002	ANCIEN	\N	\N	\N	NON	\N	\N
647	647	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
651	651	MAIRE	\N	1995	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
655	655	MAIRE	\N	1977	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
660	660	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
664	664	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
668	668	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
675	675	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
679	679	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
687	687	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
692	692	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
696	696	CONSMUNI	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1485	1485	CONSREG	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
1494	1494	CONSREG	\N	1983	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1490	1490	CONSREG	\N	\N	1973-09-23 00:00:00	1973	ANCIEN	\N	\N	\N	NON	\N	\N
1500	1500	PDTREG	1988-12-19 00:00:00	\N	2002-05-08 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2016-09-16 14:45:54
1504	1504	VICPDTREG	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6155	2456	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6156	2457	CONSMUNI	2001-03-11 00:00:00	2001	2001-10-14 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
684	684	CONSMUNI	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
715	715	CONSMUNI	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6157	2458	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6158	2459	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1426	1426	CGPARIPDT	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
770	770	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6159	2460	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
709	709	CONSPARI	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
795	795	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
750	750	CONSMUNI	\N	1993	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
793	793	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
732	732	MAIRE	\N	1971	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	OUI	\N	\N
6162	2462	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-18 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6163	2463	CONSGENE	2001-03-11 00:00:00	2001	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
782	782	MAIREADJOINT	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
771	771	CONSMUNI	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6164	2464	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6165	2465	CONSMUNI	2001-03-11 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6167	2467	CONSMUNI	2001-03-11 00:00:00	2001	2008-03-21 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6168	2468	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
723	723	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5007	2003	MAIRE	1995-05-18 00:00:00	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6171	2470	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6173	2471	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6174	2472	CONSMUNI	2001-03-11 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6176	2474	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-25 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6401	3057	DEPUTE	1973-03-11 00:00:00	1973	1978-04-02 00:00:00	1978	ANCIEN	\N	\N	\N	NON	\N	2016-12-12 17:28:37
6590	3058	DEPUTE	1978-03-19 00:00:00	1978	1981-05-22 00:00:00	1981	ANCIEN	\N	\N	\N	NON	\N	\N
6430	3062	CONSMUNI	2001-03-11 00:00:00	2001	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6592	3063	CONSMUNI	\N	1995	\N	1996	ANCIEN	\N	\N	\N	NON	\N	\N
6578	3064	MAIREADJOINT	2001-03-18 00:00:00	2001	2008-03-21 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6581	3065	MAIREADJOINT	2001-03-23 00:00:00	2001	2014-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-07 11:35:22
6595	3066	CONSGENE	1976-03-14 00:00:00	1976	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6597	3068	VICPDTGEN	\N	1992	2004-04-01 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6435	3071	VICPDTGEN	\N	1992	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
6434	3070	MAIREADJOINT	\N	1997	2008-03-21 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6484	3072	CONSMUNI	1989-03-19 00:00:00	1989	1995-06-18 00:00:00	1995	ANCIEN	\N	\N	\N	NON	\N	\N
6600	3073	VICPDTGEN	\N	1976	2008-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11396	11374	DEPUTE	1986-03-16 00:00:00	1986	1986-04-01 00:00:00	1986	ANCIEN	\N	\N	\N	NON	\N	\N
6435	3075	CONSGENE	\N	1998	2008-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6610	3077	MAIRE	\N	1971	\N	1989	ANCIEN	\N	\N	\N	NON	\N	\N
6612	3078	CONSREG	\N	1985	\N	1997	ANCIEN	\N	\N	\N	NON	\N	\N
6613	3079	MAIRE	\N	1995	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6614	3080	VICPDTREG	\N	1986	\N	2002	ANCIEN	\N	\N	\N	NON	\N	\N
6615	3081	MAIRE	\N	1981	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6619	3082	CONSREG	\N	1992	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6623	3084	VICPDTREG	\N	1992	2001-11-22 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6624	3085	CONSGENE	\N	1979	\N	1985	ANCIEN	\N	\N	\N	NON	\N	\N
6625	3086	CONSGENE	1973-09-30 00:00:00	1973	\N	1988	ANCIEN	\N	\N	\N	NON	\N	\N
6626	3087	CONSREG	\N	1973	\N	1986	ANCIEN	\N	\N	\N	NON	\N	\N
6625	3088	PDTGEN	1976-03-17 00:00:00	1976	\N	1985	ANCIEN	\N	\N	\N	NON	\N	\N
6628	3089	PDTREG	\N	1979	2006-05-16 00:00:00	2006	ANCIEN	\N	\N	\N	NON	\N	\N
6546	3090	CONSGENE	\N	2001	2004-03-28 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6632	3091	CONSGENE	\N	1992	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
6634	3092	CONSREG	\N	1988	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6642	3094	MAIRE	\N	1995	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6643	3095	MAIRE	\N	1989	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
6646	3097	MAIREADJOINT	2001-03-18 00:00:00	2001	2014-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-09 22:21:29
6213	3098	CONSMUNI	2001-04-01 00:00:00	\N	2009-05-25 00:00:00	2009	ANCIEN	\N	\N	\N	NON	\N	\N
6651	3099	MAIRE	\N	1962	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6658	3105	CONSREG	1982-08-01 00:00:00	1982	1992-03-22 00:00:00	1992	ANCIEN	\N	\N	\N	NON	\N	\N
6663	3106	CONSREG	\N	1992	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6650	3104	PREVICPDTGEN	2001-03-25 00:00:00	2001	2004-03-28 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6666	3108	CONSREG	\N	1977	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
6666	3109	VICPDTREG	\N	1998	2004-03-28 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6668	3110	MAIREADJOINT	\N	1977	\N	1989	ANCIEN	\N	\N	\N	NON	\N	\N
6557	3114	CONSMUNI	2001-10-26 00:00:00	2001	2003-01-01 00:00:00	2003	ANCIEN	\N	\N	\N	NON	\N	\N
6534	3115	CONSGENE	2001-12-02 00:00:00	2001	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6596	3116	CONSREG	2001-12-02 00:00:00	2001	2002-01-02 00:00:00	2002	ANCIEN	\N	\N	\N	NON	\N	\N
6742	3120	MAIRE	2001-03-25 00:00:00	2001	2008-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6747	3121	MAIRE	2001-03-11 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6748	3122	MAIRE	1995-06-01 00:00:00	1995	2008-03-16 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
1470	1470	PDTGEN	\N	1994	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1470	3126	VICPDTGEN	\N	1992	\N	1994	ANCIEN	\N	\N	\N	NON	\N	\N
774	3124	CONSMUNI	\N	1968	\N	1983	ANCIEN	\N	\N	\N	NON	\N	\N
6752	3128	MAIRE	\N	1983	2002-06-07 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6751	3129	VICPDTGEN	\N	1979	2004-04-01 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6753	3130	CONSREG	\N	1995	\N	1988	ANCIEN	\N	\N	\N	NON	\N	\N
6762	3132	MAIRE	\N	1983	2019-07-13 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6770	3136	DEPUTE	\N	1981	\N	1986	ANCIEN	\N	\N	\N	NON	\N	\N
711	711	CONSPARI	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6771	3138	CONSMUNI	\N	1995	2008-03-26 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6772	3139	PDTGEN	\N	1989	2008-03-26 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6773	3140	CONSGENE	2002-10-20 00:00:00	\N	2008-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6027	3143	CONSMUNI	2003-01-27 00:00:00	2003	2008-03-21 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6785	3142	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6789	3144	MAIRE	\N	1982	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
6790	3145	MAIRE	\N	1995	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6791	3146	CONSGENE	\N	1994	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6791	3147	PDTGEN	\N	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6792	3148	CONSREG	\N	1998	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6794	3149	CONSMUNI	1989-03-25 00:00:00	1989	1994-12-18 00:00:00	1995	ANCIEN	\N	\N	\N	NON	\N	\N
9673	3150	DEPUTE	\N	1956	\N	1958	ANCIEN	\N	\N	\N	NON	\N	\N
50791	50084	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-09 03:44:04	\N
9688	3152	DEPUTE	\N	\N	\N	1986	ANCIEN	\N	\N	\N	NON	\N	\N
9689	3153	DEPUTE	1967-05-08 00:00:00	1967	1968-05-30 00:00:00	1968	ANCIEN	\N	\N	\N	NON	\N	2017-06-15 10:48:41
50805	50095	MAIRE	2014-03-31 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2017-09-19 15:06:25	2017-09-19 15:06:52
9691	3155	DEPUTE	1988-06-12 00:00:00	1988	1993-04-01 00:00:00	1993	ANCIEN	\N	\N	\N	NON	\N	2016-12-08 14:33:13
9692	3156	DEPUTE	\N	1981	\N	1986	ANCIEN	\N	\N	\N	NON	\N	\N
9674	3157	DEPUTE	\N	\N	\N	1958	ANCIEN	\N	\N	\N	NON	\N	\N
50806	50096	CONSREG	2010-03-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2017-09-19 15:11:47	2017-09-19 15:12:16
9675	3159	DEPUTE	\N	1948	\N	1958	ANCIEN	\N	\N	\N	NON	\N	\N
9676	3163	DEPUTE	\N	\N	\N	1958	ANCIEN	\N	\N	\N	NON	\N	\N
9698	3165	DEPUTE	\N	\N	\N	1986	ANCIEN	\N	\N	\N	NON	\N	\N
6045	2889	MAIRE	2001-04-09 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6335	2894	CONSREG	\N	1992	\N	1999	ANCIEN	\N	\N	\N	NON	\N	\N
6338	2899	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-18 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6162	2905	MAIREADJOINT	2001-03-18 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6345	2910	CONSGENEPARI	2001-03-18 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6360	2919	MAIRE	1993-06-13 00:00:00	1993	2001-03-25 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6372	2923	CONSREG	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6383	2926	DEPUTE	1997-06-01 00:00:00	1997	2001-09-30 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	2017-06-15 10:49:00
6415	2941	MAIRE	\N	1989	2014-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-10-30 11:26:45
6422	2945	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6430	2948	MAIRE	\N	1989	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6441	2953	MAIRE	\N	1971	2006-05-16 00:00:00	2006	ANCIEN	\N	\N	\N	NON	\N	\N
6447	2957	MAIRE	\N	1977	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6457	2962	CONSGENE	\N	1979	\N	2002	ANCIEN	\N	\N	\N	OUI	\N	\N
6478	2966	MAIRE	2001-03-23 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6487	2970	PDTREG	\N	1992	2004-04-02 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6492	2973	MAIRE	2001-03-23 00:00:00	2001	2008-03-14 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6501	2979	DEPUTE	1993-05-01 00:00:00	1993	1997-04-21 00:00:00	1997	ANCIEN	\N	\N	\N	NON	\N	2016-12-12 10:28:36
6516	2985	CONSREG	1992-03-22 00:00:00	1992	1998-03-15 00:00:00	1998	ANCIEN	\N	\N	\N	NON	\N	\N
6522	2989	CONSGENE	1982-03-21 00:00:00	1982	2001-12-08 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6532	2994	DEPUTE	1978-03-19 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2016-12-12 12:14:46
6538	2998	VICPDTREG	1998-03-15 00:00:00	1998	2001-10-15 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6544	3004	MAIRE	\N	1971	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
6549	3008	MAIRE	\N	1971	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6416	3011	CONSGENE	\N	1992	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
6476	3017	PDTREG	\N	1992	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
6558	3021	CONSGENE	\N	1999	\N	2014	ANCIEN	\N	\N	\N	NON	\N	2015-01-21 17:52:17
6565	3026	DEPUTE	1993-03-28 00:00:00	1993	1997-04-21 00:00:00	1997	ANCIEN	\N	\N	\N	NON	\N	2016-12-12 15:38:37
6569	3030	VICPDTREG	\N	1985	\N	1988	ANCIEN	\N	\N	\N	NON	\N	\N
6572	3034	MAIRE	\N	1983	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6510	3038	CONSGENE	\N	1979	\N	1994	ANCIEN	\N	\N	\N	NON	\N	\N
6637	3093	PDTGEN	\N	\N	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
6644	3096	VICPDTGEN	\N	1988	2001-10-15 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6652	3101	DEPUTE	1973-04-02 00:00:00	1981	1978-04-01 00:00:00	1986	ANCIEN	\N	\N	\N	NON	\N	2017-06-15 10:48:23
6665	3107	CONSMUNI	\N	1995	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6670	3112	CONSMUNI	\N	2001	2002-02-01 00:00:00	2002	ANCIEN	\N	\N	\N	NON	\N	\N
6742	3119	CONSMUNI	\N	1977	2001-03-25 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1470	3125	CONSGENE	\N	1985	\N	1992	ANCIEN	\N	\N	\N	NON	\N	\N
6750	3127	VICPDTREG	\N	1985	\N	1992	ANCIEN	\N	\N	\N	NON	\N	\N
6235	3135	PDTGEN	2002-06-24 00:00:00	\N	2008-03-21 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
9711	3180	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
9717	3187	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
9680	3190	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
9722	3193	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
9682	3196	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
9684	3206	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
9734	3209	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
9685	3216	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
9743	3219	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10055	3225	MAIRE	\N	\N	2010-10-31 00:00:00	2010	ANCIEN	\N	\N	\N	NON	\N	\N
10058	3228	MAIRE	\N	\N	2005-09-22 00:00:00	2005	ANCIEN	\N	\N	\N	NON	\N	\N
10062	3232	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10065	3235	MAIRE	\N	\N	2020-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10068	3238	MAIRE	\N	\N	2018-11-19 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10071	3241	MAIREADJOINT	\N	\N	2013-06-10 00:00:00	2013	ANCIEN	\N	\N	\N	NON	\N	\N
10075	3245	CONSMUNI	\N	\N	2017-01-28 00:00:00	2017	ANCIEN	\N	\N	\N	NON	\N	\N
10078	3248	MAIRE	\N	\N	2001-10-18 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
10109	3279	CONSMUNI	\N	\N	2003-11-13 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10113	3283	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10116	3286	CONSMUNI	\N	\N	2013-03-13 00:00:00	2013	ANCIEN	\N	\N	\N	NON	\N	\N
10120	3290	MAIREADJOINT	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10123	3293	MAIRE	\N	\N	2011-10-27 00:00:00	2011	ANCIEN	\N	\N	\N	NON	\N	\N
10127	3297	CONSMUNI	\N	\N	2012-07-30 00:00:00	2012	ANCIEN	\N	\N	\N	NON	\N	\N
10130	3300	MAIRE	\N	\N	2016-03-03 00:00:00	2016	ANCIEN	\N	\N	\N	NON	\N	\N
10133	3303	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10136	3306	MAIRE	\N	\N	1999-07-22 00:00:00	1999	ANCIEN	\N	\N	\N	NON	\N	\N
10140	3310	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10144	3314	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10147	3317	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10150	3320	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10153	3323	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10156	3326	CONSMUNI	\N	\N	2008-06-08 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
10160	3330	MAIRE	\N	\N	2002-11-03 00:00:00	2002	ANCIEN	\N	\N	\N	NON	\N	\N
10164	3334	MAIRE	\N	\N	2018-08-04 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10167	3337	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10170	3340	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10173	3343	MAIRE	\N	\N	2019-08-13 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10177	3347	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10180	3350	MAIRE	\N	\N	2002-01-15 00:00:00	2002	ANCIEN	\N	\N	\N	NON	\N	\N
10184	3354	MAIRE	\N	1977	\N	1997	ANCIEN	\N	\N	\N	NON	\N	\N
10187	3357	CONSMUNI	\N	\N	2013-09-13 00:00:00	2013	ANCIEN	\N	\N	\N	NON	\N	\N
10191	3361	MAIRE	\N	\N	2002-03-04 00:00:00	2002	ANCIEN	\N	\N	\N	NON	\N	\N
10194	3364	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10197	3367	CONSMUNI	\N	\N	2014-03-03 00:00:00	2014	ANCIEN	\N	\N	\N	NON	\N	\N
10199	3369	MAIRE	\N	\N	2003-12-06 00:00:00	2003	ANCIEN	\N	\N	\N	NON	\N	\N
10206	3376	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10209	3379	CONSMUNI	\N	\N	2019-07-03 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10213	3383	CONSMUNI	\N	\N	2007-12-25 00:00:00	2007	ANCIEN	\N	\N	\N	NON	\N	\N
10216	3386	MAIRE	\N	\N	1998-07-07 00:00:00	1998	ANCIEN	\N	\N	\N	NON	\N	\N
10220	3390	PDTGEN	\N	\N	2005-09-22 00:00:00	2005	ANCIEN	\N	\N	\N	NON	\N	\N
10224	3394	VICPDTGEN	\N	\N	2021-04-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10227	3397	CONSGENE	\N	\N	2018-11-19 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10232	3402	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10236	3406	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10239	3409	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10243	3413	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10246	3416	CONSGENE	\N	\N	2006-04-13 00:00:00	2006	ANCIEN	\N	\N	\N	NON	\N	\N
10249	3419	CONSGENE	\N	\N	1998-12-12 00:00:00	1998	ANCIEN	\N	\N	\N	NON	\N	\N
10255	3425	CONSGENE	\N	\N	2000-01-28 00:00:00	2000	ANCIEN	\N	\N	\N	NON	\N	\N
10259	3429	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10263	3433	PDTGEN	\N	\N	2014-03-06 00:00:00	2014	ANCIEN	\N	\N	\N	NON	\N	\N
10266	3436	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10269	3439	CONSGENE	\N	\N	2020-02-04 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10273	3443	CONSGENE	\N	\N	2008-11-19 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
10276	3446	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10280	3450	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10283	3453	CONSGENE	\N	\N	2010-09-13 00:00:00	2010	ANCIEN	\N	\N	\N	NON	\N	\N
10287	3457	VICPDTGEN	\N	\N	1997-11-17 00:00:00	1997	ANCIEN	\N	\N	\N	NON	\N	\N
10298	3468	VICPDTGEN	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10302	3472	CONSGENE	\N	\N	2018-01-17 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2018-02-01 13:23:37
10305	3475	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10385	3525	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
50807	50097	MAIRE	2008-03-17 00:00:00	\N	2014-03-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-09-19 15:18:23	2017-09-19 15:19:10
10403	3538	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10407	3542	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10410	3545	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10413	3548	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10417	3552	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10420	3555	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10423	3558	DEPUTE	\N	\N	\N	1958	ANCIEN	\N	\N	\N	NON	\N	\N
10427	3562	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10431	3565	DEPUTE	\N	\N	\N	1997	ANCIEN	\N	\N	\N	NON	\N	\N
10434	3568	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10441	3575	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10445	3578	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10456	3582	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10465	3586	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10564	10553	CONSGENEPARI	2001-03-18 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10565	10554	CONSGENEPARI	2001-03-18 00:00:00	2001	2008-03-16 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
10566	10555	CONSGENEPARI	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
10567	10556	CONSARR	2001-03-18 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
1421	10563	VICPDTGEN	\N	\N	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
10570	10558	MAIREADJOINT	\N	1989	2010-12-17 00:00:00	2010	ANCIEN	\N	\N	\N	NON	\N	\N
10570	10559	CONSMUNI	\N	1977	2010-12-17 00:00:00	2010	ANCIEN	\N	\N	\N	NON	\N	\N
706	706	MAIREADJOINT	\N	1983	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
10572	10565	CONSREG	\N	\N	\N	2003	ANCIEN	\N	\N	\N	NON	\N	\N
6486	10567	CONSGENE	\N	1979	\N	1992	ANCIEN	\N	\N	\N	NON	\N	\N
6486	10568	CONSGENE	\N	1998	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1479	10572	CONSGENE	\N	1980	\N	1992	ANCIEN	\N	\N	\N	NON	\N	\N
10575	10570	CONSGENEPARI	\N	1983	\N	1989	ANCIEN	\N	\N	\N	NON	\N	\N
10137	3307	MAIRE	\N	\N	2003-07-04 00:00:00	2003	ANCIEN	\N	\N	\N	NON	\N	\N
10578	10573	DEPUTE	1993-03-28 00:00:00	1993	1995-09-24 00:00:00	1995	ANCIEN	\N	\N	\N	NON	\N	2016-12-08 14:26:00
1402	2791	PDTGEN	2001-03-23 00:00:00	2001	2004-01-09 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
1402	10574	CONSGENE	2004-01-09 00:00:00	2004	2004-03-28 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
1459	10582	CONSGENE	2004-01-19 00:00:00	2004	2004-03-28 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10260	3430	CONSGENE	\N	\N	2004-01-31 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10583	10584	MAIRE	2003-12-19 00:00:00	\N	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
10587	10585	MAIRE	\N	2001	2016-11-03 00:00:00	2016	ANCIEN	\N	\N	\N	NON	\N	\N
6069	10592	CONSMUNI	2004-02-02 00:00:00	\N	2004-04-23 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
5076	10581	CONSGENE	\N	2003	2004-03-21 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10588	10587	CONSGENE	1988-09-25 00:00:00	1988	\N	1994	ANCIEN	\N	\N	\N	NON	\N	\N
10588	10588	VICPDTGEN	\N	1994	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
10588	10589	CONSGENE	\N	1998	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
788	10593	MAIRE	\N	1977	2001-03-11 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10587	10591	MAIRE	\N	1971	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
10595	10595	CONSGENE	\N	1988	\N	1992	ANCIEN	\N	\N	\N	NON	\N	\N
1347	10598	CONSGENE	1982-03-11 00:00:00	1982	1990-07-10 00:00:00	1990	ANCIEN	\N	\N	\N	NON	\N	\N
10596	10597	CONSGENE	\N	1992	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
1347	1347	PDTGEN	1990-07-11 00:00:00	1990	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6360	10599	MAIRE	2001-03-25 00:00:00	2001	2009-04-26 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6650	10600	CONSGENE	1973-09-30 00:00:00	1973	2001-03-25 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
10597	10601	CONSGENE	\N	1962	1973-09-13 00:00:00	1973	ANCIEN	\N	\N	\N	NON	\N	\N
10603	10607	CONSMUNI	1995-06-21 00:00:00	1995	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6652	3102	DEPUTE	1973-04-02 00:00:00	1973	1978-04-01 00:00:00	1978	ANCIEN	\N	\N	\N	NON	\N	2017-06-15 10:48:23
6658	10604	PREVICPDTREG	1992-03-22 00:00:00	1992	1998-03-18 00:00:00	1998	ANCIEN	\N	\N	\N	NON	\N	\N
6567	10605	VICPDTGEN	\N	1994	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
10607	10610	CONSREG	2004-03-28 00:00:00	2004	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10606	10609	CONSREG	\N	1992	\N	1993	ANCIEN	\N	\N	\N	NON	\N	\N
10608	10611	CONSREG	2004-03-28 00:00:00	2004	2004-03-28 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10610	10613	CONSREG	2004-03-28 00:00:00	2004	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10611	10614	CONSREG	2004-03-28 00:00:00	2004	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10612	10615	CONSREG	2004-03-28 00:00:00	2004	2010-06-22 00:00:00	2010	ANCIEN	\N	\N	\N	NON	\N	\N
10613	10616	CONSREG	2004-03-28 00:00:00	2004	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10614	10617	CONSREG	2004-03-28 00:00:00	2004	2007-12-16 00:00:00	2007	ANCIEN	\N	\N	\N	NON	\N	\N
10615	10618	CONSGENE	2004-03-21 00:00:00	2004	2019-07-18 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10616	10619	CONSGENE	2004-03-28 00:00:00	2004	2008-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10617	10620	CONSGENE	2004-03-28 00:00:00	2004	2004-04-01 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
1363	2846	VICPDTGEN	2001-03-23 00:00:00	2001	2004-03-28 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10618	10621	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6448	3113	CONSGENE	2001-12-02 00:00:00	2001	2004-03-21 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6406	2935	VICPDTGEN	\N	1979	2004-04-01 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6406	10623	PDTGEN	2004-04-01 00:00:00	2004	2011-03-31 00:00:00	2011	ANCIEN	\N	\N	\N	NON	\N	\N
6751	10624	PDTGEN	2004-04-01 00:00:00	2004	2008-03-20 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6357	2914	PDTREG	\N	\N	2004-04-02 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10637	10664	CONSREG	2004-04-02 00:00:00	2004	2010-03-21 00:00:00	2010	ANCIEN	\N	\N	\N	NON	\N	\N
5157	10627	CONSREG	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6749	10667	CONSGENE	2004-03-21 00:00:00	2004	2022-05-07 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10639	10666	CONSREG	2004-04-02 00:00:00	2004	2010-03-21 00:00:00	2010	ANCIEN	\N	\N	\N	NON	\N	\N
6586	10630	PDTREG	2004-04-02 00:00:00	2004	2015-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2015-12-15 12:00:52
5115	2052	PDTREG	\N	\N	2004-04-02 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10638	10665	CONSREG	2004-04-02 00:00:00	2004	2004-04-07 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10635	10662	CONSREG	2004-04-02 00:00:00	2004	\N	2010	ANCIEN	\N	\N	\N	NON	\N	\N
6560	10633	CONSREG	2004-04-02 00:00:00	2004	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
1339	10634	CONSGENE	\N	1979	\N	1988	ANCIEN	\N	\N	\N	NON	\N	\N
1339	10635	VICPDTGEN	\N	1988	\N	1992	ANCIEN	\N	\N	\N	NON	\N	\N
10619	10636	CONSGENE	2004-03-21 00:00:00	2004	2004-03-31 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10620	10637	PDTGEN	2001-03-23 00:00:00	2001	2004-03-21 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10619	10638	PREVICPDTGEN	2004-04-01 00:00:00	2004	2015-05-03 00:00:00	2015	ANCIEN	\N	\N	\N	NON	\N	\N
10621	10639	PDTGEN	2001-03-23 00:00:00	2001	2004-03-27 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10622	10640	CONSGENE	2004-03-28 00:00:00	2004	2011-03-27 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
1460	10641	CONSGENE	\N	1982	\N	1994	ANCIEN	\N	\N	\N	NON	\N	\N
10623	10642	CONSGENE	2001-03-11 00:00:00	2001	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
10623	10643	VICPDTGEN	2001-03-23 00:00:00	2001	2004-01-22 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10623	10644	PDTGEN	2004-01-22 00:00:00	2004	2004-03-27 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10624	10645	CONSGENE	2004-03-28 00:00:00	2004	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10625	10646	CONSGENE	2004-04-01 00:00:00	2004	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10626	10647	CONSGENE	2004-04-01 00:00:00	\N	2014-03-30 00:00:00	2014	ANCIEN	\N	\N	\N	NON	\N	2015-01-21 18:03:22
10627	10648	CONSGENE	2008-03-21 00:00:00	\N	2014-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-05-26 14:24:58
10627	10649	PDTGEN	2004-04-01 00:00:00	2004	2008-03-20 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10628	10650	CONSGENE	2004-03-28 00:00:00	2004	2004-04-01 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10628	10651	PDTGEN	2004-04-01 00:00:00	2004	2006-06-01 00:00:00	2006	ANCIEN	\N	\N	\N	NON	\N	\N
10629	10652	CONSGENE	2004-03-28 00:00:00	2004	2004-04-01 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10629	10653	PREVICPDTGEN	2004-04-01 00:00:00	2004	2011-03-30 00:00:00	2011	ANCIEN	\N	\N	\N	NON	\N	\N
10630	10654	CONSGENE	2004-03-28 00:00:00	2004	2004-04-01 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10630	10655	VICPDTGEN	2004-04-01 00:00:00	2004	2011-03-27 00:00:00	2011	ANCIEN	\N	\N	\N	NON	\N	\N
10631	10656	CONSGENE	2004-03-21 00:00:00	2004	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
10632	10658	CONSGENE	2004-03-21 00:00:00	2004	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10633	10659	PREVICPDTGEN	2008-03-21 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
5102	2752	CONSGENE	\N	1998	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1475	2753	PDTGEN	2001-03-23 00:00:00	2001	2004-04-01 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6006	2754	PDTGEN	2001-03-23 00:00:00	2001	2004-04-01 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6163	2755	PDTGEN	2001-03-23 00:00:00	2001	2020-09-11 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
1382	2756	PDTGEN	2001-03-23 00:00:00	2001	2004-03-21 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6095	2757	PDTGEN	2001-03-23 00:00:00	2001	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6095	2402	CONSGENE	2001-03-11 00:00:00	2001	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6089	2762	PDTGEN	2001-03-23 00:00:00	2001	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6277	2759	CONSGENE	\N	\N	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6277	2760	PDTGEN	\N	\N	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1450	2761	PDTGEN	2001-03-23 00:00:00	2001	2004-04-01 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
1407	2763	PDTGEN	2001-03-23 00:00:00	2001	2023-05-14 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
1373	2764	PDTGEN	2001-03-23 00:00:00	2001	2001-10-14 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1414	2765	PDTGEN	2001-03-23 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6278	2766	CONSREG	\N	1984	\N	1983	ANCIEN	\N	\N	\N	NON	\N	\N
6279	2767	MAIREADJOINT	\N	1983	\N	1988	ANCIEN	\N	\N	\N	NON	\N	\N
1456	2768	PDTGEN	1993-12-21 00:00:00	1993	2001-03-22 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6153	2769	PDTGEN	2001-03-23 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
1442	2770	PDTGEN	\N	1990	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6073	2771	PDTGEN	2001-03-23 00:00:00	2001	\N	2011	ANCIEN	\N	\N	\N	NON	\N	\N
6189	2772	PDTGEN	1992-04-03 00:00:00	1992	2008-03-20 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6205	2784	MAIRE	2001-03-25 00:00:00	2001	2017-07-16 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6185	2785	MAIRE	2001-03-25 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6200	2786	MAIREADJOINT	2001-03-23 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6193	2787	PDTGEN	2001-03-23 00:00:00	2001	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
5150	2788	PDTGEN	2001-03-23 00:00:00	2001	2004-03-28 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6208	2789	MAIRE	2001-03-25 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
1387	2790	PDTGEN	2001-03-23 00:00:00	2001	2004-03-21 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
1459	2792	PDTGEN	2001-03-23 00:00:00	2001	2004-01-19 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6199	2783	MAIRE	2001-03-25 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6086	2793	CONSMUNI	2001-03-25 00:00:00	2001	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6217	2794	MAIRE	2001-03-25 00:00:00	2001	2008-03-21 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6211	2795	MAIRE	2001-03-25 00:00:00	2001	2008-03-16 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6218	2796	MAIRE	2001-03-25 00:00:00	2001	2008-03-21 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6212	2797	MAIRE	2001-03-25 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6221	2798	MAIRE	2001-03-25 00:00:00	2001	2024-01-05 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6209	2799	MAIRE	2001-03-25 00:00:00	2001	2007-03-08 00:00:00	2007	ANCIEN	\N	\N	\N	NON	\N	\N
6219	2800	MAIRE	2001-03-25 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6177	2801	MAIREADJOINT	2001-03-25 00:00:00	2001	2020-05-14 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6182	2803	MAIREADJOINT	2001-03-25 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6076	2804	MAIREADJOINT	2001-03-23 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
1447	2807	CONSGENE	2001-03-23 00:00:00	2001	2004-03-28 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
1360	2810	CONSGENE	2001-03-23 00:00:00	2001	2021-12-17 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
5045	2812	VICPDTGEN	2001-03-23 00:00:00	2001	2004-03-28 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
5059	2813	VICPDTGEN	2001-03-23 00:00:00	2001	2004-03-28 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
1396	2814	CONSGENE	2001-03-18 00:00:00	2001	2001-03-22 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1404	2815	VICPDTGEN	2001-03-23 00:00:00	2001	2013-01-23 00:00:00	2013	ANCIEN	\N	\N	\N	NON	\N	\N
1399	2817	CONSGENE	2001-03-23 00:00:00	2001	2001-03-28 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1440	2818	CONSGENE	2001-03-23 00:00:00	2001	2004-03-28 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
1400	2819	CONSGENE	2001-03-23 00:00:00	2001	2001-04-06 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5174	2821	CONSGENE	2001-03-23 00:00:00	2001	2004-03-28 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6091	2823	VICPDTGEN	2001-03-23 00:00:00	2001	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
5097	2824	VICPDTGEN	2001-03-23 00:00:00	2001	2004-03-28 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6125	2825	VICPDTGEN	2001-03-23 00:00:00	2001	\N	2010	ANCIEN	\N	\N	\N	NON	\N	\N
6101	2826	MAIREADJOINT	2001-03-23 00:00:00	2001	2015-04-28 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-11-16 16:54:15
6102	2827	VICPDTGEN	2001-03-23 00:00:00	2001	2022-08-18 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
1462	2828	CONSGENE	2001-03-11 00:00:00	2001	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6281	2831	VICPDTGEN	2001-03-23 00:00:00	2001	2008-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6283	2832	CONSGENE	2001-03-18 00:00:00	2001	2001-03-27 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6284	2833	CONSGENE	2001-03-18 00:00:00	2001	2004-03-28 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6285	2834	CONSGENE	2001-03-18 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6290	2835	CONSMUNI	2001-03-18 00:00:00	2001	2001-03-25 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6290	2836	MAIREADJOINT	2001-03-25 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6092	2838	MAIREADJOINT	2001-03-23 00:00:00	2001	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6105	2839	VICPDTGEN	2001-03-23 00:00:00	2001	2004-03-28 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6105	2411	CONSGENE	2001-03-11 00:00:00	2001	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5169	2840	VICPDTGEN	2001-03-23 00:00:00	2001	2004-03-27 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2015-03-31 17:45:55
1383	2841	VICPDTGEN	2001-03-23 00:00:00	2001	2004-03-21 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
1383	1383	CONSGENE	\N	\N	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6292	2842	CONSGENE	2001-03-18 00:00:00	2001	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6292	2843	VICPDTGEN	2001-03-23 00:00:00	2001	2004-04-01 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
1396	2844	VICPDTGEN	2001-03-23 00:00:00	2001	2004-03-28 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6232	2845	PREVICPDTGEN	2001-03-23 00:00:00	2001	2008-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
5816	2167	VICPDTGEN	\N	1992	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
5820	2172	CONSREG	\N	1998	2024-03-13 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
5817	2171	CONSGENE	\N	1970	\N	1992	ANCIEN	\N	\N	\N	NON	\N	\N
5821	2173	CONSGENE	\N	1982	\N	1992	ANCIEN	\N	\N	\N	NON	\N	\N
5821	2175	CONSGENE	\N	1998	\N	1999	ANCIEN	\N	\N	\N	NON	\N	\N
5830	2184	CONSREG	\N	\N	2004-10-18 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
5822	2177	CONSMUNI	\N	1983	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
5826	2179	CONSREG	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
5827	2180	CONSREG	\N	1986	\N	1992	ANCIEN	\N	\N	\N	NON	\N	\N
5829	2182	CONSREG	\N	1998	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
5833	2185	MAIRE	\N	1995	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5834	2187	VICPDTGEN	\N	1994	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5835	2188	MAIRE	\N	1983	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
5836	2189	MAIRE	\N	1995	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5840	2191	DEPUTE	1981-06-21 00:00:00	1981	1986-04-01 00:00:00	1986	ANCIEN	\N	\N	\N	NON	\N	2016-12-08 17:17:18
5841	2192	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5843	2193	CONSMUNI	1995-06-25 00:00:00	1995	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5852	2200	CONSREG	1986-03-16 00:00:00	1986	1992-03-22 00:00:00	1992	ANCIEN	\N	\N	\N	NON	\N	\N
5849	2197	CONSPARI	\N	1989	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5851	2199	CONSARR	\N	1983	\N	1989	ANCIEN	\N	\N	\N	NON	\N	\N
5853	2201	DEPUTE	1988-07-29 00:00:00	1988	1993-04-01 00:00:00	1993	ANCIEN	\N	\N	\N	NON	\N	2016-12-12 17:44:07
5856	2202	MAIRE	2000-03-30 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
5859	2206	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
5858	2207	VICPDTGEN	\N	1982	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
5857	2205	MAIREADJOINT	2000-04-17 00:00:00	2000	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5860	2209	MAIRE	\N	1977	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
5866	2218	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
5863	2214	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
5865	2216	MAIREADJOINT	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5864	2215	CONSGENE	\N	1994	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5870	2221	PDTREG	\N	1983	2007-11-21 00:00:00	2007	ANCIEN	\N	\N	\N	NON	\N	\N
5871	2222	PDTGEN	1985-03-17 00:00:00	1985	1998-03-15 00:00:00	1998	ANCIEN	\N	\N	\N	NON	\N	\N
5872	2223	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5874	2225	CONSMUNI	2000-03-10 00:00:00	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5875	2226	MAIREADJOINT	\N	1998	2000-05-26 00:00:00	2000	ANCIEN	\N	\N	\N	NON	\N	\N
5877	2229	CONSREG	\N	\N	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
5875	2230	CONSMUNI	\N	1983	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
5034	2231	CONSGENE	\N	1998	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5034	2232	CONSGENE	\N	1982	\N	1992	ANCIEN	\N	\N	\N	NON	\N	\N
5882	2234	VICPDTREG	\N	1992	2009-05-28 00:00:00	2009	ANCIEN	\N	\N	\N	NON	\N	\N
5882	2235	CONSREG	\N	1992	2009-05-28 00:00:00	2009	ANCIEN	\N	\N	\N	NON	\N	\N
5887	2236	MAIRE	\N	1977	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5888	2237	CONSGENE	\N	1985	\N	1992	ANCIEN	\N	\N	\N	NON	\N	\N
5890	2239	CONSREG	\N	1992	\N	1992	ANCIEN	\N	\N	\N	NON	\N	\N
5894	2240	CONSMUNI	\N	1995	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
5895	2241	MAIRE	\N	1989	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
5897	2243	CONSMUNI	\N	1977	\N	1989	ANCIEN	\N	\N	\N	NON	\N	\N
5898	2244	CONSREG	\N	1992	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
5900	2245	VICPDTGEN	\N	1992	\N	1994	ANCIEN	\N	\N	\N	NON	\N	\N
5897	2247	CONSMUNI	\N	1995	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5888	2248	VICPDTGEN	\N	1992	\N	1994	ANCIEN	\N	\N	\N	NON	\N	\N
6000	2300	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6001	2301	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6005	2304	CONSGENE	2001-03-11 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6006	2305	CONSGENE	2001-03-11 00:00:00	2001	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6008	2307	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6009	2309	CONSGENE	2001-03-11 00:00:00	2001	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6010	2310	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6011	2311	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6014	2314	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6015	2315	CONSGENE	2001-03-11 00:00:00	2001	2020-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6018	2319	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6020	2321	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6021	2322	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6023	2325	CONSMUNI	2001-03-11 00:00:00	2001	2008-03-14 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6024	2326	CONSGENE	2001-03-11 00:00:00	2001	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6026	2327	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6031	2331	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6032	2333	CONSMUNI	2001-03-11 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	2014-10-09 10:33:51
6033	2334	CONSMUNI	2001-03-11 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6037	2337	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6038	2338	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6041	2340	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6042	2341	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6043	2342	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6044	2343	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6046	2345	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6047	2346	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6049	2348	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6050	2349	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6051	2350	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6054	2352	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6055	2353	CONSGENE	2001-03-11 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6056	2354	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6057	2355	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6059	2357	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6062	2360	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
724	724	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6063	2361	CONSMUNI	2001-03-11 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6064	2362	CONSGENE	2001-03-11 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6065	2363	CONSGENE	2001-03-11 00:00:00	2001	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
726	726	MAIRE	\N	1965	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6068	2365	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6069	2366	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6070	2367	CONSGENE	2001-03-11 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
789	789	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6072	2369	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
11669	13074	MAIREADJOINT	2009-07-26 00:00:00	\N	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-11-30 16:52:52
6075	2372	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
739	739	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6077	2374	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5862	2375	CONSMUNI	\N	1995	2016-03-19 00:00:00	2016	ANCIEN	\N	\N	\N	NON	\N	\N
5858	2379	CONSGENE	\N	1998	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
763	763	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6078	2380	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6079	2384	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6080	2385	CONSMUNI	2001-03-11 00:00:00	2001	2008-03-21 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
5281	2386	MAIRE	\N	1959	1999-03-20 00:00:00	1999	ANCIEN	\N	\N	\N	OUI	\N	\N
773	773	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6082	2388	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
778	778	CONSMUNI	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6083	2389	CONSMUNI	2001-03-11 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6084	2390	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6085	2391	CONSGENE	2001-03-11 00:00:00	2001	2008-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6086	2392	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
758	758	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6087	2393	CONSGENE	2001-03-11 00:00:00	2001	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6088	2395	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6089	2396	CONSGENE	2001-03-11 00:00:00	2001	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6091	2398	CONSGENE	2001-03-11 00:00:00	2001	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6092	2399	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6093	2400	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
10241	3411	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10242	3412	VICPDTGEN	\N	\N	2012-02-02 00:00:00	2012	ANCIEN	\N	\N	\N	NON	\N	\N
10244	3414	CONSGENE	\N	\N	2001-01-05 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
10245	3415	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10247	3417	CGPARIVICPDT	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10248	3418	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10250	3420	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10251	3421	CONSGENE	\N	\N	2007-09-29 00:00:00	2007	ANCIEN	\N	\N	\N	NON	\N	\N
10252	3422	VICPDTGEN	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10253	3423	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10254	3424	CONSGENE	\N	\N	2018-05-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2018-05-23 11:11:23
10256	3426	CONSGENE	\N	\N	2019-03-26 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10257	3427	VICPDTGEN	\N	\N	2012-12-07 00:00:00	2012	ANCIEN	\N	\N	\N	NON	\N	\N
10258	3428	PDTGEN	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10261	3431	VICPDTGEN	\N	\N	2003-11-13 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10262	3432	CONSGENE	\N	\N	2011-07-08 00:00:00	2011	ANCIEN	\N	\N	\N	NON	\N	\N
10264	3434	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10265	3435	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10267	3437	VICPDTGEN	\N	\N	2009-06-01 00:00:00	2009	ANCIEN	\N	\N	\N	NON	\N	\N
10268	3438	CONSGENE	\N	\N	1997-03-07 00:00:00	1997	ANCIEN	\N	\N	\N	NON	\N	\N
10270	3440	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10271	3441	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10272	3442	CONSGENE	\N	\N	2007-10-25 00:00:00	2007	ANCIEN	\N	\N	\N	NON	\N	\N
10274	3444	CONSGENE	\N	\N	1983-12-27 00:00:00	1983	ANCIEN	\N	\N	\N	NON	\N	\N
10275	3445	CONSGENE	\N	\N	1999-07-22 00:00:00	1999	ANCIEN	\N	\N	\N	NON	\N	\N
10277	3447	CONSGENE	\N	\N	2013-09-30 00:00:00	2013	ANCIEN	\N	\N	\N	NON	\N	\N
10278	3448	CONSGENE	\N	\N	2002-03-07 00:00:00	2002	ANCIEN	\N	\N	\N	NON	\N	\N
10279	3449	PDTGEN	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10281	3451	VICPDTGEN	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10282	3452	CONSGENE	\N	\N	2023-04-26 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10284	3454	PDTGEN	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10285	3455	PDTGEN	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10286	3456	CONSGENE	\N	\N	1999-08-16 00:00:00	1999	ANCIEN	\N	\N	\N	NON	\N	\N
10288	3458	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10289	3459	CONSGENE	\N	\N	2002-11-03 00:00:00	2002	ANCIEN	\N	\N	\N	NON	\N	\N
10290	3460	CONSGENE	\N	\N	2018-08-04 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10291	3461	CONSGENE	\N	\N	2001-10-30 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
10292	3462	VICPDTGEN	\N	\N	2004-08-18 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10293	3463	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10294	3464	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10295	3465	PDTGEN	\N	\N	2007-05-17 00:00:00	2007	ANCIEN	\N	\N	\N	NON	\N	\N
10296	3466	CONSGENE	\N	\N	2009-08-08 00:00:00	2009	ANCIEN	\N	\N	\N	NON	\N	\N
10297	3467	PDTGEN	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10299	3469	CONSGENE	\N	\N	2007-05-21 00:00:00	2007	ANCIEN	\N	\N	\N	NON	\N	\N
10300	3470	VICPDTGEN	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10301	3471	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10303	3473	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10304	3474	CONSGENE	\N	\N	2016-09-29 00:00:00	2016	ANCIEN	\N	\N	\N	NON	\N	\N
10306	3476	CONSGENE	\N	\N	1985-05-26 00:00:00	1985	ANCIEN	\N	\N	\N	NON	\N	\N
10307	3477	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10308	3478	PDTGEN	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10309	3479	PDTGEN	\N	\N	2005-07-15 00:00:00	2005	ANCIEN	\N	\N	\N	NON	\N	\N
10310	3480	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10311	3481	PDTGEN	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10312	3482	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10313	3483	CONSGENE	\N	\N	1996-07-09 00:00:00	1996	ANCIEN	\N	\N	\N	NON	\N	\N
10314	3484	CONSGENEPARI	\N	\N	2009-09-27 00:00:00	2009	ANCIEN	\N	\N	\N	NON	\N	\N
10315	3485	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10316	3486	CONSGENE	\N	\N	2019-07-03 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10317	3487	VICPDTGEN	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10318	3488	CONSGENE	\N	\N	2016-10-05 00:00:00	2016	ANCIEN	\N	\N	\N	NON	\N	\N
10320	3490	VICPDTGEN	\N	\N	2000-01-11 00:00:00	2000	ANCIEN	\N	\N	\N	NON	\N	\N
10321	3491	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10322	3492	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10367	3493	CONSREG	\N	\N	1996-07-21 00:00:00	1996	ANCIEN	\N	\N	\N	NON	\N	\N
10369	3494	CONSREG	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10356	3495	CONSREG	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10358	3496	CONSREG	\N	\N	2017-07-27 00:00:00	2017	ANCIEN	\N	\N	\N	NON	\N	\N
10350	3497	CONSREG	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10355	3498	CONSREG	\N	\N	2007-09-29 00:00:00	2007	ANCIEN	\N	\N	\N	NON	\N	\N
10370	3499	CONSREG	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10348	3500	CONSREG	\N	\N	2021-04-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10364	3501	CONSREG	\N	\N	2010-09-13 00:00:00	2010	ANCIEN	\N	\N	\N	NON	\N	\N
10368	3502	CONSREG	\N	\N	2016-09-29 00:00:00	2016	ANCIEN	\N	\N	\N	NON	\N	\N
10361	3503	CONSREG	\N	\N	2013-03-13 00:00:00	2013	ANCIEN	\N	\N	\N	NON	\N	\N
10351	3504	CONSREG	\N	\N	2017-09-23 00:00:00	2017	ANCIEN	\N	\N	\N	NON	\N	\N
10354	3505	CONSREG	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10372	3506	CONSREG	\N	\N	2011-01-24 00:00:00	2011	ANCIEN	\N	\N	\N	NON	\N	\N
10349	3507	CONSREG	\N	\N	2018-11-19 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10363	3508	CONSREG	\N	\N	2021-04-17 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10365	3509	CONSREG	\N	\N	2000-12-28 00:00:00	2000	ANCIEN	\N	\N	\N	NON	\N	\N
10371	3510	CONSREG	\N	\N	1998-02-09 00:00:00	1998	ANCIEN	\N	\N	\N	NON	\N	\N
10359	3511	PDTREG	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10362	3512	PDTREG	\N	\N	2011-10-27 00:00:00	2011	ANCIEN	\N	\N	\N	NON	\N	\N
10353	3513	VICPDTREG	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10366	3514	VICPDTREG	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10352	3515	VICPDTREG	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10360	3516	VICPDTREG	\N	\N	2001-03-27 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
10357	3517	VICPDTREG	\N	\N	2004-02-04 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6220	3518	CONSMUNI	2003-03-29 00:00:00	2003	2008-03-21 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
10380	3520	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
50801	50091	MAIRE	2001-03-19 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2017-09-18 18:22:26	2017-09-18 18:23:42
10382	3522	DEPUTE	\N	1945	\N	1958	ANCIEN	\N	\N	\N	NON	\N	\N
10383	3523	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10384	3524	DEPUTE	\N	\N	\N	1958	ANCIEN	\N	\N	\N	NON	\N	\N
10386	3526	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10387	3527	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
50802	50092	CONSMUNI	2014-03-31 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2017-09-18 18:28:14	2017-09-18 18:28:55
50803	50093	CONSCOMINT	2017-01-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2017-09-18 18:29:56	2017-09-18 18:30:25
1380	1380	CONSGENE	\N	\N	2002-11-11 00:00:00	2002	ANCIEN	\N	\N	\N	NON	\N	\N
10397	3532	DEPUTE	\N	\N	\N	1946	ANCIEN	\N	\N	\N	NON	\N	\N
10398	3533	DEPUTE	\N	1945	\N	1958	ANCIEN	\N	\N	\N	NON	\N	\N
50804	50094	CONSREG	2015-12-14 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2017-09-18 18:32:13	2017-09-18 18:34:25
6560	3022	VICPDTREG	\N	1998	2004-04-02 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6561	3023	VICPDTREG	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6563	3024	VICPDTREG	\N	1983	\N	1986	ANCIEN	\N	\N	\N	NON	\N	\N
6564	3025	DEPUTE	1978-03-19 00:00:00	1978	1981-05-22 00:00:00	1981	ANCIEN	\N	\N	\N	NON	\N	2016-12-12 11:02:34
6566	3027	MAIRE	\N	1971	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6567	3028	CONSGENE	\N	1982	\N	1994	ANCIEN	\N	\N	\N	NON	\N	\N
6568	3029	VICPDTGEN	\N	1998	2001-12-08 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6570	3031	DEPUTE	1986-03-16 00:00:00	1986	1988-05-14 00:00:00	1988	ANCIEN	\N	\N	\N	NON	\N	2016-12-12 15:42:34
6423	3032	CONSGENE	\N	1982	\N	1994	ANCIEN	\N	\N	\N	NON	\N	\N
6571	3033	MAIREADJOINT	\N	1983	2008-03-20 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	2014-04-09 22:40:46
6573	3035	CONSREG	\N	1986	\N	2002	ANCIEN	\N	\N	\N	NON	\N	\N
6574	3036	DEPUTE	1988-06-12 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2016-12-12 12:18:02
6575	3037	CONSMUNI	\N	1983	2001-12-08 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6577	3039	DEPUTE	1986-03-16 00:00:00	1986	1988-05-14 00:00:00	1988	ANCIEN	\N	\N	\N	NON	\N	2016-12-09 15:51:30
6578	3040	MAIREADJOINT	\N	1977	\N	1983	ANCIEN	\N	\N	\N	NON	\N	\N
6578	3041	MAIRE	\N	1983	2001-03-18 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6515	3042	CONSGENE	\N	1994	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6579	3043	CONSGENE	\N	1976	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6580	3044	DEPUTE	1981-06-21 00:00:00	\N	1991-05-18 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2016-12-12 12:19:14
6581	3045	MAIRE	\N	1965	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6582	3046	CONSREG	1986-03-16 00:00:00	1986	\N	1988	ANCIEN	\N	\N	\N	NON	\N	\N
6596	3067	VICPDTREG	\N	1998	2001-12-02 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6583	3048	MAIREADJOINT	2001-03-23 00:00:00	2001	2008-03-21 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6584	3049	CONSREG	\N	1992	2004-03-28 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6585	3051	CONSMUNI	2001-03-18 00:00:00	2001	2008-03-21 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6586	3052	CONSREG	\N	1983	2004-04-01 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	2015-12-15 12:00:52
6587	3053	MAIRE	\N	1995	\N	1997	ANCIEN	\N	\N	\N	NON	\N	\N
6588	3054	MAIREADJOINT	\N	1983	2014-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-17 11:17:28
6589	3055	CONSREG	\N	1998	2001-12-08 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
50808	50098	CONSMUNI	2014-03-23 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-19 15:29:33	2017-09-19 15:35:01
12500	13079	CONSMUNI	2012-03-23 00:00:00	\N	2014-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-17 11:57:02
10402	3537	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10404	3539	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10406	3541	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10408	3543	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10409	3544	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10411	3546	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10412	3547	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10415	3550	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10421	3556	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10425	3560	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10426	3561	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10429	3563	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10430	3564	DEPUTE	\N	\N	\N	1958	ANCIEN	\N	\N	\N	NON	\N	\N
10432	3566	DEPUTE	\N	\N	\N	1958	ANCIEN	\N	\N	\N	NON	\N	\N
10435	3569	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10436	3570	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10437	3571	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10439	3573	DEPUTE	\N	\N	\N	1958	ANCIEN	\N	\N	\N	NON	\N	\N
10440	3574	DEPUTE	\N	\N	\N	1958	ANCIEN	\N	\N	\N	NON	\N	\N
10443	3576	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10446	3579	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10447	3580	DEPUTE	\N	\N	\N	1947	ANCIEN	\N	\N	\N	NON	\N	\N
10457	3583	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10460	3584	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10466	3587	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10471	3591	DEPUTE	\N	\N	\N	1958	ANCIEN	\N	\N	\N	NON	\N	\N
6310	2884	CONSMUNI	2001-03-18 00:00:00	2001	2001-03-25 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5112	2886	CONSGENE	2001-03-11 00:00:00	2001	2004-03-21 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6213	2890	MAIRESEC	2001-04-01 00:00:00	2001	2001-04-01 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6316	2888	MAIRE	2001-04-09 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
1399	2891	VICPDTGEN	2001-03-28 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6552	3010	MAIRE	\N	1989	2001-05-15 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1400	2892	VICPDTGEN	2001-04-06 00:00:00	2001	2004-04-01 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
678	2893	MAIRE	\N	1992	\N	1996	ANCIEN	\N	\N	\N	NON	\N	\N
6004	2303	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6337	2897	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-18 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6337	2898	MAIRE	2001-03-18 00:00:00	2001	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6338	2900	MAIRE	2001-03-18 00:00:00	2001	2001-07-01 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6339	2901	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-18 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6339	2902	MAIRE	2001-03-18 00:00:00	2001	2001-12-08 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5140	2903	CONSGENE	2001-03-23 00:00:00	2001	2004-03-28 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
49628	48224	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:45	\N
6340	2904	CONSMUNI	2001-03-11 00:00:00	2001	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6341	2906	CONSMUNI	2001-03-18 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6342	2907	CONSMUNI	2001-03-11 00:00:00	2001	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6343	2908	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6346	2911	MAIRE	2001-03-23 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6348	2912	CONSGENE	2001-03-23 00:00:00	2001	2006-01-21 00:00:00	2006	ANCIEN	\N	\N	\N	NON	\N	\N
6358	2918	DEPUTE	1973-03-04 00:00:00	1973	1977-05-01 00:00:00	1977	ANCIEN	\N	\N	\N	NON	\N	2016-12-08 14:52:08
6363	2920	CONSGENE	\N	1998	2001-09-30 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6368	2921	MAIRE	\N	1989	2014-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-09 10:43:23
6371	2922	PDTGEN	1985-03-10 00:00:00	1985	2004-04-01 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6376	2924	MAIRE	1972-07-17 00:00:00	1972	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6382	2925	MAIRE	\N	1989	2006-05-12 00:00:00	2006	ANCIEN	\N	\N	\N	NON	\N	\N
6386	2927	MAIRE	\N	1983	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6390	2928	CONSGENE	\N	\N	2011-03-27 00:00:00	2011	ANCIEN	\N	\N	\N	NON	\N	\N
6398	2932	PDTGEN	\N	1979	2004-04-01 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6397	2931	VICPDTGEN	\N	\N	2004-04-01 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6405	2934	MAIRE	\N	1971	2004-03-31 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6408	2936	MAIRE	2001-03-18 00:00:00	2001	2008-03-21 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6410	2937	CONSGENE	\N	1982	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6409	2938	MAIRE	\N	1982	2001-12-08 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6412	2939	MAIRE	1989-03-12 00:00:00	\N	2017-10-22 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-11-08 15:52:51
6416	2942	VICPDTGEN	\N	1998	2004-04-01 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6418	2943	PDTREG	\N	1998	2004-04-02 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6420	2944	DEPUTE	1993-03-28 00:00:00	1993	1997-04-21 00:00:00	1997	ANCIEN	\N	\N	\N	NON	\N	2016-12-08 18:36:09
6423	2946	PDTGEN	\N	1994	2004-04-01 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6424	2947	DEPUTE	1988-06-12 00:00:00	\N	2001-09-23 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2016-12-12 12:05:55
6434	2949	MAIRE	\N	1971	\N	1997	ANCIEN	\N	\N	\N	NON	\N	\N
6435	2950	CONSGENE	\N	1987	\N	1992	ANCIEN	\N	\N	\N	NON	\N	\N
6438	2951	MAIREADJOINT	\N	1983	2001-09-29 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6439	2952	VICPDTGEN	\N	2001	2004-03-28 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6442	2954	DEPUTE	\N	1967	2001-09-30 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6445	2955	MAIRE	\N	1995	2011-11-07 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6446	2956	CONSREG	\N	1986	2001-11-30 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6448	2958	VICPDTGEN	\N	1985	2001-12-02 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6451	2959	MAIRE	2001-03-25 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6456	2961	MAIRE	\N	1983	\N	2006	ANCIEN	\N	\N	\N	NON	\N	\N
6461	2963	MAIRE	1994-05-16 00:00:00	1994	2008-03-21 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6474	2964	CONSREG	\N	1998	2001-12-08 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6476	2965	CONSREG	\N	1998	2001-10-22 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6482	2967	MAIRE	\N	1983	2008-03-21 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6484	2968	MAIREADJOINT	1995-06-18 00:00:00	1995	2001-10-19 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6486	2969	CONSGENE	2001-03-18 00:00:00	2001	2001-11-30 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6489	2971	MAIRE	1971-03-21 00:00:00	1971	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6491	2972	MAIRE	\N	1995	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6493	2974	CONSGENE	2001-03-18 00:00:00	2001	2008-03-21 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6496	2975	CONSREG	\N	1998	2004-04-02 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6498	2976	MAIRE	\N	1983	2008-03-16 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6499	2977	VICPDTGEN	\N	1985	2004-03-28 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6500	2978	MAIRE	1993-05-16 00:00:00	1993	2010-05-08 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6508	2980	MAIRE	\N	1989	2014-06-11 00:00:00	2014	ANCIEN	\N	\N	\N	NON	\N	\N
6510	2981	VICPDTGEN	\N	1994	2004-03-28 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6512	2982	MAIRE	\N	1989	2003-05-14 00:00:00	2003	ANCIEN	\N	\N	\N	OUI	\N	\N
6515	2984	PDTGEN	2001-03-23 00:00:00	2001	2004-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2015-01-21 17:55:09
6518	2986	MAIRE	\N	1983	2015-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2016-04-18 17:34:42
6520	2987	PDTGEN	2001-03-23 00:00:00	2001	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6521	2988	VICPDTREG	\N	1998	2001-12-08 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6525	2990	MAIREADJOINT	\N	1983	2008-03-16 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6527	2991	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6478	2992	CONSMUNI	\N	1977	\N	1983	ANCIEN	\N	\N	\N	NON	\N	\N
6478	2993	MAIREADJOINT	\N	1983	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
6537	2997	MAIREADJOINT	2001-03-11 00:00:00	2001	2008-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6540	2999	MAIRE	\N	1971	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
6542	3002	CONSREG	\N	1984	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6543	3003	CONSREG	\N	1983	\N	1988	ANCIEN	\N	\N	\N	NON	\N	\N
6546	3005	PDTGEN	\N	1998	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6545	3006	CONSREG	\N	1986	\N	1993	ANCIEN	\N	\N	\N	NON	\N	\N
6547	3007	DEPUTE	1993-03-28 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2016-12-12 12:18:37
6550	3009	CONSREG	1992-03-01 00:00:00	1992	1992-08-01 00:00:00	1992	ANCIEN	\N	\N	\N	NON	\N	\N
6553	3012	MAIRE	\N	1980	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6554	3014	MAIREADJOINT	\N	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6555	3015	CONSGENE	\N	1982	2001-12-08 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6557	3018	MAIRE	\N	1994	2001-10-26 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6558	3019	CONSGENE	\N	1988	\N	1991	ANCIEN	\N	\N	\N	NON	\N	2015-01-21 17:52:18
6558	3020	VICPDTGEN	\N	1992	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
6177	2475	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-25 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
704	704	MAIREADJOINT	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6178	2476	CONSMUNI	2001-03-11 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6180	2478	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6182	2479	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-25 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
685	685	MAIREADJOINT	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6184	2481	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6185	2482	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-25 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6186	2483	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6187	2484	CONSGENE	2001-03-11 00:00:00	2001	2008-03-21 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6189	2486	CONSGENE	1979-03-25 00:00:00	1979	1992-04-03 00:00:00	1992	ANCIEN	\N	\N	\N	NON	\N	\N
707	707	CONSPARI	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6190	2487	CONSMUNI	2001-03-11 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6191	2488	CONSMUNI	2001-03-18 00:00:00	2001	2024-01-10 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
5112	2050	VICPDTGEN	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1359	1359	VICPDTGEN	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6194	2531	MAIRE	\N	1977	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5195	2497	CONSGENE	2001-03-11 00:00:00	2001	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1367	2500	CONSGENE	2001-03-11 00:00:00	2001	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1371	1371	VICPDTGEN	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1371	2501	CONSGENE	2001-03-11 00:00:00	2001	2004-03-28 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
5051	2020	VICPDTGEN	\N	\N	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1434	1434	VICPDTGEN	1992-03-29 00:00:00	1992	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1434	2508	CONSGENE	2001-03-11 00:00:00	2001	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1398	1398	PDTGEN	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1400	1400	VICPDTGEN	\N	1998	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1402	2516	CONSGENE	2001-03-11 00:00:00	2001	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1407	1407	PDTGEN	\N	1982	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1441	1441	VICPDTGEN	\N	\N	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1449	1449	VICPDTGEN	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1451	2525	CONSGENE	2001-03-11 00:00:00	2001	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1467	1467	PDTGEN	1985-03-17 00:00:00	1985	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1467	2527	CONSGENE	2001-03-11 00:00:00	2001	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6193	2530	CONSGENE	2001-03-11 00:00:00	2001	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
9700	3167	DEPUTE	\N	\N	\N	1986	ANCIEN	\N	\N	\N	NON	\N	\N
50796	50089	PREMADJOINT	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-15 14:37:07	2017-09-15 14:39:29
9702	3169	DEPUTE	\N	1967	\N	1981	ANCIEN	\N	\N	\N	NON	\N	\N
9703	3170	DEPUTE	\N	1967	\N	1971	ANCIEN	\N	\N	\N	NON	\N	\N
9708	3175	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
9677	3176	DEPUTE	\N	\N	\N	1958	ANCIEN	\N	\N	\N	NON	\N	\N
9709	3177	DEPUTE	\N	\N	\N	1980	ANCIEN	\N	\N	\N	NON	\N	\N
9678	3178	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
9710	3179	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
9679	3183	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
9715	3185	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
9716	3186	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
9718	3188	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
50792	50085	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-09 03:44:15	\N
50793	50086	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-09 03:44:16	\N
9681	3194	DEPUTE	\N	\N	\N	1958	ANCIEN	\N	\N	\N	NON	\N	\N
9723	3195	DEPUTE	\N	\N	\N	1986	ANCIEN	\N	\N	\N	NON	\N	\N
50794	50087	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-09 03:44:21	\N
50799	50090	MAIREADJOINT	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-15 14:57:22	2017-09-20 15:59:40
50809	50099	PDTDPT	2015-04-02 00:00:00	\N	2017-10-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-19 15:38:13	2017-11-09 16:04:13
9683	3202	DEPUTE	\N	\N	\N	1958	ANCIEN	\N	\N	\N	NON	\N	\N
9730	3204	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
9731	3205	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
9735	3210	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
9738	3213	DEPUTE	1978-03-19 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2016-12-13 11:37:57
9739	3214	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
9740	3215	DEPUTE	1981-07-25 00:00:00	1981	1986-04-01 00:00:00	1986	ANCIEN	\N	\N	\N	NON	\N	2017-06-15 10:50:31
9686	3221	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10056	3226	MAIRE	\N	\N	2016-03-15 00:00:00	2016	ANCIEN	\N	\N	\N	NON	\N	\N
10057	3227	MAIRE	\N	\N	2006-01-23 00:00:00	2006	ANCIEN	\N	\N	\N	NON	\N	\N
10059	3229	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10060	3230	MAIRE	\N	\N	2023-11-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10061	3231	CONSMUNI	\N	\N	2013-05-21 00:00:00	2013	ANCIEN	\N	\N	\N	NON	\N	\N
10063	3233	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10064	3234	MAIRE	\N	\N	2021-04-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10066	3236	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10067	3237	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10069	3239	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10070	3240	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10073	3243	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10074	3244	MAIRE	\N	\N	2021-12-16 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10076	3246	MAIREADJOINT	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10077	3247	MAIRE	\N	\N	1999-04-06 00:00:00	1999	ANCIEN	\N	\N	\N	NON	\N	\N
10079	3249	MAIRE	\N	\N	2017-09-23 00:00:00	2017	ANCIEN	\N	\N	\N	NON	\N	\N
10080	3250	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10081	3251	MAIREADJOINT	\N	\N	2002-06-02 00:00:00	2002	ANCIEN	\N	\N	\N	NON	\N	\N
10082	3252	MAIRE	\N	\N	2009-10-22 00:00:00	2009	ANCIEN	\N	\N	\N	NON	\N	\N
10083	3253	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10084	3254	MAIRE	\N	\N	2009-03-19 00:00:00	2009	ANCIEN	\N	\N	\N	NON	\N	\N
10085	3255	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10086	3256	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10087	3257	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10088	3258	MAIRE	\N	\N	2006-04-13 00:00:00	2006	ANCIEN	\N	\N	\N	NON	\N	\N
10089	3259	CONSPARI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10090	3260	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10091	3261	MAIRE	\N	\N	1998-12-12 00:00:00	1998	ANCIEN	\N	\N	\N	NON	\N	\N
10092	3262	CONSMUNI	\N	\N	2013-05-26 00:00:00	2013	ANCIEN	\N	\N	\N	NON	\N	\N
10093	3263	MAIRE	\N	\N	2007-09-29 00:00:00	2007	ANCIEN	\N	\N	\N	NON	\N	\N
10094	3264	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10095	3265	MAIRE	\N	\N	2012-09-04 00:00:00	2012	ANCIEN	\N	\N	\N	NON	\N	\N
10096	3266	MAIRE	\N	\N	2016-06-22 00:00:00	2016	ANCIEN	\N	\N	\N	NON	\N	\N
10097	3267	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10098	3268	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10099	3269	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10100	3270	MAIRE	\N	\N	2019-03-26 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10101	3271	MAIRE	\N	\N	2012-12-07 00:00:00	2012	ANCIEN	\N	\N	\N	NON	\N	\N
10102	3272	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10103	3273	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10104	3274	MAIRE	\N	\N	1988-07-13 00:00:00	1988	ANCIEN	\N	\N	\N	NON	\N	\N
10106	3276	MAIRE	\N	\N	2004-01-31 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10107	3277	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10108	3278	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10110	3280	CONSMUNI	\N	\N	2011-07-08 00:00:00	2011	ANCIEN	\N	\N	\N	NON	\N	\N
10111	3281	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10112	3282	MAIRE	\N	\N	2014-03-06 00:00:00	2014	ANCIEN	\N	\N	\N	NON	\N	\N
10114	3284	MAIRE	\N	\N	1996-12-18 00:00:00	1996	ANCIEN	\N	\N	\N	NON	\N	\N
10115	3285	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10117	3287	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10118	3288	MAIRE	\N	\N	1997-01-22 00:00:00	1997	ANCIEN	\N	\N	\N	NON	\N	\N
10119	3289	MAIRE	\N	\N	2009-05-18 00:00:00	2009	ANCIEN	\N	\N	\N	NON	\N	\N
10121	3291	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10122	3292	MAIRE	\N	\N	2009-06-01 00:00:00	2009	ANCIEN	\N	\N	\N	NON	\N	\N
10124	3294	MAIRE	\N	\N	2020-02-04 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10125	3295	MAIRE	\N	\N	2021-07-15 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10126	3296	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10128	3298	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10129	3299	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10131	3301	MAIRE	\N	\N	2007-10-25 00:00:00	2007	ANCIEN	\N	\N	\N	NON	\N	\N
10132	3302	MAIRE	\N	\N	2004-04-07 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10134	3304	MAIRE	\N	\N	1983-12-27 00:00:00	1983	ANCIEN	\N	\N	\N	NON	\N	\N
10135	3305	MAIRE	\N	\N	2021-03-19 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10138	3308	CONSMUNI	\N	\N	2000-04-21 00:00:00	2000	ANCIEN	\N	\N	\N	NON	\N	\N
10141	3311	CONSMUNI	\N	\N	2002-03-07 00:00:00	2002	ANCIEN	\N	\N	\N	NON	\N	\N
10142	3312	MAIRE	\N	\N	2012-04-27 00:00:00	2012	ANCIEN	\N	\N	\N	NON	\N	\N
10143	3313	MAIRE	\N	\N	2004-08-19 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10145	3315	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10146	3316	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10148	3318	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10149	3319	CONSMUNI	\N	\N	2023-04-26 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10151	3321	MAIRE	\N	\N	2007-09-17 00:00:00	2007	ANCIEN	\N	\N	\N	NON	\N	\N
10152	3322	CONSMUNI	\N	\N	2007-09-05 00:00:00	2007	ANCIEN	\N	\N	\N	NON	\N	\N
10154	3324	MAIRE	\N	\N	2017-12-01 00:00:00	2017	ANCIEN	\N	\N	\N	NON	\N	\N
10155	3325	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10157	3327	CONSMUNI	\N	\N	1997-11-17 00:00:00	1997	ANCIEN	\N	\N	\N	NON	\N	\N
10158	3328	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10159	3329	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10161	3331	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10162	3332	CONSMUNI	\N	\N	2016-12-15 00:00:00	2016	ANCIEN	\N	\N	\N	NON	\N	\N
10163	3333	CONSMUNI	\N	\N	1999-06-25 00:00:00	1999	ANCIEN	\N	\N	\N	NON	\N	\N
10165	3335	MAIRE	\N	\N	2001-10-30 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
10166	3336	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10169	3339	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10171	3341	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10172	3342	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10174	3344	MAIRE	\N	\N	2003-07-03 00:00:00	2003	ANCIEN	\N	\N	\N	NON	\N	\N
10175	3345	MAIREADJOINT	\N	\N	2004-06-21 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10176	3346	MAIRE	\N	\N	2007-10-08 00:00:00	2007	ANCIEN	\N	\N	\N	NON	\N	\N
10178	3348	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10179	3349	MAIRE	\N	\N	2007-05-21 00:00:00	2007	ANCIEN	\N	\N	\N	NON	\N	\N
10181	3351	MAIRE	\N	\N	2000-12-27 00:00:00	2000	ANCIEN	\N	\N	\N	NON	\N	\N
10182	3352	CONSMUNI	\N	\N	2018-01-17 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2018-02-01 13:23:37
10183	3353	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10185	3355	MAIRE	\N	\N	2016-09-29 00:00:00	2016	ANCIEN	\N	\N	\N	NON	\N	\N
10186	3356	MAIRE	\N	\N	2011-10-24 00:00:00	2011	ANCIEN	\N	\N	\N	NON	\N	\N
10188	3358	CONSMUNI	\N	\N	2016-07-02 00:00:00	2016	ANCIEN	\N	\N	\N	NON	\N	\N
10189	3359	MAIRE	\N	\N	2011-06-18 00:00:00	2011	ANCIEN	\N	\N	\N	NON	\N	\N
10190	3360	CONSMUNI	\N	\N	2005-11-19 00:00:00	2005	ANCIEN	\N	\N	\N	NON	\N	\N
10192	3362	MAIRE	\N	\N	1985-05-26 00:00:00	1985	ANCIEN	\N	\N	\N	NON	\N	\N
10193	3363	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10195	3365	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10196	3366	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10198	3368	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10202	3372	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10203	3373	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10205	3375	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10207	3377	CONSPARI	\N	\N	2009-09-27 00:00:00	2009	ANCIEN	\N	\N	\N	NON	\N	\N
10208	3378	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10210	3380	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10211	3381	CONSMUNI	\N	\N	2013-09-03 00:00:00	2013	ANCIEN	\N	\N	\N	NON	\N	\N
10212	3382	MAIRE	\N	\N	2009-08-09 00:00:00	2009	ANCIEN	\N	\N	\N	NON	\N	\N
10214	3384	CONSMUNI	\N	\N	2018-08-13 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10215	3385	MAIRE	\N	\N	2008-06-28 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
10219	3389	CONSGENE	\N	\N	2016-03-15 00:00:00	2016	ANCIEN	\N	\N	\N	NON	\N	\N
10221	3391	CONSGENE	\N	\N	2013-05-21 00:00:00	2013	ANCIEN	\N	\N	\N	NON	\N	\N
10222	3392	PDTGEN	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10225	3395	CONSGENE	\N	\N	2020-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10226	3396	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10228	3398	VICPDTGEN	\N	\N	2014-06-01 00:00:00	2014	ANCIEN	\N	\N	\N	NON	\N	\N
10229	3399	PDTGEN	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10230	3400	VICPDTGEN	\N	\N	2004-09-29 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10231	3401	VICPDTGEN	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10233	3403	VICPDTGEN	\N	\N	2001-10-18 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
10234	3404	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10235	3405	CONSGENE	\N	\N	2017-09-23 00:00:00	2017	ANCIEN	\N	\N	\N	NON	\N	\N
10237	3407	PDTGEN	\N	\N	1989-09-17 00:00:00	1989	ANCIEN	\N	\N	\N	NON	\N	\N
10238	3408	VICPDTGEN	\N	\N	2006-03-09 00:00:00	2006	ANCIEN	\N	\N	\N	NON	\N	\N
10240	3410	CONSGENEPARI	\N	\N	2002-06-02 00:00:00	2002	ANCIEN	\N	\N	\N	NON	\N	\N
10503	3619	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10504	3620	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10505	3621	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10506	3622	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6536	2996	MAIREADJOINT	2001-03-18 00:00:00	2001	\N	2005	ANCIEN	\N	\N	\N	NON	\N	\N
10201	3371	CONSMUNI	\N	\N	2006-02-22 00:00:00	2006	ANCIEN	\N	\N	\N	NON	\N	\N
10139	3309	MAIRE	\N	\N	2006-04-25 00:00:00	2006	ANCIEN	\N	\N	\N	NON	\N	\N
11189	11132	CONSMUNI	2001-03-18 00:00:00	2001	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
10319	3489	CONSGENE	\N	\N	2006-05-18 00:00:00	2006	ANCIEN	\N	\N	\N	NON	\N	\N
11194	11133	CONSMUNI	1965-04-01 00:00:00	1965	1969-03-31 00:00:00	1969	ANCIEN	\N	\N	\N	NON	\N	\N
11194	11134	MAIREADJOINT	1969-04-01 00:00:00	1969	1983-03-31 00:00:00	1983	ANCIEN	\N	\N	\N	NON	\N	\N
11194	11135	MAIRE	1983-04-01 00:00:00	1983	2014-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-17 11:33:08
11195	11136	CONSGENE	1996-01-22 00:00:00	1996	1998-03-31 00:00:00	1998	ANCIEN	\N	\N	\N	NON	\N	\N
11195	11137	VICPDTGEN	1998-04-01 00:00:00	1998	\N	2012	ANCIEN	\N	\N	\N	NON	\N	\N
10979	11138	CONSMUNI	\N	1977	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11209	11147	DEPUTE	1973-03-11 00:00:00	1973	1978-04-02 00:00:00	1978	ANCIEN	\N	\N	\N	NON	\N	2016-12-09 14:25:22
11211	11148	CONSGENE	\N	1973	\N	1976	ANCIEN	\N	\N	\N	NON	\N	\N
11211	11149	PDTGEN	\N	1976	\N	1997	ANCIEN	\N	\N	\N	NON	\N	\N
11212	11150	MAIRE	\N	1977	\N	1997	ANCIEN	\N	\N	\N	NON	\N	\N
11212	11152	MAIREADJOINT	\N	1997	2008-03-21 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11211	11153	CONSGENE	\N	1997	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11211	11155	VICPDTGEN	\N	2004	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6031	11157	CONSMUNI	2006-02-01 00:00:00	2006	2008-03-21 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11219	11158	CONSMUNI	\N	\N	2008-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11227	11164	DEPUTE	1986-03-16 00:00:00	1986	1988-05-14 00:00:00	1988	ANCIEN	\N	\N	\N	NON	\N	2016-12-08 14:39:38
11220	11160	CONSREG	\N	2003	2010-03-21 00:00:00	2010	ANCIEN	\N	\N	\N	NON	\N	\N
11222	11161	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11222	11162	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11226	11163	DEPUTE	1971-12-05 00:00:00	1971	1973-04-01 00:00:00	1973	ANCIEN	\N	\N	\N	NON	\N	2017-06-15 10:48:39
11230	11165	CONSREG	2002-10-01 00:00:00	2002	\N	2010	ANCIEN	\N	\N	\N	NON	\N	\N
11231	11166	MAIRE	\N	1989	\N	2007	ANCIEN	\N	\N	\N	NON	\N	\N
11246	11170	MAIREADJOINT	\N	\N	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11265	11183	MAIRE	\N	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11307	11220	MAIRE	1995-06-18 00:00:00	1995	2014-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-08 16:43:39
11267	11185	MAIRE	\N	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11316	11226	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11308	11222	CONSGENE	1998-03-15 00:00:00	1998	\N	2007	ANCIEN	\N	\N	\N	NON	\N	\N
11317	11227	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11327	11246	DEPUTE	2002-12-15 00:00:00	2002	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11321	11236	MAIRE	2008-03-15 00:00:00	2008	2014-03-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-07 11:17:03
11323	11239	CONSMUNI	2008-03-11 00:00:00	2008	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11322	11238	CONSGENE	2008-03-10 00:00:00	2008	2008-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11324	11240	CONSMUNI	2008-03-10 00:00:00	2008	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11326	11244	CONSMUNI	2008-03-16 00:00:00	2008	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11253	11176	MAIREADJOINT	\N	1983	\N	1989	ANCIEN	\N	\N	\N	NON	\N	\N
11256	11177	CONSMUNI	\N	1983	2008-03-21 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11257	11178	CONSREG	\N	1986	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
11258	11179	DEPUTE	1988-06-12 00:00:00	1988	1993-04-01 00:00:00	1993	ANCIEN	\N	\N	\N	NON	\N	2016-12-13 10:45:23
11256	11180	MAIRE	\N	1989	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
11257	11181	PDTREG	\N	1998	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11256	11182	MAIREADJOINT	\N	2001	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11331	11250	DEPUTE	2002-06-16 00:00:00	2002	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11328	11248	DEPUTE	2002-06-16 00:00:00	2002	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11330	11249	DEPUTE	2002-06-16 00:00:00	2002	2007-06-25 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2016-12-12 12:12:46
6024	11251	CONSGENE	2008-03-16 00:00:00	2008	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
1434	11252	CONSGENE	2008-03-16 00:00:00	2008	2008-03-20 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6461	11258	CONSMUNI	2008-03-21 00:00:00	2008	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6189	11254	VICPDTGEN	2008-03-20 00:00:00	2008	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11332	11256	MAIRE	2008-03-22 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6376	11257	CONSMUNI	\N	2008	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6223	11259	CONSMUNI	\N	2008	2020-06-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10895	11260	MAIRE	\N	2008	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6218	11261	CONSMUNI	\N	2008	2008-04-25 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11246	11262	CONSMUNI	2008-03-21 00:00:00	2008	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6217	11263	CONSMUNI	\N	2008	2018-04-27 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2018-04-30 14:05:27
10915	11264	CONSMUNI	2008-03-21 00:00:00	2008	\N	2010	ANCIEN	\N	\N	\N	NON	\N	\N
6216	11265	CONSMUNI	\N	2008	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6020	11267	CONSMUNI	\N	2008	2008-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10885	11268	CONSMUNI	\N	2008	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6209	11269	CONSMUNI	\N	2008	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11333	11270	MAIRE	2008-03-21 00:00:00	2008	2014-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-08 14:36:02
6159	11272	CONSMUNI	\N	2008	2008-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6094	11273	CONSMUNI	2008-03-21 00:00:00	2008	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10863	11274	CONSMUNI	2008-03-22 00:00:00	2008	\N	2012	ANCIEN	\N	\N	\N	NON	\N	\N
6482	11275	CONSMUNI	2008-03-22 00:00:00	2008	2014-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-07 11:38:49
10830	11276	MAIRE	2008-03-15 00:00:00	2008	2014-03-31 00:00:00	2014	ANCIEN	\N	\N	\N	NON	\N	2014-05-05 14:45:08
10647	11278	CONSGENE	2008-03-20 00:00:00	2008	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6751	11279	VICPDTGEN	2008-03-20 00:00:00	2008	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11232	11167	PREVICPDTGEN	\N	1982	\N	1989	ANCIEN	\N	\N	\N	NON	\N	\N
11294	11204	MAIRE	\N	1983	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11294	11205	CONSMUNI	\N	1983	\N	1983	ANCIEN	\N	\N	\N	NON	\N	\N
11295	11206	CONSGENE	\N	1992	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11295	11207	PDTGEN	\N	2004	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11319	11280	CONSGENE	2008-03-20 00:00:00	2008	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11336	11304	CONSMUNI	2008-03-21 00:00:00	\N	2014-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-07 11:11:37
11337	11305	CONSMUNI	2008-03-21 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11338	11306	CONSMUNI	2008-03-14 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
1389	1389	VICPDTGEN	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1406	1406	CONSGENE	1985-03-17 00:00:00	1985	2011-03-27 00:00:00	2011	ANCIEN	\N	\N	\N	NON	\N	\N
1410	1410	CONSGENE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1414	1414	CONSGENE	\N	\N	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1422	1422	CONSGENEPARI	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1428	1428	CONSGENE	\N	\N	2001-10-18 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1433	1433	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
1439	1439	VICPDTGEN	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1724	1724	DEPUTE	1978-04-03 00:00:00	1978	1981-05-22 00:00:00	1993	ANCIEN	\N	\N	\N	NON	\N	2017-06-15 10:48:33
1726	1726	DEPUTE	1993-05-02 00:00:00	1993	1995-07-19 00:00:00	1997	ANCIEN	\N	\N	\N	NON	\N	2017-06-15 10:49:20
1729	1729	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
1732	1732	DEPUTE	1981-06-21 00:00:00	1981	1986-04-01 00:00:00	1986	ANCIEN	\N	\N	\N	NON	\N	2016-12-12 16:58:30
1735	1735	DEPUTE	1981-07-02 00:00:00	1978	1984-08-24 00:00:00	1986	ANCIEN	\N	\N	\N	NON	\N	2017-06-15 10:48:40
1745	1745	DEPUTE	1986-03-16 00:00:00	1986	1986-04-01 00:00:00	1986	ANCIEN	\N	\N	\N	NON	\N	2016-12-12 16:55:47
1748	1748	DEPUTE	1986-03-16 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
5011	2005	DEPUTE	1993-03-28 00:00:00	1993	1997-04-21 00:00:00	1997	ANCIEN	\N	\N	\N	NON	\N	2016-12-09 15:49:41
5029	2010	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5044	2016	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5059	2022	VICPDTGEN	1998-03-15 00:00:00	1998	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5075	2030	MAIRE	\N	1970	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5085	2036	DEPUTE	1993-03-28 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2016-12-12 15:39:58
5096	2041	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5104	2047	DEPUTE	1993-03-28 00:00:00	1993	1997-04-21 00:00:00	1997	ANCIEN	\N	\N	\N	NON	\N	2016-12-12 16:31:14
5129	2058	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5132	2060	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5137	2064	CONSREG	\N	1998	1998-10-27 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
5145	2069	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5155	2075	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
5169	2083	CONSGENE	\N	\N	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5102	2109	PDTGEN	\N	1992	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
5228	2113	DEPUTE	1988-06-12 00:00:00	1988	1993-04-01 00:00:00	1993	ANCIEN	\N	\N	\N	NON	\N	2016-12-09 11:44:36
5231	2116	MAIRE	\N	1982	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5238	2125	CONSREG	\N	1984	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
5136	2133	CONSGENE	\N	1998	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5250	2138	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
5254	2141	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
5258	2145	DEPUTE	1981-07-05 00:00:00	1981	1982-01-01 00:00:00	1982	ANCIEN	\N	\N	\N	NON	\N	2016-12-08 19:24:55
5260	2149	MAIRE	\N	1983	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5088	2157	CONSMUNI	\N	1983	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
1367	2164	CONSGENE	\N	1979	\N	1982	ANCIEN	\N	\N	\N	NON	\N	\N
5821	2174	PDTGEN	\N	1992	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
5825	2178	CONSREG	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
5828	2181	CONSREG	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
5834	2186	CONSGENE	\N	1982	\N	1994	ANCIEN	\N	\N	\N	NON	\N	\N
5838	2190	DEPUTE	1981-06-21 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2016-12-12 12:01:46
5844	2194	CONSREG	\N	1992	1994-02-11 00:00:00	1994	ANCIEN	\N	\N	\N	NON	\N	\N
5850	2198	MAIREADJOINT	\N	1977	\N	1983	ANCIEN	\N	\N	\N	NON	\N	\N
5860	2208	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
5862	2211	MAIRE	\N	1977	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
5869	2220	MAIRE	\N	1971	2007-11-21 00:00:00	2007	ANCIEN	\N	\N	\N	NON	\N	\N
5873	2224	CONSGENE	\N	\N	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5876	2228	VICPDTGEN	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1462	2233	VICPDTGEN	2000-07-12 00:00:00	2000	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5890	2238	VICPDTREG	\N	1992	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
5896	2242	CONSMUNI	\N	199	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
5897	2246	MAIRE	\N	1989	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
5888	2249	CONSGENE	\N	1994	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6007	2306	CONSGENE	2001-03-11 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6013	2313	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6019	2320	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6028	2329	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6040	2339	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6045	2344	CONSMUNI	2001-03-11 00:00:00	2001	2001-04-09 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6053	2351	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6060	2358	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6067	2364	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6071	2368	CONSMUNI	2001-03-11 00:00:00	2001	2001-01-18 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6076	2373	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
748	2383	MAIRE	2000-03-30 00:00:00	2000	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6081	2387	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
784	784	CONSMUNI	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6090	2397	CONSGENE	2001-03-11 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6094	2401	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6103	2408	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6108	2414	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6117	2420	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6123	2426	CONSMUNI	2001-03-11 00:00:00	2001	2008-03-21 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6127	2429	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6133	2435	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6141	2443	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
599	599	MAIRE	\N	1989	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6146	2448	CONSGENE	2001-03-11 00:00:00	2001	2008-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
1390	1390	PDTGEN	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1417	1417	CONSGENE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
673	673	MAIRE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
754	754	MAIREADJOINT	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6160	2461	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1421	1421	CONSGENEPARI	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6166	2466	CONSMUNI	2001-03-11 00:00:00	2001	2011-10-27 00:00:00	2011	ANCIEN	\N	\N	\N	NON	\N	\N
6169	2469	CONSMUNI	2001-03-11 00:00:00	2001	2021-11-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6175	2473	CONSMUNI	2001-03-11 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6179	2477	CONSMUNI	2001-03-11 00:00:00	2001	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6183	2480	CONSGENE	2001-03-11 00:00:00	2001	2008-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6188	2485	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6031	2612	MAIRE	2001-03-17 00:00:00	2001	2006-01-31 00:00:00	2006	ANCIEN	\N	\N	\N	NON	\N	\N
6082	2617	MAIRE	2001-03-17 00:00:00	2001	2023-10-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6088	2621	MAIRE	2001-03-17 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6001	2626	MAIRE	2001-03-17 00:00:00	2001	2008-03-16 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6011	2633	MAIRE	2001-03-17 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6151	2637	MAIRE	2001-03-17 00:00:00	2001	2008-03-16 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6069	2641	MAIRE	2001-03-17 00:00:00	2001	2004-02-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6075	2645	MAIRE	2001-03-17 00:00:00	2001	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6094	2649	MAIRE	2001-03-17 00:00:00	2001	2008-03-21 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6171	2654	MAIRE	2001-03-17 00:00:00	2001	2006-08-11 00:00:00	2006	ANCIEN	\N	\N	\N	NON	\N	\N
6109	2415	CONSMUNI	2001-03-11 00:00:00	2001	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6273	2735	CONSMUNI	2001-03-18 00:00:00	2001	2003-01-01 00:00:00	2003	ANCIEN	\N	\N	\N	NON	\N	\N
6087	2741	PDTGEN	2001-03-23 00:00:00	2001	2004-04-01 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
5097	2042	VICPDTGEN	\N	\N	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6281	2830	CONSGENE	2001-03-11 00:00:00	2001	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6291	2837	CONSGENEPARI	2001-03-23 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6301	2875	CONSGENE	\N	1994	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
6302	2880	VICPDTGEN	2001-03-18 00:00:00	2001	2004-03-21 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6310	2885	MAIRE	2001-03-25 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10939	10959	CONSREG	\N	1992	\N	1994	ANCIEN	\N	\N	\N	NON	\N	\N
10938	10958	CONSPARI	1983-03-06 00:00:00	1983	1989-03-12 00:00:00	1989	ANCIEN	\N	\N	\N	NON	\N	\N
10940	10961	CONSGENEPARI	\N	1983	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
10941	10962	DEPUTE	1997-07-04 00:00:00	1997	2001-02-12 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
10937	10963	MAIREADJOINT	\N	1997	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10943	10964	CONSREG	1992-03-22 00:00:00	1992	1998-03-15 00:00:00	1998	ANCIEN	\N	\N	\N	NON	\N	\N
10952	10965	MAIRE	\N	1977	2008-01-01 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
10954	10966	CONSREG	\N	1983	\N	1988	ANCIEN	\N	\N	\N	NON	\N	\N
10956	10967	CONSGENE	\N	1988	1998-01-13 00:00:00	1998	ANCIEN	\N	\N	\N	NON	\N	\N
10957	10968	CONSREG	\N	1992	\N	1994	ANCIEN	\N	\N	\N	NON	\N	\N
10958	10969	DEPUTE	1997-06-01 00:00:00	1997	2002-06-18 00:00:00	2002	ANCIEN	\N	\N	\N	NON	\N	2017-06-15 10:49:58
10960	10970	MAIREARR	1995-07-03 00:00:00	1995	2014-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-07 09:57:53
10962	10974	CONSREG	1986-03-16 00:00:00	1986	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
10961	10972	CONSGENE	1989-03-19 00:00:00	1989	\N	\N	ACTIF	\N	\N	\N	NON	\N	2017-06-29 15:55:07
10964	10975	CONSPARI	\N	1998	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11382	11352	CONSREG	1992-03-12 00:00:00	1992	\N	1992	ANCIEN	\N	\N	\N	NON	\N	\N
10971	10978	CONSMUNI	\N	1995	\N	2000	ANCIEN	\N	\N	\N	NON	\N	2014-04-09 11:08:01
10965	10977	CONSGENE	\N	1998	\N	\N	ACTIF	\N	\N	\N	NON	\N	2017-06-29 15:55:31
10971	10979	MAIREADJOINT	\N	2001	\N	2015	ANCIEN	\N	\N	\N	NON	\N	2015-06-23 11:22:21
10972	10980	CONSMUNI	\N	1989	\N	2002	ANCIEN	\N	\N	\N	NON	\N	\N
10974	10981	CONSREG	1992-03-22 00:00:00	1992	\N	1994	ANCIEN	\N	\N	\N	NON	\N	\N
10975	10982	DEPUTE	1997-06-01 00:00:00	1997	1997-07-04 00:00:00	2002	ANCIEN	\N	\N	\N	NON	\N	2017-06-15 10:51:33
10977	10983	CONSGENE	1998-03-22 00:00:00	1998	2004-03-21 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10979	10984	MAIRE	\N	1977	2006-06-30 00:00:00	2006	ANCIEN	\N	\N	\N	NON	\N	\N
10980	10985	CONSGENE	1987-04-12 00:00:00	1987	\N	1994	ANCIEN	\N	\N	\N	NON	\N	\N
10980	10986	VICPDTGEN	\N	1994	2008-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10983	10987	MAIRE	\N	1983	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10985	10988	DEPUTE	1981-06-21 00:00:00	1981	1986-04-01 00:00:00	1986	ANCIEN	\N	\N	\N	NON	\N	2016-12-13 10:02:24
10986	10989	MAIRE	\N	1995	2017-10-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-12-04 16:53:51
10988	10990	CONSGENE	1998-03-22 00:00:00	1998	2004-10-25 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10987	10991	CONSGENE	1992-03-29 00:00:00	1992	2011-03-27 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10990	10992	CONSREG	\N	1998	2010-03-21 00:00:00	2010	ANCIEN	\N	\N	\N	NON	\N	\N
10991	10993	CONSGENE	\N	1979	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
10992	10994	DEPUTE	\N	1985	\N	1986	ANCIEN	\N	\N	\N	NON	\N	\N
10993	10995	CONSMUNI	\N	1977	\N	1983	ANCIEN	\N	\N	\N	NON	\N	\N
10995	10996	MAIRE	\N	1983	2008-03-16 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
10996	10998	VICPDTGEN	1985-03-17 00:00:00	1985	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11003	10999	CONSGENE	\N	1998	\N	2003	ANCIEN	\N	\N	\N	NON	\N	\N
11003	11000	VICPDTGEN	\N	2003	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11003	11001	PDTGEN	\N	2004	2008-03-21 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11006	11002	CONSMUNI	\N	1983	\N	1989	ANCIEN	\N	\N	\N	NON	\N	\N
11010	11007	MAIRE	\N	1970	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
11005	11004	CONSGENE	1998-03-22 00:00:00	1998	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11012	11009	DEPUTE	1986-04-02 00:00:00	1986	1988-05-14 00:00:00	1997	ANCIEN	\N	\N	\N	NON	\N	2017-06-15 10:48:41
11008	11006	MAIREADJOINT	\N	1995	2004-12-23 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11011	11008	CONSGENE	\N	1970	\N	1985	ANCIEN	\N	\N	\N	NON	\N	\N
11011	11010	PDTGEN	\N	1985	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11016	11011	CONSGENE	1985-03-17 00:00:00	1985	\N	1992	ANCIEN	\N	\N	\N	NON	\N	\N
11018	11012	MAIRE	\N	1989	2011-01-01 00:00:00	2011	ANCIEN	\N	\N	\N	NON	\N	\N
11016	11013	VICPDTGEN	\N	1992	1998-03-21 00:00:00	1998	ANCIEN	\N	\N	\N	NON	\N	\N
11016	11014	CONSGENE	1998-03-22 00:00:00	1998	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
11020	11015	CONSREG	1998-03-15 00:00:00	1998	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
11023	11016	MAIRE	\N	\N	2008-03-21 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11026	11017	CONSGENE	1988-03-06 00:00:00	1988	\N	1994	ANCIEN	\N	\N	\N	NON	\N	\N
11027	11018	MAIRE	\N	1989	2008-03-16 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11026	11019	VICPDTGEN	\N	1994	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11030	11021	VICPDTGEN	\N	1994	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
11031	11022	MAIRE	\N	1989	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
11918	11728	VICPDTREG	\N	1992	\N	1993	ANCIEN	\N	\N	\N	NON	\N	\N
12009	11770	CONSGENE	\N	2004	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12066	11812	CONSREG	\N	2004	\N	2010	ANCIEN	\N	\N	\N	NON	\N	\N
10200	3370	MAIRE	\N	\N	2011-01-24 00:00:00	2011	ANCIEN	\N	\N	\N	NON	\N	\N
5144	10704	CONSREG	1998-03-16 00:00:00	1998	1998-10-05 00:00:00	1998	ANCIEN	\N	\N	\N	NON	\N	\N
10668	10705	CONSGENE	\N	1989	\N	1992	ANCIEN	\N	\N	\N	NON	\N	\N
6439	10706	CONSGENE	1998-03-22 00:00:00	1998	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
772	772	MAIRE	\N	1977	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1736	1736	DEPUTE	1991-06-01 00:00:00	1991	1993-04-01 00:00:00	1993	ANCIEN	\N	\N	\N	NON	\N	2016-12-09 15:59:31
1355	10707	VICPDTGEN	\N	1994	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
1355	10708	CONSGENE	\N	1982	\N	1994	ANCIEN	\N	\N	\N	NON	\N	\N
1408	10709	VICPDTGEN	\N	1982	\N	1992	ANCIEN	\N	\N	\N	NON	\N	\N
1408	10710	PDTGEN	1992-04-05 00:00:00	1992	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5075	10711	CONSMUNI	\N	1953	\N	1970	ANCIEN	\N	\N	\N	NON	\N	\N
10669	10712	CONSGENE	\N	1979	2008-11-12 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
672	2733	MAIRE	\N	1971	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
10670	10714	CONSREG	\N	1982	1986-03-16 00:00:00	1986	ANCIEN	\N	\N	\N	NON	\N	\N
5040	10716	MAIRE	\N	1986	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
10671	10717	CONSREG	\N	1983	1986-03-16 00:00:00	1986	ANCIEN	\N	\N	\N	NON	\N	\N
10673	10722	CONSREG	1986-03-16 00:00:00	1986	1992-03-21 00:00:00	1992	ANCIEN	\N	\N	\N	NON	\N	\N
10672	10719	CONSPARI	1989-03-19 00:00:00	1989	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
6196	10721	CONSPARI	1995-06-18 00:00:00	1995	2001-03-18 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6582	10730	VICPDTREG	\N	1988	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
10674	10724	VICPDTGEN	1985-03-17 00:00:00	1985	\N	1993	ANCIEN	\N	\N	\N	NON	\N	\N
10680	10731	DEPUTE	1986-03-16 00:00:00	1986	1988-05-14 00:00:00	1988	ANCIEN	\N	\N	\N	NON	\N	2016-12-12 11:03:05
10676	10728	CONSMUNI	2002-07-05 00:00:00	\N	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
10678	10729	CONSREG	1992-03-22 00:00:00	1992	\N	1996	ANCIEN	\N	\N	\N	NON	\N	\N
10681	10732	DEPUTE	1993-03-28 00:00:00	1993	1997-04-21 00:00:00	1997	ANCIEN	\N	\N	\N	NON	\N	2016-12-12 11:03:26
10682	10733	VICPDTGEN	\N	1988	1998-03-14 00:00:00	1998	ANCIEN	\N	\N	\N	NON	\N	\N
10683	10734	CONSGENE	1998-03-15 00:00:00	1998	2004-03-28 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10683	10735	CONSGENE	2004-03-28 00:00:00	2004	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
1409	10736	VICPDTGEN	\N	1982	1988-10-07 00:00:00	1988	ANCIEN	\N	\N	\N	NON	\N	\N
683	10737	MAIREADJOINT	\N	1983	\N	1988	ANCIEN	\N	\N	\N	NON	\N	\N
10684	10738	CONSREG	1986-03-16 00:00:00	1986	\N	1988	ANCIEN	\N	\N	\N	NON	\N	\N
10684	10739	VICPDTREG	\N	1988	1992-06-22 00:00:00	1992	ANCIEN	\N	\N	\N	NON	\N	\N
1487	11358	CONSREG	1998-03-15 00:00:00	1998	2004-03-28 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
1472	11353	VICPDTGEN	\N	1992	2001-03-18 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1472	11354	CONSGENE	2001-03-18 00:00:00	2001	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6207	11355	PREMADJOINT	1995-06-18 00:00:00	1995	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	2017-11-09 15:22:45
11157	11359	CONSGENE	1973-09-30 00:00:00	\N	1985-03-22 00:00:00	1985	ANCIEN	\N	\N	\N	NON	\N	\N
11386	11368	DEPUTE	1986-03-16 00:00:00	1986	1988-05-14 00:00:00	1988	ANCIEN	\N	\N	\N	NON	\N	\N
11157	11360	CONSGENE	\N	1988	\N	1989	ANCIEN	\N	\N	\N	NON	\N	\N
49631	48227	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:46	\N
6143	11362	MAIREADJOINT	1971-03-14 00:00:00	1971	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1487	11363	VICPDTREG	2008-03-21 00:00:00	1985	1992-03-22 00:00:00	1992	ANCIEN	\N	\N	\N	NON	\N	\N
1487	11364	CONSREG	\N	1973	1985-04-15 00:00:00	1985	ANCIEN	\N	\N	\N	NON	\N	\N
11383	11365	DEPUTE	1978-03-12 00:00:00	1978	1980-09-28 00:00:00	1980	ANCIEN	\N	\N	\N	NON	\N	\N
11393	11370	DEPUTE	1967-03-12 00:00:00	1967	1968-05-30 00:00:00	1968	ANCIEN	\N	\N	\N	NON	\N	\N
11385	11367	DEPUTE	1978-03-19 00:00:00	1978	1981-05-22 00:00:00	1981	ANCIEN	\N	\N	\N	NON	\N	\N
11394	11371	DEPUTE	1997-06-01 00:00:00	1997	2001-09-30 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	2017-06-15 10:50:26
11395	11372	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
49630	48226	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:46	\N
11492	11422	MAIRE	2001-03-18 00:00:00	\N	2017-10-15 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-10-16 10:23:35
11493	11423	CONSREG	\N	2004	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11509	11428	CONSGENE	1994-10-09 00:00:00	1994	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1497	1497	PREVICPDTREG	\N	1992	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
1495	1495	VICPDTREG	\N	\N	2007-02-25 00:00:00	2007	ANCIEN	\N	\N	\N	NON	\N	\N
1675	1675	DEPUTE	1968-06-30 00:00:00	1968	1973-04-01 00:00:00	1973	ANCIEN	\N	\N	\N	NON	\N	2016-12-12 17:03:52
1678	1678	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
1681	1681	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
1685	1685	DEPUTE	1976-09-28 00:00:00	1976	1978-04-01 00:00:00	1978	ANCIEN	\N	\N	\N	NON	\N	2017-06-15 10:49:30
49632	48228	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:46	\N
1697	1697	DEPUTE	1988-07-29 00:00:00	\N	1991-08-09 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-06-15 10:49:09
1710	1710	DEPUTE	1981-06-21 00:00:00	1981	1986-04-01 00:00:00	1986	ANCIEN	\N	\N	\N	NON	\N	2016-12-08 18:11:18
1714	1714	DEPUTE	1983-04-25 00:00:00	1983	1986-04-01 00:00:00	1986	ANCIEN	\N	\N	\N	NON	\N	2017-06-15 10:50:37
1452	1452	PDTGEN	\N	\N	1999-09-16 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
1456	1456	CONSGENE	1973-09-30 00:00:00	1973	1993-12-20 00:00:00	1993	ANCIEN	\N	\N	\N	NON	\N	\N
1460	1460	VICPDTGEN	\N	1994	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1465	1465	CONSGENE	\N	\N	1998-11-02 00:00:00	1998	ANCIEN	\N	\N	\N	NON	\N	\N
1477	1477	PDTGEN	\N	1976	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1481	1481	CONSGENE	\N	\N	2004-03-28 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
1447	1447	VICPDTGEN	\N	\N	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1346	1346	CONSGENE	\N	\N	2001-09-04 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1356	1356	PDTGEN	1994-04-01 00:00:00	1994	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1362	1362	VICPDTGEN	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1368	1368	VICPDTGEN	\N	1979	2004-03-28 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
1372	1372	PDTGEN	\N	\N	2012-01-13 00:00:00	2012	ANCIEN	\N	\N	\N	NON	\N	\N
1375	1375	CONSGENE	\N	\N	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1381	1381	CONSGENE	\N	\N	2011-03-27 00:00:00	2011	ANCIEN	\N	\N	\N	NON	\N	\N
1385	1385	CONSGENE	1996-09-22 00:00:00	1996	2004-03-28 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10710	10778	PREVICPDTREG	\N	1992	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
5059	10779	CONSGENE	\N	1973	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
10712	10780	CONSMUNI	\N	1983	\N	1989	ANCIEN	\N	\N	\N	NON	\N	\N
5836	10781	CONSMUNI	\N	1977	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
10714	10782	CONSMUNI	\N	1965	\N	1966	ANCIEN	\N	\N	\N	NON	\N	\N
10714	10783	MAIREADJOINT	\N	1966	\N	1971	ANCIEN	\N	\N	\N	NON	\N	\N
10714	10784	MAIRE	\N	1971	\N	1977	ANCIEN	\N	\N	\N	NON	\N	\N
10715	10785	CONSREG	\N	1976	\N	1979	ANCIEN	\N	\N	\N	NON	\N	\N
1463	10786	CONSGENE	\N	1973	\N	1981	ANCIEN	\N	\N	\N	NON	\N	\N
1463	10787	VICPDTGEN	\N	1981	\N	1988	ANCIEN	\N	\N	\N	NON	\N	\N
6412	10788	CONSMUNI	\N	1983	1989-03-11 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-11-08 15:52:51
6413	10789	CONSGENE	\N	1992	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6413	2940	VICPDTGEN	\N	2001	2001-12-05 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
5231	10791	MAIREADJOINT	\N	1977	\N	1982	ANCIEN	\N	\N	\N	NON	\N	\N
5062	10792	CONSMUNI	\N	1965	\N	1977	ANCIEN	\N	\N	\N	NON	\N	\N
5266	10793	VICPDTREG	\N	1979	\N	1982	ANCIEN	\N	\N	\N	NON	\N	\N
10718	10794	CONSGENE	\N	1982	\N	1988	ANCIEN	\N	\N	\N	NON	\N	\N
5062	10795	MAIREARR	\N	1983	\N	1989	ANCIEN	\N	\N	\N	NON	\N	\N
750	10796	MAIREADJOINT	\N	1995	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1497	10797	VICPDTREG	\N	2004	2015-08-10 00:00:00	2015	ANCIEN	\N	\N	\N	NON	\N	\N
743	10798	MAIREADJOINT	\N	1977	\N	1983	ANCIEN	\N	\N	\N	NON	\N	\N
5140	10799	CONSGENE	1973-09-30 00:00:00	1973	\N	1979	ANCIEN	\N	\N	\N	NON	\N	\N
5140	10800	VICPDTGEN	\N	1979	\N	1994	ANCIEN	\N	\N	\N	NON	\N	\N
10719	10801	CONSREG	\N	1981	\N	1982	ANCIEN	\N	\N	\N	NON	\N	\N
10719	10802	VICPDTREG	\N	1982	\N	1982	ANCIEN	\N	\N	\N	NON	\N	\N
10719	10803	CONSREG	\N	1982	\N	1986	ANCIEN	\N	\N	\N	NON	\N	\N
10720	10804	CONSREG	\N	1986	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
10722	10805	CONSGENE	1985-03-17 00:00:00	1985	\N	1986	ANCIEN	\N	\N	\N	NON	\N	\N
10722	10806	VICPDTGEN	1986-05-27 00:00:00	1986	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
10723	10807	CONSREG	1983-10-11 00:00:00	1983	1985-03-22 00:00:00	1985	ANCIEN	\N	\N	\N	NON	\N	\N
10724	10808	CONSREG	1986-03-16 00:00:00	1986	\N	1992	ANCIEN	\N	\N	\N	NON	\N	\N
10724	10809	VICPDTREG	\N	1992	\N	1992	ANCIEN	\N	\N	\N	NON	\N	\N
5190	10811	CONSGENE	1988-10-03 00:00:00	1988	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
5190	2091	VICPDTGEN	\N	1998	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1457	1457	CONSGENE	\N	1985	2000-04-01 00:00:00	2000	ANCIEN	\N	\N	\N	NON	\N	\N
10726	10812	CONSREG	\N	1978	\N	1992	ANCIEN	\N	\N	\N	NON	\N	\N
10727	10813	CONSREG	\N	1986	\N	1992	ANCIEN	\N	\N	\N	NON	\N	\N
5281	10814	CONSMUNI	\N	1953	\N	1959	ANCIEN	\N	\N	\N	NON	\N	\N
10728	10816	CONSREG	\N	1973	2009-04-11 00:00:00	2009	ANCIEN	\N	\N	\N	NON	\N	\N
10728	10817	PDTREG	\N	1985	2009-04-11 00:00:00	2009	ANCIEN	\N	\N	\N	NON	\N	\N
10728	10818	CONSREG	\N	1986	2009-04-11 00:00:00	2009	ANCIEN	\N	\N	\N	NON	\N	\N
10729	10819	MAIREADJOINT	\N	1977	\N	1983	ANCIEN	\N	\N	\N	NON	\N	\N
10729	10820	CONSMUNI	\N	1983	\N	1989	ANCIEN	\N	\N	\N	NON	\N	\N
5174	10821	CONSGENE	\N	1985	\N	1988	ANCIEN	\N	\N	\N	NON	\N	\N
10730	10822	CONSREG	\N	1974	\N	1979	ANCIEN	\N	\N	\N	NON	\N	\N
1350	10823	CONSGENE	\N	1994	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
1358	10824	CONSGENE	\N	1992	1998-03-11 00:00:00	1998	ANCIEN	\N	\N	\N	NON	\N	\N
5194	10825	CONSMUNI	\N	1971	\N	1977	ANCIEN	\N	\N	\N	NON	\N	\N
6456	10826	CONSMUNI	\N	1971	\N	1972	ANCIEN	\N	\N	\N	NON	\N	\N
6456	10827	MAIREADJOINT	\N	1972	\N	1983	ANCIEN	\N	\N	\N	NON	\N	\N
10736	10828	CONSREG	\N	1983	\N	1992	ANCIEN	\N	\N	\N	NON	\N	\N
1440	10829	CONSGENE	\N	1979	\N	1985	ANCIEN	\N	\N	\N	NON	\N	\N
620	10831	MAIREADJOINT	\N	1971	\N	1983	ANCIEN	\N	\N	\N	NON	\N	\N
10738	10832	CONSREG	\N	1976	\N	1988	ANCIEN	\N	\N	\N	NON	\N	\N
10739	10833	CONSGENE	\N	1982	\N	1989	ANCIEN	\N	\N	\N	NON	\N	\N
6447	10834	CONSMUNI	\N	2001	2015-04-07 00:00:00	2015	ANCIEN	\N	\N	\N	NON	\N	\N
6107	10835	CONSMUNI	2001-07-01 00:00:00	2001	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
10742	10837	DEPUTE	1973-03-11 00:00:00	1973	1978-04-02 00:00:00	1978	ANCIEN	\N	\N	\N	NON	\N	2016-12-13 10:15:01
10744	10840	DEPUTE	1981-06-14 00:00:00	1981	1981-07-23 00:00:00	1981	ANCIEN	\N	\N	\N	NON	\N	2016-12-13 10:16:03
10743	10839	DEPUTE	1978-04-03 00:00:00	1978	1981-05-22 00:00:00	1981	ANCIEN	\N	\N	\N	NON	\N	2017-06-15 10:50:47
10656	10841	CONSGENE	\N	2004	2008-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10760	10842	CONSREG	1998-03-15 00:00:00	1998	1998-03-21 00:00:00	1998	ANCIEN	\N	\N	\N	NON	\N	\N
10761	10843	VICPDTREG	1998-03-22 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10760	10844	VICPDTREG	1998-03-22 00:00:00	1998	2004-03-21 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10762	10848	PREVICPDTGEN	\N	2004	2010-11-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10762	10846	CONSGENE	\N	1988	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10760	10847	CONSREG	2004-03-22 00:00:00	2004	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10763	10849	DEPUTE	1994-11-27 00:00:00	1994	1997-04-21 00:00:00	1997	ANCIEN	\N	\N	\N	NON	\N	2017-06-15 10:50:29
10766	10850	MAIREADJOINT	\N	1981	\N	1983	ANCIEN	\N	\N	\N	NON	\N	\N
10767	10851	CONSGENE	\N	1981	\N	1982	ANCIEN	\N	\N	\N	NON	\N	\N
10767	10853	VICPDTGEN	\N	1982	\N	1992	ANCIEN	\N	\N	\N	NON	\N	\N
10766	10854	MAIRE	\N	1983	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
10767	10855	PDTGEN	\N	1992	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
10772	10856	PDTREG	\N	1998	\N	2002	ANCIEN	\N	\N	\N	NON	\N	\N
10772	10862	CONSREG	\N	2004	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10792	10863	CONSGENE	\N	1982	\N	1988	ANCIEN	\N	\N	\N	NON	\N	\N
10793	10864	MAIRE	\N	1983	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10794	10865	DEPUTE	1986-03-16 00:00:00	1986	1988-05-14 00:00:00	1988	ANCIEN	\N	\N	\N	NON	\N	2016-12-12 16:34:29
10800	10867	CONSGENE	\N	1982	\N	1989	ANCIEN	\N	\N	\N	NON	\N	\N
10801	10868	CONSGENE	\N	1994	\N	1997	ANCIEN	\N	\N	\N	NON	\N	\N
10802	10869	DEPUTE	1981-06-21 00:00:00	\N	1984-08-23 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2016-12-12 11:58:11
10803	10870	DEPUTE	1986-03-16 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2016-12-12 11:58:36
10804	10871	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-06-15 10:48:19
10808	10875	CONSGENE	1998-03-22 00:00:00	1998	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
10808	10876	VICPDTGEN	\N	2001	2004-10-01 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10809	10877	CONSMUNI	\N	1983	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
10810	10878	CONSREG	1998-03-15 00:00:00	1998	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10810	10879	VICPDTREG	1986-03-16 00:00:00	1986	1998-03-15 00:00:00	1998	ANCIEN	\N	\N	\N	NON	\N	\N
10809	10880	MAIREADJOINT	\N	1995	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
10809	10881	MAIRE	\N	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10811	10883	CONSGENE	1992-03-29 00:00:00	1992	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10807	10882	MAIRE	1989-03-19 00:00:00	1989	2017-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-11-13 10:04:02
10812	10884	MAIRE	\N	1983	2005-01-28 00:00:00	2005	ANCIEN	\N	\N	\N	NON	\N	\N
10819	10885	CONSREG	2004-03-28 00:00:00	2004	\N	2005	ANCIEN	\N	\N	\N	NON	\N	\N
10821	10886	MAIRE	2001-03-21 00:00:00	2001	2017-10-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-11-06 16:30:11
10829	10887	CONSREG	\N	1992	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10829	10888	VICPDTREG	\N	2004	\N	2007	ANCIEN	\N	\N	\N	NON	\N	\N
10830	10889	MAIREADJOINT	\N	2001	2008-03-15 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
10838	10890	CONSGENE	\N	1992	\N	1994	ANCIEN	\N	\N	\N	NON	\N	\N
10839	10891	MAIRE	\N	2001	2015-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2015-10-06 18:02:17
10840	10892	MAIRE	\N	1989	2015-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2015-07-17 16:05:46
10842	10893	CONSGENE	2001-03-18 00:00:00	2001	2004-11-15 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10841	10894	MAIRE	1977-03-20 00:00:00	1977	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
10845	10895	MAIRE	\N	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10848	10896	CONSMUNI	\N	1977	\N	1989	ANCIEN	\N	\N	\N	NON	\N	\N
10846	10897	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10848	10898	MAIREADJOINT	\N	1989	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
10849	10899	CONSGENE	\N	1994	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
10849	10900	VICPDTGEN	\N	1998	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
10850	10901	CONSMUNI	\N	1983	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
10849	10902	CONSGENE	\N	2001	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10853	10905	CONSMUNI	\N	1998	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10854	10906	CONSREG	1986-03-16 00:00:00	1986	1992-03-22 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10855	10907	DEPUTE	1997-06-01 00:00:00	1997	2002-06-18 00:00:00	2002	ANCIEN	\N	\N	\N	NON	\N	2017-06-15 10:48:51
10856	10908	CONSGENE	1998-03-21 00:00:00	1998	1998-03-21 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10863	10909	MAIRE	\N	2001	2008-03-21 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
10866	10910	MAIRE	\N	1995	2009-06-08 00:00:00	2009	ANCIEN	\N	\N	\N	NON	\N	\N
10867	10911	CONSGENE	\N	1998	2004-10-20 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10868	10912	CONSREG	\N	1986	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
10869	10913	DEPUTE	1997-06-01 00:00:00	1997	2000-04-27 00:00:00	2000	ANCIEN	\N	\N	\N	NON	\N	2017-06-15 10:51:10
10874	10914	MAIREADJOINT	\N	1995	2008-03-21 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
10877	10915	MAIREADJOINT	\N	1995	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10881	10920	CONSGENEPARI	\N	2001	2020-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-06-29 15:53:53
10880	10922	MAIREADJOINT	\N	2001	2005-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10885	10923	MAIRE	2001-03-25 00:00:00	2001	2008-03-21 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
10887	10924	CONSGENE	1992-03-29 00:00:00	1992	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
10888	10925	CONSREG	\N	2002	2004-03-21 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10889	10926	CONSMUNI	1995-06-11 00:00:00	1995	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
10895	10927	CONSMUNI	\N	1983	\N	1997	ANCIEN	\N	\N	\N	NON	\N	\N
10896	10928	MAIREADJOINT	\N	2001	2008-03-21 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
10897	10929	CONSGENE	\N	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	2017-06-29 15:55:53
10899	10931	CONSMUNI	\N	2000	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10905	10932	CONSREG	\N	\N	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10908	10933	VICPDTREG	2004-03-28 00:00:00	2004	\N	2005	ANCIEN	\N	\N	\N	NON	\N	\N
10909	10934	CONSGENE	2004-03-28 00:00:00	2004	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10910	10935	CONSPARI	\N	2001	2006-03-01 00:00:00	2006	ANCIEN	\N	\N	\N	NON	\N	\N
10911	10936	CONSGENEPARI	\N	2001	2006-03-01 00:00:00	2006	ANCIEN	\N	\N	\N	NON	\N	\N
10913	10937	CONSREG	2004-03-28 00:00:00	2004	2004-12-20 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10915	10938	MAIREADJOINT	\N	2004	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
10915	10939	CONSMUNI	\N	2001	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10920	10945	CONSREG	1992-03-22 00:00:00	1992	2004-03-21 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10917	10941	CONSARR	\N	1983	2008-03-16 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
10918	10942	MAIRE	\N	\N	2019-07-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-16 18:03:09
10924	10946	CONSPARI	\N	1983	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10919	10944	CONSGENEPARI	\N	1989	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
10925	10947	CONSGENEPARI	\N	1983	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10927	10949	CONSREG	\N	1998	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10929	10950	CONSGENE	\N	1982	\N	1994	ANCIEN	\N	\N	\N	NON	\N	\N
10930	10951	DEPUTE	1993-04-30 00:00:00	1993	1995-09-24 00:00:00	1995	ANCIEN	\N	\N	\N	NON	\N	2016-12-09 11:52:33
10932	10952	MAIRE	1996-12-12 00:00:00	1996	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10929	10953	VICPDTGEN	\N	1994	2011-03-27 00:00:00	2011	ANCIEN	\N	\N	\N	NON	\N	\N
10934	10954	CONSMUNI	\N	1977	\N	1983	ANCIEN	\N	\N	\N	NON	\N	\N
10934	10955	MAIRE	\N	1983	2008-03-16 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
10936	10956	CONSGENE	\N	1994	2008-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10937	10957	MAIRE	\N	1988	\N	1997	ANCIEN	\N	\N	\N	NON	\N	\N
11444	11408	PDTGEN	\N	1982	\N	1985	ANCIEN	\N	\N	\N	NON	\N	\N
11444	11409	CONSGENE	\N	1976	\N	1992	ANCIEN	\N	\N	\N	NON	\N	\N
11683	11644	CONSMUNI	1983-03-01 00:00:00	\N	2001-03-01 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
11686	11645	VICPDTREG	1992-03-01 00:00:00	1992	2001-06-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11567	11646	CONSMUNI	\N	1992	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
11567	11647	MAIREADJOINT	\N	1983	\N	1992	ANCIEN	\N	\N	\N	NON	\N	\N
11815	11656	CONSMUNI	\N	\N	2013-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2013-07-22 14:09:21
11848	11666	CONSMUNI	\N	1989	\N	2002	ANCIEN	\N	\N	\N	NON	\N	\N
11848	11667	MAIREADJOINT	\N	1977	\N	1989	ANCIEN	\N	\N	\N	NON	\N	\N
11849	11668	CONSREG	\N	1986	\N	1992	ANCIEN	\N	\N	\N	NON	\N	\N
11919	11729	VICPDTGEN	\N	1988	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
11920	11730	MAIREADJOINT	\N	1983	\N	1989	ANCIEN	\N	\N	\N	NON	\N	\N
1466	11731	VICPDTGEN	\N	1982	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
11797	11732	VICPDTGEN	\N	\N	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
11924	11734	CONSMUNI	\N	1989	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
11926	11735	CONSGENE	\N	1998	\N	1994	ANCIEN	\N	\N	\N	NON	\N	\N
11927	11736	MAIREADJOINT	\N	1977	\N	1983	ANCIEN	\N	\N	\N	NON	\N	\N
11928	11737	CONSREG	\N	1992	\N	1993	ANCIEN	\N	\N	\N	NON	\N	\N
11929	11738	CONSGENE	\N	1982	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
11930	11739	VICPDTREG	\N	1988	\N	1992	ANCIEN	\N	\N	\N	NON	\N	\N
6592	11740	MAIRE	\N	1996	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
771	11741	MAIREADJOINT	\N	1983	\N	1989	ANCIEN	\N	\N	\N	NON	\N	\N
6410	11742	PREVICPDTGEN	\N	2004	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11931	11743	VICPDTREG	\N	1986	\N	1992	ANCIEN	\N	\N	\N	NON	\N	\N
11932	11744	CONSGENE	\N	1988	\N	1994	ANCIEN	\N	\N	\N	NON	\N	\N
11708	11574	MAIRE	\N	1992	2009-02-08 00:00:00	2009	ANCIEN	\N	\N	\N	NON	\N	\N
10105	3275	CONSMUNI	\N	\N	2009-07-29 00:00:00	2009	ANCIEN	\N	\N	\N	NON	\N	\N
6360	11763	MAIREADJOINT	2009-10-22 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12012	11771	MAIRE	2008-03-30 00:00:00	2008	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10682	11782	CONSGENE	\N	1982	\N	1988	ANCIEN	\N	\N	\N	NON	\N	\N
11213	11154	CONSREG	\N	1973	\N	1986	ANCIEN	\N	\N	\N	NON	\N	\N
6209	11169	MAIREADJOINT	2007-03-09 00:00:00	2007	2008-03-21 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11272	11186	CONSGENE	1998-03-20 00:00:00	1998	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6456	11224	CONSMUNI	\N	2006	2016-12-10 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2016-12-12 16:10:15
11273	11188	MAIRE	2001-03-20 00:00:00	2001	2017-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-11-14 10:36:10
11347	11316	MAIRE	2008-03-21 00:00:00	2008	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11275	11190	VICPDTREG	\N	1992	\N	1993	ANCIEN	\N	\N	\N	NON	\N	\N
11275	11191	CONSREG	\N	1986	\N	1992	ANCIEN	\N	\N	\N	NON	\N	\N
11277	11196	CONSGENE	\N	1983	\N	1996	ANCIEN	\N	\N	\N	NON	\N	\N
11275	11193	CONSREG	\N	1998	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11276	11194	MAIRE	\N	1995	2014-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-08 16:08:11
11401	11384	CONSGENE	1985-05-17 00:00:00	1985	1998-03-15 00:00:00	1998	ANCIEN	\N	\N	\N	NON	\N	\N
11278	11197	DEPUTE	1993-03-28 00:00:00	1993	1997-04-21 00:00:00	1997	ANCIEN	\N	\N	\N	NON	\N	2016-12-08 18:06:31
11349	11318	CONSMUNI	2008-03-21 00:00:00	\N	2020-03-15 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11276	11200	MAIREADJOINT	\N	1983	\N	1989	ANCIEN	\N	\N	\N	NON	\N	\N
10829	11201	CONSREG	\N	2007	2009-05-15 00:00:00	2009	ANCIEN	\N	\N	\N	NON	\N	\N
6461	11383	MAIREADJOINT	1983-03-13 00:00:00	1983	1994-05-16 00:00:00	1994	ANCIEN	\N	\N	\N	NON	\N	\N
11491	11421	CONSGENE	\N	2004	2009-10-10 00:00:00	2009	ANCIEN	\N	\N	\N	NON	\N	\N
11489	11418	MAIREADJOINT	\N	2001	\N	2002	ANCIEN	\N	\N	\N	NON	\N	2016-06-02 15:57:39
11489	11419	MAIRE	\N	2003	2016-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2016-06-02 15:57:39
11490	11420	CONSMUNI	\N	1983	\N	1989	ANCIEN	\N	\N	\N	NON	\N	\N
11500	11424	CONSMUNI	\N	1992	\N	\N	ACTIF	\N	\N	\N	NON	\N	2014-05-12 16:04:27
11502	11425	CONSGENE	1998-03-22 00:00:00	\N	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
11502	11426	VICPDTGEN	\N	2001	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
11502	11427	PDTGEN	2001-12-01 00:00:00	2001	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11519	11435	CONSMUNI	\N	\N	2010-03-15 00:00:00	2010	ANCIEN	\N	\N	\N	NON	\N	\N
11522	11439	CONSGENE	1992-03-29 00:00:00	\N	2011-03-20 00:00:00	2011	ANCIEN	\N	\N	\N	NON	\N	\N
11523	11440	MAIRE	1995-06-01 00:00:00	1995	2014-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-07 16:31:14
11553	11458	MAIRE	1995-06-10 00:00:00	1995	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-12-18 15:52:45
11522	11442	VICPDTGEN	\N	2002	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11552	11457	CONSREG	2004-04-02 00:00:00	2004	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11555	11459	CONSREG	\N	1998	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11400	11380	DEPUTE	1978-05-06 00:00:00	1978	1981-05-22 00:00:00	1988	ANCIEN	\N	\N	\N	NON	\N	2017-06-15 10:49:30
11397	11376	DEPUTE	1988-06-12 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2016-12-13 11:01:11
11594	11481	DEPUTE	1981-06-21 00:00:00	1981	1986-04-01 00:00:00	1986	ANCIEN	\N	\N	\N	NON	\N	2016-12-09 14:15:21
11398	11378	DEPUTE	1986-03-16 00:00:00	1986	1988-05-14 00:00:00	1988	ANCIEN	\N	\N	\N	NON	\N	\N
11399	11379	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11555	11460	VICPDTREG	\N	2004	2015-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2015-12-15 15:06:54
11568	11464	CONSGENE	\N	1992	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
11568	11466	CONSGENE	\N	2004	\N	2007	ANCIEN	\N	\N	\N	NON	\N	\N
11585	11473	CONSGENE	\N	1973	\N	1982	ANCIEN	\N	\N	\N	NON	\N	\N
11585	11475	VICPDTGEN	\N	1973	\N	1976	ANCIEN	\N	\N	\N	NON	\N	\N
11586	11476	MAIRE	\N	1977	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11592	11480	CONSREG	\N	1986	\N	1988	ANCIEN	\N	\N	\N	NON	\N	\N
11605	11486	MAIRE	\N	2001	2014-03-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-07 11:25:17
11609	11492	MAIRE	1995-06-01 00:00:00	1995	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2018-01-23 18:59:24
11609	11491	CONSMUNI	\N	1983	1995-05-31 00:00:00	1995	ANCIEN	\N	\N	\N	NON	\N	2018-01-23 18:59:24
11611	11493	CONSREG	\N	1998	2015-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2015-12-15 15:04:14
11630	11506	DEPUTE	1973-03-11 00:00:00	1973	1978-04-02 00:00:00	1978	ANCIEN	\N	\N	\N	NON	\N	2016-12-08 17:26:19
11632	11510	MAIRE	\N	1983	\N	1997	ANCIEN	\N	\N	\N	NON	\N	\N
11632	11511	MAIRE	\N	2001	\N	2007	ANCIEN	\N	\N	\N	NON	\N	\N
11635	11514	PDTREG	\N	1981	\N	1982	ANCIEN	\N	\N	\N	NON	\N	\N
11655	11532	VICPDTGEN	\N	2004	\N	2010	ANCIEN	\N	\N	\N	NON	\N	\N
11655	11530	CONSGENE	\N	2001	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11656	11531	MAIREADJOINT	1989-03-01 00:00:00	1989	2008-03-16 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11662	11533	MAIRE	\N	1989	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-11-15 10:19:00
11663	11534	CONSGENE	\N	1995	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
11663	11536	VICPDTGEN	\N	2001	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11672	11542	CONSGENE	\N	2001	2009-01-11 00:00:00	2009	ANCIEN	\N	\N	\N	NON	\N	\N
11673	11543	MAIRE	\N	2008	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-10-06 16:48:42
11680	11548	CONSREG	\N	1998	2008-10-17 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11682	11551	MAIRE	\N	1995	2017-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-11-14 09:40:28
6382	11156	MAIREADJOINT	2006-05-12 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11285	11202	DEPUTE	2007-06-10 00:00:00	2007	2012-06-19 00:00:00	2012	ANCIEN	\N	\N	\N	NON	\N	2016-12-09 11:53:07
11003	11283	CONSGENE	2008-03-21 00:00:00	2008	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11684	11554	VICPDTGEN	\N	1998	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
11855	11673	CONSMUNI	\N	1989	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
11693	11559	CONSGENE	\N	1994	2008-10-28 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11695	11563	CONSMUNI	\N	1983	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11715	11578	CONSGENE	\N	1998	2009-03-29 00:00:00	2009	ANCIEN	\N	\N	\N	NON	\N	\N
11695	11566	MAIREADJOINT	\N	1983	\N	1992	ANCIEN	\N	\N	\N	NON	\N	\N
11878	11683	MAIREADJOINT	\N	\N	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
11717	11584	MAIRE	\N	1995	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
11716	11581	MAIRE	2008-03-09 00:00:00	2008	2014-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-08 12:20:49
11741	11599	CONSGENE	1981-09-12 00:00:00	1981	\N	1992	ANCIEN	\N	\N	\N	NON	\N	\N
11743	11602	MAIRE	\N	1989	\N	2010	ANCIEN	\N	\N	\N	NON	\N	\N
11741	11600	VICPDTGEN	\N	2001	2011-11-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11750	11609	CONSGENE	\N	1988	2008-11-23 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11749	11607	MAIRE	\N	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11751	11613	CONSREG	\N	1986	\N	2002	ANCIEN	\N	\N	\N	NON	\N	\N
11766	11624	CONSGENE	\N	1998	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11768	11626	MAIREADJOINT	\N	1989	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
11766	11625	PDTGEN	\N	2004	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11777	11630	CONSGENE	\N	1998	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11777	11631	VICPDTGEN	\N	2005	\N	2014	ANCIEN	\N	\N	\N	NON	\N	2015-01-27 10:18:19
11778	11632	MAIRE	\N	2004	2014-03-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-07 11:22:42
11634	11661	MAIREADJOINT	1987-06-01 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11634	11660	CONSMUNI	1983-03-01 00:00:00	\N	1987-06-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11856	11674	CONSREG	\N	1986	\N	1992	ANCIEN	\N	\N	\N	NON	\N	\N
10633	10660	PDTGEN	\N	2001	2008-03-20 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10634	10661	CONSREG	2004-04-02 00:00:00	2004	\N	2005	ANCIEN	\N	\N	\N	NON	\N	\N
10636	10663	CONSREG	2004-04-02 00:00:00	2004	2010-03-21 00:00:00	2010	ANCIEN	\N	\N	\N	NON	\N	\N
6749	3123	CONSGENE	1998-03-22 00:00:00	1998	2004-03-21 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10640	10668	CONSGENE	2004-03-21 00:00:00	2004	2004-04-01 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10640	10669	PDTGEN	2004-04-01 00:00:00	2004	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10641	10670	CONSGENE	2004-03-21 00:00:00	2004	2004-04-01 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10641	10671	PREVICPDTGEN	2004-04-01 00:00:00	2004	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10642	10672	PDTGEN	2004-03-21 00:00:00	2004	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6006	10673	PDTGEN	2004-04-01 00:00:00	2004	2008-03-16 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
10646	10674	CONSGENE	2004-03-28 00:00:00	2004	2011-03-27 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10647	10675	PDTGEN	2004-04-01 00:00:00	2004	2008-03-20 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
10648	10676	CONSGENE	2004-03-28 00:00:00	2004	2004-04-01 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10648	10677	VICPDTGEN	2004-04-01 00:00:00	2004	\N	2010	ANCIEN	\N	\N	\N	NON	\N	\N
6541	3000	VICPDTGEN	\N	1979	2004-04-01 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10649	10678	VICPDTGEN	2004-04-01 00:00:00	2004	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10650	10679	PDTGEN	2004-04-01 00:00:00	2004	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10651	10680	PDTGEN	2004-04-01 00:00:00	2004	2014-04-17 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-08 16:00:46
10652	10681	CONSGENE	2004-04-01 00:00:00	2004	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10653	10682	CONSGENE	2004-04-01 00:00:00	2004	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10654	10683	VICPDTGEN	2004-04-01 00:00:00	2004	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6534	2995	PDTGEN	\N	2001	2004-04-01 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10655	10684	PDTGEN	2004-04-01 00:00:00	2004	2011-03-30 00:00:00	2011	ANCIEN	\N	\N	\N	NON	\N	\N
10657	10687	CONSGENE	2004-03-28 00:00:00	2004	2004-04-01 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10657	10688	VICPDTGEN	2004-04-01 00:00:00	2004	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10658	10689	PDTGEN	2004-04-01 00:00:00	2004	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10660	10691	CONSGENE	2004-03-28 00:00:00	2004	2023-10-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6087	10692	PDTGEN	2004-04-01 00:00:00	2004	2008-03-21 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
10661	10693	VICPDTGEN	2004-03-28 00:00:00	2004	2011-03-27 00:00:00	2011	ANCIEN	\N	\N	\N	NON	\N	\N
1442	1442	PDTGEN	2001-03-23 00:00:00	2001	2004-04-01 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10662	10694	PDTGEN	2004-04-01 00:00:00	2004	2013-01-05 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10663	10695	CONSGENE	2004-04-01 00:00:00	2004	2011-03-27 00:00:00	2011	ANCIEN	\N	\N	\N	NON	\N	\N
10664	10696	PREVICPDTGEN	2004-04-01 00:00:00	2004	2011-03-27 00:00:00	2011	ANCIEN	\N	\N	\N	NON	\N	\N
10665	10697	PDTGEN	2004-04-01 00:00:00	2004	2011-03-31 00:00:00	2011	ANCIEN	\N	\N	\N	NON	\N	\N
10666	10698	PDTGEN	2004-04-01 00:00:00	2004	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10617	10699	VICPDTGEN	2004-04-01 00:00:00	2004	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10667	10700	CONSGENE	2004-03-28 00:00:00	2004	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6009	2750	PDTGEN	2001-03-23 00:00:00	2001	2004-04-01 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6009	10701	PDTGEN	2004-04-01 00:00:00	2004	2008-03-21 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6496	10702	VICPDTREG	2004-04-02 00:00:00	2004	\N	2010	ANCIEN	\N	\N	\N	NON	\N	\N
5144	10703	VICPDTREG	1992-03-22 00:00:00	1992	1998-03-15 00:00:00	1998	ANCIEN	\N	\N	\N	NON	\N	\N
6210	2847	MAIREADJOINT	2001-03-25 00:00:00	2001	2008-03-15 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
1367	2849	VICPDTGEN	2001-03-23 00:00:00	2001	2004-03-28 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6176	2850	MAIREADJOINT	2001-03-25 00:00:00	2001	\N	2008	ANCIEN	\N	\N	\N	NON	\N	2013-11-04 16:58:28
6004	2896	MAIRE	2001-03-23 00:00:00	2001	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1434	2852	VICPDTGEN	2001-03-23 00:00:00	2001	2008-03-16 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6250	2853	MAIRE	2001-03-25 00:00:00	2001	2014-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-08 16:51:31
6216	2854	MAIRE	2001-03-25 00:00:00	2001	2008-03-21 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6121	2856	VICPDTGEN	2001-03-23 00:00:00	2001	2008-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
1441	2857	VICPDTGEN	2001-03-23 00:00:00	2001	2004-03-28 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6356	2916	MAIRE	2008-03-14 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6294	2859	CONSMUNI	2001-03-18 00:00:00	2001	2013-07-14 00:00:00	2013	ANCIEN	\N	\N	\N	NON	\N	\N
6236	2860	VICPDTGEN	2001-03-23 00:00:00	2001	2020-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
5873	2861	VICPDTGEN	2001-03-23 00:00:00	2001	2004-03-28 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
1449	2862	VICPDTGEN	2001-03-23 00:00:00	2001	2004-03-28 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
1451	2863	PREVICPDTGEN	2001-03-23 00:00:00	2001	2004-04-01 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6235	2864	VICPDTGEN	2001-03-23 00:00:00	2001	2002-07-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
1463	2866	CONSGENE	2001-03-23 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6295	2867	CONSGENE	2001-03-18 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6296	2868	CONSGENE	2001-03-18 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6297	2870	CONSMUNI	2001-03-18 00:00:00	2001	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6298	2871	CONSMUNI	2001-03-18 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6299	2872	CONSGENE	2001-03-18 00:00:00	2001	2018-05-17 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2018-05-23 11:13:25
5103	2873	CONSMUNI	\N	1989	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
6300	2874	CONSREG	\N	1992	\N	1994	ANCIEN	\N	\N	\N	NON	\N	\N
6203	2876	MAIRE	2001-03-25 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
5076	2877	VICPDTGEN	2001-03-23 00:00:00	2001	2008-11-12 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
5076	2032	CONSGENE	1992-03-29 00:00:00	1992	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6228	2878	VICPDTGEN	2001-03-23 00:00:00	2001	2008-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6303	2882	CONSGENE	2001-03-18 00:00:00	2001	2004-03-28 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
1496	2883	PDTREG	2001-04-13 00:00:00	\N	2015-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2015-12-15 14:57:21
49633	48229	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:46	\N
10479	3598	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10482	3600	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10486	3602	DEPUTE	\N	\N	\N	1958	ANCIEN	\N	\N	\N	NON	\N	\N
10487	3603	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10489	3605	DEPUTE	\N	\N	\N	1946	ANCIEN	\N	\N	\N	NON	\N	\N
10490	3606	DEPUTE	\N	\N	\N	1940	ANCIEN	\N	\N	\N	NON	\N	\N
10491	3607	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10493	3609	DEPUTE	\N	\N	\N	1958	ANCIEN	\N	\N	\N	NON	\N	\N
10494	3610	DEPUTE	\N	\N	\N	1969	ANCIEN	\N	\N	\N	NON	\N	\N
10495	3611	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10496	3612	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10498	3614	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10499	3615	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10500	3616	DEPUTE	\N	\N	\N	1940	ANCIEN	\N	\N	\N	NON	\N	\N
10501	3617	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10502	3618	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10204	3374	CONSMUNI	\N	\N	1994-02-23 00:00:00	1994	ANCIEN	\N	\N	\N	NON	\N	\N
11032	11023	CONSREG	\N	1998	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
12054	13075	PDTREG	2009-09-14 00:00:00	\N	2010-03-26 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11034	11025	CONSGENE	\N	1994	\N	1997	ANCIEN	\N	\N	\N	NON	\N	\N
11035	11026	MAIRE	\N	1995	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11036	11027	DEPUTE	1997-06-01 00:00:00	1997	2002-06-18 00:00:00	2002	ANCIEN	\N	\N	\N	NON	\N	2017-06-15 10:50:21
10874	11028	CONSMUNI	\N	1989	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
11037	11029	MAIRE	1997-10-23 00:00:00	\N	2017-10-23 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2018-01-24 19:31:59
11039	11030	MAIRE	\N	2001	2021-02-02 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11040	11031	CONSREG	\N	2004	\N	2005	ANCIEN	\N	\N	\N	NON	\N	\N
10993	11032	MAIREADJOINT	\N	1983	\N	1989	ANCIEN	\N	\N	\N	NON	\N	\N
10993	11034	CONSMUNI	\N	1995	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10799	11036	CONSMUNI	\N	1983	\N	1989	ANCIEN	\N	\N	\N	NON	\N	\N
10851	11037	VICPDTREG	1998-03-15 00:00:00	1998	2004-03-21 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11057	11038	MAIREADJOINT	\N	2001	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11058	11039	CONSGENE	\N	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11060	11040	CONSPARI	\N	1995	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10895	11041	MAIRE	\N	1997	2000-06-23 00:00:00	2000	ANCIEN	\N	\N	\N	NON	\N	\N
10895	11042	CONSMUNI	2000-06-24 00:00:00	2000	2008-03-21 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
10938	11044	MAIREADJOINT	\N	1989	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
11006	11045	MAIRE	\N	1989	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10838	11046	VICPDTGEN	\N	1994	2004-03-21 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10888	11048	VICPDTREG	1998-03-15 00:00:00	1998	\N	2002	ANCIEN	\N	\N	\N	NON	\N	\N
11026	11049	PREVICPDTGEN	\N	2004	2004-10-26 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10962	11050	VICPDTREG	\N	1998	2004-03-21 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11068	11053	MAIREADJOINT	\N	1989	\N	2005	ANCIEN	\N	\N	\N	NON	\N	\N
11076	11060	CONSARR	\N	2001	2008-03-16 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11070	11055	DEPUTE	\N	1988	\N	1993	ANCIEN	\N	\N	\N	NON	\N	\N
11073	11057	CONSMUNI	\N	2001	2008-03-21 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11010	11058	MAIREADJOINT	\N	2001	2008-03-21 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11077	11062	CONSMUNI	\N	2001	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11078	11064	MAIREADJOINT	\N	1995	\N	2000	ANCIEN	\N	\N	\N	NON	\N	2014-04-29 18:20:05
11079	11066	CONSMUNI	\N	1983	\N	1989	ANCIEN	\N	\N	\N	NON	\N	\N
11079	11067	MAIREADJOINT	\N	1989	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
11057	11068	CONSMUNI	\N	1981	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
11039	11069	CONSMUNI	\N	1977	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
11031	11070	MAIREADJOINT	\N	2001	2008-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11083	11071	CONSMUNI	\N	2001	2008-03-16 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11086	11072	MAIRE	\N	1989	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
11086	11073	CONSMUNI	\N	1989	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6021	11074	MAIREADJOINT	\N	2002	2004-10-25 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6081	11076	MAIREADJOINT	\N	2004	2017-10-26 00:00:00	2017	ANCIEN	\N	\N	\N	NON	\N	\N
10863	11077	CONSMUNI	\N	1992	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
10072	3242	MAIRE	\N	\N	2004-09-29 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10168	3338	MAIRE	\N	\N	2004-08-18 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11092	11078	CONSGENE	1992-03-29 00:00:00	1992	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
11092	11079	PREVICPDTGEN	\N	1998	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11092	11080	PDTGEN	2004-04-01 00:00:00	2004	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11093	11081	MAIRE	\N	1995	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11096	11082	CONSGENE	1985-03-17 00:00:00	1985	\N	1992	ANCIEN	\N	\N	\N	NON	\N	\N
11097	11083	MAIRE	\N	1983	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11096	11084	VICPDTGEN	\N	1992	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11096	11085	CONSGENE	2004-03-21 00:00:00	2004	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11100	11086	CONSGENE	1985-03-17 00:00:00	1985	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
11101	11087	CONSMUNI	\N	1977	\N	1983	ANCIEN	\N	\N	\N	NON	\N	\N
11101	11088	MAIREADJOINT	\N	1984	1995-03-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-08 14:55:30
11100	11090	VICPDTGEN	\N	1998	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11104	11091	MAIRE	\N	1995	2008-03-16 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12780	13084	CONSGENE	2012-12-02 00:00:00	2012	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11339	11307	CONSMUNI	2008-03-21 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11340	11308	CONSMUNI	2008-03-21 00:00:00	\N	2014-03-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-07 11:23:22
11350	11319	CONSREG	\N	1985	2008-09-24 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11370	11334	CONSMUNI	1971-03-21 00:00:00	1971	\N	1982	ANCIEN	\N	\N	\N	NON	\N	\N
11351	11321	CONSMUNI	\N	2008	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
630	11327	CONSMUNI	\N	1995	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
11366	11326	CONSGENE	2008-03-23 00:00:00	2008	2015-02-25 00:00:00	2015	ANCIEN	\N	\N	\N	NON	\N	\N
630	11328	MAIREADJOINT	\N	1989	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
11368	11329	CONSREG	\N	1986	\N	1986	ANCIEN	\N	\N	\N	NON	\N	\N
11368	11330	CONSREG	\N	1992	\N	1992	ANCIEN	\N	\N	\N	NON	\N	\N
11370	11335	MAIRE	1985-10-03 00:00:00	1985	1995-06-18 00:00:00	1995	ANCIEN	\N	\N	\N	NON	\N	\N
11370	11336	CONSMUNI	1995-06-18 00:00:00	1995	1996-06-14 00:00:00	1996	ANCIEN	\N	\N	\N	NON	\N	\N
11371	11337	CONSGENE	1976-03-14 00:00:00	1976	1985-03-17 00:00:00	1985	ANCIEN	\N	\N	\N	NON	\N	\N
11371	11338	VICPDTGEN	1985-03-17 00:00:00	1985	1988-10-02 00:00:00	1988	ANCIEN	\N	\N	\N	NON	\N	\N
11370	11340	MAIREADJOINT	\N	1982	1985-10-03 00:00:00	1985	ANCIEN	\N	\N	\N	NON	\N	\N
11372	11339	CONSREG	\N	1978	\N	1982	ANCIEN	\N	\N	\N	NON	\N	\N
10807	11349	MAIREADJOINT	1977-03-20 00:00:00	1977	1989-03-19 00:00:00	1989	ANCIEN	\N	\N	\N	NON	\N	\N
1340	11347	CONSGENE	1982-03-21 00:00:00	1982	1985-03-17 00:00:00	1985	ANCIEN	\N	\N	\N	NON	\N	\N
10807	11348	CONSMUNI	1971-03-21 00:00:00	1971	1977-03-20 00:00:00	1977	ANCIEN	\N	\N	\N	NON	\N	\N
11373	11344	MAIRE	1990-09-26 00:00:00	1990	1993-10-29 00:00:00	1993	ANCIEN	\N	\N	\N	NON	\N	\N
11373	11345	MAIREADJOINT	\N	\N	1990-09-26 00:00:00	1990	ANCIEN	\N	\N	\N	NON	\N	\N
11381	11350	CONSREG	1986-03-16 00:00:00	1986	\N	1988	ANCIEN	\N	\N	\N	NON	\N	\N
1409	10740	PDTGEN	1988-10-07 00:00:00	1988	1998-03-22 00:00:00	1998	ANCIEN	\N	\N	\N	NON	\N	\N
683	10741	CONSMUNI	\N	1988	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1409	10742	CONSGENE	1998-03-22 00:00:00	1998	2004-03-28 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10687	10743	DEPUTE	1988-06-05 00:00:00	1988	1988-07-05 00:00:00	1988	ANCIEN	\N	\N	\N	NON	\N	\N
10688	10744	CONSMUNI	\N	1972	\N	1977	ANCIEN	\N	\N	\N	NON	\N	\N
10688	10746	MAIREADJOINT	\N	1977	\N	1983	ANCIEN	\N	\N	\N	NON	\N	\N
10688	10747	CONSMUNI	\N	1983	\N	1989	ANCIEN	\N	\N	\N	NON	\N	\N
10689	10748	CONSGENE	1977-09-11 00:00:00	1977	1992-03-29 00:00:00	1992	ANCIEN	\N	\N	\N	NON	\N	\N
6386	10749	MAIREADJOINT	\N	1977	\N	1983	ANCIEN	\N	\N	\N	NON	\N	\N
1499	1499	CONSREG	\N	1995	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
1499	10750	VICPDTREG	\N	1998	\N	1999	ANCIEN	\N	\N	\N	NON	\N	\N
1499	10751	CONSREG	\N	1999	2004-03-28 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10691	10752	CONSREG	\N	1992	1998-03-15 00:00:00	1998	ANCIEN	\N	\N	\N	NON	\N	\N
10692	10753	CONSMUNI	\N	1977	\N	1983	ANCIEN	\N	\N	\N	NON	\N	\N
10692	10754	MAIREADJOINT	\N	1983	\N	1989	ANCIEN	\N	\N	\N	NON	\N	\N
10693	10755	VICPDTREG	\N	1985	\N	1989	ANCIEN	\N	\N	\N	NON	\N	\N
1356	10756	CONSGENE	1970-03-15 00:00:00	1970	1985-03-17 00:00:00	1985	ANCIEN	\N	\N	\N	NON	\N	\N
1356	10757	VICPDTGEN	1985-03-17 00:00:00	1985	1994-04-01 00:00:00	1994	ANCIEN	\N	\N	\N	NON	\N	\N
10694	10758	CONSREG	1986-03-16 00:00:00	1986	1992-03-22 00:00:00	1992	ANCIEN	\N	\N	\N	NON	\N	\N
5869	10759	CONSMUNI	\N	1959	2007-11-21 00:00:00	2007	ANCIEN	\N	\N	\N	NON	\N	\N
5869	10760	MAIREADJOINT	\N	1965	2007-11-21 00:00:00	2007	ANCIEN	\N	\N	\N	NON	\N	\N
10696	10761	CONSMUNI	\N	1953	\N	1960	ANCIEN	\N	\N	\N	NON	\N	\N
10696	10762	MAIRE	\N	1960	2021-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10697	10765	VICPDTGEN	\N	1992	2021-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10697	10764	CONSGENE	\N	1976	\N	1992	ANCIEN	\N	\N	\N	NON	\N	\N
10698	10766	CONSMUNI	\N	1971	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
10698	10767	MAIRE	\N	1995	2022-03-10 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10701	10768	MAIREADJOINT	\N	1983	2004-06-07 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	2017-09-24 18:47:10
10703	10769	CONSGENE	1994-03-28 00:00:00	\N	2009-05-25 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-09-24 18:48:21
6069	10771	MAIRE	2004-04-23 00:00:00	2004	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6051	10772	MAIREADJOINT	2004-04-23 00:00:00	2004	2019-07-18 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10705	10773	VICPDTREG	\N	1986	\N	1989	ANCIEN	\N	\N	\N	NON	\N	\N
651	10774	MAIREADJOINT	\N	1987	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
5101	10775	MAIREADJOINT	\N	1977	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
10708	10776	MAIREADJOINT	\N	1977	\N	1983	ANCIEN	\N	\N	\N	NON	\N	\N
10709	10777	CONSREG	\N	1986	\N	1989	ANCIEN	\N	\N	\N	NON	\N	\N
11105	11092	CONSREG	1998-03-15 00:00:00	1998	2004-03-21 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11106	11093	MAIRE	1995-03-27 00:00:00	\N	2014-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-08 14:55:30
6207	2895	CONSMUNI	2001-03-23 00:00:00	\N	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10993	11095	MAIRE	\N	1989	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
6405	11096	CONSMUNI	2004-04-01 00:00:00	2004	2008-03-21 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
10657	11097	CONSGENE	\N	2004	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11113	11098	MAIRE	\N	1977	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
11114	11099	CONSGENE	\N	1982	\N	1988	ANCIEN	\N	\N	\N	NON	\N	\N
11115	11100	DEPUTE	1986-03-16 00:00:00	1986	1988-05-14 00:00:00	1988	ANCIEN	\N	\N	\N	NON	\N	2016-12-12 15:35:07
11117	11101	VICPDTGEN	\N	1982	1992-10-07 00:00:00	1992	ANCIEN	\N	\N	\N	NON	\N	\N
6155	11102	CONSMUNI	\N	2004	2008-03-21 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11121	11103	CONSGENE	\N	1992	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
10812	11104	MAIREADJOINT	2005-01-29 00:00:00	2005	2014-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-08 15:57:28
10880	11105	CONSPARI	2005-02-08 00:00:00	2005	2020-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11129	11106	CONSGENE	\N	1999	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
11130	11107	CONSMUNI	\N	\N	2008-03-16 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11135	11108	PREVICPDTGEN	\N	\N	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
11136	11109	CONSREG	\N	1982	\N	1989	ANCIEN	\N	\N	\N	NON	\N	\N
11146	11110	VICPDTAN	\N	1989	\N	1993	ANCIEN	\N	\N	\N	NON	\N	\N
11146	11111	DEPUTE	\N	1978	\N	1989	ANCIEN	\N	\N	\N	NON	\N	\N
11152	11113	VICPDTREG	\N	1985	\N	1988	ANCIEN	\N	\N	\N	NON	\N	\N
11154	11114	MAIRE	\N	1995	2014-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-17 12:08:36
11157	11121	PDTGEN	1985-03-22 00:00:00	1985	\N	1988	ANCIEN	\N	\N	\N	NON	\N	\N
6143	11120	MAIREADJOINT	\N	2005	2008-03-21 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11155	11117	PREVICPDTGEN	\N	2001	2005-08-27 00:00:00	2005	ANCIEN	\N	\N	\N	NON	\N	\N
11155	11119	VICPDTGEN	\N	1994	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
11169	11122	MAIREADJOINT	\N	1979	\N	1989	ANCIEN	\N	\N	\N	NON	\N	\N
11170	11125	CONSGENE	\N	1994	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11170	11124	PDTGEN	\N	2001	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11169	11126	MAIRE	\N	1989	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11171	11127	CONSREG	\N	1998	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
10217	3387	CONSMUNI	\N	\N	2005-09-27 00:00:00	2005	ANCIEN	\N	\N	\N	NON	\N	\N
11178	11129	CONSMUNI	\N	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11506	12196	PDTINTCOM	\N	2001	2016-12-31 00:00:00	\N	ANCIEN	\N	Président de la Communauté de communes de la Beauce d'Orgères	Président de la Communauté de communes de la Beauce d'Orgères	NON	\N	2017-12-04 18:31:58
11862	12197	VICPDTINTCOM	\N	2001	\N	\N	ACTIF	\N	Vice-présidente de la Communauté d'agglomération de Montluçon	Vice-présidente de la Communauté d'agglomération de Montluçon	NON	\N	\N
11863	12198	VICPDTINTCOM	2002-03-01 00:00:00	2002	2017-01-21 00:00:00	\N	ANCIEN	\N	Vice-président de la Communauté d'agglomération du Pays de Montbéliard	Vice-président de la Communauté d'agglomération du Pays de Montbéliard	NON	\N	2018-02-01 19:42:13
11595	12199	PDTINTCOM	\N	1989	\N	2008	ANCIEN	\N	Président de la Communauté d'agglomération Rennes-Métropole	Président de la Communauté d'agglomération Rennes-Métropole	NON	\N	\N
11658	12200	CONSINTCOM	\N	1999	2008-03-01 00:00:00	2008	ANCIEN	\N	Conseiller, Communauté d'agglomération de Quimper-Communauté	Conseiller, Communauté d'agglomération de Quimper-Communauté	NON	\N	\N
10662	13093	CONSGENE	2013-01-06 00:00:00	2013	2015-02-16 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2015-03-12 10:24:15
11674	12201	VICPDTINTCOM	\N	2008	2014-03-16 00:00:00	\N	ANCIEN	\N	Vice-président de la Communauté de communes du Pays de Douarnenez	Vice-président de la Communauté de communes du Pays de Douarnenez	NON	\N	2014-10-09 12:18:12
11697	12202	PDTINTCOM	2001-04-01 00:00:00	2001	2017-06-25 00:00:00	\N	ANCIEN	\N	Président de la Communauté d'agglomération du Bassin d'Aurillac	Président de la Communauté d'agglomération du Bassin d'Aurillac	NON	\N	\N
11921	12203	CONSINTCOM	\N	2008	2020-01-01 00:00:00	\N	ANCIEN	\N	Conseiller, Communauté de communes de l'ouest guyanais	Conseiller, Communauté de communes de l'ouest guyanais	NON	\N	\N
11755	12204	PDTINTCOM	\N	2002	2014-10-01 00:00:00	\N	ANCIEN	\N	Président de la Communauté d'agglomération de Nîmes-Métropole	Président de la Communauté d'agglomération de Nîmes-Métropole	NON	\N	2014-10-10 16:00:15
11375	12205	VICPDTINTCOM	2008-04-16 00:00:00	2008	2014-04-01 00:00:00	\N	ANCIEN	\N	Vice-présidente de la Communauté de communes des Trois Frontières	Vice-présidente de la Communauté de communes des Trois Frontières	NON	\N	2014-05-14 09:38:05
11469	12206	CONSINTCOM	\N	\N	\N	2008	ANCIEN	\N	Conseiller, Communauté d'agglomération belfortaine	Conseiller, Communauté d'agglomération belfortaine	NON	\N	\N
11801	12207	VICPDTINTCOM	2001-03-01 00:00:00	2001	2008-03-01 00:00:00	2008	ANCIEN	\N	Vice-présidente de la Communauté de communes de Ventadour	Vice-présidente de la Communauté de communes de Ventadour	NON	\N	\N
11834	12208	PDTINTCOM	\N	1977	\N	2008	ANCIEN	\N	Président de la Communauté d'agglomeration belfortaine	Président de la Communauté d'agglomeration belfortaine	NON	\N	\N
11833	12209	PDTINTCOM	\N	2001	\N	2008	ANCIEN	\N	Président de la communauté des communes du Saint-Affricain	Président de la communauté des communes du Saint-Affricain	NON	\N	\N
11840	12210	PDTINTCOM	\N	2001	2017-10-01 00:00:00	\N	ANCIEN	\N	de Morlaix Communauté	Membre de la Communauté d'agglomération de Morlaix	NON	\N	2017-11-15 10:19:53
11875	12211	PDTINTCOM	\N	\N	2017-10-15 00:00:00	\N	ANCIEN	\N	Président de la Communauté de communes du Laonnois	Président de la Communauté de communes du Laonnois	NON	\N	2017-10-16 10:23:35
11362	12212	PDTINTCOM	2000-01-01 00:00:00	2000	2008-04-10 00:00:00	2008	ANCIEN	\N	Président de la Communauté d'agglomération Fréjus - Saint-Raphaël	Président de la Communauté d'agglomération Fréjus - Saint-Raphaël	NON	\N	\N
11886	12213	PDTINTCOM	\N	1993	\N	2000	ANCIEN	\N	Président de la Communauté de Communes du Massif du Vercors	Président de la Communauté de Communes du Massif du Vercors	NON	\N	\N
11156	12214	VICPDTINTCOM	1995-07-24 00:00:00	1995	2008-03-21 00:00:00	2008	ANCIEN	\N	Vice-président de la Communauté urbaine de Bordeaux	Vice-président de la Communauté urbaine de Bordeaux	NON	\N	\N
11280	12215	PDTINTCOM	2002-01-15 00:00:00	2002	2008-04-18 00:00:00	2008	ANCIEN	\N	Président de la Communauté de communes de Cambremer	Président de la Communauté de communes de Cambremer	NON	\N	\N
11857	12216	PDTINTCOM	\N	1994	\N	2001	ANCIEN	\N	Président de la Communauté de communes de l'ouest guyanais	Président de la Communauté de communes de l'ouest guyanais	NON	\N	\N
11867	12217	PREPDTINTCOM	\N	2002	\N	\N	ACTIF	\N	Premier Vice-Président de l'Agglopole Provence	Premier Vice-Président de l'Agglopole Provence	NON	\N	\N
11915	12218	VICPDTINTCOM	\N	\N	\N	2008	ANCIEN	\N	Vice-présidente de la communauté de communes du Parisis	Vice-présidente de la communauté de communes du Parisis	NON	\N	\N
11870	12219	PDTINTCOM	\N	1998	\N	\N	ACTIF	\N	Président de l'Airfobep (Association agréée pour la surveillance de la qualité de l'air Etang de Berre Ouest des Bouches	Président de l'Airfobep (Association agréée pour la surveillance de la qualité de l'air Etang de Berre Ouest des Bouches du Rhône)	NON	\N	\N
11871	12220	PDTINTCOM	\N	2000	\N	\N	ACTIF	\N	Président du Groupement d'intérêt public pour la réhabilitation de l'étang de Berre	Président du Groupement d'intérêt public pour la réhabilitation de l'étang de Berre	NON	\N	\N
11872	12221	PDTINTCOM	\N	2001	\N	\N	ACTIF	\N	Président du Syndicat d'aménagement du Bassin de l'arc	Président du Syndicat d'aménagement du Bassin de l'arc	NON	\N	\N
11873	12222	PDTINTCOM	\N	1992	\N	2002	ANCIEN	\N	Président du Multi pôle Étang de Berre	Président du Multi pôle Étang de Berre	NON	\N	\N
11198	12223	PDTINTCOM	\N	2005	\N	\N	ACTIF	\N	Président de l'Agglomération de la région de Compiègne	Président de l'Agglomération de la région de Compiègne	NON	\N	\N
11243	12224	VICPDTINTCOM	\N	\N	2020-06-25 00:00:00	\N	ANCIEN	\N	Vice-président de la Communauté d'agglomération havraise	Vice-président de la Communauté d'agglomération havraise	NON	\N	\N
11953	12225	PDTINTCOM	2008-06-13 00:00:00	\N	\N	\N	ACTIF	\N	Président du pays de la Baie du Mont Saint-Michel	Président du pays de la Baie du Mont Saint-Michel	NON	\N	\N
11977	12226	PDTINTCOM	\N	2009	\N	\N	ACTIF	\N	Président de la communauté de communes du Vézelien	Président de la communauté de communes du Vézelien	NON	\N	\N
12052	12227	PDTINTCOM	2008-03-15 00:00:00	2008	\N	\N	ACTIF	\N	Présidente de la Communauté d'agglomération de Valenciennes Métropole	Présidente de la Communauté d'agglomération de Valenciennes Métropole	NON	\N	\N
11978	12228	PDTINTCOM	\N	\N	\N	2009	ANCIEN	\N	Président du sivom de Vézelay	Président du sivom de Vézelay	NON	\N	\N
11843	12229	CONSINTCOM	2008-04-21 00:00:00	2008	2015-12-31 00:00:00	\N	ANCIEN	\N	Conseiller, Communauté urbaine Marseille Provence Metropole	Conseiller, Communauté urbaine Marseille Provence Metropole	NON	\N	2016-07-08 10:49:09
11287	12230	VICPDTINTCOM	2005-01-01 00:00:00	\N	\N	2010	ANCIEN	\N	Vice-président de la Communauté d'agglomération du Coeur-de-Seine	Vice-président de la Communauté d'agglomération du Coeur-de-Seine	NON	\N	\N
1752	12231	PDTINTCOM	\N	1989	\N	2001	ANCIEN	\N	Président du District du Pays Salonais	Président du District du Pays Salonais	NON	\N	\N
11414	12232	VICPDTINTCOM	\N	2008	2016-12-31 00:00:00	\N	ANCIEN	\N	Vice-présidente de la Communauté de communes de la Porte du Sundgau	Première vice-présidente de la Communauté de communes de la Porte du Sundgau	NON	\N	2017-04-21 14:36:15
1783	12233	PDTINTCOM	\N	1994	\N	2001	ANCIEN	\N	Président de la Communauté de communes du Pays d'Amplepuis-Thizy	Président de la Communauté de communes du Pays d'Amplepuis-Thizy	NON	\N	\N
11817	12234	PDTINTCOM	\N	1997	\N	2004	ANCIEN	\N	Président de la Communauté de communes Auxois-Sud	Président de la Communauté de communes Auxois-Sud	NON	\N	\N
11853	12235	PDTINTCOM	\N	\N	\N	2008	ANCIEN	\N	Président de la Communauté de communes Sud-Bouriane	Président de la Communauté de communes Sud-Bouriane	NON	\N	\N
11216	12236	PDTINTCOM	\N	1989	2005-12-21 00:00:00	2005	ANCIEN	\N	Président de la Communauté de communes de l'Emblavez	Président de la Communauté de communes de l'Emblavez	NON	\N	\N
10863	13085	MAIRE	\N	2013	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11802	12237	PDTINTCOM	2008-04-17 00:00:00	2008	2016-03-21 00:00:00	\N	ANCIEN	\N	Président de la communauté de communes de Bernay et des environs	Président de la communauté de communes de Bernay et des environs	NON	\N	2016-06-02 15:56:44
6332	12001	PDTINTCOM	\N	\N	2008-03-16 00:00:00	2008	ANCIEN	\N	Président de Quimper Communauté	Président de Quimper Communauté	NON	\N	\N
6333	12002	PDTINTCOM	\N	\N	\N	\N	ACTIF	\N	Président de la communauté d'agglomération Haut Val de Marne	Président de la communauté d'agglomération Haut Val de Marne	NON	\N	\N
6336	12003	PDTINTCOM	\N	\N	2023-10-28 00:00:00	\N	ANCIEN	\N	Président du SIVOM de l'agglomération de Mulhouse	Président du SIVOM de l'agglomération de Mulhouse	NON	\N	\N
1760	12004	PDTINTCOM	\N	\N	2020-11-24 00:00:00	\N	ANCIEN	\N	Président du syndicat intercommunal de l'électricité et du gaz de l'Eure	Président du syndicat intercommunal de l'électricité et du gaz de l'Eure	NON	\N	\N
6494	12005	PDTINTCOM	\N	1998	2014-10-01 00:00:00	\N	ANCIEN	\N	Président de la Communauté urbaine d'Arras	Président de la Communauté urbaine d'Arras	NON	\N	2014-10-28 17:14:18
6523	12006	VICPDTINTCOM	\N	\N	\N	\N	ACTIF	\N	Vice-présidente de la Communauté d'agglomération de Tours Plus	Vice-présidente de la Communauté d'agglomération de Tours Plus	NON	\N	\N
6524	12007	PREPDTINTCOM	\N	2001	2014-10-01 00:00:00	\N	ANCIEN	\N	Vice-président d'Angers-Loire-Métropole Communauté d'agglomération	Vice-président d'Angers-Loire-Métropole Communauté d'agglomération	NON	\N	2014-10-27 11:07:41
6539	12008	PDTINTCOM	1995-12-21 00:00:00	1995	2008-04-14 00:00:00	2008	ANCIEN	\N	Président de la Communauté d'agglomération de Saint-Etienne-Métropole	Président de la Communauté d'agglomération de Saint-Etienne-Métropole	NON	\N	\N
6562	12009	PREPDTINTCOM	\N	1993	2001-10-19 00:00:00	2001	ANCIEN	\N	Premier Vice-président de la Communauté d'agglomération de Laval	Premier Vice-président de la Communauté d'agglomération de Laval	NON	\N	\N
6593	12010	PDTINTCOM	2001-01-01 00:00:00	2001	2006-01-01 00:00:00	2006	ANCIEN	\N	Président de la Communauté de communes du canton de Saint-Gildas-des-Bois	Président de la Communauté de communes du canton de Saint-Gildas-des-Bois	NON	\N	\N
6594	12011	PDTINTCOM	\N	\N	2014-09-22 00:00:00	\N	ANCIEN	\N	Président de la Communauté de communes du Pays des lacs	Président de la Communauté de communes du Pays des lacs	NON	\N	2014-09-23 17:58:39
6599	12012	PDTINTCOM	\N	2000	\N	2008	ANCIEN	\N	Président de la Communauté de communes des Cheires	Président de la Communauté de communes des Cheires	NON	\N	\N
6601	12013	PDTINTCOM	\N	1999	\N	\N	ACTIF	\N	Président de la Communauté de communes du Pays de Montmédy	Président de la Communauté de communes du Pays de Montmédy	NON	\N	\N
6604	12014	VICPDTINTCOM	\N	\N	\N	2008	ANCIEN	\N	Vice-présidente de la Communauté de communes du canton de Bergues	Vice-présidente de la Communauté de communes du canton de Bergues	NON	\N	\N
6606	12015	PREPDTINTCOM	2001-12-21 00:00:00	\N	\N	2012	ANCIEN	\N	Première vice-présidente de la Communauté d'agglomération de Blois - Agglopolys	Première vice-présidente de la Communauté d'agglomération de Blois - Agglopolys	NON	\N	2013-06-25 15:46:11
6607	12016	PDTINTCOM	2002-12-31 00:00:00	2002	\N	\N	ACTIF	\N	Président de la Communauté d'agglomération de Nevers	Président de la Communauté d'agglomération de Nevers	NON	\N	\N
6609	12017	VICPDTINTCOM	\N	\N	2001-12-01 00:00:00	2001	ANCIEN	\N	Vice-président de la Communauté urbaine de Cherbourg	Vice-président de la Communauté urbaine de Cherbourg	NON	\N	\N
6617	12018	PDTINTCOM	2000-11-07 00:00:00	2000	\N	\N	ACTIF	\N	Président de la Communauté d'agglomération Perpignan-Méditerranée	Président de la Communauté d'agglomération Perpignan-Méditerranée	NON	\N	\N
1749	12019	PDTINTCOM	\N	1983	2000-06-19 00:00:00	2000	ANCIEN	\N	Président du District urbain d'Oyonnax	Président du District urbain d'Oyonnax	NON	\N	\N
1750	12020	PDTINTCOM	\N	\N	2017-04-04 00:00:00	2017	ANCIEN	\N	Président de la communauté de communes des Duyes et Bléone	Président de la communauté de communes des Duyes et Bléone	NON	\N	\N
1754	12021	PDTINTCOM	\N	1992	\N	\N	ACTIF	\N	Président de la Communauté de communes de la Haute-Saintonge	Président de la Communauté de communes de la Haute-Saintonge	NON	\N	\N
1755	12022	PDTINTCOM	\N	1993	\N	2001	ANCIEN	\N	Président de la Communauté de communes Charente-Arnoult-Coeur de Saintonge	Président de la Communauté de communes Charente-Arnoult-Coeur de Saintonge	NON	\N	\N
1756	12023	PDTINTCOM	\N	\N	2008-03-10 00:00:00	2008	ANCIEN	\N	Président du district de l'agglomération dijonnaise	Président du district de l'agglomération dijonnaise	NON	\N	\N
5233	12024	PDTINTCOM	\N	1994	\N	\N	ACTIF	\N	Président de la Communauté de communes du Pays de Saint-Flour	Président de la Communauté de communes du Pays de Saint-Flour	NON	\N	\N
1761	12025	PDTINTCOM	\N	\N	2010-12-20 00:00:00	2010	ANCIEN	\N	Président du syndicat électrique du Perche	Président du syndicat électrique du Perche	NON	\N	\N
1762	12026	PDTINTCOM	\N	\N	2002-11-11 00:00:00	2002	ANCIEN	\N	Président du SIVOM	Président du SIVOM	NON	\N	\N
1764	12027	PDTINTCOM	\N	\N	\N	2001	ANCIEN	\N	Président de la Communauté de communes des Collines du Perche	Président de la Communauté de communes des Collines du Perche	NON	\N	\N
1767	12028	VICPDTINTCOM	\N	\N	\N	2001	ANCIEN	\N	Vice-président du District de Nantes  	Vice-président du District de Nantes  	NON	\N	\N
1768	12029	PDTINTCOM	\N	\N	\N	2004	ANCIEN	\N	Président de la Communauté de communes de Catus	Président de la Communauté de communes de Catus	NON	\N	\N
1770	12030	PDTINTCOM	\N	\N	2009-12-08 00:00:00	2009	ANCIEN	\N	Président de la Communauté de communes de Montrevault	Président de la Communauté de communes de Montrevault	NON	\N	\N
1772	12031	PDTINTCOM	\N	\N	\N	2005	ANCIEN	\N	Président de la Communauté de communes du canton de Lessay	Président de la Communauté de communes du canton de Lessay	NON	\N	\N
1773	12032	VICPDTINTCOM	\N	\N	\N	\N	ACTIF	\N	Vice-Président de la Communauté de communes de la Sélune	Vice-Président de la Communauté de communes de la Sélune	NON	\N	\N
1777	12033	VICPDTINTCOM	\N	\N	\N	\N	ACTIF	\N	Vice-président de la Communauté d'agglomération de Cambrai	Vice-président de la Communauté d'agglomération de Cambrai	NON	\N	\N
1778	12034	PDTINTCOM	\N	\N	2008-04-02 00:00:00	\N	ANCIEN	\N	Président de Lille-Métropole Communauté urbaine	Président de Lille-Métropole Communauté urbaine	NON	\N	\N
1782	12035	PDTINTCOM	\N	\N	2023-10-21 00:00:00	\N	ANCIEN	\N	Président de la Communauté de Communes des Coteaux de la Mossig	Président de la Communauté de Communes des Coteaux de la Mossig	NON	\N	\N
1784	12036	CONSCOMINT	\N	\N	2014-03-23 00:00:00	\N	ANCIEN	\N	Président du district de Vesoul	Président du district de Vesoul	NON	\N	\N
1785	12037	PDTINTCOM	\N	\N	2008-03-16 00:00:00	2008	ANCIEN	\N	Président de la Communauté de communes entre Saône et Grosne	Président de la Communauté de communes entre Saône et Grosne	NON	\N	\N
1786	12038	PDTINTCOM	\N	1993	\N	2001	ANCIEN	\N	Président de la Communauté de communes Matour et sa région	Président de la Communauté de communes Matour et sa région	NON	\N	\N
1787	12039	PDTINTCOM	\N	\N	\N	\N	ACTIF	\N	Président de la Communauté de communes de Lucé	Président de la Communauté de communes de Lucé	NON	\N	\N
1788	12040	PDTINTCOM	\N	1993	\N	2001	ANCIEN	\N	Président de la Communauté de communes du Pays des Brières et du Gesnois	Président de la Communauté de communes du Pays des Brières et du Gesnois	NON	\N	\N
1790	12041	PDTINTCOM	\N	1989	\N	2001	ANCIEN	\N	Président de la Communauté de communes des Vallées de Thônes	Président de la Communauté de communes des Vallées de Thônes	NON	\N	\N
1791	12042	PDTINTCOM	\N	1993	\N	1998	ANCIEN	\N	Président de la Communauté de communes du Segala-Carmausin	Président de la Communauté de communes du Segala-Carmausin	NON	\N	\N
1792	12043	PDTINTCOM	\N	\N	\N	\N	ACTIF	\N	Président de la Communauté de communes des Deux-Rives	Président de la Communauté de communes des Deux-Rives	NON	\N	\N
1793	12044	PDTINTCOM	\N	\N	2009-04-11 00:00:00	2009	ANCIEN	\N	Président de la Communauté de Communes du SISEL	Président de la Communauté de Communes du SISEL	NON	\N	\N
5214	12045	PDTINTCOM	2002-11-12 00:00:00	2002	2008-04-11 00:00:00	2008	ANCIEN	\N	Président de la Communauté d'agglomération des Portes de l'Eure	Président de la Communauté d'agglomération des Portes de l'Eure	NON	\N	\N
5222	12046	PDTINTCOM	1997-01-19 00:00:00	\N	\N	1999	ANCIEN	\N	Président du district de l'agglomération périgourdine	Président du district de l'agglomération périgourdine	NON	\N	\N
5225	12047	PDTINTCOM	1993-11-22 00:00:00	1993	1999-12-31 00:00:00	1999	ANCIEN	\N	Président de la Communauté de communes Bayeux Intercom	Président de la Communauté de communes Bayeux Intercom	NON	\N	\N
10590	12048	PDTINTCOM	\N	\N	2016-11-03 00:00:00	2016	ANCIEN	\N	Président du Syndicat intercommunal de protection de la Vallée de la Bièvre	Président du Syndicat intercommunal de protection de la Vallée de la Bièvre	NON	\N	\N
10686	12049	VICPDTINTCOM	\N	1983	2007-06-21 00:00:00	2007	ANCIEN	\N	Vice-président du district de l'agglomération de Nancy	Vice-président du district de l'agglomération de Nancy	NON	\N	\N
10711	12050	VICPDTINTCOM	\N	1995	\N	2008	ANCIEN	\N	Vice-Présidente de la Communauté de communes du Pays de Châteaulin et du Porzay	Vice-Présidente de la Communauté de communes du Pays de Châteaulin et du Porzay	NON	\N	\N
10713	12051	CONSINTCOM	\N	2001	2008-04-17 00:00:00	2008	ANCIEN	\N	Conseiller, Marseille-Provence-Métropole Communauté urbaine	Conseiller, Marseille-Provence-Métropole Communauté urbaine	NON	\N	\N
10716	12052	PDTINTCOM	1994-01-01 00:00:00	1994	2016-12-31 00:00:00	\N	ANCIEN	\N	Président de la Communauté de communes de la Plaine de Bourgogne	Président de la Communauté de communes de la Plaine de Bourgogne	NON	\N	2017-04-21 15:12:03
10717	12053	VICPDTINTCOM	\N	2001	2014-10-01 00:00:00	\N	ANCIEN	\N	Vice-Président de la Communauté d'agglomération de Rouen	Vice-Président de la Communauté d'agglomération de Rouen	NON	\N	2014-10-23 16:10:19
10721	12054	VICPDTINTCOM	\N	2001	\N	\N	ACTIF	\N	Vice-président de la Communauté d'agglomération de la Plaine centrale du Val-de-Marne	Vice-président de la Communauté d'agglomération de la Plaine centrale du Val-de-Marne	NON	\N	\N
10725	12055	PDTINTCOM	\N	\N	\N	1999	ANCIEN	\N	Président de la Communauté des communes de Landerneau - Daoulas 	Président de la Communauté des communes de Landerneau - Daoulas 	NON	\N	\N
12054	11802	PREVICPDTREG	2010-03-27 00:00:00	2010	2015-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2015-12-15 15:18:37
10732	12056	PDTINTCOM	\N	2000	2007-12-16 00:00:00	2007	ANCIEN	\N	Président de la Communauté de communes du Coeur de France	Président de la Communauté de communes du Coeur de France	NON	\N	\N
10733	12057	PDTINTCOM	\N	\N	\N	2004	ANCIEN	\N	Président de la Communauté de communes du Moncoutantais "Terre de Sèvre"	Président de la Communauté de communes du Moncoutantais "Terre de Sèvre"	NON	\N	\N
10737	12058	PDTINTCOM	\N	1983	\N	2001	ANCIEN	\N	Président du Syndicat intercommunal à vocations multiples du Pays de Sierentz	Président du Syndicat intercommunal à vocations multiples du Pays de Sierentz	NON	\N	\N
10740	12059	PDTINTCOM	1991-12-27 00:00:00	1991	\N	2001	ANCIEN	\N	Président de la Communauté d'agglomération de Saint-Brieuc	Président de la Communauté d'agglomération de Saint-Brieuc	NON	\N	\N
10773	12060	PDTINTCOM	\N	2001	\N	\N	ACTIF	\N	Président de la Communauté de communes de Sablé-sur-Sarthe	Président de la Communauté de communes de Sablé-sur-Sarthe	NON	\N	\N
10822	12061	VICPDTINTCOM	\N	2001	\N	2008	ANCIEN	\N	Vice-présidente de la Communauté de communes de la Porte du Sundgau	Vice-présidente de la Communauté de communes de la Porte du Sundgau	NON	\N	\N
11402	12062	CONSINTCOM	2008-03-09 00:00:00	2008	2014-03-30 00:00:00	\N	ANCIEN	\N	Conseiller, Communauté d'agglomération de Laval	Conseiller, Communauté d'agglomération de Laval	NON	\N	2014-10-23 10:57:28
10891	12063	PDTDELINTCOM	2001-03-18 00:00:00	2001	2008-04-18 00:00:00	2008	ANCIEN	\N	Présidente déléguée de la Communauté urbaine de Strasbourg	Présidente déléguée de la Communauté urbaine de Strasbourg	NON	\N	\N
11009	12064	PDTINTCOM	\N	1995	2016-12-31 00:00:00	\N	ANCIEN	\N	Président de la Communauté de communes du Haut-Clocher	Président de la Communauté de communes du Haut-Clocher	NON	\N	\N
11019	12065	PDTINTCOM	\N	1993	2015-03-16 00:00:00	\N	ANCIEN	\N	Président de la Communauté de communes des Pays du Rhône et d'Ouvèze	Président de la Communauté de communes des Pays du Rhône et d'Ouvèze	NON	\N	2015-03-17 15:42:26
11038	12066	CONSINTCOM	\N	1995	2014-12-31 00:00:00	2014	ANCIEN	\N	Conseiller, Communauté urbaine du Grand Lyon	Conseiller, Communauté urbaine du Grand Lyon	NON	\N	2015-01-16 09:47:00
11041	12067	VICPDTINTCOM	\N	2001	\N	\N	ACTIF	\N	Vice-président de la Communauté d'agglomération du Haut-Val-de-Marne	Vice-président de la Communauté d'agglomération du Haut-Val-de-Marne	NON	\N	\N
11042	12068	PDTINTCOM	\N	2004	\N	2006	ANCIEN	\N	Président de la Communauté de communes de Charenton-le-Pont - Saint-Maurice	Président de la Communauté de communes de Charenton-le-Pont - Saint-Maurice	NON	\N	\N
11055	12069	PDTINTCOM	\N	2001	2005-03-31 00:00:00	2005	ANCIEN	\N	Président de la Communauté d'agglomération de Mulhouse Sud Alsace	Président de la Communauté d'agglomération de Mulhouse Sud Alsace	NON	\N	\N
11059	12070	VICPDTINTCOM	\N	1982	\N	2008	ANCIEN	\N	Vice-président de la Communauté d'agglomération dracénoise	Vice-président de la Communauté d'agglomération dracénoise	NON	\N	\N
11062	12071	PDTINTCOM	\N	1997	\N	2001	ANCIEN	\N	Président de la Communauté urbaine de Strasbourg	Président de la Communauté urbaine de Strasbourg	NON	\N	\N
11066	12072	CONSINTCOM	\N	2001	2014-04-01 00:00:00	\N	ANCIEN	\N	Conseillère, Communauté d'agglomération Melun - Val-de-Seine	Conseillère, Communauté d'agglomération Melun - Val-de-Seine	NON	\N	2014-05-28 14:52:13
11085	12073	CONSINTCOM	\N	2001	\N	2008	ANCIEN	\N	Conseillère, Communauté d'agglomération de Rouen	Conseillère, Communauté d'agglomération de Rouen	NON	\N	\N
11071	12074	PDTINTCOM	\N	2001	2004-12-23 00:00:00	2004	ANCIEN	\N	Président de la Communauté d'agglomération Chambéry-Métropole	Président de la Communauté d'agglomération Chambéry-Métropole	NON	\N	\N
11075	12075	PDTINTCOM	\N	1991	2008-03-16 00:00:00	2008	ANCIEN	\N	Président de la Communauté de communes du canton de Cuiseaux	Président de la Communauté de communes du canton de Cuiseaux	NON	\N	\N
11979	12256	VICPDTINTCOM	1989-03-25 00:00:00	1989	2003-03-25 00:00:00	2003	ANCIEN	\N	Vice-président de la communauté d'agglomération de Villefranche	Vice-président de la communauté d'agglomération de Villefranche	NON	\N	\N
5880	12257	PDTINTCOM	\N	1995	2014-03-28 00:00:00	\N	ANCIEN	\N	Président de la Communauté d'agglomération de Saint-Quentin	Président de la Communauté d'agglomération de Saint-Quentin	NON	\N	2014-04-07 09:53:01
11646	11680	CONSMUNI	\N	1983	\N	1989	ANCIEN	\N	\N	\N	NON	\N	\N
11715	11681	VICPDTGEN	\N	2004	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11879	11684	CONSREG	\N	\N	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11887	11697	MAIRE	\N	1989	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
11888	11698	MAIREADJOINT	\N	1997	\N	1983	ANCIEN	\N	\N	\N	NON	\N	\N
11889	11699	CONSGENE	\N	1973	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
11890	11700	CONSMUNI	\N	1989	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
11891	11701	MAIRE	\N	1989	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11523	11676	CONSMUNI	\N	1977	1995-05-20 00:00:00	1995	ANCIEN	\N	\N	\N	NON	\N	2014-04-07 16:31:14
11892	11702	MAIRE	\N	1983	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
11893	11703	VICPDTGEN	\N	1992	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
11894	11704	CONSMUNI	\N	1983	\N	1989	ANCIEN	\N	\N	\N	NON	\N	\N
11895	11705	CONSMUNI	\N	1989	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
11896	11706	MAIREADJOINT	\N	1977	\N	1979	ANCIEN	\N	\N	\N	NON	\N	\N
11897	11707	CONSGENE	\N	1992	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
11898	11708	MAIREADJOINT	\N	1983	\N	1986	ANCIEN	\N	\N	\N	NON	\N	\N
11899	11709	VICPDTREG	\N	1992	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
11900	11710	CONSGENE	\N	1994	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
6049	11711	CONSMUNI	\N	2008	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11901	11712	CONSREG	\N	1986	\N	1989	ANCIEN	\N	\N	\N	NON	\N	\N
11902	11713	VICPDTGEN	\N	1985	\N	1993	ANCIEN	\N	\N	\N	NON	\N	\N
11903	11714	MAIRE	\N	1971	\N	1977	ANCIEN	\N	\N	\N	NON	\N	\N
11904	11715	MAIREADJOINT	\N	1983	\N	1989	ANCIEN	\N	\N	\N	NON	\N	\N
10676	11745	PREMADJOINT	2014-04-01 00:00:00	\N	2017-10-23 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-11-09 10:45:08
11617	11759	CONSGENE	\N	2008	2011-03-28 00:00:00	2011	ANCIEN	\N	\N	\N	NON	\N	\N
1462	2829	VICPDTGEN	2001-03-23 00:00:00	2001	2004-03-28 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
12008	11768	VICPDTREG	\N	2008	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6113	2604	MAIRE	2001-03-17 00:00:00	2001	2010-10-23 00:00:00	2010	ANCIEN	\N	\N	\N	NON	\N	\N
10218	3388	CONSGENE	\N	\N	2010-10-31 00:00:00	2010	ANCIEN	\N	\N	\N	NON	\N	\N
10762	11799	PDTGEN	2010-12-01 00:00:00	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12054	11803	CONSREG	\N	1998	2009-09-13 00:00:00	2009	ANCIEN	\N	\N	\N	NON	\N	2015-12-15 15:18:37
12055	11804	MAIRE	\N	1995	2011-01-09 00:00:00	2011	ANCIEN	\N	\N	\N	NON	\N	\N
12057	11805	MAIREADJOINT	\N	2008	2016-01-12 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2016-06-02 17:14:40
12058	11806	MAIRE	\N	1989	2010-05-10 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11231	11168	CONSMUNI	\N	1971	\N	1989	ANCIEN	\N	\N	\N	NON	\N	\N
11466	11416	PDTGEN	2004-04-01 00:00:00	2004	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11465	11411	CONSMUNI	\N	1977	\N	1986	ANCIEN	\N	\N	\N	NON	\N	\N
11465	11412	MAIRE	\N	1986	2004-04-01 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11465	11413	MAIREADJOINT	2004-04-01 00:00:00	2004	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11907	11718	CONSGENE	\N	1976	\N	1982	ANCIEN	\N	\N	\N	NON	\N	\N
11466	11415	PREVICPDTGEN	1998-03-22 00:00:00	1998	2004-04-01 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11906	11717	CONSMUNI	\N	1971	\N	1977	ANCIEN	\N	\N	\N	NON	\N	\N
11908	11719	CONSREG	\N	1986	\N	1989	ANCIEN	\N	\N	\N	NON	\N	\N
11272	11720	VICPDTGEN	\N	2008	2014-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-10-21 17:19:15
11909	11721	CONSMUNI	\N	1979	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11910	11722	CONSGENE	\N	1976	\N	1982	ANCIEN	\N	\N	\N	NON	\N	\N
11911	11723	CONSGENE	\N	1973	2009-09-09 00:00:00	2009	ANCIEN	\N	\N	\N	NON	\N	\N
1698	1698	DEPUTE	1978-03-19 00:00:00	1978	1981-05-22 00:00:00	1981	ANCIEN	\N	\N	\N	NON	\N	2016-12-12 09:55:05
1716	1716	DEPUTE	1973-03-11 00:00:00	1973	1978-04-02 00:00:00	1978	ANCIEN	\N	\N	\N	NON	\N	2016-12-09 10:31:14
1738	1738	DEPUTE	1988-06-12 00:00:00	\N	1995-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2016-12-12 12:09:27
5003	2002	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
5041	2015	CONSGENE	1994-03-27 00:00:00	1994	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6092	2680	MAIRE	2001-03-17 00:00:00	2001	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
10223	3393	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
1707	1707	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6268	2729	MAIREADJOINT	2001-03-17 00:00:00	2001	2008-03-21 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11189	11382	MAIREADJOINT	\N	2008	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11707	11648	MAIREADJOINT	\N	1977	\N	2002	ANCIEN	\N	\N	\N	NON	\N	\N
11806	11649	CONSGENE	\N	1998	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11807	11650	MAIRE	1995-03-01 00:00:00	1995	2014-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-16 17:54:50
11808	11651	CONSGENE	2004-07-09 00:00:00	2004	2008-03-16 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6100	11271	CONSMUNI	\N	2008	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11602	11653	CONSGENE	\N	2004	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11811	11654	MAIREADJOINT	2001-03-01 00:00:00	2001	\N	2015	ANCIEN	\N	\N	\N	NON	\N	2016-09-13 16:39:53
11814	11655	VICPDTGEN	\N	\N	2011-03-27 00:00:00	2011	ANCIEN	\N	\N	\N	NON	\N	\N
10849	10904	VICPDTGEN	\N	2004	2008-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10880	10918	CONSPARI	\N	1995	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
11492	11657	CONSMUNI	\N	1995	\N	1999	ANCIEN	\N	\N	\N	NON	\N	\N
11590	11479	MAIRE	\N	1989	2017-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-11-08 15:59:02
11633	11512	VICPDTGEN	2004-03-28 00:00:00	2004	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11670	11539	MAIRE	\N	1989	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11694	11565	MAIRE	1983-03-13 00:00:00	\N	2001-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11753	11611	CONSGENE	\N	1998	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6500	11784	CONSMUNI	1993-05-16 00:00:00	1993	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11518	11434	CONSREG	2004-03-28 00:00:00	\N	2010-03-15 00:00:00	2010	ANCIEN	\N	\N	\N	NON	\N	\N
12029	11780	MAIRE	\N	1997	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12059	11807	CONSMUNI	2010-05-11 00:00:00	\N	2020-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
10654	11785	PREVICPDTGEN	\N	2008	2011-03-27 00:00:00	2011	ANCIEN	\N	\N	\N	NON	\N	\N
12036	11786	CONSGENE	\N	2010	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11655	11787	CONSGENE	\N	2010	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6125	11788	CONSGENE	\N	2010	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12062	11808	MAIREADJOINT	\N	2001	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6571	11232	MAIRE	2008-03-21 00:00:00	2008	2014-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-09 22:40:46
11320	11233	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6023	11234	MAIRE	2008-03-14 00:00:00	2008	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10896	11282	CONSPARI	2008-03-22 00:00:00	2008	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11325	11242	MAIRE	2008-03-21 00:00:00	2008	2021-09-09 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11361	11323	MAIRE	\N	1997	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11363	11324	VICPDTGEN	\N	2004	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11363	11325	CONSGENE	\N	1998	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
1356	11386	PDTGEN	2001-03-23 00:00:00	2001	2008-03-20 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
1356	11387	CONSGENE	2001-03-11 00:00:00	2001	2001-03-23 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
1356	11388	CONSGENE	2008-03-16 00:00:00	2008	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6023	11389	MAIRE	1977-03-20 00:00:00	1977	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6094	11390	MAIRE	1995-06-18 00:00:00	1995	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6094	11391	CONSMUNI	1983-03-13 00:00:00	1983	1995-06-18 00:00:00	1995	ANCIEN	\N	\N	\N	NON	\N	\N
6268	11393	MAIRE	1977-03-20 00:00:00	1977	2001-03-11 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6268	11394	CONSMUNI	1971-03-21 00:00:00	1971	1977-03-20 00:00:00	1977	ANCIEN	\N	\N	\N	NON	\N	\N
6268	11395	CONSMUNI	2008-03-21 00:00:00	2008	2017-05-15 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-05-16 15:18:13
1434	11396	CONSGENE	1985-03-17 00:00:00	1985	1992-03-29 00:00:00	1992	ANCIEN	\N	\N	\N	NON	\N	\N
1434	11397	PDTGEN	2008-03-20 00:00:00	2008	2011-03-30 00:00:00	2011	ANCIEN	\N	\N	\N	NON	\N	\N
11913	11724	PDTREG	\N	1981	\N	1985	ANCIEN	\N	\N	\N	NON	\N	\N
11905	11716	CONSREG	\N	1983	\N	1986	ANCIEN	\N	\N	\N	NON	\N	\N
11914	11725	CONSGENE	\N	1982	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11916	11726	PDTREG	\N	1974	\N	1981	ANCIEN	\N	\N	\N	NON	\N	\N
11917	11727	CONSGENE	\N	1967	\N	1973	ANCIEN	\N	\N	\N	NON	\N	\N
11448	12244	PDTINTCOM	2002-12-18 00:00:00	2002	\N	\N	ACTIF	\N	Président de la Communauté de communes du Bonnevalais	Président de la Communauté de communes du Bonnevalais	NON	\N	\N
11449	12245	CONSINTCOM	\N	2000	\N	\N	ACTIF	\N	Conseiller, Communauté de communes d'Arrats-Gimone	Conseiller, Communauté de communes d'Arrats-Gimone	NON	\N	\N
11450	12246	CONSINTCOM	1999-12-31 00:00:00	1999	\N	2008	ANCIEN	\N	Conseiller, Communauté de communes Bayeux Intercom	Conseiller, Communauté de communes Bayeux Intercom	NON	\N	\N
11435	12122	PDTINTCOM	\N	1992	2014-04-14 00:00:00	\N	ANCIEN	\N	Président de la Communauté de communes des Vallées de la Brèche et de la Noye	Président de la Communauté de communes des Vallées de la Brèche et de la Noye	NON	\N	2017-04-21 11:58:37
11436	12123	CONSINTCOM	2008-04-10 00:00:00	2008	\N	\N	ACTIF	\N	Conseillère, Communauté de communes de Benfeld et environs	Conseillère, Communauté de communes de Benfeld et environs	NON	\N	\N
11437	12124	VICPDTINTCOM	\N	2001	\N	2008	ANCIEN	\N	Vice-présidente de la Communaupole de Lens-Liévin	Vice-présidente de la Communaupole de Lens-Liévin	NON	\N	\N
11439	12125	CONSINTCOM	\N	1997	\N	\N	ACTIF	\N	Conseiller, Communauté de communes de Haute-Charente	Conseiller, Communauté de communes de Haute-Charente	NON	\N	\N
11440	12126	VICPDTINTCOM	2008-04-08 00:00:00	2008	\N	\N	ACTIF	\N	Vice-président de la Communauté d'agglomération Val-et-Forêt	Premier vice-président de la Communauté d'agglomération Val-et-Forêt	NON	\N	2017-04-21 11:42:19
11441	12127	PDTINTCOM	2001-04-05 00:00:00	2001	2008-04-08 00:00:00	2008	ANCIEN	\N	Président de la Communauté d'agglomération Val-et-Forêt	Président de la Communauté d'agglomération Val-et-Forêt	NON	\N	\N
11445	12128	PDTINTCOM	2008-04-10 00:00:00	2008	\N	2014	ANCIEN	\N	Président de la Communauté de communes du Sillon Mosellan	Président de la Communauté de communes du Sillon Mosellan	NON	\N	2014-11-20 12:28:34
11625	12129	VICPDTINTCOM	2008-04-17 00:00:00	2008	2020-05-11 00:00:00	\N	ANCIEN	\N	Vice-président de la  Communauté urbaine Marseille-Provence-Métropole	Vice-président de la  Communauté urbaine Marseille-Provence-Métropole	NON	\N	\N
11666	12130	VICPDTINTCOM	2008-04-01 00:00:00	2008	2016-12-31 00:00:00	\N	ANCIEN	\N	Vice-présidente de la Communauté d'agglomération du Pays d'Aix	Vice-présidente de la Communauté d'agglomération du Pays d'Aix	NON	\N	2017-11-30 16:56:23
11703	12131	CONSINTCOM	\N	1992	\N	1995	ANCIEN	\N	Conseiller, Communauté de communes du Bassin de vie de Bourg-en-Bresse	Conseiller, Communauté de communes du Bassin de vie de Bourg-en-Bresse	NON	\N	\N
11196	12132	VICPDTINTCOM	\N	1995	\N	\N	ACTIF	\N	Vice-président de la Communauté de communes du Saint-Chinianais	Vice-président de la Communauté de communes du Saint-Chinianais	NON	\N	\N
11268	12133	PDTINTCOM	\N	\N	2008-04-18 00:00:00	2008	ANCIEN	\N	Présidente de la Communauté de communes rurales des Monts de Flandres	Présidente de la Communauté de communes rurales des Monts de Flandres	NON	\N	\N
11348	12134	PREPDTINTCOM	2008-04-08 00:00:00	2008	\N	\N	ACTIF	\N	Première vice-présidente de la Communauté d'agglomération Toulon-Provence-Méditerrannée	Première vice-présidente de la Communauté d'agglomération Toulon-Provence-Méditerrannée	NON	\N	\N
11713	12135	VICPDTINTCOM	\N	2008	2014-11-03 00:00:00	\N	ANCIEN	\N	Vice-présidente de la Communauté de communes Bugey-Vallée de l'Ain	Vice-présidente de la Communauté de communes Bugey-Vallée de l'Ain	NON	\N	2014-11-05 15:34:35
11784	12136	PDTINTCOM	\N	2001	\N	\N	ACTIF	\N	Président de la Communauté d'agglomération du Grand Dijon	Président de la Communauté d'agglomération du Grand Dijon	NON	\N	\N
11424	12174	VICPDTINTCOM	\N	\N	\N	\N	ACTIF	\N	Vice-président de la Communauté de communes Auzances - Bellegarde	Vice-président de la Communauté de communes Auzances - Bellegarde	NON	\N	\N
11403	12175	PREPDTINTCOM	\N	2008	\N	\N	ACTIF	\N	Premier vice-président de la Communauté d'agglomération de Bayonne-Anglet-Biarritz	Premier vice-président de la Communauté d'agglomération de Bayonne-Anglet-Biarritz	NON	\N	\N
11404	12176	CONSINTCOM	\N	2008	2014-04-01 00:00:00	\N	ANCIEN	\N	Conseiller, Communauté d'agglomération dracénoise	Conseiller, Communauté d'agglomération dracénoise	NON	\N	2014-04-08 15:57:42
11405	12177	PREPDTINTCOM	2008-04-10 00:00:00	2008	\N	\N	ACTIF	\N	Premier vice-président de la Communauté d'agglomération Fréjus - Saint-Raphaël	Premier vice-président de la Communauté d'agglomération Fréjus - Saint-Raphaël	NON	\N	\N
11406	12178	PDTINTCOM	2008-04-10 00:00:00	2008	\N	\N	ACTIF	\N	Président de la Communauté de communes du Mirebellois	Président de la Communauté de communes du Mirebellois	NON	\N	\N
11407	12179	VICPDTINTCOM	2008-04-17 00:00:00	2008	\N	\N	ACTIF	\N	Vice-président de Marseille-Provence-Métropole Communauté urbaine	Vice-président de Marseille-Provence-Métropole Communauté urbaine	NON	\N	\N
11408	12180	CONSINTCOM	\N	2008	\N	\N	ACTIF	\N	Conseillère, Communauté de communes du canton de Bergues	Conseillère, Communauté de communes du canton de Bergues	NON	\N	\N
11425	12181	VICPDTINTCOM	2006-01-01 00:00:00	2006	2009-01-01 00:00:00	2009	ANCIEN	\N	Vice-président de la Communauté de communes du Parisis	Vice-président de la Communauté de communes du Parisis	NON	\N	\N
11426	12182	CONSINTCOM	\N	2008	\N	\N	ACTIF	\N	Conseillère, Communauté d'agglomération de Bayonne-Anglet-Biarritz	Conseillère, Communauté d'agglomération de Bayonne-Anglet-Biarritz	NON	\N	\N
11669	13077	CONSMUNI	2009-06-09 00:00:00	2009	2009-07-25 00:00:00	2009	ANCIEN	\N	\N	\N	NON	\N	\N
11427	12183	CONSINTCOM	2003-12-12 00:00:00	2003	2016-10-10 00:00:00	\N	ANCIEN	\N	Conseiller, Communauté de communes Plaines et Forêts d'Yvelines	Conseiller, Communauté de communes Plaines et Forêts d'Yvelines	NON	\N	2016-10-25 11:46:32
11453	12184	VICPDTINTCOM	\N	2004	2015-01-15 00:00:00	2015	ANCIEN	\N	Vice-président de la Communauté de communes d'Artagnan-en-Fézensac	Vice-président de la Communauté de communes d'Artagnan-en-Fézensac	NON	\N	\N
11454	12185	CONSINTCOM	2008-04-11 00:00:00	2008	\N	\N	ACTIF	\N	Conseiller, Communauté de communes de Rivière-Chinon-Saint-Benoist-la-Forêt	Conseiller, Communauté de communes de Rivière-Chinon-Saint-Benoist-la-Forêt	NON	\N	\N
11455	12186	VICPDTINTCOM	\N	2001	2008-04-11 00:00:00	2008	ANCIEN	\N	Vice-président de la Communauté de communes de Rivière-Chinon-Saint-Benoist-la-Forêt	Vice-président de la Communauté de communes de Rivière-Chinon-Saint-Benoist-la-Forêt	NON	\N	\N
11457	12187	CONSINTCOM	\N	2001	\N	\N	ACTIF	\N	Conseiller, Communauté de communes du canton de Saint-Béat	Conseiller, Communauté de communes du canton de Saint-Béat	NON	\N	\N
11380	12164	PDTINTCOM	2000-06-19 00:00:00	2000	2001-03-11 00:00:00	2001	ANCIEN	\N	Président de la Communauté de commune d'Oyonnax	Président de la Communauté de commune d'Oyonnax	NON	\N	\N
11458	12188	VICPDTINTCOM	\N	2008	2014-04-01 00:00:00	\N	ANCIEN	\N	Vice-présidente de la Communauté de communes du Jarnisy	Vice-présidente de la Communauté de communes du Jarnisy	NON	\N	2014-04-09 22:41:18
11459	12189	CONSINTCOM	\N	2001	\N	2008	ANCIEN	\N	Conseillère, Communauté de communes du Jarnisy	Conseillère, Communauté de communes du Jarnisy	NON	\N	\N
11460	12190	CONSINTCOM	\N	1997	2014-10-01 00:00:00	\N	ANCIEN	\N	Conseillère, Communauté de communes du Châtillonnais	Conseillère, Communauté de communes du Châtillonnais	NON	\N	2014-10-30 11:27:05
11461	12191	VICPDTINTCOM	\N	1995	\N	1997	ANCIEN	\N	Vice-présidente de la Communauté de communes du Châtillonnais	Vice-présidente de la Communauté de communes du Châtillonnais	NON	\N	\N
11842	12137	VICPDTINTCOM	\N	2001	\N	2009	ANCIEN	\N	Vice-présidente de la Communauté d'agglomération de la Riviera	Vice-présidente de la Communauté d'agglomération de la Riviera	NON	\N	\N
11809	12138	VICPDTINTCOM	2008-07-01 00:00:00	2008	2013-02-06 00:00:00	2013	ANCIEN	\N	Vice-Président de la Communauté urbaine Nice-Côte d'Azur	Vice-Président de la Communauté urbaine Nice-Côte d'Azur	NON	\N	\N
11810	12139	PDTINTCOM	\N	2002	\N	2012	ANCIEN	\N	Présidente de la Communauté de communes autour de Lédignan	Présidente de la Communauté de communes autour de Lédignan	NON	\N	\N
11813	12140	VICPDTINTCOM	\N	\N	\N	\N	ACTIF	\N	Vice-présidente de la Communauté d'agglomération Vitré-Communauté	Vice-présidente de la Communauté d'agglomération Vitré-Communauté	NON	\N	\N
11288	12141	PDTINTCOM	\N	\N	2008-03-17 00:00:00	2008	ANCIEN	\N	Président de la Communauté de communes de Bernay et des environs	Président de la Communauté de communes de Bernay et des environs	NON	\N	\N
11367	12142	PDTINTCOM	\N	\N	\N	2008	ANCIEN	\N	Président de la Communauté de communes des Monts de Châlus	Président de la Communauté de communes des Monts de Châlus	NON	\N	\N
11593	12143	PDTINTCOM	\N	1993	2017-11-09 00:00:00	\N	ANCIEN	\N	Président de la Communauté de communes Lauragais-Revel-Sorézois	Président de la Communauté de communes Lauragais-Revel-Sorézois	NON	\N	2017-11-08 16:07:40
11573	12144	VICPDTINTCOM	2001-03-01 00:00:00	2001	2014-04-01 00:00:00	\N	ANCIEN	\N	Vice-présidente de la Communauté urbaine de Bordeaux	Vice-présidente de la Communauté urbaine de Bordeaux	NON	\N	2014-04-08 15:53:41
11624	12145	VICPDTINTCOM	2014-03-01 00:00:00	\N	2017-10-02 00:00:00	\N	ANCIEN	\N	Vice-Président de la Communauté d'Agglomération Sophia Antipolis	Vice-Président de la Communauté d'Agglomération Sophia Antipolis	NON	\N	\N
11636	12146	PDTINTCOM	\N	2002	\N	2014	ANCIEN	\N	Président de la Communauté d'agglomération Pôle Azur Provence	Président de la Communauté d'agglomération Pôle Azur Provence	NON	\N	2014-04-09 10:49:08
11657	12147	PREPDTINTCOM	2002-01-01 00:00:00	2002	2015-12-31 00:00:00	\N	ANCIEN	\N	Premier vice-président de la Communauté urbaine Nice-Côte d'Azur	Premier vice-président de la Communauté urbaine Nice-Côte d'Azur	NON	\N	2016-07-08 11:09:05
11415	12148	CONSINTCOM	2008-04-11 00:00:00	2008	\N	\N	ACTIF	\N	Conseiller, Communauté de communes Arguenon-Hunaudaye	Conseiller, Communauté de communes Arguenon-Hunaudaye	NON	\N	\N
11832	12149	VICPDTINTCOM	2008-04-17 00:00:00	2008	\N	2013	ANCIEN	\N	Vice-présidente de Marseille-Provence-Métropole Communauté urbaine	Vice-présidente de Marseille-Provence-Métropole Communauté urbaine	NON	\N	2015-03-17 17:50:27
11671	12150	PDTINTCOM	\N	1989	\N	2010	ANCIEN	\N	Président de la Communauté de communes du Pays d'Argentat	Président de la Communauté de communes du Pays d'Argentat	NON	\N	\N
11696	12151	PDTINTCOM	\N	1986	2014-04-01 00:00:00	\N	ANCIEN	\N	Président de la Communauté de communes du Pays de la Serre	Président de la Communauté de communes du Pays de la Serre	NON	\N	2014-04-09 10:57:27
11709	12152	PDTINTCOM	\N	2001	2014-09-30 00:00:00	\N	ANCIEN	\N	Président de la Communauté d'agglomération périgourdine	Président de la Communauté d'agglomération périgourdine	NON	\N	2014-12-11 16:12:17
11847	12153	PDTINTCOM	\N	\N	2008-10-24 00:00:00	\N	ANCIEN	\N	Président de la Communauté de communes de la région de Pons	Président de la Communauté de communes de la région de Pons	NON	\N	\N
11865	12154	VICPDTINTCOM	2001-04-01 00:00:00	2001	2004-03-31 00:00:00	2004	ANCIEN	\N	Vice-président de la Communauté d'agglomération de Montpellier	Vice-président de la Communauté d'agglomération de Montpellier	NON	\N	\N
11018	13086	MAIREADJOINT	2012-01-01 00:00:00	2012	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11195	13089	CONSGENE	\N	2013	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11866	12155	PREPDTINTCOM	2008-03-09 00:00:00	2008	2012-07-13 00:00:00	2012	ANCIEN	\N	Premier Vice-Président de la Communauté de communes de Privas-Rhônes-Vallées	Premier Vice-Président de la Communauté de communes de Privas-Rhônes-Vallées	NON	\N	\N
11175	12156	PDTINTCOM	\N	2000	2017-09-30 00:00:00	\N	ANCIEN	\N	Président de la Communauté de communes des Vals de Cher et d'Arnon	Président de la Communauté de communes des Vals de Cher et d'Arnon	NON	\N	2018-02-01 14:16:39
11179	12157	PDTINTCOM	\N	\N	\N	\N	ACTIF	\N	Présidente de la Communauté de communes de Saint-Laurent-de-Neste	Présidente de la Communauté de communes de Saint-Laurent-de-Neste	NON	\N	\N
11309	12158	PREPDTINTCOM	\N	2006	2015-12-31 00:00:00	\N	ANCIEN	\N	Premier vice-président de la Communauté de communes de Charenton-le-Pont - Saint-Maurice	Premier vice-président de la Communauté de communes de Charenton-le-Pont - Saint-Maurice	NON	\N	2016-07-08 10:53:04
11463	12159	VICPDTINTCOM	\N	\N	2017-10-24 00:00:00	\N	ANCIEN	\N	Vice-président de la Communauté de communes de Quillebeuf-sur-Seine	Vice-président de la Communauté de communes de Quillebeuf-sur-Seine	NON	\N	2017-11-09 18:01:07
11738	12160	PDTINTCOM	\N	\N	2014-10-01 00:00:00	\N	ANCIEN	\N	Président de la Communauté d'agglomération Castelroussine	Président de la Communauté d'agglomération Castelroussine	NON	\N	2014-10-10 15:51:11
11259	12161	PDTINTCOM	\N	1993	\N	2006	ANCIEN	\N	Président de la Communauté de communes de Saint-Saëns - Porte-de-Bray	Président de la Communauté de communes de Saint-Saëns - Porte-de-Bray	NON	\N	\N
11364	12162	CONSINTCOM	2008-04-18 00:00:00	2008	2015-12-31 00:00:00	\N	ANCIEN	\N	Conseillère, Communauté urbaine de Strasbourg	Conseillère, Communauté urbaine de Strasbourg	NON	\N	2016-07-08 11:10:58
11365	12163	PREPDTINTCOM	2008-04-18 00:00:00	2008	\N	\N	ACTIF	\N	Premier Vice-président de la Communauté urbaine de Strasbourg	Premier Vice-président de la Communauté urbaine de Strasbourg	NON	\N	\N
10952	13081	CONSMUNI	2008-01-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11974	11751	CONSGENE	\N	1992	2011-03-30 00:00:00	2011	ANCIEN	\N	\N	\N	NON	\N	\N
11416	12165	CONSINTCOM	2004-11-04 00:00:00	2004	\N	\N	ACTIF	\N	Conseiller, Communauté d'agglomération Mâconnais - Val-de-Saône	Conseiller, Communauté d'agglomération Mâconnais - Val-de-Saône	NON	\N	\N
11417	12166	CONSINTCOM	2008-04-17 00:00:00	2008	2009-05-25 00:00:00	2009	ANCIEN	\N	Conseiller, Marseille-Provence-Métropole Communauté urbaine	Conseiller, Marseille-Provence-Métropole Communauté urbaine	NON	\N	\N
11418	12167	VICPDTINTCOM	\N	2001	\N	\N	ACTIF	\N	Vice-président de la Communauté d'agglomération de Rouen	Vice-président de la Communauté d'agglomération de Rouen	NON	\N	\N
11419	12168	VICPDTINTCOM	\N	\N	\N	\N	ACTIF	\N	Vice-président de la Communauté d'agglomération Arc-de-Seine	Vice-président de la Communauté d'agglomération Arc-de-Seine	NON	\N	\N
11420	12169	PDTINTCOM	2008-04-11 00:00:00	2008	\N	2011	ANCIEN	\N	Président de la Communauté d'agglomération Seine-Essonne	Président de la Communauté d'agglomération Seine-Essonne	NON	\N	\N
11421	12170	VICPDTINTCOM	\N	2001	\N	\N	ACTIF	\N	Vice-président de la Communauté de communes du Pays Yonnais	Vice-président de la Communauté de communes du Pays Yonnais	NON	\N	\N
11422	12171	PDTINTCOM	\N	\N	2021-09-09 00:00:00	\N	ANCIEN	\N	Présidente de la Communauté de communes du Sud-Basse-Terre	Présidente de la Communauté de communes du Sud-Basse-Terre	NON	\N	\N
11423	12172	VICPDTINTCOM	\N	\N	2022-11-21 00:00:00	\N	ANCIEN	\N	Vice-président de la Communauté d'agglomération de Bastia	Vice-président de la Communauté d'agglomération de Bastia	NON	\N	\N
12022	12173	PDTINTCOM	2010-01-01 00:00:00	\N	2015-12-31 00:00:00	\N	ANCIEN	\N	Président de la Communauté d'agglomération du Coeur-de-Seine	Président de la Communauté d'agglomération du Coeur-de-Seine	NON	\N	2016-07-08 10:53:43
11677	11546	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-06-15 10:51:38
11786	11637	CONSREG	\N	1994	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
11798	11642	CONSARR	2008-03-16 00:00:00	2008	2014-03-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-08 16:31:57
11706	11569	CONSREG	1998-03-15 00:00:00	1998	2004-03-21 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11781	11634	CONSGENE	\N	1998	2008-10-24 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11712	11576	MAIRE	1995-06-18 00:00:00	1995	2017-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-11-10 10:30:04
11720	11587	MAIRE	1995-06-18 00:00:00	1995	2014-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-07 14:45:20
11783	11636	MAIRE	\N	2001	2014-04-06 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-16 17:13:50
11492	11658	MAIREADJOINT	\N	1999	2001-03-17 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-10-16 10:23:35
11632	11659	MAIREADJOINT	\N	1977	\N	1983	ANCIEN	\N	\N	\N	NON	\N	\N
11776	11677	MAIREADJOINT	1986-03-01 00:00:00	1986	1997-04-29 00:00:00	1997	ANCIEN	\N	\N	\N	NON	\N	2017-11-15 10:31:01
10628	11139	CONSGENE	2006-06-01 00:00:00	2006	2011-03-27 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11023	11245	CONSMUNI	2008-03-21 00:00:00	2008	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11334	11284	MAIRE	2008-03-16 00:00:00	\N	2022-05-07 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11553	11665	CONSMUNI	1983-03-08 00:00:00	1983	1995-06-09 00:00:00	1995	ANCIEN	\N	\N	\N	NON	\N	2017-12-18 15:52:45
6525	11286	CONSMUNI	2008-03-16 00:00:00	\N	2014-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-09-08 11:55:11
11335	11287	CONSMUNI	2008-03-21 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6157	11288	CONSMUNI	2008-03-21 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11851	11669	CONSMUNI	\N	1995	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11851	11670	MAIRE	\N	1965	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
11852	11671	CONSGENE	\N	1965	\N	1994	ANCIEN	\N	\N	\N	NON	\N	\N
11852	11672	PDTGEN	\N	1994	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11859	11675	CONSREG	\N	\N	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
6742	11294	CONSMUNI	2008-03-21 00:00:00	\N	2024-02-05 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11864	11678	CONSMUNI	2001-04-01 00:00:00	2001	2004-03-31 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11716	11679	CONSMUNI	\N	2006	2008-03-09 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11618	11682	CONSMUNI	\N	1977	1983-03-01 00:00:00	1983	ANCIEN	\N	\N	\N	NON	\N	\N
10583	11685	CONSMUNI	\N	2009	2014-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-07 11:20:05
6118	11299	MAIRE	2008-03-21 00:00:00	2008	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6608	11686	MAIRE	\N	1980	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6584	11687	VICPDTREG	\N	1986	\N	1992	ANCIEN	\N	\N	\N	NON	\N	\N
6184	11302	CONSMUNI	2008-03-21 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
6790	11303	CONSMUNI	2009-03-21 00:00:00	\N	2014-03-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-07 11:27:06
11880	11688	CONSGENE	\N	1985	\N	1988	ANCIEN	\N	\N	\N	NON	\N	\N
11881	11689	PREVICPDTREG	\N	\N	\N	1985	ANCIEN	\N	\N	\N	NON	\N	\N
11881	11690	CONSREG	\N	\N	\N	1992	ANCIEN	\N	\N	\N	NON	\N	\N
11663	11747	CONSGENE	\N	2008	\N	2011	ANCIEN	\N	\N	\N	NON	\N	\N
11883	11692	CONSGENE	\N	1973	\N	1989	ANCIEN	\N	\N	\N	NON	\N	\N
11882	11693	PREVICPDTREG	\N	1986	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
11882	11694	VICPDTREG	\N	1982	\N	1986	ANCIEN	\N	\N	\N	NON	\N	\N
11884	11695	CONSREG	\N	1986	\N	1988	ANCIEN	\N	\N	\N	NON	\N	\N
734	11696	MAIREADJOINT	\N	1977	\N	1996	ANCIEN	\N	\N	\N	NON	\N	\N
11734	11596	CONSMUNI	1983-03-14 00:00:00	1983	1989-03-12 00:00:00	1989	ANCIEN	\N	\N	\N	NON	\N	\N
11752	11612	PDTREG	2004-04-02 00:00:00	2004	2015-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2015-12-15 14:56:16
11740	11598	MAIRE	1989-03-12 00:00:00	1989	2001-03-28 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
11744	11601	MAIREADJOINT	2001-03-28 00:00:00	2001	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11747	11605	CONSGENE	\N	1976	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11762	11619	DEPUTE	1981-06-21 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2016-12-12 12:16:08
11793	11639	MAIRE	1996-03-16 00:00:00	\N	2014-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-07 10:12:22
11796	11640	MAIRE	\N	1995	2017-10-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2018-01-23 19:17:21
6360	11748	MAIRE	2009-06-30 00:00:00	\N	2009-10-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11764	11622	DEPUTE	1997-06-01 00:00:00	\N	2000-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-06-15 10:51:14
11971	11749	VICPDTGEN	1994-03-27 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11792	11638	CONSREG	2004-03-01 00:00:00	2004	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11797	11641	CONSGENE	\N	1985	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
11528	11664	MAIREADJOINT	\N	1983	\N	1994	ANCIEN	\N	\N	\N	NON	\N	2014-04-07 11:31:53
11972	11750	MAIRE	\N	1989	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11975	11752	MAIRE	\N	2008	2011-03-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11976	11753	MAIRE	\N	1983	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11989	11757	CONSREG	\N	2004	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11988	11756	MAIRE	\N	2008	2014-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-08 16:24:29
11989	11758	VICPDTREG	\N	2008	\N	2010	ANCIEN	\N	\N	\N	NON	\N	\N
11996	11764	MAIRE	\N	1971	\N	1982	ANCIEN	\N	\N	\N	NON	\N	\N
12013	11774	PDTREG	2010-03-22 00:00:00	2010	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11999	11766	MAIRE	\N	2001	2008-02-28 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
12015	11776	CONSREG	2010-03-22 00:00:00	2010	2014-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-29 18:18:06
12014	11775	CONSREG	2010-03-22 00:00:00	2010	2015-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2015-12-15 15:01:45
12017	11778	CONSREG	2010-03-21 00:00:00	2010	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10838	11047	CONSGENE	2004-03-21 00:00:00	2004	2004-10-26 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11638	11516	CONSGENE	\N	1989	1998-03-01 00:00:00	1998	ANCIEN	\N	\N	\N	NON	\N	\N
11201	11140	MAIRE	\N	1983	\N	2000	ANCIEN	\N	\N	\N	NON	\N	\N
11201	11141	CONSMUNI	\N	2000	2008-03-21 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11202	11142	CONSGENE	\N	1988	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
11202	11143	PDTGEN	\N	1998	2011-03-31 00:00:00	2011	ANCIEN	\N	\N	\N	NON	\N	\N
11301	11209	CONSPARI	1995-06-01 00:00:00	1995	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11291	11217	PDTGEN	2007-12-16 00:00:00	2007	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11302	11212	MAIREADJOINT	1995-06-01 00:00:00	1995	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11302	11213	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11303	11214	CONSREG	1998-03-15 00:00:00	\N	2004-03-21 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11412	11403	DEPUTE	1973-03-11 00:00:00	1973	1981-07-23 00:00:00	1981	ANCIEN	\N	\N	\N	NON	\N	\N
11413	11407	MAIREADJOINT	2008-03-21 00:00:00	2008	2020-03-16 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6650	11405	CONSGENE	2004-03-28 00:00:00	2004	2020-03-16 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11620	11499	VICPDTREG	2004-03-28 00:00:00	2004	2010-03-21 00:00:00	2010	ANCIEN	\N	\N	\N	NON	\N	\N
12016	11777	CONSREG	2010-03-21 00:00:00	2010	\N	2013	ANCIEN	\N	\N	\N	NON	\N	2013-06-21 11:02:21
12018	11779	CONSREG	2010-03-21 00:00:00	2010	\N	2010	ANCIEN	\N	\N	\N	NON	\N	\N
11044	11035	CONSREG	\N	1981	\N	1984	ANCIEN	\N	\N	\N	NON	\N	\N
1501	1501	VICPDTREG	\N	\N	2004-03-28 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
10609	10612	VICPDTREG	2004-03-28 00:00:00	2004	2010-03-21 00:00:00	2010	ANCIEN	\N	\N	\N	NON	\N	\N
11146	11783	DEPUTE	\N	1993	\N	2005	ANCIEN	\N	\N	\N	NON	\N	\N
12037	11789	CONSMUNI	2010-10-05 00:00:00	2010	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12038	11790	CONSMUNI	2010-10-05 00:00:00	\N	2014-03-28 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-07 09:52:36
12040	11791	MAIRE	1999-01-20 00:00:00	\N	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
12041	11792	CONSREG	2004-03-28 00:00:00	2004	2021-07-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12046	11797	MAIRE	1995-03-01 00:00:00	1995	2008-02-28 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
12042	11794	CONSREG	\N	2010	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11035	11266	CONSMUNI	\N	2008	\N	2010	ANCIEN	\N	\N	\N	NON	\N	\N
11545	11455	MAIREADJOINT	1995-06-15 00:00:00	\N	2007-07-15 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11546	11456	CONSGENE	1998-03-13 00:00:00	1998	2007-07-15 00:00:00	2007	ANCIEN	\N	\N	\N	NON	\N	\N
11566	11461	DEPUTE	2002-06-16 00:00:00	2002	2008-09-30 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11567	11462	MAIRE	\N	2006	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11572	11468	MAIRE	1995-06-01 00:00:00	1995	2011-12-31 00:00:00	2011	ANCIEN	\N	\N	\N	NON	\N	\N
11569	11467	CONSREG	\N	1986	\N	2002	ANCIEN	\N	\N	\N	NON	\N	\N
11574	11469	VICPDTREG	1998-03-01 00:00:00	1998	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11578	11470	CONSREG	\N	1992	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
11578	11471	VICPDTREG	\N	1998	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11579	11472	MAIREADJOINT	\N	2001	2014-03-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-05-27 18:31:11
11587	11477	CONSREG	\N	1998	2008-10-06 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11587	11478	VICPDTREG	\N	1992	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
11607	11488	CONSGENE	\N	1998	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
11607	11489	VICPDTGEN	\N	2001	\N	2011	ANCIEN	\N	\N	\N	NON	\N	\N
11608	11490	CONSMUNI	\N	1989	2008-09-26 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11617	11496	CONSGENE	\N	1985	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11617	11497	VICPDTGEN	\N	2004	2008-12-18 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11618	11498	MAIRE	1983-03-01 00:00:00	1983	2013-02-06 00:00:00	2013	ANCIEN	\N	\N	\N	NON	\N	\N
11622	11501	CONSREG	\N	1998	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11623	11502	MAIRE	\N	1996	2016-10-20 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-09-25 10:33:46
11634	11513	MAIRE	1995-06-18 00:00:00	1995	2014-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-07 10:58:37
11643	11517	CONSGENE	\N	1998	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
11643	11518	VICPDTGEN	\N	2001	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11645	11519	MAIREADJOINT	\N	1989	\N	2009	ANCIEN	\N	\N	\N	NON	\N	\N
11647	11520	CONSREG	\N	1998	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
11652	11527	CONSGENE	\N	1998	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11652	11528	VICPDTGEN	\N	2004	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11653	11529	MAIRE	1995-06-18 00:00:00	1995	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11667	11537	CONSGENE	\N	1993	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11667	11538	PREVICPDTGEN	\N	2008	2011-03-27 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11683	11553	MAIRE	2001-03-01 00:00:00	2001	2008-03-16 00:00:00	2008	ANCIEN	\N	\N	\N	OUI	\N	\N
11685	11556	CONSGENE	1994-03-01 00:00:00	1994	2005-06-01 00:00:00	2005	ANCIEN	\N	\N	\N	NON	\N	\N
11207	11144	CONSMUNI	2006-09-10 00:00:00	2006	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11248	11171	MAIRE	1989-03-01 00:00:00	1989	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11291	11203	PREVICPDTGEN	2004-03-28 00:00:00	2004	2007-12-16 00:00:00	2007	ANCIEN	\N	\N	\N	NON	\N	\N
11249	11173	CONSGENE	1998-10-02 00:00:00	1988	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11342	11310	CONSMUNI	2008-03-21 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11249	11175	PREVICPDTGEN	\N	2004	2007-07-15 00:00:00	2007	ANCIEN	\N	\N	\N	NON	\N	\N
11341	11309	CONSMUNI	2008-03-21 00:00:00	\N	2014-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-08 16:48:38
11343	11311	MAIRE	2008-03-21 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11344	11312	CONSMUNI	2008-03-21 00:00:00	\N	2014-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-06-11 16:21:26
11345	11313	MAIRE	2008-03-21 00:00:00	\N	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2018-02-01 14:15:45
11346	11314	CONSMUNI	2008-03-21 00:00:00	\N	2015-02-25 00:00:00	2015	ANCIEN	\N	\N	\N	NON	\N	\N
11686	11557	CONSREG	1986-03-01 00:00:00	1986	1992-03-01 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
6658	11410	CONSREG	1998-03-22 00:00:00	1998	2001-12-01 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
11692	11558	CONSGENE	1985-03-17 00:00:00	1985	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
11692	11560	PDTGEN	\N	2001	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11694	11562	MAIREADJOINT	2001-03-23 00:00:00	2001	2014-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-09 10:54:49
11718	11585	PDTGEN	2004-04-01 00:00:00	2004	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11718	11583	CONSGENE	\N	1992	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11722	11588	MAIRE	1995-06-01 00:00:00	1995	2004-03-01 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11722	11589	CONSMUNI	2008-03-01 00:00:00	2008	2014-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-07 17:15:35
11727	11591	CONSREG	\N	1998	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11727	11592	VICPDTREG	\N	2004	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11729	11593	CONSGENE	\N	2008	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11735	11594	CONSGENE	\N	2001	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11736	11595	MAIRE	\N	2001	2014-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-07 11:07:16
11745	11604	CONSGENE	\N	2008	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11754	11615	MAIRE	\N	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11756	11617	CONSREG	\N	1998	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11756	11618	VICPDTREG	\N	2004	2008-10-15 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11774	11627	CONSREG	1992-03-01 00:00:00	1992	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11774	11628	VICPDTREG	2004-03-01 00:00:00	2004	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11776	11629	MAIRE	1997-04-30 00:00:00	1997	2017-09-18 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-11-15 10:31:01
11803	12238	PDTINTCOM	\N	\N	\N	\N	ACTIF	\N	de la Communauté d'agglomération du Bassin d'Arcachon-Sud 	Vice-président de la Communauté d'agglomération du Bassin d'Arcachon-Sud 	NON	\N	2014-10-13 14:23:03
11885	12239	CONSINTCOM	\N	\N	\N	1996	ANCIEN	\N	Conseiller, communauté urbaine de Lyon	Conseiller, communauté urbaine de Lyon	NON	\N	\N
11936	12240	PDTINTCOM	\N	\N	\N	\N	ACTIF	\N	Président de la Communauté de communes du Gâtinais 	Président de la Communauté de communes du Gâtinais 	NON	\N	\N
11290	12241	PDTINTCOM	2006-09-28 00:00:00	2006	2008-04-04 00:00:00	2008	ANCIEN	\N	Président de la Communauté urbaine d'Alençon	Président de la Communauté urbaine d'Alençon	NON	\N	\N
11446	12242	VICPDTINTCOM	\N	2001	\N	2003	ANCIEN	\N	Vice-présidente de Nantes-Métropole Communauté urbaine	Vice-présidente de Nantes-Métropole Communauté urbaine	NON	\N	\N
11447	12243	PDTINTCOM	2008-04-16 00:00:00	2008	\N	\N	ACTIF	\N	Président de la Communauté de communes Aubrac-Lot-Causse	Président de la Communauté de communes Aubrac-Lot-Causse	NON	\N	\N
11080	12076	VICPDTINTCOM	\N	2002	2008-04-08 00:00:00	\N	ANCIEN	\N	Vice-présidente de la Communauté d'agglomération Toulon-Provence-Méditerrannée	Vice-présidente de la Communauté d'agglomération Toulon-Provence-Méditerrannée	NON	\N	\N
11081	12077	VICPDTINTCOM	\N	1989	\N	\N	ACTIF	\N	Vice-présidente de la Communauté d'agglomération de Villefranche-sur-Saône	Vice-présidente de la Communauté d'agglomération de Villefranche-sur-Saône	NON	\N	\N
11082	12078	PDTINTCOM	2001-04-11 00:00:00	2001	2008-04-10 00:00:00	2008	ANCIEN	\N	Présidente de la Communauté de communes de Benfeld et environs	Présidente de la Communauté de communes de Benfeld et environs	NON	\N	\N
11098	12079	PDTINTCOM	\N	2001	\N	\N	ACTIF	\N	Président de la Communauté de communes du Pays vouglaisien	Président de la Communauté de communes du Pays vouglaisien	NON	\N	\N
11102	12080	PDTINTCOM	1995-01-24 00:00:00	1995	2014-04-01 00:00:00	\N	ANCIEN	\N	Président de la Communauté de communes du Saosnois	Président de la Communauté de communes du Saosnois	NON	\N	2014-04-08 15:32:02
11108	12081	CONSINTCOM	2003-02-01 00:00:00	2003	2004-12-31 00:00:00	2004	ANCIEN	\N	Conseiller, Communauté d'agglomération du Grand Avignon	Conseiller, Communauté d'agglomération du Grand Avignon	NON	\N	\N
11109	12082	CONSINTCOM	\N	2001	2008-04-17 00:00:00	2008	ANCIEN	\N	Conseiller, Communauté urbaine de Strasbourg	Conseiller, Communauté urbaine de Strasbourg	NON	\N	\N
11110	12083	PDTINTCOM	2002-12-21 00:00:00	2002	2008-04-12 00:00:00	2008	ANCIEN	\N	Président de la Communauté de communes du Pays d'Auray	Président de la Communauté de communes du Pays d'Auray	NON	\N	\N
11116	12084	PDTINTCOM	\N	1977	\N	1998	ANCIEN	\N	Président du Syndicat d'agglomérations nouvelles Ouest-Provence	Président du Syndicat d'agglomérations nouvelles Ouest-Provence	NON	\N	\N
11118	12085	PREPDTINTCOM	\N	2003	2008-04-10 00:00:00	2008	ANCIEN	\N	Premier vice-président de la Communauté de communes du Mirebellois	Premier vice-président de la Communauté de communes du Mirebellois	NON	\N	\N
11139	12086	VICPDTINTCOM	2005-04-01 00:00:00	2005	\N	2009	ANCIEN	\N	Vice-Président de la Communauté d'agglomération de Mulhouse Sud Alsace	Vice-Président de la Communauté d'agglomération de Mulhouse Sud Alsace	NON	\N	\N
11148	12087	PDTINTCOM	\N	1994	2008-04-17 00:00:00	2008	ANCIEN	\N	Président d'honneur de la Communauté de communes du canton d'Oulchy-le-Château	Président d'honneur de la Communauté de communes du canton d'Oulchy-le-Château	NON	\N	\N
6622	12088	VICPDTINTCOM	\N	\N	2015-04-07 00:00:00	2015	ANCIEN	\N	Vice-président de la Communauté d'agglomération d'Hénin-Carvin	Vice-président de la Communauté d'agglomération d'Hénin-Carvin	NON	\N	\N
6627	12089	PDTINTCOM	2001-01-01 00:00:00	2001	2006-05-16 00:00:00	2006	ANCIEN	\N	Président de la Communauté d'agglomération de Pau	Président de la Communauté d'agglomération de Pau	NON	\N	\N
6635	12090	PDTINTCOM	\N	\N	2009-01-07 00:00:00	2009	ANCIEN	\N	Président de la Communauté de communes de Sumène-Artense	Président de la Communauté de communes de Sumène-Artense	NON	\N	\N
6636	12091	PDTINTCOM	\N	\N	\N	\N	ACTIF	\N	Président de la Communauté de communes d'Ackerland	Président de la Communauté de communes d'Ackerland	NON	\N	\N
6647	12092	VICPDTINTCOM	2001-03-18 00:00:00	2001	2014-04-01 00:00:00	\N	ANCIEN	\N	Vice-présidente de Lille-Métropole Communauté urbaine	Vice-présidente de Lille-Métropole Communauté urbaine	NON	\N	2014-04-09 22:21:41
12342	12945	CONSMUNI	2001-03-18 00:00:00	\N	2008-03-15 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6662	12093	VICPDTINTCOM	\N	\N	\N	\N	ACTIF	\N	Vice-président de la Communauté de communes du Pays de la faience de Desvres	Vice-président de la Communauté de communes du Pays de la faience de Desvres	NON	\N	\N
11509	11429	PDTGEN	2001-03-23 00:00:00	2001	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11529	11445	VICPDTGEN	2004-03-21 00:00:00	2004	2011-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-05-12 16:31:09
11512	11431	MAIRE	\N	1986	1995-06-18 00:00:00	1995	ANCIEN	\N	\N	\N	NON	\N	\N
11513	11432	MAIRE	1995-06-18 00:00:00	1995	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
11513	11433	CONSMUNI	\N	2001	\N	2009	ANCIEN	\N	\N	\N	NON	\N	\N
11517	11436	CONSREG	\N	1986	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11517	11437	PREVICPDTREG	\N	2004	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11599	11482	MAIRE	\N	1977	2020-05-11 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11529	11444	CONSGENE	1993-12-19 00:00:00	1993	2004-03-21 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11528	11443	CONSMUNI	\N	1977	\N	1982	ANCIEN	\N	\N	\N	NON	\N	2014-04-07 11:31:53
11528	11446	MAIRE	1995-06-18 00:00:00	1995	2008-10-16 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11531	11447	CONSMUNI	\N	1983	\N	2009	ANCIEN	\N	\N	\N	NON	\N	\N
11532	11448	CONSREG	\N	1992	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
11533	11449	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11533	11450	CONSMUNI	\N	1995	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11534	11451	CONSGENE	\N	1998	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11534	11452	PDTGEN	\N	2004	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11531	11453	MAIREADJOINT	\N	2004	\N	1983	ANCIEN	\N	\N	\N	NON	\N	\N
11531	11454	MAIRE	\N	1995	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11616	11495	MAIREARR	\N	2008	2017-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2018-01-23 18:55:47
11602	11484	CONSGENE	1992-03-29 00:00:00	1992	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
11702	11568	PDTGEN	2008-03-20 00:00:00	2008	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
11602	11503	VICPDTGEN	\N	1998	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11628	11504	CONSREG	\N	\N	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
11651	11525	CONSREG	1992-04-01 00:00:00	1992	2004-03-31 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
11646	11521	MAIRE	1989-04-01 00:00:00	1989	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11676	11544	MAIRE	1995-06-18 00:00:00	\N	2017-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-11-28 16:31:22
11649	11523	CONSGENE	2004-04-01 00:00:00	2004	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11669	11540	MAIREADJOINT	2008-03-16 00:00:00	2008	2009-06-08 00:00:00	2009	ANCIEN	\N	\N	\N	NON	\N	\N
11702	11567	CONSGENE	1988-10-02 00:00:00	1988	2008-03-20 00:00:00	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11866	13082	CONSINTCOM	2012-07-15 00:00:00	2012	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11462	12192	PREPDTINTCOM	2008-04-18 00:00:00	2008	\N	\N	ACTIF	\N	Premier vice-président de la Communauté de communes du Quercitain	Premier vice-président de la Communauté de communes du Quercitain	NON	\N	\N
11800	12193	VICPDTINTCOM	\N	2001	2017-09-30 00:00:00	\N	ANCIEN	\N	Vice-Président de la Communauté d'agglomération Vitré-Communauté	Vice-Président de la Communauté d'agglomération Vitré-Communauté	NON	\N	2018-01-23 19:00:07
11274	12194	VICPDTINTCOM	\N	2001	2017-06-20 00:00:00	\N	ANCIEN	\N	Vice-président de la Communauté de communes des Crêtes préardennaises	Vice-président de la Communauté de communes des Crêtes préardennaises	NON	\N	2017-11-14 10:37:01
11279	12195	PDTINTCOM	\N	\N	2014-04-01 00:00:00	\N	ANCIEN	\N	Président de la Communauté d'agglomération Béziers-Méditerranée	Président de la Communauté d'agglomération Béziers-Méditerranée	NON	\N	2014-04-08 16:10:31
5218	12111	PDTINTCOM	\N	1994	\N	2003	ANCIEN	\N	Président de la Communauté de communes de Surgères	Président de la Communauté de communes de Surgères	NON	\N	\N
10571	12112	PDTDELINTCOM	\N	\N	2010-12-17 00:00:00	2010	ANCIEN	\N	Président délégué du Conseil de développement de la Communauté Urbaine de Lyon	Président délégué du Conseil de développement de la Communauté Urbaine de Lyon	NON	\N	\N
12910	13091	VICPDTINTCOM	\N	2013	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10579	12113	PDTINTCOM	2003-01-08 00:00:00	2003	2008-04-08 00:00:00	\N	ANCIEN	\N	Président de la Communauté d'agglomération du Val-de-Seine	Président de la Communauté d'agglomération du Val-de-Seine	NON	\N	\N
10580	12114	VICPDTINTCOM	\N	\N	2014-06-11 00:00:00	2014	ANCIEN	\N	Vice-président de Nantes-Métropole Communauté urbaine	Vice-président de Nantes-Métropole Communauté urbaine	NON	\N	\N
10589	12115	CONSINTCOM	\N	2004	2008-03-16 00:00:00	2008	ANCIEN	\N	Conseiller, Communauté de communes de Sumène-Artense	Conseiller, Communauté de communes de Sumène-Artense	NON	\N	\N
11433	12116	PDTINTCOM	\N	2003	\N	\N	ACTIF	\N	Président de la Communauté de communes Castillon - Pujols	Président de la Communauté de communes Castillon - Pujols	NON	\N	\N
11428	12117	VICPDTINTCOM	\N	2008	2014-04-01 00:00:00	\N	ANCIEN	\N	Conseiller, Communauté de communes du Val-de-l'Eure	Conseiller, Communauté de communes du Val-de-l'Eure	NON	\N	2014-04-08 16:05:02
11429	12118	CONSINTCOM	2002-01-01 00:00:00	2002	\N	\N	ACTIF	\N	Conseiller, Communauté de communes du Pays de Limours	Conseiller, Communauté de communes du Pays de Limours	NON	\N	\N
11431	12119	CONSINTCOM	2008-04-18 00:00:00	2008	\N	\N	ACTIF	\N	Conseillère, Communauté de communes rurales des Monts de Flandres	Conseillère, Communauté de communes rurales des Monts de Flandres	NON	\N	\N
11432	12120	PDTINTCOM	2008-04-10 00:00:00	2008	2015-04-28 00:00:00	\N	ANCIEN	\N	Président de la Communauté de communes du Pays de Tronçais	Président de la Communauté de communes du Pays de Tronçais	NON	\N	2017-11-16 16:39:43
11434	12121	CONSINTCOM	\N	2001	\N	\N	ACTIF	\N	Conseiller, Communauté de communes de Cernay et environs	Conseiller, Communauté de communes de Cernay et environs	NON	\N	\N
12911	13092	PDTINTCOM	\N	2013	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12777	13099	CONSGENE	2011-10-27 00:00:00	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2013-04-08 10:44:49	\N
5226	11974	PDTINTCOM	\N	\N	2008-03-16 00:00:00	2008	ANCIEN	\N	Président de la Communauté de communes du Pays de Dol-de-Bretagne 	Président de la Communauté de communes du Pays de Dol-de-Bretagne 	NON	\N	\N
5234	11975	PDTINTCOM	\N	1994	2003-08-28 00:00:00	2003	ANCIEN	\N	Président de la communauté de communes du pays guerchais	Président de la communauté de communes du pays guerchais	NON	\N	\N
5243	11976	PDTINTCOM	\N	1993	\N	\N	ACTIF	\N	Président  de la Communauté de communes de la Pointe du Médoc	Président  de la Communauté de communes de la Pointe du Médoc	NON	\N	\N
5245	11977	PDTINTCOM	\N	1996	2006-06-29 00:00:00	2006	ANCIEN	\N	Président de la Communauté de communes du centre Tregor	Président de la Communauté de communes du centre Tregor	NON	\N	\N
5262	11978	PDTINTCOM	\N	1993	2009-09-09 00:00:00	2009	ANCIEN	\N	Président de la Communauté de communes de Guéret - Saint-Vaury	Président de la Communauté de communes de Guéret - Saint-Vaury	NON	\N	\N
5264	11979	PDTINTCOM	\N	1996	2001-04-20 00:00:00	2001	ANCIEN	\N	Président de la communauté de l'agglomération de Clermont-Ferrand	Président de la communauté de l'agglomération de Clermont-Ferrand	NON	\N	\N
5265	11980	PDTINTCOM	\N	\N	2000-09-15 00:00:00	2000	ANCIEN	\N	Président de la Communauté de communes Marseille-Provence-Métropole	Président de la Communauté de communes Marseille-Provence-Métropole	NON	\N	\N
11410	11981	PREPDTINTCOM	2008-04-17 00:00:00	2008	\N	\N	ACTIF	\N	Premier vice-président de la Communauté de communes du Pays de Pont-Château - Saint-Gildas-des-Bois	Premier vice-président de la Communauté de communes du Pays de Pont-Château - Saint-Gildas-des-Bois	NON	\N	\N
5268	11982	PDTINTCOM	\N	1993	1999-06-11 00:00:00	\N	ANCIEN	\N	Président de la Communauté de communes du Pays Viganais	Président de la Communauté de communes du Pays Viganais	NON	\N	\N
5277	11983	VICPDTINTCOM	\N	\N	2011-10-27 00:00:00	2011	ANCIEN	\N	Vice-président de la communauté de communes du Segala	Vice-président de la communauté de communes du Segala	NON	\N	\N
5280	11984	VICPDTINTCOM	1995-07-05 00:00:00	1995	2008-04-11 00:00:00	2008	ANCIEN	\N	Vice-président de la Communauté de communes Arguenon-Hunaudaye	Vice-président de la Communauté de communes Arguenon-Hunaudaye	NON	\N	\N
5837	11985	VICPDTINTCOM	\N	\N	2001-04-20 00:00:00	2001	ANCIEN	\N	Vice-président de la Communauté urbaine du Grand Lyon	Vice-président de la Communauté urbaine du Grand Lyon	NON	\N	\N
5879	11986	PDTINTCOM	2000-09-15 00:00:00	2000	2008-04-17 00:00:00	2008	ANCIEN	\N	Président de Marseille-Provence-Métropole Communauté urbaine	Président de Marseille-Provence-Métropole Communauté urbaine	NON	\N	\N
5881	11987	PDTINTCOM	\N	1999	\N	\N	ACTIF	\N	Président de la communauté d'agglomération périgourdine	Président de la communauté d'agglomération périgourdine	NON	\N	\N
6280	11988	PDTINTCOM	\N	\N	2001-04-09 00:00:00	2001	ANCIEN	\N	Président du Syndicat de la région de Flines A Guenan	Président du Syndicat de la région de Flines A Guenan	NON	\N	\N
6282	11989	PDTINTCOM	\N	\N	\N	2008	ANCIEN	\N	Président de la Communauté de communes de la région d'Hallencourt	Président de la Communauté de communes de la région d'Hallencourt	NON	\N	\N
6293	11990	PDTINTCOM	\N	1996	\N	\N	ACTIF	\N	Président de la communauté de communes de Saint Laurent de Chamousset	Président de la communauté de communes de Saint Laurent de Chamousset	NON	\N	\N
6306	11991	PDTINTCOM	2001-04-20 00:00:00	2001	2014-12-31 00:00:00	2014	ANCIEN	\N	Président de la Communauté urbaine du Grand Lyon	Président de la Communauté urbaine du Grand Lyon	NON	\N	2015-01-16 09:46:13
6307	11992	PDTINTCOM	2001-04-20 00:00:00	2001	\N	\N	ACTIF	\N	Président de la communauté de l'agglomération de Clermont-Ferrand	Président de la communauté de l'agglomération de Clermont-Ferrand	NON	\N	\N
6308	11993	PDTINTCOM	\N	1989	2008-04-12 00:00:00	2008	ANCIEN	\N	Président de la Communauté de l'agglomération du Pays de Montbéliard	Président de la Communauté de l'agglomération du Pays de Montbéliard	NON	\N	\N
11411	11994	PDTINTCOM	2006-01-01 00:00:00	2006	2008-04-17 00:00:00	2008	ANCIEN	\N	Président de la Communauté de communes du Pays de Pont-Château - Saint-Gildas-des-Bois	Président de la Communauté de communes du Pays de Pont-Château - Saint-Gildas-des-Bois	NON	\N	\N
6313	11995	PDTINTCOM	\N	1992	\N	1995	ANCIEN	\N	Président de la communauté de communes de Saint-Claude	Président de la communauté de communes de Saint-Claude	NON	\N	\N
6315	11996	VICPDTINTCOM	\N	\N	2017-05-15 00:00:00	\N	ANCIEN	\N	Vice-Président de la Communauté de communes de la Vallée de la Barousse	Vice-Président de la Communauté de communes de la Vallée de la Barousse	NON	\N	2017-05-16 15:18:13
5892	11997	CONSINTCOM	\N	\N	2008-12-29 00:00:00	2008	ANCIEN	\N	Conseillère, syndicat d'électrification et d'équipement de la Lozère	Conseillère, syndicat d'électrification et d'équipement de la Lozère	NON	\N	\N
12071	11998	PDTINTCOM	\N	\N	2002-11-11 00:00:00	2002	ANCIEN	\N	Président du syndicat d'adduction d'eau	Président du syndicat d'adduction d'eau	NON	\N	\N
6331	11999	PDTINTCOM	\N	\N	\N	2008	ANCIEN	\N	Président de la Communauté d'agglomération de Bayonne-Anglet-Biarritz	Président de la Communauté d'agglomération de Bayonne-Anglet-Biarritz	NON	\N	\N
12582	12862	CONSMUNI	\N	1995	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12583	12863	MAIRE	1995-06-18 00:00:00	\N	2001-03-18 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12580	12864	PDTGEN	2001-03-23 00:00:00	\N	2008-03-20 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12584	12865	CONSREG	2004-03-28 00:00:00	\N	2010-03-14 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12580	12866	VICPDTGEN	\N	2008	2011-03-20 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12580	12868	CONSGENE	2011-03-21 00:00:00	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12764	12872	MAIRE	2001-03-18 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12850	13040	MEMBREINTCOM	2001-03-18 00:00:00	\N	2014-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-11-10 12:12:30
12851	13041	PDTINTCOM	\N	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12763	12874	CONSGENE	2001-03-11 00:00:00	\N	\N	2011	ANCIEN	\N	\N	\N	NON	\N	2013-09-23 10:45:42
12765	12875	MAIREADJOINT	1971-03-11 00:00:00	\N	2001-03-17 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	2014-04-09 22:36:40
12767	12878	VICPDTGEN	2004-03-21 00:00:00	\N	2008-03-16 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12767	12879	PREVICPDTGEN	2008-03-16 00:00:00	\N	2011-11-30 00:00:00	2011	ANCIEN	\N	\N	\N	NON	\N	\N
12765	12877	MAIRE	2001-03-18 00:00:00	\N	2014-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-09 22:36:28
12351	12937	DEPUTE	\N	1997	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
12766	12876	CONSREG	1998-03-15 00:00:00	\N	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
12787	12926	CONSGENE	1979-01-01 00:00:00	\N	1988-01-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12101	12925	DEPUTE	1988-06-12 00:00:00	\N	1992-05-02 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2016-12-13 10:56:52
11030	12936	PDTGEN	\N	2001	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12788	12928	CONSINTCOM	2001-03-18 00:00:00	\N	2015-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-05-23 10:42:37
12409	12935	MAIRE	1983-03-14 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12351	12938	DEPUTE	\N	2002	2011-09-30 00:00:00	2011	ANCIEN	\N	\N	\N	NON	\N	\N
12791	12939	PDTREG	1998-03-16 00:00:00	\N	2001-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12793	12944	VICPDTINTCOM	2008-03-16 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12792	12942	PDTGEN	2004-04-01 00:00:00	\N	2014-03-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-10-02 10:07:56
12794	12946	VICPDTGEN	1998-03-01 00:00:00	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12794	12947	CONSGENE	1994-03-01 00:00:00	\N	1998-02-28 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12795	12948	PDTINTCOM	1983-03-01 00:00:00	1983	2014-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-10-22 17:27:15
12796	12949	MAIREADJOINT	1995-06-18 00:00:00	\N	2014-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-08 15:39:26
12797	12950	CONSGENE	2008-03-01 00:00:00	2008	2012-09-01 00:00:00	2012	ANCIEN	\N	\N	\N	NON	\N	\N
12798	12951	CONSINTCOM	1995-06-18 00:00:00	\N	2012-09-01 00:00:00	2012	ANCIEN	\N	\N	\N	NON	\N	\N
12466	12952	MAIREADJOINT	1989-03-19 00:00:00	\N	2001-02-28 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12501	12953	PREPDTINTCOM	1995-04-01 00:00:00	\N	2014-03-17 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2015-02-17 15:46:00
12800	12955	CONSINTCOM	2008-03-21 00:00:00	\N	\N	2014	ANCIEN	\N	\N	\N	NON	\N	2014-11-18 16:30:31
12386	12956	CONSMUNI	1983-03-31 00:00:00	\N	1995-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12801	12957	PDTINTCOM	1995-03-01 00:00:00	\N	2001-03-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12802	12958	CONSMUNI	1983-03-13 00:00:00	\N	1995-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12802	12959	MAIRE	1995-06-18 00:00:00	\N	2014-03-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-07 11:17:50
12803	12960	PREVICPDTREG	1998-03-01 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12804	12961	PDTINTCOM	1983-03-13 00:00:00	\N	2015-04-07 00:00:00	2015	ANCIEN	\N	\N	\N	NON	\N	\N
12805	12962	CONSMUNI	1983-03-13 00:00:00	\N	1989-03-18 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12490	12697	PDTGEN	2001-03-23 00:00:00	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12768	12883	VICPDTGEN	2004-03-01 00:00:00	\N	2012-02-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12493	12700	CONSREG	2004-03-28 00:00:00	\N	2004-03-31 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
12769	12886	PDTGEN	2004-04-01 00:00:00	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12805	12963	MAIREADJOINT	1989-03-19 00:00:00	\N	2001-03-18 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12769	12885	CONSGENE	1988-09-01 00:00:00	\N	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
12806	12964	CONSINTCOM	1983-03-13 00:00:00	\N	2001-03-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12770	12888	CONSINTCOM	\N	2001	\N	2010	ANCIEN	\N	\N	\N	NON	\N	\N
12770	12889	VICPDTINTCOM	2010-07-01 00:00:00	\N	\N	2012	ANCIEN	\N	\N	\N	NON	\N	\N
12771	12891	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12524	12892	PDTGEN	\N	2004	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12772	12893	DELINTCOM	\N	1989	\N	2011	ANCIEN	\N	\N	\N	NON	\N	\N
12162	12895	CONSMUNI	1983-03-13 00:00:00	\N	1995-06-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12773	12896	CONSGENE	1988-03-01 00:00:00	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12774	12897	CONSINTCOM	2010-01-01 00:00:00	\N	\N	2011	ANCIEN	\N	\N	\N	NON	\N	\N
12774	12899	MEMBREINTCOM	1983-03-13 00:00:00	\N	\N	2010	ANCIEN	\N	\N	\N	NON	\N	\N
12775	12901	VICPDTGEN	2004-01-01 00:00:00	\N	2014-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-06-16 16:10:07
12807	12966	MAIRE	1983-03-12 00:00:00	\N	2014-03-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-07 11:15:45
12809	12968	DEPUTE	1995-09-24 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-06-15 10:49:37
12810	12969	CONSREG	1992-06-01 00:00:00	\N	1995-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12811	12970	CONSMUNI	2001-03-18 00:00:00	\N	2021-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12812	12971	VICPDTINTCOM	2001-03-18 00:00:00	\N	2016-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2016-07-08 11:06:50
12813	12972	MAIREADJOINT	1989-03-19 00:00:00	\N	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
12814	12973	VICPDTGEN	2001-03-01 00:00:00	\N	2004-03-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12815	12974	CONSINTCOM	\N	2001	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
12816	12975	CONSGENE	1998-03-01 00:00:00	\N	2012-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12817	12976	MAIRE	\N	2000	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12817	12977	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12319	12387	CONSMUNI	\N	1977	\N	1989	ANCIEN	\N	\N	\N	NON	\N	2014-09-24 16:11:00
12320	12388	CONSGENE	\N	1988	2004-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12319	12389	MAIRE	\N	1989	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
12322	12390	PDTINTCOM	1997-01-01 00:00:00	1997	2014-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-28 11:49:37
12323	12392	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-06-15 10:51:00
12320	12393	PDTGEN	2004-04-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12319	12394	PREMADJOINT	\N	2005	2014-09-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-09-24 15:55:36
12351	12413	DEPUTE	1986-03-16 00:00:00	\N	\N	1988	ANCIEN	\N	\N	\N	NON	\N	2016-12-12 12:05:13
12352	12414	DEPUTE	\N	1997	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12353	12415	DEPUTE	\N	2002	\N	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12357	12419	PDTINTCOM	\N	\N	2014-04-07 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-23 13:53:52
12371	12433	MAIREADJOINT	\N	1983	\N	1990	ANCIEN	\N	\N	\N	NON	\N	\N
12371	12434	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12371	12435	MAIRE	\N	2001	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
12371	12436	MAIRE	\N	2006	\N	2011	ANCIEN	\N	\N	\N	NON	\N	\N
12372	12437	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12372	12438	DEPUTE	\N	1997	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12373	12439	DEPUTE	\N	\N	\N	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12374	12440	PDTGEN	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12762	12870	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12378	12449	CONSREG	\N	1986	\N	1992	ANCIEN	\N	\N	\N	NON	\N	\N
12776	12903	PDTINTCOM	2002-01-01 00:00:00	\N	2013-12-02 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-10-22 17:34:20
12776	12904	MEMBREINTCOM	2001-01-01 00:00:00	2001	2001-12-31 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
12777	12905	VICPDTGEN	2004-03-28 00:00:00	\N	2011-10-26 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2013-04-08 10:44:49
12396	12907	CONSMUNI	1989-03-01 00:00:00	\N	1995-03-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12779	12909	CONSMUNI	2001-03-18 00:00:00	\N	2011-11-05 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12108	12910	VICPDTREG	2010-03-01 00:00:00	2010	2012-01-01 00:00:00	2012	ANCIEN	\N	\N	\N	NON	\N	\N
12780	12911	CONSGENE	1985-03-01 00:00:00	\N	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
12780	12912	PREVICPDTGEN	2004-03-01 00:00:00	\N	2012-12-01 00:00:00	2012	ANCIEN	\N	\N	\N	NON	\N	\N
6606	13100	MEMBREINTCOM	\N	2013	\N	\N	ACTIF	\N	\N	\N	NON	2013-06-25 15:46:12	\N
12919	13101	MAIRE	2001-01-01 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	2013-07-01 09:39:25	2013-07-01 09:39:30
12922	13106	MAIRE	\N	1989	\N	2001	ANCIEN	\N	\N	\N	NON	2013-08-19 14:50:17	2013-08-19 14:50:32
12922	13107	MAIRE	\N	2008	\N	\N	ACTIF	\N	\N	\N	NON	2013-08-19 14:50:33	\N
12920	13104	VICPDTINTCOM	\N	2001	\N	\N	ACTIF	\N	\N	\N	NON	2013-07-01 09:41:09	\N
12233	13105	CONSMUNI	2013-07-22 00:00:00	\N	2014-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2013-07-23 16:15:02	2014-04-08 15:54:52
12923	13108	CONSGENE	\N	1992	\N	\N	ACTIF	\N	\N	\N	NON	2013-08-19 14:52:05	\N
12924	13109	CONSREG	\N	1998	\N	2008	ANCIEN	\N	\N	\N	NON	2013-08-19 14:53:15	2013-08-19 14:53:27
12925	13110	MAIREADJOINT	\N	2008	\N	\N	ACTIF	\N	\N	\N	NON	2013-08-19 14:58:59	2013-08-19 14:59:06
11708	13111	MAIREADJOINT	2009-02-09 00:00:00	2009	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2013-08-19 15:31:33	2014-12-11 16:11:18
12926	13112	CONSREG	2010-03-21 00:00:00	\N	2015-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2013-08-19 18:01:25	2015-12-15 15:03:55
12927	13114	MAIRE	2013-01-01 00:00:00	2013	\N	\N	ACTIF	\N	\N	\N	NON	2013-08-26 10:59:29	2013-08-26 10:59:36
12930	13115	MAIRE	2008-03-23 00:00:00	2008	2014-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2013-10-01 15:34:07	2014-05-20 10:20:52
12931	13116	VICPDTGEN	\N	2008	\N	\N	ACTIF	\N	\N	\N	NON	2013-10-01 15:38:57	2013-10-01 15:39:02
1794	12000	PDTINTCOM	\N	\N	\N	\N	ACTIF	\N	Président de la Communauté d'agglomération de Mantes-en-Yvelines	Président de la Communauté d'agglomération de Mantes-en-Yvelines	NON	\N	\N
12074	12264	CONSMUNI	\N	2008	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12075	12265	CGPARIPDT	2015-04-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	2017-09-20 16:44:04
12074	12266	MAIRE	\N	1983	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11451	12247	VICPDTINTCOM	\N	2002	\N	\N	ACTIF	\N	Vice-président de la Communauté d'agglomération du Val-d'Yerres	Vice-président de la Communauté d'agglomération du Val-d'Yerres	NON	\N	\N
11990	12248	VICPDTINTCOM	\N	2009	2009-12-07 00:00:00	2009	ANCIEN	\N	Vice-Présidente de la communauté de communes d'Aubusson-Felletin	Vice-Présidente de la communauté de communes d'Aubusson-Felletin	NON	\N	\N
12031	12249	CONSINTCOM	\N	2010	\N	\N	ACTIF	\N	Conseiller,  communauté de communes de la Brie Nangissienne	Conseiller,  communauté de communes de la Brie Nangissienne	NON	\N	\N
12070	12250	PDTINTCOM	\N	\N	2002-11-11 00:00:00	2002	ANCIEN	\N	Président du syndicat intercommunal de développement économique de la Lomagne	Président du syndicat intercommunal de développement économique de la Lomagne	NON	\N	\N
12030	12251	PREPDTINTCOM	\N	2008	\N	\N	ACTIF	\N	Première vice-Présidente de la communauté de communes du pays de Charlieu	Première vice-Présidente de la communauté de communes du pays de Charlieu	NON	\N	\N
12047	12252	VICPDTINTCOM	\N	2001	\N	2008	ANCIEN	\N	Vice-présidente de la communauté d'agglomération d'Angers	Vice-présidente de la communauté d'agglomération d'Angers	NON	\N	\N
1771	12253	PDTINTCOM	\N	\N	2013-07-14 00:00:00	2013	ANCIEN	\N	Président du district urbain de Saumur	Président du district urbain de Saumur	NON	\N	\N
12060	12254	VICPDTINTCOM	2010-01-01 00:00:00	\N	2017-10-07 00:00:00	\N	ANCIEN	\N	Vice-présidente de la Communauté de Communes du Pays de l¿Or	Vice-présidente de la Communauté de Communes du Pays de l¿Or	NON	\N	2017-12-18 15:56:52
12051	12255	PDTINTCOM	2009-12-16 00:00:00	\N	2017-01-09 00:00:00	\N	ANCIEN	\N	Président de la communauté Mulhouse Alsace Agglomération	Président de la communauté Mulhouse Alsace Agglomération	NON	\N	2017-11-14 11:17:06
12522	12748	MAIREADJOINT	\N	1977	\N	1983	ANCIEN	\N	\N	\N	NON	\N	\N
12781	12914	PDTINTCOM	2008-03-01 00:00:00	2008	\N	2012	ANCIEN	\N	\N	\N	NON	\N	\N
12781	12915	MEMBREINTCOM	\N	1983	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
12782	12916	VICPDTINTCOM	2010-01-01 00:00:00	\N	2011-11-01 00:00:00	2011	ANCIEN	\N	\N	\N	NON	\N	\N
12782	12917	MEMBREINTCOM	2008-03-16 00:00:00	\N	2009-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12515	12918	MAIREADJOINT	2001-03-17 00:00:00	\N	2001-12-16 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12784	12919	CONSGENE	1979-03-15 00:00:00	\N	2011-10-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
1506	12978	PREVICPDTREG	\N	1992	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
12786	12922	PREPDTINTCOM	2008-03-16 00:00:00	\N	2015-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2016-07-08 10:52:22
12785	12921	VICPDTGEN	2008-03-01 00:00:00	\N	2011-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12789	12931	VICPDTGEN	2010-11-10 00:00:00	\N	2012-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12789	12940	PDTGEN	\N	1994	2010-11-09 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12435	12930	PDTREG	2010-11-10 00:00:00	\N	2014-08-26 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-08-27 16:33:38
1506	12979	PDTREG	\N	1998	\N	2010	ANCIEN	\N	\N	\N	NON	\N	\N
12503	12982	CONSREG	2010-03-14 00:00:00	\N	2011-11-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12820	12983	PDTINTCOM	2008-04-17 00:00:00	\N	2014-03-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-06-27 16:56:44
12823	12993	MAIRE	1989-03-19 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12268	12984	MAIREADJOINT	1989-03-19 00:00:00	\N	1995-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12268	12986	CONSMUNI	1995-06-18 00:00:00	\N	2004-03-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12301	12987	DEPUTE	2000-03-19 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12821	12989	VICPDTGEN	1994-03-28 00:00:00	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12297	12990	MAIRE	1989-03-19 00:00:00	\N	2001-03-18 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12297	12991	MAIREADJOINT	1981-06-14 00:00:00	\N	1989-03-19 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12822	12992	DEPUTE	2004-01-01 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12824	12994	CONSGENE	2004-01-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12825	12995	DELINTCOM	1989-03-19 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12826	12996	MEMBREINTCOM	2001-03-01 00:00:00	\N	2014-03-24 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-10-27 11:54:29
12827	12997	MAIREADJOINT	2001-06-01 00:00:00	\N	2012-01-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12828	12998	VICPDTGEN	2008-05-01 00:00:00	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12828	12999	CONSGENE	2001-12-01 00:00:00	\N	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
11974	12267	PDTGEN	2011-03-31 00:00:00	2011	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10629	12269	PDTGEN	2011-03-31 00:00:00	2011	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
1434	12270	CONSGENE	2011-03-31 00:00:00	2011	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
5844	12283	VICPDTREG	1994-02-12 00:00:00	1994	1998-03-17 00:00:00	1998	ANCIEN	\N	\N	\N	NON	\N	\N
12089	12284	MAIREADJOINT	2008-03-17 00:00:00	2008	2012-02-01 00:00:00	2012	ANCIEN	\N	\N	\N	NON	\N	\N
12132	12286	MAIRE	2001-03-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12133	12287	CONSREG	2004-03-28 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12142	12288	VICPDTINTCOM	\N	2001	\N	\N	\N	\N	\N	\N	NON	\N	\N
12148	12289	MAIREADJOINT	\N	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12150	12290	MAIREADJOINT	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12344	12533	PDTGEN	\N	2008	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12344	12534	CONSGENE	\N	2001	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
12284	12535	PREPDTINTCOM	\N	2008	2014-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-08 11:46:05
12244	12536	PDTGEN	\N	2008	\N	2011	ANCIEN	\N	\N	\N	NON	\N	\N
12244	12537	CONSGENE	\N	2011	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12403	12538	CONSREG	\N	2011	\N	2011	ANCIEN	\N	\N	\N	NON	\N	\N
12111	12544	CONSGENE	\N	2008	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12346	12541	CONSGENE	2008-03-16 00:00:00	2008	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12347	12546	CONSREG	\N	2004	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
12349	12550	CONSMUNI	\N	2008	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12348	12551	CONSINTCOM	2008-01-02 00:00:00	\N	2015-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2016-07-08 11:08:08
12407	12553	MAIRE	1989-03-19 00:00:00	\N	2014-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-09 22:08:09
12112	12555	MAIRE	\N	2008	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12113	12557	MAIRE	\N	1995	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12278	12565	VICPDTREG	2004-03-01 00:00:00	\N	2015-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2015-12-15 14:58:55
12282	12572	MAIRE	\N	1977	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
12288	12577	CONSREG	\N	1998	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12291	12579	PREVICPDTGEN	\N	2004	\N	2011	ANCIEN	\N	\N	\N	NON	\N	\N
12291	12580	VICPDTGEN	\N	1994	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
6754	12094	PDTINTCOM	\N	\N	\N	\N	ACTIF	\N	Président de la Communauté de communes du Pays de Saint-Bonnet-le-Château 	Président de la Communauté de communes du Pays de Saint-Bonnet-le-Château 	NON	\N	\N
6763	12095	PDTINTCOM	\N	\N	2019-07-13 00:00:00	\N	ANCIEN	\N	Président de la communauté de communes de la vallée du Gapeau	Président de la communauté de communes de la vallée du Gapeau	NON	\N	\N
6793	12096	PDTINTCOM	\N	1999	2014-03-30 00:00:00	\N	ANCIEN	\N	PrÃ©sident de la CommunautÃ© de communes du Pays Riolais	Président de la Communauté de communes du Pays Riolais	NON	\N	2014-04-07 11:29:00
10373	12097	VICPDTINTCOM	\N	\N	2013-06-10 00:00:00	2013	ANCIEN	\N	Vice-président de la communauté urbaine	Vice-président de la communauté urbaine	NON	\N	\N
10374	12098	PDTINTCOM	\N	\N	2003-03-31 00:00:00	2003	ANCIEN	\N	Président du syndicat mixte d'urbanisme et d'aménagement des pays de Houdan et de Montfort lamaury	Président du syndicat mixte d'urbanisme et d'aménagement des pays de Houdan et de Montfort lamaury	NON	\N	\N
10375	12099	PDTINTCOM	\N	\N	2016-03-03 00:00:00	2016	ANCIEN	\N	Président du district de l'agglomération de Périgueux	Président du district de l'agglomération de Périgueux	NON	\N	\N
10376	12100	PDTINTCOM	\N	\N	\N	\N	ACTIF	\N	Président du sivom	Président du sivom	NON	\N	\N
10377	12101	CONSINTCOM	1977-01-01 00:00:00	\N	\N	\N	ACTIF	\N	Président du syndicat de l'agglomération nouvelle de Cergy-Pontoise	Président du syndicat de l'agglomération nouvelle de Cergy-Pontoise	NON	\N	\N
10392	12102	VICPDTINTCOM	\N	2001	2022-05-07 00:00:00	\N	ANCIEN	\N	Vice-président de la Communauté de communes du Pays Beaumontois	Vice-président de la Communauté de communes du Pays Beaumontois	NON	\N	\N
10393	12103	PDTINTCOM	\N	1995	\N	2001	ANCIEN	\N	Président de la Communauté de communes du Pays Beaumontois	Président de la Communauté de communes du Pays Beaumontois	NON	\N	\N
12291	12581	PDTGEN	\N	1988	\N	1994	ANCIEN	\N	\N	\N	NON	\N	\N
12262	12611	MAIREADJOINT	\N	1983	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
12120	12588	MAIRE	2002-01-01 00:00:00	2001	2014-03-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-07 11:20:43
12121	12593	DEPUTE	1997-06-01 00:00:00	1997	2002-06-18 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-06-15 10:49:27
12262	12612	CONSMUNI	\N	1977	\N	1983	ANCIEN	\N	\N	\N	NON	\N	\N
12122	12614	PDTGEN	\N	2004	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12122	12615	VICPDTGEN	\N	2001	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
12127	12618	CONSGENE	\N	1994	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12124	12623	CONSMUNI	\N	1977	\N	1983	ANCIEN	\N	\N	\N	NON	\N	\N
12123	12625	PDTINTCOM	\N	1995	\N	\N	\N	\N	\N	\N	NON	\N	\N
12125	12628	PDTINTCOM	\N	\N	\N	\N	\N	\N	\N	\N	NON	\N	\N
12477	12679	PDTGEN	\N	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12477	12680	CONSGENE	\N	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12479	12681	MAIRE	1986-06-27 00:00:00	\N	2001-06-15 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
12831	13003	CONSINTCOM	1995-06-18 00:00:00	\N	2015-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2016-07-08 11:05:02
12505	12719	CONSGENE	2011-04-01 00:00:00	2011	2011-07-31 00:00:00	2011	ANCIEN	\N	\N	\N	NON	\N	\N
12829	13001	CONSINTCOM	2001-06-01 00:00:00	\N	\N	2011	ANCIEN	\N	\N	\N	NON	\N	\N
12506	12721	CONSREG	\N	1992	\N	2002	ANCIEN	\N	\N	\N	NON	\N	\N
12830	13002	VICPDTGEN	2008-03-16 00:00:00	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12507	12723	VICPDTINTCOM	2002-01-01 00:00:00	2002	2017-10-27 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2018-05-30 09:31:48
12341	13004	CONSMUNI	1983-03-13 00:00:00	\N	1995-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12508	12729	MAIREADJOINT	\N	1977	\N	1989	ANCIEN	\N	\N	\N	NON	\N	\N
12908	13087	MAIREADJOINT	\N	\N	2014-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-23 12:04:02
12509	12731	CONSGENE	\N	1982	\N	1994	ANCIEN	\N	\N	\N	NON	\N	\N
12833	13006	CONSREG	1986-03-15 00:00:00	\N	1997-06-15 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12511	12734	MAIREADJOINT	\N	1995	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
12545	12783	CONSGENE	1975-01-19 00:00:00	\N	1985-03-09 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12545	12784	VICPDTGEN	1985-03-10 00:00:00	1985	2004-04-29 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
12545	12785	PDTGEN	2004-04-30 00:00:00	\N	2014-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-07-16 16:12:24
12561	12825	PDTGEN	2008-03-20 00:00:00	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12519	12742	MAIRE	\N	1995	2011-10-01 00:00:00	2011	ANCIEN	\N	\N	\N	NON	\N	\N
12520	12743	CONSGENE	\N	1997	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
12520	12744	CONSGENE	2011-03-27 00:00:00	2011	2015-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2015-03-03 10:32:39
12525	12752	CONSGENE	1992-03-29 00:00:00	\N	\N	1994	ANCIEN	\N	\N	\N	NON	\N	\N
12527	12754	MAIRE	1995-06-18 00:00:00	\N	2017-10-22 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-09-29 15:52:55
12529	12756	MAIRE	1977-03-22 00:00:00	\N	1998-03-22 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12530	12757	DEPUTE	1981-06-21 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12543	13011	CONSGENE	1985-03-17 00:00:00	\N	\N	1986	ANCIEN	\N	\N	\N	NON	\N	\N
12530	12781	DEPUTE	\N	1993	1997-04-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2016-12-12 11:55:57
12134	12804	MAIRE	\N	1990	\N	2014	ANCIEN	\N	\N	\N	NON	\N	2014-10-15 16:52:48
12531	12771	CONSGENE	1994-03-27 00:00:00	\N	1998-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12539	12774	PDTGEN	2001-03-18 00:00:00	\N	2011-03-30 00:00:00	2011	ANCIEN	\N	\N	\N	NON	\N	\N
12531	12775	PDTGEN	1998-03-22 00:00:00	\N	2001-03-17 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12134	12805	MAIREADJOINT	\N	1971	\N	1989	ANCIEN	\N	\N	\N	NON	\N	\N
12135	12806	CONSREG	1986-03-01 00:00:00	1986	2001-04-01 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
12136	12807	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-06-15 10:50:50
12144	12809	PDTINTCOM	2001-04-10 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12554	12811	CONSGENE	\N	1982	\N	1993	ANCIEN	\N	\N	\N	NON	\N	\N
12790	12932	CONSGENE	1990-10-01 00:00:00	\N	2011-12-31 00:00:00	2011	ANCIEN	\N	\N	\N	NON	\N	\N
12543	13012	VICPDTGEN	\N	1986	2004-04-01 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
12539	13013	CONSGENE	2011-03-31 00:00:00	\N	2014-01-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-10-20 12:17:11
12570	13014	CONSGENE	2007-03-02 00:00:00	\N	2014-04-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-06-10 15:11:32
12458	13017	MAIRE	1989-03-19 00:00:00	\N	2001-03-18 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12834	13018	VICPDTGEN	1993-01-01 00:00:00	\N	2001-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12525	13021	VICPDTGEN	\N	1994	1998-03-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12458	13022	CONSMUNI	2001-03-18 00:00:00	\N	2008-03-16 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12327	12395	MAIRE	1983-03-10 00:00:00	\N	2006-12-18 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12328	12396	CONSGENE	1994-01-23 00:00:00	\N	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
12328	12397	VICPDTGEN	\N	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12327	12398	CONSMUNI	1977-03-20 00:00:00	\N	1983-03-06 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12329	12399	MAIRE	\N	2002	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12330	12400	MAIRE	\N	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12331	12401	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12335	12402	MAIRE	\N	1995	\N	2011	ANCIEN	\N	\N	\N	NON	\N	\N
12336	12403	CONSGENE	1998-03-22 00:00:00	\N	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
12336	12404	VICPDTGEN	\N	2004	2011-03-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12100	12443	VICPDTREG	2004-04-28 00:00:00	\N	2010-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12102	12445	CONSGENE	\N	1979	\N	1988	ANCIEN	\N	\N	\N	NON	\N	\N
12570	13008	PREVICPDTGEN	2004-03-01 00:00:00	\N	2007-03-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12821	13010	CONSGENE	1988-10-03 00:00:00	\N	1994-03-27 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12297	13009	MAIREADJOINT	2001-03-19 00:00:00	\N	2008-03-09 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12460	13019	CONSREG	2004-03-21 00:00:00	2004	2011-09-30 00:00:00	2011	ANCIEN	\N	\N	\N	NON	\N	\N
12835	13023	CONSREG	2010-03-01 00:00:00	\N	2015-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2015-12-15 15:11:05
12837	13026	MAIRE	1995-06-18 00:00:00	\N	2017-11-05 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-11-13 15:39:22
12836	13025	CONSINTCOM	2001-03-15 00:00:00	\N	2015-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2016-10-06 14:53:39
12838	13027	VICPDTREG	2010-03-01 00:00:00	\N	2011-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12839	13028	VICPDTGEN	1998-03-01 00:00:00	\N	2010-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12410	13030	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-06-15 10:51:02
12153	13031	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-06-15 10:49:23
12153	13032	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-06-15 10:49:23
12153	13033	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-06-15 10:49:23
12832	13036	CONSGENE	1992-03-29 00:00:00	\N	2001-03-22 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12832	13037	PDTGEN	2001-03-23 00:00:00	\N	2014-06-24 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-09-04 14:15:24
12412	13038	CONSMUNI	1983-03-13 00:00:00	\N	1987-01-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12852	13042	CONSGENE	\N	2007	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
12853	13044	CONSREG	1998-03-15 00:00:00	\N	2004-03-31 00:00:00	2013	ANCIEN	\N	\N	\N	NON	\N	2013-06-21 11:09:49
12853	13045	VICPDTREG	2004-04-01 00:00:00	\N	\N	2013	ANCIEN	\N	\N	\N	NON	\N	2013-06-21 00:08:36
1506	13050	CONSREG	\N	2010	2015-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2015-12-15 15:06:54
12857	13052	DEPUTE	1956-01-02 00:00:00	\N	1958-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
1748	13053	DEPUTE	1993-03-28 00:00:00	\N	1996-04-14 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12861	13058	CONSREG	2002-03-01 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12859	13056	CONSMUNI	1989-03-19 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12860	13057	MAIREADJOINT	1995-06-18 00:00:00	\N	2001-03-18 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12862	13059	CONSMUNI	2008-03-16 00:00:00	\N	\N	2011	ANCIEN	\N	\N	\N	NON	\N	\N
12106	13060	CONSREG	2004-03-21 00:00:00	\N	2010-03-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12863	13061	CONSINTCOM	1983-03-14 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12814	13062	CONSGENE	\N	2010	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
6445	13063	CONSMUNI	2011-11-08 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12349	13064	MAIREADJOINT	\N	2001	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
12348	13065	VICPDTINTCOM	\N	2001	2008-01-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2016-07-08 11:07:50
12390	13066	CONSMUNI	2011-11-18 00:00:00	\N	2014-03-28 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-07 11:06:17
11741	13067	CONSGENE	2011-12-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
11607	13070	CONSGENE	\N	2012	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12915	13097	MAIREADJOINT	\N	2008	2014-03-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-07-16 16:39:24
11572	13072	CONSMUNI	2012-01-01 00:00:00	2012	2014-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-08 12:04:22
12915	13096	MAIRE	\N	1995	\N	2007	ANCIEN	\N	\N	\N	NON	\N	2014-07-16 16:36:45
12082	12275	CONSREG	1992-03-01 00:00:00	\N	1998-02-28 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12343	12529	CONSREG	2004-03-01 00:00:00	\N	2011-11-14 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12342	12528	MAIRE	2008-03-16 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12345	12530	MAIRE	\N	2001	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
12411	12564	DEPUTE	1996-11-27 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-06-15 10:49:41
12412	12566	MAIRE	1987-01-01 00:00:00	\N	2001-03-18 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12761	12869	PDTGEN	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12424	12620	CONSMUNI	\N	1970	\N	1974	ANCIEN	\N	\N	\N	NON	\N	\N
12426	12621	MAIRE	1995-06-18 00:00:00	\N	2014-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-10-22 17:24:22
12799	12954	MAIREADJOINT	2008-03-28 00:00:00	\N	\N	2012	ANCIEN	\N	\N	\N	NON	\N	\N
12233	12980	MAIRE	2001-03-18 00:00:00	\N	2012-09-21 00:00:00	2012	ANCIEN	\N	\N	\N	NON	\N	\N
12383	12981	VICPDTREG	1998-03-15 00:00:00	\N	2015-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-10-09 17:59:39
12532	13047	CONSMUNI	1995-03-01 00:00:00	\N	2008-02-28 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12856	13049	CONSMUNI	2001-03-01 00:00:00	\N	2008-03-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12106	13069	CONSREG	2011-12-19 00:00:00	\N	2015-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2015-12-15 15:08:49
12533	12762	MAIRE	\N	1999	2017-10-20 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-11-10 18:19:25
12534	12764	CONSREG	\N	1993	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
12537	12769	VICPDTGEN	\N	2004	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12537	12770	CONSGENE	\N	2004	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12538	12772	VICPDTINTCOM	2008-03-01 00:00:00	\N	2016-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2016-01-19 17:59:20
12550	12800	CONSGENE	1985-03-17 00:00:00	\N	2003-07-14 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12551	12801	CONSREG	1986-03-16 00:00:00	\N	2004-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12552	12802	CONSMUNI	1983-03-13 00:00:00	\N	1996-11-12 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12550	12803	PDTGEN	2003-07-15 00:00:00	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12558	12816	CONSMUNI	\N	1989	1995-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12562	12826	MAIRE	1995-06-19 00:00:00	\N	2017-10-23 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-11-10 15:57:49
12563	12829	CONSREG	1992-03-23 00:00:00	\N	1998-03-15 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12563	12830	VICPDTREG	1998-03-16 00:00:00	\N	2002-07-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12563	12831	CONSREG	2002-08-01 00:00:00	\N	2003-02-24 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12564	12832	VICPDTINTCOM	2003-01-01 00:00:00	\N	2017-10-23 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-11-10 15:58:10
12565	12833	CONSMUNI	1977-04-01 00:00:00	1977	1985-03-30 00:00:00	1985	ANCIEN	\N	\N	\N	NON	\N	\N
12565	12834	MAIRE	1985-04-01 00:00:00	1985	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12573	12841	PDTINTCOM	2005-06-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12576	12846	CONSMUNI	1971-03-21 00:00:00	\N	1983-03-13 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12577	12847	CONSGENE	1976-03-14 00:00:00	1976	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
12576	12848	MAIREADJOINT	1983-03-13 00:00:00	\N	2001-03-18 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12579	12850	DEPUTE	1981-07-24 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2016-12-13 10:37:22
12578	12851	VICPDTREG	1981-07-24 00:00:00	1982	1986-03-01 00:00:00	1986	ANCIEN	\N	\N	\N	NON	\N	\N
12578	12852	CONSREG	1986-03-01 00:00:00	\N	1998-03-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12578	12853	VICPDTREG	1998-03-01 00:00:00	\N	2010-03-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12577	12854	VICPDTGEN	2008-03-01 00:00:00	\N	2011-03-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12577	12855	PDTGEN	2011-03-31 00:00:00	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12580	12856	CONSGENE	1982-03-14 00:00:00	\N	\N	1994	ANCIEN	\N	\N	\N	NON	\N	\N
12124	12285	MAIRE	1983-03-13 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12158	12291	CONSGENE	2001-03-18 00:00:00	\N	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
12158	12292	VICPDTGEN	\N	2004	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12159	12293	CONSREG	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12159	12294	CONSREG	2004-03-28 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12164	12295	CONSGENE	2008-03-16 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12165	12296	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12171	12297	MAIRE	1983-03-14 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12172	12298	CONSGENE	\N	1979	1985-03-17 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12172	12299	VICPDTGEN	1985-03-18 00:00:00	\N	1988-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12173	12300	VICPDTINTCOM	\N	2003	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
12174	12301	VICPDTINTCOM	\N	2003	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
12174	12302	MEMBREINTCOM	1983-03-14 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12179	12303	DEPUTE	1986-03-16 00:00:00	\N	2007-06-25 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2016-12-13 11:58:13
10184	12304	MAIRE	\N	2002	2017-10-19 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2018-02-22 15:39:42
9738	12305	VICPDTAN	\N	1987	\N	1988	ANCIEN	\N	\N	\N	NON	\N	\N
9738	12306	DEPUTE	1981-06-21 00:00:00	\N	1986-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2016-12-13 11:37:57
12185	12307	DEPUTE	1997-06-01 00:00:00	\N	1999-08-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-06-15 10:49:24
12196	12312	CONSMUNI	1995-06-18 00:00:00	\N	2001-03-19 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12196	12315	MAIREADJOINT	1977-03-20 00:00:00	\N	1995-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12196	12318	MAIRE	2001-03-20 00:00:00	\N	2014-03-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-07 11:19:28
12199	12322	CONSGENE	\N	1979	\N	1985	ANCIEN	\N	\N	\N	NON	\N	\N
12215	12339	VICPDTINTCOM	2001-04-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12206	12326	CONSGENE	\N	1985	\N	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12206	12337	PREVICPDTGEN	\N	2008	\N	2011	ANCIEN	\N	\N	\N	NON	\N	\N
12406	12552	CONSREG	2004-03-28 00:00:00	\N	2015-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2015-12-15 14:57:59
12408	12558	VICPDTGEN	1982-03-22 00:00:00	\N	1988-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12410	12561	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-06-15 10:51:02
12410	12562	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-06-15 10:51:02
12408	12574	CONSGENE	1988-10-03 00:00:00	\N	2001-03-18 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12408	12578	VICPDTGEN	2001-03-19 00:00:00	\N	2008-03-09 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12417	12583	VICPDTREG	1983-01-01 00:00:00	\N	1985-01-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12420	12603	DEPUTE	1981-06-21 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12420	12604	DEPUTE	1997-06-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12421	12605	MAIREADJOINT	1977-03-14 00:00:00	\N	1983-03-13 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12421	12606	CONSMUNI	1983-03-14 00:00:00	\N	1989-03-19 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12421	12607	MAIRE	1989-03-20 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12421	12608	CONSMUNI	1995-06-19 00:00:00	\N	2001-03-18 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12421	12610	CONSMUNI	2001-03-19 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12422	12616	CONSGENE	1988-10-03 00:00:00	\N	1989-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12480	12685	MAIRE	1995-06-20 00:00:00	\N	2017-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-12-04 19:10:43
12481	12686	CONSGENE	1996-06-16 00:00:00	\N	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
12481	12687	VICPDTGEN	\N	2001	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
12481	12688	CONSGENE	2008-03-09 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12482	12689	VICPDTINTCOM	2001-01-01 00:00:00	2001	2016-07-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2016-07-08 10:22:38
12491	12698	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12492	12699	CONSGENE	\N	\N	2012-11-02 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12494	12703	VICPDTGEN	\N	2004	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12494	12704	CONSGENE	\N	2001	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
12495	12705	MAIREADJOINT	2008-03-17 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12496	12706	MAIREADJOINT	\N	1977	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12498	12710	DEPUTE	1988-06-12 00:00:00	\N	\N	1993	ANCIEN	\N	\N	\N	NON	\N	\N
12496	12708	MAIRE	\N	1983	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
12497	12709	CONSREG	1986-03-16 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12499	12712	CONSGENE	1988-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12500	12713	MAIRE	1994-05-28 00:00:00	\N	2012-03-22 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12501	12714	CONSINTCOM	1989-04-01 00:00:00	\N	1995-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12503	12715	CONSREG	1992-03-22 00:00:00	\N	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
12504	12718	CONSGENE	1988-10-02 00:00:00	\N	\N	1994	ANCIEN	\N	\N	\N	NON	\N	\N
12523	12749	CONSMUNI	\N	1989	\N	1991	ANCIEN	\N	\N	\N	NON	\N	\N
10655	12268	CONSGENE	2011-03-31 00:00:00	2011	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
1419	12458	CONSGENE	\N	\N	2001-04-02 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
12500	12725	MAIREADJOINT	1989-04-01 00:00:00	\N	1994-03-31 00:00:00	1994	ANCIEN	\N	\N	\N	NON	\N	\N
12347	12726	CONSREG	2010-03-21 00:00:00	\N	2015-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2015-12-15 15:04:38
12503	12728	VICPDTREG	1998-03-22 00:00:00	\N	2010-03-13 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12512	12736	CONSMUNI	\N	1995	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
12513	12737	CONSREG	2004-03-28 00:00:00	\N	2010-03-14 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12512	12738	MAIRE	\N	2008	2014-03-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-06-27 16:55:48
12515	12739	MAIRE	2001-12-17 00:00:00	\N	2017-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-11-13 14:33:15
12516	12740	CONSGENE	2003-03-23 00:00:00	\N	2011-11-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12518	12741	PDTINTCOM	2006-12-20 00:00:00	2006	2014-04-03 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-04 19:03:11
12521	12745	CONSGENE	1996-06-16 00:00:00	\N	2011-11-23 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12524	12750	CONSGENE	\N	1995	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
12526	12753	PDTGEN	\N	2004	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12532	12761	MAIRE	2008-03-01 00:00:00	2008	2016-05-10 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-09-20 13:44:07
12540	12776	CONSGENE	1985-03-17 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12541	12778	VICPDTGEN	\N	1992	1998-03-27 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12542	12779	CONSGENE	1985-03-17 00:00:00	\N	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
12543	12780	PDTGEN	2004-04-01 00:00:00	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12544	12782	MAIRE	2008-03-16 00:00:00	\N	2014-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-17 11:09:19
12546	12786	MAIREADJOINT	\N	1995	\N	2000	ANCIEN	\N	\N	\N	NON	\N	2014-04-07 11:41:43
12547	12787	CONSGENE	1998-03-22 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12549	12799	CONSGENE	1998-03-01 00:00:00	\N	2011-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12553	12808	MAIRE	1995-06-25 00:00:00	\N	2014-03-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-10-01 11:27:50
12548	12791	MAIRE	\N	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12548	12796	CONSMUNI	\N	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12548	12797	CONSMUNI	\N	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12546	12798	MAIRE	2001-03-18 00:00:00	\N	2014-03-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-10-01 11:28:30
12555	12813	MAIRE	1995-06-25 00:00:00	1995	2014-03-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-07 11:29:08
12556	12814	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12557	12815	CONSGENE	2001-03-18 00:00:00	\N	2014-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-02-14 17:24:34
12567	12835	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12567	12836	MAIRE	\N	1985	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12568	12837	DEPUTE	1988-06-12 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2016-12-13 11:03:12
12569	12838	CONSGENE	1992-03-29 00:00:00	\N	2011-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12570	12839	VICPDTGEN	1982-03-21 00:00:00	\N	1992-03-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12849	13039	VICPDTINTCOM	\N	2011	2014-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-09 22:37:06
12574	12842	VICPDTAN	2008-10-01 00:00:00	\N	2009-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12581	12857	CONSREG	1986-03-16 00:00:00	\N	\N	1992	ANCIEN	\N	\N	\N	NON	\N	\N
12575	12844	CONSREG	1998-03-15 00:00:00	\N	2004-03-14 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12575	12845	VICPDTREG	2004-03-15 00:00:00	\N	2010-03-14 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12581	12858	VICPDTREG	\N	1992	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
12581	12859	CONSREG	\N	1998	2015-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2015-12-15 15:03:54
12580	12860	VICPDTGEN	\N	1994	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
12585	12867	CONSMUNI	2001-03-18 00:00:00	\N	2015-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-05-23 10:35:43
6598	12258	PDTINTCOM	\N	\N	2010-12-31 00:00:00	\N	ANCIEN	\N	Président de la Communauté de communes de Prauthoy-en-Montsaugeonnais	Président de la Communauté de communes de Prauthoy-en-Montsaugeonnais	NON	\N	2018-02-22 16:09:03
1776	12259	PDTINTCOM	\N	\N	2024-01-05 00:00:00	\N	ANCIEN	\N	Président du district de l'agglomération messine	Président du district de l'agglomération messine	NON	\N	\N
12000	12260	VICPDTINTCOM	\N	1995	\N	\N	ACTIF	\N	Vice-présidente du syndicat intercommunal d'assainissement et de restauration des cours d'eau	Vice-présidente du syndicat intercommunal d'assainissement et de restauration des cours d'eau	NON	\N	\N
12001	12261	VICPDTINTCOM	\N	2001	\N	2008	ANCIEN	\N	Vice-présidente de la communauté de communes du Val d'Essonne	Vice-présidente de la communauté de communes du Val d'Essonne	NON	\N	\N
12002	12262	DELINTCOM	\N	2000	\N	2014	ANCIEN	\N	Délégué à la communauté d'agglomération Metz-Métropole	Délégué suppléant à la communauté d'agglomération Metz-Métropole	NON	\N	2014-10-16 18:30:27
12056	12263	CONSINTCOM	\N	\N	\N	2011	ANCIEN	\N	Conseiller, Conseil communautaire de Strasbourg (COS)	Conseiller, Conseil communautaire de Strasbourg (COS)	NON	\N	\N
12085	12279	DEPUTE	\N	2000	\N	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12078	12273	CONSGENE	2011-03-30 00:00:00	2011	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12086	12280	CONSMUNI	\N	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12194	12319	MAIRE	\N	1987	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12087	12281	CONSGENE	\N	2006	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12189	12309	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12211	12338	CONSMUNI	\N	1995	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
12221	12340	CONSGENE	2001-03-18 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12223	12341	CONSGENE	\N	2004	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12227	12342	CONSGENE	2008-03-09 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12222	12343	CONSMUNI	\N	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12231	12344	MEMBREINTCOM	2008-03-16 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12228	12345	CONSMUNI	2008-03-16 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12232	12346	CONSGENE	1998-03-22 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12234	12347	VICPDTGEN	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12233	12348	CONSMUNI	1995-06-18 00:00:00	\N	2001-03-17 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12235	12349	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12236	12350	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12290	12379	CONSGENE	\N	1955	\N	1964	ANCIEN	\N	\N	\N	NON	\N	\N
12237	12351	VICPDTINTCOM	2001-03-18 00:00:00	\N	2014-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-08 15:55:06
12885	13076	CONSREG	\N	1981	\N	1986	ANCIEN	\N	\N	\N	NON	\N	\N
12238	12353	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12238	12355	CONSGENE	1992-03-29 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12240	12356	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12240	12357	VICPDTGEN	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12239	12354	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12239	12358	CONSMUNI	\N	1995	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12250	12371	MAIREADJOINT	1995-06-18 00:00:00	1998	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
12241	12360	DEPUTE	2002-06-16 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12110	12361	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12242	12362	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12243	12363	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12244	12365	VICPDTGEN	\N	2001	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
12246	12367	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12245	12366	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12245	12369	CONSMUNI	\N	1983	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12247	12368	PDTGEN	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12247	12370	CONSGENE	\N	2008	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12188	12308	MAIRE	2001-03-01 00:00:00	2001	2017-10-16 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2018-05-30 09:30:37
12190	12310	DEPUTE	1993-03-28 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2016-12-12 18:35:01
12193	12311	DEPUTE	\N	\N	\N	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12195	12313	CONSMUNI	1989-03-01 00:00:00	1989	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
12197	12314	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12250	12372	CONSMUNI	\N	1995	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
12340	12405	PDTINTCOM	\N	2008	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12335	12407	MAIREADJOINT	\N	2011	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12336	12406	PDTGEN	2011-03-31 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12252	12408	CONSREG	\N	2002	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12251	12410	MAIRE	2001-03-18 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12354	12416	MAIRE	\N	2008	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12355	12417	CONSREG	2004-04-13 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12356	12418	MAIRE	\N	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12360	12421	CONSGENE	\N	1982	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
12361	12422	MAIRE	\N	1995	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12360	12423	VICPDTGEN	\N	2004	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12362	12424	CONSGENE	1998-03-22 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12363	12425	CONSMUNI	\N	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12364	12426	MAIRE	\N	1989	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12365	12427	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12366	12428	PDTINTCOM	\N	1992	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
12368	12429	CONSGENE	1994-03-27 00:00:00	\N	2008-03-09 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12369	12430	VICPDTREG	2004-03-28 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12370	12431	CONSGENE	1992-03-29 00:00:00	\N	2004-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12370	12432	VICPDTGEN	2011-03-27 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12375	12441	CONSGENE	\N	1982	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12376	12442	CONSREG	\N	1986	2004-03-28 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
12376	12444	PREVICPDTREG	2004-03-29 00:00:00	2004	2010-03-20 00:00:00	2010	ANCIEN	\N	\N	\N	NON	\N	\N
12376	12447	CONSREG	2010-03-21 00:00:00	2010	2011-12-31 00:00:00	2011	ANCIEN	\N	\N	\N	NON	\N	\N
12379	12450	CONSREG	2004-03-28 00:00:00	\N	2010-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12379	12451	VICPDTREG	2010-03-26 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12088	12282	PDTINTCOM	\N	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12380	12452	CONSMUNI	\N	2008	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12341	12521	MAIRE	1995-06-18 00:00:00	\N	2017-11-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2018-03-08 15:20:55
12401	12523	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12192	12524	MAIREADJOINT	1983-03-01 00:00:00	1983	1986-04-07 00:00:00	1986	ANCIEN	\N	\N	\N	NON	\N	\N
12186	12525	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12253	13055	PDTINTCOM	2001-03-18 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12400	12527	CONSREG	1986-03-16 00:00:00	\N	2001-03-16 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
12187	12526	VICPDTGEN	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12402	12531	PREVICPDTGEN	\N	2004	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12416	12582	CONSGENE	1985-03-17 00:00:00	\N	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
12200	12539	CONSGENE	1975-01-19 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12200	12543	VICPDTGEN	\N	1992	2004-04-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12204	12542	MAIREADJOINT	1974-03-10 00:00:00	1974	2001-03-10 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
12200	12545	PDTGEN	2004-04-30 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12203	12548	PDTINTCOM	1994-04-30 00:00:00	1994	2004-04-30 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
12207	12556	MAIRE	2008-03-16 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12413	12571	MAIRE	\N	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12413	12586	CONSMUNI	\N	1989	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12418	12585	DEPUTE	1986-03-16 00:00:00	\N	\N	1988	ANCIEN	\N	\N	\N	NON	\N	\N
12418	12587	DEPUTE	\N	1993	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
12414	12573	PDTINTCOM	\N	2008	\N	\N	\N	\N	\N	\N	NON	\N	\N
12414	12589	MEMBREINTCOM	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12418	12590	DEPUTE	1986-03-16 00:00:00	\N	\N	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12175	12599	CONSGENE	\N	1985	\N	1986	ANCIEN	\N	\N	\N	NON	\N	\N
12415	12591	CONSREG	2004-03-28 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12413	12592	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12178	12597	MAIRE	\N	1989	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
12175	12598	VICPDTGEN	\N	1986	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
12181	12609	VICPDTGEN	\N	1994	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
12175	12601	PDTGEN	2004-04-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12178	12602	MAIREADJOINT	\N	2004	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
12077	12271	DEPUTE	\N	1946	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12079	12274	CONSGENE	\N	\N	2011-03-27 00:00:00	2011	ANCIEN	\N	\N	\N	NON	\N	\N
10929	12277	CONSGENE	2011-03-28 00:00:00	2011	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12290	12380	CONSGENE	\N	1970	\N	1973	ANCIEN	\N	\N	\N	NON	\N	\N
12279	12374	PDTGEN	2001-01-01 00:00:00	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12248	12375	CONSREG	2010-03-21 00:00:00	2010	2011-10-25 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12290	12381	CONSGENE	\N	1955	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12293	12384	CONSREG	\N	1983	\N	1991	ANCIEN	\N	\N	\N	NON	\N	\N
12293	12385	PREVICPDTREG	\N	1992	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
12293	12386	PDTREG	\N	1998	\N	2010	ANCIEN	\N	\N	\N	NON	\N	\N
12182	12613	CONSGENE	1998-03-15 00:00:00	\N	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
12184	12617	VICPDTREG	\N	1994	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
12183	12622	MAIRE	\N	1995	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12425	12619	DEPUTE	1997-06-01 00:00:00	1997	2002-06-18 00:00:00	2002	ANCIEN	\N	\N	\N	NON	\N	2017-06-15 10:51:29
12191	12629	PDTINTCOM	1997-01-01 00:00:00	\N	2012-02-26 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12192	12626	MAIRE	1986-04-08 00:00:00	1986	2014-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-16 17:20:20
12402	12627	CONSGENE	\N	1985	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
12219	12630	MAIRE	\N	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12220	12631	CONSREG	2004-03-28 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12392	13078	MAIRE	2012-03-18 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12232	12633	VICPDTGEN	2004-03-28 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12232	12634	CONSGENE	2011-03-27 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12427	12635	CONSGENE	\N	1985	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12427	12636	PREVICPDTGEN	\N	2004	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12428	12637	MAIRE	\N	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12429	12638	CONSMUNI	\N	1993	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
12430	12639	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12430	12640	CONSGENE	1994-03-27 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12432	12642	MAIRE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12432	12643	CONSMUNI	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12431	12644	MAIRE	\N	1995	\N	2001	ANCIEN	\N	\N	\N	NON	\N	\N
12433	12645	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	2002	ANCIEN	\N	\N	\N	NON	\N	2017-06-15 10:49:13
12434	12646	PDTGEN	1998-03-27 00:00:00	\N	2010-11-09 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12434	12647	CONSGENE	1994-03-27 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12435	12648	PREVICPDTREG	\N	2004	2010-04-10 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12448	12649	MAIRE	\N	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12449	12650	CONSREG	1998-03-15 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12456	12656	DEPUTE	2010-11-12 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12450	12652	CONSGENE	2007-11-25 00:00:00	\N	2008-03-09 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12451	12653	MAIRE	\N	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12457	12657	CONSGENE	1994-03-20 00:00:00	\N	2001-03-11 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12459	12659	CONSREG	1998-03-15 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12460	12660	CONSREG	1998-03-15 00:00:00	1998	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
12460	12661	VICPDTREG	\N	1998	2004-03-21 00:00:00	2004	ANCIEN	\N	\N	\N	NON	\N	\N
12461	12662	MAIREADJOINT	2008-03-01 00:00:00	2008	2013-01-01 00:00:00	2013	ANCIEN	\N	\N	\N	NON	\N	\N
12466	12668	MAIRE	2008-03-23 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12475	12675	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12475	12676	DEPUTE	\N	1994	\N	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12468	12671	VICPDTGEN	2000-03-01 00:00:00	\N	2006-02-28 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12469	12673	MAIREADJOINT	\N	\N	\N	2000	ANCIEN	\N	\N	\N	NON	\N	\N
12476	12677	CONSGENE	2001-03-18 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12476	12678	PDTGEN	2004-04-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12484	12690	CONSGENE	2008-03-16 00:00:00	2008	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12478	12683	CONSMUNI	\N	2008	\N	2009	ANCIEN	\N	\N	\N	NON	\N	\N
12485	12691	VICPDTGEN	\N	2008	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12485	12692	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12487	12693	CONSGENE	1990-10-07 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12489	12694	MAIRE	1995-06-18 00:00:00	\N	2017-10-16 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-11-14 09:44:48
12490	12695	CONSGENE	1994-03-27 00:00:00	\N	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
12490	12696	VICPDTGEN	1995-02-01 00:00:00	1995	2001-03-01 00:00:00	2001	ANCIEN	\N	\N	\N	NON	\N	\N
12289	12376	CONSMUNI	\N	1995	\N	2000	ANCIEN	\N	\N	\N	NON	\N	2016-09-29 18:15:55
12289	12377	MAIRE	\N	2001	2008-03-16 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2016-09-29 18:15:55
12163	12382	CONSGENE	2001-03-11 00:00:00	\N	2008-03-19 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12163	12383	PDTGEN	2008-03-20 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12381	12453	CONSREG	1998-03-15 00:00:00	\N	\N	2011	ANCIEN	\N	\N	\N	NON	\N	2013-04-10 17:20:40
12382	12454	MAIREADJOINT	2001-03-01 00:00:00	2001	2005-10-31 00:00:00	2005	ANCIEN	\N	\N	\N	NON	\N	\N
12382	12455	MAIRE	2005-11-01 00:00:00	2005	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12103	12459	MAIRE	\N	1989	\N	2011	ANCIEN	\N	\N	\N	NON	\N	\N
12384	12460	CONSARR	\N	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12137	12464	PDTGEN	\N	2004	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12385	12462	CONSGENEPARI	\N	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12137	12465	CONSGENE	\N	1995	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
12139	12466	MAIREADJOINT	\N	1991	\N	2011	ANCIEN	\N	\N	\N	NON	\N	\N
12560	12823	DEPUTE	2002-06-01 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12146	12468	MAIREADJOINT	2001-03-15 00:00:00	\N	2014-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-09 17:14:52
12147	12469	DEPUTE	2010-06-11 00:00:00	2010	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2017-06-15 10:51:49
12386	12471	MAIREADJOINT	1995-06-18 00:00:00	\N	\N	2014	ANCIEN	\N	\N	\N	NON	\N	2014-11-18 16:06:12
12106	12473	VICPDTREG	2010-03-01 00:00:00	\N	2011-12-18 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12387	12474	MAIRE	\N	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12387	12475	CONSMUNI	\N	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12388	12476	VICPDTINTCOM	\N	2001	\N	\N	\N	\N	\N	\N	NON	\N	\N
12388	12477	MEMBREINTCOM	\N	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12107	12478	MAIRE	2001-03-18 00:00:00	\N	2014-03-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	2014-04-07 11:24:00
12108	12479	CONSREG	\N	2004	\N	2010	ANCIEN	\N	\N	\N	NON	\N	\N
12107	12480	CONSMUNI	1995-06-18 00:00:00	\N	2001-03-18 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12162	12481	MAIRE	1995-06-01 00:00:00	\N	2011-10-13 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12389	12482	CONSGENE	\N	2011	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12389	12483	PREVICPDTGEN	\N	2004	\N	2011	ANCIEN	\N	\N	\N	NON	\N	\N
12389	12485	CONSGENE	\N	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12561	12824	CONSGENE	2001-03-11 00:00:00	\N	2008-03-19 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12115	12484	DEPUTE	1996-11-26 00:00:00	1996	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12390	12486	MAIREADJOINT	1995-06-18 00:00:00	\N	2011-11-17 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
684	13080	MAIRE	\N	1989	\N	1996	ANCIEN	\N	\N	\N	NON	\N	\N
12166	12488	MAIREADJOINT	\N	1983	\N	2008	ANCIEN	\N	\N	\N	NON	\N	\N
12166	12489	CONSMUNI	\N	1977	\N	1983	ANCIEN	\N	\N	\N	NON	\N	\N
12166	12490	MAIRE	\N	2008	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12391	12491	MAIRE	\N	1989	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12170	12492	CONSREG	\N	2010	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12169	12493	CONSGENE	\N	2011	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12392	12494	MAIREADJOINT	2001-03-18 00:00:00	\N	2012-03-17 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
12394	12497	VICPDTGEN	\N	2008	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12394	12498	CONSGENE	\N	2008	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12395	12499	PDTGEN	\N	2001	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12395	12500	CONSGENE	\N	1994	\N	1995	ANCIEN	\N	\N	\N	NON	\N	\N
12395	12501	VICPDTGEN	\N	1995	\N	1998	ANCIEN	\N	\N	\N	NON	\N	\N
12395	12502	CONSGENE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12396	12503	MAIREADJOINT	1977-03-01 00:00:00	1977	1989-03-01 00:00:00	1989	ANCIEN	\N	\N	\N	NON	\N	\N
12397	12505	CONSMUNI	\N	1970	\N	1974	ANCIEN	\N	\N	\N	NON	\N	\N
12398	12506	MAIRE	\N	1989	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12399	12508	MAIRE	\N	1977	\N	1997	ANCIEN	\N	\N	\N	NON	\N	\N
12399	12509	MAIRE	\N	2002	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12399	12510	CONSMUNI	\N	1977	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12096	12511	MAIRE	\N	2008	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12095	12512	CONSGENE	\N	2004	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12338	12513	VICPDTGEN	\N	2004	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12339	12514	VICPDTREG	2010-03-26 00:00:00	\N	\N	2013	ANCIEN	\N	\N	\N	NON	\N	2013-04-05 18:17:32
12151	12515	MAIREADJOINT	\N	1995	\N	1999	ANCIEN	\N	\N	\N	NON	\N	\N
12151	12516	MAIREADJOINT	\N	2008	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12149	12517	VICPDTGEN	\N	2004	\N	2011	ANCIEN	\N	\N	\N	NON	\N	\N
12149	12518	CONSGENE	\N	2001	\N	2004	ANCIEN	\N	\N	\N	NON	\N	\N
12105	12519	CONSREG	\N	2010	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
12149	12520	CONSGENE	\N	2011	\N	\N	ACTIF	\N	\N	\N	NON	\N	\N
10449	12104	PDTINTCOM	2001-10-31 00:00:00	\N	\N	\N	ACTIF	\N	Président de la Communauté d'agglomération de Bourges	Président de la Communauté d'agglomération de Bourges	NON	\N	\N
10450	12105	PDTINTCOM	2001-12-28 00:00:00	2001	\N	2008	ANCIEN	\N	Président de la Communauté d'agglomération de Brive	Président de la Communauté d'agglomération de Brive	NON	\N	\N
10451	12106	PDTINTCOM	2002-10-31 00:00:00	\N	2003-11-04 00:00:00	2003	ANCIEN	\N	Président de la Communauté d'agglomération du Drouais	Président de la Communauté d'agglomération du Drouais	NON	\N	\N
10452	12107	PDTINTCOM	2001-12-31 00:00:00	\N	2008-04-18 00:00:00	2008	ANCIEN	\N	Président de la Communauté d'agglomération Nice-Côte d'Azur	Président de la Communauté d'agglomération Nice-Côte d'Azur	NON	\N	\N
10454	12108	PDTINTCOM	2002-02-08 00:00:00	2002	\N	\N	ACTIF	\N	Président de la Communauté d'agglomération Toulon Provence Méditerranée	Président de la Communauté d'agglomération Toulon Provence Méditerranée	NON	\N	\N
1753	12109	PDTINTCOM	\N	\N	2016-05-01 00:00:00	2016	ANCIEN	\N	Président du district du Grand Caen	Président du district du Grand Caen	NON	\N	\N
10539	12110	VICPDTINTCOM	\N	\N	\N	2008	ANCIEN	\N	Vice-président de la Communauté de communes du canton de Pipriac	Vice-président de la Communauté de communes du canton de Pipriac	NON	\N	\N
1445	13513	CONSGENE	1998-03-23 00:00:00	\N	2002-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 15:35:02	2014-09-28 15:35:27
12802	13174	CONSMUNI	2014-04-01 00:00:00	\N	2014-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-04-23 12:31:23	2014-06-10 10:42:06
13773	13187	VICPDTINTCOM	\N	2011	2017-10-02 00:00:00	\N	ANCIEN	\N	Vice-président de la Communauté des communes de la Haute Saintonge	\N	\N	2014-05-12 16:31:55	2017-10-04 16:01:05
14079	13518	CONSMUNI	1989-04-01 00:00:00	\N	1995-03-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 15:51:40	2014-09-28 15:53:09
14079	13519	MAIRE	1995-04-01 00:00:00	\N	2017-10-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 15:53:15	2018-01-25 10:02:05
14080	13520	CONSGENE	1988-04-01 00:00:00	\N	2004-03-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 15:54:58	2014-09-28 15:56:24
14080	13521	CONSGENE	2008-04-01 00:00:00	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 15:56:28	2014-09-28 15:56:46
14081	13522	CONSREG	\N	2004	\N	2008	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 16:02:07	2014-09-30 09:46:39
14092	13524	VICPDTREG	\N	2014	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-28 16:51:35	2014-09-28 17:12:33
11272	13685	CONSGENE	2014-10-21 00:00:00	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-10-21 17:19:15	\N
14260	13675	VICPDTGEN	2004-03-01 00:00:00	\N	2008-03-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-10-01 13:38:21	2014-10-01 13:38:55
14375	13676	PDTINTCOM	2014-04-15 00:00:00	\N	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2014-10-01 13:48:09	2017-11-08 17:50:27
14376	13677	CONSINTCOM	\N	2014	\N	\N	ACTIF	\N	\N	\N	NON	2014-10-02 10:36:19	2014-10-02 10:41:07
14377	13678	CONSMUNI	\N	2014	2020-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-10-02 10:37:45	2014-10-02 10:39:50
14381	13684	PDTINTCOM	2014-10-15 00:00:00	\N	\N	\N	ACTIF	de la Communauté de communes de l'Ouest Rhodanien 	de la Communauté de communes de l'Ouest Rhodanien 	\N	\N	2014-10-15 18:14:57	2014-10-15 18:15:36
11402	13687	PDTINTCOM	2014-03-31 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	2014-10-23 10:57:30	2014-10-23 10:57:45
14386	13688	VICPDTINTCOM	2014-10-01 00:00:00	\N	2016-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2014-10-23 15:53:37	2018-06-06 17:02:03
10717	13689	MEMBREINTCOM	2014-10-02 00:00:00	\N	2015-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2014-10-23 16:10:20	2016-07-08 11:10:08
6494	13690	CONSCOMINT	2014-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	2014-10-28 17:13:56	2014-10-28 17:14:11
11713	13691	CONSCOMINT	2014-11-04 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	2014-11-05 15:34:03	2014-11-05 15:34:56
12850	13692	VICPDTINTCOM	2014-04-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	2014-11-10 12:12:43	\N
14389	13693	CONSCOMINT	2014-11-20 00:00:00	2014	2020-05-27 00:00:00	\N	ANCIEN	\N	Conseiller communautaire	\N	NON	2014-11-20 12:31:58	2014-11-20 12:37:49
14346	13694	CONSCOMINT	2014-10-02 00:00:00	\N	2021-01-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2014-12-04 18:04:19	\N
11709	13695	CONSCOMINT	2014-10-01 00:00:00	\N	\N	\N	ACTIF	Conseiller communautaire	Communauté d'agglomération périgourdine	\N	\N	2014-12-11 16:12:07	\N
11708	13696	CONSMUNI	2014-10-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-12-11 16:14:06	\N
14392	13697	MAIRE	\N	1989	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-12-18 16:30:45	\N
14393	13698	CONSREG	1998-03-15 00:00:00	\N	2004-03-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-12-18 16:31:28	2014-12-18 16:32:06
14393	13699	CONSREG	2004-04-01 00:00:00	\N	2014-12-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-12-18 16:32:29	2015-03-10 15:52:25
14394	13700	VICPDTINTCOM	2014-01-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-12-18 16:33:58	\N
14398	13701	MAIRE	2007-08-01 00:00:00	\N	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2014-12-29 15:48:25	2017-12-06 15:27:32
13986	13702	CONSREG	2015-01-02 00:00:00	\N	2015-12-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-01-14 10:36:38	2015-12-15 15:06:40
14402	13703	PDTMET	2015-01-01 00:00:00	2015	\N	\N	ACTIF	\N	\N	\N	\N	2015-01-15 09:53:40	\N
14403	13704	CONSMET	2015-01-01 00:00:00	2015	\N	\N	ACTIF	\N	\N	\N	\N	2015-01-15 09:53:46	\N
14404	13705	VICPDTMET	2015-01-01 00:00:00	2015	\N	\N	ACTIF	\N	\N	\N	\N	2015-01-15 09:53:51	\N
14405	13706	PDTMET	2015-01-01 00:00:00	2015	2017-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2015-01-16 09:42:49	\N
14406	13707	CONSMET	2015-01-01 00:00:00	2015	\N	\N	ACTIF	\N	\N	\N	\N	2015-01-16 09:42:53	\N
14412	13712	CONSMUNI	2014-04-01 00:00:00	\N	2020-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2015-01-27 10:20:55	\N
14408	13709	VICPDTMET	2015-01-01 00:00:00	2015	2017-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2015-01-16 10:22:18	2017-07-11 14:30:01
14409	13710	CONSMET	2015-01-01 00:00:00	2015	2020-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2015-01-16 10:23:48	2016-06-24 11:02:38
14411	13711	PDTINTCOM	2014-04-25 00:00:00	\N	2017-10-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2015-01-26 16:23:01	2017-11-13 10:10:31
14413	13713	CONSMUNI	2014-04-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2015-01-27 10:32:50	\N
14413	13714	MAIRE	\N	1995	2014-03-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2015-01-27 10:33:10	\N
15136	13715	MAIREADJOINT	2001-03-04 00:00:00	\N	2008-02-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2015-03-04 14:35:14	\N
15136	13716	PREMADJOINT	2008-03-01 00:00:00	\N	2014-03-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2015-03-04 14:35:31	2015-03-04 16:45:27
15137	13717	CONSGENE	2004-03-28 00:00:00	\N	2011-03-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2015-03-04 14:39:23	\N
15136	13718	CONSMUNI	2014-04-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2015-03-04 16:45:40	\N
15138	13719	CONSINTCOM	2015-04-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	2015-03-10 16:14:29	2015-03-10 16:18:45
11019	13720	CONSINTCOM	2015-03-17 00:00:00	\N	2017-01-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2015-03-17 15:39:26	\N
11832	13721	MEMBREINTCOM	\N	2014	2015-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2015-03-17 17:50:49	2016-06-23 10:58:56
15143	13722	CONSDPT	2015-03-30 00:00:00	\N	2015-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-03-31 14:54:17	2015-04-03 10:41:13
15147	13726	CONSDPT	2015-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2015-03-31 15:01:34	2015-03-31 15:02:07
15154	13733	CONSDPT	2015-03-30 00:00:00	\N	2015-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-03-31 15:07:21	2015-04-15 17:40:15
15146	13725	CONSDPT	2015-03-30 00:00:00	\N	2015-07-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-03-31 15:00:28	2015-10-21 12:20:36
15148	13727	CONSDPT	2015-03-30 00:00:00	\N	2021-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-03-31 15:02:49	2015-03-31 15:03:44
15152	13731	CONSDPT	2015-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2015-03-31 15:05:38	2015-03-31 15:09:07
15151	13730	CONSDPT	2015-03-30 00:00:00	\N	2015-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-03-31 15:04:24	2015-04-15 17:39:11
15153	13732	CONSDPT	2015-03-30 00:00:00	\N	2015-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-03-31 15:06:02	2015-04-03 10:43:37
15155	13734	PDTDPT	2015-04-03 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2015-03-31 15:07:52	2015-04-03 10:34:46
15156	13735	CONSDPT	2015-03-30 00:00:00	\N	2015-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2015-03-31 15:09:27	2015-04-03 10:35:04
15157	13736	CONSDPT	2015-03-30 00:00:00	\N	2015-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-03-31 15:09:49	2015-04-03 10:37:05
15158	13737	CONSDPT	2015-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2015-03-31 15:10:55	2015-03-31 15:11:19
15159	13738	CONSDPT	2015-03-30 00:00:00	\N	2015-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-03-31 15:11:13	2015-04-03 10:38:40
15160	13739	CONSDPT	2015-03-30 00:00:00	\N	2015-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-03-31 15:11:23	2015-04-15 17:42:47
15161	13740	CONSDPT	2015-03-30 00:00:00	\N	2015-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-03-31 15:11:37	2015-04-15 17:29:16
15162	13741	CONSDPT	2015-03-30 00:00:00	\N	2015-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-03-31 15:12:28	2015-04-15 17:26:38
15163	13742	CONSDPT	2015-03-30 00:00:00	\N	2020-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-03-31 15:12:53	2015-03-31 15:13:36
15164	13743	CONSDPT	2015-03-30 00:00:00	\N	2015-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-03-31 15:13:03	2015-04-03 11:26:28
15165	13744	CONSDPT	2015-03-30 00:00:00	\N	2015-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2015-03-31 15:13:08	2015-04-03 10:38:28
15166	13745	CONSDPT	2015-03-30 00:00:00	\N	2015-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2015-03-31 15:13:46	2015-04-03 10:40:41
15167	13746	CONSDPT	2015-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2015-03-31 15:13:56	2015-03-31 15:15:28
15168	13747	CONSDPT	2015-03-30 00:00:00	\N	2015-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-03-31 15:15:46	2015-04-15 17:41:17
15169	13748	CONSDPT	2015-03-30 00:00:00	\N	2021-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-03-31 15:17:26	2015-03-31 15:17:53
15170	13749	CONSDPT	2015-03-30 00:00:00	\N	2015-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-03-31 15:19:05	2015-04-03 10:42:05
15171	13750	CONSDPT	2015-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2015-03-31 15:20:38	2015-03-31 15:21:07
15172	13751	CONSDPT	2015-03-30 00:00:00	\N	2015-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-03-31 16:42:06	2015-04-03 11:07:03
15173	13752	CONSDPT	2015-03-30 00:00:00	\N	2015-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-03-31 16:45:20	2015-04-15 17:31:42
15174	13753	CONSDPT	2015-03-30 00:00:00	\N	2015-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-03-31 16:55:02	2015-04-15 17:38:15
12948	13125	MAIREADJOINT	2008-03-16 00:00:00	\N	2014-03-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-02-14 17:34:40	2014-04-07 16:19:53
12949	13126	VICPDTREG	2010-03-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2014-02-14 17:37:54	2014-02-14 17:39:25
11716	13154	CONSMUNI	2014-04-08 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	2014-04-08 12:20:51	2014-04-08 12:21:24
12518	13135	PREPDTINTCOM	2014-04-04 00:00:00	\N	2015-12-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-04-04 19:02:26	2016-07-08 10:52:42
11276	13158	CONSMUNI	2014-04-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2014-04-08 16:08:13	2014-04-08 16:08:21
12545	13209	PREVICPDTGEN	2014-06-21 00:00:00	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-07-16 16:12:27	2014-07-16 16:12:46
13796	13220	CONSGENE	1988-10-03 00:00:00	\N	2004-03-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-16 11:31:07	2014-09-16 11:34:45
13800	13225	CONSMUNI	\N	1977	\N	1984	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-16 11:40:28	2014-09-16 11:42:24
13801	13226	CONSREG	\N	1992	\N	1997	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-16 11:42:57	2014-09-16 11:43:44
13796	13221	PDTGEN	2004-03-28 00:00:00	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-16 11:33:07	2014-09-16 11:35:44
13799	13224	SECAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-16 11:38:21	2017-06-29 09:19:43
13810	13238	MAIREADJOINT	\N	2014	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2014-09-16 16:49:13	2014-09-16 16:52:49
13811	13239	CONSREG	\N	2014	2015-12-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-09-16 16:55:20	2015-12-15 14:59:51
13813	13240	MAIRE	1995-06-20 00:00:00	1995	2017-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2014-09-16 17:00:28	2017-11-15 10:08:33
13813	13241	CONSMUNI	\N	\N	\N	1994	ANCIEN	\N	\N	\N	NON	2014-09-16 17:01:48	2014-09-16 17:02:17
13814	13242	CONSGENE	2011-03-20 00:00:00	2011	2015-01-02 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2014-09-16 17:04:10	2015-01-28 16:03:09
13815	13243	PDTINTCOM	\N	\N	\N	2013	ANCIEN	\N	\N	\N	NON	2014-09-16 17:06:40	2014-09-16 17:10:58
13816	13244	CONSREG	\N	1992	\N	1998	ANCIEN	\N	\N	\N	NON	2014-09-16 17:15:54	2014-09-16 17:17:55
13842	13270	MAIRE	\N	2001	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-17 16:56:01	2014-09-17 17:06:34
13818	13246	MAIREADJOINT	\N	2014	\N	\N	ACTIF	\N	\N	\N	NON	2014-09-16 17:19:14	2014-09-16 17:20:58
13850	13279	PDTGEN	\N	2008	2015-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-17 17:28:25	2014-09-28 21:12:40
13844	13273	PDTINTCOM	\N	2001	\N	2013	ANCIEN	\N	\N	\N	\N	2014-09-17 17:06:54	2014-09-17 17:10:14
13848	13277	CONSREG	\N	2004	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-17 17:24:09	2014-09-17 17:24:36
13851	13280	CONSMUNI	\N	2013	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-17 17:31:52	2014-09-17 17:32:20
13852	13281	CONSREG	\N	2013	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-17 17:32:59	2014-09-17 17:33:18
13854	13283	MAIRE	2008-03-21 00:00:00	2008	2016-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-17 17:34:18	2017-11-09 10:19:08
13855	13284	MAIRE	\N	2008	2017-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-17 17:35:33	2017-11-09 14:31:33
13862	13292	MAIRE	\N	1989	\N	2008	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-17 17:52:37	2014-09-17 17:53:05
13861	13291	CONSREG	\N	2014	2014-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-17 17:44:12	2014-12-04 18:03:32
13863	13293	CONSGENE	\N	2004	\N	2011	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-17 17:53:26	2014-09-17 17:54:33
13867	13298	MAIREADJOINT	1989-03-20 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-17 18:02:01	2014-09-17 18:02:52
13867	13297	CONSMUNI	1983-03-14 00:00:00	\N	1989-03-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-09-17 17:59:42	2014-09-17 18:10:15
13867	13299	MAIRE	1995-06-19 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	2014-09-17 18:04:13	2014-09-17 18:10:55
13872	13303	VICPDTGEN	1998-03-23 00:00:00	\N	2002-08-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2014-09-17 18:11:11	2014-09-17 18:12:23
13987	13444	CONSREG	\N	2004	\N	2014	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-09-18 16:21:01	2015-01-15 15:06:19
13990	13447	DEPUTE	2007-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 16:25:20	2016-12-12 12:11:31
13998	13455	MAIRE	1993-04-18 00:00:00	1993	2017-09-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 18:04:23	2017-11-08 16:26:58
14001	13462	CONSREG	2010-03-26 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-19 11:05:41	2014-09-19 11:06:12
14002	13463	CONSMUNI	\N	1989	\N	2000	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-19 11:06:29	2014-09-19 11:07:50
14002	13464	MAIREADJOINT	\N	2001	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-19 11:10:20	2014-09-19 11:15:49
14003	13465	CONSGENE	\N	2001	\N	2010	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-19 11:16:18	2014-09-19 11:17:16
14004	13466	CONSREG	2012-07-20 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-19 11:19:38	2014-09-19 11:26:12
14005	13467	MAIRE	\N	2014	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-19 11:24:26	2014-09-19 11:25:23
14006	13468	MAIRE	\N	2008	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-19 11:27:37	2014-09-19 11:28:14
14007	13469	PDTINTCOM	2013-01-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	2014-09-19 11:41:12	2014-09-19 11:42:06
13856	13622	PDTINTCOM	2008-04-01 00:00:00	\N	2014-03-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-09-29 12:09:39	2014-09-29 17:49:11
14049	13502	MAIRE	1989-04-01 00:00:00	\N	2001-03-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 12:51:31	2014-09-28 12:52:43
14051	13503	MAIRE	2001-04-01 00:00:00	\N	2017-07-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 12:52:48	2017-11-09 11:24:40
14196	13552	MAIREADJOINT	2014-03-30 00:00:00	\N	2017-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2014-09-28 17:47:24	2017-11-16 10:38:42
14228	13561	MAIRE	1989-03-01 00:00:00	\N	2017-11-02 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2014-09-28 18:00:47	2017-11-22 10:21:44
14199	13555	CONSINTCOM	2014-09-28 00:00:00	\N	2015-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2014-09-28 17:50:47	2016-07-08 11:14:19
14308	13597	MAIRE	2008-03-16 00:00:00	\N	2017-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2014-09-28 19:32:07	2018-01-23 18:51:36
14309	13598	PDTINTCOM	2014-04-25 00:00:00	\N	2017-09-21 00:00:00	\N	ANCIEN	de la Communauté de Communes Rhône Crussol	de la Communauté de Communes Rhône Crussol	\N	NON	2014-09-28 19:32:50	2018-01-23 18:53:01
14310	13600	CONSREG	2010-03-15 00:00:00	2010	2015-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-09-28 19:34:19	2015-10-21 16:33:22
14321	13611	VICPDTGEN	\N	1998	\N	2010	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-29 09:22:30	2015-01-13 17:26:22
14326	13612	CONSREG	\N	2000	\N	2001	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-09-29 09:50:46	2014-09-29 09:54:40
14327	13613	PDTINTCOM	2014-09-29 00:00:00	\N	2017-10-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-09-29 09:58:34	2017-11-30 15:11:12
50780	50073	DEPUTE	2007-06-26 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	2017-08-18 12:17:52	\N
12936	13614	CONSGENE	2014-01-23 00:00:00	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-09-29 10:23:20	2014-09-29 10:23:30
14020	13625	CONSGENE	1982-03-31 00:00:00	\N	1991-02-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-29 13:53:31	2014-09-29 13:55:20
14333	13620	CONSGENE	1998-03-15 00:00:00	\N	2014-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2014-09-29 11:28:51	2014-10-23 12:11:18
14343	13635	CONSGENE	\N	2011	2014-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-30 09:50:25	2014-10-22 17:21:11
14020	13626	VICPDTGEN	2008-03-13 00:00:00	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-29 13:55:22	2014-11-18 16:00:49
14340	13628	CONSGENE	1998-04-02 00:00:00	\N	2015-03-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-29 15:21:37	2015-03-10 16:41:01
14341	13629	VICPDTINTCOM	1989-04-15 00:00:00	\N	2015-04-02 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2014-09-29 16:11:02	2014-09-29 16:16:31
11147	13630	DEPUTE	1993-03-28 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2014-09-29 17:02:15	2016-12-12 11:35:33
13964	13631	CONSREG	\N	2005	\N	2008	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-29 17:20:31	2014-09-29 17:20:45
14344	13636	MAIRE	2001-03-20 00:00:00	\N	2017-09-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-30 10:38:49	2017-12-01 14:49:13
14345	13637	PDTINTCOM	2001-04-01 00:00:00	\N	2017-09-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2014-09-30 10:39:21	2017-12-01 14:49:51
14053	13644	VICPDTGEN	1996-03-01 00:00:00	\N	2008-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-30 11:22:01	2014-09-30 11:22:54
14053	13646	CONSGENE	2008-04-02 00:00:00	\N	2015-01-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-30 11:22:54	2015-01-13 12:04:23
14352	13648	VICPDTINTCOM	2014-04-01 00:00:00	\N	2014-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2014-09-30 11:34:38	2014-11-21 14:36:55
14353	13649	PDTINTCOM	2010-03-01 00:00:00	\N	2014-03-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2014-09-30 11:49:18	2014-09-30 11:50:36
14354	13650	CONSGENE	1998-03-01 00:00:00	\N	2004-03-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-30 11:53:27	2014-09-30 11:53:57
11579	13192	MAIRE	2014-03-31 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-05-27 18:18:12	2014-05-27 18:30:55
13787	13212	PDTGEN	2010-11-21 00:00:00	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2014-08-27 16:39:30	2014-08-27 16:40:15
13787	13211	CONSGENE	2008-03-16 00:00:00	\N	2010-11-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-08-27 16:38:52	2014-08-27 16:39:48
13788	13213	VICPDTREG	2010-03-21 00:00:00	\N	\N	2010	ANCIEN	\N	\N	\N	NON	2014-08-27 16:43:33	2014-08-28 11:11:55
13789	13214	CONSMUNI	\N	2001	\N	2005	ANCIEN	\N	\N	\N	NON	2014-08-27 16:44:55	2014-08-27 16:45:16
13788	13215	CONSREG	\N	2011	\N	2011	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-08-28 11:11:22	2014-09-03 13:49:31
13827	13257	CONSMUNI	\N	1977	\N	2002	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-17 11:56:39	2014-09-17 11:57:34
13828	13258	CONSGENE	\N	1985	2015-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-17 11:57:48	2014-09-17 11:58:38
13829	13259	CONSREG	\N	1983	\N	1986	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-17 11:58:45	2014-09-17 11:59:32
13829	13260	PDTREG	\N	1992	\N	2010	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-17 11:59:38	2014-09-29 09:30:04
13832	13261	CONSREG	2004-05-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-17 12:03:07	2014-09-17 12:04:25
13836	13264	VICPDTGEN	\N	2011	2015-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-17 12:10:13	2014-09-17 12:13:50
13835	13263	CONSREG	\N	2008	2015-01-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-17 12:09:06	2015-01-13 12:02:36
13888	13317	DEPUTE	\N	1993	\N	1997	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 11:04:45	2014-09-18 11:06:18
13889	13319	MAIRE	\N	1989	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-18 11:06:29	2014-09-18 11:11:59
13893	13324	CONSGENE	\N	1982	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-18 11:12:39	2014-09-18 11:14:01
13899	13332	MAIRE	1995-06-18 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-18 11:21:44	2014-09-29 14:34:21
13900	13333	CONSMUNI	1989-05-07 00:00:00	1989	1993-05-16 00:00:00	1995	ANCIEN	\N	\N	\N	NON	2014-09-18 11:22:08	2014-09-29 15:51:38
13905	13339	MAIRE	\N	2008	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-18 11:33:38	2014-09-18 11:39:13
13908	13342	PDTINTCOM	\N	2013	\N	\N	ACTIF	\N	\N	\N	\N	2014-09-18 11:39:19	2014-09-18 11:41:32
13919	13356	CONSMUNI	\N	1983	\N	1985	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 11:52:33	2014-09-18 11:52:54
13919	13355	MAIRE	\N	1986	\N	1995	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 11:52:03	2014-09-18 11:52:31
13920	13357	MAIRE	\N	1996	\N	2008	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 11:53:07	2014-09-18 11:53:56
13920	13358	PREMADJOINT	\N	2009	\N	2010	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 11:54:01	2014-09-18 11:54:22
13922	13361	CONSREG	\N	2010	\N	2014	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-09-18 11:54:38	2015-01-14 15:53:42
13924	13363	PDTGEN	\N	2008	2015-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 11:55:09	2014-09-18 11:55:42
13924	13364	CONSGENE	\N	1994	\N	2007	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 11:55:45	2014-09-18 11:55:56
13925	13365	PDTINTCOM	\N	1999	\N	2010	ANCIEN	\N	de la Communauté de communes des Pays d'Olt et d'Aubrac	\N	\N	2014-09-18 11:56:15	2014-09-18 11:57:38
13934	13376	CONSGENE	\N	1994	2015-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 12:01:26	2014-09-18 12:01:58
13929	13370	DEPUTE	2007-06-17 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-09-18 11:59:03	2016-12-13 11:06:30
13935	13377	CONSMUNI	\N	2001	\N	2004	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 12:02:15	2014-09-18 12:03:47
13937	13379	CONSREG	\N	2004	\N	2007	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 12:03:56	2014-09-18 12:04:13
13940	13384	MAIRE	\N	1997	\N	2001	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 12:07:56	2014-09-18 14:37:33
13954	13402	CONSGENE	\N	2001	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-18 14:37:40	2014-09-18 14:38:12
13956	13405	MAIRE	2001-03-14 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-18 14:39:30	2014-09-18 14:43:00
13955	13404	PREPDTINTCOM	\N	1997	\N	2001	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 14:38:25	2014-09-18 14:39:26
13956	13406	CONSMUNI	\N	1995	2001-03-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 14:41:17	2014-09-18 14:43:00
13957	13407	MAIRE	\N	1995	2016-01-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-09-18 14:41:20	2016-06-10 11:23:59
13958	13408	VICPDTGEN	\N	2011	\N	2014	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-09-18 14:42:02	2014-11-27 17:54:32
13959	13409	CONSGENE	2011-03-14 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-18 14:43:15	2014-09-18 14:44:00
13960	13410	PDTINTCOM	\N	2014	2018-01-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 14:43:56	2018-01-24 12:48:16
13961	13411	MAIRE	2008-03-10 00:00:00	\N	2015-12-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 14:45:15	2017-05-22 11:52:44
13962	13412	MAIRE	\N	1995	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-18 14:45:39	2014-09-18 14:47:01
13963	13413	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 14:46:01	2017-06-15 10:51:18
13964	13414	VICPDTREG	\N	1992	\N	2004	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-09-18 14:46:47	2014-09-29 17:20:29
13965	13415	CONSGENE	\N	2001	2015-01-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 14:47:11	2015-01-14 21:33:35
13968	13419	MAIRE	\N	2008	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-18 14:51:41	2014-09-18 14:52:35
13966	13417	PDTINTCOM	\N	2001	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-18 14:50:15	2014-09-18 14:50:29
13969	13420	MAIRE	1989-03-20 00:00:00	\N	2001-03-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 14:58:11	2014-09-18 14:58:48
13970	13421	CONSGENE	1988-09-01 00:00:00	\N	1994-03-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 14:59:11	2014-09-18 15:00:26
13970	13422	PREVICPDTGEN	1994-04-27 00:00:00	\N	2001-03-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 15:00:28	2014-09-18 15:00:56
13970	13423	PDTGEN	2014-04-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-18 15:00:58	2014-09-18 15:02:12
13969	13424	CONSMUNI	2001-04-18 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-18 15:02:30	2014-09-18 15:02:44
13972	13426	DEPUTE	\N	2007	\N	2012	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 15:03:01	2014-09-18 15:03:17
13973	13427	CONSINTCOM	\N	2013	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-18 15:03:29	2014-09-18 15:04:22
13991	13448	MAIRE	\N	1977	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-18 17:23:34	2014-09-18 17:24:55
13975	13429	MAIRE	\N	1983	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-18 15:30:30	2014-09-18 15:33:29
13992	13449	CONSGENE	\N	1989	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-18 17:25:09	2014-09-18 17:26:25
13993	13450	CONSREG	2010-03-22 00:00:00	\N	2010-04-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 17:26:41	2014-09-18 17:28:04
13994	13451	MAIRE	\N	2001	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-18 17:28:43	2014-09-18 17:29:41
13995	13452	PDTINTCOM	2014-04-24 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	2014-09-18 17:30:06	2014-09-18 17:33:44
13996	13453	CONSGENE	2001-04-02 00:00:00	2001	2014-12-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 17:34:41	2015-01-14 10:05:04
13997	13454	MAIRE	1992-04-02 00:00:00	\N	2016-09-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 17:35:57	2016-09-30 11:38:58
14019	13483	DEPUTE	1993-03-28 00:00:00	\N	2012-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-22 14:34:35	2016-12-12 16:33:48
14021	13485	MAIREADJOINT	1983-03-06 00:00:00	\N	1989-03-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-22 14:36:45	2014-09-22 14:37:19
14022	13486	CONSREG	\N	2010	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-22 14:38:53	2014-09-22 14:39:16
14077	13516	PDTGEN	2010-11-09 00:00:00	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2014-09-28 15:44:18	2014-09-29 15:58:55
14078	13517	MAIRE	\N	1982	\N	2010	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-09-28 15:46:08	2014-09-30 16:23:24
14082	13523	PREMADJOINT	\N	2001	2020-01-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 16:04:53	2014-09-29 10:21:48
14168	13544	CONSGENE	1989-01-01 00:00:00	\N	2012-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2014-09-28 17:31:51	2014-09-29 16:54:43
14175	13547	CONSCOMINT	\N	2002	2015-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2014-09-28 17:34:37	2017-12-04 18:48:54
14179	13548	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 17:36:30	2017-06-15 10:51:41
13752	13156	MAIRE	2014-04-04 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2014-04-08 15:58:15	2014-04-08 15:59:22
10651	13157	CONSGENE	2014-04-18 00:00:00	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-04-08 16:00:49	2014-04-08 16:01:00
12930	13189	CONSMUNI	2014-04-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-05-20 10:20:44	2014-05-20 10:23:07
11988	13160	CONSMUNI	2014-04-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2014-04-08 16:24:42	2014-04-08 16:24:51
6059	13163	MAIREADJOINT	2014-04-01 00:00:00	\N	2017-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-04-09 10:37:39	2017-11-13 14:18:17
12862	13162	CONSMUNI	2014-04-01 00:00:00	\N	2014-06-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-04-08 16:58:11	2015-01-14 10:11:13
13754	13164	CONSINTCOM	2014-04-09 00:00:00	\N	2016-12-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-04-09 10:38:41	2016-12-12 16:10:14
6368	13165	CONSMUNI	2014-04-09 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2014-04-09 10:43:26	2014-04-09 10:43:32
12820	13208	CONSCOMINT	2014-04-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-06-27 16:56:28	2014-10-27 11:12:21
12146	13167	MAIRE	2014-04-01 00:00:00	\N	2017-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-04-09 17:14:18	2018-02-13 12:35:56
13758	13178	CONSMUNI	2014-04-01 00:00:00	\N	2016-08-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-04-29 18:18:38	2016-09-07 18:04:03
13776	13196	MAIREADJOINT	\N	2001	2014-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2014-05-28 16:13:28	2014-05-28 16:15:19
13759	13180	CONSINTCOM	2014-04-01 00:00:00	\N	2015-12-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-04-29 18:20:49	2016-09-08 10:21:46
12512	13207	CONSMUNI	2014-04-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-06-27 16:55:48	2014-06-27 16:56:28
13809	13237	CONSREG	\N	2014	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-16 16:42:27	2014-09-16 16:48:32
14346	13638	VICPDTINTCOM	2014-01-01 00:00:00	\N	2014-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2014-09-30 10:40:45	2014-12-04 18:04:02
13847	13276	PDTGEN	2008-03-21 00:00:00	2008	2015-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-17 17:23:08	2014-09-28 21:28:17
13849	13278	MAIRE	\N	1989	2014-03-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-17 17:27:17	2014-09-28 17:53:40
13853	13282	MAIRE	1995-06-19 00:00:00	\N	2016-12-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-09-17 17:33:16	2017-01-11 16:25:11
14349	13642	PDTINTCOM	\N	2014	2017-06-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2014-09-30 10:51:56	2014-09-30 10:53:38
13858	13287	CONSREG	1998-03-15 00:00:00	\N	2010-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-17 17:38:08	2014-09-17 17:39:10
13860	13290	VICPDTINTCOM	2014-04-03 00:00:00	\N	2017-01-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2014-09-17 17:42:03	2017-11-15 13:12:59
13859	13289	MAIRE	1995-06-01 00:00:00	\N	2017-10-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-17 17:41:08	2017-11-15 13:12:02
13876	13307	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 10:07:12	2017-06-15 10:48:54
13877	13308	PDTGEN	1991-02-22 00:00:00	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 10:08:08	2014-09-18 10:10:28
13877	13309	CONSGENE	1979-03-25 00:00:00	\N	\N	1990	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 10:09:25	2014-09-18 10:10:28
13879	13311	MAIRE	2001-03-19 00:00:00	\N	2017-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 10:45:37	2017-10-04 09:54:30
13880	13312	VICPDTGEN	2011-03-21 00:00:00	\N	2014-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 10:46:41	2014-11-19 16:50:35
13881	13313	CONSINTCOM	2014-03-17 00:00:00	\N	2014-12-31 00:00:00	2014	ANCIEN	du Grand Lyon	du Grand Lyon	\N	\N	2014-09-18 10:48:08	2015-01-16 09:48:29
13882	13314	MAIREADJOINT	1995-06-25 00:00:00	\N	2001-03-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 10:52:46	2014-09-18 10:54:18
13883	13315	DEPUTE	2007-06-20 00:00:00	2010	2008-04-19 00:00:00	2012	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 10:55:38	2017-06-29 09:19:01
13887	13316	CONSMUNI	\N	2014	2018-12-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 11:04:43	2014-09-18 11:06:16
13887	13318	MAIRE	\N	1995	\N	2013	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 11:05:51	2014-09-18 11:06:16
1445	13320	CONSGENE	1992-03-30 00:00:00	\N	1998-03-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 11:08:45	2014-09-28 15:34:47
13895	13326	CONSGENE	\N	1985	\N	1995	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 11:13:41	2014-09-18 11:14:16
13891	13322	CONSREG	2010-03-22 00:00:00	\N	2010-07-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 11:09:38	2014-09-18 11:10:08
13897	13329	PREVICPDTREG	\N	1986	\N	1993	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 11:16:32	2014-09-18 11:17:59
13896	13328	CONSGENE	\N	1998	\N	2008	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 11:15:41	2014-09-18 11:16:09
13898	13331	DEPUTE	1993-03-28 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-09-18 11:18:59	2016-12-12 12:00:30
13901	13334	DEPUTE	1993-03-28 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 11:23:24	2016-12-13 18:05:42
13910	13344	CONSGENE	\N	1980	2015-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 11:42:48	2014-09-18 11:59:40
13906	13340	DEPUTE	2002-06-16 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 11:34:14	2016-12-13 18:06:03
13907	13341	MAIRE	\N	1980	\N	2000	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 11:38:03	2014-09-18 12:03:55
13917	13352	MAIRE	\N	1995	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-18 11:47:56	2014-09-18 11:48:33
13918	13353	MAIREADJOINT	\N	1989	\N	1994	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 11:50:18	2014-09-18 11:53:41
13923	13362	VICPDTREG	\N	1998	\N	2003	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 11:54:52	2014-09-18 11:55:18
13918	13359	CONSMUNI	\N	1983	\N	1988	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 11:54:09	2014-09-18 11:54:24
13926	13366	VICPDTREG	1992-03-23 00:00:00	\N	1993-04-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 11:57:24	2014-09-18 12:06:36
13926	13381	CONSREG	1986-03-17 00:00:00	\N	1992-03-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 12:06:46	2014-09-18 12:07:11
13939	13382	MAIREADJOINT	\N	1995	\N	2000	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 12:07:12	2014-09-18 12:08:54
13930	13372	CONSMUNI	\N	2001	\N	2008	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 12:00:15	2014-09-18 12:04:19
13926	13383	CONSREG	2004-03-29 00:00:00	\N	2004-04-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 12:07:13	2014-09-18 12:07:39
13939	13386	MAIRE	\N	2001	\N	2010	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 12:08:13	2014-09-18 12:08:54
13947	13392	MAIRE	\N	2014	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-18 12:16:01	2014-09-18 12:16:22
13949	13394	MAIRE	\N	1989	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-18 12:20:07	2014-09-18 12:20:56
13950	13395	CONSMUNI	\N	1977	\N	1978	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 12:22:58	2014-09-18 12:23:32
13950	13396	MAIRE	\N	1979	\N	2008	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 12:23:35	2014-09-18 12:23:50
13951	13397	PDTINTCOM	\N	1989	2014-12-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 12:24:08	2014-12-29 15:40:09
13952	13398	PDTGEN	2008-03-20 00:00:00	2008	2014-12-27 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2014-09-18 12:25:11	2014-12-29 15:40:09
13999	13456	DEPUTE	1993-03-21 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-19 10:41:54	2016-12-13 11:14:20
13999	13457	DEPUTE	1997-06-12 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-19 10:43:03	2016-12-13 11:14:30
14000	13460	PDTGEN	2000-07-12 00:00:00	\N	2008-03-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-19 10:45:34	2014-09-19 10:46:26
14000	13459	VICPDTGEN	1988-10-03 00:00:00	\N	2000-07-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-19 10:44:25	2014-09-19 10:50:20
14000	13461	CONSGENE	2008-03-21 00:00:00	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-19 10:50:27	2015-01-19 14:19:39
14056	13505	MAIRE	1985-01-06 00:00:00	\N	2017-11-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 12:58:10	2017-11-30 15:07:52
14057	13506	CONSGENE	\N	2011	2015-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 12:58:45	2014-09-28 12:59:16
14224	13557	MAIRE	\N	2008	2016-08-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-09-28 17:59:11	2017-02-09 16:13:07
14226	13559	VICPDTINTCOM	\N	2008	2014-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 18:00:02	2014-12-04 15:57:46
14236	13562	MEMBREINTCOM	\N	2014	2020-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-09-28 18:03:02	2014-09-28 18:03:39
14049	13563	CONSMUNI	1977-03-30 00:00:00	1977	1989-03-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 18:04:24	2014-09-30 11:21:37
13935	13641	PREMADJOINT	\N	2014	2017-05-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-30 10:51:30	2014-09-30 10:51:43
12934	13118	PDTGEN	2004-01-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2014-01-02 11:08:30	2014-01-02 11:09:21
12938	13121	DEPUTE	2000-03-27 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-01-02 11:13:00	2016-12-13 11:07:51
50781	50074	DEPUTE	2012-06-26 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	2017-08-18 12:18:14	\N
12936	13120	PDTGEN	2004-01-01 00:00:00	\N	2014-01-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-01-02 11:10:21	2014-09-29 10:22:21
12940	13122	CONSMUNI	1997-01-01 00:00:00	\N	2004-01-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-01-02 11:14:02	\N
12941	13123	PREPDTINTCOM	1993-01-01 00:00:00	\N	2014-06-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2014-01-02 11:17:33	2014-10-01 09:24:55
12942	13124	CONSMUNI	2008-03-09 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2014-01-13 10:13:01	\N
10960	13137	CONSPARI	2014-04-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2014-04-07 09:57:57	2014-04-07 09:58:40
11783	13169	CONSMUNI	2014-04-07 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2014-04-16 17:13:52	2014-04-16 17:14:03
11194	13172	CONSMUNI	2014-04-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2014-04-17 11:37:57	2014-04-17 11:38:11
6588	13171	CONSMUNI	2014-04-01 00:00:00	\N	2020-05-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-04-17 11:17:30	2014-04-17 11:17:45
13765	13181	MAIRE	2001-03-25 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2014-05-05 10:32:23	2014-05-05 10:33:27
13766	13182	CONSREG	2014-05-05 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-05-05 10:34:45	\N
13776	13197	CONSMUNI	\N	1977	\N	2001	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-05-28 18:06:34	2014-05-28 18:08:03
13781	13200	MAIRE	2006-01-20 00:00:00	\N	2010-04-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-06-25 15:55:03	2014-06-25 15:56:25
13781	13201	MAIREADJOINT	\N	2001	2006-01-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-06-25 16:02:01	2014-06-25 16:03:44
13781	13202	MAIREADJOINT	2010-04-14 00:00:00	\N	\N	2012	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-06-25 16:03:49	2014-06-25 16:04:24
13781	13203	CONSMUNI	\N	2013	\N	2014	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-06-25 16:04:27	2014-06-25 16:05:04
13782	13204	PDTREG	2010-03-26 00:00:00	\N	2015-12-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-06-25 16:05:28	2015-12-15 14:55:39
13783	13205	DEPUTE	2007-06-17 00:00:00	\N	2010-11-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-06-25 16:06:40	2016-12-13 11:45:16
13784	13206	PDTINTCOM	2006-01-25 00:00:00	\N	\N	2014	ANCIEN	\N	de la communauté de communes du Sud	\N	NON	2014-06-25 16:08:17	2014-10-22 17:53:57
13807	13235	DEPUTE	2004-05-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-16 15:31:44	2017-06-15 10:51:25
13805	13232	MAIRE	\N	2001	2015-05-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-16 15:13:58	2015-05-18 16:27:54
13819	13247	MAIRE	1983-03-14 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-17 11:24:05	2014-09-17 11:25:33
13820	13248	CONSGENE	\N	2005	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-17 11:25:47	2014-09-17 11:28:57
13820	13249	VICPDTGEN	1994-03-28 00:00:00	\N	2004-03-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-17 11:26:52	2014-09-17 11:28:10
13820	13250	CONSGENE	\N	1982	\N	1993	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-17 11:28:20	2014-09-17 11:28:57
13821	13251	PDTINTCOM	\N	2013	\N	\N	ACTIF	\N	\N	\N	\N	2014-09-17 11:29:19	2014-09-17 11:31:55
13822	13252	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-17 11:32:11	2017-06-15 10:51:27
13825	13255	VICPDTGEN	2011-03-01 00:00:00	2011	2015-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-17 11:36:29	2014-09-29 17:18:14
13824	13254	MAIRE	2014-03-15 00:00:00	2014	2017-07-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-17 11:35:11	2014-09-28 19:09:41
13826	13256	MAIRE	2008-03-16 00:00:00	\N	2017-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-17 11:39:11	2017-11-13 11:34:56
13843	13272	MAIRE	2001-03-18 00:00:00	\N	2017-09-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-17 17:06:10	2017-11-15 09:36:59
13845	13274	VICPDTINTCOM	2014-04-18 00:00:00	\N	2014-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2014-09-17 17:09:01	2015-12-17 14:29:18
13875	13306	MAIRE	\N	1992	2017-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 10:06:40	2017-10-04 17:01:48
13878	13310	CONSGENE	\N	1992	2014-10-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-09-18 10:14:03	2014-11-28 18:57:42
13903	13337	MAIRE	\N	2013	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-18 11:27:46	2014-09-18 11:31:24
13904	13338	CONSGENE	\N	2008	\N	2010	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 11:32:16	2014-09-18 11:40:49
13894	13330	PDTINTCOM	\N	2013	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2014-09-18 11:17:43	2017-10-04 17:06:59
13921	13360	MAIRE	1995-06-01 00:00:00	\N	2017-10-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2014-09-18 11:54:14	2017-11-16 14:55:29
13913	13348	VICPDTINTCOM	\N	2013	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-18 11:45:06	2014-09-18 11:47:26
13927	13367	MAIRE	2014-03-28 00:00:00	\N	2017-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-09-18 11:57:48	2017-11-15 17:53:46
13933	13375	MAIRE	\N	1995	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2014-09-18 12:00:59	2014-09-18 12:02:21
13936	13378	CONSGENE	\N	2008	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2014-09-18 12:02:30	2014-09-18 12:06:45
13942	13387	MAIRE	\N	1989	\N	\N	ACTIF	\N	Sarlat-la-Canédat	\N	NON	2014-09-18 12:08:55	2014-09-18 12:10:15
13944	13389	PREMADJOINT	2014-03-17 00:00:00	\N	2014-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-09-18 12:11:54	2014-11-20 17:47:52
13946	13391	PREVICPDTGEN	\N	2013	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2014-09-18 12:12:57	2014-09-28 19:09:22
13948	13393	CONSGENE	2001-04-01 00:00:00	\N	2008-03-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-09-18 12:16:03	2014-11-18 18:13:22
13971	13425	CONSGENE	\N	1987	\N	2002	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 15:02:53	2014-09-18 15:40:03
14023	13487	MAIRE	2008-03-15 00:00:00	\N	2017-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-22 15:10:24	2017-10-05 14:07:48
14024	13488	PDTINTCOM	2014-04-25 00:00:00	\N	2017-11-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2014-09-22 15:11:41	2018-01-18 15:28:14
14029	13493	CONSMUNI	\N	2004	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-26 17:32:57	2014-09-26 17:34:45
14032	13496	VICPDTGEN	\N	2014	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-26 17:38:37	2014-09-26 17:39:42
14031	13495	VICPDTGEN	\N	2004	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-26 17:35:07	2014-09-26 17:36:10
14033	13497	MAIREADJOINT	\N	2014	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-26 17:44:34	2014-09-26 17:45:28
14034	13498	MAIREADJOINT	\N	2001	2017-10-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-26 17:50:22	2017-11-29 09:51:36
14035	13499	CONSGENE	2014-09-26 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-26 17:53:07	\N
14053	13504	CONSGENE	1980-04-01 00:00:00	\N	1996-02-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 12:55:04	2014-09-30 11:23:24
14225	13558	MAIREADJOINT	2001-03-19 00:00:00	2001	2015-07-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 17:59:34	2015-07-28 15:19:50
14241	13564	VICPDTINTCOM	\N	2014	2015-07-27 00:00:00	\N	ANCIEN	de Lamballe communauté	de Lamballe communauté	\N	\N	2014-09-28 18:04:38	2015-07-28 15:20:21
14246	13569	CONSMUNI	\N	2008	\N	2013	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 18:13:58	2014-09-28 18:15:44
14246	13570	MAIRE	\N	2014	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-28 18:14:12	2014-09-28 18:15:44
14247	13571	CONSREG	\N	2014	\N	2014	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-09-28 18:16:03	2015-01-14 16:29:29
14253	13574	MAIRE	2008-03-17 00:00:00	\N	2014-03-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 18:27:06	2014-10-02 10:39:12
14265	13581	CONSREG	1992-03-01 00:00:00	\N	2004-03-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 18:44:28	2014-10-01 13:37:27
14255	13576	CONSREG	2011-09-28 00:00:00	2011	2014-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 18:27:56	2014-10-23 15:52:34
14260	13579	CONSGENE	2008-03-17 00:00:00	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 18:39:15	2014-09-28 18:41:32
14286	13587	PDTINTCOM	2014-03-17 00:00:00	\N	2017-09-28 00:00:00	\N	ANCIEN	de la Communauté d'agglomération Vichy Val d'Allier	de la Communauté d'agglomération Vichy Val d'Allier	\N	NON	2014-09-28 19:02:39	2017-11-27 20:09:36
14276	13584	MAIRE	1989-03-20 00:00:00	\N	2017-09-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 18:48:13	2017-11-27 20:08:39
14283	13586	DEPUTE	1993-03-28 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2014-09-28 18:59:21	2014-09-28 19:00:29
14311	13601	PDTINTCOM	\N	2005	2017-09-18 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2014-09-28 19:34:38	2017-09-26 14:28:34
14289	13589	CONSREG	2004-03-17 00:00:00	\N	2014-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2014-09-28 19:04:05	2014-12-01 23:23:42
14329	13615	VICPDTINTCOM	\N	\N	2017-09-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2014-09-29 10:49:41	2017-11-08 16:27:44
6176	13117	CONSMUNI	\N	2008	\N	\N	ACTIF	\N	\N	\N	NON	2013-11-04 16:58:30	\N
13770	13183	CONSMUNI	\N	1983	1994-03-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-05-09 11:30:17	2014-05-09 11:33:37
11793	13138	CONSMUNI	2014-04-04 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2014-04-07 10:12:28	2014-04-07 10:12:51
12196	13140	CONSMUNI	2014-04-07 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2014-04-07 11:19:30	2014-04-07 11:19:44
12120	13141	CONSMUNI	2014-04-07 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2014-04-07 11:20:47	2014-04-07 11:21:05
11605	13142	CONSMUNI	2014-04-07 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2014-04-07 11:25:19	2014-04-07 11:25:23
11528	13145	MAIRE	2014-04-01 00:00:00	\N	2017-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-04-07 11:31:15	2017-10-04 16:00:24
11755	13683	CONSINTCOM	2014-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	2014-10-10 16:00:21	2014-10-10 16:00:59
13756	13175	PREMADJOINT	2014-04-01 00:00:00	\N	2017-10-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2014-04-29 11:15:14	2017-11-06 16:25:55
6581	13148	CONSMUNI	2014-04-01 00:00:00	\N	2014-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2014-04-07 11:35:25	2014-09-23 17:44:20
13751	13150	MAIRE	2014-04-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2014-04-07 11:58:21	2014-04-07 11:58:45
11720	13151	CONSMUNI	2014-04-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2014-04-07 14:45:22	2014-04-07 14:45:32
12948	13152	CONSMUNI	2014-04-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2014-04-07 16:19:55	2014-04-07 16:20:02
11523	13153	CONSMUNI	2014-04-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2014-04-07 16:31:18	2014-04-07 16:31:26
11333	13155	CONSMUNI	2014-04-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2014-04-08 14:36:03	2014-04-08 14:36:11
13757	13177	PREPDTINTCOM	2014-04-29 00:00:00	\N	2016-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2014-04-29 11:17:07	2017-04-21 14:45:14
13770	13184	MAIRE	1994-03-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2014-05-09 11:32:43	2014-05-09 11:33:37
13772	13185	VICPDTREG	\N	2010	2015-12-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-05-09 11:39:55	2015-12-15 15:03:27
13778	13198	MAIRE	2014-04-01 00:00:00	\N	2017-10-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-06-10 14:51:16	2017-11-06 16:02:59
13804	13233	MAIREADJOINT	\N	2008	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2014-09-16 15:15:57	2017-10-09 11:55:48
13803	13228	MAIRE	2014-01-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2014-09-16 14:47:10	2014-09-16 14:49:08
13806	13234	DELINTCOM	2014-03-15 00:00:00	\N	2020-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2014-09-16 15:17:43	2017-10-09 11:57:36
13804	13231	CONSMUNI	\N	2001	\N	2007	ANCIEN	\N	\N	\N	NON	2014-09-16 15:11:45	2014-09-16 15:15:52
13976	13430	MAIRE	\N	1983	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-18 15:34:27	2014-09-18 15:35:47
13978	13433	PDTINTCOM	\N	2013	\N	\N	ACTIF	\N	\N	\N	\N	2014-09-18 15:36:50	2014-09-18 15:38:20
13971	13434	PDTGEN	\N	2003	\N	2004	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-18 15:39:19	2014-09-18 15:40:03
13971	13435	CONSGENE	\N	2005	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-18 15:40:08	2014-09-18 15:40:26
13980	13437	MAIRE	\N	1992	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-18 15:46:58	2014-09-18 15:48:49
13982	13439	VICPDTGEN	\N	1994	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-18 15:48:58	2014-09-18 15:51:00
13983	13440	PDTINTCOM	\N	2006	\N	\N	ACTIF	\N	\N	\N	\N	2014-09-18 15:51:23	2014-09-18 15:59:02
14009	13471	MAIRE	2001-03-24 00:00:00	\N	2018-05-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-22 10:54:57	2018-06-04 11:44:26
14010	13473	DEPUTE	1988-06-12 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-22 10:56:17	2016-12-12 16:27:22
14011	13474	CONSGENE	1976-03-15 00:00:00	\N	2001-03-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-22 10:56:56	2014-09-22 10:57:35
14012	13475	PDTINTCOM	2014-03-17 00:00:00	\N	2018-05-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-22 10:58:25	2018-06-04 11:44:26
14014	13478	CONSGENE	\N	2011	2014-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-09-22 11:05:59	2014-10-24 11:13:27
14013	13477	MAIRE	2014-03-17 00:00:00	\N	2017-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-22 11:05:05	2017-11-08 17:47:52
14015	13479	CONSREG	\N	2010	2014-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-09-22 11:08:01	2014-10-24 11:13:40
14016	13480	MAIRE	2014-03-30 00:00:00	\N	2017-09-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-22 11:15:49	2017-11-03 14:37:39
14025	13489	MAIRE	2014-03-17 00:00:00	\N	2017-04-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-22 15:37:30	2017-08-10 17:08:12
14018	13482	VICPDTGEN	2008-04-01 00:00:00	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-22 11:18:47	2014-09-30 15:42:20
14026	13490	VICPDTINTCOM	2014-03-17 00:00:00	\N	2015-12-31 00:00:00	\N	ANCIEN	de la communauté d'agglomération Rouen-Elbeuf-Austreberthe	de la communauté d'agglomération Rouen-Elbeuf-Austreberthe	\N	\N	2014-09-22 15:37:53	2016-07-08 11:09:49
14027	13491	MAIREADJOINT	2008-03-17 00:00:00	\N	2017-10-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-22 15:43:23	2017-11-28 10:17:19
14028	13492	MEMBREINTCOM	2014-03-17 00:00:00	\N	\N	\N	ACTIF	de la Communauté d¿agglomération havraise	de la Communauté d¿agglomération havraise	\N	\N	2014-09-22 15:44:27	2014-09-22 15:45:14
14070	13507	PDTINTCOM	\N	2001	\N	\N	ACTIF	\N	\N	\N	\N	2014-09-28 15:27:54	2014-09-28 15:32:04
14076	13514	MAIREADJOINT	\N	2001	\N	2005	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 15:36:29	2014-09-28 15:37:17
14076	13515	CONSMUNI	\N	2006	2008-03-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 15:37:44	2017-03-23 10:46:12
14124	13528	CONSGENE	2003-07-06 00:00:00	\N	2015-01-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 17:08:33	2015-01-14 10:35:02
14128	13529	CONSMUNI	2014-04-01 00:00:00	\N	2020-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 17:12:37	2014-09-28 17:12:59
14132	13530	MAIRE	\N	2008	2017-10-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 17:12:59	2017-11-10 15:28:13
14133	13531	MAIRE	2006-07-01 00:00:00	2006	2017-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 17:13:41	2017-11-13 18:53:57
14134	13532	VICPDTGEN	\N	2014	2015-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 17:14:10	2014-09-28 17:14:37
14142	13533	MAIRE	2001-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-28 17:17:15	2014-09-28 17:18:03
14143	13534	CONSGENE	2008-04-01 00:00:00	\N	2014-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-09-28 17:18:16	2014-11-18 10:11:11
14144	13535	PDTINTCOM	2014-04-30 00:00:00	\N	\N	\N	ACTIF	\N	de la Communauté d'agglomération du Bassin de Thau	\N	NON	2014-09-28 17:20:24	2014-09-28 18:20:54
14148	13536	VICPDTINTCOM	2014-04-24 00:00:00	2014	2017-09-24 00:00:00	\N	ANCIEN	de l'agglomération du Pays de Dreux	de l'agglomération du Pays de Dreux	\N	\N	2014-09-28 17:23:25	2018-01-23 19:20:53
14160	13540	MAIRE	1983-03-14 00:00:00	\N	2001-03-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 17:27:53	2014-09-28 17:30:59
14151	13539	CONSMUNI	1977-03-13 00:00:00	\N	1983-03-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 17:27:03	2014-09-28 17:27:45
14160	13541	MAIRE	2008-04-01 00:00:00	\N	2017-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 17:29:01	2017-10-03 11:50:17
14161	13542	MAIRE	2001-03-20 00:00:00	2001	2017-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 17:30:30	2018-01-23 19:20:09
14187	13550	MAIRE	\N	2014	2016-01-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 17:43:49	2016-06-03 10:18:50
14189	13551	PDTINTCOM	\N	2014	2014-10-01 00:00:00	\N	ANCIEN	de la communauté de communes du Pays d'Ornans	de la communauté de communes du Pays d'Ornans	\N	\N	2014-09-28 17:46:23	2014-10-09 14:22:36
14198	13554	CONSGENE	\N	2014	2014-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 17:48:40	2014-10-09 14:17:15
14208	13556	MAIRE	\N	2011	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-28 17:52:23	2014-09-29 16:10:05
14248	13572	CONSREG	\N	2004	\N	2010	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 18:17:33	2014-09-30 11:59:01
14249	13573	CONSGENE	2011-03-01 00:00:00	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 18:18:34	2014-09-28 18:19:39
14315	13609	PDTGEN	2004-04-02 00:00:00	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-09-28 21:16:29	2014-09-28 21:27:52
14267	13583	CONSMUNI	\N	1989	\N	2014	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-09-28 18:44:40	2014-10-02 11:02:20
14315	13608	CONSGENE	\N	1973	2004-03-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-09-28 21:14:57	2014-09-28 21:16:23
14316	13610	MAIRE	1983-03-15 00:00:00	1983	2004-03-15 00:00:00	2004	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-09-28 21:17:27	2014-09-30 16:12:02
12407	13168	CONSMUNI	2014-04-01 00:00:00	\N	2022-04-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-04-09 22:08:10	2014-04-09 22:08:18
11344	13199	MAIRE	2014-04-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-06-11 16:21:08	2014-06-11 16:21:40
13866	13296	MAIREADJOINT	2014-03-19 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-17 17:56:19	2014-09-17 17:57:03
13869	13300	MAIRE	2014-03-19 00:00:00	\N	2017-10-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-17 18:07:13	2018-01-12 09:56:07
13870	13301	VICPDTREG	2010-03-21 00:00:00	\N	2014-11-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-17 18:07:50	2014-11-03 14:16:46
13871	13302	MAIRE	1999-05-31 00:00:00	\N	2015-09-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-17 18:10:58	2015-09-25 15:21:08
13873	13304	CONSGENE	\N	2001	2015-01-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-17 18:12:01	2015-01-14 12:12:46
13874	13305	VICPDTINTCOM	\N	2002	2014-12-31 00:00:00	\N	ANCIEN	du Grand Lyon	du Grand Lyon	\N	\N	2014-09-17 18:15:12	2016-07-08 11:05:45
13981	13438	MAIRE	2001-03-15 00:00:00	\N	2017-10-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-09-18 15:47:32	2017-11-07 16:17:54
13977	13432	CONSGENE	\N	1979	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-18 15:35:22	2014-09-18 15:41:26
13979	13436	VICPDTINTCOM	2014-03-17 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-09-18 15:41:57	2014-09-18 15:43:09
14039	13500	PDTGEN	2011-03-31 00:00:00	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 12:11:19	2014-09-28 21:26:49
13985	13442	CONSREG	2004-03-01 00:00:00	2004	2010-03-01 00:00:00	2010	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-09-18 15:52:19	2015-06-24 10:24:37
13986	13443	CONSREG	2010-03-21 00:00:00	\N	2012-08-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-09-18 15:54:57	2014-09-29 11:42:46
14071	13508	MAIRE	2014-03-17 00:00:00	\N	2017-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 15:28:48	2017-11-10 18:13:39
14109	13526	MAIRE	2008-03-17 00:00:00	\N	2017-10-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 17:04:53	2017-11-09 11:09:35
14074	13511	CONSGENE	\N	2001	2015-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 15:30:18	2014-09-30 10:45:41
14075	13512	VICPDTINTCOM	2014-03-17 00:00:00	\N	2017-09-30 00:00:00	\N	ANCIEN	de la communauté de communes du Sud Territoire	de la communauté de communes du Sud Territoire	\N	\N	2014-09-28 15:33:43	2017-11-10 18:14:08
14113	13527	VICPDTGEN	\N	1994	2014-10-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-09-28 17:06:37	2014-10-23 12:07:35
14150	13538	CONSMUNI	2001-03-19 00:00:00	\N	2017-10-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 17:26:45	2017-11-22 19:46:27
14174	13546	MAIRE	2014-03-17 00:00:00	\N	2015-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 17:34:23	2015-07-02 14:27:00
14180	13549	VICPDTINTCOM	2014-03-17 00:00:00	\N	2015-12-31 00:00:00	\N	ANCIEN	de la communauté urbaine Toulouse Métropole	de la communauté urbaine Toulouse Métropole	\N	\N	2014-09-28 17:36:31	2016-07-08 11:14:02
14227	13560	MAIRE	\N	1995	2017-10-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 18:00:30	2017-11-08 17:38:32
14242	13565	MAIRE	2001-03-19 00:00:00	2001	2017-09-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 18:05:11	2018-02-08 15:50:46
14243	13566	CONSGENE	2011-03-14 00:00:00	\N	2015-01-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 18:06:10	2015-01-13 12:06:02
14244	13567	MAIREARR	2014-03-30 00:00:00	\N	2017-10-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 18:12:36	2017-11-09 15:33:41
14245	13568	CONSREG	2010-03-01 00:00:00	2010	\N	2014	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-09-28 18:13:18	2015-01-14 16:23:16
14301	13591	MAIREADJOINT	1995-06-01 00:00:00	\N	2008-03-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 19:25:42	2014-09-28 19:27:18
14295	13590	VICPDTINTCOM	2014-09-28 00:00:00	\N	2017-07-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 19:10:00	2014-09-28 19:11:11
14301	13592	MAIRE	2008-04-01 00:00:00	\N	2017-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 19:27:19	2017-11-09 10:28:28
14303	13593	CONSGENE	2008-03-16 00:00:00	\N	2011-03-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 19:28:14	2014-09-28 19:29:55
14303	13594	VICPDTGEN	2011-03-15 00:00:00	\N	2013-07-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 19:29:56	2014-09-28 19:30:20
14306	13595	DEPUTE	2013-07-01 00:00:00	\N	2014-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-09-28 19:30:40	2014-09-28 19:31:31
14307	13596	VICPDTINTCOM	\N	2001	2008-03-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-09-28 19:32:01	2014-09-28 19:33:15
14307	13599	PDTINTCOM	2008-04-01 00:00:00	\N	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2014-09-28 19:33:17	2017-11-09 10:29:10
13986	13602	VICPDTREG	2012-09-01 00:00:00	\N	2015-01-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-09-28 19:39:10	2015-01-14 10:36:45
14313	13603	CONSREG	2010-03-21 00:00:00	\N	2015-02-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 19:57:58	2015-02-11 15:51:11
14314	13604	CONSGENE	1998-03-22 00:00:00	\N	2001-02-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 19:58:42	2014-09-28 19:59:35
14314	13605	VICPDTGEN	2001-03-01 00:00:00	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 19:59:37	2014-09-28 20:00:10
13952	13606	CONSGENE	1992-03-29 00:00:00	\N	2007-03-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-28 20:03:54	2014-09-28 20:05:00
14025	13616	CONSMUNI	1995-03-01 00:00:00	\N	1998-03-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-29 10:55:17	2014-09-29 10:55:40
13856	13632	MEMBREINTCOM	2014-04-01 00:00:00	\N	2015-12-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-09-29 17:49:14	2016-07-07 13:28:20
14334	13621	MAIREADJOINT	2008-03-09 00:00:00	\N	2014-03-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-29 11:44:09	2014-09-29 11:45:06
14351	13645	CONSGENE	\N	1998	\N	2011	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-30 11:22:43	2014-09-30 11:23:54
13950	13647	PREMADJOINT	\N	2014	2014-12-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-30 11:26:16	2014-12-29 15:40:09
14350	13643	PDTINTCOM	\N	2008	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2014-09-30 11:21:34	2017-11-09 10:23:05
14355	13651	CONSINTCOM	\N	2003	2015-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2014-09-30 11:56:58	2016-07-08 11:08:35
14242	13652	CONSMUNI	1995-03-20 00:00:00	\N	2001-03-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-30 14:33:14	2014-09-30 14:34:05
14356	13653	VICPDTINTCOM	2001-03-01 00:00:00	\N	2015-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2014-09-30 14:34:17	2016-07-08 10:35:42
14358	13656	CONSMUNI	\N	2001	2014-03-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-30 14:38:38	2014-09-30 14:39:11
14357	13655	DELINTCOM	\N	2008	2015-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2014-09-30 14:34:53	2016-07-08 10:49:28
14359	13657	MAIRE	1995-03-01 00:00:00	\N	2014-03-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-30 15:42:51	2014-09-30 15:44:35
14360	13658	PREMADJOINT	2014-03-30 00:00:00	2014	2017-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-30 16:06:39	2018-05-30 09:43:35
14361	13659	MAIREADJOINT	\N	1971	\N	1983	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-30 16:09:21	2014-09-30 16:10:28
14362	13660	CONSREG	\N	1986	\N	1988	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-30 16:11:40	2014-09-30 16:12:21
14365	13663	PREVICPDTREG	\N	2010	2014-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-09-30 16:15:08	2014-10-24 11:58:19
14364	13662	DEUXADJOINT	2014-03-30 00:00:00	2014	2017-09-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-30 16:14:21	2018-05-30 09:55:22
14366	13664	CONSINTCOM	\N	2014	2015-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2014-09-30 16:15:58	2016-07-08 11:09:32
14364	13665	CONSMUNI	\N	2008	\N	2013	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-30 16:17:21	2014-09-30 16:19:25
14368	13668	CONSMUNI	1995-04-17 00:00:00	\N	2008-03-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-30 16:18:59	2014-09-30 16:20:22
14366	13667	VICPDTINTCOM	\N	2008	\N	2013	ANCIEN	\N	\N	\N	\N	2014-09-30 16:18:03	2014-09-30 16:18:53
14077	13669	CONSGENE	1982-03-01 00:00:00	\N	2010-11-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-09-30 16:24:03	2014-09-30 16:24:27
14371	13670	MAIRE	\N	1995	\N	2008	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-09-30 16:52:20	2014-09-30 16:53:29
14372	13671	PDTINTCOM	2014-09-30 00:00:00	\N	2017-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2014-09-30 17:04:28	2017-11-09 11:10:09
14373	13672	PREPDTINTCOM	\N	\N	2017-01-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2014-09-30 18:01:33	2017-09-20 16:50:51
14374	13673	MEMBREINTCOM	2014-04-15 00:00:00	\N	2015-04-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2014-10-01 10:00:35	2015-06-16 17:37:34
14378	13679	CONSMUNI	2014-03-17 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2014-10-02 10:39:17	2014-10-02 10:47:08
14379	13680	CONSMUNI	\N	2008	\N	2008	ANCIEN	\N	Nouvelle fonction	\N	NON	2014-10-02 10:56:49	2014-10-03 11:49:08
14380	13681	CONSREG	1992-03-23 00:00:00	\N	1998-03-13 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2014-10-07 16:26:20	2017-10-03 11:53:23
11674	13682	CONSINTCOM	2014-03-17 00:00:00	\N	2020-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2014-10-09 12:18:18	2014-10-09 12:18:50
14383	13686	CONSMUNI	2014-04-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	2014-10-23 10:21:41	2014-10-23 10:22:03
15175	13754	CONSDPT	2015-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2015-03-31 16:58:16	2015-03-31 16:59:38
15176	13755	CONSDPT	2015-03-30 00:00:00	\N	2021-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2015-03-31 17:01:37	2015-03-31 17:02:42
15178	13757	CONSDPT	2015-03-30 00:00:00	\N	2015-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-03-31 17:04:14	2015-04-03 11:09:21
15180	13759	CONSDPT	2015-03-30 00:00:00	\N	2015-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-03-31 17:07:12	2015-04-03 10:31:58
15181	13760	CONSDPT	2015-03-30 00:00:00	\N	2015-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-03-31 17:09:39	2015-04-03 10:34:05
15280	13881	CONSREG	2016-01-01 00:00:00	\N	2021-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2016-01-12 09:53:01	2016-01-12 09:54:23
15186	13765	CONSDPT	2015-03-30 00:00:00	\N	2015-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-03-31 17:46:01	2015-04-03 11:08:12
15172	13780	PDTDPT	2015-04-03 00:00:00	\N	2016-01-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-04-03 11:07:08	2017-09-27 16:52:38
15186	13781	PDTDPT	2015-04-03 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2015-04-03 11:08:14	2015-04-03 11:29:48
15178	13782	PDTDPT	2015-04-03 00:00:00	\N	2017-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-04-03 11:09:24	2017-12-04 18:30:29
15279	13880	MAIRE	2001-03-18 00:00:00	\N	2016-01-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2016-01-12 09:49:41	2016-02-19 14:37:34
12458	13887	MAIRE	2015-07-05 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2016-04-01 11:06:47	2016-04-01 11:07:05
15342	13938	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2016-12-07 17:32:14	2017-06-15 10:48:23
6652	13936	DEPUTE	1973-04-02 00:00:00	1986	1978-04-01 00:00:00	1988	ANCIEN	\N	\N	\N	NON	2016-12-07 17:02:50	2017-06-15 10:48:23
15340	13937	DEPUTE	\N	\N	\N	\N	ANCIEN	\N	\N	\N	NON	2016-12-07 17:05:42	\N
15343	13939	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2016-12-07 17:32:15	2017-06-15 10:48:23
15344	13940	DEPUTE	1969-07-23 00:00:00	1969	1973-04-01 00:00:00	1973	ANCIEN	\N	\N	\N	NON	2016-12-07 17:35:49	2017-06-15 10:48:41
15345	13941	DEPUTE	1973-04-02 00:00:00	1973	1977-05-01 00:00:00	1978	ANCIEN	\N	\N	\N	NON	2016-12-07 17:35:52	2017-06-15 10:48:41
15346	13942	DEPUTE	1978-04-03 00:00:00	1978	1978-05-06 00:00:00	1980	ANCIEN	\N	\N	\N	NON	2016-12-07 17:35:54	2017-06-15 10:48:41
15347	13943	DEPUTE	1986-03-13 00:00:00	1986	1988-05-14 00:00:00	1988	ANCIEN	\N	\N	\N	NON	2016-12-07 17:35:56	2016-12-14 10:39:40
15348	13944	DEPUTE	\N	\N	\N	\N	ANCIEN	\N	\N	\N	NON	2016-12-07 17:36:00	\N
15349	13945	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2016-12-07 17:45:09	2017-06-15 10:48:41
15350	13946	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	2016-12-07 17:45:10	\N
15351	13947	DEPUTE	1978-04-03 00:00:00	1978	1981-05-22 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2016-12-07 17:57:56	2017-06-15 10:48:40
15352	13948	DEPUTE	\N	\N	\N	\N	ACTIF	\N	\N	\N	NON	2016-12-07 17:57:58	\N
15353	13949	DEPUTE	1981-07-02 00:00:00	1981	1986-04-01 00:00:00	1986	ANCIEN	\N	\N	\N	NON	2016-12-07 18:08:44	2017-06-15 10:48:33
15354	13950	DEPUTE	1986-04-02 00:00:00	1986	1988-05-14 00:00:00	1988	ANCIEN	\N	\N	\N	NON	2016-12-07 18:08:46	2017-06-15 10:48:33
15355	13951	DEPUTE	1988-06-05 00:00:00	1988	1993-04-01 00:00:00	1993	ANCIEN	\N	\N	\N	NON	2016-12-07 18:09:16	2016-12-08 15:15:22
15356	13952	DEPUTE	\N	\N	\N	\N	ANCIEN	\N	\N	\N	NON	2016-12-07 18:09:27	\N
15357	13953	DEPUTE	1993-04-02 00:00:00	1993	1993-05-01 00:00:00	1993	ANCIEN	\N	\N	\N	NON	2016-12-07 18:11:12	2017-06-15 10:48:33
15404	14006	DEPUTE	1988-06-05 00:00:00	1988	\N	\N	ANCIEN	\N	\N	\N	NON	2016-12-09 08:44:04	\N
15405	14007	DEPUTE	1993-04-02 00:00:00	1993	\N	\N	ANCIEN	\N	\N	\N	NON	2016-12-09 08:44:55	\N
15406	14008	DEPUTE	1978-04-03 00:00:00	1978	1981-05-22 00:00:00	1981	ANCIEN	\N	\N	\N	NON	2016-12-09 10:25:46	2017-06-15 10:49:58
15407	14009	DEPUTE	1981-06-14 00:00:00	1981	1986-04-01 00:00:00	1986	ANCIEN	\N	\N	\N	NON	2016-12-09 10:27:01	2016-12-09 10:33:47
15408	14010	DEPUTE	1986-04-02 00:00:00	1986	1988-05-14 00:00:00	1988	ANCIEN	\N	\N	\N	NON	2016-12-09 10:27:32	2017-06-15 10:49:58
15409	14011	DEPUTE	1988-06-12 00:00:00	1988	1993-04-01 00:00:00	1993	ANCIEN	\N	\N	\N	NON	2016-12-09 10:29:41	2016-12-09 10:31:49
43686	49339	SECAN	1993-04-07 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:16	\N
43714	49340	DEPUTE	1988-06-06 00:00:00	\N	1988-06-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:17	\N
43714	49341	VICPDTAN	1988-06-24 00:00:00	\N	1992-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:17	\N
43714	49342	DEPUTE	1992-04-02 00:00:00	\N	1992-11-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:17	\N
43713	49343	DEPUTE	1986-04-02 00:00:00	\N	1986-04-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:17	\N
15415	14020	DEPUTE	1993-04-02 00:00:00	1993	1997-04-21 00:00:00	1997	ANCIEN	\N	\N	\N	NON	2016-12-09 11:21:01	2017-06-15 10:49:41
15417	14021	DEPUTE	1993-04-02 00:00:00	1993	1997-04-21 00:00:00	1997	ANCIEN	\N	\N	\N	NON	2016-12-09 11:44:05	2017-06-15 10:49:44
15418	14022	DEPUTE	2012-06-20 00:00:00	2012	2017-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2016-12-09 11:51:53	2017-06-19 09:37:29
43713	49344	VICPDTAN	1986-04-04 00:00:00	\N	1988-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:17	\N
15420	14024	DEPUTE	1986-04-02 00:00:00	1986	1988-05-14 00:00:00	1988	ANCIEN	\N	\N	\N	NON	2016-12-09 14:12:48	2017-06-15 10:49:21
15421	14025	DEPUTE	1988-06-12 00:00:00	1988	1993-04-01 00:00:00	1993	ANCIEN	\N	\N	\N	NON	2016-12-09 14:13:16	2016-12-09 14:14:26
15422	14026	DEPUTE	1997-06-01 00:00:00	1997	2002-06-18 00:00:00	2002	ANCIEN	\N	\N	\N	NON	2016-12-09 14:13:44	2017-06-15 10:49:21
15423	14027	DEPUTE	1981-06-14 00:00:00	1981	1985-12-15 00:00:00	1985	ANCIEN	\N	\N	\N	NON	2016-12-09 14:21:52	2016-12-12 14:19:12
15424	14028	DEPUTE	1986-03-16 00:00:00	1986	1988-05-14 00:00:00	1988	ANCIEN	\N	\N	\N	NON	2016-12-09 14:22:30	2016-12-09 14:25:57
15425	14029	DEPUTE	1988-06-05 00:00:00	1988	1992-05-04 00:00:00	1992	ANCIEN	\N	\N	\N	NON	2016-12-09 14:22:56	2016-12-09 14:26:13
15426	14030	DEPUTE	1993-03-28 00:00:00	1993	1997-04-21 00:00:00	1997	ANCIEN	\N	\N	\N	NON	2016-12-09 14:23:21	2016-12-09 14:26:47
15427	14031	DEPUTE	1997-06-01 00:00:00	1997	1997-07-04 00:00:00	1997	ANCIEN	\N	\N	\N	NON	2016-12-09 14:23:50	2017-06-15 10:50:03
15428	14032	DEPUTE	1988-06-12 00:00:00	1988	1993-04-01 00:00:00	1993	ANCIEN	\N	\N	\N	NON	2016-12-09 14:30:21	2016-12-12 14:17:45
15429	14033	DEPUTE	1986-04-02 00:00:00	1986	1988-05-14 00:00:00	1988	ANCIEN	\N	\N	\N	NON	2016-12-09 14:34:00	2017-06-15 10:50:03
15430	14034	DEPUTE	1988-06-12 00:00:00	1988	1993-04-01 00:00:00	1993	ANCIEN	\N	\N	\N	NON	2016-12-09 14:34:27	2017-01-19 16:52:44
43713	49345	DEPUTE	1988-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:17	\N
15433	14037	DEPUTE	1988-06-12 00:00:00	1988	1993-04-01 00:00:00	1993	ANCIEN	\N	\N	\N	NON	2016-12-09 15:51:53	\N
15513	14123	DEPUTE	2012-06-20 00:00:00	2012	2017-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2016-12-14 10:32:43	2017-06-19 09:37:23
15434	14039	SECAN	1994-04-02 00:00:00	1993	1997-04-21 00:00:00	1997	ANCIEN	\N	\N	\N	NON	2016-12-09 15:52:45	2017-06-29 09:19:37
15514	14124	DEPUTE	1988-06-12 00:00:00	1988	1993-04-01 00:00:00	1993	ANCIEN	\N	\N	\N	NON	2016-12-14 10:34:26	2016-12-14 10:34:43
15435	14041	DEPUTE	1997-06-01 00:00:00	1997	1998-09-27 00:00:00	1998	ANCIEN	\N	\N	\N	NON	2016-12-09 15:55:02	2017-06-15 10:51:17
15518	14127	MAIREADJOINT	2008-03-16 00:00:00	\N	2014-03-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-01-10 16:33:41	2017-01-10 16:35:15
15519	14128	CONSGENE	2008-03-16 00:00:00	\N	2014-03-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-01-10 16:35:29	2017-01-10 16:46:52
11435	14130	VICPDTINTCOM	2014-04-15 00:00:00	\N	2016-12-31 00:00:00	\N	ANCIEN	\N	Vice-président de la Communauté de communes des Vallées de la Brèche et de la Noye	\N	NON	2017-04-21 11:58:38	2017-04-21 11:59:14
15521	14131	CONSINTCOM	2017-01-01 00:00:00	\N	\N	\N	ACTIF	Conseiller de la communauté de communes de l'Oise Picardie	Conseiller de la communauté de communes de l'Oise Picardie	\N	NON	2017-04-21 11:59:28	2017-04-21 12:03:19
15562	14166	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:29	2017-06-19 09:36:37
15563	14167	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:29	2017-06-15 10:48:16
15564	14168	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:29	2017-06-15 10:48:16
15565	14169	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:29	2017-06-15 10:48:16
15566	14170	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:29	2017-06-15 10:48:16
15567	14171	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:29	2017-06-15 10:48:16
15568	14172	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:30	2017-06-15 10:48:16
15569	14173	DEPUTE	1973-04-02 00:00:00	\N	1977-01-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:30	2017-06-15 10:48:16
15570	14174	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:30	2017-06-15 10:48:17
15571	14175	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:30	2017-06-15 10:48:17
15572	14176	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:30	2017-06-15 10:48:17
15573	14177	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:31	2017-06-15 10:48:17
43686	49338	DEPUTE	1993-04-02 00:00:00	\N	1993-04-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:16	\N
15182	13761	CONSDPT	2015-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2015-03-31 17:09:47	2015-03-31 17:10:38
15183	13762	CONSDPT	2015-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2015-03-31 17:11:11	2015-03-31 17:11:54
15184	13763	CONSDPT	2015-03-30 00:00:00	\N	2015-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-03-31 17:12:06	2015-04-15 17:37:20
15161	13788	VICPDTDPT	2015-04-03 00:00:00	\N	2017-10-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-04-15 17:29:19	2017-10-19 11:24:09
15162	13787	VICPDTDPT	2015-04-03 00:00:00	\N	2015-12-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-04-15 17:26:48	2015-12-04 12:27:44
15173	13789	VICPDTDPT	2015-04-03 00:00:00	\N	2017-01-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-04-15 17:31:45	2015-04-15 17:32:00
15184	13790	VICPDTDPT	2015-04-03 00:00:00	\N	2017-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-04-15 17:37:23	2017-11-13 18:55:34
15174	13791	VICPDTDPT	2015-04-03 00:00:00	\N	2017-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-04-15 17:38:18	2015-04-15 17:38:30
15151	13792	VICPDTDPT	2015-04-03 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2015-04-15 17:39:13	2015-04-15 17:39:26
15154	13793	VICPDTDPT	2015-04-03 00:00:00	\N	2017-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-04-15 17:40:36	2017-11-13 09:23:00
15168	13794	VICPDTDPT	2015-04-03 00:00:00	\N	2017-09-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-04-15 17:41:19	2017-11-09 10:39:38
15160	13795	VICPDTDPT	2015-04-03 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2015-04-15 17:42:48	2015-04-15 17:43:08
13805	13802	CONSMUNI	2015-05-19 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2015-05-18 16:27:57	2015-05-18 16:28:07
15234	13833	MAIRE	1989-03-01 00:00:00	\N	2016-11-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2015-09-07 16:16:55	2018-01-08 20:22:41
13871	13839	CONSMUNI	2015-09-16 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2015-09-25 15:21:10	2015-09-25 15:21:30
15236	13835	CONSGENE	1998-03-15 00:00:00	\N	\N	2000	ANCIEN	\N	Nouvelle fonction	\N	NON	2015-09-07 16:19:52	2015-09-07 16:42:07
15236	13836	VICPDTGEN	\N	2001	2015-03-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-09-07 16:22:36	2015-09-07 16:43:42
15237	13837	VICPDTDPT	2015-03-22 00:00:00	\N	2017-09-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2015-09-07 16:26:28	2018-01-08 20:09:30
15287	13889	MAIRE	2016-01-02 00:00:00	\N	2017-10-31 00:00:00	\N	ANCIEN	\N	Maire	\N	NON	2016-04-18 17:35:21	2018-02-22 16:03:45
15180	13886	CONSDPT	2016-02-08 00:00:00	\N	2016-11-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2016-02-08 10:18:36	2016-11-18 12:37:50
15292	13892	PREVICPDTREG	2016-01-04 00:00:00	\N	2017-11-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2016-06-02 17:06:56	2018-06-08 14:56:05
14187	13893	CONSMUNI	2016-01-26 00:00:00	\N	2018-02-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2016-06-03 10:18:52	2018-03-28 12:51:27
15329	13927	CONSMET	2016-01-01 00:00:00	\N	2020-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2016-07-11 14:04:11	2016-07-11 14:04:41
15300	13897	PDTMET	2015-11-09 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2016-06-22 18:41:32	2016-06-22 18:41:50
15331	13930	CONSREG	2014-02-21 00:00:00	\N	2015-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2016-09-16 14:42:41	2016-09-16 14:44:26
15338	13934	MAIRE	2008-03-09 00:00:00	\N	2017-11-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2016-12-01 10:41:34	2018-01-23 18:48:29
15485	14094	DEPUTE	2002-06-16 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2016-12-12 18:35:16	2016-12-12 18:35:47
15574	14178	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:31	2017-06-15 10:48:17
15685	14289	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:39	2017-06-15 10:48:21
15686	14290	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:39	2017-06-15 10:48:21
15687	14291	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:39	2017-06-15 10:48:21
15688	14292	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:39	2017-06-15 10:48:21
15689	14293	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:39	2017-06-15 10:48:22
15690	14294	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:39	2017-06-15 10:48:22
15691	14295	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:39	2017-06-15 10:48:22
15692	14296	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:39	2017-06-15 10:48:22
15693	14297	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:39	2017-06-15 10:48:22
15694	14298	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:39	2017-06-15 10:48:22
15695	14299	PDTAN	2007-06-26 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:39	2017-06-29 03:42:25
15696	14300	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:39	2017-06-19 09:36:40
15697	14301	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:39	2017-06-29 03:42:25
15698	14302	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:40	2017-06-15 10:48:22
15699	14303	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:40	2017-06-15 10:48:22
15700	14304	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:40	2017-06-15 10:48:22
15701	14305	DEPUTE	1973-04-02 00:00:00	\N	1973-05-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:40	2017-06-15 10:48:22
15702	14306	DEPUTE	1986-04-02 00:00:00	\N	1986-04-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:40	2017-06-15 10:48:22
15703	14307	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:40	2017-06-15 10:48:22
15704	14308	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:40	2017-06-15 10:48:22
15705	14309	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:40	2017-06-15 10:48:22
15706	14310	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:40	2017-06-15 10:48:22
15707	14311	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:40	2017-06-15 10:48:22
15708	14312	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:40	2017-06-15 10:48:22
15709	14313	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:40	2017-06-15 10:48:22
15710	14314	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:40	2017-06-15 10:48:22
15711	14315	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:41	2017-06-15 10:48:22
15712	14316	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:41	2017-06-15 10:48:22
15713	14317	DEPUTE	1999-10-01 00:00:00	\N	2000-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:41	2017-06-29 09:18:03
15714	14318	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:41	2017-06-29 09:18:03
15715	14319	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:41	2017-06-15 10:48:23
15716	14320	DEPUTE	2002-06-19 00:00:00	\N	2004-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:41	2017-06-15 10:48:23
15717	14321	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:41	2017-06-15 10:48:23
15718	14322	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:41	2017-06-19 09:36:41
15719	14323	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:42	2017-06-15 10:48:23
15720	14324	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:42	2017-06-15 10:48:23
15721	14325	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:42	2017-06-15 10:48:23
15722	14326	DEPUTE	1991-06-18 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:42	2017-06-15 10:48:23
15723	14327	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:42	2017-06-15 10:48:23
15724	14328	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:42	2017-06-15 10:48:23
15725	14329	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:42	2017-06-15 10:48:23
15726	14330	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:43	2017-06-29 09:18:04
15727	14331	DEPUTE	1995-09-17 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:43	2017-06-29 09:18:04
15728	14332	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:43	2017-06-15 10:48:23
15729	14333	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:43	2017-06-15 10:48:23
15730	14334	DEPUTE	2011-03-28 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:43	2017-06-29 09:18:04
15731	14335	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:43	2017-06-29 09:18:04
15732	14336	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:43	2017-06-15 10:48:23
15733	14337	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:43	2017-06-15 10:48:23
15734	14338	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:43	2017-06-15 10:48:24
15735	14339	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:43	2017-06-15 10:48:24
15736	14340	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:43	2017-06-15 10:48:24
15737	14341	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:43	2017-06-15 10:48:24
15739	14343	DEPUTE	1985-05-23 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:43	2017-06-15 10:48:24
15740	14344	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:43	2017-06-15 10:48:24
15741	14345	DEPUTE	1991-03-09 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:44	2017-06-15 10:48:24
15742	14346	DEPUTE	1995-12-17 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:44	2017-06-29 03:42:27
15185	13879	PDTDPT	2016-01-04 00:00:00	\N	2017-10-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2016-01-05 15:16:55	2017-11-06 16:25:20
15185	13846	CONSDPT	2015-12-06 00:00:00	\N	2016-01-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2015-12-09 10:40:58	2016-01-05 15:16:51
15319	13916	CONSMET	2016-01-01 00:00:00	\N	2017-02-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2016-06-24 11:06:30	2017-03-01 11:22:53
15321	13918	CONSMET	2016-01-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2016-07-07 13:24:37	2016-07-07 13:24:51
15322	13919	VICPDTMET	2016-01-01 00:00:00	\N	2017-12-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2016-07-07 13:25:31	2016-07-07 13:25:53
15323	13920	CONSMET	2016-01-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2016-07-07 13:26:25	2016-07-07 13:26:42
15325	13923	CONSMET	2016-01-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2016-07-07 13:28:27	2016-07-07 13:28:48
15324	13922	CONSMET	2016-01-01 00:00:00	\N	2016-08-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2016-07-07 13:27:23	2016-09-07 18:03:39
15326	13924	CONSMET	2016-01-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2016-07-07 13:29:31	2016-07-07 13:29:45
15363	13960	DEPUTE	1981-06-14 00:00:00	1981	1986-04-01 00:00:00	1986	ANCIEN	\N	\N	\N	NON	2016-12-08 14:53:05	2016-12-08 14:54:45
15359	13955	DEPUTE	1981-06-21 00:00:00	1981	1986-04-01 00:00:00	1986	ANCIEN	\N	\N	\N	NON	2016-12-08 14:31:28	2016-12-08 14:32:10
15360	13956	DEPUTE	1973-04-02 00:00:00	\N	1977-05-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2016-12-08 14:36:33	2017-06-15 10:48:39
15361	13957	DEPUTE	1978-03-19 00:00:00	\N	1978-09-11 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2016-12-08 14:38:34	\N
28956	27553	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:44	\N
15364	13961	SECAN	1986-04-04 00:00:00	1986	1987-04-01 00:00:00	1988	ANCIEN	\N	\N	\N	NON	2016-12-08 14:54:49	2017-06-29 03:42:23
15362	13959	DEPUTE	1978-03-12 00:00:00	1978	1981-05-22 00:00:00	1981	ANCIEN	\N	\N	\N	NON	2016-12-08 14:52:53	2016-12-08 14:53:29
15365	13962	DEPUTE	1988-06-05 00:00:00	1988	1993-04-01 00:00:00	1993	ANCIEN	\N	\N	\N	NON	2016-12-08 14:56:14	2016-12-08 14:57:24
15366	13963	DEPUTE	1993-04-02 00:00:00	1993	1997-04-21 00:00:00	1997	ANCIEN	\N	\N	\N	NON	2016-12-08 14:57:27	2017-06-15 10:48:18
15367	13964	DEPUTE	1997-05-25 00:00:00	1997	2001-09-30 00:00:00	2001	ANCIEN	\N	\N	\N	NON	2016-12-08 14:58:45	2017-06-15 10:48:18
15368	13965	DEPUTE	1962-11-18 00:00:00	1962	1967-04-02 00:00:00	1967	ANCIEN	\N	\N	\N	NON	2016-12-08 15:02:59	2016-12-08 15:05:23
15369	13966	DEPUTE	1967-04-03 00:00:00	1967	1968-05-30 00:00:00	1968	ANCIEN	\N	\N	\N	NON	2016-12-08 15:05:26	2016-12-08 15:06:32
15370	13967	DEPUTE	1968-06-23 00:00:00	1968	1968-08-06 00:00:00	1968	ANCIEN	\N	\N	\N	NON	2016-12-08 15:06:34	2016-12-08 15:08:41
15371	13968	DEPUTE	1973-03-04 00:00:00	1973	1973-05-12 00:00:00	1973	ANCIEN	\N	\N	\N	NON	2016-12-08 15:08:48	2016-12-08 15:10:01
15372	13969	DEPUTE	1978-03-12 00:00:00	1978	1978-05-05 00:00:00	1978	ANCIEN	\N	\N	\N	NON	2016-12-08 15:10:02	2016-12-08 15:11:18
15373	13970	DEPUTE	1981-06-14 00:00:00	1981	1982-01-01 00:00:00	1982	ANCIEN	\N	\N	\N	NON	2016-12-08 15:11:21	2016-12-08 15:12:16
49629	48225	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:45	\N
15375	13972	DEPUTE	1993-04-02 00:00:00	1993	1997-04-21 00:00:00	1997	ANCIEN	\N	\N	\N	NON	2016-12-08 17:07:18	2017-06-15 10:48:51
15376	13973	DEPUTE	1997-06-01 00:00:00	1997	1998-09-27 00:00:00	1998	ANCIEN	\N	\N	\N	NON	2016-12-08 17:08:41	2017-06-15 10:48:51
15377	13974	DEPUTE	1986-04-02 00:00:00	1986	1988-05-14 00:00:00	1988	ANCIEN	\N	\N	\N	NON	2016-12-08 17:17:25	2017-06-15 10:49:34
15378	13975	DEPUTE	1988-06-12 00:00:00	1988	1993-04-01 00:00:00	1993	ANCIEN	\N	\N	\N	NON	2016-12-08 17:18:18	2016-12-08 17:19:48
15379	13976	DEPUTE	1999-12-05 00:00:00	1999	2002-06-18 00:00:00	2002	ANCIEN	\N	\N	\N	NON	2016-12-08 17:18:49	2016-12-08 17:20:47
15380	13977	DEPUTE	2002-06-19 00:00:00	2002	2007-06-19 00:00:00	2007	ANCIEN	\N	\N	\N	NON	2016-12-08 17:20:24	2017-06-15 10:49:34
49634	48230	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:46	\N
15382	13979	DEPUTE	1978-04-03 00:00:00	1978	1981-05-22 00:00:00	1981	ANCIEN	\N	\N	\N	NON	2016-12-08 17:26:25	2017-06-15 10:49:36
15383	13980	DEPUTE	1981-06-14 00:00:00	1981	1981-07-24 00:00:00	1981	ANCIEN	\N	\N	\N	NON	2016-12-08 17:28:38	2016-12-08 17:36:13
15390	13989	DEPUTE	1997-06-01 00:00:00	1997	2002-06-18 00:00:00	2002	ANCIEN	\N	\N	\N	NON	2016-12-08 18:20:37	2017-06-15 10:48:17
15385	13982	DEPUTE	1988-06-05 00:00:00	1988	1988-07-29 00:00:00	1988	ANCIEN	\N	\N	\N	NON	2016-12-08 17:33:46	2016-12-08 17:37:05
15384	13983	DEPUTE	1986-03-16 00:00:00	1986	1988-05-14 00:00:00	1988	ANCIEN	\N	\N	\N	NON	2016-12-08 17:36:20	\N
15386	13984	DEPUTE	1993-03-28 00:00:00	1993	1997-04-21 00:00:00	1997	ANCIEN	\N	\N	\N	NON	2016-12-08 17:37:14	2016-12-08 17:38:21
15387	13985	DEPUTE	2000-10-22 00:00:00	1997	2002-06-18 00:00:00	1997	ANCIEN	\N	\N	\N	NON	2016-12-08 17:38:56	2017-06-29 09:18:45
15387	13986	DEPUTE	2000-10-22 00:00:00	1997	2002-06-18 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2016-12-08 17:39:19	2017-06-29 09:18:45
50776	50069	DEPUTE	1978-04-03 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	2017-08-18 12:16:34	\N
15389	13988	DEPUTE	1993-04-02 00:00:00	1993	1995-09-24 00:00:00	1995	ANCIEN	\N	\N	\N	NON	2016-12-08 18:15:40	2017-06-15 10:49:49
10768	13995	DEPUTE	1981-06-21 00:00:00	1981	1986-04-01 00:00:00	1986	ANCIEN	\N	\N	\N	NON	2016-12-08 18:45:19	\N
50777	50070	DEPUTE	1981-07-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	2017-08-18 12:16:58	\N
50778	50071	DEPUTE	1997-06-12 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	2017-08-18 12:17:14	\N
50779	50072	DEPUTE	2002-06-25 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	2017-08-18 12:17:34	\N
15394	13994	DEPUTE	1997-06-01 00:00:00	1997	2001-09-30 00:00:00	2001	ANCIEN	\N	\N	\N	NON	2016-12-08 18:36:14	2017-06-15 10:50:10
15395	13996	DEPUTE	1986-04-02 00:00:00	1986	1988-05-14 00:00:00	1988	ANCIEN	\N	\N	\N	NON	2016-12-08 18:46:27	2017-06-15 10:49:37
15396	13997	DEPUTE	1988-06-05 00:00:00	1988	1993-04-01 00:00:00	1993	ANCIEN	\N	\N	\N	NON	2016-12-08 18:48:09	2016-12-08 18:48:59
15397	13998	DEPUTE	1993-04-02 00:00:00	1993	1993-05-01 00:00:00	1993	ANCIEN	\N	\N	\N	NON	2016-12-08 18:49:30	2017-06-15 10:49:37
15398	13999	DEPUTE	1997-06-01 00:00:00	1997	2002-06-07 00:00:00	2002	ANCIEN	\N	\N	\N	NON	2016-12-08 18:50:25	2017-06-15 10:49:37
15399	14000	DEPUTE	2002-06-09 00:00:00	2002	2002-07-19 00:00:00	2002	ANCIEN	\N	\N	\N	NON	2016-12-08 18:51:26	2016-12-08 18:52:18
15400	14001	DEPUTE	2007-06-10 00:00:00	2007	2012-06-19 00:00:00	2012	ANCIEN	\N	\N	\N	NON	2016-12-08 18:52:19	2016-12-08 18:53:10
15401	14002	DEPUTE	2007-06-10 00:00:00	\N	\N	\N	ANCIEN	\N	\N	\N	NON	2016-12-08 18:53:11	\N
15402	14003	DEPUTE	1986-03-16 00:00:00	1986	1986-04-01 00:00:00	1986	ANCIEN	\N	\N	\N	NON	2016-12-08 19:25:00	2016-12-08 19:25:53
15403	14004	DEPUTE	1993-03-14 00:00:00	1993	1997-04-21 00:00:00	1997	ANCIEN	\N	\N	\N	NON	2016-12-08 19:26:22	\N
15743	14347	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:44	2017-06-29 03:42:27
15744	14348	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:44	2017-06-15 10:48:24
15745	14349	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:44	2017-06-15 10:48:24
15746	14350	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:44	2017-06-15 10:48:24
15747	14351	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:44	2017-06-19 09:36:42
15748	14352	DEPUTE	2004-05-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:44	2017-06-15 10:48:24
15749	14353	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:44	2017-06-15 10:48:24
15750	14354	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:44	2017-06-15 10:48:24
15751	14355	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:44	2017-06-15 10:48:24
15752	14356	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:45	2017-06-15 10:48:24
15753	14357	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:45	2017-06-15 10:48:24
15754	14358	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:45	2017-06-15 10:48:24
15755	14359	DEPUTE	1983-02-08 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:45	2017-06-15 10:48:25
15756	14360	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:45	2017-06-15 10:48:25
15757	14361	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:45	2017-06-15 10:48:25
15758	14362	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:45	2017-06-29 09:18:04
15759	14363	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:45	2017-06-29 03:42:27
15203	13803	CONSMUNI	2014-04-01 00:00:00	\N	2015-07-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-06-12 15:39:31	2015-07-27 15:34:41
15206	13806	VICPDTREG	\N	\N	\N	2015	ANCIEN	\N	Nouvelle fonction	\N	NON	2015-06-12 15:43:33	2015-06-15 10:44:02
15203	13805	MAIREADJOINT	\N	\N	2014-03-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2015-06-12 15:40:24	2015-06-12 15:41:34
15207	13807	CONSDPT	2015-06-12 00:00:00	\N	2021-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-06-12 15:46:33	\N
15210	13809	VICPDTINTCOM	2015-06-16 00:00:00	\N	2015-07-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2015-06-16 17:38:18	2016-05-25 09:40:20
14225	13831	CONSMUNI	2015-07-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2015-07-28 15:19:40	\N
14241	13832	CONSCOMINT	2015-07-28 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	2015-07-28 15:20:03	2015-07-28 15:20:13
15254	13850	CONSREG	2015-12-14 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2015-12-15 14:52:36	2015-12-15 14:55:33
15255	13852	CONSREG	2015-12-14 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2015-12-15 14:56:57	2015-12-15 14:57:18
15256	13853	CONSREG	2015-12-14 00:00:00	\N	2021-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-12-15 14:57:58	2015-12-15 14:59:22
15262	13859	CONSREG	2015-12-14 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2015-12-15 15:04:41	2015-12-15 15:05:00
15258	13855	CONSREG	2015-12-14 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2015-12-15 15:00:44	2015-12-15 15:01:01
15259	13856	CONSREG	2015-12-14 00:00:00	\N	2021-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2015-12-15 15:01:40	2015-12-15 15:01:57
15260	13857	CONSREG	2015-12-14 00:00:00	\N	2021-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-12-15 15:02:29	2015-12-15 15:02:49
15261	13858	CONSREG	2015-12-14 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2015-12-15 15:03:31	2015-12-15 15:03:52
15263	13860	CONSREG	2015-12-14 00:00:00	\N	2021-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-12-15 15:05:34	2015-12-15 15:05:50
15264	13861	CONSREG	2015-12-14 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2015-12-15 15:06:43	2015-12-15 15:06:57
15266	13863	CONSREG	2015-12-14 00:00:00	\N	2017-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-12-15 15:07:34	2017-10-26 15:45:53
15268	13867	CONSREG	2015-12-14 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2015-12-15 15:08:51	2015-12-15 15:09:21
15274	13873	VICPDTREG	2015-12-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2015-12-15 15:11:22	\N
15271	13870	VICPDTREG	2015-12-14 00:00:00	\N	2017-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-12-15 15:09:59	2015-12-15 15:10:23
15276	13875	CONSREG	2015-12-14 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2015-12-15 15:45:15	2015-12-15 15:45:32
15459	14066	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2016-12-12 16:27:01	2017-06-15 10:49:12
15463	14070	DEPUTE	1993-03-28 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2016-12-12 16:39:14	2016-12-12 16:39:38
15470	14076	DEPUTE	1986-03-16 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2016-12-12 16:50:54	2016-12-12 16:52:39
15511	14120	DEPUTE	1978-03-19 00:00:00	\N	1978-05-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2016-12-13 10:50:17	2016-12-13 10:51:13
9738	14121	DEPUTE	1989-01-01 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2016-12-13 11:38:04	2016-12-13 11:39:02
15575	14179	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:31	2017-06-29 03:42:22
15576	14180	VICPDTAN	1988-06-24 00:00:00	\N	1992-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:31	2017-06-29 09:18:00
15577	14181	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:31	2017-06-15 10:48:17
15578	14182	VICPDTAN	1986-04-04 00:00:00	\N	1988-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:31	2017-06-29 03:42:22
15579	14183	DEPUTE	1988-06-06 00:00:00	\N	1992-11-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:31	2017-06-29 09:18:00
15580	14184	DEPUTE	1973-04-02 00:00:00	\N	1973-05-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:31	2017-06-15 10:48:17
15581	14185	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:31	2017-06-15 10:48:17
15582	14186	DEPUTE	1986-10-24 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:31	2017-06-15 10:48:17
15583	14187	DEPUTE	1978-04-02 00:00:00	\N	1980-10-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:32	2017-06-15 10:48:17
15584	14188	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:32	2017-06-15 10:48:17
15585	14189	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:32	2017-06-15 10:48:17
15586	14190	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:32	2017-06-15 10:48:17
15587	14191	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:32	2017-06-15 10:48:17
15588	14192	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:32	2017-06-15 10:48:17
15589	14193	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:32	2017-06-15 10:48:17
15590	14194	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:32	2017-06-15 10:48:17
15591	14195	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:32	2017-06-15 10:48:17
15592	14196	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:32	2017-06-15 10:48:17
15593	14197	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:32	2017-06-15 10:48:17
15594	14198	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:32	2017-06-15 10:48:17
15595	14199	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:32	2017-06-15 10:48:17
15596	14200	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:33	2017-06-15 10:48:18
15597	14201	DEPUTE	1981-07-02 00:00:00	\N	1983-02-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:33	2017-06-15 10:48:18
15598	14202	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:33	2017-06-15 10:48:18
15599	14203	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:33	2017-06-15 10:48:18
15600	14204	DEPUTE	1973-04-02 00:00:00	\N	1977-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:33	2017-06-15 10:48:18
15601	14205	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:33	2017-06-15 10:48:18
15602	14206	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:33	2017-06-15 10:48:18
15603	14207	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:33	2017-06-29 03:42:23
15604	14208	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:33	2017-06-15 10:48:18
15605	14209	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:33	2017-06-15 10:48:18
15606	14210	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:33	2017-06-19 09:36:38
15607	14211	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:33	2017-06-15 10:48:18
15608	14212	DEPUTE	1998-06-15 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:33	2017-06-15 10:48:18
15609	14213	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:34	2017-06-15 10:48:18
15610	14214	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:34	2017-06-15 10:48:18
15611	14215	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:34	2017-06-15 10:48:18
15612	14216	DEPUTE	1983-11-05 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:34	2017-06-15 10:48:18
15613	14217	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:34	2017-06-15 10:48:18
15614	14218	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:34	2017-06-15 10:48:18
15615	14219	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:34	2017-06-15 10:48:18
15616	14220	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:34	2017-06-15 10:48:19
15617	14221	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:34	2017-06-15 10:48:19
15618	14222	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:34	2017-06-15 10:48:19
15619	14223	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:34	2017-06-15 10:48:19
15620	14224	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:34	2017-06-15 10:48:19
15621	14225	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:34	2017-06-15 10:48:19
15622	14226	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:35	2017-06-15 10:48:19
15623	14227	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:35	2017-06-15 10:48:19
15624	14228	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:35	2017-06-15 10:48:19
15625	14229	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:35	2017-06-15 10:48:19
15626	14230	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:35	2017-06-15 10:48:19
15628	14232	DEPUTE	1981-07-02 00:00:00	\N	1984-08-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:35	2017-06-15 10:48:19
15629	14233	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:35	2017-06-15 10:48:19
15630	14234	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:35	2017-06-15 10:48:19
15631	14235	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:35	2017-06-15 10:48:19
15633	14237	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:35	2017-06-15 10:48:19
15634	14238	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:35	2017-06-15 10:48:19
15180	13766	PDTDPT	2015-04-03 00:00:00	\N	2016-02-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-04-03 10:31:19	2016-02-08 10:18:57
15181	13769	PDTDPT	2015-04-03 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2015-04-03 10:33:56	2015-04-03 10:34:11
13782	13876	CONSREG	2015-12-14 00:00:00	\N	2015-12-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2016-01-04 10:59:06	2016-01-04 10:59:24
15159	13774	PDTDPT	2015-04-03 00:00:00	\N	2017-10-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-04-03 10:38:34	2017-11-14 11:56:28
15164	13775	PDTDPT	2015-04-03 00:00:00	\N	2017-10-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-04-03 10:39:41	2017-11-16 12:55:01
15170	13778	PDTDPT	2015-04-03 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2015-04-03 10:41:57	2015-04-03 10:42:09
15211	13810	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-07-01 17:45:57	2017-06-19 09:38:10
15212	13811	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-07-01 17:46:47	2017-06-19 09:36:48
15213	13812	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-07-01 17:47:37	2017-06-19 09:39:21
15214	13813	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-07-01 17:48:11	2017-06-19 09:38:39
15215	13814	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-07-01 17:48:52	2017-06-19 09:36:46
15216	13815	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-07-01 17:49:35	2017-06-29 03:44:42
15217	13816	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-07-01 17:50:19	2017-06-19 09:36:53
15218	13817	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-07-01 17:50:50	2017-06-19 09:38:45
15219	13818	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-07-01 17:51:52	2017-06-19 09:39:12
15220	13819	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-07-01 17:52:31	2017-06-19 09:39:21
15221	13820	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-07-01 17:53:20	2017-06-19 09:39:21
15222	13821	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-07-01 17:53:52	2017-06-19 09:38:22
15223	13822	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-07-01 17:54:30	2017-06-19 09:38:44
15224	13823	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-07-01 17:55:02	2017-06-19 09:38:20
15225	13824	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-07-01 17:55:52	2017-06-19 09:39:23
15226	13825	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-07-01 17:56:20	2017-06-19 09:39:06
15227	13826	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-07-01 17:56:54	2017-06-19 09:39:02
15228	13827	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-07-01 17:57:28	2017-06-19 09:39:13
15229	13828	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-07-01 18:00:58	2017-06-19 09:38:27
15230	13829	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-07-01 18:01:32	2017-06-19 09:36:38
13782	13877	PDTREG	2015-12-18 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2016-01-04 10:59:26	2016-01-04 10:59:38
15283	13885	VICPDTINTCOM	2016-01-19 00:00:00	\N	2017-10-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2016-01-19 17:59:23	2017-11-10 18:20:08
15332	13932	PREPDTINTCOM	2016-01-01 00:00:00	\N	2017-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2016-10-06 14:54:52	2018-02-13 12:38:16
15335	13933	CONSMUNI	2008-03-16 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2016-11-18 12:45:29	2016-11-18 13:01:47
15458	14065	MAIRE	2008-03-16 00:00:00	\N	2014-03-16 00:00:00	2014	ANCIEN	\N	Nouvelle fonction	\N	\N	2016-12-12 16:04:19	2016-12-16 12:05:12
15512	14122	DEPUTE	1988-06-12 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2016-12-13 12:08:03	2016-12-13 12:09:15
15527	14137	PREPDTINTCOM	2016-01-11 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	2017-04-21 15:52:28	2017-04-21 15:53:23
15542	14146	VICPDTDPT	2015-03-29 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-07 15:29:40	2017-06-07 15:31:40
15635	14239	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:35	2017-06-15 10:48:19
15636	14240	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:35	2017-06-15 10:48:19
15637	14241	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:35	2017-06-15 10:48:19
15638	14242	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:35	2017-06-15 10:48:19
15639	14243	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:35	2017-06-19 09:36:39
15640	14244	DEPUTE	1991-06-18 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:35	2017-06-15 10:48:20
15641	14245	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:36	2017-06-15 10:48:20
15642	14246	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:36	2017-06-15 10:48:20
15643	14247	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:36	2017-06-15 10:48:20
15644	14248	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:36	2017-06-15 10:48:20
15645	14249	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:36	2017-06-15 10:48:20
15646	14250	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:36	2017-06-15 10:48:20
15647	14251	DEPUTE	1995-06-19 00:00:00	\N	1995-11-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:36	2017-06-15 10:48:20
15648	14252	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:36	2017-06-15 10:48:20
15649	14253	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:36	2017-06-15 10:48:20
15650	14254	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:36	2017-06-15 10:48:20
15651	14255	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:36	2017-06-15 10:48:20
15652	14256	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:36	2017-06-29 03:42:24
15653	14257	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:36	2017-06-15 10:48:20
15654	14258	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:36	2017-06-29 03:42:24
15655	14259	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:36	2017-06-15 10:48:20
15656	14260	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:36	2017-06-15 10:48:20
15657	14261	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:36	2017-06-15 10:48:20
15658	14262	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:36	2017-06-19 09:36:39
15659	14263	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:37	2017-06-15 10:48:20
15660	14264	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:37	2017-06-15 10:48:20
15661	14265	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:37	2017-06-19 09:36:39
15662	14266	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:37	2017-06-15 10:48:20
15663	14267	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:37	2017-06-15 10:48:21
15664	14268	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:37	2017-06-15 10:48:21
15665	14269	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:37	2017-06-15 10:48:21
15666	14270	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:37	2017-06-15 10:48:21
15667	14271	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:37	2017-06-15 10:48:21
15668	14272	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:38	2017-06-15 10:48:21
15669	14273	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:38	2017-06-15 10:48:21
15670	14274	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:38	2017-06-28 03:42:25
15671	14275	QUESTAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:38	2017-06-28 03:42:25
15672	14276	DEPUTE	1978-04-02 00:00:00	\N	1978-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:38	2017-06-15 10:48:21
15673	14277	DEPUTE	1981-07-02 00:00:00	\N	1983-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:38	2017-06-15 10:48:21
15674	14278	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:38	2017-06-15 10:48:21
15675	14279	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:38	2017-06-15 10:48:21
15676	14280	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:38	2017-06-15 10:48:21
15677	14281	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:38	2017-06-15 10:48:21
15678	14282	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:38	2017-06-15 10:48:21
15679	14283	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:38	2017-06-15 10:48:21
15680	14284	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:39	2017-06-15 10:48:21
15681	14285	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:39	2017-06-15 10:48:21
15682	14286	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:39	2017-06-15 10:48:21
15683	14287	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:39	2017-06-15 10:48:21
15684	14288	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:39	2017-06-15 10:48:21
15189	13784	MAIRE	2008-03-24 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2015-04-07 17:16:41	2015-04-16 11:02:55
15238	13838	PDTINTCOM	1999-03-01 00:00:00	\N	2016-12-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-09-11 17:59:58	2018-01-08 20:14:56
15197	13800	MAIREDEL	2014-04-01 00:00:00	\N	2015-06-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-05-11 18:42:22	2017-11-13 20:00:18
15241	13840	CONSDPT	2015-09-28 00:00:00	\N	2018-05-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-10-06 11:07:21	2018-05-30 15:10:56
10839	13841	CONSMUNI	2015-10-06 00:00:00	\N	2016-11-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-10-06 18:02:17	2016-12-01 10:36:51
15253	13849	CONSREG	2015-12-13 00:00:00	\N	2016-06-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-12-15 14:51:56	2016-09-23 12:10:12
15302	13899	CONSMET	2016-01-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2016-06-23 10:57:42	2016-06-23 10:59:39
15265	13862	CONSREG	2015-12-14 00:00:00	\N	2016-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2015-12-15 15:06:54	2015-12-15 15:07:21
14245	13864	CONSREG	2015-12-14 00:00:00	\N	2017-10-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2015-12-15 15:07:45	2017-11-09 15:33:55
15269	13868	CONSREG	2015-12-14 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2015-12-15 15:09:27	2015-12-15 15:09:45
10760	13866	PDTREG	2015-12-14 00:00:00	\N	2017-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2015-12-15 15:08:20	2017-11-10 14:55:07
15272	13871	CONSREG	2015-12-14 00:00:00	\N	2021-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2015-12-15 15:10:00	2015-12-15 15:10:20
15273	13872	CONSREG	2015-12-14 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2015-12-15 15:10:43	2015-12-15 15:11:00
15275	13874	CONSREG	2015-12-14 00:00:00	\N	2016-01-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2015-12-15 15:11:31	2016-06-02 17:06:40
15301	13898	CONSMET	2016-01-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2016-06-23 09:38:21	2016-06-23 09:52:26
15303	13900	CONSMET	2016-01-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2016-06-23 11:38:10	2016-06-23 11:38:36
15304	13901	CONSMET	2016-01-01 00:00:00	\N	2020-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2016-06-23 11:40:57	2016-06-23 11:41:24
15306	13903	VICPDTMET	2016-01-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2016-06-23 15:07:45	2016-06-23 15:08:17
15310	13907	CONSMET	2016-01-01 00:00:00	\N	2020-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2016-06-23 15:20:42	2016-06-23 15:21:04
15311	13908	VICPDTMET	2016-01-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2016-06-23 15:48:17	2016-06-23 15:48:33
15312	13909	CONSMET	2016-01-01 00:00:00	\N	2020-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2016-06-23 15:51:37	2016-06-23 15:51:54
15316	13913	CONSMET	2016-01-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2016-06-23 16:25:53	2016-06-23 16:26:05
11811	13928	CONSMUNI	\N	2016	2020-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2016-09-13 16:39:56	2016-09-13 16:40:14
12289	13931	CONSMUNI	2008-03-17 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2016-09-29 17:55:40	2016-09-29 18:21:08
15436	14042	DEPUTE	1981-07-02 00:00:00	1981	1981-07-23 00:00:00	1981	ANCIEN	\N	\N	\N	NON	2016-12-12 09:17:16	2017-06-15 10:48:29
15437	14043	DEPUTE	2012-06-17 00:00:00	2012	2012-06-19 00:00:00	2012	ANCIEN	\N	\N	\N	NON	2016-12-12 10:20:16	2016-12-12 10:21:05
15438	14044	DEPUTE	1993-04-02 00:00:00	1993	1997-04-21 00:00:00	1997	ANCIEN	\N	\N	\N	NON	2016-12-12 10:22:44	2017-06-15 10:48:40
15442	14050	DEPUTE	1993-03-28 00:00:00	1993	1997-04-21 00:00:00	1997	ANCIEN	\N	\N	\N	NON	2016-12-12 14:26:47	2016-12-12 14:27:09
15439	14047	DEPUTE	1997-06-01 00:00:00	1997	2001-09-30 00:00:00	2001	ANCIEN	\N	\N	\N	NON	2016-12-12 10:29:05	2017-06-15 10:49:12
15440	14048	DEPUTE	1981-06-21 00:00:00	1981	1986-04-01 00:00:00	1986	ANCIEN	\N	\N	\N	NON	2016-12-12 10:31:26	2016-12-12 10:31:45
15443	14051	DEPUTE	2007-06-29 00:00:00	2007	2012-06-19 00:00:00	2012	ANCIEN	\N	\N	\N	NON	2016-12-12 14:30:07	2016-12-12 14:30:21
15444	14052	DEPUTE	2012-06-20 00:00:00	2012	2015-08-27 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2016-12-12 14:31:01	2017-06-15 10:51:38
15445	14053	DEPUTE	1988-06-12 00:00:00	1988	1993-04-01 00:00:00	1993	ANCIEN	\N	\N	\N	NON	2016-12-12 14:32:41	2016-12-12 14:43:00
15446	14054	DEPUTE	1993-04-02 00:00:00	1993	1995-09-24 00:00:00	1995	ANCIEN	\N	\N	\N	NON	2016-12-12 14:33:15	2017-06-15 10:49:58
15447	14055	DEPUTE	1988-03-10 00:00:00	1988	1988-05-14 00:00:00	1988	ANCIEN	\N	\N	\N	NON	2016-12-12 14:50:14	2017-06-15 10:50:31
15448	14056	DEPUTE	1988-06-12 00:00:00	1988	1993-04-01 00:00:00	1993	ANCIEN	\N	\N	\N	NON	2016-12-12 14:50:39	2016-12-12 14:58:01
15449	14057	DEPUTE	1997-06-01 00:00:00	1997	2002-06-18 00:00:00	2002	ANCIEN	\N	\N	\N	NON	2016-12-12 14:51:15	2017-06-15 10:50:31
15450	14058	DEPUTE	2002-06-19 00:00:00	2002	2007-06-19 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2016-12-12 14:51:46	2017-06-29 03:43:45
15451	14059	DEPUTE	2007-06-26 00:00:00	2007	2012-06-19 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2016-12-12 14:52:29	2016-12-12 14:54:11
15452	14060	DEPUTE	2012-06-20 00:00:00	2012	2017-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2016-12-12 14:53:22	2017-06-19 09:38:01
15453	14061	DEPUTE	1988-06-12 00:00:00	1988	1993-04-01 00:00:00	1993	ANCIEN	\N	\N	\N	NON	2016-12-12 15:40:32	2016-12-12 15:43:13
15454	14062	DEPUTE	1993-04-02 00:00:00	1993	1997-04-21 00:00:00	1997	ANCIEN	\N	\N	\N	NON	2016-12-12 15:41:23	2017-06-15 10:51:32
15460	14067	DEPUTE	1988-06-12 00:00:00	1988	1993-04-01 00:00:00	1993	ANCIEN	\N	\N	\N	NON	2016-12-12 16:32:50	2016-12-12 16:34:55
15461	14068	DEPUTE	1993-04-02 00:00:00	1993	1997-04-21 00:00:00	1997	ANCIEN	\N	\N	\N	NON	2016-12-12 16:33:25	2017-06-15 10:50:02
15462	14069	DEPUTE	1997-06-01 00:00:00	1997	2002-06-18 00:00:00	2002	ANCIEN	\N	\N	\N	NON	2016-12-12 16:33:54	2017-06-15 10:50:02
15464	14071	DEPUTE	1978-04-03 00:00:00	1978	1981-05-22 00:00:00	1981	ANCIEN	\N	\N	\N	NON	2016-12-12 16:44:43	2017-06-15 10:49:15
15465	14072	DEPUTE	1981-06-21 00:00:00	1981	1986-04-01 00:00:00	1986	ANCIEN	\N	\N	\N	NON	2016-12-12 16:45:03	2016-12-12 16:47:44
15466	14073	DEPUTE	1986-04-02 00:00:00	1986	1988-05-14 00:00:00	1988	ANCIEN	\N	\N	\N	NON	2016-12-12 16:45:23	2017-06-15 10:49:15
15467	14074	DEPUTE	1988-06-12 00:00:00	1988	1993-04-01 00:00:00	1993	ANCIEN	\N	\N	\N	NON	2016-12-12 16:45:51	2016-12-12 16:48:22
15468	14075	DEPUTE	1993-04-02 00:00:00	1993	1997-04-21 00:00:00	1997	ANCIEN	\N	\N	\N	NON	2016-12-12 16:46:28	2017-06-15 10:49:15
15469	14077	DEPUTE	2007-06-29 00:00:00	2007	2012-06-19 00:00:00	2012	ANCIEN	\N	\N	\N	NON	2016-12-12 16:50:58	2016-12-12 16:51:26
15471	14078	DEPUTE	1997-06-01 00:00:00	1997	2002-06-18 00:00:00	2002	ANCIEN	\N	\N	\N	NON	2016-12-12 16:53:08	2017-06-15 10:50:14
15472	14079	DEPUTE	1988-06-12 00:00:00	1988	1993-04-01 00:00:00	1993	ANCIEN	\N	\N	\N	NON	2016-12-12 16:54:52	2016-12-12 16:56:02
15473	14080	DEPUTE	1993-04-02 00:00:00	1993	1993-05-01 00:00:00	1993	ANCIEN	\N	\N	\N	NON	2016-12-12 16:55:22	2017-06-15 10:49:53
15474	14082	DEPUTE	1986-04-02 00:00:00	1986	1988-05-14 00:00:00	1988	ANCIEN	\N	\N	\N	NON	2016-12-12 16:58:50	2017-06-15 10:50:17
15475	14083	DEPUTE	1988-06-12 00:00:00	1988	1993-04-01 00:00:00	1993	ANCIEN	\N	\N	\N	NON	2016-12-12 16:59:20	2016-12-12 17:00:24
15476	14084	DEPUTE	2008-02-05 00:00:00	2008	2012-06-19 00:00:00	2012	ANCIEN	\N	\N	\N	NON	2016-12-12 17:01:49	2016-12-12 17:02:11
15477	14085	DEPUTE	1973-04-02 00:00:00	1973	1973-05-12 00:00:00	1973	ANCIEN	\N	\N	\N	NON	2016-12-12 17:04:19	2016-12-12 17:05:29
15478	14086	DEPUTE	2002-06-19 00:00:00	2002	2007-06-19 00:00:00	2007	ANCIEN	\N	\N	\N	NON	2016-12-12 17:09:34	2017-06-15 10:51:29
15479	14087	DEPUTE	2007-06-26 00:00:00	2007	2011-09-30 00:00:00	2011	ANCIEN	\N	\N	\N	NON	2016-12-12 17:10:01	2016-12-12 17:10:29
15480	14088	DEPUTE	2007-06-29 00:00:00	2007	2012-06-19 00:00:00	2012	ANCIEN	\N	\N	\N	NON	2016-12-12 17:25:07	2016-12-12 17:25:46
15481	14089	DEPUTE	1978-04-03 00:00:00	1978	1981-05-22 00:00:00	1981	ANCIEN	\N	\N	\N	NON	2016-12-12 17:35:02	2017-06-15 10:50:26
15482	14090	DEPUTE	1981-06-21 00:00:00	1981	1986-04-01 00:00:00	1986	ANCIEN	\N	\N	\N	NON	2016-12-12 17:36:07	2016-12-12 17:38:32
15177	13756	CONSDPT	2015-03-30 00:00:00	\N	2021-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2015-03-31 17:03:18	2015-03-31 17:04:06
15156	13770	PDTDPT	2015-04-03 00:00:00	\N	2017-09-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2015-04-03 10:34:45	2017-11-16 16:40:26
15157	13771	PDTDPT	2015-04-03 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2015-04-03 10:37:07	2015-04-03 10:37:22
15155	13768	CONSDPT	2015-03-30 00:00:00	\N	2015-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-04-03 10:33:34	2015-04-03 10:35:07
15165	13773	PDTDPT	2015-04-03 00:00:00	\N	2017-09-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2015-04-03 10:37:55	2017-11-09 10:27:38
15166	13776	PDTDPT	2015-04-03 00:00:00	\N	2017-05-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-04-03 10:40:46	2017-07-03 14:36:07
15143	13777	PDTDPT	2015-04-03 00:00:00	\N	2017-09-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-04-03 10:41:18	2017-09-27 14:38:57
15153	13779	PDTDPT	2015-04-03 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2015-04-03 10:43:41	2015-04-03 10:43:49
15190	13785	PDTINTCOM	2014-03-17 00:00:00	\N	2017-01-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2015-04-08 10:58:04	2017-05-15 11:03:47
15189	13796	CONSMUNI	2001-03-26 00:00:00	\N	2008-03-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-04-16 11:02:18	2015-04-16 11:03:23
15192	13797	CONSREG	1998-03-15 00:00:00	\N	2015-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2015-04-22 16:51:41	2015-06-04 10:13:01
15193	13798	MAIRE	\N	2001	2017-03-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2015-04-22 16:52:45	2017-04-21 14:49:38
15200	13801	CONSMUNI	2014-03-01 00:00:00	\N	2015-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-05-11 19:33:37	2015-05-11 19:34:29
15208	13808	VICPDTINTCOM	2015-06-12 00:00:00	\N	2017-10-22 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2015-06-12 15:49:53	2017-11-07 16:18:44
14174	13830	MAIREADJOINT	2015-06-29 00:00:00	\N	2017-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2015-07-02 14:27:12	2015-07-02 14:27:31
15243	13842	MAIREADJOINT	2008-03-30 00:00:00	\N	2014-02-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2015-10-12 12:14:47	2015-10-12 12:16:04
15243	13843	MAIRE	2014-03-01 00:00:00	\N	2015-12-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2015-10-12 12:16:06	2017-11-08 15:58:44
15244	13844	CONSGENE	2004-03-21 00:00:00	\N	2015-03-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2015-10-12 12:16:34	2015-10-12 12:23:23
15245	13845	PDTINTCOM	2010-12-02 00:00:00	\N	2015-12-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2015-10-12 12:18:33	2017-11-08 16:01:39
15279	13882	CONSMUNI	\N	1995	2001-03-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2016-01-13 11:46:21	2016-01-13 11:46:41
15281	13883	VICPDTINTCOM	2001-03-18 00:00:00	\N	2016-01-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2016-01-13 11:47:53	2016-02-19 14:37:58
15282	13884	MAIRE	2015-12-21 00:00:00	\N	2020-01-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2016-01-13 18:39:12	2016-01-13 20:59:11
15293	13894	MAIRE	2016-01-01 00:00:00	\N	2017-09-28 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2016-06-10 11:24:28	2018-01-24 12:47:47
15483	14091	DEPUTE	1986-04-02 00:00:00	1986	1988-05-14 00:00:00	1988	ANCIEN	\N	\N	\N	NON	2016-12-12 17:36:38	2017-06-15 10:50:26
15484	14092	DEPUTE	1988-06-12 00:00:00	1988	1993-04-01 00:00:00	1993	ANCIEN	\N	\N	\N	NON	2016-12-12 17:37:10	2016-12-12 17:39:04
15489	14097	DEPUTE	1978-04-03 00:00:00	1978	1981-05-22 00:00:00	1981	ANCIEN	\N	\N	\N	NON	2016-12-13 09:51:30	2016-12-13 09:53:15
15490	14098	DEPUTE	1981-06-14 00:00:00	1981	1981-07-23 00:00:00	1981	ANCIEN	\N	\N	\N	NON	2016-12-13 09:52:19	2016-12-13 14:51:08
15491	14099	DEPUTE	1978-03-12 00:00:00	1978	1981-05-22 00:00:00	1981	ANCIEN	\N	\N	\N	NON	2016-12-13 09:54:47	2016-12-13 09:58:24
15492	14100	DEPUTE	1981-06-14 00:00:00	1981	1986-04-01 00:00:00	1986	ANCIEN	\N	\N	\N	NON	2016-12-13 09:55:11	2016-12-13 09:59:04
15493	14101	DEPUTE	1986-04-02 00:00:00	1986	1988-05-14 00:00:00	1988	ANCIEN	\N	\N	\N	NON	2016-12-13 09:55:31	2017-06-15 10:50:55
15494	14102	DEPUTE	1988-06-12 00:00:00	1988	1993-04-01 00:00:00	1993	ANCIEN	\N	\N	\N	NON	2016-12-13 09:55:54	2016-12-13 09:59:43
15495	14103	SECAN	1993-04-07 00:00:00	1993	1994-04-01 00:00:00	1997	ANCIEN	\N	\N	\N	NON	2016-12-13 09:56:27	2017-06-29 09:19:32
15496	14104	DEPUTE	1997-06-01 00:00:00	1997	2002-06-18 00:00:00	2002	ANCIEN	\N	\N	\N	NON	2016-12-13 09:56:50	2017-06-15 10:50:55
15497	14105	SECAN	2002-06-26 00:00:00	2002	2007-06-19 00:00:00	2007	ANCIEN	\N	\N	\N	NON	2016-12-13 09:57:14	2017-06-29 09:19:32
15498	14106	DEPUTE	2007-06-26 00:00:00	2007	2012-06-19 00:00:00	2012	ANCIEN	\N	\N	\N	NON	2016-12-13 09:57:41	2016-12-13 10:01:12
15508	14116	DEPUTE	1993-03-28 00:00:00	1993	1997-04-21 00:00:00	1997	ANCIEN	\N	\N	\N	NON	2016-12-13 10:40:39	2016-12-13 10:40:56
15500	14108	DEPUTE	1986-04-02 00:00:00	1986	1988-05-14 00:00:00	1988	ANCIEN	\N	\N	\N	NON	2016-12-13 10:02:58	2017-06-29 09:18:54
15501	14109	DEPUTE	1988-06-05 00:00:00	1988	1993-04-01 00:00:00	1993	ANCIEN	\N	\N	\N	NON	2016-12-13 10:03:26	2016-12-13 10:05:17
15502	14110	DEPUTE	1993-04-02 00:00:00	1993	1997-04-21 00:00:00	1997	ANCIEN	\N	\N	\N	NON	2016-12-13 10:03:55	2017-06-15 10:49:53
15503	14111	DEPUTE	1997-06-01 00:00:00	1997	2002-06-18 00:00:00	2002	ANCIEN	\N	\N	\N	NON	2016-12-13 10:04:15	2017-06-15 10:49:53
15504	14112	DEPUTE	1986-03-16 00:00:00	1986	1988-05-14 00:00:00	1988	ANCIEN	\N	\N	\N	NON	2016-12-13 10:09:04	2016-12-13 10:16:19
15505	14113	DEPUTE	1988-06-05 00:00:00	1988	1988-07-28 00:00:00	1988	ANCIEN	\N	\N	\N	NON	2016-12-13 10:13:37	2016-12-13 10:16:36
15506	14114	DEPUTE	1993-03-28 00:00:00	1993	1997-04-21 00:00:00	1997	ANCIEN	\N	\N	\N	NON	2016-12-13 10:13:56	2016-12-13 10:17:00
15507	14115	DEPUTE	1997-06-01 00:00:00	1997	1997-07-04 00:00:00	2002	ANCIEN	\N	\N	\N	NON	2016-12-13 10:14:24	2017-06-15 10:50:47
13853	14129	CONSMUNI	2016-12-06 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2017-01-11 16:25:14	2017-01-11 16:25:26
15509	14118	DEPUTE	1993-04-02 00:00:00	1993	1997-04-21 00:00:00	1997	ANCIEN	\N	\N	\N	NON	2016-12-13 10:45:57	2017-06-15 10:50:47
15510	14119	DEPUTE	1997-06-01 00:00:00	1997	2002-06-18 00:00:00	2002	ANCIEN	\N	\N	\N	NON	2016-12-13 10:46:22	2017-06-15 10:50:47
15458	14126	CONSMUNI	1989-03-01 00:00:00	\N	2008-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2016-12-16 12:10:58	2016-12-16 12:13:05
15522	14132	VICPDTINTCOM	2017-01-01 00:00:00	\N	2017-10-30 00:00:00	\N	ANCIEN	\N	Vice-présidente de la communauté d'agglomération de Saint-Louis Agglomération	\N	NON	2017-04-21 14:36:18	2017-11-06 16:29:42
15523	14133	PREPDTINTCOM	2017-01-01 00:00:00	\N	2017-10-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-04-21 14:45:25	2017-11-06 16:26:32
15524	14134	PDTINTCOM	2014-04-24 00:00:00	\N	2015-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-04-21 14:56:18	2017-04-21 15:00:09
15525	14135	PDTINTCOM	2016-01-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	2017-04-21 15:00:16	2017-04-21 15:01:26
15526	14136	CONSINTCOM	2017-01-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	2017-04-21 15:12:05	2017-04-21 15:12:59
15534	14143	PDTDPT	2015-04-02 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-05-17 11:39:41	2017-05-17 11:40:21
15535	14144	PREMADJOINT	2016-01-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-05-17 11:45:15	2017-05-17 11:46:57
15536	14145	PDTINTCOM	\N	2014	2016-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-05-17 11:47:07	2017-05-17 11:49:51
15543	14147	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:26	2017-06-15 10:48:15
15544	14148	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:26	2017-06-15 10:48:15
15545	14149	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:26	2017-06-15 10:48:15
15546	14150	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:26	2017-06-15 10:48:15
15547	14151	DEPUTE	1988-06-13 00:00:00	\N	1989-04-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:26	2017-06-15 10:48:15
15548	14152	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:29	2017-06-15 10:48:16
15549	14153	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:29	2017-06-15 10:48:16
15550	14154	SECAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:29	2017-06-29 03:42:21
15551	14155	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:29	2017-06-15 10:48:16
15552	14156	DEPUTE	2002-06-19 00:00:00	\N	2003-06-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:29	2017-06-15 10:48:16
15553	14157	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:29	2017-06-29 03:42:21
15554	14158	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:29	2017-06-29 03:42:21
15555	14159	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:29	2017-06-15 10:48:16
15556	14160	DEPUTE	1994-12-13 00:00:00	\N	1995-07-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:29	2017-06-15 10:48:16
15557	14161	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:29	2017-06-15 10:48:16
15558	14162	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:29	2017-06-15 10:48:16
15559	14163	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:29	2017-06-15 10:48:16
15560	14164	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:29	2017-06-15 10:48:16
15561	14165	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:29	2017-06-15 10:48:16
15950	14554	DEPUTE	1989-06-26 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:55	2017-06-15 10:48:32
15951	14555	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:56	2017-06-15 10:48:32
15952	14556	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:56	2017-06-15 10:48:32
15953	14557	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:56	2017-06-15 10:48:32
15954	14558	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:56	2017-06-15 10:48:32
15955	14559	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:56	2017-06-15 10:48:32
15956	14560	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:56	2017-06-15 10:48:32
15957	14561	DEPUTE	1986-09-30 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:56	2017-06-15 10:48:32
15958	14562	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:56	2017-06-15 10:48:32
15959	14563	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:56	2017-06-15 10:48:32
15960	14564	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:56	2017-06-15 10:48:32
15961	14565	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:56	2017-06-15 10:48:32
15962	14566	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:56	2017-06-15 10:48:32
15963	14567	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:56	2017-06-15 10:48:32
15964	14568	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:56	2017-06-15 10:48:32
15965	14569	DEPUTE	1994-03-13 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:56	2017-06-15 10:48:32
15966	14570	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:56	2017-06-15 10:48:32
15967	14571	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:56	2017-06-15 10:48:32
15968	14572	VICPDTAN	1995-05-31 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:56	2017-06-28 03:42:33
15969	14573	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:56	2017-06-28 03:42:33
15970	14574	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:57	2017-06-15 10:48:33
15971	14575	DEPUTE	1993-04-02 00:00:00	\N	1995-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:57	2017-06-29 09:18:09
15972	14576	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:57	2017-06-29 09:18:09
15973	14577	DEPUTE	2002-06-19 00:00:00	\N	2005-07-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:57	2017-06-29 09:18:09
15974	14578	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:57	2017-06-29 03:42:32
15975	14579	DEPUTE	2007-06-20 00:00:00	\N	2010-04-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:57	2017-06-29 03:42:32
15976	14580	DEPUTE	2012-06-20 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:57	2017-06-15 10:48:33
15977	14581	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:57	2017-06-29 09:18:09
15978	14582	DEPUTE	1997-06-12 00:00:00	\N	1999-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:57	2017-06-29 09:18:09
15979	14583	VICPDTAN	2003-10-01 00:00:00	\N	2005-07-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:57	2017-06-29 09:18:09
15980	14584	VICPDTAN	2002-06-26 00:00:00	\N	2003-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:57	2017-06-29 09:18:09
15981	14585	DEPUTE	1993-09-03 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:57	2017-06-15 10:48:33
15982	14586	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:57	2017-06-15 10:48:33
15983	14587	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:57	2017-06-15 10:48:33
15984	14588	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:57	2017-06-15 10:48:33
15985	14589	DEPUTE	1978-04-03 00:00:00	\N	1978-05-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:58	2017-06-15 10:48:33
15986	14590	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:58	2017-06-15 10:48:33
15987	14591	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:58	2017-06-15 10:48:33
15988	14592	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:58	2017-06-15 10:48:33
15989	14593	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:58	2017-06-15 10:48:33
15990	14594	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:58	2017-06-15 10:48:33
15991	14595	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:58	2017-06-15 10:48:33
15992	14596	DEPUTE	1978-04-03 00:00:00	\N	1978-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:58	2017-06-15 10:48:34
15993	14597	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:58	2017-06-15 10:48:34
15994	14598	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:58	2017-06-15 10:48:34
15995	14599	DEPUTE	1973-04-02 00:00:00	\N	1974-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:58	2017-06-15 10:48:34
15996	14600	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:58	2017-06-15 10:48:34
15997	14601	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:58	2017-06-15 10:48:34
15998	14602	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:58	2017-06-15 10:48:34
15999	14603	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:58	2017-06-15 10:48:34
16000	14604	DEPUTE	2002-06-19 00:00:00	\N	2004-05-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:58	2017-06-15 10:48:34
16001	14605	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:58	2017-06-15 10:48:34
16002	14606	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:58	2017-06-15 10:48:34
16003	14607	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:58	2017-06-15 10:48:34
16005	14609	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:58	2017-06-15 10:48:34
16006	14610	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:58	2017-06-15 10:48:34
16007	14611	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:58	2017-06-15 10:48:34
16008	14612	VICPDTAN	1992-04-02 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:58	2017-06-29 03:42:33
16010	14614	DEPUTE	1997-06-01 00:00:00	\N	1998-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:58	2017-06-15 10:48:34
16011	14615	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:58	2017-06-15 10:48:34
16012	14616	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:58	2017-06-15 10:48:34
16013	14617	PDTAN	2012-06-26 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:58	2017-06-29 09:18:10
16014	14618	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:58	2017-06-29 03:42:33
16015	14619	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:58	2017-06-29 09:18:10
16017	14621	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:59	2017-06-15 10:48:34
16018	14622	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:59	2017-06-15 10:48:34
16019	14623	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:59	2017-06-15 10:48:34
16020	14624	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:59	2017-06-15 10:48:34
16022	14626	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:59	2017-06-15 10:48:35
16023	14627	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:59	2017-06-15 10:48:35
16024	14628	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:59	2017-06-29 09:18:10
16025	14629	QUESTAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:59	2017-06-29 09:18:10
16027	14631	DEPUTE	1996-04-01 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:00	2017-06-15 10:48:35
16028	14632	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:00	2017-06-15 10:48:35
16029	14633	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:00	2017-06-15 10:48:35
16030	14634	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:00	2017-06-15 10:48:35
16032	14636	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:00	2017-06-15 10:48:35
16033	14637	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:00	2017-06-15 10:48:35
16034	14638	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:00	2017-06-15 10:48:35
16035	14639	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:00	2017-06-15 10:48:35
16037	14641	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:00	2017-06-15 10:48:35
16038	14642	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:00	2017-06-15 10:48:35
16039	14643	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:00	2017-06-15 10:48:35
16040	14644	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:00	2017-06-15 10:48:35
16042	14646	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:00	2017-06-15 10:48:35
16043	14647	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:00	2017-06-15 10:48:35
16044	14648	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:01	2017-06-15 10:48:35
16045	14649	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:01	2017-06-15 10:48:35
16046	14650	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:01	2017-06-15 10:48:35
16047	14651	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:01	2017-06-15 10:48:35
16048	14652	DEPUTE	1986-04-02 00:00:00	\N	1986-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:01	2017-06-29 03:42:33
16049	14653	DEPUTE	1986-10-24 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:01	2017-06-29 03:42:33
16050	14654	DEPUTE	1986-10-01 00:00:00	\N	1986-10-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:01	2017-06-29 09:18:11
16051	14655	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:01	2017-06-29 09:18:11
16052	14656	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:01	2017-06-15 10:48:36
16053	14657	DEPUTE	1993-04-02 00:00:00	\N	1994-05-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:01	2017-06-15 10:48:36
16054	14658	DEPUTE	1997-06-01 00:00:00	\N	2001-01-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:01	2017-06-15 10:48:36
16055	14659	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:01	2017-06-15 10:48:36
16056	14660	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:01	2017-06-15 10:48:36
16057	14661	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:01	2017-06-15 10:48:36
16058	14662	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:01	2017-06-15 10:48:36
16059	14663	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:01	2017-06-15 10:48:36
16060	14664	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:01	2017-06-15 10:48:36
16061	14665	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:01	2017-06-15 10:48:36
16062	14666	DEPUTE	1968-07-11 00:00:00	\N	1969-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:01	2017-06-15 10:48:36
16063	14667	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:01	2017-06-15 10:48:36
16064	14668	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:01	2017-06-15 10:48:36
16065	14669	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:01	2017-06-15 10:48:36
16066	14670	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:01	2017-06-15 10:48:36
16067	14671	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:01	2017-06-15 10:48:36
16068	14672	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:01	2017-06-15 10:48:36
16069	14673	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:01	2017-06-15 10:48:36
16070	14674	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:01	2017-06-15 10:48:36
16071	14675	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:02	2017-06-15 10:48:36
16072	14676	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:02	2017-06-15 10:48:36
16073	14677	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:02	2017-06-15 10:48:36
16074	14678	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:02	2017-06-15 10:48:36
16075	14679	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:02	2017-06-15 10:48:36
16076	14680	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:02	2017-06-15 10:48:37
16077	14681	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:02	2017-06-15 10:48:37
16078	14682	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:02	2017-06-15 10:48:37
29029	27626	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:47	\N
16079	14683	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:02	2017-06-15 10:48:37
16080	14684	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:02	2017-06-15 10:48:37
16081	14685	DEPUTE	1973-05-08 00:00:00	\N	1976-11-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:02	2017-06-15 10:48:37
16082	14686	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:02	2017-06-15 10:48:37
16083	14687	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:02	2017-06-15 10:48:37
16084	14688	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:02	2017-06-15 10:48:37
16085	14689	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:02	2017-06-19 09:36:49
16086	14690	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:03	2017-06-15 10:48:37
16087	14691	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:03	2017-06-15 10:48:37
16088	14692	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:03	2017-06-15 10:48:37
16089	14693	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:03	2017-06-15 10:48:37
16090	14694	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:03	2017-06-15 10:48:37
16091	14695	DEPUTE	1988-06-13 00:00:00	\N	1993-03-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:03	2017-06-15 10:48:37
16092	14696	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:03	2017-06-15 10:48:37
16093	14697	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:03	2017-06-15 10:48:37
16094	14698	DEPUTE	1998-09-27 00:00:00	\N	1999-02-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:03	2017-06-15 10:48:37
16095	14699	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:03	2017-06-15 10:48:37
16097	14701	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:04	2017-06-15 10:48:37
16098	14702	DEPUTE	1981-07-25 00:00:00	\N	1986-03-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:04	2017-06-15 10:48:38
16099	14703	DEPUTE	1981-07-02 00:00:00	\N	1983-01-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:04	2017-06-15 10:48:38
16100	14704	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:04	2017-06-15 10:48:38
16102	14706	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:05	2017-06-15 10:48:38
16103	14707	DEPUTE	1970-06-14 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:05	2017-06-15 10:48:38
16104	14708	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:05	2017-06-15 10:48:38
16105	14709	DEPUTE	1982-01-18 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:05	2017-06-29 09:18:12
16107	14711	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:05	2017-06-15 10:48:38
16108	14712	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:05	2017-06-15 10:48:38
16109	14713	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:05	2017-06-15 10:48:38
16111	14715	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:05	2017-06-15 10:48:38
16112	14716	DEPUTE	1988-06-06 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:05	2017-06-15 10:48:38
16113	14717	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:05	2017-06-15 10:48:38
16114	14718	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:05	2017-06-15 10:48:38
16115	14719	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:05	2017-06-15 10:48:38
16116	14720	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:06	2017-06-15 10:48:38
16118	14722	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:06	2017-06-15 10:48:38
16119	14723	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:06	2017-06-15 10:48:38
16120	14724	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:06	2017-06-15 10:48:38
16122	14726	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:06	2017-06-15 10:48:39
16123	14727	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:06	2017-06-15 10:48:39
16124	14728	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:07	2017-06-15 10:48:39
16125	14729	DEPUTE	1980-10-09 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:07	2017-06-15 10:48:39
16126	14730	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:07	2017-06-15 10:48:39
16128	14732	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:07	2017-06-15 10:48:39
16129	14733	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:07	2017-06-15 10:48:39
16130	14734	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:07	2017-06-15 10:48:39
16131	14735	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:07	2017-06-15 10:48:39
16133	14737	DEPUTE	1978-04-03 00:00:00	\N	1978-10-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:07	2017-06-15 10:48:39
16134	14738	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:07	2017-06-15 10:48:39
16135	14739	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:08	2017-06-15 10:48:39
16136	14740	DEPUTE	1992-05-03 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:08	2017-06-15 10:48:39
16140	14744	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:08	2017-06-15 10:48:39
16330	14934	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:23	2017-06-29 03:42:41
16331	14935	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:23	2017-06-29 03:42:41
16332	14936	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:23	2017-06-15 10:48:46
16333	14937	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:24	2017-06-15 10:48:47
16334	14938	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:24	2017-06-15 10:48:47
16335	14939	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:24	2017-06-15 10:48:47
16336	14940	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:24	2017-06-15 10:48:47
16337	14941	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:24	2017-06-19 09:36:55
16338	14942	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:24	2017-06-15 10:48:47
16339	14943	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:24	2017-06-15 10:48:47
16340	14944	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:24	2017-06-15 10:48:47
16341	14945	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:24	2017-06-15 10:48:47
16342	14946	QUESTAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:24	2017-06-28 03:42:42
16343	14947	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:24	2017-06-28 03:42:42
29105	27702	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:50	\N
16344	14948	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:24	2017-06-15 10:48:47
16345	14949	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:24	2017-06-15 10:48:47
16346	14950	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:24	2017-06-15 10:48:47
16347	14951	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:24	2017-06-15 10:48:47
16348	14952	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:24	2017-06-15 10:48:47
16349	14953	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:24	2017-06-15 10:48:47
16350	14954	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:24	2017-06-15 10:48:47
16351	14955	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:24	2017-06-15 10:48:47
16352	14956	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:24	2017-06-15 10:48:47
16353	14957	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:25	2017-06-15 10:48:47
16354	14958	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:25	2017-06-15 10:48:47
16355	14959	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:25	2017-06-15 10:48:47
16356	14960	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:25	2017-06-15 10:48:47
16357	14961	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:25	2017-06-15 10:48:47
16358	14962	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:25	2017-06-15 10:48:47
16359	14963	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:26	2017-06-15 10:48:48
16360	14964	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:26	2017-06-15 10:48:48
16361	14965	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:26	2017-06-15 10:48:48
16362	14966	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:26	2017-06-15 10:48:48
16363	14967	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:26	2017-06-15 10:48:48
16364	14968	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:26	2017-06-19 09:36:55
16365	14969	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:26	2017-06-15 10:48:48
16366	14970	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:26	2017-06-15 10:48:48
16367	14971	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:26	2017-06-15 10:48:48
16368	14972	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:26	2017-06-15 10:48:48
16369	14973	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:26	2017-06-15 10:48:48
16370	14974	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:26	2017-06-15 10:48:48
16371	14975	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:26	2017-06-15 10:48:48
16372	14976	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:27	2017-06-15 10:48:48
16373	14977	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:27	2017-06-15 10:48:48
16374	14978	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:27	2017-06-15 10:48:48
16375	14979	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:27	2017-06-15 10:48:48
16376	14980	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:27	2017-06-15 10:48:48
16377	14981	DEPUTE	1986-09-30 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:27	2017-06-15 10:48:48
16378	14982	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:27	2017-06-15 10:48:48
16379	14983	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:27	2017-06-15 10:48:48
16380	14984	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:27	2017-06-15 10:48:48
16381	14985	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:27	2017-06-15 10:48:48
16382	14986	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:27	2017-06-15 10:48:48
16383	14987	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:27	2017-06-15 10:48:48
16384	14988	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:27	2017-06-19 09:36:56
16385	14989	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:28	2017-06-15 10:48:49
16386	14990	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:28	2017-06-15 10:48:49
16387	14991	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:28	2017-06-15 10:48:49
16388	14992	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:28	2017-06-15 10:48:49
16389	14993	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:28	2017-06-15 10:48:49
16390	14994	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:28	2017-06-15 10:48:49
16391	14995	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:28	2017-06-15 10:48:49
16392	14996	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:28	2017-06-15 10:48:49
16393	14997	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:28	2017-06-15 10:48:49
16394	14998	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:28	2017-06-15 10:48:49
16395	14999	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:28	2017-06-15 10:48:49
16396	15000	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:29	2017-06-15 10:48:49
16397	15001	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:29	2017-06-15 10:48:49
16398	15002	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:29	2017-06-15 10:48:49
16399	15003	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:29	2017-06-15 10:48:49
16400	15004	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:29	2017-06-15 10:48:49
16401	15005	DEPUTE	1997-06-01 00:00:00	\N	1999-03-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:29	2017-06-15 10:48:49
16402	15006	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:29	2017-06-15 10:48:49
16403	15007	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:29	2017-06-15 10:48:49
16404	15008	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:29	2017-06-15 10:48:49
16405	15009	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:29	2017-06-15 10:48:49
16406	15010	DEPUTE	1990-01-18 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:29	2017-06-15 10:48:49
16407	15011	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:29	2017-06-15 10:48:49
16408	15012	DEPUTE	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:30	2017-06-29 03:42:43
29106	27703	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:50	\N
16409	15013	DEPUTE	2002-06-19 00:00:00	\N	2002-12-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:30	2017-06-29 03:42:43
16410	15014	DEPUTE	2003-03-24 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:30	2017-06-29 03:42:43
16412	15016	DEPUTE	1997-06-12 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:30	2017-06-29 03:42:43
16421	15025	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:30	2017-06-15 10:48:50
16422	15026	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:30	2017-06-15 10:48:50
16424	15028	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:30	2017-06-15 10:48:50
16425	15029	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:30	2017-06-15 10:48:50
16426	15030	QUESTAN	2007-06-27 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:30	2017-06-29 09:18:19
16427	15031	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:30	2017-06-29 09:18:19
16428	15032	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:30	2017-06-29 09:18:19
16429	15033	QUESTAN	2012-06-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:30	2017-06-29 09:18:19
16431	15035	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:30	2017-06-15 10:48:50
16432	15036	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:30	2017-06-15 10:48:50
16433	15037	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:30	2017-06-15 10:48:50
16434	15038	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:30	2017-06-15 10:48:50
16435	15039	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:30	2017-06-15 10:48:50
16436	15040	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:30	2017-06-15 10:48:50
16437	15041	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:30	2017-06-15 10:48:50
16438	15042	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:30	2017-06-29 03:42:43
16439	15043	SECAN	1986-04-04 00:00:00	\N	1987-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:30	2017-06-29 03:42:43
16440	15044	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:30	2017-06-15 10:48:50
16441	15045	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:30	2017-06-15 10:48:50
16442	15046	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:31	2017-06-19 09:36:57
16443	15047	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:31	2017-06-15 10:48:51
16444	15048	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:31	2017-06-15 10:48:51
16445	15049	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:31	2017-06-15 10:48:51
16446	15050	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:31	2017-06-15 10:48:51
16447	15051	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:31	2017-06-15 10:48:51
16448	15052	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:31	2017-06-15 10:48:51
16449	15053	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:31	2017-06-15 10:48:51
16450	15054	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:31	2017-06-15 10:48:51
16451	15055	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:31	2017-06-15 10:48:51
16452	15056	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:31	2017-06-15 10:48:51
16453	15057	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:31	2017-06-15 10:48:51
16454	15058	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:31	2017-06-15 10:48:51
16455	15059	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:32	2017-06-15 10:48:51
16456	15060	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:32	2017-06-15 10:48:51
16457	15061	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:32	2017-06-15 10:48:51
16458	15062	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:32	2017-06-15 10:48:51
16459	15063	DEPUTE	2012-06-20 00:00:00	\N	2015-08-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:32	2017-06-15 10:48:51
16460	15064	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:32	2017-06-15 10:48:51
16461	15065	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:32	2017-06-15 10:48:51
16462	15066	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:32	2017-06-15 10:48:51
16463	15067	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:32	2017-06-15 10:48:51
16464	15068	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:32	2017-06-15 10:48:51
16465	15069	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:32	2017-06-15 10:48:52
16466	15070	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:32	2017-06-15 10:48:52
16467	15071	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:32	2017-06-28 03:42:45
16468	15072	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:32	2017-06-15 10:48:52
16469	15073	DEPUTE	1997-06-01 00:00:00	\N	2001-11-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:33	2017-06-29 03:42:44
16470	15074	SECAN	2002-06-26 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:33	2017-06-29 09:18:20
16471	15075	VICPDTAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:33	2017-06-28 03:42:45
16472	15076	QUESTAN	1997-06-13 00:00:00	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:33	2017-06-29 03:42:44
16473	15077	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:33	2017-06-29 09:18:20
16474	15078	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:33	2017-06-15 10:48:52
16475	15079	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:33	2017-06-15 10:48:52
16476	15080	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:33	2017-06-15 10:48:52
16477	15081	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:33	2017-06-19 09:36:58
16478	15082	DEPUTE	1997-05-17 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:33	2017-06-15 10:48:52
16479	15083	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:33	2017-06-15 10:48:52
16480	15084	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:33	2017-06-15 10:48:52
16481	15085	DEPUTE	1995-06-26 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:33	2017-06-15 10:48:52
16482	15086	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:33	2017-06-15 10:48:52
16483	15087	VICPDTAN	2004-05-05 00:00:00	\N	2005-07-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:33	2017-06-29 09:18:20
16484	15088	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:33	2017-06-15 10:48:52
16485	15089	VICPDTAN	2005-07-04 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:33	2017-06-29 09:18:20
16486	15090	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:33	2017-06-29 03:42:44
16487	15091	DEPUTE	1992-07-04 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:33	2017-06-15 10:48:52
16488	15092	DEPUTE	1998-08-11 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:33	2017-06-15 10:48:52
16489	15093	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:33	2017-06-19 09:36:58
16490	15094	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:34	2017-06-15 10:48:52
16491	15095	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:34	2017-06-15 10:48:52
16492	15096	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:34	2017-06-15 10:48:52
16493	15097	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:34	2017-06-15 10:48:52
16494	15098	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:34	2017-06-29 09:18:20
16495	15099	DEPUTE	2010-12-14 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:34	2017-06-29 09:18:20
16496	15100	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:34	2017-06-19 09:36:58
16497	15101	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:34	2017-06-15 10:48:52
16498	15102	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:34	2017-06-15 10:48:53
16499	15103	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:34	2017-06-15 10:48:53
16500	15104	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:34	2017-06-15 10:48:53
16501	15105	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:34	2017-06-15 10:48:53
16502	15106	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:34	2017-06-15 10:48:53
16503	15107	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:34	2017-06-15 10:48:53
16505	15109	DEPUTE	2002-06-19 00:00:00	\N	2004-01-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:34	2017-06-15 10:48:53
16506	15110	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:35	2017-06-15 10:48:53
16507	15111	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:35	2017-06-15 10:48:53
16508	15112	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:35	2017-06-15 10:48:53
16509	15113	DEPUTE	1987-05-15 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:35	2017-06-15 10:48:53
16510	15114	DEPUTE	1988-06-13 00:00:00	\N	1993-03-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:35	2017-06-15 10:48:53
16511	15115	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:35	2017-06-15 10:48:53
16512	15116	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:35	2017-06-15 10:48:53
16513	15117	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:35	2017-06-28 03:42:44
16514	15118	DEPUTE	2013-04-20 00:00:00	\N	2013-04-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:35	2017-06-28 03:42:44
16515	15119	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:35	2017-06-15 10:48:53
16517	15121	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:35	2017-06-15 10:48:53
16518	15122	DEPUTE	1989-04-30 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:35	2017-06-15 10:48:53
16519	15123	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:35	2017-06-15 10:48:53
16520	15124	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:35	2017-06-15 10:48:53
16521	15125	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:35	2017-06-15 10:48:53
16522	15126	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:36	2017-06-15 10:48:53
16523	15127	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:36	2017-06-15 10:48:53
16141	14745	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:08	2017-06-15 10:48:39
16142	14746	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:08	2017-06-15 10:48:39
16143	14747	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:09	2017-06-15 10:48:40
16144	14748	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:09	2017-06-15 10:48:40
16145	14749	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:09	2017-06-15 10:48:40
16146	14750	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:09	2017-06-15 10:48:40
16147	14751	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:09	2017-06-15 10:48:40
16148	14752	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:09	2017-06-15 10:48:40
16149	14753	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:09	2017-06-15 10:48:40
16150	14754	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:09	2017-06-15 10:48:40
16151	14755	DEPUTE	1993-05-02 00:00:00	\N	1995-09-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:09	2017-06-15 10:48:40
16152	14756	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:09	2017-06-15 10:48:40
16153	14757	DEPUTE	1993-05-02 00:00:00	\N	1995-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:09	2017-06-15 10:48:40
16154	14758	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:09	2017-06-15 10:48:40
16155	14759	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:09	2017-06-15 10:48:40
16156	14760	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:09	2017-06-15 10:48:40
16157	14761	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:09	2017-06-15 10:48:40
16158	14762	DEPUTE	1995-09-18 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:09	2017-06-15 10:48:40
16159	14763	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:10	2017-06-15 10:48:40
16160	14764	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:10	2017-06-15 10:48:40
16161	14765	DEPUTE	2007-06-20 00:00:00	\N	2012-03-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:10	2017-06-15 10:48:40
16162	14766	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:10	2017-06-15 10:48:40
16163	14767	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:10	2017-06-15 10:48:40
16164	14768	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:10	2017-06-15 10:48:40
16165	14769	DEPUTE	1976-04-09 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:10	2017-06-15 10:48:40
16166	14770	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:10	2017-06-15 10:48:40
16167	14771	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:10	2017-06-15 10:48:40
16168	14772	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:10	2017-06-15 10:48:40
29107	27704	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:50	\N
16169	14773	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:10	2017-06-15 10:48:40
16170	14774	DEPUTE	1988-06-06 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:10	2017-06-15 10:48:40
16171	14775	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:11	2017-06-15 10:48:40
16172	14776	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:11	2017-06-15 10:48:41
16173	14777	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:11	2017-06-15 10:48:41
16174	14778	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:11	2017-06-15 10:48:41
16175	14779	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:11	2017-06-15 10:48:41
16176	14780	DEPUTE	1997-06-01 00:00:00	\N	1999-12-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:11	2017-06-15 10:48:41
16177	14781	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:11	2017-06-15 10:48:41
16178	14782	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:11	2017-06-15 10:48:41
16179	14783	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:11	2017-06-15 10:48:41
16180	14784	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:11	2017-06-15 10:48:41
16181	14785	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:11	2017-06-15 10:48:41
16182	14786	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:11	2017-06-15 10:48:41
16183	14787	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:11	2017-06-15 10:48:41
16184	14788	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:11	2017-06-15 10:48:41
16185	14789	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:11	2017-06-15 10:48:41
16186	14790	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:11	2017-06-15 10:48:41
16188	14792	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:12	2017-06-15 10:48:41
16189	14793	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:12	2017-06-15 10:48:41
16190	14794	DEPUTE	2007-07-20 00:00:00	\N	2010-12-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:12	2017-06-15 10:48:41
16191	14795	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:12	2017-06-15 10:48:41
16192	14796	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:12	2017-06-15 10:48:41
16194	14798	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:12	2017-06-15 10:48:41
16195	14799	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:13	2017-06-15 10:48:42
16196	14800	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:13	2017-06-15 10:48:42
16197	14801	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:13	2017-06-15 10:48:42
16198	14802	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:13	2017-06-15 10:48:42
16199	14803	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:13	2017-06-15 10:48:42
16200	14804	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:13	2017-06-15 10:48:42
16201	14805	DEPUTE	1995-06-09 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:13	2017-06-15 10:48:42
16202	14806	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:13	2017-06-15 10:48:42
16203	14807	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:13	2017-06-15 10:48:42
16204	14808	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:14	2017-06-15 10:48:42
16205	14809	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:14	2017-06-29 09:18:14
16206	14810	DEPUTE	2004-12-07 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:14	2017-06-29 09:18:15
16207	14811	DEPUTE	2007-06-20 00:00:00	\N	2009-04-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:14	2017-06-15 10:48:42
16208	14812	DEPUTE	1983-04-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:14	2017-06-15 10:48:42
16209	14813	DEPUTE	1976-11-14 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:14	2017-06-27 03:42:35
16210	14814	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:14	2017-06-15 10:48:42
16211	14815	DEPUTE	1967-04-03 00:00:00	\N	1967-05-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:14	2017-06-15 10:48:42
16212	14816	DEPUTE	1968-07-11 00:00:00	\N	1968-08-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:14	2017-06-15 10:48:42
16213	14817	DEPUTE	1973-04-02 00:00:00	\N	1973-05-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:14	2017-06-27 03:42:35
16214	14818	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:14	2017-06-15 10:48:42
16215	14819	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:14	2017-06-15 10:48:42
16216	14820	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:14	2017-06-15 10:48:42
16217	14821	DEPUTE	1993-04-02 00:00:00	\N	1995-05-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:14	2017-06-15 10:48:42
16218	14822	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:14	2017-06-15 10:48:42
16219	14823	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:14	2017-06-15 10:48:42
16220	14824	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:14	2017-06-15 10:48:42
16221	14825	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:15	2017-06-15 10:48:42
16222	14826	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:15	2017-06-15 10:48:42
16223	14827	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:15	2017-06-15 10:48:42
16224	14828	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:15	2017-06-15 10:48:43
16225	14829	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:15	2017-06-15 10:48:43
16226	14830	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:15	2017-06-15 10:48:43
16227	14831	DEPUTE	2007-06-20 00:00:00	\N	2011-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:15	2017-06-15 10:48:43
16228	14832	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:15	2017-06-15 10:48:43
16229	14833	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:15	2017-06-15 10:48:43
16230	14834	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:15	2017-06-15 10:48:43
16231	14835	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:15	2017-06-15 10:48:43
16233	14837	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:16	2017-06-15 10:48:43
16234	14838	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:16	2017-06-15 10:48:43
16235	14839	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:16	2017-06-15 10:48:43
16236	14840	DEPUTE	1986-04-18 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:16	2017-06-15 10:48:43
29108	27705	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:50	\N
16237	14841	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:16	2017-06-15 10:48:43
16238	14842	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:16	2017-06-15 10:48:43
16239	14843	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:16	2017-06-15 10:48:43
16240	14844	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:16	2017-06-15 10:48:43
16241	14845	VICPDTAN	1989-04-03 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:16	2017-06-29 09:18:15
16242	14846	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:16	2017-06-29 03:42:38
16243	14847	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:16	2017-06-29 03:42:38
16244	14848	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:16	2017-06-15 10:48:43
16245	14849	DEPUTE	2002-06-19 00:00:00	\N	2005-07-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:16	2017-06-15 10:48:43
16246	14850	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:16	2017-06-15 10:48:43
16247	14851	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:16	2017-06-29 09:18:15
16248	14852	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:17	2017-06-15 10:48:44
16249	14853	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:17	2017-06-29 03:42:39
16250	14854	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:17	2017-06-15 10:48:44
16251	14855	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:17	2017-06-29 09:18:15
16252	14856	SECAN	2005-10-04 00:00:00	\N	2006-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:17	2017-06-29 09:18:15
16253	14857	SECAN	2002-06-26 00:00:00	\N	2003-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:17	2017-06-29 09:18:15
16254	14858	QUESTAN	2016-09-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:17	2017-06-29 09:18:15
16255	14859	QUESTAN	2012-06-27 00:00:00	\N	2016-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:17	2017-06-29 09:18:15
16256	14860	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:17	2017-06-15 10:48:44
16257	14861	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:17	2017-06-15 10:48:44
16258	14862	DEPUTE	1968-07-11 00:00:00	\N	1969-09-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:17	2017-06-15 10:48:44
16259	14863	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:17	2017-06-15 10:48:44
16260	14864	VICPDTAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:17	2017-06-29 09:18:15
16261	14865	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:17	2017-06-15 10:48:44
16262	14866	DEPUTE	2007-06-20 00:00:00	\N	2011-12-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:17	2017-06-15 10:48:44
16263	14867	VICPDTAN	2000-10-02 00:00:00	\N	2001-08-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:17	2017-06-29 09:18:15
16264	14868	DEPUTE	1997-06-01 00:00:00	\N	2001-08-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:17	2017-06-29 09:18:15
16265	14869	VICPDTAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:17	2017-06-29 09:18:15
16266	14870	VICPDTAN	1997-06-12 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:17	2017-06-29 03:42:39
16267	14871	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:18	2017-06-15 10:48:44
16268	14872	DEPUTE	2001-01-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:18	2017-06-15 10:48:44
16269	14873	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:18	2017-06-15 10:48:44
16270	14874	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:18	2017-06-15 10:48:44
16271	14875	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:18	2017-06-15 10:48:44
16272	14876	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:18	2017-06-15 10:48:44
16273	14877	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:18	2017-06-29 03:42:39
16274	14878	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:18	2017-06-28 03:42:40
16275	14879	VICPDTAN	1988-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:18	2017-06-29 03:42:39
16276	14880	VICPDTAN	1988-06-24 00:00:00	\N	1991-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:18	2017-06-28 03:42:40
16278	14882	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:19	2017-06-15 10:48:44
16279	14883	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:19	2017-06-15 10:48:44
16280	14884	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:19	2017-06-15 10:48:44
16281	14885	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:19	2017-06-15 10:48:45
16282	14886	DEPUTE	1968-07-11 00:00:00	\N	1971-02-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:19	2017-06-15 10:48:45
16283	14887	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:19	2017-06-15 10:48:45
16284	14888	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:19	2017-06-15 10:48:45
16285	14889	DEPUTE	1978-04-03 00:00:00	\N	1978-11-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:19	2017-06-15 10:48:45
16286	14890	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:19	2017-06-15 10:48:45
16287	14891	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:19	2017-06-29 09:18:16
16288	14892	QUESTAN	1988-06-24 00:00:00	\N	1990-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:19	2017-06-29 09:18:16
16289	14893	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:19	2017-06-15 10:48:45
16290	14894	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:19	2017-06-15 10:48:45
16291	14895	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:19	2017-06-15 10:48:45
16292	14896	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:19	2017-06-15 10:48:45
16293	14897	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:19	2017-06-15 10:48:45
16294	14898	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:20	2017-06-15 10:48:45
16295	14899	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:20	2017-06-15 10:48:45
16296	14900	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:20	2017-06-15 10:48:45
16297	14901	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:20	2017-06-15 10:48:45
16298	14902	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:20	2017-06-29 09:18:16
16299	14903	VICPDTAN	1996-10-01 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:20	2017-06-29 09:18:16
16300	14904	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:20	2017-06-15 10:48:45
16301	14905	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:20	2017-06-15 10:48:45
16302	14906	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:21	2017-06-15 10:48:45
16303	14907	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:21	2017-06-15 10:48:45
16304	14908	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:21	2017-06-15 10:48:46
16305	14909	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:21	2017-06-15 10:48:46
16306	14910	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:21	2017-06-15 10:48:46
16307	14911	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:21	2017-06-15 10:48:46
16308	14912	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:21	2017-06-15 10:48:46
16309	14913	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:21	2017-06-15 10:48:46
16310	14914	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:21	2017-06-15 10:48:46
16312	14916	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:21	2017-06-15 10:48:46
16313	14917	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:21	2017-06-15 10:48:46
16314	14918	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:21	2017-06-15 10:48:46
16315	14919	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:22	2017-06-15 10:48:46
16316	14920	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:22	2017-06-15 10:48:46
16317	14921	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:22	2017-06-15 10:48:46
16319	14923	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:22	2017-06-15 10:48:46
16320	14924	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:22	2017-06-15 10:48:46
16321	14925	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:22	2017-06-15 10:48:46
16322	14926	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:22	2017-06-29 09:18:17
16323	14927	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:22	2017-06-15 10:48:46
16324	14928	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:22	2017-06-15 10:48:46
16325	14929	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:22	2017-06-19 09:36:54
16327	14931	DEPUTE	1968-07-11 00:00:00	\N	1972-04-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:23	2017-06-15 10:48:46
16328	14932	DEPUTE	1981-07-02 00:00:00	\N	1983-11-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:23	2017-06-15 10:48:46
16329	14933	SECAN	1994-04-02 00:00:00	\N	1995-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:23	2017-06-29 03:42:41
15760	14364	SECAN	2004-05-24 00:00:00	\N	2005-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:45	2017-06-29 09:18:04
15761	14365	SECAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:45	2017-06-29 09:18:04
15762	14366	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:45	2017-06-29 03:42:27
15763	14367	DEPUTE	1997-05-25 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:45	2017-06-29 09:18:04
15764	14368	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:45	2017-06-29 09:18:04
15765	14369	SECAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:45	2017-06-29 09:18:04
15766	14370	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:45	2017-06-29 03:42:27
15767	14371	DEPUTE	2002-06-19 00:00:00	\N	2006-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:45	2017-06-29 09:18:04
15768	14372	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:45	2017-06-15 10:48:25
15769	14373	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:46	2017-06-15 10:48:25
15770	14374	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:46	2017-06-15 10:48:25
15771	14375	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:46	2017-06-15 10:48:25
15772	14376	DEPUTE	2012-06-20 00:00:00	\N	2016-12-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:46	2017-06-15 10:48:25
15773	14377	DEPUTE	1995-01-22 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:46	2017-06-15 10:48:25
15774	14378	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:46	2017-06-15 10:48:25
15775	14379	DEPUTE	1991-06-17 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:46	2017-06-15 10:48:25
15776	14380	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:46	2017-06-15 10:48:25
15777	14381	DEPUTE	1997-06-01 00:00:00	\N	2001-11-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:46	2017-06-15 10:48:25
15778	14382	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:47	2017-06-15 10:48:25
15779	14383	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:47	2017-06-15 10:48:25
15780	14384	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:47	2017-06-15 10:48:25
15781	14385	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:47	2017-06-15 10:48:25
15782	14386	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:47	2017-06-15 10:48:25
15783	14387	DEPUTE	1988-06-13 00:00:00	\N	1990-09-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:47	2017-06-15 10:48:25
15784	14388	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:47	2017-06-15 10:48:25
15785	14389	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:48	2017-06-15 10:48:26
15786	14390	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:48	2017-06-15 10:48:26
15787	14391	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:48	2017-06-15 10:48:26
15788	14392	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:48	2017-06-15 10:48:26
15789	14393	DEPUTE	1973-04-02 00:00:00	\N	1974-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:48	2017-06-15 10:48:26
15790	14394	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:48	2017-06-15 10:48:26
15791	14395	DEPUTE	1986-04-02 00:00:00	\N	1987-05-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:48	2017-06-15 10:48:26
15792	14396	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:48	2017-06-15 10:48:26
15793	14397	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:48	2017-06-15 10:48:26
15794	14398	DEPUTE	2001-08-11 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:49	2017-06-15 10:48:26
15795	14399	DEPUTE	1992-06-23 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:49	2017-06-15 10:48:26
15796	14400	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:49	2017-06-15 10:48:26
15797	14401	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:49	2017-06-15 10:48:26
15798	14402	DEPUTE	1986-04-02 00:00:00	\N	1986-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:49	2017-06-15 10:48:26
15799	14403	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:49	2017-06-15 10:48:26
15800	14404	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:49	2017-06-15 10:48:26
29109	27706	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:50	\N
15801	14405	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:50	2017-06-15 10:48:26
15802	14406	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:50	2017-06-15 10:48:27
15803	14407	DEPUTE	1981-01-27 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:50	2017-06-15 10:48:27
15804	14408	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:50	2017-06-15 10:48:27
15805	14409	DEPUTE	1988-06-13 00:00:00	\N	1988-11-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:50	2017-06-28 03:42:30
15806	14410	DEPUTE	1989-02-01 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:50	2017-06-28 03:42:30
15807	14411	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:50	2017-06-15 10:48:27
15808	14412	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:50	2017-06-15 10:48:27
15809	14413	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:50	2017-06-15 10:48:27
15811	14415	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:50	2017-06-19 09:36:44
15812	14416	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:50	2017-06-15 10:48:27
15813	14417	DEPUTE	1995-10-18 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:50	2017-06-15 10:48:27
15814	14418	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:51	2017-06-15 10:48:27
15815	14419	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:51	2017-06-15 10:48:27
15817	14421	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:51	2017-06-15 10:48:27
15818	14422	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:51	2017-06-15 10:48:27
15819	14423	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:51	2017-06-15 10:48:27
15820	14424	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:51	2017-06-15 10:48:27
15823	14427	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:51	2017-06-15 10:48:27
15824	14428	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:51	2017-06-15 10:48:27
15825	14429	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:51	2017-06-15 10:48:27
15826	14430	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:51	2017-06-15 10:48:27
15828	14432	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:51	2017-06-29 03:42:29
15829	14433	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:51	2017-06-15 10:48:27
15830	14434	VICPDTAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:51	2017-06-29 03:42:29
15831	14435	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:52	2017-06-29 09:18:06
15833	14437	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:52	2017-06-15 10:48:28
15834	14438	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:52	2017-06-15 10:48:28
15835	14439	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:52	2017-06-15 10:48:28
15836	14440	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:52	2017-06-15 10:48:28
15838	14442	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:52	2017-06-15 10:48:28
15839	14443	DEPUTE	1993-04-02 00:00:00	\N	1995-06-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:52	2017-06-15 10:48:28
15840	14444	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:52	2017-06-15 10:48:28
15841	14445	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:52	2017-06-15 10:48:28
15843	14447	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:52	2017-06-15 10:48:28
15844	14448	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:52	2017-06-15 10:48:28
15845	14449	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:52	2017-06-15 10:48:28
15846	14450	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:52	2017-06-15 10:48:28
15847	14451	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:52	2017-06-15 10:48:28
15849	14453	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:52	2017-06-15 10:48:28
15850	14454	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:52	2017-06-19 09:36:45
15851	14455	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:52	2017-06-15 10:48:28
15852	14456	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:52	2017-06-15 10:48:28
15854	14458	DEPUTE	1986-04-02 00:00:00	\N	1986-04-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:52	2017-06-15 10:48:28
15855	14459	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:52	2017-06-15 10:48:28
15856	14460	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:52	2017-06-15 10:48:28
15857	14461	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:52	2017-06-15 10:48:28
15858	14462	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:52	2017-06-15 10:48:28
15859	14463	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:52	2017-06-15 10:48:28
15860	14464	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:52	2017-06-15 10:48:28
15861	14465	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:52	2017-06-15 10:48:28
15862	14466	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:52	2017-06-15 10:48:28
15863	14467	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:52	2017-06-15 10:48:28
15864	14468	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:53	2017-06-15 10:48:29
15865	14469	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:53	2017-06-15 10:48:29
15866	14470	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:53	2017-06-15 10:48:29
15867	14471	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:53	2017-06-15 10:48:29
15868	14472	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:53	2017-06-15 10:48:29
15869	14473	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:53	2017-06-15 10:48:29
15870	14474	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:53	2017-06-15 10:48:29
15871	14475	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:53	2017-06-15 10:48:29
15872	14476	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:53	2017-06-15 10:48:29
15873	14477	DEPUTE	1978-10-01 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:53	2017-06-15 10:48:29
15874	14478	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:53	2017-06-15 10:48:29
15875	14479	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:53	2017-06-15 10:48:29
29186	27783	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:52	\N
15876	14480	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:53	2017-06-15 10:48:29
15877	14481	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:53	2017-06-15 10:48:29
15878	14482	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:53	2017-06-15 10:48:29
15879	14483	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:53	2017-06-15 10:48:29
15880	14484	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:53	2017-06-15 10:48:29
15881	14485	DEPUTE	2007-06-20 00:00:00	\N	2012-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:53	2017-06-15 10:48:29
15882	14486	DEPUTE	2012-06-20 00:00:00	\N	2012-07-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:53	2017-06-28 03:42:31
15883	14487	DEPUTE	2014-05-01 00:00:00	\N	2016-03-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:53	2017-06-28 03:42:31
15884	14488	DEPUTE	1983-02-28 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:53	2017-06-15 10:48:29
15885	14489	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:53	2017-06-15 10:48:29
15886	14490	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:53	2017-06-15 10:48:29
15887	14491	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:53	2017-06-15 10:48:29
15888	14492	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:53	2017-06-28 03:42:31
15889	14493	SECAN	1987-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:53	2017-06-28 03:42:31
15890	14494	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:54	2017-06-15 10:48:30
15891	14495	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:54	2017-06-15 10:48:30
15892	14496	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:54	2017-06-15 10:48:30
15893	14497	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:54	2017-06-15 10:48:30
15894	14498	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:54	2017-06-15 10:48:30
15895	14499	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:54	2017-06-15 10:48:30
15896	14500	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:54	2017-06-15 10:48:30
15897	14501	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:54	2017-06-15 10:48:30
15898	14502	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:54	2017-06-29 09:18:07
15899	14503	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:54	2017-06-19 09:36:45
15900	14504	SECAN	2007-06-27 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:54	2017-06-29 09:18:07
15901	14505	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:54	2017-06-15 10:48:30
15902	14506	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:54	2017-06-15 10:48:30
15903	14507	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:54	2017-06-15 10:48:30
15904	14508	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:54	2017-06-15 10:48:30
15905	14509	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:54	2017-06-15 10:48:30
15906	14510	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:54	2017-06-19 09:36:45
15907	14511	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:54	2017-06-15 10:48:30
15908	14512	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:54	2017-06-15 10:48:30
15909	14513	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:54	2017-06-15 10:48:30
15910	14514	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:54	2017-06-15 10:48:30
15912	14516	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:54	2017-06-15 10:48:30
15913	14517	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:54	2017-06-15 10:48:30
15914	14518	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:54	2017-06-15 10:48:30
15915	14519	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:54	2017-06-15 10:48:30
15917	14521	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:54	2017-06-15 10:48:30
15918	14522	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:54	2017-06-15 10:48:30
15919	14523	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:54	2017-06-19 09:36:46
15921	14525	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:55	2017-06-15 10:48:31
15922	14526	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:55	2017-06-29 09:18:08
15923	14527	DEPUTE	1995-09-24 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:55	2017-06-29 09:18:08
15924	14528	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:55	2017-06-15 10:48:31
15925	14529	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:55	2017-06-15 10:48:31
15927	14531	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:55	2017-06-15 10:48:31
15928	14532	SECAN	1986-04-04 00:00:00	\N	1987-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:55	2017-06-29 09:18:08
15929	14533	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:55	2017-06-15 10:48:31
15930	14534	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:55	2017-06-15 10:48:31
15932	14536	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:55	2017-06-15 10:48:31
15933	14537	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:55	2017-06-29 09:18:08
15934	14538	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:55	2017-06-29 09:18:08
15935	14539	VICPDTAN	2010-10-05 00:00:00	\N	2011-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:55	2017-06-29 09:18:08
15936	14540	SECAN	2011-10-03 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:55	2017-06-29 09:18:08
15938	14542	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:55	2017-06-15 10:48:31
15939	14543	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:55	2017-06-15 10:48:31
15940	14544	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:55	2017-06-15 10:48:31
15941	14545	DEPUTE	1986-04-02 00:00:00	\N	1986-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:55	2017-06-29 03:42:31
15943	14547	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:55	2017-06-15 10:48:31
15944	14548	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:55	2017-06-15 10:48:31
15945	14549	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:55	2017-06-15 10:48:31
15946	14550	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:55	2017-06-15 10:48:32
15948	14552	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:55	2017-06-15 10:48:32
29187	27784	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:52	\N
15949	14553	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:55	2017-06-15 10:48:32
16619	15223	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:42	2017-06-15 10:48:57
16620	15224	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:42	2017-06-15 10:48:57
16621	15225	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:43	2017-06-15 10:48:57
16622	15226	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:43	2017-06-15 10:48:57
16623	15227	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:43	2017-06-15 10:48:57
16624	15228	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:43	2017-06-15 10:48:57
16625	15229	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:43	2017-06-15 10:48:57
16626	15230	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:43	2017-06-15 10:48:57
16627	15231	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:43	2017-06-15 10:48:57
16628	15232	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:43	2017-06-15 10:48:57
16629	15233	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:43	2017-06-15 10:48:57
16630	15234	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:43	2017-06-15 10:48:57
16631	15235	DEPUTE	1988-12-19 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:43	2017-06-15 10:48:57
16632	15236	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:43	2017-06-15 10:48:57
16633	15237	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:43	2017-06-15 10:48:57
16634	15238	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:43	2017-06-15 10:48:57
16635	15239	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:43	2017-06-15 10:48:57
16636	15240	DEPUTE	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:44	2017-06-29 09:18:23
16637	15241	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:44	2017-06-15 10:48:58
16638	15242	DEPUTE	2017-06-16 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:44	2017-06-29 09:18:23
16639	15243	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:44	2017-06-29 09:18:23
16640	15244	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:44	2017-06-15 10:48:58
16641	15245	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:44	2017-06-15 10:48:58
16642	15246	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:44	2017-06-15 10:48:58
16643	15247	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:44	2017-06-15 10:48:58
16644	15248	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:44	2017-06-15 10:48:58
16645	15249	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:44	2017-06-29 03:42:48
16646	15250	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:45	2017-06-29 09:18:24
16647	15251	QUESTAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:45	2017-06-29 03:42:48
16648	15252	DEPUTE	2007-06-20 00:00:00	\N	2010-06-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:45	2017-06-15 10:48:58
16649	15253	QUESTAN	1995-06-01 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:45	2017-06-29 03:42:48
16650	15254	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:45	2017-06-29 03:42:48
16651	15255	QUESTAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:45	2017-06-29 03:42:48
16652	15256	QUESTAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:45	2017-06-29 03:42:48
16653	15257	QUESTAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:45	2017-06-29 03:42:48
16654	15258	QUESTAN	2002-06-26 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:45	2017-06-29 09:18:24
16655	15259	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:45	2017-06-15 10:48:58
16656	15260	DEPUTE	1993-05-02 00:00:00	\N	1995-05-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:45	2017-06-15 10:48:58
16657	15261	DEPUTE	1981-07-02 00:00:00	\N	1981-12-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:45	2017-06-15 10:48:58
16658	15262	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:45	2017-06-15 10:48:58
16659	15263	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:45	2017-06-15 10:48:58
16660	15264	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:45	2017-06-15 10:48:58
16661	15265	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:45	2017-06-15 10:48:58
16662	15266	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:45	2017-06-15 10:48:58
16663	15267	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:46	2017-06-15 10:48:59
16664	15268	DEPUTE	1986-04-14 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:46	2017-06-15 10:48:59
16665	15269	DEPUTE	1996-03-26 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:46	2017-06-15 10:48:59
16666	15270	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:46	2017-06-15 10:48:59
16667	15271	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:46	2017-06-15 10:48:59
16668	15272	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:46	2017-06-15 10:48:59
16669	15273	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:46	2017-06-15 10:48:59
16670	15274	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:46	2017-06-15 10:48:59
16671	15275	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:46	2017-06-15 10:48:59
16672	15276	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:46	2017-06-15 10:48:59
16673	15277	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:47	2017-06-15 10:48:59
16674	15278	DEPUTE	1981-07-02 00:00:00	\N	1981-07-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:47	2017-06-15 10:48:59
16675	15279	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:47	2017-06-15 10:48:59
16676	15280	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:47	2017-06-15 10:48:59
16677	15281	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:47	2017-06-15 10:48:59
16679	15283	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:47	2017-06-15 10:48:59
16680	15284	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:47	2017-06-15 10:48:59
16681	15285	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:47	2017-06-15 10:48:59
16682	15286	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:47	2017-06-15 10:48:59
16683	15287	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:47	2017-06-15 10:48:59
29188	27785	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:52	\N
16684	15288	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:47	2017-06-15 10:48:59
16685	15289	DEPUTE	1986-04-02 00:00:00	\N	1986-04-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:47	2017-06-15 10:48:59
16686	15290	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:48	2017-06-15 10:49:00
16687	15291	DEPUTE	1988-09-19 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:48	2017-06-15 10:49:00
16688	15292	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:48	2017-06-15 10:49:00
16689	15293	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:48	2017-06-15 10:49:00
16690	15294	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:48	2017-06-19 09:37:03
16691	15295	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:48	2017-06-15 10:49:00
16692	15296	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:48	2017-06-15 10:49:00
16693	15297	DEPUTE	1981-07-24 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:48	2017-06-15 10:49:00
16705	15309	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:49	2017-06-15 10:49:00
16706	15310	DEPUTE	1990-08-18 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:49	2017-06-15 10:49:00
16707	15311	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:49	2017-06-15 10:49:00
16708	15312	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:49	2017-06-15 10:49:00
16709	15313	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:49	2017-06-15 10:49:00
16710	15314	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:49	2017-06-15 10:49:00
16711	15315	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:49	2017-06-15 10:49:00
16712	15316	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:49	2017-06-15 10:49:00
16714	15318	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:49	2017-06-19 09:37:04
16715	15319	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:49	2017-06-15 10:49:00
16716	15320	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:49	2017-06-15 10:49:01
16717	15321	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:49	2017-06-15 10:49:01
16718	15322	DEPUTE	1993-04-02 00:00:00	\N	1994-12-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:49	2017-06-15 10:49:01
16719	15323	DEPUTE	2004-06-28 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:49	2017-06-15 10:49:01
16720	15324	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:49	2017-06-15 10:49:01
16721	15325	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:49	2017-06-19 09:37:04
16723	15327	DEPUTE	1963-05-05 00:00:00	\N	1966-02-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:49	2017-06-15 10:49:01
16724	15328	DEPUTE	1967-04-03 00:00:00	\N	1967-05-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:50	2017-06-15 10:49:01
17007	15611	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:07	2017-06-15 10:49:11
17008	15612	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:07	2017-06-15 10:49:11
17009	15613	DEPUTE	2010-12-14 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:07	2017-06-29 03:42:57
17010	15614	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:07	2017-06-29 03:42:57
17011	15615	DEPUTE	2012-06-20 00:00:00	\N	2014-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:07	2017-06-15 10:49:11
17012	15616	SECAN	1995-04-03 00:00:00	\N	1996-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:07	2017-06-29 03:42:58
17013	15617	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:07	2017-06-15 10:49:11
17014	15618	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:07	2017-06-15 10:49:11
17016	15620	DEPUTE	1993-04-02 00:00:00	\N	1995-12-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:07	2017-06-29 09:18:31
17017	15621	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:07	2017-06-15 10:49:11
17018	15622	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:07	2017-06-15 10:49:11
17019	15623	DEPUTE	1968-07-11 00:00:00	\N	1971-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:07	2017-06-15 10:49:11
17020	15624	DEPUTE	2011-07-30 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:08	2017-06-15 10:49:11
17021	15625	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:08	2017-06-15 10:49:12
17022	15626	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:08	2017-06-15 10:49:12
17023	15627	DEPUTE	1995-09-25 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:08	2017-06-29 03:42:58
17024	15628	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:08	2017-06-29 03:42:58
17025	15629	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:08	2017-06-15 10:49:12
17026	15630	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:08	2017-06-15 10:49:12
17027	15631	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:08	2017-06-15 10:49:12
17028	15632	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:08	2017-06-15 10:49:12
17036	15640	SECAN	1985-04-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:09	2017-06-29 03:42:59
17037	15641	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:09	2017-06-15 10:49:12
17038	15642	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:09	2017-06-29 03:42:59
17039	15643	DEPUTE	1988-06-06 00:00:00	\N	1993-02-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:09	2017-06-15 10:49:12
17040	15644	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:09	2017-06-29 03:42:59
17041	15645	SECAN	1986-04-04 00:00:00	\N	1987-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:09	2017-06-29 03:42:59
17042	15646	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:09	2017-06-15 10:49:12
17043	15647	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:09	2017-06-15 10:49:12
17044	15648	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:09	2017-06-15 10:49:12
17045	15649	DEPUTE	1993-05-03 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:09	2017-06-15 10:49:12
17046	15650	DEPUTE	1973-04-02 00:00:00	\N	1976-09-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:09	2017-06-15 10:49:12
17047	15651	DEPUTE	1978-04-02 00:00:00	\N	1978-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:09	2017-06-15 10:49:12
17048	15652	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:09	2017-06-15 10:49:12
17049	15653	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:09	2017-06-15 10:49:12
17050	15654	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:10	2017-06-15 10:49:12
17051	15655	DEPUTE	1991-06-18 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:10	2017-06-15 10:49:12
29189	27786	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:52	\N
17052	15656	DEPUTE	1982-01-18 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:10	2017-06-15 10:49:13
17053	15657	SECAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:10	2017-06-29 09:18:32
17054	15658	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:10	2017-06-15 10:49:13
17055	15659	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:10	2017-06-15 10:49:13
17056	15660	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:10	2017-06-15 10:49:13
17057	15661	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:10	2017-06-15 10:49:13
17058	15662	DEPUTE	2009-07-23 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:10	2017-06-15 10:49:13
17059	15663	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:10	2017-06-29 09:18:32
17060	15664	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:10	2017-06-15 10:49:13
17061	15665	DEPUTE	2001-04-28 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:10	2017-06-15 10:49:13
17062	15666	DEPUTE	1982-06-15 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:10	2017-06-15 10:49:13
17063	15667	DEPUTE	1990-11-03 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:10	2017-06-15 10:49:13
17064	15668	DEPUTE	1968-07-11 00:00:00	\N	1970-05-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:10	2017-06-15 10:49:13
17065	15669	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:10	2017-06-15 10:49:13
17066	15670	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:10	2017-06-15 10:49:13
17067	15671	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:10	2017-06-15 10:49:13
17068	15672	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:10	2017-06-15 10:49:13
17069	15673	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:10	2017-06-15 10:49:13
17070	15674	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:10	2017-06-15 10:49:13
17071	15675	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:11	2017-06-15 10:49:13
17072	15676	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:11	2017-06-15 10:49:13
17073	15677	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:11	2017-06-15 10:49:13
17074	15678	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:11	2017-06-15 10:49:13
17075	15679	VICPDTAN	2009-10-06 00:00:00	\N	2010-10-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:11	2017-06-29 03:42:59
17076	15680	SECAN	2008-10-01 00:00:00	\N	2009-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:11	2017-06-29 09:18:32
17077	15681	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:11	2017-06-29 03:42:59
17078	15682	SECAN	2010-10-05 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:11	2017-06-29 09:18:32
17079	15683	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:11	2017-06-15 10:49:13
17080	15684	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:11	2017-06-15 10:49:13
17081	15685	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:11	2017-06-15 10:49:13
17082	15686	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:11	2017-06-15 10:49:13
17083	15687	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:11	2017-06-15 10:49:14
17084	15688	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:11	2017-06-15 10:49:14
17085	15689	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:11	2017-06-15 10:49:14
17086	15690	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:11	2017-06-15 10:49:14
17087	15691	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:11	2017-06-15 10:49:14
17088	15692	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:11	2017-06-29 03:42:59
17089	15693	DEPUTE	2009-07-24 00:00:00	\N	2009-07-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:11	2017-06-29 03:42:59
17090	15694	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:12	2017-06-15 10:49:14
17091	15695	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:12	2017-06-15 10:49:14
17092	15696	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:12	2017-06-29 09:18:32
17093	15697	SECAN	2007-06-27 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:12	2017-06-29 09:18:32
17095	15699	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:12	2017-06-29 09:18:32
17097	15701	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:12	2017-06-15 10:49:14
17098	15702	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:12	2017-06-15 10:49:14
17099	15703	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:12	2017-06-15 10:49:14
17100	15704	VICPDTAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:12	2017-06-29 03:42:59
17101	15705	VICPDTAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:12	2017-06-29 03:43:00
17102	15706	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:12	2017-06-15 10:49:14
17103	15707	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:12	2017-06-15 10:49:14
17105	15709	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:12	2017-06-29 03:42:59
17106	15710	VICPDTAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:12	2017-06-29 09:18:32
17107	15711	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:12	2017-06-29 09:18:32
17108	15712	DEPUTE	2007-06-26 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:12	2017-06-29 09:18:32
17109	15713	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:12	2017-06-15 10:49:14
17110	15714	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:12	2017-06-15 10:49:14
17111	15715	DEPUTE	1986-04-02 00:00:00	\N	1986-09-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:12	2017-06-15 10:49:14
17112	15716	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:12	2017-06-15 10:49:14
17113	15717	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:12	2017-06-15 10:49:14
17114	15718	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:13	2017-06-15 10:49:15
17115	15719	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:13	2017-06-15 10:49:15
17116	15720	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:13	2017-06-15 10:49:15
17117	15721	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:13	2017-06-15 10:49:15
17118	15722	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:13	2017-06-15 10:49:15
17119	15723	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:13	2017-06-15 10:49:15
17120	15724	DEPUTE	1978-04-03 00:00:00	\N	1981-04-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:13	2017-06-15 10:49:15
17121	15725	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:13	2017-06-15 10:49:15
17122	15726	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:13	2017-06-15 10:49:15
17123	15727	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:14	2017-06-15 10:49:15
17124	15728	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:14	2017-06-29 03:43:00
17125	15729	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:14	2017-06-15 10:49:15
17126	15730	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:14	2017-06-15 10:49:15
17127	15731	QUESTAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:14	2017-06-29 03:43:00
17128	15732	QUESTAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:14	2017-06-29 03:43:00
17129	15733	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:14	2017-06-15 10:49:15
17130	15734	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:14	2017-06-15 10:49:15
17131	15735	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:14	2017-06-15 10:49:15
17132	15736	DEPUTE	2002-06-19 00:00:00	\N	2003-02-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:14	2017-06-28 03:43:00
17133	15737	DEPUTE	2003-03-24 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:14	2017-06-28 03:43:00
17134	15738	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:14	2017-06-15 10:49:15
17135	15739	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:14	2017-06-15 10:49:15
17136	15740	DEPUTE	1988-06-13 00:00:00	\N	1991-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:14	2017-06-15 10:49:15
17137	15741	DEPUTE	1995-12-10 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:14	2017-06-15 10:49:15
17138	15742	DEPUTE	1997-06-01 00:00:00	\N	2000-09-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:14	2017-06-15 10:49:15
17139	15743	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:14	2017-06-15 10:49:15
17140	15744	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:15	2017-06-15 10:49:16
17141	15745	DEPUTE	2012-07-22 00:00:00	\N	2014-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:15	2017-06-15 10:49:16
17142	15746	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:15	2017-06-15 10:49:16
17143	15747	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:15	2017-06-15 10:49:16
17144	15748	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:15	2017-06-15 10:49:16
17145	15749	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:15	2017-06-15 10:49:16
17146	15750	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:15	2017-06-15 10:49:16
17147	15751	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:15	2017-06-15 10:49:16
17148	15752	DEPUTE	1973-04-03 00:00:00	\N	1973-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:15	2017-06-29 03:43:01
17149	15753	DEPUTE	1974-10-06 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:15	2017-06-29 03:43:01
17150	15754	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:15	2017-06-15 10:49:16
17151	15755	DEPUTE	1967-04-02 00:00:00	\N	1967-05-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:15	2017-06-15 10:49:16
17152	15756	DEPUTE	1968-07-11 00:00:00	\N	1968-08-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:15	2017-06-15 10:49:16
17153	15757	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:15	2017-06-15 10:49:16
17154	15758	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:15	2017-06-15 10:49:16
17155	15759	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:15	2017-06-15 10:49:16
17156	15760	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:15	2017-06-15 10:49:16
17157	15761	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:15	2017-06-15 10:49:16
17158	15762	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:15	2017-06-19 09:37:11
17159	15763	DEPUTE	1974-09-29 00:00:00	\N	1976-09-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:16	2017-06-29 09:18:33
17160	15764	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:16	2017-06-15 10:49:16
17161	15765	DEPUTE	1967-04-03 00:00:00	\N	1967-05-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:16	2017-06-15 10:49:16
17162	15766	DEPUTE	1968-07-11 00:00:00	\N	1968-08-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:16	2017-06-15 10:49:16
17163	15767	DEPUTE	1973-04-02 00:00:00	\N	1973-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:16	2017-06-29 09:18:33
17164	15768	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:16	2017-06-15 10:49:16
17165	15769	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:16	2017-06-15 10:49:16
17166	15770	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:16	2017-06-15 10:49:16
17167	15771	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:16	2017-06-15 10:49:16
17168	15772	DEPUTE	1986-09-20 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:16	2017-06-15 10:49:17
17170	15774	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:16	2017-06-15 10:49:17
17171	15775	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:16	2017-06-15 10:49:17
17172	15776	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:16	2017-06-15 10:49:17
17173	15777	DEPUTE	1981-07-02 00:00:00	\N	1983-07-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:16	2017-06-15 10:49:17
17174	15778	DEPUTE	1988-07-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:16	2017-06-15 10:49:17
17175	15779	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:17	2017-06-15 10:49:17
17176	15780	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:17	2017-06-15 10:49:17
17177	15781	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:17	2017-06-28 03:43:01
17178	15782	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:17	2017-06-19 09:37:12
17179	15783	VICPDTAN	2010-10-05 00:00:00	\N	2011-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:17	2017-06-28 03:43:01
17180	15784	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:17	2017-06-15 10:49:17
17181	15785	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:17	2017-06-15 10:49:17
17182	15786	DEPUTE	1997-06-01 00:00:00	\N	1997-10-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:17	2017-06-29 09:18:34
17183	15787	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:17	2017-06-15 10:49:17
17184	15788	DEPUTE	1997-12-15 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:17	2017-06-29 09:18:34
17185	15789	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:17	2017-06-15 10:49:17
29190	27787	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:52	\N
17186	15790	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:17	2017-06-15 10:49:17
17187	15791	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:17	2017-06-15 10:49:17
17188	15792	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:17	2017-06-15 10:49:17
17189	15793	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:17	2017-06-19 09:37:12
17190	15794	DEPUTE	1997-06-01 00:00:00	\N	2001-04-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:18	2017-06-15 10:49:17
17191	15795	VICPDTAN	2004-10-01 00:00:00	\N	2005-12-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:18	2017-06-29 09:18:34
17192	15796	VICPDTAN	2002-06-26 00:00:00	\N	2003-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:18	2017-06-29 03:43:01
17194	15798	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:18	2017-06-15 10:49:17
17195	15799	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:18	2017-06-15 10:49:17
17196	15800	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:18	2017-06-15 10:49:17
17197	15801	DEPUTE	1988-06-13 00:00:00	\N	1991-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:18	2017-06-15 10:49:17
17198	15802	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:18	2017-06-15 10:49:17
17199	15803	DEPUTE	1985-12-28 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:18	2017-06-15 10:49:18
17201	15805	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:18	2017-06-15 10:49:18
16725	15329	DEPUTE	1968-07-11 00:00:00	\N	1968-08-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:50	2017-06-15 10:49:01
16726	15330	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:50	2017-06-15 10:49:01
16727	15331	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:50	2017-06-15 10:49:01
16728	15332	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:50	2017-06-15 10:49:01
16729	15333	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:50	2017-06-15 10:49:01
16730	15334	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:50	2017-06-15 10:49:01
16731	15335	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:50	2017-06-15 10:49:01
16732	15336	PDTAN	2002-06-26 00:00:00	\N	2007-03-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:50	2017-06-29 03:42:50
16733	15337	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:50	2017-06-15 10:49:01
16734	15338	DEPUTE	2002-06-19 00:00:00	\N	2007-03-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:50	2017-06-29 03:42:50
16735	15339	DEPUTE	1988-01-25 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:50	2017-06-15 10:49:01
16736	15340	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:50	2017-06-15 10:49:01
16737	15341	DEPUTE	2002-12-16 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:50	2017-06-29 09:18:26
16738	15342	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:50	2017-06-15 10:49:01
16739	15343	DEPUTE	2002-06-19 00:00:00	\N	2002-10-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:50	2017-06-29 09:18:26
16740	15344	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:50	2017-06-15 10:49:01
16741	15345	DEPUTE	1984-01-19 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:50	2017-06-15 10:49:01
16742	15346	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:50	2017-06-15 10:49:02
16743	15347	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:50	2017-06-15 10:49:02
16744	15348	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:50	2017-06-15 10:49:02
16745	15349	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:50	2017-06-15 10:49:02
16746	15350	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:50	2017-06-15 10:49:02
16747	15351	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:50	2017-06-15 10:49:02
16748	15352	DEPUTE	1986-04-02 00:00:00	\N	1986-05-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:50	2017-06-15 10:49:02
16749	15353	DEPUTE	1999-03-29 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:50	2017-06-15 10:49:02
16750	15354	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:50	2017-06-29 03:42:50
16751	15355	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:50	2017-06-15 10:49:02
16752	15356	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:50	2017-06-19 09:37:04
16753	15357	SECAN	2004-10-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:50	2017-06-29 03:42:50
16754	15358	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:51	2017-06-15 10:49:02
16755	15359	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:51	2017-06-15 10:49:02
16756	15360	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:51	2017-06-15 10:49:02
16757	15361	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:51	2017-06-15 10:49:02
16758	15362	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:51	2017-06-15 10:49:02
16759	15363	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:51	2017-06-15 10:49:02
16760	15364	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:51	2017-06-15 10:49:02
16761	15365	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:51	2017-06-15 10:49:02
16762	15366	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:51	2017-06-15 10:49:02
16763	15367	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:51	2017-06-15 10:49:02
16764	15368	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:51	2017-06-19 09:37:04
16765	15369	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:51	2017-06-15 10:49:02
16766	15370	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:51	2017-06-19 09:37:04
16767	15371	DEPUTE	1976-11-18 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:51	2017-06-15 10:49:02
16768	15372	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:51	2017-06-15 10:49:02
16769	15373	DEPUTE	1986-04-18 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:51	2017-06-15 10:49:02
16770	15374	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:51	2017-06-15 10:49:02
16771	15375	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:51	2017-06-15 10:49:02
16772	15376	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:51	2017-06-15 10:49:02
16773	15377	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:51	2017-06-15 10:49:02
16774	15378	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:51	2017-06-15 10:49:02
16775	15379	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:51	2017-06-15 10:49:02
16776	15380	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:51	2017-06-15 10:49:02
16777	15381	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:51	2017-06-15 10:49:02
16778	15382	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:51	2017-06-15 10:49:02
16779	15383	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:51	2017-06-15 10:49:03
16780	15384	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:51	2017-06-15 10:49:03
16781	15385	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:51	2017-06-15 10:49:03
16782	15386	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:51	2017-06-15 10:49:03
16783	15387	DEPUTE	1997-06-01 00:00:00	\N	2001-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:51	2017-06-15 10:49:03
16784	15388	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:52	2017-06-15 10:49:03
16785	15389	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:52	2017-06-15 10:49:03
16786	15390	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:52	2017-06-15 10:49:03
16787	15391	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:52	2017-06-15 10:49:03
16788	15392	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:52	2017-06-15 10:49:03
16789	15393	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:52	2017-06-15 10:49:03
16790	15394	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:52	2017-06-15 10:49:03
16791	15395	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:52	2017-06-15 10:49:03
16792	15396	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:52	2017-06-15 10:49:03
16793	15397	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:52	2017-06-15 10:49:03
16794	15398	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:52	2017-06-15 10:49:03
16795	15399	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:52	2017-06-15 10:49:03
16796	15400	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:52	2017-06-15 10:49:03
16798	15402	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:52	2017-06-15 10:49:03
16799	15403	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:52	2017-06-15 10:49:03
16800	15404	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:52	2017-06-15 10:49:03
16801	15405	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:52	2017-06-15 10:49:03
16802	15406	DEPUTE	1997-06-01 00:00:00	\N	1998-07-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:53	2017-06-15 10:49:03
16803	15407	DEPUTE	2007-06-20 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:53	2017-06-15 10:49:03
16804	15408	DEPUTE	1975-10-03 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:53	2017-06-15 10:49:03
16805	15409	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:53	2017-06-15 10:49:03
16806	15410	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:53	2017-06-15 10:49:03
16807	15411	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:53	2017-06-15 10:49:03
16808	15412	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:53	2017-06-15 10:49:03
16809	15413	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:53	2017-06-15 10:49:04
16811	15415	DEPUTE	1978-05-06 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:53	2017-06-15 10:49:04
16812	15416	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:53	2017-06-15 10:49:04
16813	15417	DEPUTE	1986-04-02 00:00:00	\N	1988-01-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:53	2017-06-15 10:49:04
16814	15418	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:53	2017-06-15 10:49:04
16815	15419	DEPUTE	1981-07-02 00:00:00	\N	1986-02-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:54	2017-06-15 10:49:04
16816	15420	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:54	2017-06-15 10:49:04
16817	15421	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:54	2017-06-15 10:49:04
16819	15423	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:54	2017-06-15 10:49:04
16820	15424	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:54	2017-06-15 10:49:04
16821	15425	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:54	2017-06-15 10:49:04
16822	15426	DEPUTE	1994-09-13 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:54	2017-06-15 10:49:04
16823	15427	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:54	2017-06-15 10:49:04
16824	15428	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:54	2017-06-15 10:49:04
16825	15429	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:55	2017-06-15 10:49:04
16826	15430	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:55	2017-06-15 10:49:04
16827	15431	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:55	2017-06-15 10:49:04
16828	15432	DEPUTE	2008-12-01 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:55	2017-06-15 10:49:04
16829	15433	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:55	2017-06-15 10:49:04
16830	15434	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:55	2017-06-15 10:49:04
16831	15435	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:55	2017-06-15 10:49:04
16832	15436	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:55	2017-06-15 10:49:04
16833	15437	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:55	2017-06-15 10:49:04
16834	15438	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:55	2017-06-15 10:49:04
16835	15439	DEPUTE	2007-06-20 00:00:00	\N	2008-11-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:55	2017-06-15 10:49:04
16836	15440	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:56	2017-06-15 10:49:04
16837	15441	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:56	2017-06-15 10:49:05
16838	15442	DEPUTE	1993-04-02 00:00:00	\N	1995-09-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:56	2017-06-15 10:49:05
16839	15443	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:56	2017-06-15 10:49:05
16840	15444	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:56	2017-06-15 10:49:05
16841	15445	DEPUTE	1968-07-11 00:00:00	\N	1972-08-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:56	2017-06-15 10:49:05
16842	15446	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:56	2017-06-15 10:49:05
16843	15447	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:56	2017-06-15 10:49:05
29191	27788	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:52	\N
16844	15448	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:56	2017-06-15 10:49:05
16845	15449	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:56	2017-06-15 10:49:05
16846	15450	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:56	2017-06-15 10:49:05
16847	15451	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:56	2017-06-15 10:49:05
16848	15452	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:56	2017-06-15 10:49:05
16849	15453	DEPUTE	1978-04-03 00:00:00	\N	1978-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:56	2017-06-15 10:49:05
16850	15454	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:56	2017-06-15 10:49:05
16851	15455	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:56	2017-06-15 10:49:05
16852	15456	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:56	2017-06-15 10:49:05
16853	15457	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:56	2017-06-15 10:49:05
16854	15458	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:57	2017-06-15 10:49:05
16855	15459	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:57	2017-06-15 10:49:05
16856	15460	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:57	2017-06-15 10:49:05
16857	15461	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:57	2017-06-15 10:49:05
16858	15462	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:57	2017-06-15 10:49:05
16859	15463	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:57	2017-06-15 10:49:06
16860	15464	DEPUTE	1956-01-19 00:00:00	\N	1958-06-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:57	2017-06-29 09:18:28
16861	15465	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:57	2017-06-15 10:49:06
16862	15466	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:57	2017-06-15 10:49:06
16863	15467	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:57	2017-06-15 10:49:06
16865	15469	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:57	2017-06-15 10:49:06
16866	15470	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:57	2017-06-29 09:18:28
16867	15471	DEPUTE	1995-12-10 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:57	2017-06-15 10:49:06
16868	15472	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:58	2017-06-15 10:49:06
16869	15473	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:58	2017-06-15 10:49:06
16870	15474	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:58	2017-06-15 10:49:06
16871	15475	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:58	2017-06-15 10:49:06
16872	15476	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:58	2017-06-15 10:49:06
16873	15477	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:58	2017-06-15 10:49:06
16874	15478	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:58	2017-06-15 10:49:06
16875	15479	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:58	2017-06-15 10:49:06
16876	15480	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:58	2017-06-15 10:49:06
16877	15481	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:58	2017-06-15 10:49:06
16878	15482	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:58	2017-06-29 09:18:28
16879	15483	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:58	2017-06-15 10:49:06
16880	15484	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:58	2017-06-15 10:49:06
16881	15485	SECAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:58	2017-06-29 09:18:28
16882	15486	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:58	2017-06-29 03:42:52
16883	15487	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:58	2017-06-15 10:49:06
16884	15488	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:58	2017-06-15 10:49:06
16885	15489	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:58	2017-06-15 10:49:06
16886	15490	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:58	2017-06-15 10:49:06
16887	15491	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:58	2017-06-15 10:49:06
16888	15492	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:58	2017-06-29 09:18:28
16889	15493	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:58	2017-06-15 10:49:06
16890	15494	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:58	2017-06-29 09:18:28
16891	15495	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:58	2017-06-15 10:49:06
16892	15496	QUESTAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:58	2017-06-29 09:18:28
16893	15497	QUESTAN	1994-04-02 00:00:00	\N	1995-04-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:58	2017-06-29 09:18:28
16894	15498	QUESTAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:58	2017-06-29 09:18:28
16895	15499	QUESTAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:58	2017-06-29 09:18:28
16896	15500	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:59	2017-06-15 10:49:07
16897	15501	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:59	2017-06-15 10:49:07
16898	15502	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:59	2017-06-29 09:18:28
16899	15503	SECAN	2007-06-27 00:00:00	\N	2010-10-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:59	2017-06-29 09:18:28
16900	15504	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:59	2017-06-15 10:49:07
16901	15505	DEPUTE	1972-04-14 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:59	2017-06-15 10:49:07
16903	15507	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:59	2017-06-15 10:49:07
16904	15508	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:59	2017-06-15 10:49:07
16905	15509	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:59	2017-06-15 10:49:07
16906	15510	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:59	2017-06-15 10:49:07
16908	15512	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:59	2017-06-15 10:49:07
16909	15513	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:59	2017-06-15 10:49:07
16910	15514	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:59	2017-06-15 10:49:07
16911	15515	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:00	2017-06-15 10:49:07
29192	27789	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:52	\N
16912	15516	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:00	2017-06-15 10:49:07
16913	15517	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:00	2017-06-15 10:49:07
16914	15518	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:00	2017-06-15 10:49:07
16915	15519	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:00	2017-06-15 10:49:07
16917	15521	DEPUTE	1988-06-06 00:00:00	\N	1988-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:00	2017-06-15 10:49:07
16918	15522	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:00	2017-06-15 10:49:07
16919	15523	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:01	2017-06-15 10:49:08
16920	15524	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:01	2017-06-15 10:49:08
16921	15525	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:01	2017-06-15 10:49:08
16922	15526	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:01	2017-06-15 10:49:08
16923	15527	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:01	2017-06-15 10:49:08
16924	15528	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:01	2017-06-15 10:49:08
16925	15529	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:01	2017-06-15 10:49:08
16926	15530	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:01	2017-06-15 10:49:08
16927	15531	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:01	2017-06-15 10:49:08
16928	15532	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:01	2017-06-19 09:37:07
16929	15533	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:01	2017-06-15 10:49:08
16930	15534	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:01	2017-06-15 10:49:08
16931	15535	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:02	2017-06-15 10:49:08
16932	15536	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:02	2017-06-15 10:49:08
16933	15537	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:02	2017-06-15 10:49:08
16934	15538	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:02	2017-06-15 10:49:08
16935	15539	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:02	2017-06-15 10:49:08
16936	15540	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:02	2017-06-15 10:49:08
16937	15541	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:02	2017-06-15 10:49:08
16938	15542	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:02	2017-06-29 09:18:30
16939	15543	DEPUTE	2007-06-20 00:00:00	\N	2009-01-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:02	2017-06-29 03:42:55
16940	15544	DEPUTE	2005-10-04 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:02	2017-06-29 09:18:30
16941	15545	DEPUTE	2010-12-14 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:02	2017-06-29 03:42:55
16942	15546	DEPUTE	2012-12-17 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:02	2017-06-29 03:42:56
16943	15547	DEPUTE	2012-06-20 00:00:00	\N	2012-10-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:02	2017-06-29 03:42:55
16944	15548	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:02	2017-06-15 10:49:08
16945	15549	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:02	2017-06-15 10:49:09
16946	15550	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:02	2017-06-15 10:49:09
16947	15551	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:02	2017-06-15 10:49:09
16948	15552	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:02	2017-06-15 10:49:09
16949	15553	DEPUTE	1998-09-27 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:02	2017-06-15 10:49:09
16950	15554	DEPUTE	1973-05-13 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:03	2017-06-15 10:49:09
16951	15555	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:03	2017-06-15 10:49:09
16952	15556	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:03	2017-06-15 10:49:09
16953	15557	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:03	2017-06-15 10:49:09
16954	15558	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:03	2017-06-15 10:49:09
16955	15559	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:03	2017-06-15 10:49:09
16956	15560	DEPUTE	1968-07-11 00:00:00	\N	1971-12-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:03	2017-06-15 10:49:09
16957	15561	DEPUTE	1986-04-02 00:00:00	\N	1986-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:03	2017-06-29 03:42:56
16958	15562	DEPUTE	1986-09-29 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:03	2017-06-29 03:42:56
16959	15563	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:03	2017-06-15 10:49:09
16960	15564	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:03	2017-06-15 10:49:09
16961	15565	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:04	2017-06-15 10:49:09
16962	15566	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:04	2017-06-15 10:49:09
16963	15567	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:04	2017-06-15 10:49:09
16964	15568	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:04	2017-06-15 10:49:09
16965	15569	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:04	2017-06-15 10:49:09
16966	15570	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:04	2017-06-15 10:49:09
16967	15571	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:04	2017-06-15 10:49:09
16968	15572	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:04	2017-06-15 10:49:09
16969	15573	SECAN	2012-06-27 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:04	2017-06-29 09:18:30
16970	15574	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:04	2017-06-29 09:18:30
16971	15575	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:04	2017-06-29 09:18:30
16972	15576	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:04	2017-06-29 09:18:30
16973	15577	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:04	2017-06-15 10:49:10
16974	15578	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:04	2017-06-15 10:49:10
16975	15579	DEPUTE	1997-06-01 00:00:00	\N	2001-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:04	2017-06-15 10:49:10
16976	15580	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:05	2017-06-15 10:49:10
16977	15581	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:05	2017-06-15 10:49:10
29193	27790	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:52	\N
16978	15582	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:05	2017-06-15 10:49:10
16979	15583	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:05	2017-06-15 10:49:10
16980	15584	DEPUTE	1973-04-02 00:00:00	\N	1977-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:05	2017-06-15 10:49:10
16981	15585	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:05	2017-06-15 10:49:10
16982	15586	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:05	2017-06-15 10:49:10
16983	15587	DEPUTE	1982-01-17 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:05	2017-06-15 10:49:10
16984	15588	DEPUTE	1978-04-03 00:00:00	\N	1978-05-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:05	2017-06-15 10:49:10
16985	15589	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:05	2017-06-15 10:49:10
16986	15590	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:05	2017-06-15 10:49:10
16987	15591	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:05	2017-06-15 10:49:10
16988	15592	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:06	2017-06-15 10:49:10
16989	15593	DEPUTE	1999-03-30 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:06	2017-06-15 10:49:10
16990	15594	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:06	2017-06-15 10:49:10
16991	15595	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:06	2017-06-15 10:49:10
16992	15596	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:06	2017-06-15 10:49:10
16993	15597	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:06	2017-06-15 10:49:10
16994	15598	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:06	2017-06-15 10:49:10
16995	15599	SECAN	1997-06-13 00:00:00	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:06	2017-06-29 03:42:57
16996	15600	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:06	2017-06-15 10:49:10
16998	15602	DEPUTE	1993-04-02 00:00:00	\N	1996-02-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:06	2017-06-15 10:49:11
17000	15604	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:06	2017-06-15 10:49:11
17001	15605	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:06	2017-06-15 10:49:11
17002	15606	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:07	2017-06-15 10:49:11
17003	15607	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:07	2017-06-15 10:49:11
17004	15608	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:07	2017-06-15 10:49:11
17005	15609	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:07	2017-06-15 10:49:11
17006	15610	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:07	2017-06-29 03:42:58
16525	15129	DEPUTE	2007-06-20 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:36	2017-06-15 10:48:53
16526	15130	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:36	2017-06-15 10:48:53
16527	15131	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:36	2017-06-15 10:48:54
16528	15132	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:36	2017-06-15 10:48:54
16529	15133	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:36	2017-06-15 10:48:54
16530	15134	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:36	2017-06-15 10:48:54
16531	15135	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:36	2017-06-15 10:48:54
16532	15136	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:36	2017-06-19 09:36:59
16533	15137	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:36	2017-06-15 10:48:54
16534	15138	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:36	2017-06-15 10:48:54
16535	15139	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:36	2017-06-15 10:48:54
16536	15140	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:37	2017-06-15 10:48:54
16537	15141	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:37	2017-06-15 10:48:54
16538	15142	DEPUTE	1994-02-26 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:37	2017-06-15 10:48:54
16539	15143	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:37	2017-06-15 10:48:54
16540	15144	DEPUTE	1997-06-01 00:00:00	\N	2000-12-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:37	2017-06-15 10:48:54
16541	15145	DEPUTE	1968-07-11 00:00:00	\N	1968-08-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:37	2017-06-15 10:48:54
16542	15146	DEPUTE	1995-12-10 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:37	2017-06-15 10:48:54
16543	15147	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:37	2017-06-15 10:48:54
16544	15148	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:37	2017-06-15 10:48:54
16545	15149	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:37	2017-06-15 10:48:54
16546	15150	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:38	2017-06-15 10:48:54
16547	15151	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:38	2017-06-15 10:48:54
16548	15152	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:38	2017-06-15 10:48:54
16549	15153	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:38	2017-06-15 10:48:54
16550	15154	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:38	2017-06-15 10:48:54
16551	15155	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:38	2017-06-15 10:48:54
16552	15156	DEPUTE	2007-06-20 00:00:00	\N	2010-06-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:38	2017-06-15 10:48:54
16553	15157	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:38	2017-06-15 10:48:55
16554	15158	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:38	2017-06-15 10:48:55
16555	15159	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:38	2017-06-15 10:48:55
16556	15160	DEPUTE	2012-06-20 00:00:00	\N	2017-04-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:38	2017-06-15 10:48:55
16557	15161	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:38	2017-06-15 10:48:55
16558	15162	DEPUTE	1988-06-06 00:00:00	\N	1988-11-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:38	2017-06-15 10:48:55
16559	15163	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:38	2017-06-15 10:48:55
16560	15164	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:38	2017-06-15 10:48:55
16561	15165	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:39	2017-06-15 10:48:55
16562	15166	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:39	2017-06-15 10:48:55
29194	27791	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:52	\N
16563	15167	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:39	2017-06-15 10:48:55
16564	15168	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:39	2017-06-15 10:48:55
16565	15169	SECAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:39	2017-06-29 09:18:21
16566	15170	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:39	2017-06-29 09:18:21
16567	15171	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:39	2017-06-15 10:48:55
16568	15172	DEPUTE	1990-09-21 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:39	2017-06-15 10:48:55
16569	15173	DEPUTE	1981-07-02 00:00:00	\N	1983-04-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:39	2017-06-15 10:48:55
16570	15174	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:39	2017-06-15 10:48:55
16571	15175	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:39	2017-06-15 10:48:55
16572	15176	DEPUTE	1997-06-01 00:00:00	\N	1999-12-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:39	2017-06-15 10:48:55
16573	15177	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:39	2017-06-15 10:48:55
16574	15178	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:39	2017-06-15 10:48:55
16575	15179	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:39	2017-06-15 10:48:55
16576	15180	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:39	2017-06-15 10:48:55
16577	15181	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:39	2017-06-15 10:48:55
16578	15182	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:39	2017-06-15 10:48:55
16579	15183	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:39	2017-06-15 10:48:55
16580	15184	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:39	2017-06-15 10:48:55
16581	15185	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:39	2017-06-19 09:37:00
16582	15186	DEPUTE	1997-06-01 00:00:00	\N	1999-10-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:40	2017-06-15 10:48:55
16583	15187	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:40	2017-06-15 10:48:56
16584	15188	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:40	2017-06-15 10:48:56
16585	15189	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:40	2017-06-15 10:48:56
16586	15190	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:40	2017-06-15 10:48:56
16587	15191	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:40	2017-06-15 10:48:56
16588	15192	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:40	2017-06-15 10:48:56
16589	15193	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:40	2017-06-15 10:48:56
16590	15194	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:40	2017-06-19 09:37:00
16591	15195	DEPUTE	1998-09-27 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:41	2017-06-29 09:18:22
16592	15196	DEPUTE	1998-05-04 00:00:00	\N	1998-07-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:41	2017-06-29 09:18:22
16593	15197	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:41	2017-06-15 10:48:56
16594	15198	DEPUTE	1986-04-02 00:00:00	\N	1987-10-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:41	2017-06-15 10:48:56
16595	15199	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:41	2017-06-15 10:48:56
16596	15200	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:41	2017-06-15 10:48:56
16597	15201	DEPUTE	1993-04-02 00:00:00	\N	1993-09-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:41	2017-06-15 10:48:56
16598	15202	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:41	2017-06-15 10:48:56
16599	15203	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:41	2017-06-15 10:48:56
16601	15205	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:42	2017-06-15 10:48:56
16602	15206	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:42	2017-06-29 09:18:23
16603	15207	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:42	2017-06-29 09:18:23
16604	15208	VICPDTAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:42	2017-06-29 03:42:47
16605	15209	VICPDTAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:42	2017-06-29 09:18:23
16606	15210	VICPDTAN	1998-03-24 00:00:00	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:42	2017-06-29 03:42:47
16607	15211	VICPDTAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:42	2017-06-29 03:42:47
16608	15212	VICPDTAN	1999-02-10 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:42	2017-06-29 09:18:23
16610	15214	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:42	2017-06-15 10:48:57
16611	15215	DEPUTE	1988-06-13 00:00:00	\N	1991-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:42	2017-06-15 10:48:57
16612	15216	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:42	2017-06-15 10:48:57
16613	15217	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:42	2017-06-15 10:48:57
16614	15218	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:42	2017-06-15 10:48:57
16615	15219	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:42	2017-06-15 10:48:57
16616	15220	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:42	2017-06-19 09:37:01
16618	15222	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:42	2017-06-19 09:37:01
17393	15997	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:33	2017-06-15 10:49:25
17394	15998	DEPUTE	1958-12-09 00:00:00	\N	1959-02-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:33	2017-06-15 10:49:25
17395	15999	DEPUTE	1962-12-06 00:00:00	\N	1963-01-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:33	2017-06-15 10:49:25
17396	16000	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:33	2017-06-15 10:49:25
17397	16001	DEPUTE	1968-07-11 00:00:00	\N	1969-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:33	2017-06-15 10:49:25
17398	16002	DEPUTE	1973-04-02 00:00:00	\N	1973-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:33	2017-06-15 10:49:25
17399	16003	DEPUTE	1984-09-24 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:33	2017-06-15 10:49:25
17400	16004	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:33	2017-06-15 10:49:25
17401	16005	DEPUTE	1988-06-06 00:00:00	\N	1989-11-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:33	2017-06-15 10:49:25
17402	16006	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:33	2017-06-15 10:49:25
17403	16007	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:33	2017-06-15 10:49:25
17404	16008	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:34	2017-06-15 10:49:25
17405	16009	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:34	2017-06-15 10:49:25
17406	16010	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:34	2017-06-15 10:49:25
17407	16011	VICPDTAN	1997-06-13 00:00:00	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:34	2017-06-29 09:18:39
17408	16012	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:34	2017-06-15 10:49:25
17409	16013	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:34	2017-06-19 09:37:16
17410	16014	VICPDTAN	1998-10-01 00:00:00	\N	1998-10-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:34	2017-06-29 09:18:39
17411	16015	DEPUTE	1997-06-01 00:00:00	\N	1998-11-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:34	2017-06-29 09:18:39
17412	16016	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:34	2017-06-15 10:49:25
17413	16017	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:34	2017-06-15 10:49:25
17414	16018	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:34	2017-06-15 10:49:25
17415	16019	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:34	2017-06-15 10:49:26
17416	16020	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:34	2017-06-15 10:49:26
17417	16021	DEPUTE	1993-05-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:34	2017-06-15 10:49:26
17418	16022	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:34	2017-06-15 10:49:26
17419	16023	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:34	2017-06-15 10:49:26
17420	16024	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:34	2017-06-15 10:49:26
17421	16025	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:34	2017-06-19 09:37:17
17422	16026	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:34	2017-06-15 10:49:26
17423	16027	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:34	2017-06-15 10:49:26
17424	16028	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:34	2017-06-15 10:49:26
17425	16029	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:34	2017-06-15 10:49:26
17426	16030	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:34	2017-06-15 10:49:26
17427	16031	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:34	2017-06-15 10:49:26
17428	16032	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:34	2017-06-15 10:49:26
17429	16033	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:34	2017-06-15 10:49:26
17430	16034	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:34	2017-06-15 10:49:26
17431	16035	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:35	2017-06-15 10:49:26
17432	16036	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:35	2017-06-15 10:49:26
17433	16037	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:35	2017-06-15 10:49:26
17434	16038	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:35	2017-06-29 03:43:07
17435	16039	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:35	2017-06-29 09:18:39
17436	16040	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:35	2017-06-15 10:49:26
17437	16041	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:35	2017-06-15 10:49:26
17438	16042	QUESTAN	1990-04-02 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:35	2017-06-29 03:43:07
17439	16043	QUESTAN	1994-04-02 00:00:00	\N	1995-05-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:35	2017-06-29 09:18:39
17440	16044	QUESTAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:35	2017-06-29 09:18:39
17441	16045	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:35	2017-06-15 10:49:26
17442	16046	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:35	2017-06-15 10:49:26
17443	16047	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:35	2017-06-15 10:49:26
17444	16048	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:35	2017-06-15 10:49:26
17445	16049	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:35	2017-06-15 10:49:27
17446	16050	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:35	2017-06-15 10:49:27
17447	16051	DEPUTE	2002-06-19 00:00:00	\N	2007-03-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:35	2017-06-15 10:49:27
17448	16052	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:35	2017-06-15 10:49:27
17449	16053	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:35	2017-06-29 03:43:07
17450	16054	SECAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:35	2017-06-29 03:43:07
17451	16055	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:36	2017-06-15 10:49:27
17453	16057	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:36	2017-06-15 10:49:27
17454	16058	SECAN	2003-10-01 00:00:00	\N	2005-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:36	2017-06-29 09:18:39
17455	16059	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:36	2017-06-15 10:49:27
17456	16060	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:36	2017-06-29 09:18:39
17457	16061	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:36	2017-06-15 10:49:27
17458	16062	DEPUTE	2007-06-20 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:36	2017-06-15 10:49:27
17459	16063	DEPUTE	1973-04-02 00:00:00	\N	1973-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:36	2017-06-15 10:49:27
17460	16064	DEPUTE	1967-04-03 00:00:00	\N	1967-05-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:36	2017-06-15 10:49:27
17461	16065	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:36	2017-06-15 10:49:27
17462	16066	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:36	2017-06-15 10:49:27
17463	16067	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:36	2017-06-15 10:49:27
17464	16068	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:36	2017-06-15 10:49:27
17465	16069	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:36	2017-06-15 10:49:27
17466	16070	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:36	2017-06-15 10:49:27
17467	16071	DEPUTE	1981-07-02 00:00:00	\N	1982-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:36	2017-06-15 10:49:27
17468	16072	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:36	2017-06-15 10:49:27
17469	16073	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:36	2017-06-15 10:49:27
17470	16074	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:37	2017-06-15 10:49:27
17472	16076	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:37	2017-06-15 10:49:27
17473	16077	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:37	2017-06-15 10:49:27
17474	16078	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:37	2017-06-15 10:49:28
17475	16079	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:37	2017-06-15 10:49:28
17476	16080	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:37	2017-06-15 10:49:28
17477	16081	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:37	2017-06-19 09:37:18
17478	16082	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:37	2017-06-15 10:49:28
17480	16084	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:37	2017-06-15 10:49:28
17481	16085	VICPDTAN	2005-06-09 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:37	2017-06-29 09:18:40
17482	16086	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:37	2017-06-29 03:43:08
17483	16087	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:37	2017-06-15 10:49:28
17484	16088	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:37	2017-06-19 09:37:18
17486	16090	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:37	2017-06-29 03:43:08
17487	16091	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:37	2017-06-29 09:18:40
17488	16092	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:38	2017-06-15 10:49:28
17489	16093	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:38	2017-06-15 10:49:28
17490	16094	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:38	2017-06-15 10:49:28
17491	16095	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:38	2017-06-15 10:49:28
17492	16096	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:38	2017-06-15 10:49:28
17493	16097	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:38	2017-06-15 10:49:28
17494	16098	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:38	2017-06-15 10:49:28
17495	16099	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:38	2017-06-15 10:49:28
17496	16100	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:38	2017-06-15 10:49:28
17497	16101	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:38	2017-06-15 10:49:28
17498	16102	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:38	2017-06-15 10:49:28
17499	16103	DEPUTE	1997-06-01 00:00:00	\N	2001-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:38	2017-06-29 09:18:40
17500	16104	DEPUTE	2001-04-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:38	2017-06-29 09:18:40
17501	16105	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:38	2017-06-15 10:49:29
17502	16106	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:38	2017-06-15 10:49:29
17503	16107	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:38	2017-06-15 10:49:29
17504	16108	DEPUTE	1997-06-01 00:00:00	\N	1999-12-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:38	2017-06-15 10:49:29
17505	16109	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:38	2017-06-15 10:49:29
17506	16110	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:38	2017-06-15 10:49:29
17507	16111	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:38	2017-06-15 10:49:29
17508	16112	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:38	2017-06-15 10:49:29
17509	16113	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:38	2017-06-15 10:49:29
17510	16114	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:39	2017-06-15 10:49:29
17511	16115	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:39	2017-06-15 10:49:29
17512	16116	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:39	2017-06-29 09:18:41
17513	16117	VICPDTAN	2009-10-06 00:00:00	\N	2010-10-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:39	2017-06-29 09:18:41
17514	16118	SECAN	2010-10-05 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:39	2017-06-29 03:43:07
17515	16119	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:39	2017-06-15 10:49:29
17516	16120	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:39	2017-06-15 10:49:29
17517	16121	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:39	2017-06-15 10:49:29
17518	16122	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:39	2017-06-15 10:49:29
17519	16123	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:39	2017-06-15 10:49:29
17520	16124	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:39	2017-06-15 10:49:29
17521	16125	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:39	2017-06-15 10:49:29
17522	16126	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:39	2017-06-15 10:49:29
17523	16127	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:39	2017-06-29 09:18:41
17524	16128	QUESTAN	2004-05-05 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:39	2017-06-29 09:18:41
17525	16129	DEPUTE	1981-07-02 00:00:00	\N	1983-12-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:39	2017-06-15 10:49:29
17526	16130	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:39	2017-06-15 10:49:29
17528	16132	DEPUTE	1991-02-04 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:40	2017-06-29 09:18:41
17529	16133	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:40	2017-06-15 10:49:29
17530	16134	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:40	2017-06-15 10:49:29
17531	16135	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:40	2017-06-15 10:49:29
17532	16136	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:40	2017-06-15 10:49:29
17533	16137	DEPUTE	1978-04-02 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:40	2017-06-15 10:49:30
17534	16138	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:40	2017-06-15 10:49:30
17535	16139	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:40	2017-06-15 10:49:30
17536	16140	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:40	2017-06-15 10:49:30
17537	16141	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:40	2017-06-15 10:49:30
17538	16142	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:40	2017-06-15 10:49:30
17539	16143	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:40	2017-06-15 10:49:30
17540	16144	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:40	2017-06-15 10:49:30
17541	16145	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:40	2017-06-15 10:49:30
17542	16146	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:40	2017-06-15 10:49:30
17543	16147	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:41	2017-06-15 10:49:30
17544	16148	PDTAN	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:41	2017-06-28 03:43:10
17545	16149	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:41	2017-06-29 09:18:42
17546	16150	PDTAN	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:41	2017-06-28 03:43:10
17547	16151	PDTAN	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:41	2017-06-29 03:43:10
17548	16152	DEPUTE	1970-09-20 00:00:00	\N	1970-10-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:41	2017-06-29 09:18:42
17549	16153	DEPUTE	1968-07-11 00:00:00	\N	1969-07-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:41	2017-06-29 09:18:42
17550	16154	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:41	2017-06-15 10:49:30
17551	16155	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:41	2017-06-15 10:49:30
17552	16156	PDTAN	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:41	2017-06-29 03:43:10
17553	16157	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:41	2017-06-15 10:49:30
17554	16158	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:41	2017-06-15 10:49:30
17555	16159	PDTAN	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:41	2017-06-29 09:18:42
17556	16160	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:41	2017-06-28 03:43:10
17557	16161	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:41	2017-06-29 03:43:10
17558	16162	PDTAN	1968-07-11 00:00:00	\N	1969-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:41	2017-06-29 09:18:42
17559	16163	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:41	2017-06-28 03:43:10
17560	16164	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:41	2017-06-29 03:43:10
17561	16165	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:41	2017-06-15 10:49:31
17562	16166	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:41	2017-06-15 10:49:31
17563	16167	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:42	2017-06-15 10:49:31
17565	16169	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:42	2017-06-15 10:49:31
17566	16170	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:42	2017-06-15 10:49:31
17567	16171	DEPUTE	1968-07-11 00:00:00	\N	1968-08-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:42	2017-06-15 10:49:31
17568	16172	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:42	2017-06-15 10:49:31
17569	16173	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:42	2017-06-15 10:49:31
17570	16174	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:42	2017-06-15 10:49:31
17572	16176	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:42	2017-06-15 10:49:31
17573	16177	DEPUTE	1962-12-06 00:00:00	\N	1966-02-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:43	2017-06-15 10:49:31
17574	16178	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:43	2017-06-15 10:49:31
17575	16179	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:43	2017-06-15 10:49:31
17576	16180	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:43	2017-06-15 10:49:31
17577	16181	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:43	2017-06-15 10:49:31
17578	16182	DEPUTE	1993-04-02 00:00:00	\N	1994-11-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:43	2017-06-15 10:49:31
17580	16184	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:43	2017-06-15 10:49:32
17581	16185	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:43	2017-06-15 10:49:32
17582	16186	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:43	2017-06-15 10:49:32
17583	16187	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:43	2017-06-15 10:49:32
17775	16379	DEPUTE	1981-07-22 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:54	2017-06-15 10:49:38
17776	16380	DEPUTE	1986-09-30 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:54	2017-06-15 10:49:38
17777	16381	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:55	2017-06-15 10:49:39
17778	16382	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:55	2017-06-15 10:49:39
17779	16383	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:55	2017-06-15 10:49:39
17780	16384	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:55	2017-06-15 10:49:39
17781	16385	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:55	2017-06-15 10:49:39
17782	16386	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:55	2017-06-15 10:49:39
17783	16387	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:55	2017-06-15 10:49:39
17784	16388	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:55	2017-06-15 10:49:39
17785	16389	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:55	2017-06-15 10:49:39
17786	16390	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:55	2017-06-15 10:49:39
17787	16391	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:56	2017-06-15 10:49:39
17788	16392	DEPUTE	1973-04-03 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:56	2017-06-15 10:49:39
17789	16393	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:56	2017-06-15 10:49:39
17790	16394	DEPUTE	1959-03-07 00:00:00	\N	1960-03-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:56	2017-06-15 10:49:39
17791	16395	DEPUTE	1962-12-06 00:00:00	\N	1963-01-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:56	2017-06-15 10:49:39
17792	16396	DEPUTE	1967-04-02 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:56	2017-06-15 10:49:39
17793	16397	DEPUTE	1968-07-11 00:00:00	\N	1972-08-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:56	2017-06-15 10:49:39
17794	16398	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:56	2017-06-15 10:49:39
17795	16399	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:56	2017-06-15 10:49:39
17796	16400	DEPUTE	1981-07-23 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:56	2017-06-15 10:49:39
17797	16401	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:56	2017-06-15 10:49:39
17798	16402	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:56	2017-06-15 10:49:39
29195	27792	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:52	\N
17799	16403	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:56	2017-06-15 10:49:39
17800	16404	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:56	2017-06-15 10:49:39
17801	16405	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:56	2017-06-15 10:49:39
17802	16406	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:56	2017-06-19 09:37:24
17803	16407	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:56	2017-06-15 10:49:40
17804	16408	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:56	2017-06-15 10:49:40
17805	16409	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:56	2017-06-15 10:49:40
17806	16410	DEPUTE	1986-04-02 00:00:00	\N	1988-03-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:56	2017-06-15 10:49:40
17807	16411	DEPUTE	2005-07-03 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:57	2017-06-29 09:18:47
17808	16412	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:57	2017-06-15 10:49:40
17809	16413	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:57	2017-06-15 10:49:40
17810	16414	DEPUTE	2002-07-19 00:00:00	\N	2005-01-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:57	2017-06-29 09:18:47
17811	16415	DEPUTE	1998-04-06 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:57	2017-06-15 10:49:40
17812	16416	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:57	2017-06-15 10:49:40
17813	16417	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:58	2017-06-15 10:49:40
17814	16418	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:58	2017-06-19 09:37:24
17815	16419	DEPUTE	1992-05-03 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:58	2017-06-15 10:49:40
17816	16420	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:58	2017-06-15 10:49:40
17817	16421	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:58	2017-06-15 10:49:40
17818	16422	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:58	2017-06-15 10:49:40
17819	16423	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:58	2017-06-15 10:49:40
17820	16424	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:58	2017-06-15 10:49:40
17821	16425	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:58	2017-06-15 10:49:40
17822	16426	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:58	2017-06-19 09:37:24
17823	16427	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:58	2017-06-15 10:49:40
17824	16428	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:58	2017-06-15 10:49:40
17825	16429	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:59	2017-06-15 10:49:40
17826	16430	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:59	2017-06-15 10:49:40
17827	16431	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:59	2017-06-15 10:49:40
17828	16432	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:59	2017-06-15 10:49:40
17829	16433	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:59	2017-06-15 10:49:41
17830	16434	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:59	2017-06-15 10:49:41
17831	16435	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:59	2017-06-15 10:49:41
17832	16436	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:59	2017-06-15 10:49:41
17833	16437	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:59	2017-06-15 10:49:41
17834	16438	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:59	2017-06-15 10:49:41
17835	16439	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:59	2017-06-15 10:49:41
17836	16440	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:59	2017-06-15 10:49:41
17837	16441	DEPUTE	2001-11-24 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:59	2017-06-15 10:49:41
17838	16442	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:59	2017-06-15 10:49:41
17839	16443	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:59	2017-06-15 10:49:41
17840	16444	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:59	2017-06-15 10:49:41
17841	16445	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:59	2017-06-15 10:49:41
17842	16446	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:59	2017-06-15 10:49:41
17843	16447	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:00	2017-06-15 10:49:41
17844	16448	DEPUTE	2012-06-20 00:00:00	\N	2014-04-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:00	2017-06-15 10:49:41
17845	16449	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:00	2017-06-15 10:49:41
17846	16450	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:00	2017-06-15 10:49:41
17847	16451	DEPUTE	2007-06-20 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:00	2017-06-15 10:49:41
17848	16452	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:00	2017-06-15 10:49:41
17849	16453	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:00	2017-06-15 10:49:41
17850	16454	DEPUTE	1994-02-08 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:00	2017-06-15 10:49:41
17852	16456	DEPUTE	1981-07-02 00:00:00	\N	1981-12-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:01	2017-06-15 10:49:41
17853	16457	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:01	2017-06-15 10:49:41
17854	16458	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:01	2017-06-15 10:49:41
17855	16459	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:01	2017-06-15 10:49:41
17856	16460	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:01	2017-06-19 09:37:25
17857	16461	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:01	2017-06-15 10:49:42
17858	16462	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:01	2017-06-15 10:49:42
17859	16463	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:01	2017-06-15 10:49:42
17861	16465	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:01	2017-06-15 10:49:42
17862	16466	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:01	2017-06-15 10:49:42
17863	16467	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:01	2017-06-15 10:49:42
17864	16468	DEPUTE	1988-07-29 00:00:00	\N	1988-11-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:02	2017-06-15 10:49:42
17865	16469	DEPUTE	1981-07-02 00:00:00	\N	1985-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:02	2017-06-15 10:49:42
29196	27793	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:52	\N
17866	16470	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:02	2017-06-15 10:49:42
17868	16472	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:03	2017-06-15 10:49:42
17869	16473	VICPDTAN	1995-06-15 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:03	2017-06-29 03:43:15
17870	16474	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:03	2017-06-29 09:18:48
17871	16475	VICPDTAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:03	2017-06-29 03:43:17
17872	16476	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:03	2017-06-29 03:43:15
17873	16477	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:03	2017-06-29 03:43:17
17874	16478	QUESTAN	2002-06-26 00:00:00	\N	2004-05-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:03	2017-06-29 09:18:48
17875	16479	QUESTAN	2004-05-05 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:03	2017-06-29 09:18:48
17876	16480	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:03	2017-06-29 03:43:17
17877	16481	SECAN	1992-04-02 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:03	2017-06-29 03:43:17
17878	16482	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:03	2017-06-15 10:49:42
17879	16483	DEPUTE	1994-02-08 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:03	2017-06-15 10:49:42
17880	16484	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:03	2017-06-15 10:49:42
17881	16485	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:04	2017-06-15 10:49:42
17882	16486	DEPUTE	1978-04-03 00:00:00	\N	1978-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:04	2017-06-15 10:49:43
17883	16487	DEPUTE	1968-07-11 00:00:00	\N	1968-08-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:04	2017-06-15 10:49:43
17884	16488	DEPUTE	1973-04-02 00:00:00	\N	1973-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:04	2017-06-15 10:49:43
17885	16489	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:04	2017-06-15 10:49:43
17886	16490	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:04	2017-06-15 10:49:43
17887	16491	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:04	2017-06-15 10:49:43
17888	16492	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:04	2017-06-15 10:49:43
17889	16493	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:04	2017-06-15 10:49:43
17890	16494	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:04	2017-06-15 10:49:43
17891	16495	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:04	2017-06-15 10:49:43
17892	16496	DEPUTE	2007-07-20 00:00:00	\N	2010-12-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:04	2017-06-15 10:49:43
17893	16497	DEPUTE	1981-07-02 00:00:00	\N	1983-04-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:04	2017-06-15 10:49:43
17894	16498	DEPUTE	1997-06-12 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:05	2017-06-29 09:18:49
17895	16499	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:05	2017-06-19 09:37:26
17896	16500	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:05	2017-06-28 03:43:17
17897	16501	DEPUTE	1999-10-01 00:00:00	\N	2000-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:05	2017-06-29 09:18:49
17898	16502	DEPUTE	1991-02-04 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:05	2017-06-15 10:49:43
17899	16503	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:05	2017-06-15 10:49:43
17900	16504	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:05	2017-06-15 10:49:43
17901	16505	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:05	2017-06-15 10:49:43
17902	16506	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:05	2017-06-15 10:49:43
17903	16507	DEPUTE	1975-06-23 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:05	2017-06-15 10:49:43
17904	16508	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:05	2017-06-15 10:49:43
17905	16509	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:05	2017-06-15 10:49:43
17906	16510	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:05	2017-06-15 10:49:43
17907	16511	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:05	2017-06-15 10:49:43
17908	16512	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:05	2017-06-15 10:49:43
17909	16513	DEPUTE	1997-05-25 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:05	2017-06-15 10:49:43
17910	16514	DEPUTE	2002-06-19 00:00:00	\N	2004-04-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:05	2017-06-29 03:43:18
17911	16515	DEPUTE	2002-06-25 00:00:00	\N	2002-06-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:05	2017-06-29 03:43:18
17912	16516	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:06	2017-06-15 10:49:44
17913	16517	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:06	2017-06-15 10:49:44
17914	16518	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:06	2017-06-15 10:49:44
17915	16519	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:06	2017-06-15 10:49:44
17916	16520	DEPUTE	1980-11-30 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:06	2017-06-15 10:49:44
17917	16521	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:06	2017-06-15 10:49:44
17918	16522	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:06	2017-06-15 10:49:44
17920	16524	DEPUTE	1993-09-21 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:06	2017-06-29 03:43:18
17921	16525	DEPUTE	1993-04-02 00:00:00	\N	1993-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:06	2017-06-29 03:43:18
17922	16526	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:07	2017-06-15 10:49:44
17923	16527	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:07	2017-06-15 10:49:44
17924	16528	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:07	2017-06-15 10:49:44
17925	16529	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:07	2017-06-15 10:49:44
17926	16530	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:07	2017-06-15 10:49:44
17927	16531	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:07	2017-06-15 10:49:44
17928	16532	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:07	2017-06-15 10:49:44
17929	16533	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:07	2017-06-15 10:49:44
17930	16534	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:08	2017-06-15 10:49:44
17931	16535	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:08	2017-06-15 10:49:44
17932	16536	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:08	2017-06-15 10:49:44
17933	16537	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:08	2017-06-15 10:49:44
17934	16538	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:08	2017-06-15 10:49:44
17935	16539	DEPUTE	1986-02-27 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:08	2017-06-15 10:49:45
17936	16540	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:08	2017-06-15 10:49:45
17937	16541	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:08	2017-06-15 10:49:45
17938	16542	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:08	2017-06-15 10:49:45
17939	16543	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:08	2017-06-15 10:49:45
17940	16544	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:08	2017-06-15 10:49:45
17941	16545	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:08	2017-06-15 10:49:45
17942	16546	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:08	2017-06-15 10:49:45
17943	16547	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:08	2017-06-15 10:49:45
17944	16548	DEPUTE	1989-01-20 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:09	2017-06-15 10:49:45
17945	16549	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:09	2017-06-15 10:49:45
17946	16550	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:09	2017-06-15 10:49:45
17947	16551	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:09	2017-06-15 10:49:45
17948	16552	DEPUTE	1981-07-02 00:00:00	\N	1983-11-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:09	2017-06-15 10:49:45
17949	16553	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:09	2017-06-15 10:49:45
17956	16560	DEPUTE	1985-12-16 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:09	2017-06-15 10:49:45
17958	16562	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:09	2017-06-15 10:49:45
17959	16563	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:09	2017-06-15 10:49:45
17960	16564	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:09	2017-06-15 10:49:45
17961	16565	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:10	2017-06-15 10:49:45
17962	16566	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:10	2017-06-15 10:49:45
17963	16567	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:10	2017-06-15 10:49:45
17964	16568	DEPUTE	1988-06-13 00:00:00	\N	1989-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:10	2017-06-15 10:49:45
17966	16570	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:10	2017-06-26 03:43:04
17967	16571	VICPDTAN	1995-06-01 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:10	2017-06-29 09:18:50
17584	16188	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:43	2017-06-15 10:49:32
17585	16189	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:43	2017-06-15 10:49:32
17586	16190	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:43	2017-06-15 10:49:32
17587	16191	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:43	2017-06-15 10:49:32
17588	16192	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:43	2017-06-15 10:49:32
17589	16193	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:44	2017-06-15 10:49:32
17590	16194	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:44	2017-06-15 10:49:32
17591	16195	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:44	2017-06-15 10:49:32
17592	16196	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:44	2017-06-15 10:49:32
17593	16197	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:44	2017-06-19 09:37:20
17594	16198	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:44	2017-06-15 10:49:32
17595	16199	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:44	2017-06-15 10:49:32
17596	16200	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:44	2017-06-15 10:49:32
17597	16201	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:44	2017-06-15 10:49:32
17598	16202	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:44	2017-06-15 10:49:32
17599	16203	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:44	2017-06-15 10:49:32
17600	16204	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:44	2017-06-15 10:49:32
17601	16205	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:44	2017-06-15 10:49:32
17602	16206	SECAN	2012-06-27 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:44	2017-06-29 03:43:11
17603	16207	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:44	2017-06-29 09:18:43
17604	16208	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:44	2017-06-29 09:18:43
17605	16209	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:44	2017-06-29 09:18:43
17606	16210	DEPUTE	1962-12-06 00:00:00	\N	1966-02-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:45	2017-06-15 10:49:32
17607	16211	DEPUTE	1968-07-11 00:00:00	\N	1972-08-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:45	2017-06-15 10:49:32
17608	16212	DEPUTE	1973-04-02 00:00:00	\N	1973-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:45	2017-06-15 10:49:32
17609	16213	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:45	2017-06-15 10:49:32
17610	16214	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:45	2017-06-15 10:49:32
17611	16215	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:45	2017-06-15 10:49:33
17612	16216	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:45	2017-06-15 10:49:33
17613	16217	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:45	2017-06-15 10:49:33
17614	16218	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:45	2017-06-15 10:49:33
17615	16219	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:45	2017-06-15 10:49:33
17616	16220	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:45	2017-06-15 10:49:33
17617	16221	DEPUTE	2007-06-20 00:00:00	\N	2009-11-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:45	2017-06-15 10:49:33
17618	16222	DEPUTE	1983-12-18 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:45	2017-06-15 10:49:33
17619	16223	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:45	2017-06-15 10:49:33
17620	16224	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:45	2017-06-29 03:43:10
17621	16225	SECAN	1999-10-02 00:00:00	\N	2000-04-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:45	2017-06-29 09:18:43
29197	27794	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:53	\N
17622	16226	SECAN	1994-04-02 00:00:00	\N	1995-04-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:45	2017-06-29 09:18:43
17623	16227	SECAN	1996-10-01 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:45	2017-06-29 09:18:43
17624	16228	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:45	2017-06-29 09:18:43
17625	16229	SECAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:45	2017-06-29 09:18:43
17626	16230	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:45	2017-06-29 09:18:43
17627	16231	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:45	2017-06-15 10:49:33
17628	16232	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:45	2017-06-15 10:49:33
17629	16233	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:45	2017-06-15 10:49:33
17630	16234	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:45	2017-06-15 10:49:33
17631	16235	DEPUTE	1993-04-02 00:00:00	\N	1994-09-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:45	2017-06-15 10:49:33
17632	16236	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:46	2017-06-15 10:49:33
17633	16237	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:46	2017-06-15 10:49:33
17634	16238	DEPUTE	2007-03-05 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:46	2017-06-15 10:49:33
17635	16239	DEPUTE	1978-04-03 00:00:00	\N	1979-08-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:46	2017-06-15 10:49:33
17636	16240	DEPUTE	1986-04-02 00:00:00	\N	1986-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:46	2017-06-15 10:49:33
17637	16241	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:46	2017-06-15 10:49:34
17638	16242	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:46	2017-06-15 10:49:34
17639	16243	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:46	2017-06-15 10:49:34
17640	16244	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:46	2017-06-15 10:49:34
17641	16245	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:46	2017-06-15 10:49:34
17642	16246	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:46	2017-06-15 10:49:34
17643	16247	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:47	2017-06-15 10:49:34
17644	16248	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:47	2017-06-15 10:49:34
17645	16249	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:47	2017-06-15 10:49:34
17646	16250	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:47	2017-06-15 10:49:34
17647	16251	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:47	2017-06-15 10:49:34
17648	16252	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:47	2017-06-15 10:49:34
17649	16253	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:47	2017-06-15 10:49:34
17650	16254	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:47	2017-06-15 10:49:34
17651	16255	DEPUTE	1988-06-13 00:00:00	\N	1993-03-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:47	2017-06-15 10:49:34
17652	16256	DEPUTE	1999-12-06 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:47	2017-06-15 10:49:34
17653	16257	DEPUTE	1973-05-06 00:00:00	\N	1976-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:48	2017-06-15 10:49:34
17654	16258	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:48	2017-06-15 10:49:34
17655	16259	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:48	2017-06-15 10:49:34
17656	16260	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:48	2017-06-15 10:49:34
17657	16261	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:48	2017-06-15 10:49:34
17659	16263	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:48	2017-06-15 10:49:34
17660	16264	DEPUTE	1958-12-09 00:00:00	\N	1959-03-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:48	2017-06-15 10:49:35
17661	16265	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:49	2017-06-15 10:49:35
17665	16269	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:49	2017-06-15 10:49:35
17666	16270	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:49	2017-06-15 10:49:35
17667	16271	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:49	2017-06-15 10:49:35
17668	16272	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:49	2017-06-19 09:37:22
17670	16274	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:49	2017-06-15 10:49:35
17671	16275	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:49	2017-06-15 10:49:35
17672	16276	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:49	2017-06-15 10:49:35
17673	16277	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:49	2017-06-15 10:49:35
17674	16278	DEPUTE	1998-03-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:49	2017-06-15 10:49:35
17675	16279	DEPUTE	2002-06-19 00:00:00	\N	2003-03-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:49	2017-06-15 10:49:35
17676	16280	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:49	2017-06-15 10:49:35
17677	16281	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:49	2017-06-15 10:49:35
17678	16282	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:49	2017-06-15 10:49:35
17679	16283	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:49	2017-06-15 10:49:35
17681	16285	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:49	2017-06-15 10:49:35
17682	16286	DEPUTE	1981-07-02 00:00:00	\N	1981-12-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:50	2017-06-15 10:49:35
17683	16287	DEPUTE	1992-05-03 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:50	2017-06-15 10:49:35
17684	16288	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:50	2017-06-15 10:49:35
17685	16289	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:50	2017-06-15 10:49:35
17686	16290	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:50	2017-06-15 10:49:35
17687	16291	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:50	2017-06-19 09:37:22
17688	16292	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:50	2017-06-15 10:49:36
17689	16293	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:50	2017-06-15 10:49:36
17690	16294	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:50	2017-06-15 10:49:36
17691	16295	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:50	2017-06-15 10:49:36
17692	16296	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:50	2017-06-15 10:49:36
29198	27795	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:53	\N
17693	16297	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:50	2017-06-15 10:49:36
17694	16298	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:50	2017-06-15 10:49:36
17695	16299	DEPUTE	1991-06-10 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:50	2017-06-29 09:18:45
17696	16300	DEPUTE	1988-06-06 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:50	2017-06-29 09:18:45
17697	16301	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:50	2017-06-15 10:49:36
17698	16302	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:50	2017-06-29 09:18:45
17699	16303	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:50	2017-06-15 10:49:36
17700	16304	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:50	2017-06-15 10:49:36
17701	16305	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:50	2017-06-15 10:49:36
17702	16306	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:50	2017-06-15 10:49:36
17703	16307	DEPUTE	1986-09-30 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:50	2017-06-15 10:49:36
17704	16308	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:50	2017-06-15 10:49:36
17705	16309	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:50	2017-06-15 10:49:36
17706	16310	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:50	2017-06-15 10:49:36
17707	16311	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:50	2017-06-15 10:49:36
17708	16312	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:50	2017-06-15 10:49:36
17709	16313	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:50	2017-06-15 10:49:36
17710	16314	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:50	2017-06-15 10:49:36
17711	16315	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:50	2017-06-15 10:49:36
17712	16316	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:50	2017-06-15 10:49:36
17713	16317	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:51	2017-06-15 10:49:36
17714	16318	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:51	2017-06-15 10:49:36
17715	16319	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:51	2017-06-15 10:49:36
17716	16320	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:51	2017-06-15 10:49:37
17717	16321	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:51	2017-06-15 10:49:37
17718	16322	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:51	2017-06-15 10:49:37
17719	16323	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:51	2017-06-15 10:49:37
17720	16324	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:51	2017-06-15 10:49:37
17721	16325	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:51	2017-06-15 10:49:37
17722	16326	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:51	2017-06-15 10:49:37
17723	16327	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:51	2017-06-15 10:49:37
17724	16328	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:51	2017-06-15 10:49:37
17725	16329	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:51	2017-06-15 10:49:37
17726	16330	DEPUTE	2002-06-19 00:00:00	\N	2002-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:51	2017-06-15 10:49:37
17727	16331	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:51	2017-06-15 10:49:37
17728	16332	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:52	2017-06-15 10:49:37
17729	16333	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:52	2017-06-15 10:49:37
17730	16334	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:52	2017-06-15 10:49:37
17732	16336	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:52	2017-06-15 10:49:37
17733	16337	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:52	2017-06-28 03:43:13
17734	16338	SECAN	1991-04-02 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:52	2017-06-29 09:18:46
17735	16339	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:52	2017-06-15 10:49:37
17736	16340	VICPDTAN	1987-04-02 00:00:00	\N	1988-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:52	2017-06-28 03:43:13
17737	16341	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:52	2017-06-29 09:18:46
17738	16342	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:53	2017-06-15 10:49:37
17739	16343	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:53	2017-06-15 10:49:37
17740	16344	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:53	2017-06-15 10:49:37
17741	16345	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:53	2017-06-15 10:49:37
17742	16346	DEPUTE	1997-06-01 00:00:00	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:53	2017-06-15 10:49:37
17743	16347	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:53	2017-06-15 10:49:37
17744	16348	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:53	2017-06-15 10:49:37
17745	16349	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:53	2017-06-15 10:49:37
17746	16350	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:53	2017-06-15 10:49:38
17747	16351	DEPUTE	1981-07-02 00:00:00	\N	1982-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:53	2017-06-15 10:49:38
17748	16352	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:53	2017-06-15 10:49:38
17749	16353	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:53	2017-06-15 10:49:38
17750	16354	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:53	2017-06-15 10:49:38
17751	16355	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:53	2017-06-15 10:49:38
17752	16356	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:54	2017-06-15 10:49:38
17753	16357	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:54	2017-06-15 10:49:38
17754	16358	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:54	2017-06-15 10:49:38
17755	16359	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:54	2017-06-15 10:49:38
17756	16360	DEPUTE	1995-12-11 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:54	2017-06-15 10:49:38
17757	16361	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:54	2017-06-15 10:49:38
17758	16362	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:54	2017-06-15 10:49:38
29199	27796	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:53	\N
17759	16363	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:54	2017-06-15 10:49:38
17760	16364	DEPUTE	1993-04-02 00:00:00	\N	1996-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:54	2017-06-29 03:43:13
17761	16365	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:54	2017-06-15 10:49:38
17762	16366	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:54	2017-06-15 10:49:38
17763	16367	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:54	2017-06-15 10:49:38
17764	16368	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:54	2017-06-29 03:43:13
17765	16369	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:54	2017-06-15 10:49:38
17766	16370	DEPUTE	1981-07-02 00:00:00	\N	1985-08-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:54	2017-06-15 10:49:38
17768	16372	VICPDTAN	1991-04-02 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:54	2017-06-29 09:18:46
17769	16373	VICPDTAN	1998-10-28 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:54	2017-06-29 09:18:46
17770	16374	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:54	2017-06-29 09:18:46
17771	16375	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:54	2017-06-29 03:43:14
17772	16376	VICPDTAN	1999-10-01 00:00:00	\N	2000-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:54	2017-06-29 09:18:46
17774	16378	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:54	2017-06-15 10:49:38
17202	15806	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:18	2017-06-29 03:43:02
17203	15807	VICPDTAN	2015-01-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:18	2017-06-29 03:43:02
17204	15808	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:19	2017-06-15 10:49:18
17205	15809	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:19	2017-06-15 10:49:18
17206	15810	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:19	2017-06-15 10:49:18
17207	15811	DEPUTE	1986-04-02 00:00:00	\N	1988-05-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:19	2017-06-15 10:49:18
17208	15812	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:19	2017-06-15 10:49:18
17209	15813	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:19	2017-06-15 10:49:18
17210	15814	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:19	2017-06-15 10:49:18
17211	15815	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:19	2017-06-15 10:49:18
17212	15816	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:20	2017-06-15 10:49:18
17213	15817	SECAN	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:20	2017-06-29 03:43:01
17214	15818	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:20	2017-06-15 10:49:18
17215	15819	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:20	2017-06-29 09:18:34
17216	15820	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:20	2017-06-29 09:18:34
17217	15821	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:20	2017-06-29 09:18:34
17218	15822	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:20	2017-06-15 10:49:18
17219	15823	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:20	2017-06-15 10:49:18
17220	15824	SECAN	1987-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:20	2017-06-29 09:18:34
17221	15825	VICPDTAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:20	2017-06-29 09:18:34
17222	15826	VICPDTAN	1994-04-02 00:00:00	\N	1995-04-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:20	2017-06-29 09:18:34
17223	15827	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:20	2017-06-29 03:43:01
17224	15828	DEPUTE	1981-07-02 00:00:00	\N	1984-09-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:20	2017-06-15 10:49:18
17225	15829	DEPUTE	1986-09-30 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:20	2017-06-15 10:49:18
17226	15830	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:20	2017-06-15 10:49:19
17227	15831	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:20	2017-06-15 10:49:19
17228	15832	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:20	2017-06-15 10:49:19
17229	15833	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:20	2017-06-15 10:49:19
17230	15834	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:20	2017-06-15 10:49:19
17231	15835	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:21	2017-06-15 10:49:19
17232	15836	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:21	2017-06-15 10:49:19
17233	15837	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:21	2017-06-15 10:49:19
17234	15838	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:21	2017-06-15 10:49:19
17235	15839	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:21	2017-06-15 10:49:19
17236	15840	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:21	2017-06-15 10:49:19
17237	15841	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:21	2017-06-15 10:49:19
17238	15842	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:21	2017-06-15 10:49:19
17239	15843	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:21	2017-06-15 10:49:19
17240	15844	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:21	2017-06-15 10:49:19
17241	15845	DEPUTE	1977-03-04 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:22	2017-06-15 10:49:19
17242	15846	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:22	2017-06-15 10:49:19
17243	15847	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:22	2017-06-15 10:49:19
17244	15848	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:22	2017-06-15 10:49:19
17245	15849	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:22	2017-06-15 10:49:19
17246	15850	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:22	2017-06-15 10:49:19
17247	15851	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:22	2017-06-15 10:49:19
17248	15852	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:22	2017-06-15 10:49:19
17249	15853	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:22	2017-06-15 10:49:19
17250	15854	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:22	2017-06-15 10:49:19
17251	15855	DEPUTE	1997-06-01 00:00:00	\N	2000-04-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:22	2017-06-15 10:49:19
17252	15856	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:23	2017-06-15 10:49:20
17253	15857	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:23	2017-06-15 10:49:20
17254	15858	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:23	2017-06-15 10:49:20
17255	15859	DEPUTE	1998-10-01 00:00:00	\N	2000-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:23	2017-06-29 09:18:35
17256	15860	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:23	2017-06-29 09:18:35
17257	15861	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:23	2017-06-15 10:49:20
17258	15862	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:23	2017-06-15 10:49:20
17259	15863	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:23	2017-06-15 10:49:20
17260	15864	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:24	2017-06-15 10:49:20
17261	15865	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:24	2017-06-15 10:49:20
17262	15866	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:24	2017-06-15 10:49:20
17263	15867	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:24	2017-06-19 09:37:14
17264	15868	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:24	2017-06-15 10:49:20
17265	15869	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:24	2017-06-15 10:49:20
17267	15871	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:24	2017-06-15 10:49:20
17268	15872	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:25	2017-06-15 10:49:20
17269	15873	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:25	2017-06-15 10:49:20
17270	15874	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:25	2017-06-15 10:49:20
17271	15875	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:25	2017-06-15 10:49:20
17272	15876	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:25	2017-06-15 10:49:20
17273	15877	DEPUTE	1997-06-01 00:00:00	\N	2001-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:25	2017-06-15 10:49:20
17274	15878	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:25	2017-06-15 10:49:20
17275	15879	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:25	2017-06-15 10:49:20
17276	15880	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:25	2017-06-15 10:49:20
17277	15881	DEPUTE	1988-06-13 00:00:00	\N	1990-01-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:25	2017-06-15 10:49:20
17278	15882	DEPUTE	1996-02-26 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:25	2017-06-15 10:49:21
17279	15883	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:25	2017-06-15 10:49:21
17280	15884	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:25	2017-06-15 10:49:21
17281	15885	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:25	2017-06-15 10:49:21
17282	15886	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:25	2017-06-15 10:49:21
17283	15887	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:25	2017-06-15 10:49:21
17284	15888	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:25	2017-06-15 10:49:21
17285	15889	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:25	2017-06-15 10:49:21
17287	15891	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:25	2017-06-15 10:49:21
17288	15892	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:26	2017-06-15 10:49:21
17289	15893	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:26	2017-06-15 10:49:21
17290	15894	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:26	2017-06-15 10:49:21
17291	15895	DEPUTE	1991-06-18 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:26	2017-06-15 10:49:21
17292	15896	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:26	2017-06-15 10:49:21
17293	15897	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:26	2017-06-15 10:49:21
17295	15899	DEPUTE	1996-09-15 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:27	2017-06-15 10:49:21
17296	15900	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:27	2017-06-15 10:49:21
17297	15901	DEPUTE	1986-04-02 00:00:00	\N	1987-10-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:27	2017-06-15 10:49:21
17298	15902	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:27	2017-06-15 10:49:21
17299	15903	DEPUTE	1997-05-25 00:00:00	\N	2001-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:27	2017-06-15 10:49:21
17300	15904	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:27	2017-06-15 10:49:21
17301	15905	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:27	2017-06-15 10:49:22
17302	15906	DEPUTE	2002-06-19 00:00:00	\N	2003-02-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:27	2017-06-15 10:49:22
17303	15907	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:28	2017-06-15 10:49:22
17304	15908	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:28	2017-06-15 10:49:22
17305	15909	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:28	2017-06-15 10:49:22
17307	15911	DEPUTE	2007-06-20 00:00:00	\N	2012-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:28	2017-06-15 10:49:22
17308	15912	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:28	2017-06-15 10:49:22
17309	15913	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:28	2017-06-15 10:49:22
17310	15914	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:29	2017-06-15 10:49:22
17311	15915	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:29	2017-06-15 10:49:22
17312	15916	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:29	2017-06-15 10:49:22
17313	15917	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:29	2017-06-15 10:49:22
17314	15918	DEPUTE	2004-05-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:29	2017-06-15 10:49:22
17315	15919	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:29	2017-06-15 10:49:22
17316	15920	VICPDTAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:29	2017-06-29 09:18:37
17317	15921	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:29	2017-06-15 10:49:22
17318	15922	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:29	2017-06-15 10:49:22
17319	15923	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:29	2017-06-19 09:37:15
17320	15924	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:29	2017-06-29 09:18:37
17324	15928	DEPUTE	1993-05-02 00:00:00	\N	1995-06-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:30	2017-06-29 09:18:37
29200	27797	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:53	\N
17325	15929	DEPUTE	1995-07-17 00:00:00	\N	1995-08-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:30	2017-06-29 09:18:37
17326	15930	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:30	2017-06-15 10:49:23
17327	15931	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:30	2017-06-15 10:49:23
17328	15932	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:30	2017-06-15 10:49:23
17329	15933	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:30	2017-06-19 09:37:15
17330	15934	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:30	2017-06-15 10:49:23
17331	15935	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:30	2017-06-15 10:49:23
17332	15936	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:30	2017-06-15 10:49:23
17333	15937	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:30	2017-06-15 10:49:23
17334	15938	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:30	2017-06-15 10:49:23
17335	15939	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:30	2017-06-15 10:49:23
17336	15940	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:30	2017-06-15 10:49:23
17337	15941	QUESTAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:30	2017-06-29 09:18:38
17338	15942	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:30	2017-06-29 03:43:06
17339	15943	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:30	2017-06-29 09:18:38
17340	15944	SECAN	1992-04-02 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:30	2017-06-29 03:43:06
17341	15945	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:30	2017-06-15 10:49:23
17342	15946	DEPUTE	1980-10-20 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:30	2017-06-15 10:49:23
17343	15947	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:30	2017-06-15 10:49:23
17344	15948	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:30	2017-06-15 10:49:23
17345	15949	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:30	2017-06-15 10:49:23
17347	15951	SECAN	1997-06-13 00:00:00	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:30	2017-06-29 03:43:04
17348	15952	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:30	2017-06-15 10:49:23
17349	15953	VICPDTAN	2007-06-27 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:30	2017-06-28 03:43:04
17350	15954	DEPUTE	2007-06-20 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:30	2017-06-28 03:43:04
17351	15955	DEPUTE	1995-12-08 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:31	2017-06-15 10:49:23
17352	15956	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:31	2017-06-15 10:49:23
17353	15957	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:31	2017-06-15 10:49:23
17354	15958	DEPUTE	1973-04-02 00:00:00	\N	1975-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:31	2017-06-15 10:49:23
17355	15959	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:31	2017-06-15 10:49:23
17356	15960	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:31	2017-06-19 09:37:16
17357	15961	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:31	2017-06-15 10:49:24
17358	15962	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:31	2017-06-15 10:49:24
17359	15963	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:31	2017-06-15 10:49:24
17360	15964	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:31	2017-06-15 10:49:24
17361	15965	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:31	2017-06-15 10:49:24
17362	15966	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:31	2017-06-15 10:49:24
17363	15967	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:31	2017-06-15 10:49:24
17364	15968	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:31	2017-06-15 10:49:24
17365	15969	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:31	2017-06-15 10:49:24
17366	15970	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:31	2017-06-15 10:49:24
17367	15971	SECAN	2008-10-01 00:00:00	\N	2010-10-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:31	2017-06-29 09:18:38
17368	15972	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:31	2017-06-19 09:37:16
17369	15973	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:32	2017-06-29 09:18:38
17370	15974	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:32	2017-06-15 10:49:24
17371	15975	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:32	2017-06-15 10:49:24
17372	15976	DEPUTE	2000-03-20 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:32	2017-06-15 10:49:24
17373	15977	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:32	2017-06-15 10:49:24
17374	15978	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:32	2017-06-15 10:49:24
17375	15979	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:32	2017-06-15 10:49:24
17376	15980	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:32	2017-06-15 10:49:24
17377	15981	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:32	2017-06-15 10:49:24
17378	15982	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:32	2017-06-15 10:49:24
17379	15983	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:32	2017-06-19 09:37:16
17380	15984	DEPUTE	1983-04-23 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:32	2017-06-15 10:49:24
17381	15985	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:33	2017-06-15 10:49:24
17382	15986	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:33	2017-06-15 10:49:24
17383	15987	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:33	2017-06-15 10:49:24
17384	15988	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:33	2017-06-15 10:49:24
17386	15990	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:33	2017-06-15 10:49:24
17387	15991	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:33	2017-06-19 09:37:16
17388	15992	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:33	2017-06-15 10:49:25
17389	15993	DEPUTE	2002-06-19 00:00:00	\N	2004-03-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:33	2017-06-15 10:49:25
17390	15994	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:33	2017-06-15 10:49:25
17391	15995	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:33	2017-06-29 03:43:07
29201	27798	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:53	\N
17392	15996	DEPUTE	1995-06-25 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:33	2017-06-29 03:43:07
18062	16666	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:14	2017-06-15 10:49:49
18063	16667	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:14	2017-06-15 10:49:49
18064	16668	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:14	2017-06-15 10:49:49
18066	16670	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:14	2017-06-15 10:49:49
18067	16671	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:14	2017-06-15 10:49:49
18068	16672	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:14	2017-06-15 10:49:49
18069	16673	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:15	2017-06-15 10:49:49
18070	16674	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:15	2017-06-15 10:49:49
18071	16675	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:15	2017-06-15 10:49:49
18072	16676	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:15	2017-06-19 09:37:31
18073	16677	DEPUTE	1993-05-02 00:00:00	\N	1995-05-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:15	2017-06-15 10:49:49
18074	16678	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:15	2017-06-15 10:49:49
18075	16679	DEPUTE	2001-07-29 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:15	2017-06-15 10:49:49
18076	16680	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:15	2017-06-15 10:49:49
18077	16681	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:15	2017-06-15 10:49:49
18078	16682	DEPUTE	2004-06-21 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:15	2017-06-15 10:49:49
18079	16683	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:15	2017-06-15 10:49:49
18080	16684	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:15	2017-06-19 09:37:31
18081	16685	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:15	2017-06-15 10:49:49
18082	16686	DEPUTE	1981-07-02 00:00:00	\N	1984-01-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:15	2017-06-15 10:49:49
18083	16687	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:15	2017-06-15 10:49:49
18084	16688	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:15	2017-06-15 10:49:49
18085	16689	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:16	2017-06-15 10:49:50
18086	16690	VICPDTAN	2011-10-03 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:16	2017-06-28 03:43:23
18087	16691	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:16	2017-06-29 03:43:20
18088	16692	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:16	2017-06-28 03:43:23
18090	16694	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:16	2017-06-15 10:49:50
18091	16695	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:16	2017-06-15 10:49:50
18092	16696	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:16	2017-06-15 10:49:50
18093	16697	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:16	2017-06-15 10:49:50
18094	16698	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:16	2017-06-15 10:49:50
18095	16699	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:16	2017-06-15 10:49:50
18096	16700	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:16	2017-06-19 09:37:31
18097	16701	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:16	2017-06-15 10:49:50
18098	16702	DEPUTE	1977-03-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:16	2017-06-15 10:49:50
18099	16703	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:16	2017-06-15 10:49:50
18100	16704	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:16	2017-06-15 10:49:50
18101	16705	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:16	2017-06-15 10:49:50
18102	16706	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:16	2017-06-15 10:49:50
18103	16707	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:16	2017-06-15 10:49:50
18104	16708	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:16	2017-06-15 10:49:50
18105	16709	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:16	2017-06-15 10:49:50
18106	16710	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:16	2017-06-15 10:49:50
18107	16711	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:16	2017-06-15 10:49:50
18108	16712	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:16	2017-06-15 10:49:50
18109	16713	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:16	2017-06-15 10:49:50
18110	16714	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:16	2017-06-15 10:49:50
18111	16715	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:16	2017-06-19 09:37:31
18112	16716	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:17	2017-06-15 10:49:50
18113	16717	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:17	2017-06-15 10:49:50
18114	16718	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:17	2017-06-15 10:49:50
18115	16719	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:17	2017-06-15 10:49:50
18116	16720	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:17	2017-06-19 09:37:32
18117	16721	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:17	2017-06-15 10:49:51
18118	16722	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:17	2017-06-15 10:49:51
18119	16723	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:17	2017-06-15 10:49:51
18120	16724	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:17	2017-06-15 10:49:51
18121	16725	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:17	2017-06-15 10:49:51
18122	16726	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:17	2017-06-15 10:49:51
18123	16727	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:17	2017-06-15 10:49:51
18124	16728	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:17	2017-06-15 10:49:51
18125	16729	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:17	2017-06-15 10:49:51
18126	16730	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:17	2017-06-15 10:49:51
18127	16731	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:17	2017-06-19 09:37:32
29202	27799	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:53	\N
18128	16732	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:18	2017-06-15 10:49:51
18129	16733	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:18	2017-06-15 10:49:51
18130	16734	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:18	2017-06-15 10:49:51
18131	16735	DEPUTE	2010-12-15 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:18	2017-06-15 10:49:51
18132	16736	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:18	2017-06-15 10:49:51
18133	16737	DEPUTE	1988-06-13 00:00:00	\N	1990-11-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:18	2017-06-15 10:49:51
18134	16738	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:18	2017-06-15 10:49:51
18135	16739	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:18	2017-06-15 10:49:51
18136	16740	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:18	2017-06-15 10:49:51
18137	16741	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:18	2017-06-15 10:49:51
18138	16742	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:18	2017-06-15 10:49:51
18139	16743	DEPUTE	2004-01-14 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:19	2017-06-15 10:49:51
18140	16744	DEPUTE	2007-06-20 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:19	2017-06-15 10:49:51
18141	16745	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:19	2017-06-15 10:49:52
18142	16746	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:19	2017-06-15 10:49:52
18143	16747	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:19	2017-06-15 10:49:52
18144	16748	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:19	2017-06-15 10:49:52
18145	16749	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:19	2017-06-15 10:49:52
18146	16750	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:19	2017-06-15 10:49:52
18147	16751	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:19	2017-06-15 10:49:52
18148	16752	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:19	2017-06-15 10:49:52
18149	16753	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:19	2017-06-19 09:37:33
18150	16754	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:19	2017-06-15 10:49:52
18152	16756	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:20	2017-06-15 10:49:52
18153	16757	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:20	2017-06-15 10:49:52
18154	16758	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:20	2017-06-15 10:49:52
18155	16759	DEPUTE	1993-04-02 00:00:00	\N	1995-05-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:20	2017-06-15 10:49:52
18156	16760	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:20	2017-06-15 10:49:52
18441	17045	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:41	2017-06-15 10:50:02
18442	17046	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:41	2017-06-15 10:50:02
18443	17047	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:42	2017-06-15 10:50:02
18444	17048	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:42	2017-06-15 10:50:02
18445	17049	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:42	2017-06-15 10:50:03
18446	17050	DEPUTE	1986-10-01 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:42	2017-06-29 03:43:28
18447	17051	DEPUTE	1986-04-02 00:00:00	\N	1986-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:42	2017-06-29 03:43:28
18448	17052	DEPUTE	1988-06-06 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:42	2017-06-15 10:50:03
18449	17053	DEPUTE	1997-06-01 00:00:00	\N	1997-07-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:42	2017-06-15 10:50:03
18450	17054	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:42	2017-06-15 10:50:03
18451	17055	DEPUTE	1981-07-02 00:00:00	\N	1985-12-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:42	2017-06-15 10:50:03
18452	17056	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:42	2017-06-15 10:50:03
18453	17057	DEPUTE	1988-06-06 00:00:00	\N	1992-05-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:42	2017-06-15 10:50:03
18454	17058	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:42	2017-06-15 10:50:03
18455	17059	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:42	2017-06-15 10:50:03
18456	17060	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:43	2017-06-15 10:50:03
18457	17061	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:43	2017-06-15 10:50:03
18458	17062	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:43	2017-06-15 10:50:03
18459	17063	DEPUTE	1981-07-02 00:00:00	\N	1984-08-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:43	2017-06-15 10:50:03
18460	17064	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:43	2017-06-15 10:50:03
18461	17065	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:43	2017-06-15 10:50:03
18462	17066	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:43	2017-06-15 10:50:03
18463	17067	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:43	2017-06-15 10:50:03
18464	17068	DEPUTE	2010-08-05 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:43	2017-06-29 09:19:01
18465	17069	DEPUTE	1967-04-02 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:43	2017-06-15 10:50:04
18466	17070	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:43	2017-06-15 10:50:04
18467	17071	DEPUTE	1973-04-03 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:43	2017-06-15 10:50:04
18468	17072	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:43	2017-06-15 10:50:04
18469	17073	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:43	2017-06-15 10:50:04
18470	17074	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:43	2017-06-15 10:50:04
18471	17075	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:43	2017-06-15 10:50:04
18472	17076	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:43	2017-06-15 10:50:04
18473	17077	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:43	2017-06-15 10:50:04
18474	17078	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:43	2017-06-15 10:50:04
18475	17079	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:43	2017-06-15 10:50:04
18476	17080	DEPUTE	1981-07-02 00:00:00	\N	1986-03-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:44	2017-06-15 10:50:04
18477	17081	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:44	2017-06-15 10:50:04
29203	27800	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:53	\N
18478	17082	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:44	2017-06-15 10:50:04
18479	17083	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:44	2017-06-15 10:50:04
18480	17084	DEPUTE	2012-06-20 00:00:00	\N	2016-03-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:44	2017-06-15 10:50:04
18481	17085	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:44	2017-06-15 10:50:04
18482	17086	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:44	2017-06-15 10:50:04
18483	17087	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:44	2017-06-15 10:50:04
18484	17088	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:44	2017-06-15 10:50:04
18485	17089	DEPUTE	2002-06-19 00:00:00	\N	2004-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:44	2017-06-15 10:50:04
18486	17090	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:44	2017-06-15 10:50:04
18487	17091	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:44	2017-06-15 10:50:04
18488	17092	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:44	2017-06-15 10:50:04
18489	17093	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:45	2017-06-15 10:50:04
18490	17094	DEPUTE	1961-06-11 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:45	2017-06-15 10:50:04
18491	17095	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:45	2017-06-15 10:50:04
18492	17096	DEPUTE	1967-04-02 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:45	2017-06-15 10:50:05
18493	17097	DEPUTE	1968-07-11 00:00:00	\N	1969-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:45	2017-06-15 10:50:05
18494	17098	DEPUTE	1973-04-03 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:45	2017-06-15 10:50:05
18495	17099	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:45	2017-06-15 10:50:05
18496	17100	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:45	2017-06-15 10:50:05
18497	17101	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:45	2017-06-15 10:50:05
18498	17102	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:45	2017-06-15 10:50:05
18499	17103	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:45	2017-06-15 10:50:05
18500	17104	DEPUTE	1978-05-06 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:45	2017-06-15 10:50:05
18502	17106	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:45	2017-06-15 10:50:05
18503	17107	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:45	2017-06-15 10:50:05
18504	17108	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:45	2017-06-15 10:50:05
18505	17109	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:45	2017-06-15 10:50:05
18506	17110	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:45	2017-06-15 10:50:05
18507	17111	DEPUTE	1998-05-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:46	2017-06-15 10:50:05
18508	17112	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:46	2017-06-15 10:50:05
18509	17113	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:46	2017-06-15 10:50:05
18510	17114	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:46	2017-06-29 03:43:29
18511	17115	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:46	2017-06-15 10:50:05
18512	17116	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:46	2017-06-15 10:50:05
18513	17117	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:46	2017-06-19 09:37:41
18514	17118	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:46	2017-06-29 03:43:29
18515	17119	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:46	2017-06-15 10:50:05
18516	17120	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:46	2017-06-15 10:50:05
18517	17121	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:46	2017-06-15 10:50:05
18518	17122	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:46	2017-06-15 10:50:05
18519	17123	DEPUTE	1978-04-02 00:00:00	\N	1980-10-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:47	2017-06-15 10:50:05
18520	17124	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:47	2017-06-15 10:50:05
18521	17125	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:47	2017-06-15 10:50:05
18522	17126	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:47	2017-06-15 10:50:06
18523	17127	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:47	2017-06-15 10:50:06
18525	17129	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:47	2017-06-15 10:50:06
18526	17130	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:47	2017-06-15 10:50:06
18527	17131	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:47	2017-06-15 10:50:06
18528	17132	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:47	2017-06-15 10:50:06
18529	17133	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:47	2017-06-19 09:37:41
18530	17134	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:48	2017-06-15 10:50:06
18531	17135	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:48	2017-06-15 10:50:06
18533	17137	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:48	2017-06-15 10:50:06
18534	17138	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:48	2017-06-29 09:19:03
18535	17139	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:48	2017-06-15 10:50:06
18536	17140	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:48	2017-06-29 03:43:30
18537	17141	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:48	2017-06-29 03:43:32
18538	17142	QUESTAN	1995-04-03 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:48	2017-06-29 09:19:03
18539	17143	SECAN	2002-06-26 00:00:00	\N	2004-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:48	2017-06-29 03:43:30
18540	17144	SECAN	2008-10-01 00:00:00	\N	2009-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:48	2017-06-29 03:43:32
18541	17145	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:48	2017-06-15 10:50:06
18542	17146	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:48	2017-06-15 10:50:06
18543	17147	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:49	2017-06-15 10:50:06
18544	17148	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:49	2017-06-15 10:50:06
18545	17149	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:49	2017-06-15 10:50:06
29204	27801	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:53	\N
18546	17150	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:49	2017-06-15 10:50:06
18547	17151	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:49	2017-06-15 10:50:06
18548	17152	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:49	2017-06-15 10:50:07
18549	17153	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:49	2017-06-15 10:50:07
18550	17154	DEPUTE	1997-06-01 00:00:00	\N	2001-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:49	2017-06-15 10:50:07
18551	17155	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:49	2017-06-15 10:50:07
18552	17156	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:49	2017-06-15 10:50:07
18553	17157	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:49	2017-06-15 10:50:07
18554	17158	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:49	2017-06-19 09:37:42
18555	17159	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:49	2017-06-15 10:50:07
18556	17160	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:49	2017-06-15 10:50:07
18557	17161	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:49	2017-06-15 10:50:07
18558	17162	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:49	2017-06-15 10:50:07
18559	17163	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:49	2017-06-15 10:50:07
18560	17164	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:49	2017-06-15 10:50:07
18561	17165	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:49	2017-06-15 10:50:07
18562	17166	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:49	2017-06-29 03:43:31
18563	17167	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:49	2017-06-29 03:43:32
18564	17168	VICPDTAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:49	2017-06-29 03:43:31
18565	17169	VICPDTAN	1988-06-24 00:00:00	\N	1992-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:49	2017-06-29 03:43:32
18566	17170	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:50	2017-06-15 10:50:07
18567	17171	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:50	2017-06-15 10:50:07
18568	17172	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:50	2017-06-15 10:50:07
18569	17173	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:50	2017-06-15 10:50:07
18570	17174	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:50	2017-06-15 10:50:07
18571	17175	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:50	2017-06-15 10:50:07
18572	17176	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:50	2017-06-15 10:50:07
18573	17177	DEPUTE	1988-06-13 00:00:00	\N	1992-04-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:50	2017-06-15 10:50:07
18574	17178	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:50	2017-06-15 10:50:08
18575	17179	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:50	2017-06-15 10:50:08
18576	17180	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:50	2017-06-15 10:50:08
18577	17181	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:51	2017-06-15 10:50:08
18578	17182	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:51	2017-06-15 10:50:08
18579	17183	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:51	2017-06-15 10:50:08
18580	17184	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:51	2017-06-19 09:37:43
18591	17195	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:51	2017-06-15 10:50:08
18592	17196	DEPUTE	1981-07-02 00:00:00	\N	1982-07-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:51	2017-06-29 03:43:33
18593	17197	DEPUTE	1982-09-05 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:51	2017-06-29 03:43:33
18594	17198	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:51	2017-06-15 10:50:08
18595	17199	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:51	2017-06-15 10:50:08
18596	17200	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:51	2017-06-15 10:50:08
18597	17201	DEPUTE	1997-05-25 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:51	2017-06-15 10:50:08
18598	17202	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:51	2017-06-15 10:50:08
18599	17203	DEPUTE	1976-02-13 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:51	2017-06-15 10:50:08
18600	17204	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:51	2017-06-15 10:50:08
18601	17205	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:51	2017-06-15 10:50:08
18602	17206	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:51	2017-06-15 10:50:08
18603	17207	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:51	2017-06-15 10:50:08
18605	17209	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:51	2017-06-15 10:50:08
18606	17210	DEPUTE	1997-06-12 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:51	2017-06-29 09:19:04
18607	17211	DEPUTE	1973-04-02 00:00:00	\N	1977-06-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:51	2017-06-15 10:50:08
18608	17212	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:51	2017-06-15 10:50:09
18609	17213	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:51	2017-06-15 10:50:09
18610	17214	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:51	2017-06-15 10:50:09
18611	17215	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:51	2017-06-28 03:43:32
18612	17216	DEPUTE	1993-04-02 00:00:00	\N	1993-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:51	2017-06-28 03:43:35
18613	17217	DEPUTE	1993-09-20 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:51	2017-06-28 03:43:35
18614	17218	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:51	2017-06-15 10:50:09
18615	17219	DEPUTE	1997-06-01 00:00:00	\N	1997-12-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:51	2017-06-29 09:19:04
18616	17220	DEPUTE	2000-02-07 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:51	2017-06-29 09:19:04
18617	17221	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:51	2017-06-15 10:50:09
18618	17222	DEPUTE	2012-06-20 00:00:00	\N	2017-03-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:51	2017-06-15 10:50:09
18619	17223	PDTAN	1992-01-22 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:51	2017-06-28 03:43:32
18620	17224	DEPUTE	1981-07-02 00:00:00	\N	1986-02-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:52	2017-06-15 10:50:09
18621	17225	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:52	2017-06-15 10:50:09
18622	17226	DEPUTE	1983-04-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:52	2017-06-15 10:50:09
18623	17227	DEPUTE	1998-05-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:52	2017-06-15 10:50:09
18624	17228	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:52	2017-06-15 10:50:09
18625	17229	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:53	2017-06-15 10:50:09
18626	17230	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:53	2017-06-15 10:50:09
18627	17231	DEPUTE	1993-04-02 00:00:00	\N	1993-12-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:53	2017-06-15 10:50:09
18629	17233	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:53	2017-06-15 10:50:09
18630	17234	DEPUTE	2008-05-26 00:00:00	\N	2009-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:53	2017-06-29 09:19:05
18631	17235	DEPUTE	2010-12-14 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:53	2017-06-29 09:19:05
18632	17236	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:53	2017-06-29 09:19:05
18633	17237	DEPUTE	2012-06-20 00:00:00	\N	2016-03-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:53	2017-06-15 10:50:09
18635	17239	DEPUTE	1999-12-10 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:53	2017-06-15 10:50:10
18636	17240	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:53	2017-06-15 10:50:10
18637	17241	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:53	2017-06-15 10:50:10
18157	16761	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:20	2017-06-15 10:49:52
18158	16762	DEPUTE	1988-06-13 00:00:00	\N	1988-10-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:20	2017-06-15 10:49:52
18159	16763	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:20	2017-06-15 10:49:52
18160	16764	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:20	2017-06-15 10:49:52
18161	16765	DEPUTE	1994-08-23 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:20	2017-06-15 10:49:52
18162	16766	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:20	2017-06-15 10:49:52
18163	16767	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:20	2017-06-15 10:49:52
18164	16768	DEPUTE	2007-06-20 00:00:00	\N	2008-09-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:20	2017-06-15 10:49:52
18165	16769	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:21	2017-06-15 10:49:52
18166	16770	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:21	2017-06-15 10:49:52
18167	16771	DEPUTE	2012-06-20 00:00:00	\N	2014-05-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:21	2017-06-15 10:49:52
18168	16772	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:21	2017-06-15 10:49:52
18169	16773	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:21	2017-06-15 10:49:53
18170	16774	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:21	2017-06-15 10:49:53
18171	16775	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:21	2017-06-15 10:49:53
18172	16776	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:21	2017-06-15 10:49:53
18173	16777	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:21	2017-06-15 10:49:53
18174	16778	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:21	2017-06-15 10:49:53
18175	16779	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:21	2017-06-15 10:49:53
18176	16780	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:21	2017-06-15 10:49:53
18177	16781	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:21	2017-06-15 10:49:53
18178	16782	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:22	2017-06-15 10:49:53
18179	16783	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:22	2017-06-15 10:49:53
18180	16784	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:22	2017-06-15 10:49:53
18181	16785	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:22	2017-06-15 10:49:53
18182	16786	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:22	2017-06-15 10:49:53
18183	16787	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:22	2017-06-15 10:49:53
18184	16788	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:22	2017-06-15 10:49:53
18185	16789	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:22	2017-06-15 10:49:53
18186	16790	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:22	2017-06-15 10:49:53
18187	16791	VICPDTAN	1986-04-04 00:00:00	\N	1987-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:22	2017-06-29 09:18:54
18188	16792	DEPUTE	1971-12-05 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:23	2017-06-15 10:49:53
18189	16793	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:23	2017-06-15 10:49:53
18190	16794	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:23	2017-06-15 10:49:53
18191	16795	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:23	2017-06-15 10:49:53
18192	16796	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:23	2017-06-15 10:49:53
18193	16797	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:23	2017-06-29 09:18:54
18194	16798	SECAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:23	2017-06-29 09:18:54
18195	16799	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:23	2017-06-15 10:49:54
18196	16800	DEPUTE	1967-04-03 00:00:00	\N	1967-05-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:23	2017-06-15 10:49:54
18197	16801	DEPUTE	1968-07-11 00:00:00	\N	1969-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:23	2017-06-15 10:49:54
18198	16802	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:23	2017-06-15 10:49:54
18199	16803	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:23	2017-06-15 10:49:54
18200	16804	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:23	2017-06-15 10:49:54
18201	16805	DEPUTE	2007-06-20 00:00:00	\N	2010-03-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:23	2017-06-15 10:49:54
18203	16807	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:23	2017-06-29 03:43:24
18204	16808	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:24	2017-06-15 10:49:54
18205	16809	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:24	2017-06-15 10:49:54
18206	16810	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:24	2017-06-15 10:49:54
18207	16811	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:24	2017-06-15 10:49:54
18208	16812	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:24	2017-06-15 10:49:54
29205	27802	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:53	\N
18209	16813	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:24	2017-06-19 09:37:34
18210	16814	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:24	2017-06-15 10:49:54
18211	16815	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:24	2017-06-15 10:49:54
18212	16816	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:24	2017-06-29 09:18:55
18213	16817	VICPDTAN	2003-10-01 00:00:00	\N	2004-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:24	2017-06-29 09:18:55
18214	16818	VICPDTAN	2006-01-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:24	2017-06-29 09:18:55
18215	16819	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:24	2017-06-15 10:49:54
18216	16820	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:24	2017-06-15 10:49:54
18217	16821	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:24	2017-06-15 10:49:54
18218	16822	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:24	2017-06-15 10:49:54
18219	16823	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:24	2017-06-15 10:49:55
18220	16824	VICPDTAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:24	2017-06-29 03:43:24
18221	16825	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:24	2017-06-15 10:49:55
18222	16826	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:24	2017-06-15 10:49:55
18223	16827	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:24	2017-06-15 10:49:55
18224	16828	DEPUTE	1997-06-01 00:00:00	\N	2001-04-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:24	2017-06-15 10:49:55
18225	16829	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:24	2017-06-29 03:43:24
18226	16830	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:25	2017-06-15 10:49:55
18227	16831	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:25	2017-06-15 10:49:55
18228	16832	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:25	2017-06-15 10:49:55
18229	16833	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:25	2017-06-15 10:49:55
18230	16834	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:25	2017-06-15 10:49:55
18231	16835	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:25	2017-06-15 10:49:55
18232	16836	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:25	2017-06-15 10:49:55
18233	16837	DEPUTE	1958-12-09 00:00:00	\N	1961-09-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:25	2017-06-15 10:49:55
18234	16838	DEPUTE	1973-04-02 00:00:00	\N	1974-07-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:25	2017-06-15 10:49:55
18235	16839	DEPUTE	1974-07-26 00:00:00	\N	1977-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:25	2017-06-15 10:49:55
18236	16840	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:25	2017-06-15 10:49:55
18237	16841	DEPUTE	1986-04-02 00:00:00	\N	1986-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:25	2017-06-15 10:49:55
18238	16842	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:25	2017-06-15 10:49:55
18239	16843	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:26	2017-06-15 10:49:55
18241	16845	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:26	2017-06-15 10:49:55
18242	16846	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:26	2017-06-15 10:49:55
18243	16847	DEPUTE	1958-12-09 00:00:00	\N	1961-04-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:26	2017-06-15 10:49:55
18244	16848	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:26	2017-06-15 10:49:55
18245	16849	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:26	2017-06-15 10:49:55
18246	16850	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:26	2017-06-15 10:49:55
18248	16852	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:27	2017-06-15 10:49:56
18249	16853	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:27	2017-06-15 10:49:56
18250	16854	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:27	2017-06-15 10:49:56
18251	16855	DEPUTE	1986-04-02 00:00:00	\N	1986-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:27	2017-06-29 09:18:56
18252	16856	DEPUTE	1986-10-01 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:27	2017-06-29 09:18:56
18255	16859	DEPUTE	1974-04-29 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:28	2017-06-15 10:49:56
18256	16860	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:28	2017-06-15 10:49:56
18257	16861	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:28	2017-06-15 10:49:56
18258	16862	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:28	2017-06-15 10:49:56
18259	16863	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:28	2017-06-15 10:49:56
18260	16864	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:28	2017-06-29 03:43:24
18261	16865	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:28	2017-06-15 10:49:56
18262	16866	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:28	2017-06-15 10:49:56
18263	16867	DEPUTE	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:28	2017-06-29 03:43:24
18264	16868	DEPUTE	1983-12-04 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:28	2017-06-15 10:49:56
18265	16869	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:28	2017-06-15 10:49:56
18266	16870	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:28	2017-06-15 10:49:56
18267	16871	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:28	2017-06-15 10:49:56
18268	16872	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:28	2017-06-15 10:49:56
18269	16873	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:28	2017-06-15 10:49:56
18270	16874	DEPUTE	1999-02-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:28	2017-06-15 10:49:56
18271	16875	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:28	2017-06-15 10:49:56
18272	16876	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:28	2017-06-15 10:49:56
18273	16877	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:28	2017-06-19 09:37:35
18274	16878	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:29	2017-06-15 10:49:56
18275	16879	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:29	2017-06-29 09:18:56
18276	16880	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:29	2017-06-15 10:49:57
18277	16881	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:29	2017-06-15 10:49:57
18278	16882	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:29	2017-06-15 10:49:57
18279	16883	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:29	2017-06-15 10:49:57
18280	16884	DEPUTE	1997-06-01 00:00:00	\N	2001-02-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:29	2017-06-15 10:49:57
18281	16885	VICPDTAN	1984-04-01 00:00:00	\N	1985-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:29	2017-06-29 09:18:56
18282	16886	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:29	2017-06-15 10:49:57
18283	16887	DEPUTE	1998-11-30 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:29	2017-06-15 10:49:57
18284	16888	DEPUTE	2010-12-14 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:29	2017-06-29 09:18:56
18285	16889	DEPUTE	2012-06-20 00:00:00	\N	2016-07-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:29	2017-06-15 10:49:57
18286	16890	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:29	2017-06-29 09:18:56
18287	16891	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:29	2017-06-15 10:49:57
18288	16892	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:29	2017-06-15 10:49:57
18289	16893	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:29	2017-06-15 10:49:57
18290	16894	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:29	2017-06-15 10:49:57
18291	16895	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:29	2017-06-15 10:49:57
18292	16896	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:29	2017-06-15 10:49:57
18293	16897	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:29	2017-06-15 10:49:57
18294	16898	DEPUTE	2014-05-03 00:00:00	\N	2014-10-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:29	2017-06-29 09:18:56
18295	16899	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:29	2017-06-29 09:18:56
18296	16900	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:29	2017-06-15 10:49:57
18297	16901	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:29	2017-06-15 10:49:57
18298	16902	DEPUTE	2003-02-03 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:29	2017-06-29 09:18:56
18299	16903	DEPUTE	2002-06-19 00:00:00	\N	2002-11-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:29	2017-06-29 09:18:56
18300	16904	DEPUTE	1981-07-24 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:30	2017-06-15 10:49:57
18301	16905	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:30	2017-06-15 10:49:57
18302	16906	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:30	2017-06-15 10:49:57
18303	16907	DEPUTE	1990-11-03 00:00:00	\N	1991-11-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:30	2017-06-15 10:49:57
18304	16908	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:30	2017-06-15 10:49:57
18305	16909	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:30	2017-06-15 10:49:58
18306	16910	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:30	2017-06-15 10:49:58
18307	16911	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:30	2017-06-15 10:49:58
18308	16912	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:31	2017-06-15 10:49:58
18309	16913	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:31	2017-06-15 10:49:58
18310	16914	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:31	2017-06-15 10:49:58
18311	16915	DEPUTE	1988-06-06 00:00:00	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:31	2017-06-15 10:49:58
18313	16917	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:31	2017-06-15 10:49:58
18314	16918	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:31	2017-06-15 10:49:58
18315	16919	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:31	2017-06-15 10:49:58
18316	16920	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:31	2017-06-15 10:49:58
18317	16921	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:31	2017-06-15 10:49:58
18318	16922	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:31	2017-06-15 10:49:58
18319	16923	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:31	2017-06-15 10:49:58
18320	16924	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:31	2017-06-15 10:49:58
18321	16925	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:31	2017-06-15 10:49:58
18322	16926	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:31	2017-06-15 10:49:58
18323	16927	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:31	2017-06-15 10:49:58
18324	16928	DEPUTE	1997-06-01 00:00:00	\N	1999-08-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:32	2017-06-15 10:49:58
18325	16929	DEPUTE	2003-03-24 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:32	2017-06-15 10:49:58
18326	16930	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:32	2017-06-15 10:49:58
18327	16931	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:32	2017-06-15 10:49:58
18328	16932	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:32	2017-06-15 10:49:58
18329	16933	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:32	2017-06-15 10:49:58
18330	16934	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:32	2017-06-15 10:49:58
18331	16935	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:32	2017-06-15 10:49:58
18332	16936	DEPUTE	1981-07-02 00:00:00	\N	1985-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:33	2017-06-15 10:49:59
18333	16937	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:33	2017-06-15 10:49:59
18334	16938	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:33	2017-06-15 10:49:59
18335	16939	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:33	2017-06-15 10:49:59
18337	16941	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:33	2017-06-15 10:49:59
18338	16942	DEPUTE	2002-06-19 00:00:00	\N	2002-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:33	2017-06-15 10:49:59
18339	16943	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:33	2017-06-15 10:49:59
18340	16944	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:33	2017-06-15 10:49:59
18341	16945	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:33	2017-06-15 10:49:59
18342	16946	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:33	2017-06-15 10:49:59
18343	16947	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:33	2017-06-19 09:37:36
18344	16948	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:34	2017-06-15 10:49:59
29206	27803	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:53	\N
18346	16950	DEPUTE	1968-07-11 00:00:00	\N	1968-08-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:34	2017-06-15 10:49:59
18347	16951	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:34	2017-06-15 10:49:59
18348	16952	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:34	2017-06-15 10:49:59
18349	16953	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:34	2017-06-15 10:49:59
18350	16954	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:34	2017-06-15 10:49:59
18351	16955	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:34	2017-06-15 10:49:59
18352	16956	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:34	2017-06-15 10:49:59
18353	16957	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:34	2017-06-15 10:49:59
18354	16958	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:34	2017-06-29 09:18:58
18355	16959	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:34	2017-06-29 09:18:58
18356	16960	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:34	2017-06-15 10:49:59
18357	16961	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:34	2017-06-15 10:49:59
18358	16962	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:34	2017-06-15 10:49:59
18359	16963	DEPUTE	1978-05-06 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:34	2017-06-15 10:49:59
18360	16964	DEPUTE	1995-12-10 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:35	2017-06-15 10:50:00
18361	16965	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:35	2017-06-15 10:50:00
18362	16966	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:35	2017-06-15 10:50:00
18363	16967	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:35	2017-06-15 10:50:00
18364	16968	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:35	2017-06-19 09:37:37
18365	16969	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:35	2017-06-15 10:50:00
18366	16970	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:35	2017-06-15 10:50:00
18367	16971	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:35	2017-06-15 10:50:00
18368	16972	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:35	2017-06-15 10:50:00
18369	16973	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:35	2017-06-15 10:50:00
18370	16974	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:35	2017-06-15 10:50:00
18371	16975	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:35	2017-06-15 10:50:00
18372	16976	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:35	2017-06-29 09:18:58
18373	16977	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:35	2017-06-15 10:50:00
18374	16978	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:35	2017-06-15 10:50:00
18375	16979	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:35	2017-06-15 10:50:00
18376	16980	VICPDTAN	1995-04-03 00:00:00	\N	1996-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:35	2017-06-29 09:18:58
18377	16981	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:36	2017-06-15 10:50:00
18378	16982	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:36	2017-06-15 10:50:00
18379	16983	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:36	2017-06-15 10:50:00
18380	16984	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:36	2017-06-15 10:50:00
18381	16985	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:36	2017-06-15 10:50:00
18382	16986	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:36	2017-06-15 10:50:00
18383	16987	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:36	2017-06-19 09:37:37
18384	16988	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:36	2017-06-15 10:50:00
18385	16989	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:36	2017-06-15 10:50:00
18386	16990	SECAN	1988-06-24 00:00:00	\N	1992-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:36	2017-06-29 09:18:58
18387	16991	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:36	2017-06-29 09:18:58
18388	16992	DEPUTE	1973-04-02 00:00:00	\N	1976-04-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:36	2017-06-15 10:50:00
18389	16993	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:36	2017-06-15 10:50:00
18390	16994	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:37	2017-06-15 10:50:00
18391	16995	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:37	2017-06-15 10:50:00
18392	16996	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:37	2017-06-15 10:50:01
18393	16997	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:37	2017-06-15 10:50:01
18394	16998	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:37	2017-06-15 10:50:01
18395	16999	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:37	2017-06-15 10:50:01
18396	17000	DEPUTE	1993-04-02 00:00:00	\N	1995-11-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:37	2017-06-15 10:50:01
18397	17001	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:37	2017-06-15 10:50:01
18398	17002	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:37	2017-06-15 10:50:01
18399	17003	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:37	2017-06-15 10:50:01
18400	17004	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:37	2017-06-15 10:50:01
18401	17005	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:38	2017-06-15 10:50:01
18402	17006	DEPUTE	1996-03-17 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:38	2017-06-15 10:50:01
18403	17007	DEPUTE	1997-06-01 00:00:00	\N	1999-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:38	2017-06-15 10:50:01
18404	17008	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:38	2017-06-15 10:50:01
18405	17009	QUESTAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:38	2017-06-29 09:18:59
18406	17010	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:38	2017-06-15 10:50:01
18407	17011	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:38	2017-06-15 10:50:01
18408	17012	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:38	2017-06-19 09:37:38
18409	17013	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:38	2017-06-29 09:18:59
18410	17014	SECAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:38	2017-06-29 09:18:59
29207	27804	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:53	\N
18411	17015	QUESTAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:38	2017-06-29 09:18:59
18412	17016	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:38	2017-06-29 09:18:59
18413	17017	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:38	2017-06-15 10:50:01
18414	17018	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:38	2017-06-15 10:50:01
18415	17019	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:38	2017-06-15 10:50:01
18416	17020	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:38	2017-06-15 10:50:01
18418	17022	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:39	2017-06-15 10:50:01
18419	17023	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:39	2017-06-15 10:50:01
18420	17024	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:39	2017-06-15 10:50:01
18421	17025	DEPUTE	1968-08-13 00:00:00	\N	1969-09-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:39	2017-06-15 10:50:02
18422	17026	DEPUTE	1973-05-03 00:00:00	\N	1974-07-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:39	2017-06-15 10:50:02
18423	17027	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:39	2017-06-15 10:50:02
18424	17028	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:39	2017-06-15 10:50:02
18425	17029	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:39	2017-06-15 10:50:02
18426	17030	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:39	2017-06-15 10:50:02
18427	17031	DEPUTE	1973-04-03 00:00:00	\N	1974-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:39	2017-06-15 10:50:02
18428	17032	DEPUTE	1986-04-02 00:00:00	\N	1986-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:39	2017-06-15 10:50:02
18429	17033	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:39	2017-06-15 10:50:02
18430	17034	DEPUTE	1999-08-29 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:39	2017-06-15 10:50:02
18431	17035	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:40	2017-06-15 10:50:02
18433	17037	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:40	2017-06-15 10:50:02
18434	17038	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:40	2017-06-15 10:50:02
18435	17039	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:40	2017-06-15 10:50:02
18436	17040	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:40	2017-06-15 10:50:02
18437	17041	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:40	2017-06-15 10:50:02
18438	17042	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:40	2017-06-15 10:50:02
18439	17043	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:41	2017-06-15 10:50:02
17968	16572	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:10	2017-06-15 10:49:46
17969	16573	DEPUTE	2002-06-19 00:00:00	\N	2007-01-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:10	2017-06-15 10:49:46
17970	16574	SECAN	1992-04-02 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:10	2017-06-26 03:43:04
17971	16575	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:10	2017-06-29 09:18:50
17972	16576	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:10	2017-06-29 03:43:19
17973	16577	SECAN	1994-04-02 00:00:00	\N	1995-05-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:10	2017-06-29 09:18:50
17974	16578	DEPUTE	2002-06-19 00:00:00	\N	2006-09-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:10	2017-06-15 10:49:46
17975	16579	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:10	2017-06-15 10:49:46
17976	16580	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:10	2017-06-15 10:49:46
17977	16581	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:10	2017-06-15 10:49:46
17978	16582	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:10	2017-06-15 10:49:46
17979	16583	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:10	2017-06-15 10:49:46
17980	16584	DEPUTE	1988-12-19 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:10	2017-06-15 10:49:46
17981	16585	DEPUTE	1993-05-02 00:00:00	\N	1995-06-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:10	2017-06-15 10:49:46
17982	16586	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:10	2017-06-15 10:49:46
17983	16587	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:10	2017-06-15 10:49:46
17984	16588	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:10	2017-06-15 10:49:46
17985	16589	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:10	2017-06-15 10:49:46
17986	16590	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:11	2017-06-15 10:49:46
17987	16591	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:11	2017-06-15 10:49:46
17988	16592	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:11	2017-06-15 10:49:46
17989	16593	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:11	2017-06-15 10:49:46
17990	16594	DEPUTE	1988-06-06 00:00:00	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:11	2017-06-15 10:49:46
17991	16595	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:11	2017-06-15 10:49:46
17992	16596	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:11	2017-06-15 10:49:46
17993	16597	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:11	2017-06-15 10:49:46
17994	16598	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:11	2017-06-15 10:49:46
17995	16599	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:11	2017-06-15 10:49:46
17996	16600	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:11	2017-06-15 10:49:46
17997	16601	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:11	2017-06-15 10:49:46
17998	16602	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:11	2017-06-15 10:49:47
17999	16603	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:11	2017-06-29 09:18:51
18000	16604	VICPDTAN	1988-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:11	2017-06-29 09:18:51
18001	16605	DEPUTE	1995-12-14 00:00:00	\N	1996-02-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:11	2017-06-15 10:49:47
18002	16606	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:12	2017-06-15 10:49:47
18003	16607	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:12	2017-06-15 10:49:47
18004	16608	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:12	2017-06-15 10:49:47
18005	16609	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:12	2017-06-15 10:49:47
29208	27805	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:53	\N
18006	16610	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:12	2017-06-15 10:49:47
18007	16611	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:12	2017-06-15 10:49:47
18008	16612	DEPUTE	1998-01-25 00:00:00	\N	1999-12-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:12	2017-06-15 10:49:47
18009	16613	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:12	2017-06-15 10:49:47
18010	16614	DEPUTE	1968-08-13 00:00:00	\N	1971-11-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:12	2017-06-15 10:49:47
18012	16616	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:12	2017-06-15 10:49:47
18013	16617	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:12	2017-06-15 10:49:47
18014	16618	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:13	2017-06-15 10:49:47
18015	16619	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:13	2017-06-15 10:49:47
18016	16620	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:13	2017-06-15 10:49:47
18017	16621	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:13	2017-06-15 10:49:47
18018	16622	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:13	2017-06-15 10:49:47
18019	16623	DEPUTE	2007-06-20 00:00:00	\N	2011-05-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:13	2017-06-15 10:49:47
18020	16624	DEPUTE	1993-05-02 00:00:00	\N	1995-07-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:13	2017-06-29 09:18:51
18021	16625	DEPUTE	1995-12-08 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:13	2017-06-29 09:18:51
18022	16626	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:13	2017-06-15 10:49:47
18023	16627	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:13	2017-06-15 10:49:47
18024	16628	DEPUTE	1981-07-02 00:00:00	\N	1986-03-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:13	2017-06-15 10:49:47
18025	16629	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:13	2017-06-15 10:49:47
18026	16630	DEPUTE	1986-12-10 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:13	2017-06-15 10:49:48
18027	16631	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:13	2017-06-15 10:49:48
18028	16632	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:13	2017-06-15 10:49:48
18029	16633	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:13	2017-06-15 10:49:48
18030	16634	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:13	2017-06-15 10:49:48
18031	16635	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:13	2017-06-15 10:49:48
18032	16636	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:13	2017-06-15 10:49:48
18033	16637	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:13	2017-06-15 10:49:48
18034	16638	DEPUTE	1984-08-24 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:13	2017-06-15 10:49:48
18035	16639	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:13	2017-06-15 10:49:48
18036	16640	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:13	2017-06-15 10:49:48
18037	16641	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:13	2017-06-15 10:49:48
18038	16642	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:13	2017-06-15 10:49:48
18039	16643	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:13	2017-06-15 10:49:48
18040	16644	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:13	2017-06-15 10:49:48
18041	16645	DEPUTE	1993-04-02 00:00:00	\N	1996-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:14	2017-06-29 09:18:51
18042	16646	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:14	2017-06-15 10:49:48
18043	16647	DEPUTE	2007-06-20 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:14	2017-06-15 10:49:48
18044	16648	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:14	2017-06-29 09:18:51
18045	16649	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:14	2017-06-15 10:49:48
18046	16650	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:14	2017-06-15 10:49:48
18047	16651	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:14	2017-06-15 10:49:48
18048	16652	DEPUTE	1967-04-02 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:14	2017-06-15 10:49:48
18049	16653	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:14	2017-06-15 10:49:48
18050	16654	DEPUTE	1973-04-03 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:14	2017-06-15 10:49:48
18052	16656	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:14	2017-06-15 10:49:48
18053	16657	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:14	2017-06-15 10:49:48
18054	16658	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:14	2017-06-15 10:49:48
18055	16659	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:14	2017-06-15 10:49:48
18056	16660	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:14	2017-06-15 10:49:48
18057	16661	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:14	2017-06-15 10:49:49
18059	16663	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:14	2017-06-15 10:49:49
18060	16664	DEPUTE	1968-12-15 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:14	2017-06-29 03:43:21
18061	16665	DEPUTE	1968-07-11 00:00:00	\N	1968-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:14	2017-06-29 03:43:21
18827	17431	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:06	2017-06-15 10:50:17
18828	17432	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:06	2017-06-29 09:19:09
18829	17433	DEPUTE	1995-10-09 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:07	2017-06-29 09:19:09
18830	17434	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:07	2017-06-15 10:50:17
18831	17435	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:07	2017-06-15 10:50:17
18832	17436	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:07	2017-06-15 10:50:17
18833	17437	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:07	2017-06-15 10:50:17
18834	17438	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:07	2017-06-15 10:50:17
18835	17439	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:07	2017-06-15 10:50:17
18836	17440	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:07	2017-06-15 10:50:17
18837	17441	DEPUTE	1978-04-02 00:00:00	\N	1980-09-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:07	2017-06-15 10:50:17
18838	17442	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:07	2017-06-15 10:50:17
29209	27806	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:53	\N
18839	17443	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:07	2017-06-15 10:50:17
18840	17444	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:07	2017-06-15 10:50:17
18841	17445	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:08	2017-06-15 10:50:17
18842	17446	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:08	2017-06-15 10:50:17
18843	17447	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:08	2017-06-15 10:50:17
18844	17448	DEPUTE	2000-04-28 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:08	2017-06-15 10:50:17
18845	17449	DEPUTE	1992-05-05 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:08	2017-06-15 10:50:17
18846	17450	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:08	2017-06-15 10:50:18
18847	17451	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:08	2017-06-15 10:50:18
18848	17452	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:09	2017-06-15 10:50:18
18849	17453	DEPUTE	1981-07-02 00:00:00	\N	1984-08-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:09	2017-06-15 10:50:18
18850	17454	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:09	2017-06-15 10:50:18
18851	17455	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:09	2017-06-15 10:50:18
18852	17456	DEPUTE	1988-06-06 00:00:00	\N	1992-05-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:09	2017-06-15 10:50:18
18853	17457	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:09	2017-06-15 10:50:18
18854	17458	DEPUTE	1997-06-01 00:00:00	\N	1998-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:09	2017-06-15 10:50:18
18855	17459	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:09	2017-06-15 10:50:18
18856	17460	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:09	2017-06-15 10:50:18
18857	17461	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:09	2017-06-15 10:50:18
18858	17462	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:09	2017-06-19 09:37:49
18859	17463	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:09	2017-06-15 10:50:18
18860	17464	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:10	2017-06-15 10:50:18
18861	17465	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:10	2017-06-15 10:50:18
18862	17466	DEPUTE	1988-06-06 00:00:00	\N	1988-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:10	2017-06-29 03:43:39
18863	17467	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:10	2017-06-15 10:50:18
18864	17468	DEPUTE	1988-09-19 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:10	2017-06-29 03:43:39
18865	17469	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:10	2017-06-15 10:50:18
18866	17470	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:10	2017-06-15 10:50:18
18867	17471	DEPUTE	2012-06-20 00:00:00	\N	2013-01-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:10	2017-06-29 09:19:10
18868	17472	DEPUTE	2013-03-24 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:10	2017-06-29 09:19:10
18869	17473	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:10	2017-06-15 10:50:18
18870	17474	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:10	2017-06-15 10:50:18
18871	17475	DEPUTE	2012-06-20 00:00:00	\N	2014-07-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:10	2017-06-15 10:50:18
18872	17476	DEPUTE	1978-04-03 00:00:00	\N	1980-09-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:10	2017-06-15 10:50:19
18873	17477	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:10	2017-06-15 10:50:19
18874	17478	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:11	2017-06-15 10:50:19
18875	17479	DEPUTE	1994-11-18 00:00:00	\N	1995-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:11	2017-06-15 10:50:19
18876	17480	DEPUTE	1958-12-09 00:00:00	\N	1962-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:11	2017-06-15 10:50:19
18877	17481	DEPUTE	1962-12-06 00:00:00	\N	1963-01-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:11	2017-06-15 10:50:19
18878	17482	DEPUTE	1967-04-03 00:00:00	\N	1967-05-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:11	2017-06-15 10:50:19
18879	17483	DEPUTE	1968-07-11 00:00:00	\N	1968-08-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:11	2017-06-15 10:50:19
18880	17484	DEPUTE	1973-04-02 00:00:00	\N	1973-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:11	2017-06-15 10:50:19
18881	17485	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:11	2017-06-15 10:50:19
18882	17486	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:11	2017-06-15 10:50:19
18883	17487	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:11	2017-06-15 10:50:19
18884	17488	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:11	2017-06-15 10:50:19
18885	17489	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:11	2017-06-15 10:50:19
18886	17490	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:11	2017-06-15 10:50:19
18887	17491	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:11	2017-06-15 10:50:19
18888	17492	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:11	2017-06-15 10:50:19
18889	17493	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:11	2017-06-15 10:50:19
18890	17494	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:11	2017-06-15 10:50:19
18891	17495	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:12	2017-06-15 10:50:19
18892	17496	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:12	2017-06-15 10:50:19
18893	17497	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:12	2017-06-15 10:50:19
18894	17498	DEPUTE	1988-06-13 00:00:00	\N	1990-08-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:12	2017-06-15 10:50:19
18896	17500	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:12	2017-06-15 10:50:20
18897	17501	DEPUTE	1992-05-03 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:12	2017-06-15 10:50:20
18898	17502	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:12	2017-06-15 10:50:20
18899	17503	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:12	2017-06-15 10:50:20
18900	17504	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:12	2017-06-15 10:50:20
18901	17505	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:12	2017-06-15 10:50:20
18902	17506	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:12	2017-06-15 10:50:20
18903	17507	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:12	2017-06-15 10:50:20
18905	17509	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:12	2017-06-15 10:50:20
29210	27807	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:53	\N
18906	17510	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:12	2017-06-15 10:50:20
18907	17511	DEPUTE	1981-07-02 00:00:00	\N	1984-04-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:12	2017-06-15 10:50:20
18908	17512	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:12	2017-06-15 10:50:20
18909	17513	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:12	2017-06-15 10:50:20
18910	17514	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:12	2017-06-15 10:50:20
18911	17515	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:12	2017-06-15 10:50:20
18912	17516	DEPUTE	2007-06-20 00:00:00	\N	2010-12-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:12	2017-06-20 03:43:30
18914	17518	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:13	2017-06-19 09:37:50
18915	17519	DEPUTE	2000-04-28 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:13	2017-06-15 10:50:20
18916	17520	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:13	2017-06-15 10:50:20
18917	17521	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:13	2017-06-15 10:50:20
18918	17522	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:13	2017-06-15 10:50:20
18919	17523	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:13	2017-06-19 09:37:50
18920	17524	DEPUTE	1988-07-29 00:00:00	\N	1991-04-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:13	2017-06-15 10:50:20
18922	17526	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:13	2017-06-15 10:50:20
18923	17527	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:13	2017-06-15 10:50:20
18924	17528	DEPUTE	2002-06-19 00:00:00	\N	2007-04-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:13	2017-06-15 10:50:20
18925	17529	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:13	2017-06-15 10:50:20
18926	17530	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:13	2017-06-19 09:37:50
18927	17531	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:13	2017-06-15 10:50:21
18928	17532	DEPUTE	1997-05-25 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:13	2017-06-15 10:50:21
18929	17533	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:13	2017-06-15 10:50:21
18930	17534	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:13	2017-06-29 03:43:38
18931	17535	DEPUTE	2010-12-14 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:13	2017-06-29 03:43:38
18933	17537	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:14	2017-06-15 10:50:21
18934	17538	DEPUTE	1995-12-11 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:14	2017-06-28 03:43:42
18935	17539	DEPUTE	1999-10-02 00:00:00	\N	2000-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:14	2017-06-29 09:19:11
18936	17540	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:14	2017-06-15 10:50:21
18937	17541	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:14	2017-06-15 10:50:21
18938	17542	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:14	2017-06-19 09:37:51
18939	17543	DEPUTE	1996-10-01 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:14	2017-06-28 03:43:42
18940	17544	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:14	2017-06-29 09:19:11
18941	17545	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:14	2017-06-15 10:50:21
18942	17546	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:14	2017-06-15 10:50:21
18943	17547	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:14	2017-06-15 10:50:21
18944	17548	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:14	2017-06-19 09:37:51
18945	17549	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:14	2017-06-15 10:50:21
18946	17550	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:14	2017-06-15 10:50:21
18947	17551	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:14	2017-06-15 10:50:21
18948	17552	DEPUTE	2007-06-20 00:00:00	\N	2008-09-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:14	2017-06-15 10:50:21
18949	17553	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:15	2017-06-15 10:50:21
18950	17554	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:15	2017-06-15 10:50:21
18951	17555	DEPUTE	1993-12-13 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:15	2017-06-29 03:43:41
18952	17556	DEPUTE	1993-04-02 00:00:00	\N	1993-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:15	2017-06-29 03:43:41
18953	17557	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:15	2017-06-15 10:50:21
18954	17558	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:15	2017-06-15 10:50:21
18955	17559	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:15	2017-06-15 10:50:21
18956	17560	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:15	2017-06-19 09:37:51
18957	17561	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:15	2017-06-15 10:50:22
18958	17562	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:15	2017-06-15 10:50:22
18959	17563	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:15	2017-06-15 10:50:22
18960	17564	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:15	2017-06-15 10:50:22
18961	17565	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:15	2017-06-19 09:37:51
18962	17566	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:15	2017-06-15 10:50:22
18963	17567	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:15	2017-06-15 10:50:22
18964	17568	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:15	2017-06-15 10:50:22
18965	17569	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:15	2017-06-15 10:50:22
18966	17570	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:15	2017-06-15 10:50:22
18967	17571	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:15	2017-06-15 10:50:22
18968	17572	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:16	2017-06-15 10:50:22
18969	17573	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:16	2017-06-15 10:50:22
18970	17574	DEPUTE	1988-04-05 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:16	2017-06-15 10:50:22
18971	17575	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:16	2017-06-15 10:50:22
18972	17576	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:16	2017-06-15 10:50:22
18973	17577	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:16	2017-06-15 10:50:22
29211	27808	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:53	\N
18974	17578	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:16	2017-06-15 10:50:22
18975	17579	DEPUTE	2007-06-20 00:00:00	\N	2009-08-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:16	2017-06-15 10:50:22
18976	17580	DEPUTE	1985-03-30 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:16	2017-06-15 10:50:22
18977	17581	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:16	2017-06-15 10:50:22
18978	17582	DEPUTE	1984-08-24 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:16	2017-06-15 10:50:22
18979	17583	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:16	2017-06-15 10:50:22
18980	17584	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:16	2017-06-15 10:50:22
18981	17585	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:16	2017-06-15 10:50:22
18982	17586	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:16	2017-06-15 10:50:22
18983	17587	DEPUTE	1981-07-25 00:00:00	\N	1986-03-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:16	2017-06-15 10:50:22
18984	17588	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:17	2017-06-15 10:50:22
18985	17589	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:17	2017-06-15 10:50:22
18986	17590	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:17	2017-06-15 10:50:22
18987	17591	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:17	2017-06-15 10:50:22
18988	17592	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:17	2017-06-15 10:50:23
18989	17593	DEPUTE	1997-06-01 00:00:00	\N	1997-12-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:17	2017-06-15 10:50:23
18990	17594	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:17	2017-06-15 10:50:23
18991	17595	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:17	2017-06-15 10:50:23
18992	17596	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:17	2017-06-15 10:50:23
18993	17597	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:17	2017-06-15 10:50:23
18994	17598	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:17	2017-06-15 10:50:23
18995	17599	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:17	2017-06-15 10:50:23
18996	17600	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:17	2017-06-15 10:50:23
18997	17601	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:17	2017-06-15 10:50:23
18998	17602	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:17	2017-06-15 10:50:23
18999	17603	DEPUTE	1998-11-29 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:17	2017-06-15 10:50:23
19000	17604	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:17	2017-06-15 10:50:23
19001	17605	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:17	2017-06-15 10:50:23
19002	17606	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:17	2017-06-19 09:37:52
19003	17607	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:17	2017-06-15 10:50:23
19004	17608	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:18	2017-06-15 10:50:23
19005	17609	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:18	2017-06-15 10:50:23
19006	17610	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:18	2017-06-15 10:50:23
19007	17611	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:18	2017-06-15 10:50:23
19008	17612	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:18	2017-06-15 10:50:23
19009	17613	DEPUTE	1984-08-20 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:18	2017-06-15 10:50:23
19011	17615	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:18	2017-06-15 10:50:23
19012	17616	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:18	2017-06-15 10:50:23
19013	17617	DEPUTE	2002-06-19 00:00:00	\N	2002-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:18	2017-06-15 10:50:23
19015	17619	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:18	2017-06-15 10:50:24
19016	17620	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:18	2017-06-15 10:50:24
19206	17810	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:31	2017-06-29 09:19:17
19207	17811	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:31	2017-06-15 10:50:31
19208	17812	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:31	2017-06-15 10:50:31
19209	17813	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:31	2017-06-15 10:50:31
19210	17814	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:31	2017-06-29 09:19:17
19211	17815	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:31	2017-06-29 09:19:18
19212	17816	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:31	2017-06-29 03:43:48
19213	17817	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:31	2017-06-29 09:19:17
19214	17818	SECAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:31	2017-06-29 09:19:17
19215	17819	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:32	2017-06-15 10:50:31
19216	17820	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:32	2017-06-15 10:50:31
19217	17821	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:32	2017-06-29 09:19:18
19218	17822	SECAN	2004-10-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:32	2017-06-29 03:43:45
19219	17823	SECAN	2009-10-06 00:00:00	\N	2010-10-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:32	2017-06-29 09:19:18
19221	17825	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:33	2017-06-15 10:50:31
19222	17826	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:33	2017-06-15 10:50:31
19223	17827	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:33	2017-06-15 10:50:31
19224	17828	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:33	2017-06-15 10:50:31
19225	17829	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:33	2017-06-15 10:50:32
19226	17830	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:33	2017-06-15 10:50:32
19227	17831	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:33	2017-06-15 10:50:32
19228	17832	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:33	2017-06-15 10:50:32
19229	17833	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:33	2017-06-15 10:50:32
19230	17834	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:33	2017-06-15 10:50:32
29212	27809	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:53	\N
19231	17835	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:33	2017-06-15 10:50:32
19232	17836	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:33	2017-06-15 10:50:32
19233	17837	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:33	2017-06-15 10:50:32
19234	17838	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:33	2017-06-15 10:50:32
19235	17839	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:33	2017-06-15 10:50:32
19236	17840	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:33	2017-06-15 10:50:32
19237	17841	DEPUTE	1988-06-13 00:00:00	\N	1992-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:33	2017-06-15 10:50:32
19238	17842	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:33	2017-06-15 10:50:32
19239	17843	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:33	2017-06-15 10:50:32
19240	17844	DEPUTE	1973-04-02 00:00:00	\N	1973-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:33	2017-06-29 09:19:18
19241	17845	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:33	2017-06-15 10:50:32
19242	17846	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:33	2017-06-15 10:50:32
19243	17847	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:33	2017-06-15 10:50:32
19244	17848	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:33	2017-06-15 10:50:32
19245	17849	DEPUTE	1976-05-09 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:33	2017-06-29 09:19:18
19246	17850	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:33	2017-06-15 10:50:32
19247	17851	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:33	2017-06-15 10:50:32
19248	17852	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:33	2017-06-15 10:50:32
19249	17853	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:33	2017-06-15 10:50:32
19250	17854	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:33	2017-06-15 10:50:32
19251	17855	DEPUTE	1975-06-15 00:00:00	\N	1976-09-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:33	2017-06-15 10:50:32
19252	17856	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:33	2017-06-15 10:50:32
19253	17857	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:33	2017-06-15 10:50:32
19254	17858	DEPUTE	1993-04-02 00:00:00	\N	1995-07-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:33	2017-06-15 10:50:32
19255	17859	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:33	2017-06-15 10:50:32
19256	17860	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:34	2017-06-15 10:50:33
19257	17861	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:34	2017-06-15 10:50:33
19258	17862	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:34	2017-06-15 10:50:33
19260	17864	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:34	2017-06-15 10:50:33
19261	17865	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:34	2017-06-15 10:50:33
19262	17866	SECAN	2002-06-26 00:00:00	\N	2004-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:34	2017-06-28 03:43:50
19263	17867	DEPUTE	2002-06-19 00:00:00	\N	2004-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:34	2017-06-28 03:43:50
19264	17868	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:34	2017-06-15 10:50:33
19265	17869	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:34	2017-06-15 10:50:33
19266	17870	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:34	2017-06-15 10:50:33
19267	17871	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:34	2017-06-15 10:50:33
19268	17872	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:34	2017-06-15 10:50:33
19269	17873	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:34	2017-06-15 10:50:33
19270	17874	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:34	2017-06-15 10:50:33
19271	17875	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:34	2017-06-15 10:50:33
19272	17876	DEPUTE	1962-12-06 00:00:00	\N	1964-12-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:34	2017-06-15 10:50:33
19273	17877	DEPUTE	2011-05-06 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:34	2017-06-15 10:50:33
19274	17878	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:34	2017-06-19 09:38:02
19275	17879	DEPUTE	1995-12-10 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:34	2017-06-15 10:50:33
19276	17880	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:34	2017-06-15 10:50:33
19277	17881	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:34	2017-06-15 10:50:33
19278	17882	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:34	2017-06-15 10:50:33
19279	17883	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:34	2017-06-29 09:19:19
19280	17884	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:34	2017-06-28 03:43:50
19281	17885	VICPDTAN	2007-06-27 00:00:00	\N	2009-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:34	2017-06-29 09:19:19
19282	17886	SECAN	2012-06-27 00:00:00	\N	2013-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:34	2017-06-29 03:43:46
19283	17887	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:34	2017-06-29 09:19:19
19285	17889	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:34	2017-06-29 09:19:19
19286	17890	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:34	2017-06-29 03:43:46
19287	17891	DEPUTE	1982-08-30 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:34	2017-06-15 10:50:33
19288	17892	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:34	2017-06-15 10:50:34
19289	17893	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:34	2017-06-15 10:50:34
19290	17894	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:34	2017-06-15 10:50:34
19292	17896	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:34	2017-06-15 10:50:34
19293	17897	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:34	2017-06-15 10:50:34
19294	17898	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:34	2017-06-15 10:50:34
19295	17899	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:34	2017-06-15 10:50:34
19296	17900	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:35	2017-06-15 10:50:34
19297	17901	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:35	2017-06-15 10:50:34
19298	17902	DEPUTE	1997-06-01 00:00:00	\N	2001-04-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:35	2017-06-29 03:43:49
29213	27810	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:53	\N
19300	17904	DEPUTE	2009-07-24 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:35	2017-06-29 03:43:49
19301	17905	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:35	2017-06-29 03:43:49
19302	17906	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:35	2017-06-19 09:38:02
19303	17907	VICPDTAN	1997-06-13 00:00:00	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:35	2017-06-29 03:43:49
19304	17908	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:35	2017-06-15 10:50:34
19305	17909	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:35	2017-06-15 10:50:34
19306	17910	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:35	2017-06-15 10:50:34
19307	17911	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:35	2017-06-15 10:50:34
19308	17912	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:35	2017-06-15 10:50:34
19309	17913	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:35	2017-06-15 10:50:34
19310	17914	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:35	2017-06-29 03:43:50
19311	17915	DEPUTE	1988-06-13 00:00:00	\N	1991-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:35	2017-06-15 10:50:34
19312	17916	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:35	2017-06-15 10:50:34
19313	17917	VICPDTAN	1988-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:35	2017-06-29 03:43:50
19315	17919	DEPUTE	1995-09-24 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:35	2017-06-29 03:43:47
19316	17920	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:35	2017-06-29 03:43:47
19317	17921	DEPUTE	1997-05-25 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:35	2017-06-15 10:50:34
19318	17922	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:35	2017-06-29 09:19:19
19319	17923	DEPUTE	2005-03-14 00:00:00	\N	2005-07-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:35	2017-06-29 09:19:19
19320	17924	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:35	2017-06-15 10:50:35
19321	17925	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:35	2017-06-15 10:50:35
19322	17926	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:35	2017-06-15 10:50:35
19323	17927	DEPUTE	2007-06-20 00:00:00	\N	2008-02-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:35	2017-06-15 10:50:35
19324	17928	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:35	2017-06-15 10:50:35
19325	17929	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:35	2017-06-15 10:50:35
19326	17930	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:35	2017-06-15 10:50:35
19327	17931	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:35	2017-06-15 10:50:35
19328	17932	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:35	2017-06-15 10:50:35
19329	17933	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:35	2017-06-15 10:50:35
19330	17934	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:36	2017-06-15 10:50:35
19331	17935	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:36	2017-06-28 03:43:51
19332	17936	SECAN	2008-10-01 00:00:00	\N	2009-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:36	2017-06-29 09:19:20
19333	17937	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:36	2017-06-19 09:38:03
19334	17938	SECAN	2004-10-01 00:00:00	\N	2005-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:36	2017-06-28 03:43:51
19336	17940	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:36	2017-06-15 10:50:35
19337	17941	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:36	2017-06-15 10:50:35
19338	17942	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:36	2017-06-15 10:50:35
19339	17943	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:36	2017-06-15 10:50:35
19340	17944	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:36	2017-06-15 10:50:35
19341	17945	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:36	2017-06-15 10:50:35
19342	17946	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:36	2017-06-15 10:50:35
19343	17947	DEPUTE	2007-06-20 00:00:00	\N	2011-07-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:36	2017-06-15 10:50:35
19344	17948	DEPUTE	2012-06-20 00:00:00	\N	2016-08-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:36	2017-06-15 10:50:35
19345	17949	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:36	2017-06-15 10:50:35
19346	17950	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:36	2017-06-15 10:50:35
19347	17951	DEPUTE	1981-07-02 00:00:00	\N	1983-02-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:36	2017-06-15 10:50:35
19348	17952	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:36	2017-06-19 09:38:03
19349	17953	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:36	2017-06-15 10:50:35
19350	17954	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:37	2017-06-15 10:50:36
19351	17955	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:37	2017-06-15 10:50:36
19352	17956	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:37	2017-06-15 10:50:36
19353	17957	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:37	2017-06-15 10:50:36
19354	17958	DEPUTE	2012-06-26 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:37	2017-06-27 03:43:42
19355	17959	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:37	2017-06-27 03:43:42
19356	17960	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:37	2017-06-15 10:50:36
19357	17961	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:37	2017-06-15 10:50:36
19358	17962	DEPUTE	1993-05-02 00:00:00	\N	1995-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:37	2017-06-15 10:50:36
19359	17963	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:37	2017-06-15 10:50:36
19360	17964	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:37	2017-06-15 10:50:36
19361	17965	SECAN	2010-10-05 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:37	2017-06-29 09:19:20
19362	17966	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:37	2017-06-19 09:38:03
19363	17967	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:37	2017-06-29 09:19:20
19364	17968	SECAN	2007-06-27 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:37	2017-06-29 09:19:20
19365	17969	DEPUTE	2008-02-04 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:37	2017-06-15 10:50:36
19366	17970	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:37	2017-06-15 10:50:36
19367	17971	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:38	2017-06-15 10:50:36
19368	17972	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:38	2017-06-15 10:50:36
19369	17973	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:38	2017-06-15 10:50:36
19370	17974	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:38	2017-06-15 10:50:36
19371	17975	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:38	2017-06-15 10:50:36
19372	17976	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:38	2017-06-15 10:50:36
19373	17977	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:38	2017-06-15 10:50:36
19374	17978	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:38	2017-06-29 03:43:48
19375	17979	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:38	2017-06-28 03:43:52
19376	17980	DEPUTE	1997-06-01 00:00:00	\N	2000-04-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:38	2017-06-15 10:50:36
19377	17981	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:38	2017-06-15 10:50:36
19378	17982	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:38	2017-06-19 09:38:04
19379	17983	SECAN	1988-06-24 00:00:00	\N	1992-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:38	2017-06-28 03:43:52
19380	17984	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:38	2017-06-29 03:43:51
19381	17985	SECAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:38	2017-06-29 03:43:51
19383	17987	DEPUTE	1978-04-02 00:00:00	\N	1978-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:38	2017-06-15 10:50:37
19384	17988	DEPUTE	1986-04-02 00:00:00	\N	1986-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:38	2017-06-29 03:43:48
19385	17989	DEPUTE	1986-10-01 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:38	2017-06-29 03:43:48
19386	17990	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:39	2017-06-15 10:50:37
19387	17991	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:39	2017-06-15 10:50:37
19388	17992	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:39	2017-06-15 10:50:37
19389	17993	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:39	2017-06-29 09:19:21
19391	17995	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:39	2017-06-15 10:50:37
19392	17996	PDTAN	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:39	2017-06-29 09:19:21
19393	17997	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:39	2017-06-15 10:50:37
19394	17998	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:39	2017-06-15 10:50:37
19395	17999	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:39	2017-06-15 10:50:37
19017	17621	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:18	2017-06-15 10:50:24
19018	17622	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:18	2017-06-15 10:50:24
19019	17623	SECAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:18	2017-06-29 03:43:42
19020	17624	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:18	2017-06-29 09:19:13
19021	17625	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:18	2017-06-29 03:43:42
19022	17626	SECAN	1988-06-24 00:00:00	\N	1992-10-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:18	2017-06-29 09:19:13
19023	17627	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:18	2017-06-15 10:50:24
19024	17628	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:18	2017-06-15 10:50:24
19025	17629	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:18	2017-06-15 10:50:24
19026	17630	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:18	2017-06-15 10:50:24
19027	17631	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:18	2017-06-15 10:50:24
19028	17632	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:18	2017-06-15 10:50:24
19029	17633	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:18	2017-06-15 10:50:24
19030	17634	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:19	2017-06-15 10:50:24
19031	17635	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:19	2017-06-15 10:50:24
19032	17636	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:19	2017-06-15 10:50:24
19033	17637	DEPUTE	1981-07-02 00:00:00	\N	1981-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:19	2017-06-15 10:50:24
19034	17638	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:19	2017-06-15 10:50:24
19035	17639	DEPUTE	1988-06-13 00:00:00	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:19	2017-06-15 10:50:24
19036	17640	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:19	2017-06-15 10:50:24
19037	17641	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:19	2017-06-15 10:50:24
19038	17642	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:19	2017-06-15 10:50:24
19039	17643	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:19	2017-06-15 10:50:24
19040	17644	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:19	2017-06-15 10:50:24
19041	17645	DEPUTE	1993-04-02 00:00:00	\N	1993-05-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:19	2017-06-15 10:50:24
19042	17646	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:19	2017-06-15 10:50:24
19043	17647	DEPUTE	1973-04-02 00:00:00	\N	1973-05-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:19	2017-06-15 10:50:24
19044	17648	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:19	2017-06-15 10:50:24
19045	17649	VICPDTAN	1992-04-02 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:19	2017-06-29 03:43:43
19046	17650	VICPDTAN	1993-04-07 00:00:00	\N	1993-04-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:19	2017-06-29 09:19:13
19047	17651	DEPUTE	1997-06-01 00:00:00	\N	1998-03-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:19	2017-06-29 03:43:40
19048	17652	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:19	2017-06-29 03:43:43
19049	17653	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:19	2017-06-29 09:19:13
19050	17654	VICPDTAN	1997-06-13 00:00:00	\N	1998-03-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:19	2017-06-29 03:43:40
19051	17655	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:19	2017-06-15 10:50:25
19052	17656	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:20	2017-06-15 10:50:25
19053	17657	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:20	2017-06-15 10:50:25
19054	17658	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:20	2017-06-15 10:50:25
19055	17659	DEPUTE	1973-04-02 00:00:00	\N	1976-02-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:20	2017-06-15 10:50:25
19056	17660	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:20	2017-06-15 10:50:25
19057	17661	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:20	2017-06-15 10:50:25
19058	17662	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:20	2017-06-15 10:50:25
19059	17663	DEPUTE	1978-04-03 00:00:00	\N	1978-05-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:20	2017-06-15 10:50:25
19060	17664	DEPUTE	1973-04-02 00:00:00	\N	1976-02-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:20	2017-06-15 10:50:25
19061	17665	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:20	2017-06-15 10:50:25
19062	17666	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:20	2017-06-15 10:50:25
19063	17667	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:20	2017-06-15 10:50:25
19064	17668	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:20	2017-06-29 09:19:13
19065	17669	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:20	2017-06-29 09:19:13
19067	17671	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:20	2017-06-15 10:50:25
19068	17672	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:20	2017-06-15 10:50:25
19069	17673	DEPUTE	1996-10-20 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:20	2017-06-15 10:50:25
19070	17674	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:20	2017-06-15 10:50:25
19071	17675	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:20	2017-06-15 10:50:25
19072	17676	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:20	2017-06-15 10:50:25
19073	17677	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:20	2017-06-15 10:50:25
19074	17678	DEPUTE	1988-06-06 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:20	2017-06-15 10:50:25
19075	17679	DEPUTE	1993-04-02 00:00:00	\N	1996-02-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:20	2017-06-15 10:50:25
19076	17680	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:21	2017-06-15 10:50:25
19077	17681	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:21	2017-06-15 10:50:25
19078	17682	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:21	2017-06-15 10:50:26
19079	17683	DEPUTE	2005-07-03 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:21	2017-06-15 10:50:26
19080	17684	DEPUTE	2010-04-23 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:21	2017-06-15 10:50:26
19081	17685	DEPUTE	2014-12-15 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:21	2017-06-19 09:37:54
19082	17686	DEPUTE	1999-07-23 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:21	2017-06-15 10:50:26
19083	17687	DEPUTE	1982-05-24 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:21	2017-06-15 10:50:26
19084	17688	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:21	2017-06-15 10:50:26
19085	17689	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:21	2017-06-15 10:50:26
19086	17690	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:21	2017-06-15 10:50:26
19087	17691	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:22	2017-06-15 10:50:26
19088	17692	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:22	2017-06-15 10:50:26
19089	17693	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:22	2017-06-15 10:50:26
19090	17694	PDTAN	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:22	2017-06-29 09:19:14
19091	17695	DEPUTE	1988-06-13 00:00:00	\N	1990-11-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:22	2017-06-15 10:50:26
19092	17696	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:22	2017-06-29 09:19:14
19093	17697	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:22	2017-06-15 10:50:26
19094	17698	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:22	2017-06-15 10:50:26
19095	17699	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:22	2017-06-15 10:50:26
19096	17700	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:22	2017-06-15 10:50:26
19097	17701	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:22	2017-06-15 10:50:26
19098	17702	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:22	2017-06-15 10:50:26
19099	17703	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:22	2017-06-15 10:50:26
19101	17705	DEPUTE	1974-09-29 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:23	2017-06-29 03:43:41
19102	17706	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:23	2017-06-15 10:50:27
19103	17707	DEPUTE	1969-10-19 00:00:00	\N	1971-03-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:23	2017-06-29 03:43:45
19104	17708	DEPUTE	1968-07-11 00:00:00	\N	1968-08-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:23	2017-06-29 03:43:45
19105	17709	DEPUTE	1973-04-02 00:00:00	\N	1973-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:23	2017-06-29 03:43:41
19106	17710	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:23	2017-06-15 10:50:27
19107	17711	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:23	2017-06-15 10:50:27
19109	17713	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:23	2017-06-28 03:43:42
19110	17714	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:23	2017-06-15 10:50:27
19111	17715	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:23	2017-06-15 10:50:27
19112	17716	VICPDTAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:23	2017-06-28 03:43:42
19113	17717	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:23	2017-06-15 10:50:27
19114	17718	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:23	2017-06-15 10:50:27
19115	17719	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:23	2017-06-15 10:50:27
19116	17720	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:23	2017-06-15 10:50:27
19117	17721	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:23	2017-06-15 10:50:27
19118	17722	DEPUTE	1988-06-13 00:00:00	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:23	2017-06-15 10:50:27
19119	17723	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:23	2017-06-15 10:50:27
19121	17725	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:24	2017-06-15 10:50:27
19122	17726	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:24	2017-06-15 10:50:27
19123	17727	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:24	2017-06-15 10:50:27
29214	27811	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:53	\N
19124	17728	DEPUTE	1988-06-06 00:00:00	\N	1991-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:24	2017-06-15 10:50:27
19125	17729	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:24	2017-06-15 10:50:27
19126	17730	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:24	2017-06-15 10:50:27
19127	17731	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:24	2017-06-15 10:50:27
19128	17732	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:24	2017-06-15 10:50:27
19129	17733	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:24	2017-06-15 10:50:27
19130	17734	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:24	2017-06-15 10:50:28
19131	17735	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:24	2017-06-29 09:19:15
19132	17736	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:24	2017-06-15 10:50:28
19133	17737	SECAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:24	2017-06-29 09:19:15
19134	17738	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:24	2017-06-29 09:19:15
19135	17739	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:24	2017-06-15 10:50:28
19136	17740	DEPUTE	2001-11-20 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:24	2017-06-15 10:50:28
19137	17741	DEPUTE	1992-05-03 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:25	2017-06-15 10:50:28
19138	17742	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:25	2017-06-15 10:50:28
19139	17743	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:25	2017-06-29 09:19:15
19140	17744	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:25	2017-06-15 10:50:28
19141	17745	VICPDTAN	2002-06-26 00:00:00	\N	2005-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:25	2017-06-29 09:19:15
19142	17746	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:25	2017-06-15 10:50:28
19143	17747	VICPDTAN	1993-04-14 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:25	2017-06-29 09:19:15
19144	17748	VICPDTAN	1994-04-02 00:00:00	\N	1995-05-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:25	2017-06-29 09:19:15
19145	17749	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:25	2017-06-29 03:43:46
19146	17750	VICPDTAN	2005-10-04 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:25	2017-06-29 09:19:15
19147	17751	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:25	2017-06-15 10:50:28
19148	17752	DEPUTE	1980-11-30 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:25	2017-06-15 10:50:28
19149	17753	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:25	2017-06-15 10:50:28
19150	17754	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:25	2017-06-15 10:50:28
19151	17755	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:26	2017-06-15 10:50:28
19152	17756	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:26	2017-06-15 10:50:28
19153	17757	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:26	2017-06-15 10:50:28
19154	17758	DEPUTE	1986-04-02 00:00:00	\N	1986-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:26	2017-06-15 10:50:28
19155	17759	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:26	2017-06-15 10:50:29
19156	17760	DEPUTE	1969-09-21 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:26	2017-06-15 10:50:29
19157	17761	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:26	2017-06-15 10:50:29
19158	17762	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:26	2017-06-15 10:50:29
19159	17763	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:26	2017-06-15 10:50:29
19160	17764	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:26	2017-06-15 10:50:29
19161	17765	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:26	2017-06-15 10:50:29
19162	17766	DEPUTE	1985-09-21 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:26	2017-06-15 10:50:29
19163	17767	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:26	2017-06-15 10:50:29
19164	17768	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:26	2017-06-15 10:50:29
19165	17769	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:27	2017-06-15 10:50:29
19166	17770	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:27	2017-06-15 10:50:29
19167	17771	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:27	2017-06-15 10:50:29
19168	17772	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:27	2017-06-15 10:50:29
19169	17773	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:27	2017-06-15 10:50:29
19170	17774	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:27	2017-06-15 10:50:29
19171	17775	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:27	2017-06-19 09:37:58
19172	17776	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:27	2017-06-15 10:50:29
19173	17777	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:27	2017-06-15 10:50:29
19174	17778	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:28	2017-06-15 10:50:29
19175	17779	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:28	2017-06-15 10:50:29
19176	17780	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:28	2017-06-15 10:50:29
19177	17781	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:28	2017-06-15 10:50:29
19178	17782	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:28	2017-06-15 10:50:29
19179	17783	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:29	2017-06-15 10:50:29
19180	17784	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:29	2017-06-15 10:50:30
19181	17785	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:29	2017-06-15 10:50:30
19182	17786	DEPUTE	1993-04-02 00:00:00	\N	1995-09-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:29	2017-06-15 10:50:30
19183	17787	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:29	2017-06-15 10:50:30
19184	17788	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:29	2017-06-15 10:50:30
19185	17789	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:29	2017-06-15 10:50:30
19186	17790	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:29	2017-06-15 10:50:30
19188	17792	DEPUTE	1973-04-02 00:00:00	\N	1974-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:30	2017-06-15 10:50:30
19189	17793	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:30	2017-06-15 10:50:30
19190	17794	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:30	2017-06-15 10:50:30
19191	17795	DEPUTE	1993-04-02 00:00:00	\N	1994-08-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:30	2017-06-15 10:50:30
19192	17796	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:30	2017-06-15 10:50:30
19194	17798	DEPUTE	1993-04-02 00:00:00	\N	1994-11-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:30	2017-06-29 03:43:47
19195	17799	SECAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:30	2017-06-29 09:19:17
19196	17800	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:30	2017-06-15 10:50:30
19197	17801	DEPUTE	1995-09-13 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:30	2017-06-29 03:43:47
19198	17802	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:30	2017-06-29 09:19:17
19199	17803	DEPUTE	2000-04-28 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:31	2017-06-15 10:50:30
19200	17804	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:31	2017-06-15 10:50:31
19202	17806	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:31	2017-06-15 10:50:31
19203	17807	VICPDTAN	1988-06-24 00:00:00	\N	1989-04-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:31	2017-06-29 09:19:17
19204	17808	DEPUTE	1995-09-17 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:31	2017-06-29 03:43:48
19205	17809	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:31	2017-06-29 03:43:48
18638	17242	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:53	2017-06-28 03:43:36
18639	17243	DEPUTE	1991-09-26 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:53	2017-06-29 09:19:05
18640	17244	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:53	2017-06-29 09:19:05
18641	17245	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:53	2017-06-15 10:50:10
18642	17246	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:53	2017-06-15 10:50:10
18643	17247	VICPDTAN	1986-04-04 00:00:00	\N	1987-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:53	2017-06-28 03:43:36
18644	17248	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:53	2017-06-15 10:50:10
18645	17249	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:53	2017-06-15 10:50:10
18646	17250	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:53	2017-06-15 10:50:10
18647	17251	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:53	2017-06-27 03:43:26
18648	17252	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:54	2017-06-15 10:50:10
18649	17253	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:54	2017-06-15 10:50:10
18650	17254	DEPUTE	1997-06-01 00:00:00	\N	2000-04-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:54	2017-06-29 03:43:32
18651	17255	DEPUTE	2007-06-20 00:00:00	\N	2012-06-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:54	2017-06-15 10:50:10
18652	17256	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:54	2017-06-15 10:50:10
18653	17257	PDTAN	1988-06-23 00:00:00	\N	1992-01-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:54	2017-06-27 03:43:26
18654	17258	PDTAN	1997-06-12 00:00:00	\N	2000-03-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:54	2017-06-29 03:43:32
18655	17259	DEPUTE	1978-04-02 00:00:00	\N	1980-11-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:54	2017-06-15 10:50:10
18656	17260	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:54	2017-06-15 10:50:10
18657	17261	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:54	2017-06-15 10:50:10
18658	17262	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:54	2017-06-15 10:50:11
18659	17263	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:54	2017-06-15 10:50:11
18660	17264	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:54	2017-06-15 10:50:11
18661	17265	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:54	2017-06-15 10:50:11
18662	17266	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:54	2017-06-15 10:50:11
18663	17267	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:54	2017-06-15 10:50:11
18664	17268	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:54	2017-06-15 10:50:11
18665	17269	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:54	2017-06-15 10:50:11
18666	17270	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:54	2017-06-15 10:50:11
18667	17271	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:54	2017-06-15 10:50:11
18668	17272	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:54	2017-06-15 10:50:11
18669	17273	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:54	2017-06-15 10:50:11
18670	17274	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:55	2017-06-15 10:50:11
18671	17275	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:55	2017-06-29 09:19:05
18672	17276	DEPUTE	1993-04-02 00:00:00	\N	1995-09-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:55	2017-06-29 09:19:05
18673	17277	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:55	2017-06-15 10:50:11
18674	17278	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:55	2017-06-15 10:50:11
18675	17279	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:55	2017-06-15 10:50:11
18676	17280	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:55	2017-06-15 10:50:11
18677	17281	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:55	2017-06-15 10:50:11
18678	17282	DEPUTE	1968-07-11 00:00:00	\N	1969-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:55	2017-06-15 10:50:11
18679	17283	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:55	2017-06-15 10:50:11
18680	17284	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:55	2017-06-15 10:50:11
18681	17285	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:55	2017-06-15 10:50:11
18682	17286	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:55	2017-06-15 10:50:11
18683	17287	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:55	2017-06-15 10:50:11
18684	17288	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:56	2017-06-15 10:50:11
18685	17289	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:56	2017-06-15 10:50:11
18686	17290	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:56	2017-06-15 10:50:11
18687	17291	DEPUTE	1978-04-02 00:00:00	\N	1980-09-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:56	2017-06-15 10:50:11
18689	17293	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:56	2017-06-15 10:50:12
18690	17294	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:56	2017-06-15 10:50:12
18691	17295	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:56	2017-06-15 10:50:12
18692	17296	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:56	2017-06-15 10:50:12
18693	17297	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:56	2017-06-15 10:50:12
18694	17298	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:56	2017-06-15 10:50:12
18695	17299	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:56	2017-06-15 10:50:12
18696	17300	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:56	2017-06-15 10:50:12
18697	17301	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:57	2017-06-29 09:19:06
18698	17302	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:57	2017-06-29 09:19:06
18699	17303	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:57	2017-06-29 09:19:06
18700	17304	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:57	2017-06-29 09:19:06
18701	17305	SECAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:57	2017-06-29 09:19:06
18702	17306	DEPUTE	1973-04-02 00:00:00	\N	1974-04-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:57	2017-06-15 10:50:12
18703	17307	DEPUTE	1975-07-07 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:57	2017-06-15 10:50:12
18704	17308	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:57	2017-06-15 10:50:12
18705	17309	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:57	2017-06-15 10:50:12
18706	17310	SECAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:57	2017-06-29 03:43:35
18707	17311	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:57	2017-06-29 09:19:06
18708	17312	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:57	2017-06-15 10:50:12
18709	17313	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:57	2017-06-15 10:50:12
18710	17314	SECAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:57	2017-06-29 09:19:06
18711	17315	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:57	2017-06-29 03:43:35
18712	17316	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:57	2017-06-29 03:43:35
18713	17317	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:57	2017-06-15 10:50:12
18714	17318	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:57	2017-06-15 10:50:12
18715	17319	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:57	2017-06-29 09:19:06
18717	17321	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:57	2017-06-15 10:50:12
18718	17322	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:57	2017-06-29 03:43:35
18719	17323	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:57	2017-06-29 09:19:06
18720	17324	VICPDTAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:57	2017-06-29 09:19:06
18721	17325	SECAN	1997-06-13 00:00:00	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:57	2017-06-29 09:19:06
18723	17327	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:58	2017-06-15 10:50:13
18724	17328	DEPUTE	1986-04-02 00:00:00	\N	1987-12-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:58	2017-06-15 10:50:13
18725	17329	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:58	2017-06-15 10:50:13
18726	17330	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:58	2017-06-15 10:50:13
18727	17331	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:58	2017-06-15 10:50:13
18728	17332	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:58	2017-06-15 10:50:13
18729	17333	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:58	2017-06-15 10:50:13
18731	17335	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:58	2017-06-29 09:19:06
18732	17336	VICPDTAN	2009-10-06 00:00:00	\N	2010-11-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:58	2017-06-29 09:19:06
18733	17337	DEPUTE	2007-06-20 00:00:00	\N	2010-12-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:58	2017-06-29 09:19:06
18735	17339	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:58	2017-06-29 09:19:06
18736	17340	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:59	2017-06-15 10:50:13
18737	17341	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:59	2017-06-15 10:50:13
18738	17342	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:59	2017-06-19 09:37:46
18739	17343	DEPUTE	1981-04-15 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:59	2017-06-15 10:50:13
18740	17344	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:59	2017-06-15 10:50:13
18741	17345	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:59	2017-06-15 10:50:13
18742	17346	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:59	2017-06-15 10:50:13
18743	17347	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:59	2017-06-15 10:50:13
18744	17348	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:59	2017-06-15 10:50:13
18745	17349	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:00	2017-06-15 10:50:13
18747	17351	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:00	2017-06-15 10:50:14
18748	17352	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:00	2017-06-15 10:50:14
18749	17353	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:00	2017-06-15 10:50:14
18750	17354	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:00	2017-06-15 10:50:14
18751	17355	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:00	2017-06-15 10:50:14
18752	17356	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:00	2017-06-15 10:50:14
18753	17357	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:00	2017-06-19 09:37:46
18754	17358	DEPUTE	1988-06-13 00:00:00	\N	1992-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:01	2017-06-15 10:50:14
18755	17359	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:01	2017-06-15 10:50:14
18756	17360	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:01	2017-06-15 10:50:14
18757	17361	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:01	2017-06-15 10:50:14
18758	17362	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:01	2017-06-19 09:37:46
18759	17363	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:01	2017-06-15 10:50:14
18760	17364	DEPUTE	1973-04-02 00:00:00	\N	1976-09-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:01	2017-06-15 10:50:14
18761	17365	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:01	2017-06-15 10:50:14
18762	17366	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:01	2017-06-15 10:50:14
18763	17367	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:01	2017-06-15 10:50:14
18764	17368	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:01	2017-06-15 10:50:14
18765	17369	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:01	2017-06-15 10:50:14
18766	17370	DEPUTE	1973-04-02 00:00:00	\N	1973-05-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:01	2017-06-29 03:43:36
18767	17371	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:01	2017-06-15 10:50:14
18768	17372	DEPUTE	1968-07-11 00:00:00	\N	1969-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:01	2017-06-15 10:50:14
18769	17373	DEPUTE	1975-05-25 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:01	2017-06-29 03:43:36
18770	17374	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:01	2017-06-15 10:50:14
18771	17375	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:01	2017-06-15 10:50:14
18772	17376	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:01	2017-06-15 10:50:14
18773	17377	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:01	2017-06-15 10:50:14
18774	17378	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:01	2017-06-15 10:50:14
18775	17379	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:02	2017-06-15 10:50:15
18776	17380	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:02	2017-06-15 10:50:15
18777	17381	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:02	2017-06-15 10:50:15
18778	17382	DEPUTE	1971-12-13 00:00:00	\N	1972-01-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:02	2017-06-29 09:19:07
18779	17383	DEPUTE	1968-07-11 00:00:00	\N	1968-08-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:02	2017-06-29 09:19:07
18780	17384	DEPUTE	1973-04-02 00:00:00	\N	1973-05-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:02	2017-06-15 10:50:15
18781	17385	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:02	2017-06-15 10:50:15
18782	17386	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:02	2017-06-15 10:50:15
18783	17387	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:02	2017-06-15 10:50:15
18784	17388	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:02	2017-06-15 10:50:15
18785	17389	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:02	2017-06-15 10:50:15
18786	17390	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:02	2017-06-15 10:50:15
18787	17391	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:02	2017-06-15 10:50:15
18788	17392	DEPUTE	1992-11-03 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:02	2017-06-15 10:50:15
18789	17393	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:03	2017-06-15 10:50:15
18790	17394	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:03	2017-06-15 10:50:15
18791	17395	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:03	2017-06-15 10:50:15
18792	17396	DEPUTE	1988-06-13 00:00:00	\N	1992-07-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:03	2017-06-15 10:50:15
18793	17397	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:03	2017-06-15 10:50:15
18794	17398	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:03	2017-06-15 10:50:15
18795	17399	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:03	2017-06-15 10:50:15
18796	17400	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:03	2017-06-19 09:37:47
18797	17401	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:03	2017-06-15 10:50:16
18798	17402	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:03	2017-06-15 10:50:16
18799	17403	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:03	2017-06-15 10:50:16
18800	17404	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:03	2017-06-15 10:50:16
18801	17405	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:03	2017-06-15 10:50:16
18802	17406	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:03	2017-06-15 10:50:16
18803	17407	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:03	2017-06-15 10:50:16
18804	17408	DEPUTE	2007-06-20 00:00:00	\N	2011-11-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:03	2017-06-15 10:50:16
18805	17409	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:04	2017-06-15 10:50:16
18806	17410	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:04	2017-06-15 10:50:16
18807	17411	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:04	2017-06-15 10:50:16
18808	17412	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:04	2017-06-15 10:50:16
18809	17413	DEPUTE	1981-07-02 00:00:00	\N	1984-09-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:04	2017-06-15 10:50:16
18810	17414	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:05	2017-06-15 10:50:16
18811	17415	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:05	2017-06-15 10:50:16
18812	17416	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:05	2017-06-15 10:50:16
18813	17417	DEPUTE	1973-05-06 00:00:00	\N	1974-07-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:05	2017-06-15 10:50:16
18814	17418	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:05	2017-06-15 10:50:16
18815	17419	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:05	2017-06-15 10:50:16
18816	17420	SECAN	2007-06-27 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:05	2017-06-29 09:19:09
18817	17421	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:05	2017-06-19 09:37:48
18818	17422	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:05	2017-06-29 09:19:09
18819	17423	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:05	2017-06-15 10:50:16
18821	17425	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:06	2017-06-15 10:50:16
18822	17426	DEPUTE	1962-12-06 00:00:00	\N	1963-03-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:06	2017-06-15 10:50:17
18823	17427	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:06	2017-06-15 10:50:17
18824	17428	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:06	2017-06-15 10:50:17
18825	17429	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:06	2017-06-15 10:50:17
29215	27812	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:53	\N
18826	17430	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:06	2017-06-15 10:50:17
19490	18094	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:47	2017-06-15 10:50:41
19491	18095	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:48	2017-06-15 10:50:41
19492	18096	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:48	2017-06-15 10:50:41
19493	18097	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:48	2017-06-15 10:50:41
19495	18099	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:48	2017-06-15 10:50:41
19497	18101	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:48	2017-06-15 10:50:41
19498	18102	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:48	2017-06-15 10:50:41
19499	18103	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:48	2017-06-15 10:50:41
19500	18104	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:48	2017-06-15 10:50:41
19501	18105	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:48	2017-06-15 10:50:41
19502	18106	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:48	2017-06-15 10:50:41
19503	18107	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:48	2017-06-15 10:50:41
19504	18108	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:48	2017-06-15 10:50:41
19505	18109	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:48	2017-06-15 10:50:41
19506	18110	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:48	2017-06-15 10:50:41
19507	18111	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:48	2017-06-15 10:50:42
19508	18112	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:48	2017-06-15 10:50:42
19509	18113	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:48	2017-06-15 10:50:42
19510	18114	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:48	2017-06-15 10:50:42
19511	18115	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:48	2017-06-15 10:50:42
19512	18116	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:48	2017-06-15 10:50:42
19513	18117	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:48	2017-06-15 10:50:42
19514	18118	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:48	2017-06-15 10:50:42
19515	18119	DEPUTE	1988-06-13 00:00:00	\N	1989-05-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:48	2017-06-15 10:50:42
19516	18120	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:48	2017-06-15 10:50:42
19517	18121	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:48	2017-06-15 10:50:42
19518	18122	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:48	2017-06-15 10:50:42
19519	18123	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:48	2017-06-15 10:50:42
19520	18124	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:48	2017-06-29 03:43:55
19521	18125	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:48	2017-06-15 10:50:42
19522	18126	DEPUTE	1995-09-17 00:00:00	\N	1995-12-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:48	2017-06-29 03:43:55
19523	18127	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:48	2017-06-15 10:50:42
19524	18128	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:48	2017-06-15 10:50:42
19525	18129	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:48	2017-06-15 10:50:42
19526	18130	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:48	2017-06-15 10:50:42
19527	18131	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:49	2017-06-15 10:50:42
19528	18132	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:49	2017-06-19 09:38:08
19529	18133	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:49	2017-06-15 10:50:42
19530	18134	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:49	2017-06-15 10:50:42
19531	18135	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:49	2017-06-15 10:50:42
19532	18136	DEPUTE	1983-11-05 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:49	2017-06-15 10:50:42
19533	18137	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:49	2017-06-15 10:50:42
19534	18138	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:49	2017-06-15 10:50:42
19535	18139	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:49	2017-06-15 10:50:42
19536	18140	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:49	2017-06-15 10:50:42
19537	18141	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:49	2017-06-15 10:50:42
19538	18142	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:49	2017-06-15 10:50:42
19539	18143	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:49	2017-06-29 03:43:55
19540	18144	DEPUTE	2014-05-03 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:49	2017-06-29 03:43:55
19541	18145	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:49	2017-06-15 10:50:43
19542	18146	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:49	2017-06-15 10:50:43
19543	18147	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:49	2017-06-15 10:50:43
19544	18148	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:49	2017-06-29 09:19:24
19545	18149	DEPUTE	2002-06-19 00:00:00	\N	2006-06-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:49	2017-06-15 10:50:43
19546	18150	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:49	2017-06-29 09:19:24
19547	18151	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:49	2017-06-15 10:50:43
19548	18152	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:49	2017-06-15 10:50:43
19549	18153	DEPUTE	1993-04-02 00:00:00	\N	1993-12-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:49	2017-06-15 10:50:43
19550	18154	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:49	2017-06-15 10:50:43
19551	18155	DEPUTE	1997-06-01 00:00:00	\N	2000-04-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:49	2017-06-15 10:50:43
19552	18156	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:49	2017-06-15 10:50:43
19553	18157	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:49	2017-06-15 10:50:43
19554	18158	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:49	2017-06-15 10:50:43
19555	18159	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:49	2017-06-15 10:50:43
29216	27813	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:53	\N
19556	18160	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:49	2017-06-15 10:50:43
19557	18161	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:49	2017-06-15 10:50:43
19558	18162	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:49	2017-06-15 10:50:43
19559	18163	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:49	2017-06-15 10:50:43
19560	18164	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:49	2017-06-15 10:50:43
19561	18165	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:50	2017-06-15 10:50:43
19562	18166	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:50	2017-06-15 10:50:43
19563	18167	DEPUTE	1987-10-30 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:50	2017-06-15 10:50:43
19564	18168	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:50	2017-06-15 10:50:43
19565	18169	DEPUTE	1984-08-24 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:50	2017-06-15 10:50:43
19566	18170	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:50	2017-06-15 10:50:43
19567	18171	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:50	2017-06-15 10:50:43
19568	18172	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:50	2017-06-15 10:50:43
19569	18173	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:50	2017-06-15 10:50:43
19570	18174	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:50	2017-06-15 10:50:44
19571	18175	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:50	2017-06-15 10:50:44
19572	18176	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:50	2017-06-19 09:38:09
19573	18177	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:50	2017-06-15 10:50:44
19574	18178	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:50	2017-06-15 10:50:44
19576	18180	DEPUTE	1998-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:50	2017-06-15 10:50:44
19578	18182	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:50	2017-06-29 09:19:25
19579	18183	QUESTAN	2016-09-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:50	2017-06-29 09:19:25
19580	18184	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:50	2017-06-15 10:50:44
19581	18185	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:50	2017-06-15 10:50:44
19582	18186	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:50	2017-06-15 10:50:44
19583	18187	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:50	2017-06-15 10:50:44
19584	18188	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:50	2017-06-15 10:50:44
19585	18189	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:51	2017-06-15 10:50:44
19872	18476	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:09	2017-06-15 10:50:54
19873	18477	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:09	2017-06-15 10:50:54
19874	18478	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:09	2017-06-15 10:50:54
19875	18479	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:09	2017-06-15 10:50:54
19876	18480	DEPUTE	1993-05-02 00:00:00	\N	1995-07-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:09	2017-06-15 10:50:54
19877	18481	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:09	2017-06-15 10:50:54
19878	18482	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:09	2017-06-15 10:50:54
19879	18483	DEPUTE	2007-07-20 00:00:00	\N	2011-03-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:09	2017-06-15 10:50:54
19880	18484	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:09	2017-06-15 10:50:54
19881	18485	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:09	2017-06-15 10:50:54
19882	18486	DEPUTE	1986-10-09 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:09	2017-06-15 10:50:54
19883	18487	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:09	2017-06-15 10:50:54
19884	18488	DEPUTE	2004-05-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:09	2017-06-15 10:50:54
19885	18489	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:10	2017-06-15 10:50:55
19886	18490	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:10	2017-06-15 10:50:55
19887	18491	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:10	2017-06-15 10:50:55
19888	18492	DEPUTE	1961-09-26 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:10	2017-06-15 10:50:55
19889	18493	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:10	2017-06-15 10:50:55
19890	18494	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:10	2017-06-15 10:50:55
19891	18495	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:10	2017-06-15 10:50:55
19892	18496	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:10	2017-06-15 10:50:55
19893	18497	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:10	2017-06-15 10:50:55
19894	18498	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:10	2017-06-15 10:50:55
19895	18499	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:10	2017-06-15 10:50:55
19896	18500	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:10	2017-06-15 10:50:55
19897	18501	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:10	2017-06-15 10:50:55
19898	18502	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:10	2017-06-15 10:50:55
19899	18503	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:10	2017-06-15 10:50:55
19900	18504	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:10	2017-06-15 10:50:55
19901	18505	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:10	2017-06-15 10:50:55
19902	18506	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:10	2017-06-15 10:50:55
19903	18507	DEPUTE	1978-05-07 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:10	2017-06-15 10:50:55
19904	18508	DEPUTE	1977-05-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:10	2017-06-15 10:50:55
19905	18509	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:11	2017-06-15 10:50:55
19906	18510	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:11	2017-06-15 10:50:55
19907	18511	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:11	2017-06-15 10:50:55
19908	18512	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:11	2017-06-15 10:50:55
29217	27814	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:53	\N
19909	18513	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:11	2017-06-15 10:50:55
19910	18514	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:11	2017-06-29 09:19:32
19911	18515	SECAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:11	2017-06-29 03:44:03
19912	18516	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:11	2017-06-29 09:19:32
19913	18517	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:11	2017-06-15 10:50:56
19914	18518	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:11	2017-06-15 10:50:56
19915	18519	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:12	2017-06-15 10:50:56
19916	18520	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:12	2017-06-15 10:50:56
19917	18521	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:12	2017-06-15 10:50:56
19918	18522	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:12	2017-06-15 10:50:56
19919	18523	DEPUTE	2001-09-25 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:12	2017-06-15 10:50:56
19920	18524	DEPUTE	1973-04-02 00:00:00	\N	1976-11-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:12	2017-06-15 10:50:56
19921	18525	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:12	2017-06-15 10:50:56
19922	18526	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:12	2017-06-29 09:19:32
19923	18527	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:12	2017-06-15 10:50:56
19924	18528	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:12	2017-06-19 09:38:16
19925	18529	SECAN	2002-06-26 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:12	2017-06-29 09:19:32
19926	18530	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:13	2017-06-15 10:50:56
19927	18531	DEPUTE	1981-07-24 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:13	2017-06-15 10:50:56
19928	18532	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:13	2017-06-15 10:50:56
19929	18533	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:13	2017-06-15 10:50:56
19930	18534	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:13	2017-06-15 10:50:56
19931	18535	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:13	2017-06-15 10:50:56
19932	18536	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:13	2017-06-15 10:50:56
19933	18537	DEPUTE	1981-07-02 00:00:00	\N	1983-11-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:13	2017-06-15 10:50:56
19935	18539	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:13	2017-06-15 10:50:56
19936	18540	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:13	2017-06-15 10:50:56
19937	18541	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:13	2017-06-15 10:50:56
19938	18542	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:13	2017-06-15 10:50:56
19939	18543	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:13	2017-06-15 10:50:56
19940	18544	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:13	2017-06-15 10:50:57
19941	18545	DEPUTE	1986-04-02 00:00:00	\N	1986-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:13	2017-06-15 10:50:57
19942	18546	DEPUTE	1973-05-06 00:00:00	\N	1974-07-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:14	2017-06-15 10:50:57
19943	18547	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:14	2017-06-15 10:50:57
19944	18548	DEPUTE	2001-10-04 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:14	2017-06-15 10:50:57
19945	18549	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:14	2017-06-19 09:38:16
19946	18550	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:14	2017-06-15 10:50:57
19947	18551	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:14	2017-06-15 10:50:57
19948	18552	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:14	2017-06-15 10:50:57
19949	18553	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:14	2017-06-15 10:50:57
19950	18554	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:14	2017-06-15 10:50:57
19951	18555	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:14	2017-06-15 10:50:57
19952	18556	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:15	2017-06-15 10:50:57
19953	18557	DEPUTE	1993-04-02 00:00:00	\N	1993-11-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:15	2017-06-15 10:50:57
19954	18558	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:15	2017-06-15 10:50:57
19955	18559	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:15	2017-06-15 10:50:57
19957	18561	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:15	2017-06-15 10:50:57
19958	18562	DEPUTE	1984-09-10 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:16	2017-06-15 10:50:57
19959	18563	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:16	2017-06-15 10:50:57
19960	18564	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:16	2017-06-15 10:50:57
19961	18565	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:16	2017-06-15 10:50:58
19962	18566	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:16	2017-06-15 10:50:58
19964	18568	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:16	2017-06-15 10:50:58
19965	18569	DEPUTE	2007-06-20 00:00:00	\N	2011-12-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:16	2017-06-15 10:50:58
19966	18570	DEPUTE	2000-11-19 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:16	2017-06-15 10:50:58
19967	18571	DEPUTE	1991-06-18 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:17	2017-06-15 10:50:58
19968	18572	SECAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:17	2017-06-29 09:19:33
19969	18573	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:17	2017-06-29 09:19:33
19970	18574	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:17	2017-06-15 10:50:58
19971	18575	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:17	2017-06-15 10:50:58
19972	18576	VICPDTAN	1997-06-13 00:00:00	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:17	2017-06-29 09:19:33
19973	18577	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:17	2017-06-29 09:19:33
19974	18578	VICPDTAN	1994-04-02 00:00:00	\N	1995-06-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:17	2017-06-29 03:44:05
19975	18579	VICPDTAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:17	2017-06-29 09:19:33
19976	18580	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:17	2017-06-29 09:19:33
19977	18581	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:17	2017-06-15 10:50:58
19978	18582	DEPUTE	1998-11-21 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:17	2017-06-15 10:50:58
19979	18583	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:17	2017-06-15 10:50:58
19980	18584	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:17	2017-06-15 10:50:58
19981	18585	DEPUTE	1969-10-26 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:17	2017-06-15 10:50:58
19982	18586	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:17	2017-06-15 10:50:58
19983	18587	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:17	2017-06-15 10:50:58
19984	18588	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:17	2017-06-15 10:50:58
19985	18589	DEPUTE	1988-06-13 00:00:00	\N	1988-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:17	2017-06-15 10:50:58
19986	18590	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:18	2017-06-15 10:50:59
19987	18591	DEPUTE	1962-12-06 00:00:00	\N	1963-03-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:18	2017-06-29 09:19:34
19988	18592	DEPUTE	1963-05-12 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:18	2017-06-29 09:19:34
19989	18593	DEPUTE	1967-04-03 00:00:00	\N	1967-07-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:18	2017-06-29 09:19:34
19990	18594	DEPUTE	1967-08-27 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:18	2017-06-29 09:19:34
19991	18595	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:18	2017-06-15 10:50:59
19992	18596	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:18	2017-06-15 10:50:59
19993	18597	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:18	2017-06-15 10:50:59
19994	18598	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:18	2017-06-15 10:50:59
19995	18599	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:18	2017-06-15 10:50:59
19996	18600	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:18	2017-06-15 10:50:59
19997	18601	DEPUTE	1997-06-01 00:00:00	\N	1998-04-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:18	2017-06-15 10:50:59
19998	18602	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:18	2017-06-15 10:50:59
19999	18603	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:18	2017-06-15 10:50:59
20000	18604	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:18	2017-06-29 03:44:05
20001	18605	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:18	2017-06-29 09:19:34
20002	18606	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:18	2017-06-15 10:50:59
20003	18607	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:18	2017-06-29 09:19:34
20004	18608	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:18	2017-06-29 03:44:05
20005	18609	SECAN	2002-06-26 00:00:00	\N	2006-11-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:18	2017-06-29 09:19:34
20006	18610	SECAN	2013-10-01 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:18	2017-06-29 09:19:34
20007	18611	DEPUTE	1984-04-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:18	2017-06-15 10:50:59
20008	18612	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:18	2017-06-15 10:50:59
20009	18613	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:18	2017-06-15 10:50:59
20010	18614	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:18	2017-06-15 10:50:59
20011	18615	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:18	2017-06-15 10:50:59
20012	18616	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:18	2017-06-15 10:50:59
20013	18617	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:18	2017-06-15 10:50:59
20014	18618	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:18	2017-06-15 10:50:59
20015	18619	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:18	2017-06-19 09:38:18
20016	18620	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:19	2017-06-15 10:50:59
20017	18621	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:19	2017-06-15 10:50:59
20018	18622	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:19	2017-06-19 09:38:18
20019	18623	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:19	2017-06-15 10:50:59
20020	18624	DEPUTE	1981-07-24 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:19	2017-06-15 10:51:00
20021	18625	DEPUTE	1986-10-01 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:19	2017-06-29 09:19:35
20022	18626	DEPUTE	1986-04-02 00:00:00	\N	1986-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:19	2017-06-29 09:19:35
20023	18627	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:19	2017-06-15 10:51:00
20024	18628	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:19	2017-06-15 10:51:00
20025	18629	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:19	2017-06-15 10:51:00
20026	18630	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:19	2017-06-15 10:51:00
20027	18631	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:19	2017-06-15 10:51:00
20028	18632	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:19	2017-06-15 10:51:00
20029	18633	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:19	2017-06-15 10:51:00
20031	18635	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:20	2017-06-15 10:51:00
20032	18636	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:20	2017-06-15 10:51:00
20033	18637	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:20	2017-06-15 10:51:00
20034	18638	DEPUTE	2012-06-20 00:00:00	\N	2016-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:20	2017-06-29 09:19:35
20035	18639	QUESTAN	2012-06-27 00:00:00	\N	2016-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:20	2017-06-29 09:19:35
20036	18640	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:20	2017-06-15 10:51:00
20037	18641	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:20	2017-06-15 10:51:00
20038	18642	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:20	2017-06-15 10:51:00
20039	18643	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:21	2017-06-15 10:51:00
20040	18644	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:21	2017-06-15 10:51:00
20041	18645	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:21	2017-06-15 10:51:00
20042	18646	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:21	2017-06-15 10:51:00
29218	27815	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:53	\N
20044	18648	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:21	2017-06-15 10:51:00
20045	18649	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:21	2017-06-15 10:51:01
20046	18650	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:21	2017-06-15 10:51:01
20047	18651	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:21	2017-06-15 10:51:01
20048	18652	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:21	2017-06-15 10:51:01
20049	18653	SECAN	2002-10-02 00:00:00	\N	2004-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:21	2017-06-29 09:19:35
20051	18655	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:21	2017-06-19 09:38:19
20052	18656	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:21	2017-06-29 09:19:35
20053	18657	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:21	2017-06-15 10:51:01
20054	18658	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:21	2017-06-15 10:51:01
20055	18659	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:22	2017-06-15 10:51:01
20056	18660	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:22	2017-06-15 10:51:01
20057	18661	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:22	2017-06-15 10:51:01
20059	18663	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:22	2017-06-15 10:51:01
19586	18190	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:51	2017-06-15 10:50:44
19587	18191	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:51	2017-06-15 10:50:44
19588	18192	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:51	2017-06-15 10:50:44
19589	18193	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:51	2017-06-29 09:19:25
19590	18194	QUESTAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:51	2017-06-29 09:19:25
19591	18195	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:51	2017-06-15 10:50:44
19592	18196	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:51	2017-06-15 10:50:44
19593	18197	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:51	2017-06-15 10:50:44
19594	18198	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:51	2017-06-15 10:50:44
19595	18199	DEPUTE	1978-04-02 00:00:00	\N	1980-10-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:51	2017-06-15 10:50:44
19596	18200	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:51	2017-06-15 10:50:44
19597	18201	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:51	2017-06-15 10:50:44
19598	18202	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:51	2017-06-15 10:50:44
19599	18203	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:51	2017-06-15 10:50:44
19600	18204	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:51	2017-06-15 10:50:44
19601	18205	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:51	2017-06-19 09:38:09
19602	18206	VICPDTAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:51	2017-06-29 09:19:25
19603	18207	VICPDTAN	2000-03-30 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:51	2017-06-29 09:19:25
19604	18208	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:51	2017-06-29 03:43:56
19605	18209	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:51	2017-06-15 10:50:45
19606	18210	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:51	2017-06-15 10:50:45
19607	18211	DEPUTE	1981-07-25 00:00:00	\N	1983-04-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:51	2017-06-15 10:50:45
19608	18212	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:51	2017-06-15 10:50:45
19609	18213	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:51	2017-06-15 10:50:45
19610	18214	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:51	2017-06-15 10:50:45
19611	18215	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:51	2017-06-15 10:50:45
19612	18216	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:51	2017-06-19 09:38:09
19613	18217	DEPUTE	1997-06-01 00:00:00	\N	1998-02-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:51	2017-06-15 10:50:45
19614	18218	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:52	2017-06-15 10:50:45
19615	18219	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:52	2017-06-15 10:50:45
19616	18220	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:52	2017-06-15 10:50:45
19617	18221	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:52	2017-06-15 10:50:45
19618	18222	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:52	2017-06-15 10:50:45
19619	18223	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:52	2017-06-15 10:50:45
19620	18224	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:52	2017-06-15 10:50:45
19621	18225	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:52	2017-06-15 10:50:45
19622	18226	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:52	2017-06-15 10:50:45
19623	18227	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:52	2017-06-15 10:50:45
19624	18228	DEPUTE	1988-06-13 00:00:00	\N	1991-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:52	2017-06-15 10:50:45
19625	18229	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:52	2017-06-15 10:50:45
19626	18230	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:52	2017-06-15 10:50:45
19627	18231	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:52	2017-06-15 10:50:45
19628	18232	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:52	2017-06-15 10:50:45
19629	18233	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:52	2017-06-15 10:50:45
19630	18234	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:52	2017-06-15 10:50:46
19631	18235	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:52	2017-06-15 10:50:46
19632	18236	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:52	2017-06-28 03:43:54
19633	18237	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:52	2017-06-29 03:43:57
19634	18238	VICPDTAN	2007-06-27 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:52	2017-06-28 03:43:54
19635	18239	VICPDTAN	2012-06-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:52	2017-06-29 03:43:57
19636	18240	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:52	2017-06-15 10:50:46
19637	18241	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:52	2017-06-29 03:43:57
19638	18242	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:52	2017-06-15 10:50:46
19639	18243	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:52	2017-06-15 10:50:46
19640	18244	VICPDTAN	2002-06-26 00:00:00	\N	2005-06-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:52	2017-06-29 09:19:26
19641	18245	SECAN	1988-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:52	2017-06-29 03:43:57
19642	18246	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:52	2017-06-29 09:19:26
19643	18247	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:52	2017-06-15 10:50:46
19644	18248	DEPUTE	1988-07-29 00:00:00	\N	1992-12-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:53	2017-06-15 10:50:46
19645	18249	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:53	2017-06-15 10:50:46
19646	18250	SECAN	2004-10-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:53	2017-06-29 09:19:26
19647	18251	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:53	2017-06-29 09:19:26
19648	18252	DEPUTE	2012-06-20 00:00:00	\N	2014-05-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:53	2017-06-15 10:50:46
19650	18254	VICPDTAN	2007-06-27 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:53	2017-06-29 09:19:26
19651	18255	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:53	2017-06-15 10:50:46
19652	18256	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:53	2017-06-15 10:50:46
19653	18257	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:53	2017-06-15 10:50:46
19654	18258	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:53	2017-06-15 10:50:46
19655	18259	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:53	2017-06-15 10:50:46
19656	18260	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:53	2017-06-15 10:50:46
19657	18261	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:53	2017-06-15 10:50:46
19658	18262	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:53	2017-06-15 10:50:46
19659	18263	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:53	2017-06-15 10:50:46
19660	18264	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:53	2017-06-15 10:50:46
19661	18265	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:53	2017-06-15 10:50:47
19662	18266	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:53	2017-06-15 10:50:47
19663	18267	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:53	2017-06-15 10:50:47
19665	18269	DEPUTE	1983-05-09 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:53	2017-06-29 03:43:54
19666	18270	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:53	2017-06-15 10:50:47
19667	18271	DEPUTE	1988-06-06 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:53	2017-06-15 10:50:47
19668	18272	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:53	2017-06-15 10:50:47
19669	18273	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:54	2017-06-29 09:19:27
19670	18274	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:54	2017-06-15 10:50:47
19671	18275	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:54	2017-06-15 10:50:47
19672	18276	DEPUTE	2012-06-20 00:00:00	\N	2017-01-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:54	2017-06-29 09:19:27
19673	18277	DEPUTE	2017-04-22 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:54	2017-06-29 09:19:27
19674	18278	DEPUTE	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:54	2017-06-29 09:19:27
19676	18280	DEPUTE	1973-04-02 00:00:00	\N	1977-03-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:54	2017-06-15 10:50:47
19677	18281	DEPUTE	1997-07-05 00:00:00	\N	2001-02-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:54	2017-06-15 10:50:47
19678	18282	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:54	2017-06-15 10:50:47
19680	18284	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:54	2017-06-15 10:50:47
19681	18285	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:54	2017-06-15 10:50:47
19682	18286	QUESTAN	2007-06-27 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:54	2017-06-29 09:19:27
19683	18287	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:54	2017-06-29 09:19:27
19684	18288	DEPUTE	2016-03-12 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:54	2017-06-29 09:19:27
19685	18289	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:54	2017-06-29 09:19:27
19686	18290	DEPUTE	2000-04-28 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:55	2017-06-15 10:50:48
19687	18291	DEPUTE	1973-04-02 00:00:00	\N	1974-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:55	2017-06-15 10:50:48
19688	18292	DEPUTE	1986-04-02 00:00:00	\N	1986-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:55	2017-06-15 10:50:48
19689	18293	DEPUTE	1978-04-02 00:00:00	\N	1978-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:55	2017-06-15 10:50:48
19690	18294	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:55	2017-06-15 10:50:48
19692	18296	SECAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:55	2017-06-29 09:19:27
19693	18297	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:55	2017-06-29 03:43:58
19694	18298	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:55	2017-06-29 09:19:27
19695	18299	SECAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:55	2017-06-29 03:43:58
19696	18300	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:56	2017-06-15 10:50:48
19697	18301	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:56	2017-06-15 10:50:48
19698	18302	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:56	2017-06-15 10:50:48
19699	18303	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:56	2017-06-15 10:50:48
19700	18304	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:56	2017-06-15 10:50:48
19701	18305	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:56	2017-06-15 10:50:48
19702	18306	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:56	2017-06-19 09:38:12
19703	18307	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:56	2017-06-15 10:50:48
19704	18308	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:56	2017-06-15 10:50:48
19705	18309	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:57	2017-06-15 10:50:48
19706	18310	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:57	2017-06-15 10:50:48
19707	18311	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:57	2017-06-15 10:50:48
19708	18312	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:57	2017-06-15 10:50:48
19709	18313	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:57	2017-06-15 10:50:48
19710	18314	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:57	2017-06-15 10:50:48
19711	18315	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:57	2017-06-15 10:50:49
19712	18316	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:57	2017-06-15 10:50:49
19713	18317	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:57	2017-06-15 10:50:49
19714	18318	DEPUTE	1973-04-02 00:00:00	\N	1977-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:57	2017-06-15 10:50:49
19715	18319	DEPUTE	1978-04-03 00:00:00	\N	1978-05-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:57	2017-06-15 10:50:49
19716	18320	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:57	2017-06-15 10:50:49
19717	18321	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:58	2017-06-15 10:50:49
19718	18322	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:58	2017-06-15 10:50:49
19719	18323	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:58	2017-06-15 10:50:49
19720	18324	SECAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:58	2017-06-29 09:19:28
19721	18325	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:58	2017-06-29 09:19:28
19722	18326	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:58	2017-06-29 09:19:28
19723	18327	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:58	2017-06-15 10:50:49
19724	18328	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:58	2017-06-15 10:50:49
19725	18329	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:58	2017-06-15 10:50:49
19726	18330	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:58	2017-06-15 10:50:49
19727	18331	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:59	2017-06-15 10:50:49
19728	18332	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:59	2017-06-15 10:50:49
19729	18333	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:59	2017-06-15 10:50:49
19730	18334	DEPUTE	2007-06-20 00:00:00	\N	2009-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:59	2017-06-29 09:19:28
19731	18335	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:59	2017-06-29 09:19:28
19732	18336	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:59	2017-06-19 09:38:12
19733	18337	DEPUTE	1997-07-03 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:59	2017-06-15 10:50:49
19734	18338	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:59	2017-06-15 10:50:49
19735	18339	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:59	2017-06-15 10:50:49
19736	18340	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:59	2017-06-19 09:38:12
19737	18341	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:59	2017-06-15 10:50:49
19738	18342	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:59	2017-06-15 10:50:49
19739	18343	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:59	2017-06-15 10:50:49
19740	18344	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:00	2017-06-15 10:50:50
19741	18345	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:00	2017-06-15 10:50:50
19742	18346	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:00	2017-06-15 10:50:50
19743	18347	SECAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:00	2017-06-29 09:19:29
19744	18348	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:00	2017-06-15 10:50:50
19745	18349	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:00	2017-06-29 09:19:29
19746	18350	DEPUTE	1981-07-02 00:00:00	\N	1983-04-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:00	2017-06-15 10:50:50
19747	18351	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:00	2017-06-15 10:50:50
19748	18352	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:00	2017-06-15 10:50:50
19749	18353	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:00	2017-06-15 10:50:50
19750	18354	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:00	2017-06-15 10:50:50
19751	18355	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:00	2017-06-15 10:50:50
19752	18356	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:00	2017-06-15 10:50:50
19753	18357	DEPUTE	2007-06-20 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:00	2017-06-15 10:50:50
19754	18358	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:01	2017-06-15 10:50:50
19755	18359	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:01	2017-06-15 10:50:50
19756	18360	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:01	2017-06-15 10:50:50
19757	18361	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:01	2017-06-15 10:50:50
19758	18362	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:01	2017-06-15 10:50:50
19759	18363	DEPUTE	1988-12-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:01	2017-06-15 10:50:50
19760	18364	DEPUTE	2002-06-19 00:00:00	\N	2006-06-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:01	2017-06-15 10:50:50
19761	18365	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:01	2017-06-15 10:50:50
19762	18366	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:01	2017-06-15 10:50:50
19763	18367	DEPUTE	2007-06-20 00:00:00	\N	2011-07-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:01	2017-06-29 09:19:29
19764	18368	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:01	2017-06-29 09:19:29
19765	18369	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:01	2017-06-19 09:38:13
19766	18370	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:01	2017-06-15 10:50:50
19767	18371	DEPUTE	1986-05-07 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:01	2017-06-15 10:50:50
19769	18373	DEPUTE	1988-06-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:02	2017-06-15 10:50:51
19770	18374	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:02	2017-06-15 10:50:51
19771	18375	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:02	2017-06-15 10:50:51
19772	18376	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:02	2017-06-15 10:50:51
29219	27816	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:53	\N
19774	18378	DEPUTE	1988-06-13 00:00:00	\N	1992-07-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:02	2017-06-15 10:50:51
19775	18379	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:02	2017-06-28 03:44:02
19776	18380	DEPUTE	1997-06-01 00:00:00	\N	2001-12-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:02	2017-06-15 10:50:51
19777	18381	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:02	2017-06-15 10:50:51
19778	18382	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:02	2017-06-15 10:50:51
19779	18383	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:02	2017-06-15 10:50:51
19780	18384	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:03	2017-06-15 10:50:51
19781	18385	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:03	2017-06-15 10:50:51
19782	18386	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:03	2017-06-15 10:50:51
19783	18387	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:03	2017-06-15 10:50:51
19787	18391	DEPUTE	1968-07-11 00:00:00	\N	1971-10-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:04	2017-06-15 10:50:51
19788	18392	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:04	2017-06-15 10:50:51
19789	18393	DEPUTE	1995-08-17 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:04	2017-06-15 10:50:51
19790	18394	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:04	2017-06-15 10:50:51
19791	18395	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:04	2017-06-15 10:50:51
19792	18396	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:04	2017-06-15 10:50:51
19793	18397	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:04	2017-06-15 10:50:52
19794	18398	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:04	2017-06-15 10:50:52
19795	18399	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:04	2017-06-15 10:50:52
19796	18400	DEPUTE	1993-04-02 00:00:00	\N	1993-11-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:04	2017-06-15 10:50:52
19797	18401	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:04	2017-06-15 10:50:52
19798	18402	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:04	2017-06-15 10:50:52
19799	18403	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:04	2017-06-15 10:50:52
19800	18404	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:04	2017-06-15 10:50:52
19801	18405	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:04	2017-06-15 10:50:52
19802	18406	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:04	2017-06-15 10:50:52
19803	18407	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:05	2017-06-15 10:50:52
19804	18408	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:05	2017-06-15 10:50:52
19805	18409	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:05	2017-06-15 10:50:52
19806	18410	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:05	2017-06-15 10:50:52
19807	18411	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:05	2017-06-15 10:50:52
19808	18412	DEPUTE	1973-05-06 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:05	2017-06-15 10:50:52
19809	18413	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:05	2017-06-15 10:50:52
19810	18414	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:05	2017-06-15 10:50:52
19811	18415	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:05	2017-06-15 10:50:52
19812	18416	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:05	2017-06-15 10:50:52
19813	18417	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:05	2017-06-15 10:50:52
19814	18418	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:05	2017-06-15 10:50:52
19815	18419	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:05	2017-06-15 10:50:52
19816	18420	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:05	2017-06-15 10:50:52
19817	18421	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:05	2017-06-15 10:50:52
19818	18422	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:05	2017-06-15 10:50:52
19819	18423	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:05	2017-06-15 10:50:52
19820	18424	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:05	2017-06-15 10:50:52
19821	18425	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:06	2017-06-15 10:50:52
19822	18426	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:06	2017-06-15 10:50:52
19823	18427	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:06	2017-06-15 10:50:52
19824	18428	DEPUTE	2012-06-20 00:00:00	\N	2012-10-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:06	2017-06-15 10:50:52
19825	18429	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:06	2017-06-15 10:50:53
19826	18430	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:06	2017-06-15 10:50:53
19827	18431	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:06	2017-06-15 10:50:53
19828	18432	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:06	2017-06-19 09:38:14
19829	18433	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:06	2017-06-15 10:50:53
19831	18435	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:06	2017-06-15 10:50:53
19832	18436	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:06	2017-06-15 10:50:53
19833	18437	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:06	2017-06-15 10:50:53
19834	18438	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:06	2017-06-15 10:50:53
19835	18439	DEPUTE	1968-07-11 00:00:00	\N	1969-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:06	2017-06-15 10:50:53
19836	18440	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:07	2017-06-15 10:50:53
19837	18441	QUESTAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:07	2017-06-29 09:19:30
19838	18442	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:07	2017-06-15 10:50:53
19839	18443	DEPUTE	1997-06-01 00:00:00	\N	1998-09-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:07	2017-06-15 10:50:53
19840	18444	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:07	2017-06-29 03:44:02
19841	18445	QUESTAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:07	2017-06-29 09:19:30
19842	18446	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:07	2017-06-15 10:50:53
29220	27817	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:53	\N
19843	18447	DEPUTE	1968-07-11 00:00:00	\N	1969-07-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:07	2017-06-15 10:50:53
19844	18448	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:07	2017-06-15 10:50:53
19845	18449	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:07	2017-06-15 10:50:53
19846	18450	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:07	2017-06-15 10:50:53
19847	18451	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:07	2017-06-15 10:50:53
19848	18452	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:07	2017-06-15 10:50:53
19849	18453	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:07	2017-06-15 10:50:53
19850	18454	DEPUTE	1997-05-25 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:07	2017-06-15 10:50:53
19851	18455	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:07	2017-06-15 10:50:53
19852	18456	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:07	2017-06-15 10:50:53
19853	18457	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:07	2017-06-15 10:50:54
19854	18458	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:07	2017-06-15 10:50:54
19855	18459	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:07	2017-06-15 10:50:54
19856	18460	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:07	2017-06-15 10:50:54
19857	18461	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:07	2017-06-15 10:50:54
19858	18462	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:08	2017-06-15 10:50:54
19859	18463	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:08	2017-06-15 10:50:54
19860	18464	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:08	2017-06-15 10:50:54
19862	18466	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:08	2017-06-15 10:50:54
19863	18467	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:08	2017-06-15 10:50:54
19864	18468	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:08	2017-06-15 10:50:54
19865	18469	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:08	2017-06-15 10:50:54
19866	18470	DEPUTE	1988-10-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:08	2017-06-15 10:50:54
19867	18471	DEPUTE	1995-05-10 00:00:00	\N	1995-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:09	2017-06-15 10:50:54
19868	18472	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:09	2017-06-15 10:50:54
19870	18474	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:09	2017-06-15 10:50:54
19871	18475	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:09	2017-06-15 10:50:54
19396	18000	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:39	2017-06-15 10:50:37
19397	18001	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:39	2017-06-15 10:50:37
19398	18002	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:39	2017-06-15 10:50:37
19399	18003	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:39	2017-06-15 10:50:37
19400	18004	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:39	2017-06-15 10:50:37
19401	18005	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:39	2017-06-15 10:50:37
19402	18006	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:40	2017-06-15 10:50:37
19403	18007	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:40	2017-06-15 10:50:37
19404	18008	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:40	2017-06-15 10:50:37
19405	18009	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:40	2017-06-15 10:50:38
19406	18010	DEPUTE	1996-05-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:40	2017-06-15 10:50:38
19407	18011	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:40	2017-06-15 10:50:38
19408	18012	DEPUTE	1989-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:40	2017-06-15 10:50:38
19409	18013	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:40	2017-06-15 10:50:38
19410	18014	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:40	2017-06-15 10:50:38
19411	18015	SECAN	1987-04-02 00:00:00	\N	1988-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:40	2017-06-29 09:19:21
19412	18016	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:40	2017-06-29 09:19:21
19413	18017	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:41	2017-06-15 10:50:38
19414	18018	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:41	2017-06-15 10:50:38
19415	18019	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:41	2017-06-15 10:50:38
19416	18020	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:41	2017-06-15 10:50:38
19417	18021	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:41	2017-06-15 10:50:38
19418	18022	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:41	2017-06-15 10:50:38
19419	18023	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:41	2017-06-15 10:50:38
19420	18024	DEPUTE	1973-04-02 00:00:00	\N	1974-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:41	2017-06-15 10:50:38
19421	18025	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:41	2017-06-15 10:50:38
19423	18027	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:41	2017-06-15 10:50:38
19424	18028	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:41	2017-06-15 10:50:38
19425	18029	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:41	2017-06-15 10:50:38
19426	18030	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:41	2017-06-15 10:50:38
19427	18031	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:41	2017-06-15 10:50:38
19428	18032	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:41	2017-06-15 10:50:38
19429	18033	DEPUTE	1981-07-02 00:00:00	\N	1983-04-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:41	2017-06-15 10:50:38
19430	18034	DEPUTE	1980-11-30 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:41	2017-06-15 10:50:38
19431	18035	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:41	2017-06-15 10:50:38
19432	18036	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:42	2017-06-15 10:50:39
19433	18037	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:42	2017-06-15 10:50:39
19434	18038	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:42	2017-06-15 10:50:39
29221	27818	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:54	\N
19435	18039	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:42	2017-06-15 10:50:39
19436	18040	DEPUTE	1973-04-02 00:00:00	\N	1977-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:42	2017-06-15 10:50:39
19437	18041	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:42	2017-06-15 10:50:39
19438	18042	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:42	2017-06-15 10:50:39
19439	18043	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:42	2017-06-15 10:50:39
19440	18044	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:42	2017-06-15 10:50:39
19441	18045	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:43	2017-06-15 10:50:39
19442	18046	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:43	2017-06-15 10:50:39
19443	18047	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:43	2017-06-15 10:50:39
19444	18048	DEPUTE	1973-04-02 00:00:00	\N	1973-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:43	2017-06-15 10:50:39
19445	18049	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:43	2017-06-15 10:50:39
19446	18050	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:43	2017-06-15 10:50:39
19447	18051	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:43	2017-06-15 10:50:39
19448	18052	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:43	2017-06-15 10:50:39
19449	18053	DEPUTE	1973-04-02 00:00:00	\N	1975-06-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:43	2017-06-15 10:50:39
19450	18054	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:44	2017-06-15 10:50:39
19451	18055	DEPUTE	1989-12-04 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:44	2017-06-15 10:50:39
19452	18056	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:44	2017-06-15 10:50:39
19453	18057	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:44	2017-06-15 10:50:40
19454	18058	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:44	2017-06-15 10:50:40
19455	18059	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:44	2017-06-15 10:50:40
19456	18060	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:44	2017-06-15 10:50:40
19457	18061	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:44	2017-06-15 10:50:40
19458	18062	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:45	2017-06-15 10:50:40
19459	18063	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:45	2017-06-15 10:50:40
19460	18064	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:45	2017-06-19 09:38:06
19461	18065	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:45	2017-06-15 10:50:40
19462	18066	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:45	2017-06-15 10:50:40
19463	18067	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:45	2017-06-15 10:50:40
19464	18068	VICPDTAN	1987-04-02 00:00:00	\N	1988-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:45	2017-06-29 09:19:23
19465	18069	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:45	2017-06-15 10:50:40
19466	18070	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:45	2017-06-29 09:19:23
19467	18071	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:45	2017-06-15 10:50:40
19468	18072	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:46	2017-06-15 10:50:40
19469	18073	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:46	2017-06-15 10:50:40
19470	18074	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:46	2017-06-15 10:50:40
19471	18075	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:46	2017-06-15 10:50:40
19472	18076	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:46	2017-06-15 10:50:40
19473	18077	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:46	2017-06-15 10:50:40
19474	18078	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:46	2017-06-15 10:50:40
19475	18079	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:46	2017-06-15 10:50:40
19476	18080	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:46	2017-06-15 10:50:40
19477	18081	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:46	2017-06-15 10:50:40
19478	18082	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:46	2017-06-15 10:50:40
19479	18083	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:47	2017-06-15 10:50:40
19481	18085	DEPUTE	1980-11-30 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:47	2017-06-15 10:50:41
19482	18086	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:47	2017-06-15 10:50:41
19483	18087	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:47	2017-06-15 10:50:41
19484	18088	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:47	2017-06-15 10:50:41
19486	18090	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:47	2017-06-15 10:50:41
19487	18091	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:47	2017-06-15 10:50:41
19488	18092	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:47	2017-06-15 10:50:41
19489	18093	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:47	2017-06-15 10:50:41
20255	18859	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:31	2017-06-19 09:38:23
20256	18860	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:31	2017-06-29 09:19:39
20257	18861	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:31	2017-06-29 09:19:39
20258	18862	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:31	2017-06-29 09:19:39
20259	18863	DEPUTE	2012-06-20 00:00:00	\N	2016-01-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:31	2017-06-15 10:51:08
20260	18864	DEPUTE	2002-06-25 00:00:00	\N	2002-06-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:31	2017-06-29 09:19:39
20261	18865	DEPUTE	2007-07-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:32	2017-06-15 10:51:08
20262	18866	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:32	2017-06-15 10:51:08
20263	18867	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:32	2017-06-15 10:51:08
20264	18868	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:32	2017-06-29 09:19:39
20266	18870	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:32	2017-06-15 10:51:08
20267	18871	DEPUTE	2012-07-22 00:00:00	\N	2017-01-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:32	2017-06-15 10:51:08
29222	27819	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:54	\N
20268	18872	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:32	2017-06-15 10:51:08
20269	18873	DEPUTE	2012-03-23 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:32	2017-06-29 09:19:39
20270	18874	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:32	2017-06-19 09:38:23
20271	18875	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:32	2017-06-29 09:19:39
20272	18876	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:32	2017-06-15 10:51:08
20273	18877	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:32	2017-06-15 10:51:08
20274	18878	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:32	2017-06-15 10:51:08
20275	18879	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:32	2017-06-15 10:51:08
20276	18880	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:33	2017-06-15 10:51:08
20277	18881	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:33	2017-06-15 10:51:08
20278	18882	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:33	2017-06-15 10:51:08
20279	18883	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:33	2017-06-15 10:51:08
20280	18884	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:33	2017-06-15 10:51:08
20281	18885	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:33	2017-06-15 10:51:08
20282	18886	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:33	2017-06-19 09:38:23
20283	18887	DEPUTE	2005-07-03 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:33	2017-06-15 10:51:09
20284	18888	DEPUTE	2009-07-23 00:00:00	\N	2010-12-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:33	2017-06-29 09:19:39
20285	18889	DEPUTE	2007-07-20 00:00:00	\N	2008-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:33	2017-06-29 09:19:39
20286	18890	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:33	2017-06-19 09:38:23
20287	18891	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:33	2017-06-15 10:51:09
20288	18892	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:34	2017-06-15 10:51:09
20289	18893	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:34	2017-06-15 10:51:09
20290	18894	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:34	2017-06-19 09:38:24
20292	18896	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:34	2017-06-15 10:51:09
20293	18897	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:34	2017-06-15 10:51:09
20294	18898	DEPUTE	1978-04-03 00:00:00	\N	1978-05-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:34	2017-06-15 10:51:09
20295	18899	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:34	2017-06-15 10:51:09
20296	18900	DEPUTE	1973-04-02 00:00:00	\N	1973-05-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:34	2017-06-15 10:51:09
20297	18901	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:34	2017-06-15 10:51:09
20298	18902	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:34	2017-06-15 10:51:09
20299	18903	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:34	2017-06-15 10:51:09
20300	18904	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:34	2017-06-15 10:51:09
20301	18905	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:35	2017-06-15 10:51:09
20302	18906	DEPUTE	1988-06-13 00:00:00	\N	1991-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:35	2017-06-15 10:51:09
20303	18907	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:35	2017-06-26 03:43:42
20304	18908	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:35	2017-06-15 10:51:09
20305	18909	DEPUTE	2001-04-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:35	2017-06-26 03:43:42
20306	18910	DEPUTE	2007-06-20 00:00:00	\N	2007-10-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:35	2017-06-15 10:51:09
20307	18911	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:35	2017-06-15 10:51:09
20308	18912	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:35	2017-06-15 10:51:09
20309	18913	SECAN	1988-06-24 00:00:00	\N	1991-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:35	2017-06-29 03:44:12
20310	18914	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:35	2017-06-29 03:44:12
20311	18915	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:35	2017-06-15 10:51:10
20312	18916	DEPUTE	1980-11-30 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:35	2017-06-15 10:51:10
20313	18917	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:35	2017-06-15 10:51:10
20314	18918	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:35	2017-06-29 09:19:40
20315	18919	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:35	2017-06-29 09:19:40
20316	18920	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:35	2017-06-29 09:19:40
20317	18921	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:35	2017-06-29 09:19:40
20318	18922	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:35	2017-06-15 10:51:10
20319	18923	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:36	2017-06-15 10:51:10
20320	18924	DEPUTE	1988-06-13 00:00:00	\N	1991-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:36	2017-06-15 10:51:10
20321	18925	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:36	2017-06-15 10:51:10
20322	18926	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:36	2017-06-15 10:51:10
20323	18927	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:36	2017-06-15 10:51:10
20324	18928	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:36	2017-06-19 09:38:24
20325	18929	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:36	2017-06-15 10:51:10
20326	18930	DEPUTE	1988-06-13 00:00:00	\N	1989-06-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:36	2017-06-15 10:51:10
20327	18931	DEPUTE	1981-07-02 00:00:00	\N	1985-09-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:36	2017-06-15 10:51:10
20328	18932	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:36	2017-06-15 10:51:10
20329	18933	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:36	2017-06-15 10:51:10
20330	18934	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:37	2017-06-15 10:51:10
20331	18935	DEPUTE	1989-02-03 00:00:00	\N	1992-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:37	2017-06-15 10:51:10
20332	18936	DEPUTE	1993-04-02 00:00:00	\N	1996-07-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:37	2017-06-15 10:51:10
20333	18937	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:37	2017-06-15 10:51:10
29223	27820	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:54	\N
20334	18938	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:37	2017-06-15 10:51:10
20335	18939	DEPUTE	1997-06-01 00:00:00	\N	1998-07-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:37	2017-06-15 10:51:10
20336	18940	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:37	2017-06-15 10:51:11
20337	18941	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:37	2017-06-15 10:51:11
20338	18942	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:37	2017-06-15 10:51:11
20339	18943	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:37	2017-06-15 10:51:11
20340	18944	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:38	2017-06-15 10:51:11
20341	18945	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:38	2017-06-15 10:51:11
20342	18946	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:38	2017-06-19 09:38:25
20343	18947	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:38	2017-06-15 10:51:11
20345	18949	DEPUTE	1988-06-13 00:00:00	\N	1989-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:38	2017-06-15 10:51:11
20346	18950	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:38	2017-06-15 10:51:11
20347	18951	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:38	2017-06-15 10:51:11
20348	18952	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:38	2017-06-15 10:51:11
20349	18953	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:38	2017-06-15 10:51:11
20350	18954	DEPUTE	1983-01-09 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:38	2017-06-15 10:51:11
20352	18956	DEPUTE	1988-06-13 00:00:00	\N	1988-11-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:38	2017-06-15 10:51:11
20353	18957	SECAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:38	2017-06-29 03:44:13
20354	18958	SECAN	2002-06-26 00:00:00	\N	2002-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:38	2017-06-28 03:44:10
20355	18959	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:38	2017-06-15 10:51:11
20356	18960	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:38	2017-06-19 09:38:25
20357	18961	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:38	2017-06-29 03:44:13
20358	18962	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:38	2017-06-29 03:44:13
20359	18963	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:38	2017-06-28 03:44:10
20360	18964	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:39	2017-06-15 10:51:11
20361	18965	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:39	2017-06-15 10:51:11
20362	18966	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:39	2017-06-15 10:51:11
20363	18967	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:39	2017-06-29 09:19:41
20364	18968	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:39	2017-06-15 10:51:12
20365	18969	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:39	2017-06-15 10:51:12
20366	18970	DEPUTE	2012-06-20 00:00:00	\N	2017-03-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:39	2017-06-15 10:51:12
20367	18971	DEPUTE	1997-06-12 00:00:00	\N	1999-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:39	2017-06-29 09:19:41
20368	18972	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:39	2017-06-15 10:51:12
20369	18973	DEPUTE	2012-07-22 00:00:00	\N	2014-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:39	2017-06-15 10:51:12
20370	18974	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:39	2017-06-15 10:51:12
20371	18975	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:39	2017-06-15 10:51:12
20372	18976	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:39	2017-06-15 10:51:12
20373	18977	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:39	2017-06-15 10:51:12
20374	18978	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:39	2017-06-15 10:51:12
20375	18979	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:39	2017-06-15 10:51:12
20376	18980	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:39	2017-06-19 09:38:26
20377	18981	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:40	2017-06-15 10:51:12
20378	18982	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:40	2017-06-15 10:51:12
20379	18983	DEPUTE	1991-06-17 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:40	2017-06-15 10:51:12
20380	18984	DEPUTE	1981-07-23 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:40	2017-06-15 10:51:12
20381	18985	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:40	2017-06-15 10:51:12
20382	18986	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:40	2017-06-15 10:51:12
20388	18992	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:41	2017-06-15 10:51:12
20389	18993	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:41	2017-06-15 10:51:12
20390	18994	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:41	2017-06-15 10:51:12
20391	18995	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:41	2017-06-15 10:51:12
20392	18996	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:41	2017-06-15 10:51:12
20393	18997	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:41	2017-06-15 10:51:13
20394	18998	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:41	2017-06-15 10:51:13
20395	18999	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:41	2017-06-15 10:51:13
20396	19000	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:41	2017-06-15 10:51:13
20397	19001	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:41	2017-06-15 10:51:13
20398	19002	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:41	2017-06-19 09:38:26
20399	19003	DEPUTE	1973-04-02 00:00:00	\N	1976-02-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:41	2017-06-29 09:19:42
20400	19004	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:41	2017-06-15 10:51:13
20401	19005	DEPUTE	1968-08-13 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:41	2017-06-15 10:51:13
20402	19006	DEPUTE	1976-11-15 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:41	2017-06-29 09:19:42
20403	19007	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:41	2017-06-15 10:51:13
20404	19008	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:41	2017-06-15 10:51:13
20405	19009	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:41	2017-06-15 10:51:13
29224	27821	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:54	\N
20406	19010	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:41	2017-06-15 10:51:13
20407	19011	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:41	2017-06-15 10:51:13
20408	19012	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:41	2017-06-15 10:51:13
20409	19013	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:41	2017-06-15 10:51:13
20410	19014	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:41	2017-06-15 10:51:13
20411	19015	DEPUTE	1995-11-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:41	2017-06-15 10:51:13
20412	19016	DEPUTE	1976-02-13 00:00:00	\N	1976-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:41	2017-06-15 10:51:13
20413	19017	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:41	2017-06-15 10:51:13
20414	19018	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:41	2017-06-15 10:51:13
20415	19019	DEPUTE	1978-04-02 00:00:00	\N	1980-09-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:41	2017-06-15 10:51:13
20416	19020	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:42	2017-06-15 10:51:14
20417	19021	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:42	2017-06-15 10:51:14
20418	19022	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:42	2017-06-15 10:51:14
20419	19023	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:42	2017-06-15 10:51:14
20420	19024	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:42	2017-06-15 10:51:14
20421	19025	DEPUTE	1997-06-01 00:00:00	\N	2000-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:42	2017-06-15 10:51:14
20422	19026	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:42	2017-06-29 03:44:15
20423	19027	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:42	2017-06-15 10:51:14
20424	19028	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:42	2017-06-29 03:44:11
20425	19029	QUESTAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:42	2017-06-29 03:44:15
20426	19030	SECAN	2010-10-05 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:42	2017-06-29 03:44:11
20427	19031	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:42	2017-06-15 10:51:14
20428	19032	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:43	2017-06-29 09:19:42
20429	19033	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:43	2017-06-29 09:19:42
20430	19034	SECAN	2009-10-06 00:00:00	\N	2010-10-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:43	2017-06-29 09:19:42
20431	19035	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:43	2017-06-19 09:38:27
20432	19036	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:43	2017-06-29 09:19:42
20434	19038	SECAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:43	2017-06-29 09:19:42
20435	19039	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:43	2017-06-29 09:19:42
20436	19040	SECAN	2002-06-26 00:00:00	\N	2004-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:43	2017-06-29 09:19:42
20437	19041	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:43	2017-06-29 09:19:42
20440	19044	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:43	2017-06-15 10:51:14
20441	19045	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:43	2017-06-15 10:51:14
20442	19046	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:43	2017-06-15 10:51:14
20443	19047	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:43	2017-06-15 10:51:14
20444	19048	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:43	2017-06-15 10:51:14
20445	19049	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:43	2017-06-19 09:38:27
20446	19050	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:43	2017-06-15 10:51:14
20447	19051	DEPUTE	1986-04-02 00:00:00	\N	1986-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:43	2017-06-15 10:51:14
20448	19052	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:43	2017-06-15 10:51:14
20449	19053	DEPUTE	1980-10-27 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:43	2017-06-15 10:51:15
20640	19244	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:00	2017-06-15 10:51:21
20641	19245	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:00	2017-06-15 10:51:22
20642	19246	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:00	2017-06-15 10:51:22
20643	19247	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:00	2017-06-19 09:38:33
20644	19248	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:00	2017-06-15 10:51:22
20645	19249	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:00	2017-06-15 10:51:22
20646	19250	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:00	2017-06-19 09:38:33
20647	19251	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:00	2017-06-15 10:51:22
20648	19252	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:00	2017-06-15 10:51:22
20649	19253	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:00	2017-06-19 09:38:33
20650	19254	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:00	2017-06-15 10:51:22
20651	19255	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:00	2017-06-15 10:51:22
20652	19256	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:00	2017-06-19 09:38:33
20653	19257	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:00	2017-06-15 10:51:22
20654	19258	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:00	2017-06-15 10:51:22
20655	19259	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:00	2017-06-19 09:38:33
20656	19260	DEPUTE	2006-06-27 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:00	2017-06-15 10:51:22
20657	19261	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:00	2017-06-15 10:51:22
20658	19262	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:00	2017-06-15 10:51:22
20659	19263	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:00	2017-06-19 09:38:33
20660	19264	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:00	2017-06-15 10:51:22
20661	19265	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:00	2017-06-15 10:51:22
20663	19267	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:01	2017-06-15 10:51:22
20664	19268	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:01	2017-06-15 10:51:22
29225	27822	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:54	\N
20665	19269	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:01	2017-06-15 10:51:22
20666	19270	DEPUTE	2007-06-20 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:01	2017-06-15 10:51:22
20667	19271	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:01	2017-06-15 10:51:22
20668	19272	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:01	2017-06-15 10:51:22
20669	19273	DEPUTE	2004-05-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:01	2017-06-15 10:51:22
20670	19274	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:01	2017-06-15 10:51:22
20671	19275	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:01	2017-06-15 10:51:22
20672	19276	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:01	2017-06-29 03:44:21
20673	19277	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:01	2017-06-29 09:19:47
20675	19279	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:01	2017-06-15 10:51:23
20676	19280	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:01	2017-06-15 10:51:23
20677	19281	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:01	2017-06-19 09:38:33
20678	19282	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:01	2017-06-15 10:51:23
20679	19283	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:01	2017-06-15 10:51:23
20680	19284	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:01	2017-06-19 09:38:34
20681	19285	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:02	2017-06-15 10:51:23
20682	19286	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:02	2017-06-29 09:19:48
20683	19287	DEPUTE	2007-06-20 00:00:00	\N	2011-07-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:02	2017-06-29 09:19:48
20684	19288	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:02	2017-06-28 03:44:17
20685	19289	SECAN	2007-06-27 00:00:00	\N	2011-07-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:02	2017-06-29 09:19:48
20686	19290	SECAN	2013-10-01 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:02	2017-06-28 03:44:17
20687	19291	DEPUTE	2011-07-30 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:02	2017-06-15 10:51:23
20688	19292	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:02	2017-06-15 10:51:23
20689	19293	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:02	2017-06-15 10:51:23
20690	19294	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:02	2017-06-19 09:38:34
20691	19295	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:02	2017-06-15 10:51:23
20692	19296	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:02	2017-06-15 10:51:23
20693	19297	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:02	2017-06-19 09:38:34
20694	19298	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:02	2017-06-15 10:51:23
20695	19299	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:02	2017-06-15 10:51:23
20697	19301	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:02	2017-06-29 09:19:48
20698	19302	DEPUTE	2005-09-12 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:02	2017-06-29 09:19:48
20699	19303	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:02	2017-06-15 10:51:23
20700	19304	DEPUTE	2002-06-25 00:00:00	\N	2002-06-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:02	2017-06-29 09:19:48
20701	19305	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:02	2017-06-15 10:51:23
20702	19306	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:02	2017-06-15 10:51:23
20703	19307	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:03	2017-06-15 10:51:23
20704	19308	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:03	2017-06-15 10:51:24
20705	19309	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:03	2017-06-15 10:51:24
20706	19310	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:03	2017-06-19 09:38:34
20707	19311	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:03	2017-06-15 10:51:24
20708	19312	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:03	2017-06-15 10:51:24
20709	19313	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:03	2017-06-19 09:38:34
20710	19314	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:03	2017-06-15 10:51:24
20711	19315	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:03	2017-06-15 10:51:24
20712	19316	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:03	2017-06-15 10:51:24
20713	19317	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:03	2017-06-15 10:51:24
20714	19318	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:03	2017-06-15 10:51:24
20715	19319	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:03	2017-06-15 10:51:24
20716	19320	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:03	2017-06-15 10:51:24
20717	19321	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:03	2017-06-15 10:51:24
20718	19322	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:03	2017-06-29 03:44:18
20719	19323	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:03	2017-06-29 09:19:48
20720	19324	SECAN	2011-07-07 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:03	2017-06-29 03:44:18
20721	19325	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:03	2017-06-29 09:19:48
20722	19326	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:03	2017-06-29 03:44:22
20723	19327	SECAN	2012-06-27 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:03	2017-06-29 09:19:48
20724	19328	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:03	2017-06-15 10:51:24
20725	19329	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:04	2017-06-15 10:51:24
20726	19330	DEPUTE	2002-07-19 00:00:00	\N	2004-09-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:04	2017-06-15 10:51:24
20727	19331	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:04	2017-06-15 10:51:24
20729	19333	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:04	2017-06-15 10:51:24
20730	19334	DEPUTE	2002-12-16 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:04	2017-06-15 10:51:24
20731	19335	DEPUTE	2007-06-20 00:00:00	\N	2008-04-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:04	2017-06-29 09:19:49
20732	19336	DEPUTE	2010-08-05 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:04	2017-06-29 09:19:49
29226	27823	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:54	\N
20733	19337	DEPUTE	2008-04-19 00:00:00	\N	2010-08-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:04	2017-06-15 10:51:24
20734	19338	DEPUTE	2003-06-25 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:04	2017-06-15 10:51:25
20735	19339	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:04	2017-06-15 10:51:25
20736	19340	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:04	2017-06-19 09:38:35
20737	19341	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:04	2017-06-15 10:51:25
20738	19342	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:04	2017-06-15 10:51:25
20739	19343	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:04	2017-06-19 09:38:35
20740	19344	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:05	2017-06-15 10:51:25
20741	19345	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:05	2017-06-15 10:51:25
20742	19346	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:05	2017-06-19 09:38:35
20744	19348	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:05	2017-06-15 10:51:25
20745	19349	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:05	2017-06-15 10:51:25
20746	19350	DEPUTE	2004-03-30 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:05	2017-06-15 10:51:25
20747	19351	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:05	2017-06-15 10:51:25
20748	19352	DEPUTE	2004-05-01 00:00:00	\N	2005-08-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:05	2017-06-15 10:51:25
20749	19353	DEPUTE	2010-12-15 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:05	2017-06-15 10:51:25
20750	19354	DEPUTE	2010-12-15 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:05	2017-06-29 09:19:49
20751	19355	DEPUTE	2007-07-20 00:00:00	\N	2009-02-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:05	2017-06-29 09:19:49
20752	19356	DEPUTE	2004-05-01 00:00:00	\N	2005-07-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:05	2017-06-15 10:51:25
20753	19357	DEPUTE	2010-04-23 00:00:00	\N	2010-12-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:05	2017-06-15 10:51:25
20754	19358	DEPUTE	2004-05-01 00:00:00	\N	2005-07-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:05	2017-06-15 10:51:25
20755	19359	DEPUTE	2007-07-20 00:00:00	\N	2010-12-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:05	2017-06-15 10:51:25
20756	19360	DEPUTE	2007-07-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:06	2017-06-15 10:51:25
20757	19361	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:06	2017-06-15 10:51:25
20758	19362	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:06	2017-06-15 10:51:25
20759	19363	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:06	2017-06-15 10:51:25
20760	19364	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:06	2017-06-15 10:51:25
20761	19365	DEPUTE	2004-05-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:06	2017-06-15 10:51:25
20762	19366	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:06	2017-06-15 10:51:26
20763	19367	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:06	2017-06-15 10:51:26
20764	19368	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:06	2017-06-15 10:51:26
20765	19369	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:06	2017-06-15 10:51:26
20766	19370	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:06	2017-06-15 10:51:26
20767	19371	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:06	2017-06-15 10:51:26
20768	19372	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:06	2017-06-15 10:51:26
20769	19373	DEPUTE	2007-06-20 00:00:00	\N	2010-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:06	2017-06-15 10:51:26
20770	19374	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:07	2017-06-15 10:51:26
20771	19375	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:07	2017-06-15 10:51:26
20772	19376	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:07	2017-06-15 10:51:26
20773	19377	DEPUTE	2012-06-20 00:00:00	\N	2016-03-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:07	2017-06-15 10:51:26
20774	19378	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:07	2017-06-15 10:51:26
20775	19379	DEPUTE	2007-06-20 00:00:00	\N	2008-04-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:07	2017-06-29 03:44:24
20776	19380	DEPUTE	2009-07-24 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:07	2017-06-29 03:44:24
20778	19382	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:07	2017-06-15 10:51:26
20779	19383	DEPUTE	2007-06-26 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:07	2017-06-29 03:44:20
20780	19384	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:07	2017-06-19 09:38:36
20781	19385	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:07	2017-06-29 03:44:20
20782	19386	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:07	2017-06-15 10:51:26
20783	19387	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:07	2017-06-19 09:38:36
20784	19388	DEPUTE	2005-01-24 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:07	2017-06-15 10:51:26
20785	19389	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:07	2017-06-15 10:51:26
20786	19390	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:07	2017-06-19 09:38:36
20787	19391	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:08	2017-06-15 10:51:27
20788	19392	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:08	2017-06-15 10:51:27
20789	19393	DEPUTE	1995-09-17 00:00:00	\N	1995-10-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:08	2017-06-29 03:44:20
20790	19394	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:08	2017-06-15 10:51:27
20791	19395	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:08	2017-06-29 03:44:20
20792	19396	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:08	2017-06-15 10:51:27
20793	19397	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:08	2017-06-15 10:51:27
20794	19398	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:08	2017-06-29 09:19:50
20795	19399	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:08	2017-06-15 10:51:27
20796	19400	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:08	2017-06-29 09:19:50
20797	19401	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:08	2017-06-19 09:38:36
20798	19402	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:08	2017-06-29 09:19:50
20799	19403	SECAN	2000-04-06 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:08	2017-06-29 09:19:50
29227	27824	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:54	\N
20800	19404	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:08	2017-06-15 10:51:27
20801	19405	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:08	2017-06-15 10:51:27
20802	19406	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:08	2017-06-15 10:51:27
20803	19407	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:08	2017-06-15 10:51:27
20804	19408	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:08	2017-06-15 10:51:27
20805	19409	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:08	2017-06-15 10:51:27
20806	19410	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:08	2017-06-15 10:51:27
20807	19411	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:08	2017-06-15 10:51:27
20808	19412	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:09	2017-06-15 10:51:27
20809	19413	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:09	2017-06-15 10:51:27
20810	19414	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:09	2017-06-15 10:51:27
20811	19415	DEPUTE	1993-04-02 00:00:00	\N	1995-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:09	2017-06-15 10:51:27
20812	19416	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:09	2017-06-15 10:51:27
20813	19417	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:09	2017-06-15 10:51:27
20814	19418	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:09	2017-06-15 10:51:27
20815	19419	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:09	2017-06-15 10:51:27
20816	19420	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:10	2017-06-15 10:51:27
20817	19421	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:10	2017-06-15 10:51:27
20818	19422	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:10	2017-06-15 10:51:28
20819	19423	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:10	2017-06-15 10:51:28
20820	19424	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:10	2017-06-15 10:51:28
20821	19425	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:10	2017-06-29 03:44:22
20822	19426	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:10	2017-06-29 09:19:51
20823	19427	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:10	2017-06-28 03:44:27
20825	19429	SECAN	1995-06-01 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:10	2017-06-29 03:44:22
20826	19430	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:10	2017-06-29 09:19:51
20827	19431	SECAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:10	2017-06-29 03:44:25
20450	19054	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:43	2017-06-15 10:51:15
20452	19056	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:44	2017-06-15 10:51:15
20453	19057	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:44	2017-06-15 10:51:15
20454	19058	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:44	2017-06-28 03:44:17
20455	19059	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:44	2017-06-15 10:51:15
20456	19060	DEPUTE	1995-06-18 00:00:00	\N	1995-12-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:44	2017-06-28 03:44:17
20457	19061	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:44	2017-06-15 10:51:15
20458	19062	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:44	2017-06-15 10:51:15
20459	19063	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:44	2017-06-15 10:51:15
20460	19064	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:44	2017-06-15 10:51:15
20461	19065	DEPUTE	1980-11-30 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:44	2017-06-15 10:51:15
20462	19066	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:44	2017-06-15 10:51:15
20463	19067	DEPUTE	1988-06-13 00:00:00	\N	1992-06-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:44	2017-06-15 10:51:15
20464	19068	DEPUTE	1987-12-17 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:44	2017-06-15 10:51:15
20465	19069	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:44	2017-06-15 10:51:15
20466	19070	DEPUTE	1973-04-02 00:00:00	\N	1977-03-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:44	2017-06-15 10:51:15
20467	19071	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:45	2017-06-15 10:51:15
20468	19072	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:45	2017-06-15 10:51:15
20469	19073	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:45	2017-06-15 10:51:15
20470	19074	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:45	2017-06-15 10:51:15
20471	19075	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:45	2017-06-15 10:51:15
20472	19076	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:45	2017-06-15 10:51:15
20473	19077	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:45	2017-06-19 09:38:27
20474	19078	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:45	2017-06-15 10:51:15
20475	19079	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:45	2017-06-15 10:51:15
20476	19080	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:45	2017-06-15 10:51:15
20477	19081	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:45	2017-06-15 10:51:15
20478	19082	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:45	2017-06-15 10:51:15
20479	19083	VICPDTAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:45	2017-06-29 09:19:43
20480	19084	DEPUTE	1997-06-01 00:00:00	\N	1999-02-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:45	2017-06-29 09:19:43
20481	19085	VICPDTAN	1998-10-01 00:00:00	\N	1999-02-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:45	2017-06-29 09:19:43
20482	19086	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:46	2017-06-15 10:51:16
20483	19087	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:46	2017-06-15 10:51:16
20484	19088	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:46	2017-06-15 10:51:16
20485	19089	DEPUTE	1999-08-29 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:46	2017-06-15 10:51:16
20486	19090	SECAN	2006-10-04 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:46	2017-06-29 09:19:43
20487	19091	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:46	2017-06-28 03:44:17
20488	19092	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:46	2017-06-29 09:19:43
20489	19093	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:46	2017-06-29 09:19:43
20490	19094	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:46	2017-06-29 09:19:43
20491	19095	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:46	2017-06-29 09:19:43
20492	19096	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:46	2017-06-29 09:19:43
20493	19097	SECAN	2003-10-01 00:00:00	\N	2004-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:46	2017-06-29 09:19:43
20494	19098	SECAN	2007-06-27 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:46	2017-06-28 03:44:18
20495	19099	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:46	2017-06-15 10:51:16
20496	19100	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:46	2017-06-15 10:51:16
20497	19101	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:46	2017-06-15 10:51:16
20498	19102	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:46	2017-06-15 10:51:16
20499	19103	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:47	2017-06-19 09:38:28
20500	19104	DEPUTE	2000-09-30 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:47	2017-06-15 10:51:16
20501	19105	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:47	2017-06-15 10:51:16
20502	19106	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:47	2017-06-29 03:44:12
20503	19107	SECAN	2007-06-27 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:47	2017-06-29 09:19:44
20504	19108	SECAN	2012-06-27 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:47	2017-06-29 09:19:44
20505	19109	SECAN	2002-06-26 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:47	2017-06-29 03:44:12
20506	19110	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:47	2017-06-29 09:19:44
20507	19111	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:47	2017-06-29 09:19:44
20508	19112	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:47	2017-06-29 03:44:13
20509	19113	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:47	2017-06-29 03:44:16
20510	19114	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:47	2017-06-15 10:51:17
20511	19115	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:47	2017-06-15 10:51:17
20512	19116	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:47	2017-06-15 10:51:17
20513	19117	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:47	2017-06-15 10:51:17
20514	19118	DEPUTE	1997-06-01 00:00:00	\N	1998-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:47	2017-06-15 10:51:17
20515	19119	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:47	2017-06-15 10:51:17
20516	19120	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:47	2017-06-15 10:51:17
20517	19121	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:47	2017-06-15 10:51:17
20518	19122	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:48	2017-06-15 10:51:17
20519	19123	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:48	2017-06-15 10:51:17
20520	19124	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:48	2017-06-15 10:51:17
20521	19125	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:48	2017-06-15 10:51:17
20522	19126	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:48	2017-06-15 10:51:17
20523	19127	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:48	2017-06-15 10:51:17
20524	19128	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:48	2017-06-15 10:51:17
20525	19129	DEPUTE	1978-04-03 00:00:00	\N	1978-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:49	2017-06-15 10:51:17
20526	19130	DEPUTE	1958-12-09 00:00:00	\N	1962-05-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:49	2017-06-15 10:51:17
20527	19131	DEPUTE	1962-12-06 00:00:00	\N	1963-01-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:49	2017-06-15 10:51:17
20528	19132	DEPUTE	1967-04-03 00:00:00	\N	1967-05-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:49	2017-06-15 10:51:17
20530	19134	DEPUTE	1973-04-02 00:00:00	\N	1973-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:49	2017-06-15 10:51:17
20531	19135	DEPUTE	1982-01-18 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:49	2017-06-15 10:51:17
20532	19136	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:49	2017-06-15 10:51:17
20534	19138	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:49	2017-06-15 10:51:17
20536	19140	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:49	2017-06-15 10:51:17
20537	19141	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:49	2017-06-15 10:51:17
20538	19142	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:49	2017-06-15 10:51:18
20539	19143	DEPUTE	2007-07-20 00:00:00	\N	2010-12-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:50	2017-06-15 10:51:18
20540	19144	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:50	2017-06-15 10:51:18
20541	19145	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:50	2017-06-19 09:38:29
20542	19146	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:50	2017-06-15 10:51:18
20543	19147	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:50	2017-06-15 10:51:18
20544	19148	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:50	2017-06-15 10:51:18
20545	19149	DEPUTE	2005-07-03 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:50	2017-06-15 10:51:18
20546	19150	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:51	2017-06-15 10:51:18
20547	19151	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:51	2017-06-15 10:51:18
20548	19152	DEPUTE	2012-07-21 00:00:00	\N	2014-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:51	2017-06-15 10:51:18
20549	19153	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:51	2017-06-15 10:51:18
20550	19154	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:51	2017-06-15 10:51:18
20551	19155	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:51	2017-06-15 10:51:18
20552	19156	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:51	2017-06-19 09:38:29
20553	19157	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:51	2017-06-15 10:51:18
20555	19159	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:52	2017-06-15 10:51:18
20556	19160	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:52	2017-06-15 10:51:18
20557	19161	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:52	2017-06-15 10:51:18
29228	27825	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:54	\N
20559	19163	DEPUTE	2004-05-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:52	2017-06-15 10:51:18
20560	19164	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:52	2017-06-15 10:51:18
20561	19165	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:52	2017-06-15 10:51:18
20562	19166	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:52	2017-06-15 10:51:19
20563	19167	VICPDTAN	2011-07-07 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:52	2017-06-29 03:44:18
20564	19168	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:52	2017-06-29 03:44:18
20565	19169	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:53	2017-06-15 10:51:19
20566	19170	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:53	2017-06-29 03:44:18
20567	19171	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:53	2017-06-29 09:19:45
20568	19172	DEPUTE	2012-06-20 00:00:00	\N	2016-01-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:53	2017-06-15 10:51:19
20569	19173	DEPUTE	2009-02-15 00:00:00	\N	2010-12-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:53	2017-06-29 09:19:45
20570	19174	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:53	2017-06-15 10:51:19
20571	19175	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:53	2017-06-15 10:51:19
20572	19176	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:53	2017-06-15 10:51:19
20573	19177	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:53	2017-06-19 09:38:30
20574	19178	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:53	2017-06-15 10:51:19
20575	19179	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:53	2017-06-15 10:51:19
20576	19180	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:53	2017-06-15 10:51:19
20577	19181	DEPUTE	2007-07-20 00:00:00	\N	2010-12-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:54	2017-06-15 10:51:19
20578	19182	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:54	2017-06-15 10:51:19
20579	19183	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:54	2017-06-15 10:51:19
20580	19184	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:54	2017-06-15 10:51:19
20581	19185	DEPUTE	2004-05-15 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:54	2017-06-15 10:51:19
20582	19186	DEPUTE	2007-04-27 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:55	2017-06-15 10:51:19
20583	19187	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:55	2017-06-15 10:51:19
20584	19188	DEPUTE	2007-06-20 00:00:00	\N	2010-12-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:55	2017-06-15 10:51:19
20585	19189	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:55	2017-06-15 10:51:19
20586	19190	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:55	2017-06-15 10:51:19
20587	19191	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:55	2017-06-19 09:38:31
20588	19192	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:55	2017-06-15 10:51:20
20589	19193	DEPUTE	2008-09-15 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:55	2017-06-28 03:44:15
20590	19194	DEPUTE	2007-06-20 00:00:00	\N	2007-11-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:55	2017-06-28 03:44:15
20591	19195	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:55	2017-06-19 09:38:31
20592	19196	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:55	2017-06-15 10:51:20
20593	19197	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:55	2017-06-15 10:51:20
20594	19198	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:55	2017-06-19 09:38:31
20595	19199	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:56	2017-06-15 10:51:20
20596	19200	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:56	2017-06-15 10:51:20
20597	19201	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:56	2017-06-19 09:38:31
20598	19202	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:56	2017-06-15 10:51:20
20599	19203	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:56	2017-06-15 10:51:20
20600	19204	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:56	2017-06-19 09:38:31
20601	19205	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:56	2017-06-15 10:51:20
20602	19206	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:56	2017-06-15 10:51:20
20603	19207	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:57	2017-06-15 10:51:20
20604	19208	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:57	2017-06-15 10:51:20
20605	19209	SECAN	2008-10-01 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:57	2017-06-29 09:19:46
20606	19210	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:57	2017-06-29 03:44:20
20607	19211	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:57	2017-06-29 09:19:46
20608	19212	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:57	2017-06-29 09:19:46
20609	19213	SECAN	2012-06-27 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:57	2017-06-29 09:19:46
20610	19214	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:57	2017-06-29 09:19:46
20611	19215	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:57	2017-06-15 10:51:20
20612	19216	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:57	2017-06-19 09:38:32
20613	19217	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:57	2017-06-15 10:51:20
20614	19218	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:57	2017-06-15 10:51:20
20616	19220	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:57	2017-06-15 10:51:21
20617	19221	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:57	2017-06-15 10:51:21
20618	19222	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:57	2017-06-19 09:38:32
20619	19223	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:58	2017-06-15 10:51:21
20620	19224	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:58	2017-06-15 10:51:21
20621	19225	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:58	2017-06-15 10:51:21
20622	19226	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:58	2017-06-15 10:51:21
20623	19227	DEPUTE	2007-07-20 00:00:00	\N	2010-12-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:58	2017-06-15 10:51:21
20624	19228	DEPUTE	2004-07-05 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:58	2017-06-15 10:51:21
29229	27826	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:54	\N
20625	19229	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:58	2017-06-15 10:51:21
20626	19230	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:58	2017-06-19 09:38:32
20627	19231	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:59	2017-06-15 10:51:21
20628	19232	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:59	2017-06-15 10:51:21
20629	19233	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:59	2017-06-19 09:38:32
20630	19234	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:59	2017-06-15 10:51:21
20631	19235	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:59	2017-06-15 10:51:21
20632	19236	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:59	2017-06-15 10:51:21
20633	19237	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:59	2017-06-15 10:51:21
20634	19238	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:00	2017-06-15 10:51:21
20635	19239	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:00	2017-06-15 10:51:21
20636	19240	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:00	2017-06-19 09:38:33
20638	19242	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:00	2017-06-15 10:51:21
20639	19243	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:00	2017-06-15 10:51:21
20060	18664	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:22	2017-06-15 10:51:01
20061	18665	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:22	2017-06-15 10:51:01
20062	18666	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:22	2017-06-15 10:51:01
20063	18667	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:22	2017-06-19 09:38:20
20064	18668	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:22	2017-06-15 10:51:01
20065	18669	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:22	2017-06-15 10:51:01
20066	18670	DEPUTE	1997-06-01 00:00:00	\N	1999-03-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:22	2017-06-15 10:51:01
20072	18676	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:22	2017-06-15 10:51:01
20073	18677	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:22	2017-06-15 10:51:01
20074	18678	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:22	2017-06-15 10:51:02
20075	18679	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:22	2017-06-15 10:51:02
20076	18680	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:23	2017-06-15 10:51:02
20077	18681	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:23	2017-06-15 10:51:02
20078	18682	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:23	2017-06-15 10:51:02
20079	18683	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:23	2017-06-15 10:51:02
20080	18684	SECAN	2008-10-01 00:00:00	\N	2009-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:23	2017-06-29 09:19:36
20081	18685	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:23	2017-06-29 09:19:36
20082	18686	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:23	2017-06-15 10:51:02
20083	18687	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:23	2017-06-15 10:51:02
20084	18688	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:23	2017-06-15 10:51:02
20085	18689	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:23	2017-06-15 10:51:02
20086	18690	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:23	2017-06-15 10:51:02
20087	18691	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:23	2017-06-15 10:51:02
20088	18692	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:23	2017-06-15 10:51:02
20089	18693	DEPUTE	1993-04-02 00:00:00	\N	1996-11-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:23	2017-06-15 10:51:02
20090	18694	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:23	2017-06-15 10:51:02
20091	18695	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:23	2017-06-15 10:51:02
20092	18696	VICPDTAN	2008-10-01 00:00:00	\N	2009-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:23	2017-06-29 03:44:04
20093	18697	SECAN	2009-10-06 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:23	2017-06-29 03:44:07
20094	18698	SECAN	2007-06-27 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:23	2017-06-29 09:19:36
20095	18699	DEPUTE	2007-06-20 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:23	2017-06-29 09:19:36
20096	18700	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:23	2017-06-15 10:51:02
20097	18701	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:23	2017-06-15 10:51:02
20098	18702	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:23	2017-06-15 10:51:02
20099	18703	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:23	2017-06-15 10:51:02
20100	18704	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:23	2017-06-15 10:51:02
20101	18705	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:23	2017-06-15 10:51:02
20102	18706	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:24	2017-06-15 10:51:02
20103	18707	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:24	2017-06-15 10:51:03
20104	18708	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:24	2017-06-15 10:51:03
20105	18709	SECAN	2002-06-26 00:00:00	\N	2003-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:24	2017-06-29 03:44:07
20106	18710	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:24	2017-06-15 10:51:03
20107	18711	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:24	2017-06-19 09:38:20
20108	18712	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:24	2017-06-15 10:51:03
20109	18713	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:24	2017-06-29 03:44:07
20110	18714	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:24	2017-06-15 10:51:03
20111	18715	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:24	2017-06-15 10:51:03
20112	18716	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:24	2017-06-15 10:51:03
20113	18717	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:24	2017-06-15 10:51:03
20114	18718	DEPUTE	1991-02-05 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:24	2017-06-29 09:19:36
20115	18719	DEPUTE	1993-04-02 00:00:00	\N	1997-02-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:24	2017-06-15 10:51:03
29230	27827	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:54	\N
20116	18720	DEPUTE	1988-06-13 00:00:00	\N	1990-12-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:24	2017-06-29 09:19:36
20117	18721	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:24	2017-06-15 10:51:03
20118	18722	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:24	2017-06-15 10:51:03
20120	18724	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:24	2017-06-15 10:51:03
20121	18725	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:24	2017-06-15 10:51:03
20122	18726	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:24	2017-06-15 10:51:03
20123	18727	DEPUTE	1986-04-02 00:00:00	\N	1987-05-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:24	2017-06-15 10:51:03
20124	18728	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:24	2017-06-15 10:51:03
20125	18729	DEPUTE	2010-12-14 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:24	2017-06-29 09:19:36
20126	18730	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:24	2017-06-15 10:51:03
20127	18731	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:24	2017-06-29 09:19:36
20128	18732	DEPUTE	1981-07-02 00:00:00	\N	1982-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:24	2017-06-15 10:51:03
20129	18733	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:24	2017-06-15 10:51:03
20130	18734	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:24	2017-06-15 10:51:03
20131	18735	DEPUTE	1998-11-30 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:25	2017-06-15 10:51:03
20132	18736	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:25	2017-06-15 10:51:03
20133	18737	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:25	2017-06-15 10:51:04
20134	18738	DEPUTE	1962-12-06 00:00:00	\N	1966-02-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:25	2017-06-15 10:51:04
20135	18739	DEPUTE	1967-04-03 00:00:00	\N	1967-05-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:25	2017-06-15 10:51:04
20136	18740	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:25	2017-06-15 10:51:04
20137	18741	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:25	2017-06-15 10:51:04
20138	18742	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:25	2017-06-15 10:51:04
20139	18743	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:25	2017-06-15 10:51:04
20140	18744	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:25	2017-06-15 10:51:04
20141	18745	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:25	2017-06-15 10:51:04
20142	18746	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:25	2017-06-15 10:51:04
20143	18747	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:25	2017-06-15 10:51:04
20145	18749	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:25	2017-06-15 10:51:04
20146	18750	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:25	2017-06-15 10:51:04
20147	18751	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:25	2017-06-15 10:51:04
20148	18752	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:25	2017-06-15 10:51:04
20149	18753	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:25	2017-06-15 10:51:04
20150	18754	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:25	2017-06-15 10:51:04
20151	18755	VICPDTAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:25	2017-06-29 09:19:37
20152	18756	DEPUTE	2007-06-20 00:00:00	\N	2010-12-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:25	2017-06-15 10:51:04
20153	18757	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:25	2017-06-29 09:19:37
20154	18758	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:25	2017-06-19 09:38:21
20156	18760	VICPDTAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:25	2017-06-29 09:19:37
20157	18761	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:25	2017-06-29 09:19:37
20159	18763	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:26	2017-06-15 10:51:04
20160	18764	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:26	2017-06-15 10:51:04
20161	18765	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:26	2017-06-15 10:51:04
20162	18766	DEPUTE	1973-04-02 00:00:00	\N	1974-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:26	2017-06-15 10:51:04
20163	18767	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:26	2017-06-15 10:51:04
20164	18768	DEPUTE	1978-04-03 00:00:00	\N	1978-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:26	2017-06-15 10:51:04
20165	18769	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:26	2017-06-15 10:51:04
20166	18770	DEPUTE	1988-06-06 00:00:00	\N	1991-03-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:26	2017-06-15 10:51:04
20167	18771	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:26	2017-06-15 10:51:05
20168	18772	DEPUTE	1986-10-01 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:26	2017-06-29 03:44:08
20169	18773	DEPUTE	1986-04-02 00:00:00	\N	1986-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:26	2017-06-29 03:44:08
20170	18774	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:26	2017-06-15 10:51:05
20171	18775	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:26	2017-06-15 10:51:05
20172	18776	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:26	2017-06-15 10:51:05
20173	18777	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:26	2017-06-15 10:51:05
20174	18778	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:26	2017-06-15 10:51:05
20175	18779	DEPUTE	1983-11-15 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:26	2017-06-15 10:51:05
20176	18780	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:26	2017-06-15 10:51:05
20177	18781	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:26	2017-06-15 10:51:05
20178	18782	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:27	2017-06-15 10:51:05
20179	18783	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:27	2017-06-15 10:51:05
20180	18784	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:27	2017-06-15 10:51:05
20181	18785	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:27	2017-06-15 10:51:05
20182	18786	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:27	2017-06-29 03:44:09
20183	18787	VICPDTAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:27	2017-06-29 03:44:09
20184	18788	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:27	2017-06-15 10:51:05
20185	18789	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:27	2017-06-15 10:51:05
20186	18790	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:27	2017-06-15 10:51:05
20187	18791	DEPUTE	1994-06-20 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:27	2017-06-15 10:51:05
20188	18792	DEPUTE	1996-02-25 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:27	2017-06-15 10:51:05
20189	18793	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:27	2017-06-15 10:51:05
20190	18794	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:27	2017-06-15 10:51:05
20191	18795	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:27	2017-06-15 10:51:05
20192	18796	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:27	2017-06-19 09:38:21
20193	18797	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:27	2017-06-15 10:51:05
20194	18798	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:27	2017-06-15 10:51:05
20195	18799	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:27	2017-06-15 10:51:05
20196	18800	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:27	2017-06-15 10:51:05
20197	18801	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:27	2017-06-15 10:51:05
20198	18802	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:27	2017-06-15 10:51:05
20199	18803	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:27	2017-06-15 10:51:06
20200	18804	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:27	2017-06-15 10:51:06
20201	18805	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:27	2017-06-15 10:51:06
20202	18806	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:27	2017-06-15 10:51:06
20203	18807	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:27	2017-06-15 10:51:06
20204	18808	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:27	2017-06-27 03:44:00
20205	18809	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:27	2017-06-29 03:44:09
20206	18810	SECAN	1987-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:27	2017-06-27 03:44:00
20207	18811	SECAN	1988-06-24 00:00:00	\N	1992-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:27	2017-06-28 03:44:11
20208	18812	SECAN	1992-10-21 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:27	2017-06-29 03:44:09
20209	18813	SECAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:28	2017-06-29 03:44:09
20210	18814	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:28	2017-06-15 10:51:06
20211	18815	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:28	2017-06-29 03:44:09
20212	18816	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:28	2017-06-29 09:19:37
20213	18817	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:28	2017-06-29 09:19:37
20214	18818	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:28	2017-06-15 10:51:06
20215	18819	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:28	2017-06-15 10:51:06
20216	18820	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:28	2017-06-15 10:51:06
20217	18821	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:28	2017-06-15 10:51:06
20218	18822	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:28	2017-06-15 10:51:06
20219	18823	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:28	2017-06-15 10:51:06
20220	18824	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:28	2017-06-15 10:51:06
20221	18825	DEPUTE	1986-04-02 00:00:00	\N	1986-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:28	2017-06-29 03:44:09
20222	18826	DEPUTE	1986-08-25 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:28	2017-06-29 03:44:09
20223	18827	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:28	2017-06-15 10:51:06
20224	18828	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:29	2017-06-15 10:51:06
20225	18829	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:29	2017-06-15 10:51:06
20226	18830	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:29	2017-06-15 10:51:06
20228	18832	DEPUTE	2012-06-20 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:29	2017-06-15 10:51:07
20229	18833	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:29	2017-06-15 10:51:07
20230	18834	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:29	2017-06-15 10:51:07
20231	18835	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:29	2017-06-28 03:44:07
20232	18836	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:29	2017-06-15 10:51:07
20233	18837	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:29	2017-06-19 09:38:22
20234	18838	DEPUTE	2002-06-25 00:00:00	\N	2002-06-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:29	2017-06-28 03:44:07
20235	18839	DEPUTE	2003-03-11 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:30	2017-06-15 10:51:07
20236	18840	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:30	2017-06-15 10:51:07
20237	18841	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:30	2017-06-19 09:38:22
20239	18843	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:30	2017-06-15 10:51:07
20240	18844	DEPUTE	2006-06-07 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:30	2017-06-15 10:51:07
20241	18845	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:30	2017-06-15 10:51:07
20242	18846	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:30	2017-06-15 10:51:07
20243	18847	DEPUTE	2007-06-20 00:00:00	\N	2008-04-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:30	2017-06-15 10:51:07
20244	18848	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:30	2017-06-15 10:51:07
20246	18850	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:31	2017-06-15 10:51:07
20247	18851	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:31	2017-06-15 10:51:07
20248	18852	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:31	2017-06-15 10:51:07
20249	18853	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:31	2017-06-15 10:51:07
20250	18854	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:31	2017-06-15 10:51:07
20251	18855	DEPUTE	2007-06-20 00:00:00	\N	2008-03-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:31	2017-06-15 10:51:07
20252	18856	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:31	2017-06-19 09:38:23
29231	27828	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:54	\N
20253	18857	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:31	2017-06-15 10:51:07
20927	19531	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:16	2017-06-15 10:51:31
20928	19532	DEPUTE	2002-06-19 00:00:00	\N	2004-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:16	2017-06-15 10:51:31
20929	19533	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:16	2017-06-15 10:51:31
20930	19534	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:16	2017-06-15 10:51:31
20931	19535	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:16	2017-06-15 10:51:31
20932	19536	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:17	2017-06-29 09:19:53
20933	19537	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:17	2017-06-15 10:51:32
20934	19538	SECAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:17	2017-06-29 09:19:53
20935	19539	DEPUTE	1993-04-02 00:00:00	\N	1995-12-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:17	2017-06-15 10:51:32
20936	19540	DEPUTE	1991-06-17 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:17	2017-06-15 10:51:32
20937	19541	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:17	2017-06-15 10:51:32
20938	19542	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:17	2017-06-15 10:51:32
20939	19543	DEPUTE	1968-07-11 00:00:00	\N	1969-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:17	2017-06-15 10:51:32
20940	19544	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:17	2017-06-15 10:51:32
20941	19545	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:17	2017-06-15 10:51:32
20942	19546	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:17	2017-06-15 10:51:32
20943	19547	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:17	2017-06-15 10:51:32
20944	19548	DEPUTE	1993-04-02 00:00:00	\N	1995-05-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:17	2017-06-15 10:51:32
20945	19549	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:17	2017-06-15 10:51:32
20946	19550	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:18	2017-06-15 10:51:32
20947	19551	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:18	2017-06-15 10:51:32
20948	19552	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:18	2017-06-15 10:51:32
20949	19553	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:18	2017-06-15 10:51:32
20950	19554	DEPUTE	1988-06-13 00:00:00	\N	1991-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:18	2017-06-15 10:51:32
20951	19555	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:18	2017-06-15 10:51:32
20952	19556	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:18	2017-06-15 10:51:32
20953	19557	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:18	2017-06-15 10:51:32
20954	19558	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:18	2017-06-15 10:51:32
20955	19559	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:18	2017-06-15 10:51:32
20956	19560	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:18	2017-06-19 09:38:40
20957	19561	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:18	2017-06-15 10:51:32
20958	19562	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:18	2017-06-15 10:51:32
20959	19563	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:18	2017-06-15 10:51:32
20960	19564	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:18	2017-06-15 10:51:32
20961	19565	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:18	2017-06-15 10:51:32
20962	19566	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:19	2017-06-15 10:51:33
20963	19567	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:19	2017-06-15 10:51:33
20964	19568	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:19	2017-06-15 10:51:33
20965	19569	DEPUTE	1980-11-30 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:19	2017-06-15 10:51:33
20966	19570	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:19	2017-06-15 10:51:33
20967	19571	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:19	2017-06-15 10:51:33
20968	19572	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:19	2017-06-15 10:51:33
20969	19573	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:19	2017-06-15 10:51:33
20970	19574	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:19	2017-06-15 10:51:33
20971	19575	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:19	2017-06-15 10:51:33
20972	19576	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:19	2017-06-15 10:51:33
20973	19577	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:19	2017-06-15 10:51:33
20974	19578	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:19	2017-06-15 10:51:33
20976	19580	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:19	2017-06-15 10:51:33
20977	19581	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:19	2017-06-15 10:51:33
20978	19582	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:19	2017-06-15 10:51:33
20979	19583	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:19	2017-06-15 10:51:33
20980	19584	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:19	2017-06-15 10:51:33
20981	19585	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:19	2017-06-15 10:51:33
20982	19586	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:19	2017-06-15 10:51:33
20983	19587	DEPUTE	1986-04-02 00:00:00	\N	1988-04-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:19	2017-06-15 10:51:33
20984	19588	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:20	2017-06-15 10:51:33
20985	19589	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:20	2017-06-15 10:51:33
20986	19590	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:20	2017-06-15 10:51:33
20987	19591	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:20	2017-06-15 10:51:33
20988	19592	DEPUTE	1995-12-12 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:20	2017-06-29 09:19:54
20989	19593	DEPUTE	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:20	2017-06-29 09:19:54
20990	19594	VICPDTAN	2005-10-04 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:20	2017-06-29 09:19:54
20991	19595	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:20	2017-06-15 10:51:34
29232	27829	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:54	\N
20992	19596	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:20	2017-06-19 09:38:40
20993	19597	DEPUTE	1996-10-01 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:20	2017-06-29 09:19:54
20994	19598	DEPUTE	1997-06-12 00:00:00	\N	2000-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:20	2017-06-29 09:19:54
20995	19599	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:20	2017-06-29 03:44:28
20996	19600	VICPDTAN	2005-07-04 00:00:00	\N	2005-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:20	2017-06-29 09:19:54
20997	19601	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:20	2017-06-29 09:19:54
20998	19602	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:20	2017-06-15 10:51:34
20999	19603	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:20	2017-06-15 10:51:34
21000	19604	DEPUTE	1997-06-01 00:00:00	\N	1997-10-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:20	2017-06-29 09:19:54
21001	19605	DEPUTE	1997-12-14 00:00:00	\N	2000-05-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:20	2017-06-29 09:19:54
21002	19606	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:21	2017-06-15 10:51:34
21003	19607	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:21	2017-06-15 10:51:34
21004	19608	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:21	2017-06-15 10:51:34
21006	19610	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:21	2017-06-15 10:51:34
21007	19611	DEPUTE	1981-07-02 00:00:00	\N	1986-03-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:21	2017-06-15 10:51:34
21008	19612	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:21	2017-06-15 10:51:34
21009	19613	VICPDTAN	1994-04-02 00:00:00	\N	1995-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:21	2017-06-29 03:44:29
21010	19614	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:21	2017-06-15 10:51:34
21011	19615	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:21	2017-06-28 03:44:31
21013	19617	VICPDTAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:21	2017-06-29 03:44:25
21014	19618	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:21	2017-06-29 03:44:29
21015	19619	VICPDTAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:21	2017-06-28 03:44:31
21017	19621	DEPUTE	2005-09-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:21	2017-06-29 09:19:55
21018	19622	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:21	2017-06-29 09:19:55
21019	19623	DEPUTE	2010-12-14 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:21	2017-06-29 09:19:55
21020	19624	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:21	2017-06-19 09:38:41
21021	19625	DEPUTE	1981-07-02 00:00:00	\N	1984-08-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:22	2017-06-15 10:51:35
21022	19626	DEPUTE	1990-01-25 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:22	2017-06-15 10:51:35
21309	19913	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:42	2017-06-29 03:45:14
21310	19914	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:42	2017-06-15 10:51:45
21311	19915	DEPUTE	2007-06-26 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:42	2017-06-29 09:20:02
21312	19916	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:42	2017-06-29 09:20:02
21313	19917	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:42	2017-06-29 03:44:38
21314	19918	SECAN	2007-06-27 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:42	2017-06-29 09:20:02
21315	19919	VICPDTAN	2016-05-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:42	2017-06-29 09:20:02
21316	19920	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:42	2017-06-15 10:51:45
21317	19921	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:42	2017-06-15 10:51:45
21318	19922	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:42	2017-06-19 09:38:51
21319	19923	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:43	2017-06-15 10:51:45
21320	19924	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:43	2017-06-19 09:38:51
21321	19925	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:43	2017-06-15 10:51:45
21322	19926	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:43	2017-06-19 09:38:51
21323	19927	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:43	2017-06-15 10:51:45
21324	19928	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:43	2017-06-19 09:38:51
21325	19929	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:43	2017-06-15 10:51:46
21326	19930	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:43	2017-06-19 09:38:52
21327	19931	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:43	2017-06-15 10:51:46
21328	19932	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:43	2017-06-15 10:51:46
21329	19933	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:43	2017-06-19 09:38:52
21330	19934	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:43	2017-06-15 10:51:46
21331	19935	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:43	2017-06-19 09:38:52
21332	19936	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:44	2017-06-15 10:51:46
21333	19937	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:44	2017-06-15 10:51:46
21334	19938	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:44	2017-06-29 03:44:39
21335	19939	DEPUTE	2007-06-20 00:00:00	\N	2009-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:44	2017-06-29 03:44:39
21337	19941	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:44	2017-06-15 10:51:46
21338	19942	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:44	2017-06-28 03:44:34
21339	19943	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:44	2017-06-19 09:38:52
21340	19944	DEPUTE	2008-03-07 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:44	2017-06-15 10:51:46
21341	19945	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:44	2017-06-19 09:38:52
21343	19947	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:44	2017-06-19 09:38:52
21344	19948	DEPUTE	2012-07-22 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:44	2017-06-19 09:38:52
21345	19949	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:44	2017-06-15 10:51:46
21346	19950	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:44	2017-06-15 10:51:46
21347	19951	DEPUTE	2010-06-07 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:45	2017-06-15 10:51:46
21348	19952	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:45	2017-06-19 09:38:52
21349	19953	DEPUTE	2014-09-27 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:45	2017-06-29 03:44:39
21350	19954	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:45	2017-06-15 10:51:46
21351	19955	DEPUTE	2012-07-22 00:00:00	\N	2014-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:45	2017-06-29 03:44:39
21352	19956	DEPUTE	2017-03-22 00:00:00	\N	2017-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:45	2017-06-15 10:51:47
21353	19957	DEPUTE	2010-12-15 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:45	2017-06-15 10:51:47
21354	19958	DEPUTE	2009-11-04 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:45	2017-06-15 10:51:47
21355	19959	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:45	2017-06-19 09:38:53
21356	19960	DEPUTE	2012-07-22 00:00:00	\N	2013-04-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:45	2017-06-15 10:51:47
21357	19961	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:45	2017-06-15 10:51:47
21358	19962	DEPUTE	2007-07-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:45	2017-06-15 10:51:47
21359	19963	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:45	2017-06-15 10:51:47
21360	19964	DEPUTE	2008-04-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:45	2017-06-15 10:51:47
21361	19965	DEPUTE	2014-05-10 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:45	2017-06-19 09:38:53
21362	19966	DEPUTE	2011-05-05 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:45	2017-06-15 10:51:47
21363	19967	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:45	2017-06-19 09:38:53
21364	19968	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:45	2017-06-15 10:51:47
21365	19969	DEPUTE	2008-11-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:45	2017-06-15 10:51:47
21366	19970	DEPUTE	2012-06-20 00:00:00	\N	2016-04-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:45	2017-06-15 10:51:47
21367	19971	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:45	2017-06-19 09:38:53
21369	19973	DEPUTE	2011-05-03 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:45	2017-06-15 10:51:47
21370	19974	DEPUTE	2010-04-01 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:45	2017-06-15 10:51:47
21371	19975	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:45	2017-06-19 09:38:53
21372	19976	DEPUTE	2016-05-30 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:45	2017-06-19 09:38:53
21373	19977	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:46	2017-06-19 09:38:53
21374	19978	DEPUTE	2008-06-02 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:46	2017-06-15 10:51:47
21375	19979	DEPUTE	2012-03-23 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:46	2017-06-15 10:51:47
21376	19980	DEPUTE	2012-06-20 00:00:00	\N	2017-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:46	2017-06-17 03:44:31
21377	19981	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:46	2017-06-15 10:51:47
21378	19982	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:46	2017-06-15 10:51:47
21379	19983	DEPUTE	2008-04-20 00:00:00	\N	2009-07-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:46	2017-06-15 10:51:48
21380	19984	DEPUTE	2009-01-13 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:46	2017-06-15 10:51:48
21381	19985	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:46	2017-06-15 10:51:48
21382	19986	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:46	2017-06-15 10:51:48
21383	19987	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:46	2017-06-19 09:38:54
21384	19988	DEPUTE	2008-12-15 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:46	2017-06-15 10:51:48
21385	19989	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:46	2017-06-19 09:38:54
21386	19990	DEPUTE	2008-02-04 00:00:00	\N	2008-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:46	2017-06-15 10:51:48
21387	19991	DEPUTE	2007-12-16 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:46	2017-06-15 10:51:48
21388	19992	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:46	2017-06-19 09:38:54
21389	19993	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:46	2017-06-15 10:51:48
21390	19994	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:46	2017-06-19 09:38:54
21391	19995	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:46	2017-06-15 10:51:48
21392	19996	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:46	2017-06-29 09:20:04
21393	19997	DEPUTE	2014-05-03 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:46	2017-06-29 09:20:04
21394	19998	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:46	2017-06-15 10:51:48
21395	19999	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:46	2017-06-19 09:38:54
21396	20000	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:46	2017-06-15 10:51:48
21397	20001	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:46	2017-06-19 09:38:54
21398	20002	DEPUTE	2008-04-13 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:47	2017-06-15 10:51:48
21399	20003	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:47	2017-06-15 10:51:48
21401	20005	DEPUTE	2009-10-19 00:00:00	\N	2011-07-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:47	2017-06-15 10:51:48
21402	20006	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:47	2017-06-19 09:38:55
21403	20007	DEPUTE	2011-07-30 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:47	2017-06-15 10:51:48
21404	20008	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:47	2017-06-15 10:51:48
21405	20009	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:47	2017-06-15 10:51:48
21406	20010	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:47	2017-06-15 10:51:48
21407	20011	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:47	2017-06-15 10:51:48
21408	20012	DEPUTE	2010-07-12 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:47	2017-06-15 10:51:49
21409	20013	DEPUTE	2016-03-21 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:47	2017-06-19 09:38:55
21410	20014	DEPUTE	2016-03-21 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:47	2017-06-19 09:38:56
21412	20016	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:47	2017-06-15 10:51:49
21413	20017	DEPUTE	1968-07-11 00:00:00	\N	1968-08-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:47	2017-06-15 10:51:49
21414	20018	DEPUTE	2014-05-03 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:47	2017-06-29 09:20:05
21415	20019	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:47	2017-06-29 09:20:05
29233	27830	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:54	\N
21416	20020	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:47	2017-06-29 03:44:37
21417	20021	DEPUTE	2014-12-22 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:47	2017-06-29 09:20:05
21418	20022	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:47	2017-06-29 09:20:05
21419	20023	DEPUTE	2014-09-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:47	2017-06-28 03:44:36
21420	20024	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:47	2017-06-28 03:44:36
21421	20025	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:48	2017-06-29 09:20:05
21422	20026	DEPUTE	2014-05-03 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:48	2017-06-29 09:20:05
21423	20027	SECAN	1987-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:48	2017-06-29 09:20:05
21424	20028	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:48	2017-06-29 09:20:05
21425	20029	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:48	2017-06-15 10:51:49
21426	20030	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:48	2017-06-15 10:51:49
21427	20031	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:48	2017-06-15 10:51:49
21428	20032	DEPUTE	2007-06-20 00:00:00	\N	2010-04-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:48	2017-06-29 03:44:37
21429	20033	DEPUTE	2011-06-30 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:48	2017-06-29 03:44:37
21430	20034	DEPUTE	2011-10-28 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:48	2017-06-15 10:51:49
21431	20035	DEPUTE	2009-07-23 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:48	2017-06-15 10:51:49
21432	20036	DEPUTE	2010-12-15 00:00:00	\N	2012-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:48	2017-06-15 10:51:49
21433	20037	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:48	2017-06-19 09:39:01
21434	20038	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:48	2017-06-15 10:51:50
21435	20039	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:49	2017-06-15 10:51:50
21436	20040	DEPUTE	2007-06-20 00:00:00	\N	2011-05-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:49	2017-06-15 10:51:50
21437	20041	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:49	2017-06-15 10:51:50
21438	20042	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:49	2017-06-15 10:51:50
21439	20043	DEPUTE	2012-06-20 00:00:00	\N	2014-05-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:49	2017-06-29 03:44:42
21440	20044	DEPUTE	2014-06-30 00:00:00	\N	2014-07-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:49	2017-06-29 03:44:42
21441	20045	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:49	2017-06-15 10:51:50
21442	20046	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:49	2017-06-19 09:39:03
21443	20047	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:49	2017-06-15 10:51:50
21444	20048	DEPUTE	2014-09-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:49	2017-06-29 09:20:06
21445	20049	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:49	2017-06-29 09:20:06
21446	20050	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:49	2017-06-15 10:51:50
21447	20051	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:49	2017-06-15 10:51:50
21448	20052	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:49	2017-06-19 09:39:04
21449	20053	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:50	2017-06-15 10:51:50
21450	20054	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:50	2017-06-15 10:51:50
21451	20055	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:50	2017-06-29 09:20:06
21452	20056	DEPUTE	2015-04-06 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:50	2017-06-29 09:20:06
21453	20057	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:50	2017-06-15 10:51:50
21454	20058	DEPUTE	2012-06-20 00:00:00	\N	2017-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:50	2017-06-15 10:51:50
21455	20059	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:50	2017-06-15 10:51:50
21456	20060	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:50	2017-06-19 09:39:05
21457	20061	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:50	2017-06-15 10:51:51
21459	20063	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:50	2017-06-15 10:51:51
21460	20064	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:50	2017-06-19 09:39:06
21461	20065	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:50	2017-06-15 10:51:51
21462	20066	DEPUTE	2007-06-20 00:00:00	\N	2008-03-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:51	2017-06-15 10:51:51
21463	20067	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:51	2017-06-15 10:51:51
21464	20068	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:51	2017-06-19 09:39:07
21465	20069	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:51	2017-06-15 10:51:51
21466	20070	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:51	2017-06-15 10:51:51
21467	20071	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:51	2017-06-15 10:51:51
21468	20072	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:51	2017-06-19 09:39:08
21469	20073	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:51	2017-06-15 10:51:51
21470	20074	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:51	2017-06-19 09:39:08
21471	20075	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:51	2017-06-15 10:51:51
21472	20076	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:51	2017-06-29 09:20:07
21473	20077	DEPUTE	2014-09-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:51	2017-06-29 09:20:07
21474	20078	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:51	2017-06-15 10:51:51
21475	20079	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:51	2017-06-19 09:39:09
21476	20080	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:52	2017-06-15 10:51:51
21477	20081	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:52	2017-06-19 09:39:10
21478	20082	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:52	2017-06-15 10:51:51
21479	20083	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:52	2017-06-19 09:39:10
21480	20084	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:52	2017-06-28 03:44:39
21481	20085	VICPDTAN	2011-10-03 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:52	2017-06-28 03:44:39
29234	27831	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:54	\N
21482	20086	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:52	2017-06-15 10:51:51
21483	20087	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:52	2017-06-15 10:51:52
21484	20088	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:52	2017-06-19 09:39:11
21485	20089	DEPUTE	2007-06-26 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:52	2017-06-29 03:44:44
21487	20091	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:52	2017-06-29 03:44:44
21488	20092	SECAN	2007-06-27 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:52	2017-06-29 03:44:44
21489	20093	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:52	2017-06-15 10:51:52
21490	20094	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:52	2017-06-19 09:39:11
21491	20095	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:52	2017-06-15 10:51:52
21492	20096	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:52	2017-06-19 09:39:11
21493	20097	DEPUTE	2007-06-26 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:53	2017-06-29 03:44:44
21494	20098	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:53	2017-06-19 09:39:11
21495	20099	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:53	2017-06-29 03:44:44
21496	20100	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:53	2017-06-15 10:51:52
21023	19627	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:22	2017-06-15 10:51:35
21024	19628	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:22	2017-06-15 10:51:35
21025	19629	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:22	2017-06-15 10:51:35
21026	19630	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:22	2017-06-15 10:51:35
21027	19631	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:22	2017-06-15 10:51:35
21028	19632	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:22	2017-06-15 10:51:35
21029	19633	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:23	2017-06-15 10:51:35
21030	19634	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:23	2017-06-15 10:51:35
21031	19635	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:23	2017-06-15 10:51:35
21032	19636	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:23	2017-06-15 10:51:35
21033	19637	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:23	2017-06-15 10:51:35
21034	19638	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:23	2017-06-15 10:51:35
21035	19639	DEPUTE	1997-06-01 00:00:00	\N	1998-04-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:23	2017-06-15 10:51:35
21036	19640	DEPUTE	1998-02-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:23	2017-06-15 10:51:35
21037	19641	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:23	2017-06-15 10:51:35
21038	19642	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:23	2017-06-15 10:51:35
21039	19643	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:23	2017-06-19 09:38:41
21040	19644	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:23	2017-06-15 10:51:35
21041	19645	DEPUTE	1986-08-25 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:23	2017-06-29 09:19:55
21042	19646	DEPUTE	1986-04-02 00:00:00	\N	1986-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:23	2017-06-29 09:19:55
21043	19647	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:23	2017-06-15 10:51:35
21044	19648	DEPUTE	1988-06-13 00:00:00	\N	1992-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:23	2017-06-15 10:51:35
21045	19649	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:23	2017-06-15 10:51:35
21046	19650	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:23	2017-06-15 10:51:35
21047	19651	DEPUTE	2000-03-19 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:23	2017-06-15 10:51:35
21049	19653	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:24	2017-06-15 10:51:36
21050	19654	DEPUTE	2007-06-20 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:24	2017-06-15 10:51:36
21051	19655	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:24	2017-06-15 10:51:36
21052	19656	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:24	2017-06-29 09:19:56
21053	19657	DEPUTE	2000-06-26 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:24	2017-06-15 10:51:36
21054	19658	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:24	2017-06-15 10:51:36
21055	19659	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:24	2017-06-28 03:44:32
21056	19660	SECAN	2006-12-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:24	2017-06-29 09:19:56
21057	19661	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:24	2017-06-28 03:44:32
21058	19662	DEPUTE	2000-10-22 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:24	2017-06-15 10:51:36
21059	19663	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:24	2017-06-15 10:51:36
21060	19664	DEPUTE	2001-04-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:24	2017-06-15 10:51:36
21061	19665	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:24	2017-06-15 10:51:36
21063	19667	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:25	2017-06-15 10:51:36
21064	19668	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:25	2017-06-19 09:38:42
21065	19669	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:25	2017-06-15 10:51:36
21066	19670	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:25	2017-06-19 09:38:42
21067	19671	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:25	2017-06-15 10:51:36
21068	19672	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:25	2017-06-15 10:51:36
21069	19673	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:25	2017-06-19 09:38:42
21070	19674	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:25	2017-06-15 10:51:36
21071	19675	DEPUTE	2007-07-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:25	2017-06-15 10:51:36
21072	19676	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:26	2017-06-15 10:51:36
21073	19677	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:26	2017-06-15 10:51:36
21074	19678	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:26	2017-06-19 09:38:43
21075	19679	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:26	2017-06-15 10:51:37
29235	27832	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:54	\N
21076	19680	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:26	2017-06-29 03:44:26
21077	19681	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:26	2017-06-29 09:19:56
21078	19682	VICPDTAN	2008-09-26 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:26	2017-06-29 03:44:26
21079	19683	VICPDTAN	2012-06-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:26	2017-06-29 09:19:56
21080	19684	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:26	2017-06-15 10:51:37
21081	19685	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:26	2017-06-15 10:51:37
21082	19686	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:26	2017-06-15 10:51:37
21083	19687	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:26	2017-06-15 10:51:37
21084	19688	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:26	2017-06-19 09:38:43
21085	19689	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:26	2017-06-15 10:51:37
21086	19690	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:26	2017-06-15 10:51:37
21087	19691	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:26	2017-06-19 09:38:43
21088	19692	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:27	2017-06-29 09:19:57
21089	19693	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:27	2017-06-15 10:51:37
21090	19694	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:27	2017-06-19 09:38:43
21091	19695	DEPUTE	2002-06-25 00:00:00	\N	2002-06-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:27	2017-06-29 09:19:57
21092	19696	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:27	2017-06-15 10:51:37
21093	19697	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:27	2017-06-15 10:51:37
21094	19698	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:27	2017-06-15 10:51:37
21095	19699	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:27	2017-06-15 10:51:37
21096	19700	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:27	2017-06-15 10:51:37
21097	19701	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:27	2017-06-15 10:51:37
21098	19702	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:27	2017-06-19 09:38:43
21100	19704	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:28	2017-06-15 10:51:37
21101	19705	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:28	2017-06-15 10:51:37
21102	19706	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:28	2017-06-15 10:51:38
21103	19707	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:28	2017-06-15 10:51:38
21104	19708	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:28	2017-06-19 09:38:44
21105	19709	DEPUTE	2007-07-04 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:28	2017-06-15 10:51:38
21106	19710	DEPUTE	2012-12-17 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:28	2017-06-19 09:38:44
21107	19711	DEPUTE	2007-07-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:28	2017-06-15 10:51:38
21108	19712	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:29	2017-06-19 09:38:44
21109	19713	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:29	2017-06-15 10:51:38
21110	19714	DEPUTE	2004-05-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:29	2017-06-15 10:51:38
21111	19715	DEPUTE	2004-11-22 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:30	2017-06-15 10:51:38
21112	19716	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:30	2017-06-15 10:51:38
21113	19717	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:30	2017-06-19 09:38:44
21114	19718	DEPUTE	2004-05-01 00:00:00	\N	2005-07-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:30	2017-06-15 10:51:38
21115	19719	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:30	2017-06-29 09:19:58
21116	19720	QUESTAN	2007-06-27 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:30	2017-06-29 09:19:58
21117	19721	SECAN	2005-10-04 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:30	2017-06-29 09:19:58
21118	19722	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:30	2017-06-29 09:19:58
21119	19723	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:30	2017-06-15 10:51:38
21120	19724	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:31	2017-06-15 10:51:38
21121	19725	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:31	2017-06-15 10:51:38
21122	19726	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:31	2017-06-19 09:38:45
21123	19727	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:31	2017-06-15 10:51:38
21124	19728	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:31	2017-06-15 10:51:39
21125	19729	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:31	2017-06-15 10:51:39
21126	19730	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:31	2017-06-15 10:51:39
21127	19731	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:31	2017-06-19 09:38:45
21128	19732	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:32	2017-06-15 10:51:39
21129	19733	DEPUTE	2007-06-20 00:00:00	\N	2011-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:32	2017-06-15 10:51:39
21130	19734	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:32	2017-06-15 10:51:39
21131	19735	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:32	2017-06-15 10:51:39
21132	19736	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:32	2017-06-19 09:38:45
21133	19737	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:32	2017-06-19 09:38:45
21136	19740	DEPUTE	2010-11-13 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:33	2017-06-15 10:51:39
21137	19741	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:33	2017-06-15 10:51:39
21138	19742	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:33	2017-06-15 10:51:39
21139	19743	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:33	2017-06-19 09:38:45
21140	19744	DEPUTE	2010-06-05 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:33	2017-06-15 10:51:39
21141	19745	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:33	2017-06-29 09:19:59
21142	19746	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:33	2017-06-29 09:19:59
21143	19747	DEPUTE	2009-04-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:33	2017-06-15 10:51:39
21144	19748	DEPUTE	2009-09-28 00:00:00	\N	2010-05-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:33	2017-06-29 09:19:59
21145	19749	DEPUTE	2007-07-20 00:00:00	\N	2009-07-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:33	2017-06-29 09:19:59
21146	19750	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:33	2017-06-19 09:38:45
21147	19751	DEPUTE	2012-07-22 00:00:00	\N	2013-08-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:33	2017-06-15 10:51:39
21148	19752	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:33	2017-06-15 10:51:39
21149	19753	DEPUTE	2007-07-20 00:00:00	\N	2012-03-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:33	2017-06-15 10:51:39
21150	19754	DEPUTE	2008-09-19 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:33	2017-06-15 10:51:39
21151	19755	DEPUTE	2010-04-23 00:00:00	\N	2011-06-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:33	2017-06-15 10:51:39
21152	19756	DEPUTE	2012-07-22 00:00:00	\N	2016-03-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:33	2017-06-15 10:51:40
21153	19757	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:33	2017-06-15 10:51:40
21154	19758	DEPUTE	2007-07-20 00:00:00	\N	2009-07-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:34	2017-06-15 10:51:40
21155	19759	DEPUTE	2013-06-10 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:34	2017-06-19 09:38:46
21156	19760	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:34	2017-06-15 10:51:40
21157	19761	DEPUTE	2014-05-10 00:00:00	\N	2014-05-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:34	2017-06-15 10:51:40
21158	19762	DEPUTE	2004-05-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:34	2017-06-15 10:51:40
21159	19763	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:34	2017-06-15 10:51:40
21160	19764	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:34	2017-06-15 10:51:40
21161	19765	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:34	2017-06-15 10:51:40
21163	19767	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:34	2017-06-15 10:51:40
21164	19768	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:34	2017-06-15 10:51:40
21165	19769	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:34	2017-06-19 09:38:46
21166	19770	DEPUTE	2005-10-04 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:34	2017-06-29 03:44:34
21167	19771	DEPUTE	2007-06-20 00:00:00	\N	2010-12-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:34	2017-06-15 10:51:40
21168	19772	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:34	2017-06-29 03:44:34
21169	19773	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:34	2017-06-15 10:51:40
21170	19774	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:34	2017-06-15 10:51:40
21171	19775	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:34	2017-06-19 09:38:46
21172	19776	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:34	2017-06-15 10:51:40
21173	19777	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:35	2017-06-15 10:51:40
21174	19778	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:35	2017-06-15 10:51:40
21175	19779	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:35	2017-06-15 10:51:40
21176	19780	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:35	2017-06-15 10:51:40
21177	19781	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:35	2017-06-15 10:51:40
21178	19782	DEPUTE	2007-06-20 00:00:00	\N	2007-11-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:35	2017-06-15 10:51:40
21179	19783	DEPUTE	2002-07-19 00:00:00	\N	2005-06-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:35	2017-06-15 10:51:40
21180	19784	DEPUTE	2009-01-05 00:00:00	\N	2010-12-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:35	2017-06-15 10:51:40
21181	19785	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:35	2017-06-15 10:51:40
21182	19786	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:35	2017-06-15 10:51:40
21183	19787	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:35	2017-06-19 09:38:46
21184	19788	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:35	2017-06-15 10:51:41
21185	19789	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:35	2017-06-15 10:51:41
21186	19790	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:35	2017-06-15 10:51:41
21187	19791	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:35	2017-06-15 10:51:41
21188	19792	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:35	2017-06-15 10:51:41
21189	19793	DEPUTE	2012-07-22 00:00:00	\N	2014-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:36	2017-06-15 10:51:41
21190	19794	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:36	2017-06-15 10:51:41
21191	19795	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:36	2017-06-15 10:51:41
21192	19796	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:36	2017-06-19 09:38:47
21194	19798	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:36	2017-06-15 10:51:41
21195	19799	SECAN	2009-10-06 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:36	2017-06-29 09:20:00
21196	19800	DEPUTE	2012-07-22 00:00:00	\N	2014-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:36	2017-06-15 10:51:41
21197	19801	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:36	2017-06-29 09:20:00
21198	19802	VICPDTAN	2008-10-01 00:00:00	\N	2009-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:36	2017-06-29 09:20:00
21199	19803	DEPUTE	2003-02-03 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:36	2017-06-29 09:20:00
21200	19804	DEPUTE	2002-06-19 00:00:00	\N	2002-11-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:36	2017-06-29 09:20:00
21201	19805	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:36	2017-06-15 10:51:41
21202	19806	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:36	2017-06-19 09:38:47
21203	19807	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:36	2017-06-15 10:51:41
21204	19808	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:36	2017-06-15 10:51:41
21205	19809	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:36	2017-06-15 10:51:41
21206	19810	DEPUTE	2002-06-25 00:00:00	\N	2002-06-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:36	2017-06-29 03:44:35
21207	19811	VICPDTAN	2010-11-16 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:36	2017-06-29 03:44:35
21208	19812	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:36	2017-06-19 09:38:47
21209	19813	VICPDTAN	2006-12-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:36	2017-06-29 09:20:00
21211	19815	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:36	2017-06-29 03:44:35
21213	19817	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:37	2017-06-15 10:51:42
21214	19818	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:37	2017-06-15 10:51:42
21215	19819	DEPUTE	2002-06-19 00:00:00	\N	2003-02-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:37	2017-06-15 10:51:42
21216	19820	DEPUTE	2003-06-02 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:37	2017-06-15 10:51:42
21217	19821	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:37	2017-06-15 10:51:42
21218	19822	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:37	2017-06-15 10:51:42
21219	19823	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:37	2017-06-19 09:38:47
21220	19824	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:37	2017-06-15 10:51:42
21221	19825	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:37	2017-06-15 10:51:42
21222	19826	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:37	2017-06-19 09:38:48
21223	19827	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:37	2017-06-15 10:51:42
21224	19828	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:37	2017-06-15 10:51:42
21225	19829	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:37	2017-06-15 10:51:42
21226	19830	DEPUTE	2014-05-03 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:37	2017-06-29 09:20:00
21227	19831	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:37	2017-06-29 09:20:00
21228	19832	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:37	2017-06-15 10:51:42
21229	19833	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:38	2017-06-15 10:51:42
21230	19834	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:38	2017-06-15 10:51:42
21231	19835	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:38	2017-06-19 09:38:48
21232	19836	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:38	2017-06-15 10:51:42
21233	19837	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:38	2017-06-15 10:51:42
21234	19838	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:38	2017-06-19 09:38:48
21235	19839	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:38	2017-06-15 10:51:42
21236	19840	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:38	2017-06-15 10:51:42
21237	19841	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:38	2017-06-19 09:38:48
21238	19842	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:38	2017-06-15 10:51:42
21239	19843	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:38	2017-06-29 03:44:31
21240	19844	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:38	2017-06-29 03:44:36
21241	19845	SECAN	2007-06-27 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:38	2017-06-29 03:44:31
21242	19846	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:38	2017-06-29 03:44:36
21243	19847	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:38	2017-06-29 09:20:00
21244	19848	SECAN	2012-06-27 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:38	2017-06-29 09:20:00
21245	19849	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:38	2017-06-15 10:51:43
21246	19850	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:38	2017-06-15 10:51:43
21247	19851	DEPUTE	2012-06-20 00:00:00	\N	2013-08-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:38	2017-06-29 09:20:01
21248	19852	DEPUTE	2014-05-03 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:38	2017-06-29 09:20:01
21249	19853	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:38	2017-06-15 10:51:43
21250	19854	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:38	2017-06-15 10:51:43
21251	19855	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:38	2017-06-15 10:51:43
21252	19856	DEPUTE	2007-06-20 00:00:00	\N	2007-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:38	2017-06-15 10:51:43
21253	19857	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:39	2017-06-29 09:20:01
21254	19858	DEPUTE	2007-06-20 00:00:00	\N	2011-10-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:39	2017-06-29 03:44:36
21255	19859	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:39	2017-06-19 09:38:49
21256	19860	DEPUTE	2007-06-26 00:00:00	\N	2011-10-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:39	2017-06-29 03:44:36
21257	19861	DEPUTE	2002-06-25 00:00:00	\N	2002-06-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:39	2017-06-29 09:20:01
21258	19862	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:39	2017-06-29 03:44:36
21259	19863	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:39	2017-06-15 10:51:43
21260	19864	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:39	2017-06-15 10:51:43
21261	19865	DEPUTE	2012-06-20 00:00:00	\N	2016-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:39	2017-06-29 09:20:01
21262	19866	VICPDTAN	2012-06-27 00:00:00	\N	2014-12-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:39	2017-06-29 09:20:01
21263	19867	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:39	2017-06-15 10:51:43
21265	19869	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:39	2017-06-15 10:51:43
21266	19870	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:39	2017-06-15 10:51:43
21267	19871	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:39	2017-06-19 09:38:49
21268	19872	DEPUTE	2007-06-26 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:39	2017-06-29 09:20:01
21269	19873	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:39	2017-06-29 09:20:01
21270	19874	DEPUTE	2016-03-12 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:39	2017-06-29 09:20:01
21271	19875	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:39	2017-06-29 09:20:01
21272	19876	DEPUTE	2007-06-20 00:00:00	\N	2009-01-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:39	2017-06-28 03:44:32
21273	19877	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:39	2017-06-28 03:44:32
21274	19878	DEPUTE	2012-06-20 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:39	2017-06-19 09:38:49
21275	19879	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:40	2017-06-15 10:51:44
21276	19880	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:40	2017-06-19 09:38:49
21277	19881	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:40	2017-06-15 10:51:44
21278	19882	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:40	2017-06-19 09:38:49
29236	27833	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:54	\N
21279	19883	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:40	2017-06-15 10:51:44
21280	19884	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:40	2017-06-15 10:51:44
21281	19885	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:40	2017-06-19 09:38:50
21282	19886	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:40	2017-06-15 10:51:44
21283	19887	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:40	2017-06-15 10:51:44
21284	19888	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:40	2017-06-19 09:38:50
21285	19889	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:40	2017-06-15 10:51:44
21286	19890	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:40	2017-06-19 09:38:50
21287	19891	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:40	2017-06-15 10:51:44
21288	19892	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:41	2017-06-15 10:51:44
21289	19893	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:41	2017-06-19 09:38:50
21290	19894	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:41	2017-06-15 10:51:44
21291	19895	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:41	2017-06-19 09:38:50
21292	19896	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:41	2017-06-15 10:51:44
21294	19898	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:41	2017-06-15 10:51:44
21295	19899	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:41	2017-06-19 09:38:50
21296	19900	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:41	2017-06-15 10:51:44
21297	19901	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:41	2017-06-15 10:51:44
21298	19902	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:41	2017-06-19 09:38:50
21299	19903	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:41	2017-06-15 10:51:45
21300	19904	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:41	2017-06-15 10:51:45
21301	19905	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:41	2017-06-19 09:38:50
21302	19906	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:42	2017-06-15 10:51:45
21303	19907	DEPUTE	2012-06-20 00:00:00	\N	2016-02-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:42	2017-06-15 10:51:45
21304	19908	DEPUTE	2007-06-20 00:00:00	\N	2010-11-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:42	2017-06-15 10:51:45
21305	19909	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:42	2017-06-15 10:51:45
21306	19910	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:42	2017-06-19 09:38:51
20828	19432	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:10	2017-06-29 09:19:51
20829	19433	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:10	2017-06-29 09:19:51
20830	19434	SECAN	2002-06-26 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:10	2017-06-28 03:44:27
20831	19435	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:10	2017-06-15 10:51:28
20832	19436	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:11	2017-06-15 10:51:28
20833	19437	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:11	2017-06-15 10:51:28
20834	19438	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:11	2017-06-15 10:51:28
20835	19439	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:11	2017-06-15 10:51:28
20836	19440	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:11	2017-06-15 10:51:28
20837	19441	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:11	2017-06-15 10:51:28
20838	19442	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:11	2017-06-15 10:51:28
20839	19443	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:11	2017-06-15 10:51:28
20840	19444	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:11	2017-06-15 10:51:28
20841	19445	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:11	2017-06-15 10:51:28
20842	19446	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:11	2017-06-15 10:51:28
20843	19447	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:11	2017-06-15 10:51:28
20844	19448	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:11	2017-06-15 10:51:28
20845	19449	DEPUTE	1994-02-08 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:11	2017-06-15 10:51:28
20846	19450	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:11	2017-06-15 10:51:28
20847	19451	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:11	2017-06-15 10:51:29
20848	19452	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:11	2017-06-19 09:38:38
20849	19453	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:12	2017-06-15 10:51:29
20850	19454	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:12	2017-06-15 10:51:29
20851	19455	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:12	2017-06-15 10:51:29
20852	19456	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:12	2017-06-15 10:51:29
20853	19457	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:12	2017-06-15 10:51:29
20854	19458	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:12	2017-06-15 10:51:29
20855	19459	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:12	2017-06-15 10:51:29
20856	19460	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:12	2017-06-15 10:51:29
20857	19461	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:12	2017-06-15 10:51:29
20858	19462	DEPUTE	2007-06-20 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:12	2017-06-15 10:51:29
20859	19463	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:12	2017-06-15 10:51:29
20860	19464	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:12	2017-06-15 10:51:29
20861	19465	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:12	2017-06-15 10:51:29
20862	19466	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:12	2017-06-15 10:51:29
20863	19467	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:12	2017-06-15 10:51:29
20864	19468	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:13	2017-06-15 10:51:29
20865	19469	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:13	2017-06-15 10:51:29
29237	27834	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:54	\N
20866	19470	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:13	2017-06-15 10:51:29
20867	19471	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:13	2017-06-15 10:51:29
20868	19472	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:13	2017-06-19 09:38:38
20869	19473	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:13	2017-06-15 10:51:29
20870	19474	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:13	2017-06-15 10:51:30
20871	19475	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:13	2017-06-15 10:51:30
20872	19476	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:13	2017-06-15 10:51:30
20873	19477	DEPUTE	1997-06-01 00:00:00	\N	1999-12-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:13	2017-06-15 10:51:30
20874	19478	DEPUTE	1988-05-08 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:13	2017-06-15 10:51:30
20875	19479	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:13	2017-06-15 10:51:30
20881	19485	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:14	2017-06-15 10:51:30
20882	19486	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:14	2017-06-15 10:51:30
20883	19487	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:14	2017-06-15 10:51:30
20884	19488	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:14	2017-06-15 10:51:30
20885	19489	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:14	2017-06-15 10:51:30
20886	19490	DEPUTE	1986-04-02 00:00:00	\N	1987-10-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:14	2017-06-15 10:51:30
20887	19491	DEPUTE	1993-04-02 00:00:00	\N	1996-04-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:14	2017-06-15 10:51:30
20888	19492	DEPUTE	1987-10-14 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:14	2017-06-15 10:51:30
20889	19493	DEPUTE	1988-06-06 00:00:00	\N	1988-10-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:14	2017-06-15 10:51:30
20890	19494	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:14	2017-06-15 10:51:30
20891	19495	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:14	2017-06-15 10:51:30
20892	19496	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:14	2017-06-15 10:51:30
20893	19497	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:14	2017-06-19 09:38:39
20894	19498	DEPUTE	1988-06-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:14	2017-06-15 10:51:30
20895	19499	DEPUTE	1997-05-17 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:14	2017-06-15 10:51:30
20896	19500	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:14	2017-06-15 10:51:30
20897	19501	DEPUTE	1978-04-02 00:00:00	\N	1980-09-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:14	2017-06-15 10:51:30
20898	19502	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:14	2017-06-15 10:51:30
20899	19503	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:14	2017-06-15 10:51:30
20900	19504	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:14	2017-06-15 10:51:30
20901	19505	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:15	2017-06-15 10:51:30
20902	19506	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:15	2017-06-15 10:51:31
20903	19507	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:15	2017-06-15 10:51:31
20904	19508	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:15	2017-06-15 10:51:31
20905	19509	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:15	2017-06-15 10:51:31
20907	19511	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:15	2017-06-15 10:51:31
20908	19512	DEPUTE	1991-06-18 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:15	2017-06-15 10:51:31
20909	19513	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:15	2017-06-15 10:51:31
20910	19514	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:15	2017-06-15 10:51:31
20911	19515	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:15	2017-06-15 10:51:31
20912	19516	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:15	2017-06-15 10:51:31
20913	19517	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:16	2017-06-15 10:51:31
20914	19518	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:16	2017-06-15 10:51:31
20915	19519	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:16	2017-06-15 10:51:31
20916	19520	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:16	2017-06-15 10:51:31
20917	19521	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:16	2017-06-29 09:19:53
20919	19523	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:16	2017-06-15 10:51:31
20920	19524	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:16	2017-06-15 10:51:31
20921	19525	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:16	2017-06-15 10:51:31
20922	19526	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:16	2017-06-15 10:51:31
20923	19527	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:16	2017-06-15 10:51:31
20924	19528	DEPUTE	1987-06-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:16	2017-06-15 10:51:31
20925	19529	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:16	2017-06-15 10:51:31
21688	20292	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:07	2017-06-19 09:39:21
21689	20293	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:07	2017-06-19 09:39:21
21690	20294	DEPUTE	2012-06-20 00:00:00	\N	2014-05-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:08	2017-06-29 09:20:14
21691	20295	DEPUTE	2017-03-28 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:08	2017-06-29 09:20:14
21692	20296	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:08	2017-06-19 09:39:22
21693	20297	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:08	2017-06-19 09:39:22
21694	20298	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:08	2017-06-19 09:39:22
21695	20299	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:08	2017-06-19 09:39:22
21696	20300	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:08	2017-06-19 09:39:22
21697	20301	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:08	2017-06-19 09:39:22
21698	20302	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:08	2017-06-29 09:20:14
21699	20303	DEPUTE	2012-06-26 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:08	2017-06-29 09:20:14
29238	27835	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:54	\N
21700	20304	DEPUTE	2012-06-26 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:08	2017-06-29 03:45:13
21701	20305	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:08	2017-06-29 03:45:13
21702	20306	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:08	2017-06-19 09:39:22
21703	20307	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:08	2017-06-19 09:39:22
21704	20308	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:08	2017-06-19 09:39:22
21705	20309	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:08	2017-06-19 09:39:22
21706	20310	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:08	2017-06-19 09:39:22
21707	20311	DEPUTE	2012-06-20 00:00:00	\N	2014-04-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:08	2017-06-15 10:52:01
21708	20312	DEPUTE	2012-06-20 00:00:00	\N	2013-02-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:09	2017-06-15 10:52:01
21709	20313	DEPUTE	2012-06-20 00:00:00	\N	2014-05-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:09	2017-06-15 10:52:01
21710	20314	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:09	2017-06-19 09:39:22
21711	20315	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:09	2017-06-19 09:39:23
21712	20316	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:09	2017-06-19 09:39:23
21713	20317	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:09	2017-06-19 09:39:23
21714	20318	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:09	2017-06-19 09:39:23
21715	20319	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:09	2017-06-19 09:39:23
21716	20320	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:09	2017-06-19 09:39:23
21717	20321	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:09	2017-06-19 09:39:23
21718	20322	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:09	2017-06-19 09:39:23
21719	20323	DEPUTE	2012-06-20 00:00:00	\N	2016-03-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:09	2017-06-29 09:20:14
21720	20324	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:10	2017-06-19 09:39:23
21721	20325	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:10	2017-06-19 09:39:23
21723	20327	DEPUTE	2012-06-20 00:00:00	\N	2013-02-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:10	2017-06-15 10:52:01
21724	20328	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:10	2017-06-19 09:39:23
21725	20329	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:10	2017-06-19 09:39:23
21726	20330	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:10	2017-06-19 09:39:23
21727	20331	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:10	2017-06-19 09:39:24
21728	20332	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:10	2017-06-19 09:39:24
21729	20333	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:10	2017-06-19 09:39:24
21730	20334	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:10	2017-06-19 09:39:24
21731	20335	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:10	2017-06-19 09:39:24
21732	20336	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:10	2017-06-19 09:39:24
21733	20337	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:11	2017-06-19 09:39:24
21734	20338	DEPUTE	2012-06-20 00:00:00	\N	2012-10-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:11	2017-06-15 10:52:02
21735	20339	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:11	2017-06-19 09:39:24
21736	20340	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:11	2017-06-19 09:39:24
21738	20342	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:11	2017-06-19 09:39:24
21739	20343	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:11	2017-06-19 09:39:24
21740	20344	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:11	2017-06-19 09:39:24
21741	20345	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:11	2017-06-19 09:39:24
21742	20346	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:11	2017-06-19 09:39:24
21743	20347	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:11	2017-06-19 09:39:24
21744	20348	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:11	2017-06-29 09:20:15
21745	20349	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:11	2017-06-29 03:44:49
21746	20350	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:11	2017-06-29 09:20:15
21747	20351	SECAN	2012-06-27 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:11	2017-06-29 09:20:15
21748	20352	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:11	2017-06-19 09:39:24
21749	20353	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:11	2017-06-19 09:39:24
21750	20354	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:11	2017-06-19 09:39:24
21751	20355	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:11	2017-06-19 09:39:24
21752	20356	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:11	2017-06-19 09:39:24
21753	20357	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:12	2017-06-19 09:39:24
21754	20358	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:12	2017-06-19 09:39:24
21756	20360	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:12	2017-06-19 09:39:24
21757	20361	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:12	2017-06-19 09:39:25
21758	20362	DEPUTE	2012-06-20 00:00:00	\N	2015-07-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:12	2017-06-29 09:20:16
21759	20363	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:12	2017-06-19 09:39:25
21760	20364	DEPUTE	2012-06-20 00:00:00	\N	2013-01-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:12	2017-06-15 10:52:03
21761	20365	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:12	2017-06-19 09:39:25
21762	20366	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:12	2017-06-19 09:39:25
21763	20367	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:12	2017-06-19 09:39:25
21764	20368	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:12	2017-06-19 09:39:25
21765	20369	DEPUTE	2012-07-22 00:00:00	\N	2016-03-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:12	2017-06-15 10:52:03
21766	20370	DEPUTE	2012-07-22 00:00:00	\N	2014-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:12	2017-06-15 10:52:03
21767	20371	DEPUTE	2014-06-02 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:12	2017-06-19 09:39:25
29239	27836	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:54	\N
21768	20372	DEPUTE	2014-07-04 00:00:00	\N	2015-07-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:12	2017-06-15 10:52:03
21769	20373	DEPUTE	2012-07-22 00:00:00	\N	2015-04-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:12	2017-06-15 10:52:03
21770	20374	DEPUTE	2015-08-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:12	2017-06-19 09:39:25
21771	20375	DEPUTE	2014-10-05 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:12	2017-06-19 09:39:25
21772	20376	DEPUTE	2012-07-22 00:00:00	\N	2017-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:13	2017-06-17 03:44:43
21773	20377	DEPUTE	2012-07-22 00:00:00	\N	2014-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:13	2017-06-15 10:52:03
21775	20379	DEPUTE	2014-05-10 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:13	2017-06-19 09:39:26
21776	20380	DEPUTE	2014-05-10 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:13	2017-06-19 09:39:26
21777	20381	DEPUTE	2012-07-22 00:00:00	\N	2016-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:13	2017-06-15 10:52:03
21778	20382	DEPUTE	2015-08-28 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:13	2017-06-19 09:39:26
21779	20383	DEPUTE	2016-03-12 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:13	2017-06-19 09:39:26
21780	20384	DEPUTE	2012-07-22 00:00:00	\N	2014-07-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:13	2017-06-15 10:52:04
21781	20385	DEPUTE	2012-07-22 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:13	2017-06-19 09:39:26
21782	20386	DEPUTE	2014-09-27 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:13	2017-06-19 09:39:26
21783	20387	DEPUTE	2014-07-04 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:13	2017-06-19 09:39:26
21784	20388	DEPUTE	2017-01-07 00:00:00	\N	2017-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:13	2017-06-15 10:52:04
21785	20389	DEPUTE	2014-05-10 00:00:00	\N	2017-03-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:13	2017-06-15 10:52:04
21786	20390	DEPUTE	2012-07-22 00:00:00	\N	2014-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:13	2017-06-15 10:52:04
21787	20391	DEPUTE	2016-03-12 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:13	2017-06-19 09:39:26
21788	20392	DEPUTE	2016-03-12 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:14	2017-06-19 09:39:26
21789	20393	DEPUTE	2015-07-18 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:14	2017-06-19 09:39:27
21790	20394	DEPUTE	2016-06-13 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:14	2017-06-19 09:39:27
21791	20395	DEPUTE	2016-03-12 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:14	2017-06-19 09:39:27
21792	20396	DEPUTE	2012-12-17 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:14	2017-06-19 09:39:27
21793	20397	DEPUTE	2014-05-10 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:14	2017-06-19 09:39:27
21794	20398	DEPUTE	2013-08-03 00:00:00	\N	2014-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:14	2017-06-15 10:52:04
21795	20399	DEPUTE	2013-03-24 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:14	2017-06-19 09:39:27
21796	20400	DEPUTE	2013-06-10 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:14	2017-06-19 09:39:27
21797	20401	DEPUTE	2013-06-24 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:14	2017-06-19 09:39:27
21798	20402	DEPUTE	2016-04-25 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:15	2017-06-19 09:39:27
21799	20403	DEPUTE	2016-05-30 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:15	2017-06-19 09:39:27
21800	20404	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:15	2017-06-15 10:52:05
21801	20405	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:15	2017-06-15 10:52:05
21802	20406	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:15	2017-06-15 10:52:05
21803	20407	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:15	2017-06-15 10:52:05
21804	20408	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:15	2017-06-15 10:52:05
21805	20409	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:15	2017-06-15 10:52:05
21806	20410	DEPUTE	2015-09-14 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:15	2017-06-19 09:39:30
21807	20411	DEPUTE	1968-09-06 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:15	2017-06-15 10:52:05
21808	20412	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:15	2017-06-15 10:52:05
21809	20413	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:15	2017-06-15 10:52:05
21810	20414	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:16	2017-06-15 10:52:05
21811	20415	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:16	2017-06-15 10:52:05
21812	20416	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:16	2017-06-15 10:52:05
21813	20417	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:16	2017-06-15 10:52:05
21814	20418	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:16	2017-06-15 10:52:05
21815	20419	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:16	2017-06-15 10:52:05
21816	20420	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:16	2017-06-15 10:52:05
21817	20421	DEPUTE	2014-06-30 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:16	2017-06-19 09:39:30
21818	20422	DEPUTE	2014-06-30 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:16	2017-06-19 09:39:30
21819	20423	DEPUTE	2014-07-30 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:16	2017-06-19 09:39:30
21820	20424	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:16	2017-06-15 10:52:05
21821	20425	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:16	2017-06-15 10:52:05
21822	20426	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:16	2017-06-15 10:52:05
21823	20427	DEPUTE	1973-04-02 00:00:00	\N	1973-05-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:16	2017-06-15 10:52:05
21824	20428	DEPUTE	1978-04-03 00:00:00	\N	1978-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:16	2017-06-15 10:52:05
21825	20429	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:17	2017-06-15 10:52:05
21826	20430	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:17	2017-06-15 10:52:05
21827	20431	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:17	2017-06-15 10:52:05
21828	20432	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:17	2017-06-15 10:52:06
21829	20433	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:17	2017-06-15 10:52:06
21830	20434	DEPUTE	1973-04-02 00:00:00	\N	1974-07-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:17	2017-06-15 10:52:06
21831	20435	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:17	2017-06-15 10:52:06
21832	20436	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:17	2017-06-15 10:52:06
21833	20437	DEPUTE	1963-05-12 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:17	2017-06-15 10:52:06
29240	27837	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:54	\N
21834	20438	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:17	2017-06-15 10:52:06
21835	20439	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:17	2017-06-15 10:52:06
16232	14836	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:15	2017-06-15 10:48:43
16311	14915	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:21	2017-06-15 10:48:46
16318	14922	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:22	2017-06-15 10:48:46
16326	14930	DEPUTE	1996-10-01 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:22	2017-06-29 09:18:17
21844	20448	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:48:50	\N
21845	20449	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:48:50	\N
21846	20450	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:48:50	\N
21847	20451	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:48:50	\N
21848	20452	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:48:50	\N
21849	20453	SECAN	1986-04-04 00:00:00	\N	1987-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:48:50	2017-06-29 09:18:19
21850	20454	DEPUTE	1988-06-13 00:00:00	\N	1988-11-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:48:50	\N
21851	20455	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:48:50	2017-06-29 09:18:19
16423	15027	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:30	2017-06-15 10:48:50
16430	15034	DEPUTE	1971-12-05 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:30	2017-06-15 10:48:50
16516	15120	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:35	2017-06-15 10:48:53
16524	15128	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:36	2017-06-15 10:48:53
16609	15213	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:42	2017-06-15 10:48:57
16617	15221	DEPUTE	1999-03-15 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:42	2017-06-15 10:48:57
21852	20456	DEPUTE	1992-02-03 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:49:00	\N
21853	20457	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:49:00	\N
21854	20458	VICPDTAN	2002-06-26 00:00:00	\N	2003-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:49:00	2017-06-29 09:18:25
21855	20459	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:49:00	\N
21856	20460	DEPUTE	2005-09-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:49:00	2017-06-29 09:18:25
21857	20461	DEPUTE	2007-06-20 00:00:00	\N	2010-04-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:49:00	2017-06-29 03:42:50
21858	20462	DEPUTE	2010-12-14 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:49:00	2017-06-29 09:18:25
21859	20463	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:49:00	2017-06-19 09:37:03
21860	20464	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:49:00	2017-06-29 09:18:25
21861	20465	VICPDTAN	2003-10-01 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:49:00	2017-06-29 03:42:50
21862	20466	VICPDTAN	2007-06-27 00:00:00	\N	2008-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:49:00	2017-06-29 09:18:25
16713	15317	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:49	2017-06-15 10:49:00
16722	15326	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:49	2017-06-15 10:49:01
16810	15414	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:53	2017-06-15 10:49:04
16818	15422	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:54	2017-06-15 10:49:04
16902	15506	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:59	2017-06-15 10:49:07
16907	15511	DEPUTE	1997-06-01 00:00:00	\N	2001-09-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:59	2017-06-15 10:49:07
16999	15603	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:06	2017-06-15 10:49:11
21863	20467	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:49:12	\N
21864	20468	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:49:12	\N
21865	20469	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:49:12	\N
21866	20470	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:49:12	\N
21867	20471	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:49:12	\N
21868	20472	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:49:12	\N
21869	20473	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:49:12	\N
17094	15698	SECAN	2005-10-04 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:12	2017-06-29 09:18:32
17096	15700	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:12	2017-06-15 10:49:14
17104	15708	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:12	2017-06-29 09:18:32
17193	15797	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:18	2017-06-29 09:18:34
17200	15804	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:18	2017-06-15 10:49:18
17286	15890	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:25	2017-06-15 10:49:21
17294	15898	DEPUTE	1987-10-14 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:27	2017-06-15 10:49:21
21870	20474	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:49:22	\N
21871	20475	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:49:22	\N
21872	20476	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:49:22	\N
17385	15989	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:33	2017-06-15 10:49:24
17471	16075	DEPUTE	1973-05-13 00:00:00	\N	1975-04-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:37	2017-06-15 10:49:27
17479	16083	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:37	2017-06-15 10:49:28
17485	16089	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:37	2017-06-29 03:43:07
17564	16168	DEPUTE	1969-07-21 00:00:00	\N	1970-07-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:42	2017-06-15 10:49:31
17571	16175	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:42	2017-06-15 10:49:31
17579	16183	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:43	2017-06-15 10:49:32
21873	20477	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:49:35	\N
21874	20478	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:49:35	\N
17664	16268	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:49	2017-06-15 10:49:35
17669	16273	DEPUTE	1978-04-02 00:00:00	\N	1980-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:49	2017-06-15 10:49:35
17680	16284	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:49	2017-06-15 10:49:35
17767	16371	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:54	2017-06-15 10:49:38
17773	16377	PDTAN	2000-03-29 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:54	2017-06-29 09:18:46
17860	16464	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:01	2017-06-15 10:49:42
17867	16471	DEPUTE	1981-07-02 00:00:00	\N	1985-12-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:02	2017-06-15 10:49:42
21875	20479	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:49:45	\N
21876	20480	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:49:45	\N
21877	20481	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:49:45	\N
21878	20482	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:49:45	2017-06-29 09:18:50
21879	20483	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:49:45	\N
21880	20484	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:49:45	2017-06-29 09:18:50
17957	16561	DEPUTE	1992-05-05 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:09	2017-06-15 10:49:45
17965	16569	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:10	2017-06-15 10:49:46
18051	16655	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:14	2017-06-15 10:49:48
18058	16662	DEPUTE	1964-12-12 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:14	2017-06-15 10:49:49
18151	16755	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:20	2017-06-15 10:49:52
18240	16844	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:26	2017-06-15 10:49:55
18247	16851	DEPUTE	1973-04-02 00:00:00	\N	1975-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:27	2017-06-15 10:49:56
21881	20485	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:49:56	\N
21882	20486	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:49:56	\N
18336	16940	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:33	2017-06-15 10:49:59
18345	16949	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:34	2017-06-15 10:49:59
18432	17036	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:40	2017-06-15 10:50:02
18440	17044	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:41	2017-06-15 10:50:02
18524	17128	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:47	2017-06-15 10:50:06
18532	17136	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:48	2017-06-15 10:50:06
21883	20487	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:50:08	2017-06-28 03:43:35
21884	20488	SECAN	1995-05-31 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:50:08	2017-06-29 03:43:33
21885	20489	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:50:08	\N
21886	20490	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:50:08	\N
21887	20491	DEPUTE	2007-06-20 00:00:00	\N	2011-07-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:50:08	2017-06-29 09:19:04
21888	20492	VICPDTAN	2007-06-27 00:00:00	\N	2011-07-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:50:08	2017-06-29 09:19:04
21889	20493	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:50:08	2017-06-19 09:37:43
21890	20494	SECAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:50:08	2017-06-28 03:43:35
21891	20495	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:50:08	2017-06-29 03:43:33
21892	20496	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:50:08	2017-06-29 09:19:04
18628	17232	DEPUTE	2002-06-19 00:00:00	\N	2005-07-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:53	2017-06-15 10:50:09
18634	17238	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:53	2017-06-15 10:50:10
18716	17320	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:57	2017-06-15 10:50:12
18722	17326	SECAN	2012-06-27 00:00:00	\N	2013-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:57	2017-06-29 03:43:35
18730	17334	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:58	2017-06-15 10:50:13
18820	17424	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:06	2017-06-15 10:50:16
19679	18283	DEPUTE	1984-09-29 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:54	2017-06-15 10:50:47
19768	18372	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:02	2017-06-15 10:50:51
21896	20500	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:50:51	\N
21897	20501	DEPUTE	1993-04-02 00:00:00	\N	1994-02-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:50:51	\N
21898	20502	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:50:51	\N
19861	18465	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:08	2017-06-15 10:50:54
19869	18473	DEPUTE	1968-07-11 00:00:00	\N	1971-02-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:09	2017-06-15 10:50:54
19956	18560	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:15	2017-06-15 10:50:57
19963	18567	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:16	2017-06-15 10:50:58
20043	18647	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:21	2017-06-15 10:51:00
20050	18654	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:21	2017-06-15 10:51:01
20058	18662	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:22	2017-06-15 10:51:01
21899	20503	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:51:01	\N
21900	20504	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:51:01	\N
21901	20505	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:51:01	\N
21902	20506	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:51:01	\N
21903	20507	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:51:01	\N
20144	18748	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:25	2017-06-15 10:51:04
20155	18759	VICPDTAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:25	2017-06-29 09:19:37
20158	18762	PDTAN	2007-03-07 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:25	2017-06-29 09:19:37
20238	18842	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:30	2017-06-15 10:51:07
20245	18849	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:30	2017-06-15 10:51:07
20254	18858	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:31	2017-06-15 10:51:08
20344	18948	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:38	2017-06-15 10:51:11
21904	20508	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:51:12	\N
29241	27838	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:54	\N
21905	20509	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:51:12	\N
21906	20510	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:51:12	\N
21907	20511	DEPUTE	2002-06-19 00:00:00	\N	2006-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:51:12	\N
21908	20512	DEPUTE	1997-05-25 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:51:12	\N
20433	19037	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:43	2017-06-29 09:19:42
20439	19043	DEPUTE	1993-04-02 00:00:00	\N	1995-09-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:43	2017-06-15 10:51:14
20529	19133	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:49	2017-06-15 10:51:17
20535	19139	DEPUTE	1973-04-02 00:00:00	\N	1975-07-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:49	2017-06-15 10:51:17
21909	20513	DEPUTE	2008-04-19 00:00:00	\N	2010-08-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:51:21	\N
20728	19332	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:04	2017-06-15 10:51:24
20824	19428	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:10	2017-06-15 10:51:28
21910	20514	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:51:30	\N
21911	20515	DEPUTE	1988-06-13 00:00:00	\N	1992-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:51:30	\N
21912	20516	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:51:30	\N
21913	20517	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:51:30	\N
21914	20518	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:51:30	2017-06-19 09:38:38
20918	19522	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:16	2017-06-29 09:19:53
20926	19530	DEPUTE	1993-04-02 00:00:00	\N	1994-10-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:16	2017-06-15 10:51:31
21005	19609	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:21	2017-06-15 10:51:34
21012	19616	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:21	2017-06-15 10:51:34
21016	19620	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:21	2017-06-29 09:19:55
21915	20519	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:51:39	\N
21916	20520	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:51:39	\N
21210	19814	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:36	2017-06-29 09:20:00
21212	19816	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:37	2017-06-15 10:51:41
21308	19912	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:42	2017-06-29 03:45:14
21917	20521	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:51:46	\N
21918	20522	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:51:52	\N
21919	20523	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:51:52	2017-06-19 09:39:12
21920	20524	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:51:57	2017-06-19 09:39:19
21921	20525	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:52:02	2017-06-19 09:39:24
21922	20526	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:52:06	\N
21923	20527	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:52:06	\N
21924	20528	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:52:06	\N
21925	20529	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:52:06	\N
21926	20530	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:52:06	\N
16411	15015	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:30	2017-06-29 03:42:43
16504	15108	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:34	2017-06-15 10:48:53
16187	14791	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:12	2017-06-15 10:48:41
16277	14881	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:19	2017-06-15 10:48:44
16678	15282	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:47	2017-06-15 10:48:59
17015	15619	DEPUTE	1996-02-26 00:00:00	\N	1996-03-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:07	2017-06-29 09:18:31
17169	15773	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:16	2017-06-15 10:49:17
16797	15401	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:52	2017-06-15 10:49:03
16864	15468	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:57	2017-06-15 10:49:06
16916	15520	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:00	2017-06-15 10:49:07
16997	15601	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:06	2017-06-29 03:42:57
16600	15204	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:41	2017-06-15 10:48:56
17452	16056	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:36	2017-06-15 10:49:27
17527	16131	DEPUTE	1988-06-13 00:00:00	\N	1990-12-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:39	2017-06-29 09:18:41
17851	16455	DEPUTE	2000-04-28 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:00	2017-06-15 10:49:41
17919	16523	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:06	2017-06-15 10:49:44
17658	16262	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:48	2017-06-15 10:49:34
17731	16335	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:52	2017-06-15 10:49:37
17266	15870	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:24	2017-06-15 10:49:20
17306	15910	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:28	2017-06-15 10:49:22
18065	16669	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:14	2017-06-15 10:49:49
18501	17105	DEPUTE	1983-12-19 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:45	2017-06-15 10:50:05
18604	17208	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:51	2017-06-29 09:19:04
18202	16806	QUESTAN	2002-06-26 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:23	2017-06-29 03:43:24
18312	16916	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:31	2017-06-15 10:49:58
18417	17021	DEPUTE	1977-06-30 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:39	2017-06-15 10:50:01
18011	16615	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:12	2017-06-15 10:49:47
18904	17508	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:12	2017-06-15 10:50:20
19259	17863	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:34	2017-06-15 10:50:33
19314	17918	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:35	2017-06-15 10:50:34
19066	17670	DEPUTE	1997-05-25 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:20	2017-06-15 10:50:25
19120	17724	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:24	2017-06-15 10:50:27
18688	17292	DEPUTE	1981-07-02 00:00:00	\N	1983-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:56	2017-06-15 10:50:12
18746	17350	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:00	2017-06-15 10:50:13
19494	18098	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:48	2017-06-15 10:50:41
19575	18179	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:50	2017-06-15 10:50:44
19934	18538	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:13	2017-06-15 10:50:56
20030	18634	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:19	2017-06-15 10:51:00
19649	18253	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:53	2017-06-29 09:19:26
19691	18295	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:55	2017-06-15 10:50:48
19773	18377	DEPUTE	1995-09-07 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:02	2017-06-28 03:44:02
19830	18434	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:06	2017-06-15 10:50:53
19422	18026	DEPUTE	1978-04-03 00:00:00	\N	1978-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:41	2017-06-15 10:50:38
20291	18895	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:34	2017-06-15 10:51:09
20351	18955	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:38	2017-06-15 10:51:11
20438	19042	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:43	2017-06-15 10:51:14
20662	19266	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:01	2017-06-15 10:51:22
20743	19347	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:05	2017-06-15 10:51:25
20451	19055	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:43	2017-06-15 10:51:15
20533	19137	DEPUTE	1993-04-02 00:00:00	\N	1995-09-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:49	2017-06-15 10:51:17
20554	19158	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:52	2017-06-15 10:51:18
20119	18723	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:24	2017-06-15 10:51:03
20227	18831	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:29	2017-06-15 10:51:07
20975	19579	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:19	2017-06-15 10:51:33
21048	19652	DEPUTE	2000-03-20 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:24	2017-06-15 10:51:36
21193	19797	DEPUTE	2006-09-02 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:36	2017-06-15 10:51:41
21307	19911	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:42	2017-06-15 10:51:45
20906	19510	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:15	2017-06-15 10:51:31
17346	15950	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:45:30	2017-06-29 03:43:04
19335	17939	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:36	2017-06-29 09:19:20
20265	18869	DEPUTE	2017-01-07 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:32	2017-06-29 09:19:39
20674	19278	SECAN	2012-06-27 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:01	2017-06-29 09:19:47
12775	20531	CONSGENEPARI	2015-01-01 00:00:00	\N	2020-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-06-16 16:14:59	2017-06-16 16:15:22
21927	20532	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-17 03:42:51	2017-06-29 09:18:23
21928	20533	DEPUTE	2017-06-16 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-17 03:44:44	2017-06-19 09:39:26
21929	20534	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:36:37	\N
21930	20535	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:36:39	\N
21931	20536	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:36:49	\N
21932	20537	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:36:55	\N
21933	20538	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:36:55	\N
21934	20539	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:36:57	\N
21935	20540	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:36:58	\N
21936	20541	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:37:00	\N
21937	20542	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:37:01	\N
21938	20543	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:37:03	\N
21939	20544	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:37:04	\N
21940	20545	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:37:04	\N
15627	14231	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:35	2017-06-15 10:48:19
15632	14236	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:35	2017-06-15 10:48:19
15738	14342	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:43	2017-06-15 10:48:24
15810	14414	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:50	2017-06-15 10:48:27
15816	14420	DEPUTE	1997-06-01 00:00:00	\N	1998-08-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:51	2017-06-15 10:48:27
15821	14425	DEPUTE	2002-06-19 00:00:00	\N	2007-03-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:51	2017-06-15 10:48:27
21841	20445	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:25:29	2017-06-15 10:48:27
15827	14431	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:51	2017-06-15 10:48:27
15832	14436	VICPDTAN	2001-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:52	2017-06-29 09:18:06
15837	14441	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:52	2017-06-15 10:48:28
15842	14446	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:52	2017-06-15 10:48:28
15848	14452	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:52	2017-06-15 10:48:28
15853	14457	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:52	2017-06-15 10:48:28
15911	14515	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:54	2017-06-15 10:48:30
15916	14520	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:54	2017-06-15 10:48:30
15920	14524	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:55	2017-06-15 10:48:31
15926	14530	DEPUTE	1978-04-02 00:00:00	\N	1981-01-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:55	2017-06-15 10:48:31
15931	14535	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:55	2017-06-15 10:48:31
15937	14541	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:55	2017-06-15 10:48:31
15942	14546	DEPUTE	1986-09-29 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:55	2017-06-29 03:42:31
15947	14551	DEPUTE	1983-07-27 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:55	2017-06-15 10:48:32
29242	27839	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:54	\N
16004	14608	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:58	2017-06-15 10:48:34
16009	14613	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:58	2017-06-15 10:48:34
16016	14620	DEPUTE	1988-06-06 00:00:00	\N	1990-12-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:59	2017-06-15 10:48:34
16021	14625	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:43:59	2017-06-15 10:48:34
16026	14630	DEPUTE	1993-04-02 00:00:00	\N	1995-12-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:00	2017-06-15 10:48:35
16031	14635	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:00	2017-06-15 10:48:35
16036	14640	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:00	2017-06-15 10:48:35
16041	14645	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:00	2017-06-15 10:48:35
16096	14700	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:04	2017-06-15 10:48:37
16101	14705	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:04	2017-06-15 10:48:38
16106	14710	DEPUTE	1981-07-02 00:00:00	\N	1981-12-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:05	2017-06-29 09:18:12
16110	14714	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:05	2017-06-15 10:48:38
16117	14721	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:06	2017-06-15 10:48:38
16121	14725	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:06	2017-06-15 10:48:38
16127	14731	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:07	2017-06-15 10:48:39
16132	14736	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:07	2017-06-15 10:48:39
21842	20446	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:25:41	2017-06-15 10:48:39
21843	20447	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:25:41	2017-06-15 10:48:39
16139	14743	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:08	2017-06-15 10:48:39
16193	14797	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:44:12	2017-06-15 10:48:41
21893	20497	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:50:19	\N
18913	17517	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:12	2017-06-20 03:43:30
18921	17525	DEPUTE	1997-07-05 00:00:00	\N	2000-09-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:13	2017-06-15 10:50:20
19010	17614	DEPUTE	1989-12-04 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:18	2017-06-15 10:50:23
19014	17618	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:18	2017-06-15 10:50:24
19100	17704	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:22	2017-06-15 10:50:26
19108	17712	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:23	2017-06-15 10:50:27
19187	17791	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:29	2017-06-15 10:50:30
19193	17797	DEPUTE	2011-07-30 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:30	2017-06-15 10:50:30
19201	17805	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:31	2017-06-15 10:50:31
21894	20498	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:50:31	\N
19284	17888	VICPDTAN	2002-06-26 00:00:00	\N	2004-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:34	2017-06-28 03:43:50
19291	17895	DEPUTE	1981-07-24 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:34	2017-06-15 10:50:34
19299	17903	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:35	2017-06-15 10:50:34
19382	17986	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:38	2017-06-15 10:50:37
19390	17994	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:39	2017-06-15 10:50:37
19480	18084	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:47	2017-06-15 10:50:41
19485	18089	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:47	2017-06-15 10:50:41
21895	20499	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 10:50:41	\N
19577	18181	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:50	2017-06-15 10:50:44
19664	18268	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:53	2017-06-29 03:43:54
19675	18279	DEPUTE	1997-06-12 00:00:00	\N	2000-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:54	2017-06-29 09:19:27
21497	20101	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:53	2017-06-19 09:39:11
21498	20102	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:53	2017-06-15 10:51:52
21499	20103	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:53	2017-06-19 09:39:11
21500	20104	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:53	2017-06-15 10:51:52
21501	20105	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:53	2017-06-15 10:51:52
21502	20106	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:53	2017-06-19 09:39:11
21503	20107	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:53	2017-06-15 10:51:52
21504	20108	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:53	2017-06-15 10:51:52
21505	20109	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:53	2017-06-19 09:39:12
21506	20110	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:54	2017-06-15 10:51:52
21509	20113	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:54	2017-06-15 10:51:52
21510	20114	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:54	2017-06-19 09:39:12
21511	20115	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:54	2017-06-15 10:51:53
21512	20116	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:54	2017-06-29 03:44:44
21513	20117	DEPUTE	2016-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:54	2017-06-29 03:44:44
21514	20118	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:54	2017-06-15 10:51:53
21515	20119	DEPUTE	2014-07-04 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:54	2017-06-29 09:20:08
21516	20120	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:54	2017-06-29 09:20:08
21517	20121	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:54	2017-06-15 10:51:53
21518	20122	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:54	2017-06-19 09:39:12
21519	20123	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:54	2017-06-15 10:51:53
21520	20124	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:54	2017-06-15 10:51:53
21522	20126	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:54	2017-06-15 10:51:53
21523	20127	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:54	2017-06-29 09:20:32
21524	20128	DEPUTE	2014-05-03 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:54	2017-06-29 09:20:32
21525	20129	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:55	2017-06-15 10:51:53
21526	20130	DEPUTE	2013-08-03 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:55	2017-06-29 09:20:08
21527	20131	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:55	2017-06-29 09:20:08
21528	20132	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:55	2017-06-15 10:51:53
21529	20133	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:55	2017-06-29 03:44:44
21530	20134	VICPDTAN	2012-06-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:55	2017-06-29 03:44:44
21531	20135	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:55	2017-06-15 10:51:53
21532	20136	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:55	2017-06-15 10:51:53
21533	20137	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:55	2017-06-15 10:51:53
21534	20138	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:55	2017-06-19 09:39:12
21535	20139	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:55	2017-06-15 10:51:53
21536	20140	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:55	2017-06-29 09:20:08
21537	20141	SECAN	2012-06-27 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:55	2017-06-29 09:20:08
21538	20142	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:55	2017-06-29 09:20:08
21539	20143	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:55	2017-06-29 03:44:45
21540	20144	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:55	2017-06-15 10:51:53
21541	20145	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:55	2017-06-19 09:39:13
21542	20146	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:55	2017-06-15 10:51:53
21543	20147	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:56	2017-06-15 10:51:54
21544	20148	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:56	2017-06-19 09:39:13
21545	20149	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:56	2017-06-19 09:39:13
21546	20150	DEPUTE	2010-12-29 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:56	2017-06-15 10:51:54
21547	20151	DEPUTE	2012-07-22 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:56	2017-06-19 09:39:13
21548	20152	DEPUTE	2012-07-22 00:00:00	\N	2014-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:56	2017-06-15 10:51:54
21549	20153	DEPUTE	2012-07-22 00:00:00	\N	2014-12-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:56	2017-06-15 10:51:54
21550	20154	DEPUTE	2012-07-22 00:00:00	\N	2014-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:56	2017-06-15 10:51:54
21551	20155	DEPUTE	2012-07-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:56	2017-06-19 09:39:13
21552	20156	DEPUTE	2017-05-06 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:56	2017-06-19 09:39:14
21553	20157	DEPUTE	2016-03-04 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:56	2017-06-19 09:39:14
21554	20158	DEPUTE	2015-07-18 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:57	2017-06-19 09:39:14
21555	20159	DEPUTE	2012-07-22 00:00:00	\N	2014-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:57	2017-06-29 09:20:09
21556	20160	DEPUTE	2015-02-09 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:57	2017-06-29 09:20:09
21557	20161	DEPUTE	2016-02-28 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:57	2017-06-19 09:39:14
21558	20162	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:57	2017-06-29 09:20:09
21559	20163	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:57	2017-06-29 09:20:09
21560	20164	DEPUTE	2012-06-26 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:57	2017-06-29 09:20:09
21561	20165	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:57	2017-06-19 09:39:14
21562	20166	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:57	2017-06-19 09:39:14
21563	20167	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:57	2017-06-19 09:39:14
21564	20168	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:57	2017-06-19 09:39:14
21565	20169	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:57	2017-06-19 09:39:14
21566	20170	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:57	2017-06-19 09:39:15
21567	20171	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:58	2017-06-19 09:39:15
21568	20172	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:58	2017-06-19 09:39:15
21569	20173	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:58	2017-06-19 09:39:15
21571	20175	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:58	2017-06-19 09:39:15
21572	20176	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:58	2017-06-19 09:39:15
21573	20177	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:58	2017-06-19 09:39:15
21574	20178	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:58	2017-06-19 09:39:15
21575	20179	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:58	2017-06-19 09:39:15
21576	20180	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:59	2017-06-19 09:39:15
21577	20181	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:59	2017-06-19 09:39:15
21578	20182	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:59	2017-06-29 03:44:42
21579	20183	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:59	2017-06-19 09:39:16
21580	20184	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:59	2017-06-19 09:39:16
21581	20185	VICPDTAN	2012-06-27 00:00:00	\N	2016-05-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:59	2017-06-29 03:44:42
21583	20187	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:59	2017-06-19 09:39:16
21584	20188	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:59	2017-06-19 09:39:16
21585	20189	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:59	2017-06-19 09:39:16
21586	20190	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:00	2017-06-19 09:39:16
21587	20191	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:00	2017-06-19 09:39:16
21588	20192	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:00	2017-06-19 09:39:16
21589	20193	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:00	2017-06-19 09:39:16
21590	20194	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:00	2017-06-19 09:39:16
21591	20195	DEPUTE	2012-06-20 00:00:00	\N	2014-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:00	2017-06-29 09:20:10
21592	20196	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:00	2017-06-19 09:39:17
21593	20197	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:00	2017-06-19 09:39:17
21594	20198	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:00	2017-06-19 09:39:17
21595	20199	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:00	2017-06-19 09:39:17
21596	20200	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:01	2017-06-19 09:39:17
21597	20201	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:01	2017-06-19 09:39:17
21598	20202	DEPUTE	2012-06-20 00:00:00	\N	2014-05-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:01	2017-06-15 10:51:56
21599	20203	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:01	2017-06-19 09:39:17
21600	20204	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:01	2017-06-19 09:39:17
21601	20205	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:01	2017-06-19 09:39:17
21602	20206	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:01	2017-06-19 09:39:17
21603	20207	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:01	2017-06-19 09:39:17
21604	20208	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:01	2017-06-19 09:39:17
21605	20209	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:02	2017-06-19 09:39:17
21606	20210	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:02	2017-06-19 09:39:18
21607	20211	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:02	2017-06-19 09:39:18
21608	20212	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:02	2017-06-19 09:39:18
21609	20213	DEPUTE	2012-06-20 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:02	2017-06-19 09:39:18
21610	20214	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:02	2017-06-19 09:39:18
21611	20215	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:02	2017-06-19 09:39:18
21612	20216	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:02	2017-06-19 09:39:18
21613	20217	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:02	2017-06-19 09:39:18
21614	20218	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:02	2017-06-19 09:39:18
21615	20219	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:03	2017-06-19 09:39:18
21616	20220	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:03	2017-06-19 09:39:18
21617	20221	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:03	2017-06-19 09:39:18
21618	20222	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:03	2017-06-19 09:39:18
21619	20223	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:03	2017-06-19 09:39:18
21620	20224	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:03	2017-06-19 09:39:18
21621	20225	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:03	2017-06-19 09:39:18
21622	20226	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:03	2017-06-19 09:39:18
21623	20227	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:03	2017-06-19 09:39:18
21624	20228	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:04	2017-06-19 09:39:19
21625	20229	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:04	2017-06-19 09:39:19
21626	20230	DEPUTE	2012-06-20 00:00:00	\N	2016-01-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:04	2017-06-29 03:44:44
21627	20231	DEPUTE	2012-06-26 00:00:00	\N	2016-01-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:04	2017-06-29 03:44:44
21628	20232	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:04	2017-06-19 09:39:19
21629	20233	DEPUTE	2015-07-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:04	2017-06-29 03:44:49
21630	20234	DEPUTE	2012-06-20 00:00:00	\N	2014-07-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:04	2017-06-29 03:44:49
21631	20235	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:04	2017-06-19 09:39:19
21633	20237	DEPUTE	2012-06-20 00:00:00	\N	2016-03-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:04	2017-06-15 10:51:58
21634	20238	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:04	2017-06-19 09:39:19
21635	20239	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:04	2017-06-19 09:39:19
21636	20240	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:04	2017-06-19 09:39:19
21637	20241	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:04	2017-06-19 09:39:19
21639	20243	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:05	2017-06-19 09:39:19
21640	20244	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:05	2017-06-19 09:39:19
21641	20245	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:05	2017-06-29 03:44:45
21642	20246	DEPUTE	2012-06-26 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:05	2017-06-29 03:44:45
21643	20247	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:05	2017-06-19 09:39:19
21644	20248	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:05	2017-06-19 09:39:19
21645	20249	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:05	2017-06-19 09:39:19
21646	20250	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:05	2017-06-19 09:39:19
21647	20251	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:05	2017-06-19 09:39:19
21648	20252	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:05	2017-06-19 09:39:19
21649	20253	DEPUTE	2012-06-20 00:00:00	\N	2014-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:05	2017-06-15 10:51:58
21650	20254	DEPUTE	2012-06-20 00:00:00	\N	2012-06-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:05	2017-06-15 10:51:58
21651	20255	DEPUTE	2012-06-20 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:05	2017-06-19 09:39:20
21652	20256	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:05	2017-06-19 09:39:20
21653	20257	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:05	2017-06-19 09:39:20
21654	20258	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:05	2017-06-19 09:39:20
21655	20259	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:05	2017-06-19 09:39:20
21656	20260	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:05	2017-06-29 09:20:13
21657	20261	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:05	2017-06-29 09:20:13
29243	27840	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:55	\N
21658	20262	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:06	2017-06-29 09:20:13
21659	20263	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:06	2017-06-19 09:39:20
21660	20264	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:06	2017-06-19 09:39:20
21661	20265	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:06	2017-06-19 09:39:20
21662	20266	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:06	2017-06-19 09:39:20
21663	20267	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:06	2017-06-19 09:39:20
21664	20268	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:06	2017-06-19 09:39:20
21665	20269	DEPUTE	2012-06-20 00:00:00	\N	2016-03-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:06	2017-06-15 10:51:59
21666	20270	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:06	2017-06-19 09:39:20
21667	20271	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:06	2017-06-19 09:39:20
21668	20272	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:06	2017-06-19 09:39:20
21670	20274	DEPUTE	2012-06-26 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:06	2017-06-29 09:20:13
21671	20275	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:06	2017-06-19 09:39:20
21672	20276	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:06	2017-06-19 09:39:21
21673	20277	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:07	2017-06-19 09:39:21
21674	20278	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:07	2017-06-19 09:39:21
21675	20279	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:07	2017-06-19 09:39:21
21676	20280	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:07	2017-06-19 09:39:21
21677	20281	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:07	2017-06-19 09:39:21
21678	20282	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:07	2017-06-19 09:39:21
21679	20283	SECAN	2012-06-27 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:07	2017-06-29 09:20:31
21680	20284	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:07	2017-06-29 03:45:12
21682	20286	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:07	2017-06-29 09:20:31
21683	20287	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:07	2017-06-19 09:39:21
21684	20288	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:07	2017-06-19 09:39:21
21685	20289	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:07	2017-06-19 09:39:21
21686	20290	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:07	2017-06-19 09:39:21
21687	20291	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:07	2017-06-19 09:39:21
27005	25602	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:47	\N
27006	25603	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:47	\N
27007	25604	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:47	\N
27008	25605	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:47	\N
27009	25606	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:47	\N
27010	25607	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:47	\N
27011	25608	DEPUTE	1993-05-02 00:00:00	\N	1995-07-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:47	\N
27012	25609	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:47	\N
27013	25610	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:47	\N
27014	25611	DEPUTE	2007-07-20 00:00:00	\N	2011-03-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:47	\N
27015	25612	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:47	\N
27016	25613	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:47	\N
27017	25614	DEPUTE	1986-10-09 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:47	\N
27018	25615	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:47	\N
27019	25616	DEPUTE	2004-05-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:47	\N
27020	25617	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:47	\N
27021	25618	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:47	\N
27022	25619	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:47	\N
27023	25620	DEPUTE	1961-09-26 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:47	\N
27024	25621	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:47	\N
27025	25622	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:47	\N
27026	25623	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:47	\N
27027	25624	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:47	\N
27028	25625	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:47	\N
27029	25626	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:47	\N
27030	25627	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:47	\N
27031	25628	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:47	\N
27032	25629	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:47	\N
27033	25630	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:47	\N
27034	25631	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:47	\N
27035	25632	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:47	\N
27036	25633	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:48	\N
27037	25634	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:48	\N
27038	25635	DEPUTE	1978-05-07 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:48	\N
27039	25636	DEPUTE	1977-05-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:48	\N
27040	25637	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:48	\N
27041	25638	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:48	\N
27042	25639	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:48	\N
27043	25640	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:48	\N
27044	25641	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:48	\N
27045	25642	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:48	\N
27046	25643	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:48	\N
27047	25644	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:48	\N
27048	25645	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:48	\N
27049	25646	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:48	\N
27050	25647	SECAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:48	\N
27051	25648	SECAN	2002-06-26 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:48	\N
27052	25649	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:48	\N
27053	25650	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:48	\N
27054	25651	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:48	\N
27055	25652	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:48	\N
27056	25653	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:48	\N
27057	25654	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:48	\N
27058	25655	DEPUTE	2001-09-25 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:48	\N
27059	25656	DEPUTE	1973-04-02 00:00:00	\N	1976-11-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:48	\N
27060	25657	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:48	\N
27061	25658	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:48	\N
27062	25659	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:48	\N
27063	25660	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:48	\N
27064	25661	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:48	\N
27065	25662	SECAN	2002-06-26 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:48	\N
27066	25663	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:48	\N
27067	25664	DEPUTE	1981-07-24 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:49	\N
27068	25665	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:49	\N
27069	25666	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:49	\N
27070	25667	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:49	\N
27071	25668	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:49	\N
27072	25669	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:49	\N
27073	25670	DEPUTE	1981-07-02 00:00:00	\N	1983-11-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:49	\N
27074	25671	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:49	\N
27075	25672	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:49	\N
27076	25673	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:49	\N
27077	25674	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:49	\N
27078	25675	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:49	\N
27079	25676	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:49	\N
27080	25677	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:49	\N
27081	25678	DEPUTE	1986-04-02 00:00:00	\N	1986-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:49	\N
27082	25679	DEPUTE	1973-05-06 00:00:00	\N	1974-07-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:49	\N
27083	25680	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:49	\N
27084	25681	DEPUTE	2001-10-04 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:49	\N
27085	25682	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:49	\N
27086	25683	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:49	\N
27087	25684	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:49	\N
27088	25685	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:49	\N
27089	25686	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:49	\N
27090	25687	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:49	\N
27091	25688	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:49	\N
27092	25689	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:49	\N
27093	25690	DEPUTE	1993-04-02 00:00:00	\N	1993-11-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:49	\N
27094	25691	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:49	\N
27095	25692	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:49	\N
27096	25693	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:50	\N
27097	25694	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:50	\N
22729	21326	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:47	\N
22730	21327	DEPUTE	1991-06-18 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:47	\N
22731	21328	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:47	\N
22732	21329	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:47	\N
22733	21330	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:47	\N
22734	21331	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:47	\N
22735	21332	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:47	\N
22736	21333	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:47	\N
22737	21334	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:47	\N
22738	21335	DEPUTE	1995-09-17 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:47	\N
22739	21336	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:47	\N
22740	21337	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:47	\N
22741	21338	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:47	\N
22742	21339	DEPUTE	2011-03-28 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:47	\N
22743	21340	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:47	\N
22744	21341	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:47	\N
22745	21342	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:47	\N
22746	21343	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:47	\N
22747	21344	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:47	\N
22748	21345	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:47	\N
22749	21346	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:47	\N
22750	21347	DEPUTE	1985-05-23 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:47	\N
22751	21348	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:47	\N
22752	21349	DEPUTE	1991-03-09 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:47	\N
22753	21350	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:47	\N
22754	21351	DEPUTE	1995-12-17 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:47	\N
22755	21352	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:47	\N
22756	21353	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:47	\N
22757	21354	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:47	\N
22758	21355	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:47	\N
22759	21356	DEPUTE	2004-05-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:47	\N
22760	21357	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:48	\N
22761	21358	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:48	\N
22762	21359	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:48	\N
22763	21360	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:48	\N
22764	21361	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:48	\N
22765	21362	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:48	\N
22766	21363	DEPUTE	1983-02-08 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:48	\N
22767	21364	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:48	\N
22768	21365	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:48	\N
22769	21366	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:48	\N
22770	21367	DEPUTE	1997-05-25 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:48	\N
22771	21368	DEPUTE	2002-06-19 00:00:00	\N	2006-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:48	\N
22772	21369	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:48	\N
22773	21370	SECAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:48	\N
22774	21371	SECAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:48	\N
22775	21372	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:48	\N
22776	21373	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:48	\N
22777	21374	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:48	\N
22778	21375	SECAN	2004-05-24 00:00:00	\N	2005-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:48	\N
22779	21376	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:48	\N
22780	21377	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:48	\N
22781	21378	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:48	\N
22782	21379	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:48	\N
22783	21380	DEPUTE	2012-06-20 00:00:00	\N	2016-12-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:48	\N
22784	21381	DEPUTE	1995-01-22 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:48	\N
22785	21382	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:48	\N
22786	21383	DEPUTE	1991-06-17 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:48	\N
22787	21384	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:48	\N
22788	21385	DEPUTE	1997-06-01 00:00:00	\N	2001-11-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:48	\N
22789	21386	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:48	\N
22790	21387	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:48	\N
22791	21388	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:48	\N
22792	21389	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:48	\N
22793	21390	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:49	\N
22794	21391	DEPUTE	1988-06-13 00:00:00	\N	1990-09-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:49	\N
22795	21392	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:49	\N
22796	21393	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:49	\N
22797	21394	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:49	\N
22798	21395	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:49	\N
22799	21396	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:49	\N
22800	21397	DEPUTE	1973-04-02 00:00:00	\N	1974-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:49	\N
22801	21398	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:49	\N
22802	21399	DEPUTE	1986-04-02 00:00:00	\N	1987-05-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:49	\N
22803	21400	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:49	\N
22804	21401	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:49	\N
22805	21402	DEPUTE	2001-08-11 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:49	\N
22806	21403	DEPUTE	1992-06-23 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:49	\N
22807	21404	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:49	\N
22808	21405	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:49	\N
22809	21406	DEPUTE	1986-04-02 00:00:00	\N	1986-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:49	\N
22810	21407	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:49	\N
22811	21408	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:49	\N
22812	21409	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:49	\N
22813	21410	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:49	\N
22814	21411	DEPUTE	1981-01-27 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:49	\N
22815	21412	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:49	\N
22816	21413	DEPUTE	1988-06-13 00:00:00	\N	1988-11-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:49	\N
22817	21414	DEPUTE	1989-02-01 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:49	\N
22818	21415	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:49	\N
22819	21416	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:49	\N
22820	21417	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:50	\N
22821	21418	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:50	\N
24217	22814	DEPUTE	1967-04-03 00:00:00	\N	1967-05-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:28	\N
24218	22815	DEPUTE	1968-07-11 00:00:00	\N	1968-08-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:28	\N
24219	22816	DEPUTE	1973-04-02 00:00:00	\N	1973-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:28	\N
24220	22817	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:28	\N
24221	22818	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:28	\N
24222	22819	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:28	\N
24223	22820	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:28	\N
24224	22821	DEPUTE	1986-09-20 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:28	\N
24225	22822	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:28	\N
24226	22823	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:28	\N
24227	22824	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:28	\N
24228	22825	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:28	\N
24229	22826	DEPUTE	1981-07-02 00:00:00	\N	1983-07-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:28	\N
24230	22827	DEPUTE	1988-07-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:28	\N
24231	22828	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:28	\N
24232	22829	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:28	\N
24233	22830	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:28	\N
24234	22831	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:28	\N
24235	22832	VICPDTAN	2010-10-05 00:00:00	\N	2011-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:28	\N
24236	22833	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:29	\N
24237	22834	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:29	\N
24238	22835	DEPUTE	1997-06-01 00:00:00	\N	1997-10-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:29	\N
24239	22836	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:29	\N
24240	22837	DEPUTE	1997-12-15 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:29	\N
24241	22838	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:29	\N
24242	22839	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:29	\N
24243	22840	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:29	\N
24244	22841	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:29	\N
24245	22842	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:29	\N
24246	22843	DEPUTE	1997-06-01 00:00:00	\N	2001-04-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:29	\N
24247	22844	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:29	\N
24248	22845	VICPDTAN	2002-06-26 00:00:00	\N	2003-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:29	\N
24249	22846	VICPDTAN	2004-10-01 00:00:00	\N	2005-12-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:29	\N
24250	22847	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:29	\N
24251	22848	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:29	\N
24252	22849	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:29	\N
24253	22850	DEPUTE	1988-06-13 00:00:00	\N	1991-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:29	\N
24254	22851	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:29	\N
24255	22852	DEPUTE	1985-12-28 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:29	\N
24256	22853	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:29	\N
24257	22854	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:29	\N
24258	22855	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:29	\N
24259	22856	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:29	\N
24260	22857	VICPDTAN	2015-01-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:29	\N
24261	22858	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:29	\N
24262	22859	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:29	\N
24263	22860	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:29	\N
24264	22861	DEPUTE	1986-04-02 00:00:00	\N	1988-05-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:29	\N
24265	22862	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:29	\N
24266	22863	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:29	\N
24267	22864	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:29	\N
24268	22865	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:30	\N
24269	22866	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:30	\N
24270	22867	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:30	\N
24271	22868	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:30	\N
24272	22869	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:30	\N
24273	22870	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:30	\N
24274	22871	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:30	\N
24275	22872	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:30	\N
24276	22873	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:30	\N
24277	22874	SECAN	1987-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:30	\N
24278	22875	VICPDTAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:30	\N
24279	22876	VICPDTAN	1994-04-02 00:00:00	\N	1995-04-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:30	\N
24280	22877	SECAN	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:30	\N
24281	22878	DEPUTE	1981-07-02 00:00:00	\N	1984-09-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:30	\N
24282	22879	DEPUTE	1986-09-30 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:30	\N
24283	22880	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:30	\N
24284	22881	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:30	\N
24285	22882	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:30	\N
24286	22883	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:30	\N
24287	22884	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:30	\N
24288	22885	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:30	\N
24289	22886	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:30	\N
24290	22887	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:30	\N
24291	22888	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:30	\N
24292	22889	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:30	\N
24293	22890	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:30	\N
24294	22891	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:30	\N
24295	22892	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:30	\N
24296	22893	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:30	\N
24297	22894	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:30	\N
24298	22895	DEPUTE	1977-03-04 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:30	\N
24299	22896	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:30	\N
24300	22897	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:30	\N
24301	22898	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:30	\N
24302	22899	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:31	\N
24303	22900	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:31	\N
24304	22901	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:31	\N
24305	22902	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:31	\N
24306	22903	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:31	\N
24307	22904	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:31	\N
24308	22905	DEPUTE	1997-06-01 00:00:00	\N	2000-04-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:31	\N
24309	22906	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:31	\N
25610	24207	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:07	\N
25611	24208	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:07	\N
25612	24209	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:07	\N
25613	24210	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:07	\N
25614	24211	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:07	\N
25615	24212	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:07	\N
25616	24213	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:08	\N
25617	24214	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:08	\N
25618	24215	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:08	\N
25619	24216	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:08	\N
25620	24217	DEPUTE	1978-04-02 00:00:00	\N	1980-10-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:08	\N
25621	24218	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:08	\N
25622	24219	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:08	\N
25623	24220	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:08	\N
25624	24221	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:08	\N
25625	24222	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:08	\N
25626	24223	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:08	\N
25627	24224	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:08	\N
25628	24225	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:08	\N
25629	24226	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:08	\N
25630	24227	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:08	\N
25631	24228	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:08	\N
25632	24229	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:08	\N
25633	24230	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:08	\N
25634	24231	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:08	\N
25635	24232	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:08	\N
25636	24233	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:08	\N
25637	24234	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:08	\N
25638	24235	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:08	\N
25639	24236	QUESTAN	1995-04-03 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:08	\N
25640	24237	SECAN	2002-06-26 00:00:00	\N	2004-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:09	\N
25641	24238	SECAN	2008-10-01 00:00:00	\N	2009-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:09	\N
25642	24239	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:09	\N
25643	24240	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:09	\N
25644	24241	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:09	\N
25645	24242	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:09	\N
25646	24243	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:09	\N
25647	24244	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:09	\N
25648	24245	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:09	\N
25649	24246	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:09	\N
25650	24247	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:09	\N
25651	24248	DEPUTE	1997-06-01 00:00:00	\N	2001-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:09	\N
25652	24249	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:09	\N
25653	24250	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:09	\N
25654	24251	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:09	\N
25655	24252	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:09	\N
25656	24253	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:09	\N
25657	24254	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:09	\N
25658	24255	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:09	\N
25659	24256	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:09	\N
25660	24257	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:09	\N
25661	24258	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:09	\N
25662	24259	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:09	\N
25663	24260	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:09	\N
25664	24261	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:10	\N
25665	24262	VICPDTAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:10	\N
25666	24263	VICPDTAN	1988-06-24 00:00:00	\N	1992-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:10	\N
25667	24264	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:10	\N
25668	24265	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:10	\N
25669	24266	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:10	\N
25670	24267	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:10	\N
25671	24268	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:10	\N
25672	24269	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:10	\N
25673	24270	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:10	\N
25674	24271	DEPUTE	1988-06-13 00:00:00	\N	1992-04-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:10	\N
25675	24272	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:10	\N
25676	24273	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:10	\N
25677	24274	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:10	\N
25678	24275	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:10	\N
25679	24276	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:10	\N
25680	24277	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:10	\N
25681	24278	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:10	\N
25682	24279	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:10	\N
25683	24280	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:10	\N
25684	24281	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:10	\N
25685	24282	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:10	\N
25686	24283	DEPUTE	2007-06-20 00:00:00	\N	2011-07-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:10	\N
25687	24284	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:10	\N
25688	24285	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:10	\N
25689	24286	SECAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:10	\N
25690	24287	SECAN	1995-05-31 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:10	\N
25691	24288	VICPDTAN	2007-06-27 00:00:00	\N	2011-07-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:10	\N
25692	24289	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:10	\N
25693	24290	DEPUTE	1981-07-02 00:00:00	\N	1982-07-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:10	\N
25694	24291	DEPUTE	1982-09-05 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:10	\N
25695	24292	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:10	\N
25696	24293	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:10	\N
25697	24294	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:10	\N
25698	24295	DEPUTE	1997-05-25 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:10	\N
25699	24296	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:10	\N
25700	24297	DEPUTE	1976-02-13 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:10	\N
25701	24298	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:10	\N
25702	24299	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:10	\N
27098	25695	DEPUTE	1984-09-10 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:50	\N
27099	25696	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:50	\N
27100	25697	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:50	\N
27101	25698	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:50	\N
27102	25699	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:50	\N
27103	25700	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:50	\N
27104	25701	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:50	\N
27105	25702	DEPUTE	2007-06-20 00:00:00	\N	2011-12-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:50	\N
27106	25703	DEPUTE	2000-11-19 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:50	\N
27107	25704	DEPUTE	1991-06-18 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:50	\N
27108	25705	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:50	\N
27109	25706	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:50	\N
27110	25707	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:50	\N
27111	25708	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:50	\N
27112	25709	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:50	\N
27113	25710	SECAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:50	\N
27114	25711	VICPDTAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:50	\N
27115	25712	VICPDTAN	1994-04-02 00:00:00	\N	1995-06-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:50	\N
27116	25713	VICPDTAN	1997-06-13 00:00:00	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:50	\N
27117	25714	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:50	\N
27118	25715	DEPUTE	1998-11-21 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:50	\N
27119	25716	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:50	\N
27120	25717	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:50	\N
27121	25718	DEPUTE	1969-10-26 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:51	\N
27122	25719	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:51	\N
27123	25720	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:51	\N
27124	25721	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:51	\N
27125	25722	DEPUTE	1988-06-13 00:00:00	\N	1988-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:51	\N
27126	25723	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:51	\N
27127	25724	DEPUTE	1962-12-06 00:00:00	\N	1963-03-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:51	\N
27128	25725	DEPUTE	1963-05-12 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:51	\N
27129	25726	DEPUTE	1967-04-03 00:00:00	\N	1967-07-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:51	\N
27130	25727	DEPUTE	1967-08-27 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:51	\N
27131	25728	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:51	\N
27132	25729	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:51	\N
27133	25730	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:51	\N
27134	25731	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:51	\N
27135	25732	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:51	\N
27136	25733	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:51	\N
27137	25734	DEPUTE	1997-06-01 00:00:00	\N	1998-04-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:51	\N
27138	25735	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:51	\N
27139	25736	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:51	\N
27140	25737	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:51	\N
27141	25738	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:51	\N
27142	25739	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:51	\N
27143	25740	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:51	\N
27144	25741	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:51	\N
27145	25742	SECAN	2002-06-26 00:00:00	\N	2006-11-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:51	\N
27146	25743	SECAN	2013-10-01 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:51	\N
27147	25744	DEPUTE	1984-04-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:51	\N
27148	25745	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:51	\N
27149	25746	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:51	\N
27150	25747	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:51	\N
27151	25748	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:51	\N
27152	25749	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:52	\N
27153	25750	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:52	\N
27154	25751	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:52	\N
27155	25752	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:52	\N
27156	25753	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:52	\N
27157	25754	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:52	\N
27158	25755	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:52	\N
27159	25756	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:52	\N
27160	25757	DEPUTE	1981-07-24 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:52	\N
27161	25758	DEPUTE	1986-04-02 00:00:00	\N	1986-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:52	\N
27162	25759	DEPUTE	1986-10-01 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:52	\N
27163	25760	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:52	\N
27164	25761	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:52	\N
27165	25762	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:52	\N
27166	25763	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:52	\N
27167	25764	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:52	\N
27168	25765	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:52	\N
27169	25766	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:52	\N
27170	25767	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:52	\N
27171	25768	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:52	\N
27172	25769	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:52	\N
27173	25770	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:52	\N
27174	25771	DEPUTE	2012-06-20 00:00:00	\N	2016-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:52	\N
27175	25772	QUESTAN	2012-06-27 00:00:00	\N	2016-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:52	\N
27176	25773	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:53	\N
27177	25774	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:53	\N
27178	25775	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:53	\N
27179	25776	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:53	\N
27180	25777	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:53	\N
27181	25778	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:53	\N
27182	25779	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:53	\N
27183	25780	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:53	\N
27184	25781	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:53	\N
27185	25782	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:53	\N
27186	25783	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:53	\N
27187	25784	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:53	\N
27188	25785	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:53	\N
27189	25786	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:53	\N
27190	25787	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:53	\N
22822	21419	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:50	\N
22823	21420	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:50	\N
22824	21421	DEPUTE	1995-10-18 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:50	\N
22825	21422	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:50	\N
22826	21423	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:50	\N
22827	21424	DEPUTE	1997-06-01 00:00:00	\N	1998-08-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:50	\N
22828	21425	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:50	\N
22829	21426	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:50	\N
22830	21427	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:50	\N
22831	21428	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:50	\N
22832	21429	DEPUTE	2002-06-19 00:00:00	\N	2007-03-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:50	\N
22833	21430	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:50	\N
22834	21431	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:50	\N
22835	21432	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:50	\N
22836	21433	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:50	\N
22837	21434	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:50	\N
22838	21435	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:50	\N
22839	21436	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:50	\N
22840	21437	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:50	\N
22841	21438	VICPDTAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:50	\N
22842	21439	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:50	\N
22843	21440	VICPDTAN	2001-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:50	\N
22844	21441	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:50	\N
22845	21442	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:50	\N
22846	21443	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:50	\N
22847	21444	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:50	\N
22848	21445	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:50	\N
22849	21446	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:50	\N
22850	21447	DEPUTE	1993-04-02 00:00:00	\N	1995-06-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:50	\N
22851	21448	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:50	\N
22852	21449	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:50	\N
22853	21450	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:50	\N
22854	21451	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:50	\N
22855	21452	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:50	\N
22856	21453	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:50	\N
22857	21454	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:50	\N
22858	21455	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:50	\N
22859	21456	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:50	\N
22860	21457	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:50	\N
22861	21458	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:50	\N
22862	21459	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22863	21460	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22864	21461	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22865	21462	DEPUTE	1986-04-02 00:00:00	\N	1986-04-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22866	21463	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22867	21464	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22868	21465	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22869	21466	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22870	21467	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22871	21468	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22872	21469	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22873	21470	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22874	21471	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22875	21472	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22876	21473	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22877	21474	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22878	21475	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22879	21476	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22880	21477	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22881	21478	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22882	21479	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22883	21480	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22884	21481	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22885	21482	DEPUTE	1978-10-01 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22886	21483	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22887	21484	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22888	21485	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22889	21486	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22890	21487	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22891	21488	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22892	21489	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22893	21490	DEPUTE	2007-06-20 00:00:00	\N	2012-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22894	21491	DEPUTE	2012-06-20 00:00:00	\N	2012-07-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22895	21492	DEPUTE	2014-05-01 00:00:00	\N	2016-03-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22896	21493	DEPUTE	1983-02-28 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22897	21494	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22898	21495	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22899	21496	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22900	21497	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22901	21498	SECAN	1987-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22902	21499	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22903	21500	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22904	21501	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22905	21502	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22906	21503	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22907	21504	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22908	21505	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22909	21506	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22910	21507	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22911	21508	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22912	21509	SECAN	2007-06-27 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22913	21510	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22914	21511	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
24310	22907	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:31	\N
24311	22908	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:31	\N
24312	22909	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:31	\N
24313	22910	DEPUTE	1998-10-01 00:00:00	\N	2000-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:31	\N
24314	22911	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:31	\N
24315	22912	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:31	\N
24316	22913	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:31	\N
24317	22914	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:31	\N
24318	22915	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:31	\N
24319	22916	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:31	\N
24320	22917	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:31	\N
24321	22918	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:31	\N
24322	22919	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:31	\N
24323	22920	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:31	\N
24324	22921	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:31	\N
24325	22922	DEPUTE	1993-05-02 00:00:00	\N	1995-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:31	\N
24326	22923	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:31	\N
24327	22924	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:31	\N
24328	22925	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:31	\N
24329	22926	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:31	\N
24330	22927	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:31	\N
24331	22928	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:31	\N
24332	22929	DEPUTE	1997-06-01 00:00:00	\N	2001-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:31	\N
24333	22930	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:32	\N
24334	22931	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:32	\N
24335	22932	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:32	\N
24336	22933	DEPUTE	1988-06-13 00:00:00	\N	1990-01-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:32	\N
24337	22934	DEPUTE	1996-02-26 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:32	\N
24338	22935	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:32	\N
24339	22936	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:32	\N
24340	22937	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:32	\N
24341	22938	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:32	\N
24342	22939	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:32	\N
24343	22940	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:32	\N
24344	22941	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:32	\N
24345	22942	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:32	\N
24346	22943	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:32	\N
24347	22944	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:32	\N
24348	22945	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:32	\N
24349	22946	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:32	\N
24350	22947	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:32	\N
24351	22948	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:32	\N
24352	22949	DEPUTE	1991-06-18 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:32	\N
24353	22950	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:32	\N
24354	22951	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:32	\N
24355	22952	DEPUTE	1987-10-14 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:32	\N
24356	22953	DEPUTE	1996-09-15 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:32	\N
24357	22954	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:32	\N
24358	22955	DEPUTE	1986-04-02 00:00:00	\N	1987-10-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:32	\N
24359	22956	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:32	\N
24360	22957	DEPUTE	1997-05-25 00:00:00	\N	2001-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:32	\N
24361	22958	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:32	\N
24362	22959	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:32	\N
24363	22960	DEPUTE	2002-06-19 00:00:00	\N	2003-02-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:32	\N
24364	22961	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24365	22962	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24366	22963	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24367	22964	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24368	22965	DEPUTE	2007-06-20 00:00:00	\N	2012-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24369	22966	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24370	22967	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24371	22968	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24372	22969	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24373	22970	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24374	22971	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24375	22972	DEPUTE	2004-05-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24376	22973	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24377	22974	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24378	22975	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24379	22976	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24380	22977	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24381	22978	VICPDTAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24382	22979	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24383	22980	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24384	22981	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24385	22982	DEPUTE	1993-05-02 00:00:00	\N	1995-06-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24386	22983	DEPUTE	1995-07-17 00:00:00	\N	1995-08-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24387	22984	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24388	22985	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24389	22986	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24390	22987	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24391	22988	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24392	22989	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24393	22990	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24394	22991	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24395	22992	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24396	22993	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24397	22994	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24398	22995	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24399	22996	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24400	22997	QUESTAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24401	22998	SECAN	1992-04-02 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24402	22999	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
25703	24300	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:10	\N
25704	24301	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:10	\N
25705	24302	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:10	\N
25706	24303	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:10	\N
25707	24304	DEPUTE	1997-06-12 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:10	\N
25708	24305	DEPUTE	1973-04-02 00:00:00	\N	1977-06-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:10	\N
25709	24306	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25710	24307	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25711	24308	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25712	24309	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25713	24310	DEPUTE	1993-04-02 00:00:00	\N	1993-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25714	24311	DEPUTE	1993-09-20 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25715	24312	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25716	24313	DEPUTE	2000-02-07 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25717	24314	DEPUTE	1997-06-01 00:00:00	\N	1997-12-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25718	24315	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25719	24316	DEPUTE	2012-06-20 00:00:00	\N	2017-03-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25720	24317	PDTAN	1992-01-22 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25721	24318	DEPUTE	1993-05-02 00:00:00	\N	1995-05-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25722	24319	DEPUTE	1981-07-02 00:00:00	\N	1986-02-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25723	24320	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25724	24321	DEPUTE	1983-04-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25725	24322	DEPUTE	1998-05-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25726	24323	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25727	24324	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25728	24325	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25729	24326	DEPUTE	1993-04-02 00:00:00	\N	1993-12-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25730	24327	DEPUTE	2002-06-19 00:00:00	\N	2005-07-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25731	24328	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25732	24329	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25733	24330	DEPUTE	2008-05-26 00:00:00	\N	2009-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25734	24331	DEPUTE	2010-12-14 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25735	24332	DEPUTE	2012-06-20 00:00:00	\N	2016-03-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25736	24333	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25737	24334	DEPUTE	1997-06-01 00:00:00	\N	2001-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25738	24335	DEPUTE	1999-12-10 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25739	24336	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25740	24337	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25741	24338	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25742	24339	DEPUTE	1991-09-26 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25743	24340	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25744	24341	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25745	24342	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25746	24343	VICPDTAN	1986-04-04 00:00:00	\N	1987-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25747	24344	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25748	24345	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25749	24346	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25750	24347	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25751	24348	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25752	24349	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25753	24350	DEPUTE	1997-06-01 00:00:00	\N	2000-04-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25754	24351	DEPUTE	2007-06-20 00:00:00	\N	2012-06-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25755	24352	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25756	24353	PDTAN	1988-06-23 00:00:00	\N	1992-01-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25757	24354	PDTAN	1997-06-12 00:00:00	\N	2000-03-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25758	24355	DEPUTE	1978-04-02 00:00:00	\N	1980-11-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25759	24356	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25760	24357	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25761	24358	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25762	24359	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25763	24360	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25764	24361	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25765	24362	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25766	24363	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25767	24364	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25768	24365	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25769	24366	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25770	24367	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25771	24368	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25772	24369	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:11	\N
25773	24370	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25774	24371	DEPUTE	1993-04-02 00:00:00	\N	1995-09-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25775	24372	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25776	24373	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25777	24374	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25778	24375	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25779	24376	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25780	24377	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25781	24378	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25782	24379	DEPUTE	1968-07-11 00:00:00	\N	1969-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25783	24380	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25784	24381	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25785	24382	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25786	24383	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25787	24384	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25788	24385	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25789	24386	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25790	24387	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25791	24388	DEPUTE	1978-04-02 00:00:00	\N	1980-09-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25792	24389	DEPUTE	1981-07-02 00:00:00	\N	1983-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25793	24390	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25794	24391	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25795	24392	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
27191	25788	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:53	\N
27192	25789	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:53	\N
27193	25790	SECAN	2002-10-02 00:00:00	\N	2004-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:53	\N
27194	25791	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:53	\N
27195	25792	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:53	\N
27196	25793	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:53	\N
27197	25794	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:53	\N
27198	25795	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:53	\N
27199	25796	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:53	\N
27200	25797	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:53	\N
27201	25798	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:53	\N
27202	25799	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:53	\N
27203	25800	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:53	\N
27204	25801	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:53	\N
27205	25802	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:53	\N
27206	25803	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:53	\N
27207	25804	DEPUTE	1997-06-01 00:00:00	\N	1999-03-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:53	\N
27208	25805	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:53	\N
27209	25806	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:53	\N
27210	25807	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:53	\N
27211	25808	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:53	\N
27212	25809	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:53	\N
27213	25810	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27214	25811	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27215	25812	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27216	25813	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27217	25814	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27218	25815	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27219	25816	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27220	25817	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27221	25818	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27222	25819	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27223	25820	SECAN	2008-10-01 00:00:00	\N	2009-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27224	25821	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27225	25822	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27226	25823	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27227	25824	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27228	25825	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27229	25826	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27230	25827	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27231	25828	DEPUTE	1993-04-02 00:00:00	\N	1996-11-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27232	25829	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27233	25830	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27234	25831	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27235	25832	DEPUTE	2007-06-20 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27236	25833	VICPDTAN	2008-10-01 00:00:00	\N	2009-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27237	25834	SECAN	2007-06-27 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27238	25835	SECAN	2009-10-06 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27239	25836	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27240	25837	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27241	25838	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27242	25839	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27243	25840	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27244	25841	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27245	25842	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27246	25843	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27247	25844	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27248	25845	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27249	25846	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27250	25847	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27251	25848	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27252	25849	SECAN	2002-06-26 00:00:00	\N	2003-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27253	25850	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27254	25851	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27255	25852	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27256	25853	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27257	25854	DEPUTE	1991-02-05 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27258	25855	DEPUTE	1993-04-02 00:00:00	\N	1997-02-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27259	25856	DEPUTE	1988-06-13 00:00:00	\N	1990-12-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27260	25857	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27261	25858	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27262	25859	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27263	25860	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27264	25861	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27265	25862	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27266	25863	DEPUTE	1986-04-02 00:00:00	\N	1987-05-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27267	25864	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27268	25865	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27269	25866	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27270	25867	DEPUTE	2010-12-14 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27271	25868	DEPUTE	1981-07-02 00:00:00	\N	1982-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27272	25869	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27273	25870	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27274	25871	DEPUTE	1998-11-30 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27275	25872	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27276	25873	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27277	25874	DEPUTE	1962-12-06 00:00:00	\N	1966-02-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27278	25875	DEPUTE	1967-04-03 00:00:00	\N	1967-05-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27279	25876	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27280	25877	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27281	25878	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27282	25879	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27283	25880	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
22915	21512	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22916	21513	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22917	21514	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22918	21515	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22919	21516	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22920	21517	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:51	\N
22921	21518	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22922	21519	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22923	21520	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22924	21521	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22925	21522	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22926	21523	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22927	21524	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22928	21525	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22929	21526	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22930	21527	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22931	21528	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22932	21529	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22933	21530	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22934	21531	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22935	21532	DEPUTE	1995-09-24 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22936	21533	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22937	21534	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22938	21535	DEPUTE	1978-04-02 00:00:00	\N	1981-01-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22939	21536	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22940	21537	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22941	21538	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22942	21539	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22943	21540	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22944	21541	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22945	21542	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22946	21543	SECAN	1986-04-04 00:00:00	\N	1987-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22947	21544	VICPDTAN	2010-10-05 00:00:00	\N	2011-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22948	21545	SECAN	2011-10-03 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22949	21546	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22950	21547	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22951	21548	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22952	21549	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22953	21550	DEPUTE	1986-04-02 00:00:00	\N	1986-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22954	21551	DEPUTE	1986-09-29 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22955	21552	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22956	21553	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22957	21554	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22958	21555	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22959	21556	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22960	21557	DEPUTE	1983-07-27 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22961	21558	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22962	21559	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22963	21560	DEPUTE	1989-06-26 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22964	21561	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22965	21562	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22966	21563	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22967	21564	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22968	21565	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22969	21566	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22970	21567	DEPUTE	1986-09-30 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22971	21568	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22972	21569	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:52	\N
22973	21570	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
22974	21571	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
22975	21572	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
22976	21573	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
22977	21574	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
22978	21575	DEPUTE	1994-03-13 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
22979	21576	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
22980	21577	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
22981	21578	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
22982	21579	VICPDTAN	1995-05-31 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
22983	21580	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
22984	21581	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
22985	21582	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
22986	21583	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
22987	21584	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
22988	21585	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
22989	21586	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
22990	21587	DEPUTE	2002-06-19 00:00:00	\N	2005-07-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
22991	21588	DEPUTE	2007-06-20 00:00:00	\N	2010-04-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
22992	21589	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
22993	21590	DEPUTE	2012-06-20 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
22994	21591	DEPUTE	1993-04-02 00:00:00	\N	1995-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
22995	21592	DEPUTE	1997-06-12 00:00:00	\N	1999-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
22996	21593	VICPDTAN	2003-10-01 00:00:00	\N	2005-07-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
22997	21594	VICPDTAN	2002-06-26 00:00:00	\N	2003-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
22998	21595	DEPUTE	1993-09-03 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
22999	21596	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
23000	21597	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
23001	21598	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
23002	21599	DEPUTE	1978-04-03 00:00:00	\N	1978-05-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
23003	21600	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
23004	21601	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
23005	21602	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
23006	21603	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
23007	21604	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
24403	23000	DEPUTE	1980-10-20 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24404	23001	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24405	23002	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24406	23003	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24407	23004	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24408	23005	SECAN	1997-06-13 00:00:00	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24409	23006	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24410	23007	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24411	23008	DEPUTE	2007-06-20 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24412	23009	VICPDTAN	2007-06-27 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24413	23010	DEPUTE	1995-12-08 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24414	23011	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24415	23012	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:33	\N
24416	23013	DEPUTE	1973-04-02 00:00:00	\N	1975-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24417	23014	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24418	23015	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24419	23016	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24420	23017	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24421	23018	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24422	23019	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24423	23020	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24424	23021	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24425	23022	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24426	23023	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24427	23024	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24428	23025	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24429	23026	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24430	23027	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24431	23028	SECAN	2008-10-01 00:00:00	\N	2010-10-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24432	23029	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24433	23030	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24434	23031	DEPUTE	2000-03-20 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24435	23032	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24436	23033	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24437	23034	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24438	23035	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24439	23036	DEPUTE	1997-06-01 00:00:00	\N	1999-08-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24440	23037	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24441	23038	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24442	23039	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24443	23040	DEPUTE	1983-04-23 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24444	23041	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24445	23042	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24446	23043	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24447	23044	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24448	23045	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24449	23046	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24450	23047	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24451	23048	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24452	23049	DEPUTE	2002-06-19 00:00:00	\N	2004-03-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24453	23050	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24454	23051	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24455	23052	DEPUTE	1995-06-25 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24456	23053	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24457	23054	DEPUTE	1958-12-09 00:00:00	\N	1959-02-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24458	23055	DEPUTE	1962-12-06 00:00:00	\N	1963-01-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24459	23056	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24460	23057	DEPUTE	1968-07-11 00:00:00	\N	1969-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24461	23058	DEPUTE	1973-04-02 00:00:00	\N	1973-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24462	23059	DEPUTE	1984-09-24 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24463	23060	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:34	\N
24464	23061	DEPUTE	1988-06-06 00:00:00	\N	1989-11-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:35	\N
24465	23062	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:35	\N
24466	23063	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:35	\N
24467	23064	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:35	\N
24468	23065	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:35	\N
24469	23066	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:35	\N
24470	23067	DEPUTE	1997-06-01 00:00:00	\N	1998-11-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:35	\N
24471	23068	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:35	\N
24472	23069	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:35	\N
24473	23070	VICPDTAN	1997-06-13 00:00:00	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:35	\N
24474	23071	VICPDTAN	1998-10-01 00:00:00	\N	1998-10-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:35	\N
24475	23072	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:35	\N
24476	23073	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:35	\N
24477	23074	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:35	\N
24478	23075	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:35	\N
24479	23076	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:35	\N
24480	23077	DEPUTE	1993-05-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:35	\N
24481	23078	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:35	\N
24482	23079	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:35	\N
24483	23080	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:35	\N
24484	23081	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:35	\N
24485	23082	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:35	\N
24486	23083	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:35	\N
24487	23084	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:35	\N
24488	23085	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:35	\N
24489	23086	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:35	\N
24490	23087	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:35	\N
24491	23088	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:35	\N
24492	23089	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:35	\N
24493	23090	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:35	\N
24494	23091	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:35	\N
24495	23092	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:35	\N
25796	24393	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25797	24394	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25798	24395	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25799	24396	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25800	24397	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25801	24398	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25802	24399	SECAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25803	24400	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25804	24401	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25805	24402	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25806	24403	DEPUTE	1973-04-02 00:00:00	\N	1974-04-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25807	24404	DEPUTE	1975-07-07 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25808	24405	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25809	24406	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25810	24407	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25811	24408	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25812	24409	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25813	24410	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25814	24411	SECAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25815	24412	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25816	24413	SECAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25817	24414	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25818	24415	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25819	24416	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25820	24417	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25821	24418	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25822	24419	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25823	24420	SECAN	1997-06-13 00:00:00	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25824	24421	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25825	24422	VICPDTAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25826	24423	SECAN	2012-06-27 00:00:00	\N	2013-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25827	24424	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:12	\N
25828	24425	DEPUTE	1986-04-02 00:00:00	\N	1987-12-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:13	\N
25829	24426	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:13	\N
25830	24427	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:13	\N
25831	24428	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:13	\N
25832	24429	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:13	\N
25833	24430	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:13	\N
25834	24431	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:13	\N
25835	24432	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:13	\N
25836	24433	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:13	\N
25837	24434	DEPUTE	2007-06-20 00:00:00	\N	2010-12-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:13	\N
25838	24435	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:13	\N
25839	24436	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:13	\N
25840	24437	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:13	\N
25841	24438	VICPDTAN	2004-10-01 00:00:00	\N	2006-11-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:13	\N
25842	24439	VICPDTAN	2009-10-06 00:00:00	\N	2010-11-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:13	\N
25843	24440	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:13	\N
25844	24441	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:13	\N
25845	24442	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:13	\N
25846	24443	DEPUTE	1981-04-15 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:13	\N
25847	24444	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:13	\N
25848	24445	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:13	\N
25849	24446	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:13	\N
25850	24447	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:13	\N
25851	24448	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:13	\N
25852	24449	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:13	\N
25853	24450	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:13	\N
25854	24451	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:13	\N
25855	24452	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:13	\N
25856	24453	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:13	\N
25857	24454	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:13	\N
25858	24455	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:13	\N
25859	24456	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:13	\N
25860	24457	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:13	\N
25861	24458	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:13	\N
25862	24459	DEPUTE	1988-06-13 00:00:00	\N	1992-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:13	\N
25863	24460	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:13	\N
25864	24461	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:13	\N
25865	24462	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:14	\N
25866	24463	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:14	\N
25867	24464	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:14	\N
25868	24465	DEPUTE	1973-04-02 00:00:00	\N	1976-09-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:14	\N
25869	24466	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:14	\N
25870	24467	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:14	\N
25871	24468	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:14	\N
25872	24469	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:14	\N
25873	24470	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:14	\N
25874	24471	DEPUTE	1975-05-25 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:14	\N
25875	24472	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:14	\N
25876	24473	DEPUTE	1968-07-11 00:00:00	\N	1969-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:14	\N
25877	24474	DEPUTE	1973-04-02 00:00:00	\N	1973-05-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:14	\N
25878	24475	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:14	\N
25879	24476	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:14	\N
25880	24477	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:14	\N
25881	24478	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:14	\N
25882	24479	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:14	\N
25883	24480	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:14	\N
25884	24481	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:14	\N
25885	24482	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:14	\N
25886	24483	DEPUTE	1968-07-11 00:00:00	\N	1968-08-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:14	\N
25887	24484	DEPUTE	1971-12-13 00:00:00	\N	1972-01-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:14	\N
25888	24485	DEPUTE	1973-04-02 00:00:00	\N	1973-05-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:14	\N
27284	25881	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27285	25882	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27286	25883	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27287	25884	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:54	\N
27288	25885	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27289	25886	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27290	25887	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27291	25888	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27292	25889	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27293	25890	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27294	25891	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27295	25892	DEPUTE	2007-06-20 00:00:00	\N	2010-12-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27296	25893	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27297	25894	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27298	25895	VICPDTAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27299	25896	VICPDTAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27300	25897	VICPDTAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27301	25898	PDTAN	2007-03-07 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27302	25899	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27303	25900	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27304	25901	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27305	25902	DEPUTE	1973-04-02 00:00:00	\N	1974-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27306	25903	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27307	25904	DEPUTE	1978-04-03 00:00:00	\N	1978-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27308	25905	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27309	25906	DEPUTE	1988-06-06 00:00:00	\N	1991-03-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27310	25907	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27311	25908	DEPUTE	1986-04-02 00:00:00	\N	1986-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27312	25909	DEPUTE	1986-10-01 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27313	25910	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27314	25911	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27315	25912	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27316	25913	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27317	25914	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27318	25915	DEPUTE	1983-11-15 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27319	25916	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27320	25917	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27321	25918	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27322	25919	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27323	25920	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27324	25921	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27325	25922	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27326	25923	VICPDTAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27327	25924	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27328	25925	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27329	25926	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27330	25927	DEPUTE	1994-06-20 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27331	25928	DEPUTE	1996-02-25 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27332	25929	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27333	25930	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27334	25931	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27335	25932	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27336	25933	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27337	25934	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27338	25935	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27339	25936	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27340	25937	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27341	25938	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:55	\N
27342	25939	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:56	\N
27343	25940	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:56	\N
27344	25941	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:56	\N
27345	25942	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:56	\N
27346	25943	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:56	\N
27347	25944	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:56	\N
27348	25945	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:56	\N
27349	25946	SECAN	1987-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:56	\N
27350	25947	SECAN	1988-06-24 00:00:00	\N	1992-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:56	\N
27351	25948	SECAN	1992-10-21 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:56	\N
27352	25949	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:56	\N
27353	25950	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:56	\N
27354	25951	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:56	\N
27355	25952	SECAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:56	\N
27356	25953	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:56	\N
27357	25954	SECAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:56	\N
27358	25955	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:56	\N
27359	25956	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:56	\N
27360	25957	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:56	\N
27361	25958	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:56	\N
27362	25959	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:56	\N
27363	25960	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:56	\N
27364	25961	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:56	\N
27365	25962	DEPUTE	1986-04-02 00:00:00	\N	1986-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:56	\N
27366	25963	DEPUTE	1986-08-25 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:56	\N
27367	25964	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:56	\N
27368	25965	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:56	\N
27369	25966	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:56	\N
27370	25967	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:56	\N
27371	25968	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:56	\N
27372	25969	DEPUTE	2012-06-20 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:56	\N
27373	25970	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:56	\N
27374	25971	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:56	\N
27375	25972	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:56	\N
27376	25973	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:56	\N
23008	21605	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
23009	21606	DEPUTE	1978-04-03 00:00:00	\N	1978-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
23010	21607	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
23011	21608	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
23012	21609	DEPUTE	1973-04-02 00:00:00	\N	1974-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
23013	21610	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
23014	21611	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
23015	21612	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
23016	21613	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
23017	21614	DEPUTE	2002-06-19 00:00:00	\N	2004-05-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
23018	21615	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
23019	21616	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
23020	21617	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
23021	21618	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
23022	21619	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:53	\N
23023	21620	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:54	\N
23024	21621	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:54	\N
23025	21622	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:54	\N
23026	21623	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:54	\N
23027	21624	DEPUTE	1997-06-01 00:00:00	\N	1998-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:54	\N
23028	21625	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:54	\N
23029	21626	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:54	\N
23030	21627	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:54	\N
23031	21628	VICPDTAN	1992-04-02 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:54	\N
23032	21629	PDTAN	2012-06-26 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:54	\N
23033	21630	DEPUTE	1988-06-06 00:00:00	\N	1990-12-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:54	\N
23034	21631	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:54	\N
23035	21632	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:54	\N
23036	21633	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:54	\N
23037	21634	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:54	\N
23038	21635	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:54	\N
23039	21636	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:54	\N
23040	21637	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:54	\N
23041	21638	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:54	\N
23042	21639	QUESTAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:54	\N
23043	21640	DEPUTE	1993-04-02 00:00:00	\N	1995-12-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:54	\N
23044	21641	DEPUTE	1996-04-01 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:54	\N
23045	21642	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:54	\N
23046	21643	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:54	\N
23047	21644	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:54	\N
23048	21645	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:54	\N
23049	21646	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:54	\N
23050	21647	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:54	\N
23051	21648	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:54	\N
23052	21649	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:54	\N
23053	21650	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:54	\N
23054	21651	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:54	\N
23055	21652	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:55	\N
23056	21653	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:55	\N
23057	21654	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:55	\N
23058	21655	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:55	\N
23059	21656	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:55	\N
23060	21657	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:55	\N
23061	21658	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:55	\N
23062	21659	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:55	\N
23063	21660	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:55	\N
23064	21661	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:55	\N
23065	21662	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:55	\N
23066	21663	DEPUTE	1986-04-02 00:00:00	\N	1986-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:55	\N
23067	21664	DEPUTE	1986-10-24 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:55	\N
23068	21665	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:55	\N
23069	21666	DEPUTE	1986-10-01 00:00:00	\N	1986-10-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:55	\N
23070	21667	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:55	\N
23071	21668	DEPUTE	1993-04-02 00:00:00	\N	1994-05-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:55	\N
23072	21669	DEPUTE	1997-06-01 00:00:00	\N	2001-01-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:55	\N
23073	21670	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:55	\N
23074	21671	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:55	\N
23075	21672	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:55	\N
23076	21673	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:55	\N
23077	21674	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:55	\N
23078	21675	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:55	\N
23079	21676	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:55	\N
23080	21677	DEPUTE	1968-07-11 00:00:00	\N	1969-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:55	\N
23081	21678	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:55	\N
23082	21679	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:55	\N
23083	21680	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:55	\N
23084	21681	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:55	\N
23085	21682	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:55	\N
23086	21683	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:55	\N
23087	21684	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:55	\N
23088	21685	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:56	\N
23089	21686	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:56	\N
23090	21687	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:56	\N
23091	21688	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:56	\N
23092	21689	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:56	\N
23093	21690	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:56	\N
23094	21691	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:56	\N
23095	21692	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:56	\N
23096	21693	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:56	\N
23097	21694	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:56	\N
23098	21695	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:56	\N
23099	21696	DEPUTE	1973-05-08 00:00:00	\N	1976-11-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:56	\N
23100	21697	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:56	\N
24496	23093	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:35	\N
24497	23094	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:35	\N
24498	23095	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:35	\N
24499	23096	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:35	\N
24500	23097	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:35	\N
24501	23098	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:35	\N
24502	23099	QUESTAN	1990-04-02 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:35	\N
24503	23100	QUESTAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:35	\N
24504	23101	QUESTAN	1994-04-02 00:00:00	\N	1995-05-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:35	\N
24505	23102	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:35	\N
24506	23103	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:35	\N
24507	23104	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:35	\N
24508	23105	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:35	\N
24509	23106	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:36	\N
24510	23107	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:36	\N
24511	23108	DEPUTE	2002-06-19 00:00:00	\N	2007-03-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:36	\N
24512	23109	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:36	\N
24513	23110	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:36	\N
24514	23111	SECAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:36	\N
24515	23112	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:36	\N
24516	23113	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:36	\N
24517	23114	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:36	\N
24518	23115	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:36	\N
24519	23116	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:36	\N
24520	23117	SECAN	2003-10-01 00:00:00	\N	2005-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:36	\N
24521	23118	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:36	\N
24522	23119	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:36	\N
24523	23120	DEPUTE	2007-06-20 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:36	\N
24524	23121	DEPUTE	1973-04-02 00:00:00	\N	1973-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:36	\N
24525	23122	DEPUTE	1967-04-03 00:00:00	\N	1967-05-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:36	\N
24526	23123	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:36	\N
24527	23124	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:36	\N
24528	23125	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:36	\N
24529	23126	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:36	\N
24530	23127	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:36	\N
24531	23128	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:36	\N
24532	23129	DEPUTE	1981-07-02 00:00:00	\N	1982-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:36	\N
24533	23130	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:36	\N
24534	23131	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:36	\N
24535	23132	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:36	\N
24536	23133	DEPUTE	1973-05-13 00:00:00	\N	1975-04-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:36	\N
24537	23134	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:36	\N
24538	23135	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:36	\N
24539	23136	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:36	\N
24540	23137	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:36	\N
24541	23138	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:36	\N
24542	23139	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:36	\N
24543	23140	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:37	\N
24544	23141	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:37	\N
24545	23142	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:37	\N
24546	23143	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:37	\N
24547	23144	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:37	\N
24548	23145	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:37	\N
24549	23146	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:37	\N
24550	23147	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:37	\N
24551	23148	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:37	\N
24552	23149	VICPDTAN	2005-06-09 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:37	\N
24553	23150	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:37	\N
24554	23151	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:37	\N
24555	23152	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:37	\N
24556	23153	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:37	\N
24557	23154	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:37	\N
24558	23155	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:37	\N
24559	23156	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:37	\N
24560	23157	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:37	\N
24561	23158	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:37	\N
24562	23159	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:37	\N
24563	23160	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:37	\N
24564	23161	DEPUTE	1997-06-01 00:00:00	\N	2001-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:37	\N
24565	23162	DEPUTE	2001-04-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:37	\N
24566	23163	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:37	\N
24567	23164	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:37	\N
24568	23165	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:37	\N
24569	23166	DEPUTE	1997-06-01 00:00:00	\N	1999-12-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:37	\N
24570	23167	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:37	\N
24571	23168	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:37	\N
24572	23169	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:37	\N
24573	23170	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:37	\N
24574	23171	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:37	\N
24575	23172	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:37	\N
24576	23173	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:37	\N
24577	23174	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:38	\N
24578	23175	VICPDTAN	2009-10-06 00:00:00	\N	2010-10-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:38	\N
24579	23176	SECAN	2010-10-05 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:38	\N
24580	23177	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:38	\N
24581	23178	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:38	\N
24582	23179	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:38	\N
24583	23180	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:38	\N
24584	23181	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:38	\N
24585	23182	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:38	\N
24586	23183	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:38	\N
24587	23184	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:38	\N
24588	23185	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:38	\N
25889	24486	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:14	\N
25890	24487	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:14	\N
25891	24488	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:14	\N
25892	24489	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:14	\N
25893	24490	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:14	\N
25894	24491	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:14	\N
25895	24492	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:14	\N
25896	24493	DEPUTE	1992-11-03 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:14	\N
25897	24494	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:14	\N
25898	24495	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:14	\N
25899	24496	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:14	\N
25900	24497	DEPUTE	1988-06-13 00:00:00	\N	1992-07-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:14	\N
25901	24498	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:14	\N
25902	24499	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:14	\N
25903	24500	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:14	\N
25904	24501	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:14	\N
25905	24502	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:14	\N
25906	24503	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:15	\N
25907	24504	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:15	\N
25908	24505	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:15	\N
25909	24506	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:15	\N
25910	24507	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:15	\N
25911	24508	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:15	\N
25912	24509	DEPUTE	2007-06-20 00:00:00	\N	2011-11-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:15	\N
25913	24510	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:15	\N
25914	24511	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:15	\N
25915	24512	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:15	\N
25916	24513	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:15	\N
25917	24514	DEPUTE	1981-07-02 00:00:00	\N	1984-09-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:15	\N
25918	24515	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:15	\N
25919	24516	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:15	\N
25920	24517	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:15	\N
25921	24518	DEPUTE	1973-05-06 00:00:00	\N	1974-07-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:15	\N
25922	24519	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:15	\N
25923	24520	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:15	\N
25924	24521	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:15	\N
25925	24522	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:15	\N
25926	24523	SECAN	2007-06-27 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:15	\N
25927	24524	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:15	\N
25928	24525	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:15	\N
25929	24526	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:16	\N
25930	24527	DEPUTE	1962-12-06 00:00:00	\N	1963-03-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:16	\N
25931	24528	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:16	\N
25932	24529	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:16	\N
25933	24530	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:16	\N
25934	24531	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:16	\N
25935	24532	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:16	\N
25936	24533	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:16	\N
25937	24534	DEPUTE	1995-10-09 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:16	\N
25938	24535	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:16	\N
25939	24536	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:16	\N
25940	24537	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:16	\N
25941	24538	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:16	\N
25942	24539	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:16	\N
25943	24540	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:16	\N
25944	24541	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:16	\N
25945	24542	DEPUTE	1978-04-02 00:00:00	\N	1980-09-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:16	\N
25946	24543	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:16	\N
25947	24544	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:16	\N
25948	24545	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:16	\N
25949	24546	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:16	\N
25950	24547	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:16	\N
25951	24548	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:16	\N
25952	24549	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:16	\N
25953	24550	DEPUTE	2000-04-28 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:16	\N
25954	24551	DEPUTE	1992-05-05 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:17	\N
25955	24552	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:17	\N
25956	24553	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:17	\N
25957	24554	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:17	\N
25958	24555	DEPUTE	1981-07-02 00:00:00	\N	1984-08-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:17	\N
25959	24556	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:17	\N
25960	24557	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:17	\N
25961	24558	DEPUTE	1988-06-06 00:00:00	\N	1992-05-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:17	\N
25962	24559	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:17	\N
25963	24560	DEPUTE	1997-06-01 00:00:00	\N	1998-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:17	\N
25964	24561	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:17	\N
25965	24562	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:17	\N
25966	24563	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:17	\N
25967	24564	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:17	\N
25968	24565	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:17	\N
25969	24566	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:17	\N
25970	24567	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:17	\N
25971	24568	DEPUTE	1988-06-06 00:00:00	\N	1988-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:17	\N
25972	24569	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:17	\N
25973	24570	DEPUTE	1988-09-19 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:17	\N
25974	24571	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:17	\N
25975	24572	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:17	\N
25976	24573	DEPUTE	2012-06-20 00:00:00	\N	2013-01-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:17	\N
25977	24574	DEPUTE	2013-03-24 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:17	\N
25978	24575	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:17	\N
25979	24576	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:18	\N
25980	24577	DEPUTE	2012-06-20 00:00:00	\N	2014-07-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:18	\N
25981	24578	DEPUTE	1978-04-03 00:00:00	\N	1980-09-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:18	\N
27377	25974	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:56	\N
27471	26068	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:00	\N
27472	26069	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:00	\N
27473	26070	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:00	\N
27474	26071	DEPUTE	1988-06-13 00:00:00	\N	1989-06-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:00	\N
27475	26072	DEPUTE	1981-07-02 00:00:00	\N	1985-09-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:00	\N
27476	26073	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:00	\N
27477	26074	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:00	\N
27478	26075	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:00	\N
27479	26076	DEPUTE	1989-02-03 00:00:00	\N	1992-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:00	\N
27480	26077	DEPUTE	1993-04-02 00:00:00	\N	1996-07-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:00	\N
27481	26078	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:00	\N
27482	26079	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:00	\N
27483	26080	DEPUTE	1997-06-01 00:00:00	\N	1998-07-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:00	\N
27484	26081	DEPUTE	1997-06-01 00:00:00	\N	2000-04-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:00	\N
27485	26082	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:00	\N
27486	26083	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:00	\N
27487	26084	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:00	\N
27488	26085	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:00	\N
27489	26086	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:00	\N
27490	26087	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:01	\N
27491	26088	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:01	\N
27492	26089	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:01	\N
27493	26090	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:01	\N
27494	26091	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:01	\N
27495	26092	DEPUTE	1988-06-13 00:00:00	\N	1989-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:01	\N
27496	26093	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:01	\N
27497	26094	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:01	\N
27498	26095	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:01	\N
27499	26096	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:01	\N
27500	26097	DEPUTE	1983-01-09 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:01	\N
27501	26098	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:01	\N
27502	26099	DEPUTE	1988-06-13 00:00:00	\N	1988-11-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:01	\N
27503	26100	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:01	\N
27504	26101	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:01	\N
27505	26102	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:01	\N
27506	26103	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:01	\N
27507	26104	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:01	\N
27508	26105	SECAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:01	\N
27509	26106	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:01	\N
27510	26107	SECAN	2002-06-26 00:00:00	\N	2002-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:01	\N
27511	26108	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:01	\N
27512	26109	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:01	\N
27513	26110	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:01	\N
27514	26111	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:01	\N
27515	26112	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:01	\N
27516	26113	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:02	\N
27517	26114	DEPUTE	2012-06-20 00:00:00	\N	2017-03-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:02	\N
27518	26115	DEPUTE	1997-06-12 00:00:00	\N	1999-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:02	\N
27519	26116	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:02	\N
27520	26117	DEPUTE	2012-07-22 00:00:00	\N	2014-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:02	\N
27521	26118	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:02	\N
27522	26119	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:02	\N
27523	26120	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:02	\N
27524	26121	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:02	\N
27525	26122	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:02	\N
27526	26123	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:02	\N
27527	26124	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:02	\N
27528	26125	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:02	\N
27529	26126	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:02	\N
27530	26127	DEPUTE	1991-06-17 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:02	\N
27531	26128	DEPUTE	1981-07-23 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:02	\N
27532	26129	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:02	\N
27533	26130	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:02	\N
27534	26131	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:02	\N
27535	26132	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:02	\N
27536	26133	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:02	\N
27537	26134	DEPUTE	2002-06-19 00:00:00	\N	2006-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:02	\N
27538	26135	DEPUTE	1997-05-25 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:02	\N
27539	26136	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:02	\N
27540	26137	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:02	\N
27541	26138	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:02	\N
27542	26139	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:02	\N
27543	26140	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:02	\N
27544	26141	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:02	\N
27545	26142	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:02	\N
27546	26143	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:02	\N
27547	26144	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:02	\N
27548	26145	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:02	\N
27549	26146	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:02	\N
27550	26147	DEPUTE	1976-11-15 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:02	\N
27551	26148	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:02	\N
27552	26149	DEPUTE	1968-08-13 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:02	\N
27553	26150	DEPUTE	1973-04-02 00:00:00	\N	1976-02-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:02	\N
27554	26151	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:02	\N
27555	26152	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:02	\N
27556	26153	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27557	26154	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27558	26155	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27559	26156	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27560	26157	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27561	26158	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27562	26159	DEPUTE	1995-11-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
23101	21698	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:56	\N
23102	21699	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:56	\N
23103	21700	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:56	\N
23104	21701	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:56	\N
23105	21702	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:56	\N
23106	21703	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:56	\N
23107	21704	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:56	\N
23108	21705	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:57	\N
23109	21706	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:57	\N
23110	21707	DEPUTE	1988-06-13 00:00:00	\N	1993-03-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:57	\N
23111	21708	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:57	\N
23112	21709	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:57	\N
23113	21710	DEPUTE	1998-09-27 00:00:00	\N	1999-02-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:57	\N
23114	21711	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:57	\N
23115	21712	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:57	\N
23116	21713	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:57	\N
23117	21714	DEPUTE	1981-07-25 00:00:00	\N	1986-03-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:57	\N
23118	21715	DEPUTE	1981-07-02 00:00:00	\N	1983-01-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:57	\N
23119	21716	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:57	\N
23120	21717	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:57	\N
23121	21718	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:57	\N
23122	21719	DEPUTE	1970-06-14 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:57	\N
23123	21720	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:57	\N
23124	21721	DEPUTE	1981-07-02 00:00:00	\N	1981-12-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:57	\N
23125	21722	DEPUTE	1982-01-18 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:57	\N
23126	21723	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:57	\N
23127	21724	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:57	\N
23128	21725	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:57	\N
23129	21726	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:58	\N
23130	21727	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:58	\N
23131	21728	DEPUTE	1988-06-06 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:58	\N
23132	21729	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:58	\N
23133	21730	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:58	\N
23134	21731	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:58	\N
23135	21732	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:58	\N
23136	21733	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:58	\N
23137	21734	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:58	\N
23138	21735	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:58	\N
23139	21736	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:58	\N
23140	21737	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:58	\N
23141	21738	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:58	\N
23142	21739	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:58	\N
23143	21740	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:58	\N
23144	21741	DEPUTE	1980-10-09 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:58	\N
23145	21742	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:58	\N
23146	21743	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:58	\N
23147	21744	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:58	\N
23148	21745	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:59	\N
23149	21746	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:59	\N
23150	21747	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:59	\N
23151	21748	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:59	\N
23152	21749	DEPUTE	1971-12-05 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:59	\N
23153	21750	DEPUTE	1973-04-02 00:00:00	\N	1977-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:59	\N
23154	21751	DEPUTE	1978-04-03 00:00:00	\N	1978-10-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:59	\N
23155	21752	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:59	\N
23156	21753	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:59	\N
23157	21754	DEPUTE	1992-05-03 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:59	\N
23158	21755	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:59	\N
23159	21756	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:59	\N
23160	21757	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:59	\N
23161	21758	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:59	\N
23162	21759	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:59	\N
23163	21760	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:59	\N
23164	21761	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:59	\N
23165	21762	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:59	\N
23166	21763	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:59	\N
23167	21764	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:59	\N
23168	21765	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:59	\N
23169	21766	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:59	\N
23170	21767	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:59	\N
23171	21768	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:59	\N
23172	21769	DEPUTE	1993-05-02 00:00:00	\N	1995-09-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:59	\N
23173	21770	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:59	\N
23174	21771	DEPUTE	1993-05-02 00:00:00	\N	1995-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:59	\N
23175	21772	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:59	\N
23176	21773	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:59	\N
23177	21774	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:59	\N
23178	21775	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:59	\N
23179	21776	DEPUTE	1995-09-18 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:59	\N
23180	21777	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:59	\N
23181	21778	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:59	\N
23182	21779	DEPUTE	2007-06-20 00:00:00	\N	2012-03-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:59	\N
23183	21780	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:59	\N
23184	21781	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:59	\N
23185	21782	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:59	\N
23186	21783	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:00	\N
23187	21784	DEPUTE	1976-04-09 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:00	\N
23188	21785	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:00	\N
23189	21786	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:00	\N
23190	21787	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:00	\N
23191	21788	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:00	\N
23192	21789	DEPUTE	1981-07-02 00:00:00	\N	1984-08-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:00	\N
23193	21790	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:00	\N
24589	23186	QUESTAN	2004-05-05 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:38	\N
24590	23187	DEPUTE	1981-07-02 00:00:00	\N	1983-12-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:38	\N
24591	23188	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:38	\N
24592	23189	DEPUTE	1991-02-04 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:38	\N
24593	23190	DEPUTE	1988-06-13 00:00:00	\N	1990-12-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:38	\N
24594	23191	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:38	\N
24595	23192	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:38	\N
24596	23193	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:38	\N
24597	23194	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:38	\N
24598	23195	DEPUTE	1978-04-02 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:38	\N
24599	23196	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:38	\N
24600	23197	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:38	\N
24601	23198	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:38	\N
24602	23199	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:38	\N
24603	23200	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:38	\N
24604	23201	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:38	\N
24605	23202	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:38	\N
24606	23203	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:38	\N
24607	23204	DEPUTE	1976-09-28 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:39	\N
24608	23205	DEPUTE	1978-05-06 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:39	\N
24609	23206	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:39	\N
24610	23207	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:39	\N
24611	23208	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:39	\N
24612	23209	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:39	\N
24613	23210	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:39	\N
24614	23211	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:39	\N
24615	23212	DEPUTE	1968-07-11 00:00:00	\N	1969-07-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:39	\N
24616	23213	DEPUTE	1970-09-20 00:00:00	\N	1970-10-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:39	\N
24617	23214	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:39	\N
24618	23215	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:39	\N
24619	23216	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:39	\N
24620	23217	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:39	\N
24621	23218	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:39	\N
24622	23219	PDTAN	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:39	\N
24623	23220	PDTAN	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:39	\N
24624	23221	PDTAN	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:39	\N
24625	23222	PDTAN	1968-07-11 00:00:00	\N	1969-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:39	\N
24626	23223	PDTAN	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:39	\N
24627	23224	PDTAN	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:39	\N
24628	23225	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:39	\N
24629	23226	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:39	\N
24630	23227	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:39	\N
24631	23228	DEPUTE	1969-07-21 00:00:00	\N	1970-07-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:39	\N
24632	23229	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:39	\N
24633	23230	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:39	\N
24634	23231	DEPUTE	1968-07-11 00:00:00	\N	1968-08-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:40	\N
24635	23232	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:40	\N
24636	23233	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:40	\N
24637	23234	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:40	\N
24638	23235	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:40	\N
24639	23236	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:40	\N
24640	23237	DEPUTE	1962-12-06 00:00:00	\N	1966-02-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:40	\N
24641	23238	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:40	\N
24642	23239	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:40	\N
24643	23240	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:40	\N
24644	23241	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:40	\N
24645	23242	DEPUTE	1993-04-02 00:00:00	\N	1994-11-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:40	\N
24646	23243	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:40	\N
24647	23244	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:40	\N
24648	23245	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:40	\N
24649	23246	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:40	\N
24650	23247	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:40	\N
24651	23248	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:40	\N
24652	23249	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:40	\N
24653	23250	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:40	\N
24654	23251	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:40	\N
24655	23252	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:40	\N
24656	23253	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:40	\N
24657	23254	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:40	\N
24658	23255	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:40	\N
24659	23256	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:40	\N
24660	23257	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:40	\N
24661	23258	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:40	\N
24662	23259	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:40	\N
24663	23260	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:40	\N
24664	23261	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:40	\N
24665	23262	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:40	\N
24666	23263	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:41	\N
24667	23264	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:41	\N
24668	23265	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:41	\N
24669	23266	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:41	\N
24670	23267	SECAN	2012-06-27 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:41	\N
24671	23268	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:41	\N
24672	23269	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:41	\N
24673	23270	DEPUTE	1962-12-06 00:00:00	\N	1966-02-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:41	\N
24674	23271	DEPUTE	1968-07-11 00:00:00	\N	1972-08-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:41	\N
24675	23272	DEPUTE	1973-04-02 00:00:00	\N	1973-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:41	\N
24676	23273	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:41	\N
24677	23274	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:41	\N
24678	23275	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:41	\N
24679	23276	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:41	\N
24680	23277	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:41	\N
24681	23278	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:41	\N
25982	24579	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:18	\N
25983	24580	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:18	\N
25984	24581	DEPUTE	1994-11-18 00:00:00	\N	1995-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:18	\N
25985	24582	DEPUTE	1958-12-09 00:00:00	\N	1962-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:18	\N
25986	24583	DEPUTE	1962-12-06 00:00:00	\N	1963-01-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:18	\N
25987	24584	DEPUTE	1967-04-03 00:00:00	\N	1967-05-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:18	\N
25988	24585	DEPUTE	1968-07-11 00:00:00	\N	1968-08-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:18	\N
25989	24586	DEPUTE	1973-04-02 00:00:00	\N	1973-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:18	\N
25990	24587	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:18	\N
25991	24588	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:18	\N
25992	24589	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:18	\N
25993	24590	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:18	\N
25994	24591	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:18	\N
25995	24592	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:18	\N
25996	24593	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:18	\N
25997	24594	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:18	\N
25998	24595	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:18	\N
25999	24596	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:18	\N
26000	24597	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26001	24598	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26002	24599	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26003	24600	DEPUTE	1988-06-13 00:00:00	\N	1990-08-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26004	24601	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26005	24602	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26006	24603	DEPUTE	1992-05-03 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26007	24604	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26008	24605	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26009	24606	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26010	24607	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26011	24608	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26012	24609	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26013	24610	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26014	24611	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26015	24612	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26016	24613	DEPUTE	1981-07-02 00:00:00	\N	1984-04-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26017	24614	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26018	24615	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26019	24616	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26020	24617	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26021	24618	DEPUTE	2007-06-20 00:00:00	\N	2010-12-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26022	24619	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26023	24620	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26024	24621	DEPUTE	2000-04-28 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26025	24622	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26026	24623	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26027	24624	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26028	24625	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26029	24626	DEPUTE	1988-07-29 00:00:00	\N	1991-04-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26030	24627	DEPUTE	1997-07-05 00:00:00	\N	2000-09-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26031	24628	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26032	24629	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26033	24630	DEPUTE	2002-06-19 00:00:00	\N	2007-04-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26034	24631	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26035	24632	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26036	24633	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26037	24634	DEPUTE	1997-05-25 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26038	24635	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26039	24636	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26040	24637	DEPUTE	2010-12-14 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26041	24638	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26042	24639	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26043	24640	DEPUTE	1995-12-11 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26044	24641	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26045	24642	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26046	24643	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26047	24644	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26048	24645	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26049	24646	DEPUTE	1996-10-01 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26050	24647	DEPUTE	1999-10-02 00:00:00	\N	2000-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26051	24648	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26052	24649	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26053	24650	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26054	24651	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:19	\N
26055	24652	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:20	\N
26056	24653	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:20	\N
26057	24654	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:20	\N
26058	24655	DEPUTE	2007-06-20 00:00:00	\N	2008-09-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:20	\N
26059	24656	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:20	\N
26060	24657	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:20	\N
26061	24658	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:20	\N
26062	24659	DEPUTE	1993-04-02 00:00:00	\N	1993-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:20	\N
26063	24660	DEPUTE	1993-12-13 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:20	\N
26064	24661	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:20	\N
26065	24662	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:20	\N
26066	24663	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:20	\N
26067	24664	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:20	\N
26068	24665	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:20	\N
26069	24666	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:20	\N
26070	24667	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:20	\N
26071	24668	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:20	\N
26072	24669	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:20	\N
26073	24670	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:20	\N
26074	24671	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:20	\N
27843	26440	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27844	26441	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27845	26442	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27846	26443	SECAN	2012-06-27 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27847	26444	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27848	26445	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27849	26446	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27850	26447	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27851	26448	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27852	26449	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27853	26450	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27854	26451	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27855	26452	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27856	26453	DEPUTE	2007-06-20 00:00:00	\N	2011-07-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27857	26454	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27858	26455	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27859	26456	SECAN	2007-06-27 00:00:00	\N	2011-07-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27860	26457	SECAN	2013-10-01 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27861	26458	DEPUTE	2011-07-30 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27862	26459	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27863	26460	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27864	26461	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27865	26462	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27866	26463	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27867	26464	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27868	26465	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:11	\N
27869	26466	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:11	\N
27870	26467	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:11	\N
27871	26468	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:11	\N
27872	26469	DEPUTE	2005-09-12 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:11	\N
27873	26470	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:11	\N
27874	26471	DEPUTE	2002-06-25 00:00:00	\N	2002-06-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:11	\N
27875	26472	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:11	\N
27876	26473	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:11	\N
27877	26474	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:11	\N
27878	26475	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:11	\N
27879	26476	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:11	\N
27880	26477	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:11	\N
27881	26478	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:11	\N
27882	26479	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:11	\N
27883	26480	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:11	\N
27884	26481	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:11	\N
27885	26482	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:11	\N
27886	26483	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:11	\N
27887	26484	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:11	\N
27888	26485	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:11	\N
27889	26486	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:11	\N
27890	26487	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:11	\N
27891	26488	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:11	\N
27892	26489	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:11	\N
27893	26490	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:11	\N
27894	26491	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:11	\N
27895	26492	SECAN	2011-07-07 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:11	\N
27896	26493	SECAN	2012-06-27 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:11	\N
27897	26494	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:11	\N
27898	26495	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:11	\N
27899	26496	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:11	\N
27900	26497	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:11	\N
27901	26498	DEPUTE	2002-07-19 00:00:00	\N	2004-09-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:11	\N
27902	26499	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:11	\N
27903	26500	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:11	\N
27904	26501	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:11	\N
27905	26502	DEPUTE	2002-12-16 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:12	\N
27906	26503	DEPUTE	2007-06-20 00:00:00	\N	2008-04-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:12	\N
27907	26504	DEPUTE	2010-08-05 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:12	\N
27908	26505	DEPUTE	2008-04-19 00:00:00	\N	2010-08-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:12	\N
27909	26506	DEPUTE	2003-06-25 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:12	\N
27910	26507	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:12	\N
27911	26508	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:12	\N
27912	26509	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:12	\N
27913	26510	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:12	\N
27914	26511	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:12	\N
27915	26512	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:12	\N
27916	26513	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:12	\N
27917	26514	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:12	\N
27918	26515	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:12	\N
27919	26516	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:12	\N
27920	26517	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:12	\N
27921	26518	DEPUTE	2004-03-30 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:12	\N
27922	26519	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:12	\N
27923	26520	DEPUTE	2004-05-01 00:00:00	\N	2005-08-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:12	\N
27924	26521	DEPUTE	2010-12-15 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:12	\N
27925	26522	DEPUTE	2004-05-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:12	\N
27926	26523	DEPUTE	2007-07-20 00:00:00	\N	2009-02-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:12	\N
27927	26524	DEPUTE	2010-12-15 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:12	\N
27928	26525	DEPUTE	2004-05-01 00:00:00	\N	2005-07-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:12	\N
27929	26526	DEPUTE	2010-04-23 00:00:00	\N	2010-12-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:12	\N
27930	26527	DEPUTE	2004-05-01 00:00:00	\N	2005-07-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:12	\N
27931	26528	DEPUTE	2007-07-20 00:00:00	\N	2010-12-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:12	\N
27932	26529	DEPUTE	2007-07-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:12	\N
27933	26530	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:12	\N
27934	26531	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:12	\N
27935	26532	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:13	\N
23194	21791	DEPUTE	1988-06-06 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:00	\N
23195	21792	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:00	\N
23196	21793	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:00	\N
23197	21794	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:00	\N
23198	21795	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:00	\N
23199	21796	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:00	\N
23200	21797	DEPUTE	1997-06-01 00:00:00	\N	1999-12-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:00	\N
23201	21798	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:00	\N
23202	21799	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:00	\N
23203	21800	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:00	\N
23204	21801	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:00	\N
23205	21802	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:00	\N
23206	21803	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:00	\N
23207	21804	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:00	\N
23208	21805	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:00	\N
23209	21806	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:00	\N
23210	21807	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:00	\N
23211	21808	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:00	\N
23212	21809	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:00	\N
23213	21810	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:00	\N
23214	21811	DEPUTE	2007-07-20 00:00:00	\N	2010-12-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:00	\N
23215	21812	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:00	\N
23216	21813	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:00	\N
23217	21814	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:00	\N
23218	21815	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:00	\N
23219	21816	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:00	\N
23220	21817	DEPUTE	1978-04-03 00:00:00	\N	1978-05-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:00	\N
23221	21818	DEPUTE	1967-05-08 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:00	\N
23222	21819	DEPUTE	1969-07-23 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:00	\N
23223	21820	DEPUTE	1973-04-02 00:00:00	\N	1977-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:00	\N
23224	21821	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:00	\N
23225	21822	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:00	\N
23226	21823	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:00	\N
23227	21824	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:00	\N
23228	21825	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:00	\N
23229	21826	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:00	\N
23230	21827	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:00	\N
23231	21828	DEPUTE	1995-06-09 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:00	\N
23232	21829	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:01	\N
23233	21830	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:01	\N
23234	21831	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:01	\N
23235	21832	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:01	\N
23236	21833	DEPUTE	2004-12-07 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:01	\N
23237	21834	DEPUTE	2007-06-20 00:00:00	\N	2009-04-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:01	\N
23238	21835	DEPUTE	1983-04-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:01	\N
23239	21836	DEPUTE	1976-11-14 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:01	\N
23240	21837	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:01	\N
23241	21838	DEPUTE	1967-04-03 00:00:00	\N	1967-05-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:01	\N
23242	21839	DEPUTE	1968-07-11 00:00:00	\N	1968-08-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:01	\N
23243	21840	DEPUTE	1973-04-02 00:00:00	\N	1973-05-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:01	\N
23244	21841	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:01	\N
23245	21842	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:01	\N
23246	21843	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:01	\N
23247	21844	DEPUTE	1993-04-02 00:00:00	\N	1995-05-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:01	\N
23248	21845	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:01	\N
23249	21846	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:01	\N
23250	21847	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:01	\N
23251	21848	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:01	\N
23252	21849	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:01	\N
23253	21850	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:01	\N
23254	21851	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:01	\N
23255	21852	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:01	\N
23256	21853	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:01	\N
23257	21854	DEPUTE	2007-06-20 00:00:00	\N	2011-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:01	\N
23258	21855	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:01	\N
23259	21856	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:01	\N
23260	21857	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:01	\N
23261	21858	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:01	\N
23262	21859	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:01	\N
23263	21860	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:01	\N
23264	21861	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:01	\N
23265	21862	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:01	\N
23266	21863	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:02	\N
23267	21864	DEPUTE	1986-04-18 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:02	\N
23268	21865	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:02	\N
23269	21866	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:02	\N
23270	21867	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:02	\N
23271	21868	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:02	\N
23272	21869	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:02	\N
23273	21870	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:02	\N
23274	21871	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:02	\N
23275	21872	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:02	\N
23276	21873	DEPUTE	2002-06-19 00:00:00	\N	2005-07-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:02	\N
23277	21874	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:02	\N
23278	21875	VICPDTAN	1989-04-03 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:02	\N
23279	21876	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:02	\N
23280	21877	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:02	\N
23281	21878	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:02	\N
23282	21879	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:02	\N
23283	21880	SECAN	2002-06-26 00:00:00	\N	2003-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:02	\N
23284	21881	SECAN	2005-10-04 00:00:00	\N	2006-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:02	\N
23285	21882	QUESTAN	2016-09-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:02	\N
23286	21883	QUESTAN	2012-06-27 00:00:00	\N	2016-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:02	\N
24682	23279	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:41	\N
24683	23280	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:41	\N
24684	23281	DEPUTE	2007-06-20 00:00:00	\N	2009-11-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:41	\N
24685	23282	DEPUTE	1983-12-18 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:41	\N
24686	23283	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:41	\N
24687	23284	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:41	\N
24688	23285	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:41	\N
24689	23286	SECAN	1994-04-02 00:00:00	\N	1995-04-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:41	\N
24690	23287	SECAN	1996-10-01 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:41	\N
24691	23288	SECAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:41	\N
24692	23289	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:41	\N
24693	23290	SECAN	1999-10-02 00:00:00	\N	2000-04-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:41	\N
24694	23291	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:41	\N
24695	23292	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:41	\N
24696	23293	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:42	\N
24697	23294	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:42	\N
24698	23295	DEPUTE	1993-04-02 00:00:00	\N	1994-09-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:42	\N
24699	23296	DEPUTE	1988-07-29 00:00:00	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:42	\N
24700	23297	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:42	\N
24701	23298	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:42	\N
24702	23299	DEPUTE	2007-03-05 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:42	\N
24703	23300	DEPUTE	1978-04-03 00:00:00	\N	1979-08-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:42	\N
24704	23301	DEPUTE	1986-04-02 00:00:00	\N	1986-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:42	\N
24705	23302	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:42	\N
24706	23303	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:42	\N
24707	23304	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:42	\N
24708	23305	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:42	\N
24709	23306	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:42	\N
24710	23307	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:42	\N
24711	23308	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:42	\N
24712	23309	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:42	\N
24713	23310	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:42	\N
24714	23311	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:42	\N
24715	23312	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:42	\N
24716	23313	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:42	\N
24717	23314	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:43	\N
24718	23315	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:43	\N
24719	23316	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:43	\N
24720	23317	DEPUTE	1988-06-13 00:00:00	\N	1993-03-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:43	\N
24721	23318	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:43	\N
24722	23319	DEPUTE	1999-12-06 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:43	\N
24723	23320	DEPUTE	1973-05-06 00:00:00	\N	1976-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:43	\N
24724	23321	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:43	\N
24725	23322	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:43	\N
24726	23323	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:43	\N
24727	23324	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:43	\N
24728	23325	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:43	\N
24729	23326	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:43	\N
24730	23327	DEPUTE	1958-12-09 00:00:00	\N	1959-03-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:43	\N
24731	23328	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:43	\N
24732	23329	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:43	\N
24733	23330	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:43	\N
24734	23331	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:43	\N
24735	23332	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:43	\N
24736	23333	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:43	\N
24737	23334	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:43	\N
24738	23335	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:43	\N
24739	23336	DEPUTE	1978-04-02 00:00:00	\N	1980-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:43	\N
24740	23337	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:43	\N
24741	23338	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:43	\N
24742	23339	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:43	\N
24743	23340	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:43	\N
24744	23341	DEPUTE	1998-03-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24745	23342	DEPUTE	2002-06-19 00:00:00	\N	2003-03-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24746	23343	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24747	23344	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24748	23345	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24749	23346	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24750	23347	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24751	23348	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24752	23349	DEPUTE	1981-07-02 00:00:00	\N	1981-12-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24753	23350	DEPUTE	1992-05-03 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24754	23351	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24755	23352	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24756	23353	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24757	23354	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24758	23355	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24759	23356	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24760	23357	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24761	23358	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24762	23359	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24763	23360	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24764	23361	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24765	23362	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24766	23363	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24767	23364	DEPUTE	1988-06-06 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24768	23365	DEPUTE	1991-06-10 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24769	23366	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24770	23367	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24771	23368	DEPUTE	2000-10-22 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24772	23369	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24773	23370	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24774	23371	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
26075	24672	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:20	\N
26076	24673	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:20	\N
26077	24674	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:20	\N
26078	24675	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:20	\N
26079	24676	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:20	\N
26080	24677	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:20	\N
26081	24678	DEPUTE	1988-04-05 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:20	\N
26082	24679	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:20	\N
26083	24680	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:20	\N
26084	24681	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:20	\N
26085	24682	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:20	\N
26086	24683	DEPUTE	2007-06-20 00:00:00	\N	2009-08-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:20	\N
26087	24684	DEPUTE	1985-03-30 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:20	\N
26088	24685	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:20	\N
26089	24686	DEPUTE	1984-08-24 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:20	\N
26090	24687	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:20	\N
26091	24688	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:20	\N
26092	24689	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:20	\N
26093	24690	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:20	\N
26094	24691	DEPUTE	1981-07-25 00:00:00	\N	1986-03-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:20	\N
26095	24692	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:21	\N
26096	24693	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:21	\N
26097	24694	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:21	\N
26098	24695	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:21	\N
26099	24696	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:21	\N
26100	24697	DEPUTE	1997-06-01 00:00:00	\N	1997-12-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:21	\N
26101	24698	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:21	\N
26102	24699	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:21	\N
26103	24700	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:21	\N
26104	24701	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:21	\N
26105	24702	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:21	\N
26106	24703	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:21	\N
26107	24704	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:21	\N
26108	24705	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:21	\N
26109	24706	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:21	\N
26110	24707	DEPUTE	1998-11-29 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:21	\N
26111	24708	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:21	\N
26112	24709	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:21	\N
26113	24710	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:21	\N
26114	24711	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:21	\N
26115	24712	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:21	\N
26116	24713	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:21	\N
26117	24714	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:21	\N
26118	24715	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:21	\N
26119	24716	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:21	\N
26120	24717	DEPUTE	1984-08-20 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:21	\N
26121	24718	DEPUTE	1989-12-04 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:21	\N
26122	24719	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:21	\N
26123	24720	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:21	\N
26124	24721	DEPUTE	2002-06-19 00:00:00	\N	2002-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:21	\N
26125	24722	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:21	\N
26126	24723	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:21	\N
26127	24724	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:21	\N
26128	24725	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:21	\N
26129	24726	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:21	\N
26130	24727	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:21	\N
26131	24728	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:21	\N
26132	24729	SECAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:21	\N
26133	24730	SECAN	1988-06-24 00:00:00	\N	1992-10-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:21	\N
26134	24731	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:22	\N
26135	24732	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:22	\N
26136	24733	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:22	\N
26137	24734	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:22	\N
26138	24735	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:22	\N
26139	24736	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:22	\N
26140	24737	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:22	\N
26141	24738	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:22	\N
26142	24739	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:22	\N
26143	24740	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:22	\N
26144	24741	DEPUTE	1981-07-02 00:00:00	\N	1981-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:22	\N
26145	24742	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:22	\N
26146	24743	DEPUTE	1988-06-13 00:00:00	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:22	\N
26147	24744	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:22	\N
26148	24745	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:22	\N
26149	24746	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:22	\N
26150	24747	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:22	\N
26151	24748	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:22	\N
26152	24749	DEPUTE	1993-04-02 00:00:00	\N	1993-05-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:22	\N
26153	24750	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:22	\N
26154	24751	DEPUTE	1973-04-02 00:00:00	\N	1973-05-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:22	\N
26155	24752	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:22	\N
26156	24753	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:22	\N
26157	24754	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:22	\N
26158	24755	DEPUTE	1997-06-01 00:00:00	\N	1998-03-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:22	\N
26159	24756	VICPDTAN	1992-04-02 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:22	\N
26160	24757	VICPDTAN	1993-04-07 00:00:00	\N	1993-04-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:22	\N
26161	24758	VICPDTAN	1997-06-13 00:00:00	\N	1998-03-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:22	\N
26162	24759	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:22	\N
26163	24760	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:22	\N
26164	24761	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:22	\N
26165	24762	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:22	\N
26166	24763	DEPUTE	1973-04-02 00:00:00	\N	1976-02-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:22	\N
26167	24764	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:22	\N
28118	26715	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:18	\N
28119	26716	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:19	\N
28120	26717	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:19	\N
28121	26718	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:19	\N
28122	26719	SECAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:19	\N
28123	26720	DEPUTE	1993-04-02 00:00:00	\N	1995-12-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:19	\N
28124	26721	DEPUTE	1991-06-17 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:19	\N
28125	26722	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:19	\N
28126	26723	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:19	\N
28127	26724	DEPUTE	1968-07-11 00:00:00	\N	1969-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:19	\N
28128	26725	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:19	\N
28129	26726	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:19	\N
28130	26727	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:19	\N
28131	26728	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:19	\N
28132	26729	DEPUTE	1993-04-02 00:00:00	\N	1995-05-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:19	\N
28133	26730	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:19	\N
28134	26731	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:19	\N
28135	26732	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:19	\N
28136	26733	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:19	\N
28137	26734	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:19	\N
28138	26735	DEPUTE	1988-06-13 00:00:00	\N	1991-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:19	\N
28139	26736	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:19	\N
28140	26737	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:19	\N
28141	26738	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:19	\N
28142	26739	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:19	\N
28143	26740	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:19	\N
28144	26741	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:19	\N
28145	26742	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:19	\N
28146	26743	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:19	\N
28147	26744	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:19	\N
28148	26745	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:19	\N
28149	26746	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:19	\N
28150	26747	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:19	\N
28151	26748	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:19	\N
28152	26749	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:19	\N
28153	26750	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:19	\N
28154	26751	DEPUTE	1980-11-30 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:19	\N
28155	26752	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:19	\N
28156	26753	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:19	\N
28157	26754	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:19	\N
28158	26755	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:19	\N
28159	26756	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:19	\N
28160	26757	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28161	26758	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28162	26759	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28163	26760	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28164	26761	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28165	26762	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28166	26763	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28167	26764	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28168	26765	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28169	26766	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28170	26767	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28171	26768	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28172	26769	DEPUTE	1986-04-02 00:00:00	\N	1988-04-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28173	26770	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28174	26771	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28175	26772	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28176	26773	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28177	26774	DEPUTE	1995-12-12 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28178	26775	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28179	26776	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28180	26777	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28181	26778	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28182	26779	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28183	26780	DEPUTE	1996-10-01 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28184	26781	DEPUTE	1997-06-12 00:00:00	\N	2000-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28185	26782	DEPUTE	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28186	26783	VICPDTAN	2005-07-04 00:00:00	\N	2005-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28187	26784	VICPDTAN	2005-10-04 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28188	26785	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28189	26786	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28190	26787	DEPUTE	1997-06-01 00:00:00	\N	1997-10-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28191	26788	DEPUTE	1997-12-14 00:00:00	\N	2000-05-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28192	26789	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28193	26790	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28194	26791	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28195	26792	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28196	26793	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28197	26794	DEPUTE	1981-07-02 00:00:00	\N	1986-03-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28198	26795	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28199	26796	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28200	26797	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28201	26798	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28202	26799	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28203	26800	VICPDTAN	1994-04-02 00:00:00	\N	1995-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28204	26801	VICPDTAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28205	26802	VICPDTAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28206	26803	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:20	\N
28207	26804	DEPUTE	2005-09-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:21	\N
28208	26805	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:21	\N
28209	26806	DEPUTE	2010-12-14 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:21	\N
28210	26807	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:21	\N
23287	21884	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:02	\N
23288	21885	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:02	\N
23289	21886	DEPUTE	1968-07-11 00:00:00	\N	1969-09-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:02	\N
23290	21887	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:02	\N
23291	21888	DEPUTE	1997-06-01 00:00:00	\N	2001-08-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:02	\N
23292	21889	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:02	\N
23293	21890	DEPUTE	2007-06-20 00:00:00	\N	2011-12-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:02	\N
23294	21891	VICPDTAN	1997-06-12 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:02	\N
23295	21892	VICPDTAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:02	\N
23296	21893	VICPDTAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:02	\N
23297	21894	VICPDTAN	2000-10-02 00:00:00	\N	2001-08-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:02	\N
23298	21895	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:03	\N
23299	21896	DEPUTE	2001-01-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:03	\N
23300	21897	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:03	\N
23301	21898	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:03	\N
23302	21899	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:03	\N
23303	21900	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:03	\N
23304	21901	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:03	\N
23305	21902	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:03	\N
23306	21903	VICPDTAN	1988-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:03	\N
23307	21904	VICPDTAN	1988-06-24 00:00:00	\N	1991-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:03	\N
23308	21905	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:03	\N
23309	21906	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:03	\N
23310	21907	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:03	\N
23311	21908	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:03	\N
23312	21909	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:03	\N
23313	21910	DEPUTE	1968-07-11 00:00:00	\N	1971-02-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:03	\N
23314	21911	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:03	\N
23315	21912	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:03	\N
23316	21913	DEPUTE	1978-04-03 00:00:00	\N	1978-11-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:03	\N
23317	21914	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:03	\N
23318	21915	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:03	\N
23319	21916	QUESTAN	1988-06-24 00:00:00	\N	1990-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:03	\N
23320	21917	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:03	\N
23321	21918	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:03	\N
23322	21919	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:03	\N
23323	21920	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:03	\N
23324	21921	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:03	\N
23325	21922	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:03	\N
23326	21923	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:03	\N
23327	21924	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:03	\N
23328	21925	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:03	\N
23329	21926	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:03	\N
23330	21927	VICPDTAN	1996-10-01 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:03	\N
23331	21928	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:03	\N
23332	21929	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:04	\N
23333	21930	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:04	\N
23334	21931	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:04	\N
23335	21932	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:04	\N
23336	21933	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:04	\N
23337	21934	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:04	\N
23338	21935	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:04	\N
23339	21936	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:04	\N
23340	21937	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:04	\N
23341	21938	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:04	\N
23342	21939	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:04	\N
23343	21940	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:04	\N
23344	21941	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:04	\N
23345	21942	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:04	\N
23346	21943	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:04	\N
23347	21944	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:04	\N
23348	21945	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:04	\N
23349	21946	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:04	\N
23350	21947	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:04	\N
23351	21948	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:04	\N
23352	21949	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:04	\N
23353	21950	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:04	\N
23354	21951	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:04	\N
23355	21952	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:04	\N
23356	21953	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:04	\N
23357	21954	DEPUTE	1996-10-01 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:04	\N
23358	21955	DEPUTE	1968-07-11 00:00:00	\N	1972-04-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:04	\N
23359	21956	DEPUTE	1981-07-02 00:00:00	\N	1983-11-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:04	\N
23360	21957	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:04	\N
23361	21958	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:04	\N
23362	21959	SECAN	1994-04-02 00:00:00	\N	1995-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:04	\N
23363	21960	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:04	\N
23364	21961	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:04	\N
23365	21962	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:05	\N
23366	21963	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:05	\N
23367	21964	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:05	\N
23368	21965	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:05	\N
23369	21966	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:05	\N
23370	21967	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:05	\N
23371	21968	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:05	\N
23372	21969	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:05	\N
23373	21970	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:05	\N
23374	21971	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:05	\N
23375	21972	QUESTAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:05	\N
23376	21973	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:05	\N
23377	21974	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:05	\N
23378	21975	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:05	\N
23379	21976	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:05	\N
24775	23372	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24776	23373	DEPUTE	1986-09-30 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24777	23374	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24778	23375	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24779	23376	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24780	23377	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24781	23378	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24782	23379	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24783	23380	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24784	23381	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24785	23382	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24786	23383	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24787	23384	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24788	23385	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24789	23386	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24790	23387	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24791	23388	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24792	23389	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24793	23390	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24794	23391	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24795	23392	DEPUTE	1995-09-24 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24796	23393	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24797	23394	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24798	23395	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24799	23396	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24800	23397	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24801	23398	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24802	23399	DEPUTE	2002-06-19 00:00:00	\N	2002-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24803	23400	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24804	23401	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24805	23402	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24806	23403	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24807	23404	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:44	\N
24808	23405	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24809	23406	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24810	23407	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24811	23408	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24812	23409	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24813	23410	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24814	23411	VICPDTAN	1987-04-02 00:00:00	\N	1988-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24815	23412	SECAN	1991-04-02 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24816	23413	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24817	23414	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24818	23415	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24819	23416	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24820	23417	DEPUTE	1997-06-01 00:00:00	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24821	23418	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24822	23419	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24823	23420	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24824	23421	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24825	23422	DEPUTE	1981-07-02 00:00:00	\N	1982-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24826	23423	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24827	23424	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24828	23425	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24829	23426	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24830	23427	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24831	23428	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24832	23429	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24833	23430	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24834	23431	DEPUTE	1995-12-11 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24835	23432	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24836	23433	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24837	23434	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24838	23435	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24839	23436	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24840	23437	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24841	23438	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24842	23439	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24843	23440	DEPUTE	1993-04-02 00:00:00	\N	1996-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24844	23441	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24845	23442	DEPUTE	1981-07-02 00:00:00	\N	1985-08-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24846	23443	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24847	23444	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24848	23445	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24849	23446	VICPDTAN	1991-04-02 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24850	23447	VICPDTAN	1998-10-28 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24851	23448	VICPDTAN	1999-10-01 00:00:00	\N	2000-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24852	23449	PDTAN	2000-03-29 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24853	23450	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24854	23451	DEPUTE	1981-07-22 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24855	23452	DEPUTE	1986-09-30 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24856	23453	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24857	23454	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24858	23455	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24859	23456	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24860	23457	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24861	23458	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24862	23459	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:45	\N
24863	23460	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:46	\N
24864	23461	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:46	\N
24865	23462	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:46	\N
24866	23463	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:46	\N
24867	23464	DEPUTE	1973-04-03 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:46	\N
26168	24765	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:22	\N
26169	24766	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:22	\N
26170	24767	DEPUTE	1978-04-03 00:00:00	\N	1978-05-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:23	\N
26171	24768	DEPUTE	1973-04-02 00:00:00	\N	1976-02-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:23	\N
26172	24769	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:23	\N
26173	24770	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:23	\N
26174	24771	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:23	\N
26175	24772	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:23	\N
26176	24773	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:23	\N
26177	24774	DEPUTE	1997-05-25 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:23	\N
26178	24775	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:23	\N
26179	24776	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:23	\N
26180	24777	DEPUTE	1996-10-20 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:23	\N
26181	24778	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:23	\N
26182	24779	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:23	\N
26183	24780	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:23	\N
26184	24781	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:23	\N
26185	24782	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:23	\N
26186	24783	DEPUTE	1988-06-06 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:23	\N
26187	24784	DEPUTE	1993-04-02 00:00:00	\N	1996-02-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:23	\N
26188	24785	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:23	\N
26189	24786	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:23	\N
26190	24787	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:23	\N
26191	24788	DEPUTE	2005-07-03 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:23	\N
26192	24789	DEPUTE	2010-04-23 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:23	\N
26193	24790	DEPUTE	2014-12-15 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:23	\N
26194	24791	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:23	\N
26195	24792	DEPUTE	1999-07-23 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:23	\N
26196	24793	DEPUTE	1982-05-24 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:23	\N
26197	24794	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:23	\N
26198	24795	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:23	\N
26199	24796	DEPUTE	1993-05-24 00:00:00	\N	1995-09-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:24	\N
26200	24797	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:24	\N
26201	24798	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:24	\N
26202	24799	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:24	\N
26203	24800	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:24	\N
26204	24801	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:24	\N
26205	24802	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:24	\N
26206	24803	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:24	\N
26207	24804	DEPUTE	1988-06-13 00:00:00	\N	1990-11-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:24	\N
26208	24805	DEPUTE	1997-06-01 00:00:00	\N	2001-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:24	\N
26209	24806	PDTAN	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:24	\N
26210	24807	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:24	\N
26211	24808	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:24	\N
26212	24809	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:24	\N
26213	24810	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:24	\N
26214	24811	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:24	\N
26215	24812	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:24	\N
26216	24813	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:24	\N
26217	24814	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:24	\N
26218	24815	DEPUTE	1974-09-29 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:24	\N
26219	24816	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:24	\N
26220	24817	DEPUTE	1968-07-11 00:00:00	\N	1968-08-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:24	\N
26221	24818	DEPUTE	1969-10-19 00:00:00	\N	1971-03-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:24	\N
26222	24819	DEPUTE	1973-04-02 00:00:00	\N	1973-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:24	\N
26223	24820	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:24	\N
26224	24821	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:24	\N
26225	24822	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:24	\N
26226	24823	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:24	\N
26227	24824	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:24	\N
26228	24825	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:24	\N
26229	24826	VICPDTAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:24	\N
26230	24827	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:24	\N
26231	24828	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:24	\N
26232	24829	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:24	\N
26233	24830	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:25	\N
26234	24831	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:25	\N
26235	24832	DEPUTE	1988-06-13 00:00:00	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:25	\N
26236	24833	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:25	\N
26237	24834	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:25	\N
26238	24835	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:25	\N
26239	24836	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:25	\N
26240	24837	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:25	\N
26241	24838	DEPUTE	1988-06-06 00:00:00	\N	1991-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:25	\N
26242	24839	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:25	\N
26243	24840	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:25	\N
26244	24841	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:25	\N
26245	24842	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:25	\N
26246	24843	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:25	\N
26247	24844	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:25	\N
26248	24845	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:25	\N
26249	24846	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:25	\N
26250	24847	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:25	\N
26251	24848	SECAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:25	\N
26252	24849	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:25	\N
26253	24850	DEPUTE	2001-11-20 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:25	\N
26254	24851	DEPUTE	1992-05-03 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:25	\N
26255	24852	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:25	\N
26256	24853	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:25	\N
26257	24854	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:25	\N
26258	24855	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:25	\N
26259	24856	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:25	\N
26260	24857	VICPDTAN	1994-04-02 00:00:00	\N	1995-05-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:25	\N
27563	26160	DEPUTE	1976-02-13 00:00:00	\N	1976-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27564	26161	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27565	26162	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27566	26163	DEPUTE	1978-04-02 00:00:00	\N	1980-09-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27567	26164	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27568	26165	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27569	26166	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27570	26167	DEPUTE	1997-06-01 00:00:00	\N	2000-11-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27571	26168	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27572	26169	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27573	26170	DEPUTE	1997-06-01 00:00:00	\N	2000-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27574	26171	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27575	26172	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27576	26173	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27577	26174	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27578	26175	QUESTAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27579	26176	SECAN	2010-10-05 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27580	26177	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27581	26178	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27582	26179	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27583	26180	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27584	26181	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27585	26182	SECAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27586	26183	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27587	26184	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27588	26185	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27589	26186	SECAN	2002-06-26 00:00:00	\N	2004-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27590	26187	SECAN	2009-10-06 00:00:00	\N	2010-10-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27591	26188	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27592	26189	DEPUTE	1993-04-02 00:00:00	\N	1995-09-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27593	26190	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27594	26191	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27595	26192	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27596	26193	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27597	26194	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27598	26195	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27599	26196	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27600	26197	DEPUTE	1986-04-02 00:00:00	\N	1986-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27601	26198	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27602	26199	DEPUTE	1980-10-27 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27603	26200	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27604	26201	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27605	26202	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27606	26203	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27607	26204	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:03	\N
27608	26205	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:04	\N
27609	26206	DEPUTE	1995-06-18 00:00:00	\N	1995-12-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:04	\N
27610	26207	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:04	\N
27611	26208	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:04	\N
27612	26209	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:04	\N
27613	26210	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:04	\N
27614	26211	DEPUTE	1980-11-30 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:04	\N
27615	26212	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:04	\N
27616	26213	DEPUTE	1988-06-13 00:00:00	\N	1992-06-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:04	\N
27617	26214	DEPUTE	1987-12-17 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:04	\N
27618	26215	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:04	\N
27619	26216	DEPUTE	1973-04-02 00:00:00	\N	1977-03-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:04	\N
27620	26217	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:04	\N
27621	26218	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:04	\N
27622	26219	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:04	\N
27623	26220	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:04	\N
27624	26221	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:04	\N
27625	26222	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:04	\N
27626	26223	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:04	\N
27627	26224	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:04	\N
27628	26225	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:04	\N
27629	26226	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:04	\N
27630	26227	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:04	\N
27631	26228	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:04	\N
27632	26229	DEPUTE	1997-06-01 00:00:00	\N	1999-02-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:04	\N
27633	26230	VICPDTAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:04	\N
27634	26231	VICPDTAN	1998-10-01 00:00:00	\N	1999-02-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:04	\N
27635	26232	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:04	\N
27636	26233	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:04	\N
27637	26234	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:04	\N
27638	26235	DEPUTE	1999-08-29 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:04	\N
27639	26236	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:04	\N
27640	26237	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:04	\N
27641	26238	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:04	\N
27642	26239	SECAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:04	\N
27643	26240	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:04	\N
27644	26241	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:04	\N
27645	26242	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:04	\N
27646	26243	SECAN	2003-10-01 00:00:00	\N	2004-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:04	\N
27647	26244	SECAN	2006-10-04 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:04	\N
27648	26245	SECAN	2007-06-27 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:04	\N
27649	26246	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:04	\N
27650	26247	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:04	\N
27651	26248	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:05	\N
27652	26249	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:05	\N
27653	26250	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:05	\N
27654	26251	DEPUTE	2000-09-30 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:05	\N
27655	26252	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:05	\N
23380	21977	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:05	\N
23381	21978	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:05	\N
23382	21979	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:05	\N
23383	21980	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:05	\N
23384	21981	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:05	\N
23385	21982	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:05	\N
23386	21983	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:05	\N
23387	21984	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:05	\N
23388	21985	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:05	\N
23389	21986	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:05	\N
23390	21987	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:05	\N
23391	21988	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:05	\N
23392	21989	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:05	\N
23393	21990	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:05	\N
23394	21991	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:05	\N
23395	21992	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:05	\N
23396	21993	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:05	\N
23397	21994	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:05	\N
23398	21995	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:06	\N
23399	21996	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:06	\N
23400	21997	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:06	\N
23401	21998	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:06	\N
23402	21999	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:06	\N
23403	22000	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:06	\N
23404	22001	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:06	\N
23405	22002	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:06	\N
23406	22003	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:06	\N
23407	22004	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:06	\N
23408	22005	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:06	\N
23409	22006	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:06	\N
23410	22007	DEPUTE	1986-09-30 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:06	\N
23411	22008	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:06	\N
23412	22009	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:06	\N
23413	22010	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:06	\N
23414	22011	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:06	\N
23415	22012	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:06	\N
23416	22013	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:06	\N
23417	22014	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:06	\N
23418	22015	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:06	\N
23419	22016	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:06	\N
23420	22017	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:06	\N
23421	22018	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:06	\N
23422	22019	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:06	\N
23423	22020	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:07	\N
23424	22021	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:07	\N
23425	22022	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:07	\N
23426	22023	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:07	\N
23427	22024	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:07	\N
23428	22025	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:07	\N
23429	22026	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:07	\N
23430	22027	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:07	\N
23431	22028	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:07	\N
23432	22029	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:07	\N
23433	22030	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:07	\N
23434	22031	DEPUTE	1997-06-01 00:00:00	\N	1999-03-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:07	\N
23435	22032	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:07	\N
23436	22033	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:07	\N
23437	22034	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:07	\N
23438	22035	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:07	\N
23439	22036	DEPUTE	1990-01-18 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:07	\N
23440	22037	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:07	\N
23441	22038	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:07	\N
23442	22039	DEPUTE	2002-06-19 00:00:00	\N	2002-12-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:07	\N
23443	22040	DEPUTE	2003-03-24 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:07	\N
23444	22041	DEPUTE	1997-06-12 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:07	\N
23445	22042	DEPUTE	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:07	\N
23446	22043	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23447	22044	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23448	22045	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23449	22046	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23450	22047	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23451	22048	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23452	22049	DEPUTE	1988-06-13 00:00:00	\N	1988-11-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23453	22050	SECAN	1986-04-04 00:00:00	\N	1987-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23454	22051	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23455	22052	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23456	22053	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23457	22054	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23458	22055	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23459	22056	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23460	22057	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23461	22058	QUESTAN	2007-06-27 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23462	22059	QUESTAN	2012-06-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23463	22060	DEPUTE	1971-12-05 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23464	22061	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23465	22062	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23466	22063	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23467	22064	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23468	22065	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23469	22066	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23470	22067	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23471	22068	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23472	22069	SECAN	1986-04-04 00:00:00	\N	1987-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
24868	23465	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:46	\N
24869	23466	DEPUTE	1959-03-07 00:00:00	\N	1960-03-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:46	\N
24870	23467	DEPUTE	1962-12-06 00:00:00	\N	1963-01-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:46	\N
24871	23468	DEPUTE	1967-04-02 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:46	\N
24872	23469	DEPUTE	1968-07-11 00:00:00	\N	1972-08-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:46	\N
24873	23470	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:46	\N
24874	23471	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:46	\N
24875	23472	DEPUTE	1981-07-23 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:46	\N
24876	23473	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:46	\N
24877	23474	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:46	\N
24878	23475	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:46	\N
24879	23476	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:46	\N
24880	23477	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:46	\N
24881	23478	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:46	\N
24882	23479	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:46	\N
24883	23480	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:46	\N
24884	23481	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:46	\N
24885	23482	DEPUTE	1986-04-02 00:00:00	\N	1988-03-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:46	\N
24886	23483	DEPUTE	2002-07-19 00:00:00	\N	2005-01-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:46	\N
24887	23484	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:46	\N
24888	23485	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:46	\N
24889	23486	DEPUTE	2005-07-03 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:46	\N
24890	23487	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:46	\N
24891	23488	DEPUTE	1998-04-06 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:46	\N
24892	23489	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:46	\N
24893	23490	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:46	\N
24894	23491	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:46	\N
24895	23492	DEPUTE	1992-05-03 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:46	\N
24896	23493	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:46	\N
24897	23494	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:46	\N
24898	23495	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:46	\N
24899	23496	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:46	\N
24900	23497	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:46	\N
24901	23498	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:47	\N
24902	23499	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:47	\N
24903	23500	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:47	\N
24904	23501	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:47	\N
24905	23502	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:47	\N
24906	23503	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:47	\N
24907	23504	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:47	\N
24908	23505	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:47	\N
24909	23506	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:47	\N
24910	23507	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:47	\N
24911	23508	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:47	\N
24912	23509	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:47	\N
24913	23510	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:47	\N
24914	23511	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:47	\N
24915	23512	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:47	\N
24916	23513	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:47	\N
24917	23514	DEPUTE	2001-11-24 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:47	\N
24918	23515	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:47	\N
24919	23516	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:47	\N
24920	23517	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:47	\N
24921	23518	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:47	\N
24922	23519	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:47	\N
24923	23520	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:47	\N
24924	23521	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:47	\N
24925	23522	DEPUTE	2012-06-20 00:00:00	\N	2014-04-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:47	\N
24926	23523	DEPUTE	1996-11-27 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:47	\N
24927	23524	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:47	\N
24928	23525	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:47	\N
24929	23526	DEPUTE	2007-06-20 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:47	\N
24930	23527	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:47	\N
24931	23528	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:47	\N
24932	23529	DEPUTE	1994-02-08 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:47	\N
24933	23530	DEPUTE	2000-04-28 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:47	\N
24934	23531	DEPUTE	1981-07-02 00:00:00	\N	1981-12-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:47	\N
24935	23532	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:47	\N
24936	23533	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:47	\N
24937	23534	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:47	\N
24938	23535	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:48	\N
24939	23536	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:48	\N
24940	23537	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:48	\N
24941	23538	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:48	\N
24942	23539	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:48	\N
24943	23540	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:48	\N
24944	23541	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:48	\N
24945	23542	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:48	\N
24946	23543	DEPUTE	1988-07-29 00:00:00	\N	1988-11-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:48	\N
24947	23544	DEPUTE	1981-07-02 00:00:00	\N	1985-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:48	\N
24948	23545	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:48	\N
24949	23546	DEPUTE	1981-07-02 00:00:00	\N	1985-12-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:48	\N
24950	23547	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:48	\N
24951	23548	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:48	\N
24952	23549	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:48	\N
24953	23550	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:48	\N
24954	23551	VICPDTAN	1995-06-15 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:48	\N
24955	23552	VICPDTAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:48	\N
24956	23553	QUESTAN	2004-05-05 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:48	\N
24957	23554	QUESTAN	2002-06-26 00:00:00	\N	2004-05-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:48	\N
24958	23555	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:48	\N
24959	23556	SECAN	1992-04-02 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:48	\N
24960	23557	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:48	\N
26261	24858	VICPDTAN	1993-04-14 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:25	\N
26262	24859	VICPDTAN	2005-10-04 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:25	\N
26263	24860	VICPDTAN	2002-06-26 00:00:00	\N	2005-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:25	\N
26264	24861	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:25	\N
26265	24862	DEPUTE	1980-11-30 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:25	\N
26266	24863	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:25	\N
26267	24864	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:26	\N
26268	24865	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:26	\N
26269	24866	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:26	\N
26270	24867	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:26	\N
26271	24868	DEPUTE	1986-04-02 00:00:00	\N	1986-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:26	\N
26272	24869	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:26	\N
26273	24870	DEPUTE	1969-09-21 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:26	\N
26274	24871	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:26	\N
26275	24872	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:26	\N
26276	24873	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:26	\N
26277	24874	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:26	\N
26278	24875	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:26	\N
26279	24876	DEPUTE	1985-09-21 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:26	\N
26280	24877	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:26	\N
26281	24878	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:26	\N
26282	24879	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:26	\N
26283	24880	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:26	\N
26284	24881	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:26	\N
26285	24882	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:26	\N
26286	24883	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:26	\N
26287	24884	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:26	\N
26288	24885	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:26	\N
26289	24886	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:26	\N
26290	24887	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:26	\N
26291	24888	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:26	\N
26292	24889	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:26	\N
26293	24890	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:26	\N
26294	24891	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:27	\N
26295	24892	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:27	\N
26296	24893	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:27	\N
26297	24894	DEPUTE	1994-11-27 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:27	\N
26298	24895	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:27	\N
26299	24896	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:27	\N
26300	24897	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:27	\N
26301	24898	DEPUTE	1993-04-02 00:00:00	\N	1995-09-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:27	\N
26302	24899	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:27	\N
26303	24900	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:27	\N
26304	24901	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:27	\N
26305	24902	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:27	\N
26306	24903	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:27	\N
26307	24904	DEPUTE	1973-04-02 00:00:00	\N	1974-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:27	\N
26308	24905	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:27	\N
26309	24906	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:27	\N
26310	24907	DEPUTE	1993-04-02 00:00:00	\N	1994-08-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:27	\N
26311	24908	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:27	\N
26312	24909	DEPUTE	2011-07-30 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:27	\N
26313	24910	DEPUTE	1993-04-02 00:00:00	\N	1994-11-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:27	\N
26314	24911	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:27	\N
26315	24912	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:27	\N
26316	24913	DEPUTE	1995-09-13 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:27	\N
26317	24914	SECAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:27	\N
26318	24915	DEPUTE	2000-04-28 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:28	\N
26319	24916	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:28	\N
26320	24917	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:28	\N
26321	24918	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:28	\N
26322	24919	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:28	\N
26323	24920	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:28	\N
26324	24921	DEPUTE	1995-09-17 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:28	\N
26325	24922	VICPDTAN	1988-06-24 00:00:00	\N	1989-04-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:28	\N
26326	24923	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:28	\N
26327	24924	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:28	\N
26328	24925	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:28	\N
26329	24926	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:28	\N
26330	24927	SECAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:28	\N
26331	24928	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:28	\N
26332	24929	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:28	\N
26333	24930	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:28	\N
26334	24931	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:28	\N
26335	24932	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:28	\N
26336	24933	DEPUTE	1988-03-10 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:28	\N
26337	24934	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:28	\N
26338	24935	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:28	\N
26339	24936	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:28	\N
26340	24937	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:28	\N
26341	24938	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:28	\N
26342	24939	SECAN	2004-10-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:28	\N
26343	24940	SECAN	2009-10-06 00:00:00	\N	2010-10-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:28	\N
26344	24941	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:28	\N
26345	24942	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:28	\N
26346	24943	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:28	\N
26347	24944	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:28	\N
26348	24945	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:28	\N
26349	24946	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:28	\N
26350	24947	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:28	\N
26351	24948	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:28	\N
26352	24949	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:28	\N
26353	24950	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:28	\N
21722	20326	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:10	2017-06-19 09:39:23
21521	20125	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:54	2017-06-19 09:39:12
21638	20242	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:05	2017-06-19 09:39:19
27936	26533	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:13	\N
27937	26534	DEPUTE	2004-05-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:13	\N
27938	26535	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:13	\N
27939	26536	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:13	\N
27940	26537	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:13	\N
27941	26538	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:13	\N
27942	26539	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:13	\N
27943	26540	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:13	\N
27944	26541	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:13	\N
27945	26542	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:13	\N
27946	26543	DEPUTE	2007-06-20 00:00:00	\N	2010-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:13	\N
27947	26544	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:13	\N
27948	26545	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:13	\N
27949	26546	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:13	\N
27950	26547	DEPUTE	2012-06-20 00:00:00	\N	2016-03-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:13	\N
27951	26548	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:13	\N
27952	26549	DEPUTE	2007-06-20 00:00:00	\N	2008-04-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:13	\N
27953	26550	DEPUTE	2009-07-24 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:13	\N
27954	26551	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:13	\N
27955	26552	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:13	\N
27956	26553	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:13	\N
27957	26554	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:13	\N
27958	26555	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:13	\N
27959	26556	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:13	\N
27960	26557	DEPUTE	2007-06-26 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:13	\N
27961	26558	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:13	\N
27962	26559	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:14	\N
27963	26560	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:14	\N
27964	26561	DEPUTE	2005-01-24 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:14	\N
27965	26562	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:14	\N
27966	26563	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:14	\N
27967	26564	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:14	\N
27968	26565	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:14	\N
27969	26566	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:14	\N
27970	26567	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:14	\N
27971	26568	DEPUTE	1995-09-17 00:00:00	\N	1995-10-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:14	\N
27972	26569	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:14	\N
27973	26570	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:14	\N
27974	26571	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:14	\N
27975	26572	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:14	\N
27976	26573	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:14	\N
27977	26574	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:14	\N
27978	26575	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:14	\N
27979	26576	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:14	\N
27980	26577	SECAN	2000-04-06 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:14	\N
27981	26578	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:14	\N
27982	26579	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:14	\N
27983	26580	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:14	\N
27984	26581	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:14	\N
27985	26582	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:14	\N
27986	26583	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:14	\N
27987	26584	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:14	\N
27988	26585	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:14	\N
27989	26586	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:14	\N
27990	26587	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:14	\N
27991	26588	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:15	\N
27992	26589	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:15	\N
27993	26590	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:15	\N
27994	26591	DEPUTE	1993-04-02 00:00:00	\N	1995-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:15	\N
27995	26592	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:15	\N
27996	26593	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:15	\N
27997	26594	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:15	\N
27998	26595	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:15	\N
27999	26596	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:15	\N
28000	26597	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:15	\N
28001	26598	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:15	\N
28002	26599	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:15	\N
28003	26600	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:15	\N
28004	26601	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:15	\N
28005	26602	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:15	\N
28006	26603	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:15	\N
28007	26604	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:15	\N
28008	26605	SECAN	1995-06-01 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:15	\N
28009	26606	SECAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:15	\N
28010	26607	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:15	\N
28011	26608	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:15	\N
28012	26609	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:15	\N
28013	26610	SECAN	2002-06-26 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:15	\N
28014	26611	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:15	\N
28015	26612	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:16	\N
28016	26613	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:16	\N
28017	26614	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:16	\N
28018	26615	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:16	\N
28019	26616	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:16	\N
28020	26617	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:16	\N
28021	26618	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:16	\N
28022	26619	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:16	\N
28023	26620	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:16	\N
28024	26621	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:16	\N
23473	22070	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23474	22071	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23475	22072	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23476	22073	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23477	22074	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23478	22075	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23479	22076	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23480	22077	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23481	22078	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23482	22079	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23483	22080	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23484	22081	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23485	22082	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23486	22083	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23487	22084	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23488	22085	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23489	22086	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23490	22087	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23491	22088	DEPUTE	1997-06-01 00:00:00	\N	1998-09-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23492	22089	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23493	22090	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23494	22091	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23495	22092	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23496	22093	DEPUTE	2012-06-20 00:00:00	\N	2015-08-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23497	22094	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23498	22095	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23499	22096	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23500	22097	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23501	22098	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:08	\N
23502	22099	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23503	22100	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23504	22101	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23505	22102	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23506	22103	DEPUTE	1997-06-01 00:00:00	\N	2001-11-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23507	22104	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23508	22105	VICPDTAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23509	22106	QUESTAN	1997-06-13 00:00:00	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23510	22107	SECAN	2002-06-26 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23511	22108	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23512	22109	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23513	22110	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23514	22111	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23515	22112	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23516	22113	DEPUTE	1997-05-17 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23517	22114	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23518	22115	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23519	22116	DEPUTE	1995-06-26 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23520	22117	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23521	22118	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23522	22119	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23523	22120	VICPDTAN	2005-07-04 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23524	22121	VICPDTAN	2004-05-05 00:00:00	\N	2005-07-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23525	22122	DEPUTE	1992-07-04 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23526	22123	DEPUTE	1998-08-11 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23527	22124	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23528	22125	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23529	22126	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23530	22127	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23531	22128	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23532	22129	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23533	22130	DEPUTE	2010-12-14 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23534	22131	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23535	22132	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23536	22133	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23537	22134	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23538	22135	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23539	22136	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23540	22137	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23541	22138	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23542	22139	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23543	22140	DEPUTE	2002-06-19 00:00:00	\N	2004-01-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23544	22141	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23545	22142	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23546	22143	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23547	22144	DEPUTE	1987-05-15 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23548	22145	DEPUTE	1988-06-13 00:00:00	\N	1993-03-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23549	22146	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23550	22147	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23551	22148	DEPUTE	2013-04-20 00:00:00	\N	2013-04-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23552	22149	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:09	\N
23553	22150	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:10	\N
23554	22151	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:10	\N
23555	22152	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:10	\N
23556	22153	DEPUTE	1989-04-30 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:10	\N
23557	22154	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:10	\N
23558	22155	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:10	\N
23559	22156	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:10	\N
23560	22157	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:10	\N
23561	22158	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:10	\N
23562	22159	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:10	\N
23563	22160	DEPUTE	2007-06-20 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:10	\N
23564	22161	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:10	\N
23565	22162	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:10	\N
24961	23558	DEPUTE	1994-02-08 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:48	\N
24962	23559	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:49	\N
24963	23560	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:49	\N
24964	23561	DEPUTE	1978-04-03 00:00:00	\N	1978-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:49	\N
24965	23562	DEPUTE	1968-07-11 00:00:00	\N	1968-08-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:49	\N
24966	23563	DEPUTE	1973-04-02 00:00:00	\N	1973-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:49	\N
24967	23564	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:49	\N
24968	23565	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:49	\N
24969	23566	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:49	\N
24970	23567	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:49	\N
24971	23568	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:49	\N
24972	23569	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:49	\N
24973	23570	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:49	\N
24974	23571	DEPUTE	2007-07-20 00:00:00	\N	2010-12-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:49	\N
24975	23572	DEPUTE	1981-07-02 00:00:00	\N	1983-04-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:49	\N
24976	23573	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:49	\N
24977	23574	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:49	\N
24978	23575	DEPUTE	1997-06-12 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:49	\N
24979	23576	DEPUTE	1999-10-01 00:00:00	\N	2000-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:49	\N
24980	23577	DEPUTE	1991-02-04 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:49	\N
24981	23578	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:49	\N
24982	23579	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:49	\N
24983	23580	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:49	\N
24984	23581	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:49	\N
24985	23582	DEPUTE	1975-06-23 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:50	\N
24986	23583	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:50	\N
24987	23584	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:50	\N
24988	23585	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:50	\N
24989	23586	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:50	\N
24990	23587	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:50	\N
24991	23588	DEPUTE	1997-05-25 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:50	\N
24992	23589	DEPUTE	2002-06-19 00:00:00	\N	2004-04-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:50	\N
24993	23590	DEPUTE	2002-06-25 00:00:00	\N	2002-06-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:50	\N
24994	23591	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:50	\N
24995	23592	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:50	\N
24996	23593	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:50	\N
24997	23594	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:50	\N
24998	23595	DEPUTE	1980-11-30 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:50	\N
24999	23596	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:50	\N
25000	23597	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:50	\N
25001	23598	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:50	\N
25002	23599	DEPUTE	1993-04-02 00:00:00	\N	1993-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:50	\N
25003	23600	DEPUTE	1993-09-21 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:50	\N
25004	23601	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:50	\N
25005	23602	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:50	\N
25006	23603	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:50	\N
25007	23604	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:50	\N
25008	23605	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:50	\N
25009	23606	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:51	\N
25010	23607	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:51	\N
25011	23608	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:51	\N
25012	23609	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:51	\N
25013	23610	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:51	\N
25014	23611	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:51	\N
25015	23612	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:51	\N
25016	23613	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:51	\N
25017	23614	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:51	\N
25018	23615	DEPUTE	1986-02-27 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:51	\N
25019	23616	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:51	\N
25020	23617	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:51	\N
25021	23618	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:51	\N
25022	23619	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:51	\N
25023	23620	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:51	\N
25024	23621	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:51	\N
25025	23622	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:51	\N
25026	23623	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:51	\N
25027	23624	DEPUTE	1989-01-20 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:51	\N
25028	23625	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:51	\N
25029	23626	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:51	\N
25030	23627	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:51	\N
25031	23628	DEPUTE	1981-07-02 00:00:00	\N	1983-11-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25032	23629	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25033	23630	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25034	23631	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25035	23632	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25036	23633	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25037	23634	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25038	23635	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25039	23636	DEPUTE	1985-12-16 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25040	23637	DEPUTE	1992-05-05 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25041	23638	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25042	23639	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25043	23640	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25044	23641	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25045	23642	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25046	23643	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25047	23644	DEPUTE	1988-06-13 00:00:00	\N	1989-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25048	23645	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25049	23646	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25050	23647	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25051	23648	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25052	23649	DEPUTE	2002-06-19 00:00:00	\N	2007-01-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25053	23650	SECAN	1992-04-02 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
26354	24951	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:28	\N
26355	24952	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:28	\N
26356	24953	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:28	\N
26357	24954	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:28	\N
26358	24955	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:28	\N
26359	24956	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26360	24957	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26361	24958	DEPUTE	1988-06-13 00:00:00	\N	1992-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26362	24959	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26363	24960	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26364	24961	DEPUTE	1976-05-09 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26365	24962	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26366	24963	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26367	24964	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26368	24965	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26369	24966	DEPUTE	1973-04-02 00:00:00	\N	1973-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26370	24967	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26371	24968	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26372	24969	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26373	24970	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26374	24971	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26375	24972	DEPUTE	1975-06-15 00:00:00	\N	1976-09-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26376	24973	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26377	24974	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26378	24975	DEPUTE	1993-04-02 00:00:00	\N	1995-07-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26379	24976	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26380	24977	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26381	24978	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26382	24979	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26383	24980	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26384	24981	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26385	24982	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26386	24983	DEPUTE	2002-06-19 00:00:00	\N	2004-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26387	24984	SECAN	2002-06-26 00:00:00	\N	2004-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26388	24985	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26389	24986	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26390	24987	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26391	24988	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26392	24989	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26393	24990	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26394	24991	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26395	24992	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26396	24993	DEPUTE	1962-12-06 00:00:00	\N	1964-12-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26397	24994	DEPUTE	2011-05-06 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26398	24995	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26399	24996	DEPUTE	1995-12-10 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26400	24997	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26401	24998	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26402	24999	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26403	25000	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26404	25001	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26405	25002	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26406	25003	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26407	25004	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26408	25005	VICPDTAN	2002-06-26 00:00:00	\N	2004-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26409	25006	VICPDTAN	2007-06-27 00:00:00	\N	2009-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26410	25007	SECAN	2012-06-27 00:00:00	\N	2013-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26411	25008	DEPUTE	1982-08-30 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:29	\N
26412	25009	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:30	\N
26413	25010	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:30	\N
26414	25011	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:30	\N
26415	25012	DEPUTE	1981-07-24 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:30	\N
26416	25013	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:30	\N
26417	25014	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:30	\N
26418	25015	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:30	\N
26419	25016	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:30	\N
26420	25017	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:30	\N
26421	25018	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:30	\N
26422	25019	DEPUTE	1997-06-01 00:00:00	\N	2001-04-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:30	\N
26423	25020	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:30	\N
26424	25021	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:30	\N
26425	25022	DEPUTE	2009-07-24 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:30	\N
26426	25023	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:30	\N
26427	25024	VICPDTAN	1997-06-13 00:00:00	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:30	\N
26428	25025	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:30	\N
26429	25026	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:30	\N
26430	25027	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:30	\N
26431	25028	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:30	\N
26432	25029	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:30	\N
26433	25030	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:30	\N
26434	25031	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:30	\N
26435	25032	DEPUTE	1988-06-13 00:00:00	\N	1991-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:30	\N
26436	25033	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:30	\N
26437	25034	VICPDTAN	1988-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:30	\N
26438	25035	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:30	\N
26439	25036	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:30	\N
26440	25037	DEPUTE	1995-09-24 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:30	\N
26441	25038	DEPUTE	1997-05-25 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:30	\N
26442	25039	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:30	\N
26443	25040	DEPUTE	2005-03-14 00:00:00	\N	2005-07-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:30	\N
26444	25041	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:30	\N
26445	25042	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:30	\N
26446	25043	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:30	\N
28211	26808	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:21	\N
28212	26809	DEPUTE	1981-07-02 00:00:00	\N	1984-08-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:21	\N
28213	26810	DEPUTE	1990-01-25 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:21	\N
28214	26811	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:21	\N
28215	26812	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:21	\N
28216	26813	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:21	\N
28217	26814	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:21	\N
28218	26815	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:21	\N
28219	26816	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:21	\N
28220	26817	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:21	\N
28221	26818	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:21	\N
28222	26819	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:21	\N
28223	26820	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:21	\N
28224	26821	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:21	\N
28225	26822	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:21	\N
28226	26823	DEPUTE	1997-06-01 00:00:00	\N	1998-04-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:21	\N
28227	26824	DEPUTE	1998-02-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:21	\N
28228	26825	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:21	\N
28229	26826	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:21	\N
28230	26827	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:21	\N
28231	26828	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:21	\N
28232	26829	DEPUTE	1986-04-02 00:00:00	\N	1986-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:21	\N
28233	26830	DEPUTE	1986-08-25 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:21	\N
28234	26831	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:21	\N
28235	26832	DEPUTE	1988-06-13 00:00:00	\N	1992-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:21	\N
28236	26833	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:21	\N
28237	26834	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:21	\N
28238	26835	DEPUTE	2000-03-19 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:21	\N
28239	26836	DEPUTE	2000-03-20 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:21	\N
28240	26837	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:21	\N
28241	26838	DEPUTE	2007-06-20 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:21	\N
28242	26839	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:21	\N
28243	26840	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:21	\N
28244	26841	DEPUTE	2000-06-26 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:21	\N
28245	26842	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:21	\N
28246	26843	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:22	\N
28247	26844	SECAN	2006-12-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:22	\N
28248	26845	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:22	\N
28249	26846	DEPUTE	2000-10-22 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:22	\N
28250	26847	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:22	\N
28251	26848	DEPUTE	2001-04-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:22	\N
28252	26849	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:22	\N
28253	26850	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:22	\N
28254	26851	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:22	\N
28255	26852	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:22	\N
28256	26853	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:22	\N
28257	26854	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:22	\N
28258	26855	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:22	\N
28259	26856	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:22	\N
28260	26857	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:22	\N
28261	26858	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:22	\N
28262	26859	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:22	\N
28263	26860	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:22	\N
28264	26861	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:22	\N
28265	26862	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:22	\N
28266	26863	DEPUTE	2007-07-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:22	\N
28267	26864	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:22	\N
28268	26865	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:22	\N
28269	26866	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:22	\N
28270	26867	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:22	\N
28271	26868	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:22	\N
28272	26869	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:22	\N
28273	26870	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:22	\N
28274	26871	VICPDTAN	2008-09-26 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:22	\N
28275	26872	VICPDTAN	2012-06-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:22	\N
28276	26873	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:22	\N
28277	26874	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:22	\N
28278	26875	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:22	\N
28279	26876	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:23	\N
28280	26877	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:23	\N
28281	26878	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:23	\N
28282	26879	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:23	\N
28283	26880	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:23	\N
28284	26881	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:23	\N
28285	26882	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:23	\N
28286	26883	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:23	\N
28287	26884	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:23	\N
28288	26885	DEPUTE	2002-06-25 00:00:00	\N	2002-06-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:23	\N
28289	26886	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:23	\N
28290	26887	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:23	\N
28291	26888	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:23	\N
28292	26889	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:23	\N
28293	26890	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:23	\N
28294	26891	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:23	\N
28295	26892	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:23	\N
28296	26893	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:23	\N
28297	26894	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:23	\N
28298	26895	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:23	\N
28299	26896	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:23	\N
28300	26897	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:23	\N
28301	26898	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:23	\N
28302	26899	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:23	\N
28303	26900	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:23	\N
23566	22163	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:10	\N
23567	22164	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:10	\N
23568	22165	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:10	\N
23569	22166	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:10	\N
23570	22167	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:10	\N
23571	22168	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:10	\N
23572	22169	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:10	\N
23573	22170	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:10	\N
23574	22171	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:10	\N
23575	22172	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:10	\N
23576	22173	DEPUTE	1994-02-26 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:10	\N
23577	22174	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:10	\N
23578	22175	DEPUTE	1997-06-01 00:00:00	\N	2000-12-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:10	\N
23579	22176	DEPUTE	1968-07-11 00:00:00	\N	1968-08-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:10	\N
23580	22177	DEPUTE	1995-12-10 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:10	\N
23581	22178	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:10	\N
23582	22179	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:10	\N
23583	22180	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:10	\N
23584	22181	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:10	\N
23585	22182	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:10	\N
23586	22183	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:10	\N
23587	22184	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:10	\N
23588	22185	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:10	\N
23589	22186	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:11	\N
23590	22187	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:11	\N
23591	22188	DEPUTE	2007-06-20 00:00:00	\N	2010-06-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:11	\N
23592	22189	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:11	\N
23593	22190	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:11	\N
23594	22191	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:11	\N
23595	22192	DEPUTE	2012-06-20 00:00:00	\N	2017-04-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:11	\N
23596	22193	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:11	\N
23597	22194	DEPUTE	1988-06-06 00:00:00	\N	1988-11-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:11	\N
23598	22195	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:11	\N
23599	22196	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:11	\N
23600	22197	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:11	\N
23601	22198	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:11	\N
23602	22199	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:11	\N
23603	22200	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:11	\N
23604	22201	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:11	\N
23605	22202	SECAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:11	\N
23606	22203	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:11	\N
23607	22204	DEPUTE	1990-09-21 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:11	\N
23608	22205	DEPUTE	1981-07-02 00:00:00	\N	1983-04-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:11	\N
23609	22206	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:11	\N
23610	22207	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:11	\N
23611	22208	DEPUTE	1997-06-01 00:00:00	\N	1999-12-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:11	\N
23612	22209	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:11	\N
23613	22210	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:11	\N
23614	22211	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:11	\N
23615	22212	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:11	\N
23616	22213	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:11	\N
23617	22214	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:11	\N
23618	22215	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:11	\N
23619	22216	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:11	\N
23620	22217	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:11	\N
23621	22218	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:11	\N
23622	22219	DEPUTE	1997-06-01 00:00:00	\N	1999-10-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:11	\N
23623	22220	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:11	\N
23624	22221	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:11	\N
23625	22222	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:11	\N
23626	22223	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:12	\N
23627	22224	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:12	\N
23628	22225	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:12	\N
23629	22226	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:12	\N
23630	22227	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:12	\N
23631	22228	DEPUTE	1998-05-04 00:00:00	\N	1998-07-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:12	\N
23632	22229	DEPUTE	1998-09-27 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:12	\N
23633	22230	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:12	\N
23634	22231	DEPUTE	1986-04-02 00:00:00	\N	1987-10-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:12	\N
23635	22232	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:12	\N
23636	22233	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:12	\N
23637	22234	DEPUTE	1993-04-02 00:00:00	\N	1993-09-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:12	\N
23638	22235	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:12	\N
23639	22236	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:12	\N
23640	22237	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:12	\N
23641	22238	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:12	\N
23642	22239	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:12	\N
23643	22240	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:12	\N
23644	22241	VICPDTAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:12	\N
23645	22242	VICPDTAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:12	\N
23646	22243	VICPDTAN	1998-03-24 00:00:00	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:12	\N
23647	22244	VICPDTAN	1999-02-10 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:12	\N
23648	22245	VICPDTAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:12	\N
23649	22246	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:12	\N
23650	22247	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:12	\N
23651	22248	DEPUTE	1988-06-13 00:00:00	\N	1991-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:12	\N
23652	22249	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:12	\N
23653	22250	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:12	\N
23654	22251	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:12	\N
23655	22252	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:12	\N
23656	22253	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:12	\N
23657	22254	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:13	\N
23658	22255	DEPUTE	1999-03-15 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:13	\N
25054	23651	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25055	23652	SECAN	1994-04-02 00:00:00	\N	1995-05-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25056	23653	VICPDTAN	1995-06-01 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25057	23654	DEPUTE	2002-06-19 00:00:00	\N	2006-09-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25058	23655	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25059	23656	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25060	23657	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25061	23658	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25062	23659	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25063	23660	DEPUTE	1988-12-19 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25064	23661	DEPUTE	1993-05-02 00:00:00	\N	1995-06-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25065	23662	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25066	23663	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25067	23664	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25068	23665	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25069	23666	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25070	23667	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25071	23668	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25072	23669	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25073	23670	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25074	23671	DEPUTE	1988-06-06 00:00:00	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25075	23672	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25076	23673	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25077	23674	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25078	23675	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25079	23676	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25080	23677	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25081	23678	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25082	23679	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25083	23680	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25084	23681	VICPDTAN	1988-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25085	23682	DEPUTE	1995-12-14 00:00:00	\N	1996-02-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25086	23683	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25087	23684	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25088	23685	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25089	23686	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25090	23687	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25091	23688	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:52	\N
25092	23689	DEPUTE	1998-01-25 00:00:00	\N	1999-12-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:53	\N
25093	23690	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:53	\N
25094	23691	DEPUTE	1968-08-13 00:00:00	\N	1971-11-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:53	\N
25095	23692	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:53	\N
25096	23693	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:53	\N
25097	23694	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:53	\N
25098	23695	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:53	\N
25099	23696	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:53	\N
25100	23697	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:53	\N
25101	23698	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:53	\N
25102	23699	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:53	\N
25103	23700	DEPUTE	2007-06-20 00:00:00	\N	2011-05-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:53	\N
25104	23701	DEPUTE	1993-05-02 00:00:00	\N	1995-07-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:53	\N
25105	23702	DEPUTE	1995-12-08 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:53	\N
25106	23703	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:53	\N
25107	23704	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:53	\N
25108	23705	DEPUTE	1981-07-02 00:00:00	\N	1986-03-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:53	\N
25109	23706	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:53	\N
25110	23707	DEPUTE	1986-12-10 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:53	\N
25111	23708	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:53	\N
25112	23709	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:53	\N
25113	23710	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:53	\N
25114	23711	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:53	\N
25115	23712	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:53	\N
25116	23713	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:53	\N
25117	23714	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:53	\N
25118	23715	DEPUTE	1984-08-24 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:53	\N
25119	23716	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:53	\N
25120	23717	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:53	\N
25121	23718	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:53	\N
25122	23719	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:53	\N
25123	23720	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:53	\N
25124	23721	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:53	\N
25125	23722	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:53	\N
25126	23723	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:53	\N
25127	23724	DEPUTE	2007-06-20 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:53	\N
25128	23725	DEPUTE	1993-04-02 00:00:00	\N	1996-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:53	\N
25129	23726	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:53	\N
25130	23727	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:53	\N
25131	23728	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:53	\N
25132	23729	DEPUTE	1967-04-02 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:53	\N
25133	23730	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:54	\N
25134	23731	DEPUTE	1973-04-03 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:54	\N
25135	23732	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:54	\N
25136	23733	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:54	\N
25137	23734	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:54	\N
25138	23735	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:54	\N
25139	23736	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:54	\N
25140	23737	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:54	\N
25141	23738	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:54	\N
25142	23739	DEPUTE	1964-12-12 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:54	\N
25143	23740	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:54	\N
25144	23741	DEPUTE	1968-07-11 00:00:00	\N	1968-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:54	\N
25145	23742	DEPUTE	1968-12-15 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:54	\N
25146	23743	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:54	\N
26447	25044	DEPUTE	2007-06-20 00:00:00	\N	2008-02-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:30	\N
26448	25045	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:30	\N
26449	25046	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:30	\N
26450	25047	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:30	\N
26451	25048	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:30	\N
26452	25049	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:30	\N
26453	25050	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:30	\N
26454	25051	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:31	\N
26455	25052	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:31	\N
26456	25053	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:31	\N
26457	25054	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:31	\N
26458	25055	SECAN	2004-10-01 00:00:00	\N	2005-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:31	\N
26459	25056	SECAN	2008-10-01 00:00:00	\N	2009-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:31	\N
26460	25057	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:31	\N
26461	25058	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:31	\N
26462	25059	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:31	\N
26463	25060	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:31	\N
26464	25061	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:31	\N
26465	25062	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:31	\N
26466	25063	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:31	\N
26467	25064	DEPUTE	2007-06-20 00:00:00	\N	2011-07-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:31	\N
26468	25065	DEPUTE	2012-06-20 00:00:00	\N	2016-08-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:31	\N
26469	25066	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:31	\N
26470	25067	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:31	\N
26471	25068	DEPUTE	1981-07-02 00:00:00	\N	1983-02-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:31	\N
26472	25069	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:31	\N
26473	25070	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:31	\N
26474	25071	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:31	\N
26475	25072	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:31	\N
26476	25073	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:31	\N
26477	25074	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:31	\N
26478	25075	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:31	\N
26479	25076	DEPUTE	2012-06-26 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:31	\N
26480	25077	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:31	\N
26481	25078	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:31	\N
26482	25079	DEPUTE	1993-05-02 00:00:00	\N	1995-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:31	\N
26483	25080	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:32	\N
26484	25081	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:32	\N
26485	25082	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:32	\N
26486	25083	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:32	\N
26487	25084	SECAN	2007-06-27 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:32	\N
26488	25085	SECAN	2010-10-05 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:32	\N
26489	25086	DEPUTE	2008-02-04 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:32	\N
26490	25087	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:32	\N
26491	25088	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:32	\N
26492	25089	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:32	\N
26493	25090	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:32	\N
26494	25091	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:32	\N
26495	25092	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:32	\N
26496	25093	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:32	\N
26497	25094	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:32	\N
26498	25095	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:32	\N
26499	25096	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:32	\N
26500	25097	DEPUTE	1997-06-01 00:00:00	\N	2000-04-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:32	\N
26501	25098	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:32	\N
26502	25099	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:32	\N
26503	25100	SECAN	1988-06-24 00:00:00	\N	1992-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:32	\N
26504	25101	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:32	\N
26505	25102	SECAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:32	\N
26506	25103	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:32	\N
26507	25104	DEPUTE	1978-04-02 00:00:00	\N	1978-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:32	\N
26508	25105	DEPUTE	1986-04-02 00:00:00	\N	1986-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:32	\N
26509	25106	DEPUTE	1986-10-01 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:32	\N
26510	25107	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:32	\N
26511	25108	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:32	\N
26512	25109	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:32	\N
26513	25110	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:32	\N
26514	25111	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:32	\N
26515	25112	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:32	\N
26516	25113	PDTAN	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:32	\N
26517	25114	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:33	\N
26518	25115	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:33	\N
26519	25116	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:33	\N
26520	25117	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:33	\N
26521	25118	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:33	\N
26522	25119	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:33	\N
26523	25120	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:33	\N
26524	25121	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:33	\N
26525	25122	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:33	\N
26526	25123	DEPUTE	1983-04-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:33	\N
26527	25124	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:33	\N
26528	25125	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:33	\N
26529	25126	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:33	\N
26530	25127	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:33	\N
26531	25128	DEPUTE	1996-05-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:33	\N
26532	25129	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:33	\N
26533	25130	DEPUTE	1989-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:33	\N
26534	25131	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:33	\N
26535	25132	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:33	\N
26536	25133	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:33	\N
26537	25134	SECAN	1987-04-02 00:00:00	\N	1988-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:33	\N
26538	25135	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:33	\N
26539	25136	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:33	\N
27656	26253	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:05	\N
27657	26254	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:05	\N
27658	26255	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:05	\N
27659	26256	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:05	\N
27660	26257	SECAN	2002-06-26 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:05	\N
27661	26258	SECAN	2007-06-27 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:05	\N
27662	26259	SECAN	2012-06-27 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:05	\N
27663	26260	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:05	\N
27664	26261	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:05	\N
27665	26262	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:05	\N
27666	26263	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:05	\N
27667	26264	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:05	\N
27668	26265	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:05	\N
27669	26266	DEPUTE	1997-06-01 00:00:00	\N	1998-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:05	\N
27670	26267	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:05	\N
27671	26268	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:05	\N
27672	26269	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:05	\N
27673	26270	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:05	\N
27674	26271	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:05	\N
27675	26272	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:05	\N
27676	26273	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:05	\N
27677	26274	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:05	\N
27678	26275	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:05	\N
27679	26276	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:05	\N
27680	26277	DEPUTE	1997-06-01 00:00:00	\N	1998-09-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:05	\N
27681	26278	DEPUTE	1978-04-03 00:00:00	\N	1978-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:05	\N
27682	26279	DEPUTE	1958-12-09 00:00:00	\N	1962-05-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:05	\N
27683	26280	DEPUTE	1962-12-06 00:00:00	\N	1963-01-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:05	\N
27684	26281	DEPUTE	1967-04-03 00:00:00	\N	1967-05-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:05	\N
27685	26282	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:05	\N
27686	26283	DEPUTE	1973-04-02 00:00:00	\N	1973-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:05	\N
27687	26284	DEPUTE	1982-01-18 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:05	\N
27688	26285	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:05	\N
27689	26286	DEPUTE	1993-04-02 00:00:00	\N	1995-09-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:05	\N
27690	26287	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:05	\N
27691	26288	DEPUTE	1973-04-02 00:00:00	\N	1975-07-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:05	\N
27692	26289	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:05	\N
27693	26290	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:06	\N
27694	26291	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:06	\N
27695	26292	DEPUTE	2007-07-20 00:00:00	\N	2010-12-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:06	\N
27696	26293	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:06	\N
27697	26294	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:06	\N
27698	26295	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:06	\N
27699	26296	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:06	\N
27700	26297	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:06	\N
27701	26298	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:06	\N
27702	26299	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:06	\N
27703	26300	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:06	\N
27704	26301	DEPUTE	2005-07-03 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:06	\N
27705	26302	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:06	\N
27706	26303	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:06	\N
27707	26304	DEPUTE	2012-07-21 00:00:00	\N	2014-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:06	\N
27708	26305	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:06	\N
27709	26306	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:06	\N
27710	26307	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:06	\N
27711	26308	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:06	\N
27712	26309	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:06	\N
27713	26310	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:06	\N
27714	26311	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:06	\N
27715	26312	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:06	\N
27716	26313	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:06	\N
27717	26314	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:06	\N
27718	26315	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:07	\N
27719	26316	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:07	\N
27720	26317	DEPUTE	2004-05-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:07	\N
27721	26318	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:07	\N
27722	26319	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:07	\N
27723	26320	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:07	\N
27724	26321	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:07	\N
27725	26322	VICPDTAN	2011-07-07 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:07	\N
27726	26323	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:07	\N
27727	26324	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:07	\N
27728	26325	DEPUTE	2009-02-15 00:00:00	\N	2010-12-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:07	\N
27729	26326	DEPUTE	2012-06-20 00:00:00	\N	2016-01-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:07	\N
27730	26327	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:07	\N
27731	26328	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:07	\N
27732	26329	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:07	\N
27733	26330	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:07	\N
27734	26331	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:07	\N
27735	26332	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:07	\N
27736	26333	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:07	\N
27737	26334	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:07	\N
27738	26335	DEPUTE	2007-07-20 00:00:00	\N	2010-12-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:07	\N
27739	26336	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:07	\N
27740	26337	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:07	\N
27741	26338	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:07	\N
27742	26339	DEPUTE	2004-05-15 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:07	\N
27743	26340	DEPUTE	2007-04-27 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:07	\N
27744	26341	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:07	\N
27745	26342	DEPUTE	2007-06-20 00:00:00	\N	2010-12-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:07	\N
27746	26343	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:08	\N
27747	26344	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:08	\N
27748	26345	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:08	\N
23659	22256	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:13	\N
23660	22257	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:13	\N
23661	22258	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:13	\N
23662	22259	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:13	\N
23663	22260	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:13	\N
23664	22261	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:13	\N
23665	22262	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:13	\N
23666	22263	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:13	\N
23667	22264	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:13	\N
29245	27842	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:55	\N
23668	22265	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:13	\N
23669	22266	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:13	\N
23670	22267	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:13	\N
23671	22268	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:13	\N
23672	22269	DEPUTE	1988-12-19 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:13	\N
23673	22270	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:13	\N
23674	22271	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:13	\N
23675	22272	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:13	\N
23676	22273	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:13	\N
23677	22274	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:13	\N
23678	22275	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:13	\N
23679	22276	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:13	\N
23680	22277	DEPUTE	2017-06-16 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:13	\N
23681	22278	DEPUTE	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:13	\N
23682	22279	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:14	\N
23683	22280	DEPUTE	1993-05-02 00:00:00	\N	1995-07-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:14	\N
23684	22281	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:14	\N
23685	22282	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:14	\N
23686	22283	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:14	\N
23687	22284	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:14	\N
23688	22285	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:14	\N
23689	22286	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:14	\N
23690	22287	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:14	\N
23691	22288	DEPUTE	2007-06-20 00:00:00	\N	2010-06-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:14	\N
23692	22289	QUESTAN	1995-06-01 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:14	\N
23693	22290	QUESTAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:14	\N
23694	22291	QUESTAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:14	\N
23695	22292	QUESTAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:14	\N
23696	22293	QUESTAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:14	\N
23697	22294	QUESTAN	2002-06-26 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:14	\N
23698	22295	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:14	\N
23699	22296	DEPUTE	1993-05-02 00:00:00	\N	1995-05-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:14	\N
23700	22297	DEPUTE	1981-07-02 00:00:00	\N	1981-12-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:14	\N
23701	22298	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:14	\N
23702	22299	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:14	\N
23703	22300	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:14	\N
23704	22301	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:14	\N
23705	22302	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:14	\N
23706	22303	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:15	\N
23707	22304	DEPUTE	1986-04-14 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:15	\N
23708	22305	DEPUTE	1996-03-26 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:15	\N
23709	22306	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:15	\N
23710	22307	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:15	\N
23711	22308	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:15	\N
23712	22309	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:15	\N
23713	22310	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:15	\N
23714	22311	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:15	\N
23715	22312	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:15	\N
23716	22313	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:15	\N
23717	22314	DEPUTE	1981-07-02 00:00:00	\N	1981-07-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:15	\N
23718	22315	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:15	\N
23719	22316	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:15	\N
23720	22317	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:15	\N
23721	22318	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:15	\N
23722	22319	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:15	\N
23723	22320	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:15	\N
23724	22321	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:16	\N
23725	22322	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:16	\N
23726	22323	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:16	\N
23727	22324	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:16	\N
23728	22325	DEPUTE	1986-04-02 00:00:00	\N	1986-04-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:16	\N
23729	22326	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:16	\N
23730	22327	DEPUTE	1988-09-19 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:16	\N
23731	22328	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:16	\N
23732	22329	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:16	\N
23733	22330	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:16	\N
23734	22331	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:16	\N
23735	22332	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:16	\N
23736	22333	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:16	\N
23737	22334	DEPUTE	1981-07-24 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:16	\N
23738	22335	DEPUTE	1992-02-03 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:16	\N
23739	22336	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:16	\N
23740	22337	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:16	\N
23741	22338	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:16	\N
23742	22339	DEPUTE	2005-09-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:16	\N
23743	22340	DEPUTE	2007-06-20 00:00:00	\N	2010-04-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:16	\N
23744	22341	DEPUTE	2010-12-14 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:16	\N
23745	22342	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:16	\N
23746	22343	VICPDTAN	2002-06-26 00:00:00	\N	2003-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:16	\N
23747	22344	VICPDTAN	2003-10-01 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:16	\N
23748	22345	VICPDTAN	2007-06-27 00:00:00	\N	2008-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:16	\N
23749	22346	DEPUTE	1997-06-01 00:00:00	\N	2001-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:16	\N
23750	22347	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:16	\N
23751	22348	DEPUTE	1990-08-18 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:16	\N
22540	21137	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-23 03:44:31	\N
25147	23744	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:54	\N
25148	23745	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:54	\N
25149	23746	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:54	\N
25150	23747	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:54	\N
25151	23748	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:54	\N
25152	23749	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:54	\N
25153	23750	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:54	\N
25154	23751	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:54	\N
25155	23752	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:54	\N
25156	23753	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:54	\N
25157	23754	DEPUTE	1993-05-02 00:00:00	\N	1995-05-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:54	\N
25158	23755	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:54	\N
25159	23756	DEPUTE	2001-07-29 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:54	\N
25160	23757	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:54	\N
25161	23758	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:54	\N
25162	23759	DEPUTE	1993-04-02 00:00:00	\N	1995-09-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:54	\N
25163	23760	DEPUTE	2004-06-21 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:54	\N
25164	23761	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:54	\N
25165	23762	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:54	\N
25166	23763	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:54	\N
25167	23764	DEPUTE	1981-07-02 00:00:00	\N	1984-01-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:54	\N
25168	23765	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:54	\N
25169	23766	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:54	\N
25170	23767	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:55	\N
25171	23768	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:55	\N
25172	23769	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:55	\N
25173	23770	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:55	\N
25174	23771	VICPDTAN	2011-10-03 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:55	\N
25175	23772	VICPDTAN	2012-06-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:55	\N
25176	23773	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:55	\N
25177	23774	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:55	\N
25178	23775	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:55	\N
25179	23776	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:55	\N
25180	23777	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:55	\N
25181	23778	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:55	\N
25182	23779	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:55	\N
25183	23780	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:55	\N
25184	23781	DEPUTE	1977-03-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:55	\N
25185	23782	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:55	\N
25186	23783	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:55	\N
25187	23784	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:55	\N
25188	23785	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:55	\N
25189	23786	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:55	\N
25190	23787	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:55	\N
25191	23788	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:55	\N
25192	23789	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:55	\N
25193	23790	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:55	\N
25194	23791	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:55	\N
25195	23792	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:55	\N
25196	23793	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:55	\N
25197	23794	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:55	\N
25198	23795	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:55	\N
25199	23796	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:55	\N
25200	23797	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:55	\N
25201	23798	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:55	\N
25202	23799	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:55	\N
25203	23800	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:55	\N
25204	23801	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:55	\N
25205	23802	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:56	\N
25206	23803	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:56	\N
25207	23804	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:56	\N
25208	23805	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:56	\N
25209	23806	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:56	\N
25210	23807	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:56	\N
25211	23808	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:56	\N
25212	23809	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:56	\N
25213	23810	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:56	\N
25214	23811	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:56	\N
25215	23812	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:56	\N
25216	23813	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:56	\N
25217	23814	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:56	\N
25218	23815	DEPUTE	2010-12-15 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:56	\N
25219	23816	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:56	\N
25220	23817	DEPUTE	1988-06-13 00:00:00	\N	1990-11-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:56	\N
25221	23818	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:56	\N
25222	23819	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:56	\N
25223	23820	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:56	\N
25224	23821	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:56	\N
25225	23822	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:56	\N
25226	23823	DEPUTE	2004-01-14 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:56	\N
25227	23824	DEPUTE	2007-06-20 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:56	\N
25228	23825	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:56	\N
25229	23826	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:56	\N
25230	23827	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:57	\N
25231	23828	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:57	\N
25232	23829	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:57	\N
25233	23830	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:57	\N
25234	23831	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:57	\N
25235	23832	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:57	\N
25236	23833	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:57	\N
25237	23834	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:57	\N
25238	23835	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:57	\N
26540	25137	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:33	\N
26541	25138	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:33	\N
26542	25139	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:34	\N
26543	25140	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:34	\N
26544	25141	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:34	\N
26545	25142	DEPUTE	1973-04-02 00:00:00	\N	1974-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:34	\N
26546	25143	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:34	\N
26547	25144	DEPUTE	1978-04-03 00:00:00	\N	1978-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:34	\N
26548	25145	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:34	\N
26549	25146	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:34	\N
26550	25147	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:34	\N
26551	25148	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:34	\N
26552	25149	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:34	\N
26553	25150	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:34	\N
26554	25151	DEPUTE	1981-07-02 00:00:00	\N	1983-04-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:34	\N
26555	25152	DEPUTE	1980-11-30 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:34	\N
26556	25153	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:34	\N
26557	25154	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:34	\N
26558	25155	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:34	\N
26559	25156	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:34	\N
26560	25157	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:34	\N
26561	25158	DEPUTE	1973-04-02 00:00:00	\N	1977-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:34	\N
26562	25159	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:34	\N
26563	25160	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:34	\N
26564	25161	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:34	\N
26565	25162	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:34	\N
26566	25163	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:34	\N
26567	25164	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:35	\N
26568	25165	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:35	\N
26569	25166	DEPUTE	1973-04-02 00:00:00	\N	1973-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:35	\N
26570	25167	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:35	\N
26571	25168	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:35	\N
26572	25169	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:35	\N
26573	25170	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:35	\N
26574	25171	DEPUTE	1973-04-02 00:00:00	\N	1975-06-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:35	\N
26575	25172	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:35	\N
26576	25173	DEPUTE	1989-12-04 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:35	\N
26577	25174	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:35	\N
26578	25175	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:35	\N
26579	25176	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:35	\N
26580	25177	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:35	\N
26581	25178	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:35	\N
26582	25179	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:35	\N
26583	25180	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:35	\N
26584	25181	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:35	\N
26585	25182	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:35	\N
26586	25183	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:35	\N
26587	25184	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:36	\N
26588	25185	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:36	\N
26589	25186	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:36	\N
26590	25187	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:36	\N
26591	25188	VICPDTAN	1987-04-02 00:00:00	\N	1988-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:36	\N
26592	25189	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:36	\N
26593	25190	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:36	\N
26594	25191	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:36	\N
26595	25192	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:36	\N
26596	25193	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:36	\N
26597	25194	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:36	\N
26598	25195	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:36	\N
26599	25196	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:36	\N
26600	25197	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:36	\N
26601	25198	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:36	\N
26602	25199	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:36	\N
26603	25200	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:36	\N
26604	25201	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:36	\N
26605	25202	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:36	\N
26606	25203	DEPUTE	1980-11-30 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:36	\N
26607	25204	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:36	\N
26608	25205	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:36	\N
26609	25206	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:36	\N
26610	25207	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26611	25208	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26612	25209	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26613	25210	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26614	25211	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26615	25212	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26616	25213	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26617	25214	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26618	25215	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26619	25216	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26620	25217	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26621	25218	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26622	25219	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26623	25220	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26624	25221	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26625	25222	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26626	25223	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26627	25224	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26628	25225	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26629	25226	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26630	25227	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26631	25228	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26632	25229	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
28025	26622	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:16	\N
28026	26623	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:16	\N
28027	26624	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:16	\N
28028	26625	DEPUTE	1994-02-08 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:16	\N
28029	26626	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:16	\N
28030	26627	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:16	\N
28031	26628	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:16	\N
28032	26629	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:16	\N
28033	26630	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:16	\N
28034	26631	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:16	\N
28035	26632	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:16	\N
28036	26633	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:16	\N
28037	26634	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:16	\N
28038	26635	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:16	\N
28039	26636	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:16	\N
28040	26637	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:16	\N
28041	26638	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:17	\N
28042	26639	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:17	\N
28043	26640	DEPUTE	2007-06-20 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:17	\N
28044	26641	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:17	\N
28045	26642	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:17	\N
28046	26643	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:17	\N
28047	26644	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:17	\N
28048	26645	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:17	\N
28049	26646	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:17	\N
28050	26647	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:17	\N
28051	26648	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:17	\N
28052	26649	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:17	\N
28053	26650	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:17	\N
28054	26651	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:17	\N
28055	26652	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:17	\N
28056	26653	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:17	\N
28057	26654	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:17	\N
28058	26655	DEPUTE	1997-06-01 00:00:00	\N	1999-12-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:17	\N
28059	26656	DEPUTE	1988-05-08 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:17	\N
28060	26657	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:17	\N
28061	26658	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:17	\N
28062	26659	DEPUTE	1988-06-13 00:00:00	\N	1992-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:17	\N
28063	26660	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:17	\N
28064	26661	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:17	\N
28065	26662	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:17	\N
28066	26663	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:17	\N
28067	26664	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:17	\N
28068	26665	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:17	\N
28069	26666	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:17	\N
28070	26667	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:17	\N
28071	26668	DEPUTE	1986-04-02 00:00:00	\N	1987-10-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:17	\N
28072	26669	DEPUTE	1993-04-02 00:00:00	\N	1996-04-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:17	\N
28073	26670	DEPUTE	1987-10-14 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:18	\N
28074	26671	DEPUTE	1988-06-06 00:00:00	\N	1988-10-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:18	\N
28075	26672	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:18	\N
28076	26673	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:18	\N
28077	26674	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:18	\N
28078	26675	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:18	\N
28079	26676	DEPUTE	1988-06-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:18	\N
28080	26677	DEPUTE	1997-05-17 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:18	\N
28081	26678	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:18	\N
28082	26679	DEPUTE	1978-04-02 00:00:00	\N	1980-09-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:18	\N
28083	26680	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:18	\N
28084	26681	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:18	\N
28085	26682	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:18	\N
28086	26683	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:18	\N
28087	26684	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:18	\N
28088	26685	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:18	\N
28089	26686	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:18	\N
28090	26687	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:18	\N
28091	26688	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:18	\N
28092	26689	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:18	\N
28093	26690	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:18	\N
28094	26691	DEPUTE	1991-06-18 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:18	\N
28095	26692	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:18	\N
28096	26693	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:18	\N
28097	26694	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:18	\N
28098	26695	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:18	\N
28099	26696	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:18	\N
28100	26697	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:18	\N
28101	26698	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:18	\N
28102	26699	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:18	\N
28103	26700	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:18	\N
28104	26701	DEPUTE	2014-05-01 00:00:00	\N	2014-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:18	\N
28105	26702	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:18	\N
28106	26703	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:18	\N
28107	26704	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:18	\N
28108	26705	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:18	\N
28109	26706	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:18	\N
28110	26707	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:18	\N
28111	26708	DEPUTE	1987-06-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:18	\N
28112	26709	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:18	\N
28113	26710	DEPUTE	1993-04-02 00:00:00	\N	1994-10-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:18	\N
28114	26711	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:18	\N
28115	26712	DEPUTE	2002-06-19 00:00:00	\N	2004-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:18	\N
28116	26713	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:18	\N
28117	26714	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:18	\N
23752	22349	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:16	\N
23753	22350	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:16	\N
23754	22351	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:16	\N
23755	22352	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:16	\N
23756	22353	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:16	\N
23757	22354	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:16	\N
23758	22355	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:16	\N
23759	22356	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:16	\N
23760	22357	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:16	\N
23761	22358	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:16	\N
23762	22359	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:16	\N
23763	22360	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:16	\N
23764	22361	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:16	\N
23765	22362	DEPUTE	1993-04-02 00:00:00	\N	1994-12-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:16	\N
23766	22363	DEPUTE	2004-06-28 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23767	22364	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23768	22365	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23769	22366	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23770	22367	DEPUTE	1963-05-05 00:00:00	\N	1966-02-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23771	22368	DEPUTE	1967-04-03 00:00:00	\N	1967-05-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23772	22369	DEPUTE	1968-07-11 00:00:00	\N	1968-08-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23773	22370	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23774	22371	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23775	22372	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23776	22373	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23777	22374	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23778	22375	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23779	22376	DEPUTE	2002-06-19 00:00:00	\N	2007-03-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23780	22377	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23781	22378	PDTAN	2002-06-26 00:00:00	\N	2007-03-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23782	22379	DEPUTE	1988-01-25 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23783	22380	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23784	22381	DEPUTE	2002-06-19 00:00:00	\N	2002-10-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23785	22382	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23786	22383	DEPUTE	2002-12-16 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23787	22384	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23788	22385	DEPUTE	1984-01-19 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23789	22386	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23790	22387	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23791	22388	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23792	22389	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23793	22390	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23794	22391	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23795	22392	DEPUTE	1986-04-02 00:00:00	\N	1986-05-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23796	22393	DEPUTE	1999-03-29 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23797	22394	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23798	22395	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23799	22396	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23800	22397	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23801	22398	SECAN	2004-10-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23802	22399	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23803	22400	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23804	22401	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23805	22402	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23806	22403	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23807	22404	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23808	22405	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23809	22406	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23810	22407	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23811	22408	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23812	22409	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23813	22410	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23814	22411	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23815	22412	DEPUTE	1976-11-18 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23816	22413	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23817	22414	DEPUTE	1986-04-18 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23818	22415	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23819	22416	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23820	22417	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23821	22418	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23822	22419	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23823	22420	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23824	22421	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23825	22422	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23826	22423	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23827	22424	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23828	22425	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23829	22426	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23830	22427	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23831	22428	DEPUTE	1997-06-01 00:00:00	\N	2001-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23832	22429	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23833	22430	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23834	22431	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23835	22432	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:17	\N
23836	22433	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
23837	22434	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
23838	22435	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
23839	22436	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
23840	22437	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
23841	22438	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
23842	22439	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
23843	22440	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
23844	22441	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
25239	23836	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:57	\N
25240	23837	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:57	\N
25241	23838	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:57	\N
25242	23839	DEPUTE	1993-04-02 00:00:00	\N	1995-05-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:57	\N
25243	23840	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:57	\N
25244	23841	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:57	\N
25245	23842	DEPUTE	1988-06-13 00:00:00	\N	1988-10-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:57	\N
25246	23843	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:57	\N
25247	23844	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:57	\N
25248	23845	DEPUTE	1994-08-23 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:57	\N
25249	23846	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:57	\N
25250	23847	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:57	\N
25251	23848	DEPUTE	2007-06-20 00:00:00	\N	2008-09-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:57	\N
25252	23849	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:57	\N
25253	23850	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:57	\N
25254	23851	DEPUTE	2012-06-20 00:00:00	\N	2014-05-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:57	\N
25255	23852	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:57	\N
25256	23853	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:57	\N
25257	23854	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:58	\N
25258	23855	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:58	\N
25259	23856	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:58	\N
25260	23857	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:58	\N
25261	23858	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:58	\N
25262	23859	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:58	\N
25263	23860	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:58	\N
25264	23861	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:58	\N
25265	23862	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:58	\N
25266	23863	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:58	\N
25267	23864	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:58	\N
25268	23865	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:58	\N
25269	23866	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:58	\N
25270	23867	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:58	\N
25271	23868	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:58	\N
25272	23869	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:58	\N
25273	23870	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:58	\N
25274	23871	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:58	\N
25275	23872	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:58	\N
25276	23873	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:58	\N
25277	23874	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:58	\N
25278	23875	VICPDTAN	1986-04-04 00:00:00	\N	1987-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:58	\N
25279	23876	DEPUTE	1971-12-05 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:58	\N
25280	23877	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:58	\N
25281	23878	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:58	\N
25282	23879	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:58	\N
25283	23880	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:58	\N
25284	23881	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:58	\N
25285	23882	SECAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:58	\N
25286	23883	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:58	\N
25287	23884	DEPUTE	1967-04-03 00:00:00	\N	1967-05-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:58	\N
25288	23885	DEPUTE	1968-07-11 00:00:00	\N	1969-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:58	\N
25289	23886	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:58	\N
25290	23887	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:58	\N
25291	23888	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:58	\N
25292	23889	DEPUTE	2007-06-20 00:00:00	\N	2010-03-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:58	\N
25293	23890	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:58	\N
25294	23891	QUESTAN	2002-06-26 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:58	\N
25295	23892	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:59	\N
25296	23893	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:59	\N
25297	23894	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:59	\N
25298	23895	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:59	\N
25299	23896	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:59	\N
25300	23897	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:59	\N
25301	23898	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:59	\N
25302	23899	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:59	\N
25303	23900	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:59	\N
25304	23901	VICPDTAN	2003-10-01 00:00:00	\N	2004-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:59	\N
25305	23902	VICPDTAN	2006-01-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:59	\N
25306	23903	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:59	\N
25307	23904	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:59	\N
25308	23905	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:59	\N
25309	23906	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:59	\N
25310	23907	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:59	\N
25311	23908	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:59	\N
25312	23909	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:59	\N
25313	23910	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:59	\N
25314	23911	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:59	\N
25315	23912	DEPUTE	1997-06-01 00:00:00	\N	2001-04-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:59	\N
25316	23913	VICPDTAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:59	\N
25317	23914	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:59	\N
25318	23915	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:59	\N
25319	23916	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:59	\N
25320	23917	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:59	\N
25321	23918	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:59	\N
25322	23919	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:59	\N
25323	23920	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:59	\N
25324	23921	DEPUTE	1958-12-09 00:00:00	\N	1961-09-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:59	\N
25325	23922	DEPUTE	1973-04-02 00:00:00	\N	1974-07-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:59	\N
25326	23923	DEPUTE	1974-07-26 00:00:00	\N	1977-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:59	\N
25327	23924	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:59	\N
25328	23925	DEPUTE	1986-04-02 00:00:00	\N	1986-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:59	\N
25329	23926	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:59	\N
25330	23927	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25331	23928	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
26633	25230	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26634	25231	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26635	25232	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26636	25233	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26637	25234	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26638	25235	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26639	25236	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26640	25237	DEPUTE	1988-06-13 00:00:00	\N	1989-05-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26641	25238	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26642	25239	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26643	25240	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26644	25241	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26645	25242	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26646	25243	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26647	25244	DEPUTE	1995-09-17 00:00:00	\N	1995-12-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26648	25245	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26649	25246	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26650	25247	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26651	25248	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26652	25249	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26653	25250	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26654	25251	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26655	25252	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26656	25253	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26657	25254	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26658	25255	DEPUTE	1983-11-05 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26659	25256	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26660	25257	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26661	25258	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:37	\N
26662	25259	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:38	\N
26663	25260	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:38	\N
26664	25261	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:38	\N
26665	25262	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:38	\N
26666	25263	DEPUTE	2014-05-03 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:38	\N
26667	25264	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:38	\N
26668	25265	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:38	\N
26669	25266	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:38	\N
26670	25267	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:38	\N
26671	25268	DEPUTE	2002-06-19 00:00:00	\N	2006-06-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:38	\N
26672	25269	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:38	\N
26673	25270	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:38	\N
26674	25271	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:38	\N
26675	25272	DEPUTE	1993-04-02 00:00:00	\N	1993-12-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:38	\N
26676	25273	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:38	\N
26677	25274	DEPUTE	1997-06-01 00:00:00	\N	2000-04-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:38	\N
26678	25275	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:38	\N
26679	25276	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:38	\N
26680	25277	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:38	\N
26681	25278	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:38	\N
26682	25279	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:38	\N
26683	25280	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:38	\N
26684	25281	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:38	\N
26685	25282	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:38	\N
26686	25283	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:38	\N
26687	25284	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:38	\N
26688	25285	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:38	\N
26689	25286	DEPUTE	1987-10-30 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:38	\N
26690	25287	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:38	\N
26691	25288	DEPUTE	1984-08-24 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:38	\N
26692	25289	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:38	\N
26693	25290	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:38	\N
26694	25291	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:38	\N
26695	25292	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:38	\N
26696	25293	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:38	\N
26697	25294	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:38	\N
26698	25295	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:38	\N
26699	25296	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:38	\N
26700	25297	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:38	\N
26701	25298	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:38	\N
26702	25299	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:39	\N
26703	25300	DEPUTE	1998-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:39	\N
26704	25301	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:39	\N
26705	25302	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:39	\N
26706	25303	QUESTAN	2016-09-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:39	\N
26707	25304	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:39	\N
26708	25305	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:39	\N
26709	25306	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:39	\N
26710	25307	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:39	\N
26711	25308	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:39	\N
26712	25309	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:39	\N
26713	25310	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:39	\N
26714	25311	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:39	\N
26715	25312	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:39	\N
26716	25313	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:39	\N
26717	25314	QUESTAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:39	\N
26718	25315	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:39	\N
26719	25316	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:39	\N
26720	25317	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:39	\N
26721	25318	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:39	\N
26722	25319	DEPUTE	1978-04-02 00:00:00	\N	1980-10-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:39	\N
26723	25320	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:39	\N
26724	25321	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:39	\N
26725	25322	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:39	\N
27378	25975	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:56	\N
27379	25976	DEPUTE	2002-06-25 00:00:00	\N	2002-06-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:56	\N
27380	25977	DEPUTE	2003-03-11 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:56	\N
27381	25978	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:56	\N
27382	25979	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:56	\N
27383	25980	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:56	\N
27384	25981	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:56	\N
27385	25982	DEPUTE	2006-06-07 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:56	\N
27386	25983	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:57	\N
27387	25984	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:57	\N
27388	25985	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:57	\N
27389	25986	DEPUTE	2007-06-20 00:00:00	\N	2008-04-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:57	\N
27390	25987	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:57	\N
27391	25988	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:57	\N
27392	25989	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:57	\N
27393	25990	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:57	\N
27394	25991	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:57	\N
27395	25992	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:57	\N
27396	25993	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:57	\N
27397	25994	DEPUTE	2007-06-20 00:00:00	\N	2008-03-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:57	\N
27398	25995	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:57	\N
27399	25996	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:57	\N
27400	25997	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:57	\N
27401	25998	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:57	\N
27402	25999	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:57	\N
27403	26000	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:57	\N
27404	26001	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:57	\N
27405	26002	DEPUTE	2012-06-20 00:00:00	\N	2016-01-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:57	\N
27406	26003	DEPUTE	2002-06-25 00:00:00	\N	2002-06-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:57	\N
27407	26004	DEPUTE	2007-07-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:57	\N
27408	26005	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:57	\N
27409	26006	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:57	\N
27410	26007	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:57	\N
27411	26008	DEPUTE	2017-01-07 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:57	\N
27412	26009	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:57	\N
27413	26010	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:57	\N
27414	26011	DEPUTE	2012-07-22 00:00:00	\N	2017-01-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:57	\N
27415	26012	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:57	\N
27416	26013	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:57	\N
27417	26014	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:57	\N
27418	26015	DEPUTE	2012-03-23 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:57	\N
27419	26016	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:58	\N
27420	26017	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:58	\N
27421	26018	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:58	\N
27422	26019	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:58	\N
27423	26020	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:58	\N
27424	26021	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:58	\N
27425	26022	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:58	\N
27426	26023	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:58	\N
27427	26024	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:58	\N
27428	26025	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:58	\N
27429	26026	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:58	\N
27430	26027	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:58	\N
27431	26028	DEPUTE	2005-07-03 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:58	\N
27432	26029	DEPUTE	2007-07-20 00:00:00	\N	2008-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:58	\N
27433	26030	DEPUTE	2009-07-23 00:00:00	\N	2010-12-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:58	\N
27434	26031	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:58	\N
27435	26032	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:58	\N
27436	26033	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:58	\N
27437	26034	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:58	\N
27438	26035	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:58	\N
27439	26036	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:58	\N
27440	26037	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:58	\N
27441	26038	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:58	\N
27442	26039	DEPUTE	1978-04-03 00:00:00	\N	1978-05-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:59	\N
27443	26040	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:59	\N
27444	26041	DEPUTE	1973-04-02 00:00:00	\N	1973-05-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:59	\N
27445	26042	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:59	\N
27446	26043	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:59	\N
27447	26044	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:59	\N
27448	26045	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:59	\N
27449	26046	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:59	\N
27450	26047	DEPUTE	1988-06-13 00:00:00	\N	1991-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:59	\N
27451	26048	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:59	\N
27452	26049	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:59	\N
27453	26050	DEPUTE	2001-04-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:59	\N
27454	26051	DEPUTE	2007-06-20 00:00:00	\N	2007-10-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:59	\N
27455	26052	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:59	\N
27456	26053	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:59	\N
27457	26054	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:59	\N
27458	26055	SECAN	1988-06-24 00:00:00	\N	1991-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:59	\N
27459	26056	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:59	\N
27460	26057	DEPUTE	1980-11-30 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:59	\N
27461	26058	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:59	\N
27462	26059	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:59	\N
27463	26060	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:59	\N
27464	26061	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:59	\N
27465	26062	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:59	\N
27466	26063	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:59	\N
27467	26064	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:59	\N
27468	26065	DEPUTE	1988-06-13 00:00:00	\N	1991-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:59	\N
27469	26066	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:00	\N
27470	26067	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:00	\N
23845	22442	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
23846	22443	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
23847	22444	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
23848	22445	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
23849	22446	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
23850	22447	DEPUTE	1997-06-01 00:00:00	\N	1998-07-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
23851	22448	DEPUTE	2007-06-20 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
23852	22449	DEPUTE	1975-10-03 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
23853	22450	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
23854	22451	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
23855	22452	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
23856	22453	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
23857	22454	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
23858	22455	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
23859	22456	DEPUTE	1978-05-06 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
23860	22457	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
23861	22458	DEPUTE	1986-04-02 00:00:00	\N	1988-01-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
23862	22459	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
23863	22460	DEPUTE	1981-07-02 00:00:00	\N	1986-02-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
23864	22461	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
23865	22462	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
23866	22463	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
23867	22464	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
23868	22465	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
23869	22466	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
23870	22467	DEPUTE	1994-09-13 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
23871	22468	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
23872	22469	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
23873	22470	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
23874	22471	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
23875	22472	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
23876	22473	DEPUTE	2008-12-01 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
23877	22474	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
23878	22475	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
23879	22476	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
23880	22477	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
23881	22478	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
23882	22479	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:18	\N
23883	22480	DEPUTE	2007-06-20 00:00:00	\N	2008-11-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:19	\N
23884	22481	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:19	\N
23885	22482	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:19	\N
23886	22483	DEPUTE	1993-04-02 00:00:00	\N	1995-09-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:19	\N
23887	22484	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:19	\N
23888	22485	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:19	\N
23889	22486	DEPUTE	1968-07-11 00:00:00	\N	1972-08-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:19	\N
23890	22487	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:19	\N
23891	22488	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:19	\N
23892	22489	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:19	\N
23893	22490	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:19	\N
23894	22491	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:19	\N
23895	22492	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:19	\N
23896	22493	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:19	\N
23897	22494	DEPUTE	1978-04-03 00:00:00	\N	1978-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:19	\N
23898	22495	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:19	\N
23899	22496	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:19	\N
23900	22497	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:19	\N
23901	22498	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:19	\N
23902	22499	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:19	\N
23903	22500	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:19	\N
23904	22501	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:19	\N
23905	22502	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:19	\N
23906	22503	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:19	\N
23907	22504	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:19	\N
23908	22505	DEPUTE	1956-01-19 00:00:00	\N	1958-06-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:19	\N
23909	22506	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:19	\N
23910	22507	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:19	\N
23911	22508	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:19	\N
23912	22509	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:19	\N
23913	22510	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:19	\N
23914	22511	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:19	\N
23915	22512	DEPUTE	1995-12-10 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:19	\N
23916	22513	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:19	\N
23917	22514	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:19	\N
23918	22515	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:19	\N
23919	22516	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:19	\N
23920	22517	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:19	\N
23921	22518	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:19	\N
23922	22519	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:19	\N
23923	22520	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:19	\N
23924	22521	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:19	\N
23925	22522	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:19	\N
23926	22523	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:19	\N
23927	22524	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:19	\N
23928	22525	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:19	\N
23929	22526	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:20	\N
23930	22527	SECAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:20	\N
23931	22528	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:20	\N
23932	22529	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:20	\N
23933	22530	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:20	\N
23934	22531	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:20	\N
23935	22532	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:20	\N
23936	22533	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:20	\N
23937	22534	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:20	\N
25332	23929	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25333	23930	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25334	23931	DEPUTE	1958-12-09 00:00:00	\N	1961-04-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25335	23932	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25336	23933	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25337	23934	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25338	23935	DEPUTE	1973-04-02 00:00:00	\N	1975-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25339	23936	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25340	23937	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25341	23938	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25342	23939	DEPUTE	1986-04-02 00:00:00	\N	1986-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25343	23940	DEPUTE	1986-10-01 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25344	23941	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25345	23942	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25346	23943	DEPUTE	1974-04-29 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25347	23944	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25348	23945	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25349	23946	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25350	23947	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25351	23948	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25352	23949	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25353	23950	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25354	23951	DEPUTE	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25355	23952	DEPUTE	1983-12-04 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25356	23953	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25357	23954	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25358	23955	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25359	23956	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25360	23957	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25361	23958	DEPUTE	1999-02-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25362	23959	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25363	23960	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25364	23961	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25365	23962	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25366	23963	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25367	23964	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25368	23965	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25369	23966	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25370	23967	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25371	23968	DEPUTE	1997-06-01 00:00:00	\N	2001-02-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25372	23969	VICPDTAN	1984-04-01 00:00:00	\N	1985-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25373	23970	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25374	23971	DEPUTE	1998-11-30 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25375	23972	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25376	23973	DEPUTE	2012-06-20 00:00:00	\N	2016-07-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25377	23974	DEPUTE	2010-12-14 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:00	\N
25378	23975	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25379	23976	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25380	23977	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25381	23978	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25382	23979	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25383	23980	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25384	23981	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25385	23982	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25386	23983	DEPUTE	2014-05-03 00:00:00	\N	2014-10-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25387	23984	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25388	23985	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25389	23986	DEPUTE	2002-06-19 00:00:00	\N	2002-11-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25390	23987	DEPUTE	2003-02-03 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25391	23988	DEPUTE	1981-07-24 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25392	23989	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25393	23990	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25394	23991	DEPUTE	1990-11-03 00:00:00	\N	1991-11-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25395	23992	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25396	23993	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25397	23994	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25398	23995	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25399	23996	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25400	23997	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25401	23998	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25402	23999	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25403	24000	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25404	24001	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25405	24002	DEPUTE	1988-06-06 00:00:00	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25406	24003	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25407	24004	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25408	24005	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25409	24006	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25410	24007	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25411	24008	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25412	24009	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25413	24010	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25414	24011	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25415	24012	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25416	24013	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25417	24014	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25418	24015	DEPUTE	1997-06-01 00:00:00	\N	1999-08-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25419	24016	DEPUTE	2003-03-24 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25420	24017	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25421	24018	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25422	24019	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25423	24020	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25424	24021	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
26726	25323	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:39	\N
26727	25324	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:39	\N
26728	25325	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:39	\N
26729	25326	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:39	\N
26730	25327	VICPDTAN	2000-03-30 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:39	\N
26731	25328	VICPDTAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:39	\N
26732	25329	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:39	\N
26733	25330	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:39	\N
26734	25331	DEPUTE	1981-07-25 00:00:00	\N	1983-04-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:39	\N
26735	25332	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:39	\N
26736	25333	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:39	\N
26737	25334	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:39	\N
26738	25335	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:39	\N
26739	25336	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:39	\N
26740	25337	DEPUTE	1997-06-01 00:00:00	\N	1998-02-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:39	\N
26741	25338	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:39	\N
26742	25339	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26743	25340	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26744	25341	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26745	25342	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26746	25343	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26747	25344	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26748	25345	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26749	25346	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26750	25347	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26751	25348	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26752	25349	DEPUTE	1988-06-13 00:00:00	\N	1991-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26753	25350	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26754	25351	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26755	25352	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26756	25353	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26757	25354	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26758	25355	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26759	25356	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26760	25357	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26761	25358	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26762	25359	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26763	25360	VICPDTAN	2007-06-27 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26764	25361	VICPDTAN	2012-06-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26765	25362	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26766	25363	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26767	25364	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26768	25365	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26769	25366	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26770	25367	SECAN	1988-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26771	25368	VICPDTAN	2002-06-26 00:00:00	\N	2005-06-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26772	25369	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26773	25370	DEPUTE	1988-07-29 00:00:00	\N	1992-12-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26774	25371	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26775	25372	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26776	25373	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26777	25374	DEPUTE	2012-06-20 00:00:00	\N	2014-05-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26778	25375	SECAN	2004-10-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26779	25376	VICPDTAN	2007-06-27 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26780	25377	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26781	25378	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26782	25379	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26783	25380	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26784	25381	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26785	25382	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26786	25383	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26787	25384	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26788	25385	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26789	25386	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:40	\N
26790	25387	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:41	\N
26791	25388	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:41	\N
26792	25389	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:41	\N
26793	25390	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:41	\N
26794	25391	DEPUTE	1983-05-09 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:41	\N
26795	25392	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:41	\N
26796	25393	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:41	\N
26797	25394	DEPUTE	1988-06-06 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:41	\N
26798	25395	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:41	\N
26799	25396	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:41	\N
26800	25397	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:41	\N
26801	25398	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:41	\N
26802	25399	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:41	\N
26803	25400	DEPUTE	2012-06-20 00:00:00	\N	2017-01-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:41	\N
26804	25401	DEPUTE	2017-04-22 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:41	\N
26805	25402	DEPUTE	1997-06-12 00:00:00	\N	2000-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:41	\N
26806	25403	DEPUTE	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:41	\N
26807	25404	DEPUTE	1973-04-02 00:00:00	\N	1977-03-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:41	\N
26808	25405	DEPUTE	1997-07-05 00:00:00	\N	2001-02-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:41	\N
26809	25406	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:41	\N
26810	25407	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:41	\N
26811	25408	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:41	\N
26812	25409	DEPUTE	1984-09-29 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:41	\N
26813	25410	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:41	\N
26814	25411	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:41	\N
26815	25412	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:41	\N
26816	25413	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:41	\N
26817	25414	DEPUTE	2016-03-12 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:41	\N
26818	25415	QUESTAN	2007-06-27 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:41	\N
27749	26346	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:08	\N
27750	26347	DEPUTE	2008-09-15 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:08	\N
27751	26348	DEPUTE	2007-06-20 00:00:00	\N	2007-11-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:08	\N
27752	26349	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:08	\N
27753	26350	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:08	\N
27754	26351	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:08	\N
27755	26352	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:08	\N
27756	26353	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:08	\N
27757	26354	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:08	\N
27758	26355	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:08	\N
27759	26356	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:08	\N
27760	26357	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:08	\N
27761	26358	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:08	\N
27762	26359	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:08	\N
27763	26360	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:08	\N
27764	26361	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:08	\N
27765	26362	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:08	\N
27766	26363	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:08	\N
27767	26364	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:08	\N
27768	26365	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:08	\N
27769	26366	SECAN	2008-10-01 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:08	\N
27770	26367	SECAN	2012-06-27 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:08	\N
27771	26368	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:08	\N
27772	26369	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:08	\N
27773	26370	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:08	\N
27774	26371	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:08	\N
27775	26372	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:08	\N
27776	26373	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:08	\N
27777	26374	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:08	\N
27778	26375	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:08	\N
27779	26376	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:08	\N
27780	26377	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:09	\N
27781	26378	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:09	\N
27782	26379	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:09	\N
27783	26380	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:09	\N
27784	26381	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:09	\N
27785	26382	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:09	\N
27786	26383	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:09	\N
27787	26384	DEPUTE	2007-07-20 00:00:00	\N	2010-12-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:09	\N
27788	26385	DEPUTE	2004-07-05 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:09	\N
27789	26386	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:09	\N
27790	26387	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:09	\N
27791	26388	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:09	\N
27792	26389	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:09	\N
27793	26390	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:09	\N
27794	26391	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:09	\N
27795	26392	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:09	\N
27796	26393	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:09	\N
27797	26394	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:09	\N
27798	26395	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:09	\N
27799	26396	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:09	\N
27800	26397	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:09	\N
27801	26398	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:09	\N
27802	26399	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:09	\N
27803	26400	DEPUTE	2008-04-19 00:00:00	\N	2010-08-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:09	\N
27804	26401	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:09	\N
27805	26402	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:09	\N
27806	26403	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:09	\N
27807	26404	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:09	\N
27808	26405	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:09	\N
27809	26406	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:09	\N
27810	26407	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:09	\N
27811	26408	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:09	\N
27812	26409	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:09	\N
27813	26410	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:09	\N
27814	26411	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:09	\N
27815	26412	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:09	\N
27816	26413	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27817	26414	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27818	26415	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27819	26416	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27820	26417	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27821	26418	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27822	26419	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27823	26420	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27824	26421	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27825	26422	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27826	26423	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27827	26424	DEPUTE	2006-06-27 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27828	26425	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27829	26426	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27830	26427	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27831	26428	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27832	26429	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27833	26430	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27834	26431	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27835	26432	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27836	26433	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27837	26434	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27838	26435	DEPUTE	2007-06-20 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27839	26436	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27840	26437	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27841	26438	DEPUTE	2004-05-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
27842	26439	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:10	\N
23938	22535	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:20	\N
23939	22536	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:20	\N
23940	22537	QUESTAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:20	\N
23941	22538	QUESTAN	1994-04-02 00:00:00	\N	1995-04-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:20	\N
23942	22539	QUESTAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:20	\N
23943	22540	QUESTAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:20	\N
23944	22541	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:20	\N
23945	22542	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:20	\N
23946	22543	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:20	\N
23947	22544	SECAN	2007-06-27 00:00:00	\N	2010-10-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:20	\N
23948	22545	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:20	\N
23949	22546	DEPUTE	1972-04-14 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:20	\N
23950	22547	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:20	\N
23951	22548	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:20	\N
23952	22549	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:20	\N
23953	22550	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:20	\N
23954	22551	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:20	\N
23955	22552	DEPUTE	1997-06-01 00:00:00	\N	2001-09-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:20	\N
23956	22553	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:20	\N
23957	22554	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:20	\N
23958	22555	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:20	\N
23959	22556	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:20	\N
23960	22557	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:20	\N
23961	22558	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:20	\N
23962	22559	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:20	\N
23963	22560	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:20	\N
23964	22561	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:20	\N
23965	22562	DEPUTE	1988-06-06 00:00:00	\N	1988-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:20	\N
23966	22563	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:21	\N
23967	22564	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:21	\N
23968	22565	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:21	\N
23969	22566	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:21	\N
23970	22567	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:21	\N
23971	22568	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:21	\N
23972	22569	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:21	\N
23973	22570	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:21	\N
23974	22571	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:21	\N
23975	22572	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:21	\N
23976	22573	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:21	\N
23977	22574	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:21	\N
23978	22575	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:21	\N
23979	22576	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:21	\N
23980	22577	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:21	\N
23981	22578	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:21	\N
23982	22579	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:21	\N
23983	22580	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:21	\N
23984	22581	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:21	\N
23985	22582	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:21	\N
23986	22583	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:21	\N
23987	22584	DEPUTE	2007-06-20 00:00:00	\N	2009-01-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:21	\N
23988	22585	DEPUTE	2005-10-04 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:21	\N
23989	22586	DEPUTE	2010-12-14 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:21	\N
23990	22587	DEPUTE	2012-06-20 00:00:00	\N	2012-10-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:21	\N
23991	22588	DEPUTE	2012-12-17 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:21	\N
23992	22589	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:21	\N
23993	22590	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:22	\N
23994	22591	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:22	\N
23995	22592	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:22	\N
23996	22593	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:22	\N
23997	22594	DEPUTE	1998-09-27 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:22	\N
23998	22595	DEPUTE	1973-05-13 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:22	\N
23999	22596	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:22	\N
24000	22597	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:22	\N
24001	22598	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:22	\N
24002	22599	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:22	\N
24003	22600	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:22	\N
24004	22601	DEPUTE	1968-07-11 00:00:00	\N	1971-12-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:22	\N
24005	22602	DEPUTE	1986-04-02 00:00:00	\N	1986-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:22	\N
24006	22603	DEPUTE	1986-09-29 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:22	\N
24007	22604	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:22	\N
24008	22605	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:22	\N
24009	22606	DEPUTE	1988-07-29 00:00:00	\N	1991-08-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:22	\N
24010	22607	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:22	\N
24011	22608	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:22	\N
24012	22609	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:22	\N
24013	22610	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:22	\N
24014	22611	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:23	\N
24015	22612	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:23	\N
24016	22613	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:23	\N
24017	22614	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:23	\N
24018	22615	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:23	\N
24019	22616	SECAN	2012-06-27 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:23	\N
24020	22617	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:23	\N
24021	22618	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:23	\N
24022	22619	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:23	\N
24023	22620	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:23	\N
24024	22621	DEPUTE	1997-06-01 00:00:00	\N	2001-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:23	\N
24025	22622	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:23	\N
24026	22623	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:23	\N
24027	22624	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:23	\N
24028	22625	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:23	\N
24029	22626	DEPUTE	1973-04-02 00:00:00	\N	1977-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:23	\N
24030	22627	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:23	\N
25425	24022	DEPUTE	1993-04-02 00:00:00	\N	1995-09-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25426	24023	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25427	24024	DEPUTE	1981-07-02 00:00:00	\N	1985-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:01	\N
25428	24025	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:02	\N
25429	24026	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:02	\N
25430	24027	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:02	\N
25431	24028	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:02	\N
25432	24029	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:02	\N
25433	24030	DEPUTE	2002-06-19 00:00:00	\N	2002-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:02	\N
25434	24031	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:02	\N
25435	24032	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:02	\N
25436	24033	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:02	\N
25437	24034	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:02	\N
25438	24035	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:02	\N
25439	24036	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:02	\N
25440	24037	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:02	\N
25441	24038	DEPUTE	1968-07-11 00:00:00	\N	1968-08-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:02	\N
25442	24039	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:02	\N
25443	24040	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:02	\N
25444	24041	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:02	\N
25445	24042	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:02	\N
25446	24043	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:02	\N
25447	24044	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:02	\N
25448	24045	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:02	\N
25449	24046	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:02	\N
25450	24047	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:02	\N
25451	24048	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:02	\N
25452	24049	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:02	\N
25453	24050	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:02	\N
25454	24051	DEPUTE	1978-05-06 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:02	\N
25455	24052	DEPUTE	1995-12-10 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:02	\N
25456	24053	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:02	\N
25457	24054	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:02	\N
25458	24055	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:02	\N
25459	24056	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:02	\N
25460	24057	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:02	\N
25461	24058	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:02	\N
25462	24059	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:02	\N
25463	24060	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:02	\N
25464	24061	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:02	\N
25465	24062	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:02	\N
25466	24063	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:02	\N
25467	24064	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:02	\N
25468	24065	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:02	\N
25469	24066	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:02	\N
25470	24067	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:03	\N
25471	24068	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:03	\N
25472	24069	VICPDTAN	1995-04-03 00:00:00	\N	1996-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:03	\N
25473	24070	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:03	\N
25474	24071	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:03	\N
25475	24072	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:03	\N
25476	24073	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:03	\N
25477	24074	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:03	\N
25478	24075	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:03	\N
25479	24076	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:03	\N
25480	24077	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:03	\N
25481	24078	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:03	\N
25482	24079	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:03	\N
25483	24080	SECAN	1988-06-24 00:00:00	\N	1992-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:03	\N
25484	24081	DEPUTE	1973-04-02 00:00:00	\N	1976-04-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:03	\N
25485	24082	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:03	\N
25486	24083	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:03	\N
25487	24084	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:03	\N
25488	24085	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:03	\N
25489	24086	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:03	\N
25490	24087	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:03	\N
25491	24088	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:03	\N
25492	24089	DEPUTE	1993-04-02 00:00:00	\N	1995-11-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:03	\N
25493	24090	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:03	\N
25494	24091	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:03	\N
25495	24092	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:03	\N
25496	24093	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:03	\N
25497	24094	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:03	\N
25498	24095	DEPUTE	1996-03-17 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:03	\N
25499	24096	DEPUTE	1997-06-01 00:00:00	\N	1999-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:03	\N
25500	24097	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:03	\N
25501	24098	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:03	\N
25502	24099	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:03	\N
25503	24100	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:03	\N
25504	24101	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:03	\N
25505	24102	SECAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:03	\N
25506	24103	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:03	\N
25507	24104	QUESTAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:03	\N
25508	24105	QUESTAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:04	\N
25509	24106	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:04	\N
25510	24107	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:04	\N
25511	24108	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:04	\N
25512	24109	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:04	\N
25513	24110	DEPUTE	1977-06-30 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:04	\N
25514	24111	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:04	\N
25515	24112	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:04	\N
25516	24113	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:04	\N
25517	24114	DEPUTE	1968-08-13 00:00:00	\N	1969-09-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:04	\N
26819	25416	DEPUTE	2000-04-28 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:41	\N
26820	25417	DEPUTE	1973-04-02 00:00:00	\N	1974-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:41	\N
26821	25418	DEPUTE	1986-04-02 00:00:00	\N	1986-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:41	\N
26822	25419	DEPUTE	1978-04-02 00:00:00	\N	1978-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:41	\N
26823	25420	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:41	\N
26824	25421	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:41	\N
26825	25422	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:41	\N
26826	25423	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:41	\N
26827	25424	SECAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:42	\N
26828	25425	SECAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:42	\N
26829	25426	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:42	\N
26830	25427	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:42	\N
26831	25428	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:42	\N
26832	25429	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:42	\N
26833	25430	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:42	\N
26834	25431	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:42	\N
26835	25432	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:42	\N
26836	25433	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:42	\N
26837	25434	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:42	\N
26838	25435	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:42	\N
26839	25436	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:42	\N
26840	25437	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:42	\N
26841	25438	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:42	\N
26842	25439	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:42	\N
26843	25440	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:42	\N
26844	25441	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:42	\N
26845	25442	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:42	\N
26846	25443	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:42	\N
26847	25444	DEPUTE	1973-04-02 00:00:00	\N	1977-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:42	\N
26848	25445	DEPUTE	1978-04-03 00:00:00	\N	1978-05-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:42	\N
26849	25446	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:42	\N
26850	25447	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:42	\N
26851	25448	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:42	\N
26852	25449	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:42	\N
26853	25450	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:42	\N
26854	25451	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:42	\N
26855	25452	SECAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:42	\N
26856	25453	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:42	\N
26857	25454	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:42	\N
26858	25455	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:43	\N
26859	25456	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:43	\N
26860	25457	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:43	\N
26861	25458	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:43	\N
26862	25459	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:43	\N
26863	25460	DEPUTE	2007-06-20 00:00:00	\N	2009-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:43	\N
26864	25461	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:43	\N
26865	25462	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:43	\N
26866	25463	DEPUTE	1997-07-03 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:43	\N
26867	25464	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:43	\N
26868	25465	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:43	\N
26869	25466	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:43	\N
26870	25467	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:43	\N
26871	25468	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:43	\N
26872	25469	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:43	\N
26873	25470	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:43	\N
26874	25471	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:43	\N
26875	25472	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:43	\N
26876	25473	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:43	\N
26877	25474	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:43	\N
26878	25475	SECAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:43	\N
26879	25476	DEPUTE	1981-07-02 00:00:00	\N	1983-04-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:43	\N
26880	25477	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:43	\N
26881	25478	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:43	\N
26882	25479	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:43	\N
26883	25480	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:43	\N
26884	25481	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:43	\N
26885	25482	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:43	\N
26886	25483	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:44	\N
26887	25484	DEPUTE	2007-06-20 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:44	\N
26888	25485	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:44	\N
26889	25486	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:44	\N
26890	25487	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:44	\N
26891	25488	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:44	\N
26892	25489	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:44	\N
26893	25490	DEPUTE	1988-12-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:44	\N
26894	25491	DEPUTE	2002-06-19 00:00:00	\N	2006-06-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:44	\N
26895	25492	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:44	\N
26896	25493	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:44	\N
26897	25494	DEPUTE	2007-06-20 00:00:00	\N	2011-07-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:44	\N
26898	25495	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:44	\N
26899	25496	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:44	\N
26900	25497	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:44	\N
26901	25498	DEPUTE	1986-05-07 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:44	\N
26902	25499	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:44	\N
26903	25500	DEPUTE	1988-06-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:44	\N
26904	25501	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:44	\N
26905	25502	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:44	\N
26906	25503	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:44	\N
26907	25504	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:44	\N
26908	25505	DEPUTE	1988-06-13 00:00:00	\N	1992-07-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:44	\N
26909	25506	DEPUTE	1995-09-07 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:44	\N
26910	25507	DEPUTE	1997-06-01 00:00:00	\N	2001-12-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:44	\N
26911	25508	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:45	\N
22543	21140	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:42	\N
22544	21141	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:42	\N
22545	21142	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:42	\N
22546	21143	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:42	\N
22547	21144	DEPUTE	1988-06-13 00:00:00	\N	1989-04-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:42	\N
22548	21145	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:42	\N
22549	21146	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:42	\N
22550	21147	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:42	\N
22551	21148	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:42	\N
22552	21149	DEPUTE	2002-06-19 00:00:00	\N	2003-06-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:42	\N
22553	21150	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:42	\N
22554	21151	SECAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:42	\N
22555	21152	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:42	\N
22556	21153	DEPUTE	1994-12-13 00:00:00	\N	1995-07-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:42	\N
22557	21154	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:42	\N
22558	21155	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:42	\N
22559	21156	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:42	\N
22560	21157	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:42	\N
22561	21158	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22562	21159	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22563	21160	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22564	21161	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22565	21162	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22566	21163	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22567	21164	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22568	21165	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22569	21166	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22570	21167	DEPUTE	1973-04-02 00:00:00	\N	1977-01-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22571	21168	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22572	21169	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22573	21170	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22574	21171	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22575	21172	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22576	21173	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22577	21174	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22578	21175	DEPUTE	1988-06-06 00:00:00	\N	1992-11-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22579	21176	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22580	21177	VICPDTAN	1986-04-04 00:00:00	\N	1988-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22581	21178	VICPDTAN	1988-06-24 00:00:00	\N	1992-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22582	21179	DEPUTE	1973-04-02 00:00:00	\N	1973-05-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22583	21180	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22584	21181	DEPUTE	1986-10-24 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22585	21182	DEPUTE	1978-04-02 00:00:00	\N	1980-10-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22586	21183	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22587	21184	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22588	21185	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22589	21186	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22590	21187	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22591	21188	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22592	21189	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22593	21190	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22594	21191	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22595	21192	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22596	21193	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22597	21194	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22598	21195	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22599	21196	DEPUTE	1981-07-02 00:00:00	\N	1983-02-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22600	21197	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22601	21198	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22602	21199	DEPUTE	1973-04-02 00:00:00	\N	1977-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22603	21200	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22604	21201	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22605	21202	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22606	21203	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22607	21204	DEPUTE	1997-05-25 00:00:00	\N	2001-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22608	21205	SECAN	1986-04-04 00:00:00	\N	1987-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22609	21206	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:43	\N
22610	21207	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
22611	21208	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
22612	21209	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
22613	21210	DEPUTE	1998-06-15 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
22614	21211	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
22615	21212	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
22616	21213	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
22617	21214	DEPUTE	1983-11-05 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
22618	21215	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
22619	21216	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
22620	21217	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
22621	21218	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
22622	21219	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
22623	21220	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
22624	21221	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
22625	21222	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
22626	21223	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
22627	21224	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
22628	21225	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
22629	21226	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
22630	21227	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
22631	21228	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
22632	21229	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
22633	21230	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
22634	21231	DEPUTE	1981-07-02 00:00:00	\N	1984-08-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
22635	21232	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
24031	22628	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:23	\N
24032	22629	DEPUTE	1982-01-17 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:23	\N
24033	22630	DEPUTE	1978-04-03 00:00:00	\N	1978-05-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:23	\N
24034	22631	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:23	\N
24035	22632	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:23	\N
24036	22633	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:23	\N
24037	22634	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:23	\N
24038	22635	DEPUTE	1999-03-30 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:23	\N
24039	22636	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:23	\N
24040	22637	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:24	\N
24041	22638	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:24	\N
24042	22639	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:24	\N
24043	22640	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:24	\N
24044	22641	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:24	\N
24045	22642	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:24	\N
24046	22643	SECAN	1997-06-13 00:00:00	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:24	\N
24047	22644	DEPUTE	1993-04-02 00:00:00	\N	1996-02-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:24	\N
24048	22645	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:24	\N
24049	22646	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:24	\N
24050	22647	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:24	\N
24051	22648	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:24	\N
24052	22649	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:24	\N
24053	22650	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:24	\N
24054	22651	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:24	\N
24055	22652	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:24	\N
24056	22653	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:24	\N
24057	22654	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:24	\N
24058	22655	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:24	\N
24059	22656	DEPUTE	2010-12-14 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:24	\N
24060	22657	DEPUTE	2012-06-20 00:00:00	\N	2014-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:24	\N
24061	22658	SECAN	1995-04-03 00:00:00	\N	1996-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:24	\N
24062	22659	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:24	\N
24063	22660	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:25	\N
24064	22661	DEPUTE	1993-04-02 00:00:00	\N	1995-12-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:25	\N
24065	22662	DEPUTE	1996-02-26 00:00:00	\N	1996-03-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:25	\N
24066	22663	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:25	\N
24067	22664	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:25	\N
24068	22665	DEPUTE	1968-07-11 00:00:00	\N	1971-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:25	\N
24069	22666	DEPUTE	2011-07-30 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:25	\N
24070	22667	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:25	\N
24071	22668	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:25	\N
24072	22669	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:25	\N
24073	22670	DEPUTE	1995-09-25 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:25	\N
24074	22671	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:25	\N
24075	22672	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:25	\N
24076	22673	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:25	\N
24077	22674	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:25	\N
24078	22675	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:25	\N
24079	22676	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:25	\N
24080	22677	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:25	\N
24081	22678	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:25	\N
24082	22679	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:25	\N
24083	22680	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:25	\N
24084	22681	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:25	\N
24085	22682	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:25	\N
24086	22683	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:25	\N
24087	22684	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:25	\N
24088	22685	DEPUTE	1988-06-06 00:00:00	\N	1993-02-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:25	\N
24089	22686	SECAN	1985-04-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:25	\N
24090	22687	SECAN	1986-04-04 00:00:00	\N	1987-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:25	\N
24091	22688	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:25	\N
24092	22689	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:25	\N
24093	22690	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:25	\N
24094	22691	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:25	\N
24095	22692	DEPUTE	1993-05-03 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:25	\N
24096	22693	DEPUTE	1997-06-01 00:00:00	\N	2001-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:25	\N
24097	22694	DEPUTE	1973-04-02 00:00:00	\N	1976-09-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:25	\N
24098	22695	DEPUTE	1978-04-02 00:00:00	\N	1978-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:25	\N
24099	22696	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:25	\N
24100	22697	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:25	\N
24101	22698	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24102	22699	DEPUTE	1991-06-18 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24103	22700	DEPUTE	1982-01-18 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24104	22701	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24105	22702	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24106	22703	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24107	22704	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24108	22705	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24109	22706	DEPUTE	2009-07-23 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24110	22707	SECAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24111	22708	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24112	22709	DEPUTE	2001-04-28 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24113	22710	DEPUTE	1982-06-15 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24114	22711	DEPUTE	1990-11-03 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24115	22712	DEPUTE	1968-07-11 00:00:00	\N	1970-05-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24116	22713	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24117	22714	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24118	22715	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24119	22716	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24120	22717	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24121	22718	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24122	22719	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24123	22720	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
22542	21139	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 03:44:33	2017-06-29 09:20:02
25518	24115	DEPUTE	1973-05-03 00:00:00	\N	1974-07-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:04	\N
25519	24116	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:04	\N
25520	24117	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:04	\N
25521	24118	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:04	\N
25522	24119	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:04	\N
25523	24120	DEPUTE	1973-04-03 00:00:00	\N	1974-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:04	\N
25524	24121	DEPUTE	1986-04-02 00:00:00	\N	1986-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:04	\N
25525	24122	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:04	\N
25526	24123	DEPUTE	1999-08-29 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:04	\N
25527	24124	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:04	\N
25528	24125	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:04	\N
25529	24126	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:04	\N
25530	24127	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:04	\N
25531	24128	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:04	\N
25532	24129	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:04	\N
25533	24130	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:04	\N
25534	24131	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:04	\N
25535	24132	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:04	\N
25536	24133	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:05	\N
25537	24134	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:05	\N
25538	24135	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:05	\N
25539	24136	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:05	\N
25540	24137	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:05	\N
25541	24138	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:05	\N
25542	24139	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:05	\N
25543	24140	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:05	\N
25544	24141	DEPUTE	1986-04-02 00:00:00	\N	1986-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:05	\N
25545	24142	DEPUTE	1986-10-01 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:05	\N
25546	24143	DEPUTE	1988-06-06 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:05	\N
25547	24144	DEPUTE	1997-06-01 00:00:00	\N	1997-07-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:05	\N
25548	24145	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:05	\N
25549	24146	DEPUTE	1981-07-02 00:00:00	\N	1985-12-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:05	\N
25550	24147	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:05	\N
25551	24148	DEPUTE	1988-06-06 00:00:00	\N	1992-05-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:05	\N
25552	24149	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:05	\N
25553	24150	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:05	\N
25554	24151	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:05	\N
25555	24152	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:05	\N
25556	24153	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:05	\N
25557	24154	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:05	\N
25558	24155	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:05	\N
25559	24156	DEPUTE	1981-07-02 00:00:00	\N	1984-08-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:05	\N
25560	24157	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:06	\N
25561	24158	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:06	\N
25562	24159	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:06	\N
25563	24160	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:06	\N
25564	24161	DEPUTE	2007-06-20 00:00:00	\N	2008-04-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:06	\N
25565	24162	DEPUTE	2010-08-05 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:06	\N
25566	24163	DEPUTE	1967-04-02 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:06	\N
25567	24164	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:06	\N
25568	24165	DEPUTE	1973-04-03 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:06	\N
25569	24166	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:06	\N
25570	24167	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:06	\N
25571	24168	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:06	\N
25572	24169	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:06	\N
25573	24170	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:06	\N
25574	24171	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:06	\N
25575	24172	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:06	\N
25576	24173	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:06	\N
25577	24174	DEPUTE	1981-07-02 00:00:00	\N	1986-03-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:06	\N
25578	24175	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:06	\N
25579	24176	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:06	\N
25580	24177	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:06	\N
25581	24178	DEPUTE	2012-06-20 00:00:00	\N	2016-03-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:06	\N
25582	24179	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:06	\N
25583	24180	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:06	\N
25584	24181	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:06	\N
25585	24182	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:06	\N
25586	24183	DEPUTE	2002-06-19 00:00:00	\N	2004-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:06	\N
25587	24184	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:06	\N
25588	24185	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:06	\N
25589	24186	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:07	\N
25590	24187	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:07	\N
25591	24188	DEPUTE	1961-06-11 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:07	\N
25592	24189	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:07	\N
25593	24190	DEPUTE	1967-04-02 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:07	\N
25594	24191	DEPUTE	1968-07-11 00:00:00	\N	1969-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:07	\N
25595	24192	DEPUTE	1973-04-03 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:07	\N
25596	24193	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:07	\N
25597	24194	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:07	\N
25598	24195	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:07	\N
25599	24196	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:07	\N
25600	24197	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:07	\N
25601	24198	DEPUTE	1978-05-06 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:07	\N
25602	24199	DEPUTE	1983-12-19 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:07	\N
25603	24200	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:07	\N
25604	24201	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:07	\N
25605	24202	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:07	\N
25606	24203	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:07	\N
25607	24204	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:07	\N
25608	24205	DEPUTE	1998-05-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:07	\N
25609	24206	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:07	\N
26912	25509	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:45	\N
26913	25510	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:45	\N
26914	25511	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:45	\N
26915	25512	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:45	\N
26916	25513	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:45	\N
26917	25514	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:45	\N
26918	25515	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:45	\N
26919	25516	DEPUTE	1993-04-02 00:00:00	\N	1994-02-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:45	\N
26920	25517	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:45	\N
26921	25518	DEPUTE	1968-07-11 00:00:00	\N	1971-10-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:45	\N
26922	25519	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:45	\N
26923	25520	DEPUTE	1995-08-17 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:45	\N
26924	25521	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:45	\N
26925	25522	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:45	\N
26926	25523	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:45	\N
26927	25524	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:45	\N
26928	25525	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:45	\N
26929	25526	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:45	\N
26930	25527	DEPUTE	1993-04-02 00:00:00	\N	1993-11-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:45	\N
26931	25528	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:45	\N
26932	25529	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:45	\N
26933	25530	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:45	\N
26934	25531	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:45	\N
26935	25532	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:45	\N
26936	25533	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:45	\N
26937	25534	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:45	\N
26938	25535	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:45	\N
26939	25536	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:45	\N
26940	25537	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:45	\N
26941	25538	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:45	\N
26942	25539	DEPUTE	1973-05-06 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:45	\N
26943	25540	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:45	\N
26944	25541	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:45	\N
26945	25542	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:45	\N
26946	25543	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:45	\N
26947	25544	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:45	\N
26948	25545	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26949	25546	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26950	25547	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26951	25548	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26952	25549	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26953	25550	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26954	25551	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26955	25552	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26956	25553	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26957	25554	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26958	25555	DEPUTE	2012-06-20 00:00:00	\N	2012-10-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26959	25556	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26960	25557	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26961	25558	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26962	25559	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26963	25560	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26964	25561	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26965	25562	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26966	25563	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26967	25564	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26968	25565	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26969	25566	DEPUTE	1968-07-11 00:00:00	\N	1969-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26970	25567	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26971	25568	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26972	25569	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26973	25570	DEPUTE	1997-06-01 00:00:00	\N	1998-09-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26974	25571	QUESTAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26975	25572	QUESTAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26976	25573	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26977	25574	DEPUTE	1968-07-11 00:00:00	\N	1969-07-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26978	25575	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26979	25576	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26980	25577	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26981	25578	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26982	25579	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26983	25580	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26984	25581	DEPUTE	1997-05-25 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26985	25582	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26986	25583	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26987	25584	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26988	25585	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26989	25586	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26990	25587	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26991	25588	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26992	25589	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26993	25590	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26994	25591	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26995	25592	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26996	25593	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26997	25594	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:46	\N
26998	25595	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:47	\N
26999	25596	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:47	\N
27000	25597	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:47	\N
27001	25598	DEPUTE	1988-10-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:47	\N
27002	25599	DEPUTE	1995-05-10 00:00:00	\N	1995-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:47	\N
27003	25600	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:47	\N
27004	25601	DEPUTE	1968-07-11 00:00:00	\N	1971-02-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:41:47	\N
22636	21233	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
22637	21234	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
22638	21235	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
22639	21236	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
22640	21237	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
22641	21238	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
22642	21239	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
22643	21240	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
22644	21241	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
22645	21242	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
22646	21243	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
22647	21244	DEPUTE	1991-06-18 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
22648	21245	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
22649	21246	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
22650	21247	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
22651	21248	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
22652	21249	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
22653	21250	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
22654	21251	DEPUTE	1995-06-19 00:00:00	\N	1995-11-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
22655	21252	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
22656	21253	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:44	\N
22657	21254	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:45	\N
22658	21255	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:45	\N
22659	21256	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:45	\N
22660	21257	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:45	\N
22661	21258	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:45	\N
22662	21259	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:45	\N
22663	21260	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:45	\N
22664	21261	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:45	\N
22665	21262	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:45	\N
22666	21263	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:45	\N
22667	21264	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:45	\N
22668	21265	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:45	\N
22669	21266	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:45	\N
22670	21267	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:45	\N
22671	21268	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:45	\N
22672	21269	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:45	\N
22673	21270	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:45	\N
22674	21271	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:45	\N
22675	21272	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:45	\N
22676	21273	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:45	\N
22677	21274	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:45	\N
22678	21275	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:45	\N
22679	21276	QUESTAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:45	\N
22680	21277	DEPUTE	1978-04-02 00:00:00	\N	1978-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:45	\N
22681	21278	DEPUTE	1981-07-02 00:00:00	\N	1983-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:45	\N
22682	21279	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:45	\N
22683	21280	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:45	\N
22684	21281	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:45	\N
22685	21282	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:45	\N
22686	21283	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:45	\N
22687	21284	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:45	\N
22688	21285	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:45	\N
22689	21286	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:46	\N
22690	21287	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:46	\N
22691	21288	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:46	\N
22692	21289	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:46	\N
22693	21290	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:46	\N
22694	21291	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:46	\N
22695	21292	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:46	\N
22696	21293	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:46	\N
22697	21294	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:46	\N
22698	21295	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:46	\N
22699	21296	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:46	\N
22700	21297	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:46	\N
22701	21298	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:46	\N
22702	21299	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:46	\N
22703	21300	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:46	\N
22704	21301	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:46	\N
22705	21302	PDTAN	2007-06-26 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:46	\N
22706	21303	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:46	\N
22707	21304	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:46	\N
22708	21305	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:46	\N
22709	21306	DEPUTE	1973-04-02 00:00:00	\N	1973-05-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:46	\N
22710	21307	DEPUTE	1986-04-02 00:00:00	\N	1986-04-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:46	\N
22711	21308	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:46	\N
22712	21309	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:46	\N
22713	21310	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:46	\N
22714	21311	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:46	\N
22715	21312	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:46	\N
22716	21313	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:46	\N
22717	21314	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:46	\N
22718	21315	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:46	\N
22719	21316	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:46	\N
22720	21317	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:46	\N
22721	21318	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:46	\N
22722	21319	DEPUTE	1999-10-01 00:00:00	\N	2000-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:46	\N
22723	21320	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:47	\N
22724	21321	DEPUTE	2002-06-19 00:00:00	\N	2004-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:47	\N
22725	21322	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:47	\N
22726	21323	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:47	\N
22727	21324	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:47	\N
22728	21325	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:39:47	\N
24124	22721	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24125	22722	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24126	22723	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24127	22724	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24128	22725	VICPDTAN	2009-10-06 00:00:00	\N	2010-10-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24129	22726	SECAN	2008-10-01 00:00:00	\N	2009-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24130	22727	SECAN	2010-10-05 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24131	22728	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24132	22729	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24133	22730	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24134	22731	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24135	22732	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24136	22733	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24137	22734	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24138	22735	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24139	22736	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24140	22737	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24141	22738	DEPUTE	2009-07-24 00:00:00	\N	2009-07-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24142	22739	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24143	22740	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24144	22741	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24145	22742	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24146	22743	SECAN	2005-10-04 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24147	22744	SECAN	2007-06-27 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24148	22745	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24149	22746	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24150	22747	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24151	22748	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24152	22749	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24153	22750	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:26	\N
24154	22751	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:27	\N
24155	22752	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:27	\N
24156	22753	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:27	\N
24157	22754	VICPDTAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:27	\N
24158	22755	VICPDTAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:27	\N
24159	22756	VICPDTAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:27	\N
24160	22757	DEPUTE	2007-06-26 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:27	\N
24161	22758	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:27	\N
24162	22759	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:27	\N
24163	22760	DEPUTE	1986-04-02 00:00:00	\N	1986-09-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:27	\N
24164	22761	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:27	\N
24165	22762	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:27	\N
24166	22763	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:27	\N
24167	22764	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:27	\N
24168	22765	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:27	\N
24169	22766	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:27	\N
24170	22767	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:27	\N
24171	22768	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:27	\N
24172	22769	DEPUTE	1978-04-03 00:00:00	\N	1981-04-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:27	\N
24173	22770	DEPUTE	1977-01-11 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:27	\N
24174	22771	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:27	\N
24175	22772	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:27	\N
24176	22773	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:27	\N
24177	22774	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:27	\N
24178	22775	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:27	\N
24179	22776	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:27	\N
24180	22777	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:27	\N
24181	22778	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:27	\N
24182	22779	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:27	\N
24183	22780	QUESTAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:27	\N
24184	22781	QUESTAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:27	\N
24185	22782	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:27	\N
24186	22783	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:27	\N
24187	22784	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:27	\N
24188	22785	DEPUTE	2002-06-19 00:00:00	\N	2003-02-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:27	\N
24189	22786	DEPUTE	2003-03-24 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:27	\N
24190	22787	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:27	\N
24191	22788	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:27	\N
24192	22789	DEPUTE	1988-06-13 00:00:00	\N	1991-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:27	\N
24193	22790	DEPUTE	1995-12-10 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:27	\N
24194	22791	DEPUTE	1997-06-01 00:00:00	\N	2000-09-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:27	\N
24195	22792	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:27	\N
24196	22793	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:27	\N
24197	22794	DEPUTE	2012-07-22 00:00:00	\N	2014-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:27	\N
24198	22795	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:28	\N
24199	22796	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:28	\N
24200	22797	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:28	\N
24201	22798	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:28	\N
24202	22799	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:28	\N
24203	22800	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:28	\N
24204	22801	DEPUTE	1973-04-03 00:00:00	\N	1973-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:28	\N
24205	22802	DEPUTE	1974-10-06 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:28	\N
24206	22803	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:28	\N
24207	22804	DEPUTE	1967-04-02 00:00:00	\N	1967-05-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:28	\N
24208	22805	DEPUTE	1968-07-11 00:00:00	\N	1968-08-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:28	\N
24209	22806	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:28	\N
24210	22807	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:28	\N
24211	22808	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:28	\N
24212	22809	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:28	\N
24213	22810	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:28	\N
24214	22811	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:28	\N
24215	22812	DEPUTE	1974-09-29 00:00:00	\N	1976-09-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:28	\N
24216	22813	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:40:28	\N
30291	28888	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:10	\N
30292	28889	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:10	\N
30293	28890	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:10	\N
30294	28891	DEPUTE	2007-06-20 00:00:00	\N	2011-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:10	\N
30295	28892	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:10	\N
30296	28893	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:10	\N
30297	28894	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:10	\N
30298	28895	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:10	\N
30299	28896	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:10	\N
30300	28897	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:10	\N
30301	28898	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:10	\N
30302	28899	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:11	\N
30303	28900	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:11	\N
30304	28901	DEPUTE	1986-04-18 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:11	\N
30305	28902	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:11	\N
30306	28903	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:11	\N
30307	28904	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:11	\N
30308	28905	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:11	\N
30309	28906	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:11	\N
30310	28907	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:11	\N
30311	28908	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:11	\N
30312	28909	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:11	\N
30313	28910	DEPUTE	2002-06-19 00:00:00	\N	2005-07-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:11	\N
30314	28911	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:11	\N
30315	28912	VICPDTAN	1989-04-03 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:11	\N
30316	28913	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:11	\N
30317	28914	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:11	\N
30318	28915	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:11	\N
30319	28916	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:11	\N
30320	28917	SECAN	2002-06-26 00:00:00	\N	2003-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:11	\N
30321	28918	SECAN	2005-10-04 00:00:00	\N	2006-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:11	\N
30322	28919	QUESTAN	2016-09-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:11	\N
30323	28920	QUESTAN	2012-06-27 00:00:00	\N	2016-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:11	\N
30324	28921	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:11	\N
30325	28922	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:11	\N
30326	28923	DEPUTE	1968-07-11 00:00:00	\N	1969-09-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:11	\N
30327	28924	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:11	\N
30328	28925	DEPUTE	1997-06-01 00:00:00	\N	2001-08-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:11	\N
30329	28926	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:11	\N
30330	28927	DEPUTE	2007-06-20 00:00:00	\N	2011-12-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:11	\N
30331	28928	VICPDTAN	1997-06-12 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:11	\N
30332	28929	VICPDTAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:11	\N
30333	28930	VICPDTAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:11	\N
30334	28931	VICPDTAN	2000-10-02 00:00:00	\N	2001-08-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:11	\N
30335	28932	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:11	\N
30336	28933	DEPUTE	2001-01-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:11	\N
30337	28934	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:11	\N
30338	28935	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:12	\N
30339	28936	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:12	\N
30340	28937	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:12	\N
30341	28938	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:12	\N
30342	28939	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:12	\N
30343	28940	VICPDTAN	1988-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:12	\N
30344	28941	VICPDTAN	1988-06-24 00:00:00	\N	1991-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:12	\N
30345	28942	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:12	\N
30346	28943	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:12	\N
30347	28944	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:12	\N
30348	28945	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:12	\N
30349	28946	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:12	\N
30350	28947	DEPUTE	1968-07-11 00:00:00	\N	1971-02-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:12	\N
30351	28948	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:12	\N
30352	28949	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:12	\N
30353	28950	DEPUTE	1978-04-03 00:00:00	\N	1978-11-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:12	\N
30354	28951	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:12	\N
30355	28952	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:12	\N
30356	28953	QUESTAN	1988-06-24 00:00:00	\N	1990-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:12	\N
30357	28954	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:12	\N
30358	28955	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:12	\N
30359	28956	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:12	\N
30360	28957	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:12	\N
30361	28958	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:12	\N
30362	28959	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:12	\N
30363	28960	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:12	\N
30364	28961	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:12	\N
30365	28962	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:12	\N
30366	28963	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:13	\N
30367	28964	VICPDTAN	1996-10-01 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:13	\N
30368	28965	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:13	\N
30369	28966	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:13	\N
30370	28967	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:13	\N
30371	28968	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:13	\N
30372	28969	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:13	\N
30373	28970	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:13	\N
30374	28971	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:13	\N
30375	28972	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:13	\N
29246	27843	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:55	\N
30376	28973	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:13	\N
30377	28974	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:13	\N
30378	28975	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:13	\N
30379	28976	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:13	\N
30380	28977	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:13	\N
30381	28978	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:13	\N
30382	28979	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:13	\N
30756	29353	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:25	\N
30757	29354	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:25	\N
30758	29355	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:25	\N
30759	29356	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:25	\N
30760	29357	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:25	\N
30761	29358	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:25	\N
30762	29359	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:25	\N
30763	29360	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:25	\N
30764	29361	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:25	\N
30765	29362	DEPUTE	1986-04-02 00:00:00	\N	1986-04-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:25	\N
30766	29363	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:26	\N
30767	29364	DEPUTE	1988-09-19 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:26	\N
30768	29365	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:26	\N
30769	29366	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:26	\N
30770	29367	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:26	\N
30771	29368	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:26	\N
30772	29369	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:26	\N
30773	29370	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:26	\N
30774	29371	DEPUTE	1981-07-24 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:26	\N
30775	29372	DEPUTE	1992-02-03 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:26	\N
30776	29373	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:26	\N
30777	29374	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:26	\N
30778	29375	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:26	\N
30779	29376	DEPUTE	2005-09-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:26	\N
30780	29377	DEPUTE	2007-06-20 00:00:00	\N	2010-04-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:26	\N
30781	29378	DEPUTE	2010-12-14 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:26	\N
30782	29379	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:26	\N
30783	29380	VICPDTAN	2002-06-26 00:00:00	\N	2003-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:26	\N
30784	29381	VICPDTAN	2003-10-01 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:26	\N
30785	29382	VICPDTAN	2007-06-27 00:00:00	\N	2008-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:26	\N
30786	29383	DEPUTE	1997-06-01 00:00:00	\N	2001-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:26	\N
30787	29384	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:26	\N
30788	29385	DEPUTE	1990-08-18 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:26	\N
30789	29386	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:26	\N
30790	29387	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:26	\N
30791	29388	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:26	\N
30792	29389	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:26	\N
30793	29390	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:26	\N
30794	29391	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:26	\N
30795	29392	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:26	\N
30796	29393	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:26	\N
30797	29394	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:26	\N
30798	29395	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:26	\N
30799	29396	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:26	\N
30800	29397	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:26	\N
30801	29398	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:26	\N
30802	29399	DEPUTE	1993-04-02 00:00:00	\N	1994-12-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:26	\N
30803	29400	DEPUTE	2004-06-28 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:26	\N
30804	29401	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:26	\N
30805	29402	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:26	\N
30806	29403	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:26	\N
30807	29404	DEPUTE	1963-05-05 00:00:00	\N	1966-02-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:26	\N
30808	29405	DEPUTE	1967-04-03 00:00:00	\N	1967-05-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:26	\N
30809	29406	DEPUTE	1968-07-11 00:00:00	\N	1968-08-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:26	\N
30810	29407	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:26	\N
30811	29408	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30812	29409	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30813	29410	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30814	29411	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30815	29412	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30816	29413	DEPUTE	2002-06-19 00:00:00	\N	2007-03-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30817	29414	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30818	29415	PDTAN	2002-06-26 00:00:00	\N	2007-03-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30819	29416	DEPUTE	1988-01-25 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30820	29417	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30821	29418	DEPUTE	2002-06-19 00:00:00	\N	2002-10-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30822	29419	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30823	29420	DEPUTE	2002-12-16 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30824	29421	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30825	29422	DEPUTE	1984-01-19 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30826	29423	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30827	29424	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30828	29425	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30829	29426	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30830	29427	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30831	29428	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30832	29429	DEPUTE	1986-04-02 00:00:00	\N	1986-05-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30833	29430	DEPUTE	1999-03-29 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30834	29431	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30835	29432	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30836	29433	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30837	29434	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30838	29435	SECAN	2004-10-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30839	29436	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30840	29437	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30841	29438	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30842	29439	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30843	29440	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30844	29441	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30845	29442	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30846	29443	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30847	29444	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30848	29445	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
22516	21121	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:56	\N
22518	21123	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:43:51	\N
22519	21124	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:43:55	\N
22520	21125	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:43:59	\N
22521	21126	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:44:02	\N
22522	21127	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:44:05	\N
32708	31305	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:27	\N
32709	31306	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:27	\N
32710	31307	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:27	\N
32711	31308	DEPUTE	1988-06-13 00:00:00	\N	1992-04-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:27	\N
32712	31309	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:27	\N
32713	31310	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:27	\N
32714	31311	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:27	\N
32715	31312	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:27	\N
32716	31313	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:27	\N
32717	31314	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:27	\N
32718	31315	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:27	\N
32719	31316	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:27	\N
32720	31317	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:27	\N
32721	31318	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:27	\N
32722	31319	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:27	\N
32723	31320	DEPUTE	2007-06-20 00:00:00	\N	2011-07-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:27	\N
32724	31321	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:27	\N
32725	31322	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:27	\N
32726	31323	SECAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:27	\N
32727	31324	SECAN	1995-05-31 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:27	\N
32728	31325	VICPDTAN	2007-06-27 00:00:00	\N	2011-07-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:27	\N
32729	31326	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:27	\N
32730	31327	DEPUTE	1981-07-02 00:00:00	\N	1982-07-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:27	\N
32731	31328	DEPUTE	1982-09-05 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:27	\N
32732	31329	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:27	\N
32733	31330	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:27	\N
32734	31331	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:27	\N
32735	31332	DEPUTE	1997-05-25 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:27	\N
32736	31333	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:27	\N
32737	31334	DEPUTE	1976-02-13 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:27	\N
32738	31335	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:27	\N
32739	31336	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:27	\N
32740	31337	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32741	31338	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32742	31339	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32743	31340	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32744	31341	DEPUTE	1997-06-12 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32745	31342	DEPUTE	1973-04-02 00:00:00	\N	1977-06-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32746	31343	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32747	31344	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32748	31345	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32749	31346	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32750	31347	DEPUTE	1993-04-02 00:00:00	\N	1993-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32751	31348	DEPUTE	1993-09-20 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32752	31349	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32753	31350	DEPUTE	2000-02-07 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32754	31351	DEPUTE	1997-06-01 00:00:00	\N	1997-12-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32755	31352	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32756	31353	DEPUTE	2012-06-20 00:00:00	\N	2017-03-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32757	31354	PDTAN	1992-01-22 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32758	31355	DEPUTE	1993-05-02 00:00:00	\N	1995-05-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32759	31356	DEPUTE	1981-07-02 00:00:00	\N	1986-02-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32760	31357	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32761	31358	DEPUTE	1983-04-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32762	31359	DEPUTE	1998-05-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32763	31360	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32764	31361	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32765	31362	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32766	31363	DEPUTE	1993-04-02 00:00:00	\N	1993-12-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32767	31364	DEPUTE	2002-06-19 00:00:00	\N	2005-07-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32768	31365	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32769	31366	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32770	31367	DEPUTE	2008-05-26 00:00:00	\N	2009-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32771	31368	DEPUTE	2010-12-14 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32772	31369	DEPUTE	2012-06-20 00:00:00	\N	2016-03-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32773	31370	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32774	31371	DEPUTE	1997-06-01 00:00:00	\N	2001-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32775	31372	DEPUTE	1999-12-10 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32776	31373	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32777	31374	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32778	31375	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32779	31376	DEPUTE	1991-09-26 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32780	31377	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32781	31378	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32782	31379	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32783	31380	VICPDTAN	1986-04-04 00:00:00	\N	1987-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32784	31381	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32785	31382	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32786	31383	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:28	\N
32787	31384	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:29	\N
32788	31385	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:29	\N
32789	31386	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:29	\N
32790	31387	DEPUTE	1997-06-01 00:00:00	\N	2000-04-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:29	\N
32791	31388	DEPUTE	2007-06-20 00:00:00	\N	2012-06-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:29	\N
32792	31389	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:29	\N
32793	31390	PDTAN	1988-06-23 00:00:00	\N	1992-01-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:29	\N
32794	31391	PDTAN	1997-06-12 00:00:00	\N	2000-03-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:29	\N
28584	27181	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:32	\N
28585	27182	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:32	\N
28586	27183	DEPUTE	2011-05-03 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:32	\N
28587	27184	DEPUTE	2010-04-01 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:32	\N
28588	27185	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:32	\N
28589	27186	DEPUTE	2016-05-30 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:32	\N
28590	27187	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:32	\N
28591	27188	DEPUTE	2008-06-02 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:32	\N
28592	27189	DEPUTE	2012-03-23 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:32	\N
28593	27190	DEPUTE	2012-06-20 00:00:00	\N	2017-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:32	\N
28594	27191	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:32	\N
28595	27192	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:32	\N
28596	27193	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:32	\N
28597	27194	DEPUTE	2008-04-20 00:00:00	\N	2009-07-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:32	\N
28598	27195	DEPUTE	2009-01-13 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:32	\N
28599	27196	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:32	\N
28600	27197	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:32	\N
28601	27198	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:33	\N
28602	27199	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:33	\N
28603	27200	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:33	\N
28604	27201	DEPUTE	2008-12-15 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:33	\N
28605	27202	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:33	\N
28606	27203	DEPUTE	2008-02-04 00:00:00	\N	2008-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:33	\N
28607	27204	DEPUTE	2007-12-16 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:33	\N
28608	27205	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:33	\N
28609	27206	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:33	\N
28610	27207	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:33	\N
28611	27208	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:33	\N
28612	27209	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:33	\N
28613	27210	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:33	\N
28614	27211	DEPUTE	2014-05-03 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:33	\N
28615	27212	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:33	\N
28616	27213	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:33	\N
28617	27214	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:33	\N
28618	27215	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:33	\N
28619	27216	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:33	\N
28620	27217	DEPUTE	2008-04-13 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:33	\N
28621	27218	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:33	\N
28622	27219	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:33	\N
28623	27220	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:33	\N
28624	27221	DEPUTE	2009-10-19 00:00:00	\N	2011-07-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:33	\N
28625	27222	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:33	\N
28626	27223	DEPUTE	2011-07-30 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:33	\N
28627	27224	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:33	\N
28628	27225	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:33	\N
28629	27226	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:33	\N
28630	27227	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:33	\N
28631	27228	DEPUTE	2010-07-12 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:33	\N
28632	27229	DEPUTE	2016-03-21 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:33	\N
28633	27230	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:33	\N
28634	27231	DEPUTE	2016-03-21 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:34	\N
28635	27232	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:34	\N
28636	27233	DEPUTE	2016-03-21 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:34	\N
28637	27234	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:34	\N
28638	27235	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:34	\N
28639	27236	DEPUTE	1968-07-11 00:00:00	\N	1968-08-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:34	\N
28640	27237	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:34	\N
28641	27238	DEPUTE	2014-05-03 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:34	\N
28642	27239	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:34	\N
28643	27240	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:34	\N
28644	27241	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:34	\N
28645	27242	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:34	\N
28646	27243	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:34	\N
28647	27244	DEPUTE	2014-12-22 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:34	\N
28648	27245	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:34	\N
28649	27246	DEPUTE	2014-09-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:34	\N
28650	27247	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:34	\N
28651	27248	DEPUTE	2014-05-03 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:34	\N
28652	27249	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:34	\N
28653	27250	SECAN	1987-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:34	\N
28654	27251	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:34	\N
28655	27252	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:34	\N
28656	27253	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:34	\N
28657	27254	DEPUTE	2007-06-20 00:00:00	\N	2010-04-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:34	\N
28658	27255	DEPUTE	2011-06-30 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:34	\N
28659	27256	DEPUTE	2011-10-28 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:34	\N
28660	27257	DEPUTE	2009-07-23 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:34	\N
28661	27258	DEPUTE	2010-06-11 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:34	\N
28662	27259	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:34	\N
28663	27260	DEPUTE	2010-12-15 00:00:00	\N	2012-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:34	\N
28664	27261	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:34	\N
28665	27262	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:34	\N
28666	27263	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:34	\N
28667	27264	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:35	\N
28668	27265	DEPUTE	2007-06-20 00:00:00	\N	2011-05-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:35	\N
28669	27266	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:35	\N
28670	27267	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:35	\N
28671	27268	DEPUTE	2012-06-20 00:00:00	\N	2014-05-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:35	\N
28672	27269	DEPUTE	2014-06-30 00:00:00	\N	2014-07-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:35	\N
28673	27270	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:35	\N
28674	27271	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:35	\N
28675	27272	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:35	\N
28676	27273	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:35	\N
28677	27274	DEPUTE	2014-09-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:35	\N
30383	28980	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:13	\N
30850	29447	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30851	29448	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30852	29449	DEPUTE	1976-11-18 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30853	29450	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30854	29451	DEPUTE	1986-04-18 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30855	29452	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30856	29453	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30857	29454	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30858	29455	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30859	29456	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30860	29457	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30861	29458	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30862	29459	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
30863	29460	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:28	\N
30864	29461	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:28	\N
30865	29462	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:28	\N
30866	29463	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:28	\N
30867	29464	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:28	\N
30868	29465	DEPUTE	1997-06-01 00:00:00	\N	2001-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:28	\N
30869	29466	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:28	\N
30870	29467	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:28	\N
30871	29468	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:28	\N
30872	29469	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:28	\N
30873	29470	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:28	\N
30874	29471	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:28	\N
30875	29472	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:28	\N
30876	29473	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:28	\N
30877	29474	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:28	\N
30878	29475	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:28	\N
30879	29476	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:28	\N
30880	29477	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:28	\N
30881	29478	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:28	\N
30882	29479	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:28	\N
30883	29480	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:28	\N
30884	29481	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:28	\N
30885	29482	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:28	\N
30886	29483	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:28	\N
30887	29484	DEPUTE	1997-06-01 00:00:00	\N	1998-07-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:28	\N
30888	29485	DEPUTE	2007-06-20 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:28	\N
30889	29486	DEPUTE	1975-10-03 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:28	\N
30890	29487	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:28	\N
30891	29488	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:28	\N
30892	29489	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:28	\N
30893	29490	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:28	\N
30894	29491	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:28	\N
30895	29492	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:28	\N
30896	29493	DEPUTE	1978-05-06 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:28	\N
30897	29494	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:28	\N
30898	29495	DEPUTE	1986-04-02 00:00:00	\N	1988-01-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:28	\N
30899	29496	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:28	\N
30900	29497	DEPUTE	1981-07-02 00:00:00	\N	1986-02-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:28	\N
30901	29498	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:29	\N
30902	29499	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:29	\N
30903	29500	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:29	\N
30904	29501	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:29	\N
30905	29502	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:29	\N
30906	29503	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:29	\N
30907	29504	DEPUTE	1994-09-13 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:29	\N
30908	29505	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:29	\N
30909	29506	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:29	\N
30910	29507	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:29	\N
30911	29508	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:29	\N
30912	29509	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:29	\N
30913	29510	DEPUTE	2008-12-01 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:29	\N
30914	29511	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:29	\N
30915	29512	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:29	\N
30916	29513	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:29	\N
30917	29514	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:29	\N
30918	29515	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:29	\N
30919	29516	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:29	\N
30920	29517	DEPUTE	2007-06-20 00:00:00	\N	2008-11-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:29	\N
30921	29518	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:29	\N
30922	29519	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:29	\N
30923	29520	DEPUTE	1993-04-02 00:00:00	\N	1995-09-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:29	\N
30924	29521	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:29	\N
30925	29522	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:29	\N
30926	29523	DEPUTE	1968-07-11 00:00:00	\N	1972-08-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:29	\N
30927	29524	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:29	\N
30928	29525	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:29	\N
30929	29526	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:29	\N
30930	29527	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:29	\N
30931	29528	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:29	\N
30932	29529	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:29	\N
30933	29530	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:29	\N
30934	29531	DEPUTE	1978-04-03 00:00:00	\N	1978-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:29	\N
30935	29532	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:29	\N
30936	29533	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:30	\N
30937	29534	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:30	\N
30938	29535	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:30	\N
30939	29536	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:30	\N
30940	29537	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:30	\N
30941	29538	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:30	\N
30849	29446	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:27	\N
31872	30469	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:57	\N
31873	30470	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:57	\N
31874	30471	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:57	\N
31875	30472	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:57	\N
31876	30473	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:57	\N
31877	30474	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:57	\N
31878	30475	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:57	\N
31879	30476	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:57	\N
31880	30477	DEPUTE	1993-04-02 00:00:00	\N	1996-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:57	\N
31881	30478	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:57	\N
31882	30479	DEPUTE	1981-07-02 00:00:00	\N	1985-08-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:57	\N
31883	30480	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:57	\N
31884	30481	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:57	\N
31885	30482	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:57	\N
31886	30483	VICPDTAN	1991-04-02 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:57	\N
31887	30484	VICPDTAN	1998-10-28 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:57	\N
31888	30485	VICPDTAN	1999-10-01 00:00:00	\N	2000-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:57	\N
31889	30486	PDTAN	2000-03-29 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:57	\N
31890	30487	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:57	\N
31891	30488	DEPUTE	1981-07-22 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:57	\N
31892	30489	DEPUTE	1986-09-30 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:57	\N
31893	30490	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:57	\N
31894	30491	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:57	\N
31895	30492	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:57	\N
31896	30493	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:57	\N
31897	30494	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:57	\N
31898	30495	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:57	\N
31899	30496	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:58	\N
31900	30497	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:58	\N
31901	30498	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:58	\N
31902	30499	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:58	\N
31903	30500	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:58	\N
31904	30501	DEPUTE	1973-04-03 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:58	\N
31905	30502	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:58	\N
31906	30503	DEPUTE	1959-03-07 00:00:00	\N	1960-03-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:58	\N
31907	30504	DEPUTE	1962-12-06 00:00:00	\N	1963-01-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:58	\N
31908	30505	DEPUTE	1967-04-02 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:58	\N
31909	30506	DEPUTE	1968-07-11 00:00:00	\N	1972-08-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:58	\N
31910	30507	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:58	\N
31911	30508	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:58	\N
31912	30509	DEPUTE	1981-07-23 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:58	\N
31913	30510	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:58	\N
31914	30511	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:58	\N
31915	30512	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:58	\N
31916	30513	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:58	\N
31917	30514	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:58	\N
31918	30515	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:58	\N
31919	30516	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:58	\N
31920	30517	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:58	\N
31921	30518	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:58	\N
31922	30519	DEPUTE	1986-04-02 00:00:00	\N	1988-03-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:58	\N
31923	30520	DEPUTE	2002-07-19 00:00:00	\N	2005-01-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:58	\N
31924	30521	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:58	\N
31925	30522	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:58	\N
31926	30523	DEPUTE	2005-07-03 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:58	\N
31927	30524	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:58	\N
31928	30525	DEPUTE	1998-04-06 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:58	\N
31929	30526	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:59	\N
31930	30527	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:59	\N
31931	30528	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:59	\N
31932	30529	DEPUTE	1992-05-03 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:59	\N
31933	30530	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:59	\N
31934	30531	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:59	\N
31935	30532	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:59	\N
31936	30533	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:59	\N
31937	30534	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:59	\N
31938	30535	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:59	\N
31939	30536	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:59	\N
31940	30537	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:59	\N
31941	30538	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:59	\N
31942	30539	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:59	\N
31943	30540	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:59	\N
31944	30541	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:59	\N
31945	30542	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:59	\N
31946	30543	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:59	\N
31947	30544	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:59	\N
31948	30545	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:59	\N
31949	30546	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:59	\N
31950	30547	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:59	\N
31951	30548	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:59	\N
31952	30549	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:59	\N
31953	30550	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:59	\N
31954	30551	DEPUTE	2001-11-24 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:59	\N
31955	30552	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:59	\N
31956	30553	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:59	\N
31957	30554	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:59	\N
31958	30555	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:00	\N
31959	30556	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:00	\N
31960	30557	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:00	\N
31961	30558	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:00	\N
31962	30559	DEPUTE	2012-06-20 00:00:00	\N	2014-04-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:00	\N
31963	30560	DEPUTE	1996-11-27 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:00	\N
32795	31392	DEPUTE	1978-04-02 00:00:00	\N	1980-11-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:29	\N
32796	31393	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:29	\N
32797	31394	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:29	\N
32798	31395	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:29	\N
32799	31396	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:29	\N
32800	31397	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:29	\N
32801	31398	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:29	\N
32802	31399	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:29	\N
32803	31400	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:29	\N
32804	31401	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:29	\N
32805	31402	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:29	\N
32806	31403	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:29	\N
32807	31404	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:29	\N
32808	31405	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:29	\N
32809	31406	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:29	\N
32810	31407	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:29	\N
32811	31408	DEPUTE	1993-04-02 00:00:00	\N	1995-09-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:29	\N
32812	31409	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:29	\N
32813	31410	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:29	\N
32814	31411	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:29	\N
32815	31412	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:29	\N
32816	31413	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:29	\N
32817	31414	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:29	\N
32818	31415	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:29	\N
32819	31416	DEPUTE	1968-07-11 00:00:00	\N	1969-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:29	\N
32820	31417	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:29	\N
32821	31418	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:29	\N
32822	31419	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:29	\N
32823	31420	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:29	\N
32824	31421	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:29	\N
32825	31422	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:30	\N
32826	31423	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:30	\N
32827	31424	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:30	\N
32828	31425	DEPUTE	1978-04-02 00:00:00	\N	1980-09-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:30	\N
32829	31426	DEPUTE	1981-07-02 00:00:00	\N	1983-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:30	\N
32830	31427	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:30	\N
32831	31428	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:30	\N
32832	31429	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:30	\N
32833	31430	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:30	\N
32834	31431	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:30	\N
32835	31432	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:30	\N
32836	31433	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:30	\N
32837	31434	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:30	\N
32838	31435	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:30	\N
32839	31436	SECAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:30	\N
32840	31437	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:30	\N
32841	31438	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:30	\N
32842	31439	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:30	\N
32843	31440	DEPUTE	1973-04-02 00:00:00	\N	1974-04-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:30	\N
32844	31441	DEPUTE	1975-07-07 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:30	\N
32845	31442	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:30	\N
32846	31443	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:30	\N
32847	31444	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:30	\N
32848	31445	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:30	\N
32849	31446	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:30	\N
32850	31447	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:30	\N
32851	31448	SECAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:30	\N
32852	31449	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:30	\N
32853	31450	SECAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:30	\N
32854	31451	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:30	\N
32855	31452	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:30	\N
32856	31453	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:30	\N
32857	31454	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:30	\N
32858	31455	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:30	\N
32859	31456	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:30	\N
32860	31457	SECAN	1997-06-13 00:00:00	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:30	\N
32861	31458	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:30	\N
32862	31459	VICPDTAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:30	\N
32863	31460	SECAN	2012-06-27 00:00:00	\N	2013-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:31	\N
32864	31461	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:31	\N
32865	31462	DEPUTE	1986-04-02 00:00:00	\N	1987-12-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:31	\N
32866	31463	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:31	\N
32867	31464	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:31	\N
32868	31465	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:31	\N
32869	31466	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:31	\N
32870	31467	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:31	\N
32871	31468	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:31	\N
32872	31469	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:31	\N
32873	31470	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:31	\N
32874	31471	DEPUTE	2007-06-20 00:00:00	\N	2010-12-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:31	\N
32875	31472	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:31	\N
32876	31473	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:31	\N
32877	31474	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:31	\N
32878	31475	VICPDTAN	2004-10-01 00:00:00	\N	2006-11-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:31	\N
32879	31476	VICPDTAN	2009-10-06 00:00:00	\N	2010-11-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:31	\N
32880	31477	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:31	\N
32881	31478	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:31	\N
32882	31479	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:31	\N
32883	31480	DEPUTE	1981-04-15 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:31	\N
32884	31481	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:31	\N
32885	31482	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:31	\N
32886	31483	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:31	\N
32887	31484	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:32	\N
22532	21129	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-22 03:44:39	\N
22533	21130	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-22 03:45:09	\N
22534	21131	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-22 03:45:10	\N
22535	21132	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-22 03:45:15	\N
22536	21133	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-22 03:45:17	\N
22537	21134	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-22 03:45:19	\N
22538	21135	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-22 03:45:21	\N
22539	21136	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-22 03:45:23	\N
28678	27275	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:35	\N
28679	27276	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:35	\N
28680	27277	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:35	\N
28681	27278	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:35	\N
28682	27279	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:35	\N
28683	27280	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:35	\N
28684	27281	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:35	\N
28685	27282	DEPUTE	2015-04-06 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:35	\N
28686	27283	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:35	\N
28687	27284	DEPUTE	2012-06-20 00:00:00	\N	2017-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:35	\N
28688	27285	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:35	\N
28689	27286	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:35	\N
28690	27287	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:35	\N
28691	27288	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:35	\N
28692	27289	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:35	\N
28693	27290	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:35	\N
28694	27291	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:35	\N
28695	27292	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:35	\N
28696	27293	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:35	\N
28697	27294	DEPUTE	2007-06-20 00:00:00	\N	2008-03-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:35	\N
28698	27295	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:35	\N
28699	27296	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:35	\N
28700	27297	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:35	\N
28701	27298	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:36	\N
28702	27299	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:36	\N
28703	27300	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:36	\N
28704	27301	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:36	\N
28705	27302	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:36	\N
28706	27303	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:36	\N
28707	27304	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:36	\N
28708	27305	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:36	\N
28709	27306	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:36	\N
28710	27307	DEPUTE	2014-09-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:36	\N
28711	27308	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:36	\N
28712	27309	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:36	\N
28713	27310	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:36	\N
28714	27311	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:36	\N
28715	27312	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:36	\N
28716	27313	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:36	\N
28717	27314	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:36	\N
28718	27315	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:36	\N
28719	27316	VICPDTAN	2011-10-03 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:36	\N
28720	27317	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:36	\N
28721	27318	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:36	\N
28722	27319	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:36	\N
28723	27320	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:36	\N
28724	27321	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:36	\N
28725	27322	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:36	\N
28726	27323	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:36	\N
28727	27324	DEPUTE	2007-06-26 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:36	\N
28728	27325	SECAN	2007-06-27 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:36	\N
28729	27326	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:36	\N
28730	27327	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:36	\N
28731	27328	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:36	\N
28732	27329	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:36	\N
28733	27330	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:36	\N
28734	27331	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28735	27332	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28736	27333	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28737	27334	DEPUTE	2007-06-26 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28738	27335	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28739	27336	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28740	27337	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28741	27338	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28742	27339	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28743	27340	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28744	27341	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28745	27342	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28746	27343	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28747	27344	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28748	27345	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28749	27346	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28750	27347	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28751	27348	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28752	27349	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28753	27350	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28754	27351	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28755	27352	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28756	27353	DEPUTE	2016-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28757	27354	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28758	27355	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28759	27356	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28760	27357	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28761	27358	DEPUTE	2014-07-04 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28762	27359	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28763	27360	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
30942	29539	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:30	\N
30943	29540	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:30	\N
30944	29541	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:30	\N
30945	29542	DEPUTE	1956-01-19 00:00:00	\N	1958-06-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:30	\N
30946	29543	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:30	\N
30947	29544	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:30	\N
30948	29545	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:30	\N
30949	29546	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:30	\N
30950	29547	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:30	\N
30951	29548	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:30	\N
30952	29549	DEPUTE	1995-12-10 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:30	\N
30953	29550	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:30	\N
30954	29551	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:30	\N
30955	29552	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:30	\N
30956	29553	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:30	\N
30957	29554	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:30	\N
30958	29555	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:30	\N
30959	29556	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:30	\N
30960	29557	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:30	\N
30961	29558	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:30	\N
30962	29559	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:30	\N
30963	29560	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:30	\N
30964	29561	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:30	\N
30965	29562	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:30	\N
30966	29563	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:30	\N
30967	29564	SECAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:30	\N
30968	29565	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:30	\N
30969	29566	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:31	\N
30970	29567	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:31	\N
30971	29568	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:31	\N
30972	29569	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:31	\N
30973	29570	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:31	\N
30974	29571	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:31	\N
30975	29572	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:31	\N
30976	29573	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:31	\N
30977	29574	QUESTAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:31	\N
30978	29575	QUESTAN	1994-04-02 00:00:00	\N	1995-04-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:31	\N
30979	29576	QUESTAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:31	\N
30980	29577	QUESTAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:31	\N
30981	29578	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:31	\N
30982	29579	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:31	\N
30983	29580	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:31	\N
30984	29581	SECAN	2007-06-27 00:00:00	\N	2010-10-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:31	\N
30985	29582	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:31	\N
30986	29583	DEPUTE	1972-04-14 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:31	\N
30987	29584	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:31	\N
30988	29585	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:31	\N
30989	29586	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:31	\N
30990	29587	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:31	\N
30991	29588	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:31	\N
30992	29589	DEPUTE	1997-06-01 00:00:00	\N	2001-09-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:31	\N
30993	29590	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:31	\N
30994	29591	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:31	\N
30995	29592	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:31	\N
30996	29593	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:31	\N
30997	29594	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:31	\N
30998	29595	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:31	\N
30999	29596	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:31	\N
31000	29597	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:31	\N
31001	29598	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:31	\N
31002	29599	DEPUTE	1988-06-06 00:00:00	\N	1988-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:31	\N
31003	29600	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:32	\N
31004	29601	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:32	\N
31005	29602	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:32	\N
31006	29603	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:32	\N
31007	29604	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:32	\N
31008	29605	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:32	\N
31009	29606	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:32	\N
31010	29607	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:32	\N
31011	29608	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:32	\N
31012	29609	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:32	\N
31013	29610	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:32	\N
31014	29611	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:32	\N
31015	29612	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:32	\N
31016	29613	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:32	\N
31017	29614	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:32	\N
31018	29615	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:32	\N
31019	29616	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:32	\N
31020	29617	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:32	\N
31021	29618	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:32	\N
31022	29619	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:32	\N
31023	29620	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:32	\N
31024	29621	DEPUTE	2007-06-20 00:00:00	\N	2009-01-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:32	\N
31025	29622	DEPUTE	2005-10-04 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:32	\N
31026	29623	DEPUTE	2010-12-14 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:32	\N
31027	29624	DEPUTE	2012-06-20 00:00:00	\N	2012-10-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:32	\N
31028	29625	DEPUTE	2012-12-17 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:32	\N
31029	29626	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:32	\N
31030	29627	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:33	\N
31031	29628	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:33	\N
31032	29629	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:33	\N
31033	29630	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:33	\N
31034	29631	DEPUTE	1998-09-27 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:33	\N
31964	30561	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:00	\N
31965	30562	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:00	\N
31966	30563	DEPUTE	2007-06-20 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:00	\N
31967	30564	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:00	\N
31968	30565	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:00	\N
31969	30566	DEPUTE	1994-02-08 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:00	\N
31970	30567	DEPUTE	2000-04-28 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:00	\N
31971	30568	DEPUTE	1981-07-02 00:00:00	\N	1981-12-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:00	\N
31972	30569	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:00	\N
31973	30570	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:00	\N
31974	30571	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:00	\N
31975	30572	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:00	\N
31976	30573	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:00	\N
31977	30574	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:00	\N
31978	30575	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:00	\N
31979	30576	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:00	\N
31980	30577	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:00	\N
31981	30578	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:00	\N
31982	30579	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:00	\N
31983	30580	DEPUTE	1988-07-29 00:00:00	\N	1988-11-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:00	\N
31984	30581	DEPUTE	1981-07-02 00:00:00	\N	1985-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:00	\N
31985	30582	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:01	\N
31986	30583	DEPUTE	1981-07-02 00:00:00	\N	1985-12-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:01	\N
31987	30584	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:01	\N
31988	30585	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:01	\N
31989	30586	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:01	\N
31990	30587	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:01	\N
31991	30588	VICPDTAN	1995-06-15 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:01	\N
31992	30589	VICPDTAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:01	\N
31993	30590	QUESTAN	2004-05-05 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:01	\N
31994	30591	QUESTAN	2002-06-26 00:00:00	\N	2004-05-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:01	\N
31995	30592	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:01	\N
31996	30593	SECAN	1992-04-02 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:01	\N
31997	30594	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:01	\N
31998	30595	DEPUTE	1994-02-08 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:01	\N
31999	30596	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:01	\N
32000	30597	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:01	\N
32001	30598	DEPUTE	1978-04-03 00:00:00	\N	1978-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:01	\N
32002	30599	DEPUTE	1968-07-11 00:00:00	\N	1968-08-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:01	\N
32003	30600	DEPUTE	1973-04-02 00:00:00	\N	1973-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:01	\N
32004	30601	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:01	\N
32005	30602	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:01	\N
32006	30603	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:01	\N
32007	30604	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:01	\N
32008	30605	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:01	\N
32009	30606	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:01	\N
32010	30607	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:02	\N
32011	30608	DEPUTE	2007-07-20 00:00:00	\N	2010-12-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:02	\N
32012	30609	DEPUTE	1981-07-02 00:00:00	\N	1983-04-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:02	\N
32013	30610	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:02	\N
32014	30611	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:02	\N
32015	30612	DEPUTE	1997-06-12 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:02	\N
32016	30613	DEPUTE	1999-10-01 00:00:00	\N	2000-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:02	\N
32017	30614	DEPUTE	1991-02-04 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:02	\N
32018	30615	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:02	\N
32019	30616	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:02	\N
32020	30617	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:02	\N
32021	30618	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:02	\N
32022	30619	DEPUTE	1975-06-23 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:02	\N
32023	30620	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:02	\N
32024	30621	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:02	\N
32025	30622	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:02	\N
32026	30623	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:02	\N
32027	30624	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:02	\N
32028	30625	DEPUTE	1997-05-25 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:02	\N
32029	30626	DEPUTE	2002-06-19 00:00:00	\N	2004-04-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:02	\N
32030	30627	DEPUTE	2002-06-25 00:00:00	\N	2002-06-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:02	\N
32031	30628	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:02	\N
32032	30629	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:02	\N
32033	30630	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:02	\N
32034	30631	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:02	\N
32035	30632	DEPUTE	1980-11-30 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:02	\N
32036	30633	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:02	\N
32037	30634	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:03	\N
32038	30635	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:03	\N
32039	30636	DEPUTE	1993-04-02 00:00:00	\N	1993-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:03	\N
32040	30637	DEPUTE	1993-09-21 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:03	\N
32041	30638	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:03	\N
32042	30639	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:03	\N
32043	30640	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:03	\N
32044	30641	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:03	\N
32045	30642	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:03	\N
32046	30643	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:03	\N
32047	30644	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:03	\N
32048	30645	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:03	\N
32049	30646	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:03	\N
32050	30647	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:03	\N
32051	30648	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:03	\N
32052	30649	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:03	\N
32053	30650	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:03	\N
32054	30651	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:03	\N
32055	30652	DEPUTE	1986-02-27 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:03	\N
32056	30653	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:03	\N
32888	31485	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:32	\N
32889	31486	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:32	\N
32890	31487	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:32	\N
32891	31488	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:32	\N
32892	31489	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:32	\N
32893	31490	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:32	\N
32894	31491	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:32	\N
32895	31492	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:32	\N
32896	31493	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:32	\N
32897	31494	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:32	\N
32898	31495	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:32	\N
32899	31496	DEPUTE	1988-06-13 00:00:00	\N	1992-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:32	\N
32900	31497	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:32	\N
32901	31498	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:32	\N
32902	31499	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:32	\N
32903	31500	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:32	\N
32904	31501	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:32	\N
32905	31502	DEPUTE	1973-04-02 00:00:00	\N	1976-09-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:32	\N
32906	31503	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:32	\N
32907	31504	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:32	\N
32908	31505	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:32	\N
32909	31506	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:32	\N
32910	31507	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:32	\N
32911	31508	DEPUTE	1975-05-25 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:32	\N
32912	31509	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:32	\N
32913	31510	DEPUTE	1968-07-11 00:00:00	\N	1969-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:33	\N
32914	31511	DEPUTE	1973-04-02 00:00:00	\N	1973-05-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:33	\N
32915	31512	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:33	\N
32916	31513	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:33	\N
32917	31514	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:33	\N
32918	31515	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:33	\N
32919	31516	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:33	\N
32920	31517	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:33	\N
32921	31518	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:33	\N
32922	31519	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:33	\N
32923	31520	DEPUTE	1968-07-11 00:00:00	\N	1968-08-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:33	\N
32924	31521	DEPUTE	1971-12-13 00:00:00	\N	1972-01-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:33	\N
32925	31522	DEPUTE	1973-04-02 00:00:00	\N	1973-05-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:33	\N
32926	31523	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:33	\N
32927	31524	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:33	\N
32928	31525	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:33	\N
32929	31526	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:33	\N
32930	31527	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:33	\N
32931	31528	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:33	\N
32932	31529	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:33	\N
32933	31530	DEPUTE	1992-11-03 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:33	\N
32934	31531	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:33	\N
32935	31532	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:34	\N
32936	31533	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:34	\N
32937	31534	DEPUTE	1988-06-13 00:00:00	\N	1992-07-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:34	\N
32938	31535	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:34	\N
32939	31536	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:34	\N
32940	31537	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:34	\N
32941	31538	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:34	\N
32942	31539	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:34	\N
32943	31540	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:34	\N
32944	31541	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:34	\N
32945	31542	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:34	\N
32946	31543	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:34	\N
32947	31544	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:34	\N
32948	31545	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:34	\N
32949	31546	DEPUTE	2007-06-20 00:00:00	\N	2011-11-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:34	\N
32950	31547	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:34	\N
32951	31548	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:34	\N
32952	31549	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:34	\N
32953	31550	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:34	\N
32954	31551	DEPUTE	1981-07-02 00:00:00	\N	1984-09-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:35	\N
32955	31552	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:35	\N
32956	31553	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:35	\N
32957	31554	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:35	\N
32958	31555	DEPUTE	1973-05-06 00:00:00	\N	1974-07-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:36	\N
32959	31556	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:36	\N
32960	31557	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:36	\N
32961	31558	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:36	\N
32962	31559	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:36	\N
32963	31560	SECAN	2007-06-27 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:36	\N
32964	31561	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:36	\N
32965	31562	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:36	\N
32966	31563	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:36	\N
32967	31564	DEPUTE	1962-12-06 00:00:00	\N	1963-03-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:36	\N
32968	31565	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:36	\N
32969	31566	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:36	\N
32970	31567	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:36	\N
32971	31568	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:36	\N
32972	31569	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:36	\N
32973	31570	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:36	\N
32974	31571	DEPUTE	1995-10-09 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:37	\N
32975	31572	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:37	\N
32976	31573	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:37	\N
32977	31574	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:37	\N
32978	31575	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:37	\N
32979	31576	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:37	\N
32980	31577	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:37	\N
28764	27361	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28765	27362	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28766	27363	DEPUTE	2013-08-03 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28767	27364	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28768	27365	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28769	27366	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28770	27367	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28771	27368	VICPDTAN	2012-06-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28772	27369	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28773	27370	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28774	27371	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28775	27372	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28776	27373	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28777	27374	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28778	27375	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28779	27376	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28780	27377	SECAN	2012-06-27 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28781	27378	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28782	27379	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28783	27380	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28784	27381	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28785	27382	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28786	27383	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28787	27384	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28788	27385	DEPUTE	2010-12-29 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:37	\N
28789	27386	DEPUTE	2012-07-22 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:38	\N
28790	27387	DEPUTE	2012-07-22 00:00:00	\N	2014-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:38	\N
28791	27388	DEPUTE	2012-07-22 00:00:00	\N	2014-12-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:38	\N
28792	27389	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:38	\N
28793	27390	DEPUTE	2012-07-22 00:00:00	\N	2014-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:38	\N
28794	27391	DEPUTE	2012-07-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:38	\N
28795	27392	DEPUTE	2017-05-06 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:38	\N
28796	27393	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:38	\N
28797	27394	DEPUTE	2016-03-04 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:38	\N
28798	27395	DEPUTE	2015-07-18 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:38	\N
28799	27396	DEPUTE	2012-07-22 00:00:00	\N	2014-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:38	\N
28800	27397	DEPUTE	2015-02-09 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:38	\N
28801	27398	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:38	\N
28802	27399	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:38	\N
28803	27400	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:38	\N
28804	27401	DEPUTE	2012-06-26 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:38	\N
28805	27402	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:38	\N
28806	27403	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:38	\N
28807	27404	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:38	\N
28808	27405	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:38	\N
28809	27406	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:38	\N
28810	27407	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:38	\N
28811	27408	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:38	\N
28812	27409	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:38	\N
28813	27410	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:38	\N
28814	27411	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:38	\N
28815	27412	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:38	\N
28816	27413	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:38	\N
28817	27414	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:38	\N
28818	27415	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:38	\N
28819	27416	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:38	\N
28820	27417	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:38	\N
28821	27418	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:39	\N
28822	27419	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:39	\N
28823	27420	DEPUTE	2012-06-20 00:00:00	\N	2016-03-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:39	\N
28824	27421	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:39	\N
28825	27422	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:39	\N
28826	27423	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:39	\N
28827	27424	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:39	\N
28828	27425	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:39	\N
28829	27426	VICPDTAN	2012-06-27 00:00:00	\N	2016-05-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:39	\N
28830	27427	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:39	\N
28831	27428	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:39	\N
28832	27429	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:39	\N
28833	27430	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:39	\N
28834	27431	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:39	\N
28835	27432	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:39	\N
28836	27433	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:39	\N
28837	27434	DEPUTE	2012-06-20 00:00:00	\N	2014-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:39	\N
28838	27435	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:39	\N
28839	27436	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:39	\N
28840	27437	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:39	\N
28841	27438	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:39	\N
28842	27439	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:39	\N
28843	27440	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:39	\N
28844	27441	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:39	\N
28845	27442	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:40	\N
28846	27443	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:40	\N
28847	27444	DEPUTE	2012-06-20 00:00:00	\N	2014-05-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:40	\N
28848	27445	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:40	\N
28849	27446	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:40	\N
28850	27447	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:40	\N
28851	27448	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:40	\N
28852	27449	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:40	\N
28853	27450	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:40	\N
28854	27451	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:40	\N
28855	27452	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:40	\N
28856	27453	DEPUTE	2012-06-20 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:40	\N
28857	27454	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:40	\N
31035	29632	DEPUTE	1973-05-13 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:33	\N
31036	29633	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:33	\N
31037	29634	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:33	\N
31038	29635	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:33	\N
31039	29636	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:33	\N
31040	29637	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:33	\N
31041	29638	DEPUTE	1968-07-11 00:00:00	\N	1971-12-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:33	\N
31042	29639	DEPUTE	1986-04-02 00:00:00	\N	1986-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:33	\N
31043	29640	DEPUTE	1986-09-29 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:33	\N
31044	29641	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:33	\N
31045	29642	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:33	\N
31046	29643	DEPUTE	1988-07-29 00:00:00	\N	1991-08-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:33	\N
31047	29644	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:33	\N
31048	29645	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:33	\N
31049	29646	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:33	\N
31050	29647	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:33	\N
31051	29648	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:33	\N
31052	29649	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:33	\N
31053	29650	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:33	\N
31054	29651	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:34	\N
31055	29652	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:34	\N
31056	29653	SECAN	2012-06-27 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:34	\N
31057	29654	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:34	\N
31058	29655	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:34	\N
31059	29656	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:34	\N
31060	29657	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:34	\N
31061	29658	DEPUTE	1997-06-01 00:00:00	\N	2001-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:34	\N
31062	29659	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:34	\N
31063	29660	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:34	\N
31064	29661	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:34	\N
31065	29662	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:34	\N
31066	29663	DEPUTE	1973-04-02 00:00:00	\N	1977-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:34	\N
31067	29664	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:34	\N
31068	29665	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:34	\N
31069	29666	DEPUTE	1982-01-17 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:34	\N
31070	29667	DEPUTE	1978-04-03 00:00:00	\N	1978-05-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:34	\N
31071	29668	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:34	\N
31072	29669	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:34	\N
31073	29670	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:34	\N
31074	29671	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:34	\N
31075	29672	DEPUTE	1999-03-30 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:34	\N
31076	29673	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:34	\N
31077	29674	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:34	\N
31078	29675	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:34	\N
31079	29676	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:34	\N
31080	29677	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:34	\N
31081	29678	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:34	\N
31082	29679	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:35	\N
31083	29680	SECAN	1997-06-13 00:00:00	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:35	\N
31084	29681	DEPUTE	1993-04-02 00:00:00	\N	1996-02-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:35	\N
31085	29682	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:35	\N
31086	29683	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:35	\N
31087	29684	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:35	\N
31088	29685	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:35	\N
31089	29686	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:35	\N
31090	29687	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:35	\N
31091	29688	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:35	\N
31092	29689	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:35	\N
31093	29690	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:35	\N
31094	29691	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:35	\N
31095	29692	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:35	\N
31096	29693	DEPUTE	2010-12-14 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:35	\N
31097	29694	DEPUTE	2012-06-20 00:00:00	\N	2014-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:35	\N
31098	29695	SECAN	1995-04-03 00:00:00	\N	1996-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:35	\N
31099	29696	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:35	\N
31100	29697	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:35	\N
31101	29698	DEPUTE	1993-04-02 00:00:00	\N	1995-12-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:35	\N
31102	29699	DEPUTE	1996-02-26 00:00:00	\N	1996-03-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:35	\N
31103	29700	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:35	\N
31104	29701	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:35	\N
31105	29702	DEPUTE	1968-07-11 00:00:00	\N	1971-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:35	\N
31106	29703	DEPUTE	2011-07-30 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31107	29704	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31108	29705	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31109	29706	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31110	29707	DEPUTE	1995-09-25 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31111	29708	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31112	29709	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31113	29710	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31114	29711	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31115	29712	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31116	29713	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31117	29714	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31118	29715	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31119	29716	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31120	29717	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31121	29718	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31122	29719	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31123	29720	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31124	29721	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31125	29722	DEPUTE	1988-06-06 00:00:00	\N	1993-02-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31126	29723	SECAN	1985-04-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31127	29724	SECAN	1986-04-04 00:00:00	\N	1987-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
32057	30654	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:03	\N
32058	30655	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:03	\N
32059	30656	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:03	\N
32060	30657	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:03	\N
32061	30658	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32062	30659	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32063	30660	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32064	30661	DEPUTE	1989-01-20 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32065	30662	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32066	30663	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32067	30664	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32068	30665	DEPUTE	1981-07-02 00:00:00	\N	1983-11-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32069	30666	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32070	30667	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32071	30668	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32072	30669	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32073	30670	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32074	30671	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32075	30672	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32076	30673	DEPUTE	1985-12-16 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32077	30674	DEPUTE	1992-05-05 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32078	30675	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32079	30676	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32080	30677	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32081	30678	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32082	30679	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32083	30680	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32084	30681	DEPUTE	1988-06-13 00:00:00	\N	1989-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32085	30682	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32086	30683	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32087	30684	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32088	30685	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32089	30686	DEPUTE	2002-06-19 00:00:00	\N	2007-01-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32090	30687	SECAN	1992-04-02 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32091	30688	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32092	30689	SECAN	1994-04-02 00:00:00	\N	1995-05-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32093	30690	VICPDTAN	1995-06-01 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32094	30691	DEPUTE	2002-06-19 00:00:00	\N	2006-09-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32095	30692	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32096	30693	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32097	30694	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32098	30695	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32099	30696	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32100	30697	DEPUTE	1988-12-19 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32101	30698	DEPUTE	1993-05-02 00:00:00	\N	1995-06-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32102	30699	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32103	30700	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32104	30701	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32105	30702	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32106	30703	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32107	30704	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32108	30705	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32109	30706	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32110	30707	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32111	30708	DEPUTE	1988-06-06 00:00:00	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32112	30709	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32113	30710	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:04	\N
32114	30711	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:05	\N
32115	30712	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:05	\N
32116	30713	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:05	\N
32117	30714	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:05	\N
32118	30715	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:05	\N
32119	30716	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:05	\N
32120	30717	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:05	\N
32121	30718	VICPDTAN	1988-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:05	\N
32122	30719	DEPUTE	1995-12-14 00:00:00	\N	1996-02-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:05	\N
32123	30720	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:05	\N
32124	30721	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:05	\N
32125	30722	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:05	\N
32126	30723	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:05	\N
32127	30724	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:05	\N
32128	30725	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:05	\N
32129	30726	DEPUTE	1998-01-25 00:00:00	\N	1999-12-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:05	\N
32130	30727	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:05	\N
32131	30728	DEPUTE	1968-08-13 00:00:00	\N	1971-11-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:05	\N
32132	30729	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:05	\N
32133	30730	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:05	\N
32134	30731	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:05	\N
32135	30732	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:05	\N
32136	30733	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:05	\N
32137	30734	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:05	\N
32138	30735	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:05	\N
32139	30736	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:05	\N
32140	30737	DEPUTE	2007-06-20 00:00:00	\N	2011-05-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:05	\N
32141	30738	DEPUTE	1993-05-02 00:00:00	\N	1995-07-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:05	\N
32142	30739	DEPUTE	1995-12-08 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:05	\N
32143	30740	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:05	\N
32144	30741	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:05	\N
32145	30742	DEPUTE	1981-07-02 00:00:00	\N	1986-03-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:05	\N
32146	30743	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:05	\N
32147	30744	DEPUTE	1986-12-10 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:05	\N
32148	30745	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:05	\N
32149	30746	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:05	\N
32981	31578	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:37	\N
32982	31579	DEPUTE	1978-04-02 00:00:00	\N	1980-09-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:37	\N
32983	31580	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:37	\N
32984	31581	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:37	\N
32985	31582	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:37	\N
32986	31583	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:38	\N
32987	31584	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:38	\N
32988	31585	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:39	\N
32989	31586	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:39	\N
32990	31587	DEPUTE	2000-04-28 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:39	\N
32991	31588	DEPUTE	1992-05-05 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:39	\N
32992	31589	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:39	\N
32993	31590	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:39	\N
32994	31591	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:39	\N
32995	31592	DEPUTE	1981-07-02 00:00:00	\N	1984-08-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:39	\N
32996	31593	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:39	\N
32997	31594	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:39	\N
32998	31595	DEPUTE	1988-06-06 00:00:00	\N	1992-05-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:39	\N
32999	31596	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:39	\N
33000	31597	DEPUTE	1997-06-01 00:00:00	\N	1998-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:39	\N
33001	31598	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:40	\N
33002	31599	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:40	\N
33003	31600	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:40	\N
33004	31601	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:40	\N
33005	31602	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:40	\N
33006	31603	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:40	\N
33007	31604	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:40	\N
33008	31605	DEPUTE	1988-06-06 00:00:00	\N	1988-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:40	\N
33009	31606	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:40	\N
33010	31607	DEPUTE	1988-09-19 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:40	\N
33011	31608	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:40	\N
33012	31609	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:40	\N
33013	31610	DEPUTE	2012-06-20 00:00:00	\N	2013-01-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:41	\N
33014	31611	DEPUTE	2013-03-24 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:41	\N
33015	31612	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:41	\N
33016	31613	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:41	\N
33017	31614	DEPUTE	2012-06-20 00:00:00	\N	2014-07-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:41	\N
33018	31615	DEPUTE	1978-04-03 00:00:00	\N	1980-09-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:41	\N
33019	31616	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:41	\N
33020	31617	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:42	\N
33021	31618	DEPUTE	1994-11-18 00:00:00	\N	1995-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:42	\N
33022	31619	DEPUTE	1958-12-09 00:00:00	\N	1962-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:42	\N
33023	31620	DEPUTE	1962-12-06 00:00:00	\N	1963-01-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:42	\N
33024	31621	DEPUTE	1967-04-03 00:00:00	\N	1967-05-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:42	\N
33025	31622	DEPUTE	1968-07-11 00:00:00	\N	1968-08-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:42	\N
33026	31623	DEPUTE	1973-04-02 00:00:00	\N	1973-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:42	\N
33027	31624	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:42	\N
33028	31625	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:42	\N
33029	31626	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:42	\N
33030	31627	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:43	\N
33031	31628	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:43	\N
33032	31629	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:43	\N
33033	31630	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:43	\N
33034	31631	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:43	\N
33035	31632	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:44	\N
33036	31633	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:44	\N
33037	31634	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:44	\N
33038	31635	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:44	\N
33039	31636	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:44	\N
33040	31637	DEPUTE	1988-06-13 00:00:00	\N	1990-08-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:44	\N
33041	31638	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:44	\N
33042	31639	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:44	\N
33043	31640	DEPUTE	1992-05-03 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:44	\N
33044	31641	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:44	\N
33045	31642	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:44	\N
33046	31643	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:44	\N
33047	31644	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:44	\N
33048	31645	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:44	\N
33049	31646	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:44	\N
33050	31647	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:44	\N
33051	31648	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:44	\N
33052	31649	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:44	\N
33053	31650	DEPUTE	1981-07-02 00:00:00	\N	1984-04-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:44	\N
33054	31651	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:44	\N
33055	31652	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:44	\N
33056	31653	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:44	\N
33057	31654	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:44	\N
33058	31655	DEPUTE	2007-06-20 00:00:00	\N	2010-12-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:44	\N
33059	31656	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:44	\N
33060	31657	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:44	\N
33061	31658	DEPUTE	2000-04-28 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:44	\N
33062	31659	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:44	\N
33063	31660	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:44	\N
33064	31661	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:44	\N
33065	31662	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:44	\N
33066	31663	DEPUTE	1988-07-29 00:00:00	\N	1991-04-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:44	\N
33067	31664	DEPUTE	1997-07-05 00:00:00	\N	2000-09-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:44	\N
33068	31665	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:44	\N
33069	31666	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:44	\N
33070	31667	DEPUTE	2002-06-19 00:00:00	\N	2007-04-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:44	\N
33071	31668	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:44	\N
33072	31669	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:44	\N
33073	31670	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:44	\N
28858	27455	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:40	\N
28859	27456	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:40	\N
28860	27457	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:40	\N
28861	27458	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:40	\N
28862	27459	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:41	\N
28863	27460	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:41	\N
28864	27461	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:41	\N
28865	27462	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:41	\N
28866	27463	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:41	\N
28867	27464	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:41	\N
28868	27465	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:41	\N
28869	27466	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:41	\N
28870	27467	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:41	\N
28871	27468	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:41	\N
28872	27469	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:41	\N
28873	27470	DEPUTE	2012-06-20 00:00:00	\N	2016-01-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:41	\N
28874	27471	DEPUTE	2012-06-26 00:00:00	\N	2016-01-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:41	\N
28875	27472	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:41	\N
28876	27473	DEPUTE	2012-06-20 00:00:00	\N	2014-07-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:41	\N
28877	27474	DEPUTE	2015-07-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:41	\N
28878	27475	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:41	\N
28879	27476	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:41	\N
28880	27477	DEPUTE	2012-06-20 00:00:00	\N	2016-03-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:42	\N
28881	27478	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:42	\N
28882	27479	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:42	\N
28883	27480	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:42	\N
28884	27481	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:42	\N
28885	27482	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:42	\N
28886	27483	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:42	\N
28887	27484	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:42	\N
28888	27485	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:42	\N
28889	27486	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:42	\N
28890	27487	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:42	\N
28891	27488	DEPUTE	2012-06-26 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:42	\N
28892	27489	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:42	\N
28893	27490	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:42	\N
28894	27491	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:42	\N
28895	27492	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:42	\N
28896	27493	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:42	\N
28897	27494	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:42	\N
28898	27495	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:42	\N
28899	27496	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:42	\N
28900	27497	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:42	\N
28901	27498	DEPUTE	2012-06-20 00:00:00	\N	2014-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:42	\N
28902	27499	DEPUTE	2012-06-20 00:00:00	\N	2012-06-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:42	\N
28903	27500	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:42	\N
28904	27501	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:42	\N
28905	27502	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:42	\N
28906	27503	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:42	\N
28907	27504	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:42	\N
28908	27505	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:42	\N
28909	27506	DEPUTE	2012-06-20 00:00:00	\N	2016-03-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:42	\N
28910	27507	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:42	\N
28911	27508	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:42	\N
28912	27509	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:42	\N
28913	27510	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:42	\N
28914	27511	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:42	\N
28915	27512	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:43	\N
28916	27513	DEPUTE	2012-06-20 00:00:00	\N	2016-03-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:43	\N
28917	27514	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:43	\N
28918	27515	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:43	\N
28919	27516	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:43	\N
28920	27517	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:43	\N
28921	27518	DEPUTE	2012-06-26 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:43	\N
28922	27519	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:43	\N
28923	27520	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:43	\N
28924	27521	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:43	\N
28925	27522	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:43	\N
28926	27523	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:43	\N
28927	27524	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:43	\N
28928	27525	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:43	\N
28929	27526	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:43	\N
28930	27527	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:43	\N
28931	27528	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:43	\N
28932	27529	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:43	\N
28933	27530	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:43	\N
28934	27531	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:43	\N
28935	27532	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:43	\N
28936	27533	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:43	\N
28937	27534	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:43	\N
28938	27535	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:43	\N
28939	27536	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:43	\N
28940	27537	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:43	\N
28941	27538	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:43	\N
28942	27539	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:43	\N
28943	27540	DEPUTE	2012-06-20 00:00:00	\N	2014-05-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:43	\N
28944	27541	DEPUTE	2017-03-28 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:43	\N
28945	27542	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:44	\N
28946	27543	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:44	\N
28947	27544	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:44	\N
28948	27545	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:44	\N
28949	27546	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:44	\N
28950	27547	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:44	\N
28951	27548	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:44	\N
31128	29725	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31129	29726	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31130	29727	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31131	29728	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31132	29729	DEPUTE	1993-05-03 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31133	29730	DEPUTE	1997-06-01 00:00:00	\N	2001-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31134	29731	DEPUTE	1973-04-02 00:00:00	\N	1976-09-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31135	29732	DEPUTE	1978-04-02 00:00:00	\N	1978-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31136	29733	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31137	29734	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31138	29735	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31139	29736	DEPUTE	1991-06-18 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31140	29737	DEPUTE	1982-01-18 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31141	29738	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31142	29739	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31143	29740	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31144	29741	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31145	29742	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31146	29743	DEPUTE	2009-07-23 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31147	29744	SECAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31148	29745	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31149	29746	DEPUTE	2001-04-28 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31150	29747	DEPUTE	1982-06-15 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31151	29748	DEPUTE	1990-11-03 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31152	29749	DEPUTE	1968-07-11 00:00:00	\N	1970-05-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31153	29750	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31154	29751	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:36	\N
31155	29752	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31156	29753	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31157	29754	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31158	29755	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31159	29756	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31160	29757	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31161	29758	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31162	29759	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31163	29760	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31164	29761	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31165	29762	VICPDTAN	2009-10-06 00:00:00	\N	2010-10-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31166	29763	SECAN	2008-10-01 00:00:00	\N	2009-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31167	29764	SECAN	2010-10-05 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31168	29765	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31169	29766	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31170	29767	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31171	29768	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31172	29769	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31173	29770	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31174	29771	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31175	29772	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31176	29773	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31177	29774	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31178	29775	DEPUTE	2009-07-24 00:00:00	\N	2009-07-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31179	29776	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31180	29777	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31181	29778	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31182	29779	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31183	29780	SECAN	2005-10-04 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31184	29781	SECAN	2007-06-27 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31185	29782	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31186	29783	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31187	29784	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31188	29785	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31189	29786	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31190	29787	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31191	29788	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31192	29789	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31193	29790	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31194	29791	VICPDTAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31195	29792	VICPDTAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31196	29793	VICPDTAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31197	29794	DEPUTE	2007-06-26 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31198	29795	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31199	29796	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31200	29797	DEPUTE	1986-04-02 00:00:00	\N	1986-09-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31201	29798	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31202	29799	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31203	29800	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31204	29801	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31205	29802	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31206	29803	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31207	29804	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31208	29805	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:37	\N
31209	29806	DEPUTE	1978-04-03 00:00:00	\N	1981-04-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:38	\N
31210	29807	DEPUTE	1977-01-11 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:38	\N
31211	29808	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:38	\N
31212	29809	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:38	\N
31213	29810	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:38	\N
31214	29811	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:38	\N
31215	29812	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:38	\N
31216	29813	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:38	\N
31217	29814	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:38	\N
31218	29815	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:38	\N
31219	29816	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:38	\N
31220	29817	QUESTAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:38	\N
32150	30747	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:05	\N
32151	30748	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:05	\N
32152	30749	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:05	\N
32153	30750	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:05	\N
32154	30751	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:05	\N
32155	30752	DEPUTE	1984-08-24 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:06	\N
32156	30753	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:06	\N
32157	30754	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:06	\N
32158	30755	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:06	\N
32159	30756	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:06	\N
32160	30757	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:06	\N
32161	30758	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:06	\N
32162	30759	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:06	\N
32163	30760	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:06	\N
32164	30761	DEPUTE	2007-06-20 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:06	\N
32165	30762	DEPUTE	1993-04-02 00:00:00	\N	1996-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:06	\N
32166	30763	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:06	\N
32167	30764	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:06	\N
32168	30765	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:06	\N
32169	30766	DEPUTE	1967-04-02 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:06	\N
32170	30767	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:06	\N
32171	30768	DEPUTE	1973-04-03 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:06	\N
32172	30769	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:06	\N
32173	30770	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:06	\N
32174	30771	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:06	\N
32175	30772	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:06	\N
32176	30773	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:06	\N
32177	30774	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:06	\N
32178	30775	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:06	\N
32179	30776	DEPUTE	1964-12-12 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:06	\N
32180	30777	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:06	\N
32181	30778	DEPUTE	1968-07-11 00:00:00	\N	1968-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:06	\N
32182	30779	DEPUTE	1968-12-15 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:06	\N
32183	30780	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:06	\N
32184	30781	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:06	\N
32185	30782	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:06	\N
32186	30783	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:06	\N
32187	30784	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:06	\N
32188	30785	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:06	\N
32189	30786	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:06	\N
32190	30787	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:06	\N
32191	30788	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:06	\N
32192	30789	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:06	\N
32193	30790	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:06	\N
32194	30791	DEPUTE	1993-05-02 00:00:00	\N	1995-05-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:07	\N
32195	30792	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:07	\N
32196	30793	DEPUTE	2001-07-29 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:07	\N
32197	30794	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:07	\N
32198	30795	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:07	\N
32199	30796	DEPUTE	1993-04-02 00:00:00	\N	1995-09-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:07	\N
32200	30797	DEPUTE	2004-06-21 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:07	\N
32201	30798	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:07	\N
32202	30799	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:07	\N
32203	30800	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:07	\N
32204	30801	DEPUTE	1981-07-02 00:00:00	\N	1984-01-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:07	\N
32205	30802	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:07	\N
32206	30803	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:07	\N
32207	30804	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:07	\N
32208	30805	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:07	\N
32209	30806	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:07	\N
32210	30807	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:07	\N
32211	30808	VICPDTAN	2011-10-03 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:07	\N
32212	30809	VICPDTAN	2012-06-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:07	\N
32213	30810	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:07	\N
32214	30811	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:07	\N
32215	30812	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:07	\N
32216	30813	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:07	\N
32217	30814	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:07	\N
32218	30815	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:07	\N
32219	30816	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:07	\N
32220	30817	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:07	\N
32221	30818	DEPUTE	1977-03-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:07	\N
32222	30819	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:07	\N
32223	30820	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:07	\N
32224	30821	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:07	\N
32225	30822	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:07	\N
32226	30823	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:07	\N
32227	30824	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:07	\N
32228	30825	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:07	\N
32229	30826	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:07	\N
32230	30827	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:08	\N
32231	30828	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:08	\N
32232	30829	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:08	\N
32233	30830	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:08	\N
32234	30831	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:08	\N
32235	30832	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:08	\N
32236	30833	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:08	\N
32237	30834	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:08	\N
32238	30835	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:08	\N
32239	30836	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:08	\N
32240	30837	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:08	\N
32241	30838	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:08	\N
32242	30839	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:08	\N
33074	31671	DEPUTE	1997-05-25 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:44	\N
33540	32137	SECAN	1988-06-24 00:00:00	\N	1992-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:01	\N
33541	32138	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:01	\N
33542	32139	SECAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:01	\N
33543	32140	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:01	\N
33544	32141	DEPUTE	1978-04-02 00:00:00	\N	1978-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:01	\N
33545	32142	DEPUTE	1986-04-02 00:00:00	\N	1986-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:01	\N
33546	32143	DEPUTE	1986-10-01 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:01	\N
33547	32144	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:01	\N
33548	32145	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:01	\N
33549	32146	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:01	\N
33550	32147	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:01	\N
33551	32148	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:01	\N
33552	32149	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:01	\N
33553	32150	PDTAN	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:01	\N
33554	32151	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:01	\N
33555	32152	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:01	\N
33556	32153	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:02	\N
33557	32154	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:02	\N
33558	32155	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:02	\N
33559	32156	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:02	\N
33560	32157	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:02	\N
33561	32158	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:02	\N
33562	32159	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:02	\N
33563	32160	DEPUTE	1983-04-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:02	\N
33564	32161	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:02	\N
33565	32162	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:02	\N
33566	32163	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:02	\N
33567	32164	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:02	\N
33568	32165	DEPUTE	1996-05-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:02	\N
33569	32166	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:02	\N
33570	32167	DEPUTE	1989-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:02	\N
33571	32168	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:02	\N
33572	32169	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:02	\N
33573	32170	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:02	\N
33574	32171	SECAN	1987-04-02 00:00:00	\N	1988-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:02	\N
33575	32172	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:03	\N
33576	32173	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:03	\N
33577	32174	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:03	\N
33578	32175	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:03	\N
33579	32176	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:03	\N
33580	32177	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:03	\N
33581	32178	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:03	\N
33582	32179	DEPUTE	1973-04-02 00:00:00	\N	1974-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:03	\N
33583	32180	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:03	\N
33584	32181	DEPUTE	1978-04-03 00:00:00	\N	1978-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:03	\N
33585	32182	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:03	\N
33586	32183	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:03	\N
33587	32184	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:03	\N
33588	32185	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:03	\N
33589	32186	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:03	\N
33590	32187	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:03	\N
33591	32188	DEPUTE	1981-07-02 00:00:00	\N	1983-04-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:03	\N
33592	32189	DEPUTE	1980-11-30 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:03	\N
33593	32190	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:03	\N
33594	32191	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:03	\N
33595	32192	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:03	\N
33596	32193	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:03	\N
33597	32194	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:03	\N
33598	32195	DEPUTE	1973-04-02 00:00:00	\N	1977-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:03	\N
33599	32196	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:04	\N
33600	32197	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:04	\N
33601	32198	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:04	\N
33602	32199	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:04	\N
33603	32200	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:04	\N
33604	32201	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:04	\N
33605	32202	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:04	\N
33606	32203	DEPUTE	1973-04-02 00:00:00	\N	1973-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:04	\N
33607	32204	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:04	\N
33608	32205	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:04	\N
33609	32206	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:04	\N
33610	32207	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:04	\N
33611	32208	DEPUTE	1973-04-02 00:00:00	\N	1975-06-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:04	\N
33612	32209	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:04	\N
33613	32210	DEPUTE	1989-12-04 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:04	\N
33614	32211	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:05	\N
33615	32212	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:05	\N
33616	32213	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:05	\N
33617	32214	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:05	\N
33618	32215	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:05	\N
33619	32216	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:05	\N
33620	32217	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:05	\N
33621	32218	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:05	\N
33622	32219	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:05	\N
33623	32220	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:05	\N
33624	32221	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:05	\N
33625	32222	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:05	\N
33626	32223	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:05	\N
33627	32224	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:05	\N
33628	32225	VICPDTAN	1987-04-02 00:00:00	\N	1988-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:05	\N
33629	32226	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:05	\N
33630	32227	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:05	\N
33631	32228	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:06	\N
28952	27549	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:44	\N
28953	27550	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:44	\N
28954	27551	DEPUTE	2012-06-26 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:44	\N
28955	27552	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:44	\N
28957	27554	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:44	\N
28958	27555	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:44	\N
28959	27556	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:44	\N
28960	27557	DEPUTE	2012-06-20 00:00:00	\N	2014-04-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:44	\N
28961	27558	DEPUTE	2012-06-20 00:00:00	\N	2013-02-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:44	\N
28962	27559	DEPUTE	2012-06-20 00:00:00	\N	2014-05-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:44	\N
28963	27560	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:44	\N
28964	27561	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:44	\N
28965	27562	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:44	\N
28966	27563	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:44	\N
28967	27564	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:44	\N
28968	27565	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:44	\N
28969	27566	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:44	\N
28970	27567	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:45	\N
28971	27568	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:45	\N
28972	27569	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:45	\N
28973	27570	DEPUTE	2012-06-20 00:00:00	\N	2016-03-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:45	\N
28974	27571	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:45	\N
28975	27572	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:45	\N
28976	27573	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:45	\N
28977	27574	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:45	\N
28978	27575	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:45	\N
28979	27576	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:45	\N
28980	27577	DEPUTE	2012-06-20 00:00:00	\N	2013-02-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:45	\N
28981	27578	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:45	\N
28982	27579	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:45	\N
28983	27580	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:45	\N
28984	27581	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:45	\N
28985	27582	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:45	\N
28986	27583	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:45	\N
28987	27584	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:45	\N
28988	27585	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:45	\N
28989	27586	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:45	\N
28990	27587	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:45	\N
28991	27588	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:45	\N
28992	27589	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:45	\N
28993	27590	DEPUTE	2012-06-20 00:00:00	\N	2012-10-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:46	\N
28994	27591	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:46	\N
28995	27592	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:46	\N
28996	27593	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:46	\N
28997	27594	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:46	\N
28998	27595	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:46	\N
28999	27596	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:46	\N
29000	27597	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:46	\N
29001	27598	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:46	\N
29002	27599	SECAN	2012-06-27 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:46	\N
29003	27600	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:46	\N
29004	27601	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:46	\N
29005	27602	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:46	\N
29006	27603	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:46	\N
29007	27604	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:46	\N
29008	27605	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:46	\N
29009	27606	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:46	\N
29010	27607	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:46	\N
29011	27608	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:46	\N
29012	27609	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:47	\N
29013	27610	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:47	\N
29014	27611	DEPUTE	2012-06-20 00:00:00	\N	2015-07-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:47	\N
29015	27612	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:47	\N
29016	27613	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:47	\N
29017	27614	DEPUTE	2012-06-20 00:00:00	\N	2013-01-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:47	\N
29018	27615	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:47	\N
29019	27616	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:47	\N
29020	27617	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:47	\N
29021	27618	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:47	\N
29022	27619	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:47	\N
29023	27620	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:47	\N
29024	27621	DEPUTE	2012-07-22 00:00:00	\N	2016-03-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:47	\N
29025	27622	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:47	\N
29026	27623	DEPUTE	2012-07-22 00:00:00	\N	2014-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:47	\N
29027	27624	DEPUTE	2014-06-02 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:47	\N
29028	27625	DEPUTE	2014-07-04 00:00:00	\N	2015-07-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:47	\N
29030	27627	DEPUTE	2012-07-22 00:00:00	\N	2015-04-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:47	\N
29031	27628	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:47	\N
29032	27629	DEPUTE	2014-10-05 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:47	\N
29033	27630	DEPUTE	2012-07-22 00:00:00	\N	2017-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:47	\N
29034	27631	DEPUTE	2012-07-22 00:00:00	\N	2014-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:47	\N
29035	27632	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:47	\N
29036	27633	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:47	\N
29037	27634	DEPUTE	2016-04-16 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:47	\N
29038	27635	DEPUTE	2014-05-10 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:48	\N
29039	27636	DEPUTE	2014-05-10 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:48	\N
29040	27637	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:48	\N
29041	27638	DEPUTE	2012-07-22 00:00:00	\N	2016-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:48	\N
29042	27639	DEPUTE	2015-08-28 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:48	\N
29043	27640	DEPUTE	2017-06-16 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:48	\N
29044	27641	DEPUTE	2016-03-12 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:48	\N
29045	27642	DEPUTE	2012-07-22 00:00:00	\N	2014-07-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:48	\N
29046	27643	DEPUTE	2012-07-22 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:48	\N
31221	29818	QUESTAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:38	\N
31222	29819	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:38	\N
31223	29820	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:38	\N
31224	29821	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:38	\N
31225	29822	DEPUTE	2002-06-19 00:00:00	\N	2003-02-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:38	\N
31226	29823	DEPUTE	2003-03-24 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:38	\N
31227	29824	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:38	\N
31228	29825	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:38	\N
31229	29826	DEPUTE	1988-06-13 00:00:00	\N	1991-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:38	\N
31230	29827	DEPUTE	1995-12-10 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:38	\N
31231	29828	DEPUTE	1997-06-01 00:00:00	\N	2000-09-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:38	\N
31232	29829	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:38	\N
31233	29830	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:38	\N
31234	29831	DEPUTE	2012-07-22 00:00:00	\N	2014-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:38	\N
31235	29832	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:38	\N
31236	29833	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:38	\N
31237	29834	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:38	\N
31238	29835	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:38	\N
31239	29836	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:38	\N
31240	29837	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:38	\N
31241	29838	DEPUTE	1973-04-03 00:00:00	\N	1973-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:38	\N
31242	29839	DEPUTE	1974-10-06 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:38	\N
31243	29840	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:38	\N
31244	29841	DEPUTE	1967-04-02 00:00:00	\N	1967-05-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:38	\N
31245	29842	DEPUTE	1968-07-11 00:00:00	\N	1968-08-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:38	\N
31246	29843	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:38	\N
31247	29844	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:38	\N
31248	29845	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:38	\N
31249	29846	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:39	\N
31250	29847	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:39	\N
31251	29848	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:39	\N
31252	29849	DEPUTE	1974-09-29 00:00:00	\N	1976-09-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:39	\N
31253	29850	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:39	\N
31254	29851	DEPUTE	1967-04-03 00:00:00	\N	1967-05-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:39	\N
31255	29852	DEPUTE	1968-07-11 00:00:00	\N	1968-08-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:39	\N
31256	29853	DEPUTE	1973-04-02 00:00:00	\N	1973-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:39	\N
31257	29854	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:39	\N
31258	29855	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:39	\N
31259	29856	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:39	\N
31260	29857	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:39	\N
31261	29858	DEPUTE	1986-09-20 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:39	\N
31262	29859	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:39	\N
31263	29860	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:39	\N
31264	29861	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:39	\N
31265	29862	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:39	\N
31266	29863	DEPUTE	1981-07-02 00:00:00	\N	1983-07-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:39	\N
31267	29864	DEPUTE	1988-07-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:39	\N
31268	29865	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:39	\N
31269	29866	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:39	\N
31270	29867	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:39	\N
31271	29868	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:39	\N
31272	29869	VICPDTAN	2010-10-05 00:00:00	\N	2011-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:39	\N
31273	29870	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:39	\N
29247	27844	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:55	\N
31274	29871	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:39	\N
31275	29872	DEPUTE	1997-06-01 00:00:00	\N	1997-10-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:39	\N
31276	29873	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:39	\N
31277	29874	DEPUTE	1997-12-15 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:39	\N
31278	29875	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:39	\N
31279	29876	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:39	\N
31280	29877	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:39	\N
31281	29878	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:39	\N
31282	29879	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:39	\N
31283	29880	DEPUTE	1997-06-01 00:00:00	\N	2001-04-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:39	\N
31284	29881	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:39	\N
31285	29882	VICPDTAN	2002-06-26 00:00:00	\N	2003-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:39	\N
31286	29883	VICPDTAN	2004-10-01 00:00:00	\N	2005-12-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:39	\N
31287	29884	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:40	\N
31288	29885	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:40	\N
31289	29886	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:40	\N
31290	29887	DEPUTE	1988-06-13 00:00:00	\N	1991-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:40	\N
31291	29888	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:40	\N
31292	29889	DEPUTE	1985-12-28 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:40	\N
31293	29890	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:40	\N
31294	29891	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:40	\N
31295	29892	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:40	\N
31296	29893	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:40	\N
31297	29894	VICPDTAN	2015-01-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:40	\N
31298	29895	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:40	\N
31299	29896	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:40	\N
31300	29897	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:40	\N
31301	29898	DEPUTE	1986-04-02 00:00:00	\N	1988-05-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:40	\N
31302	29899	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:40	\N
31303	29900	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:40	\N
31304	29901	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:40	\N
31305	29902	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:40	\N
31306	29903	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:40	\N
31307	29904	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:40	\N
31308	29905	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:40	\N
31309	29906	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:40	\N
31310	29907	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:40	\N
31311	29908	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:40	\N
31312	29909	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:40	\N
31313	29910	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:40	\N
32243	30840	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:08	\N
32244	30841	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:08	\N
32245	30842	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:08	\N
32246	30843	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:08	\N
32247	30844	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:08	\N
32248	30845	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:08	\N
32249	30846	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:08	\N
32250	30847	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:08	\N
32251	30848	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:08	\N
32252	30849	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:08	\N
32253	30850	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:08	\N
32254	30851	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:08	\N
32255	30852	DEPUTE	2010-12-15 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:08	\N
32256	30853	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:08	\N
32257	30854	DEPUTE	1988-06-13 00:00:00	\N	1990-11-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:09	\N
32258	30855	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:09	\N
32259	30856	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:09	\N
32260	30857	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:09	\N
32261	30858	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:09	\N
32262	30859	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:09	\N
32263	30860	DEPUTE	2004-01-14 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:09	\N
32264	30861	DEPUTE	2007-06-20 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:09	\N
32265	30862	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:09	\N
32266	30863	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:09	\N
32267	30864	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:09	\N
32268	30865	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:09	\N
32269	30866	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:09	\N
32270	30867	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:09	\N
32271	30868	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:09	\N
32272	30869	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:09	\N
32273	30870	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:09	\N
32274	30871	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:09	\N
32275	30872	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:09	\N
32276	30873	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:09	\N
32277	30874	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:09	\N
32278	30875	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:09	\N
32279	30876	DEPUTE	1993-04-02 00:00:00	\N	1995-05-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:09	\N
32280	30877	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:09	\N
32281	30878	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:09	\N
32282	30879	DEPUTE	1988-06-13 00:00:00	\N	1988-10-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:09	\N
32283	30880	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:09	\N
32284	30881	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:09	\N
32285	30882	DEPUTE	1994-08-23 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:09	\N
32286	30883	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:09	\N
32287	30884	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:09	\N
32288	30885	DEPUTE	2007-06-20 00:00:00	\N	2008-09-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:10	\N
32289	30886	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:10	\N
32290	30887	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:10	\N
32291	30888	DEPUTE	2012-06-20 00:00:00	\N	2014-05-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:10	\N
32292	30889	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:10	\N
32293	30890	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:10	\N
32294	30891	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:10	\N
32295	30892	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:10	\N
32296	30893	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:10	\N
32297	30894	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:10	\N
32298	30895	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:10	\N
32299	30896	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:10	\N
32300	30897	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:10	\N
32301	30898	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:10	\N
32302	30899	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:10	\N
32303	30900	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:10	\N
32304	30901	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:10	\N
32305	30902	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:10	\N
32306	30903	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:10	\N
32307	30904	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:10	\N
32308	30905	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:10	\N
32309	30906	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:10	\N
32310	30907	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:10	\N
32311	30908	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:10	\N
32312	30909	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:10	\N
32313	30910	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:10	\N
32314	30911	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:10	\N
32315	30912	VICPDTAN	1986-04-04 00:00:00	\N	1987-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:10	\N
32316	30913	DEPUTE	1971-12-05 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:11	\N
32317	30914	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:11	\N
32318	30915	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:11	\N
32319	30916	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:11	\N
32320	30917	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:11	\N
32321	30918	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:11	\N
32322	30919	SECAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:11	\N
32323	30920	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:11	\N
32324	30921	DEPUTE	1967-04-03 00:00:00	\N	1967-05-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:11	\N
32325	30922	DEPUTE	1968-07-11 00:00:00	\N	1969-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:11	\N
32326	30923	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:11	\N
32327	30924	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:11	\N
32328	30925	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:11	\N
32329	30926	DEPUTE	2007-06-20 00:00:00	\N	2010-03-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:11	\N
32330	30927	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:11	\N
32331	30928	QUESTAN	2002-06-26 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:11	\N
32332	30929	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:11	\N
32333	30930	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:11	\N
32334	30931	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:11	\N
32335	30932	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:11	\N
33168	31765	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:48	\N
33169	31766	SECAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:48	\N
33170	31767	SECAN	1988-06-24 00:00:00	\N	1992-10-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:48	\N
33171	31768	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:48	\N
33172	31769	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:48	\N
33173	31770	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:48	\N
33174	31771	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:48	\N
33175	31772	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:48	\N
33176	31773	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:48	\N
33177	31774	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:48	\N
33178	31775	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:48	\N
33179	31776	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:48	\N
33180	31777	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:48	\N
33181	31778	DEPUTE	1981-07-02 00:00:00	\N	1981-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:48	\N
33182	31779	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:48	\N
33183	31780	DEPUTE	1988-06-13 00:00:00	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:48	\N
33184	31781	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:48	\N
33185	31782	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:48	\N
33186	31783	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:48	\N
33187	31784	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:48	\N
33188	31785	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:48	\N
33189	31786	DEPUTE	1993-04-02 00:00:00	\N	1993-05-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:48	\N
33190	31787	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:48	\N
33191	31788	DEPUTE	1973-04-02 00:00:00	\N	1973-05-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:48	\N
33192	31789	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:48	\N
33193	31790	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:48	\N
33194	31791	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:49	\N
33195	31792	DEPUTE	1997-06-01 00:00:00	\N	1998-03-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:49	\N
33196	31793	VICPDTAN	1992-04-02 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:49	\N
33197	31794	VICPDTAN	1993-04-07 00:00:00	\N	1993-04-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:49	\N
33198	31795	VICPDTAN	1997-06-13 00:00:00	\N	1998-03-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:49	\N
33199	31796	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:49	\N
33200	31797	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:49	\N
33201	31798	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:49	\N
33202	31799	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:49	\N
33203	31800	DEPUTE	1973-04-02 00:00:00	\N	1976-02-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:49	\N
33204	31801	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:49	\N
33205	31802	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:49	\N
33206	31803	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:49	\N
33207	31804	DEPUTE	1978-04-03 00:00:00	\N	1978-05-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:49	\N
33208	31805	DEPUTE	1973-04-02 00:00:00	\N	1976-02-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:49	\N
33209	31806	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:49	\N
33210	31807	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:49	\N
33211	31808	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:49	\N
33212	31809	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:49	\N
33213	31810	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:49	\N
33214	31811	DEPUTE	1997-05-25 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:49	\N
33215	31812	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:49	\N
33216	31813	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:49	\N
33217	31814	DEPUTE	1996-10-20 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:49	\N
33218	31815	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:49	\N
33219	31816	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:49	\N
33220	31817	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:49	\N
33221	31818	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:49	\N
33222	31819	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:49	\N
33223	31820	DEPUTE	1988-06-06 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:49	\N
33224	31821	DEPUTE	1993-04-02 00:00:00	\N	1996-02-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:49	\N
33225	31822	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:49	\N
33226	31823	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:49	\N
33227	31824	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:50	\N
33228	31825	DEPUTE	2005-07-03 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:50	\N
33229	31826	DEPUTE	2010-04-23 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:50	\N
33230	31827	DEPUTE	2014-12-15 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:50	\N
33231	31828	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:50	\N
33232	31829	DEPUTE	1999-07-23 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:50	\N
33233	31830	DEPUTE	1982-05-24 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:50	\N
33234	31831	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:50	\N
33235	31832	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:50	\N
33236	31833	DEPUTE	1993-05-24 00:00:00	\N	1995-09-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:50	\N
33237	31834	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:50	\N
33238	31835	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:50	\N
33239	31836	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:50	\N
33240	31837	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:50	\N
33241	31838	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:50	\N
33242	31839	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:50	\N
33243	31840	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:50	\N
33244	31841	DEPUTE	1988-06-13 00:00:00	\N	1990-11-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:50	\N
33245	31842	DEPUTE	1997-06-01 00:00:00	\N	2001-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:50	\N
33246	31843	PDTAN	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:50	\N
33247	31844	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:50	\N
33248	31845	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:50	\N
33249	31846	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:50	\N
33250	31847	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:50	\N
33251	31848	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:50	\N
33252	31849	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:50	\N
33253	31850	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:50	\N
33254	31851	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:51	\N
33255	31852	DEPUTE	1974-09-29 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:51	\N
33256	31853	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:51	\N
33257	31854	DEPUTE	1968-07-11 00:00:00	\N	1968-08-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:51	\N
33258	31855	DEPUTE	1969-10-19 00:00:00	\N	1971-03-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:51	\N
33259	31856	DEPUTE	1973-04-02 00:00:00	\N	1973-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:51	\N
33260	31857	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:51	\N
29047	27644	DEPUTE	2014-09-27 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:48	\N
29048	27645	DEPUTE	2014-07-04 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:48	\N
29049	27646	DEPUTE	2017-01-07 00:00:00	\N	2017-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:48	\N
29050	27647	DEPUTE	2014-05-10 00:00:00	\N	2017-03-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:48	\N
29051	27648	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:48	\N
29052	27649	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:48	\N
29053	27650	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:48	\N
29054	27651	DEPUTE	2012-07-22 00:00:00	\N	2014-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:48	\N
29055	27652	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:48	\N
29056	27653	DEPUTE	2016-03-12 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:48	\N
29057	27654	DEPUTE	2016-03-12 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:48	\N
29058	27655	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:48	\N
29059	27656	DEPUTE	2015-07-18 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:48	\N
29060	27657	DEPUTE	2016-06-13 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:48	\N
29061	27658	DEPUTE	2016-03-12 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:48	\N
29062	27659	DEPUTE	2012-12-17 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:48	\N
29063	27660	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:48	\N
29064	27661	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:48	\N
29065	27662	DEPUTE	2014-05-10 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:48	\N
29066	27663	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:48	\N
29067	27664	DEPUTE	2013-08-03 00:00:00	\N	2014-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:48	\N
29068	27665	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:48	\N
29069	27666	DEPUTE	2013-03-24 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:48	\N
29070	27667	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:48	\N
29071	27668	DEPUTE	2013-06-10 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:48	\N
29072	27669	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:48	\N
29073	27670	DEPUTE	2013-06-24 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:49	\N
29074	27671	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:49	\N
29075	27672	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:49	\N
29076	27673	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:49	\N
29077	27674	DEPUTE	2016-04-25 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:49	\N
29078	27675	DEPUTE	2016-05-30 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:49	\N
29079	27676	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:49	\N
29080	27677	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:49	\N
29081	27678	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:49	\N
29082	27679	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:49	\N
29083	27680	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:49	\N
29084	27681	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:49	\N
29085	27682	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:49	\N
29086	27683	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:49	\N
29087	27684	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:49	\N
29088	27685	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:49	\N
29089	27686	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:49	\N
29090	27687	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:49	\N
29091	27688	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:49	\N
29092	27689	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:49	\N
29093	27690	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:49	\N
29094	27691	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:49	\N
29095	27692	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:49	\N
29096	27693	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:49	\N
29097	27694	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:49	\N
29098	27695	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:49	\N
29099	27696	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:49	\N
29100	27697	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:49	\N
29101	27698	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:49	\N
29102	27699	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:49	\N
29103	27700	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:50	\N
29104	27701	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:50	\N
29110	27707	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:50	\N
29111	27708	DEPUTE	2015-09-14 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:50	\N
29112	27709	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:50	\N
29113	27710	DEPUTE	1968-09-06 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:50	\N
29114	27711	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:50	\N
29115	27712	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:50	\N
29116	27713	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:50	\N
29117	27714	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:50	\N
29118	27715	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:50	\N
29119	27716	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:50	\N
29120	27717	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:50	\N
29121	27718	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:50	\N
29122	27719	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:50	\N
29123	27720	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:50	\N
29124	27721	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:50	\N
29125	27722	DEPUTE	2014-06-30 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:50	\N
29126	27723	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:50	\N
29127	27724	DEPUTE	2014-06-30 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:50	\N
29128	27725	DEPUTE	2014-07-30 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:50	\N
29129	27726	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:50	\N
29130	27727	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:50	\N
29131	27728	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:50	\N
29132	27729	DEPUTE	1973-04-02 00:00:00	\N	1973-05-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:50	\N
29133	27730	DEPUTE	1978-04-03 00:00:00	\N	1978-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:50	\N
29134	27731	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:51	\N
29135	27732	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:51	\N
29136	27733	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:51	\N
29137	27734	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:51	\N
29138	27735	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:51	\N
29139	27736	DEPUTE	1973-04-02 00:00:00	\N	1974-07-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:51	\N
29140	27737	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:51	\N
29141	27738	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:51	\N
29142	27739	DEPUTE	1963-05-12 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:51	\N
31314	29911	SECAN	1987-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:40	\N
31315	29912	VICPDTAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:40	\N
31316	29913	VICPDTAN	1994-04-02 00:00:00	\N	1995-04-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:40	\N
31317	29914	SECAN	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:40	\N
31318	29915	DEPUTE	1981-07-02 00:00:00	\N	1984-09-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:41	\N
31319	29916	DEPUTE	1986-09-30 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:41	\N
31320	29917	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:41	\N
31321	29918	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:41	\N
31322	29919	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:41	\N
31323	29920	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:41	\N
31324	29921	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:41	\N
31325	29922	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:41	\N
31326	29923	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:41	\N
31327	29924	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:41	\N
31328	29925	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:41	\N
31329	29926	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:41	\N
31330	29927	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:41	\N
31331	29928	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:41	\N
31332	29929	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:41	\N
31333	29930	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:41	\N
31334	29931	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:41	\N
31335	29932	DEPUTE	1977-03-04 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:41	\N
31336	29933	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:41	\N
31337	29934	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:41	\N
31338	29935	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:41	\N
31339	29936	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:41	\N
31340	29937	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:41	\N
31341	29938	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:42	\N
31342	29939	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:42	\N
31343	29940	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:42	\N
31344	29941	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:42	\N
31345	29942	DEPUTE	1997-06-01 00:00:00	\N	2000-04-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:42	\N
31346	29943	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:42	\N
31347	29944	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:42	\N
31348	29945	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:42	\N
31349	29946	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:42	\N
31350	29947	DEPUTE	1998-10-01 00:00:00	\N	2000-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:42	\N
31351	29948	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:42	\N
31352	29949	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:42	\N
31353	29950	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:42	\N
31354	29951	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:42	\N
31355	29952	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:42	\N
31356	29953	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:42	\N
31357	29954	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:42	\N
31358	29955	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:42	\N
31359	29956	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:42	\N
31360	29957	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:42	\N
31361	29958	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:42	\N
31362	29959	DEPUTE	1993-05-02 00:00:00	\N	1995-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:42	\N
31363	29960	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:42	\N
31364	29961	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:43	\N
31365	29962	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:43	\N
31366	29963	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:43	\N
31367	29964	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:43	\N
31368	29965	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:43	\N
31369	29966	DEPUTE	1997-06-01 00:00:00	\N	2001-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:43	\N
31370	29967	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:43	\N
31371	29968	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:43	\N
31372	29969	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:43	\N
31373	29970	DEPUTE	1988-06-13 00:00:00	\N	1990-01-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:43	\N
31374	29971	DEPUTE	1996-02-26 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:43	\N
31375	29972	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:43	\N
31376	29973	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:43	\N
31377	29974	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:43	\N
31378	29975	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:43	\N
31379	29976	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:43	\N
31380	29977	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:43	\N
31381	29978	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:43	\N
31382	29979	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:43	\N
31383	29980	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:43	\N
31384	29981	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:43	\N
31385	29982	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:43	\N
31386	29983	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:43	\N
31387	29984	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:43	\N
31388	29985	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:43	\N
31389	29986	DEPUTE	1991-06-18 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:43	\N
31390	29987	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:43	\N
31391	29988	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:44	\N
31392	29989	DEPUTE	1987-10-14 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:44	\N
31393	29990	DEPUTE	1996-09-15 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:44	\N
31394	29991	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:44	\N
31395	29992	DEPUTE	1986-04-02 00:00:00	\N	1987-10-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:44	\N
31396	29993	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:44	\N
31397	29994	DEPUTE	1997-05-25 00:00:00	\N	2001-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:44	\N
31398	29995	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:44	\N
31399	29996	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:44	\N
31400	29997	DEPUTE	2002-06-19 00:00:00	\N	2003-02-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:44	\N
31401	29998	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:44	\N
31402	29999	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:44	\N
31403	30000	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:44	\N
31404	30001	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:44	\N
31405	30002	DEPUTE	2007-06-20 00:00:00	\N	2012-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:44	\N
31406	30003	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:44	\N
32336	30933	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:11	\N
32337	30934	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:11	\N
32338	30935	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:11	\N
32339	30936	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:11	\N
32340	30937	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:11	\N
32341	30938	VICPDTAN	2003-10-01 00:00:00	\N	2004-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:11	\N
32342	30939	VICPDTAN	2006-01-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:11	\N
32343	30940	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:11	\N
32344	30941	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:11	\N
32345	30942	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:11	\N
32346	30943	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:11	\N
32347	30944	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:11	\N
32348	30945	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:12	\N
32349	30946	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:12	\N
32350	30947	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:12	\N
32351	30948	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:12	\N
32352	30949	DEPUTE	1997-06-01 00:00:00	\N	2001-04-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:12	\N
32353	30950	VICPDTAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:12	\N
32354	30951	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:12	\N
32355	30952	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:12	\N
32356	30953	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:12	\N
32357	30954	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:12	\N
32358	30955	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:12	\N
32359	30956	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:12	\N
32360	30957	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:12	\N
32361	30958	DEPUTE	1958-12-09 00:00:00	\N	1961-09-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:12	\N
32362	30959	DEPUTE	1973-04-02 00:00:00	\N	1974-07-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:12	\N
32363	30960	DEPUTE	1974-07-26 00:00:00	\N	1977-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:12	\N
32364	30961	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:12	\N
32365	30962	DEPUTE	1986-04-02 00:00:00	\N	1986-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:12	\N
32366	30963	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:12	\N
32367	30964	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:12	\N
32368	30965	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:12	\N
32369	30966	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:12	\N
32370	30967	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:12	\N
32371	30968	DEPUTE	1958-12-09 00:00:00	\N	1961-04-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:12	\N
32372	30969	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:12	\N
32373	30970	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:12	\N
32374	30971	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:13	\N
32375	30972	DEPUTE	1973-04-02 00:00:00	\N	1975-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:13	\N
32376	30973	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:13	\N
32377	30974	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:13	\N
32378	30975	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:13	\N
32379	30976	DEPUTE	1986-04-02 00:00:00	\N	1986-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:13	\N
32380	30977	DEPUTE	1986-10-01 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:13	\N
32381	30978	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:13	\N
32382	30979	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:13	\N
32383	30980	DEPUTE	1974-04-29 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:13	\N
32384	30981	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:13	\N
32385	30982	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:13	\N
32386	30983	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:13	\N
32387	30984	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:13	\N
32388	30985	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:13	\N
32389	30986	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:13	\N
32390	30987	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:13	\N
32391	30988	DEPUTE	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:13	\N
32392	30989	DEPUTE	1983-12-04 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:13	\N
32393	30990	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:13	\N
32394	30991	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:13	\N
32395	30992	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:13	\N
32396	30993	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:13	\N
32397	30994	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:13	\N
32398	30995	DEPUTE	1999-02-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:13	\N
32399	30996	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:13	\N
32400	30997	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:13	\N
32401	30998	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:13	\N
32402	30999	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:13	\N
32403	31000	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:13	\N
32404	31001	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:13	\N
32405	31002	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:13	\N
32406	31003	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:13	\N
32407	31004	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:13	\N
32408	31005	DEPUTE	1997-06-01 00:00:00	\N	2001-02-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:13	\N
32409	31006	VICPDTAN	1984-04-01 00:00:00	\N	1985-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:13	\N
32410	31007	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:13	\N
32411	31008	DEPUTE	1998-11-30 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:13	\N
32412	31009	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:13	\N
32413	31010	DEPUTE	2012-06-20 00:00:00	\N	2016-07-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:13	\N
32414	31011	DEPUTE	2010-12-14 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:13	\N
32415	31012	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:13	\N
32416	31013	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:13	\N
32417	31014	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:13	\N
32418	31015	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:13	\N
32419	31016	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:14	\N
32420	31017	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:14	\N
32421	31018	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:14	\N
32422	31019	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:14	\N
32423	31020	DEPUTE	2014-05-03 00:00:00	\N	2014-10-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:14	\N
32424	31021	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:14	\N
32425	31022	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:14	\N
32426	31023	DEPUTE	2002-06-19 00:00:00	\N	2002-11-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:14	\N
32427	31024	DEPUTE	2003-02-03 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:14	\N
32428	31025	DEPUTE	1981-07-24 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:14	\N
33354	31951	SECAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:56	\N
33355	31952	DEPUTE	2000-04-28 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:56	\N
33356	31953	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:56	\N
33357	31954	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:56	\N
33358	31955	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:56	\N
33359	31956	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:56	\N
33360	31957	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:56	\N
33361	31958	DEPUTE	1995-09-17 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:56	\N
33362	31959	VICPDTAN	1988-06-24 00:00:00	\N	1989-04-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:56	\N
33363	31960	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:56	\N
33364	31961	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:56	\N
33365	31962	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:56	\N
33366	31963	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:56	\N
33367	31964	SECAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:56	\N
33368	31965	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:56	\N
33369	31966	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:56	\N
33370	31967	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:56	\N
33371	31968	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:56	\N
33372	31969	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:56	\N
33373	31970	DEPUTE	1988-03-10 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:56	\N
33374	31971	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:56	\N
33375	31972	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:56	\N
33376	31973	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:56	\N
33377	31974	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:56	\N
33378	31975	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:56	\N
33379	31976	SECAN	2004-10-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:56	\N
33380	31977	SECAN	2009-10-06 00:00:00	\N	2010-10-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:56	\N
33381	31978	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:56	\N
33382	31979	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:56	\N
33383	31980	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33384	31981	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33385	31982	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33386	31983	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33387	31984	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33388	31985	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33389	31986	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33390	31987	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33391	31988	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33392	31989	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33393	31990	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33394	31991	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33395	31992	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33396	31993	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33397	31994	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33398	31995	DEPUTE	1988-06-13 00:00:00	\N	1992-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33399	31996	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33400	31997	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33401	31998	DEPUTE	1976-05-09 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33402	31999	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33403	32000	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33404	32001	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33405	32002	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33406	32003	DEPUTE	1973-04-02 00:00:00	\N	1973-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33407	32004	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33408	32005	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33409	32006	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33410	32007	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33411	32008	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33412	32009	DEPUTE	1975-06-15 00:00:00	\N	1976-09-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33413	32010	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33414	32011	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33415	32012	DEPUTE	1993-04-02 00:00:00	\N	1995-07-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33416	32013	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33417	32014	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33418	32015	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33419	32016	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33420	32017	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33421	32018	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33422	32019	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33423	32020	DEPUTE	2002-06-19 00:00:00	\N	2004-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33424	32021	SECAN	2002-06-26 00:00:00	\N	2004-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33425	32022	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33426	32023	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33427	32024	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33428	32025	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33429	32026	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33430	32027	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33431	32028	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33432	32029	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:57	\N
33433	32030	DEPUTE	1962-12-06 00:00:00	\N	1964-12-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:58	\N
33434	32031	DEPUTE	2011-05-06 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:58	\N
33435	32032	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:58	\N
33436	32033	DEPUTE	1995-12-10 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:58	\N
33437	32034	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:58	\N
33438	32035	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:58	\N
33439	32036	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:58	\N
33440	32037	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:58	\N
33441	32038	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:58	\N
33442	32039	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:58	\N
33443	32040	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:58	\N
33444	32041	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:58	\N
33445	32042	VICPDTAN	2002-06-26 00:00:00	\N	2004-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:58	\N
33446	32043	VICPDTAN	2007-06-27 00:00:00	\N	2009-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:58	\N
29143	27740	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:51	\N
29144	27741	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:51	\N
29145	27742	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:51	\N
29146	27743	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:51	\N
29147	27744	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:51	\N
29148	27745	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:51	\N
29149	27746	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:51	\N
29150	27747	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:51	\N
29151	27748	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:51	\N
29152	27749	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:51	\N
29153	27750	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:51	\N
29154	27751	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:51	\N
29155	27752	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:51	\N
29156	27753	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:51	\N
29157	27754	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:51	\N
29158	27755	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:51	\N
29159	27756	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:51	\N
29160	27757	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:51	\N
29161	27758	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:51	\N
29162	27759	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:51	\N
29163	27760	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:51	\N
29164	27761	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:51	\N
29165	27762	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:52	\N
29166	27763	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:52	\N
29167	27764	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:52	\N
29168	27765	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:52	\N
29169	27766	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:52	\N
29170	27767	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:52	\N
29171	27768	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:52	\N
29172	27769	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:52	\N
29173	27770	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:52	\N
29174	27771	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:52	\N
29175	27772	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:52	\N
29176	27773	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:52	\N
29177	27774	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:52	\N
29178	27775	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:52	\N
29179	27776	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:52	\N
29180	27777	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:52	\N
29181	27778	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:52	\N
29182	27779	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:52	\N
29183	27780	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:52	\N
29184	27781	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:52	\N
29185	27782	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:52	\N
31407	30004	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:44	\N
31408	30005	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:44	\N
31409	30006	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31410	30007	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31411	30008	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31412	30009	DEPUTE	2004-05-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31413	30010	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31414	30011	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31415	30012	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31416	30013	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31417	30014	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31418	30015	VICPDTAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31419	30016	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31420	30017	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31421	30018	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31422	30019	DEPUTE	1993-05-02 00:00:00	\N	1995-06-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31423	30020	DEPUTE	1995-07-17 00:00:00	\N	1995-08-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31424	30021	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31425	30022	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31426	30023	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31427	30024	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31428	30025	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31429	30026	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31430	30027	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31431	30028	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31432	30029	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31433	30030	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31434	30031	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31435	30032	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31436	30033	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31437	30034	QUESTAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31438	30035	SECAN	1992-04-02 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31439	30036	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31440	30037	DEPUTE	1980-10-20 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31441	30038	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31442	30039	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31443	30040	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31444	30041	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31445	30042	SECAN	1997-06-13 00:00:00	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31446	30043	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31447	30044	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31448	30045	DEPUTE	2007-06-20 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31449	30046	VICPDTAN	2007-06-27 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31450	30047	DEPUTE	1995-12-08 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31451	30048	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31452	30049	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31453	30050	DEPUTE	1973-04-02 00:00:00	\N	1975-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31454	30051	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31455	30052	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31456	30053	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31457	30054	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31458	30055	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31459	30056	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31460	30057	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31461	30058	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31462	30059	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:45	\N
31463	30060	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:46	\N
31464	30061	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:46	\N
31465	30062	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:46	\N
31466	30063	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:46	\N
31467	30064	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:46	\N
31468	30065	SECAN	2008-10-01 00:00:00	\N	2010-10-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:46	\N
31469	30066	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:46	\N
31470	30067	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:46	\N
31471	30068	DEPUTE	2000-03-20 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:46	\N
31472	30069	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:46	\N
31473	30070	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:46	\N
31474	30071	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:46	\N
31475	30072	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:46	\N
31476	30073	DEPUTE	1997-06-01 00:00:00	\N	1999-08-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:46	\N
31477	30074	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:46	\N
31478	30075	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:46	\N
31479	30076	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:46	\N
31480	30077	DEPUTE	1983-04-23 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:46	\N
31481	30078	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:46	\N
31482	30079	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:46	\N
31483	30080	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:46	\N
31484	30081	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:46	\N
31485	30082	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:46	\N
31486	30083	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:46	\N
31487	30084	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:46	\N
31488	30085	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:46	\N
31489	30086	DEPUTE	2002-06-19 00:00:00	\N	2004-03-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:46	\N
31490	30087	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:46	\N
31491	30088	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:46	\N
31492	30089	DEPUTE	1995-06-25 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:46	\N
31493	30090	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:46	\N
31494	30091	DEPUTE	1958-12-09 00:00:00	\N	1959-02-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:46	\N
31495	30092	DEPUTE	1962-12-06 00:00:00	\N	1963-01-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:46	\N
31496	30093	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:46	\N
31497	30094	DEPUTE	1968-07-11 00:00:00	\N	1969-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:46	\N
31498	30095	DEPUTE	1973-04-02 00:00:00	\N	1973-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:46	\N
31499	30096	DEPUTE	1984-09-24 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:46	\N
32429	31026	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:14	\N
32430	31027	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:14	\N
32431	31028	DEPUTE	1990-11-03 00:00:00	\N	1991-11-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:14	\N
32432	31029	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:14	\N
32433	31030	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:14	\N
32434	31031	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:14	\N
32435	31032	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:14	\N
32436	31033	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:14	\N
32437	31034	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:14	\N
32438	31035	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:14	\N
32439	31036	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:14	\N
32440	31037	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:14	\N
32441	31038	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:14	\N
32442	31039	DEPUTE	1988-06-06 00:00:00	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:14	\N
32443	31040	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:14	\N
32444	31041	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:14	\N
32445	31042	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:14	\N
32446	31043	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:14	\N
32447	31044	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:14	\N
32448	31045	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:14	\N
32449	31046	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:14	\N
32450	31047	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:14	\N
32451	31048	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:14	\N
32452	31049	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:14	\N
32453	31050	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:14	\N
32454	31051	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:14	\N
32455	31052	DEPUTE	1997-06-01 00:00:00	\N	1999-08-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:14	\N
32456	31053	DEPUTE	2003-03-24 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:14	\N
32457	31054	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:14	\N
32458	31055	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:14	\N
32459	31056	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:14	\N
32460	31057	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:14	\N
32461	31058	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:15	\N
32462	31059	DEPUTE	1993-04-02 00:00:00	\N	1995-09-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:15	\N
32463	31060	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:15	\N
32464	31061	DEPUTE	1981-07-02 00:00:00	\N	1985-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:15	\N
32465	31062	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:15	\N
32466	31063	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:15	\N
32467	31064	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:15	\N
32468	31065	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:15	\N
32469	31066	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:15	\N
32470	31067	DEPUTE	2002-06-19 00:00:00	\N	2002-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:15	\N
32471	31068	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:15	\N
32472	31069	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:15	\N
32473	31070	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:15	\N
32474	31071	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:15	\N
32475	31072	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:15	\N
32476	31073	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:15	\N
32477	31074	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:15	\N
32478	31075	DEPUTE	1968-07-11 00:00:00	\N	1968-08-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:15	\N
32479	31076	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:15	\N
32480	31077	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:15	\N
32481	31078	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:15	\N
32482	31079	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:15	\N
32483	31080	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:15	\N
32484	31081	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:15	\N
32485	31082	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:15	\N
32486	31083	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:15	\N
32487	31084	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:15	\N
32488	31085	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:15	\N
32489	31086	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:15	\N
32490	31087	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:15	\N
32491	31088	DEPUTE	1978-05-06 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:15	\N
32492	31089	DEPUTE	1995-12-10 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:15	\N
32493	31090	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:15	\N
32494	31091	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:15	\N
32495	31092	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:15	\N
32496	31093	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:15	\N
32497	31094	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:15	\N
32498	31095	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:15	\N
32499	31096	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:15	\N
32500	31097	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:15	\N
32501	31098	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:15	\N
32502	31099	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:15	\N
32503	31100	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:15	\N
32504	31101	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:15	\N
32505	31102	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:16	\N
32506	31103	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:16	\N
32507	31104	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:16	\N
32508	31105	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:16	\N
32509	31106	VICPDTAN	1995-04-03 00:00:00	\N	1996-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:16	\N
32510	31107	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:16	\N
32511	31108	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:16	\N
32512	31109	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:16	\N
32513	31110	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:16	\N
32514	31111	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:16	\N
32515	31112	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:16	\N
32516	31113	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:16	\N
32517	31114	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:16	\N
32518	31115	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:16	\N
32519	31116	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:16	\N
32520	31117	SECAN	1988-06-24 00:00:00	\N	1992-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:16	\N
32521	31118	DEPUTE	1973-04-02 00:00:00	\N	1976-04-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:16	\N
33632	32229	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:06	\N
33633	32230	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:06	\N
33634	32231	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:06	\N
33635	32232	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:06	\N
33636	32233	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:06	\N
33637	32234	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:06	\N
33638	32235	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:06	\N
33639	32236	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:06	\N
33640	32237	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:06	\N
33641	32238	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:06	\N
33642	32239	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:06	\N
33643	32240	DEPUTE	1980-11-30 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:06	\N
33644	32241	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:06	\N
33645	32242	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:06	\N
33646	32243	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:06	\N
33647	32244	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:06	\N
33648	32245	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:06	\N
33649	32246	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:06	\N
33650	32247	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:06	\N
33651	32248	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:07	\N
33652	32249	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:07	\N
33653	32250	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:07	\N
33654	32251	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:07	\N
33655	32252	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:07	\N
33656	32253	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:07	\N
33657	32254	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:07	\N
33658	32255	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:07	\N
33659	32256	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:07	\N
33660	32257	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:07	\N
33661	32258	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:07	\N
33662	32259	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:07	\N
33663	32260	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:07	\N
33664	32261	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:07	\N
33665	32262	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:07	\N
33666	32263	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:07	\N
33667	32264	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:07	\N
33668	32265	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:07	\N
33669	32266	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:07	\N
33670	32267	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:07	\N
33671	32268	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:07	\N
33672	32269	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:07	\N
33673	32270	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:07	\N
33674	32271	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:07	\N
33675	32272	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:07	\N
33676	32273	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:07	\N
33677	32274	DEPUTE	1988-06-13 00:00:00	\N	1989-05-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:07	\N
33678	32275	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:07	\N
33679	32276	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:07	\N
33680	32277	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:07	\N
33681	32278	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:07	\N
33682	32279	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:07	\N
33683	32280	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:07	\N
33684	32281	DEPUTE	1995-09-17 00:00:00	\N	1995-12-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:07	\N
33685	32282	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:07	\N
33686	32283	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:07	\N
33687	32284	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:07	\N
33688	32285	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:07	\N
33689	32286	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:07	\N
33690	32287	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:07	\N
33691	32288	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:07	\N
33692	32289	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:07	\N
33693	32290	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:07	\N
33694	32291	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:07	\N
33695	32292	DEPUTE	1983-11-05 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:08	\N
33696	32293	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:08	\N
33697	32294	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:08	\N
33698	32295	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:08	\N
33699	32296	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:08	\N
33700	32297	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:08	\N
33701	32298	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:08	\N
33702	32299	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:08	\N
33703	32300	DEPUTE	2014-05-03 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:08	\N
33704	32301	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:08	\N
33705	32302	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:08	\N
33706	32303	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:08	\N
33707	32304	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:08	\N
33708	32305	DEPUTE	2002-06-19 00:00:00	\N	2006-06-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:08	\N
33709	32306	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:08	\N
33710	32307	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:08	\N
33711	32308	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:08	\N
33712	32309	DEPUTE	1993-04-02 00:00:00	\N	1993-12-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:08	\N
33713	32310	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:08	\N
33714	32311	DEPUTE	1997-06-01 00:00:00	\N	2000-04-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:08	\N
33715	32312	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:08	\N
33716	32313	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:08	\N
33717	32314	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:08	\N
33718	32315	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:08	\N
33719	32316	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:08	\N
33720	32317	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:08	\N
33721	32318	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:08	\N
33722	32319	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:08	\N
33723	32320	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:08	\N
33724	32321	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:08	\N
29244	27841	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:55	\N
29248	27845	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:55	\N
29249	27846	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:55	\N
29250	27847	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:55	\N
29251	27848	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:55	\N
29252	27849	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:55	\N
29253	27850	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:55	\N
29254	27851	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:55	\N
29255	27852	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:55	\N
29256	27853	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:55	\N
29257	27854	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:55	\N
29258	27855	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:55	\N
29259	27856	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:56	\N
29260	27857	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:56	\N
29261	27858	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:56	\N
29262	27859	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:56	\N
29263	27860	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:56	\N
29264	27861	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:56	\N
29265	27862	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:56	\N
29266	27863	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:56	\N
29267	27864	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:56	\N
29268	27865	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:56	\N
29269	27866	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:56	\N
29270	27867	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:56	\N
29271	27868	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:56	\N
29272	27869	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:56	\N
29273	27870	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:56	\N
29274	27871	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:56	\N
29275	27872	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:56	\N
29276	27873	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:56	\N
29277	27874	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:56	\N
29278	27875	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:56	\N
29279	27876	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:56	\N
29280	27877	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:56	\N
29281	27878	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:56	\N
29282	27879	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:56	\N
29283	27880	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:56	\N
29284	27881	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:56	\N
29285	27882	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:56	\N
29286	27883	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:56	\N
29287	27884	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:56	\N
29288	27885	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:56	\N
29289	27886	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:56	\N
29290	27887	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:56	\N
29291	27888	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:56	\N
29292	27889	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:56	\N
29293	27890	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:57	\N
29294	27891	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:57	\N
29295	27892	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:57	\N
29296	27893	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:57	\N
29297	27894	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:57	\N
29298	27895	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:57	\N
29299	27896	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:57	\N
29300	27897	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:57	\N
29301	27898	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:57	\N
29302	27899	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:57	\N
29303	27900	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:57	\N
29304	27901	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:57	\N
29305	27902	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:57	\N
29306	27903	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:57	\N
29307	27904	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:57	\N
29308	27905	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:57	\N
29309	27906	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:57	\N
29310	27907	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:57	\N
29311	27908	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:57	\N
29312	27909	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:57	\N
29313	27910	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:57	\N
29314	27911	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:57	\N
29315	27912	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:57	\N
29316	27913	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:57	\N
29317	27914	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:57	\N
29318	27915	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:58	\N
29319	27916	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:58	\N
29320	27917	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:58	\N
29321	27918	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:58	\N
29322	27919	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:58	\N
29323	27920	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:58	\N
29324	27921	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:58	\N
29325	27922	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:58	\N
29326	27923	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:58	\N
29327	27924	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:58	\N
29328	27925	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:58	\N
29329	27926	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:58	\N
29330	27927	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:58	\N
29331	27928	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:58	\N
29332	27929	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:58	\N
29333	27930	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:58	\N
29334	27931	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:58	\N
29335	27932	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:58	\N
29336	27933	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:59	\N
29337	27934	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:59	\N
29338	27935	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:59	\N
29339	27936	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:59	\N
29340	27937	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:59	\N
29341	27938	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:59	\N
29342	27939	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:59	\N
29343	27940	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:59	\N
29344	27941	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:59	\N
29345	27942	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:59	\N
31500	30097	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:46	\N
31501	30098	DEPUTE	1988-06-06 00:00:00	\N	1989-11-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:46	\N
31502	30099	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:46	\N
31503	30100	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:46	\N
31504	30101	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:46	\N
31505	30102	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31506	30103	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31507	30104	DEPUTE	1997-06-01 00:00:00	\N	1998-11-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31508	30105	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31509	30106	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31510	30107	VICPDTAN	1997-06-13 00:00:00	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31511	30108	VICPDTAN	1998-10-01 00:00:00	\N	1998-10-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31512	30109	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31513	30110	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31514	30111	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31515	30112	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31516	30113	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31517	30114	DEPUTE	1993-05-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31518	30115	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31519	30116	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31520	30117	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31521	30118	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31522	30119	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31523	30120	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31524	30121	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31525	30122	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31526	30123	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31527	30124	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31528	30125	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31529	30126	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31530	30127	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31531	30128	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31532	30129	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31533	30130	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31534	30131	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31535	30132	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31536	30133	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31537	30134	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31538	30135	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31539	30136	QUESTAN	1990-04-02 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31540	30137	QUESTAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31541	30138	QUESTAN	1994-04-02 00:00:00	\N	1995-05-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31542	30139	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31543	30140	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31544	30141	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31545	30142	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31546	30143	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31547	30144	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31548	30145	DEPUTE	2002-06-19 00:00:00	\N	2007-03-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31549	30146	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31550	30147	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31551	30148	SECAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:47	\N
31552	30149	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:48	\N
31553	30150	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:48	\N
31554	30151	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:48	\N
31555	30152	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:48	\N
31556	30153	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:48	\N
31557	30154	SECAN	2003-10-01 00:00:00	\N	2005-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:48	\N
31558	30155	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:48	\N
31559	30156	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:48	\N
31560	30157	DEPUTE	2007-06-20 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:48	\N
31561	30158	DEPUTE	1973-04-02 00:00:00	\N	1973-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:48	\N
31562	30159	DEPUTE	1967-04-03 00:00:00	\N	1967-05-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:48	\N
31563	30160	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:48	\N
31564	30161	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:48	\N
31565	30162	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:48	\N
31566	30163	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:48	\N
31567	30164	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:48	\N
31568	30165	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:48	\N
31569	30166	DEPUTE	1981-07-02 00:00:00	\N	1982-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:48	\N
31570	30167	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:48	\N
31571	30168	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:48	\N
31572	30169	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:48	\N
31573	30170	DEPUTE	1973-05-13 00:00:00	\N	1975-04-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:48	\N
31574	30171	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:48	\N
31575	30172	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:48	\N
31576	30173	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:48	\N
31577	30174	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:48	\N
31578	30175	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:48	\N
31579	30176	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:48	\N
31580	30177	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:48	\N
31581	30178	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:48	\N
31582	30179	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:48	\N
31583	30180	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:48	\N
31584	30181	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:48	\N
31585	30182	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:48	\N
31586	30183	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:48	\N
31587	30184	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:48	\N
31588	30185	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:49	\N
31589	30186	VICPDTAN	2005-06-09 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:49	\N
31590	30187	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:49	\N
31591	30188	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:49	\N
31592	30189	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:49	\N
32522	31119	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:16	\N
32523	31120	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:16	\N
32524	31121	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:16	\N
32525	31122	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:16	\N
32526	31123	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:16	\N
32527	31124	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:16	\N
32528	31125	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:16	\N
32529	31126	DEPUTE	1993-04-02 00:00:00	\N	1995-11-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:16	\N
32530	31127	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:16	\N
32531	31128	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:16	\N
32532	31129	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:16	\N
32533	31130	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:17	\N
32534	31131	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:17	\N
32535	31132	DEPUTE	1996-03-17 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:17	\N
32536	31133	DEPUTE	1997-06-01 00:00:00	\N	1999-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:17	\N
32537	31134	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:17	\N
32538	31135	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:17	\N
32539	31136	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:17	\N
32540	31137	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:17	\N
32541	31138	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:17	\N
32542	31139	SECAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:17	\N
32543	31140	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:17	\N
32544	31141	QUESTAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:17	\N
32545	31142	QUESTAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:17	\N
32546	31143	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:17	\N
32547	31144	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:17	\N
32548	31145	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:17	\N
32549	31146	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:17	\N
32550	31147	DEPUTE	1977-06-30 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:17	\N
32551	31148	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:17	\N
32552	31149	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:17	\N
32553	31150	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:17	\N
32554	31151	DEPUTE	1968-08-13 00:00:00	\N	1969-09-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:17	\N
32555	31152	DEPUTE	1973-05-03 00:00:00	\N	1974-07-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:17	\N
32556	31153	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:17	\N
32557	31154	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:17	\N
32558	31155	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:17	\N
32559	31156	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:17	\N
32560	31157	DEPUTE	1973-04-03 00:00:00	\N	1974-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:17	\N
32561	31158	DEPUTE	1986-04-02 00:00:00	\N	1986-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:18	\N
32562	31159	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:18	\N
32563	31160	DEPUTE	1999-08-29 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:18	\N
32564	31161	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:18	\N
32565	31162	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:18	\N
32566	31163	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:18	\N
32567	31164	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:18	\N
32568	31165	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:18	\N
32569	31166	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:18	\N
32570	31167	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:18	\N
32571	31168	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:18	\N
32572	31169	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:18	\N
32573	31170	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:18	\N
32574	31171	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:18	\N
32575	31172	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:18	\N
32576	31173	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:18	\N
32577	31174	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:18	\N
32578	31175	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:18	\N
32579	31176	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:18	\N
32580	31177	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:19	\N
32581	31178	DEPUTE	1986-04-02 00:00:00	\N	1986-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:19	\N
32582	31179	DEPUTE	1986-10-01 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:19	\N
32583	31180	DEPUTE	1988-06-06 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:19	\N
32584	31181	DEPUTE	1997-06-01 00:00:00	\N	1997-07-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:19	\N
32585	31182	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:19	\N
32586	31183	DEPUTE	1981-07-02 00:00:00	\N	1985-12-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:19	\N
32587	31184	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:19	\N
32588	31185	DEPUTE	1988-06-06 00:00:00	\N	1992-05-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:19	\N
32589	31186	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:19	\N
32590	31187	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:19	\N
32591	31188	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:19	\N
32592	31189	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:19	\N
32593	31190	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:19	\N
32594	31191	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:19	\N
32595	31192	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:19	\N
32596	31193	DEPUTE	1981-07-02 00:00:00	\N	1984-08-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:19	\N
32597	31194	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:19	\N
32598	31195	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:19	\N
32599	31196	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:19	\N
32600	31197	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:19	\N
32601	31198	DEPUTE	2007-06-20 00:00:00	\N	2008-04-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:19	\N
32602	31199	DEPUTE	2010-08-05 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:19	\N
32603	31200	DEPUTE	1967-04-02 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:19	\N
32604	31201	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:19	\N
32605	31202	DEPUTE	1973-04-03 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:19	\N
32606	31203	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:19	\N
32607	31204	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:19	\N
32608	31205	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:19	\N
32609	31206	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:19	\N
32610	31207	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:19	\N
32611	31208	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:19	\N
32612	31209	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:20	\N
32613	31210	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:20	\N
32614	31211	DEPUTE	1981-07-02 00:00:00	\N	1986-03-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:20	\N
33261	31858	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:51	\N
33262	31859	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:51	\N
33263	31860	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:51	\N
33264	31861	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:51	\N
33265	31862	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:51	\N
33266	31863	VICPDTAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:51	\N
33267	31864	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:51	\N
33268	31865	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:51	\N
33269	31866	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:51	\N
33270	31867	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:51	\N
33271	31868	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:51	\N
33272	31869	DEPUTE	1988-06-13 00:00:00	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:51	\N
33273	31870	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:51	\N
33274	31871	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:51	\N
33275	31872	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:51	\N
33276	31873	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:51	\N
33277	31874	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:51	\N
33278	31875	DEPUTE	1988-06-06 00:00:00	\N	1991-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:51	\N
33279	31876	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:51	\N
33280	31877	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:51	\N
33281	31878	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:52	\N
33282	31879	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:52	\N
33283	31880	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:52	\N
33284	31881	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:52	\N
33285	31882	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:52	\N
33286	31883	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:52	\N
33287	31884	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:52	\N
33288	31885	SECAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:52	\N
33289	31886	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:52	\N
33290	31887	DEPUTE	2001-11-20 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:52	\N
33291	31888	DEPUTE	1992-05-03 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:52	\N
33292	31889	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:52	\N
33293	31890	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:52	\N
33294	31891	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:52	\N
33295	31892	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:52	\N
33296	31893	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:52	\N
33297	31894	VICPDTAN	1994-04-02 00:00:00	\N	1995-05-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:52	\N
33298	31895	VICPDTAN	1993-04-14 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:52	\N
33299	31896	VICPDTAN	2005-10-04 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:52	\N
33300	31897	VICPDTAN	2002-06-26 00:00:00	\N	2005-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:52	\N
33301	31898	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:52	\N
33302	31899	DEPUTE	1980-11-30 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:52	\N
33303	31900	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:52	\N
33304	31901	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:52	\N
33305	31902	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:52	\N
33306	31903	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:52	\N
33307	31904	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:53	\N
33308	31905	DEPUTE	1986-04-02 00:00:00	\N	1986-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:53	\N
33309	31906	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:53	\N
33310	31907	DEPUTE	1969-09-21 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:53	\N
33311	31908	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:53	\N
33312	31909	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:53	\N
33313	31910	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:53	\N
33314	31911	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:53	\N
33315	31912	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:53	\N
33316	31913	DEPUTE	1985-09-21 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:53	\N
33317	31914	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:53	\N
33318	31915	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:53	\N
33319	31916	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:53	\N
33320	31917	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:53	\N
33321	31918	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:53	\N
33322	31919	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:53	\N
33323	31920	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:53	\N
33324	31921	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:53	\N
33325	31922	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:54	\N
33326	31923	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:54	\N
33327	31924	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:54	\N
33328	31925	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:54	\N
33329	31926	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:54	\N
33330	31927	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:54	\N
33331	31928	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:54	\N
33332	31929	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:54	\N
33333	31930	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:54	\N
33334	31931	DEPUTE	1994-11-27 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:55	\N
33335	31932	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:55	\N
33336	31933	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:55	\N
33337	31934	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:55	\N
33338	31935	DEPUTE	1993-04-02 00:00:00	\N	1995-09-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:55	\N
33339	31936	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:55	\N
33340	31937	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:55	\N
33341	31938	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:55	\N
33342	31939	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:55	\N
33343	31940	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:55	\N
33344	31941	DEPUTE	1973-04-02 00:00:00	\N	1974-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:55	\N
33345	31942	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:55	\N
33346	31943	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:55	\N
33347	31944	DEPUTE	1993-04-02 00:00:00	\N	1994-08-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:55	\N
33348	31945	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:55	\N
33349	31946	DEPUTE	2011-07-30 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:56	\N
33350	31947	DEPUTE	1993-04-02 00:00:00	\N	1994-11-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:56	\N
33351	31948	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:56	\N
33352	31949	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:56	\N
33353	31950	DEPUTE	1995-09-13 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:56	\N
29346	27943	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:59	\N
29347	27944	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:59	\N
29348	27945	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:59	\N
29349	27946	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:59	\N
29350	27947	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:59	\N
29351	27948	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:59	\N
29352	27949	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:59	\N
29353	27950	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:59	\N
29354	27951	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:00	\N
29355	27952	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:00	\N
29356	27953	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:00	\N
29357	27954	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:00	\N
29358	27955	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:00	\N
29359	27956	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:00	\N
29360	27957	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:00	\N
29361	27958	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:00	\N
29362	27959	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:00	\N
29363	27960	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:00	\N
29364	27961	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:00	\N
29365	27962	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:00	\N
29366	27963	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:00	\N
29367	27964	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:00	\N
29368	27965	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:00	\N
29369	27966	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:00	\N
29370	27967	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:00	\N
29371	27968	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:00	\N
29372	27969	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:00	\N
29373	27970	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:00	\N
29374	27971	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:00	\N
29375	27972	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:00	\N
29376	27973	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:00	\N
29377	27974	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:00	\N
29378	27975	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:00	\N
29379	27976	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:00	\N
29380	27977	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:00	\N
29381	27978	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:00	\N
29382	27979	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:00	\N
29383	27980	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:01	\N
29384	27981	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:01	\N
29385	27982	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:01	\N
29386	27983	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:01	\N
29387	27984	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:01	\N
29388	27985	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:01	\N
29389	27986	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:01	\N
29390	27987	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:01	\N
29391	27988	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:01	\N
29392	27989	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:01	\N
29393	27990	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:01	\N
29394	27991	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:01	\N
29395	27992	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:01	\N
29396	27993	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:01	\N
29397	27994	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:01	\N
29398	27995	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:01	\N
29399	27996	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:01	\N
29400	27997	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:01	\N
29401	27998	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:01	\N
29402	27999	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:01	\N
29403	28000	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:01	\N
29404	28001	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:01	\N
29405	28002	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:01	\N
29406	28003	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:01	\N
29407	28004	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:01	\N
29408	28005	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:01	\N
29409	28006	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:01	\N
29410	28007	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:01	\N
29411	28008	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:01	\N
29412	28009	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:02	\N
29413	28010	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:02	\N
29414	28011	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:02	\N
29415	28012	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:02	\N
29416	28013	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:02	\N
29417	28014	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:02	\N
29418	28015	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:02	\N
29419	28016	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:02	\N
29420	28017	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:02	\N
29421	28018	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:02	\N
29422	28019	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:02	\N
29423	28020	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:02	\N
29424	28021	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:02	\N
29425	28022	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:02	\N
29426	28023	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:02	\N
29427	28024	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:02	\N
29428	28025	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:02	\N
29429	28026	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:02	\N
29430	28027	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:02	\N
29431	28028	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:02	\N
29432	28029	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:02	\N
29433	28030	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:02	\N
29434	28031	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:02	\N
29435	28032	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:02	\N
29436	28033	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:03	\N
29437	28034	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:03	\N
29438	28035	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:03	\N
29439	28036	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:03	\N
29440	28037	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:03	\N
29441	28038	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:03	\N
29442	28039	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:03	\N
29443	28040	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:03	\N
29444	28041	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:03	\N
29445	28042	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:03	\N
29446	28043	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:03	\N
29447	28044	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:03	\N
31593	30190	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:49	\N
31594	30191	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:49	\N
31595	30192	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:49	\N
31596	30193	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:49	\N
31597	30194	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:49	\N
31598	30195	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:49	\N
31599	30196	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:49	\N
31600	30197	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:49	\N
31601	30198	DEPUTE	1997-06-01 00:00:00	\N	2001-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:49	\N
31602	30199	DEPUTE	2001-04-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:49	\N
31603	30200	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:49	\N
31604	30201	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:49	\N
31605	30202	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:49	\N
31606	30203	DEPUTE	1997-06-01 00:00:00	\N	1999-12-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:49	\N
31607	30204	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:49	\N
31608	30205	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:49	\N
31609	30206	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:49	\N
31610	30207	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:49	\N
31611	30208	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:49	\N
31612	30209	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:49	\N
31613	30210	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:49	\N
31614	30211	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:49	\N
31615	30212	VICPDTAN	2009-10-06 00:00:00	\N	2010-10-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:49	\N
31616	30213	SECAN	2010-10-05 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:49	\N
31617	30214	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:49	\N
31618	30215	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:49	\N
31619	30216	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:49	\N
31620	30217	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:49	\N
31621	30218	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:49	\N
31622	30219	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:50	\N
31623	30220	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:50	\N
31624	30221	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:50	\N
31625	30222	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:50	\N
31626	30223	QUESTAN	2004-05-05 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:50	\N
31627	30224	DEPUTE	1981-07-02 00:00:00	\N	1983-12-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:50	\N
31628	30225	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:50	\N
31629	30226	DEPUTE	1991-02-04 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:50	\N
31630	30227	DEPUTE	1988-06-13 00:00:00	\N	1990-12-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:50	\N
31631	30228	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:50	\N
31632	30229	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:50	\N
31633	30230	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:50	\N
31634	30231	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:50	\N
31635	30232	DEPUTE	1978-04-02 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:50	\N
31636	30233	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:50	\N
31637	30234	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:50	\N
31638	30235	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:50	\N
31639	30236	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:50	\N
31640	30237	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:50	\N
31641	30238	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:50	\N
31642	30239	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:50	\N
31643	30240	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:50	\N
31644	30241	DEPUTE	1976-09-28 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:50	\N
31645	30242	DEPUTE	1978-05-06 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:50	\N
31646	30243	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:50	\N
31647	30244	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:50	\N
31648	30245	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:50	\N
31649	30246	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:50	\N
31650	30247	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:50	\N
31651	30248	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:50	\N
31652	30249	DEPUTE	1968-07-11 00:00:00	\N	1969-07-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:50	\N
31653	30250	DEPUTE	1970-09-20 00:00:00	\N	1970-10-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:50	\N
31654	30251	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:50	\N
31655	30252	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:50	\N
31656	30253	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:50	\N
31657	30254	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:50	\N
31658	30255	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:50	\N
31659	30256	PDTAN	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:50	\N
31660	30257	PDTAN	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:51	\N
31661	30258	PDTAN	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:51	\N
31662	30259	PDTAN	1968-07-11 00:00:00	\N	1969-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:51	\N
31663	30260	PDTAN	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:51	\N
31664	30261	PDTAN	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:51	\N
31665	30262	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:51	\N
31666	30263	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:51	\N
31667	30264	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:51	\N
31668	30265	DEPUTE	1969-07-21 00:00:00	\N	1970-07-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:51	\N
31669	30266	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:51	\N
31670	30267	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:51	\N
31671	30268	DEPUTE	1968-07-11 00:00:00	\N	1968-08-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:51	\N
31672	30269	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:51	\N
31673	30270	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:51	\N
31674	30271	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:51	\N
31675	30272	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:51	\N
31676	30273	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:51	\N
31677	30274	DEPUTE	1962-12-06 00:00:00	\N	1966-02-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:51	\N
31678	30275	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:51	\N
31679	30276	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:51	\N
31680	30277	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:51	\N
31681	30278	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:51	\N
31682	30279	DEPUTE	1993-04-02 00:00:00	\N	1994-11-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:51	\N
31683	30280	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:51	\N
31684	30281	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:51	\N
31685	30282	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:52	\N
32615	31212	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:20	\N
32616	31213	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:20	\N
32617	31214	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:20	\N
32618	31215	DEPUTE	2012-06-20 00:00:00	\N	2016-03-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:20	\N
32619	31216	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:20	\N
32620	31217	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:20	\N
32621	31218	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:20	\N
32622	31219	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:20	\N
32623	31220	DEPUTE	2002-06-19 00:00:00	\N	2004-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:20	\N
32624	31221	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:20	\N
32625	31222	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:20	\N
32626	31223	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:20	\N
32627	31224	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:20	\N
32628	31225	DEPUTE	1961-06-11 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:20	\N
32629	31226	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:20	\N
32630	31227	DEPUTE	1967-04-02 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:20	\N
32631	31228	DEPUTE	1968-07-11 00:00:00	\N	1969-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:20	\N
32632	31229	DEPUTE	1973-04-03 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:20	\N
32633	31230	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:20	\N
32634	31231	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:20	\N
32635	31232	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:20	\N
32636	31233	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:20	\N
32637	31234	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:20	\N
32638	31235	DEPUTE	1978-05-06 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:20	\N
32639	31236	DEPUTE	1983-12-19 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:20	\N
32640	31237	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:21	\N
32641	31238	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:21	\N
32642	31239	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:21	\N
32643	31240	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:21	\N
32644	31241	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:21	\N
32645	31242	DEPUTE	1998-05-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:21	\N
32646	31243	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:21	\N
32647	31244	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:21	\N
32648	31245	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:21	\N
32649	31246	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:21	\N
32650	31247	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:21	\N
32651	31248	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:21	\N
32652	31249	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:21	\N
32653	31250	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:21	\N
32654	31251	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:21	\N
32655	31252	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:21	\N
32656	31253	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:23	\N
32657	31254	DEPUTE	1978-04-02 00:00:00	\N	1980-10-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:23	\N
32658	31255	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:23	\N
32659	31256	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:23	\N
32660	31257	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:23	\N
32661	31258	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:23	\N
32662	31259	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:23	\N
32663	31260	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:23	\N
32664	31261	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:23	\N
32665	31262	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:23	\N
32666	31263	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:23	\N
32667	31264	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:23	\N
32668	31265	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:25	\N
32669	31266	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:25	\N
32670	31267	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:25	\N
32671	31268	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:25	\N
32672	31269	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:25	\N
32673	31270	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:25	\N
32674	31271	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:25	\N
32675	31272	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:25	\N
32676	31273	QUESTAN	1995-04-03 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:25	\N
32677	31274	SECAN	2002-06-26 00:00:00	\N	2004-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:25	\N
32678	31275	SECAN	2008-10-01 00:00:00	\N	2009-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:25	\N
32679	31276	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:25	\N
32680	31277	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:25	\N
32681	31278	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:25	\N
32682	31279	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:25	\N
32683	31280	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:25	\N
32684	31281	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:25	\N
32685	31282	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:25	\N
32686	31283	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:26	\N
32687	31284	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:26	\N
32688	31285	DEPUTE	1997-06-01 00:00:00	\N	2001-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:26	\N
32689	31286	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:26	\N
32690	31287	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:26	\N
32691	31288	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:26	\N
32692	31289	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:26	\N
32693	31290	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:26	\N
32694	31291	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:26	\N
32695	31292	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:26	\N
32696	31293	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:26	\N
32697	31294	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:26	\N
32698	31295	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:26	\N
32699	31296	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:26	\N
32700	31297	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:26	\N
32701	31298	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:26	\N
32702	31299	VICPDTAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:26	\N
32703	31300	VICPDTAN	1988-06-24 00:00:00	\N	1992-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:26	\N
32704	31301	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:27	\N
32705	31302	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:27	\N
32706	31303	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:27	\N
32707	31304	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:27	\N
33447	32044	SECAN	2012-06-27 00:00:00	\N	2013-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:58	\N
33448	32045	DEPUTE	1982-08-30 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:58	\N
33449	32046	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:58	\N
33450	32047	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:58	\N
33451	32048	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:58	\N
33452	32049	DEPUTE	1981-07-24 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:58	\N
33453	32050	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:58	\N
33454	32051	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:58	\N
33455	32052	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:58	\N
33456	32053	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:58	\N
33457	32054	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:58	\N
33458	32055	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:58	\N
33459	32056	DEPUTE	1997-06-01 00:00:00	\N	2001-04-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:58	\N
33460	32057	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:58	\N
33461	32058	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:58	\N
33462	32059	DEPUTE	2009-07-24 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:58	\N
33463	32060	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:58	\N
33464	32061	VICPDTAN	1997-06-13 00:00:00	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:58	\N
33465	32062	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:58	\N
33466	32063	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:58	\N
33467	32064	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:58	\N
33468	32065	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:58	\N
33469	32066	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:58	\N
33470	32067	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:58	\N
33471	32068	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:58	\N
33472	32069	DEPUTE	1988-06-13 00:00:00	\N	1991-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:58	\N
33473	32070	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:58	\N
33474	32071	VICPDTAN	1988-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:58	\N
33475	32072	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:58	\N
33476	32073	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:58	\N
33477	32074	DEPUTE	1995-09-24 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:59	\N
33478	32075	DEPUTE	1997-05-25 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:59	\N
33479	32076	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:59	\N
33480	32077	DEPUTE	2005-03-14 00:00:00	\N	2005-07-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:59	\N
33481	32078	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:59	\N
33482	32079	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:59	\N
33483	32080	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:59	\N
33484	32081	DEPUTE	2007-06-20 00:00:00	\N	2008-02-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:59	\N
33485	32082	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:59	\N
33486	32083	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:59	\N
33487	32084	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:59	\N
33488	32085	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:59	\N
33489	32086	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:59	\N
33490	32087	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:59	\N
33491	32088	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:59	\N
33492	32089	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:59	\N
33493	32090	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:59	\N
33494	32091	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:59	\N
33495	32092	SECAN	2004-10-01 00:00:00	\N	2005-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:59	\N
33496	32093	SECAN	2008-10-01 00:00:00	\N	2009-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:59	\N
33497	32094	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:59	\N
33498	32095	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:59	\N
33499	32096	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:59	\N
33500	32097	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:59	\N
33501	32098	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:59	\N
33502	32099	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:59	\N
33503	32100	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:59	\N
33504	32101	DEPUTE	2007-06-20 00:00:00	\N	2011-07-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:59	\N
33505	32102	DEPUTE	2012-06-20 00:00:00	\N	2016-08-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:59	\N
33506	32103	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:59	\N
33507	32104	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:59	\N
33508	32105	DEPUTE	1981-07-02 00:00:00	\N	1983-02-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:59	\N
33509	32106	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:00	\N
33510	32107	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:00	\N
33511	32108	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:00	\N
33512	32109	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:00	\N
33513	32110	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:00	\N
33514	32111	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:00	\N
33515	32112	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:00	\N
33516	32113	DEPUTE	2012-06-26 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:00	\N
33517	32114	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:00	\N
33518	32115	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:00	\N
33519	32116	DEPUTE	1993-05-02 00:00:00	\N	1995-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:00	\N
33520	32117	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:00	\N
33521	32118	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:00	\N
33522	32119	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:00	\N
33523	32120	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:00	\N
33524	32121	SECAN	2007-06-27 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:00	\N
33525	32122	SECAN	2010-10-05 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:00	\N
33526	32123	DEPUTE	2008-02-04 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:00	\N
33527	32124	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:01	\N
33528	32125	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:01	\N
33529	32126	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:01	\N
33530	32127	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:01	\N
33531	32128	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:01	\N
33532	32129	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:01	\N
33533	32130	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:01	\N
33534	32131	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:01	\N
33535	32132	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:01	\N
33536	32133	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:01	\N
33537	32134	DEPUTE	1997-06-01 00:00:00	\N	2000-04-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:01	\N
33538	32135	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:01	\N
33539	32136	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:01	\N
29448	28045	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:03	\N
29449	28046	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:03	\N
29450	28047	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:03	\N
29451	28048	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:03	\N
29452	28049	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:03	\N
29453	28050	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:03	\N
29454	28051	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:03	\N
29455	28052	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:03	\N
29456	28053	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:03	\N
29457	28054	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:03	\N
29458	28055	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:04	\N
29459	28056	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:04	\N
29460	28057	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:04	\N
29461	28058	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:04	\N
29462	28059	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:04	\N
29463	28060	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:04	\N
29464	28061	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:04	\N
29465	28062	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:04	\N
29466	28063	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:04	\N
29467	28064	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:04	\N
29468	28065	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:04	\N
29469	28066	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:04	\N
29470	28067	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:04	\N
29471	28068	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:04	\N
29472	28069	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:04	\N
29473	28070	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:04	\N
29474	28071	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:04	\N
29475	28072	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:04	\N
29476	28073	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:04	\N
29477	28074	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:04	\N
29478	28075	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:04	\N
29479	28076	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:04	\N
29480	28077	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:04	\N
29481	28078	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:04	\N
29482	28079	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:04	\N
29483	28080	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:04	\N
29484	28081	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:04	\N
29485	28082	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:04	\N
29486	28083	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:04	\N
29487	28084	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:04	\N
29488	28085	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:04	\N
29489	28086	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:04	\N
29490	28087	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:04	\N
29491	28088	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:04	\N
29492	28089	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:04	\N
29493	28090	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:04	\N
29494	28091	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:04	\N
29495	28092	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:05	\N
29496	28093	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:05	\N
29497	28094	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:05	\N
29498	28095	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:05	\N
29499	28096	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:05	\N
29500	28097	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:05	\N
29501	28098	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:05	\N
29502	28099	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:05	\N
29503	28100	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:05	\N
29504	28101	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:05	\N
29505	28102	SECAN	2012-06-27 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:05	\N
29506	28103	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:05	\N
29507	28104	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:05	\N
29508	28105	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:05	\N
29509	28106	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:05	\N
29510	28107	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:05	\N
29511	28108	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:05	\N
29512	28109	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:05	\N
29513	28110	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:05	\N
29514	28111	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:05	\N
29515	28112	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:05	\N
29516	28113	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:05	\N
29517	28114	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:05	\N
29518	28115	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:05	\N
29519	28116	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:05	\N
29520	28117	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:05	\N
29521	28118	DEPUTE	2016-02-28 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:05	\N
29522	28119	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:05	\N
29523	28120	DEPUTE	2012-06-26 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:05	\N
29524	28121	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:05	\N
29525	28122	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:05	\N
29526	28123	DEPUTE	2014-05-03 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:05	\N
29527	28124	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:05	\N
29528	28125	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:05	\N
29529	28126	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:06	\N
29530	28127	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:06	\N
29531	28128	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:06	\N
29532	28129	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:06	\N
29533	28130	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:06	\N
29534	28131	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:06	\N
29535	28132	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:06	\N
29536	28133	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:06	\N
29537	28134	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:06	\N
29538	28135	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:06	\N
29539	28136	DEPUTE	2015-08-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:06	\N
29540	28137	DEPUTE	2012-06-20 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:06	\N
29541	28138	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:06	\N
29542	28139	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:06	\N
29543	28140	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:06	\N
29544	28141	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:06	\N
29545	28142	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:06	\N
31686	30283	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:52	\N
31687	30284	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:52	\N
31688	30285	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:52	\N
31689	30286	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:52	\N
31690	30287	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:52	\N
31691	30288	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:52	\N
31692	30289	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:52	\N
31693	30290	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:52	\N
31694	30291	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:52	\N
31695	30292	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:52	\N
31696	30293	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:52	\N
31697	30294	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:52	\N
31698	30295	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:52	\N
31699	30296	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:52	\N
31700	30297	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:52	\N
31701	30298	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:52	\N
31702	30299	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:52	\N
31703	30300	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:52	\N
31704	30301	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:52	\N
31705	30302	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:52	\N
31706	30303	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:52	\N
31707	30304	SECAN	2012-06-27 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:52	\N
31708	30305	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:52	\N
31709	30306	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:52	\N
31710	30307	DEPUTE	1962-12-06 00:00:00	\N	1966-02-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:52	\N
31711	30308	DEPUTE	1968-07-11 00:00:00	\N	1972-08-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:52	\N
31712	30309	DEPUTE	1973-04-02 00:00:00	\N	1973-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:52	\N
31713	30310	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:52	\N
31714	30311	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:53	\N
31715	30312	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:53	\N
31716	30313	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:53	\N
31717	30314	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:53	\N
31718	30315	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:53	\N
31719	30316	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:53	\N
31720	30317	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:53	\N
31721	30318	DEPUTE	2007-06-20 00:00:00	\N	2009-11-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:53	\N
31722	30319	DEPUTE	1983-12-18 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:53	\N
31723	30320	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:53	\N
31724	30321	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:53	\N
31725	30322	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:53	\N
31726	30323	SECAN	1994-04-02 00:00:00	\N	1995-04-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:53	\N
31727	30324	SECAN	1996-10-01 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:53	\N
31728	30325	SECAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:53	\N
31729	30326	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:53	\N
31730	30327	SECAN	1999-10-02 00:00:00	\N	2000-04-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:53	\N
31731	30328	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:53	\N
31732	30329	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:53	\N
31733	30330	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:53	\N
31734	30331	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:53	\N
31735	30332	DEPUTE	1993-04-02 00:00:00	\N	1994-09-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:53	\N
31736	30333	DEPUTE	1988-07-29 00:00:00	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:53	\N
31737	30334	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:53	\N
31738	30335	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:53	\N
31739	30336	DEPUTE	2007-03-05 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:53	\N
31740	30337	DEPUTE	1978-04-03 00:00:00	\N	1979-08-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:54	\N
31741	30338	DEPUTE	1986-04-02 00:00:00	\N	1986-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:54	\N
31742	30339	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:54	\N
31743	30340	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:54	\N
31744	30341	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:54	\N
31745	30342	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:54	\N
31746	30343	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:54	\N
31747	30344	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:54	\N
31748	30345	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:54	\N
31749	30346	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:54	\N
31750	30347	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:54	\N
31751	30348	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:54	\N
31752	30349	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:54	\N
31753	30350	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:54	\N
31754	30351	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:54	\N
31755	30352	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:54	\N
31756	30353	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:54	\N
31757	30354	DEPUTE	1988-06-13 00:00:00	\N	1993-03-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:54	\N
31758	30355	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:54	\N
31759	30356	DEPUTE	1999-12-06 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:54	\N
31760	30357	DEPUTE	1973-05-06 00:00:00	\N	1976-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:54	\N
31761	30358	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:55	\N
31762	30359	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:55	\N
31763	30360	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:55	\N
31764	30361	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:55	\N
31765	30362	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:55	\N
31766	30363	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:55	\N
31767	30364	DEPUTE	1958-12-09 00:00:00	\N	1959-03-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:55	\N
31768	30365	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:55	\N
31769	30366	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:55	\N
31770	30367	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:55	\N
31771	30368	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:55	\N
31772	30369	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:55	\N
31773	30370	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:55	\N
31774	30371	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:55	\N
31775	30372	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:55	\N
31776	30373	DEPUTE	1978-04-02 00:00:00	\N	1980-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:55	\N
31777	30374	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:55	\N
31778	30375	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:55	\N
21941	20546	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:37:04	\N
21942	20547	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:37:12	\N
21943	20548	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:37:14	\N
21944	20549	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:37:17	\N
21945	20550	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:37:22	\N
21946	20551	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:37:23	\N
21947	20552	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:37:31	\N
18089	16693	VICPDTAN	2012-06-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:16	2017-06-29 03:43:20
21948	20553	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:37:31	\N
21949	20554	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:37:37	\N
21950	20555	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:37:44	\N
21951	20556	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:37:45	\N
18734	17338	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:46:58	2017-06-19 09:37:46
18932	17536	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:47:13	2017-06-19 09:37:50
21952	20557	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:37:51	\N
21953	20558	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:37:54	\N
21954	20559	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:37:54	\N
21955	20560	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:37:58	\N
21956	20561	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:08	\N
21957	20562	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:09	\N
21958	20563	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:10	\N
21959	20564	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:15	\N
21960	20565	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:16	\N
21961	20566	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:22	\N
21962	20567	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:23	\N
21963	20568	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:23	\N
21964	20569	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:25	\N
21965	20570	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:25	\N
21966	20571	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:28	\N
21967	20572	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:29	\N
21968	20573	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:29	\N
21969	20574	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:29	\N
21970	20575	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:30	\N
20558	19162	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:52	2017-06-19 09:38:30
21971	20576	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:31	\N
21972	20577	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:32	\N
21973	20578	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:32	\N
20615	19219	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:48:57	2017-06-19 09:38:32
21974	20579	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:32	\N
21975	20580	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:33	\N
21976	20581	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:33	\N
21977	20582	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:33	\N
21978	20583	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:33	\N
21979	20584	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:33	\N
21980	20585	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:33	\N
21981	20586	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:33	\N
21982	20587	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:33	\N
21983	20588	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:34	\N
20696	19300	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:02	2017-06-19 09:38:34
21984	20589	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:34	\N
21985	20590	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:35	\N
21986	20591	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:36	\N
20777	19381	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:07	2017-06-19 09:38:36
21987	20592	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:36	\N
21988	20593	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:36	\N
21989	20594	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:36	2017-06-29 09:19:50
21990	20595	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:36	\N
21991	20596	DEPUTE	2014-05-01 00:00:00	\N	2014-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:39	2017-06-29 09:19:53
21992	20597	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:40	\N
21993	20598	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:41	\N
21994	20599	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:42	\N
21062	19666	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:24	2017-06-19 09:38:42
21995	20600	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:42	\N
21996	20601	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:42	\N
21997	20602	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:43	\N
21998	20603	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:43	\N
21099	19703	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:28	2017-06-19 09:38:43
21999	20604	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:44	\N
22000	20605	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:45	\N
22001	20606	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:45	\N
22002	20607	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:45	\N
22003	20608	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:45	\N
22004	20609	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:46	\N
21162	19766	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:34	2017-06-19 09:38:46
22005	20610	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:47	\N
22006	20611	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:47	\N
22007	20612	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:48	\N
22008	20613	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:49	\N
21264	19868	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:39	2017-06-19 09:38:49
22009	20614	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:49	\N
22010	20615	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:49	\N
22011	20616	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:49	\N
22012	20617	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:50	\N
21293	19897	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:41	2017-06-19 09:38:50
22013	20618	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:50	\N
22014	20619	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:51	\N
22015	20620	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:51	\N
22016	20621	PDTAN	2017-06-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:51	2017-06-29 09:20:02
22017	20622	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:51	\N
22018	20623	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:52	\N
22019	20624	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:52	\N
21336	19940	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:44	2017-06-19 09:38:52
22020	20625	DEPUTE	2012-06-20 00:00:00	\N	2015-07-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:52	2017-06-28 03:44:34
33075	31672	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:44	\N
33076	31673	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:44	\N
33077	31674	DEPUTE	2010-12-14 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:44	\N
33078	31675	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:44	\N
33079	31676	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:45	\N
33080	31677	DEPUTE	1995-12-11 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:45	\N
33081	31678	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:45	\N
33082	31679	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:45	\N
33083	31680	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:45	\N
33084	31681	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:45	\N
33085	31682	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:45	\N
33086	31683	DEPUTE	1996-10-01 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:45	\N
33087	31684	DEPUTE	1999-10-02 00:00:00	\N	2000-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:45	\N
33088	31685	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:45	\N
33089	31686	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:45	\N
33090	31687	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:45	\N
33091	31688	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:45	\N
33092	31689	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:45	\N
33093	31690	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:45	\N
33094	31691	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:45	\N
33095	31692	DEPUTE	2007-06-20 00:00:00	\N	2008-09-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:45	\N
33096	31693	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:45	\N
33097	31694	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:45	\N
33098	31695	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:45	\N
33099	31696	DEPUTE	1993-04-02 00:00:00	\N	1993-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:45	\N
33100	31697	DEPUTE	1993-12-13 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:45	\N
33101	31698	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:45	\N
33102	31699	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:45	\N
33103	31700	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:45	\N
33104	31701	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:45	\N
33105	31702	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:45	\N
33106	31703	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:45	\N
33107	31704	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:45	\N
33108	31705	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:45	\N
33109	31706	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:45	\N
33110	31707	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:45	\N
33111	31708	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:45	\N
33112	31709	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:45	\N
33113	31710	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:45	\N
33114	31711	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:45	\N
33115	31712	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:45	\N
33116	31713	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:45	\N
33117	31714	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:45	\N
33118	31715	DEPUTE	1988-04-05 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:45	\N
33119	31716	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:45	\N
33120	31717	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:45	\N
33121	31718	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:45	\N
33122	31719	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:47	\N
33123	31720	DEPUTE	2007-06-20 00:00:00	\N	2009-08-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:47	\N
33124	31721	DEPUTE	1985-03-30 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:47	\N
33125	31722	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:47	\N
33126	31723	DEPUTE	1984-08-24 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:47	\N
33127	31724	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:47	\N
33128	31725	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:47	\N
33129	31726	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:47	\N
33130	31727	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:47	\N
33131	31728	DEPUTE	1981-07-25 00:00:00	\N	1986-03-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:47	\N
33132	31729	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:47	\N
33133	31730	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:47	\N
33134	31731	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:47	\N
33135	31732	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:47	\N
33136	31733	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:47	\N
33137	31734	DEPUTE	1997-06-01 00:00:00	\N	1997-12-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:47	\N
33138	31735	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:47	\N
33139	31736	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:47	\N
33140	31737	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:47	\N
33141	31738	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:47	\N
33142	31739	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:47	\N
33143	31740	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:47	\N
33144	31741	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:47	\N
33145	31742	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:47	\N
33146	31743	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:47	\N
33147	31744	DEPUTE	1998-11-29 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:47	\N
33148	31745	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:47	\N
33149	31746	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:47	\N
33150	31747	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:47	\N
33151	31748	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:47	\N
33152	31749	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:47	\N
33153	31750	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:47	\N
33154	31751	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:47	\N
33155	31752	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:47	\N
33156	31753	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:47	\N
33157	31754	DEPUTE	1984-08-20 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:48	\N
33158	31755	DEPUTE	1989-12-04 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:48	\N
33159	31756	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:48	\N
33160	31757	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:48	\N
33161	31758	DEPUTE	2002-06-19 00:00:00	\N	2002-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:48	\N
33162	31759	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:48	\N
33163	31760	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:48	\N
33164	31761	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:48	\N
33165	31762	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:48	\N
33166	31763	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:48	\N
33167	31764	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:31:48	\N
29546	28143	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:06	\N
29547	28144	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:06	\N
29548	28145	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:06	\N
29549	28146	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:06	\N
29550	28147	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:06	\N
29551	28148	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:06	\N
29552	28149	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:06	\N
29553	28150	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:06	\N
29554	28151	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:07	\N
29555	28152	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:07	\N
29556	28153	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:07	\N
29557	28154	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:07	\N
29558	28155	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:07	\N
29559	28156	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:07	\N
29560	28157	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:07	\N
29561	28158	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:07	\N
29562	28159	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:07	\N
29563	28160	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:07	\N
29564	28161	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:07	\N
29565	28162	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:07	\N
29566	28163	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:07	\N
29567	28164	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:07	\N
29568	28165	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:07	\N
29569	28166	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:07	\N
29570	28167	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:07	\N
29571	28168	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:07	\N
29572	28169	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:08	\N
29573	28170	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:08	\N
29574	28171	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:08	\N
29575	28172	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:08	\N
29576	28173	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:08	\N
29577	28174	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:08	\N
29578	28175	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:08	\N
29579	28176	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:43:08	\N
29766	28363	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:54	\N
29767	28364	DEPUTE	1991-06-18 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:54	\N
29768	28365	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:54	\N
29769	28366	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:54	\N
29770	28367	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:54	\N
29771	28368	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:54	\N
29772	28369	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:54	\N
29773	28370	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:54	\N
29774	28371	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:54	\N
29775	28372	DEPUTE	1995-09-17 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:54	\N
29776	28373	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:54	\N
29777	28374	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:54	\N
29778	28375	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:54	\N
29779	28376	DEPUTE	2011-03-28 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:54	\N
29780	28377	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:54	\N
29781	28378	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:54	\N
29782	28379	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:54	\N
29783	28380	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:54	\N
29784	28381	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:54	\N
29785	28382	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:54	\N
29786	28383	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:54	\N
29787	28384	DEPUTE	1985-05-23 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:55	\N
29788	28385	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:55	\N
29789	28386	DEPUTE	1991-03-09 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:55	\N
29790	28387	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:55	\N
29791	28388	DEPUTE	1995-12-17 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:55	\N
29792	28389	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:55	\N
29793	28390	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:55	\N
29794	28391	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:55	\N
29795	28392	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:55	\N
29796	28393	DEPUTE	2004-05-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:55	\N
29797	28394	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:55	\N
29798	28395	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:55	\N
29799	28396	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:55	\N
29800	28397	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:55	\N
29801	28398	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:55	\N
29802	28399	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:55	\N
29803	28400	DEPUTE	1983-02-08 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:55	\N
29804	28401	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:55	\N
29805	28402	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:55	\N
29806	28403	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:55	\N
29807	28404	DEPUTE	1997-05-25 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:55	\N
29808	28405	DEPUTE	2002-06-19 00:00:00	\N	2006-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:55	\N
29809	28406	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:55	\N
29810	28407	SECAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:55	\N
29811	28408	SECAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:55	\N
29812	28409	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:55	\N
29813	28410	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:55	\N
29814	28411	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:55	\N
29815	28412	SECAN	2004-05-24 00:00:00	\N	2005-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:55	\N
29816	28413	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:56	\N
29817	28414	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:56	\N
29818	28415	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:56	\N
29819	28416	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:56	\N
29820	28417	DEPUTE	2012-06-20 00:00:00	\N	2016-12-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:56	\N
29821	28418	DEPUTE	1995-01-22 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:56	\N
29822	28419	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:56	\N
29823	28420	DEPUTE	1991-06-17 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:56	\N
29824	28421	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:56	\N
29825	28422	DEPUTE	1997-06-01 00:00:00	\N	2001-11-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:56	\N
29826	28423	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:56	\N
31779	30376	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:55	\N
31780	30377	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:55	\N
31781	30378	DEPUTE	1998-03-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:55	\N
31782	30379	DEPUTE	2002-06-19 00:00:00	\N	2003-03-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:55	\N
31783	30380	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:55	\N
31784	30381	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:55	\N
31785	30382	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:55	\N
31786	30383	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:55	\N
31787	30384	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:55	\N
31788	30385	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:55	\N
31789	30386	DEPUTE	1981-07-02 00:00:00	\N	1981-12-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:55	\N
31790	30387	DEPUTE	1992-05-03 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:55	\N
31791	30388	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:55	\N
31792	30389	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:55	\N
31793	30390	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:55	\N
31794	30391	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:55	\N
31795	30392	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:55	\N
31796	30393	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:55	\N
31797	30394	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:55	\N
31798	30395	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:55	\N
31799	30396	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:55	\N
31800	30397	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31801	30398	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31802	30399	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31803	30400	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31804	30401	DEPUTE	1988-06-06 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31805	30402	DEPUTE	1991-06-10 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31806	30403	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31807	30404	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31808	30405	DEPUTE	2000-10-22 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31809	30406	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31810	30407	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31811	30408	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31812	30409	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31813	30410	DEPUTE	1986-09-30 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31814	30411	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31815	30412	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31816	30413	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31817	30414	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31818	30415	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31819	30416	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31820	30417	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31821	30418	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31822	30419	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31823	30420	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31824	30421	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31825	30422	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31826	30423	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31827	30424	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31828	30425	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31829	30426	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31830	30427	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31831	30428	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31832	30429	DEPUTE	1995-09-24 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31833	30430	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31834	30431	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31835	30432	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31836	30433	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31837	30434	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31838	30435	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31839	30436	DEPUTE	2002-06-19 00:00:00	\N	2002-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31840	30437	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31841	30438	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31842	30439	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31843	30440	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31844	30441	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31845	30442	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31846	30443	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31847	30444	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31848	30445	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31849	30446	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31850	30447	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31851	30448	VICPDTAN	1987-04-02 00:00:00	\N	1988-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31852	30449	SECAN	1991-04-02 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31853	30450	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31854	30451	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31855	30452	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:56	\N
31856	30453	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:57	\N
31857	30454	DEPUTE	1997-06-01 00:00:00	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:57	\N
31858	30455	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:57	\N
31859	30456	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:57	\N
31860	30457	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:57	\N
31861	30458	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:57	\N
31862	30459	DEPUTE	1981-07-02 00:00:00	\N	1982-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:57	\N
31863	30460	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:57	\N
31864	30461	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:57	\N
31865	30462	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:57	\N
31866	30463	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:57	\N
31867	30464	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:57	\N
31868	30465	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:57	\N
31869	30466	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:57	\N
31870	30467	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:57	\N
31871	30468	DEPUTE	1995-12-11 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:57	\N
22021	20626	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:52	\N
22022	20627	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:53	\N
22023	20628	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:53	\N
21368	19972	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:45	2017-06-19 09:38:53
22024	20629	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:53	\N
22025	20630	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:54	\N
22026	20631	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:54	\N
22027	20632	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:54	\N
22028	20633	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:54	\N
21400	20004	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:47	2017-06-19 09:38:54
22029	20634	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:55	\N
22030	20635	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:55	\N
22031	20636	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:56	\N
21411	20015	DEPUTE	2016-03-21 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:47	2017-06-19 09:38:56
22032	20637	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:56	\N
22033	20638	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:57	\N
22034	20639	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:58	\N
22035	20640	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-19 09:38:58	2017-06-29 03:44:37
22036	20641	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:01	\N
22037	20642	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:01	\N
22038	20643	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:02	\N
22039	20644	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:03	\N
22040	20645	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:06	\N
21458	20062	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:50	2017-06-19 09:39:06
22041	20646	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:08	\N
22042	20647	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:08	\N
22043	20648	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:09	\N
22044	20649	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:11	\N
22045	20650	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:11	\N
21486	20090	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:52	2017-06-19 09:39:11
22046	20651	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:11	\N
22047	20652	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:11	\N
22048	20653	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:11	\N
22049	20654	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:12	\N
22050	20655	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:12	\N
22051	20656	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:12	\N
22052	20657	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:12	\N
22053	20658	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:13	\N
22054	20659	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:13	\N
22055	20660	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:13	\N
22056	20661	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:13	\N
22057	20662	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:14	\N
22058	20663	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:14	\N
22059	20664	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:14	\N
22060	20665	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:14	\N
22061	20666	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:15	\N
21570	20174	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:58	2017-06-19 09:39:15
22062	20667	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:15	\N
22063	20668	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:15	\N
22064	20669	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:16	\N
22065	20670	DEPUTE	2012-06-20 00:00:00	\N	2016-03-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:16	2017-06-29 03:44:42
21582	20186	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:49:59	2017-06-19 09:39:16
22066	20671	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:16	\N
22067	20672	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:17	2017-06-29 09:20:10
22068	20673	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:17	\N
22069	20674	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:17	\N
22070	20675	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:17	\N
22071	20676	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:18	\N
22072	20677	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:18	\N
22073	20678	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:19	\N
22074	20679	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:19	\N
22075	20680	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:19	\N
22076	20681	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:19	\N
22077	20682	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:19	\N
22078	20683	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:19	\N
22079	20684	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:19	\N
22080	20685	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:20	\N
22081	20686	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:20	\N
22082	20687	DEPUTE	2012-06-20 00:00:00	\N	2016-03-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:20	2017-06-29 09:20:13
22083	20688	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:20	\N
21669	20273	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:06	2017-06-29 09:20:13
22084	20689	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:21	\N
22085	20690	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:21	\N
22086	20691	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:21	\N
22087	20692	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:21	\N
21681	20285	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:07	2017-06-29 09:20:31
22088	20693	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:22	\N
22089	20694	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:22	\N
22090	20695	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:22	\N
22091	20696	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:22	\N
22092	20697	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:23	\N
22093	20698	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:23	\N
22094	20699	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:23	\N
22095	20700	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:23	2017-06-29 09:20:14
22096	20701	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:23	\N
22097	20702	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:23	\N
22098	20703	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:23	\N
22099	20704	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:23	\N
22100	20705	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:24	\N
22101	20706	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:24	\N
22102	20707	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:24	\N
21755	20359	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:12	2017-06-19 09:39:24
22103	20708	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:25	\N
22104	20709	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:25	2017-06-29 09:20:16
22105	20710	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:25	\N
29580	28177	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:46	\N
29581	28178	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:46	\N
29582	28179	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:46	\N
29583	28180	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:46	\N
29584	28181	DEPUTE	1988-06-13 00:00:00	\N	1989-04-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:46	\N
29585	28182	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:47	\N
29586	28183	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:47	\N
29587	28184	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:47	\N
29588	28185	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:47	\N
29589	28186	DEPUTE	2002-06-19 00:00:00	\N	2003-06-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:47	\N
29590	28187	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:47	\N
29591	28188	SECAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:47	\N
29592	28189	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:47	\N
29593	28190	DEPUTE	1994-12-13 00:00:00	\N	1995-07-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:47	\N
29594	28191	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:47	\N
29595	28192	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:47	\N
29596	28193	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:47	\N
29597	28194	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:47	\N
29598	28195	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:47	\N
29599	28196	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:47	\N
29600	28197	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:47	\N
29601	28198	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:47	\N
29602	28199	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:47	\N
29603	28200	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:47	\N
29604	28201	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:47	\N
29605	28202	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:47	\N
29606	28203	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:47	\N
29607	28204	DEPUTE	1973-04-02 00:00:00	\N	1977-01-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:47	\N
29608	28205	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:47	\N
29609	28206	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:47	\N
29610	28207	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:47	\N
29611	28208	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:47	\N
29612	28209	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:47	\N
29613	28210	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:47	\N
29614	28211	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:47	\N
29615	28212	DEPUTE	1988-06-06 00:00:00	\N	1992-11-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:47	\N
29616	28213	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:47	\N
29617	28214	VICPDTAN	1986-04-04 00:00:00	\N	1988-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:47	\N
29618	28215	VICPDTAN	1988-06-24 00:00:00	\N	1992-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:47	\N
22152	20757	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:30	\N
29619	28216	DEPUTE	1973-04-02 00:00:00	\N	1973-05-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:48	\N
29620	28217	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:48	\N
29621	28218	DEPUTE	1986-10-24 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:48	\N
29622	28219	DEPUTE	1978-04-02 00:00:00	\N	1980-10-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:48	\N
29623	28220	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:48	\N
29624	28221	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:48	\N
29625	28222	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:48	\N
29626	28223	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:48	\N
29627	28224	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:48	\N
29628	28225	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:48	\N
29629	28226	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:48	\N
29630	28227	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:48	\N
29631	28228	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:48	\N
29632	28229	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:48	\N
29633	28230	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:48	\N
29634	28231	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:48	\N
29635	28232	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:48	\N
29636	28233	DEPUTE	1981-07-02 00:00:00	\N	1983-02-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:48	\N
29637	28234	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:48	\N
29638	28235	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:48	\N
29639	28236	DEPUTE	1973-04-02 00:00:00	\N	1977-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:48	\N
29640	28237	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:48	\N
29641	28238	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:48	\N
29642	28239	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:48	\N
29643	28240	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:48	\N
29644	28241	DEPUTE	1997-05-25 00:00:00	\N	2001-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:48	\N
29645	28242	SECAN	1986-04-04 00:00:00	\N	1987-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:48	\N
29646	28243	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:48	\N
29647	28244	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:48	\N
29648	28245	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:48	\N
29649	28246	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:48	\N
29650	28247	DEPUTE	1998-06-15 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:49	\N
29651	28248	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:49	\N
29652	28249	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:49	\N
29653	28250	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:49	\N
29654	28251	DEPUTE	1983-11-05 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:49	\N
29655	28252	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:49	\N
29656	28253	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:49	\N
29657	28254	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:49	\N
29658	28255	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:49	\N
29659	28256	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:49	\N
29660	28257	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:49	\N
29661	28258	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:49	\N
29662	28259	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:49	\N
29663	28260	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:49	\N
29664	28261	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:49	\N
29665	28262	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:49	\N
29666	28263	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:49	\N
29667	28264	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:49	\N
29668	28265	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:49	\N
29669	28266	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:49	\N
29670	28267	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:49	\N
29671	28268	DEPUTE	1981-07-02 00:00:00	\N	1984-08-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:49	\N
29672	28269	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:49	\N
29827	28424	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:56	\N
29828	28425	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:56	\N
29829	28426	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:56	\N
29830	28427	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:56	\N
29831	28428	DEPUTE	1988-06-13 00:00:00	\N	1990-09-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:56	\N
29832	28429	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:56	\N
29833	28430	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:56	\N
29834	28431	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:57	\N
29835	28432	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:57	\N
29836	28433	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:57	\N
29837	28434	DEPUTE	1973-04-02 00:00:00	\N	1974-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:57	\N
29838	28435	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:57	\N
29839	28436	DEPUTE	1986-04-02 00:00:00	\N	1987-05-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:57	\N
29840	28437	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:57	\N
29841	28438	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:57	\N
29842	28439	DEPUTE	2001-08-11 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:57	\N
29843	28440	DEPUTE	1992-06-23 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:57	\N
29844	28441	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:57	\N
29845	28442	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:57	\N
29846	28443	DEPUTE	1986-04-02 00:00:00	\N	1986-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:57	\N
29847	28444	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:57	\N
29848	28445	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:57	\N
29849	28446	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:57	\N
29850	28447	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:57	\N
29851	28448	DEPUTE	1981-01-27 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:57	\N
29852	28449	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:57	\N
29853	28450	DEPUTE	1988-06-13 00:00:00	\N	1988-11-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:57	\N
29854	28451	DEPUTE	1989-02-01 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:57	\N
29855	28452	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:58	\N
29856	28453	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:58	\N
29857	28454	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:58	\N
29858	28455	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:58	\N
29859	28456	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:58	\N
29860	28457	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:58	\N
29861	28458	DEPUTE	1995-10-18 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:58	\N
29862	28459	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:58	\N
29863	28460	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:58	\N
29864	28461	DEPUTE	1997-06-01 00:00:00	\N	1998-08-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:58	\N
29865	28462	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:58	\N
29866	28463	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:58	\N
29867	28464	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:58	\N
29868	28465	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:58	\N
29869	28466	DEPUTE	2002-06-19 00:00:00	\N	2007-03-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:58	\N
29870	28467	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:58	\N
29871	28468	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:58	\N
29872	28469	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:58	\N
29873	28470	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:58	\N
29874	28471	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:58	\N
29875	28472	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:58	\N
29876	28473	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:58	\N
29877	28474	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:58	\N
29878	28475	VICPDTAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:58	\N
29879	28476	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:58	\N
29880	28477	VICPDTAN	2001-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:58	\N
29881	28478	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:58	\N
29882	28479	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:58	\N
29883	28480	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:58	\N
29884	28481	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:58	\N
29885	28482	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:58	\N
29886	28483	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:58	\N
29887	28484	DEPUTE	1993-04-02 00:00:00	\N	1995-06-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:58	\N
29888	28485	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:58	\N
29889	28486	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:58	\N
29890	28487	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29891	28488	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29892	28489	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29893	28490	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29894	28491	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29895	28492	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29896	28493	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29897	28494	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29898	28495	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29899	28496	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29900	28497	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29901	28498	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29902	28499	DEPUTE	1986-04-02 00:00:00	\N	1986-04-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29903	28500	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29904	28501	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29905	28502	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29906	28503	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29907	28504	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29908	28505	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29909	28506	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29910	28507	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29911	28508	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29912	28509	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29913	28510	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29914	28511	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29915	28512	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29916	28513	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29917	28514	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29918	28515	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29919	28516	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
30384	28981	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:13	\N
30385	28982	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:13	\N
30386	28983	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:13	\N
30387	28984	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:13	\N
30388	28985	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:13	\N
30389	28986	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:13	\N
30390	28987	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:14	\N
30391	28988	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:14	\N
30392	28989	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:14	\N
30393	28990	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:14	\N
30394	28991	DEPUTE	1996-10-01 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:14	\N
30395	28992	DEPUTE	1968-07-11 00:00:00	\N	1972-04-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:14	\N
30396	28993	DEPUTE	1981-07-02 00:00:00	\N	1983-11-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:14	\N
30397	28994	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:14	\N
30398	28995	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:14	\N
30399	28996	SECAN	1994-04-02 00:00:00	\N	1995-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:14	\N
30400	28997	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:14	\N
30401	28998	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:14	\N
30402	28999	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:14	\N
30403	29000	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:14	\N
30404	29001	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:14	\N
30405	29002	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:14	\N
30406	29003	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:14	\N
30407	29004	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:14	\N
30408	29005	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:14	\N
30409	29006	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:14	\N
30410	29007	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:14	\N
30411	29008	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:14	\N
30412	29009	QUESTAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:14	\N
30413	29010	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:14	\N
30414	29011	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:14	\N
30415	29012	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:14	\N
30416	29013	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:14	\N
30417	29014	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:14	\N
30418	29015	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:14	\N
30419	29016	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:14	\N
30420	29017	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:14	\N
30421	29018	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:14	\N
30422	29019	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:15	\N
30423	29020	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:15	\N
30424	29021	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:15	\N
30425	29022	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:15	\N
30426	29023	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:15	\N
30427	29024	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:15	\N
30428	29025	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:15	\N
30429	29026	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:15	\N
30430	29027	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:15	\N
30431	29028	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:15	\N
30432	29029	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:15	\N
30433	29030	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:15	\N
30434	29031	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:15	\N
30435	29032	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:15	\N
30436	29033	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:15	\N
30437	29034	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:15	\N
30438	29035	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:15	\N
30439	29036	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:15	\N
30440	29037	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:15	\N
30441	29038	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:15	\N
30442	29039	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:15	\N
30443	29040	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:15	\N
30444	29041	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:15	\N
30445	29042	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:15	\N
30446	29043	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:16	\N
30447	29044	DEPUTE	1986-09-30 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:16	\N
30448	29045	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:16	\N
30449	29046	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:16	\N
30450	29047	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:16	\N
30451	29048	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:16	\N
30452	29049	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:16	\N
30453	29050	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:16	\N
30454	29051	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:16	\N
30455	29052	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:16	\N
30456	29053	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:16	\N
30457	29054	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:16	\N
30458	29055	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:16	\N
30459	29056	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:16	\N
30460	29057	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:16	\N
30461	29058	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:16	\N
30462	29059	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:16	\N
30463	29060	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:16	\N
30464	29061	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:16	\N
30465	29062	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:16	\N
30466	29063	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:16	\N
30467	29064	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:16	\N
30468	29065	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:16	\N
30469	29066	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:16	\N
30470	29067	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:16	\N
30471	29068	DEPUTE	1997-06-01 00:00:00	\N	1999-03-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:16	\N
30472	29069	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:17	\N
30473	29070	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:17	\N
30474	29071	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:17	\N
30475	29072	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:17	\N
30476	29073	DEPUTE	1990-01-18 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:17	\N
22106	20711	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:25	\N
22107	20712	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:25	\N
22108	20713	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:25	\N
22109	20714	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:25	\N
22110	20715	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:25	\N
22111	20716	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:25	\N
21774	20378	DEPUTE	2016-04-16 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-15 09:50:13	2017-06-19 09:39:25
22112	20717	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:26	\N
22113	20718	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:26	\N
22114	20719	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:26	\N
22115	20720	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:26	\N
22116	20721	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:26	\N
22117	20722	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:27	\N
22118	20723	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:27	\N
22119	20724	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:27	\N
22120	20725	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:27	\N
22121	20726	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:27	\N
22122	20727	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:27	\N
22123	20728	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:28	\N
22124	20729	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:28	\N
22125	20730	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:28	\N
22126	20731	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:28	\N
22127	20732	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:28	\N
22128	20733	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:28	\N
22129	20734	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:28	\N
22130	20735	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:28	\N
22131	20736	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:29	\N
22132	20737	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:29	\N
22133	20738	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:29	\N
22134	20739	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:29	\N
22135	20740	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:29	\N
22137	20742	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:29	\N
22138	20743	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:29	\N
22139	20744	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:29	\N
22140	20745	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:29	\N
22141	20746	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:29	\N
22142	20747	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:29	\N
22143	20748	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:29	\N
22144	20749	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:29	\N
22145	20750	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:30	\N
22146	20751	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:30	\N
22147	20752	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:30	\N
22148	20753	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:30	\N
22149	20754	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:30	\N
22150	20755	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:30	\N
22151	20756	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:30	\N
22153	20758	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:30	\N
22154	20759	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:30	\N
22155	20760	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:30	\N
22156	20761	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:30	\N
22157	20762	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:31	\N
22158	20763	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:31	\N
22159	20764	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:31	\N
22160	20765	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:31	\N
22161	20766	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:31	\N
22162	20767	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:31	\N
22163	20768	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:31	\N
22164	20769	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:31	\N
22165	20770	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:31	\N
22166	20771	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:31	\N
22167	20772	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:31	\N
22168	20773	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:31	\N
22169	20774	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:31	\N
22170	20775	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:31	\N
22171	20776	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:31	\N
22172	20777	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:32	\N
22173	20778	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:32	\N
22174	20779	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:32	\N
22175	20780	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:32	\N
22176	20781	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:32	\N
22177	20782	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:32	\N
22178	20783	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:32	\N
22179	20784	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:32	\N
22180	20785	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:32	\N
22181	20786	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:32	\N
22182	20787	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:32	\N
22183	20788	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:32	\N
22184	20789	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:32	\N
22185	20790	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:33	\N
22186	20791	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:33	\N
22187	20792	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:33	\N
22188	20793	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:33	\N
22189	20794	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:33	\N
22190	20795	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:33	\N
22191	20796	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:33	\N
22192	20797	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:33	\N
22193	20798	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:33	\N
22194	20799	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:33	\N
22195	20800	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:33	\N
22196	20801	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:33	\N
22197	20802	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:33	\N
22198	20803	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:34	\N
22199	20804	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:34	\N
22200	20805	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:34	\N
22201	20806	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:34	\N
22202	20807	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:34	\N
22203	20808	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:34	\N
22204	20809	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:34	\N
22205	20810	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:34	\N
22206	20811	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:34	\N
29673	28270	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:49	\N
29674	28271	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:49	\N
29675	28272	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:50	\N
29676	28273	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:50	\N
29677	28274	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:50	\N
29678	28275	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:50	\N
29679	28276	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:50	\N
29680	28277	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:50	\N
29681	28278	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:50	\N
29682	28279	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:50	\N
29683	28280	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:50	\N
29684	28281	DEPUTE	1991-06-18 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:50	\N
29685	28282	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:50	\N
29686	28283	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:50	\N
29687	28284	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:50	\N
29688	28285	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:50	\N
29689	28286	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:50	\N
29690	28287	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:50	\N
29691	28288	DEPUTE	1995-06-19 00:00:00	\N	1995-11-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:50	\N
29692	28289	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:50	\N
29693	28290	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:50	\N
29694	28291	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:50	\N
29695	28292	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:50	\N
22236	20841	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:36	\N
29696	28293	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:50	\N
29697	28294	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:50	\N
29698	28295	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:50	\N
29699	28296	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:50	\N
29700	28297	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:50	\N
29701	28298	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:51	\N
29702	28299	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:51	\N
29703	28300	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:51	\N
29704	28301	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:51	\N
29705	28302	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:51	\N
29706	28303	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:51	\N
29707	28304	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:51	\N
29708	28305	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:51	\N
29709	28306	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:51	\N
29710	28307	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:51	\N
29711	28308	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:51	\N
29712	28309	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:51	\N
29713	28310	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:51	\N
29714	28311	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:51	\N
29715	28312	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:51	\N
29716	28313	QUESTAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:51	\N
29717	28314	DEPUTE	1978-04-02 00:00:00	\N	1978-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:51	\N
29718	28315	DEPUTE	1981-07-02 00:00:00	\N	1983-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:51	\N
29719	28316	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:51	\N
29720	28317	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:51	\N
29721	28318	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:51	\N
29722	28319	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:51	\N
29723	28320	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:51	\N
29724	28321	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:52	\N
29725	28322	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:52	\N
29726	28323	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:52	\N
29727	28324	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:52	\N
29728	28325	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:52	\N
29729	28326	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:52	\N
29730	28327	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:52	\N
29731	28328	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:52	\N
29732	28329	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:52	\N
29733	28330	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:52	\N
29734	28331	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:52	\N
29735	28332	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:52	\N
29736	28333	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:52	\N
29737	28334	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:52	\N
29738	28335	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:52	\N
29739	28336	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:52	\N
29740	28337	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:52	\N
29741	28338	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:52	\N
29742	28339	PDTAN	2007-06-26 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:52	\N
29743	28340	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:52	\N
29744	28341	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:52	\N
29745	28342	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:52	\N
29746	28343	DEPUTE	1973-04-02 00:00:00	\N	1973-05-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:52	\N
29747	28344	DEPUTE	1986-04-02 00:00:00	\N	1986-04-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:53	\N
29748	28345	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:53	\N
29749	28346	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:53	\N
29750	28347	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:53	\N
29751	28348	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:53	\N
29752	28349	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:53	\N
29753	28350	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:53	\N
29754	28351	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:53	\N
29755	28352	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:53	\N
29756	28353	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:53	\N
29757	28354	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:53	\N
29758	28355	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:53	\N
29759	28356	DEPUTE	1999-10-01 00:00:00	\N	2000-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:53	\N
29760	28357	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:53	\N
29761	28358	DEPUTE	2002-06-19 00:00:00	\N	2004-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:53	\N
29762	28359	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:53	\N
29763	28360	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:53	\N
29764	28361	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:54	\N
29765	28362	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:54	\N
29920	28517	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29921	28518	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29922	28519	DEPUTE	1978-10-01 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29923	28520	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29924	28521	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29925	28522	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29926	28523	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29927	28524	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29928	28525	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29929	28526	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29930	28527	DEPUTE	2007-06-20 00:00:00	\N	2012-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29931	28528	DEPUTE	2012-06-20 00:00:00	\N	2012-07-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29932	28529	DEPUTE	2014-05-01 00:00:00	\N	2016-03-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29933	28530	DEPUTE	1983-02-28 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29934	28531	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29935	28532	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29936	28533	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29937	28534	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29938	28535	SECAN	1987-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29939	28536	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29940	28537	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29941	28538	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:29:59	\N
29942	28539	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:00	\N
29943	28540	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:00	\N
29944	28541	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:00	\N
29945	28542	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:00	\N
29946	28543	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:00	\N
29947	28544	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:00	\N
29948	28545	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:00	\N
29949	28546	SECAN	2007-06-27 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:00	\N
29950	28547	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:00	\N
29951	28548	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:00	\N
29952	28549	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:00	\N
29953	28550	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:00	\N
29954	28551	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:00	\N
29955	28552	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:00	\N
29956	28553	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:00	\N
29957	28554	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:00	\N
29958	28555	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:00	\N
29959	28556	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:00	\N
29960	28557	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:00	\N
29961	28558	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:00	\N
29962	28559	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:00	\N
29963	28560	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:00	\N
29964	28561	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:00	\N
29965	28562	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:00	\N
29966	28563	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:00	\N
29967	28564	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:00	\N
29968	28565	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:00	\N
29969	28566	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:00	\N
29970	28567	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:00	\N
29971	28568	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:00	\N
29972	28569	DEPUTE	1995-09-24 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:00	\N
29973	28570	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:00	\N
29974	28571	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:00	\N
29975	28572	DEPUTE	1978-04-02 00:00:00	\N	1981-01-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:00	\N
29976	28573	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:01	\N
29977	28574	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:01	\N
29978	28575	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:01	\N
29979	28576	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:01	\N
29980	28577	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:01	\N
29981	28578	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:01	\N
29982	28579	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:01	\N
29983	28580	SECAN	1986-04-04 00:00:00	\N	1987-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:01	\N
29984	28581	VICPDTAN	2010-10-05 00:00:00	\N	2011-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:01	\N
29985	28582	SECAN	2011-10-03 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:01	\N
29986	28583	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:01	\N
29987	28584	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:01	\N
29988	28585	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:01	\N
29989	28586	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:01	\N
29990	28587	DEPUTE	1986-04-02 00:00:00	\N	1986-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:01	\N
29991	28588	DEPUTE	1986-09-29 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:01	\N
29992	28589	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:01	\N
29993	28590	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:01	\N
29994	28591	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:01	\N
29995	28592	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:01	\N
29996	28593	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:01	\N
29997	28594	DEPUTE	1983-07-27 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:01	\N
29998	28595	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:01	\N
29999	28596	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:01	\N
30000	28597	DEPUTE	1989-06-26 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:01	\N
30001	28598	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:01	\N
30002	28599	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:01	\N
30003	28600	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:01	\N
30004	28601	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:01	\N
30005	28602	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:01	\N
30006	28603	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:01	\N
30007	28604	DEPUTE	1986-09-30 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:01	\N
30008	28605	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:01	\N
30009	28606	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:02	\N
30010	28607	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:02	\N
30011	28608	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:02	\N
30012	28609	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:02	\N
30477	29074	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:17	\N
30478	29075	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:17	\N
30479	29076	DEPUTE	2002-06-19 00:00:00	\N	2002-12-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:17	\N
30480	29077	DEPUTE	2003-03-24 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:17	\N
30481	29078	DEPUTE	1997-06-12 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:17	\N
30482	29079	DEPUTE	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:17	\N
30483	29080	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:17	\N
30484	29081	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:17	\N
30485	29082	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:17	\N
30486	29083	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:17	\N
30487	29084	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:17	\N
30488	29085	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:17	\N
30489	29086	DEPUTE	1988-06-13 00:00:00	\N	1988-11-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:17	\N
30490	29087	SECAN	1986-04-04 00:00:00	\N	1987-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:17	\N
30491	29088	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:17	\N
30492	29089	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:17	\N
30493	29090	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:17	\N
30494	29091	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:17	\N
30495	29092	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:17	\N
30496	29093	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:17	\N
30497	29094	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:17	\N
30498	29095	QUESTAN	2007-06-27 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:17	\N
30499	29096	QUESTAN	2012-06-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:17	\N
30500	29097	DEPUTE	1971-12-05 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:17	\N
30501	29098	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:17	\N
30502	29099	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:17	\N
30503	29100	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:17	\N
30504	29101	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:17	\N
30505	29102	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:17	\N
30506	29103	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:17	\N
30507	29104	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:17	\N
30508	29105	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:17	\N
30509	29106	SECAN	1986-04-04 00:00:00	\N	1987-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:17	\N
30510	29107	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:17	\N
30511	29108	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30512	29109	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30513	29110	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30514	29111	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30515	29112	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30516	29113	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30517	29114	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30518	29115	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30519	29116	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30520	29117	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30521	29118	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30522	29119	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30523	29120	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30524	29121	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30525	29122	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30526	29123	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30527	29124	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30528	29125	DEPUTE	1997-06-01 00:00:00	\N	1998-09-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30529	29126	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30530	29127	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30531	29128	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30532	29129	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30533	29130	DEPUTE	2012-06-20 00:00:00	\N	2015-08-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30534	29131	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30535	29132	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30536	29133	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30537	29134	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30538	29135	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30539	29136	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30540	29137	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30541	29138	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30542	29139	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30543	29140	DEPUTE	1997-06-01 00:00:00	\N	2001-11-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30544	29141	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30545	29142	VICPDTAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30546	29143	QUESTAN	1997-06-13 00:00:00	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30547	29144	SECAN	2002-06-26 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30548	29145	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30549	29146	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30550	29147	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30551	29148	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30552	29149	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30553	29150	DEPUTE	1997-05-17 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30554	29151	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30555	29152	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30556	29153	DEPUTE	1995-06-26 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30557	29154	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30558	29155	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30559	29156	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30560	29157	VICPDTAN	2005-07-04 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30561	29158	VICPDTAN	2004-05-05 00:00:00	\N	2005-07-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30562	29159	DEPUTE	1992-07-04 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30563	29160	DEPUTE	1998-08-11 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30564	29161	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:18	\N
30565	29162	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:19	\N
30566	29163	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:19	\N
30567	29164	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:19	\N
30568	29165	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:19	\N
30569	29166	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:19	\N
22207	20812	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:34	\N
22208	20813	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:34	\N
22209	20814	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:34	\N
22210	20815	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:35	\N
22211	20816	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:35	\N
22212	20817	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:35	\N
22213	20818	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:35	\N
22214	20819	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:35	\N
22215	20820	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:35	\N
22216	20821	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:35	\N
22217	20822	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:35	\N
22218	20823	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:35	\N
22219	20824	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:35	\N
22220	20825	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:36	\N
22221	20826	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:36	\N
22222	20827	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:36	\N
22223	20828	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:36	\N
22225	20830	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:36	\N
22226	20831	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:36	\N
22227	20832	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:36	\N
22228	20833	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:36	\N
22229	20834	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:36	\N
22230	20835	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:36	\N
22231	20836	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:36	\N
22232	20837	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:36	\N
22233	20838	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:36	\N
22234	20839	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:36	\N
22235	20840	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:36	\N
22237	20842	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:36	\N
22238	20843	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:37	\N
22239	20844	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:37	\N
22240	20845	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:37	\N
22241	20846	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:37	\N
22242	20847	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:37	\N
22243	20848	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:37	\N
22244	20849	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:37	\N
22245	20850	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:37	\N
22246	20851	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:37	\N
22247	20852	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:37	\N
22248	20853	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:37	\N
22249	20854	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:37	\N
22250	20855	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:37	\N
22251	20856	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:37	\N
22252	20857	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:37	\N
22253	20858	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:37	\N
22254	20859	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:37	\N
22255	20860	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:38	\N
22256	20861	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:38	\N
22257	20862	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:38	\N
22258	20863	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:38	\N
22259	20864	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:38	\N
22260	20865	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:38	\N
22261	20866	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:38	\N
22262	20867	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:38	\N
22263	20868	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:38	\N
22264	20869	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:38	\N
22265	20870	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:38	\N
22266	20871	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:38	\N
22267	20872	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:38	\N
22268	20873	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:38	\N
22269	20874	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:38	\N
22270	20875	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:38	\N
22271	20876	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:39	\N
22272	20877	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:39	\N
22273	20878	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:39	\N
22274	20879	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:39	\N
22275	20880	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:39	\N
22276	20881	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:39	\N
22277	20882	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:39	\N
22278	20883	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:39	\N
22279	20884	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:39	\N
22280	20885	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:39	\N
22281	20886	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:39	\N
22282	20887	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:39	\N
22283	20888	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:39	\N
22284	20889	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:39	\N
22285	20890	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:39	\N
22286	20891	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:40	\N
22287	20892	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:40	\N
22288	20893	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:40	\N
22289	20894	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:40	\N
22290	20895	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:40	\N
22291	20896	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:40	\N
22292	20897	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:40	\N
22293	20898	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:40	\N
22294	20899	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:40	\N
22295	20900	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:40	\N
22296	20901	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:40	\N
22297	20902	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:40	\N
22298	20903	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:40	\N
22299	20904	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:41	\N
22300	20905	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:41	\N
22301	20906	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:41	\N
22302	20907	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:41	\N
22303	20908	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:41	\N
22304	20909	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:41	\N
22305	20910	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:41	\N
22306	20911	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:41	\N
22307	20912	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:41	\N
22308	20913	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:41	\N
22309	20914	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:41	\N
28304	26901	DEPUTE	2007-07-04 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:23	\N
28305	26902	DEPUTE	2012-12-17 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:23	\N
28306	26903	DEPUTE	2007-07-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:23	\N
28307	26904	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:23	\N
28308	26905	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:24	\N
28309	26906	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:24	\N
28310	26907	DEPUTE	2012-06-20 00:00:00	\N	2015-08-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:24	\N
28311	26908	DEPUTE	2004-05-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:24	\N
28312	26909	DEPUTE	2004-11-22 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:24	\N
28313	26910	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:24	\N
28314	26911	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:24	\N
28315	26912	DEPUTE	2004-05-01 00:00:00	\N	2005-07-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:24	\N
28316	26913	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:24	\N
28317	26914	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:24	\N
28318	26915	SECAN	2005-10-04 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:24	\N
28319	26916	QUESTAN	2007-06-27 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:24	\N
28320	26917	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:24	\N
28321	26918	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:24	\N
28322	26919	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:24	\N
28323	26920	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:24	\N
28324	26921	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:24	\N
28325	26922	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:24	\N
28326	26923	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:24	\N
28327	26924	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:24	\N
28328	26925	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:24	\N
28329	26926	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:24	\N
28330	26927	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:24	\N
28331	26928	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:24	\N
28332	26929	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:24	\N
28333	26930	DEPUTE	2007-06-20 00:00:00	\N	2011-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:24	\N
28334	26931	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:24	\N
28335	26932	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:24	\N
28336	26933	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:24	\N
28337	26934	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:24	\N
28338	26935	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:24	\N
28339	26936	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:24	\N
28340	26937	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:25	\N
28341	26938	DEPUTE	2010-11-13 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:25	\N
28342	26939	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:25	\N
28343	26940	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:25	\N
28344	26941	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:25	\N
28345	26942	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:25	\N
28346	26943	DEPUTE	2010-06-05 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:25	\N
28347	26944	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:25	\N
28348	26945	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:25	\N
28349	26946	DEPUTE	2009-04-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:25	\N
28350	26947	DEPUTE	2007-07-20 00:00:00	\N	2009-07-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:25	\N
28351	26948	DEPUTE	2009-09-28 00:00:00	\N	2010-05-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:25	\N
28352	26949	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:25	\N
28353	26950	DEPUTE	2012-07-22 00:00:00	\N	2013-08-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:25	\N
28354	26951	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:25	\N
28355	26952	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:25	\N
28356	26953	DEPUTE	2007-07-20 00:00:00	\N	2012-03-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:25	\N
28357	26954	DEPUTE	2008-09-19 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:25	\N
28358	26955	DEPUTE	2010-04-23 00:00:00	\N	2011-06-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:25	\N
28359	26956	DEPUTE	2012-07-22 00:00:00	\N	2016-03-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:25	\N
28360	26957	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:25	\N
28361	26958	DEPUTE	2007-07-20 00:00:00	\N	2009-07-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:25	\N
28362	26959	DEPUTE	2013-06-10 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:25	\N
28363	26960	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:25	\N
28364	26961	DEPUTE	2014-05-10 00:00:00	\N	2014-05-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:25	\N
28365	26962	DEPUTE	2004-05-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:25	\N
28366	26963	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:25	\N
28367	26964	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:25	\N
28368	26965	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:25	\N
28369	26966	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:25	\N
28370	26967	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:25	\N
28371	26968	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:25	\N
28372	26969	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:25	\N
28373	26970	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:25	\N
28374	26971	DEPUTE	2007-06-20 00:00:00	\N	2010-12-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:25	\N
28375	26972	DEPUTE	2005-10-04 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:25	\N
28376	26973	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:25	\N
28377	26974	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:25	\N
28378	26975	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:25	\N
28379	26976	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:25	\N
28380	26977	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:25	\N
28381	26978	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:25	\N
28382	26979	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:25	\N
28383	26980	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:25	\N
28384	26981	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:26	\N
28385	26982	DEPUTE	2007-06-20 00:00:00	\N	2007-11-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:26	\N
28386	26983	DEPUTE	2002-07-19 00:00:00	\N	2005-06-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:26	\N
28387	26984	DEPUTE	2009-01-05 00:00:00	\N	2010-12-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:26	\N
28388	26985	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:26	\N
28389	26986	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:26	\N
28390	26987	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:26	\N
28391	26988	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:26	\N
28392	26989	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:26	\N
28393	26990	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:26	\N
28394	26991	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:26	\N
28395	26992	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:26	\N
28396	26993	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:26	\N
30013	28610	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:02	\N
30014	28611	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:02	\N
30015	28612	DEPUTE	1994-03-13 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:02	\N
30016	28613	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:02	\N
30017	28614	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:02	\N
30018	28615	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:02	\N
30019	28616	VICPDTAN	1995-05-31 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:02	\N
30020	28617	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:02	\N
30021	28618	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:02	\N
30022	28619	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:02	\N
30023	28620	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:02	\N
30024	28621	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:02	\N
30025	28622	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:02	\N
30026	28623	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:02	\N
30027	28624	DEPUTE	2002-06-19 00:00:00	\N	2005-07-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:02	\N
30028	28625	DEPUTE	2007-06-20 00:00:00	\N	2010-04-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:02	\N
30029	28626	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:02	\N
30030	28627	DEPUTE	2012-06-20 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:02	\N
30031	28628	DEPUTE	1993-04-02 00:00:00	\N	1995-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:02	\N
30032	28629	DEPUTE	1997-06-12 00:00:00	\N	1999-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:02	\N
30033	28630	VICPDTAN	2003-10-01 00:00:00	\N	2005-07-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:02	\N
30034	28631	VICPDTAN	2002-06-26 00:00:00	\N	2003-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:02	\N
30035	28632	DEPUTE	1993-09-03 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:02	\N
30036	28633	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:02	\N
30037	28634	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:02	\N
30038	28635	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:02	\N
30039	28636	DEPUTE	1978-04-03 00:00:00	\N	1978-05-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:02	\N
30040	28637	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:02	\N
30041	28638	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:02	\N
30042	28639	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:02	\N
30043	28640	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:02	\N
30044	28641	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:02	\N
30045	28642	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:02	\N
30046	28643	DEPUTE	1978-04-03 00:00:00	\N	1978-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:03	\N
30047	28644	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:03	\N
30048	28645	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:03	\N
30049	28646	DEPUTE	1973-04-02 00:00:00	\N	1974-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:03	\N
30050	28647	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:03	\N
30051	28648	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:03	\N
30052	28649	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:03	\N
30053	28650	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:03	\N
30054	28651	DEPUTE	2002-06-19 00:00:00	\N	2004-05-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:03	\N
30055	28652	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:03	\N
30056	28653	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:03	\N
30057	28654	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:03	\N
30058	28655	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:03	\N
30059	28656	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:03	\N
30060	28657	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:03	\N
30061	28658	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:03	\N
30062	28659	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:03	\N
30063	28660	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:03	\N
30064	28661	DEPUTE	1997-06-01 00:00:00	\N	1998-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:03	\N
30065	28662	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:03	\N
30066	28663	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:03	\N
30067	28664	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:03	\N
30068	28665	VICPDTAN	1992-04-02 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:03	\N
30069	28666	PDTAN	2012-06-26 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:03	\N
30070	28667	DEPUTE	1988-06-06 00:00:00	\N	1990-12-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:03	\N
30071	28668	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:03	\N
30072	28669	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:03	\N
30073	28670	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:03	\N
30074	28671	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:03	\N
30075	28672	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:03	\N
30076	28673	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:03	\N
30077	28674	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:03	\N
30078	28675	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:03	\N
30079	28676	QUESTAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:03	\N
30080	28677	DEPUTE	1993-04-02 00:00:00	\N	1995-12-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:04	\N
30081	28678	DEPUTE	1996-04-01 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:04	\N
30082	28679	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:04	\N
30083	28680	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:04	\N
30084	28681	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:04	\N
30085	28682	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:04	\N
30086	28683	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:04	\N
30087	28684	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:04	\N
30088	28685	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:04	\N
30089	28686	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:04	\N
30090	28687	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:04	\N
30091	28688	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:04	\N
30092	28689	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:04	\N
30093	28690	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:04	\N
30094	28691	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:04	\N
30095	28692	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:04	\N
30096	28693	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:04	\N
30097	28694	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:04	\N
30098	28695	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:04	\N
30099	28696	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:04	\N
30100	28697	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:04	\N
30101	28698	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:04	\N
30102	28699	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:04	\N
30103	28700	DEPUTE	1986-04-02 00:00:00	\N	1986-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:04	\N
30104	28701	DEPUTE	1986-10-24 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:04	\N
30105	28702	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:04	\N
30570	29167	DEPUTE	2010-12-14 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:19	\N
30571	29168	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:19	\N
30572	29169	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:19	\N
30573	29170	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:19	\N
30574	29171	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:19	\N
30575	29172	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:19	\N
30576	29173	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:19	\N
30577	29174	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:19	\N
30578	29175	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:19	\N
30579	29176	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:19	\N
30580	29177	DEPUTE	2002-06-19 00:00:00	\N	2004-01-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:19	\N
30581	29178	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:19	\N
30582	29179	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:19	\N
30583	29180	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:19	\N
30584	29181	DEPUTE	1987-05-15 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:19	\N
30585	29182	DEPUTE	1988-06-13 00:00:00	\N	1993-03-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:19	\N
30586	29183	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:19	\N
30587	29184	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:19	\N
30588	29185	DEPUTE	2013-04-20 00:00:00	\N	2013-04-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:19	\N
30589	29186	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:19	\N
30590	29187	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:19	\N
30591	29188	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:19	\N
30592	29189	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:19	\N
30593	29190	DEPUTE	1989-04-30 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:19	\N
30594	29191	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:19	\N
30595	29192	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:19	\N
30596	29193	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:19	\N
30597	29194	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:19	\N
30598	29195	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:19	\N
30599	29196	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:19	\N
30600	29197	DEPUTE	2007-06-20 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:19	\N
30601	29198	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:19	\N
30602	29199	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:19	\N
30603	29200	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:20	\N
30604	29201	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:20	\N
30605	29202	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:20	\N
30606	29203	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:20	\N
30607	29204	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:20	\N
30608	29205	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:20	\N
30609	29206	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:20	\N
30610	29207	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:20	\N
30611	29208	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:20	\N
30612	29209	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:20	\N
30613	29210	DEPUTE	1994-02-26 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:20	\N
30614	29211	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:20	\N
30615	29212	DEPUTE	1997-06-01 00:00:00	\N	2000-12-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:20	\N
30616	29213	DEPUTE	1968-07-11 00:00:00	\N	1968-08-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:20	\N
30617	29214	DEPUTE	1995-12-10 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:20	\N
30618	29215	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:20	\N
30619	29216	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:20	\N
30620	29217	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:20	\N
30621	29218	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:20	\N
30622	29219	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:20	\N
30623	29220	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:20	\N
30624	29221	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:20	\N
30625	29222	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:20	\N
30626	29223	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:20	\N
30627	29224	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:20	\N
30628	29225	DEPUTE	2007-06-20 00:00:00	\N	2010-06-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:20	\N
30629	29226	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:20	\N
30630	29227	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:20	\N
30631	29228	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:20	\N
30632	29229	DEPUTE	2012-06-20 00:00:00	\N	2017-04-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:20	\N
30633	29230	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:20	\N
30634	29231	DEPUTE	1988-06-06 00:00:00	\N	1988-11-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:20	\N
30635	29232	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:21	\N
30636	29233	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:21	\N
30637	29234	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:21	\N
30638	29235	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:21	\N
30639	29236	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:21	\N
30640	29237	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:21	\N
30641	29238	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:21	\N
30642	29239	SECAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:21	\N
30643	29240	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:21	\N
30644	29241	DEPUTE	1990-09-21 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:21	\N
30645	29242	DEPUTE	1981-07-02 00:00:00	\N	1983-04-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:21	\N
30646	29243	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:21	\N
30647	29244	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:21	\N
30648	29245	DEPUTE	1997-06-01 00:00:00	\N	1999-12-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:21	\N
30649	29246	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:21	\N
30650	29247	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:21	\N
30651	29248	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:21	\N
30652	29249	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:21	\N
30653	29250	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:21	\N
30654	29251	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:21	\N
30655	29252	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:21	\N
30656	29253	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:21	\N
30657	29254	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:21	\N
30658	29255	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:21	\N
30659	29256	DEPUTE	1997-06-01 00:00:00	\N	1999-10-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:21	\N
30660	29257	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:21	\N
30661	29258	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:21	\N
30662	29259	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:21	\N
22310	20915	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:41	\N
22311	20916	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:41	\N
22312	20917	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:42	\N
22313	20918	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:42	\N
22314	20919	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:42	\N
22315	20920	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:42	\N
22316	20921	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:42	\N
22317	20922	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:42	\N
22318	20923	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:42	\N
22319	20924	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:42	\N
22320	20925	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:42	\N
22321	20926	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:42	\N
22322	20927	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:43	\N
22323	20928	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:43	\N
22325	20930	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:43	\N
22326	20931	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:43	\N
22327	20932	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:43	\N
22328	20933	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:43	\N
22329	20934	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:43	\N
22330	20935	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:43	\N
22331	20936	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:43	\N
22332	20937	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:43	\N
22333	20938	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:43	\N
22334	20939	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:43	\N
22335	20940	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:43	\N
22336	20941	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:43	\N
22337	20942	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:43	\N
22338	20943	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:43	\N
22339	20944	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:43	\N
22340	20945	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:43	\N
22341	20946	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:44	\N
22342	20947	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:44	\N
22343	20948	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:44	\N
22344	20949	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:44	\N
22345	20950	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:44	\N
22346	20951	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:44	\N
22347	20952	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:44	\N
22348	20953	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:44	\N
22349	20954	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:44	\N
22350	20955	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:44	\N
22351	20956	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:44	\N
22352	20957	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:44	\N
22353	20958	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:44	\N
22354	20959	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:44	\N
22355	20960	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:44	\N
22356	20961	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:44	\N
22357	20962	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:44	\N
22358	20963	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:44	\N
22359	20964	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:44	\N
22360	20965	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:45	\N
22361	20966	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:45	\N
22362	20967	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:45	\N
22363	20968	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:45	\N
22364	20969	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:45	\N
22365	20970	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:45	\N
22366	20971	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:45	\N
22367	20972	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:45	\N
22368	20973	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:45	\N
22369	20974	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:45	\N
22370	20975	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:45	\N
22371	20976	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:45	\N
22372	20977	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:45	\N
22373	20978	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:45	\N
22374	20979	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:45	\N
22375	20980	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:46	\N
22376	20981	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:46	\N
22377	20982	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:46	\N
22378	20983	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:46	\N
22379	20984	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:46	\N
22380	20985	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:46	\N
22381	20986	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:46	\N
22382	20987	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:46	\N
22383	20988	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:46	\N
22384	20989	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:46	\N
22385	20990	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:46	\N
22386	20991	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:46	\N
22387	20992	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:46	\N
22388	20993	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:47	\N
22389	20994	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:47	\N
22390	20995	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:47	\N
22391	20996	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:47	\N
22392	20997	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:47	\N
22393	20998	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:47	\N
22394	20999	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:47	\N
22395	21000	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:47	\N
22396	21001	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:47	\N
22397	21002	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:47	\N
22398	21003	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:47	\N
22399	21004	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:48	\N
22400	21005	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:48	\N
22401	21006	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:48	\N
22402	21007	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:48	\N
22403	21008	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:48	\N
22404	21009	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:48	\N
22405	21010	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:48	\N
22406	21011	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:48	\N
22407	21012	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:48	\N
22408	21013	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:48	\N
22409	21014	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:48	\N
22410	21015	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:48	\N
22411	21016	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:49	\N
22412	21017	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:49	\N
28397	26994	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:26	\N
28398	26995	DEPUTE	2012-07-22 00:00:00	\N	2014-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:26	\N
28399	26996	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:26	\N
28400	26997	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:26	\N
28401	26998	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:26	\N
28402	26999	DEPUTE	2006-09-02 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:26	\N
28403	27000	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:26	\N
28404	27001	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:26	\N
28405	27002	DEPUTE	2012-07-22 00:00:00	\N	2014-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:26	\N
28406	27003	VICPDTAN	2008-10-01 00:00:00	\N	2009-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:26	\N
28407	27004	SECAN	2009-10-06 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:26	\N
28408	27005	DEPUTE	2002-06-19 00:00:00	\N	2002-11-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:26	\N
28409	27006	DEPUTE	2003-02-03 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:26	\N
28410	27007	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:26	\N
28411	27008	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:26	\N
28412	27009	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:26	\N
28413	27010	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:26	\N
28414	27011	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:26	\N
28415	27012	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:26	\N
28416	27013	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:26	\N
28417	27014	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:26	\N
28418	27015	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:26	\N
28419	27016	DEPUTE	2002-06-25 00:00:00	\N	2002-06-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:26	\N
28420	27017	VICPDTAN	2006-12-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:26	\N
28421	27018	VICPDTAN	2010-11-16 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:27	\N
28422	27019	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:27	\N
28423	27020	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:27	\N
28424	27021	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:27	\N
28425	27022	DEPUTE	2002-06-19 00:00:00	\N	2003-02-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:27	\N
28426	27023	DEPUTE	2003-06-02 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:27	\N
28427	27024	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:27	\N
28428	27025	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:27	\N
28429	27026	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:27	\N
28430	27027	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:27	\N
28431	27028	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:27	\N
28432	27029	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:27	\N
28433	27030	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:27	\N
28434	27031	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:27	\N
28435	27032	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:27	\N
28436	27033	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:27	\N
28437	27034	DEPUTE	2014-05-03 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:27	\N
28438	27035	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:27	\N
28439	27036	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:27	\N
28440	27037	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:27	\N
28441	27038	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:27	\N
28442	27039	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:27	\N
28443	27040	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:27	\N
28444	27041	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:27	\N
28445	27042	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:27	\N
28446	27043	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:27	\N
28447	27044	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:27	\N
28448	27045	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:27	\N
28449	27046	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:27	\N
28450	27047	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:27	\N
28451	27048	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:27	\N
28452	27049	SECAN	2007-06-27 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:27	\N
28453	27050	SECAN	2012-06-27 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:28	\N
28454	27051	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:28	\N
28455	27052	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:28	\N
28456	27053	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:28	\N
28457	27054	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:28	\N
22487	21092	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:54	\N
28458	27055	DEPUTE	2012-06-20 00:00:00	\N	2013-08-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:28	\N
28459	27056	DEPUTE	2014-05-03 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:28	\N
28460	27057	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:28	\N
28461	27058	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:28	\N
28462	27059	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:28	\N
28463	27060	DEPUTE	2007-06-20 00:00:00	\N	2007-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:28	\N
28464	27061	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:28	\N
28465	27062	DEPUTE	2007-06-20 00:00:00	\N	2011-10-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:28	\N
28466	27063	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:28	\N
28467	27064	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:28	\N
28468	27065	DEPUTE	2002-06-25 00:00:00	\N	2002-06-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:28	\N
28469	27066	DEPUTE	2007-06-26 00:00:00	\N	2011-10-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:28	\N
28470	27067	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:28	\N
28471	27068	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:28	\N
28472	27069	DEPUTE	2012-06-20 00:00:00	\N	2016-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:28	\N
28473	27070	VICPDTAN	2012-06-27 00:00:00	\N	2014-12-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:28	\N
28474	27071	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:28	\N
28475	27072	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:28	\N
28476	27073	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:28	\N
28477	27074	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:28	\N
28478	27075	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:28	\N
28479	27076	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:28	\N
28480	27077	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:28	\N
28481	27078	DEPUTE	2016-03-12 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:28	\N
28482	27079	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:28	\N
28483	27080	DEPUTE	2007-06-26 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:28	\N
28484	27081	DEPUTE	2007-06-20 00:00:00	\N	2009-01-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:28	\N
28485	27082	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:28	\N
28486	27083	DEPUTE	2012-06-20 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:28	\N
28487	27084	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:28	\N
28488	27085	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:28	\N
28489	27086	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:28	\N
30106	28703	DEPUTE	1986-10-01 00:00:00	\N	1986-10-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:04	\N
30107	28704	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:04	\N
30108	28705	DEPUTE	1993-04-02 00:00:00	\N	1994-05-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:04	\N
30109	28706	DEPUTE	1997-06-01 00:00:00	\N	2001-01-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:04	\N
30110	28707	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:04	\N
30111	28708	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:04	\N
30112	28709	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:05	\N
30113	28710	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:05	\N
30114	28711	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:05	\N
30115	28712	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:05	\N
30116	28713	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:05	\N
30117	28714	DEPUTE	1968-07-11 00:00:00	\N	1969-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:05	\N
30118	28715	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:05	\N
30119	28716	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:05	\N
30120	28717	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:05	\N
30121	28718	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:05	\N
30122	28719	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:05	\N
30123	28720	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:05	\N
30124	28721	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:05	\N
30125	28722	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:05	\N
30126	28723	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:05	\N
30127	28724	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:05	\N
30128	28725	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:05	\N
30129	28726	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:05	\N
30130	28727	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:05	\N
30131	28728	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:05	\N
30132	28729	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:05	\N
30133	28730	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:05	\N
30134	28731	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:05	\N
30135	28732	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:05	\N
30136	28733	DEPUTE	1973-05-08 00:00:00	\N	1976-11-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:05	\N
30137	28734	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:05	\N
30138	28735	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:05	\N
30139	28736	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:05	\N
30140	28737	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:05	\N
30141	28738	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:05	\N
30142	28739	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:06	\N
30143	28740	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:06	\N
30144	28741	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:06	\N
30145	28742	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:06	\N
30146	28743	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:06	\N
30147	28744	DEPUTE	1988-06-13 00:00:00	\N	1993-03-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:06	\N
30148	28745	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:06	\N
30149	28746	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:06	\N
30150	28747	DEPUTE	1998-09-27 00:00:00	\N	1999-02-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:06	\N
30151	28748	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:06	\N
30152	28749	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:06	\N
30153	28750	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:06	\N
30154	28751	DEPUTE	1981-07-25 00:00:00	\N	1986-03-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:06	\N
30155	28752	DEPUTE	1981-07-02 00:00:00	\N	1983-01-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:06	\N
30156	28753	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:06	\N
30157	28754	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:06	\N
30158	28755	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:06	\N
30159	28756	DEPUTE	1970-06-14 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:06	\N
30160	28757	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:06	\N
30161	28758	DEPUTE	1981-07-02 00:00:00	\N	1981-12-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:06	\N
30162	28759	DEPUTE	1982-01-18 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:06	\N
30163	28760	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:06	\N
30164	28761	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:06	\N
30165	28762	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:07	\N
30166	28763	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:07	\N
30167	28764	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:07	\N
30168	28765	DEPUTE	1988-06-06 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:07	\N
30169	28766	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:07	\N
30170	28767	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:07	\N
30171	28768	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:07	\N
30172	28769	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:07	\N
30173	28770	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:07	\N
30174	28771	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:07	\N
30175	28772	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:07	\N
30176	28773	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:07	\N
30177	28774	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:07	\N
30178	28775	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:07	\N
30179	28776	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:07	\N
30180	28777	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:07	\N
30181	28778	DEPUTE	1980-10-09 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:07	\N
30182	28779	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:07	\N
30183	28780	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:07	\N
30184	28781	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:08	\N
30185	28782	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:08	\N
30186	28783	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:08	\N
30187	28784	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:08	\N
30188	28785	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:08	\N
30189	28786	DEPUTE	1971-12-05 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:08	\N
30190	28787	DEPUTE	1973-04-02 00:00:00	\N	1977-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:08	\N
30191	28788	DEPUTE	1978-04-03 00:00:00	\N	1978-10-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:08	\N
30192	28789	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:08	\N
30193	28790	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:08	\N
30194	28791	DEPUTE	1992-05-03 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:08	\N
30195	28792	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:08	\N
30196	28793	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:08	\N
30197	28794	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:08	\N
30198	28795	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:08	\N
30663	29260	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:21	\N
30664	29261	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:21	\N
30665	29262	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:21	\N
30666	29263	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:22	\N
30667	29264	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:22	\N
30668	29265	DEPUTE	1998-05-04 00:00:00	\N	1998-07-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:22	\N
30669	29266	DEPUTE	1998-09-27 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:22	\N
30670	29267	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:22	\N
30671	29268	DEPUTE	1986-04-02 00:00:00	\N	1987-10-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:22	\N
30672	29269	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:22	\N
30673	29270	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:22	\N
30674	29271	DEPUTE	1993-04-02 00:00:00	\N	1993-09-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:22	\N
30675	29272	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:22	\N
30676	29273	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:22	\N
30677	29274	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:22	\N
30678	29275	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:22	\N
30679	29276	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:22	\N
30680	29277	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:22	\N
30681	29278	VICPDTAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:22	\N
30682	29279	VICPDTAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:22	\N
30683	29280	VICPDTAN	1998-03-24 00:00:00	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:22	\N
30684	29281	VICPDTAN	1999-02-10 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:22	\N
30685	29282	VICPDTAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:22	\N
30686	29283	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:22	\N
30687	29284	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:22	\N
30688	29285	DEPUTE	1988-06-13 00:00:00	\N	1991-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:22	\N
30689	29286	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:22	\N
30690	29287	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:22	\N
30691	29288	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:22	\N
30692	29289	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:22	\N
30693	29290	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:22	\N
30694	29291	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:22	\N
30695	29292	DEPUTE	1999-03-15 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:22	\N
30696	29293	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:23	\N
30697	29294	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:23	\N
30698	29295	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:23	\N
30699	29296	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:23	\N
30700	29297	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:23	\N
30701	29298	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:23	\N
30702	29299	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:23	\N
30703	29300	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:23	\N
30704	29301	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:23	\N
30705	29302	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:23	\N
30706	29303	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:23	\N
30707	29304	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:23	\N
30708	29305	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:23	\N
30709	29306	DEPUTE	1988-12-19 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:23	\N
30710	29307	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:23	\N
30711	29308	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:23	\N
30712	29309	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:23	\N
30713	29310	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:23	\N
30714	29311	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:23	\N
30715	29312	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:23	\N
30716	29313	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:23	\N
30717	29314	DEPUTE	2017-06-16 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:23	\N
30718	29315	DEPUTE	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:23	\N
30719	29316	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:23	\N
30720	29317	DEPUTE	1993-05-02 00:00:00	\N	1995-07-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:23	\N
30721	29318	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:24	\N
30722	29319	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:24	\N
30723	29320	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:24	\N
30724	29321	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:24	\N
30725	29322	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:24	\N
30726	29323	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:24	\N
30727	29324	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:24	\N
30728	29325	DEPUTE	2007-06-20 00:00:00	\N	2010-06-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:24	\N
30729	29326	QUESTAN	1995-06-01 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:24	\N
30730	29327	QUESTAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:24	\N
30731	29328	QUESTAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:24	\N
30732	29329	QUESTAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:24	\N
30733	29330	QUESTAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:24	\N
30734	29331	QUESTAN	2002-06-26 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:24	\N
30735	29332	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:24	\N
30736	29333	DEPUTE	1993-05-02 00:00:00	\N	1995-05-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:24	\N
30737	29334	DEPUTE	1981-07-02 00:00:00	\N	1981-12-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:24	\N
30738	29335	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:24	\N
30739	29336	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:24	\N
30740	29337	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:24	\N
30741	29338	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:24	\N
30742	29339	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:24	\N
30743	29340	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:24	\N
30744	29341	DEPUTE	1986-04-14 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:24	\N
30745	29342	DEPUTE	1996-03-26 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:24	\N
30746	29343	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:25	\N
30747	29344	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:25	\N
30748	29345	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:25	\N
30749	29346	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:25	\N
30750	29347	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:25	\N
30751	29348	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:25	\N
30752	29349	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:25	\N
30753	29350	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:25	\N
30754	29351	DEPUTE	1981-07-02 00:00:00	\N	1981-07-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:25	\N
30755	29352	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:25	\N
22413	21018	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:49	\N
22414	21019	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:49	\N
22415	21020	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:49	\N
22416	21021	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:49	\N
22417	21022	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:49	\N
22418	21023	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:49	\N
22419	21024	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:49	\N
22420	21025	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:49	\N
22421	21026	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:50	\N
22422	21027	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:50	\N
22423	21028	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:50	\N
22425	21030	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:50	\N
22426	21031	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:50	\N
22427	21032	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:50	\N
22428	21033	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:50	\N
22429	21034	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:50	\N
22430	21035	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:50	\N
22431	21036	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:50	\N
22432	21037	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:50	\N
22433	21038	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:50	\N
22434	21039	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:50	\N
22435	21040	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:50	\N
22436	21041	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:50	\N
22437	21042	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:50	\N
22438	21043	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:50	\N
22439	21044	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:50	\N
22440	21045	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:51	\N
22441	21046	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:51	\N
22442	21047	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:51	\N
22443	21048	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:51	\N
22444	21049	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:51	\N
22445	21050	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:51	\N
22446	21051	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:51	\N
22447	21052	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:51	\N
22448	21053	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:51	\N
22449	21054	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:51	\N
22450	21055	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:51	\N
22451	21056	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:51	\N
22452	21057	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:51	\N
22453	21058	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:51	\N
22454	21059	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:51	\N
22455	21060	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:51	\N
22456	21061	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:51	\N
22457	21062	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:51	\N
22458	21063	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:51	\N
22459	21064	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:52	\N
22460	21065	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:52	\N
22461	21066	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:52	\N
22462	21067	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:52	\N
22463	21068	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:52	\N
22464	21069	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:52	\N
22465	21070	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:52	\N
22466	21071	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:52	\N
22467	21072	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:52	\N
22468	21073	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:52	\N
22469	21074	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:52	\N
22470	21075	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:52	\N
22471	21076	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:52	\N
22472	21077	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:52	\N
22473	21078	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:52	\N
22474	21079	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:53	\N
22475	21080	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:53	\N
22476	21081	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:53	\N
22477	21082	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:53	\N
22478	21083	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:53	\N
22479	21084	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:53	\N
22480	21085	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:53	\N
22481	21086	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:53	\N
22482	21087	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:53	\N
22483	21088	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:53	\N
22484	21089	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:53	\N
22485	21090	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:53	\N
22486	21091	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:54	\N
22488	21093	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:54	\N
22489	21094	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:54	\N
22490	21095	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:54	\N
22491	21096	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:54	\N
22492	21097	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:54	\N
22493	21098	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:54	\N
22494	21099	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:54	\N
22495	21100	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:54	\N
22496	21101	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:54	\N
22497	21102	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:54	\N
22498	21103	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:54	\N
22499	21104	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:55	\N
22500	21105	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:55	\N
22501	21106	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:55	\N
22502	21107	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:55	\N
22503	21108	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:55	\N
22504	21109	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:55	\N
22505	21110	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:55	\N
22506	21111	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:55	\N
22507	21112	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:55	\N
22508	21113	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:55	\N
22509	21114	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:55	\N
22510	21115	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:55	\N
22511	21116	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:55	\N
22512	21117	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:56	\N
22513	21118	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:56	\N
22514	21119	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:56	\N
22515	21120	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-19 09:39:56	\N
28490	27087	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:29	\N
28491	27088	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:29	\N
28492	27089	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:29	\N
28493	27090	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:29	\N
28494	27091	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:29	\N
28495	27092	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:29	\N
28496	27093	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:29	\N
28497	27094	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:29	\N
28498	27095	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:29	\N
28499	27096	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:29	\N
28500	27097	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:29	\N
28501	27098	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:29	\N
28502	27099	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:29	\N
28503	27100	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:29	\N
28504	27101	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:29	\N
28505	27102	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:29	\N
28506	27103	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:29	\N
28507	27104	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:29	\N
28508	27105	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:29	\N
28509	27106	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:29	\N
28510	27107	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:29	\N
28511	27108	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:29	\N
28512	27109	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:29	\N
28513	27110	DEPUTE	2012-06-20 00:00:00	\N	2016-02-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:29	\N
28514	27111	DEPUTE	2007-06-20 00:00:00	\N	2010-11-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:30	\N
28515	27112	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:30	\N
28516	27113	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:30	\N
28517	27114	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:30	\N
28518	27115	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:30	\N
28519	27116	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:30	\N
28520	27117	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:30	\N
28521	27118	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:30	\N
28522	27119	DEPUTE	2007-06-26 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:30	\N
28523	27120	SECAN	2007-06-27 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:30	\N
28524	27121	VICPDTAN	2016-05-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:30	\N
28525	27122	PDTAN	2017-06-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:30	\N
28526	27123	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:30	\N
28527	27124	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:30	\N
28528	27125	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:30	\N
28529	27126	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:30	\N
28530	27127	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:30	\N
28531	27128	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:30	\N
28532	27129	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:30	\N
28533	27130	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:30	\N
28534	27131	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:30	\N
28535	27132	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:30	\N
36235	34832	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:47	\N
28536	27133	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:30	\N
28537	27134	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:30	\N
28538	27135	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:31	\N
28539	27136	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:31	\N
28540	27137	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:31	\N
28541	27138	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:31	\N
28542	27139	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:31	\N
28543	27140	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:31	\N
28544	27141	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:31	\N
28545	27142	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:31	\N
28546	27143	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:31	\N
28547	27144	DEPUTE	2007-06-20 00:00:00	\N	2009-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:31	\N
28548	27145	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:31	\N
28549	27146	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:31	\N
28550	27147	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:31	\N
28551	27148	DEPUTE	2012-06-20 00:00:00	\N	2015-07-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:31	\N
28552	27149	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:31	\N
28553	27150	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:31	\N
28554	27151	DEPUTE	2008-03-07 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:31	\N
28555	27152	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:31	\N
28556	27153	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:31	\N
28557	27154	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:31	\N
28558	27155	DEPUTE	2012-07-22 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:31	\N
28559	27156	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:31	\N
28560	27157	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:31	\N
28561	27158	DEPUTE	2010-06-07 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:31	\N
28562	27159	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:31	\N
28563	27160	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:31	\N
28564	27161	DEPUTE	2012-07-22 00:00:00	\N	2014-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:31	\N
28565	27162	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:32	\N
28566	27163	DEPUTE	2014-09-27 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:32	\N
28567	27164	DEPUTE	2017-03-22 00:00:00	\N	2017-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:32	\N
28568	27165	DEPUTE	2010-12-15 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:32	\N
28569	27166	DEPUTE	2009-11-04 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:32	\N
28570	27167	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:32	\N
28571	27168	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:32	\N
28572	27169	DEPUTE	2012-07-22 00:00:00	\N	2013-04-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:32	\N
28573	27170	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:32	\N
28574	27171	DEPUTE	2007-07-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:32	\N
28575	27172	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:32	\N
28576	27173	DEPUTE	2008-04-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:32	\N
28577	27174	DEPUTE	2014-05-10 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:32	\N
28578	27175	DEPUTE	2011-05-05 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:32	\N
28579	27176	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:32	\N
28580	27177	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:32	\N
28581	27178	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:32	\N
28582	27179	DEPUTE	2008-11-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:32	\N
28583	27180	DEPUTE	2012-06-20 00:00:00	\N	2016-04-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 09:42:32	\N
22541	21138	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-27 03:44:47	\N
30199	28796	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:08	\N
30200	28797	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:08	\N
30201	28798	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:08	\N
30202	28799	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:08	\N
30203	28800	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:08	\N
30204	28801	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:08	\N
30205	28802	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:08	\N
30206	28803	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:08	\N
30207	28804	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:08	\N
30208	28805	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:08	\N
30209	28806	DEPUTE	1993-05-02 00:00:00	\N	1995-09-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:08	\N
30210	28807	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:08	\N
30211	28808	DEPUTE	1993-05-02 00:00:00	\N	1995-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:08	\N
30212	28809	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:08	\N
30213	28810	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:08	\N
30214	28811	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:08	\N
30215	28812	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:08	\N
30216	28813	DEPUTE	1995-09-18 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:08	\N
30217	28814	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:08	\N
30218	28815	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:08	\N
30219	28816	DEPUTE	2007-06-20 00:00:00	\N	2012-03-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:08	\N
30220	28817	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:09	\N
30221	28818	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:09	\N
30222	28819	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:09	\N
30223	28820	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:09	\N
30224	28821	DEPUTE	1976-04-09 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:09	\N
30225	28822	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:09	\N
30226	28823	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:09	\N
30227	28824	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:09	\N
30228	28825	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:09	\N
30229	28826	DEPUTE	1981-07-02 00:00:00	\N	1984-08-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:09	\N
30230	28827	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:09	\N
30231	28828	DEPUTE	1988-06-06 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:09	\N
30232	28829	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:09	\N
30233	28830	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:09	\N
30234	28831	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:09	\N
30235	28832	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:09	\N
30236	28833	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:09	\N
30237	28834	DEPUTE	1997-06-01 00:00:00	\N	1999-12-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:09	\N
30238	28835	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:09	\N
30239	28836	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:09	\N
30240	28837	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:09	\N
30241	28838	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:09	\N
30242	28839	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:09	\N
30243	28840	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:09	\N
30244	28841	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:09	\N
30245	28842	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:09	\N
30246	28843	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:09	\N
30247	28844	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:09	\N
30248	28845	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:09	\N
30249	28846	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:09	\N
30250	28847	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:09	\N
30251	28848	DEPUTE	2007-07-20 00:00:00	\N	2010-12-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:09	\N
30252	28849	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:09	\N
30253	28850	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:09	\N
30254	28851	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:09	\N
30255	28852	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:09	\N
30256	28853	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:09	\N
30257	28854	DEPUTE	1978-04-03 00:00:00	\N	1978-05-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:09	\N
30258	28855	DEPUTE	1967-05-08 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:09	\N
30259	28856	DEPUTE	1969-07-23 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:09	\N
30260	28857	DEPUTE	1973-04-02 00:00:00	\N	1977-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:09	\N
30261	28858	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:09	\N
30262	28859	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:09	\N
30263	28860	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:09	\N
30264	28861	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:09	\N
30265	28862	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:09	\N
30266	28863	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:10	\N
30267	28864	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:10	\N
30268	28865	DEPUTE	1995-06-09 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:10	\N
30269	28866	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:10	\N
30270	28867	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:10	\N
30271	28868	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:10	\N
30272	28869	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:10	\N
30273	28870	DEPUTE	2004-12-07 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:10	\N
30274	28871	DEPUTE	2007-06-20 00:00:00	\N	2009-04-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:10	\N
30275	28872	DEPUTE	1983-04-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:10	\N
30276	28873	DEPUTE	1976-11-14 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:10	\N
30277	28874	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:10	\N
30278	28875	DEPUTE	1967-04-03 00:00:00	\N	1967-05-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:10	\N
30279	28876	DEPUTE	1968-07-11 00:00:00	\N	1968-08-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:10	\N
30280	28877	DEPUTE	1973-04-02 00:00:00	\N	1973-05-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:10	\N
30281	28878	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:10	\N
30282	28879	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:10	\N
30283	28880	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:10	\N
30284	28881	DEPUTE	1993-04-02 00:00:00	\N	1995-05-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:10	\N
30285	28882	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:10	\N
30286	28883	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:10	\N
30287	28884	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:10	\N
30288	28885	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:10	\N
30289	28886	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:10	\N
30290	28887	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:30:10	\N
51101	50384	MAIREADJOINT	2014-04-05 00:00:00	\N	2017-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 17:04:10	2017-11-09 09:46:07
51125	50387	MAIRE	1995-06-18 00:00:00	\N	2014-04-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 17:18:54	2017-09-24 17:23:46
51125	50388	MAIREADJOINT	1977-03-20 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 17:21:48	2017-09-24 17:23:46
51125	50393	CONSMUNI	2014-04-06 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-24 17:23:49	2017-09-24 17:24:10
51149	50403	MAIRE	1989-03-20 00:00:00	\N	2017-10-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 17:34:07	2018-01-25 11:48:59
51149	50414	MAIREADJOINT	1977-03-13 00:00:00	\N	1989-03-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-09-24 17:42:17	2017-09-24 17:43:10
51149	50412	CONSMUNI	1971-03-21 00:00:00	\N	1977-03-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-09-24 17:41:17	2017-09-24 17:42:13
51197	50428	CONSREG	2010-03-21 00:00:00	\N	2017-10-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-09-24 17:55:21	2018-05-30 09:51:13
50866	50424	CONSDPT	2017-04-18 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2017-09-24 17:49:21	2017-09-24 17:49:42
51199	50430	MAIREADJOINT	2014-03-30 00:00:00	\N	2017-10-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-09-24 17:56:45	2018-05-30 09:51:49
51352	50536	PDTGEN	2011-03-31 00:00:00	\N	2014-09-22 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-09-24 20:51:07	2017-09-24 20:51:43
51390	50571	PDTINTCOM	2014-03-23 00:00:00	\N	2017-11-09 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-09-25 17:44:35	2018-01-12 14:58:30
51165	50572	MAIREADJOINT	\N	1983	2001-03-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-25 17:49:20	2017-09-25 17:49:43
50999	50570	CONSMUNI	1995-03-19 00:00:00	\N	2014-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-25 17:39:43	2017-09-25 17:40:06
50934	50573	MAIREADJOINT	2014-03-16 00:00:00	\N	2016-01-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-25 17:52:00	2017-09-25 17:52:29
51391	50574	CONSMUNI	2001-03-18 00:00:00	\N	2008-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-25 17:52:39	2017-09-25 17:53:31
51392	50575	CONSMUNI	1995-03-19 00:00:00	\N	2001-03-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-25 17:53:44	2017-09-25 17:54:38
50943	50605	CONSMUNI	1995-06-18 00:00:00	\N	2016-12-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-26 17:35:18	2017-09-26 17:35:55
50877	50606	CONSMUNI	2008-03-16 00:00:00	\N	2014-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-26 17:38:27	2017-09-26 17:39:28
51413	50607	CONSINTCOM	2008-03-23 00:00:00	\N	2014-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-09-26 17:39:49	2017-09-26 17:41:04
51414	50608	VICPDTINTCOM	2001-03-18 00:00:00	\N	2015-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-09-26 17:41:05	2017-09-26 17:43:09
51415	50609	VICPDTINTCOM	2017-01-01 00:00:00	\N	2017-10-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-26 17:46:17	2018-05-30 09:25:46
51416	50610	CONSGENE	2008-03-16 00:00:00	\N	2015-03-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-26 17:49:49	2017-09-26 17:50:45
51417	50611	MAIRE	2012-06-23 00:00:00	\N	2015-12-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-26 17:52:02	2017-09-26 17:52:39
51418	50612	VICPDTINTCOM	2012-06-23 00:00:00	\N	2015-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-09-26 17:53:15	2017-09-26 17:54:16
51419	50613	VICPDTREG	2010-03-21 00:00:00	\N	2015-12-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-26 17:55:51	2017-09-26 17:58:53
51327	50614	CONSMUNI	1989-03-19 00:00:00	\N	1999-11-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-26 17:58:25	2017-09-26 18:01:34
51420	50615	VICPDTINTCOM	2014-01-01 00:00:00	\N	2017-10-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-09-26 18:03:20	2017-11-06 12:01:49
50837	50618	MAIRE	1983-03-13 00:00:00	\N	2014-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-26 18:10:10	2017-09-26 18:10:27
50861	50617	CONSMUNI	2008-03-16 00:00:00	\N	2014-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-26 18:06:53	2017-09-26 18:07:06
51421	50619	PDTINTCOM	2004-01-01 00:00:00	\N	2016-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-09-26 18:11:28	2017-09-26 18:12:14
51422	50620	VICPDTINTCOM	2017-01-01 00:00:00	\N	2018-01-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-09-26 18:11:31	2018-01-02 10:56:44
51423	50621	PDTINTCOM	1995-12-29 00:00:00	\N	2016-12-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-09-26 18:19:55	2017-09-26 18:23:30
51424	50622	CONSMET	2015-01-02 00:00:00	\N	2020-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-09-27 10:13:18	2017-09-27 10:14:27
51425	50623	VICPDTINTCOM	2017-01-01 00:00:00	\N	2017-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-09-27 10:17:46	2018-02-19 16:53:04
51426	50624	VICPDTINTCOM	2014-03-23 00:00:00	\N	2017-10-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-09-27 10:19:38	2018-05-30 16:21:08
51427	50625	VICPDTINTCOM	2008-03-16 00:00:00	\N	2014-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-09-27 10:20:03	2017-09-27 10:21:07
51427	50626	PDTINTCOM	2014-03-30 00:00:00	\N	2016-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-09-27 10:20:45	2017-09-27 10:21:28
51430	50629	VICPDTINTCOM	2017-01-01 00:00:00	\N	2017-10-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-09-27 10:27:25	2017-11-20 11:47:34
51429	50628	CONSREG	2010-03-21 00:00:00	\N	2015-12-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-27 10:21:32	2017-09-27 10:22:04
51431	50630	VICPDTINTCOM	2014-03-30 00:00:00	\N	2016-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-09-27 10:31:30	2017-09-27 10:33:55
51077	50631	VICPDTINTCOM	2014-04-29 00:00:00	\N	2016-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-09-27 10:49:42	2017-11-13 18:34:35
51432	50632	CONSCOMINT	2015-01-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	2017-09-27 10:59:26	2017-09-27 10:59:58
51433	50633	VICPDTMET	2016-01-22 00:00:00	\N	2017-10-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-27 11:11:39	2018-02-09 10:00:44
51434	50634	VICPDTINTCOM	2004-01-01 00:00:00	\N	2017-10-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-27 11:14:03	2017-12-06 14:24:57
51435	50635	CONSCOMINT	2014-01-01 00:00:00	\N	2020-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-09-27 11:29:02	2017-09-27 11:29:45
51436	50636	PDTINTCOM	1997-01-01 00:00:00	\N	2013-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-09-27 11:29:04	2017-09-27 11:30:40
51437	50637	CONSGENE	1988-02-02 00:00:00	\N	2001-03-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-27 11:31:26	2017-09-27 11:33:12
50895	50638	CONSREG	2015-12-13 00:00:00	\N	2020-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-27 11:35:01	2017-09-27 11:35:37
51438	50639	CONSCOMINT	2014-01-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	2017-09-27 11:55:33	2017-09-27 11:56:06
50921	50640	CONSMUNI	2001-03-18 00:00:00	\N	2008-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-27 14:31:55	2017-09-27 14:32:17
51439	50641	VICPDTINTCOM	2008-03-16 00:00:00	\N	2014-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-09-27 14:33:39	2017-09-27 14:34:29
15143	50642	CONSDPT	2017-09-16 00:00:00	\N	2017-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-27 14:38:18	2017-09-27 14:38:48
51440	50643	MAIREADJOINT	2014-03-30 00:00:00	\N	2017-10-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-27 14:53:16	2017-11-20 14:36:28
51441	50644	CONSCOMINT	2014-03-30 00:00:00	\N	2017-10-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-09-27 14:53:58	2017-11-20 14:37:20
50842	50645	CONSMUNI	2001-03-18 00:00:00	\N	2014-03-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-27 15:26:33	2017-09-27 15:26:52
51442	50646	CONSCOMINT	2014-03-30 00:00:00	\N	2015-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-09-27 15:38:19	2017-09-27 15:39:24
51443	50647	CONSINTCOM	2016-01-01 00:00:00	\N	\N	\N	ACTIF	\N	Conseiller territorial	\N	\N	2017-09-27 15:42:25	2017-09-27 15:43:11
15172	50649	CONSDPT	2016-01-24 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-27 16:52:42	2017-09-27 16:52:51
51445	50650	VICPDTINTCOM	2014-03-30 00:00:00	\N	2017-10-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-09-27 17:25:29	2017-11-10 10:35:29
51000	50653	CONSREG	2010-03-21 00:00:00	\N	2015-12-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-28 11:13:59	2017-09-28 11:14:29
51449	50654	VICPDTINTCOM	2015-12-14 00:00:00	\N	2017-12-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-09-28 11:15:17	2018-01-08 17:38:39
51450	50657	VICPDTGEN	2004-03-28 00:00:00	\N	2011-03-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-28 11:30:14	2017-09-28 11:31:51
51450	50656	VICPDTGEN	1992-03-29 00:00:00	\N	1998-03-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-28 11:29:33	2017-09-28 11:31:14
51374	50658	PREMADJOINT	2008-03-16 00:00:00	\N	2014-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-28 11:39:23	2017-09-28 11:40:26
51263	50659	MAIREADJOINT	2001-03-18 00:00:00	\N	2008-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-28 12:12:46	2018-04-03 11:41:00
50972	50660	CONSMUNI	2008-03-16 00:00:00	\N	2014-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-28 16:03:07	2017-09-28 16:03:42
50998	50661	CONSREG	1998-03-15 00:00:00	\N	2015-12-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-28 17:42:28	2017-09-28 17:42:56
51451	50662	CONSCOMINT	2014-03-23 00:00:00	\N	2021-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-09-29 10:02:25	2017-11-16 18:52:39
50948	50663	CONSMUNI	2014-03-23 00:00:00	\N	2020-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-09-29 10:45:47	2017-09-29 10:46:02
51454	50664	MAIREADJOINT	2008-03-16 00:00:00	\N	2017-10-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-10-01 09:27:56	2017-12-14 09:55:16
51455	50665	CONSREG	2015-12-13 00:00:00	\N	2017-10-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-10-01 09:29:45	2017-12-14 09:55:45
34098	32695	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:22	\N
34099	32696	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:22	\N
34100	32697	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:22	\N
34101	32698	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:22	\N
34102	32699	SECAN	2002-06-26 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:22	\N
34103	32700	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:22	\N
34104	32701	DEPUTE	1981-07-24 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:22	\N
34105	32702	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:22	\N
34106	32703	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:22	\N
34107	32704	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:22	\N
34108	32705	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:22	\N
34109	32706	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:22	\N
34110	32707	DEPUTE	1981-07-02 00:00:00	\N	1983-11-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:22	\N
34111	32708	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:22	\N
34112	32709	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:22	\N
34113	32710	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:22	\N
34114	32711	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:22	\N
34115	32712	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:22	\N
34116	32713	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:22	\N
34117	32714	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:22	\N
34118	32715	DEPUTE	1986-04-02 00:00:00	\N	1986-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:22	\N
34119	32716	DEPUTE	1973-05-06 00:00:00	\N	1974-07-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:23	\N
34120	32717	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:23	\N
34121	32718	DEPUTE	2001-10-04 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:23	\N
34122	32719	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:23	\N
34123	32720	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:23	\N
34124	32721	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:23	\N
34125	32722	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:23	\N
34126	32723	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:23	\N
34127	32724	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:23	\N
34128	32725	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:23	\N
34129	32726	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:23	\N
34130	32727	DEPUTE	1993-04-02 00:00:00	\N	1993-11-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:23	\N
34131	32728	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:23	\N
34132	32729	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:23	\N
34133	32730	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:23	\N
34134	32731	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:23	\N
34135	32732	DEPUTE	1984-09-10 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:23	\N
34136	32733	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:23	\N
34137	32734	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:23	\N
34138	32735	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:24	\N
34139	32736	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:24	\N
34140	32737	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:24	\N
34141	32738	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:24	\N
34142	32739	DEPUTE	2007-06-20 00:00:00	\N	2011-12-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:24	\N
34143	32740	DEPUTE	2000-11-19 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:24	\N
36236	34833	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:47	\N
34144	32741	DEPUTE	1991-06-18 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:24	\N
34145	32742	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:24	\N
34146	32743	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:24	\N
34147	32744	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:24	\N
34148	32745	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:24	\N
34149	32746	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:24	\N
34150	32747	SECAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:24	\N
34151	32748	VICPDTAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:24	\N
34152	32749	VICPDTAN	1994-04-02 00:00:00	\N	1995-06-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:24	\N
34153	32750	VICPDTAN	1997-06-13 00:00:00	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:24	\N
34154	32751	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:24	\N
34155	32752	DEPUTE	1998-11-21 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:24	\N
34156	32753	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:24	\N
34157	32754	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:24	\N
34158	32755	DEPUTE	1969-10-26 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:24	\N
34159	32756	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:24	\N
34160	32757	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:24	\N
34161	32758	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:24	\N
34162	32759	DEPUTE	1988-06-13 00:00:00	\N	1988-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:24	\N
34163	32760	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:24	\N
34164	32761	DEPUTE	1962-12-06 00:00:00	\N	1963-03-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:24	\N
34165	32762	DEPUTE	1963-05-12 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:24	\N
34166	32763	DEPUTE	1967-04-03 00:00:00	\N	1967-07-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:24	\N
34167	32764	DEPUTE	1967-08-27 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:24	\N
34168	32765	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:24	\N
34169	32766	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:24	\N
34170	32767	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:24	\N
34171	32768	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:24	\N
34172	32769	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:24	\N
34173	32770	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:24	\N
34174	32771	DEPUTE	1997-06-01 00:00:00	\N	1998-04-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:25	\N
34175	32772	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:25	\N
34176	32773	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:25	\N
34177	32774	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:25	\N
34178	32775	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:25	\N
34179	32776	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:25	\N
34180	32777	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:25	\N
34181	32778	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:25	\N
34182	32779	SECAN	2002-06-26 00:00:00	\N	2006-11-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:25	\N
34183	32780	SECAN	2013-10-01 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:25	\N
34184	32781	DEPUTE	1984-04-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:25	\N
34185	32782	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:25	\N
34186	32783	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:25	\N
34187	32784	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:25	\N
34188	32785	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:25	\N
34189	32786	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:25	\N
34190	32787	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:25	\N
35588	34185	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:17	\N
35589	34186	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:17	\N
35590	34187	DEPUTE	2008-03-07 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:17	\N
35591	34188	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:17	\N
35592	34189	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:17	\N
35593	34190	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:17	\N
35594	34191	DEPUTE	2012-07-22 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:17	\N
35595	34192	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:17	\N
35596	34193	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:17	\N
35597	34194	DEPUTE	2010-06-07 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:17	\N
35598	34195	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:17	\N
35599	34196	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:17	\N
35600	34197	DEPUTE	2012-07-22 00:00:00	\N	2014-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:17	\N
35601	34198	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:17	\N
35602	34199	DEPUTE	2014-09-27 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:17	\N
35603	34200	DEPUTE	2017-03-22 00:00:00	\N	2017-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:17	\N
35604	34201	DEPUTE	2010-12-15 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:17	\N
35605	34202	DEPUTE	2009-11-04 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:17	\N
35606	34203	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:18	\N
35607	34204	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:18	\N
35608	34205	DEPUTE	2012-07-22 00:00:00	\N	2013-04-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:18	\N
35609	34206	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:18	\N
35610	34207	DEPUTE	2007-07-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:18	\N
35611	34208	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:18	\N
35612	34209	DEPUTE	2008-04-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:18	\N
35613	34210	DEPUTE	2014-05-10 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:18	\N
35614	34211	DEPUTE	2011-05-05 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:18	\N
35615	34212	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:18	\N
35616	34213	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:18	\N
35617	34214	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:18	\N
35618	34215	DEPUTE	2008-11-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:18	\N
35619	34216	DEPUTE	2012-06-20 00:00:00	\N	2016-04-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:18	\N
35620	34217	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:18	\N
35621	34218	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:18	\N
35622	34219	DEPUTE	2011-05-03 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:18	\N
35623	34220	DEPUTE	2010-04-01 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:18	\N
35624	34221	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:18	\N
35625	34222	DEPUTE	2016-05-30 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:18	\N
35626	34223	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:18	\N
35627	34224	DEPUTE	2008-06-02 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:18	\N
35628	34225	DEPUTE	2012-03-23 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:18	\N
35629	34226	DEPUTE	2012-06-20 00:00:00	\N	2017-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:18	\N
35630	34227	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:18	\N
35631	34228	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:18	\N
35632	34229	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:18	\N
35633	34230	DEPUTE	2008-04-20 00:00:00	\N	2009-07-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:18	\N
35634	34231	DEPUTE	2009-01-13 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:18	\N
35635	34232	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:18	\N
35636	34233	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:18	\N
35637	34234	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:19	\N
35638	34235	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:19	\N
35639	34236	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:19	\N
35640	34237	DEPUTE	2008-12-15 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:19	\N
35641	34238	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:19	\N
35642	34239	DEPUTE	2008-02-04 00:00:00	\N	2008-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:19	\N
35643	34240	DEPUTE	2007-12-16 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:19	\N
35644	34241	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:19	\N
35645	34242	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:19	\N
35646	34243	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:19	\N
35647	34244	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:19	\N
35648	34245	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:19	\N
35649	34246	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:19	\N
35650	34247	DEPUTE	2014-05-03 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:19	\N
35651	34248	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:19	\N
35652	34249	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:19	\N
35653	34250	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:19	\N
35654	34251	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:19	\N
35655	34252	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:19	\N
35656	34253	DEPUTE	2008-04-13 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:19	\N
35657	34254	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:19	\N
35658	34255	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:19	\N
35659	34256	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:19	\N
35660	34257	DEPUTE	2009-10-19 00:00:00	\N	2011-07-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:19	\N
35661	34258	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:19	\N
35662	34259	DEPUTE	2011-07-30 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:19	\N
35663	34260	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:19	\N
35664	34261	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:19	\N
35665	34262	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:19	\N
35666	34263	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:19	\N
35667	34264	DEPUTE	2010-07-12 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:19	\N
35668	34265	DEPUTE	2016-03-21 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:19	\N
35669	34266	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:19	\N
35670	34267	DEPUTE	2016-03-21 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:19	\N
35671	34268	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:20	\N
35672	34269	DEPUTE	2016-03-21 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:20	\N
35673	34270	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:20	\N
35674	34271	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:20	\N
35675	34272	DEPUTE	1968-07-11 00:00:00	\N	1968-08-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:20	\N
35676	34273	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:20	\N
35677	34274	DEPUTE	2014-05-03 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:20	\N
35678	34275	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:20	\N
35679	34276	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:20	\N
35680	34277	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:20	\N
35681	34278	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:20	\N
36237	34834	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:47	\N
44779	49438	VICPDTAN	1999-02-10 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:42	\N
44778	49439	DEPUTE	1993-04-02 00:00:00	\N	1993-04-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:42	\N
44778	49440	VICPDTAN	1993-04-07 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:42	\N
44826	49441	DEPUTE	1997-06-01 00:00:00	\N	1997-06-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:43	\N
44826	49442	QUESTAN	1997-06-13 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:43	\N
44824	49443	DEPUTE	1993-04-02 00:00:00	\N	1995-06-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:43	\N
44824	49444	QUESTAN	1995-06-01 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:43	\N
44825	49445	DEPUTE	2002-06-19 00:00:00	\N	2002-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:43	\N
44825	49446	QUESTAN	2002-06-26 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:43	\N
44876	49447	DEPUTE	2002-06-19 00:00:00	\N	2002-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:44	\N
44876	49448	VICPDTAN	2002-06-26 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:44	\N
44879	49449	DEPUTE	2007-06-20 00:00:00	\N	2007-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:44	\N
44879	49450	VICPDTAN	2007-06-27 00:00:00	\N	2008-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:44	\N
44879	49451	DEPUTE	2008-09-27 00:00:00	\N	2010-04-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:44	\N
44915	49452	DEPUTE	2002-06-19 00:00:00	\N	2002-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:45	\N
44915	49453	PDTAN	2002-06-26 00:00:00	\N	2007-03-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:45	\N
44933	49454	DEPUTE	2002-06-19 00:00:00	\N	2004-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:45	\N
44933	49455	SECAN	2004-10-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:45	\N
45062	49456	DEPUTE	1993-04-02 00:00:00	\N	1993-04-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:47	\N
45062	49457	SECAN	1993-04-07 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:47	\N
45074	49458	DEPUTE	1997-06-01 00:00:00	\N	1997-06-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:48	\N
45074	49459	QUESTAN	1997-06-13 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:48	\N
45074	49460	DEPUTE	1999-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:48	\N
45072	49461	DEPUTE	1993-04-02 00:00:00	\N	1993-04-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:48	\N
45072	49462	QUESTAN	1993-04-07 00:00:00	\N	1995-04-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:48	\N
45072	49463	DEPUTE	1995-04-04 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:48	\N
45082	49464	DEPUTE	2007-06-20 00:00:00	\N	2007-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:48	\N
45082	49465	SECAN	2007-06-27 00:00:00	\N	2010-10-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:48	\N
45082	49466	DEPUTE	2010-10-06 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:48	\N
45154	49467	DEPUTE	2012-06-20 00:00:00	\N	2012-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:49	\N
45154	49468	SECAN	2012-06-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:49	\N
45180	49469	DEPUTE	1997-06-01 00:00:00	\N	1997-06-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:50	\N
45180	49470	SECAN	1997-06-13 00:00:00	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:50	\N
45180	49471	DEPUTE	1998-10-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:50	\N
45191	49472	DEPUTE	1993-04-02 00:00:00	\N	1995-04-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:51	\N
45191	49473	SECAN	1995-04-03 00:00:00	\N	1996-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:51	\N
45191	49474	DEPUTE	1996-10-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:51	\N
50748	49475	SECAN	1985-04-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:51	\N
50748	49476	DEPUTE	1986-04-02 00:00:00	\N	1986-04-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:51	\N
50748	49477	SECAN	1986-04-04 00:00:00	\N	1987-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:51	\N
50748	49478	DEPUTE	1987-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:51	\N
45240	49479	DEPUTE	1986-04-02 00:00:00	\N	1986-04-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:52	\N
45240	49480	SECAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:52	\N
45263	49481	DEPUTE	2007-06-20 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:52	\N
45263	49482	SECAN	2008-10-01 00:00:00	\N	2009-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:52	\N
45263	49483	VICPDTAN	2009-10-07 00:00:00	\N	2010-10-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:52	\N
45263	49484	SECAN	2010-10-06 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:52	\N
45280	49485	DEPUTE	2002-06-19 00:00:00	\N	2005-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:52	\N
45280	49486	SECAN	2005-10-04 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:52	\N
45281	49487	DEPUTE	2007-06-20 00:00:00	\N	2007-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:52	\N
45281	49488	SECAN	2007-06-27 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:52	\N
45281	49489	DEPUTE	2008-10-02 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:52	\N
50749	49490	VICPDTAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:52	\N
50749	49491	DEPUTE	1993-04-02 00:00:00	\N	1993-04-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:52	\N
50749	49492	VICPDTAN	1993-04-07 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:52	\N
45316	49493	DEPUTE	1997-06-01 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:53	\N
45316	49494	QUESTAN	1998-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:53	\N
45316	49495	DEPUTE	2000-10-03 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:53	\N
45369	49496	DEPUTE	2007-06-20 00:00:00	\N	2010-10-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:54	\N
45369	49497	VICPDTAN	2010-10-05 00:00:00	\N	2011-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:54	\N
45369	49498	DEPUTE	2011-10-03 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:54	\N
45383	49499	DEPUTE	2002-06-19 00:00:00	\N	2002-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:54	\N
45383	49500	VICPDTAN	2002-06-26 00:00:00	\N	2003-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:54	\N
45383	49501	DEPUTE	2003-10-01 00:00:00	\N	2004-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:54	\N
45383	49502	VICPDTAN	2004-10-01 00:00:00	\N	2005-12-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:54	\N
45383	49503	DEPUTE	2006-01-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:54	\N
45394	49504	DEPUTE	2012-06-20 00:00:00	\N	2015-01-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:54	\N
45394	49505	VICPDTAN	2015-01-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:54	\N
50750	49506	VICPDTAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:55	\N
50750	49507	DEPUTE	1993-04-02 00:00:00	\N	1994-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:55	\N
50750	49508	VICPDTAN	1994-04-02 00:00:00	\N	1995-04-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:55	\N
50750	49509	DEPUTE	1995-04-04 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:55	\N
50751	49510	SECAN	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:55	\N
50751	49511	DEPUTE	1986-04-02 00:00:00	\N	1987-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:55	\N
50751	49512	SECAN	1987-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:55	\N
45513	49513	DEPUTE	1997-06-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:00	\N
45513	49514	VICPDTAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:00	\N
45513	49515	DEPUTE	2000-10-03 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:00	\N
45535	49516	DEPUTE	1988-06-06 00:00:00	\N	1992-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:00	\N
45535	49517	SECAN	1992-04-02 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:00	\N
45534	49518	DEPUTE	1986-04-02 00:00:00	\N	1986-04-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:00	\N
45534	49519	QUESTAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:00	\N
45543	49520	DEPUTE	1997-06-01 00:00:00	\N	1997-06-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:00	\N
45543	49521	SECAN	1997-06-13 00:00:00	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:00	\N
45543	49522	DEPUTE	1998-10-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:00	\N
45547	49523	DEPUTE	2007-06-20 00:00:00	\N	2007-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:00	\N
45547	49524	VICPDTAN	2007-06-27 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:00	\N
45547	49525	DEPUTE	2008-10-02 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:00	\N
45565	49526	DEPUTE	2007-06-20 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:00	\N
45565	49527	SECAN	2008-10-01 00:00:00	\N	2010-10-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:00	\N
45565	49528	DEPUTE	2010-10-06 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:00	\N
45606	49529	DEPUTE	1997-06-01 00:00:00	\N	1997-06-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:01	\N
50837	50135	PREMADJOINT	2014-03-30 00:00:00	\N	2018-01-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-19 17:09:09	2018-01-02 10:59:44
50844	50142	MAIREADJOINT	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	2017-09-19 17:27:40	2017-09-19 17:30:33
50839	50137	PDTDPT	2015-03-29 00:00:00	\N	2017-10-23 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-09-19 17:12:08	2017-12-04 18:36:27
50852	50150	MAIRE	1989-03-19 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	2017-09-19 17:37:46	2017-09-19 17:39:44
50849	50147	CONSDPT	2015-03-29 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	2017-09-19 17:31:15	2017-09-19 17:34:11
50859	50158	CONSMUNI	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2017-09-19 17:54:58	2017-09-19 17:57:26
50857	50155	CONSREG	2015-12-13 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	2017-09-19 17:52:00	2017-09-19 17:52:53
50863	50162	MAIRE	2005-06-26 00:00:00	\N	2017-10-24 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-09-19 18:06:53	2017-11-09 17:53:49
50866	50165	VICPDTDPT	2011-03-27 00:00:00	\N	2017-04-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-09-19 18:13:05	2017-09-26 10:04:11
50872	50171	MAIRE	2008-03-16 00:00:00	\N	2017-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-19 18:40:34	2018-02-19 16:52:16
50873	50172	MAIRE	1989-03-19 00:00:00	\N	2008-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-19 18:43:03	2017-09-19 18:44:08
50874	50173	PDTDPT	2015-03-30 00:00:00	\N	2017-10-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-19 18:44:26	2017-11-09 16:00:06
50875	50174	CONSGENE	1992-03-22 00:00:00	\N	1993-12-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-19 18:44:27	2017-09-24 19:45:43
50875	50175	PDTGEN	2008-03-20 00:00:00	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-19 18:46:00	2017-09-20 10:07:42
50995	50304	CONSMUNI	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-22 09:51:09	2017-09-22 09:51:45
51009	50317	MAIRE	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-22 11:01:41	2017-09-22 11:03:26
51010	50319	MAIRE	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-22 11:04:00	2017-09-22 11:04:58
51012	50321	VICPDTDPT	2015-12-13 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-22 11:05:02	2017-09-22 11:06:22
51015	50324	CONSMUNI	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-22 11:07:03	2017-09-22 11:07:51
51023	50332	MAIREADJOINT	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-22 11:42:22	2017-09-22 15:43:14
51025	50334	CONSMUNI	2017-09-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-22 11:43:49	\N
51026	50335	CONSMUNI	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-22 11:45:13	2017-09-22 11:45:51
51027	50336	MAIRE	2002-07-03 00:00:00	\N	2017-10-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-22 11:46:28	2018-02-09 10:01:16
51028	50337	CONSMUNI	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-22 11:48:49	2017-09-22 11:49:56
51457	50666	PREMADJOINT	1983-09-13 00:00:00	\N	1993-09-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-10-01 09:45:52	2017-11-21 18:27:40
51457	50667	MAIRE	1993-09-13 00:00:00	\N	2017-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-10-01 09:46:56	2017-11-21 18:27:27
51458	50668	CONSGENE	1985-03-17 00:00:00	\N	1998-03-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-10-01 09:47:47	2017-10-01 09:50:06
52358	51871	CONSMUNI	1995-03-15 00:00:00	\N	2001-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51460	50670	CONSREG	1985-03-17 00:00:00	\N	1993-09-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-10-01 09:52:21	2017-10-01 09:53:04
51463	50672	MAIREADJOINT	2014-03-30 00:00:00	\N	2017-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-10-01 10:08:19	2017-10-02 10:41:37
51465	50673	MAIRE	2008-03-16 00:00:00	\N	2017-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-10-01 10:45:40	2017-11-15 10:00:04
51466	50674	CONSREG	2015-12-13 00:00:00	\N	2021-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-10-01 10:47:19	2017-10-01 10:47:59
51467	50675	VICPDTINTCOM	2014-01-01 00:00:00	\N	2017-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-10-01 10:48:48	2017-11-15 10:01:18
51469	50676	PREMADJOINT	2014-03-30 00:00:00	\N	2017-10-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-10-01 10:55:00	2018-04-18 15:13:00
51470	50677	CONSGENE	2012-06-21 00:00:00	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-10-01 10:56:32	2017-10-01 10:58:26
51471	50678	CONSDPT	2015-03-30 00:00:00	\N	2017-10-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-10-01 10:58:31	2018-04-18 15:14:26
34214	32811	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:26	\N
51473	50679	MAIRE	1995-06-18 00:00:00	\N	2017-10-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-10-01 11:03:42	2017-12-12 17:13:01
51474	50680	CONSGENE	1999-01-31 00:00:00	\N	2004-04-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-10-01 11:05:16	2017-10-01 11:06:57
51475	50681	CONSDPT	2015-03-29 00:00:00	\N	2017-11-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-10-01 11:07:02	2017-12-12 17:15:13
51474	50682	CONSGENE	2017-10-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-10-01 11:08:31	\N
51477	50683	CONSMUNI	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-10-01 11:28:25	2017-10-01 11:30:20
51479	50684	CONSDPT	2015-03-29 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-10-01 11:35:30	2017-10-01 11:37:52
51481	50685	PREMADJOINT	2001-03-18 00:00:00	\N	2017-10-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-10-01 11:42:20	2017-11-08 16:37:42
51482	50686	CONSDPT	2015-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-10-01 11:43:44	2017-10-01 11:44:42
51484	50687	PREMADJOINT	2014-03-30 00:00:00	\N	2017-11-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-10-01 11:49:04	2017-10-25 16:21:58
51494	50700	VICPDTDPT	2015-03-29 00:00:00	\N	2017-10-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-10-02 14:59:41	2017-10-25 16:36:25
51486	50689	VICPDTINTCOM	2017-01-01 00:00:00	\N	2017-11-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-10-01 11:51:51	2017-10-25 16:38:34
51488	50690	MAIRE	2014-03-30 00:00:00	\N	2017-10-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-10-01 11:59:24	2017-12-06 12:48:43
50996	50932	CONSDPT	2017-12-19 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2018-01-08 16:14:47	2018-01-08 16:14:55
52358	51872	MAIREADJOINT	2001-03-16 00:00:00	\N	2018-12-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51491	50693	VICPDTINTCOM	2014-03-23 00:00:00	\N	2017-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-10-02 10:36:53	2017-12-12 17:14:07
51463	50694	CONSMUNI	2017-10-01 00:00:00	\N	2020-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-10-02 10:40:32	2017-10-02 10:41:45
51492	50695	MEMBREINTCOM	2017-10-02 00:00:00	\N	2020-07-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-10-02 10:44:52	\N
51493	50696	CONSGENE	2001-03-18 00:00:00	\N	2008-03-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-10-02 11:15:19	2017-10-02 11:20:17
51484	50697	CONSMUNI	2008-03-16 00:00:00	\N	2014-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-10-02 14:46:21	2017-10-02 14:47:16
51484	50698	MAIREADJOINT	2001-03-18 00:00:00	\N	2008-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-10-02 14:47:21	2017-10-02 14:48:05
51485	50699	CONSGENE	2011-03-27 00:00:00	\N	2014-12-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-10-02 14:55:06	2017-10-02 14:55:34
51495	50701	CONSGENE	2004-03-28 00:00:00	\N	2015-03-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-10-02 16:07:43	2017-10-02 16:12:15
14160	50702	CONSMUNI	2017-10-01 00:00:00	\N	2021-02-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-10-03 11:50:29	2017-10-03 11:50:51
11528	50705	CONSMUNI	2017-10-03 00:00:00	\N	2019-01-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-10-04 16:00:11	2017-10-04 16:00:30
13879	50704	CONSMUNI	2017-06-28 00:00:00	\N	2020-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-10-04 09:57:38	2017-10-04 09:57:57
13773	50706	CONSCOMINT	2017-10-03 00:00:00	\N	2019-01-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-10-04 16:00:45	2017-10-04 16:01:27
13875	50707	CONSMUNI	2017-10-01 00:00:00	\N	2020-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-10-04 17:01:50	2017-10-04 17:02:03
13894	50708	CONSCOMINT	2017-10-01 00:00:00	\N	2020-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-10-04 17:02:32	2017-10-04 17:06:49
14023	50710	CONSMUNI	2017-10-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-10-05 14:07:50	2017-10-05 14:07:57
51337	50711	CONSGENE	1992-03-29 00:00:00	\N	1998-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-10-05 14:57:29	2017-10-05 14:57:55
51337	50712	CONSGENE	1998-03-16 00:00:00	\N	2002-11-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-10-05 14:57:59	2017-10-05 15:00:15
51340	50714	CONSCOMINT	2008-03-16 00:00:00	\N	2014-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-10-05 15:04:35	2017-10-05 15:05:00
11673	50715	CONSMUNI	2017-10-01 00:00:00	\N	2020-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-10-06 16:48:26	2017-10-06 16:48:49
13804	50716	CONSMUNI	2017-10-01 00:00:00	\N	2020-03-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-10-09 11:56:03	2017-10-09 11:56:30
51498	50717	DEPUTE	1973-03-11 00:00:00	1973	1981-05-22 00:00:00	1981	ANCIEN	\N	\N	\N	NON	2017-10-10 12:05:51	2017-10-10 12:06:24
11492	50718	CONSMUNI	2017-10-16 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-10-16 10:21:54	\N
34191	32788	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:25	\N
34192	32789	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:25	\N
34193	32790	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:25	\N
34194	32791	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:25	\N
34195	32792	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:25	\N
34196	32793	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:25	\N
34197	32794	DEPUTE	1981-07-24 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:25	\N
34198	32795	DEPUTE	1986-04-02 00:00:00	\N	1986-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:25	\N
34199	32796	DEPUTE	1986-10-01 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:25	\N
34200	32797	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:25	\N
34201	32798	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:25	\N
34202	32799	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:25	\N
34203	32800	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:26	\N
34204	32801	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:26	\N
34205	32802	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:26	\N
34206	32803	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:26	\N
34207	32804	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:26	\N
34208	32805	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:26	\N
34209	32806	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:26	\N
34210	32807	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:26	\N
34211	32808	DEPUTE	2012-06-20 00:00:00	\N	2016-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:26	\N
34212	32809	QUESTAN	2012-06-27 00:00:00	\N	2016-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:26	\N
34213	32810	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:26	\N
34215	32812	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:26	\N
34216	32813	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:26	\N
34217	32814	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:26	\N
34218	32815	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:26	\N
34219	32816	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:26	\N
34220	32817	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:26	\N
34221	32818	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:26	\N
34222	32819	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:26	\N
34223	32820	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:26	\N
34224	32821	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:26	\N
34225	32822	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:26	\N
34226	32823	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:26	\N
34227	32824	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:26	\N
34228	32825	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:27	\N
34229	32826	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:27	\N
34230	32827	SECAN	2002-10-02 00:00:00	\N	2004-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:27	\N
34231	32828	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:27	\N
34232	32829	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:27	\N
34233	32830	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:27	\N
34234	32831	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:27	\N
34235	32832	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:27	\N
34236	32833	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:27	\N
34237	32834	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:27	\N
34238	32835	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:27	\N
34239	32836	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:27	\N
34240	32837	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:27	\N
34241	32838	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:27	\N
34242	32839	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:27	\N
34243	32840	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:27	\N
34244	32841	DEPUTE	1997-06-01 00:00:00	\N	1999-03-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:27	\N
34245	32842	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:27	\N
34246	32843	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:27	\N
34247	32844	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:27	\N
34248	32845	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:27	\N
34249	32846	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:27	\N
34250	32847	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:27	\N
34251	32848	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:27	\N
34252	32849	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:27	\N
34253	32850	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:27	\N
34254	32851	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:27	\N
34255	32852	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:27	\N
34256	32853	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:27	\N
34257	32854	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:27	\N
34258	32855	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:27	\N
34259	32856	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:27	\N
34260	32857	SECAN	2008-10-01 00:00:00	\N	2009-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:27	\N
34261	32858	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:27	\N
34262	32859	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:27	\N
34263	32860	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:27	\N
34264	32861	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:27	\N
34265	32862	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:27	\N
34266	32863	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:27	\N
34267	32864	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:27	\N
34268	32865	DEPUTE	1993-04-02 00:00:00	\N	1996-11-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:27	\N
34269	32866	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:27	\N
34270	32867	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:27	\N
34271	32868	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:27	\N
34272	32869	DEPUTE	2007-06-20 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:28	\N
34273	32870	VICPDTAN	2008-10-01 00:00:00	\N	2009-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:28	\N
34274	32871	SECAN	2007-06-27 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:28	\N
34275	32872	SECAN	2009-10-06 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:28	\N
34276	32873	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:28	\N
34277	32874	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:28	\N
34278	32875	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:28	\N
34279	32876	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:28	\N
34280	32877	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:28	\N
34281	32878	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:28	\N
34282	32879	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:28	\N
34283	32880	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:28	\N
35682	34279	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:20	\N
35683	34280	DEPUTE	2014-12-22 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:20	\N
35684	34281	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:20	\N
35685	34282	DEPUTE	2014-09-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:20	\N
35686	34283	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:20	\N
35687	34284	DEPUTE	2014-05-03 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:20	\N
35688	34285	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:20	\N
35689	34286	SECAN	1987-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:20	\N
35690	34287	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:20	\N
35691	34288	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:20	\N
35692	34289	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:20	\N
35693	34290	DEPUTE	2007-06-20 00:00:00	\N	2010-04-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:20	\N
35694	34291	DEPUTE	2011-06-30 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:20	\N
35695	34292	DEPUTE	2011-10-28 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:20	\N
35696	34293	DEPUTE	2009-07-23 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:20	\N
35697	34294	DEPUTE	2010-06-11 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:20	\N
35698	34295	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:20	\N
35699	34296	DEPUTE	2010-12-15 00:00:00	\N	2012-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:21	\N
35700	34297	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:21	\N
35701	34298	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:21	\N
35702	34299	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:21	\N
35703	34300	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:21	\N
35704	34301	DEPUTE	2007-06-20 00:00:00	\N	2011-05-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:21	\N
35705	34302	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:21	\N
35706	34303	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:21	\N
35707	34304	DEPUTE	2012-06-20 00:00:00	\N	2014-05-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:21	\N
35708	34305	DEPUTE	2014-06-30 00:00:00	\N	2014-07-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:21	\N
35709	34306	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:21	\N
35710	34307	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:21	\N
35711	34308	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:21	\N
35712	34309	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:21	\N
35713	34310	DEPUTE	2014-09-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:21	\N
35714	34311	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:21	\N
35715	34312	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:21	\N
35716	34313	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:21	\N
35717	34314	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:21	\N
35718	34315	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:21	\N
35719	34316	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:21	\N
35720	34317	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:21	\N
35721	34318	DEPUTE	2015-04-06 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:21	\N
35722	34319	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:22	\N
35723	34320	DEPUTE	2012-06-20 00:00:00	\N	2017-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:22	\N
35724	34321	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:22	\N
35725	34322	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:22	\N
35726	34323	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:22	\N
35727	34324	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:22	\N
35728	34325	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:22	\N
35729	34326	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:22	\N
35730	34327	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:22	\N
35731	34328	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:22	\N
35732	34329	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:22	\N
35733	34330	DEPUTE	2007-06-20 00:00:00	\N	2008-03-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:22	\N
35734	34331	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:22	\N
35735	34332	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:22	\N
35736	34333	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:22	\N
35737	34334	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:22	\N
35738	34335	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:23	\N
35739	34336	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:23	\N
35740	34337	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:23	\N
35741	34338	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:23	\N
35742	34339	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:23	\N
35743	34340	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:23	\N
35744	34341	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:23	\N
35745	34342	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:23	\N
35746	34343	DEPUTE	2014-09-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:23	\N
35747	34344	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:23	\N
35748	34345	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:23	\N
35749	34346	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:23	\N
35750	34347	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:23	\N
35751	34348	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:23	\N
35752	34349	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:23	\N
35753	34350	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:23	\N
35754	34351	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:23	\N
35755	34352	VICPDTAN	2011-10-03 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:23	\N
35756	34353	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:23	\N
35757	34354	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:23	\N
35758	34355	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:23	\N
35759	34356	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:23	\N
35760	34357	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:24	\N
35761	34358	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:24	\N
35762	34359	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:24	\N
35763	34360	DEPUTE	2007-06-26 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:24	\N
35764	34361	SECAN	2007-06-27 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:24	\N
35765	34362	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:24	\N
35766	34363	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:24	\N
35767	34364	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:24	\N
35768	34365	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:24	\N
35769	34366	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:24	\N
35770	34367	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:24	\N
35771	34368	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:24	\N
35772	34369	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:24	\N
35773	34370	DEPUTE	2007-06-26 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:24	\N
35774	34371	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:24	\N
35775	34372	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:24	\N
45606	49530	VICPDTAN	1997-06-13 00:00:00	\N	1998-10-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:01	\N
45606	49531	DEPUTE	1998-10-21 00:00:00	\N	1998-11-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:01	\N
50752	49532	QUESTAN	1990-04-02 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:01	\N
50752	49533	DEPUTE	1993-04-02 00:00:00	\N	1993-04-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:01	\N
50752	49534	QUESTAN	1993-04-07 00:00:00	\N	1995-05-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:01	\N
50752	49535	DEPUTE	1995-06-01 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:01	\N
45649	49536	DEPUTE	1986-04-02 00:00:00	\N	1986-04-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:02	\N
45649	49537	SECAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:02	\N
45654	49538	DEPUTE	2002-06-19 00:00:00	\N	2003-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:02	\N
45654	49539	SECAN	2003-10-01 00:00:00	\N	2005-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:02	\N
45654	49540	DEPUTE	2005-10-04 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:02	\N
45683	49541	DEPUTE	1997-06-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:02	\N
45683	49542	SECAN	1999-10-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:02	\N
45682	49543	DEPUTE	2002-06-19 00:00:00	\N	2005-06-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:02	\N
45682	49544	VICPDTAN	2005-06-09 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:02	\N
45713	49545	DEPUTE	2007-06-20 00:00:00	\N	2009-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:03	\N
45713	49546	VICPDTAN	2009-10-06 00:00:00	\N	2010-10-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:03	\N
45713	49547	SECAN	2010-10-05 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:03	\N
45724	49548	DEPUTE	2002-06-19 00:00:00	\N	2004-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:03	\N
45724	49549	QUESTAN	2004-05-05 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:03	\N
45751	49550	PDTAN	1968-07-11 00:00:00	\N	1969-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:04	\N
45751	49551	DEPUTE	1969-06-21 00:00:00	\N	1969-07-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:04	\N
45805	49552	DEPUTE	2012-06-20 00:00:00	\N	2012-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:05	\N
45805	49553	SECAN	2012-06-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:05	\N
45824	49554	DEPUTE	1997-06-01 00:00:00	\N	1997-06-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:05	\N
45824	49555	SECAN	1997-06-13 00:00:00	\N	2000-04-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:05	\N
45824	49556	DEPUTE	2000-04-07 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:05	\N
45823	49557	DEPUTE	1993-04-02 00:00:00	\N	1994-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:05	\N
45823	49558	SECAN	1994-04-02 00:00:00	\N	1995-04-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:05	\N
45823	49559	DEPUTE	1995-04-04 00:00:00	\N	1996-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:05	\N
45823	49560	SECAN	1996-10-01 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:05	\N
45948	49561	DEPUTE	1988-06-13 00:00:00	\N	1991-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:08	\N
45948	49562	SECAN	1991-04-02 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:08	\N
45947	49563	DEPUTE	1986-04-02 00:00:00	\N	1987-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:08	\N
45947	49564	VICPDTAN	1987-04-02 00:00:00	\N	1988-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:08	\N
45947	49565	DEPUTE	1988-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:08	\N
45984	49566	DEPUTE	1997-06-01 00:00:00	\N	1998-10-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:08	\N
45984	49567	VICPDTAN	1998-10-28 00:00:00	\N	2000-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:08	\N
45984	49568	PDTAN	2000-03-29 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:08	\N
45983	49569	DEPUTE	1988-06-13 00:00:00	\N	1991-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:09	\N
45983	49570	VICPDTAN	1991-04-02 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:09	\N
46089	49571	DEPUTE	1997-06-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:11	\N
46089	49572	VICPDTAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:11	\N
46087	49573	DEPUTE	1993-04-02 00:00:00	\N	1995-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:11	\N
46087	49574	VICPDTAN	1995-06-15 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:11	\N
46088	49575	DEPUTE	2002-06-19 00:00:00	\N	2002-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:11	\N
46088	49576	QUESTAN	2002-06-26 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:11	\N
46094	49577	DEPUTE	1988-06-13 00:00:00	\N	1992-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:11	\N
46094	49578	SECAN	1992-04-02 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:11	\N
46172	49579	DEPUTE	1997-06-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:13	\N
46172	49580	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:13	\N
50753	49581	SECAN	1992-04-02 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:13	\N
50753	49582	DEPUTE	1993-04-02 00:00:00	\N	1993-04-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:13	\N
50753	49583	SECAN	1993-04-07 00:00:00	\N	1995-06-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:13	\N
50753	49584	VICPDTAN	1995-06-01 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:13	\N
46219	49585	DEPUTE	1986-04-02 00:00:00	\N	1988-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:14	\N
46219	49586	VICPDTAN	1988-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:14	\N
50754	49587	VICPDTAN	2011-10-03 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:16	\N
50754	49588	DEPUTE	2012-06-20 00:00:00	\N	2012-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:16	\N
50754	49589	VICPDTAN	2012-06-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:16	\N
46411	49593	DEPUTE	1986-04-02 00:00:00	\N	1986-04-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:18	\N
46411	49594	VICPDTAN	1986-04-04 00:00:00	\N	1987-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:18	\N
46411	49595	DEPUTE	1987-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:18	\N
46421	49596	DEPUTE	1988-06-13 00:00:00	\N	1988-06-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:18	\N
46421	49597	SECAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:18	\N
46430	49598	DEPUTE	2002-06-19 00:00:00	\N	2002-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:19	\N
46430	49599	QUESTAN	2002-06-26 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:19	\N
46440	49600	DEPUTE	2002-06-19 00:00:00	\N	2003-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:19	\N
46440	49601	VICPDTAN	2003-10-01 00:00:00	\N	2004-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:19	\N
46440	49602	DEPUTE	2004-10-01 00:00:00	\N	2006-01-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:19	\N
46440	49603	VICPDTAN	2006-01-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:19	\N
46448	49604	DEPUTE	1986-04-02 00:00:00	\N	1986-04-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:19	\N
46448	49605	VICPDTAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:33:19	\N
50943	50251	MAIRE	2017-01-01 00:00:00	\N	2017-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-20 16:04:52	2018-01-24 11:11:28
50945	50253	VICPDTDPT	2015-03-29 00:00:00	\N	2017-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-20 16:13:19	2018-01-24 11:12:02
50952	50260	CONSREG	2015-12-13 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 16:32:47	2017-09-20 16:33:01
50954	50262	MAIRE	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 16:41:06	2017-09-20 16:41:22
50958	50267	CONSDPT	2015-03-29 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 16:51:49	2017-09-20 16:52:10
50959	50268	CONSMUNI	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 16:53:55	2017-09-20 16:54:10
50960	50269	CONSMUNI	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 16:57:46	2017-09-20 16:58:06
50961	50270	CONSMUNI	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 17:08:19	2017-09-20 17:08:36
50962	50271	MAIRE	2001-03-18 00:00:00	\N	2017-11-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-09-20 17:09:53	2018-01-12 14:52:54
50963	50272	CONSREG	2015-12-13 00:00:00	\N	2017-10-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-09-20 17:12:27	2018-01-12 14:57:42
50964	50273	MAIRE	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 17:15:39	2017-09-20 17:15:57
50965	50274	CONSMUNI	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 17:17:31	2017-09-20 17:18:20
11875	50719	CONSINTCOM	2017-10-16 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	2017-10-16 10:23:37	2017-10-16 10:23:51
15161	50720	CONSDPT	2017-10-19 00:00:00	\N	2020-09-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-10-19 11:22:31	\N
12528	50721	PDTINTCOM	2001-03-18 00:00:00	\N	2017-10-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-10-19 14:50:08	2017-10-19 14:51:43
51499	50722	CONSCOMINT	2017-10-19 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	2017-10-19 14:51:48	2017-10-19 14:52:36
12527	50723	CONSMUNI	2017-10-23 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-10-23 12:02:53	2017-10-23 12:51:19
51484	50724	CONSMUNI	2017-11-06 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-10-25 16:21:27	2017-10-25 16:21:58
51486	50725	CONSCOMINT	2017-11-06 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	2017-10-25 16:38:11	2017-10-25 16:38:25
51501	50726	PREMADJOINT	1977-03-20 00:00:00	\N	1983-03-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-11-03 10:54:32	2017-11-03 10:58:28
51501	50727	MAIRE	1983-03-13 00:00:00	\N	2017-11-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-11-03 10:58:33	2018-01-10 18:58:11
51502	50728	PREPDTINTCOM	2014-03-30 00:00:00	\N	2017-11-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-11-03 11:00:02	2018-01-10 18:58:47
50860	50731	CONSDPT	2017-09-24 00:00:00	\N	2021-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-11-06 12:02:06	2017-11-06 12:02:19
14016	50730	CONSMUNI	2017-09-30 00:00:00	\N	2023-11-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-11-03 15:23:29	2017-11-03 15:23:56
13778	50734	CONSMUNI	2017-11-06 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-06 16:02:40	\N
15185	50735	CONSDPT	2017-10-31 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-06 16:24:42	2017-11-06 16:25:14
13756	50736	CONSMUNI	2017-10-31 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-06 16:25:34	2017-11-06 16:25:48
15523	50737	CONSCOMINT	2017-10-31 00:00:00	\N	2020-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-11-06 16:26:10	2017-11-06 16:26:26
10821	50738	CONSMUNI	2017-10-31 00:00:00	\N	2020-05-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-11-06 16:29:48	2017-11-06 16:30:04
13981	50739	CONSMUNI	2017-10-23 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-07 16:17:38	2017-11-07 16:18:04
15208	50740	CONSCOMINT	2017-10-23 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	2017-11-07 16:18:15	2017-11-07 16:18:31
51305	50741	CONSMUNI	2017-10-31 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-08 10:00:09	2017-11-08 10:00:36
51308	50742	CONSCOMINT	2017-10-31 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	2017-11-08 10:01:32	2017-11-08 10:03:32
6412	50745	CONSMUNI	2017-10-23 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-08 15:50:57	2017-11-08 15:52:51
11590	50747	CONSMUNI	2017-11-07 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-08 15:58:48	2017-11-08 15:59:08
36238	34835	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:47	\N
11593	50748	CONSCOMINT	2017-11-10 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	2017-11-08 15:59:20	2017-11-08 16:07:23
13998	50750	CONSMUNI	2017-09-12 00:00:00	\N	2020-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-11-08 16:26:47	2017-11-08 16:27:06
14329	50751	CONSCOMINT	2017-09-12 00:00:00	\N	2020-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-11-08 16:27:22	2017-11-08 16:28:10
14301	50771	CONSMUNI	2017-10-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-09 10:28:13	2017-11-09 10:28:35
51507	50753	CONSCOMINT	2017-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	2017-11-08 17:01:03	2017-11-08 17:02:41
51101	50766	CONSMUNI	2017-10-02 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-09 09:46:09	2017-11-09 09:46:23
13854	50767	MAIREADJOINT	2016-06-16 00:00:00	\N	2017-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-11-09 10:19:12	2017-11-09 10:19:59
13854	50768	CONSMUNI	2017-10-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-09 10:20:02	2017-11-09 10:21:41
14350	50769	MEMBREINTCOM	2017-10-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-09 10:23:17	2017-11-09 10:23:43
15165	50770	CONSDPT	2017-09-29 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-09 10:27:40	2017-11-09 10:28:10
14307	50772	CONSCOMINT	2017-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	2017-11-09 10:28:47	2017-11-09 10:29:01
15168	50773	CONSDPT	2017-09-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-09 10:39:26	2017-11-09 10:39:48
10676	50774	CONSMUNI	2017-10-24 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-09 10:44:26	2017-11-09 10:45:08
14109	50775	CONSMUNI	2017-10-12 00:00:00	\N	2020-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-11-09 11:07:59	2017-11-09 11:09:42
14372	50776	CONSCOMINT	2017-10-12 00:00:00	\N	2020-06-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-11-09 11:09:51	2017-11-09 11:10:27
14051	50777	CONSMUNI	2017-07-16 00:00:00	\N	2020-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-11-09 11:24:28	2017-11-09 11:24:56
13961	50778	CONSMUNI	2016-01-11 00:00:00	\N	2020-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-11-09 11:31:53	2017-11-09 12:12:43
50823	50779	CONSDPT	2017-10-31 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-09 11:39:13	2017-11-09 11:39:35
51508	50780	CONSCOMINT	2017-11-08 00:00:00	\N	2020-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-11-09 12:14:21	2017-11-09 12:16:12
51509	50781	MAIREDEL	2008-03-21 00:00:00	\N	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-11-09 13:05:39	2017-11-09 13:07:49
51511	50785	CONSDPT	2015-03-29 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2017-11-09 13:12:12	2017-11-09 13:14:07
51510	50783	CONSGENE	2012-06-21 00:00:00	\N	2015-03-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-11-09 13:11:16	2017-11-09 13:12:07
13855	50786	CONSMUNI	2017-10-01 00:00:00	\N	2020-05-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-11-09 14:31:21	2017-11-09 14:31:40
50967	50787	CONSMUNI	2017-10-24 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-09 14:40:07	2017-11-09 14:40:24
14244	50788	CONSMUNI	2017-10-24 00:00:00	\N	2020-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-11-09 15:33:15	2017-11-09 15:33:29
50874	50789	CONSDPT	2017-10-17 00:00:00	\N	2018-03-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-11-09 15:59:52	2017-11-09 16:00:40
50809	50790	CONSDPT	2017-10-25 00:00:00	\N	2021-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-11-09 16:04:00	2017-11-09 16:04:20
11712	50793	CONSMUNI	2017-06-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2017-11-10 10:29:49	2017-11-10 10:30:12
51165	50792	CONSMUNI	2017-10-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-10 10:26:43	2017-11-10 10:27:00
10760	50794	CONSREG	2017-10-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-10 14:54:58	2017-11-10 14:55:15
14132	50795	CONSMUNI	2017-10-24 00:00:00	\N	2020-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-11-10 15:27:50	2017-11-10 15:28:06
12562	50796	CONSMUNI	2017-10-24 00:00:00	\N	2020-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-11-10 15:56:55	2017-11-10 15:57:49
12564	50797	CONSCOMINT	2017-10-24 00:00:00	\N	2020-03-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-11-10 15:57:49	2017-11-10 15:58:02
14071	50798	CONSMUNI	2017-10-01 00:00:00	\N	2021-07-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-11-10 18:13:28	2017-11-10 18:13:47
14075	50799	CONSCOMINT	2017-10-01 00:00:00	\N	2021-07-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-11-10 18:14:00	2017-11-10 18:14:19
12533	50800	CONSMUNI	2017-10-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-10 18:18:54	2017-11-10 18:19:14
15283	50801	CONSCOMINT	2017-10-21 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	2017-11-10 18:19:41	2017-11-10 18:19:59
15154	50802	CONSDPT	2017-10-01 00:00:00	\N	2021-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-11-13 09:23:12	2017-11-13 09:23:31
10807	50803	CONSMUNI	2017-10-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-13 10:04:05	2017-11-13 10:04:23
51319	50804	MEMBREINTCOM	2017-10-13 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-13 11:27:47	2017-11-13 11:28:07
51313	50805	CONSMUNI	2017-10-06 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-13 11:28:38	2017-11-13 11:28:50
13826	50806	CONSMUNI	2017-10-01 00:00:00	\N	2020-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-11-13 11:35:04	2017-11-13 11:35:22
6059	50807	CONSMUNI	2017-10-02 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-13 14:18:21	2017-11-13 14:18:34
12515	50808	CONSMUNI	2017-10-13 00:00:00	\N	2020-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-11-13 14:33:17	2017-11-13 14:33:52
12837	50809	CONSMUNI	2017-11-06 00:00:00	\N	2020-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-11-13 15:39:25	2017-11-13 15:39:37
34284	32881	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:28	\N
34285	32882	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:28	\N
34286	32883	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:28	\N
34287	32884	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:28	\N
34288	32885	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:28	\N
34289	32886	SECAN	2002-06-26 00:00:00	\N	2003-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:28	\N
34290	32887	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:28	\N
34291	32888	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:28	\N
34292	32889	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:28	\N
34293	32890	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:28	\N
34294	32891	DEPUTE	1991-02-05 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:28	\N
34295	32892	DEPUTE	1993-04-02 00:00:00	\N	1997-02-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:28	\N
34296	32893	DEPUTE	1988-06-13 00:00:00	\N	1990-12-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:28	\N
34297	32894	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:28	\N
34298	32895	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:28	\N
34299	32896	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:28	\N
34300	32897	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:28	\N
34301	32898	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:28	\N
34302	32899	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:28	\N
34303	32900	DEPUTE	1986-04-02 00:00:00	\N	1987-05-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:28	\N
34304	32901	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:28	\N
34305	32902	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:28	\N
34306	32903	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:28	\N
34307	32904	DEPUTE	2010-12-14 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:28	\N
34308	32905	DEPUTE	1981-07-02 00:00:00	\N	1982-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:28	\N
34309	32906	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:28	\N
34310	32907	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:28	\N
34311	32908	DEPUTE	1998-11-30 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:28	\N
34312	32909	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:28	\N
34313	32910	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:28	\N
34314	32911	DEPUTE	1962-12-06 00:00:00	\N	1966-02-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:28	\N
34315	32912	DEPUTE	1967-04-03 00:00:00	\N	1967-05-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:28	\N
34316	32913	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:28	\N
34317	32914	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:28	\N
34318	32915	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:29	\N
34319	32916	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:29	\N
34320	32917	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:29	\N
34321	32918	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:29	\N
34322	32919	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:29	\N
34323	32920	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:29	\N
34324	32921	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:29	\N
34325	32922	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:29	\N
34326	32923	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:29	\N
34327	32924	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:29	\N
34328	32925	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:29	\N
34329	32926	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:29	\N
34330	32927	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:29	\N
34331	32928	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:29	\N
34332	32929	DEPUTE	2007-06-20 00:00:00	\N	2010-12-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:29	\N
34333	32930	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:29	\N
34334	32931	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:29	\N
34335	32932	VICPDTAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:29	\N
34336	32933	VICPDTAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:29	\N
34337	32934	VICPDTAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:29	\N
34338	32935	PDTAN	2007-03-07 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:29	\N
34339	32936	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:29	\N
34340	32937	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:29	\N
34341	32938	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:29	\N
34342	32939	DEPUTE	1973-04-02 00:00:00	\N	1974-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:29	\N
34343	32940	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:29	\N
34344	32941	DEPUTE	1978-04-03 00:00:00	\N	1978-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:29	\N
34345	32942	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:29	\N
34346	32943	DEPUTE	1988-06-06 00:00:00	\N	1991-03-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:29	\N
34347	32944	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:29	\N
34348	32945	DEPUTE	1986-04-02 00:00:00	\N	1986-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:29	\N
34349	32946	DEPUTE	1986-10-01 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:29	\N
34350	32947	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:29	\N
34351	32948	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:29	\N
34352	32949	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:29	\N
34353	32950	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:29	\N
34354	32951	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:30	\N
34355	32952	DEPUTE	1983-11-15 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:30	\N
34356	32953	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:30	\N
34357	32954	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:30	\N
34358	32955	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:30	\N
34359	32956	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:30	\N
34360	32957	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:30	\N
34361	32958	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:30	\N
34362	32959	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:30	\N
34363	32960	VICPDTAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:30	\N
34364	32961	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:30	\N
34365	32962	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:30	\N
34366	32963	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:30	\N
34367	32964	DEPUTE	1994-06-20 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:30	\N
34368	32965	DEPUTE	1996-02-25 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:30	\N
34369	32966	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:30	\N
34370	32967	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:30	\N
34371	32968	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:30	\N
34372	32969	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:30	\N
34373	32970	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:30	\N
34374	32971	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:30	\N
34375	32972	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:30	\N
34376	32973	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:30	\N
35776	34373	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:24	\N
35777	34374	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:24	\N
35778	34375	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:24	\N
35779	34376	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:24	\N
35780	34377	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:24	\N
35781	34378	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:24	\N
35782	34379	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:24	\N
35783	34380	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:25	\N
35784	34381	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:25	\N
35785	34382	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:25	\N
35786	34383	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:25	\N
35787	34384	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:25	\N
35788	34385	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:25	\N
35789	34386	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:25	\N
35790	34387	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:25	\N
35791	34388	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:25	\N
35792	34389	DEPUTE	2016-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:25	\N
35793	34390	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:25	\N
35794	34391	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:25	\N
35795	34392	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:25	\N
35796	34393	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:25	\N
35797	34394	DEPUTE	2014-07-04 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:25	\N
35798	34395	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:25	\N
35799	34396	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:25	\N
35800	34397	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:25	\N
35801	34398	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:25	\N
35802	34399	DEPUTE	2013-08-03 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:25	\N
35803	34400	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:25	\N
35804	34401	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:25	\N
35805	34402	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:25	\N
35806	34403	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:25	\N
35807	34404	VICPDTAN	2012-06-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:25	\N
35808	34405	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:25	\N
35809	34406	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:25	\N
35810	34407	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:25	\N
35811	34408	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:25	\N
35812	34409	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:25	\N
35813	34410	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:25	\N
35814	34411	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:25	\N
35815	34412	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:25	\N
35816	34413	SECAN	2012-06-27 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:25	\N
35817	34414	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:25	\N
35818	34415	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:25	\N
35819	34416	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:25	\N
35820	34417	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:25	\N
35821	34418	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:25	\N
35822	34419	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:26	\N
35823	34420	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:26	\N
35824	34421	DEPUTE	2010-12-29 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:26	\N
35825	34422	DEPUTE	2012-07-22 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:26	\N
35826	34423	DEPUTE	2012-07-22 00:00:00	\N	2014-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:26	\N
35827	34424	DEPUTE	2012-07-22 00:00:00	\N	2014-12-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:26	\N
35828	34425	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:26	\N
35829	34426	DEPUTE	2012-07-22 00:00:00	\N	2014-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:26	\N
35830	34427	DEPUTE	2012-07-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:26	\N
35831	34428	DEPUTE	2017-05-06 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:26	\N
35832	34429	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:26	\N
35833	34430	DEPUTE	2016-03-04 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:26	\N
35834	34431	DEPUTE	2015-07-18 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:26	\N
35835	34432	DEPUTE	2012-07-22 00:00:00	\N	2014-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:26	\N
35836	34433	DEPUTE	2015-02-09 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:26	\N
35837	34434	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:26	\N
35838	34435	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:26	\N
35839	34436	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:26	\N
35840	34437	DEPUTE	2012-06-26 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:26	\N
35841	34438	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:26	\N
35842	34439	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:26	\N
35843	34440	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:26	\N
35844	34441	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:27	\N
35845	34442	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:27	\N
35846	34443	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:27	\N
35847	34444	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:27	\N
35848	34445	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:27	\N
35849	34446	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:27	\N
35850	34447	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:27	\N
35851	34448	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:27	\N
35852	34449	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:27	\N
35853	34450	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:27	\N
35854	34451	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:27	\N
35855	34452	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:27	\N
35856	34453	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:27	\N
35857	34454	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:27	\N
35858	34455	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:27	\N
35859	34456	DEPUTE	2012-06-20 00:00:00	\N	2016-03-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:27	\N
35860	34457	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:27	\N
35861	34458	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:27	\N
35862	34459	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:28	\N
35863	34460	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:28	\N
35864	34461	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:28	\N
35865	34462	VICPDTAN	2012-06-27 00:00:00	\N	2016-05-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:28	\N
35866	34463	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:28	\N
35867	34464	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:28	\N
35868	34465	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:28	\N
35869	34466	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:28	\N
50966	50275	CONSMUNI	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 17:20:05	2017-09-20 17:20:28
51266	50462	MAIREADJOINT	2001-03-18 00:00:00	\N	2008-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 18:56:10	2017-09-24 19:00:44
51281	50470	CONSPARI	2014-03-30 00:00:00	\N	2014-04-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 19:11:05	2017-09-24 19:13:09
51281	50472	MAIREADJOINT	2014-04-05 00:00:00	\N	2017-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 19:13:13	2018-05-30 09:58:53
51283	50474	MAIREADJOINT	2001-04-02 00:00:00	\N	2014-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 19:14:06	2017-09-24 19:15:50
51313	50489	MAIRE	2001-03-18 00:00:00	\N	2017-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-09-24 19:41:29	2017-11-13 11:28:37
51315	50492	CONSDPT	2015-03-29 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-24 19:44:00	2017-09-24 19:45:38
51316	50494	CONSGENE	1994-03-27 00:00:00	\N	2015-03-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 19:45:05	2017-09-27 10:39:55
51318	50496	VICPDTINTCOM	2017-01-01 00:00:00	\N	2017-10-31 00:00:00	\N	ANCIEN	\N	de la Communauté de communes "Dômes Sancy Artense"	\N	\N	2017-09-24 19:48:38	2017-09-24 19:51:52
51319	50497	PDTINTCOM	2008-03-23 00:00:00	\N	2017-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-09-24 19:50:05	2017-11-13 11:23:13
51323	50502	VICPDTGEN	2001-03-11 00:00:00	\N	2015-03-28 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-09-24 19:57:24	2017-09-24 19:59:32
51325	50504	CONSMUNI	2008-03-16 00:00:00	\N	2012-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 19:59:09	2017-09-24 20:01:09
51328	50507	CONSDPT	2015-03-29 00:00:00	\N	2021-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 20:02:49	2017-10-02 16:13:29
51330	50509	CONSMUNI	1989-03-19 00:00:00	\N	2017-10-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 20:05:35	2017-09-24 20:06:36
51333	50512	VICPDTINTCOM	2002-11-28 00:00:00	\N	2016-12-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 20:11:51	2017-09-26 16:49:14
51353	50537	CONSDPT	2015-03-29 00:00:00	\N	2021-06-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 20:54:10	2017-09-24 20:54:45
51346	50526	CONSREG	2004-04-28 00:00:00	\N	2015-12-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 20:34:00	2017-09-24 20:34:43
51344	50524	MAIRE	2008-03-16 00:00:00	\N	2017-10-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 20:32:58	2017-11-20 11:46:54
51347	50527	MAIRE	1995-03-19 00:00:00	\N	2008-03-15 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-09-24 20:34:19	2017-09-26 18:06:47
51354	50538	CONSGENE	2008-03-16 00:00:00	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 20:56:26	2017-09-24 20:57:42
51355	50539	CONSGENE	2001-03-18 00:00:00	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 21:05:04	2017-09-24 21:06:12
51356	50540	CONSREG	1992-03-22 00:00:00	\N	2001-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 21:06:47	2017-09-24 21:07:49
51359	50543	MAIRE	2001-03-11 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-25 10:06:54	2017-09-26 10:30:38
51360	50544	CONSREG	1998-03-16 00:00:00	\N	2002-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-25 10:11:22	2017-09-25 10:12:17
11623	50545	CONSMUNI	2016-10-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2017-09-25 10:32:28	2017-09-25 10:33:46
50901	50548	PDTREG	2014-05-02 00:00:00	\N	2015-12-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-25 11:21:47	2017-09-28 18:18:56
51369	50547	MAIRE	2001-03-19 00:00:00	\N	2005-04-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-25 11:15:52	2017-09-25 11:17:54
51370	50549	CONSGENE	2004-03-28 00:00:00	\N	2010-03-27 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-09-25 11:23:37	2017-09-25 11:25:30
51369	50551	CONSMUNI	1989-03-19 00:00:00	\N	2001-03-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-25 11:25:52	2017-09-25 11:27:45
51372	50552	PREVICPDTREG	2010-03-26 00:00:00	\N	2015-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-09-25 11:25:53	2017-09-25 11:27:02
51373	50553	CONSGENE	2002-03-27 00:00:00	\N	2002-10-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-25 11:33:55	2017-09-25 11:37:10
51374	50554	MAIREADJOINT	2014-03-30 00:00:00	\N	2017-11-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-25 11:42:43	2017-09-25 11:43:29
51375	50555	CONSMUNI	2014-03-16 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	2017-09-25 11:53:24	2017-09-25 11:53:55
51375	50556	MAIREADJOINT	2008-03-16 00:00:00	\N	2014-03-15 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-09-25 11:54:07	2017-09-25 11:54:36
51376	50557	CONSGENEPARI	2008-03-16 00:00:00	\N	2020-03-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-25 11:55:33	2017-09-25 17:01:58
51378	50559	VICPDTINTCOM	2014-03-16 00:00:00	\N	2017-11-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-09-25 12:05:48	2018-02-09 09:54:56
51379	50560	CONSGENEPARI	2008-03-16 00:00:00	\N	2020-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-09-25 12:09:48	2017-09-25 12:11:13
51380	50561	CONSGENEPARI	2001-03-18 00:00:00	\N	2020-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-25 15:49:16	2017-09-25 15:50:29
51382	50563	CONSGENE	2001-03-27 00:00:00	\N	2015-12-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-25 16:48:00	2017-09-25 16:50:39
51383	50564	MAIRE	2001-03-18 00:00:00	\N	2014-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-25 16:52:24	2017-09-25 16:53:58
51066	50576	MAIREADJOINT	\N	1983	1988-03-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-26 09:56:28	2017-09-26 09:57:42
51393	50577	PDTINTCOM	2014-03-23 00:00:00	\N	2017-10-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-09-26 10:00:35	2017-11-09 17:54:11
51395	50580	MAIREADJOINT	2001-03-18 00:00:00	\N	2003-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-09-26 10:47:51	2017-09-27 16:54:57
51394	50579	CONSREG	2011-03-21 00:00:00	\N	2015-12-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-26 10:43:56	2017-09-26 10:44:53
51395	50581	CONSMUNI	2003-12-15 00:00:00	\N	2008-03-16 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-09-26 10:51:12	2017-09-26 10:52:58
51396	50582	VICPDTINTCOM	2014-03-23 00:00:00	\N	2018-04-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-09-26 10:52:59	2018-05-15 14:51:37
51397	50583	CONSCOMINT	2001-03-18 00:00:00	\N	2008-03-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-09-26 10:54:41	2017-09-26 10:59:06
51398	50584	CONSMUNI	2014-03-23 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-26 11:07:20	2017-09-26 11:07:52
51399	50585	MAIRE	1995-03-19 00:00:00	\N	2011-03-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-26 11:11:48	2017-09-26 11:13:07
51400	50586	PDTDPT	2015-04-02 00:00:00	\N	2017-10-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-26 11:14:49	2017-11-08 15:47:24
51401	50587	CONSGENE	1998-03-22 00:00:00	\N	2015-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-26 11:16:46	2017-09-26 11:19:46
14311	50590	CONSCOMINT	2017-09-19 00:00:00	\N	2018-12-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-09-26 14:28:39	2017-09-26 14:28:51
51101	50589	CONSMUNI	2008-03-16 00:00:00	\N	2014-04-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-26 12:00:32	2017-09-26 12:00:57
51403	50591	VICPDTINTCOM	2014-04-02 00:00:00	\N	2018-04-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-09-26 14:35:17	2018-05-30 10:17:42
50795	50592	CONSMUNI	2017-09-26 00:00:00	\N	2022-02-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-26 15:01:31	\N
50826	50593	MAIREADJOINT	1995-06-18 00:00:00	\N	1999-12-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-26 16:38:53	2017-09-26 16:39:35
51404	50594	CONSCOMINT	2008-03-16 00:00:00	\N	2020-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-09-26 16:46:14	2017-09-26 16:50:47
51405	50595	PREPDTINTCOM	2017-09-26 00:00:00	\N	2017-10-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-09-26 16:47:58	2017-12-12 14:06:18
50993	50596	MAIREADJOINT	2011-03-13 00:00:00	\N	2014-04-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-26 16:51:04	2017-09-26 16:51:42
51406	50597	VICPDTGEN	2008-03-16 00:00:00	\N	2015-12-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-26 16:51:31	2017-09-26 16:55:12
51407	50598	CONSREG	2015-12-13 00:00:00	\N	2021-12-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-26 16:59:32	2017-09-26 17:00:21
51408	50599	CONSGENE	2006-11-26 00:00:00	\N	2008-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-26 17:05:03	2017-09-26 17:06:58
51410	50601	PDTINTCOM	2017-01-01 00:00:00	\N	2017-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-09-26 17:31:54	2018-01-24 11:12:39
51411	50602	VICPDTREG	2015-12-13 00:00:00	\N	2017-10-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-26 17:32:06	2017-12-05 14:06:58
51412	50603	CONSGENE	2004-03-28 00:00:00	\N	2015-03-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-26 17:33:00	2017-09-26 17:34:06
50943	50604	CONSMUNI	1989-03-19 00:00:00	\N	1995-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-26 17:35:04	2017-09-26 17:35:37
50880	50371	MAIREADJOINT	2008-03-16 00:00:00	\N	2010-08-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 14:01:48	2017-09-24 14:04:46
51305	50484	MAIRE	2008-03-16 00:00:00	\N	2017-10-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 19:25:49	2017-11-08 10:00:21
51308	50485	VICPDTINTCOM	2008-03-16 00:00:00	\N	2014-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-09-24 19:27:04	2017-09-24 19:28:17
51308	50486	PDTINTCOM	2014-03-30 00:00:00	\N	2017-10-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-09-24 19:27:51	2017-11-08 10:01:44
51314	50491	CONSGENE	2008-03-16 00:00:00	\N	2015-03-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 19:42:53	2017-09-24 19:44:04
50875	50493	VICPDTGEN	1994-01-01 00:00:00	\N	2008-03-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 19:44:50	2017-09-24 19:46:25
51317	50495	PDTINTCOM	1995-03-01 00:00:00	\N	2008-03-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-09-24 19:47:40	2017-09-24 19:49:07
51322	50501	MAIREADJOINT	2012-11-09 00:00:00	\N	2017-10-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 19:56:52	2017-11-08 17:42:48
51324	50503	PDTINTCOM	2014-03-30 00:00:00	\N	2017-10-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-09-24 19:58:22	2017-11-08 17:42:03
51326	50505	CONSREG	2015-12-13 00:00:00	\N	2017-10-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 19:59:20	2017-11-08 17:43:33
51327	50506	MAIRE	1999-11-25 00:00:00	\N	2008-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 20:02:47	2017-09-26 18:01:09
51329	50508	CONSMUNI	2008-03-16 00:00:00	\N	2017-10-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 20:02:56	2018-01-23 12:35:27
51331	50510	CONSGENE	2004-03-28 00:00:00	\N	2015-03-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 20:06:06	2017-09-24 20:07:15
51332	50511	VICPDTDPT	2015-03-29 00:00:00	\N	2017-10-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 20:07:41	2017-12-22 16:30:34
51336	50516	MAIRE	1989-03-19 00:00:00	\N	2018-04-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 20:22:58	2018-05-30 09:35:00
51337	50517	CONSGENE	2008-03-16 00:00:00	\N	2015-03-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 20:25:09	2017-09-24 20:26:10
43670	50810	CONSMUNI	2017-09-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-13 15:57:01	2017-11-13 15:57:19
51340	50520	VICPDTINTCOM	2014-03-30 00:00:00	\N	2015-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-09-24 20:28:29	2017-10-05 15:04:32
51345	50525	MAIREADJOINT	2014-03-30 00:00:00	\N	2018-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 20:33:26	2018-05-30 09:37:57
51345	50529	CONSMUNI	2008-03-16 00:00:00	\N	2014-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 20:35:23	2017-09-24 20:35:35
51350	50532	CONSCOMINT	2009-01-01 00:00:00	\N	2015-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-09-24 20:37:33	2017-09-24 20:38:34
51032	50811	CONSMUNI	2017-10-10 00:00:00	\N	2020-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-11-13 18:20:42	2017-11-13 18:20:52
51513	50812	VICPDTINTCOM	2017-01-01 00:00:00	\N	2017-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-11-13 18:34:43	2017-11-13 18:38:52
51513	50813	CONSCOMINT	2017-10-10 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	2017-11-13 18:38:55	2017-11-15 14:14:09
14133	50814	CONSMUNI	2017-10-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-13 18:54:01	2017-11-13 18:54:19
14133	50815	CONSMUNI	\N	1995	2006-06-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-11-13 18:54:23	2017-11-13 18:54:55
15184	50816	CONSDPT	2017-10-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-13 18:55:38	2017-11-13 18:55:49
15197	50818	CONSMUNI	2017-11-13 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-13 20:00:28	\N
11682	50819	CONSMUNI	2017-09-16 00:00:00	\N	2020-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-11-14 09:40:17	2017-11-14 09:40:35
51514	50820	VICPDTINTCOM	\N	\N	2017-09-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-11-14 09:41:17	2017-11-14 09:42:24
12489	50821	CONSMUNI	2017-10-17 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-14 09:44:50	2017-11-14 09:45:03
51211	50822	CONSMUNI	2017-10-14 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-14 10:31:05	2017-11-14 10:31:19
51213	50823	CONSDPT	2017-10-21 00:00:00	\N	2021-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-11-14 10:32:56	2017-11-14 10:33:13
11273	50824	CONSMUNI	2017-06-21 00:00:00	\N	2020-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-11-14 10:36:00	2017-11-14 10:36:26
51515	50825	MAIREADJOINT	1983-03-20 00:00:00	\N	2001-03-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-11-14 10:37:54	2017-11-14 10:39:25
12051	50826	CONSCOMINT	2017-01-10 00:00:00	\N	2020-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-11-14 11:17:08	2017-11-15 14:11:35
15159	50827	CONSDPT	2017-10-24 00:00:00	\N	2020-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-11-14 11:56:33	2017-11-14 11:56:53
51033	50828	CONSMUNI	2017-10-01 00:00:00	\N	2020-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-11-14 15:53:01	2017-11-14 15:53:12
13843	50829	CONSMUNI	2017-09-19 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-15 09:37:00	2017-11-15 09:37:08
13813	50830	CONSMUNI	2017-09-30 00:00:00	\N	2020-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-11-15 10:08:36	2017-11-15 10:08:48
11662	50831	CONSMUNI	2017-10-02 00:00:00	\N	2020-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-11-15 10:19:02	2017-11-15 10:19:18
11776	50832	CONSMUNI	2017-09-19 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-15 10:31:07	2017-11-15 10:31:24
13859	50833	CONSMUNI	2017-10-10 00:00:00	\N	2021-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-11-15 13:12:05	2017-11-15 13:12:13
13860	50834	CONSCOMINT	2017-01-03 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-15 13:13:29	2017-11-15 14:06:31
13927	50835	CONSMUNI	2017-09-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-15 17:53:48	2017-11-15 17:54:12
14196	50836	CONSMUNI	2017-06-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-16 10:38:25	2017-11-16 10:38:53
15164	50837	CONSDPT	2017-10-24 00:00:00	\N	2020-12-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-11-16 12:54:10	2017-11-16 12:55:15
13921	50838	CONSMUNI	2017-11-01 00:00:00	\N	2020-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-11-16 14:47:54	2017-11-16 14:48:11
50992	50839	CONSDPT	2017-10-24 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	2017-11-16 14:57:57	2017-11-16 14:58:20
51517	50842	CONSPARI	2001-03-18 00:00:00	\N	2001-03-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-11-16 15:50:21	2017-11-16 15:54:55
51517	50843	MAIREADJOINT	2001-03-25 00:00:00	\N	2008-03-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-11-16 15:52:34	2017-11-16 15:54:55
51517	50844	CONSPARI	2008-03-17 00:00:00	\N	2020-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-11-16 15:54:55	2017-11-16 15:55:25
15156	50845	CONSDPT	2017-09-26 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-16 16:40:28	2017-11-16 16:40:38
50972	50846	CONSMUNI	2017-10-05 00:00:00	\N	2021-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-11-16 18:51:12	2017-11-16 18:51:25
51215	50847	CONSCOMINT	2017-10-10 00:00:00	\N	2020-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-11-17 09:25:00	2017-11-17 09:38:58
51040	50848	CONSDPT	2017-10-25 00:00:00	\N	2021-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-11-17 11:03:58	2017-11-17 11:07:18
50880	50849	CONSMUNI	2017-10-25 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-20 11:18:37	2017-11-20 11:18:55
51520	50850	CONSCOMINT	2017-10-25 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	2017-11-20 11:19:03	2017-11-20 11:19:41
51344	50851	CONSMUNI	2017-10-24 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-20 11:45:54	2017-11-20 11:47:02
51430	50852	CONSCOMINT	2017-10-24 00:00:00	\N	2017-10-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-11-20 11:47:12	2018-01-12 14:43:48
51188	50853	CONSDPT	2017-10-24 00:00:00	\N	2021-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-11-20 14:43:56	2017-11-20 14:44:10
51457	50854	CONSMUNI	2017-10-02 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-21 18:27:43	2017-11-21 18:27:54
50817	50856	CONSMUNI	2017-10-18 00:00:00	\N	2020-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-11-21 18:32:52	2017-11-21 18:33:21
51523	50861	CONSCOMINT	2014-03-30 00:00:00	\N	2020-03-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-11-22 10:23:06	2017-11-22 10:29:00
14228	50860	CONSMUNI	2017-11-03 00:00:00	\N	2020-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-11-22 10:21:47	2017-11-22 10:21:54
51524	50862	CONSMET	2017-03-20 00:00:00	\N	2020-07-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-11-22 12:39:39	2017-11-22 12:40:24
51527	50864	CONSMUNI	2001-03-18 00:00:00	\N	2011-01-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-11-24 22:00:29	2017-11-24 22:02:10
51529	50867	VICPDTDPT	2015-03-30 00:00:00	\N	2017-10-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-11-24 22:06:57	2017-11-24 22:09:03
51528	50866	CONSGENE	2011-03-27 00:00:00	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-11-24 22:05:29	2017-11-24 22:06:51
34443	33040	DEPUTE	2002-06-25 00:00:00	\N	2002-06-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:33	\N
51529	50868	CONSDPT	2017-10-26 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-24 22:09:48	2017-11-24 22:10:10
51530	50869	PDTINTCOM	2017-01-01 00:00:00	\N	2017-12-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-11-24 22:10:27	2018-05-30 09:20:01
50953	50870	CONSMUNI	2017-11-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-27 12:40:38	2017-11-27 12:40:45
34377	32974	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:30	\N
34378	32975	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:30	\N
34379	32976	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:30	\N
34380	32977	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:30	\N
34381	32978	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:30	\N
34382	32979	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:30	\N
34383	32980	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:30	\N
34384	32981	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:30	\N
34385	32982	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:31	\N
34386	32983	SECAN	1987-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:31	\N
34387	32984	SECAN	1988-06-24 00:00:00	\N	1992-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:31	\N
34388	32985	SECAN	1992-10-21 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:31	\N
34389	32986	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:31	\N
34390	32987	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:31	\N
34391	32988	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:31	\N
34392	32989	SECAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:31	\N
34393	32990	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:31	\N
34394	32991	SECAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:31	\N
34395	32992	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:31	\N
34396	32993	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:31	\N
34397	32994	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:31	\N
34398	32995	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:31	\N
34399	32996	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:31	\N
34400	32997	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:31	\N
34401	32998	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:31	\N
34402	32999	DEPUTE	1986-04-02 00:00:00	\N	1986-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:31	\N
34403	33000	DEPUTE	1986-08-25 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:31	\N
34404	33001	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:31	\N
34405	33002	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:31	\N
34406	33003	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:31	\N
34407	33004	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:31	\N
34408	33005	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:31	\N
34409	33006	DEPUTE	2012-06-20 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:31	\N
34410	33007	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:31	\N
34411	33008	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:31	\N
34412	33009	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:32	\N
34413	33010	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:32	\N
34414	33011	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:32	\N
34415	33012	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:32	\N
34416	33013	DEPUTE	2002-06-25 00:00:00	\N	2002-06-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:32	\N
34417	33014	DEPUTE	2003-03-11 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:32	\N
34418	33015	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:32	\N
34419	33016	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:32	\N
34420	33017	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:32	\N
34421	33018	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:32	\N
34422	33019	DEPUTE	2006-06-07 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:32	\N
34423	33020	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:32	\N
34424	33021	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:32	\N
34425	33022	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:32	\N
34426	33023	DEPUTE	2007-06-20 00:00:00	\N	2008-04-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:32	\N
34427	33024	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:32	\N
34428	33025	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:32	\N
34429	33026	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:32	\N
34430	33027	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:32	\N
34431	33028	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:32	\N
34432	33029	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:32	\N
34433	33030	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:33	\N
34434	33031	DEPUTE	2007-06-20 00:00:00	\N	2008-03-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:33	\N
34435	33032	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:33	\N
34436	33033	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:33	\N
34437	33034	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:33	\N
34438	33035	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:33	\N
34439	33036	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:33	\N
34440	33037	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:33	\N
34441	33038	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:33	\N
34442	33039	DEPUTE	2012-06-20 00:00:00	\N	2016-01-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:33	\N
36141	34738	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:42	\N
34444	33041	DEPUTE	2007-07-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:33	\N
34445	33042	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:33	\N
34446	33043	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:33	\N
34447	33044	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:33	\N
34448	33045	DEPUTE	2017-01-07 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:33	\N
34449	33046	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:33	\N
34450	33047	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:33	\N
34451	33048	DEPUTE	2012-07-22 00:00:00	\N	2017-01-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:33	\N
34452	33049	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:33	\N
34453	33050	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:33	\N
34454	33051	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:33	\N
34455	33052	DEPUTE	2012-03-23 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:33	\N
34456	33053	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:34	\N
34457	33054	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:34	\N
34458	33055	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:34	\N
34459	33056	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:34	\N
34460	33057	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:34	\N
34461	33058	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:34	\N
34462	33059	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:34	\N
34463	33060	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:34	\N
34464	33061	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:34	\N
34465	33062	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:34	\N
34466	33063	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:34	\N
34467	33064	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:34	\N
34468	33065	DEPUTE	2005-07-03 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:34	\N
34469	33066	DEPUTE	2007-07-20 00:00:00	\N	2008-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:34	\N
35870	34467	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:28	\N
35871	34468	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:28	\N
35872	34469	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:28	\N
35873	34470	DEPUTE	2012-06-20 00:00:00	\N	2014-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:28	\N
35874	34471	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:28	\N
35875	34472	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:28	\N
35876	34473	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:28	\N
35877	34474	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:28	\N
35878	34475	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:28	\N
35879	34476	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:29	\N
35880	34477	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:29	\N
35881	34478	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:29	\N
35882	34479	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:29	\N
35883	34480	DEPUTE	2012-06-20 00:00:00	\N	2014-05-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:29	\N
35884	34481	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:29	\N
35885	34482	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:29	\N
35886	34483	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:29	\N
35887	34484	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:29	\N
35888	34485	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:29	\N
35889	34486	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:29	\N
35890	34487	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:29	\N
35891	34488	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:29	\N
35892	34489	DEPUTE	2012-06-20 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:30	\N
35893	34490	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:30	\N
35894	34491	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:30	\N
35895	34492	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:30	\N
35896	34493	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:30	\N
35897	34494	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:30	\N
35898	34495	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:30	\N
35899	34496	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:30	\N
35900	34497	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:30	\N
35901	34498	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:30	\N
35902	34499	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:30	\N
35903	34500	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:30	\N
35904	34501	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:30	\N
35905	34502	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:30	\N
35906	34503	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:30	\N
35907	34504	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:31	\N
35908	34505	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:31	\N
35909	34506	DEPUTE	2012-06-20 00:00:00	\N	2016-01-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:31	\N
35910	34507	DEPUTE	2012-06-26 00:00:00	\N	2016-01-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:31	\N
35911	34508	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:31	\N
35912	34509	DEPUTE	2012-06-20 00:00:00	\N	2014-07-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:31	\N
35913	34510	DEPUTE	2015-07-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:31	\N
35914	34511	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:31	\N
35915	34512	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:31	\N
35916	34513	DEPUTE	2012-06-20 00:00:00	\N	2016-03-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:31	\N
35917	34514	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:31	\N
35918	34515	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:31	\N
35919	34516	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:31	\N
35920	34517	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:31	\N
35921	34518	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:31	\N
35922	34519	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:31	\N
35923	34520	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:31	\N
35924	34521	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:31	\N
35925	34522	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:31	\N
35926	34523	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:32	\N
35927	34524	DEPUTE	2012-06-26 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:32	\N
35928	34525	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:32	\N
35929	34526	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:32	\N
35930	34527	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:32	\N
35931	34528	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:32	\N
35932	34529	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:32	\N
35933	34530	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:32	\N
35934	34531	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:32	\N
35935	34532	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:32	\N
35936	34533	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:32	\N
35937	34534	DEPUTE	2012-06-20 00:00:00	\N	2014-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:32	\N
35938	34535	DEPUTE	2012-06-20 00:00:00	\N	2012-06-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:32	\N
35939	34536	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:32	\N
35940	34537	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:32	\N
35941	34538	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:32	\N
35942	34539	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:32	\N
35943	34540	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:32	\N
35944	34541	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:32	\N
35945	34542	DEPUTE	2012-06-20 00:00:00	\N	2016-03-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:32	\N
35946	34543	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:32	\N
35947	34544	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:32	\N
35948	34545	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:32	\N
35949	34546	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:32	\N
35950	34547	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:32	\N
35951	34548	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:32	\N
35952	34549	DEPUTE	2012-06-20 00:00:00	\N	2016-03-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:32	\N
35953	34550	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:32	\N
35954	34551	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:32	\N
35955	34552	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:32	\N
35956	34553	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:32	\N
35957	34554	DEPUTE	2012-06-26 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:32	\N
35958	34555	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:32	\N
35959	34556	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:32	\N
35960	34557	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:32	\N
35961	34558	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:33	\N
35962	34559	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:33	\N
35963	34560	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:33	\N
49636	48232	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:46	\N
49637	48233	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:46	\N
49638	48234	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:46	\N
49639	48235	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:46	\N
49640	48236	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:46	\N
49641	48237	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:46	\N
49642	48238	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:46	\N
49643	48239	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:46	\N
49644	48240	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:46	\N
49645	48241	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:46	\N
49646	48242	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:46	\N
49647	48243	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:46	\N
49648	48244	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:46	\N
49649	48245	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:46	\N
49650	48246	DEPUTE	2012-06-20 00:00:00	\N	2016-02-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:46	\N
49651	48247	DEPUTE	2007-06-20 00:00:00	\N	2010-11-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:46	\N
49652	48248	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:46	\N
49653	48249	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:47	\N
49654	48250	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:47	\N
49655	48251	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:47	\N
49656	48252	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:47	2017-08-10 03:44:12
49657	48253	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:47	2017-08-10 10:57:41
49659	48255	DEPUTE	2007-06-26 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:47	2017-08-10 03:44:12
49660	48256	VICPDTAN	2016-05-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:47	2017-08-10 10:57:41
49661	48257	PDTAN	2017-06-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:47	2017-08-10 10:57:41
49662	48258	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:47	\N
49663	48259	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:47	\N
49664	48260	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:47	\N
49665	48261	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:47	\N
49666	48262	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:47	\N
49667	48263	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:47	\N
49668	48264	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:47	\N
49669	48265	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:47	\N
49670	48266	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:47	\N
49671	48267	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:47	\N
49672	48268	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:47	\N
49673	48269	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:47	\N
49674	48270	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:47	\N
49675	48271	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:47	\N
49676	48272	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:47	\N
49677	48273	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:47	\N
49678	48274	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:48	\N
49679	48275	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:48	\N
49680	48276	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:48	\N
49681	48277	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:48	\N
49682	48278	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:48	\N
49683	48279	DEPUTE	2007-06-20 00:00:00	\N	2009-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:48	2017-08-10 10:57:42
49684	48280	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:48	2017-08-10 10:57:42
49685	48281	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:48	\N
49686	48282	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:48	\N
49687	48283	DEPUTE	2012-06-20 00:00:00	\N	2015-07-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:48	2017-08-10 10:57:42
49688	48284	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:48	2017-08-10 10:57:42
49689	48285	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:48	\N
49690	48286	DEPUTE	2008-03-07 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:48	\N
49691	48287	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:48	\N
49692	48288	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:48	\N
49693	48289	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:48	\N
49694	48290	DEPUTE	2012-07-22 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:48	\N
49695	48291	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:48	\N
49696	48292	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:48	\N
49697	48293	DEPUTE	2010-06-07 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:48	\N
49698	48294	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:48	\N
49699	48295	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:48	\N
49700	48296	DEPUTE	2012-07-22 00:00:00	\N	2014-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:48	2017-08-07 03:44:10
49701	48297	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:48	\N
49702	48298	DEPUTE	2014-09-27 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:48	2017-08-07 03:44:10
49703	48299	DEPUTE	2017-03-22 00:00:00	\N	2017-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-07-25 10:46:48	2018-01-23 09:26:47
49704	48300	DEPUTE	2010-12-15 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:48	\N
49705	48301	DEPUTE	2009-11-04 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:48	\N
49706	48302	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:48	\N
49707	48303	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:48	\N
49708	48304	DEPUTE	2012-07-22 00:00:00	\N	2013-04-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:48	\N
49709	48305	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:48	\N
49710	48306	DEPUTE	2007-07-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:48	\N
49711	48307	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:48	\N
49712	48308	DEPUTE	2008-04-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:49	\N
49713	48309	DEPUTE	2014-05-10 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:49	\N
49714	48310	DEPUTE	2011-05-05 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:49	\N
49715	48311	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:49	\N
49716	48312	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:49	\N
49717	48313	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:49	\N
49718	48314	DEPUTE	2008-11-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:49	\N
49719	48315	DEPUTE	2012-06-20 00:00:00	\N	2016-04-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:49	\N
49720	48316	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:49	\N
49721	48317	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:49	\N
49722	48318	DEPUTE	2011-05-03 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:49	\N
49723	48319	DEPUTE	2010-04-01 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:49	\N
49724	48320	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:49	\N
49725	48321	DEPUTE	2016-05-30 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:49	\N
49726	48322	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:49	\N
49727	48323	DEPUTE	2008-06-02 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:49	\N
49728	48324	DEPUTE	2012-03-23 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:49	\N
50880	50372	CONSMUNI	2001-03-18 00:00:00	\N	2008-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 14:04:50	2017-09-24 14:07:58
51053	50743	CONSPARI	2017-10-06 00:00:00	\N	2020-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-11-08 15:41:16	2017-11-08 15:42:05
51400	50744	CONSDPT	2017-10-20 00:00:00	\N	2021-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-11-08 15:47:27	2017-11-08 15:47:59
15243	50746	CONSMUNI	2015-12-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-08 15:58:46	2017-11-08 15:59:43
15245	50749	MEMBREINTCOM	2015-12-31 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-08 16:01:45	2017-11-08 16:02:02
50940	50754	CONSMUNI	2017-10-02 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-08 17:35:46	2017-11-08 17:35:56
14227	50755	CONSMUNI	2017-10-12 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-08 17:38:35	2017-11-08 17:38:47
51324	50756	MEMBREINTCOM	2017-10-19 00:00:00	\N	2020-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-11-08 17:42:05	2017-11-08 17:42:30
51322	50757	CONSMUNI	2017-10-19 00:00:00	\N	2020-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-11-08 17:42:58	2017-11-08 17:43:09
14013	50758	CONSMUNI	2017-10-02 00:00:00	\N	2020-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-11-08 17:47:57	2017-11-08 17:48:06
14375	50759	MEMBREINTCOM	2017-10-02 00:00:00	\N	2020-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-11-08 17:50:30	2017-11-08 17:50:45
14276	50871	CONSMUNI	2017-09-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-27 20:08:20	2017-11-27 20:08:51
51534	50887	CONSGENE	1992-03-29 00:00:00	\N	1998-03-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-12-04 18:26:50	2017-12-04 18:31:01
15178	50888	CONSDPT	2017-10-01 00:00:00	\N	2021-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-12-04 18:30:19	2017-12-04 18:31:01
51534	50889	VICPDTGEN	1998-03-23 00:00:00	\N	2011-03-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-12-04 18:31:05	2017-12-04 18:41:07
51534	50892	PDTGEN	2011-03-31 00:00:00	\N	2015-03-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-12-04 18:41:11	2017-12-04 18:41:49
12480	50893	CONSMUNI	2017-10-11 00:00:00	\N	2020-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-12-04 19:10:46	2017-12-04 19:11:07
50840	50894	CONSMUNI	2017-10-11 00:00:00	\N	2020-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-12-04 21:44:30	2017-12-04 21:44:41
50843	50895	CONSDPT	2017-10-11 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-12-04 21:45:20	2017-12-04 21:45:32
51540	50901	VICPDTMET	2015-01-01 00:00:00	\N	2017-10-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-12-06 15:12:48	2017-12-06 15:15:17
14398	50903	CONSMUNI	2017-10-01 00:00:00	\N	2020-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-12-06 15:27:34	2017-12-06 15:27:44
51546	50911	MAIRE	1995-03-19 00:00:00	\N	2018-01-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-12-18 14:32:12	2018-02-16 16:07:31
51547	50912	CONSCOMINT	2005-12-21 00:00:00	\N	2020-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-12-18 14:35:36	2017-12-18 14:37:16
51550	50913	MAIRE	2014-03-30 00:00:00	\N	2018-01-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-12-18 14:53:20	2018-05-17 11:30:12
51550	50917	MAIREADJOINT	2008-03-16 00:00:00	\N	2014-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-12-18 14:56:18	2017-12-20 15:27:26
51554	50919	CONSREG	2015-12-13 00:00:00	\N	2018-01-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-12-18 14:57:51	2018-05-17 11:35:14
51555	50920	CONSREG	2010-03-30 00:00:00	\N	2015-12-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-12-18 14:59:30	2017-12-18 15:16:09
51546	50923	MAIREADJOINT	1989-03-19 00:00:00	\N	1995-03-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-12-20 18:02:55	2017-12-20 18:03:41
11037	50968	CONSMUNI	2017-10-24 00:00:00	\N	2020-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2018-01-24 19:32:04	2018-01-24 19:32:10
51296	50948	CONSCOMINT	2017-10-13 00:00:00	\N	2022-02-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2018-01-16 09:50:45	2018-01-16 09:54:00
51003	50969	CONSMUNI	2017-10-23 00:00:00	\N	2018-04-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2018-01-24 19:38:28	2018-01-24 19:38:34
14079	50970	CONSMUNI	2017-11-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2018-01-25 10:02:09	2018-01-25 10:02:16
11863	50975	CONSCOMINT	2017-01-22 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	2018-02-01 19:42:15	2018-02-01 19:42:36
51027	50996	CONSMUNI	2017-10-24 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2018-02-09 10:01:18	2018-02-09 10:01:27
51378	50995	CONSCOMINT	2017-11-02 00:00:00	\N	2021-06-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2018-02-09 09:54:58	2018-02-09 09:55:13
12146	50997	CONSMUNI	2017-10-03 00:00:00	\N	2020-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2018-02-13 12:36:05	2018-02-13 12:36:28
15332	50998	CONSCOMINT	2017-10-03 00:00:00	\N	2020-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2018-02-13 12:38:21	2018-02-13 12:42:18
51572	51015	DEPUTE	2018-03-26 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2018-03-28 03:44:10	\N
51583	51035	DEPUTE	2018-04-24 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2018-04-27 03:44:47	\N
50825	51018	CONSDPT	2017-10-21 00:00:00	\N	2021-07-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2018-03-29 00:01:24	2018-03-29 00:01:33
50842	51034	CONSMUNI	2018-04-11 00:00:00	\N	2020-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2018-04-26 14:57:18	2018-04-26 14:57:51
51550	51038	CONSMUNI	2018-01-03 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2018-05-17 11:30:28	2018-05-17 11:34:30
15292	51064	CONSREG	2017-11-24 00:00:00	\N	2021-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2018-06-08 14:56:07	2018-06-08 14:56:35
51268	51097	CONSMUNI	2017-10-20 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
51632	51109	MAIRE	2008-03-22 00:00:00	\N	2018-09-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51628	51101	CONSCOMINT	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
51656	51146	PDTINTCOM	2001-01-17 00:00:00	\N	2017-12-31 00:00:00	\N	ANCIEN	\N	Communauté de communes du Val Drouette	\N	\N	\N	\N
51654	51147	CONSCOMINT	2019-01-05 00:00:00	\N	\N	\N	ACTIF	\N	Communauté de communes des Portes Euréliennes d'Île-de-France	\N	\N	\N	\N
51653	51148	CONSMUNI	2019-01-05 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
51633	51110	VICPDTINTCOM	2012-11-14 00:00:00	\N	2017-11-15 00:00:00	\N	ANCIEN	Communauté de communes Cluses-Arve et Montagnes	Communauté de communes Cluses-Arve et Montagnes	\N	\N	\N	\N
51633	51111	CONSCOMINT	2017-11-16 00:00:00	\N	\N	\N	ACTIF	Communauté de communes Cluses-Arve et Montagnes	Communauté de communes Cluses-Arve et Montagnes	\N	\N	\N	\N
51636	51116	CONSCOMINT	2017-01-02 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
11018	51115	CONSMUNI	2017-10-02 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
13935	51120	CONSMUNI	2017-05-19 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
15173	51121	CONSDPT	2017-01-25 00:00:00	\N	2021-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
14349	51122	CONSCOMINT	2017-06-02 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
50697	51203	DEPUTE	2017-06-21 00:00:00	\N	2018-09-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50697	51204	PDTAN	2018-09-12 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51637	51126	DEPUTE	2018-10-01 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51640	51130	DEPUTE	2018-10-05 00:00:00	\N	2019-08-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51650	51140	DEPUTE	2018-11-26 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51666	51160	CONSGENE	2004-03-28 00:00:00	\N	2008-03-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51666	51162	VICPDTGEN	2008-03-17 00:00:00	\N	2015-03-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51668	51163	CONSDPT	2015-03-29 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
51676	51174	DEPUTE	2019-04-28 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51677	51175	DEPUTE	2019-04-28 00:00:00	\N	2021-05-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50398	51191	DEPUTE	2017-06-21 00:00:00	\N	2017-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50398	51192	SECAN	2017-06-28 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50730	51254	DEPUTE	2017-06-21 00:00:00	\N	2017-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50730	51255	VICPDTAN	2017-06-28 00:00:00	\N	2017-11-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50511	51195	DEPUTE	2017-06-21 00:00:00	\N	2017-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50511	51196	VICPDTAN	2017-06-28 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50592	51199	DEPUTE	2017-06-21 00:00:00	\N	2017-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50592	51200	VICPDTAN	2017-06-28 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50412	51201	DEPUTE	2017-06-21 00:00:00	\N	2017-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50412	51202	QUESTAN	2017-06-28 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50656	51252	DEPUTE	2017-06-21 00:00:00	\N	2019-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50656	51253	SECAN	2019-10-01 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
34470	33067	DEPUTE	2009-07-23 00:00:00	\N	2010-12-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:34	\N
34471	33068	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:34	\N
34472	33069	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:34	\N
34473	33070	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:34	\N
34474	33071	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:34	\N
34475	33072	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:34	\N
34476	33073	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:34	\N
34477	33074	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:34	\N
34478	33075	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:35	\N
34479	33076	DEPUTE	1978-04-03 00:00:00	\N	1978-05-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:35	\N
34480	33077	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:35	\N
34481	33078	DEPUTE	1973-04-02 00:00:00	\N	1973-05-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:35	\N
34482	33079	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:35	\N
34483	33080	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:35	\N
34484	33081	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:35	\N
34485	33082	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:35	\N
34486	33083	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:35	\N
34487	33084	DEPUTE	1988-06-13 00:00:00	\N	1991-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:35	\N
34488	33085	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:35	\N
34489	33086	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:35	\N
34490	33087	DEPUTE	2001-04-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:35	\N
34491	33088	DEPUTE	2007-06-20 00:00:00	\N	2007-10-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:35	\N
34492	33089	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:35	\N
34493	33090	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:35	\N
34494	33091	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:35	\N
34495	33092	SECAN	1988-06-24 00:00:00	\N	1991-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:35	\N
34496	33093	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:35	\N
34497	33094	DEPUTE	1980-11-30 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:35	\N
34498	33095	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:35	\N
34499	33096	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:35	\N
34500	33097	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:35	\N
34501	33098	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:35	\N
34502	33099	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:35	\N
34503	33100	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:36	\N
34504	33101	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:36	\N
34505	33102	DEPUTE	1988-06-13 00:00:00	\N	1991-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:36	\N
34506	33103	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:36	\N
34507	33104	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:36	\N
34508	33105	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:36	\N
34509	33106	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:36	\N
34510	33107	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:36	\N
34511	33108	DEPUTE	1988-06-13 00:00:00	\N	1989-06-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:36	\N
34512	33109	DEPUTE	1981-07-02 00:00:00	\N	1985-09-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:36	\N
34513	33110	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:36	\N
34514	33111	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:36	\N
34515	33112	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:36	\N
34516	33113	DEPUTE	1989-02-03 00:00:00	\N	1992-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:36	\N
34517	33114	DEPUTE	1993-04-02 00:00:00	\N	1996-07-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:36	\N
34518	33115	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:36	\N
34519	33116	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:37	\N
34520	33117	DEPUTE	1997-06-01 00:00:00	\N	1998-07-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:37	\N
34521	33118	DEPUTE	1997-06-01 00:00:00	\N	2000-04-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:37	\N
34522	33119	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:37	\N
34523	33120	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:37	\N
34524	33121	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:37	\N
34525	33122	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:37	\N
34526	33123	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:37	\N
34527	33124	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:37	\N
34528	33125	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:37	\N
34529	33126	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:37	\N
34530	33127	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:37	\N
34531	33128	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:37	\N
34532	33129	DEPUTE	1988-06-13 00:00:00	\N	1989-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:37	\N
34533	33130	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:37	\N
34534	33131	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:37	\N
34535	33132	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:37	\N
34536	33133	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:37	\N
34537	33134	DEPUTE	1983-01-09 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:37	\N
34538	33135	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:37	\N
34539	33136	DEPUTE	1988-06-13 00:00:00	\N	1988-11-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:37	\N
34540	33137	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:37	\N
34541	33138	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:37	\N
34542	33139	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:37	\N
34543	33140	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:37	\N
34544	33141	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:37	\N
34545	33142	SECAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:37	\N
34546	33143	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:37	\N
34547	33144	SECAN	2002-06-26 00:00:00	\N	2002-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:37	\N
34548	33145	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:38	\N
34549	33146	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:38	\N
34550	33147	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:38	\N
34551	33148	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:38	\N
34552	33149	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:38	\N
34553	33150	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:38	\N
34554	33151	DEPUTE	2012-06-20 00:00:00	\N	2017-03-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:38	\N
34555	33152	DEPUTE	1997-06-12 00:00:00	\N	1999-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:38	\N
34556	33153	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:38	\N
34557	33154	DEPUTE	2012-07-22 00:00:00	\N	2014-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:38	\N
34558	33155	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:38	\N
34559	33156	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:38	\N
34560	33157	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:38	\N
34561	33158	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:38	\N
34562	33159	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:38	\N
35964	34561	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:33	\N
35965	34562	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:33	\N
35966	34563	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:33	\N
35967	34564	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:33	\N
35968	34565	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:33	\N
35969	34566	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:33	\N
35970	34567	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:33	\N
35971	34568	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:33	\N
35972	34569	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:33	\N
35973	34570	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:33	\N
35974	34571	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:33	\N
35975	34572	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:33	\N
35976	34573	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:33	\N
35977	34574	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:33	\N
35978	34575	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:33	\N
35979	34576	DEPUTE	2012-06-20 00:00:00	\N	2014-05-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:33	\N
35980	34577	DEPUTE	2017-03-28 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:33	\N
35981	34578	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:33	\N
35982	34579	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:33	\N
35983	34580	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:33	\N
35984	34581	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:33	\N
35985	34582	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:34	\N
35986	34583	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:34	\N
35987	34584	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:34	\N
35988	34585	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:34	\N
35989	34586	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:34	\N
35990	34587	DEPUTE	2012-06-26 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:34	\N
35991	34588	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:34	\N
35992	34589	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:34	\N
35993	34590	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:34	\N
35994	34591	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:34	\N
35995	34592	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:34	\N
35996	34593	DEPUTE	2012-06-20 00:00:00	\N	2014-04-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:34	\N
35997	34594	DEPUTE	2012-06-20 00:00:00	\N	2013-02-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:34	\N
35998	34595	DEPUTE	2012-06-20 00:00:00	\N	2014-05-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:34	\N
35999	34596	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:34	\N
36000	34597	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:34	\N
36001	34598	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:34	\N
36002	34599	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:34	\N
36003	34600	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:34	\N
36004	34601	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:34	\N
36005	34602	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:34	\N
36006	34603	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:34	\N
36007	34604	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:34	\N
36008	34605	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:34	\N
36009	34606	DEPUTE	2012-06-20 00:00:00	\N	2016-03-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:34	\N
36010	34607	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:34	\N
36011	34608	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:34	\N
36012	34609	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:35	\N
36013	34610	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:35	\N
36014	34611	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:35	\N
36015	34612	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:35	\N
36016	34613	DEPUTE	2012-06-20 00:00:00	\N	2013-02-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:35	\N
36017	34614	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:35	\N
36018	34615	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:35	\N
36019	34616	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:35	\N
36020	34617	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:35	\N
36021	34618	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:35	\N
36022	34619	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:35	\N
36023	34620	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:35	\N
36024	34621	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:35	\N
36025	34622	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:35	\N
36026	34623	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:35	\N
36027	34624	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:35	\N
36028	34625	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:35	\N
36029	34626	DEPUTE	2012-06-20 00:00:00	\N	2012-10-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:35	\N
36030	34627	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:36	\N
36031	34628	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:36	\N
36032	34629	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:36	\N
36033	34630	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:36	\N
36034	34631	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:36	\N
36035	34632	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:36	\N
36036	34633	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:36	\N
36037	34634	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:36	\N
36038	34635	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:36	\N
36039	34636	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:36	\N
36040	34637	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:36	\N
36041	34638	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:36	\N
36042	34639	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:36	\N
36043	34640	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:37	\N
36044	34641	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:37	\N
36045	34642	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:37	\N
36046	34643	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:37	\N
36047	34644	DEPUTE	2012-06-20 00:00:00	\N	2015-07-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:37	\N
36048	34645	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:37	\N
36049	34646	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:37	\N
36050	34647	DEPUTE	2012-06-20 00:00:00	\N	2013-01-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:37	\N
36051	34648	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:37	\N
36052	34649	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:37	\N
36053	34650	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:37	\N
36054	34651	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:37	\N
36055	34652	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:37	\N
36056	34653	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:38	\N
36057	34654	DEPUTE	2012-07-22 00:00:00	\N	2016-03-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:38	\N
49729	48325	DEPUTE	2012-06-20 00:00:00	\N	2017-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:49	\N
49730	48326	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:49	\N
49731	48327	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:49	\N
49732	48328	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:49	\N
49733	48329	DEPUTE	2008-04-20 00:00:00	\N	2009-07-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:49	\N
49734	48330	DEPUTE	2009-01-13 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:49	\N
49735	48331	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:49	\N
49736	48332	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:49	\N
49737	48333	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:49	\N
49738	48334	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:49	\N
49739	48335	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:49	\N
49740	48336	DEPUTE	2008-12-15 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:49	\N
49741	48337	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:49	\N
49742	48338	DEPUTE	2008-02-04 00:00:00	\N	2008-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:49	\N
49743	48339	DEPUTE	2007-12-16 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:49	\N
49744	48340	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:50	\N
49745	48341	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:50	\N
49746	48342	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:50	\N
49747	48343	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:50	\N
49748	48344	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:50	\N
49749	48345	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:50	2017-08-10 10:57:43
49750	48346	DEPUTE	2014-05-03 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:50	2017-08-10 10:57:43
49751	48347	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:50	\N
49752	48348	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:50	\N
49753	48349	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:50	\N
49754	48350	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:50	\N
49755	48351	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:50	\N
49756	48352	DEPUTE	2008-04-13 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:50	\N
49757	48353	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:50	\N
49758	48354	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:50	\N
49759	48355	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:50	\N
49760	48356	DEPUTE	2009-10-19 00:00:00	\N	2011-07-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:50	\N
49761	48357	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:50	\N
49762	48358	DEPUTE	2011-07-30 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:50	\N
49763	48359	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:50	\N
49764	48360	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:50	\N
49765	48361	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:50	\N
49766	48362	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:50	\N
49767	48363	DEPUTE	2010-07-12 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:50	\N
49768	48364	DEPUTE	2016-03-21 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:50	\N
49769	48365	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:50	\N
49770	48366	DEPUTE	2016-03-21 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:50	\N
49771	48367	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:50	\N
49772	48368	DEPUTE	2016-03-21 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:50	\N
49774	48370	SECAN	2017-06-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:50	2017-08-10 10:57:44
49775	48371	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:50	\N
49776	48372	DEPUTE	1968-07-11 00:00:00	\N	1968-08-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:50	\N
49777	48373	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:50	2017-08-10 03:44:15
49778	48374	DEPUTE	2014-05-03 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:51	2017-08-10 03:44:15
49780	48376	SECAN	2017-06-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:51	2017-08-07 03:44:12
49781	48377	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:51	2017-08-10 10:57:44
49782	48378	DEPUTE	2017-06-21 00:00:00	\N	2018-07-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:51	\N
49783	48379	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:51	2017-08-10 10:57:44
49784	48380	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:51	2017-08-10 10:57:44
49785	48381	DEPUTE	2014-12-22 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:51	2017-08-10 10:57:44
49786	48382	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:51	2017-08-09 03:44:31
49787	48383	DEPUTE	2014-09-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:51	2017-08-09 03:44:31
49788	48384	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:51	2017-08-08 03:44:40
49789	48385	DEPUTE	2014-05-03 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:51	2017-08-08 03:44:40
49791	48387	SECAN	1987-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:51	2017-08-10 03:44:15
49792	48388	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:51	\N
49793	48389	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:51	\N
49794	48390	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:51	\N
49795	48391	DEPUTE	2007-06-20 00:00:00	\N	2010-04-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:51	2017-08-09 03:44:31
49796	48392	DEPUTE	2011-06-30 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:51	2017-08-09 03:44:31
49797	48393	DEPUTE	2011-10-28 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:51	\N
49798	48394	DEPUTE	2009-07-23 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:51	\N
49799	48395	DEPUTE	2010-06-11 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:51	\N
49800	48396	DEPUTE	2017-06-21 00:00:00	\N	2020-08-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:51	\N
49801	48397	DEPUTE	2010-12-15 00:00:00	\N	2012-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:51	\N
49802	48398	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:51	\N
49803	48399	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:51	\N
49804	48400	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:51	\N
49805	48401	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:51	\N
49806	48402	DEPUTE	2007-06-20 00:00:00	\N	2011-05-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:51	\N
49807	48403	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:52	\N
49808	48404	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:52	\N
49809	48405	DEPUTE	2012-06-20 00:00:00	\N	2014-05-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:52	2017-08-10 10:57:44
49810	48406	DEPUTE	2014-06-30 00:00:00	\N	2014-07-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:52	2017-08-10 10:57:44
49811	48407	DEPUTE	2017-06-21 00:00:00	\N	2017-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:52	\N
49812	48408	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:52	\N
49813	48409	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:52	\N
49814	48410	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:52	\N
49815	48411	DEPUTE	2014-09-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:52	2017-08-10 10:57:45
49816	48412	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:52	2017-08-10 10:57:45
49817	48413	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:52	\N
49818	48414	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:52	\N
49819	48415	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:52	\N
49820	48416	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:52	\N
49821	48417	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:52	\N
49822	48418	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:52	2017-08-08 03:44:41
14027	50873	CONSMUNI	2017-10-24 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-28 10:17:11	2017-11-28 10:17:25
14034	50877	CONSMUNI	2017-11-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-29 09:51:39	2017-11-29 09:52:05
51065	50904	CONSMUNI	2017-09-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-12-07 10:13:08	2017-12-07 10:13:19
51532	50881	CONSDPT	2014-06-25 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-12-01 09:50:43	2017-12-01 09:53:01
51541	50905	CONSCOMINT	2014-03-30 00:00:00	\N	\N	\N	ACTIF	Agglomération Provence Verte	Agglomération Provence Verte	\N	\N	2017-12-07 10:13:56	2017-12-07 10:16:21
51551	50914	MAIREADJOINT	1995-06-18 00:00:00	\N	2008-03-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-12-18 14:53:29	2017-12-18 14:54:35
51551	50915	MAIRE	2008-03-17 00:00:00	\N	2018-01-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-12-18 14:54:36	2018-02-13 14:38:55
51552	50916	PDTINTCOM	2008-03-17 00:00:00	\N	2016-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-12-18 14:55:18	2017-12-18 14:56:31
51553	50918	PDTINTCOM	2017-01-01 00:00:00	\N	2018-01-11 00:00:00	\N	ANCIEN	Communauté de communes Vienne et Gartempe	Communauté de communes Vienne et Gartempe	\N	\N	2017-12-18 14:56:35	2018-02-13 14:45:18
51653	51141	MAIRE	2001-03-18 00:00:00	\N	2019-01-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51654	51142	PDTINTCOM	2017-01-12 00:00:00	\N	2019-01-04 00:00:00	\N	ANCIEN	Portes Euréliennes d'Île-de-France	Communauté de communes des Portes Euréliennes d'Île-de-France	\N	\N	\N	\N
51558	50930	DEPUTE	2017-12-25 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-12-26 03:44:34	\N
51559	50931	VICPDTGEN	2001-03-18 00:00:00	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2018-01-02 10:47:12	2018-01-02 10:50:25
51266	50941	CONSPARI	2008-03-16 00:00:00	\N	2020-03-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2018-01-10 14:38:09	2018-01-10 14:38:42
50962	50945	CONSMUNI	2017-11-17 00:00:00	\N	2020-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2018-01-12 14:53:20	2018-01-12 14:56:39
51390	50946	MEMBREINTCOM	2017-11-10 00:00:00	\N	2020-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2018-01-12 14:58:42	2018-01-12 15:11:04
50421	50977	DEPUTE	2017-06-21 00:00:00	\N	2018-02-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2018-02-06 03:44:52	\N
50421	50978	SECAN	2018-02-01 00:00:00	\N	2018-04-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2018-02-06 03:44:52	2018-04-06 03:44:52
50421	50979	DEPUTE	2018-04-04 00:00:00	\N	2021-09-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2018-02-06 03:44:52	2018-04-06 03:44:52
50596	50980	DEPUTE	2017-06-21 00:00:00	\N	2018-02-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2018-02-06 03:44:57	\N
50596	50981	SECAN	2018-02-01 00:00:00	\N	2018-04-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2018-02-06 03:44:57	2018-04-06 03:44:57
50596	50982	DEPUTE	2018-04-04 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2018-02-06 03:44:57	2018-04-06 03:44:57
51692	51225	CONSMUNI	2014-03-30 00:00:00	\N	2019-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51693	51226	CONSDPT	2008-03-16 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
51695	51227	CONSCOMINT	2017-01-01 00:00:00	\N	2019-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
12532	51283	CONSMUNI	2017-10-01 00:00:00	\N	2020-03-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51700	51284	CONSCOMINT	2016-05-20 00:00:00	\N	2020-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	\N
51093	50988	CONSMUNI	2017-12-23 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2018-02-06 12:21:16	2018-02-06 12:21:45
51565	50990	DEPUTE	2018-02-05 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2018-02-07 03:44:47	\N
51566	50991	DEPUTE	2018-02-05 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2018-02-07 03:45:13	\N
51182	50992	CONSMUNI	2017-10-19 00:00:00	\N	2020-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2018-02-08 15:14:37	2018-02-08 15:14:46
51551	50999	CONSMUNI	2018-01-12 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2018-02-13 14:39:00	2018-02-13 14:44:15
51469	51031	CONSMUNI	2017-10-16 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2018-04-18 15:13:04	2018-04-18 15:13:34
51553	51001	CONSCOMINT	2018-01-12 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2018-02-13 14:45:31	2018-02-13 14:50:09
50990	51003	CONSMUNI	2017-11-25 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2018-02-16 16:01:51	2018-02-16 16:02:09
51546	51004	CONSMUNI	2018-01-12 00:00:00	\N	2020-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2018-02-16 16:07:33	2018-02-16 16:07:52
51011	51005	CONSMUNI	2017-09-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2018-02-16 16:13:19	2018-02-16 16:13:26
50814	51017	CONSDPT	2017-10-16 00:00:00	\N	2021-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2018-03-28 18:07:15	2018-03-28 18:07:45
51581	51032	DEPUTE	2018-04-16 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2018-04-19 03:44:58	\N
51582	51033	DEPUTE	2018-04-23 00:00:00	\N	2021-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2018-04-26 03:44:45	\N
50950	51040	CONSMUNI	2017-10-06 00:00:00	\N	2020-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2018-05-30 09:24:13	2018-05-30 09:24:41
51415	51041	CONSCOMINT	2017-10-06 00:00:00	\N	2020-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2018-05-30 09:25:58	2018-05-30 09:26:27
12188	51042	CONSMUNI	2017-10-17 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2018-05-30 09:30:43	2018-05-30 09:31:03
12507	51043	CONSCOMINT	2017-10-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2018-05-30 09:31:50	2018-05-30 09:32:22
51336	51044	CONSMUNI	2018-04-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2018-05-30 09:35:05	2018-05-30 09:35:20
36142	34739	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:42	\N
51345	51045	CONSMUNI	2018-05-06 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2018-05-30 09:38:01	2018-05-30 09:38:12
14360	51046	CONSMUNI	2017-10-02 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2018-05-30 09:43:39	2018-05-30 09:44:01
51199	51047	CONSMUNI	2017-10-17 00:00:00	\N	\N	2021	ANCIEN	\N	Nouvelle fonction	\N	NON	2018-05-30 09:52:15	2018-05-30 09:52:47
14364	51048	CONSMUNI	2017-09-12 00:00:00	\N	2020-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2018-05-30 09:55:27	2018-05-30 09:55:41
51590	51054	CONSARR	2017-10-07 00:00:00	\N	2020-06-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2018-05-30 10:13:07	2018-05-30 10:13:47
50877	51055	CONSMUNI	2017-12-13 00:00:00	\N	2021-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2018-05-30 10:16:54	2018-05-30 10:17:14
51403	51056	CONSCOMINT	2018-04-17 00:00:00	\N	2021-07-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2018-05-30 10:17:46	2018-05-30 10:18:09
50985	51057	CONSMUNI	2017-10-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2018-05-30 16:11:48	2018-05-30 16:12:12
50827	51062	CONSMUNI	2017-10-02 00:00:00	\N	2020-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2018-06-06 10:15:25	2018-06-06 10:15:45
51617	51085	MAIREADJOINT	1989-03-19 00:00:00	\N	2017-07-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51617	51086	CONSMUNI	2017-07-18 00:00:00	\N	2020-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51618	51087	CONSDPT	2011-03-27 00:00:00	\N	2014-12-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
14174	51090	CONSMUNI	2017-10-01 00:00:00	\N	2020-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51619	51089	CONSMET	2015-01-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
51623	51091	VICPDTMET	2016-01-01 00:00:00	\N	2017-09-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
6205	51134	MAIRE	2018-11-05 00:00:00	\N	2023-11-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
46977	51143	DEPUTE	2017-06-21 00:00:00	\N	2018-07-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
46977	51144	VICPDTAN	2018-07-17 00:00:00	\N	2019-01-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51655	51145	DEPUTE	2019-01-10 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
15322	51285	CONSMET	2018-01-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
51710	51294	DEPUTE	2020-03-17 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51708	51293	DEPUTE	2020-02-12 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51725	51320	DEPUTE	2020-05-29 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
51149	51352	CONSMUNI	2020-06-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
51712	51319	CONSDPT	2019-10-02 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
14242	51334	MAIRE	2020-07-04 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
12146	51353	CONSMUNI	2020-06-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
15332	51354	CONSCOMINT	2020-06-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
12515	51355	CONSMUNI	2020-06-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
51754	51358	CONSCOMINT	2020-05-18 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
50893	51357	CONSMUNI	2020-05-18 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
51755	51359	CONSMUNI	2020-03-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
51613	51360	CONSMUNI	2020-06-28 00:00:00	\N	2023-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51756	51361	CONSCOMINT	2020-06-28 00:00:00	\N	2023-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
14398	51364	CONSMUNI	2020-06-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
50955	51365	CONSMUNI	2020-06-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
50962	51366	CONSMUNI	2020-06-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
51390	51367	MEMBREINTCOM	2020-06-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
51760	51368	DEPUTE	2020-07-14 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
34563	33160	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:38	\N
34564	33161	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:38	\N
34565	33162	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:38	\N
34566	33163	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:38	\N
34567	33164	DEPUTE	1991-06-17 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:38	\N
34568	33165	DEPUTE	1981-07-23 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:38	\N
34569	33166	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:38	\N
34570	33167	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:38	\N
34571	33168	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:38	\N
34572	33169	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:38	\N
34573	33170	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:38	\N
34574	33171	DEPUTE	2002-06-19 00:00:00	\N	2006-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:38	\N
34575	33172	DEPUTE	1997-05-25 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:38	\N
34576	33173	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34577	33174	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34578	33175	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34579	33176	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34580	33177	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34581	33178	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34582	33179	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34583	33180	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34584	33181	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34585	33182	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34586	33183	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34587	33184	DEPUTE	1976-11-15 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34588	33185	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34589	33186	DEPUTE	1968-08-13 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34590	33187	DEPUTE	1973-04-02 00:00:00	\N	1976-02-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34591	33188	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34592	33189	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34593	33190	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34594	33191	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34595	33192	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34596	33193	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34597	33194	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34598	33195	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34599	33196	DEPUTE	1995-11-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34600	33197	DEPUTE	1976-02-13 00:00:00	\N	1976-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34601	33198	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34602	33199	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34603	33200	DEPUTE	1978-04-02 00:00:00	\N	1980-09-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34604	33201	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34605	33202	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34606	33203	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34607	33204	DEPUTE	1997-06-01 00:00:00	\N	2000-11-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34608	33205	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34609	33206	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34610	33207	DEPUTE	1997-06-01 00:00:00	\N	2000-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34611	33208	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34612	33209	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34613	33210	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34614	33211	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34615	33212	QUESTAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34616	33213	SECAN	2010-10-05 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34617	33214	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34618	33215	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34619	33216	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34620	33217	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34621	33218	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34622	33219	SECAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34623	33220	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34624	33221	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34625	33222	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34626	33223	SECAN	2002-06-26 00:00:00	\N	2004-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34627	33224	SECAN	2009-10-06 00:00:00	\N	2010-10-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34628	33225	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34629	33226	DEPUTE	1993-04-02 00:00:00	\N	1995-09-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34630	33227	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34631	33228	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:39	\N
34632	33229	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:40	\N
34633	33230	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:40	\N
34634	33231	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:40	\N
34635	33232	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:40	\N
34636	33233	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:40	\N
34637	33234	DEPUTE	1986-04-02 00:00:00	\N	1986-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:40	\N
34638	33235	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:40	\N
34639	33236	DEPUTE	1980-10-27 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:40	\N
34640	33237	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:40	\N
34641	33238	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:40	\N
34642	33239	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:40	\N
34643	33240	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:40	\N
34644	33241	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:40	\N
34645	33242	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:40	\N
34646	33243	DEPUTE	1995-06-18 00:00:00	\N	1995-12-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:40	\N
34647	33244	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:40	\N
34648	33245	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:40	\N
34649	33246	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:40	\N
34650	33247	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:40	\N
34651	33248	DEPUTE	1980-11-30 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:40	\N
34652	33249	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:40	\N
34653	33250	DEPUTE	1988-06-13 00:00:00	\N	1992-06-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:40	\N
34654	33251	DEPUTE	1987-12-17 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:40	\N
34655	33252	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:40	\N
36058	34655	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:38	\N
36059	34656	DEPUTE	2012-07-22 00:00:00	\N	2014-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:38	\N
36060	34657	DEPUTE	2014-06-02 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:38	\N
36061	34658	DEPUTE	2014-07-04 00:00:00	\N	2015-07-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:38	\N
36062	34659	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:38	\N
36063	34660	DEPUTE	2012-07-22 00:00:00	\N	2015-04-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:38	\N
36064	34661	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:38	\N
36065	34662	DEPUTE	2014-10-05 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:38	\N
36066	34663	DEPUTE	2012-07-22 00:00:00	\N	2017-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:38	\N
36067	34664	DEPUTE	2012-07-22 00:00:00	\N	2014-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:38	\N
36068	34665	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:38	\N
36069	34666	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:38	\N
36070	34667	DEPUTE	2016-04-16 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:38	\N
36071	34668	DEPUTE	2014-05-10 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:38	\N
36072	34669	DEPUTE	2014-05-10 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:38	\N
36073	34670	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:38	\N
36074	34671	DEPUTE	2012-07-22 00:00:00	\N	2016-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:38	\N
36075	34672	DEPUTE	2015-08-28 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:38	\N
36076	34673	DEPUTE	2017-06-16 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:38	\N
36077	34674	DEPUTE	2016-03-12 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:39	\N
36078	34675	DEPUTE	2012-07-22 00:00:00	\N	2014-07-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:39	\N
36079	34676	DEPUTE	2012-07-22 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:39	\N
36080	34677	DEPUTE	2014-09-27 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:39	\N
36081	34678	DEPUTE	2014-07-04 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:39	\N
36082	34679	DEPUTE	2017-01-07 00:00:00	\N	2017-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:39	\N
36083	34680	DEPUTE	2014-05-10 00:00:00	\N	2017-03-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:39	\N
36084	34681	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:39	\N
36085	34682	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:39	\N
36086	34683	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:39	\N
36087	34684	DEPUTE	2012-07-22 00:00:00	\N	2014-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:39	\N
36088	34685	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:39	\N
36089	34686	DEPUTE	2016-03-12 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:39	\N
36090	34687	DEPUTE	2016-03-12 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:39	\N
36091	34688	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:39	\N
36092	34689	DEPUTE	2015-07-18 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:39	\N
36093	34690	DEPUTE	2016-06-13 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:39	\N
36094	34691	DEPUTE	2016-03-12 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:39	\N
36095	34692	DEPUTE	2012-12-17 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:39	\N
36096	34693	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:39	\N
36097	34694	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:40	\N
36098	34695	DEPUTE	2014-05-10 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:40	\N
36099	34696	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:40	\N
36100	34697	DEPUTE	2013-08-03 00:00:00	\N	2014-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:40	\N
36101	34698	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:40	\N
36102	34699	DEPUTE	2013-03-24 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:40	\N
36103	34700	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:40	\N
36104	34701	DEPUTE	2013-06-10 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:40	\N
36105	34702	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:40	\N
36106	34703	DEPUTE	2013-06-24 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:40	\N
36107	34704	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:40	\N
36108	34705	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:40	\N
36109	34706	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:40	\N
36110	34707	DEPUTE	2016-04-25 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:40	\N
36111	34708	DEPUTE	2016-05-30 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:40	\N
36112	34709	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:40	\N
36113	34710	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:40	\N
36114	34711	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:40	\N
36115	34712	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:40	\N
36116	34713	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:40	\N
36117	34714	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:40	\N
36118	34715	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:41	\N
36119	34716	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:41	\N
36120	34717	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:41	\N
36121	34718	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:41	\N
36122	34719	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:41	\N
36123	34720	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:41	\N
36124	34721	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:41	\N
36125	34722	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:41	\N
36126	34723	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:41	\N
36127	34724	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:41	\N
36128	34725	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:41	\N
36129	34726	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:41	\N
36130	34727	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:41	\N
36131	34728	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:41	\N
36132	34729	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:41	\N
36133	34730	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:41	\N
36134	34731	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:41	\N
36135	34732	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:42	\N
36136	34733	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:42	\N
36137	34734	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:42	\N
36138	34735	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:42	\N
36139	34736	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:42	\N
36140	34737	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:42	\N
36143	34740	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:42	\N
36144	34741	DEPUTE	2015-09-14 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:42	\N
36145	34742	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:42	\N
36146	34743	DEPUTE	1968-09-06 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:42	\N
36147	34744	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:42	\N
36148	34745	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:42	\N
36149	34746	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:42	\N
36150	34747	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:42	\N
36151	34748	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:42	\N
36152	34749	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:42	\N
36153	34750	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:43	\N
49823	48419	DEPUTE	2015-04-06 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:52	2017-08-08 03:44:41
49824	48420	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:52	\N
49825	48421	DEPUTE	2012-06-20 00:00:00	\N	2017-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:52	\N
49826	48422	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:52	\N
49827	48423	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:52	\N
49828	48424	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:52	\N
49829	48425	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:53	\N
49830	48426	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:53	\N
49831	48427	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:53	\N
49832	48428	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:53	\N
49833	48429	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:53	\N
49834	48430	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:53	\N
49835	48431	DEPUTE	2007-06-20 00:00:00	\N	2008-03-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:53	\N
49836	48432	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:53	\N
49837	48433	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:53	\N
49838	48434	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:53	\N
49839	48435	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:53	\N
49840	48436	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:53	\N
49841	48437	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:53	\N
49842	48438	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:53	\N
49843	48439	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:53	\N
49844	48440	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:53	\N
49845	48441	DEPUTE	2017-06-21 00:00:00	\N	2020-08-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:53	\N
49846	48442	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:53	\N
49847	48443	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:53	2017-08-10 10:57:45
49848	48444	DEPUTE	2014-09-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:53	2017-08-10 10:57:45
49849	48445	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:53	\N
49850	48446	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:53	\N
49851	48447	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:53	\N
49852	48448	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:54	\N
49853	48449	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:54	\N
49854	48450	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:54	\N
49855	48451	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:54	\N
49857	48453	VICPDTAN	2011-10-03 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:54	2017-08-10 10:57:46
49858	48454	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:54	\N
49859	48455	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:54	\N
49860	48456	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:54	\N
49863	48459	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:54	\N
49864	48460	DEPUTE	2017-06-21 00:00:00	\N	2017-12-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:54	2017-12-26 03:44:23
49865	48461	DEPUTE	2007-06-26 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:54	2017-08-09 03:44:33
49866	48462	SECAN	2007-06-27 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:54	2017-08-09 03:44:33
49867	48463	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:54	\N
49868	48464	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:54	\N
49869	48465	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:54	\N
49870	48466	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:54	\N
49871	48467	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:54	\N
49872	48468	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:54	2017-08-08 03:44:43
49873	48469	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:54	\N
49874	48470	DEPUTE	2017-06-21 00:00:00	\N	2018-11-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:54	\N
49875	48471	DEPUTE	2007-06-26 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:54	2017-08-08 03:44:43
49876	48472	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:54	\N
49877	48473	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:54	\N
49878	48474	DEPUTE	2017-06-21 00:00:00	\N	2020-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:54	\N
49879	48475	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:55	\N
49880	48476	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:55	\N
49881	48477	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:55	\N
49882	48478	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:55	\N
49883	48479	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:55	\N
36157	34754	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:43	\N
49884	48480	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:55	\N
49885	48481	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:55	\N
49886	48482	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:55	\N
49887	48483	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:55	\N
49888	48484	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:55	\N
49889	48485	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:55	\N
49890	48486	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:55	\N
49891	48487	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:55	\N
49892	48488	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:55	\N
49893	48489	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:55	\N
49894	48490	DEPUTE	2016-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:55	2017-08-10 03:44:17
49895	48491	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:55	2017-08-10 03:44:17
49896	48492	DEPUTE	2017-06-21 00:00:00	\N	2020-11-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:55	\N
49897	48493	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:55	\N
49898	48494	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:55	2017-08-10 10:57:46
49899	48495	DEPUTE	2014-07-04 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:55	2017-08-10 10:57:46
49900	48496	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:55	\N
49901	48497	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:55	\N
49902	48498	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:55	\N
49903	48499	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:55	\N
49904	48500	DEPUTE	2013-08-03 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:55	2017-08-10 10:57:47
49905	48501	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:55	2017-08-10 10:57:47
49906	48502	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:55	\N
49907	48503	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:55	\N
49909	48505	VICPDTAN	2012-06-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:55	2017-08-10 03:44:17
49910	48506	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:55	\N
49911	48507	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:55	\N
49912	48508	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:55	\N
49913	48509	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:55	\N
49914	48510	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:55	\N
49915	48511	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:55	\N
49916	48512	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:55	\N
51525	50863	CONSDPT	2015-04-02 00:00:00	\N	2017-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-11-22 19:46:35	2017-11-22 19:48:23
14286	50872	CONSCOMINT	2017-09-29 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	2017-11-27 20:09:39	2017-11-27 20:09:56
50922	50874	CONSDPT	2017-11-18 00:00:00	\N	2021-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-11-28 14:46:59	2017-11-28 14:47:06
11669	50878	CONSMUNI	2017-10-02 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-30 16:52:57	2017-11-30 16:53:16
51531	50876	CONSMUNI	2017-09-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-11-28 16:14:11	2017-11-28 16:15:23
51639	51129	CONSINTCOM	2017-10-02 00:00:00	\N	\N	\N	ACTIF	de la communauté territoriale du Pays d'Aix	Nouvelle fonction	\N	\N	\N	\N
14344	50882	CONSMUNI	2017-09-14 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-12-01 14:49:16	2017-12-01 14:49:28
14345	50883	CONSCOMINT	2017-09-27 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	2017-12-01 14:49:53	2017-12-01 14:50:08
10986	50884	CONSMUNI	2017-10-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-12-04 16:53:52	2017-12-04 16:54:01
51533	50885	CONSINTCOM	2017-01-01 00:00:00	\N	\N	\N	ACTIF	territorial	territorial de Grand Paris - Grand Est	\N	\N	2017-12-04 17:03:33	2017-12-04 17:30:18
50839	50886	CONSDPT	2017-10-24 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-12-04 18:15:18	2017-12-04 18:15:45
50884	50891	CONSDPT	2017-10-31 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-12-04 18:39:32	2017-12-04 18:39:46
51411	50896	CONSREG	2017-10-20 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-12-05 14:07:03	2017-12-05 14:07:47
51488	50897	CONSMUNI	2017-10-10 00:00:00	\N	2020-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-12-06 12:48:45	2017-12-06 12:48:58
50543	50907	SECAN	2017-06-28 00:00:00	\N	2017-12-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-12-12 03:45:13	\N
50955	50899	CONSMUNI	2017-10-23 00:00:00	\N	2020-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-12-06 14:24:37	2017-12-06 14:24:42
51434	50900	CONSCOMINT	2017-10-23 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-12-06 14:24:58	2017-12-06 14:30:06
50543	50906	DEPUTE	2017-06-21 00:00:00	\N	2017-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-12-12 03:45:13	\N
51473	50908	CONSMUNI	2017-11-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-12-12 17:13:10	2017-12-12 17:13:25
51491	50909	CONSCOMINT	2017-12-09 00:00:00	\N	2020-10-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-12-12 17:14:16	2017-12-12 17:14:34
51454	50910	CONSMUNI	2017-11-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-12-14 09:55:21	2017-12-14 09:55:28
50977	50924	CONSMUNI	2017-12-16 00:00:00	\N	2017-12-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-12-20 19:05:29	2018-01-02 11:05:22
50979	50925	CONSDPT	2017-12-19 00:00:00	\N	2021-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-12-20 19:06:18	2017-12-20 19:06:23
51557	50928	VICPDTINTCOM	2017-01-01 00:00:00	\N	2017-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-12-21 14:20:26	2017-12-21 14:23:42
51556	50927	VICPDTINTCOM	1999-01-01 00:00:00	\N	2016-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-12-21 14:19:32	2017-12-21 14:20:23
51000	50933	CONSREG	2017-12-31 00:00:00	\N	2021-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2018-01-08 17:20:38	2018-01-08 17:21:22
51279	51105	CONSDPT	2017-10-01 00:00:00	\N	2021-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50999	51113	CONSMUNI	2018-01-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
50139	51189	DEPUTE	2017-06-21 00:00:00	\N	2017-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50139	51190	SECAN	2017-06-28 00:00:00	\N	2021-08-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
14024	50955	CONSCOMINT	2017-11-16 00:00:00	\N	2020-11-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2018-01-18 15:28:17	2018-01-18 15:28:42
50943	50966	CONSMUNI	2017-10-03 00:00:00	\N	2020-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2018-01-24 11:11:30	2018-01-24 11:11:41
50945	50967	CONSDPT	2017-10-03 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2018-01-24 11:12:03	2018-01-24 11:12:11
51149	50971	CONSMUNI	2017-10-22 00:00:00	\N	2020-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2018-01-25 11:49:03	2018-01-25 11:49:14
50896	50972	CONSREG	2017-11-16 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2018-01-25 15:20:25	2018-01-25 15:20:53
11345	50974	CONSMUNI	2017-10-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2018-02-01 14:15:47	2018-02-01 14:16:11
14242	50993	CONSMUNI	2017-09-22 00:00:00	\N	2020-07-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2018-02-08 15:50:56	2018-02-08 15:51:15
50872	51006	CONSMUNI	2017-10-07 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2018-02-19 16:52:18	2018-02-19 16:52:27
10184	51007	CONSMUNI	2017-10-20 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2018-02-22 15:39:44	2018-02-22 15:39:52
15287	51008	CONSMUNI	2017-12-03 00:00:00	\N	2020-06-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2018-02-22 16:03:49	2018-02-22 16:04:06
51569	51009	PDTINTCOM	2011-01-01 00:00:00	\N	2017-10-31 00:00:00	\N	ANCIEN	CC d'Auberive, Vingeanne et Montsaugeonnais	Communauté de communes d'Auberive, Vingeanne et Montsaugeonnais	\N	\N	2018-02-22 16:06:32	2018-02-22 16:18:33
51569	51010	CONSCOMINT	2017-11-01 00:00:00	\N	2020-06-30 00:00:00	\N	ANCIEN	CC d'Auberive, Vingeanne et Montsaugeonnais	Communauté de communes d'Auberive, Vingeanne et Montsaugeonnais	\N	\N	2018-02-22 16:18:38	2018-02-22 16:20:03
12341	51011	CONSMUNI	2017-11-02 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2018-03-08 15:21:01	2018-03-08 15:21:10
51425	51012	CONSCOMINT	2017-09-28 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	2018-03-08 15:26:16	2018-03-08 15:26:35
51571	51014	DEPUTE	2018-03-19 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2018-03-22 03:44:45	\N
51263	51022	MAIRE	2008-03-16 00:00:00	\N	2017-10-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2018-04-03 14:45:04	2018-04-03 16:03:54
50815	51030	CONSMUNI	2017-10-25 00:00:00	\N	2020-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2018-04-09 19:13:28	2018-04-09 19:13:47
51592	51058	CONSMUNI	2008-03-16 00:00:00	\N	2018-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2018-06-04 13:56:55	2018-06-04 13:58:21
51595	51061	CONSREG	2015-12-13 00:00:00	\N	2021-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2018-06-04 14:00:43	2018-06-04 14:01:33
51594	51060	CONSCOMINT	2008-03-16 00:00:00	\N	2018-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2018-06-04 13:58:53	2018-06-04 13:59:56
14386	51063	CONSCOMINT	2017-01-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2018-06-06 17:02:08	2018-06-06 17:02:44
51605	51072	MAIRE	2008-03-16 00:00:00	\N	2018-07-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51606	51073	CONSDPT	2015-03-29 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
51607	51074	CONSCOMINT	2008-03-16 00:00:00	\N	2018-07-12 00:00:00	\N	ANCIEN	Collines du Perche normand	Collines du Perche normand	\N	\N	\N	\N
51608	51075	CONSMUNI	2008-03-16 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
51609	51076	CONSREG	2004-03-28 00:00:00	\N	2015-12-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51626	51096	DEPUTE	2018-07-12 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51613	51080	CONSMUNI	2017-11-02 00:00:00	\N	2020-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
49092	51098	DEPUTE	2017-06-21 00:00:00	\N	2018-01-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51312	51084	CONSMUNI	2017-11-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
49092	51099	VICPDTAN	2018-01-18 00:00:00	\N	2018-07-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51627	51100	DEPUTE	2018-07-16 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
11697	51152	MEMBREINTCOM	2017-06-26 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N
51639	51128	VICPDTINTCOM	2017-01-01 00:00:00	\N	2017-10-01 00:00:00	\N	ANCIEN	Communauté territoriale du Pays d'Aix	Nouvelle fonction	\N	\N	\N	\N
51669	51165	MAIRE	1995-06-18 00:00:00	\N	2018-12-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
15271	51169	CONSREG	2017-10-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
51525	51170	CONSDPT	2017-10-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
51678	51176	DEPUTE	2019-05-01 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51672	51172	CONSCOMINT	2001-04-01 00:00:00	\N	2014-03-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
51672	51173	PDTINTCOM	2014-03-31 00:00:00	\N	2017-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
47899	51179	DEPUTE	2017-06-21 00:00:00	\N	2017-11-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
47899	51180	VICPDTAN	2017-11-08 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50045	51187	DEPUTE	2017-06-21 00:00:00	\N	2017-11-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50045	51188	VICPDTAN	2017-11-07 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
34656	33253	DEPUTE	1973-04-02 00:00:00	\N	1977-03-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:40	\N
34657	33254	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:40	\N
34658	33255	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:40	\N
34659	33256	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:40	\N
34660	33257	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:40	\N
34661	33258	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:40	\N
34662	33259	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:40	\N
34663	33260	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:40	\N
34664	33261	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:40	\N
34665	33262	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:40	\N
34666	33263	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:40	\N
34667	33264	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:40	\N
34668	33265	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:40	\N
34669	33266	DEPUTE	1997-06-01 00:00:00	\N	1999-02-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:40	\N
34670	33267	VICPDTAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:40	\N
34671	33268	VICPDTAN	1998-10-01 00:00:00	\N	1999-02-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:40	\N
34672	33269	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:40	\N
34673	33270	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:40	\N
34674	33271	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:41	\N
34675	33272	DEPUTE	1999-08-29 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:41	\N
34676	33273	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:41	\N
34677	33274	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:41	\N
34678	33275	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:41	\N
34679	33276	SECAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:41	\N
34680	33277	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:41	\N
34681	33278	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:41	\N
34682	33279	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:41	\N
34683	33280	SECAN	2003-10-01 00:00:00	\N	2004-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:41	\N
34684	33281	SECAN	2006-10-04 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:41	\N
34685	33282	SECAN	2007-06-27 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:41	\N
34686	33283	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:41	\N
34687	33284	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:41	\N
34688	33285	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:41	\N
34689	33286	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:41	\N
34690	33287	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:41	\N
34691	33288	DEPUTE	2000-09-30 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:41	\N
34692	33289	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:41	\N
34693	33290	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:41	\N
34694	33291	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:41	\N
34695	33292	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:41	\N
34696	33293	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:41	\N
34697	33294	SECAN	2002-06-26 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:41	\N
34698	33295	SECAN	2007-06-27 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:41	\N
34699	33296	SECAN	2012-06-27 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:41	\N
34700	33297	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:41	\N
34701	33298	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:41	\N
34702	33299	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:41	\N
34703	33300	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:41	\N
34704	33301	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:41	\N
34705	33302	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:41	\N
34706	33303	DEPUTE	1997-06-01 00:00:00	\N	1998-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:41	\N
34707	33304	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:42	\N
34708	33305	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:42	\N
34709	33306	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:42	\N
34710	33307	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:42	\N
34711	33308	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:42	\N
34712	33309	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:42	\N
34713	33310	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:42	\N
34714	33311	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:42	\N
34715	33312	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:42	\N
34716	33313	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:42	\N
34717	33314	DEPUTE	1997-06-01 00:00:00	\N	1998-09-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:42	\N
34718	33315	DEPUTE	1978-04-03 00:00:00	\N	1978-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:42	\N
34719	33316	DEPUTE	1958-12-09 00:00:00	\N	1962-05-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:42	\N
34720	33317	DEPUTE	1962-12-06 00:00:00	\N	1963-01-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:42	\N
34721	33318	DEPUTE	1967-04-03 00:00:00	\N	1967-05-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:42	\N
34722	33319	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:42	\N
34723	33320	DEPUTE	1973-04-02 00:00:00	\N	1973-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:42	\N
34724	33321	DEPUTE	1982-01-18 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:42	\N
34725	33322	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:42	\N
34726	33323	DEPUTE	1993-04-02 00:00:00	\N	1995-09-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:42	\N
34727	33324	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:42	\N
34728	33325	DEPUTE	1973-04-02 00:00:00	\N	1975-07-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:42	\N
34729	33326	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:42	\N
34730	33327	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:42	\N
34731	33328	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:42	\N
34732	33329	DEPUTE	2007-07-20 00:00:00	\N	2010-12-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:43	\N
34733	33330	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:43	\N
34734	33331	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:43	\N
34735	33332	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:43	\N
34736	33333	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:43	\N
34737	33334	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:43	\N
34738	33335	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:43	\N
34739	33336	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:43	\N
34740	33337	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:43	\N
34741	33338	DEPUTE	2005-07-03 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:43	\N
34742	33339	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:43	\N
34743	33340	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:43	\N
34744	33341	DEPUTE	2012-07-21 00:00:00	\N	2014-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:43	\N
34745	33342	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:43	\N
34746	33343	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:43	\N
34747	33344	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:43	\N
34748	33345	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:43	\N
36154	34751	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:43	\N
36155	34752	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:43	\N
36156	34753	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:43	\N
36158	34755	DEPUTE	2014-06-30 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:43	\N
36159	34756	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:43	\N
36160	34757	DEPUTE	2014-06-30 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:43	\N
36161	34758	DEPUTE	2014-07-30 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:43	\N
36162	34759	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:43	\N
36163	34760	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:43	\N
36164	34761	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:43	\N
36165	34762	DEPUTE	1973-04-02 00:00:00	\N	1973-05-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:43	\N
36166	34763	DEPUTE	1978-04-03 00:00:00	\N	1978-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:43	\N
36167	34764	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:43	\N
36168	34765	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:43	\N
36169	34766	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:43	\N
36170	34767	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:44	\N
36171	34768	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:44	\N
36172	34769	DEPUTE	1973-04-02 00:00:00	\N	1974-07-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:44	\N
36173	34770	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:44	\N
36174	34771	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:44	\N
36175	34772	DEPUTE	1963-05-12 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:44	\N
36176	34773	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:44	\N
36177	34774	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:44	\N
36178	34775	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:44	\N
36179	34776	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:44	\N
36180	34777	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:44	\N
36181	34778	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:44	\N
36182	34779	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:44	\N
36183	34780	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:44	\N
36184	34781	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:44	\N
36185	34782	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:44	\N
36186	34783	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:44	\N
36187	34784	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:44	\N
36188	34785	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:44	\N
36189	34786	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:45	\N
36190	34787	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:45	\N
36191	34788	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:45	\N
36192	34789	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:45	\N
36193	34790	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:45	\N
36194	34791	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:45	\N
36195	34792	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:45	\N
36196	34793	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:45	\N
36197	34794	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:45	\N
36198	34795	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:45	\N
36199	34796	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:45	\N
36200	34797	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:45	\N
36201	34798	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:45	\N
36202	34799	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:45	\N
36203	34800	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:45	\N
36204	34801	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:45	\N
36205	34802	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:45	\N
36206	34803	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:45	\N
36207	34804	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:45	\N
36208	34805	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:46	\N
36209	34806	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:46	\N
36210	34807	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:46	\N
36211	34808	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:46	\N
36212	34809	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:46	\N
36213	34810	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:46	\N
36214	34811	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:46	\N
36215	34812	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:46	\N
36216	34813	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:46	\N
36217	34814	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:46	\N
36218	34815	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:46	\N
36219	34816	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:46	\N
36220	34817	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:46	\N
36221	34818	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:46	\N
36222	34819	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:46	\N
36223	34820	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:46	\N
36224	34821	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:46	\N
36225	34822	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:46	\N
36226	34823	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:46	\N
36227	34824	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:46	\N
36228	34825	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:46	\N
36229	34826	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:46	\N
36230	34827	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:46	\N
36231	34828	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:46	\N
36232	34829	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:46	\N
36233	34830	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:46	\N
36234	34831	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:47	\N
36239	34836	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:47	\N
36240	34837	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:47	\N
36241	34838	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:47	\N
36242	34839	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:47	\N
36243	34840	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:47	\N
36244	34841	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:47	\N
36245	34842	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:47	\N
36246	34843	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:47	\N
36247	34844	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:47	\N
36248	34845	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:47	\N
36249	34846	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:47	\N
36250	34847	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:47	\N
36251	34848	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:47	\N
36252	34849	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:47	\N
49918	48514	SECAN	2012-06-27 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:55	2017-08-10 10:57:47
49919	48515	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:55	2017-08-10 03:44:17
49920	48516	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:55	2017-08-10 03:44:17
49921	48517	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:55	\N
49922	48518	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:55	\N
49923	48519	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:56	\N
49924	48520	DEPUTE	2017-06-21 00:00:00	\N	2020-07-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:56	\N
49925	48521	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:56	\N
49926	48522	DEPUTE	2010-12-29 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:56	\N
49927	48523	DEPUTE	2012-07-22 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:56	\N
49928	48524	DEPUTE	2012-07-22 00:00:00	\N	2014-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:56	\N
49929	48525	DEPUTE	2012-07-22 00:00:00	\N	2014-12-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:56	\N
49930	48526	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:56	\N
49931	48527	DEPUTE	2012-07-22 00:00:00	\N	2014-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:56	\N
49932	48528	DEPUTE	2012-07-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:56	\N
49933	48529	DEPUTE	2017-05-06 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:56	\N
49934	48530	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:56	\N
49935	48531	DEPUTE	2016-03-04 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:56	\N
49936	48532	DEPUTE	2015-07-18 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:56	\N
49937	48533	DEPUTE	2012-07-22 00:00:00	\N	2014-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:56	2017-08-10 10:57:47
49938	48534	DEPUTE	2015-02-09 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:56	2017-08-10 10:57:47
49939	48535	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:56	\N
49941	48537	DEPUTE	2017-06-21 00:00:00	\N	2022-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:56	\N
49942	48538	DEPUTE	2012-06-26 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:56	2017-08-09 03:44:35
49943	48539	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:56	2017-08-09 03:44:35
49944	48540	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:56	\N
49945	48541	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:56	\N
49946	48542	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:56	\N
49947	48543	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:56	\N
49948	48544	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:56	\N
49949	48545	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:57	\N
49950	48546	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:57	\N
49951	48547	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:57	\N
49952	48548	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:57	\N
49953	48549	DEPUTE	2017-06-21 00:00:00	\N	2020-02-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:57	\N
49954	48550	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:57	\N
49955	48551	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:57	\N
49956	48552	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:57	\N
49957	48553	DEPUTE	2017-06-21 00:00:00	\N	2018-04-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:57	2018-04-27 03:44:29
49958	48554	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:57	\N
49959	48555	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:57	\N
49960	48556	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:57	\N
49961	48557	DEPUTE	2012-06-20 00:00:00	\N	2016-03-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:57	2017-08-08 03:44:45
49962	48558	DEPUTE	2017-06-21 00:00:00	\N	2020-07-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:57	\N
49963	48559	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:57	2017-08-08 03:44:45
49964	48560	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:57	\N
49965	48561	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:57	\N
49967	48563	VICPDTAN	2012-06-27 00:00:00	\N	2016-05-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:57	2017-08-10 03:44:19
49968	48564	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:57	\N
49969	48565	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:58	\N
49970	48566	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:58	\N
49971	48567	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:58	\N
49972	48568	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:58	\N
49973	48569	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:58	\N
49974	48570	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:58	\N
49975	48571	DEPUTE	2012-06-20 00:00:00	\N	2014-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:58	2017-08-10 10:57:49
49976	48572	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:58	2017-08-10 10:57:49
49977	48573	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:58	\N
49978	48574	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:58	\N
49979	48575	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:58	\N
49980	48576	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:58	\N
49981	48577	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:58	\N
49982	48578	DEPUTE	2017-06-21 00:00:00	\N	2020-08-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:58	\N
49983	48579	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:58	\N
49984	48580	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:58	\N
49985	48581	DEPUTE	2012-06-20 00:00:00	\N	2014-05-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:58	\N
49986	48582	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:58	\N
49987	48583	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:58	\N
49988	48584	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:59	\N
49989	48585	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:59	\N
49990	48586	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:59	\N
49991	48587	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:59	\N
49992	48588	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:59	\N
49993	48589	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:59	\N
49994	48590	DEPUTE	2012-06-20 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:59	\N
49995	48591	DEPUTE	2017-06-21 00:00:00	\N	2017-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:59	\N
49996	48592	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:59	\N
49997	48593	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:59	\N
49998	48594	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:59	\N
49999	48595	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:59	\N
50000	48596	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:59	\N
50001	48597	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:59	\N
50002	48598	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:59	\N
50003	48599	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:59	\N
50004	48600	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:59	\N
50005	48601	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:00	\N
50006	48602	DEPUTE	2017-06-21 00:00:00	\N	2020-01-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:00	\N
50007	48603	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:00	\N
50008	48604	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:00	\N
50009	48605	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:00	\N
50010	48606	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:00	\N
51540	50902	CONSMET	2017-10-10 00:00:00	\N	2020-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-12-06 15:14:54	2017-12-06 15:15:30
51332	50929	CONSDPT	2017-11-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-12-22 16:30:37	2017-12-22 16:30:45
51561	50940	CONSMUNI	2016-12-01 00:00:00	\N	2020-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2018-01-08 20:23:30	2018-01-09 09:46:47
15237	50935	CONSDPT	2017-09-08 00:00:00	\N	2021-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2018-01-08 20:09:32	2018-01-08 20:09:40
51501	50942	CONSMUNI	2017-12-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2018-01-10 18:58:17	2018-01-10 18:58:30
51560	50937	PDTINTCOM	2017-01-01 00:00:00	\N	2017-09-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2018-01-08 20:14:32	2018-01-08 20:19:29
51560	50938	CONSCOMINT	2017-09-08 00:00:00	\N	2020-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2018-01-08 20:19:30	2018-01-08 20:19:40
51502	50943	CONSCOMINT	2017-12-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2018-01-10 18:58:48	2018-01-10 18:59:14
13869	50944	CONSMUNI	2017-11-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2018-01-12 10:50:20	2018-01-12 10:50:57
50737	50956	DEPUTE	2017-06-21 00:00:00	\N	2017-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2018-01-23 03:45:16	\N
50737	50957	SECAN	2017-06-28 00:00:00	\N	2018-01-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2018-01-23 03:45:16	\N
15338	50958	CONSMUNI	2017-11-03 00:00:00	\N	2020-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2018-01-23 18:48:31	2018-01-23 18:48:40
14308	50959	CONSMUNI	2017-09-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2018-01-23 18:51:38	2018-01-23 18:51:45
14309	50960	CONSCOMINT	2017-09-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2018-01-23 18:53:02	2018-01-23 18:53:13
11616	50961	CONSARR	2017-09-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2018-01-23 18:55:49	2018-01-23 18:56:50
11609	50962	CONSMUNI	2017-10-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2018-01-23 18:59:29	2018-01-23 18:59:41
11796	50963	CONSMUNI	2017-10-31 00:00:00	\N	2020-01-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2018-01-23 19:17:27	2018-01-23 19:17:39
14161	50964	CONSMUNI	2017-10-01 00:00:00	\N	2020-03-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2018-01-23 19:20:10	2018-01-23 19:20:29
14148	50965	CONSCOMINT	2017-09-25 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	2018-01-23 19:20:56	2018-01-23 19:21:57
50730	51256	DEPUTE	2017-11-08 00:00:00	\N	2018-02-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50730	51257	SECAN	2018-02-01 00:00:00	\N	2019-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50730	51258	DEPUTE	2019-10-01 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50365	51262	DEPUTE	2017-06-21 00:00:00	\N	2017-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50365	51263	SECAN	2017-06-28 00:00:00	\N	2019-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50365	51264	DEPUTE	2019-10-01 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50885	51036	CONSMUNI	2018-04-12 00:00:00	\N	2020-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2018-05-15 14:50:31	2018-05-15 14:50:57
51396	51037	CONSCOMINT	2018-04-12 00:00:00	\N	2020-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2018-05-15 14:51:43	2018-05-15 14:53:46
51631	51108	DELINTCOM	2017-10-02 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
51631	51107	PREPDTINTCOM	2017-01-01 00:00:00	\N	2017-10-01 00:00:00	\N	ANCIEN	Communauté de communes Ponthieu-Marquenterre	Nouvelle fonction	\N	\N	\N	\N
6205	51132	CONSMUNI	2017-07-17 00:00:00	\N	2018-11-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
14405	51133	CONSMET	2017-07-10 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
51645	51135	DEPUTE	2018-11-17 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51647	51137	DEPUTE	2018-11-17 00:00:00	\N	2020-08-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51648	51138	DEPUTE	2018-11-17 00:00:00	\N	2021-07-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51649	51139	DEPUTE	2018-11-17 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51573	51259	DEPUTE	2018-03-26 00:00:00	\N	2018-04-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51573	51260	SECAN	2018-04-03 00:00:00	\N	2019-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51573	51261	DEPUTE	2019-10-01 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51657	51153	DEPUTE	2019-02-26 00:00:00	\N	2022-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50503	51265	DEPUTE	2017-06-21 00:00:00	\N	2017-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50503	51266	VICPDTAN	2017-06-28 00:00:00	\N	2019-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50503	51267	DEPUTE	2019-10-01 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50451	51268	DEPUTE	2017-06-21 00:00:00	\N	2019-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50451	51269	VICPDTAN	2019-10-01 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51570	51270	DEPUTE	2018-03-12 00:00:00	\N	2018-04-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51570	51271	SECAN	2018-04-03 00:00:00	\N	2019-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51570	51272	DEPUTE	2019-10-01 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50599	51273	DEPUTE	2017-06-21 00:00:00	\N	2017-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50599	51274	SECAN	2017-06-28 00:00:00	\N	2019-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50599	51275	DEPUTE	2019-10-01 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50400	51278	DEPUTE	2017-06-21 00:00:00	\N	2019-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50400	51279	SECAN	2019-10-01 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51698	51280	DEPUTE	2019-10-04 00:00:00	\N	2022-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51700	51281	PDTINTCOM	2008-03-01 00:00:00	\N	2016-05-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	\N
15174	51286	CONSDPT	2017-10-01 00:00:00	\N	2017-12-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
10918	51290	CONSMUNI	2019-07-02 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
51705	51291	DEPUTE	2020-01-18 00:00:00	\N	2022-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51707	51292	DEPUTE	2020-02-01 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51711	51302	MAIRE	1995-06-30 00:00:00	\N	2015-03-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51712	51303	PDTDPT	2015-04-02 00:00:00	\N	2019-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51713	51304	DEPUTE	2020-03-30 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51721	51314	PDTINTCOM	2002-01-01 00:00:00	\N	2016-12-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51723	51316	PDTINTCOM	2017-01-26 00:00:00	\N	2019-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51711	51317	CONSMUNI	2015-04-01 00:00:00	\N	2019-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51724	51318	CONSGENE	1993-12-01 00:00:00	\N	2015-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51726	51321	DEPUTE	2020-05-28 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51727	51322	DEPUTE	2019-07-07 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51731	51323	DEPUTE	2020-06-18 00:00:00	\N	2020-06-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51732	51324	DEPUTE	2020-06-18 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51735	51325	DEPUTE	2020-06-23 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51736	51326	DEPUTE	2020-06-23 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51738	51327	DEPUTE	2020-06-24 00:00:00	\N	2020-06-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50915	51328	CONSMUNI	2017-10-03 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
11624	51331	CONSCOMINT	2017-10-03 00:00:00	\N	2019-12-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
14082	51330	CONSMUNI	2020-01-02 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
51744	51332	DEPUTE	2020-06-28 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51540	51335	CONSMET	2020-06-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
51751	51336	CONSMUNI	2020-06-25 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
51463	51337	CONSMUNI	2020-05-23 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
51492	51338	MEMBREINTCOM	2020-07-10 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
6588	51339	CONSMUNI	2020-05-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
14013	51340	CONSMUNI	2020-06-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
14375	51341	MEMBREINTCOM	2020-06-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
11273	51342	CONSMUNI	2020-06-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
14051	51343	CONSMUNI	2020-06-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
15338	51346	CONSMUNI	2020-06-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
51752	51345	MEMBREINTCOM	2020-06-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
14132	51347	CONSMUNI	2020-06-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
13813	51348	CONSMUNI	2020-06-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
14244	51349	CONSMUNI	2020-06-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
50815	51351	CONSMUNI	2020-06-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
34749	33346	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:43	\N
34750	33347	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:43	\N
34751	33348	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:44	\N
34752	33349	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:44	\N
34753	33350	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:44	\N
34754	33351	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:44	\N
34755	33352	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:44	\N
34756	33353	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:44	\N
34757	33354	DEPUTE	2004-05-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:44	\N
34758	33355	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:44	\N
34759	33356	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:44	\N
34760	33357	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:44	\N
34761	33358	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:44	\N
34762	33359	VICPDTAN	2011-07-07 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:44	\N
34763	33360	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:44	\N
34764	33361	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:44	\N
34765	33362	DEPUTE	2009-02-15 00:00:00	\N	2010-12-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:44	\N
34766	33363	DEPUTE	2012-06-20 00:00:00	\N	2016-01-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:44	\N
34767	33364	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:44	\N
34768	33365	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:44	\N
34769	33366	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:44	\N
34770	33367	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:44	\N
34771	33368	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:44	\N
34772	33369	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:45	\N
34773	33370	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:45	\N
34774	33371	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:45	\N
34775	33372	DEPUTE	2007-07-20 00:00:00	\N	2010-12-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:45	\N
34776	33373	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:45	\N
34777	33374	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:45	\N
34778	33375	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:45	\N
34779	33376	DEPUTE	2004-05-15 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:45	\N
34780	33377	DEPUTE	2007-04-27 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:45	\N
34781	33378	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:45	\N
34782	33379	DEPUTE	2007-06-20 00:00:00	\N	2010-12-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:45	\N
34783	33380	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:45	\N
34784	33381	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:45	\N
34785	33382	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:45	\N
34786	33383	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:46	\N
34787	33384	DEPUTE	2008-09-15 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:46	\N
34788	33385	DEPUTE	2007-06-20 00:00:00	\N	2007-11-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:46	\N
34789	33386	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:46	\N
34790	33387	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:46	\N
34791	33388	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:46	\N
34792	33389	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:46	\N
34793	33390	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:46	\N
34794	33391	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:46	\N
34795	33392	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:46	\N
34796	33393	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:46	\N
34797	33394	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:46	\N
34798	33395	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:46	\N
34799	33396	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:46	\N
34800	33397	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:46	\N
34801	33398	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:46	\N
34802	33399	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:46	\N
34803	33400	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:47	\N
34804	33401	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:47	\N
34805	33402	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:47	\N
34806	33403	SECAN	2008-10-01 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:47	\N
34807	33404	SECAN	2012-06-27 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:47	\N
34808	33405	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:47	\N
34809	33406	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:47	\N
34810	33407	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:47	\N
34811	33408	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:47	\N
34812	33409	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:47	\N
34813	33410	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:47	\N
34814	33411	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:47	\N
34815	33412	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:47	\N
34816	33413	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:47	\N
34817	33414	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:47	\N
34818	33415	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:47	\N
34819	33416	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:47	\N
34820	33417	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:47	\N
34821	33418	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:47	\N
34822	33419	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:47	\N
34823	33420	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:47	\N
34824	33421	DEPUTE	2007-07-20 00:00:00	\N	2010-12-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:48	\N
34825	33422	DEPUTE	2004-07-05 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:48	\N
34826	33423	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:48	\N
34827	33424	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:48	\N
34828	33425	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:48	\N
34829	33426	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:48	\N
34830	33427	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:48	\N
34831	33428	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:48	\N
34832	33429	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:48	\N
34833	33430	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:48	\N
34834	33431	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:48	\N
36326	34923	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:51	\N
34835	33432	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:48	\N
34836	33433	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:48	\N
34837	33434	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:48	\N
34838	33435	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:48	\N
34839	33436	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:48	\N
34840	33437	DEPUTE	2008-04-19 00:00:00	\N	2010-08-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:48	\N
34841	33438	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:48	\N
36253	34850	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:47	\N
36254	34851	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:48	\N
36255	34852	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:48	\N
36256	34853	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:48	\N
36257	34854	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:48	\N
36258	34855	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:48	\N
36259	34856	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:48	\N
36260	34857	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:48	\N
36261	34858	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:48	\N
36262	34859	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:48	\N
36263	34860	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:48	\N
36264	34861	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:48	\N
36265	34862	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:48	\N
36266	34863	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:48	\N
36267	34864	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:48	\N
36268	34865	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:48	\N
36269	34866	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:48	\N
36270	34867	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:48	\N
36271	34868	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:48	\N
36272	34869	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:48	\N
36273	34870	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:48	\N
36274	34871	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:49	\N
36275	34872	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:49	\N
36276	34873	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:49	\N
36277	34874	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:49	\N
36278	34875	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:49	\N
36279	34876	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:49	\N
36280	34877	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:49	\N
36281	34878	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:49	\N
36282	34879	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:49	\N
36283	34880	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:49	\N
36284	34881	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:49	\N
36285	34882	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:49	\N
36286	34883	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:49	\N
36287	34884	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:49	\N
36288	34885	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:49	\N
36289	34886	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:50	\N
36290	34887	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:50	\N
36291	34888	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:50	\N
36292	34889	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:50	\N
36293	34890	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:50	\N
36294	34891	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:50	\N
36295	34892	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:50	\N
36296	34893	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:50	\N
36297	34894	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:50	\N
36298	34895	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:50	\N
36299	34896	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:50	\N
36300	34897	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:50	\N
36301	34898	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:50	\N
36302	34899	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:50	\N
36303	34900	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:50	\N
36304	34901	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:50	\N
36305	34902	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:50	\N
36306	34903	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:50	\N
36307	34904	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:51	\N
36308	34905	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:51	\N
36309	34906	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:51	\N
36310	34907	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:51	\N
36311	34908	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:51	\N
36312	34909	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:51	\N
36313	34910	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:51	\N
36314	34911	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:51	\N
36315	34912	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:51	\N
36316	34913	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:51	\N
36317	34914	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:51	\N
36318	34915	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:51	\N
36319	34916	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:51	\N
36320	34917	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:51	\N
36321	34918	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:51	\N
36322	34919	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:51	\N
36323	34920	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:51	\N
36324	34921	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:51	\N
36325	34922	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:51	\N
36327	34924	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:51	\N
36328	34925	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:51	\N
36329	34926	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:51	\N
36330	34927	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:52	\N
36331	34928	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:52	\N
36332	34929	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:52	\N
36333	34930	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:52	\N
36334	34931	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:52	\N
36335	34932	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:52	\N
36336	34933	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:52	\N
36337	34934	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:52	\N
36338	34935	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:52	\N
36339	34936	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:52	\N
36340	34937	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:52	\N
36341	34938	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:52	\N
36342	34939	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:52	\N
36343	34940	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:52	\N
36344	34941	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:52	\N
36345	34942	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:52	\N
36346	34943	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:52	\N
36347	34944	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:52	\N
36348	34945	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:53	\N
36349	34946	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:53	\N
36350	34947	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:53	\N
36351	34948	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:53	\N
36352	34949	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:53	\N
36353	34950	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:53	\N
36354	34951	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:53	\N
50011	48607	DEPUTE	2012-06-20 00:00:00	\N	2016-01-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:00	2017-08-10 03:44:20
50012	48608	DEPUTE	2012-06-26 00:00:00	\N	2016-01-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:00	2017-08-10 03:44:20
50013	48609	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:00	\N
50014	48610	DEPUTE	2012-06-20 00:00:00	\N	2014-07-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:00	2017-08-10 03:44:20
50015	48611	DEPUTE	2015-07-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:00	2017-08-10 03:44:20
50016	48612	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:00	\N
50017	48613	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:00	\N
50018	48614	DEPUTE	2012-06-20 00:00:00	\N	2016-03-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:00	\N
50019	48615	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:00	\N
50020	48616	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:00	\N
50021	48617	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:01	\N
50022	48618	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:01	\N
50023	48619	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:01	\N
50024	48620	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:01	\N
50025	48621	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:01	\N
50026	48622	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:01	\N
50027	48623	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:01	2017-08-10 03:44:21
50028	48624	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:01	\N
50029	48625	DEPUTE	2012-06-26 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:01	2017-08-10 03:44:21
50030	48626	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:01	\N
50031	48627	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:01	\N
50032	48628	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:01	\N
50033	48629	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:01	\N
50034	48630	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:01	\N
50035	48631	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:01	\N
50036	48632	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:01	\N
50037	48633	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:01	\N
50038	48634	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:01	\N
50039	48635	DEPUTE	2012-06-20 00:00:00	\N	2014-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:01	\N
50040	48636	DEPUTE	2012-06-20 00:00:00	\N	2012-06-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:01	\N
50041	48637	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:01	\N
50042	48638	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:01	\N
50043	48639	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:01	\N
50046	48642	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:01	2017-08-10 03:44:21
50047	48643	DEPUTE	2012-06-20 00:00:00	\N	2016-03-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:01	2017-08-10 10:57:51
50048	48644	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:01	2017-08-10 10:57:51
50049	48645	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:01	\N
50050	48646	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:01	\N
50051	48647	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:01	\N
50052	48648	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:01	\N
50053	48649	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:01	\N
50054	48650	DEPUTE	2012-06-20 00:00:00	\N	2016-03-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:01	\N
50055	48651	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:02	\N
50056	48652	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:02	\N
50057	48653	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:02	\N
50058	48654	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:02	2017-08-10 10:57:51
50059	48655	DEPUTE	2012-06-26 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:02	2017-08-10 10:57:51
50060	48656	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:02	\N
50061	48657	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:02	\N
50062	48658	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:02	\N
50063	48659	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:02	\N
50064	48660	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:02	\N
50065	48661	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:02	\N
50066	48662	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:02	\N
50067	48663	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:02	\N
50068	48664	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:02	\N
50069	48665	DEPUTE	2017-06-21 00:00:00	\N	2020-06-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:02	\N
50070	48666	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:02	\N
50071	48667	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:02	\N
50072	48668	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:02	\N
50073	48669	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:02	\N
50074	48670	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:02	\N
50075	48671	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:02	\N
50076	48672	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:02	\N
50077	48673	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:02	\N
50078	48674	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:03	\N
50079	48675	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:03	\N
50080	48676	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:03	\N
50081	48677	DEPUTE	2012-06-20 00:00:00	\N	2014-05-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:03	2017-08-10 10:57:52
50082	48678	DEPUTE	2017-03-28 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:03	2017-08-10 10:57:52
50083	48679	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:03	\N
50084	48680	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:03	\N
50085	48681	DEPUTE	2012-06-20 00:00:00	1500	2017-06-20 00:00:00	1600	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:03	2023-09-26 17:42:19
50086	48682	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:03	\N
50087	48683	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:03	\N
50088	48684	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:03	\N
50089	48685	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:03	\N
50090	48686	DEPUTE	2017-06-21 00:00:00	\N	2020-07-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:03	\N
50091	48687	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:03	2017-08-10 10:57:52
50092	48688	DEPUTE	2012-06-26 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:03	2017-08-10 10:57:52
50093	48689	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:03	\N
50094	48690	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:03	\N
50095	48691	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:03	\N
50096	48692	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:03	\N
50097	48693	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:03	\N
50098	48694	DEPUTE	2012-06-20 00:00:00	\N	2014-04-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:03	\N
50099	48695	DEPUTE	2012-06-20 00:00:00	\N	2013-02-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:03	\N
50100	48696	DEPUTE	2012-06-20 00:00:00	\N	2014-05-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:03	\N
50101	48697	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:04	\N
50102	48698	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:04	\N
50103	48699	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:04	\N
50104	48700	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:04	\N
46503	49644	DEPUTE	1981-07-02 00:00:00	\N	1984-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:48	\N
46503	49645	VICPDTAN	1984-04-01 00:00:00	\N	1985-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:48	\N
46503	49646	DEPUTE	1985-04-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:48	\N
46586	49647	DEPUTE	1997-06-01 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:50	\N
46586	49648	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:50	\N
46586	49649	DEPUTE	1999-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:50	\N
46605	49650	DEPUTE	1993-04-02 00:00:00	\N	1995-04-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:50	\N
46605	49651	VICPDTAN	1995-04-03 00:00:00	\N	1996-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:50	\N
46605	49652	DEPUTE	1996-10-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:50	\N
46619	49653	DEPUTE	1988-06-13 00:00:00	\N	1988-06-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:50	\N
46619	49654	SECAN	1988-06-24 00:00:00	\N	1992-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:50	\N
46619	49655	DEPUTE	1992-04-02 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:50	\N
46638	49656	DEPUTE	1997-06-01 00:00:00	\N	1997-06-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:51	\N
46638	49657	SECAN	1997-06-13 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:51	\N
46638	49658	QUESTAN	1999-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:51	\N
46748	49659	DEPUTE	1997-06-01 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:53	\N
46748	49660	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:53	\N
46748	49661	DEPUTE	1999-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:53	\N
46772	49662	DEPUTE	1993-04-02 00:00:00	\N	1995-04-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:53	\N
46772	49663	QUESTAN	1995-04-03 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:53	\N
46774	49664	DEPUTE	2002-06-19 00:00:00	\N	2002-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:53	\N
46774	49665	SECAN	2002-06-26 00:00:00	\N	2004-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:53	\N
46774	49666	DEPUTE	2004-10-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:53	\N
46775	49667	DEPUTE	2007-06-20 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:53	\N
46775	49668	SECAN	2008-10-01 00:00:00	\N	2009-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:53	\N
46775	49669	DEPUTE	2009-10-07 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:53	\N
46801	49670	DEPUTE	1988-06-13 00:00:00	\N	1988-06-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:54	\N
46801	49671	VICPDTAN	1988-06-24 00:00:00	\N	1992-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:54	\N
46801	49672	DEPUTE	1992-04-02 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:54	\N
46800	49673	DEPUTE	1986-04-02 00:00:00	\N	1986-04-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:54	\N
46800	49674	VICPDTAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:54	\N
50757	49675	SECAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:55	\N
50757	49676	DEPUTE	1993-04-02 00:00:00	\N	1995-05-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:55	\N
50757	49677	SECAN	1995-05-31 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:55	\N
46823	49678	DEPUTE	2007-06-20 00:00:00	\N	2007-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:55	\N
46823	49679	VICPDTAN	2007-06-27 00:00:00	\N	2011-07-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:55	\N
46823	49680	DEPUTE	2011-07-07 00:00:00	\N	2011-07-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:55	\N
50758	49681	PDTAN	1992-01-22 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:55	\N
50758	49682	DEPUTE	1993-04-02 00:00:00	\N	1993-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:55	\N
46878	49683	DEPUTE	1986-04-02 00:00:00	\N	1986-04-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:55	\N
46878	49684	VICPDTAN	1986-04-04 00:00:00	\N	1987-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:55	\N
46878	49685	DEPUTE	1987-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:55	\N
46890	49686	DEPUTE	1997-06-01 00:00:00	\N	1997-06-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:55	\N
46890	49687	PDTAN	1997-06-12 00:00:00	\N	2000-03-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:55	\N
46890	49688	DEPUTE	2000-03-28 00:00:00	\N	2000-04-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:55	\N
46887	49689	DEPUTE	1988-06-06 00:00:00	\N	1988-06-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:55	\N
46887	49690	PDTAN	1988-06-23 00:00:00	\N	1992-01-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:55	\N
46887	49691	DEPUTE	1992-01-22 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:55	\N
46911	49692	DEPUTE	1993-04-02 00:00:00	\N	1993-04-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:56	\N
46911	49693	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:56	\N
46911	49694	DEPUTE	1994-04-02 00:00:00	\N	1995-09-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:56	\N
46938	49695	DEPUTE	1997-06-01 00:00:00	\N	1997-06-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:56	\N
46938	49696	SECAN	1997-06-13 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:56	\N
50759	49697	SECAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:56	\N
50759	49698	DEPUTE	1993-04-02 00:00:00	\N	1993-04-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:56	\N
50759	49699	SECAN	1993-04-07 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:56	\N
46956	49700	DEPUTE	1997-06-01 00:00:00	\N	1997-06-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:56	\N
46956	49701	SECAN	1997-06-13 00:00:00	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:56	\N
46956	49702	DEPUTE	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:56	\N
46956	49703	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:56	\N
46956	49704	VICPDTAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:56	\N
46959	49705	DEPUTE	2012-06-20 00:00:00	\N	2012-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:56	\N
46959	49706	SECAN	2012-06-27 00:00:00	\N	2013-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:56	\N
46959	49707	DEPUTE	2013-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:56	\N
46972	49708	DEPUTE	2002-06-19 00:00:00	\N	2004-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:57	\N
46972	49709	VICPDTAN	2004-10-01 00:00:00	\N	2006-11-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:57	\N
46972	49710	DEPUTE	2006-12-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:57	\N
46974	49711	DEPUTE	2007-06-20 00:00:00	\N	2009-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:57	\N
46974	49712	VICPDTAN	2009-10-06 00:00:00	\N	2010-11-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:57	\N
46974	49713	DEPUTE	2010-11-17 00:00:00	\N	2010-12-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:57	\N
50760	49714	SECAN	2007-06-27 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:59	\N
50760	49715	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:46:59	\N
47268	49716	DEPUTE	1988-06-06 00:00:00	\N	1988-06-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:02	\N
47268	49717	SECAN	1988-06-24 00:00:00	\N	1992-10-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:02	\N
47268	49718	DEPUTE	1992-10-21 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:02	\N
47267	49719	DEPUTE	1986-04-02 00:00:00	\N	1986-04-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:02	\N
47267	49720	SECAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:02	\N
47295	49721	DEPUTE	1997-06-01 00:00:00	\N	1997-06-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:03	\N
47295	49722	VICPDTAN	1997-06-13 00:00:00	\N	1998-03-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:03	\N
50761	49723	VICPDTAN	1992-04-02 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:03	\N
50761	49724	DEPUTE	1993-04-02 00:00:00	\N	1993-04-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:03	\N
50761	49725	VICPDTAN	1993-04-07 00:00:00	\N	1993-04-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:03	\N
50761	49726	DEPUTE	1993-04-09 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:03	\N
50762	49727	PDTAN	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:04	\N
50762	49728	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:04	\N
47363	49729	DEPUTE	1986-04-02 00:00:00	\N	1986-04-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:04	\N
47363	49730	VICPDTAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:04	\N
47385	49731	DEPUTE	1993-04-02 00:00:00	\N	1993-04-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:05	\N
47385	49732	SECAN	1993-04-07 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:05	\N
47393	49733	DEPUTE	1993-04-02 00:00:00	\N	1993-04-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:05	\N
47393	49734	VICPDTAN	1993-04-14 00:00:00	\N	1995-05-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:05	\N
47393	49735	DEPUTE	1995-06-01 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:05	\N
47395	49736	DEPUTE	2002-06-19 00:00:00	\N	2002-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:05	\N
34842	33439	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:48	\N
34843	33440	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:48	\N
34844	33441	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:48	\N
34845	33442	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:48	\N
34846	33443	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:49	\N
34847	33444	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:49	\N
34848	33445	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:49	\N
34849	33446	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:49	\N
34850	33447	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:49	\N
34851	33448	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:49	\N
34852	33449	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:49	\N
34853	33450	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:49	\N
34854	33451	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:49	\N
34855	33452	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:49	\N
34856	33453	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:49	\N
34857	33454	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:49	\N
34858	33455	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:49	\N
34859	33456	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:49	\N
34860	33457	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:49	\N
34861	33458	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:49	\N
34862	33459	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:49	\N
34863	33460	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:49	\N
34864	33461	DEPUTE	2006-06-27 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:49	\N
34865	33462	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:49	\N
34866	33463	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:49	\N
34867	33464	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:49	\N
34868	33465	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:49	\N
34869	33466	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:49	\N
34870	33467	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:49	\N
34871	33468	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:49	\N
34872	33469	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:49	\N
34873	33470	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:49	\N
34874	33471	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:49	\N
34875	33472	DEPUTE	2007-06-20 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:49	\N
34876	33473	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:49	\N
34877	33474	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:49	\N
34878	33475	DEPUTE	2004-05-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:49	\N
34879	33476	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:49	\N
34880	33477	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:49	\N
34881	33478	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:49	\N
34882	33479	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:49	\N
34883	33480	SECAN	2012-06-27 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:49	\N
34884	33481	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:49	\N
34885	33482	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:50	\N
34886	33483	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:50	\N
34887	33484	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:50	\N
34888	33485	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:50	\N
34889	33486	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:50	\N
34890	33487	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:50	\N
34891	33488	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:50	\N
34892	33489	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:50	\N
34893	33490	DEPUTE	2007-06-20 00:00:00	\N	2011-07-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:50	\N
34894	33491	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:50	\N
34895	33492	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:50	\N
34896	33493	SECAN	2007-06-27 00:00:00	\N	2011-07-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:50	\N
34897	33494	SECAN	2013-10-01 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:50	\N
34898	33495	DEPUTE	2011-07-30 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:50	\N
34899	33496	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:50	\N
34900	33497	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:50	\N
34901	33498	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:50	\N
34902	33499	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:50	\N
34903	33500	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:50	\N
34904	33501	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:50	\N
34905	33502	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:50	\N
34906	33503	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:50	\N
34907	33504	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:50	\N
34908	33505	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:50	\N
34909	33506	DEPUTE	2005-09-12 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:50	\N
34910	33507	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:50	\N
34911	33508	DEPUTE	2002-06-25 00:00:00	\N	2002-06-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:50	\N
34912	33509	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:50	\N
34913	33510	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:50	\N
34914	33511	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:50	\N
34915	33512	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:50	\N
34916	33513	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:50	\N
34917	33514	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:50	\N
34918	33515	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:50	\N
34919	33516	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:51	\N
34920	33517	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:51	\N
34921	33518	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:51	\N
34922	33519	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:51	\N
34923	33520	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:51	\N
34924	33521	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:51	\N
34925	33522	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:51	\N
34926	33523	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:51	\N
34927	33524	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:51	\N
34928	33525	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:51	\N
34929	33526	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:51	\N
34930	33527	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:51	\N
34931	33528	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:51	\N
34932	33529	SECAN	2011-07-07 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:51	\N
34933	33530	SECAN	2012-06-27 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:51	\N
34934	33531	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:51	\N
34935	33532	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:51	\N
36355	34952	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:53	\N
36356	34953	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:53	\N
36357	34954	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:53	\N
36358	34955	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:53	\N
36359	34956	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:53	\N
36360	34957	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:53	\N
36361	34958	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:53	\N
36362	34959	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:53	\N
36363	34960	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:53	\N
36364	34961	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:54	\N
36365	34962	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:54	\N
36366	34963	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:54	\N
36367	34964	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:54	\N
36368	34965	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:54	\N
36369	34966	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:54	\N
36370	34967	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:54	\N
36371	34968	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:54	\N
36372	34969	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:54	\N
36373	34970	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:54	\N
36374	34971	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:54	\N
36375	34972	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:54	\N
36376	34973	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:54	\N
36377	34974	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:54	\N
36378	34975	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:55	\N
36379	34976	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:55	\N
36380	34977	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:55	\N
36381	34978	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:55	\N
36382	34979	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:55	\N
36383	34980	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:55	\N
36384	34981	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:55	\N
36385	34982	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:55	\N
36386	34983	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:55	\N
36387	34984	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:55	\N
36388	34985	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:55	\N
36389	34986	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:55	\N
36390	34987	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:56	\N
36391	34988	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:56	\N
36392	34989	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:56	\N
36393	34990	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:56	\N
36394	34991	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:56	\N
36395	34992	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:56	\N
36396	34993	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:56	\N
36397	34994	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:56	\N
36398	34995	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:56	\N
36399	34996	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:56	\N
36400	34997	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:56	\N
36401	34998	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:56	\N
36402	34999	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:56	\N
36403	35000	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:56	\N
36404	35001	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:56	\N
36405	35002	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:56	\N
36406	35003	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:56	\N
36407	35004	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:57	\N
36408	35005	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:57	\N
36409	35006	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:57	\N
36410	35007	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:57	\N
36411	35008	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:57	\N
36412	35009	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:57	\N
36413	35010	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:57	\N
36414	35011	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:57	\N
36415	35012	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:57	\N
36416	35013	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:57	\N
36417	35014	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:57	\N
36418	35015	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:57	\N
36419	35016	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:57	\N
36420	35017	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:57	\N
36421	35018	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:57	\N
36422	35019	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:57	\N
36423	35020	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:57	\N
36424	35021	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:57	\N
36425	35022	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:57	\N
36426	35023	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:58	\N
36427	35024	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:58	\N
36428	35025	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:58	\N
36429	35026	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:58	\N
36430	35027	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:58	\N
36431	35028	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:58	\N
36432	35029	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:58	\N
36433	35030	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:58	\N
36434	35031	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:58	\N
36435	35032	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:58	\N
36436	35033	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:58	\N
36437	35034	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:58	\N
36438	35035	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:58	\N
36439	35036	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:58	\N
36440	35037	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:58	\N
36441	35038	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:58	\N
36442	35039	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:58	\N
36443	35040	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:58	\N
36444	35041	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:58	\N
36445	35042	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:58	\N
36446	35043	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:59	\N
36447	35044	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:59	\N
36448	35045	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:59	\N
36449	35046	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:59	\N
36450	35047	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:59	\N
36451	35048	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:59	\N
36452	35049	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:59	\N
36453	35050	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:59	\N
36454	35051	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:59	\N
36455	35052	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:59	\N
36456	35053	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:59	\N
50105	48701	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:04	\N
50106	48702	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:04	\N
50107	48703	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:04	\N
50108	48704	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:04	\N
50109	48705	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:04	\N
50110	48706	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:04	\N
50111	48707	DEPUTE	2012-06-20 00:00:00	\N	2016-03-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:04	2017-08-10 10:57:52
50112	48708	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:04	2017-08-10 10:57:52
50113	48709	DEPUTE	2017-06-21 00:00:00	\N	2020-08-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:04	\N
50114	48710	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:04	\N
50115	48711	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:04	\N
50116	48712	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:04	\N
50117	48713	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:04	\N
50118	48714	DEPUTE	2012-06-20 00:00:00	\N	2013-02-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:04	\N
50119	48715	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:04	\N
50120	48716	DEPUTE	2017-06-21 00:00:00	\N	2020-08-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:04	\N
50121	48717	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:04	\N
50122	48718	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:04	\N
50123	48719	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:04	\N
50124	48720	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:04	\N
50125	48721	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:04	\N
50126	48722	DEPUTE	2017-06-21 00:00:00	\N	2018-07-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:05	\N
50127	48723	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:05	\N
50128	48724	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:05	\N
50129	48725	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:05	\N
50130	48726	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:05	\N
50131	48727	DEPUTE	2012-06-20 00:00:00	\N	2012-10-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:05	\N
50132	48728	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:05	\N
50133	48729	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:05	\N
50134	48730	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:05	\N
50135	48731	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:05	\N
50136	48732	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:05	\N
50137	48733	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:05	\N
50138	48734	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:05	\N
50140	48736	SECAN	2017-06-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:05	2017-08-10 10:57:53
50141	48737	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:05	\N
50142	48738	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:05	\N
50143	48739	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:06	\N
50144	48740	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:06	\N
50145	48741	DEPUTE	2017-06-21 00:00:00	\N	2017-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:06	\N
50146	48742	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:06	\N
50147	48743	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:06	\N
50148	48744	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:06	\N
50149	48745	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:06	\N
50150	48746	DEPUTE	2012-06-20 00:00:00	\N	2015-07-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:06	2017-08-10 03:44:24
50151	48747	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:06	2017-08-10 03:44:24
50152	48748	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:06	\N
50153	48749	DEPUTE	2012-06-20 00:00:00	\N	2013-01-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:06	\N
50154	48750	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:06	\N
50155	48751	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:06	\N
50156	48752	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:06	\N
50157	48753	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:06	\N
50158	48754	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:06	\N
50159	48755	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:06	\N
50160	48756	DEPUTE	2012-07-22 00:00:00	\N	2016-03-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:07	\N
50161	48757	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:07	\N
50162	48758	DEPUTE	2012-07-22 00:00:00	\N	2014-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:07	\N
50163	48759	DEPUTE	2014-06-02 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:07	\N
50164	48760	DEPUTE	2014-07-04 00:00:00	\N	2015-07-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:07	\N
50165	48761	DEPUTE	2017-06-21 00:00:00	\N	2017-12-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:07	2017-12-20 03:44:45
50166	48762	DEPUTE	2012-07-22 00:00:00	\N	2015-04-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:07	\N
50167	48763	DEPUTE	2017-06-21 00:00:00	\N	2020-03-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:07	\N
50168	48764	DEPUTE	2014-10-05 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:07	\N
50169	48765	DEPUTE	2012-07-22 00:00:00	\N	2017-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:07	\N
50170	48766	DEPUTE	2012-07-22 00:00:00	\N	2014-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:07	\N
50171	48767	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:07	\N
50172	48768	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:07	\N
50173	48769	DEPUTE	2016-04-16 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:07	\N
50174	48770	DEPUTE	2014-05-10 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:07	\N
50175	48771	DEPUTE	2014-05-10 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:07	\N
50176	48772	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:07	\N
50177	48773	DEPUTE	2012-07-22 00:00:00	\N	2016-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:07	\N
50178	48774	DEPUTE	2015-08-28 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:07	\N
50179	48775	DEPUTE	2017-06-16 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:07	\N
50180	48776	DEPUTE	2016-03-12 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:07	\N
50181	48777	DEPUTE	2012-07-22 00:00:00	\N	2014-07-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:07	\N
50182	48778	DEPUTE	2012-07-22 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:07	\N
50183	48779	DEPUTE	2014-09-27 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:07	\N
50184	48780	DEPUTE	2014-07-04 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:07	\N
50185	48781	DEPUTE	2017-01-07 00:00:00	\N	2017-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:07	\N
50186	48782	DEPUTE	2014-05-10 00:00:00	\N	2017-03-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:07	\N
50187	48783	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:07	\N
50188	48784	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:08	\N
50189	48785	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:08	\N
50190	48786	DEPUTE	2012-07-22 00:00:00	\N	2014-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:08	\N
50191	48787	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:08	\N
50192	48788	DEPUTE	2016-03-12 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:08	\N
50193	48789	DEPUTE	2016-03-12 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:08	\N
50194	48790	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:08	\N
50195	48791	DEPUTE	2015-07-18 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:08	\N
50196	48792	DEPUTE	2016-06-13 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:08	\N
50197	48793	DEPUTE	2016-03-12 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:08	\N
50198	48794	DEPUTE	2012-12-17 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:08	\N
50199	48795	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:08	\N
47395	49737	VICPDTAN	2002-06-26 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:05	\N
50763	49738	SECAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:07	\N
50763	49739	DEPUTE	1993-04-02 00:00:00	\N	1994-11-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:07	\N
47459	49740	DEPUTE	1988-06-06 00:00:00	\N	1988-06-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:07	\N
47459	49741	VICPDTAN	1988-06-24 00:00:00	\N	1989-04-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:07	\N
47459	49742	DEPUTE	1989-04-04 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:07	\N
47466	49743	DEPUTE	1997-06-01 00:00:00	\N	1997-06-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:07	\N
47466	49744	SECAN	1997-06-13 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:07	\N
47476	49745	DEPUTE	2002-06-19 00:00:00	\N	2004-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:07	\N
47476	49746	SECAN	2004-10-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:07	\N
47477	49747	DEPUTE	2007-06-20 00:00:00	\N	2009-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:07	\N
47477	49748	SECAN	2009-10-06 00:00:00	\N	2010-10-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:07	\N
47477	49749	DEPUTE	2010-10-06 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:07	\N
47523	49750	DEPUTE	2002-06-19 00:00:00	\N	2002-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:08	\N
47523	49751	SECAN	2002-06-26 00:00:00	\N	2004-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:08	\N
47540	49752	DEPUTE	1997-06-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:08	\N
47540	49753	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:08	\N
47541	49754	DEPUTE	2002-06-19 00:00:00	\N	2002-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:08	\N
47541	49755	VICPDTAN	2002-06-26 00:00:00	\N	2004-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:08	\N
47541	49756	DEPUTE	2004-10-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:08	\N
47543	49757	DEPUTE	2012-06-20 00:00:00	\N	2012-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:08	\N
47543	49758	SECAN	2012-06-27 00:00:00	\N	2013-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:08	\N
47543	49759	DEPUTE	2013-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:08	\N
47542	49760	DEPUTE	2007-06-20 00:00:00	\N	2007-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:08	\N
47542	49761	VICPDTAN	2007-06-27 00:00:00	\N	2009-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:08	\N
47542	49762	DEPUTE	2009-10-07 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:08	\N
47559	49763	DEPUTE	1997-06-01 00:00:00	\N	1997-06-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:09	\N
47559	49764	VICPDTAN	1997-06-13 00:00:00	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:09	\N
47559	49765	DEPUTE	1998-10-01 00:00:00	\N	2001-04-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:09	\N
47571	49766	DEPUTE	1986-04-02 00:00:00	\N	1988-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:09	\N
47571	49767	VICPDTAN	1988-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:09	\N
47592	49768	DEPUTE	2002-06-19 00:00:00	\N	2004-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:09	\N
47592	49769	SECAN	2004-10-01 00:00:00	\N	2005-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:09	\N
47592	49770	DEPUTE	2005-10-04 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:09	\N
47593	49771	DEPUTE	2007-06-20 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:09	\N
47593	49772	SECAN	2008-10-01 00:00:00	\N	2009-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:09	\N
47593	49773	DEPUTE	2009-10-07 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:09	\N
50764	49774	SECAN	2010-10-05 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:10	\N
50764	49775	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:10	\N
47622	49776	DEPUTE	2007-06-20 00:00:00	\N	2007-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:10	\N
47622	49777	SECAN	2007-06-27 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:10	\N
47622	49778	DEPUTE	2008-10-02 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:10	\N
47635	49779	DEPUTE	1993-04-02 00:00:00	\N	1993-04-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:10	\N
47635	49780	SECAN	1993-04-07 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:10	\N
47636	49781	DEPUTE	1988-06-13 00:00:00	\N	1988-06-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:10	\N
47636	49782	SECAN	1988-06-24 00:00:00	\N	1992-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:10	\N
47636	49783	DEPUTE	1992-04-02 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:10	\N
47673	49784	DEPUTE	1986-04-02 00:00:00	\N	1987-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:11	\N
47673	49785	SECAN	1987-04-02 00:00:00	\N	1988-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:11	\N
47673	49786	DEPUTE	1988-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:11	\N
47726	49787	DEPUTE	1986-04-02 00:00:00	\N	1987-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:13	\N
47726	49788	VICPDTAN	1987-04-02 00:00:00	\N	1988-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:13	\N
47726	49789	DEPUTE	1988-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:13	\N
47807	49790	DEPUTE	1997-06-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:14	\N
47807	49791	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:14	\N
47807	49792	DEPUTE	2000-10-03 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:14	\N
47842	49793	DEPUTE	2012-06-20 00:00:00	\N	2016-09-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:15	\N
47842	49794	QUESTAN	2016-09-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:15	\N
47853	49795	DEPUTE	1986-04-02 00:00:00	\N	1986-04-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:15	\N
47853	49796	QUESTAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:15	\N
47866	49797	DEPUTE	1997-06-01 00:00:00	\N	2000-03-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:16	\N
47866	49798	VICPDTAN	2000-03-30 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:16	\N
50765	49799	VICPDTAN	2007-06-27 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:16	\N
50765	49800	DEPUTE	2012-06-20 00:00:00	\N	2012-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:16	\N
50765	49801	VICPDTAN	2012-06-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:16	\N
47906	49802	DEPUTE	2002-06-19 00:00:00	\N	2002-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:16	\N
47906	49803	VICPDTAN	2002-06-26 00:00:00	\N	2005-06-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:16	\N
47906	49804	DEPUTE	2005-06-09 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:16	\N
47903	49805	DEPUTE	1986-04-02 00:00:00	\N	1988-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:17	\N
47903	49806	SECAN	1988-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:17	\N
47912	49807	DEPUTE	2002-06-19 00:00:00	\N	2004-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:17	\N
47912	49808	SECAN	2004-10-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:17	\N
47913	49809	DEPUTE	2007-06-20 00:00:00	\N	2007-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:17	\N
47913	49810	VICPDTAN	2007-06-27 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:17	\N
47913	49811	DEPUTE	2008-10-02 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:17	\N
47952	49812	DEPUTE	2007-06-20 00:00:00	\N	2007-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:17	\N
47952	49813	QUESTAN	2007-06-27 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:17	\N
47963	49814	DEPUTE	1988-06-13 00:00:00	\N	1988-06-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:18	\N
47963	49815	SECAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:18	\N
47962	49816	DEPUTE	1986-04-02 00:00:00	\N	1986-04-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:18	\N
47962	49817	SECAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:18	\N
47990	49818	DEPUTE	1993-04-02 00:00:00	\N	1993-04-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:19	\N
47990	49819	SECAN	1993-04-07 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:19	\N
48013	49820	DEPUTE	1988-06-13 00:00:00	\N	1988-06-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:19	\N
48013	49821	SECAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:19	\N
48108	49822	DEPUTE	1993-04-02 00:00:00	\N	1993-04-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:21	\N
48108	49823	QUESTAN	1993-04-07 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:21	\N
48182	49824	DEPUTE	1993-04-02 00:00:00	\N	1993-04-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:22	\N
48182	49825	SECAN	1993-04-07 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:22	\N
48184	49826	DEPUTE	2002-06-19 00:00:00	\N	2002-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:22	\N
48184	49827	SECAN	2002-06-26 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:22	\N
48198	49828	DEPUTE	2002-06-19 00:00:00	\N	2002-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:23	\N
48198	49829	SECAN	2002-06-26 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:23	\N
34936	33533	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:51	\N
34937	33534	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:51	\N
34938	33535	DEPUTE	2002-07-19 00:00:00	\N	2004-09-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:51	\N
34939	33536	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:51	\N
34940	33537	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:51	\N
34941	33538	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:51	\N
34942	33539	DEPUTE	2002-12-16 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:51	\N
34943	33540	DEPUTE	2007-06-20 00:00:00	\N	2008-04-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:51	\N
34944	33541	DEPUTE	2010-08-05 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:51	\N
34945	33542	DEPUTE	2008-04-19 00:00:00	\N	2010-08-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:51	\N
34946	33543	DEPUTE	2003-06-25 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:51	\N
34947	33544	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:51	\N
34948	33545	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:51	\N
34949	33546	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:51	\N
34950	33547	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:51	\N
34951	33548	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:52	\N
34952	33549	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:52	\N
34953	33550	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:52	\N
34954	33551	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:52	\N
34955	33552	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:52	\N
34956	33553	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:52	\N
34957	33554	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:52	\N
34958	33555	DEPUTE	2004-03-30 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:52	\N
34959	33556	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:52	\N
34960	33557	DEPUTE	2004-05-01 00:00:00	\N	2005-08-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:52	\N
34961	33558	DEPUTE	2010-12-15 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:52	\N
34962	33559	DEPUTE	2004-05-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:52	\N
34963	33560	DEPUTE	2007-07-20 00:00:00	\N	2009-02-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:52	\N
34964	33561	DEPUTE	2010-12-15 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:52	\N
34965	33562	DEPUTE	2004-05-01 00:00:00	\N	2005-07-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:52	\N
34966	33563	DEPUTE	2010-04-23 00:00:00	\N	2010-12-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:52	\N
34967	33564	DEPUTE	2004-05-01 00:00:00	\N	2005-07-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:52	\N
34968	33565	DEPUTE	2007-07-20 00:00:00	\N	2010-12-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:52	\N
34969	33566	DEPUTE	2007-07-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:52	\N
34970	33567	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:52	\N
34971	33568	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:52	\N
34972	33569	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:52	\N
34973	33570	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:52	\N
34974	33571	DEPUTE	2004-05-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:52	\N
34975	33572	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:52	\N
34976	33573	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:52	\N
34977	33574	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:53	\N
34978	33575	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:53	\N
34979	33576	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:53	\N
34980	33577	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:53	\N
34981	33578	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:53	\N
34982	33579	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:53	\N
34983	33580	DEPUTE	2007-06-20 00:00:00	\N	2010-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:53	\N
34984	33581	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:53	\N
34985	33582	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:53	\N
34986	33583	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:53	\N
34987	33584	DEPUTE	2012-06-20 00:00:00	\N	2016-03-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:53	\N
34988	33585	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:53	\N
34989	33586	DEPUTE	2007-06-20 00:00:00	\N	2008-04-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:53	\N
34990	33587	DEPUTE	2009-07-24 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:53	\N
34991	33588	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:53	\N
34992	33589	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:53	\N
34993	33590	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:53	\N
34994	33591	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:53	\N
34995	33592	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:53	\N
34996	33593	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:53	\N
34997	33594	DEPUTE	2007-06-26 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:53	\N
34998	33595	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:53	\N
34999	33596	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:53	\N
35000	33597	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:53	\N
35001	33598	DEPUTE	2005-01-24 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:53	\N
35002	33599	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:53	\N
35003	33600	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:53	\N
35004	33601	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:53	\N
35005	33602	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:53	\N
35006	33603	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:54	\N
35007	33604	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:54	\N
35008	33605	DEPUTE	1995-09-17 00:00:00	\N	1995-10-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:54	\N
35009	33606	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:54	\N
35010	33607	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:54	\N
35011	33608	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:54	\N
35012	33609	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:54	\N
35013	33610	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:54	\N
35014	33611	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:54	\N
35015	33612	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:54	\N
35016	33613	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:54	\N
35017	33614	SECAN	2000-04-06 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:54	\N
35018	33615	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:54	\N
35019	33616	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:54	\N
35020	33617	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:54	\N
35021	33618	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:54	\N
35022	33619	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:54	\N
35023	33620	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:54	\N
35024	33621	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:54	\N
35025	33622	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:54	\N
35026	33623	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:54	\N
35027	33624	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:54	\N
35028	33625	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:54	\N
36457	35054	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:59	\N
36458	35055	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:59	\N
36459	35056	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:59	\N
36460	35057	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:59	\N
36461	35058	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:59	\N
36462	35059	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:59	\N
36463	35060	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:59	\N
36464	35061	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:59	\N
36465	35062	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:00	\N
36466	35063	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:00	\N
36467	35064	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:00	\N
36468	35065	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:00	\N
36469	35066	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:00	\N
36470	35067	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:00	\N
36471	35068	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:00	\N
36472	35069	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:00	\N
36473	35070	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:00	\N
36474	35071	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:00	\N
36475	35072	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:00	\N
36476	35073	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:00	\N
36477	35074	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:00	\N
36478	35075	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:00	\N
36479	35076	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:00	\N
36480	35077	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:00	\N
36481	35078	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:00	\N
36482	35079	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:00	\N
36483	35080	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:00	\N
36484	35081	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:01	\N
36485	35082	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:01	\N
36486	35083	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:01	\N
36487	35084	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:01	\N
36488	35085	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:01	\N
36489	35086	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:01	\N
36490	35087	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:01	\N
36491	35088	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:01	\N
36492	35089	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:01	\N
36493	35090	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:01	\N
36494	35091	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:01	\N
36495	35092	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:01	\N
36496	35093	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:01	\N
36497	35094	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:01	\N
36498	35095	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:01	\N
36499	35096	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:01	\N
36500	35097	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:01	\N
36501	35098	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:01	\N
36502	35099	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:01	\N
36503	35100	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:02	\N
36504	35101	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:02	\N
36505	35102	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:02	\N
36506	35103	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:02	\N
36507	35104	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:02	\N
36508	35105	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:02	\N
36509	35106	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:02	\N
36510	35107	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:02	\N
36511	35108	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:02	\N
36512	35109	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:02	\N
36513	35110	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:02	\N
36514	35111	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:02	\N
36515	35112	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:02	\N
36516	35113	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:02	\N
36517	35114	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:02	\N
36518	35115	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:02	\N
36519	35116	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:02	\N
36520	35117	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:02	\N
36521	35118	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:02	\N
36522	35119	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:02	\N
36523	35120	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:02	\N
36524	35121	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:02	\N
36525	35122	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:02	\N
36526	35123	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:02	\N
36527	35124	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:02	\N
36528	35125	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:02	\N
36529	35126	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:02	\N
36530	35127	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:03	\N
36531	35128	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:03	\N
36532	35129	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:03	\N
36533	35130	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:03	\N
36534	35131	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:03	\N
36535	35132	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:03	\N
36536	35133	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:03	\N
36537	35134	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:03	\N
36538	35135	SECAN	2012-06-27 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:03	\N
36539	35136	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:03	\N
36540	35137	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:03	\N
36541	35138	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:03	\N
36542	35139	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:03	\N
36543	35140	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:03	\N
36544	35141	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:03	\N
36545	35142	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:03	\N
36546	35143	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:03	\N
36547	35144	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:03	\N
36548	35145	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:03	\N
36549	35146	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:03	\N
36550	35147	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:03	\N
36551	35148	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:03	\N
36552	35149	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:03	\N
36553	35150	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:03	\N
36554	35151	DEPUTE	2016-02-28 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:03	\N
36555	35152	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:04	\N
36556	35153	DEPUTE	2012-06-26 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:04	\N
50200	48796	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:08	\N
50201	48797	DEPUTE	2014-05-10 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:08	\N
50202	48798	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:08	\N
50203	48799	DEPUTE	2013-08-03 00:00:00	\N	2014-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:08	\N
50204	48800	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:08	\N
50205	48801	DEPUTE	2013-03-24 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:08	\N
50206	48802	DEPUTE	2017-06-21 00:00:00	\N	2018-02-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:08	2018-02-06 03:44:45
33736	32333	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:09	\N
50207	48803	DEPUTE	2013-06-10 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:08	\N
50208	48804	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:08	\N
50209	48805	DEPUTE	2013-06-24 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:08	\N
50210	48806	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:08	\N
50211	48807	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:08	\N
50212	48808	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:08	\N
50213	48809	DEPUTE	2016-04-25 00:00:00	1500	2017-06-20 00:00:00	1600	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:08	2023-09-26 15:38:56
50214	48810	DEPUTE	2016-05-30 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:08	\N
50215	48811	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:08	\N
50216	48812	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:09	\N
50217	48813	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:09	\N
50218	48814	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:09	\N
50219	48815	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:09	\N
50220	48816	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:09	\N
50221	48817	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:09	\N
50222	48818	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:09	\N
50223	48819	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:09	\N
50224	48820	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:09	\N
50225	48821	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:09	\N
50226	48822	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:09	\N
50227	48823	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:09	\N
50228	48824	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:09	\N
50229	48825	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:09	\N
50230	48826	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:09	\N
50231	48827	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:09	\N
50232	48828	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:09	\N
50233	48829	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:09	\N
50234	48830	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:09	\N
50235	48831	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:09	\N
50236	48832	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:09	\N
50237	48833	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:09	\N
50238	48834	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:09	\N
50239	48835	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:09	\N
50240	48836	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:10	\N
50241	48837	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:10	\N
50242	48838	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:10	\N
50243	48839	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:10	\N
50244	48840	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:10	\N
50245	48841	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:10	\N
50246	48842	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:10	\N
50247	48843	DEPUTE	2015-09-14 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:10	\N
50248	48844	DEPUTE	2017-06-21 00:00:00	\N	2021-07-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:10	\N
50249	48845	DEPUTE	1968-09-06 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:10	\N
50250	48846	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:10	\N
50251	48847	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:10	\N
50252	48848	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:10	\N
50253	48849	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:10	\N
50254	48850	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:10	\N
50255	48851	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:10	\N
50256	48852	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:10	\N
50257	48853	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:10	\N
50258	48854	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:10	\N
50259	48855	DEPUTE	2017-06-21 00:00:00	\N	2017-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:10	\N
50260	48856	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:10	\N
50261	48857	DEPUTE	2014-06-30 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:10	\N
50262	48858	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:10	\N
50263	48859	DEPUTE	2014-06-30 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:10	\N
50264	48860	DEPUTE	2014-07-30 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:10	\N
50265	48861	DEPUTE	2017-07-22 00:00:00	\N	2022-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:10	\N
50266	48862	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:11	\N
50267	48863	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:11	\N
50268	48864	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:11	\N
50269	48865	DEPUTE	1973-04-02 00:00:00	\N	1973-05-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:11	\N
50270	48866	DEPUTE	1978-04-03 00:00:00	\N	1978-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:11	\N
50271	48867	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:11	\N
50272	48868	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:11	\N
50273	48869	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:11	\N
50274	48870	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:11	\N
50275	48871	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:11	\N
50276	48872	DEPUTE	1973-04-02 00:00:00	\N	1974-07-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:11	\N
50277	48873	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:11	\N
50278	48874	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:11	\N
50279	48875	DEPUTE	1963-05-12 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:11	\N
50280	48876	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:11	\N
50281	48877	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:11	\N
50282	48878	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:11	\N
50283	48879	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:11	\N
50284	48880	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:11	\N
50285	48881	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:11	\N
50286	48882	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:11	\N
50287	48883	DEPUTE	2017-06-21 00:00:00	\N	2021-01-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:11	\N
50288	48884	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:11	\N
50289	48885	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:11	\N
50290	48886	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:11	\N
50291	48887	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:11	\N
50292	48888	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:12	\N
50293	48889	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:12	\N
50294	48890	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:12	\N
50295	48891	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:12	\N
50296	48892	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:12	\N
48249	49830	DEPUTE	1997-06-01 00:00:00	\N	1997-06-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:24	\N
48249	49831	VICPDTAN	1997-06-13 00:00:00	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:24	\N
48249	49832	DEPUTE	1998-10-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:24	\N
48246	49833	DEPUTE	1993-04-02 00:00:00	\N	1993-04-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:24	\N
48246	49834	VICPDTAN	1993-04-07 00:00:00	\N	1995-06-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:24	\N
48246	49835	DEPUTE	1995-06-15 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:24	\N
48245	49836	DEPUTE	1986-04-02 00:00:00	\N	1986-04-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:24	\N
48245	49837	SECAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:24	\N
48277	49838	DEPUTE	1997-06-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:25	\N
48277	49839	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:25	\N
48277	49840	DEPUTE	2000-10-03 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:25	\N
48278	49841	DEPUTE	2002-06-19 00:00:00	\N	2002-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:25	\N
48278	49842	SECAN	2002-06-26 00:00:00	\N	2006-11-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:25	\N
48278	49843	DEPUTE	2006-12-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:25	\N
48280	49844	DEPUTE	2012-06-20 00:00:00	\N	2013-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:25	\N
48280	49845	SECAN	2013-10-01 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:25	\N
48280	49846	DEPUTE	2014-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:25	\N
48311	49847	DEPUTE	2012-06-20 00:00:00	\N	2012-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:26	\N
48311	49848	QUESTAN	2012-06-27 00:00:00	\N	2016-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:26	\N
48327	49849	DEPUTE	2002-06-19 00:00:00	\N	2002-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:26	\N
48327	49850	SECAN	2002-10-02 00:00:00	\N	2004-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:26	\N
48327	49851	DEPUTE	2004-10-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:26	\N
48359	49852	DEPUTE	2007-06-20 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:27	\N
48359	49853	SECAN	2008-10-01 00:00:00	\N	2009-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:27	\N
48359	49854	DEPUTE	2009-10-07 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:27	\N
48372	49855	DEPUTE	2007-06-20 00:00:00	\N	2007-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:27	\N
48372	49856	SECAN	2007-06-27 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:27	\N
48372	49857	VICPDTAN	2008-10-02 00:00:00	\N	2009-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:27	\N
48372	49858	SECAN	2009-10-07 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:27	\N
48385	49859	DEPUTE	2002-06-19 00:00:00	\N	2002-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:27	\N
48385	49860	SECAN	2002-06-26 00:00:00	\N	2003-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:27	\N
48385	49861	DEPUTE	2003-10-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:27	\N
48431	49862	DEPUTE	1997-06-01 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:27	\N
48431	49863	VICPDTAN	1998-10-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:27	\N
48433	49864	DEPUTE	2002-06-19 00:00:00	\N	2007-03-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:27	\N
48433	49865	PDTAN	2007-03-07 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:28	\N
48462	49866	DEPUTE	1997-06-01 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:28	\N
48462	49867	VICPDTAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:28	\N
48462	49868	DEPUTE	1999-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:28	\N
48485	49869	DEPUTE	1988-06-13 00:00:00	\N	1988-06-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:28	\N
48485	49870	SECAN	1988-06-24 00:00:00	\N	1992-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:28	\N
48485	49871	DEPUTE	1992-04-02 00:00:00	\N	1992-10-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:28	\N
48485	49872	SECAN	1992-10-21 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:28	\N
48484	49873	DEPUTE	1986-04-02 00:00:00	\N	1987-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:28	\N
48484	49874	SECAN	1987-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:28	\N
48490	49875	DEPUTE	1993-04-02 00:00:00	\N	1993-04-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:28	\N
48490	49876	SECAN	1993-04-07 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:28	\N
48489	49877	DEPUTE	1986-04-02 00:00:00	\N	1986-04-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:28	\N
48489	49878	SECAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:28	\N
48594	49879	DEPUTE	1988-06-13 00:00:00	\N	1988-06-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:31	\N
48594	49880	SECAN	1988-06-24 00:00:00	\N	1991-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:31	\N
48594	49881	DEPUTE	1991-04-02 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:31	\N
48599	49882	DEPUTE	1997-06-01 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:31	\N
48599	49883	SECAN	1998-10-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:31	\N
48640	49884	DEPUTE	1997-06-01 00:00:00	\N	1997-06-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:33	\N
48640	49885	SECAN	1997-06-13 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:33	\N
48640	49886	DEPUTE	1999-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:33	\N
48641	49887	DEPUTE	2002-06-19 00:00:00	\N	2002-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:33	\N
48641	49888	SECAN	2002-06-26 00:00:00	\N	2002-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:33	\N
48641	49889	DEPUTE	2002-10-02 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:33	\N
48712	49890	DEPUTE	1997-06-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:34	\N
48712	49891	QUESTAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:34	\N
48714	49892	DEPUTE	2007-06-20 00:00:00	\N	2010-10-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:34	\N
48714	49893	SECAN	2010-10-05 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:34	\N
48718	49894	DEPUTE	1997-06-01 00:00:00	\N	1997-06-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:34	\N
48718	49895	SECAN	1997-06-13 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:34	\N
48719	49896	DEPUTE	2002-06-19 00:00:00	\N	2002-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:34	\N
48719	49897	SECAN	2002-06-26 00:00:00	\N	2004-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:34	\N
48719	49898	DEPUTE	2004-10-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:34	\N
48720	49899	DEPUTE	2007-06-20 00:00:00	\N	2009-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:34	\N
48720	49900	SECAN	2009-10-06 00:00:00	\N	2010-10-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:34	\N
48720	49901	DEPUTE	2010-10-06 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:34	\N
48769	49902	DEPUTE	1997-06-01 00:00:00	\N	1997-06-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:35	\N
48769	49903	VICPDTAN	1997-06-13 00:00:00	\N	1999-02-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:35	\N
48776	49904	DEPUTE	1997-06-01 00:00:00	\N	1997-06-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:35	\N
48776	49905	SECAN	1997-06-13 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:35	\N
48777	49906	DEPUTE	2002-06-19 00:00:00	\N	2003-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:35	\N
48777	49907	SECAN	2003-10-01 00:00:00	\N	2004-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:35	\N
48777	49908	DEPUTE	2004-10-01 00:00:00	\N	2006-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:35	\N
48777	49909	SECAN	2006-10-04 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:35	\N
48778	49910	DEPUTE	2007-06-20 00:00:00	\N	2007-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:35	\N
48778	49911	SECAN	2007-06-27 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:35	\N
48778	49912	DEPUTE	2008-10-02 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:35	\N
48793	49913	DEPUTE	2002-06-19 00:00:00	\N	2002-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:35	\N
48793	49914	SECAN	2002-06-26 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:35	\N
50766	49915	SECAN	2007-06-27 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:35	\N
50766	49916	DEPUTE	2012-06-20 00:00:00	\N	2012-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:35	\N
50766	49917	SECAN	2012-06-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:35	\N
48861	49918	DEPUTE	2007-06-20 00:00:00	\N	2011-07-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:37	\N
48861	49919	VICPDTAN	2011-07-07 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:37	\N
50767	49920	SECAN	2008-10-01 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:38	\N
50767	49921	DEPUTE	2012-06-20 00:00:00	\N	2012-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:38	\N
50767	49922	SECAN	2012-06-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:38	\N
35029	33626	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:54	\N
35030	33627	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:55	\N
35031	33628	DEPUTE	1993-04-02 00:00:00	\N	1995-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:55	\N
35032	33629	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:55	\N
35033	33630	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:55	\N
35034	33631	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:55	\N
35035	33632	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:55	\N
35036	33633	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:55	\N
35037	33634	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:55	\N
35038	33635	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:55	\N
35039	33636	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:55	\N
35040	33637	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:55	\N
35041	33638	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:55	\N
35042	33639	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:55	\N
35043	33640	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:55	\N
35044	33641	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:55	\N
35045	33642	SECAN	1995-06-01 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:55	\N
35046	33643	SECAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:55	\N
35047	33644	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:55	\N
35048	33645	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:56	\N
35049	33646	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:56	\N
35050	33647	SECAN	2002-06-26 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:56	\N
35051	33648	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:56	\N
35052	33649	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:56	\N
35053	33650	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:56	\N
35054	33651	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:56	\N
35055	33652	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:56	\N
35056	33653	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:56	\N
35057	33654	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:56	\N
35058	33655	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:56	\N
35059	33656	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:56	\N
35060	33657	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:56	\N
35061	33658	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:56	\N
35062	33659	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:56	\N
35063	33660	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:56	\N
35064	33661	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:56	\N
35065	33662	DEPUTE	1994-02-08 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:56	\N
35066	33663	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:56	\N
35067	33664	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:57	\N
35068	33665	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:57	\N
35069	33666	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:57	\N
35070	33667	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:57	\N
35071	33668	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:57	\N
35072	33669	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:57	\N
35073	33670	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:57	\N
35074	33671	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:57	\N
35075	33672	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:57	\N
35076	33673	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:57	\N
35077	33674	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:57	\N
35078	33675	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:57	\N
35079	33676	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:57	\N
35080	33677	DEPUTE	2007-06-20 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:57	\N
35081	33678	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:57	\N
35082	33679	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:57	\N
35083	33680	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:57	\N
35084	33681	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:57	\N
35085	33682	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:57	\N
35086	33683	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:58	\N
35087	33684	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:58	\N
35088	33685	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:58	\N
35089	33686	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:58	\N
35090	33687	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:58	\N
35091	33688	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:58	\N
35092	33689	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:58	\N
35093	33690	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:58	\N
35094	33691	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:58	\N
35095	33692	DEPUTE	1997-06-01 00:00:00	\N	1999-12-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:58	\N
35096	33693	DEPUTE	1988-05-08 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:58	\N
35097	33694	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:58	\N
35098	33695	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:58	\N
35099	33696	DEPUTE	1988-06-13 00:00:00	\N	1992-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:58	\N
35100	33697	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:58	\N
35101	33698	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:58	\N
35102	33699	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:58	\N
35103	33700	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:58	\N
35104	33701	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:58	\N
35105	33702	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:58	\N
35106	33703	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:58	\N
35107	33704	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:58	\N
35108	33705	DEPUTE	1986-04-02 00:00:00	\N	1987-10-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:58	\N
35109	33706	DEPUTE	1993-04-02 00:00:00	\N	1996-04-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:58	\N
35110	33707	DEPUTE	1987-10-14 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:58	\N
35111	33708	DEPUTE	1988-06-06 00:00:00	\N	1988-10-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:58	\N
35112	33709	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:58	\N
35113	33710	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:58	\N
35114	33711	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:58	\N
35115	33712	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:58	\N
35116	33713	DEPUTE	1988-06-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:58	\N
35117	33714	DEPUTE	1997-05-17 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:58	\N
35118	33715	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:58	\N
35119	33716	DEPUTE	1978-04-02 00:00:00	\N	1980-09-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:58	\N
35120	33717	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:58	\N
35121	33718	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:58	\N
36557	35154	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:04	\N
36558	35155	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:04	\N
36559	35156	DEPUTE	2014-05-03 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:04	\N
36560	35157	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:04	\N
36561	35158	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:04	\N
36562	35159	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:04	\N
36563	35160	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:04	\N
36564	35161	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:04	\N
36565	35162	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:04	\N
36566	35163	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:04	\N
36567	35164	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:04	\N
36568	35165	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:04	\N
36569	35166	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:04	\N
36570	35167	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:04	\N
36571	35168	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:04	\N
36572	35169	DEPUTE	2015-08-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:04	\N
36573	35170	DEPUTE	2012-06-20 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:04	\N
36574	35171	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:05	\N
36575	35172	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:05	\N
36576	35173	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:05	\N
36577	35174	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:05	\N
36578	35175	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:05	\N
36579	35176	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:05	\N
36580	35177	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:05	\N
36581	35178	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:05	\N
36582	35179	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:05	\N
36583	35180	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:05	\N
36584	35181	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:05	\N
36585	35182	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:05	\N
36586	35183	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:05	\N
36587	35184	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:05	\N
36588	35185	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:05	\N
36589	35186	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:05	\N
36590	35187	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:05	\N
36591	35188	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:05	\N
36592	35189	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:06	\N
36593	35190	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:06	\N
36594	35191	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:06	\N
36595	35192	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:06	\N
36596	35193	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:06	\N
36597	35194	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:06	\N
36598	35195	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:06	\N
36599	35196	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:06	\N
36600	35197	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:06	\N
36601	35198	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:06	\N
36602	35199	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:06	\N
36603	35200	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:06	\N
36604	35201	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:06	\N
36605	35202	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:06	\N
36606	35203	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:06	\N
36607	35204	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:07	\N
36608	35205	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:07	\N
36609	35206	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:07	\N
36610	35207	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:07	\N
36611	35208	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:07	\N
36612	35209	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:34:07	\N
50742	49336	MAIREADJOINT	2014-03-24 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-07-31 12:14:14	2017-07-31 12:15:22
51686	51221	DEPUTE	2019-07-08 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
50327	51215	DEPUTE	2017-06-21 00:00:00	\N	2017-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50327	51216	QUESTAN	2017-06-28 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51687	51222	DEPUTE	2019-08-17 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
45395	51228	DEPUTE	2017-06-21 00:00:00	\N	2019-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
45395	51229	VICPDTAN	2019-10-01 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50422	50028	DEPUTE	2017-06-21 00:00:00	\N	2017-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:48:17	\N
50422	50029	VICPDTAN	2017-06-28 00:00:00	\N	2017-11-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:48:17	2017-11-09 03:45:18
50422	50030	DEPUTE	2017-11-08 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:48:17	2017-11-09 03:45:18
46309	51230	DEPUTE	2017-06-21 00:00:00	\N	2017-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
46309	51231	SECAN	2017-06-28 00:00:00	\N	2019-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
46309	51232	DEPUTE	2019-10-01 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
48856	51233	DEPUTE	2017-06-21 00:00:00	\N	2019-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
48856	51234	SECAN	2019-10-01 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
49582	51235	DEPUTE	2017-06-21 00:00:00	\N	2019-01-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
49582	51236	VICPDTAN	2019-01-15 00:00:00	\N	2019-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
49582	51237	DEPUTE	2019-10-01 00:00:00	\N	2020-06-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
49635	51238	DEPUTE	2017-06-21 00:00:00	\N	2019-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
49635	51239	SECAN	2019-10-01 00:00:00	\N	2021-01-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
49773	51240	DEPUTE	2017-06-21 00:00:00	\N	2017-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
49773	51241	SECAN	2017-06-28 00:00:00	\N	2019-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50579	50043	DEPUTE	2017-06-21 00:00:00	\N	2017-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:48:23	\N
50579	50044	SECAN	2017-06-28 00:00:00	\N	2018-01-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:48:23	2018-02-06 03:45:07
50579	50045	DEPUTE	2018-02-01 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:48:23	2018-02-06 03:45:07
49773	51242	DEPUTE	2019-10-01 00:00:00	\N	2020-06-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50430	51245	DEPUTE	2017-06-21 00:00:00	\N	2017-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50430	51246	SECAN	2017-06-28 00:00:00	\N	2019-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50430	51247	DEPUTE	2019-10-01 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50630	50052	DEPUTE	2017-06-21 00:00:00	\N	2017-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:48:25	\N
50630	50053	VICPDTAN	2017-06-28 00:00:00	\N	2018-01-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:48:25	2018-01-18 03:44:43
50630	50054	DEPUTE	2018-01-17 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:48:25	2018-01-18 03:44:43
50660	50055	DEPUTE	2012-06-20 00:00:00	\N	2012-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:48:26	\N
50464	51248	DEPUTE	2017-06-21 00:00:00	\N	2019-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50464	51249	SECAN	2019-10-01 00:00:00	\N	2020-08-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50525	51250	DEPUTE	2017-06-21 00:00:00	\N	2019-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50525	51251	SECAN	2019-10-01 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50297	48893	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:12	\N
50298	48894	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:12	\N
50299	48895	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:12	\N
50300	48896	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:12	\N
50301	48897	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:12	\N
50302	48898	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:12	\N
50303	48899	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:12	\N
50304	48900	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:12	\N
50305	48901	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:12	\N
50306	48902	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:12	\N
50307	48903	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:12	\N
50308	48904	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:12	\N
50309	48905	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:12	\N
50310	48906	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:12	\N
50311	48907	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:12	\N
50312	48908	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:12	\N
50313	48909	DEPUTE	2017-06-21 00:00:00	\N	2022-01-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:12	\N
50314	48910	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:12	\N
50315	48911	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:12	\N
50316	48912	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:13	\N
50317	48913	DEPUTE	2017-06-21 00:00:00	\N	2022-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:13	\N
50318	48914	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:13	\N
50319	48915	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:13	\N
50320	48916	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:13	\N
50321	48917	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:13	\N
50322	48918	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:13	\N
50323	48919	DEPUTE	2017-06-21 00:00:00	\N	2017-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:13	\N
50324	48920	DEPUTE	2017-07-22 00:00:00	\N	2019-04-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:13	\N
50325	48921	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:13	\N
50326	48922	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:13	\N
50783	50076	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-08 23:16:27	\N
50328	48924	QUESTAN	2017-06-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:13	2017-08-10 03:44:28
50329	48925	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:13	\N
50330	48926	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:13	\N
50331	48927	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:13	\N
50332	48928	DEPUTE	2017-06-21 00:00:00	\N	2021-07-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:13	\N
50333	48929	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:13	\N
50334	48930	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:13	\N
50335	48931	DEPUTE	2017-06-21 00:00:00	\N	2019-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:13	\N
50336	48932	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:13	\N
50337	48933	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:13	\N
50338	48934	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:13	\N
50339	48935	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:13	\N
50340	48936	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:13	\N
50341	48937	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:13	\N
50342	48938	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:14	\N
50343	48939	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:14	\N
50344	48940	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:14	\N
50345	48941	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:14	\N
50346	48942	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:14	\N
50347	48943	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:14	\N
50348	48944	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:14	\N
50349	48945	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:14	\N
50350	48946	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:14	\N
50351	48947	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:14	\N
52721	52665	VICPDTAN	2022-06-29 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
50352	48948	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:14	\N
50353	48949	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:14	\N
50354	48950	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:14	\N
50355	48951	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:14	\N
50356	48952	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:14	\N
50357	48953	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:14	\N
50358	48954	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:14	\N
50359	48955	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:14	\N
50360	48956	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:14	\N
50361	48957	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:14	\N
50362	48958	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:14	\N
50363	48959	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:14	\N
50364	48960	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:15	\N
50795	50088	MAIRE	2001-06-15 00:00:00	\N	2017-09-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-14 11:05:25	2018-02-19 17:02:44
50366	48962	SECAN	2017-06-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:15	2017-08-10 10:57:59
50367	48963	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:15	\N
50368	48964	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:15	\N
50369	48965	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:15	\N
50370	48966	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:15	\N
50371	48967	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:15	\N
50372	48968	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:15	\N
50373	48969	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:15	\N
50374	48970	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:15	\N
50375	48971	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:15	\N
50377	48973	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:15	\N
50378	48974	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:15	\N
50379	48975	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:15	\N
50380	48976	DEPUTE	2017-06-21 00:00:00	\N	2021-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:15	\N
50381	48977	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:16	\N
50382	48978	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:16	\N
50383	48979	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:16	\N
50384	48980	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:16	\N
50385	48981	DEPUTE	2017-06-21 00:00:00	\N	2022-02-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:16	\N
50386	48982	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:16	\N
50387	48983	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:16	\N
50388	48984	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:16	\N
50389	48985	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:16	\N
50390	48986	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:16	\N
50391	48987	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:16	\N
50392	48988	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:16	\N
50393	48989	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:16	\N
50394	48990	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:16	\N
50395	48991	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:16	\N
50397	48993	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:16	\N
48981	49923	DEPUTE	2012-06-20 00:00:00	\N	2012-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:39	\N
48981	49924	SECAN	2012-06-27 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:40	\N
48981	49925	DEPUTE	2014-10-01 00:00:00	\N	2015-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:40	\N
48981	49926	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:40	\N
48995	49927	DEPUTE	2012-06-20 00:00:00	\N	2013-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:40	\N
48995	49928	SECAN	2013-10-01 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:40	\N
48995	49929	DEPUTE	2014-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:40	\N
48993	49930	DEPUTE	2007-06-20 00:00:00	\N	2007-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:40	\N
48993	49931	SECAN	2007-06-27 00:00:00	\N	2011-07-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:40	\N
50768	49932	SECAN	2011-07-07 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:40	\N
50768	49933	DEPUTE	2012-06-20 00:00:00	\N	2012-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:40	\N
50768	49934	SECAN	2012-06-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:40	\N
50769	49935	DEPUTE	2007-06-26 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:42	\N
49114	49936	DEPUTE	1997-06-01 00:00:00	\N	2000-04-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:42	\N
49114	49937	SECAN	2000-04-06 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:42	\N
49142	49938	DEPUTE	1997-06-01 00:00:00	\N	1997-06-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:43	\N
49142	49939	SECAN	1997-06-13 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:43	\N
49141	49940	DEPUTE	1993-04-02 00:00:00	\N	1995-06-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:43	\N
49141	49941	SECAN	1995-06-01 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:43	\N
49143	49942	DEPUTE	2002-06-19 00:00:00	\N	2002-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:43	\N
49143	49943	SECAN	2002-06-26 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:43	\N
49256	49944	DEPUTE	1986-04-02 00:00:00	\N	1986-04-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:45	\N
49256	49945	SECAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:45	\N
49316	49946	DEPUTE	2002-06-19 00:00:00	\N	2005-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:46	\N
49316	49947	VICPDTAN	2005-07-04 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:46	\N
49338	49948	DEPUTE	1997-06-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:47	\N
49338	49949	VICPDTAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:47	\N
49338	49950	DEPUTE	2000-10-03 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:47	\N
49336	49951	DEPUTE	1993-04-02 00:00:00	\N	1993-04-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:47	\N
49336	49952	VICPDTAN	1993-04-07 00:00:00	\N	1995-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:47	\N
49336	49953	DEPUTE	1995-05-31 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:47	\N
49380	49954	DEPUTE	2002-06-19 00:00:00	\N	2006-12-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:48	\N
49380	49955	SECAN	2006-12-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:48	\N
49383	49956	DEPUTE	2012-06-20 00:00:00	\N	2015-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:48	\N
49383	49957	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:48	\N
50770	49958	VICPDTAN	2008-09-26 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:48	\N
50770	49959	DEPUTE	2012-06-20 00:00:00	\N	2012-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:48	\N
50770	49960	VICPDTAN	2012-06-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:48	\N
49453	49961	DEPUTE	2002-06-19 00:00:00	\N	2005-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:50	\N
49453	49962	SECAN	2005-10-04 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:50	\N
49454	49963	DEPUTE	2007-06-20 00:00:00	\N	2007-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:50	\N
49454	49964	QUESTAN	2007-06-27 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:50	\N
49484	49965	DEPUTE	2012-06-20 00:00:00	\N	2014-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:50	\N
49484	49966	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:50	\N
49484	49967	DEPUTE	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:50	\N
49541	49968	DEPUTE	2007-06-20 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:52	\N
49541	49969	VICPDTAN	2008-10-01 00:00:00	\N	2009-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:52	\N
49541	49970	SECAN	2009-10-07 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:52	\N
49552	49971	DEPUTE	2002-06-19 00:00:00	\N	2006-12-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:52	\N
49552	49972	VICPDTAN	2006-12-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:52	\N
50771	49973	VICPDTAN	2010-11-16 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:52	\N
50771	49974	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:52	\N
50772	49975	SECAN	2007-06-27 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:53	\N
50772	49976	DEPUTE	2012-06-20 00:00:00	\N	2012-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:53	\N
50772	49977	SECAN	2012-06-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:53	\N
49609	49978	DEPUTE	2012-06-20 00:00:00	\N	2012-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:53	\N
49609	49979	VICPDTAN	2012-06-27 00:00:00	\N	2014-12-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:53	\N
49609	49980	DEPUTE	2015-01-01 00:00:00	\N	2016-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:53	\N
50773	49981	DEPUTE	2007-06-26 00:00:00	\N	2016-05-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:54	\N
50773	49982	VICPDTAN	2016-05-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:54	\N
49658	49983	DEPUTE	2017-06-21 00:00:00	\N	2017-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:54	\N
49658	49984	PDTAN	2017-06-27 00:00:00	\N	2018-09-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:54	\N
49658	49985	DEPUTE	2018-09-05 00:00:00	\N	2018-10-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:54	2018-06-15 03:44:29
49861	51185	DEPUTE	2017-06-21 00:00:00	\N	2018-01-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
49861	51186	QUESTAN	2018-01-17 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
49790	49992	DEPUTE	1986-04-02 00:00:00	\N	1987-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:57	\N
49790	49993	SECAN	1987-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:57	\N
49856	49994	DEPUTE	2007-06-20 00:00:00	\N	2011-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:59	\N
49856	49995	VICPDTAN	2011-10-03 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:59	\N
50774	49996	DEPUTE	2007-06-26 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:59	\N
49862	49997	DEPUTE	2007-06-20 00:00:00	\N	2007-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:59	\N
49862	49998	SECAN	2007-06-27 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:59	\N
49862	49999	DEPUTE	2008-10-02 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:47:59	\N
50775	50000	DEPUTE	2007-06-26 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:48:00	\N
49908	50001	DEPUTE	2012-06-20 00:00:00	\N	2012-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:48:00	\N
49908	50002	VICPDTAN	2012-06-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:48:00	\N
49917	50003	DEPUTE	2012-06-20 00:00:00	\N	2012-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:48:00	\N
49917	50004	SECAN	2012-06-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:48:00	\N
49940	50005	DEPUTE	2012-06-20 00:00:00	\N	2014-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:48:01	\N
49940	50006	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:48:01	\N
49940	50007	DEPUTE	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:48:01	\N
49966	50008	DEPUTE	2012-06-20 00:00:00	\N	2012-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:48:02	\N
49966	50009	VICPDTAN	2012-06-27 00:00:00	\N	2016-05-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:48:02	\N
49966	50010	DEPUTE	2016-05-10 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:48:02	\N
50044	50011	DEPUTE	2012-06-20 00:00:00	\N	2015-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:48:05	\N
50044	50012	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:48:05	\N
35122	33719	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:59	\N
35123	33720	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:59	\N
35124	33721	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:59	\N
35125	33722	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:59	\N
35126	33723	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:59	\N
35127	33724	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:59	\N
35128	33725	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:59	\N
35129	33726	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:59	\N
35130	33727	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:59	\N
35131	33728	DEPUTE	1991-06-18 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:59	\N
35132	33729	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:59	\N
35133	33730	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:59	\N
35134	33731	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:59	\N
35135	33732	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:59	\N
35136	33733	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:59	\N
35137	33734	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:59	\N
35138	33735	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:59	\N
35139	33736	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:59	\N
35140	33737	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:59	\N
35141	33738	DEPUTE	2014-05-01 00:00:00	\N	2014-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:59	\N
35142	33739	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:59	\N
35143	33740	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:59	\N
35144	33741	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:59	\N
35145	33742	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:59	\N
35146	33743	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:59	\N
35147	33744	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:59	\N
35148	33745	DEPUTE	1987-06-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:59	\N
35149	33746	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:59	\N
35150	33747	DEPUTE	1993-04-02 00:00:00	\N	1994-10-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:59	\N
35151	33748	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:59	\N
35152	33749	DEPUTE	2002-06-19 00:00:00	\N	2004-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:59	\N
35153	33750	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:59	\N
35154	33751	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:59	\N
35155	33752	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:59	\N
35156	33753	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:00	\N
35157	33754	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:00	\N
35158	33755	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:00	\N
35159	33756	SECAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:00	\N
35160	33757	DEPUTE	1993-04-02 00:00:00	\N	1995-12-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:00	\N
35161	33758	DEPUTE	1991-06-17 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:00	\N
35162	33759	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:00	\N
35163	33760	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:00	\N
35164	33761	DEPUTE	1968-07-11 00:00:00	\N	1969-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:00	\N
35165	33762	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:00	\N
35166	33763	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:00	\N
35167	33764	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:00	\N
35168	33765	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:00	\N
35169	33766	DEPUTE	1993-04-02 00:00:00	\N	1995-05-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:00	\N
35170	33767	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:00	\N
35171	33768	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:00	\N
35172	33769	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:00	\N
35173	33770	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:00	\N
35174	33771	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:00	\N
35175	33772	DEPUTE	1988-06-13 00:00:00	\N	1991-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:00	\N
35176	33773	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:00	\N
35177	33774	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:00	\N
35178	33775	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:00	\N
35179	33776	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:00	\N
35180	33777	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:00	\N
35181	33778	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:00	\N
35182	33779	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:00	\N
35183	33780	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:00	\N
35184	33781	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:00	\N
35185	33782	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:00	\N
35186	33783	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:00	\N
35187	33784	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:00	\N
35188	33785	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:00	\N
35189	33786	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:00	\N
35190	33787	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:00	\N
35191	33788	DEPUTE	1980-11-30 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:00	\N
35192	33789	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:00	\N
35193	33790	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:01	\N
35194	33791	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:01	\N
35195	33792	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:01	\N
35196	33793	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:01	\N
35197	33794	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:01	\N
35198	33795	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:01	\N
35199	33796	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:01	\N
35200	33797	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:01	\N
35201	33798	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:01	\N
35202	33799	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:01	\N
35203	33800	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:01	\N
35204	33801	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:01	\N
35205	33802	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:01	\N
35206	33803	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:01	\N
35207	33804	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:01	\N
35208	33805	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:01	\N
35209	33806	DEPUTE	1986-04-02 00:00:00	\N	1988-04-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:01	\N
35210	33807	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:01	\N
35211	33808	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:01	\N
35212	33809	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:01	\N
35213	33810	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:01	\N
35214	33811	DEPUTE	1995-12-12 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:01	\N
50660	50056	SECAN	2012-06-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:48:26	\N
50705	50057	DEPUTE	2017-06-21 00:00:00	\N	2017-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:48:27	\N
50705	50058	QUESTAN	2017-06-28 00:00:00	\N	2018-01-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:48:27	2018-01-18 03:44:47
50705	50059	DEPUTE	2018-01-17 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:48:27	2018-01-18 03:44:47
50709	50060	DEPUTE	2012-06-20 00:00:00	\N	2014-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:48:27	\N
50709	50061	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:48:27	\N
50709	50062	DEPUTE	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 16:48:27	\N
51004	50973	CONSMET	2017-10-23 00:00:00	\N	2018-04-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2018-01-25 16:53:56	2018-01-25 16:54:07
50782	50075	DEPUTE	2017-08-22 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-30 03:44:51	\N
50811	50101	CONSMUNI	2014-03-23 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-19 15:47:51	2017-09-19 15:49:03
50845	50143	MAIRE	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-19 17:27:59	2017-09-19 17:28:19
50846	50144	PREPDTINTCOM	2017-01-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-19 17:29:24	2017-09-19 17:29:52
50850	50148	CONSDPT	2015-03-29 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-19 17:31:18	2017-09-19 17:32:13
50851	50149	CONSREG	2015-12-13 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-19 17:36:42	2017-09-19 17:36:59
50853	50151	CONSMUNI	2001-03-18 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-19 17:40:15	2017-09-19 17:40:34
50854	50152	MAIRE	1989-03-19 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-19 17:42:01	2017-09-19 17:42:15
50855	50153	PREPDTINTCOM	2014-03-31 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-19 17:43:36	2017-09-19 17:45:40
50858	50156	CONSGENE	1998-03-22 00:00:00	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-19 17:54:00	2017-09-19 17:57:15
50861	50160	MAIRE	2014-03-31 00:00:00	\N	2015-12-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-19 17:59:25	2017-09-19 18:00:03
50860	50159	VICPDTDPT	2015-03-30 00:00:00	\N	2017-09-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-19 17:56:00	2017-11-06 12:02:30
50862	50161	MAIRE	2016-01-01 00:00:00	\N	2017-10-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-19 17:59:33	2017-11-06 12:01:20
50864	50163	MAIRE	1989-03-19 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-19 18:10:07	2017-09-19 18:10:27
50865	50164	VICPDTDPT	2008-03-16 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-19 18:12:54	2017-09-19 18:13:16
50867	50166	CONSMUNI	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-19 18:20:53	2017-09-19 18:21:11
50868	50167	CONSREG	2010-03-21 00:00:00	\N	2015-12-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-19 18:25:36	2017-09-19 18:26:16
50869	50168	CONSREG	2015-12-13 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-19 18:25:46	2017-09-19 18:26:28
50870	50169	CONSMUNI	2008-03-16 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-19 18:37:38	2017-09-19 18:37:56
50871	50170	PDTINTCOM	2017-01-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-19 18:38:02	2017-09-19 18:38:30
50904	50207	VICPDTREG	2015-12-13 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 11:49:17	2017-09-20 11:49:53
50905	50208	MAIRE	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 11:51:10	2017-09-20 11:51:55
12532	50221	CINQADJOINT	2016-05-11 00:00:00	\N	2017-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-20 13:43:58	2017-09-20 13:44:20
50917	50222	MAIRE	2017-01-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 13:53:13	2017-09-20 13:53:43
50918	50223	MAIRE	1983-03-13 00:00:00	\N	2004-03-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-20 13:55:12	2017-09-20 14:09:32
50918	50224	PREMADJOINT	2004-03-28 00:00:00	\N	2016-12-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-20 14:09:21	2017-09-20 14:09:52
50919	50225	CONSDPT	2015-03-29 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 14:11:59	2017-09-20 14:13:51
50920	50226	CONSGENE	1988-10-02 00:00:00	\N	2004-03-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-20 14:12:02	2017-09-20 14:12:39
50920	50227	PDTGEN	2004-03-28 00:00:00	\N	2015-03-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-20 14:12:54	2017-09-20 14:13:12
50921	50228	CONSMUNI	2014-03-30 00:00:00	\N	2017-10-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-20 14:31:16	2017-11-28 14:46:37
50921	50229	MAIRE	2008-03-16 00:00:00	\N	2014-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-20 14:31:30	2017-09-20 14:31:59
50922	50230	VICPDTDPT	2015-03-29 00:00:00	\N	2017-11-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-20 14:34:26	2017-11-28 14:46:56
50923	50231	MAIRE	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 14:37:08	2017-09-20 14:37:29
50924	50232	CONSCOMINT	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 14:37:35	2017-09-20 14:38:28
50925	50233	MAIRE	2008-03-16 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 14:40:31	2017-09-20 14:40:49
50926	50234	PDTINTCOM	2008-03-16 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 14:40:59	2017-09-20 14:45:15
50927	50235	CONSMUNI	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 14:47:36	2017-09-20 14:48:40
50928	50236	CONSREG	2015-12-13 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 14:49:57	2017-09-20 14:50:11
50929	50237	CONSCOMINT	2015-12-13 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 14:52:14	2017-09-20 14:52:50
50930	50238	MAIRE	2001-03-18 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 14:53:41	2017-09-20 14:54:02
50931	50239	CONSDPT	2015-03-29 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 15:14:58	2017-09-20 15:15:40
50932	50240	MAIRE	2008-03-16 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 15:16:42	2017-09-20 15:17:00
50933	50241	MAIRE	2001-03-18 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 15:27:58	2017-09-20 15:28:16
50934	50242	MAIRE	2016-01-05 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 15:31:56	2017-09-24 20:21:48
50935	50243	MAIREADJOINT	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 15:33:45	2017-09-22 15:56:02
50936	50244	CONSDPT	2015-03-29 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 15:35:55	2017-09-20 15:36:12
50937	50245	MAIRE	1989-03-19 00:00:00	\N	2017-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-20 15:45:36	2017-09-27 10:40:52
50938	50246	CONSDPT	2015-03-29 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 15:47:34	2017-09-20 15:47:51
50939	50247	CONSMUNI	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 15:50:45	2017-09-20 15:51:03
50940	50248	MAIREADJOINT	2014-03-30 00:00:00	\N	2017-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-20 15:51:51	2017-11-08 17:35:39
50941	50249	CONSMUNI	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 15:54:28	2017-09-20 15:55:03
50942	50250	CONSMUNI	2014-03-30 00:00:00	\N	2020-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-20 16:03:20	2017-09-20 16:05:25
50944	50252	CONSMUNI	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 16:10:12	2017-09-20 16:11:04
50946	50254	CONSMUNI	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 16:16:35	2017-09-20 16:17:07
50947	50255	MAIRE	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 16:18:05	2017-09-20 16:18:58
50948	50256	MAIRE	2001-03-18 00:00:00	\N	2008-03-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-20 16:20:16	2017-09-29 10:47:38
50949	50257	MAIRE	1499-12-31 00:50:39	1500	2023-11-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-09-20 16:21:22	2023-09-27 11:56:56
50950	50258	MAIREADJOINT	2016-01-01 00:00:00	\N	2017-10-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-20 16:27:05	2018-05-30 09:24:02
50951	50259	MAIREDEL	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 16:30:05	2017-09-20 16:30:53
50953	50261	MAIREADJOINT	2014-03-30 00:00:00	\N	2017-10-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-20 16:37:13	2017-11-27 12:40:34
50955	50263	MAIRE	1989-03-19 00:00:00	\N	2017-10-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-20 16:41:41	2017-12-06 14:24:35
50956	50264	CONSMUNI	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 16:43:55	2017-09-20 16:44:58
12075	50265	CONSGENE	\N	2008	2015-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-20 16:44:09	2017-09-20 16:44:46
50399	48995	SECAN	2017-06-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:16	2017-08-10 10:58:00
50401	48997	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:17	\N
50402	48998	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:17	\N
50403	48999	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:17	\N
50404	49000	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:17	\N
50405	49001	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:17	\N
50406	49002	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:17	\N
50407	49003	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:17	\N
50408	49004	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:17	\N
50409	49005	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:17	\N
50410	49006	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:17	\N
50411	49007	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:17	\N
50906	50209	CONSMUNI	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 11:55:31	2017-09-20 11:58:16
50413	49009	QUESTAN	2017-06-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:17	2017-08-10 03:44:31
50414	49010	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:17	\N
50415	49011	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:17	\N
50416	49012	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:17	\N
50418	49014	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:17	\N
50419	49015	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:17	\N
50420	49016	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:17	\N
50912	50216	MAIRE	2008-03-16 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 12:02:22	2017-09-20 12:03:42
50423	49019	VICPDTAN	2017-06-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:17	2017-08-09 03:44:52
50424	49020	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:17	\N
50425	49021	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:17	\N
50426	49022	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:17	\N
50427	49023	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:18	\N
50428	49024	DEPUTE	2017-06-21 00:00:00	\N	2017-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:18	\N
50429	49025	DEPUTE	2017-07-22 00:00:00	\N	2022-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:18	\N
50431	49027	SECAN	2017-06-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:18	2017-08-10 10:58:01
50432	49028	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:18	\N
50433	49029	DEPUTE	2017-06-21 00:00:00	\N	2018-11-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:18	\N
50434	49030	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:18	\N
50435	49031	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:18	\N
50436	49032	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:18	\N
50437	49033	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:18	\N
50438	49034	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:18	\N
53925	53732	DEPUTE	2024-02-10 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
50439	49035	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:18	\N
50440	49036	DEPUTE	2017-06-21 00:00:00	\N	2020-08-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:18	\N
50441	49037	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:18	\N
50442	49038	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:18	\N
50443	49039	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:18	\N
50444	49040	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:18	\N
50445	49041	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:18	\N
50446	49042	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:18	\N
50447	49043	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:18	\N
50448	49044	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:18	\N
50449	49045	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:18	\N
50450	49046	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:18	\N
50452	49048	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:19	\N
50453	49049	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:19	\N
50454	49050	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:19	\N
50455	49051	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:19	\N
50456	49052	DEPUTE	2017-06-21 00:00:00	\N	2022-01-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:19	\N
50457	49053	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:19	\N
50458	49054	DEPUTE	2017-07-22 00:00:00	\N	2018-11-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:19	\N
50459	49055	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:19	\N
50460	49056	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:19	\N
50461	49057	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:19	\N
50462	49058	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:19	\N
50463	49059	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:19	\N
50465	49061	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:19	\N
50466	49062	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:19	\N
50467	49063	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:19	\N
50468	49064	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:19	\N
50469	49065	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:19	\N
50470	49066	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:19	\N
50471	49067	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:19	\N
50472	49068	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:19	\N
50473	49069	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:20	\N
50474	49070	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:20	\N
50475	49071	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:20	\N
50476	49072	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:20	\N
50477	49073	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:20	\N
50478	49074	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:20	\N
50479	49075	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:20	\N
50480	49076	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:20	\N
50481	49077	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:20	\N
50482	49078	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:20	\N
50483	49079	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:20	\N
50484	49080	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:20	\N
50485	49081	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:20	\N
50486	49082	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:20	\N
50487	49083	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:20	\N
50488	49084	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:20	\N
50489	49085	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:20	\N
50490	49086	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:20	\N
50491	49087	DEPUTE	2017-06-21 00:00:00	\N	2020-01-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:21	\N
50492	49088	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:21	\N
50493	49089	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:21	\N
50494	49090	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:21	\N
50495	49091	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:21	\N
50496	49092	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:21	\N
50497	49093	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:21	\N
50498	49094	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:21	\N
50499	49095	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:21	\N
50500	49096	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:21	\N
33726	32323	DEPUTE	1987-10-30 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:09	\N
33727	32324	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:09	\N
33728	32325	DEPUTE	1984-08-24 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:09	\N
33729	32326	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:09	\N
33730	32327	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:09	\N
33731	32328	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:09	\N
33732	32329	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:09	\N
33733	32330	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:09	\N
33734	32331	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:09	\N
33735	32332	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:09	\N
33737	32334	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:09	\N
33738	32335	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:09	\N
33739	32336	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:09	\N
33740	32337	DEPUTE	1998-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:09	\N
33741	32338	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:09	\N
33742	32339	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:09	\N
33743	32340	QUESTAN	2016-09-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:09	\N
33744	32341	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:09	\N
33745	32342	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:09	\N
33746	32343	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:09	\N
33747	32344	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:09	\N
33748	32345	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:09	\N
33749	32346	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:09	\N
33750	32347	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:09	\N
33751	32348	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:09	\N
33752	32349	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:09	\N
33753	32350	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:09	\N
33754	32351	QUESTAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:09	\N
33755	32352	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:09	\N
33756	32353	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:09	\N
33757	32354	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:09	\N
33758	32355	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:09	\N
33759	32356	DEPUTE	1978-04-02 00:00:00	\N	1980-10-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:09	\N
33760	32357	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:10	\N
33761	32358	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:10	\N
33762	32359	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:10	\N
33763	32360	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:10	\N
33764	32361	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:10	\N
33765	32362	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:10	\N
33766	32363	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:10	\N
33767	32364	VICPDTAN	2000-03-30 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:10	\N
33768	32365	VICPDTAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:10	\N
33769	32366	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:10	\N
33770	32367	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:10	\N
33771	32368	DEPUTE	1981-07-25 00:00:00	\N	1983-04-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:10	\N
33772	32369	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:10	\N
33773	32370	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:10	\N
33774	32371	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:10	\N
33775	32372	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:10	\N
33776	32373	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:10	\N
33777	32374	DEPUTE	1997-06-01 00:00:00	\N	1998-02-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:10	\N
33778	32375	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:10	\N
33779	32376	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:10	\N
33780	32377	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:10	\N
33781	32378	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:10	\N
33782	32379	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:10	\N
33783	32380	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:10	\N
33784	32381	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:10	\N
33785	32382	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:10	\N
33786	32383	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:10	\N
33787	32384	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:10	\N
33788	32385	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:10	\N
33789	32386	DEPUTE	1988-06-13 00:00:00	\N	1991-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:10	\N
33790	32387	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:10	\N
33791	32388	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:10	\N
33792	32389	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:10	\N
33793	32390	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:10	\N
33794	32391	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:10	\N
33795	32392	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:10	\N
33796	32393	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:10	\N
33797	32394	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:11	\N
33798	32395	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:11	\N
33799	32396	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:11	\N
33800	32397	VICPDTAN	2007-06-27 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:11	\N
33801	32398	VICPDTAN	2012-06-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:11	\N
33802	32399	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:11	\N
33803	32400	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:11	\N
33804	32401	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:11	\N
33805	32402	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:11	\N
33806	32403	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:11	\N
33807	32404	SECAN	1988-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:11	\N
33808	32405	VICPDTAN	2002-06-26 00:00:00	\N	2005-06-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:11	\N
33809	32406	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:11	\N
33810	32407	DEPUTE	1988-07-29 00:00:00	\N	1992-12-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:11	\N
33811	32408	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:11	\N
33812	32409	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:11	\N
33813	32410	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:11	\N
33814	32411	DEPUTE	2012-06-20 00:00:00	\N	2014-05-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:11	\N
33815	32412	SECAN	2004-10-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:11	\N
33816	32413	VICPDTAN	2007-06-27 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:11	\N
33817	32414	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:11	\N
33818	32415	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:11	\N
35215	33812	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:01	\N
35216	33813	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:01	\N
35217	33814	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:01	\N
35218	33815	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:01	\N
35219	33816	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:01	\N
35220	33817	DEPUTE	1996-10-01 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:01	\N
35221	33818	DEPUTE	1997-06-12 00:00:00	\N	2000-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:01	\N
35222	33819	DEPUTE	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:01	\N
35223	33820	VICPDTAN	2005-07-04 00:00:00	\N	2005-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:01	\N
35224	33821	VICPDTAN	2005-10-04 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:01	\N
35225	33822	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:01	\N
35226	33823	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:01	\N
35227	33824	DEPUTE	1997-06-01 00:00:00	\N	1997-10-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:01	\N
35228	33825	DEPUTE	1997-12-14 00:00:00	\N	2000-05-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:02	\N
35229	33826	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:02	\N
35230	33827	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:02	\N
35231	33828	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:02	\N
35232	33829	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:02	\N
35233	33830	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:02	\N
35234	33831	DEPUTE	1981-07-02 00:00:00	\N	1986-03-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:02	\N
35235	33832	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:02	\N
35236	33833	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:02	\N
35237	33834	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:02	\N
35238	33835	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:02	\N
35239	33836	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:02	\N
35240	33837	VICPDTAN	1994-04-02 00:00:00	\N	1995-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:02	\N
35241	33838	VICPDTAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:02	\N
35242	33839	VICPDTAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:02	\N
35243	33840	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:02	\N
35244	33841	DEPUTE	2005-09-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:02	\N
35245	33842	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:02	\N
35246	33843	DEPUTE	2010-12-14 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:02	\N
35247	33844	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:02	\N
35248	33845	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:02	\N
35249	33846	DEPUTE	1981-07-02 00:00:00	\N	1984-08-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:02	\N
35250	33847	DEPUTE	1990-01-25 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:02	\N
35251	33848	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:02	\N
35252	33849	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:02	\N
35253	33850	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:02	\N
35254	33851	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:02	\N
35255	33852	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:03	\N
35256	33853	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:03	\N
35257	33854	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:03	\N
35258	33855	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:03	\N
35259	33856	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:03	\N
35260	33857	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:03	\N
35261	33858	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:03	\N
35262	33859	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:03	\N
35263	33860	DEPUTE	1997-06-01 00:00:00	\N	1998-04-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:03	\N
35264	33861	DEPUTE	1998-02-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:03	\N
35265	33862	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:03	\N
35266	33863	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:03	\N
35267	33864	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:03	\N
35268	33865	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:03	\N
35269	33866	DEPUTE	1986-04-02 00:00:00	\N	1986-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:03	\N
35270	33867	DEPUTE	1986-08-25 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:03	\N
35271	33868	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:03	\N
35272	33869	DEPUTE	1988-06-13 00:00:00	\N	1992-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:03	\N
35273	33870	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:03	\N
35274	33871	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:03	\N
35275	33872	DEPUTE	2000-03-19 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:03	\N
35276	33873	DEPUTE	2000-03-20 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:03	\N
35277	33874	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:03	\N
35278	33875	DEPUTE	2007-06-20 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:04	\N
35279	33876	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:04	\N
35280	33877	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:04	\N
35281	33878	DEPUTE	2000-06-26 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:04	\N
35282	33879	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:04	\N
35283	33880	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:04	\N
35284	33881	SECAN	2006-12-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:04	\N
35285	33882	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:04	\N
35286	33883	DEPUTE	2000-10-22 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:04	\N
35287	33884	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:04	\N
35288	33885	DEPUTE	2001-04-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:04	\N
35289	33886	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:04	\N
35290	33887	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:04	\N
35291	33888	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:04	\N
35292	33889	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:04	\N
35293	33890	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:04	\N
35294	33891	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:04	\N
35295	33892	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:04	\N
35296	33893	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:04	\N
35297	33894	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:04	\N
35298	33895	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:04	\N
35299	33896	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:04	\N
35300	33897	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:04	\N
35301	33898	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:04	\N
35302	33899	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:04	\N
35303	33900	DEPUTE	2007-07-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:04	\N
35304	33901	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:05	\N
35305	33902	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:05	\N
35306	33903	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:05	\N
35307	33904	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:05	\N
50878	50178	MAIRE	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 10:47:21	2017-09-20 10:47:41
50879	50179	CONSCOMINT	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 10:48:23	2017-09-20 10:49:02
50880	50180	MAIRE	2010-08-02 00:00:00	\N	2017-10-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-20 10:50:04	2017-11-20 11:18:48
50882	50182	MAIRE	2001-03-18 00:00:00	\N	2015-03-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-20 10:53:17	2017-09-20 10:53:49
50883	50183	CONSGENE	2008-03-16 00:00:00	\N	2011-03-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-20 10:54:10	2017-09-20 10:55:20
50884	50184	PDTDPT	2015-03-29 00:00:00	\N	2017-10-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-20 10:54:12	2017-12-04 18:39:29
50883	50185	VICPDTGEN	2011-03-27 00:00:00	\N	2015-03-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-20 10:55:24	2017-09-20 10:55:44
50888	50189	CONSMUNI	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 11:02:56	2017-09-20 11:03:13
50887	50188	CONSREG	2015-12-13 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 11:00:10	2017-09-20 11:00:23
50890	50191	CONSMUNI	2008-03-16 00:00:00	\N	2014-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-20 11:18:48	2017-09-20 11:19:20
50890	50192	QUATADJOINT	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 11:19:23	2017-09-20 11:19:41
50891	50193	CONSDPT	2015-03-29 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 11:25:32	2017-09-20 11:25:51
50894	50196	MAIRE	2001-03-18 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 11:28:51	2017-09-20 11:29:12
50897	50199	PREVICPDTDPT	2015-03-29 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 11:30:41	2017-09-20 11:32:25
50898	50200	CONSGENE	2001-03-18 00:00:00	\N	2011-03-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-20 11:30:42	2017-09-20 11:31:37
50898	50201	PREVICPDTGEN	2011-03-27 00:00:00	\N	2015-03-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-20 11:31:52	2017-09-20 11:32:10
50907	50210	CONSDPT	2015-03-29 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 11:55:38	2017-09-20 11:56:56
50908	50211	CONSGENE	1992-03-29 00:00:00	\N	2008-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-20 11:55:40	2017-09-20 11:58:05
50908	50212	VICPDTGEN	2008-03-16 00:00:00	\N	2015-03-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-20 11:56:21	2017-09-20 11:56:41
50909	50213	MAIRE	2001-03-18 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 11:58:10	2017-09-20 11:58:30
50910	50214	PDTINTCOM	2008-03-16 00:00:00	\N	2014-03-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-20 12:00:03	2017-09-20 12:00:52
50911	50215	MAIRE	2008-03-16 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 12:02:00	2017-09-20 12:02:24
50913	50217	CONSCOMINT	2010-01-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 12:05:20	2017-09-20 12:05:50
50914	50218	CONSCOMINT	2010-01-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 12:09:34	2017-09-20 12:10:05
50915	50219	MAIREADJOINT	2014-03-30 00:00:00	\N	2017-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-20 12:11:54	2017-09-22 15:55:12
50916	50220	CONSDPT	2015-03-29 00:00:00	\N	2017-10-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-20 12:13:56	2017-09-20 12:14:17
50957	50266	CONSMUNI	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 16:45:34	2017-09-20 16:46:29
50972	50281	MAIRE	2014-03-30 00:00:00	\N	2017-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-21 17:29:50	2017-11-16 18:51:08
50976	50285	MAIRE	1990-11-30 00:00:00	\N	2014-03-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-09-21 17:36:37	2017-09-24 19:35:46
50977	50286	MAIRE	2001-03-18 00:00:00	\N	2017-12-15 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-09-21 17:45:50	2017-12-20 19:05:27
50979	50288	VICPDTDPT	2015-03-29 00:00:00	\N	2017-12-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-21 17:47:03	2017-12-20 19:06:11
50981	50290	VICPDTMET	2015-01-02 00:00:00	\N	2017-12-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-09-21 17:49:09	2018-01-02 11:05:41
50989	50298	CONSMUNI	2008-03-16 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	2017-09-21 17:58:34	2017-09-21 18:00:41
50990	50299	MAIRE	1988-02-11 00:00:00	\N	2017-11-24 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-09-21 18:17:16	2018-02-16 16:01:35
50992	50301	VICPDTDPT	2015-04-02 00:00:00	\N	2017-10-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-09-21 18:31:09	2017-11-16 14:58:09
50993	50302	MAIRE	2014-04-04 00:00:00	\N	2017-10-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-21 18:41:24	2017-12-12 14:05:49
50994	50303	CONSDPT	2015-03-29 00:00:00	\N	2021-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-21 18:46:54	2017-09-21 18:48:06
50996	50305	PDTDPT	2015-03-18 00:00:00	\N	2017-12-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-22 10:05:21	2018-01-08 16:14:45
51000	50309	VICPDTREG	2015-12-13 00:00:00	\N	2017-12-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-22 10:17:55	2018-01-08 17:20:30
50998	50307	VICPDTREG	2015-12-13 00:00:00	\N	2017-12-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-22 10:09:33	2018-02-01 20:39:45
51006	50315	MAIREADJOINT	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2017-09-22 10:48:54	2017-09-22 11:40:57
51011	50320	MAIRE	1995-06-18 00:00:00	\N	2017-09-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-22 11:04:27	2018-02-16 16:13:08
51014	50323	CONSGENE	1998-03-22 00:00:00	\N	2004-03-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-22 11:05:23	2017-09-22 11:06:04
51016	50325	CONSMUNI	2008-03-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2017-09-22 11:11:43	2017-09-22 11:12:08
51017	50326	CONSDPT	2015-03-29 00:00:00	\N	2021-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-09-22 11:18:09	2017-09-22 11:18:32
51018	50327	MAIREADJOINT	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2017-09-22 11:25:04	2017-09-22 11:25:34
51020	50329	CONSREG	2015-12-13 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2017-09-22 11:33:03	2017-09-22 11:33:46
51029	50338	CONSREG	2015-12-13 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2017-09-22 11:49:10	2017-09-22 11:50:02
51030	50339	MAIRE	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2017-09-22 11:52:51	2017-09-22 11:53:45
51031	50340	CONSDPT	2015-03-29 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-22 11:59:27	2017-09-22 12:04:40
51032	50341	MAIRE	2001-03-18 00:00:00	\N	2017-10-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-22 13:44:59	2017-11-13 18:20:40
51033	50342	MAIRE	2014-03-30 00:00:00	\N	2017-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-22 13:48:40	2017-11-14 15:52:44
51034	50343	CONSDPT	2015-03-29 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-22 13:54:34	2017-09-22 13:56:09
51035	50344	CONSGENE	1994-03-27 00:00:00	\N	2001-03-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-22 13:56:26	2017-09-24 17:37:39
51036	50345	MAIREADJOINT	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-22 13:58:48	2017-09-22 15:56:47
51037	50346	CONSDPT	2015-03-29 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-22 14:01:25	2017-09-22 14:01:41
51038	50347	MAIRE	1995-06-18 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-22 14:02:31	2017-09-22 14:02:52
51039	50348	CONSMUNI	1989-03-19 00:00:00	\N	2017-10-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-22 14:04:40	2017-11-17 10:59:01
51040	50349	PREVICPDTDPT	2015-03-29 00:00:00	\N	2017-10-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-22 14:05:02	2017-11-17 11:03:54
51041	50350	MAIRE	2001-03-18 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-22 15:26:27	2017-09-22 15:30:22
51043	50352	CONSDPT	2015-03-29 00:00:00	\N	2017-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-22 15:35:39	2017-11-09 12:50:14
51044	50353	CONSMET	2014-04-18 00:00:00	\N	2020-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-09-22 15:39:45	2017-09-22 15:40:00
51046	50355	MAIRE	2008-03-16 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-22 15:44:33	2017-09-22 15:46:33
51047	50356	MAIRE	2008-03-16 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-22 15:50:21	2017-09-22 15:52:09
51049	50358	CONSPARI	2008-03-16 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-22 18:20:52	2017-09-22 18:21:42
51052	50361	PREVICPDTREG	1998-03-15 00:00:00	\N	2015-12-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-22 18:28:32	2017-11-16 15:36:06
51053	50362	MAIREADJOINT	2012-07-09 00:00:00	\N	2017-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-22 18:34:30	2017-11-08 15:41:09
50501	49097	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:21	\N
50502	49098	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:21	\N
50999	50308	MAIREADJOINT	2014-03-30 00:00:00	\N	2017-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-09-22 10:17:42	2017-09-22 10:22:08
50504	49100	VICPDTAN	2017-06-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:21	2017-08-07 03:44:33
50505	49101	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:21	\N
50506	49102	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:21	\N
50507	49103	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:21	\N
50508	49104	DEPUTE	2017-06-21 00:00:00	\N	2022-01-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:21	\N
50509	49105	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:21	\N
50510	49106	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:21	\N
50512	49108	VICPDTAN	2017-06-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:22	2017-08-09 03:44:55
50513	49109	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:22	\N
50514	49110	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:22	\N
50515	49111	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:22	\N
50516	49112	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:22	\N
50517	49113	DEPUTE	2017-06-21 00:00:00	\N	2020-08-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:22	\N
50518	49114	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:22	\N
50519	49115	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:22	\N
50520	49116	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:22	\N
50521	49117	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:22	\N
50522	49118	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:22	\N
50523	49119	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:22	\N
50524	49120	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:22	\N
50526	49122	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:22	\N
50527	49123	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:22	\N
50528	49124	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:22	\N
50529	49125	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:22	\N
50530	49126	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:22	\N
50531	49127	DEPUTE	2017-06-21 00:00:00	\N	2020-08-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:22	\N
50532	49128	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:22	\N
50533	49129	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:22	\N
50534	49130	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:22	\N
50535	49131	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:22	\N
50536	49132	DEPUTE	2017-06-21 00:00:00	\N	2022-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:22	\N
50537	49133	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:23	\N
50538	49134	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:23	\N
50539	49135	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:23	\N
50540	49136	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:23	\N
50541	49137	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:23	\N
50542	49138	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:23	2017-08-10 03:44:35
51002	50311	CONSREG	2015-12-13 00:00:00	\N	2017-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-09-22 10:20:55	2017-09-22 10:22:05
50544	49140	SECAN	2017-06-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:23	2017-08-10 10:58:05
50545	49141	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:23	\N
50546	49142	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:23	\N
50547	49143	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:23	\N
50548	49144	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:23	\N
50549	49145	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:23	\N
50550	49146	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:23	\N
50551	49147	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:23	\N
50552	49148	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:23	\N
50553	49149	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:23	\N
50554	49150	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:23	\N
50555	49151	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:23	\N
50556	49152	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:23	\N
50557	49153	DEPUTE	2017-06-21 00:00:00	\N	2018-02-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:23	2018-02-06 03:44:56
50558	49154	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:23	\N
50559	49155	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:24	\N
50561	49157	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:24	\N
50563	49159	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:24	\N
50564	49160	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:24	\N
50565	49161	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:24	\N
50566	49162	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:24	\N
50567	49163	DEPUTE	2017-06-21 00:00:00	\N	2017-11-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:24	2017-11-18 03:46:16
50568	49164	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:24	\N
50569	49165	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:24	\N
50570	49166	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:24	\N
50571	49167	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:24	\N
50572	49168	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:24	\N
50573	49169	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:24	\N
50574	49170	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:24	\N
50575	49171	DEPUTE	2017-06-21 00:00:00	\N	2022-01-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:24	\N
50576	49172	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:24	\N
50577	49173	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:24	\N
50578	49174	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:24	\N
51003	50312	MAIRE	1995-06-18 00:00:00	\N	2017-10-22 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-09-22 10:28:59	2018-01-24 19:38:27
50580	49176	SECAN	2017-06-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:25	2017-08-10 10:58:06
50581	49177	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:25	\N
50582	49178	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:25	\N
50583	49179	DEPUTE	2017-06-21 00:00:00	1500	2022-06-21 00:00:00	1600	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:25	2023-09-26 18:11:44
50584	49180	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:25	\N
50585	49181	DEPUTE	2017-06-21 00:00:00	\N	2020-08-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:25	\N
50586	49182	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:25	\N
50587	49183	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:25	\N
50588	49184	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:25	\N
50589	49185	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:25	\N
50590	49186	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:25	\N
50591	49187	DEPUTE	2017-06-21 00:00:00	\N	2017-12-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:25	2017-12-12 03:45:07
50593	49189	VICPDTAN	2017-06-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:25	2017-08-10 10:58:06
50594	49190	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:25	\N
50595	49191	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:25	\N
50597	49193	DEPUTE	2017-06-21 00:00:00	\N	2017-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:25	\N
50598	49194	DEPUTE	2017-07-22 00:00:00	\N	2020-08-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:26	\N
50600	49196	SECAN	2017-06-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:26	2017-08-10 10:58:07
50601	49197	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:26	\N
50602	49198	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:26	\N
33819	32416	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:11	\N
33820	32417	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:11	\N
33821	32418	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:11	\N
33822	32419	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:11	\N
33823	32420	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:11	\N
33824	32421	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:11	\N
33825	32422	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:11	\N
33826	32423	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:11	\N
33827	32424	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:11	\N
33828	32425	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:11	\N
33829	32426	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:11	\N
33830	32427	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:11	\N
33831	32428	DEPUTE	1983-05-09 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:11	\N
33832	32429	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:11	\N
33833	32430	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:11	\N
33834	32431	DEPUTE	1988-06-06 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:11	\N
33835	32432	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:11	\N
33836	32433	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:11	\N
33837	32434	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:12	\N
33838	32435	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:12	\N
33839	32436	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:12	\N
33840	32437	DEPUTE	2012-06-20 00:00:00	\N	2017-01-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:12	\N
33841	32438	DEPUTE	2017-04-22 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:12	\N
33842	32439	DEPUTE	1997-06-12 00:00:00	\N	2000-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:12	\N
33843	32440	DEPUTE	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:12	\N
33844	32441	DEPUTE	1973-04-02 00:00:00	\N	1977-03-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:12	\N
33845	32442	DEPUTE	1997-07-05 00:00:00	\N	2001-02-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:12	\N
33846	32443	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:12	\N
33847	32444	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:12	\N
33848	32445	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:12	\N
33849	32446	DEPUTE	1984-09-29 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:12	\N
33850	32447	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:12	\N
33851	32448	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:12	\N
33852	32449	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:12	\N
33853	32450	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:12	\N
33854	32451	DEPUTE	2016-03-12 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:12	\N
33855	32452	QUESTAN	2007-06-27 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:12	\N
33856	32453	DEPUTE	2000-04-28 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:12	\N
33857	32454	DEPUTE	1973-04-02 00:00:00	\N	1974-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:12	\N
33858	32455	DEPUTE	1986-04-02 00:00:00	\N	1986-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:12	\N
33859	32456	DEPUTE	1978-04-02 00:00:00	\N	1978-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:12	\N
33860	32457	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:12	\N
33861	32458	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:12	\N
33862	32459	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:12	\N
33863	32460	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:12	\N
33864	32461	SECAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:13	\N
33865	32462	SECAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:13	\N
33866	32463	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:13	\N
33867	32464	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:13	\N
33868	32465	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:13	\N
33869	32466	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:13	\N
33870	32467	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:13	\N
33871	32468	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:13	\N
33872	32469	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:13	\N
33873	32470	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:13	\N
33874	32471	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:13	\N
33875	32472	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:13	\N
33876	32473	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:13	\N
33877	32474	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:13	\N
33878	32475	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:13	\N
33879	32476	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:13	\N
33880	32477	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:13	\N
33881	32478	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:13	\N
33882	32479	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:13	\N
33883	32480	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:13	\N
33884	32481	DEPUTE	1973-04-02 00:00:00	\N	1977-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:14	\N
33885	32482	DEPUTE	1978-04-03 00:00:00	\N	1978-05-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:14	\N
33886	32483	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:14	\N
33887	32484	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:14	\N
33888	32485	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:14	\N
33889	32486	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:14	\N
33890	32487	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:14	\N
33891	32488	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:14	\N
33892	32489	SECAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:14	\N
33893	32490	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:14	\N
33894	32491	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:14	\N
33895	32492	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:14	\N
33896	32493	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:14	\N
33897	32494	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:14	\N
33898	32495	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:14	\N
33899	32496	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:14	\N
33900	32497	DEPUTE	2007-06-20 00:00:00	\N	2009-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:14	\N
33901	32498	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:14	\N
33902	32499	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:14	\N
33903	32500	DEPUTE	1997-07-03 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:15	\N
33904	32501	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:15	\N
33905	32502	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:15	\N
33906	32503	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:15	\N
33907	32504	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:15	\N
33908	32505	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:15	\N
33909	32506	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:15	\N
33910	32507	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:15	\N
33911	32508	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:15	\N
35308	33905	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:05	\N
35309	33906	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:05	\N
35310	33907	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:05	\N
35311	33908	VICPDTAN	2008-09-26 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:05	\N
35312	33909	VICPDTAN	2012-06-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:05	\N
35313	33910	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:05	\N
35314	33911	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:05	\N
35315	33912	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:05	\N
35316	33913	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:05	\N
35317	33914	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:05	\N
35318	33915	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:05	\N
35319	33916	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:05	\N
35320	33917	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:05	\N
35321	33918	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:05	\N
35322	33919	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:05	\N
35323	33920	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:05	\N
35324	33921	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:05	\N
35325	33922	DEPUTE	2002-06-25 00:00:00	\N	2002-06-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:05	\N
35326	33923	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:05	\N
35327	33924	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:05	\N
35328	33925	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:05	\N
35329	33926	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:05	\N
35330	33927	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:06	\N
35331	33928	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:06	\N
35332	33929	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:06	\N
35333	33930	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:06	\N
35334	33931	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:06	\N
35335	33932	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:06	\N
35336	33933	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:06	\N
35337	33934	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:06	\N
35338	33935	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:06	\N
35339	33936	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:06	\N
35340	33937	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:06	\N
35341	33938	DEPUTE	2007-07-04 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:06	\N
35342	33939	DEPUTE	2012-12-17 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:06	\N
35343	33940	DEPUTE	2007-07-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:06	\N
35344	33941	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:06	\N
35345	33942	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:06	\N
35346	33943	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:06	\N
35347	33944	DEPUTE	2012-06-20 00:00:00	\N	2015-08-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:06	\N
35348	33945	DEPUTE	2004-05-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:06	\N
35349	33946	DEPUTE	2004-11-22 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:07	\N
35350	33947	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:07	\N
35351	33948	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:07	\N
35352	33949	DEPUTE	2004-05-01 00:00:00	\N	2005-07-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:07	\N
35353	33950	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:07	\N
35354	33951	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:07	\N
35355	33952	SECAN	2005-10-04 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:07	\N
35356	33953	QUESTAN	2007-06-27 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:07	\N
35357	33954	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:07	\N
35358	33955	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:07	\N
35359	33956	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:07	\N
35360	33957	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:07	\N
35361	33958	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:07	\N
35362	33959	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:07	\N
35363	33960	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:07	\N
35364	33961	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:07	\N
35365	33962	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:07	\N
35366	33963	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:07	\N
35367	33964	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:07	\N
35368	33965	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:07	\N
35369	33966	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:07	\N
35370	33967	DEPUTE	2007-06-20 00:00:00	\N	2011-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:07	\N
35371	33968	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:07	\N
35372	33969	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:07	\N
35373	33970	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:07	\N
35374	33971	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:08	\N
35375	33972	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:08	\N
35376	33973	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:08	\N
35377	33974	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:08	\N
35378	33975	DEPUTE	2010-11-13 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:08	\N
35379	33976	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:08	\N
35380	33977	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:08	\N
35381	33978	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:08	\N
35382	33979	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:08	\N
35383	33980	DEPUTE	2010-06-05 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:08	\N
35384	33981	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:08	\N
35385	33982	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:08	\N
35386	33983	DEPUTE	2009-04-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:08	\N
35387	33984	DEPUTE	2007-07-20 00:00:00	\N	2009-07-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:08	\N
35388	33985	DEPUTE	2009-09-28 00:00:00	\N	2010-05-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:08	\N
35389	33986	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:08	\N
35390	33987	DEPUTE	2012-07-22 00:00:00	\N	2013-08-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:08	\N
35391	33988	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:08	\N
35392	33989	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:08	\N
35393	33990	DEPUTE	2007-07-20 00:00:00	\N	2012-03-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:08	\N
35394	33991	DEPUTE	2008-09-19 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:08	\N
35395	33992	DEPUTE	2010-04-23 00:00:00	\N	2011-06-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:08	\N
35396	33993	DEPUTE	2012-07-22 00:00:00	\N	2016-03-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:08	\N
35397	33994	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:08	\N
35398	33995	DEPUTE	2007-07-20 00:00:00	\N	2009-07-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:08	\N
35399	33996	DEPUTE	2013-06-10 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:08	\N
35400	33997	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:08	\N
51054	50364	CONSPARI	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-22 18:39:22	2017-09-22 18:39:51
51055	50365	CONSPARI	2014-03-23 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-22 18:41:14	2017-09-22 18:41:41
51057	50367	CONSREG	2015-12-13 00:00:00	\N	2017-10-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-22 18:44:27	2017-10-19 10:38:53
51065	50368	MAIRE	2014-03-30 00:00:00	\N	2017-09-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-09-24 11:17:42	2017-12-07 10:13:03
51066	50369	MAIRE	1988-03-20 00:00:00	\N	\N	2001	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 11:45:10	2017-09-26 09:57:42
51067	50370	CONSGENE	\N	\N	2015-03-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 11:46:56	2017-09-24 11:48:31
51082	50374	MAIRE	1987-05-31 00:00:00	\N	2017-10-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 16:27:48	2017-11-10 10:35:04
51083	50375	CONSGENE	1992-03-22 00:00:00	\N	1998-03-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 16:41:10	2017-09-24 16:44:24
51083	50376	VICPDTGEN	1998-03-22 00:00:00	\N	2015-03-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 16:42:48	2017-09-24 16:44:24
51084	50377	MAIRE	\N	1990	2017-12-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 16:43:13	2018-01-08 14:48:19
51091	50378	CONSREG	2015-12-13 00:00:00	\N	2021-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-09-24 16:45:37	2017-09-24 16:46:14
51092	50379	VICPDTDPT	2015-03-29 00:00:00	\N	2017-12-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 16:56:43	2018-02-06 12:22:22
50671	49267	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:28	\N
51093	50380	MAIREADJOINT	2014-03-30 00:00:00	\N	2017-12-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 16:57:18	2018-02-06 12:21:02
51110	50386	CONSREG	2015-03-21 00:00:00	\N	2015-12-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 17:12:45	2017-09-24 17:13:06
51093	50382	CONSMUNI	2008-03-16 00:00:00	\N	2014-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 16:58:32	2017-09-24 17:00:11
51130	50392	MAIRE	1995-06-18 00:00:00	\N	2008-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 17:23:48	2017-09-24 17:24:27
51130	50390	CONSMUNI	1989-03-19 00:00:00	\N	1995-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 17:22:15	2017-09-24 17:23:36
51131	50391	CONSGENE	1998-03-22 00:00:00	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 17:23:40	2017-09-24 17:25:09
51132	50394	MAIRE	2008-03-16 00:00:00	\N	2014-03-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 17:24:30	2017-09-24 17:26:21
51136	50395	CONSREG	1998-03-15 00:00:00	\N	2001-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 17:25:43	2017-09-24 17:26:48
51137	50396	CONSGENE	1994-03-27 00:00:00	\N	2001-03-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 17:26:48	2017-09-24 17:29:43
51137	50398	VICPDTGEN	2001-03-18 00:00:00	\N	2002-10-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 17:29:48	2017-09-24 17:30:07
51146	50400	VICPDTINTCOM	2003-01-01 00:00:00	\N	2014-03-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-09-24 17:30:36	2017-09-24 17:34:35
51147	50401	MAIRE	1983-03-13 00:00:00	\N	2004-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 17:32:06	2017-09-24 17:34:20
51157	50413	CONSREG	2004-03-28 00:00:00	\N	2021-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 17:41:22	2017-09-24 17:48:55
51155	50406	VICPDTINTCOM	2014-03-16 00:00:00	\N	2018-04-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-09-24 17:37:00	2018-04-26 14:58:46
51035	50410	VICPDTGEN	2001-03-11 00:00:00	\N	2008-03-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 17:39:56	2017-09-24 17:40:56
51165	50415	MAIRE	2001-03-18 00:00:00	\N	2017-10-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 17:42:25	2017-11-10 10:26:53
51035	50417	CONSGENE	2008-03-09 00:00:00	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 17:43:41	2017-09-24 17:44:24
51166	50418	CONSREG	2004-03-28 00:00:00	\N	2017-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 17:44:05	2017-11-10 10:26:35
51189	50425	CONSDPT	2015-03-29 00:00:00	\N	2017-10-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 17:50:19	2018-02-09 09:57:29
51182	50422	MAIRE	2008-03-16 00:00:00	\N	2017-10-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 17:48:15	2018-02-08 15:14:35
51190	50426	CONSMUNI	1995-06-18 00:00:00	\N	2001-03-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 17:53:31	2017-09-24 17:54:21
51190	50427	MAIREADJOINT	2001-03-18 00:00:00	\N	2008-03-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 17:54:23	2017-09-24 17:55:13
51198	50429	CONSREG	2015-12-13 00:00:00	\N	2017-10-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 17:56:12	2017-09-24 17:56:26
51190	50431	CONSMUNI	2014-03-30 00:00:00	\N	2020-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 17:57:20	2017-09-24 17:57:27
51211	50433	MAIRE	2001-03-18 00:00:00	\N	2017-10-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 18:08:19	2017-11-14 10:31:02
51212	50434	CONSGENE	2011-03-27 00:00:00	\N	2015-03-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 18:09:00	2017-09-27 15:22:02
51213	50435	PREVICPDTDPT	2015-03-29 00:00:00	\N	2017-10-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 18:11:34	2017-11-14 10:32:49
51214	50436	PDTINTCOM	2001-03-18 00:00:00	\N	2015-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-09-24 18:13:18	2017-11-17 09:46:33
51215	50437	VICPDTINTCOM	2016-01-01 00:00:00	\N	2017-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-09-24 18:14:34	2017-11-17 09:38:38
51235	50438	MAIRE	2001-03-18 00:00:00	\N	2014-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 18:18:43	2017-09-24 18:19:37
51239	50439	CONSGENE	1998-03-22 00:00:00	\N	2004-03-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 18:20:26	2017-09-24 18:21:07
50896	50440	CONSREG	2015-12-13 00:00:00	\N	2016-01-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 18:20:42	2017-09-24 18:20:55
51239	50441	VICPDTGEN	2004-03-21 00:00:00	\N	2011-03-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 18:21:10	2017-09-24 18:21:58
51239	50442	CONSGENE	2011-03-27 00:00:00	\N	2015-03-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 18:22:05	2017-09-24 18:22:33
51246	50443	CONSGENE	2004-03-28 00:00:00	\N	2008-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 18:28:11	2017-10-10 10:38:28
51246	50447	VICPDTGEN	2008-03-16 00:00:00	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 18:35:20	2017-09-24 18:36:06
51249	50448	PDTINTCOM	2001-03-18 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	2017-09-24 18:36:15	2017-09-24 18:38:01
51248	50446	MAIRE	2008-03-16 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-24 18:33:38	2017-09-24 18:34:58
51251	50450	PDTINTCOM	2017-01-01 00:00:00	\N	2017-10-09 00:00:00	\N	ANCIEN	de la communauté de communes Mad et Moselle	de la communauté de communes Mad et Moselle	\N	\N	2017-09-24 18:37:37	2017-09-24 18:41:16
51253	50451	VICPDTDPT	2015-03-29 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-24 18:39:55	2017-09-24 18:41:40
10703	50453	PDTGEN	2009-05-25 00:00:00	\N	2014-04-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 18:48:22	2017-09-24 18:52:21
51260	50455	MAIRE	\N	2003	\N	2015	ANCIEN	\N	\N	\N	NON	2017-09-24 18:51:26	2017-09-24 18:52:19
10703	50456	CONSGENE	2014-04-11 00:00:00	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 18:51:32	2017-09-24 18:52:38
51027	50457	MAIREADJOINT	2001-03-18 00:00:00	\N	2002-07-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 18:51:36	2017-09-24 18:52:11
51027	50458	CONSMUNI	1995-06-18 00:00:00	\N	2001-03-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 18:51:44	2017-09-24 18:52:26
51264	50460	CONSREG	2010-03-21 00:00:00	\N	2010-10-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-09-24 18:53:23	2017-09-24 18:54:55
51265	50461	CONSREG	2004-03-28 00:00:00	\N	2017-10-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 18:53:32	2018-02-09 10:00:56
51277	50467	VICPDTGEN	1998-03-22 00:00:00	\N	2015-03-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 19:03:37	2017-09-24 19:05:10
51276	50466	CONSREG	2015-12-13 00:00:00	\N	2017-10-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 19:00:27	2018-02-07 16:05:10
51279	50468	VICPDTDPT	2015-03-29 00:00:00	\N	2017-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 19:05:54	2017-09-24 19:06:26
50824	50477	CONSMUNI	2014-07-03 00:00:00	\N	2017-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-09-24 19:16:22	2017-09-24 19:17:03
51289	50478	CONSDPT	2015-03-29 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-24 19:16:56	2017-09-24 19:17:24
51295	50481	PDTINTCOM	2008-03-16 00:00:00	\N	2015-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-09-24 19:19:45	2017-09-24 19:21:38
51296	50482	PDTINTCOM	2016-01-01 00:00:00	\N	2017-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-09-24 19:19:47	2018-01-16 09:50:21
51297	50483	CONSGENE	2002-06-09 00:00:00	\N	2014-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-09-24 19:20:04	2017-09-26 17:35:07
51312	50488	MAIRE	2014-03-30 00:00:00	\N	2017-11-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 19:40:35	2017-09-24 19:42:38
50603	49199	DEPUTE	2017-06-21 00:00:00	\N	2022-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:26	\N
50604	49200	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:26	\N
50605	49201	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:26	\N
50606	49202	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:26	\N
50607	49203	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:26	\N
50608	49204	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:26	\N
50609	49205	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:26	\N
50610	49206	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:26	\N
50611	49207	DEPUTE	2017-06-21 00:00:00	\N	2019-07-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:26	\N
50612	49208	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:26	\N
50613	49209	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:26	\N
50614	49210	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:26	\N
50615	49211	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:26	\N
50616	49212	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:26	\N
50617	49213	DEPUTE	2017-06-21 00:00:00	\N	2020-07-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:27	\N
50618	49214	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:27	\N
50619	49215	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:27	\N
50620	49216	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:27	\N
50621	49217	DEPUTE	2017-06-21 00:00:00	\N	2020-08-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:27	\N
50622	49218	DEPUTE	2017-06-21 00:00:00	\N	2019-02-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:27	\N
50623	49219	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:27	\N
50624	49220	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:27	\N
50625	49221	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:27	\N
50626	49222	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:27	\N
50627	49223	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:27	\N
50628	49224	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:27	\N
50629	49225	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:27	\N
50631	49227	VICPDTAN	2017-06-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:27	2017-08-10 10:58:08
50632	49228	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:27	\N
50633	49229	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:27	\N
50634	49230	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:27	\N
50635	49231	DEPUTE	2017-06-21 00:00:00	\N	2018-11-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:27	\N
50636	49232	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:27	\N
50637	49233	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:27	\N
50638	49234	DEPUTE	2017-06-21 00:00:00	\N	2019-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:27	\N
50639	49235	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:27	\N
50640	49236	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:27	\N
50641	49237	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:27	\N
50642	49238	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:27	\N
50643	49239	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:27	\N
50644	49240	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:27	\N
50645	49241	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:28	\N
50646	49242	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:28	\N
50647	49243	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:28	\N
50648	49244	DEPUTE	2017-07-22 00:00:00	\N	2019-04-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:28	\N
50649	49245	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:28	\N
50650	49246	DEPUTE	2017-07-22 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:28	\N
50651	49247	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:28	\N
50652	49248	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:28	\N
50653	49249	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:28	\N
50654	49250	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:28	\N
50655	49251	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:28	\N
50657	49253	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:28	\N
50658	49254	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:28	\N
50659	49255	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:28	\N
50661	49257	SECAN	2012-06-27 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:28	2017-08-10 10:58:08
50662	49258	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:28	2017-08-10 10:58:08
50663	49259	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:28	2017-08-10 10:58:08
50664	49260	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:28	\N
50665	49261	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:28	\N
50666	49262	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:28	\N
50667	49263	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:28	\N
50668	49264	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:28	\N
50669	49265	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:28	\N
50670	49266	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:28	\N
50672	49268	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:28	\N
50673	49269	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:29	\N
50674	49270	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:29	\N
50675	49271	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:29	\N
50676	49272	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:29	\N
50677	49273	DEPUTE	2016-02-28 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:29	\N
50678	49274	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:29	2017-08-08 03:45:13
50679	49275	DEPUTE	2012-06-26 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:29	2017-08-08 03:45:13
50680	49276	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:29	\N
50681	49277	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:29	2017-08-10 10:58:09
50682	49278	DEPUTE	2014-05-03 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:29	2017-08-10 10:58:09
50683	49279	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:29	\N
50684	49280	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:29	\N
50685	49281	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:29	\N
50686	49282	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:29	\N
50687	49283	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:29	\N
50688	49284	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:29	\N
50689	49285	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:29	\N
50690	49286	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:29	\N
50691	49287	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:29	\N
50692	49288	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:29	\N
50693	49289	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:29	\N
50694	49290	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:29	\N
50695	49291	DEPUTE	2015-08-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:29	\N
50696	49292	DEPUTE	2012-06-20 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:29	\N
50698	49294	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:29	\N
50699	49295	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:30	\N
50700	49296	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:30	\N
33912	32509	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:15	\N
33913	32510	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:15	\N
33914	32511	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:15	\N
33915	32512	SECAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:15	\N
33916	32513	DEPUTE	1981-07-02 00:00:00	\N	1983-04-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:15	\N
33917	32514	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:15	\N
33918	32515	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:15	\N
33919	32516	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:15	\N
33920	32517	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:15	\N
33921	32518	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:15	\N
33922	32519	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:15	\N
33923	32520	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:15	\N
33924	32521	DEPUTE	2007-06-20 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:15	\N
33925	32522	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:16	\N
33926	32523	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:16	\N
33927	32524	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:16	\N
33928	32525	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:16	\N
33929	32526	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:16	\N
33930	32527	DEPUTE	1988-12-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:16	\N
33931	32528	DEPUTE	2002-06-19 00:00:00	\N	2006-06-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:16	\N
33932	32529	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:16	\N
33933	32530	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:16	\N
33934	32531	DEPUTE	2007-06-20 00:00:00	\N	2011-07-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:16	\N
33935	32532	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:16	\N
33936	32533	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:16	\N
33937	32534	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:16	\N
33938	32535	DEPUTE	1986-05-07 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:16	\N
33939	32536	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:16	\N
33940	32537	DEPUTE	1988-06-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:16	\N
33941	32538	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:17	\N
33942	32539	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:17	\N
33943	32540	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:17	\N
33944	32541	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:17	\N
33945	32542	DEPUTE	1988-06-13 00:00:00	\N	1992-07-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:17	\N
33946	32543	DEPUTE	1995-09-07 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:17	\N
33947	32544	DEPUTE	1997-06-01 00:00:00	\N	2001-12-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:17	\N
33948	32545	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:17	\N
33949	32546	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:17	\N
33950	32547	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:17	\N
33951	32548	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:17	\N
33952	32549	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:17	\N
33953	32550	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:17	\N
33954	32551	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:17	\N
33955	32552	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:17	\N
33956	32553	DEPUTE	1993-04-02 00:00:00	\N	1994-02-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:17	\N
33957	32554	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:17	\N
33958	32555	DEPUTE	1968-07-11 00:00:00	\N	1971-10-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:17	\N
33959	32556	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:17	\N
33960	32557	DEPUTE	1995-08-17 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:17	\N
33961	32558	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:17	\N
33962	32559	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:18	\N
33963	32560	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:18	\N
33964	32561	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:18	\N
33965	32562	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:18	\N
33966	32563	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:18	\N
33967	32564	DEPUTE	1993-04-02 00:00:00	\N	1993-11-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:18	\N
33968	32565	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:18	\N
33969	32566	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:18	\N
33970	32567	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:18	\N
33971	32568	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:18	\N
33972	32569	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:18	\N
33973	32570	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:18	\N
33974	32571	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:18	\N
33975	32572	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:18	\N
33976	32573	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:18	\N
33977	32574	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:18	\N
33978	32575	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:18	\N
33979	32576	DEPUTE	1973-05-06 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:18	\N
33980	32577	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:18	\N
33981	32578	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:18	\N
33982	32579	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:18	\N
33983	32580	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:18	\N
33984	32581	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:18	\N
33985	32582	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:18	\N
33986	32583	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:18	\N
33987	32584	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:18	\N
33988	32585	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:18	\N
33989	32586	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:18	\N
33990	32587	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:18	\N
33991	32588	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:18	\N
33992	32589	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:18	\N
33993	32590	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:18	\N
33994	32591	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:18	\N
33995	32592	DEPUTE	2012-06-20 00:00:00	\N	2012-10-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:18	\N
33996	32593	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:18	\N
33997	32594	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:18	\N
33998	32595	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:18	\N
33999	32596	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:18	\N
34000	32597	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:18	\N
34001	32598	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:19	\N
34002	32599	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:19	\N
34003	32600	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:19	\N
34004	32601	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:19	\N
35401	33998	DEPUTE	2014-05-10 00:00:00	\N	2014-05-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:08	\N
35402	33999	DEPUTE	2004-05-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:08	\N
35403	34000	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:08	\N
35404	34001	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:09	\N
35405	34002	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:09	\N
35406	34003	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:09	\N
35407	34004	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:09	\N
35408	34005	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:09	\N
35409	34006	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:09	\N
35410	34007	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:09	\N
35411	34008	DEPUTE	2007-06-20 00:00:00	\N	2010-12-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:09	\N
35412	34009	DEPUTE	2005-10-04 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:09	\N
35413	34010	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:09	\N
35414	34011	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:09	\N
35415	34012	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:09	\N
35416	34013	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:09	\N
35417	34014	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:09	\N
35418	34015	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:09	\N
35419	34016	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:09	\N
35420	34017	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:09	\N
35421	34018	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:09	\N
35422	34019	DEPUTE	2007-06-20 00:00:00	\N	2007-11-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:09	\N
35423	34020	DEPUTE	2002-07-19 00:00:00	\N	2005-06-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:09	\N
35424	34021	DEPUTE	2009-01-05 00:00:00	\N	2010-12-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:09	\N
35425	34022	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:09	\N
35426	34023	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:09	\N
35427	34024	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:09	\N
35428	34025	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:09	\N
35429	34026	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:09	\N
35430	34027	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:09	\N
35431	34028	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:09	\N
35432	34029	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:09	\N
35433	34030	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:09	\N
35434	34031	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:10	\N
35435	34032	DEPUTE	2012-07-22 00:00:00	\N	2014-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:10	\N
35436	34033	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:10	\N
35437	34034	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:10	\N
35438	34035	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:10	\N
35439	34036	DEPUTE	2006-09-02 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:10	\N
35440	34037	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:10	\N
35441	34038	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:10	\N
35442	34039	DEPUTE	2012-07-22 00:00:00	\N	2014-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:10	\N
35443	34040	VICPDTAN	2008-10-01 00:00:00	\N	2009-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:10	\N
35444	34041	SECAN	2009-10-06 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:10	\N
35445	34042	DEPUTE	2002-06-19 00:00:00	\N	2002-11-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:10	\N
35446	34043	DEPUTE	2003-02-03 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:10	\N
35447	34044	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:10	\N
35448	34045	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:10	\N
35449	34046	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:10	\N
35450	34047	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:10	\N
35451	34048	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:10	\N
35452	34049	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:10	\N
35453	34050	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:10	\N
35454	34051	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:10	\N
35455	34052	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:10	\N
35456	34053	DEPUTE	2002-06-25 00:00:00	\N	2002-06-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:10	\N
35457	34054	VICPDTAN	2006-12-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:10	\N
35458	34055	VICPDTAN	2010-11-16 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:10	\N
35459	34056	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:10	\N
35460	34057	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:10	\N
35461	34058	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:10	\N
35462	34059	DEPUTE	2002-06-19 00:00:00	\N	2003-02-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:11	\N
35463	34060	DEPUTE	2003-06-02 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:11	\N
35464	34061	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:11	\N
35465	34062	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:11	\N
35466	34063	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:11	\N
35467	34064	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:11	\N
35468	34065	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:11	\N
35469	34066	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:11	\N
35470	34067	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:11	\N
35471	34068	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:11	\N
35472	34069	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:11	\N
35473	34070	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:11	\N
35474	34071	DEPUTE	2014-05-03 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:11	\N
35475	34072	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:11	\N
35476	34073	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:11	\N
35477	34074	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:11	\N
35478	34075	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:11	\N
35479	34076	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:11	\N
35480	34077	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:11	\N
35481	34078	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:11	\N
35482	34079	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:11	\N
35483	34080	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:11	\N
35484	34081	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:11	\N
35485	34082	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:11	\N
35486	34083	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:12	\N
35487	34084	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:12	\N
35488	34085	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:12	\N
35489	34086	SECAN	2007-06-27 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:12	\N
35490	34087	SECAN	2012-06-27 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:12	\N
35491	34088	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:12	\N
35492	34089	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:12	\N
35493	34090	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:12	\N
43740	49346	DEPUTE	1986-04-02 00:00:00	\N	1986-04-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:18	\N
43740	49347	SECAN	1986-04-04 00:00:00	\N	1987-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:18	\N
43740	49348	DEPUTE	1987-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:18	\N
43795	49349	DEPUTE	1997-06-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:19	\N
43795	49350	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:19	\N
43814	49351	DEPUTE	1988-06-13 00:00:00	\N	1988-06-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:20	\N
43814	49352	QUESTAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:20	\N
50744	49353	PDTAN	2007-06-26 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:21	\N
50744	49354	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:21	\N
43906	49355	DEPUTE	1997-05-25 00:00:00	\N	1997-06-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:22	\N
43906	49356	SECAN	1997-06-13 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:22	\N
43905	49357	DEPUTE	1993-04-02 00:00:00	\N	1993-04-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:23	\N
43905	49358	SECAN	1993-04-07 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:23	\N
43907	49359	DEPUTE	2002-06-19 00:00:00	\N	2004-05-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:23	\N
43907	49360	SECAN	2004-05-24 00:00:00	\N	2005-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:23	\N
43907	49361	DEPUTE	2005-10-04 00:00:00	\N	2006-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:23	\N
43975	49362	DEPUTE	1997-06-01 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:25	\N
43975	49363	VICPDTAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:25	\N
43975	49364	DEPUTE	1999-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:25	\N
43978	49365	DEPUTE	1997-06-01 00:00:00	\N	2001-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:25	\N
43978	49366	VICPDTAN	2001-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:25	\N
44036	49367	DEPUTE	1986-04-02 00:00:00	\N	1987-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:26	\N
44036	49368	SECAN	1987-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:26	\N
44046	49369	DEPUTE	2007-06-20 00:00:00	\N	2007-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:26	\N
44046	49370	SECAN	2007-06-27 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:26	\N
44046	49371	DEPUTE	2008-10-02 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:26	\N
44076	49372	DEPUTE	1986-04-02 00:00:00	\N	1986-04-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:26	\N
44076	49373	SECAN	1986-04-04 00:00:00	\N	1987-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:26	\N
44076	49374	DEPUTE	1987-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:26	\N
44081	49375	DEPUTE	2007-06-20 00:00:00	\N	2010-10-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:27	\N
44081	49376	VICPDTAN	2010-10-05 00:00:00	\N	2011-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:27	\N
44081	49377	SECAN	2011-10-03 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:27	\N
44117	49378	DEPUTE	1993-04-02 00:00:00	\N	1995-05-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:27	\N
44117	49379	VICPDTAN	1995-05-31 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:27	\N
44126	49380	DEPUTE	2002-06-19 00:00:00	\N	2002-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:28	\N
44126	49381	VICPDTAN	2002-06-26 00:00:00	\N	2005-07-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:28	\N
50745	49382	VICPDTAN	1992-04-02 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:28	\N
50745	49383	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:28	\N
44166	49384	DEPUTE	2012-06-20 00:00:00	\N	2012-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:28	\N
44166	49385	PDTAN	2012-06-26 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:28	\N
44177	49386	DEPUTE	1988-06-13 00:00:00	\N	1988-06-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:28	\N
44177	49387	QUESTAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:28	\N
50746	49388	VICPDTAN	1989-04-03 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:33	\N
50746	49389	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:33	\N
44416	49390	DEPUTE	2002-06-19 00:00:00	\N	2002-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:34	\N
44416	49391	SECAN	2002-06-26 00:00:00	\N	2003-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:34	\N
44416	49392	DEPUTE	2003-10-01 00:00:00	\N	2005-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:34	\N
44416	49393	SECAN	2005-10-04 00:00:00	\N	2006-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:34	\N
44416	49394	DEPUTE	2006-10-04 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:34	\N
44418	49395	DEPUTE	2012-06-20 00:00:00	\N	2012-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:34	\N
44418	49396	QUESTAN	2012-06-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:34	\N
44427	49397	DEPUTE	1997-06-01 00:00:00	\N	1997-06-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:34	\N
44427	49398	VICPDTAN	1997-06-12 00:00:00	\N	2001-08-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:34	\N
44441	49399	DEPUTE	1988-06-13 00:00:00	\N	1988-06-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:34	\N
44441	49400	VICPDTAN	1988-06-24 00:00:00	\N	1991-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:34	\N
44441	49401	DEPUTE	1991-04-02 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:34	\N
44440	49402	DEPUTE	1986-04-02 00:00:00	\N	1988-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:34	\N
44440	49403	VICPDTAN	1988-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:34	\N
44454	49404	DEPUTE	1988-06-06 00:00:00	\N	1988-06-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:34	\N
44454	49405	QUESTAN	1988-06-24 00:00:00	\N	1990-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:35	\N
44454	49406	DEPUTE	1990-04-02 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:35	\N
44465	49407	DEPUTE	1993-04-02 00:00:00	\N	1996-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:35	\N
44465	49408	VICPDTAN	1996-10-01 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:35	\N
44496	49409	DEPUTE	1993-04-02 00:00:00	\N	1993-04-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:36	\N
44496	49410	SECAN	1993-04-07 00:00:00	\N	1995-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:36	\N
44496	49411	DEPUTE	1995-05-31 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:36	\N
44510	49412	DEPUTE	1986-04-02 00:00:00	\N	1986-04-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:36	\N
44510	49413	QUESTAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:36	\N
44587	49414	DEPUTE	1986-04-02 00:00:00	\N	1986-04-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:38	\N
44587	49415	SECAN	1986-04-04 00:00:00	\N	1987-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:38	\N
44587	49416	DEPUTE	1987-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:38	\N
50747	49417	QUESTAN	2007-06-27 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:38	\N
50747	49418	DEPUTE	2012-06-20 00:00:00	\N	2012-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:38	\N
50747	49419	QUESTAN	2012-06-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:38	\N
44607	49420	DEPUTE	1986-04-02 00:00:00	\N	1986-04-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:38	\N
44607	49421	SECAN	1986-04-04 00:00:00	\N	1987-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:38	\N
44607	49422	DEPUTE	1987-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:38	\N
44642	49423	DEPUTE	1997-06-01 00:00:00	\N	1997-06-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:39	\N
44642	49424	QUESTAN	1997-06-13 00:00:00	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:39	\N
44642	49425	DEPUTE	1998-10-01 00:00:00	\N	2001-11-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:39	\N
44640	49426	DEPUTE	1993-04-02 00:00:00	\N	1993-04-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:39	\N
44640	49427	VICPDTAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:39	\N
44640	49428	DEPUTE	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:39	\N
44643	49429	DEPUTE	2002-06-19 00:00:00	\N	2002-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:39	\N
44643	49430	SECAN	2002-06-26 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:39	\N
44657	49431	DEPUTE	2002-06-19 00:00:00	\N	2004-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:39	\N
44657	49432	VICPDTAN	2004-05-05 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:39	\N
44740	49433	DEPUTE	1988-06-13 00:00:00	\N	1988-06-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:41	\N
44740	49434	SECAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:41	\N
44779	49435	DEPUTE	1997-06-01 00:00:00	\N	1998-03-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:42	\N
44779	49436	VICPDTAN	1998-03-24 00:00:00	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:42	\N
44779	49437	DEPUTE	1998-10-01 00:00:00	\N	1999-02-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-08-11 11:32:42	\N
50701	49297	DEPUTE	2017-06-21 00:00:00	\N	2021-07-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:30	\N
50702	49298	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:30	\N
50703	49299	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:30	\N
50704	49300	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:30	\N
50967	50276	MAIRE	2008-03-16 00:00:00	\N	2017-10-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-21 17:13:05	2017-11-09 14:40:18
50706	49302	QUESTAN	2017-06-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:30	2017-08-10 10:58:10
50707	49303	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:30	\N
50708	49304	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:30	\N
50968	50277	MAIRE	2014-03-30 00:00:00	\N	2017-10-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-21 17:19:23	2017-12-04 19:10:17
50710	49306	DEPUTE	2017-06-21 00:00:00	\N	2020-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:30	\N
50711	49307	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:30	2017-08-10 10:58:10
50712	49308	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:30	\N
50713	49309	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:30	\N
50714	49310	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:30	\N
50715	49311	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:30	\N
50716	49312	DEPUTE	2017-06-21 00:00:00	\N	2021-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:30	\N
50717	49313	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:30	\N
50718	49314	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:30	\N
50719	49315	DEPUTE	2017-06-21 00:00:00	\N	2018-11-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:30	\N
50720	49316	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:30	\N
50721	49317	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:30	\N
50722	49318	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:30	\N
50723	49319	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:30	\N
50724	49320	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:31	\N
50725	49321	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:31	\N
50726	49322	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:31	\N
50727	49323	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:31	\N
50728	49324	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:31	\N
50729	49325	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:31	\N
50969	50278	CONSDPT	2015-03-29 00:00:00	\N	2021-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-21 17:20:27	2017-09-24 18:20:23
50731	49327	VICPDTAN	2017-06-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:31	2017-08-10 10:58:10
50732	49328	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:31	\N
50733	49329	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:31	\N
50734	49330	DEPUTE	2017-06-21 00:00:00	\N	2020-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:31	\N
50735	49331	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:31	\N
50736	49332	DEPUTE	2017-07-22 00:00:00	\N	2020-08-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:31	\N
50970	50279	PREMADJOINT	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-21 17:21:31	2017-09-21 17:22:08
50738	49334	SECAN	2017-06-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:31	2017-08-09 03:45:05
50739	49335	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:47:31	\N
50971	50280	MAIRE	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-21 17:28:49	2017-09-21 17:30:04
50973	50282	CONSDPT	2017-09-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-21 17:30:15	\N
35558	34155	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:15	\N
50974	50283	CONSMUNI	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-21 17:31:18	2017-09-21 17:31:43
50975	50284	CONSMUNI	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-21 17:32:51	2017-09-21 17:33:31
50978	50287	MAIRE	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-21 17:46:49	2017-09-21 17:47:38
50980	50289	CONSDPT	2017-09-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-21 17:47:44	\N
50982	50291	CONSMUNI	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-21 17:49:13	2017-09-21 17:49:49
50983	50292	CONSMUNI	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-21 17:50:17	2017-09-21 17:51:51
50984	50293	CONSDPT	2015-12-13 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-21 17:52:12	2017-09-21 17:53:15
50985	50294	MAIRE	1995-03-19 00:00:00	\N	2017-10-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-21 17:53:48	2018-05-30 16:11:43
50986	50295	CONSDPT	2015-12-13 00:00:00	\N	2017-10-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-21 17:55:02	2018-05-30 15:40:25
50987	50296	CONSDPT	2015-12-13 00:00:00	\N	2018-01-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-21 17:56:14	2018-02-26 11:09:21
50988	50297	MAIRE	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-21 17:58:06	2017-09-21 17:58:54
51004	50313	VICPDTMET	\N	2016	2017-10-22 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-09-22 10:32:29	2018-01-25 16:53:54
51005	50314	CONSDPT	2015-03-29 00:00:00	\N	2017-11-30 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-09-22 10:34:07	2017-09-22 10:45:27
51007	50316	MAIRE	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	2017-09-22 10:57:56	2017-09-22 11:00:46
51007	50318	CONSMUNI	2008-03-16 00:00:00	\N	2014-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-09-22 11:02:31	2017-09-22 11:02:55
51013	50322	VICPDTDPT	2015-03-29 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	2017-09-22 11:05:13	2017-09-22 11:07:01
51352	50535	PREVICPDTGEN	2004-03-28 00:00:00	\N	2011-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-09-24 20:49:57	2017-09-26 12:08:58
51022	50331	CONSDPT	2015-03-29 00:00:00	\N	2021-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-09-22 11:41:12	2017-09-24 20:29:32
51024	50333	CONSMUNI	2008-03-16 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	NON	2017-09-22 11:43:28	2017-09-22 11:44:39
51095	50383	MAIREADJOINT	2001-03-18 00:00:00	\N	2015-03-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 16:59:52	2017-09-24 17:03:12
51148	50405	CONSGENE	2001-03-18 00:00:00	\N	2004-04-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 17:34:57	2017-09-24 17:37:34
51148	50407	VICPDTGEN	2004-04-16 00:00:00	\N	2015-03-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 17:37:39	2017-09-24 17:40:27
51109	50416	VICPDTGEN	2001-03-18 00:00:00	\N	2015-03-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 17:42:30	2017-09-24 17:43:46
51188	50423	VICPDTDPT	2015-03-29 00:00:00	\N	2017-10-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 17:49:15	2017-11-20 14:44:03
50882	50432	CONSMUNI	2015-03-29 00:00:00	\N	2017-10-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 18:04:46	2017-09-24 18:05:10
51280	50469	PREMADJOINT	2001-03-18 00:00:00	\N	2004-10-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 19:09:13	2017-09-24 19:12:47
51268	50464	PREMADJOINT	2008-03-16 00:00:00	\N	2017-10-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 18:57:55	2017-09-24 19:07:48
51280	50471	MAIRE	2004-10-08 00:00:00	\N	2017-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-24 19:12:49	2017-11-13 19:54:16
51282	50473	PDTINTCOM	2014-03-30 00:00:00	\N	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017-09-24 19:13:36	2017-11-13 19:55:02
51285	50475	CONSDPT	2015-03-29 00:00:00	\N	2021-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-09-24 19:15:08	2017-09-24 19:16:58
51311	50487	CONSGENE	1994-03-27 00:00:00	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-09-24 19:33:19	2017-09-24 19:34:39
51292	50480	CONSMUNI	2008-03-16 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-24 19:18:53	2017-09-24 19:20:01
50990	50490	CONSMUNI	1983-03-14 00:00:00	\N	1988-02-11 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-09-24 19:41:54	2017-09-24 19:42:19
51321	50500	CONSGENE	2008-03-16 00:00:00	\N	2015-03-28 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-09-24 19:55:11	2017-09-26 11:13:41
51334	50513	MAIREDEL	2012-09-27 00:00:00	\N	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-09-24 20:14:22	2017-11-09 14:34:12
51339	50519	VICPDTGEN	2008-03-16 00:00:00	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-09-24 20:26:46	2017-09-24 20:29:24
51335	50515	CONSGENE	2011-03-27 00:00:00	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-09-24 20:18:24	2017-09-24 20:19:35
51341	50521	VICPDTREG	1998-03-15 00:00:00	\N	2008-03-16 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-09-24 20:30:35	2017-09-24 20:37:55
51349	50530	MAIREADJOINT	2001-03-11 00:00:00	\N	2014-03-22 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-09-24 20:35:27	2017-09-26 11:57:08
51349	50531	CONSMUNI	1995-06-11 00:00:00	\N	2001-03-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-09-24 20:36:26	2017-09-24 20:41:25
51351	50533	MAIREADJOINT	1989-03-24 00:00:00	\N	2014-03-01 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-09-24 20:43:46	2017-09-24 20:45:18
51352	50534	VICPDTGEN	1998-03-22 00:00:00	\N	2004-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-09-24 20:45:59	2017-09-24 20:49:54
34005	32602	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:19	\N
34006	32603	DEPUTE	1968-07-11 00:00:00	\N	1969-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:19	\N
34007	32604	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:19	\N
34008	32605	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:19	\N
34009	32606	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:19	\N
34010	32607	DEPUTE	1997-06-01 00:00:00	\N	1998-09-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:19	\N
34011	32608	QUESTAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:19	\N
34012	32609	QUESTAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:19	\N
34013	32610	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:19	\N
34014	32611	DEPUTE	1968-07-11 00:00:00	\N	1969-07-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:19	\N
34015	32612	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:19	\N
34016	32613	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:19	\N
34017	32614	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:19	\N
34018	32615	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:19	\N
34019	32616	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:19	\N
34020	32617	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:19	\N
34021	32618	DEPUTE	1997-05-25 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:19	\N
34022	32619	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:19	\N
34023	32620	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:19	\N
34024	32621	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:19	\N
34025	32622	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:19	\N
34026	32623	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:19	\N
34027	32624	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:19	\N
34028	32625	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:19	\N
34029	32626	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:19	\N
34030	32627	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:19	\N
34031	32628	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:19	\N
34032	32629	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:19	\N
34033	32630	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:19	\N
34034	32631	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:19	\N
34035	32632	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:19	\N
34036	32633	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:19	\N
34037	32634	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:20	\N
34038	32635	DEPUTE	1988-10-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:20	\N
34039	32636	DEPUTE	1995-05-10 00:00:00	\N	1995-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:20	\N
34040	32637	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:20	\N
34041	32638	DEPUTE	1968-07-11 00:00:00	\N	1971-02-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:20	\N
34042	32639	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:20	\N
34043	32640	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:20	\N
34044	32641	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:20	\N
34045	32642	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:20	\N
34046	32643	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:20	\N
34047	32644	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:20	\N
34048	32645	DEPUTE	1993-05-02 00:00:00	\N	1995-07-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:20	\N
34049	32646	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:20	\N
34050	32647	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:20	\N
34051	32648	DEPUTE	2007-07-20 00:00:00	\N	2011-03-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:20	\N
34052	32649	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:20	\N
34053	32650	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:20	\N
34054	32651	DEPUTE	1986-10-09 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:20	\N
34055	32652	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:20	\N
34056	32653	DEPUTE	2004-05-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:20	\N
34057	32654	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:20	\N
34058	32655	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:20	\N
34059	32656	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:20	\N
34060	32657	DEPUTE	1961-09-26 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:20	\N
34061	32658	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:20	\N
34062	32659	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:20	\N
34063	32660	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:20	\N
34064	32661	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:20	\N
34065	32662	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:20	\N
34066	32663	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:20	\N
34067	32664	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:20	\N
34068	32665	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:21	\N
34069	32666	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:21	\N
34070	32667	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:21	\N
34071	32668	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:21	\N
34072	32669	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:21	\N
34073	32670	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:21	\N
34074	32671	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:21	\N
34075	32672	DEPUTE	1978-05-07 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:21	\N
34076	32673	DEPUTE	1977-05-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:21	\N
34077	32674	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:21	\N
34078	32675	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:21	\N
34079	32676	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:21	\N
34080	32677	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:21	\N
34081	32678	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:21	\N
34082	32679	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:21	\N
34083	32680	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:21	\N
34084	32681	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:21	\N
34085	32682	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:21	\N
34086	32683	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:21	\N
34087	32684	SECAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:21	\N
34088	32685	SECAN	2002-06-26 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:21	\N
34089	32686	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:21	\N
34090	32687	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:21	\N
34091	32688	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:21	\N
34092	32689	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:21	\N
34093	32690	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:21	\N
34094	32691	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:22	\N
34095	32692	DEPUTE	2001-09-25 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:22	\N
34096	32693	DEPUTE	1973-04-02 00:00:00	\N	1976-11-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:22	\N
34097	32694	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:22	\N
35494	34091	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:12	\N
35495	34092	DEPUTE	2012-06-20 00:00:00	\N	2013-08-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:12	\N
35496	34093	DEPUTE	2014-05-03 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:12	\N
35497	34094	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:12	\N
35498	34095	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:12	\N
35499	34096	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:12	\N
35500	34097	DEPUTE	2007-06-20 00:00:00	\N	2007-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:12	\N
35501	34098	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:12	\N
35502	34099	DEPUTE	2007-06-20 00:00:00	\N	2011-10-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:12	\N
35503	34100	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:12	\N
35504	34101	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:12	\N
35505	34102	DEPUTE	2002-06-25 00:00:00	\N	2002-06-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:12	\N
35506	34103	DEPUTE	2007-06-26 00:00:00	\N	2011-10-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:12	\N
35507	34104	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:12	\N
35508	34105	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:12	\N
35509	34106	DEPUTE	2012-06-20 00:00:00	\N	2016-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:12	\N
35510	34107	VICPDTAN	2012-06-27 00:00:00	\N	2014-12-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:12	\N
35511	34108	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:13	\N
35512	34109	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:13	\N
35513	34110	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:13	\N
35514	34111	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:13	\N
35515	34112	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:13	\N
35516	34113	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:13	\N
35517	34114	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:13	\N
35518	34115	DEPUTE	2016-03-12 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:13	\N
35519	34116	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:13	\N
35520	34117	DEPUTE	2007-06-26 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:13	\N
35521	34118	DEPUTE	2007-06-20 00:00:00	\N	2009-01-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:13	\N
35522	34119	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:13	\N
35523	34120	DEPUTE	2012-06-20 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:13	\N
35524	34121	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:13	\N
35525	34122	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:13	\N
35526	34123	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:13	\N
35527	34124	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:13	\N
35528	34125	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:13	\N
35529	34126	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:13	\N
35530	34127	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:13	\N
35531	34128	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:13	\N
35532	34129	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:14	\N
35533	34130	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:14	\N
35534	34131	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:14	\N
35535	34132	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:14	\N
35536	34133	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:14	\N
35537	34134	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:14	\N
35538	34135	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:14	\N
35539	34136	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:14	\N
35540	34137	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:14	\N
35541	34138	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:14	\N
35542	34139	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:14	\N
35543	34140	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:14	\N
35544	34141	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:14	\N
35545	34142	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:14	\N
35546	34143	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:14	\N
35547	34144	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:15	\N
35548	34145	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:15	\N
35549	34146	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:15	\N
35550	34147	DEPUTE	2012-06-20 00:00:00	\N	2016-02-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:15	\N
35551	34148	DEPUTE	2007-06-20 00:00:00	\N	2010-11-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:15	\N
35552	34149	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:15	\N
35553	34150	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:15	\N
35554	34151	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:15	\N
35555	34152	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:15	\N
35556	34153	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:15	\N
35557	34154	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:15	\N
35559	34156	DEPUTE	2007-06-26 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:15	\N
35560	34157	VICPDTAN	2016-05-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:15	\N
35561	34158	PDTAN	2017-06-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:15	\N
35562	34159	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:15	\N
35563	34160	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:15	\N
35564	34161	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:15	\N
35565	34162	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:16	\N
35566	34163	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:16	\N
35567	34164	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:16	\N
35568	34165	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:16	\N
35569	34166	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:16	\N
35570	34167	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:16	\N
35571	34168	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:16	\N
35572	34169	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:16	\N
35573	34170	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:16	\N
35574	34171	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:16	\N
35575	34172	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:16	\N
35576	34173	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:16	\N
35577	34174	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:16	\N
35578	34175	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:16	\N
35579	34176	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:16	\N
35580	34177	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:16	\N
35581	34178	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:16	\N
35582	34179	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:17	\N
35583	34180	DEPUTE	2007-06-20 00:00:00	\N	2009-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:17	\N
35584	34181	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:17	\N
35585	34182	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:17	\N
35586	34183	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:17	\N
35587	34184	DEPUTE	2012-06-20 00:00:00	\N	2015-07-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:33:17	\N
47863	46459	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:50	\N
47864	46460	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:50	\N
47865	46461	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:50	\N
50841	50139	CONSCOMINT	2014-03-23 00:00:00	\N	2017-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-09-19 17:17:00	2017-12-04 21:46:13
47867	46463	VICPDTAN	2000-03-30 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:50	2017-08-07 03:43:33
47868	46464	VICPDTAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:50	2017-08-07 03:43:33
47869	46465	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:51	\N
47870	46466	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:51	\N
47871	46467	DEPUTE	1981-07-25 00:00:00	\N	1983-04-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:51	\N
47872	46468	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:51	\N
47873	46469	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:51	\N
47874	46470	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:51	\N
47875	46471	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:51	\N
47876	46472	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:51	\N
47877	46473	DEPUTE	1997-06-01 00:00:00	\N	1998-02-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:51	\N
47878	46474	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:51	\N
47879	46475	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:51	\N
47880	46476	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:51	\N
47881	46477	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:51	\N
47882	46478	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:51	\N
47883	46479	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:51	\N
47884	46480	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:51	\N
47885	46481	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:51	\N
47886	46482	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:51	\N
47887	46483	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:51	\N
47888	46484	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:51	\N
47889	46485	DEPUTE	1988-06-13 00:00:00	\N	1991-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:51	\N
47890	46486	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:51	\N
47891	46487	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:51	\N
47892	46488	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:51	\N
47893	46489	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:51	\N
47894	46490	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:51	\N
47895	46491	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:51	\N
47896	46492	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:51	\N
47897	46493	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:51	2017-08-10 10:57:09
47898	46494	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:51	2017-08-10 10:57:09
47900	46496	VICPDTAN	2007-06-27 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:51	2017-08-10 10:57:09
47901	46497	VICPDTAN	2012-06-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:51	2017-08-10 10:57:09
47902	46498	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:52	\N
50842	50140	MAIRE	2014-03-23 00:00:00	\N	2018-04-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-19 17:19:31	2018-04-26 14:57:11
47904	46500	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:52	\N
47905	46501	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:52	\N
47907	46503	SECAN	1988-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:52	2017-08-10 10:57:09
47908	46504	VICPDTAN	2002-06-26 00:00:00	\N	2005-06-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:52	2017-08-10 03:43:39
47909	46505	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:52	\N
47910	46506	DEPUTE	1988-07-29 00:00:00	\N	1992-12-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:52	\N
47911	46507	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:52	\N
47914	46510	DEPUTE	2012-06-20 00:00:00	\N	2014-05-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:52	\N
47915	46511	SECAN	2004-10-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:52	2017-08-09 03:43:49
47916	46512	VICPDTAN	2007-06-27 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:52	2017-08-09 03:43:49
47917	46513	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:52	\N
47918	46514	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:52	\N
47919	46515	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:52	\N
47920	46516	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:52	\N
47921	46517	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:52	\N
47922	46518	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:52	\N
47923	46519	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:52	\N
47924	46520	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:52	\N
47925	46521	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:52	\N
47926	46522	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:52	\N
47927	46523	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:52	\N
47928	46524	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:52	\N
47929	46525	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:52	\N
47930	46526	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:52	2017-08-10 10:57:09
47931	46527	DEPUTE	1983-05-09 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:52	2017-08-10 10:57:09
47932	46528	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:52	\N
47933	46529	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:52	\N
47934	46530	DEPUTE	1988-06-06 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:52	\N
47935	46531	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:52	\N
47936	46532	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:52	\N
47937	46533	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:53	2017-08-10 03:43:39
47938	46534	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:53	\N
47939	46535	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:53	\N
47940	46536	DEPUTE	2012-06-20 00:00:00	\N	2017-01-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:53	2017-08-10 10:57:09
47941	46537	DEPUTE	2017-04-22 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:53	2017-08-10 10:57:09
47942	46538	DEPUTE	1997-06-12 00:00:00	\N	2000-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:53	2017-08-07 03:43:34
47943	46539	DEPUTE	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:53	2017-08-10 03:43:39
47944	46540	DEPUTE	1973-04-02 00:00:00	\N	1977-03-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:53	\N
47945	46541	DEPUTE	1997-07-05 00:00:00	\N	2001-02-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:53	\N
47946	46542	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:53	\N
47947	46543	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:53	\N
47948	46544	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:53	\N
47949	46545	DEPUTE	1984-09-29 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:53	\N
47950	46546	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:53	\N
47951	46547	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:53	\N
47953	46549	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:53	2017-08-10 10:57:10
47954	46550	DEPUTE	2016-03-12 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:53	2017-08-10 10:57:10
47955	46551	QUESTAN	2007-06-27 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:53	2017-08-10 03:43:40
49349	47945	DEPUTE	1981-07-02 00:00:00	\N	1984-08-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:37	\N
49350	47946	DEPUTE	1990-01-25 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:37	\N
49351	47947	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:37	\N
49352	47948	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:37	\N
49353	47949	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:37	\N
49354	47950	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:37	\N
49355	47951	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:37	\N
49356	47952	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:37	\N
49357	47953	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:37	\N
49358	47954	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:37	\N
49359	47955	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:37	\N
49360	47956	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:37	\N
49361	47957	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:37	\N
49362	47958	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:37	\N
49363	47959	DEPUTE	1997-06-01 00:00:00	\N	1998-04-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:37	\N
49364	47960	DEPUTE	1998-02-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:37	\N
49365	47961	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:37	\N
49366	47962	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:37	\N
49367	47963	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:37	\N
49368	47964	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:37	\N
49369	47965	DEPUTE	1986-04-02 00:00:00	\N	1986-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:37	2017-08-10 10:57:35
49370	47966	DEPUTE	1986-08-25 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:37	2017-08-10 10:57:35
49371	47967	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:37	\N
49372	47968	DEPUTE	1988-06-13 00:00:00	\N	1992-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:37	\N
49373	47969	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:37	\N
49374	47970	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:37	\N
49375	47971	DEPUTE	2000-03-19 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:37	\N
49376	47972	DEPUTE	2000-03-20 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:37	\N
49377	47973	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:37	\N
49378	47974	DEPUTE	2007-06-20 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:37	\N
49379	47975	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:38	\N
49381	47977	DEPUTE	2000-06-26 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:38	\N
49382	47978	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:38	\N
49384	47980	SECAN	2006-12-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:38	2017-08-10 03:44:06
49385	47981	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:38	2017-08-10 10:57:35
49386	47982	DEPUTE	2000-10-22 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:38	\N
49387	47983	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:38	\N
49388	47984	DEPUTE	2001-04-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:38	\N
49389	47985	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:38	\N
49390	47986	DEPUTE	2012-06-20 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:38	2017-08-11 16:47:48
49391	47987	DEPUTE	2017-06-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:38	\N
49392	47988	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:38	\N
49393	47989	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:38	\N
49394	47990	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:38	\N
49395	47991	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:38	\N
49396	47992	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:38	\N
49397	47993	DEPUTE	2017-06-21 00:00:00	\N	2020-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:38	\N
49398	47994	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:38	\N
49399	47995	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:38	\N
49400	47996	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:38	\N
49401	47997	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:38	\N
49402	47998	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:38	\N
49403	47999	DEPUTE	2007-07-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:38	\N
49404	48000	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:38	\N
49405	48001	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:38	\N
49406	48002	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:38	\N
49408	48004	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:39	\N
49409	48005	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:39	2017-08-10 03:44:07
49410	48006	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:39	2017-08-10 10:57:36
49411	48007	VICPDTAN	2008-09-26 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:39	2017-08-10 03:44:07
49412	48008	VICPDTAN	2012-06-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:39	2017-08-10 10:57:36
49413	48009	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:39	\N
49414	48010	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:39	\N
49415	48011	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:39	\N
49416	48012	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:39	\N
49417	48013	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:39	\N
49418	48014	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:39	\N
49419	48015	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:39	\N
49420	48016	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:39	\N
49421	48017	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:39	2017-08-10 10:57:36
49422	48018	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:39	\N
49423	48019	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:39	\N
49424	48020	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:39	\N
49425	48021	DEPUTE	2002-06-25 00:00:00	\N	2002-06-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:39	2017-08-10 10:57:36
49426	48022	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:39	\N
49427	48023	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:39	\N
49428	48024	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:39	\N
49429	48025	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:39	\N
49430	48026	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:39	\N
49431	48027	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:39	\N
49432	48028	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:39	\N
49433	48029	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:39	\N
49434	48030	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:39	\N
49435	48031	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:40	\N
49436	48032	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:40	\N
49437	48033	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:40	\N
49438	48034	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:40	\N
49439	48035	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:40	\N
49440	48036	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:40	\N
49441	48037	DEPUTE	2007-07-04 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:40	\N
44888	43484	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:18	\N
44889	43485	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:18	\N
44890	43486	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:18	\N
44891	43487	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:18	\N
44892	43488	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:18	\N
44893	43489	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:18	\N
44894	43490	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:18	\N
44895	43491	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:18	\N
44896	43492	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:18	\N
44897	43493	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:18	\N
44898	43494	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:18	\N
44899	43495	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:18	\N
44900	43496	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:18	\N
44901	43497	DEPUTE	1993-04-02 00:00:00	\N	1994-12-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:18	\N
44902	43498	DEPUTE	2004-06-28 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:18	\N
44903	43499	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:18	\N
44904	43500	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:18	\N
44905	43501	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:18	\N
44906	43502	DEPUTE	1963-05-05 00:00:00	\N	1966-02-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:18	\N
44907	43503	DEPUTE	1967-04-03 00:00:00	\N	1967-05-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:18	\N
44908	43504	DEPUTE	1968-07-11 00:00:00	\N	1968-08-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:18	\N
44909	43505	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:18	\N
44910	43506	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:18	\N
44911	43507	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:18	\N
44912	43508	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	\N
44913	43509	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	\N
44914	43510	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	\N
44916	43512	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	\N
44917	43513	PDTAN	2002-06-26 00:00:00	\N	2007-03-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	2017-08-10 10:56:17
44918	43514	DEPUTE	1988-01-25 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	\N
44919	43515	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	\N
44920	43516	DEPUTE	2002-06-19 00:00:00	\N	2002-10-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	2017-08-10 10:56:17
44921	43517	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	\N
44922	43518	DEPUTE	2002-12-16 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	2017-08-10 10:56:17
44923	43519	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	\N
44924	43520	DEPUTE	1984-01-19 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	\N
44925	43521	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	\N
44926	43522	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	\N
44927	43523	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	\N
44928	43524	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	\N
44929	43525	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	\N
44930	43526	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	\N
44931	43527	DEPUTE	1986-04-02 00:00:00	\N	1986-05-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	\N
44932	43528	DEPUTE	1999-03-29 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	\N
44934	43530	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	\N
44935	43531	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	\N
44936	43532	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	\N
44937	43533	SECAN	2004-10-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	2017-08-10 10:56:18
44938	43534	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	\N
44939	43535	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	\N
44940	43536	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	\N
44941	43537	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	\N
44942	43538	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	\N
44943	43539	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	\N
44944	43540	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	\N
44945	43541	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	\N
44946	43542	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	\N
44947	43543	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	\N
44948	43544	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	\N
44949	43545	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	\N
44950	43546	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	\N
44951	43547	DEPUTE	1976-11-18 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	\N
44952	43548	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	\N
44953	43549	DEPUTE	1986-04-18 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	\N
44954	43550	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	\N
44955	43551	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	\N
44956	43552	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	\N
44957	43553	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	\N
44958	43554	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	\N
44959	43555	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	\N
44960	43556	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	\N
44961	43557	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:19	\N
44962	43558	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:20	\N
44963	43559	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:20	\N
44964	43560	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:20	\N
44965	43561	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:20	\N
44966	43562	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:20	\N
44967	43563	DEPUTE	1997-06-01 00:00:00	\N	2001-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:20	\N
44968	43564	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:20	\N
44969	43565	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:20	\N
44970	43566	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:20	\N
44971	43567	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:20	\N
44972	43568	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:20	\N
44973	43569	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:20	\N
44974	43570	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:20	\N
44975	43571	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:20	\N
44976	43572	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:20	\N
44977	43573	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:20	\N
44978	43574	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:20	\N
44979	43575	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:20	\N
44980	43576	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:20	\N
46375	44971	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:03	\N
46376	44972	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:03	\N
46377	44973	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:03	\N
46378	44974	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:03	\N
46379	44975	DEPUTE	1993-04-02 00:00:00	\N	1995-05-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:03	\N
46380	44976	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:03	\N
46381	44977	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:03	\N
46382	44978	DEPUTE	1988-06-13 00:00:00	\N	1988-10-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:03	\N
46383	44979	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:03	\N
46384	44980	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:03	\N
46385	44981	DEPUTE	1994-08-23 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:04	\N
46386	44982	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:04	\N
46387	44983	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:04	\N
46388	44984	DEPUTE	2007-06-20 00:00:00	\N	2008-09-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:04	\N
46389	44985	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:04	\N
46390	44986	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:04	\N
46391	44987	DEPUTE	2012-06-20 00:00:00	\N	2014-05-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:04	\N
46392	44988	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:04	\N
46393	44989	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:04	\N
46394	44990	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:04	\N
46395	44991	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:04	\N
46396	44992	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:04	\N
46397	44993	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:04	\N
46398	44994	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:04	\N
46399	44995	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:04	\N
46400	44996	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:04	\N
46401	44997	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:04	\N
46402	44998	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:04	\N
46403	44999	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:04	\N
46404	45000	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:04	\N
46405	45001	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:04	\N
46406	45002	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:04	\N
46407	45003	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:04	\N
46408	45004	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:04	\N
46409	45005	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:04	\N
46410	45006	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:05	\N
50820	50114	PREPDTINTCOM	2014-04-24 00:00:00	\N	2017-03-19 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-09-19 16:22:31	2017-11-21 18:36:46
46412	45008	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:05	\N
46413	45009	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:05	\N
46414	45010	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:05	\N
46415	45011	VICPDTAN	1986-04-04 00:00:00	\N	1987-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:05	2017-08-10 10:56:43
46416	45012	DEPUTE	1971-12-05 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:05	\N
46417	45013	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:05	\N
46418	45014	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:05	\N
46419	45015	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:05	\N
46420	45016	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:05	\N
50821	50115	MAIRE	2014-03-31 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2017-09-19 16:28:07	2017-09-19 16:28:30
46422	45018	SECAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:05	2017-08-10 10:56:43
46423	45019	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:05	\N
46424	45020	DEPUTE	1967-04-03 00:00:00	\N	1967-05-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:05	\N
46425	45021	DEPUTE	1968-07-11 00:00:00	\N	1969-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:05	\N
46426	45022	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:05	\N
46427	45023	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:05	\N
46428	45024	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:05	\N
46429	45025	DEPUTE	2007-06-20 00:00:00	\N	2010-03-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:05	\N
46431	45027	QUESTAN	2002-06-26 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:05	2017-08-10 03:43:13
46432	45028	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:05	\N
46433	45029	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:05	\N
46434	45030	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:05	\N
46435	45031	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:05	\N
46436	45032	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:05	\N
46437	45033	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:05	\N
46438	45034	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:06	\N
46439	45035	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:06	\N
46441	45037	VICPDTAN	2003-10-01 00:00:00	\N	2004-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:06	2017-08-10 10:56:44
46442	45038	VICPDTAN	2006-01-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:06	2017-08-10 10:56:44
46443	45039	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:06	\N
46444	45040	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:06	\N
46445	45041	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:06	\N
46446	45042	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:06	\N
46447	45043	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:06	\N
46449	45045	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:06	\N
46450	45046	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:06	\N
46451	45047	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:06	\N
46452	45048	DEPUTE	1997-06-01 00:00:00	\N	2001-04-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:06	\N
46453	45049	VICPDTAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:06	2017-08-10 10:56:44
46454	45050	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:06	\N
46455	45051	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:06	\N
46456	45052	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:06	\N
46457	45053	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:06	\N
46458	45054	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:06	\N
46459	45055	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:06	\N
46460	45056	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:06	\N
46461	45057	DEPUTE	1958-12-09 00:00:00	\N	1961-09-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:06	\N
46462	45058	DEPUTE	1973-04-02 00:00:00	\N	1974-07-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:06	\N
46463	45059	DEPUTE	1974-07-26 00:00:00	\N	1977-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:06	\N
46464	45060	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:06	\N
46465	45061	DEPUTE	1986-04-02 00:00:00	\N	1986-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:07	\N
46466	45062	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:07	\N
46467	45063	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:07	\N
47958	46554	DEPUTE	1986-04-02 00:00:00	\N	1986-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:53	\N
47959	46555	DEPUTE	1978-04-02 00:00:00	\N	1978-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:53	\N
47960	46556	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:53	\N
47961	46557	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:53	\N
50843	50141	VICPDTDPT	2015-12-13 00:00:00	\N	2017-10-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-09-19 17:20:53	2017-12-04 21:45:17
47964	46560	SECAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:54	2017-08-10 10:57:10
47965	46561	SECAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:54	2017-08-10 10:57:10
47966	46562	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:54	\N
47967	46563	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:54	\N
47968	46564	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:54	\N
47969	46565	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:54	\N
47970	46566	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:54	\N
47971	46567	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:54	\N
47972	46568	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:54	\N
47973	46569	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:54	\N
47974	46570	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:54	\N
47975	46571	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:54	\N
47976	46572	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:54	\N
47977	46573	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:54	\N
47978	46574	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:54	\N
47979	46575	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:54	\N
47980	46576	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:54	\N
47981	46577	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:54	\N
47982	46578	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:54	\N
47983	46579	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:54	\N
47984	46580	DEPUTE	1973-04-02 00:00:00	\N	1977-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:54	\N
47985	46581	DEPUTE	1978-04-03 00:00:00	\N	1978-05-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:54	\N
47956	46552	DEPUTE	2000-04-28 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:53	\N
47957	46553	DEPUTE	1973-04-02 00:00:00	\N	1974-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:53	\N
47986	46582	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:54	\N
47987	46583	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:54	\N
47988	46584	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:55	\N
47989	46585	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:55	\N
47991	46587	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:55	2017-08-07 03:43:35
47992	46588	SECAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:55	2017-08-10 10:57:11
47993	46589	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:55	\N
47994	46590	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:55	\N
47995	46591	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:55	\N
47996	46592	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:55	\N
47997	46593	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:55	\N
47998	46594	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:55	\N
47999	46595	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:55	\N
48000	46596	DEPUTE	2007-06-20 00:00:00	\N	2009-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:55	2017-08-08 03:43:58
48001	46597	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:55	2017-08-08 03:43:58
48002	46598	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:55	\N
48003	46599	DEPUTE	1997-07-03 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:55	\N
48004	46600	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:55	\N
48005	46601	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:55	\N
48006	46602	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:55	\N
48007	46603	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:55	\N
48008	46604	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:55	\N
48009	46605	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:55	\N
48010	46606	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:55	\N
48011	46607	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:55	\N
48012	46608	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:55	\N
48014	46610	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:55	\N
48015	46611	SECAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:55	2017-08-10 03:43:41
48016	46612	DEPUTE	1981-07-02 00:00:00	\N	1983-04-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:56	\N
48017	46613	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:56	\N
48018	46614	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:56	\N
48019	46615	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:56	\N
48020	46616	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:56	\N
48021	46617	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:56	\N
48022	46618	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:56	\N
48023	46619	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:56	\N
48024	46620	DEPUTE	2007-06-20 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:56	\N
48025	46621	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:56	\N
48026	46622	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:56	\N
48027	46623	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:56	\N
48028	46624	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:56	\N
48029	46625	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:56	\N
48030	46626	DEPUTE	1988-12-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:56	\N
48031	46627	DEPUTE	2002-06-19 00:00:00	\N	2006-06-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:56	\N
48032	46628	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:56	\N
48033	46629	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:56	\N
48034	46630	DEPUTE	2007-06-20 00:00:00	\N	2011-07-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:56	2017-08-10 03:43:42
48035	46631	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:56	2017-08-10 03:43:42
48036	46632	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:56	\N
48037	46633	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:56	\N
48038	46634	DEPUTE	1986-05-07 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:56	\N
48039	46635	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:56	\N
48040	46636	DEPUTE	1988-06-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:56	\N
48041	46637	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:57	\N
48042	46638	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:57	\N
48043	46639	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:57	\N
48044	46640	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:57	2017-08-09 03:43:52
48045	46641	DEPUTE	1988-06-13 00:00:00	\N	1992-07-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:57	\N
48046	46642	DEPUTE	1995-09-07 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:57	2017-08-09 03:43:52
48047	46643	DEPUTE	1997-06-01 00:00:00	\N	2001-12-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:57	\N
48048	46644	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:57	\N
49442	48038	DEPUTE	2012-12-17 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:40	\N
49443	48039	DEPUTE	2007-07-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:40	\N
49444	48040	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:40	\N
49445	48041	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:40	\N
49446	48042	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:40	\N
49447	48043	DEPUTE	2012-06-20 00:00:00	\N	2015-08-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:40	\N
49448	48044	DEPUTE	2004-05-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:40	\N
49449	48045	DEPUTE	2004-11-22 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:40	\N
49450	48046	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:40	\N
49451	48047	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:40	\N
49452	48048	DEPUTE	2004-05-01 00:00:00	\N	2005-07-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:40	\N
49455	48051	SECAN	2005-10-04 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:40	2017-08-10 10:57:37
49456	48052	QUESTAN	2007-06-27 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:40	2017-08-08 03:44:31
49457	48053	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:41	\N
49458	48054	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:41	\N
49459	48055	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:41	\N
49460	48056	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:41	\N
49461	48057	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:41	\N
49462	48058	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:41	\N
49463	48059	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:41	\N
49464	48060	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:41	\N
49465	48061	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:41	\N
49466	48062	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:41	\N
49467	48063	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:41	\N
49468	48064	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:41	\N
49469	48065	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:41	\N
49470	48066	DEPUTE	2007-06-20 00:00:00	\N	2011-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:41	\N
49471	48067	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:41	\N
49472	48068	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:41	\N
49473	48069	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:41	\N
49474	48070	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:41	\N
49475	48071	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:41	\N
49476	48072	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:41	\N
49477	48073	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:41	\N
49478	48074	DEPUTE	2010-11-13 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:41	\N
49479	48075	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:41	\N
49480	48076	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:41	\N
49481	48077	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:41	\N
49482	48078	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:41	\N
49483	48079	DEPUTE	2010-06-05 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:41	\N
49485	48081	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:41	2017-08-10 03:44:08
49486	48082	DEPUTE	2009-04-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:41	\N
49487	48083	DEPUTE	2007-07-20 00:00:00	\N	2009-07-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:41	2017-08-10 03:44:08
49488	48084	DEPUTE	2009-09-28 00:00:00	\N	2010-05-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:41	2017-08-10 03:44:08
49489	48085	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:41	\N
49490	48086	DEPUTE	2012-07-22 00:00:00	\N	2013-08-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:41	\N
49491	48087	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:42	\N
49492	48088	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:42	\N
49493	48089	DEPUTE	2007-07-20 00:00:00	\N	2012-03-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:42	\N
49494	48090	DEPUTE	2008-09-19 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:42	\N
49495	48091	DEPUTE	2010-04-23 00:00:00	\N	2011-06-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:42	\N
49496	48092	DEPUTE	2012-07-22 00:00:00	\N	2016-03-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:42	\N
49497	48093	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:42	\N
49498	48094	DEPUTE	2007-07-20 00:00:00	\N	2009-07-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:42	\N
49499	48095	DEPUTE	2013-06-10 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:42	\N
49500	48096	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:42	\N
49501	48097	DEPUTE	2014-05-10 00:00:00	\N	2014-05-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:42	\N
49502	48098	DEPUTE	2004-05-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:42	\N
49503	48099	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:42	\N
49504	48100	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:42	\N
49505	48101	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:42	\N
49506	48102	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:42	\N
49507	48103	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:42	\N
49508	48104	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:42	\N
49509	48105	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:42	\N
49510	48106	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:42	2017-08-10 10:57:38
49511	48107	DEPUTE	2007-06-20 00:00:00	\N	2010-12-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:42	\N
49512	48108	DEPUTE	2005-10-04 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:42	2017-08-10 10:57:38
49513	48109	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:42	\N
49514	48110	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:42	\N
49515	48111	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:42	\N
49516	48112	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:42	\N
49517	48113	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:42	\N
49518	48114	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:42	\N
49519	48115	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:42	\N
53926	53733	DEPUTE	2024-02-10 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
49520	48116	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:42	\N
49521	48117	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:42	\N
49522	48118	DEPUTE	2007-06-20 00:00:00	\N	2007-11-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:42	\N
49523	48119	DEPUTE	2002-07-19 00:00:00	\N	2005-06-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:42	\N
49524	48120	DEPUTE	2009-01-05 00:00:00	\N	2010-12-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:42	\N
49525	48121	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:43	\N
49526	48122	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:43	\N
49527	48123	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:43	\N
49528	48124	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:43	\N
49529	48125	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:43	\N
49530	48126	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:43	\N
49531	48127	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:43	\N
49532	48128	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:43	\N
49533	48129	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:43	\N
49534	48130	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:43	\N
50893	50195	MAIREADJOINT	2014-03-30 00:00:00	\N	2017-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-20 11:26:33	2017-09-20 11:29:14
44981	43577	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:20	\N
44982	43578	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:20	\N
44983	43579	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:20	\N
44984	43580	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:20	\N
44985	43581	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:20	\N
44986	43582	DEPUTE	1997-06-01 00:00:00	\N	1998-07-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:20	\N
44987	43583	DEPUTE	2007-06-20 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:20	\N
44988	43584	DEPUTE	1975-10-03 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:20	\N
44989	43585	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:20	\N
44990	43586	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:20	\N
44991	43587	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:20	\N
44992	43588	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:20	\N
44993	43589	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:20	\N
44994	43590	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:20	\N
44995	43591	DEPUTE	1978-05-06 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:20	\N
44996	43592	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:20	\N
44997	43593	DEPUTE	1986-04-02 00:00:00	\N	1988-01-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:20	\N
44998	43594	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:21	\N
44999	43595	DEPUTE	1981-07-02 00:00:00	\N	1986-02-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:21	\N
45000	43596	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:21	\N
45001	43597	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:21	\N
45002	43598	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:21	\N
45003	43599	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:21	\N
45004	43600	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:21	\N
45005	43601	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:21	\N
45006	43602	DEPUTE	1994-09-13 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:21	\N
45007	43603	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:21	\N
45008	43604	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:21	\N
45009	43605	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:21	\N
45010	43606	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:21	\N
45011	43607	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:21	\N
45012	43608	DEPUTE	2008-12-01 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:21	\N
45013	43609	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:21	\N
45014	43610	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:21	\N
45015	43611	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:21	\N
45016	43612	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:21	\N
45017	43613	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:21	\N
45018	43614	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:21	\N
45019	43615	DEPUTE	2007-06-20 00:00:00	\N	2008-11-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:21	\N
45020	43616	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:21	\N
45021	43617	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:21	\N
45022	43618	DEPUTE	1993-04-02 00:00:00	\N	1995-09-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:21	\N
45023	43619	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:21	\N
45024	43620	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:21	\N
45025	43621	DEPUTE	1968-07-11 00:00:00	\N	1972-08-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:21	\N
45026	43622	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:21	\N
45027	43623	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:21	\N
45028	43624	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:21	\N
45029	43625	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:21	\N
45030	43626	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:22	\N
45031	43627	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:22	\N
45032	43628	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:22	\N
45033	43629	DEPUTE	1978-04-03 00:00:00	\N	1978-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:22	\N
45034	43630	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:22	\N
45035	43631	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:22	\N
45036	43632	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:22	\N
45037	43633	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:22	\N
45038	43634	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:22	\N
45039	43635	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:22	\N
45040	43636	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:22	\N
45041	43637	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:22	\N
45042	43638	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:22	\N
45043	43639	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:22	\N
45044	43640	DEPUTE	1956-01-19 00:00:00	\N	1958-06-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:22	2017-08-10 10:56:19
45045	43641	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:22	\N
45046	43642	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:22	\N
45047	43643	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:22	\N
45048	43644	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:22	\N
45049	43645	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:22	\N
45050	43646	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:22	2017-08-10 10:56:19
45051	43647	DEPUTE	1995-12-10 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:22	\N
45052	43648	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:22	\N
45053	43649	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:22	\N
45054	43650	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:22	\N
45055	43651	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:22	\N
45056	43652	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:22	\N
45057	43653	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:22	\N
45058	43654	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:22	\N
45059	43655	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:22	\N
45060	43656	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:22	\N
45061	43657	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:23	\N
45063	43659	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:23	\N
45064	43660	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:23	\N
45065	43661	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:23	2017-08-10 03:42:48
45066	43662	SECAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:23	2017-08-10 10:56:19
45067	43663	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:23	\N
45068	43664	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:23	\N
45069	43665	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:23	\N
45070	43666	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:23	\N
45071	43667	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:23	\N
45073	43669	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:23	\N
46468	45064	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:07	\N
46469	45065	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:07	\N
46470	45066	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:07	\N
46471	45067	DEPUTE	1958-12-09 00:00:00	\N	1961-04-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:07	\N
46472	45068	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:07	\N
46473	45069	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:07	\N
46474	45070	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:07	\N
46475	45071	DEPUTE	1973-04-02 00:00:00	\N	1975-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:07	\N
46476	45072	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:07	\N
46477	45073	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:07	\N
46478	45074	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:07	\N
46479	45075	DEPUTE	1986-04-02 00:00:00	\N	1986-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:07	2017-08-08 03:43:24
46480	45076	DEPUTE	1986-10-01 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:07	2017-08-08 03:43:25
46481	45077	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:07	\N
46482	45078	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:07	\N
46483	45079	DEPUTE	1974-04-29 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:07	\N
46484	45080	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:07	\N
46485	45081	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:07	\N
46486	45082	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:07	\N
46487	45083	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:07	\N
46488	45084	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:07	2017-08-09 03:43:20
46489	45085	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:07	\N
46490	45086	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:07	\N
46491	45087	DEPUTE	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:07	2017-08-09 03:43:20
46492	45088	DEPUTE	1983-12-04 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:07	\N
46493	45089	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:08	\N
46494	45090	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:08	\N
46495	45091	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:08	\N
46496	45092	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:08	\N
46497	45093	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:08	\N
46498	45094	DEPUTE	1999-02-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:08	\N
46499	45095	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:08	\N
52572	52109	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
46500	45096	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:08	\N
46501	45097	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:08	\N
46502	45098	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:08	\N
46504	45100	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:08	\N
46505	45101	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:08	\N
46506	45102	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:08	\N
46507	45103	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:08	\N
46508	45104	DEPUTE	1997-06-01 00:00:00	\N	2001-02-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:08	\N
46509	45105	VICPDTAN	1984-04-01 00:00:00	\N	1985-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:08	2017-08-10 10:56:45
46510	45106	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:08	\N
46511	45107	DEPUTE	1998-11-30 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:08	\N
46512	45108	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:08	2017-08-10 10:56:45
46513	45109	DEPUTE	2012-06-20 00:00:00	\N	2016-07-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:08	\N
46514	45110	DEPUTE	2010-12-14 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:08	2017-08-10 10:56:45
46515	45111	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:08	\N
46516	45112	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:08	\N
46517	45113	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:08	\N
46518	45114	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:08	\N
46519	45115	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:08	\N
46520	45116	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:08	\N
46521	45117	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:08	\N
46522	45118	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:08	2017-08-07 03:43:11
46523	45119	DEPUTE	2014-05-03 00:00:00	\N	2014-10-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:08	2017-08-07 03:43:11
46524	45120	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:08	\N
46525	45121	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:08	\N
46526	45122	DEPUTE	2002-06-19 00:00:00	\N	2002-11-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:08	2017-08-10 10:56:45
46527	45123	DEPUTE	2003-02-03 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:08	2017-08-10 10:56:45
46528	45124	DEPUTE	1981-07-24 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:08	\N
46529	45125	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:08	\N
46530	45126	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:08	\N
46531	45127	DEPUTE	1990-11-03 00:00:00	\N	1991-11-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:08	\N
46532	45128	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:08	\N
46533	45129	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:08	\N
46534	45130	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:08	\N
46535	45131	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:08	\N
46536	45132	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:08	\N
46537	45133	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46538	45134	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46539	45135	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46540	45136	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46541	45137	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46542	45138	DEPUTE	1988-06-06 00:00:00	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46543	45139	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46544	45140	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46545	45141	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46546	45142	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46547	45143	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46548	45144	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46549	45145	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46550	45146	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46551	45147	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46552	45148	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46553	45149	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46554	45150	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46555	45151	DEPUTE	1997-06-01 00:00:00	\N	1999-08-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46556	45152	DEPUTE	2003-03-24 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46557	45153	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46558	45154	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46559	45155	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46560	45156	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
14408	42265	CONSMET	2017-07-11 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-07-11 14:29:48	\N
48049	46645	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:57	\N
48050	46646	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:57	\N
48051	46647	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:57	\N
48052	46648	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:57	\N
48053	46649	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:57	\N
48054	46650	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:57	\N
48055	46651	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:57	\N
48056	46652	DEPUTE	1993-04-02 00:00:00	\N	1994-02-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:57	\N
52573	52110	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
48057	46653	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:57	\N
48058	46654	DEPUTE	1968-07-11 00:00:00	\N	1971-10-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:57	\N
48059	46655	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:57	\N
48060	46656	DEPUTE	1995-08-17 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:57	\N
48061	46657	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:57	\N
48062	46658	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:57	\N
48063	46659	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:57	\N
48064	46660	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:57	\N
48065	46661	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:57	\N
48066	46662	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:57	\N
48067	46663	DEPUTE	1993-04-02 00:00:00	\N	1993-11-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:57	\N
48068	46664	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:57	\N
48069	46665	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:57	\N
48070	46666	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:57	\N
48071	46667	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:57	\N
48072	46668	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:57	\N
48073	46669	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:58	\N
48074	46670	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:58	\N
48075	46671	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:58	\N
48076	46672	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:58	\N
48077	46673	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:58	\N
48078	46674	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:58	\N
48079	46675	DEPUTE	1973-05-06 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:58	\N
48080	46676	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:58	\N
48081	46677	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:58	\N
48082	46678	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:58	\N
48083	46679	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:58	\N
48084	46680	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:58	\N
48085	46681	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:58	\N
48086	46682	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:58	\N
48087	46683	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:58	\N
48088	46684	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:58	\N
48089	46685	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:58	\N
48090	46686	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:58	\N
48091	46687	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:58	\N
48092	46688	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:58	\N
48093	46689	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:58	\N
48094	46690	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:58	\N
48095	46691	DEPUTE	2012-06-20 00:00:00	\N	2012-10-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:58	\N
48096	46692	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:58	\N
48097	46693	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:58	\N
48098	46694	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:58	\N
48099	46695	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:58	\N
48100	46696	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:58	\N
48101	46697	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:58	\N
48102	46698	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:58	\N
48103	46699	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:58	\N
48104	46700	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:58	\N
48105	46701	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:58	\N
48106	46702	DEPUTE	1968-07-11 00:00:00	\N	1969-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:58	\N
48107	46703	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:58	\N
48109	46705	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:58	\N
48110	46706	DEPUTE	1997-06-01 00:00:00	\N	1998-09-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:58	\N
48111	46707	QUESTAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:58	2017-08-10 10:57:13
48112	46708	QUESTAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:58	2017-08-10 03:43:43
48113	46709	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:58	\N
48114	46710	DEPUTE	1968-07-11 00:00:00	\N	1969-07-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:58	\N
48115	46711	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:58	\N
48116	46712	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:58	\N
48117	46713	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:59	\N
48118	46714	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:59	\N
48119	46715	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:59	\N
48120	46716	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:59	\N
48121	46717	DEPUTE	1997-05-25 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:59	\N
48122	46718	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:59	\N
48123	46719	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:59	\N
48124	46720	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:59	\N
48125	46721	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:59	\N
48126	46722	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:59	\N
48127	46723	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:59	\N
48128	46724	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:59	\N
48129	46725	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:59	\N
48130	46726	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:59	\N
48131	46727	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:59	\N
48132	46728	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:59	\N
48133	46729	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:59	\N
48134	46730	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:59	\N
48135	46731	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:59	\N
48136	46732	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:59	\N
48137	46733	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:59	\N
48138	46734	DEPUTE	1988-10-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:59	\N
48139	46735	DEPUTE	1995-05-10 00:00:00	\N	1995-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:59	\N
48140	46736	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:59	\N
49535	48131	DEPUTE	2012-07-22 00:00:00	\N	2014-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:43	\N
49536	48132	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:43	\N
49537	48133	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:43	\N
49538	48134	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:43	\N
49539	48135	DEPUTE	2006-09-02 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:43	\N
49540	48136	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:43	\N
49542	48138	DEPUTE	2012-07-22 00:00:00	\N	2014-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:43	\N
49543	48139	VICPDTAN	2008-10-01 00:00:00	\N	2009-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:43	2017-08-10 10:57:39
49544	48140	SECAN	2009-10-06 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:43	2017-08-10 03:44:09
49545	48141	DEPUTE	2002-06-19 00:00:00	\N	2002-11-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:43	2017-08-10 10:57:39
49546	48142	DEPUTE	2003-02-03 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:43	2017-08-10 10:57:39
49547	48143	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:43	\N
49548	48144	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:43	\N
49549	48145	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:43	\N
49550	48146	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:43	\N
49551	48147	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:43	\N
49553	48149	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:43	2017-08-10 10:57:39
49554	48150	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:43	\N
49555	48151	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:43	\N
49556	48152	DEPUTE	2002-06-25 00:00:00	\N	2002-06-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:43	2017-08-10 10:57:39
49557	48153	VICPDTAN	2006-12-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:43	2017-08-10 10:57:39
49558	48154	VICPDTAN	2010-11-16 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:43	2017-08-10 10:57:39
49559	48155	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:43	\N
49560	48156	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:43	\N
49561	48157	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:43	\N
49562	48158	DEPUTE	2002-06-19 00:00:00	\N	2003-02-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:44	\N
49563	48159	DEPUTE	2003-06-02 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:44	\N
49564	48160	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:44	\N
49565	48161	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:44	\N
49566	48162	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:44	\N
49567	48163	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:44	\N
49568	48164	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:44	\N
49569	48165	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:44	\N
49570	48166	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:44	\N
49571	48167	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:44	\N
49572	48168	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:44	\N
49573	48169	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:44	2017-08-10 03:44:10
49574	48170	DEPUTE	2014-05-03 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:44	2017-08-10 03:44:10
49575	48171	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:44	\N
49576	48172	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:44	\N
49577	48173	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:44	\N
49578	48174	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:44	\N
49579	48175	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:44	\N
49580	48176	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:44	\N
49581	48177	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:44	\N
49583	48179	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:44	\N
49584	48180	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:44	\N
49585	48181	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:44	\N
49586	48182	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:44	\N
49587	48183	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:44	2017-08-10 03:44:10
49588	48184	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:44	2017-08-10 10:57:40
49589	48185	SECAN	2007-06-27 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:44	2017-08-10 03:44:10
49590	48186	SECAN	2012-06-27 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:44	2017-08-10 10:57:40
49591	48187	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:44	2017-08-10 10:57:40
49592	48188	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:44	2017-08-10 03:44:10
49593	48189	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:44	\N
49594	48190	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:44	\N
49595	48191	DEPUTE	2012-06-20 00:00:00	\N	2013-08-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:44	2017-08-10 03:44:11
49596	48192	DEPUTE	2014-05-03 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:44	2017-08-10 03:44:11
49597	48193	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:44	\N
49598	48194	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:44	\N
49599	48195	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:45	\N
49600	48196	DEPUTE	2007-06-20 00:00:00	\N	2007-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:45	\N
49601	48197	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:45	2017-08-10 03:44:11
49602	48198	DEPUTE	2007-06-20 00:00:00	\N	2011-10-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:45	2017-08-10 10:57:40
49603	48199	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:45	\N
49604	48200	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:45	2017-08-09 03:44:26
49605	48201	DEPUTE	2002-06-25 00:00:00	\N	2002-06-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:45	2017-08-10 03:44:11
49606	48202	DEPUTE	2007-06-26 00:00:00	\N	2011-10-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:45	2017-08-10 10:57:40
49607	48203	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:45	\N
49608	48204	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:45	\N
49610	48206	VICPDTAN	2012-06-27 00:00:00	\N	2014-12-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:45	2017-08-10 10:57:40
49611	48207	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:45	\N
49612	48208	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:45	\N
49613	48209	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:45	\N
49614	48210	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:45	\N
49615	48211	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:45	\N
49616	48212	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:45	2017-08-07 03:44:08
49617	48213	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:45	2017-08-10 10:57:40
49618	48214	DEPUTE	2016-03-12 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:45	2017-08-10 10:57:40
49619	48215	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:45	\N
49620	48216	DEPUTE	2007-06-26 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:45	2017-08-07 03:44:08
49621	48217	DEPUTE	2007-06-20 00:00:00	\N	2009-01-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:45	2017-08-09 03:44:26
49622	48218	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:45	2017-08-09 03:44:26
49623	48219	DEPUTE	2012-06-20 00:00:00	\N	2017-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:45	\N
49624	48220	DEPUTE	2017-06-21 00:00:00	\N	2017-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:45	\N
49625	48221	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:45	\N
49626	48222	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:45	\N
49627	48223	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:45	\N
45075	43671	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:23	\N
45076	43672	QUESTAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:23	2017-08-10 10:56:20
45077	43673	QUESTAN	1994-04-02 00:00:00	\N	1995-04-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:23	2017-08-10 10:56:20
45078	43674	QUESTAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:23	2017-08-10 10:56:20
45079	43675	QUESTAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:23	2017-08-10 03:42:48
45080	43676	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:23	\N
45081	43677	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:23	\N
45083	43679	SECAN	2007-06-27 00:00:00	\N	2010-10-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:23	2017-08-10 10:56:20
45084	43680	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:23	\N
45085	43681	DEPUTE	1972-04-14 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:23	\N
45086	43682	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:23	\N
45087	43683	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:23	\N
45088	43684	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:23	\N
45089	43685	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:23	\N
45090	43686	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:23	\N
45091	43687	DEPUTE	1997-06-01 00:00:00	\N	2001-09-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:24	\N
45092	43688	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:24	\N
45093	43689	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:24	\N
45094	43690	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:24	\N
45095	43691	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:24	\N
45096	43692	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:24	\N
45097	43693	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:24	\N
45098	43694	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:24	\N
45099	43695	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:24	\N
45100	43696	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:24	\N
45101	43697	DEPUTE	1988-06-06 00:00:00	\N	1988-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:24	\N
45102	43698	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:24	\N
45103	43699	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:24	\N
45104	43700	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:24	\N
45105	43701	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:24	\N
45106	43702	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:24	\N
45107	43703	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:24	\N
45108	43704	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:24	\N
45109	43705	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:24	\N
45110	43706	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:24	\N
45111	43707	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:24	\N
45112	43708	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:24	\N
45113	43709	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:24	\N
45114	43710	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:24	\N
45115	43711	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:25	\N
45116	43712	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:25	\N
45117	43713	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:25	\N
45118	43714	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:25	\N
45119	43715	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:25	\N
45120	43716	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:25	\N
45121	43717	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:25	\N
45122	43718	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:25	2017-08-10 03:42:49
45123	43719	DEPUTE	2007-06-20 00:00:00	\N	2009-01-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:25	2017-08-10 10:56:21
45124	43720	DEPUTE	2005-10-04 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:25	2017-08-10 03:42:49
45125	43721	DEPUTE	2010-12-14 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:25	2017-08-10 10:56:21
45126	43722	DEPUTE	2012-06-20 00:00:00	\N	2012-10-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:25	2017-08-07 03:42:47
45127	43723	DEPUTE	2012-12-17 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:25	2017-08-07 03:42:47
45128	43724	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:25	\N
45129	43725	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:25	\N
45130	43726	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:25	\N
45131	43727	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:25	\N
45132	43728	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:25	\N
45133	43729	DEPUTE	1998-09-27 00:00:00	1500	2002-06-18 00:00:00	1600	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:25	2023-09-26 15:52:29
45134	43730	DEPUTE	1973-05-13 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:25	\N
45135	43731	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:25	\N
45136	43732	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:25	\N
45137	43733	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:25	\N
45138	43734	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:25	\N
45139	43735	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:25	\N
45140	43736	DEPUTE	1968-07-11 00:00:00	\N	1971-12-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:25	\N
45141	43737	DEPUTE	1986-04-02 00:00:00	\N	1986-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:26	2017-08-04 03:42:51
45142	43738	DEPUTE	1986-09-29 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:26	2017-08-04 03:42:51
45143	43739	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:26	\N
45144	43740	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:26	\N
45145	43741	DEPUTE	1988-07-29 00:00:00	\N	1991-08-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:26	\N
45146	43742	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:26	\N
45147	43743	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:26	\N
45148	43744	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:26	\N
45149	43745	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:26	\N
45150	43746	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:26	\N
45151	43747	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:26	\N
45152	43748	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:26	\N
45153	43749	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:26	\N
45155	43751	SECAN	2012-06-27 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:26	2017-08-10 03:42:50
45156	43752	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:26	2017-08-10 10:56:21
45157	43753	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:26	2017-08-10 10:56:21
45158	43754	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:26	\N
45159	43755	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:26	\N
45160	43756	DEPUTE	1997-06-01 00:00:00	\N	2001-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:26	\N
45161	43757	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:26	\N
45162	43758	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:26	\N
45163	43759	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:26	\N
45164	43760	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:26	\N
45165	43761	DEPUTE	1973-04-02 00:00:00	\N	1977-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:27	\N
45166	43762	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:27	\N
46561	45157	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46562	45158	DEPUTE	1993-04-02 00:00:00	\N	1995-09-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46563	45159	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46564	45160	DEPUTE	1981-07-02 00:00:00	\N	1985-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46565	45161	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46566	45162	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46567	45163	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46568	45164	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46569	45165	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46570	45166	DEPUTE	2002-06-19 00:00:00	\N	2002-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46571	45167	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46572	45168	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46573	45169	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46574	45170	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46575	45171	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46576	45172	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46577	45173	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46578	45174	DEPUTE	1968-07-11 00:00:00	\N	1968-08-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46579	45175	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46580	45176	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46581	45177	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46582	45178	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46583	45179	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46584	45180	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:09	\N
46585	45181	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:10	\N
50822	50116	CONSREG	2015-12-14 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2017-09-19 16:28:42	2017-09-19 16:29:17
46587	45183	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:10	2017-08-10 10:56:46
46588	45184	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:10	\N
46589	45185	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:10	\N
46590	45186	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:10	\N
46591	45187	DEPUTE	1978-05-06 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:10	\N
46592	45188	DEPUTE	1995-12-10 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:10	\N
46593	45189	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:10	\N
46594	45190	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:10	\N
46595	45191	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:10	\N
46596	45192	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:10	\N
46597	45193	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:10	\N
46598	45194	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:10	\N
46599	45195	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:10	\N
46600	45196	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:10	\N
46601	45197	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:10	\N
46602	45198	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:10	\N
46603	45199	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:10	\N
46604	45200	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:10	\N
46606	45202	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:10	\N
46607	45203	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:10	\N
46608	45204	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:10	\N
46609	45205	VICPDTAN	1995-04-03 00:00:00	\N	1996-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:10	2017-08-10 03:43:15
46610	45206	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:10	\N
46611	45207	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:10	\N
46612	45208	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:10	\N
46613	45209	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:10	\N
46614	45210	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:10	\N
46615	45211	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:10	\N
46616	45212	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:10	\N
46617	45213	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:10	\N
46618	45214	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:10	\N
46620	45216	SECAN	1988-06-24 00:00:00	\N	1992-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:10	2017-08-10 10:56:47
46621	45217	DEPUTE	1973-04-02 00:00:00	\N	1976-04-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:10	\N
46622	45218	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:10	\N
46623	45219	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:10	\N
46624	45220	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:11	\N
46625	45221	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:11	\N
46626	45222	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:11	\N
46627	45223	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:11	\N
46628	45224	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:11	\N
46629	45225	DEPUTE	1993-04-02 00:00:00	\N	1995-11-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:11	\N
46630	45226	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:11	\N
46631	45227	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:11	\N
46632	45228	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:11	\N
46633	45229	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:11	\N
46634	45230	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:11	\N
46635	45231	DEPUTE	1996-03-17 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:11	\N
46636	45232	DEPUTE	1997-06-01 00:00:00	\N	1999-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:11	\N
46637	45233	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:11	\N
46639	45235	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:11	\N
46640	45236	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:11	\N
46641	45237	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:11	\N
46642	45238	SECAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:11	2017-08-10 03:43:16
46643	45239	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:11	2017-08-10 10:56:47
46644	45240	QUESTAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:11	2017-08-10 03:43:16
46645	45241	QUESTAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:11	2017-08-10 10:56:47
46646	45242	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:11	\N
46647	45243	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:11	\N
46648	45244	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:11	\N
46649	45245	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:11	\N
46650	45246	DEPUTE	1977-06-30 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:11	\N
46651	45247	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:11	\N
46652	45248	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:11	\N
46653	45249	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:11	\N
48141	46737	DEPUTE	1968-07-11 00:00:00	\N	1971-02-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:59	\N
48142	46738	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:59	\N
48143	46739	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:59	\N
48144	46740	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:59	\N
48145	46741	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:59	\N
48146	46742	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:59	\N
48147	46743	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:59	\N
48148	46744	DEPUTE	1993-05-02 00:00:00	\N	1995-07-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:59	\N
48149	46745	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:59	\N
48150	46746	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:59	\N
48151	46747	DEPUTE	2007-07-20 00:00:00	\N	2011-03-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:59	\N
48152	46748	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:00	\N
48153	46749	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:00	\N
48154	46750	DEPUTE	1986-10-09 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:00	\N
48155	46751	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:00	\N
48156	46752	DEPUTE	2004-05-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:00	\N
48157	46753	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:00	\N
48158	46754	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:00	\N
48159	46755	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:00	\N
48160	46756	DEPUTE	1961-09-26 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:00	\N
48161	46757	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:00	\N
48162	46758	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:00	\N
48163	46759	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:00	\N
48164	46760	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:00	\N
48165	46761	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:00	\N
48166	46762	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:00	\N
48167	46763	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:00	\N
48168	46764	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:00	\N
48169	46765	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:00	\N
48170	46766	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:00	\N
48171	46767	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:00	\N
48172	46768	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:00	\N
48173	46769	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:00	\N
48174	46770	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:00	\N
48175	46771	DEPUTE	1978-05-07 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:00	\N
48176	46772	DEPUTE	1977-05-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:00	\N
48177	46773	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:00	\N
48178	46774	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:00	\N
48179	46775	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:00	\N
48180	46776	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:00	\N
48181	46777	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:00	\N
48183	46779	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:00	\N
48185	46781	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:00	\N
48186	46782	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:00	2017-08-10 10:57:14
48187	46783	SECAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:00	2017-08-10 10:57:14
48188	46784	SECAN	2002-06-26 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:00	2017-08-10 10:57:14
48189	46785	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:01	\N
48190	46786	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:01	\N
48191	46787	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:01	\N
48192	46788	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:01	\N
48193	46789	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:01	\N
48194	46790	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:01	\N
48195	46791	DEPUTE	2001-09-25 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:01	\N
48196	46792	DEPUTE	1973-04-02 00:00:00	\N	1976-11-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:01	\N
48197	46793	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:01	\N
48199	46795	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:01	\N
48200	46796	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:01	\N
48201	46797	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:01	\N
48202	46798	SECAN	2002-06-26 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:01	2017-08-09 03:43:55
48203	46799	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:01	\N
48204	46800	DEPUTE	1981-07-24 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:01	\N
48205	46801	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:01	\N
48206	46802	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:01	\N
48207	46803	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:01	\N
48208	46804	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:01	\N
48209	46805	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:01	\N
48210	46806	DEPUTE	1981-07-02 00:00:00	\N	1983-11-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:01	\N
48211	46807	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:01	\N
48212	46808	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:01	\N
48213	46809	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:01	\N
48214	46810	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:01	\N
48215	46811	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:01	\N
48216	46812	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:01	\N
48217	46813	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:01	\N
48218	46814	DEPUTE	1986-04-02 00:00:00	\N	1986-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:02	\N
48219	46815	DEPUTE	1973-05-06 00:00:00	\N	1974-07-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:02	\N
48220	46816	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:02	\N
48221	46817	DEPUTE	2001-10-04 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:02	\N
48222	46818	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:02	\N
48223	46819	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:02	\N
48224	46820	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:02	\N
48225	46821	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:02	\N
48226	46822	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:02	\N
48227	46823	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:02	\N
48228	46824	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:02	\N
48229	46825	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:02	\N
48230	46826	DEPUTE	1993-04-02 00:00:00	\N	1993-11-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:02	\N
48231	46827	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:02	\N
48232	46828	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:02	\N
48233	46829	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:02	\N
50847	50145	MAIREADJOINT	2008-03-16 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-19 17:29:27	2017-09-19 17:37:47
43679	42275	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:38	\N
43680	42276	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:38	\N
43681	42277	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:38	\N
43682	42278	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:38	\N
43683	42279	DEPUTE	1988-06-13 00:00:00	\N	1989-04-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:38	\N
43684	42280	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:38	\N
43685	42281	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:38	\N
50813	50103	MAIRE	1995-06-18 00:00:00	\N	2017-10-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-19 16:03:36	2017-12-21 14:15:07
43687	42283	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:38	\N
43688	42284	DEPUTE	2002-06-19 00:00:00	\N	2003-06-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:38	\N
43689	42285	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:38	2017-08-09 03:42:18
43690	42286	SECAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:38	2017-08-10 03:42:24
43691	42287	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:39	\N
43692	42288	DEPUTE	1994-12-13 00:00:00	\N	1995-07-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:39	\N
43693	42289	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:39	\N
43694	42290	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:39	\N
43695	42291	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:39	\N
43696	42292	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:39	\N
43697	42293	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:39	\N
43698	42294	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:39	\N
43699	42295	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:39	\N
43700	42296	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:39	\N
43701	42297	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:39	\N
43702	42298	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:39	\N
43703	42299	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:39	\N
43704	42300	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:39	\N
43705	42301	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:39	\N
43706	42302	DEPUTE	1973-04-02 00:00:00	\N	1977-01-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:39	\N
43707	42303	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:39	\N
43708	42304	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:39	\N
43709	42305	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:39	\N
43710	42306	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:39	\N
43711	42307	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:39	\N
43712	42308	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:39	\N
50823	50117	PDTDPT	2014-06-23 00:00:00	\N	2017-10-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-19 16:32:29	2017-11-09 11:39:24
43715	42311	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:39	\N
43716	42312	VICPDTAN	1986-04-04 00:00:00	\N	1988-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:39	2017-08-10 10:55:50
43717	42313	VICPDTAN	1988-06-24 00:00:00	\N	1992-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:39	2017-08-10 10:55:50
43718	42314	DEPUTE	1973-04-02 00:00:00	\N	1973-05-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:39	\N
43719	42315	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:40	\N
43720	42316	DEPUTE	1986-10-24 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:40	\N
43721	42317	DEPUTE	1978-04-02 00:00:00	\N	1980-10-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:40	\N
43722	42318	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:40	\N
43723	42319	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:40	\N
43724	42320	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:40	\N
43725	42321	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:40	\N
43726	42322	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:40	\N
43727	42323	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:40	\N
43728	42324	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:40	\N
43729	42325	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:40	\N
43730	42326	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:40	\N
43731	42327	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:40	\N
43732	42328	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:40	\N
43733	42329	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:40	\N
43734	42330	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:40	\N
43735	42331	DEPUTE	1981-07-02 00:00:00	\N	1983-02-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:40	\N
43736	42332	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:40	\N
43737	42333	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:40	\N
43738	42334	DEPUTE	1973-04-02 00:00:00	\N	1977-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:40	\N
43739	42335	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:40	\N
43741	42337	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:40	\N
43742	42338	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:40	\N
43743	42339	DEPUTE	1997-05-25 00:00:00	\N	2001-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:40	\N
43744	42340	SECAN	1986-04-04 00:00:00	\N	1987-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:40	2017-08-09 03:42:20
43745	42341	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:40	\N
43746	42342	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:40	\N
43747	42343	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:40	\N
43748	42344	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:40	\N
43749	42345	DEPUTE	1998-06-15 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:40	\N
43750	42346	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:40	\N
43751	42347	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:41	\N
43752	42348	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:41	\N
43753	42349	DEPUTE	1983-11-05 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:41	\N
43754	42350	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:41	\N
43755	42351	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:41	\N
43756	42352	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:41	\N
43757	42353	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:41	\N
43758	42354	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:41	\N
43759	42355	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:41	\N
43760	42356	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:41	\N
43761	42357	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:41	\N
43762	42358	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:41	\N
43763	42359	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:41	\N
43764	42360	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:41	\N
43765	42361	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:41	\N
43766	42362	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:41	\N
43767	42363	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:41	\N
43768	42364	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:41	\N
43769	42365	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:41	\N
43770	42366	DEPUTE	1981-07-02 00:00:00	\N	1984-08-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:41	\N
43771	42367	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:41	\N
45167	43763	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:27	\N
45168	43764	DEPUTE	1982-01-17 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:27	\N
45169	43765	DEPUTE	1978-04-03 00:00:00	\N	1978-05-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:27	\N
45170	43766	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:27	\N
45171	43767	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:27	\N
45172	43768	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:27	\N
45173	43769	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:27	\N
45174	43770	DEPUTE	1999-03-30 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:27	\N
45175	43771	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:27	\N
45176	43772	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:27	\N
45177	43773	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:27	\N
45178	43774	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:27	\N
45179	43775	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:27	\N
45181	43777	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:27	\N
45182	43778	SECAN	1997-06-13 00:00:00	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:27	2017-08-10 10:56:22
45183	43779	DEPUTE	1993-04-02 00:00:00	\N	1996-02-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:27	\N
45184	43780	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:27	\N
45185	43781	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:27	\N
45186	43782	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:27	\N
45187	43783	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:27	\N
45188	43784	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:27	\N
45189	43785	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:27	\N
45190	43786	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:27	\N
45192	43788	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:28	\N
45193	43789	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:28	\N
45194	43790	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:28	2017-08-10 10:56:22
45195	43791	DEPUTE	2010-12-14 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:28	2017-08-10 10:56:22
45196	43792	DEPUTE	2012-06-20 00:00:00	\N	2014-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:28	\N
45197	43793	SECAN	1995-04-03 00:00:00	\N	1996-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:28	2017-08-08 03:42:56
45198	43794	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:28	\N
45199	43795	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:28	\N
45200	43796	DEPUTE	1993-04-02 00:00:00	\N	1995-12-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:28	2017-08-10 10:56:22
45201	43797	DEPUTE	1996-02-26 00:00:00	\N	1996-03-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:28	2017-08-10 10:56:22
45202	43798	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:28	\N
45203	43799	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:28	\N
45204	43800	DEPUTE	1968-07-11 00:00:00	\N	1971-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:28	\N
45205	43801	DEPUTE	2011-07-30 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:28	\N
45206	43802	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:28	\N
45207	43803	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:28	\N
45208	43804	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:28	2017-08-10 10:56:23
45209	43805	DEPUTE	1995-09-25 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:28	2017-08-10 10:56:23
45210	43806	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:28	\N
45211	43807	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:28	\N
45212	43808	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:28	\N
45213	43809	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:28	\N
45214	43810	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:28	\N
45215	43811	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:28	\N
45216	43812	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:28	\N
45217	43813	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:28	\N
45218	43814	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:28	\N
45219	43815	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:28	\N
45220	43816	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:28	\N
45221	43817	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:28	2017-08-10 03:42:52
45222	43818	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:28	\N
45223	43819	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:28	2017-08-08 03:42:57
45224	43820	DEPUTE	1988-06-06 00:00:00	\N	1993-02-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:29	\N
45225	43821	SECAN	1985-04-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:29	2017-08-10 03:42:52
45226	43822	SECAN	1986-04-04 00:00:00	\N	1987-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:29	2017-08-08 03:42:57
45227	43823	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:29	\N
45228	43824	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:29	\N
45229	43825	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:29	\N
45230	43826	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:29	\N
45231	43827	DEPUTE	1993-05-03 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:29	\N
45232	43828	DEPUTE	1997-06-01 00:00:00	\N	2001-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:29	\N
45233	43829	DEPUTE	1973-04-02 00:00:00	\N	1976-09-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:29	\N
45234	43830	DEPUTE	1978-04-02 00:00:00	\N	1978-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:29	\N
45235	43831	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:29	\N
45236	43832	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:29	\N
45237	43833	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:29	\N
45238	43834	DEPUTE	1991-06-18 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:29	\N
45239	43835	DEPUTE	1982-01-18 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:29	\N
45241	43837	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:29	\N
45242	43838	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:29	\N
45243	43839	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:29	\N
45244	43840	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:29	\N
45245	43841	DEPUTE	2009-07-23 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:29	\N
45246	43842	SECAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:29	2017-08-10 10:56:23
45247	43843	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:29	\N
45248	43844	DEPUTE	2001-04-28 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:29	\N
45249	43845	DEPUTE	1982-06-15 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:29	\N
45250	43846	DEPUTE	1990-11-03 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:29	\N
45251	43847	DEPUTE	1968-07-11 00:00:00	\N	1970-05-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:29	\N
45252	43848	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:29	\N
45253	43849	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:29	\N
45254	43850	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:29	\N
45255	43851	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:29	\N
45256	43852	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:29	\N
45257	43853	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:29	\N
45258	43854	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:29	\N
45259	43855	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:29	\N
46654	45250	DEPUTE	1968-08-13 00:00:00	\N	1969-09-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:11	\N
46655	45251	DEPUTE	1973-05-03 00:00:00	\N	1974-07-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:11	\N
46656	45252	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:11	\N
46657	45253	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:11	\N
46658	45254	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:11	\N
46659	45255	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:11	\N
46660	45256	DEPUTE	1973-04-03 00:00:00	\N	1974-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:11	\N
46661	45257	DEPUTE	1986-04-02 00:00:00	\N	1986-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:12	\N
46662	45258	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:12	\N
46663	45259	DEPUTE	1999-08-29 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:12	\N
46664	45260	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:12	\N
46665	45261	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:12	\N
46666	45262	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:12	\N
46667	45263	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:12	\N
46668	45264	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:12	\N
46669	45265	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:12	\N
46670	45266	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:12	\N
46671	45267	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:12	\N
46672	45268	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:12	\N
46673	45269	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:12	\N
46674	45270	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:12	\N
46675	45271	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:12	\N
46676	45272	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:12	\N
46677	45273	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:12	\N
46678	45274	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:12	\N
46679	45275	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:12	\N
46680	45276	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:12	\N
46681	45277	DEPUTE	1986-04-02 00:00:00	\N	1986-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:12	2017-08-10 03:43:17
46682	45278	DEPUTE	1986-10-01 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:12	2017-08-10 03:43:17
46683	45279	DEPUTE	1988-06-06 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:12	\N
46684	45280	DEPUTE	1997-06-01 00:00:00	\N	1997-07-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:12	\N
46685	45281	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:13	\N
46686	45282	DEPUTE	1981-07-02 00:00:00	\N	1985-12-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:13	\N
46687	45283	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:13	\N
46688	45284	DEPUTE	1988-06-06 00:00:00	\N	1992-05-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:13	\N
46689	45285	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:13	\N
46690	45286	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:13	\N
46691	45287	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:13	\N
46692	45288	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:13	\N
46693	45289	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:13	\N
46694	45290	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:13	\N
46695	45291	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:13	\N
46696	45292	DEPUTE	1981-07-02 00:00:00	\N	1984-08-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:13	\N
46697	45293	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:13	\N
46698	45294	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:13	\N
46699	45295	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:13	\N
46700	45296	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:13	\N
46701	45297	DEPUTE	2007-06-20 00:00:00	\N	2008-04-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:13	2017-08-10 10:56:48
46702	45298	DEPUTE	2010-08-05 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:13	2017-08-10 10:56:48
46703	45299	DEPUTE	1967-04-02 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:13	\N
46704	45300	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:13	\N
46705	45301	DEPUTE	1973-04-03 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:13	\N
46706	45302	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:13	\N
46707	45303	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:13	\N
46708	45304	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:13	\N
46709	45305	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:13	\N
46710	45306	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:13	\N
46711	45307	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:13	\N
46712	45308	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:13	\N
46713	45309	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:13	\N
46714	45310	DEPUTE	1981-07-02 00:00:00	\N	1986-03-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:14	\N
46715	45311	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:14	\N
46716	45312	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:14	\N
46717	45313	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:14	\N
46718	45314	DEPUTE	2012-06-20 00:00:00	\N	2016-03-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:14	\N
46719	45315	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:14	\N
46720	45316	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:14	\N
46721	45317	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:14	\N
46722	45318	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:14	\N
46723	45319	DEPUTE	2002-06-19 00:00:00	\N	2004-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:14	\N
46724	45320	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:14	\N
46725	45321	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:14	\N
46726	45322	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:14	\N
46727	45323	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:14	\N
46728	45324	DEPUTE	1961-06-11 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:14	\N
46729	45325	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:14	\N
46730	45326	DEPUTE	1967-04-02 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:14	\N
46731	45327	DEPUTE	1968-07-11 00:00:00	\N	1969-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:14	\N
46732	45328	DEPUTE	1973-04-03 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:14	\N
46733	45329	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:14	\N
46734	45330	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:14	\N
46735	45331	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:14	\N
46736	45332	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:14	\N
46737	45333	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:14	\N
46738	45334	DEPUTE	1978-05-06 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:14	\N
46739	45335	DEPUTE	1983-12-19 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:14	\N
46740	45336	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:14	\N
46741	45337	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:14	\N
46742	45338	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:15	\N
46743	45339	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:15	\N
46744	45340	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:15	\N
46745	45341	DEPUTE	1998-05-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:15	\N
46746	45342	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:15	\N
48234	46830	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:02	\N
48235	46831	DEPUTE	1984-09-10 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:02	\N
48236	46832	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:02	\N
48237	46833	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:03	\N
48238	46834	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:03	\N
48239	46835	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:03	\N
48240	46836	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:03	\N
48241	46837	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:03	\N
48242	46838	DEPUTE	2007-06-20 00:00:00	\N	2011-12-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:03	\N
48243	46839	DEPUTE	2000-11-19 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:03	\N
48244	46840	DEPUTE	1991-06-18 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:03	\N
50876	50176	CONSMUNI	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 10:14:59	2017-09-20 10:15:17
50877	50177	MAIREADJOINT	2014-03-30 00:00:00	\N	2017-12-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-20 10:41:46	2018-05-30 10:16:49
48247	46843	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:03	\N
48248	46844	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:03	\N
50881	50181	CONSDPT	2015-03-29 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 10:53:03	2017-09-20 10:54:16
48250	46846	SECAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:03	2017-08-09 03:43:57
48251	46847	VICPDTAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:03	2017-08-10 10:57:15
48252	46848	VICPDTAN	1994-04-02 00:00:00	\N	1995-06-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:03	2017-08-10 10:57:15
48253	46849	VICPDTAN	1997-06-13 00:00:00	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:03	2017-08-10 03:43:45
48254	46850	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:03	\N
48255	46851	DEPUTE	1998-11-21 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:03	\N
48256	46852	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:03	\N
48257	46853	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:03	\N
48258	46854	DEPUTE	1969-10-26 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:03	\N
48259	46855	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:03	\N
48260	46856	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:03	\N
48261	46857	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:03	\N
48262	46858	DEPUTE	1988-06-13 00:00:00	\N	1988-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:03	\N
48263	46859	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:03	\N
48264	46860	DEPUTE	1962-12-06 00:00:00	\N	1963-03-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:03	2017-08-10 03:43:46
48265	46861	DEPUTE	1963-05-12 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:03	2017-08-10 03:43:46
48266	46862	DEPUTE	1967-04-03 00:00:00	\N	1967-07-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:03	2017-08-10 03:43:46
48267	46863	DEPUTE	1967-08-27 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:03	2017-08-10 03:43:46
48268	46864	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:04	\N
48269	46865	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:04	\N
48270	46866	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:04	\N
48271	46867	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:04	\N
48272	46868	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:04	\N
48273	46869	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:04	\N
48274	46870	DEPUTE	1997-06-01 00:00:00	\N	1998-04-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:04	\N
48275	46871	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:04	\N
48276	46872	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:04	\N
48279	46875	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:04	\N
48281	46877	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:04	2017-08-09 03:43:57
48282	46878	SECAN	2002-06-26 00:00:00	\N	2006-11-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:04	2017-08-09 03:43:57
48283	46879	SECAN	2013-10-01 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:04	2017-08-09 03:43:57
48284	46880	DEPUTE	1984-04-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:04	\N
48285	46881	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:04	\N
48286	46882	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:04	\N
48287	46883	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:04	\N
48288	46884	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:04	\N
48289	46885	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:04	\N
48290	46886	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:04	\N
48291	46887	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:04	\N
48292	46888	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:04	\N
48293	46889	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:04	\N
48294	46890	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:04	\N
48295	46891	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:04	\N
48296	46892	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:04	\N
48297	46893	DEPUTE	1981-07-24 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:04	\N
48298	46894	DEPUTE	1986-04-02 00:00:00	\N	1986-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:04	2017-08-07 03:43:42
48299	46895	DEPUTE	1986-10-01 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:04	2017-08-07 03:43:42
48300	46896	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:04	\N
48301	46897	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:05	\N
48302	46898	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:05	\N
48303	46899	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:05	\N
48304	46900	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:05	\N
48305	46901	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:05	\N
48306	46902	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:05	\N
48307	46903	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:05	\N
48308	46904	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:05	\N
48309	46905	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:05	\N
48310	46906	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:05	\N
48312	46908	QUESTAN	2012-06-27 00:00:00	\N	2016-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:05	2017-08-08 03:44:05
48313	46909	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:05	\N
48314	46910	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:05	\N
48315	46911	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:05	\N
48316	46912	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:05	\N
48317	46913	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:05	\N
48318	46914	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:06	\N
48319	46915	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:06	\N
48320	46916	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:06	\N
48321	46917	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:06	\N
48322	46918	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:06	\N
48323	46919	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:06	\N
48324	46920	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:06	\N
48325	46921	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:06	\N
48326	46922	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:06	\N
43772	42368	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:41	\N
43773	42369	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:41	\N
43774	42370	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:41	\N
43775	42371	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:41	\N
43776	42372	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:41	\N
43777	42373	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:41	\N
43778	42374	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:41	\N
43779	42375	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:41	\N
43780	42376	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:41	\N
43781	42377	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:41	\N
43782	42378	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:41	\N
43783	42379	DEPUTE	1991-06-18 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:41	\N
43784	42380	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:41	\N
43785	42381	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:41	\N
43786	42382	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:41	\N
43787	42383	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:42	\N
43788	42384	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:42	\N
43789	42385	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:42	\N
43790	42386	DEPUTE	1995-06-19 00:00:00	\N	1995-11-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:42	\N
43791	42387	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:42	\N
43792	42388	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:42	\N
43793	42389	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:42	\N
43794	42390	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:42	\N
43796	42392	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:42	\N
43797	42393	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:42	2017-08-10 03:42:26
43798	42394	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:42	\N
43799	42395	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:42	\N
43800	42396	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:42	\N
43801	42397	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:42	\N
43802	42398	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:42	\N
43803	42399	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:42	\N
43804	42400	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:42	\N
43805	42401	DEPUTE	2017-06-21 00:00:00	\N	2017-08-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:42	2017-08-25 03:42:25
43806	42402	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:42	\N
43807	42403	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:42	\N
43808	42404	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:42	\N
43809	42405	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:42	\N
43810	42406	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:42	\N
43811	42407	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:42	\N
43812	42408	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:42	\N
43813	42409	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:43	\N
43815	42411	QUESTAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:43	2017-08-10 10:55:53
43816	42412	DEPUTE	1978-04-02 00:00:00	\N	1978-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:43	\N
43817	42413	DEPUTE	1981-07-02 00:00:00	\N	1983-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:43	\N
43818	42414	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:43	\N
43819	42415	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:43	\N
43820	42416	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:43	\N
43821	42417	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:43	\N
43822	42418	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:43	\N
43823	42419	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:43	\N
43825	42421	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:43	\N
43826	42422	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:43	\N
43827	42423	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:43	\N
43828	42424	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:43	\N
43829	42425	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:43	\N
43830	42426	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:43	\N
43831	42427	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:43	\N
43832	42428	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:43	\N
43833	42429	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:43	\N
43834	42430	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:43	\N
43835	42431	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:43	\N
43836	42432	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:43	\N
43837	42433	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:43	\N
43838	42434	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:44	\N
43839	42435	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:44	2017-08-10 10:55:54
43840	42436	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:44	\N
43841	42437	PDTAN	2007-06-26 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:44	2017-08-10 10:55:54
43842	42438	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:44	\N
43843	42439	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:44	\N
43844	42440	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:44	\N
43845	42441	DEPUTE	1973-04-02 00:00:00	\N	1973-05-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:44	\N
43846	42442	DEPUTE	1986-04-02 00:00:00	\N	1986-04-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:44	\N
43847	42443	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:44	\N
43848	42444	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:44	\N
43849	42445	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:44	\N
43850	42446	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:44	\N
43851	42447	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:44	\N
43852	42448	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:44	\N
43853	42449	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:44	\N
43854	42450	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:44	\N
43855	42451	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:44	\N
43856	42452	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:44	\N
43857	42453	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:44	2017-08-10 03:42:27
43858	42454	DEPUTE	1999-10-01 00:00:00	\N	2000-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:44	2017-08-10 03:42:27
43859	42455	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:44	\N
43860	42456	DEPUTE	2002-06-19 00:00:00	\N	2004-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:44	\N
43861	42457	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:44	\N
43862	42458	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:44	\N
43863	42459	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:44	\N
43864	42460	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:44	\N
45260	43856	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:29	\N
45261	43857	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:29	\N
45262	43858	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:29	\N
45264	43860	VICPDTAN	2009-10-06 00:00:00	\N	2010-10-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:29	2017-08-10 10:56:23
45265	43861	SECAN	2008-10-01 00:00:00	\N	2009-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:29	2017-08-10 10:56:23
45266	43862	SECAN	2010-10-05 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:29	2017-08-10 10:56:23
45267	43863	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:29	\N
45268	43864	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:29	\N
45269	43865	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:29	\N
45270	43866	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:29	\N
45271	43867	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:29	\N
45272	43868	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	\N
45273	43869	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	\N
45274	43870	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	\N
45275	43871	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	\N
45276	43872	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	2017-08-10 03:42:52
45277	43873	DEPUTE	2009-07-24 00:00:00	\N	2009-07-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	2017-08-10 03:42:52
45278	43874	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	\N
45279	43875	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	\N
45282	43878	SECAN	2005-10-04 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	2017-08-10 10:56:23
45283	43879	SECAN	2007-06-27 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	2017-08-10 10:56:23
45284	43880	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	\N
45285	43881	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	\N
45286	43882	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	\N
45287	43883	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	\N
45288	43884	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	2017-08-10 10:56:24
45289	43885	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	2017-08-10 10:56:24
45290	43886	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	\N
45291	43887	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	\N
45292	43888	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	2017-08-10 03:42:52
45293	43889	VICPDTAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	2017-08-10 10:56:24
45294	43890	VICPDTAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	2017-08-10 10:56:24
45295	43891	VICPDTAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	2017-08-10 10:56:24
45296	43892	DEPUTE	2007-06-26 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	2017-08-10 03:42:52
45297	43893	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	\N
45298	43894	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	\N
45299	43895	DEPUTE	1986-04-02 00:00:00	\N	1986-09-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	\N
45300	43896	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	\N
45301	43897	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	\N
45302	43898	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	\N
45303	43899	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	\N
45304	43900	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	\N
45305	43901	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	\N
45306	43902	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	\N
45307	43903	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	\N
45308	43904	DEPUTE	1978-04-03 00:00:00	\N	1981-04-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	\N
45309	43905	DEPUTE	1977-01-11 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	\N
45310	43906	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	\N
45311	43907	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	\N
45312	43908	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	\N
45313	43909	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	\N
45314	43910	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	\N
45315	43911	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	\N
45317	43913	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	\N
45318	43914	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	\N
45319	43915	QUESTAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	2017-08-10 10:56:24
45320	43916	QUESTAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	2017-08-10 10:56:24
45321	43917	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	\N
45322	43918	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:30	\N
45323	43919	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:31	\N
45324	43920	DEPUTE	2002-06-19 00:00:00	\N	2003-02-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:31	2017-08-10 10:56:24
45325	43921	DEPUTE	2003-03-24 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:31	2017-08-10 10:56:24
45326	43922	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:31	\N
45327	43923	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:31	\N
45328	43924	DEPUTE	1988-06-13 00:00:00	\N	1991-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:31	\N
45329	43925	DEPUTE	1995-12-10 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:31	\N
45330	43926	DEPUTE	1997-06-01 00:00:00	\N	2000-09-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:31	\N
45331	43927	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:31	\N
45332	43928	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:31	\N
45333	43929	DEPUTE	2012-07-22 00:00:00	\N	2014-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:31	\N
45334	43930	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:31	\N
45335	43931	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:31	\N
45336	43932	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:31	\N
45337	43933	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:31	\N
45338	43934	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:31	\N
45339	43935	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:31	\N
45340	43936	DEPUTE	1973-04-03 00:00:00	\N	1973-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:31	2017-08-10 03:42:53
45341	43937	DEPUTE	1974-10-06 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:31	2017-08-10 03:42:53
45342	43938	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:31	\N
45343	43939	DEPUTE	1967-04-02 00:00:00	\N	1967-05-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:31	\N
45344	43940	DEPUTE	1968-07-11 00:00:00	\N	1968-08-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:31	\N
45345	43941	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:31	\N
45346	43942	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:31	\N
45347	43943	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:31	\N
45348	43944	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:31	\N
45349	43945	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:31	\N
45350	43946	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:31	\N
45351	43947	DEPUTE	1974-09-29 00:00:00	\N	1976-09-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:31	2017-08-09 03:42:55
45352	43948	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:31	\N
46747	45343	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:15	\N
50825	50119	VICPDTDPT	2015-03-30 00:00:00	\N	2017-10-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-09-19 16:35:25	2018-03-29 00:01:23
46749	45345	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:15	\N
46750	45346	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:15	\N
46751	45347	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:15	\N
46752	45348	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:15	2017-08-03 03:43:22
46753	45349	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:15	\N
46754	45350	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:15	\N
46755	45351	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:15	\N
46756	45352	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:15	\N
46757	45353	DEPUTE	1978-04-02 00:00:00	\N	1980-10-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:15	\N
46758	45354	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:15	\N
46759	45355	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:15	\N
46760	45356	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:15	\N
46761	45357	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:15	\N
46762	45358	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:15	\N
46763	45359	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:15	\N
46764	45360	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:15	\N
46765	45361	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:15	\N
46766	45362	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:15	\N
46767	45363	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:16	\N
46768	45364	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:16	\N
46769	45365	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:16	\N
46770	45366	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:16	\N
46771	45367	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:16	\N
50826	50120	MAIRE	1999-12-15 00:00:00	\N	2015-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-09-19 16:35:58	2017-09-26 16:38:50
46773	45369	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:16	\N
50827	50121	MAIREADJOINT	2001-03-18 00:00:00	\N	2017-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-19 16:42:15	2018-06-06 10:15:15
46776	45372	QUESTAN	1995-04-03 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:16	2017-08-10 03:43:18
46777	45373	SECAN	2002-06-26 00:00:00	\N	2004-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:16	2017-08-10 03:43:18
46778	45374	SECAN	2008-10-01 00:00:00	\N	2009-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:16	2017-08-10 10:56:50
46779	45375	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:16	\N
46780	45376	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:16	\N
46781	45377	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:16	\N
46782	45378	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:16	\N
46783	45379	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:16	\N
46784	45380	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:16	\N
46785	45381	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:16	\N
46786	45382	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:16	\N
46787	45383	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:16	\N
46788	45384	DEPUTE	1997-06-01 00:00:00	\N	2001-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:16	\N
46789	45385	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:16	\N
46790	45386	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:16	\N
46791	45387	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:17	\N
46792	45388	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:17	\N
46793	45389	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:17	\N
46794	45390	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:17	\N
46795	45391	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:17	\N
46796	45392	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:17	\N
46797	45393	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:17	\N
46798	45394	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:17	\N
46799	45395	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:17	\N
46802	45398	VICPDTAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:17	2017-08-10 10:56:50
46803	45399	VICPDTAN	1988-06-24 00:00:00	\N	1992-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:17	2017-08-10 03:43:19
46804	45400	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:17	\N
46805	45401	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:17	\N
46806	45402	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:17	\N
46807	45403	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:17	\N
46808	45404	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:17	\N
46809	45405	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:17	\N
46810	45406	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:17	\N
46811	45407	DEPUTE	1988-06-13 00:00:00	\N	1992-04-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:17	\N
46812	45408	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	\N
46813	45409	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	\N
46814	45410	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	\N
46815	45411	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	\N
46816	45412	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	\N
46817	45413	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	\N
46818	45414	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	\N
46819	45415	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	2017-08-10 10:56:51
46820	45416	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	2017-08-09 03:43:26
46821	45417	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	\N
46822	45418	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	\N
46824	45420	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	2017-08-09 03:43:26
46825	45421	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	\N
46826	45422	SECAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	2017-08-10 10:56:51
46827	45423	SECAN	1995-05-31 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	2017-08-09 03:43:26
46828	45424	VICPDTAN	2007-06-27 00:00:00	\N	2011-07-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	2017-08-10 10:56:51
46829	45425	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	\N
46830	45426	DEPUTE	1981-07-02 00:00:00	\N	1982-07-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	2017-08-06 03:43:28
46831	45427	DEPUTE	1982-09-05 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	2017-08-06 03:43:28
46832	45428	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	\N
46833	45429	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	\N
46834	45430	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	\N
46835	45431	DEPUTE	1997-05-25 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	\N
46836	45432	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	\N
46837	45433	DEPUTE	1976-02-13 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	\N
46838	45434	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	\N
46839	45435	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	\N
50885	50186	MAIRE	2008-03-16 00:00:00	\N	2018-04-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-20 10:57:12	2018-05-15 14:50:25
48328	46924	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:06	\N
48329	46925	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:06	\N
48330	46926	SECAN	2002-10-02 00:00:00	\N	2004-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:06	2017-08-10 10:57:17
48331	46927	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:06	\N
48332	46928	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:06	\N
48333	46929	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:06	\N
48334	46930	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:06	\N
48335	46931	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:06	\N
48336	46932	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:06	\N
48337	46933	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:06	\N
48338	46934	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:06	\N
48339	46935	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:06	\N
48340	46936	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:06	\N
48341	46937	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:06	\N
48342	46938	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:06	\N
48343	46939	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:06	\N
48344	46940	DEPUTE	1997-06-01 00:00:00	\N	1999-03-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:06	\N
48345	46941	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:06	\N
48346	46942	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:06	\N
48347	46943	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:06	\N
48348	46944	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:06	\N
48349	46945	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:06	\N
48350	46946	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:06	\N
48351	46947	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:06	\N
48352	46948	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	\N
48353	46949	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	\N
48354	46950	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	\N
48355	46951	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	\N
48356	46952	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	\N
48357	46953	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	\N
48358	46954	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	\N
48360	46956	SECAN	2008-10-01 00:00:00	\N	2009-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	2017-08-10 10:57:17
48361	46957	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	\N
48362	46958	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	\N
48363	46959	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	\N
48364	46960	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	\N
48365	46961	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	\N
48366	46962	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	\N
48367	46963	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	\N
48368	46964	DEPUTE	1993-04-02 00:00:00	\N	1996-11-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	\N
48369	46965	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	\N
48370	46966	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	\N
48371	46967	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	\N
48373	46969	VICPDTAN	2008-10-01 00:00:00	\N	2009-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	2017-08-10 10:57:17
48374	46970	SECAN	2007-06-27 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	2017-08-10 03:43:47
48375	46971	SECAN	2009-10-06 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	2017-08-10 10:57:17
48376	46972	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	\N
48377	46973	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	\N
48378	46974	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	\N
48379	46975	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	\N
48380	46976	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	\N
48381	46977	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	\N
48382	46978	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	\N
48383	46979	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	\N
48384	46980	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	\N
48386	46982	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	\N
48387	46983	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	\N
48388	46984	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	\N
48389	46985	SECAN	2002-06-26 00:00:00	\N	2003-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	2017-08-10 03:43:48
48390	46986	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	\N
48391	46987	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	\N
48392	46988	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	\N
48393	46989	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	\N
48394	46990	DEPUTE	1991-02-05 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	2017-08-10 03:43:48
48395	46991	DEPUTE	1993-04-02 00:00:00	\N	1997-02-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	\N
48396	46992	DEPUTE	1988-06-13 00:00:00	\N	1990-12-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	2017-08-10 03:43:48
48397	46993	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	\N
48398	46994	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	\N
48399	46995	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	\N
48400	46996	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	\N
48401	46997	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	\N
48402	46998	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	\N
48403	46999	DEPUTE	1986-04-02 00:00:00	\N	1987-05-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	\N
48404	47000	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	\N
48405	47001	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	2017-08-10 03:43:48
48406	47002	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	\N
48407	47003	DEPUTE	2010-12-14 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	2017-08-10 03:43:48
48408	47004	DEPUTE	1981-07-02 00:00:00	\N	1982-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	\N
48409	47005	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:07	\N
48410	47006	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:08	\N
48411	47007	DEPUTE	1998-11-30 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:08	\N
48412	47008	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:08	\N
48413	47009	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:08	\N
48414	47010	DEPUTE	1962-12-06 00:00:00	\N	1966-02-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:08	\N
48415	47011	DEPUTE	1967-04-03 00:00:00	\N	1967-05-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:08	\N
48416	47012	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:08	\N
48417	47013	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:08	\N
48418	47014	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:08	\N
48419	47015	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:08	\N
43865	42461	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:44	\N
43866	42462	DEPUTE	1991-06-18 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:45	\N
43867	42463	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:45	\N
43868	42464	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:45	\N
43869	42465	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:45	\N
43870	42466	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:45	\N
43871	42467	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:45	\N
43872	42468	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:45	\N
43873	42469	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:45	2017-08-06 03:42:25
43874	42470	DEPUTE	1995-09-17 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:45	2017-08-06 03:42:25
43875	42471	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:45	\N
43876	42472	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:45	\N
43877	42473	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:45	2017-08-10 10:55:55
43878	42474	DEPUTE	2011-03-28 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:45	2017-08-10 10:55:55
43879	42475	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:45	\N
43880	42476	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:45	\N
43881	42477	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:45	\N
43882	42478	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:45	\N
43883	42479	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:45	\N
43884	42480	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:45	\N
43885	42481	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:45	\N
43886	42482	DEPUTE	1985-05-23 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:45	\N
43887	42483	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:45	\N
43888	42484	DEPUTE	1991-03-09 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:45	\N
43889	42485	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:45	2017-08-10 03:42:28
43890	42486	DEPUTE	1995-12-17 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:45	2017-08-10 03:42:28
43891	42487	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:45	\N
43892	42488	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:46	\N
43893	42489	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:46	\N
43894	42490	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:46	\N
43895	42491	DEPUTE	2004-05-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:46	\N
43896	42492	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:46	\N
43897	42493	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:46	\N
43898	42494	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:46	\N
43899	42495	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:46	\N
43900	42496	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:46	\N
43901	42497	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:46	\N
43902	42498	DEPUTE	1983-02-08 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:46	\N
43903	42499	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:46	\N
43904	42500	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:46	\N
43908	42504	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:46	2017-08-10 10:55:56
43909	42505	SECAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:46	2017-08-10 10:55:56
43910	42506	SECAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:46	2017-08-10 03:42:29
43911	42507	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:46	2017-08-10 10:55:56
43912	42508	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:46	2017-08-10 10:55:56
43913	42509	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:46	2017-08-10 10:55:56
43914	42510	SECAN	2004-05-24 00:00:00	\N	2005-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:46	2017-08-04 03:42:23
43915	42511	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:46	\N
43916	42512	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:46	\N
43917	42513	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:46	\N
43918	42514	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:46	\N
43919	42515	DEPUTE	2012-06-20 00:00:00	\N	2016-12-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:46	\N
43920	42516	DEPUTE	1995-01-22 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:47	\N
43921	42517	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:47	\N
43922	42518	DEPUTE	1991-06-17 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:47	\N
43923	42519	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:47	\N
43924	42520	DEPUTE	1997-06-01 00:00:00	\N	2001-11-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:47	\N
43925	42521	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:47	\N
43926	42522	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:47	\N
43927	42523	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:47	\N
43928	42524	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:47	\N
43929	42525	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:47	\N
43930	42526	DEPUTE	1988-06-13 00:00:00	\N	1990-09-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:47	\N
43931	42527	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:47	\N
43932	42528	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:47	\N
43933	42529	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:47	\N
43934	42530	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:47	\N
43935	42531	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:47	\N
43936	42532	DEPUTE	1973-04-02 00:00:00	\N	1974-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:47	\N
43937	42533	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:47	\N
43938	42534	DEPUTE	1986-04-02 00:00:00	\N	1987-05-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:47	\N
43939	42535	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:47	\N
43940	42536	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:47	\N
43941	42537	DEPUTE	2001-08-11 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:47	\N
43942	42538	DEPUTE	1992-06-23 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:48	\N
43943	42539	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:48	\N
43944	42540	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:48	\N
43945	42541	DEPUTE	1986-04-02 00:00:00	\N	1986-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:48	\N
43946	42542	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:48	\N
43947	42543	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:48	\N
43948	42544	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:48	\N
43949	42545	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:48	\N
43950	42546	DEPUTE	1981-01-27 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:48	\N
43951	42547	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:48	\N
43952	42548	DEPUTE	1988-06-13 00:00:00	\N	1988-11-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:48	2017-08-04 03:42:25
43953	42549	DEPUTE	1989-02-01 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:48	2017-08-04 03:42:25
43954	42550	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:48	\N
43955	42551	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:48	\N
43956	42552	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:48	\N
43957	42553	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:48	\N
45353	43949	DEPUTE	1967-04-03 00:00:00	\N	1967-05-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:31	\N
45354	43950	DEPUTE	1968-07-11 00:00:00	\N	1968-08-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:31	\N
45355	43951	DEPUTE	1973-04-02 00:00:00	\N	1973-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:31	2017-08-09 03:42:55
45356	43952	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:31	\N
45357	43953	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:31	\N
45358	43954	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:31	\N
45359	43955	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:31	\N
45360	43956	DEPUTE	1986-09-20 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:31	\N
45361	43957	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:31	\N
45362	43958	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:31	\N
45363	43959	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:31	\N
45364	43960	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:32	\N
45365	43961	DEPUTE	1981-07-02 00:00:00	\N	1983-07-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:32	\N
45366	43962	DEPUTE	1988-07-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:32	\N
45367	43963	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:32	\N
45368	43964	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:32	\N
45370	43966	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:32	\N
45371	43967	VICPDTAN	2010-10-05 00:00:00	\N	2011-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:32	2017-08-08 03:42:59
45372	43968	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:32	\N
45373	43969	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:32	\N
45374	43970	DEPUTE	1997-06-01 00:00:00	\N	1997-10-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:32	2017-08-10 10:56:25
45375	43971	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:32	\N
45376	43972	DEPUTE	1997-12-15 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:32	2017-08-10 10:56:25
45377	43973	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:32	\N
45378	43974	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:32	\N
45379	43975	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:32	\N
45380	43976	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:32	\N
45381	43977	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:32	\N
45382	43978	DEPUTE	1997-06-01 00:00:00	\N	2001-04-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:32	\N
45384	43980	VICPDTAN	2002-06-26 00:00:00	\N	2003-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:32	2017-08-10 10:56:25
45385	43981	VICPDTAN	2004-10-01 00:00:00	\N	2005-12-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:32	2017-08-10 10:56:25
45386	43982	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:32	\N
45387	43983	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:32	\N
45388	43984	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:32	\N
45389	43985	DEPUTE	1988-06-13 00:00:00	\N	1991-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:32	\N
45390	43986	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:32	\N
45391	43987	DEPUTE	1985-12-28 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:33	\N
45392	43988	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:33	\N
45393	43989	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:33	\N
45396	43992	VICPDTAN	2015-01-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:33	2017-08-10 03:42:54
45397	43993	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:33	\N
45398	43994	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:33	\N
45399	43995	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:33	\N
45400	43996	DEPUTE	1986-04-02 00:00:00	\N	1988-05-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:33	\N
45401	43997	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:33	\N
45402	43998	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:33	\N
45403	43999	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:33	\N
45404	44000	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:33	\N
45405	44001	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:33	\N
45406	44002	SECAN	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:33	2017-08-10 10:56:25
45407	44003	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:33	\N
45408	44004	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:33	2017-08-10 10:56:25
45409	44005	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:33	2017-08-10 10:56:25
45410	44006	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:33	2017-08-10 03:42:54
45411	44007	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:33	\N
45412	44008	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:33	\N
45413	44009	SECAN	1987-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:33	2017-08-10 10:56:25
45414	44010	VICPDTAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:33	2017-08-10 03:42:54
45415	44011	VICPDTAN	1994-04-02 00:00:00	\N	1995-04-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:33	2017-08-10 10:56:25
52694	52231	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
45416	44012	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:33	2017-08-10 10:56:25
45417	44013	DEPUTE	1981-07-02 00:00:00	\N	1984-09-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:33	\N
45418	44014	DEPUTE	1986-09-30 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:33	\N
45419	44015	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:33	\N
45420	44016	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:34	\N
45421	44017	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:34	\N
45422	44018	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:34	\N
45423	44019	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:34	\N
45424	44020	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:34	\N
45425	44021	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:34	\N
45426	44022	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:34	\N
45427	44023	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:34	\N
45428	44024	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:34	\N
45429	44025	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:34	\N
45430	44026	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:34	\N
45431	44027	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:34	\N
45432	44028	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:34	\N
45433	44029	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:34	\N
45434	44030	DEPUTE	1977-03-04 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:34	\N
45435	44031	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:34	\N
45436	44032	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:34	\N
45437	44033	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:34	\N
45438	44034	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:34	\N
45439	44035	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:34	\N
45440	44036	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:34	\N
45441	44037	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:34	\N
45442	44038	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:34	\N
45443	44039	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:34	\N
45444	44040	DEPUTE	1997-06-01 00:00:00	\N	2000-04-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:34	\N
45445	44041	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:35	\N
46840	45436	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	\N
46841	45437	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	\N
46842	45438	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	2017-08-10 03:43:19
46843	45439	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	\N
46844	45440	DEPUTE	1997-06-12 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	2017-08-10 03:43:19
46845	45441	DEPUTE	1973-04-02 00:00:00	\N	1977-06-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	\N
46846	45442	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	\N
46847	45443	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	\N
46848	45444	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	\N
46849	45445	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	2017-08-10 10:56:51
46850	45446	DEPUTE	1993-04-02 00:00:00	\N	1993-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	2017-08-09 03:43:27
46851	45447	DEPUTE	1993-09-20 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	2017-08-09 03:43:27
46852	45448	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	\N
46853	45449	DEPUTE	2000-02-07 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	2017-08-09 03:43:27
46854	45450	DEPUTE	1997-06-01 00:00:00	\N	1997-12-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	2017-08-09 03:43:27
46855	45451	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	\N
46856	45452	DEPUTE	2012-06-20 00:00:00	\N	2017-03-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	\N
46857	45453	PDTAN	1992-01-22 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	2017-08-10 10:56:51
46858	45454	DEPUTE	1993-05-02 00:00:00	\N	1995-05-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	\N
46859	45455	DEPUTE	1981-07-02 00:00:00	\N	1986-02-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	\N
46860	45456	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	\N
46861	45457	DEPUTE	1983-04-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	\N
46862	45458	DEPUTE	1998-05-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	\N
46863	45459	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	\N
46864	45460	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:18	\N
46865	45461	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	\N
46866	45462	DEPUTE	1993-04-02 00:00:00	\N	1993-12-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	\N
46867	45463	DEPUTE	2002-06-19 00:00:00	\N	2005-07-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	\N
46868	45464	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	\N
46869	45465	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	2017-08-10 10:56:51
46870	45466	DEPUTE	2008-05-26 00:00:00	\N	2009-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	2017-08-10 10:56:51
46871	45467	DEPUTE	2010-12-14 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	2017-08-10 10:56:51
46872	45468	DEPUTE	2012-06-20 00:00:00	\N	2016-03-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	\N
46873	45469	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	\N
46874	45470	DEPUTE	1997-06-01 00:00:00	\N	2001-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	\N
46875	45471	DEPUTE	1999-12-10 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	\N
46876	45472	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	\N
46877	45473	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	\N
46879	45475	DEPUTE	1991-09-26 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	2017-08-10 10:56:51
46880	45476	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	2017-08-10 10:56:51
46881	45477	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	\N
46882	45478	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	\N
46883	45479	VICPDTAN	1986-04-04 00:00:00	\N	1987-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	2017-08-08 03:43:32
46884	45480	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	\N
46885	45481	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	\N
46886	45482	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	\N
46888	45484	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	\N
46889	45485	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	\N
46891	45487	DEPUTE	2007-06-20 00:00:00	\N	2012-06-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	\N
46892	45488	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	\N
46893	45489	PDTAN	1988-06-23 00:00:00	\N	1992-01-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	2017-08-10 10:56:51
46894	45490	PDTAN	1997-06-12 00:00:00	\N	2000-03-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	2017-08-10 10:56:51
46895	45491	DEPUTE	1978-04-02 00:00:00	\N	1980-11-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	\N
46896	45492	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	\N
46897	45493	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	\N
46898	45494	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	\N
46899	45495	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	\N
46900	45496	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	\N
46901	45497	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	\N
46902	45498	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	\N
46903	45499	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	\N
46904	45500	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	\N
46905	45501	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	\N
46906	45502	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	\N
46907	45503	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	\N
46908	45504	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	\N
46909	45505	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	\N
46910	45506	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	\N
46912	45508	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	2017-08-10 10:56:52
46913	45509	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	\N
46914	45510	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	\N
46915	45511	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	\N
46916	45512	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	\N
46917	45513	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	\N
46918	45514	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	\N
46919	45515	DEPUTE	1968-07-11 00:00:00	\N	1969-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	\N
46920	45516	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	\N
46921	45517	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:19	\N
46922	45518	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:20	\N
46923	45519	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:20	\N
46924	45520	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:20	\N
46925	45521	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:20	\N
46926	45522	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:20	\N
46927	45523	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:20	\N
46928	45524	DEPUTE	1978-04-02 00:00:00	\N	1980-09-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:20	\N
46929	45525	DEPUTE	1981-07-02 00:00:00	\N	1983-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:20	\N
46930	45526	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:20	\N
46931	45527	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:20	\N
46932	45528	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:20	\N
48420	47016	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:08	\N
48421	47017	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:08	\N
48422	47018	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:08	\N
48423	47019	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:08	\N
48424	47020	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:08	\N
48425	47021	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:08	\N
48426	47022	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:08	\N
48427	47023	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:08	\N
48428	47024	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:08	\N
48429	47025	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:08	\N
48430	47026	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:08	\N
50889	50190	PREMADJOINT	2008-03-16 00:00:00	\N	2017-10-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-20 11:18:15	2017-09-20 11:25:15
48432	47028	DEPUTE	2007-06-20 00:00:00	\N	2010-12-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:08	\N
50892	50194	CONSMUNI	2008-03-16 00:00:00	\N	2017-11-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-20 11:26:21	2018-01-25 16:12:41
48434	47030	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:08	\N
48435	47031	VICPDTAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:08	2017-08-10 10:57:18
48436	47032	VICPDTAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:08	2017-08-10 10:57:18
48437	47033	VICPDTAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:08	2017-08-10 10:57:18
48438	47034	PDTAN	2007-03-07 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:08	2017-08-10 10:57:18
48439	47035	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:08	\N
48440	47036	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:08	\N
48441	47037	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:08	\N
48442	47038	DEPUTE	1973-04-02 00:00:00	\N	1974-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:08	\N
48443	47039	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:08	\N
48444	47040	DEPUTE	1978-04-03 00:00:00	\N	1978-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:08	\N
48445	47041	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:08	\N
48446	47042	DEPUTE	1988-06-06 00:00:00	\N	1991-03-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:08	\N
48447	47043	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:08	\N
48448	47044	DEPUTE	1986-04-02 00:00:00	\N	1986-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:08	2017-08-10 10:57:18
48449	47045	DEPUTE	1986-10-01 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:08	2017-08-10 10:57:18
48450	47046	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:08	\N
48451	47047	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:08	\N
48452	47048	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:08	\N
48453	47049	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:08	\N
48454	47050	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:08	\N
48455	47051	DEPUTE	1983-11-15 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:08	\N
48456	47052	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:08	\N
48457	47053	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:09	\N
48458	47054	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:09	\N
48459	47055	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:09	\N
48460	47056	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:09	\N
48461	47057	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:09	\N
48463	47059	VICPDTAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:09	2017-08-09 03:44:00
48464	47060	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:09	\N
48465	47061	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:09	\N
48466	47062	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:09	\N
48467	47063	DEPUTE	1994-06-20 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:09	\N
48468	47064	DEPUTE	1996-02-25 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:09	\N
48469	47065	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:09	\N
48470	47066	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:09	\N
48471	47067	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:09	\N
48472	47068	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:09	\N
48473	47069	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:09	\N
48474	47070	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:09	\N
48475	47071	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:09	\N
48476	47072	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:09	\N
48477	47073	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:09	\N
48478	47074	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:09	\N
48479	47075	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:09	\N
48480	47076	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:09	\N
48481	47077	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:09	\N
48482	47078	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:09	\N
48483	47079	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:09	\N
48486	47082	SECAN	1987-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:09	2017-08-10 10:57:19
48487	47083	SECAN	1988-06-24 00:00:00	\N	1992-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:09	2017-08-10 10:57:19
48488	47084	SECAN	1992-10-21 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:09	2017-08-10 10:57:19
48491	47087	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:09	\N
48492	47088	SECAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:09	2017-08-10 10:57:19
48493	47089	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:09	2017-08-10 10:57:19
48494	47090	SECAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:09	2017-08-10 03:43:49
48495	47091	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:09	\N
48496	47092	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:09	\N
48497	47093	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:10	\N
48498	47094	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:10	\N
48499	47095	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:10	\N
48500	47096	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:10	\N
48501	47097	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:10	\N
48502	47098	DEPUTE	1986-04-02 00:00:00	\N	1986-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:10	2017-08-04 03:44:07
48503	47099	DEPUTE	1986-08-25 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:10	2017-08-04 03:44:07
48504	47100	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:10	\N
48505	47101	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:10	\N
48506	47102	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:10	\N
48507	47103	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:10	\N
48508	47104	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:10	\N
48509	47105	DEPUTE	2012-06-20 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:10	\N
48510	47106	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:10	\N
48511	47107	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:10	\N
48512	47108	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:10	2017-08-10 10:57:19
43958	42554	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:48	\N
43959	42555	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:48	\N
43960	42556	DEPUTE	1995-10-18 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:48	\N
43961	42557	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:48	\N
43962	42558	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:48	\N
43963	42559	DEPUTE	1997-06-01 00:00:00	\N	1998-08-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:48	\N
43964	42560	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:48	\N
43965	42561	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:48	\N
43966	42562	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:48	\N
43967	42563	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:49	\N
43968	42564	DEPUTE	2002-06-19 00:00:00	\N	2007-03-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:49	\N
43969	42565	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:49	\N
43970	42566	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:49	\N
43971	42567	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:49	\N
43972	42568	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:49	\N
43973	42569	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:49	\N
43974	42570	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:49	\N
50824	50118	MAIRE	2002-06-30 00:00:00	\N	2014-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-09-19 16:34:14	2017-09-24 19:16:35
43976	42572	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:49	\N
43977	42573	VICPDTAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:49	2017-08-06 03:42:28
43979	42575	VICPDTAN	2001-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:49	2017-08-09 03:42:27
43980	42576	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:49	\N
43981	42577	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:49	\N
43982	42578	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:49	\N
43983	42579	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:49	\N
43984	42580	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:49	\N
43985	42581	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:49	\N
43986	42582	DEPUTE	1993-04-02 00:00:00	\N	1995-06-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:49	\N
43987	42583	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:49	\N
43988	42584	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:49	\N
43989	42585	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:49	\N
43990	42586	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:49	\N
43991	42587	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:49	\N
43992	42588	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:49	\N
43993	42589	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:49	\N
43994	42590	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:49	\N
43995	42591	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:49	\N
43996	42592	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:49	\N
43997	42593	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:49	\N
43998	42594	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:49	\N
43999	42595	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:49	\N
44000	42596	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:49	\N
44001	42597	DEPUTE	1986-04-02 00:00:00	\N	1986-04-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:49	\N
44002	42598	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:49	\N
44003	42599	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:49	\N
44004	42600	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:49	\N
44005	42601	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:49	\N
44006	42602	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:49	\N
44007	42603	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:49	\N
44008	42604	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:49	\N
44009	42605	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:49	\N
44010	42606	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:49	\N
44011	42607	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:49	\N
44012	42608	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:49	\N
44013	42609	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:49	\N
44014	42610	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:49	\N
44015	42611	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:50	\N
44016	42612	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:50	\N
44017	42613	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:50	\N
44018	42614	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:50	\N
44019	42615	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:50	\N
44020	42616	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:50	\N
44021	42617	DEPUTE	1978-10-01 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:50	\N
44022	42618	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:50	\N
44023	42619	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:50	\N
44024	42620	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:50	\N
44025	42621	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:50	\N
44026	42622	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:50	\N
52696	52233	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
44027	42623	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:50	\N
44028	42624	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:50	\N
44029	42625	DEPUTE	2007-06-20 00:00:00	\N	2012-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:50	\N
44030	42626	DEPUTE	2012-06-20 00:00:00	\N	2012-07-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:50	2017-08-10 03:42:31
44031	42627	DEPUTE	2014-05-01 00:00:00	\N	2016-03-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:50	2017-08-10 03:42:31
44032	42628	DEPUTE	1983-02-28 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:50	\N
44033	42629	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:50	\N
44034	42630	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:50	\N
44035	42631	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:50	\N
44037	42633	SECAN	1987-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:50	2017-08-10 03:42:31
44038	42634	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:50	\N
44039	42635	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:50	\N
44040	42636	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:50	\N
44041	42637	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:50	\N
44042	42638	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:50	\N
44043	42639	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:50	\N
44044	42640	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:50	\N
44045	42641	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:50	\N
44047	42643	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:50	\N
44048	42644	SECAN	2007-06-27 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:50	2017-08-10 10:55:58
44049	42645	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:50	\N
44050	42646	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:50	\N
45446	44042	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:35	\N
45447	44043	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:35	\N
45448	44044	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:35	2017-08-10 10:56:26
45449	44045	DEPUTE	1998-10-01 00:00:00	\N	2000-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:35	2017-08-10 10:56:26
45450	44046	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:35	\N
45451	44047	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:35	\N
45452	44048	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:35	\N
45453	44049	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:35	\N
45454	44050	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:35	\N
45455	44051	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:35	\N
45456	44052	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:35	\N
45457	44053	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:35	\N
45458	44054	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:35	\N
45459	44055	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:35	\N
45460	44056	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:35	\N
45461	44057	DEPUTE	1993-05-02 00:00:00	\N	1995-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:35	\N
45462	44058	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:35	\N
45463	44059	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:35	\N
45464	44060	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:35	\N
45465	44061	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:35	\N
45466	44062	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:35	\N
45467	44063	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:35	\N
45468	44064	DEPUTE	1997-06-01 00:00:00	\N	2001-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:35	\N
45469	44065	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:36	\N
45470	44066	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:36	\N
45471	44067	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:36	\N
45472	44068	DEPUTE	1988-06-13 00:00:00	\N	1990-01-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:36	\N
45473	44069	DEPUTE	1996-02-26 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:36	\N
45474	44070	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:36	\N
45475	44071	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:36	\N
45476	44072	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:36	\N
45477	44073	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:36	\N
45478	44074	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:36	\N
45479	44075	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:36	\N
45480	44076	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:36	\N
45481	44077	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:36	\N
45482	44078	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:36	\N
45483	44079	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:36	\N
45484	44080	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:36	\N
45485	44081	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:36	\N
45486	44082	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:36	\N
45487	44083	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:36	\N
45488	44084	DEPUTE	1991-06-18 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:36	\N
45489	44085	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:36	\N
45490	44086	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:36	\N
45491	44087	DEPUTE	1987-10-14 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:36	\N
45492	44088	DEPUTE	1996-09-15 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:36	\N
45493	44089	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:37	\N
45494	44090	DEPUTE	1986-04-02 00:00:00	\N	1987-10-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:37	\N
45495	44091	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:37	\N
45496	44092	DEPUTE	1997-05-25 00:00:00	\N	2001-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:37	\N
45497	44093	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:37	\N
45498	44094	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:37	\N
45499	44095	DEPUTE	2002-06-19 00:00:00	\N	2003-02-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:37	\N
45500	44096	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:37	\N
45501	44097	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:37	\N
45502	44098	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:37	\N
45503	44099	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:37	\N
45504	44100	DEPUTE	2007-06-20 00:00:00	\N	2012-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:37	\N
45505	44101	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:37	\N
45506	44102	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:37	\N
45507	44103	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:37	\N
45508	44104	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:37	\N
45509	44105	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:37	\N
45510	44106	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	\N
45511	44107	DEPUTE	2004-05-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	\N
45512	44108	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	\N
45514	44110	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	\N
45515	44111	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	\N
45516	44112	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	\N
45517	44113	VICPDTAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	2017-08-10 03:42:57
45518	44114	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	\N
45519	44115	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	\N
45520	44116	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	\N
45521	44117	DEPUTE	1993-05-02 00:00:00	\N	1995-06-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	2017-08-08 03:43:04
45522	44118	DEPUTE	1995-07-17 00:00:00	\N	1995-08-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	2017-08-08 03:43:04
45523	44119	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	\N
45524	44120	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	\N
45525	44121	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	\N
45526	44122	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	\N
45527	44123	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	\N
45528	44124	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	\N
45529	44125	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	\N
45530	44126	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	\N
45531	44127	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	\N
45532	44128	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	\N
45533	44129	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	\N
45536	44132	QUESTAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	2017-08-10 10:56:28
45537	44133	SECAN	1992-04-02 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	2017-08-10 10:56:28
45538	44134	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	\N
50816	50107	VICPDTINTCOM	2017-01-01 00:00:00	\N	2017-10-15 00:00:00	\N	ANCIEN	\N	\N	\N	NON	2017-09-19 16:11:59	2018-03-28 18:15:57
46933	45529	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:20	\N
46934	45530	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:20	\N
46935	45531	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:20	\N
46936	45532	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:20	\N
46937	45533	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:20	\N
50828	50122	PDTINTCOM	2014-04-18 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2017-09-19 16:44:32	2017-09-19 16:45:05
46939	45535	SECAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:20	2017-08-10 10:56:52
46940	45536	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:20	2017-08-10 10:56:52
46941	45537	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:20	2017-08-10 10:56:52
46942	45538	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:20	2017-08-10 10:56:52
46943	45539	DEPUTE	1973-04-02 00:00:00	\N	1974-04-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:20	\N
46944	45540	DEPUTE	1975-07-07 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:20	\N
46945	45541	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:20	\N
46946	45542	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:20	\N
46947	45543	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:20	2017-08-10 10:56:52
46948	45544	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:20	2017-08-03 03:43:26
46949	45545	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:20	\N
46950	45546	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:20	\N
46951	45547	SECAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:20	2017-08-03 03:43:26
46952	45548	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:20	2017-08-10 10:56:52
46953	45549	SECAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:20	2017-08-10 10:56:52
46954	45550	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:20	\N
46955	45551	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:20	\N
46957	45553	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:20	\N
46958	45554	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:20	\N
46960	45556	SECAN	1997-06-13 00:00:00	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:20	2017-08-10 10:56:52
46961	45557	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:20	2017-08-10 03:43:21
46962	45558	VICPDTAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:20	2017-08-10 10:56:52
46963	45559	SECAN	2012-06-27 00:00:00	\N	2013-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:20	2017-08-09 03:43:28
46964	45560	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:21	\N
46965	45561	DEPUTE	1986-04-02 00:00:00	\N	1987-12-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:21	\N
46966	45562	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:21	\N
46967	45563	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:21	\N
46968	45564	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:21	\N
46969	45565	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:21	\N
46970	45566	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:21	\N
46971	45567	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:21	\N
46973	45569	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:21	\N
46975	45571	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:21	2017-08-10 03:43:21
46976	45572	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:21	\N
46978	45574	VICPDTAN	2004-10-01 00:00:00	\N	2006-11-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:21	2017-08-10 10:56:53
46979	45575	VICPDTAN	2009-10-06 00:00:00	\N	2010-11-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:21	2017-08-10 10:56:53
46980	45576	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:21	\N
46981	45577	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:21	\N
46982	45578	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:21	\N
46983	45579	DEPUTE	1981-04-15 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:21	\N
46984	45580	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:21	\N
46985	45581	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:21	\N
46986	45582	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:21	\N
46987	45583	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:21	\N
46988	45584	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:21	\N
46989	45585	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:21	\N
46990	45586	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:21	\N
46991	45587	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:21	\N
46992	45588	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:21	\N
46993	45589	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:21	\N
46994	45590	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:21	\N
46995	45591	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:22	\N
46996	45592	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:22	\N
46997	45593	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:22	\N
46998	45594	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:22	\N
46999	45595	DEPUTE	1988-06-13 00:00:00	\N	1992-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:22	\N
47000	45596	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:22	\N
47001	45597	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:22	\N
47002	45598	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:22	\N
47003	45599	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:22	\N
47004	45600	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:22	\N
47005	45601	DEPUTE	1973-04-02 00:00:00	\N	1976-09-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:22	\N
47006	45602	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:22	\N
47007	45603	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:22	\N
47008	45604	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:22	\N
47009	45605	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:22	\N
47010	45606	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:22	\N
47011	45607	DEPUTE	1975-05-25 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:22	2017-08-10 10:56:53
47012	45608	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:22	\N
47013	45609	DEPUTE	1968-07-11 00:00:00	\N	1969-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:22	\N
47014	45610	DEPUTE	1973-04-02 00:00:00	\N	1973-05-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:22	2017-08-10 10:56:53
47015	45611	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:22	\N
47016	45612	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:22	\N
47017	45613	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:22	\N
47018	45614	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:22	\N
47019	45615	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:22	\N
47020	45616	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:22	\N
47021	45617	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:22	\N
47022	45618	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:22	\N
47023	45619	DEPUTE	1968-07-11 00:00:00	\N	1968-08-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:22	2017-08-10 10:56:54
47024	45620	DEPUTE	1971-12-13 00:00:00	\N	1972-01-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:22	2017-08-10 10:56:54
47025	45621	DEPUTE	1973-04-02 00:00:00	\N	1973-05-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:22	\N
48513	47109	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:10	\N
48514	47110	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:10	\N
48515	47111	DEPUTE	2017-06-21 00:00:00	\N	2021-07-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:10	\N
48516	47112	DEPUTE	2002-06-25 00:00:00	\N	2002-06-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:10	2017-08-10 10:57:19
48517	47113	DEPUTE	2003-03-11 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:10	\N
48518	47114	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:10	\N
48519	47115	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:10	\N
48520	47116	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:10	\N
48521	47117	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:10	\N
48522	47118	DEPUTE	2006-06-07 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:10	\N
48523	47119	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:10	\N
48524	47120	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:10	\N
48525	47121	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:10	\N
48526	47122	DEPUTE	2007-06-20 00:00:00	\N	2008-04-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:10	\N
48527	47123	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:11	\N
48528	47124	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:11	\N
48529	47125	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:11	\N
48530	47126	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:11	\N
48531	47127	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:11	\N
48532	47128	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:11	\N
48533	47129	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:11	\N
48534	47130	DEPUTE	2007-06-20 00:00:00	\N	2008-03-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:11	\N
48535	47131	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:11	\N
48536	47132	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:11	\N
48537	47133	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:11	\N
48538	47134	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:11	\N
48539	47135	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:11	2017-08-10 03:43:50
48540	47136	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:11	2017-08-10 03:43:50
48541	47137	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:11	2017-08-10 03:43:50
48542	47138	DEPUTE	2012-06-20 00:00:00	\N	2016-01-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:11	\N
48543	47139	DEPUTE	2002-06-25 00:00:00	\N	2002-06-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:11	2017-08-10 03:43:50
48544	47140	DEPUTE	2007-07-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:11	\N
48545	47141	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:11	\N
48546	47142	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:11	\N
48547	47143	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:11	2017-08-10 03:43:50
48548	47144	DEPUTE	2017-01-07 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:11	2017-08-10 03:43:50
48549	47145	DEPUTE	2017-06-21 00:00:00	\N	2018-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:11	\N
48550	47146	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:11	\N
48551	47147	DEPUTE	2012-07-22 00:00:00	\N	2017-01-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:11	\N
48552	47148	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:11	\N
48553	47149	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:11	2017-08-10 10:57:20
48554	47150	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:12	\N
48555	47151	DEPUTE	2012-03-23 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:12	2017-08-10 10:57:20
48556	47152	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:12	\N
48557	47153	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:12	\N
48558	47154	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:12	\N
48559	47155	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:12	\N
48560	47156	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:12	\N
48561	47157	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:12	\N
48562	47158	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:12	\N
48563	47159	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:12	\N
48564	47160	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:12	\N
48565	47161	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:12	\N
48566	47162	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:12	\N
48567	47163	DEPUTE	2017-06-21 00:00:00	\N	2020-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:12	\N
48568	47164	DEPUTE	2005-07-03 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:12	\N
48569	47165	DEPUTE	2007-07-20 00:00:00	\N	2008-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:12	2017-08-10 03:43:51
48570	47166	DEPUTE	2009-07-23 00:00:00	\N	2010-12-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:12	2017-08-10 03:43:51
48571	47167	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:12	\N
48572	47168	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:12	\N
48573	47169	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:12	\N
48574	47170	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:12	\N
48575	47171	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:12	\N
48576	47172	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:12	\N
48577	47173	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:12	\N
48578	47174	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:13	\N
48579	47175	DEPUTE	1978-04-03 00:00:00	\N	1978-05-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:13	\N
48580	47176	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:13	\N
48581	47177	DEPUTE	1973-04-02 00:00:00	\N	1973-05-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:13	\N
48582	47178	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:13	\N
48583	47179	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:13	\N
48584	47180	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:13	\N
48585	47181	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:13	\N
48586	47182	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:13	\N
48587	47183	DEPUTE	1988-06-13 00:00:00	\N	1991-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:13	\N
48588	47184	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:13	2017-08-10 10:57:21
48589	47185	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:13	\N
48590	47186	DEPUTE	2001-04-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:13	2017-08-10 10:57:21
48591	47187	DEPUTE	2007-06-20 00:00:00	\N	2007-10-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:13	\N
48592	47188	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:13	\N
48593	47189	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:13	\N
48595	47191	SECAN	1988-06-24 00:00:00	\N	1991-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:13	2017-08-10 10:57:21
48596	47192	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:13	\N
48597	47193	DEPUTE	1980-11-30 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:13	\N
48598	47194	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:13	\N
48600	47196	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:13	2017-08-10 10:57:21
48601	47197	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:13	2017-08-10 10:57:21
48602	47198	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:13	2017-08-10 03:43:51
48603	47199	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:13	\N
48604	47200	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:13	\N
48605	47201	DEPUTE	1988-06-13 00:00:00	\N	1991-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:13	\N
44051	42647	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:50	\N
44052	42648	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:50	\N
44053	42649	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:50	\N
44054	42650	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:50	\N
44055	42651	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:50	\N
44056	42652	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:50	\N
44057	42653	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:50	\N
44058	42654	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:50	\N
44059	42655	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:50	\N
44060	42656	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:51	\N
44061	42657	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:51	\N
44062	42658	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:51	\N
44063	42659	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:51	\N
44064	42660	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:51	\N
44065	42661	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:51	\N
44066	42662	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:51	\N
44067	42663	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:51	\N
44068	42664	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:51	\N
44069	42665	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:51	\N
44070	42666	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:51	2017-08-10 03:42:31
44071	42667	DEPUTE	1995-09-24 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:51	2017-08-10 03:42:31
44072	42668	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:51	\N
44073	42669	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:51	\N
44074	42670	DEPUTE	1978-04-02 00:00:00	\N	1981-01-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:51	\N
44075	42671	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:51	\N
44077	42673	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:51	\N
44078	42674	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:51	\N
44079	42675	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:51	\N
44080	42676	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:51	\N
44082	42678	SECAN	1986-04-04 00:00:00	\N	1987-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:51	2017-08-10 03:42:32
44083	42679	VICPDTAN	2010-10-05 00:00:00	\N	2011-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:51	2017-08-10 10:55:59
44084	42680	SECAN	2011-10-03 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:51	2017-08-07 03:42:29
44085	42681	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:51	\N
44086	42682	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:51	\N
44087	42683	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:51	\N
44088	42684	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:51	\N
44089	42685	DEPUTE	1986-04-02 00:00:00	\N	1986-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:51	2017-08-10 10:55:59
44090	42686	DEPUTE	1986-09-29 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:51	2017-08-10 10:55:59
44091	42687	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:51	\N
44092	42688	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:51	\N
44093	42689	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:51	\N
44094	42690	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:51	\N
44095	42691	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:51	\N
44096	42692	DEPUTE	1983-07-27 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:51	\N
44097	42693	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:51	\N
44098	42694	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:51	\N
44099	42695	DEPUTE	1989-06-26 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:51	\N
44100	42696	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:52	\N
44101	42697	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:52	\N
44102	42698	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:52	\N
44103	42699	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:52	\N
44104	42700	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:52	\N
44105	42701	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:52	\N
44106	42702	DEPUTE	1986-09-30 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:52	\N
44107	42703	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:52	\N
44108	42704	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:52	\N
44109	42705	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:52	\N
44110	42706	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:52	\N
44111	42707	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:52	\N
44112	42708	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:52	\N
44113	42709	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:52	\N
44114	42710	DEPUTE	1994-03-13 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:52	\N
44115	42711	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:52	\N
44116	42712	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:52	\N
44118	42714	VICPDTAN	1995-05-31 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:52	2017-08-10 10:56:00
44119	42715	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:52	\N
44120	42716	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:52	\N
44121	42717	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:52	\N
44122	42718	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:52	\N
44123	42719	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:52	\N
44124	42720	DEPUTE	1993-04-02 00:00:00	\N	1995-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:52	2017-08-11 11:32:28
44125	42721	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:52	2017-08-10 10:56:00
44127	42723	DEPUTE	2007-06-20 00:00:00	\N	2010-04-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:52	2017-08-07 03:42:29
44128	42724	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:52	2017-08-07 03:42:29
44129	42725	DEPUTE	2012-06-20 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:52	\N
44130	42726	DEPUTE	1993-04-02 00:00:00	\N	1995-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:52	2017-08-10 10:56:00
44131	42727	DEPUTE	1997-06-12 00:00:00	\N	1999-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:52	2017-08-10 10:56:00
44132	42728	VICPDTAN	2003-10-01 00:00:00	\N	2005-07-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:52	2017-08-10 10:56:00
44133	42729	VICPDTAN	2002-06-26 00:00:00	\N	2003-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:52	2017-08-10 10:56:00
44134	42730	DEPUTE	1993-09-03 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:52	\N
44135	42731	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:52	\N
44136	42732	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:53	\N
44137	42733	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:53	\N
44138	42734	DEPUTE	1978-04-03 00:00:00	\N	1978-05-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:53	\N
44139	42735	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:53	\N
44140	42736	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:53	\N
44141	42737	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:53	\N
44142	42738	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:53	\N
44143	42739	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:53	\N
45539	44135	DEPUTE	1980-10-20 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	\N
45540	44136	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	\N
45541	44137	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	\N
45542	44138	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	\N
50817	50108	MAIREADJOINT	1989-03-20 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-09-19 16:14:38	2017-09-19 16:18:24
45544	44140	SECAN	1997-06-13 00:00:00	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	2017-08-10 10:56:28
45545	44141	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	\N
45546	44142	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	\N
45548	44144	VICPDTAN	2007-06-27 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	2017-08-10 10:56:28
45549	44145	DEPUTE	1995-12-08 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	\N
45550	44146	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	\N
45551	44147	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	\N
45552	44148	DEPUTE	1973-04-02 00:00:00	\N	1975-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	\N
45553	44149	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	\N
45554	44150	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	\N
45555	44151	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	\N
45556	44152	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	\N
45557	44153	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	\N
45558	44154	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	\N
45559	44155	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	\N
45560	44156	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	\N
45561	44157	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	\N
45562	44158	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	\N
45563	44159	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	\N
45564	44160	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:38	\N
45566	44162	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:39	\N
45567	44163	SECAN	2008-10-01 00:00:00	\N	2010-10-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:39	2017-08-10 10:56:29
45568	44164	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:39	\N
45569	44165	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:39	\N
45570	44166	DEPUTE	2000-03-20 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:39	\N
45571	44167	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:39	\N
45572	44168	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:39	\N
45573	44169	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:39	\N
45574	44170	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:39	\N
45575	44171	DEPUTE	1997-06-01 00:00:00	\N	1999-08-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:39	\N
45576	44172	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:39	\N
45577	44173	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:39	\N
45578	44174	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:39	\N
45579	44175	DEPUTE	1983-04-23 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:39	\N
45580	44176	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:39	\N
45581	44177	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:39	\N
45582	44178	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:39	\N
45583	44179	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:39	\N
45584	44180	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:39	\N
45585	44181	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:39	\N
45586	44182	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:39	\N
45587	44183	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:39	\N
45588	44184	DEPUTE	2002-06-19 00:00:00	\N	2004-03-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:39	\N
45589	44185	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:39	\N
45590	44186	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:39	2017-08-10 03:42:58
45591	44187	DEPUTE	1995-06-25 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:39	2017-08-10 03:42:58
45592	44188	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:39	\N
45593	44189	DEPUTE	1958-12-09 00:00:00	\N	1959-02-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:39	\N
45594	44190	DEPUTE	1962-12-06 00:00:00	\N	1963-01-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:39	\N
45595	44191	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:39	\N
45596	44192	DEPUTE	1968-07-11 00:00:00	\N	1969-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:39	\N
45597	44193	DEPUTE	1973-04-02 00:00:00	\N	1973-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:39	\N
45598	44194	DEPUTE	1984-09-24 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:39	\N
45599	44195	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:39	\N
45600	44196	DEPUTE	1988-06-06 00:00:00	\N	1989-11-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:39	\N
45601	44197	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:39	\N
45602	44198	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:39	\N
45603	44199	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:39	\N
45604	44200	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:39	\N
45605	44201	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:39	\N
45607	44203	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:39	\N
45608	44204	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:39	\N
45609	44205	VICPDTAN	1997-06-13 00:00:00	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:39	2017-08-10 10:56:29
45610	44206	VICPDTAN	1998-10-01 00:00:00	\N	1998-10-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:39	2017-08-09 03:43:01
45611	44207	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:40	\N
45612	44208	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:40	\N
45613	44209	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:40	\N
45614	44210	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:40	\N
45615	44211	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:40	\N
45616	44212	DEPUTE	1993-05-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:40	\N
45617	44213	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:40	\N
45618	44214	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:40	\N
45619	44215	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:40	\N
45620	44216	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:40	\N
45621	44217	DEPUTE	2017-06-21 00:00:00	\N	2020-05-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:40	\N
45622	44218	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:40	\N
45623	44219	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:40	\N
45624	44220	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:40	\N
45625	44221	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:40	\N
45626	44222	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:40	\N
45627	44223	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:40	\N
45628	44224	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:40	\N
45629	44225	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:40	\N
45630	44226	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:40	\N
45631	44227	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:40	\N
47026	45622	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:22	\N
47027	45623	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:22	\N
47028	45624	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:22	\N
47029	45625	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:22	\N
47030	45626	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:22	\N
47031	45627	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:23	\N
47032	45628	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:23	\N
47033	45629	DEPUTE	1992-11-03 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:23	\N
47034	45630	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:23	\N
47035	45631	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:23	\N
47036	45632	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:23	\N
47037	45633	DEPUTE	1988-06-13 00:00:00	\N	1992-07-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:23	\N
47038	45634	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:23	\N
47039	45635	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:23	\N
47040	45636	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:23	\N
47041	45637	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:23	\N
47042	45638	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:23	\N
47043	45639	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:23	\N
47044	45640	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:23	\N
47045	45641	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:23	\N
47046	45642	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:23	\N
47047	45643	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:23	\N
47048	45644	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:23	\N
47049	45645	DEPUTE	2007-06-20 00:00:00	\N	2011-11-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:23	\N
47050	45646	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:23	\N
47051	45647	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:23	\N
47052	45648	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:23	\N
47053	45649	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:23	\N
47054	45650	DEPUTE	1981-07-02 00:00:00	\N	1984-09-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:23	\N
47055	45651	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:24	\N
47056	45652	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:24	\N
47057	45653	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:24	\N
47058	45654	DEPUTE	1973-05-06 00:00:00	\N	1974-07-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:24	\N
47059	45655	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:24	\N
47060	45656	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:24	\N
47061	45657	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:24	2017-08-08 03:43:36
47062	45658	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:24	\N
47063	45659	SECAN	2007-06-27 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:24	2017-08-08 03:43:36
47064	45660	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:24	\N
47065	45661	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:24	\N
47066	45662	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:24	\N
47067	45663	DEPUTE	1962-12-06 00:00:00	\N	1963-03-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:24	\N
47068	45664	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:24	\N
47069	45665	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:24	\N
47070	45666	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:24	\N
47071	45667	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:24	\N
47072	45668	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:24	\N
47073	45669	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:24	2017-08-10 03:43:24
47074	45670	DEPUTE	1995-10-09 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:24	2017-08-10 03:43:24
47075	45671	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:24	\N
47076	45672	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:24	\N
47077	45673	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:24	\N
47078	45674	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:24	\N
47079	45675	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:24	\N
47080	45676	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:24	\N
47081	45677	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:25	\N
47082	45678	DEPUTE	1978-04-02 00:00:00	\N	1980-09-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:25	\N
47083	45679	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:25	\N
47084	45680	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:25	\N
47085	45681	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:25	\N
47086	45682	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:25	\N
47087	45683	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:25	\N
47088	45684	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:25	\N
47089	45685	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:25	\N
47090	45686	DEPUTE	2000-04-28 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:25	\N
47091	45687	DEPUTE	1992-05-05 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:25	\N
47092	45688	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:25	\N
47093	45689	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:25	\N
47094	45690	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:25	\N
47095	45691	DEPUTE	1981-07-02 00:00:00	\N	1984-08-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:25	\N
47096	45692	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:25	\N
47097	45693	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:25	\N
47098	45694	DEPUTE	1988-06-06 00:00:00	\N	1992-05-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:25	\N
47099	45695	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:25	\N
47100	45696	DEPUTE	1997-06-01 00:00:00	\N	1998-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:25	\N
47101	45697	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:25	\N
47102	45698	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:25	\N
47103	45699	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:25	\N
47104	45700	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:25	\N
47105	45701	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:26	\N
47106	45702	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:26	\N
47107	45703	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:26	\N
47108	45704	DEPUTE	1988-06-06 00:00:00	\N	1988-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:26	2017-08-09 03:43:32
47109	45705	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:26	\N
47110	45706	DEPUTE	1988-09-19 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:26	2017-08-09 03:43:32
47111	45707	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:26	\N
47112	45708	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:26	\N
47113	45709	DEPUTE	2012-06-20 00:00:00	\N	2013-01-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:26	2017-08-09 03:43:32
47114	45710	DEPUTE	2013-03-24 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:26	2017-08-09 03:43:32
47115	45711	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:26	\N
47116	45712	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:26	\N
47117	45713	DEPUTE	2012-06-20 00:00:00	\N	2014-07-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:26	\N
47118	45714	DEPUTE	1978-04-03 00:00:00	\N	1980-09-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:26	\N
48606	47202	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:14	\N
48607	47203	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:14	\N
48608	47204	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:14	\N
48609	47205	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:14	\N
48610	47206	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:14	\N
48611	47207	DEPUTE	1988-06-13 00:00:00	\N	1989-06-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:14	\N
48612	47208	DEPUTE	1981-07-02 00:00:00	\N	1985-09-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:14	\N
48613	47209	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:14	\N
48614	47210	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:14	\N
48615	47211	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:14	\N
48616	47212	DEPUTE	1989-02-03 00:00:00	\N	1992-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:14	\N
48617	47213	DEPUTE	1993-04-02 00:00:00	\N	1996-07-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:14	\N
48618	47214	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:14	\N
48619	47215	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:14	\N
48620	47216	DEPUTE	1997-06-01 00:00:00	\N	1998-07-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:14	\N
48621	47217	DEPUTE	1997-06-01 00:00:00	\N	2000-04-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:14	\N
48622	47218	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:14	\N
48623	47219	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:14	\N
48624	47220	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:14	\N
48625	47221	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:14	\N
48626	47222	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:15	\N
48627	47223	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:15	\N
48628	47224	DEPUTE	2017-06-21 00:00:00	\N	2020-07-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:15	\N
48629	47225	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:15	\N
48630	47226	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:15	\N
48631	47227	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:15	\N
48632	47228	DEPUTE	1988-06-13 00:00:00	\N	1989-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:15	\N
48633	47229	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:15	\N
48634	47230	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:15	\N
48635	47231	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:15	\N
48636	47232	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:15	\N
48637	47233	DEPUTE	1983-01-09 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:15	\N
48638	47234	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:15	\N
48639	47235	DEPUTE	1988-06-13 00:00:00	\N	1988-11-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:15	\N
48642	47238	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:15	\N
48643	47239	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:15	\N
48644	47240	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:15	\N
48645	47241	SECAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:15	2017-08-10 10:57:22
48646	47242	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:15	2017-08-10 10:57:22
48647	47243	SECAN	2002-06-26 00:00:00	\N	2002-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:15	2017-08-10 10:57:22
48648	47244	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:15	\N
48649	47245	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:15	\N
48650	47246	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:16	\N
48651	47247	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:16	2017-08-10 03:43:53
48652	47248	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:16	\N
48653	47249	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:16	\N
48654	47250	DEPUTE	2012-06-20 00:00:00	\N	2017-03-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:16	\N
48655	47251	DEPUTE	1997-06-12 00:00:00	\N	1999-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:16	2017-08-10 03:43:53
48656	47252	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:16	\N
48657	47253	DEPUTE	2012-07-22 00:00:00	\N	2014-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:16	\N
48658	47254	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:16	\N
48659	47255	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:16	\N
48660	47256	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:16	\N
48661	47257	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:16	\N
48662	47258	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:16	\N
48663	47259	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:16	\N
48664	47260	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:16	\N
48665	47261	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:16	\N
48666	47262	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:16	\N
48667	47263	DEPUTE	1991-06-17 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:16	\N
48668	47264	DEPUTE	1981-07-23 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:16	\N
48669	47265	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:16	\N
48670	47266	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:16	\N
48671	47267	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:16	\N
48672	47268	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:16	\N
48673	47269	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	\N
48674	47270	DEPUTE	2002-06-19 00:00:00	\N	2006-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	\N
48675	47271	DEPUTE	1997-05-25 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	\N
48676	47272	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	\N
48677	47273	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	\N
48678	47274	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	\N
48679	47275	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	\N
48680	47276	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	\N
48681	47277	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	\N
48682	47278	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	\N
48683	47279	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	\N
48684	47280	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	\N
48685	47281	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	\N
48686	47282	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	\N
48687	47283	DEPUTE	1976-11-15 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	2017-08-08 03:44:13
48688	47284	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	\N
48689	47285	DEPUTE	1968-08-13 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	\N
48690	47286	DEPUTE	1973-04-02 00:00:00	\N	1976-02-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	2017-08-08 03:44:13
48691	47287	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	\N
48692	47288	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	\N
48693	47289	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	\N
48694	47290	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	\N
48695	47291	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	\N
48696	47292	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	\N
48697	47293	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	\N
48698	47294	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	\N
44144	42740	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:53	\N
44145	42741	DEPUTE	1978-04-03 00:00:00	\N	1978-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:53	\N
44146	42742	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:53	\N
44147	42743	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:53	\N
44148	42744	DEPUTE	1973-04-02 00:00:00	\N	1974-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:53	\N
44149	42745	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:53	\N
44150	42746	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:53	\N
44151	42747	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:53	\N
44152	42748	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:53	\N
44153	42749	DEPUTE	2002-06-19 00:00:00	\N	2004-05-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:53	\N
44154	42750	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:53	\N
44155	42751	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:53	\N
44156	42752	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:53	\N
44157	42753	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:53	\N
44158	42754	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:53	\N
44159	42755	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:53	\N
44160	42756	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:53	\N
44161	42757	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:53	2017-08-10 10:56:01
44162	42758	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:53	\N
44163	42759	DEPUTE	1997-06-01 00:00:00	\N	1998-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:53	\N
44164	42760	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:53	\N
44165	42761	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:53	\N
44167	42763	VICPDTAN	1992-04-02 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:53	2017-08-10 10:56:01
44168	42764	PDTAN	2012-06-26 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:53	2017-08-08 03:42:33
44169	42765	DEPUTE	1988-06-06 00:00:00	\N	1990-12-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:53	\N
44170	42766	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:53	\N
44171	42767	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:54	\N
44172	42768	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:54	\N
44173	42769	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:54	\N
44174	42770	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:54	\N
44175	42771	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:54	\N
44176	42772	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:54	\N
44178	42774	QUESTAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:54	2017-08-10 03:42:33
44179	42775	DEPUTE	1993-04-02 00:00:00	\N	1995-12-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:54	\N
44180	42776	DEPUTE	1996-04-01 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:54	\N
44181	42777	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:54	\N
52698	52235	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
44182	42778	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:54	\N
44183	42779	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:54	\N
44184	42780	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:54	\N
44185	42781	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:54	\N
44186	42782	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:54	\N
44187	42783	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:54	\N
44188	42784	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:54	\N
44189	42785	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:54	\N
44190	42786	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:54	\N
44191	42787	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:54	\N
44192	42788	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:54	\N
44193	42789	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:54	\N
44194	42790	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:54	\N
44195	42791	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:54	\N
44196	42792	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:54	\N
44197	42793	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:55	\N
44198	42794	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:55	\N
44199	42795	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:55	\N
44200	42796	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:55	\N
44201	42797	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:55	\N
44202	42798	DEPUTE	1986-04-02 00:00:00	\N	1986-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:55	2017-08-10 10:56:02
44203	42799	DEPUTE	1986-10-24 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:55	2017-08-10 10:56:02
44204	42800	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:55	2017-08-09 03:42:31
44205	42801	DEPUTE	1986-10-01 00:00:00	\N	1986-10-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:55	2017-08-09 03:42:31
44206	42802	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:55	\N
44207	42803	DEPUTE	1993-04-02 00:00:00	\N	1994-05-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:55	\N
44208	42804	DEPUTE	1997-06-01 00:00:00	\N	2001-01-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:55	\N
44209	42805	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:55	\N
44210	42806	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:55	\N
44211	42807	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:55	\N
44212	42808	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:55	\N
44213	42809	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:55	\N
44214	42810	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:55	\N
44215	42811	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:55	\N
44216	42812	DEPUTE	1968-07-11 00:00:00	\N	1969-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:55	\N
44217	42813	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:55	\N
44218	42814	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:55	\N
44219	42815	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:55	\N
44220	42816	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:55	\N
44221	42817	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:55	\N
44222	42818	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:55	\N
44223	42819	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:55	\N
44224	42820	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:55	\N
44225	42821	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:55	\N
44226	42822	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:55	\N
44227	42823	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:55	\N
44228	42824	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:55	\N
44229	42825	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:55	\N
44230	42826	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:56	\N
44231	42827	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:56	\N
44232	42828	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:56	\N
44233	42829	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:56	\N
44234	42830	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:56	\N
44235	42831	DEPUTE	1973-05-08 00:00:00	\N	1976-11-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:56	\N
44236	42832	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:56	\N
45632	44228	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:40	\N
45633	44229	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:40	\N
45634	44230	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:40	2017-08-10 03:42:58
45635	44231	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:40	2017-08-10 10:56:30
45636	44232	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:40	\N
45637	44233	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:40	\N
45638	44234	QUESTAN	1990-04-02 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:40	2017-08-10 03:42:58
45639	44235	QUESTAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:40	2017-08-10 10:56:30
45640	44236	QUESTAN	1994-04-02 00:00:00	\N	1995-05-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:40	2017-08-10 10:56:30
45641	44237	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:40	\N
45642	44238	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:40	\N
45643	44239	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:40	\N
45644	44240	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:40	\N
45645	44241	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:40	\N
45646	44242	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:40	\N
45647	44243	DEPUTE	2002-06-19 00:00:00	\N	2007-03-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:40	\N
45648	44244	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:40	\N
50817	50110	CONSMUNI	1995-06-19 00:00:00	\N	2001-03-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-09-19 16:15:17	2017-09-19 16:17:25
45650	44246	SECAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:41	2017-08-04 03:43:01
45651	44247	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:41	\N
45652	44248	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:41	\N
45653	44249	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:41	\N
50817	50111	MAIRE	2014-03-31 00:00:00	\N	2017-10-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-09-19 16:16:22	2017-11-21 18:32:49
45655	44251	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:41	\N
45656	44252	SECAN	2003-10-01 00:00:00	\N	2005-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:41	2017-08-10 03:42:59
45657	44253	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:41	\N
45658	44254	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:41	\N
45659	44255	DEPUTE	2007-06-20 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:41	\N
45660	44256	DEPUTE	1973-04-02 00:00:00	\N	1973-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:41	\N
45661	44257	DEPUTE	1967-04-03 00:00:00	\N	1967-05-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:41	\N
45662	44258	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:41	\N
45663	44259	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:41	\N
45664	44260	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:41	\N
45665	44261	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:41	\N
45666	44262	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:41	\N
45667	44263	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:41	\N
45668	44264	DEPUTE	1981-07-02 00:00:00	\N	1982-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:41	\N
45669	44265	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:41	\N
45670	44266	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:41	\N
45671	44267	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:41	\N
45672	44268	DEPUTE	1973-05-13 00:00:00	\N	1975-04-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:41	\N
45673	44269	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:41	\N
45674	44270	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:41	\N
45675	44271	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:41	\N
45676	44272	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:41	\N
45677	44273	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:41	\N
45678	44274	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:41	\N
45679	44275	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:41	\N
45680	44276	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:41	\N
45681	44277	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:41	\N
45684	44280	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:42	\N
45685	44281	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:42	\N
45686	44282	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:42	2017-08-10 10:56:30
45687	44283	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:42	2017-08-10 10:56:30
45688	44284	VICPDTAN	2005-06-09 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:42	2017-08-10 10:56:30
45689	44285	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:42	\N
45690	44286	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:42	\N
45691	44287	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:42	\N
45692	44288	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:42	\N
45693	44289	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:42	\N
45694	44290	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:42	\N
45695	44291	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:42	\N
45696	44292	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:42	\N
45697	44293	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:42	\N
45698	44294	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:42	\N
45699	44295	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:42	\N
45700	44296	DEPUTE	1997-06-01 00:00:00	\N	2001-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:42	2017-08-10 10:56:31
45701	44297	DEPUTE	2001-04-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:42	2017-08-10 10:56:31
45702	44298	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:42	\N
45703	44299	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:42	\N
45704	44300	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:42	\N
45705	44301	DEPUTE	1997-06-01 00:00:00	\N	1999-12-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:42	\N
45706	44302	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:42	\N
45707	44303	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:42	\N
45708	44304	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:42	\N
45709	44305	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:42	\N
45710	44306	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:42	\N
45711	44307	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:42	\N
45712	44308	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:42	\N
45714	44310	VICPDTAN	2009-10-06 00:00:00	\N	2010-10-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:42	2017-08-10 03:43:00
45715	44311	SECAN	2010-10-05 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:42	2017-08-10 10:56:31
45716	44312	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:42	\N
45717	44313	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:43	\N
45718	44314	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:43	\N
45719	44315	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:43	\N
45720	44316	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:43	\N
45721	44317	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:43	\N
45722	44318	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:43	\N
45723	44319	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:43	\N
47119	45715	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:26	\N
47120	45716	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:26	\N
47121	45717	DEPUTE	1994-11-18 00:00:00	\N	1995-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:26	\N
47122	45718	DEPUTE	1958-12-09 00:00:00	\N	1962-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:26	\N
47123	45719	DEPUTE	1962-12-06 00:00:00	\N	1963-01-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:26	\N
47124	45720	DEPUTE	1967-04-03 00:00:00	\N	1967-05-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:26	\N
47125	45721	DEPUTE	1968-07-11 00:00:00	\N	1968-08-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:26	\N
47126	45722	DEPUTE	1973-04-02 00:00:00	\N	1973-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:26	\N
47127	45723	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:27	\N
47128	45724	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:27	\N
47129	45725	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:27	\N
47130	45726	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:27	\N
47131	45727	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:27	\N
47132	45728	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:27	\N
47133	45729	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:27	\N
47134	45730	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:27	\N
47135	45731	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:27	\N
47136	45732	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:27	\N
47137	45733	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:27	\N
47138	45734	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:27	\N
47139	45735	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:27	\N
47140	45736	DEPUTE	1988-06-13 00:00:00	\N	1990-08-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:27	\N
47141	45737	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:27	\N
47142	45738	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:27	\N
47143	45739	DEPUTE	1992-05-03 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:27	\N
47144	45740	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:27	\N
47145	45741	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:27	\N
47146	45742	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:27	\N
47147	45743	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:27	\N
47148	45744	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:27	\N
47149	45745	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:27	\N
47150	45746	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:27	\N
47151	45747	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:27	\N
47152	45748	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:27	\N
47153	45749	DEPUTE	1981-07-02 00:00:00	\N	1984-04-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:27	\N
47154	45750	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:27	\N
47155	45751	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:27	\N
47156	45752	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:27	\N
47157	45753	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:27	\N
47158	45754	DEPUTE	2007-06-20 00:00:00	\N	2010-12-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:27	2017-08-10 10:56:56
47159	45755	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:27	2017-08-10 10:56:56
47160	45756	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:27	\N
47161	45757	DEPUTE	2000-04-28 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:27	\N
47162	45758	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	\N
47163	45759	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	\N
47164	45760	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	\N
47165	45761	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	\N
47166	45762	DEPUTE	1988-07-29 00:00:00	\N	1991-04-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	\N
47167	45763	DEPUTE	1997-07-05 00:00:00	\N	2000-09-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	\N
47168	45764	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	\N
47169	45765	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	\N
47170	45766	DEPUTE	2002-06-19 00:00:00	\N	2007-04-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	\N
47171	45767	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	\N
47172	45768	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	\N
47173	45769	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	\N
47174	45770	DEPUTE	1997-05-25 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	\N
47175	45771	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	\N
47176	45772	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	2017-08-10 03:43:26
47177	45773	DEPUTE	2010-12-14 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	2017-08-10 03:43:26
47178	45774	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	\N
47179	45775	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	\N
47180	45776	DEPUTE	1995-12-11 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	2017-08-04 03:43:38
47181	45777	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	2017-08-10 10:56:57
47182	45778	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	\N
47183	45779	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	\N
47184	45780	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	\N
47185	45781	DEPUTE	2017-06-21 00:00:00	\N	2020-08-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	\N
47186	45782	DEPUTE	1996-10-01 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	2017-08-04 03:43:38
47187	45783	DEPUTE	1999-10-02 00:00:00	\N	2000-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	2017-08-10 10:56:57
47188	45784	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	\N
47189	45785	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	\N
47190	45786	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	\N
47191	45787	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	\N
47192	45788	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	\N
47193	45789	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	\N
47194	45790	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	\N
47195	45791	DEPUTE	2007-06-20 00:00:00	\N	2008-09-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	\N
47196	45792	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	\N
47197	45793	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	\N
47198	45794	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	\N
47199	45795	DEPUTE	1993-04-02 00:00:00	\N	1993-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	2017-08-09 03:43:34
47200	45796	DEPUTE	1993-12-13 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	2017-08-09 03:43:34
47201	45797	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	\N
47202	45798	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	\N
47203	45799	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	\N
47204	45800	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	\N
47205	45801	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	\N
47206	45802	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	\N
47207	45803	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	\N
47208	45804	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	\N
47209	45805	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:28	\N
47210	45806	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:29	\N
47211	45807	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:29	\N
48699	47295	DEPUTE	1995-11-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	\N
48700	47296	DEPUTE	1976-02-13 00:00:00	\N	1976-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	\N
48701	47297	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	\N
48702	47298	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	\N
48703	47299	DEPUTE	1978-04-02 00:00:00	\N	1980-09-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	\N
48704	47300	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	\N
48705	47301	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	\N
48706	47302	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	\N
48707	47303	DEPUTE	1997-06-01 00:00:00	\N	2000-11-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	\N
48708	47304	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	\N
48709	47305	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	\N
48710	47306	DEPUTE	1997-06-01 00:00:00	\N	2000-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	\N
48711	47307	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	\N
50896	50198	VICPDTREG	2016-01-04 00:00:00	\N	2017-11-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-20 11:29:38	2018-01-25 15:20:23
48713	47309	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	\N
50899	50202	MAIREADJOINT	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 11:36:19	2017-09-20 11:37:39
48715	47311	QUESTAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	2017-08-10 10:57:23
48716	47312	SECAN	2010-10-05 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	2017-08-10 03:43:53
48717	47313	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	\N
50900	50203	VICPDTDPT	2015-12-13 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 11:37:49	2017-09-20 11:42:53
50901	50204	PDTREG	2004-03-29 00:00:00	\N	2012-08-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-20 11:44:53	2017-09-25 11:33:55
48721	47317	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	\N
48722	47318	SECAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	2017-08-10 10:57:23
48723	47319	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	2017-08-10 10:57:23
48724	47320	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	2017-08-10 10:57:23
48725	47321	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	2017-08-10 10:57:23
48726	47322	SECAN	2002-06-26 00:00:00	\N	2004-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	2017-08-10 10:57:23
48727	47323	SECAN	2009-10-06 00:00:00	\N	2010-10-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:17	2017-08-10 10:57:23
48728	47324	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:18	\N
48729	47325	DEPUTE	1993-04-02 00:00:00	\N	1995-09-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:18	\N
48730	47326	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:18	\N
48731	47327	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:18	\N
48732	47328	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:18	\N
48733	47329	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:18	\N
48734	47330	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:18	\N
48735	47331	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:18	\N
48736	47332	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:18	\N
48737	47333	DEPUTE	1986-04-02 00:00:00	\N	1986-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:18	\N
48738	47334	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:18	\N
48739	47335	DEPUTE	1980-10-27 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:18	\N
48740	47336	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:18	\N
48741	47337	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:18	\N
48742	47338	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:18	\N
48743	47339	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:18	\N
48744	47340	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:18	2017-08-10 10:57:24
48745	47341	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:18	\N
48746	47342	DEPUTE	1995-06-18 00:00:00	\N	1995-12-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:18	2017-08-10 10:57:24
48747	47343	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:18	\N
48748	47344	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:18	\N
48749	47345	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:18	\N
48750	47346	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:18	\N
48751	47347	DEPUTE	1980-11-30 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:18	\N
48752	47348	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:18	\N
48753	47349	DEPUTE	1988-06-13 00:00:00	\N	1992-06-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:18	\N
48754	47350	DEPUTE	1987-12-17 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:18	\N
48755	47351	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:18	\N
48756	47352	DEPUTE	1973-04-02 00:00:00	\N	1977-03-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:18	\N
48757	47353	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:18	\N
48758	47354	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:18	\N
48759	47355	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:18	\N
48760	47356	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:18	\N
48761	47357	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:18	\N
48762	47358	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:18	\N
48763	47359	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:18	\N
48764	47360	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:18	\N
48765	47361	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:18	\N
48766	47362	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:18	\N
48767	47363	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:18	\N
48768	47364	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:18	\N
48770	47366	VICPDTAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:18	2017-08-10 10:57:24
48771	47367	VICPDTAN	1998-10-01 00:00:00	\N	1999-02-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:18	2017-08-10 10:57:24
48772	47368	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:19	\N
48773	47369	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:19	\N
48774	47370	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:19	\N
48775	47371	DEPUTE	1999-08-29 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:19	\N
48779	47375	SECAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:19	2017-08-10 10:57:24
48780	47376	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:19	2017-08-10 03:43:54
48781	47377	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:19	2017-08-10 10:57:24
48782	47378	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:19	2017-08-10 10:57:24
48783	47379	SECAN	2003-10-01 00:00:00	\N	2004-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:19	2017-08-10 10:57:24
48784	47380	SECAN	2006-10-04 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:19	2017-08-09 03:44:07
48785	47381	SECAN	2007-06-27 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:19	2017-08-10 03:43:54
48786	47382	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:19	\N
48787	47383	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:19	\N
48788	47384	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:19	\N
48789	47385	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:19	\N
48790	47386	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:19	\N
48791	47387	DEPUTE	2000-09-30 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:19	\N
44237	42833	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:56	\N
44238	42834	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:56	\N
44239	42835	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:56	\N
44240	42836	DEPUTE	2017-06-21 00:00:00	\N	2020-07-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:56	\N
44241	42837	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:56	\N
44242	42838	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:56	\N
44243	42839	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:56	\N
44244	42840	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:56	\N
44245	42841	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:56	\N
44246	42842	DEPUTE	1988-06-13 00:00:00	\N	1993-03-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:56	\N
44247	42843	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:56	\N
44248	42844	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:56	\N
44249	42845	DEPUTE	1998-09-27 00:00:00	\N	1999-02-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:56	\N
44250	42846	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:56	\N
44251	42847	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:57	\N
44252	42848	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:57	\N
44253	42849	DEPUTE	1981-07-25 00:00:00	\N	1986-03-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:57	\N
44254	42850	DEPUTE	1981-07-02 00:00:00	\N	1983-01-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:57	\N
44255	42851	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:57	\N
44256	42852	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:57	\N
44257	42853	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:57	\N
44258	42854	DEPUTE	1970-06-14 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:57	\N
44259	42855	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:57	\N
44260	42856	DEPUTE	1981-07-02 00:00:00	\N	1981-12-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:57	2017-08-10 03:42:35
44261	42857	DEPUTE	1982-01-18 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:57	2017-08-10 03:42:35
44262	42858	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:57	\N
44263	42859	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:57	\N
44264	42860	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:57	\N
44265	42861	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:57	\N
44266	42862	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:57	\N
44267	42863	DEPUTE	1988-06-06 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:57	\N
44268	42864	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:57	\N
44269	42865	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:57	\N
44270	42866	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:57	\N
44271	42867	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:57	\N
44272	42868	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:58	\N
44273	42869	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:58	\N
44274	42870	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:58	\N
44275	42871	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:58	\N
44276	42872	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:58	\N
44277	42873	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:58	\N
44278	42874	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:58	\N
44279	42875	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:58	\N
44280	42876	DEPUTE	1980-10-09 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:58	\N
44281	42877	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:58	\N
44282	42878	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:58	\N
44283	42879	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:58	\N
44284	42880	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:58	\N
44285	42881	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:58	\N
44286	42882	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:58	\N
44287	42883	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:58	\N
44288	42884	DEPUTE	1971-12-05 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:58	\N
44289	42885	DEPUTE	1973-04-02 00:00:00	\N	1977-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:58	\N
44290	42886	DEPUTE	1978-04-03 00:00:00	\N	1978-10-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:58	\N
44291	42887	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:58	\N
44292	42888	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:58	\N
44293	42889	DEPUTE	1992-05-03 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:59	\N
44294	42890	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:59	\N
44295	42891	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:59	\N
44296	42892	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:59	\N
44297	42893	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:59	\N
44298	42894	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:59	\N
44299	42895	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:59	\N
44300	42896	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:59	\N
44301	42897	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:59	\N
44302	42898	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:59	\N
44303	42899	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:59	\N
44304	42900	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:59	\N
44305	42901	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:59	\N
44306	42902	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:59	\N
44307	42903	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:59	\N
44308	42904	DEPUTE	1993-05-02 00:00:00	\N	1995-09-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:59	\N
44309	42905	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:59	\N
44310	42906	DEPUTE	1993-05-02 00:00:00	\N	1995-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:59	\N
44311	42907	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:59	\N
44312	42908	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:59	\N
44313	42909	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:59	\N
44314	42910	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:59	\N
44315	42911	DEPUTE	1995-09-18 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:59	\N
44316	42912	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:59	\N
44317	42913	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:59	\N
44318	42914	DEPUTE	2007-06-20 00:00:00	\N	2012-03-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:59	\N
44319	42915	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:59	\N
44320	42916	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:59	\N
44321	42917	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:59	\N
44322	42918	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:59	\N
44323	42919	DEPUTE	1976-04-09 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:59	\N
44324	42920	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:59	\N
44325	42921	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:59	\N
44326	42922	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:59	\N
44327	42923	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:59	\N
44328	42924	DEPUTE	1981-07-02 00:00:00	\N	1984-08-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:59	\N
44329	42925	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:59	\N
45725	44321	QUESTAN	2004-05-05 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:43	2017-08-10 10:56:31
45726	44322	DEPUTE	1981-07-02 00:00:00	\N	1983-12-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:43	\N
45727	44323	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:43	\N
45728	44324	DEPUTE	1991-02-04 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:43	2017-08-06 03:43:04
45729	44325	DEPUTE	1988-06-13 00:00:00	\N	1990-12-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:43	2017-08-06 03:43:04
45730	44326	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:43	\N
45731	44327	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:43	\N
45732	44328	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:43	\N
45733	44329	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:43	\N
45734	44330	DEPUTE	1978-04-02 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:43	\N
45735	44331	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:43	\N
45736	44332	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:43	\N
45737	44333	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:43	\N
45738	44334	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:43	\N
45739	44335	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:43	\N
45740	44336	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:43	\N
45741	44337	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:43	\N
45742	44338	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:43	\N
45743	44339	DEPUTE	1976-09-28 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:44	\N
45744	44340	DEPUTE	1978-05-06 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:44	\N
45745	44341	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:44	\N
45746	44342	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:44	\N
45747	44343	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:44	2017-08-10 10:56:32
45748	44344	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:44	2017-08-10 10:56:32
45749	44345	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:44	2017-08-11 03:42:47
45750	44346	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:44	2017-08-11 03:42:47
45752	44348	DEPUTE	1970-09-20 00:00:00	\N	1970-10-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:44	2017-08-10 10:56:32
45753	44349	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:44	\N
45754	44350	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:44	\N
45755	44351	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:44	2017-08-11 03:42:47
45756	44352	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:44	\N
45757	44353	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:44	\N
45758	44354	PDTAN	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:44	2017-08-10 10:56:32
45759	44355	PDTAN	1962-12-06 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:44	2017-08-11 11:33:04
45760	44356	PDTAN	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:44	2017-08-11 03:42:47
45761	44357	DEPUTE	1968-07-11 00:00:00	\N	1969-07-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:44	2017-08-10 10:56:32
45762	44358	PDTAN	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:44	2017-08-10 10:56:32
45763	44359	PDTAN	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:44	2017-08-11 03:42:47
45764	44360	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:44	\N
45765	44361	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:44	\N
45766	44362	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:44	\N
45767	44363	DEPUTE	1969-07-21 00:00:00	\N	1970-07-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:44	\N
45768	44364	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:44	\N
45769	44365	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:44	\N
45770	44366	DEPUTE	1968-07-11 00:00:00	\N	1968-08-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:44	\N
45771	44367	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:44	\N
45772	44368	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:44	\N
45773	44369	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:45	\N
45774	44370	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:45	\N
45775	44371	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:45	\N
45776	44372	DEPUTE	1962-12-06 00:00:00	\N	1966-02-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:45	\N
45777	44373	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:45	\N
45778	44374	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:45	\N
45779	44375	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:45	\N
45780	44376	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:45	\N
45781	44377	DEPUTE	1993-04-02 00:00:00	\N	1994-11-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:45	\N
45782	44378	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:45	\N
45783	44379	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:45	\N
45784	44380	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:45	\N
45785	44381	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:45	\N
45786	44382	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:45	\N
45787	44383	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:45	\N
45788	44384	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:45	\N
45789	44385	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:45	\N
45790	44386	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:45	\N
45791	44387	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:45	\N
45792	44388	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:45	\N
45793	44389	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:45	\N
45794	44390	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:45	\N
45795	44391	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:45	\N
45796	44392	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:45	\N
45797	44393	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:45	\N
45798	44394	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:45	\N
45799	44395	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:46	\N
45800	44396	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:46	\N
45801	44397	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:46	\N
45802	44398	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:46	\N
45803	44399	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:46	\N
45804	44400	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:46	\N
45806	44402	SECAN	2012-06-27 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:46	2017-08-10 10:56:33
45807	44403	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:46	2017-08-10 03:43:02
45808	44404	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:46	2017-08-10 03:43:02
45809	44405	DEPUTE	1962-12-06 00:00:00	\N	1966-02-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:46	\N
45810	44406	DEPUTE	1968-07-11 00:00:00	\N	1972-08-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:46	\N
45811	44407	DEPUTE	1973-04-02 00:00:00	\N	1973-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:46	\N
45812	44408	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:46	\N
45813	44409	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:46	\N
45814	44410	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:46	\N
45815	44411	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:46	\N
45816	44412	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:46	\N
45817	44413	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:46	\N
47212	45808	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:29	\N
47213	45809	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:29	\N
47214	45810	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:29	\N
47215	45811	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:29	\N
47216	45812	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:29	\N
47217	45813	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:29	\N
47218	45814	DEPUTE	1988-04-05 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:29	\N
47219	45815	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:29	\N
47220	45816	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:29	\N
47221	45817	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:29	\N
47222	45818	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:29	\N
47223	45819	DEPUTE	2007-06-20 00:00:00	\N	2009-08-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:29	\N
47224	45820	DEPUTE	1985-03-30 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:29	\N
47225	45821	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:29	\N
47226	45822	DEPUTE	1984-08-24 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:29	\N
47227	45823	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:29	\N
47228	45824	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:29	\N
47229	45825	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:29	\N
47230	45826	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:29	\N
47231	45827	DEPUTE	1981-07-25 00:00:00	\N	1986-03-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:29	\N
47232	45828	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:29	\N
47233	45829	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:29	\N
47234	45830	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:29	\N
47235	45831	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:29	\N
47236	45832	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:29	\N
47237	45833	DEPUTE	1997-06-01 00:00:00	\N	1997-12-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:29	\N
47238	45834	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:29	\N
47239	45835	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:29	\N
47240	45836	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:29	\N
47241	45837	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:29	\N
47242	45838	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:29	\N
47243	45839	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:29	\N
47244	45840	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:29	\N
47245	45841	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:29	\N
47246	45842	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:29	\N
47247	45843	DEPUTE	1998-11-29 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:29	\N
47248	45844	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:30	\N
47249	45845	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:30	\N
47250	45846	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:30	\N
47251	45847	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:30	\N
47252	45848	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:30	\N
47253	45849	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:30	\N
47254	45850	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:30	\N
47255	45851	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:30	\N
47256	45852	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:30	\N
47257	45853	DEPUTE	1984-08-20 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:30	\N
47258	45854	DEPUTE	1989-12-04 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:30	\N
47259	45855	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:30	\N
47260	45856	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:30	\N
47261	45857	DEPUTE	2002-06-19 00:00:00	\N	2002-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:30	\N
47262	45858	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:30	\N
47263	45859	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:30	\N
47264	45860	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:30	\N
47265	45861	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:30	\N
47266	45862	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:30	\N
50829	50123	CONSMUNI	2001-03-19 00:00:00	\N	2014-04-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-09-19 16:45:11	2017-09-19 16:45:50
47269	45865	SECAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:30	2017-08-10 10:56:58
47270	45866	SECAN	1988-06-24 00:00:00	\N	1992-10-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:30	2017-08-08 03:43:41
47271	45867	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:30	\N
47272	45868	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:30	\N
47273	45869	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:30	\N
47274	45870	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:30	\N
47275	45871	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:30	\N
47276	45872	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:30	\N
47277	45873	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:30	\N
47278	45874	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:30	\N
47279	45875	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:30	\N
47280	45876	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:30	\N
47281	45877	DEPUTE	1981-07-02 00:00:00	\N	1981-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:30	\N
47282	45878	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:30	\N
47283	45879	DEPUTE	1988-06-13 00:00:00	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:30	\N
47284	45880	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:30	\N
47285	45881	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:30	\N
47286	45882	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:30	\N
47287	45883	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:31	\N
47288	45884	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:31	\N
47289	45885	DEPUTE	1993-04-02 00:00:00	\N	1993-05-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:31	\N
47290	45886	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:31	\N
47291	45887	DEPUTE	1973-04-02 00:00:00	\N	1973-05-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:31	\N
47292	45888	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:31	\N
47293	45889	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:31	2017-08-10 10:56:58
47294	45890	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:31	2017-08-07 03:43:23
47296	45892	VICPDTAN	1992-04-02 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:31	2017-08-10 10:56:58
47297	45893	VICPDTAN	1993-04-07 00:00:00	\N	1993-04-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:31	2017-08-07 03:43:23
47298	45894	VICPDTAN	1997-06-13 00:00:00	\N	1998-03-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:31	2017-08-09 03:43:36
47299	45895	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:31	\N
47300	45896	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:31	\N
47301	45897	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:31	\N
47302	45898	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:31	\N
47303	45899	DEPUTE	1973-04-02 00:00:00	\N	1976-02-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:31	\N
47304	45900	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:31	\N
48792	47388	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:19	\N
48794	47390	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:19	2017-08-09 03:44:07
48795	47391	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:19	2017-08-10 10:57:24
48796	47392	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:19	\N
48797	47393	SECAN	2002-06-26 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:19	2017-08-10 10:57:24
48798	47394	SECAN	2007-06-27 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:19	2017-08-09 03:44:07
48799	47395	SECAN	2012-06-27 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:19	2017-08-10 10:57:24
48800	47396	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:19	2017-08-10 10:57:24
48801	47397	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:19	2017-08-10 10:57:24
48802	47398	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:19	\N
48803	47399	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:19	\N
48804	47400	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:19	\N
48805	47401	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:19	\N
48806	47402	DEPUTE	1997-06-01 00:00:00	\N	1998-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:19	\N
48807	47403	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:19	\N
48808	47404	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:19	\N
48809	47405	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:19	\N
48810	47406	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:19	\N
48811	47407	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:20	\N
48812	47408	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:20	\N
48813	47409	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:20	\N
48814	47410	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:20	\N
48815	47411	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:20	\N
48816	47412	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:20	\N
48817	47413	DEPUTE	1997-06-01 00:00:00	\N	1998-09-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:20	\N
48818	47414	DEPUTE	1978-04-03 00:00:00	\N	1978-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:20	\N
48819	47415	DEPUTE	1958-12-09 00:00:00	\N	1962-05-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:20	\N
48820	47416	DEPUTE	1962-12-06 00:00:00	\N	1963-01-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:20	\N
48821	47417	DEPUTE	1967-04-03 00:00:00	\N	1967-05-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:20	\N
48822	47418	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:20	\N
48823	47419	DEPUTE	1973-04-02 00:00:00	\N	1973-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:20	\N
48824	47420	DEPUTE	1982-01-18 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:20	\N
48825	47421	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:20	\N
48826	47422	DEPUTE	1993-04-02 00:00:00	\N	1995-09-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:20	\N
48827	47423	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:20	\N
48828	47424	DEPUTE	1973-04-02 00:00:00	\N	1975-07-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:20	\N
48829	47425	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:20	\N
48830	47426	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:20	\N
48831	47427	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:20	\N
48832	47428	DEPUTE	2007-07-20 00:00:00	\N	2010-12-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:20	\N
48833	47429	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:20	\N
48834	47430	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:20	\N
48835	47431	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:20	\N
48836	47432	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:20	\N
48837	47433	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:20	\N
48838	47434	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:20	\N
48839	47435	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:20	\N
48840	47436	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:20	\N
48841	47437	DEPUTE	2005-07-03 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:20	\N
48842	47438	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:21	\N
48843	47439	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:21	\N
48844	47440	DEPUTE	2012-07-21 00:00:00	\N	2014-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:21	\N
48845	47441	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:21	\N
48846	47442	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:21	\N
48847	47443	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:21	\N
48848	47444	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:21	\N
48849	47445	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:21	\N
48850	47446	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:21	\N
48851	47447	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:21	\N
48852	47448	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:21	\N
48853	47449	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:21	\N
48854	47450	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:21	\N
48855	47451	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:21	\N
48857	47453	DEPUTE	2004-05-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:21	\N
48858	47454	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:21	\N
48859	47455	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:21	\N
48860	47456	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:21	\N
48862	47458	VICPDTAN	2011-07-07 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:21	2017-08-10 03:43:56
48863	47459	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:21	\N
48864	47460	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:21	2017-08-10 10:57:26
48865	47461	DEPUTE	2009-02-15 00:00:00	\N	2010-12-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:21	2017-08-10 10:57:26
48866	47462	DEPUTE	2012-06-20 00:00:00	\N	2016-01-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:21	\N
48867	47463	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:21	2017-08-10 03:43:56
48868	47464	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:22	\N
48869	47465	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:22	\N
48870	47466	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:22	\N
48871	47467	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:22	\N
48872	47468	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:22	\N
48873	47469	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:22	\N
48874	47470	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:22	\N
48875	47471	DEPUTE	2007-07-20 00:00:00	\N	2010-12-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:22	\N
48876	47472	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:22	\N
48877	47473	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:22	\N
48878	47474	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:22	\N
48879	47475	DEPUTE	2004-05-15 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:22	\N
48880	47476	DEPUTE	2007-04-27 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:22	\N
48881	47477	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:22	\N
48882	47478	DEPUTE	2007-06-20 00:00:00	\N	2010-12-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:22	\N
48883	47479	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:22	\N
48884	47480	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:22	\N
44330	42926	DEPUTE	1988-06-06 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:43:59	\N
44331	42927	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:00	\N
44332	42928	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:00	\N
44333	42929	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:00	\N
44334	42930	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:00	\N
44335	42931	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:00	\N
44336	42932	DEPUTE	1997-06-01 00:00:00	\N	1999-12-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:00	\N
44337	42933	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:00	\N
44338	42934	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:00	\N
44339	42935	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:00	\N
44340	42936	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:00	\N
44341	42937	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:00	\N
44342	42938	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:00	\N
44343	42939	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:00	\N
44344	42940	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:00	\N
44345	42941	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:00	\N
44346	42942	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:00	\N
44347	42943	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:00	\N
44348	42944	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:00	\N
44349	42945	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:00	\N
44350	42946	DEPUTE	2007-07-20 00:00:00	\N	2010-12-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:00	\N
44351	42947	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:00	\N
44352	42948	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:00	\N
44353	42949	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:00	\N
44354	42950	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:00	\N
44355	42951	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:00	\N
44356	42952	DEPUTE	1978-04-03 00:00:00	\N	1978-05-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:00	\N
44357	42953	DEPUTE	1967-05-08 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:00	\N
44358	42954	DEPUTE	1969-07-23 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:00	\N
44359	42955	DEPUTE	1973-04-02 00:00:00	\N	1977-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:00	\N
44360	42956	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:00	\N
44361	42957	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:00	\N
44362	42958	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:00	\N
44363	42959	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:00	\N
44364	42960	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:00	\N
44365	42961	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:00	\N
44366	42962	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:00	\N
44367	42963	DEPUTE	1995-06-09 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:00	\N
44368	42964	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:00	\N
44369	42965	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:00	\N
44370	42966	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:01	\N
44371	42967	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:01	2017-08-10 03:42:37
44372	42968	DEPUTE	2004-12-07 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:01	2017-08-10 03:42:37
44373	42969	DEPUTE	2007-06-20 00:00:00	\N	2009-04-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:01	\N
44374	42970	DEPUTE	1983-04-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:01	\N
44375	42971	DEPUTE	1976-11-14 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:01	2017-08-07 03:42:34
44376	42972	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:01	\N
44377	42973	DEPUTE	1967-04-03 00:00:00	\N	1967-05-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:01	\N
44378	42974	DEPUTE	1968-07-11 00:00:00	\N	1968-08-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:01	\N
44379	42975	DEPUTE	1973-04-02 00:00:00	\N	1973-05-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:01	2017-08-07 03:42:34
44380	42976	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:01	\N
44381	42977	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:01	\N
44382	42978	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:01	\N
44383	42979	DEPUTE	1993-04-02 00:00:00	\N	1995-05-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:01	\N
44384	42980	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:01	\N
44385	42981	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:01	\N
44386	42982	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:01	\N
44387	42983	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:01	\N
44388	42984	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:01	\N
44389	42985	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:01	\N
44390	42986	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:01	\N
44391	42987	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:01	\N
44392	42988	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:01	\N
44393	42989	DEPUTE	2007-06-20 00:00:00	\N	2011-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:01	\N
44394	42990	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:01	\N
44395	42991	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:01	\N
44396	42992	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:01	\N
44397	42993	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:01	\N
44398	42994	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:01	\N
44399	42995	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:01	\N
44400	42996	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:01	\N
44401	42997	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:01	\N
44402	42998	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:01	\N
44403	42999	DEPUTE	1986-04-18 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:01	\N
44404	43000	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:01	\N
44405	43001	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:01	\N
44406	43002	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:01	\N
44407	43003	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:01	\N
44408	43004	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:01	2017-08-07 03:42:35
44409	43005	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:01	2017-08-09 03:42:35
44410	43006	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:01	2017-08-09 03:42:35
44411	43007	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:02	\N
44412	43008	DEPUTE	2002-06-19 00:00:00	\N	2005-07-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:02	\N
44413	43009	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:02	\N
44414	43010	VICPDTAN	1989-04-03 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:02	2017-08-07 03:42:35
44415	43011	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:02	\N
44417	43013	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:02	\N
44419	43015	SECAN	2002-06-26 00:00:00	\N	2003-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:02	2017-08-09 03:42:35
44420	43016	SECAN	2005-10-04 00:00:00	\N	2006-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:02	2017-08-09 03:42:35
44421	43017	QUESTAN	2016-09-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:02	2017-08-10 10:56:07
44422	43018	QUESTAN	2012-06-27 00:00:00	\N	2016-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:02	2017-08-09 03:42:35
45818	44414	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:46	\N
45819	44415	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:46	\N
45820	44416	DEPUTE	2007-06-20 00:00:00	\N	2009-11-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:46	\N
45821	44417	DEPUTE	1983-12-18 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:46	\N
45822	44418	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:46	\N
45825	44421	SECAN	1994-04-02 00:00:00	\N	1995-04-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:46	2017-08-10 03:43:02
45826	44422	SECAN	1996-10-01 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:46	2017-08-08 03:43:10
45827	44423	SECAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:46	2017-08-10 10:56:33
45828	44424	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:46	2017-08-10 10:56:33
45829	44425	SECAN	1999-10-02 00:00:00	\N	2000-04-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:46	2017-08-10 10:56:33
45830	44426	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:47	\N
45831	44427	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:47	\N
45832	44428	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:47	\N
45833	44429	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:47	\N
45834	44430	DEPUTE	1993-04-02 00:00:00	\N	1994-09-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:47	\N
45835	44431	DEPUTE	1988-07-29 00:00:00	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:47	\N
45836	44432	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:47	\N
45837	44433	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:47	\N
45838	44434	DEPUTE	2007-03-05 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:47	\N
45839	44435	DEPUTE	1978-04-03 00:00:00	\N	1979-08-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:47	\N
45840	44436	DEPUTE	1986-04-02 00:00:00	\N	1986-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:47	\N
45841	44437	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:47	\N
45842	44438	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:47	\N
45843	44439	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:47	\N
45844	44440	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:47	\N
45845	44441	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:47	\N
45846	44442	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:47	\N
45847	44443	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:47	\N
45848	44444	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:48	\N
45849	44445	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:48	\N
45850	44446	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:48	\N
45851	44447	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:48	\N
45852	44448	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:48	\N
45853	44449	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:48	\N
45854	44450	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:48	\N
45855	44451	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:48	\N
45856	44452	DEPUTE	1988-06-13 00:00:00	\N	1993-03-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:48	\N
45857	44453	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:48	\N
45858	44454	DEPUTE	1999-12-06 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:48	\N
45859	44455	DEPUTE	1973-05-06 00:00:00	\N	1976-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:48	\N
45860	44456	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:48	\N
45861	44457	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:48	\N
45862	44458	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:48	\N
45863	44459	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:48	\N
45864	44460	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:48	\N
45865	44461	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:48	\N
45866	44462	DEPUTE	1958-12-09 00:00:00	\N	1959-03-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	\N
45867	44463	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	\N
45868	44464	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	\N
45869	44465	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	\N
45870	44466	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	\N
45871	44467	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	\N
45872	44468	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	\N
45873	44469	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	\N
45874	44470	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	\N
45875	44471	DEPUTE	1978-04-02 00:00:00	\N	1980-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	\N
45876	44472	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	\N
45877	44473	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	\N
45878	44474	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	\N
45879	44475	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	\N
45880	44476	DEPUTE	1998-03-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	\N
45881	44477	DEPUTE	2002-06-19 00:00:00	\N	2003-03-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	\N
45882	44478	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	\N
45883	44479	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	\N
45884	44480	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	\N
45885	44481	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	\N
45886	44482	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	\N
45887	44483	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	\N
45888	44484	DEPUTE	1981-07-02 00:00:00	\N	1981-12-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	\N
45889	44485	DEPUTE	1992-05-03 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	\N
45890	44486	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	\N
45891	44487	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	\N
45892	44488	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	\N
45893	44489	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	\N
45894	44490	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	\N
45895	44491	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	\N
45896	44492	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	\N
45897	44493	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	\N
45898	44494	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	\N
45899	44495	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	\N
45900	44496	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	\N
45901	44497	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	\N
45902	44498	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	\N
45903	44499	DEPUTE	1988-06-06 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	2017-08-10 03:43:04
45904	44500	DEPUTE	1991-06-10 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	2017-08-10 03:43:04
45905	44501	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	\N
45906	44502	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	2017-08-10 10:56:35
45907	44503	DEPUTE	2000-10-22 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	2017-08-10 10:56:35
45908	44504	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	\N
45909	44505	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	\N
45910	44506	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	\N
47305	45901	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:31	\N
47306	45902	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:31	\N
47307	45903	DEPUTE	1978-04-03 00:00:00	\N	1978-05-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:31	\N
47308	45904	DEPUTE	1973-04-02 00:00:00	\N	1976-02-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:31	\N
47309	45905	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:31	\N
47310	45906	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:31	\N
47311	45907	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:31	\N
47312	45908	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:31	2017-08-10 10:56:58
47313	45909	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:31	2017-08-10 10:56:58
47314	45910	DEPUTE	1997-05-25 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:31	\N
47315	45911	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:31	\N
47316	45912	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:31	\N
47317	45913	DEPUTE	1996-10-20 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:31	\N
47318	45914	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:31	\N
47319	45915	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:31	\N
47320	45916	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:31	\N
47321	45917	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:31	\N
47322	45918	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:31	\N
47323	45919	DEPUTE	1988-06-06 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:32	\N
47324	45920	DEPUTE	1993-04-02 00:00:00	\N	1996-02-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:32	\N
47325	45921	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:32	\N
47326	45922	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:32	\N
47327	45923	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:32	\N
47328	45924	DEPUTE	2005-07-03 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:32	\N
47329	45925	DEPUTE	2010-04-23 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:32	\N
47330	45926	DEPUTE	2014-12-15 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:32	\N
47331	45927	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:32	\N
47332	45928	DEPUTE	1999-07-23 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:32	\N
47333	45929	DEPUTE	1982-05-24 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:32	\N
47334	45930	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:32	\N
47335	45931	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:32	\N
47336	45932	DEPUTE	1993-05-24 00:00:00	\N	1995-09-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:32	\N
47337	45933	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:32	\N
47338	45934	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:32	\N
47339	45935	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:32	\N
47340	45936	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:32	\N
47341	45937	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:32	2017-08-10 10:56:59
47342	45938	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:32	\N
47343	45939	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:32	\N
47344	45940	DEPUTE	1988-06-13 00:00:00	\N	1990-11-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:32	\N
47345	45941	DEPUTE	1997-06-01 00:00:00	\N	2001-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:32	\N
47346	45942	PDTAN	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:32	2017-08-10 10:56:59
47347	45943	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:32	\N
47348	45944	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:32	\N
47349	45945	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:32	\N
47350	45946	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:32	\N
47351	45947	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:32	\N
47352	45948	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:32	\N
47353	45949	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:32	\N
47354	45950	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:33	\N
47355	45951	DEPUTE	1974-09-29 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:33	2017-08-10 03:43:28
47356	45952	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:33	\N
47357	45953	DEPUTE	1968-07-11 00:00:00	\N	1968-08-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:33	2017-08-10 03:43:28
47358	45954	DEPUTE	1969-10-19 00:00:00	\N	1971-03-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:33	2017-08-10 03:43:28
47359	45955	DEPUTE	1973-04-02 00:00:00	\N	1973-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:33	2017-08-10 03:43:28
47360	45956	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:33	\N
47361	45957	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:33	\N
47362	45958	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:33	\N
50830	50124	MAIRE	2001-03-18 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2017-09-19 16:46:42	2017-09-19 16:47:03
47364	45960	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:33	\N
47365	45961	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:33	\N
47366	45962	VICPDTAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:33	2017-08-10 03:43:28
47367	45963	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:33	\N
47368	45964	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:33	\N
47369	45965	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:33	\N
47370	45966	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:33	\N
47371	45967	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:33	\N
47372	45968	DEPUTE	1988-06-13 00:00:00	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:33	\N
47373	45969	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:33	\N
47374	45970	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:33	\N
47375	45971	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:33	\N
47376	45972	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:33	\N
47377	45973	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:33	\N
47378	45974	DEPUTE	1988-06-06 00:00:00	\N	1991-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:33	\N
47379	45975	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:33	\N
47380	45976	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:33	\N
47381	45977	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:33	\N
47382	45978	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:33	\N
47383	45979	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:33	\N
47384	45980	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:34	\N
47386	45982	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:34	\N
47387	45983	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:34	2017-08-10 10:56:59
47388	45984	SECAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:34	2017-08-10 10:56:59
47389	45985	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:34	\N
47390	45986	DEPUTE	2001-11-20 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:34	\N
47391	45987	DEPUTE	1992-05-03 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:34	\N
47392	45988	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:34	\N
47394	45990	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:34	\N
47396	45992	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:34	\N
47397	45993	VICPDTAN	1994-04-02 00:00:00	\N	1995-05-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:34	2017-08-10 10:57:00
48885	47481	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:23	\N
48886	47482	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:23	\N
48887	47483	DEPUTE	2008-09-15 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:23	2017-08-10 10:57:27
48888	47484	DEPUTE	2007-06-20 00:00:00	\N	2007-11-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:23	2017-08-10 10:57:27
48889	47485	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:23	\N
48890	47486	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:23	\N
48891	47487	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:23	\N
48892	47488	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:23	\N
48893	47489	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:23	\N
48894	47490	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:23	\N
48895	47491	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:23	\N
48896	47492	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:23	\N
48897	47493	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:23	\N
48898	47494	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:23	\N
48899	47495	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:23	\N
48900	47496	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:23	\N
48901	47497	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:23	\N
48902	47498	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:23	\N
48903	47499	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:23	\N
48904	47500	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:23	2017-08-07 03:43:53
48905	47501	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:23	2017-08-10 10:57:27
48906	47502	SECAN	2008-10-01 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:23	2017-08-07 03:43:53
48907	47503	SECAN	2012-06-27 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:23	2017-08-10 10:57:27
48908	47504	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:23	2017-08-10 10:57:27
48909	47505	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:23	2017-08-10 03:43:57
48910	47506	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:24	\N
48911	47507	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:24	\N
48912	47508	DEPUTE	2017-06-21 00:00:00	\N	2020-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:24	\N
48913	47509	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:24	\N
48914	47510	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:24	\N
48915	47511	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:24	\N
48916	47512	DEPUTE	2017-06-21 00:00:00	\N	2020-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:24	\N
48917	47513	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:24	\N
48918	47514	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:24	\N
48919	47515	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:24	\N
48920	47516	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:24	\N
48921	47517	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:24	\N
48922	47518	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:24	\N
48923	47519	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:24	\N
48924	47520	DEPUTE	2007-07-20 00:00:00	\N	2010-12-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:24	\N
48925	47521	DEPUTE	2004-07-05 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:24	\N
48926	47522	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:24	\N
48927	47523	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:24	\N
48928	47524	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:24	\N
48929	47525	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:24	\N
48930	47526	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:25	\N
48931	47527	DEPUTE	2017-06-21 00:00:00	\N	2017-12-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:25	2017-12-20 03:43:58
48932	47528	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:25	\N
48933	47529	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:25	\N
48934	47530	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:25	\N
48935	47531	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:25	\N
48936	47532	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:25	\N
48937	47533	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:25	\N
48938	47534	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:25	\N
48939	47535	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:25	\N
48940	47536	DEPUTE	2008-04-19 00:00:00	\N	2010-08-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:25	\N
48941	47537	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:25	\N
48942	47538	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:25	\N
48943	47539	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:25	\N
48944	47540	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:25	\N
48945	47541	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:25	\N
48946	47542	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:25	\N
48947	47543	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:25	\N
48948	47544	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:25	\N
48949	47545	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:25	\N
48950	47546	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:25	\N
48951	47547	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:25	\N
48952	47548	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:25	\N
48953	47549	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:25	\N
48954	47550	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:25	\N
48955	47551	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:25	\N
48956	47552	DEPUTE	2017-06-21 00:00:00	\N	2020-08-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:25	\N
48957	47553	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:25	\N
48958	47554	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:25	\N
48959	47555	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:25	\N
48960	47556	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:25	\N
52700	52237	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
48961	47557	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:25	\N
48962	47558	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:25	\N
48963	47559	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:25	\N
48964	47560	DEPUTE	2006-06-27 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:25	\N
48965	47561	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:25	\N
48966	47562	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:25	\N
48967	47563	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:25	\N
48968	47564	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:25	\N
48969	47565	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:25	\N
48970	47566	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:25	\N
48971	47567	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:26	\N
48972	47568	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:26	\N
48973	47569	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:26	\N
48974	47570	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:26	\N
48975	47571	DEPUTE	2007-06-20 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:26	\N
48976	47572	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:26	\N
48977	47573	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:26	\N
48978	47574	DEPUTE	2004-05-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:26	\N
44426	43022	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:02	\N
50784	50077	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-08 23:16:27	\N
44428	43024	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:02	\N
44429	43025	DEPUTE	2007-06-20 00:00:00	\N	2011-12-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:02	\N
44430	43026	VICPDTAN	1997-06-12 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:02	2017-08-10 10:56:07
44431	43027	VICPDTAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:02	2017-08-10 10:56:07
44432	43028	VICPDTAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:02	2017-08-10 03:42:38
44433	43029	VICPDTAN	2000-10-02 00:00:00	\N	2001-08-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:02	2017-08-10 03:42:38
44434	43030	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:02	\N
44435	43031	DEPUTE	2001-01-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:02	\N
44436	43032	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:02	\N
44437	43033	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:02	\N
44438	43034	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:02	\N
44439	43035	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:03	\N
50785	50078	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-08 23:16:27	\N
50786	50079	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-08 23:16:27	\N
44442	43038	VICPDTAN	1988-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:03	2017-08-10 10:56:07
44443	43039	VICPDTAN	1988-06-24 00:00:00	\N	1991-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:03	2017-08-07 03:42:36
44444	43040	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:03	\N
44445	43041	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:03	\N
44446	43042	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:03	\N
44447	43043	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:03	\N
44448	43044	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:03	\N
44449	43045	DEPUTE	1968-07-11 00:00:00	\N	1971-02-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:03	\N
44450	43046	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:03	\N
44451	43047	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:03	\N
44452	43048	DEPUTE	1978-04-03 00:00:00	\N	1978-11-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:03	\N
44453	43049	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:03	\N
50787	50080	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-09-08 23:16:53	\N
44455	43051	QUESTAN	1988-06-24 00:00:00	\N	1990-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:03	2017-08-10 10:56:08
44456	43052	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:03	\N
44457	43053	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:03	\N
44458	43054	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:03	\N
44459	43055	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:03	\N
44460	43056	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:03	\N
44461	43057	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:03	\N
44462	43058	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:03	\N
44463	43059	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:03	\N
44464	43060	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:03	\N
44466	43062	VICPDTAN	1996-10-01 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:04	2017-08-07 03:42:36
44467	43063	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:04	\N
44468	43064	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:04	\N
44469	43065	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:04	\N
44470	43066	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:04	\N
44471	43067	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:04	\N
44472	43068	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:04	\N
44473	43069	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:04	\N
44474	43070	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:04	\N
44475	43071	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:04	\N
44476	43072	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:04	\N
44477	43073	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:04	\N
44478	43074	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:04	\N
44479	43075	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:04	\N
44480	43076	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:04	\N
44481	43077	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:04	\N
44482	43078	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:04	\N
44483	43079	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:04	\N
44484	43080	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:04	\N
44485	43081	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:04	\N
44486	43082	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:04	\N
44487	43083	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:04	\N
44488	43084	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:04	\N
44489	43085	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:05	2017-08-10 10:56:09
44490	43086	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:05	\N
44491	43087	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:05	\N
44492	43088	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:05	\N
44493	43089	DEPUTE	1996-10-01 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:05	2017-08-10 10:56:09
44494	43090	DEPUTE	1968-07-11 00:00:00	\N	1972-04-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:05	\N
44495	43091	DEPUTE	1981-07-02 00:00:00	\N	1983-11-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:05	\N
44497	43093	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:05	2017-08-10 03:42:39
44498	43094	SECAN	1994-04-02 00:00:00	\N	1995-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:05	2017-08-10 03:42:39
44423	43019	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:02	\N
44424	43020	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:02	\N
44425	43021	DEPUTE	1968-07-11 00:00:00	\N	1969-09-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:02	\N
44499	43095	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:05	\N
44500	43096	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:05	\N
44501	43097	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:05	\N
44502	43098	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:05	\N
44503	43099	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:05	\N
44504	43100	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:05	\N
44505	43101	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:05	\N
44506	43102	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:05	\N
44507	43103	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:05	\N
44508	43104	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:05	\N
44509	43105	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:05	\N
44511	43107	QUESTAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:05	2017-08-10 10:56:09
44512	43108	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:05	\N
44513	43109	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:05	\N
44514	43110	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:05	\N
44515	43111	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:06	\N
33725	32322	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-06-29 11:32:09	\N
45911	44507	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	\N
45912	44508	DEPUTE	1986-09-30 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	\N
45913	44509	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:49	\N
45914	44510	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:50	\N
45915	44511	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:50	\N
45916	44512	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:50	\N
45917	44513	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:50	\N
45918	44514	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:50	\N
45919	44515	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:50	\N
45920	44516	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:50	\N
45921	44517	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:50	\N
45922	44518	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:50	\N
45923	44519	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:50	\N
45924	44520	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:50	\N
45925	44521	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:50	\N
45926	44522	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:50	\N
45927	44523	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:50	\N
45928	44524	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:50	\N
45929	44525	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:50	\N
45930	44526	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:50	\N
45931	44527	DEPUTE	1995-09-24 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:50	\N
45932	44528	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:50	\N
45933	44529	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:50	\N
45934	44530	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:50	\N
45935	44531	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:50	\N
45936	44532	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:50	\N
45937	44533	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:50	\N
45938	44534	DEPUTE	2002-06-19 00:00:00	\N	2002-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:50	\N
45939	44535	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:50	\N
45940	44536	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:50	\N
45941	44537	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:50	\N
45942	44538	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:50	\N
45943	44539	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:50	\N
45944	44540	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:50	\N
45945	44541	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:50	\N
45946	44542	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:50	\N
50819	50112	CONSDPT	2001-03-19 00:00:00	\N	2004-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-09-19 16:18:59	2017-09-19 16:20:42
45949	44545	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:50	\N
45950	44546	VICPDTAN	1987-04-02 00:00:00	\N	1988-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:50	2017-08-09 03:43:08
45951	44547	SECAN	1991-04-02 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:50	2017-08-08 03:43:12
45952	44548	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:50	\N
45953	44549	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:50	\N
45954	44550	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:50	\N
45955	44551	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:50	\N
45956	44552	DEPUTE	1997-06-01 00:00:00	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:50	\N
45957	44553	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:50	\N
45958	44554	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:50	\N
45959	44555	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:50	\N
45960	44556	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:51	\N
45961	44557	DEPUTE	1981-07-02 00:00:00	\N	1982-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:51	\N
45962	44558	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:51	\N
45963	44559	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:51	\N
45964	44560	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:51	\N
45965	44561	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:51	\N
45966	44562	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:51	\N
45967	44563	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:51	\N
45968	44564	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:51	\N
45969	44565	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:51	\N
45970	44566	DEPUTE	1995-12-11 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:51	\N
45971	44567	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:51	\N
45972	44568	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:51	\N
45973	44569	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:51	\N
45974	44570	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:51	2017-08-11 03:42:51
45975	44571	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:51	\N
45976	44572	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:51	\N
45977	44573	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:51	\N
45978	44574	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:51	\N
45979	44575	DEPUTE	1993-04-02 00:00:00	\N	1996-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:51	2017-08-11 03:42:51
45980	44576	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:51	\N
45981	44577	DEPUTE	1981-07-02 00:00:00	\N	1985-08-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:51	\N
45982	44578	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:51	\N
45985	44581	VICPDTAN	1991-04-02 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:51	2017-08-10 10:56:36
45986	44582	VICPDTAN	1998-10-28 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:51	2017-08-10 10:56:36
45987	44583	VICPDTAN	1999-10-01 00:00:00	\N	2000-03-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:51	2017-08-10 10:56:36
45988	44584	PDTAN	2000-03-29 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:51	2017-08-10 10:56:36
45989	44585	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:51	\N
45990	44586	DEPUTE	1981-07-22 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:51	\N
45991	44587	DEPUTE	1986-09-30 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:51	\N
45992	44588	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:51	\N
45993	44589	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:51	\N
45994	44590	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:51	\N
45995	44591	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:51	\N
45996	44592	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:51	\N
45997	44593	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:51	\N
45998	44594	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:51	\N
45999	44595	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:51	\N
46000	44596	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:51	\N
46001	44597	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:51	\N
46002	44598	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:51	\N
47398	45994	VICPDTAN	1993-04-14 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:34	2017-08-10 10:57:00
47399	45995	VICPDTAN	2005-10-04 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:34	2017-08-10 10:57:00
47400	45996	VICPDTAN	2002-06-26 00:00:00	\N	2005-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:34	2017-08-09 03:43:38
47401	45997	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:34	\N
47402	45998	DEPUTE	1980-11-30 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:34	\N
47403	45999	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:34	\N
47404	46000	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:34	\N
47405	46001	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:34	\N
47406	46002	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:34	\N
47407	46003	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:34	\N
47408	46004	DEPUTE	1986-04-02 00:00:00	\N	1986-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:34	\N
47409	46005	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:34	\N
47410	46006	DEPUTE	1969-09-21 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:34	\N
47411	46007	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:34	\N
47412	46008	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:34	\N
47413	46009	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:34	\N
47414	46010	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:35	\N
47415	46011	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:35	\N
47416	46012	DEPUTE	1985-09-21 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:35	\N
47417	46013	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:35	\N
47418	46014	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:35	\N
47419	46015	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:35	\N
47420	46016	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:35	\N
47421	46017	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:35	\N
47422	46018	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:35	\N
47423	46019	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:35	\N
47424	46020	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:35	\N
47425	46021	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:35	\N
47426	46022	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:35	\N
47427	46023	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:35	\N
47428	46024	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:35	\N
47429	46025	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:35	\N
47430	46026	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:35	\N
47431	46027	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:35	\N
47432	46028	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:35	\N
47433	46029	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:36	\N
47434	46030	DEPUTE	1994-11-27 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:36	\N
47435	46031	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:36	\N
47436	46032	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:36	\N
47437	46033	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:36	\N
47438	46034	DEPUTE	1993-04-02 00:00:00	\N	1995-09-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:36	\N
47439	46035	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:36	\N
47440	46036	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:36	\N
47441	46037	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:36	\N
47442	46038	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:36	\N
47443	46039	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:36	\N
47444	46040	DEPUTE	1973-04-02 00:00:00	\N	1974-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:36	\N
47445	46041	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:36	\N
47446	46042	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:36	\N
47447	46043	DEPUTE	1993-04-02 00:00:00	\N	1994-08-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:36	\N
47448	46044	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:36	\N
47449	46045	DEPUTE	2011-07-30 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:36	\N
47450	46046	DEPUTE	1993-04-02 00:00:00	\N	1994-11-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:36	2017-08-10 10:57:01
47451	46047	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:36	2017-08-10 10:57:01
47452	46048	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:36	\N
47453	46049	DEPUTE	1995-09-13 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:36	2017-08-10 10:57:01
47454	46050	SECAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:36	2017-08-10 10:57:01
47455	46051	DEPUTE	2000-04-28 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:36	\N
47456	46052	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:37	\N
47457	46053	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:37	\N
47458	46054	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:37	\N
50831	50125	VICPDTDPT	2015-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2017-09-19 16:49:45	2017-09-19 16:50:01
47460	46056	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:37	2017-08-10 10:57:01
47461	46057	DEPUTE	1995-09-17 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:37	2017-08-10 10:57:01
47462	46058	VICPDTAN	1988-06-24 00:00:00	\N	1989-04-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:37	2017-08-09 03:43:40
47463	46059	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:37	\N
47464	46060	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:37	\N
47465	46061	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:37	\N
47467	46063	SECAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:37	2017-08-10 03:43:31
47468	46064	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:37	2017-08-10 10:57:02
47469	46065	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:37	2017-08-10 10:57:02
47470	46066	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:37	2017-08-10 03:43:31
47471	46067	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:37	\N
47472	46068	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:37	\N
47473	46069	DEPUTE	1988-03-10 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:37	\N
47474	46070	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:37	\N
47475	46071	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:37	\N
47478	46074	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:37	\N
47479	46075	SECAN	2004-10-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:37	2017-08-10 10:57:02
47480	46076	SECAN	2009-10-06 00:00:00	\N	2010-10-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:37	2017-08-10 10:57:02
47481	46077	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:37	\N
47482	46078	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:37	\N
47483	46079	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:37	\N
47484	46080	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:37	\N
47485	46081	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:37	\N
47486	46082	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:37	\N
47487	46083	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:37	\N
47488	46084	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:37	\N
47489	46085	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:37	\N
47490	46086	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:37	\N
48979	47575	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:26	\N
48980	47576	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:26	\N
48982	47578	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:26	\N
48983	47579	SECAN	2012-06-27 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:26	2017-08-10 10:57:28
48984	47580	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:26	2017-08-10 10:57:28
48985	47581	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:26	\N
48986	47582	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:26	\N
48987	47583	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:26	\N
48988	47584	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:26	\N
48989	47585	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:26	\N
48990	47586	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:26	\N
48991	47587	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:26	\N
48992	47588	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:26	\N
48994	47590	DEPUTE	2012-06-17 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:26	2017-08-10 10:57:29
48996	47592	SECAN	2007-06-27 00:00:00	\N	2011-07-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:26	2017-08-10 10:57:29
48997	47593	SECAN	2013-10-01 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:26	2017-08-10 03:43:59
48998	47594	DEPUTE	2011-07-30 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:26	\N
48999	47595	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:26	\N
49000	47596	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:26	\N
49001	47597	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:26	\N
49002	47598	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:26	\N
49003	47599	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:26	\N
49004	47600	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:26	\N
49005	47601	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:26	\N
49006	47602	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:26	\N
49007	47603	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:26	\N
49008	47604	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:26	2017-08-10 03:43:59
49009	47605	DEPUTE	2005-09-12 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:26	2017-08-10 10:57:29
49010	47606	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:26	\N
49011	47607	DEPUTE	2002-06-25 00:00:00	\N	2002-06-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:26	2017-08-10 10:57:29
49012	47608	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:26	\N
49013	47609	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:27	\N
49014	47610	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:27	\N
49015	47611	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:27	\N
49016	47612	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:27	\N
49017	47613	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:27	\N
49018	47614	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:27	\N
49019	47615	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:27	\N
49020	47616	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:27	\N
49021	47617	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:27	\N
49022	47618	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:27	\N
49023	47619	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:27	\N
49024	47620	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:27	\N
49025	47621	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:27	\N
49026	47622	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:27	\N
49027	47623	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:27	\N
49028	47624	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:27	\N
49029	47625	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:27	2017-08-10 10:57:29
49030	47626	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:27	2017-08-10 03:43:59
49031	47627	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:27	\N
49032	47628	SECAN	2011-07-07 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:27	2017-08-10 10:57:29
49033	47629	SECAN	2012-06-27 00:00:00	\N	2014-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:27	2017-08-10 10:57:29
49034	47630	SECAN	2014-10-01 00:00:00	\N	2015-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:27	2017-08-10 10:57:29
49035	47631	SECAN	2015-10-01 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:27	2017-08-10 10:57:29
49036	47632	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:27	\N
49037	47633	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:27	\N
49038	47634	DEPUTE	2002-07-19 00:00:00	\N	2004-09-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:27	\N
49039	47635	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:27	\N
49040	47636	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:27	\N
49041	47637	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:27	\N
49042	47638	DEPUTE	2002-12-16 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:27	\N
49043	47639	DEPUTE	2007-06-20 00:00:00	\N	2008-04-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:27	2017-08-10 10:57:30
49044	47640	DEPUTE	2010-08-05 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:27	2017-08-10 10:57:30
49045	47641	DEPUTE	2008-04-19 00:00:00	\N	2010-08-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:28	\N
49046	47642	DEPUTE	2003-06-25 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:28	\N
49047	47643	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:28	\N
49048	47644	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:28	\N
49049	47645	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:28	\N
49050	47646	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:28	\N
49051	47647	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:28	\N
49052	47648	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:28	\N
49053	47649	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:28	\N
49054	47650	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:28	\N
49055	47651	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:28	\N
49056	47652	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:28	\N
49057	47653	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:28	\N
49058	47654	DEPUTE	2004-03-30 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:28	\N
49059	47655	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:28	\N
49060	47656	DEPUTE	2004-05-01 00:00:00	\N	2005-08-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:28	\N
49061	47657	DEPUTE	2010-12-15 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:28	\N
49062	47658	DEPUTE	2004-05-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:28	\N
49063	47659	DEPUTE	2007-07-20 00:00:00	\N	2009-02-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:28	2017-08-10 10:57:30
49064	47660	DEPUTE	2010-12-15 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:28	2017-08-10 10:57:30
49065	47661	DEPUTE	2004-05-01 00:00:00	\N	2005-07-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:28	\N
49066	47662	DEPUTE	2010-04-23 00:00:00	\N	2010-12-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:28	\N
49067	47663	DEPUTE	2004-05-01 00:00:00	\N	2005-07-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:28	\N
49068	47664	DEPUTE	2007-07-20 00:00:00	\N	2010-12-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:28	\N
49069	47665	DEPUTE	2007-07-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:28	\N
49070	47666	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:28	\N
49071	47667	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:28	\N
44516	43112	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:06	\N
44517	43113	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:06	\N
44518	43114	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:06	\N
44519	43115	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:06	\N
44520	43116	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:06	\N
44521	43117	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:06	\N
44522	43118	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:06	\N
44523	43119	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:06	\N
44524	43120	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:06	\N
44525	43121	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:06	\N
44526	43122	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:06	\N
44527	43123	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:06	\N
44528	43124	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:06	\N
44529	43125	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:06	\N
44530	43126	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:06	\N
44531	43127	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:06	\N
44532	43128	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:06	\N
44533	43129	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:06	\N
44534	43130	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:06	\N
44535	43131	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:06	\N
44536	43132	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:06	\N
44537	43133	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:06	\N
44538	43134	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:06	\N
44539	43135	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:07	\N
44540	43136	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:07	\N
44541	43137	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:07	\N
44542	43138	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:07	\N
44543	43139	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:07	\N
44544	43140	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:07	\N
44545	43141	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:07	\N
44546	43142	DEPUTE	1986-09-30 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:07	\N
44547	43143	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:07	\N
44548	43144	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:07	\N
44549	43145	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:07	\N
44550	43146	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:07	\N
44551	43147	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:07	\N
44552	43148	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:07	\N
44553	43149	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:07	\N
44554	43150	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:07	\N
44555	43151	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:07	\N
44556	43152	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:07	\N
44557	43153	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:07	\N
44558	43154	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:07	\N
44559	43155	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:07	\N
44560	43156	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:07	\N
44561	43157	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:08	\N
44562	43158	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:08	\N
44563	43159	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:08	\N
44564	43160	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:08	\N
44565	43161	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:08	\N
44566	43162	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:08	\N
44567	43163	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:08	\N
44568	43164	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:08	\N
44569	43165	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:08	\N
44570	43166	DEPUTE	1997-06-01 00:00:00	\N	1999-03-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:08	\N
44571	43167	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:08	\N
44572	43168	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:08	\N
44573	43169	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:08	\N
44574	43170	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:08	\N
44575	43171	DEPUTE	1990-01-18 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:08	\N
44576	43172	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:08	\N
44577	43173	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:08	2017-08-10 10:56:11
44578	43174	DEPUTE	2002-06-19 00:00:00	\N	2002-12-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:08	2017-08-10 10:56:11
44579	43175	DEPUTE	2003-03-24 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:08	2017-08-10 10:56:11
44580	43176	DEPUTE	1997-06-12 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:08	2017-08-10 10:56:11
44581	43177	DEPUTE	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:08	2017-08-10 10:56:11
44582	43178	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:08	\N
44583	43179	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:08	\N
44584	43180	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:08	\N
44585	43181	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:08	\N
44586	43182	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:08	\N
44588	43184	DEPUTE	1988-06-13 00:00:00	\N	1988-11-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	\N
44589	43185	SECAN	1986-04-04 00:00:00	\N	1987-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	2017-08-10 10:56:11
44590	43186	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	\N
44591	43187	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	\N
44592	43188	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	\N
44593	43189	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	\N
44594	43190	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	\N
44595	43191	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	2017-08-10 10:56:11
44596	43192	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	2017-08-10 10:56:11
44597	43193	QUESTAN	2007-06-27 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	2017-08-10 10:56:11
44598	43194	QUESTAN	2012-06-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	2017-08-10 10:56:11
44599	43195	DEPUTE	1971-12-05 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	\N
44600	43196	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	\N
44601	43197	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	\N
44602	43198	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	\N
44603	43199	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	\N
44604	43200	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	\N
44605	43201	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	\N
44606	43202	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	\N
44608	43204	SECAN	1986-04-04 00:00:00	\N	1987-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	2017-08-06 03:42:42
46003	44599	DEPUTE	1973-04-03 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:52	\N
46004	44600	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:52	\N
46005	44601	DEPUTE	1959-03-07 00:00:00	\N	1960-03-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:52	\N
46006	44602	DEPUTE	1962-12-06 00:00:00	\N	1963-01-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:52	\N
46007	44603	DEPUTE	1967-04-02 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:52	\N
46008	44604	DEPUTE	1968-07-11 00:00:00	\N	1972-08-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:52	\N
46009	44605	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:52	\N
46010	44606	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:52	\N
46011	44607	DEPUTE	1981-07-23 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:52	\N
46012	44608	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:52	\N
46013	44609	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:52	\N
46014	44610	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:52	\N
46015	44611	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:52	\N
46016	44612	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:52	\N
46017	44613	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:52	\N
46018	44614	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:52	\N
46019	44615	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:52	\N
46020	44616	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:52	\N
46021	44617	DEPUTE	1986-04-02 00:00:00	\N	1988-03-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:52	\N
46022	44618	DEPUTE	2002-07-19 00:00:00	\N	2005-01-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:52	2017-08-04 03:43:10
46023	44619	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:52	\N
46024	44620	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:52	\N
46025	44621	DEPUTE	2005-07-03 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:52	2017-08-04 03:43:10
46026	44622	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:52	\N
46027	44623	DEPUTE	1998-04-06 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:52	\N
46028	44624	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:52	\N
46029	44625	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:52	\N
46030	44626	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:52	\N
46031	44627	DEPUTE	1992-05-03 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:52	\N
46032	44628	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:52	\N
46033	44629	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:52	\N
46034	44630	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:52	\N
46035	44631	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:52	\N
46036	44632	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:52	\N
46037	44633	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:52	\N
46038	44634	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:52	\N
46039	44635	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:53	\N
46040	44636	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:53	\N
46041	44637	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:53	\N
46042	44638	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:53	\N
46043	44639	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:53	\N
46044	44640	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:53	\N
46045	44641	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:53	\N
46046	44642	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:53	\N
46047	44643	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:53	\N
46048	44644	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:53	\N
46049	44645	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:53	\N
46050	44646	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:53	\N
46051	44647	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:53	\N
46052	44648	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:53	\N
46053	44649	DEPUTE	2001-11-24 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:53	\N
46054	44650	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:53	\N
46055	44651	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:53	\N
46056	44652	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:53	\N
46057	44653	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:53	\N
46058	44654	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:53	\N
46059	44655	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:53	\N
46060	44656	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:53	\N
46061	44657	DEPUTE	2012-06-20 00:00:00	\N	2014-04-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:53	\N
46062	44658	DEPUTE	1996-11-27 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:54	\N
46063	44659	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:54	\N
46064	44660	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:54	\N
46065	44661	DEPUTE	2007-06-20 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:54	\N
46066	44662	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:54	\N
46067	44663	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:54	\N
46068	44664	DEPUTE	1994-02-08 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:54	\N
46069	44665	DEPUTE	2000-04-28 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:54	\N
46070	44666	DEPUTE	1981-07-02 00:00:00	\N	1981-12-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:54	\N
46071	44667	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:54	\N
46072	44668	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:54	\N
46073	44669	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:54	\N
46074	44670	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:54	\N
46075	44671	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:54	\N
46076	44672	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:54	\N
46077	44673	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:54	\N
46078	44674	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:54	\N
46079	44675	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:54	\N
46080	44676	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:54	\N
46081	44677	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:54	\N
46082	44678	DEPUTE	1988-07-29 00:00:00	\N	1988-11-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:54	\N
46083	44679	DEPUTE	1981-07-02 00:00:00	\N	1985-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:54	\N
46084	44680	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:54	\N
46085	44681	DEPUTE	1981-07-02 00:00:00	\N	1985-12-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:54	\N
46086	44682	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:55	\N
46090	44686	VICPDTAN	1995-06-15 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:55	2017-08-10 03:43:07
46091	44687	VICPDTAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:55	2017-08-10 10:56:37
46092	44688	QUESTAN	2004-05-05 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:55	2017-08-10 10:56:38
46093	44689	QUESTAN	2002-06-26 00:00:00	\N	2004-05-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:55	2017-08-10 10:56:38
46095	44691	SECAN	1992-04-02 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:55	2017-08-10 03:43:07
50819	50113	VICPDTGEN	2004-04-03 00:00:00	\N	2008-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-09-19 16:20:11	2017-09-19 16:21:23
47491	46087	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:37	\N
47492	46088	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:38	\N
47493	46089	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:38	\N
47494	46090	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:38	\N
47495	46091	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:38	\N
47496	46092	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:38	\N
47497	46093	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:38	\N
47498	46094	DEPUTE	1988-06-13 00:00:00	\N	1992-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:38	\N
47499	46095	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:38	\N
47500	46096	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:38	\N
47501	46097	DEPUTE	1976-05-09 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:38	2017-08-10 03:43:31
47502	46098	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:38	\N
47503	46099	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:38	\N
47504	46100	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:38	\N
47505	46101	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:38	\N
47506	46102	DEPUTE	1973-04-02 00:00:00	\N	1973-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:38	2017-08-10 03:43:31
47507	46103	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:38	\N
47508	46104	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:38	\N
47509	46105	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:38	\N
47510	46106	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:38	\N
47511	46107	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:38	\N
47512	46108	DEPUTE	1975-06-15 00:00:00	\N	1976-09-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:38	\N
47513	46109	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:38	\N
47514	46110	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:38	\N
47515	46111	DEPUTE	1993-04-02 00:00:00	\N	1995-07-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:38	\N
47516	46112	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:38	\N
47517	46113	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:38	\N
47518	46114	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:38	\N
47519	46115	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:38	\N
47520	46116	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:38	\N
47521	46117	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:38	\N
47522	46118	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:38	\N
50832	50126	CONSMUNI	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2017-09-19 16:55:47	2017-09-19 16:56:24
47524	46120	SECAN	2002-06-26 00:00:00	\N	2004-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:38	2017-08-10 10:57:02
47525	46121	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:38	\N
47526	46122	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:38	\N
47527	46123	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:38	\N
47528	46124	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:38	\N
47529	46125	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:38	\N
47530	46126	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:38	\N
47531	46127	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:38	\N
47532	46128	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:38	\N
47533	46129	DEPUTE	1962-12-06 00:00:00	\N	1964-12-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:38	\N
47534	46130	DEPUTE	2011-05-06 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:38	\N
47535	46131	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:38	\N
47536	46132	DEPUTE	1995-12-10 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:38	\N
47537	46133	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:39	\N
47538	46134	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:39	\N
47539	46135	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:39	\N
50832	50127	MAIRE	2008-03-16 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2017-09-19 16:55:54	2017-09-19 16:56:13
50833	50128	MAIRE	2008-03-16 00:00:00	\N	2016-12-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-09-19 17:00:55	2017-09-19 17:02:18
47544	46140	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:39	2017-08-10 03:43:32
47545	46141	VICPDTAN	2002-06-26 00:00:00	\N	2004-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:39	2017-08-09 03:43:41
47546	46142	VICPDTAN	2007-06-27 00:00:00	\N	2009-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:39	2017-08-10 10:57:03
47547	46143	SECAN	2012-06-27 00:00:00	\N	2013-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:39	2017-08-10 03:43:32
47548	46144	DEPUTE	1982-08-30 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:39	\N
47549	46145	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:39	\N
47550	46146	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:39	\N
47551	46147	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:39	\N
47552	46148	DEPUTE	1981-07-24 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:39	\N
47553	46149	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:39	\N
47554	46150	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:39	\N
52702	52239	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
47555	46151	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:39	\N
47556	46152	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:39	\N
47557	46153	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:39	\N
47558	46154	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:39	\N
47560	46156	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:39	\N
47561	46157	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:39	2017-08-10 10:57:03
47562	46158	DEPUTE	2009-07-24 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:39	2017-08-10 10:57:03
47563	46159	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:39	\N
47564	46160	VICPDTAN	1997-06-13 00:00:00	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:39	2017-08-10 10:57:03
47565	46161	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:39	\N
47566	46162	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:39	\N
47567	46163	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:39	\N
47568	46164	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:39	\N
47569	46165	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:39	\N
47570	46166	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:39	\N
47572	46168	DEPUTE	1988-06-13 00:00:00	\N	1991-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:39	\N
47573	46169	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:39	\N
47574	46170	VICPDTAN	1988-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:39	2017-08-10 10:57:03
47575	46171	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:39	\N
47576	46172	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:39	2017-08-09 03:43:41
47577	46173	DEPUTE	1995-09-24 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:39	2017-08-09 03:43:41
47578	46174	DEPUTE	1997-05-25 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:39	\N
47579	46175	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:39	2017-08-04 03:43:47
47580	46176	DEPUTE	2005-03-14 00:00:00	\N	2005-07-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:39	2017-08-04 03:43:47
47581	46177	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:39	\N
47582	46178	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:39	\N
47583	46179	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:39	\N
49072	47668	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:29	\N
49073	47669	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:29	\N
49074	47670	DEPUTE	2004-05-01 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:29	\N
49075	47671	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:29	\N
49076	47672	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:29	\N
49077	47673	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:29	\N
49078	47674	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:29	\N
49079	47675	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:29	\N
49080	47676	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:29	\N
49081	47677	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:29	\N
49082	47678	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:29	\N
49083	47679	DEPUTE	2007-06-20 00:00:00	\N	2010-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:29	\N
49084	47680	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:29	\N
49085	47681	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:29	\N
49086	47682	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:29	\N
49087	47683	DEPUTE	2012-06-20 00:00:00	\N	2016-03-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:29	\N
49088	47684	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:29	\N
49089	47685	DEPUTE	2007-06-20 00:00:00	\N	2008-04-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:29	2017-08-10 10:57:31
49090	47686	DEPUTE	2009-07-24 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:29	2017-08-10 10:57:31
49091	47687	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:29	\N
49093	47689	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:29	\N
49094	47690	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:29	2017-08-10 10:57:31
49095	47691	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:29	\N
49096	47692	DEPUTE	2017-06-21 00:00:00	\N	2020-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:29	\N
49097	47693	DEPUTE	2007-06-26 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:29	2017-08-10 10:57:31
49098	47694	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:29	\N
49099	47695	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:29	\N
49100	47696	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:30	\N
49101	47697	DEPUTE	2005-01-24 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:30	\N
49102	47698	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:30	\N
49103	47699	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:30	\N
49104	47700	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:30	\N
49105	47701	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:30	\N
49106	47702	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:30	2017-08-10 03:44:01
49107	47703	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:30	\N
49108	47704	DEPUTE	1995-09-17 00:00:00	\N	1995-10-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:30	2017-08-10 03:44:01
49109	47705	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:30	\N
49110	47706	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:30	\N
49111	47707	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:30	2017-08-10 03:44:01
49112	47708	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:30	2017-08-10 03:44:01
49113	47709	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:30	\N
44630	43226	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	\N
50902	50205	CONSMUNI	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 11:46:16	2017-09-20 11:47:22
49115	47711	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:30	\N
49116	47712	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:30	\N
49117	47713	SECAN	2000-04-06 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:30	2017-08-10 10:57:31
49118	47714	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:30	2017-08-10 10:57:31
49119	47715	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:30	\N
49120	47716	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:30	\N
49121	47717	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:30	\N
49122	47718	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:30	\N
49123	47719	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:30	\N
49124	47720	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:30	\N
49125	47721	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:30	\N
49126	47722	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:30	\N
49127	47723	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:30	\N
49128	47724	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:31	\N
49129	47725	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:31	\N
49130	47726	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:31	\N
49131	47727	DEPUTE	1993-04-02 00:00:00	\N	1995-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:31	\N
49132	47728	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:31	\N
49133	47729	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:31	\N
49134	47730	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:31	\N
49135	47731	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:31	\N
49136	47732	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:31	\N
49137	47733	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:31	\N
49138	47734	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:31	\N
49139	47735	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:31	\N
49140	47736	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:31	\N
49144	47740	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:31	\N
49145	47741	SECAN	1995-06-01 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:31	2017-08-10 10:57:32
49146	47742	SECAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:31	2017-08-10 10:57:32
49147	47743	SECAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:31	2017-08-10 10:57:32
49148	47744	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:31	2017-08-10 10:57:32
49149	47745	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:31	2017-08-10 10:57:32
49150	47746	SECAN	2002-06-26 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:31	2017-08-10 10:57:32
49151	47747	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:31	\N
49152	47748	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:32	\N
49153	47749	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:32	\N
49154	47750	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:32	\N
49155	47751	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:32	\N
49156	47752	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:32	\N
49157	47753	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:32	\N
49158	47754	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:32	\N
49159	47755	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:32	\N
49160	47756	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:32	\N
49161	47757	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:32	\N
49162	47758	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:32	\N
49163	47759	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:32	\N
49164	47760	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:32	\N
44609	43205	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	\N
44610	43206	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	\N
44611	43207	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	\N
44612	43208	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	\N
44613	43209	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	\N
44614	43210	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	\N
44615	43211	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	\N
44616	43212	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	\N
44617	43213	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	\N
44618	43214	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	\N
44619	43215	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	\N
44620	43216	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	\N
44621	43217	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	\N
44622	43218	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	\N
44623	43219	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	\N
44624	43220	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	\N
44625	43221	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	\N
44626	43222	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	\N
44627	43223	DEPUTE	1997-06-01 00:00:00	\N	1998-09-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	\N
44628	43224	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	\N
44629	43225	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	\N
44631	43227	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	\N
44632	43228	DEPUTE	2012-06-20 00:00:00	\N	2015-08-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	\N
44633	43229	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	\N
44634	43230	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	\N
44635	43231	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	\N
44636	43232	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	\N
44637	43233	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:09	\N
44638	43234	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:10	\N
44639	43235	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:10	\N
44641	43237	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:10	\N
44644	43240	VICPDTAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:10	2017-08-10 10:56:12
44645	43241	QUESTAN	1997-06-13 00:00:00	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:10	2017-08-10 10:56:12
44646	43242	SECAN	2002-06-26 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:10	2017-08-10 10:56:12
44647	43243	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:10	\N
44648	43244	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:10	\N
44649	43245	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:10	\N
44650	43246	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:10	\N
44652	43248	DEPUTE	1997-05-17 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:10	\N
44653	43249	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:10	\N
44654	43250	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:10	\N
44655	43251	DEPUTE	1995-06-26 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:10	\N
44656	43252	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:10	\N
44658	43254	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:10	\N
44659	43255	VICPDTAN	2005-07-04 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:10	2017-08-10 10:56:12
44660	43256	VICPDTAN	2004-05-05 00:00:00	\N	2005-07-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:10	2017-08-09 03:42:41
44661	43257	DEPUTE	1992-07-04 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:10	\N
44662	43258	DEPUTE	1998-08-11 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:10	\N
44663	43259	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:10	\N
44664	43260	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:10	\N
44665	43261	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:10	\N
44666	43262	DEPUTE	1997-06-01 00:00:00	\N	2002-06-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:10	\N
44667	43263	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:10	\N
44668	43264	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:10	2017-08-10 03:42:42
44669	43265	DEPUTE	2010-12-14 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:10	2017-08-10 03:42:42
44670	43266	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:10	\N
44671	43267	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:10	\N
44672	43268	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:10	\N
44673	43269	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:10	\N
44674	43270	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:10	\N
44675	43271	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:10	\N
44676	43272	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:10	\N
44677	43273	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:10	\N
44678	43274	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:10	\N
44679	43275	DEPUTE	2002-06-19 00:00:00	\N	2004-01-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:10	\N
44680	43276	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:10	\N
44681	43277	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:10	\N
44682	43278	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:10	\N
44683	43279	DEPUTE	1987-05-15 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:10	\N
44684	43280	DEPUTE	1988-06-13 00:00:00	\N	1993-03-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:10	\N
44685	43281	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:10	\N
44686	43282	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:11	\N
44687	43283	DEPUTE	2013-04-20 00:00:00	\N	2013-04-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:11	2017-08-10 10:56:12
44688	43284	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:11	2017-08-10 10:56:12
44689	43285	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:11	\N
44690	43286	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:11	\N
44691	43287	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:11	\N
44692	43288	DEPUTE	1989-04-30 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:11	\N
44693	43289	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:11	\N
44694	43290	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:11	\N
44695	43291	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:11	\N
44696	43292	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:11	\N
44697	43293	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:11	\N
44698	43294	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:11	\N
44699	43295	DEPUTE	2007-06-20 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:11	\N
44700	43296	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:11	\N
44701	43297	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:11	\N
50812	50102	CONSDPT	2004-03-29 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2017-09-19 15:59:31	2017-09-19 16:00:17
46096	44692	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:55	\N
46097	44693	DEPUTE	1994-02-08 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:55	\N
46098	44694	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:55	\N
46099	44695	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:55	\N
46100	44696	DEPUTE	1978-04-03 00:00:00	\N	1978-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:55	\N
46101	44697	DEPUTE	1968-07-11 00:00:00	\N	1968-08-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:55	\N
46102	44698	DEPUTE	1973-04-02 00:00:00	\N	1973-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:55	\N
46103	44699	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:55	\N
46104	44700	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:55	\N
46105	44701	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:55	\N
46106	44702	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:55	\N
46107	44703	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:55	\N
46108	44704	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:55	\N
46109	44705	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:55	\N
46110	44706	DEPUTE	2007-07-20 00:00:00	\N	2010-12-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:55	\N
46111	44707	DEPUTE	1981-07-02 00:00:00	\N	1983-04-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:55	\N
46112	44708	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:55	2017-08-10 10:56:38
46113	44709	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:55	\N
46114	44710	DEPUTE	1997-06-12 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:56	2017-08-10 10:56:38
46115	44711	DEPUTE	1999-10-01 00:00:00	\N	2000-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:56	2017-08-10 10:56:38
46116	44712	DEPUTE	1991-02-04 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:56	\N
46117	44713	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:56	\N
46118	44714	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:56	\N
46119	44715	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:56	\N
46120	44716	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:56	\N
46121	44717	DEPUTE	1975-06-23 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:56	\N
46122	44718	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:56	\N
46123	44719	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:56	\N
46124	44720	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:56	\N
46125	44721	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:56	\N
46126	44722	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:56	\N
46127	44723	DEPUTE	1997-05-25 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:56	\N
46128	44724	DEPUTE	2002-06-19 00:00:00	\N	2004-04-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:56	2017-08-10 10:56:38
46129	44725	DEPUTE	2002-06-25 00:00:00	\N	2002-06-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:56	2017-08-10 10:56:38
46130	44726	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:56	\N
46131	44727	DEPUTE	2002-07-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:56	\N
46132	44728	DEPUTE	2002-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:56	\N
46133	44729	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:56	\N
46134	44730	DEPUTE	1980-11-30 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:56	\N
46135	44731	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:56	\N
46136	44732	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:56	\N
46137	44733	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:56	\N
46138	44734	DEPUTE	1993-04-02 00:00:00	\N	1993-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:56	2017-08-10 03:43:08
46139	44735	DEPUTE	1993-09-21 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:56	2017-08-10 03:43:08
46140	44736	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:56	\N
46141	44737	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:57	\N
46142	44738	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:57	\N
46143	44739	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:57	\N
46144	44740	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:57	\N
46145	44741	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:57	\N
46146	44742	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:57	\N
46147	44743	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:57	\N
46148	44744	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:57	\N
46149	44745	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:57	\N
46150	44746	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:57	\N
46151	44747	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:57	\N
46152	44748	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:57	\N
46153	44749	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:57	\N
46154	44750	DEPUTE	1986-02-27 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:57	\N
46155	44751	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:57	\N
46156	44752	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:57	\N
46157	44753	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:57	\N
46158	44754	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:57	\N
46159	44755	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:57	\N
46160	44756	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:57	\N
46161	44757	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:57	\N
46162	44758	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:57	\N
46163	44759	DEPUTE	1989-01-20 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:57	\N
46164	44760	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	\N
46165	44761	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	\N
46166	44762	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	\N
52174	51788	CONSDPT	2020-10-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
46167	44763	DEPUTE	1981-07-02 00:00:00	\N	1983-11-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	\N
46168	44764	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	\N
46169	44765	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	\N
46170	44766	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	\N
46171	44767	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	\N
46173	44769	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	\N
46174	44770	SECAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	2017-08-10 03:43:09
46175	44771	DEPUTE	1985-12-16 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	\N
46176	44772	DEPUTE	1992-05-05 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	\N
46177	44773	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	\N
46178	44774	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	\N
46179	44775	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	\N
46180	44776	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	\N
46181	44777	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	\N
46182	44778	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	\N
46183	44779	DEPUTE	1988-06-13 00:00:00	\N	1989-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	\N
46184	44780	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	\N
46185	44781	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	2017-08-10 10:56:39
46186	44782	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	2017-08-09 03:43:13
46187	44783	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	\N
46188	44784	DEPUTE	2002-06-19 00:00:00	\N	2007-01-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	\N
47584	46180	DEPUTE	2007-06-20 00:00:00	\N	2008-02-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:39	\N
47585	46181	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:40	\N
47586	46182	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:40	\N
47587	46183	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:40	\N
47588	46184	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:40	\N
47589	46185	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:40	\N
47590	46186	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:40	\N
47591	46187	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:40	\N
50834	50129	MAIRE	2017-01-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2017-09-19 17:01:17	2017-09-19 17:02:05
50838	50134	CONSDPT	2008-03-16 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	2017-09-19 17:07:56	2017-09-19 17:08:15
47594	46190	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:40	\N
47595	46191	SECAN	2004-10-01 00:00:00	\N	2005-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:40	2017-08-08 03:43:48
47596	46192	SECAN	2008-10-01 00:00:00	\N	2009-10-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:40	2017-08-10 03:43:33
47597	46193	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:40	\N
47598	46194	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:40	\N
47599	46195	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:40	\N
47600	46196	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:40	\N
47601	46197	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:40	\N
47602	46198	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:40	\N
47603	46199	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:40	\N
47604	46200	DEPUTE	2007-06-20 00:00:00	\N	2011-07-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:40	\N
47605	46201	DEPUTE	2012-06-20 00:00:00	\N	2016-08-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:40	\N
47606	46202	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:40	\N
47607	46203	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:40	\N
47608	46204	DEPUTE	1981-07-02 00:00:00	\N	1983-02-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:40	\N
47609	46205	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:40	\N
47610	46206	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:40	\N
47611	46207	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:40	\N
47612	46208	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:40	\N
47613	46209	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:41	\N
47614	46210	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:41	\N
47615	46211	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:41	2017-08-09 03:43:42
47616	46212	DEPUTE	2012-06-26 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:41	2017-08-09 03:43:42
47617	46213	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:41	\N
47618	46214	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:41	\N
47619	46215	DEPUTE	1993-05-02 00:00:00	\N	1995-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:41	\N
47620	46216	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:41	\N
47621	46217	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:41	\N
47623	46219	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:41	\N
47624	46220	SECAN	2007-06-27 00:00:00	\N	2008-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:41	2017-08-10 03:43:33
47625	46221	SECAN	2010-10-05 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:41	2017-08-10 03:43:33
47626	46222	DEPUTE	2008-02-04 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:41	\N
47627	46223	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:41	\N
47628	46224	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:41	\N
47629	46225	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:41	\N
47630	46226	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:41	\N
47631	46227	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:41	\N
47632	46228	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:41	\N
47633	46229	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:41	\N
47634	46230	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:41	\N
47637	46233	DEPUTE	1997-06-01 00:00:00	\N	2000-04-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:41	\N
47638	46234	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:41	\N
47639	46235	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:41	\N
47640	46236	SECAN	1988-06-24 00:00:00	\N	1992-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:41	2017-08-10 10:57:04
47641	46237	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:41	2017-08-10 03:43:34
47642	46238	SECAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:41	2017-08-08 03:43:49
47643	46239	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:42	\N
47644	46240	DEPUTE	1978-04-02 00:00:00	\N	1978-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:42	\N
47645	46241	DEPUTE	1986-04-02 00:00:00	\N	1986-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:42	2017-08-09 03:43:43
47646	46242	DEPUTE	1986-10-01 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:42	2017-08-09 03:43:43
47647	46243	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:42	\N
47648	46244	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:42	\N
47649	46245	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:42	\N
47650	46246	PDTAN	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:42	2017-08-11 03:43:15
47651	46247	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:42	\N
47652	46248	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:42	\N
47653	46249	PDTAN	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:42	2017-08-11 16:47:11
47654	46250	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:42	\N
47655	46251	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:42	\N
47656	46252	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:42	\N
47657	46253	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:42	\N
47658	46254	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:42	\N
47659	46255	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:42	\N
47660	46256	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:42	\N
47661	46257	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:42	\N
47662	46258	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:42	\N
47663	46259	DEPUTE	1983-04-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:42	\N
47664	46260	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:42	\N
47665	46261	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:42	\N
47666	46262	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:42	\N
47667	46263	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:43	\N
47668	46264	DEPUTE	1996-05-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:43	\N
47669	46265	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:43	\N
47670	46266	DEPUTE	1989-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:43	\N
47671	46267	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:43	\N
47672	46268	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:43	\N
47674	46270	SECAN	1987-04-02 00:00:00	\N	1988-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:43	2017-08-09 03:43:44
47675	46271	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:43	\N
47676	46272	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:43	\N
43670	42266	MAIRE	2001-03-19 00:00:00	\N	2017-09-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-24 16:44:15	2017-11-13 15:57:11
49165	47761	DEPUTE	1994-02-08 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:32	\N
49166	47762	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:32	\N
49167	47763	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:32	\N
49168	47764	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:32	\N
49169	47765	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:32	\N
49170	47766	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:32	\N
49171	47767	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:32	\N
49172	47768	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:32	\N
49173	47769	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:32	\N
49174	47770	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:32	\N
49175	47771	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:32	\N
49176	47772	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:32	\N
49177	47773	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:32	\N
49178	47774	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:32	\N
49179	47775	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:32	\N
49180	47776	DEPUTE	2007-06-20 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:33	\N
49181	47777	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:33	\N
49182	47778	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:33	\N
49183	47779	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:33	\N
49184	47780	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:33	\N
49185	47781	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:33	\N
49186	47782	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:33	\N
49187	47783	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:33	\N
49188	47784	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:33	\N
49189	47785	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:33	\N
49190	47786	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:33	\N
49191	47787	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:33	\N
49192	47788	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:33	\N
49193	47789	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:33	\N
49194	47790	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:33	\N
49195	47791	DEPUTE	1997-06-01 00:00:00	\N	1999-12-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:33	\N
49196	47792	DEPUTE	1988-05-08 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:33	\N
49197	47793	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:33	\N
49198	47794	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:33	\N
49199	47795	DEPUTE	1988-06-13 00:00:00	\N	1992-05-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:33	\N
49200	47796	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:33	\N
49201	47797	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:33	\N
49202	47798	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:33	\N
49203	47799	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:33	\N
49204	47800	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:33	\N
49205	47801	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:33	\N
49206	47802	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:33	\N
49207	47803	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:33	\N
49208	47804	DEPUTE	1986-04-02 00:00:00	\N	1987-10-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:33	\N
49209	47805	DEPUTE	1993-04-02 00:00:00	\N	1996-04-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:33	\N
49210	47806	DEPUTE	1987-10-14 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:33	\N
49211	47807	DEPUTE	1988-06-06 00:00:00	\N	1988-10-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:33	\N
49212	47808	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:33	\N
49213	47809	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:33	\N
49214	47810	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:33	\N
49215	47811	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:33	\N
49216	47812	DEPUTE	1988-06-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:34	\N
49217	47813	DEPUTE	1997-05-17 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:34	\N
49218	47814	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:34	\N
49219	47815	DEPUTE	1978-04-02 00:00:00	\N	1980-09-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:34	\N
49220	47816	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:34	\N
49221	47817	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:34	\N
49222	47818	DEPUTE	1993-04-02 00:00:00	\N	1995-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:34	\N
49223	47819	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:34	\N
49224	47820	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:34	\N
49225	47821	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:34	\N
49226	47822	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:34	\N
49227	47823	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:34	\N
49228	47824	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:34	\N
49229	47825	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:34	\N
49230	47826	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:34	\N
49231	47827	DEPUTE	1991-06-18 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:34	\N
49232	47828	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:34	\N
49233	47829	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:34	\N
49234	47830	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:34	\N
49235	47831	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:34	\N
49236	47832	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:34	\N
49237	47833	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:34	\N
49238	47834	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:34	\N
49239	47835	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:34	\N
49240	47836	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:34	2017-08-10 10:57:33
49241	47837	DEPUTE	2014-05-01 00:00:00	\N	2014-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:34	2017-08-10 10:57:33
49242	47838	DEPUTE	2017-06-18 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:34	2017-08-10 10:57:33
49243	47839	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:34	\N
49244	47840	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:34	\N
49245	47841	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:34	\N
49246	47842	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:34	\N
49247	47843	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:34	\N
49248	47844	DEPUTE	1987-06-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:34	\N
49249	47845	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:34	\N
49250	47846	DEPUTE	1993-04-02 00:00:00	\N	1994-10-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:34	\N
49251	47847	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:34	\N
49252	47848	DEPUTE	2002-06-19 00:00:00	\N	2004-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:34	\N
49253	47849	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:34	\N
49254	47850	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:34	\N
49255	47851	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:34	\N
44702	43298	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:11	\N
44703	43299	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:11	\N
44704	43300	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:11	\N
44705	43301	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:11	\N
44706	43302	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:11	\N
44707	43303	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:11	\N
44708	43304	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:11	\N
44709	43305	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:11	\N
44710	43306	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:11	\N
44711	43307	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:11	\N
44712	43308	DEPUTE	1994-02-26 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:11	\N
44713	43309	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:11	\N
44714	43310	DEPUTE	1997-06-01 00:00:00	\N	2000-12-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:11	\N
44715	43311	DEPUTE	1968-07-11 00:00:00	\N	1968-08-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:11	\N
44716	43312	DEPUTE	1995-12-10 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:11	\N
44717	43313	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:11	\N
44718	43314	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:12	\N
44719	43315	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:12	\N
44720	43316	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:12	\N
44721	43317	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:12	\N
44722	43318	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:12	\N
44723	43319	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:12	\N
44724	43320	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:12	\N
44725	43321	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:12	\N
44726	43322	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:12	\N
44727	43323	DEPUTE	2007-06-20 00:00:00	\N	2010-06-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:12	\N
44728	43324	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:12	\N
44729	43325	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:12	\N
44730	43326	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:12	\N
44731	43327	DEPUTE	2012-06-20 00:00:00	\N	2017-04-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:12	\N
44732	43328	DEPUTE	1986-04-02 00:00:00	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:12	\N
44733	43329	DEPUTE	1988-06-06 00:00:00	\N	1988-11-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:12	\N
44734	43330	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:12	\N
44735	43331	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:12	\N
44736	43332	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:12	\N
44737	43333	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:12	\N
44738	43334	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:12	\N
44739	43335	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:12	\N
50814	50104	PREVICPDTDPT	2016-03-01 00:00:00	\N	2017-10-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-09-19 16:05:10	2018-03-28 18:07:06
44741	43337	SECAN	1988-06-24 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:12	2017-08-10 10:56:13
44742	43338	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:12	\N
44743	43339	DEPUTE	1990-09-21 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:12	\N
44744	43340	DEPUTE	1981-07-02 00:00:00	\N	1983-04-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:12	\N
44745	43341	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:12	\N
44746	43342	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:13	\N
44747	43343	DEPUTE	1997-06-01 00:00:00	\N	1999-12-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:13	\N
44748	43344	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:13	\N
44749	43345	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:13	\N
44750	43346	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:13	\N
44751	43347	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:13	\N
44752	43348	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:13	\N
44753	43349	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:13	\N
44754	43350	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:13	\N
44755	43351	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:13	\N
44756	43352	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:13	\N
44757	43353	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:13	\N
44758	43354	DEPUTE	1997-06-01 00:00:00	\N	1999-10-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:13	\N
44759	43355	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:13	\N
44760	43356	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:13	\N
44761	43357	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:13	\N
44762	43358	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:13	\N
44763	43359	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:13	\N
44764	43360	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:13	\N
44765	43361	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:13	\N
44766	43362	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:13	\N
44767	43363	DEPUTE	1998-05-04 00:00:00	\N	1998-07-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:13	2017-08-10 10:56:14
44768	43364	DEPUTE	1998-09-27 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:13	2017-08-10 10:56:14
44769	43365	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:14	\N
44770	43366	DEPUTE	1986-04-02 00:00:00	\N	1987-10-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:14	\N
44771	43367	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:14	\N
44772	43368	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:14	\N
44773	43369	DEPUTE	1993-04-02 00:00:00	\N	1993-09-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:14	\N
44774	43370	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:14	\N
44775	43371	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:14	\N
44776	43372	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:14	\N
44777	43373	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:14	\N
44780	43376	VICPDTAN	1994-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:14	2017-08-10 10:56:14
44781	43377	VICPDTAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:14	2017-08-10 10:56:14
44782	43378	VICPDTAN	1998-03-24 00:00:00	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:14	2017-08-10 03:42:44
44783	43379	VICPDTAN	1999-02-10 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:14	2017-08-10 10:56:14
44784	43380	VICPDTAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:14	2017-08-10 10:56:14
44785	43381	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:14	\N
44786	43382	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:14	\N
44787	43383	DEPUTE	1988-06-13 00:00:00	\N	1991-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:14	\N
44788	43384	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:14	\N
44789	43385	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:14	\N
44790	43386	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:14	\N
44791	43387	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:14	\N
44792	43388	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:14	\N
44793	43389	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:14	\N
44794	43390	DEPUTE	1999-03-15 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:14	\N
46189	44785	SECAN	1992-04-02 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	2017-08-10 10:56:39
46190	44786	SECAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	2017-08-10 10:56:39
46191	44787	SECAN	1994-04-02 00:00:00	\N	1995-05-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	2017-08-10 10:56:39
46192	44788	VICPDTAN	1995-06-01 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	2017-08-10 10:56:39
46193	44789	DEPUTE	2002-06-19 00:00:00	\N	2006-09-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	\N
46194	44790	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	\N
46195	44791	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	\N
46196	44792	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	\N
46197	44793	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	\N
46198	44794	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	\N
46199	44795	DEPUTE	1988-12-19 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	\N
46200	44796	DEPUTE	1993-05-02 00:00:00	\N	1995-06-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	\N
46201	44797	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	\N
46202	44798	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	\N
46203	44799	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	\N
46204	44800	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	\N
46205	44801	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	\N
46206	44802	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	\N
46207	44803	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	\N
46208	44804	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	\N
46209	44805	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	\N
46210	44806	DEPUTE	1988-06-06 00:00:00	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	\N
46211	44807	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	\N
46212	44808	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	\N
46213	44809	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	\N
46214	44810	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	\N
46215	44811	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	\N
46216	44812	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:58	\N
46217	44813	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:59	\N
46218	44814	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:59	\N
46220	44816	VICPDTAN	1988-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:59	2017-08-09 03:43:14
46221	44817	DEPUTE	1995-12-14 00:00:00	\N	1996-02-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:59	\N
46222	44818	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:59	\N
46223	44819	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:59	\N
46224	44820	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:59	\N
46225	44821	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:59	\N
46226	44822	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:59	\N
46227	44823	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:59	\N
46228	44824	DEPUTE	1998-01-25 00:00:00	\N	1999-12-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:59	\N
46229	44825	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:59	\N
46230	44826	DEPUTE	1968-08-13 00:00:00	\N	1971-11-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:59	\N
46231	44827	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:59	\N
46232	44828	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:59	\N
46233	44829	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:59	\N
46234	44830	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:59	\N
46235	44831	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:59	\N
46236	44832	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:59	\N
46237	44833	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:59	\N
46238	44834	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:59	\N
46239	44835	DEPUTE	2007-06-20 00:00:00	\N	2011-05-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:59	\N
46240	44836	DEPUTE	1993-05-02 00:00:00	\N	1995-07-13 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:59	2017-08-10 10:56:40
46241	44837	DEPUTE	1995-12-08 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:59	2017-08-10 10:56:40
46242	44838	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:59	\N
46243	44839	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:59	\N
46244	44840	DEPUTE	1981-07-02 00:00:00	\N	1986-03-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:59	\N
46245	44841	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:59	\N
46246	44842	DEPUTE	1986-12-10 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:59	\N
46247	44843	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:59	\N
46248	44844	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:59	\N
46249	44845	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:59	\N
46250	44846	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:59	\N
46251	44847	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:59	\N
46252	44848	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:59	\N
46253	44849	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:59	\N
46254	44850	DEPUTE	1984-08-24 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:59	\N
46255	44851	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:59	\N
46256	44852	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:00	\N
46257	44853	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:00	\N
46258	44854	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:00	\N
46259	44855	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:00	\N
46260	44856	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:00	\N
46261	44857	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:00	2017-08-10 03:43:10
46262	44858	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:00	\N
46263	44859	DEPUTE	2007-06-20 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:00	\N
46264	44860	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:00	2017-08-11 11:33:15
46265	44861	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:00	\N
46266	44862	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:00	\N
46267	44863	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:00	\N
46268	44864	DEPUTE	1967-04-02 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:00	\N
46269	44865	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:00	\N
46270	44866	DEPUTE	1973-04-03 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:00	\N
46271	44867	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:00	\N
46272	44868	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:00	\N
46273	44869	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:00	\N
46274	44870	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:00	\N
46275	44871	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:00	\N
46276	44872	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:00	\N
46277	44873	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:00	\N
46278	44874	DEPUTE	1964-12-12 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:00	\N
46279	44875	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:00	\N
46280	44876	DEPUTE	1968-07-11 00:00:00	\N	1968-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:00	2017-08-10 10:56:41
46281	44877	DEPUTE	1968-12-15 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:00	2017-08-10 10:56:41
47677	46273	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:43	\N
47678	46274	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:43	\N
47679	46275	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:43	\N
47680	46276	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:43	\N
47681	46277	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:43	\N
47682	46278	DEPUTE	1973-04-02 00:00:00	\N	1974-07-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:43	\N
47683	46279	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:43	\N
47684	46280	DEPUTE	1978-04-03 00:00:00	\N	1978-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:43	\N
47685	46281	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:43	\N
47686	46282	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:43	\N
47687	46283	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:43	\N
47688	46284	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:43	\N
47689	46285	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:43	\N
47690	46286	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:44	\N
47691	46287	DEPUTE	1981-07-02 00:00:00	\N	1983-04-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:44	\N
47692	46288	DEPUTE	1980-11-30 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:44	\N
47693	46289	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:44	\N
47694	46290	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:44	\N
47695	46291	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:44	\N
47696	46292	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:44	\N
47697	46293	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:44	\N
47698	46294	DEPUTE	1973-04-02 00:00:00	\N	1977-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:44	\N
47699	46295	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:44	\N
47700	46296	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:44	\N
47701	46297	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:44	\N
47702	46298	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:44	\N
47703	46299	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:44	\N
47704	46300	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:44	\N
47705	46301	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:45	\N
47706	46302	DEPUTE	1973-04-02 00:00:00	\N	1973-05-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:45	\N
47707	46303	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:45	\N
47708	46304	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:45	\N
47709	46305	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:45	\N
47710	46306	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:45	\N
47711	46307	DEPUTE	1973-04-02 00:00:00	\N	1975-06-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:45	\N
47712	46308	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:45	\N
47713	46309	DEPUTE	1989-12-04 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:45	\N
47714	46310	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:45	\N
47715	46311	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:45	\N
47716	46312	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:45	\N
47717	46313	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:45	\N
47718	46314	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:45	\N
47719	46315	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:45	\N
47720	46316	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:45	\N
47721	46317	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:45	\N
47722	46318	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:45	\N
47723	46319	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:46	\N
47724	46320	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:46	\N
47725	46321	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:46	\N
47727	46323	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:46	\N
47728	46324	VICPDTAN	1987-04-02 00:00:00	\N	1988-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:46	2017-08-10 03:43:36
47729	46325	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:46	\N
47730	46326	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:46	\N
47731	46327	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:46	\N
47732	46328	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:46	\N
47733	46329	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:46	\N
47734	46330	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:46	\N
47735	46331	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:46	\N
47736	46332	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:46	\N
47737	46333	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:46	\N
47738	46334	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:46	\N
47739	46335	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:46	\N
47740	46336	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:46	\N
47741	46337	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:47	\N
47742	46338	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:47	\N
47743	46339	DEPUTE	1980-11-30 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:47	\N
47744	46340	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:47	\N
47745	46341	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:47	\N
47746	46342	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:47	\N
47747	46343	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:47	\N
47748	46344	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:47	\N
47749	46345	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:47	\N
47750	46346	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:47	\N
47751	46347	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:47	\N
47752	46348	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:47	\N
47753	46349	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:47	\N
47754	46350	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:47	\N
47755	46351	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:47	\N
47756	46352	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:47	\N
47757	46353	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:47	\N
47758	46354	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:47	\N
47759	46355	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:47	\N
47760	46356	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:47	\N
47761	46357	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:47	\N
47762	46358	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:47	\N
47763	46359	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:47	\N
47764	46360	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:47	\N
47765	46361	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:47	\N
47766	46362	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:48	\N
47767	46363	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:48	\N
47768	46364	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:48	\N
47769	46365	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:48	\N
50903	50206	CONSMUNI	2014-03-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-09-20 11:48:04	2017-09-20 11:49:07
49257	47853	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:35	\N
49258	47854	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:35	\N
49259	47855	SECAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:35	2017-08-10 03:44:04
49260	47856	DEPUTE	1993-04-02 00:00:00	\N	1995-12-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:35	\N
49261	47857	DEPUTE	1991-06-17 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:35	\N
49262	47858	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:35	\N
49263	47859	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:35	\N
52699	52663	VICPDTAN	2022-06-29 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
49264	47860	DEPUTE	1968-07-11 00:00:00	\N	1969-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:35	\N
49265	47861	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:35	\N
49266	47862	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:35	\N
49267	47863	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:35	\N
49268	47864	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:35	\N
49269	47865	DEPUTE	1993-04-02 00:00:00	\N	1995-05-08 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:35	\N
49270	47866	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:35	\N
49271	47867	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:35	\N
49272	47868	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:35	\N
49273	47869	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:35	\N
49274	47870	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:35	\N
49275	47871	DEPUTE	1988-06-13 00:00:00	\N	1991-06-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:35	\N
49276	47872	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:35	\N
49277	47873	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:35	\N
49278	47874	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:35	\N
49279	47875	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:35	\N
49280	47876	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:35	\N
49281	47877	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:35	\N
49282	47878	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:35	\N
49283	47879	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:35	\N
49284	47880	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:35	\N
49285	47881	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:35	\N
49286	47882	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:35	\N
49287	47883	DEPUTE	1997-06-01 00:00:00	\N	1997-07-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:35	\N
49288	47884	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:35	\N
49289	47885	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:35	\N
49290	47886	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:35	\N
49291	47887	DEPUTE	1980-11-30 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:35	\N
49292	47888	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:35	\N
49293	47889	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:35	\N
49294	47890	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:35	\N
49295	47891	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:35	\N
49296	47892	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:35	\N
49297	47893	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:35	\N
49298	47894	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:35	\N
49299	47895	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:35	\N
49300	47896	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:35	\N
49301	47897	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:35	\N
49302	47898	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:36	\N
49303	47899	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:36	\N
49304	47900	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:36	\N
49305	47901	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:36	\N
49306	47902	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:36	\N
49307	47903	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:36	\N
49308	47904	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:36	\N
49309	47905	DEPUTE	1986-04-02 00:00:00	\N	1988-04-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:36	\N
49310	47906	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:36	\N
49311	47907	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:36	\N
49312	47908	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:36	\N
49313	47909	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:36	\N
49314	47910	DEPUTE	1995-12-12 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:36	2017-08-10 10:57:34
49315	47911	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:36	2017-08-10 03:44:05
49317	47913	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:36	\N
49318	47914	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:36	\N
49319	47915	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:36	\N
49320	47916	DEPUTE	1996-10-01 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:36	2017-08-10 10:57:34
49321	47917	DEPUTE	1997-06-12 00:00:00	\N	2000-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:36	2017-08-10 03:44:05
49322	47918	DEPUTE	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:36	2017-08-10 03:44:05
49323	47919	VICPDTAN	2005-07-04 00:00:00	\N	2005-10-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:36	2017-08-10 10:57:34
49324	47920	VICPDTAN	2005-10-04 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:36	2017-08-09 03:44:19
49325	47921	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:36	\N
49326	47922	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:36	\N
49327	47923	DEPUTE	1997-06-01 00:00:00	\N	1997-10-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:36	2017-08-10 10:57:34
49328	47924	DEPUTE	1997-12-14 00:00:00	\N	2000-05-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:36	2017-08-10 10:57:34
49329	47925	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:36	\N
49330	47926	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:36	\N
49331	47927	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:36	\N
49332	47928	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:36	\N
49333	47929	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:36	\N
49334	47930	DEPUTE	1981-07-02 00:00:00	\N	1986-03-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:36	\N
49335	47931	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:36	\N
49337	47933	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:36	\N
49339	47935	DEPUTE	2002-06-19 00:00:00	\N	2002-07-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:36	\N
49340	47936	VICPDTAN	1994-04-02 00:00:00	\N	1995-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:36	2017-08-10 10:57:35
49341	47937	VICPDTAN	1993-04-07 00:00:00	\N	1994-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:36	2017-08-10 03:44:05
49342	47938	VICPDTAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:36	2017-08-09 03:44:19
49343	47939	DEPUTE	2002-06-19 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:36	2017-08-10 03:44:05
49344	47940	DEPUTE	2005-09-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:36	2017-08-10 03:44:05
49345	47941	DEPUTE	2007-06-20 00:00:00	\N	2007-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:36	2017-08-09 03:44:20
49346	47942	DEPUTE	2010-12-14 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:36	2017-08-09 03:44:20
49347	47943	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:36	\N
49348	47944	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:46:36	\N
44795	43391	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:14	\N
44796	43392	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:14	\N
44797	43393	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:14	\N
44798	43394	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:14	\N
44799	43395	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:14	\N
44800	43396	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:15	\N
44801	43397	DEPUTE	1988-06-06 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:15	\N
44802	43398	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:15	\N
44803	43399	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:15	\N
44804	43400	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:15	\N
44805	43401	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:15	\N
44806	43402	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:15	\N
44807	43403	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:15	\N
44808	43404	DEPUTE	1988-12-19 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:15	\N
44809	43405	DEPUTE	1993-05-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:15	\N
44810	43406	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:15	\N
44811	43407	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:15	\N
44812	43408	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:15	\N
44813	43409	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:15	2017-08-10 03:42:45
44814	43410	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:15	\N
44815	43411	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:15	2017-08-09 03:42:45
44816	43412	DEPUTE	2017-06-16 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:15	2017-08-09 03:42:45
44817	43413	DEPUTE	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:15	2017-08-10 03:42:45
44818	43414	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:15	\N
44819	43415	DEPUTE	1993-05-02 00:00:00	\N	1995-07-17 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:15	\N
44820	43416	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:16	\N
44821	43417	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:16	\N
44822	43418	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:16	\N
44823	43419	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:16	\N
50815	50106	MAIRE	1977-03-21 00:00:00	\N	2017-10-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-09-19 16:07:15	2018-03-28 18:01:23
44827	43423	DEPUTE	2007-06-20 00:00:00	\N	2010-06-11 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:16	\N
44828	43424	QUESTAN	1995-06-01 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:16	2017-08-10 10:56:15
44829	43425	QUESTAN	1997-06-13 00:00:00	\N	1998-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:16	2017-08-10 10:56:15
44830	43426	QUESTAN	1998-10-01 00:00:00	\N	1999-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:16	2017-08-10 10:56:15
44831	43427	QUESTAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:16	2017-08-10 10:56:15
44832	43428	QUESTAN	2000-10-02 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:16	2017-08-10 10:56:15
44833	43429	QUESTAN	2002-06-26 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:16	2017-08-10 03:42:45
44834	43430	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:16	\N
44835	43431	DEPUTE	1993-05-02 00:00:00	\N	1995-05-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:16	\N
44836	43432	DEPUTE	1981-07-02 00:00:00	\N	1981-12-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:16	\N
44837	43433	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:16	\N
44838	43434	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:16	\N
44839	43435	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:16	\N
44840	43436	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:16	\N
44841	43437	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:16	\N
44842	43438	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:16	\N
44843	43439	DEPUTE	1986-04-14 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:16	\N
44844	43440	DEPUTE	1996-03-26 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:16	\N
44845	43441	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:17	\N
44846	43442	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:17	\N
44847	43443	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:17	\N
44848	43444	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:17	\N
44849	43445	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:17	\N
44850	43446	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:17	\N
44851	43447	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:17	\N
44852	43448	DEPUTE	1997-07-05 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:17	\N
44853	43449	DEPUTE	1981-07-02 00:00:00	\N	1981-07-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:17	\N
44854	43450	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:17	\N
44855	43451	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:17	\N
44856	43452	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:17	\N
44857	43453	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:17	\N
44858	43454	DEPUTE	1958-12-09 00:00:00	\N	1962-10-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:17	\N
44859	43455	DEPUTE	1962-12-06 00:00:00	\N	1967-04-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:17	\N
44860	43456	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:17	\N
44861	43457	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:17	\N
44862	43458	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:17	\N
44863	43459	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:17	\N
44864	43460	DEPUTE	1986-04-02 00:00:00	\N	1986-04-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:17	\N
44865	43461	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:17	\N
44866	43462	DEPUTE	1988-09-19 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:18	\N
44867	43463	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:18	\N
44868	43464	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:18	\N
44869	43465	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:18	\N
44870	43466	DEPUTE	2017-06-21 00:00:00	\N	2021-03-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:18	\N
44871	43467	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:18	\N
44872	43468	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:18	\N
44873	43469	DEPUTE	1981-07-24 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:18	\N
44874	43470	DEPUTE	1992-02-03 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:18	\N
44875	43471	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:18	\N
44877	43473	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:18	\N
44878	43474	DEPUTE	2005-09-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:18	2017-08-10 10:56:17
44880	43476	DEPUTE	2010-12-14 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:18	2017-08-10 10:56:17
44881	43477	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:18	\N
44882	43478	VICPDTAN	2002-06-26 00:00:00	\N	2003-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:18	2017-08-10 10:56:17
44883	43479	VICPDTAN	2003-10-01 00:00:00	\N	2004-04-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:18	2017-08-10 10:56:17
44884	43480	VICPDTAN	2007-06-27 00:00:00	\N	2008-09-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:18	2017-08-10 10:56:17
44885	43481	DEPUTE	1997-06-01 00:00:00	\N	2001-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:18	\N
44886	43482	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:18	\N
44887	43483	DEPUTE	1990-08-18 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:44:18	\N
46282	44878	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:00	\N
46283	44879	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:00	\N
46284	44880	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:00	\N
46285	44881	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:00	\N
46286	44882	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:00	\N
46287	44883	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:00	\N
46288	44884	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:00	\N
46289	44885	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:00	\N
46290	44886	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:00	\N
46291	44887	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:00	\N
46292	44888	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:00	\N
46293	44889	DEPUTE	1993-05-02 00:00:00	\N	1995-05-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:00	\N
46294	44890	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:00	\N
46295	44891	DEPUTE	2001-07-29 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:00	\N
46296	44892	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:00	\N
46297	44893	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:01	\N
46298	44894	DEPUTE	1993-04-02 00:00:00	\N	1995-09-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:01	\N
46299	44895	DEPUTE	2004-06-21 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:01	\N
46300	44896	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:01	\N
46301	44897	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:01	\N
46302	44898	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:01	\N
46303	44899	DEPUTE	1981-07-02 00:00:00	\N	1984-01-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:01	\N
46304	44900	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:01	\N
46305	44901	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:01	\N
46306	44902	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:01	\N
46307	44903	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:01	2017-08-10 10:56:41
46308	44904	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:01	2017-08-10 10:56:41
46310	44906	VICPDTAN	2011-10-03 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:01	2017-08-10 10:56:41
46311	44907	VICPDTAN	2012-06-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:01	2017-08-10 10:56:41
46312	44908	SECAN	2017-06-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:01	2017-08-10 10:56:41
46313	44909	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:01	\N
46314	44910	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:01	\N
46315	44911	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:01	\N
46316	44912	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:01	\N
46317	44913	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:01	\N
46318	44914	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:01	\N
46319	44915	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:01	\N
46320	44916	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:01	\N
46321	44917	DEPUTE	1977-03-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:01	\N
46322	44918	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:01	\N
46323	44919	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:01	\N
46324	44920	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:01	\N
46325	44921	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:01	\N
46326	44922	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:01	\N
46327	44923	DEPUTE	1995-06-19 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:01	\N
46328	44924	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:01	\N
46329	44925	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:01	\N
46330	44926	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:01	\N
46331	44927	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:01	\N
46332	44928	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:01	\N
46333	44929	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:01	\N
46334	44930	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:02	\N
46335	44931	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:02	\N
46336	44932	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:02	\N
46337	44933	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:02	\N
46338	44934	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:02	\N
46339	44935	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:02	\N
46340	44936	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:02	\N
46341	44937	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:02	\N
46342	44938	DEPUTE	1981-07-25 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:02	\N
46343	44939	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:02	\N
46344	44940	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:02	\N
46345	44941	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:02	\N
46346	44942	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:02	\N
46347	44943	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:02	\N
46348	44944	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:02	\N
46349	44945	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:02	\N
46350	44946	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:02	\N
46351	44947	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:02	\N
46352	44948	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:02	\N
46353	44949	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:02	\N
46354	44950	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:02	\N
46355	44951	DEPUTE	2010-12-15 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:02	\N
46356	44952	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:02	\N
46357	44953	DEPUTE	1988-06-13 00:00:00	\N	1990-11-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:02	\N
46358	44954	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:03	\N
46359	44955	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:03	\N
46360	44956	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:03	\N
46361	44957	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:03	\N
46362	44958	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:03	\N
46363	44959	DEPUTE	2004-01-14 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:03	\N
46364	44960	DEPUTE	2007-06-20 00:00:00	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:03	\N
46365	44961	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:03	\N
46366	44962	DEPUTE	1967-04-03 00:00:00	\N	1968-05-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:03	\N
46367	44963	DEPUTE	1968-07-11 00:00:00	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:03	\N
46368	44964	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:03	\N
46369	44965	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:03	\N
46370	44966	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:03	\N
46371	44967	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:03	\N
46372	44968	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:03	\N
46373	44969	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:03	\N
46374	44970	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:03	\N
47770	46366	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:48	\N
47771	46367	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:48	\N
47772	46368	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:48	\N
47773	46369	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:48	\N
47774	46370	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:48	\N
47775	46371	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:48	\N
47776	46372	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:48	\N
47777	46373	DEPUTE	1988-06-13 00:00:00	\N	1989-05-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:48	\N
47778	46374	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:48	\N
47779	46375	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:48	\N
47780	46376	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:48	\N
47781	46377	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:48	\N
47782	46378	DEPUTE	1993-04-02 00:00:00	\N	1993-05-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:48	2017-08-10 10:57:07
47783	46379	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:48	\N
47784	46380	DEPUTE	1995-09-17 00:00:00	\N	1995-12-07 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:48	2017-08-10 10:57:07
47785	46381	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:48	\N
47786	46382	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:48	\N
47787	46383	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:48	\N
47788	46384	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:48	\N
47789	46385	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:48	\N
47790	46386	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:48	\N
47791	46387	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:48	\N
47792	46388	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:48	\N
47793	46389	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:48	\N
47794	46390	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:48	\N
47795	46391	DEPUTE	1983-11-05 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:48	\N
47796	46392	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:48	\N
47797	46393	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:48	\N
47798	46394	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:48	\N
47799	46395	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:48	\N
47800	46396	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:48	\N
47801	46397	DEPUTE	2007-06-20 00:00:00	\N	2012-06-16 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:48	\N
47802	46398	DEPUTE	2012-06-20 00:00:00	\N	2012-07-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:48	2017-08-07 03:43:32
47803	46399	DEPUTE	2014-05-03 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:48	2017-08-07 03:43:32
47804	46400	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:48	\N
47805	46401	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:48	\N
47806	46402	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:48	\N
50840	50138	MAIRE	1995-06-18 00:00:00	\N	2017-10-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	2017-09-19 17:16:32	2017-12-04 21:44:24
47808	46404	DEPUTE	2002-06-19 00:00:00	\N	2006-06-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:49	\N
47809	46405	SECAN	1999-10-01 00:00:00	\N	2000-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:49	2017-08-10 10:57:07
47810	46406	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:49	\N
47811	46407	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:49	\N
47812	46408	DEPUTE	1993-04-02 00:00:00	\N	1993-12-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:49	\N
47813	46409	DEPUTE	1988-06-13 00:00:00	\N	1988-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:49	\N
47814	46410	DEPUTE	1997-06-01 00:00:00	\N	2000-04-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:49	\N
47815	46411	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:49	\N
47816	46412	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:49	\N
47817	46413	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:49	\N
47818	46414	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:49	\N
47819	46415	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:49	\N
47820	46416	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:49	\N
47821	46417	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:49	\N
47822	46418	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:49	\N
47823	46419	DEPUTE	1988-07-29 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:49	\N
47824	46420	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:49	\N
47825	46421	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:49	\N
47826	46422	DEPUTE	1987-10-30 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:49	\N
47827	46423	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:49	\N
47828	46424	DEPUTE	1984-08-24 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:49	\N
47829	46425	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:49	\N
47830	46426	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:49	\N
47831	46427	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:49	\N
47832	46428	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:49	\N
47833	46429	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:49	\N
47834	46430	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:49	\N
47835	46431	DEPUTE	2012-06-20 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:49	\N
47836	46432	DEPUTE	2017-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:49	\N
47837	46433	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:49	\N
47838	46434	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:50	\N
47839	46435	DEPUTE	2002-06-19 00:00:00	\N	2007-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:50	\N
47840	46436	DEPUTE	1998-06-08 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:50	\N
47841	46437	DEPUTE	2007-06-20 00:00:00	\N	2012-06-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:50	\N
47843	46439	QUESTAN	2016-09-27 00:00:00	\N	2017-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:50	2017-08-08 03:43:54
47844	46440	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:50	\N
47845	46441	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:50	\N
47846	46442	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:50	\N
47847	46443	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:50	\N
47848	46444	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:50	\N
47849	46445	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:50	\N
47850	46446	DEPUTE	1973-04-02 00:00:00	\N	1978-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:50	\N
47851	46447	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:50	\N
47852	46448	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:50	\N
47854	46450	QUESTAN	1986-04-04 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:50	2017-08-10 10:57:08
47855	46451	DEPUTE	1978-04-03 00:00:00	\N	1981-05-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:50	\N
47856	46452	DEPUTE	1981-07-02 00:00:00	\N	1986-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:50	\N
47857	46453	DEPUTE	1986-04-02 00:00:00	\N	1988-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:50	\N
47858	46454	DEPUTE	1988-06-13 00:00:00	\N	1993-04-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:50	\N
47859	46455	DEPUTE	1978-04-02 00:00:00	\N	1980-10-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:50	\N
47860	46456	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:50	\N
47861	46457	DEPUTE	1993-04-02 00:00:00	\N	1997-04-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:50	\N
47862	46458	DEPUTE	1997-06-01 00:00:00	\N	2002-06-18 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	2017-07-25 10:45:50	\N
51788	51387	DEPUTE	2020-08-04 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51789	51388	DEPUTE	2020-08-04 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51790	51389	DEPUTE	2020-08-04 00:00:00	\N	2021-04-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52358	51878	CONSMUNI	2020-12-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52359	51879	MEMBREINTCOM	2020-12-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52046	51880	CONSMUNI	2020-10-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52137	51812	CONSMUNI	2020-10-26 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52138	51813	CONSINTCOM	2020-10-26 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53395	52823	CONSMUNI	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 11:58:48
53905	53708	DEPUTE	2000-01-01 00:00:00	\N	2005-01-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53397	52825	CONSDPT	2023-01-09 00:00:00	\N	2023-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 11:58:48
53904	53706	CONSGENE	1399-12-24 00:50:39	\N	1404-12-23 00:50:39	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53438	52885	MAIRE	1499-12-31 00:50:39	1500	2023-11-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 15:22:04
53439	52886	MEMBREINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 15:22:04
53639	53180	MAIRE	1499-12-31 00:50:39	1500	1599-11-06 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-27 11:45:48
53640	53181	PDTINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-27 11:45:48
53641	53182	CONSGENEPARI	1600-01-09 00:50:39	1600	1699-11-06 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-27 11:45:48
53642	53183	CONSMUNI	2023-11-06 00:00:00	2023	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-27 11:45:48
53643	53184	CONSDPT	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-27 11:45:48
53644	53185	MEMBREINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-27 11:45:48
53889	53680	CONSMUNI	2023-11-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52245	51869	MAIREADJOINT	2001-03-15 00:00:00	\N	2014-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51792	51390	DEPUTE	2020-08-05 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51793	51391	DEPUTE	2020-08-05 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51646	51883	DEPUTE	2018-11-17 00:00:00	\N	2021-01-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51328	51909	CONSDPT	2021-06-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
51646	51884	SECAN	2021-01-26 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52118	51910	CONSDPT	2021-06-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52389	51914	DEPUTE	2021-07-07 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50994	51939	CONSDPT	2021-06-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52412	51940	CONSDPT	2021-06-20 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52120	51941	CONSDPT	2021-06-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
15272	51942	CONSREG	2021-06-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52116	51943	CONSDPT	2021-06-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53175	52734	DEPUTE	2023-01-29 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53176	52735	DEPUTE	2022-06-22 00:00:00	\N	2022-12-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53679	53239	MAIRE	1499-12-31 00:50:39	1500	1599-11-06 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-28 12:16:25
53680	53240	VICPDTINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-28 12:16:25
53681	53241	PDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-28 12:16:25
53682	53242	PDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-28 12:16:25
53878	53651	PDTINTCOM	1499-12-23 00:50:39	\N	1504-12-22 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	\N
53765	53707	CONSMUNI	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-11-16 16:56:35
51774	51376	DEPUTE	1981-07-02 00:00:00	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51775	51377	DEPUTE	2020-07-28 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51784	51383	DEPUTE	2020-08-01 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52314	51818	PDTINTCOM	2008-01-03 00:00:00	\N	\N	2018	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52314	51819	VICPDTINTCOM	2008-01-01 00:00:00	\N	2008-01-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52315	51820	MAIREADJOINT	\N	2001	\N	2019	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53910	53713	CONSMUNI	2023-11-06 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53911	53714	MAIRE	1600-11-06 00:50:39	1600	1699-11-06 00:50:39	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53468	53715	CONSDPT	2000-01-09 00:00:00	2020	2023-11-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53912	53716	CONSCOMINT	2023-11-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53938	53750	DEPUTE	2024-03-09 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53939	53751	DEPUTE	2024-03-09 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53940	53752	DEPUTE	2024-03-09 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53941	53753	DEPUTE	2024-03-09 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52276	51747	MAIRE	2020-03-15 00:00:00	\N	2021-01-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52277	51748	VICPDTDPT	2015-03-15 00:00:00	\N	2020-12-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52278	51749	VICPDTINTCOM	2020-03-15 00:00:00	\N	2021-01-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52279	51750	MAIRE	2020-05-15 00:00:00	\N	2020-10-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52280	51751	VICPDTINTCOM	2020-07-15 00:00:00	\N	2020-10-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52281	51752	MAIRE	2008-03-15 00:00:00	\N	2020-10-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52282	51753	PDTINTCOM	2014-04-15 00:00:00	\N	2020-10-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52284	51755	CONSDPT	2011-03-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52367	51890	DEPUTE	2021-04-22 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52282	51757	VICPDTINTCOM	2008-04-15 00:00:00	\N	2014-04-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53156	52714	MAIRE	2014-05-15 00:00:00	\N	2022-12-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53156	52715	CONSMUNI	2023-01-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53157	52716	MEMBREINTCOM	2023-01-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53157	52717	VICPDTINTCOM	2020-01-15 00:00:00	\N	2022-12-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53533	53017	MEMBREINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 16:15:47
53892	53691	CONSMUNI	2023-11-02 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53793	53402	MEMBREINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-10-02 10:50:17
53794	53403	CONSREG	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-10-09 12:26:45
53795	53404	PDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-10-02 10:50:17
53824	53443	MEMBREINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-10-02 11:26:43
53823	53442	VICPDTDPT	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-10-02 11:26:43
52028	51446	CONSMUNI	2020-03-15 00:00:00	\N	2020-10-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52029	51447	VICPDTINTCOM	2020-04-15 00:00:00	\N	2020-10-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	\N
52030	51448	PDTDPT	2015-03-15 00:00:00	\N	2020-10-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52029	51451	MEMBREINTCOM	1992-03-15 00:00:00	\N	2020-03-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	\N
52028	51450	CONSMUNI	1983-03-15 00:00:00	\N	2020-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52030	51452	CONSDPT	2001-03-15 00:00:00	\N	2015-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52032	51453	CONSREG	2015-12-15 00:00:00	\N	2021-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52013	51455	MAIREADJOINT	2008-03-15 00:00:00	\N	2020-03-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52016	51456	CONSDPT	2011-03-15 00:00:00	\N	2015-03-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52015	51457	MEMBREINTCOM	2008-03-15 00:00:00	\N	2020-07-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52035	51458	CONSMUNI	2020-06-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
52036	51459	MAIRE	2020-05-15 00:00:00	\N	2020-10-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52036	51460	MAIRE	2014-03-27 00:00:00	\N	2020-05-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52037	51461	CONSCOMINT	2020-07-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
52037	51462	VICPDTINTCOM	2014-03-15 00:00:00	\N	2020-07-14 00:00:00	\N	ANCIEN	Vice-Président délégué à la gestion durable de l'eau	Vice-Président délégué à la gestion durable de l'eau	\N	NON	\N	\N
52038	51463	CONSMUNI	2020-03-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52038	51464	CONSMUNI	2001-03-15 00:00:00	\N	2020-03-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52039	51465	VICPDTREG	2010-03-15 00:00:00	\N	2015-12-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52041	51468	MAIRE	1989-03-15 00:00:00	\N	2017-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52039	51467	CONSREG	2004-03-15 00:00:00	\N	2010-03-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52041	51469	CONSMUNI	2017-06-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52042	51470	PDTINTCOM	2002-03-15 00:00:00	\N	2017-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52042	51471	MEMBREINTCOM	2017-06-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52043	51472	VICPDTREG	1992-03-15 00:00:00	\N	2002-06-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52044	51473	MAIREADJOINT	2020-06-15 00:00:00	\N	2020-10-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52243	51722	VICPDTINTCOM	2017-09-15 00:00:00	\N	2020-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52046	51475	MAIRE	2020-03-15 00:00:00	\N	2020-10-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52046	51476	MAIRE	1989-03-15 00:00:00	\N	2020-03-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52048	51477	CONSDPT	1992-03-15 00:00:00	\N	1998-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52049	51478	VICPDTREG	2015-03-15 00:00:00	\N	2020-10-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52050	51479	MAIREADJOINT	1995-03-15 00:00:00	\N	2001-03-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52052	51482	CONSDPT	2015-03-15 00:00:00	\N	2020-10-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52051	51481	CONSMUNI	2014-03-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52243	51723	VICPDTINTCOM	2020-06-15 00:00:00	\N	2020-10-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52244	51724	MAIRE	2016-11-15 00:00:00	\N	2020-09-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52245	51725	CONSMUNI	1995-03-15 00:00:00	\N	2001-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52245	51727	MAIRE	2014-03-15 00:00:00	\N	2020-10-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52247	51728	VICPDTINTCOM	2003-03-15 00:00:00	\N	2020-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52247	51729	VICPDTINTCOM	2020-03-15 00:00:00	\N	2020-10-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52255	51730	MAIRE	2020-03-15 00:00:00	\N	2020-10-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52256	51731	VICPDTINTCOM	2020-07-15 00:00:00	\N	2020-10-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52257	51732	CONSDPT	2015-03-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52255	51733	MAIRE	2014-03-15 00:00:00	\N	2020-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52256	51734	VICPDTINTCOM	2014-04-15 00:00:00	\N	2020-07-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52257	51735	CONSDPT	2011-03-15 00:00:00	\N	2015-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52259	51739	MAIRE	2008-03-15 00:00:00	\N	2020-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52259	51740	MAIRE	2001-03-15 00:00:00	\N	2008-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52260	51741	MEMBREINTCOM	2014-03-15 00:00:00	\N	2020-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53818	53435	MAIRE	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-10-02 10:59:01
52271	51744	MAIRE	2014-03-15 00:00:00	\N	2020-10-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52272	51745	PDTINTCOM	2014-04-15 00:00:00	\N	2020-10-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52273	51746	VICPDTDPT	2015-04-15 00:00:00	\N	2020-10-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52142	51782	CONSINTCOM	2020-10-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52232	51783	CONSMUNI	2020-10-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52018	51784	CONSMUNI	2020-10-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
52020	51785	CONSCOMINT	2020-10-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
52036	51786	CONSMUNI	2020-10-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
52090	51787	CONSDPT	2020-10-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
52099	51789	CONSMUNI	2020-10-09 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
53820	53437	MEMBREINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-10-02 10:59:01
52109	51791	CONSDPT	2020-10-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
52279	51792	CONSMUNI	2020-10-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
52145	51793	CONSDPT	2020-10-27 00:00:00	\N	2021-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52127	51794	CONSMUNI	2020-10-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
52128	51795	CONSCOMINT	2020-10-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
52303	51796	CONSMUNI	2020-06-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
52304	51797	CONSCOMINT	2020-06-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
52305	51798	VICPDTREG	2015-12-15 00:00:00	\N	2020-11-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52303	51799	CONSMUNI	2008-03-15 00:00:00	\N	2014-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52303	51800	CONSMUNI	2014-03-15 00:00:00	\N	2020-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52304	51801	CONSCOMINT	2008-03-15 00:00:00	\N	2014-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52304	51802	CONSCOMINT	2014-03-15 00:00:00	\N	2020-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52238	51803	CONSMUNI	2020-06-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
52306	51804	CONSREG	\N	1998	\N	2002	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52307	51805	CONSGENE	\N	1994	\N	2008	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52308	51806	PDTINTCOM	2020-09-30 00:00:00	\N	2020-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52173	51648	MAIRE	1989-03-15 00:00:00	\N	2015-04-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52174	51649	PDTDPT	2015-04-16 00:00:00	\N	2020-10-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52174	51650	CONSDPT	2004-03-15 00:00:00	\N	2015-04-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52120	51807	CONSDPT	2020-10-16 00:00:00	\N	2021-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52176	51652	MAIREADJOINT	\N	2008	2014-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
44651	51990	DEPUTE	2017-06-21 00:00:00	\N	2021-09-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
44651	51991	SECAN	2021-09-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52179	51656	MAIREADJOINT	2001-03-15 00:00:00	\N	2009-05-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52181	51657	VICPDTINTCOM	2001-05-15 00:00:00	\N	2009-05-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	\N
52182	51658	CONSDPT	2001-03-15 00:00:00	\N	2015-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52182	51659	PDTDPT	2015-03-16 00:00:00	\N	2020-10-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53373	52789	MEMBREINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 10:36:09
53434	52879	MAIREADJOINT	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 15:14:25
53718	53652	CONSMUNI	2023-11-03 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53879	53653	MEMBREINTCOM	2023-11-03 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53535	53019	CONSMUNI	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-10-09 12:26:57
53618	53146	MAIRE	1615-01-09 00:50:39	1500	1630-11-06 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-27 11:25:49
53619	53147	VICPDTINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-27 11:25:49
53621	53149	MAIREADJOINT	1600-01-09 00:50:39	1500	1612-12-31 00:50:39	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-27 11:25:49
53622	53150	CONSMUNI	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-27 11:25:49
52749	52670	DEPUTE	2022-06-22 00:00:00	\N	2022-06-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53695	53258	MAIRE	1499-12-31 00:50:39	1500	1599-11-06 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-28 14:27:00
52749	52671	VICPDTAN	2022-06-29 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52018	51829	MAIRE	2014-03-15 00:00:00	\N	2020-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52020	51830	CONSCOMINT	2014-03-15 00:00:00	\N	2020-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53199	52781	DEPUTE	2023-08-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53384	52801	CONSREG	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 11:05:46
53383	52802	VICPDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 11:05:46
53382	52803	MAIRE	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 11:05:46
53829	53659	CONSREG	2023-11-02 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53613	53133	CONSREG	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-27 09:25:13
53827	53657	CONSMUNI	2023-11-02 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53459	53371	MEMBREINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-10-02 00:22:26
53752	53662	CONSDPT	2023-11-02 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53752	53661	PDTDPT	1499-12-31 00:50:39	\N	2023-11-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53179	52739	CONSREG	2021-06-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53458	52915	MAIREADJOINT	1499-12-31 00:50:39	1500	1599-11-06 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 15:42:03
53459	52916	MEMBREINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 15:42:03
53480	52948	VICPDTINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 15:53:38
53481	52949	CONSDPT	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 15:53:38
53482	52950	MAIRE	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 15:53:38
53483	52951	CONSDPT	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 15:53:38
53484	52952	VICPDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 15:53:38
53488	52967	VICPDTINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 15:56:59
53799	53408	CONSREG	1499-12-31 00:50:39	1500	2024-01-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	2023-10-02 10:53:27
53490	52970	VICPDTINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 15:56:59
53545	53655	MEMBREINTCOM	2023-11-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N
53492	52972	PDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 15:56:59
53493	52973	PDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 15:56:59
53601	53114	CONSMUNI	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 18:11:44
53602	53115	MEMBREINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 18:11:44
53603	53116	MAIREADJOINT	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 18:11:44
53686	53245	CONSPARI	1600-01-09 00:50:39	1600	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-28 12:18:47
53687	53246	MAIREARR	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-28 12:18:47
53540	53654	CONSMUNI	2023-11-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52183	51660	VICPDTINTCOM	2020-03-15 00:00:00	\N	2021-07-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52184	51661	CONSDPT	2015-03-15 00:00:00	\N	2021-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52183	51662	MEMBREINTCOM	2014-03-15 00:00:00	\N	2020-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52185	51663	CONSMUNI	2020-03-15 00:00:00	\N	2020-10-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52202	51667	MAIREADJOINT	2008-03-15 00:00:00	\N	2020-05-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52203	51668	CONSMUNI	2020-06-15 00:00:00	\N	2022-02-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52204	51669	MEMBREINTCOM	2020-06-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
52205	51670	CONSMUNI	2020-06-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
52206	51671	MEMBREINTCOM	2020-06-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
52207	51672	VICPDTREG	2016-01-15 00:00:00	\N	2020-10-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52206	51675	MEMBREINTCOM	2018-10-15 00:00:00	\N	2020-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52205	51674	CONSMUNI	2014-03-15 00:00:00	\N	2020-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52209	51676	CONSREG	2014-05-15 00:00:00	\N	2016-01-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52358	51873	MAIRE	2019-01-01 00:00:00	\N	2020-05-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52211	51678	CONSMUNI	1989-03-15 00:00:00	\N	2001-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52211	51679	CONSMUNI	2015-06-15 00:00:00	\N	2020-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52211	51680	MAIRE	2001-03-15 00:00:00	\N	2015-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52212	51681	VICPDTINTCOM	2001-04-15 00:00:00	\N	2008-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52212	51682	PDTINTCOM	2008-03-15 00:00:00	\N	2017-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52213	51683	PDTINTCOM	2017-01-15 00:00:00	\N	2020-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52210	51684	CONSDPT	2001-03-15 00:00:00	\N	2015-04-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52210	51685	PDTDPT	2015-04-15 00:00:00	\N	2020-10-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52358	51874	MAIRE	2020-05-16 00:00:00	\N	2020-12-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52359	51875	MEMBREINTCOM	2017-01-01 00:00:00	\N	2020-06-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52359	51876	VICPDTINTCOM	2020-07-01 00:00:00	\N	2020-12-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52360	51877	MEMBREINTCOM	2008-04-01 00:00:00	\N	2016-12-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53767	53366	VICPDTINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-29 18:45:17
53768	53367	CONSREG	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-29 18:45:17
53769	53368	PDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-29 18:45:17
53770	53369	PDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-29 18:45:17
53803	53634	MEMBREINTCOM	1499-12-31 00:50:39	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53410	53636	MEMBREINTCOM	1499-12-31 00:50:39	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53465	53638	MEMBREINTCOM	2023-10-09 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53909	53712	CONSMUNI	2023-11-06 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52336	51845	CONSINTCOM	2016-01-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52337	51846	CONSINTCOM	2016-01-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52338	51847	VICPDTINTCOM	2014-04-07 00:00:00	\N	2017-12-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52338	51848	CONSINTCOM	2017-12-30 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52339	51849	CONSINTCOM	\N	2016	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52340	51850	CONSINTCOM	2016-01-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52341	51851	VICPDTINTCOM	2016-07-01 00:00:00	\N	2017-10-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52341	51852	CONSINTCOM	2017-10-25 00:00:00	\N	2021-07-19 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
14355	51853	CONSINTCOM	2016-01-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
14199	51854	CONSINTCOM	2016-01-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52004	51776	CONSMUNI	2020-10-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52005	51777	MEMBREINTCOM	2020-11-06 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52454	51992	CONSMUNI	2014-03-15 00:00:00	\N	2020-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52445	51987	MEMBREINTCOM	2020-03-15 00:00:00	\N	2021-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
52202	52704	CONSMUNI	2022-09-05 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52455	51994	CONSMUNI	2020-06-16 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53159	52718	CONSREG	2021-06-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53167	52726	DEPUTE	2023-01-29 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53168	52727	DEPUTE	2022-06-22 00:00:00	\N	2022-12-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53438	53685	CONSMUNI	2023-11-02 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53891	53688	CONSDPT	2023-10-06 00:00:00	\N	2023-11-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53929	53736	DEPUTE	2024-02-12 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53930	53737	DEPUTE	2024-02-12 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53932	53739	DEPUTE	2024-02-12 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53934	53741	DEPUTE	2024-02-12 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
15263	51937	CONSREG	2021-06-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52135	51600	MAIRE	2014-03-15 00:00:00	\N	2020-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52136	51601	VICPDTINTCOM	2020-07-15 00:00:00	\N	2020-10-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52135	51602	MAIRE	2020-03-15 00:00:00	\N	2020-10-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52136	51603	MEMBREINTCOM	2014-03-15 00:00:00	\N	2020-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52137	51604	MAIRE	2020-03-15 00:00:00	\N	2020-10-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52138	51605	VICPDTINTCOM	2020-06-15 00:00:00	\N	2020-10-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52137	51606	MAIREADJOINT	1983-03-15 00:00:00	\N	1995-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52137	51607	MAIRE	1995-06-15 00:00:00	\N	2020-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52139	51608	PDTINTCOM	2008-03-15 00:00:00	\N	2014-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52139	51609	VICPDTINTCOM	2014-03-15 00:00:00	\N	2017-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52140	51610	CONSDPT	2008-03-15 00:00:00	\N	2015-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52141	51611	CONSMUNI	2020-03-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52142	51612	VICPDTINTCOM	2020-03-15 00:00:00	\N	2020-10-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52141	51613	MAIREADJOINT	2008-03-15 00:00:00	\N	2020-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52142	51614	VICPDTINTCOM	2014-03-15 00:00:00	\N	2020-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52143	51615	MAIREADJOINT	2020-03-15 00:00:00	\N	2020-10-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52144	51616	MEMBREINTCOM	2020-03-15 00:00:00	\N	2020-10-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52145	51617	VICPDTDPT	2015-03-15 00:00:00	\N	2020-10-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52143	51618	MAIREADJOINT	2001-03-15 00:00:00	\N	2020-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52143	51619	CONSMUNI	1995-03-15 00:00:00	\N	2001-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52145	51620	CONSDPT	2001-03-15 00:00:00	\N	2015-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52148	51621	CONSMUNI	2001-03-15 00:00:00	\N	2015-07-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52149	51622	MAIREADJOINT	2014-04-15 00:00:00	\N	2020-10-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52149	51623	CONSMUNI	2008-04-15 00:00:00	\N	2014-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52150	51624	MEMBREINTCOM	2014-04-15 00:00:00	\N	2020-10-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52151	51625	VICPDTDPT	2015-03-15 00:00:00	\N	2020-10-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52152	51626	MAIRE	2008-03-15 00:00:00	\N	2014-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52153	51627	CONSCOMINT	2020-03-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52152	51628	CONSMUNI	2014-03-15 00:00:00	\N	2020-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52154	51629	PDTINTCOM	2002-01-15 00:00:00	\N	2008-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52286	51758	CONSDPT	2015-03-15 00:00:00	\N	2021-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52287	51759	MAIRE	1995-06-15 00:00:00	\N	2018-12-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52287	51760	MAIREDEL	2019-09-15 00:00:00	\N	2020-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52288	51761	MAIRE	2019-01-15 00:00:00	\N	2020-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52289	51762	PDTINTCOM	2001-03-15 00:00:00	\N	2008-12-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52290	51763	PDTINTCOM	2009-01-15 00:00:00	\N	2020-07-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52286	51764	CONSDPT	1994-06-15 00:00:00	\N	2001-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52286	51765	VICPDTDPT	2001-03-15 00:00:00	\N	2015-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52234	51885	CONSDPT	2020-10-15 00:00:00	\N	2021-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52049	51886	CONSREG	2020-10-26 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53589	53100	MAIREADJOINT	1499-12-31 00:50:39	1500	1515-10-23 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 17:42:19
53590	53101	VICPDTINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 17:42:19
53647	53188	CONSMUNI	1499-12-31 00:50:39	1500	2023-11-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-27 11:48:52
53648	53189	CONSREG	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-27 11:48:52
53883	53668	CONSMUNI	2023-11-07 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53884	53669	CONSCOMINT	2023-11-07 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52021	51439	DEPUTE	2020-09-28 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52022	51440	DEPUTE	2020-09-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52023	51441	DEPUTE	2020-09-28 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52024	51442	DEPUTE	2020-09-28 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52025	51443	DEPUTE	2020-09-28 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53561	53061	MAIREADJOINT	1499-12-31 00:50:39	1500	1599-11-06 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 16:41:48
53562	53062	VICPDTINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 16:41:48
53563	53063	CONSREG	1499-12-31 00:50:39	1500	1599-11-06 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 16:41:48
53564	53064	VICPDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 16:41:48
53726	53300	CONSDPT	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-28 17:11:14
53633	53165	CONSREG	2023-09-27 00:00:00	\N	2023-11-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53725	53299	MAIREADJOINT	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-28 17:11:14
53727	53304	CONSDPT	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-28 17:11:43
53728	53305	MAIREADJOINT	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-28 17:11:43
53729	53306	CONSDPT	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-28 17:11:43
53730	53310	MAIRE	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-28 17:12:01
53731	53311	VICPDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-28 17:12:01
53732	53312	CONSREG	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-28 17:12:01
53735	53318	CONSDPT	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-28 17:12:23
53776	53375	MAIRE	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-10-02 09:09:02
53739	53327	MEMBREINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-28 17:12:42
53741	53329	VICPDTDPT	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-28 17:12:42
53742	53330	PDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-28 17:12:42
53746	53334	MEMBREINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-28 17:12:58
53851	53511	VICPDTINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-10-05 09:31:19
53852	53512	VICPDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-10-05 09:31:19
52196	51664	CONSMUNI	2014-04-15 00:00:00	\N	2020-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52199	51665	VICPDTDPT	1998-03-15 00:00:00	\N	2014-08-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52201	51666	CONSREG	2010-03-15 00:00:00	\N	2013-02-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52390	51915	CONSREG	2021-06-26 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52721	52664	DEPUTE	2022-06-22 00:00:00	\N	2022-06-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52699	52662	DEPUTE	2022-06-22 00:00:00	\N	2022-06-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52877	52674	DEPUTE	2022-06-22 00:00:00	\N	2022-06-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52877	52675	VICPDTAN	2022-06-29 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53927	53734	DEPUTE	2024-02-10 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
51182	52736	CONSMUNI	2020-03-16 00:00:00	\N	2021-06-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51188	51920	CONSDPT	2021-06-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53177	52737	CONSDPT	2021-06-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53186	52768	DEPUTE	2023-06-10 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53442	52891	MAIRE	1499-12-31 00:50:39	1500	1599-11-06 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 15:26:18
53443	52892	MEMBREINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 15:26:18
53444	52893	VICPDTREG	1499-12-31 00:50:39	1500	1599-11-06 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 15:26:18
53506	52981	MAIRE	1499-12-31 00:50:39	1500	1599-11-06 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 16:04:01
53507	52982	VICPDTINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 16:04:01
53508	52983	CONSDPT	1499-12-31 00:50:39	1500	1599-11-06 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 16:04:01
53605	53121	MAIREDEL	1600-01-09 00:50:39	1600	2023-10-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 18:14:06
53649	53191	PDTINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-27 11:56:56
49779	51959	DEPUTE	2017-06-21 00:00:00	\N	2017-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52010	51771	CONSDPT	2020-09-15 00:00:00	\N	2021-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
49779	51960	SECAN	2017-06-28 00:00:00	\N	2018-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
49779	51961	DEPUTE	2018-10-01 00:00:00	\N	2020-03-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
49779	51962	SECAN	2020-03-22 00:00:00	\N	2021-08-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
49779	51963	DEPUTE	2021-09-01 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50562	51964	DEPUTE	2017-06-21 00:00:00	\N	2018-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50562	51965	SECAN	2018-10-01 00:00:00	\N	2020-03-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50562	51966	DEPUTE	2020-03-22 00:00:00	\N	2021-09-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50562	51967	SECAN	2021-09-01 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52182	51855	CONSDPT	2020-10-26 00:00:00	\N	2021-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52372	51892	DEPUTE	2021-06-07 00:00:00	\N	2021-07-06 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52373	51893	DEPUTE	2021-06-07 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52374	51894	DEPUTE	2021-06-06 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53389	52814	MAIRE	1400-01-01 00:50:39	\N	1499-12-30 00:50:39	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52330	51837	MEMBREINTCOM	2001-03-15 00:00:00	\N	2008-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52330	51838	VICPDTINTCOM	2014-03-15 00:00:00	\N	2020-07-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52503	52040	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52512	52049	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52516	52053	DEPUTE	2022-06-22 00:00:00	\N	2022-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52517	52054	DEPUTE	2022-06-22 00:00:00	\N	2022-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52519	52056	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52521	52058	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52524	52061	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52527	52064	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52528	52065	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52529	52066	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52531	52068	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52532	52069	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52533	52070	DEPUTE	2022-06-22 00:00:00	\N	2022-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52534	52071	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52535	52072	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52536	52073	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52537	52074	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52538	52075	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52539	52076	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52540	52077	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52541	52078	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52542	52079	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52543	52080	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52544	52081	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52545	52082	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52546	52083	DEPUTE	2022-06-22 00:00:00	\N	2023-09-24 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52547	52084	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52549	52086	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52550	52087	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52551	52088	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52552	52089	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52553	52090	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52554	52091	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52555	52092	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52556	52093	DEPUTE	2022-06-22 00:00:00	\N	2022-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52557	52094	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52558	52095	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52559	52096	DEPUTE	2022-06-22 00:00:00	\N	2022-08-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52560	52097	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52561	52098	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52562	52099	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52563	52100	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52564	52101	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52565	52102	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52567	52104	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52568	52105	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52569	52106	DEPUTE	2022-06-22 00:00:00	\N	2023-02-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52570	52107	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52571	52108	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52574	52111	DEPUTE	2022-06-22 00:00:00	\N	2023-01-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52575	52112	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52577	52114	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52578	52115	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52579	52116	DEPUTE	2022-06-22 00:00:00	\N	2022-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52580	52117	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52581	52118	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52582	52119	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52583	52120	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52584	52121	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52586	52123	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52587	52124	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52588	52125	DEPUTE	2022-06-22 00:00:00	\N	2022-12-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52589	52126	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52590	52127	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52591	52128	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52592	52129	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52593	52130	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52594	52131	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52595	52132	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52596	52133	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52597	52134	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52598	52135	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52599	52136	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52600	52137	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52601	52138	DEPUTE	2022-06-22 00:00:00	\N	2022-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52602	52139	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52603	52140	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52605	52142	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52606	52143	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52607	52144	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52608	52145	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52609	52146	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52610	52147	DEPUTE	2022-06-22 00:00:00	\N	2023-08-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52611	52148	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52612	52149	DEPUTE	2022-06-22 00:00:00	\N	2022-08-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52613	52150	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52614	52151	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52615	52152	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52616	52153	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52617	52154	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52618	52155	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52619	52156	DEPUTE	2022-06-22 00:00:00	\N	2024-03-08 00:00:00	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52620	52157	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52621	52158	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52622	52159	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52623	52160	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52624	52161	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52625	52162	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52626	52163	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52627	52164	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52628	52165	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52629	52166	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52630	52167	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52631	52168	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52632	52169	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52633	52170	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52634	52171	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52635	52172	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52636	52173	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52637	52174	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52638	52175	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52639	52176	DEPUTE	2022-06-22 00:00:00	\N	2022-08-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52640	52177	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52641	52178	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53164	52723	DEPUTE	2023-01-29 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52420	51954	DEPUTE	2021-07-28 00:00:00	\N	2021-08-25 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53165	52724	DEPUTE	2022-06-22 00:00:00	\N	2022-12-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53181	52741	DEPUTE	2023-04-17 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53182	52742	DEPUTE	2023-04-17 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53183	52743	DEPUTE	2023-04-17 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53389	52811	CONSMUNI	1499-12-31 00:50:39	1500	2023-11-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 11:43:56
53844	53472	VICPDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-10-04 17:27:54
53511	52989	VICPDTINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 16:07:04
53512	52990	PDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 16:07:04
53513	52991	PDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 16:07:04
53843	53471	VICPDTINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-10-04 17:27:54
52113	51572	CONSMUNI	2014-03-15 00:00:00	\N	2020-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52113	51573	MAIREADJOINT	2020-03-15 00:00:00	\N	2020-10-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52114	51574	CONSMUNI	2008-03-15 00:00:00	\N	2014-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52115	51575	MEMBREINTCOM	2020-03-15 00:00:00	\N	2020-10-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52116	51576	CONSDPT	2015-04-15 00:00:00	\N	2021-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52703	52240	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52117	51577	CONSMUNI	2020-03-15 00:00:00	\N	2020-10-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52117	51578	MAIREADJOINT	2008-03-15 00:00:00	\N	2020-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52117	51579	CONSMUNI	2001-03-15 00:00:00	\N	2008-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52118	51580	CONSDPT	2011-03-15 00:00:00	\N	2015-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52118	51581	CONSDPT	2015-03-15 00:00:00	\N	2021-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52119	51582	MAIREADJOINT	2020-03-15 00:00:00	\N	2020-10-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52119	51583	CONSMUNI	2008-03-15 00:00:00	\N	2020-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52120	51584	CONSDPT	2004-03-15 00:00:00	\N	2015-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52120	51585	VICPDTDPT	2015-03-15 00:00:00	\N	2020-10-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52121	51586	VICPDTINTCOM	2008-03-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52124	51589	VICPDTDPT	2015-03-15 00:00:00	\N	2020-10-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52123	51588	MAIRE	2014-03-15 00:00:00	\N	2020-10-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52125	51590	PDTINTCOM	2017-01-15 00:00:00	\N	2020-10-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52126	51591	CONSREG	1998-03-15 00:00:00	\N	2004-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52127	51592	MAIREADJOINT	2001-03-15 00:00:00	\N	2020-10-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52128	51593	VICPDTINTCOM	2001-03-15 00:00:00	\N	2020-10-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52129	51594	VICPDTDPT	2017-10-15 00:00:00	\N	2020-10-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52130	51595	CONSMUNI	1983-03-15 00:00:00	\N	1989-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52131	51596	CONSREG	1993-03-15 00:00:00	\N	2015-12-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52436	51969	MAIRE	2014-04-01 00:00:00	\N	2021-07-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52437	51970	CONSDPT	2015-04-01 00:00:00	\N	2016-01-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52438	51971	CONSREG	2015-12-15 00:00:00	\N	2021-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52440	51972	VICPDTINTCOM	2016-12-15 00:00:00	\N	2020-03-15 00:00:00	\N	ANCIEN	établissement public territorial Paris Terres d'Envol	Nouvelle fonction	\N	\N	\N	\N
52441	51973	VICPDTINTCOM	2014-03-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52642	52179	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52643	52180	DEPUTE	2022-06-22 00:00:00	\N	2022-08-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52644	52181	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52645	52182	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52646	52183	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52647	52184	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52648	52185	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52649	52186	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52650	52187	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52652	52189	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52653	52190	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52654	52191	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52656	52193	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52658	52195	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52660	52197	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52662	52199	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52665	52202	DEPUTE	2022-06-22 00:00:00	\N	2022-08-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52667	52204	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52669	52206	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52672	52209	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52674	52211	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52678	52215	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52680	52217	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52682	52219	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52684	52221	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52686	52223	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52688	52225	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52690	52227	DEPUTE	2022-06-22 00:00:00	\N	2022-08-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52692	52229	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52693	52230	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52697	52234	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52701	52238	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52704	52241	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52706	52243	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52708	52245	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52710	52247	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52712	52249	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52714	52251	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52715	52252	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52717	52254	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52719	52256	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52724	52260	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52726	52263	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52728	52265	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52730	52267	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52732	52269	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52743	52280	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52763	52300	DEPUTE	2022-06-22 00:00:00	\N	2022-08-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52765	52302	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52766	52303	DEPUTE	2022-06-22 00:00:00	\N	2024-02-11 00:00:00	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52770	52307	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52775	52312	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52777	52314	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52781	52318	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52784	52321	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52787	52324	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52791	52328	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52793	52330	DEPUTE	2022-06-22 00:00:00	\N	2023-08-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52796	52333	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52799	52336	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52802	52339	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52803	52340	DEPUTE	2022-06-22 00:00:00	\N	2024-01-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52805	52342	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52806	52343	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52808	52345	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52811	52348	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52812	52349	DEPUTE	2022-06-22 00:00:00	\N	2022-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52813	52350	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52815	52352	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52816	52353	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52817	52354	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52818	52355	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52819	52356	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52821	52358	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52822	52359	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52823	52360	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52824	52361	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52825	52362	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52826	52363	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52380	51898	DEPUTE	2021-06-28 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52472	52009	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52473	52010	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52474	52011	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52475	52012	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52476	52013	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52477	52014	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52478	52015	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52479	52016	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52480	52017	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52481	52018	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52483	52020	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52485	52022	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52486	52023	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52487	52024	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52488	52025	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52489	52026	DEPUTE	2022-06-22 00:00:00	\N	2023-11-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52490	52027	DEPUTE	2022-06-22 00:00:00	\N	2023-08-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52491	52028	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52492	52029	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52495	52032	DEPUTE	2022-06-22 00:00:00	\N	2022-08-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52496	52033	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52497	52034	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52498	52035	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52499	52036	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52500	52037	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52501	52038	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52502	52039	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52504	52041	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52505	52042	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52506	52043	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52507	52044	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52508	52045	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52509	52046	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52510	52047	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52511	52048	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52513	52050	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52514	52051	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52518	52055	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52520	52057	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52522	52059	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52523	52060	DEPUTE	2022-06-22 00:00:00	\N	2022-12-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52525	52062	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52526	52063	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52530	52067	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52655	52192	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52657	52194	DEPUTE	2022-06-22 00:00:00	\N	2022-08-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52659	52196	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52661	52198	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52663	52200	DEPUTE	2022-06-22 00:00:00	\N	2022-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52664	52201	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52666	52203	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52668	52205	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52670	52207	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52671	52208	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52673	52210	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52675	52212	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52677	52214	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52679	52216	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52681	52218	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52683	52220	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52685	52222	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52687	52224	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52689	52226	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52691	52228	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52705	52242	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52707	52244	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52709	52246	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52711	52248	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52713	52250	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52716	52253	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52718	52255	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52720	52257	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52722	52259	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52723	52261	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52725	52262	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52727	52264	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52729	52266	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52731	52268	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52733	52270	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52735	52272	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52736	52273	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52737	52274	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52738	52275	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52739	52276	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52740	52277	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52741	52278	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52742	52279	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52745	52282	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52746	52283	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52747	52284	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52748	52285	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52750	52287	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52751	52288	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52752	52289	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52753	52290	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52754	52291	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52755	52292	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52756	52293	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52757	52294	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52758	52295	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52759	52296	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52760	52297	DEPUTE	2022-06-22 00:00:00	\N	2023-06-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52761	52298	DEPUTE	2022-06-22 00:00:00	\N	2022-08-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52762	52299	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52764	52301	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52767	52304	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52769	52306	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52771	52309	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52774	52311	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52778	52315	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52782	52319	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52785	52322	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
51785	51384	DEPUTE	2020-08-03 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51786	51385	DEPUTE	2020-08-03 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51787	51386	DEPUTE	2020-08-03 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52053	51483	DEPUTE	2020-09-28 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52059	51489	MAIRE	2016-06-15 00:00:00	\N	2020-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52059	51490	MAIRE	2020-03-15 00:00:00	\N	2020-10-23 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52065	51496	VICPDTREG	2015-12-15 00:00:00	\N	2020-10-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52387	51911	CONSREG	2021-07-02 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
15259	51912	CONSREG	2021-06-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
52068	51499	VICPDTDPT	2004-03-15 00:00:00	\N	2011-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52067	51498	CONSMUNI	1989-03-15 00:00:00	\N	2000-09-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52068	51500	CONSDPT	2001-10-02 00:00:00	\N	2004-03-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52068	51501	CONSDPT	2011-03-15 00:00:00	\N	2015-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52070	51502	MAIREADJOINT	1989-03-15 00:00:00	\N	1992-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52070	51503	CONSMUNI	1983-03-15 00:00:00	\N	1989-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52070	51504	MAIRE	1992-03-15 00:00:00	\N	2020-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52071	51505	PDTINTCOM	2017-04-15 00:00:00	\N	2020-07-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52072	51506	PDTINTCOM	2000-04-15 00:00:00	\N	2016-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52075	51510	CONSDPT	1991-03-15 00:00:00	\N	1994-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52074	51509	PDTINTCOM	1993-03-15 00:00:00	\N	1999-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52075	51511	CONSDPT	1998-03-15 00:00:00	\N	2001-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52075	51512	VICPDTDPT	1994-03-15 00:00:00	\N	1998-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52075	51513	VICPDTDPT	2001-03-15 00:00:00	\N	2008-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52075	51514	CONSDPT	2008-03-15 00:00:00	\N	2015-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52828	52365	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52829	52366	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52830	52367	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52831	52368	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52832	52369	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52833	52370	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52834	52371	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52835	52372	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52836	52373	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52837	52374	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52838	52375	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52839	52376	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52840	52377	DEPUTE	2022-06-22 00:00:00	\N	2023-08-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52841	52378	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52842	52379	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52843	52380	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52844	52381	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52845	52382	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52846	52383	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52847	52384	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52848	52385	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52850	52387	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52851	52388	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52852	52389	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52853	52390	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52854	52391	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52855	52392	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52856	52393	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52857	52394	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52859	52396	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52860	52397	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52861	52398	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52862	52399	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52863	52400	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52864	52401	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52865	52402	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52866	52403	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52867	52404	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52868	52405	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52869	52406	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52870	52407	DEPUTE	2022-06-22 00:00:00	\N	2022-12-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52871	52408	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52872	52409	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52873	52410	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52875	52412	DEPUTE	2022-06-22 00:00:00	\N	2022-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52879	52416	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52881	52418	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52882	52419	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52883	52420	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52884	52421	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52885	52422	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52886	52423	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52887	52424	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52888	52425	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52889	52426	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52890	52427	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52891	52428	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52892	52429	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52893	52430	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52894	52431	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52895	52432	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52896	52433	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52898	52435	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52900	52437	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52901	52438	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52903	52440	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52905	52442	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52982	52519	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53018	52555	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53019	52556	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53021	52558	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53022	52559	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53024	52561	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53026	52563	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53027	52564	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53029	52566	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53030	52567	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53032	52569	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53034	52571	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53035	52572	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53037	52574	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53038	52575	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53040	52577	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53042	52579	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53043	52580	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53045	52582	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53047	52584	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53049	52586	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53050	52587	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53054	52591	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53055	52592	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53057	52594	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53059	52596	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53060	52597	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52076	51774	CONSMUNI	2020-10-31 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52077	51775	CONSINTCOM	2020-10-31 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52401	51921	CONSMUNI	2014-03-15 00:00:00	\N	2021-07-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52402	51922	CONSCOMINT	2014-03-15 00:00:00	\N	2021-07-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52403	51923	CONSREG	2021-06-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
51017	51924	CONSDPT	2021-06-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
52404	51925	CONSREG	2021-06-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
52405	51926	CONSDPT	2021-06-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
52151	51927	CONSDPT	2021-06-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
52406	51928	CONSDPT	2021-06-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
52234	51929	CONSDPT	2021-06-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
52145	51930	CONSDPT	2021-06-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
50922	51931	CONSDPT	2021-06-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
52788	52325	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52790	52327	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52794	52331	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52797	52334	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52800	52337	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52804	52341	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52807	52344	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52809	52346	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52810	52347	DEPUTE	2022-06-22 00:00:00	\N	2022-07-22 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52814	52351	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52897	52434	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52899	52436	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52902	52439	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52904	52441	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52906	52443	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52907	52444	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52908	52445	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52909	52446	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52910	52447	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52913	52450	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52915	52452	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52918	52455	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52921	52458	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52923	52460	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52925	52462	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52928	52465	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52930	52467	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52933	52470	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52936	52473	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52938	52475	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52940	52477	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52943	52480	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52945	52482	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52947	52484	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52950	52487	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52952	52489	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52955	52492	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52957	52494	DEPUTE	2022-06-22 00:00:00	\N	2023-08-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52959	52496	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52962	52499	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52964	52501	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52966	52503	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52969	52506	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52971	52508	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52973	52510	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52976	52513	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52978	52515	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52980	52517	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52983	52520	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52986	52523	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52988	52525	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52990	52527	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52993	52530	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52995	52532	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52997	52534	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52999	52536	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53002	52539	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53004	52541	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53006	52543	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53008	52545	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53010	52547	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53012	52549	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53016	52553	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53112	52649	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53466	53619	CONSMUNI	2023-11-06 00:00:00	2023	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-10-09 08:47:41
53387	52807	MEMBREINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 11:24:57
53923	53729	DEPUTE	2024-01-11 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53876	53649	MAIREADJOINT	1499-12-23 00:50:39	\N	1599-01-01 00:50:39	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53877	53650	CONSARR	2023-10-25 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53472	52931	VICPDTDPT	1499-12-31 00:50:39	1500	1599-11-06 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 15:47:19
53599	53110	CONSDPT	1499-12-23 00:50:39	\N	1599-01-01 00:50:39	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53470	53623	CONSREG	1499-12-31 00:50:39	1500	1599-12-31 00:50:39	1600	ANCIEN	\N	\N	\N	\N	\N	2023-10-09 08:47:41
53890	53681	VICPDTDPT	2023-01-01 00:00:00	\N	2023-11-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53667	53627	MAIRE	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-10-09 08:47:41
53890	53682	CONSDPT	2023-11-02 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
50949	53683	CONSMUNI	2023-11-02 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53650	53684	MEMBREINTCOM	2023-11-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N
53893	53692	CONSMUNI	2023-10-23 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53894	53693	CONSCOMINT	2023-11-06 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N
53895	53694	CONSMUNI	2023-11-06 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53896	53695	CONSMUNI	2023-11-06 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53897	53696	CONSCOMINT	2023-11-06 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N
53062	52599	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53063	52600	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53065	52602	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53067	52604	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53068	52605	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53070	52607	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53072	52609	DEPUTE	2022-06-22 00:00:00	\N	2023-08-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53073	52610	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53075	52612	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53077	52614	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53078	52615	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53080	52617	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53082	52619	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53084	52621	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53085	52622	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53087	52624	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53089	52626	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53090	52627	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53092	52629	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53094	52631	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53096	52633	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53097	52634	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53099	52636	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53101	52638	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53103	52640	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53104	52641	DEPUTE	2022-06-22 00:00:00	\N	2023-06-03 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53106	52643	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53114	52651	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53160	52719	DEPUTE	2023-01-29 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53161	52720	DEPUTE	2022-06-22 00:00:00	\N	2022-12-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53162	52721	DEPUTE	2023-01-29 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53163	52722	DEPUTE	2023-01-29 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53446	52897	CONSMUNI	1499-12-31 00:50:39	1500	1599-11-06 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 15:30:53
53447	52898	MEMBREINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 15:30:53
53448	52899	CONSREG	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 15:30:53
53450	52901	CONSREG	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 15:35:19
53451	52905	MAIREADJOINT	1499-12-31 00:50:39	1500	1515-10-27 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 15:37:39
53452	52906	MEMBREINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 15:37:39
53453	52907	CONSREG	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 15:37:39
53455	52910	MAIREADJOINT	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 15:38:56
53456	52911	VICPDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 15:38:56
53521	53004	MAIRE	1615-01-09 00:50:39	1615	1630-11-13 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	2023-10-05 09:31:19
53522	53005	VICPDTINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 16:12:44
53523	53006	VICPDTGEN	1499-12-31 00:50:39	1500	1515-11-03 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	2023-10-05 09:31:19
53524	53007	MAIRE	1499-12-31 00:50:39	1500	1515-12-21 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	2023-10-05 09:31:19
53881	53658	CONSREG	2023-11-04 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53526	53009	VICPDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 16:12:44
53583	53094	MAIRE	1600-01-09 00:50:39	1500	1699-11-06 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 17:34:23
53584	53095	PDTINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 17:34:23
53585	53096	MAIREADJOINT	1499-12-31 00:50:39	1500	1515-12-21 00:50:39	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 17:34:23
53586	53097	VICPDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 17:34:23
53625	53514	VICPDTINTCOM	1499-12-31 00:50:39	1500	2023-11-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	2023-10-05 11:51:54
53880	53656	CONSMUNI	2023-11-06 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53627	53516	MAIRE	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-10-05 11:51:54
53629	53518	VICPDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-10-05 11:51:54
52151	51780	CONSDPT	2020-10-15 00:00:00	\N	2021-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52311	51817	CONSDPT	\N	2015	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52086	51821	CONSMUNI	2020-10-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52087	51822	CONSDPT	2020-10-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
52088	51823	MEMBREINTCOM	2020-10-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52273	51824	CONSDPT	2020-10-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52135	51825	CONSMUNI	2020-10-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52136	51826	MEMBREINTCOM	2020-10-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52164	51827	CONSMUNI	2020-10-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
15280	51938	CONSREG	2021-06-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53144	52705	DEPUTE	2022-10-10 00:00:00	\N	2022-11-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53434	53527	MAIREADJOINT	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-10-05 13:27:07
53435	53528	VICPDTINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-10-05 13:27:07
52076	51527	MAIRE	2001-01-03 00:00:00	\N	2020-10-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52077	51528	VICPDTINTCOM	2020-05-15 00:00:00	\N	2020-10-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52078	51529	VICPDTDPT	1998-03-15 00:00:00	\N	2015-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52079	51530	MAIRE	2020-03-15 00:00:00	\N	2020-10-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52079	51531	MAIRE	1995-03-15 00:00:00	\N	2020-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52080	51532	VICPDTINTCOM	2020-06-15 00:00:00	\N	2020-10-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52081	51533	CONSREG	2015-12-15 00:00:00	\N	2021-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52082	51534	CONSDPT	2004-03-15 00:00:00	\N	2011-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52292	51767	CONSDPT	2011-03-15 00:00:00	\N	2014-12-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52152	51768	CONSMUNI	2001-03-15 00:00:00	\N	2008-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52152	51769	CONSMUNI	2020-10-16 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52431	51968	DEPUTE	2021-10-06 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53907	53709	VICPDTDPT	2023-10-01 00:00:00	\N	2023-11-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53907	53710	CONSDPT	2023-11-02 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52245	51870	CONSMUNI	2020-10-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52447	51985	CONSREG	2022-01-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53579	53087	MAIRE	1499-12-31 00:50:39	1500	2023-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 17:18:31
53580	53088	MEMBREINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 17:18:31
53581	53089	CONSMUNI	2023-11-06 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 17:18:31
53651	53196	MAIREADJOINT	1600-01-09 00:50:39	1500	2024-03-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-27 15:43:51
53652	53197	VICPDTINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-27 15:43:51
53654	53199	CONSMUNI	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-27 15:43:51
53688	53252	CONSMUNI	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-28 12:27:00
53689	53253	MEMBREINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-28 12:27:00
53690	53254	MAIRE	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-28 12:27:00
53899	53698	CONSMUNI	2023-11-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53692	53256	PDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-28 12:27:00
53805	53424	PDTINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-10-02 10:57:54
53710	53283	VICPDTINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-28 17:10:04
53505	53699	MEMBREINTCOM	2023-11-02 00:00:00	\N	2023-12-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	\N
53900	53700	CONSMUNI	2023-11-02 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53714	53287	VICPDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-28 17:10:04
53715	53288	CONSREG	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-28 17:10:04
53718	53293	MAIRE	1499-12-31 00:50:39	1500	1515-10-23 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-28 17:10:55
53720	53294	PDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-28 17:10:55
53719	53295	VICPDTINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-28 17:10:55
53721	53296	PDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-28 17:10:55
53809	53428	VICPDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-10-02 10:57:54
53810	53429	PDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-10-02 10:57:54
53811	53430	PDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-10-02 10:57:54
53812	53431	PDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-10-02 10:57:54
52065	51811	CONSREG	2020-10-27 00:00:00	\N	2021-07-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52376	51896	DEPUTE	2021-06-07 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52377	51897	DEPUTE	2021-06-07 00:00:00	\N	2022-01-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52418	51952	VICPDTGEN	2001-03-15 00:00:00	\N	2015-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52419	51953	CONSREG	2021-06-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
52448	51984	DEPUTE	2022-01-07 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53401	52831	MEMBREINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 12:03:52
53148	52708	CONSPARI	2017-10-19 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53169	52729	DEPUTE	2023-01-29 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53703	53770	CONSMUNI	2024-03-06 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53950	53772	CONSDPT	2024-03-04 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53653	53773	VICPDTDPT	1599-01-09 00:50:39	\N	2024-03-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53866	53648	VICPDTINTCOM	1499-12-31 00:50:39	\N	1599-11-06 00:50:39	\N	ANCIEN	\N	\N	\N	NON	\N	\N
53865	53646	MAIRE	1499-12-31 00:50:39	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52261	51738	CONSREG	2018-09-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
52259	51736	MAIRE	2020-03-15 00:00:00	\N	2020-10-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52260	51737	PDTINTCOM	2020-07-15 00:00:00	\N	2020-10-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
53888	53674	CONSDPT	2023-10-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53394	52818	CONSPARI	1600-01-09 00:50:39	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 11:53:47
53529	53013	CONSPARI	1600-01-09 00:50:39	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 16:13:46
53530	53014	VICPDTINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 16:13:46
53531	53015	MAIREADJOINT	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 16:13:46
53567	53070	MAIRE	1499-12-31 00:50:39	1500	1515-10-23 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 16:44:49
53568	53071	VICPDTINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 16:44:49
53569	53072	VICPDTGEN	1499-12-31 00:50:39	1500	1515-10-23 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 16:44:49
53570	53073	MAIRE	1400-01-01 00:50:39	1500	1499-12-22 00:50:39	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 16:44:49
53571	53074	VICPDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 16:44:49
53451	53676	CONSPARI	2023-11-06 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53451	53677	CONSARR	2023-11-06 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53460	52914	VICPDTREG	2015-09-26 00:00:00	\N	2019-01-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53559	53055	CONSDPT	1499-12-31 00:50:39	1500	2023-11-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 16:32:13
53558	53054	MAIREADJOINT	1499-12-31 00:50:39	1500	2023-11-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 16:32:13
52457	51995	DEPUTE	2022-04-06 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53171	52730	DEPUTE	2023-01-29 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53700	53264	MAIRE	1499-12-31 00:50:39	1500	2023-10-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-28 14:49:23
53187	52769	DEPUTE	2023-07-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53188	52770	DEPUTE	2023-07-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53189	52771	DEPUTE	2023-07-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53190	52772	DEPUTE	2023-07-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53191	52773	DEPUTE	2023-07-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53192	52774	DEPUTE	2023-07-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53660	53767	CONSDPT	2024-03-25 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52162	51772	CONSMUNI	2020-10-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52163	51773	CONSCOMINT	2020-07-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52030	51887	CONSDPT	2020-10-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53487	53689	CONSMUNI	2023-11-02 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53498	53690	CONSCOMINT	2023-11-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N
53914	53717	CONSMUNI	2023-11-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53406	53731	CONSCOMINT	2024-01-01 00:00:00	\N	\N	\N	ACTIF	Établissement public territorial Plaine Commune	Nouvelle fonction	\N	\N	\N	\N
53124	52684	DEPUTE	2022-07-23 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53123	52683	DEPUTE	2022-07-23 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53125	52685	DEPUTE	2022-07-23 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53126	52686	DEPUTE	2022-07-23 00:00:00	\N	2024-02-09 00:00:00	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53127	52687	DEPUTE	2022-07-23 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53128	52688	DEPUTE	2022-07-23 00:00:00	\N	2024-02-11 00:00:00	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53129	52689	DEPUTE	2022-07-23 00:00:00	\N	2024-02-09 00:00:00	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53130	52690	DEPUTE	2022-07-23 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53131	52691	DEPUTE	2022-07-23 00:00:00	\N	2024-02-11 00:00:00	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53132	52692	DEPUTE	2022-07-23 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53390	53539	VICPDTINTCOM	1499-12-31 00:50:39	1500	2023-10-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	2023-10-05 13:37:06
53396	53535	VICPDTINTCOM	1499-12-31 00:50:39	1500	2023-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	2023-10-05 13:33:29
53920	53723	CONSMUNI	2023-11-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53398	53537	CONSMUNI	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-10-05 13:33:29
53688	53541	CONSMUNI	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-10-05 13:37:06
53690	53543	MAIRE	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-10-05 13:37:06
52242	51815	CONSMUNI	2020-10-27 00:00:00	\N	2021-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52243	51816	CONSCOMINT	2020-10-27 00:00:00	\N	2021-07-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52332	51839	CONSINTCOM	2020-06-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52333	51840	CONSINTCOM	2016-01-01 00:00:00	\N	2020-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52333	51841	CONSINTCOM	2020-06-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52334	51842	VICPDTINTCOM	2015-01-01 00:00:00	\N	2017-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52334	51843	CONSINTCOM	2017-10-02 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52335	51844	CONSINTCOM	2015-01-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52566	53745	DEPUTE	2022-06-22 00:00:00	\N	2024-02-13 00:00:00	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52566	53746	QUESTAN	2024-02-13 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52768	53747	DEPUTE	2022-06-22 00:00:00	\N	2022-06-29 00:00:00	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52768	53748	QUESTAN	2022-06-29 00:00:00	\N	2024-02-13 00:00:00	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52768	53749	DEPUTE	2024-02-14 00:00:00	\N	2024-03-08 00:00:00	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52210	51808	CONSDPT	2020-10-15 00:00:00	\N	2021-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51992	51809	CONSMUNI	2020-10-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
51994	51810	CONSDPT	2020-10-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53170	52728	DEPUTE	2023-01-29 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53172	52731	DEPUTE	2022-06-22 00:00:00	\N	2022-12-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53885	53671	CONSDPT	2023-11-02 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53412	52849	MEMBREINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 12:17:49
53710	53463	VICPDTINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-10-04 17:24:58
53414	52851	PDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 12:17:49
53498	53562	VICPDTINTCOM	1499-12-23 00:50:39	\N	2023-11-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	\N
53478	53561	VICPDTINTCOM	1499-12-31 00:50:39	\N	1515-10-25 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	\N
53604	53563	MEMBREINTCOM	1499-12-31 00:50:39	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N
53886	53672	CONSMUNI	1515-10-24 00:50:39	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53714	53467	VICPDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-10-04 17:24:58
52482	53487	DEPUTE	2022-06-22 00:00:00	\N	2023-05-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52482	53488	SECAN	2023-05-10 00:00:00	\N	2023-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52482	53489	DEPUTE	2023-10-03 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52484	53490	DEPUTE	2022-06-22 00:00:00	\N	2023-05-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52484	53491	SECAN	2023-05-10 00:00:00	\N	2023-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52484	53492	DEPUTE	2023-10-03 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52695	53493	DEPUTE	2022-06-22 00:00:00	\N	2023-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52695	53494	SECAN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52734	53495	DEPUTE	2022-06-22 00:00:00	\N	2023-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52734	53496	SECAN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52820	53497	DEPUTE	2022-06-22 00:00:00	\N	2023-05-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52820	53498	SECAN	2023-05-10 00:00:00	\N	2023-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52820	53499	DEPUTE	2023-10-03 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53052	53500	DEPUTE	2022-06-22 00:00:00	\N	2023-10-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53052	53501	SECAN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53532	53567	VICPDTINTCOM	1499-12-31 00:50:39	\N	1515-10-24 00:50:39	\N	ANCIEN	\N	\N	\N	NON	\N	\N
53374	53568	MEMBREINTCOM	1499-12-31 00:50:39	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N
53655	53569	VICPDTINTCOM	1499-12-31 00:50:39	\N	2024-03-04 00:00:00	\N	ANCIEN	\N	Vice-Président	\N	\N	\N	\N
53539	53570	VICPDTINTCOM	1499-12-31 00:50:39	\N	2023-11-01 00:00:00	\N	ANCIEN	\N	Vice-Président	\N	\N	\N	\N
53591	53571	VICPDTINTCOM	1499-12-31 00:50:39	\N	1515-10-23 00:50:39	\N	ANCIEN	Vice-Président	Vice-Président	\N	\N	\N	\N
53546	53572	VICPDTINTCOM	1499-12-31 00:50:39	\N	1599-12-31 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	\N
53545	53573	PDTINTCOM	1499-12-31 00:50:39	\N	1514-12-22 00:50:39	\N	ANCIEN	\N	Président	\N	\N	\N	\N
53638	53574	PDTINTCOM	1499-12-31 00:50:39	\N	2023-11-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	\N
53645	53575	PDTINTCOM	1499-12-31 00:50:39	\N	1599-11-06 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	\N
53887	53673	MEMBREINTCOM	1515-10-31 00:50:39	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53708	53577	MEMBREINTCOM	1499-12-31 00:50:39	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N
53623	53578	VICPDTINTCOM	1499-12-31 00:50:39	\N	1515-10-27 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	\N
53898	53697	CONSMUNI	2023-11-06 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53573	53580	VICPDTINTCOM	1499-12-31 00:50:39	\N	2023-11-02 00:00:00	\N	ANCIEN	\N	\N	\N	NON	\N	\N
53650	53581	PDTINTCOM	1499-12-31 00:50:39	\N	2023-11-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	\N
53565	53582	VICPDTINTCOM	1499-12-31 00:50:39	\N	1599-11-06 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	\N
53566	53583	VICPDTINTCOM	1499-12-31 00:50:39	\N	1599-12-31 00:50:39	\N	ANCIEN	\N	\N	\N	NON	\N	\N
53555	53584	MEMBREINTCOM	1499-12-31 00:50:39	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N
53557	53585	MEMBREINTCOM	1499-12-31 00:50:39	\N	1599-12-31 00:50:39	\N	ANCIEN	\N	\N	\N	NON	\N	\N
53556	53586	VICPDTINTCOM	1499-12-31 00:50:39	\N	1599-12-31 00:50:39	\N	ANCIEN	\N	\N	\N	NON	\N	\N
53662	53587	PDTINTCOM	1499-12-31 00:50:39	\N	2024-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	\N
53663	53588	VICPDTINTCOM	1499-12-31 00:50:39	\N	1599-12-31 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	\N
53815	53589	PDTINTCOM	1499-12-31 00:50:39	\N	1599-12-31 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	\N
53816	53590	PDTINTCOM	1499-12-31 00:50:39	\N	1599-12-31 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	\N
53817	53591	PDTINTCOM	1499-12-31 00:50:39	\N	1599-12-31 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	\N
53527	53592	VICPDTINTCOM	1499-12-31 00:50:39	\N	2023-11-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	\N
53509	53594	VICPDTINTCOM	1499-12-31 00:50:39	\N	1599-11-06 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	\N
53496	53596	PDTINTCOM	1499-12-23 00:50:39	\N	1599-12-31 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	\N
53501	53597	PDTINTCOM	1499-12-31 00:50:39	\N	1599-12-31 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	\N
53582	53598	MEMBREINTCOM	1499-12-31 00:50:39	\N	1515-10-27 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	\N
53486	53600	VICPDTINTCOM	1499-12-31 00:50:39	\N	1599-12-31 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	\N
53454	53601	MEMBREINTCOM	1499-12-31 00:50:39	\N	1515-10-27 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	\N
53578	53602	CONSCOMINT	1499-12-31 00:50:39	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N
53449	53603	CONSCOMINT	1499-12-31 00:50:39	\N	1599-11-06 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	\N
53587	53604	PDTINTCOM	1600-01-09 00:50:39	\N	1699-11-06 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	\N
53588	53605	VICPDTINTCOM	1499-12-31 00:50:39	\N	1599-12-31 00:50:39	\N	ANCIEN	\N	\N	\N	NON	\N	\N
53424	53606	PDTINTCOM	1499-12-31 00:50:39	\N	2023-10-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	\N
53421	53607	PDTINTCOM	1499-12-31 00:50:39	\N	1599-11-06 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	\N
53798	53609	PDTINTCOM	1499-12-31 00:50:39	\N	1599-12-31 00:50:39	\N	ANCIEN	\N	\N	\N	NON	\N	\N
53406	53610	VICPDTINTCOM	1499-12-31 00:50:39	\N	2023-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	\N
53733	53611	VICPDTINTCOM	1499-12-31 00:50:39	\N	1599-12-31 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	\N
53839	53612	PDTINTCOM	1499-12-31 00:50:39	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N
53457	53613	VICPDTINTCOM	1499-12-31 00:50:39	\N	1515-10-27 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	\N
53505	53614	VICPDTINTCOM	1499-12-31 00:50:39	\N	2023-11-01 00:00:00	\N	ANCIEN	Vice-Président	Vice-Président	\N	\N	\N	\N
53520	53615	VICPDTINTCOM	1499-12-23 00:50:39	\N	1599-12-31 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	\N
53821	53617	MEMBREINTCOM	1499-12-31 00:50:39	\N	1599-12-31 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	\N
53676	53233	VICPDTINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-28 11:32:26
53677	53234	VICPDTREG	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-28 11:32:26
52773	52310	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52776	52313	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52779	52316	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52783	52320	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52786	52323	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52789	52326	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52792	52329	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52795	52332	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52798	52335	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52801	52338	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52858	52395	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52874	52411	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52876	52413	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52878	52415	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52880	52417	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52911	52448	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52912	52449	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52914	52451	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52916	52453	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52917	52454	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52919	52456	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52920	52457	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52922	52459	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52924	52461	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52926	52463	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52927	52464	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52929	52466	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52931	52468	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52932	52469	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52934	52471	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52935	52472	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52937	52474	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52939	52476	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52941	52478	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52942	52479	DEPUTE	2022-06-22 00:00:00	\N	2022-08-04 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52944	52481	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52946	52483	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52948	52485	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52949	52486	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52951	52488	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52953	52490	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52954	52491	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52956	52493	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52958	52495	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52960	52497	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52961	52498	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52963	52500	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52965	52502	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52967	52504	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52968	52505	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52970	52507	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52972	52509	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52974	52511	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52975	52512	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52977	52514	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52979	52516	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52981	52518	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52984	52521	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52985	52522	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52987	52524	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52989	52526	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52991	52528	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52992	52529	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52994	52531	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52996	52533	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52998	52535	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53000	52537	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53001	52538	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53003	52540	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53005	52542	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53007	52544	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53009	52546	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53011	52548	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53013	52550	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53014	52551	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53017	52554	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53020	52557	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53023	52560	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53025	52562	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53028	52565	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53031	52568	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53033	52570	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53036	52573	DEPUTE	2022-06-22 00:00:00	\N	2024-03-08 00:00:00	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53039	52576	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53041	52578	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53044	52581	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53046	52583	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53048	52585	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53051	52588	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53053	52590	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53056	52593	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53058	52595	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53061	52598	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53064	52601	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53066	52603	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53069	52606	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53071	52608	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53074	52611	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53076	52613	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53079	52616	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53081	52618	DEPUTE	2022-06-22 00:00:00	\N	2023-01-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53083	52620	DEPUTE	2022-06-22 00:00:00	\N	2024-03-08 00:00:00	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53086	52623	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53088	52625	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53091	52628	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53093	52630	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53095	52632	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53098	52635	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53100	52637	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53102	52639	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53105	52642	DEPUTE	2022-06-22 00:00:00	\N	2023-01-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53107	52644	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53109	52646	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53111	52648	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53113	52650	DEPUTE	2022-06-22 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53634	53170	MAIRE	1499-12-31 00:50:39	1500	2023-11-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-27 11:38:57
53635	53171	PDTINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-27 11:38:57
53931	53738	DEPUTE	2024-02-12 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53609	53127	MAIREADJOINT	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 18:16:22
53610	53128	CONSDPT	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 18:16:22
53928	53735	DEPUTE	2024-02-12 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53826	53445	CONSMUNI	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-10-02 19:10:56
52083	51535	MAIRE	2014-03-15 00:00:00	\N	2015-12-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52083	51536	MAIREADJOINT	2020-03-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52084	51537	CONSDPT	2015-12-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52084	51538	PDTDPT	2015-04-15 00:00:00	\N	2015-12-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52085	51539	VICPDTINTCOM	2020-03-15 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N
52086	51540	MAIREADJOINT	1995-04-15 00:00:00	\N	2001-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52086	51541	MAIRE	2001-03-15 00:00:00	\N	2015-04-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52086	51542	MAIREADJOINT	2015-04-15 00:00:00	\N	2020-10-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52087	51543	PDTDPT	2015-03-15 00:00:00	\N	2020-10-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53166	52725	DEPUTE	2022-06-22 00:00:00	\N	2022-12-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52088	51545	PDTINTCOM	2020-07-15 00:00:00	\N	2020-10-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	\N
52089	51546	MAIRE	2014-03-15 00:00:00	\N	2020-10-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52090	51547	VICPDTDPT	2015-03-15 00:00:00	\N	2020-10-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52241	51720	CONSMUNI	2020-06-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
52240	51719	MAIREARR	2014-03-15 00:00:00	\N	2017-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52242	51721	MAIRE	2017-09-15 00:00:00	\N	2020-10-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53378	52794	PDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 10:48:23
53377	52795	PDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 10:48:23
53376	52796	VICPDTINTCOM	1499-12-31 00:50:39	1500	1515-10-23 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 10:48:23
53558	53670	CONSMUNI	2023-11-02 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53592	53106	MAIRE	1499-12-31 00:50:39	1500	1599-11-06 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 17:45:31
53593	53107	VICPDTINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 17:45:31
53594	53108	VICPDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 17:45:31
53595	53109	VICPDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 17:45:31
53756	53548	VICPDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-10-05 17:11:10
53472	53725	CONSDPT	2023-11-06 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53755	53547	VICPDTINTCOM	1499-12-31 00:50:39	1500	1599-11-06 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	2023-10-05 17:11:10
53757	53549	VICPDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-10-05 17:11:10
53933	53740	DEPUTE	2024-02-12 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53935	53742	DEPUTE	2024-02-12 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53936	53743	DEPUTE	2024-02-12 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53937	53744	DEPUTE	2024-02-12 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
51780	51379	VICPDTDPT	2015-04-01 00:00:00	\N	2020-09-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51781	51380	MAIRE	2020-06-28 00:00:00	\N	2020-09-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51782	51381	VICPDTMET	2016-03-01 00:00:00	\N	2020-09-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53540	53031	MAIRE	1499-12-31 00:50:39	1500	1515-10-24 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 16:27:45
53541	53032	PDTINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 16:27:45
53542	53033	CONSDPT	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 16:27:45
53543	53034	CONSDPT	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 16:27:45
53544	53035	VICPDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 16:27:45
53944	53758	MAIRE	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2024-03-26 14:55:29
53945	53759	VICPDTINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2024-03-26 14:55:29
53946	53760	CONSDPT	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2024-03-26 16:47:54
51799	51396	DEPUTE	2020-08-27 00:00:00	\N	2022-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51800	51397	DEPUTE	2020-08-27 00:00:00	\N	2022-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51801	51398	DEPUTE	2020-08-27 00:00:00	\N	2022-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51802	51399	DEPUTE	2020-08-27 00:00:00	\N	2022-04-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51803	51400	DEPUTE	2020-08-27 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53778	53382	MEMBREINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-10-02 09:17:42
53780	53384	PDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-10-02 09:17:42
53781	53385	CONSREG	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-10-09 12:26:45
51798	51395	DEPUTE	2020-08-25 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52095	51551	VICPDTINTCOM	2020-07-15 00:00:00	\N	2020-10-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52096	51552	CONSREG	2015-12-15 00:00:00	\N	2021-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52133	51598	DEPUTE	2020-10-08 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52132	51597	DEPUTE	2020-10-08 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52134	51599	DEPUTE	2020-10-08 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52153	51630	CONSCOMINT	2008-03-15 00:00:00	\N	2020-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52156	51631	VICPDTDPT	2008-03-15 00:00:00	\N	2012-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52156	51632	CONSDPT	2005-06-15 00:00:00	\N	2008-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53117	52676	CONSMUNI	1989-03-15 00:00:00	\N	1995-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53118	52677	CONSMUNI	1995-03-15 00:00:00	\N	1997-05-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53118	52678	MAIRE	1997-05-15 00:00:00	\N	2001-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53119	52679	MAIRE	2001-03-15 00:00:00	\N	2008-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53120	52680	MAIRE	2008-03-15 00:00:00	\N	2014-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53121	52681	MAIRE	2014-03-15 00:00:00	\N	2016-05-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53122	52682	VICPDTDPT	2004-03-15 00:00:00	\N	2016-01-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
53404	52835	MAIREADJOINT	1499-12-31 00:50:39	1500	1599-11-06 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 12:10:30
53405	52836	VICPDTINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 12:10:30
53408	52841	MEMBREINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 12:12:07
53409	52842	CONSREG	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 12:12:07
53503	52976	MAIRE	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 16:01:37
53504	52977	VICPDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 16:01:37
53547	53044	CONSMUNI	1600-01-09 00:50:39	1500	2023-11-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 16:31:08
53548	53045	MEMBREINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 16:31:08
53549	53046	PDTDPT	1499-12-31 00:50:39	1500	1599-11-06 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 16:31:08
53551	53048	MAIRE	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 16:31:08
53553	53050	MEMBREINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 16:31:08
53554	53051	VICPDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 16:31:08
52216	51690	CONSREG	2015-12-15 00:00:00	\N	2021-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52217	51691	MAIRE	2001-03-15 00:00:00	\N	2020-07-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52218	51692	VICPDTINTCOM	2008-03-15 00:00:00	\N	2016-12-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52219	51693	CONSDPT	2011-03-15 00:00:00	\N	2015-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52223	51694	MAIRE	2020-06-15 00:00:00	\N	2020-10-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52224	51695	VICPDTINTCOM	2001-03-15 00:00:00	\N	2020-07-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52225	51696	VICPDTDPT	2015-03-15 00:00:00	\N	2020-09-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52223	51699	CONSMUNI	1995-06-15 00:00:00	\N	2001-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52223	51698	MAIRE	2001-03-15 00:00:00	\N	2020-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52229	51700	MEMBREINTCOM	1995-06-15 00:00:00	\N	2001-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52229	51701	VICPDTINTCOM	2001-06-15 00:00:00	\N	2014-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52229	51702	PDTINTCOM	2014-06-15 00:00:00	\N	2018-01-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52224	51703	VICPDTINTCOM	2020-07-15 00:00:00	\N	2020-09-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52225	51704	CONSDPT	2001-03-15 00:00:00	\N	2015-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52232	51705	MAIREADJOINT	1995-03-15 00:00:00	\N	2020-10-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52233	51706	CONSDPT	2015-03-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
52234	51707	PDTDPT	2015-04-15 00:00:00	\N	2020-10-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52234	51708	VICPDTDPT	2001-04-15 00:00:00	\N	2009-04-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52234	51709	CONSDPT	2009-04-15 00:00:00	\N	2015-04-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52234	51710	CONSDPT	1994-05-15 00:00:00	\N	2001-04-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52235	51711	CONSMUNI	2020-03-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
52235	51712	CONSMUNI	2001-03-15 00:00:00	\N	2020-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52236	51713	CONSREG	2004-03-15 00:00:00	\N	2015-12-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52237	51714	CONSDPT	2015-03-15 00:00:00	\N	2021-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52238	51715	MAIRE	1989-03-15 00:00:00	\N	2000-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52238	51716	MAIRE	2014-03-15 00:00:00	\N	2015-05-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52302	51781	PDTINTCOM	\N	2017	\N	2020	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52032	51907	CONSREG	2021-06-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
15260	51908	CONSREG	2021-06-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53517	52995	MAIREADJOINT	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-10-09 12:25:56
53518	52996	PDTDPT	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-10-09 12:25:56
53519	52997	VICPDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 16:11:40
53656	53206	MAIREADJOINT	1600-01-09 00:50:39	1600	2024-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-27 15:47:44
53657	53207	PDTINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-27 15:47:44
53659	53209	MAIRE	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-27 15:47:44
53660	53210	PDTDPT	1499-12-31 00:50:39	1500	1599-12-31 00:50:39	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-27 15:47:44
53661	53211	VICPDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-27 15:47:44
53670	53225	MAIREADJOINT	1600-01-09 00:50:39	1500	2023-11-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-27 17:38:26
53671	53226	MEMBREINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-27 17:38:26
53672	53227	CONSMUNI	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-27 17:38:26
53416	53644	MEMBREINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-10-09 12:26:45
53785	53392	VICPDTINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-10-02 09:20:03
53787	53394	PDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-10-02 09:20:03
53788	53395	PDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-10-02 09:20:03
52345	51858	CONSINTCOM	2016-01-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52344	51857	CONSINTCOM	2015-12-14 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52346	51859	CONSINTCOM	2016-01-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52347	51860	CONSINTCOM	2016-01-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52348	51861	CONSINTCOM	2016-01-01 00:00:00	\N	2020-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52349	51862	CONSINTCOM	2016-01-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52091	51863	CONSMUNI	2020-10-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52095	51864	CONSCOMINT	2020-10-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52123	51865	CONSMUNI	2020-10-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52125	51866	CONSCOMINT	2020-10-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52362	51881	DEPUTE	2021-01-13 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53133	52693	DEPUTE	2022-08-05 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53134	52694	DEPUTE	2022-08-05 00:00:00	\N	2023-08-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53135	52695	DEPUTE	2022-08-05 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53136	52696	DEPUTE	2022-08-05 00:00:00	\N	2024-02-11 00:00:00	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53137	52697	DEPUTE	2022-08-05 00:00:00	\N	2022-08-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53138	52698	DEPUTE	2022-08-05 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53139	52699	DEPUTE	2022-08-05 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53140	52700	DEPUTE	2022-08-05 00:00:00	\N	2024-02-11 00:00:00	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53141	52701	DEPUTE	2022-08-05 00:00:00	\N	2024-02-11 00:00:00	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53142	52702	DEPUTE	2022-08-05 00:00:00	\N	2024-02-09 00:00:00	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53143	52703	DEPUTE	2022-08-05 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53193	52775	DEPUTE	2023-08-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53194	52776	DEPUTE	2023-08-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53195	52777	DEPUTE	2023-08-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53196	52778	DEPUTE	2023-08-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53197	52779	DEPUTE	2023-08-21 00:00:00	\N	2024-02-11 00:00:00	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53198	52780	DEPUTE	2023-08-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53611	53129	DEPUTE	2023-09-25 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53840	53550	VICPDTINTCOM	1499-12-31 00:50:39	1500	1599-12-31 00:50:39	1600	ANCIEN	\N	\N	\N	\N	\N	\N
53838	53552	VICPDTINTCOM	1499-12-31 00:50:39	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N
53403	53553	MEMBREINTCOM	1499-12-23 00:50:39	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N
53441	53554	MEMBREINTCOM	1499-12-23 00:50:39	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N
53428	53555	CONSCOMINT	1499-12-31 00:50:39	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N
53774	53558	CONSCOMINT	1499-12-31 00:50:39	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N
53445	53557	MEMBREINTCOM	1499-12-31 00:50:39	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N
53669	53559	PDTINTCOM	1499-12-31 00:50:39	\N	1599-11-06 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	\N
52044	51778	CONSMUNI	2020-10-16 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52079	51779	CONSMUNI	2020-10-21 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53372	52786	MEMBREINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-25 13:39:29
53371	52787	CONSMUNI	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 16:15:47
53418	52856	MAIRE	1499-12-31 00:50:39	1500	1599-11-06 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 12:21:15
53419	52857	PDTINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 12:21:15
53420	52858	CONSREG	1499-12-31 00:50:39	1500	2023-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 12:21:15
53488	52960	VICPDTINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 15:56:57
53487	52961	MAIREDEL	1499-12-31 00:50:39	1500	2023-11-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 15:56:57
53489	52962	MAIRE	1499-12-31 00:50:39	1500	1515-10-13 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 15:56:57
53490	52963	VICPDTINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 15:56:57
53492	52965	PDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 15:56:57
53493	52966	PDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 15:56:57
52459	51996	DEPUTE	2022-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52460	51997	DEPUTE	2022-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52461	51998	DEPUTE	2022-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52462	51999	DEPUTE	2022-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52463	52000	DEPUTE	2022-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52464	52001	DEPUTE	2022-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52465	52002	DEPUTE	2022-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52466	52003	DEPUTE	2022-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52467	52004	DEPUTE	2022-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52468	52005	DEPUTE	2022-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52469	52006	DEPUTE	2022-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52470	52007	DEPUTE	2022-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52471	52008	DEPUTE	2022-06-21 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53922	53727	CONSMUNI	2023-12-20 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53424	53728	MEMBREINTCOM	2023-10-21 00:00:00	\N	\N	\N	ACTIF	\N	Membre	\N	\N	\N	\N
52027	51445	DEPUTE	2020-09-28 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52383	51900	CONSDPT	2021-07-06 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53617	53140	CONSPARI	1499-12-31 00:50:39	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53620	53667	VICPDTGEN	1499-12-31 00:50:39	\N	1515-10-27 00:50:39	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53882	53665	CONSDPT	2023-11-03 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
51776	51378	DEPUTE	2020-07-29 00:00:00	\N	2020-07-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51795	51392	DEPUTE	2020-08-01 00:00:00	\N	2020-08-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51796	51393	DEPUTE	2020-08-07 00:00:00	\N	2020-09-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51797	51394	DEPUTE	2020-08-07 00:00:00	\N	2022-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52058	51488	CONSMET	2020-06-15 00:00:00	\N	2020-10-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52099	51554	CONSMUNI	2014-03-15 00:00:00	\N	2020-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52099	51555	MAIREADJOINT	2020-03-15 00:00:00	\N	2020-10-09 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52100	51556	MAIRE	1983-03-15 00:00:00	\N	2020-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52101	51557	VICPDTINTCOM	1995-04-15 00:00:00	\N	2008-04-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52103	51558	MAIRE	1991-01-15 00:00:00	\N	2019-01-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52104	51559	CONSMUNI	2020-06-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52105	51560	VICPDTREG	2015-12-15 00:00:00	\N	2020-10-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52106	51561	PDTINTCOM	1996-01-15 00:00:00	\N	2014-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52106	51562	MEMBREINTCOM	2014-03-15 00:00:00	\N	2019-01-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52107	51564	CONSMUNI	1995-06-15 00:00:00	\N	2001-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52107	51565	MAIREADJOINT	2001-06-15 00:00:00	\N	2008-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52107	51566	MAIREADJOINT	2020-06-15 00:00:00	\N	2020-10-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52108	51567	MEMBREINTCOM	2020-06-15 00:00:00	\N	2020-10-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52109	51568	VICPDTDPT	2015-03-15 00:00:00	\N	2020-10-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52111	51569	VICPDTINTCOM	2001-06-15 00:00:00	\N	2008-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52109	51570	CONSDPT	2008-03-15 00:00:00	\N	2015-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51992	51413	MAIRE	2020-03-15 00:00:00	\N	2020-10-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51993	51414	MEMBREINTCOM	2020-03-15 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N
51994	51415	VICPDTDPT	2015-03-15 00:00:00	\N	2020-10-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51995	51416	PDTINTCOM	2000-12-15 00:00:00	\N	2014-02-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	\N
51996	51417	VICPDTINTCOM	2018-01-15 00:00:00	\N	2020-03-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	\N
51997	51418	PDTINTCOM	2014-03-15 00:00:00	\N	2017-12-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	\N
51998	51419	CONSDPT	2004-03-15 00:00:00	\N	2008-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51999	51420	CONSDPT	2004-03-15 00:00:00	\N	2021-06-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52000	51421	MAIRE	2000-05-15 00:00:00	\N	2020-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52000	51422	MAIREADJOINT	1995-03-15 00:00:00	\N	2000-04-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52000	51423	CONSMUNI	1990-09-15 00:00:00	\N	1995-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52004	51426	MAIRE	2020-03-15 00:00:00	\N	2020-10-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52003	51425	VICPDTINTCOM	2003-01-15 00:00:00	\N	2020-06-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	\N
52005	51427	PDTINTCOM	2014-04-15 00:00:00	\N	2020-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	\N
52009	51428	MAIRE	2010-03-15 00:00:00	\N	2014-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52010	51429	VICPDTDPT	2015-03-15 00:00:00	\N	2020-09-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52011	51430	CONSMUNI	2008-03-15 00:00:00	\N	2020-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52015	51434	MEMBREINTCOM	2020-07-15 00:00:00	\N	2020-10-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	\N
52013	51432	MAIREADJOINT	2020-06-15 00:00:00	\N	2020-10-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52016	51435	CONSDPT	2015-03-15 00:00:00	\N	2021-06-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52363	51882	DEPUTE	2021-01-22 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53372	52784	MEMBREINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-25 12:48:17
53371	52785	CONSMUNI	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-25 12:48:17
53574	53080	MAIREADJOINT	1499-12-31 00:50:39	1500	1599-11-06 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 17:13:52
53575	53081	MEMBREINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 17:13:52
53576	53082	CONSREG	1499-12-31 00:50:39	1500	1599-11-06 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 17:13:52
53577	53083	CONSDPT	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 17:13:52
53703	53266	MAIREADJOINT	1499-12-31 00:50:39	1500	2024-03-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-28 16:41:03
52018	51436	MAIRE	2020-06-15 00:00:00	\N	2020-10-26 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52366	51889	DEPUTE	2021-04-06 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52020	51438	VICPDTINTCOM	2020-06-15 00:00:00	\N	2020-10-26 00:00:00	\N	ANCIEN	communauté de communes C¿ur d'Yvelines	communauté de communes C¿ur d'Yvelines	\N	NON	\N	\N
52407	51932	MAIREADJOINT	2015-06-15 00:00:00	\N	2021-07-12 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52407	51933	CONSMUNI	2021-07-13 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52493	52654	DEPUTE	2022-06-22 00:00:00	\N	2022-06-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52409	51935	VICPDTDPT	2015-04-15 00:00:00	\N	2021-06-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52493	52655	QUESTAN	2022-06-29 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52515	52656	DEPUTE	2022-06-22 00:00:00	\N	2022-06-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52515	52657	QUESTAN	2022-06-29 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52548	52658	DEPUTE	2022-06-22 00:00:00	\N	2022-06-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52548	52659	VICPDTAN	2022-06-29 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52651	52660	DEPUTE	2022-06-22 00:00:00	\N	2022-06-29 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52651	52661	VICPDTAN	2022-06-29 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53174	52733	DEPUTE	2022-06-22 00:00:00	\N	2022-12-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53185	52767	DEPUTE	2023-06-04 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53173	52732	DEPUTE	2023-01-29 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52239	51717	CONSREG	1992-03-15 00:00:00	\N	2002-05-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52321	51828	MEMBREINTCOM	2008-04-15 00:00:00	\N	2020-10-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53180	52740	DEPUTE	2023-04-02 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53184	52766	CONSMUNI	2020-03-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53705	53272	MEMBREINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-28 16:52:20
53707	53274	MAIREADJOINT	1499-12-31 00:50:39	1500	1599-12-31 00:50:39	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-28 16:52:20
53827	53451	MAIRE	1499-12-31 00:50:39	1500	2023-11-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	2023-10-02 16:50:01
53828	53452	PDTINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-10-02 11:35:30
53829	53453	VICPDTREG	1499-12-31 00:50:39	1500	2023-11-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	2023-10-02 16:50:01
53830	53454	PDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-10-02 11:35:30
53831	53455	PDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-10-02 11:35:30
52170	51814	CONSMUNI	2020-10-20 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53614	53137	CONSDPT	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-27 09:52:14
53615	53138	MAIREADJOINT	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-27 09:52:14
53616	53139	CONSDPT	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-27 09:52:14
53801	53412	MAIREADJOINT	1499-12-31 00:50:39	1500	2023-11-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	2023-10-02 10:55:34
53802	53413	MEMBREINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-10-02 10:55:34
53836	53459	PDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-10-02 16:50:01
53837	53460	PDTINTCOM	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-10-02 16:50:01
53835	53461	PDTINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-10-02 16:50:01
53945	53764	VICPDTINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2024-03-26 16:47:54
53948	53765	MAIRE	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2024-03-26 16:47:54
52091	51548	MAIREADJOINT	2008-03-15 00:00:00	\N	2020-05-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52091	51549	MAIRE	2020-05-15 00:00:00	\N	2020-10-27 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53475	52938	VICPDTINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 15:52:29
53474	52937	MAIRE	1499-12-31 00:50:39	1500	1515-10-25 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 15:52:29
53476	52939	VICPDTREG	1499-12-31 00:50:39	1500	1515-10-25 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 15:52:29
53477	52940	CONSDPT	1500-01-01 00:00:00	1500	1600-01-01 00:00:00	1600	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 15:52:29
53536	53023	MAIRE	1499-12-31 00:50:39	1500	2023-11-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 16:22:23
53537	53024	VICPDTINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 16:22:23
53538	53025	CONSREG	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 16:22:23
53908	53711	CONSDPT	2023-11-13 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52214	51686	CONSMUNI	2020-03-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
52214	51687	MAIRE	\N	2001	\N	2014	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52214	51688	CONSMUNI	\N	2014	\N	2020	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52215	51689	CONSMUNI	1989-03-15 00:00:00	\N	2001-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52329	51831	MAIREADJOINT	2014-03-15 00:00:00	\N	2020-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52330	51832	VICPDTINTCOM	2020-07-15 00:00:00	\N	2020-11-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52331	51833	CONSDPT	2015-03-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
52329	51834	MAIREADJOINT	2001-03-15 00:00:00	\N	2008-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52329	51835	CONSMUNI	2008-03-15 00:00:00	\N	2014-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52329	51836	MAIREADJOINT	2020-03-15 00:00:00	\N	2020-11-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
53921	53726	DEPUTE	2023-12-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52059	51867	CONSMUNI	2020-10-23 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52061	51868	CONSINTCOM	2016-01-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52157	51633	MAIREADJOINT	2008-03-15 00:00:00	\N	2020-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52158	51634	VICPDTINTCOM	2008-03-15 00:00:00	\N	2020-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52162	51635	MAIRE	2001-03-15 00:00:00	\N	2020-10-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52772	52652	DEPUTE	2022-06-22 00:00:00	\N	2022-06-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52163	51637	PDTINTCOM	2001-09-15 00:00:00	\N	2020-07-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52164	51638	MAIRE	2001-03-15 00:00:00	\N	2020-10-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52165	51639	VICPDTINTCOM	2020-06-15 00:00:00	\N	2020-10-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52165	51640	PDTINTCOM	2017-01-15 00:00:00	\N	2020-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52167	51641	MAIRE	2020-03-15 00:00:00	\N	2020-10-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52169	51642	CONSDPT	2015-03-15 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	NON	\N	\N
52167	51643	MAIRE	1989-03-15 00:00:00	\N	2014-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52170	51644	MAIRE	2008-03-15 00:00:00	\N	2020-10-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52171	51645	VICPDTINTCOM	2014-03-15 00:00:00	\N	2020-10-20 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52172	51646	MAIRE	2020-03-15 00:00:00	\N	2020-10-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52172	51647	MAIRE	2014-03-15 00:00:00	\N	2020-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	NON	\N	\N
52772	52653	PDTAN	2022-06-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53178	52738	DEPUTE	2023-01-29 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53801	53678	CONSPARI	2023-11-02 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52413	51944	CONSDPT	2021-06-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52414	51945	CONSDPT	2021-06-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
51213	51946	CONSDPT	2021-06-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
12940	51947	CONSMUNI	2020-06-28 00:00:00	\N	2021-07-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
15163	51948	CONSDPT	2021-06-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
51000	51949	CONSREG	2021-06-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52415	51950	CONSDPT	2021-07-01 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52416	51951	CONSREG	2021-07-02 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52422	51956	DEPUTE	2021-08-01 00:00:00	\N	2021-09-14 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52423	51957	DEPUTE	2021-08-01 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52424	51958	DEPUTE	2021-08-02 00:00:00	\N	2021-08-02 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52443	51974	CONSMUNI	2006-10-01 00:00:00	\N	2008-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52443	51975	MAIREADJOINT	2014-03-01 00:00:00	\N	2020-03-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52443	51976	MAIREADJOINT	2008-03-16 00:00:00	\N	2014-02-28 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52443	51977	MAIREADJOINT	2020-03-16 00:00:00	\N	2021-12-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52444	51978	MEMBREINTCOM	2008-03-15 00:00:00	\N	2014-03-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	\N
52446	51981	CONSREG	2022-01-07 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52447	51982	CONSREG	2015-12-15 00:00:00	\N	2021-06-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52447	51983	VICPDTREG	2021-06-16 00:00:00	\N	2021-12-31 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52451	51988	DEPUTE	2022-01-30 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52452	51989	DEPUTE	2022-01-30 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52494	52748	DEPUTE	2022-06-22 00:00:00	\N	2023-05-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52494	52749	SECAN	2023-05-10 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52576	52750	DEPUTE	2022-06-22 00:00:00	\N	2023-05-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52576	52751	SECAN	2023-05-10 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52585	52752	DEPUTE	2022-06-22 00:00:00	\N	2023-05-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52585	52753	SECAN	2023-05-10 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52604	52754	DEPUTE	2022-06-22 00:00:00	\N	2023-05-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52604	52755	SECAN	2023-05-10 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52676	52756	DEPUTE	2022-06-22 00:00:00	\N	2023-05-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52676	52757	SECAN	2023-05-10 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52744	52758	DEPUTE	2022-06-22 00:00:00	\N	2023-05-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52744	52759	SECAN	2023-05-10 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52780	52760	DEPUTE	2022-06-22 00:00:00	\N	2023-05-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52780	52761	SECAN	2023-05-10 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52827	52764	DEPUTE	2022-06-22 00:00:00	\N	2023-05-10 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52827	52765	SECAN	2023-05-10 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53422	52861	MAIRE	1499-12-31 00:50:39	1500	2023-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 12:35:02
53423	52862	PDTINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 12:35:02
53425	52866	MAIRE	1499-12-31 00:50:39	1500	1515-10-24 00:50:39	\N	ANCIEN	\N	\N	\N	\N	\N	2023-09-26 12:35:51
53426	52867	MEMBREINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 12:35:51
53427	52868	CONSREG	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-26 12:35:51
53751	53343	VICPDTINTCOM	1500-01-01 00:00:00	1500	\N	\N	ACTIF	\N	\N	\N	\N	\N	2023-09-28 17:13:39
49407	51515	DEPUTE	2017-06-21 00:00:00	\N	2020-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
49407	51516	SECAN	2020-10-01 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50376	51517	DEPUTE	2017-06-21 00:00:00	\N	2020-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50376	51518	SECAN	2020-10-01 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50396	51519	DEPUTE	2017-06-21 00:00:00	\N	2019-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50396	51520	SECAN	2019-10-01 00:00:00	\N	2020-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50396	51521	DEPUTE	2020-10-01 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50417	51522	DEPUTE	2017-06-21 00:00:00	\N	2019-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50417	51523	SECAN	2019-10-01 00:00:00	\N	2020-09-30 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50417	51524	DEPUTE	2020-10-01 00:00:00	\N	2021-03-05 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50560	51525	DEPUTE	2017-06-21 00:00:00	\N	2020-10-01 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
50560	51526	SECAN	2020-10-01 00:00:00	\N	2022-06-21 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
52010	51901	CONSDPT	2021-06-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52384	51902	CONSREG	2021-06-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52184	51903	CONSDPT	2021-06-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52172	51904	CONSMUNI	2020-10-31 00:00:00	\N	2021-07-15 00:00:00	\N	ANCIEN	\N	Nouvelle fonction	\N	\N	\N	\N
51040	51905	CONSDPT	2021-06-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52210	51906	CONSDPT	2021-06-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
52421	51955	CONSREG	2021-07-02 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53147	52706	DEPUTE	2022-11-10 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
51632	52710	CONSMUNI	2018-09-09 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53918	53719	CONSMUNI	2023-11-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53150	52712	CONSREG	2021-06-27 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53917	53718	CONSMUNI	2023-11-28 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53565	53720	CONSCOMINT	2023-11-06 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N
53919	53721	CONSMUNI	2023-11-06 00:00:00	\N	\N	\N	ACTIF	\N	Nouvelle fonction	\N	\N	\N	\N
53645	53722	CONSCOMINT	2023-11-06 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N
\.


--
-- Data for Name: eluvil; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY eluvil (eluid, eludatdeb, eludatelu, eludatfin, temvalcod, evelic, evelib, evelil, eveobs, eluanndeb, eluannfin, elunbrhab, typmancod, senmat, vilart, eludatcum, vilurlcmp, url, syscredat, sysmajdat) FROM stdin;
726	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Handschuheim	\N	\N	1965	2001	232	MUNICIPAL	77029G	de 	\N	\N	\N	\N	\N
727	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Wasselonne	\N	\N	\N	2001	4916	MUNICIPAL	91002E	de 	\N	\N	\N	\N	\N
729	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Lapoutroie	\N	\N	1977	2001	1981	MUNICIPAL	86030A	de 	\N	\N	\N	\N	\N
730	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Landser	\N	\N	1977	2001	1941	MUNICIPAL	95045J	de 	\N	http://www.ville-landser.fr/	\N	\N	\N
731	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Villeurbanne	\N	\N	\N	2001	116872	MUNICIPAL	95017E	de 	\N	http://www.mairie-villeurbanne.fr/	\N	\N	\N
732	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Corcelles-en-Beaujolais	\N	\N	1971	2001	633	MUNICIPAL	77047J	de 	\N	\N	\N	\N	\N
733	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Thizy	\N	\N	\N	2001	2855	MUNICIPAL	95049N	de 	\N	\N	\N	\N	\N
734	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Vénissieux	\N	\N	\N	2001	60444	MUNICIPAL	95032D	de 	\N	http://www.ville-venissieux.fr/	\N	\N	\N
735	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Vesoul	\N	\N	\N	2001	17614	MUNICIPAL	95041E	de 	\N	\N	\N	\N	\N
736	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Sennecey-le-Grand	\N	\N	\N	2001	2568	MUNICIPAL	95030B	de 	\N	\N	\N	\N	\N
737	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Sainte-Radegonde	\N	\N	\N	2001	201	MUNICIPAL	86043F	de 	\N	\N	\N	\N	\N
738	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Dompierre-les-Ormes	\N	\N	\N	2001	833	MUNICIPAL	95020Y	de 	\N	\N	\N	\N	\N
739	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Le Luart	\N	\N	\N	2001	952	MUNICIPAL	77043E	de 	\N	\N	\N	\N	\N
740	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Lombron	\N	\N	\N	2001	1786	MUNICIPAL	95019G	de 	\N	http://www.mairie-lombron.fr	\N	\N	\N
741	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Montmélian	\N	\N	\N	2001	3930	MUNICIPAL	77060F	de 	\N	http://www.montmelian.com/	\N	\N	\N
742	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Groisy	\N	\N	\N	2001	2190	MUNICIPAL	95015C	de 	\N	http://www.groisy.org	\N	\N	\N
743	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Sevrier	\N	\N	1977	2001	2980	MUNICIPAL	95038K	de 	\N	\N	\N	\N	\N
744	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Serraval	\N	\N	\N	2001	430	MUNICIPAL	95005A	de 	\N	\N	\N	\N	\N
745	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Les Grandes-Ventes	\N	\N	\N	2001	1729	MUNICIPAL	95014B	de 	\N	\N	\N	\N	\N
748	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Grand-Quevilly	\N	\N	1977	2001	27658	MUNICIPAL	95003X	de 	\N	\N	\N	\N	\N
749	\N	\N	2011-02-23 00:00:00	ANCIEN	\N	Le Petit-Quevilly	\N	\N	\N	2011	22600	MUNICIPAL	88006J	de 	\N	\N	\N	\N	\N
750	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Le Havre	\N	\N	1993	2001	197299	MUNICIPAL	95034F	de 	\N	http://www.ville-lehavre.fr/	\N	\N	\N
751	\N	\N	1999-11-27 00:00:00	ANCIEN	\N	Provins	\N	\N	\N	1999	11608	MUNICIPAL	95054K	de 	\N	http://www.mairie-provins.fr/	\N	\N	\N
752	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Coulombs-en-Valois	\N	\N	\N	2001	482	MUNICIPAL	83003J	de 	\N	\N	\N	\N	\N
753	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	La Madeleine-sur-Loing	\N	\N	\N	2001	287	MUNICIPAL	95039L	de 	\N	\N	\N	\N	\N
754	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Pantin	\N	\N	\N	2001	47303	MUNICIPAL	78007E	de 	\N	http://www.ville-pantin.fr/	\N	\N	\N
755	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Neuilly-Plaisance	\N	\N	1983	2001	18195	MUNICIPAL	95024D	de 	\N	\N	\N	\N	\N
756	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Neuilly-sur-Marne	\N	\N	\N	2001	31461	MUNICIPAL	95046K	de 	\N	\N	\N	\N	\N
757	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Pré-Saint-Gervais	\N	\N	\N	2001	15373	MUNICIPAL	77017C	du	\N	\N	\N	\N	\N
759	\N	\N	2002-12-10 00:00:00	ANCIEN	\N	Villemomble	\N	\N	1983	2002	26863	MUNICIPAL	86014A	de 	\N	http://www.villemomble.fr/	\N	\N	\N
760	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Moncoutant	\N	\N	1977	2001	3102	MUNICIPAL	95009E	de 	\N	\N	\N	\N	\N
761	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Ménigoute	\N	\N	1983	2001	895	MUNICIPAL	95028H	de 	\N	\N	\N	\N	\N
764	\N	\N	1998-11-02 00:00:00	ANCIEN	\N	Dourgne	\N	\N	\N	1998	1211	MUNICIPAL	95048M	de 	\N	\N	\N	\N	\N
765	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Le Ségur	\N	\N	\N	2001	265	MUNICIPAL	95052H	de 	\N	\N	\N	\N	\N
766	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Valence-d'Agen	\N	\N	1977	2001	4901	MUNICIPAL	86010V	de 	\N	\N	\N	\N	\N
767	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Caussade	\N	\N	\N	2001	6009	MUNICIPAL	88008L	de 	\N	\N	\N	\N	\N
768	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Sucy-en-Brie	\N	\N	\N	2001	25839	MUNICIPAL	95057N	de 	\N	\N	\N	\N	\N
770	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Vincennes	\N	\N	\N	2001	42267	MUNICIPAL	86018E	de 	\N	http://www.mairie-vincennes.fr/	\N	\N	\N
772	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Ecouen	\N	\N	1977	2001	4846	MUNICIPAL	97009N	d'	\N	http://www.ecouen.fr/	\N	\N	\N
773	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Garges-lès-Gonesse	\N	\N	\N	2001	42144	MUNICIPAL	95051G	de 	\N	http://www.garges.net	\N	\N	\N
774	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Pignans	\N	\N	\N	2001	2338	MUNICIPAL	95031C	de 	\N	\N	\N	\N	\N
775	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Saint-Raphaël	\N	\N	\N	2001	26616	MUNICIPAL	86035F	de 	\N	\N	\N	\N	\N
776	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Vaison-la-Romaine	\N	\N	\N	2001	5663	MUNICIPAL	95037J	de 	\N	\N	\N	\N	\N
778	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	La Guérinière	\N	\N	\N	2001	1402	MUNICIPAL	86041D	de 	\N	\N	\N	\N	\N
779	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Mouilleron-le-Captif	\N	\N	\N	2001	3238	MUNICIPAL	95021A	de 	\N	\N	\N	\N	\N
780	\N	\N	2000-05-24 00:00:00	ANCIEN	\N	Nieul-sur-l'Autise	\N	\N	\N	2000	943	MUNICIPAL	87002A	de 	\N	\N	\N	\N	\N
782	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Chasseneuil-du-Poitou	\N	\N	\N	2001	3200	MUNICIPAL	95059Q	de 	\N	\N	\N	\N	\N
783	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Saint-Martin-le-Vieux	\N	\N	\N	2001	719	MUNICIPAL	90004C	de 	\N	\N	\N	\N	\N
784	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Châlus	\N	\N	\N	2001	1907	MUNICIPAL	95055L	de 	\N	\N	\N	\N	\N
785	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Remiremont	\N	\N	\N	2001	9068	MUNICIPAL	77058M	de 	\N	http://www.remiremont.fr/	\N	\N	\N
786	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Auxerre	\N	\N	\N	2001	38819	MUNICIPAL	95033E	d'	\N	http://www.auxerre.com	\N	\N	\N
787	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Saint-Valérien	\N	\N	1977	2001	1666	MUNICIPAL	86044G	de 	\N	\N	\N	\N	\N
788	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Montigny-le-Bretonneux	\N	\N	1977	2001	31687	MUNICIPAL	95004Y	de 	\N	\N	\N	\N	\N
789	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Rambouillet	\N	\N	\N	2001	24343	MUNICIPAL	86034E	de 	\N	http://www.rambouillet.fr	\N	\N	\N
790	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Le Pecq	\N	\N	\N	2001	17006	MUNICIPAL	95035G	de 	\N	http://www.ville-lepecq.fr/	\N	\N	\N
791	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Buchelay	\N	\N	\N	2001	2066	MUNICIPAL	95013A	de 	\N	\N	\N	\N	\N
792	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Basse-Terre	\N	\N	\N	2001	13796	MUNICIPAL	95050F	de 	\N	\N	\N	\N	\N
794	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Iracoubo	\N	\N	\N	2001	1578	MUNICIPAL	89035T	d'	\N	\N	\N	\N	\N
795	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Le Marin	\N	\N	\N	2001	6429	MUNICIPAL	86021Y	de 	\N	\N	\N	\N	\N
796	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Fort-de-France	\N	\N	\N	2001	100663	MUNICIPAL	95044H	de 	\N	\N	\N	\N	\N
797	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Le Tampon	\N	\N	\N	2001	48436	MUNICIPAL	98002K	de 	\N	http://perso.wanadoo.fr/le-tampon/index.htm	\N	\N	\N
798	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Saint-Paul	\N	\N	\N	2001	71952	MUNICIPAL	96003C	de 	\N	\N	\N	\N	\N
799	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Ouvéa	\N	\N	1983	2001	3540	MUNICIPAL	92033R	d'	\N	\N	\N	\N	\N
800	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Sainte Cécile les Vignes	\N	\N	\N	2001	1927	MUNICIPAL	86042E	de 	\N	http://sainte-cecile.org	\N	\N	\N
5029	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Clermont-Ferrand	\N	\N	1971	2001	136181	MUNICIPAL	98009S	de 	\N	\N	\N	\N	\N
5007	1995-06-18 00:00:00	\N	2001-03-11 00:00:00	ANCIEN	\N	Brive-la-Gaillarde	\N	\N	\N	2001	49765	MUNICIPAL	98007Q	de 	\N	\N	\N	\N	\N
5044	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Cavan	\N	\N	1971	2001	1080	MUNICIPAL	98012M	de 	\N	http://www.mairie-cavan.fr/	\N	\N	\N
5040	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Eup	\N	\N	1986	2001	151	MUNICIPAL	98011L	d'	\N	\N	\N	\N	\N
5050	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Pacy-sur-Eure	\N	\N	1977	2001	4295	MUNICIPAL	98013N	de 	\N	\N	\N	\N	\N
5058	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Surgères	\N	\N	1971	2001	6049	MUNICIPAL	98014P	de 	\N	\N	\N	\N	\N
5061	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Aix-En-Provence	\N	\N	1989	2001	123842	MUNICIPAL	98015Q	d'	\N	\N	\N	\N	\N
5062	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Marseille	\N	\N	1965	2001	80055	MUNICIPAL	89029V	de 	\N	http://www.mairie-marseille.fr/	\N	\N	\N
5069	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Roquefort-la-Bédoule	\N	\N	1983	2001	4162	MUNICIPAL	98017S	de 	\N	\N	\N	\N	\N
5075	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Chateauneuf-les-Martigues	\N	\N	1953	2001	10911	MUNICIPAL	98020M	de 	\N	\N	\N	\N	\N
5088	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	2e secteur de Marseille	\N	\N	1977	2001	800550	MUNICIPAL	98022P	du	\N	\N	\N	\N	\N
5101	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Cérilly	\N	\N	1977	2001	1591	MUNICIPAL	98024R	de 	\N	\N	\N	\N	\N
5103	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Bourges	\N	\N	1989	2001	75609	MUNICIPAL	98025S	de 	\N	http://www.ville-bourges.fr/	\N	\N	\N
5116	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Ribérac	\N	\N	1971	2001	4118	MUNICIPAL	98029W	de 	\N	http://www.mairie-riberac.fr/	\N	\N	\N
5123	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Saint-Flour	\N	\N	1993	2001	7417	MUNICIPAL	98027U	de 	\N	\N	\N	\N	\N
5124	1971-03-21 00:00:00	\N	2001-03-11 00:00:00	ANCIEN	\N	Volx	\N	\N	\N	2001	2516	MUNICIPAL	98030P	de 	\N	\N	\N	\N	\N
5127	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Guéret	\N	\N	1978	2001	14706	MUNICIPAL	80024B	de 	\N	\N	\N	\N	\N
5129	1997-01-19 00:00:00	\N	2001-03-11 00:00:00	ANCIEN	\N	Périgueux	\N	\N	\N	2001	30280	MUNICIPAL	98031Q	de 	\N	http://www.ville-perigueux.fr/	\N	\N	\N
5132	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Marsan	\N	\N	1976	2001	420	MUNICIPAL	98032R	de 	\N	\N	\N	\N	\N
5135	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Lupiac	\N	\N	1965	2001	356	MUNICIPAL	98033S	de 	\N	\N	\N	\N	\N
5139	\N	\N	1999-06-11 00:00:00	ANCIEN	\N	Le Vigan	\N	\N	1977	\N	4523	MUNICIPAL	98034T	de 	\N	\N	\N	\N	\N
5143	1995-06-25 00:00:00	\N	2001-03-11 00:00:00	ANCIEN	\N	Saint-Quentin	\N	\N	1995	2001	60644	MUNICIPAL	98036V	de 	\N	\N	\N	\N	\N
5149	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Antraigues sur Volane	\N	\N	1983	2001	506	MUNICIPAL	98037W	d'	\N	\N	\N	\N	\N
5152	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Plénée-Jugon	\N	\N	1983	2001	2235	MUNICIPAL	98038X	de 	\N	\N	\N	\N	\N
5154	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Etagnac	\N	\N	1993	2001	949	MUNICIPAL	98039Y	d'	\N	\N	\N	\N	\N
5165	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Caen	\N	\N	1995	2001	112846	MUNICIPAL	98041S	de 	\N	http://www.ville-caen.fr/	\N	\N	\N
5168	1995-07-20 00:00:00	\N	2001-03-11 00:00:00	ANCIEN	\N	Bayeux	\N	\N	\N	2001	14704	MUNICIPAL	98042T	de 	\N	http://www.mairie-bayeux.fr/	\N	\N	\N
5176	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Dol-de-Bretagne	\N	\N	1988	2001	4629	MUNICIPAL	98045W	de 	\N	\N	\N	\N	\N
5189	1983-03-20 00:00:00	\N	2001-03-11 00:00:00	ANCIEN	\N	La Roche-Maurice	\N	\N	1983	2001	1603	MUNICIPAL	98046X	de 	\N	\N	\N	\N	\N
581	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Saint-Nizier-le-Bouchoux	\N	\N	\N	2001	625	MUNICIPAL	89016Q	de 	\N	\N	\N	\N	\N
582	1983-03-13 00:00:00	\N	2001-03-11 00:00:00	ANCIEN	\N	Oyonnax	\N	\N	1983	2001	23869	MUNICIPAL	89027T	d'	\N	\N	\N	\N	\N
583	\N	\N	\N	ACTIF	\N	Sissonne	\N	\N	\N	\N	2315	MUNICIPAL	88005H	de 	\N	\N	\N	\N	\N
584	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Droizy	\N	\N	\N	2001	66	MUNICIPAL	78003A	de 	\N	\N	\N	\N	\N
585	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Marcillat-en-Combraille	\N	\N	1971	2001	866	MUNICIPAL	89018S	de 	\N	\N	\N	\N	\N
586	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	La Saulce	\N	\N	\N	2001	632	MUNICIPAL	89006N	de 	\N	\N	\N	\N	\N
587	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Péone-Valberg	\N	\N	1959	2001	528	MUNICIPAL	88012G	de 	\N	\N	\N	\N	\N
588	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Tende	\N	\N	\N	2001	2089	MUNICIPAL	84004P	de 	\N	\N	\N	\N	\N
589	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Saint-Paul de Vence	\N	\N	\N	2001	2903	MUNICIPAL	85003S	de 	\N	\N	\N	\N	\N
590	\N	\N	2001-10-15 00:00:00	ANCIEN	\N	Aubenas	\N	\N	\N	2001	11105	MUNICIPAL	80021X	d'	\N	http://www.aubenas.fr/	\N	\N	\N
591	\N	\N	1998-12-31 00:00:00	ANCIEN	\N	Alincourt	\N	\N	\N	\N	91	MUNICIPAL	96005E	d'	\N	\N	\N	\N	\N
592	\N	\N	2001-09-04 00:00:00	ANCIEN	\N	Sinsat	\N	\N	\N	2001	97	MUNICIPAL	80004W	de 	\N	\N	\N	\N	\N
593	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Essoyes	\N	\N	1977	2001	685	MUNICIPAL	94003T	d'	\N	\N	\N	\N	\N
595	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Séverac-le-Château	\N	\N	1995	2001	2486	MUNICIPAL	89041R	de 	\N	\N	\N	\N	\N
596	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Rignac	\N	\N	1977	2001	1740	MUNICIPAL	80035E	de 	\N	\N	\N	\N	\N
597	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Belfort	\N	\N	\N	2001	50125	MUNICIPAL	80017C	de 	\N	http://www.mairie-belfort.fr/	\N	\N	\N
598	\N	\N	\N	ACTIF	\N	Arles	\N	\N	\N	\N	52058	MUNICIPAL	89024Q	d'	\N	http://www.ville-arles.fr/	\N	\N	\N
599	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Salon-de-Provence	\N	\N	1989	2001	34054	MUNICIPAL	89042S	de 	\N	\N	\N	\N	\N
601	\N	\N	2000-06-21 00:00:00	ANCIEN	\N	Puy-Sainte-Réparade	\N	\N	\N	2000	4414	MUNICIPAL	89036U	de 	\N	\N	\N	\N	\N
602	\N	\N	2016-05-01 00:00:00	ANCIEN	\N	Caen	\N	\N	\N	2016	112846	MUNICIPAL	71018C	de 	\N	http://www.ville-caen.fr/	\N	\N	\N
603	\N	\N	\N	ACTIF	\N	Tracy-sur-Mer	\N	\N	\N	\N	252	MUNICIPAL	70001N	de 	\N	\N	\N	\N	\N
6084	2001-03-11 00:00:00	\N	2008-03-16 00:00:00	ANCIEN	\N	Le Ségur	\N	\N	2001	2008	265	MUNICIPAL	95052H	de	\N	\N	\N	\N	\N
758	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Aubervilliers	\N	\N	\N	2001	67557	MUNICIPAL	95060H	d'	\N	http://www.mairie-aubervilliers.fr/	\N	\N	\N
6088	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Châtillon	\N	\N	2001	\N	26411	MUNICIPAL	93005R	de 	\N	\N	\N	\N	\N
6092	2001-03-11 00:00:00	\N	\N	ANCIEN	\N	Tende	\N	\N	2001	2008	2089	MUNICIPAL	84004P	de	\N	\N	\N	\N	\N
6093	2001-03-11 00:00:00	\N	2008-03-16 00:00:00	ANCIEN	\N	Marcillat-en-Combraille	\N	\N	2001	2008	866	MUNICIPAL	89018S	de	\N	\N	\N	\N	\N
6094	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Châteaulin	\N	\N	2001	\N	4965	MUNICIPAL	98049B	de	\N	http://www.chateaulin.fr	\N	\N	\N
6096	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Rauzan	\N	\N	2001	\N	978	MUNICIPAL	90003B	de	\N	\N	\N	\N	\N
6100	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Saint-André-de-Sangonis	\N	\N	2001	\N	3472	MUNICIPAL	80015A	de	\N	\N	\N	\N	\N
6101	2001-03-11 00:00:00	\N	2015-04-28 00:00:00	ANCIEN	\N	Cérilly	\N	\N	\N	\N	1591	MUNICIPAL	98024R	de	\N	\N	\N	\N	2017-11-16 16:54:15
6103	2001-03-11 00:00:00	\N	2022-08-18 00:00:00	ANCIEN	\N	Trizay	\N	\N	2001	\N	1049	MUNICIPAL	89014N	de	\N	http://www.trizay.com/	\N	\N	\N
6104	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Victot-Pontfol	\N	\N	2001	\N	132	MUNICIPAL	89007P	de	\N	\N	\N	\N	\N
6107	2001-03-11 00:00:00	\N	\N	ANCIEN	\N	Bayeux	\N	\N	2001	2008	14704	MUNICIPAL	98042T	de 	\N	http://www.mairie-bayeux.fr/	\N	\N	\N
6108	2001-03-11 00:00:00	\N	2008-03-16 00:00:00	ANCIEN	\N	Monségur	\N	\N	2001	2008	1537	MUNICIPAL	89025R	de 	\N	\N	\N	\N	\N
6109	2001-03-11 00:00:00	\N	2008-03-16 00:00:00	ANCIEN	\N	Dol-de-Bretagne	\N	\N	2001	2008	4629	MUNICIPAL	98045W	de	\N	\N	\N	\N	\N
6112	\N	\N	2010-01-13 00:00:00	ANCIEN	\N	Bouges-le-Château	\N	\N	\N	2010	308	MUNICIPAL	89030N	de 	\N	\N	\N	\N	\N
6113	2001-03-11 00:00:00	\N	2010-10-23 00:00:00	ANCIEN	\N	Roquefort-la-Bédoule	\N	\N	2001	2010	4162	MUNICIPAL	98017S	de	\N	\N	\N	\N	\N
6114	2001-03-11 00:00:00	\N	2021-09-28 00:00:00	ANCIEN	\N	Droizy	\N	\N	2001	\N	66	MUNICIPAL	78003A	de 	\N	\N	\N	\N	\N
6116	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Saint-Flour	\N	\N	2001	\N	7417	MUNICIPAL	98027U	de	\N	http://www.saint-flour.fr/	\N	\N	\N
6117	2001-03-11 00:00:00	\N	2003-08-28 00:00:00	ANCIEN	\N	La Guerche-de-Bretagne	\N	\N	2001	2003	4123	MUNICIPAL	98043U	de	\N	www.paysdevitre.org/site/infos/commune/fiche_commune.php3?Commune=30	\N	\N	\N
6118	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Plénée-Jugon	\N	\N	2001	\N	2235	MUNICIPAL	98038X	de	\N	\N	\N	\N	\N
6119	2001-03-11 00:00:00	\N	2009-09-09 00:00:00	ANCIEN	\N	Guéret	\N	\N	2001	2009	14706	MUNICIPAL	80024B	de	\N	\N	\N	\N	\N
6120	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Bourges	\N	\N	2001	\N	75609	MUNICIPAL	98025S	de	\N	http://www.ville-bourges.fr/	\N	\N	\N
6122	1976-03-11 00:00:00	\N	2019-08-27 00:00:00	ANCIEN	\N	Carbon-Blanc	\N	\N	1976	2001	5842	MUNICIPAL	80027E	de	\N	\N	\N	\N	\N
6123	2001-03-11 00:00:00	\N	2008-03-21 00:00:00	ANCIEN	\N	La Roche-Maurice	\N	\N	2001	2008	1603	MUNICIPAL	98046X	de 	\N	\N	\N	\N	\N
6127	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Lupersat	\N	\N	2001	\N	375	MUNICIPAL	73006G	de	\N	\N	\N	\N	\N
5145	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Villers-en-Prayères	\N	\N	1953	2001	118	MUNICIPAL	66002K	de 	\N	\N	\N	\N	\N
6129	2001-03-11 00:00:00	\N	2007-09-03 00:00:00	ANCIEN	\N	Villers-en-Prayères	\N	\N	2001	2007	118	MUNICIPAL	66002K	de	\N	\N	\N	\N	\N
6130	2001-03-11 00:00:00	\N	2008-03-21 00:00:00	ANCIEN	\N	Saint-Nizier-le-Bouchoux	\N	\N	2001	\N	625	MUNICIPAL	89016Q	de	\N	\N	\N	\N	\N
617	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Messigny-et-Vantoux	\N	\N	\N	2001	1070	MUNICIPAL	89037V	de 	\N	\N	\N	\N	\N
6133	2001-03-11 00:00:00	\N	2008-03-16 00:00:00	ANCIEN	\N	Messigny-et-Vantoux	\N	\N	2001	2008	1070	MUNICIPAL	89037V	de	\N	\N	\N	\N	\N
6134	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Etagnac	\N	\N	2001	\N	949	MUNICIPAL	98039Y	d'	\N	\N	\N	\N	\N
6135	2001-03-11 00:00:00	\N	2015-01-15 00:00:00	ANCIEN	\N	Lupiac	\N	\N	2001	2015	356	MUNICIPAL	98033S	de	\N	\N	\N	\N	\N
6136	2001-03-11 00:00:00	\N	2021-12-17 00:00:00	ANCIEN	\N	Lévie	\N	\N	2001	\N	781	MUNICIPAL	94002S	de	\N	\N	\N	\N	\N
6138	2001-03-11 00:00:00	\N	2008-03-21 00:00:00	ANCIEN	\N	Séverac-le-Château	\N	\N	2001	\N	2486	MUNICIPAL	89041R	de	\N	\N	\N	\N	\N
647	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Monségur	\N	\N	\N	2001	1537	MUNICIPAL	89025R	de 	\N	\N	\N	\N	\N
649	\N	\N	\N	ACTIF	\N	Nanterre	\N	\N	\N	\N	84565	MUNICIPAL	97003G	de 	\N	http://www.mairie-nanterre.fr/	\N	\N	\N
650	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Châtillon	\N	\N	\N	2001	26411	MUNICIPAL	93005R	de 	\N	\N	\N	\N	\N
651	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Ville-d'Avray	\N	\N	1987	2001	11616	MUNICIPAL	95007C	de 	\N	\N	\N	\N	\N
652	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Boulogne-Billancourt	\N	\N	\N	2001	101743	MUNICIPAL	77019E	de 	\N	http://www.mairie-boulogne-billancourt.fr/	\N	\N	\N
653	\N	\N	\N	ANCIEN	\N	Neuilly-sur-Seine	\N	\N	1983	2001	\N	MUNICIPAL	77053G	de 	\N	\N	\N	\N	\N
654	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Puteaux	\N	\N	\N	2001	42756	MUNICIPAL	95016D	de 	\N	http://www.mairie-puteaux.fr/	\N	\N	\N
655	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Saint-André-de-Sangonis	\N	\N	1977	2001	3472	MUNICIPAL	80015A	de 	\N	\N	\N	\N	\N
656	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Montpellier	\N	\N	\N	2001	207996	MUNICIPAL	89043T	de 	\N	http://www.ville-montpellier.fr/	\N	\N	\N
657	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Clermont-l'Hérault	\N	\N	\N	2001	6041	MUNICIPAL	80048K	de 	\N	\N	\N	\N	\N
658	\N	\N	2016-08-19 00:00:00	ANCIEN	\N	Retiers	\N	\N	\N	2016	3306	MUNICIPAL	89026S	de 	\N	\N	\N	\N	\N
660	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Château-Renault	\N	\N	\N	2001	5787	MUNICIPAL	83026R	de 	\N	\N	\N	\N	\N
661	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	La Ville-aux-Dames	\N	\N	1977	2001	4193	MUNICIPAL	92030N	de 	\N	http://www.ville-aux-dames.com	\N	\N	\N
662	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Chambray-lès-Tours	\N	\N	\N	2001	1940	MUNICIPAL	92012L	de 	\N	\N	\N	\N	\N
663	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Autrans	\N	\N	\N	2001	1406	MUNICIPAL	83031N	d'	\N	http://www.autrans.fr	\N	\N	\N
6179	2001-03-11 00:00:00	\N	\N	ANCIEN	\N	Châlus	\N	\N	2001	2001	1907	MUNICIPAL	95055L	de	\N	\N	\N	\N	\N
6180	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Montmélian	\N	\N	2001	\N	3930	MUNICIPAL	77060F	de	\N	http://www.montmelian.com/	\N	\N	\N
6182	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Blagny-sur-Vingeanne	\N	\N	2001	\N	122	MUNICIPAL	98048A	de	\N	\N	\N	\N	\N
5065	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Marseille	\N	\N	1995	2001	800550	MUNICIPAL	98016R	de 	\N	http://www.mairie-marseille.fr/	\N	\N	\N
6184	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Volx	\N	\N	2001	\N	2516	MUNICIPAL	98030P	de	\N	\N	\N	\N	\N
6185	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Marseille	\N	\N	2001	\N	807000	MUNICIPAL	89029V	de	\N	http://www.mairie-marseille.fr/	\N	\N	\N
6186	2001-03-11 00:00:00	\N	2008-03-16 00:00:00	ANCIEN	\N	Censerey	\N	\N	2001	2008	209	MUNICIPAL	98003L	de	\N	\N	\N	\N	\N
6188	2001-03-11 00:00:00	\N	2018-10-10 00:00:00	ANCIEN	\N	Autrèche	\N	\N	2001	\N	3284	MUNICIPAL	83026R	d'	\N	\N	\N	\N	\N
6190	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Les Halles	\N	\N	2001	\N	\N	MUNICIPAL	86047K	de	\N	\N	\N	\N	\N
6191	2001-03-18 00:00:00	\N	2024-01-10 00:00:00	ANCIEN	\N	Mellac	\N	\N	2001	\N	21294	MUNICIPAL	98051U	de	\N	\N	\N	\N	\N
6196	\N	\N	\N	ACTIF	\N	Paris (20ème arrondissement)	\N	\N	1989	\N	2152423	MUNICIPAL	00001A	de	\N	\N	\N	\N	\N
6246	2001-03-11 00:00:00	\N	2008-03-17 00:00:00	ANCIEN	\N	Lavelanet	\N	\N	2001	2008	6872	MUNICIPAL	98006P	de	\N	\N	\N	\N	\N
6199	2001-03-18 00:00:00	\N	\N	ACTIF	\N	Paris	\N	\N	2001	\N	\N	MUNICIPAL	95022B	de	\N	http://www.paris.fr	\N	\N	\N
6200	2001-03-18 00:00:00	\N	\N	ACTIF	\N	Paris (14ème arrondissement)	\N	\N	2001	\N	2152423	MUNICIPAL	95058P	de	\N	\N	\N	\N	\N
6202	2001-03-18 00:00:00	\N	\N	ACTIF	\N	Villers-lès-Nancy	\N	\N	2001	\N	16515	MUNICIPAL	92009R	de	\N	http://www.villers-les-nancy.fr	\N	\N	\N
6203	2001-03-18 00:00:00	\N	\N	ACTIF	\N	Brunoy	\N	\N	2001	\N	24000	MUNICIPAL	01001E	de	\N	http://www.ville-brunoy.fr/	\N	\N	\N
6206	2001-03-18 00:00:00	\N	2008-03-21 00:00:00	ANCIEN	\N	Belfort	\N	\N	2001	2008	50125	MUNICIPAL	80017C	de	\N	http://www.mairie-belfort.fr/	\N	\N	\N
6207	1995-06-18 00:00:00	\N	\N	ANCIEN	\N	Avignon	\N	\N	\N	2004	86939	MUNICIPAL	87003B	d'	\N	http://www.mairie-avignon.fr/	\N	\N	2017-11-09 15:22:45
11413	2008-03-21 00:00:00	\N	2020-03-16 00:00:00	ANCIEN	\N	Piana	\N	\N	2008	\N	\N	MUNICIPAL	01065W	de	\N	\N	\N	\N	\N
6208	2001-03-18 00:00:00	\N	\N	ACTIF	\N	Toulon	\N	\N	2001	\N	\N	MUNICIPAL	95031C	de	\N	http://www.toulon.com/ 	\N	\N	\N
664	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Sapois	\N	\N	\N	2001	310	MUNICIPAL	89004L	de 	\N	\N	\N	\N	\N
6209	2001-03-18 00:00:00	\N	\N	ACTIF	\N	Boulogne-Billancourt	\N	\N	2001	\N	101743	MUNICIPAL	77019E	de	\N	http://www.mairie-boulogne-billancourt.fr/	\N	\N	\N
6210	2001-03-18 00:00:00	\N	2008-03-15 00:00:00	ANCIEN	\N	Le Havre	\N	\N	2001	2008	197299	MUNICIPAL	95034F	de	\N	http://www.ville-lehavre.fr/	\N	\N	\N
6211	2001-03-18 00:00:00	\N	2008-03-16 00:00:00	ANCIEN	\N	Quimper	\N	\N	2001	2008	59437	MUNICIPAL	86006A	de	\N	\N	\N	\N	\N
6212	2001-03-18 00:00:00	\N	\N	ACTIF	\N	Clermont-Ferrand	\N	\N	2001	\N	136181	MUNICIPAL	98009S	de	\N	http://www.clermont-ferrand.fr/	\N	\N	\N
6213	2001-03-18 00:00:00	\N	2009-05-25 00:00:00	ANCIEN	\N	2e secteur de Marseille	\N	\N	2001	2009	800550	MUNICIPAL	98022P	du	\N	\N	\N	\N	\N
6214	2001-03-18 00:00:00	\N	2006-04-29 00:00:00	ANCIEN	\N	Saint-Raphaël	\N	\N	2001	2006	26616	MUNICIPAL	86035F	de	\N	\N	\N	\N	\N
6216	2001-03-18 00:00:00	\N	\N	ACTIF	\N	Vernon	\N	\N	2001	\N	25000	MUNICIPAL	98013N	de	\N	http://www.vernon27.fr/	\N	\N	\N
6217	2001-03-18 00:00:00	\N	2018-04-27 00:00:00	ANCIEN	\N	Brive-la-Gaillarde	\N	\N	2001	\N	49765	MUNICIPAL	98007Q	de	\N	\N	\N	\N	2018-04-30 14:05:27
6218	2001-03-18 00:00:00	\N	2008-04-25 00:00:00	ANCIEN	\N	Nice	\N	\N	2001	2008	342439	MUNICIPAL	98040R	de	\N	http://www.ville-nice.fr/	\N	\N	\N
6219	2001-03-18 00:00:00	\N	\N	ACTIF	\N	Sucy-en-Brie	\N	\N	2001	\N	25839	MUNICIPAL	95057N	de	\N	\N	\N	\N	\N
6221	2001-03-18 00:00:00	\N	2024-01-05 00:00:00	ANCIEN	\N	Metz	\N	\N	2001	\N	119594	MUNICIPAL	74042Q	de	\N	http://www.mairie-metz.fr/	\N	\N	\N
6222	2001-03-18 00:00:00	\N	2008-03-21 00:00:00	ANCIEN	\N	Saint-Brieuc	\N	\N	2001	2008	44752	MUNICIPAL	89040Q	de	\N	http://www.mairie-saint-brieuc.fr/	\N	\N	\N
6223	2001-03-18 00:00:00	\N	2020-06-29 00:00:00	ANCIEN	\N	Montbéliard	\N	\N	2001	\N	29005	MUNICIPAL	80041C	de	\N	http://www.montbeliard.com/	\N	\N	\N
6242	2001-03-18 00:00:00	\N	2004-02-12 00:00:00	ANCIEN	\N	Gif-sur-Yvette	\N	\N	2001	2004	19754	MUNICIPAL	95053J	de	\N	\N	\N	\N	\N
6243	2001-03-18 00:00:00	\N	2001-03-25 00:00:00	ANCIEN	\N	Fontainebleau	\N	\N	2001	2001	15714	MUNICIPAL	99003Q	de	\N	\N	\N	\N	\N
6244	2001-03-18 00:00:00	\N	2001-03-25 00:00:00	ANCIEN	\N	Chambray-lès-Tours	\N	\N	2001	2001	1940	MUNICIPAL	92012L	de	\N	\N	\N	\N	\N
6248	2001-03-11 00:00:00	\N	2010-07-25 00:00:00	ANCIEN	\N	Sainte Cécile les Vignes	\N	\N	2001	2010	1927	MUNICIPAL	86042E	de	\N	http://sainte-cecile.org	\N	\N	\N
6249	2001-03-18 00:00:00	\N	\N	ANCIEN	\N	Aix-En-Provence	\N	\N	2001	2001	123842	MUNICIPAL	98015Q	d'	\N	\N	\N	\N	\N
6279	\N	\N	\N	ANCIEN	\N	Nevers	\N	\N	1983	1988	\N	MUNICIPAL	92016Q	de	\N	http://www.ville-nevers.fr/	\N	\N	\N
6252	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Peyssies	\N	\N	2001	\N	500	MUNICIPAL	80039J	de	\N	\N	\N	\N	\N
6256	2001-03-18 00:00:00	\N	\N	ACTIF	\N	Orly	\N	\N	\N	\N	21646	MUNICIPAL	97005J	d'	\N	http://www.ville-orly.fr/	\N	\N	\N
6258	2001-03-11 00:00:00	\N	2009-04-11 00:00:00	ANCIEN	\N	Basses	\N	\N	2001	2009	\N	MUNICIPAL	68036E	de	\N	\N	\N	\N	\N
6259	2001-03-18 00:00:00	\N	2021-07-07 00:00:00	ANCIEN	\N	Saint-Paul de Vence	\N	\N	2001	\N	2903	MUNICIPAL	85003S	de	\N	\N	\N	\N	\N
6265	2001-03-11 00:00:00	\N	2020-03-21 00:00:00	ANCIEN	\N	La Guérinière	\N	\N	2001	\N	1402	MUNICIPAL	86041D	de	\N	\N	\N	\N	\N
6268	1971-03-21 00:00:00	\N	2017-05-15 00:00:00	ANCIEN	\N	Sarp	\N	\N	1971	\N	\N	MUNICIPAL	01003G	de	\N	\N	\N	\N	2017-05-16 15:18:13
6270	2001-03-18 00:00:00	\N	\N	ACTIF	\N	Marseille (7ème secteur)	\N	\N	2001	\N	800550	MUNICIPAL	98016R	de	\N	\N	\N	\N	\N
6294	2001-03-18 00:00:00	\N	2013-07-14 00:00:00	ANCIEN	\N	Saumur	\N	\N	2001	2013	30131	MUNICIPAL	92026S	de	\N	http://www.ville-saumur.fr/	\N	\N	\N
6272	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Le Tampon	\N	\N	2001	\N	48436	MUNICIPAL	98002K	de	\N	http://perso.wanadoo.fr/le-tampon/index.htm	\N	\N	\N
6290	2001-03-18 00:00:00	\N	\N	ACTIF	\N	Paris	\N	\N	2001	\N	\N	MUNICIPAL	01004H	de	\N	http://www.paris.fr	\N	\N	\N
6338	2001-03-11 00:00:00	\N	2001-07-01 00:00:00	ANCIEN	\N	Vercel-Villedieu-le-Camp	\N	\N	2001	2001	1088	MUNICIPAL	88009M	de	\N	\N	\N	\N	\N
6337	2001-03-11 00:00:00	\N	\N	ANCIEN	\N	Nordhouse	\N	\N	2001	2001	1333	MUNICIPAL	95036H	de	\N	\N	\N	\N	\N
6339	2001-03-11 00:00:00	\N	\N	ANCIEN	\N	Vaison-la-Romaine	\N	\N	2001	2001	5663	MUNICIPAL	95037J	de 	\N	\N	\N	\N	\N
6340	2001-03-11 00:00:00	\N	\N	ANCIEN	\N	Lessay	\N	\N	2001	2001	1719	MUNICIPAL	82002D	de 	\N	\N	\N	\N	\N
6341	2001-03-18 00:00:00	\N	\N	ACTIF	\N	Saint-Claude	\N	\N	2001	\N	\N	MUNICIPAL	01002F	de	\N	http://www.saint-claude.fr	\N	\N	\N
6342	2001-03-11 00:00:00	\N	2023-10-12 00:00:00	ANCIEN	\N	Caen	\N	\N	2001	2001	112846	MUNICIPAL	98041S	de	\N	http://www.ville-caen.fr/	\N	\N	\N
6356	\N	\N	\N	ACTIF	\N	La Canourgue	\N	\N	\N	\N	\N	MUNICIPAL	01005J	de	\N	http://www.la-canourgue.com/	\N	\N	\N
6376	1972-07-17 00:00:00	\N	\N	ACTIF	\N	Saint-André	\N	\N	1972	\N	36300	MUNICIPAL	01010F	de	\N	\N	\N	\N	\N
6382	\N	\N	\N	ACTIF	\N	Chinon	\N	\N	1989	\N	9100	MUNICIPAL	01012H	de	\N	http://www.ville-chinon.com	\N	\N	\N
6386	\N	\N	\N	ACTIF	\N	Saint-Pierre-des-Corps	\N	\N	1977	\N	16200	MUNICIPAL	01013J	de	\N	http://www.ville-saint-pierre-des-corps.fr/	\N	\N	\N
6405	\N	\N	2008-03-21 00:00:00	ANCIEN	\N	Landevant	\N	\N	1971	2008	2100	MUNICIPAL	01021J	de	\N	\N	\N	\N	\N
6408	2001-03-18 00:00:00	\N	2008-03-21 00:00:00	ANCIEN	\N	La Croix-Helléan	\N	\N	2001	2008	600	MUNICIPAL	01022K	de	\N	\N	\N	\N	\N
6409	\N	\N	2001-12-08 00:00:00	ANCIEN	\N	Clermont	\N	\N	1983	2001	\N	MUNICIPAL	01023L	de	\N	\N	\N	\N	\N
6412	\N	\N	\N	ACTIF	\N	Witry-lès-Reims	\N	\N	1983	\N	4600	MUNICIPAL	01024M	de	\N	\N	\N	\N	\N
6415	\N	\N	2014-10-01 00:00:00	ANCIEN	\N	Cuchery	\N	\N	1989	\N	350	MUNICIPAL	01025N	de	\N	\N	\N	\N	2014-10-30 11:26:45
6430	\N	\N	\N	ANCIEN	\N	Orléans	\N	\N	1989	2008	\N	MUNICIPAL	01028R	d'	\N	\N	\N	\N	\N
6434	\N	\N	2008-03-21 00:00:00	ANCIEN	\N	Saint-Sandoux	\N	\N	1971	2008	\N	MUNICIPAL	01030K	de	\N	\N	\N	\N	\N
6438	\N	\N	2001-09-29 00:00:00	ANCIEN	\N	Clermont-Ferrand	\N	\N	1983	2001	\N	MUNICIPAL	01031L	de	\N	\N	\N	\N	\N
6441	\N	\N	2006-05-16 00:00:00	ANCIEN	\N	Pau	\N	\N	1971	2006	80000	MUNICIPAL	01032M	de	\N	\N	\N	\N	\N
6447	\N	\N	2015-04-07 00:00:00	ANCIEN	\N	Rouvroy	\N	\N	1977	2015	9100	MUNICIPAL	01035Q	de	\N	\N	\N	\N	\N
6451	2001-03-25 00:00:00	\N	\N	ACTIF	\N	Annay-sous-Lens	\N	\N	\N	\N	4700	MUNICIPAL	01036R	d'	\N	\N	\N	\N	\N
6456	\N	\N	2016-12-10 00:00:00	ANCIEN	\N	Pouilly-lès-Feurs	\N	\N	1971	\N	1000	MUNICIPAL	01037S	de	\N	\N	\N	\N	2016-12-12 16:10:15
6461	1994-05-16 00:00:00	\N	\N	ACTIF	\N	Saint-Etienne	\N	\N	1994	\N	183000	MUNICIPAL	01039U	de	\N	http://www.mairie-st-etienne.fr/	\N	\N	\N
6478	\N	\N	\N	ACTIF	\N	Hoymille	\N	\N	1977	\N	3240	MUNICIPAL	01045S	d'	\N	http://www.hoymille.fr/	\N	\N	\N
6482	\N	\N	2014-04-04 00:00:00	ANCIEN	\N	Dole	\N	\N	1983	\N	26000	MUNICIPAL	01046T	de	\N	\N	\N	\N	2014-04-07 11:38:49
6484	1989-03-19 00:00:00	\N	2001-10-19 00:00:00	ANCIEN	\N	Laval	\N	\N	1989	2001	\N	MUNICIPAL	01047U	de	\N	http://www.mairie-laval.fr/	\N	\N	\N
6489	1971-03-21 00:00:00	\N	\N	ACTIF	\N	Marville	\N	\N	1971	\N	540	MUNICIPAL	01049W	de	\N	http://www.marville55.com	\N	\N	\N
13770	\N	\N	\N	ACTIF	\N	Montataire	\N	\N	1983	\N	0	MUNICIPAL	14013P	de 	\N	\N	\N	2014-05-09 11:30:17	2014-05-09 11:33:38
6498	\N	\N	2008-03-16 00:00:00	ANCIEN	\N	Monflanquin	\N	\N	1983	2008	2300	MUNICIPAL	01050P	de	\N	\N	\N	\N	\N
6500	1993-05-16 00:00:00	\N	\N	ACTIF	\N	Nevers	\N	\N	1993	\N	43000	MUNICIPAL	01051Q	de	\N	http://www.ville-nevers.fr/	\N	\N	\N
6518	\N	\N	2015-12-31 00:00:00	ANCIEN	\N	Vaux-sous-Aubigny	\N	\N	1983	\N	720	MUNICIPAL	01057W	de	\N	\N	\N	\N	2016-04-18 17:34:42
6525	\N	\N	2014-04-01 00:00:00	ANCIEN	\N	Angers	\N	\N	1983	\N	\N	MUNICIPAL	01016M	d'	\N	http://www.ville-angers.fr/	\N	\N	2014-09-08 11:55:16
6536	2001-03-18 00:00:00	\N	\N	ANCIEN	\N	Valenciennes	\N	\N	2001	2005	\N	MUNICIPAL	01043Q	de	\N	http://www.ville-valenciennes.fr/	\N	\N	\N
6537	2001-03-11 00:00:00	\N	2008-03-21 00:00:00	ANCIEN	\N	Cilaos	\N	\N	2001	\N	\N	MUNICIPAL	01009N	de 	\N	http://www.ville-cilaos.fr	\N	\N	\N
6540	\N	\N	\N	ANCIEN	\N	Blanzac	\N	\N	1971	1995	\N	MUNICIPAL	01052R	de	\N	\N	\N	\N	\N
6552	\N	\N	2001-05-15 00:00:00	ANCIEN	\N	Fuilet	\N	\N	1989	2001	\N	MUNICIPAL	01017N	du	\N	\N	\N	\N	\N
6613	\N	\N	\N	ANCIEN	\N	La Croix-Helléan	\N	\N	1995	2001	600	MUNICIPAL	01022K	de	\N	\N	\N	\N	\N
6557	\N	\N	2003-01-01 00:00:00	ANCIEN	\N	Marcq-en-Baroeul	\N	\N	1994	2003	\N	MUNICIPAL	01042P	de	\N	\N	\N	\N	\N
6566	\N	\N	\N	ANCIEN	\N	Ormes	\N	\N	1971	2001	\N	MUNICIPAL	01029S	d'	\N	http://www.ville-lesormes.fr/	\N	\N	\N
6571	\N	\N	2014-04-01 00:00:00	ANCIEN	\N	Conflans-en-Jarnisy	\N	\N	1983	\N	0	MUNICIPAL	01015L	de	\N	\N	\N	\N	2014-04-09 22:40:46
6572	\N	\N	\N	ANCIEN	\N	Blainville-sur-l'Eau	\N	\N	1983	2001	\N	MUNICIPAL	01014K	de	\N	\N	\N	\N	\N
6575	\N	\N	2001-12-08 00:00:00	ANCIEN	\N	Nantes	\N	\N	1983	2001	\N	MUNICIPAL	01054T	de	\N	http://www.mairie-nantes.fr/	\N	\N	\N
6578	\N	\N	2008-03-21 00:00:00	ANCIEN	\N	Saint-Gildas-des-Bois	\N	\N	1977	2008	\N	MUNICIPAL	01056V	de	\N	\N	\N	\N	\N
6581	\N	\N	2014-06-30 00:00:00	ANCIEN	\N	Uxelles	\N	\N	1965	\N	0	MUNICIPAL	01008M	d'	\N	\N	\N	\N	2014-09-23 17:44:20
6583	2001-03-23 00:00:00	\N	2008-03-21 00:00:00	ANCIEN	\N	La Ricamarie	\N	\N	2001	2008	\N	MUNICIPAL	01038T	de	\N	http://www.ville-la-ricamarie.fr/	\N	\N	\N
6585	2001-01-18 00:00:00	\N	2008-03-21 00:00:00	ANCIEN	\N	Saint-Quirin	\N	\N	2001	2008	\N	MUNICIPAL	83042R	de 	\N	\N	\N	\N	\N
6588	\N	\N	\N	ACTIF	\N	Talange	\N	\N	1983	\N	0	MUNICIPAL	01062T	de	\N	\N	\N	\N	2014-04-17 11:17:45
6592	\N	\N	\N	ANCIEN	\N	Saint-Blin	\N	\N	1995	2001	\N	MUNICIPAL	01058X	de	\N	\N	\N	\N	\N
6608	\N	\N	2001-12-01 00:00:00	ANCIEN	\N	Cherbourg - Octeville	\N	\N	1980	2001	\N	MUNICIPAL	01011G	de	\N	\N	\N	\N	\N
6610	\N	\N	\N	ANCIEN	\N	Saint-Germain-sur-Vienne	\N	\N	1971	1989	\N	MUNICIPAL	01012H	de	\N	\N	\N	\N	\N
6615	\N	\N	2019-08-19 00:00:00	ANCIEN	\N	Vic-sur-Seille	\N	\N	1981	2001	\N	MUNICIPAL	01061S	de	\N	\N	\N	\N	\N
6642	\N	\N	\N	ACTIF	\N	Bonneval	\N	\N	1995	\N	4370	MUNICIPAL	01064V	de	\N	http://www.ville-bonneval.fr/	\N	\N	\N
6643	\N	\N	\N	ANCIEN	\N	Saint-Maur-sur-Loir	\N	\N	1989	1995	\N	MUNICIPAL	01064V	de	\N	\N	\N	\N	\N
6651	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Piana	\N	\N	1962	2001	\N	MUNICIPAL	01065W	de	\N	\N	\N	\N	\N
6668	\N	\N	\N	ANCIEN	\N	Villeneuve d'Ascq	\N	\N	1977	1989	\N	MUNICIPAL	02001J	de	\N	http://www.mairie-villeneuvedascq.fr/	\N	\N	\N
6670	\N	\N	2002-02-01 00:00:00	ANCIEN	\N	Valenciennes	\N	\N	2001	2002	\N	MUNICIPAL	02001J	de	\N	http://www.ville-valenciennes.fr/	\N	\N	\N
6742	\N	\N	2024-02-05 00:00:00	ANCIEN	\N	Fleurbaix	\N	\N	1977	\N	2530	MUNICIPAL	02003L	de	\N	\N	\N	\N	\N
6747	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Berd'huis	\N	\N	2001	\N	1100	MUNICIPAL	02004M	de 	\N	\N	\N	\N	\N
6748	1995-06-01 00:00:00	\N	2008-03-16 00:00:00	ANCIEN	\N	Nojals-et-Clottes	\N	\N	1995	2008	196	MUNICIPAL	02005N	de	\N	\N	\N	\N	\N
6762	\N	\N	2019-07-13 00:00:00	ANCIEN	\N	Solliès-Ville	\N	\N	1983	\N	2200	MUNICIPAL	02006P	de	\N	\N	\N	\N	\N
6771	\N	\N	2008-03-26 00:00:00	ANCIEN	\N	Gray	\N	\N	1995	2008	\N	MUNICIPAL	02007Q	\N	\N	http://www.ville-gray.fr/	\N	\N	\N
6789	\N	\N	\N	ANCIEN	\N	La Chaux-la-Lotière	\N	\N	1982	1995	\N	MUNICIPAL	03001N	de	\N	\N	\N	\N	\N
6790	\N	\N	\N	ACTIF	\N	Rioz	\N	\N	1995	\N	0	MUNICIPAL	03001N	de	\N	\N	\N	\N	2014-04-07 11:27:06
6794	1989-03-25 00:00:00	\N	1994-12-18 00:00:00	ANCIEN	\N	Nanterre	\N	\N	1989	1995	\N	MUNICIPAL	99004R	de	\N	http://www.mairie-nanterre.fr/	\N	\N	\N
10056	\N	\N	2016-03-15 00:00:00	ANCIEN	\N	Amélie les Bains Palalda	\N	\N	\N	2016	\N	MUNICIPAL	58343H	\N	\N	\N	\N	\N	\N
10057	\N	\N	2006-01-23 00:00:00	ANCIEN	\N	Perpignan	\N	\N	\N	2006	113650	MUNICIPAL	59213C	\N	\N	http://www.mairie-perpignan.fr/	\N	\N	\N
10058	\N	\N	2005-09-22 00:00:00	ANCIEN	\N	Le Champ-de-la-Pierre	\N	\N	\N	2005	50	MUNICIPAL	59215E	\N	\N	\N	\N	\N	\N
10059	\N	\N	\N	ACTIF	\N	Radinghem-en-Weppes	\N	\N	\N	\N	\N	MUNICIPAL	000339	\N	\N	\N	\N	\N	\N
10060	\N	\N	2023-11-21 00:00:00	ANCIEN	\N	Pointe-à-Pitre	\N	\N	\N	\N	26083	MUNICIPAL	59564Y	\N	\N	\N	\N	\N	\N
10061	\N	\N	2013-05-21 00:00:00	ANCIEN	\N	Quillan	\N	\N	\N	2013	\N	MUNICIPAL	58613L	\N	\N	\N	\N	\N	\N
10062	\N	\N	\N	ACTIF	\N	Pont-Saint-Esprit	\N	\N	\N	\N	8135	MUNICIPAL	59721T	\N	\N	\N	\N	\N	\N
10063	\N	\N	\N	ACTIF	\N	Montoire-sur-le-Loir	\N	\N	\N	\N	\N	MUNICIPAL	000460	\N	\N	\N	\N	\N	\N
10064	\N	\N	2021-04-21 00:00:00	ANCIEN	\N	Quimper	\N	\N	\N	\N	\N	MUNICIPAL	58819Y	\N	\N	\N	\N	\N	\N
10065	\N	\N	2020-02-13 00:00:00	ANCIEN	\N	Brassac-les-Mines	\N	\N	\N	\N	4110	MUNICIPAL	59217G	\N	\N	\N	\N	\N	\N
10066	\N	\N	\N	ACTIF	\N	Saint-Paul-de-la-Réunion	\N	\N	\N	\N	\N	MUNICIPAL	000541	\N	\N	\N	\N	\N	\N
10067	\N	\N	\N	ACTIF	\N	Buzançais	\N	\N	\N	\N	4980	MUNICIPAL	000321	\N	\N	\N	\N	\N	\N
10068	\N	\N	2018-11-19 00:00:00	ANCIEN	\N	Bagnols-sur-Ceze	\N	\N	\N	\N	\N	MUNICIPAL	59309K	\N	\N	\N	\N	\N	\N
10069	\N	\N	\N	ACTIF	\N	Marly-le-Roi	\N	\N	\N	\N	\N	MUNICIPAL	000553	\N	\N	http://www.mairie-marlyleroi.fr/	\N	\N	\N
10070	\N	\N	\N	ACTIF	\N	Corbigny	\N	\N	\N	\N	\N	MUNICIPAL	000353	\N	\N	\N	\N	\N	\N
10072	\N	\N	2004-09-29 00:00:00	ANCIEN	\N	La Ravoire	\N	\N	\N	2004	6009	MUNICIPAL	59567C	\N	\N	http://www.laravoire.com	\N	\N	\N
10074	\N	\N	2021-12-16 00:00:00	ANCIEN	\N	Tonnay-Boutonne	\N	\N	\N	\N	1060	MUNICIPAL	58920U	\N	\N	\N	\N	\N	\N
10075	\N	\N	2017-01-28 00:00:00	ANCIEN	\N	Aix-en-Provence	\N	\N	\N	2017	\N	MUNICIPAL	58921V	\N	\N	\N	\N	\N	\N
10076	\N	\N	\N	ACTIF	\N	Paris	\N	\N	\N	\N	2	MUNICIPAL	000545	\N	\N	http://www.paris.fr	\N	\N	\N
10077	\N	\N	1999-04-06 00:00:00	ANCIEN	\N	Forbach	\N	\N	\N	1999	27320	MUNICIPAL	59220B	\N	\N	http://www.mairie-forbach.fr/	\N	\N	\N
10078	\N	\N	2001-10-18 00:00:00	ANCIEN	\N	Bogève	\N	\N	\N	2001	675	MUNICIPAL	59568D	\N	\N	\N	\N	\N	\N
10079	\N	\N	2017-09-23 00:00:00	ANCIEN	\N	Caraman	\N	\N	\N	2017	1640	MUNICIPAL	58951C	\N	\N	\N	\N	\N	\N
10080	\N	\N	\N	ACTIF	\N	Salles	\N	\N	\N	\N	3645	MUNICIPAL	58946F	\N	\N	\N	\N	\N	\N
10083	\N	\N	\N	ACTIF	\N	Saint-Hilaire-de-Riez	\N	\N	\N	\N	\N	MUNICIPAL	000538	\N	\N	\N	\N	\N	\N
10084	\N	\N	2009-03-19 00:00:00	ANCIEN	\N	Cachan	\N	\N	\N	2009	24266	MUNICIPAL	59525R	\N	\N	http://www.ville-cachan.fr/	\N	\N	\N
10085	\N	\N	\N	ACTIF	\N	Le Bleymard	\N	\N	\N	\N	450	MUNICIPAL	000510	\N	\N	\N	\N	\N	\N
10086	\N	\N	\N	ACTIF	\N	Brioude	\N	\N	\N	\N	7285	MUNICIPAL	83022M	\N	\N	\N	\N	\N	\N
10087	\N	\N	\N	ACTIF	\N	Carpentras	\N	\N	\N	\N	\N	MUNICIPAL	000572	\N	\N	http://www.ville-carpentras.fr/	\N	\N	\N
10088	\N	\N	2006-04-13 00:00:00	ANCIEN	\N	Bresle	\N	\N	\N	2006	\N	MUNICIPAL	58349P	\N	\N	http://www.bresles.fr/	\N	\N	\N
10090	\N	\N	\N	ACTIF	\N	Paris	\N	\N	\N	\N	\N	MUNICIPAL	000501	\N	\N	http://www.paris.fr	\N	\N	\N
10091	\N	\N	1998-12-12 00:00:00	ANCIEN	\N	Licques	\N	\N	\N	1998	1390	MUNICIPAL	59223E	\N	\N	\N	\N	\N	\N
10092	\N	\N	2013-05-26 00:00:00	ANCIEN	\N	Figeac	\N	\N	\N	2013	\N	MUNICIPAL	59224F	\N	\N	http://www.ville-figeac.fr/	\N	\N	\N
10093	\N	\N	2007-09-29 00:00:00	ANCIEN	\N	Lamentin	\N	\N	\N	2007	\N	MUNICIPAL	58649Y	\N	\N	\N	\N	\N	\N
10094	\N	\N	\N	ACTIF	\N	Le Soler	\N	\N	\N	\N	4405	MUNICIPAL	000438	\N	\N	\N	\N	\N	\N
5194	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Blagny-sur-Vingeanne	\N	\N	1971	2001	122	MUNICIPAL	98048A	de 	\N	\N	\N	\N	\N
5201	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Quillebeuf-sur-Seine	\N	\N	1977	2001	1044	MUNICIPAL	98050T	de 	\N	\N	\N	\N	\N
5205	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Mellac	\N	\N	\N	2001	21924	MUNICIPAL	98051U	de 	\N	\N	\N	\N	\N
5212	1965-05-05 00:00:00	\N	2000-03-10 00:00:00	ANCIEN	\N	Pirae	\N	\N	\N	2000	15000	MUNICIPAL	98052V	de 	\N	\N	\N	\N	\N
5216	\N	\N	\N	ANCIEN	\N	Mijanes	\N	\N	1983	1995	79	MUNICIPAL	98006P	de 	\N	\N	\N	\N	\N
5274	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Almayrac	\N	\N	1989	2001	267	MUNICIPAL	98054X	d'	\N	\N	\N	\N	\N
5231	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Oissel	\N	\N	1977	2001	11444	MUNICIPAL	98053W	d'	\N	http://www.ville-oissel.fr/	\N	\N	\N
5260	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Langeac	\N	\N	1959	2001	4195	MUNICIPAL	98026T	de 	\N	\N	\N	\N	\N
5281	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Loudun	\N	\N	1953	2001	7854	MUNICIPAL	68036E	de 	\N	http://www.ville-loudun.fr	\N	\N	\N
5822	\N	\N	2024-03-13 00:00:00	ANCIEN	\N	Lille	\N	\N	1983	1995	\N	MUNICIPAL	99001N	de	\N	http://www.mairie-lille.fr/	\N	\N	\N
5833	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Le Bourget-du-Lac	\N	\N	1995	2001	2886	MUNICIPAL	95067Q	du	\N	http://www.bourgetdulac.com	\N	\N	\N
5835	\N	\N	\N	ANCIEN	\N	Les Echelles	\N	\N	1983	1995	1246	MUNICIPAL	95067Q	des	\N	\N	\N	\N	\N
5836	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Lyon	\N	\N	1977	2001	415487	MUNICIPAL	99002P	de	\N	http://www.lyon.fr/page/accueil.html	\N	\N	\N
5841	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Fontainebleau	\N	\N	\N	2001	15714	MUNICIPAL	99003Q	de	\N	\N	\N	\N	\N
5843	1995-06-25 00:00:00	\N	2001-03-11 00:00:00	ANCIEN	\N	Boulogne-Billancourt	\N	\N	1995	2001	101743	MUNICIPAL	99004R	de	\N	http://www.mairie-boulogne-billancourt.fr/	\N	\N	\N
5850	\N	\N	\N	ANCIEN	\N	Sarcelles	\N	\N	1977	1983	56833	MUNICIPAL	00001A	de	\N	http://www.sarcelles.com/	\N	\N	\N
5851	\N	\N	\N	ANCIEN	\N	Paris (11eme arrondissement)	\N	\N	1983	1989	\N	MUNICIPAL	00001A	de	\N	\N	\N	\N	\N
5857	2000-04-17 00:00:00	\N	2001-03-11 00:00:00	ANCIEN	\N	Ier arrondissement de Paris	\N	\N	2000	2001	\N	MUNICIPAL	77009C	de	\N	\N	\N	\N	\N
5862	\N	\N	2016-03-19 00:00:00	ANCIEN	\N	Breuillet	\N	\N	1977	2016	7321	MUNICIPAL	93007T	de	\N	http://www.ville-breuillet.fr/	\N	\N	\N
5865	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Gennevilliers	\N	\N	\N	2001	44818	MUNICIPAL	00002B	de	\N	http://www.ville-gennevilliers.fr/	\N	\N	\N
5869	\N	\N	2007-11-21 00:00:00	ANCIEN	\N	Châteauroux	\N	\N	1959	2007	50969	MUNICIPAL	89020L	de	\N	\N	\N	\N	\N
5872	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Bouray-sur-Juine	\N	\N	\N	2001	1706	MUNICIPAL	00003C	de	\N	\N	\N	\N	\N
5874	2000-03-10 00:00:00	\N	2001-03-11 00:00:00	ANCIEN	\N	Pirae	\N	\N	\N	2001	15000	MUNICIPAL	98052V	de	\N	\N	\N	\N	\N
5875	\N	\N	2000-05-26 00:00:00	ANCIEN	\N	Metz	\N	\N	1983	2000	\N	MUNICIPAL	00004D	de	\N	http://www.mairie-metz.fr/	\N	\N	\N
5887	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Brunoy	\N	\N	1977	2001	24000	MUNICIPAL	01001E	de	\N	http://www.ville-brunoy.fr/	\N	\N	\N
6001	2001-03-11 00:00:00	\N	2008-03-16 00:00:00	ANCIEN	\N	Blanzac-Porcheresse	\N	\N	2001	2008	394	MUNICIPAL	96008H	de	\N	\N	\N	\N	\N
6004	2001-03-11 00:00:00	\N	2001-03-23 00:00:00	ANCIEN	\N	Péone-Valberg	\N	\N	2001	2001	528	MUNICIPAL	88012G	de	\N	\N	\N	\N	\N
604	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Victot-Pontfol	\N	\N	\N	2001	132	MUNICIPAL	89007P	de 	\N	\N	\N	\N	\N
605	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Ydes	\N	\N	\N	2001	1965	MUNICIPAL	89010J	d'	\N	\N	\N	\N	\N
606	\N	\N	1999-02-17 00:00:00	ANCIEN	\N	Saint-Chamant	\N	\N	\N	1999	329	MUNICIPAL	89038W	de 	\N	\N	\N	\N	\N
607	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Blanzac-Porcheresse	\N	\N	1979	2001	394	MUNICIPAL	96008H	de 	\N	\N	\N	\N	\N
609	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Trizay	\N	\N	\N	2001	1049	MUNICIPAL	89014N	de 	\N	http://www.trizay.com/	\N	\N	\N
610	\N	\N	2007-07-17 00:00:00	ANCIEN	\N	Saint-Jean d'Angély	\N	\N	\N	2007	8060	MUNICIPAL	89012L	de 	\N	\N	\N	\N	\N
611	\N	\N	2008-11-27 00:00:00	ANCIEN	\N	Sancerre	\N	\N	\N	2008	2059	MUNICIPAL	71017B	de 	\N	\N	\N	\N	\N
613	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Saint-Priest-de-Gimel	\N	\N	\N	2001	412	MUNICIPAL	80031A	de 	\N	\N	\N	\N	\N
614	\N	\N	2003-11-19 00:00:00	ANCIEN	\N	Ussel	\N	\N	\N	2003	11448	MUNICIPAL	80007A	d'	\N	\N	\N	\N	\N
615	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Lévie	\N	\N	\N	2001	781	MUNICIPAL	94002S	de 	\N	\N	\N	\N	\N
618	\N	\N	\N	ACTIF	\N	Saint-Samson-sur-Rance	\N	\N	\N	\N	1180	MUNICIPAL	80036F	de 	\N	\N	\N	\N	\N
619	\N	\N	2023-04-05 00:00:00	ANCIEN	\N	Ploufragan	\N	\N	\N	\N	10583	MUNICIPAL	97010F	de 	\N	\N	\N	\N	\N
620	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Saint-Brieuc	\N	\N	\N	2001	44752	MUNICIPAL	89040Q	de 	\N	http://www.mairie-saint-brieuc.fr/	\N	\N	\N
621	\N	\N	2021-02-12 00:00:00	ANCIEN	\N	Saint-Vaury	\N	\N	\N	\N	2059	MUNICIPAL	81010Y	de 	\N	\N	\N	\N	\N
622	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Lupersat	\N	\N	\N	2001	375	MUNICIPAL	73006G	de 	\N	\N	\N	\N	\N
623	\N	\N	\N	ACTIF	\N	Le Bugue	\N	\N	\N	\N	2764	MUNICIPAL	97001E	de 	\N	\N	\N	\N	\N
624	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Vercel-Villedieu-le-Camp	\N	\N	1977	2001	1088	MUNICIPAL	88009M	de 	\N	\N	\N	\N	\N
625	\N	\N	2010-02-27 00:00:00	ANCIEN	\N	Maisons-du-Bois-Lièvremont	\N	\N	\N	2010	461	MUNICIPAL	88002E	de 	\N	\N	\N	\N	\N
626	\N	\N	2020-06-29 00:00:00	ANCIEN	\N	Montbéliard	\N	\N	2001	2008	29005	MUNICIPAL	80041C	de 	\N	http://www.montbeliard.com/	\N	\N	\N
627	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Les Ulis	\N	\N	\N	2001	27164	MUNICIPAL	86037H	de 	\N	http://www.ville-les-ulis.fr	\N	\N	\N
628	\N	\N	2000-12-13 00:00:00	ANCIEN	\N	Mennecy	\N	\N	\N	2000	11048	MUNICIPAL	95027G	de 	\N	\N	\N	\N	\N
629	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Gif-sur-Yvette	\N	\N	\N	2001	19754	MUNICIPAL	95053J	de 	\N	\N	\N	\N	\N
631	\N	\N	2000-03-18 00:00:00	ANCIEN	\N	Mennecy	\N	\N	\N	2000	11048	MUNICIPAL	88003F	de 	\N	\N	\N	\N	\N
632	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Bernay	\N	\N	\N	2001	10582	MUNICIPAL	89022N	de 	\N	http://www.ville-bernay27.fr	\N	\N	\N
633	\N	\N	2012-01-13 00:00:00	ANCIEN	\N	Lyons-la-forêt	\N	\N	\N	2012	701	MUNICIPAL	81014D	de 	\N	\N	\N	\N	\N
634	\N	\N	2020-11-24 00:00:00	ANCIEN	\N	Le Thuit	\N	\N	\N	\N	81	MUNICIPAL	83004K	de 	\N	\N	\N	\N	\N
635	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Tremblay-les-Villages	\N	\N	\N	2001	1451	MUNICIPAL	89009R	de 	\N	\N	\N	\N	\N
636	\N	\N	2010-12-20 00:00:00	ANCIEN	\N	Senonches	\N	\N	\N	2010	3171	MUNICIPAL	89031P	de 	\N	\N	\N	\N	\N
637	\N	\N	2014-02-21 00:00:00	ANCIEN	\N	Ploudalmezeau	\N	\N	\N	2014	4874	MUNICIPAL	80003V	de 	\N	\N	\N	\N	\N
638	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Quimper	\N	\N	\N	2001	59437	MUNICIPAL	86006A	de 	\N	\N	\N	\N	\N
639	\N	\N	2010-08-11 00:00:00	ANCIEN	\N	Plouvorn	\N	\N	\N	2010	2584	MUNICIPAL	89034S	de 	\N	\N	\N	\N	\N
640	\N	\N	2014-09-07 00:00:00	ANCIEN	\N	Valleraugue	\N	\N	\N	2014	1091	MUNICIPAL	92046W	de 	\N	\N	\N	\N	\N
641	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Bessèges	\N	\N	\N	2001	3635	MUNICIPAL	80040B	de 	\N	\N	\N	\N	\N
642	\N	\N	\N	ACTIF	\N	Launaguet	\N	\N	\N	\N	3768	MUNICIPAL	96001A	de 	\N	http://www.launaguet.com/	\N	\N	\N
643	\N	\N	2002-11-11 00:00:00	ANCIEN	\N	Lectoure	\N	\N	\N	2002	4034	MUNICIPAL	89008Q	de 	\N	http://www.lectoure.fr/	\N	\N	\N
645	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Rauzan	\N	\N	\N	2001	978	MUNICIPAL	90003B	de 	\N	\N	\N	\N	\N
665	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Mont-de-Marsan	\N	\N	\N	2001	28328	MUNICIPAL	83039W	de 	\N	\N	\N	\N	\N
666	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Contres	\N	\N	\N	2001	2979	MUNICIPAL	86005Y	de 	\N	\N	\N	\N	\N
668	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Rosières	\N	\N	\N	2001	1305	MUNICIPAL	78006D	de 	\N	http://www.ville-rosieres.fr	\N	\N	\N
670	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Saint-Nazaire	\N	\N	\N	2001	64812	MUNICIPAL	92019T	de 	\N	http://www.mairie-saintnazaire.fr/	\N	\N	\N
671	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	La Baule	\N	\N	\N	2001	14845	MUNICIPAL	92032Q	de 	\N	\N	\N	\N	\N
672	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Bouguenais	\N	\N	1971	2001	15099	MUNICIPAL	83012K	de 	\N	http://www.ville-bouguenais.fr/	\N	\N	\N
674	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Nuzéjouls	\N	\N	1971	2001	238	MUNICIPAL	92039X	de 	\N	\N	\N	\N	\N
675	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Francescas	\N	\N	\N	2001	625	MUNICIPAL	81001X	de 	\N	\N	\N	\N	\N
676	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Etriché	\N	\N	\N	2001	1024	MUNICIPAL	83038V	d'	\N	\N	\N	\N	\N
678	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Lessay	\N	\N	\N	2001	1719	MUNICIPAL	82002D	de 	\N	\N	\N	\N	\N
680	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Château-Gontier	\N	\N	1971	2001	8350	MUNICIPAL	83011J	de 	\N	\N	\N	\N	\N
681	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Villers-lès-Nancy	\N	\N	\N	2001	16515	MUNICIPAL	92009R	de 	\N	http://www.villers-les-nancy.fr	\N	\N	\N
682	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Vroncourt	\N	\N	\N	2001	138	MUNICIPAL	83036T	de 	\N	\N	\N	\N	\N
683	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Nancy	\N	\N	1971	2001	99351	MUNICIPAL	92007P	de 	\N	http://www.mairie-nancy.fr/	\N	\N	\N
684	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Jarny	\N	\N	\N	2001	8401	MUNICIPAL	92040Q	de 	\N	http://www.jarny.fr/site/index.php	\N	\N	\N
686	\N	\N	\N	ANCIEN	\N	Josselin	\N	\N	1965	2000	2338	MUNICIPAL	83050R	de 	\N	http://www.josselin.com/	\N	\N	\N
687	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Buléon	\N	\N	\N	2001	492	MUNICIPAL	81011A	de 	\N	\N	\N	\N	\N
688	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Metz	\N	\N	\N	2001	119594	MUNICIPAL	74042Q	de 	\N	http://www.mairie-metz.fr/	\N	\N	\N
689	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Creutzwald	\N	\N	\N	2001	15169	MUNICIPAL	74013K	de 	\N	\N	\N	\N	\N
690	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Serémange-Erzange	\N	\N	\N	2001	4143	MUNICIPAL	96007G	de 	\N	\N	\N	\N	\N
692	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Saint-Aubin les Forges	\N	\N	\N	2001	368	MUNICIPAL	92016Q	de 	\N	\N	\N	\N	\N
694	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Dechy	\N	\N	\N	2001	5464	MUNICIPAL	97006K	de 	\N	\N	\N	\N	\N
695	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Roubaix	\N	\N	\N	2001	97746	MUNICIPAL	65017N	de 	\N	http://www.mairie-roubaix.fr/	\N	\N	\N
696	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Lys-lez-Lannoy	\N	\N	\N	2001	12300	MUNICIPAL	97007L	de 	\N	\N	\N	\N	\N
697	\N	\N	2001-03-10 00:00:00	ANCIEN	\N	Cambrai	\N	\N	1995	\N	33092	MUNICIPAL	92031P	de 	\N	http://www.villedecambrai.com/	\N	\N	2014-10-09 10:33:51
698	\N	\N	1999-10-16 00:00:00	ANCIEN	\N	Steenvoorde	\N	\N	1965	1999	4020	MUNICIPAL	83013L	de 	\N	\N	\N	\N	\N
699	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Lille	\N	\N	\N	2001	172142	MUNICIPAL	85002R	de 	\N	http://www.mairie-lille.fr/	\N	\N	\N
700	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Lille	\N	\N	\N	2001	172242	MUNICIPAL	92037V	de 	\N	http://www.mairie-lille.fr/	\N	\N	\N
702	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Oursel-Maison	\N	\N	\N	2001	185	MUNICIPAL	92045V	d'	\N	\N	\N	\N	\N
703	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Compiègne	\N	\N	\N	2001	41896	MUNICIPAL	92035T	de 	\N	http://www.compiegne.fr/	\N	\N	\N
706	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Paris	\N	Ancien Vice-Président du Conseil de Paris	\N	2001	2175200	MUNICIPAL	95056M	de 	\N	http://www.paris.fr	\N	\N	\N
707	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Paris	\N	\N	\N	2001	\N	MUNICIPAL	86025D	de 	\N	http://www.paris.fr	\N	\N	\N
708	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Paris	\N	\N	\N	2001	2175200	MUNICIPAL	95026F	de 	\N	http://www.paris.fr	\N	\N	\N
709	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Paris	\N	\N	\N	2001	\N	MUNICIPAL	95022B	de	\N	http://www.paris.fr	\N	\N	\N
710	\N	\N	2000-04-17 00:00:00	ANCIEN	\N	Ier arrondissement de Paris	\N	\N	\N	2000	\N	MUNICIPAL	77009C	de 	\N	\N	\N	\N	\N
713	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Desvres	\N	\N	\N	2001	5318	MUNICIPAL	92043T	de 	\N	\N	\N	\N	\N
714	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Bapaume	\N	\N	\N	2001	3509	MUNICIPAL	92017R	de 	\N	\N	\N	\N	\N
715	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Liévin	\N	\N	\N	2001	33263	MUNICIPAL	83047W	de 	\N	http://www.ville-lievin.fr/	\N	\N	\N
716	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Isbergues	\N	\N	\N	2001	5145	MUNICIPAL	92027T	d'	\N	\N	\N	\N	\N
717	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Puy-Guillaume	\N	\N	\N	2001	2634	MUNICIPAL	81015E	de 	\N	http://www.puy-guillaume.com	\N	\N	\N
718	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Sévignacq-Meyracq	\N	\N	\N	2001	437	MUNICIPAL	83021L	de 	\N	\N	\N	\N	\N
719	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Lanne-en-Baretous	\N	\N	\N	2001	513	MUNICIPAL	92006N	de 	\N	\N	\N	\N	\N
720	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Biarritz	\N	\N	\N	2001	28742	MUNICIPAL	92013M	de 	\N	http://www.mairie-biarritz.fr/	\N	\N	\N
721	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Saint-Laurent de Neste	\N	\N	\N	2001	912	MUNICIPAL	92020L	de 	\N	\N	\N	\N	\N
722	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Saint-Laurent-de-la-Salanque	\N	\N	\N	2001	7186	MUNICIPAL	92036U	de 	\N	\N	\N	\N	\N
723	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Prades	\N	\N	\N	2001	6009	MUNICIPAL	92011K	de 	\N	http://www.prades.com/	\N	\N	\N
724	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Nordhouse	\N	\N	1977	2001	1333	MUNICIPAL	95036H	de 	\N	\N	\N	\N	\N
725	\N	\N	\N	ANCIEN	\N	Strasbourg	\N	\N	1995	1998	252338	MUNICIPAL	92005M	de 	\N	http://www.mairie-strasbourg.fr/	\N	\N	\N
11231	\N	\N	\N	ANCIEN	\N	Gap	\N	\N	1971	2007	\N	MUNICIPAL	07003H	de	\N	http://www.ville-gap.fr/	\N	\N	\N
11324	2008-03-21 00:00:00	\N	\N	ACTIF	\N	Annecy	\N	\N	2008	\N	0	MUNICIPAL	95038K	d'	\N	http://www.ville-annecy.fr/	\N	\N	2014-04-09 10:44:15
11336	2008-03-21 00:00:00	\N	2014-03-31 00:00:00	ANCIEN	\N	Drancy	\N	\N	\N	\N	0	MUNICIPAL	04085P	de	\N	http://www.drancy.net/index.php?id_rub=home	\N	\N	2014-04-07 11:11:37
11373	\N	\N	1993-10-29 00:00:00	ANCIEN	\N	Nice	\N	\N	\N	1993	\N	MUNICIPAL	89046W	\N	\N	http://www.ville-nice.fr/	\N	\N	\N
11361	\N	\N	\N	ACTIF	\N	Fréjus	\N	\N	1997	\N	\N	MUNICIPAL	08007R	de	\N	http://www.ville-frejus.fr/	\N	\N	\N
11325	2008-03-21 00:00:00	\N	2021-09-09 00:00:00	ANCIEN	\N	Basse-Terre	\N	\N	2008	\N	\N	MUNICIPAL	95050F	de	\N	http://www.annuaire-mairie.fr/ville-basse-terre.html#descriptif	\N	\N	\N
11590	\N	\N	\N	ACTIF	\N	Revel	\N	\N	1989	\N	\N	MUNICIPAL	08028W	de	\N	http://www.revel-lauragais.com/pages/f/communes/textes_communes/revel.html	\N	\N	\N
11670	\N	\N	2014-02-13 00:00:00	ANCIEN	\N	Argentat	\N	\N	1989	\N	\N	MUNICIPAL	08046Y	d'	\N	http://www.argentat.fr	\N	\N	2014-02-14 10:05:07
10127	\N	\N	2012-07-30 00:00:00	ANCIEN	\N	Boulogne-Billancourt	\N	\N	\N	2012	101743	MUNICIPAL	59537V	\N	\N	http://www.mairie-boulogne-billancourt.fr/	\N	\N	\N
10150	\N	\N	\N	ACTIF	\N	Limoges	\N	\N	\N	\N	144080	MUNICIPAL	000351	\N	\N	http://www.mairie-limoges.fr/	\N	\N	\N
10155	\N	\N	\N	ACTIF	\N	Montville	\N	\N	\N	\N	4365	MUNICIPAL	000561	\N	\N	http://www.mairie-montville.fr/	\N	\N	\N
10158	\N	\N	\N	ACTIF	\N	Sausset-les-Pins	\N	\N	\N	\N	3880	MUNICIPAL	000502	\N	\N	http://www.ville-sausset-les-pins.fr/	\N	\N	\N
10163	\N	\N	1999-06-25 00:00:00	ANCIEN	\N	Villersexel	\N	\N	\N	1999	1460	MUNICIPAL	59551T	\N	\N	http://www.villersexel.org	\N	\N	\N
10170	\N	\N	\N	ACTIF	\N	Ajaccio	\N	\N	\N	\N	55280	MUNICIPAL	000419	\N	\N	http://www.ajaccio.fr/	\N	\N	\N
10178	\N	\N	\N	ACTIF	\N	Soulac-sur-Mer	\N	\N	\N	\N	2590	MUNICIPAL	000514	\N	\N	http://www.mairie-soulac.fr	\N	\N	\N
10193	\N	\N	\N	ACTIF	\N	Alfortville	\N	\N	\N	\N	36119	MUNICIPAL	95065N	\N	\N	http://www.mairie-alfortville.fr/	\N	\N	\N
10096	\N	\N	2016-06-22 00:00:00	ANCIEN	\N	Lautrec	\N	\N	\N	2016	1527	MUNICIPAL	59572Y	\N	\N	\N	\N	\N	\N
10097	\N	\N	\N	ACTIF	\N	La Dornac	\N	\N	\N	\N	\N	MUNICIPAL	000621	\N	\N	\N	\N	\N	\N
10098	\N	\N	\N	ACTIF	\N	Buxy	\N	\N	\N	\N	\N	MUNICIPAL	58670V	\N	\N	\N	\N	\N	\N
10099	\N	\N	\N	ACTIF	\N	Ouilly-le-Vicomte	\N	\N	\N	\N	910	MUNICIPAL	000331	\N	\N	\N	\N	\N	\N
10100	\N	\N	2019-03-26 00:00:00	ANCIEN	\N	Saint-Etienne	\N	\N	\N	\N	\N	MUNICIPAL	58330C	\N	\N	http://www.mairie-st-etienne.fr/	\N	\N	\N
10101	\N	\N	2012-12-07 00:00:00	ANCIEN	\N	Aroue-Ithorots-Olhaïby	\N	\N	\N	2012	250	MUNICIPAL	59227J	\N	\N	\N	\N	\N	\N
10102	\N	\N	\N	ACTIF	\N	Avignon	\N	\N	\N	\N	\N	MUNICIPAL	000164	\N	\N	http://www.mairie-avignon.fr/	\N	\N	\N
10103	\N	\N	\N	ACTIF	\N	Réalmont	\N	\N	\N	\N	\N	MUNICIPAL	000647	\N	\N	\N	\N	\N	\N
10105	\N	\N	2009-07-29 00:00:00	ANCIEN	\N	Gonfreville-l'Orcher	\N	\N	\N	2009	\N	MUNICIPAL	58630M	\N	\N	\N	\N	\N	\N
10106	\N	\N	2004-01-31 00:00:00	ANCIEN	\N	Villemur-sur-Tarn	\N	\N	\N	2004	4460	MUNICIPAL	58942B	\N	\N	\N	\N	\N	\N
10107	\N	\N	\N	ACTIF	\N	<commune indéterminée>	\N	\N	\N	\N	\N	MUNICIPAL	58502E	\N	\N	\N	\N	\N	\N
10108	\N	\N	\N	ACTIF	\N	Groffliers	\N	\N	\N	\N	\N	MUNICIPAL	000411	\N	\N	\N	\N	\N	\N
10109	\N	\N	2003-11-13 00:00:00	ANCIEN	\N	<commune indéterminée>	\N	\N	\N	\N	\N	MUNICIPAL	58351H	\N	\N	\N	\N	\N	\N
10110	\N	\N	2011-07-08 00:00:00	ANCIEN	\N	Beziers	\N	\N	\N	2011	\N	MUNICIPAL	58934B	\N	\N	http://www.ville-beziers.fr/	\N	\N	\N
10111	\N	\N	\N	ACTIF	\N	Port-Lesney (Jura)	\N	\N	\N	\N	\N	MUNICIPAL	000197	\N	\N	\N	\N	\N	\N
10112	\N	\N	2014-03-06 00:00:00	ANCIEN	\N	Cahors	\N	\N	\N	2014	\N	MUNICIPAL	58818X	\N	\N	http://www.mairie-cahors.fr/	\N	\N	\N
10113	\N	\N	\N	ACTIF	\N	Neufchâtel en Bray	\N	\N	\N	\N	\N	MUNICIPAL	000177	\N	\N	\N	\N	\N	\N
10114	\N	\N	1996-12-18 00:00:00	ANCIEN	\N	Auffay	\N	\N	\N	1996	1888	MUNICIPAL	000449	\N	\N	\N	\N	\N	\N
10116	\N	\N	2013-03-13 00:00:00	ANCIEN	\N	Salon-de-Provence	\N	\N	\N	2013	\N	MUNICIPAL	58944D	\N	\N	\N	\N	\N	\N
10117	\N	\N	\N	ACTIF	\N	Nanterre	\N	\N	\N	\N	84565	MUNICIPAL	86027F	\N	\N	http://www.mairie-nanterre.fr/	\N	\N	\N
10118	\N	\N	1997-01-22 00:00:00	ANCIEN	\N	Bondy	\N	\N	\N	1997	46676	MUNICIPAL	000533	\N	\N	http://www.ville-bondy.fr/	\N	\N	\N
11531	\N	\N	\N	ANCIEN	\N	Bourg-de-Péage	\N	\N	1983	2009	\N	MUNICIPAL	08016S	de	\N	\N	\N	\N	\N
10200	\N	\N	2011-01-24 00:00:00	ANCIEN	\N	Besançon	\N	\N	\N	2011	\N	MUNICIPAL	59307H	\N	\N	http://www.mairie-besancon.fr/	\N	\N	\N
11798	2008-03-16 00:00:00	\N	2014-03-30 00:00:00	ANCIEN	\N	Marseille (4ème et 5ème arrondissements)	\N	\N	\N	\N	0	MUNICIPAL	08026U	de	\N	http://www.mairie-marseille.fr/	\N	\N	2014-04-08 16:31:57
10205	\N	\N	\N	ACTIF	\N	Thionville	\N	\N	\N	\N	41450	MUNICIPAL	59247N	\N	\N	http://www.mairie-thionville.fr/	\N	\N	\N
10213	\N	\N	2007-12-25 00:00:00	ANCIEN	\N	Lille	\N	\N	\N	2007	\N	MUNICIPAL	59252K	\N	\N	http://www.mairie-lille.fr/	\N	\N	\N
612	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Saint-Amand-Montrond	\N	\N	1983	2001	11937	MUNICIPAL	89045V	de 	\N	http://www.cg18.fr/commune/st-amand-montrond/	\N	\N	\N
10701	\N	\N	2004-06-07 00:00:00	ANCIEN	\N	Versailles	\N	\N	1983	\N	\N	MUNICIPAL	04018C	de	\N	http://www.mairie-versailles.fr/	\N	\N	2017-09-24 18:47:10
10714	\N	\N	\N	ANCIEN	\N	Albert	\N	\N	1965	1977	\N	MUNICIPAL	95023C	d'	\N	http://www.ville-albert.fr/	\N	\N	\N
10799	\N	\N	\N	ANCIEN	\N	Mulhouse	\N	\N	1983	1989	\N	MUNICIPAL	04040A	de	\N	http://www.mairie-mulhouse.fr/	\N	\N	\N
11632	\N	\N	\N	ANCIEN	\N	Belfort	\N	\N	1983	2007	\N	MUNICIPAL	02053W	de	\N	http://www.mairie-belfort.fr/	\N	\N	\N
11768	\N	\N	\N	ANCIEN	\N	Besançon	\N	\N	1989	1998	\N	MUNICIPAL	08067E	de	\N	http://www.mairie-besancon.fr/	\N	\N	\N
10104	\N	\N	1988-07-13 00:00:00	ANCIEN	\N	Le Havre	\N	\N	\N	1988	\N	MUNICIPAL	59305F	\N	\N	http://www.ville-lehavre.fr/	\N	\N	\N
10115	\N	\N	\N	ACTIF	\N	Saint-Ouen	\N	\N	\N	\N	42343	MUNICIPAL	59574B	\N	\N	http://www.ville-saintouen.fr	\N	\N	\N
12012	2008-03-30 00:00:00	\N	\N	ACTIF	\N	Plérin	\N	\N	2008	\N	\N	MUNICIPAL	10003H	de	\N	http://www.ville-plerin.fr/	\N	\N	\N
10055	\N	\N	2010-10-31 00:00:00	ANCIEN	\N	Aillières-Beauvoir	\N	\N	\N	2010	237	MUNICIPAL	59533R	\N	\N	\N	\N	\N	\N
12057	\N	\N	2016-01-12 00:00:00	ANCIEN	\N	Valenciennes	\N	\N	2008	\N	\N	MUNICIPAL	01043Q	de	\N	\N	\N	\N	2016-06-02 17:14:40
12058	\N	\N	\N	ANCIEN	\N	Mulhouse	\N	\N	1989	2010	\N	MUNICIPAL	04040A	de 	\N	\N	\N	\N	\N
12059	\N	\N	\N	ACTIF	\N	Mulhouse	\N	\N	2010	\N	\N	MUNICIPAL	04040A	de	\N	\N	\N	\N	\N
12074	\N	\N	\N	ACTIF	\N	Montmédy	\N	\N	1983	\N	\N	MUNICIPAL	11003M	de	\N	\N	\N	\N	\N
11335	2008-03-21 00:00:00	\N	\N	ACTIF	\N	Sonnaz	\N	\N	\N	\N	\N	MUNICIPAL	04090L	de	\N	\N	\N	\N	\N
11851	\N	\N	\N	ACTIF	\N	Cazals	\N	\N	1965	\N	\N	MUNICIPAL	08074D	de	\N	http://www.info82.com/cazals/	\N	\N	\N
12029	\N	\N	\N	ACTIF	\N	Briennon	\N	\N	1997	\N	\N	MUNICIPAL	10005K	de	\N	\N	\N	\N	\N
11332	2008-03-22 00:00:00	\N	\N	ACTIF	\N	Montreuil-sous-Bois	\N	\N	\N	\N	\N	MUNICIPAL	04082L	de	\N	http://www.montreuil.fr/	\N	\N	\N
11618	\N	\N	2013-02-06 00:00:00	ANCIEN	\N	Saint-Jean-Cap-Ferrat	\N	\N	1977	2013	\N	MUNICIPAL	08036W	de	\N	http://www.saintjeancapferrat.fr/forum/index.php	\N	\N	\N
10845	\N	\N	\N	ACTIF	\N	Briis-sous-Forges	\N	\N	2001	\N	\N	MUNICIPAL	04050C	de	\N	http://www.mairie-de-briis-sous-forges.fr/	\N	\N	\N
6041	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Oursel-Maison	\N	\N	2001	\N	185	MUNICIPAL	92045V	d'	\N	 http://www.oursel-maison.fr/	\N	\N	2016-05-12 18:19:56
11682	\N	\N	2020-06-27 00:00:00	ANCIEN	\N	Fleurance	\N	\N	1995	\N	\N	MUNICIPAL	08049C	de	\N	http://www.villefleurance.fr/	\N	\N	\N
10821	2001-03-21 00:00:00	\N	2020-05-25 00:00:00	ANCIEN	\N	Ranspach-le-Bas	\N	\N	\N	\N	\N	MUNICIPAL	04044E	de	\N	http://www.portedusundgau.fr/ranspach_le_bas.htm	\N	\N	2017-11-06 16:30:04
6250	2001-03-18 00:00:00	\N	2014-03-31 00:00:00	ANCIEN	\N	Bourg-lès-Valence	\N	\N	\N	\N	19000	MUNICIPAL	96006F	de	\N	http://www.bourg-les-valence.fr/	\N	\N	2014-04-08 16:51:31
6126	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Marsan	\N	\N	2001	\N	420	MUNICIPAL	98032R	de	\N	\N	\N	\N	\N
11018	\N	\N	\N	ACTIF	\N	Sorgues	\N	\N	1989	\N	\N	MUNICIPAL	04092N	de	\N	http://www.sorgues.fr/	\N	\N	\N
6079	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Grand-Quevilly	\N	\N	2001	\N	27658	MUNICIPAL	95003X	de	\N	http://www.ville-grand-quevilly.fr/	\N	\N	\N
11201	\N	\N	2008-03-21 00:00:00	ANCIEN	\N	Talairan	\N	\N	1983	2008	\N	MUNICIPAL	06005F	de	\N	\N	\N	\N	\N
11301	1995-06-01 00:00:00	\N	\N	ACTIF	\N	Paris (XVIIème arrondissement)	\N	\N	1995	\N	\N	MUNICIPAL	07033P	de 	\N	http://www.paris.fr	\N	\N	\N
11605	\N	\N	\N	ACTIF	\N	Châteaubourg	\N	\N	2001	\N	0	MUNICIPAL	08032S	de	\N	http://chateaubourg.fr/site/	\N	\N	2014-04-07 11:25:24
10952	\N	\N	\N	ACTIF	\N	Montigny-lès-Cormeilles	\N	\N	1977	\N	\N	MUNICIPAL	04078Q	de	\N	http://www.montigny95.fr/	\N	\N	\N
6368	\N	\N	\N	ACTIF	\N	La Chaussée-Saint-Victor	\N	\N	1989	\N	4100	MUNICIPAL	01007L	de	\N	http://www.lachausseesaintvictor.fr/	\N	\N	2014-04-09 10:43:32
6508	\N	\N	2014-06-11 00:00:00	ANCIEN	\N	Saint-Herblain	\N	\N	1989	2014	44820	MUNICIPAL	01053S	de	\N	http://www.saint-herblain.fr/	\N	\N	\N
11623	\N	\N	\N	ACTIF	\N	Valbonne Sophia Antipolis	\N	\N	1996	\N	0	MUNICIPAL	08038Y	de	\N	http://www.ville-valbonne.fr/	\N	\N	2014-04-09 11:03:30
5096	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Fontenay-sur-Eure	\N	\N	1983	2001	669	MUNICIPAL	98023Q	de 	\N	\N	\N	\N	\N
6097	2001-03-11 00:00:00	\N	2014-04-01 00:00:00	ANCIEN	\N	Fontenay-sur-Eure	\N	http://valdeleure.decideur.net/index.adml?s=9575637301152345586220&r=149	\N	\N	669	MUNICIPAL	98023Q	de	\N	\N	\N	\N	2014-04-08 16:04:50
10807	1971-03-21 00:00:00	\N	\N	ACTIF	\N	Saint-Maurice	\N	\N	\N	\N	\N	MUNICIPAL	04042C	de	\N	http://www.ville-saint-maurice.com/	\N	\N	2017-11-13 10:04:23
11553	1983-03-08 00:00:00	\N	2017-09-30 00:00:00	ANCIEN	\N	Saint-Aunès	\N	\N	\N	\N	\N	MUNICIPAL	08020N	de	\N	http://www.saint-aunes.fr/	\N	\N	2017-12-18 15:53:06
11523	\N	\N	\N	ACTIF	\N	Bourbriac	\N	\N	1977	\N	0	MUNICIPAL	08014Q	de	\N	http://www.bourbriac.fr/	\N	\N	2014-04-07 16:31:26
6045	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Ville-d'Avray	\N	\N	2001	\N	11616	MUNICIPAL	95007C	de	\N	http://www.mairie-villedavray.fr/	\N	\N	\N
6000	2001-03-11 00:00:00	\N	2010-10-04 00:00:00	ANCIEN	\N	Saint-Quentin	\N	\N	2001	2010	60644	MUNICIPAL	98036V	de	\N	http://www.ville-saintquentin.fr/	\N	\N	\N
11972	\N	\N	\N	ANCIEN	\N	Villefranche-sur-Saône	\N	\N	1989	2008	\N	MUNICIPAL	09010Q	de	\N	\N	\N	\N	\N
11975	\N	\N	2011-03-01 00:00:00	ANCIEN	\N	Vézelay	\N	\N	2008	\N	\N	MUNICIPAL	09011R	de	\N	\N	\N	\N	\N
11976	\N	\N	\N	ANCIEN	\N	Pierre-Perthuis	\N	\N	1983	2008	\N	MUNICIPAL	09011R	de	\N	\N	\N	\N	\N
11996	\N	\N	\N	ANCIEN	\N	Saint-Cloud	\N	\N	1971	1982	\N	MUNICIPAL	77019E	de	\N	\N	\N	\N	\N
11999	\N	\N	2008-02-28 00:00:00	ANCIEN	\N	Vert-le-Petit	\N	\N	2001	2008	\N	MUNICIPAL	10001F	de	\N	\N	\N	\N	\N
11207	2006-09-10 00:00:00	\N	\N	ACTIF	\N	Saint-Céneri-le-Gérei	\N	\N	2006	\N	\N	MUNICIPAL	92029V	de	\N	\N	\N	\N	\N
11248	1989-03-01 00:00:00	\N	\N	ACTIF	\N	Garches	\N	\N	1989	\N	\N	MUNICIPAL	07024N	de	\N	http://www.ville-garches.fr/	\N	\N	\N
11341	2008-03-21 00:00:00	\N	2014-03-31 00:00:00	ANCIEN	\N	Orsennes	\N	\N	\N	\N	0	MUNICIPAL	07032N	de	\N	\N	\N	\N	2014-04-08 16:48:38
11342	2008-03-21 00:00:00	\N	\N	ACTIF	\N	Saint-Valérien	\N	\N	\N	\N	\N	MUNICIPAL	86044G	de	\N	\N	\N	\N	\N
12409	1983-03-14 00:00:00	\N	\N	ACTIF	\N	Beauregard-l'Évêque	\N	\N	\N	\N	\N	MUNICIPAL	11105E	de	\N	\N	\N	\N	\N
11344	2008-03-21 00:00:00	\N	\N	ACTIF	\N	Laval	\N	\N	\N	\N	\N	MUNICIPAL	01047U	de	\N	http://www.mairie-laval.fr/	\N	\N	\N
11345	2008-03-21 00:00:00	\N	\N	ACTIF	\N	Lazenay	\N	\N	\N	\N	0	MUNICIPAL	05012A	de	\N	\N	\N	\N	2018-02-01 14:16:11
11346	2008-03-21 00:00:00	\N	2015-02-25 00:00:00	ANCIEN	\N	Sospel	\N	\N	\N	2015	\N	MUNICIPAL	84004P	de	\N	\N	\N	\N	\N
12046	1995-03-01 00:00:00	\N	2008-02-28 00:00:00	ANCIEN	\N	Val-de-Vière	\N	\N	1995	2008	\N	MUNICIPAL	10007M	de	\N	\N	\N	\N	\N
12103	1989-03-18 00:00:00	\N	2011-03-11 00:00:00	ANCIEN	\N	Athis-Mons	\N	\N	\N	\N	\N	MUNICIPAL	11077T	d'	\N	\N	\N	\N	\N
13778	2014-04-01 00:00:00	2014-04-01 00:00:00	\N	ACTIF	\N	Charbonnières-les-Vieilles	\N	\N	\N	\N	\N	MUNICIPAL	11104D	de 	\N	\N	\N	2014-06-10 14:51:16	2014-06-10 14:52:19
13826	2008-03-16 00:00:00	\N	2020-03-15 00:00:00	ANCIEN	\N	Vonnas	\N	\N	\N	\N	\N	MUNICIPAL	14038Y	de	\N	\N	\N	2014-09-17 11:39:11	2017-11-13 11:35:22
13824	2014-03-15 00:00:00	2014-03-28 00:00:00	2017-07-15 00:00:00	ANCIEN	\N	Vallery	\N	\N	\N	\N	\N	MUNICIPAL	14037X	de	\N	\N	\N	2014-09-17 11:35:11	2014-09-29 17:17:51
13827	\N	\N	\N	ANCIEN	\N	Cayenne	\N	\N	1977	2002	\N	MUNICIPAL	14039A	de	\N	\N	\N	2014-09-17 11:56:39	2014-09-17 11:57:34
12120	2002-01-01 00:00:00	\N	\N	ACTIF	\N	La Charité-sur-Loire	\N	\N	\N	\N	0	MUNICIPAL	11015D	de	\N	\N	\N	\N	2014-04-07 11:21:06
13843	2001-03-18 00:00:00	2001-03-18 00:00:00	\N	ACTIF	\N	Mus	\N	\N	\N	\N	\N	MUNICIPAL	14059S	de 	\N	\N	\N	2014-09-17 17:06:10	2017-11-15 09:37:08
12134	\N	\N	\N	ANCIEN	\N	Mortagne-au-Perche	\N	\N	1971	2014	\N	MUNICIPAL	11100Y	de	\N	\N	\N	\N	2014-10-15 16:52:48
12139	\N	\N	\N	ANCIEN	\N	Lognes	\N	\N	1991	2011	\N	MUNICIPAL	11074Q	de	\N	\N	\N	\N	\N
12479	1986-06-27 00:00:00	\N	2001-06-15 00:00:00	ANCIEN	\N	Tullins	\N	\N	\N	2001	\N	MUNICIPAL	11041F	de	\N	\N	\N	\N	\N
12519	\N	\N	2011-10-01 00:00:00	ANCIEN	\N	Clichy-sous-Bois	\N	\N	1995	2011	\N	MUNICIPAL	11051H	de	\N	\N	\N	\N	\N
12856	2001-03-01 00:00:00	\N	2008-03-01 00:00:00	ANCIEN	\N	Sada	\N	\N	\N	\N	\N	MUNICIPAL	11072N	de	\N	\N	\N	\N	\N
12527	1995-06-18 00:00:00	1995-06-18 00:00:00	\N	ACTIF	\N	Massy	\N	\N	\N	\N	0	MUNICIPAL	11070L	de	\N	http://www.ville-massy.fr	\N	\N	2017-10-23 12:51:13
12107	1995-06-18 00:00:00	\N	2014-03-30 00:00:00	ANCIEN	\N	Clamart	\N	\N	\N	\N	0	MUNICIPAL	11084S	de	\N	\N	\N	\N	2014-04-07 11:24:01
13849	\N	\N	2014-03-16 00:00:00	ANCIEN	\N	Preuschdorf	\N	\N	1989	\N	\N	MUNICIPAL	14061L	de	\N	\N	\N	2014-09-17 17:27:17	2014-09-28 17:53:40
12146	2001-03-15 00:00:00	\N	\N	ACTIF	\N	Aubergenville	\N	\N	\N	\N	0	MUNICIPAL	11090Q	d'	\N	\N	\N	\N	2018-02-13 12:36:28
12529	1977-03-22 00:00:00	\N	1998-03-22 00:00:00	ANCIEN	\N	Crosne	\N	\N	\N	\N	\N	MUNICIPAL	11068S	de	\N	\N	\N	\N	\N
12162	1983-03-13 00:00:00	\N	2011-10-13 00:00:00	ANCIEN	\N	Bondy	\N	\N	\N	\N	\N	MUNICIPAL	11054L	de	\N	\N	\N	\N	\N
12171	1983-03-14 00:00:00	\N	\N	ACTIF	\N	Franconville-la-Garenne	\N	\N	\N	\N	\N	MUNICIPAL	11088W	de	\N	\N	\N	\N	\N
12178	\N	\N	\N	ANCIEN	\N	Pierrefitte-sur-Aire	\N	\N	1989	2004	\N	MUNICIPAL	11082Q	de	\N	\N	\N	\N	\N
12188	2001-03-01 00:00:00	\N	\N	ACTIF	\N	Woippy	\N	\N	\N	\N	\N	MUNICIPAL	11049P	de	\N	\N	\N	\N	2018-05-30 09:31:03
12192	1983-03-01 00:00:00	\N	2014-03-31 00:00:00	ANCIEN	\N	Martel	\N	\N	\N	\N	0	MUNICIPAL	11012A	de	\N	\N	\N	\N	2014-04-16 17:21:43
12196	1977-03-20 00:00:00	\N	\N	ACTIF	\N	Eragny-sur-Oise	\N	\N	\N	\N	0	MUNICIPAL	11089X	d'	\N	\N	\N	\N	2014-04-07 11:19:45
12195	1989-04-01 00:00:00	\N	1995-06-01 00:00:00	ANCIEN	\N	Metz	\N	\N	1989	1995	\N	MUNICIPAL	11049P	de	\N	\N	\N	\N	\N
12862	2008-03-16 00:00:00	\N	2014-06-02 00:00:00	ANCIEN	\N	Les Ulis	\N	\N	\N	\N	0	MUNICIPAL	11069T	de 	\N	\N	\N	\N	2015-01-14 10:11:13
12204	1974-03-10 00:00:00	\N	2001-03-10 00:00:00	ANCIEN	\N	Saint-Julien-Chapteuil	\N	\N	1974	2001	\N	MUNICIPAL	11093T	de	\N	\N	\N	\N	\N
12533	\N	\N	\N	ACTIF	\N	Meudon	\N	\N	1999	\N	\N	MUNICIPAL	11085T	de	\N	\N	\N	\N	\N
12207	\N	\N	\N	ACTIF	\N	Moirax	\N	\N	1983	\N	\N	MUNICIPAL	11094U	de	\N	\N	\N	\N	\N
12211	\N	\N	\N	ANCIEN	\N	Cosne-sur-Loire	\N	\N	1995	2001	\N	MUNICIPAL	11015D	de	\N	\N	\N	\N	\N
12552	1983-03-13 00:00:00	\N	1996-11-12 00:00:00	ANCIEN	\N	Sézanne	\N	\N	\N	\N	\N	MUNICIPAL	11097X	de	\N	\N	\N	\N	\N
12349	\N	\N	\N	ACTIF	\N	Nantes	\N	\N	2001	\N	\N	MUNICIPAL	11065P	de	\N	\N	\N	\N	\N
12384	\N	\N	\N	ACTIF	\N	Paris (XVème arrondissement)	\N	\N	2001	\N	\N	MUNICIPAL	11080N	de	\N	\N	\N	\N	\N
12386	1983-03-31 00:00:00	\N	\N	ANCIEN	\N	Versailles	\N	\N	\N	2014	\N	MUNICIPAL	11091R	de	\N	\N	\N	\N	2014-11-18 16:06:12
12390	1995-06-18 00:00:00	\N	2014-03-28 00:00:00	ANCIEN	\N	Pantin	\N	\N	\N	\N	0	MUNICIPAL	11055M	de	\N	\N	\N	\N	2014-04-07 11:06:17
12392	2001-03-18 00:00:00	\N	\N	ACTIF	\N	Alfortville	\N	\N	\N	\N	\N	MUNICIPAL	11032E	d'	\N	\N	\N	\N	\N
12396	\N	\N	\N	ANCIEN	\N	Champigny-sur-Marne	\N	\N	1977	1989	\N	MUNICIPAL	11034G	de	\N	\N	\N	\N	\N
12860	1995-06-18 00:00:00	\N	2001-03-18 00:00:00	ANCIEN	\N	Blincourt	\N	\N	\N	\N	\N	MUNICIPAL	11044J	de 	\N	\N	\N	\N	\N
12859	1989-03-19 00:00:00	\N	1995-06-18 00:00:00	ANCIEN	\N	Choisy-la-Victoire	\N	\N	\N	\N	\N	MUNICIPAL	11044J	de 	\N	\N	\N	\N	\N
12412	1983-03-13 00:00:00	\N	2001-03-18 00:00:00	ANCIEN	\N	Mont-Dore	\N	\N	\N	\N	\N	MUNICIPAL	11010L	de	\N	\N	\N	\N	\N
12424	\N	\N	2020-01-11 00:00:00	ANCIEN	\N	Koné	\N	\N	1970	1974	\N	MUNICIPAL	11011M	de	\N	\N	\N	\N	\N
12426	1995-06-18 00:00:00	\N	2014-03-23 00:00:00	ANCIEN	\N	Île des Pins	\N	\N	\N	\N	\N	MUNICIPAL	11011M	de l'	\N	\N	\N	\N	2014-10-22 17:24:22
12508	\N	\N	\N	ANCIEN	\N	Trignac	\N	\N	1977	1989	\N	MUNICIPAL	11066Q	de	\N	\N	\N	\N	\N
12511	\N	\N	\N	ANCIEN	\N	Saint-Nazaire	\N	\N	1995	2001	\N	MUNICIPAL	11066Q	de	\N	\N	\N	\N	\N
12802	1983-03-13 00:00:00	\N	2014-04-02 00:00:00	ANCIEN	\N	Tours	\N	\N	\N	\N	0	MUNICIPAL	11108H	de	\N	\N	\N	\N	2014-06-10 10:42:06
12805	1983-03-13 00:00:00	\N	2001-03-18 00:00:00	ANCIEN	\N	Clermont-Ferrand	\N	\N	\N	\N	\N	MUNICIPAL	11104D	de	\N	\N	\N	\N	\N
12807	1983-03-12 00:00:00	\N	2014-03-30 00:00:00	ANCIEN	\N	Montlouis sur Loire	\N	\N	\N	\N	0	MUNICIPAL	11107G	de	\N	\N	\N	\N	2014-04-07 11:15:45
12811	2001-03-18 00:00:00	\N	2021-07-19 00:00:00	ANCIEN	\N	Nancy	\N	\N	\N	\N	\N	MUNICIPAL	11048N	de	\N	\N	\N	\N	\N
12813	1989-03-19 00:00:00	\N	\N	ANCIEN	\N	Nantes	\N	\N	\N	2008	\N	MUNICIPAL	11067R	de	\N	\N	\N	\N	\N
12827	2001-06-01 00:00:00	\N	2012-01-31 00:00:00	ANCIEN	\N	Rouvroy	\N	\N	\N	\N	\N	MUNICIPAL	11063M	de	\N	\N	\N	\N	\N
12837	1995-06-18 00:00:00	\N	2020-06-28 00:00:00	ANCIEN	\N	Le François	\N	\N	\N	\N	\N	MUNICIPAL	11109J	de	\N	\N	\N	\N	2017-11-13 15:39:37
12382	\N	\N	\N	ACTIF	\N	Orchies	\N	\N	2001	\N	\N	MUNICIPAL	11039M	d'	\N	\N	\N	\N	\N
12522	\N	\N	\N	ANCIEN	\N	Blainville-sur-l'Eau	\N	\N	1977	1983	\N	MUNICIPAL	01014K	de	\N	\N	\N	\N	\N
12341	1983-03-13 00:00:00	\N	\N	ACTIF	\N	Marquillies	\N	\N	\N	\N	\N	MUNICIPAL	11040E	de	\N	\N	\N	\N	2018-03-08 15:21:10
12342	2001-03-18 00:00:00	\N	\N	ACTIF	\N	Calais	\N	\N	\N	\N	\N	MUNICIPAL	11060J	de	\N	\N	\N	\N	\N
12480	1995-06-20 00:00:00	\N	2020-06-28 00:00:00	ANCIEN	\N	Saint-Sébastien-sur-Loire	\N	\N	\N	\N	\N	MUNICIPAL	11064N	de	\N	\N	\N	\N	2017-12-04 19:11:08
12515	2001-03-17 00:00:00	\N	\N	ACTIF	\N	Bourget	\N	\N	\N	\N	\N	MUNICIPAL	11053K	du	\N	\N	\N	\N	2017-11-13 14:33:52
12500	1989-04-01 00:00:00	\N	2014-03-31 00:00:00	ANCIEN	\N	Roubaix	\N	\N	\N	\N	0	MUNICIPAL	11037K	de	\N	\N	\N	\N	2014-04-17 11:57:02
11343	2008-03-21 00:00:00	\N	\N	ACTIF	\N	Le Quesnoy	\N	\N	2008	\N	\N	MUNICIPAL	92042S	de	\N	http://www.lequesnoyvilleforte.fr/	\N	\N	\N
701	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Le Quesnoy	\N	\N	\N	2001	4890	MUNICIPAL	92042S	de 	\N	\N	\N	\N	\N
6491	\N	\N	\N	ANCIEN	\N	Roquetoire	\N	\N	1995	2001	1500	MUNICIPAL	01033N	de	\N	\N	\N	\N	\N
6492	2001-03-23 00:00:00	\N	2008-03-14 00:00:00	ANCIEN	\N	Roquetoire	\N	\N	2001	2008	1500	MUNICIPAL	01033N	de	\N	\N	\N	\N	\N
6527	\N	\N	\N	ACTIF	\N	Villard-Bonnot	\N	\N	\N	\N	\N	MUNICIPAL	01059Y	de	\N	\N	\N	\N	\N
6544	\N	\N	\N	ANCIEN	\N	Saint-Just-Chaleyssin	\N	\N	1971	1995	\N	MUNICIPAL	01019Q	de	\N	\N	\N	\N	\N
6646	2001-03-18 00:00:00	\N	2014-04-01 00:00:00	ANCIEN	\N	Lille	\N	\N	\N	\N	0	MUNICIPAL	92018S	de	\N	http://www.mairie-lille.fr/	\N	\N	2014-04-09 22:21:29
6038	2001-03-11 00:00:00	\N	2001-06-01 00:00:00	ANCIEN	\N	Le Quesnoy	\N	\N	2001	2001	4890	MUNICIPAL	92042S	de	\N	\N	\N	\N	\N
10896	\N	\N	\N	ACTIF	\N	Paris (18ème arrondissement)	\N	\N	2001	\N	\N	MUNICIPAL	04066L	de	\N	http://www.paris.fr	\N	\N	\N
10910	\N	\N	2006-03-01 00:00:00	ANCIEN	\N	Paris (13ème arrondissement)	\N	\N	2001	2006	\N	MUNICIPAL	04067M	de	\N	\N	\N	\N	\N
10960	1995-07-03 00:00:00	\N	\N	ACTIF	\N	Paris (19ème arrondissement)	\N	\N	\N	\N	0	MUNICIPAL	04079R	de	\N	\N	\N	\N	2014-04-07 09:58:40
11076	\N	\N	2008-03-16 00:00:00	ANCIEN	\N	Paris (16ème arrondissement)	\N	\N	2001	2008	\N	MUNICIPAL	04077P	de	\N	\N	\N	\N	\N
11130	\N	\N	2008-03-16 00:00:00	ANCIEN	\N	Saint-Pierre	\N	\N	\N	2008	\N	MUNICIPAL	05001W	de	\N	http://www.ville-saintpierre.fr/index.php	\N	\N	\N
11338	2008-03-14 00:00:00	\N	\N	ACTIF	\N	Roquetoire	\N	\N	\N	\N	\N	MUNICIPAL	01033N	de	\N	\N	\N	\N	\N
10880	\N	\N	\N	ACTIF	\N	Paris (20ème arrondissement)	\N	\N	1995	\N	\N	MUNICIPAL	04059M	de	\N	http://www.paris.fr	\N	\N	\N
12040	1999-01-20 00:00:00	\N	\N	ANCIEN	\N	Bouchemaine	\N	\N	\N	2008	\N	MUNICIPAL	10006L	de	\N	\N	\N	\N	\N
6445	\N	\N	\N	ACTIF	\N	Arras	\N	\N	1995	\N	43500	MUNICIPAL	01034P	d'	\N	http://www.ville-arras.fr/	\N	\N	\N
12429	\N	\N	2014-08-26 00:00:00	ANCIEN	\N	Perpignan	\N	\N	1993	1995	\N	MUNICIPAL	11018G	de	\N	\N	\N	\N	2014-08-27 16:33:37
12431	\N	\N	2014-08-26 00:00:00	ANCIEN	\N	Millas	\N	\N	1995	2001	\N	MUNICIPAL	11018G	de	\N	\N	\N	\N	2014-08-27 16:33:37
12461	2008-03-01 00:00:00	\N	2013-01-01 00:00:00	ANCIEN	\N	Tampon (La Réunion)	\N	\N	2008	2013	\N	MUNICIPAL	11022C	du	\N	\N	\N	\N	\N
12451	\N	\N	\N	ACTIF	\N	Saint-Pierre (La Réunion)	\N	\N	2001	\N	\N	MUNICIPAL	11020A	de	\N	\N	\N	\N	\N
12458	1989-03-19 00:00:00	\N	\N	ACTIF	\N	Sainte-Rose (La Réunion)	\N	\N	\N	\N	\N	MUNICIPAL	11025F	de	\N	\N	\N	\N	2016-04-01 11:07:05
12466	2008-03-23 00:00:00	\N	\N	ACTIF	\N	Saint-Pierre (Miquelon)	\N	\N	\N	\N	\N	MUNICIPAL	11023D	de	\N	\N	\N	\N	\N
12489	1995-06-18 00:00:00	\N	\N	ACTIF	\N	Domène	\N	\N	\N	\N	\N	MUNICIPAL	11043H	de	\N	\N	\N	\N	2017-11-14 09:45:03
12512	\N	\N	\N	ACTIF	\N	Saint-Étienne	\N	\N	1995	\N	\N	MUNICIPAL	11057P	de	\N	\N	\N	\N	\N
12532	1995-03-01 00:00:00	\N	2020-03-03 00:00:00	ANCIEN	\N	Mende	\N	\N	\N	\N	0	MUNICIPAL	11081P	de	\N	http://www.mende.fr/	\N	\N	2017-09-20 13:44:07
12544	2008-03-16 00:00:00	\N	2014-03-31 00:00:00	ANCIEN	\N	Mamoudzou (Mayotte)	\N	\N	\N	\N	0	MUNICIPAL	11071M	de	\N	\N	\N	\N	2014-04-17 11:09:19
12546	\N	\N	2014-03-30 00:00:00	ANCIEN	\N	Conflans-Sainte-Honorine	\N	\N	1995	\N	0	MUNICIPAL	11096W	de	\N	\N	\N	\N	2014-10-01 11:28:30
12553	1995-06-25 00:00:00	\N	2014-03-30 00:00:00	ANCIEN	\N	Auray	\N	\N	\N	\N	0	MUNICIPAL	11098Y	d'	\N	\N	\N	\N	2014-10-01 11:27:51
12555	1995-06-25 00:00:00	\N	2014-03-30 00:00:00	ANCIEN	\N	Saint-Nolff	\N	\N	\N	\N	0	MUNICIPAL	11099A	de	\N	\N	\N	\N	2014-04-07 11:29:08
12585	2001-03-18 00:00:00	\N	2015-04-01 00:00:00	ANCIEN	\N	Pau	\N	\N	\N	\N	\N	MUNICIPAL	11110B	de	\N	\N	\N	\N	2017-05-23 10:35:43
12908	\N	\N	2014-04-01 00:00:00	ANCIEN	\N	Grasse	\N	\N	\N	\N	0	MUNICIPAL	13001T	de 	\N	\N	\N	\N	2014-04-23 12:04:02
12919	2001-01-01 00:00:00	\N	\N	ACTIF	\N	Meyenheim	\N	\N	2001	\N	\N	MUNICIPAL	13003V	de	\N	\N	\N	2013-07-01 09:38:47	\N
12922	\N	\N	\N	ACTIF	\N	Notre-Dame-des-Millières	\N	\N	1989	\N	\N	MUNICIPAL	12038D	de 	\N	\N	\N	2013-08-19 14:48:30	\N
12925	\N	\N	\N	ACTIF	\N	Rodez	\N	\N	2008	\N	\N	MUNICIPAL	12039E	de 	\N	\N	\N	2013-08-19 14:58:37	\N
12927	2013-01-01 00:00:00	\N	\N	ACTIF	\N	Thizy-les-Bourgs	\N	\N	2013	\N	\N	MUNICIPAL	95049N	de	\N	\N	\N	2013-08-26 10:59:08	\N
12930	2008-03-23 00:00:00	\N	\N	ACTIF	\N	Eu	\N	\N	\N	\N	\N	MUNICIPAL	13005X	d'	\N	\N	\N	2013-10-01 15:33:06	\N
6008	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Mâcon	\N	\N	2001	\N	37275	MUNICIPAL	95020Y	de	\N	http://www.macon.fr/	\N	\N	\N
5897	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Saint-Claude	\N	\N	1977	2001	\N	MUNICIPAL	01002F	de	\N	http://www.saint-claude.fr	\N	\N	\N
6010	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Lanne-en-Baretous	\N	\N	2001	\N	513	MUNICIPAL	92006N	de	\N	\N	\N	\N	\N
6011	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Creutzwald	\N	\N	2001	\N	15169	MUNICIPAL	74013K	de	\N	\N	\N	\N	\N
6014	2001-03-11 00:00:00	\N	2020-02-21 00:00:00	ANCIEN	\N	Puy-Guillaume	\N	\N	2001	\N	2634	MUNICIPAL	81015E	de	\N	http://www.puy-guillaume.com	\N	\N	\N
6018	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Vroncourt	\N	\N	2001	\N	138	MUNICIPAL	83036T	de	\N	\N	\N	\N	\N
6019	2001-03-11 00:00:00	\N	2019-09-16 00:00:00	ANCIEN	\N	Sapois	\N	\N	2001	\N	310	MUNICIPAL	89004L	de	\N	\N	\N	\N	\N
6020	2001-03-11 00:00:00	\N	2008-03-21 00:00:00	ANCIEN	\N	Mont-de-Marsan	\N	\N	2001	\N	28328	MUNICIPAL	83039W	de	\N	\N	\N	\N	\N
6021	2001-03-11 00:00:00	\N	2004-10-25 00:00:00	ANCIEN	\N	Alençon	\N	\N	2001	2004	29988	MUNICIPAL	92029V	d'	\N	http://www.ville-alencon.fr/	\N	\N	\N
6022	2001-03-11 00:00:00	\N	2008-11-12 00:00:00	ANCIEN	\N	Chateauneuf-les-Martigues	\N	\N	2001	2008	10911	MUNICIPAL	98020M	de	\N	\N	\N	\N	\N
6023	1977-03-20 00:00:00	\N	\N	ACTIF	\N	Jonzac	\N	\N	1977	\N	3998	MUNICIPAL	89013M	de	\N	http://www.mairie-jonzac.fr/	\N	\N	\N
6026	2001-03-11 00:00:00	\N	2008-03-16 00:00:00	ANCIEN	\N	Ydes	\N	\N	2001	2008	1965	MUNICIPAL	89010J	d'	\N	\N	\N	\N	\N
6027	2001-03-11 00:00:00	\N	2008-03-21 00:00:00	ANCIEN	\N	Bernay	\N	\N	2001	2008	10582	MUNICIPAL	89022N	de	\N	http://www.ville-bernay27.fr	\N	\N	\N
6028	2001-03-11 00:00:00	\N	2022-10-18 00:00:00	ANCIEN	\N	Buléon	\N	\N	2001	\N	492	MUNICIPAL	81011A	de	\N	\N	\N	\N	\N
6032	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Cambrai	\N	\N	\N	\N	33092	MUNICIPAL	92031P	de	\N	http://www.villedecambrai.com/	\N	\N	2014-04-07 11:33:04
6037	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Compiègne	\N	\N	2001	\N	41896	MUNICIPAL	92035T	de	\N	http://www.compiegne.fr/	\N	\N	\N
693	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Château-Chinon	\N	\N	\N	2001	2502	MUNICIPAL	86053H	de 	\N	\N	\N	\N	\N
6040	2001-03-11 00:00:00	\N	2014-06-08 00:00:00	ANCIEN	\N	Francescas	\N	\N	2001	2014	625	MUNICIPAL	81001X	de	\N	\N	\N	\N	\N
6042	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Langeac	\N	\N	2001	\N	4195	MUNICIPAL	98026T	de	\N	\N	\N	\N	\N
6043	2001-03-11 00:00:00	\N	2004-10-04 00:00:00	ANCIEN	\N	Montigny-le-Bretonneux	\N	Fin de mandat de maire annoncée au BQ du 5/10/2004	2001	2004	31687	MUNICIPAL	95004Y	de	\N	\N	\N	\N	\N
6044	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Ecouen	\N	\N	2001	\N	4846	MUNICIPAL	97009N	d'	\N	http://www.ecouen.fr/	\N	\N	\N
6046	2001-03-11 00:00:00	\N	2008-03-17 00:00:00	ANCIEN	\N	Moncoutant	\N	\N	2001	2008	3102	MUNICIPAL	95009E	de	\N	\N	\N	\N	\N
6047	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Les Grandes-Ventes	\N	\N	2001	\N	1729	MUNICIPAL	95014B	de	\N	\N	\N	\N	\N
6049	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Buchelay	\N	\N	2001	\N	2066	MUNICIPAL	95013A	de	\N	\N	\N	\N	\N
6050	2001-03-11 00:00:00	\N	2008-03-17 00:00:00	ANCIEN	\N	Bouray-sur-Juine	\N	\N	2001	2008	1706	MUNICIPAL	00003C	de	\N	\N	\N	\N	\N
6051	2001-03-11 00:00:00	\N	2019-07-18 00:00:00	ANCIEN	\N	Puteaux	\N	\N	2001	\N	42756	MUNICIPAL	95016D	de	\N	http://www.mairie-puteaux.fr/	\N	\N	\N
6053	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Mouilleron-le-Captif	\N	\N	2001	\N	3238	MUNICIPAL	95021A	de	\N	http://www.mairie-mouilleronlecaptif.fr/	\N	\N	2014-04-09 10:49:54
6054	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Neuilly-Plaisance	\N	\N	2001	\N	18195	MUNICIPAL	95024D	de	\N	http://www.mairie-neuillyplaisance.com/	\N	\N	\N
6056	2001-03-11 00:00:00	\N	2008-03-16 00:00:00	ANCIEN	\N	Ménigoute	\N	\N	2001	2008	895	MUNICIPAL	95028H	de	\N	\N	\N	\N	\N
6057	2001-03-11 00:00:00	\N	2023-10-28 00:00:00	ANCIEN	\N	Illzach	\N	\N	2001	\N	15485	MUNICIPAL	95029J	de	\N	http://www.ville-illzach.fr	\N	\N	\N
6058	2001-03-11 00:00:00	\N	2008-03-16 00:00:00	ANCIEN	\N	Sennecey-le-Grand	\N	\N	2001	2008	2568	MUNICIPAL	95030B	de	\N	\N	\N	\N	\N
6060	2001-03-11 00:00:00	\N	2019-03-30 00:00:00	ANCIEN	\N	Coulombs-en-Valois	\N	\N	2001	\N	482	MUNICIPAL	83003J	de	\N	\N	\N	\N	\N
6062	2001-03-11 00:00:00	\N	2013-01-30 00:00:00	ANCIEN	\N	Le Pecq	\N	\N	2001	\N	17006	MUNICIPAL	95035G	de	\N	http://www.ville-lepecq.fr/	\N	\N	\N
6067	2001-03-11 00:00:00	\N	2008-03-10 00:00:00	ANCIEN	\N	Sevrier	\N	\N	2001	2008	2980	MUNICIPAL	95038K	de	\N	\N	\N	\N	\N
6068	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Handschuheim	\N	\N	2001	\N	232	MUNICIPAL	77029G	de	\N	\N	\N	\N	\N
6069	2001-03-11 00:00:00	\N	\N	ACTIF	\N	La Madeleine-sur-Loing	\N	\N	2001	\N	287	MUNICIPAL	95039L	de	\N	\N	\N	\N	\N
6071	2001-03-11 00:00:00	\N	2014-03-24 00:00:00	ANCIEN	\N	Vesoul	\N	\N	\N	\N	17614	MUNICIPAL	95041E	de	\N	\N	\N	\N	2014-09-18 10:55:15
6072	2001-03-11 00:00:00	\N	2014-03-30 00:00:00	ANCIEN	\N	Rambouillet	\N	\N	\N	\N	24343	MUNICIPAL	86034E	de	\N	http://www.rambouillet.fr	\N	\N	2014-04-07 11:30:22
6074	2001-03-11 00:00:00	\N	2020-12-21 00:00:00	ANCIEN	\N	Les Ulis	\N	\N	2001	\N	27164	MUNICIPAL	86037H	de	\N	http://www.ville-les-ulis.fr	\N	\N	\N
6076	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Le Luart	\N	\N	2001	\N	952	MUNICIPAL	77043E	de	\N	\N	\N	\N	\N
6077	2001-03-11 00:00:00	\N	2022-08-20 00:00:00	ANCIEN	\N	Neuilly-sur-Marne	\N	\N	2001	\N	31461	MUNICIPAL	95046K	de	\N	http://www.mairiedeneuillysurmarne.com/	\N	\N	\N
763	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Hallencourt	\N	\N	\N	2001	1374	MUNICIPAL	95047L	d'	\N	\N	\N	\N	\N
6078	2001-03-11 00:00:00	\N	2014-03-23 00:00:00	ANCIEN	\N	Hallencourt	\N	\N	\N	\N	1374	MUNICIPAL	95047L	d'	\N	\N	\N	\N	2014-04-07 10:19:45
6080	2001-03-11 00:00:00	\N	2008-03-21 00:00:00	ANCIEN	\N	Basse-Terre	\N	\N	2001	2008	13796	MUNICIPAL	95050F	de	\N	\N	\N	\N	\N
6081	2001-03-11 00:00:00	\N	2017-10-26 00:00:00	ANCIEN	\N	Garges-lès-Gonesse	\N	\N	2001	2017	42144	MUNICIPAL	95051G	de	\N	http://www.garges.net	\N	\N	\N
6082	2001-03-11 00:00:00	\N	2023-10-21 00:00:00	ANCIEN	\N	Wasselonne	\N	\N	2001	\N	4916	MUNICIPAL	91002E	de	\N	\N	\N	\N	\N
11904	\N	\N	\N	ANCIEN	\N	Saint-Germain-en-Laye	\N	\N	1983	1989	\N	MUNICIPAL	95035G	de	\N	\N	\N	\N	\N
6360	1993-06-13 00:00:00	\N	\N	ACTIF	\N	Perpignan	\N	\N	1993	\N	107000	MUNICIPAL	01006K	de	\N	http://www.mairie-perpignan.fr/	\N	\N	\N
6512	\N	\N	\N	ANCIEN	\N	Carquefou	\N	\N	1989	2003	\N	MUNICIPAL	01055U	de	\N	http://www.mairie-carquefou.fr/	\N	\N	\N
6549	\N	\N	\N	ANCIEN	\N	Vienne	\N	\N	1971	2001	\N	MUNICIPAL	01020H	de	\N	http://www.vienne.fr/	\N	\N	\N
6587	\N	\N	\N	ANCIEN	\N	Hayange	\N	\N	1995	1997	\N	MUNICIPAL	83042R	d'	\N	http://www.ville-hayange.fr/	\N	\N	\N
11334	2008-03-16 00:00:00	\N	2022-05-07 00:00:00	ANCIEN	\N	Beaumont du Perigord	\N	\N	\N	\N	\N	MUNICIPAL	02005N	de	\N	\N	\N	\N	\N
11512	\N	\N	1995-06-18 00:00:00	ANCIEN	\N	Masbaraud-Mérignat	\N	\N	1986	1995	\N	MUNICIPAL	08012N	de	\N	\N	\N	\N	\N
11513	1995-06-18 00:00:00	\N	\N	ANCIEN	\N	Bourganeuf	\N	\N	1995	2009	\N	MUNICIPAL	08012N	de	\N	\N	\N	\N	\N
11528	\N	\N	2019-01-13 00:00:00	ANCIEN	\N	Pons	\N	\N	1977	\N	0	MUNICIPAL	08015R	de	\N	http://www.pons-ville.fr/	\N	\N	2014-04-07 11:31:53
11599	\N	\N	2020-05-11 00:00:00	ANCIEN	\N	Allauch	\N	\N	1977	\N	\N	MUNICIPAL	08029X	d'	\N	http://www.allauch.com/	\N	\N	\N
11616	\N	\N	\N	ACTIF	\N	Marseille (15ème et 16ème arrondissements)	\N	\N	2008	\N	\N	MUNICIPAL	08035V	de	\N	\N	\N	\N	2018-01-23 18:55:58
11646	\N	\N	\N	ACTIF	\N	Berre-l'Etang	\N	\N	1983	\N	\N	MUNICIPAL	08040S	de	\N	http://www.berre-l-etang.fr/mairie/	\N	\N	\N
11669	2008-03-16 00:00:00	\N	\N	ACTIF	\N	Aix-en-Provence	\N	\N	\N	\N	\N	MUNICIPAL	08044W	d'	\N	\N	\N	\N	2017-11-30 16:53:16
11676	1995-06-18 00:00:00	1995-06-18 00:00:00	2017-09-29 00:00:00	ANCIEN	\N	Marseille (4ème et 5ème arrondissements)	\N	\N	\N	\N	\N	MUNICIPAL	08048B	de	\N	http://www.marseille4-5.com/	\N	\N	2017-11-28 16:13:50
11707	\N	\N	\N	ANCIEN	\N	Bourg-en-Bresse	\N	\N	1977	2002	\N	MUNICIPAL	08053X	de	\N	\N	\N	\N	\N
11712	1995-06-18 00:00:00	\N	\N	ACTIF	\N	Cerdon	\N	\N	\N	\N	999	MUNICIPAL	08056B	de	\N	\N	\N	\N	2017-11-10 10:29:59
11720	1995-06-18 00:00:00	\N	\N	ACTIF	\N	Miribel	\N	\N	\N	\N	0	MUNICIPAL	08059E	de	\N	http://www.miribel.fr/	\N	\N	2014-04-07 14:45:33
11920	\N	\N	\N	ANCIEN	\N	Nancy	\N	\N	1983	1989	\N	MUNICIPAL	92040Q	de	\N	http://www.mairie-nancy.fr/	\N	\N	\N
11924	\N	\N	\N	ANCIEN	\N	Poitiers	\N	\N	1989	1995	\N	MUNICIPAL	95059Q	de	\N	http://www.mairie-poitiers.fr/	\N	\N	\N
11927	\N	\N	2022-05-29 00:00:00	ANCIEN	\N	Villeneuve-d'Asq	\N	\N	1977	1983	\N	MUNICIPAL	85002R	de	\N	\N	\N	\N	\N
6665	\N	\N	\N	ANCIEN	\N	Valenciennes	\N	\N	1995	2001	\N	MUNICIPAL	02001J	de	\N	http://www.ville-valenciennes.fr/	\N	\N	\N
6752	\N	\N	2002-06-07 00:00:00	ANCIEN	\N	Chauvigny	\N	\N	1983	\N	\N	MUNICIPAL	02002K	de	\N	http://www.chauvigny.cg86.fr/	\N	\N	\N
10071	\N	\N	2013-06-10 00:00:00	ANCIEN	\N	Dunkerque	\N	\N	\N	2013	70331	MUNICIPAL	79002D	\N	\N	http://www.ville-dunkerque.fr/	\N	\N	\N
11194	1965-04-01 00:00:00	\N	\N	ACTIF	\N	Saint-Chinian	\N	\N	\N	\N	0	MUNICIPAL	06004E	de	\N	http://saintchinian.fr/	\N	\N	2014-04-17 11:38:11
11265	\N	\N	\N	ACTIF	\N	Wattwiller	\N	\N	2001	\N	\N	MUNICIPAL	07027R	de	\N	http://www.annuaire-mairie.fr/mairie-wattwiller.html	\N	\N	\N
11267	\N	\N	\N	ACTIF	\N	Méteren	\N	\N	2001	\N	\N	MUNICIPAL	07028S	de	\N	\N	\N	\N	2017-06-07 15:56:49
11307	1995-06-18 00:00:00	\N	2014-03-31 00:00:00	ANCIEN	\N	Mehun-sur-Yèvre	\N	\N	\N	\N	0	MUNICIPAL	07034Q	de	\N	\N	\N	\N	2014-04-08 16:43:39
11492	\N	\N	\N	ACTIF	\N	Laon	\N	\N	2001	\N	\N	MUNICIPAL	08010L	de	\N	http://www.ville-laon.fr/	\N	\N	\N
11793	1996-03-16 00:00:00	\N	\N	ACTIF	\N	Kourou	\N	\N	\N	\N	0	MUNICIPAL	08072B	de	\N	http://www.ville-kourou.fr/	\N	\N	2014-04-07 10:13:48
11796	\N	\N	2020-01-01 00:00:00	ANCIEN	\N	Mana	\N	\N	1995	\N	\N	MUNICIPAL	08073C	de	\N	http://www.annuaire-mairie.fr/ville-mana.html	\N	\N	2018-01-23 19:17:39
11848	\N	\N	\N	ANCIEN	\N	Saint-Martin	\N	\N	1977	2002	\N	MUNICIPAL	08023R	de	\N	\N	\N	\N	\N
677	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Saumur	\N	\N	\N	2001	30131	MUNICIPAL	92026S	de 	\N	http://www.ville-saumur.fr/	\N	\N	\N
685	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Carnac	\N	\N	\N	2001	4243	MUNICIPAL	83016P	de 	\N	http://www.carnac.fr	\N	\N	\N
705	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Alençon	\N	\N	\N	2001	29988	MUNICIPAL	92029V	d'	\N	http://www.ville-alencon.fr/	\N	\N	\N
728	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Illzach	\N	\N	\N	2001	15485	MUNICIPAL	95029J	de 	\N	http://www.ville-illzach.fr	\N	\N	\N
747	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Dieppe	\N	\N	\N	2001	35894	MUNICIPAL	95066P	de 	\N	http://www.mairie-dieppe.fr/	\N	\N	\N
771	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Orly	\N	\N	\N	2001	21646	MUNICIPAL	97005J	d'	\N	http://www.ville-orly.fr/	\N	\N	\N
5081	1990-07-14 00:00:00	\N	2001-03-11 00:00:00	ANCIEN	\N	Soulac-sur-Mer	\N	\N	\N	2001	3946	MUNICIPAL	98021N	de 	\N	http://www.mairie-soulac.fr	\N	\N	\N
5171	1989-03-17 00:00:00	\N	2001-03-11 00:00:00	ANCIEN	\N	La Guerche-de-Bretagne	\N	\N	\N	2001	4123	MUNICIPAL	98043U	de 	\N	www.paysdevitre.org/site/infos/commune/fiche_commune.php3?Commune=30	\N	\N	\N
600	\N	\N	\N	ACTIF	\N	Marseille	\N	\N	\N	\N	800550	MUNICIPAL	89039X	de 	\N	http://www.mairie-marseille.fr/	\N	\N	\N
630	\N	\N	\N	ANCIEN	\N	Massy	\N	\N	1983	2001	38574	MUNICIPAL	86039K	de 	\N	http://www.ville-massy.fr/fo/massy.php	\N	\N	\N
644	\N	\N	\N	ACTIF	\N	Bruges	\N	\N	\N	\N	8753	MUNICIPAL	93006S	de 	\N	http://www.mairie-bruges.fr/	\N	\N	\N
6197	2001-03-18 00:00:00	\N	2008-03-16 00:00:00	ANCIEN	\N	Paris	\N	\N	2001	2008	2152423	MUNICIPAL	95011X	de	\N	http://www.paris.fr	\N	\N	\N
6205	2001-03-18 00:00:00	\N	2023-11-25 00:00:00	ANCIEN	\N	Lyon	\N	\N	\N	\N	415487	MUNICIPAL	99002P	de	\N	http://www.mairie-lyon.fr/	\N	\N	\N
6215	2001-03-18 00:00:00	\N	2008-03-21 00:00:00	ANCIEN	\N	Lille	\N	\N	2001	2008	172242	MUNICIPAL	92037V	de	\N	http://www.mairie-lille.fr/	\N	\N	\N
6220	2001-03-18 00:00:00	\N	2008-03-21 00:00:00	ANCIEN	\N	Aubervilliers	\N	\N	2001	2008	67557	MUNICIPAL	95060H	d'	\N	http://www.mairie-aubervilliers.fr/	\N	\N	\N
6241	2001-03-18 00:00:00	\N	2009-12-18 00:00:00	ANCIEN	\N	Valognes	\N	\N	2001	2009	\N	MUNICIPAL	92025R	de	\N	http://www.mairie-valognes.fr/	\N	\N	\N
10198	\N	\N	\N	ACTIF	\N	Clichy	\N	\N	\N	\N	\N	MUNICIPAL	58662V	\N	\N	http://www.ville-clichy.fr/	\N	\N	\N
10199	\N	\N	2003-12-06 00:00:00	ANCIEN	\N	<commune indéterminée>	\N	\N	\N	2003	\N	MUNICIPAL	58352J	\N	\N	\N	\N	\N	\N
10201	\N	\N	2006-02-22 00:00:00	ANCIEN	\N	Aignan	\N	\N	\N	2006	\N	MUNICIPAL	58933A	\N	\N	http://perso.wanadoo.fr/aignan	\N	\N	\N
10202	\N	\N	\N	ACTIF	\N	Fontainebleau	\N	\N	\N	\N	18755	MUNICIPAL	000440	\N	\N	\N	\N	\N	\N
10203	\N	\N	\N	ACTIF	\N	Draguignan	\N	\N	\N	\N	\N	MUNICIPAL	000279	\N	\N	http://www.ville-draguignan.fr/	\N	\N	\N
10204	\N	\N	1994-02-23 00:00:00	ANCIEN	\N	Chatillon-sur-Seine	\N	\N	\N	1994	\N	MUNICIPAL	000452	\N	\N	\N	\N	\N	\N
10206	\N	\N	\N	ACTIF	\N	<commune indéterminée>	\N	\N	\N	\N	\N	MUNICIPAL	000330	\N	\N	\N	\N	\N	\N
10207	\N	\N	2009-09-27 00:00:00	ANCIEN	\N	Paris	\N	\N	\N	2009	2	MUNICIPAL	59560U	\N	\N	http://www.paris.fr	\N	\N	\N
10208	\N	\N	\N	ACTIF	\N	Fabas	\N	\N	\N	\N	\N	MUNICIPAL	000592	\N	\N	\N	\N	\N	\N
10209	\N	\N	2019-07-03 00:00:00	ANCIEN	\N	Saint-Laurent du Maroni	\N	\N	\N	\N	\N	MUNICIPAL	58950B	\N	\N	\N	\N	\N	\N
10210	\N	\N	\N	ACTIF	\N	Jouy-en-Josas	\N	\N	\N	\N	\N	MUNICIPAL	000595	\N	\N	http://www.jouy-en-josas.fr	\N	\N	\N
10211	\N	\N	2013-09-03 00:00:00	ANCIEN	\N	Dumbea	\N	\N	\N	2013	\N	MUNICIPAL	59250H	\N	\N	\N	\N	\N	\N
10212	\N	\N	2009-08-09 00:00:00	ANCIEN	\N	Givors	\N	\N	\N	2009	\N	MUNICIPAL	55510R	\N	\N	http://www.ville-givors.fr/	\N	\N	\N
10214	\N	\N	2018-08-13 00:00:00	ANCIEN	\N	Palaiseau	\N	\N	\N	\N	28395	MUNICIPAL	59562W	\N	\N	http://www.ville-palaiseau.fr/	\N	\N	\N
10215	\N	\N	2008-06-28 00:00:00	ANCIEN	\N	L'Ile-Bouchard	\N	\N	\N	2008	1800	MUNICIPAL	59253L	\N	\N	\N	\N	\N	\N
10216	\N	\N	1998-07-07 00:00:00	ANCIEN	\N	Groix	\N	\N	\N	1998	\N	MUNICIPAL	58355M	\N	\N	\N	\N	\N	\N
10217	\N	\N	2005-09-27 00:00:00	ANCIEN	\N	Colmar	\N	\N	\N	2005	\N	MUNICIPAL	58655W	\N	\N	http://www.ville-colmar.fr/	\N	\N	\N
10538	\N	\N	2008-03-18 00:00:00	ANCIEN	\N	Sixt-sur-Aff	\N	\N	\N	2008	1908	MUNICIPAL	03002P	de	\N	\N	\N	\N	\N
6297	2001-03-18 00:00:00	\N	\N	ANCIEN	\N	Auxerre	\N	\N	2001	2004	38819	MUNICIPAL	95033E	d'	\N	http://www.auxerre.com	\N	\N	\N
6273	2001-03-18 00:00:00	\N	2003-01-01 00:00:00	ANCIEN	\N	Lille	\N	\N	2001	2003	\N	MUNICIPAL	92044U	de	\N	http://www.mairie-lille.fr/	\N	\N	\N
10119	\N	\N	2009-05-18 00:00:00	ANCIEN	\N	Dennebroeucq	\N	\N	\N	2009	269	MUNICIPAL	59229L	\N	\N	\N	\N	\N	\N
10120	\N	\N	\N	ACTIF	\N	Bourg-lès-Valence	\N	\N	\N	\N	18230	MUNICIPAL	80020W	\N	\N	\N	\N	\N	\N
10121	\N	\N	\N	ACTIF	\N	Rouen	\N	\N	\N	\N	102723	MUNICIPAL	59535T	\N	\N	http://www.mairie-rouen.fr/	\N	\N	\N
10122	\N	\N	2009-06-01 00:00:00	ANCIEN	\N	Ampuis	\N	\N	\N	2009	\N	MUNICIPAL	58656X	\N	\N	\N	\N	\N	\N
10123	\N	\N	2011-10-27 00:00:00	ANCIEN	\N	Le Perreux	\N	\N	\N	2011	\N	MUNICIPAL	000599	\N	\N	\N	\N	\N	\N
10124	\N	\N	2020-02-04 00:00:00	ANCIEN	\N	Caestre	\N	\N	\N	\N	1340	MUNICIPAL	59230D	\N	\N	\N	\N	\N	\N
10125	\N	\N	2021-07-15 00:00:00	ANCIEN	\N	Dax	\N	\N	\N	\N	19640	MUNICIPAL	59231E	\N	\N	\N	\N	\N	\N
10126	\N	\N	\N	ACTIF	\N	Poitiers	\N	\N	\N	\N	\N	MUNICIPAL	58816V	\N	\N	http://www.mairie-poitiers.fr/	\N	\N	\N
10128	\N	\N	\N	ACTIF	\N	Cateau-Cambrésis	\N	\N	\N	\N	8311	MUNICIPAL	59232F	\N	\N	\N	\N	\N	\N
10129	\N	\N	\N	ACTIF	\N	Meulan	\N	\N	\N	\N	\N	MUNICIPAL	000551	\N	\N	\N	\N	\N	\N
10130	\N	\N	2016-03-03 00:00:00	ANCIEN	\N	Périgueux	\N	\N	\N	2016	30280	MUNICIPAL	89032Q	\N	\N	http://www.ville-perigueux.fr/	\N	\N	\N
10131	\N	\N	2007-10-25 00:00:00	ANCIEN	\N	Bosc-Roger-en-Roumois	\N	\N	\N	2007	2300	MUNICIPAL	58949J	\N	\N	\N	\N	\N	\N
10132	\N	\N	2004-04-07 00:00:00	ANCIEN	\N	La Charité-sur-Loire	\N	\N	\N	2004	6420	MUNICIPAL	59233G	\N	\N	\N	\N	\N	\N
10133	\N	\N	\N	ACTIF	\N	Ittenheim	\N	\N	\N	\N	1594	MUNICIPAL	58115W	\N	\N	\N	\N	\N	\N
10134	\N	\N	1983-12-27 00:00:00	ANCIEN	\N	Boulogne-sur-Mer	\N	\N	\N	1983	48350	MUNICIPAL	000185	\N	\N	\N	\N	\N	\N
10135	\N	\N	2021-03-19 00:00:00	ANCIEN	\N	Trappes	\N	\N	\N	\N	\N	MUNICIPAL	58644T	\N	\N	http://www.ville-trappes.fr	\N	\N	\N
12915	\N	\N	2014-03-30 00:00:00	ANCIEN	\N	Guînes	\N	\N	1995	\N	0	MUNICIPAL	13002U	de	\N	\N	\N	\N	2014-07-16 16:39:25
10136	\N	\N	1999-07-22 00:00:00	ANCIEN	\N	Saint-Julien-le-Montagne	\N	\N	\N	1999	\N	MUNICIPAL	000630	\N	\N	\N	\N	\N	\N
10137	\N	\N	2003-07-04 00:00:00	ANCIEN	\N	Crolles	\N	\N	\N	2003	\N	MUNICIPAL	58348N	\N	\N	http://www.ville-crolles.fr/	\N	\N	\N
10138	\N	\N	2000-04-21 00:00:00	ANCIEN	\N	Montceau-les-Mines	\N	\N	\N	2000	22999	MUNICIPAL	59539X	\N	\N	\N	\N	\N	\N
10139	\N	\N	2006-04-25 00:00:00	ANCIEN	\N	Lagnieu	\N	\N	\N	2006	5595	MUNICIPAL	58913V	\N	\N	\N	\N	\N	\N
10140	\N	\N	\N	ACTIF	\N	Marigny-le-Châtel	\N	\N	\N	\N	\N	MUNICIPAL	000456	\N	\N	\N	\N	\N	\N
10141	\N	\N	2002-03-07 00:00:00	ANCIEN	\N	Montbazens	\N	\N	\N	2002	\N	MUNICIPAL	58948H	\N	\N	\N	\N	\N	\N
10142	\N	\N	2012-04-27 00:00:00	ANCIEN	\N	Aups	\N	\N	\N	2012	\N	MUNICIPAL	58626R	\N	\N	\N	\N	\N	\N
10143	\N	\N	2004-08-19 00:00:00	ANCIEN	\N	Minihy-Tréguier	\N	\N	\N	2004	790	MUNICIPAL	58924Y	\N	\N	\N	\N	\N	\N
10144	\N	\N	\N	ACTIF	\N	Rouen	\N	\N	\N	\N	105085	MUNICIPAL	000442	\N	\N	http://www.mairie-rouen.fr/	\N	\N	\N
10145	\N	\N	\N	ACTIF	\N	Bouzeron	\N	\N	\N	\N	\N	MUNICIPAL	000248	\N	\N	\N	\N	\N	\N
10146	\N	\N	\N	ACTIF	\N	Saint-Ouen	\N	\N	\N	\N	\N	MUNICIPAL	000280	\N	\N	http://www.ville-saintouen.fr	\N	\N	\N
10147	\N	\N	\N	ACTIF	\N	Saint-Thierry	\N	\N	\N	\N	\N	MUNICIPAL	000144	\N	\N	\N	\N	\N	\N
10148	\N	\N	\N	ACTIF	\N	Callac	\N	\N	\N	\N	2592	MUNICIPAL	89033R	\N	\N	\N	\N	\N	\N
10149	\N	\N	2023-04-26 00:00:00	ANCIEN	\N	Case-Pilote	\N	\N	\N	\N	3657	MUNICIPAL	59546W	\N	\N	\N	\N	\N	\N
10151	\N	\N	2007-09-17 00:00:00	ANCIEN	\N	Goyave	\N	\N	\N	2007	3656	MUNICIPAL	59547X	\N	\N	\N	\N	\N	\N
10152	\N	\N	2007-09-05 00:00:00	ANCIEN	\N	Massiac	\N	\N	\N	2007	\N	MUNICIPAL	58947G	\N	\N	\N	\N	\N	\N
10153	\N	\N	\N	ACTIF	\N	Prades	\N	\N	\N	\N	\N	MUNICIPAL	000611	\N	\N	http://www.prades.com/	\N	\N	\N
10154	\N	\N	2017-12-01 00:00:00	ANCIEN	\N	La Courneuve	\N	\N	\N	2017	\N	MUNICIPAL	58633Q	\N	\N	http://www.ville-la-courneuve.fr/	\N	\N	\N
10156	\N	\N	2008-06-08 00:00:00	ANCIEN	\N	Briey	\N	\N	\N	2008	\N	MUNICIPAL	59235J	\N	\N	http://www.ville-briey.fr/	\N	\N	\N
10157	\N	\N	1997-11-17 00:00:00	ANCIEN	\N	Saint-Etienne	\N	\N	\N	1997	199396	MUNICIPAL	88011F	\N	\N	http://www.mairie-st-etienne.fr/	\N	\N	\N
10159	\N	\N	\N	ACTIF	\N	Calmont	\N	\N	\N	\N	\N	MUNICIPAL	000323	\N	\N	\N	\N	\N	\N
10160	\N	\N	2002-11-03 00:00:00	ANCIEN	\N	Antibes Juan-les-Pins	\N	\N	\N	2002	\N	MUNICIPAL	59717X	\N	\N	\N	\N	\N	\N
10161	\N	\N	\N	ACTIF	\N	Freyming-Merlebach	\N	\N	\N	\N	15224	MUNICIPAL	92038W	\N	\N	http://www.freyming-merlebach.fr/site/index.php	\N	\N	\N
10162	\N	\N	2016-12-15 00:00:00	ANCIEN	\N	Colombes	\N	\N	\N	2016	\N	MUNICIPAL	58635S	\N	\N	http://www.mairie-colombes.fr/	\N	\N	\N
10164	\N	\N	2018-08-04 00:00:00	ANCIEN	\N	Saint Rogatien	\N	\N	\N	\N	755	MUNICIPAL	58914W	\N	\N	http://www.mairie-saint-rogatien.fr/	\N	\N	\N
10165	\N	\N	2001-10-30 00:00:00	ANCIEN	\N	Noirétable	\N	\N	\N	2001	1200	MUNICIPAL	59236K	\N	\N	\N	\N	\N	\N
10166	\N	\N	\N	ACTIF	\N	Ermenouville	\N	\N	\N	\N	200	MUNICIPAL	000705	\N	\N	\N	\N	\N	\N
10167	\N	\N	\N	ACTIF	\N	Doullens	\N	\N	\N	\N	6615	MUNICIPAL	000586	\N	\N	http://www.mairie-doullens.fr/	\N	\N	\N
10168	\N	\N	2004-08-18 00:00:00	ANCIEN	\N	Saint-Germain-des-Grois	\N	\N	\N	2004	180	MUNICIPAL	59240F	\N	\N	\N	\N	\N	\N
10169	\N	\N	\N	ACTIF	\N	Sainte-Geneviève-des-Bois	\N	\N	\N	\N	\N	MUNICIPAL	58645U	\N	\N	\N	\N	\N	\N
10171	\N	\N	\N	ACTIF	\N	Paris	\N	\N	\N	\N	\N	MUNICIPAL	000488	\N	\N	http://www.paris.fr	\N	\N	\N
10172	\N	\N	\N	ACTIF	\N	<commune indéterminée>	\N	\N	\N	\N	\N	MUNICIPAL	000393	\N	\N	\N	\N	\N	\N
10173	\N	\N	2019-08-13 00:00:00	ANCIEN	\N	Vinantes	\N	\N	\N	\N	527	MUNICIPAL	59578F	\N	\N	\N	\N	\N	\N
10174	\N	\N	2003-07-03 00:00:00	ANCIEN	\N	Saint-Pierre	\N	\N	\N	2003	5580	MUNICIPAL	59579G	\N	\N	http://www.ville-saintpierre.fr/index.php	\N	\N	\N
10175	\N	\N	2004-06-21 00:00:00	ANCIEN	\N	Villiers-le-Bel	\N	\N	\N	2004	26110	MUNICIPAL	59580Y	\N	\N	\N	\N	\N	\N
10176	\N	\N	2007-10-08 00:00:00	ANCIEN	\N	Saint-Rémy-la-Vanne	\N	\N	\N	2007	702	MUNICIPAL	59554W	\N	\N	\N	\N	\N	\N
10177	\N	\N	\N	ACTIF	\N	Montelimar	\N	\N	\N	\N	\N	MUNICIPAL	000307	\N	\N	\N	\N	\N	\N
10179	\N	\N	2007-05-21 00:00:00	ANCIEN	\N	Luisant	\N	\N	\N	2007	5445	MUNICIPAL	58916Y	\N	\N	\N	\N	\N	\N
10180	\N	\N	2002-01-15 00:00:00	ANCIEN	\N	L'Isle-Adam	\N	\N	\N	2002	9979	MUNICIPAL	59556Y	\N	\N	\N	\N	\N	\N
10181	\N	\N	2000-12-27 00:00:00	ANCIEN	\N	Duisans	\N	\N	\N	2000	1230	MUNICIPAL	59242H	\N	\N	\N	\N	\N	\N
10182	\N	\N	2018-01-17 00:00:00	ANCIEN	\N	Dunkerque	\N	\N	\N	\N	\N	MUNICIPAL	59244K	\N	\N	http://www.ville-dunkerque.fr/	\N	\N	2018-02-01 13:23:37
10183	\N	\N	\N	ACTIF	\N	Levens	\N	\N	\N	\N	1800	MUNICIPAL	000104	\N	\N	http://www.villelevens.fr/	\N	\N	\N
10184	\N	\N	\N	ACTIF	\N	Saint-Ouen L'Aumône	\N	\N	1977	\N	18673	MUNICIPAL	95063L	de	\N	\N	\N	\N	2018-02-22 15:39:52
10185	\N	\N	2016-09-29 00:00:00	ANCIEN	\N	Mirambeau	\N	\N	\N	2016	1380	MUNICIPAL	58938F	\N	\N	\N	\N	\N	\N
10186	\N	\N	2011-10-24 00:00:00	ANCIEN	\N	Brux	\N	\N	\N	2011	693	MUNICIPAL	77003V	\N	\N	\N	\N	\N	\N
10187	\N	\N	2013-09-13 00:00:00	ANCIEN	\N	Cros-de-Montvert	\N	\N	\N	2013	\N	MUNICIPAL	58919C	\N	\N	\N	\N	\N	\N
10188	\N	\N	2016-07-02 00:00:00	ANCIEN	\N	Conflans-Sainte-Honorine	\N	\N	\N	2016	31467	MUNICIPAL	95064M	\N	\N	\N	\N	\N	\N
10189	\N	\N	2011-06-18 00:00:00	ANCIEN	\N	Saint-Sardos	\N	\N	\N	2011	563	MUNICIPAL	59558B	\N	\N	\N	\N	\N	\N
10190	\N	\N	2005-11-19 00:00:00	ANCIEN	\N	Vitry	\N	\N	\N	2005	\N	MUNICIPAL	58638V	\N	\N	http://www.mairie-vitry94.fr/	\N	\N	\N
10191	\N	\N	2002-03-04 00:00:00	ANCIEN	\N	Razac-sur-l'Isle	\N	\N	\N	2002	2060	MUNICIPAL	58929E	\N	\N	\N	\N	\N	\N
10192	\N	\N	1985-05-26 00:00:00	ANCIEN	\N	Marvejols	\N	\N	\N	1985	\N	MUNICIPAL	000443	\N	\N	http://www.ville-marvejols.fr/	\N	\N	\N
10194	\N	\N	\N	ACTIF	\N	Strasbourg	\N	\N	\N	\N	\N	MUNICIPAL	000505	\N	\N	http://www.mairie-strasbourg.fr/	\N	\N	\N
10195	\N	\N	\N	ACTIF	\N	<commune indéterminée>	\N	\N	\N	\N	\N	MUNICIPAL	000453	\N	\N	\N	\N	\N	\N
10196	\N	\N	\N	ACTIF	\N	Viarmes	\N	\N	\N	\N	\N	MUNICIPAL	000564	\N	\N	\N	\N	\N	\N
10197	\N	\N	2014-03-03 00:00:00	ANCIEN	\N	Paris	\N	\N	\N	2014	\N	MUNICIPAL	57752S	\N	\N	http://www.paris.fr	\N	\N	\N
6159	2001-03-11 00:00:00	\N	2008-03-21 00:00:00	ANCIEN	\N	Caussade	\N	\N	2001	\N	6009	MUNICIPAL	88008L	de	\N	\N	\N	\N	\N
762	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Beaucamps-le-Vieux	\N	\N	\N	2001	1404	MUNICIPAL	95025E	de 	\N	\N	\N	\N	\N
6160	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Le Marin	\N	\N	2001	\N	6429	MUNICIPAL	86021Y	de	\N	\N	\N	\N	\N
793	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Petit-Bourg	\N	\N	\N	2001	13084	MUNICIPAL	95043G	de 	\N	\N	\N	\N	\N
6162	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Gennevilliers	\N	\N	2001	\N	44818	MUNICIPAL	00002B	de	\N	http://www.ville-gennevilliers.fr/	\N	\N	\N
746	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Turretot	\N	\N	\N	2001	1178	MUNICIPAL	95062K	de 	\N	\N	\N	\N	\N
594	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Cuxac-Cabardès	\N	\N	\N	2001	724	MUNICIPAL	74050Q	de 	\N	\N	\N	\N	\N
6164	2001-03-11 00:00:00	\N	2008-03-17 00:00:00	ANCIEN	\N	Saint-Martin-le-Vieux	\N	\N	2001	2008	719	MUNICIPAL	90004C	de	\N	\N	\N	\N	\N
6165	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Créteil	\N	\N	2001	\N	82088	MUNICIPAL	97004H	de	\N	http://www.ville-creteil.fr/	\N	\N	\N
6166	2001-03-11 00:00:00	\N	2011-10-27 00:00:00	ANCIEN	\N	Almayrac	\N	\N	2001	2011	267	MUNICIPAL	98054X	d'	\N	\N	\N	\N	\N
6167	2001-03-11 00:00:00	\N	2008-03-21 00:00:00	ANCIEN	\N	Bouguenais	\N	\N	2001	2008	15099	MUNICIPAL	83012K	de	\N	http://www.ville-bouguenais.fr/	\N	\N	\N
6168	2001-03-11 00:00:00	\N	2014-03-31 00:00:00	ANCIEN	\N	Quillebeuf-sur-Seine	\N	\N	\N	\N	1044	MUNICIPAL	98050T	de	\N	\N	\N	\N	2014-04-09 17:05:22
6169	2001-03-11 00:00:00	\N	2021-11-30 00:00:00	ANCIEN	\N	Turretot	\N	\N	2001	\N	1178	MUNICIPAL	95062K	de	\N	\N	\N	\N	\N
6171	2001-03-11 00:00:00	\N	2006-08-11 00:00:00	ANCIEN	\N	Cuxac-Cabardès	\N	\N	2001	2006	724	MUNICIPAL	74050Q	de	\N	\N	\N	\N	\N
6174	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Saint-Nazaire	\N	\N	2001	\N	64812	MUNICIPAL	92019T	de	\N	http://www.mairie-saintnazaire.fr/	\N	\N	\N
6175	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Saint-Laurent de Neste	\N	\N	2001	\N	912	MUNICIPAL	92020L	de	\N	\N	\N	\N	\N
6176	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Serémange-Erzange	\N	\N	2001	\N	4143	MUNICIPAL	96007G	de	\N	\N	\N	\N	2014-04-09 17:16:55
6177	2001-03-11 00:00:00	\N	2020-05-14 00:00:00	ANCIEN	\N	Chevrières	\N	\N	2001	\N	1575	MUNICIPAL	83054V	de	\N	\N	\N	\N	\N
704	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Chevrières	\N	\N	\N	2001	1575	MUNICIPAL	83054V	de 	\N	\N	\N	\N	\N
10850	\N	\N	2023-10-08 00:00:00	ANCIEN	\N	Dammarie-les-Lys	\N	\N	1983	2001	\N	MUNICIPAL	04052E	de	\N	\N	\N	\N	\N
10863	\N	\N	\N	ACTIF	\N	Nangis	\N	\N	1992	\N	\N	MUNICIPAL	04054G	de	\N	http://www.ville-nangis.fr	\N	\N	\N
10866	\N	\N	2009-06-08 00:00:00	ANCIEN	\N	Corbeil-Essonnes	\N	\N	1995	2009	\N	MUNICIPAL	04055H	de	\N	http://www.corbeil-essonnes.com	\N	\N	\N
10874	\N	\N	2008-03-21 00:00:00	ANCIEN	\N	Versailles	\N	\N	1989	2008	\N	MUNICIPAL	04058L	de	\N	http://www.mairie-versailles.fr/	\N	\N	\N
10877	\N	\N	\N	ACTIF	\N	Alluets-le-Roi	\N	\N	1995	\N	\N	MUNICIPAL	04060E	d'	\N	\N	\N	\N	\N
10885	2001-03-25 00:00:00	\N	\N	ACTIF	\N	Strasbourg	\N	\N	2001	\N	\N	MUNICIPAL	04061F	de	\N	http://www.mairie-strasbourg.fr/	\N	\N	\N
10889	1995-06-11 00:00:00	\N	\N	ANCIEN	\N	Argenteuil	\N	\N	1995	2001	\N	MUNICIPAL	04063H	d'	\N	http://www.ville-argenteuil.fr/	\N	\N	\N
11068	\N	\N	\N	ANCIEN	\N	Saint-Priest	\N	\N	1989	2005	\N	MUNICIPAL	04046G	de	\N	\N	\N	\N	\N
10915	\N	\N	2010-04-01 00:00:00	ANCIEN	\N	Rouen	\N	\N	2001	2010	\N	MUNICIPAL	04070G	de	\N	http://www.mairie-rouen.fr/	\N	\N	\N
10917	\N	\N	2008-03-16 00:00:00	ANCIEN	\N	Paris (8ème arrondissement)	\N	\N	1983	2008	\N	MUNICIPAL	04071H	de	\N	\N	\N	\N	\N
10918	\N	\N	\N	ACTIF	\N	Herbsheim	\N	\N	\N	\N	0	MUNICIPAL	04069P	de	\N	\N	\N	\N	2014-04-16 18:03:10
10924	\N	\N	\N	ACTIF	\N	Paris (15ème arrondissement)	\N	\N	1983	\N	\N	MUNICIPAL	04072J	de	\N	\N	\N	\N	\N
10934	\N	\N	2008-03-16 00:00:00	ANCIEN	\N	Saint-Fargeau	\N	\N	1977	2008	\N	MUNICIPAL	04073K	de	\N	\N	\N	\N	\N
10937	\N	\N	\N	ANCIEN	\N	Villiers-le-Bel	\N	\N	1988	2004	\N	MUNICIPAL	04076N	de	\N	\N	\N	\N	\N
10938	1983-03-06 00:00:00	\N	2001-03-11 00:00:00	ANCIEN	\N	Paris	\N	\N	1983	2001	\N	MUNICIPAL	04075M	de	\N	http://www.paris.fr	\N	\N	\N
10964	\N	\N	\N	ACTIF	\N	Paris (7ème arrondissement)	\N	\N	1998	\N	\N	MUNICIPAL	04080J	de	\N	\N	\N	\N	\N
10971	\N	\N	\N	ANCIEN	\N	Vanves	\N	\N	1995	2015	0	MUNICIPAL	04081K	de	\N	http://www.vanves.fr/	\N	\N	2015-06-23 11:22:22
10979	\N	\N	\N	ACTIF	\N	Givrand	\N	\N	1977	\N	\N	MUNICIPAL	04083M	de	\N	\N	\N	\N	\N
10983	\N	\N	2021-01-24 00:00:00	ANCIEN	\N	Héricourt	\N	\N	1983	2004	\N	MUNICIPAL	04084N	d'	\N	http://www.hericourt.com/	\N	\N	\N
10986	\N	\N	\N	ACTIF	\N	Pavillons-sous-Bois	\N	\N	1995	\N	\N	MUNICIPAL	04086Q	des	\N	http://www.ville-pavillons-sous-bois.fr/	\N	\N	2017-12-04 16:54:01
10993	\N	\N	\N	ANCIEN	\N	Labruguière	\N	\N	1977	2004	\N	MUNICIPAL	04087R	de	\N	\N	\N	\N	\N
10995	\N	\N	2008-03-16 00:00:00	ANCIEN	\N	La Chapelle-aux-Bois	\N	\N	1983	2008	\N	MUNICIPAL	04088S	de	\N	\N	\N	\N	\N
11008	\N	\N	2004-12-23 00:00:00	ANCIEN	\N	Chambéry	\N	\N	1995	2004	\N	MUNICIPAL	04090L	de	\N	http://www.mairie-chambery.fr/	\N	\N	\N
11010	\N	\N	2008-03-21 00:00:00	ANCIEN	\N	Varennes-Saint-Sauveur	\N	\N	1970	2008	\N	MUNICIPAL	04091M	de	\N	\N	\N	\N	\N
11023	\N	\N	\N	ACTIF	\N	Miquelon-Langlade	\N	\N	2001	\N	\N	MUNICIPAL	04093P	de	\N	\N	\N	\N	\N
11027	\N	\N	2008-03-16 00:00:00	ANCIEN	\N	Diamant	\N	\N	1989	2008	\N	MUNICIPAL	04094Q	du	\N	\N	\N	\N	\N
11031	\N	\N	\N	ANCIEN	\N	Gosier	\N	\N	1989	2008	\N	MUNICIPAL	04095R	du	\N	\N	\N	\N	\N
11035	\N	\N	\N	ANCIEN	\N	Abymes	\N	\N	1995	2010	\N	MUNICIPAL	04096S	des	\N	\N	\N	\N	\N
11039	\N	\N	2021-02-02 00:00:00	ANCIEN	\N	Fontenay-sous-Bois	\N	\N	1977	\N	\N	MUNICIPAL	04039H	de	\N	http://www.fontenay-sous-bois.fr/	\N	\N	\N
11057	\N	\N	\N	ANCIEN	\N	Vincennes	\N	\N	1981	2004	\N	MUNICIPAL	04043D	de	\N	http://www.mairie-vincennes.fr/	\N	\N	\N
11077	\N	\N	\N	ANCIEN	\N	Dieppe	\N	\N	2001	2004	\N	MUNICIPAL	04068N	de	\N	http://www.mairie-dieppe.fr/	\N	\N	\N
11078	\N	\N	\N	ANCIEN	\N	Bois-Guillaume	\N	\N	1995	2000	0	MUNICIPAL	04070G	de	\N	\N	\N	\N	2014-04-29 18:20:05
11079	\N	\N	\N	ANCIEN	\N	Drancy	\N	\N	1983	1995	\N	MUNICIPAL	04085P	de	\N	http://www.drancy.net/index.php?id_rub=home	\N	\N	\N
11083	\N	\N	2008-03-16 00:00:00	ANCIEN	\N	Chiconi	\N	\N	2001	2008	\N	MUNICIPAL	04062G	de	\N	\N	\N	\N	\N
11097	\N	\N	\N	ACTIF	\N	Benassay	\N	\N	1983	\N	\N	MUNICIPAL	04098U	de	\N	\N	\N	\N	\N
11093	\N	\N	\N	ANCIEN	\N	Neuville-Lez-Beaulieu	\N	\N	1995	2004	\N	MUNICIPAL	04097T	de	\N	\N	\N	\N	\N
11101	\N	\N	1995-03-01 00:00:00	ANCIEN	\N	Mamers	\N	\N	1977	\N	0	MUNICIPAL	04099V	de	\N	http://www.mairie-mamers.fr/	\N	\N	2014-04-08 14:55:30
11106	\N	\N	\N	ACTIF	\N	Commerveil	\N	\N	1995	\N	0	MUNICIPAL	04099V	de	\N	\N	\N	\N	2014-04-08 14:55:43
11113	\N	\N	\N	ANCIEN	\N	Istres	\N	\N	1977	1998	\N	MUNICIPAL	04101V	d'	\N	http://www.istres.fr/	\N	\N	\N
11154	\N	\N	2014-03-31 00:00:00	ANCIEN	\N	Furiani	\N	\N	1995	\N	0	MUNICIPAL	05011Y	de	\N	http://www.furiani.corse.fr/	\N	\N	2014-04-17 12:08:36
11169	\N	\N	\N	ANCIEN	\N	Lazenay	\N	\N	1989	2004	\N	MUNICIPAL	05012A	de	\N	\N	\N	\N	\N
11178	\N	\N	\N	ACTIF	\N	Solesmes	\N	\N	2001	\N	\N	MUNICIPAL	02009S	de	\N	\N	\N	\N	\N
11189	2001-03-18 00:00:00	\N	\N	ACTIF	\N	Anglet	\N	\N	2001	\N	\N	MUNICIPAL	06001B	d'	\N	http://www.ville-anglet.fr/	\N	\N	\N
11212	\N	\N	2008-03-21 00:00:00	ANCIEN	\N	Pleslin-Trigavou	\N	\N	1977	2008	\N	MUNICIPAL	06006G	de	\N	\N	\N	\N	\N
11253	\N	\N	\N	ANCIEN	\N	Petit-Quevilly	\N	\N	1983	1989	\N	MUNICIPAL	07025P	du	\N	\N	\N	\N	\N
11256	\N	\N	2008-03-21 00:00:00	ANCIEN	\N	Saint-Saëns	\N	\N	1983	2008	\N	MUNICIPAL	07025P	de 	\N	\N	\N	\N	\N
11294	\N	\N	2016-11-17 00:00:00	ANCIEN	\N	Orsennes	\N	\N	1983	2004	\N	MUNICIPAL	07032N	de	\N	\N	\N	\N	2016-11-18 12:37:49
11321	2008-03-15 00:00:00	\N	2014-03-30 00:00:00	ANCIEN	\N	Sainte-Adresse	\N	\N	\N	\N	0	MUNICIPAL	95034F	de	\N	http://www.ville-sainte-adresse.fr/	\N	\N	2014-04-07 11:17:03
11333	2008-03-21 00:00:00	\N	\N	ACTIF	\N	Saint-Fons	\N	\N	\N	\N	0	MUNICIPAL	04046G	de	\N	http://www.saint-fons.fr/	\N	\N	2014-04-08 14:36:11
11465	\N	\N	\N	ANCIEN	\N	Valdoie	\N	\N	1977	2008	\N	MUNICIPAL	08008S	de	\N	\N	\N	\N	\N
11567	\N	\N	\N	ACTIF	\N	Gujan-Mestras	\N	\N	2006	\N	\N	MUNICIPAL	08022Q	de	\N	http://www.ville-gujanmestras.fr/	\N	\N	\N
11340	2008-03-21 00:00:00	\N	2014-03-30 00:00:00	ANCIEN	\N	Neuville-Lez-Beaulieu	\N	\N	\N	\N	0	MUNICIPAL	04097T	de	\N	\N	\N	\N	2014-04-07 11:23:22
11351	\N	\N	\N	ANCIEN	\N	Nouméa	\N	\N	2008	2008	\N	MUNICIPAL	92033R	de	\N	http://www.ville-noumea.nc	\N	\N	\N
11370	1971-03-21 00:00:00	\N	1996-06-14 00:00:00	ANCIEN	\N	Toulon	\N	\N	1971	1996	\N	MUNICIPAL	86049M	de 	\N	\N	\N	\N	\N
11545	\N	\N	\N	ANCIEN	\N	Saint-Barthélemy	\N	\N	\N	2007	\N	MUNICIPAL	08019V	de	\N	\N	\N	\N	\N
11572	1995-06-01 00:00:00	\N	2014-04-01 00:00:00	ANCIEN	\N	Artigues-près-Bordeaux	\N	\N	\N	\N	0	MUNICIPAL	08024S	d'	\N	http://www.artigues-pres-bordeaux.fr/	\N	\N	2014-04-08 12:04:31
11579	\N	\N	\N	ACTIF	\N	Mérignac	\N	\N	2001	\N	0	MUNICIPAL	08025T	de	\N	http://www.merignac.com/	\N	\N	2014-04-07 10:19:06
11608	\N	\N	2008-09-26 00:00:00	ANCIEN	\N	Toulouse	\N	\N	1989	2008	\N	MUNICIPAL	08033T	de	\N	http://www.mairie-toulouse.fr/	\N	\N	\N
11634	1983-03-01 00:00:00	\N	2014-03-31 00:00:00	ANCIEN	\N	Grasse	\N	\N	\N	\N	0	MUNICIPAL	08039A	de	\N	http://www.ville-grasse.fr/	\N	\N	2014-04-07 10:58:37
11645	\N	\N	2020-09-24 00:00:00	ANCIEN	\N	Menton	\N	\N	1989	2009	\N	MUNICIPAL	08041T	de	\N	http://www.ville-menton.fr/	\N	\N	\N
11653	1995-06-18 00:00:00	\N	\N	ACTIF	\N	Cagnes-sur-Mer	\N	\N	1995	\N	\N	MUNICIPAL	08042U	de	\N	http://www.cagnes-sur-mer.fr	\N	\N	\N
11683	\N	\N	\N	ANCIEN	\N	Egletons	\N	\N	2001	2008	\N	MUNICIPAL	08050U	d'	\N	http://www.mairie-egletons.fr/	\N	\N	\N
11694	1983-03-13 00:00:00	\N	2014-04-01 00:00:00	ANCIEN	\N	Marle	\N	\N	\N	\N	0	MUNICIPAL	08052W	de	\N	\N	\N	\N	2014-04-09 10:54:49
11708	\N	\N	\N	ACTIF	\N	Chancelade	\N	\N	1992	\N	\N	MUNICIPAL	08055A	de	\N	\N	\N	\N	\N
11722	1995-06-01 00:00:00	\N	2014-03-31 00:00:00	ANCIEN	\N	Montbron	\N	\N	\N	\N	0	MUNICIPAL	08058D	de	\N	\N	\N	\N	2014-04-07 17:15:35
11736	\N	\N	2014-03-31 00:00:00	ANCIEN	\N	Châteauroux	\N	\N	2001	\N	0	MUNICIPAL	08062Y	de	\N	http://www.ville-chateauroux.fr/	\N	\N	2014-04-07 11:07:16
11219	\N	\N	2008-03-21 00:00:00	ANCIEN	\N	Fouquières-lès-Lens	\N	\N	\N	\N	\N	MUNICIPAL	07001F	de	\N	\N	\N	\N	\N
11222	\N	\N	\N	ACTIF	\N	Angres	\N	\N	\N	\N	\N	MUNICIPAL	07002G	d'	\N	\N	\N	\N	\N
11246	\N	\N	\N	ACTIF	\N	Seichamps	\N	\N	\N	\N	\N	MUNICIPAL	07023M	de	\N	http://www.mairie-seichamps.fr/	\N	\N	\N
11864	2001-04-01 00:00:00	\N	2004-03-31 00:00:00	ANCIEN	\N	Montpellier	\N	\N	2001	2004	\N	MUNICIPAL	08021P	de	\N	http://www.ville-montpellier.fr/	\N	\N	\N
11740	1989-03-12 00:00:00	\N	2001-03-28 00:00:00	ANCIEN	\N	Chailly-sur-Armançon	\N	\N	1989	2001	\N	MUNICIPAL	08061X	de	\N	\N	\N	\N	\N
11744	2001-03-28 00:00:00	\N	\N	ANCIEN	\N	Pouilly-en-Auxois	\N	\N	2001	2008	\N	MUNICIPAL	08061X	de	\N	\N	\N	\N	\N
11754	\N	\N	\N	ACTIF	\N	Saint-Affrique	\N	\N	2001	\N	0	MUNICIPAL	08066D	de	\N	http://www.saintaffrique.com/ 	\N	\N	2014-01-09 11:32:06
11776	1986-03-01 00:00:00	\N	\N	ACTIF	\N	Audincourt	\N	\N	\N	\N	\N	MUNICIPAL	08068F	d'	\N	http://www.audincourt.com	\N	\N	2017-11-15 10:31:24
11783	\N	\N	\N	ACTIF	\N	Dijon	\N	\N	2001	\N	0	MUNICIPAL	08070Y	de	\N	http://www.ville-dijon.fr/	\N	\N	2014-04-16 17:14:03
11807	1995-03-01 00:00:00	\N	2014-03-31 00:00:00	ANCIEN	\N	Lignerolles	\N	\N	\N	\N	0	MUNICIPAL	08054Y	de	\N	\N	\N	\N	2014-04-16 17:54:50
11811	2001-03-01 00:00:00	\N	2020-06-28 00:00:00	ANCIEN	\N	Blagnac	\N	\N	\N	\N	\N	MUNICIPAL	08031R	de	\N	http://www.mairie-blagnac.fr/	\N	\N	2016-09-13 16:40:14
11815	\N	\N	2013-07-17 00:00:00	ANCIEN	\N	Arue	\N	\N	\N	\N	\N	MUNICIPAL	08071A	d'	\N	\N	\N	\N	\N
11903	\N	\N	\N	ANCIEN	\N	Arbonne	\N	\N	1971	1977	\N	MUNICIPAL	92013M	d'	\N	\N	\N	\N	\N
12233	1995-06-18 00:00:00	\N	2014-04-01 00:00:00	ANCIEN	\N	Saint-Paul-Lès-Dax	\N	\N	\N	\N	0	MUNICIPAL	11014C	de	\N	\N	\N	\N	2014-04-08 15:54:57
12558	\N	\N	1995-06-17 00:00:00	ANCIEN	\N	Perpignan	\N	\N	1989	\N	\N	MUNICIPAL	11101A	de	\N	\N	\N	\N	\N
12250	\N	\N	\N	ANCIEN	\N	Avrillé	\N	\N	1995	2008	\N	MUNICIPAL	11030C	d'	\N	\N	\N	\N	\N
12251	2001-03-18 00:00:00	\N	\N	ACTIF	\N	Beauvais	\N	\N	2001	\N	\N	MUNICIPAL	11044J	de	\N	\N	\N	\N	\N
12562	1995-06-19 00:00:00	\N	2020-03-15 00:00:00	ANCIEN	\N	Le Soler	\N	\N	\N	\N	\N	MUNICIPAL	11101A	du	\N	\N	\N	\N	\N
12268	1989-03-19 00:00:00	\N	2004-03-01 00:00:00	ANCIEN	\N	Arras	\N	\N	\N	2004	\N	MUNICIPAL	11061K	d'	\N	\N	\N	\N	\N
12289	\N	\N	\N	ACTIF	\N	Puymiclan	\N	\N	1995	\N	\N	MUNICIPAL	11095V	de	\N	\N	\N	\N	\N
12297	1981-06-14 00:00:00	\N	2011-03-19 00:00:00	ANCIEN	\N	Lumbres	\N	\N	\N	\N	\N	MUNICIPAL	11059R	de	\N	\N	\N	\N	\N
12565	\N	\N	\N	ACTIF	\N	Romorantin-Lanthenay	\N	\N	1977	\N	\N	MUNICIPAL	11106F	de	\N	\N	\N	\N	\N
12576	1971-03-21 00:00:00	\N	2022-02-03 00:00:00	ANCIEN	\N	Viven	\N	\N	\N	2001	\N	MUNICIPAL	11112D	de	\N	\N	\N	\N	\N
12764	2001-03-18 00:00:00	\N	\N	ACTIF	\N	Saint-Louis-de-Marie-Galante	\N	\N	\N	\N	\N	MUNICIPAL	11114F	de	\N	\N	\N	\N	\N
12583	1995-06-18 00:00:00	\N	2001-03-18 00:00:00	ANCIEN	\N	Bidache	\N	\N	\N	\N	\N	MUNICIPAL	11111C	de	\N	\N	\N	\N	\N
12089	2008-03-17 00:00:00	\N	\N	ANCIEN	\N	Villeneuve-la-Garenne	\N	\N	2008	2012	24711	MUNICIPAL	99004R	de	\N	\N	\N	\N	\N
12327	1977-03-20 00:00:00	\N	2006-12-18 00:00:00	ANCIEN	\N	Sully-sur-Loire	\N	\N	\N	\N	\N	MUNICIPAL	11103C	de	\N	\N	\N	\N	\N
12407	1989-03-19 00:00:00	\N	2022-04-09 00:00:00	ANCIEN	\N	Dunkerque	\N	\N	\N	\N	0	MUNICIPAL	11035H	de	\N	\N	\N	\N	2014-04-09 22:08:18
12765	1971-03-11 00:00:00	\N	2014-04-01 00:00:00	ANCIEN	\N	Pointe-Noire	\N	\N	\N	\N	0	MUNICIPAL	11113E	de	\N	\N	\N	\N	2014-04-09 22:36:28
12779	2001-03-18 00:00:00	\N	2011-11-05 00:00:00	ANCIEN	\N	Compiègne	\N	\N	\N	\N	\N	MUNICIPAL	11045K	de	\N	\N	\N	\N	\N
13789	\N	\N	\N	ANCIEN	\N	Meaux	\N	\N	2001	2005	\N	MUNICIPAL	14018U	de	\N	\N	\N	2014-08-27 16:44:55	2014-08-27 17:16:01
12796	1995-06-18 00:00:00	\N	2014-04-01 00:00:00	ANCIEN	\N	Grenoble	\N	\N	\N	\N	0	MUNICIPAL	11042G	de	\N	\N	\N	\N	2014-04-08 15:39:31
12319	\N	\N	2014-09-01 00:00:00	ANCIEN	\N	Bailleul-sur-Thérain	\N	\N	1977	\N	\N	MUNICIPAL	11046L	de	\N	\N	\N	\N	2014-09-24 16:11:00
12799	2008-03-28 00:00:00	\N	\N	ANCIEN	\N	Unieux	\N	\N	\N	2012	\N	MUNICIPAL	11056N	d'	\N	\N	\N	\N	\N
12823	1989-03-19 00:00:00	\N	\N	ACTIF	\N	Cambrin	\N	\N	\N	\N	\N	MUNICIPAL	11062L	de	\N	\N	\N	\N	\N
6144	2001-03-11 00:00:00	\N	2007-12-16 00:00:00	ANCIEN	\N	Saint-Amand-Montrond	\N	\N	2001	2007	11937	MUNICIPAL	89045V	de	\N	http://www.cg18.fr/commune/st-amand-montrond/	\N	\N	\N
679	1983-03-13 00:00:00	\N	2001-03-11 00:00:00	ANCIEN	\N	Le Teilleul	\N	\N	1983	2001	1433	MUNICIPAL	96004D	de 	\N	\N	\N	\N	\N
6145	2001-03-11 00:00:00	\N	2014-03-24 00:00:00	ANCIEN	\N	Le Teilleul	\N	\N	\N	\N	1433	MUNICIPAL	96004D	de	\N	\N	\N	\N	2015-02-27 10:24:52
6143	2001-03-11 00:00:00	\N	2008-03-21 00:00:00	ANCIEN	\N	Bordeaux	\N	\N	2001	2008	210336	MUNICIPAL	80046H	de	\N	\N	\N	\N	\N
6147	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Saint-Aubin les Forges	\N	\N	2001	\N	368	MUNICIPAL	92016Q	de	\N	\N	\N	\N	\N
669	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Saint-Mars-la-Jaille	\N	\N	\N	2001	2114	MUNICIPAL	83023N	de 	\N	\N	\N	\N	\N
6149	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Bapaume	\N	\N	2001	\N	3509	MUNICIPAL	92017R	de	\N	\N	\N	\N	\N
6150	2001-03-11 00:00:00	\N	2002-01-19 00:00:00	ANCIEN	\N	Lys-lez-Lannoy	\N	\N	2001	2002	12300	MUNICIPAL	97007L	de	\N	\N	\N	\N	\N
6151	2001-03-11 00:00:00	\N	2008-03-16 00:00:00	ANCIEN	\N	Autrans	\N	\N	2001	2008	1406	MUNICIPAL	83031N	d'	\N	http://www.autrans.fr	\N	\N	\N
6152	2001-03-11 00:00:00	\N	2020-08-26 00:00:00	ANCIEN	\N	Rosières	\N	\N	2001	\N	1305	MUNICIPAL	78006D	de	\N	http://www.ville-rosieres.fr	\N	\N	\N
691	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Many	\N	\N	\N	2001	196	MUNICIPAL	97008M	de 	\N	\N	\N	\N	\N
6154	2001-03-11 00:00:00	\N	2013-01-23 00:00:00	ANCIEN	\N	Etriché	\N	\N	2001	2013	1024	MUNICIPAL	83038V	d'	\N	\N	\N	\N	\N
6155	2001-03-11 00:00:00	\N	2008-03-21 00:00:00	ANCIEN	\N	Nuzéjouls	\N	\N	2001	2008	238	MUNICIPAL	92039X	de	\N	\N	\N	\N	\N
673	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Estouy	\N	\N	\N	2001	443	MUNICIPAL	83043S	de 	\N	\N	\N	\N	\N
6156	2001-03-11 00:00:00	\N	2001-10-14 00:00:00	ANCIEN	\N	Tremblay-les-Villages	\N	\N	2001	2001	1451	MUNICIPAL	89009R	de	\N	\N	\N	\N	\N
6157	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Desvres	\N	\N	2001	\N	5318	MUNICIPAL	92043T	de	\N	\N	\N	\N	\N
6158	2001-03-11 00:00:00	\N	2008-03-16 00:00:00	ANCIEN	\N	Château-Chinon	\N	\N	2001	2008	2502	MUNICIPAL	86053H	de	\N	\N	\N	\N	\N
10551	\N	\N	2006-04-29 00:00:00	ANCIEN	\N	Saint-Raphaël	\N	\N	1977	2006	\N	MUNICIPAL	86035F	de	\N	\N	\N	\N	\N
10553	\N	\N	\N	ACTIF	\N	Beuzac	\N	\N	\N	\N	\N	MUNICIPAL	000639	\N	\N	\N	\N	\N	\N
10555	\N	\N	\N	ANCIEN	\N	Metz	\N	\N	1983	1995	\N	MUNICIPAL	83042R	de	\N	http://www.mairie-metz.fr/	\N	\N	\N
712	\N	\N	\N	ACTIF	\N	20ème arrondissement de Paris	\N	\N	\N	\N	\N	MUNICIPAL	95018F	de 	\N	\N	\N	\N	\N
10567	2001-03-18 00:00:00	\N	\N	ACTIF	\N	Paris (20ème arrondissement)	\N	\N	2001	\N	\N	MUNICIPAL	95056M	de	\N	\N	\N	\N	\N
10570	\N	\N	2010-12-17 00:00:00	ANCIEN	\N	Lyon	\N	\N	1977	2010	\N	MUNICIPAL	03003Q	de	\N	http://www.mairie-lyon.fr/	\N	\N	\N
10583	2003-12-19 00:00:00	\N	2014-03-31 00:00:00	ANCIEN	\N	Eup	\N	\N	\N	\N	148	MUNICIPAL	98011L	d'	\N	\N	\N	\N	2014-04-07 11:20:05
10587	\N	\N	2016-11-03 00:00:00	ANCIEN	\N	Verrières-le-Buisson	\N	\N	2001	2016	16100	MUNICIPAL	03004R	de	\N	\N	\N	\N	\N
10603	1995-06-21 00:00:00	\N	\N	ANCIEN	\N	Metz	\N	\N	1995	2001	\N	MUNICIPAL	01060R	de	\N	http://www.mairie-metz.fr/	\N	\N	\N
10672	1989-03-19 00:00:00	\N	\N	ANCIEN	\N	Paris (11eme arrondissement)	\N	\N	1989	1995	\N	MUNICIPAL	00001A	de	\N	\N	\N	\N	\N
10676	2002-07-05 00:00:00	\N	\N	ACTIF	\N	Saint-Nizier de Fornas	\N	\N	\N	\N	\N	MUNICIPAL	97011G	de	\N	\N	\N	\N	\N
10688	\N	\N	\N	ANCIEN	\N	Sarcelles	\N	\N	1972	1989	\N	MUNICIPAL	79004F	de	\N	http://www.sarcelles.com/	\N	\N	\N
10692	\N	\N	2021-09-30 00:00:00	ANCIEN	\N	Houilles	\N	\N	1977	1989	\N	MUNICIPAL	86011W	de	\N	http://www.ville-houilles.fr/	\N	\N	\N
10696	\N	\N	2021-03-25 00:00:00	ANCIEN	\N	Ennery	\N	\N	1953	\N	2060	MUNICIPAL	04016A	d'	\N	\N	\N	\N	\N
10698	\N	\N	2022-03-10 00:00:00	ANCIEN	\N	Presly	\N	\N	1971	\N	228	MUNICIPAL	04017B	de	\N	http://www.cg18.fr/commune/presly	\N	\N	\N
10708	\N	\N	\N	ANCIEN	\N	Valence	\N	\N	1977	1983	\N	MUNICIPAL	89015P	de	\N	http://www.mairie-valence.fr/	\N	\N	\N
10712	\N	\N	\N	ANCIEN	\N	Martigues	\N	\N	1983	1989	\N	MUNICIPAL	98016R	de	\N	http://www.ville-martigues.fr/	\N	\N	\N
769	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Créteil	\N	\N	1977	2001	82088	MUNICIPAL	97004H	de 	\N	http://www.ville-creteil.fr/	\N	\N	\N
10729	\N	\N	\N	ANCIEN	\N	Fougères	\N	\N	1977	1989	\N	MUNICIPAL	98044V	de	\N	http://www.mairie-fougeres.fr/	\N	\N	\N
10766	\N	\N	\N	ANCIEN	\N	Sablé-sur-Sarthe	\N	\N	1981	2001	\N	MUNICIPAL	02009S	de	\N	\N	\N	\N	\N
10793	\N	\N	\N	ACTIF	\N	Plessis-Trévise	\N	\N	1983	\N	\N	MUNICIPAL	04037F	du	\N	http://www.leplessistrevise.fr/	\N	\N	\N
10809	\N	\N	\N	ACTIF	\N	La Valette du Var	\N	\N	1983	\N	\N	MUNICIPAL	04041B	de	\N	http://www.lavalette83.fr/	\N	\N	\N
10812	\N	\N	2014-04-01 00:00:00	ANCIEN	\N	Figanières	\N	\N	1983	\N	0	MUNICIPAL	04038G	de	\N	http://www.figanieres.com	\N	\N	2014-04-08 15:57:28
10830	\N	\N	2014-03-31 00:00:00	ANCIEN	\N	Hégenheim	\N	\N	2001	\N	0	MUNICIPAL	04045F	d'	\N	http://www.ville-hegenheim.fr	\N	\N	2014-05-05 14:45:08
10839	\N	\N	2016-11-30 00:00:00	ANCIEN	\N	Crécy-la-Chapelle	\N	\N	2001	\N	\N	MUNICIPAL	04048J	de	\N	http://www.crecylachapelle.eu/	\N	\N	2016-12-01 10:36:51
10840	\N	\N	2015-06-22 00:00:00	ANCIEN	\N	Gleizé	\N	\N	1989	\N	\N	MUNICIPAL	04049K	de	\N	http://www.mairie-gleize.fr	\N	\N	2015-07-17 16:05:46
10841	1977-03-20 00:00:00	\N	2016-11-30 00:00:00	ANCIEN	\N	Condé-Sainte-Libiaire	\N	\N	1977	2001	\N	MUNICIPAL	04048J	de	\N	\N	\N	\N	2016-12-01 10:36:51
10848	\N	\N	\N	ANCIEN	\N	Ecully	\N	\N	1977	1995	\N	MUNICIPAL	04051D	d'	\N	http://www.ville-ecully.fr/	\N	\N	\N
10073	\N	\N	\N	ACTIF	\N	Bruges	\N	\N	\N	\N	\N	MUNICIPAL	000634	\N	\N	http://www.mairie-bruges.fr/	\N	\N	\N
10081	\N	\N	2002-06-02 00:00:00	ANCIEN	\N	Paris	\N	\N	\N	2002	2	MUNICIPAL	59524Q	\N	\N	http://www.paris.fr	\N	\N	\N
10089	\N	\N	\N	ACTIF	\N	Paris	\N	\N	\N	\N	2	MUNICIPAL	59527T	\N	\N	http://www.paris.fr	\N	\N	\N
10095	\N	\N	2012-09-04 00:00:00	ANCIEN	\N	Lens	\N	\N	\N	2012	38310	MUNICIPAL	59226H	\N	\N	http://www.villedelens.fr/	\N	\N	\N
6013	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Biarritz	\N	\N	2001	\N	28742	MUNICIPAL	92013M	de	\N	http://www.mairie-biarritz.fr/	\N	\N	\N
6031	2001-03-11 00:00:00	\N	2008-03-21 00:00:00	ANCIEN	\N	La Ville-aux-Dames	\N	\N	\N	2008	4193	MUNICIPAL	92030N	de	\N	http://www.ville-aux-dames.com	\N	\N	\N
6059	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Oissel	\N	\N	\N	\N	11444	MUNICIPAL	98053W	d'	\N	http://www.ville-oissel.fr/	\N	\N	2017-11-13 14:18:34
6075	2001-03-11 00:00:00	\N	\N	ANCIEN	\N	Landser	\N	\N	2001	2008	1941	MUNICIPAL	95045J	de	\N	http://www.ville-landser.fr/	\N	\N	\N
6086	2001-03-11 00:00:00	\N	2020-09-11 00:00:00	ANCIEN	\N	Remiremont	\N	\N	2001	2004	9068	MUNICIPAL	77058M	de	\N	http://www.remiremont.fr/	\N	\N	\N
6098	2001-03-11 00:00:00	\N	\N	ANCIEN	\N	Périgueux	\N	\N	2001	2008	30280	MUNICIPAL	98031Q	de	\N	http://www.ville-perigueux.fr/	\N	\N	\N
6131	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Soulac-sur-Mer	\N	\N	2001	\N	3946	MUNICIPAL	98021N	de	\N	http://www.mairie-soulac.fr	\N	\N	\N
6139	2001-03-11 00:00:00	\N	2006-06-29 00:00:00	ANCIEN	\N	Cavan	\N	\N	2001	2006	1080	MUNICIPAL	98012M	de	\N	http://www.mairie-cavan.fr/	\N	\N	\N
11273	2001-03-20 00:00:00	\N	\N	ACTIF	\N	Neuville-Day	\N	\N	\N	\N	\N	MUNICIPAL	07029T	de	\N	\N	\N	\N	2017-11-14 10:36:10
11276	\N	\N	\N	ACTIF	\N	Béziers	\N	\N	1983	\N	0	MUNICIPAL	07030L	de	\N	http://www.ville-beziers.fr/	\N	\N	2014-04-08 16:08:21
11347	2008-03-21 00:00:00	\N	\N	ACTIF	\N	Saint-Gildas-des-Bois	\N	\N	2008	\N	\N	MUNICIPAL	01056V	de	\N	http://www.cc-paysdepontchateau.fr/	\N	\N	\N
11349	2008-03-21 00:00:00	\N	2020-03-15 00:00:00	ANCIEN	\N	Nouilly	\N	\N	\N	\N	999	MUNICIPAL	01060R	de	\N	\N	\N	\N	\N
11489	\N	\N	2016-03-21 00:00:00	ANCIEN	\N	Bernay	\N	\N	2001	\N	\N	MUNICIPAL	08009T	de	\N	http://www.ville-bernay27.fr	\N	\N	2016-06-02 15:57:39
11490	\N	\N	\N	ANCIEN	\N	Bonneville-Aptot	\N	\N	1983	1989	\N	MUNICIPAL	08009T	de	\N	\N	\N	\N	\N
11500	\N	1992-05-16 00:00:00	\N	ACTIF	\N	Terminiers	\N	\N	1992	\N	999	MUNICIPAL	08011M	de	\N	\N	\N	\N	2014-05-12 16:04:27
11519	\N	\N	2010-03-15 00:00:00	ANCIEN	\N	Loudéac	\N	\N	\N	2010	\N	MUNICIPAL	08013P	de	\N	\N	\N	\N	\N
11586	\N	\N	\N	ANCIEN	\N	Rennes	\N	\N	1977	2008	\N	MUNICIPAL	08027V	de	\N	http://www.ville-rennes.fr/	\N	\N	\N
11609	\N	\N	\N	ACTIF	\N	Pertre	\N	\N	1983	\N	\N	MUNICIPAL	08034U	du	\N	http://www.lepertre.fr/topic/index.html	\N	\N	2018-01-23 18:59:41
11656	1989-03-01 00:00:00	\N	2008-03-16 00:00:00	ANCIEN	\N	Ergué-Gabéric	\N	\N	1989	2008	\N	MUNICIPAL	08043V	d'	\N	\N	\N	\N	\N
11662	\N	\N	2020-06-28 00:00:00	ANCIEN	\N	Lanmeur	\N	\N	1989	\N	\N	MUNICIPAL	08045X	de	\N	\N	\N	\N	2017-11-15 10:19:08
11673	\N	\N	2020-06-28 00:00:00	ANCIEN	\N	Douarnenez	\N	\N	2008	\N	\N	MUNICIPAL	08047A	de	\N	http://www.mairie-douarnenez.fr/	\N	\N	\N
11695	\N	\N	\N	ACTIF	\N	Aurillac	\N	\N	1983	\N	\N	MUNICIPAL	08051V	d'	\N	\N	\N	\N	\N
11716	\N	\N	\N	ACTIF	\N	Privas	\N	\N	2006	\N	0	MUNICIPAL	08057C	de	\N	http://www.mairie-privas.fr/	\N	\N	2014-04-08 12:21:08
11717	\N	\N	\N	ANCIEN	\N	Saint-Priest	\N	\N	1995	2001	\N	MUNICIPAL	08057C	de	\N	\N	\N	\N	\N
11743	\N	\N	\N	ANCIEN	\N	Aigremont	\N	\N	1989	2010	\N	MUNICIPAL	08063A	d'	\N	http://www.annuaire-mairie.fr/mairie-aigremont-30.html	\N	\N	\N
11749	\N	\N	\N	ACTIF	\N	Nîmes	\N	\N	2001	\N	\N	MUNICIPAL	08065C	de	\N	http://www.nimes.fr/	\N	\N	\N
11778	\N	\N	2014-03-30 00:00:00	ANCIEN	\N	Salives	\N	\N	2004	\N	0	MUNICIPAL	08069G	de	\N	\N	\N	\N	2014-04-07 11:22:42
711	\N	\N	2001-03-11 00:00:00	ANCIEN	\N	Paris	\N	Ancien Président du Conseil de Paris 	\N	2001	\N	MUNICIPAL	77013X	de 	\N	http://www.paris.fr	\N	\N	\N
11988	\N	\N	\N	ACTIF	\N	Felletin	\N	demande d'ajout lien de son assistant David Darroussin le 22/06/2010	2008	\N	0	MUNICIPAL	09012S	de	\N	http://www.felletin.fr/	\N	\N	2014-04-08 16:24:51
12055	\N	\N	2011-01-09 00:00:00	ANCIEN	\N	Souffelweyersheim	\N	\N	1995	2011	\N	MUNICIPAL	10015M	de	\N	\N	\N	\N	\N
11855	\N	\N	\N	ANCIEN	\N	Saint-Malo	\N	\N	1989	1995	\N	MUNICIPAL	08037X	de	\N	http://www.ville-saint-malo.fr/	\N	\N	\N
11878	\N	\N	\N	ANCIEN	\N	Paris	\N	\N	\N	2001	\N	MUNICIPAL	59312E	de	\N	http://www.paris.fr	\N	\N	\N
11887	\N	\N	\N	ANCIEN	\N	Choue	\N	\N	1989	1995	\N	MUNICIPAL	92022N	de	\N	\N	\N	\N	\N
11888	\N	\N	\N	ANCIEN	\N	Montdoubleau	\N	\N	1977	1983	\N	MUNICIPAL	92022N	de	\N	\N	\N	\N	\N
11890	\N	\N	\N	ANCIEN	\N	Reims	\N	\N	1989	1995	\N	MUNICIPAL	01026P	de	\N	http://www.ville-reims.fr/	\N	\N	\N
11891	\N	\N	\N	ANCIEN	\N	Oneux	\N	\N	1989	2004	\N	MUNICIPAL	04089T	d'	\N	\N	\N	\N	\N
11892	\N	\N	\N	ANCIEN	\N	Meung-sur-Loire	\N	\N	1983	2001	\N	MUNICIPAL	01027Q	de	\N	\N	\N	\N	\N
11894	\N	\N	\N	ANCIEN	\N	Saint-Laurent-Blangy	\N	\N	1983	1989	\N	MUNICIPAL	07001F	de	\N	\N	\N	\N	\N
11895	\N	\N	\N	ANCIEN	\N	Arras	\N	\N	1989	1995	\N	MUNICIPAL	07001F	d'	\N	\N	\N	\N	\N
11896	\N	\N	\N	ANCIEN	\N	Sallèles-d'Aude	\N	\N	1977	1979	\N	MUNICIPAL	80013X	de	\N	\N	\N	\N	\N
11898	\N	\N	\N	ANCIEN	\N	Montauban	\N	\N	1983	1986	\N	MUNICIPAL	88008L	de	\N	http://www.ville-montauban.fr/	\N	\N	\N
12062	\N	\N	\N	ANCIEN	\N	Saint-Germain-en-Laye	\N	\N	2001	2008	\N	MUNICIPAL	11001K	de	\N	\N	\N	\N	\N
11906	\N	\N	\N	ANCIEN	\N	Boult	\N	\N	1971	1977	\N	MUNICIPAL	03001N	de	\N	\N	\N	\N	\N
11909	\N	\N	\N	ANCIEN	\N	Angers	\N	\N	1979	2004	\N	MUNICIPAL	01018P	d'	\N	http://www.ville-angers.fr/	\N	\N	\N
10082	\N	\N	2009-10-22 00:00:00	ANCIEN	\N	Lezey	\N	\N	\N	2009	\N	MUNICIPAL	58366Q	\N	\N	\N	\N	\N	\N
12038	2010-10-05 00:00:00	\N	2014-03-28 00:00:00	ANCIEN	\N	Saint-Quentin	\N	\N	\N	\N	0	MUNICIPAL	98036V	de 	\N	\N	\N	\N	2014-04-07 09:52:36
6173	2001-03-11 00:00:00	\N	\N	ACTIF	\N	Sournia	\N	\N	2001	\N	368	MUNICIPAL	92011K	de	\N	http://www.sournia.com	\N	\N	\N
10895	\N	\N	\N	ACTIF	\N	Strasbourg	\N	\N	1983	\N	\N	MUNICIPAL	04065K	de	\N	http://www.mairie-strasbourg.fr/	\N	\N	\N
10932	1996-12-12 00:00:00	\N	\N	ACTIF	\N	Ermont	\N	\N	1996	\N	\N	MUNICIPAL	04074L	d'	\N	http://www.ville-ermont.fr/	\N	\N	\N
10972	\N	\N	\N	ANCIEN	\N	Dole	\N	\N	1989	2002	\N	MUNICIPAL	04082L	de	\N	http://www.ville-dole.fr/	\N	\N	\N
11037	1997-10-23 00:00:00	\N	2020-06-28 00:00:00	ANCIEN	\N	Oullins	\N	\N	\N	\N	\N	MUNICIPAL	04047H	d'	\N	http://www.ville-oullins.fr/	\N	\N	2018-01-24 19:32:10
11073	\N	\N	2017-08-06 00:00:00	ANCIEN	\N	Meaux	\N	\N	2001	2008	\N	MUNICIPAL	04053F	de	\N	http://www.ville-meaux.fr/	\N	\N	2017-08-07 16:31:39
11104	\N	\N	2008-03-16 00:00:00	ANCIEN	\N	Cormeilles-en-Parisis	\N	\N	1995	\N	\N	MUNICIPAL	04100U	de	\N	http://www.ville-cormeilles95.fr/	\N	\N	\N
14079	1989-04-01 00:00:00	1989-04-01 00:00:00	\N	ACTIF	\N	Coucouron	\N	\N	\N	\N	\N	MUNICIPAL	14199E	de 	\N	\N	\N	2014-09-28 15:51:40	2018-01-25 10:02:16
14377	\N	\N	2020-06-28 00:00:00	ANCIEN	\N	Besançon	\N	\N	2014	\N	\N	MUNICIPAL	14123H	de	\N	\N	\N	2014-10-02 10:37:45	2014-10-02 10:39:50
15279	\N	2001-03-18 00:00:00	2016-01-29 00:00:00	ANCIEN	\N	Merlimont	\N	\N	1995	\N	\N	MUNICIPAL	14331P	de	2016-01-29 00:00:00	\N	\N	2016-01-12 09:49:41	2016-02-19 14:37:34
15518	2008-03-16 00:00:00	2008-03-16 00:00:00	2014-03-16 00:00:00	ANCIEN	\N	Boulogne-Billancourt	\N	\N	\N	\N	\N	MUNICIPAL	14363X	de	\N	\N	\N	2017-01-10 16:33:41	2017-01-10 16:35:15
50815	1977-03-21 00:00:00	1977-03-20 00:00:00	\N	ACTIF	\N	Chédigny	\N	\N	\N	\N	\N	MUNICIPAL	19441R	de	\N	\N	\N	2017-09-19 16:07:00	2018-04-09 19:13:47
50817	1989-03-20 00:00:00	1989-03-19 00:00:00	2020-06-28 00:00:00	ANCIEN	\N	Tours	\N	\N	\N	\N	\N	MUNICIPAL	19515S	de	\N	\N	\N	2017-09-19 16:14:38	2017-11-21 18:33:21
50826	1995-06-18 00:00:00	1995-06-18 00:00:00	2015-03-29 00:00:00	ANCIEN	\N	Cernans	\N	\N	\N	\N	\N	MUNICIPAL	19479G	de	\N	\N	\N	2017-09-19 16:35:58	2017-09-26 16:39:35
50840	1995-06-18 00:00:00	1995-06-18 00:00:00	2020-06-27 00:00:00	ANCIEN	\N	Chaux-Champagny	\N	\N	\N	\N	\N	MUNICIPAL	19467C	de	\N	\N	\N	2017-09-19 17:16:32	2017-12-04 21:44:41
50972	2008-03-16 00:00:00	2014-03-30 00:00:00	2021-07-21 00:00:00	ANCIEN	\N	Onnaing	\N	\N	\N	\N	\N	MUNICIPAL	19565D	d'	\N	\N	\N	2017-09-21 17:29:50	2017-11-16 18:51:25
50976	1990-11-30 00:00:00	\N	2014-03-30 00:00:00	ANCIEN	\N	Brouckerque	\N	\N	\N	\N	\N	MUNICIPAL	17589D	de	\N	\N	\N	2017-09-21 17:36:37	2017-09-24 19:35:46
50977	2001-03-18 00:00:00	2001-03-18 00:00:00	2017-12-30 00:00:00	ANCIEN	\N	Saint-André-lez-Lille	\N	\N	\N	\N	\N	MUNICIPAL	19569H	de	\N	\N	\N	2017-09-21 17:45:50	2018-01-02 11:05:22
50990	1983-03-14 00:00:00	1988-02-11 00:00:00	\N	ACTIF	\N	Lambersart	\N	\N	\N	\N	\N	MUNICIPAL	04008A	de	\N	\N	\N	2017-09-21 18:17:16	2018-02-16 16:02:09
51039	1989-03-19 00:00:00	1989-03-19 00:00:00	2017-10-23 00:00:00	ANCIEN	\N	Biarritz	\N	\N	\N	\N	\N	MUNICIPAL	19621T	de	\N	\N	\N	2017-09-22 14:04:40	2017-11-17 10:59:01
51395	2001-03-18 00:00:00	2001-03-18 00:00:00	2008-03-16 00:00:00	ANCIEN	\N	Ponchon	\N	\N	\N	\N	\N	MUNICIPAL	19573D	de	\N	\N	\N	2017-09-26 10:47:51	2017-09-26 10:52:58
51398	2014-03-23 00:00:00	2014-03-23 00:00:00	\N	ACTIF	\N	Blanc-Mesnil	\N	\N	\N	\N	\N	MUNICIPAL	19695N	du	\N	\N	\N	2017-09-26 11:07:20	2017-09-26 11:07:52
51053	2012-07-09 00:00:00	2008-03-16 00:00:00	2020-06-27 00:00:00	ANCIEN	\N	Paris	\N	\N	\N	\N	\N	MUNICIPAL	19651A	de	\N	\N	\N	2017-09-22 18:34:30	2017-11-08 15:42:05
51613	2017-11-02 00:00:00	\N	2023-10-06 00:00:00	ANCIEN	\N	Morne-à-l'Eau	\N	\N	\N	\N	\N	MUNICIPAL	19715Y	de	\N	\N	\N	\N	\N
51147	1983-03-13 00:00:00	1983-03-13 00:00:00	2004-04-01 00:00:00	ANCIEN	\N	Abitain	\N	\N	\N	\N	\N	MUNICIPAL	19619A	d'	\N	\N	\N	2017-09-24 17:32:06	2017-09-26 17:02:08
51617	1989-03-19 00:00:00	1989-03-19 00:00:00	2020-06-28 00:00:00	ANCIEN	\N	Villeurbanne	\N	\N	\N	\N	\N	MUNICIPAL	19251M	de	\N	\N	\N	\N	\N
51399	1995-03-19 00:00:00	1995-03-19 00:00:00	2011-03-19 00:00:00	ANCIEN	\N	Persan	\N	\N	\N	\N	\N	MUNICIPAL	19667J	de	\N	\N	\N	2017-09-26 11:11:48	2017-09-26 11:13:07
51454	2008-03-16 00:00:00	2008-03-16 00:00:00	\N	ACTIF	\N	Bordeaux 	\N	\N	\N	\N	\N	MUNICIPAL	19719D	de	\N	\N	\N	2017-10-01 09:27:56	2017-12-14 09:55:28
51517	2001-03-18 00:00:00	2001-03-18 00:00:00	2020-03-15 00:00:00	ANCIEN	\N	Paris	\N	\N	\N	\N	\N	MUNICIPAL	19649G	de	\N	\N	\N	2017-11-16 15:50:21	2017-11-16 15:52:30
51531	2017-09-30 00:00:00	2017-09-30 00:00:00	\N	ACTIF	\N	Marseille (4ème et 5ème arrondissements)	\N	\N	\N	\N	\N	MUNICIPAL	08048B	de	\N	\N	\N	2017-11-28 16:14:11	2017-11-28 16:18:43
52091	2008-03-15 00:00:00	\N	\N	ACTIF	\N	Drom	\N	\N	\N	\N	\N	MUNICIPAL	20094J	de	\N	\N	\N	\N	\N
52113	2014-03-15 00:00:00	\N	2020-10-26 00:00:00	ANCIEN	\N	Antibes	\N	\N	\N	\N	\N	MUNICIPAL	20138D	d'	\N	\N	\N	\N	\N
52114	2008-03-15 00:00:00	\N	2014-03-15 00:00:00	ANCIEN	\N	Vallauris	\N	\N	\N	\N	\N	MUNICIPAL	20138D	de	\N	\N	\N	\N	\N
52117	2001-03-15 00:00:00	\N	2020-10-26 00:00:00	ANCIEN	\N	Toulon	\N	\N	\N	\N	\N	MUNICIPAL	20078J	de	\N	\N	\N	\N	\N
52119	2008-03-15 00:00:00	\N	2020-10-23 00:00:00	ANCIEN	\N	Saint-Raphaël	\N	\N	\N	\N	\N	MUNICIPAL	20074E	de	\N	\N	\N	\N	\N
52127	2001-03-15 00:00:00	\N	\N	ACTIF	\N	Chartres	\N	\N	\N	\N	\N	MUNICIPAL	20068G	de	\N	\N	\N	\N	\N
52123	2014-03-15 00:00:00	\N	\N	ACTIF	\N	Digoin	\N	\N	\N	\N	\N	MUNICIPAL	20120S	de	\N	\N	\N	\N	\N
52130	1983-03-15 00:00:00	\N	1989-03-15 00:00:00	ANCIEN	\N	Brou	\N	\N	\N	\N	\N	MUNICIPAL	20068G	de	\N	\N	\N	\N	\N
52407	2015-06-15 00:00:00	2015-06-15 00:00:00	\N	ACTIF	\N	Aix-en-Provence	\N	\N	\N	\N	\N	MUNICIPAL	20248J	d'	\N	\N	\N	\N	\N
52455	2020-06-16 00:00:00	2020-06-16 00:00:00	\N	ACTIF	\N	Itteville	\N	\N	\N	\N	\N	MUNICIPAL	20298U	d'	\N	\N	\N	\N	\N
52454	2014-03-15 00:00:00	2014-03-15 00:00:00	2020-06-15 00:00:00	ANCIEN	\N	Yerres	\N	\N	\N	\N	\N	MUNICIPAL	20298U	de	\N	\N	\N	\N	\N
53156	2014-05-15 00:00:00	2014-05-15 00:00:00	\N	ACTIF	\N	Hudiviller	\N	\N	\N	\N	\N	MUNICIPAL	20980G	d'	\N	\N	\N	\N	\N
53371	1500-01-01 00:00:00	1500-01-01 00:00:00	\N	ACTIF	\N	Denain	\N	\N	1500	\N	1000	MUNICIPAL	21085M	de	\N	\N	\N	\N	2023-09-26 16:15:44
53389	1400-01-01 00:50:39	1499-12-31 00:50:39	2023-11-01 00:00:00	ANCIEN	\N	Dormans	\N	\N	\N	\N	1000	MUNICIPAL	21063F	de	\N	\N	\N	\N	2023-10-05 13:37:04
53394	1600-01-09 00:50:39	1600-01-09 00:50:39	\N	ACTIF	\N	Paris	\N	\N	\N	\N	0	MUNICIPAL	21089R	de	\N	\N	\N	\N	2023-09-26 11:53:44
53395	1500-01-01 00:00:00	1500-01-01 00:00:00	\N	ACTIF	\N	Saint-Denis	\N	\N	\N	\N	999	MUNICIPAL	21035B	de	\N	\N	\N	\N	2023-10-05 13:33:26
53398	1500-01-01 00:00:00	1500-01-01 00:00:00	1600-01-01 00:00:00	ANCIEN	\N	Saint-Denis	\N	\N	\N	\N	0	MUNICIPAL	21035B	de	\N	\N	\N	\N	2023-10-05 13:33:26
53404	1499-12-31 00:50:39	1499-12-31 00:50:39	1599-11-06 00:50:39	ANCIEN	\N	Saint-Ouen	\N	\N	\N	\N	1000	MUNICIPAL	21077M	de	\N	\N	\N	\N	2023-09-26 12:10:27
53422	1499-12-31 00:50:39	1499-12-31 00:50:39	2023-10-09 00:00:00	ANCIEN	\N	Cahors	\N	\N	\N	\N	1000	MUNICIPAL	21031W	de	\N	\N	\N	\N	2023-09-26 12:34:59
53425	1499-12-31 00:50:39	1499-12-31 00:50:39	1515-10-24 00:50:39	ANCIEN	\N	Saint-Léonard 	\N	\N	\N	\N	999	MUNICIPAL	21065H	de	\N	\N	\N	\N	2023-09-26 12:35:48
53434	1500-01-01 00:00:00	1499-12-31 00:50:39	\N	ACTIF	\N	Asnières-sur-Seine	\N	\N	1500	\N	1000	MUNICIPAL	21071F	d'	\N	\N	\N	\N	2023-10-05 13:27:04
53438	1499-12-31 00:50:39	1499-12-31 00:50:39	\N	ACTIF	\N	Saint-Jean-de-la-Ruelle 	\N	\N	\N	\N	1000	MUNICIPAL	21057H	de	\N	\N	\N	\N	2023-09-26 15:22:01
53442	1499-12-31 00:50:39	1499-12-31 00:50:39	1599-11-06 00:50:39	ANCIEN	\N	Sucy-en-Brie	\N	\N	\N	\N	1000	MUNICIPAL	21072G	de	\N	\N	\N	\N	2023-09-26 15:26:15
53446	1499-12-31 00:50:39	1499-12-31 00:50:39	1599-11-06 00:50:39	ANCIEN	\N	Vannes	\N	\N	\N	\N	1000	MUNICIPAL	21051B	de	\N	\N	\N	\N	2023-09-26 15:30:51
53451	1499-12-31 00:50:39	2023-11-06 00:00:00	\N	ACTIF	\N	Paris	\N	\N	\N	\N	1000	MUNICIPAL	21094N	de	\N	\N	\N	\N	2023-09-26 15:37:36
53455	1500-01-01 00:00:00	1500-01-01 00:00:00	1600-01-01 00:00:00	ANCIEN	\N	Nantes	\N	\N	1500	1600	0	MUNICIPAL	18395Y	de	\N	\N	\N	\N	2023-09-26 15:38:53
53458	1499-12-31 00:50:39	1499-12-31 00:50:39	1599-11-06 00:50:39	ANCIEN	\N	Liévin	\N	\N	\N	\N	1000	MUNICIPAL	21067K	de	\N	\N	\N	\N	2023-10-02 00:22:24
53474	1499-12-31 00:50:39	1499-12-31 00:50:39	1515-10-25 00:50:39	ANCIEN	\N	Téteghem-Coudekerque-Village	\N	\N	\N	\N	1000	MUNICIPAL	15197G	de	\N	\N	\N	\N	2023-09-26 15:52:26
53466	2023-11-06 00:00:00	2023-11-06 00:00:00	\N	ACTIF	\N	Martel	\N	\N	\N	\N	1000	MUNICIPAL	21041Y	de	\N	\N	\N	\N	2023-10-09 08:47:38
12948	2008-03-16 00:00:00	2008-03-16 00:00:00	\N	ACTIF	\N	Brive-la-Gaillarde	\N	\N	\N	\N	0	MUNICIPAL	14002L	de	\N	\N	\N	2014-02-14 17:34:40	2014-04-07 16:20:02
13800	\N	1977-01-08 00:00:00	\N	ANCIEN	\N	Nedde	\N	\N	1977	1984	\N	MUNICIPAL	14028W	de	\N	\N	\N	2014-09-16 11:40:28	2014-09-16 11:42:24
50880	2001-03-18 00:00:00	\N	\N	ACTIF	\N	Saint-Paulien	\N	\N	\N	\N	\N	MUNICIPAL	19507S	de	\N	\N	\N	2017-09-20 10:50:04	2017-09-24 14:07:58
13813	\N	\N	\N	ACTIF	\N	Couzeix	\N	\N	\N	\N	\N	MUNICIPAL	14034U	de	\N	\N	\N	2014-09-16 17:00:28	2017-11-15 10:08:48
50882	2001-03-18 00:00:00	\N	2017-10-20 00:00:00	ANCIEN	\N	Olivet	\N	\N	\N	\N	\N	MUNICIPAL	19421M	d'	\N	\N	\N	2017-09-20 10:53:17	2017-09-24 18:05:10
13854	2008-03-21 00:00:00	\N	\N	ACTIF	\N	Caussade	\N	\N	\N	\N	\N	MUNICIPAL	14069U	de	\N	\N	\N	2014-09-17 17:34:18	2017-11-09 10:21:41
13855	\N	\N	2020-05-24 00:00:00	ANCIEN	\N	Moncoutant	\N	\N	2008	\N	\N	MUNICIPAL	14071N	de	\N	\N	\N	2014-09-17 17:35:33	2014-09-17 17:45:03
13998	1993-04-18 00:00:00	\N	2020-06-28 00:00:00	ANCIEN	\N	Montendre	\N	\N	\N	\N	\N	MUNICIPAL	14159V	de	\N	\N	\N	2014-09-18 18:04:23	2014-09-29 10:32:07
14049	1977-03-30 00:00:00	1977-04-01 00:00:00	2001-03-30 00:00:00	ANCIEN	\N	Le Lonzac	\N	\N	\N	\N	\N	MUNICIPAL	14195A	\N	\N	\N	\N	2014-09-28 12:51:31	2014-09-30 11:21:37
14051	2001-04-01 00:00:00	\N	\N	ACTIF	\N	Chamberet	\N	\N	\N	\N	\N	MUNICIPAL	14195A	de 	\N	\N	\N	2014-09-28 12:52:48	2014-09-28 12:53:50
14196	2014-03-30 00:00:00	2014-03-30 00:00:00	\N	ACTIF	\N	Toulouse	\N	\N	\N	\N	\N	MUNICIPAL	14223L	de	\N	\N	\N	2014-09-28 17:47:24	2014-09-28 17:56:27
14228	1989-03-01 00:00:00	\N	2020-03-15 00:00:00	ANCIEN	\N	Boulogne-sur-Gesse	\N	\N	\N	\N	\N	MUNICIPAL	14221J	de	\N	\N	\N	2014-09-28 18:00:47	2017-11-22 10:21:54
14308	2008-03-16 00:00:00	\N	\N	ACTIF	\N	Guilherand-Granges	\N	\N	\N	\N	\N	MUNICIPAL	14259Y	de	\N	\N	\N	2014-09-28 19:32:07	2018-01-23 18:51:45
14344	2001-03-20 00:00:00	\N	\N	ACTIF	\N	Châteaugiron	\N	\N	\N	\N	\N	MUNICIPAL	14231L	de	\N	\N	\N	2014-09-30 10:38:49	2017-12-01 14:54:47
14392	\N	\N	\N	ACTIF	\N	Talange	\N	\N	1989	\N	\N	MUNICIPAL	14263U	de 	\N	\N	\N	2014-12-18 16:30:09	2014-12-18 16:30:45
15136	2001-03-04 00:00:00	2001-03-01 00:00:00	\N	ACTIF	\N	Aubervilliers	\N	\N	\N	\N	\N	MUNICIPAL	14269B	d'	\N	\N	\N	2015-03-04 14:33:10	2015-03-04 16:45:40
15234	1989-03-01 00:00:00	\N	2016-11-30 00:00:00	ANCIEN	\N	Chalinargues	\N	\N	\N	\N	\N	MUNICIPAL	14327T	de 	\N	\N	\N	2015-09-07 16:16:55	2018-01-08 20:22:41
15287	2016-01-02 00:00:00	2016-01-02 00:00:00	2020-06-30 00:00:00	ANCIEN	\N	Le Montsaugeonnais	\N	\N	\N	\N	\N	MUNICIPAL	01057W	de	\N	\N	\N	2016-04-18 17:35:21	2018-02-22 16:04:06
15338	2008-03-09 00:00:00	2008-03-09 00:00:00	\N	ACTIF	\N	Aubepierre-Ozouer-le-Repos	\N	\N	\N	\N	\N	MUNICIPAL	14357A	d'	\N	\N	\N	2016-12-01 10:41:34	2018-01-23 18:48:40
50742	2014-03-24 00:00:00	2014-03-24 00:00:00	\N	ACTIF	\N	Villeneuve-Saint-Georges	\N	\N	\N	\N	\N	MUNICIPAL	19285X	de	\N	\N	\N	2017-07-31 12:14:14	2017-07-31 12:15:22
50915	2014-03-30 00:00:00	\N	\N	ACTIF	\N	Biars-sur-Cère	\N	\N	\N	\N	\N	MUNICIPAL	19503N	de	\N	\N	\N	2017-09-20 12:11:54	2017-09-20 12:12:23
50943	1989-03-19 00:00:00	\N	2020-06-28 00:00:00	ANCIEN	\N	Saint-Priest-Bramefant	\N	\N	\N	\N	\N	MUNICIPAL	19387D	de	\N	\N	\N	2017-09-20 16:04:52	2018-01-24 11:11:41
50962	2001-03-18 00:00:00	\N	\N	ACTIF	\N	Limours	\N	\N	\N	\N	\N	MUNICIPAL	19399H	de	\N	\N	\N	2017-09-20 17:09:53	2018-01-12 14:56:39
50999	1995-03-19 00:00:00	1995-03-19 00:00:00	\N	ACTIF	\N	Tourcoing	\N	\N	\N	\N	\N	MUNICIPAL	19581D	de	\N	\N	\N	2017-09-22 10:17:42	2017-09-25 17:40:06
51003	1995-06-18 00:00:00	1995-06-18 00:00:00	2018-04-15 00:00:00	ANCIEN	\N	Lesquin	\N	\N	\N	\N	\N	MUNICIPAL	19585H	de	\N	\N	\N	2017-09-22 10:28:59	2018-01-24 19:38:35
51011	1995-06-18 00:00:00	1995-06-18 00:00:00	\N	ACTIF	\N	Saint-Raphaël	\N	\N	\N	\N	\N	MUNICIPAL	15447F	de	\N	\N	\N	2017-09-22 11:04:27	2018-02-16 16:13:26
51248	2008-03-16 00:00:00	2008-03-16 00:00:00	\N	ACTIF	\N	Lachapelle-aux-Pots	\N	\N	\N	\N	\N	MUNICIPAL	19677L	de	\N	\N	\N	2017-09-24 18:33:38	2017-09-24 18:34:58
51260	\N	2003-03-16 00:00:00	\N	ANCIEN	\N	Agnetz	\N	\N	2003	2015	\N	MUNICIPAL	11115U	d'	\N	\N	\N	2017-09-24 18:51:26	2017-09-25 14:28:35
51313	2001-03-18 00:00:00	2001-03-18 00:00:00	\N	ACTIF	\N	Oignies	\N	\N	\N	\N	\N	MUNICIPAL	19681G	de	\N	\N	\N	2017-09-24 19:41:29	2017-11-13 11:28:50
51347	1995-03-19 00:00:00	1995-03-19 00:00:00	2008-03-15 00:00:00	ANCIEN	\N	Chissay-en-Touraine	\N	\N	\N	\N	\N	MUNICIPAL	19511N	de	\N	\N	\N	2017-09-24 20:34:19	2017-09-26 18:06:47
51359	2001-03-11 00:00:00	2001-03-11 00:00:00	\N	ACTIF	\N	Alès	\N	\N	\N	\N	\N	MUNICIPAL	16431B	d'	\N	\N	\N	2017-09-25 10:06:54	2017-09-25 10:08:36
51527	2001-03-18 00:00:00	2001-03-18 00:00:00	2011-01-01 00:00:00	ANCIEN	\N	Senlis	\N	\N	\N	\N	\N	MUNICIPAL	19741B	de	\N	\N	\N	2017-11-24 22:00:29	2017-11-24 22:02:10
51653	2001-03-18 00:00:00	2001-03-18 00:00:00	\N	ACTIF	\N	Épernon	\N	\N	\N	\N	\N	MUNICIPAL	19794Q	d'	\N	\N	\N	\N	\N
52018	2014-03-15 00:00:00	2020-03-15 00:00:00	\N	ACTIF	\N	Saint-Rémy-l'Honoré	\N	\N	\N	\N	\N	MUNICIPAL	20152B	de	\N	\N	\N	\N	\N
52028	1983-03-15 00:00:00	1983-03-15 00:00:00	2020-10-15 00:00:00	ANCIEN	\N	Rouillac 	\N	\N	\N	\N	\N	MUNICIPAL	20042V	de	\N	\N	\N	\N	\N
52035	2020-06-28 00:00:00	2020-06-28 00:00:00	\N	ACTIF	\N	Camon	\N	\N	\N	\N	\N	MUNICIPAL	20060X	de	\N	\N	\N	\N	\N
52036	2014-03-27 00:00:00	2014-03-15 00:00:00	\N	ACTIF	\N	Arnage	\N	\N	\N	\N	\N	MUNICIPAL	20070A	d'	\N	\N	\N	\N	\N
52038	2001-03-15 00:00:00	2001-03-15 00:00:00	\N	ACTIF	\N	Talence	\N	\N	\N	\N	\N	MUNICIPAL	20142Y	de	\N	\N	\N	\N	\N
52041	1989-03-15 00:00:00	1989-03-15 00:00:00	\N	ACTIF	\N	Albert	\N	\N	\N	\N	\N	MUNICIPAL	17229F	d'	\N	\N	\N	\N	\N
52044	2020-06-15 00:00:00	2020-06-15 00:00:00	\N	ACTIF	\N	Lyon 7e arrondissement	\N	\N	\N	\N	\N	MUNICIPAL	20134Y	de	\N	\N	\N	\N	\N
52046	1989-03-15 00:00:00	1989-03-15 00:00:00	\N	ACTIF	\N	Tourrenquets	\N	\N	\N	\N	\N	MUNICIPAL	20040T	de	\N	\N	\N	\N	\N
52050	1995-03-15 00:00:00	1995-03-15 00:00:00	2001-03-14 00:00:00	ANCIEN	\N	Saint-Brieuc	\N	\N	\N	\N	\N	MUNICIPAL	20102Q	de	\N	\N	\N	\N	\N
52051	2014-03-15 00:00:00	2014-03-15 00:00:00	\N	ACTIF	\N	Vals-les-Bains	\N	\N	\N	\N	\N	MUNICIPAL	20026V	de	\N	\N	\N	\N	\N
52196	2014-04-15 00:00:00	2014-04-15 00:00:00	2020-06-15 00:00:00	ANCIEN	\N	Marseille	\N	\N	\N	\N	\N	MUNICIPAL	12028B	de	\N	\N	\N	\N	\N
52217	2001-03-15 00:00:00	\N	2020-07-15 00:00:00	ANCIEN	\N	Duilhac sous Peyrepertuse	\N	\N	\N	\N	\N	MUNICIPAL	20030R	de	\N	\N	\N	\N	\N
52223	1995-06-15 00:00:00	\N	2020-10-15 00:00:00	ANCIEN	\N	Buchy	\N	\N	\N	\N	1111	MUNICIPAL	20144B	de	\N	\N	\N	\N	\N
52232	1995-03-15 00:00:00	1995-03-15 00:00:00	\N	ACTIF	\N	Durmenach	\N	\N	\N	\N	999	MUNICIPAL	20124W	de	\N	\N	\N	\N	\N
52235	2001-03-15 00:00:00	2020-03-15 00:00:00	\N	ACTIF	\N	Geispolsheim	\N	\N	\N	\N	1111	MUNICIPAL	20100N	de	\N	\N	\N	\N	\N
52238	1989-03-15 00:00:00	\N	\N	ACTIF	\N	Saint Pierre de Trivisy	\N	\N	\N	\N	999	MUNICIPAL	17023S	de	\N	\N	\N	\N	\N
52244	2016-11-15 00:00:00	\N	2020-09-15 00:00:00	ANCIEN	\N	Remiremont	\N	\N	\N	\N	\N	MUNICIPAL	20048C	de	\N	\N	\N	\N	\N
52245	1995-03-15 00:00:00	\N	\N	ACTIF	\N	Houssen	\N	\N	\N	\N	\N	MUNICIPAL	20126Y	d'	\N	\N	\N	\N	\N
52255	2014-03-15 00:00:00	\N	2020-10-26 00:00:00	ANCIEN	\N	Saint Agne	\N	\N	\N	\N	\N	MUNICIPAL	20028X	de	\N	\N	\N	\N	\N
52271	2014-03-15 00:00:00	2014-03-15 00:00:00	2020-10-15 00:00:00	ANCIEN	\N	Crécy-sur-Serre	\N	\N	\N	\N	1111	MUNICIPAL	20122U	de	\N	\N	\N	\N	\N
52303	2008-03-15 00:00:00	2020-06-15 00:00:00	\N	ACTIF	\N	Nantes	\N	\N	\N	\N	1111	MUNICIPAL	20172F	de	\N	\N	\N	\N	\N
52329	2001-03-15 00:00:00	2020-03-15 00:00:00	2020-11-15 00:00:00	ANCIEN	\N	Migennes	\N	\N	\N	\N	1111	MUNICIPAL	20174H	de	\N	\N	\N	\N	\N
52401	2014-03-15 00:00:00	\N	2021-07-14 00:00:00	ANCIEN	\N	Buhl-Lorraine	\N	\N	\N	\N	\N	MUNICIPAL	19954N	de 	\N	\N	\N	\N	\N
53487	1499-12-31 00:50:39	1499-12-31 00:50:39	\N	ACTIF	\N	Cherbourg-en-Cotentin	\N	\N	\N	\N	1000	MUNICIPAL	21062E	de	\N	\N	\N	\N	2023-09-26 15:56:56
53489	1499-12-31 00:50:39	1499-12-31 00:50:39	1515-10-13 00:50:39	ANCIEN	\N	Langeais	\N	\N	\N	\N	1000	MUNICIPAL	21056G	de	\N	\N	\N	\N	2023-09-26 15:56:56
13899	1995-06-18 00:00:00	\N	\N	ACTIF	\N	Troyes	\N	\N	\N	\N	\N	MUNICIPAL	05004A	de	\N	\N	\N	2014-09-18 11:21:44	2014-09-29 14:34:21
13900	1989-05-07 00:00:00	\N	1993-05-16 00:00:00	ANCIEN	\N	Nogent-sur-Seine	\N	\N	\N	\N	\N	MUNICIPAL	05004A	de	\N	\N	\N	2014-09-18 11:22:08	2014-09-29 15:51:38
13920	\N	\N	\N	ANCIEN	\N	Saint-Geniez-d'Olt	\N	\N	1996	2010	\N	MUNICIPAL	14103D	de	\N	\N	\N	2014-09-18 11:53:07	2014-09-18 11:54:23
13919	\N	\N	\N	ANCIEN	\N	Pierrefiche	\N	\N	1983	1995	\N	MUNICIPAL	14103D	de	\N	\N	\N	2014-09-18 11:52:03	2014-09-18 11:53:03
13935	\N	\N	\N	ACTIF	\N	Ayssènes	\N	\N	2001	\N	999	MUNICIPAL	14111D	d'	\N	\N	\N	2014-09-18 12:02:15	2014-09-30 10:51:43
50921	2001-03-18 00:00:00	\N	2017-10-31 00:00:00	ANCIEN	\N	Port-Louis	\N	\N	\N	\N	\N	MUNICIPAL	19447X	de	\N	\N	\N	2017-09-20 14:31:16	2017-11-28 14:46:37
13957	\N	\N	2016-01-01 00:00:00	ANCIEN	\N	Condé-sur-Noireau	\N	\N	1995	\N	\N	MUNICIPAL	14133K	de	\N	\N	\N	2014-09-18 14:41:20	2016-06-10 11:23:59
13961	2008-03-10 00:00:00	\N	2020-06-28 00:00:00	ANCIEN	\N	Luxeuil-les-Bains	\N	\N	\N	\N	\N	MUNICIPAL	14135M	de	2015-12-31 00:00:00	\N	\N	2014-09-18 14:45:15	2017-11-09 11:32:16
13962	\N	\N	\N	ACTIF	\N	Mézidon-Canon	\N	\N	1995	\N	\N	MUNICIPAL	14137P	de	\N	\N	\N	2014-09-18 14:45:39	2014-09-18 14:47:01
13997	1992-04-02 00:00:00	\N	2016-09-15 00:00:00	ANCIEN	\N	Pleudihen-sur-Rance	\N	\N	\N	\N	\N	MUNICIPAL	14157T	de	\N	\N	\N	2014-09-18 17:35:57	2016-09-30 11:38:58
14021	1983-03-06 00:00:00	\N	1989-03-12 00:00:00	ANCIEN	\N	Chambéry	\N	\N	\N	\N	\N	MUNICIPAL	14175V	de	\N	\N	\N	2014-09-22 14:36:45	2014-09-22 14:37:19
14078	\N	\N	\N	ANCIEN	\N	Penta-di-Casinca	\N	\N	1982	2010	\N	MUNICIPAL	14201E	de	\N	\N	\N	2014-09-28 15:46:08	2014-09-30 16:23:25
14082	\N	\N	\N	ACTIF	\N	Trèbes	\N	\N	2001	\N	\N	MUNICIPAL	14097Y	de	\N	\N	\N	2014-09-28 16:04:53	2014-09-28 16:05:34
14224	\N	2008-04-01 00:00:00	2016-08-18 00:00:00	ANCIEN	\N	Arthaz-Pont-Notre-Dame	\N	\N	2008	\N	\N	MUNICIPAL	14237S	d'	\N	\N	\N	2014-09-28 17:59:11	2017-02-09 16:13:07
14253	2008-03-17 00:00:00	\N	2014-03-17 00:00:00	ANCIEN	\N	Nagel-Séez-Mesnil	\N	\N	\N	\N	\N	MUNICIPAL	14249W	de	\N	\N	\N	2014-09-28 18:27:06	2014-10-02 10:54:47
14276	1989-03-20 00:00:00	\N	\N	ACTIF	\N	Vichy	\N	\N	\N	\N	\N	MUNICIPAL	14251Q	de	\N	\N	\N	2014-09-28 18:48:13	2014-09-28 18:56:54
50934	2014-03-16 00:00:00	2016-01-05 00:00:00	\N	ACTIF	\N	Putanges-le-Lac	\N	\N	\N	\N	\N	MUNICIPAL	19483C	de	\N	\N	\N	2017-09-20 15:31:56	2017-09-25 17:52:29
50937	1989-03-19 00:00:00	1989-03-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	Laqueuille	\N	\N	\N	\N	\N	MUNICIPAL	19383Y	de	\N	\N	\N	2017-09-20 15:45:36	2017-09-27 10:40:52
51266	2001-03-18 00:00:00	2001-03-18 00:00:00	2020-03-31 00:00:00	ANCIEN	\N	Paris 16ème	\N	\N	\N	\N	\N	MUNICIPAL	19643A	de	\N	\N	\N	2017-09-24 18:56:10	2018-01-10 14:38:32
51263	2001-03-18 00:00:00	2001-03-18 00:00:00	2017-10-18 00:00:00	ANCIEN	\N	Xème arrondissement de Paris	\N	\N	\N	\N	\N	MUNICIPAL	19647E	du	\N	\N	\N	2017-09-24 18:53:19	2018-04-03 16:19:03
51281	2014-03-30 00:00:00	2014-03-30 00:00:00	2017-10-06 00:00:00	ANCIEN	\N	Paris	\N	\N	\N	\N	\N	MUNICIPAL	19683J	de	\N	\N	\N	2017-09-24 19:11:05	2018-05-30 10:05:29
51283	2001-04-02 00:00:00	2001-04-02 00:00:00	2014-03-29 00:00:00	ANCIEN	\N	XIXème arrondissement de Paris	\N	\N	\N	\N	\N	MUNICIPAL	19683J	du	\N	\N	\N	2017-09-24 19:14:06	2017-09-24 19:15:50
51781	2020-06-28 00:00:00	\N	2020-09-02 00:00:00	ANCIEN	\N	La Ciotat	\N	\N	\N	\N	\N	MUNICIPAL	19966S	de	\N	\N	\N	\N	\N
51325	2008-03-16 00:00:00	2008-03-16 00:00:00	2012-06-18 00:00:00	ANCIEN	\N	Château-Gontier	\N	\N	\N	\N	\N	MUNICIPAL	18083K	de	\N	\N	\N	2017-09-24 19:59:09	2017-09-24 20:01:09
51369	1989-03-19 00:00:00	2001-03-19 00:00:00	2005-04-29 00:00:00	ANCIEN	\N	Vieux-Habitants	\N	\N	\N	\N	\N	MUNICIPAL	12016W	de	\N	\N	\N	2017-09-25 11:15:52	2017-09-25 11:27:45
51391	2001-03-18 00:00:00	2001-03-18 00:00:00	2008-03-15 00:00:00	ANCIEN	\N	Alençon	\N	\N	\N	\N	\N	MUNICIPAL	19483C	d'	\N	\N	\N	2017-09-25 17:52:39	2017-09-25 17:53:31
51374	2008-03-16 00:00:00	2014-03-30 00:00:00	2017-11-01 00:00:00	ANCIEN	\N	Morne-à-l'Eau	\N	\N	\N	\N	\N	MUNICIPAL	19715Y	de	\N	\N	\N	2017-09-25 11:42:43	2017-09-28 11:40:26
51392	1995-03-19 00:00:00	1995-03-19 00:00:00	2001-03-17 00:00:00	ANCIEN	\N	Putanges-Pont-Ecrepin 	\N	\N	\N	\N	\N	MUNICIPAL	19483C	de	\N	\N	\N	2017-09-25 17:53:44	2017-09-25 17:54:38
51417	2012-06-23 00:00:00	\N	2015-12-31 00:00:00	ANCIEN	\N	Cherbourg-Octeville	\N	\N	\N	\N	\N	MUNICIPAL	19333N	de	\N	\N	\N	2017-09-26 17:52:02	2017-09-26 17:52:39
52214	\N	2020-03-15 00:00:00	\N	ACTIF	\N	Althen des Paluds	\N	\N	2001	\N	1111	MUNICIPAL	20084G	d'	\N	\N	\N	\N	\N
52215	1989-03-15 00:00:00	\N	2001-03-15 00:00:00	ANCIEN	\N	Cabrières d'Aigues	\N	\N	\N	\N	\N	MUNICIPAL	20084G	de	\N	\N	\N	\N	\N
52436	2014-04-01 00:00:00	2014-04-01 00:00:00	2021-07-01 00:00:00	ANCIEN	\N	Blanc-Mesnil	\N	\N	\N	\N	\N	MUNICIPAL	20252E	du	\N	\N	\N	\N	\N
53382	1500-01-01 00:00:00	1500-01-01 00:00:00	1600-01-01 00:00:00	ANCIEN	\N	Grand-Champ	\N	\N	1500	1600	0	MUNICIPAL	21050A	de	\N	\N	\N	\N	2023-09-26 11:05:43
53418	1499-12-31 00:50:39	1499-12-31 00:50:39	1599-11-06 00:50:39	ANCIEN	\N	Melun	\N	\N	\N	\N	1000	MUNICIPAL	21076L	de	\N	\N	\N	\N	2023-09-26 12:21:13
53482	1500-01-01 00:00:00	1500-01-01 00:00:00	1600-01-01 00:00:00	ANCIEN	\N	Orsay	\N	\N	1500	1600	0	MUNICIPAL	21059K	d'	\N	\N	\N	\N	2023-09-26 15:53:35
53503	1500-01-01 00:00:00	1499-12-31 00:50:39	1600-01-01 00:00:00	ANCIEN	\N	Andilly	\N	\N	1500	1600	0	MUNICIPAL	21086N	d'	\N	\N	\N	\N	2023-09-26 16:01:34
53506	1499-12-31 00:50:39	1499-12-31 00:50:39	1599-11-06 00:50:39	ANCIEN	\N	Boën-sur-Lignon	\N	\N	\N	\N	1000	MUNICIPAL	21070E	de	\N	\N	\N	\N	2023-09-26 16:03:59
53517	1500-01-01 00:00:00	1500-01-01 00:00:00	1600-01-01 00:00:00	ANCIEN	\N	Saint-Nazaire	\N	\N	1500	1600	0	MUNICIPAL	21066J	de	\N	\N	\N	\N	2023-10-09 12:25:54
53521	1615-01-09 00:50:39	1615-01-09 00:50:39	1630-11-13 00:50:39	ANCIEN	\N	Saint-Chamond	\N	\N	\N	\N	1000	MUNICIPAL	21068L	de	\N	\N	\N	\N	2023-10-05 09:31:16
53524	1500-01-01 00:00:00	1499-12-31 00:50:39	1600-01-01 00:00:00	ANCIEN	\N	Saint-Chamond	\N	\N	1500	1600	0	MUNICIPAL	21068L	de	\N	\N	\N	\N	2023-10-05 09:31:16
53529	1600-01-09 00:50:39	1600-01-09 00:50:39	\N	ACTIF	\N	Paris	\N	\N	\N	\N	1000	MUNICIPAL	21092L	de	\N	\N	\N	\N	2023-09-26 16:13:44
53531	1500-01-01 00:00:00	1499-12-31 00:50:39	1600-01-01 00:00:00	ANCIEN	\N	Paris	\N	\N	1500	1600	0	MUNICIPAL	21092L	de	\N	\N	\N	\N	2023-09-26 16:13:44
53535	1500-01-01 00:00:00	1500-01-01 00:00:00	1600-01-01 00:00:00	ANCIEN	\N	Sainte-Marie-la-Mer	\N	\N	1500	1600	0	MUNICIPAL	21044C	de	\N	\N	\N	\N	2023-10-09 12:26:55
53536	1499-12-31 00:50:39	1499-12-31 00:50:39	2023-11-01 00:00:00	ANCIEN	\N	Brouckerque 	\N	\N	\N	\N	1000	MUNICIPAL	21087P	de	\N	\N	\N	\N	2023-09-26 16:22:20
53540	1499-12-31 00:50:39	1499-12-31 00:50:39	\N	ACTIF	\N	Cigogné	\N	\N	\N	\N	999	MUNICIPAL	21054E	de	\N	\N	\N	\N	2023-09-26 16:27:42
53547	1600-01-09 00:50:39	1600-01-09 00:50:39	2023-11-01 00:00:00	ANCIEN	\N	Saint-Avertin	\N	\N	\N	\N	1000	MUNICIPAL	21055F	de	\N	\N	\N	\N	2023-09-26 16:31:05
53551	1500-01-01 00:00:00	1500-01-01 00:00:00	1600-01-01 00:00:00	ANCIEN	\N	Saint-Avertin	\N	\N	1500	1600	0	MUNICIPAL	21055F	de	\N	\N	\N	\N	2023-09-26 16:31:05
53558	1499-12-31 00:50:39	1499-12-31 00:50:39	\N	ACTIF	\N	Mitry-Mory	\N	\N	\N	\N	1000	MUNICIPAL	21075K	de	\N	\N	\N	\N	2023-09-26 16:32:09
53561	1499-12-31 00:50:39	1499-12-31 00:50:39	1599-11-06 00:50:39	ANCIEN	\N	Villers-Saint-Paul	\N	\N	\N	\N	1000	MUNICIPAL	21060C	de	\N	\N	\N	\N	2023-09-26 16:41:45
53567	1499-12-31 00:50:39	1499-12-31 00:50:39	1515-10-23 00:50:39	ANCIEN	\N	Nogent	\N	\N	\N	\N	1000	MUNICIPAL	21039F	de	\N	\N	\N	\N	2023-09-26 16:44:46
53570	1400-01-01 00:50:39	1400-01-01 00:50:39	1499-12-22 00:50:39	ANCIEN	\N	Nogent	\N	\N	\N	\N	0	MUNICIPAL	21039F	de	\N	\N	\N	\N	2023-09-26 16:44:46
13752	2014-04-04 00:00:00	2014-03-30 00:00:00	\N	ACTIF	\N	Saint-Cirq-Lapopie	\N	\N	\N	\N	218	MUNICIPAL	92039X	de 	\N	\N	\N	2014-04-08 15:58:15	2014-04-08 15:59:48
13776	\N	\N	2014-04-01 00:00:00	ANCIEN	\N	Melun	\N	\N	2001	\N	0	MUNICIPAL	04057K	de	\N	\N	\N	2014-05-28 16:13:28	2014-05-28 16:15:20
13758	2014-04-01 00:00:00	\N	2016-08-31 00:00:00	ANCIEN	\N	Rouen	\N	\N	\N	\N	0	MUNICIPAL	04070G	de	\N	\N	\N	2014-04-29 18:18:38	2016-09-07 18:04:03
13853	1995-06-19 00:00:00	1995-06-19 00:00:00	\N	ACTIF	\N	Illkirch-Graffenstaden	\N	\N	\N	\N	\N	MUNICIPAL	14065Q	d'	\N	\N	\N	2014-09-17 17:33:16	2017-01-11 16:25:27
13859	1995-06-01 00:00:00	2008-03-18 00:00:00	2021-07-22 00:00:00	ANCIEN	\N	Gries	\N	\N	\N	\N	\N	MUNICIPAL	14073Q	de	\N	\N	\N	2014-09-17 17:41:08	2017-11-15 13:12:13
13879	2001-03-19 00:00:00	2001-03-19 00:00:00	2020-06-28 00:00:00	ANCIEN	\N	Meyzieu	\N	\N	\N	\N	\N	MUNICIPAL	14087W	de	\N	\N	\N	2014-09-18 10:45:37	2017-10-04 09:57:57
13882	1995-06-25 00:00:00	\N	2001-03-18 00:00:00	ANCIEN	\N	Lescure d'Albigeois	\N	\N	\N	\N	\N	MUNICIPAL	14085U	de	\N	\N	\N	2014-09-18 10:52:46	2014-09-18 10:54:18
13887	\N	\N	2018-12-17 00:00:00	ANCIEN	\N	Albi	\N	\N	1995	\N	\N	MUNICIPAL	14089Y	d'	\N	\N	\N	2014-09-18 11:04:42	2014-09-18 11:06:17
13907	\N	\N	\N	ANCIEN	\N	Bermesnil	\N	\N	1980	2000	\N	MUNICIPAL	14093U	de	\N	\N	\N	2014-09-18 11:38:03	2014-09-18 12:03:55
13930	\N	\N	\N	ANCIEN	\N	Oisemont	\N	\N	2001	2008	\N	MUNICIPAL	14093U	d'	\N	\N	\N	2014-09-18 12:00:15	2014-09-18 12:04:19
13939	\N	\N	\N	ANCIEN	\N	Brusquet	\N	\N	1995	2010	\N	MUNICIPAL	14107H	du	\N	\N	\N	2014-09-18 12:07:12	2014-09-18 12:08:54
50813	1995-06-18 00:00:00	1995-06-18 00:00:00	2017-10-12 00:00:00	ANCIEN	\N	Fréthun	\N	\N	\N	\N	\N	MUNICIPAL	19521Q	de	\N	\N	\N	2017-09-19 16:03:36	2017-12-21 14:15:07
50824	2002-06-30 00:00:00	2002-06-30 00:00:00	2017-10-11 00:00:00	ANCIEN	\N	Barlin	\N	\N	\N	\N	\N	MUNICIPAL	19525U	de	\N	\N	\N	2017-09-19 16:34:14	2017-09-24 19:16:35
13950	\N	\N	2014-12-27 00:00:00	ANCIEN	\N	Chabottes	\N	\N	1977	\N	\N	MUNICIPAL	14129P	de	\N	\N	\N	2014-09-18 12:22:58	2014-12-29 15:40:09
14056	1985-01-06 00:00:00	1985-01-06 00:00:00	2017-11-03 00:00:00	ANCIEN	\N	Arnave	\N	\N	\N	\N	\N	MUNICIPAL	14197C	d'	\N	\N	\N	2014-09-28 12:58:10	2017-11-30 15:07:52
14413	\N	\N	\N	ACTIF	\N	Saint-Romain-Lachalm	\N	\N	1995	\N	999	MUNICIPAL	14267Y	de 	\N	\N	\N	2015-01-27 10:32:19	2015-01-27 10:33:10
14358	\N	\N	2014-03-17 00:00:00	ANCIEN	\N	Saint-Martin	\N	\N	2001	\N	\N	MUNICIPAL	14261S	de	\N	\N	\N	2014-09-30 14:38:38	2014-09-30 14:39:11
15203	\N	\N	2015-07-24 00:00:00	ANCIEN	\N	Caen	\N	\N	\N	\N	\N	MUNICIPAL	14281W	de 	\N	\N	\N	2015-06-12 15:39:31	2015-07-27 15:34:41
50827	2001-03-18 00:00:00	2001-03-18 00:00:00	2020-06-28 00:00:00	ANCIEN	\N	Dourges	\N	\N	\N	\N	\N	MUNICIPAL	19527W	de	\N	\N	\N	2017-09-19 16:42:15	2018-06-06 10:15:45
50837	1983-03-13 00:00:00	1983-03-13 00:00:00	2018-01-01 00:00:00	ANCIEN	\N	Ouroux-en-Morvan	\N	\N	\N	\N	\N	MUNICIPAL	19531S	d'	\N	\N	\N	2017-09-19 17:07:09	2018-01-02 10:59:44
50842	2001-03-18 00:00:00	2014-03-23 00:00:00	2020-03-15 00:00:00	ANCIEN	\N	Montreuil-Juigné	\N	\N	\N	\N	\N	MUNICIPAL	19533U	de	\N	\N	\N	2017-09-19 17:19:31	2018-04-26 14:57:51
50863	2005-06-26 00:00:00	2005-06-26 00:00:00	2017-10-24 00:00:00	ANCIEN	\N	Bailly-Romainvilliers	\N	\N	\N	\N	\N	MUNICIPAL	19543W	de	\N	\N	\N	2017-09-19 18:06:53	2017-11-09 17:53:49
50872	2008-03-16 00:00:00	\N	\N	ACTIF	\N	Saint-Marcel-de-Félines	\N	\N	\N	\N	\N	MUNICIPAL	19413M	de	\N	\N	\N	2017-09-19 18:40:34	2018-02-19 16:52:27
50873	1989-03-19 00:00:00	\N	2008-03-15 00:00:00	ANCIEN	\N	Bourg-Argental	\N	\N	\N	\N	\N	MUNICIPAL	19415P	de	\N	\N	\N	2017-09-19 18:43:03	2017-09-19 18:44:21
50967	2008-03-16 00:00:00	2008-03-16 00:00:00	\N	ACTIF	\N	Percy	\N	\N	\N	\N	\N	MUNICIPAL	19347U	du	\N	\N	\N	2017-09-21 17:13:05	2017-11-09 15:57:05
50968	2014-03-30 00:00:00	2014-03-30 00:00:00	2017-10-24 00:00:00	ANCIEN	\N	Grand-Lemps	\N	\N	\N	\N	\N	MUNICIPAL	19349W	du	\N	\N	\N	2017-09-21 17:19:23	2017-12-04 19:10:17
50985	1995-03-19 00:00:00	1995-03-19 00:00:00	\N	ACTIF	\N	Lafox	\N	\N	\N	\N	\N	MUNICIPAL	19367Y	de	\N	\N	\N	2017-09-21 17:53:48	2018-05-30 16:12:12
51027	1995-06-18 00:00:00	\N	\N	ACTIF	\N	Vincennes	\N	\N	\N	\N	\N	MUNICIPAL	19611R	de	\N	\N	\N	2017-09-22 11:46:28	2018-02-09 10:01:27
51349	1995-06-11 00:00:00	1995-06-11 00:00:00	2014-03-22 00:00:00	ANCIEN	\N	Lille	\N	\N	\N	\N	\N	MUNICIPAL	19599P	de	\N	\N	\N	2017-09-24 20:35:27	2017-09-26 11:57:08
51334	2012-09-27 00:00:00	\N	2017-10-01 00:00:00	ANCIEN	\N	Hellemmes	\N	\N	\N	\N	\N	MUNICIPAL	19637C	d'	\N	\N	\N	2017-09-24 20:14:22	2017-11-09 14:34:12
51095	2001-03-18 00:00:00	2001-03-18 00:00:00	2015-03-18 00:00:00	ANCIEN	\N	Saint-Denis	\N	\N	\N	\N	\N	MUNICIPAL	19577H	de	\N	\N	\N	2017-09-24 16:59:52	2017-09-24 17:03:12
51268	2008-03-16 00:00:00	2008-03-16 00:00:00	\N	ACTIF	\N	Saint-Germain-en-Laye	\N	\N	\N	\N	\N	MUNICIPAL	19701S	de	\N	\N	\N	2017-09-24 18:57:55	2017-09-24 19:07:48
51280	2001-03-18 00:00:00	2001-03-18 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	Montigny-le-Bretonneux	\N	\N	\N	\N	\N	MUNICIPAL	19699S	de	\N	\N	\N	2017-09-24 19:09:13	2018-01-18 11:05:51
51292	2008-03-16 00:00:00	2008-03-16 00:00:00	\N	ACTIF	\N	Versailles	\N	\N	\N	\N	\N	MUNICIPAL	19697Q	de	\N	\N	\N	2017-09-24 19:18:53	2017-09-24 19:20:01
51351	1989-03-24 00:00:00	1989-03-24 00:00:00	2014-03-01 00:00:00	ANCIEN	\N	Lille	\N	\N	\N	\N	\N	MUNICIPAL	14021P	de	\N	\N	\N	2017-09-24 20:43:46	2017-09-24 20:45:18
51457	1983-09-13 00:00:00	1983-09-13 00:00:00	\N	ACTIF	\N	Talence	\N	\N	\N	\N	\N	MUNICIPAL	19721W	de	\N	\N	\N	2017-10-01 09:45:52	2017-11-21 18:27:54
51463	2014-03-30 00:00:00	2014-03-30 00:00:00	\N	ACTIF	\N	Saint-Macaire	\N	\N	\N	\N	\N	MUNICIPAL	19723Y	de	\N	\N	\N	2017-10-01 10:08:19	2017-10-01 10:09:38
51465	2008-03-16 00:00:00	2008-03-16 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	Noaillan	\N	\N	\N	\N	\N	MUNICIPAL	19725B	de	\N	\N	\N	2017-10-01 10:45:40	2017-11-15 10:00:04
51469	2014-03-30 00:00:00	2014-03-30 00:00:00	\N	ACTIF	\N	La Flèche	\N	\N	\N	\N	\N	MUNICIPAL	19727D	de	\N	\N	\N	2017-10-01 10:55:00	2018-04-18 15:13:34
51473	1995-06-18 00:00:00	1995-06-18 00:00:00	\N	ACTIF	\N	Mandelieu-la-Napoule	\N	\N	\N	\N	\N	MUNICIPAL	19729F	de	\N	\N	\N	2017-10-01 11:03:42	2018-02-06 14:47:10
12940	1997-01-01 00:00:00	1997-01-01 00:00:00	2021-07-02 00:00:00	ANCIEN	\N	Elbeuf	\N	\N	\N	\N	0	MUNICIPAL	14001X	d'	\N	\N	\N	2014-01-02 11:13:15	2014-01-02 11:50:48
12942	2008-03-09 00:00:00	2008-03-09 00:00:00	\N	ACTIF	\N	Montjoi	\N	\N	\N	\N	0	MUNICIPAL	86010V	de 	\N	\N	\N	2014-01-13 10:09:47	2014-01-13 10:13:01
13765	2001-03-25 00:00:00	\N	\N	ACTIF	\N	Savolles	\N	\N	\N	\N	0	MUNICIPAL	14012N	de	\N	http://mairie-savolles.fr/	\N	2014-05-05 10:32:23	2014-05-05 10:46:09
13781	\N	2006-01-20 00:00:00	\N	ANCIEN	\N	Le Tampon	\N	\N	2001	2014	0	MUNICIPAL	14017T	\N	\N	\N	\N	2014-06-25 15:55:03	2014-06-25 16:05:04
13805	\N	\N	\N	ACTIF	\N	Poiré-sur-Vie	\N	\N	2001	\N	\N	MUNICIPAL	14031R	de	\N	\N	\N	2014-09-16 15:13:58	2015-05-18 16:28:07
13875	\N	\N	2020-07-04 00:00:00	ANCIEN	\N	Plonéour-Lanvern	\N	\N	1992	\N	\N	MUNICIPAL	14083S	de	\N	\N	\N	2014-09-18 10:06:40	2017-10-04 17:02:03
50893	2014-03-30 00:00:00	2014-03-30 00:00:00	\N	ACTIF	\N	Abymes	\N	\N	\N	\N	\N	MUNICIPAL	19301E	des	\N	\N	\N	2017-09-20 11:26:33	2017-09-20 11:29:14
13921	1995-06-01 00:00:00	1995-03-20 00:00:00	2020-06-27 00:00:00	ANCIEN	\N	Tain-l'Hermitage	\N	\N	\N	\N	\N	MUNICIPAL	14105F	de	\N	\N	\N	2014-09-18 11:54:14	2017-11-16 14:55:29
13927	2014-03-28 00:00:00	\N	\N	ACTIF	\N	Vinsobres	\N	\N	\N	\N	\N	MUNICIPAL	14109K	de	\N	\N	\N	2014-09-18 11:57:48	2017-11-15 17:54:12
13944	2014-03-17 00:00:00	\N	2014-10-01 00:00:00	ANCIEN	\N	Guéret	\N	\N	\N	\N	\N	MUNICIPAL	14121F	de	\N	\N	\N	2014-09-18 12:11:54	2014-11-20 17:47:52
14023	2008-03-15 00:00:00	\N	\N	ACTIF	\N	Marnaz	\N	\N	\N	\N	\N	MUNICIPAL	14179A	de	\N	\N	\N	2014-09-22 15:10:24	2017-10-05 14:07:57
14034	\N	\N	\N	ACTIF	\N	Nice	\N	\N	2001	\N	\N	MUNICIPAL	14187A	de	\N	\N	\N	2014-09-26 17:50:22	2017-11-29 09:52:05
14225	2001-03-19 00:00:00	\N	\N	ACTIF	\N	Lamballe	\N	\N	\N	\N	\N	MUNICIPAL	14235Q	de	\N	\N	\N	2014-09-28 17:59:34	2014-09-30 17:48:29
14246	\N	\N	\N	ACTIF	\N	Fréjus	\N	\N	2008	\N	\N	MUNICIPAL	14247U	de	\N	\N	\N	2014-09-28 18:13:58	2014-09-28 18:15:44
14334	2008-03-09 00:00:00	\N	2014-03-23 00:00:00	ANCIEN	\N	Chalon-sur-Saône	\N	\N	\N	\N	\N	MUNICIPAL	14151M	de	\N	\N	\N	2014-09-29 11:44:09	2014-09-29 11:45:06
14361	\N	\N	2018-05-31 00:00:00	ANCIEN	\N	Saint-Marceau	\N	\N	1971	1983	\N	MUNICIPAL	14167V	de	\N	\N	\N	2014-09-30 16:09:21	2018-06-04 11:44:26
14383	2014-04-01 00:00:00	\N	\N	ACTIF	\N	Lille	\N	\N	\N	\N	\N	MUNICIPAL	01042P	de	\N	\N	\N	2014-10-23 10:21:41	2014-10-23 10:21:59
14412	2014-04-01 00:00:00	2014-04-01 00:00:00	2020-06-28 00:00:00	ANCIEN	\N	Dijon	\N	\N	\N	\N	\N	MUNICIPAL	08069G	de 	\N	\N	\N	2015-01-27 10:19:38	2015-01-27 10:20:56
15458	1989-03-01 00:00:00	2008-03-16 00:00:00	2014-03-16 00:00:00	ANCIEN	\N	Mars	\N	\N	\N	\N	\N	MUNICIPAL	14361V	de	\N	\N	\N	2016-12-12 16:04:19	2016-12-16 12:11:55
15335	2008-03-16 00:00:00	2008-03-16 00:00:00	\N	ACTIF	\N	Châteauroux	\N	\N	\N	\N	\N	MUNICIPAL	14355X	de 	\N	\N	\N	2016-11-18 12:45:29	2017-11-08 17:00:49
50940	2014-03-30 00:00:00	2014-03-30 00:00:00	\N	ACTIF	\N	Fort-de-France	\N	\N	\N	\N	\N	MUNICIPAL	19295A	de	\N	\N	\N	2017-09-20 15:51:51	2017-11-08 17:35:56
50942	2014-03-30 00:00:00	2014-03-30 00:00:00	2020-06-28 00:00:00	ANCIEN	\N	Koné	\N	\N	\N	\N	\N	MUNICIPAL	19319Q	de	\N	\N	\N	2017-09-20 16:03:20	2017-09-20 16:05:25
50948	2001-03-18 00:00:00	2001-03-18 00:00:00	2020-06-27 00:00:00	ANCIEN	\N	Mamoudzou	\N	\N	\N	\N	\N	MUNICIPAL	19329S	de	\N	\N	\N	2017-09-20 16:20:16	2017-09-29 10:46:02
50949	1499-12-31 00:50:39	1499-12-31 00:50:39	\N	ACTIF	\N	Dzaoudzi	\N	\N	\N	\N	1000	MUNICIPAL	19331L	de	\N	\N	\N	2017-09-20 16:21:22	2023-09-27 11:56:54
50950	2016-01-01 00:00:00	\N	2020-06-27 00:00:00	ANCIEN	\N	Cherbourg-en-Cotentin	\N	\N	\N	\N	\N	MUNICIPAL	19333N	de	\N	\N	\N	2017-09-20 16:27:05	2018-05-30 09:24:41
50953	2014-03-30 00:00:00	2008-03-16 00:00:00	\N	ACTIF	\N	Stainville	\N	\N	\N	\N	\N	MUNICIPAL	19563B	de	\N	\N	\N	2017-09-20 16:37:13	2017-11-27 12:40:45
50955	1989-03-19 00:00:00	2014-03-30 00:00:00	\N	ACTIF	\N	Basse-Ham	\N	\N	\N	\N	\N	MUNICIPAL	19335Q	de	\N	\N	\N	2017-09-20 16:41:41	2017-12-06 14:24:42
51066	\N	\N	\N	ANCIEN	\N	Rognonas	\N	\N	1983	2001	\N	MUNICIPAL	14115H	de	\N	\N	\N	2017-09-24 11:45:10	2017-09-26 09:57:42
51082	1987-05-31 00:00:00	\N	2017-10-20 00:00:00	ANCIEN	\N	Avirons	\N	\N	\N	\N	\N	MUNICIPAL	19659J	des	\N	\N	\N	2017-09-24 16:27:48	2017-11-10 10:35:04
51093	2008-03-16 00:00:00	\N	\N	ACTIF	\N	Saint-Pierre	\N	\N	\N	\N	\N	MUNICIPAL	19657G	de	\N	\N	\N	2017-09-24 16:57:18	2018-02-06 12:21:45
51130	1989-03-19 00:00:00	\N	2008-03-15 00:00:00	ANCIEN	\N	Croisic	\N	\N	\N	\N	\N	MUNICIPAL	17583W	du	\N	\N	\N	2017-09-24 17:22:15	2017-09-28 09:29:37
51132	2008-03-16 00:00:00	\N	2014-03-30 00:00:00	ANCIEN	\N	Guérande	\N	\N	\N	\N	\N	MUNICIPAL	17583W	de	\N	\N	\N	2017-09-24 17:24:30	2017-09-24 17:26:21
51165	\N	2001-03-18 00:00:00	\N	ACTIF	\N	Saint-Gratien	\N	\N	1983	\N	\N	MUNICIPAL	19673G	de	\N	\N	\N	2017-09-24 17:42:25	2017-09-25 17:49:43
51182	2008-03-16 00:00:00	\N	2021-06-01 00:00:00	ANCIEN	\N	Saint-Leu-la-Forêt	\N	\N	\N	\N	\N	MUNICIPAL	19671E	de	\N	\N	\N	2017-09-24 17:48:15	2018-02-08 15:14:46
51190	1995-06-18 00:00:00	1995-06-18 00:00:00	2020-03-15 00:00:00	ANCIEN	\N	Taverny	\N	\N	\N	\N	\N	MUNICIPAL	19669L	de	\N	\N	\N	2017-09-24 17:53:31	2017-09-24 17:57:27
51211	2001-03-18 00:00:00	\N	\N	ACTIF	\N	Château-Bernard	\N	\N	\N	\N	999	MUNICIPAL	19679N	de	\N	\N	\N	2017-09-24 18:08:19	2017-11-14 10:31:19
51235	2001-03-18 00:00:00	2001-03-18 00:00:00	2014-03-29 00:00:00	ANCIEN	\N	Châbons	\N	\N	\N	\N	\N	MUNICIPAL	19349W	de	\N	\N	\N	2017-09-24 18:18:43	2017-09-24 18:19:37
51305	2008-03-16 00:00:00	\N	\N	ACTIF	\N	Saint-Chéron	\N	\N	\N	\N	\N	MUNICIPAL	19691J	de	\N	\N	\N	2017-09-24 19:25:49	2017-09-24 19:28:35
51322	2012-11-09 00:00:00	\N	2020-06-28 00:00:00	ANCIEN	\N	Capbreton	\N	\N	\N	\N	\N	MUNICIPAL	19489J	de	\N	\N	\N	2017-09-24 19:56:52	2017-11-08 17:43:09
51327	1989-03-19 00:00:00	1989-03-19 00:00:00	2008-03-15 00:00:00	ANCIEN	\N	Aubagnan	\N	\N	\N	\N	\N	MUNICIPAL	17779H	d'	\N	\N	\N	2017-09-24 20:02:47	2017-09-26 18:00:15
51329	2008-03-16 00:00:00	\N	2017-10-31 00:00:00	ANCIEN	\N	Hagetmau	\N	\N	\N	\N	\N	MUNICIPAL	17779H	de	\N	\N	\N	2017-09-24 20:02:56	2018-01-23 12:35:27
51336	1989-03-19 00:00:00	1989-03-19 00:00:00	\N	ACTIF	\N	Plessis-Robinson	\N	\N	\N	\N	\N	MUNICIPAL	17637T	du	\N	\N	\N	2017-09-24 20:22:58	2018-05-30 09:35:21
51345	2008-03-16 00:00:00	\N	\N	ACTIF	\N	Boulogne-Billancourt	\N	\N	\N	\N	\N	MUNICIPAL	19711U	de	\N	\N	\N	2017-09-24 20:33:26	2018-05-30 09:38:12
51477	2014-03-30 00:00:00	2014-03-30 00:00:00	\N	ACTIF	\N	 La Celle	\N	\N	\N	\N	\N	MUNICIPAL	19731Y	de	\N	\N	\N	2017-10-01 11:28:25	2017-10-01 11:30:20
51481	2001-03-18 00:00:00	2001-03-18 00:00:00	2017-10-11 00:00:00	ANCIEN	\N	Villeneuve-lès-Avignon	\N	\N	\N	\N	\N	MUNICIPAL	19733B	de	\N	\N	\N	2017-10-01 11:42:20	2017-11-09 10:25:53
51484	2001-03-18 00:00:00	2014-03-30 00:00:00	\N	ACTIF	\N	Caen	\N	\N	\N	\N	\N	MUNICIPAL	19735D	de	\N	\N	\N	2017-10-01 11:49:04	2017-10-02 14:48:05
51488	2014-03-30 00:00:00	2014-03-30 00:00:00	2020-06-28 00:00:00	ANCIEN	\N	Dardilly	\N	\N	\N	\N	\N	MUNICIPAL	19737F	de	\N	\N	\N	2017-10-01 11:59:24	2017-12-06 12:48:58
51605	2008-03-16 00:00:00	\N	2018-07-10 00:00:00	ANCIEN	\N	Bellême	\N	\N	\N	\N	\N	MUNICIPAL	19762G	de	\N	\N	\N	\N	\N
51515	1983-03-20 00:00:00	1983-03-20 00:00:00	2001-03-18 00:00:00	ANCIEN	\N	Givet	\N	\N	\N	\N	\N	MUNICIPAL	07029T	de	\N	\N	\N	2017-11-14 10:37:54	2017-11-14 10:39:33
51546	1989-03-19 00:00:00	1989-03-19 00:00:00	2020-06-27 00:00:00	ANCIEN	\N	Dosches	\N	\N	\N	\N	\N	MUNICIPAL	19745F	de	\N	\N	\N	2017-12-18 14:32:12	2018-02-16 16:07:52
51550	2008-03-16 00:00:00	2014-03-30 00:00:00	\N	ACTIF	\N	Saint-Sauveur-en-Puisaye	\N	\N	\N	\N	\N	MUNICIPAL	19749K	de	\N	\N	\N	2017-12-18 14:53:20	2018-05-17 11:31:08
51608	2008-03-16 00:00:00	\N	\N	ACTIF	\N	Avion	\N	\N	\N	\N	\N	MUNICIPAL	19760E	d'	\N	\N	\N	\N	\N
51711	1995-06-30 00:00:00	1995-06-30 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	Montville	\N	\N	\N	\N	\N	MUNICIPAL	19826F	de	\N	\N	\N	\N	\N
51692	2014-03-30 00:00:00	2014-03-30 00:00:00	2019-09-26 00:00:00	ANCIEN	\N	Podensac	\N	\N	\N	\N	\N	MUNICIPAL	19820Y	de	\N	\N	\N	\N	\N
52100	1983-03-15 00:00:00	\N	2020-06-15 00:00:00	ANCIEN	\N	Péret	\N	\N	\N	\N	\N	MUNICIPAL	20116W	de	\N	\N	\N	\N	\N
52099	2014-03-15 00:00:00	\N	\N	ACTIF	\N	La Bouilladisse	\N	\N	\N	\N	\N	MUNICIPAL	20110Q	de	\N	\N	\N	\N	\N
52103	1991-01-15 00:00:00	\N	2019-01-15 00:00:00	ANCIEN	\N	Divonne-les-Bains	\N	\N	\N	\N	\N	MUNICIPAL	17367Q	de	\N	\N	\N	\N	\N
13756	2014-04-01 00:00:00	\N	\N	ACTIF	\N	Saint-Pois	\N	\N	\N	\N	999	MUNICIPAL	05008E	de	\N	\N	\N	2014-04-29 11:15:14	2014-04-29 11:16:28
13751	2014-04-01 00:00:00	\N	\N	ACTIF	\N	Angers	\N	\N	\N	\N	0	MUNICIPAL	11030C	d'	\N	\N	\N	2014-04-07 11:58:21	2014-04-07 11:58:45
13804	\N	\N	2020-03-31 00:00:00	ANCIEN	\N	Château-d'Olonne	\N	\N	2001	\N	\N	MUNICIPAL	14030Q	de	\N	\N	\N	2014-09-16 15:04:40	2017-10-09 11:56:30
14009	2001-03-24 00:00:00	2001-03-24 00:00:00	2018-05-31 00:00:00	ANCIEN	\N	Mans	\N	\N	\N	\N	\N	MUNICIPAL	14167V	du	\N	\N	\N	2014-09-22 10:54:57	2018-06-04 11:44:26
14013	2014-03-17 00:00:00	\N	\N	ACTIF	\N	Lude	\N	\N	\N	\N	\N	MUNICIPAL	14169X	du	\N	\N	\N	2014-09-22 11:05:05	2017-11-08 17:48:07
14016	2014-03-30 00:00:00	\N	2023-11-01 00:00:00	ANCIEN	\N	Bonnétable	\N	\N	\N	\N	\N	MUNICIPAL	14173T	de	\N	\N	\N	2014-09-22 11:15:49	2017-11-03 15:23:56
14027	2008-03-17 00:00:00	\N	\N	ACTIF	\N	Havre	\N	\N	\N	\N	\N	MUNICIPAL	14053L	du	\N	\N	\N	2014-09-22 15:43:23	2014-09-30 11:44:45
14025	1995-03-01 00:00:00	\N	2020-03-15 00:00:00	ANCIEN	\N	Saint-Pierre-de-Manneville	\N	\N	\N	\N	\N	MUNICIPAL	14051J	de	\N	\N	\N	2014-09-22 15:37:30	2017-08-10 17:09:01
14076	\N	\N	2008-03-09 00:00:00	ANCIEN	\N	Saponcourt	\N	\N	2001	\N	\N	MUNICIPAL	14135M	de	\N	\N	\N	2014-09-28 15:36:29	2017-03-23 10:46:12
14128	2014-04-01 00:00:00	2014-04-01 00:00:00	2020-06-15 00:00:00	ANCIEN	\N	Servian	\N	\N	\N	\N	\N	MUNICIPAL	14207L	de 	\N	\N	\N	2014-09-28 17:12:37	2014-09-28 17:13:03
14132	\N	\N	\N	ACTIF	\N	Messimy	\N	\N	2008	\N	\N	MUNICIPAL	14215L	de	\N	\N	\N	2014-09-28 17:12:59	2014-09-28 17:13:23
14133	\N	\N	\N	ACTIF	\N	Beauvais-sur-Matha	\N	\N	1995	\N	999	MUNICIPAL	14213J	de	\N	\N	\N	2014-09-28 17:13:41	2017-11-13 18:54:55
14142	2001-03-30 00:00:00	2001-03-30 00:00:00	\N	ACTIF	\N	Sète	\N	\N	\N	\N	\N	MUNICIPAL	14209N	de 	\N	\N	\N	2014-09-28 17:17:15	2014-09-28 17:18:03
14151	1977-03-13 00:00:00	1977-03-13 00:00:00	1983-03-05 00:00:00	ANCIEN	\N	La Cavalerie	\N	\N	\N	\N	\N	MUNICIPAL	14211G	de 	\N	\N	\N	2014-09-28 17:27:03	2014-09-28 17:27:45
14160	1983-03-14 00:00:00	1983-03-14 00:00:00	2021-02-01 00:00:00	ANCIEN	\N	Castelnau-le-Lez	\N	\N	\N	\N	\N	MUNICIPAL	14211G	de 	\N	\N	\N	2014-09-28 17:27:53	2017-10-03 11:50:51
14161	2001-03-20 00:00:00	\N	2020-03-01 00:00:00	ANCIEN	\N	Serville	\N	\N	\N	\N	\N	MUNICIPAL	14217N	de	\N	\N	\N	2014-09-28 17:30:30	2018-01-23 19:20:29
14187	\N	\N	2018-02-28 00:00:00	ANCIEN	\N	Ornans	\N	\N	2014	\N	\N	MUNICIPAL	14219Q	d'	\N	\N	\N	2014-09-28 17:43:49	2018-03-28 12:51:27
14208	\N	\N	\N	ACTIF	\N	Cabrières-d'Aigues 	\N	\N	2011	\N	\N	MUNICIPAL	14233N	de	\N	\N	\N	2014-09-28 17:52:23	2014-09-29 16:10:05
14267	\N	1989-04-01 00:00:00	\N	ANCIEN	\N	Rainneville	\N	\N	1989	2014	\N	MUNICIPAL	14063N	de	\N	\N	\N	2014-09-28 18:44:40	2014-10-02 11:02:20
14316	1983-03-15 00:00:00	\N	2004-03-15 00:00:00	ANCIEN	\N	La Mézière	\N	\N	\N	\N	\N	MUNICIPAL	14227Q	de 	\N	\N	\N	2014-09-28 21:17:27	2014-09-30 16:12:03
14360	2014-03-30 00:00:00	\N	\N	ACTIF	\N	Mazières-en-Gâtines	\N	\N	\N	\N	\N	MUNICIPAL	14119M	de	\N	\N	\N	2014-09-30 16:06:39	2018-05-30 09:44:01
14364	\N	\N	2020-06-28 00:00:00	ANCIEN	\N	Rennes	\N	\N	2008	\N	\N	MUNICIPAL	14229S	de	\N	\N	\N	2014-09-30 16:14:21	2018-05-30 09:55:41
14378	2014-03-17 00:00:00	2014-03-17 00:00:00	\N	ACTIF	\N	Évreux	\N	\N	\N	\N	\N	MUNICIPAL	14249W	d'	\N	\N	\N	2014-10-02 10:39:17	2014-10-23 15:57:05
50795	2001-06-15 00:00:00	\N	2022-02-02 00:00:00	ANCIEN	\N	Sainte-Geneviève-des-bois	\N	\N	\N	\N	\N	MUNICIPAL	19289C	de 	\N	\N	\N	2017-09-14 11:05:25	2017-09-14 11:12:56
15189	2001-03-26 00:00:00	2001-03-26 00:00:00	\N	ACTIF	\N	Benais	\N	\N	\N	\N	\N	MUNICIPAL	14271U	de 	\N	\N	\N	2015-04-07 17:16:41	2015-04-16 11:03:23
15197	2014-04-01 00:00:00	2014-03-30 00:00:00	2015-06-02 00:00:00	ANCIEN	\N	Tehurui	\N	\N	\N	\N	\N	MUNICIPAL	14275Y	de 	\N	\N	\N	2015-05-11 18:42:22	2017-11-13 20:00:18
50861	2008-03-16 00:00:00	\N	2015-12-31 00:00:00	ANCIEN	\N	Montrichard	\N	\N	\N	\N	\N	MUNICIPAL	19511N	de	\N	\N	\N	2017-09-19 17:59:25	2017-09-27 09:47:39
50862	2016-01-01 00:00:00	\N	2017-10-25 00:00:00	ANCIEN	\N	Montrichard Val de Cher	\N	\N	\N	\N	\N	MUNICIPAL	19511N	de	\N	\N	\N	2017-09-19 17:59:33	2017-11-06 12:01:20
50877	2008-03-16 00:00:00	2014-03-30 00:00:00	2021-07-19 00:00:00	ANCIEN	\N	Angers	\N	\N	\N	\N	\N	MUNICIPAL	19545Y	d'	\N	\N	\N	2017-09-20 10:41:46	2018-05-30 10:17:14
50885	2008-03-16 00:00:00	2008-03-16 00:00:00	2020-06-28 00:00:00	ANCIEN	\N	Ponts-de-Cé\t	\N	\N	\N	\N	\N	MUNICIPAL	19549D	des	\N	\N	\N	2017-09-20 10:57:12	2018-05-15 14:50:57
50889	2008-03-16 00:00:00	2008-03-16 00:00:00	2017-10-09 00:00:00	ANCIEN	\N	Limey-Remenauville	\N	\N	\N	\N	\N	MUNICIPAL	19551W	de	\N	\N	\N	2017-09-20 11:18:15	2017-09-20 11:24:05
50892	2008-03-16 00:00:00	\N	2017-11-15 00:00:00	ANCIEN	\N	Villerupt	\N	\N	\N	\N	\N	MUNICIPAL	19553Y	de	\N	\N	\N	2017-09-20 11:26:21	2018-01-25 16:12:41
51084	\N	\N	2017-12-30 00:00:00	ANCIEN	\N	Sainte-Marie	\N	\N	1990	\N	\N	MUNICIPAL	19583F	de	\N	\N	\N	2017-09-24 16:43:13	2018-01-08 14:48:19
51375	2008-03-16 00:00:00	2014-03-16 00:00:00	\N	ACTIF	\N	Villejuif	\N	\N	\N	\N	\N	MUNICIPAL	19689Q	de	\N	\N	\N	2017-09-25 11:53:24	2017-09-25 11:54:36
51440	2014-03-30 00:00:00	2014-03-30 00:00:00	2017-10-23 00:00:00	ANCIEN	\N	Chinon	\N	\N	\N	\N	\N	MUNICIPAL	19443T	de	\N	\N	\N	2017-09-27 14:53:16	2017-11-20 14:36:28
51501	1977-03-20 00:00:00	1977-03-20 00:00:00	\N	ACTIF	\N	La Ferté-Saint-Cyr	\N	\N	\N	\N	\N	MUNICIPAL	19739H	de	\N	\N	\N	2017-11-03 10:54:32	2018-01-10 18:58:30
51509	2008-03-21 00:00:00	2008-03-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	Aurillac	\N	\N	\N	\N	\N	MUNICIPAL	19253P	d'	\N	\N	\N	2017-11-09 13:05:39	2017-11-09 13:07:49
51551	1995-06-18 00:00:00	1995-06-18 00:00:00	\N	ACTIF	\N	Montmorillon	\N	\N	\N	\N	\N	MUNICIPAL	19747H	de	\N	\N	\N	2017-12-18 14:53:29	2018-02-13 14:44:15
51592	2008-03-16 00:00:00	\N	2018-06-21 00:00:00	ANCIEN	\N	Bolbec	\N	\N	\N	\N	\N	MUNICIPAL	19758L	de	\N	\N	\N	2018-06-04 13:56:55	2018-06-04 14:00:36
51590	2017-10-07 00:00:00	2017-10-07 00:00:00	2020-06-01 00:00:00	ANCIEN	\N	XIXème arrondissement de Paris	\N	\N	\N	\N	\N	MUNICIPAL	19683J	du	\N	\N	\N	2018-05-30 10:13:07	2018-05-30 10:13:47
51632	2008-03-22 00:00:00	2008-03-22 00:00:00	\N	ACTIF	\N	Nancy-sur-Cluses	\N	\N	\N	\N	\N	MUNICIPAL	19768N	de	\N	\N	\N	\N	\N
51751	2020-07-13 00:00:00	2020-06-25 00:00:00	\N	ACTIF	\N	Moncoutant-sur-Sèvre	\N	\N	\N	\N	\N	MUNICIPAL	14071N	de	\N	\N	\N	\N	\N
51755	2020-03-15 00:00:00	\N	\N	ACTIF	\N	Maromme	\N	\N	\N	\N	\N	MUNICIPAL	14051J	de	\N	\N	\N	\N	\N
52059	2016-06-15 00:00:00	\N	\N	ACTIF	\N	Rognac	\N	\N	\N	\N	\N	MUNICIPAL	20108W	de	\N	\N	\N	\N	\N
52067	1989-03-15 00:00:00	\N	2000-09-15 00:00:00	ANCIEN	\N	Cannes	\N	\N	\N	\N	\N	MUNICIPAL	20136B	de	\N	\N	\N	\N	\N
52070	1983-03-15 00:00:00	\N	2020-03-15 00:00:00	ANCIEN	\N	Villefranche d'Allier	\N	\N	\N	\N	\N	MUNICIPAL	20020P	de	\N	\N	\N	\N	\N
52104	2020-06-15 00:00:00	\N	\N	ACTIF	\N	Lyon 	\N	\N	\N	\N	\N	MUNICIPAL	17367Q	de	\N	\N	\N	\N	\N
52107	1995-06-15 00:00:00	\N	2020-10-26 00:00:00	ANCIEN	\N	Cavaillon	\N	\N	\N	\N	\N	MUNICIPAL	20086J	de	\N	\N	\N	\N	\N
52135	2014-03-15 00:00:00	2020-03-15 00:00:00	\N	ACTIF	\N	Gilette	\N	\N	\N	\N	\N	MUNICIPAL	20140W	de	\N	\N	\N	\N	\N
52137	1983-03-15 00:00:00	2020-03-15 00:00:00	\N	ACTIF	\N	Néoules	\N	\N	\N	\N	\N	MUNICIPAL	20072C	de	\N	\N	\N	\N	\N
52141	2008-03-15 00:00:00	2020-03-15 00:00:00	\N	ACTIF	\N	Saint Pabu	\N	\N	\N	\N	\N	MUNICIPAL	20106U	de	\N	\N	\N	\N	\N
52143	1995-03-15 00:00:00	2020-03-15 00:00:00	2020-10-26 00:00:00	ANCIEN	\N	Saint-Vit	\N	\N	\N	\N	\N	MUNICIPAL	20066E	de	\N	\N	\N	\N	\N
52148	2001-03-15 00:00:00	\N	2015-07-15 00:00:00	ANCIEN	\N	Saint-Barthélemy	\N	\N	\N	\N	\N	MUNICIPAL	20034V	de	\N	\N	\N	\N	\N
52149	2008-04-15 00:00:00	2014-04-15 00:00:00	2020-10-15 00:00:00	ANCIEN	\N	Charleville-Mézières	\N	\N	\N	\N	\N	MUNICIPAL	20056C	de	\N	\N	\N	\N	\N
52152	2001-03-15 00:00:00	2020-03-15 00:00:00	\N	ACTIF	\N	Guingamp	\N	\N	\N	\N	\N	MUNICIPAL	18193Q	de	\N	\N	\N	\N	\N
52157	2008-03-15 00:00:00	\N	2020-06-15 00:00:00	ANCIEN	\N	Montauban	\N	\N	\N	\N	\N	MUNICIPAL	20052X	de	\N	\N	\N	\N	\N
52162	2001-03-15 00:00:00	2001-03-15 00:00:00	\N	ACTIF	\N	Moulin-Neuf	\N	\N	\N	\N	\N	MUNICIPAL	20018V	de	\N	\N	\N	\N	\N
52164	2001-03-15 00:00:00	2001-03-15 00:00:00	\N	ACTIF	\N	Santa-Lucia-di-Mercurio	\N	\N	\N	\N	999	MUNICIPAL	20036X	de	\N	\N	\N	\N	\N
52167	1989-03-15 00:00:00	2020-03-15 00:00:00	2020-10-15 00:00:00	ANCIEN	\N	Donneville	\N	\N	\N	\N	1111	MUNICIPAL	17965H	de	\N	\N	\N	\N	\N
52170	2008-03-15 00:00:00	1995-03-15 00:00:00	\N	ACTIF	\N	Meuzac	\N	\N	\N	\N	999	MUNICIPAL	20082E	de	\N	\N	\N	\N	\N
52172	2014-03-15 00:00:00	\N	2021-07-15 00:00:00	ANCIEN	\N	Jussey	\N	\N	\N	\N	1111	MUNICIPAL	20054A	de	\N	\N	\N	\N	\N
52173	1989-03-15 00:00:00	\N	2015-04-15 00:00:00	ANCIEN	\N	Blauzac	\N	\N	\N	\N	\N	MUNICIPAL	20088L	de 	\N	\N	\N	\N	\N
52179	2001-03-15 00:00:00	2001-03-15 00:00:00	2009-05-15 00:00:00	ANCIEN	\N	Saint-Brieuc	\N	\N	\N	\N	\N	MUNICIPAL	20104S	de	\N	\N	\N	\N	\N
52176	\N	2008-03-15 00:00:00	2014-03-15 00:00:00	ANCIEN	\N	Marseille	\N	\N	2008	\N	\N	MUNICIPAL	17737W	de	\N	\N	\N	\N	\N
52185	2020-03-15 00:00:00	\N	2020-10-27 00:00:00	ANCIEN	\N	Punaauia	\N	\N	\N	\N	1111	MUNICIPAL	20150Y	de	\N	\N	\N	\N	\N
13869	2014-03-19 00:00:00	1974-03-18 00:00:00	\N	ACTIF	\N	Tagsdorf	\N	\N	\N	\N	\N	MUNICIPAL	14079W	de	\N	\N	\N	2014-09-17 18:07:13	2018-01-12 10:50:57
13871	1999-05-31 00:00:00	\N	\N	ACTIF	\N	Bron	\N	\N	\N	\N	\N	MUNICIPAL	14081Q	de	\N	\N	\N	2014-09-17 18:10:58	2015-09-25 15:21:30
13981	2001-03-15 00:00:00	\N	\N	ACTIF	\N	Châtenoy-le-Royal	\N	\N	\N	\N	\N	MUNICIPAL	14147R	de	\N	\N	\N	2014-09-18 15:47:32	2015-06-12 15:49:15
14398	2007-08-01 00:00:00	\N	\N	ACTIF	\N	Lazer	\N	\N	\N	\N	\N	MUNICIPAL	14265W	de	\N	\N	\N	2014-12-29 15:46:14	2017-12-06 15:27:44
14071	2014-03-17 00:00:00	2008-03-17 00:00:00	2021-07-15 00:00:00	ANCIEN	\N	Beaucourt	\N	\N	\N	\N	\N	MUNICIPAL	14193X	de	\N	\N	\N	2014-09-28 15:28:48	2014-09-28 15:39:58
14109	2008-03-17 00:00:00	2008-03-17 00:00:00	2020-06-15 00:00:00	ANCIEN	\N	Saulieu	\N	\N	\N	\N	\N	MUNICIPAL	14205J	de	\N	\N	\N	2014-09-28 17:04:53	2014-09-28 17:05:20
14150	2001-03-19 00:00:00	\N	2017-10-31 00:00:00	ANCIEN	\N	Saint-Quentin	\N	\N	\N	\N	\N	MUNICIPAL	14026U	de	\N	\N	\N	2014-09-28 17:26:45	2017-11-22 19:46:27
14174	2014-03-17 00:00:00	\N	2020-06-28 00:00:00	ANCIEN	\N	Tournefeuille	\N	\N	\N	\N	\N	MUNICIPAL	14225N	de	\N	\N	\N	2014-09-28 17:34:23	2015-07-02 14:27:31
14227	\N	\N	\N	ACTIF	\N	Meyrargues	\N	\N	1995	\N	\N	MUNICIPAL	14241N	de	\N	\N	\N	2014-09-28 18:00:30	2017-11-08 17:38:48
14242	1995-03-20 00:00:00	\N	\N	ACTIF	\N	Pennes-Mirabeau	\N	\N	\N	\N	\N	MUNICIPAL	14239U	des	\N	\N	\N	2014-09-28 18:05:11	2018-02-08 15:51:56
14244	2014-03-30 00:00:00	2014-03-30 00:00:00	\N	ACTIF	\N	Marseille (13ème et 14ème arrondissements)	\N	\N	\N	\N	\N	MUNICIPAL	14055N	de	\N	\N	\N	2014-09-28 18:12:36	2014-09-30 15:27:55
14301	1995-06-01 00:00:00	1995-06-01 00:00:00	\N	ACTIF	\N	Auch	\N	\N	\N	\N	\N	MUNICIPAL	14257W	d'	\N	\N	\N	2014-09-28 19:25:42	2014-09-28 19:27:32
14359	1995-03-01 00:00:00	\N	2014-03-17 00:00:00	ANCIEN	\N	Beaufay	\N	\N	\N	\N	\N	MUNICIPAL	14173T	de	\N	\N	\N	2014-09-30 15:42:51	2014-09-30 15:44:35
14368	1995-04-17 00:00:00	\N	2008-03-16 00:00:00	ANCIEN	\N	La Chapelle-Taillefert	\N	\N	\N	\N	\N	MUNICIPAL	14121F	de	\N	\N	\N	2014-09-30 16:18:59	2014-09-30 16:20:23
14371	\N	\N	\N	ANCIEN	\N	La Rouaudière	\N	\N	1995	2008	\N	MUNICIPAL	14042U	de	\N	\N	\N	2014-09-30 16:52:20	2014-09-30 16:53:29
14379	\N	\N	\N	ANCIEN	\N	Arue	\N	\N	2008	2008	\N	MUNICIPAL	14044W	d'	\N	\N	\N	2014-10-02 10:56:49	2014-10-03 11:49:09
15200	2014-03-01 00:00:00	\N	2015-05-05 00:00:00	ANCIEN	\N	Punaauia	\N	\N	\N	\N	\N	MUNICIPAL	14277B	de 	\N	\N	\N	2015-05-11 19:33:37	2015-05-11 19:34:29
15193	\N	\N	2017-03-08 00:00:00	ANCIEN	\N	Arleux	\N	\N	2001	\N	\N	MUNICIPAL	14273W	de 	\N	\N	\N	2015-04-22 16:52:45	2017-04-21 14:49:38
15243	2008-03-30 00:00:00	2008-03-30 00:00:00	\N	ACTIF	\N	Saint-Denis-lès-Rebais	\N	\N	\N	\N	999	MUNICIPAL	14329V	de 	\N	\N	\N	2015-10-12 12:14:47	2017-11-08 15:59:43
15282	2015-12-21 00:00:00	2015-12-14 00:00:00	2020-01-11 00:00:00	ANCIEN	\N	Île des Pins	\N	\N	\N	\N	\N	MUNICIPAL	11011M	de l'	\N	\N	\N	2016-01-13 18:39:12	2016-01-13 20:59:11
15293	2016-01-01 00:00:00	\N	2017-09-28 00:00:00	ANCIEN	\N	Condé-en-Normandie	\N	\N	\N	\N	\N	MUNICIPAL	14133K	de	\N	\N	\N	2016-06-10 11:24:28	2018-01-24 12:47:47
15535	2016-01-01 00:00:00	2016-01-01 00:00:00	\N	ACTIF	\N	Loudenvielle	\N	\N	\N	\N	\N	MUNICIPAL	14365A	de	\N	\N	\N	2017-05-17 11:45:15	2017-05-17 11:46:58
43670	2001-03-19 00:00:00	2001-03-19 00:00:00	\N	ACTIF	\N	Domecy-sur-Cure	\N	\N	\N	\N	\N	MUNICIPAL	19269X	de	\N	\N	\N	2017-07-24 16:44:15	2017-07-24 16:45:10
50993	2011-03-13 00:00:00	2011-03-13 00:00:00	2017-10-24 00:00:00	ANCIEN	\N	Albertville	\N	\N	\N	\N	\N	MUNICIPAL	19575F	d'	\N	\N	\N	2017-09-21 18:41:24	2017-12-12 14:05:49
51016	2008-03-15 00:00:00	\N	\N	ACTIF	\N	Suresnes	\N	\N	\N	\N	\N	MUNICIPAL	19591F	de	\N	\N	\N	2017-09-22 11:11:43	2017-09-27 09:47:15
51032	2001-03-18 00:00:00	2001-03-18 00:00:00	2020-06-28 00:00:00	ANCIEN	\N	Lau-Balagnas	\N	\N	\N	\N	\N	MUNICIPAL	19629C	de	\N	\N	\N	2017-09-22 13:44:59	2017-11-13 18:20:52
51033	2014-03-30 00:00:00	\N	2020-06-27 00:00:00	ANCIEN	\N	Arrens-Marsous	\N	\N	\N	\N	\N	MUNICIPAL	19631V	d'	\N	\N	\N	2017-09-22 13:48:40	2017-11-14 15:53:12
51561	2016-12-01 00:00:00	\N	2020-06-28 00:00:00	ANCIEN	\N	Neussargues en Pinatelle	\N	\N	\N	\N	\N	MUNICIPAL	14327T	de	\N	\N	\N	2018-01-08 20:22:28	2018-01-09 09:46:47
51065	2014-03-30 00:00:00	2014-03-30 00:00:00	\N	ACTIF	\N	Saint-Maximin-la-Sainte-Baume	\N	\N	\N	\N	\N	MUNICIPAL	14029X	de	\N	\N	\N	2017-09-24 11:17:42	2017-12-07 10:13:19
51101	2008-03-16 00:00:00	2014-03-30 00:00:00	\N	ACTIF	\N	Aulnay-sous-Bois	\N	\N	\N	\N	\N	MUNICIPAL	19663E	de	\N	\N	\N	2017-09-24 17:04:10	2017-11-09 09:46:23
51149	1971-03-21 00:00:00	1971-03-21 00:00:00	\N	ACTIF	\N	Plouay	\N	\N	\N	\N	\N	MUNICIPAL	16685X	de	\N	\N	\N	2017-09-24 17:34:07	2018-01-25 11:49:14
51199	2014-03-30 00:00:00	2014-03-30 00:00:00	\N	ANCIEN	\N	Chelles	\N	\N	\N	2021	\N	MUNICIPAL	19675J	de	\N	\N	\N	2017-09-24 17:56:45	2018-05-30 09:52:47
51312	2014-03-30 00:00:00	2008-03-16 00:00:00	\N	ACTIF	\N	Hertzing	\N	\N	\N	\N	999	MUNICIPAL	19685L	de	\N	\N	\N	2017-09-24 19:40:35	2017-09-27 11:53:43
51330	1989-03-19 00:00:00	\N	2017-10-31 00:00:00	ANCIEN	\N	Bompas	\N	\N	\N	\N	\N	MUNICIPAL	19703U	de	\N	\N	\N	2017-09-24 20:05:35	2017-09-24 20:06:36
51383	2001-03-18 00:00:00	2001-03-18 00:00:00	2014-03-29 00:00:00	ANCIEN	\N	Tonneins	\N	\N	\N	\N	\N	MUNICIPAL	19369B	de	\N	\N	\N	2017-09-25 16:52:24	2017-09-25 16:53:58
51344	2008-03-16 00:00:00	2008-03-16 00:00:00	\N	ACTIF	\N	Neuvy-sur-Loire	\N	\N	\N	\N	\N	MUNICIPAL	19713W	de	\N	\N	\N	2017-09-24 20:32:58	2017-09-27 10:28:35
51669	1995-06-18 00:00:00	1995-06-18 00:00:00	2018-12-01 00:00:00	ANCIEN	\N	Lesches-en-Diois	\N	\N	\N	\N	\N	MUNICIPAL	19782L	de	\N	\N	\N	\N	\N
51992	2020-03-15 00:00:00	2020-03-15 00:00:00	\N	ACTIF	\N	Sébrazac	\N	\N	\N	\N	999	MUNICIPAL	20032T	de	\N	\N	\N	\N	\N
52000	1990-09-15 00:00:00	\N	2020-06-15 00:00:00	ANCIEN	\N	Palais-sur-Vienne	\N	\N	\N	\N	\N	MUNICIPAL	20080C	du	\N	\N	\N	\N	\N
52004	2020-03-15 00:00:00	2020-03-15 00:00:00	\N	ACTIF	\N	Cayenne	\N	\N	\N	\N	\N	MUNICIPAL	20146D	de	\N	\N	\N	\N	\N
52009	2010-03-15 00:00:00	\N	2014-03-15 00:00:00	ANCIEN	\N	Cayenne	\N	\N	\N	\N	\N	MUNICIPAL	20146D	de	\N	\N	\N	\N	\N
52011	2008-03-15 00:00:00	\N	2020-03-15 00:00:00	ANCIEN	\N	Bassillac et Auberoche	\N	\N	\N	\N	\N	MUNICIPAL	20046A	de	\N	\N	\N	\N	\N
52076	2001-01-03 00:00:00	2001-03-15 00:00:00	\N	ACTIF	\N	Tallard	\N	\N	\N	\N	\N	MUNICIPAL	14189C	de	\N	\N	\N	\N	\N
52013	2008-03-15 00:00:00	2020-06-15 00:00:00	2020-10-26 00:00:00	ANCIEN	\N	Nîmes	\N	\N	\N	\N	\N	MUNICIPAL	20090E	de	\N	\N	\N	\N	\N
52079	1995-03-15 00:00:00	2020-03-15 00:00:00	\N	ACTIF	\N	Moissac Bellevue	\N	\N	\N	\N	\N	MUNICIPAL	20076G	de	\N	\N	\N	\N	\N
52083	2014-03-15 00:00:00	\N	\N	ACTIF	\N	Vernon	\N	\N	\N	\N	\N	MUNICIPAL	19265T	de	\N	\N	\N	\N	\N
52086	1995-04-15 00:00:00	\N	\N	ACTIF	\N	Monts-sur-Guesnes	\N	\N	\N	\N	999	MUNICIPAL	20024T	de	\N	\N	\N	\N	\N
52089	2014-03-15 00:00:00	\N	2020-10-26 00:00:00	ANCIEN	\N	Reuilly	\N	\N	\N	\N	\N	MUNICIPAL	20022R	de	\N	\N	\N	\N	\N
52202	2008-03-15 00:00:00	\N	\N	ACTIF	\N	Saint-Jacques de la Lande	\N	\N	\N	\N	\N	MUNICIPAL	20092G	de	\N	\N	\N	\N	\N
52203	2020-06-15 00:00:00	\N	2022-02-01 00:00:00	ANCIEN	\N	Aurillac	\N	\N	\N	\N	1111	MUNICIPAL	20044X	d'	\N	\N	\N	\N	\N
52205	2014-03-15 00:00:00	2020-06-15 00:00:00	\N	ACTIF	\N	Strasbourg	\N	\N	\N	\N	1111	MUNICIPAL	20098N	de	\N	\N	\N	\N	\N
52240	2014-03-15 00:00:00	\N	2017-06-15 00:00:00	ANCIEN	\N	Marseille (11ème et 12ème arrondissements)	\N	\N	\N	\N	\N	MUNICIPAL	17737W	de	\N	\N	\N	\N	\N
52211	1989-03-15 00:00:00	1989-03-15 00:00:00	2020-03-15 00:00:00	ANCIEN	\N	Bernaville	\N	\N	\N	\N	\N	MUNICIPAL	20062A	de	\N	\N	\N	\N	\N
52241	2020-06-15 00:00:00	2020-06-15 00:00:00	\N	ACTIF	\N	Marseille	\N	\N	\N	\N	\N	MUNICIPAL	17737W	de	\N	\N	\N	\N	\N
52242	2017-09-15 00:00:00	\N	2021-07-28 00:00:00	ANCIEN	\N	Rixheim	\N	\N	\N	\N	1111	MUNICIPAL	20128B	de	\N	\N	\N	\N	\N
52276	2020-03-15 00:00:00	\N	2021-01-04 00:00:00	ANCIEN	\N	Gerstheim	\N	\N	\N	\N	\N	MUNICIPAL	20096L	de	\N	\N	\N	\N	\N
52259	2001-03-15 00:00:00	2020-03-15 00:00:00	2020-10-15 00:00:00	ANCIEN	\N	Les Échelles	\N	\N	\N	\N	1111	MUNICIPAL	20058E	de	\N	\N	\N	\N	\N
52279	2020-05-15 00:00:00	\N	\N	ACTIF	\N	Saussay-la-Campagne	\N	\N	\N	\N	\N	MUNICIPAL	20118Y	de	\N	\N	\N	\N	\N
52281	2008-03-15 00:00:00	\N	2020-10-26 00:00:00	ANCIEN	\N	Marennes-Hiers-Brouage	\N	\N	\N	\N	\N	MUNICIPAL	20064C	de	\N	\N	\N	\N	\N
52287	1995-06-15 00:00:00	\N	2020-06-15 00:00:00	ANCIEN	\N	Belleville	\N	\N	\N	\N	\N	MUNICIPAL	20132W	de	\N	\N	\N	\N	\N
52288	2019-01-15 00:00:00	\N	2020-06-15 00:00:00	ANCIEN	\N	Belleville en Beaujolais	\N	\N	\N	\N	\N	MUNICIPAL	20132W	de	\N	\N	\N	\N	\N
52315	\N	\N	\N	ANCIEN	\N	Dun-sur-Auron	\N	\N	2001	2019	\N	MUNICIPAL	19798U	de	\N	\N	\N	\N	\N
52358	1995-03-15 00:00:00	1995-03-15 00:00:00	\N	ACTIF	\N	Gouville-sur-Mer	\N	\N	\N	\N	\N	MUNICIPAL	20180F	de	\N	\N	\N	\N	\N
52443	2006-10-01 00:00:00	2006-10-01 00:00:00	2021-12-31 00:00:00	ANCIEN	\N	Béthune	\N	\N	\N	\N	\N	MUNICIPAL	20286Q	de 	\N	\N	\N	\N	\N
53117	1989-03-15 00:00:00	1989-03-15 00:00:00	1995-03-15 00:00:00	ANCIEN	\N	Arcueil	\N	\N	\N	\N	\N	MUNICIPAL	20914V	d'	\N	\N	\N	\N	\N
53118	1995-03-15 00:00:00	1995-03-15 00:00:00	2001-03-15 00:00:00	ANCIEN	\N	Arcueil	\N	\N	\N	\N	\N	MUNICIPAL	20914V	d'	\N	\N	\N	\N	\N
53119	2001-03-15 00:00:00	2001-03-15 00:00:00	2008-03-15 00:00:00	ANCIEN	\N	Arcueil	\N	\N	\N	\N	\N	MUNICIPAL	20914V	d'	\N	\N	\N	\N	\N
53120	2008-03-15 00:00:00	2008-03-15 00:00:00	2014-03-15 00:00:00	ANCIEN	\N	Arcueil	\N	\N	\N	\N	\N	MUNICIPAL	20914V	d'	\N	\N	\N	\N	\N
53121	2014-03-15 00:00:00	2014-03-15 00:00:00	2016-05-15 00:00:00	ANCIEN	\N	Arcueil	\N	\N	\N	\N	\N	MUNICIPAL	20914V	d'	\N	\N	\N	\N	\N
53148	2017-10-19 00:00:00	\N	\N	ACTIF	\N	Paris (Xème arrondissement)	\N	\N	\N	\N	\N	MUNICIPAL	19647E	de	\N	\N	\N	\N	\N
53184	2020-03-15 00:00:00	2020-03-15 00:00:00	\N	ACTIF	\N	Dreux	\N	\N	\N	\N	\N	MUNICIPAL	14217N	de	\N	\N	\N	\N	\N
53589	1499-12-31 00:50:39	1499-12-31 00:50:39	1515-10-23 00:50:39	ANCIEN	\N	Lille	\N	\N	\N	\N	1000	MUNICIPAL	18207D	de	\N	\N	\N	\N	2023-09-26 17:42:16
53605	1600-01-09 00:50:39	1600-01-09 00:50:39	2023-10-26 00:00:00	ANCIEN	\N	Chaudron-en-Mauges	\N	\N	\N	\N	1000	MUNICIPAL	21046E	de	\N	\N	\N	\N	2023-09-26 18:14:03
53618	1615-01-09 00:50:39	1615-01-09 00:50:39	1630-11-06 00:50:39	ANCIEN	\N	Satolas-et-Bonce	\N	\N	\N	\N	1000	MUNICIPAL	21080G	de	\N	\N	\N	\N	2023-09-27 11:25:46
53621	1500-01-01 00:00:00	1600-01-09 00:50:39	1600-01-01 00:00:00	ANCIEN	\N	Satolas-et-Bonce	\N	\N	1500	1600	0	MUNICIPAL	21080G	de	\N	\N	\N	\N	2023-09-27 11:25:46
53622	1500-01-01 00:00:00	1499-12-31 00:50:39	1600-01-01 00:00:00	ANCIEN	\N	Satolas-et-Bonce	\N	\N	1500	1600	0	MUNICIPAL	21080G	de	\N	\N	\N	\N	2023-09-27 11:25:46
53639	1499-12-31 00:50:39	1499-12-31 00:50:39	1599-11-06 00:50:39	ANCIEN	\N	Damazan	\N	\N	\N	\N	0	MUNICIPAL	21040X	de	\N	\N	\N	\N	2023-09-27 11:45:45
53642	2023-11-06 00:00:00	2023-11-06 00:00:00	\N	ACTIF	\N	Damazan	\N	\N	\N	\N	0	MUNICIPAL	21040X	de	\N	\N	\N	\N	2023-09-27 11:45:45
53651	1600-01-09 00:50:39	1600-01-09 00:50:39	2024-03-04 00:00:00	ANCIEN	\N	Metz 	\N	\N	\N	\N	1000	MUNICIPAL	21081H	de	\N	\N	\N	\N	2023-09-27 15:43:48
53654	1500-01-01 00:00:00	1499-12-31 00:50:39	1600-01-01 00:00:00	ANCIEN	\N	Metz	\N	\N	1500	1600	0	MUNICIPAL	21081H	de	\N	\N	\N	\N	2023-09-27 15:43:48
53686	1600-01-09 00:50:39	1499-12-31 00:50:39	\N	ACTIF	\N	Paris	\N	\N	\N	\N	1000	MUNICIPAL	21095P	de	\N	\N	\N	\N	2023-09-28 12:18:44
53687	1500-01-01 00:00:00	1499-12-31 00:50:39	1600-01-01 00:00:00	ANCIEN	\N	Paris	\N	\N	1500	1600	0	MUNICIPAL	21095P	de	\N	\N	\N	\N	2023-09-28 12:18:44
53688	1500-01-01 00:00:00	1499-12-31 00:50:39	\N	ACTIF	\N	Le-controis-en-Sologne	\N	\N	1500	\N	1000	MUNICIPAL	21052C	de	\N	\N	\N	\N	2023-10-05 13:37:04
53690	1500-01-01 00:00:00	1499-12-31 00:50:39	1600-01-01 00:00:00	ANCIEN	\N	Le-controis-en-Sologne	\N	\N	1500	1600	0	MUNICIPAL	21052C	de	\N	\N	\N	\N	2023-10-05 13:37:04
53883	2023-11-07 00:00:00	\N	\N	ACTIF	\N	Bazancourt	\N	\N	\N	\N	\N	MUNICIPAL	21064G	de	\N	\N	\N	\N	\N
53889	2023-11-01 00:00:00	\N	\N	ACTIF	\N	Senon	\N	\N	\N	\N	\N	MUNICIPAL	21042A	de 	\N	\N	\N	\N	\N
53818	1500-01-01 00:00:00	1500-01-01 00:00:00	1600-01-01 00:00:00	ANCIEN	\N	Fréteval	\N	\N	1500	1600	0	MUNICIPAL	21053D	de	\N	\N	\N	\N	2023-10-02 10:58:58
53899	2023-11-01 00:00:00	\N	\N	ACTIF	\N	Andilly	\N	\N	\N	\N	\N	MUNICIPAL	21086N	de 	\N	\N	\N	\N	\N
53900	2023-11-02 00:00:00	\N	\N	ACTIF	\N	Bonneuil-sur-Marne	\N	\N	\N	\N	\N	MUNICIPAL	21073H	de	\N	\N	\N	\N	\N
53909	2023-11-06 00:00:00	2023-11-06 00:00:00	\N	ACTIF	\N	Sucy-en-Brie	\N	\N	\N	\N	\N	MUNICIPAL	21072G	de	\N	\N	\N	\N	\N
53592	1499-12-31 00:50:39	1499-12-31 00:50:39	1599-11-06 00:50:39	ANCIEN	\N	La Trinité	\N	\N	\N	\N	1000	MUNICIPAL	21096Q	de	\N	\N	\N	\N	2023-09-26 17:45:28
53700	1499-12-31 00:50:39	1499-12-31 00:50:39	2023-10-26 00:00:00	ANCIEN	\N	Lifou	\N	\N	\N	\N	1000	MUNICIPAL	21030V	de	\N	\N	\N	\N	2023-09-28 14:49:20
53922	2023-12-20 00:00:00	2023-10-10 00:00:00	\N	ACTIF	\N	Cahors	\N	\N	\N	\N	\N	MUNICIPAL	21031W	de 	\N	\N	\N	\N	\N
53865	1499-12-31 00:50:39	1499-12-31 00:50:39	\N	ACTIF	\N	Woelfling lès Sarreguemines	\N	\N	\N	\N	\N	MUNICIPAL	21082J	de	\N	\N	\N	\N	\N
53647	1499-12-31 00:50:39	1499-12-31 00:50:39	2023-11-01 00:00:00	ANCIEN	\N	Nangis	\N	\N	\N	\N	1000	MUNICIPAL	21074J	de	\N	\N	\N	\N	2023-09-27 11:48:50
53695	1499-12-31 00:50:39	1499-12-31 00:50:39	1599-11-06 00:50:39	ANCIEN	\N	Dumbéa	\N	\N	\N	\N	1000	MUNICIPAL	21029D	de	\N	\N	\N	\N	2023-09-28 14:26:57
53725	1500-01-01 00:00:00	1500-01-01 00:00:00	1600-01-01 00:00:00	ANCIEN	\N	Strasbourg	\N	\N	1500	1600	0	MUNICIPAL	21043B	de	\N	\N	\N	\N	2023-09-28 17:11:12
53776	1500-01-01 00:00:00	1499-12-31 00:50:39	1600-01-01 00:00:00	ANCIEN	\N	Évecquemont	\N	\N	1500	1600	0	MUNICIPAL	21079P	d'	\N	\N	\N	\N	2023-10-02 09:08:59
53880	2023-11-06 00:00:00	\N	\N	ACTIF	\N	Saint-Léonard 	\N	\N	\N	\N	\N	MUNICIPAL	21065H	de	\N	\N	\N	\N	\N
53765	1500-01-01 00:00:00	1500-01-01 00:00:00	1600-01-01 00:00:00	ANCIEN	\N	Saint-Pierre	\N	\N	1500	1600	0	MUNICIPAL	21032X	de	\N	\N	\N	\N	2023-11-16 16:56:32
53910	2023-11-06 00:00:00	2023-11-06 00:00:00	\N	ACTIF	\N	Liévin	\N	\N	\N	\N	\N	MUNICIPAL	21067K	de	\N	\N	\N	\N	\N
53911	1600-11-06 00:50:39	1600-11-06 00:50:39	1699-11-06 00:50:39	ANCIEN	\N	Martel	\N	\N	\N	\N	\N	MUNICIPAL	21041Y	de	\N	\N	\N	\N	\N
53617	1499-12-31 00:50:39	1499-12-31 00:50:39	\N	ACTIF	\N	Paris	\N	\N	\N	\N	\N	MUNICIPAL	21090J	de	\N	\N	\N	\N	\N
53656	1600-01-09 00:50:39	1600-01-09 00:50:39	2024-03-25 00:00:00	ANCIEN	\N	Champagnole	\N	\N	\N	\N	1000	MUNICIPAL	21047F	de	\N	\N	\N	\N	2023-09-27 15:47:41
53659	1500-01-01 00:00:00	1499-12-31 00:50:39	1600-01-01 00:00:00	ANCIEN	\N	Champagnole	\N	\N	1500	1600	0	MUNICIPAL	21047F	de	\N	\N	\N	\N	2023-09-27 15:47:41
53670	1600-01-09 00:50:39	1499-12-31 00:50:39	2023-11-01 00:00:00	ANCIEN	\N	Clermont-Ferrand	\N	\N	\N	\N	1000	MUNICIPAL	21045D	de	\N	\N	\N	\N	2023-09-27 17:38:23
53672	1500-01-01 00:00:00	1499-12-31 00:50:39	1600-01-01 00:00:00	ANCIEN	\N	Chamalières	\N	\N	1500	1600	0	MUNICIPAL	21045D	de	\N	\N	\N	\N	2023-09-27 17:38:23
53886	1515-10-24 00:50:39	1515-10-24 00:50:39	\N	ACTIF	\N	Lille	\N	\N	\N	\N	\N	MUNICIPAL	18207D	de	\N	\N	\N	\N	\N
53679	1499-12-31 00:50:39	1499-12-31 00:50:39	1599-11-06 00:50:39	ANCIEN	\N	Salazie	\N	\N	\N	\N	1000	MUNICIPAL	21033Y	de	\N	\N	\N	\N	2023-09-28 12:16:23
53826	1500-01-01 00:00:00	1499-12-31 00:50:39	1600-01-01 00:00:00	ANCIEN	\N	Aulnay-sous-Bois 	\N	\N	1500	1600	0	MUNICIPAL	21078N	d'	\N	\N	\N	\N	2023-10-02 19:10:53
53827	1499-12-31 00:50:39	1499-12-31 00:50:39	\N	ACTIF	\N	Potelle	\N	\N	\N	\N	999	MUNICIPAL	21083K	de	\N	\N	\N	\N	2023-10-02 16:49:59
53898	2023-11-06 00:00:00	2023-11-06 00:00:00	\N	ACTIF	\N	Boën-sur-Lignon	\N	\N	\N	\N	\N	MUNICIPAL	21070E	de	\N	\N	\N	\N	\N
53583	1600-01-09 00:50:39	1600-01-09 00:50:39	1699-11-06 00:50:39	ANCIEN	\N	Tracy-le-Mont	\N	\N	\N	\N	1000	MUNICIPAL	21061D	de	\N	\N	\N	\N	2023-09-26 17:34:20
53585	1500-01-01 00:00:00	1499-12-31 00:50:39	1600-01-01 00:00:00	ANCIEN	\N	Tracy-le-Mont	\N	\N	1500	1600	0	MUNICIPAL	21061D	de	\N	\N	\N	\N	2023-09-26 17:34:20
53892	2023-11-02 00:00:00	2023-11-02 00:00:00	\N	ACTIF	\N	Clermont-Ferrand	\N	\N	\N	\N	\N	MUNICIPAL	21045D	de 	\N	\N	\N	\N	\N
53893	2023-10-23 00:00:00	2023-10-23 00:00:00	\N	ACTIF	\N	Tracy-le-Mont	\N	\N	\N	\N	\N	MUNICIPAL	21061D	de	\N	\N	\N	\N	\N
53627	1500-01-01 00:00:00	1499-12-31 00:50:39	1600-01-01 00:00:00	ANCIEN	\N	Senon	\N	\N	\N	\N	0	MUNICIPAL	21042A	de	\N	\N	\N	\N	2023-10-05 12:10:54
53634	1499-12-31 00:50:39	1499-12-31 00:50:39	2023-11-01 00:00:00	ANCIEN	\N	Meung-sur-Loire	\N	\N	\N	\N	1000	MUNICIPAL	21058J	de	\N	\N	\N	\N	2023-09-27 11:38:55
53876	1499-12-23 00:50:39	1499-12-23 00:50:39	1599-01-01 00:50:39	ANCIEN	\N	Paris	\N	\N	\N	\N	\N	MUNICIPAL	21089R	de	\N	\N	\N	\N	\N
53730	1500-01-01 00:00:00	1500-01-01 00:00:00	1600-01-01 00:00:00	ANCIEN	\N	Grand-Champ	\N	\N	1500	1600	0	MUNICIPAL	21050A	de	\N	\N	\N	\N	2023-09-28 17:11:58
53718	1499-12-31 00:50:39	1499-12-31 00:50:39	\N	ACTIF	\N	Fosses	\N	\N	\N	\N	1000	MUNICIPAL	21084L	de	\N	\N	\N	\N	2023-09-28 17:10:53
53728	1500-01-01 00:00:00	1500-01-01 00:00:00	1600-01-01 00:00:00	ANCIEN	\N	Trélazé	\N	\N	1500	1600	0	MUNICIPAL	21048G	de	\N	\N	\N	\N	2023-09-28 17:11:40
53877	2023-10-25 00:00:00	\N	\N	ACTIF	\N	19ème arrondissement de Paris	\N	\N	\N	\N	\N	MUNICIPAL	21089R	du 	\N	\N	\N	\N	\N
53895	2023-11-06 00:00:00	2023-11-06 00:00:00	\N	ACTIF	\N	Saint-Ouen	\N	\N	\N	\N	\N	MUNICIPAL	21077M	de	\N	\N	\N	\N	\N
53896	2023-11-06 00:00:00	2023-11-06 00:00:00	\N	ACTIF	\N	Melun	\N	\N	\N	\N	\N	MUNICIPAL	21076L	de	\N	\N	\N	\N	\N
53579	1500-01-01 00:00:00	1499-12-31 00:50:39	\N	ACTIF	\N	Bazancourt	\N	\N	1500	\N	1000	MUNICIPAL	21064G	de	\N	\N	\N	\N	2023-09-26 17:18:29
53581	2023-11-06 00:00:00	1449-12-31 00:50:39	\N	ACTIF	\N	Bazancourt	\N	\N	\N	\N	0	MUNICIPAL	21064G	de	\N	\N	\N	\N	2023-09-26 17:18:29
53615	1500-01-01 00:00:00	1500-01-01 00:00:00	1600-01-01 00:00:00	ANCIEN	\N	Trélazé	\N	\N	1500	1600	0	MUNICIPAL	21048G	de	\N	\N	\N	\N	2023-09-27 09:52:11
53914	2023-11-28 00:00:00	2023-11-06 00:00:00	\N	ACTIF	\N	Salazie	\N	\N	\N	\N	\N	MUNICIPAL	21033Y	de	\N	\N	\N	\N	\N
53944	1500-01-01 00:00:00	1499-12-31 00:50:39	\N	ACTIF	\N	Trois-Moutiers	\N	\N	1500	\N	1000	MUNICIPAL	21125C	des	\N	\N	\N	\N	2024-03-26 14:55:25
53948	1500-01-01 00:00:00	1500-01-01 00:00:00	\N	ACTIF	\N	LES TROIS-MOUTIERS	\N	\N	1500	\N	1000	MUNICIPAL	21125C	des	\N	\N	\N	\N	2024-03-26 16:47:51
53667	1500-01-01 00:00:00	1499-12-31 00:50:39	1600-01-01 00:00:00	ANCIEN	\N	Floirac	\N	\N	1500	1600	0	MUNICIPAL	21041Y	de	\N	\N	\N	\N	2023-10-09 08:47:38
53601	1500-01-01 00:00:00	1500-01-01 00:00:00	\N	ACTIF	\N	Suresnes	\N	\N	1500	\N	1000	MUNICIPAL	19111A	de	\N	\N	\N	\N	2023-09-26 18:11:42
53603	1500-01-01 00:00:00	1500-01-01 00:00:00	1600-01-01 00:00:00	ANCIEN	\N	Suresnes	\N	\N	1500	1600	0	MUNICIPAL	19111A	de	\N	\N	\N	\N	2023-09-26 18:11:42
53707	1499-12-31 00:50:39	1499-12-31 00:50:39	1599-12-31 00:50:39	ANCIEN	\N	Bonneuil-sur-Marne	\N	\N	\N	\N	0	MUNICIPAL	21073H	de	\N	\N	\N	\N	2023-09-28 16:52:17
53801	1499-12-31 00:50:39	1499-12-31 00:50:39	\N	ACTIF	\N	Paris	\N	\N	\N	\N	1000	MUNICIPAL	21088Q	de	\N	\N	\N	\N	2023-10-02 10:55:32
53574	1499-12-31 00:50:39	1499-12-31 00:50:39	1599-11-06 00:50:39	ANCIEN	\N	Hénin-Beaumont	\N	\N	\N	\N	1000	MUNICIPAL	21069M	de	\N	\N	\N	\N	2023-09-26 17:13:49
53609	1500-01-01 00:00:00	1500-01-01 00:00:00	1600-01-01 00:00:00	ANCIEN	\N	Strasbourg	\N	\N	1500	1600	0	MUNICIPAL	21043B	de	\N	\N	\N	\N	2023-09-26 18:16:19
53703	1499-12-31 00:50:39	1499-12-31 00:50:39	\N	ACTIF	\N	Terre-de-Bas	\N	\N	\N	\N	999	MUNICIPAL	21097R	de	\N	\N	\N	\N	2023-09-28 16:41:00
53917	2023-11-28 00:00:00	2023-11-06 00:00:00	\N	ACTIF	\N	Dumbéa	\N	\N	\N	\N	\N	MUNICIPAL	21029D	de	\N	\N	\N	\N	\N
53918	2023-11-28 00:00:00	2023-11-06 00:00:00	\N	ACTIF	\N	Villers-Saint-Paul	\N	\N	\N	\N	\N	MUNICIPAL	21060C	de	\N	\N	\N	\N	\N
53919	2023-11-06 00:00:00	2023-11-06 00:00:00	\N	ACTIF	\N	La Trinité	\N	\N	\N	\N	\N	MUNICIPAL	21096Q	de	\N	\N	\N	\N	\N
53920	2023-11-28 00:00:00	2023-11-06 00:00:00	\N	ACTIF	\N	Hénin-Beaumont	\N	\N	\N	\N	\N	MUNICIPAL	21069M	de	\N	\N	\N	\N	\N
\.


--
-- Data for Name: etadebman; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY etadebman (etadebmancod, etadebmanlic, etadebmanlib, etadebmannumtri, etadebmanlil, etadebmanlicfem, etadebmanlibfem, etadebmanlilfem, etadebmanlicplu, etadebmanlibplu, etadebmanlilplu, syscredat, sysmajdat) FROM stdin;
ELECTION	Election	Nouveau	1	Election	Election	Nouvelle	Election	Elections	Nouveaux	Elections	\N	\N
REELECTION	Réélection	Réélu	2	Réélu	Réélection	Réélue	Réélue	Réélection	Réélus	Réélus	\N	\N
REMPLACE	Remplace	Remplace	3	Remplace	Remplace	Remplace	Remplace	Remplace	Remplace	Remplacent	\N	\N
REN	Renouvellement	Réélu	4	Réélu	Renouvellement	Réélue	Réélue	Renouvellement	Réélus	Réélus	\N	\N
REN1	Renouvellement 1	Réélu	5	Réélu	Renouvellement 1	Réélue	Réélue	Renouvellement 1	Réélus	Réélus	\N	\N
REN2	Renouvellement 2	Réélu	6	Réélu	Renouvellement 2	Réélue	Réélue	Renouvellement 2	Réélus	Réélus	\N	\N
REN3	Renouvellement 3	Réélu	7	Réélu	Renouvellement 3	Réélue	Réélue	Renouvellement 3	Réélus	Réélus	\N	\N
REN4	Renouvellement 4	Réélu	8	Réélu	Renouvellement 4	Réélue	Réélue	Renouvellement 4	Réélus	Réélus	\N	\N
REN5	Renouvellement 5	Réélu	9	Réélu	Renouvellement 5	Réélue	Réélue	Renouvellement 5	Réélus	Réélus	\N	\N
REN6	Renouvellement 6	Réélu	10	Réélu	Renouvellement 6	Réélue	Réélue	Renouvellement 6	Réélus	Réélus	\N	\N
REN7	Renouvellement 7	Réélu	11	Réélu	Renouvellement 7	Réélue	Réélue	Renouvellement 7	Réélus	Réélus	\N	\N
REPRISE	Reprise suite à fin fon. membre Gvt	Reprise de l'exercice du mandat de sénateur suite à la cessation de fonction de membre du Gouvernement	12	Reprise de l'exercice du mandat de sénateur suite à la cessation de fonction de membre du Gouvernement	Reprise de l'exercice du mandat de sénateur suite à la cessation de fonction de membre du Gouvernement	Reprise de l'exercice du mandat de sénateur suite à la cessation de fonction de membre du Gouvernement	Reprise de l'exercice du mandat de sénateur suite à la cessation de fonction de membre du Gouvernement	Reprise de l'exercice du mandat de sénateur suite à la cessa	Reprise de l'exercice du mandat de sénateur suite à la cessation de fonction de membre du Gouvernement	Reprise de l'exercice du mandat de sénateur suite à la cessation de fonction de membre du Gouvernement	\N	\N
\.


--
-- Data for Name: etafinman; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY etafinman (etafinmancod, etafinmanlic, etafinman, etafinmannumtri, etafinmanlil, etafinmanlicfem, etafinmanlibfem, etafinmanlilfem, etafinmanlicplu, etafinmanlibplu, etafinmanlilplu, syscredat, sysmajdat) FROM stdin;
CESMEMGVT	Membre Gouvernement	Devenu membre du Gouvernement	8	Devenu membre du Gouvernement	Membre Gouvernement	Devenue membre du Gouvernement	Devenue membre du Gouvernement	Membres Gouvernement	Devenus membres du Gouvernement	Devenus membres du Gouvernement	\N	\N
CESDEPUTE	Élu député	Élu député	9	Élu député	Élue députée	Élue députée	Élue députée	Élus députés	Élus députés	Élu députés	\N	\N
CESMEMCC	Nommé membre CC	Nommé membre du Conseil Constitutionnel	11	Nommé membre du Conseil Constitutionnel	Nommée membre CC	Nommée membre du Conseil Constitutionnel	Nommée membre du Conseil Constitutionnel	Nommés membres CC	Nommés membres du Conseil Constitutionnel	Nommés membres du Conseil Constitutionnel	\N	\N
DEMPREMIN	Démission (Premier ministre)	Démissionnaire (devenu Premier ministre)	13	Démissionnaire (devenu Premier ministre)	Démission (Premier ministre)	Démissionnaire (devenue Premier ministre)	Démissionnaire (devenue Premier ministre)	Démissions (Premiers ministres)	Démissionnaires (devenus Premiers ministres)	Devenus Premiers ministres (Démissionnaires)	\N	\N
ACTIF	En Cours	En Cours	0	En Cours	En Cours	En Cours	En Cours	En Cours	En Cours	En Cours	\N	\N
ANNCC	Annulé par CC	Annulé par le Conseil Constitutionnel	18	Élection annulée par le Conseil Constitutionnel	Annulé par CC	Annulé par le Conseil Constitutionnel	Élection annulée par le Conseil Constitutionnel	Annulés par CC	Annulés par le Conseil Constitutionnel	Élections annulées par le Conseil Constitutionnel	\N	\N
DECCC	Dech. par CC	Déchéance par le Conseil Constitutionnel	19	Déchéance constatée par le Conseil Constitutionnel	Dech. par CC	Déchéance par le Conseil Constitutionnel	Déchéance constatée par le Conseil Constitutionnel	Dech. par CC	Déchéances par le Conseil Constitutionnel	Déchéances constatée par le Conseil Constitutionnel	\N	\N
DECEDE	Décédé	Décédé	2	Décédé	Décédée	Décédée	Décédée	Décédés	Décédés	Décédés	\N	\N
DEM	Démissionnaire	Démissionnaire	12	Démissionnaire	Démissionnaire	Démissionnaire	Démissionnaire	Démissionnaires	Démissionnaires	Démissionnaires	\N	\N
DEMMEMGVT	Démission (Membre Gouvt)	Démissionnaire (devenu membre du Gouvernement)	14	Démissionnaire (devenu membre du Gouvernement)	Démission (Membre Gouvt)	Démissionnaire (devenue membre du Gouvernement)	Démissionnaire (devenue membre du Gouvernement)	Démissions (Membres Gouvt)	Démissionnaires (devenus membres du Gouvernement)	Devenus membres du Gouvernement	\N	\N
FINMAN	Fin de mandat	Fin de mandat	3	Fin de mandat	Fin de mandat	Fin de mandat	Fin de mandat	Fins de mandat	Fins de mandat	Fins de mandat	\N	\N
NONREELU	Non réélu	Non réélu	5	Non réélu	Non réélue	Non réélue	Non réélue	Non réélus	Non réélus	Non réélus	\N	\N
NONREP	Ne se représente pas	Ne se représente pas	4	Ne se représente pas	Ne se représente pas	Ne se représente pas	Ne se représente pas	Ne se représentent pas	Ne se représentent pas	Ne se représentent pas	\N	\N
DEMDEPUTE	Démission (Député)	Démissionnaire (élu député)	15	Démissionnaire (élu député)	Démission (Députée)	Démissionnaire (élue député)	Démissionnaire (élue députée)	Démissions (Députés)	Démissionnaires (élus députés)	Élus députés	\N	\N
CESMANORD	Cessation de mandat (1962)	Cessation de mandat (Ordonnance de 1962)	21	Cessation de mandat (en application de l'ordonnance n°62-737 du 03-07-1962 consécutive à l'indépendance de l'Algérie)	Cessation de mandat (1962)	Cessation de mandat (Ordonnance du 03-07-1962)	Cessation de mandat (en application de l'ordonnance n°62-737 du 03-07-1962 consécutive à l'indépendance de l'Algérie)	Cessations de mandat (1962)	Cessations de mandat (Ordonnance du 03-07-1962)	Cessations de mandat (en application de l'ordonnance n°62-737 du 03-07-1962 consécutive à l'indépendance de l'Algérie)	\N	\N
DEMMEMCC	Démission (Membre CC)	Démissionnaire (nommé membre du Conseil Constitutionnel)	17	Démissionnaire (nommé membre du Conseil Constitutionnel)	Démission (Membre CC)	Démissionnaire (nommée membre du Conseil Constitutionnel)	Nommée membre du Conseil Constitutionnel	Démissions (Membres CC)	Démissionnaires (nommés membres du Conseil Constitutionnel)	Nommés membres du Conseil Constitutionnel	\N	\N
CESDEPUTEEUR	Élu député européen	Élu député européen	10	Élu député européen	Élue députée européenne	Élue députée européenne	Élue députée européenne	Élus députés européens	Élus députés européens	Élus députés européens	\N	\N
DEMDEPUTEEUR	Démission (Député européen)	Démissionnaire (élu député européen)	16	Démissionnaire (élu député européen)	Démission (élue députée européenne)	Démissionnaire (élue députée européenne)	Démissionnaire (élue députée européenne)	Démission (élus députés européens)	Démissionnaires (élus députés européens)	Démissionnaires (élus députés européens)	\N	\N
CESPREMIN	Premier ministre	Devenu Premier ministre	7	Devenu Premier ministre	Premier ministre	Devenue Premier ministre	Devenue Premier ministre	Premiers ministres	Devenus Premiers ministres	Devenus Premiers ministres	\N	\N
REPEXE	Reprise mandat d'ancien membre du Gvt	Reprise de l'exercice du mandat d'un ancien membre du Gouvernement	22	Reprise de l'exercice du mandat d'un ancien membre du Gouvernement	Reprise de l'exercice du mandat d'un ancien membre du Gouver	Reprise de l'exercice du mandat d'un ancien membre du Gouvernement	Reprise de l'exercice du mandat d'un ancien membre du Gouvernement	Reprise de l'exercice du mandat d'un ancien membre du Gouver	Reprise de l'exercice du mandat d'un ancien membre du Gouvernement	Reprise de l'exercice du mandat d'un ancien membre du Gouvernement	\N	\N
CESMAN	Cessation de mandat	Cessation de mandat	23	Cessation de mandat	Cessation de mandat	Cessation de mandat	Cessation de mandat	Cessation de mandat	Cessation de mandat	Cessation de mandat	\N	\N
SEREP	En cours, se représente	En cours, se représente	2	En cours, se représente	En cours, se représente	En cours, se représente	En cours, se représente	En cours, se représente	En cours, se représente	En cours, se représente	\N	\N
DEMCC	Démissionné d'office par le Conseil constitutionnel	Déclaré démissionnaire d'office de son mandat de sénateur par le Conseil constitutionnel	24	Déclaré démissionnaire d'office de son mandat de sénateur par le Conseil constitutionnel	Démissionnée d'office par le Conseil constitutionnel	Déclarée démissionnaire d'office de son mandat de sénateur par le Conseil constitutionnel	Déclarée démissionnaire d'office de son mandat de sénateur par le Conseil constitutionnel	Démissionnés d'office par le Conseil constitutionnel	Déclarés démissionnaires d'office de leurs mandats de sénateur par le Conseil constitutionnel	Déclarés démissionnaires d'office de leurs mandats de sénateur par le Conseil constitutionnel	\N	\N
FININCOMPAT	De droit (incompatibilité mandats locaux)	De droit (incompatibilité mandats locaux)	26	De droit (incompatibilité mandats locaux)	De droit (incompatibilité mandats locaux)	De droit (incompatibilité mandats locaux)	De droit (incompatibilité mandats locaux)	De droit (incompatibilité mandats locaux)	De droit (incompatibilité mandats locaux)	De droit (incompatibilité mandats locaux)	\N	\N
FINMEMGVT	De droit (membre du Gouvernement)	Membre du Gouvernement	27	Membre du Gouvernement	Membre du Gouvernement	Membre du Gouvernement	Membre du Gouvernement	Membres du Gouvernement	Membres du Gouvernement	Membres du Gouvernement	\N	\N
\.


--
-- Data for Name: etasen; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY etasen (etasencod, etasenlic, etasenlib, etasennumtri, etasenlil, etasenlicfem, etasenlibfem, etasenlilfem, etasenlicplu, etasenlibplu, etasenlilplu, syscredat, sysmajdat) FROM stdin;
ACTIF	En exercice	Sénateur en exercice	1	Sénateur en exercice	En exercice	Sénateur en exercice	Sénateur en exercice	En exercice	Sénateur en exercice	Sénateur en exercice	\N	\N
ANCIEN	Ancien sénateur	Ancien sénateur	2	Ancien sénateur	Ancien sénateur	Ancien sénateur	Ancien sénateur	Ancien sénateur	Ancien sénateur	Ancien sénateur	\N	\N
AUTRE	Autres	Autres personnes	3	Autres personnes	Autres	Autres personnes	Autres personnes	Autres	Autres personnes	Autres personnes	\N	\N
ANCIEN4R	Ancien sénateur 4e R.	Ancien sénateur 4e République	5	Ancien sénateur 4e République	Ancienne sénatrice 4e R.	Ancienne sénatrice 4e République	Ancienne sénatrice 4e République	Anciens sénateurs 4e R.	Anciens sénateurs 4e République	Anciens sénateurs 4e République	\N	\N
ANCIEN3R	Ancien sénateur 3e R.	Ancien sénateur 3e République	6	Ancien sénateur 3e République	Ancienne sénatrice 3e R.	Ancienne sénatrice 3e République	Ancienne sénatrice 3e République	Anciens sénateurs 3e R.	Anciens sénateurs 3e République	Anciens sénateurs 3e République	\N	\N
PAIRS_FRA	Ancien pair de France	Ancien pair de France	9	Ancien pair de France	\N	\N	\N	Anciens pairs de France	Anciens pairs de France	Anciens pairs de France	2018-01-26 11:40:44	\N
ANCIENSC	Ancien sénateur Communauté	Ancien sénateur de la Communauté	8	Ancien sénateur de la Communauté	Ancienne sénatrice Communauté	Ancienne sénatrice de la Communauté	Ancienne sénatrice de la Communauté	Anciens sénateurs Communauté	Anciens sénateurs de la Communauté	Anciens sénateurs de la Communauté	2015-02-10 11:59:30	\N
ANCIEN2E	Ancien sénateur 2nd E.	Ancien sénateur 2nd Empire	7	Ancien sénateur Second Empire	Ancienne sénatrice 2nd E.	Ancienne sénatrice 2nd Empire	Ancienne sénatrice Second Empire	Anciens sénateurs 2nd E.	Anciens sénateurs 2nd Empire	Anciens sénateurs Second Empire	2014-02-26 11:38:56	\N
\.


--
-- Data for Name: fonact_participant; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY fonact_participant (fapcod, faplic, faplicfem, faplib, faplibfem, faplicplu, faplicfemplu, faplibplu, faplibfemplu) FROM stdin;
RAPPORTEUR_FOND	Rapporteur au fond	Rapporteure au fond	Rapporteur au fond	Rapporteure au fond	Rapporteurs au fond	Rapporteures au fond	Rapporteurs au fond	Rapporteures au fond
PRESIDENT	Président	Présidente	Président	Présidente	Présidents	Présidentes	Présidents	Présidentes
PARTICIPANT	Participant	Participante	Participant	Participante	Participants	Participantes	Participants	Participantes
RAPPORTEUR_AVIS	Rapporteur pour avis	Rapporteure pour avis	Rapporteur pour avis	Rapporteure pour avis	Rapporteurs pour avis	Rapporteures pour avis	Rapporteurs pour avis	Rapporteures pour avis
\.


--
-- Data for Name: foncom; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY foncom (foncomcod, foncomlib, foncomlic, foncomnumtri, foncomlil, foncomlicfem, foncomlibfem, foncomlilfem, foncomlicplu, foncomlibplu, foncomlilplu, foncomlicfemplu, foncomlibfemplu, foncomlilfemplu, syscredat, sysmajdat) FROM stdin;
MEMBRECOM	 	Membre	9	 	Membre	 	 	Membres	 	 	Membres	Membres	Membres	\N	\N
PDTCOM	Président	Président	1	Président	Présidente	Présidente	Présidente	Présidents	Présidents	Présidents	Présidentes	Présidentes	Présidentes	\N	\N
RAPGENCOM	Rapporteur général	Rapporteur général	2	Rapporteur général	Rapporteure générale	Rapporteure générale	Rapporteure générale	Rapporteurs généraux	Rapporteurs généraux	Rapporteurs généraux	Rapporteures générales	Rapporteures générales	Rapporteures générales	\N	\N
SECRETCOM	Secrétaire	Secrétaire	5	Secrétaire	Secrétaire	Secrétaire	Secrétaire	Secrétaires	Secrétaires	Secrétaires	Secrétaires	Secrétaires	Secrétaires	\N	\N
VICPDTCOM	Vice-Président	Vice-Président	4	Vice-Président	Vice-Présidente	Vice-Présidente	Vice-Présidente	Vice-Présidents	Vice-Présidents	Vice-Présidents	Vice-Présidentes	Vice-Présidentes	Vice-Présidentes	\N	\N
RAPCOM	Rapporteur	Rapporteur	7	Rapporteur	Rapporteure	Rapporteure	Rapporteur	Rapporteurs	Rapporteurs	Rapporteurs	Rapporteures	Rapporteures	Rapporteures	\N	\N
RAPADJCOM	Rapporteur adjoint	Rapporteur adjoint	8	Rapporteur adjoint	Rapporteure adjointe	Rapporteure adjointe	Rapporteur adjoint	Rapporteurs adjoints	Rapporteurs adjoints	Rapporteurs adjoints	Rapporteures adjointes	Rapporteures adjointes	Rapporteures adjointes	\N	\N
VICPDTHONCOM	Vice-Président d'honneur	Vice-Président d'honneur	10	Vice-Président d'honneur	Vice-Présidente d'honneur	Vice-Présidente d'honneur	Vice-Présidente d'honneur	Vice-Présidents d'honneur	Vice-Présidents d'honneur	Vice-Présidents d'honneur	Vice-Présidentes d'honneur	Vice-Présidentes d'honneur	Vice-Présidentes d'honneur	\N	\N
VICPDTPRECOM	Premier Vice-Président	Premier Vice-Président	3	Premier Vice-Président	Première Vice-Présidente	Première Vice-Présidente	Première Vice-Présidente	Premiers Vice-Présidents	Premiers Vice-Présidents	Premiers Vice-Présidents	Premières Vice-Présidentes	Premières Vice-Présidentes	Premières Vice-Présidentes	\N	\N
PDTRAPCOM	Président et rapporteur	Président et rapporteur	1	Président et rapporteur	Présidente et rapporteure	Présidente et rapporteure	Présidente et rapporteure	Président et rapporteur	Président et rapporteur	Président et rapporteur	Présidentes et rapporteures	Présidentes et rapporteures	Présidentes et rapporteures	\N	\N
VICPDTRAPCOM	Vice-Président et rapporteur	Vice-Président et rapporteur	4	Vice-Président et rapporteur	Vice-Président et rapporteur	Vice-Présidente et rapporteure	Vice-Présidente et rapporteure	Vice-Président et rapporteur	Vice-Président et rapporteur	Vice-Président et rapporteur	Vice-Présidentes et rapporteures	Vice-Présidentes et rapporteures	Vice-Présidentes et rapporteures	\N	\N
SECRETRAPCOM	Secrétaire Rapporteur	Secrétaire Rapporteur	6	Secrétaire Rapporteur	Secrétaire rapporteure	Secrétaire rapporteure	Secrétaire rapporteur	Secrétaires rapporteur	Secrétaires Rapporteur	Secrétaires Rapporteur	Secrétaires rapporteures	Secrétaires rapporteures	Secrétaires rapporteures	\N	\N
\.


--
-- Data for Name: fondelega; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY fondelega (fondelcod, fondellib, fondellic, fondelnumtri, fondellil, fondellicfem, fondellibfem, fondellilfem, fondellicplu, fondellibplu, fondellilplu, fondellicfemplu, fondellibfemplu, fondellilfemplu, syscredat, sysmajdat) FROM stdin;
PDTDRTDEL	Président de droit	Président de droit	2	Président de droit	Présidente de droit	Présidente de droit	Présidente de droit	Présidents de droit	Présidents de droit	Présidents de droit	Présidentes de droit	Présidentes de droit	Présidentes de droit	\N	\N
PDTEXECUTDEL	Président exécutif	Président exécutif	3	Président exécutif	Présidente exécutive	Présidente exécutive	Présidente exécutive	Présidents exécutifs	Présidents exécutifs	Présidents exécutifs	Présidentes exécutives	Présidentes exécutives	Présidentes exécutives	\N	\N
VICPDTDELDEL	Vice-Président délégué	Vice-Président délégué	7	Vice-Président délégué	Vice-Présidente déléguée	Vice-Présidente déléguée	Vice-Présidente déléguée	Vice-Présidents délégués	Vice-Présidents délégués	Vice-Présidents délégués	Vice-Présidentes déléguées	Vice-Présidentes déléguées	Vice-Présidentes déléguées	\N	\N
TRESORDEL	Trésorier	Trésorier	12	Trésorier	Trésorière	Trésorière	Trésorière	Trésoriers	Trésoriers	Trésoriers	Trésorières	Trésorières	Trésorières	\N	\N
TRESORADJDEL	Trésorier adjoint	Trésorier adjoint	13	Trésorier adjoint	Trésorière adjointe	Trésorière adjointe	Trésorière adjointe	Trésoriers adjoints	Trésoriers adjoints	Trésoriers adjoints	Trésorières adjointes	Trésorières adjointes	Trésorières adjointes	\N	\N
DELEGUEDEL	Membre	Membre	17	Membre	Membre	Membre	Membre	Membres	Membres	Membres	Membres	Membres	Membres	\N	\N
DELSUPDEL	Membre suppléant	Suppléant	16	Membre suppléant	Suppléante	Membre suppléante	Membre suppléante	Suppléants	Membres suppléants	Membres suppléants	Suppléantes	Suppléantes	Suppléantes	\N	\N
DELTITDEL	Membre titulaire	Titulaire	15	Membre titulaire	Titulaire	Membre titulaire	Membre titulaire	Titulaires	Membres titulaires	Membres titulaires	Titulaires	Titulaires	Titulaires	\N	\N
PDTDEL	Président	Président	1	Président	Présidente	Présidente	Présidente	Présidents	Présidents	Présidents	Présidentes	Présidentes	Présidentes	\N	\N
SECRETDEL	Secrétaire	Secrétaire	10	Secrétaire	Secrétaire	Secrétaire	Secrétaire	Secrétaires	Secrétaires	Secrétaires	Secrétaires	Secrétaires	Secrétaires	\N	\N
VICPDTDEL	Vice-Président	Vice-Président	8	Vice-Président	Vice-Présidente	Vice-Présidente	Vice-Présidente	Vice-Présidents	Vice-Présidents	Vice-Présidents	Vice-Présidents	Vice-Présidents	Vice-Présidents	\N	\N
SECRETGENDEL	Secrétaire Général	Secrétaire Général	9	Secrétaire Général	Secrétaire Générale	Secrétaire Générale	Secrétaire Général	Secrétaires Généraux	Secrétaires Généraux	Secrétaires Généraux	Secrétaires Généraux	Secrétaires Généraux	Secrétaires Généraux	\N	\N
AUTFONDEL	Membre du Bureau	Autre membre Bureau	13	Membre du Bureau	Membre du Bureau	Membre du Bureau	Membre du Bureau	Membres du Bureau	Membres du Bureau	Membres du Bureau	Membres du Bureau	Membres du Bureau	Membres du Bureau	\N	\N
VICPDTPREDEL	Premier Vice-Président	Premier Vice-Président	6	Premier Vice-Président	Première Vice-Présidente	Première Vice-Présidente	Première Vice-Présidente	Premiers Vice-Présidents	Premiers Vice-Président	Premiers Vice-Présidents	Premières Vice-Présidentes	Premières Vice-Présidentes	Premières Vice-Présidentes	\N	\N
PDTDELDEL	Président délégué	Président délégué	4	Président délégué	Présidente déléguée	Présidente déléguée	Présidente déléguée	Présidents délégués	Présidents délégués	Présidents délégués	Présidentes déléguées	Présidentes déléguées	Présidentes déléguées	\N	\N
SECRETADJDEL	Secrétaire adjoint	Secrétaire adjoint	11	Secrétaire adjoint	Secrétaire adjointe	Secrétaire adjointe	Secrétaire adjointe	Secrétaires adjoints	Secrétaires adjoints	Secrétaires adjoints	Secrétaires adjointes	Secrétaires adjointes	Secrétaires adjointes	\N	\N
CHEFDEL	Chef	Chef	1	Chef	Chef	Chef	Chef	Chefs	Chefs	Chefs	Chefs	Chefs	Chefs	\N	\N
VICPDTPRESIM	Premier Vice-Président, chargé de la simplification des normes	Premier Vice-Président, simplification des normes	5	Premier Vice-Président, chargé de la simplification des normes	Première Vice-Présidente, simplification des normes	Première Vice-Présidente, chargée de la simplification des normes	Première Vice-Présidente, chargée de la simplification des normes	Premiers Vice-Présidents, simplification des normes	Premiers Vice-Présidents, chargés de la simplification des normes	Premiers Vice-Présidents, chargés de la simplification des normes	Premières Vice-Présidentes, simplification des normes	Premières Vice-Présidentes, chargées de la simplification des normes	Premières Vice-Présidentes, chargées de la simplification des normes	\N	\N
RAPGEN	Rapporteur général	Rapporteur général	18	Rapporteur général	Rapporteure générale	Rapporteure générale	Rapporteure générale	Rapporteurs généraux	Rapporteurs généraux	Rapporteurs généraux	Rapporteures générales	Rapporteures générales	Rapporteures générales	\N	\N
\.


--
-- Data for Name: fongrppol; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY fongrppol (fongrppolcod, fongrppollib, fongrppollic, fongrppolnumtri, fongrppollil, fongrppollibfem, fongrppollicfem, fongrppollilfem, fongrppollibplu, fongrppollicplu, fongrppollilplu, syscredat, sysmajdat, fongrppollicfemplu, fongrppollibfemplu, fongrppollilfemplu) FROM stdin;
DELPOL	Délégué	Délégué	5	Délégué	Déléguée	Déléguée	Déléguée	Délégués	Délégués	Délégués	\N	\N	Déléguées	Déléguées	Déléguées
MEMBREPOL	                                           	Membre	6	                                           	                                           	Membre	                                           	                                           	Membres	                                           	\N	\N	Membres	                                           s	                                           s
PDTPOL	Président	Président	1	Président	Présidente	Présidente	Présidente	Présidents	Présidents	Présidents	\N	\N	Présidentes	Présidentes	Présidentes
PDTDELPOL	Président délégué	Président délégué	2	Président délégué	Présidente déléguée	Présidente déléguée	Présidente déléguée	Présidents délégués	Présidents délégués	Présidents délégués	\N	\N	Présidentes déléguées	Présidentes déléguées	Présidentes déléguées
VICPDTPOL	Vice-Président	Vice-Président	3	Vice-Président	Vice-Présidente	Vice-Présidente	Vice-Présidente	Vice-Présidents	Vice-Présidents	Vice-Présidents	\N	\N	Vice-Présidentes	Vice-Présidentes	Vice-Présidentes
VICPDTDELPOL	Vice-Président délégué	Vice-Président délégué	4	Vice-Président délégué	Vice-Présidente déléguée	Vice-Présidente déléguée	Vice-Présidente déléguée	Vice-Présidents délégués	Vice-Présidents délégués	Vice-Présidents délégués	\N	\N	Vice-Présidentes déléguées	Vice-Présidentes déléguées	Vice-Présidentes déléguées
\.


--
-- Data for Name: fongrpsen; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY fongrpsen (fongrpsencod, fongrpsenlib, fongrpsenlic, fongrpsennumtri, fongrpsenlil, fongrpsenlibfem, fongrpsenlicfem, fongrpsenlilfem, fongrpsenlibplu, fongrpsenlicplu, fongrpsenlilplu, syscredat, sysmajdat, fongrpsenlicfemplu, fongrpsenlibfemplu, fongrpsenlilfemplu) FROM stdin;
SECRET	Secrétaire	Secrétaire	9	Secrétaire	Secrétaire	Secrétaire	Secrétaire	Secrétaires	Secrétaires	Secrétaires	\N	\N	Secrétaires	Secrétaires	Secrétaires
PDT	Président	Président	1	Président	Présidente	Présidente	Présidente	Présidents	Présidents	Présidents	\N	\N	Présidentes	Présidentes	Présidentes
TRESORADJ	Trésorier adjoint	Trésorier adjoint	12	Trésorier adjoint	Trésorière adjointe	Trésorière adjointe	Trésorière adjointe	Trésoriers adjoints	Trésoriers adjoints	Trésoriers adjoints	\N	\N	Trésorières adjointes	Trésorières adjointes	Trésorières adjointes
MEMBRE	 	Membre	20	Membre	 	Membre	Membre	Membres	Membres	 	\N	\N	Membres	Membres	Membres
PDTDEL	Président délégué	Président délégué	3	Président délégué	Présidente déléguée	Présidente déléguée	Présidente déléguée	Présidents délégués	Présidents délégués	Présidents délégués	\N	\N	Présidentes déléguées	Présidentes déléguées	Présidentes déléguées
PDTHON	Président d'honneur	Président d'honneur	2	Président d'honneur	Présidente d'honneur	Présidente d'honneur	Présidente d'honneur	Présidents d'honneur	Présidents d'honneur	Présidents d'honneur	\N	\N	Présidentes d'honneur	Présidentes d'honneur	Présidentes d'honneur
SECGEN	Secrétaire général	Secrétaire général	8	Secrétaire général	Secrétaire générale	Secrétaire générale	Secrétaire générale	Secrétaires généraux	Secrétaires généraux	Secrétaires généraux	\N	\N	Secrétaires générales	Secrétaires générales	Secrétaires générales
TRESOR	Trésorier	Trésorier	11	Trésorier	Trésorière	Trésorière	Trésorière	Trésoriers	Trésoriers	Trésoriers	\N	\N	Trésorières	Trésorières	Trésorières
VICPDT	Vice-Président	Vice-Président	7	Vice-Président	Vice-Présidente	Vice-Présidente	Vice-Présidente	Vice-Présidents	Vice-Présidents	Vice-Présidents	\N	\N	Vice-Présidentes	Vice-Présidentes	Vice-Présidentes
MEMBREBUR	Membre du bureau	Membre bureau	14	Membre du bureau	Membre du bureau	Membre bureau	Membre du bureau	Membres du bureau	Membres bureau	Membres du bureau	\N	\N	Membres bureau	Membres du bureau	Membres du bureau
SECRETADJ	Secrétaire adjoint	Secrétaire adjoint	10	Secrétaire adjoint	Secrétaire adjointe	Secrétaire adjointe	Secrétaire adjoint	Secrétaires adjoints	Secrétaires adjoints	Secrétaires adjoints	\N	\N	Secrétaires adjointes	Secrétaires adjointes	Secrétaires adjointes
VICPDTDRT	Vice-Président de droit	Vice-Président de droit	2	Vice-Président de droit	Vice-Présidente de droit	Vice-Présidente droit	Vice-Présidente de droit	Vice-Présidents de droit	Vice-Présidents droit	Vice-Présidents de droit	\N	\N	Vice-Présidentes droit	Vice-Présidentes de droit	Vice-Président de droit
VICPDTPRE	Premier Vice-Président	Premier Vice-Président	4	Premier Vice-Président	Première Vice-Présidente	Première Vice-Présidente	Première Vice-Présidente	Premier Vice-Présidents	Premier Vice-Présidents	Premier Vice-Président	\N	\N	Premières Vice-Présidentes	Premières Vice-Présidentes	Premières Vice-Présidentes
VICPDTDEU	Deuxième Vice-Président	Deuxième Vice-Président	5	Deuxième Vice-Président	Deuxième Vice-Présidente	Deuxième Vice-Présidente	Deuxième Vice-Présidente	Deuxième Vice-Présidents	Deuxième Vice-Présidents	Deuxième Vice-Présidents	\N	\N	Deuxièmes Vice-Présidentes	Deuxièmes Vice-Présidentes	Deuxièmes Vice-Présidentes
VICPDTDEL	Vice-Président délégué	Vice-Président délégué	6	Vice-Président délégué	Vice-Présidente déléguée	Vice-Présidente déléguée	Vice-Présidente déléguée	Vice-Présidents délégués	Vice-Présidents délégués	Vice-Présidents délégués	\N	\N	Vice-Présidentes déléguées	Vice-Présidentes déléguées	Vice-Présidentes déléguées
MEMBREDRT	Membre de droit	Membre de droit	13	Membre de droit	Membre de droit	Membre de droit	Membre de droit	Membres de droit	Membres de droit	Membres de droit	\N	\N	Membres de droits	Membres de droits	Membres de droits
\.


--
-- Data for Name: fonmemcom; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY fonmemcom (fonmemcomid, foncomcod, fonmemcomdatdeb, fonmemcomdatfin, fonmemcomrngprt, temvalcod, evelic, evelib, evelil, eveobs, memcomid, syscredat, sysmajdat) FROM stdin;
237	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	237	\N	\N
238	MEMBRECOM	\N	1998-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	238	\N	\N
10995	MEMBRECOM	2013-04-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9282	\N	\N
240	MEMBRECOM	\N	2000-10-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	240	\N	\N
10996	MEMBRECOM	2013-04-04 00:00:00	2014-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9283	\N	\N
242	VICPDTCOM	1996-02-21 00:00:00	1998-10-02 00:00:00	5	ANCIEN	\N	\N	\N	\N	242	\N	\N
10997	VICPDTCOM	2013-04-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9284	\N	2014-09-28 19:07:43
244	MEMBRECOM	\N	1999-11-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	244	\N	\N
245	PDTCOM	1983-04-20 00:00:00	1998-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	245	\N	\N
246	VICPDTCOM	1997-01-29 00:00:00	1998-10-06 00:00:00	1	ANCIEN	\N	\N	\N	\N	246	\N	\N
247	SECRETCOM	1995-10-05 00:00:00	1998-10-06 00:00:00	3	ANCIEN	\N	\N	\N	\N	247	\N	\N
248	VICPDTCOM	1996-02-14 00:00:00	1998-10-06 00:00:00	4	ANCIEN	\N	\N	\N	\N	248	\N	\N
249	MEMBRECOM	\N	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	249	\N	\N
251	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	251	\N	\N
252	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	252	\N	\N
253	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	253	\N	\N
254	MEMBRECOM	2001-10-03 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	254	\N	\N
255	MEMBRECOM	\N	1998-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	255	\N	\N
256	MEMBRECOM	\N	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	256	\N	\N
10998	RAPCOM	2013-04-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9285	\N	2014-09-28 17:31:42
259	MEMBRECOM	\N	1998-11-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	259	\N	\N
260	MEMBRECOM	\N	1998-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	260	\N	\N
261	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	261	\N	\N
262	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	262	\N	\N
263	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	263	\N	\N
264	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	264	\N	\N
265	MEMBRECOM	\N	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	265	\N	\N
266	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	266	\N	\N
267	MEMBRECOM	1998-03-05 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	267	\N	\N
268	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	268	\N	\N
269	MEMBRECOM	\N	1998-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	269	\N	\N
272	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	272	\N	\N
273	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	273	\N	\N
274	VICPDTCOM	1995-10-05 00:00:00	1998-10-06 00:00:00	1	ANCIEN	\N	\N	\N	\N	274	\N	\N
275	SECRETCOM	1992-10-08 00:00:00	1998-10-06 00:00:00	4	ANCIEN	\N	\N	\N	\N	275	\N	\N
10994	MEMBRECOM	2013-04-04 00:00:00	2020-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9281	\N	\N
277	SECRETCOM	1992-10-08 00:00:00	1998-10-06 00:00:00	2	ANCIEN	\N	\N	\N	\N	277	\N	\N
278	MEMBRECOM	\N	1998-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	278	\N	\N
280	SECRETCOM	1995-10-05 00:00:00	1998-10-06 00:00:00	4	ANCIEN	\N	\N	\N	\N	280	\N	\N
281	MEMBRECOM	1997-10-07 00:00:00	1998-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	281	\N	\N
282	MEMBRECOM	\N	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	282	\N	\N
283	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	283	\N	\N
284	PDTCOM	1986-10-06 00:00:00	1998-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	284	\N	\N
285	MEMBRECOM	\N	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	285	\N	\N
286	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	286	\N	\N
287	MEMBRECOM	2001-10-03 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	287	\N	\N
289	MEMBRECOM	1997-01-30 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	289	\N	\N
290	MEMBRECOM	\N	1998-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	290	\N	\N
291	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	291	\N	\N
292	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	292	\N	\N
294	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	294	\N	\N
295	VICPDTCOM	1997-10-08 00:00:00	1998-10-06 00:00:00	6	ANCIEN	\N	\N	\N	\N	295	\N	\N
296	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	296	\N	\N
297	MEMBRECOM	\N	2000-05-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	297	\N	\N
298	MEMBRECOM	\N	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	298	\N	\N
299	MEMBRECOM	\N	2000-05-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	299	\N	\N
301	MEMBRECOM	\N	1999-01-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	301	\N	\N
302	MEMBRECOM	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	302	\N	\N
303	MEMBRECOM	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	303	\N	\N
304	MEMBRECOM	\N	1998-11-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	304	\N	\N
305	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	305	\N	\N
306	MEMBRECOM	1992-10-07 00:00:00	1998-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	306	\N	\N
308	MEMBRECOM	\N	1998-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	308	\N	\N
309	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	309	\N	\N
310	SECRETCOM	1977-10-06 00:00:00	1980-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	310	\N	\N
311	MEMBRECOM	1986-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	311	\N	\N
312	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	312	\N	\N
313	SECRETCOM	1992-10-08 00:00:00	2001-09-30 00:00:00	3	ANCIEN	\N	\N	\N	\N	313	\N	\N
314	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	314	\N	\N
315	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	315	\N	\N
318	MEMBRECOM	\N	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	318	\N	\N
319	MEMBRECOM	\N	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	319	\N	\N
321	MEMBRECOM	\N	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	321	\N	\N
322	MEMBRECOM	\N	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	323	\N	\N
323	MEMBRECOM	\N	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	324	\N	\N
324	MEMBRECOM	\N	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	325	\N	\N
325	MEMBRECOM	\N	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	326	\N	\N
326	MEMBRECOM	\N	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	327	\N	\N
328	MEMBRECOM	1998-10-01 00:00:00	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	329	\N	\N
329	MEMBRECOM	1998-10-01 00:00:00	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	330	\N	\N
330	MEMBRECOM	1998-10-01 00:00:00	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	331	\N	\N
331	MEMBRECOM	1998-10-01 00:00:00	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	332	\N	\N
333	MEMBRECOM	1998-10-01 00:00:00	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	334	\N	\N
335	MEMBRECOM	1998-10-01 00:00:00	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	336	\N	\N
336	MEMBRECOM	1998-10-01 00:00:00	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	337	\N	\N
340	MEMBRECOM	1998-10-01 00:00:00	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	340	\N	\N
339	MEMBRECOM	1998-10-01 00:00:00	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	339	\N	\N
343	MEMBRECOM	1998-10-01 00:00:00	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	342	\N	\N
344	MEMBRECOM	\N	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	343	\N	\N
345	MEMBRECOM	1998-10-01 00:00:00	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	344	\N	\N
346	MEMBRECOM	1998-10-01 00:00:00	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	345	\N	\N
347	MEMBRECOM	1998-10-01 00:00:00	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	346	\N	\N
349	MEMBRECOM	1998-10-01 00:00:00	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	347	\N	\N
350	MEMBRECOM	1998-10-01 00:00:00	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	348	\N	\N
353	MEMBRECOM	1998-10-01 00:00:00	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	351	\N	\N
354	MEMBRECOM	1998-10-01 00:00:00	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	352	\N	\N
355	MEMBRECOM	1998-10-01 00:00:00	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	353	\N	\N
356	MEMBRECOM	1998-10-01 00:00:00	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	354	\N	\N
357	MEMBRECOM	1998-10-01 00:00:00	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	355	\N	\N
358	MEMBRECOM	1998-10-01 00:00:00	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	356	\N	\N
359	MEMBRECOM	1998-10-01 00:00:00	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	357	\N	\N
360	MEMBRECOM	1998-10-01 00:00:00	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	358	\N	\N
361	MEMBRECOM	1998-10-01 00:00:00	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	359	\N	\N
362	MEMBRECOM	1998-10-01 00:00:00	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	360	\N	\N
363	MEMBRECOM	1998-10-01 00:00:00	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	361	\N	\N
364	MEMBRECOM	1998-10-01 00:00:00	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	362	\N	\N
366	MEMBRECOM	1998-10-01 00:00:00	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	364	\N	\N
367	MEMBRECOM	1998-10-01 00:00:00	1998-10-05 00:00:00	1	ANCIEN	\N	\N	\N	\N	365	\N	\N
445	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	438	\N	\N
446	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	439	\N	\N
447	MEMBRECOM	1998-10-06 00:00:00	2000-01-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	440	\N	\N
450	MEMBRECOM	1998-10-06 00:00:00	1999-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	443	\N	\N
451	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	444	\N	\N
452	MEMBRECOM	\N	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	322	\N	\N
453	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	445	\N	\N
466	PDTCOM	1998-10-07 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	124	\N	\N
455	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	447	\N	\N
456	MEMBRECOM	1998-10-06 00:00:00	2001-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	448	\N	\N
457	MEMBRECOM	1998-10-06 00:00:00	1998-11-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	449	\N	\N
458	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	450	\N	\N
327	MEMBRECOM	\N	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	328	\N	\N
459	MEMBRECOM	1998-10-06 00:00:00	2001-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	451	\N	\N
460	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	452	\N	\N
461	MEMBRECOM	1998-10-06 00:00:00	2001-06-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	453	\N	\N
341	MEMBRECOM	1998-10-01 00:00:00	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	341	\N	\N
463	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	455	\N	\N
464	MEMBRECOM	1998-10-06 00:00:00	2001-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	456	\N	\N
465	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	457	\N	\N
467	VICPDTCOM	1998-10-07 00:00:00	2001-10-03 00:00:00	5	ANCIEN	\N	\N	\N	\N	13	\N	\N
468	MEMBRECOM	1983-10-06 00:00:00	1995-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	146	\N	\N
470	VICPDTCOM	1998-10-07 00:00:00	2000-05-04 00:00:00	3	ANCIEN	\N	\N	\N	\N	117	\N	\N
471	VICPDTCOM	1998-10-07 00:00:00	2001-09-30 00:00:00	4	ANCIEN	\N	\N	\N	\N	140	\N	\N
472	VICPDTCOM	1998-10-07 00:00:00	2001-10-03 00:00:00	6	ANCIEN	\N	\N	\N	\N	173	\N	\N
473	SECRETCOM	1998-10-07 00:00:00	2001-10-03 00:00:00	1	ANCIEN	\N	\N	\N	\N	277	\N	\N
475	SECRETCOM	1998-10-07 00:00:00	2001-10-03 00:00:00	4	ANCIEN	\N	\N	\N	\N	191	\N	\N
476	PDTCOM	1998-10-07 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	135	\N	\N
478	MEMBRECOM	1998-10-07 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	51	\N	\N
479	VICPDTCOM	1998-10-07 00:00:00	2001-09-30 00:00:00	2	ANCIEN	\N	\N	\N	\N	139	\N	\N
480	MEMBRECOM	1998-10-07 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	87	\N	\N
482	MEMBRECOM	1998-10-07 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2	\N	\N
483	SECRETCOM	1998-10-07 00:00:00	2001-10-03 00:00:00	4	ANCIEN	\N	\N	\N	\N	280	\N	\N
316	PDTCOM	1993-04-14 00:00:00	1998-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	316	\N	\N
369	MEMBRECOM	1998-10-01 00:00:00	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	366	\N	\N
371	MEMBRECOM	1998-10-01 00:00:00	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	367	\N	\N
373	MEMBRECOM	1998-10-01 00:00:00	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	368	\N	\N
375	MEMBRECOM	1998-10-01 00:00:00	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	369	\N	\N
376	MEMBRECOM	1998-10-01 00:00:00	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	370	\N	\N
377	MEMBRECOM	\N	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	371	\N	\N
378	MEMBRECOM	1998-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	372	\N	\N
379	MEMBRECOM	1998-10-03 00:00:00	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	373	\N	\N
380	MEMBRECOM	1998-10-06 00:00:00	2000-01-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	374	\N	\N
382	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	375	\N	\N
383	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	376	\N	\N
384	MEMBRECOM	1998-10-06 00:00:00	2000-05-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	377	\N	\N
385	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	378	\N	\N
386	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	379	\N	\N
387	MEMBRECOM	1998-10-06 00:00:00	2001-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	380	\N	\N
388	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	381	\N	\N
389	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	382	\N	\N
390	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	383	\N	\N
391	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	384	\N	\N
392	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	385	\N	\N
393	MEMBRECOM	1998-10-06 00:00:00	2001-04-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	386	\N	\N
394	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	387	\N	\N
395	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	388	\N	\N
396	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	389	\N	\N
397	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	390	\N	\N
398	MEMBRECOM	1998-10-06 00:00:00	1998-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	391	\N	\N
399	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	392	\N	\N
400	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	393	\N	\N
401	MEMBRECOM	1998-10-06 00:00:00	1998-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	394	\N	\N
402	MEMBRECOM	1998-10-06 00:00:00	1998-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	395	\N	\N
403	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	396	\N	\N
404	MEMBRECOM	1998-10-06 00:00:00	2001-03-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	397	\N	\N
405	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	398	\N	\N
406	MEMBRECOM	1998-10-06 00:00:00	2001-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	399	\N	\N
407	MEMBRECOM	1998-10-06 00:00:00	2001-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	400	\N	\N
408	MEMBRECOM	1998-10-06 00:00:00	2002-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	401	\N	\N
409	MEMBRECOM	1998-10-06 00:00:00	1998-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	402	\N	\N
410	MEMBRECOM	1998-10-06 00:00:00	2001-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	403	\N	\N
411	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	404	\N	\N
412	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	405	\N	\N
413	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	406	\N	\N
415	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	408	\N	\N
416	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	409	\N	\N
417	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	410	\N	\N
418	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	411	\N	\N
419	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	412	\N	\N
420	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	413	\N	\N
421	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	414	\N	\N
422	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	415	\N	\N
423	MEMBRECOM	1998-10-06 00:00:00	1999-01-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	416	\N	\N
424	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	417	\N	\N
425	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	418	\N	\N
427	MEMBRECOM	1998-10-06 00:00:00	2001-09-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	420	\N	\N
428	MEMBRECOM	1998-10-06 00:00:00	2000-05-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	421	\N	\N
429	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	422	\N	\N
430	MEMBRECOM	1998-10-06 00:00:00	2000-03-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	423	\N	\N
431	MEMBRECOM	1998-10-06 00:00:00	1999-09-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	424	\N	\N
432	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	425	\N	\N
433	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	426	\N	\N
434	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	427	\N	\N
435	MEMBRECOM	1998-10-06 00:00:00	2000-05-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	428	\N	\N
436	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	429	\N	\N
438	MEMBRECOM	1998-10-06 00:00:00	2001-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	431	\N	\N
440	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	433	\N	\N
441	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	434	\N	\N
442	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	435	\N	\N
443	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	436	\N	\N
444	MEMBRECOM	1998-10-06 00:00:00	2001-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	437	\N	\N
1	MEMBRECOM	2001-10-03 00:00:00	2004-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1	\N	\N
2	SECRETCOM	1992-10-08 00:00:00	1998-10-06 00:00:00	3	ANCIEN	\N	\N	\N	\N	2	\N	\N
3	MEMBRECOM	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3	\N	\N
5	MEMBRECOM	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	5	\N	\N
6	VICPDTCOM	1980-10-07 00:00:00	1998-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6	\N	\N
7	MEMBRECOM	2001-10-03 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7	\N	\N
8	VICPDTCOM	1995-10-05 00:00:00	1998-09-30 00:00:00	4	ANCIEN	\N	\N	\N	\N	8	\N	\N
9	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9	\N	\N
10	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10	\N	\N
11	MEMBRECOM	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11	\N	\N
12	MEMBRECOM	1989-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12	\N	\N
13	VICPDTCOM	\N	1998-10-06 00:00:00	1	ANCIEN	\N	\N	\N	\N	13	\N	\N
14	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14	\N	\N
15	MEMBRECOM	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15	\N	\N
16	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16	\N	\N
17	MEMBRECOM	2001-10-03 00:00:00	2007-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17	\N	\N
18	VICPDTCOM	1992-10-08 00:00:00	1998-09-30 00:00:00	3	ANCIEN	\N	\N	\N	\N	18	\N	\N
19	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19	\N	\N
20	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	20	\N	\N
21	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	21	\N	\N
22	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	22	\N	\N
23	VICPDTCOM	1996-02-07 00:00:00	1998-10-06 00:00:00	5	ANCIEN	\N	\N	\N	\N	23	\N	\N
24	MEMBRECOM	\N	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	24	\N	\N
25	MEMBRECOM	\N	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	25	\N	\N
26	VICPDTCOM	1996-02-14 00:00:00	1998-09-30 00:00:00	6	ANCIEN	\N	\N	\N	\N	26	\N	\N
27	MEMBRECOM	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	27	\N	\N
28	MEMBRECOM	1989-10-02 00:00:00	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	28	\N	\N
29	MEMBRECOM	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	29	\N	\N
30	MEMBRECOM	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	30	\N	\N
31	MEMBRECOM	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	31	\N	\N
32	MEMBRECOM	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	32	\N	\N
33	MEMBRECOM	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	33	\N	\N
34	MEMBRECOM	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	34	\N	\N
35	MEMBRECOM	\N	1998-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	35	\N	\N
36	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	36	\N	\N
37	MEMBRECOM	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	37	\N	\N
38	SECRETCOM	1986-10-06 00:00:00	1998-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	38	\N	\N
39	MEMBRECOM	\N	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	39	\N	\N
40	MEMBRECOM	\N	1998-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	40	\N	\N
42	MEMBRECOM	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	42	\N	\N
44	SECRETCOM	1996-02-14 00:00:00	1998-10-06 00:00:00	3	ANCIEN	\N	\N	\N	\N	44	\N	\N
45	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	45	\N	\N
46	MEMBRECOM	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	46	\N	\N
47	MEMBRECOM	\N	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	47	\N	\N
48	MEMBRECOM	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	48	\N	\N
632	MEMBRECOM	2000-10-25 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	524	\N	\N
633	MEMBRECOM	2000-10-25 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	525	\N	\N
634	MEMBRECOM	2001-01-17 00:00:00	0001-01-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	526	\N	\N
635	MEMBRECOM	2001-01-23 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	527	\N	\N
636	MEMBRECOM	2001-01-23 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	528	\N	\N
637	VICPDTCOM	2001-01-24 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	243	\N	\N
10973	MEMBRECOM	2013-04-02 00:00:00	2015-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9260	\N	2015-10-13 14:23:12
639	MEMBRECOM	2001-02-08 00:00:00	2001-03-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	529	\N	\N
640	MEMBRECOM	2001-03-03 00:00:00	2001-03-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	530	\N	\N
700	MEMBRECOM	2001-03-27 00:00:00	2001-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	601	\N	\N
701	MEMBRECOM	2001-03-27 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	602	\N	\N
703	MEMBRECOM	2001-03-28 00:00:00	2001-04-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	604	\N	\N
704	MEMBRECOM	2001-04-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	605	\N	\N
705	MEMBRECOM	2001-04-05 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	606	\N	\N
706	MEMBRECOM	2001-04-05 00:00:00	2001-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	607	\N	\N
709	MEMBRECOM	2001-06-14 00:00:00	2001-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	608	\N	\N
708	SECRETCOM	2001-04-18 00:00:00	2001-10-03 00:00:00	3	ANCIEN	\N	\N	\N	\N	386	\N	\N
710	MEMBRECOM	2001-06-14 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	609	\N	\N
711	MEMBRECOM	2001-06-21 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	610	\N	\N
712	MEMBRECOM	2001-06-21 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	611	\N	\N
715	MEMBRECOM	2001-06-19 00:00:00	2001-11-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	614	\N	\N
716	SECRETCOM	2001-06-19 00:00:00	2001-11-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	615	\N	\N
717	MEMBRECOM	2001-06-19 00:00:00	2001-11-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	616	\N	\N
718	MEMBRECOM	2001-06-19 00:00:00	2001-11-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	617	\N	\N
719	MEMBRECOM	2001-06-19 00:00:00	2001-11-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	618	\N	\N
720	VICPDTCOM	2001-06-19 00:00:00	2001-11-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	619	\N	\N
721	MEMBRECOM	2001-06-19 00:00:00	2001-11-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	620	\N	\N
722	MEMBRECOM	2001-06-19 00:00:00	2001-11-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	621	\N	\N
723	VICPDTCOM	2001-06-19 00:00:00	2001-11-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	622	\N	\N
756	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	655	\N	\N
725	VICPDTCOM	2001-06-19 00:00:00	2001-11-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	624	\N	\N
726	MEMBRECOM	2001-06-19 00:00:00	2001-11-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	625	\N	\N
727	SECRETCOM	2001-06-19 00:00:00	2001-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	626	\N	\N
728	MEMBRECOM	2001-06-19 00:00:00	2001-11-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	627	\N	\N
730	VICPDTCOM	2001-06-19 00:00:00	2001-11-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	629	\N	\N
731	MEMBRECOM	2001-06-19 00:00:00	2001-11-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	630	\N	\N
732	MEMBRECOM	2001-06-19 00:00:00	2001-11-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	631	\N	\N
733	RAPCOM	2001-06-19 00:00:00	2001-11-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	632	\N	\N
734	MEMBRECOM	2001-06-19 00:00:00	2001-11-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	633	\N	\N
735	MEMBRECOM	2001-06-19 00:00:00	2001-11-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	634	\N	\N
736	MEMBRECOM	2001-06-19 00:00:00	2001-11-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	635	\N	\N
737	MEMBRECOM	2001-06-19 00:00:00	2001-11-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	636	\N	\N
738	MEMBRECOM	2001-06-19 00:00:00	2001-11-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	637	\N	\N
739	PDTCOM	2001-06-19 00:00:00	2001-11-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	638	\N	\N
740	MEMBRECOM	2001-06-19 00:00:00	2001-11-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	639	\N	\N
741	MEMBRECOM	2001-06-19 00:00:00	2001-11-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	640	\N	\N
743	SECRETCOM	2001-06-19 00:00:00	2001-11-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	642	\N	\N
744	VICPDTCOM	2001-06-19 00:00:00	2001-11-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	643	\N	\N
745	MEMBRECOM	2001-06-19 00:00:00	2001-11-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	644	\N	\N
746	MEMBRECOM	2001-06-19 00:00:00	2001-11-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	645	\N	\N
747	MEMBRECOM	2001-06-19 00:00:00	2001-11-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	646	\N	\N
748	MEMBRECOM	2001-06-19 00:00:00	2001-09-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	647	\N	\N
749	MEMBRECOM	2001-06-19 00:00:00	2001-11-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	648	\N	\N
757	MEMBRECOM	2001-10-03 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	656	\N	\N
752	MEMBRECOM	2001-06-19 00:00:00	2001-11-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	651	\N	\N
753	VICPDTCOM	2001-06-19 00:00:00	2001-11-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	652	\N	\N
759	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	658	\N	\N
760	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	659	\N	\N
761	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	660	\N	\N
762	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	661	\N	\N
763	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	662	\N	\N
764	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	3	ANCIEN	\N	\N	\N	\N	663	\N	\N
120	MEMBRECOM	\N	2001-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	120	\N	\N
121	MEMBRECOM	\N	2001-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	121	\N	\N
10974	MEMBRECOM	2013-04-02 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9261	\N	\N
123	MEMBRECOM	\N	2001-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	123	\N	\N
124	PDTCOM	1995-10-11 00:00:00	1998-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	124	\N	\N
125	MEMBRECOM	\N	2001-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	125	\N	\N
127	VICPDTCOM	1996-10-09 00:00:00	1998-10-07 00:00:00	3	ANCIEN	\N	\N	\N	\N	127	\N	\N
128	MEMBRECOM	\N	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	128	\N	\N
129	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	129	\N	\N
130	MEMBRECOM	1974-10-04 00:00:00	1980-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	130	\N	\N
131	SECRETCOM	1996-02-21 00:00:00	1998-10-14 00:00:00	4	ANCIEN	\N	\N	\N	\N	131	\N	\N
132	MEMBRECOM	\N	2001-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	132	\N	\N
133	SECRETCOM	\N	1998-10-06 00:00:00	2	ANCIEN	\N	\N	\N	\N	133	\N	\N
134	MEMBRECOM	\N	1998-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	134	\N	\N
135	PDTCOM	1986-10-08 00:00:00	1998-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	135	\N	\N
136	MEMBRECOM	\N	2001-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	136	\N	\N
137	MEMBRECOM	\N	2001-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	137	\N	\N
138	VICPDTCOM	1996-02-21 00:00:00	1998-10-06 00:00:00	4	ANCIEN	\N	\N	\N	\N	138	\N	\N
140	VICPDTCOM	1996-02-14 00:00:00	1998-10-06 00:00:00	5	ANCIEN	\N	\N	\N	\N	140	\N	\N
141	MEMBRECOM	\N	2001-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	141	\N	\N
142	MEMBRECOM	\N	1998-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	142	\N	\N
10975	MEMBRECOM	2013-04-02 00:00:00	2014-04-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9262	\N	2014-04-23 09:56:25
144	SECRETCOM	1995-10-05 00:00:00	1998-10-06 00:00:00	4	ANCIEN	\N	\N	\N	\N	144	\N	\N
145	MEMBRECOM	\N	2000-01-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	145	\N	\N
146	VICPDTCOM	1995-10-05 00:00:00	1998-10-07 00:00:00	2	ANCIEN	\N	\N	\N	\N	146	\N	\N
147	MEMBRECOM	1986-10-06 00:00:00	1998-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	147	\N	\N
148	SECRETCOM	1996-02-14 00:00:00	2001-09-30 00:00:00	1	ANCIEN	\N	\N	\N	\N	148	\N	\N
150	MEMBRECOM	\N	2001-01-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	150	\N	\N
151	MEMBRECOM	1992-10-07 00:00:00	1998-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	151	\N	\N
153	MEMBRECOM	2001-10-03 00:00:00	2007-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	153	\N	\N
155	MEMBRECOM	1983-10-06 00:00:00	1995-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	155	\N	\N
156	MEMBRECOM	\N	2001-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	156	\N	\N
157	MEMBRECOM	\N	2001-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	157	\N	\N
10976	MEMBRECOM	2013-04-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9263	\N	\N
158	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	158	\N	\N
159	MEMBRECOM	\N	2001-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	159	\N	\N
854	MEMBRECOM	2001-10-03 00:00:00	2005-03-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	62	\N	\N
855	MEMBRECOM	2001-10-03 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	379	\N	\N
856	MEMBRECOM	2001-10-03 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	22	\N	\N
857	MEMBRECOM	2001-10-03 00:00:00	2004-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	89	\N	\N
858	MEMBRECOM	2001-10-03 00:00:00	2008-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	728	\N	\N
859	MEMBRECOM	2001-10-03 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	381	\N	\N
860	MEMBRECOM	2001-10-03 00:00:00	2009-09-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	382	\N	\N
861	MEMBRECOM	2001-10-03 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	729	\N	\N
862	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	260	\N	\N
863	MEMBRECOM	2001-10-03 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	519	\N	\N
864	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	63	\N	\N
921	MEMBRECOM	2001-10-03 00:00:00	2010-03-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	203	\N	\N
866	MEMBRECOM	2001-10-03 00:00:00	2008-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	176	\N	\N
867	MEMBRECOM	2001-10-03 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	730	\N	\N
868	MEMBRECOM	2001-10-03 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	234	\N	\N
869	MEMBRECOM	2001-10-03 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	731	\N	\N
870	MEMBRECOM	2001-10-03 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	384	\N	\N
871	MEMBRECOM	2001-10-03 00:00:00	2006-06-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	385	\N	\N
872	VICPDTCOM	2001-10-03 00:00:00	2011-09-30 00:00:00	9	ANCIEN	\N	\N	\N	\N	235	\N	\N
873	MEMBRECOM	2001-10-03 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	732	\N	\N
874	MEMBRECOM	2001-10-03 00:00:00	2008-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	734	\N	\N
875	MEMBRECOM	2001-10-03 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	733	\N	\N
876	MEMBRECOM	2001-10-03 00:00:00	2004-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	312	\N	\N
877	MEMBRECOM	2001-10-03 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	207	\N	\N
923	MEMBRECOM	2001-10-03 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	276	\N	\N
879	MEMBRECOM	2001-10-03 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	185	\N	\N
880	MEMBRECOM	2001-10-03 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	503	\N	\N
881	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	35	\N	\N
882	MEMBRECOM	2001-10-03 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	88	\N	\N
929	MEMBRECOM	2001-10-03 00:00:00	2004-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	56	\N	\N
930	MEMBRECOM	2001-10-03 00:00:00	2001-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	195	\N	\N
886	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	736	\N	\N
888	MEMBRECOM	2001-10-03 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	175	\N	\N
890	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	317	\N	\N
891	MEMBRECOM	2001-10-01 00:00:00	2004-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	739	\N	\N
892	MEMBRECOM	2001-10-03 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	738	\N	2014-09-28 17:22:11
925	MEMBRECOM	2001-10-03 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	749	\N	\N
894	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	79	\N	\N
895	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	514	\N	\N
896	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	740	\N	\N
897	MEMBRECOM	2001-10-03 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	389	\N	2014-10-08 16:59:48
898	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	218	\N	\N
900	MEMBRECOM	2001-10-03 00:00:00	2004-12-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	388	\N	\N
901	MEMBRECOM	2001-10-03 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	390	\N	\N
902	MEMBRECOM	2001-10-03 00:00:00	2004-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	741	\N	\N
903	MEMBRECOM	2001-10-03 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	232	\N	\N
904	MEMBRECOM	2001-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	742	\N	\N
905	MEMBRECOM	2001-10-03 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	467	\N	\N
910	MEMBRECOM	2001-10-03 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	743	\N	\N
907	MEMBRECOM	2001-10-03 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	294	\N	\N
908	MEMBRECOM	2001-10-03 00:00:00	2004-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	163	\N	\N
912	MEMBRECOM	2001-10-03 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	744	\N	\N
926	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	241	\N	\N
914	MEMBRECOM	2001-10-03 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	745	\N	\N
915	MEMBRECOM	2001-10-03 00:00:00	2007-01-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	99	\N	\N
916	MEMBRECOM	2001-10-03 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	269	\N	\N
917	MEMBRECOM	2001-10-01 00:00:00	2011-08-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	747	\N	\N
918	SECRETCOM	2001-10-03 00:00:00	2004-10-05 00:00:00	2	ANCIEN	\N	\N	\N	\N	2	\N	\N
919	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	227	\N	\N
920	MEMBRECOM	2001-10-03 00:00:00	2008-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	748	\N	\N
922	MEMBRECOM	2001-10-03 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	392	\N	\N
924	MEMBRECOM	2001-10-03 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	520	\N	\N
927	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	407	\N	\N
928	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	133	\N	\N
931	MEMBRECOM	2001-10-03 00:00:00	2002-02-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	750	\N	\N
932	MEMBRECOM	2001-10-03 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	94	\N	\N
933	MEMBRECOM	2001-10-03 00:00:00	2006-08-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	21	\N	\N
934	MEMBRECOM	2001-10-03 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	751	\N	\N
935	MEMBRECOM	2001-10-03 00:00:00	2002-07-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	410	\N	\N
936	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	394	\N	\N
937	MEMBRECOM	2001-10-03 00:00:00	2008-09-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	752	\N	\N
938	MEMBRECOM	2001-10-03 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	753	\N	\N
939	MEMBRECOM	2001-10-03 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	417	\N	\N
940	MEMBRECOM	2001-10-03 00:00:00	2008-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	754	\N	\N
941	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	250	\N	\N
943	MEMBRECOM	2001-10-03 00:00:00	2004-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	283	\N	\N
944	MEMBRECOM	2001-10-03 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	408	\N	\N
945	MEMBRECOM	2001-10-03 00:00:00	2008-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	755	\N	\N
946	MEMBRECOM	2001-10-03 00:00:00	2004-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	459	\N	\N
947	MEMBRECOM	2001-10-03 00:00:00	2004-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19	\N	\N
949	MEMBRECOM	2001-10-03 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	174	\N	\N
948	MEMBRECOM	2001-10-03 00:00:00	2002-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	281	\N	\N
950	MEMBRECOM	2001-10-03 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	756	\N	\N
951	MEMBRECOM	2001-10-03 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	239	\N	\N
953	MEMBRECOM	2001-10-03 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	51	\N	\N
952	MEMBRECOM	2001-10-03 00:00:00	2004-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	23	\N	\N
954	MEMBRECOM	2001-10-03 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	757	\N	\N
956	MEMBRECOM	2001-10-03 00:00:00	2004-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	758	\N	\N
955	MEMBRECOM	2001-10-03 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	314	\N	\N
957	MEMBRECOM	2001-10-03 00:00:00	2004-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	496	\N	\N
970	MEMBRECOM	2001-10-03 00:00:00	2004-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	763	\N	\N
960	MEMBRECOM	2001-10-03 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	761	\N	\N
961	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	270	\N	\N
962	MEMBRECOM	2001-10-03 00:00:00	2004-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	422	\N	\N
963	MEMBRECOM	2001-10-03 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	64	\N	\N
964	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	66	\N	\N
965	MEMBRECOM	2001-10-03 00:00:00	2004-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	762	\N	\N
966	MEMBRECOM	2001-10-03 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	224	\N	2014-09-28 17:07:41
967	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	497	\N	\N
968	MEMBRECOM	2001-10-03 00:00:00	2002-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	273	\N	\N
969	MEMBRECOM	2001-10-03 00:00:00	2004-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	499	\N	\N
971	MEMBRECOM	2001-10-03 00:00:00	2007-01-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	764	\N	\N
972	MEMBRECOM	2001-10-01 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	765	\N	\N
973	MEMBRECOM	2001-10-03 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	409	\N	\N
974	MEMBRECOM	2001-10-03 00:00:00	2004-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	498	\N	\N
975	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	268	\N	\N
976	MEMBRECOM	2001-10-03 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	184	\N	\N
977	MEMBRECOM	2001-10-03 00:00:00	2007-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	766	\N	\N
978	MEMBRECOM	2001-10-03 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	418	\N	\N
979	MEMBRECOM	2001-10-03 00:00:00	2004-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	767	\N	\N
980	MEMBRECOM	2001-10-03 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	252	\N	\N
981	MEMBRECOM	2001-10-03 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	768	\N	\N
982	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	173	\N	\N
983	MEMBRECOM	2001-10-03 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	769	\N	\N
984	MEMBRECOM	2001-10-03 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	308	\N	\N
985	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	248	\N	\N
986	MEMBRECOM	2001-10-03 00:00:00	2004-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	770	\N	\N
987	MEMBRECOM	2001-10-03 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	309	\N	\N
539	SECRETCOM	1998-10-07 00:00:00	2001-10-03 00:00:00	1	ANCIEN	\N	\N	\N	\N	190	\N	\N
989	MEMBRECOM	2001-10-03 00:00:00	2002-12-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	253	\N	\N
990	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	771	\N	\N
991	MEMBRECOM	2001-10-03 00:00:00	2002-06-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	772	\N	\N
992	MEMBRECOM	2001-10-03 00:00:00	2002-10-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	412	\N	\N
477	VICPDTCOM	1998-10-07 00:00:00	2001-10-03 00:00:00	1	ANCIEN	\N	\N	\N	\N	246	\N	\N
993	MEMBRECOM	2001-10-03 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	773	\N	\N
994	MEMBRECOM	2001-10-03 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	187	\N	\N
995	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	181	\N	\N
996	MEMBRECOM	2001-10-03 00:00:00	2003-11-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	425	\N	\N
997	MEMBRECOM	2001-10-03 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	192	\N	\N
998	MEMBRECOM	2001-10-03 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	527	\N	\N
1000	MEMBRECOM	2001-10-03 00:00:00	2002-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	775	\N	\N
999	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	506	\N	\N
1001	MEMBRECOM	2001-10-03 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	522	\N	\N
1002	MEMBRECOM	2001-10-03 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	413	\N	\N
1003	MEMBRECOM	2001-10-03 00:00:00	2004-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	44	\N	\N
1004	MEMBRECOM	2001-10-03 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	36	\N	\N
1005	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	228	\N	\N
1006	MEMBRECOM	2001-10-03 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	426	\N	\N
1007	MEMBRECOM	2001-10-03 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	204	\N	\N
1008	MEMBRECOM	2001-10-03 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	230	\N	\N
1009	MEMBRECOM	2001-10-03 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	776	\N	2017-09-24 17:28:55
1010	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	20	\N	\N
1011	MEMBRECOM	2001-10-03 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	777	\N	\N
1012	MEMBRECOM	2001-10-03 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	216	\N	\N
1014	MEMBRECOM	2001-10-03 00:00:00	2002-06-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	427	\N	\N
10971	MEMBRECOM	2013-04-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9258	\N	\N
1015	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	468	\N	\N
1016	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	278	\N	\N
1017	MEMBRECOM	2001-10-03 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	219	\N	\N
1018	MEMBRECOM	2001-10-03 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	267	\N	\N
1019	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	528	\N	\N
1020	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	287	\N	\N
1021	MEMBRECOM	2001-10-03 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	97	\N	\N
1022	MEMBRECOM	2001-10-03 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	229	\N	2014-10-09 10:52:58
1023	MEMBRECOM	2001-10-03 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	272	\N	\N
1024	MEMBRECOM	2001-10-03 00:00:00	2006-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	414	\N	\N
1025	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	243	\N	\N
1026	MEMBRECOM	2001-10-03 00:00:00	2002-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	610	\N	\N
1027	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	231	\N	\N
1028	MEMBRECOM	2001-10-03 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	264	\N	\N
1030	MEMBRECOM	2001-10-03 00:00:00	2001-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	778	\N	\N
1029	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	275	\N	\N
1031	MEMBRECOM	2001-10-03 00:00:00	2003-11-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	415	\N	\N
1033	MEMBRECOM	2001-10-03 00:00:00	2003-11-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	474	\N	\N
1034	MEMBRECOM	2001-10-03 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	779	\N	\N
1036	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	92	\N	\N
1035	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	405	\N	\N
1037	MEMBRECOM	2001-10-03 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	188	\N	\N
1038	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	210	\N	\N
1039	MEMBRECOM	2001-10-03 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	780	\N	\N
1040	MEMBRECOM	2001-10-03 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	193	\N	\N
1041	MEMBRECOM	2001-10-03 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	429	\N	\N
1042	MEMBRECOM	2001-10-03 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	245	\N	\N
437	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	430	\N	\N
1044	MEMBRECOM	2001-10-03 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	430	\N	\N
1045	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	290	\N	\N
1046	MEMBRECOM	2001-10-03 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	781	\N	\N
1048	MEMBRECOM	2001-10-03 00:00:00	2002-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	782	\N	\N
1049	MEMBRECOM	2001-10-03 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	108	\N	\N
1050	MEMBRECOM	2001-10-03 00:00:00	2002-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	783	\N	\N
1052	MEMBRECOM	2001-10-03 00:00:00	2004-04-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	271	\N	\N
549	VICPDTCOM	1998-10-07 00:00:00	2001-10-03 00:00:00	2	ANCIEN	\N	\N	\N	\N	40	\N	\N
1053	MEMBRECOM	2001-10-03 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	784	\N	\N
509	VICPDTCOM	1998-10-07 00:00:00	2001-10-03 00:00:00	6	ANCIEN	\N	\N	\N	\N	61	\N	\N
1054	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	61	\N	\N
1057	MEMBRECOM	2001-10-03 00:00:00	2001-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	72	\N	\N
1058	MEMBRECOM	2001-10-03 00:00:00	2009-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	178	\N	\N
439	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	432	\N	\N
1060	MEMBRECOM	2001-10-03 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	432	\N	\N
1061	MEMBRECOM	2001-10-03 00:00:00	2004-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	445	\N	\N
1062	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	433	\N	\N
49	MEMBRECOM	\N	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	49	\N	\N
50	MEMBRECOM	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	50	\N	\N
51	VICPDTCOM	1992-10-08 00:00:00	1998-10-06 00:00:00	2	ANCIEN	\N	\N	\N	\N	51	\N	\N
52	VICPDTCOM	1997-09-24 00:00:00	1998-09-30 00:00:00	6	ANCIEN	\N	\N	\N	\N	52	\N	\N
53	MEMBRECOM	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	53	\N	\N
54	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	54	\N	\N
55	SECRETCOM	1992-10-08 00:00:00	1998-09-30 00:00:00	2	ANCIEN	\N	\N	\N	\N	55	\N	\N
56	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	56	\N	\N
57	MEMBRECOM	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	57	\N	\N
58	MEMBRECOM	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	58	\N	\N
59	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	59	\N	\N
60	MEMBRECOM	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	60	\N	\N
61	VICPDTCOM	1986-10-06 00:00:00	1998-10-06 00:00:00	6	ANCIEN	\N	\N	\N	\N	61	\N	\N
62	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	62	\N	\N
63	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	63	\N	\N
64	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	64	\N	\N
65	MEMBRECOM	\N	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	65	\N	\N
66	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	66	\N	\N
67	SECRETCOM	1995-10-05 00:00:00	1998-10-06 00:00:00	4	ANCIEN	\N	\N	\N	\N	67	\N	\N
68	MEMBRECOM	\N	2000-03-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	68	\N	\N
69	MEMBRECOM	2001-10-03 00:00:00	2004-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	69	\N	\N
70	VICPDTCOM	1995-10-05 00:00:00	1998-09-30 00:00:00	2	ANCIEN	\N	\N	\N	\N	70	\N	\N
71	MEMBRECOM	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	71	\N	\N
72	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	72	\N	\N
73	MEMBRECOM	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	73	\N	\N
74	MEMBRECOM	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	74	\N	\N
75	MEMBRECOM	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	75	\N	\N
76	MEMBRECOM	\N	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	76	\N	\N
77	MEMBRECOM	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	77	\N	\N
78	MEMBRECOM	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	78	\N	\N
79	MEMBRECOM	1986-10-07 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	79	\N	\N
80	MEMBRECOM	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	80	\N	\N
81	MEMBRECOM	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	81	\N	\N
82	MEMBRECOM	1980-10-02 00:00:00	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	82	\N	\N
83	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	83	\N	\N
84	MEMBRECOM	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	84	\N	\N
85	MEMBRECOM	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	85	\N	\N
86	MEMBRECOM	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	86	\N	\N
87	VICPDTCOM	1996-02-14 00:00:00	1998-10-06 00:00:00	5	ANCIEN	\N	\N	\N	\N	87	\N	\N
10873	MEMBRECOM	2013-03-12 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9159	2013-03-12 09:29:51	2014-10-08 16:53:57
89	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	89	\N	\N
90	MEMBRECOM	1989-10-02 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	90	\N	\N
91	MEMBRECOM	1997-09-17 00:00:00	1998-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	91	\N	\N
92	MEMBRECOM	\N	1998-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	92	\N	\N
93	MEMBRECOM	2001-10-03 00:00:00	2004-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	93	\N	\N
94	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	94	\N	\N
95	PDTCOM	\N	1998-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	95	\N	\N
96	MEMBRECOM	1995-10-04 00:00:00	1999-12-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	96	\N	\N
97	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	97	\N	\N
98	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	98	\N	\N
99	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	99	\N	\N
100	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	100	\N	\N
101	MEMBRECOM	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	101	\N	\N
102	MEMBRECOM	1980-10-07 00:00:00	1983-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	102	\N	\N
103	VICPDTCOM	1983-10-07 00:00:00	1998-09-30 00:00:00	1	ANCIEN	\N	\N	\N	\N	103	\N	\N
104	SECRETCOM	1995-10-05 00:00:00	1998-09-30 00:00:00	1	ANCIEN	\N	\N	\N	\N	104	\N	\N
105	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	105	\N	\N
106	MEMBRECOM	2001-10-03 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	106	\N	\N
108	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	108	\N	\N
109	VICPDTCOM	1996-02-21 00:00:00	2001-09-23 00:00:00	3	ANCIEN	\N	\N	\N	\N	109	\N	\N
110	MEMBRECOM	1995-10-05 00:00:00	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	110	\N	\N
111	MEMBRECOM	\N	2001-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	111	\N	\N
112	SECRETCOM	1986-10-06 00:00:00	1998-10-06 00:00:00	2	ANCIEN	\N	\N	\N	\N	112	\N	\N
113	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	113	\N	\N
114	MEMBRECOM	\N	2001-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	114	\N	\N
115	MEMBRECOM	\N	2001-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	115	\N	\N
116	MEMBRECOM	\N	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	116	\N	\N
117	VICPDTCOM	1995-10-05 00:00:00	1998-10-06 00:00:00	4	ANCIEN	\N	\N	\N	\N	117	\N	\N
118	VICPDTCOM	1994-10-19 00:00:00	1998-10-06 00:00:00	3	ANCIEN	\N	\N	\N	\N	118	\N	\N
119	VICPDTCOM	1989-10-05 00:00:00	2001-10-01 00:00:00	1	ANCIEN	\N	\N	\N	\N	119	\N	\N
160	MEMBRECOM	\N	2001-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	160	\N	\N
161	MEMBRECOM	\N	2000-04-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	161	\N	\N
162	MEMBRECOM	\N	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	162	\N	\N
163	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	163	\N	\N
164	MEMBRECOM	\N	2001-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	164	\N	\N
165	MEMBRECOM	\N	2000-05-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	165	\N	\N
166	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	166	\N	\N
167	MEMBRECOM	1997-06-24 00:00:00	1998-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	167	\N	\N
168	MEMBRECOM	\N	2001-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	168	\N	\N
169	MEMBRECOM	1997-09-17 00:00:00	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	169	\N	\N
10951	MEMBRECOM	2013-03-13 00:00:00	2013-03-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9178	2013-03-13 16:51:34	\N
171	MEMBRECOM	\N	2001-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	171	\N	\N
172	MEMBRECOM	\N	1999-10-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	172	\N	\N
173	VICPDTCOM	1996-02-14 00:00:00	1998-10-06 00:00:00	6	ANCIEN	\N	\N	\N	\N	173	\N	\N
10952	MEMBRECOM	2013-03-13 00:00:00	2013-03-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9181	2013-03-13 16:52:05	\N
175	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	175	\N	\N
176	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	176	\N	\N
177	MEMBRECOM	\N	2001-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	177	\N	\N
178	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	178	\N	\N
179	VICPDTCOM	1996-02-07 00:00:00	1998-10-06 00:00:00	5	ANCIEN	\N	\N	\N	\N	179	\N	\N
180	MEMBRECOM	\N	2001-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	180	\N	\N
181	MEMBRECOM	\N	1998-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	181	\N	\N
182	RAPGENCOM	1995-10-05 00:00:00	1998-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	182	\N	\N
183	MEMBRECOM	\N	2000-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	183	\N	\N
184	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	184	\N	\N
185	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	185	\N	\N
186	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	186	\N	\N
187	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	187	\N	\N
188	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	188	\N	\N
190	MEMBRECOM	1980-10-07 00:00:00	1998-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	190	\N	\N
191	SECRETCOM	1996-02-14 00:00:00	1998-10-06 00:00:00	4	ANCIEN	\N	\N	\N	\N	191	\N	\N
192	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	192	\N	\N
193	SECRETCOM	1996-02-07 00:00:00	1998-10-06 00:00:00	1	ANCIEN	\N	\N	\N	\N	193	\N	\N
194	MEMBRECOM	\N	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	194	\N	\N
195	SECRETCOM	1997-09-24 00:00:00	1998-10-06 00:00:00	3	ANCIEN	\N	\N	\N	\N	195	\N	\N
196	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	196	\N	\N
197	MEMBRECOM	\N	2001-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	197	\N	\N
198	MEMBRECOM	\N	2001-09-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	198	\N	\N
199	MEMBRECOM	1995-10-04 00:00:00	1998-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	199	\N	\N
200	MEMBRECOM	\N	2000-05-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	200	\N	\N
201	SECRETCOM	1996-10-09 00:00:00	1998-10-06 00:00:00	3	ANCIEN	\N	\N	\N	\N	201	\N	\N
202	MEMBRECOM	\N	2001-09-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	202	\N	\N
203	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	203	\N	\N
204	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	204	\N	\N
205	MEMBRECOM	\N	2001-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	205	\N	\N
206	MEMBRECOM	2001-10-03 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	206	\N	\N
10953	MEMBRECOM	2013-03-13 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9226	2013-03-13 16:52:43	2013-12-16 10:28:45
208	VICPDTCOM	1989-10-05 00:00:00	1998-10-05 00:00:00	3	ANCIEN	\N	\N	\N	\N	208	\N	\N
209	MEMBRECOM	\N	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	209	\N	\N
210	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	210	\N	\N
211	MEMBRECOM	2001-10-03 00:00:00	2004-05-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	211	\N	\N
212	MEMBRECOM	1995-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	212	\N	\N
213	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	213	\N	\N
215	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	215	\N	\N
216	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	216	\N	\N
217	MEMBRECOM	\N	1998-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	217	\N	\N
218	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	218	\N	\N
219	MEMBRECOM	1992-10-08 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	219	\N	\N
220	SECRETCOM	1986-10-06 00:00:00	1992-10-08 00:00:00	1	ANCIEN	\N	\N	\N	\N	220	\N	\N
221	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	221	\N	\N
222	MEMBRECOM	1995-10-04 00:00:00	1999-11-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	222	\N	\N
224	VICPDTCOM	1997-07-03 00:00:00	1998-10-06 00:00:00	3	ANCIEN	\N	\N	\N	\N	224	\N	\N
225	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	225	\N	\N
226	MEMBRECOM	\N	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	226	\N	\N
228	MEMBRECOM	2001-10-03 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	228	\N	\N
229	SECRETCOM	2001-01-24 00:00:00	2001-10-03 00:00:00	2	ANCIEN	\N	\N	\N	\N	229	\N	\N
230	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	230	\N	\N
231	VICPDTCOM	1995-10-05 00:00:00	1998-10-06 00:00:00	3	ANCIEN	\N	\N	\N	\N	231	\N	\N
232	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	232	\N	\N
233	MEMBRECOM	\N	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	233	\N	\N
234	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	234	\N	\N
10954	MEMBRECOM	2013-03-13 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9228	2013-03-13 16:52:56	2013-12-16 10:28:45
236	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	236	\N	\N
1989	MEMBRECOM	\N	1979-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1442	\N	\N
1990	MEMBRECOM	\N	1961-08-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1443	\N	\N
1991	VICPDTCOM	1959-10-08 00:00:00	1968-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1444	\N	\N
1993	VICPDTCOM	1959-05-12 00:00:00	1971-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1446	\N	\N
1994	MEMBRECOM	\N	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1447	\N	\N
1995	SECRETCOM	1974-10-04 00:00:00	1975-10-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1448	\N	\N
1997	MEMBRECOM	1970-10-08 00:00:00	1971-11-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1450	\N	\N
1998	MEMBRECOM	1968-10-09 00:00:00	1971-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1451	\N	\N
2000	MEMBRECOM	\N	1968-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1453	\N	\N
2001	SECRETCOM	1960-10-06 00:00:00	1966-04-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1454	\N	\N
2002	MEMBRECOM	\N	1973-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1455	\N	\N
2003	MEMBRECOM	\N	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1456	\N	\N
2004	MEMBRECOM	\N	1962-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1457	\N	\N
2005	MEMBRECOM	\N	1971-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1458	\N	\N
2006	MEMBRECOM	\N	1968-03-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1459	\N	\N
2007	MEMBRECOM	\N	1965-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1460	\N	\N
2008	MEMBRECOM	\N	1971-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1461	\N	\N
2009	MEMBRECOM	\N	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1462	\N	\N
2010	MEMBRECOM	\N	1980-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1463	\N	\N
2011	MEMBRECOM	\N	1962-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1464	\N	\N
2012	MEMBRECOM	\N	1966-06-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1465	\N	\N
2013	MEMBRECOM	\N	1965-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1466	\N	\N
2014	MEMBRECOM	\N	1959-04-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1467	\N	\N
2015	SECRETCOM	1965-10-06 00:00:00	1968-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1468	\N	\N
2030	SECRETCOM	1980-10-07 00:00:00	1986-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1499	\N	\N
2031	MEMBRECOM	\N	1983-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1500	\N	\N
2032	MEMBRECOM	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1501	\N	\N
2034	MEMBRECOM	1986-10-06 00:00:00	1992-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1503	\N	\N
2035	VICPDTCOM	1977-10-06 00:00:00	1983-05-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1772	\N	\N
2036	MEMBRECOM	\N	1995-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1504	\N	\N
2037	MEMBRECOM	\N	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1505	\N	\N
2039	MEMBRECOM	\N	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1491	\N	\N
2040	MEMBRECOM	1990-06-28 00:00:00	1998-02-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1492	\N	\N
2041	MEMBRECOM	\N	1990-04-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1493	\N	\N
2043	MEMBRECOM	\N	1986-07-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1771	\N	\N
2044	MEMBRECOM	\N	1992-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1495	\N	\N
2045	VICPDTCOM	1989-10-05 00:00:00	1992-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1496	\N	\N
2046	MEMBRECOM	\N	1986-09-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1497	\N	\N
2048	MEMBRECOM	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1480	\N	\N
2049	MEMBRECOM	\N	1987-02-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1481	\N	\N
2050	MEMBRECOM	\N	1989-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1482	\N	\N
2051	MEMBRECOM	\N	1988-06-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1483	\N	\N
2053	MEMBRECOM	1992-10-07 00:00:00	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1485	\N	\N
2054	SECRETCOM	1992-10-08 00:00:00	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1486	\N	\N
2055	MEMBRECOM	\N	1986-12-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1770	\N	\N
2057	MEMBRECOM	\N	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1488	\N	\N
2058	MEMBRECOM	1979-10-07 00:00:00	1980-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1489	\N	\N
2059	MEMBRECOM	\N	1997-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1469	\N	\N
2060	MEMBRECOM	\N	1983-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1470	\N	\N
2062	MEMBRECOM	1986-10-07 00:00:00	1989-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1472	\N	\N
2063	MEMBRECOM	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1473	\N	\N
2064	MEMBRECOM	\N	1989-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1474	\N	\N
2067	MEMBRECOM	\N	1986-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1477	\N	\N
2068	SECRETCOM	1971-10-06 00:00:00	1986-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1478	\N	\N
2070	MEMBRECOM	1965-10-06 00:00:00	1970-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1506	\N	\N
2071	MEMBRECOM	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1507	\N	\N
2072	MEMBRECOM	\N	1990-11-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1508	\N	\N
2074	SECRETCOM	1992-10-08 00:00:00	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1510	\N	\N
2075	MEMBRECOM	\N	1996-01-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1511	\N	\N
2076	MEMBRECOM	\N	1989-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1512	\N	\N
2077	MEMBRECOM	\N	1989-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1513	\N	\N
2078	MEMBRECOM	\N	1989-09-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1514	\N	\N
2079	MEMBRECOM	\N	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1515	\N	\N
2080	VICPDTCOM	1970-10-07 00:00:00	1974-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1516	\N	\N
2081	MEMBRECOM	\N	1995-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1517	\N	\N
765	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	664	\N	\N
766	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	665	\N	\N
767	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	666	\N	\N
768	MEMBRECOM	2001-10-03 00:00:00	2004-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	667	\N	\N
769	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	668	\N	\N
770	MEMBRECOM	2001-10-03 00:00:00	2004-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	669	\N	\N
771	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	670	\N	\N
772	MEMBRECOM	2001-10-03 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	671	\N	\N
773	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	672	\N	\N
774	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	673	\N	\N
775	MEMBRECOM	2001-10-03 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	674	\N	\N
776	MEMBRECOM	2001-10-03 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	675	\N	2014-10-09 13:52:05
777	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	676	\N	\N
778	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	677	\N	\N
779	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	678	\N	\N
780	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	679	\N	\N
781	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	680	\N	\N
782	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	2	ANCIEN	\N	\N	\N	\N	681	\N	\N
783	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	682	\N	\N
784	MEMBRECOM	2001-10-03 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	683	\N	\N
785	MEMBRECOM	2001-10-03 00:00:00	2004-10-05 00:00:00	7	ANCIEN	\N	\N	\N	\N	684	\N	\N
786	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	685	\N	\N
787	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	686	\N	\N
788	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	5	ANCIEN	\N	\N	\N	\N	687	\N	\N
789	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	688	\N	\N
790	MEMBRECOM	2001-10-03 00:00:00	2004-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	689	\N	\N
791	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	690	\N	\N
792	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	691	\N	\N
793	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	692	\N	\N
794	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	693	\N	\N
796	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	695	\N	\N
1381	MEMBRECOM	2003-02-12 00:00:00	2003-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	968	\N	\N
1383	MEMBRECOM	2003-02-12 00:00:00	2003-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	969	\N	\N
1384	MEMBRECOM	2003-02-12 00:00:00	2003-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	970	\N	\N
1385	MEMBRECOM	2003-02-12 00:00:00	2003-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	971	\N	\N
1386	MEMBRECOM	2003-02-12 00:00:00	2003-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	972	\N	\N
1387	MEMBRECOM	2003-02-12 00:00:00	2003-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	973	\N	\N
1388	MEMBRECOM	2003-02-12 00:00:00	2003-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	974	\N	\N
1390	MEMBRECOM	2003-02-12 00:00:00	2003-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	976	\N	\N
1391	MEMBRECOM	2003-02-12 00:00:00	2003-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	977	\N	\N
1392	MEMBRECOM	2003-02-12 00:00:00	2003-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	978	\N	\N
1393	MEMBRECOM	2003-02-12 00:00:00	2003-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	979	\N	\N
1394	MEMBRECOM	2003-02-12 00:00:00	2003-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	980	\N	\N
1395	MEMBRECOM	2003-02-12 00:00:00	2003-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	981	\N	\N
1396	MEMBRECOM	2003-02-12 00:00:00	2003-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	982	\N	\N
1397	MEMBRECOM	2003-02-12 00:00:00	2003-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	983	\N	\N
1398	MEMBRECOM	2003-02-12 00:00:00	2003-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	984	\N	\N
1399	MEMBRECOM	2003-02-12 00:00:00	2003-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	985	\N	\N
1400	MEMBRECOM	2003-02-12 00:00:00	2003-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	986	\N	\N
1412	MEMBRECOM	2003-02-09 00:00:00	2003-02-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1001	\N	\N
1413	MEMBRECOM	2003-02-12 00:00:00	2003-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1002	\N	\N
1414	MEMBRECOM	2003-02-12 00:00:00	2003-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1003	\N	\N
1415	MEMBRECOM	2003-02-12 00:00:00	2003-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1004	\N	\N
1416	MEMBRECOM	2003-02-12 00:00:00	2003-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1005	\N	\N
1417	MEMBRECOM	2003-02-12 00:00:00	2003-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1006	\N	\N
1418	MEMBRECOM	2003-02-12 00:00:00	2003-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1007	\N	\N
1419	MEMBRECOM	2003-02-12 00:00:00	2003-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1008	\N	\N
1420	MEMBRECOM	2003-02-12 00:00:00	2003-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1009	\N	\N
1421	MEMBRECOM	2003-02-12 00:00:00	2003-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1010	\N	\N
1422	MEMBRECOM	2003-02-12 00:00:00	2003-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1011	\N	\N
1423	MEMBRECOM	2003-02-12 00:00:00	2003-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1012	\N	\N
1424	MEMBRECOM	2003-02-12 00:00:00	2003-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1013	\N	\N
1425	MEMBRECOM	2003-02-12 00:00:00	2003-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1014	\N	\N
1432	MEMBRECOM	2003-02-27 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1021	\N	\N
1427	MEMBRECOM	2003-02-12 00:00:00	2003-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1016	\N	\N
1428	MEMBRECOM	2003-02-12 00:00:00	2003-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1017	\N	\N
1429	MEMBRECOM	2003-02-12 00:00:00	2003-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1018	\N	\N
1430	MEMBRECOM	2003-02-12 00:00:00	2003-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1019	\N	\N
1431	MEMBRECOM	2003-02-12 00:00:00	2003-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1020	\N	\N
1433	SECRETCOM	2003-03-05 00:00:00	2004-10-07 00:00:00	4	ANCIEN	\N	\N	\N	\N	260	\N	\N
1434	VICPDTCOM	2003-03-05 00:00:00	2008-10-06 00:00:00	3	ANCIEN	\N	\N	\N	\N	63	\N	\N
1570	MEMBRECOM	\N	1980-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1023	\N	\N
1571	VICPDTCOM	1971-10-06 00:00:00	1974-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1024	\N	\N
1573	VICPDTCOM	1968-10-08 00:00:00	1974-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1026	\N	\N
1574	MEMBRECOM	\N	1980-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1027	\N	\N
1575	MEMBRECOM	\N	1973-06-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1028	\N	\N
1576	VICPDTCOM	1966-10-05 00:00:00	1981-01-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1029	\N	\N
1577	MEMBRECOM	\N	1969-06-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1030	\N	\N
1578	MEMBRECOM	\N	1962-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1031	\N	\N
1579	MEMBRECOM	\N	1971-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1032	\N	\N
1580	SECRETCOM	1959-10-08 00:00:00	1965-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1033	\N	\N
1582	MEMBRECOM	\N	1962-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1035	\N	\N
1583	MEMBRECOM	\N	1962-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1036	\N	\N
1584	MEMBRECOM	1959-07-02 00:00:00	1959-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1037	\N	\N
1585	MEMBRECOM	\N	1962-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1038	\N	\N
1586	MEMBRECOM	\N	1962-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1039	\N	\N
1587	MEMBRECOM	\N	1971-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1040	\N	\N
1588	MEMBRECOM	\N	1967-04-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1041	\N	\N
1589	MEMBRECOM	\N	1962-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1042	\N	\N
1590	MEMBRECOM	\N	1973-09-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1043	\N	\N
1591	MEMBRECOM	\N	1968-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1044	\N	\N
1592	MEMBRECOM	\N	1961-09-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1045	\N	\N
1594	MEMBRECOM	\N	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1047	\N	\N
1595	MEMBRECOM	1959-05-06 00:00:00	1974-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1048	\N	\N
1596	MEMBRECOM	\N	1971-11-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1049	\N	\N
1597	MEMBRECOM	\N	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1050	\N	\N
1598	MEMBRECOM	\N	1974-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1051	\N	\N
1599	MEMBRECOM	\N	1973-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1052	\N	\N
1600	MEMBRECOM	\N	1980-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1053	\N	\N
1601	MEMBRECOM	\N	1975-11-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1054	\N	\N
1602	MEMBRECOM	\N	1980-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1055	\N	\N
1603	MEMBRECOM	\N	1967-04-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1056	\N	\N
1604	MEMBRECOM	\N	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1057	\N	\N
1605	MEMBRECOM	\N	1962-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1058	\N	\N
1606	SECRETCOM	1965-10-06 00:00:00	1968-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1059	\N	\N
1607	MEMBRECOM	\N	1962-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1060	\N	\N
1608	MEMBRECOM	\N	1962-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1061	\N	\N
1609	MEMBRECOM	\N	1980-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1062	\N	\N
1610	MEMBRECOM	\N	1962-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1063	\N	\N
1611	MEMBRECOM	\N	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1064	\N	\N
1612	MEMBRECOM	\N	1980-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1065	\N	\N
1613	MEMBRECOM	\N	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1066	\N	\N
1614	MEMBRECOM	\N	1974-03-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1067	\N	\N
1615	MEMBRECOM	\N	1962-03-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1068	\N	\N
1616	MEMBRECOM	\N	1969-08-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1069	\N	\N
1617	MEMBRECOM	\N	1971-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1070	\N	\N
1618	MEMBRECOM	\N	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1071	\N	\N
1620	MEMBRECOM	\N	1962-09-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1073	\N	\N
1621	MEMBRECOM	\N	1974-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1074	\N	\N
1622	MEMBRECOM	\N	1959-07-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1075	\N	\N
1623	MEMBRECOM	\N	1971-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1076	\N	\N
1624	MEMBRECOM	\N	1980-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1077	\N	\N
1625	MEMBRECOM	\N	1977-09-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1078	\N	\N
1626	MEMBRECOM	1968-10-08 00:00:00	1976-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1079	\N	\N
1627	MEMBRECOM	\N	1968-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1080	\N	\N
2293	MEMBRECOM	\N	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1719	\N	\N
2294	MEMBRECOM	\N	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1720	\N	\N
2295	MEMBRECOM	\N	1986-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1721	\N	\N
2296	MEMBRECOM	\N	1989-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1722	\N	\N
2297	MEMBRECOM	\N	1985-05-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1723	\N	\N
2298	MEMBRECOM	\N	1997-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1724	\N	\N
2299	MEMBRECOM	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1725	\N	\N
2300	SECRETCOM	1989-10-05 00:00:00	1992-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1726	\N	\N
2301	MEMBRECOM	\N	1989-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1727	\N	\N
2302	MEMBRECOM	\N	1983-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1728	\N	\N
2304	MEMBRECOM	\N	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1730	\N	\N
2305	VICPDTCOM	1977-10-06 00:00:00	1983-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1731	\N	\N
2306	MEMBRECOM	\N	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1732	\N	\N
2307	MEMBRECOM	\N	1983-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1733	\N	\N
2308	MEMBRECOM	\N	1986-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1734	\N	\N
2309	MEMBRECOM	\N	1983-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1735	\N	\N
2310	MEMBRECOM	1995-10-04 00:00:00	1998-02-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1736	\N	\N
2311	MEMBRECOM	1986-10-06 00:00:00	1988-06-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1737	\N	\N
2312	MEMBRECOM	\N	1995-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1738	\N	\N
2313	MEMBRECOM	\N	1989-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1739	\N	\N
2314	SECRETCOM	1977-10-06 00:00:00	1983-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1740	\N	\N
2315	MEMBRECOM	\N	1989-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1741	\N	\N
2316	MEMBRECOM	\N	1993-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1742	\N	\N
2317	MEMBRECOM	\N	1986-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1743	\N	\N
2318	MEMBRECOM	\N	1989-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1744	\N	\N
2319	MEMBRECOM	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1745	\N	\N
2320	MEMBRECOM	\N	1996-07-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1781	\N	\N
2321	MEMBRECOM	\N	1983-08-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1746	\N	\N
2324	MEMBRECOM	1989-10-04 00:00:00	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1749	\N	\N
2325	MEMBRECOM	\N	1984-03-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1750	\N	\N
2327	MEMBRECOM	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1782	\N	\N
2328	SECRETCOM	1959-05-12 00:00:00	1959-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1752	\N	\N
2329	MEMBRECOM	\N	1996-05-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1753	\N	\N
2330	MEMBRECOM	\N	1985-09-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1783	\N	\N
2332	MEMBRECOM	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1754	\N	\N
2333	MEMBRECOM	\N	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1755	\N	\N
2334	MEMBRECOM	\N	1988-05-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1756	\N	\N
2335	MEMBRECOM	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1757	\N	\N
2337	SECRETCOM	1983-10-06 00:00:00	1986-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1758	\N	\N
10928	MEMBRECOM	2013-03-13 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9217	\N	2013-12-16 10:28:45
2338	VICPDTCOM	1992-10-08 00:00:00	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1759	\N	\N
2339	MEMBRECOM	\N	1983-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1760	\N	\N
2340	VICPDTCOM	1977-10-06 00:00:00	1992-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1761	\N	\N
2342	SECRETCOM	1986-10-06 00:00:00	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1763	\N	\N
2343	MEMBRECOM	\N	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1764	\N	\N
2344	MEMBRECOM	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1765	\N	\N
2347	MEMBRECOM	\N	1986-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1768	\N	\N
2348	MEMBRECOM	\N	1998-07-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1769	\N	\N
2349	MEMBRECOM	2003-01-28 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1788	\N	\N
2350	MEMBRECOM	2003-01-28 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1789	\N	\N
2351	RAPCOM	2003-01-28 00:00:00	2015-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1790	\N	2015-06-12 16:01:25
2353	MEMBRECOM	2003-01-28 00:00:00	2015-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1792	\N	2015-10-12 09:39:30
2354	MEMBRECOM	2003-01-28 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1793	\N	\N
2355	MEMBRECOM	2003-01-28 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1794	\N	2017-09-24 13:29:42
2356	MEMBRECOM	2003-01-28 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1795	\N	2017-09-24 18:20:10
2357	MEMBRECOM	2003-01-28 00:00:00	2011-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1796	\N	\N
2358	MEMBRECOM	2003-01-28 00:00:00	2015-04-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1797	\N	2015-04-21 17:14:30
2359	MEMBRECOM	2003-01-28 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1798	\N	\N
2360	MEMBRECOM	2003-01-28 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1799	\N	\N
2361	MEMBRECOM	2003-01-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	1800	\N	\N
1630	MEMBRECOM	\N	1974-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1083	\N	\N
1635	MEMBRECOM	\N	1974-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1088	\N	\N
1640	SECRETCOM	1960-10-06 00:00:00	1980-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1093	\N	\N
1645	MEMBRECOM	\N	1962-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1098	\N	\N
1649	MEMBRECOM	\N	1967-08-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1102	\N	\N
1654	MEMBRECOM	\N	1980-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1107	\N	\N
1659	MEMBRECOM	\N	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1112	\N	\N
1663	MEMBRECOM	\N	1974-03-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1116	\N	\N
1726	MEMBRECOM	\N	1980-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1179	\N	\N
1731	MEMBRECOM	\N	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1184	\N	\N
1737	MEMBRECOM	\N	1980-07-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1190	\N	\N
1742	MEMBRECOM	\N	1967-04-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1195	\N	\N
1746	MEMBRECOM	1959-04-26 00:00:00	1959-05-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1199	\N	\N
1751	MEMBRECOM	\N	1974-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1204	\N	\N
1756	MEMBRECOM	\N	1978-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1209	\N	\N
1760	MEMBRECOM	\N	1969-03-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1213	\N	\N
1824	MEMBRECOM	\N	1968-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1277	\N	\N
1829	MEMBRECOM	\N	1981-05-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1282	\N	\N
1834	MEMBRECOM	\N	1980-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1287	\N	\N
1843	MEMBRECOM	\N	1959-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1296	\N	\N
1848	MEMBRECOM	\N	1971-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1301	\N	\N
1853	MEMBRECOM	\N	1974-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1306	\N	\N
1857	SECRETCOM	1971-10-06 00:00:00	1974-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1310	\N	\N
1921	MEMBRECOM	\N	1961-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1374	\N	\N
1926	SECRETCOM	1962-10-05 00:00:00	1968-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1379	\N	\N
1931	MEMBRECOM	\N	1968-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1384	\N	\N
1936	PDTCOM	1971-10-06 00:00:00	1974-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1389	\N	\N
1940	SECRETCOM	1962-10-05 00:00:00	1963-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1393	\N	\N
1945	MEMBRECOM	\N	1962-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1398	\N	\N
1954	MEMBRECOM	\N	1965-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1407	\N	\N
2033	MEMBRECOM	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1502	\N	\N
2038	MEMBRECOM	\N	1983-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1490	\N	\N
2042	SECRETCOM	1977-10-06 00:00:00	1983-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1494	\N	\N
2047	MEMBRECOM	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1498	\N	\N
2052	MEMBRECOM	\N	1986-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1484	\N	\N
2056	MEMBRECOM	\N	1989-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1487	\N	\N
2061	MEMBRECOM	\N	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1471	\N	\N
2066	PDTCOM	1972-11-09 00:00:00	1986-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1476	\N	\N
2129	MEMBRECOM	\N	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1562	\N	\N
2134	SECRETCOM	1971-10-06 00:00:00	1974-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1567	\N	\N
2139	MEMBRECOM	\N	1985-04-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1572	\N	\N
2143	SECRETCOM	1986-10-06 00:00:00	1988-03-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1576	\N	\N
2148	MEMBRECOM	\N	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1581	\N	\N
2153	MEMBRECOM	\N	1992-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1586	\N	\N
2158	MEMBRECOM	\N	1995-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1591	\N	\N
2162	VICPDTCOM	1989-10-05 00:00:00	1997-03-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1595	\N	\N
2225	MEMBRECOM	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1655	\N	\N
2230	VICPDTCOM	1983-10-06 00:00:00	1989-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1660	\N	\N
2235	MEMBRECOM	\N	1988-06-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1664	\N	\N
2240	MEMBRECOM	\N	1989-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1669	\N	\N
2244	MEMBRECOM	\N	1983-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1672	\N	\N
2249	MEMBRECOM	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1677	\N	\N
2254	MEMBRECOM	\N	1989-05-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1682	\N	\N
2259	MEMBRECOM	\N	1995-09-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1779	\N	\N
2322	MEMBRECOM	\N	1983-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1747	\N	\N
2326	MEMBRECOM	\N	1989-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1751	\N	\N
2331	MEMBRECOM	\N	1992-04-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1787	\N	\N
2336	MEMBRECOM	\N	1983-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1785	\N	\N
2341	SECRETCOM	1971-10-06 00:00:00	1974-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1762	\N	\N
2345	MEMBRECOM	\N	1986-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1766	\N	\N
2363	MEMBRECOM	2003-05-14 00:00:00	2007-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1803	\N	\N
2364	MEMBRECOM	2003-05-14 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1804	\N	\N
2365	PDTCOM	2003-05-15 00:00:00	2004-04-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1805	\N	\N
2367	RAPCOM	2003-05-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	1807	\N	\N
2368	MEMBRECOM	2003-05-15 00:00:00	2015-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1808	\N	2015-06-12 16:01:58
2369	MEMBRECOM	2003-05-15 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1809	\N	\N
2370	MEMBRECOM	2003-05-15 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1810	\N	2017-09-24 17:19:42
2371	MEMBRECOM	2003-05-15 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1811	\N	2017-09-24 17:06:55
2372	MEMBRECOM	2003-05-15 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1812	\N	\N
2373	MEMBRECOM	2003-05-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1813	\N	2014-09-28 12:54:15
2374	MEMBRECOM	2003-05-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1814	\N	2014-09-28 17:40:23
2375	MEMBRECOM	2003-05-15 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1815	\N	\N
2376	MEMBRECOM	2003-05-15 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1816	\N	\N
2378	MEMBRECOM	2003-05-15 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1818	\N	\N
2411	VICPDTCOM	2003-06-26 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1849	\N	\N
2398	RAPCOM	2003-06-18 00:00:00	2015-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1836	\N	2015-10-12 09:39:30
2383	VICPDTCOM	2003-06-12 00:00:00	2014-07-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1821	\N	2014-07-01 09:25:11
2384	RAPCOM	2003-06-12 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1822	\N	2014-09-28 16:59:41
2385	MEMBRECOM	2003-06-12 00:00:00	2015-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1823	\N	2015-10-12 09:39:30
2386	MEMBRECOM	2003-06-12 00:00:00	2007-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1824	\N	\N
2387	MEMBRECOM	2003-06-12 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1825	\N	\N
2388	MEMBRECOM	2003-06-12 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1826	\N	\N
2389	MEMBRECOM	2003-06-12 00:00:00	2018-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1827	\N	2018-05-31 10:52:17
2390	MEMBRECOM	2003-06-12 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1828	\N	\N
2392	MEMBRECOM	2003-06-12 00:00:00	2017-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1830	\N	2017-09-25 09:56:00
2393	MEMBRECOM	2003-06-12 00:00:00	2013-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1831	\N	\N
2394	MEMBRECOM	2003-06-12 00:00:00	2015-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1832	\N	2015-06-12 15:59:49
2395	MEMBRECOM	2003-06-12 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1833	\N	\N
2396	MEMBRECOM	2003-06-12 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1834	\N	\N
2397	PDTCOM	2003-06-18 00:00:00	2004-11-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1835	\N	\N
2399	RAPCOM	2003-06-18 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1837	\N	\N
2400	RAPCOM	2003-06-18 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1838	\N	\N
2401	MEMBRECOM	2003-06-18 00:00:00	2015-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1839	\N	2015-01-08 17:14:28
2402	MEMBRECOM	2003-06-18 00:00:00	2013-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1840	\N	\N
2403	MEMBRECOM	2003-06-18 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1841	\N	\N
2404	MEMBRECOM	2003-06-18 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1842	\N	\N
2405	MEMBRECOM	2003-06-18 00:00:00	2018-12-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1843	\N	\N
2406	MEMBRECOM	2003-06-18 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1844	\N	\N
2407	MEMBRECOM	2003-06-18 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1845	\N	\N
2408	MEMBRECOM	2003-06-18 00:00:00	2010-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1846	\N	\N
2409	MEMBRECOM	2003-06-18 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1847	\N	2017-09-24 16:43:43
2410	MEMBRECOM	2003-06-18 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1848	\N	2017-09-24 17:09:24
2413	MEMBRECOM	2003-06-26 00:00:00	2004-11-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1851	\N	\N
2414	MEMBRECOM	2003-06-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	1852	\N	\N
2415	MEMBRECOM	2003-06-26 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1853	\N	\N
2416	MEMBRECOM	2003-06-26 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1854	\N	\N
2417	MEMBRECOM	2003-06-26 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1855	\N	\N
2418	MEMBRECOM	2003-06-26 00:00:00	2017-07-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1856	\N	2017-07-04 15:08:09
2419	MEMBRECOM	2003-06-26 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1857	\N	2017-09-24 17:35:15
2420	MEMBRECOM	2003-06-26 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1858	\N	\N
2421	MEMBRECOM	2003-06-26 00:00:00	2004-04-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1859	\N	\N
2423	MEMBRECOM	2003-06-26 00:00:00	2007-09-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1861	\N	\N
2424	MEMBRECOM	2003-06-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	1862	\N	\N
2464	SECRETCOM	1959-05-12 00:00:00	1974-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1369	\N	\N
2428	PDTCOM	1959-05-06 00:00:00	1974-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1864	\N	\N
2465	VICPDTCOM	1959-10-08 00:00:00	1968-06-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1106	\N	\N
2461	SECRETCOM	1959-05-12 00:00:00	1971-02-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1025	\N	\N
2433	VICPDTCOM	1959-05-12 00:00:00	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1199	\N	\N
2467	PDTCOM	1959-05-12 00:00:00	1968-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1451	\N	\N
2468	VICPDTCOM	1959-05-12 00:00:00	1967-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1433	\N	\N
2439	VICPDTCOM	1959-05-06 00:00:00	1966-03-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1869	\N	\N
2469	VICPDTCOM	1959-05-12 00:00:00	1968-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1367	\N	\N
2471	SECRETCOM	1959-05-12 00:00:00	1966-03-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1385	\N	\N
2472	SECRETCOM	1959-05-12 00:00:00	1971-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1712	\N	\N
2446	SECRETCOM	1959-05-12 00:00:00	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1121	\N	\N
2447	SECRETCOM	1959-05-12 00:00:00	1965-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1183	\N	\N
2450	PDTCOM	1959-05-12 00:00:00	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1371	\N	\N
2451	VICPDTCOM	1959-05-12 00:00:00	1977-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1240	\N	\N
2476	SECRETCOM	1959-05-06 00:00:00	1977-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1887	\N	\N
2477	MEMBRECOM	1985-10-22 00:00:00	1986-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1479	\N	\N
2454	VICPDTCOM	1959-05-12 00:00:00	1970-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1450	\N	\N
2455	VICPDTCOM	1959-05-12 00:00:00	1980-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1767	\N	\N
2478	VICPDTCOM	1959-05-06 00:00:00	1965-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1888	\N	\N
2479	PDTCOM	1959-05-12 00:00:00	1959-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1889	\N	\N
1777	VICPDTCOM	1959-05-06 00:00:00	1959-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1230	\N	\N
2481	PDTCOM	1959-10-08 00:00:00	1968-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1230	\N	\N
1900	SECRETCOM	1959-05-12 00:00:00	1959-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1353	\N	\N
2483	SECRETCOM	1959-05-12 00:00:00	1959-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1892	\N	\N
2485	VICPDTCOM	1959-10-08 00:00:00	1965-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1894	\N	\N
1581	SECRETCOM	1959-10-08 00:00:00	1960-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1034	\N	\N
2486	VICPDTCOM	1959-05-12 00:00:00	1962-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1895	\N	\N
2487	SECRETCOM	1959-05-12 00:00:00	1962-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1896	\N	\N
2488	SECRETCOM	1959-05-12 00:00:00	1964-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1897	\N	\N
1996	SECRETCOM	1959-05-06 00:00:00	1965-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1449	\N	\N
2489	VICPDTCOM	1962-10-05 00:00:00	1963-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1387	\N	\N
2490	MEMBRECOM	1959-05-06 00:00:00	1962-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1899	\N	\N
2491	MEMBRECOM	1989-10-04 00:00:00	1992-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1509	\N	\N
2492	VICPDTCOM	1963-10-03 00:00:00	1964-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1895	\N	\N
2493	SECRETCOM	1963-10-03 00:00:00	1964-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1387	\N	\N
2494	MEMBRECOM	1959-05-06 00:00:00	1960-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1900	\N	\N
2495	VICPDTCOM	1959-10-08 00:00:00	1965-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1752	\N	\N
1930	MEMBRECOM	1960-10-06 00:00:00	1968-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1383	\N	\N
2496	VICPDTCOM	1964-10-07 00:00:00	1971-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1387	\N	\N
2497	SECRETCOM	1965-10-06 00:00:00	1968-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1901	\N	\N
1593	SECRETCOM	1966-10-05 00:00:00	1971-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1046	\N	\N
2499	SECRETCOM	1965-10-05 00:00:00	1970-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1903	\N	\N
2500	VICPDTCOM	1968-10-08 00:00:00	1970-08-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1230	\N	\N
2501	VICPDTCOM	1968-10-08 00:00:00	1974-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1417	\N	\N
2502	SECRETCOM	1968-10-08 00:00:00	1971-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1904	\N	\N
2503	MEMBRECOM	1966-10-05 00:00:00	1968-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1905	\N	\N
2504	VICPDTCOM	1968-10-08 00:00:00	1971-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1127	\N	\N
1791	SECRETCOM	1968-10-08 00:00:00	1971-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1244	\N	\N
2505	SECRETCOM	1968-10-08 00:00:00	1971-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1786	\N	\N
2506	MEMBRECOM	1965-10-06 00:00:00	1966-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1906	\N	\N
2507	SECRETCOM	1970-10-07 00:00:00	1971-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1907	\N	\N
2509	VICPDTCOM	1970-10-06 00:00:00	1980-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1910	\N	\N
2510	VICPDTCOM	1971-10-06 00:00:00	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1144	\N	\N
2511	SECRETCOM	1971-10-06 00:00:00	1980-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1911	\N	\N
2512	VICPDTCOM	1971-10-06 00:00:00	1977-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1912	\N	\N
2513	SECRETCOM	1971-10-06 00:00:00	1975-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1913	\N	\N
2514	PDTCOM	1971-10-06 00:00:00	1973-03-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1633	\N	\N
1899	SECRETCOM	1971-10-06 00:00:00	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1352	\N	\N
1063	MEMBRECOM	2001-10-03 00:00:00	2008-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	787	\N	\N
1064	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	277	\N	\N
1065	MEMBRECOM	2001-10-03 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	788	\N	\N
1066	MEMBRECOM	2001-10-03 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	215	\N	\N
1067	MEMBRECOM	2001-10-03 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	122	\N	2014-10-08 17:36:57
1068	MEMBRECOM	2001-10-03 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	789	\N	\N
1069	MEMBRECOM	2001-10-03 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	434	\N	\N
1070	MEMBRECOM	2001-10-03 00:00:00	2002-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	170	\N	\N
1071	MEMBRECOM	2001-10-03 00:00:00	2002-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	447	\N	\N
1072	MEMBRECOM	2001-10-03 00:00:00	2004-04-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	435	\N	\N
1073	MEMBRECOM	2001-10-03 00:00:00	2004-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	258	\N	\N
1074	MEMBRECOM	2001-10-03 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	436	\N	\N
1076	MEMBRECOM	2001-10-03 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	611	\N	\N
1075	MEMBRECOM	2001-10-03 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	465	\N	\N
1077	MEMBRECOM	2001-10-03 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	305	\N	\N
1079	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	790	\N	\N
1080	MEMBRECOM	2001-10-03 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	438	\N	\N
1082	MEMBRECOM	2001-10-03 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	791	\N	\N
1083	MEMBRECOM	2001-10-03 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	143	\N	\N
1084	MEMBRECOM	2001-10-03 00:00:00	2004-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	292	\N	\N
1085	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	87	\N	\N
1086	MEMBRECOM	2001-10-03 00:00:00	2003-12-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	439	\N	\N
1087	MEMBRECOM	2001-10-03 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	41	\N	\N
1088	MEMBRECOM	2001-10-03 00:00:00	2002-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	483	\N	\N
1089	MEMBRECOM	2001-10-03 00:00:00	2004-10-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16	\N	\N
448	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	441	\N	\N
1090	MEMBRECOM	2001-10-03 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	441	\N	\N
1091	MEMBRECOM	2001-10-03 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	105	\N	\N
1092	MEMBRECOM	2001-10-03 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10	\N	\N
1093	MEMBRECOM	2001-10-03 00:00:00	2003-11-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	792	\N	\N
1094	MEMBRECOM	2001-10-03 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	59	\N	\N
449	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	442	\N	\N
1096	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	442	\N	\N
1097	MEMBRECOM	2001-10-03 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	142	\N	\N
1098	MEMBRECOM	2001-10-03 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	793	\N	\N
1100	MEMBRECOM	2001-10-03 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	794	\N	\N
1101	MEMBRECOM	2001-10-03 00:00:00	2005-03-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	444	\N	\N
1102	MEMBRECOM	2001-10-03 00:00:00	2004-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	795	\N	\N
1103	MEMBRECOM	2001-10-03 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	796	\N	\N
1105	MEMBRECOM	2001-10-03 00:00:00	2007-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	493	\N	\N
1106	MEMBRECOM	2001-10-03 00:00:00	2004-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	450	\N	\N
1107	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	255	\N	\N
1108	MEMBRECOM	2001-10-03 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	398	\N	\N
1109	MEMBRECOM	2001-10-03 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	113	\N	\N
1110	MEMBRECOM	2001-10-03 00:00:00	2004-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	407	\N	\N
1111	MEMBRECOM	2001-10-03 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	797	\N	\N
1112	MEMBRECOM	2001-10-03 00:00:00	2002-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	452	\N	\N
1113	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	316	\N	\N
462	MEMBRECOM	1998-10-06 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	454	\N	\N
1114	MEMBRECOM	2001-10-03 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	798	\N	\N
1115	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	469	\N	\N
223	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	223	\N	\N
1116	MEMBRECOM	2001-10-03 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	223	\N	\N
1117	MEMBRECOM	2001-10-03 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	237	\N	\N
522	VICPDTCOM	1998-10-07 00:00:00	2001-10-03 00:00:00	3	ANCIEN	\N	\N	\N	\N	118	\N	\N
1118	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	118	\N	\N
1119	MEMBRECOM	2001-10-03 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	213	\N	\N
1120	MEMBRECOM	2001-10-03 00:00:00	2001-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	247	\N	\N
1121	MEMBRECOM	2001-10-03 00:00:00	2004-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	455	\N	\N
1123	MEMBRECOM	2001-10-03 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	800	\N	\N
1125	MEMBRECOM	2001-10-03 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	801	\N	\N
1126	MEMBRECOM	2001-10-03 00:00:00	2004-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	802	\N	\N
1127	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	238	\N	\N
1128	MEMBRECOM	2001-10-03 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	311	\N	\N
1129	MEMBRECOM	2001-10-03 00:00:00	2004-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	609	\N	\N
1130	MEMBRECOM	2001-10-03 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	286	\N	\N
1131	MEMBRECOM	2001-10-03 00:00:00	2007-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9	\N	\N
1132	MEMBRECOM	2001-10-03 00:00:00	2004-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	803	\N	\N
1133	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	217	\N	\N
1134	MEMBRECOM	2001-10-03 00:00:00	2004-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	804	\N	\N
1135	MEMBRECOM	2001-10-03 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	805	\N	\N
1136	PDTCOM	2001-10-04 00:00:00	2002-06-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	469	\N	\N
1137	VICPDTCOM	2001-10-04 00:00:00	2004-09-30 00:00:00	1	ANCIEN	\N	\N	\N	\N	278	\N	\N
1139	VICPDTCOM	2001-10-04 00:00:00	2004-10-07 00:00:00	2	ANCIEN	\N	\N	\N	\N	133	\N	\N
1140	VICPDTCOM	2001-10-04 00:00:00	2004-10-07 00:00:00	3	ANCIEN	\N	\N	\N	\N	40	\N	\N
1143	VICPDTCOM	2001-10-04 00:00:00	2004-09-30 00:00:00	5	ANCIEN	\N	\N	\N	\N	270	\N	\N
1144	VICPDTCOM	2001-10-04 00:00:00	2004-10-07 00:00:00	6	ANCIEN	\N	\N	\N	\N	722	\N	\N
1145	SECRETCOM	2001-10-04 00:00:00	2004-10-07 00:00:00	1	ANCIEN	\N	\N	\N	\N	20	\N	\N
1146	SECRETCOM	2001-10-04 00:00:00	2004-10-07 00:00:00	2	ANCIEN	\N	\N	\N	\N	241	\N	\N
1148	SECRETCOM	2001-10-04 00:00:00	2008-10-06 00:00:00	4	ANCIEN	\N	\N	\N	\N	275	\N	\N
1149	RAPGENCOM	2001-10-04 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	468	\N	\N
1150	PDTCOM	2001-10-04 00:00:00	2004-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	405	\N	\N
1151	VICPDTCOM	2001-10-04 00:00:00	2008-10-06 00:00:00	1	ANCIEN	\N	\N	\N	\N	243	\N	\N
1152	VICPDTCOM	2001-10-04 00:00:00	2002-01-19 00:00:00	2	ANCIEN	\N	\N	\N	\N	394	\N	\N
1153	VICPDTCOM	2001-10-04 00:00:00	2004-10-07 00:00:00	3	ANCIEN	\N	\N	\N	\N	118	\N	\N
1154	VICPDTCOM	2001-10-04 00:00:00	2004-10-07 00:00:00	4	ANCIEN	\N	\N	\N	\N	12	\N	\N
1155	VICPDTCOM	2001-10-04 00:00:00	2008-09-30 00:00:00	6	ANCIEN	\N	\N	\N	\N	295	\N	\N
1156	VICPDTCOM	2001-10-04 00:00:00	2004-10-06 00:00:00	5	ANCIEN	\N	\N	\N	\N	421	\N	\N
1157	SECRETCOM	2001-10-04 00:00:00	2004-09-30 00:00:00	1	ANCIEN	\N	\N	\N	\N	92	\N	\N
484	PDTCOM	1998-10-07 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	316	\N	\N
317	VICPDTCOM	1992-10-08 00:00:00	1998-10-06 00:00:00	2	ANCIEN	\N	\N	\N	\N	317	\N	\N
485	VICPDTCOM	1998-10-07 00:00:00	2001-10-03 00:00:00	2	ANCIEN	\N	\N	\N	\N	317	\N	\N
488	VICPDTCOM	1998-10-07 00:00:00	2001-09-30 00:00:00	4	ANCIEN	\N	\N	\N	\N	126	\N	\N
487	VICPDTCOM	1998-10-07 00:00:00	2001-10-03 00:00:00	6	ANCIEN	\N	\N	\N	\N	248	\N	\N
489	MEMBRECOM	1989-10-04 00:00:00	1995-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	67	\N	\N
490	VICPDTCOM	1998-10-07 00:00:00	2001-10-03 00:00:00	1	ANCIEN	\N	\N	\N	\N	44	\N	\N
491	SECRETCOM	1998-10-07 00:00:00	2001-03-27 00:00:00	3	ANCIEN	\N	\N	\N	\N	189	\N	\N
492	MEMBRECOM	1998-10-07 00:00:00	1998-10-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	95	\N	\N
502	VICPDTCOM	1998-10-07 00:00:00	2001-10-03 00:00:00	4	ANCIEN	\N	\N	\N	\N	224	\N	\N
507	MEMBRECOM	1998-10-07 00:00:00	2001-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	152	\N	\N
508	MEMBRECOM	1998-10-07 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	23	\N	\N
510	MEMBRECOM	1998-10-07 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	193	\N	\N
511	SECRETCOM	1998-10-07 00:00:00	2001-09-30 00:00:00	2	ANCIEN	\N	\N	\N	\N	112	\N	\N
512	SECRETCOM	1998-10-07 00:00:00	2001-09-30 00:00:00	4	ANCIEN	\N	\N	\N	\N	201	\N	\N
513	MEMBRECOM	1998-10-07 00:00:00	2001-06-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	144	\N	\N
514	VICPDTCOM	1998-10-07 00:00:00	2001-10-03 00:00:00	4	ANCIEN	\N	\N	\N	\N	231	\N	\N
515	VICPDTCOM	1998-10-07 00:00:00	2001-10-03 00:00:00	3	ANCIEN	\N	\N	\N	\N	270	\N	\N
517	MEMBRECOM	1998-10-07 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	133	\N	\N
518	SECRETCOM	1998-10-07 00:00:00	2001-10-03 00:00:00	3	ANCIEN	\N	\N	\N	\N	195	\N	\N
519	SECRETCOM	1998-10-07 00:00:00	2001-10-03 00:00:00	4	ANCIEN	\N	\N	\N	\N	275	\N	\N
520	PDTCOM	1998-10-07 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	245	\N	\N
521	VICPDTCOM	1998-10-07 00:00:00	2001-01-22 00:00:00	1	ANCIEN	\N	\N	\N	\N	274	\N	\N
523	VICPDTCOM	1998-10-07 00:00:00	2001-09-30 00:00:00	4	ANCIEN	\N	\N	\N	\N	138	\N	\N
524	VICPDTCOM	1998-10-07 00:00:00	2001-10-03 00:00:00	5	ANCIEN	\N	\N	\N	\N	295	\N	\N
525	SECRETCOM	1998-10-07 00:00:00	2001-10-03 00:00:00	3	ANCIEN	\N	\N	\N	\N	250	\N	\N
526	SECRETCOM	1998-10-07 00:00:00	2001-10-03 00:00:00	4	ANCIEN	\N	\N	\N	\N	247	\N	\N
527	MEMBRECOM	1986-04-10 00:00:00	1996-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	131	\N	\N
528	VICPDTCOM	1998-10-07 00:00:00	2001-09-30 00:00:00	1	ANCIEN	\N	\N	\N	\N	151	\N	\N
530	SECRETCOM	1998-10-07 00:00:00	2001-10-03 00:00:00	2	ANCIEN	\N	\N	\N	\N	35	\N	\N
531	VICPDTCOM	1998-10-07 00:00:00	2001-10-03 00:00:00	3	ANCIEN	\N	\N	\N	\N	142	\N	\N
532	VICPDTCOM	1998-10-07 00:00:00	1999-12-15 00:00:00	4	ANCIEN	\N	\N	\N	\N	281	\N	\N
533	VICPDTCOM	1998-10-07 00:00:00	2001-10-03 00:00:00	5	ANCIEN	\N	\N	\N	\N	260	\N	\N
534	VICPDTCOM	1998-10-07 00:00:00	2001-09-30 00:00:00	6	ANCIEN	\N	\N	\N	\N	167	\N	\N
10972	RAPCOM	2013-04-02 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9259	\N	2017-09-24 18:16:52
535	SECRETCOM	1998-10-07 00:00:00	1999-12-15 00:00:00	2	ANCIEN	\N	\N	\N	\N	227	\N	\N
536	SECRETCOM	1998-10-07 00:00:00	2001-09-30 00:00:00	3	ANCIEN	\N	\N	\N	\N	199	\N	\N
537	VICPDTCOM	1998-10-07 00:00:00	2001-10-03 00:00:00	3	ANCIEN	\N	\N	\N	\N	255	\N	\N
538	VICPDTCOM	1998-10-07 00:00:00	2001-10-03 00:00:00	5	ANCIEN	\N	\N	\N	\N	134	\N	\N
540	SECRETCOM	1998-10-07 00:00:00	2001-10-03 00:00:00	2	ANCIEN	\N	\N	\N	\N	181	\N	\N
541	SECRETCOM	1998-10-07 00:00:00	2001-10-03 00:00:00	4	ANCIEN	\N	\N	\N	\N	308	\N	\N
542	PDTCOM	1998-10-07 00:00:00	2001-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	419	\N	\N
543	VICPDTCOM	1998-10-07 00:00:00	2001-09-23 00:00:00	2	ANCIEN	\N	\N	\N	\N	130	\N	\N
544	VICPDTCOM	1998-10-07 00:00:00	2001-10-03 00:00:00	5	ANCIEN	\N	\N	\N	\N	217	\N	\N
545	SECRETCOM	1998-10-07 00:00:00	2001-10-03 00:00:00	1	ANCIEN	\N	\N	\N	\N	238	\N	\N
546	SECRETCOM	1998-10-07 00:00:00	2001-10-03 00:00:00	3	ANCIEN	\N	\N	\N	\N	290	\N	\N
548	VICPDTCOM	1998-10-07 00:00:00	2001-10-03 00:00:00	1	ANCIEN	\N	\N	\N	\N	278	\N	\N
550	VICPDTCOM	1998-10-07 00:00:00	2001-10-03 00:00:00	5	ANCIEN	\N	\N	\N	\N	269	\N	\N
551	VICPDTCOM	1998-10-07 00:00:00	2001-10-03 00:00:00	6	ANCIEN	\N	\N	\N	\N	402	\N	\N
552	SECRETCOM	1998-10-07 00:00:00	2001-09-30 00:00:00	1	ANCIEN	\N	\N	\N	\N	147	\N	\N
553	SECRETCOM	1998-10-07 00:00:00	2001-10-03 00:00:00	2	ANCIEN	\N	\N	\N	\N	241	\N	\N
554	VICPDTCOM	1998-10-07 00:00:00	2001-10-03 00:00:00	2	ANCIEN	\N	\N	\N	\N	394	\N	\N
555	VICPDTCOM	1998-10-07 00:00:00	2000-03-28 00:00:00	6	ANCIEN	\N	\N	\N	\N	91	\N	\N
556	SECRETCOM	1998-10-07 00:00:00	2001-01-23 00:00:00	1	ANCIEN	\N	\N	\N	\N	243	\N	\N
557	SECRETCOM	1998-10-07 00:00:00	2001-10-03 00:00:00	1	ANCIEN	\N	\N	\N	\N	92	\N	\N
293	MEMBRECOM	\N	1998-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	293	\N	\N
558	MEMBRECOM	1998-10-14 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	459	\N	\N
559	MEMBRECOM	1998-10-14 00:00:00	1999-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	460	\N	\N
560	MEMBRECOM	1998-10-14 00:00:00	2001-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	461	\N	\N
561	MEMBRECOM	1998-10-14 00:00:00	2000-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	462	\N	\N
562	MEMBRECOM	1998-10-20 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	463	\N	\N
563	MEMBRECOM	\N	1998-11-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	464	\N	\N
564	MEMBRECOM	1998-11-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	465	\N	\N
567	MEMBRECOM	1998-11-16 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	467	\N	\N
566	MEMBRECOM	1998-11-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	466	\N	\N
279	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	279	\N	\N
288	MEMBRECOM	\N	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	288	\N	\N
300	MEMBRECOM	1996-04-15 00:00:00	2000-03-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	300	\N	\N
307	MEMBRECOM	\N	1998-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	307	\N	\N
320	MEMBRECOM	\N	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	320	\N	\N
334	MEMBRECOM	1998-10-01 00:00:00	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	335	\N	\N
352	MEMBRECOM	1998-10-01 00:00:00	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	350	\N	\N
365	MEMBRECOM	1998-10-01 00:00:00	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	363	\N	\N
568	RAPGENCOM	1998-10-07 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	468	\N	\N
569	PDTCOM	1998-10-07 00:00:00	2001-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	469	\N	\N
570	MEMBRECOM	1999-01-21 00:00:00	1999-02-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	470	\N	\N
571	MEMBRECOM	1999-01-21 00:00:00	1999-02-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	471	\N	\N
574	MEMBRECOM	1999-02-17 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	474	\N	\N
573	MEMBRECOM	1999-02-17 00:00:00	1999-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	473	\N	\N
575	MEMBRECOM	1999-10-05 00:00:00	2000-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	475	\N	\N
576	MEMBRECOM	1999-10-05 00:00:00	2000-05-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	476	\N	\N
587	VICPDTCOM	1999-12-15 00:00:00	2001-10-03 00:00:00	4	ANCIEN	\N	\N	\N	\N	227	\N	\N
578	MEMBRECOM	1999-10-12 00:00:00	2001-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	477	\N	\N
588	SECRETCOM	1999-12-15 00:00:00	2001-10-03 00:00:00	4	ANCIEN	\N	\N	\N	\N	281	\N	\N
589	MEMBRECOM	2000-01-20 00:00:00	2001-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	484	\N	\N
581	MEMBRECOM	1999-10-12 00:00:00	2000-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	478	\N	\N
582	MEMBRECOM	1999-11-09 00:00:00	2001-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	479	\N	\N
583	MEMBRECOM	1999-11-04 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	480	\N	\N
584	MEMBRECOM	\N	1997-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	481	\N	\N
585	MEMBRECOM	1999-11-17 00:00:00	2000-01-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	482	\N	\N
586	MEMBRECOM	2000-01-20 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	483	\N	\N
590	MEMBRECOM	2000-01-20 00:00:00	2001-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	485	\N	\N
591	MEMBRECOM	2000-01-20 00:00:00	2001-01-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	486	\N	\N
592	MEMBRECOM	\N	2000-02-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	487	\N	\N
593	MEMBRECOM	2000-02-23 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	488	\N	\N
594	MEMBRECOM	2000-03-07 00:00:00	2000-04-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	489	\N	\N
595	MEMBRECOM	2000-03-07 00:00:00	2000-04-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	490	\N	\N
596	MEMBRECOM	2000-03-19 00:00:00	2000-03-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	492	\N	\N
597	MEMBRECOM	2000-03-28 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	493	\N	\N
598	MEMBRECOM	2000-03-28 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	494	\N	\N
599	MEMBRECOM	2000-03-29 00:00:00	2000-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	495	\N	\N
600	MEMBRECOM	2000-04-04 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	496	\N	\N
601	MEMBRECOM	2000-04-04 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	497	\N	\N
602	MEMBRECOM	2000-04-25 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	498	\N	\N
603	MEMBRECOM	2000-04-25 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	499	\N	\N
604	MEMBRECOM	2000-04-28 00:00:00	2000-05-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	500	\N	\N
605	MEMBRECOM	\N	2000-05-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	501	\N	\N
606	MEMBRECOM	2000-05-02 00:00:00	2000-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	502	\N	\N
607	MEMBRECOM	2000-05-02 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	503	\N	\N
608	MEMBRECOM	2000-05-04 00:00:00	2000-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	504	\N	\N
609	MEMBRECOM	2000-05-04 00:00:00	2000-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	505	\N	\N
610	MEMBRECOM	2000-05-16 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	506	\N	\N
611	MEMBRECOM	2000-05-16 00:00:00	2001-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	507	\N	\N
612	MEMBRECOM	2000-05-23 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	508	\N	\N
613	MEMBRECOM	2000-05-23 00:00:00	2001-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	509	\N	\N
614	MEMBRECOM	2000-05-23 00:00:00	2000-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	510	\N	\N
615	MEMBRECOM	2000-05-23 00:00:00	2000-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	511	\N	\N
617	VICPDTCOM	2000-05-24 00:00:00	2001-10-03 00:00:00	6	ANCIEN	\N	\N	\N	\N	421	\N	\N
619	MEMBRECOM	2000-06-28 00:00:00	2000-10-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	513	\N	\N
620	MEMBRECOM	2000-06-28 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	514	\N	\N
623	MEMBRECOM	2000-10-02 00:00:00	2000-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	516	\N	\N
622	MEMBRECOM	2000-10-02 00:00:00	2000-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	515	\N	\N
624	MEMBRECOM	2000-10-03 00:00:00	2000-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	517	\N	\N
627	VICPDTCOM	2000-10-05 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	517	\N	\N
626	MEMBRECOM	2000-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	519	\N	\N
628	MEMBRECOM	2000-10-10 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	520	\N	\N
629	MEMBRECOM	2000-10-10 00:00:00	2001-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	521	\N	\N
630	MEMBRECOM	2000-10-12 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	522	\N	\N
631	MEMBRECOM	2000-10-12 00:00:00	2001-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	523	\N	\N
1805	MEMBRECOM	\N	1972-05-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1258	\N	\N
1806	MEMBRECOM	\N	1963-11-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1259	\N	\N
1807	MEMBRECOM	\N	1971-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1260	\N	\N
1808	MEMBRECOM	\N	1977-01-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1261	\N	\N
1809	MEMBRECOM	\N	1980-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1262	\N	\N
1810	MEMBRECOM	\N	1962-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1263	\N	\N
1811	MEMBRECOM	\N	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1264	\N	\N
1812	MEMBRECOM	\N	1981-02-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1265	\N	\N
1813	MEMBRECOM	\N	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1266	\N	\N
1814	MEMBRECOM	\N	1979-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1267	\N	\N
1815	MEMBRECOM	\N	1971-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1268	\N	\N
1816	MEMBRECOM	\N	1965-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1269	\N	\N
1817	MEMBRECOM	\N	1962-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1270	\N	\N
1818	MEMBRECOM	\N	1973-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1271	\N	\N
1819	MEMBRECOM	1962-10-05 00:00:00	1971-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1272	\N	\N
1820	VICPDTCOM	1967-10-11 00:00:00	1976-04-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1273	\N	\N
1821	MEMBRECOM	\N	1974-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1274	\N	\N
1822	MEMBRECOM	\N	1978-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1275	\N	\N
1823	MEMBRECOM	\N	1977-12-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1276	\N	\N
1826	SECRETCOM	1975-10-09 00:00:00	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1279	\N	\N
1827	SECRETCOM	1959-10-08 00:00:00	1970-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1280	\N	\N
1828	SECRETCOM	1969-10-08 00:00:00	1971-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1281	\N	\N
1830	MEMBRECOM	\N	1965-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1283	\N	\N
1831	MEMBRECOM	\N	1965-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1284	\N	\N
1832	MEMBRECOM	\N	1971-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1285	\N	\N
1833	MEMBRECOM	\N	1971-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1286	\N	\N
1835	MEMBRECOM	\N	1978-03-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1288	\N	\N
1836	MEMBRECOM	\N	1977-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1289	\N	\N
1837	MEMBRECOM	\N	1959-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1290	\N	\N
1838	MEMBRECOM	\N	1976-12-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1291	\N	\N
1840	SECRETCOM	1964-10-07 00:00:00	1965-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1293	\N	\N
1841	MEMBRECOM	\N	1968-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1294	\N	\N
1842	MEMBRECOM	\N	1962-09-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1295	\N	\N
1844	MEMBRECOM	\N	1969-09-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1297	\N	\N
1845	MEMBRECOM	\N	1983-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1298	\N	\N
1846	MEMBRECOM	\N	1980-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1299	\N	\N
1847	SECRETCOM	1971-10-06 00:00:00	1974-02-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1300	\N	\N
1849	MEMBRECOM	\N	1962-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1302	\N	\N
1850	SECRETCOM	1974-10-04 00:00:00	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1303	\N	\N
1851	MEMBRECOM	\N	1960-05-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1304	\N	\N
1852	MEMBRECOM	\N	1971-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1305	\N	\N
1854	MEMBRECOM	\N	1980-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1307	\N	\N
1855	MEMBRECOM	\N	1974-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1308	\N	\N
1856	MEMBRECOM	\N	1974-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1309	\N	\N
1858	MEMBRECOM	\N	1966-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1311	\N	\N
1859	MEMBRECOM	\N	1971-08-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1312	\N	\N
1861	MEMBRECOM	\N	1980-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1314	\N	\N
1862	MEMBRECOM	\N	1978-10-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1315	\N	\N
1863	MEMBRECOM	\N	1968-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1316	\N	\N
1864	MEMBRECOM	\N	1968-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1317	\N	\N
1865	MEMBRECOM	\N	1969-07-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1318	\N	\N
1866	MEMBRECOM	\N	1981-09-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1319	\N	\N
1867	MEMBRECOM	\N	1983-05-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1320	\N	\N
1868	MEMBRECOM	\N	1968-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1321	\N	\N
1869	VICPDTCOM	1974-10-04 00:00:00	1980-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1322	\N	\N
1870	VICPDTCOM	1971-10-06 00:00:00	1973-05-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1323	\N	\N
1871	MEMBRECOM	\N	1968-10-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1324	\N	\N
1872	MEMBRECOM	\N	1986-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1325	\N	\N
1873	MEMBRECOM	\N	1965-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1326	\N	\N
1874	MEMBRECOM	\N	1974-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1327	\N	\N
1875	VICPDTCOM	1959-05-06 00:00:00	1960-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1328	\N	\N
1876	SECRETCOM	1971-10-06 00:00:00	1980-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1329	\N	\N
1877	MEMBRECOM	\N	1980-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1330	\N	\N
1878	MEMBRECOM	\N	1971-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1331	\N	\N
1879	MEMBRECOM	\N	1971-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1332	\N	\N
1880	MEMBRECOM	\N	1975-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1333	\N	\N
1881	MEMBRECOM	\N	1980-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1334	\N	\N
1882	MEMBRECOM	1975-10-09 00:00:00	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1335	\N	\N
1883	MEMBRECOM	\N	1968-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1336	\N	\N
1884	MEMBRECOM	\N	1981-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1337	\N	\N
1885	MEMBRECOM	\N	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1338	\N	\N
1886	MEMBRECOM	\N	1962-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1339	\N	\N
1887	MEMBRECOM	\N	1979-01-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1340	\N	\N
1888	MEMBRECOM	\N	1980-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1341	\N	\N
1889	MEMBRECOM	\N	1960-10-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1342	\N	\N
1890	MEMBRECOM	\N	1974-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1343	\N	\N
1891	MEMBRECOM	\N	1976-03-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1344	\N	\N
1892	MEMBRECOM	\N	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1345	\N	\N
1893	MEMBRECOM	\N	1982-01-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1346	\N	\N
1894	MEMBRECOM	\N	1979-05-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1347	\N	\N
1895	MEMBRECOM	\N	1973-09-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1348	\N	\N
1896	MEMBRECOM	\N	1975-12-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1349	\N	\N
1897	MEMBRECOM	\N	1974-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1350	\N	\N
1898	MEMBRECOM	\N	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1351	\N	\N
1901	MEMBRECOM	\N	1971-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1354	\N	\N
1902	MEMBRECOM	\N	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1355	\N	\N
1903	MEMBRECOM	\N	1976-02-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1356	\N	\N
1904	SECRETCOM	1959-05-12 00:00:00	1969-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1357	\N	\N
1905	MEMBRECOM	\N	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1358	\N	\N
1906	MEMBRECOM	\N	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1359	\N	\N
1907	MEMBRECOM	\N	1979-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1360	\N	\N
1908	PDTCOM	1959-05-12 00:00:00	1971-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1361	\N	\N
1909	MEMBRECOM	\N	1961-07-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1362	\N	\N
1910	MEMBRECOM	\N	1970-06-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1363	\N	\N
1911	MEMBRECOM	1960-10-06 00:00:00	1965-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1364	\N	\N
1912	VICPDTCOM	1959-05-12 00:00:00	1967-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1365	\N	\N
1913	MEMBRECOM	\N	1971-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1366	\N	\N
1914	MEMBRECOM	1959-05-06 00:00:00	1959-05-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1367	\N	\N
1915	MEMBRECOM	\N	1966-12-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1368	\N	\N
1917	MEMBRECOM	\N	1959-08-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1370	\N	\N
1919	MEMBRECOM	\N	1974-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1372	\N	\N
1920	MEMBRECOM	\N	1970-11-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1373	\N	\N
1922	PDTCOM	1959-05-06 00:00:00	1971-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1375	\N	\N
1923	MEMBRECOM	\N	1965-03-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1376	\N	\N
1924	MEMBRECOM	\N	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1377	\N	\N
1307	MEMBRECOM	2003-01-15 00:00:00	2003-05-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	893	\N	\N
1308	MEMBRECOM	2003-01-15 00:00:00	2003-05-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	894	\N	\N
1340	MEMBRECOM	2002-12-12 00:00:00	2003-06-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	927	\N	\N
1310	MEMBRECOM	2003-01-15 00:00:00	2003-05-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	896	\N	\N
1311	MEMBRECOM	2003-01-15 00:00:00	2003-05-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	897	\N	\N
1313	MEMBRECOM	2003-01-15 00:00:00	2003-05-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	899	\N	\N
1314	MEMBRECOM	2003-01-15 00:00:00	2003-05-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	900	\N	\N
1315	MEMBRECOM	2003-01-15 00:00:00	2003-05-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	901	\N	\N
1316	MEMBRECOM	2003-01-15 00:00:00	2003-05-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	902	\N	\N
1317	MEMBRECOM	2003-01-15 00:00:00	2003-05-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	903	\N	\N
1319	MEMBRECOM	2003-01-15 00:00:00	2003-05-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	905	\N	\N
1320	MEMBRECOM	2003-01-15 00:00:00	2003-05-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	906	\N	\N
1321	MEMBRECOM	2003-01-15 00:00:00	2003-05-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	907	\N	\N
1322	MEMBRECOM	2003-01-15 00:00:00	2003-05-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	908	\N	\N
1342	MEMBRECOM	2002-12-12 00:00:00	2003-06-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	929	\N	\N
1343	MEMBRECOM	2002-12-12 00:00:00	2003-06-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	930	\N	\N
1344	MEMBRECOM	2002-12-12 00:00:00	2003-06-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	931	\N	\N
1345	MEMBRECOM	2002-12-12 00:00:00	2003-06-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	932	\N	\N
1346	MEMBRECOM	2002-12-12 00:00:00	2003-06-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	933	\N	\N
1347	MEMBRECOM	2002-12-12 00:00:00	2003-06-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	934	\N	\N
1349	MEMBRECOM	2002-12-12 00:00:00	2003-06-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	936	\N	\N
1350	MEMBRECOM	2002-12-12 00:00:00	2003-06-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	937	\N	\N
1351	MEMBRECOM	2002-12-12 00:00:00	2003-06-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	938	\N	\N
1352	MEMBRECOM	2002-12-12 00:00:00	2003-06-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	939	\N	\N
1353	MEMBRECOM	2002-12-12 00:00:00	2003-06-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	940	\N	\N
1354	MEMBRECOM	2002-12-12 00:00:00	2003-06-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	941	\N	\N
1355	MEMBRECOM	2002-12-12 00:00:00	2003-06-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	942	\N	\N
1357	MEMBRECOM	2002-12-12 00:00:00	2003-06-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	944	\N	\N
1358	MEMBRECOM	2002-12-12 00:00:00	2003-06-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	945	\N	\N
1359	MEMBRECOM	2002-12-12 00:00:00	2003-06-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	946	\N	\N
1360	MEMBRECOM	2002-12-12 00:00:00	2003-06-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	947	\N	\N
1925	MEMBRECOM	\N	1962-11-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1378	\N	\N
1927	MEMBRECOM	\N	1979-09-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1380	\N	\N
1928	MEMBRECOM	\N	1966-05-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1381	\N	\N
1929	VICPDTCOM	1970-10-07 00:00:00	1971-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1382	\N	\N
1933	VICPDTCOM	1967-04-05 00:00:00	1971-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1386	\N	\N
1934	SECRETCOM	1959-05-12 00:00:00	1962-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1387	\N	\N
1935	MEMBRECOM	\N	1976-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1388	\N	\N
1937	MEMBRECOM	\N	1965-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1390	\N	\N
1938	MEMBRECOM	\N	1969-01-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1391	\N	\N
1941	MEMBRECOM	\N	1965-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1394	\N	\N
1942	MEMBRECOM	\N	1975-04-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1395	\N	\N
1943	MEMBRECOM	\N	1974-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1396	\N	\N
1944	MEMBRECOM	\N	1965-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1397	\N	\N
1946	MEMBRECOM	1973-06-14 00:00:00	1980-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1399	\N	\N
1947	SECRETCOM	1971-10-06 00:00:00	1974-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1400	\N	\N
1948	MEMBRECOM	\N	1968-09-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1401	\N	\N
1949	VICPDTCOM	1959-05-12 00:00:00	1965-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1402	\N	\N
1951	MEMBRECOM	\N	1968-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1404	\N	\N
1952	MEMBRECOM	\N	1965-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1405	\N	\N
1953	MEMBRECOM	\N	1968-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1406	\N	\N
1955	MEMBRECOM	\N	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1408	\N	\N
1956	MEMBRECOM	\N	1974-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1409	\N	\N
1957	MEMBRECOM	\N	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1410	\N	\N
1958	MEMBRECOM	\N	1970-10-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1411	\N	\N
1959	MEMBRECOM	\N	1964-08-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1412	\N	\N
1960	MEMBRECOM	\N	1976-05-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1413	\N	\N
1961	MEMBRECOM	1977-10-06 00:00:00	1980-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1414	\N	\N
1962	MEMBRECOM	\N	1962-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1415	\N	\N
1963	MEMBRECOM	\N	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1416	\N	\N
1964	SECRETCOM	1959-10-08 00:00:00	1968-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1417	\N	\N
1965	VICPDTCOM	1959-05-12 00:00:00	1959-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1418	\N	\N
1966	MEMBRECOM	\N	1971-10-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1419	\N	\N
1967	MEMBRECOM	\N	1965-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1420	\N	\N
1968	MEMBRECOM	\N	1968-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1421	\N	\N
1969	MEMBRECOM	\N	1962-09-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1422	\N	\N
1970	MEMBRECOM	\N	1971-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1423	\N	\N
1971	MEMBRECOM	\N	1961-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1424	\N	\N
1972	MEMBRECOM	\N	1968-09-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1425	\N	\N
1973	MEMBRECOM	\N	1968-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1426	\N	\N
1974	MEMBRECOM	\N	1972-11-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1427	\N	\N
1975	MEMBRECOM	\N	1963-01-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1428	\N	\N
1976	VICPDTCOM	1967-10-11 00:00:00	1971-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1429	\N	\N
1977	MEMBRECOM	\N	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1430	\N	\N
1978	MEMBRECOM	\N	1974-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1431	\N	\N
1192	SECRETCOM	2001-10-04 00:00:00	2003-03-05 00:00:00	4	ANCIEN	\N	\N	\N	\N	63	\N	\N
1193	PDTCOM	2001-10-04 00:00:00	2002-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	316	\N	\N
1194	VICPDTCOM	2001-10-04 00:00:00	2002-09-30 00:00:00	1	ANCIEN	\N	\N	\N	\N	190	\N	\N
1195	VICPDTCOM	2001-10-04 00:00:00	2004-09-30 00:00:00	2	ANCIEN	\N	\N	\N	\N	317	\N	\N
1196	VICPDTCOM	2001-10-04 00:00:00	2002-07-10 00:00:00	3	ANCIEN	\N	\N	\N	\N	255	\N	\N
1197	VICPDTCOM	2001-10-04 00:00:00	2004-02-12 00:00:00	4	ANCIEN	\N	\N	\N	\N	66	\N	\N
1198	VICPDTCOM	2001-10-04 00:00:00	2004-09-30 00:00:00	5	ANCIEN	\N	\N	\N	\N	248	\N	\N
1213	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	810	\N	\N
1200	SECRETCOM	2001-10-04 00:00:00	2005-10-03 00:00:00	1	ANCIEN	\N	\N	\N	\N	506	\N	\N
1201	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	93	\N	\N
1202	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	153	\N	\N
1203	MEMBRECOM	1992-10-08 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17	\N	\N
1204	SECRETCOM	2001-10-04 00:00:00	2007-02-25 00:00:00	2	ANCIEN	\N	\N	\N	\N	181	\N	\N
1205	SECRETCOM	2001-10-04 00:00:00	2008-09-30 00:00:00	4	ANCIEN	\N	\N	\N	\N	79	\N	\N
1206	SECRETCOM	2001-10-04 00:00:00	2004-10-05 00:00:00	4	ANCIEN	\N	\N	\N	\N	736	\N	\N
1207	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	683	\N	\N
1211	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	809	\N	\N
1209	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	807	\N	\N
1210	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	808	\N	\N
1214	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	811	\N	\N
10926	MEMBRECOM	2013-03-13 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9215	\N	2013-12-16 10:28:45
1217	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	812	\N	\N
1218	MEMBRECOM	\N	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	206	\N	\N
1219	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	813	\N	\N
1220	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	814	\N	\N
1221	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	815	\N	\N
1222	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	816	\N	\N
1223	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	817	\N	\N
1224	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	818	\N	\N
1225	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	819	\N	\N
1226	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	820	\N	\N
1227	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	821	\N	\N
1228	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	822	\N	\N
1231	MEMBRECOM	2001-10-15 00:00:00	2001-11-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	825	\N	\N
1230	MEMBRECOM	2001-10-10 00:00:00	2004-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	824	\N	\N
1232	MEMBRECOM	2001-11-06 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	826	\N	\N
1233	MEMBRECOM	2001-10-01 00:00:00	2002-01-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	828	\N	\N
1234	MEMBRECOM	2002-01-15 00:00:00	2002-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	829	\N	\N
1235	MEMBRECOM	2002-01-20 00:00:00	2002-01-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	830	\N	\N
1236	MEMBRECOM	2002-01-29 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	831	\N	\N
1237	VICPDTCOM	2002-02-06 00:00:00	2004-10-07 00:00:00	2	ANCIEN	\N	\N	\N	\N	750	\N	\N
1238	MEMBRECOM	\N	2001-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	832	\N	\N
1239	MEMBRECOM	2002-06-27 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	833	\N	\N
1240	MEMBRECOM	2002-06-08 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	834	\N	\N
1241	MEMBRECOM	2002-06-08 00:00:00	2002-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	835	\N	\N
1242	MEMBRECOM	2002-06-08 00:00:00	2002-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	836	\N	\N
742	MEMBRECOM	2001-06-19 00:00:00	2001-11-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	641	\N	\N
751	MEMBRECOM	2001-06-19 00:00:00	2001-11-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	650	\N	\N
1245	MEMBRECOM	2002-06-27 00:00:00	2002-07-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	841	\N	\N
1246	MEMBRECOM	2002-06-27 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	842	\N	\N
1247	MEMBRECOM	2002-06-27 00:00:00	2007-06-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	843	\N	\N
1248	MEMBRECOM	2002-06-27 00:00:00	2008-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	844	\N	\N
1249	MEMBRECOM	2002-06-27 00:00:00	2004-06-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	845	\N	\N
1250	MEMBRECOM	2002-06-27 00:00:00	2003-11-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	846	\N	\N
1252	MEMBRECOM	2002-07-03 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	848	\N	\N
1259	PDTCOM	2002-07-10 00:00:00	2004-10-07 00:00:00	1	ANCIEN	\N	\N	\N	\N	255	\N	\N
1273	MEMBRECOM	2002-07-30 00:00:00	2003-05-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	857	\N	\N
1262	MEMBRECOM	2002-07-10 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	316	\N	\N
1263	VICPDTCOM	2002-07-10 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	452	\N	\N
1264	VICPDTCOM	2002-07-02 00:00:00	2008-10-06 00:00:00	2	ANCIEN	\N	\N	\N	\N	170	\N	\N
1270	MEMBRECOM	2002-07-18 00:00:00	2002-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	854	\N	\N
1266	PDTCOM	2002-07-17 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	841	\N	\N
1274	MEMBRECOM	2002-10-03 00:00:00	2002-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	859	\N	\N
1276	MEMBRECOM	2002-10-01 00:00:00	2004-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	861	\N	\N
1277	MEMBRECOM	2002-10-01 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	862	\N	\N
1278	MEMBRECOM	2002-10-01 00:00:00	2008-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	863	\N	\N
1279	MEMBRECOM	2002-10-03 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	864	\N	\N
1281	MEMBRECOM	2002-10-08 00:00:00	2003-05-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	867	\N	\N
1282	MEMBRECOM	2002-10-08 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	868	\N	\N
1284	MEMBRECOM	2002-10-15 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	870	\N	\N
1286	MEMBRECOM	2002-10-15 00:00:00	2004-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	873	\N	\N
1287	VICPDTCOM	2002-10-16 00:00:00	2008-10-06 00:00:00	2	ANCIEN	\N	\N	\N	\N	412	\N	\N
1288	MEMBRECOM	2002-12-11 00:00:00	2002-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	874	\N	\N
1289	MEMBRECOM	2002-12-19 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	875	\N	\N
1290	PDTCOM	2002-10-01 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	876	\N	\N
1292	MEMBRECOM	2008-10-07 00:00:00	2010-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	878	\N	\N
1295	MEMBRECOM	2002-10-01 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	881	\N	2014-09-28 13:16:32
1296	MEMBRECOM	2002-10-01 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	882	\N	\N
1297	MEMBRECOM	2002-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	883	\N	\N
1298	SECRETRAPCOM	2002-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	884	\N	\N
1299	MEMBRECOM	2002-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	885	\N	\N
1301	MEMBRECOM	2003-01-15 00:00:00	2003-05-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	887	\N	\N
1302	MEMBRECOM	2003-01-15 00:00:00	2003-05-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	888	\N	\N
1303	MEMBRECOM	2003-01-15 00:00:00	2003-05-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	889	\N	\N
1304	MEMBRECOM	2003-01-15 00:00:00	2003-05-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	890	\N	\N
1306	MEMBRECOM	2003-01-15 00:00:00	2003-05-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	892	\N	\N
797	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	696	\N	\N
798	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	697	\N	\N
799	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	698	\N	\N
800	MEMBRECOM	2001-10-03 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	699	\N	\N
801	MEMBRECOM	2001-10-03 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	700	\N	\N
802	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	701	\N	\N
803	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	702	\N	\N
804	MEMBRECOM	2001-10-03 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	703	\N	\N
805	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	704	\N	\N
806	MEMBRECOM	2001-10-03 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	705	\N	\N
807	MEMBRECOM	2001-10-03 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	706	\N	\N
808	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	707	\N	\N
809	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	708	\N	\N
810	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	709	\N	\N
811	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	710	\N	\N
812	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	711	\N	\N
813	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	712	\N	\N
814	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	713	\N	\N
815	MEMBRECOM	2001-10-01 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	714	\N	\N
817	MEMBRECOM	2001-10-03 00:00:00	2002-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	716	\N	\N
819	MEMBRECOM	2001-10-03 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	98	\N	\N
820	MEMBRECOM	2001-10-03 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	296	\N	\N
821	MEMBRECOM	2001-10-03 00:00:00	2004-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	717	\N	\N
822	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	225	\N	\N
823	MEMBRECOM	2001-10-03 00:00:00	2007-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	718	\N	\N
824	MEMBRECOM	2001-10-03 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	261	\N	2014-09-28 19:03:04
825	VICPDTCOM	2001-10-03 00:00:00	2008-09-24 00:00:00	7	ANCIEN	\N	\N	\N	\N	134	\N	\N
826	MEMBRECOM	2001-10-03 00:00:00	2002-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	719	\N	\N
827	MEMBRECOM	2001-10-03 00:00:00	2008-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	720	\N	\N
828	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	45	\N	\N
830	MEMBRECOM	2001-10-03 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	721	\N	\N
831	MEMBRECOM	2001-10-03 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	262	\N	\N
832	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	722	\N	\N
835	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	295	\N	\N
836	MEMBRECOM	2001-10-03 00:00:00	2008-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	723	\N	\N
838	MEMBRECOM	2001-10-03 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	517	\N	\N
839	MEMBRECOM	2001-10-03 00:00:00	2009-11-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	480	\N	\N
841	MEMBRECOM	2001-10-03 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	724	\N	\N
842	MEMBRECOM	2001-10-03 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	376	\N	\N
843	MEMBRECOM	2001-10-03 00:00:00	2006-05-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	725	\N	\N
844	MEMBRECOM	2001-10-03 00:00:00	2004-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	266	\N	\N
845	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	378	\N	\N
846	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	191	\N	\N
847	MEMBRECOM	2001-10-03 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	166	\N	\N
848	MEMBRECOM	2001-10-03 00:00:00	2004-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	726	\N	\N
849	MEMBRECOM	2001-10-03 00:00:00	2006-07-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	100	\N	\N
850	MEMBRECOM	2001-10-03 00:00:00	2004-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	525	\N	\N
852	MEMBRECOM	2001-10-03 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	727	\N	\N
853	MEMBRECOM	2001-10-03 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	291	\N	\N
1628	MEMBRECOM	1964-10-07 00:00:00	1968-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1081	\N	\N
1629	MEMBRECOM	\N	1968-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1082	\N	\N
1631	MEMBRECOM	\N	1962-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1084	\N	\N
1632	MEMBRECOM	\N	1965-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1085	\N	\N
1633	MEMBRECOM	\N	1983-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1086	\N	\N
1634	MEMBRECOM	\N	1971-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1087	\N	\N
1636	SECRETCOM	1974-10-04 00:00:00	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1089	\N	\N
1637	MEMBRECOM	\N	1974-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1090	\N	\N
1638	MEMBRECOM	\N	1962-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1091	\N	\N
1639	MEMBRECOM	\N	1974-08-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1092	\N	\N
1641	MEMBRECOM	\N	1967-03-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1094	\N	\N
1642	MEMBRECOM	\N	1965-08-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1095	\N	\N
1643	SECRETCOM	1970-10-07 00:00:00	1977-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1096	\N	\N
1644	MEMBRECOM	\N	1972-09-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1097	\N	\N
1646	VICPDTCOM	1965-10-06 00:00:00	1974-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1099	\N	\N
1647	MEMBRECOM	\N	1981-04-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1100	\N	\N
1648	MEMBRECOM	\N	1968-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1101	\N	\N
1650	PDTCOM	1973-04-04 00:00:00	1978-08-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1103	\N	\N
1651	MEMBRECOM	\N	1976-03-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1104	\N	\N
1652	MEMBRECOM	\N	1962-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1105	\N	\N
1655	MEMBRECOM	\N	1971-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1108	\N	\N
1656	MEMBRECOM	\N	1974-09-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1109	\N	\N
1657	MEMBRECOM	\N	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1110	\N	\N
1658	MEMBRECOM	\N	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1111	\N	\N
1660	MEMBRECOM	\N	1980-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1113	\N	\N
1661	MEMBRECOM	\N	1978-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1114	\N	\N
1662	MEMBRECOM	\N	1979-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1115	\N	\N
1664	MEMBRECOM	\N	1962-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1117	\N	\N
1665	MEMBRECOM	\N	1971-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1118	\N	\N
1666	MEMBRECOM	\N	1974-01-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1119	\N	\N
1667	MEMBRECOM	\N	1965-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1120	\N	\N
1669	MEMBRECOM	\N	1968-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1122	\N	\N
1670	MEMBRECOM	\N	1974-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1123	\N	\N
1671	MEMBRECOM	\N	1980-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1124	\N	\N
1672	VICPDTCOM	1971-10-06 00:00:00	1974-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1125	\N	\N
1673	MEMBRECOM	\N	1971-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1126	\N	\N
1675	MEMBRECOM	\N	1980-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1128	\N	\N
1676	MEMBRECOM	\N	1962-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1129	\N	\N
1677	MEMBRECOM	\N	1983-03-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1130	\N	\N
1678	MEMBRECOM	\N	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1131	\N	\N
1679	MEMBRECOM	\N	1981-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1132	\N	\N
1680	MEMBRECOM	\N	1967-05-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1133	\N	\N
1681	MEMBRECOM	\N	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1134	\N	\N
1682	MEMBRECOM	\N	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1135	\N	\N
1683	MEMBRECOM	\N	1971-01-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1136	\N	\N
1684	MEMBRECOM	\N	1962-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1137	\N	\N
1685	MEMBRECOM	\N	1965-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1138	\N	\N
1686	MEMBRECOM	\N	1968-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1139	\N	\N
1687	MEMBRECOM	\N	1962-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1140	\N	\N
1688	MEMBRECOM	\N	1962-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1141	\N	\N
1689	MEMBRECOM	\N	1980-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1142	\N	\N
1690	MEMBRECOM	\N	1965-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1143	\N	\N
1691	SECRETCOM	1964-10-07 00:00:00	1971-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1144	\N	\N
1692	MEMBRECOM	\N	1980-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1145	\N	\N
1693	MEMBRECOM	\N	1974-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1146	\N	\N
1694	MEMBRECOM	\N	1980-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1147	\N	\N
1695	MEMBRECOM	\N	1980-11-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1148	\N	\N
1696	MEMBRECOM	\N	1962-10-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1149	\N	\N
1697	MEMBRECOM	\N	1972-12-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1150	\N	\N
1698	MEMBRECOM	\N	1978-01-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1151	\N	\N
1699	SECRETCOM	1975-05-21 00:00:00	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1152	\N	\N
1700	MEMBRECOM	\N	1974-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1153	\N	\N
1701	MEMBRECOM	\N	1962-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1154	\N	\N
1703	MEMBRECOM	\N	1971-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1156	\N	\N
1704	MEMBRECOM	\N	1978-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1157	\N	\N
1705	VICPDTCOM	1965-10-06 00:00:00	1978-05-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1158	\N	\N
1706	MEMBRECOM	\N	1974-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1159	\N	\N
1707	MEMBRECOM	\N	1982-10-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1160	\N	\N
1708	MEMBRECOM	1974-10-04 00:00:00	1977-03-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1161	\N	\N
1709	MEMBRECOM	\N	1977-03-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1162	\N	\N
1710	MEMBRECOM	\N	1962-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1163	\N	\N
1712	MEMBRECOM	\N	1967-04-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1165	\N	\N
1713	MEMBRECOM	\N	1971-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1166	\N	\N
1714	MEMBRECOM	\N	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1167	\N	\N
1715	MEMBRECOM	\N	1962-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1168	\N	\N
1716	MEMBRECOM	\N	1971-07-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1169	\N	\N
1717	MEMBRECOM	\N	1978-08-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1170	\N	\N
1718	MEMBRECOM	\N	1971-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1171	\N	\N
1719	VICPDTCOM	1971-10-06 00:00:00	1980-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1172	\N	\N
1720	SECRETCOM	1971-10-06 00:00:00	1974-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1173	\N	\N
1721	MEMBRECOM	\N	1981-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1174	\N	\N
1722	MEMBRECOM	\N	1965-02-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1175	\N	\N
1723	MEMBRECOM	\N	1974-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1176	\N	\N
1724	MEMBRECOM	1977-12-15 00:00:00	1983-04-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1177	\N	\N
1725	SECRETCOM	1974-10-04 00:00:00	1975-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1178	\N	\N
10927	MEMBRECOM	2013-03-13 00:00:00	2013-03-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9216	\N	\N
1727	MEMBRECOM	\N	1980-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1180	\N	\N
1728	PDTCOM	1971-10-06 00:00:00	1983-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1181	\N	\N
1729	MEMBRECOM	\N	1971-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1182	\N	\N
1730	MEMBRECOM	1959-05-06 00:00:00	1959-05-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1183	\N	\N
1732	MEMBRECOM	\N	1962-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1185	\N	\N
1733	MEMBRECOM	\N	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1186	\N	\N
1734	MEMBRECOM	\N	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1187	\N	\N
1735	MEMBRECOM	\N	1962-12-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1188	\N	\N
1736	VICPDTCOM	1959-05-06 00:00:00	1967-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1189	\N	\N
1738	MEMBRECOM	\N	1981-11-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1191	\N	\N
1739	MEMBRECOM	\N	1975-07-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1192	\N	\N
1740	SECRETCOM	1964-10-07 00:00:00	1968-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1193	\N	\N
1741	SECRETCOM	1966-10-05 00:00:00	1974-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1194	\N	\N
1743	MEMBRECOM	\N	1974-10-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1196	\N	\N
1744	SECRETCOM	1968-10-08 00:00:00	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1197	\N	\N
1745	VICPDTCOM	1965-10-06 00:00:00	1967-04-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1198	\N	\N
1747	MEMBRECOM	\N	1968-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1200	\N	\N
1748	MEMBRECOM	\N	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1201	\N	\N
1749	MEMBRECOM	\N	1974-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1202	\N	\N
1750	MEMBRECOM	\N	1971-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1203	\N	\N
1752	MEMBRECOM	\N	1972-12-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1205	\N	\N
1753	MEMBRECOM	\N	1983-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1206	\N	\N
1754	MEMBRECOM	\N	1981-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1207	\N	\N
1755	MEMBRECOM	\N	1968-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1208	\N	\N
1757	SECRETCOM	1959-05-12 00:00:00	1971-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1210	\N	\N
1758	MEMBRECOM	\N	1974-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1211	\N	\N
1759	SECRETCOM	1966-10-05 00:00:00	1968-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1212	\N	\N
1761	SECRETCOM	1977-10-06 00:00:00	1982-08-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1214	\N	\N
1762	MEMBRECOM	\N	1974-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1215	\N	\N
1763	MEMBRECOM	\N	1973-11-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1216	\N	\N
1764	MEMBRECOM	\N	1981-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1217	\N	\N
1765	MEMBRECOM	\N	1962-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1218	\N	\N
1766	MEMBRECOM	\N	1980-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1219	\N	\N
1767	MEMBRECOM	\N	1962-05-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1220	\N	\N
1768	SECRETCOM	1974-10-04 00:00:00	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1221	\N	\N
1769	MEMBRECOM	\N	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1222	\N	\N
1770	MEMBRECOM	\N	1974-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1223	\N	\N
1771	MEMBRECOM	\N	1980-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1224	\N	\N
1772	MEMBRECOM	\N	1971-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1225	\N	\N
1773	VICPDTCOM	1959-05-12 00:00:00	1968-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1226	\N	\N
1774	SECRETCOM	1968-10-06 00:00:00	1974-05-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1227	\N	\N
1775	MEMBRECOM	\N	1982-03-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1228	\N	\N
1776	MEMBRECOM	\N	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1229	\N	\N
1778	MEMBRECOM	\N	1962-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1231	\N	\N
1779	MEMBRECOM	\N	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1232	\N	\N
1780	MEMBRECOM	\N	1979-06-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1233	\N	\N
1781	SECRETCOM	1974-10-04 00:00:00	1980-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1234	\N	\N
1782	MEMBRECOM	\N	1959-05-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1235	\N	\N
1783	MEMBRECOM	\N	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1236	\N	\N
1784	MEMBRECOM	\N	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1237	\N	\N
1785	MEMBRECOM	\N	1962-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1238	\N	\N
1786	MEMBRECOM	\N	1983-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1239	\N	\N
1787	MEMBRECOM	1977-10-07 00:00:00	1981-08-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1240	\N	\N
1788	MEMBRECOM	\N	1962-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1241	\N	\N
1789	MEMBRECOM	\N	1962-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1242	\N	\N
1790	VICPDTCOM	1968-10-05 00:00:00	1971-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1243	\N	\N
1792	MEMBRECOM	\N	1968-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1245	\N	\N
1793	MEMBRECOM	\N	1962-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1246	\N	\N
1794	PDTCOM	1968-10-06 00:00:00	1971-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1247	\N	\N
1795	MEMBRECOM	\N	1974-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1248	\N	\N
1796	MEMBRECOM	\N	1971-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1249	\N	\N
1797	MEMBRECOM	\N	1980-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1250	\N	\N
1798	MEMBRECOM	\N	1962-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1251	\N	\N
1799	MEMBRECOM	\N	1971-08-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1252	\N	\N
1800	MEMBRECOM	\N	1965-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1253	\N	\N
1801	MEMBRECOM	\N	1962-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1254	\N	\N
1802	SECRETCOM	1968-10-08 00:00:00	1975-11-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1255	\N	\N
1803	MEMBRECOM	\N	1967-04-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1256	\N	\N
1804	MEMBRECOM	\N	1980-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1257	\N	\N
1986	MEMBRECOM	\N	1974-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1439	\N	\N
1987	MEMBRECOM	1962-10-05 00:00:00	1968-09-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1440	\N	\N
1988	MEMBRECOM	\N	1968-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1441	\N	\N
3057	MEMBRECOM	1971-10-02 00:00:00	1971-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2233	\N	\N
3060	MEMBRECOM	1968-10-08 00:00:00	1974-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1638	\N	\N
3061	MEMBRECOM	1974-10-04 00:00:00	1977-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1639	\N	\N
3062	MEMBRECOM	1960-10-06 00:00:00	1974-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1221	\N	\N
3065	MEMBRECOM	1968-10-08 00:00:00	1970-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1907	\N	\N
3064	MEMBRECOM	1968-10-08 00:00:00	1969-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1281	\N	\N
3066	MEMBRECOM	1971-10-06 00:00:00	1974-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1448	\N	\N
3067	MEMBRECOM	1975-10-31 00:00:00	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1448	\N	\N
3072	MEMBRECOM	1968-10-08 00:00:00	1974-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1322	\N	\N
3069	MEMBRECOM	1997-09-21 00:00:00	1997-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2234	\N	\N
3070	MEMBRECOM	1962-10-06 00:00:00	1963-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1292	\N	\N
3073	MEMBRECOM	1959-01-21 00:00:00	1959-05-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2235	\N	\N
3079	MEMBRECOM	1966-10-05 00:00:00	1968-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2238	\N	\N
3080	MEMBRECOM	1974-10-29 00:00:00	1992-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2239	\N	\N
3081	MEMBRECOM	1980-10-07 00:00:00	1986-04-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2039	\N	\N
3082	MEMBRECOM	1988-06-28 00:00:00	1988-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2240	\N	\N
3085	MEMBRECOM	2004-05-01 00:00:00	2004-05-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2242	\N	\N
3084	MEMBRECOM	1988-10-12 00:00:00	1993-04-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2241	\N	\N
3086	MEMBRECOM	2004-05-01 00:00:00	2004-05-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2243	\N	\N
3087	MEMBRECOM	2004-05-01 00:00:00	2004-05-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2244	\N	\N
3088	SECRETCOM	1960-10-06 00:00:00	1964-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1900	\N	\N
3089	MEMBRECOM	1993-06-20 00:00:00	1993-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2245	\N	\N
3090	MEMBRECOM	1993-10-01 00:00:00	1994-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2246	\N	\N
3091	MEMBRECOM	1959-10-08 00:00:00	1974-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1155	\N	\N
3093	MEMBRECOM	1974-10-04 00:00:00	1977-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1915	\N	\N
2233	MEMBRECOM	1977-10-06 00:00:00	1980-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1663	\N	\N
1825	MEMBRECOM	1966-10-05 00:00:00	1971-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1278	\N	\N
3095	MEMBRECOM	1977-10-06 00:00:00	1980-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2057	\N	\N
3096	MEMBRECOM	1965-10-06 00:00:00	1966-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1888	\N	\N
3097	PDTCOM	2004-05-05 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	227	\N	\N
3098	VICPDTCOM	1974-10-04 00:00:00	1976-01-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2024	\N	\N
3099	MEMBRECOM	1977-10-06 00:00:00	1989-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2249	\N	\N
3100	MEMBRECOM	2004-05-06 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2250	\N	\N
3101	MEMBRECOM	2004-05-06 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2251	\N	\N
3102	MEMBRECOM	2004-05-06 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2252	\N	\N
3103	MEMBRECOM	1977-10-06 00:00:00	1980-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1048	\N	\N
3104	MEMBRECOM	1965-10-06 00:00:00	1977-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2253	\N	\N
3105	VICPDTCOM	1977-10-06 00:00:00	1980-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2253	\N	\N
3107	RAPCOM	2004-04-13 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2255	\N	2014-09-28 17:40:23
3108	RAPCOM	2004-04-13 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	2256	\N	\N
3109	MEMBRECOM	2004-04-13 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2257	\N	2017-09-24 18:16:52
3110	MEMBRECOM	2004-04-13 00:00:00	2010-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2258	\N	\N
3111	MEMBRECOM	2004-04-13 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2259	\N	2017-09-24 17:09:24
3112	MEMBRECOM	2004-04-13 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2260	\N	\N
3113	MEMBRECOM	2004-04-13 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2261	\N	\N
3114	MEMBRECOM	2004-04-13 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2262	\N	\N
3115	MEMBRECOM	2004-04-13 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2263	\N	\N
3116	MEMBRECOM	2004-04-13 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2264	\N	2017-09-24 17:48:21
3117	MEMBRECOM	2004-04-13 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2265	\N	\N
3118	MEMBRECOM	2004-04-13 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2266	\N	\N
3119	MEMBRECOM	2004-04-13 00:00:00	2006-06-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2267	\N	\N
3121	RAPCOM	2004-04-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2269	\N	2014-09-28 18:00:58
3122	MEMBRECOM	2004-04-15 00:00:00	2015-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2270	\N	2015-10-12 09:39:30
3123	MEMBRECOM	2004-04-15 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2271	\N	\N
3124	MEMBRECOM	2004-04-15 00:00:00	2011-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2272	\N	\N
3126	MEMBRECOM	2004-04-15 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2274	\N	\N
3127	MEMBRECOM	2004-04-15 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2275	\N	\N
3128	MEMBRECOM	2004-04-15 00:00:00	2014-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2276	\N	2014-09-29 13:41:53
3129	MEMBRECOM	2004-04-15 00:00:00	2008-09-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2277	\N	\N
3131	MEMBRECOM	2004-04-15 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2279	\N	\N
3133	MEMBRECOM	2004-04-15 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2281	\N	2017-09-24 13:29:42
3134	VICPDTCOM	2004-05-19 00:00:00	2004-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	211	\N	\N
3135	PDTCOM	2004-05-12 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2282	\N	2014-09-28 18:58:21
3136	RAPCOM	2004-05-12 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2283	\N	2014-09-28 17:40:23
3137	RAPCOM	2004-05-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	2284	\N	\N
3138	MEMBRECOM	2004-05-12 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2285	\N	\N
3140	MEMBRECOM	2004-05-12 00:00:00	2006-06-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2287	\N	\N
3141	MEMBRECOM	2004-05-12 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2288	\N	2017-09-24 17:06:55
3142	MEMBRECOM	2004-05-12 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2289	\N	\N
3143	MEMBRECOM	2004-05-12 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2290	\N	\N
3144	MEMBRECOM	2004-05-12 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2291	\N	2017-09-24 17:48:21
3145	MEMBRECOM	2004-05-12 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2292	\N	\N
3147	MEMBRECOM	2004-05-12 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2294	\N	\N
3148	MEMBRECOM	2004-05-12 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2295	\N	\N
3150	RAPCOM	2004-05-26 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2297	\N	\N
3151	MEMBRECOM	2004-05-26 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2298	\N	\N
3152	MEMBRECOM	2004-05-26 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2299	\N	\N
3153	MEMBRECOM	2004-05-26 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2300	\N	\N
3155	MEMBRECOM	2004-05-26 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2302	\N	2014-09-28 17:07:41
3156	MEMBRECOM	2004-05-26 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2303	\N	2017-09-24 13:44:49
3157	MEMBRECOM	2004-05-26 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2304	\N	\N
3158	MEMBRECOM	2004-05-26 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2305	\N	\N
3159	MEMBRECOM	2004-05-26 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2306	\N	\N
3160	MEMBRECOM	2004-05-26 00:00:00	2007-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2307	\N	\N
3161	MEMBRECOM	2004-05-26 00:00:00	2007-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2308	\N	\N
3164	RAPCOM	2004-06-09 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2311	\N	\N
3165	MEMBRECOM	2004-06-09 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2312	\N	\N
3166	MEMBRECOM	2004-06-09 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2313	\N	\N
3167	MEMBRECOM	2004-06-09 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2314	\N	\N
3168	MEMBRECOM	2004-06-09 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2315	\N	\N
3169	MEMBRECOM	2004-06-09 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2316	\N	2014-09-28 17:07:41
3171	MEMBRECOM	2004-06-09 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2318	\N	2014-09-28 13:19:48
2118	MEMBRECOM	\N	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1552	\N	\N
2119	MEMBRECOM	\N	1988-02-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1775	\N	\N
2120	MEMBRECOM	\N	1986-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1553	\N	\N
2121	SECRETCOM	1968-10-08 00:00:00	1974-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1554	\N	\N
2122	MEMBRECOM	\N	1983-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1555	\N	\N
2123	MEMBRECOM	\N	1997-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1556	\N	\N
2124	VICPDTCOM	1977-10-06 00:00:00	1989-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1557	\N	\N
2125	MEMBRECOM	\N	1983-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1558	\N	\N
2126	MEMBRECOM	\N	1983-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1559	\N	\N
2127	MEMBRECOM	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1560	\N	\N
2128	MEMBRECOM	1977-10-06 00:00:00	1980-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1561	\N	\N
2130	MEMBRECOM	\N	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1563	\N	\N
2131	SECRETCOM	1979-06-20 00:00:00	1984-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1564	\N	\N
2132	VICPDTCOM	1986-10-06 00:00:00	1988-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1565	\N	\N
2133	MEMBRECOM	\N	1986-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1566	\N	\N
2135	MEMBRECOM	\N	1983-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1568	\N	\N
2136	MEMBRECOM	\N	1988-07-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1569	\N	\N
2137	SECRETCOM	1975-11-19 00:00:00	1977-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1570	\N	\N
2138	VICPDTCOM	1986-10-06 00:00:00	1989-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1571	\N	\N
2140	MEMBRECOM	\N	1986-07-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1573	\N	\N
2141	MEMBRECOM	\N	1983-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1574	\N	\N
2142	MEMBRECOM	\N	1989-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1575	\N	\N
2144	MEMBRECOM	\N	1988-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1577	\N	\N
2145	MEMBRECOM	\N	1986-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1578	\N	\N
2146	MEMBRECOM	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1579	\N	\N
2147	MEMBRECOM	\N	1995-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1580	\N	\N
2149	MEMBRECOM	\N	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1582	\N	\N
2150	MEMBRECOM	\N	1989-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1583	\N	\N
2151	MEMBRECOM	\N	1997-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1584	\N	\N
2152	MEMBRECOM	\N	1995-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1585	\N	\N
2154	MEMBRECOM	\N	1986-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1587	\N	\N
2155	SECRETCOM	1986-10-06 00:00:00	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1588	\N	\N
2156	MEMBRECOM	\N	1986-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1589	\N	\N
2157	MEMBRECOM	1980-10-07 00:00:00	1982-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1590	\N	\N
2159	MEMBRECOM	\N	1983-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1592	\N	\N
2160	MEMBRECOM	1959-05-12 00:00:00	1980-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1593	\N	\N
2161	MEMBRECOM	\N	1986-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1594	\N	\N
2163	MEMBRECOM	\N	1988-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1596	\N	\N
2164	MEMBRECOM	\N	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1597	\N	\N
2167	MEMBRECOM	\N	1992-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1600	\N	\N
2168	MEMBRECOM	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1601	\N	\N
2169	MEMBRECOM	\N	1988-07-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1602	\N	\N
2170	VICPDTCOM	1971-10-06 00:00:00	1974-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1603	\N	\N
2171	MEMBRECOM	\N	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1604	\N	\N
2172	SECRETCOM	1989-10-05 00:00:00	1992-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1605	\N	\N
2173	SECRETCOM	1981-07-16 00:00:00	1983-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1606	\N	\N
2174	MEMBRECOM	\N	1997-01-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1607	\N	\N
2175	MEMBRECOM	\N	1989-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1608	\N	\N
2176	MEMBRECOM	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1609	\N	\N
2177	MEMBRECOM	\N	1986-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1610	\N	\N
2178	MEMBRECOM	\N	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1611	\N	\N
2179	MEMBRECOM	\N	1995-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1612	\N	\N
2180	MEMBRECOM	\N	1993-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1613	\N	\N
2181	MEMBRECOM	\N	1974-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1614	\N	\N
2182	MEMBRECOM	\N	1986-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1784	\N	\N
2183	MEMBRECOM	\N	1983-07-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1615	\N	\N
2184	MEMBRECOM	\N	1986-04-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1616	\N	\N
2185	SECRETCOM	1977-10-06 00:00:00	1983-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1617	\N	\N
2186	MEMBRECOM	\N	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1618	\N	\N
2187	MEMBRECOM	\N	1986-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1619	\N	\N
2188	MEMBRECOM	\N	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1620	\N	\N
2189	MEMBRECOM	\N	1991-11-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1621	\N	\N
2190	MEMBRECOM	\N	1989-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1622	\N	\N
2191	MEMBRECOM	\N	1989-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1623	\N	\N
2192	MEMBRECOM	\N	1996-07-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1624	\N	\N
2193	MEMBRECOM	\N	1998-02-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1625	\N	\N
2194	MEMBRECOM	1977-10-06 00:00:00	1983-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1626	\N	\N
2195	VICPDTCOM	1977-10-06 00:00:00	1980-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1627	\N	\N
10871	MEMBRECOM	2013-03-01 00:00:00	2013-03-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9157	\N	2013-03-12 09:30:08
2196	VICPDTCOM	1992-10-08 00:00:00	1994-07-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1628	\N	\N
2197	MEMBRECOM	\N	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1629	\N	\N
2198	MEMBRECOM	\N	1989-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1630	\N	\N
2199	MEMBRECOM	\N	1986-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1631	\N	\N
2200	MEMBRECOM	\N	1989-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1632	\N	\N
2202	MEMBRECOM	\N	1989-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1634	\N	\N
2203	MEMBRECOM	\N	1986-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1635	\N	\N
2205	MEMBRECOM	\N	1986-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1637	\N	\N
2207	VICPDTCOM	1977-10-06 00:00:00	1986-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1639	\N	\N
2208	MEMBRECOM	\N	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1640	\N	\N
2209	SECRETCOM	1974-10-04 00:00:00	1983-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1641	\N	\N
2210	VICPDTCOM	1974-10-04 00:00:00	1980-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1642	\N	\N
2211	MEMBRECOM	\N	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1643	\N	\N
2212	MEMBRECOM	\N	1997-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1644	\N	\N
2213	SECRETCOM	1980-10-07 00:00:00	1986-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1645	\N	\N
2214	MEMBRECOM	\N	1989-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1776	\N	\N
2215	MEMBRECOM	\N	1990-08-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1646	\N	\N
2216	MEMBRECOM	\N	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1647	\N	\N
2217	MEMBRECOM	\N	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1648	\N	\N
2218	MEMBRECOM	\N	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1649	\N	\N
2219	MEMBRECOM	1983-10-07 00:00:00	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1650	\N	\N
2220	MEMBRECOM	\N	1983-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1651	\N	\N
2221	MEMBRECOM	\N	1989-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1652	\N	\N
2222	MEMBRECOM	\N	1987-12-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1777	\N	\N
2223	SECRETCOM	1977-10-06 00:00:00	1986-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1653	\N	\N
2224	MEMBRECOM	\N	1993-11-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1654	\N	\N
2226	VICPDTCOM	1971-10-06 00:00:00	1974-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1656	\N	\N
2227	MEMBRECOM	\N	1986-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1657	\N	\N
2228	MEMBRECOM	\N	1989-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1658	\N	\N
2229	MEMBRECOM	\N	1997-11-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1659	\N	\N
2231	MEMBRECOM	\N	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1661	\N	\N
2232	SECRETCOM	1959-05-12 00:00:00	1966-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1662	\N	\N
2234	MEMBRECOM	\N	1988-07-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1778	\N	\N
2236	MEMBRECOM	1992-10-07 00:00:00	1995-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1665	\N	\N
2237	MEMBRECOM	\N	1986-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1666	\N	\N
2238	VICPDTCOM	1977-10-06 00:00:00	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1667	\N	\N
2239	MEMBRECOM	\N	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1668	\N	\N
2241	MEMBRECOM	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1670	\N	\N
2243	MEMBRECOM	\N	1995-07-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1671	\N	\N
2245	MEMBRECOM	\N	1983-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1673	\N	\N
2246	MEMBRECOM	\N	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1674	\N	\N
2247	MEMBRECOM	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1675	\N	\N
2248	MEMBRECOM	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1676	\N	\N
2250	VICPDTCOM	1980-10-07 00:00:00	1986-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1678	\N	\N
2251	MEMBRECOM	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1679	\N	\N
2252	MEMBRECOM	\N	1986-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1680	\N	\N
2253	MEMBRECOM	\N	1994-02-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1681	\N	\N
2255	SECRETCOM	1971-10-06 00:00:00	1985-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1683	\N	\N
2256	MEMBRECOM	\N	1998-04-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1684	\N	\N
2257	MEMBRECOM	\N	1986-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1685	\N	\N
2258	MEMBRECOM	\N	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1686	\N	\N
2260	MEMBRECOM	\N	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1687	\N	\N
2261	MEMBRECOM	\N	1986-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1688	\N	\N
2262	MEMBRECOM	1977-10-06 00:00:00	1980-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1689	\N	\N
2263	MEMBRECOM	\N	1983-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1690	\N	\N
2264	MEMBRECOM	\N	1983-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1691	\N	\N
2265	MEMBRECOM	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1780	\N	\N
2266	MEMBRECOM	\N	1995-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1692	\N	\N
2267	MEMBRECOM	\N	1989-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1693	\N	\N
2268	MEMBRECOM	\N	1983-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1694	\N	\N
2269	VICPDTCOM	1989-10-05 00:00:00	1990-06-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1695	\N	\N
2270	MEMBRECOM	\N	1986-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1696	\N	\N
2271	MEMBRECOM	\N	1998-02-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1697	\N	\N
2272	MEMBRECOM	1992-10-07 00:00:00	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1698	\N	\N
2273	MEMBRECOM	\N	1989-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1699	\N	\N
2274	MEMBRECOM	\N	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1700	\N	\N
2275	MEMBRECOM	\N	1992-03-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1701	\N	\N
2276	MEMBRECOM	\N	1989-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1702	\N	\N
2277	MEMBRECOM	1971-10-06 00:00:00	1974-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1703	\N	\N
2278	VICPDTCOM	1983-10-06 00:00:00	1992-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1704	\N	\N
2279	MEMBRECOM	\N	1997-09-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1705	\N	\N
2280	MEMBRECOM	\N	1983-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1706	\N	\N
2281	MEMBRECOM	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1707	\N	\N
2282	SECRETCOM	1977-10-06 00:00:00	1980-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1708	\N	\N
2283	MEMBRECOM	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1709	\N	\N
2284	MEMBRECOM	\N	1989-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1710	\N	\N
2286	VICPDTCOM	1976-01-14 00:00:00	1983-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1712	\N	\N
2287	SECRETCOM	1996-02-07 00:00:00	1997-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1713	\N	\N
2288	MEMBRECOM	\N	1989-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1714	\N	\N
2289	MEMBRECOM	\N	1997-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1715	\N	\N
2290	MEMBRECOM	\N	1989-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1716	\N	\N
2291	VICPDTCOM	1980-10-07 00:00:00	1984-12-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1717	\N	\N
2292	MEMBRECOM	\N	1997-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1718	\N	\N
2854	MEMBRECOM	1983-10-07 00:00:00	1989-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2115	\N	\N
2855	MEMBRECOM	1983-10-07 00:00:00	1989-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1496	\N	\N
2856	MEMBRECOM	1980-10-07 00:00:00	1986-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2116	\N	\N
2857	VICPDTCOM	1989-10-05 00:00:00	1992-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1472	\N	\N
2858	MEMBRECOM	1983-10-07 00:00:00	1989-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	152	\N	\N
152	VICPDTCOM	1989-10-05 00:00:00	1998-10-07 00:00:00	3	ANCIEN	\N	\N	\N	\N	152	\N	\N
2859	MEMBRECOM	1986-10-09 00:00:00	1989-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	119	\N	\N
2860	SECRETCOM	1989-10-05 00:00:00	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1645	\N	\N
2861	MEMBRECOM	1971-10-06 00:00:00	1981-07-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2117	\N	\N
2862	MEMBRECOM	1981-07-08 00:00:00	1989-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1695	\N	\N
2863	MEMBRECOM	1986-10-06 00:00:00	1989-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2118	\N	\N
2864	RAPGENCOM	1989-10-05 00:00:00	1992-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2118	\N	\N
2865	MEMBRECOM	1962-10-05 00:00:00	1972-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2119	\N	\N
2866	MEMBRECOM	1965-10-06 00:00:00	1979-10-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2120	\N	\N
2867	VICPDTCOM	1989-10-05 00:00:00	1992-01-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1549	\N	\N
2869	MEMBRECOM	1968-10-02 00:00:00	1992-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2121	\N	\N
2871	MEMBRECOM	1981-10-08 00:00:00	1992-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	55	\N	\N
2872	MEMBRECOM	1992-10-07 00:00:00	1995-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2122	\N	\N
2873	MEMBRECOM	1992-10-08 00:00:00	1995-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2030	\N	\N
2874	MEMBRECOM	1971-10-06 00:00:00	1974-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	43	\N	\N
2875	MEMBRECOM	1986-10-06 00:00:00	1990-10-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2123	\N	\N
2876	MEMBRECOM	1990-10-30 00:00:00	1992-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1486	\N	\N
2877	MEMBRECOM	1992-10-08 00:00:00	1993-08-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1472	\N	\N
2884	SECRETCOM	1992-10-08 00:00:00	1996-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	127	\N	\N
2879	MEMBRECOM	1977-10-06 00:00:00	1978-10-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2125	\N	\N
2880	MEMBRECOM	1978-10-18 00:00:00	1983-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2126	\N	\N
2881	MEMBRECOM	1983-10-06 00:00:00	1986-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2127	\N	\N
2882	MEMBRECOM	1986-10-06 00:00:00	1992-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2128	\N	\N
2883	VICPDTCOM	1992-10-08 00:00:00	1995-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2128	\N	\N
2885	MEMBRECOM	1992-10-08 00:00:00	1995-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	220	\N	\N
2886	SECRETCOM	1983-10-06 00:00:00	1992-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18	\N	\N
2887	MEMBRECOM	1982-01-21 00:00:00	1986-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2129	\N	\N
2888	MEMBRECOM	1986-10-06 00:00:00	1992-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1628	\N	\N
2889	MEMBRECOM	1977-10-06 00:00:00	1983-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2130	\N	\N
2891	MEMBRECOM	1983-10-06 00:00:00	1990-01-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2131	\N	\N
2892	MEMBRECOM	1983-10-06 00:00:00	1992-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1510	\N	\N
2893	PDTCOM	1986-10-06 00:00:00	1993-02-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2053	\N	\N
2166	SECRETCOM	1993-04-14 00:00:00	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1599	\N	\N
2894	MEMBRECOM	1986-10-06 00:00:00	1993-04-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1599	\N	\N
2895	MEMBRECOM	1959-05-12 00:00:00	1968-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1786	\N	\N
2900	MEMBRECOM	1989-10-04 00:00:00	1995-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	104	\N	\N
2897	MEMBRECOM	1983-10-06 00:00:00	1992-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	107	\N	\N
2898	MEMBRECOM	1992-10-08 00:00:00	1995-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2132	\N	\N
2899	VICPDTCOM	1995-10-05 00:00:00	1996-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2133	\N	\N
2901	MEMBRECOM	1980-10-07 00:00:00	1995-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8	\N	\N
2902	SECRETCOM	1995-10-05 00:00:00	1996-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2030	\N	\N
2903	MEMBRECOM	1986-10-06 00:00:00	1988-06-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2134	\N	\N
2904	MEMBRECOM	1988-06-29 00:00:00	1989-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2135	\N	\N
2905	MEMBRECOM	1986-10-06 00:00:00	1989-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1645	\N	\N
3789	MEMBRECOM	2005-05-11 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2878	\N	2014-09-28 17:31:42
3790	MEMBRECOM	2005-05-11 00:00:00	2007-01-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2879	\N	\N
3791	MEMBRECOM	2005-05-11 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2880	\N	\N
3792	MEMBRECOM	2005-05-11 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2881	\N	2014-09-28 17:31:42
3793	MEMBRECOM	2005-05-11 00:00:00	2012-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2882	\N	\N
3795	MEMBRECOM	2005-05-11 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2884	\N	\N
3796	MEMBRECOM	2005-05-11 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2885	\N	\N
3797	MEMBRECOM	2005-06-19 00:00:00	2005-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2886	\N	\N
3798	MEMBRECOM	2005-06-29 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2887	\N	\N
3799	PDTCOM	2005-06-29 00:00:00	2011-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2888	\N	\N
3800	RAPCOM	2005-06-29 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2889	\N	\N
3801	MEMBRECOM	2005-06-29 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2890	\N	2017-09-24 18:17:56
3802	MEMBRECOM	2005-06-29 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	2891	\N	\N
3803	MEMBRECOM	2005-06-29 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2892	\N	\N
3804	MEMBRECOM	2005-06-29 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2893	\N	\N
3805	MEMBRECOM	2005-06-29 00:00:00	2007-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2894	\N	\N
3806	MEMBRECOM	2005-06-29 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2895	\N	\N
3807	MEMBRECOM	2005-06-29 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2896	\N	2014-09-28 17:07:41
3808	MEMBRECOM	2005-06-29 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2897	\N	2017-09-24 16:43:43
3810	MEMBRECOM	2005-06-29 00:00:00	2007-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2899	\N	\N
3811	MEMBRECOM	2005-06-29 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2900	\N	\N
3812	MEMBRECOM	2005-06-29 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2901	\N	\N
3813	RAPCOM	2005-06-30 00:00:00	2015-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2902	\N	2015-10-12 09:39:31
3814	MEMBRECOM	2005-06-30 00:00:00	2015-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2903	\N	2015-01-08 17:14:29
3815	MEMBRECOM	2005-06-30 00:00:00	2010-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2904	\N	\N
3817	MEMBRECOM	2005-06-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	2906	\N	\N
3818	MEMBRECOM	2005-06-30 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2907	\N	\N
3819	MEMBRECOM	2005-06-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	2908	\N	\N
3820	MEMBRECOM	2005-06-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	2909	\N	\N
3822	MEMBRECOM	2005-06-30 00:00:00	2007-11-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2911	\N	\N
3823	MEMBRECOM	2005-06-30 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2912	\N	\N
3825	MEMBRECOM	2005-06-30 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2914	\N	\N
3826	MEMBRECOM	2005-06-30 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2915	\N	\N
3827	VICPDTCOM	2005-07-05 00:00:00	2014-07-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2916	\N	2014-07-01 09:25:11
3828	RAPCOM	2005-07-05 00:00:00	2015-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2917	\N	2015-01-08 17:14:29
3830	MEMBRECOM	2005-07-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	2919	\N	\N
3831	MEMBRECOM	2005-07-05 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2920	\N	\N
3833	MEMBRECOM	2005-07-05 00:00:00	2018-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2922	\N	2018-05-31 10:52:17
3835	MEMBRECOM	2005-07-05 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2924	\N	\N
3836	MEMBRECOM	2005-07-05 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2925	\N	2014-09-28 18:19:47
3837	MEMBRECOM	2005-07-05 00:00:00	2012-05-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2926	\N	\N
2583	MEMBRECOM	2003-10-08 00:00:00	2004-02-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1973	\N	\N
2584	MEMBRECOM	2003-10-08 00:00:00	2004-02-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1974	\N	\N
2586	MEMBRECOM	2003-10-08 00:00:00	2004-02-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1976	\N	\N
2587	MEMBRECOM	2003-10-08 00:00:00	2004-02-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1977	\N	\N
2589	MEMBRECOM	2003-10-08 00:00:00	2004-02-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1979	\N	\N
2590	MEMBRECOM	2003-10-08 00:00:00	2004-02-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1980	\N	\N
2592	MEMBRECOM	2003-10-08 00:00:00	2004-02-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1982	\N	\N
2593	MEMBRECOM	2003-10-08 00:00:00	2004-02-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1983	\N	\N
2594	MEMBRECOM	2003-10-08 00:00:00	2004-02-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1984	\N	\N
2595	MEMBRECOM	2003-10-08 00:00:00	2004-02-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1985	\N	\N
2597	MEMBRECOM	2003-10-08 00:00:00	2004-02-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1987	\N	\N
2598	MEMBRECOM	2003-10-08 00:00:00	2004-02-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1988	\N	\N
2600	MEMBRECOM	2003-10-08 00:00:00	2004-02-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1990	\N	\N
2601	MEMBRECOM	2003-10-08 00:00:00	2004-02-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1991	\N	\N
2602	MEMBRECOM	2003-10-08 00:00:00	2004-02-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1992	\N	\N
2603	MEMBRECOM	2003-10-08 00:00:00	2004-02-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1993	\N	\N
2604	MEMBRECOM	2003-10-08 00:00:00	2004-02-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1994	\N	\N
2606	MEMBRECOM	2003-10-08 00:00:00	2004-02-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1996	\N	\N
2607	PDTCOM	2003-10-16 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1998	\N	2014-09-28 16:42:05
2608	RAPCOM	2003-10-16 00:00:00	2015-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1999	\N	2015-06-12 16:01:25
2609	MEMBRECOM	2003-10-16 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2000	\N	2014-09-28 18:00:58
2610	MEMBRECOM	2003-10-16 00:00:00	2015-04-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2001	\N	2015-04-21 17:14:30
2611	MEMBRECOM	2003-10-16 00:00:00	2011-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2002	\N	\N
2612	MEMBRECOM	2003-10-16 00:00:00	2008-09-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2003	\N	\N
2613	MEMBRECOM	2003-10-16 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2004	\N	\N
2614	MEMBRECOM	2003-10-16 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2005	\N	2017-09-24 18:20:10
2082	MEMBRECOM	1980-10-07 00:00:00	1983-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1518	\N	\N
2083	MEMBRECOM	\N	1987-02-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1519	\N	\N
2084	SECRETCOM	1980-10-07 00:00:00	1986-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1520	\N	\N
2085	MEMBRECOM	\N	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1521	\N	\N
2087	MEMBRECOM	\N	1989-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1523	\N	\N
2088	MEMBRECOM	\N	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1524	\N	\N
2089	MEMBRECOM	\N	1989-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1525	\N	\N
2090	MEMBRECOM	\N	1994-09-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1526	\N	\N
2091	MEMBRECOM	\N	1995-11-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1527	\N	\N
2092	MEMBRECOM	\N	1986-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1528	\N	\N
2093	MEMBRECOM	\N	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1529	\N	\N
2094	MEMBRECOM	\N	1996-01-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1773	\N	\N
2095	MEMBRECOM	\N	1987-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1774	\N	\N
2096	MEMBRECOM	1986-10-06 00:00:00	1992-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1530	\N	\N
2097	VICPDTCOM	1965-10-06 00:00:00	1977-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1531	\N	\N
2098	MEMBRECOM	\N	1983-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1532	\N	\N
2099	SECRETCOM	1982-06-23 00:00:00	1983-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1533	\N	\N
2100	MEMBRECOM	1992-10-07 00:00:00	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1534	\N	\N
2101	VICPDTCOM	1980-10-07 00:00:00	1983-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1535	\N	\N
2102	VICPDTCOM	1986-10-06 00:00:00	1989-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1536	\N	\N
2104	MEMBRECOM	1983-10-07 00:00:00	1983-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1538	\N	\N
2105	MEMBRECOM	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1539	\N	\N
2106	SECRETCOM	1977-10-06 00:00:00	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1540	\N	\N
2107	MEMBRECOM	\N	1983-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1541	\N	\N
2108	MEMBRECOM	\N	1996-01-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1542	\N	\N
2109	MEMBRECOM	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1543	\N	\N
2110	MEMBRECOM	\N	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1544	\N	\N
2111	MEMBRECOM	\N	1998-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1545	\N	\N
2112	MEMBRECOM	\N	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1546	\N	\N
2113	MEMBRECOM	\N	1986-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1547	\N	\N
2114	VICPDTCOM	1967-10-11 00:00:00	1968-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1548	\N	\N
2115	MEMBRECOM	1979-10-23 00:00:00	1989-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1549	\N	\N
2116	MEMBRECOM	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1550	\N	\N
2117	MEMBRECOM	\N	1992-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1551	\N	\N
2658	MEMBRECOM	1970-10-07 00:00:00	1974-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2041	\N	\N
2659	MEMBRECOM	1974-10-04 00:00:00	1977-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2042	\N	\N
2660	SECRETCOM	1977-10-06 00:00:00	1980-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2043	\N	\N
2662	SECRETCOM	1977-10-06 00:00:00	1978-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2044	\N	\N
2663	PDTCOM	1977-10-06 00:00:00	1983-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2045	\N	\N
2664	SECRETCOM	1977-10-06 00:00:00	1986-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1904	\N	\N
2665	MEMBRECOM	1968-10-08 00:00:00	1969-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2046	\N	\N
2666	MEMBRECOM	1969-10-08 00:00:00	1973-04-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2047	\N	\N
2667	MEMBRECOM	1959-10-06 00:00:00	1962-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2048	\N	\N
2668	MEMBRECOM	1964-10-03 00:00:00	1965-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2049	\N	\N
2670	VICPDTCOM	1977-10-06 00:00:00	1977-12-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2051	\N	\N
2204	SECRETCOM	1977-10-06 00:00:00	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1636	\N	\N
2303	SECRETCOM	1977-10-06 00:00:00	1989-01-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1729	\N	\N
2671	MEMBRECOM	1975-05-21 00:00:00	1977-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2052	\N	\N
2672	SECRETCOM	1978-10-05 00:00:00	1979-06-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1096	\N	\N
2673	PDTCOM	1978-10-19 00:00:00	1986-04-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2053	\N	\N
2674	MEMBRECOM	1973-05-17 00:00:00	1974-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2054	\N	\N
2675	VICPDTCOM	1974-10-04 00:00:00	1980-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2055	\N	\N
2676	MEMBRECOM	1980-10-07 00:00:00	1983-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2056	\N	\N
2677	VICPDTCOM	1980-10-07 00:00:00	1983-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1911	\N	\N
2678	SECRETCOM	1980-10-07 00:00:00	1981-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2057	\N	\N
2681	MEMBRECOM	1980-10-05 00:00:00	1982-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2055	\N	\N
2682	MEMBRECOM	1959-05-06 00:00:00	1959-05-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1353	\N	\N
2683	MEMBRECOM	1959-10-08 00:00:00	1974-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1353	\N	\N
2686	MEMBRECOM	1959-05-12 00:00:00	1974-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1642	\N	\N
2687	MEMBRECOM	1980-10-07 00:00:00	1983-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1642	\N	\N
2688	MEMBRECOM	1967-10-11 00:00:00	1971-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1762	\N	\N
2700	MEMBRECOM	1959-05-06 00:00:00	1959-05-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1093	\N	\N
2690	MEMBRECOM	1972-05-09 00:00:00	1977-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1708	\N	\N
2691	VICPDTCOM	1980-10-07 00:00:00	1983-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1708	\N	\N
2692	MEMBRECOM	1971-10-06 00:00:00	1980-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1717	\N	\N
2693	VICPDTCOM	1980-10-07 00:00:00	1983-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	130	\N	\N
2694	MEMBRECOM	1971-10-06 00:00:00	1974-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1234	\N	\N
2696	MEMBRECOM	1977-10-06 00:00:00	1980-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1645	\N	\N
2697	MEMBRECOM	1979-04-02 00:00:00	1979-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2058	\N	\N
2698	SECRETCOM	1980-10-07 00:00:00	1983-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1489	\N	\N
2699	SECRETCOM	1980-10-07 00:00:00	1992-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1762	\N	\N
2701	MEMBRECOM	1965-10-05 00:00:00	1971-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1172	\N	\N
2702	SECRETCOM	1980-10-07 00:00:00	1981-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1172	\N	\N
2705	MEMBRECOM	1959-05-12 00:00:00	1960-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2062	\N	\N
2706	MEMBRECOM	1960-10-04 00:00:00	1973-06-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2063	\N	\N
2707	VICPDTCOM	1980-10-07 00:00:00	1983-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1593	\N	\N
2708	MEMBRECOM	1968-10-08 00:00:00	1969-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1522	\N	\N
2709	MEMBRECOM	1969-10-08 00:00:00	1980-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2064	\N	\N
2710	VICPDTCOM	1980-10-07 00:00:00	1983-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2064	\N	\N
2711	MEMBRECOM	1974-10-04 00:00:00	1977-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	310	\N	\N
2712	VICPDTCOM	1980-10-07 00:00:00	1982-06-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	310	\N	\N
2713	MEMBRECOM	1973-10-23 00:00:00	1981-07-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1606	\N	\N
2714	SECRETCOM	1982-09-29 00:00:00	1986-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1590	\N	\N
2715	MEMBRECOM	1974-10-14 00:00:00	1977-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2065	\N	\N
2716	MEMBRECOM	1977-10-06 00:00:00	1982-06-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1533	\N	\N
2717	SECRETCOM	1983-10-06 00:00:00	1992-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1911	\N	\N
2718	VICPDTCOM	1983-10-06 00:00:00	1992-02-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1740	\N	\N
2719	VICPDTCOM	1983-10-06 00:00:00	1985-03-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1606	\N	\N
2720	SECRETCOM	1983-10-06 00:00:00	1984-03-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1752	\N	\N
2721	MEMBRECOM	1959-05-06 00:00:00	1959-05-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1752	\N	\N
2722	MEMBRECOM	1965-10-06 00:00:00	1983-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1752	\N	\N
2723	MEMBRECOM	1971-10-06 00:00:00	1974-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2020	\N	\N
2724	MEMBRECOM	1974-10-04 00:00:00	1980-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1535	\N	\N
2726	MEMBRECOM	1967-03-09 00:00:00	1977-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1494	\N	\N
2103	MEMBRECOM	1968-10-08 00:00:00	1971-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1537	\N	\N
2727	MEMBRECOM	1971-10-06 00:00:00	1974-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2066	\N	\N
2728	MEMBRECOM	1974-10-04 00:00:00	1983-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2067	\N	\N
2729	VICPDTCOM	1983-10-06 00:00:00	1986-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2067	\N	\N
2730	MEMBRECOM	1974-10-06 00:00:00	1983-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1704	\N	\N
2731	SECRETCOM	1983-10-06 00:00:00	1986-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	102	\N	\N
2732	MEMBRECOM	1974-01-01 00:00:00	1977-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1772	\N	\N
2733	MEMBRECOM	1959-05-06 00:00:00	1959-05-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1712	\N	\N
2734	MEMBRECOM	1971-10-06 00:00:00	1976-01-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1712	\N	\N
2735	MEMBRECOM	1980-10-07 00:00:00	1983-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	103	\N	\N
2736	MEMBRECOM	1980-10-07 00:00:00	1983-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1660	\N	\N
2737	MEMBRECOM	1971-10-06 00:00:00	1977-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2045	\N	\N
2738	MEMBRECOM	1983-10-06 00:00:00	1986-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1708	\N	\N
2739	VICPDTCOM	1983-10-06 00:00:00	1986-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2045	\N	\N
2740	MEMBRECOM	1983-10-06 00:00:00	1998-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	130	\N	\N
2742	VICPDTCOM	1983-10-07 00:00:00	1989-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1642	\N	\N
2743	MEMBRECOM	1979-05-29 00:00:00	1981-07-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1598	\N	\N
2744	MEMBRECOM	1981-07-29 00:00:00	1982-04-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2069	\N	\N
2745	MEMBRECOM	1982-04-02 00:00:00	1983-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2070	\N	\N
2746	SECRETCOM	1983-10-06 00:00:00	1986-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2070	\N	\N
2747	VICPDTCOM	1980-10-07 00:00:00	1983-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1561	\N	\N
2748	MEMBRECOM	1983-10-06 00:00:00	1986-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1561	\N	\N
2749	MEMBRECOM	1968-10-08 00:00:00	1971-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1567	\N	\N
2750	MEMBRECOM	1974-10-04 00:00:00	1975-10-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1567	\N	\N
2753	MEMBRECOM	1959-05-12 00:00:00	1973-04-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1711	\N	\N
2754	MEMBRECOM	1980-10-07 00:00:00	1988-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1711	\N	\N
2755	MEMBRECOM	1971-10-06 00:00:00	1974-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2071	\N	\N
2756	MEMBRECOM	1974-10-04 00:00:00	1980-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6	\N	\N
2757	SECRETCOM	1980-10-07 00:00:00	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1689	\N	\N
2758	MEMBRECOM	1974-10-04 00:00:00	1977-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1617	\N	\N
2759	VICPDTCOM	1983-10-06 00:00:00	1992-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1626	\N	\N
2760	MEMBRECOM	1959-05-12 00:00:00	1965-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2072	\N	\N
2761	MEMBRECOM	1965-10-06 00:00:00	1968-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2073	\N	\N
2762	MEMBRECOM	1977-10-06 00:00:00	1983-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1758	\N	\N
2763	MEMBRECOM	1959-05-12 00:00:00	1971-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1181	\N	\N
2764	MEMBRECOM	1983-10-06 00:00:00	1986-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1593	\N	\N
2765	MEMBRECOM	1959-05-12 00:00:00	1960-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1748	\N	\N
2766	MEMBRECOM	1960-10-06 00:00:00	1973-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2074	\N	\N
2767	MEMBRECOM	1973-10-11 00:00:00	1983-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2075	\N	\N
2768	VICPDTCOM	1983-10-06 00:00:00	1986-06-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2075	\N	\N
2769	MEMBRECOM	1982-06-15 00:00:00	1983-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	310	\N	\N
2770	VICPDTCOM	1983-10-06 00:00:00	1995-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	310	\N	\N
2771	SECRETCOM	1983-10-06 00:00:00	1986-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1538	\N	\N
2772	MEMBRECOM	1980-10-07 00:00:00	1983-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18	\N	\N
2774	MEMBRECOM	1974-10-04 00:00:00	1975-12-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2077	\N	\N
2775	MEMBRECOM	1975-12-05 00:00:00	1984-04-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1759	\N	\N
2776	SECRETCOM	1984-04-11 00:00:00	1992-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1759	\N	\N
2777	MEMBRECOM	1978-10-02 00:00:00	1984-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	26	\N	\N
2778	SECRETCOM	1984-10-04 00:00:00	1996-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	26	\N	\N
2779	MEMBRECOM	1965-10-06 00:00:00	1967-04-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2078	\N	\N
2780	MEMBRECOM	1983-10-06 00:00:00	1985-04-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2079	\N	\N
2781	VICPDTCOM	1985-04-03 00:00:00	1986-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2079	\N	\N
2782	MEMBRECOM	1980-10-07 00:00:00	1985-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2030	\N	\N
2783	SECRETCOM	1985-06-20 00:00:00	1986-04-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2030	\N	\N
2784	PDTCOM	2003-11-19 00:00:00	2011-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2080	\N	\N
2785	RAPCOM	2003-11-19 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2081	\N	\N
2786	MEMBRECOM	2003-11-19 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2082	\N	\N
2787	MEMBRECOM	2003-11-19 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2083	\N	\N
2788	MEMBRECOM	2003-11-19 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2084	\N	\N
2789	MEMBRECOM	2003-11-19 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2085	\N	\N
2790	MEMBRECOM	2003-11-19 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2086	\N	2014-09-28 17:07:41
2791	MEMBRECOM	2003-11-19 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2087	\N	2017-09-24 13:44:49
2792	MEMBRECOM	2003-11-19 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2088	\N	\N
2793	MEMBRECOM	2003-11-19 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2089	\N	2017-09-24 18:16:52
2794	MEMBRECOM	2003-11-19 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2090	\N	\N
2795	MEMBRECOM	2003-11-19 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2091	\N	\N
2797	MEMBRECOM	2003-11-19 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2093	\N	\N
2798	MEMBRECOM	1974-10-04 00:00:00	1977-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2094	\N	\N
2799	MEMBRECOM	1977-10-06 00:00:00	1983-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2095	\N	\N
2800	MEMBRECOM	1983-10-05 00:00:00	1986-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2096	\N	\N
2801	PDTCOM	1986-10-06 00:00:00	1995-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2097	\N	\N
2802	PDTCOM	1977-10-06 00:00:00	1986-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1571	\N	\N
2803	MEMBRECOM	1971-10-06 00:00:00	1977-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1571	\N	\N
2804	MEMBRECOM	1986-10-06 00:00:00	1989-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1520	\N	\N
2805	MEMBRECOM	1959-05-12 00:00:00	1966-02-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2098	\N	\N
2806	MEMBRECOM	1980-10-07 00:00:00	1986-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2099	\N	\N
2807	MEMBRECOM	1986-10-06 00:00:00	1988-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2067	\N	\N
2808	MEMBRECOM	1986-10-06 00:00:00	1992-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1639	\N	\N
2809	VICPDTCOM	1986-10-06 00:00:00	1988-11-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	102	\N	\N
2812	MEMBRECOM	1968-10-08 00:00:00	1977-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1627	\N	\N
2813	MEMBRECOM	1980-10-07 00:00:00	1986-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1627	\N	\N
2814	VICPDTCOM	1986-10-06 00:00:00	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1627	\N	\N
2819	MEMBRECOM	2000-04-27 00:00:00	1974-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2104	\N	\N
2820	MEMBRECOM	1969-06-26 00:00:00	1971-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1478	\N	\N
2821	MEMBRECOM	1977-10-06 00:00:00	1980-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1499	\N	\N
2822	VICPDTCOM	1986-10-06 00:00:00	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1499	\N	\N
2823	MEMBRECOM	1986-10-06 00:00:00	1996-09-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1590	\N	\N
2824	MEMBRECOM	1977-10-06 00:00:00	1986-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1588	\N	\N
2825	MEMBRECOM	1980-10-07 00:00:00	1986-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	38	\N	\N
2826	MEMBRECOM	1983-10-06 00:00:00	1986-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2105	\N	\N
2827	SECRETCOM	1986-10-06 00:00:00	1992-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2105	\N	\N
2828	MEMBRECOM	1965-10-06 00:00:00	1968-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1904	\N	\N
2829	MEMBRECOM	1971-10-06 00:00:00	1977-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1904	\N	\N
2831	MEMBRECOM	1981-10-16 00:00:00	1983-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2106	\N	\N
2832	MEMBRECOM	1983-10-07 00:00:00	1986-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2107	\N	\N
2833	VICPDTCOM	1986-10-06 00:00:00	1989-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2107	\N	\N
2834	MEMBRECOM	1980-10-07 00:00:00	1986-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1475	\N	\N
2065	VICPDTCOM	1986-10-06 00:00:00	1989-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1475	\N	\N
2835	SECRETCOM	1986-10-06 00:00:00	1989-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1708	\N	\N
2836	MEMBRECOM	1983-10-06 00:00:00	1985-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2108	\N	\N
2837	MEMBRECOM	1985-10-02 00:00:00	1986-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	112	\N	\N
2242	VICPDTHONCOM	1986-10-06 00:00:00	1993-03-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1786	\N	\N
2839	MEMBRECOM	1959-05-12 00:00:00	1972-11-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1476	\N	\N
2841	MEMBRECOM	1971-10-06 00:00:00	1972-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2109	\N	\N
2842	MEMBRECOM	1972-12-13 00:00:00	1986-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1536	\N	\N
2845	VICPDTCOM	1989-10-04 00:00:00	1995-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1520	\N	\N
2844	VICPDTCOM	1988-07-12 00:00:00	1989-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1711	\N	\N
2846	MEMBRECOM	1986-10-06 00:00:00	1989-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2111	\N	\N
2847	SECRETCOM	1989-10-05 00:00:00	1992-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2111	\N	\N
2848	MEMBRECOM	1983-10-07 00:00:00	1989-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	139	\N	\N
139	VICPDTCOM	1989-10-04 00:00:00	1998-10-06 00:00:00	2	ANCIEN	\N	\N	\N	\N	139	\N	\N
2849	MEMBRECOM	1979-10-02 00:00:00	1980-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2112	\N	\N
2850	MEMBRECOM	1980-10-07 00:00:00	1981-07-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2113	\N	\N
2851	MEMBRECOM	1981-07-08 00:00:00	1989-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2114	\N	\N
2852	SECRETCOM	1989-10-05 00:00:00	1990-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2114	\N	\N
2853	MEMBRECOM	1977-10-06 00:00:00	1989-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1605	\N	\N
3497	SECRETCOM	2004-10-07 00:00:00	2008-10-06 00:00:00	1	ANCIEN	\N	\N	\N	\N	498	\N	\N
3498	SECRETCOM	2004-10-07 00:00:00	2008-10-06 00:00:00	2	ANCIEN	\N	\N	\N	\N	717	\N	\N
3499	SECRETCOM	2004-10-07 00:00:00	2008-10-06 00:00:00	3	ANCIEN	\N	\N	\N	\N	292	\N	\N
3500	SECRETCOM	2004-10-07 00:00:00	2007-07-17 00:00:00	5	ANCIEN	\N	\N	\N	\N	667	\N	\N
3501	SECRETCOM	2004-10-07 00:00:00	2008-09-30 00:00:00	5	ANCIEN	\N	\N	\N	\N	1	\N	\N
3502	SECRETCOM	2004-10-07 00:00:00	2008-10-06 00:00:00	6	ANCIEN	\N	\N	\N	\N	795	\N	\N
3503	MEMBRECOM	2004-10-06 00:00:00	2004-11-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	212	\N	\N
3504	MEMBRECOM	2004-10-06 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	378	\N	\N
3505	MEMBRECOM	2004-10-06 00:00:00	2004-11-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	211	\N	\N
3506	PDTCOM	2004-10-07 00:00:00	2007-12-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	44	\N	\N
3507	VICPDTCOM	2004-10-07 00:00:00	2008-10-06 00:00:00	1	ANCIEN	\N	\N	\N	\N	873	\N	\N
3509	VICPDTCOM	2004-10-07 00:00:00	2008-10-06 00:00:00	4	ANCIEN	\N	\N	\N	\N	312	\N	\N
3510	VICPDTCOM	2004-10-07 00:00:00	2008-10-06 00:00:00	5	ANCIEN	\N	\N	\N	\N	739	\N	\N
3511	VICPDTCOM	2004-10-07 00:00:00	2008-09-30 00:00:00	6	ANCIEN	\N	\N	\N	\N	2574	\N	\N
3512	VICPDTCOM	2004-10-07 00:00:00	2007-09-18 00:00:00	7	ANCIEN	\N	\N	\N	\N	770	\N	\N
3513	SECRETCOM	2004-10-07 00:00:00	2008-09-30 00:00:00	2	ANCIEN	\N	\N	\N	\N	450	\N	\N
3514	SECRETCOM	2004-10-07 00:00:00	2008-10-06 00:00:00	3	ANCIEN	\N	\N	\N	\N	2529	\N	\N
3515	MEMBRECOM	2004-10-06 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	255	\N	2014-09-28 12:56:41
3517	VICPDTCOM	2004-10-07 00:00:00	2008-10-06 00:00:00	4	ANCIEN	\N	\N	\N	\N	741	\N	\N
3518	VICPDTCOM	2004-10-07 00:00:00	2008-10-06 00:00:00	5	ANCIEN	\N	\N	\N	\N	514	\N	\N
3519	VICPDTCOM	2004-10-07 00:00:00	2007-07-04 00:00:00	6	ANCIEN	\N	\N	\N	\N	803	\N	\N
3520	VICPDTCOM	2004-10-07 00:00:00	2008-09-30 00:00:00	8	ANCIEN	\N	\N	\N	\N	23	\N	\N
3521	SECRETCOM	2004-10-07 00:00:00	2011-09-30 00:00:00	1	ANCIEN	\N	\N	\N	\N	2324	\N	\N
3522	SECRETCOM	2004-10-07 00:00:00	2008-10-06 00:00:00	4	ANCIEN	\N	\N	\N	\N	804	\N	\N
3523	SECRETCOM	2004-10-07 00:00:00	2011-09-30 00:00:00	5	ANCIEN	\N	\N	\N	\N	163	\N	\N
3524	MEMBRECOM	2004-10-06 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	45	\N	\N
3525	PDTCOM	2004-10-07 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	247	\N	\N
3526	VICPDTCOM	2004-10-07 00:00:00	2008-10-06 00:00:00	1	ANCIEN	\N	\N	\N	\N	40	\N	\N
3527	MEMBRECOM	2004-10-06 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	405	\N	2014-09-28 16:42:05
3531	MEMBRECOM	2004-10-06 00:00:00	2011-01-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	118	\N	\N
3533	MEMBRECOM	2004-10-06 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12	\N	\N
3532	VICPDTCOM	2004-10-07 00:00:00	2011-09-30 00:00:00	4	ANCIEN	\N	\N	\N	\N	422	\N	\N
3534	VICPDTCOM	2004-10-08 00:00:00	2011-09-30 00:00:00	5	ANCIEN	\N	\N	\N	\N	722	\N	\N
3535	VICPDTCOM	2004-10-07 00:00:00	2008-10-06 00:00:00	2	ANCIEN	\N	\N	\N	\N	669	\N	\N
3536	VICPDTCOM	2004-10-07 00:00:00	2008-10-06 00:00:00	6	ANCIEN	\N	\N	\N	\N	20	\N	\N
3537	VICPDTCOM	2004-10-07 00:00:00	2008-10-06 00:00:00	3	ANCIEN	\N	\N	\N	\N	283	\N	\N
3538	VICPDTCOM	2004-10-07 00:00:00	2008-10-06 00:00:00	4	ANCIEN	\N	\N	\N	\N	802	\N	\N
3539	VICPDTCOM	2004-10-07 00:00:00	2008-10-06 00:00:00	7	ANCIEN	\N	\N	\N	\N	2527	\N	\N
3540	VICPDTCOM	2004-10-07 00:00:00	2008-10-06 00:00:00	6	ANCIEN	\N	\N	\N	\N	496	\N	\N
3541	VICPDTCOM	2004-10-07 00:00:00	2008-10-06 00:00:00	8	ANCIEN	\N	\N	\N	\N	69	\N	\N
3542	MEMBRECOM	2004-10-06 00:00:00	2008-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	528	\N	\N
3543	SECRETCOM	2004-10-07 00:00:00	2008-10-06 00:00:00	1	ANCIEN	\N	\N	\N	\N	824	\N	\N
3544	SECRETCOM	2004-10-07 00:00:00	2008-10-06 00:00:00	2	ANCIEN	\N	\N	\N	\N	455	\N	\N
3545	SECRETCOM	2004-10-07 00:00:00	2008-10-06 00:00:00	4	ANCIEN	\N	\N	\N	\N	459	\N	\N
3546	SECRETCOM	2004-10-07 00:00:00	2011-09-30 00:00:00	1	ANCIEN	\N	\N	\N	\N	19	\N	\N
3547	SECRETCOM	2004-10-07 00:00:00	2004-11-26 00:00:00	2	ANCIEN	\N	\N	\N	\N	2602	\N	\N
3548	SECRETCOM	2004-10-07 00:00:00	2008-09-30 00:00:00	3	ANCIEN	\N	\N	\N	\N	56	\N	\N
1141	VICPDTCOM	2001-10-04 00:00:00	2004-10-07 00:00:00	4	ANCIEN	\N	\N	\N	\N	231	\N	\N
1147	SECRETCOM	2001-10-04 00:00:00	2004-10-07 00:00:00	3	ANCIEN	\N	\N	\N	\N	195	\N	\N
3549	MEMBRECOM	2004-10-06 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	133	\N	\N
3551	MEMBRECOM	2004-10-06 00:00:00	2008-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	195	\N	\N
3552	SECRETCOM	2004-10-07 00:00:00	2008-09-30 00:00:00	4	ANCIEN	\N	\N	\N	\N	89	\N	\N
3553	MEMBRECOM	2004-10-12 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2638	\N	\N
3554	MEMBRECOM	2004-10-12 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2639	\N	\N
3555	MEMBRECOM	2004-10-12 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2640	\N	\N
3556	MEMBRECOM	2004-10-19 00:00:00	2004-11-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2643	\N	\N
3558	MEMBRECOM	2004-07-27 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2645	\N	\N
3560	MEMBRECOM	2004-07-27 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2647	\N	2014-09-28 13:21:47
3561	MEMBRECOM	2004-07-27 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2648	\N	\N
3562	MEMBRECOM	2004-07-27 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2649	\N	2017-09-24 18:20:10
3563	MEMBRECOM	2004-07-27 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2650	\N	\N
3564	MEMBRECOM	2004-07-27 00:00:00	2015-04-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2651	\N	2015-04-21 17:14:30
3565	MEMBRECOM	2004-07-27 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2652	\N	\N
3566	MEMBRECOM	2004-07-27 00:00:00	2004-11-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2653	\N	\N
3568	PDTCOM	2004-07-27 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2655	\N	2014-09-28 16:42:05
3569	MEMBRECOM	2004-07-27 00:00:00	2015-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2656	\N	2015-10-12 09:39:30
3571	MEMBRECOM	2004-07-27 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2658	\N	2014-09-28 13:21:47
3572	MEMBRECOM	2004-07-27 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2659	\N	2017-09-24 13:29:42
3573	MEMBRECOM	2004-07-27 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2660	\N	\N
3574	MEMBRECOM	2004-07-27 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2661	\N	2017-09-24 18:20:10
3575	MEMBRECOM	2004-07-27 00:00:00	2011-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2662	\N	\N
3576	MEMBRECOM	2004-07-27 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	2663	\N	\N
3577	MEMBRECOM	2004-07-27 00:00:00	2015-04-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2664	\N	2015-04-21 17:14:30
3578	MEMBRECOM	2004-07-27 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2665	\N	\N
3579	MEMBRECOM	2004-07-27 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	2666	\N	\N
3580	MEMBRECOM	2004-10-19 00:00:00	2007-11-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2667	\N	\N
3581	MEMBRECOM	2004-10-19 00:00:00	2004-11-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2668	\N	\N
3582	RAPCOM	2004-07-27 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2669	\N	\N
3583	MEMBRECOM	2004-07-27 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2670	\N	\N
3584	MEMBRECOM	2004-07-27 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2671	\N	\N
3585	RAPCOM	2004-07-27 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2673	\N	\N
3586	MEMBRECOM	2004-07-27 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2674	\N	\N
3588	MEMBRECOM	2004-11-02 00:00:00	2004-11-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2676	\N	\N
3589	MEMBRECOM	2004-11-02 00:00:00	2004-11-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2677	\N	\N
3590	MEMBRECOM	2004-11-02 00:00:00	2004-11-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2678	\N	\N
3591	MEMBRECOM	2004-11-03 00:00:00	2005-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2679	\N	\N
3592	MEMBRECOM	2004-11-03 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2680	\N	\N
3593	MEMBRECOM	2004-11-03 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2681	\N	\N
3594	MEMBRECOM	2004-11-03 00:00:00	2005-05-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2682	\N	\N
3596	RAPCOM	2004-11-18 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2684	\N	\N
3597	MEMBRECOM	2004-11-18 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2685	\N	\N
3598	MEMBRECOM	2004-11-18 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2686	\N	\N
3599	MEMBRECOM	2004-11-18 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2687	\N	\N
3600	MEMBRECOM	2004-11-18 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2688	\N	\N
3601	MEMBRECOM	2004-11-18 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2689	\N	2014-09-28 17:07:41
3603	MEMBRECOM	2004-11-18 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2691	\N	\N
3605	MEMBRECOM	2004-11-18 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2693	\N	\N
3606	MEMBRECOM	2004-11-18 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2694	\N	2017-09-24 16:43:43
2578	MEMBRECOM	2003-10-08 00:00:00	2004-02-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1968	\N	\N
3607	MEMBRECOM	2004-11-18 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2695	\N	2017-09-24 18:17:56
3608	MEMBRECOM	2004-11-18 00:00:00	2007-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2696	\N	\N
3609	VICPDTCOM	2004-12-07 00:00:00	2011-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2697	\N	\N
3610	RAPCOM	2004-12-07 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2698	\N	\N
3612	MEMBRECOM	2004-12-07 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2700	\N	2017-09-24 18:17:56
3613	MEMBRECOM	2004-12-07 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2701	\N	2017-09-24 16:43:43
3614	MEMBRECOM	2004-12-07 00:00:00	2007-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2702	\N	\N
3616	MEMBRECOM	2004-12-07 00:00:00	2015-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2704	\N	2015-06-12 16:01:25
3617	MEMBRECOM	2004-12-07 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2705	\N	2014-09-28 17:07:41
3618	MEMBRECOM	2004-12-07 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2706	\N	\N
3619	MEMBRECOM	2004-12-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2707	\N	\N
3620	MEMBRECOM	2004-12-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2708	\N	\N
3622	MEMBRECOM	2004-12-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2710	\N	\N
3623	VICPDTCOM	2004-12-14 00:00:00	2014-07-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2711	\N	2014-07-01 09:25:11
3624	RAPCOM	2004-12-14 00:00:00	2015-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2712	\N	2015-01-08 17:14:29
3625	MEMBRECOM	2004-12-14 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2713	\N	2014-09-28 13:16:32
3626	MEMBRECOM	2004-12-14 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2714	\N	2014-09-28 16:59:41
3627	MEMBRECOM	2004-12-14 00:00:00	2015-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2715	\N	2015-06-12 15:59:49
2515	PDTCOM	1968-10-08 00:00:00	1971-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1158	\N	\N
2516	SECRETCOM	1971-10-06 00:00:00	1974-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1914	\N	\N
2517	PDTCOM	1971-10-06 00:00:00	1972-10-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1438	\N	\N
2518	RAPGENCOM	1971-10-06 00:00:00	1976-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1387	\N	\N
1992	VICPDTCOM	1968-10-08 00:00:00	1971-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1445	\N	\N
2519	VICPDTCOM	1971-10-06 00:00:00	1986-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1786	\N	\N
2520	VICPDTCOM	1971-10-06 00:00:00	1977-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1244	\N	\N
2521	VICPDTCOM	1971-10-05 00:00:00	1974-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1915	\N	\N
1860	SECRETCOM	1971-10-06 00:00:00	1975-04-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1313	\N	\N
2522	SECRETCOM	1971-10-06 00:00:00	1973-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1127	\N	\N
2523	VICPDTCOM	1971-10-06 00:00:00	1977-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1903	\N	\N
2524	VICPDTCOM	1971-10-06 00:00:00	1973-03-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1281	\N	\N
2525	VICPDTCOM	2003-07-15 00:00:00	2004-04-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1916	\N	\N
2526	RAPCOM	2003-07-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	1917	\N	\N
2527	MEMBRECOM	2003-07-15 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1918	\N	\N
2528	MEMBRECOM	2003-07-15 00:00:00	2007-01-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1919	\N	\N
2529	MEMBRECOM	2003-07-15 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1920	\N	\N
2530	MEMBRECOM	2003-07-15 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1921	\N	2017-09-24 17:09:24
2531	MEMBRECOM	2003-07-15 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1922	\N	\N
2532	MEMBRECOM	2003-07-15 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1923	\N	\N
2533	MEMBRECOM	2003-07-15 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1924	\N	\N
2534	MEMBRECOM	2003-07-15 00:00:00	2004-10-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1925	\N	\N
2535	MEMBRECOM	2003-07-15 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1926	\N	\N
2536	MEMBRECOM	2003-07-15 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1927	\N	2017-09-24 17:48:21
2537	MEMBRECOM	2003-07-15 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1928	\N	2017-09-24 17:19:42
2538	MEMBRECOM	2003-07-15 00:00:00	2019-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1929	\N	\N
2540	RAPCOM	2003-07-18 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1931	\N	\N
2541	MEMBRECOM	2003-07-18 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1932	\N	\N
2542	MEMBRECOM	2003-07-18 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1933	\N	\N
2543	MEMBRECOM	2003-07-18 00:00:00	2007-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1934	\N	\N
2544	MEMBRECOM	2003-07-18 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1935	\N	2014-09-28 13:19:48
2546	MEMBRECOM	2003-07-18 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1937	\N	\N
2547	MEMBRECOM	2003-07-18 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1938	\N	\N
2548	MEMBRECOM	2003-07-18 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1939	\N	\N
2549	MEMBRECOM	2003-07-18 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1940	\N	2014-09-28 17:07:41
2550	MEMBRECOM	2003-07-18 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1941	\N	\N
2551	MEMBRECOM	2003-07-18 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1942	\N	2017-09-24 18:17:56
2552	MEMBRECOM	2003-07-18 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1943	\N	\N
2553	PDTCOM	2003-07-23 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1944	\N	2014-09-28 18:58:21
2554	RAPCOM	2003-07-23 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1945	\N	2014-09-28 17:15:42
2555	MEMBRECOM	2003-07-23 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1946	\N	2017-09-24 17:28:55
2556	MEMBRECOM	2003-07-23 00:00:00	2015-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1947	\N	2015-10-12 09:39:31
2558	MEMBRECOM	2003-07-23 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1949	\N	\N
2559	MEMBRECOM	2003-07-23 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1950	\N	\N
2560	MEMBRECOM	2003-07-23 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1951	\N	\N
2561	MEMBRECOM	2003-07-23 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1952	\N	\N
2562	MEMBRECOM	2003-07-23 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1953	\N	2014-09-28 16:59:41
2563	MEMBRECOM	2003-07-23 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1954	\N	\N
2564	MEMBRECOM	2003-07-23 00:00:00	2004-04-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1955	\N	\N
2565	MEMBRECOM	2003-07-23 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1956	\N	2014-09-28 16:50:17
2566	MEMBRECOM	2003-07-23 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1957	\N	2017-09-24 17:09:24
2567	MEMBRECOM	2003-08-29 00:00:00	2003-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1958	\N	\N
2571	MEMBRECOM	2003-10-01 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1960	\N	\N
2572	MEMBRECOM	2003-10-08 00:00:00	2004-02-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1962	\N	\N
2573	MEMBRECOM	2003-10-08 00:00:00	2004-02-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1963	\N	\N
2574	MEMBRECOM	2003-10-08 00:00:00	2004-02-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1964	\N	\N
2575	MEMBRECOM	2003-10-08 00:00:00	2004-02-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1965	\N	\N
2576	MEMBRECOM	2003-10-08 00:00:00	2004-02-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1966	\N	\N
2577	MEMBRECOM	2003-10-08 00:00:00	2004-02-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1967	\N	\N
2579	MEMBRECOM	2003-10-08 00:00:00	2004-02-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1969	\N	\N
2581	MEMBRECOM	2003-10-08 00:00:00	2004-02-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1971	\N	\N
2582	MEMBRECOM	2003-10-08 00:00:00	2004-02-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1972	\N	\N
1158	SECRETCOM	2001-10-04 00:00:00	2004-10-07 00:00:00	2	ANCIEN	\N	\N	\N	\N	528	\N	\N
1159	SECRETCOM	2001-10-04 00:00:00	2008-10-06 00:00:00	3	ANCIEN	\N	\N	\N	\N	250	\N	\N
1160	SECRETCOM	2001-10-04 00:00:00	2004-10-07 00:00:00	4	ANCIEN	\N	\N	\N	\N	247	\N	\N
1161	PDTCOM	2001-10-04 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	771	\N	\N
1162	VICPDTCOM	2001-10-04 00:00:00	2008-10-06 00:00:00	1	ANCIEN	\N	\N	\N	\N	290	\N	\N
1163	VICPDTCOM	2001-10-04 00:00:00	2008-09-30 00:00:00	2	ANCIEN	\N	\N	\N	\N	61	\N	\N
1164	VICPDTCOM	2001-10-04 00:00:00	2004-09-30 00:00:00	3	ANCIEN	\N	\N	\N	\N	218	\N	\N
1165	VICPDTCOM	2001-10-04 00:00:00	2004-09-30 00:00:00	4	ANCIEN	\N	\N	\N	\N	217	\N	\N
1166	VICPDTCOM	2001-10-04 00:00:00	2007-06-28 00:00:00	7	ANCIEN	\N	\N	\N	\N	497	\N	\N
1167	VICPDTCOM	2001-10-04 00:00:00	2004-10-07 00:00:00	6	ANCIEN	\N	\N	\N	\N	45	\N	\N
1168	SECRETCOM	2001-10-04 00:00:00	2011-09-30 00:00:00	2	ANCIEN	\N	\N	\N	\N	210	\N	\N
1169	SECRETCOM	2001-10-04 00:00:00	2004-09-30 00:00:00	2	ANCIEN	\N	\N	\N	\N	238	\N	\N
1170	SECRETCOM	2001-10-04 00:00:00	2004-10-07 00:00:00	3	ANCIEN	\N	\N	\N	\N	514	\N	\N
1171	SECRETCOM	2001-10-04 00:00:00	2008-10-06 00:00:00	3	ANCIEN	\N	\N	\N	\N	680	\N	\N
1172	PDTCOM	2001-10-04 00:00:00	2004-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	90	\N	\N
1173	VICPDTCOM	2001-10-04 00:00:00	2002-06-07 00:00:00	1	ANCIEN	\N	\N	\N	\N	433	\N	\N
1174	VICPDTCOM	2001-10-04 00:00:00	2004-10-07 00:00:00	2	ANCIEN	\N	\N	\N	\N	35	\N	\N
1175	VICPDTCOM	2001-10-04 00:00:00	2004-10-07 00:00:00	3	ANCIEN	\N	\N	\N	\N	13	\N	\N
1176	VICPDTCOM	2001-10-04 00:00:00	2004-09-30 00:00:00	4	ANCIEN	\N	\N	\N	\N	191	\N	\N
1177	VICPDTCOM	2001-10-04 00:00:00	2008-10-06 00:00:00	5	ANCIEN	\N	\N	\N	\N	173	\N	\N
1178	VICPDTCOM	2001-10-04 00:00:00	2004-10-07 00:00:00	6	ANCIEN	\N	\N	\N	\N	212	\N	\N
1179	SECRETCOM	2001-10-04 00:00:00	2008-10-06 00:00:00	1	ANCIEN	\N	\N	\N	\N	277	\N	\N
1180	SECRETCOM	2001-10-04 00:00:00	2008-10-06 00:00:00	2	ANCIEN	\N	\N	\N	\N	740	\N	\N
1181	SECRETCOM	2001-10-04 00:00:00	2004-10-05 00:00:00	3	ANCIEN	\N	\N	\N	\N	790	\N	\N
1182	SECRETCOM	2001-10-04 00:00:00	2004-10-07 00:00:00	4	ANCIEN	\N	\N	\N	\N	378	\N	\N
1184	VICPDTCOM	2001-10-04 00:00:00	2004-05-04 00:00:00	1	ANCIEN	\N	\N	\N	\N	227	\N	\N
257	MEMBRECOM	2001-10-03 00:00:00	2001-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	257	\N	\N
1185	VICPDTCOM	2001-10-04 00:00:00	2008-10-06 00:00:00	5	ANCIEN	\N	\N	\N	\N	257	\N	\N
1186	VICPDTCOM	2001-10-04 00:00:00	2008-10-06 00:00:00	2	ANCIEN	\N	\N	\N	\N	87	\N	\N
1187	VICPDTCOM	2001-10-04 00:00:00	2008-10-06 00:00:00	6	ANCIEN	\N	\N	\N	\N	236	\N	\N
1188	VICPDTCOM	2001-10-04 00:00:00	2003-03-05 00:00:00	5	ANCIEN	\N	\N	\N	\N	260	\N	\N
1189	VICPDTCOM	2001-10-04 00:00:00	2004-09-30 00:00:00	6	ANCIEN	\N	\N	\N	\N	268	\N	\N
1190	SECRETCOM	2001-10-04 00:00:00	2004-09-30 00:00:00	1	ANCIEN	\N	\N	\N	\N	225	\N	\N
1191	SECRETCOM	2001-10-04 00:00:00	2003-08-28 00:00:00	3	ANCIEN	\N	\N	\N	\N	442	\N	\N
1979	MEMBRECOM	\N	1971-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1432	\N	\N
1980	MEMBRECOM	1967-10-12 00:00:00	1968-10-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1433	\N	\N
1981	MEMBRECOM	\N	1962-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1434	\N	\N
1982	MEMBRECOM	\N	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1435	\N	\N
1983	MEMBRECOM	\N	1965-12-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1436	\N	\N
1984	VICPDTCOM	1968-10-08 00:00:00	1971-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1437	\N	\N
1985	RAPGENCOM	1959-05-12 00:00:00	1971-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1438	\N	\N
2906	VICPDTCOM	1995-10-05 00:00:00	1996-09-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1665	\N	\N
2907	MEMBRECOM	1983-10-06 00:00:00	1995-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	144	\N	\N
2908	MEMBRECOM	1989-10-05 00:00:00	1995-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	70	\N	\N
2909	SECRETCOM	1995-10-05 00:00:00	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	220	\N	\N
2910	SECRETCOM	1995-10-05 00:00:00	1997-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	52	\N	\N
2911	MEMBRECOM	1980-10-07 00:00:00	1986-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2136	\N	\N
2912	MEMBRECOM	1986-10-06 00:00:00	1995-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	52	\N	\N
2913	MEMBRECOM	1988-11-15 00:00:00	1989-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2137	\N	\N
2914	MEMBRECOM	1989-10-04 00:00:00	1995-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	242	\N	\N
2915	SECRETCOM	1995-10-05 00:00:00	1996-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	242	\N	\N
2916	SECRETCOM	1995-10-05 00:00:00	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	155	\N	\N
2917	MEMBRECOM	1996-02-21 00:00:00	1998-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2133	\N	\N
2918	MEMBRECOM	1992-10-07 00:00:00	1996-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	109	\N	\N
2919	MEMBRECOM	1996-10-04 00:00:00	1996-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	148	\N	\N
2920	VICPDTCOM	1996-02-14 00:00:00	1998-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2030	\N	\N
189	SECRETCOM	1996-02-14 00:00:00	1998-10-06 00:00:00	4	ANCIEN	\N	\N	\N	\N	189	\N	\N
2921	MEMBRECOM	1995-10-04 00:00:00	1996-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	189	\N	\N
2922	MEMBRECOM	1992-10-07 00:00:00	1996-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	201	\N	\N
2923	MEMBRECOM	1995-10-04 00:00:00	1996-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1713	\N	\N
2924	MEMBRECOM	1983-10-06 00:00:00	1996-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	138	\N	\N
2925	MEMBRECOM	1983-10-05 00:00:00	1986-04-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2138	\N	\N
2926	MEMBRECOM	1992-10-07 00:00:00	1995-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	182	\N	\N
2942	VICPDTCOM	2003-12-09 00:00:00	2014-07-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2145	\N	2014-07-01 09:25:11
2929	MEMBRECOM	1995-10-02 00:00:00	1995-10-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2139	\N	\N
2930	MEMBRECOM	1992-10-07 00:00:00	1995-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2140	\N	\N
2931	MEMBRECOM	1998-10-06 00:00:00	2000-04-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	67	\N	\N
2932	MEMBRECOM	1983-10-06 00:00:00	1986-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2141	\N	\N
2933	MEMBRECOM	1986-10-06 00:00:00	1998-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	126	\N	\N
2934	MEMBRECOM	1977-10-06 00:00:00	1980-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2142	\N	\N
2935	MEMBRECOM	1981-10-08 00:00:00	1986-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2143	\N	\N
2936	MEMBRECOM	1992-10-07 00:00:00	1996-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	140	\N	\N
2941	SECRETCOM	2003-12-10 00:00:00	2004-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	439	\N	\N
2938	VICPDTCOM	1998-10-07 00:00:00	2001-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	127	\N	\N
2943	RAPCOM	2003-12-09 00:00:00	2015-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2146	\N	2015-01-08 17:14:29
2944	MEMBRECOM	2003-12-09 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2147	\N	2014-09-28 16:59:41
2945	MEMBRECOM	2003-12-09 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2148	\N	\N
2946	MEMBRECOM	2003-12-09 00:00:00	2015-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2149	\N	2015-06-12 15:59:49
2947	MEMBRECOM	2003-12-09 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2150	\N	2017-09-24 13:47:46
2948	MEMBRECOM	2003-12-09 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2151	\N	\N
2950	MEMBRECOM	2003-12-09 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2153	\N	\N
2951	MEMBRECOM	2003-12-09 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2154	\N	2014-09-28 13:16:32
2952	MEMBRECOM	2003-12-09 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2155	\N	\N
2953	MEMBRECOM	2003-12-09 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2156	\N	\N
2954	MEMBRECOM	2003-12-09 00:00:00	2017-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2157	\N	2017-09-25 09:56:00
2955	MEMBRECOM	2003-12-09 00:00:00	2013-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2158	\N	\N
2956	PDTCOM	2003-12-16 00:00:00	2014-07-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2159	\N	2014-07-01 09:25:11
2957	RAPCOM	2003-12-16 00:00:00	2015-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2160	\N	2015-01-08 17:14:29
2959	MEMBRECOM	2003-12-16 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2162	\N	\N
2960	MEMBRECOM	2003-12-16 00:00:00	2015-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2163	\N	2015-06-12 15:59:49
2961	MEMBRECOM	2003-12-16 00:00:00	2010-03-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2164	\N	\N
2962	MEMBRECOM	2003-12-16 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2165	\N	\N
2963	MEMBRECOM	2003-12-16 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2166	\N	\N
2964	MEMBRECOM	2003-12-16 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2167	\N	2014-09-28 18:19:47
2965	MEMBRECOM	2003-12-16 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2168	\N	2014-09-28 13:16:32
2966	MEMBRECOM	2003-12-16 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2169	\N	\N
2967	MEMBRECOM	2003-12-16 00:00:00	2013-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2170	\N	\N
2968	MEMBRECOM	2003-12-16 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2171	\N	2017-09-24 13:47:46
2969	MEMBRECOM	2003-12-16 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2172	\N	\N
2970	MEMBRECOM	2004-03-02 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2173	\N	\N
2972	RAPCOM	2004-01-15 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2175	\N	\N
2973	MEMBRECOM	2004-01-15 00:00:00	2014-09-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2176	\N	2014-09-16 14:55:28
2974	MEMBRECOM	2004-01-15 00:00:00	2015-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2177	\N	2015-10-12 09:39:30
2976	MEMBRECOM	2004-01-15 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2179	\N	\N
2977	MEMBRECOM	2004-01-15 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2180	\N	\N
2978	MEMBRECOM	2004-01-15 00:00:00	2014-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2181	\N	2014-09-29 13:41:53
2979	MEMBRECOM	2004-01-15 00:00:00	2008-09-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2182	\N	\N
2980	MEMBRECOM	2004-01-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2183	\N	2014-09-28 18:00:58
2981	MEMBRECOM	2004-01-15 00:00:00	2015-04-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2184	\N	2015-04-21 17:14:30
2982	MEMBRECOM	2004-01-15 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2185	\N	\N
2983	MEMBRECOM	2004-01-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	2186	\N	\N
2984	MEMBRECOM	2004-01-15 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2187	\N	2017-09-24 13:29:42
2985	PDTCOM	2004-01-23 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2188	\N	2014-09-28 16:42:05
2986	RAPCOM	2004-01-23 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2189	\N	2017-09-24 13:29:42
2987	MEMBRECOM	2004-01-23 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2190	\N	2014-09-28 18:00:58
2988	MEMBRECOM	2004-01-23 00:00:00	2015-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2191	\N	2015-10-12 09:39:30
2989	MEMBRECOM	2004-01-23 00:00:00	2015-04-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2192	\N	2015-04-21 17:14:30
2990	MEMBRECOM	2004-01-23 00:00:00	2008-09-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2193	\N	\N
2992	MEMBRECOM	2004-01-23 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2195	\N	\N
2993	MEMBRECOM	2004-01-23 00:00:00	2014-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2196	\N	2014-09-29 13:41:53
2994	MEMBRECOM	2004-01-23 00:00:00	2015-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2197	\N	2015-06-12 16:01:25
2995	MEMBRECOM	2004-01-23 00:00:00	2011-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2198	\N	\N
2997	MEMBRECOM	2004-01-23 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2200	\N	\N
2998	MEMBRECOM	2004-01-23 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	2201	\N	\N
3000	MEMBRECOM	2004-02-11 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2203	\N	\N
3001	RAPCOM	2004-02-11 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2204	\N	\N
3003	MEMBRECOM	2004-02-11 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2206	\N	2017-09-24 18:17:56
3004	MEMBRECOM	2004-02-11 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2207	\N	\N
3005	MEMBRECOM	2004-02-11 00:00:00	2007-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2208	\N	\N
3006	MEMBRECOM	2004-02-11 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2209	\N	2017-09-24 13:44:49
3008	MEMBRECOM	2004-02-11 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2211	\N	2014-09-28 17:07:41
3009	MEMBRECOM	2004-02-11 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2212	\N	\N
3010	MEMBRECOM	2004-02-11 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2213	\N	\N
3011	MEMBRECOM	2004-02-11 00:00:00	2014-09-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2214	\N	2014-09-01 10:21:13
3012	MEMBRECOM	2004-02-11 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2215	\N	\N
3013	MEMBRECOM	1988-11-23 00:00:00	1989-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2216	\N	\N
3015	SECRETCOM	1986-10-06 00:00:00	1989-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2217	\N	\N
3016	SECRETCOM	1992-10-08 00:00:00	1995-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2218	\N	\N
270	VICPDTCOM	1996-02-07 00:00:00	1998-10-06 00:00:00	4	ANCIEN	\N	\N	\N	\N	270	\N	\N
3017	SECRETCOM	1995-10-05 00:00:00	1996-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	270	\N	\N
3172	MEMBRECOM	2004-06-09 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2319	\N	\N
3173	MEMBRECOM	2004-06-09 00:00:00	2007-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2320	\N	\N
3174	MEMBRECOM	2004-06-09 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2321	\N	\N
2628	PDTCOM	1974-10-04 00:00:00	1977-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1048	\N	\N
2631	VICPDTCOM	1974-10-04 00:00:00	1983-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2020	\N	\N
2632	MEMBRECOM	1959-05-12 00:00:00	1962-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2021	\N	\N
2633	MEMBRECOM	1962-10-05 00:00:00	1965-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2022	\N	\N
2634	MEMBRECOM	1965-10-05 00:00:00	1974-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2023	\N	\N
2635	MEMBRECOM	1968-10-08 00:00:00	1974-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2024	\N	\N
2636	VICPDTCOM	1974-10-04 00:00:00	1986-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2025	\N	\N
2637	VICPDTCOM	1974-10-04 00:00:00	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2026	\N	\N
2638	MEMBRECOM	2003-11-14 00:00:00	2005-10-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2027	\N	\N
2639	MEMBRECOM	2003-11-14 00:00:00	2007-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2028	\N	\N
2640	MEMBRECOM	2003-11-14 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2029	\N	\N
2641	SECRETCOM	1974-10-04 00:00:00	1980-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2030	\N	\N
2642	VICPDTCOM	1974-10-04 00:00:00	1980-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1353	\N	\N
2643	VICPDTCOM	1974-10-04 00:00:00	1980-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1762	\N	\N
2644	PDTCOM	1974-10-04 00:00:00	1977-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1310	\N	\N
2645	MEMBRECOM	1959-05-12 00:00:00	1962-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2031	\N	\N
2646	MEMBRECOM	1959-05-12 00:00:00	1960-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2032	\N	\N
2647	VICPDTCOM	1974-10-04 00:00:00	1989-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1554	\N	\N
2648	MEMBRECOM	1962-10-05 00:00:00	1968-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2033	\N	\N
2649	MEMBRECOM	1969-05-16 00:00:00	1971-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2034	\N	\N
2650	MEMBRECOM	1959-05-12 00:00:00	1968-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2035	\N	\N
2206	SECRETCOM	1974-10-04 00:00:00	1989-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1638	\N	\N
2651	SECRETCOM	1974-10-04 00:00:00	1977-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2036	\N	\N
2652	SECRETCOM	1974-10-04 00:00:00	1977-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1761	\N	\N
2653	SECRETCOM	1975-10-30 00:00:00	1986-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1567	\N	\N
2654	MEMBRECOM	1959-05-12 00:00:00	1962-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2037	\N	\N
2656	VICPDTCOM	1977-10-06 00:00:00	1980-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2039	\N	\N
2661	PDTCOM	1977-10-06 00:00:00	1986-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1912	\N	\N
3018	SECRETCOM	1986-10-06 00:00:00	1995-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2219	\N	\N
3019	SECRETCOM	1995-10-05 00:00:00	1996-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	248	\N	\N
3020	RAPGENCOM	1977-10-06 00:00:00	1989-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17	\N	\N
3021	SECRETCOM	1989-10-05 00:00:00	1992-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17	\N	\N
3022	VICPDTCOM	1985-04-23 00:00:00	1986-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	311	\N	\N
3023	SECRETCOM	1995-10-05 00:00:00	1996-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	87	\N	\N
3024	VICPDTCOM	1980-10-07 00:00:00	1986-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	193	\N	\N
3053	VICPDTCOM	1990-10-04 00:00:00	1995-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2229	\N	\N
3026	VICPDTCOM	1995-10-05 00:00:00	1998-03-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2220	\N	\N
3027	SECRETCOM	\N	1996-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	762	\N	\N
3028	VICPDTCOM	1996-02-07 00:00:00	1997-06-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	762	\N	\N
3029	VICPDTCOM	1987-04-15 00:00:00	1995-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	246	\N	\N
3030	SECRETCOM	1992-10-08 00:00:00	1995-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	105	\N	\N
3031	SECRETCOM	1978-05-09 00:00:00	1980-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4	\N	\N
3032	VICPDTCOM	1982-06-23 00:00:00	1989-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4	\N	\N
3034	VICPDTCOM	1980-10-07 00:00:00	1986-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	124	\N	\N
3035	SECRETCOM	1986-10-06 00:00:00	1989-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	124	\N	\N
3036	VICPDTCOM	1995-10-05 00:00:00	1997-01-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	289	\N	\N
3037	SECRETCOM	1986-10-06 00:00:00	1995-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	274	\N	\N
250	SECRETCOM	1995-10-05 00:00:00	1998-10-06 00:00:00	2	ANCIEN	\N	\N	\N	\N	250	\N	\N
3038	SECRETCOM	1977-10-06 00:00:00	1980-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2221	\N	\N
3039	SECRETCOM	1980-10-07 00:00:00	1983-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2222	\N	\N
3040	SECRETCOM	1992-10-08 00:00:00	1997-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2223	\N	\N
3041	SECRETCOM	1986-10-06 00:00:00	1989-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	867	\N	\N
3042	SECRETCOM	1990-10-04 00:00:00	1992-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	867	\N	\N
3043	SECRETCOM	1992-10-08 00:00:00	1995-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	278	\N	\N
3044	SECRETCOM	1974-10-04 00:00:00	1978-04-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2224	\N	\N
3045	SECRETCOM	1989-10-05 00:00:00	1992-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2225	\N	\N
3046	SECRETCOM	1995-10-05 00:00:00	1996-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	173	\N	\N
3047	SECRETCOM	1992-10-08 00:00:00	1995-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	212	\N	\N
3048	SECRETCOM	1983-10-06 00:00:00	1986-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2226	\N	\N
3049	SECRETCOM	1986-10-06 00:00:00	1992-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2227	\N	\N
3050	VICPDTCOM	1986-10-06 00:00:00	1987-01-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2228	\N	\N
3051	SECRETCOM	1992-10-08 00:00:00	1993-04-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	316	\N	\N
3054	MEMBRECOM	1965-10-02 00:00:00	1965-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2230	\N	\N
3058	MEMBRECOM	1972-10-17 00:00:00	1973-04-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1103	\N	\N
3059	MEMBRECOM	1973-04-02 00:00:00	1975-05-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1152	\N	\N
4627	MEMBRECOM	2007-07-26 00:00:00	2007-07-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3711	\N	\N
4628	MEMBRECOM	2007-07-26 00:00:00	2007-07-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3712	\N	2017-09-24 18:16:52
4629	MEMBRECOM	2007-07-26 00:00:00	2007-07-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3713	\N	\N
4630	MEMBRECOM	2007-07-26 00:00:00	2007-07-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3714	\N	2014-12-18 16:15:04
4631	MEMBRECOM	2007-07-26 00:00:00	2007-07-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3715	\N	\N
4632	MEMBRECOM	2007-07-26 00:00:00	2007-07-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3716	\N	\N
4633	MEMBRECOM	2007-07-26 00:00:00	2007-07-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3717	\N	\N
4634	MEMBRECOM	2007-07-26 00:00:00	2007-07-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3718	\N	\N
4635	MEMBRECOM	2007-07-26 00:00:00	2007-07-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3719	\N	\N
4636	MEMBRECOM	2007-07-26 00:00:00	2007-07-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3720	\N	\N
4638	MEMBRECOM	2007-07-26 00:00:00	2007-07-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3722	\N	\N
4639	VICPDTCOM	2007-07-27 00:00:00	2007-07-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3723	\N	2014-07-01 09:25:11
4407	MEMBRECOM	2007-01-10 00:00:00	2007-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3488	\N	\N
4408	MEMBRECOM	2007-01-10 00:00:00	2007-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3490	\N	\N
4410	MEMBRECOM	2007-01-10 00:00:00	2007-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3492	\N	\N
4412	MEMBRECOM	2007-01-10 00:00:00	2007-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3494	\N	\N
4413	MEMBRECOM	2007-01-10 00:00:00	2007-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3495	\N	\N
4415	MEMBRECOM	2007-01-10 00:00:00	2007-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3497	\N	\N
4417	MEMBRECOM	2007-01-10 00:00:00	2007-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3499	\N	\N
4419	MEMBRECOM	2007-01-10 00:00:00	2007-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3501	\N	\N
4421	MEMBRECOM	2007-01-10 00:00:00	2007-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3503	\N	\N
4422	MEMBRECOM	2007-01-18 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3504	\N	\N
4423	MEMBRECOM	2007-01-18 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3505	\N	\N
4424	MEMBRECOM	2007-01-18 00:00:00	2008-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3506	\N	\N
4553	MEMBRECOM	2007-06-26 00:00:00	2007-09-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3635	\N	\N
4554	MEMBRECOM	2007-07-05 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3636	\N	\N
4556	MEMBRECOM	2007-07-05 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3638	\N	\N
4557	MEMBRECOM	2007-07-05 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3639	\N	\N
4558	MEMBRECOM	2007-07-05 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3640	\N	\N
4559	MEMBRECOM	2007-07-05 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3641	\N	\N
4561	MEMBRECOM	2007-07-05 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3643	\N	\N
4562	MEMBRECOM	2007-07-05 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3644	\N	\N
4563	MEMBRECOM	2007-07-05 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3645	\N	\N
10980	MEMBRECOM	2013-04-02 00:00:00	2015-04-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9267	\N	2015-04-21 17:14:30
4566	MEMBRECOM	2007-07-05 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3648	\N	\N
4567	MEMBRECOM	2007-07-05 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3649	\N	\N
4568	MEMBRECOM	2007-07-05 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3650	\N	\N
4570	MEMBRECOM	2007-07-05 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3652	\N	\N
4571	MEMBRECOM	2007-07-05 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3653	\N	\N
4572	MEMBRECOM	2007-07-05 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3654	\N	\N
4573	MEMBRECOM	2007-07-05 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3655	\N	\N
4575	MEMBRECOM	2007-07-05 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3657	\N	\N
4576	MEMBRECOM	2007-07-05 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3658	\N	\N
4577	MEMBRECOM	2007-07-05 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3659	\N	\N
3882	RAPCOM	2005-11-24 00:00:00	2006-03-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2970	\N	\N
3883	MEMBRECOM	2005-10-27 00:00:00	2006-03-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2972	\N	\N
3884	SECRETCOM	2005-11-24 00:00:00	2006-03-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2973	\N	\N
3885	SECRETCOM	2005-11-24 00:00:00	2006-03-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2974	\N	\N
3886	MEMBRECOM	2005-10-27 00:00:00	2006-03-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2975	\N	\N
3888	MEMBRECOM	2005-11-23 00:00:00	2006-03-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2977	\N	\N
3889	VICPDTCOM	2005-11-24 00:00:00	2006-03-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2978	\N	\N
3890	MEMBRECOM	2005-10-27 00:00:00	2006-03-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2979	\N	\N
3891	MEMBRECOM	2005-10-27 00:00:00	2006-03-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2980	\N	\N
3893	MEMBRECOM	2005-10-27 00:00:00	2006-03-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2982	\N	\N
3894	MEMBRECOM	2005-10-27 00:00:00	2006-03-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2983	\N	\N
3895	VICPDTCOM	2005-11-24 00:00:00	2006-03-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2984	\N	\N
3896	MEMBRECOM	2005-10-27 00:00:00	2006-03-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2985	\N	\N
3897	MEMBRECOM	2005-10-27 00:00:00	2006-03-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2986	\N	\N
3898	MEMBRECOM	2005-10-27 00:00:00	2006-03-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2987	\N	\N
3901	VICPDTCOM	2005-11-24 00:00:00	2006-03-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2990	\N	\N
3902	VICPDTCOM	2005-11-24 00:00:00	2006-03-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2991	\N	\N
3904	MEMBRECOM	2005-10-27 00:00:00	2006-03-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2993	\N	\N
3905	MEMBRECOM	2005-10-27 00:00:00	2006-03-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2994	\N	\N
10981	MEMBRECOM	2013-04-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9268	\N	\N
3907	MEMBRECOM	2005-10-27 00:00:00	2006-03-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2996	\N	\N
3908	MEMBRECOM	2005-10-27 00:00:00	2006-03-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2997	\N	\N
3910	VICPDTCOM	2005-11-24 00:00:00	2006-03-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2999	\N	\N
3911	RAPCOM	2005-11-24 00:00:00	2006-03-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3000	\N	\N
3913	MEMBRECOM	2005-10-27 00:00:00	2006-03-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3002	\N	\N
3914	MEMBRECOM	2005-10-27 00:00:00	2006-03-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3003	\N	\N
3917	MEMBRECOM	2005-11-03 00:00:00	2006-05-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3007	\N	\N
3918	MEMBRECOM	2005-11-03 00:00:00	2006-05-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3008	\N	\N
3920	MEMBRECOM	2005-11-03 00:00:00	2006-05-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3010	\N	\N
3921	MEMBRECOM	2005-11-03 00:00:00	2006-05-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3011	\N	\N
3923	MEMBRECOM	2005-11-03 00:00:00	2006-05-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3013	\N	\N
3924	MEMBRECOM	2005-11-03 00:00:00	2006-05-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3015	\N	\N
3926	MEMBRECOM	2005-11-03 00:00:00	2006-05-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3017	\N	\N
3928	MEMBRECOM	2005-11-03 00:00:00	2006-05-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3019	\N	\N
3929	MEMBRECOM	2005-11-03 00:00:00	2006-05-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3020	\N	\N
3931	MEMBRECOM	2005-11-03 00:00:00	2006-05-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3022	\N	\N
3932	MEMBRECOM	2005-11-03 00:00:00	2006-05-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3023	\N	\N
3933	MEMBRECOM	2005-11-03 00:00:00	2006-05-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3024	\N	\N
3934	MEMBRECOM	2005-11-03 00:00:00	2006-05-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3025	\N	\N
3936	MEMBRECOM	2005-11-03 00:00:00	2006-05-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3027	\N	\N
3938	RAPCOM	2005-11-04 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3030	\N	2017-09-24 13:29:42
3939	MEMBRECOM	2005-11-04 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3031	\N	2014-09-28 18:00:58
3940	MEMBRECOM	2005-11-04 00:00:00	2015-04-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3032	\N	2015-04-21 17:14:30
3941	MEMBRECOM	2005-11-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	3033	\N	\N
3942	MEMBRECOM	2005-11-04 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3034	\N	\N
3943	MEMBRECOM	2005-11-04 00:00:00	2012-09-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3035	\N	\N
3944	MEMBRECOM	2005-11-04 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3036	\N	2014-09-28 12:09:44
3945	MEMBRECOM	2005-11-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	3037	\N	\N
3946	MEMBRECOM	2005-11-04 00:00:00	2008-09-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3038	\N	\N
3947	MEMBRECOM	2005-11-04 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3039	\N	\N
3948	MEMBRECOM	2005-11-04 00:00:00	2007-11-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3040	\N	\N
3949	MEMBRECOM	2005-11-04 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3041	\N	\N
3951	MEMBRECOM	2005-10-27 00:00:00	2006-03-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2971	\N	\N
1305	MEMBRECOM	2003-01-15 00:00:00	2003-05-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	891	\N	\N
1312	MEMBRECOM	2003-01-15 00:00:00	2003-05-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	898	\N	\N
1318	MEMBRECOM	2003-01-15 00:00:00	2003-05-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	904	\N	\N
2580	MEMBRECOM	2003-10-08 00:00:00	2004-02-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1970	\N	\N
2585	MEMBRECOM	2003-10-08 00:00:00	2004-02-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1975	\N	\N
2588	MEMBRECOM	2003-10-08 00:00:00	2004-02-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1978	\N	\N
2591	MEMBRECOM	2003-10-08 00:00:00	2004-02-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1981	\N	\N
2596	MEMBRECOM	2003-10-08 00:00:00	2004-02-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1986	\N	\N
2599	MEMBRECOM	2003-10-08 00:00:00	2004-02-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1989	\N	\N
2605	MEMBRECOM	2003-10-08 00:00:00	2004-02-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1995	\N	\N
1341	MEMBRECOM	2002-12-12 00:00:00	2003-06-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	928	\N	\N
1348	MEMBRECOM	2002-12-12 00:00:00	2003-06-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	935	\N	\N
1356	MEMBRECOM	2002-12-12 00:00:00	2003-06-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	943	\N	\N
729	MEMBRECOM	2001-06-19 00:00:00	2001-11-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	628	\N	\N
149	MEMBRECOM	1992-10-08 00:00:00	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	149	\N	\N
3953	VICPDTCOM	1989-10-05 00:00:00	1995-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3044	\N	\N
3954	MEMBRECOM	1995-10-05 00:00:00	2002-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3045	\N	\N
3955	MEMBRECOM	1980-10-08 00:00:00	1982-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4	\N	\N
3956	PDTCOM	2005-11-18 00:00:00	2011-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3046	\N	\N
3958	MEMBRECOM	2005-11-18 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3048	\N	\N
3985	RAPCOM	2005-11-24 00:00:00	2006-03-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3005	\N	\N
3960	MEMBRECOM	2005-11-18 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3050	\N	\N
3961	MEMBRECOM	2005-11-18 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3051	\N	\N
3962	MEMBRECOM	2005-11-18 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3052	\N	\N
3963	MEMBRECOM	2005-11-18 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3053	\N	2014-09-28 17:07:41
3965	MEMBRECOM	2005-11-18 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3055	\N	2017-09-24 13:44:49
3966	MEMBRECOM	2005-11-18 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3056	\N	\N
3967	MEMBRECOM	2005-11-18 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3057	\N	\N
3968	MEMBRECOM	2005-11-18 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3058	\N	2014-09-28 13:19:48
3969	MEMBRECOM	2005-11-18 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3059	\N	\N
3970	MEMBRECOM	2005-11-18 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3060	\N	\N
3971	MEMBRECOM	1967-10-11 00:00:00	1970-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1910	\N	\N
3972	MEMBRECOM	1986-10-02 00:00:00	1987-10-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3061	\N	\N
3973	MEMBRECOM	1987-10-20 00:00:00	1989-04-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3062	\N	\N
3974	MEMBRECOM	1989-04-05 00:00:00	1990-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2229	\N	\N
3975	MEMBRECOM	1969-10-08 00:00:00	1971-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1911	\N	\N
3976	MEMBRECOM	\N	1983-04-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	245	\N	\N
3977	MEMBRECOM	1986-10-02 00:00:00	1995-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	289	\N	\N
3979	MEMBRECOM	1959-05-06 00:00:00	1959-05-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1240	\N	\N
3980	MEMBRECOM	1959-05-06 00:00:00	1959-05-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1433	\N	\N
3981	MEMBRECOM	1959-05-06 00:00:00	1959-05-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1450	\N	\N
3982	MEMBRECOM	1959-05-06 00:00:00	1959-05-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1451	\N	\N
3983	MEMBRECOM	1968-10-04 00:00:00	1971-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1913	\N	\N
3984	MEMBRECOM	2005-11-23 00:00:00	2006-03-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3065	\N	\N
3986	VICPDTCOM	2005-11-30 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3066	\N	2014-09-28 18:58:21
3989	MEMBRECOM	2005-11-30 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3069	\N	\N
3991	MEMBRECOM	2005-11-30 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3071	\N	2014-09-28 13:39:20
3992	MEMBRECOM	2005-11-30 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3072	\N	\N
3993	MEMBRECOM	2005-11-30 00:00:00	2020-11-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3073	\N	\N
3994	MEMBRECOM	2005-11-30 00:00:00	2017-05-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3074	\N	2017-05-16 15:18:13
3995	MEMBRECOM	2005-11-30 00:00:00	2007-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3075	\N	\N
3996	MEMBRECOM	2005-11-30 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3076	\N	\N
3998	MEMBRECOM	2005-11-30 00:00:00	2019-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3078	\N	\N
3999	MEMBRECOM	2005-11-30 00:00:00	2006-06-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3079	\N	\N
4000	PDTCOM	2005-12-15 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3080	\N	2014-09-28 18:58:21
4001	RAPCOM	2005-12-15 00:00:00	2019-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3081	\N	\N
4002	MEMBRECOM	2005-12-15 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3082	\N	\N
4003	MEMBRECOM	2005-12-15 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3083	\N	\N
4004	MEMBRECOM	2005-12-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3084	\N	2014-09-28 17:09:16
4007	MEMBRECOM	2005-12-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3087	\N	2014-09-28 17:55:39
4008	MEMBRECOM	2005-12-15 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3088	\N	2017-09-24 17:18:03
4010	MEMBRECOM	2005-12-15 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3090	\N	\N
4011	MEMBRECOM	2005-12-15 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3091	\N	\N
4012	MEMBRECOM	2005-12-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3092	\N	2014-09-28 13:40:33
4013	MEMBRECOM	2005-12-15 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3093	\N	\N
4014	VICPDTCOM	2005-12-13 00:00:00	2014-07-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3094	\N	2014-07-01 09:25:11
4015	RAPCOM	2005-12-13 00:00:00	2015-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3095	\N	2015-01-08 17:14:29
4016	MEMBRECOM	2005-12-13 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3096	\N	2014-09-28 13:16:32
4018	MEMBRECOM	2005-12-13 00:00:00	2015-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3098	\N	2015-06-12 15:59:49
4019	MEMBRECOM	2005-12-13 00:00:00	2012-05-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3099	\N	\N
4020	MEMBRECOM	2005-12-13 00:00:00	2018-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3100	\N	2018-05-31 10:52:17
4021	MEMBRECOM	2005-12-13 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3101	\N	\N
4022	MEMBRECOM	2005-12-13 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3102	\N	\N
4023	MEMBRECOM	2005-12-13 00:00:00	2016-12-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3103	\N	2016-12-12 16:10:15
4024	MEMBRECOM	2005-12-13 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3104	\N	\N
4025	MEMBRECOM	2005-12-13 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3105	\N	\N
4026	MEMBRECOM	2005-12-13 00:00:00	2010-10-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3106	\N	\N
4029	RAPCOM	2005-12-15 00:00:00	2015-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3109	\N	2015-06-12 16:01:25
4030	MEMBRECOM	2005-12-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3110	\N	2014-09-28 18:00:58
4031	MEMBRECOM	2005-12-15 00:00:00	2007-11-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3111	\N	\N
4032	MEMBRECOM	2005-12-15 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3112	\N	2017-09-24 13:29:42
4033	MEMBRECOM	2005-12-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3113	\N	2014-09-28 13:21:47
4034	MEMBRECOM	2005-12-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	3114	\N	\N
4036	MEMBRECOM	2005-12-15 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3116	\N	\N
4039	MEMBRECOM	2005-12-15 00:00:00	2015-04-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3119	\N	2015-04-21 17:14:30
4042	PDTCOM	2005-12-20 00:00:00	2014-07-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3122	\N	2014-07-01 09:25:11
4044	MEMBRECOM	2005-12-20 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3124	\N	2014-09-28 13:16:32
4045	MEMBRECOM	2005-12-20 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3125	\N	2014-09-28 16:59:41
4046	MEMBRECOM	2005-12-20 00:00:00	2015-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3126	\N	2015-06-12 15:59:49
4047	MEMBRECOM	2005-12-20 00:00:00	2013-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3127	\N	\N
4048	MEMBRECOM	2005-12-20 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3128	\N	\N
4049	MEMBRECOM	2005-12-20 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3129	\N	\N
4051	MEMBRECOM	2005-12-20 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3131	\N	2014-09-28 18:19:47
4052	MEMBRECOM	2005-12-20 00:00:00	2012-05-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3132	\N	\N
4053	MEMBRECOM	2005-12-20 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3133	\N	\N
4054	MEMBRECOM	2005-12-20 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3134	\N	\N
4055	MEMBRECOM	2005-12-20 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3135	\N	2014-09-28 18:03:38
4056	MEMBRECOM	1961-11-13 00:00:00	1962-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3136	\N	\N
4059	MEMBRECOM	2005-12-22 00:00:00	2006-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3139	\N	\N
4060	MEMBRECOM	2005-12-22 00:00:00	2006-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3140	\N	\N
4061	MEMBRECOM	2005-12-22 00:00:00	2006-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3141	\N	\N
4062	MEMBRECOM	2005-12-22 00:00:00	2006-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3142	\N	\N
4063	MEMBRECOM	2005-12-22 00:00:00	2006-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3143	\N	\N
4064	MEMBRECOM	2005-12-22 00:00:00	2006-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3144	\N	\N
4066	MEMBRECOM	2005-12-22 00:00:00	2006-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3146	\N	\N
4068	MEMBRECOM	2005-12-22 00:00:00	2006-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3148	\N	\N
4069	MEMBRECOM	2005-12-22 00:00:00	2006-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3150	\N	\N
4070	MEMBRECOM	2005-12-22 00:00:00	2006-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3151	\N	\N
4071	MEMBRECOM	2005-12-22 00:00:00	2006-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3152	\N	\N
4072	MEMBRECOM	2005-12-22 00:00:00	2006-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3153	\N	\N
4073	MEMBRECOM	2005-12-22 00:00:00	2006-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3154	\N	\N
4075	MEMBRECOM	2005-12-22 00:00:00	2006-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3156	\N	\N
4076	MEMBRECOM	2005-12-22 00:00:00	2006-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3157	\N	\N
4078	MEMBRECOM	2005-12-22 00:00:00	2006-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3159	\N	\N
4079	MEMBRECOM	2005-12-22 00:00:00	2006-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3160	\N	\N
4080	MEMBRECOM	2005-12-22 00:00:00	2006-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3161	\N	\N
4081	MEMBRECOM	2005-12-22 00:00:00	2006-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3162	\N	\N
4083	MEMBRECOM	2005-12-22 00:00:00	2006-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3164	\N	\N
4086	RAPCOM	2006-01-19 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3167	\N	2014-09-28 17:31:41
4088	MEMBRECOM	2006-01-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	3169	\N	\N
4089	MEMBRECOM	2006-01-19 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3170	\N	\N
4090	MEMBRECOM	2006-01-19 00:00:00	2014-09-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3171	\N	2014-09-01 10:21:13
4091	MEMBRECOM	2006-01-19 00:00:00	2007-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3172	\N	\N
4092	MEMBRECOM	2006-01-19 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3173	\N	2017-09-24 13:44:49
4093	MEMBRECOM	2006-01-19 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3174	\N	\N
4094	MEMBRECOM	2006-01-19 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3175	\N	2014-09-28 17:07:41
4095	MEMBRECOM	2006-01-19 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3176	\N	\N
4096	MEMBRECOM	2006-01-19 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3177	\N	\N
4097	MEMBRECOM	2006-01-19 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3178	\N	\N
4099	MEMBRECOM	2006-01-26 00:00:00	2011-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3180	\N	\N
4100	RAPCOM	2006-01-26 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3181	\N	\N
4101	MEMBRECOM	2006-01-26 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3182	\N	\N
4103	PDTCOM	2006-01-26 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3184	\N	2017-09-24 18:17:56
4104	MEMBRECOM	2006-01-26 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3185	\N	\N
4105	MEMBRECOM	2006-01-26 00:00:00	2007-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3186	\N	\N
4106	MEMBRECOM	2006-01-26 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3187	\N	\N
4109	MEMBRECOM	2006-01-26 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3190	\N	\N
4110	MEMBRECOM	2006-01-26 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3191	\N	\N
4111	MEMBRECOM	2006-01-26 00:00:00	2007-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3192	\N	\N
4112	MEMBRECOM	2006-01-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	3193	\N	\N
4113	VICPDTCOM	2006-02-08 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3194	\N	2014-09-28 18:58:21
4114	RAPCOM	2006-02-08 00:00:00	2014-11-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3195	\N	2014-11-04 11:22:47
4115	MEMBRECOM	2006-02-08 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3196	\N	\N
4116	MEMBRECOM	2006-02-08 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3197	\N	\N
4117	MEMBRECOM	2006-02-08 00:00:00	2007-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3198	\N	\N
4120	MEMBRECOM	2006-02-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3201	\N	2017-09-24 17:47:27
4121	MEMBRECOM	2006-02-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3202	\N	2017-09-24 17:19:42
4122	MEMBRECOM	2006-02-08 00:00:00	2017-05-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3203	\N	2017-05-16 15:18:13
4123	MEMBRECOM	2006-02-08 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3204	\N	2014-09-28 17:40:23
4124	MEMBRECOM	2006-02-08 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3205	\N	\N
4125	MEMBRECOM	2006-02-08 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3206	\N	\N
4128	RAPCOM	2006-01-23 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3209	\N	2017-09-24 17:47:27
4129	MEMBRECOM	2006-01-23 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3210	\N	2014-09-28 17:40:23
4130	MEMBRECOM	2006-01-23 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3211	\N	2014-09-28 12:56:42
4131	MEMBRECOM	2006-01-23 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3212	\N	2017-09-24 13:44:49
4132	MEMBRECOM	2006-01-23 00:00:00	2012-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3213	\N	\N
4653	PDTCOM	2007-07-31 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3737	\N	\N
4654	RAPCOM	2007-07-31 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3738	\N	\N
4655	MEMBRECOM	2007-07-31 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3739	\N	\N
4657	MEMBRECOM	2007-07-31 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3741	\N	\N
4658	MEMBRECOM	2007-07-31 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3742	\N	2014-09-28 17:07:41
4749	MEMBRECOM	2007-12-17 00:00:00	2008-01-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3833	\N	\N
4855	MEMBRECOM	1959-05-31 00:00:00	1959-07-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3940	\N	\N
4886	RAPCOM	2008-05-21 00:00:00	2008-06-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3973	\N	2014-09-28 12:21:28
4887	MEMBRECOM	2008-05-21 00:00:00	2008-06-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3974	\N	\N
5161	MEMBRECOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4244	\N	\N
5162	MEMBRECOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4245	\N	\N
5163	MEMBRECOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4246	\N	\N
5164	MEMBRECOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4247	\N	\N
5165	MEMBRECOM	2008-10-07 00:00:00	2013-07-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4248	\N	2013-07-15 18:30:23
5166	MEMBRECOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4249	\N	\N
5167	VICPDTCOM	2008-10-07 00:00:00	2011-09-30 00:00:00	3	ANCIEN	\N	\N	\N	\N	266	\N	\N
5168	MEMBRECOM	2008-10-07 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4250	\N	2014-09-28 17:07:07
5169	MEMBRECOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4251	\N	\N
5172	MEMBRECOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4253	\N	\N
5173	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4254	\N	\N
5174	MEMBRECOM	2008-10-07 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4255	\N	\N
5175	MEMBRECOM	2008-10-07 00:00:00	2010-03-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4256	\N	\N
5176	MEMBRECOM	2008-10-07 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4257	\N	\N
5177	MEMBRECOM	2008-10-07 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4258	\N	\N
5178	MEMBRECOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4259	\N	\N
5179	MEMBRECOM	2008-10-07 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4260	\N	\N
5180	MEMBRECOM	2008-10-07 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4262	\N	\N
5181	MEMBRECOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	260	\N	\N
5182	MEMBRECOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4263	\N	\N
5183	MEMBRECOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4264	\N	\N
5184	MEMBRECOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4265	\N	\N
5185	MEMBRECOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4266	\N	\N
5186	MEMBRECOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4267	\N	\N
5187	MEMBRECOM	2008-10-07 00:00:00	2009-07-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4268	\N	\N
5188	MEMBRECOM	2008-10-07 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4269	\N	2014-09-28 17:27:29
4295	MEMBRECOM	2006-11-23 00:00:00	2006-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3376	\N	\N
4297	MEMBRECOM	2006-11-23 00:00:00	2006-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3378	\N	\N
4298	MEMBRECOM	2006-11-23 00:00:00	2006-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3379	\N	\N
4299	MEMBRECOM	2006-11-23 00:00:00	2006-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3380	\N	2014-09-28 17:07:41
4300	MEMBRECOM	2006-11-23 00:00:00	2006-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3381	\N	\N
4301	MEMBRECOM	2006-11-23 00:00:00	2006-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3382	\N	\N
4302	MEMBRECOM	2006-11-23 00:00:00	2006-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3383	\N	\N
4303	MEMBRECOM	2006-11-23 00:00:00	2006-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3384	\N	\N
4304	MEMBRECOM	2006-11-23 00:00:00	2006-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3385	\N	\N
4365	MEMBRECOM	2006-12-19 00:00:00	2006-12-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3446	\N	\N
4439	MEMBRECOM	2007-01-25 00:00:00	2007-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3521	\N	\N
4440	MEMBRECOM	2007-01-25 00:00:00	2007-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3522	\N	\N
4441	MEMBRECOM	2007-01-25 00:00:00	2007-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3523	\N	2017-09-24 17:15:15
4443	PDTCOM	2007-01-25 00:00:00	2007-01-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3525	\N	\N
4444	RAPCOM	2007-01-25 00:00:00	2007-01-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3526	\N	2017-09-24 13:44:49
4445	MEMBRECOM	2007-01-25 00:00:00	2007-01-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3527	\N	\N
4446	MEMBRECOM	2007-01-25 00:00:00	2007-01-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3528	\N	\N
4447	MEMBRECOM	2007-01-25 00:00:00	2007-01-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3529	\N	\N
4449	MEMBRECOM	2007-01-25 00:00:00	2007-01-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3531	\N	2014-09-28 17:07:41
4450	MEMBRECOM	2007-01-25 00:00:00	2007-01-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3532	\N	\N
4451	MEMBRECOM	2007-01-25 00:00:00	2007-01-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3533	\N	\N
4452	MEMBRECOM	2007-01-25 00:00:00	2007-01-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3534	\N	\N
4453	MEMBRECOM	2007-01-25 00:00:00	2007-01-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3535	\N	2017-09-24 16:43:43
4454	MEMBRECOM	2007-01-25 00:00:00	2007-01-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3536	\N	\N
4455	MEMBRECOM	2007-01-25 00:00:00	2007-01-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3537	\N	\N
4456	MEMBRECOM	2007-01-25 00:00:00	2007-01-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3538	\N	\N
4532	MEMBRECOM	2007-02-20 00:00:00	2007-02-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3614	\N	2015-06-12 16:01:58
4533	MEMBRECOM	2007-02-20 00:00:00	2007-02-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3615	\N	\N
4534	MEMBRECOM	2007-02-20 00:00:00	2007-02-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3616	\N	\N
4535	MEMBRECOM	2007-02-20 00:00:00	2007-02-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3617	\N	\N
4536	MEMBRECOM	2007-02-20 00:00:00	2007-02-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3618	\N	2017-09-24 19:25:10
4537	MEMBRECOM	2007-02-20 00:00:00	2007-02-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3619	\N	\N
4538	MEMBRECOM	2007-02-20 00:00:00	2007-02-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3620	\N	2014-09-28 17:07:41
4540	MEMBRECOM	2007-02-20 00:00:00	2007-02-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3622	\N	\N
4542	MEMBRECOM	2007-02-20 00:00:00	2007-02-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3624	\N	2014-09-28 17:31:41
4607	VICPDTCOM	2007-09-19 00:00:00	2008-10-06 00:00:00	6	ANCIEN	\N	\N	\N	\N	2577	\N	\N
4608	VICPDTCOM	2007-09-19 00:00:00	2008-10-06 00:00:00	7	ANCIEN	\N	\N	\N	\N	3683	\N	\N
4609	MEMBRECOM	2007-09-19 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3693	\N	\N
4610	MEMBRECOM	2007-09-19 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3694	\N	\N
4661	MEMBRECOM	2007-07-31 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3745	\N	2014-09-28 17:55:39
4663	MEMBRECOM	2007-07-31 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3747	\N	\N
4664	MEMBRECOM	2007-07-31 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3748	\N	2014-09-28 13:40:33
4665	MEMBRECOM	2007-07-31 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3749	\N	\N
4666	MEMBRECOM	2007-07-31 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3750	\N	2014-09-01 10:21:13
4667	MEMBRECOM	2007-09-25 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3751	\N	\N
4668	MEMBRECOM	2007-09-25 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3752	\N	2014-10-09 13:56:44
4735	VICPDTCOM	2007-12-11 00:00:00	2007-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3819	\N	2014-07-01 09:25:11
4671	VICPDTCOM	2007-10-03 00:00:00	2008-10-06 00:00:00	8	ANCIEN	\N	\N	\N	\N	2546	\N	\N
4672	SECRETCOM	2007-10-03 00:00:00	2008-10-06 00:00:00	5	ANCIEN	\N	\N	\N	\N	2594	\N	\N
4736	RAPCOM	2007-12-11 00:00:00	2007-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3820	\N	2015-01-08 17:14:29
4737	MEMBRECOM	2007-12-11 00:00:00	2007-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3821	\N	2014-09-28 13:16:32
4738	MEMBRECOM	2007-12-11 00:00:00	2007-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3822	\N	2014-09-28 16:59:41
4740	MEMBRECOM	2007-12-11 00:00:00	2007-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3824	\N	\N
4742	MEMBRECOM	2007-12-11 00:00:00	2007-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3826	\N	\N
4743	MEMBRECOM	2007-12-11 00:00:00	2007-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3827	\N	\N
4745	MEMBRECOM	2007-12-11 00:00:00	2007-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3829	\N	\N
4746	MEMBRECOM	2007-12-11 00:00:00	2007-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3830	\N	\N
4747	MEMBRECOM	2007-12-11 00:00:00	2007-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3831	\N	\N
4748	MEMBRECOM	2007-12-11 00:00:00	2007-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3832	\N	\N
4779	MEMBRECOM	2008-01-10 00:00:00	2008-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3864	\N	\N
4781	MEMBRECOM	2008-01-10 00:00:00	2008-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3866	\N	\N
4782	MEMBRECOM	2008-01-10 00:00:00	2008-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3867	\N	\N
4784	MEMBRECOM	2008-01-10 00:00:00	2008-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3869	\N	\N
4785	MEMBRECOM	2008-01-10 00:00:00	2008-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3870	\N	\N
4787	MEMBRECOM	2008-01-10 00:00:00	2008-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3872	\N	\N
4788	MEMBRECOM	2008-01-10 00:00:00	2008-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3873	\N	\N
4789	MEMBRECOM	2008-01-10 00:00:00	2008-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3874	\N	\N
4791	MEMBRECOM	2008-01-10 00:00:00	2008-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3877	\N	\N
4792	MEMBRECOM	2008-01-10 00:00:00	2008-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3878	\N	\N
4794	MEMBRECOM	2008-01-10 00:00:00	2008-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3880	\N	\N
4796	MEMBRECOM	2008-01-10 00:00:00	2008-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3882	\N	\N
4797	MEMBRECOM	2008-01-10 00:00:00	2008-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3883	\N	\N
4276	PDTCOM	2006-10-30 00:00:00	2006-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3357	\N	2014-09-28 18:58:21
4277	RAPCOM	2006-10-30 00:00:00	2006-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3358	\N	\N
4285	MEMBRECOM	2006-10-30 00:00:00	2006-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3366	\N	\N
4287	MEMBRECOM	2006-10-30 00:00:00	2006-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3368	\N	\N
4428	MEMBRECOM	2007-02-07 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3510	\N	\N
4606	MEMBRECOM	2007-09-19 00:00:00	2007-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3692	\N	\N
4741	MEMBRECOM	2007-12-11 00:00:00	2007-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3825	\N	2018-05-31 10:52:17
4800	MEMBRECOM	2008-01-10 00:00:00	2008-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3886	\N	\N
4801	MEMBRECOM	2008-01-10 00:00:00	2008-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3887	\N	\N
4802	MEMBRECOM	2008-01-10 00:00:00	2008-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3888	\N	\N
4834	MEMBRECOM	2008-01-24 00:00:00	2008-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3919	\N	\N
4835	MEMBRECOM	2008-01-24 00:00:00	2008-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3920	\N	\N
4836	MEMBRECOM	2008-01-24 00:00:00	2008-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3921	\N	\N
4838	MEMBRECOM	2008-01-24 00:00:00	2008-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3923	\N	\N
4840	RAPCOM	2008-01-31 00:00:00	2008-02-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3925	\N	2015-04-21 17:14:30
4852	MEMBRECOM	2008-01-31 00:00:00	2008-02-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3937	\N	2017-09-24 13:29:42
4877	MEMBRECOM	2008-05-14 00:00:00	2008-05-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3964	\N	\N
4958	MEMBRECOM	2008-07-02 00:00:00	2008-07-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4043	\N	2014-09-28 17:09:16
4959	MEMBRECOM	2008-07-02 00:00:00	2008-07-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4044	\N	\N
4960	MEMBRECOM	2008-07-02 00:00:00	2008-07-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4045	\N	2017-09-24 17:14:26
4961	MEMBRECOM	2008-07-02 00:00:00	2008-07-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4046	\N	2017-09-24 13:44:49
4962	MEMBRECOM	2008-07-02 00:00:00	2008-07-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4047	\N	2017-09-24 17:19:42
4963	MEMBRECOM	2008-07-02 00:00:00	2008-07-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4048	\N	2017-05-16 15:18:13
4964	MEMBRECOM	2008-07-02 00:00:00	2008-07-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4049	\N	\N
4966	MEMBRECOM	2008-07-02 00:00:00	2008-07-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4051	\N	\N
4968	MEMBRECOM	2008-07-10 00:00:00	2008-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4053	\N	\N
4969	RAPCOM	2008-07-10 00:00:00	2008-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4054	\N	\N
4970	MEMBRECOM	2008-07-10 00:00:00	2008-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4055	\N	2015-01-08 17:14:29
4971	MEMBRECOM	2008-07-10 00:00:00	2008-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4056	\N	\N
4972	MEMBRECOM	2008-07-10 00:00:00	2008-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4057	\N	2017-09-24 17:09:24
4973	MEMBRECOM	2008-07-10 00:00:00	2008-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4058	\N	\N
4974	MEMBRECOM	2008-07-10 00:00:00	2008-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4059	\N	2017-09-24 19:25:10
4975	MEMBRECOM	2008-07-10 00:00:00	2008-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4060	\N	\N
4976	MEMBRECOM	2008-07-10 00:00:00	2008-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4061	\N	\N
4977	MEMBRECOM	2008-07-10 00:00:00	2008-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4062	\N	\N
4978	MEMBRECOM	2008-07-10 00:00:00	2008-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4063	\N	\N
4675	PDTCOM	2007-10-11 00:00:00	2007-10-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3756	\N	2015-10-12 09:39:30
4676	RAPCOM	2007-10-11 00:00:00	2007-10-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3757	\N	\N
4677	MEMBRECOM	2007-10-11 00:00:00	2007-10-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3758	\N	2014-09-28 18:00:58
4678	MEMBRECOM	2007-10-11 00:00:00	2007-10-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3759	\N	2015-06-12 16:01:25
4679	MEMBRECOM	2007-10-11 00:00:00	2007-10-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3760	\N	\N
4680	MEMBRECOM	2007-10-11 00:00:00	2007-10-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3761	\N	\N
4681	MEMBRECOM	2007-10-11 00:00:00	2007-10-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3762	\N	\N
3628	MEMBRECOM	2004-12-14 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2716	\N	\N
3631	MEMBRECOM	2004-12-14 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2719	\N	\N
3632	MEMBRECOM	2004-12-14 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2720	\N	2014-09-28 18:19:47
3633	MEMBRECOM	2004-12-14 00:00:00	2012-05-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2721	\N	\N
3634	MEMBRECOM	2004-12-14 00:00:00	2010-03-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2722	\N	\N
3635	MEMBRECOM	2004-12-14 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2723	\N	\N
3637	MEMBRECOM	2004-12-24 00:00:00	2005-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2725	\N	\N
3638	PDTCOM	2004-12-20 00:00:00	2014-07-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2726	\N	2014-07-01 09:25:11
3639	RAPCOM	2004-12-20 00:00:00	2015-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2727	\N	2015-01-08 17:14:29
3640	MEMBRECOM	2004-12-20 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2728	\N	2014-09-28 13:16:32
3642	MEMBRECOM	2004-12-20 00:00:00	2015-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2730	\N	2015-06-12 15:59:49
3643	MEMBRECOM	2004-12-20 00:00:00	2013-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2731	\N	\N
3644	MEMBRECOM	2004-12-20 00:00:00	2018-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2732	\N	2018-05-31 10:52:17
3646	MEMBRECOM	2004-12-20 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2734	\N	\N
3647	MEMBRECOM	2004-12-20 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2735	\N	\N
3648	MEMBRECOM	2004-12-20 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2736	\N	2014-09-28 18:19:47
3649	MEMBRECOM	2004-12-20 00:00:00	2012-05-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2737	\N	\N
3650	MEMBRECOM	2004-12-20 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2738	\N	\N
3652	PDTCOM	2004-10-20 00:00:00	2015-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2740	\N	2015-10-12 09:39:30
3654	MEMBRECOM	2004-10-20 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2742	\N	\N
3656	MEMBRECOM	2004-10-20 00:00:00	2015-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2744	\N	2015-01-08 17:14:29
3657	MEMBRECOM	2004-10-20 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	2745	\N	\N
3659	MEMBRECOM	2004-10-20 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2747	\N	2014-09-28 12:09:44
3660	MEMBRECOM	2004-10-20 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2748	\N	\N
3662	MEMBRECOM	2004-10-20 00:00:00	2008-09-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2750	\N	\N
3664	MEMBRECOM	2004-10-20 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2752	\N	2014-09-28 18:00:58
3665	MEMBRECOM	2004-10-20 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2753	\N	\N
3666	MEMBRECOM	2005-01-19 00:00:00	2006-06-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2754	\N	\N
3668	MEMBRECOM	2005-02-02 00:00:00	2005-10-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2758	\N	\N
3669	MEMBRECOM	2005-02-02 00:00:00	2005-10-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2759	\N	\N
3670	MEMBRECOM	2005-02-02 00:00:00	2005-10-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2760	\N	\N
3672	MEMBRECOM	2005-02-02 00:00:00	2005-10-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2762	\N	\N
3673	MEMBRECOM	2005-02-02 00:00:00	2005-10-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2763	\N	\N
3675	MEMBRECOM	2005-02-02 00:00:00	2005-10-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2765	\N	\N
3676	MEMBRECOM	2005-02-02 00:00:00	2005-10-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2766	\N	\N
3678	MEMBRECOM	2005-02-02 00:00:00	2005-10-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2768	\N	\N
3679	MEMBRECOM	2005-02-02 00:00:00	2005-10-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2769	\N	\N
3680	MEMBRECOM	2005-02-02 00:00:00	2005-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2770	\N	\N
3681	MEMBRECOM	2005-02-02 00:00:00	2005-10-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2771	\N	\N
3682	MEMBRECOM	2005-02-02 00:00:00	2005-10-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2772	\N	\N
3684	MEMBRECOM	2005-02-02 00:00:00	2005-10-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2774	\N	\N
3685	MEMBRECOM	2005-02-02 00:00:00	2005-10-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2775	\N	\N
3686	MEMBRECOM	2005-02-02 00:00:00	2005-10-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2776	\N	\N
3688	MEMBRECOM	2005-02-02 00:00:00	2005-10-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2778	\N	\N
3689	MEMBRECOM	2005-02-02 00:00:00	2005-10-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2779	\N	\N
3690	MEMBRECOM	2005-02-02 00:00:00	2005-10-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2780	\N	\N
3691	MEMBRECOM	2005-02-02 00:00:00	2005-10-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2781	\N	\N
3692	MEMBRECOM	2005-02-02 00:00:00	2005-10-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2782	\N	\N
3694	MEMBRECOM	2005-02-02 00:00:00	2005-10-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2784	\N	\N
3695	MEMBRECOM	2005-02-21 00:00:00	2005-02-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2785	\N	\N
3697	MEMBRECOM	2005-02-21 00:00:00	2005-02-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2787	\N	\N
3698	MEMBRECOM	2005-02-21 00:00:00	2005-02-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2788	\N	\N
3699	MEMBRECOM	2005-02-21 00:00:00	2005-02-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2789	\N	\N
3700	MEMBRECOM	2005-01-19 00:00:00	2011-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2790	\N	\N
3701	MEMBRECOM	2005-01-19 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2791	\N	\N
3702	MEMBRECOM	2005-01-19 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2792	\N	\N
3703	MEMBRECOM	2005-01-19 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2793	\N	\N
3704	MEMBRECOM	2005-01-19 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2794	\N	\N
3705	MEMBRECOM	2005-01-19 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2795	\N	2017-09-24 16:43:43
3706	MEMBRECOM	2005-01-19 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2796	\N	2014-09-28 17:07:41
3707	MEMBRECOM	2005-01-19 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2797	\N	2017-09-24 13:44:49
3708	MEMBRECOM	2005-01-19 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2798	\N	\N
3709	MEMBRECOM	2005-01-19 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2799	\N	\N
3710	MEMBRECOM	2005-01-19 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2800	\N	\N
3712	MEMBRECOM	2005-01-19 00:00:00	2007-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2802	\N	\N
3713	MEMBRECOM	2005-01-19 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2803	\N	\N
3714	MEMBRECOM	2005-01-27 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2804	\N	2014-09-28 18:58:21
3715	MEMBRECOM	2005-01-27 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2805	\N	\N
3716	MEMBRECOM	2005-01-27 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2806	\N	2017-10-01 10:01:39
3718	MEMBRECOM	2005-01-27 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2808	\N	\N
3719	MEMBRECOM	2005-01-27 00:00:00	2012-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2809	\N	\N
3721	MEMBRECOM	2005-01-27 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2811	\N	2014-09-28 16:42:05
3722	MEMBRECOM	2005-01-27 00:00:00	2017-05-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2812	\N	2017-05-16 15:18:13
3723	MEMBRECOM	2005-01-27 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2813	\N	2014-09-28 17:38:26
3724	MEMBRECOM	2005-01-27 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2814	\N	\N
3725	MEMBRECOM	2005-01-27 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2815	\N	2014-09-28 13:39:20
3726	MEMBRECOM	2005-01-27 00:00:00	2019-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2816	\N	\N
3727	MEMBRECOM	2005-01-27 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2817	\N	\N
3729	MEMBRECOM	2005-03-01 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2819	\N	\N
3730	MEMBRECOM	2005-03-01 00:00:00	2005-03-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2820	\N	\N
3732	MEMBRECOM	2005-03-01 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2822	\N	\N
3733	MEMBRECOM	2005-03-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2823	\N	\N
3734	MEMBRECOM	2005-03-01 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2824	\N	\N
3735	MEMBRECOM	2005-03-10 00:00:00	2008-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2825	\N	\N
3736	MEMBRECOM	2005-03-10 00:00:00	2007-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2826	\N	\N
3737	SECRETCOM	2005-03-09 00:00:00	2008-10-06 00:00:00	2	ANCIEN	\N	\N	\N	\N	2820	\N	\N
3738	MEMBRECOM	2005-03-15 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2827	\N	\N
3740	MEMBRECOM	2005-05-04 00:00:00	2005-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2829	\N	\N
3741	PDTCOM	2005-03-19 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2830	\N	\N
3742	RAPCOM	2005-03-19 00:00:00	2018-08-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2831	\N	\N
3743	MEMBRECOM	2005-03-19 00:00:00	2011-03-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2832	\N	\N
3744	MEMBRECOM	2005-03-19 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2833	\N	2017-09-24 18:16:52
3745	MEMBRECOM	2005-03-19 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2834	\N	\N
3746	MEMBRECOM	2005-03-19 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2835	\N	\N
3748	MEMBRECOM	2005-03-19 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2837	\N	\N
3750	MEMBRECOM	2005-03-19 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2839	\N	2014-09-28 17:09:16
3751	MEMBRECOM	2005-03-19 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2840	\N	\N
3752	MEMBRECOM	2005-03-19 00:00:00	2010-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2841	\N	\N
3754	MEMBRECOM	2005-03-19 00:00:00	2014-12-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2843	\N	2014-12-18 16:15:04
3755	VICPDTCOM	2005-05-03 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2844	\N	2014-09-28 18:58:21
3756	RAPCOM	2005-05-03 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2845	\N	2014-09-28 17:40:23
3757	MEMBRECOM	2005-05-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	2846	\N	\N
3758	MEMBRECOM	2005-05-03 00:00:00	2007-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2847	\N	\N
3759	MEMBRECOM	2005-05-03 00:00:00	2006-06-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2848	\N	\N
3760	MEMBRECOM	2005-05-03 00:00:00	2012-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2849	\N	\N
3761	MEMBRECOM	2005-05-03 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2850	\N	\N
3762	MEMBRECOM	2005-05-03 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2851	\N	2014-09-28 17:12:41
3763	MEMBRECOM	2005-05-03 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2852	\N	2017-09-24 17:18:03
3764	MEMBRECOM	2005-05-03 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2853	\N	\N
3765	MEMBRECOM	2005-05-03 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2854	\N	\N
3766	MEMBRECOM	2005-05-03 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2855	\N	2014-09-28 16:50:17
3767	MEMBRECOM	2005-05-03 00:00:00	2019-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2856	\N	\N
3768	MEMBRECOM	2005-05-03 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2857	\N	\N
3770	RAPCOM	2005-05-04 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2859	\N	\N
3773	MEMBRECOM	2005-05-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	2862	\N	\N
3774	MEMBRECOM	2005-05-04 00:00:00	2014-09-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2863	\N	2014-09-01 10:21:13
3775	MEMBRECOM	2005-05-04 00:00:00	2007-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2864	\N	\N
3776	MEMBRECOM	2005-05-04 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2865	\N	\N
3779	MEMBRECOM	2005-05-04 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2868	\N	2014-09-28 17:07:41
3780	MEMBRECOM	2005-05-04 00:00:00	2007-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2869	\N	\N
3781	MEMBRECOM	2005-05-04 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2870	\N	\N
3782	MEMBRECOM	2005-05-04 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2871	\N	\N
3786	MEMBRECOM	2005-05-11 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2875	\N	\N
3787	MEMBRECOM	2005-05-11 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2876	\N	2014-09-28 17:09:16
3788	MEMBRECOM	2005-05-11 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2877	\N	2017-09-24 17:09:24
3479	MEMBRECOM	2004-10-06 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2630	\N	\N
3320	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2470	\N	\N
3480	MEMBRECOM	2004-10-06 00:00:00	2008-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2631	\N	\N
3481	MEMBRECOM	2004-10-06 00:00:00	2004-11-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2632	\N	\N
3482	MEMBRECOM	2004-10-06 00:00:00	2005-03-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2633	\N	\N
3359	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2508	\N	\N
3317	MEMBRECOM	2004-10-01 00:00:00	2004-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2467	\N	\N
3367	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2516	\N	\N
3307	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2457	\N	\N
758	MEMBRECOM	2001-10-03 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	657	\N	\N
3310	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2460	\N	\N
3345	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2494	\N	\N
3311	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2461	\N	\N
3351	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2500	\N	\N
3348	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2497	\N	\N
3319	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2469	\N	\N
3312	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2462	\N	\N
3352	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2501	\N	\N
3350	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2499	\N	\N
3483	MEMBRECOM	2004-10-06 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2634	\N	\N
3484	MEMBRECOM	2004-10-06 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2635	\N	\N
3485	MEMBRECOM	2004-10-06 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2636	\N	\N
3486	PDTCOM	2004-10-07 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	90	\N	\N
3487	VICPDTCOM	2004-10-07 00:00:00	2008-10-06 00:00:00	1	ANCIEN	\N	\N	\N	\N	35	\N	\N
3488	VICPDTCOM	2004-10-07 00:00:00	2008-10-06 00:00:00	3	ANCIEN	\N	\N	\N	\N	266	\N	\N
3489	VICPDTCOM	2004-10-07 00:00:00	2008-10-06 00:00:00	4	ANCIEN	\N	\N	\N	\N	407	\N	\N
3491	SECRETCOM	2004-10-07 00:00:00	2008-10-06 00:00:00	3	ANCIEN	\N	\N	\N	\N	258	\N	\N
3492	SECRETCOM	2004-10-07 00:00:00	2008-10-06 00:00:00	4	ANCIEN	\N	\N	\N	\N	2560	\N	\N
3493	SECRETCOM	2004-10-07 00:00:00	2008-10-06 00:00:00	5	ANCIEN	\N	\N	\N	\N	726	\N	\N
3494	MEMBRECOM	2004-10-07 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13	\N	\N
3495	VICPDTCOM	2004-10-07 00:00:00	2008-10-06 00:00:00	1	ANCIEN	\N	\N	\N	\N	260	\N	\N
3496	VICPDTCOM	2004-10-07 00:00:00	2008-10-06 00:00:00	4	ANCIEN	\N	\N	\N	\N	439	\N	\N
4133	MEMBRECOM	2006-01-23 00:00:00	2010-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3214	\N	\N
4134	MEMBRECOM	2006-01-23 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3215	\N	2017-09-24 18:16:52
4135	MEMBRECOM	2006-01-23 00:00:00	2017-05-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3216	\N	2017-05-16 15:18:13
4136	MEMBRECOM	2006-01-23 00:00:00	2007-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3217	\N	\N
4137	MEMBRECOM	2006-01-23 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3218	\N	\N
4139	MEMBRECOM	2006-01-23 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3220	\N	\N
4140	MEMBRECOM	2006-01-23 00:00:00	2019-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3221	\N	\N
4141	PDTCOM	2006-02-28 00:00:00	2015-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3222	\N	2015-10-12 09:39:30
4142	RAPCOM	2006-02-28 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3223	\N	\N
4143	MEMBRECOM	2006-02-28 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3224	\N	2014-09-28 18:00:58
4144	MEMBRECOM	2006-02-28 00:00:00	2007-11-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3225	\N	\N
4145	MEMBRECOM	2006-02-28 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3226	\N	2017-09-24 13:29:42
4146	MEMBRECOM	2006-02-28 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3227	\N	2017-09-24 18:20:10
4147	MEMBRECOM	2006-02-28 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3228	\N	\N
4148	MEMBRECOM	2006-02-28 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3229	\N	2014-09-28 12:09:44
4150	MEMBRECOM	2006-02-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	3231	\N	\N
4151	MEMBRECOM	2006-02-28 00:00:00	2015-04-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3232	\N	2015-04-21 17:14:30
4154	MEMBRECOM	2006-02-28 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3235	\N	\N
4155	VICPDTCOM	2006-03-05 00:00:00	2011-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3236	\N	\N
4156	RAPCOM	2006-03-05 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3237	\N	2017-09-24 18:17:56
4158	MEMBRECOM	2006-03-05 00:00:00	2021-07-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3239	\N	\N
4160	MEMBRECOM	2006-03-05 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3241	\N	2017-09-24 16:43:43
4161	MEMBRECOM	2006-03-05 00:00:00	2007-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3242	\N	\N
4162	MEMBRECOM	2006-03-05 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3243	\N	\N
4163	MEMBRECOM	2006-03-05 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3244	\N	2014-09-28 17:07:41
4164	MEMBRECOM	2006-03-05 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3245	\N	\N
4165	MEMBRECOM	2006-03-05 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3246	\N	\N
4166	MEMBRECOM	2006-03-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	3247	\N	\N
4169	RAPCOM	2006-03-07 00:00:00	2006-03-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3250	\N	\N
4170	MEMBRECOM	2006-03-07 00:00:00	2006-03-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3251	\N	\N
4171	PDTCOM	2006-03-07 00:00:00	2006-03-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3252	\N	\N
4172	MEMBRECOM	2006-03-07 00:00:00	2006-03-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3253	\N	2014-09-28 17:22:11
4173	MEMBRECOM	2006-03-07 00:00:00	2006-03-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3254	\N	2014-09-28 17:31:42
4176	MEMBRECOM	2006-03-07 00:00:00	2006-03-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3257	\N	\N
4177	MEMBRECOM	2006-03-07 00:00:00	2006-03-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3258	\N	2017-07-04 15:08:09
4178	MEMBRECOM	2006-03-07 00:00:00	2006-03-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3259	\N	\N
4179	MEMBRECOM	2006-03-07 00:00:00	2006-03-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3260	\N	\N
4180	MEMBRECOM	2006-03-07 00:00:00	2006-03-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3261	\N	\N
4182	MEMBRECOM	2006-03-07 00:00:00	2006-03-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3263	\N	\N
4183	VICPDTCOM	2006-04-05 00:00:00	2006-04-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3264	\N	2015-10-12 09:39:30
4184	RAPCOM	2006-04-05 00:00:00	2006-04-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3265	\N	\N
4185	MEMBRECOM	2006-04-05 00:00:00	2006-04-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3266	\N	\N
4186	MEMBRECOM	2006-04-05 00:00:00	2006-04-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3267	\N	2014-09-28 16:59:41
4187	MEMBRECOM	2006-04-05 00:00:00	2006-04-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3268	\N	\N
4188	MEMBRECOM	2006-04-05 00:00:00	2006-04-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3269	\N	\N
4189	MEMBRECOM	2006-04-05 00:00:00	2006-04-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3270	\N	\N
4190	MEMBRECOM	2006-04-05 00:00:00	2006-04-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3271	\N	\N
4191	MEMBRECOM	2006-04-05 00:00:00	2006-04-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3272	\N	2017-09-24 13:29:42
4192	MEMBRECOM	2006-04-05 00:00:00	2006-04-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3273	\N	\N
4193	MEMBRECOM	2006-04-05 00:00:00	2006-04-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3274	\N	\N
4194	MEMBRECOM	2006-04-05 00:00:00	2006-04-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3275	\N	2014-09-28 18:00:58
4195	MEMBRECOM	2006-04-05 00:00:00	2006-04-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3276	\N	2015-04-21 17:14:30
4196	MEMBRECOM	2006-04-05 00:00:00	2006-04-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3277	\N	\N
4197	MEMBRECOM	2006-05-17 00:00:00	2006-06-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3278	\N	\N
4201	MEMBRECOM	2006-06-06 00:00:00	2006-06-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3282	\N	\N
4205	MEMBRECOM	2006-06-15 00:00:00	2007-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3286	\N	\N
4206	MEMBRECOM	2006-06-15 00:00:00	2007-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3287	\N	\N
4208	MEMBRECOM	2006-06-15 00:00:00	2007-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3289	\N	\N
4209	MEMBRECOM	2006-06-15 00:00:00	2007-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3290	\N	\N
4211	MEMBRECOM	2006-06-15 00:00:00	2007-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3292	\N	\N
4212	MEMBRECOM	2006-06-15 00:00:00	2007-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3293	\N	\N
4213	MEMBRECOM	2006-06-15 00:00:00	2007-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3294	\N	\N
4214	MEMBRECOM	2006-06-15 00:00:00	2007-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3295	\N	\N
4216	MEMBRECOM	2006-06-15 00:00:00	2007-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3297	\N	\N
4217	MEMBRECOM	2006-06-15 00:00:00	2007-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3298	\N	\N
4219	MEMBRECOM	2006-06-15 00:00:00	2007-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3300	\N	\N
4548	MEMBRECOM	2007-06-26 00:00:00	2007-11-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3630	\N	\N
4549	MEMBRECOM	2007-06-26 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3631	\N	2017-10-04 18:57:28
4551	MEMBRECOM	2007-06-26 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3633	\N	2014-10-09 10:45:49
4579	MEMBRECOM	2007-07-05 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3661	\N	\N
4580	MEMBRECOM	2007-07-05 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3662	\N	\N
4582	MEMBRECOM	2007-07-05 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3664	\N	\N
4583	MEMBRECOM	2007-07-05 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3665	\N	\N
4584	MEMBRECOM	2007-07-05 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3666	\N	\N
4585	MEMBRECOM	2007-07-05 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3667	\N	\N
4586	MEMBRECOM	2007-07-05 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3668	\N	\N
4270	MEMBRECOM	2006-07-09 00:00:00	2006-09-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3351	\N	\N
4323	MEMBRECOM	2007-01-03 00:00:00	2007-01-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3404	\N	\N
4324	MEMBRECOM	2007-01-02 00:00:00	2007-01-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3405	\N	\N
4587	MEMBRECOM	2007-07-05 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3669	\N	\N
4590	MEMBRECOM	2007-07-05 00:00:00	2007-07-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3672	\N	\N
4591	MEMBRECOM	2007-07-11 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3673	\N	\N
4597	MEMBRECOM	2007-07-11 00:00:00	2007-09-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3683	\N	\N
4600	MEMBRECOM	2007-07-27 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3686	\N	\N
4601	MEMBRECOM	2007-07-25 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3687	\N	\N
4603	MEMBRECOM	2007-09-18 00:00:00	2007-09-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3689	\N	\N
4604	MEMBRECOM	2007-09-18 00:00:00	2007-09-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3690	\N	\N
4612	RAPCOM	2007-07-19 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3696	\N	2017-09-24 13:29:42
4613	MEMBRECOM	2007-07-19 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3697	\N	2014-09-28 18:00:58
4614	MEMBRECOM	2007-07-19 00:00:00	2015-04-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3698	\N	2015-04-21 17:14:30
4615	MEMBRECOM	2007-07-19 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3699	\N	2017-09-24 17:15:15
4616	MEMBRECOM	2007-07-19 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3700	\N	\N
4618	MEMBRECOM	2007-07-19 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3702	\N	2014-09-28 12:09:44
4619	MEMBRECOM	2007-07-19 00:00:00	2014-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3703	\N	2014-09-29 13:41:53
4620	MEMBRECOM	2007-07-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	3704	\N	\N
4621	MEMBRECOM	2007-07-19 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3705	\N	\N
4622	MEMBRECOM	2007-07-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	3706	\N	\N
4623	MEMBRECOM	2007-07-19 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3707	\N	\N
4624	MEMBRECOM	2007-07-19 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3708	\N	\N
4220	MEMBRECOM	2006-06-15 00:00:00	2007-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3301	\N	\N
4223	MEMBRECOM	2006-06-15 00:00:00	2007-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3304	\N	\N
4224	MEMBRECOM	2006-06-15 00:00:00	2007-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3305	\N	\N
4225	MEMBRECOM	2006-06-15 00:00:00	2006-06-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3306	\N	\N
4227	RAPCOM	2006-06-08 00:00:00	2006-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3308	\N	\N
4229	MEMBRECOM	2006-06-08 00:00:00	2006-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3310	\N	\N
4230	MEMBRECOM	2006-06-08 00:00:00	2006-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3311	\N	\N
4231	MEMBRECOM	2006-06-08 00:00:00	2006-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3312	\N	\N
4232	MEMBRECOM	2006-06-08 00:00:00	2006-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3313	\N	2017-09-24 17:47:28
4234	MEMBRECOM	2006-06-08 00:00:00	2006-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3315	\N	2014-09-28 17:15:42
4235	MEMBRECOM	2006-06-08 00:00:00	2006-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3316	\N	\N
4236	MEMBRECOM	2006-06-08 00:00:00	2006-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3317	\N	2017-09-24 18:16:52
4237	MEMBRECOM	2006-06-08 00:00:00	2006-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3318	\N	2014-09-28 17:40:23
4238	MEMBRECOM	2006-06-08 00:00:00	2006-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3319	\N	\N
4240	PDTCOM	2006-06-16 00:00:00	2006-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3321	\N	2015-10-12 09:39:31
4241	RAPCOM	2006-06-16 00:00:00	2006-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3322	\N	\N
4243	MEMBRECOM	2006-06-16 00:00:00	2006-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3324	\N	2015-06-12 16:01:25
4244	MEMBRECOM	2006-06-16 00:00:00	2006-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3325	\N	2017-09-24 13:29:42
4245	MEMBRECOM	2006-06-16 00:00:00	2006-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3326	\N	\N
4246	MEMBRECOM	2006-06-16 00:00:00	2006-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3327	\N	\N
4247	MEMBRECOM	2006-06-16 00:00:00	2006-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3328	\N	\N
4248	MEMBRECOM	2006-06-16 00:00:00	2006-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3329	\N	\N
4250	MEMBRECOM	2006-06-16 00:00:00	2006-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3331	\N	2015-04-21 17:14:30
4251	MEMBRECOM	2006-06-16 00:00:00	2006-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3332	\N	\N
4254	VICPDTCOM	2006-06-15 00:00:00	2006-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3335	\N	\N
4255	RAPCOM	2006-06-15 00:00:00	2006-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3336	\N	\N
4256	MEMBRECOM	2006-06-15 00:00:00	2006-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3337	\N	2014-09-28 17:35:38
4258	MEMBRECOM	2006-06-15 00:00:00	2006-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3339	\N	\N
4259	MEMBRECOM	2006-06-15 00:00:00	2006-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3340	\N	\N
4261	MEMBRECOM	2006-06-15 00:00:00	2006-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3342	\N	2017-07-04 15:08:09
4262	MEMBRECOM	2006-06-15 00:00:00	2006-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3343	\N	\N
4263	MEMBRECOM	2006-06-15 00:00:00	2006-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3344	\N	\N
4264	MEMBRECOM	2006-06-15 00:00:00	2006-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3345	\N	2014-09-28 17:22:11
4266	MEMBRECOM	2006-06-15 00:00:00	2006-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3347	\N	\N
4267	MEMBRECOM	2006-06-15 00:00:00	2006-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3348	\N	\N
4269	MEMBRECOM	2006-06-30 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3350	\N	\N
4272	MEMBRECOM	2006-09-07 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3353	\N	\N
4273	MEMBRECOM	2006-09-07 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3354	\N	\N
4274	MEMBRECOM	2006-09-25 00:00:00	2006-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3355	\N	\N
4278	MEMBRECOM	2006-10-30 00:00:00	2006-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3359	\N	2015-01-08 17:14:29
4279	MEMBRECOM	2006-10-30 00:00:00	2006-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3360	\N	\N
4280	MEMBRECOM	2006-10-30 00:00:00	2006-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3361	\N	2014-09-28 17:09:16
4281	MEMBRECOM	2006-10-30 00:00:00	2006-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3362	\N	2017-09-24 17:09:24
4282	MEMBRECOM	2006-10-30 00:00:00	2006-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3363	\N	2014-09-28 16:50:17
4283	MEMBRECOM	2006-10-30 00:00:00	2006-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3364	\N	2014-09-28 17:55:39
4284	MEMBRECOM	2006-10-30 00:00:00	2006-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3365	\N	\N
4286	MEMBRECOM	2006-10-30 00:00:00	2006-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3367	\N	\N
4289	MEMBRECOM	2006-10-30 00:00:00	2006-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3370	\N	\N
3899	MEMBRECOM	2005-10-27 00:00:00	2006-03-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2988	\N	\N
3903	MEMBRECOM	2005-10-27 00:00:00	2006-03-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2992	\N	\N
3906	MEMBRECOM	2005-10-27 00:00:00	2006-03-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2995	\N	\N
3909	SECRETCOM	2005-11-24 00:00:00	2006-03-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2998	\N	\N
3912	MEMBRECOM	2005-10-27 00:00:00	2006-03-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3001	\N	\N
3916	PDTCOM	2005-11-24 00:00:00	2006-03-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3005	\N	\N
4294	MEMBRECOM	2006-11-23 00:00:00	2006-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3375	\N	2014-09-28 17:35:38
4305	PDTCOM	2006-11-17 00:00:00	2006-11-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3386	\N	\N
4311	MEMBRECOM	2006-11-17 00:00:00	2006-11-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3392	\N	\N
4313	MEMBRECOM	2006-11-17 00:00:00	2006-11-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3394	\N	\N
4314	MEMBRECOM	2006-11-17 00:00:00	2006-11-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3395	\N	2014-09-28 17:07:41
4315	MEMBRECOM	2006-11-17 00:00:00	2006-11-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3396	\N	\N
4317	MEMBRECOM	2006-11-17 00:00:00	2006-11-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3398	\N	\N
4318	MEMBRECOM	2006-11-17 00:00:00	2006-11-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3399	\N	\N
4320	MEMBRECOM	2006-12-15 00:00:00	2007-01-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3401	\N	\N
4321	MEMBRECOM	2006-12-15 00:00:00	2007-01-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3402	\N	\N
4322	MEMBRECOM	2005-12-22 00:00:00	2006-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3165	\N	\N
4339	VICPDTCOM	2006-12-14 00:00:00	2006-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3420	\N	2014-09-28 18:58:21
4341	MEMBRECOM	2006-12-14 00:00:00	2006-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3422	\N	2015-06-12 16:01:58
4342	MEMBRECOM	2006-12-14 00:00:00	2006-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3423	\N	\N
4345	MEMBRECOM	2006-12-14 00:00:00	2006-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3426	\N	\N
4346	MEMBRECOM	2006-12-14 00:00:00	2006-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3427	\N	2017-09-24 17:19:42
4275	MEMBRECOM	2006-10-03 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3356	\N	\N
4349	MEMBRECOM	2006-12-14 00:00:00	2006-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3430	\N	\N
4350	MEMBRECOM	2006-12-14 00:00:00	2006-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3431	\N	\N
4351	MEMBRECOM	2006-12-14 00:00:00	2006-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3432	\N	2014-09-28 16:50:17
4358	MEMBRECOM	2006-12-19 00:00:00	2006-12-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3439	\N	\N
4368	MEMBRECOM	2007-01-10 00:00:00	2007-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3449	\N	\N
4369	MEMBRECOM	2007-01-10 00:00:00	2007-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3450	\N	\N
4370	MEMBRECOM	2007-01-10 00:00:00	2007-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3451	\N	\N
4372	MEMBRECOM	2007-01-10 00:00:00	2007-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3453	\N	\N
4373	MEMBRECOM	2007-01-10 00:00:00	2007-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3454	\N	\N
4375	MEMBRECOM	2007-01-10 00:00:00	2007-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3456	\N	\N
4376	MEMBRECOM	2007-01-10 00:00:00	2007-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3457	\N	\N
4378	MEMBRECOM	2007-01-10 00:00:00	2007-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3459	\N	\N
4379	MEMBRECOM	2007-01-10 00:00:00	2007-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3460	\N	\N
4380	MEMBRECOM	2007-01-10 00:00:00	2007-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3461	\N	\N
4381	MEMBRECOM	2007-01-10 00:00:00	2007-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3462	\N	\N
4383	MEMBRECOM	2007-01-10 00:00:00	2007-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3464	\N	\N
4384	MEMBRECOM	2007-01-10 00:00:00	2007-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3465	\N	\N
4385	MEMBRECOM	2007-01-10 00:00:00	2007-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3466	\N	\N
4387	MEMBRECOM	2007-01-10 00:00:00	2007-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3468	\N	\N
4388	MEMBRECOM	2007-01-10 00:00:00	2007-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3469	\N	\N
4389	MEMBRECOM	2007-01-10 00:00:00	2007-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3470	\N	\N
4390	MEMBRECOM	2007-01-10 00:00:00	2007-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3471	\N	\N
4391	MEMBRECOM	2007-01-10 00:00:00	2007-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3472	\N	\N
4393	MEMBRECOM	2007-01-10 00:00:00	2007-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3474	\N	\N
4396	MEMBRECOM	2007-01-10 00:00:00	2007-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3477	\N	\N
4397	MEMBRECOM	2007-01-10 00:00:00	2007-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3478	\N	\N
4399	MEMBRECOM	2007-01-10 00:00:00	2007-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3480	\N	\N
4401	MEMBRECOM	2007-01-10 00:00:00	2007-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3482	\N	\N
4402	MEMBRECOM	2007-01-10 00:00:00	2007-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3483	\N	\N
4404	MEMBRECOM	2007-01-10 00:00:00	2007-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3485	\N	\N
4405	MEMBRECOM	2007-01-10 00:00:00	2007-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3486	\N	\N
4406	MEMBRECOM	2007-01-10 00:00:00	2007-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3487	\N	\N
4427	MEMBRECOM	2007-01-26 00:00:00	2007-02-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3509	\N	\N
4432	MEMBRECOM	2007-01-25 00:00:00	2007-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3514	\N	2015-04-21 17:14:30
4433	MEMBRECOM	2007-01-25 00:00:00	2007-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3515	\N	\N
4434	MEMBRECOM	2007-01-25 00:00:00	2007-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3516	\N	\N
4435	MEMBRECOM	2007-01-25 00:00:00	2007-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3517	\N	\N
4436	MEMBRECOM	2007-01-25 00:00:00	2007-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3518	\N	\N
4437	MEMBRECOM	2007-01-25 00:00:00	2007-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3519	\N	\N
4457	MEMBRECOM	2007-06-26 00:00:00	2015-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3539	\N	2015-07-10 16:11:40
4463	MEMBRECOM	2007-02-01 00:00:00	2007-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3545	\N	\N
4464	MEMBRECOM	2007-02-01 00:00:00	2007-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3546	\N	\N
4466	MEMBRECOM	2007-02-01 00:00:00	2007-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3548	\N	2014-09-28 16:42:05
4467	MEMBRECOM	2007-02-01 00:00:00	2007-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3549	\N	2014-09-28 17:22:11
4468	MEMBRECOM	2007-02-01 00:00:00	2007-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3550	\N	\N
4486	MEMBRECOM	2007-02-07 00:00:00	2007-02-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3568	\N	\N
4497	MEMBRECOM	2007-02-12 00:00:00	2007-02-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3579	\N	\N
4515	VICPDTCOM	2007-02-14 00:00:00	2007-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3597	\N	2015-10-12 09:39:30
4516	RAPCOM	2007-02-14 00:00:00	2007-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3598	\N	2015-04-21 17:14:30
4517	MEMBRECOM	2007-02-14 00:00:00	2007-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3599	\N	\N
4518	MEMBRECOM	2007-02-14 00:00:00	2007-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3600	\N	2015-06-12 16:01:25
4520	MEMBRECOM	2007-02-14 00:00:00	2007-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3602	\N	2014-09-28 13:21:47
4521	MEMBRECOM	2007-02-14 00:00:00	2007-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3603	\N	\N
4543	MEMBRECOM	2007-06-18 00:00:00	2007-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3625	\N	\N
4545	MEMBRECOM	2007-07-11 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3627	\N	\N
4547	MEMBRECOM	2007-06-26 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3629	\N	2014-09-28 16:59:41
3247	MEMBRECOM	2004-07-09 00:00:00	2010-11-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2394	\N	\N
3248	MEMBRECOM	2004-07-09 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2395	\N	2014-09-28 17:07:41
3250	PDTCOM	2004-07-09 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2397	\N	\N
3251	MEMBRECOM	2004-07-09 00:00:00	2007-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2398	\N	\N
3252	MEMBRECOM	2004-07-09 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2399	\N	\N
3254	MEMBRECOM	2004-07-15 00:00:00	2015-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2401	\N	2015-01-08 17:14:29
3255	MEMBRECOM	2004-07-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2402	\N	2014-09-28 16:59:41
3256	MEMBRECOM	2004-07-15 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2403	\N	\N
3257	MEMBRECOM	2004-07-15 00:00:00	2015-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2404	\N	2015-06-12 15:59:49
3258	MEMBRECOM	2004-07-15 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2405	\N	2017-09-24 13:47:46
3259	MEMBRECOM	2004-07-15 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2406	\N	\N
3260	MEMBRECOM	2004-07-15 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2407	\N	\N
3261	MEMBRECOM	2004-07-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2408	\N	2014-09-28 18:19:47
3263	MEMBRECOM	2004-07-15 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2410	\N	\N
3264	MEMBRECOM	2004-07-15 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2411	\N	\N
3265	MEMBRECOM	2004-07-15 00:00:00	2017-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2412	\N	2017-09-25 09:56:00
3266	MEMBRECOM	2004-07-15 00:00:00	2013-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2413	\N	\N
3268	RAPCOM	2004-07-27 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2415	\N	\N
3269	MEMBRECOM	2004-07-27 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2416	\N	\N
3270	VICPDTCOM	2004-07-27 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2417	\N	\N
3271	MEMBRECOM	2004-07-27 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2418	\N	\N
3272	MEMBRECOM	2004-07-27 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2419	\N	\N
3273	MEMBRECOM	2004-07-27 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2420	\N	\N
3274	MEMBRECOM	2004-07-27 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2421	\N	\N
3275	MEMBRECOM	2004-07-27 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2422	\N	\N
3276	MEMBRECOM	2004-07-27 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2423	\N	2017-09-24 18:16:52
3277	MEMBRECOM	2004-07-27 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2424	\N	\N
3278	MEMBRECOM	2004-07-27 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2425	\N	2014-09-28 13:19:48
3279	MEMBRECOM	2004-07-27 00:00:00	2007-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2426	\N	\N
3280	MEMBRECOM	2004-07-27 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2427	\N	\N
214	MEMBRECOM	\N	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	214	\N	\N
3281	MEMBRECOM	2004-10-01 00:00:00	2004-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2429	\N	\N
3282	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2430	\N	\N
3283	MEMBRECOM	2004-09-26 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2431	\N	\N
3284	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2432	\N	\N
3285	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2433	\N	\N
3289	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2438	\N	\N
3290	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2439	\N	\N
3292	MEMBRECOM	2004-10-06 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2441	\N	2014-10-09 10:54:12
3293	MEMBRECOM	2004-10-01 00:00:00	2004-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2442	\N	\N
3294	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2443	\N	\N
3296	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2446	\N	\N
3297	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2447	\N	\N
3298	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2449	\N	\N
3303	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2452	\N	\N
3304	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2453	\N	\N
3305	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2454	\N	\N
3308	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2458	\N	\N
3313	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2463	\N	\N
3314	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2464	\N	\N
3315	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2465	\N	\N
3318	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2468	\N	\N
3321	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2471	\N	\N
3322	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2472	\N	\N
3323	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2473	\N	\N
3324	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2474	\N	\N
3326	MEMBRECOM	2004-10-06 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2476	\N	\N
3328	MEMBRECOM	2004-10-01 00:00:00	2004-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2478	\N	\N
3329	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2479	\N	\N
3330	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2480	\N	\N
3331	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2481	\N	\N
3332	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2482	\N	\N
3333	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2483	\N	\N
3334	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2484	\N	\N
3335	MEMBRECOM	2004-10-01 00:00:00	2004-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2485	\N	\N
3336	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2486	\N	\N
3337	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2487	\N	\N
3338	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2488	\N	\N
3340	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2489	\N	\N
3341	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2490	\N	\N
3342	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2491	\N	\N
3343	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2492	\N	\N
3344	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2493	\N	\N
3346	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2495	\N	\N
3347	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2496	\N	\N
3349	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2498	\N	\N
3353	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2502	\N	\N
3354	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2503	\N	\N
3355	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2504	\N	\N
3356	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2505	\N	\N
3357	MEMBRECOM	2004-10-01 00:00:00	2004-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2506	\N	\N
3358	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2507	\N	\N
3360	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2509	\N	\N
3361	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2510	\N	\N
3362	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2511	\N	\N
10872	SECRETCOM	2013-02-14 00:00:00	2014-04-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9158	\N	2014-04-10 10:15:28
10977	MEMBRECOM	2013-04-02 00:00:00	2017-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9264	\N	2017-07-24 09:56:26
3365	MEMBRECOM	2004-10-06 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2514	\N	\N
3366	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2515	\N	\N
3368	MEMBRECOM	2004-10-06 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2517	\N	\N
3369	MEMBRECOM	2004-10-06 00:00:00	2007-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2518	\N	\N
3370	MEMBRECOM	2004-10-06 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2519	\N	\N
3371	MEMBRECOM	2004-10-06 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2520	\N	\N
3372	MEMBRECOM	2004-10-06 00:00:00	2007-01-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2521	\N	\N
3373	MEMBRECOM	2004-10-06 00:00:00	2004-11-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2522	\N	\N
3374	MEMBRECOM	2004-10-06 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2523	\N	\N
3375	MEMBRECOM	2004-10-06 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2524	\N	\N
3376	MEMBRECOM	2004-10-06 00:00:00	2008-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2525	\N	\N
3377	MEMBRECOM	2004-10-06 00:00:00	2008-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2526	\N	\N
3378	MEMBRECOM	2004-10-06 00:00:00	2004-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2527	\N	\N
3379	MEMBRECOM	2004-10-06 00:00:00	2007-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2528	\N	\N
3380	MEMBRECOM	2004-10-06 00:00:00	2004-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2529	\N	\N
3381	MEMBRECOM	2004-10-06 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2530	\N	2017-10-04 18:38:42
3383	MEMBRECOM	2004-10-06 00:00:00	2008-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2532	\N	\N
3384	MEMBRECOM	2004-10-06 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2533	\N	\N
3385	MEMBRECOM	2004-10-06 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2534	\N	\N
3386	MEMBRECOM	2004-10-06 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2536	\N	\N
3388	MEMBRECOM	2004-10-06 00:00:00	2008-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2537	\N	\N
3389	MEMBRECOM	2004-10-06 00:00:00	2008-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2538	\N	\N
3390	MEMBRECOM	2004-10-06 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2539	\N	\N
3392	MEMBRECOM	2004-10-06 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2541	\N	\N
3394	MEMBRECOM	2004-10-06 00:00:00	2007-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2543	\N	\N
3395	MEMBRECOM	2004-10-06 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2544	\N	\N
3396	MEMBRECOM	2004-10-06 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2545	\N	\N
3397	MEMBRECOM	2004-10-06 00:00:00	2007-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2546	\N	\N
3398	MEMBRECOM	2004-10-06 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2547	\N	\N
3399	MEMBRECOM	2004-10-06 00:00:00	2007-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2548	\N	\N
3400	MEMBRECOM	2004-10-06 00:00:00	2004-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2550	\N	\N
3401	MEMBRECOM	2004-10-06 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2549	\N	2014-09-28 13:39:21
3402	MEMBRECOM	2004-10-06 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2551	\N	2014-09-28 17:07:41
3404	MEMBRECOM	2004-10-06 00:00:00	2008-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2553	\N	\N
3405	MEMBRECOM	2004-10-06 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2554	\N	\N
3406	MEMBRECOM	2004-10-06 00:00:00	2008-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2555	\N	\N
3407	MEMBRECOM	2004-10-06 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2556	\N	\N
3408	MEMBRECOM	2004-10-06 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2557	\N	\N
3409	MEMBRECOM	2004-10-06 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2558	\N	\N
3410	MEMBRECOM	2004-10-06 00:00:00	2008-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2559	\N	\N
3411	MEMBRECOM	2004-10-06 00:00:00	2004-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2560	\N	\N
3412	MEMBRECOM	2004-10-06 00:00:00	2009-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2561	\N	\N
3413	MEMBRECOM	2004-10-06 00:00:00	2005-03-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2562	\N	\N
3414	MEMBRECOM	2004-10-06 00:00:00	2007-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2563	\N	\N
3415	MEMBRECOM	2004-10-06 00:00:00	2008-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2564	\N	\N
3416	MEMBRECOM	2004-10-06 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2565	\N	\N
3417	MEMBRECOM	2004-10-06 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2566	\N	\N
3418	MEMBRECOM	2004-10-06 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2567	\N	\N
3420	MEMBRECOM	2004-10-06 00:00:00	2013-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2571	\N	2013-10-03 18:07:38
3421	MEMBRECOM	2004-10-06 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2572	\N	\N
3422	MEMBRECOM	2004-10-06 00:00:00	2008-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2573	\N	\N
3423	MEMBRECOM	2004-10-06 00:00:00	2004-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2574	\N	\N
3424	MEMBRECOM	2004-10-06 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2575	\N	\N
3425	MEMBRECOM	2004-10-06 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2576	\N	\N
3426	MEMBRECOM	2004-10-06 00:00:00	2007-09-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2577	\N	\N
3427	MEMBRECOM	2004-10-06 00:00:00	2008-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2578	\N	\N
3429	MEMBRECOM	2004-10-06 00:00:00	2017-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2581	\N	2017-07-24 09:56:26
3430	MEMBRECOM	2004-10-06 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2580	\N	\N
3431	MEMBRECOM	2004-10-06 00:00:00	2004-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2582	\N	\N
3432	MEMBRECOM	2004-10-06 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2583	\N	\N
3433	MEMBRECOM	2004-10-06 00:00:00	2008-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2584	\N	\N
3435	MEMBRECOM	2004-10-06 00:00:00	2005-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2586	\N	\N
3434	VICPDTCOM	2004-10-06 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2585	\N	\N
3436	PDTCOM	2004-10-06 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2587	\N	\N
3439	MEMBRECOM	2004-10-06 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2590	\N	\N
3440	MEMBRECOM	2004-10-06 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2591	\N	\N
3441	MEMBRECOM	2004-10-06 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2592	\N	\N
3442	MEMBRECOM	2004-10-06 00:00:00	2008-01-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2593	\N	\N
3443	MEMBRECOM	2004-10-06 00:00:00	2007-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2594	\N	\N
3444	MEMBRECOM	2004-10-06 00:00:00	2005-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2595	\N	\N
3445	MEMBRECOM	2004-10-06 00:00:00	2007-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2596	\N	\N
3446	MEMBRECOM	2004-10-06 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2597	\N	\N
3447	MEMBRECOM	2004-10-06 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2598	\N	\N
3448	MEMBRECOM	2004-10-06 00:00:00	2010-11-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2599	\N	\N
3449	MEMBRECOM	2004-10-06 00:00:00	2008-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2600	\N	\N
3450	MEMBRECOM	2004-10-06 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2601	\N	\N
3451	MEMBRECOM	2004-10-06 00:00:00	2004-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2602	\N	\N
3452	MEMBRECOM	2004-10-06 00:00:00	2008-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2603	\N	\N
3454	MEMBRECOM	2004-10-06 00:00:00	2009-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2605	\N	\N
3455	MEMBRECOM	2004-10-06 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2606	\N	\N
3456	MEMBRECOM	2004-10-06 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2607	\N	2014-10-09 10:54:50
3457	MEMBRECOM	2004-10-06 00:00:00	2008-01-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2608	\N	\N
3458	MEMBRECOM	2004-10-06 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2609	\N	\N
3459	MEMBRECOM	2004-10-06 00:00:00	2007-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2610	\N	\N
3460	MEMBRECOM	2004-10-06 00:00:00	2005-03-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2611	\N	\N
3461	MEMBRECOM	2004-10-06 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2612	\N	2017-09-24 17:15:15
3462	MEMBRECOM	2004-10-06 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2613	\N	\N
3463	MEMBRECOM	2004-10-06 00:00:00	2008-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2614	\N	\N
3465	MEMBRECOM	2004-10-06 00:00:00	2004-11-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2616	\N	\N
3466	MEMBRECOM	2004-10-06 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2617	\N	\N
3467	MEMBRECOM	2004-10-06 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2618	\N	2014-10-08 17:37:34
3468	MEMBRECOM	2004-10-06 00:00:00	2011-01-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2619	\N	\N
3469	MEMBRECOM	2004-10-06 00:00:00	2004-10-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2620	\N	\N
3470	MEMBRECOM	2004-10-06 00:00:00	2005-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2621	\N	\N
3471	MEMBRECOM	2004-10-06 00:00:00	2008-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2622	\N	\N
3472	MEMBRECOM	2004-10-06 00:00:00	2004-11-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2623	\N	\N
3474	MEMBRECOM	2004-10-06 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2625	\N	2014-09-28 18:58:25
3475	MEMBRECOM	2004-10-06 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2626	\N	\N
3476	MEMBRECOM	2004-10-06 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2627	\N	\N
3477	MEMBRECOM	2004-10-06 00:00:00	2005-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2628	\N	\N
3478	MEMBRECOM	2004-10-06 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2629	\N	\N
3325	MEMBRECOM	2004-10-01 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2475	\N	\N
4940	MEMBRECOM	2007-07-05 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3670	\N	\N
4981	VICPDTCOM	2008-07-09 00:00:00	2008-07-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4066	\N	2014-07-01 09:25:11
4984	MEMBRECOM	2008-07-09 00:00:00	2008-07-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4069	\N	\N
4985	MEMBRECOM	2008-07-09 00:00:00	2008-07-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4070	\N	2014-09-28 16:59:41
4986	MEMBRECOM	2008-07-09 00:00:00	2008-07-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4071	\N	\N
4987	MEMBRECOM	2008-07-09 00:00:00	2008-07-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4072	\N	2018-05-31 10:52:17
4306	RAPCOM	2006-11-17 00:00:00	2006-11-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3387	\N	\N
4307	MEMBRECOM	2006-11-17 00:00:00	2006-11-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3388	\N	\N
4308	MEMBRECOM	2006-11-17 00:00:00	2006-11-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3389	\N	\N
4309	MEMBRECOM	2006-11-17 00:00:00	2006-11-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3390	\N	\N
4690	MEMBRECOM	2007-11-22 00:00:00	2007-12-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3771	\N	\N
4691	PDTCOM	2007-11-16 00:00:00	2007-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3772	\N	\N
4692	RAPCOM	2007-11-16 00:00:00	2007-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3773	\N	\N
4693	MEMBRECOM	2007-11-16 00:00:00	2007-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3774	\N	\N
4695	MEMBRECOM	2007-11-16 00:00:00	2007-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3776	\N	\N
4698	MEMBRECOM	2007-11-16 00:00:00	2007-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3779	\N	\N
4815	MEMBRECOM	2008-01-24 00:00:00	2008-01-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3900	\N	\N
4700	MEMBRECOM	2007-11-16 00:00:00	2007-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3781	\N	2017-09-24 13:44:49
4705	MEMBRECOM	2007-11-16 00:00:00	2007-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3786	\N	\N
4806	PDTCOM	2008-01-16 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2593	\N	\N
4811	VICPDTCOM	2008-01-24 00:00:00	2008-01-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3896	\N	\N
4812	MEMBRECOM	2008-01-24 00:00:00	2008-01-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3897	\N	2017-09-24 18:05:41
4822	MEMBRECOM	2008-01-24 00:00:00	2008-01-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3907	\N	\N
4833	MEMBRECOM	2008-01-24 00:00:00	2008-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3918	\N	2014-09-28 12:21:28
4839	VICPDTCOM	2008-01-31 00:00:00	2008-02-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3924	\N	2015-10-12 09:39:31
4841	MEMBRECOM	2008-01-31 00:00:00	2008-02-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3926	\N	2014-09-28 18:00:58
4842	MEMBRECOM	2008-01-31 00:00:00	2008-02-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3927	\N	2017-09-24 17:15:15
4844	MEMBRECOM	2008-01-31 00:00:00	2008-02-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3929	\N	\N
4846	MEMBRECOM	2008-01-31 00:00:00	2008-02-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3931	\N	2014-09-28 12:09:44
4860	RAPCOM	2008-04-16 00:00:00	2008-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3947	\N	2014-09-28 17:07:41
4862	MEMBRECOM	2008-04-16 00:00:00	2008-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3949	\N	\N
4863	MEMBRECOM	2008-04-16 00:00:00	2008-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3950	\N	\N
4864	MEMBRECOM	2008-04-16 00:00:00	2008-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3951	\N	2014-09-28 13:39:21
4865	MEMBRECOM	2008-04-16 00:00:00	2008-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3952	\N	2017-09-24 17:35:15
4899	VICPDTCOM	2008-06-03 00:00:00	2008-06-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3986	\N	\N
4901	MEMBRECOM	2008-06-03 00:00:00	2008-06-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3988	\N	2014-09-28 16:42:05
4902	MEMBRECOM	2008-06-03 00:00:00	2008-06-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3989	\N	2014-09-28 17:22:11
4903	MEMBRECOM	2008-06-03 00:00:00	2008-06-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3990	\N	\N
4904	MEMBRECOM	2008-06-03 00:00:00	2008-06-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3991	\N	\N
4905	MEMBRECOM	2008-06-03 00:00:00	2008-06-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3992	\N	\N
4906	MEMBRECOM	2008-06-03 00:00:00	2008-06-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3993	\N	2014-09-28 16:59:41
4908	MEMBRECOM	2008-06-03 00:00:00	2008-06-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3995	\N	2014-09-28 17:09:16
4701	MEMBRECOM	2007-11-16 00:00:00	2007-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3782	\N	\N
4674	SECRETCOM	2007-10-03 00:00:00	2008-10-06 00:00:00	7	ANCIEN	\N	\N	\N	\N	718	\N	\N
4696	MEMBRECOM	2007-11-16 00:00:00	2007-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3777	\N	\N
4697	MEMBRECOM	2007-11-16 00:00:00	2007-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3778	\N	2014-09-28 17:07:41
4848	MEMBRECOM	2008-01-31 00:00:00	2008-02-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3933	\N	2014-09-29 13:41:53
4861	MEMBRECOM	2008-04-16 00:00:00	2008-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3948	\N	2017-09-24 18:17:56
4866	MEMBRECOM	2008-04-16 00:00:00	2008-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3953	\N	\N
4870	MEMBRECOM	2008-04-16 00:00:00	2008-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3957	\N	\N
4871	MEMBRECOM	2008-04-16 00:00:00	2008-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3958	\N	\N
4909	MEMBRECOM	2008-06-03 00:00:00	2008-06-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3996	\N	\N
4912	MEMBRECOM	2008-06-03 00:00:00	2008-06-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3999	\N	2014-09-28 17:03:42
4914	MEMBRECOM	2008-06-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4001	\N	\N
4915	MEMBRECOM	2008-06-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4002	\N	\N
4916	MEMBRECOM	2008-06-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4003	\N	\N
4918	MEMBRECOM	2008-06-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4005	\N	\N
4919	MEMBRECOM	2008-06-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4006	\N	\N
4920	MEMBRECOM	2008-06-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4007	\N	\N
4921	MEMBRECOM	2008-06-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4009	\N	\N
4989	MEMBRECOM	2008-07-09 00:00:00	2008-07-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4074	\N	\N
4924	MEMBRECOM	2008-06-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4012	\N	\N
4925	MEMBRECOM	2008-06-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4013	\N	\N
4926	MEMBRECOM	2008-06-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4014	\N	\N
4927	MEMBRECOM	2008-06-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4015	\N	\N
4929	MEMBRECOM	2008-06-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4017	\N	\N
4930	MEMBRECOM	2008-06-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4018	\N	\N
2615	MEMBRECOM	2003-10-16 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2006	\N	\N
2616	MEMBRECOM	2003-10-16 00:00:00	2014-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2007	\N	2014-09-29 13:41:53
2617	MEMBRECOM	2003-10-16 00:00:00	2015-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2008	\N	2015-10-12 09:39:30
2619	MEMBRECOM	2003-10-16 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2010	\N	\N
2620	MEMBRECOM	2003-10-16 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2011	\N	2017-09-24 13:29:42
2622	MEMBRECOM	2003-11-05 00:00:00	2004-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2013	\N	\N
2623	MEMBRECOM	2003-11-05 00:00:00	2004-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2014	\N	\N
2626	MEMBRECOM	2003-11-05 00:00:00	2003-11-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2017	\N	\N
2627	MEMBRECOM	1959-05-12 00:00:00	1972-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2018	\N	\N
2285	SECRETCOM	1973-04-03 00:00:00	1980-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1711	\N	\N
3176	MEMBRECOM	2004-06-09 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2323	\N	\N
3177	MEMBRECOM	2004-06-28 00:00:00	2004-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2324	\N	\N
3182	MEMBRECOM	2004-06-28 00:00:00	2004-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2329	\N	\N
3225	VICPDTCOM	2004-07-08 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2372	\N	2014-09-28 18:58:21
3226	RAPCOM	2004-07-08 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2373	\N	\N
3227	MEMBRECOM	2004-07-08 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2374	\N	\N
3229	MEMBRECOM	2004-07-08 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2376	\N	\N
3230	MEMBRECOM	2004-07-08 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2377	\N	2014-09-28 16:50:17
3231	MEMBRECOM	2004-07-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2378	\N	2017-09-24 17:06:55
3232	MEMBRECOM	2004-07-08 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2379	\N	2014-09-28 12:54:15
3233	MEMBRECOM	2004-07-08 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2380	\N	\N
3234	MEMBRECOM	2004-07-08 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2381	\N	\N
3235	MEMBRECOM	2004-07-08 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2382	\N	\N
3236	MEMBRECOM	2004-07-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2383	\N	2017-09-24 17:09:24
3237	MEMBRECOM	2004-07-08 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2384	\N	\N
3238	MEMBRECOM	2004-07-08 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2385	\N	\N
3239	MEMBRECOM	2004-07-09 00:00:00	2011-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2386	\N	\N
3240	RAPCOM	2004-07-09 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2387	\N	\N
3241	MEMBRECOM	2004-07-09 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2388	\N	\N
3242	PDTCOM	2004-07-09 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2389	\N	\N
3244	MEMBRECOM	2004-07-09 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2391	\N	\N
3245	MEMBRECOM	2004-07-09 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2392	\N	\N
3246	MEMBRECOM	2004-07-09 00:00:00	2004-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2393	\N	\N
4625	PDTCOM	2007-07-26 00:00:00	2007-07-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3709	\N	\N
5239	MEMBRECOM	2008-10-07 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4307	\N	\N
5240	SECRETCOM	2008-10-07 00:00:00	2011-09-30 00:00:00	6	ANCIEN	\N	\N	\N	\N	718	\N	\N
5241	PDTCOM	2008-10-07 00:00:00	2009-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	771	\N	\N
5242	MEMBRECOM	2008-10-07 00:00:00	2009-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4308	\N	\N
5243	MEMBRECOM	2008-10-07 00:00:00	2011-02-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	804	\N	\N
5244	VICPDTCOM	2008-10-07 00:00:00	2014-10-07 00:00:00	8	ANCIEN	\N	\N	\N	\N	2577	\N	2014-10-08 17:51:15
5246	PDTCOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	841	\N	\N
5247	MEMBRECOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	93	\N	\N
5248	VICPDTCOM	2008-10-07 00:00:00	2011-02-15 00:00:00	8	ANCIEN	\N	\N	\N	\N	802	\N	\N
5249	MEMBRECOM	2008-10-07 00:00:00	2009-07-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4309	\N	\N
5250	MEMBRECOM	2008-10-07 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4310	\N	2014-09-28 17:55:39
5251	VICPDTCOM	2008-10-07 00:00:00	2011-09-30 00:00:00	1	ANCIEN	\N	\N	\N	\N	758	\N	\N
5252	MEMBRECOM	2008-10-07 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4311	\N	2014-09-28 16:59:41
5253	MEMBRECOM	2008-10-07 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4312	\N	2014-09-28 17:03:41
5254	VICPDTCOM	2008-10-07 00:00:00	2011-09-30 00:00:00	5	ANCIEN	\N	\N	\N	\N	412	\N	\N
5255	MEMBRECOM	2008-10-07 00:00:00	2017-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4313	\N	2017-09-25 09:57:52
5256	VICPDTCOM	2008-10-07 00:00:00	2011-09-30 00:00:00	6	ANCIEN	\N	\N	\N	\N	873	\N	\N
5257	MEMBRECOM	2008-10-07 00:00:00	2009-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4314	\N	\N
5259	MEMBRECOM	2008-10-07 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4315	\N	2014-09-28 12:52:10
5260	PDTCOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2593	\N	\N
5261	SECRETCOM	2008-10-07 00:00:00	2011-09-30 00:00:00	3	ANCIEN	\N	\N	\N	\N	2594	\N	\N
5262	MEMBRECOM	2008-10-07 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	40	\N	2014-09-28 17:05:42
5263	VICPDTCOM	2008-10-07 00:00:00	2011-09-30 00:00:00	6	ANCIEN	\N	\N	\N	\N	69	\N	\N
5105	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4195	\N	\N
5093	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4182	\N	\N
5095	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4184	\N	\N
5107	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4197	\N	\N
5109	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4199	\N	\N
5114	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4205	\N	\N
5116	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4207	\N	\N
5118	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4209	\N	\N
5125	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4217	\N	\N
5131	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4223	\N	\N
5133	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4225	\N	\N
3839	MEMBRECOM	2005-07-05 00:00:00	2015-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2928	\N	2015-06-12 15:59:49
3840	MEMBRECOM	2005-07-05 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2929	\N	2014-09-28 18:03:38
3841	VICPDTCOM	2005-07-07 00:00:00	2011-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2930	\N	\N
3843	MEMBRECOM	2005-07-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2932	\N	\N
3844	MEMBRECOM	2005-07-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2933	\N	\N
3846	MEMBRECOM	2005-07-07 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2935	\N	2017-09-24 16:43:43
3847	MEMBRECOM	2005-07-07 00:00:00	2007-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2936	\N	\N
3848	MEMBRECOM	2005-07-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2937	\N	\N
3849	MEMBRECOM	2005-07-07 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2938	\N	2017-09-24 19:25:10
3851	MEMBRECOM	2005-07-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2940	\N	\N
3852	MEMBRECOM	2005-07-07 00:00:00	2014-09-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2941	\N	2014-09-01 10:21:13
3853	MEMBRECOM	2005-07-07 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2942	\N	\N
3854	MEMBRECOM	2005-07-07 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	2943	\N	\N
3856	RAPCOM	2005-07-07 00:00:00	2018-12-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2945	\N	\N
3857	MEMBRECOM	2005-07-07 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	2946	\N	\N
3858	MEMBRECOM	2005-07-07 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	2947	\N	\N
3859	MEMBRECOM	2005-07-07 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2948	\N	\N
3860	MEMBRECOM	2005-07-07 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2949	\N	2017-09-24 17:09:24
3861	MEMBRECOM	2005-07-07 00:00:00	2014-11-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2950	\N	2014-11-04 11:22:47
3864	MEMBRECOM	2005-07-07 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2953	\N	2017-09-24 17:47:27
3865	MEMBRECOM	2005-07-07 00:00:00	2017-05-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2954	\N	2017-05-16 15:18:13
3866	MEMBRECOM	2005-07-07 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2955	\N	\N
3867	MEMBRECOM	2005-07-07 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2956	\N	\N
3868	MEMBRECOM	2005-07-07 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2957	\N	\N
3869	MEMBRECOM	2005-09-19 00:00:00	2005-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2959	\N	\N
3871	MEMBRECOM	2005-09-19 00:00:00	2005-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2961	\N	\N
3873	MEMBRECOM	2005-10-04 00:00:00	2007-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2962	\N	\N
3874	MEMBRECOM	2005-10-04 00:00:00	2006-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2963	\N	\N
3875	MEMBRECOM	2005-10-04 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2964	\N	\N
3876	MEMBRECOM	2005-10-04 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2965	\N	\N
3877	MEMBRECOM	2005-10-04 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2966	\N	2014-10-09 13:55:18
3878	MEMBRECOM	2005-10-04 00:00:00	2008-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2967	\N	\N
3879	MEMBRECOM	2005-10-04 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2968	\N	\N
3880	SECRETCOM	2005-10-19 00:00:00	2008-09-30 00:00:00	1	ANCIEN	\N	\N	\N	\N	2027	\N	\N
3881	MEMBRECOM	2005-10-27 00:00:00	2006-03-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2969	\N	\N
4325	VICPDTCOM	2006-12-12 00:00:00	2006-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3406	\N	2014-07-01 09:25:11
4326	RAPCOM	2006-12-12 00:00:00	2006-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3407	\N	2015-01-08 17:14:29
4327	MEMBRECOM	2006-12-12 00:00:00	2006-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3408	\N	2014-09-28 13:16:32
4328	MEMBRECOM	2006-12-12 00:00:00	2006-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3409	\N	2014-09-28 16:59:41
4331	MEMBRECOM	2006-12-12 00:00:00	2006-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3412	\N	2017-09-24 17:06:55
4332	MEMBRECOM	2006-12-12 00:00:00	2006-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3413	\N	\N
4333	MEMBRECOM	2006-12-12 00:00:00	2006-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3414	\N	2014-09-28 17:27:35
4334	MEMBRECOM	2006-12-12 00:00:00	2006-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3415	\N	\N
4335	MEMBRECOM	2006-12-12 00:00:00	2006-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3416	\N	\N
4336	MEMBRECOM	2006-12-12 00:00:00	2006-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3417	\N	\N
4343	MEMBRECOM	2006-12-14 00:00:00	2006-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3424	\N	\N
4348	MEMBRECOM	2006-12-14 00:00:00	2006-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3429	\N	2017-05-16 15:18:13
4352	MEMBRECOM	2006-12-14 00:00:00	2006-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3433	\N	\N
4353	PDTCOM	2006-12-19 00:00:00	2006-12-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3434	\N	2014-07-01 09:25:11
4354	RAPCOM	2006-12-19 00:00:00	2006-12-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3435	\N	2015-01-08 17:14:29
4356	MEMBRECOM	2006-12-19 00:00:00	2006-12-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3437	\N	2014-09-28 18:19:47
4592	MEMBRECOM	2007-07-04 00:00:00	2008-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3674	\N	\N
4593	MEMBRECOM	2007-07-04 00:00:00	2007-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3675	\N	\N
4594	MEMBRECOM	2007-07-04 00:00:00	2008-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3676	\N	\N
4703	MEMBRECOM	2007-11-16 00:00:00	2007-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3784	\N	\N
4704	MEMBRECOM	2007-11-16 00:00:00	2007-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3785	\N	\N
4910	MEMBRECOM	2008-06-03 00:00:00	2008-06-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3997	\N	\N
4911	MEMBRECOM	2008-06-03 00:00:00	2008-06-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3998	\N	2014-12-18 16:15:04
4942	MEMBRECOM	2008-06-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4027	\N	\N
4943	MEMBRECOM	2008-06-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4028	\N	\N
4945	MEMBRECOM	2008-06-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4030	\N	\N
4947	MEMBRECOM	2008-06-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4032	\N	\N
4948	MEMBRECOM	2008-06-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4033	\N	\N
4949	MEMBRECOM	2008-06-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4034	\N	\N
4950	MEMBRECOM	2008-06-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4035	\N	\N
4951	MEMBRECOM	2008-06-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4036	\N	\N
4952	MEMBRECOM	2008-06-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4037	\N	\N
4953	MEMBRECOM	2008-06-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4038	\N	\N
4995	PDTCOM	2008-07-17 00:00:00	2008-07-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4080	\N	\N
4996	RAPCOM	2008-07-17 00:00:00	2008-07-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4081	\N	\N
4941	MEMBRECOM	2008-06-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4008	\N	\N
4955	PDTCOM	2008-07-02 00:00:00	2008-07-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4040	\N	2014-09-28 18:58:21
4956	MEMBRECOM	2008-07-02 00:00:00	2008-07-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4041	\N	\N
4957	RAPCOM	2008-07-02 00:00:00	2008-07-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4042	\N	\N
5000	MEMBRECOM	2008-07-17 00:00:00	2008-07-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4085	\N	\N
5001	MEMBRECOM	2008-07-17 00:00:00	2008-07-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4086	\N	\N
5002	MEMBRECOM	2008-07-17 00:00:00	2008-07-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4087	\N	\N
5004	MEMBRECOM	2008-07-17 00:00:00	2008-07-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4089	\N	2017-09-24 18:16:52
5005	MEMBRECOM	2008-07-17 00:00:00	2008-07-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4090	\N	\N
5008	MEMBRECOM	2008-07-17 00:00:00	2008-07-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4093	\N	2014-12-18 16:15:04
5009	PDTCOM	2008-07-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4094	\N	\N
5010	RAPCOM	2008-07-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4095	\N	\N
5011	MEMBRECOM	2008-07-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4096	\N	\N
5013	MEMBRECOM	2008-07-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4098	\N	\N
5014	MEMBRECOM	2008-07-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4099	\N	2014-09-28 17:07:41
5015	MEMBRECOM	2008-07-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4100	\N	2017-09-24 17:35:15
5016	MEMBRECOM	2008-07-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4101	\N	\N
5017	MEMBRECOM	2008-07-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4102	\N	\N
5018	MEMBRECOM	2008-07-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4103	\N	2014-09-28 17:07:41
5019	MEMBRECOM	2008-07-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4104	\N	2014-09-28 17:07:41
5022	MEMBRECOM	2008-07-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4107	\N	\N
5023	VICPDTCOM	2008-07-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4108	\N	\N
5025	MEMBRECOM	2008-07-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4110	\N	\N
5026	MEMBRECOM	2008-07-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4111	\N	\N
5027	MEMBRECOM	2008-07-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4112	\N	\N
5028	MEMBRECOM	2008-07-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4113	\N	\N
5029	MEMBRECOM	2008-07-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4114	\N	2017-09-24 17:35:15
5031	MEMBRECOM	2008-07-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4116	\N	\N
5032	MEMBRECOM	2008-07-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4117	\N	2014-09-28 17:07:41
5033	MEMBRECOM	2008-07-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4118	\N	2014-09-28 17:07:41
5034	MEMBRECOM	2008-07-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4119	\N	\N
5035	MEMBRECOM	2008-07-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4120	\N	\N
5036	MEMBRECOM	2008-07-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4121	\N	\N
5037	MEMBRECOM	2007-10-02 00:00:00	2008-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	289	\N	\N
5040	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4124	\N	\N
4458	VICPDTCOM	2007-02-01 00:00:00	2007-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3540	\N	\N
4459	RAPCOM	2007-02-01 00:00:00	2007-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3541	\N	\N
4460	MEMBRECOM	2007-02-01 00:00:00	2007-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3542	\N	\N
4461	MEMBRECOM	2007-02-01 00:00:00	2007-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3543	\N	\N
4462	MEMBRECOM	2007-02-01 00:00:00	2007-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3544	\N	2017-07-04 15:08:09
4475	PDTCOM	2007-02-07 00:00:00	2007-02-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3557	\N	2014-09-28 18:00:58
4476	MEMBRECOM	2007-02-07 00:00:00	2007-02-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3558	\N	\N
4477	MEMBRECOM	2007-02-07 00:00:00	2007-02-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3559	\N	2014-09-29 13:41:53
4479	MEMBRECOM	2007-02-07 00:00:00	2007-02-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3561	\N	\N
4480	MEMBRECOM	2007-02-07 00:00:00	2007-02-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3562	\N	\N
4481	MEMBRECOM	2007-02-07 00:00:00	2007-02-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3563	\N	\N
4483	MEMBRECOM	2007-02-07 00:00:00	2007-02-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3565	\N	\N
4487	PDTCOM	2007-02-12 00:00:00	2007-02-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3569	\N	2015-10-12 09:39:30
4488	RAPCOM	2007-02-12 00:00:00	2007-02-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3570	\N	2017-09-24 13:29:42
4489	MEMBRECOM	2007-02-12 00:00:00	2007-02-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3571	\N	2014-09-28 18:00:58
4490	MEMBRECOM	2007-02-12 00:00:00	2007-02-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3572	\N	\N
4491	MEMBRECOM	2007-02-12 00:00:00	2007-02-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3573	\N	2014-09-29 13:41:53
4492	MEMBRECOM	2007-02-12 00:00:00	2007-02-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3574	\N	\N
4493	MEMBRECOM	2007-02-12 00:00:00	2007-02-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3575	\N	\N
4496	MEMBRECOM	2007-02-12 00:00:00	2007-02-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3578	\N	2015-04-21 17:14:30
4498	MEMBRECOM	2007-02-12 00:00:00	2007-02-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3580	\N	2014-09-28 13:21:47
4501	PDTCOM	2007-02-15 00:00:00	2007-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3583	\N	2015-10-12 09:39:30
4502	RAPCOM	2007-02-15 00:00:00	2007-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3584	\N	\N
4503	MEMBRECOM	2007-02-15 00:00:00	2007-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3585	\N	\N
4505	MEMBRECOM	2007-02-15 00:00:00	2007-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3587	\N	\N
4506	MEMBRECOM	2007-02-15 00:00:00	2007-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3588	\N	\N
4508	MEMBRECOM	2007-02-15 00:00:00	2007-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3590	\N	2014-09-28 12:09:44
4509	MEMBRECOM	2007-02-15 00:00:00	2007-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3591	\N	\N
4510	MEMBRECOM	2007-02-15 00:00:00	2007-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3592	\N	2014-09-29 13:41:53
4511	MEMBRECOM	2007-02-15 00:00:00	2007-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3593	\N	\N
4512	MEMBRECOM	2007-02-15 00:00:00	2007-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3594	\N	\N
4514	MEMBRECOM	2007-02-15 00:00:00	2007-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3596	\N	\N
4530	MEMBRECOM	2007-02-20 00:00:00	2007-02-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3612	\N	\N
4531	MEMBRECOM	2007-02-20 00:00:00	2007-02-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3613	\N	\N
4752	MEMBRECOM	2007-12-14 00:00:00	2007-12-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3837	\N	\N
4750	PDTCOM	2007-12-14 00:00:00	2007-12-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3835	\N	2014-09-28 18:58:21
4751	RAPCOM	2007-12-14 00:00:00	2007-12-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3836	\N	\N
4755	MEMBRECOM	2007-12-14 00:00:00	2007-12-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3840	\N	2014-09-28 14:31:42
4757	MEMBRECOM	2007-12-14 00:00:00	2007-12-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3842	\N	2014-09-28 12:56:42
4758	MEMBRECOM	2007-12-14 00:00:00	2007-12-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3843	\N	2017-05-16 15:18:13
4759	MEMBRECOM	2007-12-14 00:00:00	2007-12-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3844	\N	\N
4760	MEMBRECOM	2007-12-14 00:00:00	2007-12-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3845	\N	\N
4761	MEMBRECOM	2007-12-14 00:00:00	2007-12-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3846	\N	\N
4763	MEMBRECOM	2007-12-14 00:00:00	2007-12-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3848	\N	\N
4765	RAPCOM	2007-12-18 00:00:00	2007-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3850	\N	2015-01-08 17:14:29
4766	MEMBRECOM	2007-12-18 00:00:00	2007-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3851	\N	2014-09-28 13:16:32
4767	MEMBRECOM	2007-12-18 00:00:00	2007-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3852	\N	2014-09-28 18:19:47
4768	MEMBRECOM	2007-12-18 00:00:00	2007-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3853	\N	2014-09-28 16:59:41
4769	MEMBRECOM	2007-12-18 00:00:00	2007-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3854	\N	\N
4771	MEMBRECOM	2007-12-18 00:00:00	2007-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3856	\N	\N
4825	PDTCOM	2008-01-24 00:00:00	2008-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3910	\N	\N
4853	MEMBRECOM	1959-10-08 00:00:00	1961-11-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3938	\N	\N
4854	MEMBRECOM	\N	1965-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3939	\N	\N
4867	MEMBRECOM	2008-04-16 00:00:00	2008-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3954	\N	2017-09-24 19:25:10
4869	MEMBRECOM	2008-04-16 00:00:00	2008-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3956	\N	2017-09-24 16:43:43
4876	RAPCOM	2008-05-14 00:00:00	2008-05-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3963	\N	\N
5042	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4126	\N	\N
5045	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4129	\N	\N
5049	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4131	\N	\N
5062	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4144	\N	\N
5076	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4161	\N	\N
5101	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4190	\N	\N
5106	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4196	\N	\N
5110	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4200	\N	\N
5117	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4208	\N	\N
5120	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4211	\N	\N
5127	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4219	\N	\N
5129	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4221	\N	\N
5135	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4227	\N	\N
5137	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4229	\N	\N
4271	MEMBRECOM	2006-08-12 00:00:00	2006-09-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3352	\N	\N
4337	MEMBRECOM	2006-12-12 00:00:00	2006-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3418	\N	\N
4357	MEMBRECOM	2006-12-19 00:00:00	2006-12-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3438	\N	2015-06-12 15:59:49
4359	MEMBRECOM	2006-12-19 00:00:00	2006-12-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3440	\N	\N
4361	MEMBRECOM	2006-12-19 00:00:00	2006-12-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3442	\N	\N
4362	MEMBRECOM	2006-12-19 00:00:00	2006-12-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3443	\N	\N
4364	MEMBRECOM	2006-12-19 00:00:00	2006-12-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3445	\N	\N
4473	RAPCOM	2007-02-07 00:00:00	2007-02-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3555	\N	2015-10-12 09:39:31
4478	MEMBRECOM	2007-02-07 00:00:00	2007-02-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3560	\N	\N
8314	MEMBRECOM	2009-07-08 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6872	\N	\N
8315	MEMBRECOM	2009-07-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6873	\N	2017-09-24 17:09:24
8320	MEMBRECOM	2009-07-08 00:00:00	2017-05-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6878	\N	2017-05-16 15:18:13
8321	MEMBRECOM	2009-07-08 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6879	\N	2014-09-28 17:40:23
8322	MEMBRECOM	2009-07-08 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6880	\N	\N
8323	MEMBRECOM	2009-07-08 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6881	\N	\N
8324	MEMBRECOM	2009-07-08 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6882	\N	2014-09-28 17:31:41
8344	MEMBRECOM	2009-09-15 00:00:00	2012-06-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6900	\N	\N
8584	MEMBRECOM	2010-01-21 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7136	\N	\N
8585	MEMBRECOM	2010-02-17 00:00:00	2010-02-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7139	\N	\N
8586	MEMBRECOM	2010-02-17 00:00:00	2010-08-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7140	\N	\N
8588	MEMBRECOM	2010-02-17 00:00:00	2010-08-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7142	\N	\N
8589	MEMBRECOM	2010-02-17 00:00:00	2010-08-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7143	\N	\N
8590	MEMBRECOM	2010-02-17 00:00:00	2010-02-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7144	\N	\N
8591	MEMBRECOM	2010-02-17 00:00:00	2010-08-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7145	\N	\N
8592	MEMBRECOM	2010-02-17 00:00:00	2010-08-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7146	\N	\N
8594	MEMBRECOM	2010-02-17 00:00:00	2010-08-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7148	\N	\N
8596	MEMBRECOM	2010-02-17 00:00:00	2010-08-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7151	\N	\N
8597	MEMBRECOM	2010-02-17 00:00:00	2010-02-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7152	\N	\N
8598	MEMBRECOM	2010-02-17 00:00:00	2010-02-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7153	\N	\N
8599	MEMBRECOM	2010-02-17 00:00:00	2010-08-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7154	\N	\N
8600	MEMBRECOM	2010-02-17 00:00:00	2010-08-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7155	\N	\N
8601	MEMBRECOM	2010-02-17 00:00:00	2010-08-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7156	\N	\N
8106	MEMBRECOM	2009-03-11 00:00:00	2009-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6677	\N	\N
8109	MEMBRECOM	2009-03-11 00:00:00	2009-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6680	\N	\N
8050	MEMBRECOM	2009-03-05 00:00:00	2009-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6620	\N	\N
8053	MEMBRECOM	2009-03-05 00:00:00	2009-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6623	\N	\N
8070	MEMBRECOM	2009-03-05 00:00:00	2009-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6640	\N	\N
8533	MEMBRECOM	2009-12-21 00:00:00	2010-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7085	\N	\N
8577	MEMBRECOM	2009-12-22 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7129	\N	2014-09-28 17:27:35
8536	VICPDTCOM	2009-12-17 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7088	\N	2014-09-28 18:58:21
8537	MEMBRECOM	2009-12-17 00:00:00	2018-12-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7089	\N	\N
8538	RAPCOM	2009-12-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7090	\N	\N
8539	MEMBRECOM	2009-12-17 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7091	\N	\N
8540	MEMBRECOM	2009-12-17 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7092	\N	2017-09-24 17:47:27
8570	MEMBRECOM	2009-12-22 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7122	\N	\N
8571	MEMBRECOM	2009-12-22 00:00:00	2019-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7123	\N	\N
8573	MEMBRECOM	2009-12-22 00:00:00	2018-12-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7125	\N	\N
8575	MEMBRECOM	2009-12-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7127	\N	\N
8649	VICPDTCOM	2010-02-16 00:00:00	2014-07-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7178	\N	2014-07-01 09:25:11
8578	MEMBRECOM	2009-12-22 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7130	\N	\N
8579	MEMBRECOM	2009-12-22 00:00:00	2017-05-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7131	\N	2017-05-16 15:18:13
8602	MEMBRECOM	2010-02-17 00:00:00	2010-02-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7157	\N	\N
8604	MEMBRECOM	2010-02-17 00:00:00	2010-08-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7159	\N	\N
8650	RAPCOM	2010-02-16 00:00:00	2015-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7179	\N	2015-01-08 17:14:29
8664	MEMBRECOM	2010-02-18 00:00:00	2011-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7193	\N	\N
8678	MEMBRECOM	2010-03-23 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7207	\N	2014-09-28 17:22:11
8681	MEMBRECOM	2010-03-23 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7210	\N	\N
8683	MEMBRECOM	2010-03-30 00:00:00	2010-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7211	\N	\N
8684	MEMBRECOM	2010-03-30 00:00:00	2010-03-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7212	\N	\N
8685	MEMBRECOM	2010-03-30 00:00:00	2010-03-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7213	\N	\N
8686	MEMBRECOM	2010-03-30 00:00:00	2010-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7214	\N	\N
8688	MEMBRECOM	2010-03-30 00:00:00	2010-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7216	\N	\N
8689	MEMBRECOM	2010-03-30 00:00:00	2010-03-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7217	\N	\N
8690	MEMBRECOM	2010-03-30 00:00:00	2010-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7218	\N	\N
8691	MEMBRECOM	2010-03-30 00:00:00	2010-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7219	\N	\N
8620	PDTCOM	2010-02-24 00:00:00	2010-08-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7139	\N	\N
889	MEMBRECOM	2001-10-03 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	737	\N	\N
1183	PDTCOM	2001-10-04 00:00:00	2004-04-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	289	\N	\N
3002	MEMBRECOM	2004-02-11 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2205	\N	\N
3125	MEMBRECOM	2004-04-15 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2273	\N	2017-09-24 18:20:10
3154	MEMBRECOM	2004-05-26 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2301	\N	2014-09-28 13:19:48
3162	MEMBRECOM	2004-05-26 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2309	\N	\N
3170	MEMBRECOM	2004-06-09 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2317	\N	\N
3516	VICPDTCOM	2004-10-07 00:00:00	2008-10-06 00:00:00	3	ANCIEN	\N	\N	\N	\N	609	\N	\N
3530	VICPDTCOM	2004-10-07 00:00:00	2008-10-06 00:00:00	3	ANCIEN	\N	\N	\N	\N	93	\N	\N
4931	MEMBRECOM	2008-06-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4019	\N	\N
4990	MEMBRECOM	2008-07-09 00:00:00	2008-07-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4075	\N	\N
4934	MEMBRECOM	2008-06-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4022	\N	\N
4935	MEMBRECOM	2008-06-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4023	\N	\N
4936	MEMBRECOM	2008-06-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4024	\N	\N
4991	MEMBRECOM	2008-07-09 00:00:00	2008-07-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4076	\N	2014-09-28 18:19:47
4992	MEMBRECOM	2008-07-09 00:00:00	2008-07-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4077	\N	\N
4993	RAPCOM	2008-07-09 00:00:00	2008-07-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4078	\N	\N
5038	MEMBRECOM	2008-09-08 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4122	\N	\N
4807	MEMBRECOM	2008-01-16 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3892	\N	\N
4810	MEMBRECOM	2008-01-16 00:00:00	2008-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3895	\N	\N
4824	MEMBRECOM	2008-01-24 00:00:00	2008-01-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3909	\N	\N
4880	MEMBRECOM	2008-05-14 00:00:00	2008-05-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3967	\N	2014-09-28 13:39:20
4881	MEMBRECOM	2008-05-14 00:00:00	2008-05-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3968	\N	2017-09-24 17:09:24
4889	MEMBRECOM	2008-05-21 00:00:00	2008-06-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3976	\N	\N
4890	MEMBRECOM	2008-05-21 00:00:00	2008-06-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3977	\N	2014-09-28 17:07:41
4891	MEMBRECOM	2008-05-21 00:00:00	2008-06-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3978	\N	2017-09-24 17:35:15
4892	MEMBRECOM	2008-05-21 00:00:00	2008-06-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3979	\N	2014-09-28 17:07:41
4893	MEMBRECOM	2008-05-21 00:00:00	2008-06-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3980	\N	\N
4896	MEMBRECOM	2008-05-21 00:00:00	2008-06-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3983	\N	\N
4897	MEMBRECOM	2008-05-21 00:00:00	2008-06-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3984	\N	\N
4898	MEMBRECOM	2008-05-21 00:00:00	2008-06-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3985	\N	\N
4416	MEMBRECOM	2007-01-10 00:00:00	2007-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3498	\N	\N
4420	MEMBRECOM	2007-01-10 00:00:00	2007-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3502	\N	\N
5039	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4123	\N	\N
5041	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4125	\N	\N
5043	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4127	\N	\N
5051	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4133	\N	\N
5053	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4135	\N	\N
5054	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4136	\N	\N
5057	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4139	\N	\N
5070	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4154	\N	\N
5301	SECRETCOM	2008-10-07 00:00:00	2011-09-30 00:00:00	1	ANCIEN	\N	\N	\N	\N	292	\N	\N
5302	VICPDTCOM	2008-10-07 00:00:00	2011-09-30 00:00:00	1	ANCIEN	\N	\N	\N	\N	87	\N	\N
5303	MEMBRECOM	2008-10-07 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4334	\N	\N
5304	VICPDTCOM	2008-10-07 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	439	\N	\N
5305	MEMBRECOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4335	\N	\N
5306	PDTCOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	227	\N	\N
7895	MEMBRECOM	2008-10-29 00:00:00	2008-11-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6465	\N	\N
5308	VICPDTCOM	2008-10-07 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	236	\N	\N
5309	MEMBRECOM	2008-10-07 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4336	\N	\N
5310	MEMBRECOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4337	\N	\N
5311	MEMBRECOM	2008-10-07 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4338	\N	\N
5313	MEMBRECOM	2008-10-07 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4339	\N	\N
5314	MEMBRECOM	2008-10-07 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4340	\N	\N
5315	MEMBRECOM	2008-10-07 00:00:00	2010-03-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4341	\N	\N
5316	SECRETCOM	2008-10-07 00:00:00	2011-09-30 00:00:00	3	ANCIEN	\N	\N	\N	\N	795	\N	\N
5318	MEMBRECOM	2008-10-07 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4342	\N	\N
5319	MEMBRECOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4343	\N	\N
7897	MEMBRECOM	2008-10-29 00:00:00	2008-11-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6467	\N	2017-09-24 13:44:49
7920	MEMBRECOM	2008-11-20 00:00:00	2008-11-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6490	\N	\N
7921	MEMBRECOM	2008-11-20 00:00:00	2008-11-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6491	\N	\N
7922	MEMBRECOM	2008-11-20 00:00:00	2008-11-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6492	\N	\N
7924	MEMBRECOM	2008-11-20 00:00:00	2008-11-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6494	\N	2014-09-28 17:07:41
7925	MEMBRECOM	2008-11-20 00:00:00	2008-11-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6495	\N	2017-09-24 13:44:49
7937	MEMBRECOM	2008-11-13 00:00:00	2009-01-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6507	\N	\N
7947	SECRETCOM	1986-10-09 00:00:00	1996-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2030	\N	\N
8012	MEMBRECOM	2009-02-27 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6580	\N	2014-09-28 16:40:50
8013	MEMBRECOM	2009-02-27 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	6581	\N	\N
8014	MEMBRECOM	2009-02-27 00:00:00	2017-05-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6582	\N	2017-05-16 15:18:13
8015	MEMBRECOM	2009-02-27 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6583	\N	2014-09-28 17:40:23
8016	MEMBRECOM	2009-02-27 00:00:00	2016-11-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6584	\N	2016-12-01 10:36:51
8017	MEMBRECOM	2009-02-27 00:00:00	2019-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6585	\N	\N
8018	MEMBRECOM	2009-02-27 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6586	\N	\N
8116	MEMBRECOM	2009-04-02 00:00:00	2017-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6690	\N	2017-09-25 09:56:00
8024	MEMBRECOM	2009-02-11 00:00:00	2009-02-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6592	\N	\N
8025	MEMBRECOM	2009-02-11 00:00:00	2009-02-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6593	\N	2017-09-24 17:09:24
8026	MEMBRECOM	2009-02-11 00:00:00	2009-02-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6594	\N	\N
8027	MEMBRECOM	2009-02-11 00:00:00	2009-02-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6595	\N	\N
8028	MEMBRECOM	2009-02-11 00:00:00	2009-02-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6596	\N	2014-09-28 16:40:50
8029	MEMBRECOM	2009-02-11 00:00:00	2009-02-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6597	\N	2017-05-16 15:18:13
8030	MEMBRECOM	2009-02-11 00:00:00	2009-02-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6598	\N	2014-09-28 17:40:23
8031	MEMBRECOM	2009-02-11 00:00:00	2009-02-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6599	\N	2014-09-28 16:40:50
8033	MEMBRECOM	2009-02-11 00:00:00	2009-02-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6601	\N	\N
8114	MEMBRECOM	2009-04-02 00:00:00	2012-05-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6688	\N	\N
8115	MEMBRECOM	2009-04-02 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6689	\N	2014-09-28 16:59:41
8117	MEMBRECOM	2009-04-02 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6691	\N	\N
8118	MEMBRECOM	2009-04-02 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6692	\N	\N
7904	VICPDTCOM	2008-10-29 00:00:00	2008-11-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6474	\N	\N
7906	MEMBRECOM	2008-10-29 00:00:00	2008-11-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6476	\N	2017-09-24 18:05:41
7907	MEMBRECOM	2008-10-29 00:00:00	2008-11-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6477	\N	\N
7908	MEMBRECOM	2008-10-29 00:00:00	2008-11-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6478	\N	\N
7909	MEMBRECOM	2008-10-29 00:00:00	2008-11-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6479	\N	\N
8177	SECRETCOM	2009-04-29 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6722	\N	\N
8195	MEMBRECOM	2009-06-17 00:00:00	2009-07-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6770	\N	\N
8196	MEMBRECOM	2009-06-17 00:00:00	2009-07-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6771	\N	\N
8200	MEMBRECOM	2009-06-10 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6775	\N	\N
8201	MEMBRECOM	2009-06-10 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6776	\N	\N
8202	MEMBRECOM	2009-06-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6777	\N	2014-09-28 17:34:16
8203	MEMBRECOM	2009-06-10 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6778	\N	\N
8204	MEMBRECOM	2009-06-10 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6779	\N	2017-09-24 13:44:49
8205	MEMBRECOM	2009-06-10 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6780	\N	\N
8206	MEMBRECOM	2009-06-10 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6781	\N	\N
8207	MEMBRECOM	2009-06-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6782	\N	2014-09-28 17:07:41
8208	MEMBRECOM	2009-06-10 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6783	\N	\N
8209	MEMBRECOM	2009-06-10 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6784	\N	2017-09-24 16:43:43
8210	MEMBRECOM	2009-06-10 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6785	\N	\N
3919	MEMBRECOM	2005-11-03 00:00:00	2006-05-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3009	\N	\N
3922	MEMBRECOM	2005-11-03 00:00:00	2006-05-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3012	\N	\N
3925	MEMBRECOM	2005-11-03 00:00:00	2006-05-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3016	\N	\N
3930	MEMBRECOM	2005-11-03 00:00:00	2006-05-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3021	\N	\N
3935	MEMBRECOM	2005-11-03 00:00:00	2006-05-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3026	\N	\N
8211	VICPDTCOM	2009-07-22 00:00:00	2009-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6786	\N	\N
8212	MEMBRECOM	2009-07-22 00:00:00	2009-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6787	\N	\N
8213	MEMBRECOM	2009-07-22 00:00:00	2009-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6789	\N	\N
8214	MEMBRECOM	2009-07-22 00:00:00	2009-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6790	\N	\N
8215	MEMBRECOM	2009-07-22 00:00:00	2009-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6791	\N	\N
8216	SECRETCOM	2009-07-22 00:00:00	2009-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6792	\N	\N
8217	MEMBRECOM	2009-07-22 00:00:00	2009-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6793	\N	\N
8218	MEMBRECOM	2009-07-22 00:00:00	2009-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6794	\N	\N
8219	MEMBRECOM	2009-07-22 00:00:00	2009-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6795	\N	\N
8220	MEMBRECOM	2009-07-22 00:00:00	2009-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6796	\N	\N
8221	VICPDTCOM	2009-07-22 00:00:00	2009-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6797	\N	\N
5352	SECRETCOM	2008-10-08 00:00:00	2011-09-30 00:00:00	2	ANCIEN	\N	\N	\N	\N	2600	\N	\N
5354	SECRETCOM	2008-10-08 00:00:00	2011-09-30 00:00:00	4	ANCIEN	\N	\N	\N	\N	3674	\N	\N
5355	SECRETCOM	2008-10-08 00:00:00	2011-09-30 00:00:00	5	ANCIEN	\N	\N	\N	\N	176	\N	\N
5356	SECRETCOM	2008-10-08 00:00:00	2011-09-30 00:00:00	7	ANCIEN	\N	\N	\N	\N	2532	\N	\N
7852	MEMBRECOM	2008-10-15 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6423	\N	\N
7853	PDTCOM	2008-10-15 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6424	\N	\N
7854	MEMBRECOM	2008-10-15 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6425	\N	\N
7855	MEMBRECOM	2008-10-15 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6426	\N	\N
7856	MEMBRECOM	2008-10-15 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6427	\N	\N
7858	VICPDTCOM	2008-10-15 00:00:00	2009-06-30 00:00:00	1	ANCIEN	\N	\N	\N	\N	6429	\N	\N
7859	MEMBRECOM	2008-10-15 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6430	\N	\N
7860	MEMBRECOM	2008-10-15 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6431	\N	\N
7861	SECRETCOM	2008-10-15 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6432	\N	\N
7862	MEMBRECOM	2008-10-15 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6433	\N	\N
7864	VICPDTCOM	2008-10-15 00:00:00	2009-06-30 00:00:00	2	ANCIEN	\N	\N	\N	\N	6435	\N	\N
7865	MEMBRECOM	2008-10-15 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6436	\N	\N
7866	RAPCOM	2008-10-15 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6437	\N	\N
7867	VICPDTCOM	2008-10-15 00:00:00	2009-06-30 00:00:00	2	ANCIEN	\N	\N	\N	\N	6438	\N	\N
7868	MEMBRECOM	2008-10-15 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6439	\N	\N
7870	RAPCOM	2008-10-15 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6441	\N	\N
7871	MEMBRECOM	2008-10-15 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6442	\N	\N
7873	MEMBRECOM	2008-10-15 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6444	\N	\N
7874	MEMBRECOM	2008-10-15 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6445	\N	\N
7876	MEMBRECOM	2008-10-15 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6447	\N	\N
7877	MEMBRECOM	2008-10-15 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6448	\N	\N
7878	MEMBRECOM	2008-10-15 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6449	\N	\N
7879	MEMBRECOM	2008-10-15 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6450	\N	\N
7880	MEMBRECOM	2008-10-15 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6451	\N	\N
7881	MEMBRECOM	2008-10-15 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6452	\N	\N
7883	MEMBRECOM	2008-10-15 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6454	\N	\N
7884	SECRETCOM	2008-10-15 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6455	\N	\N
7885	MEMBRECOM	2008-10-15 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6456	\N	\N
7986	MEMBRECOM	2009-01-21 00:00:00	2009-01-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6554	\N	2014-09-28 17:22:11
7963	MEMBRECOM	2008-12-19 00:00:00	2008-12-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6531	\N	2014-07-01 09:25:11
7964	MEMBRECOM	2008-12-19 00:00:00	2008-12-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6532	\N	2015-01-08 17:14:29
7965	MEMBRECOM	2008-12-19 00:00:00	2008-12-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6533	\N	2014-09-28 13:16:32
8222	MEMBRECOM	2009-07-22 00:00:00	2009-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6798	\N	\N
8223	SECRETCOM	2009-07-22 00:00:00	2009-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6800	\N	\N
8224	MEMBRECOM	2009-07-22 00:00:00	2009-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6801	\N	\N
8225	PDTCOM	2009-07-22 00:00:00	2009-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6802	\N	\N
8226	MEMBRECOM	2009-07-22 00:00:00	2009-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6803	\N	\N
8227	SECRETCOM	2009-07-22 00:00:00	2009-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6804	\N	\N
8228	MEMBRECOM	2009-07-22 00:00:00	2009-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6805	\N	\N
8229	MEMBRECOM	2009-07-22 00:00:00	2009-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6806	\N	\N
8230	VICPDTCOM	2009-07-22 00:00:00	2009-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6807	\N	\N
8231	SECRETCOM	2009-07-22 00:00:00	2009-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6808	\N	\N
8232	MEMBRECOM	2009-07-22 00:00:00	2009-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6809	\N	\N
8233	MEMBRECOM	2009-07-22 00:00:00	2009-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6810	\N	\N
8234	MEMBRECOM	2009-07-22 00:00:00	2009-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6811	\N	\N
8235	RAPCOM	2009-07-22 00:00:00	2009-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6812	\N	\N
8236	MEMBRECOM	2009-07-22 00:00:00	2009-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6813	\N	\N
8309	MEMBRECOM	2009-09-21 00:00:00	2012-06-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6867	\N	\N
8238	VICPDTCOM	2009-07-22 00:00:00	2009-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6815	\N	\N
8239	MEMBRECOM	2009-07-22 00:00:00	2009-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6816	\N	\N
8240	MEMBRECOM	2009-07-22 00:00:00	2009-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6817	\N	\N
8241	MEMBRECOM	2009-07-22 00:00:00	2009-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6818	\N	\N
8242	MEMBRECOM	2009-07-22 00:00:00	2009-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6819	\N	\N
8243	MEMBRECOM	2009-07-22 00:00:00	2009-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6820	\N	\N
8244	MEMBRECOM	2009-07-22 00:00:00	2009-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6821	\N	\N
8245	MEMBRECOM	2009-07-22 00:00:00	2009-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6822	\N	\N
8246	MEMBRECOM	2009-07-22 00:00:00	2009-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6823	\N	\N
8310	MEMBRECOM	2009-07-24 00:00:00	2009-09-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6868	\N	\N
8307	MEMBRECOM	2009-07-21 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6865	\N	\N
8316	MEMBRECOM	2009-07-08 00:00:00	2012-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6874	\N	\N
8318	MEMBRECOM	2009-07-08 00:00:00	2020-11-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6876	\N	\N
8332	MEMBRECOM	2009-07-21 00:00:00	2012-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6890	\N	\N
8333	MEMBRECOM	2009-07-21 00:00:00	2017-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6891	\N	2017-07-24 09:56:26
8334	MEMBRECOM	2009-07-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	6892	\N	\N
8335	MEMBRECOM	2009-07-21 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6893	\N	2014-09-28 13:21:47
8336	MEMBRECOM	2009-07-21 00:00:00	2019-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6894	\N	\N
8337	MEMBRECOM	2009-07-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	6895	\N	\N
8342	MEMBRECOM	2009-09-21 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6899	\N	\N
8345	SECRETCOM	2009-09-29 00:00:00	2011-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	771	\N	\N
7891	RAPCOM	2008-10-29 00:00:00	2008-11-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6461	\N	\N
7892	MEMBRECOM	2008-10-29 00:00:00	2008-11-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6462	\N	\N
7896	MEMBRECOM	2008-10-29 00:00:00	2008-11-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6466	\N	2014-09-28 17:07:41
7898	MEMBRECOM	2008-10-29 00:00:00	2008-11-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6468	\N	2014-11-04 11:22:47
7899	MEMBRECOM	2008-10-29 00:00:00	2008-11-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6469	\N	\N
7900	MEMBRECOM	2008-10-29 00:00:00	2008-11-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6470	\N	2017-09-24 17:35:15
7901	MEMBRECOM	2008-10-29 00:00:00	2008-11-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6471	\N	2017-09-24 19:25:10
7902	MEMBRECOM	2008-10-29 00:00:00	2008-11-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6472	\N	2017-09-24 17:47:27
7903	MEMBRECOM	2008-10-29 00:00:00	2008-11-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6473	\N	2017-09-24 17:28:55
7910	MEMBRECOM	2008-10-29 00:00:00	2008-11-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6480	\N	2017-09-24 17:35:15
7912	MEMBRECOM	2008-10-29 00:00:00	2008-11-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6482	\N	\N
7913	MEMBRECOM	2008-10-29 00:00:00	2008-11-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6483	\N	2017-09-24 17:47:27
7950	MEMBRECOM	2008-12-09 00:00:00	2008-12-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6518	\N	2014-09-28 13:16:32
7952	MEMBRECOM	2008-12-09 00:00:00	2008-12-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6520	\N	2015-06-12 15:59:49
7953	MEMBRECOM	2008-12-09 00:00:00	2008-12-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6521	\N	\N
7954	MEMBRECOM	2008-12-09 00:00:00	2008-12-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6522	\N	2018-05-31 10:52:17
7955	MEMBRECOM	2008-12-09 00:00:00	2008-12-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6523	\N	\N
8034	MEMBRECOM	2009-03-05 00:00:00	2009-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6602	\N	\N
8035	MEMBRECOM	2009-03-05 00:00:00	2009-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6603	\N	\N
8036	MEMBRECOM	2009-03-05 00:00:00	2009-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6604	\N	\N
8037	MEMBRECOM	2009-03-05 00:00:00	2009-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6605	\N	\N
8038	MEMBRECOM	2009-03-05 00:00:00	2009-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6607	\N	\N
8039	MEMBRECOM	2009-03-05 00:00:00	2009-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6608	\N	\N
8040	MEMBRECOM	2009-03-05 00:00:00	2009-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6609	\N	\N
8041	MEMBRECOM	2009-03-05 00:00:00	2009-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6610	\N	\N
8042	MEMBRECOM	2009-03-05 00:00:00	2009-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6611	\N	\N
8043	MEMBRECOM	2009-03-05 00:00:00	2009-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6612	\N	\N
8044	MEMBRECOM	2009-03-05 00:00:00	2009-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6613	\N	\N
8045	MEMBRECOM	2009-03-05 00:00:00	2009-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6614	\N	\N
10875	MEMBRECOM	2013-03-13 00:00:00	2013-03-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9161	\N	\N
8047	MEMBRECOM	2009-03-05 00:00:00	2009-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6616	\N	\N
8048	MEMBRECOM	2009-03-05 00:00:00	2009-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6618	\N	\N
8049	MEMBRECOM	2009-03-05 00:00:00	2009-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6619	\N	\N
8051	MEMBRECOM	2009-03-05 00:00:00	2009-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6621	\N	\N
8052	MEMBRECOM	2009-03-05 00:00:00	2009-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6622	\N	\N
10876	MEMBRECOM	2013-03-13 00:00:00	2013-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9162	\N	\N
5340	PDTCOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	247	\N	\N
5343	VICPDTCOM	2008-10-08 00:00:00	2014-09-30 00:00:00	9	ANCIEN	\N	\N	\N	\N	863	\N	2014-09-28 12:09:44
5347	VICPDTCOM	2008-10-08 00:00:00	2011-09-30 00:00:00	6	ANCIEN	\N	\N	\N	\N	755	\N	\N
5346	VICPDTCOM	2008-10-08 00:00:00	2011-09-30 00:00:00	4	ANCIEN	\N	\N	\N	\N	844	\N	\N
5349	VICPDTCOM	2008-10-08 00:00:00	2011-09-30 00:00:00	7	ANCIEN	\N	\N	\N	\N	2825	\N	\N
5351	SECRETCOM	2008-10-08 00:00:00	2011-09-30 00:00:00	1	ANCIEN	\N	\N	\N	\N	528	\N	\N
5353	SECRETCOM	2008-10-08 00:00:00	2011-09-30 00:00:00	3	ANCIEN	\N	\N	\N	\N	754	\N	\N
8055	MEMBRECOM	2009-03-05 00:00:00	2009-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6625	\N	\N
8056	MEMBRECOM	2009-03-05 00:00:00	2009-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6626	\N	\N
8057	MEMBRECOM	2009-03-05 00:00:00	2009-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6627	\N	\N
8058	MEMBRECOM	2009-03-05 00:00:00	2009-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6628	\N	\N
8059	MEMBRECOM	2009-03-05 00:00:00	2009-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6629	\N	\N
8060	MEMBRECOM	2009-03-05 00:00:00	2009-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6630	\N	\N
8061	MEMBRECOM	2009-03-05 00:00:00	2009-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6631	\N	\N
8062	MEMBRECOM	2009-03-05 00:00:00	2009-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6632	\N	\N
8063	MEMBRECOM	2009-03-05 00:00:00	2009-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6633	\N	\N
8064	MEMBRECOM	2009-03-05 00:00:00	2009-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6634	\N	\N
8065	MEMBRECOM	2009-03-05 00:00:00	2009-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6635	\N	\N
8066	MEMBRECOM	2009-03-05 00:00:00	2009-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6636	\N	\N
8067	MEMBRECOM	2009-03-05 00:00:00	2009-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6637	\N	\N
8068	MEMBRECOM	2009-03-05 00:00:00	2009-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6638	\N	\N
8069	MEMBRECOM	2009-03-05 00:00:00	2009-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6639	\N	\N
8071	MEMBRECOM	2009-03-05 00:00:00	2009-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6642	\N	\N
8072	MEMBRECOM	2009-03-05 00:00:00	2009-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6643	\N	\N
8125	PDTCOM	2009-04-02 00:00:00	2009-04-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6699	\N	2017-09-24 18:16:52
8127	MEMBRECOM	2009-04-02 00:00:00	2009-04-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6701	\N	2014-09-28 13:19:48
8139	MEMBRECOM	2009-04-29 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6713	\N	\N
8141	MEMBRECOM	2009-04-29 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6715	\N	\N
8142	VICPDTCOM	2009-04-29 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6716	\N	\N
8143	VICPDTCOM	2009-04-29 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6717	\N	\N
8144	VICPDTCOM	2009-04-29 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6718	\N	\N
8145	MEMBRECOM	2009-04-29 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6719	\N	\N
8146	MEMBRECOM	2009-04-29 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6720	\N	\N
8147	VICPDTCOM	2009-04-29 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6721	\N	\N
8148	MEMBRECOM	2009-04-29 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6723	\N	\N
8149	MEMBRECOM	2009-04-29 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6724	\N	\N
8150	MEMBRECOM	2009-04-29 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6725	\N	\N
7948	MEMBRECOM	2008-12-09 00:00:00	2008-12-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6516	\N	2014-07-01 09:25:11
7949	MEMBRECOM	2008-12-09 00:00:00	2008-12-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6517	\N	2015-01-08 17:14:29
7951	MEMBRECOM	2008-12-09 00:00:00	2008-12-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6519	\N	2014-09-28 16:59:41
7956	MEMBRECOM	2008-12-09 00:00:00	2008-12-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6524	\N	\N
7957	MEMBRECOM	2008-12-09 00:00:00	2008-12-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6525	\N	\N
8163	MEMBRECOM	2009-04-29 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6738	\N	\N
7959	MEMBRECOM	2008-12-09 00:00:00	2008-12-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6527	\N	\N
7960	MEMBRECOM	2008-12-09 00:00:00	2008-12-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6528	\N	\N
7961	MEMBRECOM	2008-12-09 00:00:00	2008-12-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6529	\N	\N
8151	RAPCOM	2009-04-29 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6726	\N	\N
8152	MEMBRECOM	2009-04-29 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6727	\N	\N
8153	MEMBRECOM	2009-04-29 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6728	\N	\N
8154	MEMBRECOM	2009-04-29 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6729	\N	\N
8155	MEMBRECOM	2009-04-29 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6730	\N	\N
8156	MEMBRECOM	2009-04-29 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6731	\N	\N
8157	MEMBRECOM	2009-04-29 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6732	\N	\N
8158	MEMBRECOM	2009-04-29 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6733	\N	\N
8159	MEMBRECOM	2009-04-29 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6734	\N	\N
8160	MEMBRECOM	2009-04-29 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6735	\N	\N
8161	MEMBRECOM	2009-04-29 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6736	\N	\N
8179	RAPCOM	2009-04-28 00:00:00	2009-05-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6754	\N	2017-09-24 17:28:55
8164	SECRETCOM	2009-04-29 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6739	\N	\N
8165	PDTCOM	2009-04-29 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6740	\N	\N
8166	MEMBRECOM	2009-04-29 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6741	\N	\N
8180	MEMBRECOM	2009-04-28 00:00:00	2009-05-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6755	\N	2018-05-31 10:52:17
8168	MEMBRECOM	2009-04-29 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6743	\N	\N
8169	MEMBRECOM	2009-04-29 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6744	\N	\N
8170	MEMBRECOM	2009-04-29 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6745	\N	\N
8171	SECRETCOM	2009-04-29 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6746	\N	\N
8172	VICPDTCOM	2009-04-29 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6747	\N	\N
8173	MEMBRECOM	2009-04-29 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6748	\N	\N
8174	MEMBRECOM	2009-04-29 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6749	\N	\N
8175	MEMBRECOM	2009-04-29 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6750	\N	\N
8176	MEMBRECOM	2009-04-29 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6751	\N	\N
8183	MEMBRECOM	2009-04-28 00:00:00	2009-05-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6758	\N	\N
8197	PDTCOM	2009-06-10 00:00:00	2011-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6772	\N	\N
8198	RAPCOM	2009-06-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	6773	\N	\N
8199	MEMBRECOM	2009-06-10 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6774	\N	\N
5320	MEMBRECOM	2011-10-01 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4344	\N	2014-10-01 19:54:29
7977	MEMBRECOM	2009-01-21 00:00:00	2009-01-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6545	\N	\N
7978	MEMBRECOM	2009-01-21 00:00:00	2009-01-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6546	\N	\N
7979	MEMBRECOM	2009-01-21 00:00:00	2009-01-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6547	\N	\N
7980	VICPDTCOM	2009-01-21 00:00:00	2009-01-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6548	\N	2017-09-24 18:16:52
7991	VICPDTCOM	2009-01-26 00:00:00	2014-07-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6559	\N	2014-07-01 09:25:11
7992	MEMBRECOM	2009-01-26 00:00:00	2012-05-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6560	\N	\N
7993	RAPCOM	2009-01-26 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6561	\N	2014-09-28 13:16:32
7994	MEMBRECOM	2009-01-26 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6562	\N	2014-09-28 16:59:41
7995	MEMBRECOM	2009-01-26 00:00:00	2015-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6563	\N	2015-01-08 17:14:29
7996	MEMBRECOM	2009-01-26 00:00:00	2015-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6564	\N	2015-06-12 15:59:49
7997	MEMBRECOM	2009-01-26 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6565	\N	\N
7998	MEMBRECOM	2009-01-26 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6566	\N	2017-09-24 18:20:10
7999	MEMBRECOM	2009-01-26 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6567	\N	\N
8000	MEMBRECOM	2009-01-26 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6568	\N	2014-09-28 12:21:28
4780	MEMBRECOM	2008-01-10 00:00:00	2008-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3865	\N	\N
4783	MEMBRECOM	2008-01-10 00:00:00	2008-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3868	\N	\N
4786	MEMBRECOM	2008-01-10 00:00:00	2008-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3871	\N	\N
4790	MEMBRECOM	2008-01-10 00:00:00	2008-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3875	\N	\N
4793	MEMBRECOM	2008-01-10 00:00:00	2008-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3879	\N	\N
4798	MEMBRECOM	2008-01-10 00:00:00	2008-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3884	\N	\N
4799	MEMBRECOM	2008-01-10 00:00:00	2008-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3885	\N	\N
4803	MEMBRECOM	2008-01-10 00:00:00	2008-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3889	\N	\N
4395	MEMBRECOM	2007-01-10 00:00:00	2007-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3476	\N	\N
4398	MEMBRECOM	2007-01-10 00:00:00	2007-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3479	\N	\N
4403	MEMBRECOM	2007-01-10 00:00:00	2007-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3484	\N	\N
4411	MEMBRECOM	2007-01-10 00:00:00	2007-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3493	\N	\N
5357	VICPDTCOM	2008-10-08 00:00:00	2011-09-30 00:00:00	2	ANCIEN	\N	\N	\N	\N	2525	\N	\N
5358	VICPDTCOM	2008-10-08 00:00:00	2011-09-30 00:00:00	3	ANCIEN	\N	\N	\N	\N	2578	\N	\N
7938	MEMBRECOM	2008-11-13 00:00:00	2009-01-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6508	\N	2018-05-31 10:52:17
7939	MEMBRECOM	2008-11-13 00:00:00	2009-01-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6509	\N	\N
7940	MEMBRECOM	2008-11-13 00:00:00	2009-01-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6510	\N	2017-09-24 18:20:10
7942	MEMBRECOM	2008-11-13 00:00:00	2009-01-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6512	\N	\N
7943	MEMBRECOM	2008-11-13 00:00:00	2009-01-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6513	\N	2014-09-28 18:19:47
7944	MEMBRECOM	2008-11-13 00:00:00	2009-01-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6514	\N	\N
7945	MEMBRECOM	2008-11-13 00:00:00	2009-01-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6515	\N	2014-09-28 18:03:38
4414	MEMBRECOM	2007-01-10 00:00:00	2007-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3496	\N	\N
4367	MEMBRECOM	2007-01-10 00:00:00	2007-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3448	\N	\N
4371	MEMBRECOM	2007-01-10 00:00:00	2007-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3452	\N	\N
4374	MEMBRECOM	2007-01-10 00:00:00	2007-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3455	\N	\N
4377	MEMBRECOM	2007-01-10 00:00:00	2007-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3458	\N	\N
4382	MEMBRECOM	2007-01-10 00:00:00	2007-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3463	\N	\N
4386	MEMBRECOM	2007-01-10 00:00:00	2007-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3467	\N	\N
4394	MEMBRECOM	2007-01-10 00:00:00	2007-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3475	\N	\N
4207	MEMBRECOM	2006-06-15 00:00:00	2007-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3288	\N	\N
4210	MEMBRECOM	2006-06-15 00:00:00	2007-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3291	\N	\N
4215	MEMBRECOM	2006-06-15 00:00:00	2007-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3296	\N	\N
4218	MEMBRECOM	2006-06-15 00:00:00	2007-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3299	\N	\N
4222	MEMBRECOM	2006-06-15 00:00:00	2007-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3303	\N	\N
8248	MEMBRECOM	2007-12-05 00:00:00	2007-12-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3814	\N	\N
8274	PDTCOM	2009-07-01 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6832	\N	\N
8275	RAPCOM	2009-07-01 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6833	\N	\N
8276	MEMBRECOM	2009-07-01 00:00:00	2015-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6834	\N	2015-06-12 16:01:25
8277	MEMBRECOM	2009-07-01 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6835	\N	\N
5363	VICPDTCOM	2008-10-08 00:00:00	2011-09-30 00:00:00	2	ANCIEN	\N	\N	\N	\N	734	\N	\N
5364	VICPDTCOM	2008-10-08 00:00:00	2011-09-30 00:00:00	8	ANCIEN	\N	\N	\N	\N	2573	\N	\N
5365	SECRETCOM	2008-10-08 00:00:00	2011-09-30 00:00:00	2	ANCIEN	\N	\N	\N	\N	2584	\N	\N
5367	SECRETCOM	2008-10-08 00:00:00	2011-09-30 00:00:00	5	ANCIEN	\N	\N	\N	\N	2538	\N	\N
5368	VICPDTCOM	2008-10-08 00:00:00	2011-09-30 00:00:00	1	ANCIEN	\N	\N	\N	\N	2614	\N	\N
5326	VICPDTCOM	2008-10-08 00:00:00	2011-09-30 00:00:00	5	ANCIEN	\N	\N	\N	\N	2553	\N	\N
5369	VICPDTCOM	2008-10-08 00:00:00	2011-09-30 00:00:00	2	ANCIEN	\N	\N	\N	\N	720	\N	\N
5328	VICPDTCOM	2008-10-08 00:00:00	2011-09-30 00:00:00	7	ANCIEN	\N	\N	\N	\N	2631	\N	\N
5370	VICPDTCOM	2008-10-08 00:00:00	2011-09-30 00:00:00	5	ANCIEN	\N	\N	\N	\N	3349	\N	\N
5372	VICPDTCOM	2008-10-08 00:00:00	2011-09-30 00:00:00	6	ANCIEN	\N	\N	\N	\N	2555	\N	\N
5331	SECRETCOM	2008-10-08 00:00:00	2011-09-30 00:00:00	2	ANCIEN	\N	\N	\N	\N	723	\N	\N
5333	SECRETCOM	2008-10-08 00:00:00	2011-09-30 00:00:00	3	ANCIEN	\N	\N	\N	\N	787	\N	\N
5334	SECRETCOM	2008-10-08 00:00:00	2011-09-30 00:00:00	4	ANCIEN	\N	\N	\N	\N	2564	\N	\N
5335	SECRETCOM	2008-10-07 00:00:00	2010-12-07 00:00:00	5	ANCIEN	\N	\N	\N	\N	3686	\N	\N
5348	VICPDTCOM	2008-10-08 00:00:00	2011-09-30 00:00:00	5	ANCIEN	\N	\N	\N	\N	728	\N	\N
5373	VICPDTCOM	2008-10-08 00:00:00	2011-09-30 00:00:00	7	ANCIEN	\N	\N	\N	\N	2622	\N	\N
5374	SECRETCOM	2008-10-08 00:00:00	2009-07-07 00:00:00	3	ANCIEN	\N	\N	\N	\N	3676	\N	\N
5375	SECRETCOM	2008-10-08 00:00:00	2011-09-30 00:00:00	6	ANCIEN	\N	\N	\N	\N	2559	\N	\N
5342	VICPDTCOM	2008-10-08 00:00:00	2011-09-30 00:00:00	4	ANCIEN	\N	\N	\N	\N	748	\N	\N
7843	MEMBRECOM	2008-10-08 00:00:00	2015-04-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6414	\N	2015-04-21 17:14:30
7844	MEMBRECOM	2008-10-08 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6415	\N	\N
7845	SECRETCOM	2008-10-08 00:00:00	2011-09-30 00:00:00	1	ANCIEN	\N	\N	\N	\N	6416	\N	\N
7846	MEMBRECOM	2008-10-08 00:00:00	2009-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6417	\N	\N
7847	MEMBRECOM	2008-10-08 00:00:00	2009-12-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6418	\N	\N
7848	MEMBRECOM	2008-10-08 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6419	\N	\N
7849	VICPDTCOM	2008-10-08 00:00:00	2011-09-30 00:00:00	3	ANCIEN	\N	\N	\N	\N	6420	\N	\N
7850	MEMBRECOM	2008-10-08 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6421	\N	\N
7851	MEMBRECOM	2008-10-08 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6422	\N	\N
8088	MEMBRECOM	2009-03-11 00:00:00	2009-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6659	\N	\N
8092	MEMBRECOM	2009-03-11 00:00:00	2009-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6663	\N	\N
8096	MEMBRECOM	2009-03-11 00:00:00	2009-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6667	\N	\N
8099	MEMBRECOM	2009-03-11 00:00:00	2009-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6670	\N	\N
8263	RAPGENCOM	2009-07-08 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	178	\N	\N
8264	MEMBRECOM	2009-07-08 00:00:00	2009-09-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	771	\N	\N
8265	PDTCOM	2009-07-08 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3676	\N	\N
8292	MEMBRECOM	2009-07-07 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6850	\N	2014-09-28 13:21:47
8293	MEMBRECOM	2009-07-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6851	\N	\N
8294	MEMBRECOM	2009-07-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6852	\N	\N
8347	MEMBRECOM	2009-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6902	\N	\N
4682	MEMBRECOM	2007-10-11 00:00:00	2007-10-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3763	\N	\N
4683	MEMBRECOM	2007-10-11 00:00:00	2007-10-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3764	\N	\N
4684	MEMBRECOM	2007-10-11 00:00:00	2007-10-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3765	\N	2015-04-21 17:14:30
4685	MEMBRECOM	2007-10-11 00:00:00	2007-10-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3766	\N	\N
4686	MEMBRECOM	2007-10-11 00:00:00	2007-10-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3767	\N	\N
4688	MEMBRECOM	2007-10-11 00:00:00	2007-10-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3769	\N	2017-09-24 13:29:42
4708	MEMBRECOM	2007-12-03 00:00:00	2016-11-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3790	\N	2016-11-18 12:37:50
4778	MEMBRECOM	2008-01-09 00:00:00	2009-06-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3863	\N	\N
4814	MEMBRECOM	2008-01-24 00:00:00	2008-01-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3899	\N	2017-09-24 18:17:56
4816	MEMBRECOM	2008-01-24 00:00:00	2008-01-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3901	\N	\N
4817	MEMBRECOM	2008-01-24 00:00:00	2008-01-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3902	\N	2017-09-24 17:35:15
4818	MEMBRECOM	2008-01-24 00:00:00	2008-01-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3903	\N	\N
4819	MEMBRECOM	2008-01-24 00:00:00	2008-01-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3904	\N	\N
4820	MEMBRECOM	2008-01-24 00:00:00	2008-01-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3905	\N	\N
4826	RAPCOM	2008-01-24 00:00:00	2008-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3911	\N	\N
4827	MEMBRECOM	2008-01-24 00:00:00	2008-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3912	\N	\N
4828	MEMBRECOM	2008-01-24 00:00:00	2008-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3913	\N	2017-09-24 18:17:56
4829	MEMBRECOM	2008-01-24 00:00:00	2008-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3914	\N	\N
4830	MEMBRECOM	2008-01-24 00:00:00	2008-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3915	\N	2014-09-28 17:07:41
4831	MEMBRECOM	2008-01-24 00:00:00	2008-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3916	\N	2017-09-24 17:35:15
4832	MEMBRECOM	2008-01-24 00:00:00	2008-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3917	\N	\N
4851	MEMBRECOM	2008-01-31 00:00:00	2008-02-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3936	\N	2014-09-28 16:42:05
4980	MEMBRECOM	2008-07-10 00:00:00	2008-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4065	\N	\N
4484	MEMBRECOM	2007-02-07 00:00:00	2007-02-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3566	\N	2014-09-28 13:21:47
4523	MEMBRECOM	2007-02-14 00:00:00	2007-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3605	\N	\N
4524	MEMBRECOM	2007-02-14 00:00:00	2007-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3606	\N	\N
4525	MEMBRECOM	2007-02-14 00:00:00	2007-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3607	\N	\N
4527	MEMBRECOM	2007-02-14 00:00:00	2007-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3609	\N	2017-09-24 17:15:15
4528	MEMBRECOM	2007-02-14 00:00:00	2007-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3610	\N	\N
4595	MEMBRECOM	2007-07-05 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3680	\N	\N
4596	MEMBRECOM	2007-07-05 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3681	\N	\N
4706	MEMBRECOM	2007-11-30 00:00:00	2007-12-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3787	\N	\N
5138	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4230	\N	\N
5139	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4231	\N	\N
5140	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4232	\N	\N
5141	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4233	\N	\N
5142	MEMBRECOM	2008-09-25 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4234	\N	\N
5366	SECRETCOM	2008-10-08 00:00:00	2011-09-30 00:00:00	4	ANCIEN	\N	\N	\N	\N	2537	\N	\N
5144	VICPDTCOM	2008-10-07 00:00:00	2011-09-30 00:00:00	2	ANCIEN	\N	\N	\N	\N	496	\N	\N
7887	VICPDTCOM	2008-10-15 00:00:00	2009-06-30 00:00:00	2	ANCIEN	\N	\N	\N	\N	6458	\N	\N
5146	VICPDTCOM	2008-10-07 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	498	\N	\N
5147	MEMBRECOM	2008-10-07 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4235	\N	\N
5148	VICPDTCOM	2008-10-07 00:00:00	2011-09-30 00:00:00	3	ANCIEN	\N	\N	\N	\N	3683	\N	\N
5150	MEMBRECOM	2008-10-07 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4236	\N	2014-09-28 17:52:18
5151	VICPDTCOM	2008-10-07 00:00:00	2011-09-30 00:00:00	7	ANCIEN	\N	\N	\N	\N	2546	\N	\N
5152	MEMBRECOM	2008-10-07 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4237	\N	\N
5153	MEMBRECOM	2008-10-07 00:00:00	2012-01-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4238	\N	2013-12-04 10:36:17
5154	VICPDTCOM	2008-10-07 00:00:00	2011-09-30 00:00:00	6	ANCIEN	\N	\N	\N	\N	173	\N	\N
5155	SECRETCOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4240	\N	\N
4640	RAPCOM	2007-07-27 00:00:00	2007-07-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3724	\N	2015-01-08 17:14:29
4641	MEMBRECOM	2007-07-27 00:00:00	2007-07-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3725	\N	\N
4643	MEMBRECOM	2007-07-27 00:00:00	2007-07-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3727	\N	\N
4644	MEMBRECOM	2007-07-27 00:00:00	2007-07-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3728	\N	\N
4645	MEMBRECOM	2007-07-27 00:00:00	2007-07-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3729	\N	2018-05-31 10:52:17
4646	MEMBRECOM	2007-07-27 00:00:00	2007-07-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3730	\N	\N
4648	MEMBRECOM	2007-07-27 00:00:00	2007-07-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3732	\N	\N
4649	MEMBRECOM	2007-07-27 00:00:00	2007-07-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3733	\N	\N
4650	MEMBRECOM	2007-07-27 00:00:00	2007-07-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3734	\N	2015-06-12 15:59:49
4651	MEMBRECOM	2007-07-27 00:00:00	2007-07-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3735	\N	\N
4652	MEMBRECOM	2007-07-27 00:00:00	2007-07-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3736	\N	2014-09-28 18:03:38
4882	MEMBRECOM	2008-05-14 00:00:00	2008-05-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3969	\N	2014-09-28 17:55:39
4883	MEMBRECOM	2008-05-14 00:00:00	2008-05-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3970	\N	2017-05-16 15:18:13
5050	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4132	\N	\N
5052	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4134	\N	\N
5056	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4138	\N	\N
5058	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4140	\N	\N
5059	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4141	\N	\N
5074	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4159	\N	\N
5092	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4180	\N	\N
5097	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4186	\N	\N
5099	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4188	\N	\N
5100	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4189	\N	\N
5102	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4191	\N	\N
5103	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4192	\N	\N
5108	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4198	\N	\N
5113	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4204	\N	\N
5115	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4206	\N	\N
5119	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4210	\N	\N
5126	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4218	\N	\N
5130	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4222	\N	\N
5132	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4224	\N	\N
5134	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4226	\N	\N
5136	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4228	\N	\N
5156	MEMBRECOM	2008-10-07 00:00:00	2012-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4241	\N	\N
4290	MEMBRECOM	1965-03-03 00:00:00	1983-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3371	\N	\N
4425	MEMBRECOM	2007-01-23 00:00:00	2007-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3507	\N	\N
4426	MEMBRECOM	2007-01-23 00:00:00	2007-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3508	\N	\N
4429	VICPDTCOM	2007-01-25 00:00:00	2007-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3511	\N	2015-10-12 09:39:30
4430	RAPCOM	2007-01-25 00:00:00	2007-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3512	\N	2014-09-29 13:41:53
4431	MEMBRECOM	2007-01-25 00:00:00	2007-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3513	\N	2014-09-28 18:00:58
4546	MEMBRECOM	2007-06-26 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3628	\N	\N
4709	MEMBRECOM	2007-12-05 00:00:00	2011-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3791	\N	\N
4710	MEMBRECOM	2007-12-05 00:00:00	2011-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3792	\N	\N
4712	MEMBRECOM	2007-12-05 00:00:00	2011-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3794	\N	\N
4713	MEMBRECOM	2007-12-05 00:00:00	2011-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3795	\N	\N
4714	MEMBRECOM	2007-12-05 00:00:00	2007-12-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3796	\N	\N
4715	MEMBRECOM	2007-12-05 00:00:00	2011-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3797	\N	\N
4716	MEMBRECOM	2007-12-05 00:00:00	2011-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3798	\N	\N
4717	MEMBRECOM	2007-12-05 00:00:00	2011-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3799	\N	\N
4719	MEMBRECOM	2007-12-05 00:00:00	2007-12-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3801	\N	\N
4720	MEMBRECOM	2007-12-05 00:00:00	2011-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3802	\N	\N
4721	MEMBRECOM	2007-12-05 00:00:00	2011-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3803	\N	\N
4722	MEMBRECOM	2007-12-05 00:00:00	2011-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3804	\N	\N
4723	MEMBRECOM	2007-12-05 00:00:00	2011-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3805	\N	\N
4724	MEMBRECOM	2007-12-05 00:00:00	2011-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3806	\N	\N
4726	MEMBRECOM	2007-12-05 00:00:00	2007-12-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3808	\N	\N
4727	MEMBRECOM	2007-12-05 00:00:00	2009-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3809	\N	\N
4728	MEMBRECOM	2007-12-05 00:00:00	2011-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3810	\N	\N
4730	MEMBRECOM	2007-12-05 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3812	\N	\N
4731	MEMBRECOM	2007-12-05 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3813	\N	\N
4732	MEMBRECOM	2007-12-05 00:00:00	2011-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3816	\N	\N
4772	MEMBRECOM	2007-12-18 00:00:00	2007-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3857	\N	\N
4773	MEMBRECOM	2007-12-18 00:00:00	2007-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3858	\N	\N
4774	MEMBRECOM	2007-12-18 00:00:00	2007-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3859	\N	2016-12-12 16:10:15
4775	MEMBRECOM	2007-12-18 00:00:00	2007-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3860	\N	\N
4776	MEMBRECOM	2007-12-18 00:00:00	2007-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3861	\N	\N
4777	MEMBRECOM	2007-12-18 00:00:00	2007-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3862	\N	2014-09-28 18:03:38
4856	MEMBRECOM	2008-03-25 00:00:00	2008-04-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3943	\N	\N
4857	MEMBRECOM	2008-03-25 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3944	\N	\N
5158	PDTCOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4243	\N	\N
5159	VICPDTCOM	2008-10-07 00:00:00	2011-09-30 00:00:00	4	ANCIEN	\N	\N	\N	\N	2560	\N	\N
5191	VICPDTCOM	2008-10-07 00:00:00	2011-09-30 00:00:00	3	ANCIEN	\N	\N	\N	\N	2529	\N	\N
5264	MEMBRECOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4316	\N	\N
5265	VICPDTCOM	2008-10-07 00:00:00	2011-09-30 00:00:00	1	ANCIEN	\N	\N	\N	\N	20	\N	\N
5266	MEMBRECOM	2008-10-07 00:00:00	2015-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4317	\N	2015-06-12 16:01:58
5267	SECRETCOM	2008-10-07 00:00:00	2011-09-30 00:00:00	3	ANCIEN	\N	\N	\N	\N	2820	\N	\N
5268	RAPGENCOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	468	\N	\N
5269	MEMBRECOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4318	\N	\N
5270	SECRETCOM	2008-10-07 00:00:00	2011-09-30 00:00:00	5	ANCIEN	\N	\N	\N	\N	275	\N	\N
4858	MEMBRECOM	2008-04-29 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3945	\N	\N
5271	MEMBRECOM	2008-10-07 00:00:00	2010-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4319	\N	\N
5272	SECRETCOM	2008-10-07 00:00:00	2014-09-30 00:00:00	2	ANCIEN	\N	\N	\N	\N	824	\N	2014-09-29 15:47:31
5274	MEMBRECOM	2008-10-07 00:00:00	2013-12-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4321	\N	2013-12-17 17:10:32
5275	MEMBRECOM	2008-10-07 00:00:00	2009-06-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4322	\N	\N
5276	VICPDTCOM	2008-10-07 00:00:00	2014-09-30 00:00:00	2	ANCIEN	\N	\N	\N	\N	243	\N	2014-09-28 18:00:58
7893	MEMBRECOM	2008-10-29 00:00:00	2008-11-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6463	\N	\N
5278	MEMBRECOM	2008-10-07 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4323	\N	2014-10-08 17:44:19
5279	MEMBRECOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4324	\N	\N
5280	MEMBRECOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	669	\N	\N
7894	MEMBRECOM	2008-10-29 00:00:00	2008-11-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6464	\N	\N
5284	MEMBRECOM	2008-10-07 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4325	\N	\N
5283	VICPDTCOM	2008-10-07 00:00:00	2011-01-13 00:00:00	4	ANCIEN	\N	\N	\N	\N	609	\N	\N
5285	MEMBRECOM	2008-10-07 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4326	\N	2014-10-09 12:11:43
5286	MEMBRECOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	290	\N	\N
5287	MEMBRECOM	2008-10-07 00:00:00	2010-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4327	\N	\N
5288	SECRETCOM	2008-10-07 00:00:00	2011-09-30 00:00:00	4	ANCIEN	\N	\N	\N	\N	680	\N	\N
5289	MEMBRECOM	2008-10-07 00:00:00	2010-03-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4328	\N	\N
5290	MEMBRECOM	2008-10-07 00:00:00	2010-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4329	\N	\N
5291	MEMBRECOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4330	\N	\N
5292	MEMBRECOM	2008-10-07 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	277	\N	2014-09-28 17:35:38
5293	VICPDTCOM	2008-10-07 00:00:00	2011-09-30 00:00:00	1	ANCIEN	\N	\N	\N	\N	35	\N	\N
5295	MEMBRECOM	2008-10-07 00:00:00	2010-10-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4332	\N	\N
5296	PDTCOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	170	\N	\N
5297	MEMBRECOM	2008-10-07 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4333	\N	2017-10-04 18:35:52
5298	SECRETCOM	2008-10-07 00:00:00	2011-09-30 00:00:00	1	ANCIEN	\N	\N	\N	\N	258	\N	\N
5299	MEMBRECOM	2008-10-07 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	740	\N	2017-10-04 18:35:56
5300	VICPDTCOM	2008-10-07 00:00:00	2010-04-16 00:00:00	2	ANCIEN	\N	\N	\N	\N	689	\N	\N
5192	SECRETCOM	2008-10-07 00:00:00	2011-09-30 00:00:00	1	ANCIEN	\N	\N	\N	\N	312	\N	\N
5193	MEMBRECOM	2008-10-07 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4272	\N	2017-10-04 18:38:46
5195	MEMBRECOM	2008-10-07 00:00:00	2009-07-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4273	\N	\N
5196	MEMBRECOM	2008-10-07 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4274	\N	2014-09-28 16:50:17
5197	MEMBRECOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4275	\N	\N
5198	MEMBRECOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4276	\N	\N
5199	MEMBRECOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	514	\N	\N
5200	MEMBRECOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4277	\N	\N
5201	MEMBRECOM	2008-10-07 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4278	\N	2017-09-24 17:47:27
5202	MEMBRECOM	2008-10-07 00:00:00	2013-07-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4280	\N	2013-07-15 18:34:00
5203	MEMBRECOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	741	\N	\N
5204	VICPDTCOM	2008-10-07 00:00:00	2014-09-30 00:00:00	4	ANCIEN	\N	\N	\N	\N	4281	\N	2014-09-28 17:22:11
5205	MEMBRECOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4282	\N	\N
5207	MEMBRECOM	2008-10-07 00:00:00	2014-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4283	\N	2014-02-14 10:10:22
3529	MEMBRECOM	2004-10-06 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	750	\N	\N
5208	MEMBRECOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4284	\N	\N
5209	MEMBRECOM	2008-10-07 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4285	\N	2014-09-28 17:34:16
5210	MEMBRECOM	2008-10-07 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4286	\N	2014-09-28 13:40:33
5211	MEMBRECOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2527	\N	\N
5212	MEMBRECOM	2008-10-07 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4287	\N	2017-09-24 17:42:26
5213	MEMBRECOM	2008-10-07 00:00:00	2013-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	241	\N	\N
5214	MEMBRECOM	2008-10-07 00:00:00	2011-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4288	\N	\N
5215	MEMBRECOM	2008-10-07 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4289	\N	2014-10-08 17:04:21
5216	MEMBRECOM	2008-10-07 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4290	\N	2014-10-09 10:53:17
5217	MEMBRECOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4291	\N	\N
5218	MEMBRECOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4292	\N	\N
5219	SECRETCOM	2008-10-07 00:00:00	2011-09-30 00:00:00	4	ANCIEN	\N	\N	\N	\N	250	\N	\N
5220	MEMBRECOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4293	\N	\N
5221	VICPDTCOM	2008-10-07 00:00:00	2011-09-30 00:00:00	5	ANCIEN	\N	\N	\N	\N	283	\N	\N
5222	MEMBRECOM	2008-10-07 00:00:00	2009-11-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4294	\N	\N
5224	MEMBRECOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4295	\N	\N
5226	MEMBRECOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4296	\N	\N
5227	MEMBRECOM	2008-10-07 00:00:00	2017-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4297	\N	2017-06-19 12:20:59
5228	MEMBRECOM	2008-10-07 00:00:00	2010-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	717	\N	\N
5229	MEMBRECOM	2008-10-07 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4298	\N	\N
8073	MEMBRECOM	2009-03-11 00:00:00	2009-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6644	\N	\N
8074	MEMBRECOM	2009-03-11 00:00:00	2009-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6645	\N	\N
8075	MEMBRECOM	2009-03-11 00:00:00	2009-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6646	\N	\N
8076	MEMBRECOM	2009-03-11 00:00:00	2009-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6647	\N	\N
8077	MEMBRECOM	2009-03-11 00:00:00	2009-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6648	\N	\N
8078	MEMBRECOM	2009-03-11 00:00:00	2009-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6649	\N	\N
8079	MEMBRECOM	2009-03-11 00:00:00	2009-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6650	\N	\N
8080	MEMBRECOM	2009-03-11 00:00:00	2009-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6651	\N	\N
8081	MEMBRECOM	2009-03-11 00:00:00	2009-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6652	\N	\N
8082	MEMBRECOM	2009-03-11 00:00:00	2009-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6653	\N	\N
8083	MEMBRECOM	2009-03-11 00:00:00	2009-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6654	\N	\N
8084	MEMBRECOM	2009-03-11 00:00:00	2009-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6655	\N	\N
8085	MEMBRECOM	2009-03-11 00:00:00	2009-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6656	\N	\N
8086	MEMBRECOM	2009-03-11 00:00:00	2009-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6657	\N	\N
8087	MEMBRECOM	2009-03-11 00:00:00	2009-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6658	\N	\N
8280	MEMBRECOM	2009-07-01 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6838	\N	2017-09-24 18:16:52
8090	MEMBRECOM	2009-03-11 00:00:00	2009-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6661	\N	\N
8091	MEMBRECOM	2009-03-11 00:00:00	2009-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6662	\N	\N
8093	MEMBRECOM	2009-03-11 00:00:00	2009-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6664	\N	\N
8094	MEMBRECOM	2009-03-11 00:00:00	2009-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6665	\N	\N
8095	MEMBRECOM	2009-03-11 00:00:00	2009-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6666	\N	\N
8097	MEMBRECOM	2009-03-11 00:00:00	2009-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6668	\N	\N
8098	MEMBRECOM	2009-03-11 00:00:00	2009-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6669	\N	\N
8100	MEMBRECOM	2009-03-11 00:00:00	2009-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6671	\N	\N
8101	MEMBRECOM	2009-03-11 00:00:00	2009-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6672	\N	\N
8103	MEMBRECOM	2009-03-11 00:00:00	2009-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6674	\N	\N
8104	MEMBRECOM	2009-03-11 00:00:00	2009-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6675	\N	\N
8105	MEMBRECOM	2009-03-11 00:00:00	2009-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6676	\N	\N
8107	MEMBRECOM	2009-03-11 00:00:00	2009-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6678	\N	\N
8108	MEMBRECOM	2009-03-11 00:00:00	2009-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6679	\N	\N
8278	MEMBRECOM	2009-07-01 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6836	\N	2017-09-24 13:14:55
10982	MEMBRECOM	2013-04-02 00:00:00	2014-05-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9269	\N	2014-05-05 10:34:09
8279	MEMBRECOM	2009-07-01 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6837	\N	2017-09-24 17:19:42
5111	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4201	\N	\N
3508	VICPDTCOM	2004-10-07 00:00:00	2008-10-06 00:00:00	3	ANCIEN	\N	\N	\N	\N	758	\N	\N
3528	VICPDTCOM	2004-10-07 00:00:00	2008-10-06 00:00:00	2	ANCIEN	\N	\N	\N	\N	241	\N	\N
7888	MEMBRECOM	2008-10-15 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6457	\N	\N
8282	MEMBRECOM	2009-07-01 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6840	\N	\N
8283	MEMBRECOM	2009-07-01 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6841	\N	2014-09-28 12:56:41
8284	MEMBRECOM	2009-07-01 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6842	\N	2017-09-24 17:04:02
8290	MEMBRECOM	2009-07-07 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6848	\N	\N
8291	MEMBRECOM	2009-07-07 00:00:00	2017-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6849	\N	2017-07-24 09:56:26
8295	MEMBRECOM	2009-07-07 00:00:00	2014-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6853	\N	2014-09-29 13:41:53
8296	MEMBRECOM	2009-07-07 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6854	\N	\N
8297	MEMBRECOM	2009-07-07 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	6855	\N	\N
8298	MEMBRECOM	2009-07-07 00:00:00	2012-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6856	\N	\N
8299	MEMBRECOM	2009-07-07 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6857	\N	2014-09-28 18:00:58
8300	MEMBRECOM	2009-07-07 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6858	\N	2017-09-24 17:35:15
8301	MEMBRECOM	2009-07-07 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	6859	\N	\N
8308	MEMBRECOM	2009-07-21 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6866	\N	\N
8346	MEMBRECOM	2009-09-29 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6831	\N	\N
8348	PDTCOM	2009-09-15 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6903	\N	2017-09-24 18:16:52
8349	RAPCOM	2009-09-15 00:00:00	2010-04-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6904	\N	\N
8350	MEMBRECOM	2009-09-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	6905	\N	\N
8351	MEMBRECOM	2009-09-15 00:00:00	2022-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6906	\N	\N
8352	MEMBRECOM	2009-09-15 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6907	\N	\N
8353	MEMBRECOM	2009-09-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	6908	\N	\N
8354	MEMBRECOM	2009-09-15 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6909	\N	\N
8355	MEMBRECOM	2009-09-15 00:00:00	2017-07-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6910	\N	2017-07-04 15:08:09
8356	MEMBRECOM	2009-09-15 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6911	\N	\N
8357	MEMBRECOM	2009-09-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6912	\N	2014-09-28 18:58:25
8358	MEMBRECOM	2009-09-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6913	\N	2014-09-28 17:35:38
8360	MEMBRECOM	2009-09-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	6915	\N	\N
8361	MEMBRECOM	2009-09-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6916	\N	2014-09-28 17:27:35
8362	PDTCOM	2009-09-29 00:00:00	2015-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6917	\N	2015-10-12 09:39:30
8363	RAPCOM	2009-09-29 00:00:00	2015-04-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6918	\N	2015-04-21 17:14:30
8364	MEMBRECOM	2009-09-29 00:00:00	2011-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6919	\N	\N
8367	MEMBRECOM	2009-09-29 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	6922	\N	\N
5230	MEMBRECOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4300	\N	\N
5231	MEMBRECOM	2008-10-07 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4301	\N	2014-10-09 13:51:32
5232	VICPDTCOM	2008-10-07 00:00:00	2011-09-30 00:00:00	8	ANCIEN	\N	\N	\N	\N	4302	\N	\N
5233	VICPDTCOM	2008-10-07 00:00:00	2011-09-30 00:00:00	4	ANCIEN	\N	\N	\N	\N	4303	\N	\N
5234	MEMBRECOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4304	\N	\N
5235	MEMBRECOM	2008-10-07 00:00:00	2011-01-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4305	\N	\N
5236	MEMBRECOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	407	\N	\N
5237	MEMBRECOM	2008-10-07 00:00:00	2009-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4306	\N	\N
5238	VICPDTCOM	2008-10-07 00:00:00	2011-09-30 00:00:00	6	ANCIEN	\N	\N	\N	\N	257	\N	\N
8968	MEMBRECOM	2010-11-17 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7467	\N	\N
8969	SECRETCOM	2010-11-17 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7468	\N	\N
8970	MEMBRECOM	2010-11-17 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7470	\N	\N
8679	MEMBRECOM	2010-03-23 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7208	\N	2017-10-04 18:38:47
3655	MEMBRECOM	2004-10-20 00:00:00	2010-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2743	\N	\N
3139	MEMBRECOM	2004-05-12 00:00:00	2010-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2286	\N	\N
4598	MEMBRECOM	2007-07-18 00:00:00	2010-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3684	\N	\N
8908	MEMBRECOM	2010-10-06 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7408	\N	\N
8903	MEMBRECOM	2010-10-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7403	\N	\N
8904	MEMBRECOM	2010-10-06 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7404	\N	2014-09-28 13:21:47
8905	MEMBRECOM	2010-10-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7405	\N	\N
8907	MEMBRECOM	2010-10-06 00:00:00	2017-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7407	\N	2017-06-19 12:20:22
8909	MEMBRECOM	2010-10-06 00:00:00	2017-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7409	\N	2017-07-24 09:56:26
8910	MEMBRECOM	2010-10-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7410	\N	\N
8971	MEMBRECOM	2010-11-17 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7471	\N	\N
8972	RAPCOM	2010-11-17 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7472	\N	\N
8973	VICPDTCOM	2010-11-17 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7473	\N	\N
8974	MEMBRECOM	2010-11-17 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7474	\N	\N
8975	MEMBRECOM	2010-11-17 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7475	\N	\N
8976	MEMBRECOM	2010-11-17 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7476	\N	\N
8977	VICPDTCOM	2010-11-17 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7477	\N	\N
8978	MEMBRECOM	2010-11-17 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7478	\N	\N
8979	MEMBRECOM	2010-11-17 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7479	\N	\N
8980	VICPDTCOM	2010-11-17 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7480	\N	\N
8981	VICPDTCOM	2010-11-17 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7481	\N	\N
8982	SECRETCOM	2010-11-17 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7482	\N	\N
8983	MEMBRECOM	2010-11-17 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7483	\N	\N
8984	MEMBRECOM	2010-11-17 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7484	\N	\N
8985	MEMBRECOM	2010-11-17 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7485	\N	\N
8986	PDTCOM	2010-11-17 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7486	\N	\N
8987	MEMBRECOM	2010-11-17 00:00:00	2011-01-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7487	\N	\N
8988	SECRETCOM	2010-11-17 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7488	\N	\N
8989	MEMBRECOM	2010-11-17 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7489	\N	\N
3731	MEMBRECOM	2005-03-01 00:00:00	2010-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2821	\N	\N
8778	PDTCOM	2010-05-04 00:00:00	2011-04-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7265	\N	\N
8779	VICPDTCOM	2010-05-04 00:00:00	2011-04-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7275	\N	\N
8780	VICPDTCOM	2010-05-04 00:00:00	2011-04-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7257	\N	\N
8781	VICPDTCOM	2010-05-04 00:00:00	2011-04-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7267	\N	\N
8782	SECRETCOM	2010-05-04 00:00:00	2011-04-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7276	\N	\N
8783	SECRETCOM	2010-05-04 00:00:00	2011-04-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7268	\N	\N
8784	MEMBRECOM	2010-04-28 00:00:00	2010-05-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7264	\N	\N
8785	SECRETCOM	2010-05-04 00:00:00	2011-04-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7264	\N	\N
8786	SECRETCOM	2010-05-04 00:00:00	2011-04-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7278	\N	\N
8787	RAPCOM	2010-05-04 00:00:00	2011-04-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7255	\N	\N
8931	MEMBRECOM	2010-10-20 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7420	\N	\N
8965	MEMBRECOM	2010-11-04 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7465	\N	\N
9010	MEMBRECOM	2010-12-15 00:00:00	2011-03-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7510	\N	\N
9120	VICPDTCOM	2010-12-17 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7620	\N	2014-09-28 18:58:21
9121	RAPCOM	2010-12-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7621	\N	\N
9122	MEMBRECOM	2010-12-17 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7622	\N	2014-09-28 17:40:23
9123	MEMBRECOM	2010-12-17 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7623	\N	2014-09-28 17:09:16
9124	MEMBRECOM	2010-12-17 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7624	\N	2017-09-24 17:09:24
9125	MEMBRECOM	2010-12-17 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7625	\N	2014-09-28 17:31:42
9126	MEMBRECOM	2010-12-17 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7626	\N	2017-09-24 17:19:42
9127	MEMBRECOM	2010-12-17 00:00:00	2019-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7627	\N	\N
9128	MEMBRECOM	2010-12-17 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7628	\N	\N
9129	MEMBRECOM	2010-12-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7629	\N	\N
9130	MEMBRECOM	2010-12-17 00:00:00	2018-12-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7630	\N	\N
9132	MEMBRECOM	2010-12-17 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7632	\N	2017-09-24 17:47:27
9133	MEMBRECOM	2010-12-17 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7633	\N	\N
9144	MEMBRECOM	2011-01-25 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7645	\N	\N
9204	SECRETCOM	2011-02-16 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	804	\N	\N
9203	MEMBRECOM	2011-01-25 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7704	\N	\N
9205	VICPDTCOM	2011-02-16 00:00:00	2014-10-07 00:00:00	7	ANCIEN	\N	\N	\N	\N	2579	\N	2014-10-08 17:46:33
9206	MEMBRECOM	2011-02-16 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	802	\N	2017-09-24 13:29:42
8657	MEMBRECOM	2010-02-16 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7186	\N	2014-09-28 13:16:32
8658	MEMBRECOM	2010-02-16 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7187	\N	2014-09-28 13:40:33
8659	MEMBRECOM	2010-02-16 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7188	\N	2014-09-28 16:59:41
8802	PDTCOM	2010-06-02 00:00:00	2015-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7308	\N	2015-10-12 09:39:31
8803	RAPCOM	2010-06-02 00:00:00	2015-04-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7309	\N	2015-04-21 17:14:30
8804	MEMBRECOM	2010-06-02 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7310	\N	2014-09-28 18:00:58
8805	MEMBRECOM	2010-06-02 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7311	\N	2014-09-28 13:40:33
8806	MEMBRECOM	2010-06-02 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7312	\N	2014-09-28 17:34:16
8807	MEMBRECOM	2010-06-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7313	\N	\N
8808	MEMBRECOM	2010-06-02 00:00:00	2012-09-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7314	\N	\N
8809	MEMBRECOM	2010-06-02 00:00:00	2017-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7315	\N	2017-06-19 12:20:59
8810	MEMBRECOM	2010-06-02 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7316	\N	2014-09-28 13:21:47
8811	MEMBRECOM	2010-06-02 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7317	\N	2017-09-24 17:15:15
8814	MEMBRECOM	2010-06-02 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7320	\N	\N
8815	MEMBRECOM	2010-06-02 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7321	\N	2017-09-24 13:29:42
5294	MEMBRECOM	2008-10-07 00:00:00	2010-11-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4331	\N	\N
8963	MEMBRECOM	2010-11-03 00:00:00	2010-11-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7463	\N	\N
9042	RAPCOM	2010-12-16 00:00:00	2015-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7542	\N	2015-01-08 17:14:29
9043	MEMBRECOM	2010-12-16 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7543	\N	\N
9045	MEMBRECOM	2010-12-16 00:00:00	2012-05-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7545	\N	\N
9055	VICPDTCOM	2010-12-17 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7555	\N	2014-09-28 18:58:21
9056	RAPCOM	2010-12-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7556	\N	\N
9057	MEMBRECOM	2010-12-17 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7557	\N	2014-09-28 17:40:23
9058	MEMBRECOM	2010-12-17 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7558	\N	2014-09-28 17:09:16
9059	MEMBRECOM	2010-12-17 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7559	\N	2017-09-24 17:09:24
9060	MEMBRECOM	2010-12-17 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7560	\N	2014-09-28 17:31:42
9062	MEMBRECOM	2010-12-17 00:00:00	2019-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7562	\N	\N
9063	MEMBRECOM	2010-12-17 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7563	\N	\N
9064	MEMBRECOM	2010-12-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7564	\N	\N
9065	MEMBRECOM	2010-12-17 00:00:00	2018-12-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7565	\N	\N
9066	MEMBRECOM	2010-12-17 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7566	\N	2014-09-28 17:03:42
9067	MEMBRECOM	2010-12-17 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7567	\N	2017-09-24 17:47:27
9068	MEMBRECOM	2010-12-17 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7568	\N	\N
8849	RAPCOM	2007-12-12 00:00:00	2011-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3817	\N	\N
8850	VICPDTCOM	2007-12-12 00:00:00	2011-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3796	\N	\N
4729	MEMBRECOM	2007-12-05 00:00:00	2007-12-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3811	\N	\N
8851	VICPDTCOM	2007-12-12 00:00:00	2011-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3811	\N	\N
8852	SECRETCOM	2007-12-12 00:00:00	2011-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3814	\N	\N
8853	SECRETCOM	2007-12-12 00:00:00	2011-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3801	\N	\N
8854	VICPDTCOM	2010-06-30 00:00:00	2011-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6967	\N	\N
8855	VICPDTCOM	2010-06-30 00:00:00	2011-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3793	\N	\N
8899	MEMBRECOM	2010-10-15 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7399	\N	\N
8914	MEMBRECOM	2010-10-15 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7413	\N	\N
3387	MEMBRECOM	2004-10-06 00:00:00	2010-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2535	\N	\N
8917	MEMBRECOM	2010-10-20 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7417	\N	\N
8918	RAPCOM	2010-10-20 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7418	\N	\N
8919	MEMBRECOM	2010-10-20 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7419	\N	\N
8920	MEMBRECOM	2010-10-20 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7421	\N	\N
8921	VICPDTCOM	2010-10-20 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7422	\N	\N
8922	MEMBRECOM	2010-10-20 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7423	\N	\N
8923	MEMBRECOM	2010-10-20 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7424	\N	\N
8924	MEMBRECOM	2010-10-20 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7425	\N	\N
8925	MEMBRECOM	2010-10-20 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7426	\N	\N
8926	MEMBRECOM	2010-10-20 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7427	\N	\N
8927	MEMBRECOM	2010-10-20 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7428	\N	\N
8928	MEMBRECOM	2010-10-20 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7429	\N	\N
8929	PDTCOM	2010-10-20 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7430	\N	\N
8930	VICPDTCOM	2010-10-20 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7431	\N	\N
9003	MEMBRECOM	2010-11-18 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7503	\N	\N
9004	MEMBRECOM	2010-11-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7504	\N	\N
2999	VICPDTCOM	2004-02-11 00:00:00	2011-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2202	\N	\N
3149	VICPDTCOM	2004-05-26 00:00:00	2011-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2296	\N	\N
3267	MEMBRECOM	2004-07-27 00:00:00	2011-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2414	\N	\N
4085	VICPDTCOM	2006-01-19 00:00:00	2011-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3166	\N	\N
8830	RAPCOM	2010-06-02 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7336	\N	\N
8831	VICPDTCOM	2010-06-02 00:00:00	2015-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7337	\N	2015-10-12 09:39:30
8832	MEMBRECOM	2010-06-02 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7338	\N	\N
8833	MEMBRECOM	2010-06-02 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7339	\N	\N
8834	MEMBRECOM	2010-06-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7340	\N	\N
8835	MEMBRECOM	2010-06-02 00:00:00	2017-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7341	\N	2017-07-24 09:56:26
5273	MEMBRECOM	2008-10-07 00:00:00	2010-10-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4320	\N	\N
8933	MEMBRECOM	2010-10-28 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7433	\N	2014-10-09 10:45:14
9019	MEMBRECOM	2010-12-07 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7519	\N	\N
9023	MEMBRECOM	2010-12-07 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7523	\N	2014-09-28 13:21:47
9025	VICPDTCOM	2010-12-08 00:00:00	2014-07-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7525	\N	2014-07-01 09:25:11
4885	PDTCOM	2008-05-21 00:00:00	2008-06-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3972	\N	\N
4291	VICPDTCOM	2006-11-23 00:00:00	2006-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3372	\N	\N
4859	VICPDTCOM	2008-04-16 00:00:00	2008-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3946	\N	\N
9140	MEMBRECOM	2011-01-23 00:00:00	2011-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7638	\N	\N
2975	MEMBRECOM	2004-01-15 00:00:00	2011-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2178	\N	\N
4843	MEMBRECOM	2008-01-31 00:00:00	2008-02-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3928	\N	\N
4495	MEMBRECOM	2007-02-12 00:00:00	2007-02-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3577	\N	\N
8370	MEMBRECOM	2009-09-29 00:00:00	2011-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6925	\N	\N
9211	MEMBRECOM	2011-02-10 00:00:00	2013-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7709	\N	\N
9221	MEMBRECOM	2011-02-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7719	\N	\N
9252	MEMBRECOM	2011-03-28 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7749	\N	\N
8647	MEMBRECOM	2010-04-01 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7176	\N	\N
8789	RAPCOM	2010-05-20 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7295	\N	\N
8693	MEMBRECOM	2010-03-30 00:00:00	2010-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7221	\N	\N
8700	MEMBRECOM	2010-03-30 00:00:00	2010-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7228	\N	\N
8993	MEMBRECOM	2010-11-18 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7493	\N	\N
9014	MEMBRECOM	2010-12-07 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7514	\N	2017-09-24 17:28:55
9018	MEMBRECOM	2010-12-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7518	\N	\N
9029	MEMBRECOM	2010-12-08 00:00:00	2012-05-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7529	\N	\N
9030	MEMBRECOM	2010-12-08 00:00:00	2017-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7530	\N	2017-09-25 09:56:00
9254	MEMBRECOM	2011-03-29 00:00:00	2015-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7751	\N	2015-07-20 11:25:15
8709	VICPDTCOM	2010-03-31 00:00:00	2015-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7237	\N	2015-10-12 09:39:30
8710	RAPCOM	2010-03-31 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7238	\N	2014-09-28 18:00:58
8711	MEMBRECOM	2010-03-31 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7239	\N	2017-09-24 17:15:15
8712	MEMBRECOM	2010-03-31 00:00:00	2011-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7240	\N	\N
8713	MEMBRECOM	2010-03-31 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7241	\N	\N
8714	MEMBRECOM	2010-03-31 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7242	\N	2014-09-28 13:21:47
8715	MEMBRECOM	2010-03-31 00:00:00	2012-09-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7243	\N	\N
8717	MEMBRECOM	2010-03-31 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7245	\N	2017-10-01 09:41:22
8718	MEMBRECOM	2010-03-31 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7246	\N	\N
8720	MEMBRECOM	2010-03-31 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7248	\N	2014-09-28 13:40:33
8721	MEMBRECOM	2010-03-31 00:00:00	2019-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7249	\N	\N
8722	MEMBRECOM	2010-03-31 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7250	\N	\N
9020	MEMBRECOM	2010-12-07 00:00:00	2021-07-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7520	\N	\N
9139	MEMBRECOM	2011-01-18 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7637	\N	\N
9141	MEMBRECOM	2011-01-26 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7639	\N	\N
9224	VICPDTCOM	2011-02-10 00:00:00	2015-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7721	\N	2015-10-12 09:39:30
9232	MEMBRECOM	2011-02-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7729	\N	\N
8676	MEMBRECOM	2010-04-01 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7205	\N	2014-09-28 17:38:26
4470	MEMBRECOM	2007-02-01 00:00:00	2007-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3552	\N	2014-09-28 17:03:42
4541	MEMBRECOM	2007-02-20 00:00:00	2007-02-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3623	\N	\N
4879	MEMBRECOM	2008-05-14 00:00:00	2008-05-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3966	\N	2014-09-28 17:09:16
4292	RAPCOM	2006-11-23 00:00:00	2006-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3373	\N	2017-09-24 19:25:10
4965	MEMBRECOM	2008-07-02 00:00:00	2008-07-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4050	\N	\N
4979	MEMBRECOM	2008-07-10 00:00:00	2008-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4064	\N	\N
4983	MEMBRECOM	2008-07-09 00:00:00	2008-07-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4068	\N	2014-09-28 13:16:32
4823	MEMBRECOM	2008-01-24 00:00:00	2008-01-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3908	\N	\N
4845	MEMBRECOM	2008-01-31 00:00:00	2008-02-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3930	\N	\N
4900	RAPCOM	2008-06-03 00:00:00	2008-06-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3987	\N	2014-09-28 17:35:38
4907	MEMBRECOM	2008-06-03 00:00:00	2008-06-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3994	\N	\N
4888	MEMBRECOM	2008-05-21 00:00:00	2008-06-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3975	\N	2017-09-24 18:17:56
4226	VICPDTCOM	2006-06-08 00:00:00	2006-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3307	\N	2014-09-28 18:58:21
4329	MEMBRECOM	2006-12-12 00:00:00	2006-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3410	\N	2015-06-12 15:59:49
4344	MEMBRECOM	2006-12-14 00:00:00	2006-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3425	\N	\N
4997	MEMBRECOM	2008-07-17 00:00:00	2008-07-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4082	\N	\N
4999	MEMBRECOM	2008-07-17 00:00:00	2008-07-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4084	\N	\N
5012	MEMBRECOM	2008-07-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4097	\N	\N
4482	MEMBRECOM	2007-02-07 00:00:00	2007-02-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3564	\N	2015-04-21 17:14:30
4494	MEMBRECOM	2007-02-12 00:00:00	2007-02-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3576	\N	\N
4504	MEMBRECOM	2007-02-15 00:00:00	2007-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3586	\N	2015-04-21 17:14:30
4513	MEMBRECOM	2007-02-15 00:00:00	2007-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3595	\N	\N
4753	MEMBRECOM	2007-12-14 00:00:00	2007-12-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3838	\N	2014-09-28 17:40:23
4764	PDTCOM	2007-12-18 00:00:00	2007-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3849	\N	2014-07-01 09:25:11
4363	MEMBRECOM	2006-12-19 00:00:00	2006-12-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3444	\N	\N
4526	MEMBRECOM	2007-02-14 00:00:00	2007-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3608	\N	2014-09-28 18:00:58
5030	MEMBRECOM	2008-07-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4115	\N	2014-09-28 17:40:23
4711	MEMBRECOM	2007-12-05 00:00:00	2010-06-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3793	\N	\N
4718	MEMBRECOM	2007-12-05 00:00:00	2011-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3800	\N	\N
4725	MEMBRECOM	2007-12-05 00:00:00	2011-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3807	\N	\N
7890	PDTCOM	2008-10-29 00:00:00	2008-11-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6460	\N	\N
7911	MEMBRECOM	2008-10-29 00:00:00	2008-11-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6481	\N	2017-09-24 13:44:49
7962	MEMBRECOM	2008-12-09 00:00:00	2008-12-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6530	\N	\N
8140	MEMBRECOM	2009-04-29 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6714	\N	\N
4102	MEMBRECOM	2006-01-26 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3183	\N	2017-09-24 19:25:10
8441	MEMBRECOM	2009-10-07 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7000	\N	2014-09-28 17:31:42
8524	MEMBRECOM	2009-12-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7075	\N	\N
8285	MEMBRECOM	2009-07-01 00:00:00	2012-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6843	\N	\N
8330	MEMBRECOM	2009-07-21 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6888	\N	\N
3850	MEMBRECOM	2005-07-07 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2939	\N	2014-09-28 17:07:41
3717	MEMBRECOM	2005-01-27 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2807	\N	2014-09-28 18:19:47
8621	VICPDTCOM	2010-02-24 00:00:00	2010-08-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7144	\N	\N
3175	MEMBRECOM	2004-06-09 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2322	\N	\N
4754	MEMBRECOM	2007-12-14 00:00:00	2007-12-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3839	\N	2014-11-04 11:22:47
5024	RAPCOM	2008-07-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4109	\N	2017-09-24 18:17:56
4174	MEMBRECOM	2006-03-07 00:00:00	2006-03-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3255	\N	\N
8764	VICPDTRAPCOM	2010-04-08 00:00:00	2015-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7280	\N	2015-10-12 09:39:30
8765	MEMBRECOM	2010-04-08 00:00:00	2016-11-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7281	\N	2016-12-01 10:36:51
8766	MEMBRECOM	2010-04-08 00:00:00	2019-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7282	\N	\N
8769	MEMBRECOM	2010-04-08 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7285	\N	2014-09-28 17:34:16
8770	MEMBRECOM	2010-04-08 00:00:00	2012-09-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7286	\N	\N
8772	MEMBRECOM	2010-04-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7288	\N	\N
8773	MEMBRECOM	2010-04-08 00:00:00	2012-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7289	\N	\N
8774	MEMBRECOM	2010-04-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7290	\N	\N
8775	MEMBRECOM	2010-04-08 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7291	\N	2014-09-28 13:21:47
8776	MEMBRECOM	2010-04-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7292	\N	\N
8795	MEMBRECOM	2010-05-20 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7301	\N	\N
8797	MEMBRECOM	2010-05-20 00:00:00	2016-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7303	\N	2017-01-03 11:09:24
8861	MEMBRECOM	2010-07-06 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7361	\N	\N
8863	MEMBRECOM	2010-07-06 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7363	\N	\N
8864	MEMBRECOM	2010-07-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7364	\N	\N
8865	MEMBRECOM	2010-07-06 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7365	\N	\N
8866	MEMBRECOM	2010-07-06 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7366	\N	2017-09-24 17:47:27
8867	MEMBRECOM	2010-07-06 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7367	\N	\N
8868	MEMBRECOM	2010-07-06 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7368	\N	\N
8673	MEMBRECOM	2010-02-18 00:00:00	2017-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7202	\N	2017-06-19 12:20:59
8674	MEMBRECOM	2010-02-18 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7203	\N	2017-09-24 18:16:52
8794	MEMBRECOM	2010-05-20 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7300	\N	\N
8856	VICPDTCOM	2010-07-06 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7356	\N	\N
8857	RAPCOM	2010-07-06 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7357	\N	\N
8858	MEMBRECOM	2010-07-06 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7358	\N	2017-09-24 18:59:59
8859	MEMBRECOM	2010-07-06 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7359	\N	2017-09-24 17:04:02
8860	MEMBRECOM	2010-07-06 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7360	\N	\N
8869	MEMBRECOM	2010-07-06 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7369	\N	2014-09-28 12:32:23
8883	MEMBRECOM	2010-07-06 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7383	\N	2014-09-28 19:03:23
8687	MEMBRECOM	2010-03-30 00:00:00	2010-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7215	\N	\N
8595	MEMBRECOM	2010-02-17 00:00:00	2010-08-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7149	\N	\N
8603	MEMBRECOM	2010-02-17 00:00:00	2010-08-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7158	\N	\N
8587	MEMBRECOM	2010-02-17 00:00:00	2010-08-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7141	\N	\N
8593	MEMBRECOM	2010-02-17 00:00:00	2010-08-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7147	\N	\N
8413	MEMBRECOM	2009-10-14 00:00:00	2010-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6969	\N	\N
8421	MEMBRECOM	2009-10-14 00:00:00	2010-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6979	\N	\N
8901	RAPCOM	2010-10-06 00:00:00	2015-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7401	\N	2015-06-12 16:01:25
8916	MEMBRECOM	2010-10-12 00:00:00	2010-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7416	\N	\N
8934	PDTCOM	2010-10-19 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7434	\N	2014-09-28 17:07:41
8964	MEMBRECOM	2010-01-08 00:00:00	2010-01-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7464	\N	\N
8991	VICPDTCOM	2010-11-18 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7491	\N	2014-09-28 17:07:41
8992	RAPCOM	2010-11-18 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7492	\N	\N
8994	MEMBRECOM	2010-11-18 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7494	\N	\N
9000	MEMBRECOM	2010-11-18 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7500	\N	\N
9001	MEMBRECOM	2010-11-18 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7501	\N	2014-09-28 17:38:26
9002	MEMBRECOM	2010-11-18 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7502	\N	\N
8996	MEMBRECOM	2010-11-18 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7496	\N	2014-09-28 17:07:41
8997	MEMBRECOM	2010-11-18 00:00:00	2014-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7497	\N	\N
8998	MEMBRECOM	2010-11-18 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7498	\N	\N
8999	MEMBRECOM	2010-11-18 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7499	\N	\N
9005	MEMBRECOM	2010-12-08 00:00:00	2010-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7505	\N	\N
9037	MEMBRECOM	2010-12-08 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7537	\N	2014-09-28 13:21:47
9038	MEMBRECOM	2010-12-08 00:00:00	2017-05-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7538	\N	2017-05-16 15:18:13
9039	PDTCOM	2010-12-16 00:00:00	2014-07-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7539	\N	2014-07-01 09:25:11
9138	VICPDTCOM	2011-01-14 00:00:00	2014-10-07 00:00:00	5	ANCIEN	\N	\N	\N	\N	2619	\N	2014-10-08 17:51:19
9179	MEMBRECOM	2011-01-19 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7680	\N	2014-09-28 17:40:23
9180	MEMBRECOM	2011-01-19 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7681	\N	2017-10-01 10:17:18
9181	MEMBRECOM	2011-01-19 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7682	\N	2014-09-28 17:34:16
9182	MEMBRECOM	2011-01-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7683	\N	\N
9183	MEMBRECOM	2011-01-19 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7684	\N	\N
9207	MEMBRECOM	2011-02-17 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7705	\N	\N
9208	PDTCOM	2011-02-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7706	\N	2014-09-28 17:07:41
9209	RAPCOM	2011-02-10 00:00:00	2020-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7707	\N	\N
9210	MEMBRECOM	2011-02-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7708	\N	\N
9212	MEMBRECOM	2011-02-10 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7710	\N	\N
9213	MEMBRECOM	2011-02-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7711	\N	2014-09-28 14:31:42
9214	MEMBRECOM	2011-02-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7712	\N	2014-09-28 17:07:41
9215	MEMBRECOM	2011-02-10 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7713	\N	\N
9216	MEMBRECOM	2011-02-10 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7714	\N	\N
9217	MEMBRECOM	2011-02-10 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7715	\N	\N
9218	MEMBRECOM	2011-02-10 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7716	\N	\N
9219	MEMBRECOM	2011-02-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7717	\N	2014-09-28 17:38:26
9220	MEMBRECOM	2011-02-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7718	\N	\N
3453	MEMBRECOM	2004-10-06 00:00:00	2011-03-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2604	\N	\N
9253	MEMBRECOM	2011-03-29 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7750	\N	\N
8733	MEMBRECOM	2010-04-17 00:00:00	2010-04-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7251	\N	\N
8798	MEMBRECOM	2010-05-20 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7304	\N	\N
8799	MEMBRECOM	2010-05-20 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7305	\N	\N
8822	MEMBRECOM	2010-05-26 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7328	\N	2017-09-24 17:19:42
8824	MEMBRECOM	2010-05-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7330	\N	\N
8825	MEMBRECOM	2010-05-26 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7331	\N	2014-09-28 16:42:05
8826	MEMBRECOM	2010-05-26 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7332	\N	2014-09-28 17:31:41
8827	MEMBRECOM	2010-05-26 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7333	\N	2017-09-24 17:09:24
8828	MEMBRECOM	2010-05-26 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7334	\N	2014-09-28 17:31:42
8829	MEMBRECOM	2010-05-26 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7335	\N	2014-09-28 19:07:43
7857	MEMBRECOM	2008-10-15 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6428	\N	\N
7863	MEMBRECOM	2008-10-15 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6434	\N	\N
7869	MEMBRECOM	2008-10-15 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6440	\N	\N
7875	MEMBRECOM	2008-10-15 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6446	\N	\N
7882	VICPDTCOM	2008-10-15 00:00:00	2009-06-30 00:00:00	2	ANCIEN	\N	\N	\N	\N	6453	\N	\N
9007	MEMBRECOM	2010-12-14 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7507	\N	\N
9008	MEMBRECOM	2010-12-14 00:00:00	2011-01-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7508	\N	\N
9009	MEMBRECOM	2010-12-14 00:00:00	2011-03-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7509	\N	\N
9011	VICPDTCOM	2010-12-07 00:00:00	2014-07-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7511	\N	2014-07-01 09:25:11
9012	RAPCOM	2010-12-07 00:00:00	2015-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7512	\N	2015-01-08 17:14:29
9013	MEMBRECOM	2010-12-07 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7513	\N	\N
9015	MEMBRECOM	2010-12-07 00:00:00	2012-05-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7515	\N	\N
9016	MEMBRECOM	2010-12-07 00:00:00	2017-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7516	\N	2017-09-25 09:56:00
9027	MEMBRECOM	2010-12-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7527	\N	\N
9028	MEMBRECOM	2010-12-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7528	\N	\N
9046	MEMBRECOM	2010-12-16 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7546	\N	2017-09-24 18:20:10
9047	MEMBRECOM	2010-12-16 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7547	\N	\N
9048	MEMBRECOM	2010-12-16 00:00:00	2021-07-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7548	\N	\N
9049	MEMBRECOM	2010-12-16 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7549	\N	2014-09-28 18:19:47
8870	PDTCOM	2010-07-06 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7370	\N	2014-09-28 18:58:21
8872	MEMBRECOM	2010-07-06 00:00:00	2019-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7372	\N	\N
8873	MEMBRECOM	2010-07-06 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7373	\N	\N
8875	MEMBRECOM	2010-07-06 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7375	\N	\N
8876	MEMBRECOM	2010-07-06 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7376	\N	2014-09-28 17:38:26
8877	MEMBRECOM	2010-07-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7377	\N	\N
8878	MEMBRECOM	2010-07-06 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7378	\N	\N
8879	MEMBRECOM	2010-07-06 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7379	\N	\N
8880	MEMBRECOM	2010-07-06 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7380	\N	2017-09-24 13:44:49
8881	MEMBRECOM	2010-07-06 00:00:00	2010-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7381	\N	\N
8882	MEMBRECOM	2010-07-06 00:00:00	2012-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7382	\N	\N
8966	VICPDTCOM	2010-11-10 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2599	\N	\N
9050	MEMBRECOM	2010-12-16 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7550	\N	2014-09-28 13:16:32
9051	MEMBRECOM	2010-12-16 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7551	\N	\N
9052	MEMBRECOM	2010-12-16 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7552	\N	\N
9053	MEMBRECOM	2010-12-16 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7553	\N	2014-09-28 13:40:33
9190	MEMBRECOM	2011-01-25 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7691	\N	2014-09-28 17:07:41
9191	MEMBRECOM	2011-01-25 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7692	\N	\N
9192	MEMBRECOM	2011-01-25 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7693	\N	\N
9193	MEMBRECOM	2011-01-25 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7694	\N	\N
9195	MEMBRECOM	2011-01-25 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7696	\N	2014-09-28 17:38:26
9196	MEMBRECOM	2011-01-25 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7697	\N	\N
9198	MEMBRECOM	2011-01-25 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7699	\N	\N
9199	MEMBRECOM	2011-01-25 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7700	\N	2014-09-28 17:07:41
9200	MEMBRECOM	2011-01-25 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7701	\N	\N
9201	MEMBRECOM	2011-01-25 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7702	\N	2014-09-28 17:34:16
9202	MEMBRECOM	2011-01-25 00:00:00	2013-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7703	\N	\N
9225	RAPCOM	2011-02-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7722	\N	2014-09-28 18:00:58
9226	MEMBRECOM	2011-02-10 00:00:00	2015-04-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7723	\N	2015-04-21 17:14:30
9227	MEMBRECOM	2011-02-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7724	\N	2014-09-28 17:40:23
9228	MEMBRECOM	2011-02-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7725	\N	\N
9229	MEMBRECOM	2011-02-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7726	\N	2014-09-28 13:40:33
9230	MEMBRECOM	2011-02-10 00:00:00	2012-09-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7727	\N	\N
8724	PDTCOM	2010-03-31 00:00:00	2010-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7234	\N	\N
8725	VICPDTCOM	2010-03-31 00:00:00	2010-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7212	\N	\N
8726	VICPDTCOM	2010-03-31 00:00:00	2010-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7213	\N	\N
8727	VICPDTCOM	2010-03-31 00:00:00	2010-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7227	\N	\N
8728	VICPDTCOM	2010-03-31 00:00:00	2010-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7229	\N	\N
8729	SECRETCOM	2010-03-31 00:00:00	2010-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7231	\N	\N
8730	SECRETCOM	2010-03-31 00:00:00	2010-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7233	\N	\N
8731	SECRETCOM	2010-03-31 00:00:00	2010-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7217	\N	\N
8732	RAPCOM	2010-03-31 00:00:00	2010-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7223	\N	\N
4599	MEMBRECOM	2007-07-25 00:00:00	2010-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3685	\N	\N
9021	MEMBRECOM	2010-12-07 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7521	\N	\N
9092	SECRETCOM	2011-01-11 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7593	\N	\N
9093	VICPDTCOM	2011-01-11 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7594	\N	\N
9095	MEMBRECOM	2011-01-11 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7596	\N	\N
9096	MEMBRECOM	2011-01-11 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7597	\N	\N
9097	VICPDTCOM	2011-01-11 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7598	\N	\N
9098	MEMBRECOM	2011-01-11 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7599	\N	\N
9099	SECRETCOM	2011-01-11 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7600	\N	\N
9100	MEMBRECOM	2011-01-11 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7601	\N	\N
9102	VICPDTCOM	2011-01-11 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7603	\N	\N
9103	VICPDTCOM	2011-01-11 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7604	\N	\N
9104	SECRETCOM	2011-01-11 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7605	\N	\N
9105	VICPDTCOM	2011-01-11 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7606	\N	\N
9106	MEMBRECOM	2011-01-11 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7607	\N	\N
9107	RAPCOM	2011-01-11 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7608	\N	\N
9108	MEMBRECOM	2011-01-11 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7609	\N	\N
9109	MEMBRECOM	2011-01-11 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7610	\N	\N
9110	MEMBRECOM	2011-01-11 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7611	\N	\N
9111	SECRETCOM	2011-01-11 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7612	\N	\N
9112	MEMBRECOM	2011-01-11 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7613	\N	\N
9113	MEMBRECOM	2011-01-11 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7614	\N	\N
9114	PDTCOM	2011-01-11 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7615	\N	\N
9115	MEMBRECOM	2011-01-11 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7616	\N	\N
9116	MEMBRECOM	2011-01-11 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7617	\N	\N
8102	MEMBRECOM	2009-03-11 00:00:00	2009-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6673	\N	\N
8491	MEMBRECOM	2009-12-09 00:00:00	2010-01-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7041	\N	\N
8492	MEMBRECOM	2009-12-09 00:00:00	2010-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7042	\N	\N
8493	MEMBRECOM	2009-12-09 00:00:00	2010-01-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7044	\N	\N
8494	MEMBRECOM	2009-12-09 00:00:00	2010-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7045	\N	\N
8495	MEMBRECOM	2009-12-09 00:00:00	2010-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7046	\N	\N
8496	MEMBRECOM	2009-12-09 00:00:00	2010-01-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7047	\N	\N
8497	MEMBRECOM	2009-12-09 00:00:00	2010-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7048	\N	\N
8498	MEMBRECOM	2009-12-09 00:00:00	2010-01-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7049	\N	\N
8499	MEMBRECOM	2009-12-09 00:00:00	2010-01-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7050	\N	\N
8500	MEMBRECOM	2009-12-09 00:00:00	2010-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7051	\N	\N
8501	MEMBRECOM	2009-12-09 00:00:00	2010-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7052	\N	\N
8502	MEMBRECOM	2009-12-09 00:00:00	2010-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7053	\N	\N
8503	MEMBRECOM	2009-12-09 00:00:00	2010-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7054	\N	\N
8504	MEMBRECOM	2009-12-09 00:00:00	2010-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7055	\N	\N
8505	MEMBRECOM	2009-12-09 00:00:00	2010-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7056	\N	\N
8506	MEMBRECOM	2009-12-09 00:00:00	2010-01-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7057	\N	\N
8508	MEMBRECOM	2009-12-09 00:00:00	2010-01-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7059	\N	\N
8509	MEMBRECOM	2009-12-09 00:00:00	2010-01-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7060	\N	\N
8510	MEMBRECOM	2009-12-09 00:00:00	2010-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7061	\N	\N
8511	MEMBRECOM	2009-12-09 00:00:00	2010-01-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7062	\N	\N
8512	MEMBRECOM	2009-12-09 00:00:00	2010-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7063	\N	\N
8513	MEMBRECOM	2009-12-09 00:00:00	2010-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7064	\N	\N
8514	MEMBRECOM	2009-12-09 00:00:00	2010-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7065	\N	\N
8515	MEMBRECOM	2009-12-09 00:00:00	2010-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7066	\N	\N
8516	MEMBRECOM	2009-12-09 00:00:00	2010-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7067	\N	\N
8517	MEMBRECOM	2009-12-09 00:00:00	2010-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7068	\N	\N
8518	VICPDTCOM	2009-12-08 00:00:00	2014-07-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7069	\N	2014-07-01 09:25:11
8519	MEMBRECOM	2009-12-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7070	\N	2017-09-24 17:06:55
8526	MEMBRECOM	2009-12-08 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7077	\N	\N
8527	MEMBRECOM	2009-12-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7078	\N	2017-09-24 17:28:55
8520	RAPCOM	2009-12-08 00:00:00	2015-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7071	\N	2015-01-08 17:14:29
8521	MEMBRECOM	2009-12-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7072	\N	\N
8522	MEMBRECOM	2009-12-08 00:00:00	2011-03-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7073	\N	\N
8523	MEMBRECOM	2009-12-08 00:00:00	2012-05-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7074	\N	\N
8528	MEMBRECOM	2009-12-08 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7079	\N	2014-09-28 17:34:16
8529	MEMBRECOM	2009-12-08 00:00:00	2021-07-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7080	\N	\N
8530	MEMBRECOM	2009-12-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7081	\N	2017-09-24 18:20:10
8531	MEMBRECOM	2009-12-08 00:00:00	2010-03-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7082	\N	\N
8532	MEMBRECOM	2009-12-18 00:00:00	2013-02-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7083	\N	\N
8543	MEMBRECOM	2009-12-17 00:00:00	2019-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7095	\N	\N
8541	MEMBRECOM	2009-12-17 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7093	\N	2017-09-24 17:09:24
8542	MEMBRECOM	2009-12-17 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7094	\N	\N
8544	MEMBRECOM	2009-12-17 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7096	\N	\N
8545	MEMBRECOM	2009-12-17 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7097	\N	2014-09-28 17:40:23
8546	MEMBRECOM	2009-12-17 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7098	\N	\N
8547	MEMBRECOM	2009-12-17 00:00:00	2012-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7099	\N	\N
8548	MEMBRECOM	2009-12-17 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7100	\N	\N
8549	MEMBRECOM	2009-12-17 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7101	\N	2014-09-28 12:32:23
8550	PDTCOM	2009-12-17 00:00:00	2014-07-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7102	\N	2014-07-01 09:25:11
8551	RAPCOM	2009-12-17 00:00:00	2015-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7103	\N	2015-01-08 17:14:29
8552	MEMBRECOM	2009-12-17 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7104	\N	\N
8553	MEMBRECOM	2009-12-17 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7105	\N	2014-09-28 18:19:47
8554	MEMBRECOM	2009-12-17 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7106	\N	\N
8555	MEMBRECOM	2009-12-17 00:00:00	2018-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7107	\N	2018-05-31 10:52:17
8557	MEMBRECOM	2009-12-17 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7109	\N	2014-09-28 16:59:41
8558	MEMBRECOM	2009-12-17 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7110	\N	\N
8559	MEMBRECOM	2009-12-17 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7111	\N	2014-09-28 13:16:32
8560	MEMBRECOM	2009-12-17 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7112	\N	2014-09-28 17:15:42
8561	MEMBRECOM	2009-12-17 00:00:00	2017-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7113	\N	2017-09-25 09:56:00
8562	MEMBRECOM	2009-12-17 00:00:00	2010-03-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7114	\N	\N
8563	MEMBRECOM	2009-12-17 00:00:00	2012-05-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7115	\N	\N
8564	MEMBRECOM	2009-12-22 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7116	\N	2014-09-28 18:58:21
8565	MEMBRECOM	2009-12-22 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7117	\N	2014-09-28 17:40:23
8566	MEMBRECOM	2009-12-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7118	\N	\N
8567	MEMBRECOM	2009-12-22 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7119	\N	\N
8568	MEMBRECOM	2009-12-22 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7120	\N	2014-09-28 14:31:42
8569	MEMBRECOM	2009-12-22 00:00:00	2020-06-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7121	\N	\N
8574	MEMBRECOM	2009-12-22 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7126	\N	\N
7946	PDTCOM	1986-04-02 00:00:00	1986-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2030	\N	\N
8134	MEMBRECOM	2009-04-02 00:00:00	2009-04-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6708	\N	\N
8135	MEMBRECOM	2009-04-02 00:00:00	2009-04-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6709	\N	\N
8136	MEMBRECOM	2009-04-02 00:00:00	2009-04-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6710	\N	\N
8137	MEMBRECOM	2009-04-02 00:00:00	2009-04-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6711	\N	\N
8138	MEMBRECOM	2009-04-02 00:00:00	2009-04-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6712	\N	\N
8273	SECRETCOM	2009-07-17 00:00:00	2009-09-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6831	\N	\N
8286	MEMBRECOM	2009-07-01 00:00:00	2019-08-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6844	\N	\N
8287	MEMBRECOM	2009-07-01 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6845	\N	2014-09-28 12:32:23
8288	PDTCOM	2009-07-07 00:00:00	2015-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6846	\N	2015-10-12 09:39:30
8311	PDTCOM	2009-07-08 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6869	\N	2014-09-28 18:58:21
8312	RAPCOM	2009-07-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	6870	\N	\N
8313	MEMBRECOM	2009-07-08 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6871	\N	\N
8008	MEMBRECOM	2009-02-27 00:00:00	2015-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6576	\N	2015-01-08 17:14:29
5805	MEMBRECOM	2008-10-08 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4723	\N	\N
5809	MEMBRECOM	2008-10-08 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4727	\N	\N
5811	MEMBRECOM	2008-10-08 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4729	\N	\N
5817	MEMBRECOM	2008-10-08 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4735	\N	\N
5823	SECRETCOM	2008-10-08 00:00:00	2011-09-30 00:00:00	2	ANCIEN	\N	\N	\N	\N	4741	\N	\N
8010	MEMBRECOM	2009-02-27 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6578	\N	2017-09-24 17:09:24
5828	MEMBRECOM	2008-10-08 00:00:00	2014-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4746	\N	2014-10-13 11:51:14
5830	MEMBRECOM	2008-10-08 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4748	\N	\N
5832	MEMBRECOM	2008-10-08 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4750	\N	\N
5836	MEMBRECOM	2008-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4754	\N	2014-10-09 15:41:14
8021	RAPCOM	2009-02-11 00:00:00	2009-02-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6589	\N	\N
8022	MEMBRECOM	2009-02-11 00:00:00	2009-02-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6590	\N	\N
8023	MEMBRECOM	2009-02-11 00:00:00	2009-02-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6591	\N	\N
8178	PDTCOM	2009-04-28 00:00:00	2009-05-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6753	\N	2014-07-01 09:25:11
8181	MEMBRECOM	2009-04-28 00:00:00	2009-05-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6756	\N	2016-12-12 16:10:15
8182	MEMBRECOM	2009-04-28 00:00:00	2009-05-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6757	\N	\N
8185	MEMBRECOM	2009-04-28 00:00:00	2009-05-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6760	\N	2017-09-24 18:20:10
5854	VICPDTCOM	2008-10-08 00:00:00	2010-03-23 00:00:00	3	ANCIEN	\N	\N	\N	\N	4408	\N	\N
5855	VICPDTCOM	2008-10-08 00:00:00	2011-09-30 00:00:00	4	ANCIEN	\N	\N	\N	\N	4409	\N	\N
5856	MEMBRECOM	2008-10-08 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4592	\N	\N
5857	VICPDTCOM	2008-10-08 00:00:00	2011-09-30 00:00:00	8	ANCIEN	\N	\N	\N	\N	4433	\N	\N
5858	VICPDTCOM	2008-10-08 00:00:00	2011-09-30 00:00:00	6	ANCIEN	\N	\N	\N	\N	4430	\N	\N
5937	VICPDTCOM	2008-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4742	\N	2014-10-09 09:38:16
5938	VICPDTCOM	2008-10-08 00:00:00	2011-09-30 00:00:00	7	ANCIEN	\N	\N	\N	\N	4752	\N	\N
5590	MEMBRECOM	2008-10-08 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4424	\N	2014-09-28 13:16:32
7682	MEMBRECOM	2008-10-08 00:00:00	2010-04-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6283	\N	\N
7830	MEMBRECOM	2008-10-08 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6409	\N	\N
8186	MEMBRECOM	2009-04-28 00:00:00	2009-05-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6761	\N	2014-09-28 12:21:28
8187	MEMBRECOM	2009-04-28 00:00:00	2009-05-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6762	\N	2014-09-28 18:19:47
8188	MEMBRECOM	2009-04-28 00:00:00	2009-05-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6763	\N	\N
8189	MEMBRECOM	2009-04-28 00:00:00	2009-05-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6764	\N	\N
8409	MEMBRECOM	2008-10-08 00:00:00	2011-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6965	\N	\N
8410	MEMBRECOM	2008-10-08 00:00:00	2011-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6966	\N	\N
8411	MEMBRECOM	2009-10-08 00:00:00	2010-06-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6967	\N	\N
8412	MEMBRECOM	2009-10-08 00:00:00	2011-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6968	\N	\N
8446	MEMBRECOM	2009-11-06 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7005	\N	2017-09-24 17:47:27
8447	MEMBRECOM	2009-11-06 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7006	\N	\N
8453	MEMBRECOM	2009-11-06 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7012	\N	\N
8454	MEMBRECOM	2009-11-06 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7013	\N	2017-09-24 17:04:02
8463	SECRETCOM	2009-11-10 00:00:00	2010-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6972	\N	\N
8464	RAPCOM	2009-11-10 00:00:00	2010-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6985	\N	\N
8465	PDTCOM	2009-11-10 00:00:00	2010-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6973	\N	\N
8466	MEMBRECOM	2009-11-16 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7015	\N	2014-09-28 17:07:41
8467	MEMBRECOM	2009-11-16 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7016	\N	\N
8468	MEMBRECOM	2009-11-16 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7017	\N	\N
8469	MEMBRECOM	2009-11-16 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7018	\N	\N
8470	MEMBRECOM	2009-11-16 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7019	\N	\N
8471	MEMBRECOM	2009-11-16 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7020	\N	2014-09-28 17:07:41
8472	MEMBRECOM	2009-11-16 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7021	\N	2014-09-28 17:07:41
8473	MEMBRECOM	2009-11-16 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7022	\N	\N
8474	MEMBRECOM	2009-11-16 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7023	\N	\N
8475	MEMBRECOM	2009-11-16 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7024	\N	\N
8476	MEMBRECOM	2009-11-16 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7025	\N	\N
8477	MEMBRECOM	2009-11-16 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7026	\N	\N
8478	MEMBRECOM	2009-11-16 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7027	\N	\N
7923	MEMBRECOM	2008-11-20 00:00:00	2008-11-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6493	\N	\N
7970	MEMBRECOM	2008-12-19 00:00:00	2008-12-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6538	\N	2017-09-24 18:20:10
7971	MEMBRECOM	2008-12-19 00:00:00	2008-12-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6539	\N	\N
7972	MEMBRECOM	2008-12-19 00:00:00	2008-12-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6540	\N	\N
7974	MEMBRECOM	2008-12-19 00:00:00	2008-12-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6542	\N	\N
7975	MEMBRECOM	2008-12-19 00:00:00	2008-12-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6543	\N	\N
7981	RAPCOM	2009-01-21 00:00:00	2009-01-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6549	\N	\N
7982	MEMBRECOM	2009-01-21 00:00:00	2009-01-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6550	\N	\N
7983	RAPCOM	2009-01-21 00:00:00	2009-01-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6551	\N	\N
7984	MEMBRECOM	2009-01-21 00:00:00	2009-01-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6552	\N	2017-07-04 15:08:09
7985	MEMBRECOM	2009-01-21 00:00:00	2009-01-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6553	\N	2014-09-28 18:58:25
7987	MEMBRECOM	2009-01-21 00:00:00	2009-01-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6555	\N	\N
7988	MEMBRECOM	2009-01-21 00:00:00	2009-01-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6556	\N	\N
7989	MEMBRECOM	2009-01-21 00:00:00	2009-01-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6557	\N	2014-09-28 17:27:35
7990	MEMBRECOM	2009-01-21 00:00:00	2009-01-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6558	\N	\N
8001	MEMBRECOM	2009-01-26 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6569	\N	2014-09-28 18:19:47
8002	MEMBRECOM	2009-01-26 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6570	\N	\N
8003	MEMBRECOM	2009-01-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	6571	\N	\N
8004	MEMBRECOM	2009-01-26 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6572	\N	\N
8289	RAPCOM	2009-07-07 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6847	\N	2017-09-24 17:15:15
8302	MEMBRECOM	2009-07-21 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6860	\N	\N
8325	VICPDTCOM	2009-07-21 00:00:00	2015-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6883	\N	2015-10-12 09:39:30
8326	RAPCOM	2009-07-21 00:00:00	2014-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6884	\N	2014-09-29 13:41:53
8327	MEMBRECOM	2009-07-21 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6885	\N	2014-09-28 18:00:58
8328	MEMBRECOM	2009-07-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	6886	\N	\N
8329	MEMBRECOM	2009-07-21 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6887	\N	\N
8331	MEMBRECOM	2009-07-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	6889	\N	\N
8338	MEMBRECOM	2009-07-21 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6896	\N	\N
8479	MEMBRECOM	2009-11-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7028	\N	\N
8482	MEMBRECOM	2009-11-25 00:00:00	2017-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7031	\N	2017-06-19 12:20:22
8483	MEMBRECOM	2009-11-25 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7032	\N	\N
8484	MEMBRECOM	2009-12-09 00:00:00	2010-01-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7033	\N	\N
8485	MEMBRECOM	2009-12-09 00:00:00	2010-01-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7035	\N	\N
8486	MEMBRECOM	2009-12-09 00:00:00	2010-01-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7036	\N	\N
8487	MEMBRECOM	2009-12-09 00:00:00	2010-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7037	\N	\N
8488	MEMBRECOM	2009-12-09 00:00:00	2010-01-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7038	\N	\N
8489	MEMBRECOM	2009-12-09 00:00:00	2010-01-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7039	\N	\N
8490	MEMBRECOM	2009-12-09 00:00:00	2010-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7040	\N	\N
8651	MEMBRECOM	2010-02-16 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7180	\N	2014-09-28 18:19:47
8817	RAPCOM	2010-05-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7323	\N	\N
8652	MEMBRECOM	2010-02-16 00:00:00	2018-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7181	\N	2018-05-31 10:52:17
8653	MEMBRECOM	2010-02-16 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7182	\N	2014-09-28 17:34:16
8654	MEMBRECOM	2010-02-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7183	\N	\N
8655	MEMBRECOM	2010-02-16 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7184	\N	\N
8656	MEMBRECOM	2010-02-16 00:00:00	2021-07-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7185	\N	\N
8682	PDTCOM	2010-03-24 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4408	\N	\N
8692	MEMBRECOM	2010-03-30 00:00:00	2010-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7220	\N	\N
8694	MEMBRECOM	2010-03-30 00:00:00	2010-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7222	\N	\N
8757	MEMBRECOM	2010-04-28 00:00:00	2010-05-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7276	\N	\N
8758	MEMBRECOM	2010-04-28 00:00:00	2011-04-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7277	\N	\N
8759	MEMBRECOM	2010-04-28 00:00:00	2010-05-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7278	\N	\N
8760	MEMBRECOM	2010-04-28 00:00:00	2011-04-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7279	\N	\N
8761	MEMBRECOM	1959-05-06 00:00:00	1959-05-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1897	\N	\N
8762	MEMBRECOM	1959-05-06 00:00:00	1970-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1382	\N	\N
8763	MEMBRECOM	1959-05-06 00:00:00	1965-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1198	\N	\N
8796	MEMBRECOM	2010-05-20 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7302	\N	\N
8837	MEMBRECOM	2010-06-02 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7343	\N	\N
8884	MEMBRECOM	2010-09-28 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7384	\N	2014-09-28 17:07:41
8885	MEMBRECOM	2010-09-28 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7385	\N	2017-09-24 18:17:56
8886	MEMBRECOM	2010-09-28 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7386	\N	\N
8887	MEMBRECOM	2010-09-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7387	\N	\N
8888	MEMBRECOM	2010-09-28 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7388	\N	\N
8889	MEMBRECOM	2010-09-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7389	\N	\N
8890	MEMBRECOM	2010-09-28 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7390	\N	2017-09-24 17:35:15
8891	MEMBRECOM	2010-09-28 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7391	\N	2017-09-24 13:44:49
3636	MEMBRECOM	2004-12-14 00:00:00	2010-10-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2724	\N	\N
4338	MEMBRECOM	2006-12-12 00:00:00	2006-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3419	\N	\N
8932	MEMBRECOM	2010-10-28 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7432	\N	\N
8935	RAPCOM	2010-10-19 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7435	\N	\N
8936	MEMBRECOM	2010-10-19 00:00:00	2020-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7436	\N	\N
8937	MEMBRECOM	2010-10-19 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7437	\N	\N
8939	MEMBRECOM	2010-10-19 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7439	\N	2014-09-28 17:34:16
8940	MEMBRECOM	2010-10-19 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7440	\N	2014-09-28 17:07:41
8942	MEMBRECOM	2010-10-19 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7442	\N	2017-09-24 17:35:15
8943	MEMBRECOM	2010-10-19 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7443	\N	2014-09-28 17:07:41
8622	VICPDTCOM	2010-02-24 00:00:00	2010-08-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7152	\N	\N
8623	MEMBRECOM	2010-02-17 00:00:00	2010-02-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7150	\N	\N
8624	SECRETCOM	2010-02-24 00:00:00	2010-08-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7150	\N	\N
8625	SECRETCOM	2010-02-24 00:00:00	2010-08-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7153	\N	\N
8626	RAPCOM	2010-02-24 00:00:00	2010-08-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7157	\N	\N
8695	MEMBRECOM	2010-03-30 00:00:00	2010-03-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7223	\N	\N
8696	MEMBRECOM	2010-03-30 00:00:00	2010-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7224	\N	\N
8697	MEMBRECOM	2010-03-30 00:00:00	2010-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7225	\N	\N
8698	MEMBRECOM	2010-03-30 00:00:00	2010-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7226	\N	\N
8699	MEMBRECOM	2010-03-30 00:00:00	2010-03-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7227	\N	\N
8701	MEMBRECOM	2010-03-30 00:00:00	2010-03-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7229	\N	\N
8702	MEMBRECOM	2010-03-30 00:00:00	2010-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7230	\N	\N
8703	MEMBRECOM	2010-03-30 00:00:00	2010-03-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7231	\N	\N
8704	MEMBRECOM	2010-03-30 00:00:00	2010-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7232	\N	\N
8705	MEMBRECOM	2010-03-30 00:00:00	2010-03-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7233	\N	\N
8706	MEMBRECOM	2010-03-30 00:00:00	2010-03-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7234	\N	\N
8707	MEMBRECOM	2010-03-30 00:00:00	2010-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7235	\N	\N
8737	MEMBRECOM	2010-04-28 00:00:00	2011-04-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7254	\N	\N
8738	MEMBRECOM	2010-04-28 00:00:00	2010-05-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7255	\N	\N
8739	MEMBRECOM	2010-04-28 00:00:00	2011-04-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7256	\N	\N
8740	MEMBRECOM	2010-04-28 00:00:00	2010-05-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7257	\N	\N
8741	MEMBRECOM	2010-04-28 00:00:00	2011-04-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7258	\N	\N
8742	MEMBRECOM	2010-04-28 00:00:00	2011-04-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7259	\N	\N
8743	MEMBRECOM	2010-04-28 00:00:00	2011-04-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7260	\N	\N
8744	MEMBRECOM	2010-04-28 00:00:00	2011-04-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7261	\N	\N
8745	MEMBRECOM	2010-04-28 00:00:00	2011-04-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7262	\N	\N
8746	MEMBRECOM	2010-04-28 00:00:00	2011-04-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7263	\N	\N
8747	MEMBRECOM	2010-04-28 00:00:00	2010-05-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7265	\N	\N
8748	MEMBRECOM	2010-04-28 00:00:00	2011-04-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7266	\N	\N
8749	MEMBRECOM	2010-04-28 00:00:00	2010-05-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7267	\N	\N
8750	MEMBRECOM	2010-04-28 00:00:00	2010-05-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7268	\N	\N
8751	MEMBRECOM	2010-04-28 00:00:00	2011-04-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7269	\N	\N
8752	MEMBRECOM	2010-04-28 00:00:00	2011-04-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7270	\N	\N
8753	MEMBRECOM	2010-04-28 00:00:00	2011-04-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7271	\N	\N
8902	MEMBRECOM	2010-10-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7402	\N	\N
8911	MEMBRECOM	2010-10-06 00:00:00	2015-04-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7411	\N	2015-04-21 17:14:30
8912	MEMBRECOM	2010-10-06 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7412	\N	2017-09-24 18:16:52
8913	MEMBRECOM	2010-10-06 00:00:00	2017-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7414	\N	2017-06-19 12:20:59
8995	MEMBRECOM	2010-11-18 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7495	\N	\N
9031	MEMBRECOM	2010-12-08 00:00:00	2018-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7531	\N	2018-05-31 10:52:17
9032	MEMBRECOM	2010-12-08 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7532	\N	\N
9033	MEMBRECOM	2010-12-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7533	\N	\N
8777	MEMBRECOM	2010-04-08 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7293	\N	\N
8816	VICPDTCOM	2010-05-26 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7322	\N	2014-09-28 18:58:21
8818	RAPCOM	2010-05-26 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7324	\N	\N
8819	MEMBRECOM	2010-05-26 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7325	\N	\N
8820	MEMBRECOM	2010-05-26 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7326	\N	\N
8821	MEMBRECOM	2010-05-26 00:00:00	2012-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7327	\N	\N
8836	MEMBRECOM	2010-06-02 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7342	\N	\N
8838	MEMBRECOM	2010-06-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7344	\N	\N
8839	MEMBRECOM	2010-06-02 00:00:00	2012-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7345	\N	\N
8840	MEMBRECOM	2010-06-02 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7346	\N	2014-09-28 16:42:05
8841	MEMBRECOM	2010-06-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7347	\N	\N
8842	MEMBRECOM	2010-06-02 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7348	\N	2014-09-28 13:21:47
8843	MEMBRECOM	2010-06-02 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7349	\N	\N
7872	MEMBRECOM	2008-10-15 00:00:00	2009-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6443	\N	\N
9069	PDTCOM	2011-01-11 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7569	\N	\N
9070	MEMBRECOM	2011-01-11 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7570	\N	\N
9071	VICPDTCOM	2011-01-11 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7571	\N	\N
9072	VICPDTCOM	2011-01-11 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7572	\N	\N
9073	MEMBRECOM	2011-01-11 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7573	\N	\N
9074	MEMBRECOM	2011-01-11 00:00:00	2011-02-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7574	\N	\N
9075	MEMBRECOM	2011-01-11 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7575	\N	\N
9076	MEMBRECOM	2011-01-11 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7576	\N	\N
9077	VICPDTCOM	2011-01-11 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7577	\N	\N
9078	MEMBRECOM	2011-01-11 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7578	\N	\N
9079	RAPCOM	2011-01-11 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7579	\N	\N
9080	MEMBRECOM	2011-01-11 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7580	\N	\N
9081	MEMBRECOM	2011-01-11 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7581	\N	\N
9082	MEMBRECOM	2011-01-11 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7582	\N	\N
9083	MEMBRECOM	2011-01-11 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7583	\N	\N
9084	SECRETCOM	2011-01-11 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7584	\N	\N
9085	MEMBRECOM	2011-01-11 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7586	\N	\N
9087	MEMBRECOM	2011-01-11 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7588	\N	\N
9088	MEMBRECOM	2011-01-11 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7589	\N	\N
9089	MEMBRECOM	2011-01-11 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7590	\N	\N
9090	MEMBRECOM	2011-01-11 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7591	\N	\N
9091	MEMBRECOM	2011-01-11 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7592	\N	\N
8723	VICPDTCOM	2010-04-07 00:00:00	2011-09-30 00:00:00	2	ANCIEN	\N	\N	\N	\N	6283	\N	\N
9151	RAPCOM	2011-02-02 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7652	\N	\N
9152	MEMBRECOM	2011-02-02 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7653	\N	\N
9153	MEMBRECOM	2011-02-02 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7654	\N	\N
9154	MEMBRECOM	2011-02-02 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7656	\N	\N
9155	MEMBRECOM	2011-02-02 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7657	\N	\N
9156	VICPDTCOM	2011-02-02 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7658	\N	\N
9157	VICPDTCOM	2011-02-02 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7659	\N	\N
9158	VICPDTCOM	2011-02-02 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7660	\N	\N
9159	MEMBRECOM	2011-02-02 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7661	\N	\N
9160	MEMBRECOM	2011-02-02 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7662	\N	\N
9161	MEMBRECOM	2011-02-02 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7663	\N	\N
9162	MEMBRECOM	2011-02-02 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7664	\N	\N
9163	PDTCOM	2011-02-02 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7665	\N	\N
9164	MEMBRECOM	2011-02-02 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7666	\N	\N
9165	MEMBRECOM	2011-02-02 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7667	\N	\N
9166	MEMBRECOM	2011-02-02 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7668	\N	\N
9167	MEMBRECOM	2011-02-02 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7669	\N	\N
9168	SECRETCOM	2011-02-02 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7670	\N	\N
9169	SECRETCOM	2011-02-02 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7671	\N	\N
9171	MEMBRECOM	2011-02-02 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7673	\N	\N
9172	VICPDTCOM	2011-02-02 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7674	\N	\N
9173	MEMBRECOM	2011-02-02 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7675	\N	\N
9174	MEMBRECOM	2011-02-02 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7655	\N	\N
9176	PDTCOM	2011-01-19 00:00:00	2015-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7677	\N	2015-10-12 09:39:30
9177	RAPCOM	2011-01-19 00:00:00	2015-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7678	\N	2015-06-12 16:01:25
9178	MEMBRECOM	2011-01-19 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7679	\N	2014-09-28 18:00:58
9184	MEMBRECOM	2011-01-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7685	\N	\N
9185	MEMBRECOM	2011-01-19 00:00:00	2017-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7686	\N	2017-07-24 09:56:26
9186	MEMBRECOM	2011-01-19 00:00:00	2015-04-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7687	\N	2015-04-21 17:14:30
9187	MEMBRECOM	2011-01-19 00:00:00	2017-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7688	\N	2017-06-19 12:20:59
9188	MEMBRECOM	2011-01-19 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7689	\N	2014-09-28 13:21:47
9189	MEMBRECOM	2011-01-19 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7690	\N	\N
8630	MEMBRECOM	2009-12-09 00:00:00	2010-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7034	\N	\N
8631	MEMBRECOM	2009-12-09 00:00:00	2010-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7043	\N	\N
8632	PDTCOM	2010-01-12 00:00:00	2010-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7049	\N	\N
8633	RAPCOM	2010-01-12 00:00:00	2010-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7050	\N	\N
8634	VICPDTCOM	2010-01-12 00:00:00	2010-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7041	\N	\N
8635	VICPDTCOM	2010-01-12 00:00:00	2010-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7057	\N	\N
8636	VICPDTCOM	2010-01-12 00:00:00	2010-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7033	\N	\N
8637	VICPDTCOM	2010-01-12 00:00:00	2010-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7036	\N	\N
8638	VICPDTCOM	2010-01-12 00:00:00	2010-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7060	\N	\N
8639	VICPDTCOM	2010-01-12 00:00:00	2010-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7039	\N	\N
8640	VICPDTCOM	2010-01-12 00:00:00	2010-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7047	\N	\N
8641	VICPDTCOM	2010-01-12 00:00:00	2010-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7038	\N	\N
8642	SECRETCOM	2010-01-12 00:00:00	2010-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7059	\N	\N
8643	SECRETCOM	2010-01-12 00:00:00	2010-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7044	\N	\N
8644	SECRETCOM	2010-01-12 00:00:00	2010-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7062	\N	\N
8645	SECRETCOM	2010-01-12 00:00:00	2010-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7035	\N	\N
4560	MEMBRECOM	2007-07-05 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3642	\N	\N
4569	MEMBRECOM	2007-07-05 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3651	\N	\N
4578	MEMBRECOM	2007-07-05 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3660	\N	\N
4057	MEMBRECOM	2005-12-22 00:00:00	2006-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3137	\N	\N
4065	MEMBRECOM	2005-12-22 00:00:00	2006-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3145	\N	\N
4074	MEMBRECOM	2005-12-22 00:00:00	2006-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3155	\N	\N
4082	MEMBRECOM	2005-12-22 00:00:00	2006-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3163	\N	\N
4938	MEMBRECOM	2007-07-05 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3671	\N	\N
4917	MEMBRECOM	2008-06-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4004	\N	\N
4928	MEMBRECOM	2008-06-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4016	\N	\N
4937	MEMBRECOM	2008-06-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4025	\N	\N
4944	MEMBRECOM	2008-06-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4029	\N	\N
8754	MEMBRECOM	2010-04-28 00:00:00	2011-04-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7272	\N	\N
8755	MEMBRECOM	2010-04-28 00:00:00	2011-04-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7273	\N	\N
8756	MEMBRECOM	2010-04-28 00:00:00	2010-05-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7275	\N	\N
4249	MEMBRECOM	2006-06-16 00:00:00	2006-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3330	\N	\N
4260	MEMBRECOM	2006-06-15 00:00:00	2006-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3341	\N	\N
4268	MEMBRECOM	2006-06-30 00:00:00	2008-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3349	\N	\N
7932	VICPDTCOM	2008-11-13 00:00:00	2009-01-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6502	\N	2014-07-01 09:25:11
7933	MEMBRECOM	2008-11-13 00:00:00	2009-01-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6503	\N	2015-01-08 17:14:29
7934	MEMBRECOM	2008-11-13 00:00:00	2009-01-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6504	\N	\N
7935	RAPCOM	2008-11-13 00:00:00	2009-01-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6505	\N	2014-09-28 13:16:32
7936	MEMBRECOM	2008-11-13 00:00:00	2009-01-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6506	\N	\N
4392	MEMBRECOM	2007-01-10 00:00:00	2007-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3473	\N	\N
4400	MEMBRECOM	2007-01-10 00:00:00	2007-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3481	\N	\N
4469	MEMBRECOM	2007-02-01 00:00:00	2007-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3551	\N	\N
4519	MEMBRECOM	2007-02-14 00:00:00	2007-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3601	\N	\N
4552	MEMBRECOM	2007-06-26 00:00:00	2014-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3634	\N	2014-09-29 13:43:10
4637	MEMBRECOM	2007-07-26 00:00:00	2007-07-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3721	\N	\N
4409	MEMBRECOM	2007-01-10 00:00:00	2007-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3491	\N	\N
4418	MEMBRECOM	2007-01-10 00:00:00	2007-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3500	\N	\N
4555	MEMBRECOM	2007-07-05 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3637	\N	\N
4564	MEMBRECOM	2007-07-05 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3646	\N	\N
4574	MEMBRECOM	2007-07-05 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3656	\N	\N
3887	MEMBRECOM	2005-10-27 00:00:00	2006-03-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2976	\N	\N
3900	MEMBRECOM	2005-10-27 00:00:00	2006-03-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2989	\N	\N
3915	MEMBRECOM	2005-10-27 00:00:00	2006-03-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3004	\N	\N
3927	MEMBRECOM	2005-11-03 00:00:00	2006-05-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3018	\N	\N
1389	MEMBRECOM	2003-02-12 00:00:00	2003-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	975	\N	\N
3990	MEMBRECOM	2005-11-30 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3070	\N	\N
4027	MEMBRECOM	2005-12-13 00:00:00	2017-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3107	\N	2017-09-25 09:56:00
4035	MEMBRECOM	2005-12-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3115	\N	2014-09-28 12:09:44
4043	RAPCOM	2005-12-20 00:00:00	2015-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3123	\N	2015-01-08 17:14:29
4050	MEMBRECOM	2005-12-20 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3130	\N	\N
4058	MEMBRECOM	2005-12-22 00:00:00	2006-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3138	\N	\N
4067	MEMBRECOM	2005-12-22 00:00:00	2006-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3147	\N	\N
4077	MEMBRECOM	2005-12-22 00:00:00	2006-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3158	\N	\N
4119	MEMBRECOM	2006-02-08 00:00:00	2012-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3200	\N	\N
4127	PDTCOM	2006-01-23 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3208	\N	2014-09-28 18:58:21
4539	MEMBRECOM	2007-02-20 00:00:00	2007-02-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3621	\N	2017-09-24 18:59:59
4795	MEMBRECOM	2008-01-10 00:00:00	2008-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3881	\N	\N
4913	MEMBRECOM	2008-06-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4000	\N	\N
4923	MEMBRECOM	2008-06-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4011	\N	\N
4932	MEMBRECOM	2008-06-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4020	\N	\N
4994	MEMBRECOM	2008-07-09 00:00:00	2008-07-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4079	\N	2014-09-28 18:03:38
4894	MEMBRECOM	2008-05-21 00:00:00	2008-06-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3981	\N	\N
5044	MEMBRECOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4128	\N	\N
5098	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4187	\N	\N
3862	MEMBRECOM	2005-07-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2951	\N	\N
3870	MEMBRECOM	2005-09-19 00:00:00	2005-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2960	\N	\N
4355	MEMBRECOM	2006-12-19 00:00:00	2006-12-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3436	\N	2014-09-28 13:16:32
4872	MEMBRECOM	2008-04-16 00:00:00	2008-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3959	\N	2014-09-28 17:31:41
4946	MEMBRECOM	2008-06-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4031	\N	\N
7914	MEMBRECOM	2008-10-29 00:00:00	2008-11-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6484	\N	2014-09-28 17:07:41
7915	MEMBRECOM	2008-10-29 00:00:00	2008-11-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6485	\N	2014-09-28 17:07:41
7916	MEMBRECOM	2008-10-29 00:00:00	2008-11-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6486	\N	\N
7917	MEMBRECOM	2008-10-29 00:00:00	2008-11-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6487	\N	2014-09-28 17:22:11
4998	MEMBRECOM	2008-07-17 00:00:00	2008-07-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4083	\N	2014-09-28 16:42:05
4499	MEMBRECOM	2007-02-12 00:00:00	2007-02-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3581	\N	2017-09-24 17:15:15
4507	MEMBRECOM	2007-02-15 00:00:00	2007-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3589	\N	\N
4529	MEMBRECOM	2007-02-20 00:00:00	2007-02-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3611	\N	\N
4762	MEMBRECOM	2007-12-14 00:00:00	2007-12-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3847	\N	\N
4770	MEMBRECOM	2007-12-18 00:00:00	2007-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3855	\N	\N
4875	VICPDTCOM	2008-05-14 00:00:00	2008-05-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3962	\N	2014-09-28 18:58:21
5096	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4185	\N	\N
4647	MEMBRECOM	2007-07-27 00:00:00	2007-07-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3731	\N	2014-09-28 18:19:47
4884	MEMBRECOM	2008-05-14 00:00:00	2008-05-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3971	\N	\N
5094	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4183	\N	\N
5128	MEMBRECOM	2008-10-01 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4220	\N	\N
8266	MEMBRECOM	2009-07-08 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6825	\N	\N
8249	MEMBRECOM	2007-12-05 00:00:00	2009-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3815	\N	\N
8250	MEMBRECOM	2007-12-05 00:00:00	2011-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3818	\N	\N
8251	MEMBRECOM	2007-12-05 00:00:00	2007-12-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3817	\N	\N
8252	MEMBRECOM	2009-03-05 00:00:00	2009-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6606	\N	\N
8253	MEMBRECOM	2009-03-05 00:00:00	2009-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6617	\N	\N
8254	MEMBRECOM	2009-03-05 00:00:00	2009-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6641	\N	\N
8255	MEMBRECOM	2008-01-10 00:00:00	2008-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3876	\N	\N
8256	MEMBRECOM	2008-07-07 00:00:00	2008-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3890	\N	\N
8257	MEMBRECOM	2008-07-07 00:00:00	2007-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3489	\N	\N
8258	MEMBRECOM	2005-11-03 00:00:00	2006-05-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3014	\N	\N
8259	VICPDTCOM	2009-07-22 00:00:00	2009-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6788	\N	\N
8260	MEMBRECOM	2009-07-22 00:00:00	2009-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6799	\N	\N
8261	MEMBRECOM	1998-10-01 00:00:00	1998-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	349	\N	\N
8267	MEMBRECOM	2009-07-08 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6826	\N	\N
8270	MEMBRECOM	2009-07-10 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6829	\N	\N
8272	MEMBRECOM	2009-07-10 00:00:00	2009-07-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6831	\N	\N
8368	MEMBRECOM	2009-09-29 00:00:00	2012-09-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6923	\N	\N
8369	MEMBRECOM	2009-09-29 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6924	\N	\N
8371	MEMBRECOM	2009-09-29 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6926	\N	2014-09-28 18:00:58
8372	MEMBRECOM	2009-09-29 00:00:00	2017-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6927	\N	2017-06-19 12:20:59
8373	MEMBRECOM	2009-09-29 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6928	\N	2014-09-28 13:40:33
8374	MEMBRECOM	2009-09-29 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6929	\N	2017-09-24 17:35:15
8386	MEMBRECOM	2009-09-29 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6941	\N	2014-09-28 18:00:58
8387	MEMBRECOM	2009-09-29 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	6942	\N	\N
8388	MEMBRECOM	2009-09-29 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	6943	\N	\N
8389	MEMBRECOM	2009-09-29 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6944	\N	\N
8391	VICPDTCOM	2009-09-29 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	6946	\N	\N
8392	RAPCOM	2009-09-29 00:00:00	2018-08-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6947	\N	\N
8393	MEMBRECOM	2009-09-29 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6948	\N	2017-09-24 18:17:56
8394	MEMBRECOM	2009-09-29 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6949	\N	2014-09-28 17:07:41
8395	MEMBRECOM	2009-09-29 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6950	\N	2014-09-28 17:22:11
8396	MEMBRECOM	2009-09-29 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6951	\N	\N
8397	MEMBRECOM	2009-09-29 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6952	\N	2017-09-24 17:35:15
8398	MEMBRECOM	2009-09-29 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6953	\N	2014-09-28 17:22:11
8399	MEMBRECOM	2009-09-29 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6954	\N	2017-09-24 18:16:52
8400	MEMBRECOM	2009-09-29 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	6955	\N	\N
8401	MEMBRECOM	2009-09-29 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6956	\N	2014-09-28 17:27:35
8402	MEMBRECOM	2009-09-29 00:00:00	2014-09-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6957	\N	2014-09-01 10:21:13
8414	MEMBRECOM	2009-10-14 00:00:00	2010-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6971	\N	\N
8404	MEMBRECOM	2009-09-29 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	6959	\N	\N
8405	MEMBRECOM	2009-09-29 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6960	\N	2017-09-24 17:04:02
8415	MEMBRECOM	2009-10-14 00:00:00	2009-11-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6973	\N	\N
8416	MEMBRECOM	2009-10-14 00:00:00	2010-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6974	\N	\N
8417	MEMBRECOM	2009-10-14 00:00:00	2009-11-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6975	\N	\N
8418	MEMBRECOM	2009-10-14 00:00:00	2010-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6976	\N	\N
8419	MEMBRECOM	2009-10-14 00:00:00	2009-11-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6977	\N	\N
8420	MEMBRECOM	2009-10-14 00:00:00	2010-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6978	\N	\N
8422	MEMBRECOM	2009-10-14 00:00:00	2009-11-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6980	\N	\N
8423	MEMBRECOM	2009-10-14 00:00:00	2010-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6981	\N	\N
8424	MEMBRECOM	2009-10-14 00:00:00	2009-11-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6982	\N	\N
7941	MEMBRECOM	2008-11-13 00:00:00	2009-01-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6511	\N	\N
7966	MEMBRECOM	2008-12-19 00:00:00	2008-12-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6534	\N	2014-09-28 16:59:41
7967	MEMBRECOM	2008-12-19 00:00:00	2008-12-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6535	\N	2015-06-12 15:59:49
7968	MEMBRECOM	2008-12-19 00:00:00	2008-12-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6536	\N	\N
7969	MEMBRECOM	2008-12-19 00:00:00	2008-12-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6537	\N	\N
7973	MEMBRECOM	2008-12-19 00:00:00	2008-12-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6541	\N	2014-09-28 18:19:47
8113	MEMBRECOM	2009-04-02 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6687	\N	2014-09-28 18:19:47
8111	PDTCOM	2009-04-02 00:00:00	2014-07-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6685	\N	2014-07-01 09:25:11
8112	RAPCOM	2009-04-02 00:00:00	2015-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6686	\N	2015-01-08 17:14:28
8119	MEMBRECOM	2009-04-02 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6693	\N	\N
8120	MEMBRECOM	2009-04-02 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6694	\N	\N
8121	MEMBRECOM	2009-04-02 00:00:00	2011-03-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6695	\N	\N
8122	MEMBRECOM	2009-04-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	6696	\N	\N
8123	MEMBRECOM	2009-04-02 00:00:00	2014-05-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6697	\N	2014-05-05 10:59:42
8124	MEMBRECOM	2009-04-02 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6698	\N	\N
8128	MEMBRECOM	2009-04-02 00:00:00	2009-04-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6702	\N	\N
8129	MEMBRECOM	2009-04-02 00:00:00	2009-04-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6703	\N	\N
8130	MEMBRECOM	2009-04-02 00:00:00	2009-04-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6704	\N	\N
8131	MEMBRECOM	2009-04-02 00:00:00	2009-04-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6705	\N	\N
8132	MEMBRECOM	2009-04-02 00:00:00	2009-04-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6706	\N	\N
8133	MEMBRECOM	2009-04-02 00:00:00	2009-04-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6707	\N	\N
3667	MEMBRECOM	2005-02-02 00:00:00	2005-10-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2757	\N	\N
3671	MEMBRECOM	2005-02-02 00:00:00	2005-10-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2761	\N	\N
3674	MEMBRECOM	2005-02-02 00:00:00	2005-10-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2764	\N	\N
3677	MEMBRECOM	2005-02-02 00:00:00	2005-10-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2767	\N	\N
3683	MEMBRECOM	2005-02-02 00:00:00	2005-10-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2773	\N	\N
3687	MEMBRECOM	2005-02-02 00:00:00	2005-10-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2777	\N	\N
3693	MEMBRECOM	2005-02-02 00:00:00	2005-10-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2783	\N	\N
8339	MEMBRECOM	2009-07-29 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6897	\N	\N
8340	MEMBRECOM	2009-07-21 00:00:00	2010-01-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6898	\N	\N
8425	MEMBRECOM	2009-10-14 00:00:00	2010-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6984	\N	\N
8426	MEMBRECOM	2009-10-14 00:00:00	2009-11-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6985	\N	\N
8428	MEMBRECOM	2009-10-07 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6987	\N	2014-09-28 18:58:21
5189	MEMBRECOM	2008-10-07 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4270	\N	2014-09-28 16:50:17
8375	MEMBRECOM	2009-09-29 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6930	\N	\N
8376	PDTCOM	2009-09-29 00:00:00	2015-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6931	\N	2015-10-12 09:39:31
8377	RAPCOM	2009-09-29 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6932	\N	\N
8380	MEMBRECOM	2009-09-29 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6935	\N	2014-09-28 13:21:47
8381	MEMBRECOM	2009-09-29 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6936	\N	\N
8382	MEMBRECOM	2009-09-29 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6937	\N	\N
8384	MEMBRECOM	2009-09-29 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	6939	\N	\N
8385	MEMBRECOM	2009-09-29 00:00:00	2012-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6940	\N	\N
8390	MEMBRECOM	2009-09-29 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6945	\N	\N
8429	MEMBRECOM	2009-10-07 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6988	\N	2014-09-28 17:31:42
8430	MEMBRECOM	2009-10-07 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6989	\N	2014-09-28 17:40:23
8431	MEMBRECOM	2009-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6990	\N	\N
8432	MEMBRECOM	2009-10-07 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6991	\N	2014-09-28 14:31:42
8434	MEMBRECOM	2009-10-07 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6993	\N	2014-09-28 12:39:09
8435	MEMBRECOM	2009-10-07 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6994	\N	2014-09-28 12:56:42
8436	MEMBRECOM	2009-10-07 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	6995	\N	\N
8438	MEMBRECOM	2009-10-07 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6997	\N	2014-09-28 17:27:35
8440	MEMBRECOM	2009-10-07 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6999	\N	\N
8442	VICPDTCOM	2009-11-06 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7001	\N	\N
8443	RAPCOM	2009-11-06 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7002	\N	2014-09-28 16:59:41
8444	MEMBRECOM	2009-11-06 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7003	\N	2017-09-24 18:16:52
8445	MEMBRECOM	2009-11-06 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7004	\N	2014-09-28 12:56:41
8448	MEMBRECOM	2009-11-06 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7007	\N	\N
8449	MEMBRECOM	2009-11-06 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7008	\N	2014-09-28 17:55:39
8450	MEMBRECOM	2009-11-06 00:00:00	2012-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7009	\N	\N
8451	MEMBRECOM	2009-11-06 00:00:00	2016-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7010	\N	2017-01-03 11:09:24
8452	MEMBRECOM	2009-11-06 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7011	\N	\N
8455	MEMBRECOM	2009-11-06 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7014	\N	2014-09-29 09:08:32
8458	VICPDTPRECOM	2009-11-10 00:00:00	2010-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6980	\N	\N
8459	VICPDTCOM	2009-11-10 00:00:00	2010-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6977	\N	\N
8460	VICPDTCOM	2009-11-10 00:00:00	2010-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6975	\N	\N
8461	SECRETCOM	2009-11-10 00:00:00	2010-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6982	\N	\N
8462	MEMBRECOM	2009-10-14 00:00:00	2009-11-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6972	\N	\N
5402	MEMBRECOM	2008-10-08 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4402	\N	\N
5403	VICPDTCOM	2008-10-08 00:00:00	2011-09-30 00:00:00	1	ANCIEN	\N	\N	\N	\N	4403	\N	\N
5410	MEMBRECOM	2008-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4413	\N	2014-10-09 15:40:04
7889	MEMBRECOM	\N	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4039	\N	\N
7918	VICPDTCOM	2008-11-20 00:00:00	2008-11-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6488	\N	\N
5420	VICPDTCOM	2008-10-08 00:00:00	2011-09-30 00:00:00	5	ANCIEN	\N	\N	\N	\N	4423	\N	\N
5423	MEMBRECOM	2008-10-08 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4427	\N	\N
7919	RAPCOM	2008-11-20 00:00:00	2008-11-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6489	\N	\N
7926	MEMBRECOM	2008-11-20 00:00:00	2008-11-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6496	\N	\N
7927	MEMBRECOM	2008-11-20 00:00:00	2008-11-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6497	\N	2017-09-24 17:35:15
7928	MEMBRECOM	2008-11-20 00:00:00	2008-11-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6498	\N	\N
7929	MEMBRECOM	2008-11-20 00:00:00	2008-11-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6499	\N	2014-09-28 17:07:41
7930	MEMBRECOM	2008-11-20 00:00:00	2008-11-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6500	\N	\N
7931	MEMBRECOM	2008-11-20 00:00:00	2008-11-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6501	\N	\N
8005	PDTCOM	2009-02-27 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6573	\N	2014-09-28 18:58:21
8006	RAPCOM	2009-02-27 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6574	\N	\N
8007	MEMBRECOM	2009-02-27 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6575	\N	\N
9135	MEMBRECOM	2011-01-13 00:00:00	2012-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7635	\N	\N
9136	SECRETCOM	2011-01-11 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7585	\N	\N
9222	MEMBRECOM	2011-02-08 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7720	\N	\N
9223	VICPDTCOM	\N	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7469	\N	\N
9233	MEMBRECOM	2011-02-10 00:00:00	2012-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7730	\N	\N
9234	MEMBRECOM	2011-02-10 00:00:00	2019-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7731	\N	\N
9235	MEMBRECOM	2011-02-10 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7732	\N	\N
9236	MEMBRECOM	2011-02-10 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7733	\N	\N
9237	MEMBRECOM	2011-02-10 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7734	\N	\N
9238	VICPDTCOM	2011-02-10 00:00:00	2015-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7735	\N	2015-10-12 09:39:30
9239	RAPCOM	2011-02-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7736	\N	2014-09-28 18:00:58
9240	MEMBRECOM	2011-02-10 00:00:00	2015-04-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7737	\N	2015-04-21 17:14:30
9241	MEMBRECOM	2011-02-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7738	\N	2014-09-28 17:40:23
9242	MEMBRECOM	2011-02-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7739	\N	\N
9243	MEMBRECOM	2011-02-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7740	\N	2014-09-28 13:40:33
9244	MEMBRECOM	2011-02-10 00:00:00	2012-09-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7741	\N	\N
9245	MEMBRECOM	2011-02-10 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7742	\N	2017-10-01 10:17:18
9246	MEMBRECOM	2011-02-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7743	\N	\N
9247	MEMBRECOM	2011-02-10 00:00:00	2012-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7744	\N	\N
9248	MEMBRECOM	2011-02-10 00:00:00	2019-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7745	\N	\N
9249	MEMBRECOM	2011-02-10 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7746	\N	\N
9250	MEMBRECOM	2011-02-10 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7747	\N	\N
9251	MEMBRECOM	2011-02-10 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7748	\N	\N
8736	MEMBRECOM	2010-04-27 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7253	\N	\N
8790	MEMBRECOM	2010-05-20 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7296	\N	\N
8792	MEMBRECOM	2010-05-20 00:00:00	2012-05-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7298	\N	\N
8800	MEMBRECOM	2010-05-20 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7306	\N	\N
9034	MEMBRECOM	2010-12-08 00:00:00	2021-07-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7534	\N	\N
9054	MEMBRECOM	2010-12-16 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7554	\N	\N
8945	MEMBRECOM	2010-10-19 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7445	\N	\N
8946	MEMBRECOM	2010-10-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7446	\N	\N
8947	MEMBRECOM	2010-10-19 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7447	\N	\N
4744	MEMBRECOM	2007-12-11 00:00:00	2007-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3828	\N	\N
4330	MEMBRECOM	2006-12-12 00:00:00	2006-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3411	\N	\N
2996	MEMBRECOM	2004-01-23 00:00:00	2010-03-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2199	\N	\N
4550	MEMBRECOM	2007-06-26 00:00:00	2010-03-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3632	\N	\N
8281	MEMBRECOM	2009-07-01 00:00:00	2010-03-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6839	\N	\N
2545	MEMBRECOM	2003-07-18 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1936	\N	2017-09-24 18:16:52
2352	VICPDTCOM	2003-01-28 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1791	\N	2014-09-28 16:42:05
2618	MEMBRECOM	2003-10-16 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2009	\N	\N
2796	MEMBRECOM	2003-11-19 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2092	\N	\N
2949	MEMBRECOM	2003-12-09 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2152	\N	\N
2958	MEMBRECOM	2003-12-16 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2161	\N	2014-09-28 16:59:41
2971	VICPDTCOM	2004-01-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2174	\N	2014-09-28 16:42:05
2991	MEMBRECOM	2004-01-23 00:00:00	2012-09-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2194	\N	\N
3007	MEMBRECOM	2004-02-11 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2210	\N	\N
3106	VICPDTCOM	2004-04-13 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2254	\N	2014-09-28 18:58:21
2366	RAPCOM	2003-05-15 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1806	\N	\N
2377	MEMBRECOM	2003-05-15 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1817	\N	\N
2391	MEMBRECOM	2003-06-12 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1829	\N	2014-09-28 13:16:32
2422	MEMBRECOM	2003-06-26 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1860	\N	2014-09-28 17:09:16
2539	VICPDTCOM	2003-07-18 00:00:00	2011-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1930	\N	\N
2557	MEMBRECOM	2003-07-23 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1948	\N	\N
3557	VICPDTCOM	2004-07-27 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2644	\N	2014-09-28 16:42:05
3570	MEMBRECOM	2004-07-27 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2657	\N	\N
3595	PDTCOM	2004-11-18 00:00:00	2011-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2683	\N	\N
3602	MEMBRECOM	2004-11-18 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2690	\N	2017-09-24 13:44:49
3615	MEMBRECOM	2004-12-07 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2703	\N	2017-09-24 13:44:49
3621	MEMBRECOM	2004-12-07 00:00:00	2014-09-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2709	\N	2014-09-01 10:21:13
3641	MEMBRECOM	2004-12-20 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2729	\N	2014-09-28 16:59:41
3651	MEMBRECOM	2004-12-20 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2739	\N	2014-09-28 18:03:38
3658	MEMBRECOM	2004-10-20 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2746	\N	\N
3663	MEMBRECOM	2004-10-20 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2751	\N	2014-09-28 16:42:05
3146	MEMBRECOM	2004-05-12 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2293	\N	2017-09-24 17:09:24
3163	PDTCOM	2004-06-09 00:00:00	2011-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2310	\N	\N
3550	MEMBRECOM	2004-10-06 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	231	\N	\N
3559	MEMBRECOM	2004-07-27 00:00:00	2009-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2646	\N	\N
3567	MEMBRECOM	2004-07-27 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	2654	\N	\N
3604	MEMBRECOM	2004-11-18 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2692	\N	2017-09-24 19:25:10
3611	MEMBRECOM	2004-12-07 00:00:00	2007-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2699	\N	\N
3661	MEMBRECOM	2004-10-20 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	2749	\N	\N
3696	MEMBRECOM	2005-02-21 00:00:00	2005-02-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2786	\N	\N
3728	MEMBRECOM	2005-02-24 00:00:00	2005-02-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2818	\N	\N
3739	MEMBRECOM	2005-03-15 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2828	\N	\N
3769	VICPDTCOM	2005-05-04 00:00:00	2011-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2858	\N	\N
3777	MEMBRECOM	2005-05-04 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2866	\N	2017-09-24 18:05:40
3784	RAPCOM	2005-05-11 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2873	\N	\N
3816	VICPDTCOM	2005-06-30 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2905	\N	2014-09-28 18:00:58
5359	VICPDTCOM	2008-10-07 00:00:00	2011-09-30 00:00:00	7	ANCIEN	\N	\N	\N	\N	749	\N	\N
5360	VICPDTCOM	2008-10-08 00:00:00	2010-10-18 00:00:00	8	ANCIEN	\N	\N	\N	\N	2603	\N	\N
5361	SECRETCOM	2008-10-08 00:00:00	2011-09-30 00:00:00	2	ANCIEN	\N	\N	\N	\N	2526	\N	\N
5362	SECRETCOM	2008-10-08 00:00:00	2011-09-30 00:00:00	4	ANCIEN	\N	\N	\N	\N	195	\N	\N
3824	MEMBRECOM	2005-06-30 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2913	\N	2017-09-24 17:35:15
3262	RAPCOM	2004-07-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2409	\N	2014-09-28 13:16:32
3382	MEMBRECOM	2004-10-06 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2531	\N	\N
3391	MEMBRECOM	2004-10-06 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2540	\N	\N
3419	MEMBRECOM	2004-10-06 00:00:00	2008-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2569	\N	\N
3428	MEMBRECOM	2004-10-06 00:00:00	2011-02-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2579	\N	\N
3437	MEMBRECOM	2004-10-06 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2588	\N	\N
3464	MEMBRECOM	2004-10-06 00:00:00	2009-07-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2615	\N	\N
3473	MEMBRECOM	2004-10-06 00:00:00	2004-10-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2624	\N	\N
3490	VICPDTCOM	2004-10-07 00:00:00	2008-10-06 00:00:00	6	ANCIEN	\N	\N	\N	\N	689	\N	\N
4152	MEMBRECOM	2006-02-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	3233	\N	\N
4159	MEMBRECOM	2006-03-05 00:00:00	2015-04-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3240	\N	2015-04-21 17:14:30
4167	MEMBRECOM	2006-03-05 00:00:00	2010-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3248	\N	\N
4221	MEMBRECOM	2006-06-15 00:00:00	2007-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3302	\N	\N
4228	MEMBRECOM	2006-06-08 00:00:00	2006-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3309	\N	2015-06-12 16:01:58
3753	MEMBRECOM	2005-03-19 00:00:00	2010-04-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2842	\N	\N
5007	MEMBRECOM	2008-07-17 00:00:00	2008-07-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4092	\N	\N
8126	RAPCOM	2009-04-02 00:00:00	2009-04-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6700	\N	\N
8892	MEMBRECOM	2010-09-28 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7392	\N	2014-09-28 17:07:41
8893	MEMBRECOM	2010-09-28 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7393	\N	2014-09-28 17:22:11
8896	MEMBRECOM	2010-09-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7396	\N	\N
8848	PDTCOM	2007-12-12 00:00:00	2011-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3808	\N	\N
8894	MEMBRECOM	2010-09-28 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7394	\N	2017-09-24 18:59:59
8897	MEMBRECOM	2010-09-28 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7397	\N	\N
8944	MEMBRECOM	2010-10-19 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7444	\N	\N
8948	PDTCOM	2010-10-22 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7448	\N	2014-09-28 17:07:41
8949	RAPCOM	2010-10-22 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7449	\N	\N
8950	MEMBRECOM	2010-10-22 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7450	\N	\N
8951	MEMBRECOM	2010-10-22 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7451	\N	2017-09-24 19:25:10
8952	MEMBRECOM	2010-10-22 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7452	\N	2017-09-24 16:43:43
8953	MEMBRECOM	2010-10-22 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7453	\N	2014-09-28 17:07:41
8954	MEMBRECOM	2010-10-22 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7454	\N	2014-09-28 17:07:41
8956	MEMBRECOM	2010-10-22 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7456	\N	\N
8958	MEMBRECOM	2010-10-22 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7458	\N	\N
8959	MEMBRECOM	2010-10-22 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7459	\N	2014-09-28 17:34:16
8960	MEMBRECOM	2010-10-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7460	\N	\N
8961	MEMBRECOM	2010-10-22 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7461	\N	\N
8967	MEMBRECOM	2010-11-17 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7466	\N	\N
10284	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8643	\N	2013-12-16 10:13:19
10285	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8644	\N	2013-12-16 10:13:19
10286	MEMBRECOM	2012-02-15 00:00:00	2012-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8645	\N	\N
10287	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8646	\N	2013-12-16 10:13:19
10288	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8647	\N	2013-12-16 10:13:19
10289	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8648	\N	2013-12-16 10:13:19
10290	MEMBRECOM	2012-02-15 00:00:00	2012-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8649	\N	\N
10291	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8650	\N	2013-12-16 10:13:19
10292	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8651	\N	2013-12-16 10:13:19
4181	MEMBRECOM	2006-03-07 00:00:00	2006-03-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3262	\N	\N
3120	VICPDTCOM	2004-04-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2268	\N	2014-09-28 16:42:05
3130	MEMBRECOM	2004-04-15 00:00:00	2015-04-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2278	\N	2015-04-21 17:14:30
3132	MEMBRECOM	2004-04-15 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2280	\N	2017-09-24 17:35:15
3711	MEMBRECOM	2005-01-19 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2801	\N	\N
3720	MEMBRECOM	2005-01-27 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2810	\N	\N
3794	MEMBRECOM	2005-05-11 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	2883	\N	\N
3809	MEMBRECOM	2005-06-29 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2898	\N	\N
3821	MEMBRECOM	2005-06-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	2910	\N	\N
3834	MEMBRECOM	2005-07-05 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2923	\N	\N
3838	MEMBRECOM	2005-07-05 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2927	\N	2014-09-28 13:16:32
3845	MEMBRECOM	2005-07-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2934	\N	\N
4465	MEMBRECOM	2007-02-01 00:00:00	2007-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3547	\N	\N
4617	MEMBRECOM	2007-07-19 00:00:00	2012-09-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3701	\N	\N
4837	MEMBRECOM	2008-01-24 00:00:00	2008-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3922	\N	2014-09-28 17:31:41
4847	MEMBRECOM	2008-01-31 00:00:00	2008-02-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3932	\N	\N
4868	MEMBRECOM	2008-04-16 00:00:00	2008-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3955	\N	2014-09-28 17:07:41
4642	MEMBRECOM	2007-07-27 00:00:00	2007-07-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3726	\N	2014-09-28 13:16:32
4316	MEMBRECOM	2006-11-17 00:00:00	2006-11-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3397	\N	2014-09-28 17:07:41
4347	MEMBRECOM	2006-12-14 00:00:00	2006-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3428	\N	2014-04-25 17:05:01
4438	MEMBRECOM	2007-01-25 00:00:00	2007-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3520	\N	\N
4522	MEMBRECOM	2007-02-14 00:00:00	2007-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3604	\N	2014-09-28 12:09:44
5006	MEMBRECOM	2008-07-17 00:00:00	2008-07-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4091	\N	\N
4288	MEMBRECOM	2006-10-30 00:00:00	2006-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3369	\N	\N
4233	MEMBRECOM	2006-06-08 00:00:00	2006-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3314	\N	\N
4265	MEMBRECOM	2006-06-15 00:00:00	2006-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3346	\N	\N
4687	MEMBRECOM	2007-10-11 00:00:00	2007-10-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3768	\N	\N
4739	MEMBRECOM	2007-12-11 00:00:00	2007-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3823	\N	2015-06-12 15:59:49
4702	MEMBRECOM	2007-11-16 00:00:00	2007-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3783	\N	\N
4821	MEMBRECOM	2008-01-24 00:00:00	2008-01-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3906	\N	\N
4895	MEMBRECOM	2008-05-21 00:00:00	2008-06-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3982	\N	\N
5157	RAPCOM	2008-10-07 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4242	\N	\N
4366	MEMBRECOM	2006-12-19 00:00:00	2006-12-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3447	\N	2014-09-28 18:03:38
4448	MEMBRECOM	2007-01-25 00:00:00	2007-01-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3530	\N	2014-09-28 13:40:33
9294	MEMBRECOM	2011-06-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7791	\N	\N
9295	MEMBRECOM	2011-06-14 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7792	\N	2017-09-24 17:35:15
9297	MEMBRECOM	2011-06-14 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7794	\N	\N
9358	MEMBRECOM	2011-04-06 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7855	\N	2014-09-28 17:34:16
9359	MEMBRECOM	2011-04-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7856	\N	\N
9360	MEMBRECOM	2011-04-06 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7857	\N	\N
9366	MEMBRECOM	2011-06-28 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7863	\N	2017-10-01 10:17:18
9367	MEMBRECOM	2011-06-28 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7864	\N	2014-09-28 13:40:33
9368	MEMBRECOM	2011-06-28 00:00:00	2012-09-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7865	\N	\N
9369	MEMBRECOM	2011-06-28 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7866	\N	\N
9370	MEMBRECOM	2011-06-28 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7867	\N	\N
9371	MEMBRECOM	2011-06-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7868	\N	\N
10054	MEMBRECOM	2011-12-19 00:00:00	2021-07-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8408	\N	\N
10052	MEMBRECOM	2011-12-19 00:00:00	2015-01-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8406	\N	2015-01-23 15:38:35
10053	MEMBRECOM	2011-12-19 00:00:00	2017-05-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8407	\N	2017-05-16 15:18:13
10055	MEMBRECOM	2011-12-19 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8409	\N	2014-09-28 18:58:21
10088	MEMBRECOM	2012-01-12 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8442	\N	2017-09-24 18:16:52
10057	MEMBRECOM	2011-12-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8411	\N	\N
10089	MEMBRECOM	2012-01-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8443	\N	\N
10090	MEMBRECOM	2012-01-12 00:00:00	2015-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8444	\N	2015-10-13 14:23:47
10091	MEMBRECOM	2012-01-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8445	\N	\N
10092	MEMBRECOM	2012-01-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8446	\N	\N
10093	MEMBRECOM	2012-01-12 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8447	\N	2017-10-01 10:17:18
10094	MEMBRECOM	2012-01-12 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8448	\N	\N
9316	PDTCOM	2011-06-21 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7813	\N	2014-09-28 18:00:58
9349	MEMBRECOM	2011-04-06 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7846	\N	2017-09-24 17:35:15
9351	MEMBRECOM	2011-04-06 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7848	\N	2017-09-24 13:29:42
9352	MEMBRECOM	2011-04-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7849	\N	\N
8191	MEMBRECOM	2009-04-28 00:00:00	2009-05-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6766	\N	\N
8184	MEMBRECOM	2009-04-28 00:00:00	2009-05-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6759	\N	\N
9693	MEMBRECOM	2011-10-01 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8181	\N	2014-09-28 17:15:42
9878	MEMBRECOM	2011-10-18 00:00:00	2012-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8255	\N	\N
9699	MEMBRECOM	2011-10-01 00:00:00	2017-09-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8185	\N	2017-09-22 10:42:23
9704	MEMBRECOM	2011-10-01 00:00:00	2011-11-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8187	\N	\N
9706	SECRETCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2594	\N	2014-10-08 18:13:40
9708	MEMBRECOM	2011-10-01 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8188	\N	2014-09-28 17:03:42
9709	VICPDTCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	6	ANCIEN	\N	\N	\N	\N	2614	\N	2014-10-08 17:50:51
9710	MEMBRECOM	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8189	\N	2014-10-08 17:33:35
9879	MEMBRECOM	2011-10-18 00:00:00	2014-08-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8256	\N	2014-08-27 16:33:38
9712	MEMBRECOM	2011-10-01 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2622	\N	2017-10-04 18:51:31
9713	VICPDTCOM	2011-10-01 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	87	\N	\N
9909	VICPDTCOM	2011-11-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8283	\N	\N
9910	RAPCOM	2011-11-02 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8284	\N	2014-09-28 17:34:16
9716	VICPDTCOM	2011-10-01 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2600	\N	\N
9717	SECRETCOM	2011-10-01 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2532	\N	\N
9718	SECRETCOM	2011-10-01 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	795	\N	\N
9721	MEMBRECOM	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2599	\N	2017-09-24 18:05:41
9722	MEMBRECOM	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8190	\N	2014-10-08 17:36:48
9724	MEMBRECOM	2011-10-01 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	20	\N	2014-09-28 13:16:32
9928	MEMBRECOM	2011-11-07 00:00:00	2013-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8302	\N	\N
9728	MEMBRECOM	2011-10-01 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8191	\N	2014-10-09 10:49:07
9729	PDTCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	468	\N	2014-10-08 17:34:16
9731	SECRETCOM	2011-10-01 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	275	\N	2014-09-28 18:03:38
9929	MEMBRECOM	2011-11-07 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8303	\N	\N
9847	PDTCOM	2011-10-01 00:00:00	2012-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8231	\N	\N
9736	MEMBRECOM	2011-10-01 00:00:00	2015-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	247	\N	2015-10-13 14:16:49
9737	MEMBRECOM	2011-10-01 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	844	\N	2014-10-09 10:52:17
9743	VICPDTCOM	2011-10-01 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	35	\N	2014-09-28 16:42:05
9746	SECRETCOM	2011-10-01 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	258	\N	2014-09-28 17:09:16
9748	RAPCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8195	\N	2014-10-08 18:11:16
9749	MEMBRECOM	2011-10-01 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8196	\N	2014-09-28 16:59:41
9751	MEMBRECOM	2011-10-01 00:00:00	2015-12-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8198	\N	2015-12-16 17:18:59
9753	VICPDTCOM	2011-10-01 00:00:00	2012-06-19 00:00:00	1	ANCIEN	\N	\N	\N	\N	749	\N	\N
9755	RAPGENCOM	2011-10-01 00:00:00	2012-06-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2525	\N	\N
9756	MEMBRECOM	2011-10-01 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8201	\N	2017-10-04 18:38:45
9757	MEMBRECOM	2011-10-01 00:00:00	2012-06-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8202	\N	\N
9758	VICPDTCOM	2011-10-01 00:00:00	2014-07-21 00:00:00	5	ANCIEN	\N	\N	\N	\N	2526	\N	2014-07-22 12:08:43
9762	MEMBRECOM	2011-10-01 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8205	\N	2014-10-09 10:46:05
9763	MEMBRECOM	2011-10-01 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8206	\N	2017-10-04 18:50:14
9767	MEMBRECOM	2011-10-01 00:00:00	2015-05-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8210	\N	2015-05-22 16:21:54
9769	MEMBRECOM	2011-10-01 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8211	\N	2014-09-28 17:52:18
9771	VICPDTCOM	2011-10-01 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8212	\N	2014-09-29 09:05:47
9772	VICPDTCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2560	\N	2014-10-08 17:51:42
9777	MEMBRECOM	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8216	\N	2014-10-08 16:53:44
9778	MEMBRECOM	2011-10-01 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8217	\N	2014-09-28 13:32:35
9930	MEMBRECOM	2011-11-07 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8304	\N	\N
9931	MEMBRECOM	2011-11-07 00:00:00	2012-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8305	\N	\N
9932	MEMBRECOM	2011-11-07 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8306	\N	2017-09-24 17:42:25
9933	MEMBRECOM	2011-11-07 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8307	\N	\N
9934	MEMBRECOM	2011-11-07 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8308	\N	2014-09-28 17:34:16
9935	MEMBRECOM	2011-11-07 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8309	\N	\N
9936	MEMBRECOM	2011-11-07 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8310	\N	\N
10078	MEMBRECOM	2012-12-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8432	\N	\N
10096	MEMBRECOM	2012-01-12 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8450	\N	2014-09-28 18:00:58
10097	MEMBRECOM	2012-01-12 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8451	\N	\N
9291	MEMBRECOM	2011-06-14 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7788	\N	2014-09-28 17:07:41
9293	MEMBRECOM	2011-06-14 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7790	\N	2017-09-24 13:44:49
9298	MEMBRECOM	2011-06-14 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7795	\N	\N
9303	MEMBRECOM	2011-06-14 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7800	\N	\N
9301	MEMBRECOM	2011-06-14 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7798	\N	2014-09-28 18:58:21
9302	RAPCOM	2011-06-14 00:00:00	2016-11-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7799	\N	2016-12-01 10:36:51
9304	MEMBRECOM	2011-06-14 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7801	\N	\N
9305	MEMBRECOM	2011-06-14 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7802	\N	2014-09-28 19:03:23
9306	MEMBRECOM	2011-06-14 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7803	\N	2014-09-28 14:31:42
9318	MEMBRECOM	2011-06-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7815	\N	\N
9319	MEMBRECOM	2011-06-21 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7816	\N	2014-09-28 13:40:33
9320	MEMBRECOM	2011-06-21 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7817	\N	2014-09-28 13:21:47
9321	MEMBRECOM	2011-06-21 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7818	\N	\N
9322	MEMBRECOM	2011-06-21 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7819	\N	2017-10-01 10:17:18
9328	MEMBRECOM	2011-06-21 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7825	\N	2017-09-24 13:29:42
9376	PDTCOM	2011-07-06 00:00:00	2011-10-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7842	\N	\N
9377	VICPDTCOM	2011-07-06 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7826	\N	\N
9378	VICPDTCOM	2011-07-06 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7837	\N	\N
9379	VICPDTCOM	2011-07-06 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7830	\N	\N
9380	VICPDTCOM	2011-07-06 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7832	\N	\N
9381	VICPDTCOM	2011-07-06 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7833	\N	\N
9382	SECRETCOM	2011-07-06 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7836	\N	\N
9383	SECRETCOM	2011-07-06 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7839	\N	\N
9384	RAPCOM	2011-07-06 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7834	\N	\N
9408	MEMBRECOM	2011-06-29 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7896	\N	\N
9409	MEMBRECOM	2011-06-29 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7897	\N	2014-09-28 13:21:47
9411	MEMBRECOM	2011-06-29 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7899	\N	\N
9418	MEMBRECOM	2011-06-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7906	\N	\N
9473	MEMBRECOM	2011-07-06 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7961	\N	\N
9477	MEMBRECOM	2011-07-06 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7965	\N	2017-09-24 17:35:15
9482	MEMBRECOM	2011-07-06 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7970	\N	2014-09-28 17:38:26
9496	MEMBRECOM	2011-07-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7984	\N	\N
9694	SECRETCOM	2011-10-01 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8182	\N	\N
9698	MEMBRECOM	2011-10-01 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3676	\N	2014-09-28 17:07:41
9700	MEMBRECOM	2011-10-01 00:00:00	2012-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8186	\N	\N
9938	RAPCOM	2011-11-07 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8312	\N	\N
9703	MEMBRECOM	2011-10-01 00:00:00	2014-07-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	841	\N	2014-07-01 09:25:11
9705	VICPDTCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	9	ANCIEN	\N	\N	\N	\N	722	\N	2014-10-08 16:41:16
9752	SECRETCOM	2011-10-01 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8199	\N	\N
9754	MEMBRECOM	2011-10-01 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8200	\N	\N
9759	MEMBRECOM	2011-10-01 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8203	\N	\N
9760	MEMBRECOM	2011-10-01 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	728	\N	\N
9761	MEMBRECOM	2011-10-01 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8204	\N	\N
9783	MEMBRECOM	2011-10-01 00:00:00	2020-02-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2559	\N	\N
9765	MEMBRECOM	2011-10-01 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8208	\N	\N
9768	PDTCOM	2011-10-01 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	748	\N	\N
9782	MEMBRECOM	2011-10-01 00:00:00	2014-09-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	163	\N	2014-09-01 10:21:13
10098	MEMBRECOM	2012-01-12 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8452	\N	\N
10100	VICPDTCOM	2012-01-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8454	\N	\N
10101	RAPCOM	2012-01-12 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8455	\N	2014-09-28 13:40:33
10103	MEMBRECOM	2012-01-12 00:00:00	2012-09-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8457	\N	\N
10104	MEMBRECOM	2012-01-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8458	\N	\N
10105	MEMBRECOM	2012-01-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8459	\N	\N
10106	MEMBRECOM	2012-01-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8460	\N	\N
10107	MEMBRECOM	2012-01-12 00:00:00	2020-06-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8461	\N	\N
10108	MEMBRECOM	2012-01-12 00:00:00	2012-05-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8462	\N	\N
10113	MEMBRECOM	2012-01-12 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8467	\N	2017-09-24 17:35:15
10133	MEMBRECOM	2012-01-25 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8491	\N	2017-09-24 19:14:37
10134	RAPCOM	2012-01-25 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8492	\N	2014-09-28 16:59:41
10135	MEMBRECOM	2012-01-25 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8493	\N	2017-09-24 17:04:02
10136	MEMBRECOM	2012-01-25 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8494	\N	2017-09-24 19:16:18
10137	MEMBRECOM	2012-01-25 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8495	\N	2017-09-24 18:16:52
10138	MEMBRECOM	2012-01-25 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8496	\N	2014-09-28 16:50:17
10371	MEMBRECOM	2012-02-21 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8724	\N	2014-10-09 11:06:53
10372	MEMBRECOM	2012-02-21 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8725	\N	2014-09-28 17:31:42
10375	VICPDTCOM	2012-02-21 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8729	\N	2014-10-08 17:43:42
10376	MEMBRECOM	2012-02-21 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8728	\N	\N
10378	MEMBRECOM	2012-02-21 00:00:00	2012-10-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8730	\N	\N
10379	MEMBRECOM	2012-02-21 00:00:00	2012-07-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8732	\N	\N
10380	MEMBRECOM	2012-02-21 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8734	\N	2014-10-08 17:12:39
10381	VICPDTCOM	2012-02-21 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8733	\N	2014-09-28 13:09:05
10382	MEMBRECOM	2012-02-21 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8735	\N	\N
10383	MEMBRECOM	2012-02-21 00:00:00	2013-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8736	\N	\N
10384	MEMBRECOM	2012-02-21 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8737	\N	2017-10-04 19:02:02
10386	PDTCOM	2012-02-21 00:00:00	2014-10-07 00:00:00	1	ANCIEN	\N	\N	\N	\N	8739	\N	2014-10-08 16:56:26
10388	VICPDTCOM	2012-02-21 00:00:00	2012-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8741	\N	\N
10389	MEMBRECOM	2012-02-21 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8743	\N	2014-10-08 16:48:24
10391	SECRETCOM	2012-02-21 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8744	\N	2014-10-08 19:06:35
10392	MEMBRECOM	2012-02-21 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8745	\N	2014-09-28 12:39:09
10393	VICPDTCOM	2012-02-21 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8747	\N	2014-10-08 19:06:29
10394	SECRETCOM	2012-02-21 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8746	\N	2014-10-08 17:48:33
10395	VICPDTCOM	2012-02-21 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8748	\N	2014-09-28 17:03:42
10396	MEMBRECOM	2012-02-21 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8750	\N	2014-10-09 11:53:19
10398	MEMBRECOM	2012-02-21 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8752	\N	2014-09-28 17:31:42
10399	MEMBRECOM	2012-02-21 00:00:00	2012-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8751	\N	\N
10401	VICPDTCOM	2012-02-21 00:00:00	2014-05-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8754	\N	2014-05-12 09:52:22
10402	VICPDTCOM	2012-02-21 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8755	\N	2014-09-28 17:31:41
10404	VICPDTCOM	2012-02-21 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8757	\N	2014-09-28 14:31:42
9261	MEMBRECOM	2011-03-31 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7758	\N	\N
9262	MEMBRECOM	2011-03-31 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7759	\N	\N
9263	MEMBRECOM	2011-03-31 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7760	\N	\N
9264	MEMBRECOM	2011-03-31 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7761	\N	2014-09-28 17:03:42
9265	MEMBRECOM	2011-03-31 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7762	\N	\N
9323	MEMBRECOM	2011-06-21 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7820	\N	2014-09-28 16:42:05
9324	MEMBRECOM	2011-06-21 00:00:00	2017-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7821	\N	2017-06-19 12:20:59
9325	MEMBRECOM	2011-06-21 00:00:00	2022-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7822	\N	\N
9326	MEMBRECOM	2011-06-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7823	\N	\N
9329	MEMBRECOM	2011-06-28 00:00:00	2011-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7826	\N	\N
9330	MEMBRECOM	2011-06-28 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7827	\N	\N
9331	MEMBRECOM	2011-06-28 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7828	\N	\N
9332	MEMBRECOM	2011-06-28 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7829	\N	\N
9333	MEMBRECOM	2011-06-28 00:00:00	2011-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7830	\N	\N
9334	MEMBRECOM	2011-06-28 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7831	\N	\N
9335	MEMBRECOM	2011-06-28 00:00:00	2011-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7832	\N	\N
9336	MEMBRECOM	2011-06-28 00:00:00	2011-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7833	\N	\N
9337	MEMBRECOM	2011-06-28 00:00:00	2011-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7834	\N	\N
9338	MEMBRECOM	2011-06-28 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7835	\N	\N
9339	MEMBRECOM	2011-06-28 00:00:00	2011-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7836	\N	\N
9340	MEMBRECOM	2011-06-28 00:00:00	2011-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7837	\N	\N
9341	MEMBRECOM	2011-06-28 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7838	\N	\N
9342	MEMBRECOM	2011-06-28 00:00:00	2011-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7839	\N	\N
9343	MEMBRECOM	2011-06-28 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7840	\N	\N
9344	MEMBRECOM	2011-06-28 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7841	\N	\N
9345	MEMBRECOM	2011-06-28 00:00:00	2011-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7842	\N	\N
9346	MEMBRECOM	2011-06-28 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7843	\N	\N
9347	MEMBRECOM	2011-06-28 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7844	\N	\N
9511	MEMBRECOM	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8001	\N	2014-10-08 18:14:13
10877	MEMBRECOM	2013-03-13 00:00:00	2013-03-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9163	\N	\N
9514	MEMBRECOM	2011-10-01 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8004	\N	2014-10-09 10:44:58
9515	MEMBRECOM	2011-10-01 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8005	\N	2014-10-09 10:48:47
9517	MEMBRECOM	2011-10-01 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8007	\N	\N
3749	MEMBRECOM	2005-03-19 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2838	\N	\N
3772	MEMBRECOM	2005-05-04 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2861	\N	\N
3228	MEMBRECOM	2004-07-08 00:00:00	2015-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2375	\N	2015-01-08 17:14:29
3243	MEMBRECOM	2004-07-09 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2390	\N	\N
3253	VICPDTCOM	2004-07-15 00:00:00	2014-07-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2400	\N	2014-07-01 09:25:11
3937	PDTCOM	2005-11-04 00:00:00	2015-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3029	\N	2015-10-12 09:39:30
3957	RAPCOM	2005-11-18 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3047	\N	\N
8660	MEMBRECOM	2010-02-16 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7189	\N	\N
8662	RAPCOM	2010-02-18 00:00:00	2015-04-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7191	\N	2015-04-21 17:14:30
8663	MEMBRECOM	2010-02-18 00:00:00	2019-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7192	\N	\N
8665	MEMBRECOM	2010-02-18 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7194	\N	2017-10-01 10:17:18
8666	MEMBRECOM	2010-02-18 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7195	\N	\N
8667	MEMBRECOM	2010-02-18 00:00:00	2012-09-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7196	\N	\N
8668	MEMBRECOM	2010-02-18 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7197	\N	\N
8669	MEMBRECOM	2010-02-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7198	\N	\N
8670	MEMBRECOM	2010-02-18 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7199	\N	2014-09-28 17:34:16
8671	MEMBRECOM	2010-02-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7200	\N	\N
8672	MEMBRECOM	2010-02-18 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7201	\N	\N
3964	MEMBRECOM	2005-11-18 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3054	\N	\N
3988	MEMBRECOM	2005-11-30 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3068	\N	2014-09-28 18:19:47
3997	MEMBRECOM	2005-11-30 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3077	\N	2014-09-28 17:38:26
4017	MEMBRECOM	2005-12-13 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3097	\N	2014-09-28 16:59:41
4028	VICPDTCOM	2005-12-15 00:00:00	2015-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3108	\N	2015-10-12 09:39:30
4038	MEMBRECOM	2005-12-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	3118	\N	\N
9443	MEMBRECOM	2011-07-01 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7931	\N	\N
4041	MEMBRECOM	2005-12-15 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3121	\N	2017-09-24 18:16:52
4087	MEMBRECOM	2006-01-19 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3168	\N	\N
4098	MEMBRECOM	2006-01-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	3179	\N	\N
4108	MEMBRECOM	2006-01-26 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3189	\N	2014-09-28 17:07:41
4118	MEMBRECOM	2006-02-08 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3199	\N	\N
4126	MEMBRECOM	2006-02-08 00:00:00	2019-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3207	\N	\N
4138	MEMBRECOM	2006-01-23 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3219	\N	\N
4149	MEMBRECOM	2006-02-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	3230	\N	\N
4157	MEMBRECOM	2006-03-05 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3238	\N	2014-09-28 17:15:42
4168	MEMBRECOM	2006-03-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	3249	\N	\N
9271	VICPDTCOM	2011-04-27 00:00:00	2015-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7768	\N	2015-10-12 09:39:30
9272	RAPCOM	2011-04-27 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7769	\N	\N
9273	MEMBRECOM	2011-04-27 00:00:00	2020-07-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7770	\N	\N
9277	MEMBRECOM	2011-04-27 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7774	\N	\N
9280	MEMBRECOM	2011-04-27 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7777	\N	\N
9282	MEMBRECOM	2011-04-27 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7779	\N	\N
9283	MEMBRECOM	2011-04-27 00:00:00	2019-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7780	\N	\N
9313	MEMBRECOM	2011-06-14 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7810	\N	\N
9314	MEMBRECOM	2011-06-14 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7811	\N	2014-09-28 17:03:42
9880	PDTCOM	2011-10-20 00:00:00	2015-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8257	\N	2015-01-08 17:14:29
9885	MEMBRECOM	2011-10-20 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8262	\N	\N
9522	MEMBRECOM	2011-10-01 00:00:00	2013-12-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8012	\N	2013-12-17 17:04:48
9523	MEMBRECOM	2011-10-01 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8013	\N	2014-10-09 10:57:32
9524	MEMBRECOM	2011-10-01 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8014	\N	\N
9887	MEMBRECOM	2011-10-20 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8264	\N	2017-09-24 18:20:10
9896	MEMBRECOM	2011-10-25 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8273	\N	\N
9897	MEMBRECOM	2011-10-25 00:00:00	2011-10-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8274	\N	\N
9898	MEMBRECOM	2011-10-25 00:00:00	2011-10-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8275	\N	\N
9899	MEMBRECOM	2011-10-25 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8276	\N	\N
9533	MEMBRECOM	2011-10-01 00:00:00	2012-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8023	\N	\N
9900	MEMBRECOM	2011-10-25 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8277	\N	\N
9535	MEMBRECOM	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8025	\N	2014-10-08 17:43:48
9901	MEMBRECOM	2011-10-25 00:00:00	2011-10-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8278	\N	\N
9538	MEMBRECOM	2011-10-01 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8028	\N	\N
9539	MEMBRECOM	2011-10-01 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8029	\N	\N
9542	MEMBRECOM	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8032	\N	2014-10-08 17:11:49
9543	MEMBRECOM	2011-10-01 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8033	\N	\N
9544	MEMBRECOM	2011-10-01 00:00:00	2011-12-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8034	\N	\N
9939	VICPDTCOM	2011-11-14 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8313	\N	2017-09-24 17:35:15
9940	RAPCOM	2011-11-14 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8314	\N	\N
9547	MEMBRECOM	2011-10-01 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8037	\N	2014-10-09 10:50:53
9941	MEMBRECOM	2011-11-14 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8315	\N	2017-09-24 17:47:28
9942	MEMBRECOM	2011-11-14 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8316	\N	2014-09-28 17:38:26
9550	MEMBRECOM	2011-10-01 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8040	\N	2014-10-09 12:15:01
9943	MEMBRECOM	2011-11-14 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8317	\N	2017-09-24 17:47:27
9944	MEMBRECOM	2011-11-14 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8318	\N	2014-09-28 17:07:41
9945	MEMBRECOM	2011-11-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8319	\N	\N
9946	MEMBRECOM	2011-11-14 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8320	\N	2014-09-28 17:07:41
9948	MEMBRECOM	2011-11-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8322	\N	\N
9949	MEMBRECOM	2011-11-14 00:00:00	2012-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8323	\N	\N
9951	MEMBRECOM	2011-11-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8325	\N	\N
9560	MEMBRECOM	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8050	\N	2017-09-24 19:14:37
9952	MEMBRECOM	2011-11-14 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8326	\N	2014-09-28 17:52:18
9562	MEMBRECOM	2011-10-01 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8052	\N	2014-10-09 12:12:49
9566	MEMBRECOM	2011-10-01 00:00:00	2013-07-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8056	\N	2013-07-19 11:52:19
10139	MEMBRECOM	2012-01-25 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8497	\N	2014-09-28 17:27:29
10364	MEMBRECOM	2012-02-21 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8716	\N	2017-09-24 16:45:26
9569	MEMBRECOM	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8059	\N	2017-09-24 16:45:26
9570	MEMBRECOM	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8060	\N	2017-09-24 10:41:28
9571	MEMBRECOM	2011-10-01 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8061	\N	\N
9572	MEMBRECOM	2011-10-01 00:00:00	2012-06-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8062	\N	\N
10366	VICPDTCOM	2012-02-21 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8718	\N	2014-09-28 17:38:26
9574	MEMBRECOM	2011-10-01 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8064	\N	\N
9575	SECRETCOM	2011-10-01 00:00:00	2012-06-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8065	\N	\N
10368	MEMBRECOM	2012-02-21 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8720	\N	2014-10-09 11:02:51
9579	MEMBRECOM	2011-10-01 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8069	\N	\N
9580	MEMBRECOM	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8070	\N	2017-09-25 10:54:33
9581	MEMBRECOM	2011-10-01 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8071	\N	\N
9582	MEMBRECOM	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8072	\N	2017-09-25 10:54:33
9584	MEMBRECOM	2011-10-01 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8074	\N	2017-10-04 18:35:43
9286	PDTCOM	2011-06-14 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7783	\N	2014-09-28 17:07:41
9287	RAPCOM	2011-06-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7784	\N	\N
9288	MEMBRECOM	2011-06-14 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7785	\N	\N
9289	MEMBRECOM	2011-06-14 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7786	\N	\N
9290	MEMBRECOM	2011-06-14 00:00:00	2013-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7787	\N	\N
9300	MEMBRECOM	2011-06-14 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7797	\N	\N
9312	MEMBRECOM	2011-06-14 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7809	\N	2017-09-24 17:09:24
9317	MEMBRECOM	2011-06-21 00:00:00	2019-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7814	\N	\N
9350	MEMBRECOM	2011-04-06 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7847	\N	2014-09-28 18:00:58
9355	MEMBRECOM	2011-04-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7852	\N	\N
9356	MEMBRECOM	2011-04-06 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7853	\N	2014-09-28 18:58:25
9357	MEMBRECOM	2011-04-06 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7854	\N	\N
9508	SECRETCOM	2011-10-01 00:00:00	2013-02-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7996	\N	\N
9509	MEMBRECOM	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7997	\N	2014-10-08 16:55:52
9480	MEMBRECOM	2011-07-06 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7968	\N	\N
9587	MEMBRECOM	2011-10-01 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8077	\N	2014-10-09 10:57:52
9495	MEMBRECOM	2011-07-08 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7983	\N	\N
9686	MEMBRECOM	2011-10-01 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8175	\N	2014-09-28 12:21:28
9687	MEMBRECOM	2011-10-01 00:00:00	2014-09-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8176	\N	2014-09-16 14:55:28
9592	MEMBRECOM	2011-10-01 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8082	\N	\N
9688	MEMBRECOM	2011-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8177	\N	\N
9594	MEMBRECOM	2011-10-01 00:00:00	2012-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8084	\N	\N
9595	MEMBRECOM	2011-10-01 00:00:00	2015-01-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8085	\N	2015-01-28 15:32:49
9596	SECRETCOM	2011-10-01 00:00:00	2012-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8086	\N	\N
9597	MEMBRECOM	2011-10-01 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8087	\N	\N
9689	MEMBRECOM	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8178	\N	2014-10-08 16:42:08
9881	RAPCOM	2011-10-20 00:00:00	2012-05-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8258	\N	\N
9882	MEMBRECOM	2011-10-20 00:00:00	2017-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8259	\N	2017-09-25 09:56:00
9883	MEMBRECOM	2011-10-20 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8260	\N	\N
9604	MEMBRECOM	2011-10-01 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8094	\N	2014-10-09 10:52:39
9605	MEMBRECOM	2011-10-01 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8095	\N	2014-10-09 13:52:12
9607	MEMBRECOM	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8097	\N	2014-10-08 17:40:09
9608	MEMBRECOM	2011-10-01 00:00:00	2014-07-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8098	\N	2014-07-01 09:29:53
9610	MEMBRECOM	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8100	\N	2017-09-24 16:24:51
9884	MEMBRECOM	2011-10-20 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8261	\N	\N
10083	MEMBRECOM	2012-12-21 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8437	\N	2014-09-28 13:40:33
9615	MEMBRECOM	2011-10-01 00:00:00	2012-02-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8105	\N	\N
9616	MEMBRECOM	2011-10-01 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8106	\N	\N
10084	MEMBRECOM	2012-12-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8438	\N	\N
9620	MEMBRECOM	2011-10-01 00:00:00	2012-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8110	\N	\N
10114	MEMBRECOM	2012-02-01 00:00:00	2012-02-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8468	\N	\N
9623	MEMBRECOM	2011-10-01 00:00:00	2018-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8113	\N	\N
10115	MEMBRECOM	2012-02-01 00:00:00	2012-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8469	\N	2013-12-16 10:26:49
10116	MEMBRECOM	2012-02-01 00:00:00	2012-02-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8472	\N	\N
10117	MEMBRECOM	2012-02-01 00:00:00	2012-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8473	\N	2013-12-16 10:26:49
9627	MEMBRECOM	2011-10-01 00:00:00	2012-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8117	\N	\N
10118	MEMBRECOM	2012-02-01 00:00:00	2012-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8474	\N	2013-12-16 10:26:49
10119	MEMBRECOM	2012-02-01 00:00:00	2012-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8475	\N	2013-12-16 10:26:49
10120	MEMBRECOM	2012-02-01 00:00:00	2012-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8476	\N	2013-12-16 10:26:49
10121	MEMBRECOM	2012-02-01 00:00:00	2012-06-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8477	\N	\N
9632	MEMBRECOM	2011-10-01 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8122	\N	\N
9633	MEMBRECOM	2011-10-01 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8123	\N	2014-10-09 12:15:08
9634	SECRETCOM	2011-10-01 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8124	\N	\N
10122	MEMBRECOM	2012-02-01 00:00:00	2012-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8478	\N	2013-12-16 10:26:49
9636	MEMBRECOM	2011-10-01 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8126	\N	2014-10-09 13:58:09
10123	MEMBRECOM	2012-02-01 00:00:00	2012-02-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8479	\N	\N
9639	MEMBRECOM	2011-10-01 00:00:00	2012-02-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8129	\N	\N
10124	MEMBRECOM	2012-02-01 00:00:00	2012-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8482	\N	2013-12-16 10:26:49
10125	MEMBRECOM	2012-02-01 00:00:00	2012-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8483	\N	2013-12-16 10:26:49
10126	MEMBRECOM	2012-02-01 00:00:00	2012-02-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8484	\N	\N
10127	MEMBRECOM	2012-02-01 00:00:00	2012-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8485	\N	2013-12-16 10:26:49
10128	MEMBRECOM	2012-02-01 00:00:00	2012-02-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8486	\N	\N
10129	MEMBRECOM	2012-02-01 00:00:00	2012-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8487	\N	2013-12-16 10:26:49
10130	MEMBRECOM	2012-02-01 00:00:00	2012-02-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8488	\N	\N
10131	PDTCOM	2012-01-25 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8489	\N	2017-09-24 13:14:55
10141	MEMBRECOM	2012-01-25 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8499	\N	\N
9390	MEMBRECOM	2011-06-27 00:00:00	2012-05-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7878	\N	\N
9393	MEMBRECOM	2011-06-27 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7881	\N	\N
9394	MEMBRECOM	2011-06-27 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7882	\N	2014-09-28 16:59:41
9395	MEMBRECOM	2011-06-27 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7883	\N	\N
9396	MEMBRECOM	2011-06-27 00:00:00	2013-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7884	\N	\N
9397	MEMBRECOM	2011-06-27 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7885	\N	\N
9402	MEMBRECOM	2011-06-29 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7890	\N	\N
9403	MEMBRECOM	2011-06-29 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7891	\N	2014-09-29 09:08:32
9404	MEMBRECOM	2011-06-29 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7892	\N	\N
9405	MEMBRECOM	2011-06-29 00:00:00	2012-09-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7893	\N	\N
9406	MEMBRECOM	2011-06-29 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7894	\N	\N
9407	MEMBRECOM	2011-06-29 00:00:00	2012-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7895	\N	\N
9422	MEMBRECOM	2011-06-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7910	\N	\N
9423	MEMBRECOM	2011-06-30 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7911	\N	2014-09-28 13:21:47
9424	MEMBRECOM	2011-06-30 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7912	\N	\N
9425	MEMBRECOM	2011-06-30 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7913	\N	\N
9426	MEMBRECOM	2011-06-30 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7914	\N	2017-09-24 13:29:42
9441	RAPCOM	2011-07-01 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7929	\N	2014-09-28 17:07:41
9442	VICPDTCOM	2011-07-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7930	\N	\N
9444	MEMBRECOM	2011-07-01 00:00:00	2018-08-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7932	\N	\N
9449	MEMBRECOM	2011-07-01 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7937	\N	2017-09-24 19:25:10
9450	MEMBRECOM	2011-07-01 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7938	\N	2014-09-28 17:07:41
9469	PDTCOM	2011-07-06 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7957	\N	2014-09-28 17:07:41
9470	RAPCOM	2011-07-06 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7958	\N	\N
9471	MEMBRECOM	2011-07-06 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7959	\N	2017-09-24 18:17:56
9472	MEMBRECOM	2011-07-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7960	\N	\N
9475	MEMBRECOM	2011-07-06 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7963	\N	2014-09-28 17:07:41
9478	MEMBRECOM	2011-07-06 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7966	\N	2014-09-28 17:07:41
9479	MEMBRECOM	2011-07-06 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7967	\N	\N
9497	MEMBRECOM	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7985	\N	2014-10-08 17:18:55
9682	MEMBRECOM	2011-10-01 00:00:00	2011-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8172	\N	\N
9723	VICPDTCOM	2011-10-01 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4302	\N	2014-09-28 17:27:35
9652	MEMBRECOM	2011-10-01 00:00:00	2014-04-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8142	\N	2014-04-16 17:42:38
9727	VICPDTCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	9	ANCIEN	\N	\N	\N	\N	720	\N	2014-10-08 17:50:56
9730	MEMBRECOM	2011-10-01 00:00:00	2012-02-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8192	\N	\N
9733	MEMBRECOM	2011-10-01 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8193	\N	\N
9656	MEMBRECOM	2011-10-01 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8146	\N	\N
11011	MEMBRECOM	2013-04-23 00:00:00	2013-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9298	\N	2013-12-16 10:30:09
9738	MEMBRECOM	2011-10-01 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	422	\N	2017-10-04 18:48:04
9740	MEMBRECOM	2011-10-01 00:00:00	2012-09-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	496	\N	\N
9661	MEMBRECOM	2011-10-01 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8151	\N	2017-10-04 18:38:40
9662	MEMBRECOM	2011-10-01 00:00:00	2012-12-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8152	\N	\N
9664	MEMBRECOM	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8154	\N	2017-09-24 17:55:12
9666	SECRETCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8156	\N	2014-10-08 18:13:46
9668	MEMBRECOM	2011-10-01 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8158	\N	\N
9669	MEMBRECOM	2011-10-01 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8159	\N	\N
9745	PDTCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3683	\N	2014-10-08 17:50:34
9747	VICPDTCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2546	\N	2014-10-08 17:49:21
9750	MEMBRECOM	2011-10-05 00:00:00	2015-12-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8197	\N	2015-12-16 17:18:56
9766	MEMBRECOM	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8209	\N	2017-09-24 17:47:27
9675	MEMBRECOM	2011-10-01 00:00:00	2012-02-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8165	\N	\N
9677	MEMBRECOM	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8167	\N	2014-10-08 18:16:46
9678	MEMBRECOM	2011-10-01 00:00:00	2014-07-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8168	\N	2014-07-16 17:22:41
9773	VICPDTCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	3	ANCIEN	\N	\N	\N	\N	8213	\N	2014-10-08 17:46:18
9779	MEMBRECOM	2011-10-01 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8218	\N	2014-09-28 17:27:35
9781	PDTCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2529	\N	2014-10-08 17:02:50
9784	MEMBRECOM	2011-10-01 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8219	\N	2014-09-28 13:21:47
9785	MEMBRECOM	2011-10-01 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8220	\N	2014-09-28 13:39:20
9786	MEMBRECOM	2011-10-01 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8221	\N	\N
9285	MEMBRECOM	2010-10-06 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7782	\N	\N
9353	MEMBRECOM	2011-04-06 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7850	\N	\N
9354	MEMBRECOM	2011-04-06 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7851	\N	\N
9410	MEMBRECOM	2011-06-29 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7898	\N	\N
9456	RAPCOM	2011-07-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7944	\N	\N
9463	MEMBRECOM	2011-07-05 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7951	\N	2014-09-28 16:59:41
9465	MEMBRECOM	2011-07-05 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7953	\N	2014-09-28 13:40:33
9466	MEMBRECOM	2011-07-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7954	\N	\N
9468	MEMBRECOM	2011-07-05 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7956	\N	2017-09-24 13:29:42
9788	MEMBRECOM	2011-10-01 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8223	\N	2014-09-29 09:08:32
9819	VICPDTCOM	2011-10-01 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4276	\N	\N
9821	VICPDTCOM	2011-10-01 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2558	\N	\N
9822	VICPDTCOM	2011-10-01 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6899	\N	\N
9823	VICPDTCOM	2011-10-01 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3674	\N	\N
9824	VICPDTCOM	2011-10-01 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4300	\N	\N
9827	SECRETCOM	2011-10-01 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2965	\N	\N
9828	SECRETCOM	2011-10-01 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	384	\N	\N
9830	VICPDTCOM	2011-10-01 00:00:00	2014-09-30 00:00:00	1	ANCIEN	\N	\N	\N	\N	4293	\N	2014-09-28 13:40:33
9832	VICPDTCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	4	ANCIEN	\N	\N	\N	\N	669	\N	2014-10-08 17:46:29
9834	VICPDTCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	6	ANCIEN	\N	\N	\N	\N	3892	\N	2014-10-08 17:46:53
9839	VICPDTCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	10	ANCIEN	\N	\N	\N	\N	7432	\N	2014-10-08 17:46:43
9841	SECRETCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	1	ANCIEN	\N	\N	\N	\N	4291	\N	2014-10-08 16:52:42
9844	SECRETCOM	2011-10-01 00:00:00	2014-09-30 00:00:00	4	ANCIEN	\N	\N	\N	\N	4292	\N	2014-09-28 17:34:16
9877	VICPDTCOM	2011-10-01 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4752	\N	2014-09-28 17:31:42
9888	MEMBRECOM	2011-10-20 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8265	\N	\N
9889	MEMBRECOM	2011-10-20 00:00:00	2013-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8266	\N	\N
9890	MEMBRECOM	2011-10-20 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8267	\N	\N
9892	MEMBRECOM	2011-10-20 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8269	\N	\N
9893	MEMBRECOM	2011-10-20 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8270	\N	2014-09-28 18:03:38
9911	MEMBRECOM	2011-11-02 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8285	\N	2017-09-24 18:17:56
9912	MEMBRECOM	2011-11-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8286	\N	\N
9914	MEMBRECOM	2011-11-02 00:00:00	2019-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8288	\N	\N
9916	MEMBRECOM	2011-11-02 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8290	\N	2014-09-28 17:40:23
9918	MEMBRECOM	2011-11-02 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8292	\N	2017-09-24 17:09:24
9919	MEMBRECOM	2011-11-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8293	\N	\N
9921	MEMBRECOM	2011-11-02 00:00:00	2017-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8295	\N	2017-06-19 12:20:59
9922	MEMBRECOM	2011-11-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8296	\N	\N
9993	PDTCOM	2011-12-06 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8327	\N	2014-11-19 17:52:46
9995	VICPDTCOM	2011-12-06 00:00:00	2014-09-30 00:00:00	2	ANCIEN	\N	\N	\N	\N	8339	\N	2014-11-19 17:50:38
9996	VICPDTCOM	2011-12-06 00:00:00	2013-04-23 00:00:00	3	ANCIEN	\N	\N	\N	\N	8347	\N	2013-04-24 10:56:26
9999	VICPDTCOM	2011-12-06 00:00:00	2014-09-30 00:00:00	5	ANCIEN	\N	\N	\N	\N	8334	\N	2014-11-19 17:50:38
10000	VICPDTCOM	2011-12-06 00:00:00	2014-09-30 00:00:00	6	ANCIEN	\N	\N	\N	\N	8341	\N	2014-09-28 16:42:05
10001	VICPDTCOM	2011-12-06 00:00:00	2014-09-30 00:00:00	7	ANCIEN	\N	\N	\N	\N	8358	\N	2014-11-19 17:50:38
10002	VICPDTCOM	2011-12-06 00:00:00	2014-09-30 00:00:00	8	ANCIEN	\N	\N	\N	\N	8340	\N	2014-09-28 17:07:41
10003	VICPDTCOM	2011-12-06 00:00:00	2012-09-19 00:00:00	9	ANCIEN	\N	\N	\N	\N	8329	\N	\N
10004	VICPDTCOM	2011-12-06 00:00:00	2012-07-21 00:00:00	10	ANCIEN	\N	\N	\N	\N	8342	\N	\N
10005	SECRETCOM	2011-12-06 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8330	\N	2014-11-19 17:50:38
10007	SECRETCOM	2011-12-06 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8344	\N	2014-09-28 13:16:32
10058	PDTCOM	2011-12-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8412	\N	\N
10065	MEMBRECOM	2011-12-21 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8419	\N	\N
10142	MEMBRECOM	2012-01-25 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8500	\N	\N
10143	MEMBRECOM	2012-01-25 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8501	\N	\N
10144	MEMBRECOM	2012-01-25 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8502	\N	2014-09-28 17:03:42
10168	MEMBRECOM	2012-01-26 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8526	\N	2014-09-28 19:07:43
10169	MEMBRECOM	2012-01-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8527	\N	\N
10170	MEMBRECOM	2012-01-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8528	\N	\N
10171	MEMBRECOM	2012-01-26 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8529	\N	2014-09-28 17:12:41
10172	MEMBRECOM	2012-01-26 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8530	\N	2014-09-28 16:40:50
10326	MEMBRECOM	2012-02-20 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8679	\N	2013-12-16 10:13:19
9270	PDTCOM	2008-10-08 00:00:00	2010-03-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7767	\N	\N
9274	MEMBRECOM	2011-04-27 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7771	\N	2017-09-24 13:29:42
9275	MEMBRECOM	2011-04-27 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7772	\N	\N
9276	MEMBRECOM	2011-04-27 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7773	\N	\N
9279	MEMBRECOM	2011-04-27 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7776	\N	\N
9281	MEMBRECOM	2011-04-27 00:00:00	2012-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7778	\N	\N
9309	MEMBRECOM	2011-06-14 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7806	\N	2014-09-28 12:56:42
9310	MEMBRECOM	2011-06-14 00:00:00	2018-12-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7807	\N	\N
9385	VICPDTCOM	2011-06-27 00:00:00	2014-07-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7873	\N	2014-07-01 09:25:11
9386	RAPCOM	2011-06-27 00:00:00	2015-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7874	\N	2015-01-08 17:14:28
9387	MEMBRECOM	2011-06-27 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7875	\N	\N
9401	MEMBRECOM	2011-06-29 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7889	\N	\N
9413	VICPDTCOM	2011-06-30 00:00:00	2015-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7901	\N	2015-10-12 09:39:30
9427	VICPDTCOM	2011-07-01 00:00:00	2015-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7915	\N	2015-10-12 09:39:30
9430	MEMBRECOM	2011-07-01 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7918	\N	\N
9431	MEMBRECOM	2011-07-01 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7919	\N	2014-09-29 09:08:32
9432	MEMBRECOM	2011-07-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7920	\N	\N
9434	MEMBRECOM	2011-07-01 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7922	\N	\N
9435	MEMBRECOM	2011-07-01 00:00:00	2012-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7923	\N	\N
9436	MEMBRECOM	2011-07-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7924	\N	\N
9437	MEMBRECOM	2011-07-01 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7925	\N	2014-09-28 13:21:47
9438	MEMBRECOM	2011-07-01 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7926	\N	\N
9439	MEMBRECOM	2011-07-01 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7927	\N	\N
9440	MEMBRECOM	2011-07-01 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7928	\N	2017-09-24 13:29:42
9445	MEMBRECOM	2011-07-01 00:00:00	2014-09-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7933	\N	2014-09-01 10:21:13
9446	MEMBRECOM	2011-07-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7934	\N	\N
9447	MEMBRECOM	2011-07-01 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7935	\N	2014-09-28 17:07:41
9448	MEMBRECOM	2011-07-01 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7936	\N	2017-09-24 17:35:15
9451	MEMBRECOM	2011-07-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7939	\N	\N
9452	MEMBRECOM	2011-07-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7940	\N	\N
9483	VICPDTCOM	2011-07-08 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7971	\N	2014-09-28 17:07:41
9484	RAPCOM	2011-07-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7972	\N	\N
9485	MEMBRECOM	2011-07-08 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7973	\N	\N
9486	MEMBRECOM	2011-07-08 00:00:00	2013-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7974	\N	\N
9487	MEMBRECOM	2011-07-08 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7975	\N	\N
9488	MEMBRECOM	2011-07-08 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7976	\N	2014-09-28 17:07:41
9489	MEMBRECOM	2011-07-08 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7977	\N	2014-09-28 17:34:16
9790	MEMBRECOM	2011-10-01 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8225	\N	\N
9793	VICPDTCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3944	\N	2014-10-08 17:48:53
9794	VICPDTCOM	2011-10-01 00:00:00	2012-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	734	\N	\N
9795	VICPDTCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	409	\N	2014-10-08 17:49:02
9797	VICPDTCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4275	\N	2014-10-08 17:49:08
9798	VICPDTCOM	2011-10-01 00:00:00	2014-09-30 00:00:00	1	ANCIEN	\N	\N	\N	\N	4282	\N	2014-09-28 17:34:16
9804	VICPDTCOM	2011-10-01 00:00:00	2012-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4242	\N	\N
9805	MEMBRECOM	2011-10-01 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2585	\N	2014-09-28 18:19:47
9802	MEMBRECOM	2011-10-01 00:00:00	2012-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8229	\N	\N
9850	SECRETCOM	2011-10-01 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8234	\N	2014-10-09 15:54:49
9810	SECRETCOM	2011-10-01 00:00:00	2011-11-01 00:00:00	3	ANCIEN	\N	\N	\N	\N	290	\N	\N
9809	SECRETCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	1	ANCIEN	\N	\N	\N	\N	514	\N	2014-10-08 17:50:59
9811	SECRETCOM	2011-10-01 00:00:00	2013-07-16 00:00:00	4	ANCIEN	\N	\N	\N	\N	7399	\N	2013-07-19 11:47:53
9812	SECRETCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	5	ANCIEN	\N	\N	\N	\N	3694	\N	2014-10-08 17:43:55
9813	RAPGENCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4277	\N	2014-10-08 17:50:41
9814	VICPDTCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4247	\N	2014-10-08 17:51:37
9816	VICPDTCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2631	\N	2014-10-08 17:51:53
9818	SECRETCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	788	\N	2014-10-08 17:52:00
9820	SECRETCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4251	\N	2014-10-08 17:52:08
9825	MEMBRECOM	2010-10-07 00:00:00	2010-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8230	\N	\N
9826	VICPDTCOM	2011-10-01 00:00:00	2013-06-27 00:00:00	7	ANCIEN	\N	\N	\N	\N	8230	\N	\N
9836	VICPDTCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	8	ANCIEN	\N	\N	\N	\N	4318	\N	2014-10-08 17:52:47
9838	VICPDTCOM	2011-10-01 00:00:00	2014-09-30 00:00:00	10	ANCIEN	\N	\N	\N	\N	231	\N	2014-09-28 16:59:41
9848	MEMBRECOM	2011-10-01 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8232	\N	2014-09-28 12:09:44
9851	MEMBRECOM	2011-10-01 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6283	\N	2014-09-28 12:21:28
9852	VICPDTCOM	2011-10-01 00:00:00	2011-12-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8235	\N	\N
9266	MEMBRECOM	2011-03-31 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7763	\N	\N
9267	MEMBRECOM	2011-03-31 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7764	\N	\N
9417	MEMBRECOM	2011-06-30 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7905	\N	2014-09-29 09:08:32
9415	MEMBRECOM	2011-06-30 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7903	\N	\N
9416	MEMBRECOM	2011-06-30 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7904	\N	\N
9419	MEMBRECOM	2011-06-30 00:00:00	2012-09-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7907	\N	\N
9420	MEMBRECOM	2011-06-30 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7908	\N	\N
9421	MEMBRECOM	2011-06-30 00:00:00	2012-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7909	\N	\N
9457	MEMBRECOM	2011-07-05 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7945	\N	2014-09-28 18:00:58
9459	MEMBRECOM	2011-07-05 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7947	\N	2017-10-01 10:17:18
9460	MEMBRECOM	2011-07-05 00:00:00	2012-09-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7948	\N	\N
9461	MEMBRECOM	2011-07-05 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7949	\N	2014-09-28 17:34:16
9462	MEMBRECOM	2011-07-05 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7950	\N	\N
9684	MEMBRECOM	2011-10-01 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8174	\N	2014-09-28 12:54:15
9690	MEMBRECOM	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8179	\N	2014-10-08 16:42:43
9691	VICPDTCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2553	\N	2014-10-08 17:51:45
9692	MEMBRECOM	2011-10-01 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	257	\N	\N
9853	VICPDTCOM	2011-10-01 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6420	\N	2014-10-09 09:37:38
9854	VICPDTCOM	2011-10-01 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4408	\N	2014-10-09 09:37:47
9855	MEMBRECOM	2011-10-01 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8236	\N	2017-10-05 11:42:54
9856	VICPDTCOM	2011-10-01 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6416	\N	2014-09-28 12:44:31
9857	MEMBRECOM	2011-10-01 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8239	\N	2014-10-09 15:39:54
9859	MEMBRECOM	2011-10-01 00:00:00	2014-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8241	\N	2014-10-13 11:49:26
9861	MEMBRECOM	2011-10-01 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8243	\N	2017-10-05 11:42:56
9862	SECRETCOM	2011-10-01 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8244	\N	2014-10-09 09:37:55
9863	MEMBRECOM	2011-10-01 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8245	\N	2014-10-09 15:40:13
9866	VICPDTCOM	2011-10-01 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8248	\N	2014-10-09 15:56:33
9867	MEMBRECOM	2011-10-01 00:00:00	2013-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8249	\N	\N
9868	MEMBRECOM	2011-10-01 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8250	\N	2014-10-09 15:40:35
9870	VICPDTCOM	2011-10-01 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8251	\N	2014-10-09 15:57:24
9871	VICPDTCOM	2011-10-01 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8252	\N	2014-10-09 09:37:52
9872	MEMBRECOM	2011-10-01 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8253	\N	2014-09-28 16:50:17
9875	PDTCOM	2011-10-01 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4433	\N	2014-10-09 09:37:34
9170	MEMBRECOM	2011-02-02 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7672	\N	\N
10029	RAPCOM	2011-12-19 00:00:00	2012-05-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8383	\N	\N
8708	MEMBRECOM	2010-04-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7236	\N	2014-10-08 17:09:47
8716	MEMBRECOM	2010-03-31 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7244	\N	\N
9117	MEMBRECOM	2011-01-11 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7618	\N	\N
9118	MEMBRECOM	2011-01-11 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7619	\N	\N
9131	MEMBRECOM	2010-12-17 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7631	\N	2014-09-28 17:03:42
9134	MEMBRECOM	2011-01-13 00:00:00	2011-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7634	\N	\N
9400	RAPCOM	2011-06-29 00:00:00	2014-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7888	\N	2014-09-29 13:41:53
9467	MEMBRECOM	2011-07-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7955	\N	\N
9906	MEMBRECOM	2011-11-02 00:00:00	2017-09-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8280	\N	2017-09-24 11:09:53
9907	MEMBRECOM	2011-11-02 00:00:00	2017-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8281	\N	2017-01-19 10:36:24
9908	MEMBRECOM	2011-11-02 00:00:00	2012-06-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8282	\N	\N
9953	MEMBRECOM	2011-11-30 00:00:00	2011-12-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8327	\N	\N
9954	MEMBRECOM	2011-11-30 00:00:00	2011-12-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8328	\N	\N
9955	MEMBRECOM	2011-11-30 00:00:00	2011-12-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8330	\N	\N
9956	MEMBRECOM	2011-11-30 00:00:00	2011-12-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8331	\N	\N
9957	MEMBRECOM	2011-11-30 00:00:00	2011-12-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8332	\N	\N
9958	MEMBRECOM	2011-11-30 00:00:00	2011-12-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8334	\N	\N
9959	MEMBRECOM	2011-11-30 00:00:00	2012-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8335	\N	\N
9960	MEMBRECOM	2011-11-30 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8336	\N	2014-11-19 17:50:38
9961	MEMBRECOM	2011-11-30 00:00:00	2011-12-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8339	\N	\N
9962	MEMBRECOM	2011-11-30 00:00:00	2011-12-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8340	\N	\N
9963	MEMBRECOM	2011-11-30 00:00:00	2011-12-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8341	\N	\N
9964	MEMBRECOM	2011-11-30 00:00:00	2011-12-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8342	\N	\N
9965	MEMBRECOM	2011-11-30 00:00:00	2011-12-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8344	\N	\N
9966	MEMBRECOM	2011-11-30 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8345	\N	2014-09-28 18:00:58
9967	MEMBRECOM	2011-11-30 00:00:00	2011-12-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8347	\N	\N
9968	MEMBRECOM	2011-11-30 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8348	\N	2014-09-28 17:40:23
9969	MEMBRECOM	2011-11-30 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8349	\N	2014-11-19 17:50:38
9970	MEMBRECOM	2011-11-30 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8350	\N	2014-09-28 17:22:11
9973	MEMBRECOM	2011-11-30 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8354	\N	2014-11-19 17:50:38
9974	MEMBRECOM	2011-11-30 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8355	\N	2014-11-19 17:50:38
9975	MEMBRECOM	2011-11-30 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8356	\N	2014-11-19 17:50:38
9976	MEMBRECOM	2011-11-30 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8357	\N	2014-09-28 13:40:33
9977	MEMBRECOM	2011-11-30 00:00:00	2012-12-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8359	\N	\N
9978	MEMBRECOM	2011-11-30 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8360	\N	2014-09-28 13:21:47
9979	MEMBRECOM	2011-11-30 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8361	\N	2014-11-19 17:50:38
9981	MEMBRECOM	2011-11-30 00:00:00	2014-05-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8363	\N	2014-05-12 09:52:22
9982	MEMBRECOM	2011-11-30 00:00:00	2013-01-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8364	\N	\N
9829	VICPDTCOM	2011-10-01 00:00:00	2012-06-19 00:00:00	2	ANCIEN	\N	\N	\N	\N	4284	\N	\N
9831	VICPDTCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	2	ANCIEN	\N	\N	\N	\N	2540	\N	2014-10-08 17:52:31
9833	VICPDTCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	4	ANCIEN	\N	\N	\N	\N	262	\N	2014-10-08 17:52:51
9835	VICPDTCOM	2011-10-01 00:00:00	2012-06-19 00:00:00	7	ANCIEN	\N	\N	\N	\N	133	\N	\N
10146	RAPCOM	2012-01-25 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8504	\N	2017-09-24 17:47:27
10147	MEMBRECOM	2012-01-25 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8505	\N	2017-09-24 17:15:15
10148	MEMBRECOM	2012-01-25 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8506	\N	2017-09-24 18:16:52
10149	MEMBRECOM	2012-01-25 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8507	\N	2017-09-24 18:17:56
10151	MEMBRECOM	2012-01-25 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8509	\N	\N
10152	MEMBRECOM	2012-01-25 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8510	\N	\N
10153	MEMBRECOM	2012-01-25 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8511	\N	\N
10154	MEMBRECOM	2012-01-25 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8512	\N	\N
10155	MEMBRECOM	2012-01-25 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8513	\N	\N
10156	MEMBRECOM	2012-01-25 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8514	\N	2017-09-24 13:14:55
10158	MEMBRECOM	2012-01-25 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8516	\N	2014-09-28 17:27:35
10160	RAPCOM	2012-01-26 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8518	\N	2017-09-24 17:14:26
10162	MEMBRECOM	2012-01-26 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8520	\N	2014-09-28 17:38:26
10163	MEMBRECOM	2012-01-26 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8521	\N	2017-10-01 10:01:39
10164	MEMBRECOM	2012-01-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8522	\N	\N
10165	MEMBRECOM	2012-01-26 00:00:00	2019-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8523	\N	\N
10166	MEMBRECOM	2012-01-26 00:00:00	2020-06-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8524	\N	\N
10191	VICPDTCOM	2012-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8544	\N	\N
10192	RAPCOM	2012-02-08 00:00:00	2012-09-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8545	\N	\N
10194	MEMBRECOM	2012-02-08 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8547	\N	2014-09-28 13:40:33
10195	MEMBRECOM	2012-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8548	\N	\N
10196	MEMBRECOM	2012-02-08 00:00:00	2015-04-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8549	\N	2015-04-21 17:14:30
10197	MEMBRECOM	2012-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8550	\N	\N
10198	MEMBRECOM	2012-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8551	\N	\N
10199	MEMBRECOM	2012-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8552	\N	\N
10201	MEMBRECOM	2012-02-08 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8554	\N	2014-09-28 17:34:16
9414	RAPCOM	2011-06-30 00:00:00	2014-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7902	\N	2014-09-29 13:41:53
9454	MEMBRECOM	2011-07-01 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7942	\N	2014-09-28 17:38:26
9490	MEMBRECOM	2011-07-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7978	\N	2017-09-24 13:44:49
9492	MEMBRECOM	2011-07-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7980	\N	\N
9493	MEMBRECOM	2011-07-08 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7981	\N	\N
9494	MEMBRECOM	2011-07-08 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7982	\N	2014-09-28 17:38:26
9902	SECRETCOM	2011-10-26 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7842	\N	\N
9903	VICPDTCOM	2011-10-26 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8274	\N	\N
9904	SECRETCOM	2011-10-26 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8278	\N	\N
9905	PDTCOM	2011-10-26 00:00:00	2012-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8275	\N	\N
10182	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8534	\N	\N
10183	MEMBRECOM	2012-02-15 00:00:00	2012-02-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8536	\N	\N
10184	MEMBRECOM	2012-02-15 00:00:00	2013-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8537	\N	\N
10185	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8538	\N	2013-12-16 10:13:19
10203	MEMBRECOM	2012-02-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8556	\N	2017-09-24 18:17:56
10187	MEMBRECOM	2012-02-15 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8540	\N	\N
10202	MEMBRECOM	2012-02-08 00:00:00	2017-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8555	\N	2017-06-19 12:20:59
10205	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8558	\N	\N
10206	MEMBRECOM	2012-02-15 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8559	\N	\N
10207	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8560	\N	\N
10208	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8563	\N	\N
10209	MEMBRECOM	2012-02-15 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8564	\N	\N
10211	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8566	\N	\N
10212	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8567	\N	\N
10213	MEMBRECOM	2012-02-15 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8568	\N	\N
10214	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8569	\N	\N
10215	MEMBRECOM	2012-02-15 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8570	\N	\N
10216	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8571	\N	\N
10217	MEMBRECOM	2012-02-15 00:00:00	2012-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8572	\N	\N
10218	MEMBRECOM	2012-02-15 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8573	\N	\N
10220	MEMBRECOM	2012-02-15 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8575	\N	\N
10222	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8577	\N	\N
10188	MEMBRECOM	2012-02-15 00:00:00	2012-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8541	\N	\N
10189	MEMBRECOM	2012-02-15 00:00:00	2012-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8542	\N	\N
10190	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8543	\N	\N
10223	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8578	\N	\N
10224	MEMBRECOM	2012-02-15 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8579	\N	\N
10226	MEMBRECOM	2012-02-15 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8581	\N	\N
10227	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8582	\N	\N
10228	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8583	\N	\N
10229	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8584	\N	\N
10230	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8585	\N	\N
10232	MEMBRECOM	2012-02-15 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8588	\N	\N
10233	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8589	\N	\N
10234	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8590	\N	\N
10235	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8591	\N	\N
10236	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8592	\N	\N
10237	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8593	\N	\N
10238	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8594	\N	\N
10239	MEMBRECOM	2012-02-15 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8595	\N	\N
10241	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8597	\N	\N
10244	MEMBRECOM	2012-02-15 00:00:00	2013-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8601	\N	\N
10245	MEMBRECOM	2012-02-15 00:00:00	2013-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8602	\N	\N
10246	MEMBRECOM	2012-02-15 00:00:00	2013-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8603	\N	\N
10247	MEMBRECOM	2012-02-15 00:00:00	2013-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8604	\N	\N
10248	MEMBRECOM	2012-02-15 00:00:00	2013-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8605	\N	\N
10249	MEMBRECOM	2012-02-15 00:00:00	2013-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8606	\N	\N
10250	MEMBRECOM	2012-02-15 00:00:00	2012-02-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8607	\N	\N
10251	MEMBRECOM	2012-02-15 00:00:00	2013-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8608	\N	\N
10252	MEMBRECOM	2012-02-15 00:00:00	2013-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8609	\N	\N
10253	MEMBRECOM	2012-02-15 00:00:00	2012-02-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8610	\N	\N
10255	MEMBRECOM	2012-02-15 00:00:00	2013-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8612	\N	\N
10256	MEMBRECOM	2012-02-15 00:00:00	2013-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8613	\N	\N
10257	MEMBRECOM	2012-02-15 00:00:00	2013-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8614	\N	\N
10258	MEMBRECOM	2012-02-15 00:00:00	2013-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8615	\N	\N
9499	MEMBRECOM	2011-10-01 00:00:00	2011-11-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7987	\N	\N
9500	MEMBRECOM	2011-10-01 00:00:00	2011-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7988	\N	\N
9501	MEMBRECOM	2011-10-01 00:00:00	2014-05-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7989	\N	2014-05-07 12:21:27
9503	MEMBRECOM	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7991	\N	2014-10-08 17:08:19
9504	MEMBRECOM	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7992	\N	2017-09-25 10:56:48
9505	MEMBRECOM	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7993	\N	2017-09-24 17:09:24
9506	MEMBRECOM	2011-10-01 00:00:00	2014-01-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7994	\N	2014-01-07 10:45:43
9507	MEMBRECOM	2011-10-01 00:00:00	2014-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7995	\N	2014-07-22 12:08:05
9683	MEMBRECOM	2011-10-01 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8173	\N	\N
9086	MEMBRECOM	2011-01-11 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7587	\N	\N
10064	MEMBRECOM	2011-12-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8418	\N	\N
10150	MEMBRECOM	2012-01-25 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8508	\N	\N
10259	MEMBRECOM	2012-02-15 00:00:00	2012-02-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8616	\N	\N
10293	MEMBRECOM	2012-02-15 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8652	\N	\N
10294	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8653	\N	2013-12-16 10:13:19
10295	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8654	\N	2013-12-16 10:13:19
10296	MEMBRECOM	2012-02-15 00:00:00	2012-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8655	\N	\N
10297	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8656	\N	2013-12-16 10:13:19
10298	MEMBRECOM	2012-02-15 00:00:00	2012-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8657	\N	\N
10299	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8658	\N	2013-12-16 10:13:19
10300	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8659	\N	2013-12-16 10:13:19
10301	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8660	\N	2013-12-16 10:13:19
10302	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8661	\N	2013-12-16 10:13:19
10303	MEMBRECOM	2012-02-15 00:00:00	2012-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8662	\N	\N
10304	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8663	\N	2013-12-16 10:13:19
10305	MEMBRECOM	2012-02-15 00:00:00	2012-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8664	\N	\N
10306	MEMBRECOM	2012-02-15 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8665	\N	\N
10307	MEMBRECOM	2012-02-15 00:00:00	2012-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8666	\N	\N
10308	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8667	\N	\N
10310	MEMBRECOM	2012-02-15 00:00:00	2013-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8669	\N	\N
10311	MEMBRECOM	2012-02-15 00:00:00	2012-02-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8670	\N	\N
10312	MEMBRECOM	2012-02-15 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8671	\N	\N
10314	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8673	\N	\N
10315	MEMBRECOM	2012-02-15 00:00:00	2012-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8674	\N	\N
10174	PDTCOM	2012-02-07 00:00:00	2012-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8472	\N	2013-12-16 10:26:49
10175	RAPCOM	2012-02-07 00:00:00	2012-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8484	\N	2013-12-16 10:26:49
10176	VICPDTCOM	2012-02-07 00:00:00	2012-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8468	\N	2013-12-16 10:26:49
10177	VICPDTCOM	2012-02-07 00:00:00	2012-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8479	\N	2013-12-16 10:26:49
10178	VICPDTCOM	2012-02-07 00:00:00	2012-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8486	\N	2013-12-16 10:26:49
10179	VICPDTCOM	2012-02-07 00:00:00	2012-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8488	\N	2013-12-16 10:26:49
10316	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8675	\N	2013-12-16 10:13:19
10318	MEMBRECOM	2012-02-15 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8535	\N	\N
10319	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8561	\N	\N
10320	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8562	\N	\N
10322	MEMBRECOM	2012-02-15 00:00:00	2012-02-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8600	\N	\N
10323	MEMBRECOM	2012-02-15 00:00:00	2012-02-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8620	\N	\N
10324	MEMBRECOM	2012-02-15 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8586	\N	\N
10325	MEMBRECOM	2012-02-15 00:00:00	2012-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8626	\N	\N
10328	MEMBRECOM	2012-02-20 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8681	\N	\N
10329	MEMBRECOM	2012-02-20 00:00:00	2014-05-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8682	\N	2014-05-12 09:51:40
10334	MEMBRECOM	2012-02-21 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8687	\N	2014-09-28 12:56:42
10335	SECRETCOM	2012-02-21 00:00:00	2012-07-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8688	\N	\N
10337	VICPDTCOM	2012-02-21 00:00:00	2014-10-07 00:00:00	2	ANCIEN	\N	\N	\N	\N	8689	\N	2014-10-08 17:48:14
10338	MEMBRECOM	2012-02-21 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8691	\N	2014-09-28 12:44:31
10340	MEMBRECOM	2012-02-21 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8692	\N	2017-10-05 14:29:44
10344	VICPDTCOM	2012-02-21 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8696	\N	2014-10-08 17:48:19
10347	MEMBRECOM	2012-02-21 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8700	\N	2014-10-08 17:05:35
10351	MEMBRECOM	2012-02-21 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8704	\N	2014-09-28 19:03:23
10352	MEMBRECOM	2012-02-21 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8705	\N	2014-10-08 17:00:38
10353	VICPDTCOM	2012-02-21 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8706	\N	2014-09-28 17:40:23
10355	MEMBRECOM	2012-02-21 00:00:00	2016-11-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8708	\N	2016-12-01 10:36:51
10357	VICPDTCOM	2012-02-21 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8710	\N	2014-10-08 17:48:37
10359	VICPDTCOM	2012-02-21 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8712	\N	2014-10-08 17:48:28
9255	VICPDTCOM	2011-03-31 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7752	\N	2017-09-24 18:16:52
9256	RAPCOM	2011-03-31 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7753	\N	\N
9257	MEMBRECOM	2011-03-31 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7754	\N	\N
9258	MEMBRECOM	2011-03-31 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7755	\N	\N
9259	MEMBRECOM	2011-03-31 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7756	\N	\N
9260	MEMBRECOM	2011-03-31 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7757	\N	\N
9311	MEMBRECOM	2011-06-14 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7808	\N	\N
9363	RAPCOM	2011-06-28 00:00:00	2015-04-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7860	\N	2015-04-21 17:14:30
9364	MEMBRECOM	2011-06-28 00:00:00	2019-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7861	\N	\N
9372	MEMBRECOM	2011-06-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	7869	\N	\N
9373	MEMBRECOM	2011-06-28 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7870	\N	2014-09-28 17:34:16
9374	MEMBRECOM	2011-06-28 00:00:00	2017-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7871	\N	2017-06-19 12:20:59
9375	MEMBRECOM	2011-06-28 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7872	\N	\N
10068	MEMBRECOM	2011-12-21 00:00:00	2015-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8422	\N	2015-10-13 14:23:51
10012	SECRETCOM	2011-12-08 00:00:00	2014-05-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8172	\N	2014-05-05 14:50:38
10014	RAPCOM	2011-12-08 00:00:00	2012-05-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8368	\N	\N
10015	MEMBRECOM	2011-12-08 00:00:00	2017-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8369	\N	2017-09-25 09:56:00
10016	MEMBRECOM	2011-12-08 00:00:00	2014-12-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8370	\N	2014-12-18 16:15:04
10017	MEMBRECOM	2011-12-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8371	\N	\N
10018	MEMBRECOM	2011-12-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8372	\N	\N
10020	MEMBRECOM	2011-12-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8374	\N	\N
10021	MEMBRECOM	2011-12-08 00:00:00	2016-03-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8375	\N	2016-03-11 18:02:50
10022	MEMBRECOM	2011-12-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8376	\N	2017-09-24 17:47:28
10024	MEMBRECOM	2011-12-08 00:00:00	2021-07-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8378	\N	\N
10066	MEMBRECOM	2011-12-21 00:00:00	2015-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8420	\N	2015-06-12 16:01:25
10026	MEMBRECOM	2011-12-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8380	\N	\N
10069	MEMBRECOM	2011-12-21 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8423	\N	2014-09-28 13:40:33
10070	MEMBRECOM	2011-12-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8424	\N	\N
10071	MEMBRECOM	2011-12-21 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8425	\N	2017-09-24 13:29:42
10072	PDTCOM	2012-12-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8426	\N	\N
10073	MEMBRECOM	2012-12-21 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8427	\N	2014-09-28 17:34:16
10074	RAPCOM	2012-12-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8428	\N	\N
10075	MEMBRECOM	2012-12-21 00:00:00	2012-09-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8429	\N	\N
10008	VICPDTCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	412	\N	2014-10-08 17:49:12
10010	VICPDTCOM	2011-10-01 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4303	\N	2014-09-28 12:32:23
10076	MEMBRECOM	2012-12-21 00:00:00	2019-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8430	\N	\N
10260	MEMBRECOM	2012-02-15 00:00:00	2013-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8617	\N	\N
10262	MEMBRECOM	2012-02-15 00:00:00	2013-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8619	\N	\N
10263	MEMBRECOM	2012-02-15 00:00:00	2012-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8621	\N	\N
10264	MEMBRECOM	2012-02-15 00:00:00	2012-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8622	\N	\N
10265	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8623	\N	\N
10266	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8624	\N	\N
10267	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8625	\N	\N
10268	MEMBRECOM	2012-02-15 00:00:00	2012-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8627	\N	\N
10269	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8628	\N	\N
10270	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8629	\N	\N
10271	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8630	\N	\N
10272	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8631	\N	\N
10273	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8632	\N	\N
10274	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8633	\N	\N
10275	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8634	\N	\N
10278	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8637	\N	\N
10279	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8638	\N	\N
10280	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8639	\N	\N
10281	MEMBRECOM	2012-02-15 00:00:00	2012-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8640	\N	\N
10282	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8641	\N	\N
11082	RAPCOM	2013-05-14 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9326	\N	2014-04-14 14:28:41
11083	PDTCOM	2013-05-14 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9341	\N	2014-04-14 14:28:41
11192	MEMBRECOM	2013-05-16 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9436	\N	2017-09-24 13:29:42
11193	PDTCOM	2013-06-05 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9437	\N	2014-09-28 19:07:43
11195	MEMBRECOM	2013-06-05 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9439	\N	\N
11196	MEMBRECOM	2013-06-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9440	\N	\N
11198	MEMBRECOM	2013-06-05 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9442	\N	2014-09-28 17:31:42
11200	MEMBRECOM	2013-06-05 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9444	\N	2014-09-28 17:31:42
11201	MEMBRECOM	2013-06-05 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9445	\N	2017-09-24 17:06:55
11202	MEMBRECOM	2013-06-05 00:00:00	2014-05-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9446	\N	2014-05-12 09:52:22
11205	MEMBRECOM	2013-06-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9449	\N	\N
11206	MEMBRECOM	2013-06-05 00:00:00	2019-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9450	\N	\N
11207	PDTCOM	2013-06-21 00:00:00	2017-07-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9451	\N	2017-07-04 15:08:09
11208	RAPCOM	2013-06-21 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9452	\N	2017-09-24 17:15:15
11209	MEMBRECOM	2013-06-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9453	\N	\N
11210	MEMBRECOM	2013-06-21 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9454	\N	\N
11211	MEMBRECOM	2013-06-21 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9455	\N	2017-09-24 18:16:52
11212	MEMBRECOM	2013-06-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9456	\N	\N
11213	MEMBRECOM	2013-06-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9457	\N	\N
11214	MEMBRECOM	2013-06-21 00:00:00	2018-08-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9458	\N	\N
11215	MEMBRECOM	2013-06-21 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9459	\N	2014-09-28 16:42:05
11217	MEMBRECOM	2013-06-21 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9461	\N	\N
11218	MEMBRECOM	2013-06-21 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9462	\N	2014-09-28 17:07:07
11219	MEMBRECOM	2013-06-21 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9463	\N	\N
11220	MEMBRECOM	2013-06-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9464	\N	\N
11221	MEMBRECOM	2013-10-09 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9465	2013-10-09 16:53:40	2014-09-28 18:00:58
11222	VICPDTCOM	2013-07-04 00:00:00	2015-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9466	\N	2015-01-08 17:14:29
11224	MEMBRECOM	2013-07-04 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9468	\N	2017-09-24 17:47:28
11225	MEMBRECOM	2013-07-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9469	\N	\N
11226	MEMBRECOM	2013-07-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9470	\N	\N
11227	MEMBRECOM	2013-07-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9471	\N	\N
11228	MEMBRECOM	2013-07-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9472	\N	\N
11229	MEMBRECOM	2013-07-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9473	\N	\N
11230	MEMBRECOM	2013-07-04 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9474	\N	2017-09-24 18:20:10
11233	MEMBRECOM	2013-07-04 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9477	\N	2017-09-24 17:15:15
11234	MEMBRECOM	2013-07-04 00:00:00	2021-07-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9478	\N	\N
11235	MEMBRECOM	2013-07-04 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9479	\N	2014-09-28 18:03:38
11236	PDTCOM	2013-07-12 00:00:00	2015-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9480	\N	2015-01-08 17:14:29
11237	RAPCOM	2013-07-12 00:00:00	2017-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9481	\N	2017-09-25 09:56:00
11238	MEMBRECOM	2013-07-12 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9482	\N	2017-09-24 18:20:10
11239	MEMBRECOM	2013-07-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9483	\N	\N
11242	MEMBRECOM	2013-07-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9486	\N	\N
11243	MEMBRECOM	2013-07-12 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9487	\N	\N
11244	MEMBRECOM	2013-07-12 00:00:00	2021-07-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9488	\N	\N
11245	MEMBRECOM	2013-07-12 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9489	\N	2017-09-24 17:28:55
11247	MEMBRECOM	2013-07-12 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9491	\N	2017-09-24 13:47:46
11248	MEMBRECOM	2013-07-12 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9492	\N	2014-09-28 18:03:38
11249	MEMBRECOM	2013-07-12 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9493	\N	\N
11250	PDTCOM	2013-07-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9494	\N	\N
11251	RAPCOM	2013-07-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9495	\N	\N
11253	MEMBRECOM	2013-07-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9497	\N	\N
11254	MEMBRECOM	2013-07-12 00:00:00	2015-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9498	\N	2015-10-13 14:23:01
11255	MEMBRECOM	2013-07-12 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9499	\N	2017-09-24 17:15:15
11256	MEMBRECOM	2013-07-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9500	\N	\N
11257	MEMBRECOM	2013-07-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9501	\N	\N
11258	MEMBRECOM	2013-07-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9502	\N	\N
11259	MEMBRECOM	2013-07-12 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9503	\N	\N
11260	MEMBRECOM	2013-07-12 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9504	\N	2014-09-28 18:00:58
11261	MEMBRECOM	2013-07-12 00:00:00	2017-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9505	\N	2017-07-24 09:56:26
11262	MEMBRECOM	2013-07-12 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9506	\N	2014-09-28 17:34:16
11263	MEMBRECOM	2013-07-12 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9507	\N	2014-09-28 13:40:33
11264	MEMBRECOM	2013-10-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9508	2013-10-15 18:01:18	2014-09-29 09:05:47
11265	MEMBRECOM	2013-10-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9509	2013-10-15 18:01:32	2014-11-18 15:41:31
11266	MEMBRECOM	2013-10-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9511	2013-10-15 18:01:55	2014-11-18 15:41:31
11267	MEMBRECOM	2013-10-15 00:00:00	2013-11-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9512	2013-10-15 18:02:03	2013-11-06 17:25:15
11269	MEMBRECOM	2013-10-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9514	2013-10-15 18:02:22	2014-11-18 15:41:31
11270	MEMBRECOM	2013-10-15 00:00:00	2013-11-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9515	2013-10-15 18:02:31	2013-11-06 17:25:46
11271	MEMBRECOM	2013-10-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9516	2013-10-15 18:02:40	2014-09-28 17:07:41
11272	MEMBRECOM	2013-10-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9517	2013-10-15 18:02:48	2014-11-18 15:41:31
11274	MEMBRECOM	2013-10-15 00:00:00	2013-11-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9519	2013-10-15 18:03:07	2013-11-06 17:26:09
11275	MEMBRECOM	2013-10-15 00:00:00	2013-11-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9520	2013-10-15 18:03:18	2013-11-06 17:26:31
11276	MEMBRECOM	2013-10-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9521	2013-10-15 18:03:28	2014-11-18 15:41:31
10061	MEMBRECOM	2011-12-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8415	\N	\N
11277	MEMBRECOM	2013-10-15 00:00:00	2013-11-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9522	2013-10-15 18:03:35	2013-11-06 17:26:49
11278	MEMBRECOM	2013-10-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9523	2013-10-15 18:03:44	2014-11-18 15:41:31
11280	MEMBRECOM	2013-10-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9525	2013-10-15 18:04:00	2014-11-18 15:41:31
11281	MEMBRECOM	2013-10-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9526	2013-10-15 18:04:08	2014-11-18 15:41:31
11282	MEMBRECOM	2013-10-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9527	2013-10-15 18:04:17	2014-09-28 17:38:26
11283	MEMBRECOM	2013-10-15 00:00:00	2013-11-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9528	2013-10-15 18:04:24	2013-11-06 17:27:17
11284	MEMBRECOM	2013-10-15 00:00:00	2013-11-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9529	2013-10-15 18:04:32	2013-11-06 17:27:43
11285	MEMBRECOM	2013-10-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9530	2013-10-15 18:04:40	2014-11-18 15:41:31
11286	MEMBRECOM	2013-10-15 00:00:00	2013-11-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9531	2013-10-15 18:04:48	2013-11-06 17:28:18
11288	MEMBRECOM	2013-10-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9533	2013-10-15 18:05:06	2014-09-28 17:09:16
11289	MEMBRECOM	2013-10-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9534	2013-10-15 18:05:20	2014-11-18 15:41:31
11290	MEMBRECOM	2013-10-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9535	2013-10-15 18:05:27	2014-11-18 15:41:31
11292	MEMBRECOM	2013-10-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9537	2013-10-15 18:05:48	2014-11-18 15:41:31
11293	MEMBRECOM	2013-10-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9538	2013-10-15 18:05:56	2014-11-18 15:41:31
11295	MEMBRECOM	2013-10-15 00:00:00	2013-11-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9540	2013-10-15 18:06:11	2013-11-06 17:24:49
11297	PDTCOM	2013-10-16 00:00:00	2014-05-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9389	2013-10-17 09:41:46	2014-11-18 15:42:14
11298	RAPCOM	2013-10-16 00:00:00	2014-05-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9383	2013-10-17 09:42:11	2014-11-18 15:42:14
11299	VICPDTCOM	2013-10-16 00:00:00	2014-05-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9366	2013-10-17 09:42:45	2014-11-18 15:42:14
11301	VICPDTCOM	2013-10-16 00:00:00	2014-05-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9373	2013-10-17 09:43:34	2014-11-18 15:42:14
11302	VICPDTCOM	2013-10-16 00:00:00	2014-05-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9377	2013-10-17 09:43:56	2014-11-18 15:42:14
11303	VICPDTCOM	2013-10-16 00:00:00	2014-05-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9376	2013-10-17 09:44:15	2014-11-18 15:42:14
11304	VICPDTCOM	2013-10-16 00:00:00	2014-05-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9381	2013-10-17 09:44:35	2014-11-18 15:42:14
11305	VICPDTCOM	2013-10-16 00:00:00	2014-05-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9391	2013-10-17 09:44:55	2014-11-18 15:42:14
11306	VICPDTCOM	2013-10-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9542	\N	\N
11307	RAPCOM	2013-10-03 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9543	\N	\N
11308	MEMBRECOM	2013-10-03 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9544	\N	2014-09-28 17:34:16
11309	MEMBRECOM	2013-10-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9545	\N	\N
11310	MEMBRECOM	2013-10-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9546	\N	\N
11311	MEMBRECOM	2013-10-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9547	\N	\N
11313	MEMBRECOM	2013-10-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9549	\N	\N
11314	MEMBRECOM	2013-10-03 00:00:00	2015-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9550	\N	2015-10-13 14:22:43
11315	MEMBRECOM	2013-10-03 00:00:00	2014-05-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9551	\N	2014-05-05 10:34:09
11317	MEMBRECOM	2013-10-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9553	\N	\N
11319	MEMBRECOM	2013-10-03 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9555	\N	\N
11323	MEMBRECOM	2013-10-03 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9559	\N	2014-09-28 17:34:16
11321	VICPDTCOM	2013-10-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9557	\N	\N
11322	RAPCOM	2013-10-03 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9558	\N	\N
11324	MEMBRECOM	2013-10-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9560	\N	\N
11325	MEMBRECOM	2013-10-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9561	\N	\N
11326	MEMBRECOM	2013-10-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9562	\N	\N
11328	MEMBRECOM	2013-10-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9564	\N	\N
11330	MEMBRECOM	2013-10-03 00:00:00	2014-05-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9566	\N	2014-05-05 10:34:09
11114	VICPDTCOM	2013-07-17 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7399	2013-07-19 11:47:53	2014-10-08 17:51:03
11115	SECRETCOM	2013-07-17 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8056	2013-07-19 11:52:19	2014-10-08 17:51:07
11149	MEMBRECOM	2013-10-02 00:00:00	2015-12-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9393	2013-10-03 18:08:05	2015-12-16 17:19:00
11184	MEMBRECOM	2013-05-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9428	\N	\N
11185	MEMBRECOM	2013-05-16 00:00:00	2014-04-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9429	\N	2014-04-23 09:56:25
11186	MEMBRECOM	2013-05-16 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9430	\N	\N
11332	MEMBRECOM	2013-10-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9568	\N	\N
11334	MEMBRECOM	2013-10-03 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9570	\N	\N
11335	VICPDTCOM	2013-10-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9571	\N	\N
11336	RAPCOM	2013-10-03 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9572	\N	2017-09-24 18:17:56
11337	MEMBRECOM	2013-10-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9573	\N	\N
11338	MEMBRECOM	2013-10-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9574	\N	\N
11339	MEMBRECOM	2013-10-03 00:00:00	2014-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9575	\N	2014-09-29 13:41:53
11340	MEMBRECOM	2013-10-03 00:00:00	2015-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9576	\N	2015-10-13 14:22:38
11341	MEMBRECOM	2013-10-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9577	\N	\N
11342	MEMBRECOM	2013-10-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9578	\N	\N
11343	MEMBRECOM	2013-10-03 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9579	\N	2014-09-28 17:34:16
11344	MEMBRECOM	2013-10-03 00:00:00	2014-05-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9580	\N	2014-05-05 10:34:09
11345	MEMBRECOM	2013-10-03 00:00:00	2017-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9581	\N	2017-06-19 12:20:59
11346	MEMBRECOM	2013-10-03 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9582	\N	\N
11347	MEMBRECOM	2013-10-03 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9583	\N	\N
11348	MEMBRECOM	2013-10-03 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9584	\N	2017-09-24 13:29:42
11349	VICPDTCOM	2013-10-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9585	\N	\N
11351	MEMBRECOM	2013-10-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9587	\N	\N
11352	MEMBRECOM	2013-10-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9588	\N	\N
11353	MEMBRECOM	2013-10-03 00:00:00	2014-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9589	\N	2014-09-29 13:41:53
11354	MEMBRECOM	2013-10-03 00:00:00	2015-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9590	\N	2015-10-13 14:22:52
11355	MEMBRECOM	2013-10-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9591	\N	\N
11356	MEMBRECOM	2013-10-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9592	\N	\N
11357	MEMBRECOM	2013-10-03 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9593	\N	2014-09-28 17:34:16
11358	MEMBRECOM	2013-10-03 00:00:00	2014-05-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9594	\N	2014-05-05 10:34:09
11359	MEMBRECOM	2013-10-03 00:00:00	2017-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9595	\N	2017-06-19 12:20:59
11362	MEMBRECOM	2013-10-03 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9598	\N	2017-09-24 13:29:42
11363	VICPDTCOM	2013-10-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9599	\N	\N
11364	RAPCOM	2013-10-03 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9600	\N	2017-09-24 17:15:15
11365	MEMBRECOM	2013-10-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9601	\N	\N
11366	MEMBRECOM	2013-10-03 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9602	\N	2017-09-24 18:17:56
11367	MEMBRECOM	2013-10-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9603	\N	\N
11369	MEMBRECOM	2013-10-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9605	\N	\N
11370	MEMBRECOM	2013-10-03 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9606	\N	2014-09-28 17:34:16
11371	MEMBRECOM	2013-10-03 00:00:00	2014-05-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9607	\N	2014-05-05 10:34:09
11372	MEMBRECOM	2013-10-03 00:00:00	2017-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9608	\N	2017-06-19 12:20:59
11373	MEMBRECOM	2013-10-03 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9609	\N	\N
11374	MEMBRECOM	2013-10-03 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9610	\N	\N
11376	MEMBRECOM	2013-10-03 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9612	\N	2017-09-24 13:29:42
11377	VICPDTCOM	2013-10-03 00:00:00	2017-07-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9613	\N	2017-07-04 15:08:09
11378	RAPCOM	2013-10-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9614	\N	\N
11379	MEMBRECOM	2013-10-03 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9615	\N	\N
11380	MEMBRECOM	2013-10-03 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9616	\N	\N
11381	MEMBRECOM	2013-10-03 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9617	\N	\N
11382	MEMBRECOM	2013-10-03 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9618	\N	2017-09-24 18:16:52
11383	MEMBRECOM	2013-10-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9619	\N	\N
11384	MEMBRECOM	2013-10-03 00:00:00	2018-08-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9620	\N	\N
11385	MEMBRECOM	2013-10-03 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9621	\N	2017-09-24 17:35:15
11386	MEMBRECOM	2013-10-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9622	\N	\N
11387	MEMBRECOM	2013-10-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9623	\N	\N
11388	MEMBRECOM	2013-10-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9624	\N	\N
11389	MEMBRECOM	2013-10-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9625	\N	\N
11390	MEMBRECOM	2013-10-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9626	\N	\N
11392	RAPCOM	2013-10-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9628	\N	\N
11393	MEMBRECOM	2013-10-03 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9629	\N	\N
11395	MEMBRECOM	2013-10-03 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9631	\N	\N
11396	MEMBRECOM	2013-10-03 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9632	\N	2017-09-24 18:16:52
11397	MEMBRECOM	2013-10-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9633	\N	\N
11398	MEMBRECOM	2013-10-03 00:00:00	2018-08-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9634	\N	\N
11400	MEMBRECOM	2013-10-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9636	\N	\N
11401	MEMBRECOM	2013-10-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9637	\N	\N
11402	MEMBRECOM	2013-10-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9638	\N	\N
11403	MEMBRECOM	2013-10-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9639	\N	\N
11404	MEMBRECOM	2013-10-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9640	\N	\N
11110	MEMBRECOM	2013-07-12 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9359	2013-07-12 11:35:22	2014-09-28 17:14:21
11169	MEMBRECOM	2013-04-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9413	\N	\N
11173	MEMBRECOM	2013-04-17 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9417	\N	2014-09-28 17:03:42
11176	MEMBRECOM	2013-04-17 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9420	\N	2017-09-24 19:31:54
11183	MEMBRECOM	2013-05-16 00:00:00	2015-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9427	\N	2015-10-13 14:23:05
9926	MEMBRECOM	2011-11-07 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8300	\N	2014-09-28 17:38:26
9927	MEMBRECOM	2011-11-07 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8301	\N	2017-09-24 17:47:27
9984	MEMBRECOM	2011-11-30 00:00:00	2011-12-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8329	\N	\N
9985	MEMBRECOM	2011-11-30 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8333	\N	2014-09-28 16:40:50
9986	MEMBRECOM	2011-11-30 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8337	\N	2014-11-19 17:50:38
9987	MEMBRECOM	2011-11-30 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8338	\N	2014-11-19 17:50:38
9989	MEMBRECOM	2011-11-30 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8343	\N	2014-11-19 17:50:38
9990	MEMBRECOM	2011-11-30 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8346	\N	2014-11-19 17:50:38
9991	MEMBRECOM	2011-11-30 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8351	\N	2014-11-19 17:50:38
9992	MEMBRECOM	2011-11-30 00:00:00	2011-12-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8358	\N	\N
10031	MEMBRECOM	2011-12-19 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8385	\N	\N
10032	MEMBRECOM	2011-12-19 00:00:00	2018-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8386	\N	2018-05-31 10:52:17
10034	MEMBRECOM	2011-12-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8388	\N	\N
10035	MEMBRECOM	2011-12-19 00:00:00	2017-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8389	\N	2017-09-25 09:56:00
10036	MEMBRECOM	2011-12-19 00:00:00	2015-01-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8390	\N	2015-01-23 15:38:35
10039	MEMBRECOM	2011-12-19 00:00:00	2021-07-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8393	\N	\N
10040	MEMBRECOM	2011-12-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8394	\N	\N
10041	MEMBRECOM	2011-12-19 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8395	\N	2014-09-28 18:58:21
10043	RAPCOM	2011-12-19 00:00:00	2012-05-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8397	\N	\N
10044	MEMBRECOM	2011-12-19 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8398	\N	2017-09-24 17:47:28
10045	MEMBRECOM	2011-12-19 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8399	\N	\N
10047	MEMBRECOM	2011-12-19 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8401	\N	2017-09-24 17:15:15
10048	MEMBRECOM	2011-12-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8402	\N	\N
9094	SECRETCOM	2011-01-11 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7595	\N	\N
8990	MEMBRECOM	2010-11-17 00:00:00	2011-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7490	\N	\N
9681	VICPDTCOM	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8171	\N	\N
10059	MEMBRECOM	2011-12-21 00:00:00	2019-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8413	\N	\N
10062	MEMBRECOM	2011-12-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8416	\N	\N
10063	MEMBRECOM	2011-12-21 00:00:00	2015-04-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8417	\N	2015-04-21 17:14:30
10077	MEMBRECOM	2012-12-21 00:00:00	2015-04-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8431	\N	2015-04-21 17:14:30
10079	MEMBRECOM	2012-12-21 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8433	\N	\N
10086	VICPDTCOM	2012-01-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8440	\N	\N
10110	MEMBRECOM	2012-01-12 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8464	\N	2014-09-28 13:19:48
10111	MEMBRECOM	2012-01-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8465	\N	\N
10112	MEMBRECOM	2012-01-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8466	\N	\N
10173	MEMBRECOM	2012-02-07 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8531	\N	\N
10330	MEMBRECOM	2012-02-21 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8683	\N	2014-09-28 17:12:41
10333	MEMBRECOM	2012-02-21 00:00:00	2019-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8686	\N	\N
10339	MEMBRECOM	2012-02-21 00:00:00	2012-10-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8693	\N	\N
10342	MEMBRECOM	2012-02-21 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8695	\N	2014-09-28 14:31:42
10343	SECRETCOM	2012-02-21 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8697	\N	2014-10-08 19:06:39
10348	VICPDTCOM	2012-02-21 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8701	\N	2014-10-08 19:06:19
10350	MEMBRECOM	2012-02-21 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8703	\N	2014-09-28 16:40:50
10354	MEMBRECOM	2012-02-21 00:00:00	2012-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8707	\N	\N
10358	VICPDTCOM	2012-02-21 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8711	\N	2014-10-08 19:06:16
10360	MEMBRECOM	2012-02-21 00:00:00	2014-04-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8713	\N	2014-04-10 10:16:45
10362	MEMBRECOM	2012-02-21 00:00:00	2012-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8715	\N	\N
10363	VICPDTCOM	2012-02-21 00:00:00	2013-11-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8717	\N	2013-11-27 14:35:34
10367	MEMBRECOM	2012-02-21 00:00:00	2013-11-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8721	\N	2013-11-27 14:35:44
10422	VICPDTCOM	2012-02-15 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8775	\N	2017-09-24 17:35:15
10423	RAPCOM	2012-02-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8776	\N	2014-09-28 17:22:11
10514	VICPDTCOM	2012-06-20 00:00:00	2014-10-07 00:00:00	3	ANCIEN	\N	\N	\N	\N	8202	\N	2014-10-08 17:05:14
10515	VICPDTCOM	2012-06-20 00:00:00	2014-10-07 00:00:00	7	ANCIEN	\N	\N	\N	\N	8065	\N	2014-10-08 16:49:23
10516	SECRETCOM	2012-06-20 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8062	\N	2014-10-08 17:52:56
10673	MEMBRECOM	2012-11-06 00:00:00	2016-12-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8961	\N	2016-12-12 16:10:15
10811	MEMBRECOM	2012-12-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9098	\N	\N
10827	MEMBRECOM	2012-12-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9114	\N	\N
10828	MEMBRECOM	2012-12-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9115	\N	2014-09-28 16:59:41
10829	MEMBRECOM	2012-12-15 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9116	\N	2017-10-01 09:41:22
10240	MEMBRECOM	2012-02-15 00:00:00	2012-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8596	\N	\N
10517	MEMBRECOM	2012-06-17 00:00:00	2012-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8822	\N	\N
10518	MEMBRECOM	2012-06-17 00:00:00	2012-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8823	\N	\N
10519	MEMBRECOM	2012-06-17 00:00:00	2012-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8824	\N	\N
10535	MEMBRECOM	2012-07-04 00:00:00	2012-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8840	\N	2013-12-16 10:26:49
8906	MEMBRECOM	2010-10-06 00:00:00	2012-09-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7406	\N	\N
9433	MEMBRECOM	2011-07-01 00:00:00	2012-09-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7921	\N	\N
10572	MEMBRECOM	2012-09-20 00:00:00	2012-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8874	\N	\N
10666	RAPCOM	2012-11-06 00:00:00	2017-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8954	\N	2017-09-25 09:56:00
10728	MEMBRECOM	2012-11-29 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9015	\N	\N
10729	MEMBRECOM	2012-11-29 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9016	\N	\N
10737	MEMBRECOM	2012-11-27 00:00:00	2013-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9024	\N	\N
10741	MEMBRECOM	2012-11-27 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9028	\N	\N
10743	MEMBRECOM	2012-11-27 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9030	\N	\N
10839	MEMBRECOM	2013-02-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9125	\N	\N
10840	MEMBRECOM	2013-02-06 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9126	\N	2017-09-24 19:25:10
10845	MEMBRECOM	2013-02-06 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9131	\N	2017-09-24 17:47:27
10846	MEMBRECOM	2013-02-06 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9132	\N	2014-09-28 17:38:26
10847	MEMBRECOM	2013-02-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9133	\N	\N
11036	MEMBRECOM	2013-04-23 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9324	\N	2014-04-14 14:28:41
11037	MEMBRECOM	2013-04-23 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9325	\N	2014-04-14 14:28:41
11038	MEMBRECOM	2013-04-23 00:00:00	2013-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9326	\N	\N
11039	MEMBRECOM	2013-04-23 00:00:00	2013-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9327	\N	\N
11040	MEMBRECOM	2013-04-23 00:00:00	2013-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9328	\N	\N
11041	MEMBRECOM	2013-04-23 00:00:00	2013-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9329	\N	\N
11042	MEMBRECOM	2013-04-23 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9330	\N	2014-04-14 14:28:41
11043	MEMBRECOM	2013-04-23 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9331	\N	2014-04-14 14:28:41
11044	MEMBRECOM	2013-04-23 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9332	\N	2014-04-14 14:28:41
11045	MEMBRECOM	2013-04-23 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9333	\N	2014-04-14 14:28:41
11046	MEMBRECOM	2013-04-23 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9334	\N	2014-04-14 14:28:41
11047	MEMBRECOM	2013-04-23 00:00:00	2013-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9335	\N	\N
11048	MEMBRECOM	2013-04-23 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9336	\N	2014-04-14 14:28:41
10644	VICPDTCOM	2012-10-10 00:00:00	2013-06-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8884	\N	\N
11049	MEMBRECOM	2013-04-23 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9337	\N	2014-04-14 14:28:41
11050	MEMBRECOM	2013-04-23 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9338	\N	2014-04-14 14:28:41
11051	MEMBRECOM	2013-04-23 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9339	\N	2014-04-14 14:28:41
11052	MEMBRECOM	2013-04-23 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9340	\N	2014-04-14 14:28:41
11053	MEMBRECOM	2013-04-23 00:00:00	2013-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9341	\N	\N
11054	MEMBRECOM	2013-04-23 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9342	\N	2014-04-14 14:28:41
11055	MEMBRECOM	2013-04-23 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9343	\N	2014-04-14 14:28:41
11056	MEMBRECOM	2013-04-23 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9344	\N	2014-04-14 14:28:41
11057	MEMBRECOM	2013-04-23 00:00:00	2013-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9345	\N	\N
11058	MEMBRECOM	2013-04-23 00:00:00	2013-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9346	\N	2013-12-16 10:30:09
10536	VICPDTCOM	2012-07-11 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8572	\N	\N
10637	PDTCOM	2012-10-10 00:00:00	2013-06-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8898	\N	\N
10638	RAPCOM	2012-10-10 00:00:00	2013-06-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8882	\N	\N
10639	VICPDTCOM	2012-10-10 00:00:00	2013-06-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8881	\N	\N
10640	VICPDTCOM	2012-10-10 00:00:00	2013-06-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8891	\N	\N
10641	VICPDTCOM	2012-10-10 00:00:00	2013-06-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8901	\N	\N
10642	VICPDTCOM	2012-10-10 00:00:00	2013-06-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8887	\N	\N
10649	MEMBRECOM	2012-10-23 00:00:00	2012-11-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8938	\N	\N
10648	MEMBRECOM	2012-10-23 00:00:00	2012-11-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8937	\N	\N
10831	MEMBRECOM	2012-02-21 00:00:00	2013-05-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9118	\N	2017-12-19 14:40:50
10832	MEMBRECOM	2013-01-28 00:00:00	2013-05-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9119	\N	2013-05-21 17:52:05
10848	MEMBRECOM	2013-02-26 00:00:00	2013-02-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9134	\N	\N
10849	MEMBRECOM	2013-02-26 00:00:00	2013-02-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9135	\N	\N
10850	MEMBRECOM	2013-02-26 00:00:00	2013-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9136	\N	\N
10851	MEMBRECOM	2013-02-26 00:00:00	2013-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9137	\N	\N
10852	MEMBRECOM	2013-02-26 00:00:00	2013-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9138	\N	\N
10853	MEMBRECOM	2013-02-26 00:00:00	2013-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9139	\N	\N
10854	MEMBRECOM	2013-02-26 00:00:00	2013-02-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9140	\N	\N
10855	MEMBRECOM	2013-02-26 00:00:00	2013-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9141	\N	\N
10856	MEMBRECOM	2013-02-26 00:00:00	2013-02-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9142	\N	\N
10857	MEMBRECOM	2013-02-26 00:00:00	2013-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9143	\N	\N
10858	MEMBRECOM	2013-02-26 00:00:00	2013-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9144	\N	\N
10859	MEMBRECOM	2013-02-26 00:00:00	2013-02-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9145	\N	\N
10860	MEMBRECOM	2013-02-26 00:00:00	2013-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9146	\N	\N
10861	MEMBRECOM	2013-02-26 00:00:00	2013-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9147	\N	\N
10862	MEMBRECOM	2013-02-26 00:00:00	2013-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9148	\N	\N
10863	MEMBRECOM	2013-02-26 00:00:00	2013-02-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9149	\N	\N
10864	MEMBRECOM	2013-02-26 00:00:00	2013-02-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9150	\N	\N
10865	MEMBRECOM	2013-02-26 00:00:00	2013-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9151	\N	\N
10866	MEMBRECOM	2013-02-26 00:00:00	2013-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9152	\N	\N
10867	MEMBRECOM	2013-02-26 00:00:00	2013-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9153	\N	\N
10868	MEMBRECOM	2013-02-26 00:00:00	2013-02-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9154	\N	\N
11061	MEMBRECOM	2013-03-13 00:00:00	2013-03-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9349	\N	2014-01-30 14:39:09
10425	MEMBRECOM	2012-02-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8778	\N	\N
10426	MEMBRECOM	2012-02-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8779	\N	2014-09-28 17:03:42
10427	MEMBRECOM	2012-02-15 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8780	\N	2017-09-24 19:25:10
10428	MEMBRECOM	2012-02-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8781	\N	\N
10429	MEMBRECOM	2012-02-15 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8782	\N	2017-09-24 13:44:49
10430	MEMBRECOM	2012-02-15 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8783	\N	2017-09-24 17:29:37
10433	MEMBRECOM	2012-02-15 00:00:00	2020-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8786	\N	\N
10435	MEMBRECOM	2012-02-15 00:00:00	2014-09-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8788	\N	2014-09-01 10:21:13
10505	MEMBRECOM	2012-02-01 00:00:00	2012-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8481	\N	2013-12-16 10:26:49
10506	MEMBRECOM	2012-02-01 00:00:00	2012-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8480	\N	2013-12-16 10:26:49
10507	MEMBRECOM	2012-02-01 00:00:00	2012-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8471	\N	2013-12-16 10:26:49
10508	MEMBRECOM	2012-02-01 00:00:00	2012-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8470	\N	2013-12-16 10:26:49
10522	MEMBRECOM	2012-07-03 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8826	\N	\N
10559	VICPDTCOM	2012-07-26 00:00:00	2015-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8861	\N	2015-01-08 17:14:29
10561	MEMBRECOM	2012-07-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8863	\N	\N
10562	MEMBRECOM	2012-07-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8864	\N	\N
10563	MEMBRECOM	2012-07-26 00:00:00	2017-05-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8865	\N	2017-05-16 15:18:13
10564	MEMBRECOM	2012-07-26 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8866	\N	2017-09-24 18:20:10
10635	MEMBRECOM	2012-10-09 00:00:00	2012-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8933	\N	\N
10636	MEMBRECOM	2012-10-02 00:00:00	2013-06-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8883	\N	\N
10711	MEMBRECOM	2012-11-28 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8998	\N	2017-09-24 17:19:42
10739	MEMBRECOM	2012-11-27 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9026	\N	\N
10794	MEMBRECOM	2012-12-13 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9081	\N	2014-09-28 12:09:44
10699	MEMBRECOM	2012-12-05 00:00:00	2014-05-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8986	\N	2014-05-07 12:23:35
10700	MEMBRECOM	2012-12-05 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8987	\N	2017-09-24 19:31:54
10702	RAPCOM	2012-11-28 00:00:00	2014-05-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8989	\N	2014-05-12 09:52:22
10706	MEMBRECOM	2012-11-28 00:00:00	2018-12-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8993	\N	\N
10708	MEMBRECOM	2012-11-28 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8995	\N	2017-09-24 13:25:54
10800	MEMBRECOM	2012-12-13 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9087	\N	\N
10836	MEMBRECOM	2013-02-14 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9123	\N	2014-09-28 17:58:04
11012	MEMBRECOM	2013-04-23 00:00:00	2013-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9299	\N	\N
11027	MEMBRECOM	2013-04-23 00:00:00	2013-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9314	\N	2013-12-16 10:30:09
11013	MEMBRECOM	2013-04-23 00:00:00	2013-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9300	\N	2013-12-16 10:30:09
11014	MEMBRECOM	2013-04-23 00:00:00	2013-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9301	\N	2013-12-16 10:30:09
11015	MEMBRECOM	2013-04-23 00:00:00	2013-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9302	\N	2013-12-16 10:30:09
11016	MEMBRECOM	2013-04-23 00:00:00	2013-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9303	\N	2013-12-16 10:30:09
11017	MEMBRECOM	2013-04-23 00:00:00	2013-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9304	\N	\N
11018	MEMBRECOM	2013-04-23 00:00:00	2013-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9305	\N	2013-12-16 10:30:09
11019	MEMBRECOM	2013-04-23 00:00:00	2013-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9306	\N	\N
11020	MEMBRECOM	2013-04-23 00:00:00	2013-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9307	\N	2013-12-16 10:30:09
11021	MEMBRECOM	2013-04-23 00:00:00	2013-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9308	\N	2013-12-16 10:30:09
11022	MEMBRECOM	2013-04-23 00:00:00	2013-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9309	\N	2013-12-16 10:30:09
11023	MEMBRECOM	2013-04-23 00:00:00	2013-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9310	\N	\N
11024	MEMBRECOM	2013-04-23 00:00:00	2013-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9311	\N	2013-12-16 10:30:09
11025	MEMBRECOM	2013-04-23 00:00:00	2013-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9312	\N	\N
11026	MEMBRECOM	2013-04-23 00:00:00	2013-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9313	\N	\N
11029	MEMBRECOM	2013-04-23 00:00:00	2013-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9316	\N	2013-12-16 10:30:09
11030	MEMBRECOM	2013-04-23 00:00:00	2013-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9317	\N	\N
11031	MEMBRECOM	2013-04-23 00:00:00	2013-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9318	\N	2013-12-16 10:30:09
11033	MEMBRECOM	2013-04-23 00:00:00	2013-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9320	\N	2013-12-16 10:30:09
11035	MEMBRECOM	2013-04-23 00:00:00	2013-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9322	\N	2013-12-16 10:30:09
10460	PDTCOM	2012-02-15 00:00:00	2013-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8607	\N	\N
10242	MEMBRECOM	2012-02-15 00:00:00	2012-02-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8598	\N	\N
10461	VICPDTCOM	2012-02-15 00:00:00	2013-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8598	\N	\N
10462	VICPDTCOM	2012-02-15 00:00:00	2013-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8600	\N	\N
10463	VICPDTCOM	2012-02-15 00:00:00	2013-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8536	\N	\N
10464	VICPDTCOM	2012-02-15 00:00:00	2013-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8670	\N	\N
10465	VICPDTCOM	2012-02-15 00:00:00	2013-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8616	\N	\N
10466	VICPDTCOM	2012-02-15 00:00:00	2013-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8620	\N	\N
10467	RAPCOM	2012-02-15 00:00:00	2013-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8610	\N	\N
10468	PDTCOM	2012-02-22 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8640	\N	\N
10469	RAPCOM	2012-02-22 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8621	\N	\N
10470	VICPDTCOM	2012-02-22 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8666	\N	\N
10471	VICPDTCOM	2012-02-22 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8541	\N	\N
10472	VICPDTCOM	2012-02-22 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8636	\N	\N
10473	VICPDTCOM	2012-02-22 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8626	\N	\N
10474	VICPDTCOM	2012-02-22 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8622	\N	\N
10475	VICPDTCOM	2012-02-22 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8627	\N	\N
10277	MEMBRECOM	2012-02-15 00:00:00	2012-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8636	\N	\N
10495	MEMBRECOM	2012-02-28 00:00:00	2019-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8808	\N	\N
10496	MEMBRECOM	2012-02-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8809	\N	\N
10497	MEMBRECOM	2012-02-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8810	\N	\N
10498	MEMBRECOM	2012-02-28 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8811	\N	2017-09-24 17:06:55
10499	MEMBRECOM	2012-02-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8812	\N	\N
10500	MEMBRECOM	2012-02-28 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8813	\N	2014-09-28 17:03:42
10501	MEMBRECOM	2012-02-28 00:00:00	2016-11-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8814	\N	2016-12-01 10:36:51
10503	MEMBRECOM	2012-02-28 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8816	\N	\N
10283	MEMBRECOM	2012-02-15 00:00:00	2012-04-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8642	\N	2013-12-16 10:07:20
10542	MEMBRECOM	2012-07-24 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8846	\N	2014-10-09 11:06:42
10601	MEMBRECOM	2012-09-26 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8904	\N	2014-09-28 17:07:41
10602	MEMBRECOM	2012-09-26 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8905	\N	2014-09-28 17:38:26
10603	MEMBRECOM	2012-09-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8906	\N	\N
10605	MEMBRECOM	2012-09-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8908	\N	\N
10606	MEMBRECOM	2012-09-26 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8909	\N	2017-09-24 13:44:49
10612	MEMBRECOM	2012-09-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8915	\N	\N
10621	MEMBRECOM	2012-09-27 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8924	\N	\N
10622	MEMBRECOM	2012-09-27 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8925	\N	\N
10623	MEMBRECOM	2012-09-27 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8926	\N	2014-09-28 17:03:42
10676	MEMBRECOM	2012-11-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8964	\N	\N
10677	MEMBRECOM	2012-11-06 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8965	\N	2014-09-28 18:03:38
10718	MEMBRECOM	2012-11-29 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9005	\N	2017-10-01 10:17:18
10719	MEMBRECOM	2012-11-29 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9006	\N	\N
10720	MEMBRECOM	2012-11-29 00:00:00	2015-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9007	\N	2015-06-12 16:01:25
10723	MEMBRECOM	2012-11-29 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9010	\N	2017-09-24 17:09:24
10724	MEMBRECOM	2012-11-29 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9011	\N	\N
10843	MEMBRECOM	2013-02-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9129	\N	\N
10844	MEMBRECOM	2013-02-06 00:00:00	2018-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9130	\N	\N
10929	MEMBRECOM	2013-03-13 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9218	\N	2013-12-16 10:28:45
10930	MEMBRECOM	2013-03-13 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9219	\N	2013-12-16 10:28:45
10931	MEMBRECOM	2013-03-13 00:00:00	2013-04-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9220	\N	\N
10932	MEMBRECOM	2013-03-13 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9221	\N	2013-12-16 10:28:45
10933	MEMBRECOM	2013-03-13 00:00:00	2013-03-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9222	\N	\N
10934	MEMBRECOM	2013-03-13 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9223	\N	2013-12-16 10:28:45
10935	MEMBRECOM	2013-03-13 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9224	\N	2013-12-16 10:28:45
10936	MEMBRECOM	2013-03-13 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9225	\N	2013-12-16 10:28:45
10937	MEMBRECOM	2013-03-13 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9227	\N	2013-12-16 10:28:45
10938	MEMBRECOM	2013-03-13 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9229	\N	2013-12-16 10:28:45
10939	MEMBRECOM	2013-03-13 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9230	\N	2013-12-16 10:28:45
10940	MEMBRECOM	2013-03-13 00:00:00	2013-03-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9231	\N	\N
10941	MEMBRECOM	2013-03-13 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9232	\N	2013-12-16 10:28:45
10942	MEMBRECOM	2013-03-13 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9233	\N	2013-12-16 10:28:45
10943	MEMBRECOM	2013-03-13 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9234	\N	2013-12-16 10:28:45
10944	MEMBRECOM	2013-03-13 00:00:00	2013-03-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9235	\N	\N
10945	MEMBRECOM	2013-03-13 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9236	\N	2013-12-16 10:28:45
10946	MEMBRECOM	2013-03-13 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9237	\N	2013-12-16 10:28:45
10947	MEMBRECOM	2013-03-13 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9238	\N	2013-12-16 10:28:45
10436	PDTCOM	2012-02-22 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8657	\N	2013-12-16 10:13:19
10437	RAPCOM	2012-02-22 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8662	\N	2013-12-16 10:13:19
10438	VICPDTCOM	2012-02-22 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8645	\N	2013-12-16 10:13:19
10439	VICPDTCOM	2012-02-22 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8542	\N	2013-12-16 10:13:19
10440	VICPDTCOM	2012-02-22 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8664	\N	2013-12-16 10:13:19
10441	VICPDTCOM	2012-02-22 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8674	\N	2013-12-16 10:13:19
10442	SECRETCOM	2012-02-22 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8655	\N	2013-12-16 10:13:19
10443	SECRETCOM	2012-02-22 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8649	\N	2013-12-16 10:13:19
10444	PDTCOM	2012-02-21 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8570	\N	\N
10445	VICPDTCOM	2012-02-21 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8559	\N	\N
10446	VICPDTCOM	2012-02-21 00:00:00	2012-06-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8568	\N	\N
10447	VICPDTCOM	2012-02-21 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8575	\N	\N
10448	VICPDTCOM	2012-02-21 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8573	\N	\N
10449	VICPDTCOM	2012-02-21 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8564	\N	\N
10450	VICPDTCOM	2012-02-21 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8665	\N	\N
10451	RAPCOM	2012-02-21 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8535	\N	\N
10452	PDTCOM	2012-02-21 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8581	\N	\N
10453	VICPDTCOM	2012-02-21 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8595	\N	\N
10454	VICPDTCOM	2012-02-21 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8540	\N	\N
10455	VICPDTCOM	2012-02-21 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8671	\N	\N
10456	VICPDTCOM	2012-02-21 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8579	\N	\N
10457	VICPDTCOM	2012-02-21 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8588	\N	\N
10458	VICPDTCOM	2012-02-21 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8596	\N	\N
10459	RAPCOM	2012-02-21 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8586	\N	\N
10523	MEMBRECOM	2012-07-03 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8827	\N	2014-10-08 17:43:00
10524	MEMBRECOM	2012-07-03 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8828	\N	2014-10-08 17:38:49
10525	MEMBRECOM	2012-07-03 00:00:00	2014-05-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8829	\N	2014-05-05 14:01:11
10568	MEMBRECOM	2012-07-26 00:00:00	2021-07-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8870	\N	\N
10569	MEMBRECOM	2012-07-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8871	\N	\N
10570	MEMBRECOM	2012-07-26 00:00:00	2019-06-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8872	\N	\N
10571	MEMBRECOM	2012-07-26 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8873	\N	\N
10631	VICPDTCOM	2012-10-09 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4241	\N	2014-09-28 13:19:48
10647	MEMBRECOM	2012-10-18 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8936	\N	2014-11-19 17:50:38
10667	MEMBRECOM	2012-11-06 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8955	\N	\N
10669	MEMBRECOM	2012-11-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8957	\N	\N
10670	MEMBRECOM	2012-11-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8958	\N	\N
10671	MEMBRECOM	2012-11-06 00:00:00	2014-07-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8959	\N	2014-07-01 09:25:11
10709	MEMBRECOM	2012-11-28 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8996	\N	2017-09-24 17:06:55
10716	PDTCOM	2012-11-29 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9003	\N	\N
10717	RAPCOM	2012-11-29 00:00:00	2017-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9004	\N	2017-06-19 12:20:59
10730	RAPCOM	2012-11-27 00:00:00	2017-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9017	\N	2017-09-25 09:56:00
10744	RAPCOM	2012-11-29 00:00:00	2017-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9031	\N	2017-09-25 09:56:00
10745	VICPDTCOM	2012-11-29 00:00:00	2015-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9032	\N	2015-01-08 17:14:29
10747	MEMBRECOM	2012-11-29 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9034	\N	2014-09-28 17:34:16
10750	MEMBRECOM	2012-11-29 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9037	\N	\N
10752	MEMBRECOM	2012-11-29 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9039	\N	\N
10753	MEMBRECOM	2012-11-29 00:00:00	2014-12-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9040	\N	2014-12-18 16:15:04
10754	MEMBRECOM	2012-11-29 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9041	\N	\N
10755	MEMBRECOM	2012-11-29 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9042	\N	\N
10948	MEMBRECOM	2013-03-13 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9239	\N	2013-12-16 10:28:45
10949	MEMBRECOM	2013-03-13 00:00:00	2013-03-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9240	\N	\N
10950	MEMBRECOM	2013-03-13 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9241	\N	2013-12-16 10:28:45
11005	MEMBRECOM	2013-04-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9292	\N	2014-09-28 17:00:59
11006	MEMBRECOM	2013-04-10 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9293	\N	2017-09-24 17:19:42
11079	MEMBRECOM	2013-05-21 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9353	2013-05-21 17:46:50	2017-09-24 17:18:03
11080	MEMBRECOM	2013-05-21 00:00:00	2016-11-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9354	2013-05-21 17:52:23	2016-11-14 11:07:47
10545	VICPDTCOM	2012-07-24 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8847	\N	\N
10546	RAPCOM	2012-07-24 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8848	\N	2017-10-01 10:17:18
10547	MEMBRECOM	2012-07-24 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8849	\N	2014-09-28 17:07:41
10548	MEMBRECOM	2012-07-24 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8850	\N	\N
10549	MEMBRECOM	2012-07-24 00:00:00	2015-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8851	\N	2015-10-13 14:23:35
10550	MEMBRECOM	2012-07-24 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8852	\N	\N
10551	MEMBRECOM	2012-07-24 00:00:00	2019-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8853	\N	\N
10552	MEMBRECOM	2012-07-24 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8854	\N	2014-09-28 12:09:44
10553	MEMBRECOM	2012-07-24 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8855	\N	\N
10554	MEMBRECOM	2012-07-24 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8856	\N	2017-09-24 19:25:10
10555	MEMBRECOM	2012-07-24 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8857	\N	2014-09-28 17:34:16
10556	MEMBRECOM	2012-07-24 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8858	\N	\N
10557	MEMBRECOM	2012-07-24 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8859	\N	\N
10558	MEMBRECOM	2012-07-24 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8860	\N	2017-09-24 13:29:42
10477	RAPCOM	2012-02-22 00:00:00	2012-05-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8790	\N	\N
10478	MEMBRECOM	2012-02-22 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8791	\N	\N
10479	MEMBRECOM	2012-02-22 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8792	\N	\N
10483	MEMBRECOM	2012-02-22 00:00:00	2015-01-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8796	\N	2015-01-23 15:38:35
10485	MEMBRECOM	2012-02-22 00:00:00	2013-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8798	\N	\N
10487	MEMBRECOM	2012-02-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8800	\N	\N
10488	MEMBRECOM	2012-02-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8801	\N	\N
10491	RAPCOM	2012-02-28 00:00:00	2012-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8804	\N	\N
10504	MEMBRECOM	2012-03-19 00:00:00	2012-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8817	\N	\N
10650	VICPDTCOM	2012-10-02 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8221	\N	2014-09-28 13:21:47
10660	MEMBRECOM	2012-10-23 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8948	\N	\N
10661	MEMBRECOM	2012-10-23 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8949	\N	\N
10674	MEMBRECOM	2012-11-06 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8962	\N	2017-09-24 17:47:28
10675	MEMBRECOM	2012-11-06 00:00:00	2017-05-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8963	\N	2017-05-16 15:18:13
10695	MEMBRECOM	2012-11-20 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8982	\N	2014-09-28 17:52:18
10712	MEMBRECOM	2012-11-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8999	\N	\N
10764	MEMBRECOM	2012-12-13 00:00:00	2015-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9051	\N	2015-06-12 15:59:49
10765	MEMBRECOM	2012-12-13 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9052	\N	2017-09-24 18:20:10
10767	MEMBRECOM	2012-12-13 00:00:00	2020-06-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9054	\N	\N
10771	MEMBRECOM	2012-12-13 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9058	\N	2017-10-01 09:41:22
10772	MEMBRECOM	2012-12-13 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9059	\N	2017-09-24 17:15:15
10878	MEMBRECOM	2013-03-13 00:00:00	2013-03-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9164	\N	\N
10879	MEMBRECOM	2013-03-13 00:00:00	2013-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9165	\N	\N
10880	MEMBRECOM	2013-03-13 00:00:00	2013-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9166	\N	\N
10881	MEMBRECOM	2013-03-13 00:00:00	2013-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9167	\N	\N
10541	MEMBRECOM	2012-07-24 00:00:00	2013-01-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8845	\N	2013-10-30 18:24:24
10882	MEMBRECOM	2013-03-13 00:00:00	2013-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9168	\N	\N
10883	MEMBRECOM	2013-03-13 00:00:00	2013-03-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9169	\N	\N
10884	MEMBRECOM	2013-03-13 00:00:00	2013-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9170	\N	\N
10885	MEMBRECOM	2013-03-13 00:00:00	2013-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9171	\N	\N
10886	MEMBRECOM	2013-03-13 00:00:00	2013-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9172	\N	\N
10887	MEMBRECOM	2013-03-13 00:00:00	2013-03-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9173	\N	\N
10888	MEMBRECOM	2013-03-13 00:00:00	2013-03-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9174	\N	\N
10889	MEMBRECOM	2013-03-13 00:00:00	2013-03-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9175	\N	\N
10890	MEMBRECOM	2013-03-13 00:00:00	2013-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9176	\N	\N
10891	MEMBRECOM	2013-03-13 00:00:00	2013-03-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9177	\N	\N
10892	MEMBRECOM	2013-03-13 00:00:00	2013-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9179	\N	\N
10893	MEMBRECOM	2013-03-13 00:00:00	2013-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9180	\N	\N
10894	MEMBRECOM	2013-03-13 00:00:00	2013-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9182	\N	\N
10895	MEMBRECOM	2013-03-13 00:00:00	2013-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9183	\N	\N
10896	MEMBRECOM	2013-03-13 00:00:00	2013-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9184	\N	\N
10897	MEMBRECOM	2013-03-13 00:00:00	2013-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9185	\N	\N
10898	MEMBRECOM	2013-03-13 00:00:00	2013-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9186	\N	\N
10899	MEMBRECOM	2013-03-13 00:00:00	2013-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9187	\N	\N
10493	MEMBRECOM	2012-02-28 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8806	\N	2014-09-28 17:38:26
10494	MEMBRECOM	2012-02-28 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8807	\N	2014-09-28 17:31:41
10538	MEMBRECOM	2012-07-24 00:00:00	2014-05-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8842	\N	2014-05-05 10:35:50
10539	MEMBRECOM	2012-07-24 00:00:00	2014-05-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8843	\N	2014-05-05 10:35:23
10540	MEMBRECOM	2012-07-24 00:00:00	2014-05-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8844	\N	2014-05-05 10:33:42
10573	MEMBRECOM	2012-09-25 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8875	\N	2017-10-04 19:50:02
10261	MEMBRECOM	2012-02-15 00:00:00	2013-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8618	\N	\N
10243	MEMBRECOM	2012-02-15 00:00:00	2013-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8599	\N	\N
10254	MEMBRECOM	2012-02-15 00:00:00	2013-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8611	\N	\N
10833	MEMBRECOM	2013-02-05 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9120	\N	2014-10-09 15:39:51
10528	MEMBRECOM	2012-07-03 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8832	\N	2014-09-28 17:40:23
10529	MEMBRECOM	2012-07-03 00:00:00	2014-04-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8833	\N	2014-04-23 09:56:25
10530	MEMBRECOM	2012-07-03 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8834	\N	2014-10-09 11:04:00
10531	MEMBRECOM	2012-07-03 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8835	\N	2014-09-28 13:47:05
10532	MEMBRECOM	2012-07-03 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8836	\N	2014-10-09 13:50:48
10533	VICPDTCOM	2012-07-03 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8837	\N	2014-10-09 15:55:41
10534	MEMBRECOM	2012-07-03 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8839	\N	2014-09-28 16:59:41
10651	PDTCOM	2012-10-23 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8939	\N	2017-09-24 17:09:24
10707	MEMBRECOM	2012-11-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8994	\N	\N
10733	MEMBRECOM	2012-11-27 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9020	\N	2014-09-28 17:34:16
10734	MEMBRECOM	2012-11-27 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9021	\N	2017-09-24 17:06:55
10735	MEMBRECOM	2012-11-27 00:00:00	2014-07-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9022	\N	2014-07-01 09:25:11
10736	MEMBRECOM	2012-11-27 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9023	\N	\N
10835	MEMBRECOM	2013-02-13 00:00:00	2013-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9122	\N	\N
10210	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8565	\N	\N
10219	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8574	\N	\N
10309	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8668	\N	\N
10276	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8635	\N	\N
10313	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8672	\N	\N
10221	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8576	\N	\N
10225	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8580	\N	\N
10231	MEMBRECOM	2012-02-15 00:00:00	2012-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8587	\N	\N
10579	MEMBRECOM	2012-10-02 00:00:00	2012-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8881	\N	\N
10580	MEMBRECOM	2012-10-02 00:00:00	2012-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8882	\N	\N
10581	MEMBRECOM	2012-10-02 00:00:00	2012-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8884	\N	\N
10582	MEMBRECOM	2012-10-02 00:00:00	2013-06-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8885	\N	\N
10583	MEMBRECOM	2012-10-02 00:00:00	2013-06-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8886	\N	\N
10584	MEMBRECOM	2012-10-02 00:00:00	2012-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8887	\N	\N
10585	MEMBRECOM	2012-10-02 00:00:00	2013-06-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8888	\N	\N
10586	MEMBRECOM	2012-10-02 00:00:00	2013-06-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8889	\N	\N
10587	MEMBRECOM	2012-10-02 00:00:00	2013-06-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8890	\N	\N
10588	MEMBRECOM	2012-10-02 00:00:00	2012-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8891	\N	\N
10589	MEMBRECOM	2012-10-02 00:00:00	2013-06-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8892	\N	\N
10590	MEMBRECOM	2012-10-02 00:00:00	2013-06-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8893	\N	\N
10591	MEMBRECOM	2012-10-02 00:00:00	2013-06-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8894	\N	\N
10592	MEMBRECOM	2012-10-02 00:00:00	2013-06-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8895	\N	\N
10593	MEMBRECOM	2012-10-02 00:00:00	2013-06-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8896	\N	\N
10594	MEMBRECOM	2012-10-02 00:00:00	2013-06-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8897	\N	\N
10595	MEMBRECOM	2012-10-02 00:00:00	2012-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8898	\N	\N
10596	MEMBRECOM	2012-10-02 00:00:00	2013-06-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8899	\N	\N
10597	MEMBRECOM	2012-10-02 00:00:00	2012-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8900	\N	\N
10598	MEMBRECOM	2012-10-02 00:00:00	2012-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8901	\N	\N
10656	MEMBRECOM	2012-10-23 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8944	\N	\N
10662	MEMBRECOM	2012-10-23 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8950	\N	\N
10713	MEMBRECOM	2012-11-28 00:00:00	2019-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9000	\N	\N
10715	MEMBRECOM	2012-11-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9002	\N	\N
10725	MEMBRECOM	2012-11-29 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9012	\N	2017-09-24 18:16:52
10726	MEMBRECOM	2012-11-29 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9013	\N	\N
10727	MEMBRECOM	2012-11-29 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9014	\N	2014-09-28 17:34:16
10751	MEMBRECOM	2012-11-29 00:00:00	2013-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9038	\N	\N
10756	MEMBRECOM	2012-11-29 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9043	\N	2017-10-01 09:41:22
10757	MEMBRECOM	2012-11-29 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9044	\N	\N
10978	MEMBRECOM	2013-04-02 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9265	\N	\N
10979	MEMBRECOM	2013-04-02 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9266	\N	2014-09-28 17:34:16
11071	PDTCOM	2013-05-14 00:00:00	2013-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9317	\N	2013-12-16 10:30:09
11072	RAPCOM	2013-05-14 00:00:00	2013-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9310	\N	2013-12-16 10:30:09
11073	VICPDTCOM	2013-05-14 00:00:00	2013-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9299	\N	2013-12-16 10:30:09
11074	VICPDTCOM	2013-05-14 00:00:00	2013-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9304	\N	2013-12-16 10:30:09
11075	VICPDTCOM	2013-05-14 00:00:00	2013-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9306	\N	2013-12-16 10:30:09
11076	VICPDTCOM	2013-05-14 00:00:00	2013-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9345	\N	2013-12-16 10:30:09
11077	VICPDTCOM	2013-05-14 00:00:00	2013-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9312	\N	2013-12-16 10:30:09
11078	VICPDTCOM	2013-05-14 00:00:00	2013-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9313	\N	2013-12-16 10:30:09
10405	PDTCOM	2012-02-21 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8758	\N	2014-09-28 19:07:43
10406	MEMBRECOM	2012-02-21 00:00:00	2013-01-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8759	\N	\N
10407	MEMBRECOM	2012-02-21 00:00:00	2013-02-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8760	\N	\N
10408	PDTCOM	2012-02-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8761	\N	\N
10409	RAPCOM	2012-02-15 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8762	\N	2017-09-24 18:17:56
10410	MEMBRECOM	2012-02-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8763	\N	\N
10411	MEMBRECOM	2012-02-15 00:00:00	2012-09-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8764	\N	\N
10412	MEMBRECOM	2012-02-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8765	\N	2014-09-28 17:40:23
10413	MEMBRECOM	2012-02-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8766	\N	\N
10415	MEMBRECOM	2012-02-15 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8768	\N	2017-09-24 17:09:24
10416	MEMBRECOM	2012-02-15 00:00:00	2017-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8769	\N	2017-07-24 09:56:26
10417	MEMBRECOM	2012-02-15 00:00:00	2015-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8770	\N	2015-10-13 14:23:40
10418	MEMBRECOM	2012-02-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8771	\N	2014-09-28 17:34:16
10419	MEMBRECOM	2012-02-15 00:00:00	2017-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8772	\N	2017-06-19 12:20:59
10420	MEMBRECOM	2012-02-15 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8773	\N	\N
10421	MEMBRECOM	2012-02-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8774	\N	2014-09-28 13:40:33
10511	RAPGENCOM	2012-06-20 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	749	\N	2014-10-08 17:52:27
10512	VICPDTPRECOM	2012-06-20 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4284	\N	2014-10-08 17:52:35
11064	MEMBRECOM	2013-04-24 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9352	2013-04-24 10:55:32	2014-11-19 17:50:38
10682	MEMBRECOM	2012-11-13 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8969	\N	2014-10-09 13:58:19
10683	MEMBRECOM	2012-11-13 00:00:00	2013-02-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8970	\N	\N
10600	RAPCOM	2012-09-26 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8903	\N	2014-09-28 17:22:11
10607	MEMBRECOM	2012-09-26 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8910	\N	\N
10614	RAPCOM	2012-09-27 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8917	\N	\N
10615	MEMBRECOM	2012-09-27 00:00:00	2015-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8918	\N	2015-03-03 10:16:55
10616	MEMBRECOM	2012-09-27 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8919	\N	2014-09-28 12:39:09
10618	MEMBRECOM	2012-09-27 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8921	\N	\N
10619	MEMBRECOM	2012-09-27 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8922	\N	\N
10624	MEMBRECOM	2012-09-27 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8927	\N	2017-10-01 10:01:39
10625	MEMBRECOM	2012-09-27 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8928	\N	2014-09-28 17:40:23
10626	MEMBRECOM	2012-09-27 00:00:00	2016-11-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8929	\N	2016-12-01 10:36:51
10627	MEMBRECOM	2012-10-03 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8930	\N	2014-10-08 19:03:44
10628	MEMBRECOM	2012-10-03 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8931	\N	2014-10-08 19:03:52
10653	MEMBRECOM	2012-10-23 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8941	\N	\N
10654	MEMBRECOM	2012-10-23 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8942	\N	2014-09-28 17:38:26
10655	MEMBRECOM	2012-10-23 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8943	\N	2017-09-24 17:28:55
10678	MEMBRECOM	2012-11-06 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8966	\N	2017-09-24 17:15:15
10685	RAPCOM	2012-11-20 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8972	\N	\N
10680	MEMBRECOM	2012-11-12 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8967	\N	2014-09-28 16:40:50
10681	MEMBRECOM	2012-11-12 00:00:00	2014-05-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8968	\N	2014-05-05 14:50:04
10686	MEMBRECOM	2012-11-20 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8973	\N	2017-09-24 16:43:43
10687	MEMBRECOM	2012-11-20 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8974	\N	2014-09-28 17:38:26
10688	MEMBRECOM	2012-11-20 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8975	\N	\N
10690	MEMBRECOM	2012-11-20 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8977	\N	\N
10691	MEMBRECOM	2012-11-20 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8978	\N	\N
10577	MEMBRECOM	2012-10-01 00:00:00	2012-11-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8879	\N	\N
10578	MEMBRECOM	2012-10-01 00:00:00	2012-11-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8880	\N	\N
10955	RAPCOM	2013-04-02 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9242	\N	2017-09-24 18:16:52
10956	PDTCOM	2013-04-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9243	\N	\N
10957	MEMBRECOM	2013-04-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9244	\N	\N
10960	MEMBRECOM	2013-04-02 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9247	\N	\N
10961	MEMBRECOM	2013-04-02 00:00:00	2014-04-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9248	\N	2014-04-23 09:56:25
10962	MEMBRECOM	2013-04-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9249	\N	\N
10965	MEMBRECOM	2013-04-02 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9252	\N	2014-09-28 17:34:16
10966	MEMBRECOM	2013-04-02 00:00:00	2015-04-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9253	\N	2015-04-21 17:14:30
10967	MEMBRECOM	2013-04-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9254	\N	\N
10968	MEMBRECOM	2013-04-02 00:00:00	2014-05-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9255	\N	2014-05-05 10:34:09
10969	PDTCOM	2013-04-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9256	\N	\N
10970	MEMBRECOM	2013-04-02 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9257	\N	2017-09-24 19:25:10
10984	MEMBRECOM	2013-04-04 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9271	\N	2017-09-24 17:42:25
10985	MEMBRECOM	2013-04-04 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9272	\N	2014-09-28 17:38:26
10986	RAPCOM	2013-04-04 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9273	\N	2014-09-28 17:34:16
10987	MEMBRECOM	2013-04-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9274	\N	\N
10988	MEMBRECOM	2013-04-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9275	\N	\N
10989	MEMBRECOM	2013-04-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9276	\N	\N
10991	MEMBRECOM	2013-04-04 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9278	\N	2017-09-24 13:44:49
10992	MEMBRECOM	2013-04-04 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9279	\N	\N
10993	MEMBRECOM	2013-04-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9280	\N	\N
10999	MEMBRECOM	2013-04-10 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9286	\N	2017-09-24 17:06:55
11000	MEMBRECOM	2013-04-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9287	\N	2014-09-28 14:31:42
11001	MEMBRECOM	2013-04-10 00:00:00	2018-12-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9288	\N	\N
11003	MEMBRECOM	2013-04-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9290	\N	\N
11007	MEMBRECOM	2013-04-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9294	\N	\N
11008	MEMBRECOM	2013-04-10 00:00:00	2020-11-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9295	\N	\N
11009	MEMBRECOM	2013-04-10 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9296	\N	2017-09-24 13:25:54
11010	MEMBRECOM	2013-04-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9297	\N	\N
10608	MEMBRECOM	2012-09-26 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8911	\N	2017-09-24 17:47:27
10609	MEMBRECOM	2012-09-26 00:00:00	2020-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8912	\N	\N
10610	MEMBRECOM	2012-09-26 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8913	\N	2017-09-24 16:43:43
10645	VICPDTCOM	2012-10-10 00:00:00	2013-06-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8933	\N	\N
10759	RAPCOM	2012-12-13 00:00:00	2017-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9046	\N	2017-09-25 09:56:00
10761	MEMBRECOM	2012-12-13 00:00:00	2014-08-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9048	\N	2014-08-27 16:33:38
10763	MEMBRECOM	2012-12-13 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9050	\N	2014-09-28 16:59:41
10768	MEMBRECOM	2012-12-13 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9055	\N	\N
10769	MEMBRECOM	2012-12-13 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9056	\N	\N
10789	MEMBRECOM	2012-12-13 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9076	\N	\N
10790	MEMBRECOM	2012-12-13 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9077	\N	\N
10792	MEMBRECOM	2012-12-13 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9079	\N	\N
10795	MEMBRECOM	2012-12-13 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9082	\N	\N
10796	MEMBRECOM	2012-12-13 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9083	\N	\N
10797	MEMBRECOM	2012-12-13 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9084	\N	\N
10798	MEMBRECOM	2012-12-13 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9085	\N	2014-09-28 17:34:16
10799	MEMBRECOM	2012-12-13 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9086	\N	2014-09-28 13:40:33
10804	VICPDTCOM	2012-12-18 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9091	\N	2014-09-28 17:27:35
10802	RAPCOM	2012-12-18 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9089	\N	2017-09-24 17:09:24
10787	VICPDTCOM	2012-12-13 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9074	\N	\N
10788	RAPCOM	2012-12-13 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9075	\N	2017-09-24 13:42:35
10805	MEMBRECOM	2012-12-18 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9092	\N	2014-09-28 12:39:09
10806	MEMBRECOM	2012-12-18 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9093	\N	2017-09-24 13:57:40
10807	MEMBRECOM	2012-12-18 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9094	\N	\N
10808	MEMBRECOM	2012-12-18 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9095	\N	2014-09-28 16:40:50
10809	MEMBRECOM	2012-12-18 00:00:00	2020-06-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9096	\N	\N
10810	MEMBRECOM	2012-12-18 00:00:00	2015-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9097	\N	2015-03-03 10:16:55
10812	MEMBRECOM	2012-12-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9099	\N	\N
10813	MEMBRECOM	2012-12-18 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9100	\N	2017-10-01 10:01:39
10814	MEMBRECOM	2012-12-18 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9101	\N	\N
10815	MEMBRECOM	2012-12-18 00:00:00	2016-11-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9102	\N	2016-12-01 10:36:51
10817	RAPCOM	2012-12-15 00:00:00	2017-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9104	\N	2017-09-25 09:56:00
10818	MEMBRECOM	2012-12-15 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9105	\N	2017-09-24 18:20:10
10820	MEMBRECOM	2012-12-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9107	\N	\N
10822	MEMBRECOM	2012-12-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9109	\N	\N
10823	MEMBRECOM	2012-12-15 00:00:00	2016-12-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9110	\N	2016-12-12 16:10:15
10824	MEMBRECOM	2012-12-15 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9111	\N	\N
10825	MEMBRECOM	2012-12-15 00:00:00	2013-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9112	\N	\N
10826	MEMBRECOM	2012-12-15 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9113	\N	\N
10510	MEMBRECOM	2012-06-17 00:00:00	2014-05-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8820	\N	2014-05-05 10:34:09
10543	VICPDTCOM	2012-07-25 00:00:00	2014-10-07 00:00:00	3	ANCIEN	\N	\N	\N	\N	8688	\N	2014-10-08 17:05:06
12457	MEMBRECOM	2014-04-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10405	\N	\N
10544	SECRETCOM	2012-07-25 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8732	\N	2014-09-28 17:27:35
10567	MEMBRECOM	2012-07-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8869	\N	\N
10684	PDTCOM	2012-11-20 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8971	\N	2017-09-24 17:35:15
10689	MEMBRECOM	2012-11-20 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8976	\N	\N
10693	MEMBRECOM	2012-11-20 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8980	\N	2014-09-28 17:34:16
10694	MEMBRECOM	2012-11-20 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8981	\N	\N
10696	MEMBRECOM	2012-11-20 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	8983	\N	\N
10698	MEMBRECOM	2012-12-03 00:00:00	2012-12-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8985	\N	\N
10834	MEMBRECOM	2013-02-13 00:00:00	2013-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9121	\N	\N
11065	PDTCOM	2013-03-27 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9240	\N	2013-12-16 10:28:45
11066	RAPCOM	2013-03-27 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9216	\N	2013-12-16 10:28:45
11067	VICPDTCOM	2013-03-27 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9231	\N	2013-12-16 10:28:45
11068	VICPDTCOM	2013-03-27 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9235	\N	2013-12-16 10:28:45
11069	VICPDTCOM	2013-03-27 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9222	\N	2013-12-16 10:28:45
11070	VICPDTCOM	2013-03-27 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9349	\N	2013-12-16 10:28:45
11081	MEMBRECOM	2013-01-16 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9355	2013-06-03 11:57:40	2014-11-19 17:50:38
11084	VICPDTCOM	2013-05-14 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9328	\N	2014-04-14 14:28:41
11085	VICPDTCOM	2013-05-14 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9335	\N	2014-04-14 14:28:41
11086	VICPDTCOM	2013-05-14 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9329	\N	2014-04-14 14:28:41
11087	VICPDTCOM	2013-05-14 00:00:00	2013-10-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9327	\N	2014-04-14 14:28:41
11088	PDTCOM	2013-03-27 00:00:00	2013-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9164	\N	\N
11089	RAPCOM	2013-03-27 00:00:00	2013-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9174	\N	\N
11090	VICPDTCOM	2013-03-27 00:00:00	2013-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9161	\N	\N
11091	VICPDTCOM	2013-03-27 00:00:00	2013-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9163	\N	\N
11092	VICPDTCOM	2013-03-27 00:00:00	2013-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9169	\N	\N
11093	VICPDTCOM	2013-03-27 00:00:00	2013-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9173	\N	\N
11094	VICPDTCOM	2013-03-27 00:00:00	2013-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9175	\N	\N
11095	VICPDTCOM	2013-03-27 00:00:00	2013-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9177	\N	\N
11096	VICPDTCOM	2013-03-27 00:00:00	2013-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9178	\N	\N
11097	VICPDTCOM	2013-03-27 00:00:00	2013-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9181	\N	\N
11099	PDTCOM	2013-02-27 00:00:00	2013-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9150	\N	\N
11100	VICPDTCOM	2013-02-27 00:00:00	2013-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9149	\N	\N
11101	VICPDTCOM	2013-02-27 00:00:00	2013-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9145	\N	\N
11102	VICPDTCOM	2013-02-27 00:00:00	2013-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9134	\N	\N
11103	VICPDTCOM	2013-02-27 00:00:00	2013-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9135	\N	\N
11104	VICPDTCOM	2013-02-27 00:00:00	2013-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9142	\N	\N
11105	VICPDTCOM	2013-02-27 00:00:00	2013-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9154	\N	\N
11106	RAPCOM	2013-02-27 00:00:00	2013-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9140	\N	\N
11108	MEMBRECOM	2013-06-29 00:00:00	2013-07-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9357	2013-07-01 09:35:52	2013-07-09 10:44:46
11109	MEMBRECOM	2013-07-09 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9358	2013-07-09 10:45:02	2014-09-28 17:14:21
11119	MEMBRECOM	2013-10-01 00:00:00	2013-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9363	2013-10-01 15:26:12	2013-10-09 16:53:18
11112	MEMBRECOM	2013-07-15 00:00:00	2013-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9360	2013-07-15 18:33:30	2013-11-19 11:24:39
11113	MEMBRECOM	2013-07-15 00:00:00	2013-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9361	2013-07-15 18:34:09	2013-12-04 11:25:30
11122	MEMBRECOM	2013-10-02 00:00:00	2013-10-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9366	\N	2013-10-17 09:42:45
11123	MEMBRECOM	2013-10-02 00:00:00	2014-05-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9367	\N	2014-11-18 15:42:14
11124	MEMBRECOM	2013-10-02 00:00:00	2013-10-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9368	\N	2013-10-17 09:43:12
11125	MEMBRECOM	2013-10-02 00:00:00	2014-05-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9369	\N	2014-11-18 15:42:14
11126	MEMBRECOM	2013-10-02 00:00:00	2014-05-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9370	\N	2014-11-18 15:42:14
11127	MEMBRECOM	2013-10-02 00:00:00	2014-05-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9371	\N	2014-11-18 15:42:14
11128	MEMBRECOM	2013-10-02 00:00:00	2014-05-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9372	\N	2014-11-18 15:42:14
11129	MEMBRECOM	2013-10-02 00:00:00	2013-10-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9373	\N	2013-10-17 09:43:34
11130	MEMBRECOM	2013-10-02 00:00:00	2014-05-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9374	\N	2014-11-18 15:42:14
11131	MEMBRECOM	2013-10-02 00:00:00	2014-05-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9375	\N	2014-11-18 15:42:14
11132	MEMBRECOM	2013-10-02 00:00:00	2013-10-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9376	\N	2013-10-17 09:44:15
11133	MEMBRECOM	2013-10-02 00:00:00	2013-10-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9377	\N	2013-10-17 09:43:56
11134	MEMBRECOM	2013-10-02 00:00:00	2014-05-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9378	\N	2014-11-18 15:42:14
11135	MEMBRECOM	2013-10-02 00:00:00	2014-05-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9379	\N	2014-11-18 15:42:14
11136	MEMBRECOM	2013-10-02 00:00:00	2014-05-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9380	\N	2014-11-18 15:42:14
11137	MEMBRECOM	2013-10-02 00:00:00	2013-10-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9381	\N	2013-10-17 09:44:35
11138	MEMBRECOM	2013-10-02 00:00:00	2014-05-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9382	\N	2014-11-18 15:42:14
11139	MEMBRECOM	2013-10-02 00:00:00	2013-10-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9383	\N	2013-10-17 09:42:11
11140	MEMBRECOM	2013-10-02 00:00:00	2014-05-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9384	\N	2014-11-18 15:42:14
11141	MEMBRECOM	2013-10-02 00:00:00	2014-05-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9385	\N	2014-11-18 15:42:14
11142	MEMBRECOM	2013-10-02 00:00:00	2014-05-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9386	\N	2014-11-18 15:42:14
11143	MEMBRECOM	2013-10-02 00:00:00	2014-05-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9387	\N	2014-11-18 15:42:14
11144	MEMBRECOM	2013-10-02 00:00:00	2014-05-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9388	\N	2014-11-18 15:42:14
11145	MEMBRECOM	2013-10-02 00:00:00	2013-10-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9389	\N	2013-10-17 09:41:46
11146	MEMBRECOM	2013-10-02 00:00:00	2014-05-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9390	\N	2014-11-18 15:42:14
11147	MEMBRECOM	2013-10-02 00:00:00	2013-10-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9391	\N	2013-10-17 09:44:54
11148	MEMBRECOM	2013-10-02 00:00:00	2014-05-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9392	\N	2014-11-18 15:42:14
11165	RAPCOM	2013-04-17 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9409	\N	2014-09-28 17:22:11
11166	MEMBRECOM	2013-04-17 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9410	\N	2014-09-28 17:07:41
11168	MEMBRECOM	2013-04-17 00:00:00	2018-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9412	\N	\N
11170	MEMBRECOM	2013-04-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9414	\N	\N
11171	MEMBRECOM	2013-04-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9415	\N	\N
11175	MEMBRECOM	2013-04-17 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9419	\N	2017-09-24 17:47:27
11177	MEMBRECOM	2013-04-17 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9421	\N	2014-09-28 17:38:26
11178	MEMBRECOM	2013-04-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9422	\N	\N
11179	VICPDTCOM	2013-05-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9423	\N	\N
11180	RAPCOM	2013-05-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9424	\N	\N
11181	MEMBRECOM	2013-05-16 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9425	\N	2017-09-24 18:17:56
11182	MEMBRECOM	2013-05-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9426	\N	\N
11187	MEMBRECOM	2013-05-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9431	\N	\N
11188	MEMBRECOM	2013-05-16 00:00:00	2014-05-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9432	\N	2014-05-05 10:34:09
11189	MEMBRECOM	2013-05-16 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9433	\N	2014-09-28 13:40:33
11190	MEMBRECOM	2013-05-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9434	\N	\N
11191	MEMBRECOM	2013-05-16 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9435	\N	\N
11405	MEMBRECOM	2013-10-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9510	2013-10-30 16:28:37	2014-11-18 15:41:31
11406	VICPDTCOM	2013-01-23 00:00:00	2014-05-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8845	2013-10-30 18:24:24	2014-05-05 10:35:23
11407	RAPCOM	2013-10-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9641	\N	\N
11408	PDTCOM	2013-10-16 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9642	\N	2014-09-28 13:40:33
11409	MEMBRECOM	2013-10-16 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9643	\N	2014-09-28 17:34:16
11410	MEMBRECOM	2013-10-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9644	\N	\N
11411	MEMBRECOM	2013-10-16 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9645	\N	2017-09-24 17:15:15
11412	MEMBRECOM	2013-10-16 00:00:00	2015-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9646	\N	2015-10-13 14:22:34
11413	MEMBRECOM	2013-10-16 00:00:00	2014-04-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9647	\N	2014-04-23 09:56:25
11414	MEMBRECOM	2013-10-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9648	\N	\N
11415	MEMBRECOM	2013-10-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9649	\N	\N
11416	MEMBRECOM	2013-10-16 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9650	\N	\N
11417	MEMBRECOM	2013-10-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9651	\N	\N
11418	MEMBRECOM	2013-10-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9652	\N	\N
11419	MEMBRECOM	2013-10-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9653	\N	\N
11420	MEMBRECOM	2013-10-16 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9654	\N	2017-09-24 17:47:27
11421	RAPCOM	2013-10-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9655	\N	\N
11422	PDTCOM	2013-10-22 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9656	\N	2014-09-28 13:40:33
11423	MEMBRECOM	2013-10-22 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9657	\N	2014-09-28 17:34:16
11424	MEMBRECOM	2013-10-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9658	\N	\N
11425	MEMBRECOM	2013-10-22 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9659	\N	2017-09-24 17:15:15
11427	MEMBRECOM	2013-10-22 00:00:00	2014-04-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9661	\N	2014-04-23 09:56:25
11428	MEMBRECOM	2013-10-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9662	\N	\N
11429	MEMBRECOM	2013-10-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9663	\N	\N
11430	MEMBRECOM	2013-10-22 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9664	\N	\N
11431	MEMBRECOM	2013-10-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9665	\N	\N
11432	MEMBRECOM	2013-10-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9666	\N	\N
11433	MEMBRECOM	2013-10-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9667	\N	\N
11434	MEMBRECOM	2013-10-22 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9668	\N	2017-09-24 17:47:27
11435	PDTCOM	2013-11-06 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9540	2013-11-06 17:24:51	2014-11-18 15:41:31
11436	RAPCOM	2013-11-06 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9512	2013-11-06 17:25:18	2014-11-18 15:41:31
11437	VICPDTCOM	2013-11-06 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9515	2013-11-06 17:25:50	2014-09-28 16:40:50
11438	VICPDTCOM	2013-11-06 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9519	2013-11-06 17:26:10	2014-09-28 19:03:23
11439	VICPDTCOM	2013-11-06 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9520	2013-11-06 17:26:32	2014-11-18 15:41:31
11441	VICPDTCOM	2013-11-06 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9528	2013-11-06 17:27:18	2014-11-18 15:41:31
11442	VICPDTCOM	2013-11-06 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9529	2013-11-06 17:27:44	2014-11-18 15:41:31
11445	RAPCOM	2013-11-05 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9670	\N	2014-09-28 17:07:41
11446	MEMBRECOM	2013-11-05 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9671	\N	2017-09-24 13:44:49
11448	MEMBRECOM	2013-11-05 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9673	\N	2014-09-28 13:19:48
11449	MEMBRECOM	2013-11-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9674	\N	\N
11450	MEMBRECOM	2013-11-05 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9675	\N	2014-09-28 17:34:16
11452	MEMBRECOM	2013-11-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9677	\N	\N
11453	MEMBRECOM	2013-11-05 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9678	\N	2017-09-24 17:42:25
11454	MEMBRECOM	2013-11-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9679	\N	\N
11456	MEMBRECOM	2013-11-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9681	\N	\N
11457	MEMBRECOM	2013-11-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9682	\N	\N
11458	MEMBRECOM	2013-11-19 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9683	2013-11-19 11:20:41	2014-10-08 17:03:08
11459	MEMBRECOM	2013-11-19 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9684	2013-11-19 11:24:56	2014-09-28 13:19:48
11460	MEMBRECOM	2013-11-19 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9685	2013-11-19 18:42:28	2014-11-18 11:50:10
11461	MEMBRECOM	2013-11-19 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9686	2013-11-19 18:42:35	2014-11-18 11:50:10
11463	MEMBRECOM	2013-11-19 00:00:00	2013-12-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9688	2013-11-19 18:42:52	2013-12-19 18:30:57
11464	MEMBRECOM	2013-11-19 00:00:00	2013-12-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9689	2013-11-19 18:42:59	2013-12-19 18:31:30
11465	MEMBRECOM	2013-11-19 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9690	2013-11-19 18:43:06	2014-11-18 11:50:10
11466	MEMBRECOM	2013-11-19 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9691	2013-11-19 18:43:13	2014-11-18 11:50:10
12408	MEMBRECOM	2014-01-29 00:00:00	2018-12-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10356	\N	\N
11468	MEMBRECOM	2013-11-19 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9693	2013-11-19 18:43:31	2014-11-18 11:50:10
11469	MEMBRECOM	2013-11-19 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9694	2013-11-19 18:43:39	2014-11-18 11:50:10
11471	MEMBRECOM	2013-11-19 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9696	2013-11-19 18:43:54	2014-11-18 11:50:10
11472	MEMBRECOM	2013-11-19 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9697	2013-11-19 18:44:00	2014-11-18 11:50:10
11474	MEMBRECOM	2013-11-19 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9700	2013-11-19 18:44:24	2014-11-18 11:50:10
11475	MEMBRECOM	2013-11-19 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9701	2013-11-19 18:44:31	2014-11-18 11:50:10
11477	MEMBRECOM	2013-11-19 00:00:00	2013-12-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9703	2013-11-19 18:44:44	2013-12-19 18:32:24
11478	MEMBRECOM	2013-11-19 00:00:00	2013-12-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9704	2013-11-19 18:44:52	2013-12-19 18:30:00
11480	MEMBRECOM	2013-11-19 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9706	2013-11-19 18:45:04	2014-11-18 11:50:10
11481	MEMBRECOM	2013-11-19 00:00:00	2013-12-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9707	2013-11-19 18:45:10	2013-12-19 18:32:50
11482	MEMBRECOM	2013-11-19 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9708	2013-11-19 18:45:17	2014-11-18 11:50:10
11484	MEMBRECOM	2013-11-19 00:00:00	2013-12-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9710	2013-11-19 18:45:33	2013-12-19 18:33:14
11485	MEMBRECOM	2013-11-19 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9711	2013-11-19 18:45:40	2014-11-18 11:50:10
11486	MEMBRECOM	2013-11-19 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9712	2013-11-19 18:45:47	2014-11-18 11:50:10
11488	MEMBRECOM	2013-11-19 00:00:00	2013-12-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9714	2013-11-19 18:46:02	2013-12-19 18:30:28
11489	MEMBRECOM	2013-11-19 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9715	2013-11-19 18:46:09	2014-09-28 17:27:35
11490	MEMBRECOM	2013-11-19 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9716	2013-11-19 18:46:16	2014-11-18 11:50:10
11491	MEMBRECOM	2013-11-19 00:00:00	2013-12-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9717	2013-11-19 18:46:23	2013-12-19 18:33:40
11492	MEMBRECOM	2013-11-19 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9698	2013-11-19 18:46:41	2014-11-18 11:50:10
11493	MEMBRECOM	2013-11-26 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8717	2013-11-27 14:35:32	2014-10-08 17:10:29
11495	PDTCOM	2013-11-18 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9719	\N	2014-09-28 17:34:16
11496	RAPCOM	2013-11-18 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9720	\N	\N
11497	MEMBRECOM	2013-11-18 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9721	\N	2017-09-24 17:47:28
11498	MEMBRECOM	2013-11-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9722	\N	\N
11499	MEMBRECOM	2013-11-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9723	\N	\N
11500	MEMBRECOM	2013-11-18 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9724	\N	2017-09-24 19:25:10
11501	MEMBRECOM	2013-11-18 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9725	\N	2014-09-28 17:07:41
11503	MEMBRECOM	2013-11-18 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9727	\N	2014-09-28 17:38:26
11505	MEMBRECOM	2013-11-18 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9729	\N	2017-09-24 16:45:26
11506	MEMBRECOM	2013-11-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9730	\N	\N
11507	MEMBRECOM	2013-11-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9731	\N	\N
11508	MEMBRECOM	2013-11-18 00:00:00	2014-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9732	\N	\N
11509	RAPGENCOM	2013-11-29 00:00:00	2017-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9733	\N	2017-09-25 09:56:00
11510	VICPDTCOM	2013-11-29 00:00:00	2015-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9734	\N	2015-01-08 17:14:29
11511	MEMBRECOM	2013-11-29 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9735	\N	\N
11513	MEMBRECOM	2013-11-29 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9737	\N	\N
11514	MEMBRECOM	2013-11-29 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9738	\N	\N
11515	MEMBRECOM	2013-11-29 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9739	\N	\N
11516	MEMBRECOM	2013-11-29 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9740	\N	\N
11519	MEMBRECOM	2013-11-29 00:00:00	2015-04-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9743	\N	2015-04-07 16:50:27
11520	MEMBRECOM	2013-11-29 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9744	\N	2014-09-28 18:03:38
11521	MEMBRECOM	2013-11-29 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9745	\N	\N
11522	MEMBRECOM	2013-11-29 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9746	\N	\N
11524	MEMBRECOM	2013-12-10 00:00:00	2013-12-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9748	2013-12-10 15:07:06	2013-12-18 16:59:05
11526	MEMBRECOM	2013-12-10 00:00:00	2013-12-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9750	2013-12-10 15:07:35	2013-12-18 16:55:18
11527	MEMBRECOM	2013-12-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9751	2013-12-10 15:07:44	2014-11-18 15:39:16
11528	MEMBRECOM	2013-12-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9752	2013-12-10 15:07:53	2014-09-28 17:31:42
11529	MEMBRECOM	2013-12-10 00:00:00	2013-12-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9753	2013-12-10 15:08:06	2013-12-18 16:58:15
11530	MEMBRECOM	2013-12-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9754	2013-12-10 15:08:25	2014-11-18 15:39:16
11532	MEMBRECOM	2013-12-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9756	2013-12-10 15:11:20	2014-11-18 15:39:16
11534	MEMBRECOM	2013-12-10 00:00:00	2013-12-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9758	2013-12-10 15:12:33	2013-12-18 17:02:41
11673	MEMBRECOM	2014-01-23 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9879	2014-01-23 11:50:49	2014-09-28 16:40:50
11688	MEMBRECOM	2014-02-14 00:00:00	2014-02-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9880	2014-02-14 15:15:52	2014-02-21 11:15:00
11715	MEMBRECOM	2014-02-25 00:00:00	2014-03-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9907	2014-02-25 17:21:05	2014-03-11 13:44:08
11716	MEMBRECOM	2014-02-25 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9908	2014-02-25 17:21:28	2014-11-18 15:38:05
11717	MEMBRECOM	2014-02-25 00:00:00	2014-03-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9909	2014-02-25 17:23:47	2014-03-11 13:43:31
11718	MEMBRECOM	2014-02-25 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9910	2014-02-25 17:24:01	2014-11-18 15:38:05
11719	MEMBRECOM	2014-02-25 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9911	2014-02-25 17:24:27	2014-11-18 15:38:05
11720	MEMBRECOM	2014-02-25 00:00:00	2014-03-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9912	2014-02-25 17:24:50	2014-03-11 13:46:25
11721	MEMBRECOM	2014-02-25 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9913	2014-02-25 17:25:03	2014-09-28 17:27:35
11722	MEMBRECOM	2014-02-25 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9914	2014-02-25 17:25:15	2014-11-18 15:38:05
11759	MEMBRECOM	2014-06-18 00:00:00	2014-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9941	2014-06-18 22:21:50	2014-06-23 18:24:10
11760	MEMBRECOM	2014-06-18 00:00:00	2015-01-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9943	2014-06-19 09:33:50	2015-04-07 18:21:18
11761	MEMBRECOM	2014-06-18 00:00:00	2014-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9944	2014-06-19 09:33:57	2014-06-23 18:32:54
11762	MEMBRECOM	2014-06-18 00:00:00	2015-01-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9945	2014-06-19 09:34:08	2015-04-07 18:21:18
11763	MEMBRECOM	2014-06-18 00:00:00	2014-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9946	2014-06-19 09:34:16	2014-06-23 18:22:57
11764	MEMBRECOM	2014-06-18 00:00:00	2015-01-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9947	2014-06-19 09:34:23	2015-04-07 18:21:18
11765	MEMBRECOM	2014-06-18 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9948	2014-06-19 09:34:29	2014-10-09 16:15:58
11766	MEMBRECOM	2014-06-18 00:00:00	2014-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9949	2014-06-19 09:34:41	2014-06-23 18:33:52
11767	MEMBRECOM	2014-06-18 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9950	2014-06-19 09:34:48	2014-10-09 17:23:33
11768	MEMBRECOM	2014-06-18 00:00:00	2015-01-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9951	2014-06-19 09:34:55	2015-04-07 18:21:18
11769	MEMBRECOM	2014-06-18 00:00:00	2015-01-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9952	2014-06-19 09:35:00	2015-04-07 18:21:18
11770	MEMBRECOM	2014-06-18 00:00:00	2015-01-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9953	2014-06-19 09:35:09	2015-04-07 18:21:18
11771	MEMBRECOM	2014-06-18 00:00:00	2014-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9954	2014-06-19 09:35:16	2014-06-23 18:26:11
11772	MEMBRECOM	2014-06-18 00:00:00	2015-01-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9955	2014-06-19 09:35:23	2015-04-07 18:21:18
11776	MEMBRECOM	2014-06-18 00:00:00	2015-01-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9959	2014-06-19 10:57:56	2015-04-07 18:21:18
11777	MEMBRECOM	2014-06-18 00:00:00	2014-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9960	2014-06-19 11:02:46	2014-06-23 18:24:33
11778	MEMBRECOM	2014-06-18 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9961	2014-06-19 11:02:56	2014-09-28 17:38:26
11779	MEMBRECOM	2014-06-18 00:00:00	2014-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9962	2014-06-19 11:03:04	2014-06-23 18:26:33
11816	MEMBRECOM	2014-07-16 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9984	2014-07-16 17:22:41	2017-10-04 18:50:07
11823	MEMBRECOM	2014-09-29 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9991	2014-09-28 12:34:20	2014-10-20 10:49:48
11782	MEMBRECOM	2014-06-18 00:00:00	2014-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9965	2014-06-19 11:03:27	2014-06-23 18:25:10
11890	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10058	2014-09-28 18:47:00	2014-10-08 17:12:24
11784	MEMBRECOM	2014-06-18 00:00:00	2014-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9967	2014-06-19 11:08:35	2014-06-23 18:26:53
11785	MEMBRECOM	2014-06-18 00:00:00	2014-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9968	2014-06-19 11:08:41	2014-06-23 18:34:27
11786	MEMBRECOM	2014-06-18 00:00:00	2015-01-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9969	2014-06-19 11:09:40	2015-04-07 18:21:18
11787	MEMBRECOM	2014-06-18 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9970	2014-06-19 11:09:48	2014-09-28 17:34:16
11788	MEMBRECOM	2014-06-18 00:00:00	2014-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9971	2014-06-19 11:09:55	2014-06-23 18:33:18
11789	MEMBRECOM	2014-06-18 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9972	2014-06-19 11:10:04	2014-10-09 15:22:33
11790	MEMBRECOM	2014-06-18 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9973	2014-06-19 11:10:10	2014-10-09 16:15:34
11791	MEMBRECOM	2014-06-18 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9974	2014-06-19 11:10:19	2014-10-09 16:09:56
11792	MEMBRECOM	2014-06-18 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9975	2014-06-19 11:10:27	2014-10-09 17:22:09
11793	MEMBRECOM	2014-06-18 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9976	2014-06-19 11:10:34	2014-10-09 16:16:44
11794	MEMBRECOM	2014-06-18 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9977	2014-06-19 11:10:47	2014-09-28 13:40:33
11795	MEMBRECOM	2014-06-18 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9978	2014-06-19 11:10:55	2014-10-09 16:17:17
11891	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10059	2014-09-28 18:58:20	2014-10-08 17:05:53
11911	MEMBRECOM	2014-10-03 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10079	2014-10-03 00:00:00	\N
11973	MEMBRECOM	2014-10-08 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10141	2014-10-08 17:03:58	2017-10-04 19:14:09
11974	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10142	2014-10-08 17:04:12	2014-10-09 13:52:41
11975	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10143	2014-10-08 17:04:20	2014-10-09 13:51:54
11976	MEMBRECOM	2014-10-08 00:00:00	2015-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10144	2014-10-08 17:05:05	2015-07-10 11:24:50
11978	MEMBRECOM	2014-10-08 00:00:00	2015-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10146	2014-10-08 17:05:34	2015-03-03 10:16:55
11979	MEMBRECOM	2014-10-08 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10147	2014-10-08 17:05:52	2017-10-04 18:48:59
9842	SECRETCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	276	\N	2014-10-08 17:06:19
11982	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10150	2014-10-08 17:07:01	2014-10-09 12:15:14
11983	MEMBRECOM	2014-10-08 00:00:00	2017-08-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10151	2014-10-08 17:07:11	2017-08-07 16:31:39
11984	MEMBRECOM	2014-10-08 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10152	2014-10-08 17:08:18	\N
11985	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10153	2014-10-08 17:09:11	2014-10-09 11:52:03
11986	MEMBRECOM	2014-10-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10154	2014-10-08 17:09:39	2017-09-24 18:49:56
11989	MEMBRECOM	2014-10-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10157	2014-10-08 17:10:28	2017-09-24 18:17:56
11990	MEMBRECOM	2014-10-08 00:00:00	2017-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10158	2014-10-08 17:11:41	2017-06-19 16:06:01
11991	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10159	2014-10-08 17:11:49	2014-10-09 11:06:13
11992	MEMBRECOM	2014-10-08 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10160	2014-10-08 17:12:16	\N
11993	MEMBRECOM	2014-10-08 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10161	2014-10-08 17:12:22	2017-10-05 14:26:40
11994	MEMBRECOM	2014-10-08 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10162	2014-10-08 17:12:38	2017-10-05 14:29:56
11996	MEMBRECOM	2014-10-08 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10164	2014-10-08 00:00:00	\N
11998	MEMBRECOM	2014-10-08 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10166	2014-10-08 17:18:36	2017-10-05 14:26:50
11999	MEMBRECOM	2014-10-08 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10167	2014-10-08 00:00:00	\N
12001	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10169	2014-10-08 17:24:14	2014-10-09 12:14:52
12411	MEMBRECOM	2014-01-29 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10359	\N	\N
12002	MEMBRECOM	2014-10-08 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10170	2014-10-08 17:24:39	2017-10-05 14:36:03
12003	MEMBRECOM	2014-10-08 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10171	2014-10-08 17:24:54	\N
12004	MEMBRECOM	2014-10-08 00:00:00	2014-12-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10172	2014-10-08 17:25:01	2014-12-29 15:40:09
12006	MEMBRECOM	2014-10-08 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10174	2014-10-08 17:25:26	2017-10-05 14:36:45
12007	MEMBRECOM	2014-10-08 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10175	2014-10-08 17:25:37	2017-10-05 14:36:53
12008	MEMBRECOM	2014-10-08 00:00:00	2017-07-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10176	2014-10-08 17:25:44	2017-07-24 09:58:00
12009	MEMBRECOM	2014-10-08 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10177	2014-10-08 00:00:00	\N
12010	MEMBRECOM	2014-10-08 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10178	2014-10-08 17:26:01	\N
12011	MEMBRECOM	2014-10-08 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10179	2014-10-08 17:26:08	\N
12012	MEMBRECOM	2014-10-08 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10180	2014-10-08 17:32:24	2017-10-04 19:14:29
12013	MEMBRECOM	2014-10-08 00:00:00	2017-01-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10181	2014-10-08 17:32:32	2017-01-10 17:59:57
12014	MEMBRECOM	2014-10-08 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10182	2014-10-08 17:32:39	2017-10-04 19:12:40
12015	MEMBRECOM	2014-10-08 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10183	2014-10-08 17:32:48	2017-10-01 10:34:22
12016	MEMBRECOM	2014-10-08 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10184	2014-10-08 17:32:54	2017-10-04 19:15:31
12017	MEMBRECOM	2014-10-08 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10185	2014-10-08 17:33:10	2017-10-04 18:35:48
12018	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10186	2014-10-08 17:33:27	2014-10-09 13:52:22
12021	MEMBRECOM	2014-10-08 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10189	2014-10-08 17:33:52	2017-10-04 18:35:52
12022	MEMBRECOM	2014-10-08 00:00:00	2015-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10190	2014-10-08 17:34:15	2015-01-08 17:14:29
12024	MEMBRECOM	2014-10-08 00:00:00	2015-02-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10192	2014-10-08 17:35:18	2015-02-16 17:25:25
12025	MEMBRECOM	2014-10-08 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10193	2014-10-08 17:35:29	2017-10-04 18:35:58
10390	SECRETCOM	2012-02-21 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8742	\N	2014-10-08 17:35:30
11536	MEMBRECOM	2013-12-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9760	2013-12-10 15:12:58	2014-11-18 15:39:56
11537	MEMBRECOM	2013-12-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9761	2013-12-10 15:13:08	2014-11-18 15:39:56
11538	MEMBRECOM	2013-12-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9762	2013-12-10 15:13:14	2014-11-18 15:39:56
11539	MEMBRECOM	2013-12-10 00:00:00	2013-12-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9763	2013-12-10 15:13:22	2013-12-18 17:02:19
11540	MEMBRECOM	2013-12-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9764	2013-12-10 15:13:30	2014-09-28 17:03:41
11541	MEMBRECOM	2013-12-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9765	2013-12-10 15:13:39	2014-09-28 16:42:05
11542	MEMBRECOM	2013-12-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9766	2013-12-10 15:13:47	2014-09-28 18:00:58
11544	MEMBRECOM	2013-12-10 00:00:00	2013-12-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9768	2013-12-10 15:14:02	2013-12-18 17:00:47
11545	MEMBRECOM	2013-12-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9769	2013-12-10 15:14:11	2014-11-18 15:39:56
11546	MEMBRECOM	2013-12-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9770	2013-12-10 15:14:19	2014-11-18 15:39:56
11547	MEMBRECOM	2013-12-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9771	2013-12-10 15:14:28	2014-09-28 17:31:41
11567	MEMBRECOM	2013-12-10 00:00:00	2013-12-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9791	2013-12-10 17:25:51	2013-12-18 16:58:40
11568	MEMBRECOM	2013-12-10 00:00:00	2013-12-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9792	2013-12-10 17:26:49	2013-12-18 17:03:03
11598	PDTCOM	2013-12-04 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9704	2013-12-19 18:30:02	2014-11-18 11:50:10
11599	RAPCOM	2013-12-04 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9714	2013-12-19 18:30:29	2014-11-18 11:50:10
11600	VICPDTCOM	2013-12-04 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9688	2013-12-19 18:30:58	2014-11-18 11:50:10
11601	VICPDTCOM	2013-12-04 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9689	2013-12-19 18:31:32	2014-11-18 11:50:10
11602	VICPDTCOM	2013-12-04 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9703	2013-12-19 18:32:25	2014-11-18 11:50:10
11603	VICPDTCOM	2013-12-04 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9707	2013-12-19 18:32:51	2014-11-18 11:50:10
11604	VICPDTCOM	2013-12-04 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9710	2013-12-19 18:33:14	2014-11-18 11:50:10
11605	VICPDTCOM	2013-12-04 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9717	2013-12-19 18:33:41	2014-11-18 11:50:10
11607	MEMBRECOM	2013-12-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9812	\N	\N
11609	MEMBRECOM	2013-12-16 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9814	\N	2017-09-24 17:55:12
11611	MEMBRECOM	2013-12-16 00:00:00	2014-04-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9816	\N	2014-04-23 09:56:25
11612	PDTCOM	2013-12-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9817	\N	\N
11615	MEMBRECOM	2013-12-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9820	\N	\N
11616	MEMBRECOM	2013-12-16 00:00:00	2015-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9821	\N	2015-03-03 10:16:55
11617	MEMBRECOM	2013-12-16 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9822	\N	2017-09-24 17:06:55
11618	MEMBRECOM	2013-12-16 00:00:00	2014-05-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9823	\N	2014-05-05 10:34:09
11619	MEMBRECOM	2013-12-16 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9824	\N	\N
11690	MEMBRECOM	2014-02-25 00:00:00	2014-03-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9882	2014-02-25 16:14:01	2014-03-11 13:45:31
11691	MEMBRECOM	2014-02-25 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9883	2014-02-25 16:14:13	2014-11-18 15:38:05
11692	MEMBRECOM	2014-02-25 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9884	2014-02-25 16:14:35	2014-11-18 15:38:05
11693	MEMBRECOM	2014-02-25 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9885	2014-02-25 16:14:54	2014-11-18 15:38:05
11694	MEMBRECOM	2014-02-25 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9886	2014-02-25 16:15:04	2014-09-28 17:31:42
11695	MEMBRECOM	2014-02-25 00:00:00	2014-03-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9887	2014-02-25 16:15:11	2014-03-11 13:43:08
11696	MEMBRECOM	2014-02-25 00:00:00	2014-03-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9888	2014-02-25 16:15:21	2014-03-11 13:46:02
11697	MEMBRECOM	2014-02-25 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9889	2014-02-25 16:16:01	2014-11-18 15:38:05
12413	MEMBRECOM	2014-01-29 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10361	\N	\N
11698	MEMBRECOM	2014-02-25 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9891	2014-02-25 16:16:48	2014-09-28 16:59:41
11699	MEMBRECOM	2014-02-25 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9892	2014-02-25 16:16:58	2014-11-18 15:38:05
11700	MEMBRECOM	2014-02-25 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9893	2014-02-25 16:17:08	2014-11-18 15:38:05
11834	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10002	2014-09-28 16:42:03	2014-10-08 16:52:28
11835	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10003	2014-09-28 16:42:03	2014-10-08 17:32:34
11836	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10004	2014-09-28 16:49:55	2014-10-08 17:32:40
11837	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10005	2014-09-28 16:49:55	2014-10-08 17:03:59
9428	RAPCOM	2011-07-01 00:00:00	2014-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7916	\N	2014-09-29 13:41:53
9388	MEMBRECOM	2011-06-27 00:00:00	2014-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7876	\N	2014-09-29 13:43:10
12028	MEMBRECOM	2014-10-08 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10196	2014-10-08 17:37:15	2017-10-04 18:38:41
12029	MEMBRECOM	2014-10-08 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10197	2014-10-08 17:37:21	2017-10-04 19:11:13
12030	MEMBRECOM	2014-10-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10198	2014-10-08 17:37:33	2017-09-24 18:59:59
12031	MEMBRECOM	2014-10-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10199	2014-10-08 17:38:04	2017-09-24 18:16:52
9744	VICPDTCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	170	\N	2014-10-08 17:38:04
12032	MEMBRECOM	2014-10-08 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10200	2014-10-08 17:38:11	2017-10-04 19:11:34
12033	MEMBRECOM	2014-10-08 00:00:00	2017-06-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10201	2014-10-08 17:38:18	2017-06-20 15:53:49
12034	MEMBRECOM	2014-10-08 00:00:00	2017-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10202	2014-10-08 17:38:27	2017-07-12 14:23:08
12035	MEMBRECOM	2014-10-08 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10203	2014-10-08 17:38:48	2017-10-01 10:32:58
12036	MEMBRECOM	2014-10-08 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10204	2014-10-08 17:39:35	\N
12037	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10205	2014-10-08 17:39:46	2014-10-09 11:50:32
9622	MEMBRECOM	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8112	\N	2014-10-08 17:39:47
12038	MEMBRECOM	2014-10-08 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10206	2014-10-08 17:39:52	2017-10-05 14:31:47
12039	MEMBRECOM	2014-10-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10207	2014-10-08 17:40:08	2017-09-24 16:24:51
12040	MEMBRECOM	2014-10-08 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10208	2014-10-08 17:40:23	2017-10-05 14:33:42
12041	MEMBRECOM	2014-10-08 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10209	2014-10-08 00:00:00	2017-10-04 00:00:00
12044	MEMBRECOM	2014-10-08 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10212	2014-10-08 17:41:59	2017-10-01 10:22:23
12045	MEMBRECOM	2014-10-08 00:00:00	2017-06-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10213	2014-10-08 17:42:06	2017-06-02 10:02:57
12046	MEMBRECOM	2014-10-08 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10214	2014-10-08 00:00:00	\N
12047	MEMBRECOM	2014-10-08 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10215	2014-10-08 00:00:00	\N
12048	MEMBRECOM	2014-10-08 00:00:00	2020-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10216	2014-10-08 17:43:35	\N
12049	MEMBRECOM	2014-10-08 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10217	2014-10-08 17:43:41	\N
12050	MEMBRECOM	2014-10-08 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10218	2014-10-08 17:43:47	2017-10-05 14:36:29
12051	MEMBRECOM	2014-10-08 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10219	2014-10-08 17:43:55	2017-10-05 14:38:04
12053	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	755	2014-10-08 17:46:11	2014-10-09 10:52:01
9770	PDTCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	755	\N	2014-10-08 17:46:12
12055	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8155	2014-10-08 17:46:22	2014-10-09 10:54:30
9665	VICPDTCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	5	ANCIEN	\N	\N	\N	\N	8155	\N	2014-10-08 17:46:23
12057	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2579	2014-10-08 17:46:32	2014-10-09 10:53:34
12058	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6826	2014-10-08 17:46:37	2014-10-09 10:57:41
9843	SECRETCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	3	ANCIEN	\N	\N	\N	\N	6826	\N	2014-10-08 17:46:38
12059	MEMBRECOM	2014-10-08 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7432	2014-10-08 17:46:42	2017-10-05 14:27:13
12060	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2539	2014-10-08 17:46:47	2014-10-09 10:53:50
9837	VICPDTCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	8	ANCIEN	\N	\N	\N	\N	2539	\N	2014-10-08 17:46:48
12061	MEMBRECOM	2014-10-08 00:00:00	2015-05-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3892	2014-10-08 17:46:52	2015-05-06 17:34:47
12062	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8689	2014-10-08 17:48:13	2014-10-09 11:04:16
12063	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8696	2014-10-08 17:48:18	2014-10-09 11:05:20
12064	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8702	2014-10-08 17:48:23	2014-10-09 11:05:39
10349	VICPDTCOM	2012-02-21 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8702	\N	2014-10-08 17:48:24
12065	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8712	2014-10-08 17:48:27	2014-10-09 11:03:20
12066	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8746	2014-10-08 17:48:32	2014-10-09 11:07:07
12067	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8710	2014-10-08 17:48:36	2014-10-09 11:05:54
12068	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8694	2014-10-08 17:48:40	2014-10-09 11:05:02
11606	MEMBRECOM	2014-01-01 00:00:00	2014-01-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9811	2014-01-02 15:26:53	2014-01-07 10:46:27
11674	PDTCOM	2014-02-05 00:00:00	2016-04-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9867	2014-02-05 18:45:35	2016-07-07 18:27:49
11675	VICPDTCOM	2014-02-05 00:00:00	2016-04-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9876	2014-02-05 18:46:01	2016-07-07 18:10:08
11676	VICPDTCOM	2014-02-05 00:00:00	2016-04-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9842	2014-02-05 18:46:27	2016-07-07 18:15:08
11677	VICPDTCOM	2014-02-05 00:00:00	2016-04-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9850	2014-02-05 18:46:51	2016-07-07 18:18:24
11678	VICPDTCOM	2014-02-05 00:00:00	2016-04-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9855	2014-02-05 18:47:20	2016-07-07 18:29:04
11680	VICPDTCOM	2014-02-05 00:00:00	2014-04-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9871	2014-02-05 18:48:05	2014-04-17 09:33:35
11681	VICPDTCOM	2014-02-05 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9872	2014-02-05 18:48:25	2014-09-28 13:40:33
13608	MEMBRECOM	2015-06-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11475	\N	\N
11682	VICPDTCOM	2014-02-05 00:00:00	2016-04-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9847	2014-02-05 18:48:49	2016-07-07 18:32:45
11683	VICPDTCOM	2014-02-05 00:00:00	2015-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9861	2014-02-05 18:49:11	2015-03-24 17:51:12
11684	SECRETCOM	2014-02-05 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9848	2014-02-05 18:49:36	2014-09-28 12:56:42
11685	SECRETCOM	2014-02-05 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9870	2014-02-05 18:50:01	2014-10-09 17:32:18
11686	SECRETCOM	2014-02-05 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9857	2014-02-05 18:50:23	2014-09-28 17:58:04
11687	RAPCOM	2014-02-05 00:00:00	2014-04-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9874	2014-02-05 18:52:15	2014-04-14 16:10:05
11739	MEMBRECOM	2014-05-05 00:00:00	2014-05-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9921	2014-05-05 10:31:01	2014-05-07 12:21:03
11740	MEMBRECOM	2014-05-05 00:00:00	2014-05-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9922	2014-05-05 10:32:08	2014-05-07 09:36:43
11745	MEMBRECOM	2014-05-07 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9927	2014-05-07 09:32:54	2014-10-08 17:07:12
11746	MEMBRECOM	2014-05-07 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9928	2014-05-07 09:36:42	2014-09-28 19:03:23
11747	MEMBRECOM	2014-05-07 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9929	2014-05-07 09:37:02	2014-09-28 19:03:23
11814	MEMBRECOM	2014-07-02 00:00:00	2014-07-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9982	2014-07-02 12:07:37	2014-07-04 14:37:06
11819	MEMBRECOM	2014-08-27 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9987	2014-08-27 16:32:46	2014-10-08 17:09:40
11885	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10053	2014-09-28 18:32:19	2014-10-08 17:38:12
11887	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10055	2014-09-28 18:44:07	2014-10-08 17:06:34
11893	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10061	2014-09-28 18:59:41	2014-10-08 17:10:08
10341	VICPDTCOM	2012-02-21 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8694	\N	2014-10-08 17:48:41
12106	MEMBRECOM	2014-10-08 00:00:00	2015-12-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10221	2014-10-08 18:09:25	2015-12-16 17:18:57
12107	MEMBRECOM	2014-10-08 00:00:00	2015-12-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10222	2014-10-08 18:10:51	2015-12-16 17:18:58
12108	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10223	2014-10-08 18:11:02	2014-10-09 14:10:37
12109	MEMBRECOM	2014-10-08 00:00:00	2015-12-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10224	2014-10-08 18:11:09	2015-12-16 17:19:01
12110	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8195	2014-10-08 18:11:16	2014-10-09 14:10:32
12111	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4242	2014-10-08 18:11:19	2014-10-09 14:10:43
10634	PDTCOM	2012-10-09 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4242	\N	2014-10-08 18:11:19
12112	MEMBRECOM	2014-10-08 00:00:00	2015-12-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10225	2014-10-08 18:11:54	2015-12-16 17:18:58
12113	MEMBRECOM	2014-10-08 00:00:00	2015-12-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10226	2014-10-08 18:12:07	2015-12-16 17:18:54
12114	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	207	2014-10-08 18:13:33	2014-10-09 13:56:34
9791	VICPDTCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	207	\N	2014-10-08 18:13:33
12115	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2584	2014-10-08 18:13:36	2014-10-09 13:57:59
9702	SECRETCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2584	\N	2014-10-08 18:13:37
12116	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2594	2014-10-08 18:13:40	2014-10-09 13:57:38
12117	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8156	2014-10-08 18:13:46	2014-10-09 13:57:08
12118	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8150	2014-10-08 18:13:51	2014-10-09 13:57:27
9660	SECRETCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8150	\N	2014-10-08 18:13:52
12119	MEMBRECOM	2014-10-08 00:00:00	2016-03-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10227	2014-10-08 18:14:12	2016-03-11 18:02:50
12120	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10228	2014-10-08 18:16:46	2014-10-09 10:45:22
12127	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8747	2014-10-08 19:06:28	2014-10-09 11:53:11
12128	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8721	2014-10-08 19:06:31	2014-10-09 11:52:40
11494	VICPDTCOM	2013-11-26 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8721	2013-11-27 14:35:44	2014-10-08 19:06:32
12129	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8744	2014-10-08 19:06:35	2014-10-09 11:53:03
12130	MEMBRECOM	2014-10-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8697	2014-10-08 19:06:38	2017-09-25 10:54:33
12131	MEMBRECOM	2014-10-09 00:00:00	2014-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4433	2014-10-09 09:37:34	2014-10-13 11:49:18
12132	MEMBRECOM	2014-10-09 00:00:00	2014-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6420	2014-10-09 09:37:38	2014-10-13 11:50:49
12134	MEMBRECOM	2014-10-09 00:00:00	2014-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4408	2014-10-09 09:37:47	2014-10-13 11:48:47
12135	MEMBRECOM	2014-10-09 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8252	2014-10-09 09:37:52	2017-10-05 11:43:00
12136	MEMBRECOM	2014-10-09 00:00:00	2014-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8244	2014-10-09 09:37:55	2014-10-13 11:51:07
12137	MEMBRECOM	2014-10-09 00:00:00	2014-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6419	2014-10-09 09:38:00	2014-10-13 11:49:22
9876	SECRETCOM	2011-10-01 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6419	\N	2014-10-09 09:38:00
12141	MEMBRECOM	2014-10-09 00:00:00	2014-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4742	2014-10-09 09:38:15	2014-10-13 11:49:05
12142	MEMBRECOM	2014-10-09 00:00:00	2014-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8242	2014-10-09 09:38:20	2014-10-13 11:48:57
9860	VICPDTCOM	2011-10-01 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8242	\N	2014-10-09 09:38:20
12143	MEMBRECOM	2014-10-09 00:00:00	2014-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10230	2014-10-09 09:38:32	2014-10-13 11:50:58
12145	MEMBRECOM	2014-10-09 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10232	2014-10-09 09:39:31	2017-10-05 11:42:55
12146	MEMBRECOM	2014-10-09 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10233	2014-10-09 09:39:41	2017-10-05 11:42:55
12148	MEMBRECOM	2014-10-09 00:00:00	2015-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10235	2014-10-09 09:40:05	2015-10-13 14:19:58
12149	MEMBRECOM	2014-10-09 00:00:00	2014-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10236	2014-10-09 09:40:26	2014-10-13 11:51:19
12150	MEMBRECOM	2014-10-09 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10237	2014-10-09 09:40:34	2017-10-05 11:43:00
12151	MEMBRECOM	2014-10-09 00:00:00	2014-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10238	2014-10-09 09:40:42	2014-10-13 11:49:11
12153	MEMBRECOM	2014-10-09 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10240	2014-10-09 10:40:47	2017-10-05 11:42:57
12154	MEMBRECOM	2014-10-09 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10241	2014-10-09 10:41:01	2017-10-05 11:42:59
12156	MEMBRECOM	2014-10-09 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10243	2014-10-09 10:41:21	2017-10-05 11:42:59
12157	MEMBRECOM	2014-10-09 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10244	2014-10-09 10:41:39	2017-09-24 17:09:24
12158	MEMBRECOM	2014-10-09 00:00:00	2014-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10245	2014-10-09 10:41:50	2014-10-13 11:51:25
12159	MEMBRECOM	2014-10-09 00:00:00	2014-12-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10246	2014-10-09 10:42:07	2014-12-18 16:15:04
12160	PDTCOM	2014-10-09 00:00:00	2017-10-01 00:00:00	1	ANCIEN	\N	\N	\N	\N	4284	2014-10-09 10:43:47	2017-09-24 18:20:10
12161	VICPDTCOM	2014-10-09 00:00:00	2017-10-01 00:00:00	2	ANCIEN	\N	\N	\N	\N	2540	2014-10-09 10:44:19	2017-09-24 17:06:55
12162	VICPDTCOM	2014-10-09 00:00:00	2017-10-04 00:00:00	3	ANCIEN	\N	\N	\N	\N	262	2014-10-09 10:44:36	2017-10-05 14:56:16
12163	VICPDTCOM	2014-10-09 00:00:00	2017-10-03 00:00:00	4	ANCIEN	\N	\N	\N	\N	8004	2014-10-09 10:44:57	2017-10-04 19:11:38
12164	VICPDTCOM	2014-10-09 00:00:00	2017-10-04 00:00:00	5	ANCIEN	\N	\N	\N	\N	2820	2014-10-09 10:45:06	2017-10-05 14:57:13
12165	VICPDTCOM	2014-10-09 00:00:00	2017-09-30 00:00:00	6	ANCIEN	\N	\N	\N	\N	7433	2014-10-09 10:45:13	2017-10-01 09:41:22
12167	VICPDTCOM	2014-10-09 00:00:00	2015-04-07 00:00:00	8	ANCIEN	\N	\N	\N	\N	8062	2014-10-09 10:45:30	2015-04-07 16:50:27
12168	VICPDTCOM	2014-10-09 00:00:00	2017-10-04 00:00:00	9	ANCIEN	\N	\N	\N	\N	3633	2014-10-09 10:45:48	2017-10-05 14:58:01
9603	MEMBRECOM	2011-10-01 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8093	\N	2014-10-09 10:45:56
12170	VICPDTCOM	2014-10-09 00:00:00	2017-10-04 00:00:00	11	ANCIEN	\N	\N	\N	\N	8205	2014-10-09 10:46:04	2017-10-05 14:58:43
12171	RAPGENCOM	2014-10-09 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4318	2014-10-09 10:48:07	2017-10-04 19:11:34
12172	SECRETCOM	2014-10-09 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8005	2014-10-09 10:48:46	2017-09-24 18:05:41
12173	SECRETCOM	2014-10-09 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2597	2014-10-09 10:48:54	2017-10-04 19:11:49
12174	SECRETCOM	2014-10-09 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8191	2014-10-09 10:49:06	2017-10-04 19:11:46
12175	SECRETCOM	2014-10-09 00:00:00	2017-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	749	2014-10-09 10:49:17	2017-09-25 09:56:00
11620	PDTCOM	2013-12-09 00:00:00	2015-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9825	\N	2015-01-08 17:14:29
11621	MEMBRECOM	2013-12-09 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9826	\N	2017-09-24 18:20:10
11623	MEMBRECOM	2013-12-09 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9828	\N	2017-09-24 17:15:15
11624	MEMBRECOM	2013-12-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9829	\N	\N
11625	MEMBRECOM	2013-12-09 00:00:00	2018-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9830	\N	2018-05-31 10:52:17
11626	MEMBRECOM	2013-12-09 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9831	\N	\N
11627	MEMBRECOM	2013-12-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9832	\N	\N
11628	MEMBRECOM	2013-12-09 00:00:00	2015-04-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9833	\N	2015-04-07 16:50:27
11629	MEMBRECOM	2013-12-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9834	\N	\N
11633	MEMBRECOM	2013-12-09 00:00:00	2017-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9838	\N	2017-09-25 09:56:00
11832	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10000	2014-09-28 16:40:49	2014-10-08 16:51:17
11833	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10001	2014-09-28 16:40:49	2014-10-08 17:40:23
11838	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10006	2014-09-28 16:54:08	2014-10-08 16:47:37
11842	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10010	2014-09-28 17:00:59	2014-10-08 16:54:31
10365	MEMBRECOM	2012-02-21 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8719	\N	2014-09-28 17:00:59
11843	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10011	2014-09-28 17:03:41	2014-10-08 16:48:58
11844	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10012	2014-09-28 17:03:41	2014-10-08 17:32:50
11845	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10013	2014-09-28 17:03:41	2014-10-08 17:37:16
11848	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10016	2014-09-28 17:07:07	2014-10-08 17:33:54
11853	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10021	2014-09-28 17:09:16	2014-10-08 17:39:36
11854	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10022	2014-09-28 17:09:16	2014-10-08 17:03:36
10356	MEMBRECOM	2012-02-21 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8709	\N	2014-09-28 17:09:16
11870	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10038	2014-09-28 17:35:38	2014-10-08 16:53:24
11871	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10039	2014-09-28 17:38:25	2014-10-08 17:32:26
11872	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10040	2014-09-28 17:38:25	2014-10-08 17:41:02
11455	MEMBRECOM	2013-11-05 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9680	\N	2014-09-28 17:38:26
8895	MEMBRECOM	2010-09-28 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7395	\N	2014-09-28 17:38:26
10434	MEMBRECOM	2012-02-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8787	\N	2014-09-28 17:38:26
11880	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10048	2014-09-28 17:58:04	2014-10-08 17:12:17
11881	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10049	2014-09-28 18:00:57	2014-10-08 16:54:15
11882	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10050	2014-09-28 18:00:57	2014-10-08 17:24:15
4242	MEMBRECOM	2006-06-16 00:00:00	2006-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3323	\N	2014-09-28 18:00:58
11883	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10051	2014-09-28 18:03:38	2014-10-08 16:52:09
11895	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10063	2014-09-28 19:03:23	2014-10-08 17:19:14
11896	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10064	2014-09-28 19:05:58	2014-10-08 17:26:09
11897	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10065	2014-09-28 19:05:58	2014-10-08 17:26:02
11898	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10066	2014-09-28 19:07:43	2014-10-08 16:50:39
10701	PDTCOM	2012-11-28 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8988	\N	2014-09-28 19:07:43
11902	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10070	2014-09-28 19:19:39	2014-10-08 16:43:22
11903	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10071	2014-09-28 19:19:39	2014-10-08 17:01:48
11905	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10073	2014-09-28 19:29:38	2014-10-08 17:42:07
12069	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3944	2014-10-08 17:48:52	2014-10-09 13:55:25
9792	VICPDTCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6897	\N	2014-10-08 17:48:57
12071	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	409	2014-10-08 17:49:01	2014-10-09 13:56:56
12072	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4275	2014-10-08 17:49:07	2014-10-09 13:56:00
12073	MEMBRECOM	2014-10-08 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	412	2014-10-08 17:49:11	2017-10-04 18:38:48
9796	VICPDTCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2575	\N	2014-10-08 17:49:16
12075	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2546	2014-10-08 17:49:20	2014-10-09 13:57:16
12076	MEMBRECOM	2014-10-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3683	2014-10-08 17:50:34	2017-09-24 17:35:15
12077	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8108	2014-10-08 17:50:37	2014-10-09 12:12:28
9618	VICPDTCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	2	ANCIEN	\N	\N	\N	\N	8108	\N	2014-10-08 17:50:38
12078	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4277	2014-10-08 17:50:41	2014-10-09 12:12:10
12079	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	741	2014-10-08 17:50:46	2014-10-09 12:12:38
9799	VICPDTCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	3	ANCIEN	\N	\N	\N	\N	741	\N	2014-10-08 17:50:46
12081	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	720	2014-10-08 17:50:55	2014-10-09 12:13:33
12082	MEMBRECOM	2014-10-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	514	2014-10-08 17:50:59	2017-09-24 18:05:40
12083	MEMBRECOM	2014-10-08 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7399	2014-10-08 17:51:03	\N
12084	MEMBRECOM	2014-10-08 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8056	2014-10-08 00:00:00	\N
12085	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8157	2014-10-08 17:51:11	2014-10-09 12:13:46
9667	SECRETCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	2	ANCIEN	\N	\N	\N	\N	8157	\N	2014-10-08 17:51:12
12086	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2577	2014-10-08 17:51:14	2014-10-09 12:11:01
12087	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2619	2014-10-08 17:51:19	2014-10-09 12:10:41
9774	PDTCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	723	\N	2014-10-08 17:51:34
12090	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2560	2014-10-08 17:51:41	2014-10-09 13:50:34
12091	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2553	2014-10-08 17:51:45	2014-10-09 13:50:09
12092	MEMBRECOM	2014-10-08 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4245	2014-10-08 17:51:49	2017-10-04 18:35:44
9817	SECRETCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4245	\N	2014-10-08 17:51:50
12094	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3673	2014-10-08 17:51:56	2014-10-09 13:51:24
9815	VICPDTCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3673	\N	2014-10-08 17:51:56
12095	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	788	2014-10-08 17:51:59	2014-10-09 13:51:16
12097	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8142	2014-10-08 17:52:10	2014-10-09 13:51:08
12098	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	749	2014-10-08 17:52:26	2014-10-09 10:49:18
12099	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2540	2014-10-08 17:52:30	2014-10-09 10:44:19
12100	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4284	2014-10-08 17:52:34	2014-10-09 10:43:48
12101	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2820	2014-10-08 17:52:38	2014-10-09 10:45:06
9726	VICPDTCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	6	ANCIEN	\N	\N	\N	\N	2820	\N	2014-10-08 17:52:39
12102	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2597	2014-10-08 17:52:42	2014-10-09 10:48:55
9840	SECRETCOM	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2597	\N	2014-10-08 17:52:43
12103	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4318	2014-10-08 17:52:46	2014-10-09 10:48:07
12104	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	262	2014-10-08 17:52:50	2014-10-09 10:44:36
12105	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8062	2014-10-08 17:52:55	2014-10-09 10:45:31
12121	MEMBRECOM	2014-10-08 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10229	2014-10-08 00:00:00	\N
10629	MEMBRECOM	2012-10-09 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8932	\N	2014-10-08 19:03:58
12122	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8699	2014-10-08 19:06:13	2014-10-09 11:52:20
10346	VICPDTCOM	2012-02-21 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8699	\N	2014-10-08 19:06:13
12123	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8711	2014-10-08 19:06:15	2014-10-09 11:52:33
12124	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8701	2014-10-08 19:06:18	2014-10-09 11:52:27
12125	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8738	2014-10-08 19:06:22	2014-10-09 11:48:48
10385	VICPDTCOM	2012-02-21 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8738	\N	2014-10-08 19:06:22
12126	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8690	2014-10-08 19:06:25	2014-10-09 11:52:13
10336	SECRETCOM	2012-02-21 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8690	\N	2014-10-08 19:06:26
11573	MEMBRECOM	2013-12-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9797	2013-12-10 17:48:20	2014-09-28 17:40:23
11574	MEMBRECOM	2013-12-10 00:00:00	2013-12-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9798	2013-12-10 17:48:32	2013-12-18 17:01:21
11575	MEMBRECOM	2013-12-10 00:00:00	2013-12-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9799	2013-12-10 17:49:11	2013-12-18 17:03:26
11576	MEMBRECOM	2013-12-10 00:00:00	2014-05-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9800	2013-12-10 17:49:42	2014-05-05 10:34:09
11577	MEMBRECOM	2013-12-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9801	2013-12-10 17:50:02	2014-11-18 15:39:56
11578	MEMBRECOM	2013-12-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9802	2013-12-10 17:50:20	2014-09-28 13:47:05
11579	MEMBRECOM	2013-12-17 00:00:00	2013-12-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9803	2013-12-17 09:57:02	2013-12-18 16:55:51
11731	MEMBRECOM	2014-04-10 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9915	2014-04-10 10:15:52	2014-10-08 17:15:26
12454	MEMBRECOM	2014-04-30 00:00:00	2015-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10402	\N	2015-10-13 14:22:05
11732	MEMBRECOM	2014-04-10 00:00:00	2014-04-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9916	2014-04-10 10:17:16	2014-04-25 17:05:01
11735	SECRETCOM	2014-04-16 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8142	2014-04-16 17:42:38	2014-10-08 17:52:11
10722	MEMBRECOM	2012-11-29 00:00:00	2014-04-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9009	\N	2014-04-23 09:56:25
11737	MEMBRECOM	2014-04-23 00:00:00	2014-05-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9919	2014-04-23 09:57:24	2014-05-13 14:41:32
11738	MEMBRECOM	2014-05-05 00:00:00	2014-05-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9920	2014-05-05 10:30:19	2014-05-07 12:20:43
11796	MEMBRECOM	2014-06-18 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9980	2014-06-19 11:14:44	2014-09-28 19:03:23
11813	MEMBRECOM	2014-06-25 00:00:00	2014-07-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9981	2014-06-25 15:52:44	2014-07-02 12:07:38
10748	MEMBRECOM	2012-11-29 00:00:00	2014-07-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9035	\N	2014-07-01 09:25:11
11839	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10007	2014-09-28 16:59:40	2014-10-08 17:43:29
11840	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10008	2014-09-28 16:59:40	2014-10-08 16:55:33
11841	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10009	2014-09-28 16:59:40	2014-10-08 17:40:36
11846	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10014	2014-09-28 17:05:42	2014-10-08 17:25:38
11847	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10015	2014-09-28 17:05:42	2014-10-08 16:56:09
11849	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10017	2014-09-28 17:07:40	2014-10-08 17:25:15
11850	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10018	2014-09-28 17:07:40	2014-10-08 16:57:42
11851	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10019	2014-09-28 17:07:40	2014-10-08 16:50:09
11852	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10020	2014-09-28 17:07:40	2014-10-08 17:18:38
10841	RAPCOM	2013-02-06 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9127	\N	2014-09-28 17:07:41
11855	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10023	2014-09-28 17:12:40	2014-10-08 17:24:56
11857	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10025	2014-09-28 17:15:41	2014-10-08 17:25:27
11860	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10028	2014-09-28 17:27:28	2014-10-08 17:39:53
11888	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10056	2014-09-28 18:46:12	2014-10-08 16:42:51
11889	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10057	2014-09-28 18:46:12	2014-10-08 17:18:27
11892	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10060	2014-09-28 18:58:25	2014-10-08 17:25:45
11894	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10062	2014-09-28 19:03:03	2014-10-08 17:17:51
11899	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10067	2014-09-28 19:09:43	2014-10-08 16:54:02
11900	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10068	2014-09-28 19:13:08	2014-10-08 16:55:39
11901	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10069	2014-09-28 19:13:08	2014-10-08 16:44:31
11904	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10072	2014-09-28 19:20:16	2014-10-08 18:47:21
11906	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10074	2014-09-28 19:45:29	2014-10-08 17:25:03
9006	MEMBRECOM	2010-12-08 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7506	\N	2014-10-08 16:40:46
11913	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10081	2014-10-08 16:41:15	2014-10-09 13:56:25
11915	MEMBRECOM	2014-10-08 00:00:00	2014-11-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10083	2014-10-08 16:42:42	2014-11-04 11:22:47
11916	MEMBRECOM	2014-10-08 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10084	2014-10-08 16:42:50	2017-10-04 18:48:12
11917	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10085	2014-10-08 16:43:09	2014-10-09 12:15:21
11919	MEMBRECOM	2014-10-08 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10087	2014-10-08 16:43:31	2017-10-04 18:49:49
11920	MEMBRECOM	2014-10-08 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10088	2014-10-08 16:44:04	2017-10-05 14:35:35
11921	MEMBRECOM	2014-10-08 00:00:00	2017-07-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10089	2014-10-08 16:44:30	2017-08-01 16:20:19
11922	MEMBRECOM	2014-10-08 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10090	2014-10-08 16:44:59	2017-10-04 19:13:36
11923	MEMBRECOM	2014-10-08 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10091	2014-10-08 16:45:07	2017-10-04 18:35:51
11925	MEMBRECOM	2014-10-08 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10093	2014-10-08 16:45:33	2017-10-04 18:35:50
11926	MEMBRECOM	2014-10-08 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10094	2014-10-08 16:45:41	2017-10-04 19:14:35
11935	MEMBRECOM	2014-10-08 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10103	2014-10-08 16:50:38	2017-10-05 14:28:16
11928	MEMBRECOM	2014-10-08 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10096	2014-10-08 16:47:36	2017-10-05 14:28:31
11929	MEMBRECOM	2014-10-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10097	2014-10-08 16:47:49	2017-09-24 13:25:54
10403	MEMBRECOM	2012-02-21 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8756	\N	2014-10-08 16:47:50
11930	MEMBRECOM	2014-10-08 00:00:00	2019-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10098	2014-10-08 16:48:23	\N
11931	MEMBRECOM	2014-10-08 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10099	2014-10-08 16:48:57	\N
11933	MEMBRECOM	2014-10-08 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10101	2014-10-08 16:49:22	2017-10-04 18:43:10
11934	MEMBRECOM	2014-10-08 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10102	2014-10-08 16:50:08	\N
11936	MEMBRECOM	2014-10-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10104	2014-10-08 16:50:44	2017-09-24 17:29:37
10400	MEMBRECOM	2012-02-21 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8753	\N	2014-10-08 16:50:45
11937	MEMBRECOM	2014-10-08 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10105	2014-10-08 16:51:16	2017-10-04 18:52:14
11938	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10106	2014-10-08 16:51:34	2014-10-09 11:50:44
11939	MEMBRECOM	2014-10-08 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10107	2014-10-08 16:51:54	\N
11940	MEMBRECOM	2014-10-08 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10108	2014-10-08 16:52:08	2017-10-01 10:25:16
11941	MEMBRECOM	2014-10-08 00:00:00	2015-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10109	2014-10-08 16:52:27	2015-06-12 15:59:18
11943	MEMBRECOM	2014-10-08 00:00:00	2015-02-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10111	2014-10-08 16:53:24	2015-02-12 15:03:17
11944	MEMBRECOM	2014-10-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10112	2014-10-08 16:53:33	2017-09-24 17:42:26
9619	MEMBRECOM	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8109	\N	2014-10-08 16:53:34
11945	MEMBRECOM	2014-10-08 00:00:00	2019-08-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10113	2014-10-08 16:53:43	\N
11946	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10114	2014-10-08 16:53:49	2014-10-09 11:51:11
10520	MEMBRECOM	2012-06-20 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	133	\N	2014-10-08 16:53:50
11947	MEMBRECOM	2014-10-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10115	2014-10-08 16:53:56	2017-09-24 17:42:26
11949	MEMBRECOM	2014-10-08 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10117	2014-10-08 16:54:14	2017-10-05 14:34:22
11950	MEMBRECOM	2014-10-08 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10118	2014-10-08 16:54:30	2017-10-04 18:38:52
11951	MEMBRECOM	2014-10-08 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10119	2014-10-08 16:54:38	2017-10-04 18:38:59
11952	MEMBRECOM	2014-10-08 00:00:00	2015-02-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10120	2014-10-08 16:54:48	2015-02-06 14:32:44
11953	MEMBRECOM	2014-10-08 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10121	2014-10-08 16:55:32	2017-10-01 10:18:28
11955	MEMBRECOM	2014-10-08 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10123	2014-10-08 16:55:51	2017-10-05 14:53:34
11956	MEMBRECOM	2014-10-08 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10124	2014-10-08 16:56:08	\N
11957	MEMBRECOM	2014-10-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10125	2014-10-08 16:56:26	2017-09-24 17:09:24
11958	MEMBRECOM	2014-10-08 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10126	2014-10-08 16:56:39	2017-10-05 14:37:02
11959	MEMBRECOM	2014-10-08 00:00:00	2015-02-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10127	2014-10-08 16:57:20	2015-02-06 14:27:55
11961	MEMBRECOM	2014-10-08 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10129	2014-10-08 16:58:09	2017-10-04 19:42:29
11962	MEMBRECOM	2014-10-08 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10130	2014-10-08 00:00:00	\N
11963	MEMBRECOM	2014-10-08 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10131	2014-10-08 16:59:47	2017-10-04 18:38:39
11964	MEMBRECOM	2014-10-08 00:00:00	2015-05-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10132	2014-10-08 17:00:38	2015-05-06 11:42:07
11966	MEMBRECOM	2014-10-08 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10134	2014-10-08 17:00:59	2017-10-04 19:11:24
11967	MEMBRECOM	2014-10-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10135	2014-10-08 17:01:06	2017-09-24 17:47:27
9776	MEMBRECOM	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8215	\N	2014-10-08 17:01:07
11968	MEMBRECOM	2014-10-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10136	2014-10-08 17:01:26	2017-09-24 17:48:21
11630	MEMBRECOM	2013-12-09 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9835	\N	2014-09-28 16:59:41
11631	MEMBRECOM	2013-12-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9836	\N	\N
11632	RAPCOM	2013-12-09 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9837	\N	\N
11636	MEMBRECOM	2014-01-22 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9841	2014-01-21 17:10:09	2014-10-09 16:22:30
11637	MEMBRECOM	2014-01-22 00:00:00	2014-02-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9842	2014-01-21 17:10:21	2014-02-05 18:46:26
11638	MEMBRECOM	2014-01-22 00:00:00	2014-02-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9844	2014-01-21 17:10:47	2014-02-05 18:47:42
11639	MEMBRECOM	2014-01-22 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9845	2014-01-21 17:10:56	2014-10-09 17:34:51
11640	MEMBRECOM	2014-01-22 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9846	2014-01-21 17:11:02	2014-10-09 16:24:27
11641	MEMBRECOM	2014-01-22 00:00:00	2014-02-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9847	2014-01-21 17:11:25	2014-02-05 18:48:48
11642	MEMBRECOM	2014-01-22 00:00:00	2014-02-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9848	2014-01-21 17:12:03	2014-02-05 18:49:35
11643	MEMBRECOM	2014-01-22 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9849	2014-01-21 17:13:31	2014-09-28 17:14:21
11644	MEMBRECOM	2014-01-22 00:00:00	2016-04-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9851	2014-01-21 17:13:50	2016-07-07 18:30:33
11646	MEMBRECOM	2014-01-22 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9853	2014-01-21 17:14:12	2014-09-28 16:59:41
11647	MEMBRECOM	2014-01-22 00:00:00	2016-04-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9854	2014-01-21 17:15:52	2016-07-07 18:25:54
11648	MEMBRECOM	2014-01-22 00:00:00	2014-02-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9855	2014-01-21 17:16:05	2014-02-05 18:47:19
11649	MEMBRECOM	2014-01-22 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9856	2014-01-21 17:16:14	2014-09-28 17:12:41
11650	MEMBRECOM	2014-01-22 00:00:00	2014-02-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9857	2014-01-21 17:16:23	2014-02-05 18:50:22
11651	MEMBRECOM	2014-01-22 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9858	2014-01-21 17:16:31	2014-09-28 13:16:32
11652	MEMBRECOM	2014-01-22 00:00:00	2014-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9859	2014-01-21 17:16:37	2014-09-29 13:41:53
11653	MEMBRECOM	2014-01-22 00:00:00	2015-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9860	2014-01-21 17:16:45	2015-06-12 16:01:25
11654	MEMBRECOM	2014-01-22 00:00:00	2014-02-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9861	2014-01-21 17:16:52	2014-02-05 18:49:10
11655	MEMBRECOM	2014-01-22 00:00:00	2016-04-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9862	2014-01-21 17:16:58	2016-07-07 18:06:06
11656	MEMBRECOM	2014-01-22 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9863	2014-01-21 17:17:05	2014-10-09 17:31:32
11658	MEMBRECOM	2014-01-22 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9865	2014-01-21 17:17:23	2014-09-28 18:00:58
11659	MEMBRECOM	2014-01-22 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9866	2014-01-21 17:17:29	2014-10-09 17:33:24
11660	MEMBRECOM	2014-01-22 00:00:00	2014-02-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9867	2014-01-21 17:17:36	2014-02-05 18:45:34
11661	MEMBRECOM	2014-01-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	9868	2014-01-21 17:17:42	\N
11662	MEMBRECOM	2014-01-22 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9869	2014-01-21 17:17:52	2014-09-28 17:34:16
11663	MEMBRECOM	2014-01-22 00:00:00	2014-02-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9870	2014-01-21 17:18:01	2014-02-05 18:50:00
11664	MEMBRECOM	2014-01-22 00:00:00	2014-02-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9871	2014-01-21 17:18:23	2014-02-05 18:48:04
11665	MEMBRECOM	2014-01-22 00:00:00	2014-02-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9872	2014-01-21 17:18:30	2014-02-05 18:48:24
11666	MEMBRECOM	2014-01-22 00:00:00	2014-09-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9873	2014-01-21 17:18:36	2014-09-01 10:21:13
11667	MEMBRECOM	2014-01-22 00:00:00	2014-02-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9874	2014-01-21 17:18:44	2014-02-05 18:52:14
11668	MEMBRECOM	2014-01-22 00:00:00	2016-04-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9875	2014-01-21 17:18:53	2016-07-07 18:35:56
11669	MEMBRECOM	2014-01-22 00:00:00	2014-02-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9876	2014-01-21 17:19:00	2014-02-05 18:45:59
11670	MEMBRECOM	2014-01-22 00:00:00	2014-01-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9877	2014-01-21 17:19:07	2014-01-23 14:21:41
11671	MEMBRECOM	2014-01-22 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9843	2014-01-21 17:19:28	2014-09-28 17:07:41
12455	MEMBRECOM	2014-04-30 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10403	\N	\N
11672	MEMBRECOM	2014-01-22 00:00:00	2014-02-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9850	2014-01-21 17:19:49	2014-02-05 18:46:50
11689	MEMBRECOM	2014-02-21 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9881	2014-02-21 11:14:59	2014-09-28 18:32:43
11701	MEMBRECOM	2014-02-25 00:00:00	2014-09-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9894	2014-02-25 16:22:40	2014-09-16 14:55:28
11703	MEMBRECOM	2014-02-25 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9895	2014-02-25 16:34:23	2014-09-28 18:32:43
11704	MEMBRECOM	2014-02-25 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9896	2014-02-25 16:34:32	2014-11-18 15:38:05
11705	MEMBRECOM	2014-02-25 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9897	2014-02-25 16:34:39	2014-11-18 15:38:05
11707	MEMBRECOM	2014-02-25 00:00:00	2014-03-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9899	2014-02-25 16:34:52	2014-03-11 13:44:39
11708	MEMBRECOM	2014-02-25 00:00:00	2014-03-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9900	2014-02-25 16:34:58	2014-03-11 13:45:05
11709	MEMBRECOM	2014-02-25 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9901	2014-02-25 16:35:05	2014-11-18 15:38:05
11710	MEMBRECOM	2014-02-25 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9902	2014-02-25 16:35:20	2014-11-18 15:38:05
11711	MEMBRECOM	2014-02-25 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9903	2014-02-25 16:35:25	2014-11-18 15:38:05
11713	MEMBRECOM	2014-02-25 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9905	2014-02-25 16:36:13	2014-11-18 15:38:05
11714	MEMBRECOM	2014-02-25 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9906	2014-02-25 16:36:22	2014-09-28 17:27:35
11723	PDTCOM	2014-03-11 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9887	2014-03-11 13:43:08	2014-11-18 15:38:05
11725	VICPDTCOM	2014-03-11 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9907	2014-03-11 13:44:08	2014-11-18 15:38:05
11726	VICPDTCOM	2014-03-11 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9899	2014-03-11 13:44:39	2014-11-18 15:38:05
11728	VICPDTCOM	2014-03-11 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9882	2014-03-11 13:45:32	2014-11-18 15:38:05
11729	VICPDTCOM	2014-03-11 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9888	2014-03-11 13:46:02	2014-11-18 15:38:05
11734	MEMBRECOM	2014-04-14 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9918	2014-04-14 16:11:56	2014-09-28 19:03:23
11736	RAPCOM	2014-04-16 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9871	2014-04-17 09:33:38	2014-10-20 17:22:54
11741	MEMBRECOM	2014-05-05 00:00:00	2014-05-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9923	2014-05-05 10:37:45	2014-05-07 09:32:54
11742	MEMBRECOM	2014-05-05 00:00:00	2014-05-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9924	2014-05-05 10:40:21	2014-05-07 12:20:13
11743	MEMBRECOM	2014-05-05 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9925	2014-05-05 14:48:49	2014-10-08 16:54:39
11748	MEMBRECOM	2014-05-07 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9930	2014-05-07 12:20:13	2014-10-09 13:57:49
11749	MEMBRECOM	2014-05-07 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9931	2014-05-07 12:20:43	2014-09-28 16:54:10
11750	MEMBRECOM	2014-05-07 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9932	2014-05-07 12:21:03	2014-09-28 19:29:39
11751	MEMBRECOM	2014-05-07 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9933	2014-05-07 12:21:26	2017-09-24 13:42:35
11756	MEMBRECOM	2014-05-13 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9938	2014-05-13 14:41:32	2014-09-28 17:07:41
11753	MEMBRECOM	2014-05-09 00:00:00	2014-05-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9935	2014-05-09 11:29:04	2014-05-13 14:42:35
11754	MEMBRECOM	2014-05-09 00:00:00	2014-05-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9936	2014-05-09 11:37:36	2014-05-13 14:42:54
11757	MEMBRECOM	2014-05-13 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9939	2014-05-13 14:42:35	2014-10-08 17:11:42
11797	PDTCOM	2014-06-23 00:00:00	2015-01-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9946	2014-06-23 18:22:57	2015-04-07 18:21:18
11798	MEMBRECOM	2014-06-18 00:00:00	2014-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9942	2014-06-23 18:23:34	\N
11799	VICPDTCOM	2014-06-23 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9942	2014-06-23 18:23:47	2014-10-09 17:25:31
11801	VICPDTCOM	2014-06-23 00:00:00	2015-01-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9960	2014-06-23 18:24:34	2015-04-07 18:21:18
11802	VICPDTCOM	2014-06-23 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9956	2014-06-23 18:24:52	2014-10-09 16:18:54
11803	VICPDTCOM	2014-06-23 00:00:00	2015-01-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9965	2014-06-23 18:25:12	2015-04-07 18:21:18
11804	MEMBRECOM	2014-06-18 00:00:00	2014-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9979	2014-06-23 18:25:30	2014-06-23 18:37:01
11806	VICPDTCOM	2014-06-23 00:00:00	2015-01-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9954	2014-06-23 18:26:12	2015-04-07 18:21:18
11807	VICPDTCOM	2014-06-23 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9962	2014-06-23 18:26:34	2014-10-09 17:49:55
11808	VICPDTCOM	2014-06-23 00:00:00	2015-01-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9967	2014-06-23 18:26:54	2015-04-07 18:21:18
11809	SECRETCOM	2014-06-23 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9944	2014-06-23 18:32:55	2014-10-09 17:22:45
11810	SECRETCOM	2014-06-23 00:00:00	2015-01-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9971	2014-06-23 18:33:19	2015-04-07 18:21:18
11812	RAPCOM	2014-06-23 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9968	2014-06-23 18:34:30	2014-10-09 16:11:15
11815	MEMBRECOM	2014-07-04 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9983	2014-07-04 14:37:06	2017-09-24 16:24:51
11817	MEMBRECOM	2014-07-22 00:00:00	2016-12-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9985	2014-07-22 12:09:09	2016-12-12 16:10:15
11818	MEMBRECOM	2014-07-22 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9986	2014-07-22 12:09:43	2017-09-24 18:23:22
11820	MEMBRECOM	2014-09-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9988	2014-09-01 10:22:08	2014-10-08 17:01:27
11829	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9997	2014-09-28 13:40:32	2014-10-08 17:40:54
11830	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9998	2014-09-28 13:40:32	2014-10-08 17:37:22
11548	MEMBRECOM	2013-12-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9772	2013-12-10 16:45:53	2014-09-28 17:38:26
11549	MEMBRECOM	2013-12-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9773	2013-12-10 16:46:03	2014-11-18 15:39:56
11550	MEMBRECOM	2013-12-10 00:00:00	2013-12-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9774	2013-12-10 16:46:09	2013-12-18 17:03:46
11551	MEMBRECOM	2013-12-10 00:00:00	2014-09-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9775	2013-12-10 16:46:17	2014-09-01 10:21:13
11552	MEMBRECOM	2013-12-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9776	2013-12-10 16:46:30	2014-09-28 13:19:48
11553	MEMBRECOM	2013-12-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9777	2013-12-10 16:46:39	2014-11-18 15:39:56
11554	MEMBRECOM	2013-12-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9778	2013-12-10 16:46:48	2014-11-18 15:39:56
11555	MEMBRECOM	2013-12-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9779	2013-12-10 16:46:57	2014-11-18 15:39:56
11556	MEMBRECOM	2013-12-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9780	2013-12-10 16:47:16	2014-09-28 17:34:16
11557	MEMBRECOM	2013-12-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9781	2013-12-10 16:47:24	2014-11-18 15:39:56
11558	MEMBRECOM	2013-12-10 00:00:00	2013-12-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9782	2013-12-10 16:47:36	2013-12-18 17:01:55
11559	MEMBRECOM	2013-12-10 00:00:00	2013-12-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9783	2013-12-10 16:48:11	2013-12-18 16:57:49
11560	MEMBRECOM	2013-12-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9784	2013-12-10 16:48:16	2014-09-28 17:00:59
11561	MEMBRECOM	2013-12-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9785	2013-12-10 16:48:24	2014-09-28 13:40:33
11562	MEMBRECOM	2013-12-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9786	2013-12-10 16:48:30	2014-11-18 15:39:16
11563	MEMBRECOM	2013-12-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9787	2013-12-10 16:48:38	2014-09-28 14:31:42
11564	MEMBRECOM	2013-12-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9788	2013-12-10 16:48:44	2014-09-28 17:31:42
11565	MEMBRECOM	2013-12-10 00:00:00	2013-12-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9789	2013-12-10 16:48:52	2013-12-17 09:56:49
11566	MEMBRECOM	2013-12-10 00:00:00	2013-12-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9790	2013-12-10 16:49:16	2013-12-18 16:57:27
11570	MEMBRECOM	2013-12-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9794	2013-12-10 17:37:12	2014-11-18 15:39:16
11571	MEMBRECOM	2013-12-10 00:00:00	2013-12-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9795	2013-12-10 17:37:21	2013-12-18 16:56:49
11572	MEMBRECOM	2013-12-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9796	2013-12-10 17:37:52	2014-11-18 15:39:16
11028	MEMBRECOM	2013-04-23 00:00:00	2013-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9315	\N	2013-12-16 10:30:09
11032	MEMBRECOM	2013-04-23 00:00:00	2013-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9319	\N	2013-12-16 10:30:09
11034	MEMBRECOM	2013-04-23 00:00:00	2013-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9321	\N	2013-12-16 10:30:09
11580	MEMBRECOM	2013-12-17 00:00:00	2020-07-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9804	2013-12-17 17:05:13	\N
11581	MEMBRECOM	2013-12-17 00:00:00	2013-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9805	2013-12-17 17:11:08	\N
11582	PDTCOM	2013-12-17 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9750	2013-12-18 16:55:20	2014-11-18 15:39:16
11583	RAPCOM	2013-12-17 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9803	2013-12-18 16:55:53	2014-09-28 17:34:16
11584	VICPDTCOM	2013-12-17 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9795	2013-12-18 16:56:52	2014-11-18 15:39:16
11585	VICPDTCOM	2013-12-17 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9790	2013-12-18 16:57:30	2014-11-18 15:39:16
11586	VICPDTCOM	2013-12-17 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9783	2013-12-18 16:57:52	2014-11-18 15:39:16
11587	VICPDTCOM	2013-12-17 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9753	2013-12-18 16:58:17	2014-11-18 15:39:16
11588	VICPDTCOM	2013-12-17 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9791	2013-12-18 16:58:42	2014-09-28 12:39:09
11589	VICPDTCOM	2013-12-17 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9748	2013-12-18 16:59:07	2014-09-28 19:07:43
11590	PDTCOM	2013-12-18 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9768	2013-12-18 17:00:47	2014-11-18 15:39:56
11591	RAPCOM	2013-12-18 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9798	2013-12-18 17:01:22	2014-11-18 15:39:56
11592	VICPDTCOM	2013-12-18 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9782	2013-12-18 17:01:56	2014-11-18 15:39:56
11593	VICPDTCOM	2013-12-18 00:00:00	2014-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9763	2013-12-18 17:02:20	2014-09-29 13:41:53
11594	VICPDTCOM	2013-12-18 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9758	2013-12-18 17:02:44	2014-11-18 15:39:56
11596	VICPDTCOM	2013-12-18 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9799	2013-12-18 17:03:27	2014-11-18 15:39:56
11597	VICPDTCOM	2013-12-18 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9774	2013-12-18 17:03:48	2014-11-18 15:39:56
11634	MEMBRECOM	2014-01-07 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9839	2014-01-07 10:46:26	2014-10-08 16:58:47
11635	MEMBRECOM	2014-01-07 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9840	2014-01-07 10:47:37	2017-09-24 17:35:15
11773	MEMBRECOM	2014-06-18 00:00:00	2014-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9956	2014-06-19 09:48:26	2014-06-23 18:24:51
11774	MEMBRECOM	2014-06-18 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9957	2014-06-19 09:48:33	2014-10-09 16:18:42
11775	MEMBRECOM	2014-06-18 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9958	2014-06-19 09:48:40	2014-10-09 17:24:08
11821	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9989	2014-09-28 12:09:44	2014-10-08 17:35:00
11822	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9990	2014-09-28 12:32:22	2014-10-08 17:38:28
11824	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9992	2014-09-28 12:44:31	2014-10-08 17:24:40
11825	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9993	2014-09-28 12:54:15	2014-10-08 16:49:13
11826	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9994	2014-09-28 13:06:30	2014-10-08 16:45:15
11827	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9995	2014-09-28 13:16:32	2014-10-08 17:42:00
11828	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9996	2014-09-28 13:32:34	2014-10-08 17:00:53
11831	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9999	2014-09-28 14:31:41	2014-10-08 17:43:36
10705	MEMBRECOM	2012-11-28 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8992	\N	2014-09-28 14:31:42
11856	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10024	2014-09-28 17:14:20	2014-10-08 17:32:56
11858	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10026	2014-09-28 17:22:10	2014-10-08 16:51:35
11859	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10027	2014-09-28 17:22:10	2014-10-08 17:33:28
10842	VICPDTCOM	2013-02-06 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9128	\N	2014-09-28 17:22:11
11861	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10029	2014-09-28 17:27:34	2014-10-08 16:51:55
11862	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10030	2014-09-28 17:27:34	2014-10-08 17:25:53
11863	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10031	2014-09-28 17:27:34	2014-10-08 16:56:40
11864	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10032	2014-09-28 17:31:41	2014-10-08 16:45:08
11865	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10033	2014-09-28 17:31:41	2014-10-08 16:58:10
11866	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10034	2014-09-28 17:31:41	2014-10-08 17:33:43
11867	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10035	2014-09-28 17:34:15	2014-10-08 17:07:01
11868	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10036	2014-09-28 17:34:15	2014-10-08 17:04:13
11869	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10037	2014-09-28 17:34:15	2014-10-08 16:43:32
10060	RAPCOM	2011-12-21 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8414	\N	2014-09-28 17:34:16
11873	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10041	2014-09-28 17:40:23	2014-10-08 17:35:19
11874	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10042	2014-09-28 17:40:23	2014-10-08 16:45:00
11479	MEMBRECOM	2013-11-19 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9705	2013-11-19 18:44:58	2014-09-28 17:40:23
11875	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10043	2014-09-28 17:52:17	2014-10-08 16:44:05
11876	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10044	2014-09-28 17:52:17	2014-10-08 16:45:34
11877	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10045	2014-09-28 17:52:17	2014-10-08 16:45:42
9787	MEMBRECOM	2011-10-01 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8222	\N	2014-09-28 17:52:18
10830	VICPDTCOM	2012-12-18 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8359	\N	2014-09-28 17:52:18
11971	MEMBRECOM	2014-10-08 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10139	2014-10-08 17:03:07	2017-10-04 18:35:49
3855	VICPDTCOM	2005-07-07 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2944	\N	2014-09-28 18:58:21
11884	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10052	2014-09-28 18:19:47	2014-10-08 17:33:12
9719	MEMBRECOM	2011-10-01 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	69	\N	2014-09-28 18:19:47
11886	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10054	2014-09-28 18:32:41	2014-10-08 17:38:18
11907	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10075	2014-09-29 09:03:10	2014-10-08 17:09:12
11908	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10076	2014-09-29 09:05:47	2014-10-08 17:01:00
11909	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10077	2014-09-29 09:08:32	2014-10-08 16:57:21
11910	MEMBRECOM	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10078	2014-09-29 09:08:32	2014-10-08 16:54:49
12277	MEMBRECOM	2014-10-09 00:00:00	2015-01-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10252	2014-10-09 15:26:37	2015-04-07 18:21:18
12278	MEMBRECOM	2014-10-09 00:00:00	2015-01-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10253	2014-10-09 15:29:31	2015-04-07 18:21:18
12279	MEMBRECOM	2014-10-09 00:00:00	2015-01-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10254	2014-10-09 16:00:04	2015-04-07 18:21:18
12280	MEMBRECOM	2014-10-09 00:00:00	2015-01-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10255	2014-10-09 16:00:50	2015-04-07 18:21:18
12282	MEMBRECOM	2014-10-09 00:00:00	2015-01-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10257	2014-10-09 16:02:51	2015-04-07 18:21:18
12283	MEMBRECOM	2014-10-09 00:00:00	2015-01-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10258	2014-10-09 16:03:14	2015-04-07 18:21:18
9997	VICPDTCOM	2011-12-06 00:00:00	2014-09-30 00:00:00	4	ANCIEN	\N	\N	\N	\N	8328	\N	2014-11-19 17:50:38
12285	MEMBRECOM	2014-10-09 00:00:00	2015-01-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10260	2014-10-09 16:04:58	2015-04-07 18:21:18
12286	MEMBRECOM	2014-10-09 00:00:00	2015-01-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10261	2014-10-09 16:05:28	2015-04-07 18:21:18
12287	MEMBRECOM	2014-10-09 00:00:00	2015-01-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10262	2014-10-09 16:05:46	2015-04-07 18:21:18
12288	MEMBRECOM	2014-10-09 00:00:00	2015-01-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10263	2014-10-09 16:06:10	2015-04-07 18:21:18
12289	MEMBRECOM	2014-10-09 00:00:00	2015-01-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10264	2014-10-09 16:06:37	2015-04-07 18:21:18
12290	MEMBRECOM	2014-10-09 00:00:00	2015-01-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10265	2014-10-09 16:07:07	2015-04-07 18:21:18
12293	MEMBRECOM	2014-10-09 00:00:00	2016-04-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10268	2014-10-09 16:21:29	2016-07-07 18:13:47
9994	VICPDTCOM	2011-12-06 00:00:00	2014-09-30 00:00:00	1	ANCIEN	\N	\N	\N	\N	8331	\N	2014-11-19 17:50:38
12295	MEMBRECOM	2014-10-09 00:00:00	2016-04-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10270	2014-10-09 16:23:46	2016-07-07 18:37:14
12297	MEMBRECOM	2014-10-09 00:00:00	2016-04-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10272	2014-10-09 16:24:50	2016-07-07 18:19:39
12298	MEMBRECOM	2014-10-09 00:00:00	2015-05-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10273	2014-10-09 16:25:21	2015-05-19 15:18:37
10006	SECRETCOM	2011-12-06 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8332	\N	2014-11-19 17:50:38
12300	MEMBRECOM	2014-10-09 00:00:00	2016-04-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10275	2014-10-09 16:26:12	2016-07-07 18:28:22
12302	MEMBRECOM	2014-10-09 00:00:00	2016-04-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10277	2014-10-09 16:26:58	2016-07-07 18:29:48
12303	MEMBRECOM	2014-10-09 00:00:00	2016-04-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10278	2014-10-09 16:27:26	2016-07-07 18:31:18
12304	MEMBRECOM	2014-10-09 00:00:00	2016-04-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10279	2014-10-09 16:27:55	2016-07-07 18:32:03
12306	MEMBRECOM	2014-10-09 00:00:00	2016-04-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10281	2014-10-09 16:28:36	2016-07-07 18:33:46
12307	MEMBRECOM	2014-10-09 00:00:00	2016-04-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10282	2014-10-09 16:29:01	2016-07-07 18:34:33
12321	MEMBRECOM	2014-10-09 00:00:00	2015-01-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9962	2014-10-09 17:49:56	2015-04-07 18:21:18
9980	MEMBRECOM	2011-11-30 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8362	\N	2014-11-19 17:50:38
9971	MEMBRECOM	2011-11-30 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8352	\N	2014-11-19 17:50:38
9972	MEMBRECOM	2011-11-30 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8353	\N	2014-11-19 17:50:38
10738	MEMBRECOM	2012-11-27 00:00:00	2014-12-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9025	\N	2014-12-18 16:15:04
12380	MEMBRECOM	2014-12-22 00:00:00	2015-01-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10328	2014-12-18 16:18:16	2015-01-13 11:56:57
12409	MEMBRECOM	2014-01-29 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10357	\N	2017-09-24 13:25:54
12412	MEMBRECOM	2014-01-29 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10360	\N	2017-10-01 10:01:39
12424	MEMBRECOM	2014-02-05 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10372	\N	2017-10-01 10:01:39
12428	RAPCOM	2014-02-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10376	\N	\N
12432	MEMBRECOM	2014-02-10 00:00:00	2015-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10380	\N	2015-10-13 14:22:14
12458	MEMBRECOM	2014-04-30 00:00:00	2015-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10406	\N	2015-06-12 16:01:25
12459	MEMBRECOM	2014-04-30 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10407	\N	2017-09-24 18:16:52
12461	MEMBRECOM	2014-04-30 00:00:00	2017-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10409	\N	2017-06-19 12:20:59
12462	MEMBRECOM	2014-04-30 00:00:00	2019-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10410	\N	\N
12463	MEMBRECOM	2014-04-30 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10411	\N	2017-09-24 18:16:52
12464	PDTCOM	2014-04-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10412	\N	\N
12465	RAPCOM	2014-04-30 00:00:00	2015-03-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10413	\N	2015-03-18 16:55:06
12466	MEMBRECOM	2014-04-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10414	\N	\N
12468	MEMBRECOM	2014-04-30 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10416	\N	\N
12469	MEMBRECOM	2014-04-30 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10417	\N	2017-09-24 13:29:42
12470	MEMBRECOM	2014-04-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10418	\N	\N
12471	MEMBRECOM	2014-04-30 00:00:00	2015-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10419	\N	2015-06-12 16:01:25
12473	MEMBRECOM	2014-04-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10421	\N	\N
12474	MEMBRECOM	2014-04-30 00:00:00	2017-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10422	\N	2017-06-19 12:20:59
12475	MEMBRECOM	2014-04-30 00:00:00	2019-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10423	\N	\N
12477	PDTCOM	2014-05-14 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10425	\N	2017-09-24 17:09:24
12479	MEMBRECOM	2014-05-14 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10427	\N	\N
12480	MEMBRECOM	2014-05-14 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10428	\N	\N
12482	MEMBRECOM	2014-05-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10430	\N	\N
12497	MEMBRECOM	2014-05-12 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10445	\N	2017-10-01 09:41:22
12498	MEMBRECOM	2014-05-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10446	\N	\N
12500	MEMBRECOM	2014-05-12 00:00:00	2015-04-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10448	\N	2015-04-07 16:50:27
12503	MEMBRECOM	2014-05-20 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10451	\N	\N
12504	MEMBRECOM	2014-05-20 00:00:00	2015-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10452	\N	2015-10-13 14:22:01
12505	MEMBRECOM	2014-05-20 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10453	\N	\N
12508	MEMBRECOM	2014-05-20 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10456	\N	2017-09-24 17:19:42
12509	MEMBRECOM	2014-05-20 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10457	\N	\N
12510	MEMBRECOM	2014-05-20 00:00:00	2019-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10458	\N	\N
12630	MEMBRECOM	2015-01-15 00:00:00	2015-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10578	2015-01-09 11:40:14	2015-10-07 10:43:00
12631	MEMBRECOM	2015-01-15 00:00:00	2015-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10579	2015-01-09 11:40:25	2015-01-29 18:05:18
12632	MEMBRECOM	2015-01-15 00:00:00	2015-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10580	2015-01-09 11:40:33	2015-10-07 10:43:00
12903	PDTCOM	2014-07-16 00:00:00	2014-07-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10851	2015-01-26 11:23:48	2016-06-28 18:04:05
12634	MEMBRECOM	2015-01-15 00:00:00	2015-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10582	2015-01-09 11:40:51	2015-10-07 10:43:00
12539	MEMBRECOM	2014-05-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10487	\N	\N
12541	MEMBRECOM	2014-05-26 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10489	\N	2017-09-24 18:16:52
12542	MEMBRECOM	2014-05-26 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10490	\N	2017-09-24 17:15:15
12543	MEMBRECOM	2014-05-26 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10491	\N	2017-09-24 17:47:27
12635	MEMBRECOM	2015-01-15 00:00:00	2015-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10583	2015-01-09 11:41:00	2015-01-29 18:06:40
12636	MEMBRECOM	2015-01-15 00:00:00	2015-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10584	2015-01-09 11:41:13	2015-10-07 10:43:00
12638	MEMBRECOM	2015-01-15 00:00:00	2015-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10586	2015-01-09 11:41:30	2015-01-29 18:08:07
12639	MEMBRECOM	2015-01-15 00:00:00	2015-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10588	2015-01-09 11:41:50	2015-10-07 10:43:00
12640	MEMBRECOM	2015-01-15 00:00:00	2015-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10589	2015-01-09 11:41:58	2015-01-29 18:08:26
12641	MEMBRECOM	2015-01-15 00:00:00	2015-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10591	2015-01-09 11:42:16	2015-10-07 10:43:00
12643	MEMBRECOM	2015-01-15 00:00:00	2015-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10590	2015-01-09 11:42:37	2015-10-07 10:43:00
12644	MEMBRECOM	2015-01-15 00:00:00	2015-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10587	2015-01-09 11:42:53	2015-10-07 10:43:00
12813	MEMBRECOM	2015-01-15 00:00:00	2015-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10761	2015-01-13 19:14:22	2015-01-29 18:06:20
12814	MEMBRECOM	2015-01-15 00:00:00	2015-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10762	2015-01-13 19:14:33	2015-01-29 18:07:03
12816	MEMBRECOM	2015-01-15 00:00:00	2015-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10764	2015-01-13 19:15:09	2015-01-29 18:09:50
12817	MEMBRECOM	2015-01-15 00:00:00	2015-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10765	2015-01-13 19:15:17	2015-10-07 10:43:00
12818	MEMBRECOM	2015-01-15 00:00:00	2015-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10766	2015-01-13 19:15:30	2015-10-07 10:43:00
12820	MEMBRECOM	2015-01-15 00:00:00	2015-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10768	2015-01-13 19:16:04	2015-10-07 10:43:00
12821	MEMBRECOM	2015-01-15 00:00:00	2015-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10771	2015-01-13 19:16:45	2015-01-29 18:18:30
12822	MEMBRECOM	2015-01-15 00:00:00	2015-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10772	2015-01-13 19:16:57	2015-10-07 10:43:00
12823	MEMBRECOM	2015-01-15 00:00:00	2015-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10773	2015-01-13 19:17:07	2015-10-07 10:43:00
12825	MEMBRECOM	2015-01-15 00:00:00	2015-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10775	2015-01-13 19:17:21	2015-01-29 18:08:48
12904	PDTCOM	2015-01-26 00:00:00	2021-01-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10852	2015-01-26 11:47:47	2015-01-26 11:48:00
12383	PDTCOM	2014-01-29 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10331	\N	2017-09-24 17:09:24
12384	RAPCOM	2014-01-29 00:00:00	2015-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10332	\N	2015-03-03 10:16:55
12386	MEMBRECOM	2014-01-29 00:00:00	2021-07-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10334	\N	\N
12387	MEMBRECOM	2014-01-29 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10335	\N	\N
12389	MEMBRECOM	2014-01-29 00:00:00	2015-04-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10337	\N	2015-04-07 16:50:27
12390	MEMBRECOM	2014-01-29 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10338	\N	\N
12391	MEMBRECOM	2014-01-29 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10339	\N	\N
12392	MEMBRECOM	2014-01-29 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10340	\N	\N
12906	MEMBRECOM	2015-01-26 00:00:00	2015-01-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10854	2015-01-26 16:17:48	2015-01-27 13:59:30
12406	RAPCOM	2014-01-29 00:00:00	2020-06-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10354	\N	\N
12407	MEMBRECOM	2014-01-29 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10355	\N	\N
12414	MEMBRECOM	2014-01-29 00:00:00	2017-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10362	\N	2017-06-19 12:20:59
12422	MEMBRECOM	2014-02-05 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10370	\N	2017-09-24 18:07:57
12423	MEMBRECOM	2014-02-05 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10371	\N	2017-09-24 13:44:49
12488	VICPDTCOM	2014-05-12 00:00:00	2015-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10436	\N	2015-01-08 17:14:28
12491	MEMBRECOM	2014-05-12 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10439	\N	2017-09-24 17:35:15
12492	MEMBRECOM	2014-05-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10440	\N	\N
12494	MEMBRECOM	2014-05-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10442	\N	\N
12495	MEMBRECOM	2014-05-12 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10443	\N	2017-09-24 18:20:10
12605	MEMBRECOM	2014-07-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10553	\N	\N
12606	MEMBRECOM	2014-07-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10554	\N	\N
12607	MEMBRECOM	2014-07-10 00:00:00	2017-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10555	\N	2017-06-19 12:20:59
12608	MEMBRECOM	2014-07-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10556	\N	\N
12609	MEMBRECOM	2014-07-10 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10557	\N	\N
12620	MEMBRECOM	2014-07-10 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10568	\N	2017-09-24 17:06:55
12622	MEMBRECOM	2014-07-10 00:00:00	2019-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10570	\N	\N
12623	MEMBRECOM	2014-07-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10571	\N	\N
12625	MEMBRECOM	2014-07-10 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10573	\N	2017-09-24 13:25:54
12626	MEMBRECOM	2014-07-10 00:00:00	2018-12-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10574	\N	\N
10042	PDTCOM	2011-12-19 00:00:00	2015-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8396	\N	2015-01-08 17:14:29
10028	VICPDTCOM	2011-12-19 00:00:00	2015-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8382	\N	2015-01-08 17:14:29
4982	MEMBRECOM	2008-07-09 00:00:00	2008-07-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4067	\N	2015-01-08 17:14:29
10758	VICPDTCOM	2012-12-13 00:00:00	2015-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9045	\N	2015-01-08 17:14:29
10665	VICPDTCOM	2012-11-06 00:00:00	2015-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8953	\N	2015-01-08 17:14:29
10816	PDTCOM	2012-12-15 00:00:00	2015-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9103	\N	2015-01-08 17:14:29
10476	VICPDTCOM	2012-02-22 00:00:00	2015-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8789	\N	2015-01-08 17:14:29
10731	VICPDTCOM	2012-11-27 00:00:00	2015-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9018	\N	2015-01-08 17:14:29
9026	RAPCOM	2010-12-08 00:00:00	2015-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7526	\N	2015-01-08 17:14:29
10013	VICPDTCOM	2011-12-08 00:00:00	2015-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8367	\N	2015-01-08 17:14:29
12933	VICPDTCOM	2015-01-28 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8085	2015-01-28 15:32:49	2017-10-04 18:44:51
12659	VICPDTCOM	2014-07-16 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10607	\N	2017-09-24 17:35:15
12660	RAPCOM	2014-07-16 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10608	\N	\N
12681	MEMBRECOM	2014-07-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10629	\N	\N
12685	RAPCOM	2014-10-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10633	\N	\N
12805	MEMBRECOM	2015-01-15 00:00:00	2015-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10753	2015-01-13 19:12:22	2015-10-07 10:43:00
12687	MEMBRECOM	2014-10-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10635	\N	\N
12688	MEMBRECOM	2014-10-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10636	\N	\N
12690	MEMBRECOM	2014-10-16 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10638	\N	2017-10-01 10:42:05
12691	MEMBRECOM	2014-10-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10639	\N	\N
12806	MEMBRECOM	2015-01-15 00:00:00	2015-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10754	2015-01-13 19:12:33	2015-01-29 18:04:53
12807	MEMBRECOM	2015-01-15 00:00:00	2015-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10755	2015-01-13 19:12:44	2015-01-29 18:05:43
12808	MEMBRECOM	2015-01-15 00:00:00	2015-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10756	2015-01-13 19:12:57	2015-10-07 10:43:00
12809	MEMBRECOM	2015-01-15 00:00:00	2015-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10757	2015-01-13 19:13:08	2015-01-29 18:06:02
12810	MEMBRECOM	2015-01-15 00:00:00	2015-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10758	2015-01-13 19:13:16	2015-10-07 10:43:00
12811	MEMBRECOM	2015-01-15 00:00:00	2015-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10759	2015-01-13 19:13:26	2015-01-29 18:04:30
12812	MEMBRECOM	2015-01-15 00:00:00	2015-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10760	2015-01-13 19:13:38	2015-01-29 18:09:27
12905	MEMBRECOM	2014-01-29 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10853	2015-01-26 11:56:36	2015-01-26 11:58:20
12948	PDTCOM	2014-10-22 00:00:00	2015-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10292	2015-01-29 17:48:20	2015-10-07 10:48:17
12949	RAPCOM	2014-10-22 00:00:00	2015-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10303	2015-01-29 17:48:59	2015-10-07 10:48:17
12950	VICPDTCOM	2014-10-22 00:00:00	2015-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10283	2015-01-29 17:49:45	2015-10-07 10:48:17
12951	VICPDTCOM	2014-10-22 00:00:00	2015-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10284	2015-01-29 17:50:18	2015-10-07 10:48:17
12952	VICPDTCOM	2014-10-22 00:00:00	2015-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10288	2015-01-29 17:50:40	2015-10-07 10:48:17
12954	PDTCOM	2015-01-15 00:00:00	2015-06-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10314	2015-01-29 17:52:49	2015-10-07 10:47:49
12955	RAPCOM	2015-01-15 00:00:00	2015-06-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10316	2015-01-29 17:53:13	2015-10-07 10:47:49
12956	VICPDTCOM	2015-01-15 00:00:00	2015-06-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10324	2015-01-29 17:53:40	2015-10-07 10:47:49
12957	VICPDTCOM	2015-01-15 00:00:00	2015-06-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10306	2015-01-29 17:54:04	2015-10-07 10:47:49
12958	VICPDTCOM	2015-01-15 00:00:00	2015-06-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10313	2015-01-29 17:54:28	2015-10-07 10:47:49
12959	VICPDTCOM	2015-01-15 00:00:00	2015-06-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10307	2015-01-29 17:54:51	2015-10-07 10:47:49
12960	VICPDTCOM	2015-01-15 00:00:00	2015-06-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10312	2015-01-29 17:56:57	2015-10-07 10:47:49
12961	VICPDTCOM	2015-01-15 00:00:00	2015-06-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10308	2015-01-29 18:02:00	2015-10-07 10:47:49
12962	PDTCOM	2015-01-20 00:00:00	2015-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10759	2015-01-29 18:04:31	2015-10-07 10:43:00
12963	VICPDTCOM	2015-01-20 00:00:00	2015-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10754	2015-01-29 18:04:54	2015-10-07 10:43:00
12964	VICPDTCOM	2015-01-20 00:00:00	2015-02-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10579	2015-01-29 18:05:19	2015-02-11 10:16:48
12965	VICPDTCOM	2015-01-20 00:00:00	2015-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10755	2015-01-29 18:05:44	2015-10-07 10:43:00
12966	VICPDTCOM	2015-01-20 00:00:00	2015-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10757	2015-01-29 18:06:02	2015-10-07 10:43:00
12845	MEMBRECOM	2014-02-05 00:00:00	2014-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10793	2015-01-23 15:02:36	2015-01-23 15:42:04
12967	VICPDTCOM	2015-01-20 00:00:00	2015-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10761	2015-01-29 18:06:23	2015-10-07 10:43:00
12968	VICPDTCOM	2015-01-20 00:00:00	2015-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10583	2015-01-29 18:06:42	2015-10-07 10:43:00
12969	VICPDTCOM	2015-01-20 00:00:00	2015-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10762	2015-01-29 18:07:05	2015-10-07 10:43:00
12970	VICPDTCOM	2015-01-20 00:00:00	2015-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10586	2015-01-29 18:08:08	2015-10-07 10:43:00
12971	VICPDTCOM	2015-01-20 00:00:00	2015-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10589	2015-01-29 18:08:27	2015-10-07 10:43:00
12972	VICPDTCOM	2015-01-20 00:00:00	2015-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10775	2015-01-29 18:08:49	2015-10-07 10:43:00
12973	SECRETCOM	2015-01-20 00:00:00	2015-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10760	2015-01-29 18:09:28	2015-10-07 10:43:00
12974	SECRETCOM	2015-01-20 00:00:00	2015-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10764	2015-01-29 18:09:52	2015-10-07 10:43:00
12975	SECRETCOM	2015-01-20 00:00:00	2015-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10771	2015-01-29 18:18:31	2015-10-07 10:43:00
13013	MEMBRECOM	\N	1984-09-04 00:00:00	\N	ANCIEN	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11218	\N	\N
13015	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11222	\N	\N
13018	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11227	\N	\N
13019	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11228	\N	\N
12209	PDTCOM	2014-10-09 00:00:00	2017-10-04 00:00:00	1	ANCIEN	\N	\N	\N	\N	8738	2014-10-09 11:48:48	2017-10-04 18:35:25
12210	SECRETCOM	2014-10-09 00:00:00	2016-01-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10205	2014-10-09 11:50:31	2016-01-11 17:34:09
12211	SECRETCOM	2014-10-09 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10106	2014-10-09 11:50:44	2017-10-04 18:35:49
12212	SECRETCOM	2014-10-09 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10114	2014-10-09 11:51:11	2017-09-24 13:47:46
12214	VICPDTCOM	2014-10-09 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8690	2014-10-09 11:52:13	2017-09-24 13:25:54
12215	VICPDTCOM	2014-10-09 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8699	2014-10-09 11:52:20	2017-10-04 18:35:31
12216	VICPDTCOM	2014-10-09 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8701	2014-10-09 11:52:26	2017-10-04 18:35:35
12217	VICPDTCOM	2014-10-09 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8711	2014-10-09 11:52:33	2017-09-24 17:19:42
12218	VICPDTCOM	2014-10-09 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8721	2014-10-09 11:52:40	2017-09-24 17:06:55
12219	VICPDTCOM	2014-10-09 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8727	2014-10-09 11:52:48	2017-09-24 17:14:26
10373	MEMBRECOM	2012-02-21 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8727	\N	2014-10-09 11:52:48
12220	VICPDTCOM	2014-10-09 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8744	2014-10-09 11:53:03	2017-10-01 10:20:50
12222	VICPDTCOM	2014-10-09 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8750	2014-10-09 11:53:18	2017-10-04 18:35:42
12223	PDTCOM	2014-10-09 00:00:00	2017-10-04 00:00:00	1	ANCIEN	\N	\N	\N	\N	2619	2014-10-09 12:10:41	2017-10-04 18:36:02
12224	RAPGENCOM	2014-10-09 00:00:00	2017-10-04 00:00:00	2	ANCIEN	\N	\N	\N	\N	2577	2014-10-09 12:11:01	2017-10-04 18:36:11
12225	VICPDTCOM	2014-10-09 00:00:00	2017-10-04 00:00:00	3	ANCIEN	\N	\N	\N	\N	609	2014-10-09 12:11:23	2017-10-04 18:36:18
9137	MEMBRECOM	2011-01-14 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	609	\N	2014-10-09 12:11:23
12227	VICPDTCOM	2014-10-09 00:00:00	2017-10-01 00:00:00	5	ANCIEN	\N	\N	\N	\N	8104	2014-10-09 12:11:58	2017-09-24 17:29:37
9614	MEMBRECOM	2011-10-01 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8104	\N	2014-10-09 12:11:58
12228	VICPDTCOM	2014-10-09 00:00:00	2017-10-04 00:00:00	6	ANCIEN	\N	\N	\N	\N	4277	2014-10-09 12:12:10	2017-10-04 18:36:26
12229	VICPDTCOM	2014-10-09 00:00:00	2017-10-01 00:00:00	7	ANCIEN	\N	\N	\N	\N	8108	2014-10-09 12:12:27	2017-09-24 17:42:25
12230	VICPDTCOM	2014-10-09 00:00:00	2017-10-01 00:00:00	8	ANCIEN	\N	\N	\N	\N	741	2014-10-09 12:12:38	2017-09-24 16:43:43
12231	VICPDTCOM	2014-10-09 00:00:00	2017-10-01 00:00:00	9	ANCIEN	\N	\N	\N	\N	8052	2014-10-09 12:12:49	2017-09-24 12:57:09
12232	VICPDTCOM	2014-10-09 00:00:00	2017-10-04 00:00:00	10	ANCIEN	\N	\N	\N	\N	8153	2014-10-09 12:13:19	2017-10-04 18:36:30
9663	MEMBRECOM	2011-10-01 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8153	\N	2014-10-09 12:13:19
12233	VICPDTCOM	2014-10-09 00:00:00	2017-10-01 00:00:00	11	ANCIEN	\N	\N	\N	\N	720	2014-10-09 12:13:33	2017-09-24 13:44:49
12234	VICPDTCOM	2014-10-09 00:00:00	2017-10-01 00:00:00	12	ANCIEN	\N	\N	\N	\N	8157	2014-10-09 12:13:46	2017-09-24 18:07:57
12235	SECRETCOM	2014-10-09 00:00:00	2017-10-03 00:00:00	13	ANCIEN	\N	\N	\N	\N	10169	2014-10-09 12:14:52	2017-10-04 18:36:34
12236	SECRETCOM	2014-10-09 00:00:00	2017-10-04 00:00:00	14	ANCIEN	\N	\N	\N	\N	8040	2014-10-09 12:15:00	2017-10-04 18:36:37
12237	SECRETCOM	2014-10-09 00:00:00	2017-10-04 00:00:00	15	ANCIEN	\N	\N	\N	\N	8123	2014-10-09 12:15:08	2017-10-04 18:36:41
12238	SECRETCOM	2014-10-09 00:00:00	2017-10-03 00:00:00	16	ANCIEN	\N	\N	\N	\N	10150	2014-10-09 12:15:14	2017-10-04 18:36:45
12239	SECRETCOM	2014-10-09 00:00:00	2017-10-04 00:00:00	17	ANCIEN	\N	\N	\N	\N	10085	2014-10-09 12:15:21	2017-10-04 18:36:49
9849	MEMBRECOM	2011-10-01 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8233	\N	2014-10-09 15:39:29
9864	MEMBRECOM	2011-10-01 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8246	\N	2014-10-09 15:40:20
9869	MEMBRECOM	2011-10-01 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4430	\N	2014-10-09 15:40:51
12308	VICPDTCOM	2014-10-09 00:00:00	2015-01-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9975	2014-10-09 17:22:10	2015-04-07 18:21:18
12309	VICPDTCOM	2014-10-09 00:00:00	2015-01-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9944	2014-10-09 17:22:46	2015-04-07 18:21:18
12310	VICPDTCOM	2014-10-09 00:00:00	2015-01-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9950	2014-10-09 17:23:35	2015-04-07 18:21:18
12311	VICPDTCOM	2014-10-09 00:00:00	2015-01-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9958	2014-10-09 17:24:10	2015-04-07 18:21:18
12312	SECRETCOM	2014-10-09 00:00:00	2015-01-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10259	2014-10-09 17:24:50	2015-04-07 18:21:18
12313	RAPCOM	2014-10-09 00:00:00	2015-01-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9942	2014-10-09 17:25:33	2015-04-07 18:21:18
12314	VICPDTCOM	2014-10-09 00:00:00	2016-04-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10274	2014-10-09 17:29:06	2016-07-07 18:27:10
12315	VICPDTCOM	2014-10-09 00:00:00	2016-04-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9863	2014-10-09 17:31:35	2016-07-07 18:14:15
12316	VICPDTCOM	2014-10-09 00:00:00	2015-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9870	2014-10-09 17:32:19	2015-04-07 09:40:47
12317	SECRETCOM	2014-10-09 00:00:00	2016-04-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9866	2014-10-09 17:33:29	2016-07-07 18:26:18
12318	SECRETCOM	2014-10-09 00:00:00	2016-04-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10269	2014-10-09 17:34:05	2016-07-07 18:14:42
12319	SECRETCOM	2014-10-09 00:00:00	2016-04-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9845	2014-10-09 17:34:54	2016-07-07 18:33:03
12320	RAPCOM	2014-10-09 00:00:00	2016-04-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9871	2014-10-09 17:35:47	2016-07-07 18:31:39
12382	MEMBRECOM	2014-12-28 00:00:00	2015-01-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10330	2014-12-29 15:45:40	2015-01-13 11:58:37
12549	MEMBRECOM	2014-05-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10497	\N	\N
12562	MEMBRECOM	2014-06-11 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10510	\N	2017-09-24 19:31:54
12555	RAPCOM	2014-06-11 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10503	\N	2017-09-24 18:05:40
12556	MEMBRECOM	2014-06-11 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10504	\N	\N
12557	MEMBRECOM	2014-06-11 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10505	\N	\N
12558	MEMBRECOM	2014-06-11 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10506	\N	\N
12560	MEMBRECOM	2014-06-11 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10508	\N	2017-09-24 13:44:49
12564	MEMBRECOM	2014-06-11 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10512	\N	\N
12566	MEMBRECOM	2014-07-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10514	\N	\N
12567	MEMBRECOM	2014-07-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10515	\N	\N
12568	MEMBRECOM	2014-07-02 00:00:00	2015-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10516	\N	2015-10-13 14:20:56
12569	MEMBRECOM	2014-07-02 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10517	\N	2017-09-24 18:17:56
12570	MEMBRECOM	2014-07-02 00:00:00	2015-04-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10518	\N	2015-04-21 17:14:30
12571	MEMBRECOM	2014-07-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10519	\N	\N
12572	MEMBRECOM	2014-07-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10520	\N	\N
12574	MEMBRECOM	2014-07-02 00:00:00	2017-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10522	\N	2017-06-19 12:20:59
12576	MEMBRECOM	2014-07-02 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10524	\N	\N
12577	PDTCOM	2014-07-08 00:00:00	2015-01-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10525	\N	2015-01-08 17:14:29
12578	RAPCOM	2014-07-08 00:00:00	2017-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10526	\N	2017-09-25 09:56:00
12579	MEMBRECOM	2014-07-08 00:00:00	2017-08-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10527	\N	2017-08-07 16:31:39
12580	MEMBRECOM	2014-07-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10528	\N	\N
12581	MEMBRECOM	2014-07-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10529	\N	2017-09-24 17:15:15
12582	MEMBRECOM	2014-07-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10530	\N	\N
12583	MEMBRECOM	2014-07-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10531	\N	2017-09-24 18:20:10
12584	MEMBRECOM	2014-07-08 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10532	\N	\N
12585	MEMBRECOM	2014-07-08 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10533	\N	\N
12586	MEMBRECOM	2014-07-08 00:00:00	2021-07-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10534	\N	\N
12588	MEMBRECOM	2014-07-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10536	\N	\N
12589	MEMBRECOM	2014-07-08 00:00:00	2015-04-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10537	\N	2015-04-07 16:50:27
12593	MEMBRECOM	2014-07-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10541	\N	\N
12594	MEMBRECOM	2014-07-10 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10542	\N	2017-09-24 13:57:40
12595	MEMBRECOM	2014-07-10 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10543	\N	\N
12597	MEMBRECOM	2014-07-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10545	\N	\N
12598	MEMBRECOM	2014-07-10 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10546	\N	\N
12599	MEMBRECOM	2014-07-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10547	\N	\N
12615	MEMBRECOM	2014-07-10 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10563	\N	2017-09-24 13:25:54
12648	MEMBRECOM	2014-07-16 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10596	\N	2017-09-24 17:06:55
12649	MEMBRECOM	2014-07-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10597	\N	\N
12744	MEMBRECOM	2014-05-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10692	\N	\N
12776	MEMBRECOM	2014-12-06 00:00:00	2021-07-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10724	\N	\N
12777	MEMBRECOM	2014-12-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10725	\N	\N
12779	MEMBRECOM	2014-12-06 00:00:00	2018-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10727	\N	2018-05-31 10:52:17
12780	MEMBRECOM	2014-12-06 00:00:00	2015-04-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10728	\N	2015-04-07 16:50:27
12781	MEMBRECOM	2014-12-06 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10729	\N	2017-10-01 10:18:28
12782	MEMBRECOM	2014-12-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10730	\N	\N
12783	MEMBRECOM	2014-12-06 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10731	\N	\N
12785	MEMBRECOM	2014-12-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10733	\N	\N
12786	MEMBRECOM	2014-12-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10734	\N	\N
12826	MEMBRECOM	2015-01-15 00:00:00	2015-02-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10776	2015-01-14 08:41:30	2015-02-20 10:30:10
12827	MEMBRECOM	2015-01-15 00:00:00	2015-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10777	2015-01-14 08:41:40	2015-10-07 10:43:00
12837	MEMBRECOM	2014-01-29 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10785	2015-01-23 14:41:13	\N
12990	PDTCOM	2015-01-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10907	2015-01-30 14:37:45	2015-01-30 14:48:59
12836	MEMBRECOM	2014-01-29 00:00:00	2014-02-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10784	2015-01-23 14:40:51	2015-01-23 15:02:20
11462	MEMBRECOM	2013-11-19 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9687	2013-11-19 18:42:45	2014-11-18 11:50:10
11467	MEMBRECOM	2013-11-19 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9692	2013-11-19 18:43:22	2014-11-18 11:50:10
11470	MEMBRECOM	2013-11-19 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9695	2013-11-19 18:43:46	2014-11-18 11:50:10
11473	MEMBRECOM	2013-11-19 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9699	2013-11-19 18:44:17	2014-11-18 11:50:10
11476	MEMBRECOM	2013-11-19 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9702	2013-11-19 18:44:37	2014-11-18 11:50:10
12848	MEMBRECOM	2014-02-10 00:00:00	2014-07-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10796	2015-01-23 15:06:40	2015-01-23 15:37:25
11483	MEMBRECOM	2013-11-19 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9709	2013-11-19 18:45:23	2014-11-18 11:50:10
11487	MEMBRECOM	2013-11-19 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9713	2013-11-19 18:45:56	2014-11-18 11:50:10
12451	PDTCOM	2014-04-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10399	\N	\N
12453	MEMBRECOM	2014-04-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10401	\N	\N
12460	MEMBRECOM	2014-04-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10408	\N	\N
12478	RAPCOM	2014-05-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10426	\N	\N
12483	MEMBRECOM	2014-05-14 00:00:00	2016-11-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10431	\N	2016-12-01 10:36:51
12496	MEMBRECOM	2014-05-12 00:00:00	2021-07-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10444	\N	\N
12499	MEMBRECOM	2014-05-12 00:00:00	2017-05-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10447	\N	2017-05-16 15:18:13
12611	MEMBRECOM	2014-07-10 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10559	\N	2017-10-01 10:20:50
12612	MEMBRECOM	2014-07-10 00:00:00	2019-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10560	\N	\N
12535	PDTCOM	2014-05-26 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10483	\N	2017-09-24 13:14:55
12536	RAPCOM	2014-05-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10484	\N	\N
12537	MEMBRECOM	2014-05-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10485	\N	\N
12538	MEMBRECOM	2014-05-26 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10486	\N	2017-09-24 17:18:03
12540	MEMBRECOM	2014-05-26 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10488	\N	2017-09-24 17:47:28
12546	RAPCOM	2014-05-26 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10494	\N	2017-09-24 16:43:43
12565	VICPDTCOM	2014-07-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10513	\N	\N
12575	MEMBRECOM	2014-07-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10523	\N	\N
12592	MEMBRECOM	2014-07-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10540	\N	\N
12600	PDTCOM	2014-07-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10548	\N	\N
12602	MEMBRECOM	2014-07-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10550	\N	\N
12603	MEMBRECOM	2014-07-10 00:00:00	2015-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10551	\N	2015-10-13 14:20:46
12604	MEMBRECOM	2014-07-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10552	\N	\N
12610	MEMBRECOM	2014-07-10 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10558	\N	2017-09-24 17:06:55
12613	MEMBRECOM	2014-07-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10561	\N	\N
12627	MEMBRECOM	2014-07-10 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10575	\N	2017-09-24 17:19:42
12628	MEMBRECOM	2014-07-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10576	\N	\N
12693	MEMBRECOM	2014-10-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10641	\N	\N
12689	MEMBRECOM	2014-10-16 00:00:00	2015-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10637	\N	2015-06-12 16:01:25
12698	MEMBRECOM	2014-10-16 00:00:00	2019-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10646	\N	\N
12694	MEMBRECOM	2014-10-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10642	\N	\N
12695	MEMBRECOM	2014-10-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10643	\N	\N
12696	MEMBRECOM	2014-10-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10644	\N	\N
12697	MEMBRECOM	2014-10-16 00:00:00	2017-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10645	\N	2017-06-19 12:20:59
12699	PDTCOM	2014-10-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10647	\N	\N
12700	RAPCOM	2014-10-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10648	\N	\N
12718	MEMBRECOM	2014-10-19 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10666	\N	\N
12702	MEMBRECOM	2014-10-14 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10650	\N	2017-09-24 17:29:37
12703	MEMBRECOM	2014-10-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10651	\N	\N
12708	MEMBRECOM	2014-10-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10656	\N	\N
12712	MEMBRECOM	2014-10-14 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10660	\N	2017-09-24 12:57:09
12713	MEMBRECOM	2014-10-14 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10661	\N	\N
12714	PDTCOM	2014-10-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10662	\N	\N
12715	RAPCOM	2014-10-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10663	\N	\N
12716	MEMBRECOM	2014-10-19 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10664	\N	\N
12730	PDTCOM	2014-11-19 00:00:00	2015-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10678	\N	2015-10-13 14:20:40
12719	MEMBRECOM	2014-10-19 00:00:00	2020-06-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10667	\N	\N
12720	MEMBRECOM	2014-10-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10668	\N	\N
12721	MEMBRECOM	2014-10-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10669	\N	\N
12722	MEMBRECOM	2014-10-19 00:00:00	2017-08-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10670	\N	2017-08-07 16:31:39
12723	MEMBRECOM	2014-10-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10671	\N	\N
12724	MEMBRECOM	2014-10-19 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10672	\N	\N
12725	MEMBRECOM	2014-10-19 00:00:00	2018-12-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10673	\N	\N
12726	MEMBRECOM	2014-10-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10674	\N	\N
12727	MEMBRECOM	2014-10-19 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10675	\N	2017-09-24 17:06:55
12728	MEMBRECOM	2014-10-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10676	\N	\N
12740	MEMBRECOM	2014-11-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10688	\N	\N
12731	RAPCOM	2014-11-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10679	\N	\N
12732	MEMBRECOM	2014-11-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10680	\N	\N
12733	MEMBRECOM	2014-11-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10681	\N	\N
12734	MEMBRECOM	2014-11-19 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10682	\N	2017-09-24 13:25:54
12735	MEMBRECOM	2014-11-19 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10683	\N	2017-09-24 18:16:52
12736	MEMBRECOM	2014-11-19 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10684	\N	2017-09-24 19:25:10
12737	MEMBRECOM	2014-11-19 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10685	\N	2017-09-24 17:55:12
12739	MEMBRECOM	2014-11-19 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10687	\N	2017-09-24 17:28:55
12741	MEMBRECOM	2014-11-19 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10689	\N	2017-10-01 10:42:05
12742	MEMBRECOM	2014-11-19 00:00:00	2017-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10690	\N	2017-06-19 12:20:59
12743	MEMBRECOM	2014-11-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10691	\N	\N
12772	MEMBRECOM	2014-11-20 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10720	\N	\N
12774	VICPDTCOM	2014-12-06 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10722	\N	2017-09-24 18:20:10
12775	RAPCOM	2014-12-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10723	\N	\N
12801	MEMBRECOM	2014-12-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10749	\N	\N
12838	MEMBRECOM	2014-01-29 00:00:00	2014-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10786	2015-01-23 14:43:27	2015-01-23 15:16:06
12839	RAPCOM	2014-01-29 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10787	2015-01-23 14:48:39	2015-01-23 14:48:54
12840	MEMBRECOM	2014-01-29 00:00:00	2014-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10788	2015-01-23 14:49:49	2015-01-23 15:41:21
12841	MEMBRECOM	2014-01-29 00:00:00	2014-02-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10789	2015-01-23 14:50:21	2015-01-23 15:02:38
12844	MEMBRECOM	2014-02-05 00:00:00	2014-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10792	2015-01-23 15:02:19	2015-01-23 15:14:55
12849	MEMBRECOM	2014-02-10 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10797	2015-01-23 15:07:53	2017-09-24 17:18:03
12850	RAPCOM	2014-02-17 00:00:00	2015-01-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10798	2015-01-23 15:09:13	2015-01-23 15:28:28
12851	MEMBRECOM	2014-02-17 00:00:00	2014-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10799	2015-01-23 15:09:44	2015-01-23 15:43:18
12852	RAPCOM	2014-04-30 00:00:00	2014-04-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10800	2015-01-23 15:11:25	2015-01-23 15:13:44
12853	MEMBRECOM	2014-04-30 00:00:00	2014-07-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10801	2015-01-23 15:13:42	2015-01-23 15:37:01
12854	MEMBRECOM	2014-05-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10802	2015-01-23 15:14:54	\N
12855	MEMBRECOM	2014-05-14 00:00:00	2014-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10803	2015-01-23 15:15:08	2015-01-23 15:46:00
12856	MEMBRECOM	2014-05-14 00:00:00	2014-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10804	2015-01-23 15:16:05	2015-01-23 15:44:11
12857	PDTCOM	2014-05-20 00:00:00	2014-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10805	2015-01-23 15:17:51	2015-01-23 15:48:50
12858	MEMBRECOM	2014-05-20 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10806	2015-01-23 15:18:21	\N
12859	MEMBRECOM	2014-05-20 00:00:00	2014-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10807	2015-01-23 15:18:34	2015-01-23 15:49:11
12860	MEMBRECOM	2014-05-20 00:00:00	2014-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10808	2015-01-23 15:18:56	2015-01-23 15:49:33
12861	MEMBRECOM	2014-05-20 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10809	2015-01-23 15:19:11	\N
12862	MEMBRECOM	2014-05-26 00:00:00	2014-06-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10810	2015-01-23 15:20:29	2015-01-23 15:35:33
12863	MEMBRECOM	2014-05-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10811	2015-01-23 15:21:32	\N
12864	MEMBRECOM	2014-05-26 00:00:00	2014-06-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10812	2015-01-23 15:22:14	2015-01-23 15:35:54
12865	MEMBRECOM	2014-05-26 00:00:00	2014-07-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10813	2015-01-23 15:22:39	2015-01-23 15:55:23
12869	RAPCOM	2014-05-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10817	2015-01-23 15:32:41	2015-01-23 15:32:56
12870	MEMBRECOM	2014-05-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10818	2015-01-23 15:33:29	\N
12871	MEMBRECOM	2014-05-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10819	2015-01-23 15:33:48	\N
12872	MEMBRECOM	2014-05-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10820	2015-01-23 15:34:07	\N
12873	MEMBRECOM	2014-06-11 00:00:00	2014-07-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10821	2015-01-23 15:35:14	2015-01-23 15:54:23
12874	MEMBRECOM	2014-06-11 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10822	2015-01-23 15:35:31	\N
12875	MEMBRECOM	2014-06-11 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10823	2015-01-23 15:35:52	\N
12876	RAPCOM	2014-07-02 00:00:00	2014-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10824	2015-01-23 15:36:59	2015-01-23 15:47:21
12877	MEMBRECOM	2014-07-02 00:00:00	2014-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10825	2015-01-23 15:37:23	2015-01-23 15:46:40
12878	MEMBRECOM	2014-07-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10826	2015-01-23 15:38:32	2017-09-24 18:05:41
10672	MEMBRECOM	2012-11-06 00:00:00	2015-01-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8960	\N	2015-01-23 15:38:35
12879	MEMBRECOM	2014-07-10 00:00:00	2014-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10827	2015-01-23 15:41:19	2015-01-23 15:56:59
12322	PDTCOM	2014-10-13 00:00:00	2017-06-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4408	2014-10-13 11:48:47	2017-10-24 11:30:56
12323	VICPDTCOM	2014-10-13 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8242	2014-10-13 11:48:57	2017-10-05 11:42:52
12325	VICPDTCOM	2014-10-13 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10238	2014-10-13 11:49:11	2017-10-05 11:42:50
12327	VICPDTCOM	2014-10-13 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6419	2014-10-13 11:49:22	2017-10-05 11:42:52
12329	VICPDTCOM	2014-10-13 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10250	2014-10-13 11:49:33	2017-09-24 17:47:27
12331	VICPDTCOM	2014-10-13 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10230	2014-10-13 11:50:58	2017-10-05 11:42:51
12332	VICPDTCOM	2014-10-13 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8244	2014-10-13 11:51:07	2017-10-05 11:42:48
12334	SECRETCOM	2014-10-13 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10236	2014-10-13 11:51:19	2017-10-01 10:20:50
12335	SECRETCOM	2014-10-13 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10245	2014-10-13 11:51:25	2017-10-05 11:42:53
12358	MEMBRECOM	2014-10-14 00:00:00	2015-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10305	2014-10-15 09:45:06	2015-10-07 10:48:17
11702	MEMBRECOM	2014-02-25 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9890	2014-02-25 16:23:02	2014-11-18 15:38:05
11706	MEMBRECOM	2014-02-25 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9898	2014-02-25 16:34:46	2014-11-18 15:38:05
11712	MEMBRECOM	2014-02-25 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9904	2014-02-25 16:35:32	2014-11-18 15:38:05
11724	RAPCOM	2014-03-11 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9909	2014-03-11 13:43:32	2014-11-18 15:38:05
11727	VICPDTCOM	2014-03-11 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9900	2014-03-11 13:45:05	2014-11-18 15:38:05
11730	VICPDTCOM	2014-03-11 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9912	2014-03-11 13:46:26	2014-11-18 15:38:05
11525	MEMBRECOM	2013-12-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9749	2013-12-10 15:07:23	2014-11-18 15:39:16
11531	MEMBRECOM	2013-12-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9755	2013-12-10 15:08:40	2014-11-18 15:39:16
11533	MEMBRECOM	2013-12-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9757	2013-12-10 15:12:18	2014-11-18 15:39:56
11543	MEMBRECOM	2013-12-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9767	2013-12-10 15:13:55	2014-11-18 15:39:56
11569	MEMBRECOM	2013-12-10 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9793	2013-12-10 17:26:58	2014-11-18 15:39:56
11595	VICPDTCOM	2013-12-18 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9792	2013-12-18 17:03:04	2014-11-18 15:39:56
11268	MEMBRECOM	2013-10-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9513	2013-10-15 18:02:13	2014-11-18 15:41:31
11273	MEMBRECOM	2013-10-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9518	2013-10-15 18:02:58	2014-11-18 15:41:31
11279	MEMBRECOM	2013-10-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9524	2013-10-15 18:03:51	2014-11-18 15:41:31
11287	MEMBRECOM	2013-10-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9532	2013-10-15 18:04:58	2014-11-18 15:41:31
11291	MEMBRECOM	2013-10-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9536	2013-10-15 18:05:39	2014-11-18 15:41:31
11294	MEMBRECOM	2013-10-15 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9539	2013-10-15 18:06:04	2014-11-18 15:41:31
11440	VICPDTCOM	2013-11-06 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9522	2013-11-06 17:26:50	2014-11-18 15:41:31
11443	VICPDTCOM	2013-11-06 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9531	2013-11-06 17:28:22	2014-11-18 15:41:31
11300	VICPDTCOM	2013-10-16 00:00:00	2014-05-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9368	2013-10-17 09:43:12	2014-11-18 15:42:14
9983	MEMBRECOM	2011-11-30 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8365	\N	2014-11-19 18:02:17
12359	MEMBRECOM	2014-12-10 00:00:00	2015-01-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10306	2014-12-16 17:30:40	2015-01-29 17:54:03
12360	MEMBRECOM	2014-12-10 00:00:00	2015-01-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10307	2014-12-16 17:31:26	2015-01-29 17:54:50
12361	MEMBRECOM	2014-12-10 00:00:00	2015-01-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10308	2014-12-16 17:31:40	2015-01-29 18:02:15
12362	MEMBRECOM	2014-12-10 00:00:00	2015-06-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10309	2014-12-16 17:35:20	2015-10-07 10:47:49
12363	MEMBRECOM	2014-12-10 00:00:00	2015-06-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10310	2014-12-16 17:35:32	2015-10-07 10:47:49
12364	MEMBRECOM	2014-12-10 00:00:00	2015-06-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10311	2014-12-16 17:35:40	2015-10-07 10:47:49
12365	MEMBRECOM	2014-12-10 00:00:00	2015-01-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10312	2014-12-16 17:35:50	2015-01-29 17:56:56
12366	MEMBRECOM	2014-12-10 00:00:00	2015-01-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10313	2014-12-16 17:36:00	2015-01-29 17:54:27
12367	MEMBRECOM	2014-12-10 00:00:00	2015-01-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10314	2014-12-16 17:36:09	2015-01-29 17:52:49
12368	MEMBRECOM	2014-12-10 00:00:00	2015-06-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10315	2014-12-16 17:36:19	2015-10-07 10:47:49
12369	MEMBRECOM	2014-12-10 00:00:00	2015-01-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10316	2014-12-16 17:36:30	2015-01-29 17:53:12
12370	MEMBRECOM	2014-12-10 00:00:00	2015-06-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10317	2014-12-16 17:36:39	2015-10-07 10:47:49
12371	MEMBRECOM	2014-12-10 00:00:00	2015-06-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10318	2014-12-16 17:36:49	2015-10-07 10:47:49
12372	MEMBRECOM	2014-12-10 00:00:00	2015-06-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10319	2014-12-16 17:36:57	2015-10-07 10:47:49
12373	MEMBRECOM	2014-12-10 00:00:00	2015-06-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10320	2014-12-16 17:37:06	2015-10-07 10:47:49
12374	MEMBRECOM	2014-12-10 00:00:00	2015-06-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10321	2014-12-16 17:37:16	2015-10-07 10:47:49
12375	MEMBRECOM	2014-12-10 00:00:00	2015-06-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10322	2014-12-16 17:37:23	2015-10-07 10:47:49
12376	MEMBRECOM	2014-12-10 00:00:00	2015-06-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10323	2014-12-16 17:37:35	2015-10-07 10:47:49
12377	MEMBRECOM	2014-12-10 00:00:00	2015-01-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10324	2014-12-16 17:37:46	2015-01-29 17:53:39
12378	MEMBRECOM	2014-12-10 00:00:00	2015-06-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10326	2014-12-16 17:38:21	2015-10-07 10:47:49
12379	MEMBRECOM	2014-12-10 00:00:00	2015-06-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10325	2014-12-16 17:39:25	2015-10-07 10:47:49
12396	MEMBRECOM	2014-02-03 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10344	\N	2017-09-24 16:45:26
12397	MEMBRECOM	2014-02-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10345	\N	\N
12398	MEMBRECOM	2014-02-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10346	\N	\N
12399	MEMBRECOM	2014-02-03 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10347	\N	2017-09-24 13:44:49
12400	MEMBRECOM	2014-02-03 00:00:00	2020-06-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10348	\N	\N
12401	MEMBRECOM	2014-02-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10349	\N	\N
12402	MEMBRECOM	2014-02-03 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10350	\N	2017-09-24 17:47:27
12403	MEMBRECOM	2014-02-03 00:00:00	2020-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10351	\N	\N
12416	PDTCOM	2014-02-05 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10364	\N	2017-09-24 17:09:24
12417	RAPCOM	2014-02-05 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10365	\N	\N
12418	RAPCOM	2014-02-05 00:00:00	2015-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10366	\N	2015-03-03 10:16:55
12419	MEMBRECOM	2014-02-05 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10367	\N	\N
12420	MEMBRECOM	2014-02-05 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10368	\N	2017-09-24 13:57:40
12421	MEMBRECOM	2014-02-05 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10369	\N	\N
12425	MEMBRECOM	2014-02-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10373	\N	\N
12427	MEMBRECOM	2014-02-05 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10375	\N	2017-09-24 18:16:52
12429	MEMBRECOM	2014-02-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10377	\N	\N
12430	MEMBRECOM	2014-02-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10378	\N	\N
12431	MEMBRECOM	2014-02-10 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10379	\N	2017-09-24 13:42:35
12433	MEMBRECOM	2014-02-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10381	\N	\N
12434	MEMBRECOM	2014-02-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10382	\N	\N
12439	VICPDTCOM	2014-02-17 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10387	\N	2017-09-24 17:42:25
12440	MEMBRECOM	2014-02-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10388	\N	\N
12441	MEMBRECOM	2014-02-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10389	\N	\N
12443	MEMBRECOM	2014-02-17 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10391	\N	2017-09-24 17:47:27
12444	MEMBRECOM	2014-02-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10392	\N	\N
12445	MEMBRECOM	2014-02-17 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10393	\N	2017-09-24 13:44:49
12446	MEMBRECOM	2014-02-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10394	\N	\N
12448	MEMBRECOM	2014-02-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10396	\N	\N
12449	MEMBRECOM	2014-02-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10397	\N	\N
12450	MEMBRECOM	2014-02-17 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10398	\N	2017-09-24 16:45:26
12456	MEMBRECOM	2014-04-30 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10404	\N	2017-09-24 13:29:42
12484	MEMBRECOM	2014-05-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10432	\N	\N
12485	MEMBRECOM	2014-05-14 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10433	\N	2017-09-24 13:57:40
12486	MEMBRECOM	2014-05-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10434	\N	\N
12487	MEMBRECOM	2014-05-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10435	\N	\N
12524	MEMBRECOM	2014-05-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10472	\N	\N
12525	MEMBRECOM	2014-05-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10473	\N	\N
12526	MEMBRECOM	2014-05-28 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10474	\N	2017-09-24 13:44:49
12176	PDTCOM	2014-10-09 00:00:00	2020-10-05 00:00:00	1	ANCIEN	\N	\N	\N	\N	8037	2014-10-09 10:50:52	2017-10-05 14:49:57
12177	VICPDTCOM	2014-10-09 00:00:00	2017-10-03 00:00:00	2	ANCIEN	\N	\N	\N	\N	2825	2014-10-09 10:51:33	2017-10-04 18:37:24
9739	MEMBRECOM	2011-10-01 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2825	\N	2014-10-09 10:51:34
12178	VICPDTCOM	2014-10-09 00:00:00	2017-10-04 00:00:00	3	ANCIEN	\N	\N	\N	\N	755	2014-10-09 10:52:00	2017-10-04 18:37:28
12179	VICPDTCOM	2014-10-09 00:00:00	2015-04-21 00:00:00	4	ANCIEN	\N	\N	\N	\N	844	2014-10-09 10:52:17	2015-04-21 17:14:30
12180	VICPDTCOM	2014-10-09 00:00:00	2017-10-03 00:00:00	5	ANCIEN	\N	\N	\N	\N	8094	2014-10-09 10:52:38	2017-10-04 18:38:54
12181	VICPDTCOM	2014-10-09 00:00:00	2015-06-12 00:00:00	6	ANCIEN	\N	\N	\N	\N	229	2014-10-09 10:52:58	2015-06-12 16:01:25
12182	VICPDTCOM	2014-10-09 00:00:00	2017-09-30 00:00:00	7	ANCIEN	\N	\N	\N	\N	4290	2014-10-09 10:53:16	2017-10-01 10:17:18
12183	VICPDTCOM	2014-10-09 00:00:00	2017-10-03 00:00:00	8	ANCIEN	\N	\N	\N	\N	2579	2014-10-09 10:53:33	2017-10-04 18:39:01
12184	VICPDTCOM	2014-10-09 00:00:00	2017-10-03 00:00:00	9	ANCIEN	\N	\N	\N	\N	2539	2014-10-09 10:53:49	2017-10-04 18:53:16
12185	VICPDTCOM	2014-10-09 00:00:00	2017-10-04 00:00:00	10	ANCIEN	\N	\N	\N	\N	2441	2014-10-09 10:54:11	2017-10-05 14:52:38
12186	VICPDTCOM	2014-10-09 00:00:00	2017-10-03 00:00:00	11	ANCIEN	\N	\N	\N	\N	8155	2014-10-09 10:54:30	2017-10-04 18:39:10
12187	SECRETCOM	2014-10-09 00:00:00	2015-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2607	2014-10-09 10:54:49	2015-07-20 11:24:06
12188	SECRETCOM	2014-10-09 00:00:00	2017-10-01 00:00:00	13	ANCIEN	\N	\N	\N	\N	8013	2014-10-09 10:57:31	2017-09-24 18:16:52
12189	SECRETCOM	2014-10-09 00:00:00	2017-10-03 00:00:00	14	ANCIEN	\N	\N	\N	\N	6826	2014-10-09 10:57:41	2017-10-04 18:39:17
12190	SECRETCOM	2014-10-09 00:00:00	2017-10-03 00:00:00	15	ANCIEN	\N	\N	\N	\N	8077	2014-10-09 10:57:51	2017-10-04 18:39:20
12191	PDTCOM	2014-10-09 00:00:00	2017-10-01 00:00:00	1	ANCIEN	\N	\N	\N	\N	8720	2014-10-09 11:02:50	2017-09-24 13:57:40
12193	VICPDTCOM	2014-10-09 00:00:00	2017-10-01 00:00:00	3	ANCIEN	\N	\N	\N	\N	8685	2014-10-09 11:03:45	2017-09-24 18:16:52
10332	MEMBRECOM	2012-02-21 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8685	\N	2014-10-09 11:03:46
12194	VICPDTCOM	2014-10-09 00:00:00	2017-10-04 00:00:00	4	ANCIEN	\N	\N	\N	\N	8834	2014-10-09 11:03:59	2017-10-04 18:36:49
12195	VICPDTCOM	2014-10-09 00:00:00	2017-10-04 00:00:00	5	ANCIEN	\N	\N	\N	\N	8689	2014-10-09 11:04:15	2017-10-04 18:36:53
12196	VICPDTCOM	2014-10-09 00:00:00	2017-09-30 00:00:00	6	ANCIEN	\N	\N	\N	\N	8694	2014-10-09 11:05:01	2017-10-01 10:01:39
12197	VICPDTCOM	2014-10-09 00:00:00	2017-10-04 00:00:00	7	ANCIEN	\N	\N	\N	\N	8696	2014-10-09 11:05:19	2017-10-04 18:36:56
12198	VICPDTCOM	2014-10-09 00:00:00	2017-10-03 00:00:00	8	ANCIEN	\N	\N	\N	\N	8702	2014-10-09 11:05:38	2017-10-04 18:36:59
12199	VICPDTCOM	2014-10-09 00:00:00	2017-10-03 00:00:00	9	ANCIEN	\N	\N	\N	\N	8710	2014-10-09 11:05:53	2017-10-04 18:37:03
12200	VICPDTCOM	2014-10-09 00:00:00	2017-10-01 00:00:00	10	ANCIEN	\N	\N	\N	\N	10159	2014-10-09 11:06:12	2017-09-24 17:14:26
12201	VICPDTCOM	2014-10-09 00:00:00	2017-10-03 00:00:00	11	ANCIEN	\N	\N	\N	\N	8749	2014-10-09 11:06:26	2017-10-04 20:57:13
10397	MEMBRECOM	2012-02-21 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8749	\N	2014-10-09 11:06:26
12202	SECRETCOM	2014-10-09 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8846	2014-10-09 11:06:42	2017-10-04 18:37:08
12204	SECRETCOM	2014-10-09 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8746	2014-10-09 11:07:06	2017-10-05 13:01:01
12206	MEMBRECOM	2014-10-09 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10248	2014-10-09 11:08:55	2017-10-05 11:42:58
12207	MEMBRECOM	2014-10-09 00:00:00	2016-04-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10249	2014-10-09 11:09:06	2016-04-26 14:12:00
12208	MEMBRECOM	2014-10-09 00:00:00	2014-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10250	2014-10-09 11:09:16	2014-10-13 11:49:33
12240	PDTCOM	2014-10-09 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2553	2014-10-09 13:50:09	2017-10-04 18:47:52
12241	VICPDTPRECOM	2014-10-09 00:00:00	2014-10-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	235	2014-10-09 13:50:24	2014-10-14 18:02:21
9741	MEMBRECOM	2011-10-01 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	235	\N	2014-10-09 13:50:24
12242	VICPDTCOM	2014-10-09 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2560	2014-10-09 13:50:34	2017-10-04 18:39:11
12243	VICPDTCOM	2014-10-09 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8836	2014-10-09 13:50:48	2017-09-24 17:09:24
12245	VICPDTCOM	2014-10-09 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	788	2014-10-09 13:51:15	2017-09-24 18:59:59
12246	VICPDTCOM	2014-10-09 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3673	2014-10-09 13:51:24	2017-09-24 19:25:10
12248	VICPDTCOM	2014-10-09 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4251	2014-10-09 13:51:39	2017-10-04 18:44:33
12249	VICPDTCOM	2014-10-09 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2631	2014-10-09 13:51:46	2017-10-04 18:45:35
12093	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2631	2014-10-08 17:51:52	2014-10-09 13:51:47
12250	VICPDTCOM	2014-10-09 00:00:00	2014-12-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10143	2014-10-09 13:51:54	2014-12-18 16:15:04
12253	SECRETCOM	2014-10-09 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10186	2014-10-09 13:52:21	2017-10-04 18:42:31
12254	SECRETCOM	2014-10-09 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10142	2014-10-09 13:52:41	2017-10-04 18:47:57
12255	SECRETCOM	2014-10-09 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8128	2014-10-09 13:52:49	2017-10-04 18:48:00
9638	MEMBRECOM	2011-10-01 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8128	\N	2014-10-09 13:52:50
12257	VICPDTCOM	2014-10-09 00:00:00	2017-07-11 00:00:00	1	ANCIEN	\N	\N	\N	\N	3944	2014-10-09 13:55:25	2017-07-12 14:22:38
12258	VICPDTCOM	2014-10-09 00:00:00	2017-10-01 00:00:00	2	ANCIEN	\N	\N	\N	\N	4275	2014-10-09 13:56:00	2017-09-24 17:19:42
12259	VICPDTCOM	2014-10-09 00:00:00	2016-12-31 00:00:00	3	ANCIEN	\N	\N	\N	\N	6897	2014-10-09 13:56:13	2017-01-03 11:09:24
12070	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6897	2014-10-08 17:48:56	2014-10-09 13:56:13
12260	VICPDTCOM	2014-10-09 00:00:00	2015-06-12 00:00:00	4	ANCIEN	\N	\N	\N	\N	10081	2014-10-09 13:56:24	2015-06-12 15:59:49
12261	VICPDTCOM	2014-10-09 00:00:00	2017-10-01 00:00:00	5	ANCIEN	\N	\N	\N	\N	207	2014-10-09 13:56:34	2017-09-24 12:39:59
12262	VICPDTCOM	2014-10-09 00:00:00	2017-10-01 00:00:00	6	ANCIEN	\N	\N	\N	\N	3752	2014-10-09 13:56:44	2017-09-24 18:16:52
12264	VICPDTCOM	2014-10-09 00:00:00	2017-10-04 00:00:00	8	ANCIEN	\N	\N	\N	\N	8156	2014-10-09 13:57:07	2017-10-04 18:49:11
12265	VICPDTCOM	2014-10-09 00:00:00	2017-10-01 00:00:00	9	ANCIEN	\N	\N	\N	\N	2546	2014-10-09 13:57:16	2017-09-24 17:15:15
12266	VICPDTCOM	2014-10-09 00:00:00	2017-10-01 00:00:00	10	ANCIEN	\N	\N	\N	\N	8150	2014-10-09 13:57:27	2017-09-24 17:47:28
12267	SECRETCOM	2014-10-09 00:00:00	2017-10-01 00:00:00	1	ANCIEN	\N	\N	\N	\N	2594	2014-10-09 13:57:38	2017-09-24 17:04:02
12268	SECRETCOM	2014-10-09 00:00:00	2017-10-04 00:00:00	2	ANCIEN	\N	\N	\N	\N	9930	2014-10-09 13:57:48	2017-10-04 18:49:33
12269	SECRETCOM	2014-10-09 00:00:00	2017-10-04 00:00:00	3	ANCIEN	\N	\N	\N	\N	2584	2014-10-09 13:57:59	2017-10-04 18:49:36
12271	SECRETCOM	2014-10-09 00:00:00	2017-10-01 00:00:00	5	ANCIEN	\N	\N	\N	\N	8969	2014-10-09 13:58:19	2017-09-24 18:20:10
12272	PDTCOM	2014-10-09 00:00:00	2015-12-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8195	2014-10-09 14:10:32	2015-12-16 17:18:48
12273	VICPDTCOM	2014-10-09 00:00:00	2015-12-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10223	2014-10-09 14:10:37	2015-12-16 17:18:52
12274	RAPCOM	2014-10-09 00:00:00	2015-12-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4242	2014-10-09 14:10:43	2015-12-16 17:18:53
12336	MEMBRECOM	2014-10-14 00:00:00	2014-10-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10283	2014-10-14 17:40:19	2015-01-29 17:49:44
12337	MEMBRECOM	2014-10-14 00:00:00	2014-10-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10284	2014-10-14 17:40:25	2015-01-29 17:50:16
12338	MEMBRECOM	2014-10-14 00:00:00	2015-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10285	2014-10-14 17:40:38	2015-10-07 10:48:17
12340	MEMBRECOM	2014-10-14 00:00:00	2014-10-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10288	2014-10-14 17:41:10	2015-01-29 17:50:39
12341	MEMBRECOM	2014-10-14 00:00:00	2015-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10289	2014-10-14 17:41:16	2015-10-07 10:48:17
12342	MEMBRECOM	2014-10-14 00:00:00	2015-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10290	2014-10-14 17:41:28	2015-10-07 10:48:17
12343	MEMBRECOM	2014-10-14 00:00:00	2015-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10291	2014-10-14 17:41:43	2015-10-07 10:48:17
12344	MEMBRECOM	2014-10-14 00:00:00	2014-10-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10292	2014-10-14 17:41:55	2015-01-29 17:48:20
12345	MEMBRECOM	2014-10-14 00:00:00	2015-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10293	2014-10-14 17:42:07	2015-10-07 10:48:17
12346	MEMBRECOM	2014-10-14 00:00:00	2015-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10294	2014-10-14 17:42:15	2015-10-07 10:48:17
12347	MEMBRECOM	2014-10-14 00:00:00	2015-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10295	2014-10-14 17:42:23	2015-10-07 10:48:17
12348	MEMBRECOM	2014-10-14 00:00:00	2015-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10296	2014-10-14 17:42:32	2015-10-07 10:48:17
12349	MEMBRECOM	2014-10-14 00:00:00	2015-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10297	2014-10-14 17:42:43	2015-10-07 10:48:17
12350	MEMBRECOM	2014-10-14 00:00:00	2015-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10298	2014-10-14 17:42:52	2015-10-07 10:48:17
12351	MEMBRECOM	2014-10-14 00:00:00	2015-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10299	2014-10-14 17:43:05	2015-10-07 10:48:17
12352	MEMBRECOM	2014-10-14 00:00:00	2015-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10300	2014-10-14 17:43:16	2015-10-07 10:48:17
12353	MEMBRECOM	2014-10-14 00:00:00	2015-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10301	2014-10-14 17:43:29	2015-10-07 10:48:17
12354	MEMBRECOM	2014-10-14 00:00:00	2014-10-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10302	2014-10-14 17:43:37	2015-01-29 17:51:05
12355	MEMBRECOM	2014-10-14 00:00:00	2014-10-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10303	2014-10-14 17:43:45	2015-01-29 17:48:58
12356	MEMBRECOM	2014-10-14 00:00:00	2015-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10286	2014-10-14 17:45:03	2015-10-07 10:48:17
12357	VICPDTCOM	2014-10-14 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	235	2014-10-14 18:02:21	2017-10-04 18:40:16
12435	MEMBRECOM	2014-02-10 00:00:00	2015-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10383	\N	2015-06-12 16:01:25
12436	MEMBRECOM	2014-02-10 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10384	\N	2017-09-25 10:54:33
12437	MEMBRECOM	2014-02-10 00:00:00	2017-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10385	\N	2017-06-19 12:20:59
12438	MEMBRECOM	2014-02-10 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10386	\N	2017-09-24 13:29:42
12527	MEMBRECOM	2014-05-28 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10475	\N	2017-09-24 17:47:27
12529	MEMBRECOM	2014-05-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10477	\N	\N
12530	MEMBRECOM	2014-05-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10478	\N	\N
12533	VICPDTCOM	2014-05-28 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10481	\N	2017-09-24 17:35:15
12545	PDTCOM	2014-05-26 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10493	\N	2017-09-24 17:35:15
12548	MEMBRECOM	2014-05-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10496	\N	\N
12550	MEMBRECOM	2014-05-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10498	\N	\N
12551	MEMBRECOM	2014-05-26 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10499	\N	2017-09-24 13:44:49
12552	MEMBRECOM	2014-05-26 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10500	\N	2017-09-24 17:47:27
12553	MEMBRECOM	2014-05-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10501	\N	\N
12590	VICPDTCOM	2014-07-10 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10538	\N	2017-09-24 17:09:24
12591	RAPCOM	2014-07-10 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10539	\N	\N
12616	MEMBRECOM	2014-07-10 00:00:00	2018-12-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10564	\N	\N
12617	MEMBRECOM	2014-07-10 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10565	\N	2017-09-24 17:19:42
12618	MEMBRECOM	2014-07-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10566	\N	\N
12647	MEMBRECOM	2014-07-16 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10595	\N	2017-09-24 18:20:10
12646	RAPCOM	2014-07-16 00:00:00	2017-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10594	\N	2017-09-25 09:56:00
12650	MEMBRECOM	2014-07-16 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10598	\N	2017-09-24 17:15:15
12651	MEMBRECOM	2014-07-16 00:00:00	2015-04-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10599	\N	2015-04-07 16:50:27
12652	MEMBRECOM	2014-07-16 00:00:00	2015-01-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10600	\N	2015-01-23 15:38:35
12653	MEMBRECOM	2014-07-16 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10601	\N	\N
12654	MEMBRECOM	2014-07-16 00:00:00	2021-07-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10602	\N	\N
12655	MEMBRECOM	2014-07-16 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10603	\N	2017-09-24 17:28:55
12656	MEMBRECOM	2014-07-16 00:00:00	2017-05-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10604	\N	2017-05-16 15:18:13
12657	MEMBRECOM	2014-07-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10605	\N	\N
12658	MEMBRECOM	2014-07-16 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10606	\N	\N
12704	MEMBRECOM	2014-10-14 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10652	\N	\N
12705	MEMBRECOM	2014-10-14 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10653	\N	2017-09-24 17:42:25
12707	MEMBRECOM	2014-10-14 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10655	\N	2017-09-24 13:44:49
12709	MEMBRECOM	2014-10-14 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10657	\N	2017-09-24 17:15:15
12710	MEMBRECOM	2014-10-14 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10658	\N	\N
12711	MEMBRECOM	2014-10-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10659	\N	\N
12738	MEMBRECOM	2014-11-19 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10686	\N	\N
12745	MEMBRECOM	2014-02-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10693	\N	\N
12747	RAPCOM	2014-11-20 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10695	\N	\N
12748	MEMBRECOM	2014-11-20 00:00:00	2021-07-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10696	\N	\N
12749	MEMBRECOM	2014-11-20 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10697	\N	\N
12750	MEMBRECOM	2014-11-20 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10698	\N	2017-09-24 17:15:15
12752	MEMBRECOM	2014-11-20 00:00:00	2015-04-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10700	\N	2015-04-07 16:50:27
12753	MEMBRECOM	2014-11-20 00:00:00	2017-06-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10701	\N	2017-06-02 10:02:57
12754	MEMBRECOM	2014-11-20 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10702	\N	\N
12755	MEMBRECOM	2014-11-20 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10703	\N	\N
12756	MEMBRECOM	2014-11-20 00:00:00	2020-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10704	\N	\N
12757	MEMBRECOM	2014-11-20 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10705	\N	\N
12758	MEMBRECOM	2014-11-20 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10706	\N	\N
12759	MEMBRECOM	2014-11-20 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10707	\N	\N
12761	RAPCOM	2014-11-20 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10709	\N	\N
12762	MEMBRECOM	2014-11-20 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10710	\N	\N
12764	MEMBRECOM	2014-11-20 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10712	\N	\N
12765	MEMBRECOM	2014-11-20 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10713	\N	2017-09-24 17:15:15
12766	MEMBRECOM	2014-11-20 00:00:00	2018-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10714	\N	2018-05-31 10:52:17
12767	MEMBRECOM	2014-11-20 00:00:00	2017-06-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10715	\N	2017-06-02 10:02:57
12768	MEMBRECOM	2014-11-20 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10716	\N	\N
12769	MEMBRECOM	2014-11-20 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10717	\N	\N
12770	MEMBRECOM	2014-11-20 00:00:00	2020-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10718	\N	\N
12771	MEMBRECOM	2014-11-20 00:00:00	2015-04-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10719	\N	2015-04-07 16:50:27
12773	MEMBRECOM	2014-11-20 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10721	\N	\N
12778	MEMBRECOM	2014-12-06 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10726	\N	2017-09-24 17:15:15
12788	PDTCOM	2014-12-12 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10736	\N	2017-09-24 18:20:10
12789	RAPCOM	2014-12-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10737	\N	\N
12790	MEMBRECOM	2014-12-12 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10738	\N	2017-09-24 17:15:15
12791	MEMBRECOM	2014-12-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10739	\N	\N
12792	MEMBRECOM	2014-12-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10740	\N	\N
12793	MEMBRECOM	2014-12-12 00:00:00	2015-04-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10741	\N	2015-04-07 16:50:27
12794	MEMBRECOM	2014-12-12 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10742	\N	2017-09-24 17:06:55
12795	MEMBRECOM	2014-12-12 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10743	\N	\N
12796	MEMBRECOM	2014-12-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10744	\N	\N
12797	MEMBRECOM	2014-12-12 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10745	\N	\N
12798	MEMBRECOM	2014-12-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10746	\N	\N
12800	MEMBRECOM	2014-12-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10748	\N	\N
12802	MEMBRECOM	2015-01-13 00:00:00	2017-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10750	2015-01-13 11:56:57	2017-06-19 16:04:13
12803	MEMBRECOM	2015-01-13 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10751	2015-01-13 11:58:37	2017-10-04 18:50:51
12804	MEMBRECOM	2015-01-13 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10752	2015-01-13 11:59:09	2017-10-05 11:42:58
12829	MEMBRECOM	2015-01-14 00:00:00	2015-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10778	2015-01-14 12:02:56	2015-10-12 14:47:38
12830	MEMBRECOM	2014-02-03 00:00:00	2014-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10779	2015-01-22 17:04:41	2015-01-22 17:16:56
12831	MEMBRECOM	2014-02-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10780	2015-01-22 17:08:06	\N
12832	MEMBRECOM	2014-02-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10781	2015-01-22 17:12:55	\N
12908	RAPCOM	2014-07-10 00:00:00	2015-03-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10855	2015-01-26 18:31:12	2015-03-18 17:05:53
12866	MEMBRECOM	2014-05-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10814	2015-01-23 15:28:27	2015-01-26 11:17:23
12867	MEMBRECOM	2014-05-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10815	2015-01-23 15:28:45	2015-01-26 11:16:06
12868	MEMBRECOM	2014-05-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10816	2015-01-23 15:29:07	2015-01-26 11:17:52
12880	MEMBRECOM	2014-07-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10828	2015-01-23 15:42:02	\N
12881	MEMBRECOM	2014-07-10 00:00:00	2014-07-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10829	2015-01-23 15:43:16	2015-01-23 15:54:04
12882	MEMBRECOM	2014-07-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10830	2015-01-23 15:44:09	\N
12909	MEMBRECOM	2015-01-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10856	2015-01-26 18:34:18	\N
12884	MEMBRECOM	2014-07-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10832	2015-01-23 15:45:58	\N
12885	MEMBRECOM	2014-07-10 00:00:00	2020-06-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10833	2015-01-23 15:46:37	\N
12886	MEMBRECOM	2014-07-10 00:00:00	2021-01-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10834	2015-01-23 15:47:19	\N
12887	PDTCOM	2014-07-10 00:00:00	2014-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10835	2015-01-23 15:48:47	2015-01-23 15:51:22
12888	RAPCOM	2014-07-10 00:00:00	2014-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10836	2015-01-23 15:49:09	2015-01-23 15:51:51
12889	MEMBRECOM	2014-07-10 00:00:00	2014-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10837	2015-01-23 15:49:31	2015-01-23 15:52:19
12890	MEMBRECOM	2014-07-10 00:00:00	2014-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10838	2015-01-23 15:49:48	2015-01-23 15:52:46
12891	MEMBRECOM	2014-07-10 00:00:00	2014-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10839	2015-01-23 15:50:16	2015-01-23 15:53:00
12893	RAPCOM	2014-07-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10841	2015-01-23 15:51:49	2015-01-23 15:52:00
12894	MEMBRECOM	2014-07-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10842	2015-01-23 15:52:17	\N
12895	MEMBRECOM	2014-07-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10843	2015-01-23 15:52:43	\N
12896	MEMBRECOM	2014-07-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10844	2015-01-23 15:52:58	\N
12897	MEMBRECOM	2014-07-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10845	2015-01-23 15:54:02	\N
12898	MEMBRECOM	2014-07-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10846	2015-01-23 15:54:20	\N
12899	MEMBRECOM	2014-07-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10847	2015-01-23 15:55:21	\N
12900	MEMBRECOM	2014-07-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10848	2015-01-23 15:56:39	\N
12901	MEMBRECOM	2014-07-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10849	2015-01-23 15:56:57	\N
12902	MEMBRECOM	2014-07-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10850	2015-01-23 15:57:12	\N
12907	RAPCOM	2015-01-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10855	2015-01-26 18:29:08	2015-01-26 18:29:30
12910	MEMBRECOM	2014-05-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10856	2015-01-26 18:36:48	\N
12912	MEMBRECOM	2015-01-27 00:00:00	2015-01-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10858	2015-01-27 16:36:52	2015-02-03 10:36:43
12913	MEMBRECOM	2015-01-27 00:00:00	2015-07-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10859	2015-01-27 16:36:58	2015-10-07 10:46:07
12914	MEMBRECOM	2015-01-27 00:00:00	2015-01-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10860	2015-01-27 16:37:09	2015-02-03 10:37:05
12915	MEMBRECOM	2015-01-27 00:00:00	2015-07-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10861	2015-01-27 16:37:26	2015-10-07 10:46:07
12916	MEMBRECOM	2015-01-27 00:00:00	2015-07-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10862	2015-01-27 16:37:35	2015-10-07 10:46:07
12917	MEMBRECOM	2015-01-27 00:00:00	2015-07-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10863	2015-01-27 16:37:44	2015-10-07 10:46:07
12096	MEMBRECOM	2014-10-08 00:00:00	2014-10-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4251	2014-10-08 17:52:08	2014-10-09 13:51:39
12381	MEMBRECOM	2014-12-18 00:00:00	2014-12-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10329	2014-12-18 16:23:55	2015-01-05 16:08:38
12452	MEMBRECOM	2014-04-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10400	\N	\N
12507	MEMBRECOM	2014-05-20 00:00:00	2018-12-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10455	\N	\N
12587	MEMBRECOM	2014-07-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10535	\N	2017-09-24 17:28:55
12601	MEMBRECOM	2014-07-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10549	\N	\N
12661	MEMBRECOM	2014-07-16 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10609	\N	2017-09-24 17:47:28
12662	MEMBRECOM	2014-07-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10610	\N	\N
12663	MEMBRECOM	2014-07-16 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10611	\N	2017-09-24 19:25:10
12664	MEMBRECOM	2014-07-16 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10612	\N	2017-09-24 12:57:09
12665	MEMBRECOM	2014-07-16 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10613	\N	2017-09-24 18:07:57
12666	MEMBRECOM	2014-07-16 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10614	\N	2017-09-24 13:44:49
12667	MEMBRECOM	2014-07-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10615	\N	\N
12919	MEMBRECOM	2015-01-27 00:00:00	2015-01-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10865	2015-01-27 16:38:04	2015-02-03 10:35:30
12669	MEMBRECOM	2014-07-16 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10617	\N	2017-09-24 16:45:26
12670	MEMBRECOM	2014-07-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10618	\N	\N
12671	PDTCOM	2014-07-18 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10619	\N	2017-09-24 17:09:24
12672	RAPCOM	2014-07-18 00:00:00	2018-11-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10620	\N	\N
12673	RAPCOM	2014-07-18 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10621	\N	2017-09-24 17:48:21
12675	MEMBRECOM	2014-07-18 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10623	\N	2017-09-24 16:45:26
12920	MEMBRECOM	2015-01-27 00:00:00	2015-07-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10866	2015-01-27 16:38:13	2015-10-07 10:46:07
12677	MEMBRECOM	2014-07-18 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10625	\N	2017-09-24 13:44:49
12678	MEMBRECOM	2014-07-18 00:00:00	2020-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10626	\N	\N
12680	MEMBRECOM	2014-07-18 00:00:00	2016-11-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10628	\N	2016-12-01 10:36:51
12921	MEMBRECOM	2015-01-27 00:00:00	2015-07-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10867	2015-01-27 16:38:26	2015-10-07 10:46:07
12683	MEMBRECOM	2014-07-18 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10631	\N	\N
12684	VICPDTCOM	2014-10-16 00:00:00	2015-04-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10632	\N	2015-04-21 17:14:30
12918	MEMBRECOM	2015-01-27 00:00:00	2015-01-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10864	2015-01-27 16:37:52	2015-02-03 10:36:20
12922	MEMBRECOM	2015-01-27 00:00:00	2015-07-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10868	2015-01-27 16:38:36	2015-10-07 10:46:07
12923	MEMBRECOM	2015-01-27 00:00:00	2015-07-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10869	2015-01-27 16:38:45	2015-10-07 10:46:07
12924	MEMBRECOM	2015-01-27 00:00:00	2015-01-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10870	2015-01-27 16:38:56	2015-02-03 10:35:05
12925	MEMBRECOM	2015-01-27 00:00:00	2015-07-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10871	2015-01-27 16:39:04	2015-10-07 10:46:07
12926	MEMBRECOM	2015-01-27 00:00:00	2015-01-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10872	2015-01-27 16:39:13	2015-02-03 10:35:56
12927	MEMBRECOM	2015-01-27 00:00:00	2015-07-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10873	2015-01-27 16:39:23	2015-10-07 10:46:07
12928	MEMBRECOM	2015-01-27 00:00:00	2015-07-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10874	2015-01-27 16:39:38	2015-10-07 10:46:07
12929	MEMBRECOM	2015-01-27 00:00:00	2015-07-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10875	2015-01-27 16:39:47	2015-10-07 10:46:07
12930	MEMBRECOM	2015-01-27 00:00:00	2015-07-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10876	2015-01-27 16:39:55	2015-10-07 10:46:07
12931	MEMBRECOM	2015-01-27 00:00:00	2015-07-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10877	2015-01-27 16:40:06	2015-10-07 10:46:07
12932	MEMBRECOM	2015-01-27 00:00:00	2015-07-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10878	2015-01-27 16:40:13	2015-10-07 10:46:07
12934	MEMBRECOM	2015-01-14 00:00:00	2015-01-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10879	2015-01-28 16:36:03	2015-01-30 14:46:30
12935	MEMBRECOM	2015-01-14 00:00:00	2015-01-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10880	2015-01-28 16:36:14	2015-01-30 14:46:35
12936	MEMBRECOM	2015-01-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10881	2015-01-28 16:36:24	\N
12937	MEMBRECOM	2015-01-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10882	2015-01-28 16:36:38	\N
12938	MEMBRECOM	2015-01-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10883	2015-01-28 16:36:48	\N
12939	MEMBRECOM	2015-01-14 00:00:00	2015-04-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10884	2015-01-28 16:36:57	2015-04-07 16:50:27
12940	MEMBRECOM	2015-01-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10885	2015-01-28 16:37:09	\N
12941	MEMBRECOM	2015-01-14 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10886	2015-01-28 16:37:16	\N
12942	MEMBRECOM	2015-01-14 00:00:00	2017-06-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10887	2015-01-28 16:37:31	2017-06-02 10:02:57
12943	MEMBRECOM	2015-01-14 00:00:00	2021-07-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10888	2015-01-28 16:37:43	\N
12944	MEMBRECOM	2015-01-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10889	2015-01-28 16:37:57	\N
12945	MEMBRECOM	2015-01-14 00:00:00	2017-05-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10890	2015-01-28 16:38:14	2017-05-16 15:18:13
12946	MEMBRECOM	2015-01-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10891	2015-01-28 16:38:33	\N
12947	MEMBRECOM	2015-01-14 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10892	2015-01-28 16:38:52	\N
12976	PDTCOM	2015-01-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10893	2015-01-30 09:29:01	2015-01-30 14:44:05
12977	RAPCOM	2015-01-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10894	2015-01-30 09:29:18	2015-01-30 14:44:10
12978	MEMBRECOM	2015-01-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10895	2015-01-30 09:30:04	\N
12979	MEMBRECOM	2015-01-30 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10896	2015-01-30 09:30:11	2017-09-24 18:17:56
12980	MEMBRECOM	2015-01-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10897	2015-01-30 09:30:20	\N
12981	MEMBRECOM	2015-01-30 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10898	2015-01-30 09:30:26	\N
12982	MEMBRECOM	2015-01-30 00:00:00	2017-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10899	2015-01-30 09:30:34	2017-06-19 16:04:13
13578	MEMBRECOM	2015-06-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11445	\N	\N
12983	MEMBRECOM	2015-01-30 00:00:00	2018-08-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10900	2015-01-30 09:32:58	\N
12985	MEMBRECOM	2015-01-30 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10902	2015-01-30 09:33:36	2017-09-24 17:15:15
12986	MEMBRECOM	2015-01-30 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10903	2015-01-30 09:37:27	\N
12987	MEMBRECOM	2015-01-30 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10904	2015-01-30 09:38:37	\N
12988	MEMBRECOM	2015-01-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10905	2015-01-30 09:38:51	\N
12989	MEMBRECOM	2015-01-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10906	2015-01-30 09:39:02	\N
12991	MEMBRECOM	2015-01-30 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10908	2015-01-30 14:37:54	\N
12992	MEMBRECOM	2015-01-30 00:00:00	2015-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10909	2015-01-30 14:38:03	2015-10-13 14:20:35
12993	MEMBRECOM	2015-01-30 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10910	2015-01-30 14:38:10	\N
12994	MEMBRECOM	2015-01-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10911	2015-01-30 14:38:16	\N
12995	MEMBRECOM	2015-01-30 00:00:00	2015-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10912	2015-01-30 14:38:22	2015-06-12 16:01:25
12996	RAPCOM	2015-01-30 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10913	2015-01-30 14:38:31	2017-10-01 10:42:05
12997	MEMBRECOM	2015-01-30 00:00:00	2017-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10914	2015-01-30 14:38:39	2017-07-24 09:56:26
12998	MEMBRECOM	2015-01-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10915	2015-01-30 14:38:46	\N
12999	MEMBRECOM	2015-01-30 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10916	2015-01-30 14:38:53	2017-09-24 19:25:10
13000	MEMBRECOM	2015-01-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10917	2015-01-30 14:39:06	\N
13001	MEMBRECOM	2015-01-30 00:00:00	2015-04-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10918	2015-01-30 14:39:16	2015-04-21 17:14:30
13003	MEMBRECOM	2015-01-30 00:00:00	2019-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10920	2015-01-30 14:39:33	\N
13005	RAPCOM	2015-01-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10880	2015-01-30 14:46:35	\N
13006	PDTCOM	2015-01-29 00:00:00	2015-07-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10870	2015-02-03 10:35:06	2015-10-07 10:46:07
13007	RAPCOM	2015-01-29 00:00:00	2015-07-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10865	2015-02-03 10:35:31	2015-10-07 10:46:07
13008	VICPDTCOM	2015-01-29 00:00:00	2015-07-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10872	2015-02-03 10:35:59	2015-10-07 10:46:07
13009	VICPDTCOM	2015-01-29 00:00:00	2015-07-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10864	2015-02-03 10:36:21	2015-10-07 10:46:07
13010	VICPDTCOM	2015-01-29 00:00:00	2015-07-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10858	2015-02-03 10:36:44	2015-10-07 10:46:07
13011	VICPDTCOM	2015-01-29 00:00:00	2015-07-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10860	2015-02-03 10:37:06	2015-10-07 10:46:07
13021	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11236	\N	\N
13023	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11243	\N	\N
13027	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11249	\N	\N
13030	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11264	\N	\N
13031	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11266	\N	\N
13032	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11267	\N	\N
13038	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11066	\N	\N
13039	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11071	\N	\N
13041	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11085	\N	\N
13042	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11095	\N	\N
13044	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11119	\N	\N
13052	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	10927	\N	\N
13605	MEMBRECOM	2015-06-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11472	\N	\N
13054	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	10933	\N	\N
13056	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	10935	\N	\N
13068	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	10964	\N	\N
13070	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	10972	\N	\N
13071	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	10975	\N	\N
13072	VICPDTCOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	10977	\N	\N
13076	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	10996	\N	\N
13077	VICPDTCOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	10998	\N	\N
13079	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11005	\N	\N
13084	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11018	\N	\N
13085	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11021	\N	\N
13088	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11033	\N	\N
13090	SECRETCOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11041	\N	\N
13092	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11044	\N	\N
13093	MEMBRECOM	\N	1991-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11045	\N	\N
13096	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11052	\N	\N
13100	PDTCOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11072	\N	\N
13101	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11078	\N	\N
13106	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11098	\N	\N
13107	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11104	\N	\N
13110	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11110	\N	\N
13111	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11113	\N	\N
13118	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11140	\N	\N
13122	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11147	\N	\N
13126	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11155	\N	\N
13135	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11184	\N	\N
13136	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11191	\N	\N
13138	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11194	\N	\N
13139	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11197	\N	\N
13142	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11211	\N	\N
13145	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11074	\N	\N
13146	PDTCOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11081	\N	\N
13148	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11171	\N	\N
13149	RAPGENCOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11183	\N	\N
13150	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11220	\N	\N
13151	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11232	\N	\N
13152	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11239	\N	\N
13154	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11253	\N	\N
13159	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	10954	\N	\N
13162	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	10982	\N	\N
13164	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11000	\N	\N
13166	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11019	\N	\N
13172	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11086	\N	\N
13174	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11101	\N	\N
13177	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11109	\N	\N
13182	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11178	\N	\N
13184	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11205	\N	\N
13186	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11230	\N	\N
13188	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11238	\N	\N
13189	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11247	\N	\N
13198	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11001	\N	\N
13200	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11017	\N	\N
13207	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11084	\N	\N
13208	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11112	\N	\N
13211	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11132	\N	\N
13212	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11152	\N	\N
13213	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11161	\N	\N
13217	SECRETCOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11196	\N	\N
13218	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11204	\N	\N
13222	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11255	\N	\N
13223	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11257	\N	\N
13225	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11265	\N	\N
13235	SECRETCOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11024	\N	\N
13236	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11058	\N	\N
13238	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11079	\N	\N
13241	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11100	\N	\N
13246	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11139	\N	\N
13247	VICPDTCOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11156	\N	\N
13369	MEMBRECOM	2015-02-16 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11276	2015-02-16 17:25:24	2017-10-05 14:35:46
13387	MEMBRECOM	2015-02-18 00:00:00	2015-02-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11294	2015-02-18 17:50:38	2015-02-27 11:18:17
13388	MEMBRECOM	2015-02-18 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11295	2015-02-18 17:50:52	2017-09-24 18:16:52
13389	MEMBRECOM	2015-02-18 00:00:00	2015-02-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11296	2015-02-18 17:51:06	2015-02-27 11:18:29
13390	MEMBRECOM	2015-02-18 00:00:00	2018-08-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11297	2015-02-18 17:51:17	\N
13391	MEMBRECOM	2015-02-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11298	2015-02-18 17:51:49	\N
13392	MEMBRECOM	2015-02-18 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11299	2015-02-18 17:52:03	2017-09-24 18:17:56
13393	MEMBRECOM	2015-02-18 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11300	2015-02-18 17:52:14	\N
13394	MEMBRECOM	2015-02-18 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11301	2015-02-18 17:52:26	\N
13395	MEMBRECOM	2015-02-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11302	2015-02-18 17:52:36	\N
13396	MEMBRECOM	2015-02-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11303	2015-02-18 17:52:57	\N
13397	MEMBRECOM	2015-02-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11304	2015-02-18 17:53:27	\N
13398	MEMBRECOM	2015-02-18 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11305	2015-02-18 17:53:39	\N
13400	MEMBRECOM	2015-02-18 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11307	2015-02-18 17:54:26	2017-09-24 13:14:55
13401	MEMBRECOM	2015-02-19 00:00:00	2015-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11308	2015-02-20 10:30:32	2015-10-07 10:43:00
13455	VICPDTCOM	2015-03-23 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11346	2015-03-23 13:06:47	2015-03-23 13:06:54
13456	MEMBRECOM	2015-03-23 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11347	2015-03-23 13:07:03	\N
13457	RAPCOM	2015-03-23 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11348	2015-03-23 13:07:13	2017-09-24 17:35:15
13458	MEMBRECOM	2015-03-23 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11349	2015-03-23 13:07:27	\N
13459	MEMBRECOM	2015-03-23 00:00:00	2015-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11350	2015-03-23 13:07:41	2015-10-13 14:20:31
13460	MEMBRECOM	2015-03-23 00:00:00	2015-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11351	2015-03-23 13:07:50	2015-06-12 16:01:25
13461	MEMBRECOM	2015-03-23 00:00:00	2017-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11352	2015-03-23 13:08:03	2017-07-24 09:56:26
13462	MEMBRECOM	2015-03-23 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11353	2015-03-23 13:08:16	2017-09-24 18:16:52
13463	MEMBRECOM	2015-03-23 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11354	2015-03-23 13:08:30	\N
13464	MEMBRECOM	2015-03-23 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11355	2015-03-23 13:08:43	\N
13465	MEMBRECOM	2015-03-23 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11356	2015-03-23 13:08:53	2017-10-01 10:17:18
13606	MEMBRECOM	2015-06-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11473	\N	\N
13466	MEMBRECOM	2015-03-23 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11357	2015-03-23 13:09:05	\N
13467	MEMBRECOM	2015-03-23 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11358	2015-03-23 13:09:23	\N
13468	MEMBRECOM	2015-03-23 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11359	2015-03-23 13:09:38	2017-09-24 18:16:52
13469	PDTCOM	2015-03-24 00:00:00	2016-04-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9861	2015-03-24 17:50:56	2016-07-07 18:35:27
13470	VICPDTCOM	2015-03-24 00:00:00	2016-04-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9870	2015-03-24 17:53:10	2016-07-07 18:30:57
11800	VICPDTCOM	2014-06-23 00:00:00	2015-01-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9941	2014-06-23 18:24:11	2015-04-07 18:21:18
11805	VICPDTCOM	2014-06-23 00:00:00	2015-01-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9979	2014-06-23 18:25:36	2015-04-07 18:21:18
11811	SECRETCOM	2014-06-23 00:00:00	2015-01-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9949	2014-06-23 18:33:54	2015-04-07 18:21:18
9458	MEMBRECOM	2011-07-05 00:00:00	2015-04-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7946	\N	2015-04-21 17:14:30
13502	MEMBRECOM	2015-05-06 00:00:00	2015-05-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11391	2015-05-05 14:58:51	2015-05-27 16:09:31
13503	MEMBRECOM	2015-05-06 00:00:00	2015-05-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11392	2015-05-05 14:59:00	2015-05-27 16:06:38
13504	MEMBRECOM	2015-05-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11393	2015-05-05 14:59:12	2015-05-05 16:20:31
13505	MEMBRECOM	2015-05-06 00:00:00	2016-01-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11394	2015-05-05 14:59:20	2016-01-11 17:34:09
13506	MEMBRECOM	2015-05-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11395	2015-05-05 14:59:27	2015-05-05 16:20:31
13507	MEMBRECOM	2015-05-06 00:00:00	2018-12-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11396	2015-05-05 14:59:34	2015-05-05 16:20:31
13508	MEMBRECOM	2015-05-06 00:00:00	2015-05-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11397	2015-05-05 14:59:42	2015-05-27 16:04:50
13509	MEMBRECOM	2015-05-06 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11398	2015-05-05 14:59:54	2017-09-24 17:48:21
13510	MEMBRECOM	2015-05-06 00:00:00	2015-05-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11400	2015-05-05 15:00:34	2015-05-27 16:08:28
13511	MEMBRECOM	2015-05-06 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11401	2015-05-05 15:00:43	2017-09-24 17:04:02
13512	MEMBRECOM	2015-05-06 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11402	2015-05-05 15:00:50	2015-05-05 16:20:31
13513	MEMBRECOM	2015-05-06 00:00:00	2015-05-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11403	2015-05-05 15:01:03	2015-05-27 16:07:24
13537	VICPDTCOM	2015-05-19 00:00:00	2016-04-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10273	2015-05-19 15:18:37	2016-07-07 18:26:42
13538	VICPDTCOM	2015-05-22 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8210	2015-05-22 16:21:54	2017-10-04 18:57:33
13543	VICPDTCOM	2015-05-27 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11392	2015-05-27 16:06:40	2017-10-01 10:39:22
13544	VICPDTCOM	2015-05-27 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11406	2015-05-27 16:07:03	\N
13545	VICPDTCOM	2015-05-27 00:00:00	2016-03-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11403	2015-05-27 16:07:25	2016-03-11 18:02:50
13546	VICPDTCOM	2015-05-27 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11400	2015-05-27 16:08:32	2017-09-24 17:15:15
13547	MEMBRECOM	2015-06-02 00:00:00	2015-06-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11418	2015-06-02 15:40:39	2015-06-04 17:17:40
13564	RAPCOM	2015-06-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11420	2015-06-04 17:17:51	\N
13549	MEMBRECOM	2015-06-02 00:00:00	2015-06-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11420	2015-06-02 15:41:03	2015-06-04 17:17:51
13550	MEMBRECOM	2015-06-02 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11421	2015-06-02 15:41:12	\N
13551	MEMBRECOM	2015-06-02 00:00:00	2015-06-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11422	2015-06-02 15:41:24	2015-06-04 17:17:58
13552	MEMBRECOM	2015-06-02 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11423	2015-06-02 15:41:32	2017-09-24 17:06:55
13553	MEMBRECOM	2015-06-02 00:00:00	2015-06-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11424	2015-06-02 15:42:19	2015-06-04 17:18:08
13554	MEMBRECOM	2015-06-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11425	2015-06-02 15:42:31	\N
13555	MEMBRECOM	2015-06-02 00:00:00	2017-08-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11426	2015-06-02 15:42:49	2017-08-07 16:31:39
13556	MEMBRECOM	2015-06-02 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11427	2015-06-02 15:42:58	\N
13557	MEMBRECOM	2015-06-02 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11428	2015-06-02 15:43:17	\N
13558	MEMBRECOM	2015-06-02 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11429	2015-06-02 15:43:46	2017-09-24 13:25:54
13559	MEMBRECOM	2015-06-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11430	2015-06-02 15:44:03	\N
13560	MEMBRECOM	2015-06-02 00:00:00	2017-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11431	2015-06-02 15:44:15	2017-06-19 16:06:01
13565	RAPCOM	2015-06-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11422	2015-06-04 17:17:58	\N
13562	MEMBRECOM	2015-06-02 00:00:00	2020-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11433	2015-06-02 15:47:06	\N
13563	VICPDTCOM	2015-06-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11418	2015-06-04 17:17:40	\N
13566	RAPCOM	2015-06-04 00:00:00	2019-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11424	2015-06-04 17:18:08	\N
13567	MEMBRECOM	2015-06-12 00:00:00	2015-06-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11434	2015-06-12 15:35:57	2015-06-30 15:57:23
13568	MEMBRECOM	2015-06-12 00:00:00	2015-06-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11435	2015-06-12 15:40:17	2015-06-17 12:12:37
9886	MEMBRECOM	2011-10-20 00:00:00	2015-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8263	\N	2015-06-12 15:59:49
10482	MEMBRECOM	2012-02-22 00:00:00	2015-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8795	\N	2015-06-12 15:59:49
10019	MEMBRECOM	2011-12-08 00:00:00	2015-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8373	\N	2015-06-12 15:59:49
4850	MEMBRECOM	2008-01-31 00:00:00	2008-02-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3935	\N	2015-06-12 16:01:25
10080	MEMBRECOM	2012-12-21 00:00:00	2015-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8434	\N	2015-06-12 16:01:25
13569	MEMBRECOM	2015-06-17 00:00:00	2019-03-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11436	2015-06-17 12:12:37	\N
13590	MEMBRECOM	2015-06-03 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11457	\N	2017-09-24 18:17:56
13571	MEMBRECOM	2015-06-22 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11438	2015-06-22 10:24:05	2017-10-05 11:42:55
13572	PDTCOM	2015-06-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11439	\N	\N
13573	RAPCOM	2015-06-03 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11440	\N	\N
13574	MEMBRECOM	2015-06-03 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11441	\N	\N
13575	MEMBRECOM	2015-06-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11442	\N	\N
13576	MEMBRECOM	2015-06-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11443	\N	\N
13577	MEMBRECOM	2015-06-03 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11444	\N	2017-09-24 19:25:10
13579	MEMBRECOM	2015-06-03 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11446	\N	2017-10-01 10:17:18
13580	MEMBRECOM	2015-06-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11447	\N	\N
13581	MEMBRECOM	2015-06-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11448	\N	\N
13582	MEMBRECOM	2015-06-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11449	\N	\N
13583	MEMBRECOM	2015-06-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11450	\N	\N
13584	MEMBRECOM	2015-06-03 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11451	\N	2017-09-24 18:17:56
13585	MEMBRECOM	2015-06-30 00:00:00	2015-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11452	2015-06-30 15:57:23	2015-07-10 11:26:16
13586	PDTCOM	2015-06-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11453	\N	\N
13587	RAPCOM	2015-06-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11454	\N	\N
13588	MEMBRECOM	2015-06-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11455	\N	\N
13589	MEMBRECOM	2015-06-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11456	\N	\N
13591	MEMBRECOM	2015-06-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11458	\N	\N
13251	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11193	\N	\N
13252	SECRETCOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11210	\N	\N
13254	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	10966	\N	\N
13259	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11059	\N	\N
13260	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11090	\N	\N
13261	SECRETCOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11153	\N	\N
13263	SECRETCOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11186	\N	\N
13264	PDTCOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11198	\N	\N
13265	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11221	\N	\N
13266	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11244	\N	\N
13267	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11250	\N	\N
13268	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11252	\N	\N
13273	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	10973	\N	\N
13280	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11047	\N	\N
13281	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11051	\N	\N
13282	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11069	\N	\N
13283	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11077	\N	\N
13284	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11087	\N	\N
13285	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11099	\N	\N
13286	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11103	\N	\N
13291	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11170	\N	\N
13292	VICPDTCOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11176	\N	\N
13293	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11189	\N	\N
13294	VICPDTCOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11190	\N	\N
13295	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11195	\N	\N
13297	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11226	\N	\N
13299	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11254	\N	\N
13301	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11263	\N	\N
13307	VICPDTCOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	10965	\N	\N
13310	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	10997	\N	\N
13311	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11027	\N	\N
13317	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11073	\N	\N
13319	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11089	\N	\N
13327	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11208	\N	\N
13332	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	10945	\N	\N
13333	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	10947	\N	\N
13334	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	10956	\N	\N
13336	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	10961	\N	\N
13342	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11034	\N	\N
13347	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11068	\N	\N
13349	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11115	\N	\N
13350	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11118	\N	\N
13356	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11164	\N	\N
13357	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11172	\N	\N
13358	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11173	\N	\N
13359	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11188	\N	\N
13360	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11209	\N	\N
13361	MEMBRECOM	\N	\N	\N	ACTIF	\N	\N	\N	Fonction créée par script à partir de la table EXTSENCOM_MANDAT	11212	\N	\N
13365	MEMBRECOM	2015-02-10 00:00:00	2015-02-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11273	2015-02-11 10:20:10	2015-02-11 10:20:50
13366	VICPDTCOM	2015-02-11 00:00:00	2015-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11273	2015-02-11 10:20:54	2015-10-07 10:43:00
13367	MEMBRECOM	2015-02-12 00:00:00	2015-02-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11274	2015-02-12 15:04:38	2015-02-16 17:21:48
13402	VICPDTCOM	2015-02-27 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11294	2015-02-27 11:18:17	\N
13403	RAPCOM	2015-02-27 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11296	2015-02-27 11:18:29	\N
13404	MEMBRECOM	2015-03-04 00:00:00	2015-03-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11309	2015-03-04 14:32:20	2015-03-12 09:46:57
13413	MEMBRECOM	2015-03-10 00:00:00	2015-03-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11310	2015-03-10 17:24:06	2015-03-16 10:01:26
13414	MEMBRECOM	2015-03-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11311	2015-03-10 17:24:17	\N
13415	MEMBRECOM	2015-03-10 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11312	2015-03-10 17:24:28	\N
13416	MEMBRECOM	2015-03-10 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11313	2015-03-10 17:24:36	\N
13417	MEMBRECOM	2015-03-10 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11314	2015-03-10 17:24:55	2017-10-01 10:20:50
13418	MEMBRECOM	2015-03-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11315	2015-03-10 17:25:04	\N
13419	MEMBRECOM	2015-03-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11316	2015-03-10 17:25:19	\N
13420	MEMBRECOM	2015-03-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11317	2015-03-10 17:25:27	\N
13421	MEMBRECOM	2015-03-10 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11318	2015-03-10 17:25:51	2017-09-24 13:47:46
13422	MEMBRECOM	2015-03-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11319	2015-03-10 17:25:59	\N
13423	MEMBRECOM	2015-03-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11320	2015-03-10 17:26:10	\N
13424	MEMBRECOM	2015-03-10 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11321	2015-03-10 17:26:18	2017-09-24 17:47:27
13425	MEMBRECOM	2015-03-10 00:00:00	2017-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11322	2015-03-10 17:26:31	2017-06-19 16:06:01
13426	MEMBRECOM	2015-03-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11323	2015-03-10 17:26:45	\N
13427	MEMBRECOM	2015-03-10 00:00:00	2015-03-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11324	2015-03-10 17:27:32	2015-03-16 10:14:43
13428	MEMBRECOM	2015-03-10 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11325	2015-03-10 17:27:40	\N
13429	MEMBRECOM	2015-03-10 00:00:00	2015-03-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11326	2015-03-10 17:27:52	2015-03-16 10:14:58
13430	MEMBRECOM	2015-03-10 00:00:00	2018-08-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11327	2015-03-10 17:27:58	\N
13431	MEMBRECOM	2015-03-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11328	2015-03-10 17:28:10	\N
13432	MEMBRECOM	2015-03-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11329	2015-03-10 17:28:18	\N
13433	MEMBRECOM	2015-03-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11330	2015-03-10 17:28:28	\N
13434	MEMBRECOM	2015-03-10 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11331	2015-03-10 17:28:36	\N
13435	MEMBRECOM	2015-03-10 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11332	2015-03-10 17:28:50	2017-09-24 17:15:15
13436	MEMBRECOM	2015-03-10 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11333	2015-03-10 17:28:58	\N
13437	MEMBRECOM	2015-03-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11334	2015-03-10 17:29:11	\N
13438	MEMBRECOM	2015-03-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11335	2015-03-10 17:29:19	\N
13439	MEMBRECOM	2015-03-10 00:00:00	2017-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11336	2015-03-10 17:29:33	2017-06-19 16:04:13
13440	MEMBRECOM	2015-03-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11337	2015-03-10 17:29:45	\N
13441	MEMBRECOM	2015-03-12 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11338	2015-03-12 09:46:56	2017-09-24 18:07:57
11246	MEMBRECOM	2013-07-12 00:00:00	2015-04-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9490	\N	2015-04-07 16:50:27
10037	MEMBRECOM	2011-12-19 00:00:00	2015-04-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8391	\N	2015-04-07 16:50:27
10760	MEMBRECOM	2012-12-13 00:00:00	2015-04-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9047	\N	2015-04-07 16:50:27
10050	MEMBRECOM	2011-12-19 00:00:00	2015-04-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8404	\N	2015-04-07 16:50:27
13473	MEMBRECOM	2015-04-08 00:00:00	2015-05-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11361	2015-04-07 17:15:52	2015-05-06 11:43:03
13368	MEMBRECOM	2015-02-16 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11275	2015-02-16 17:21:48	2017-10-04 18:35:47
13370	MEMBRECOM	2015-02-18 00:00:00	2015-03-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11277	2015-02-17 15:30:13	2015-03-09 13:58:11
13371	MEMBRECOM	2015-02-18 00:00:00	2015-07-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11278	2015-02-17 15:30:21	2015-10-07 10:45:34
13372	MEMBRECOM	2015-02-18 00:00:00	2015-03-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11279	2015-02-17 15:30:28	2015-03-09 13:54:19
13373	MEMBRECOM	2015-02-18 00:00:00	2015-03-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11280	2015-02-17 15:30:43	2015-03-09 13:56:00
13374	MEMBRECOM	2015-02-18 00:00:00	2015-03-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11281	2015-02-17 16:35:15	2015-03-09 13:55:35
13375	MEMBRECOM	2015-02-18 00:00:00	2015-07-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11282	2015-02-17 16:35:30	2015-10-07 10:45:34
13376	MEMBRECOM	2015-02-18 00:00:00	2015-07-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11283	2015-02-17 16:35:38	2015-10-07 10:45:34
13377	MEMBRECOM	2015-02-18 00:00:00	2015-07-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11284	2015-02-17 16:35:46	2015-10-07 10:45:34
13378	MEMBRECOM	2015-02-18 00:00:00	2015-03-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11285	2015-02-17 16:35:53	2015-03-09 13:53:49
13379	MEMBRECOM	2015-02-18 00:00:00	2015-03-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11286	2015-02-17 16:36:02	2015-03-09 13:58:33
13380	MEMBRECOM	2015-02-18 00:00:00	2015-07-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11287	2015-02-17 16:36:11	2015-10-07 10:45:34
13381	MEMBRECOM	2015-02-18 00:00:00	2015-07-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11288	2015-02-17 16:36:19	2015-10-07 10:45:34
13382	MEMBRECOM	2015-02-18 00:00:00	2015-02-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11289	2015-02-18 10:03:02	2015-03-16 16:46:02
13383	MEMBRECOM	2015-02-18 00:00:00	2015-03-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11290	2015-02-18 10:03:13	2015-03-09 13:54:50
13384	MEMBRECOM	2015-02-18 00:00:00	2015-03-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11291	2015-02-18 10:03:21	2015-03-09 13:55:15
13385	MEMBRECOM	2015-02-18 00:00:00	2015-07-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11292	2015-02-18 10:03:31	2015-10-07 10:45:34
13386	MEMBRECOM	2015-02-18 00:00:00	2015-07-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11293	2015-02-18 10:03:39	2015-10-07 10:45:34
13405	PDTCOM	2015-03-05 00:00:00	2015-07-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11285	2015-03-09 13:53:49	2015-10-07 10:45:34
13406	RAPCOM	2015-03-05 00:00:00	2015-07-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11279	2015-03-09 13:54:19	2015-10-07 10:45:34
13407	VICPDTCOM	2015-03-05 00:00:00	2015-07-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11290	2015-03-09 13:54:51	2015-10-07 10:45:34
13408	VICPDTCOM	2015-03-05 00:00:00	2015-07-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11291	2015-03-09 13:55:15	2015-10-07 10:45:34
13409	VICPDTCOM	2015-03-05 00:00:00	2015-07-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11281	2015-03-09 13:55:36	2015-10-07 10:45:34
13410	VICPDTCOM	2015-03-05 00:00:00	2015-07-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11280	2015-03-09 13:56:01	2015-10-07 10:45:34
13411	VICPDTCOM	2015-03-05 00:00:00	2015-07-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11277	2015-03-09 13:58:12	2015-10-07 10:45:34
13412	VICPDTCOM	2015-03-05 00:00:00	2015-07-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11286	2015-03-09 13:58:34	2015-10-07 10:45:34
13442	VICPDTCOM	2015-03-16 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11310	2015-03-16 10:01:26	2017-09-24 13:57:40
13443	PDTCOM	2015-03-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11324	2015-03-16 10:14:42	\N
13444	RAPCOM	2015-03-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11326	2015-03-16 10:14:58	\N
13445	MEMBRECOM	2015-02-18 00:00:00	2015-07-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11339	2015-03-16 16:46:23	2015-10-07 10:45:34
13446	MEMBRECOM	2015-03-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10807	2015-03-18 16:29:11	\N
13447	VICPDTCOM	2015-03-18 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11340	2015-03-18 16:30:01	2015-03-18 16:30:07
13448	MEMBRECOM	2015-03-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11341	2015-03-18 16:30:36	\N
13449	MEMBRECOM	2015-03-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	10413	2015-03-18 16:55:06	\N
13450	RAPCOM	2015-03-18 00:00:00	2021-01-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10801	2015-03-18 16:58:20	2015-03-18 16:58:26
13451	MEMBRECOM	2015-03-18 00:00:00	2020-06-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11342	2015-03-18 17:01:08	\N
13475	MEMBRECOM	2015-04-08 00:00:00	2015-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11363	2015-04-14 14:59:41	2016-05-03 09:48:36
13474	MEMBRECOM	2015-04-08 00:00:00	2015-05-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11362	2015-04-14 14:59:28	2015-05-18 14:33:56
13476	MEMBRECOM	2015-04-08 00:00:00	2015-05-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11364	2015-04-14 14:59:49	2015-05-18 14:30:15
13477	MEMBRECOM	2015-04-08 00:00:00	2015-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11365	2015-04-14 14:59:56	2016-05-03 09:48:36
13478	MEMBRECOM	2015-04-08 00:00:00	2015-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11366	2015-04-14 15:09:20	2016-05-03 09:48:35
13479	MEMBRECOM	2015-04-08 00:00:00	2015-05-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11367	2015-04-14 15:16:14	2015-05-18 14:31:47
13480	MEMBRECOM	2015-04-08 00:00:00	2015-05-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11368	2015-04-14 15:44:39	2015-05-18 14:31:17
13481	MEMBRECOM	2015-04-08 00:00:00	2015-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11369	2015-04-14 15:44:46	2016-05-03 09:48:35
13482	MEMBRECOM	2015-04-08 00:00:00	2015-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11370	2015-04-14 15:44:58	2016-05-03 09:48:36
13483	MEMBRECOM	2015-04-08 00:00:00	2015-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11371	2015-04-14 15:45:06	2016-05-03 09:48:35
13484	MEMBRECOM	2015-04-08 00:00:00	2015-05-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11372	2015-04-14 15:45:17	2015-05-18 14:33:34
13485	MEMBRECOM	2015-04-08 00:00:00	2015-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11373	2015-04-14 15:45:26	2016-05-03 09:48:35
13486	MEMBRECOM	2015-04-08 00:00:00	2015-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11374	2015-04-14 15:45:34	2016-05-03 09:48:36
13487	MEMBRECOM	2015-04-08 00:00:00	2015-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11375	2015-04-14 15:45:42	2016-05-03 09:48:36
13488	MEMBRECOM	2015-04-08 00:00:00	2015-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11376	2015-04-14 15:45:51	2016-05-03 09:48:36
13489	MEMBRECOM	2015-04-08 00:00:00	2015-05-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11377	2015-04-14 15:53:51	2015-05-18 14:30:40
13490	MEMBRECOM	2015-04-08 00:00:00	2015-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11378	2015-04-14 15:53:57	2016-05-03 09:48:35
13491	MEMBRECOM	2015-04-08 00:00:00	2015-05-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11380	2015-04-14 15:54:20	2015-05-18 14:34:17
13492	MEMBRECOM	2015-04-08 00:00:00	2015-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11381	2015-04-14 15:54:28	2016-05-03 09:48:35
13493	MEMBRECOM	2015-04-08 00:00:00	2015-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11382	2015-04-14 15:54:41	2016-05-03 09:48:35
13494	MEMBRECOM	2015-04-08 00:00:00	2015-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11383	2015-04-14 15:54:50	2016-05-03 09:48:35
13495	MEMBRECOM	2015-04-08 00:00:00	2015-05-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11384	2015-04-14 16:09:57	2015-05-18 14:33:03
13496	MEMBRECOM	2015-04-08 00:00:00	2015-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11379	2015-04-14 16:32:02	2016-05-03 09:48:36
13497	MEMBRECOM	2015-04-22 00:00:00	2015-05-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11385	2015-04-22 16:49:30	2015-05-04 11:14:58
13498	MEMBRECOM	2015-05-04 00:00:00	2015-05-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11386	2015-05-04 10:27:12	2015-05-12 18:11:45
13499	MEMBRECOM	2015-05-04 00:00:00	2015-05-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11387	2015-05-04 10:29:04	2015-05-12 18:12:05
13514	MEMBRECOM	2015-05-06 00:00:00	2015-05-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11404	2015-05-05 15:53:16	2015-05-27 16:09:14
13515	MEMBRECOM	2015-05-06 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11405	2015-05-05 15:53:21	2017-09-24 18:16:52
13516	MEMBRECOM	2015-05-06 00:00:00	2015-05-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11406	2015-05-05 15:53:28	2015-05-27 16:07:01
13517	MEMBRECOM	2015-05-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11407	2015-05-05 15:53:36	2015-05-05 16:20:31
13518	MEMBRECOM	2015-05-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11408	2015-05-05 15:53:45	2015-05-05 16:20:31
13519	MEMBRECOM	2015-05-06 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11409	2015-05-05 15:53:51	2015-05-05 16:20:31
13520	MEMBRECOM	2015-05-06 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11410	2015-05-05 16:18:22	2015-05-05 16:20:31
13521	MEMBRECOM	2015-05-06 00:00:00	2015-05-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11411	2015-05-05 16:18:31	2015-05-27 16:08:59
13522	MEMBRECOM	2015-05-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11399	2015-05-05 17:19:49	\N
13524	MEMBRECOM	2015-05-06 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11414	2015-05-06 11:42:36	2017-10-04 18:38:42
11980	MEMBRECOM	2014-10-08 00:00:00	2015-05-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10148	2014-10-08 17:06:19	2015-05-06 11:42:37
13525	MEMBRECOM	2015-05-06 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11415	2015-05-06 11:43:03	2017-09-24 17:06:55
13526	VICPDTCOM	2015-05-06 00:00:00	2017-10-04 00:00:00	4	ANCIEN	\N	\N	\N	\N	3892	2015-05-06 17:34:47	2017-10-05 14:50:37
13527	MEMBRECOM	2015-05-12 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11416	2015-05-12 00:00:00	\N
13528	MEMBRECOM	2015-05-12 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11417	2015-05-12 18:12:05	\N
13529	PDTCOM	2015-05-13 00:00:00	2015-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11364	2015-05-18 14:30:15	2016-05-03 09:48:36
13530	RAPCOM	2015-05-13 00:00:00	2015-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11377	2015-05-18 14:30:40	2016-05-03 09:48:35
13531	VICPDTCOM	2015-05-13 00:00:00	2015-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11368	2015-05-18 14:31:17	2016-05-03 09:48:35
13532	VICPDTCOM	2015-05-13 00:00:00	2015-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11367	2015-05-18 14:31:48	2016-05-03 09:48:35
13533	VICPDTCOM	2015-05-13 00:00:00	2015-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11384	2015-05-18 14:33:03	2016-05-03 09:48:35
13534	VICPDTCOM	2015-05-13 00:00:00	2015-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11372	2015-05-18 14:33:34	2016-05-03 09:48:35
13535	VICPDTCOM	2015-05-13 00:00:00	2015-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11362	2015-05-18 14:33:56	2016-05-03 09:48:36
13536	VICPDTCOM	2015-05-13 00:00:00	2015-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11380	2015-05-18 14:34:19	2016-05-03 09:48:35
13540	RAPCOM	2015-05-27 00:00:00	2017-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11411	2015-05-27 16:05:17	2017-06-19 12:20:59
13541	VICPDTCOM	2015-05-27 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11404	2015-05-27 16:05:46	2017-09-24 18:05:41
13542	VICPDTCOM	2015-05-27 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11391	2015-05-27 16:06:14	2015-05-27 16:09:35
13707	MEMBRECOM	2015-06-17 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11563	\N	\N
13714	MEMBRECOM	2015-06-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11570	\N	\N
13716	MEMBRECOM	2015-06-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11572	\N	\N
13719	RAPCOM	2015-07-25 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11575	\N	2017-09-24 18:16:52
13732	MEMBRECOM	2015-07-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11588	\N	\N
13737	MEMBRECOM	2015-07-09 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11593	\N	2017-09-24 17:06:55
13761	RAPCOM	2015-07-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11617	\N	\N
13773	PDTRAPCOM	2015-09-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11629	\N	\N
13774	MEMBRECOM	2015-09-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11630	\N	\N
13775	MEMBRECOM	2015-09-08 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11631	\N	\N
13779	MEMBRECOM	2015-09-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11635	\N	\N
13783	MEMBRECOM	2015-09-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11639	\N	\N
13785	MEMBRECOM	2015-09-08 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11641	\N	\N
13786	MEMBRECOM	2015-09-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11642	\N	\N
13787	MEMBRECOM	2015-09-08 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11643	\N	\N
13788	MEMBRECOM	2015-09-08 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11644	\N	\N
13790	MEMBRECOM	2015-09-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11646	\N	\N
13791	MEMBRECOM	2015-09-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11647	\N	\N
13792	MEMBRECOM	2015-09-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11648	\N	\N
13793	MEMBRECOM	2015-09-16 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11649	\N	2017-09-24 18:17:56
13794	MEMBRECOM	2015-09-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11650	\N	\N
14344	PDTCOM	2016-05-03 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12179	2016-05-03 17:22:50	2017-06-12 11:08:26
13796	MEMBRECOM	2015-09-16 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11652	\N	\N
13797	MEMBRECOM	2015-09-16 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11653	\N	2017-09-25 10:54:33
13798	MEMBRECOM	2015-09-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11654	\N	\N
13799	MEMBRECOM	2015-09-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11655	\N	\N
13801	MEMBRECOM	2015-09-16 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11657	\N	\N
13802	MEMBRECOM	2015-09-16 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11658	\N	2017-09-24 13:29:42
14345	RAPCOM	2016-05-03 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12165	2016-05-03 17:23:00	2017-06-12 11:08:26
14348	VICPDTCOM	2016-05-03 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12176	2016-05-03 17:23:24	2017-06-12 11:08:26
14349	VICPDTCOM	2016-05-03 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12174	2016-05-03 17:23:30	2017-06-12 11:08:26
14350	VICPDTCOM	2016-05-03 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12187	2016-05-03 17:23:36	2017-06-12 11:08:26
14351	VICPDTCOM	2016-05-03 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12162	2016-05-03 17:23:46	2017-06-12 11:08:26
14611	MEMBRECOM	2016-06-23 00:00:00	2016-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12439	2016-06-24 20:15:45	2016-06-30 15:31:51
14612	MEMBRECOM	2016-06-23 00:00:00	2016-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12440	2016-06-24 20:15:49	2016-06-30 15:31:51
14613	MEMBRECOM	2016-06-23 00:00:00	2016-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12441	2016-06-24 20:15:53	2016-06-30 15:31:51
14614	MEMBRECOM	2016-06-23 00:00:00	2016-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12442	2016-06-24 20:15:58	2016-06-30 15:31:51
14615	MEMBRECOM	2016-06-23 00:00:00	2016-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12443	2016-06-24 20:16:03	2016-06-30 15:31:51
14616	MEMBRECOM	2016-06-23 00:00:00	2016-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12444	2016-06-24 20:16:07	2016-06-30 15:31:51
14617	MEMBRECOM	2016-06-23 00:00:00	2016-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12445	2016-06-24 20:16:14	2016-06-30 15:31:51
14618	MEMBRECOM	2016-06-23 00:00:00	2016-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12446	2016-06-24 20:16:20	2016-06-30 15:31:51
14619	PDTCOM	2016-06-28 00:00:00	2016-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12389	2016-06-28 19:39:55	2016-07-07 16:33:43
14620	RAPCOM	2016-06-28 00:00:00	2016-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12382	2016-06-28 19:40:14	2016-07-07 16:33:43
13607	MEMBRECOM	2015-06-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11474	\N	\N
14621	RAPCOM	2016-06-28 00:00:00	2016-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12385	2016-06-28 19:40:23	2016-07-07 16:33:43
14622	VICPDTCOM	2016-06-28 00:00:00	2016-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12371	2016-06-28 19:40:33	2016-07-07 16:33:43
14623	VICPDTCOM	2016-06-28 00:00:00	2016-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12377	2016-06-28 19:40:39	2016-07-07 16:33:43
14624	VICPDTCOM	2016-06-28 00:00:00	2016-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12378	2016-06-28 19:40:52	2016-07-07 16:33:43
14625	VICPDTCOM	2016-06-28 00:00:00	2016-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12383	2016-06-28 19:41:00	2016-07-07 16:33:43
14626	VICPDTCOM	2016-06-28 00:00:00	2016-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12392	2016-06-28 19:41:14	2016-07-07 16:33:43
14627	VICPDTCOM	2016-06-28 00:00:00	2016-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12393	2016-06-28 19:41:42	2016-07-07 16:33:43
14628	VICPDTCOM	2016-06-28 00:00:00	2016-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12396	2016-06-28 19:41:47	2016-07-07 16:33:43
14629	VICPDTCOM	2016-06-28 00:00:00	2016-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12399	2016-06-28 19:41:52	2016-07-07 16:33:43
14630	VICPDTCOM	2016-06-28 00:00:00	2016-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12400	2016-06-28 19:41:58	2016-07-07 16:33:43
14631	VICPDTCOM	2016-06-28 00:00:00	2016-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12401	2016-06-28 19:42:03	2016-07-07 16:33:43
14632	SECRETCOM	2016-06-28 00:00:00	2016-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12376	2016-06-28 19:42:13	2016-07-07 16:33:43
14633	SECRETCOM	2016-06-28 00:00:00	2016-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12386	2016-06-28 19:42:20	2016-07-07 16:33:43
14634	SECRETCOM	2016-06-28 00:00:00	2016-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12404	2016-06-28 19:42:25	2016-07-07 16:33:43
14635	PDTCOM	2016-06-29 00:00:00	2016-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12418	2016-06-29 14:52:12	2016-10-07 09:16:24
14636	RAPCOM	2016-06-29 00:00:00	2016-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12410	2016-06-29 14:52:20	2016-10-07 09:16:24
14637	VICPDTCOM	2016-06-29 00:00:00	2016-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12407	2016-06-29 14:52:31	2016-10-07 09:16:24
14638	VICPDTCOM	2016-06-29 00:00:00	2016-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12413	2016-06-29 14:52:40	2016-10-07 09:16:24
14639	VICPDTCOM	2016-06-29 00:00:00	2016-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12415	2016-06-29 14:52:46	2016-10-07 09:16:24
14640	VICPDTCOM	2016-06-29 00:00:00	2016-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12419	2016-06-29 14:52:52	2016-10-07 09:16:24
14641	VICPDTCOM	2016-06-29 00:00:00	2016-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12429	2016-06-29 14:52:57	2016-10-07 09:16:24
14642	VICPDTCOM	2016-06-29 00:00:00	2016-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12432	2016-06-29 14:53:02	2016-10-07 09:16:24
14643	PDTCOM	2016-06-30 00:00:00	2016-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12447	2016-06-30 15:35:51	2016-10-07 09:19:22
14647	MEMBRECOM	2016-06-30 00:00:00	2016-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12451	2016-06-30 15:37:17	2016-10-07 09:19:22
14645	RAPCOM	2016-06-30 00:00:00	2016-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12449	2016-06-30 15:36:23	2016-10-07 09:19:22
14646	MEMBRECOM	2016-06-30 00:00:00	2016-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12450	2016-06-30 15:36:55	2016-10-07 09:19:22
14648	MEMBRECOM	2016-06-30 00:00:00	2016-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12452	2016-06-30 15:37:23	2016-10-07 09:19:22
14649	MEMBRECOM	2016-06-30 00:00:00	2016-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12453	2016-06-30 15:37:30	2016-10-07 09:19:22
14650	MEMBRECOM	2016-06-30 00:00:00	2016-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12454	2016-06-30 15:37:35	2016-10-07 09:19:22
14651	MEMBRECOM	2016-06-30 00:00:00	2016-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12455	2016-06-30 15:37:42	2016-10-07 09:19:22
14652	MEMBRECOM	2016-06-30 00:00:00	2016-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12456	2016-06-30 15:37:47	2016-10-07 09:19:22
14653	MEMBRECOM	2016-06-30 00:00:00	2016-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12457	2016-06-30 15:37:56	2016-10-07 09:19:22
14654	MEMBRECOM	2016-06-30 00:00:00	2016-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12458	2016-06-30 15:38:01	2016-10-07 09:19:22
14655	MEMBRECOM	2016-06-30 00:00:00	2016-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12459	2016-06-30 15:38:06	2016-10-07 09:19:22
14656	MEMBRECOM	2016-06-30 00:00:00	2016-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12460	2016-06-30 15:38:13	2016-10-07 09:19:22
14657	MEMBRECOM	2016-06-30 00:00:00	2016-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12461	2016-06-30 15:38:19	2016-10-07 09:19:22
14575	MEMBRECOM	2016-06-22 00:00:00	2016-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12403	2016-06-22 16:32:57	2016-07-07 16:33:43
14658	MEMBRECOM	2016-07-07 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12462	2016-07-07 17:23:36	2017-06-12 11:07:18
14659	MEMBRECOM	2016-07-07 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12463	2016-07-07 17:23:41	2017-06-12 11:07:18
14660	MEMBRECOM	2016-07-07 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12464	2016-07-07 17:23:47	2017-06-12 11:07:18
14661	MEMBRECOM	2016-07-07 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12465	2016-07-07 17:24:04	2017-06-12 11:07:18
14662	MEMBRECOM	2016-07-07 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12466	2016-07-07 17:24:09	2017-06-12 11:07:18
14663	MEMBRECOM	2016-07-07 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12467	2016-07-07 17:24:15	2017-06-12 11:07:18
14664	MEMBRECOM	2016-07-07 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12468	2016-07-07 17:24:20	2017-06-12 11:07:18
14666	MEMBRECOM	2016-07-07 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12470	2016-07-07 17:24:31	2017-06-12 11:07:18
14667	MEMBRECOM	2016-07-07 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12471	2016-07-07 17:24:37	2017-06-12 11:07:18
14670	MEMBRECOM	2016-07-07 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12474	2016-07-07 17:24:59	2017-06-12 11:07:18
14671	MEMBRECOM	2016-07-07 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12475	2016-07-07 17:25:05	2017-06-12 11:07:18
14672	MEMBRECOM	2016-07-07 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12476	2016-07-07 17:25:10	2017-06-12 11:07:18
14674	MEMBRECOM	2016-07-07 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12478	2016-07-07 17:25:20	2017-06-12 11:07:18
14676	MEMBRECOM	2016-07-07 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12480	2016-07-07 17:25:29	2017-06-12 11:07:18
14677	MEMBRECOM	2016-07-07 00:00:00	2016-11-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12481	2016-07-07 17:25:34	2016-11-18 12:37:50
13601	VICPDTCOM	2015-06-09 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11468	\N	2017-09-24 18:20:10
13602	RAPCOM	2015-06-09 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11469	\N	2017-09-24 17:28:55
13603	MEMBRECOM	2015-06-09 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11470	\N	2017-09-24 17:15:15
13604	MEMBRECOM	2015-06-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11471	\N	\N
13616	RAPCOM	2015-06-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11483	\N	\N
13610	MEMBRECOM	2015-06-09 00:00:00	2021-07-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11477	\N	\N
13611	MEMBRECOM	2015-06-09 00:00:00	2020-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11478	\N	\N
13612	MEMBRECOM	2015-06-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11479	\N	\N
13613	MEMBRECOM	2015-06-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11480	\N	\N
13615	MEMBRECOM	2015-06-09 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11482	\N	\N
13617	MEMBRECOM	2015-06-10 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11484	\N	2017-10-05 09:39:15
13618	MEMBRECOM	2015-06-10 00:00:00	2015-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11485	\N	2015-10-13 14:20:25
13619	VICPDTCOM	2015-06-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11486	\N	\N
13620	MEMBRECOM	2015-06-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11487	\N	\N
13623	MEMBRECOM	2015-06-10 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11490	\N	\N
13624	MEMBRECOM	2015-06-10 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11491	\N	2017-09-24 18:16:52
13625	MEMBRECOM	2015-06-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11492	\N	\N
13626	MEMBRECOM	2015-06-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11493	\N	\N
13627	MEMBRECOM	2015-06-10 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11494	\N	2017-10-01 10:42:05
13628	MEMBRECOM	2015-06-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11495	\N	\N
13629	MEMBRECOM	2015-06-10 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11496	\N	\N
13630	MEMBRECOM	2015-07-10 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11497	2015-07-10 11:25:44	2017-10-05 14:31:34
13631	MEMBRECOM	2015-07-10 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11498	2015-07-10 11:26:16	2017-10-05 14:37:01
8900	VICPDTCOM	2010-10-06 00:00:00	2015-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7400	\N	2015-10-12 09:39:30
10959	MEMBRECOM	2013-04-02 00:00:00	2015-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9246	\N	2015-10-13 14:23:18
9913	MEMBRECOM	2011-11-02 00:00:00	2015-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8287	\N	2015-10-12 09:39:30
11329	MEMBRECOM	2013-10-03 00:00:00	2015-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9565	\N	2015-10-13 14:22:56
4611	VICPDTCOM	2007-07-19 00:00:00	2015-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3695	\N	2015-10-12 09:39:30
11426	MEMBRECOM	2013-10-22 00:00:00	2015-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9660	\N	2015-10-13 14:22:28
10200	MEMBRECOM	2012-02-08 00:00:00	2015-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8553	\N	2015-10-13 14:23:44
9362	PDTCOM	2011-06-28 00:00:00	2015-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7859	\N	2015-10-12 09:39:30
9315	RAPCOM	2011-06-21 00:00:00	2015-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7812	\N	2015-10-12 09:39:30
9455	PDTCOM	2011-07-05 00:00:00	2015-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7943	\N	2015-10-12 09:39:30
9399	VICPDTCOM	2011-06-29 00:00:00	2015-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7887	\N	2015-10-12 09:39:30
10082	MEMBRECOM	2012-12-21 00:00:00	2015-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8436	\N	2015-10-13 14:23:22
8661	VICPDTCOM	2010-02-18 00:00:00	2015-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7190	\N	2015-10-12 09:39:31
9348	MEMBRECOM	2011-04-06 00:00:00	2015-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7845	\N	2015-10-12 09:39:31
11610	MEMBRECOM	2013-12-16 00:00:00	2015-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9815	\N	2015-10-13 14:22:22
10791	MEMBRECOM	2012-12-13 00:00:00	2015-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9078	\N	2015-10-13 14:23:26
11368	MEMBRECOM	2013-10-03 00:00:00	2015-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9604	\N	2015-10-13 14:22:48
12467	MEMBRECOM	2014-04-30 00:00:00	2015-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10415	\N	2015-10-13 14:22:10
10721	MEMBRECOM	2012-11-29 00:00:00	2015-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9008	\N	2015-10-13 14:23:32
13640	MEMBRECOM	2015-10-12 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11504	2015-10-12 09:41:57	2017-10-04 19:12:55
13641	MEMBRECOM	2015-10-12 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11505	2015-10-12 14:47:37	2017-09-24 17:29:37
13733	MEMBRECOM	2015-07-09 00:00:00	2021-07-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11589	\N	\N
13643	MEMBRECOM	2015-10-12 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11507	2015-10-12 14:48:15	2017-09-24 17:29:37
13946	MEMBRECOM	2015-11-19 00:00:00	2017-06-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11802	\N	2017-06-02 10:02:57
13753	MEMBRECOM	2015-07-08 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11609	\N	\N
13822	MEMBRECOM	2015-10-28 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11678	\N	\N
13829	MEMBRECOM	2015-10-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11685	\N	\N
13830	MEMBRECOM	2015-10-28 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11686	\N	2017-09-24 13:29:42
14065	MEMBRECOM	2016-02-02 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11918	2016-02-23 15:11:47	\N
14066	VICPDTCOM	2016-02-10 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11919	2016-02-23 15:16:52	2017-09-24 13:57:40
14067	RAPCOM	2016-02-10 00:00:00	2016-11-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11920	2016-02-23 15:16:59	2016-12-01 10:36:51
14197	MEMBRECOM	2016-03-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	12050	2016-03-11 15:00:36	\N
14068	MEMBRECOM	2016-02-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11921	2016-02-23 15:17:05	\N
14069	MEMBRECOM	2016-02-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11922	2016-02-23 15:17:09	\N
14052	PDTCOM	2016-02-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11905	2016-02-23 15:09:07	\N
14053	RAPCOM	2016-02-02 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11906	2016-02-23 15:09:15	2017-09-24 19:31:54
14070	MEMBRECOM	2016-02-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11923	2016-02-23 15:17:17	\N
14071	MEMBRECOM	2016-02-10 00:00:00	2020-06-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11924	2016-02-23 15:17:23	\N
14072	MEMBRECOM	2016-02-10 00:00:00	2017-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11925	2016-02-23 15:17:27	2017-06-19 16:06:01
14073	MEMBRECOM	2016-02-10 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11926	2016-02-23 15:17:35	2017-09-24 13:44:49
14127	MEMBRECOM	2016-01-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11980	2016-02-23 15:42:12	\N
14198	MEMBRECOM	2016-03-02 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12051	2016-03-11 15:00:42	2017-09-24 17:55:12
14128	MEMBRECOM	2016-01-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11981	2016-02-23 15:42:18	\N
14129	MEMBRECOM	2016-01-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11982	2016-02-23 15:42:25	\N
14130	MEMBRECOM	2016-01-12 00:00:00	2019-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11983	2016-02-23 15:42:30	\N
14131	MEMBRECOM	2016-01-12 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11984	2016-02-23 15:42:38	2017-09-24 18:05:40
14132	MEMBRECOM	2016-01-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11985	2016-02-23 15:42:43	\N
14133	MEMBRECOM	2016-01-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11986	2016-02-23 15:42:50	\N
14134	MEMBRECOM	2016-01-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11987	2016-02-23 15:54:48	\N
14135	MEMBRECOM	2016-01-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11988	2016-02-23 15:54:56	\N
17297	VICPDTCOM	2018-10-11 00:00:00	2019-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14532	\N	\N
14136	MEMBRECOM	2016-01-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11989	2016-02-23 15:55:01	\N
14137	MEMBRECOM	2016-01-12 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11990	2016-02-23 15:55:16	2017-09-24 18:49:56
14138	MEMBRECOM	2016-01-12 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11991	2016-02-23 15:55:25	\N
14139	MEMBRECOM	2016-01-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11992	2016-02-23 15:55:33	\N
14140	MEMBRECOM	2016-01-12 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11993	2016-02-23 15:55:41	\N
14199	MEMBRECOM	2016-03-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	12052	2016-03-11 15:00:52	\N
14192	PDTCOM	2016-03-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	12045	2016-03-11 14:57:57	2016-03-11 14:59:02
14193	RAPCOM	2016-03-02 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12046	2016-03-11 14:58:04	2017-09-24 17:29:37
14194	MEMBRECOM	2016-03-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	12047	2016-03-11 14:58:12	2016-03-11 14:59:28
14195	MEMBRECOM	2016-03-02 00:00:00	2017-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12048	2016-03-11 14:58:20	2017-07-24 09:56:26
14196	MEMBRECOM	2016-03-02 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12049	2016-03-11 14:58:35	2017-09-24 18:16:52
14200	MEMBRECOM	2016-03-02 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12053	2016-03-11 15:01:09	\N
14201	MEMBRECOM	2016-03-02 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12054	2016-03-11 15:01:18	2017-09-24 18:16:52
14202	MEMBRECOM	2016-03-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	12055	2016-03-11 15:01:29	\N
14203	MEMBRECOM	2016-03-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	12056	2016-03-11 15:01:41	\N
14204	MEMBRECOM	2016-03-02 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12057	2016-03-11 15:01:54	2017-09-24 17:15:15
14205	MEMBRECOM	2016-03-02 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12058	2016-03-11 15:02:03	\N
14054	MEMBRECOM	2016-02-02 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11907	2016-02-23 15:09:20	\N
14055	MEMBRECOM	2016-02-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11908	2016-02-23 15:09:26	\N
14056	MEMBRECOM	2016-02-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11909	2016-02-23 15:09:33	\N
14057	MEMBRECOM	2016-02-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11910	2016-02-23 15:09:54	\N
14058	MEMBRECOM	2016-02-02 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11911	2016-02-23 15:10:02	2017-09-24 17:35:15
14059	MEMBRECOM	2016-02-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11912	2016-02-23 15:10:09	\N
14060	MEMBRECOM	2016-02-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11913	2016-02-23 15:11:23	\N
14061	MEMBRECOM	2016-02-02 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11914	2016-02-23 15:11:28	\N
14062	MEMBRECOM	2016-02-02 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11915	2016-02-23 15:11:33	2017-09-24 17:42:25
14063	MEMBRECOM	2016-02-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11916	2016-02-23 15:11:38	\N
14064	MEMBRECOM	2016-02-02 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11917	2016-02-23 15:11:42	2017-09-24 18:49:56
13638	MEMBRECOM	2015-09-16 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11502	2015-09-16 11:32:41	2017-10-04 18:38:48
13696	PDTCOM	2016-01-13 00:00:00	2016-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11540	2016-01-13 16:30:45	2016-10-07 09:16:01
13697	RAPCOM	2016-01-13 00:00:00	2016-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11523	2016-01-13 16:31:01	2016-10-07 09:16:01
13698	RAPCOM	2016-01-13 00:00:00	2016-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11537	2016-01-13 16:31:24	2016-10-07 09:16:01
13699	VICPDTCOM	2016-01-13 00:00:00	2016-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11526	2016-01-13 16:31:38	2016-10-07 09:16:01
13700	VICPDTCOM	2016-01-13 00:00:00	2016-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11536	2016-01-13 16:31:51	2016-10-07 09:16:01
13701	VICPDTCOM	2016-01-13 00:00:00	2016-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11528	2016-01-13 16:32:00	2016-10-07 09:16:01
13702	VICPDTCOM	2016-01-13 00:00:00	2016-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11533	2016-01-13 16:32:09	2016-10-07 09:16:01
13760	VICPDTCOM	2015-07-08 00:00:00	2020-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11616	\N	\N
13831	VICPDTCOM	2015-10-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11687	\N	\N
13833	MEMBRECOM	2015-10-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11689	\N	\N
13835	MEMBRECOM	2015-10-26 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11691	\N	2017-09-24 17:06:55
13844	VICPDTCOM	2015-11-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11700	\N	\N
13845	RAPCOM	2015-11-05 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11701	\N	\N
13846	MEMBRECOM	2015-11-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11702	\N	\N
13847	MEMBRECOM	2015-11-05 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11703	\N	\N
13850	MEMBRECOM	2015-11-05 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11706	\N	\N
13853	MEMBRECOM	2015-11-05 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11709	\N	2017-09-24 17:42:26
13854	MEMBRECOM	2015-11-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11710	\N	\N
13855	MEMBRECOM	2015-11-05 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11711	\N	2017-09-24 17:42:26
13856	MEMBRECOM	2015-11-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11712	\N	\N
13862	MEMBRECOM	2015-10-15 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11718	\N	\N
13867	MEMBRECOM	2015-10-15 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11723	\N	\N
13869	MEMBRECOM	2015-10-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11725	\N	\N
14074	MEMBRECOM	2016-02-10 00:00:00	2020-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11927	2016-02-23 15:17:44	\N
14077	MEMBRECOM	2016-02-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11930	2016-02-23 15:18:14	\N
14078	MEMBRECOM	2016-02-10 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11931	2016-02-23 15:18:25	\N
14079	MEMBRECOM	2016-02-10 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11932	2016-02-23 15:18:32	2017-09-24 16:45:26
14087	PDTCOM	2016-02-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11940	2016-02-23 15:21:36	\N
14088	RAPCOM	2016-02-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11941	2016-02-23 15:21:42	\N
14089	MEMBRECOM	2016-02-10 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11942	2016-02-23 15:21:48	\N
14091	MEMBRECOM	2016-02-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11944	2016-02-23 15:21:59	\N
14093	MEMBRECOM	2016-02-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11946	2016-02-23 15:22:08	\N
14094	MEMBRECOM	2016-02-10 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11947	2016-02-23 15:22:14	\N
14095	MEMBRECOM	2016-02-10 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11948	2016-02-23 15:22:24	\N
14096	MEMBRECOM	2016-02-10 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11949	2016-02-23 15:22:31	2017-09-24 17:06:55
14097	MEMBRECOM	2016-02-10 00:00:00	2020-07-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11950	2016-02-23 15:22:39	\N
14098	MEMBRECOM	2016-02-10 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11951	2016-02-23 15:22:48	2017-09-24 17:47:27
14102	MEMBRECOM	2016-01-19 00:00:00	2016-02-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11955	2016-02-23 15:34:42	2016-02-23 15:35:18
14100	MEMBRECOM	2016-02-10 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11953	2016-02-23 15:23:20	2017-10-01 10:20:50
14101	MEMBRECOM	2016-02-10 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11954	2016-02-23 15:26:53	\N
14114	MEMBRECOM	2016-01-19 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11967	2016-02-23 15:37:15	2017-09-24 16:43:43
14112	MEMBRECOM	2016-01-19 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11965	2016-02-23 15:37:04	\N
14113	MEMBRECOM	2016-01-19 00:00:00	2019-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11966	2016-02-23 15:37:10	\N
14115	MEMBRECOM	2016-01-19 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11968	2016-02-23 15:37:20	2017-09-24 16:45:26
14116	MEMBRECOM	2016-01-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11969	2016-02-23 15:37:26	\N
14117	MEMBRECOM	2016-01-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11970	2016-02-23 15:37:29	\N
10668	MEMBRECOM	2012-11-06 00:00:00	2016-03-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8956	\N	2016-03-11 18:02:50
14119	MEMBRECOM	2016-01-19 00:00:00	2020-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11972	2016-02-23 15:38:41	\N
14120	MEMBRECOM	2016-01-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11973	2016-02-23 15:38:48	\N
14121	MEMBRECOM	2016-01-19 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11974	2016-02-23 15:38:56	2017-09-24 17:42:25
14122	MEMBRECOM	2016-01-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11975	2016-02-23 15:39:03	\N
14123	MEMBRECOM	2016-01-19 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11976	2016-02-23 15:39:10	\N
14206	MEMBRECOM	2016-03-12 00:00:00	2016-03-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12059	2016-03-11 18:10:19	2016-03-15 16:03:57
14126	MEMBRECOM	2016-01-19 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11979	2016-02-23 15:39:39	2017-09-24 12:57:09
14207	MEMBRECOM	2016-03-15 00:00:00	2017-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12060	2016-03-15 16:03:57	2017-06-19 16:03:48
14208	MEMBRECOM	2016-03-17 00:00:00	2016-04-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12061	2016-03-17 15:20:47	2016-05-04 17:11:08
14337	RAPCOM	2016-05-02 00:00:00	2016-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12143	2016-05-02 10:28:09	2017-06-12 11:08:12
14338	VICPDTCOM	2016-05-02 00:00:00	2016-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12151	2016-05-02 10:28:21	2017-06-12 11:08:12
14339	VICPDTCOM	2016-05-02 00:00:00	2016-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12156	2016-05-02 10:28:27	2017-06-12 11:08:12
14340	VICPDTCOM	2016-05-02 00:00:00	2016-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12142	2016-05-02 10:28:34	2017-06-12 11:08:12
14341	VICPDTCOM	2016-05-02 00:00:00	2016-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12161	2016-05-02 10:28:44	2017-06-12 11:08:12
14342	VICPDTCOM	2016-05-02 00:00:00	2016-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12141	2016-05-02 10:28:54	2017-06-12 11:08:12
14343	VICPDTCOM	2016-05-02 00:00:00	2016-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12144	2016-05-02 10:29:01	2017-06-12 11:08:12
14382	VICPDTCOM	2016-05-12 00:00:00	2016-05-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12219	2016-05-12 13:51:16	2016-05-18 08:49:08
14383	RAPCOM	2016-05-12 00:00:00	2016-05-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12220	2016-05-12 13:51:34	2016-05-18 08:49:08
14384	MEMBRECOM	2016-05-12 00:00:00	2016-05-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12221	2016-05-12 13:51:40	2016-05-18 08:49:08
14385	MEMBRECOM	2016-05-12 00:00:00	2016-05-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12222	2016-05-12 13:51:45	2016-05-18 08:49:08
14386	MEMBRECOM	2016-05-12 00:00:00	2016-05-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12223	2016-05-12 13:51:52	2016-05-18 08:49:08
14387	MEMBRECOM	2016-05-12 00:00:00	2016-05-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12224	2016-05-12 13:52:00	2016-05-18 08:49:08
14388	MEMBRECOM	2016-05-12 00:00:00	2016-05-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12225	2016-05-12 13:52:07	2016-05-18 08:49:08
14389	MEMBRECOM	2016-05-12 00:00:00	2016-05-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12226	2016-05-12 13:52:16	2016-05-18 08:49:08
14390	MEMBRECOM	2016-05-12 00:00:00	2016-05-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12227	2016-05-12 13:52:25	2016-05-18 08:49:08
14391	MEMBRECOM	2016-05-12 00:00:00	2016-05-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12228	2016-05-12 13:52:31	2016-05-18 08:49:08
14392	MEMBRECOM	2016-05-12 00:00:00	2016-05-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12229	2016-05-12 13:52:36	2016-05-18 08:49:08
14393	MEMBRECOM	2016-05-12 00:00:00	2016-05-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12230	2016-05-12 13:52:47	2016-05-18 08:49:08
14394	MEMBRECOM	2016-05-12 00:00:00	2016-05-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12231	2016-05-12 13:52:52	2016-05-18 08:49:08
14395	MEMBRECOM	2016-05-12 00:00:00	2016-05-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12232	2016-05-12 13:52:56	2016-05-18 08:49:08
14487	VICPDTCOM	2016-06-08 00:00:00	2016-06-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12316	2016-06-08 17:36:07	2016-06-24 20:13:49
14488	RAPCOM	2016-06-08 00:00:00	2016-06-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12317	2016-06-08 17:36:12	2016-06-24 20:13:49
14489	RAPCOM	2016-06-08 00:00:00	2016-06-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12318	2016-06-08 17:36:18	2016-06-24 20:13:49
14490	MEMBRECOM	2016-06-08 00:00:00	2016-06-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12319	2016-06-08 17:36:23	2016-06-24 20:13:49
14491	MEMBRECOM	2016-06-08 00:00:00	2016-06-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12320	2016-06-08 17:36:29	2016-06-24 20:13:49
14492	MEMBRECOM	2016-06-08 00:00:00	2016-06-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12321	2016-06-08 17:36:34	2016-06-24 20:13:49
14493	MEMBRECOM	2016-06-08 00:00:00	2016-06-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12322	2016-06-08 17:36:40	2016-06-24 20:13:49
14494	MEMBRECOM	2016-06-08 00:00:00	2016-06-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12323	2016-06-08 17:36:45	2016-06-24 20:13:49
14495	MEMBRECOM	2016-06-08 00:00:00	2016-06-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12324	2016-06-08 17:36:51	2016-06-24 20:13:49
14496	MEMBRECOM	2016-06-08 00:00:00	2016-06-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12325	2016-06-08 17:36:58	2016-06-24 20:13:49
14497	MEMBRECOM	2016-06-08 00:00:00	2016-06-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12326	2016-06-08 17:37:03	2016-06-24 20:13:49
14498	MEMBRECOM	2016-06-08 00:00:00	2016-06-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12327	2016-06-08 17:37:09	2016-06-24 20:13:49
14499	MEMBRECOM	2016-06-08 00:00:00	2016-06-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12328	2016-06-08 17:37:14	2016-06-24 20:13:49
14500	MEMBRECOM	2016-06-08 00:00:00	2016-06-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12329	2016-06-08 17:37:29	2016-06-24 20:13:42
14501	PDTRAPCOM	2016-06-08 00:00:00	2016-06-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12330	2016-06-08 17:41:47	2016-06-24 20:13:42
14502	MEMBRECOM	2016-06-08 00:00:00	2016-06-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12331	2016-06-08 17:41:52	2016-06-24 20:13:42
14503	MEMBRECOM	2016-06-08 00:00:00	2016-06-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12332	2016-06-08 17:41:57	2016-06-24 20:13:42
14504	MEMBRECOM	2016-06-08 00:00:00	2016-06-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12333	2016-06-08 17:42:01	2016-06-24 20:13:42
13592	MEMBRECOM	2015-06-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11459	\N	\N
13593	MEMBRECOM	2015-06-03 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11460	\N	2017-10-01 10:17:18
13594	MEMBRECOM	2015-06-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11461	\N	\N
13595	MEMBRECOM	2015-06-03 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11462	\N	\N
13596	MEMBRECOM	2015-06-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11463	\N	\N
13597	MEMBRECOM	2015-06-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11464	\N	\N
13614	MEMBRECOM	2015-06-09 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11481	\N	2017-09-24 18:23:22
13599	MEMBRECOM	2015-06-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11466	\N	\N
13600	MEMBRECOM	2015-06-03 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11467	\N	\N
13622	MEMBRECOM	2015-06-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11489	\N	\N
13632	VICPDTCOM	2015-07-08 00:00:00	2017-10-03 00:00:00	4	ANCIEN	\N	\N	\N	\N	3539	2015-07-10 16:11:40	2017-10-05 09:25:14
13635	MEMBRECOM	2015-09-07 00:00:00	2015-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11499	2015-09-07 16:07:43	2015-09-16 11:31:44
13636	MEMBRECOM	2015-09-07 00:00:00	2015-09-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11500	2015-09-07 16:16:32	2015-09-14 14:28:13
13682	MEMBRECOM	2015-12-16 00:00:00	2016-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11546	2015-12-16 11:28:07	2016-10-07 09:16:01
13738	MEMBRECOM	2015-07-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11594	\N	\N
13731	PDTCOM	2015-07-09 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11587	\N	2017-09-24 18:20:10
13740	RAPCOM	2015-07-09 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11596	\N	2017-09-24 17:15:15
13741	MEMBRECOM	2015-07-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11597	\N	\N
13742	MEMBRECOM	2015-07-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11598	\N	\N
13743	MEMBRECOM	2015-07-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11599	\N	\N
13757	MEMBRECOM	2015-07-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11613	\N	\N
13758	MEMBRECOM	2015-07-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11614	\N	2017-09-24 17:04:02
13759	MEMBRECOM	2015-07-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11615	\N	\N
13764	MEMBRECOM	2015-07-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11620	\N	\N
13768	MEMBRECOM	2015-07-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11624	\N	2017-09-24 19:31:54
13770	MEMBRECOM	2015-07-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11626	\N	\N
13832	RAPCOM	2015-10-26 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11688	\N	\N
13837	MEMBRECOM	2015-10-26 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11693	\N	2017-09-24 17:19:42
13838	MEMBRECOM	2015-10-26 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11694	\N	\N
13840	MEMBRECOM	2015-10-26 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11696	\N	2017-09-24 17:42:26
13841	MEMBRECOM	2015-10-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11697	\N	\N
13842	MEMBRECOM	2015-10-26 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11698	\N	2017-09-24 17:42:26
13870	MEMBRECOM	2015-10-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11726	\N	\N
13875	MEMBRECOM	2015-11-05 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11731	\N	2017-10-01 10:42:05
13876	MEMBRECOM	2015-11-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11732	\N	\N
13877	MEMBRECOM	2015-11-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11733	\N	\N
13879	MEMBRECOM	2015-11-05 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11735	\N	\N
13882	MEMBRECOM	2015-11-05 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11738	\N	2017-09-24 17:47:27
13883	MEMBRECOM	2015-11-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11739	\N	\N
13884	MEMBRECOM	2015-11-05 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11740	\N	\N
13923	MEMBRECOM	2015-11-05 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11779	\N	\N
14176	VICPDTCOM	2016-03-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	12029	2016-03-11 11:48:56	\N
13955	MEMBRECOM	2015-11-19 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11811	\N	\N
13968	MEMBRECOM	2015-12-09 00:00:00	2021-07-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11824	\N	\N
14178	RAPCOM	2016-03-02 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12031	2016-03-11 11:50:03	2017-09-24 13:29:42
14179	MEMBRECOM	2016-03-02 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12032	2016-03-11 11:50:09	\N
14181	MEMBRECOM	2016-03-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	12034	2016-03-11 11:50:32	\N
14182	MEMBRECOM	2016-03-02 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12035	2016-03-11 11:50:54	\N
14183	MEMBRECOM	2016-03-02 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12036	2016-03-11 11:51:00	2017-09-24 18:17:56
14185	MEMBRECOM	2016-03-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	12038	2016-03-11 11:51:23	\N
14186	MEMBRECOM	2016-03-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	12039	2016-03-11 11:51:41	\N
14187	MEMBRECOM	2016-03-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	12040	2016-03-11 11:51:46	\N
14188	MEMBRECOM	2016-03-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	12041	2016-03-11 11:51:59	\N
14189	MEMBRECOM	2016-03-02 00:00:00	2019-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12042	2016-03-11 11:52:07	\N
14190	MEMBRECOM	2016-03-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	12043	2016-03-11 11:52:24	\N
14224	PDTCOM	2016-04-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	12077	2016-04-04 15:21:58	2016-04-04 15:24:24
14225	RAPCOM	2016-04-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	12078	2016-04-04 15:22:13	2016-04-04 15:24:44
14226	MEMBRECOM	2016-04-01 00:00:00	2019-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12079	2016-04-04 15:22:25	2016-04-04 15:25:03
14227	MEMBRECOM	2016-04-01 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12080	2016-04-04 15:22:35	2016-04-04 15:25:23
14229	MEMBRECOM	2016-04-01 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12082	2016-04-04 15:23:02	2016-04-04 15:25:52
14230	MEMBRECOM	2016-04-01 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12083	2016-04-04 15:23:17	2017-09-24 17:14:26
14231	MEMBRECOM	2016-04-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	12084	2016-04-04 15:29:15	2016-04-04 15:45:50
14232	MEMBRECOM	2016-04-01 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12085	2016-04-04 15:29:43	2016-04-04 15:46:12
14233	MEMBRECOM	2016-04-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	12086	2016-04-04 15:30:00	2016-04-04 15:46:31
14234	MEMBRECOM	2016-04-01 00:00:00	2020-11-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12087	2016-04-04 15:30:11	2016-04-04 15:46:47
14396	MEMBRECOM	2016-05-13 00:00:00	2016-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12233	2016-05-13 09:47:19	2016-10-05 16:14:35
14465	VICPDTCOM	2016-05-31 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12261	2016-06-01 09:55:41	2017-06-12 11:07:55
14466	VICPDTCOM	2016-05-31 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12266	2016-06-01 09:57:50	2017-06-12 11:07:55
14467	VICPDTCOM	2016-05-31 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12267	2016-06-01 09:57:56	2017-06-12 11:07:55
14468	VICPDTCOM	2016-05-31 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12271	2016-06-01 09:58:07	2017-06-12 11:07:55
14469	VICPDTCOM	2016-05-31 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12268	2016-06-01 09:58:17	2017-06-12 11:07:55
10145	PDTCOM	2012-01-25 00:00:00	2017-07-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8503	\N	2017-07-04 15:08:09
14505	MEMBRECOM	2016-06-08 00:00:00	2016-06-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12334	2016-06-08 17:42:07	2016-06-24 20:13:42
14506	MEMBRECOM	2016-06-08 00:00:00	2016-06-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12335	2016-06-08 17:42:27	2016-06-24 20:13:42
14507	MEMBRECOM	2016-06-08 00:00:00	2016-06-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12336	2016-06-08 17:42:33	2016-06-24 20:13:42
14508	MEMBRECOM	2016-06-08 00:00:00	2016-06-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12337	2016-06-08 17:42:39	2016-06-24 20:13:42
14509	MEMBRECOM	2016-06-08 00:00:00	2016-06-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12338	2016-06-08 17:42:44	2016-06-24 20:13:42
14510	MEMBRECOM	2016-06-08 00:00:00	2016-06-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12339	2016-06-08 17:42:49	2016-06-24 20:13:42
14511	MEMBRECOM	2016-06-08 00:00:00	2016-06-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12340	2016-06-08 17:42:57	2016-06-24 20:13:42
14512	MEMBRECOM	2016-06-08 00:00:00	2016-06-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12341	2016-06-08 17:43:02	2016-06-24 20:13:42
14513	MEMBRECOM	2016-06-08 00:00:00	2016-06-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12342	2016-06-08 17:43:06	2016-06-24 20:13:42
14514	SECRETCOM	2016-06-14 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8723	2016-06-14 18:05:33	2017-10-04 18:35:46
10369	MEMBRECOM	2012-02-21 00:00:00	2016-06-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8723	\N	2016-06-14 18:05:33
14543	MEMBRECOM	2016-06-22 00:00:00	2016-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12371	2016-06-22 16:28:37	2016-06-28 19:40:33
14544	MEMBRECOM	2016-06-22 00:00:00	2016-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12372	2016-06-22 16:28:42	2016-07-07 16:33:43
14545	MEMBRECOM	2016-06-22 00:00:00	2016-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12373	2016-06-22 16:28:49	2016-07-07 16:33:43
14546	MEMBRECOM	2016-06-22 00:00:00	2016-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12374	2016-06-22 16:29:18	2016-07-07 16:33:43
14547	MEMBRECOM	2016-06-22 00:00:00	2016-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12375	2016-06-22 16:29:24	2016-07-07 16:33:43
14548	MEMBRECOM	2016-06-22 00:00:00	2016-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12376	2016-06-22 16:29:30	2016-06-28 19:42:13
14549	MEMBRECOM	2016-06-22 00:00:00	2016-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12377	2016-06-22 16:29:36	2016-06-28 19:40:39
14550	MEMBRECOM	2016-06-22 00:00:00	2016-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12378	2016-06-22 16:29:42	2016-06-28 19:40:52
14551	MEMBRECOM	2016-06-22 00:00:00	2016-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12379	2016-06-22 16:29:49	2016-07-07 16:33:43
14552	MEMBRECOM	2016-06-22 00:00:00	2016-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12380	2016-06-22 16:29:56	2016-07-07 16:33:43
14553	MEMBRECOM	2016-06-22 00:00:00	2016-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12381	2016-06-22 16:30:31	2016-07-07 16:33:43
14554	MEMBRECOM	2016-06-22 00:00:00	2016-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12382	2016-06-22 16:30:39	2016-06-28 19:40:14
14555	MEMBRECOM	2016-06-22 00:00:00	2016-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12383	2016-06-22 16:30:50	2016-06-28 19:41:00
14556	MEMBRECOM	2016-06-22 00:00:00	2016-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12384	2016-06-22 16:30:58	2016-07-07 16:33:43
14557	MEMBRECOM	2016-06-22 00:00:00	2016-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12385	2016-06-22 16:31:03	2016-06-28 19:40:23
14558	MEMBRECOM	2016-06-22 00:00:00	2016-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12386	2016-06-22 16:31:11	2016-06-28 19:42:20
14559	MEMBRECOM	2016-06-22 00:00:00	2016-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12387	2016-06-22 16:31:16	2016-07-07 16:33:43
14560	MEMBRECOM	2016-06-22 00:00:00	2016-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12388	2016-06-22 16:31:23	2016-07-07 16:33:43
14561	MEMBRECOM	2016-06-22 00:00:00	2016-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12389	2016-06-22 16:31:28	2016-06-28 19:39:55
14562	MEMBRECOM	2016-06-22 00:00:00	2016-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12390	2016-06-22 16:31:36	2016-07-07 16:33:43
13633	VICPDTCOM	2015-07-20 00:00:00	2017-10-04 00:00:00	6	ANCIEN	\N	\N	\N	\N	2607	2015-07-20 11:24:06	2017-10-04 18:38:57
13634	SECRETCOM	2015-07-20 00:00:00	2017-10-04 00:00:00	12	ANCIEN	\N	\N	\N	\N	7751	2015-07-20 11:25:15	2017-10-04 18:39:14
13695	MEMBRECOM	2016-01-12 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11559	2016-01-12 09:45:37	2017-10-04 18:45:34
13817	RAPCOM	2015-10-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11673	\N	\N
13818	MEMBRECOM	2015-10-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11674	\N	\N
13819	PDTCOM	2015-10-28 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11675	\N	\N
13820	MEMBRECOM	2015-10-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11676	\N	\N
13821	MEMBRECOM	2015-10-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11677	\N	\N
13823	MEMBRECOM	2015-10-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11679	\N	\N
13824	MEMBRECOM	2015-10-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11680	\N	\N
13825	MEMBRECOM	2015-10-28 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11681	\N	\N
13827	MEMBRECOM	2015-10-28 00:00:00	2017-06-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11683	\N	2017-06-07 09:38:00
13828	MEMBRECOM	2015-10-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11684	\N	\N
13865	MEMBRECOM	2015-10-15 00:00:00	2017-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11721	\N	2017-06-19 16:06:51
13868	MEMBRECOM	2015-10-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11724	\N	\N
13871	PDTCOM	2015-11-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11727	\N	\N
13872	RAPCOM	2015-11-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11728	\N	\N
13874	MEMBRECOM	2015-11-05 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11730	\N	2017-09-24 19:25:10
13880	MEMBRECOM	2015-11-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11736	\N	\N
13881	MEMBRECOM	2015-11-05 00:00:00	2017-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11737	\N	2017-07-24 09:56:26
13900	MEMBRECOM	2015-11-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11756	\N	\N
13901	RAPCOM	2015-11-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11757	\N	\N
13902	MEMBRECOM	2015-11-12 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11758	\N	2017-09-24 17:29:37
13903	MEMBRECOM	2015-11-12 00:00:00	2020-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11759	\N	\N
13905	MEMBRECOM	2015-11-12 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11761	\N	\N
13906	MEMBRECOM	2015-11-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11762	\N	\N
13908	VICPDTCOM	2015-11-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11764	\N	\N
13909	MEMBRECOM	2015-11-12 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11765	\N	2017-09-24 17:15:15
13910	MEMBRECOM	2015-11-12 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11766	\N	\N
14235	MEMBRECOM	2016-04-01 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12088	2016-04-04 15:47:45	2017-09-24 17:06:55
14236	MEMBRECOM	2016-04-01 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12089	2016-04-04 15:48:07	\N
14237	MEMBRECOM	2016-04-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	12090	2016-04-04 15:48:29	\N
14238	MEMBRECOM	2016-04-07 00:00:00	2016-05-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12091	2016-04-07 18:05:49	2016-05-13 09:49:49
14288	MEMBRECOM	2016-04-27 00:00:00	2016-05-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12141	2016-04-27 14:58:05	2016-05-02 10:28:54
14289	MEMBRECOM	2016-04-27 00:00:00	2016-05-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12142	2016-04-27 14:58:11	2016-05-02 10:28:34
14290	MEMBRECOM	2016-04-27 00:00:00	2016-05-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12143	2016-04-27 14:58:16	2016-05-02 10:28:09
14291	MEMBRECOM	2016-04-27 00:00:00	2016-05-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12144	2016-04-27 14:58:22	2016-05-02 10:29:02
14292	MEMBRECOM	2016-04-27 00:00:00	2016-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12145	2016-04-27 14:58:27	2017-06-12 11:08:12
14293	MEMBRECOM	2016-04-27 00:00:00	2016-05-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12146	2016-04-27 14:58:34	2016-05-02 10:27:49
14294	MEMBRECOM	2016-04-27 00:00:00	2016-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12147	2016-04-27 14:58:40	2017-06-12 11:08:12
14296	MEMBRECOM	2016-04-27 00:00:00	2016-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12149	2016-04-27 14:58:51	2017-06-12 11:08:12
14297	MEMBRECOM	2016-04-27 00:00:00	2016-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12150	2016-04-27 14:59:01	2017-06-12 11:08:12
14298	MEMBRECOM	2016-04-27 00:00:00	2016-05-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12151	2016-04-27 14:59:08	2016-05-02 10:28:21
14299	MEMBRECOM	2016-04-27 00:00:00	2016-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12152	2016-04-27 14:59:14	2017-06-12 11:08:12
14300	MEMBRECOM	2016-04-27 00:00:00	2016-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12153	2016-04-27 14:59:21	2017-06-12 11:08:12
14301	MEMBRECOM	2016-04-27 00:00:00	2016-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12154	2016-04-27 14:59:28	2017-06-12 11:08:12
14302	MEMBRECOM	2016-04-27 00:00:00	2016-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12155	2016-04-27 14:59:33	2017-06-12 11:08:12
14303	MEMBRECOM	2016-04-27 00:00:00	2016-05-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12156	2016-04-27 14:59:38	2016-05-02 10:28:27
14304	MEMBRECOM	2016-04-27 00:00:00	2016-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12157	2016-04-27 14:59:43	2017-06-12 11:08:12
14305	MEMBRECOM	2016-04-27 00:00:00	2016-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12158	2016-04-27 14:59:48	2017-06-12 11:08:12
14306	MEMBRECOM	2016-04-27 00:00:00	2016-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12159	2016-04-27 14:59:55	2017-06-12 11:08:12
14307	MEMBRECOM	2016-04-27 00:00:00	2016-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12160	2016-04-27 15:00:01	2017-06-12 11:08:12
14308	MEMBRECOM	2016-04-27 00:00:00	2016-05-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12161	2016-04-27 15:00:04	2016-05-02 10:28:44
14309	MEMBRECOM	2016-04-27 00:00:00	2016-05-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12162	2016-04-27 15:15:17	2016-05-03 17:23:46
14310	MEMBRECOM	2016-04-27 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12163	2016-04-27 15:15:22	2017-06-12 11:08:26
14311	MEMBRECOM	2016-04-27 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12164	2016-04-27 15:15:26	2017-06-12 11:08:26
14312	MEMBRECOM	2016-04-27 00:00:00	2016-05-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12165	2016-04-27 15:15:31	2016-05-03 17:23:00
14313	MEMBRECOM	2016-04-27 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12166	2016-04-27 15:15:41	2017-06-12 11:08:26
14314	MEMBRECOM	2016-04-27 00:00:00	2016-05-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12167	2016-04-27 15:15:48	2016-05-03 17:23:12
14315	MEMBRECOM	2016-04-27 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12168	2016-04-27 15:15:54	2017-06-12 11:08:26
14316	MEMBRECOM	2016-04-27 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12169	2016-04-27 15:16:05	2017-06-12 11:08:26
14317	MEMBRECOM	2016-04-27 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12170	2016-04-27 15:16:10	2017-06-12 11:08:26
14318	MEMBRECOM	2016-04-27 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12171	2016-04-27 15:16:15	2017-06-12 11:08:26
14319	MEMBRECOM	2016-04-27 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12172	2016-04-27 15:16:21	2017-06-12 11:08:26
14320	MEMBRECOM	2016-04-27 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12173	2016-04-27 15:16:28	2017-06-12 11:08:26
14321	MEMBRECOM	2016-04-27 00:00:00	2016-05-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12174	2016-04-27 15:16:32	2016-05-03 17:23:30
14322	MEMBRECOM	2016-04-27 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12175	2016-04-27 15:16:38	2017-06-12 11:08:26
14323	MEMBRECOM	2016-04-27 00:00:00	2016-05-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12176	2016-04-27 15:16:43	2016-05-03 17:23:24
14324	MEMBRECOM	2016-04-27 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12177	2016-04-27 15:16:48	2017-06-12 11:08:26
14326	MEMBRECOM	2016-04-27 00:00:00	2016-05-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12179	2016-04-27 15:17:03	2016-05-03 17:22:51
14327	MEMBRECOM	2016-04-27 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12180	2016-04-27 15:17:10	2017-06-12 11:08:26
14328	MEMBRECOM	2016-04-27 00:00:00	2016-05-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12181	2016-04-27 15:17:18	2016-05-03 17:23:18
14329	MEMBRECOM	2016-04-27 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12182	2016-04-27 15:17:23	2017-06-12 11:08:26
14330	MEMBRECOM	2016-04-27 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12183	2016-04-27 15:17:29	2017-06-12 11:08:26
14331	MEMBRECOM	2016-04-27 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12184	2016-04-27 15:17:34	2017-06-12 11:08:26
14332	MEMBRECOM	2016-04-27 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12185	2016-04-27 15:17:40	2017-06-12 11:08:26
14333	MEMBRECOM	2016-04-27 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12186	2016-04-27 15:17:45	2017-06-12 11:08:26
14334	MEMBRECOM	2016-04-27 00:00:00	2016-05-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12187	2016-04-27 15:17:50	2016-05-03 17:23:36
14335	MEMBRECOM	2016-04-27 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12188	2016-04-27 15:17:55	2017-06-12 11:08:26
14451	VICPDTCOM	2016-05-18 00:00:00	2016-05-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12288	2016-05-18 08:53:38	2016-06-08 17:34:23
14452	RAPCOM	2016-05-18 00:00:00	2016-05-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12289	2016-05-18 08:53:52	2016-06-08 17:34:23
14453	MEMBRECOM	2016-05-18 00:00:00	2016-05-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12290	2016-05-18 08:53:58	2016-06-08 17:34:23
14454	MEMBRECOM	2016-05-18 00:00:00	2016-05-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12291	2016-05-18 08:54:07	2016-06-08 17:34:23
14455	MEMBRECOM	2016-05-18 00:00:00	2016-05-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12292	2016-05-18 08:54:13	2016-06-08 17:34:23
14456	MEMBRECOM	2016-05-18 00:00:00	2016-05-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12293	2016-05-18 08:54:18	2016-06-08 17:34:23
14457	MEMBRECOM	2016-05-18 00:00:00	2016-05-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12294	2016-05-18 08:54:25	2016-06-08 17:34:23
14458	MEMBRECOM	2016-05-18 00:00:00	2016-05-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12295	2016-05-18 08:54:40	2016-06-08 17:34:23
14459	MEMBRECOM	2016-05-18 00:00:00	2016-05-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12296	2016-05-18 08:54:46	2016-06-08 17:34:23
17298	VICPDTCOM	2018-10-11 00:00:00	2019-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14453	\N	\N
14460	MEMBRECOM	2016-05-18 00:00:00	2016-05-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12297	2016-05-18 08:54:56	2016-06-08 17:34:23
14461	MEMBRECOM	2016-05-18 00:00:00	2016-05-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12298	2016-05-18 08:55:01	2016-06-08 17:34:23
14462	MEMBRECOM	2016-05-18 00:00:00	2016-05-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12299	2016-05-18 08:55:07	2016-06-08 17:34:23
14463	MEMBRECOM	2016-05-18 00:00:00	2016-05-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12300	2016-05-18 08:55:14	2016-06-08 17:34:23
14464	MEMBRECOM	2016-05-18 00:00:00	2016-05-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12301	2016-05-18 08:55:19	2016-06-08 17:34:23
14563	MEMBRECOM	2016-06-22 00:00:00	2016-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12391	2016-06-22 16:31:41	2016-07-07 16:33:43
14564	MEMBRECOM	2016-06-22 00:00:00	2016-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12392	2016-06-22 16:31:48	2016-06-28 19:41:14
14565	MEMBRECOM	2016-06-22 00:00:00	2016-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12393	2016-06-22 16:31:54	2016-06-28 19:41:42
13645	PDTCOM	2015-06-25 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11509	\N	\N
13646	RAPCOM	2015-06-25 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11510	\N	\N
13647	MEMBRECOM	2015-06-25 00:00:00	2017-07-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11511	\N	2017-07-24 09:58:00
13648	MEMBRECOM	2015-06-25 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11512	\N	\N
13649	MEMBRECOM	2015-06-25 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11513	\N	2017-09-24 19:31:54
13650	MEMBRECOM	2015-06-25 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11514	\N	\N
13651	MEMBRECOM	2015-06-25 00:00:00	2018-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11515	\N	\N
13653	MEMBRECOM	2015-06-25 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11517	\N	\N
13656	MEMBRECOM	2015-06-25 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11520	\N	\N
13658	MEMBRECOM	2015-06-25 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11522	\N	\N
13685	MEMBRECOM	2015-12-16 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11549	2015-12-16 17:19:57	2017-10-04 20:36:19
13687	MEMBRECOM	2015-12-16 00:00:00	2016-01-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11551	2015-12-16 17:20:12	2016-01-28 15:22:32
13688	MEMBRECOM	2015-12-16 00:00:00	2016-01-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11552	2015-12-16 17:20:18	2016-01-28 15:22:39
13689	MEMBRECOM	2015-12-16 00:00:00	2016-01-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11553	2015-12-16 17:20:25	2016-01-28 15:18:27
13690	MEMBRECOM	2015-12-16 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11554	2015-12-16 17:20:34	2017-09-24 13:47:46
13691	MEMBRECOM	2015-12-16 00:00:00	2016-03-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11555	2015-12-16 17:20:41	2016-03-11 18:02:50
13692	MEMBRECOM	2015-12-16 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11556	2015-12-16 17:20:48	2017-10-04 20:37:03
13694	MEMBRECOM	2015-12-16 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11558	2015-12-16 17:21:04	\N
13776	MEMBRECOM	2015-09-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11632	\N	\N
13777	MEMBRECOM	2015-09-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11633	\N	\N
13778	MEMBRECOM	2015-09-08 00:00:00	2017-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11634	\N	2017-06-19 16:04:13
13800	MEMBRECOM	2015-09-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11656	\N	\N
13782	MEMBRECOM	2015-09-08 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11638	\N	\N
13789	VICPDTCOM	2015-09-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11645	\N	\N
13914	PDTCOM	2015-11-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11770	\N	\N
13916	MEMBRECOM	2015-11-05 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11772	\N	\N
13917	MEMBRECOM	2015-11-05 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11773	\N	2017-09-24 17:15:15
13919	MEMBRECOM	2015-11-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11775	\N	\N
13920	MEMBRECOM	2015-11-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11776	\N	\N
13921	MEMBRECOM	2015-11-05 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11777	\N	\N
13925	MEMBRECOM	2015-11-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11781	\N	\N
13926	MEMBRECOM	2015-11-05 00:00:00	2017-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11782	\N	2017-07-24 09:56:26
13927	MEMBRECOM	2015-11-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11783	\N	\N
13929	PDTCOM	2015-11-24 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11785	\N	\N
13930	RAPCOM	2015-11-24 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11786	\N	2017-09-24 12:57:09
13932	MEMBRECOM	2015-11-24 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11788	\N	\N
13939	MEMBRECOM	2015-11-24 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11795	\N	\N
13934	MEMBRECOM	2015-11-24 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11790	\N	\N
13935	MEMBRECOM	2015-11-24 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11791	\N	2017-09-24 17:06:55
13938	MEMBRECOM	2015-11-24 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11794	\N	\N
13940	MEMBRECOM	2015-11-24 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11796	\N	\N
13942	MEMBRECOM	2015-11-24 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11798	\N	\N
13944	VICPDTCOM	2015-11-19 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11800	\N	2017-09-24 18:20:10
13945	RAPCOM	2015-11-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11801	\N	\N
13960	PDTCOM	2015-12-09 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11816	\N	2017-09-24 18:20:10
13948	MEMBRECOM	2015-11-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11804	\N	\N
13949	MEMBRECOM	2015-11-19 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11805	\N	\N
13951	MEMBRECOM	2015-11-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11807	\N	\N
13952	MEMBRECOM	2015-11-19 00:00:00	2021-07-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11808	\N	\N
13953	MEMBRECOM	2015-11-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11809	\N	\N
13954	MEMBRECOM	2015-11-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11810	\N	\N
13959	MEMBRECOM	2015-11-19 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11815	\N	2017-09-24 18:23:22
13961	RAPCOM	2015-12-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11817	\N	\N
13962	MEMBRECOM	2015-12-09 00:00:00	2017-06-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11818	\N	2017-06-02 10:02:57
13963	MEMBRECOM	2015-12-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11819	\N	\N
13964	MEMBRECOM	2015-12-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11820	\N	\N
13965	MEMBRECOM	2015-12-09 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11821	\N	\N
13966	MEMBRECOM	2015-12-09 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11822	\N	2017-09-24 17:06:55
13967	MEMBRECOM	2015-12-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11823	\N	\N
14473	VICPDTCOM	2016-06-01 00:00:00	2016-06-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12302	2016-06-02 11:04:30	2016-06-30 15:32:20
14474	RAPCOM	2016-06-01 00:00:00	2016-06-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12303	2016-06-02 11:04:35	2016-06-30 15:32:20
14475	MEMBRECOM	2016-06-01 00:00:00	2016-06-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12304	2016-06-02 11:04:44	2016-06-30 15:32:20
14476	MEMBRECOM	2016-06-01 00:00:00	2016-06-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12305	2016-06-02 11:04:49	2016-06-30 15:32:20
14477	MEMBRECOM	2016-06-01 00:00:00	2016-06-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12306	2016-06-02 11:04:55	2016-06-30 15:32:20
14478	MEMBRECOM	2016-06-01 00:00:00	2016-06-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12307	2016-06-02 11:05:00	2016-06-30 15:32:20
14479	MEMBRECOM	2016-06-01 00:00:00	2016-06-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12308	2016-06-02 11:05:06	2016-06-30 15:32:20
14480	MEMBRECOM	2016-06-01 00:00:00	2016-06-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12309	2016-06-02 11:05:11	2016-06-30 15:32:20
14481	MEMBRECOM	2016-06-01 00:00:00	2016-06-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12310	2016-06-02 11:05:16	2016-06-30 15:32:20
14482	MEMBRECOM	2016-06-01 00:00:00	2016-06-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12311	2016-06-02 11:05:21	2016-06-30 15:32:20
14483	MEMBRECOM	2016-06-01 00:00:00	2016-06-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12312	2016-06-02 11:05:26	2016-06-30 15:32:20
14484	MEMBRECOM	2016-06-01 00:00:00	2016-06-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12313	2016-06-02 11:05:34	2016-06-30 15:32:20
14485	MEMBRECOM	2016-06-01 00:00:00	2016-06-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12314	2016-06-02 11:05:41	2016-06-30 15:32:20
14486	MEMBRECOM	2016-06-01 00:00:00	2016-06-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12315	2016-06-02 11:05:46	2016-06-30 15:32:20
14566	MEMBRECOM	2016-06-22 00:00:00	2016-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12394	2016-06-22 16:32:01	2016-07-07 16:33:43
14567	MEMBRECOM	2016-06-22 00:00:00	2016-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12395	2016-06-22 16:32:06	2016-07-07 16:33:43
14568	MEMBRECOM	2016-06-22 00:00:00	2016-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12396	2016-06-22 16:32:12	2016-06-28 19:41:47
14569	MEMBRECOM	2016-06-22 00:00:00	2016-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12397	2016-06-22 16:32:17	2016-07-07 16:33:43
14570	MEMBRECOM	2016-06-22 00:00:00	2016-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12398	2016-06-22 16:32:26	2016-07-07 16:33:43
14571	MEMBRECOM	2016-06-22 00:00:00	2016-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12399	2016-06-22 16:32:31	2016-06-28 19:41:52
14572	MEMBRECOM	2016-06-22 00:00:00	2016-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12400	2016-06-22 16:32:36	2016-06-28 19:41:58
14573	MEMBRECOM	2016-06-22 00:00:00	2016-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12401	2016-06-22 16:32:45	2016-06-28 19:42:03
14574	MEMBRECOM	2016-06-22 00:00:00	2016-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12402	2016-06-22 16:32:52	2016-07-07 16:33:43
14576	MEMBRECOM	2016-06-22 00:00:00	2016-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12404	2016-06-22 16:33:01	2016-06-28 19:42:25
14577	MEMBRECOM	2016-06-22 00:00:00	2016-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12405	2016-06-22 16:33:07	2016-07-07 16:33:43
14578	MEMBRECOM	2016-06-22 00:00:00	2016-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12406	2016-06-22 16:33:12	2016-07-07 16:33:43
14579	MEMBRECOM	2016-06-22 00:00:00	2016-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12407	2016-06-22 16:42:44	2016-06-29 14:52:31
14580	MEMBRECOM	2016-06-22 00:00:00	2016-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12408	2016-06-22 16:42:49	2016-10-07 09:16:24
14582	MEMBRECOM	2016-06-22 00:00:00	2016-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12410	2016-06-22 16:43:00	2016-06-29 14:52:20
14585	MEMBRECOM	2016-06-22 00:00:00	2016-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12413	2016-06-22 16:43:19	2016-06-29 14:52:40
14586	MEMBRECOM	2016-06-22 00:00:00	2016-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12414	2016-06-22 16:43:26	2016-10-07 09:16:24
14587	MEMBRECOM	2016-06-22 00:00:00	2016-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12415	2016-06-22 16:43:32	2016-06-29 14:52:46
14588	MEMBRECOM	2016-06-22 00:00:00	2016-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12416	2016-06-22 16:43:38	2016-10-07 09:16:24
14589	MEMBRECOM	2016-06-22 00:00:00	2016-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12417	2016-06-22 16:43:44	2016-10-07 09:16:24
14590	MEMBRECOM	2016-06-22 00:00:00	2016-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12418	2016-06-22 16:43:51	2016-06-29 14:52:12
14591	MEMBRECOM	2016-06-22 00:00:00	2016-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12419	2016-06-22 16:43:56	2016-06-29 14:52:52
14592	MEMBRECOM	2016-06-22 00:00:00	2016-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12420	2016-06-22 16:44:02	2016-10-07 09:16:24
14593	MEMBRECOM	2016-06-22 00:00:00	2016-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12421	2016-06-22 16:44:14	2016-10-07 09:16:24
14595	MEMBRECOM	2016-06-22 00:00:00	2016-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12423	2016-06-22 16:44:27	2016-10-07 09:16:24
14597	MEMBRECOM	2016-06-22 00:00:00	2016-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12425	2016-06-22 16:44:38	2016-10-07 09:16:24
14598	MEMBRECOM	2016-06-22 00:00:00	2016-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12426	2016-06-22 16:44:44	2016-10-07 09:16:24
14599	MEMBRECOM	2016-06-22 00:00:00	2016-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12427	2016-06-22 16:44:49	2016-10-07 09:16:24
14601	MEMBRECOM	2016-06-22 00:00:00	2016-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12429	2016-06-22 16:44:59	2016-06-29 14:52:57
14602	MEMBRECOM	2016-06-22 00:00:00	2016-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12430	2016-06-22 16:45:07	2016-10-07 09:16:24
14603	MEMBRECOM	2016-06-22 00:00:00	2016-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12431	2016-06-22 16:45:12	2016-10-07 09:16:24
13621	MEMBRECOM	2015-06-10 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11488	\N	\N
12637	MEMBRECOM	2015-01-15 00:00:00	2015-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10585	2015-01-09 11:41:19	2015-10-07 10:43:00
12642	MEMBRECOM	2015-01-15 00:00:00	2015-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10592	2015-01-09 11:42:27	2015-10-07 10:43:00
12815	MEMBRECOM	2015-01-15 00:00:00	2015-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10763	2015-01-13 19:14:49	2015-10-07 10:43:00
12819	MEMBRECOM	2015-01-15 00:00:00	2015-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10767	2015-01-13 19:15:47	2015-10-07 10:43:00
12824	MEMBRECOM	2015-01-15 00:00:00	2015-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10774	2015-01-13 19:17:15	2015-10-07 10:43:00
12953	VICPDTCOM	2014-10-22 00:00:00	2015-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10302	2015-01-29 17:51:06	2015-10-07 10:48:17
13654	MEMBRECOM	2015-06-25 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11518	\N	\N
13655	MEMBRECOM	2015-06-25 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11519	\N	\N
13657	MEMBRECOM	2015-06-25 00:00:00	2017-05-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11521	\N	2017-05-16 15:18:13
13659	MEMBRECOM	2015-12-16 00:00:00	2016-01-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11523	2015-12-16 11:11:46	2016-01-13 16:31:01
13660	MEMBRECOM	2015-12-16 00:00:00	2016-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11524	2015-12-16 11:12:25	2016-10-07 09:16:01
13661	MEMBRECOM	2015-12-16 00:00:00	2016-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11525	2015-12-16 11:12:42	2016-10-07 09:16:01
13662	MEMBRECOM	2015-12-16 00:00:00	2016-01-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11526	2015-12-16 11:12:53	2016-01-13 16:31:38
13663	MEMBRECOM	2015-12-16 00:00:00	2016-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11527	2015-12-16 11:13:05	2016-10-07 09:16:01
13664	MEMBRECOM	2015-12-16 00:00:00	2016-01-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11528	2015-12-16 11:13:46	2016-01-13 16:32:00
13665	MEMBRECOM	2015-12-16 00:00:00	2016-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11529	2015-12-16 11:13:54	2016-10-07 09:16:01
13666	MEMBRECOM	2015-12-16 00:00:00	2016-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11530	2015-12-16 11:14:05	2016-10-07 09:16:01
13667	MEMBRECOM	2015-12-16 00:00:00	2016-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11531	2015-12-16 11:14:13	2016-10-07 09:16:01
13668	MEMBRECOM	2015-12-16 00:00:00	2016-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11532	2015-12-16 11:14:30	2016-10-07 09:16:01
13669	MEMBRECOM	2015-12-16 00:00:00	2016-01-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11533	2015-12-16 11:14:41	2016-01-13 16:32:09
13670	MEMBRECOM	2015-12-16 00:00:00	2016-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11534	2015-12-16 11:14:48	2016-10-07 09:16:01
13671	MEMBRECOM	2015-12-16 00:00:00	2016-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11535	2015-12-16 11:15:07	2016-10-07 09:16:01
13672	MEMBRECOM	2015-12-16 00:00:00	2016-01-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11536	2015-12-16 11:15:48	2016-01-13 16:31:51
13673	MEMBRECOM	2015-12-16 00:00:00	2016-01-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11537	2015-12-16 11:16:02	2016-01-13 16:31:24
13674	MEMBRECOM	2015-12-16 00:00:00	2016-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11538	2015-12-16 11:16:12	2016-10-07 09:16:01
13675	MEMBRECOM	2015-12-16 00:00:00	2016-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11539	2015-12-16 11:16:19	2016-10-07 09:16:01
13676	MEMBRECOM	2015-12-16 00:00:00	2016-01-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11540	2015-12-16 11:16:30	2016-01-13 16:30:45
13677	MEMBRECOM	2015-12-16 00:00:00	2016-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11541	2015-12-16 11:16:39	2016-10-07 09:16:01
13678	MEMBRECOM	2015-12-16 00:00:00	2016-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11542	2015-12-16 11:16:46	2016-10-07 09:16:01
13679	MEMBRECOM	2015-12-16 00:00:00	2016-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11543	2015-12-16 11:16:53	2016-10-07 09:16:01
13680	MEMBRECOM	2015-12-16 00:00:00	2016-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11544	2015-12-16 11:17:01	2016-10-07 09:16:01
13681	MEMBRECOM	2015-12-16 00:00:00	2016-01-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11545	2015-12-16 11:17:10	2016-01-26 16:42:52
13784	MEMBRECOM	2015-09-08 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11640	\N	\N
13803	VICPDTCOM	2015-10-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11659	\N	\N
13804	RAPCOM	2015-10-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11660	\N	\N
13805	MEMBRECOM	2015-10-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11661	\N	\N
13806	MEMBRECOM	2015-10-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11662	\N	\N
13809	MEMBRECOM	2015-10-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11665	\N	\N
13812	MEMBRECOM	2015-10-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11668	\N	\N
13813	MEMBRECOM	2015-10-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11669	\N	\N
13814	MEMBRECOM	2015-10-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11670	\N	\N
13816	MEMBRECOM	2015-10-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11672	\N	2017-09-24 12:57:09
13843	MEMBRECOM	2015-10-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11699	\N	\N
13851	MEMBRECOM	2015-11-05 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11707	\N	\N
13852	MEMBRECOM	2015-11-05 00:00:00	2018-12-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11708	\N	\N
13857	VICPDTCOM	2015-10-15 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11713	\N	\N
13858	RAPCOM	2015-10-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11714	\N	\N
13859	MEMBRECOM	2015-10-15 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11715	\N	\N
13860	MEMBRECOM	2015-10-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11716	\N	\N
13861	MEMBRECOM	2015-10-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11717	\N	\N
13863	MEMBRECOM	2015-10-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11719	\N	\N
13864	MEMBRECOM	2015-10-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11720	\N	\N
13885	PDTCOM	2015-11-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11741	\N	\N
13886	RAPCOM	2015-11-05 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11742	\N	2017-09-24 17:15:15
13889	MEMBRECOM	2015-11-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11745	\N	\N
13890	MEMBRECOM	2015-11-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11746	\N	\N
13891	MEMBRECOM	2015-11-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11747	\N	\N
13892	MEMBRECOM	2015-11-05 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11748	\N	2017-10-01 10:17:18
13893	MEMBRECOM	2015-11-05 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11749	\N	\N
13894	MEMBRECOM	2015-11-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11750	\N	\N
13970	MEMBRECOM	2015-12-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11826	\N	\N
13896	MEMBRECOM	2015-11-05 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11752	\N	\N
13897	MEMBRECOM	2015-11-05 00:00:00	2017-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11753	\N	2017-07-24 09:56:26
13918	MEMBRECOM	2015-11-05 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11774	\N	2017-10-01 10:42:05
13922	MEMBRECOM	2015-11-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11778	\N	\N
13928	MEMBRECOM	2015-11-05 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11784	\N	\N
13937	MEMBRECOM	2015-11-24 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11793	\N	2017-09-24 13:44:49
13956	MEMBRECOM	2015-11-19 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11812	\N	\N
13958	MEMBRECOM	2015-11-19 00:00:00	2020-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11814	\N	\N
13969	MEMBRECOM	2015-12-09 00:00:00	2020-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11825	\N	\N
13971	MEMBRECOM	2015-12-09 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11827	\N	2017-09-24 17:09:24
13972	MEMBRECOM	2015-12-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11828	\N	\N
13973	MEMBRECOM	2015-12-09 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11829	\N	2017-09-24 18:23:22
14155	VICPDTCOM	2016-03-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	12008	2016-03-11 10:36:49	2016-03-11 10:40:08
14156	RAPCOM	2016-03-02 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12009	2016-03-11 10:37:00	2017-09-24 17:09:24
14157	MEMBRECOM	2016-03-02 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12010	2016-03-11 10:37:12	2017-09-24 17:15:15
14158	MEMBRECOM	2016-03-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	12011	2016-03-11 10:37:20	2016-03-11 10:40:59
14159	MEMBRECOM	2016-03-02 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12012	2016-03-11 10:37:26	2017-10-01 10:17:18
14160	MEMBRECOM	2016-03-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	12013	2016-03-11 10:37:36	2016-03-11 10:41:42
14161	MEMBRECOM	2016-03-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	12014	2016-03-11 10:37:53	2016-03-11 10:41:57
14162	MEMBRECOM	2016-03-02 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12015	2016-03-11 10:38:02	2016-03-11 10:42:18
14163	MEMBRECOM	2016-03-02 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12016	2016-03-11 10:38:13	2016-03-11 10:42:38
14164	MEMBRECOM	2016-03-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	12017	2016-03-11 10:38:19	2016-03-11 10:42:51
14165	MEMBRECOM	2016-03-02 00:00:00	2020-07-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12018	2016-03-11 10:38:36	2016-03-11 10:43:07
14166	MEMBRECOM	2016-03-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	12019	2016-03-11 10:38:47	2016-03-11 10:43:23
14167	MEMBRECOM	2016-03-02 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12020	2016-03-11 10:39:02	2017-09-24 18:17:56
14168	MEMBRECOM	2016-03-02 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12021	2016-03-11 10:39:13	2016-03-11 10:43:58
14375	MEMBRECOM	2016-04-27 00:00:00	2016-05-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12212	2016-05-06 10:21:50	2016-05-12 13:47:41
14376	MEMBRECOM	2016-04-27 00:00:00	2016-05-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12213	2016-05-06 10:22:04	2016-05-12 13:47:41
14368	VICPDTCOM	2016-04-27 00:00:00	2016-05-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12205	2016-05-06 10:20:50	2016-05-12 13:47:41
14369	RAPCOM	2016-04-27 00:00:00	2016-05-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12206	2016-05-06 10:20:55	2016-05-12 13:47:41
14370	MEMBRECOM	2016-04-27 00:00:00	2016-05-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12207	2016-05-06 10:21:02	2016-05-12 13:47:41
14371	MEMBRECOM	2016-04-27 00:00:00	2016-05-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12208	2016-05-06 10:21:23	2016-05-12 13:47:41
14372	MEMBRECOM	2016-04-27 00:00:00	2016-05-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12209	2016-05-06 10:21:32	2016-05-12 13:47:41
14373	MEMBRECOM	2016-04-27 00:00:00	2016-05-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12210	2016-05-06 10:21:39	2016-05-12 13:47:41
14374	MEMBRECOM	2016-04-27 00:00:00	2016-05-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12211	2016-05-06 10:21:44	2016-05-12 13:47:41
14377	MEMBRECOM	2016-04-27 00:00:00	2016-05-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12214	2016-05-06 10:22:13	2016-05-12 13:47:41
14378	MEMBRECOM	2016-04-27 00:00:00	2016-05-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12215	2016-05-06 10:22:21	2016-05-12 13:47:41
14379	MEMBRECOM	2016-04-27 00:00:00	2016-05-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12216	2016-05-06 10:22:31	2016-05-12 13:47:41
14380	MEMBRECOM	2016-04-27 00:00:00	2016-05-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12217	2016-05-06 10:22:39	2016-05-12 13:47:41
14381	MEMBRECOM	2016-04-27 00:00:00	2016-05-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12218	2016-05-06 10:22:47	2016-05-12 13:47:41
13704	VICPDTCOM	2015-06-17 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11560	\N	\N
13705	RAPCOM	2015-06-17 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11561	\N	2017-09-24 13:29:42
13706	MEMBRECOM	2015-06-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11562	\N	\N
13708	MEMBRECOM	2015-06-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11564	\N	\N
13710	MEMBRECOM	2015-06-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11566	\N	\N
13711	MEMBRECOM	2015-06-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11567	\N	\N
13712	MEMBRECOM	2015-06-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11568	\N	\N
13713	MEMBRECOM	2015-06-17 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11569	\N	\N
13718	PDTCOM	2015-07-25 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11574	\N	\N
13722	MEMBRECOM	2015-07-25 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11578	\N	2017-09-24 19:25:10
13724	MEMBRECOM	2015-07-25 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11580	\N	2017-09-24 17:09:24
13725	MEMBRECOM	2015-07-25 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11581	\N	\N
13726	MEMBRECOM	2015-07-25 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11582	\N	\N
13727	MEMBRECOM	2015-07-25 00:00:00	2017-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11583	\N	2017-07-24 09:56:26
13728	MEMBRECOM	2015-07-25 00:00:00	2017-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11584	\N	2017-06-19 12:20:59
13729	MEMBRECOM	2015-07-25 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11585	\N	\N
13730	MEMBRECOM	2015-07-25 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11586	\N	\N
13735	MEMBRECOM	2015-07-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11591	\N	\N
13749	MEMBRECOM	2015-07-08 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11605	\N	\N
13746	MEMBRECOM	2015-07-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11602	\N	\N
13747	VICPDTCOM	2015-07-08 00:00:00	2016-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11603	\N	2017-01-03 11:09:24
13748	RAPCOM	2015-07-08 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11604	\N	2017-10-05 09:39:10
13750	MEMBRECOM	2015-07-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11606	\N	2017-09-24 17:19:42
13751	MEMBRECOM	2015-07-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11607	\N	2017-09-24 19:14:37
13752	MEMBRECOM	2015-07-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11608	\N	2017-09-24 17:47:28
13755	MEMBRECOM	2015-07-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11611	\N	\N
13756	MEMBRECOM	2015-07-08 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11612	\N	2017-10-01 09:22:38
13765	MEMBRECOM	2015-07-08 00:00:00	2018-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11621	\N	\N
13766	MEMBRECOM	2015-07-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11622	\N	\N
13767	MEMBRECOM	2015-07-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11623	\N	\N
13771	MEMBRECOM	2015-07-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11627	\N	2017-09-24 18:49:56
13772	MEMBRECOM	2015-07-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11628	\N	\N
13887	MEMBRECOM	2015-11-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	11743	\N	\N
13898	MEMBRECOM	2015-11-05 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11754	\N	\N
13913	MEMBRECOM	2015-11-12 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11769	\N	\N
13974	RAPCOM	2016-01-28 00:00:00	2016-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11553	2016-01-28 15:18:27	2016-10-05 16:14:21
13975	PDTCOM	2016-01-28 00:00:00	2016-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11551	2016-01-28 15:22:32	2016-10-05 16:14:04
13976	VICPDTCOM	2016-01-28 00:00:00	2016-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11552	2016-01-28 15:22:39	2016-10-05 16:14:14
14424	MEMBRECOM	2016-05-18 00:00:00	2016-05-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12261	2016-05-17 17:42:57	2016-06-01 09:55:41
14425	MEMBRECOM	2016-05-18 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12262	2016-05-17 17:43:04	2017-06-12 11:07:55
14426	MEMBRECOM	2016-05-18 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12263	2016-05-17 17:43:10	2017-06-12 11:07:55
14427	MEMBRECOM	2016-05-18 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12264	2016-05-17 17:43:16	2017-06-12 11:07:55
14428	MEMBRECOM	2016-05-18 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12265	2016-05-17 17:43:22	2017-06-12 11:07:55
14429	MEMBRECOM	2016-05-18 00:00:00	2016-05-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12266	2016-05-17 17:43:29	2016-06-01 09:57:50
14430	MEMBRECOM	2016-05-18 00:00:00	2016-05-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12267	2016-05-17 17:43:35	2016-06-01 09:57:56
14431	MEMBRECOM	2016-05-18 00:00:00	2016-05-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12268	2016-05-17 17:43:41	2016-06-01 09:58:17
14432	MEMBRECOM	2016-05-18 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12269	2016-05-17 17:43:48	2017-06-12 11:07:55
14433	MEMBRECOM	2016-05-18 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12270	2016-05-17 17:43:54	2017-06-12 11:07:55
14434	MEMBRECOM	2016-05-18 00:00:00	2016-05-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12271	2016-05-17 17:44:00	2016-06-01 09:58:07
14435	MEMBRECOM	2016-05-18 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12272	2016-05-17 17:44:06	2017-06-12 11:07:55
14436	MEMBRECOM	2016-05-18 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12273	2016-05-17 17:44:13	2017-06-12 11:07:55
14437	MEMBRECOM	2016-05-18 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12274	2016-05-17 17:44:20	2017-06-12 11:07:55
14438	MEMBRECOM	2016-05-18 00:00:00	2016-05-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12275	2016-05-17 17:44:27	2016-06-01 09:58:38
14439	MEMBRECOM	2016-05-18 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12276	2016-05-17 17:44:34	2017-06-12 11:07:55
14440	MEMBRECOM	2016-05-18 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12277	2016-05-17 17:44:40	2017-06-12 11:07:55
14441	MEMBRECOM	2016-05-18 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12278	2016-05-17 17:44:45	2017-06-12 11:07:55
14442	MEMBRECOM	2016-05-18 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12279	2016-05-17 17:44:52	2017-06-12 11:07:55
14443	MEMBRECOM	2016-05-18 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12280	2016-05-17 17:44:59	2017-06-12 11:07:55
14444	MEMBRECOM	2016-05-18 00:00:00	2016-05-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12281	2016-05-17 17:45:06	2016-06-01 09:58:32
14445	MEMBRECOM	2016-05-18 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12282	2016-05-17 17:45:12	2017-06-12 11:07:55
14446	MEMBRECOM	2016-05-18 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12283	2016-05-17 17:45:18	2017-06-12 11:07:55
14447	MEMBRECOM	2016-05-18 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12284	2016-05-17 17:45:24	2017-06-12 11:07:55
14448	MEMBRECOM	2016-05-18 00:00:00	2016-05-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12285	2016-05-17 17:45:31	2016-06-01 09:58:53
14449	MEMBRECOM	2016-05-18 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12286	2016-05-17 17:45:39	2017-06-12 11:07:55
14450	MEMBRECOM	2016-05-18 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12287	2016-05-17 17:45:46	2017-06-12 11:07:55
14515	PDTCOM	2016-06-15 00:00:00	2016-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12343	2016-06-15 15:17:06	2016-06-24 20:12:48
14516	RAPCOM	2016-06-15 00:00:00	2016-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12344	2016-06-15 15:17:18	2016-06-24 20:12:48
14517	MEMBRECOM	2016-06-15 00:00:00	2016-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12345	2016-06-15 15:17:26	2016-06-24 20:12:48
14518	MEMBRECOM	2016-06-15 00:00:00	2016-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12346	2016-06-15 15:17:34	2016-06-24 20:12:48
14519	MEMBRECOM	2016-06-15 00:00:00	2016-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12347	2016-06-15 15:17:42	2016-06-24 20:12:48
14520	MEMBRECOM	2016-06-15 00:00:00	2016-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12348	2016-06-15 15:17:50	2016-06-24 20:12:48
14521	MEMBRECOM	2016-06-15 00:00:00	2016-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12349	2016-06-15 15:17:59	2016-06-24 20:12:48
14522	MEMBRECOM	2016-06-15 00:00:00	2016-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12350	2016-06-15 15:18:05	2016-06-24 20:12:48
14523	MEMBRECOM	2016-06-15 00:00:00	2016-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12351	2016-06-15 15:18:17	2016-06-24 20:12:48
14524	MEMBRECOM	2016-06-15 00:00:00	2016-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12352	2016-06-15 15:18:25	2016-06-24 20:12:48
14525	MEMBRECOM	2016-06-15 00:00:00	2016-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12353	2016-06-15 15:18:32	2016-06-24 20:12:48
14526	MEMBRECOM	2016-06-15 00:00:00	2016-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12354	2016-06-15 15:18:38	2016-06-24 20:12:48
14527	MEMBRECOM	2016-06-15 00:00:00	2016-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12355	2016-06-15 15:18:46	2016-06-24 20:12:48
14528	MEMBRECOM	2016-06-15 00:00:00	2016-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12356	2016-06-15 15:18:56	2016-06-24 20:12:48
14529	PDTCOM	2016-06-15 00:00:00	2016-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12357	2016-06-15 15:22:28	2016-06-24 20:12:27
14530	MEMBRECOM	2016-06-15 00:00:00	2016-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12358	2016-06-15 15:22:36	2016-06-24 20:12:27
14531	MEMBRECOM	2016-06-15 00:00:00	2016-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12359	2016-06-15 15:22:45	2016-06-24 20:12:27
14532	RAPCOM	2016-06-15 00:00:00	2016-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12360	2016-06-15 15:22:54	2016-06-24 20:12:27
14533	MEMBRECOM	2016-06-15 00:00:00	2016-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12361	2016-06-15 15:23:18	2016-06-24 20:12:27
14534	MEMBRECOM	2016-06-15 00:00:00	2016-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12362	2016-06-15 15:23:35	2016-06-24 20:12:27
14535	MEMBRECOM	2016-06-15 00:00:00	2016-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12363	2016-06-15 15:23:43	2016-06-24 20:12:27
14536	MEMBRECOM	2016-06-15 00:00:00	2016-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12364	2016-06-15 15:24:02	2016-06-24 20:12:27
14537	MEMBRECOM	2016-06-15 00:00:00	2016-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12365	2016-06-15 15:24:08	2016-06-24 20:12:27
14538	MEMBRECOM	2016-06-15 00:00:00	2016-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12366	2016-06-15 15:24:14	2016-06-24 20:12:27
14539	MEMBRECOM	2016-06-15 00:00:00	2016-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12367	2016-06-15 15:24:21	2016-06-24 20:12:27
14540	MEMBRECOM	2016-06-15 00:00:00	2016-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12368	2016-06-15 15:24:28	2016-06-24 20:12:27
14541	MEMBRECOM	2016-06-15 00:00:00	2016-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12369	2016-06-15 15:24:34	2016-06-24 20:12:27
14542	MEMBRECOM	2016-06-15 00:00:00	2016-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12370	2016-06-15 15:24:43	2016-06-24 20:12:27
14604	MEMBRECOM	2016-06-22 00:00:00	2016-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12432	2016-06-22 16:45:33	2016-06-29 14:53:02
14605	PDTCOM	2016-06-23 00:00:00	2016-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12433	2016-06-24 20:15:08	2016-06-30 15:31:51
14606	RAPCOM	2016-06-23 00:00:00	2016-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12434	2016-06-24 20:15:15	2016-06-30 15:31:51
14607	MEMBRECOM	2016-06-23 00:00:00	2016-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12435	2016-06-24 20:15:21	2016-06-30 15:31:51
14608	MEMBRECOM	2016-06-23 00:00:00	2016-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12436	2016-06-24 20:15:26	2016-06-30 15:31:51
14609	MEMBRECOM	2016-06-23 00:00:00	2016-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12437	2016-06-24 20:15:32	2016-06-30 15:31:51
14610	MEMBRECOM	2016-06-23 00:00:00	2016-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12438	2016-06-24 20:15:38	2016-06-30 15:31:51
12291	MEMBRECOM	2014-10-09 00:00:00	2016-04-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10266	2014-10-09 16:20:47	2016-07-07 18:06:54
15028	VICPDTCOM	2016-11-29 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12746	2016-12-01 15:04:27	2017-06-12 11:06:58
11608	MEMBRECOM	2013-12-16 00:00:00	2017-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9813	\N	2017-06-19 12:20:22
14712	MEMBRECOM	2016-07-13 00:00:00	2016-09-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12516	2016-07-13 16:26:10	2016-10-07 09:18:55
14713	MEMBRECOM	2016-07-13 00:00:00	2016-09-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12517	2016-07-13 16:26:18	2016-10-07 09:18:55
14714	MEMBRECOM	2016-07-13 00:00:00	2016-09-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12518	2016-07-13 16:26:26	2016-10-07 09:18:55
14715	MEMBRECOM	2016-07-13 00:00:00	2016-09-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12519	2016-07-13 16:26:33	2016-10-07 09:18:55
14716	MEMBRECOM	2016-07-13 00:00:00	2016-09-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12520	2016-07-13 16:26:42	2016-10-07 09:18:55
14805	VICPDTCOM	2016-11-16 00:00:00	2016-11-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12601	2016-11-17 10:38:47	2016-11-24 11:54:25
14718	MEMBRECOM	2016-07-13 00:00:00	2016-09-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12522	2016-07-13 16:27:38	2016-10-07 09:18:55
14719	MEMBRECOM	2016-07-13 00:00:00	2016-09-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12523	2016-07-13 16:27:45	2016-10-07 09:18:55
14720	MEMBRECOM	2016-07-13 00:00:00	2016-09-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12524	2016-07-13 16:27:55	2016-10-07 09:18:55
14721	MEMBRECOM	2016-07-13 00:00:00	2016-09-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12525	2016-07-13 16:28:02	2016-10-07 09:18:55
14722	MEMBRECOM	2016-07-13 00:00:00	2016-09-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12526	2016-07-13 16:28:08	2016-10-07 09:18:55
14723	MEMBRECOM	2016-07-13 00:00:00	2016-09-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12527	2016-07-13 16:28:17	2016-10-07 09:18:55
14724	MEMBRECOM	2016-07-13 00:00:00	2016-09-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12528	2016-07-13 16:28:25	2016-10-07 09:18:55
15009	MEMBRECOM	2016-11-22 00:00:00	2016-11-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12805	2016-11-30 18:12:05	2016-12-01 15:07:59
14807	RAPCOM	2016-11-16 00:00:00	2016-11-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12603	2016-11-17 10:39:35	2016-11-24 11:54:25
14808	MEMBRECOM	2016-11-16 00:00:00	2016-11-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12604	2016-11-17 10:39:43	2016-11-24 11:54:25
14809	MEMBRECOM	2016-11-16 00:00:00	2016-11-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12605	2016-11-17 10:39:48	2016-11-24 11:54:25
14810	MEMBRECOM	2016-11-16 00:00:00	2016-11-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12606	2016-11-17 10:39:56	2016-11-24 11:54:25
14811	MEMBRECOM	2016-11-16 00:00:00	2016-11-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12607	2016-11-17 10:40:03	2016-11-24 11:54:25
14812	MEMBRECOM	2016-11-16 00:00:00	2016-11-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12608	2016-11-17 10:40:10	2016-11-24 11:54:25
14813	MEMBRECOM	2016-11-16 00:00:00	2016-11-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12609	2016-11-17 10:40:16	2016-11-24 11:54:25
14814	MEMBRECOM	2016-11-16 00:00:00	2016-11-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12610	2016-11-17 10:40:21	2016-11-24 11:54:25
14815	MEMBRECOM	2016-11-16 00:00:00	2016-11-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12611	2016-11-17 10:40:26	2016-11-24 11:54:25
14816	MEMBRECOM	2016-11-16 00:00:00	2016-11-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12612	2016-11-17 10:40:30	2016-11-24 11:54:25
14817	MEMBRECOM	2016-11-16 00:00:00	2016-11-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12613	2016-11-17 10:40:38	2016-11-24 11:54:25
14818	MEMBRECOM	2016-11-16 00:00:00	2016-11-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12614	2016-11-17 10:40:43	2016-11-24 11:54:25
14819	MEMBRECOM	2016-11-16 00:00:00	2016-11-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12615	2016-11-17 10:40:48	2016-11-24 11:54:25
15010	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12806	2016-11-30 18:15:59	2017-06-12 11:07:07
15016	MEMBRECOM	2016-11-23 00:00:00	2016-12-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12812	2016-12-01 14:29:27	2016-12-01 15:39:15
15017	MEMBRECOM	2016-11-23 00:00:00	2016-12-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12813	2016-12-01 14:31:06	2016-12-01 15:39:21
15043	MEMBRECOM	2016-12-01 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12815	2016-12-07 11:19:56	2017-06-12 11:07:18
15111	MEMBRECOM	2017-01-12 00:00:00	2017-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12883	2017-01-13 11:11:04	2017-01-18 10:55:07
15113	MEMBRECOM	2017-01-12 00:00:00	2017-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12885	2017-01-13 11:11:14	2017-01-18 10:55:07
15122	MEMBRECOM	2017-01-12 00:00:00	2017-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12894	2017-01-13 11:12:16	2017-01-18 10:55:07
15137	VICPDTCOM	2017-01-19 00:00:00	2017-10-01 00:00:00	7	ANCIEN	\N	\N	\N	\N	8281	2017-01-19 10:36:24	2017-09-24 18:17:56
15138	VICPDTCOM	2017-01-18 00:00:00	2017-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12909	2017-01-23 14:31:21	2017-01-31 14:13:20
15139	RAPCOM	2017-01-18 00:00:00	2017-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12910	2017-01-23 14:31:27	2017-01-31 14:13:20
15140	MEMBRECOM	2017-01-18 00:00:00	2017-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12911	2017-01-23 14:31:31	2017-01-31 14:13:20
15141	MEMBRECOM	2017-01-18 00:00:00	2017-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12912	2017-01-23 14:31:36	2017-01-31 14:13:20
15142	MEMBRECOM	2017-01-18 00:00:00	2017-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12913	2017-01-23 14:31:42	2017-01-31 14:13:20
15143	MEMBRECOM	2017-01-18 00:00:00	2017-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12914	2017-01-23 14:31:46	2017-01-31 14:13:20
15144	MEMBRECOM	2017-01-18 00:00:00	2017-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12915	2017-01-23 14:31:50	2017-01-31 14:13:20
15145	MEMBRECOM	2017-01-18 00:00:00	2017-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12916	2017-01-23 14:31:54	2017-01-31 14:13:20
15146	MEMBRECOM	2017-01-18 00:00:00	2017-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12917	2017-01-23 14:31:59	2017-01-31 14:13:20
15147	MEMBRECOM	2017-01-18 00:00:00	2017-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12918	2017-01-23 14:32:05	2017-01-31 14:13:20
15148	MEMBRECOM	2017-01-18 00:00:00	2017-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12919	2017-01-23 14:32:09	2017-01-31 14:13:20
15149	MEMBRECOM	2017-01-18 00:00:00	2017-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12920	2017-01-23 14:32:14	2017-01-31 14:13:20
15150	MEMBRECOM	2017-01-18 00:00:00	2017-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12921	2017-01-23 14:32:20	2017-01-31 14:13:20
15151	MEMBRECOM	2017-01-18 00:00:00	2017-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12922	2017-01-23 14:32:24	2017-01-31 14:13:20
11331	MEMBRECOM	2013-10-03 00:00:00	2017-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9567	\N	2017-06-19 12:20:59
9464	MEMBRECOM	2011-07-05 00:00:00	2017-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7952	\N	2017-06-19 12:20:59
10102	MEMBRECOM	2012-01-12 00:00:00	2017-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8456	\N	2017-06-19 12:20:59
12426	MEMBRECOM	2014-02-05 00:00:00	2017-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10374	\N	2017-06-19 12:20:59
8719	MEMBRECOM	2010-03-31 00:00:00	2017-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7247	\N	2017-06-19 12:20:59
11316	MEMBRECOM	2013-10-03 00:00:00	2017-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9552	\N	2017-06-19 12:20:59
15257	MEMBRECOM	2017-06-18 00:00:00	2017-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13028	2017-06-19 15:51:10	2017-06-28 09:50:50
15258	MEMBRECOM	2017-06-18 00:00:00	2017-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13029	2017-06-19 15:52:41	2017-06-28 09:51:15
15259	MEMBRECOM	2017-06-18 00:00:00	2017-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10329	2017-06-19 15:56:02	2017-06-28 09:52:21
15260	MEMBRECOM	2017-06-18 00:00:00	2017-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13030	2017-06-19 15:58:23	2017-06-28 09:53:52
11758	MEMBRECOM	2014-05-13 00:00:00	2017-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9940	2014-05-13 14:42:54	2017-06-19 16:06:51
15261	MEMBRECOM	2017-06-18 00:00:00	2017-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13031	2017-06-19 16:45:46	2017-06-28 09:51:57
15262	MEMBRECOM	2017-06-18 00:00:00	2017-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13032	2017-06-19 16:48:14	2017-06-27 16:48:49
17299	VICPDTCOM	2018-10-11 00:00:00	2019-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14462	\N	\N
15264	MEMBRECOM	2017-06-15 00:00:00	2017-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13034	2017-06-19 17:55:47	2017-06-22 12:18:21
15265	MEMBRECOM	2017-06-20 00:00:00	2023-10-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13035	2017-06-20 00:00:00	\N
15266	MEMBRECOM	2017-06-22 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13036	2017-06-22 12:18:21	2017-09-24 18:16:52
15267	MEMBRECOM	2017-06-27 00:00:00	2018-11-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13037	2017-06-27 16:48:48	\N
15268	MEMBRECOM	2017-06-28 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10227	2017-06-28 09:50:49	2017-09-24 18:05:41
11391	VICPDTCOM	2013-10-03 00:00:00	2017-07-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9627	\N	2017-07-04 15:08:09
9685	MEMBRECOM	2011-10-01 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19	\N	2017-10-04 18:38:09
15270	MEMBRECOM	2017-06-28 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8682	2017-06-28 09:51:15	2017-10-04 18:38:48
15271	MEMBRECOM	2017-06-28 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13039	2017-06-28 09:51:57	2017-10-04 18:52:02
15272	MEMBRECOM	2017-06-28 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	726	2017-06-28 09:52:21	2017-10-04 19:14:51
15273	MEMBRECOM	2017-06-28 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13040	2017-06-28 09:53:51	2017-10-04 19:02:06
14696	PDTCOM	2016-07-08 00:00:00	2016-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12500	2016-07-08 11:19:43	2016-10-07 09:19:09
14697	RAPCOM	2016-07-08 00:00:00	2016-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12501	2016-07-08 11:19:51	2016-10-07 09:19:09
14698	MEMBRECOM	2016-07-08 00:00:00	2016-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12502	2016-07-08 11:19:55	2016-10-07 09:19:09
14699	MEMBRECOM	2016-07-08 00:00:00	2016-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12503	2016-07-08 11:20:00	2016-10-07 09:19:09
14700	MEMBRECOM	2016-07-08 00:00:00	2016-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12504	2016-07-08 11:20:05	2016-10-07 09:19:09
14701	MEMBRECOM	2016-07-08 00:00:00	2016-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12505	2016-07-08 11:20:10	2016-10-07 09:19:09
14702	MEMBRECOM	2016-07-08 00:00:00	2016-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12506	2016-07-08 11:20:14	2016-10-07 09:19:09
14703	MEMBRECOM	2016-07-08 00:00:00	2016-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12507	2016-07-08 11:20:19	2016-10-07 09:19:09
14704	MEMBRECOM	2016-07-08 00:00:00	2016-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12508	2016-07-08 11:20:23	2016-10-07 09:19:09
14705	MEMBRECOM	2016-07-08 00:00:00	2016-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12509	2016-07-08 11:20:27	2016-10-07 09:19:09
14706	MEMBRECOM	2016-07-08 00:00:00	2016-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12510	2016-07-08 11:20:31	2016-10-07 09:19:09
14707	MEMBRECOM	2016-07-08 00:00:00	2016-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12511	2016-07-08 11:20:35	2016-10-07 09:19:09
14708	MEMBRECOM	2016-07-08 00:00:00	2016-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12512	2016-07-08 11:20:42	2016-10-07 09:19:09
14709	MEMBRECOM	2016-07-08 00:00:00	2016-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12513	2016-07-08 11:20:46	2016-10-07 09:19:09
14804	MEMBRECOM	2016-11-13 00:00:00	2016-11-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12600	2016-11-14 18:40:41	2016-11-22 16:39:26
14967	MEMBRECOM	2016-11-22 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12763	2016-11-22 16:39:25	2017-09-24 16:24:51
14968	PDTCOM	2016-11-23 00:00:00	2016-12-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12764	2016-11-24 11:55:43	2016-12-01 15:39:21
14969	RAPCOM	2016-11-23 00:00:00	2016-12-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12765	2016-11-24 11:55:48	2016-12-01 15:39:21
14970	MEMBRECOM	2016-11-23 00:00:00	2016-12-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12766	2016-11-24 11:55:52	2016-12-01 15:39:21
14971	MEMBRECOM	2016-11-23 00:00:00	2016-12-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12767	2016-11-24 11:55:57	2016-12-01 15:39:21
14972	MEMBRECOM	2016-11-23 00:00:00	2016-12-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12768	2016-11-24 11:56:03	2016-12-01 15:39:21
14973	MEMBRECOM	2016-11-23 00:00:00	2016-12-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12769	2016-11-24 11:56:09	2016-12-01 15:39:21
14974	MEMBRECOM	2016-11-23 00:00:00	2016-12-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12770	2016-11-24 11:56:14	2016-12-01 15:39:21
14975	MEMBRECOM	2016-11-23 00:00:00	2016-12-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12771	2016-11-24 11:56:20	2016-12-01 15:39:21
14976	MEMBRECOM	2016-11-23 00:00:00	2016-12-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12772	2016-11-24 11:56:24	2016-12-01 15:39:15
14977	MEMBRECOM	2016-11-23 00:00:00	2016-12-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12773	2016-11-24 11:56:28	2016-12-01 15:39:15
14978	MEMBRECOM	2016-11-23 00:00:00	2016-12-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12774	2016-11-24 11:56:33	2016-12-01 15:39:21
14979	MEMBRECOM	2016-11-23 00:00:00	2016-12-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12775	2016-11-24 11:56:37	2016-12-01 15:39:21
14980	MEMBRECOM	2016-11-23 00:00:00	2016-12-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12776	2016-11-24 11:56:43	2016-12-01 15:39:21
14981	MEMBRECOM	2016-11-23 00:00:00	2016-12-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12777	2016-11-24 11:56:49	2016-12-01 15:39:21
14982	PDTCOM	2016-11-23 00:00:00	2016-12-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12778	2016-11-24 11:59:09	2016-12-01 15:39:15
14983	RAPCOM	2016-11-23 00:00:00	2016-12-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12779	2016-11-24 11:59:13	2016-12-01 15:39:15
14984	MEMBRECOM	2016-11-23 00:00:00	2016-12-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12780	2016-11-24 11:59:23	2016-12-01 15:39:15
14985	MEMBRECOM	2016-11-23 00:00:00	2016-12-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12781	2016-11-24 11:59:28	2016-12-01 15:39:15
14986	MEMBRECOM	2016-11-23 00:00:00	2016-12-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12782	2016-11-24 11:59:31	2016-12-01 15:39:15
14987	MEMBRECOM	2016-11-23 00:00:00	2016-12-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12783	2016-11-24 11:59:36	2016-12-01 15:39:15
14988	MEMBRECOM	2016-11-23 00:00:00	2016-12-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12784	2016-11-24 11:59:43	2016-12-01 15:39:15
14989	MEMBRECOM	2016-11-23 00:00:00	2016-12-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12785	2016-11-24 12:00:00	2016-12-01 15:39:15
14990	MEMBRECOM	2016-11-23 00:00:00	2016-12-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12786	2016-11-24 12:00:05	2016-12-01 15:39:15
14991	MEMBRECOM	2016-11-23 00:00:00	2016-12-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12787	2016-11-24 12:00:10	2016-12-01 15:39:15
14992	MEMBRECOM	2016-11-23 00:00:00	2016-12-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12788	2016-11-24 12:00:16	2016-12-01 15:39:15
10663	MEMBRECOM	2012-10-23 00:00:00	2016-11-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8951	\N	2016-12-01 10:36:51
15014	MEMBRECOM	2016-12-01 00:00:00	2016-12-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12810	2016-12-01 10:39:20	2016-12-06 15:38:54
15183	PDTCOM	2017-02-09 00:00:00	2017-02-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12954	2017-02-09 10:40:34	2017-02-14 16:23:34
15184	RAPCOM	2017-02-09 00:00:00	2017-02-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12955	2017-02-09 10:40:38	2017-02-14 16:23:34
15185	MEMBRECOM	2017-02-09 00:00:00	2017-02-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12956	2017-02-09 10:40:43	2017-02-14 16:23:34
15186	MEMBRECOM	2017-02-09 00:00:00	2017-02-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12957	2017-02-09 10:40:48	2017-02-14 16:23:34
15187	MEMBRECOM	2017-02-09 00:00:00	2017-02-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12958	2017-02-09 10:40:53	2017-02-14 16:23:34
15188	MEMBRECOM	2017-02-09 00:00:00	2017-02-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12959	2017-02-09 10:41:13	2017-02-14 16:23:34
15189	MEMBRECOM	2017-02-09 00:00:00	2017-02-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12960	2017-02-09 10:41:20	2017-02-14 16:23:34
15190	MEMBRECOM	2017-02-09 00:00:00	2017-02-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12961	2017-02-09 10:41:26	2017-02-14 16:23:34
15191	MEMBRECOM	2017-02-09 00:00:00	2017-02-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12962	2017-02-09 10:41:33	2017-02-14 16:23:34
15192	MEMBRECOM	2017-02-09 00:00:00	2017-02-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12963	2017-02-09 10:41:40	2017-02-14 16:23:34
15193	MEMBRECOM	2017-02-09 00:00:00	2017-02-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12964	2017-02-09 10:41:48	2017-02-14 16:23:34
15194	MEMBRECOM	2017-02-09 00:00:00	2017-02-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12965	2017-02-09 10:41:54	2017-02-14 16:23:34
15195	MEMBRECOM	2017-02-09 00:00:00	2017-02-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12966	2017-02-09 10:42:00	2017-02-14 16:23:34
15196	MEMBRECOM	2017-02-09 00:00:00	2017-02-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12967	2017-02-09 10:42:11	2017-02-14 16:23:34
15197	PDTCOM	2017-02-08 00:00:00	2017-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12968	2017-02-14 16:34:01	2017-02-14 16:44:06
15198	RAPCOM	2017-02-08 00:00:00	2017-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12969	2017-02-14 16:34:06	2017-02-14 16:44:06
15199	MEMBRECOM	2017-02-08 00:00:00	2017-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12970	2017-02-14 16:34:11	2017-02-14 16:44:06
15200	MEMBRECOM	2017-02-08 00:00:00	2017-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12971	2017-02-14 16:34:20	2017-02-14 16:44:06
15201	MEMBRECOM	2017-02-08 00:00:00	2017-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12972	2017-02-14 16:34:27	2017-02-14 16:44:06
15202	MEMBRECOM	2017-02-08 00:00:00	2017-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12973	2017-02-14 16:34:35	2017-02-14 16:44:06
15203	MEMBRECOM	2017-02-08 00:00:00	2017-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12974	2017-02-14 16:34:41	2017-02-14 16:44:06
15204	MEMBRECOM	2017-02-08 00:00:00	2017-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12975	2017-02-14 16:34:47	2017-02-14 16:44:06
15205	MEMBRECOM	2017-02-08 00:00:00	2017-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12976	2017-02-14 16:34:52	2017-02-14 16:44:06
15206	MEMBRECOM	2017-02-08 00:00:00	2017-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12977	2017-02-14 16:34:57	2017-02-14 16:44:06
15207	MEMBRECOM	2017-02-08 00:00:00	2017-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12978	2017-02-14 16:35:02	2017-02-14 16:44:06
15208	MEMBRECOM	2017-02-08 00:00:00	2017-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12979	2017-02-14 16:35:11	2017-02-14 16:44:06
15209	MEMBRECOM	2017-02-08 00:00:00	2017-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12980	2017-02-14 16:35:17	2017-02-14 16:44:06
15210	MEMBRECOM	2017-02-08 00:00:00	2017-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12981	2017-02-14 16:35:23	2017-02-14 16:44:06
15211	PDTCOM	2017-02-08 00:00:00	2017-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12982	2017-02-14 17:57:04	2017-02-14 18:17:29
15212	RAPCOM	2017-02-08 00:00:00	2017-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12983	2017-02-14 17:57:09	2017-02-14 18:17:29
15213	MEMBRECOM	2017-02-08 00:00:00	2017-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12984	2017-02-14 17:57:15	2017-02-14 18:17:29
15214	MEMBRECOM	2017-02-08 00:00:00	2017-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12985	2017-02-14 17:57:20	2017-02-14 18:17:29
15215	MEMBRECOM	2017-02-08 00:00:00	2017-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12986	2017-02-14 17:57:26	2017-02-14 18:17:29
15216	MEMBRECOM	2017-02-08 00:00:00	2017-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12987	2017-02-14 17:57:32	2017-02-14 18:17:29
15217	MEMBRECOM	2017-02-08 00:00:00	2017-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12988	2017-02-14 17:57:37	2017-02-14 18:17:29
15218	MEMBRECOM	2017-02-08 00:00:00	2017-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12989	2017-02-14 17:57:42	2017-02-14 18:17:29
15087	MEMBRECOM	2017-01-01 00:00:00	2017-01-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12859	2017-01-03 11:10:58	2017-01-10 18:00:19
15153	VICPDTCOM	2017-01-26 00:00:00	2017-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12924	2017-01-31 14:15:25	2017-02-07 09:57:49
15154	RAPCOM	2017-01-26 00:00:00	2017-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12925	2017-01-31 14:15:31	2017-02-07 09:57:49
15155	MEMBRECOM	2017-01-26 00:00:00	2017-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12926	2017-01-31 14:16:04	2017-02-07 09:57:49
15156	MEMBRECOM	2017-01-26 00:00:00	2017-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12927	2017-01-31 14:16:10	2017-02-07 09:57:49
15157	MEMBRECOM	2017-01-26 00:00:00	2017-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12928	2017-01-31 14:16:16	2017-02-07 09:57:49
15158	MEMBRECOM	2017-01-26 00:00:00	2017-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12929	2017-01-31 14:16:20	2017-02-07 09:57:49
15159	MEMBRECOM	2017-01-26 00:00:00	2017-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12930	2017-01-31 14:16:26	2017-02-07 09:57:49
15160	MEMBRECOM	2017-01-26 00:00:00	2017-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12931	2017-01-31 14:16:34	2017-02-07 09:57:49
15161	MEMBRECOM	2017-01-26 00:00:00	2017-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12932	2017-01-31 14:16:41	2017-02-07 09:57:49
15162	MEMBRECOM	2017-01-26 00:00:00	2017-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12933	2017-01-31 14:16:45	2017-02-07 09:57:49
15163	MEMBRECOM	2017-01-26 00:00:00	2017-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12934	2017-01-31 14:16:49	2017-02-07 09:57:49
15164	MEMBRECOM	2017-01-26 00:00:00	2017-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12935	2017-01-31 14:16:54	2017-02-07 09:57:49
15165	MEMBRECOM	2017-01-26 00:00:00	2017-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12936	2017-01-31 14:16:59	2017-02-07 09:57:49
15166	MEMBRECOM	2017-01-26 00:00:00	2017-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12937	2017-01-31 14:17:03	2017-02-07 09:57:49
15167	VICPDTCOM	2017-01-31 00:00:00	2017-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12938	2017-01-31 14:39:27	2017-02-07 09:57:43
15168	RAPCOM	2017-01-31 00:00:00	2017-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12939	2017-01-31 14:39:32	2017-02-07 09:57:43
15169	MEMBRECOM	2017-01-31 00:00:00	2017-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12940	2017-01-31 14:39:36	2017-02-07 09:57:43
15170	MEMBRECOM	2017-01-31 00:00:00	2017-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12941	2017-01-31 14:39:41	2017-02-07 09:57:43
15171	MEMBRECOM	2017-01-31 00:00:00	2017-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12942	2017-01-31 14:39:49	2017-02-07 09:57:43
15172	MEMBRECOM	2017-01-31 00:00:00	2017-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12943	2017-01-31 14:39:56	2017-02-07 09:57:43
15173	MEMBRECOM	2017-01-31 00:00:00	2017-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12944	2017-01-31 14:40:03	2017-02-07 09:57:43
15174	MEMBRECOM	2017-01-31 00:00:00	2017-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12945	2017-01-31 14:40:08	2017-02-07 09:57:43
15175	MEMBRECOM	2017-01-31 00:00:00	2017-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12946	2017-01-31 14:40:13	2017-02-07 09:57:43
15176	MEMBRECOM	2017-01-31 00:00:00	2017-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12947	2017-01-31 14:40:20	2017-02-07 09:57:43
15177	MEMBRECOM	2017-01-31 00:00:00	2017-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12948	2017-01-31 14:40:25	2017-02-07 09:57:43
15178	MEMBRECOM	2017-01-31 00:00:00	2017-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12949	2017-01-31 14:40:29	2017-02-07 09:57:43
15179	MEMBRECOM	2017-01-31 00:00:00	2017-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12950	2017-01-31 14:40:35	2017-02-07 09:57:43
15180	MEMBRECOM	2017-01-31 00:00:00	2017-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12951	2017-01-31 14:40:39	2017-02-07 09:57:43
15219	MEMBRECOM	2017-02-08 00:00:00	2017-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12990	2017-02-14 17:57:47	2017-02-14 18:17:29
15220	MEMBRECOM	2017-02-08 00:00:00	2017-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12991	2017-02-14 17:57:53	2017-02-14 18:17:29
15221	MEMBRECOM	2017-02-08 00:00:00	2017-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12992	2017-02-14 17:57:58	2017-02-14 18:17:29
15222	MEMBRECOM	2017-02-08 00:00:00	2017-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12993	2017-02-14 17:58:04	2017-02-14 18:17:29
15223	MEMBRECOM	2017-02-08 00:00:00	2017-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12994	2017-02-14 17:58:09	2017-02-14 18:17:29
15224	MEMBRECOM	2017-02-08 00:00:00	2017-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12995	2017-02-14 17:58:14	2017-02-14 18:17:29
15239	PDTCOM	2017-02-08 00:00:00	2017-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13010	2017-02-14 18:06:22	2017-02-14 18:17:34
15240	RAPCOM	2017-02-08 00:00:00	2017-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13011	2017-02-14 18:06:28	2017-02-14 18:17:34
15241	MEMBRECOM	2017-02-08 00:00:00	2017-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13012	2017-02-14 18:06:33	2017-02-14 18:17:34
15242	MEMBRECOM	2017-02-08 00:00:00	2017-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13013	2017-02-14 18:06:39	2017-02-14 18:17:34
15243	MEMBRECOM	2017-02-08 00:00:00	2017-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13014	2017-02-14 18:06:45	2017-02-14 18:17:34
15244	MEMBRECOM	2017-02-08 00:00:00	2017-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13015	2017-02-14 18:06:53	2017-02-14 18:17:34
15245	MEMBRECOM	2017-02-08 00:00:00	2017-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13016	2017-02-14 18:06:57	2017-02-14 18:17:34
15246	MEMBRECOM	2017-02-08 00:00:00	2017-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13017	2017-02-14 18:07:03	2017-02-14 18:17:34
15247	MEMBRECOM	2017-02-08 00:00:00	2017-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13018	2017-02-14 18:07:08	2017-02-14 18:17:34
15248	MEMBRECOM	2017-02-08 00:00:00	2017-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13019	2017-02-14 18:07:13	2017-02-14 18:17:34
15249	MEMBRECOM	2017-02-08 00:00:00	2017-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13020	2017-02-14 18:07:18	2017-02-14 18:17:34
15250	MEMBRECOM	2017-02-08 00:00:00	2017-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13021	2017-02-14 18:07:22	2017-02-14 18:17:34
15251	MEMBRECOM	2017-02-08 00:00:00	2017-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13022	2017-02-14 18:07:27	2017-02-14 18:17:34
15252	MEMBRECOM	2017-02-08 00:00:00	2017-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13023	2017-02-14 18:07:32	2017-02-14 18:17:34
9024	MEMBRECOM	2010-12-07 00:00:00	2017-05-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7524	\N	2017-05-16 15:18:13
8437	MEMBRECOM	2009-10-07 00:00:00	2017-05-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6996	\N	2017-05-16 15:18:13
11987	MEMBRECOM	2014-10-08 00:00:00	2017-05-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10155	2014-10-08 17:09:46	2017-05-16 15:18:13
10038	MEMBRECOM	2011-12-19 00:00:00	2017-05-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8392	\N	2017-05-16 15:18:13
11232	MEMBRECOM	2013-07-04 00:00:00	2017-05-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9476	\N	2017-05-16 15:18:13
10486	MEMBRECOM	2012-02-22 00:00:00	2017-05-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8799	\N	2017-05-16 15:18:13
9398	MEMBRECOM	2011-06-27 00:00:00	2017-05-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7886	\N	2017-05-16 15:18:13
10023	MEMBRECOM	2011-12-08 00:00:00	2017-05-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8377	\N	2017-05-16 15:18:13
10740	MEMBRECOM	2012-11-27 00:00:00	2017-05-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9027	\N	2017-05-16 15:18:13
4009	MEMBRECOM	2005-12-15 00:00:00	2017-05-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3089	\N	2017-05-16 15:18:13
15255	MEMBRECOM	2017-05-15 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13026	2017-05-16 16:19:32	2017-09-24 12:39:59
14949	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12745	2016-11-22 12:23:39	2017-06-12 11:06:53
14955	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12751	2016-11-22 12:24:48	2017-06-12 11:07:07
14956	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12752	2016-11-22 12:24:56	2017-06-12 11:07:07
14960	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12756	2016-11-22 12:27:59	2017-06-12 11:07:11
14961	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12757	2016-11-22 12:28:05	2017-06-12 11:07:11
14772	MEMBRECOM	2016-07-13 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12571	2016-10-07 09:13:03	2017-06-12 11:07:15
14673	MEMBRECOM	2016-07-07 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12477	2016-07-07 17:25:15	2017-06-12 11:07:18
14665	MEMBRECOM	2016-07-07 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12469	2016-07-07 17:24:26	2017-06-12 11:07:18
14669	MEMBRECOM	2016-07-07 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12473	2016-07-07 17:24:50	2017-06-12 11:07:18
14470	RAPCOM	2016-05-31 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12281	2016-06-01 09:58:32	2017-06-12 11:07:55
14471	VICPDTCOM	2016-05-31 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12275	2016-06-01 09:58:38	2017-06-12 11:07:55
14472	PDTCOM	2016-05-31 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12285	2016-06-01 09:58:53	2017-06-12 11:07:55
12292	MEMBRECOM	2014-10-09 00:00:00	2016-04-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10267	2014-10-09 16:21:07	2016-07-07 18:11:25
14801	PDTCOM	2016-11-09 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11551	2016-11-09 17:04:59	2017-09-24 17:28:55
14802	RAPCOM	2016-11-09 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11553	2016-11-09 17:05:06	2017-10-04 20:36:44
14803	VICPDTCOM	2016-11-09 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11552	2016-11-09 17:05:12	2017-10-04 20:29:44
14835	MEMBRECOM	2016-11-22 00:00:00	2016-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12631	2016-11-21 17:22:15	2016-12-01 15:02:22
14836	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12632	2016-11-21 17:22:24	2017-06-12 11:06:53
14837	MEMBRECOM	2016-11-22 00:00:00	2016-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12633	2016-11-21 17:22:30	2016-12-01 15:02:33
14838	MEMBRECOM	2016-11-22 00:00:00	2016-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12634	2016-11-21 17:22:37	2016-12-01 15:01:54
14839	MEMBRECOM	2016-11-22 00:00:00	2016-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12635	2016-11-21 17:22:47	2016-12-01 15:02:17
14840	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12636	2016-11-21 17:22:56	2017-06-12 11:06:53
14841	MEMBRECOM	2016-11-22 00:00:00	2016-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12637	2016-11-21 17:23:10	2016-12-01 15:02:07
14842	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12638	2016-11-21 17:23:22	2017-06-12 11:06:53
14843	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12639	2016-11-21 17:23:32	2017-06-12 11:06:53
14844	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12640	2016-11-21 17:23:39	2017-06-12 11:06:53
14845	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12641	2016-11-21 17:23:49	2017-06-12 11:06:53
14846	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12642	2016-11-21 17:23:59	2017-06-12 11:06:53
14847	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12643	2016-11-21 17:24:08	2017-06-12 11:06:53
14848	MEMBRECOM	2016-11-22 00:00:00	2016-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12644	2016-11-21 17:24:19	2016-12-01 15:02:27
14849	MEMBRECOM	2016-11-22 00:00:00	2016-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12645	2016-11-21 17:31:31	2016-12-01 15:06:36
14850	MEMBRECOM	2016-11-22 00:00:00	2016-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12646	2016-11-21 17:33:54	2016-12-01 15:04:16
14851	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12647	2016-11-21 17:34:55	2017-06-12 11:06:58
14336	PDTCOM	2016-05-02 00:00:00	2016-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12146	2016-05-02 10:27:49	2017-06-12 11:08:12
14853	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12649	2016-11-21 17:35:08	2017-06-12 11:06:58
14854	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12650	2016-11-21 17:35:13	2017-06-12 11:06:58
14855	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12651	2016-11-21 17:35:20	2017-06-12 11:06:58
14856	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12652	2016-11-21 17:35:26	2017-06-12 11:06:58
14857	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12653	2016-11-21 17:35:31	2017-06-12 11:06:58
14858	MEMBRECOM	2016-11-22 00:00:00	2016-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12654	2016-11-21 17:35:42	2016-12-01 15:06:46
14859	MEMBRECOM	2016-11-22 00:00:00	2016-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12655	2016-11-21 17:35:47	2016-12-01 15:06:52
14860	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12656	2016-11-21 17:35:51	2017-06-12 11:06:58
14861	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12657	2016-11-21 17:35:56	2017-06-12 11:06:58
14862	MEMBRECOM	2016-11-22 00:00:00	2016-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12658	2016-11-21 17:36:00	2016-12-01 15:04:22
14863	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12659	2016-11-21 17:36:06	2017-06-12 11:06:58
14926	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12722	2016-11-21 17:53:02	2017-06-12 11:07:07
14923	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12719	2016-11-21 17:52:39	2017-06-12 11:07:07
14924	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12720	2016-11-21 17:52:45	2017-06-12 11:07:07
14925	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12721	2016-11-21 17:52:52	2017-06-12 11:07:07
14927	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12723	2016-11-21 17:53:08	2017-06-12 11:07:07
14928	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12724	2016-11-21 17:53:19	2017-06-12 11:07:07
14906	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12702	2016-11-21 17:46:58	2017-06-12 11:07:11
14929	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12725	2016-11-21 17:53:25	2017-06-12 11:07:07
14930	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12726	2016-11-21 17:53:30	2017-06-12 11:07:07
14931	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12727	2016-11-21 17:53:36	2017-06-12 11:07:07
14932	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12728	2016-11-21 17:53:42	2017-06-12 11:07:07
14933	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12729	2016-11-21 17:53:49	2017-06-12 11:07:07
14934	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12730	2016-11-21 17:53:54	2017-06-12 11:07:07
14935	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12731	2016-11-21 17:53:59	2017-06-12 11:07:07
14936	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12732	2016-11-21 17:54:04	2017-06-12 11:07:07
14937	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12733	2016-11-21 17:54:16	2017-06-12 11:07:07
14938	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12734	2016-11-21 17:54:23	2017-06-12 11:07:07
14939	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12735	2016-11-21 17:54:28	2017-06-12 11:07:07
14940	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12736	2016-11-21 17:54:33	2017-06-12 11:07:07
14941	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12737	2016-11-21 17:54:38	2017-06-12 11:07:07
14907	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12703	2016-11-21 17:47:04	2017-06-12 11:07:11
14908	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12704	2016-11-21 17:47:10	2017-06-12 11:07:11
14905	MEMBRECOM	2016-11-22 00:00:00	2016-11-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12701	2016-11-21 17:46:52	2016-12-01 15:08:05
14909	MEMBRECOM	2016-11-22 00:00:00	2016-11-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12705	2016-11-21 17:47:19	2016-12-01 15:08:26
14910	MEMBRECOM	2016-11-22 00:00:00	2016-11-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12706	2016-11-21 17:47:23	2016-12-01 15:07:48
14911	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12707	2016-11-21 17:47:28	2017-06-12 11:07:11
14912	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12708	2016-11-21 17:47:35	2017-06-12 11:07:11
14913	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12709	2016-11-21 17:47:40	2017-06-12 11:07:11
14914	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12710	2016-11-21 17:47:46	2017-06-12 11:07:11
14915	MEMBRECOM	2016-11-22 00:00:00	2016-11-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12711	2016-11-21 17:47:52	2016-12-01 15:08:20
14916	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12712	2016-11-21 17:47:58	2017-06-12 11:07:11
14917	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12713	2016-11-21 17:48:05	2017-06-12 11:07:11
14918	MEMBRECOM	2016-11-22 00:00:00	2016-11-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12714	2016-11-21 17:48:09	2016-12-01 15:07:39
14919	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12715	2016-11-21 17:48:17	2017-06-12 11:07:11
14920	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12716	2016-11-21 17:49:32	2017-06-12 11:07:11
14921	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12717	2016-11-21 17:49:37	2017-06-12 11:07:11
14922	MEMBRECOM	2016-11-22 00:00:00	2016-11-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12718	2016-11-21 17:49:43	2016-12-01 15:07:54
14347	VICPDTCOM	2016-05-03 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12181	2016-05-03 17:23:18	2017-06-12 11:08:26
14346	VICPDTCOM	2016-05-03 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12167	2016-05-03 17:23:12	2017-06-12 11:08:26
14325	MEMBRECOM	2016-04-27 00:00:00	2016-10-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12178	2016-04-27 15:16:53	2017-06-12 11:08:26
14668	MEMBRECOM	2016-07-07 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12472	2016-07-07 17:24:42	2017-06-12 11:07:18
14295	MEMBRECOM	2016-04-27 00:00:00	2016-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12148	2016-04-27 14:58:46	2017-06-12 11:08:12
14787	PDTCOM	2016-10-19 00:00:00	2016-11-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12586	2016-10-20 17:04:03	2016-11-03 17:03:58
14788	RAPCOM	2016-10-19 00:00:00	2016-11-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12587	2016-10-20 17:04:08	2016-11-03 17:03:58
14789	MEMBRECOM	2016-10-19 00:00:00	2016-11-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12588	2016-10-20 17:04:12	2016-11-03 17:03:58
14790	MEMBRECOM	2016-10-19 00:00:00	2016-11-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12589	2016-10-20 17:04:19	2016-11-03 17:03:58
14791	MEMBRECOM	2016-10-19 00:00:00	2016-11-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12590	2016-10-20 17:04:27	2016-11-03 17:03:58
14792	MEMBRECOM	2016-10-19 00:00:00	2016-11-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12591	2016-10-20 17:04:33	2016-11-03 17:03:58
14793	MEMBRECOM	2016-10-19 00:00:00	2016-11-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12592	2016-10-20 17:04:38	2016-11-03 17:03:58
14794	MEMBRECOM	2016-10-19 00:00:00	2016-11-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12593	2016-10-20 17:04:43	2016-11-03 17:03:58
14795	MEMBRECOM	2016-10-19 00:00:00	2016-11-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12594	2016-10-20 17:04:47	2016-11-03 17:03:58
14796	MEMBRECOM	2016-10-19 00:00:00	2016-11-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12595	2016-10-20 17:04:53	2016-11-03 17:03:58
14797	MEMBRECOM	2016-10-19 00:00:00	2016-11-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12596	2016-10-20 17:05:02	2016-11-03 17:03:58
14798	MEMBRECOM	2016-10-19 00:00:00	2016-11-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12597	2016-10-20 17:05:10	2016-11-03 17:03:58
14799	MEMBRECOM	2016-10-19 00:00:00	2016-11-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12598	2016-10-20 17:05:18	2016-11-03 17:03:58
14800	MEMBRECOM	2016-10-19 00:00:00	2016-11-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12599	2016-10-20 17:05:24	2016-11-03 17:03:58
14820	MEMBRECOM	2016-11-18 00:00:00	2016-11-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12616	2016-11-18 12:45:10	2016-11-30 10:35:16
14942	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12738	2016-11-22 12:22:56	2017-06-12 11:06:53
14943	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12739	2016-11-22 12:23:03	2017-06-12 11:06:53
14944	MEMBRECOM	2016-11-22 00:00:00	2016-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12740	2016-11-22 12:23:08	2016-12-01 15:02:39
14945	MEMBRECOM	2016-11-22 00:00:00	2016-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12741	2016-11-22 12:23:17	2016-12-01 15:02:50
14947	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12743	2016-11-22 12:23:28	2017-06-12 11:06:53
14948	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12744	2016-11-22 12:23:33	2017-06-12 11:06:53
14950	MEMBRECOM	2016-11-22 00:00:00	2016-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12746	2016-11-22 12:24:05	2016-12-01 15:04:27
14951	MEMBRECOM	2016-11-22 00:00:00	2016-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12747	2016-11-22 12:24:11	2016-12-01 15:04:49
14952	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12748	2016-11-22 12:24:33	2017-06-12 11:07:07
14953	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12749	2016-11-22 12:24:39	2017-06-12 11:07:07
14954	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12750	2016-11-22 12:24:43	2017-06-12 11:07:07
14957	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12753	2016-11-22 12:25:01	2017-06-12 11:07:11
14958	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12754	2016-11-22 12:25:12	2017-06-12 11:07:07
14959	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12755	2016-11-22 12:25:21	2017-06-12 11:07:07
14962	MEMBRECOM	2016-11-22 00:00:00	2016-11-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12758	2016-11-22 12:28:10	2016-12-01 15:08:12
14963	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12759	2016-11-22 12:28:19	2017-06-12 11:07:11
14964	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12760	2016-11-22 12:28:24	2017-06-12 11:07:11
14965	MEMBRECOM	2016-11-22 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12761	2016-11-22 12:28:32	2017-06-12 11:07:11
14966	MEMBRECOM	2016-11-22 00:00:00	2016-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12762	2016-11-22 15:23:51	2016-12-01 15:06:55
15073	PDTCOM	2016-12-16 00:00:00	2016-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12845	2016-12-16 17:11:38	2016-12-21 14:17:51
15074	RAPCOM	2016-12-16 00:00:00	2016-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12846	2016-12-16 17:11:44	2016-12-21 14:17:51
15075	MEMBRECOM	2016-12-16 00:00:00	2016-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12847	2016-12-16 17:11:49	2016-12-21 14:17:51
15076	MEMBRECOM	2016-12-16 00:00:00	2016-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12848	2016-12-16 17:11:54	2016-12-21 14:17:51
15077	MEMBRECOM	2016-12-16 00:00:00	2016-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12849	2016-12-16 17:11:59	2016-12-21 14:17:51
15078	MEMBRECOM	2016-12-16 00:00:00	2016-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12850	2016-12-16 17:12:03	2016-12-21 14:17:51
15079	MEMBRECOM	2016-12-16 00:00:00	2016-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12851	2016-12-16 17:12:08	2016-12-21 14:17:51
15080	MEMBRECOM	2016-12-16 00:00:00	2016-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12852	2016-12-16 17:12:13	2016-12-21 14:17:51
15081	MEMBRECOM	2016-12-16 00:00:00	2016-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12853	2016-12-16 17:12:21	2016-12-21 14:17:51
15082	MEMBRECOM	2016-12-16 00:00:00	2016-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12854	2016-12-16 17:12:29	2016-12-21 14:17:51
15083	MEMBRECOM	2016-12-16 00:00:00	2016-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12855	2016-12-16 17:12:40	2016-12-21 14:17:51
15084	MEMBRECOM	2016-12-16 00:00:00	2016-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12856	2016-12-16 17:12:48	2016-12-21 14:17:51
15085	MEMBRECOM	2016-12-16 00:00:00	2016-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12857	2016-12-16 17:12:54	2016-12-21 14:17:51
15086	MEMBRECOM	2016-12-16 00:00:00	2016-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12858	2016-12-16 17:13:04	2016-12-21 14:17:51
15090	PDTCOM	2017-01-12 00:00:00	2017-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12862	2017-01-13 11:00:53	2017-01-18 10:55:00
15091	MEMBRECOM	2017-01-12 00:00:00	2017-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12863	2017-01-13 11:00:59	2017-01-18 10:55:00
15092	MEMBRECOM	2017-01-12 00:00:00	2017-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12864	2017-01-13 11:01:03	2017-01-18 10:55:00
15093	MEMBRECOM	2017-01-12 00:00:00	2017-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12865	2017-01-13 11:01:10	2017-01-18 10:55:00
15094	RAPCOM	2017-01-12 00:00:00	2017-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12866	2017-01-13 11:01:14	2017-01-18 10:55:00
15095	MEMBRECOM	2017-01-12 00:00:00	2017-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12867	2017-01-13 11:01:19	2017-01-18 10:55:00
15096	MEMBRECOM	2017-01-12 00:00:00	2017-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12868	2017-01-13 11:01:24	2017-01-18 10:55:00
15097	MEMBRECOM	2017-01-12 00:00:00	2017-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12869	2017-01-13 11:01:31	2017-01-18 10:55:00
15098	MEMBRECOM	2017-01-12 00:00:00	2017-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12870	2017-01-13 11:01:36	2017-01-18 10:55:00
15099	MEMBRECOM	2017-01-12 00:00:00	2017-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12871	2017-01-13 11:01:42	2017-01-18 10:55:00
15100	MEMBRECOM	2017-01-12 00:00:00	2017-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12872	2017-01-13 11:02:27	2017-01-18 10:55:00
15101	MEMBRECOM	2017-01-12 00:00:00	2017-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12873	2017-01-13 11:02:33	2017-01-18 10:55:00
15102	MEMBRECOM	2017-01-12 00:00:00	2017-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12874	2017-01-13 11:02:37	2017-01-18 10:55:00
15103	MEMBRECOM	2017-01-12 00:00:00	2017-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12875	2017-01-13 11:02:41	2017-01-18 10:55:00
15109	PDTCOM	2017-01-12 00:00:00	2017-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12881	2017-01-13 11:10:55	2017-01-18 10:55:07
15110	RAPCOM	2017-01-12 00:00:00	2017-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12882	2017-01-13 11:11:00	2017-01-18 10:55:07
15112	MEMBRECOM	2017-01-12 00:00:00	2017-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12884	2017-01-13 11:11:09	2017-01-18 10:55:07
15114	MEMBRECOM	2017-01-12 00:00:00	2017-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12886	2017-01-13 11:11:22	2017-01-18 10:55:07
15115	MEMBRECOM	2017-01-12 00:00:00	2017-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12887	2017-01-13 11:11:27	2017-01-18 10:55:07
15116	MEMBRECOM	2017-01-12 00:00:00	2017-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12888	2017-01-13 11:11:34	2017-01-18 10:55:07
15117	MEMBRECOM	2017-01-12 00:00:00	2017-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12889	2017-01-13 11:11:45	2017-01-18 10:55:07
15118	MEMBRECOM	2017-01-12 00:00:00	2017-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12890	2017-01-13 11:11:56	2017-01-18 10:55:07
15119	MEMBRECOM	2017-01-12 00:00:00	2017-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12891	2017-01-13 11:12:01	2017-01-18 10:55:07
15120	MEMBRECOM	2017-01-12 00:00:00	2017-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12892	2017-01-13 11:12:06	2017-01-18 10:55:07
15121	MEMBRECOM	2017-01-12 00:00:00	2017-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12893	2017-01-13 11:12:11	2017-01-18 10:55:07
15123	PDTCOM	2017-01-12 00:00:00	2017-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12895	2017-01-13 11:17:55	2017-01-18 10:55:04
15124	RAPCOM	2017-01-12 00:00:00	2017-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12896	2017-01-13 11:18:00	2017-01-18 10:55:04
15125	MEMBRECOM	2017-01-12 00:00:00	2017-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12897	2017-01-13 11:18:04	2017-01-18 10:55:04
15126	MEMBRECOM	2017-01-12 00:00:00	2017-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12898	2017-01-13 11:18:09	2017-01-18 10:55:04
15127	MEMBRECOM	2017-01-12 00:00:00	2017-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12899	2017-01-13 11:18:14	2017-01-18 10:55:04
15128	MEMBRECOM	2017-01-12 00:00:00	2017-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12900	2017-01-13 11:18:18	2017-01-18 10:55:04
15129	MEMBRECOM	2017-01-12 00:00:00	2017-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12901	2017-01-13 11:18:22	2017-01-18 10:55:04
15130	MEMBRECOM	2017-01-12 00:00:00	2017-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12902	2017-01-13 11:18:27	2017-01-18 10:55:04
15131	MEMBRECOM	2017-01-12 00:00:00	2017-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12903	2017-01-13 11:18:34	2017-01-18 10:55:04
15132	MEMBRECOM	2017-01-12 00:00:00	2017-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12904	2017-01-13 11:18:38	2017-01-18 10:55:04
15133	MEMBRECOM	2017-01-12 00:00:00	2017-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12905	2017-01-13 11:18:44	2017-01-18 10:55:04
11657	MEMBRECOM	2014-01-22 00:00:00	2016-04-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9864	2014-01-21 17:17:14	2016-07-07 18:17:39
13639	MEMBRECOM	2015-09-28 00:00:00	2016-04-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11503	2015-09-30 17:19:28	2016-07-07 18:18:00
12296	MEMBRECOM	2014-10-09 00:00:00	2016-04-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10271	2014-10-09 16:24:09	2016-07-07 18:19:14
12301	MEMBRECOM	2014-10-09 00:00:00	2016-04-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10276	2014-10-09 16:26:36	2016-07-07 18:29:29
11679	VICPDTCOM	2014-02-05 00:00:00	2016-04-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9844	2014-02-05 18:47:43	2016-07-07 18:30:09
11645	MEMBRECOM	2014-01-22 00:00:00	2016-04-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9852	2014-01-21 17:13:58	2016-07-07 18:32:24
12305	MEMBRECOM	2014-10-09 00:00:00	2016-04-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10280	2014-10-09 16:28:21	2016-07-07 18:33:24
14725	VICPDTCOM	2016-07-20 00:00:00	2016-07-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12529	2016-07-20 19:30:34	2016-10-07 09:17:16
14726	RAPCOM	2016-07-20 00:00:00	2016-07-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12530	2016-07-20 19:30:41	2016-10-07 09:17:16
14727	MEMBRECOM	2016-07-20 00:00:00	2016-07-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12531	2016-07-20 19:30:47	2016-10-07 09:17:16
14728	MEMBRECOM	2016-07-20 00:00:00	2016-07-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12532	2016-07-20 19:30:52	2016-10-07 09:17:16
14729	MEMBRECOM	2016-07-20 00:00:00	2016-07-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12533	2016-07-20 19:30:57	2016-10-07 09:17:16
14730	MEMBRECOM	2016-07-20 00:00:00	2016-07-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12534	2016-07-20 19:31:03	2016-10-07 09:17:16
14731	MEMBRECOM	2016-07-20 00:00:00	2016-07-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12535	2016-07-20 19:31:08	2016-10-07 09:17:16
14732	MEMBRECOM	2016-07-20 00:00:00	2016-07-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12536	2016-07-20 19:31:15	2016-10-07 09:17:16
14733	MEMBRECOM	2016-07-20 00:00:00	2016-07-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12537	2016-07-20 19:31:21	2016-10-07 09:17:16
14734	MEMBRECOM	2016-07-20 00:00:00	2016-07-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12538	2016-07-20 19:31:26	2016-10-07 09:17:16
14735	MEMBRECOM	2016-07-20 00:00:00	2016-07-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12539	2016-07-20 19:31:31	2016-10-07 09:17:16
14736	MEMBRECOM	2016-07-20 00:00:00	2016-07-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12540	2016-07-20 19:31:37	2016-10-07 09:17:16
14737	MEMBRECOM	2016-07-20 00:00:00	2016-07-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12541	2016-07-20 19:31:42	2016-10-07 09:17:16
14738	MEMBRECOM	2016-07-20 00:00:00	2016-07-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12542	2016-07-20 19:31:48	2016-10-07 09:17:16
14741	MEMBRECOM	2016-10-05 00:00:00	2016-11-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11551	2016-10-05 16:14:04	2016-11-09 17:04:59
14742	MEMBRECOM	2016-10-05 00:00:00	2016-11-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11552	2016-10-05 16:14:14	2016-11-09 17:05:12
14743	MEMBRECOM	2016-10-05 00:00:00	2016-11-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11553	2016-10-05 16:14:21	2016-11-09 17:05:06
14744	MEMBRECOM	2016-10-05 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12543	2016-10-05 16:14:59	\N
14755	MEMBRECOM	2016-07-13 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12554	2016-10-07 09:10:58	2017-06-12 11:07:15
14756	MEMBRECOM	2016-07-13 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12555	2016-10-07 09:11:08	2017-06-12 11:07:15
14757	MEMBRECOM	2016-07-13 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12556	2016-10-07 09:11:17	2017-06-12 11:07:15
14758	MEMBRECOM	2016-07-13 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12557	2016-10-07 09:11:23	2017-06-12 11:07:15
14759	MEMBRECOM	2016-07-13 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12558	2016-10-07 09:11:28	2017-06-12 11:07:15
14760	MEMBRECOM	2016-07-13 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12559	2016-10-07 09:11:34	2017-06-12 11:07:15
14761	MEMBRECOM	2016-07-13 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12560	2016-10-07 09:12:00	2017-06-12 11:07:15
14762	MEMBRECOM	2016-07-13 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12561	2016-10-07 09:12:09	2017-06-12 11:07:15
14753	PDTCOM	2016-07-13 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12552	2016-10-07 09:10:48	2017-06-12 11:07:15
14754	MEMBRECOM	2016-07-13 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12553	2016-10-07 09:10:53	2017-06-12 11:07:15
14763	PDTCOM	2016-07-13 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12562	2016-10-07 09:12:17	2017-06-12 11:07:15
14764	MEMBRECOM	2016-07-13 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12563	2016-10-07 09:12:22	2017-06-12 11:07:15
14765	MEMBRECOM	2016-07-13 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12564	2016-10-07 09:12:27	2017-06-12 11:07:15
14766	MEMBRECOM	2016-07-13 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12565	2016-10-07 09:12:32	2017-06-12 11:07:15
14767	MEMBRECOM	2016-07-13 00:00:00	2016-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12566	2016-10-07 09:12:37	2017-01-03 11:09:24
14768	MEMBRECOM	2016-07-13 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12567	2016-10-07 09:12:42	2017-06-12 11:07:15
14769	MEMBRECOM	2016-07-13 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12568	2016-10-07 09:12:47	2017-06-12 11:07:15
14770	MEMBRECOM	2016-07-13 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12569	2016-10-07 09:12:53	2017-06-12 11:07:15
14771	MEMBRECOM	2016-07-13 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12570	2016-10-07 09:12:58	2017-06-12 11:07:15
14594	MEMBRECOM	2016-06-22 00:00:00	2016-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12422	2016-06-22 16:44:20	2016-10-07 09:16:24
14596	MEMBRECOM	2016-06-22 00:00:00	2016-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12424	2016-06-22 16:44:33	2016-10-07 09:16:24
14581	MEMBRECOM	2016-06-22 00:00:00	2016-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12409	2016-06-22 16:42:56	2016-10-07 09:16:24
14600	MEMBRECOM	2016-06-22 00:00:00	2016-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12428	2016-06-22 16:44:55	2016-10-07 09:16:24
14583	MEMBRECOM	2016-06-22 00:00:00	2016-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12411	2016-06-22 16:43:05	2016-10-07 09:16:24
14773	PDTCOM	2016-10-18 00:00:00	2016-10-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12572	2016-10-19 10:53:41	2016-10-25 16:22:46
14774	RAPCOM	2016-10-18 00:00:00	2016-10-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12573	2016-10-19 10:53:47	2016-10-25 16:22:46
14775	MEMBRECOM	2016-10-18 00:00:00	2016-10-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12574	2016-10-19 10:53:52	2016-10-25 16:22:46
14776	RAPCOM	2016-10-18 00:00:00	2016-10-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12575	2016-10-19 10:53:57	2016-10-25 16:22:46
14777	MEMBRECOM	2016-10-18 00:00:00	2016-10-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12576	2016-10-19 10:54:02	2016-10-25 16:22:46
14778	MEMBRECOM	2016-10-18 00:00:00	2016-10-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12577	2016-10-19 10:54:08	2016-10-25 16:22:46
14779	MEMBRECOM	2016-10-18 00:00:00	2016-10-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12578	2016-10-19 10:54:13	2016-10-25 16:22:46
14780	MEMBRECOM	2016-10-18 00:00:00	2016-10-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12579	2016-10-19 10:54:19	2016-10-25 16:22:46
14781	MEMBRECOM	2016-10-18 00:00:00	2016-10-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12580	2016-10-19 10:54:23	2016-10-25 16:22:46
14782	MEMBRECOM	2016-10-18 00:00:00	2016-10-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12581	2016-10-19 10:54:28	2016-10-25 16:22:46
14783	MEMBRECOM	2016-10-18 00:00:00	2016-10-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12582	2016-10-19 10:54:33	2016-10-25 16:22:46
14784	MEMBRECOM	2016-10-18 00:00:00	2016-10-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12583	2016-10-19 10:54:39	2016-10-25 16:22:46
14785	MEMBRECOM	2016-10-18 00:00:00	2016-10-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12584	2016-10-19 10:54:43	2016-10-25 16:22:46
14786	MEMBRECOM	2016-10-18 00:00:00	2016-10-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12585	2016-10-19 10:54:48	2016-10-25 16:22:46
15018	PDTCOM	2016-11-29 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12634	2016-12-01 15:01:54	2017-06-12 11:06:53
15019	RAPCOM	2016-11-29 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12637	2016-12-01 15:02:07	2017-06-12 11:06:53
15020	VICPDTCOM	2016-11-29 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12635	2016-12-01 15:02:17	2017-06-12 11:06:53
15021	VICPDTCOM	2016-11-29 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12631	2016-12-01 15:02:22	2017-06-12 11:06:53
17300	SECRETCOM	2018-10-11 00:00:00	2019-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14531	\N	\N
15022	VICPDTCOM	2016-11-29 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12644	2016-12-01 15:02:27	2017-06-12 11:06:53
15023	VICPDTCOM	2016-11-29 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12633	2016-12-01 15:02:33	2017-06-12 11:06:53
15024	VICPDTCOM	2016-11-29 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12740	2016-12-01 15:02:39	2017-06-12 11:06:53
15025	VICPDTCOM	2016-11-29 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12741	2016-12-01 15:02:50	2017-06-12 11:06:53
15026	PDTCOM	2016-11-29 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12646	2016-12-01 15:04:16	2017-06-12 11:06:58
15027	RAPCOM	2016-11-29 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12658	2016-12-01 15:04:22	2017-06-12 11:06:58
15029	VICPDTCOM	2016-11-29 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12747	2016-12-01 15:04:49	2017-06-12 11:06:58
15030	VICPDTCOM	2016-11-29 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12645	2016-12-01 15:06:36	2017-06-12 11:06:58
15031	VICPDTCOM	2016-11-29 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12654	2016-12-01 15:06:46	2017-06-12 11:06:58
15032	VICPDTCOM	2016-11-29 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12655	2016-12-01 15:06:52	2017-06-12 11:06:58
15033	VICPDTCOM	2016-11-29 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12762	2016-12-01 15:06:55	2017-06-12 11:06:58
15034	PDTCOM	2016-12-01 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12714	2016-12-01 15:07:39	2017-06-12 11:07:11
15035	RAPCOM	2016-12-01 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12706	2016-12-01 15:07:48	2017-06-12 11:07:11
15036	VICPDTCOM	2016-12-01 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12718	2016-12-01 15:07:54	2017-06-12 11:07:11
14678	MEMBRECOM	2016-07-07 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12482	2016-07-07 17:25:39	2017-06-12 11:07:18
14679	MEMBRECOM	2016-07-07 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12483	2016-07-07 17:25:44	2017-06-12 11:07:18
14680	MEMBRECOM	2016-07-07 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12484	2016-07-07 17:25:49	2017-06-12 11:07:18
14681	MEMBRECOM	2016-07-07 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12485	2016-07-07 17:25:54	2017-06-12 11:07:18
14682	MEMBRECOM	2016-07-07 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12486	2016-07-07 17:25:58	2017-06-12 11:07:18
14683	MEMBRECOM	2016-07-07 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12487	2016-07-07 17:26:03	2017-06-12 11:07:18
14684	MEMBRECOM	2016-07-07 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12488	2016-07-07 17:26:07	2017-06-12 11:07:18
14685	MEMBRECOM	2016-07-07 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12489	2016-07-07 17:26:15	2017-06-12 11:07:18
14686	MEMBRECOM	2016-07-07 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12490	2016-07-07 17:26:21	2017-06-12 11:07:18
14687	MEMBRECOM	2016-07-07 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12491	2016-07-07 17:26:30	2017-06-12 11:07:18
14995	RAPCOM	2016-11-29 00:00:00	2016-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12791	2016-11-30 12:10:54	2016-12-15 10:00:00
14689	MEMBRECOM	2016-07-07 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12493	2016-07-07 17:27:33	2017-06-12 11:07:18
14690	MEMBRECOM	2016-07-07 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12494	2016-07-07 17:27:38	2017-06-12 11:07:18
14691	MEMBRECOM	2016-07-07 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12495	2016-07-07 17:27:46	2017-06-12 11:07:18
14692	MEMBRECOM	2016-07-07 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12496	2016-07-07 17:28:04	2017-06-12 11:07:18
14693	MEMBRECOM	2016-07-07 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12497	2016-07-07 17:28:11	2017-06-12 11:07:18
14694	MEMBRECOM	2016-07-07 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12498	2016-07-07 17:28:15	2017-06-12 11:07:18
14695	MEMBRECOM	2016-07-07 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12499	2016-07-07 17:30:38	2017-06-12 11:07:18
14584	MEMBRECOM	2016-06-22 00:00:00	2016-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12412	2016-06-22 16:43:11	2016-10-07 09:16:24
14993	MEMBRECOM	2016-11-30 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12789	2016-11-30 00:00:00	\N
14994	VICPDTCOM	2016-11-29 00:00:00	2016-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12790	2016-11-30 12:10:47	2016-12-15 10:00:00
14996	MEMBRECOM	2016-11-29 00:00:00	2016-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12792	2016-11-30 12:11:00	2016-12-15 10:00:00
14997	MEMBRECOM	2016-11-29 00:00:00	2016-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12793	2016-11-30 12:11:05	2016-12-15 10:00:00
14998	MEMBRECOM	2016-11-29 00:00:00	2016-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12794	2016-11-30 12:11:11	2016-12-15 10:00:00
14999	MEMBRECOM	2016-11-29 00:00:00	2016-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12795	2016-11-30 12:11:19	2016-12-15 10:00:00
15000	MEMBRECOM	2016-11-29 00:00:00	2016-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12796	2016-11-30 12:11:25	2016-12-15 10:00:00
15001	MEMBRECOM	2016-11-29 00:00:00	2016-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12797	2016-11-30 12:11:30	2016-12-15 10:00:00
15002	MEMBRECOM	2016-11-29 00:00:00	2016-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12798	2016-11-30 12:11:38	2016-12-15 10:00:00
15003	MEMBRECOM	2016-11-29 00:00:00	2016-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12799	2016-11-30 12:11:47	2016-12-15 10:00:00
15004	MEMBRECOM	2016-11-29 00:00:00	2016-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12800	2016-11-30 12:11:56	2016-12-15 10:00:00
15005	MEMBRECOM	2016-11-29 00:00:00	2016-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12801	2016-11-30 12:12:10	2016-12-15 10:00:00
15006	MEMBRECOM	2016-11-29 00:00:00	2016-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12802	2016-11-30 12:12:20	2016-12-15 10:00:00
15007	MEMBRECOM	2016-11-29 00:00:00	2016-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12803	2016-11-30 12:12:29	2016-12-15 10:00:00
15015	MEMBRECOM	2016-11-23 00:00:00	2016-12-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12811	2016-12-01 10:41:05	2016-12-01 15:39:21
15037	VICPDTCOM	2016-12-01 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12805	2016-12-01 15:07:59	2017-06-12 11:07:11
15038	VICPDTCOM	2016-12-01 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12701	2016-12-01 15:08:05	2017-06-12 11:07:11
15039	VICPDTCOM	2016-12-01 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12758	2016-12-01 15:08:12	2017-06-12 11:07:11
15040	VICPDTCOM	2016-12-01 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12711	2016-12-01 15:08:20	2017-06-12 11:07:11
15041	VICPDTCOM	2016-12-01 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12705	2016-12-01 15:08:26	2017-06-12 11:07:11
15042	MEMBRECOM	2016-12-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12814	2016-12-06 00:00:00	\N
15045	VICPDTCOM	2016-12-15 00:00:00	2016-12-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12817	2016-12-16 10:37:46	2016-12-21 14:17:28
17301	SECRETCOM	2018-10-11 00:00:00	2019-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14460	\N	\N
15046	RAPCOM	2016-12-15 00:00:00	2016-12-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12818	2016-12-16 10:37:52	2016-12-21 14:17:28
15047	MEMBRECOM	2016-12-15 00:00:00	2016-12-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12819	2016-12-16 10:37:57	2016-12-21 14:17:28
15048	MEMBRECOM	2016-12-15 00:00:00	2016-12-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12820	2016-12-16 10:38:01	2016-12-21 14:17:28
15049	MEMBRECOM	2016-12-15 00:00:00	2016-12-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12821	2016-12-16 10:38:05	2016-12-21 14:17:28
15050	MEMBRECOM	2016-12-15 00:00:00	2016-12-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12822	2016-12-16 10:38:12	2016-12-21 14:17:28
15051	MEMBRECOM	2016-12-15 00:00:00	2016-12-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12823	2016-12-16 10:38:18	2016-12-21 14:17:28
15052	MEMBRECOM	2016-12-15 00:00:00	2016-12-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12824	2016-12-16 10:38:24	2016-12-21 14:17:28
15053	MEMBRECOM	2016-12-15 00:00:00	2016-12-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12825	2016-12-16 10:38:29	2016-12-21 14:17:28
15054	MEMBRECOM	2016-12-15 00:00:00	2016-12-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12826	2016-12-16 10:38:38	2016-12-21 14:17:28
15055	MEMBRECOM	2016-12-15 00:00:00	2016-12-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12827	2016-12-16 10:38:49	2016-12-21 14:17:28
15056	MEMBRECOM	2016-12-15 00:00:00	2016-12-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12828	2016-12-16 10:39:03	2016-12-21 14:17:28
15057	MEMBRECOM	2016-12-15 00:00:00	2016-12-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12829	2016-12-16 10:39:10	2016-12-21 14:17:28
15058	MEMBRECOM	2016-12-15 00:00:00	2016-12-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12830	2016-12-16 10:39:21	2016-12-21 14:17:28
15059	VICPDTCOM	2016-12-13 00:00:00	2016-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12831	2016-12-16 10:41:45	2016-12-21 14:18:00
15060	RAPCOM	2016-12-13 00:00:00	2016-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12832	2016-12-16 10:41:50	2016-12-21 14:18:00
15061	MEMBRECOM	2016-12-13 00:00:00	2016-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12833	2016-12-16 10:41:57	2016-12-21 14:18:00
15062	MEMBRECOM	2016-12-13 00:00:00	2016-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12834	2016-12-16 10:42:02	2016-12-21 14:18:00
15063	MEMBRECOM	2016-12-13 00:00:00	2016-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12835	2016-12-16 10:42:06	2016-12-21 14:18:00
15064	MEMBRECOM	2016-12-13 00:00:00	2016-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12836	2016-12-16 10:42:11	2016-12-21 14:18:00
15065	MEMBRECOM	2016-12-13 00:00:00	2016-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12837	2016-12-16 10:42:14	2016-12-21 14:18:00
15066	MEMBRECOM	2016-12-13 00:00:00	2016-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12838	2016-12-16 10:42:19	2016-12-21 14:18:00
15067	MEMBRECOM	2016-12-13 00:00:00	2016-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12839	2016-12-16 10:42:27	2016-12-21 14:18:00
15068	MEMBRECOM	2016-12-13 00:00:00	2016-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12840	2016-12-16 10:42:35	2016-12-21 14:18:00
15069	MEMBRECOM	2016-12-13 00:00:00	2016-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12841	2016-12-16 10:42:43	2016-12-21 14:18:00
15070	MEMBRECOM	2016-12-13 00:00:00	2016-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12842	2016-12-16 10:42:53	2016-12-21 14:18:00
15071	MEMBRECOM	2016-12-13 00:00:00	2016-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12843	2016-12-16 10:43:03	2016-12-21 14:18:00
15072	MEMBRECOM	2016-12-13 00:00:00	2016-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12844	2016-12-16 10:43:07	2016-12-21 14:18:00
15088	MEMBRECOM	2017-01-10 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12860	2017-01-10 18:00:19	2017-09-24 19:25:10
15089	MEMBRECOM	2017-01-10 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12861	2017-01-10 18:00:51	2017-10-05 14:46:00
15134	MEMBRECOM	2017-01-12 00:00:00	2017-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12906	2017-01-13 11:18:49	2017-01-18 10:55:04
15135	MEMBRECOM	2017-01-12 00:00:00	2017-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12907	2017-01-13 11:18:53	2017-01-18 10:55:04
15136	MEMBRECOM	2017-01-12 00:00:00	2017-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12908	2017-01-13 11:18:57	2017-01-18 10:55:04
15152	MEMBRECOM	2017-01-24 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12923	2017-01-24 18:11:26	2017-09-24 18:23:22
15044	MEMBRECOM	2016-12-11 00:00:00	2017-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12816	2016-12-12 15:59:30	2017-01-24 18:11:28
13500	MEMBRECOM	2015-05-04 00:00:00	2017-06-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11388	2015-05-04 11:14:58	2017-06-07 09:38:00
15182	MEMBRECOM	2017-01-18 00:00:00	2017-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12953	2017-02-06 16:37:27	2017-06-12 11:07:15
15253	PDTCOM	2016-07-13 00:00:00	2016-09-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13024	\N	\N
15254	RAPCOM	2016-07-13 00:00:00	2016-09-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13025	\N	\N
15256	MEMBRECOM	2017-06-05 00:00:00	2017-06-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13027	2017-06-07 15:17:54	2017-06-19 16:13:09
12088	MEMBRECOM	2014-10-08 00:00:00	2017-07-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	723	2014-10-08 17:51:33	2017-07-04 15:08:09
15283	MEMBRECOM	2017-07-26 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13046	2017-07-26 15:50:27	2017-10-04 19:01:46
15336	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13094	2017-09-24 17:04:01	2017-10-04 18:57:19
12544	MEMBRECOM	2014-05-26 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10492	\N	2017-09-24 17:04:02
15340	MEMBRECOM	2017-10-02 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13098	2017-09-24 17:09:23	2017-10-05 14:54:13
15341	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13099	2017-09-24 17:09:23	2017-10-04 18:53:33
15342	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13100	2017-09-24 17:09:23	2017-10-04 18:46:18
4006	MEMBRECOM	2005-12-15 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3086	\N	2017-09-24 17:09:24
4756	MEMBRECOM	2007-12-14 00:00:00	2007-12-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3841	\N	2017-09-24 17:09:24
4239	MEMBRECOM	2006-06-08 00:00:00	2006-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3320	\N	2017-09-24 17:09:24
10490	PDTCOM	2012-03-28 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8803	\N	2017-09-24 17:09:24
4175	MEMBRECOM	2006-03-07 00:00:00	2006-03-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3256	\N	2017-09-24 17:09:24
10613	VICPDTCOM	2012-09-27 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8916	\N	2017-09-24 17:09:24
10159	VICPDTCOM	2012-01-26 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8517	\N	2017-09-24 17:09:24
12405	PDTCOM	2014-01-29 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10353	\N	2017-09-24 17:09:24
15343	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13101	2017-09-24 17:14:26	2017-10-04 18:54:36
15344	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13102	2017-09-24 17:14:26	2017-10-04 19:10:56
10659	MEMBRECOM	2012-10-23 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8947	\N	2017-09-24 17:14:26
10704	MEMBRECOM	2012-11-28 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8991	\N	2017-09-24 17:14:26
11194	RAPCOM	2013-06-05 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9438	\N	2017-09-24 17:14:26
8874	MEMBRECOM	2010-07-06 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7374	\N	2017-09-24 17:14:26
14228	MEMBRECOM	2016-04-01 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12081	2016-04-04 15:22:52	2017-09-24 17:14:26
12502	RAPCOM	2014-05-20 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10450	\N	2017-09-24 17:14:26
15349	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13107	2017-09-24 17:18:02	2017-10-04 19:00:50
15350	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13108	2017-09-24 17:18:02	2017-10-04 19:10:04
12330	VICPDTCOM	2014-10-13 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6420	2014-10-13 11:50:49	2017-09-24 17:18:03
15353	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13111	2017-09-24 17:28:55	2017-10-04 18:56:09
9044	MEMBRECOM	2010-12-16 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7544	\N	2017-09-24 17:28:55
9035	MEMBRECOM	2010-12-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7535	\N	2017-09-24 17:28:55
15360	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13118	2017-09-24 17:42:25	2017-10-04 19:01:04
15361	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13119	2017-09-24 17:42:25	2017-10-04 18:55:38
15362	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13120	2017-09-24 17:42:25	2017-10-04 18:54:27
15363	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13121	2017-09-24 17:42:25	2017-10-04 18:54:18
12547	MEMBRECOM	2014-05-26 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10495	\N	2017-09-24 17:42:25
13808	MEMBRECOM	2015-10-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11664	\N	2017-09-24 17:42:25
13769	MEMBRECOM	2015-07-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11625	\N	2017-09-24 17:42:25
10692	MEMBRECOM	2012-11-20 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8979	\N	2017-09-24 17:42:25
13911	MEMBRECOM	2015-11-12 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11767	\N	2017-09-24 17:42:25
12528	MEMBRECOM	2014-05-28 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10476	\N	2017-09-24 17:42:25
11167	VICPDTCOM	2013-04-17 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9411	\N	2017-09-24 17:42:25
12563	MEMBRECOM	2014-06-11 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10511	\N	2017-09-24 17:42:25
14092	MEMBRECOM	2016-02-10 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11945	2016-02-23 15:22:04	2017-09-24 17:42:26
15364	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13122	2017-09-24 17:47:26	2017-10-04 19:10:08
15367	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13124	2017-09-24 17:47:26	2017-10-04 18:39:55
15368	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13125	2017-09-24 17:47:26	2017-10-04 18:57:07
10657	MEMBRECOM	2012-10-23 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8945	\N	2017-09-24 17:47:27
12074	MEMBRECOM	2014-10-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2575	2014-10-08 17:49:16	2017-09-24 17:47:27
8791	MEMBRECOM	2010-05-20 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7297	\N	2017-09-24 17:47:27
13715	MEMBRECOM	2015-06-17 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11571	\N	2017-09-24 17:47:27
10604	MEMBRECOM	2012-09-26 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8907	\N	2017-09-24 17:47:27
11744	MEMBRECOM	2014-05-05 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9926	2014-05-05 14:50:48	2017-09-24 17:47:27
9296	MEMBRECOM	2011-06-14 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7793	\N	2017-09-24 17:47:27
12447	MEMBRECOM	2014-02-17 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10395	\N	2017-09-24 17:47:27
10431	MEMBRECOM	2012-02-15 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8784	\N	2017-09-24 17:47:27
11451	MEMBRECOM	2013-11-05 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9676	\N	2017-09-24 17:47:27
10565	MEMBRECOM	2012-07-26 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8867	\N	2017-09-24 17:47:28
8433	MEMBRECOM	2009-10-07 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6992	\N	2017-09-24 17:47:28
10030	MEMBRECOM	2011-12-19 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8384	\N	2017-09-24 17:47:28
10819	MEMBRECOM	2012-12-15 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9106	\N	2017-09-24 17:47:28
11977	MEMBRECOM	2014-10-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10145	2014-10-08 17:05:13	2017-09-24 17:47:28
8793	MEMBRECOM	2010-05-20 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7299	\N	2017-09-24 17:47:28
10140	MEMBRECOM	2012-01-25 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8498	\N	2017-09-24 17:47:28
15372	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13129	2017-09-24 17:55:12	2017-10-04 18:45:46
15373	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13130	2017-09-24 17:55:12	2017-10-04 18:43:50
15374	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13131	2017-09-24 17:55:12	2017-10-04 18:45:52
13723	MEMBRECOM	2015-07-25 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11579	\N	2017-09-24 17:55:12
13002	MEMBRECOM	2015-01-30 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10919	2015-01-30 14:39:26	2017-09-24 17:55:12
15375	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13132	2017-09-24 18:05:40	2017-10-04 18:56:08
15376	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13133	2017-09-24 18:05:40	2017-10-04 18:56:13
15377	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13134	2017-09-24 18:05:40	2017-10-04 18:43:08
15378	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13135	2017-09-24 18:05:40	2017-10-04 18:40:53
13763	MEMBRECOM	2015-07-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11619	\N	2017-09-24 18:05:40
13734	MEMBRECOM	2015-07-09 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11590	\N	2017-09-24 18:05:41
4293	MEMBRECOM	2006-11-23 00:00:00	2006-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3374	\N	2017-09-24 18:05:41
14076	MEMBRECOM	2016-02-10 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11929	2016-02-23 15:18:06	2017-09-24 18:05:41
15381	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13138	2017-09-24 18:16:33	2017-10-04 18:42:53
9502	MEMBRECOM	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7990	\N	2017-09-24 13:14:55
12506	MEMBRECOM	2014-05-20 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10454	\N	2017-09-24 13:14:55
11970	MEMBRECOM	2014-10-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10138	2014-10-08 17:02:49	2017-09-24 13:14:55
11199	MEMBRECOM	2013-06-05 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9443	\N	2017-09-24 13:25:54
12679	MEMBRECOM	2014-07-18 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10627	\N	2017-09-24 13:25:54
11004	MEMBRECOM	2013-04-10 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9291	\N	2017-09-24 13:25:54
10710	MEMBRECOM	2012-11-28 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8997	\N	2017-09-24 13:25:54
11172	MEMBRECOM	2013-04-17 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9416	\N	2017-09-24 13:44:49
4312	MEMBRECOM	2006-11-17 00:00:00	2006-11-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3393	\N	2017-09-24 13:44:49
13811	MEMBRECOM	2015-10-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11667	\N	2017-09-24 13:44:49
11504	MEMBRECOM	2013-11-18 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9728	\N	2017-09-24 13:44:49
13907	MEMBRECOM	2015-11-12 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11763	\N	2017-09-24 13:44:49
4660	MEMBRECOM	2007-07-31 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3744	\N	2017-09-24 13:44:49
9197	MEMBRECOM	2011-01-25 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7698	\N	2017-09-24 13:44:49
9476	MEMBRECOM	2011-07-06 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7964	\N	2017-09-24 13:44:49
10331	MEMBRECOM	2012-02-21 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8684	\N	2017-09-24 13:44:49
10664	MEMBRECOM	2012-10-23 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8952	\N	2017-09-24 13:57:40
9586	MEMBRECOM	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8076	\N	2017-09-24 18:16:33
15395	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13151	2017-09-24 18:20:09	2017-10-04 18:55:13
15396	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13152	2017-09-24 18:20:09	2017-10-04 18:53:56
12410	MEMBRECOM	2014-01-29 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10358	\N	2017-09-24 18:20:10
12760	VICPDTCOM	2014-11-20 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10708	\N	2017-09-24 18:20:10
9022	MEMBRECOM	2010-12-07 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7522	\N	2017-09-24 18:20:10
13004	PDTCOM	2015-01-30 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10879	2015-01-30 14:46:30	2017-09-24 18:20:10
11512	MEMBRECOM	2013-11-29 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9736	\N	2017-09-24 18:20:10
10746	MEMBRECOM	2012-11-29 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9033	\N	2017-09-24 18:20:10
9036	MEMBRECOM	2010-12-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7536	\N	2017-09-24 18:20:10
12746	VICPDTCOM	2014-11-20 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10694	\N	2017-09-24 18:20:10
10132	MEMBRECOM	2012-01-25 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8490	\N	2017-09-24 18:20:10
15402	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13158	2017-09-24 18:44:44	2017-10-04 18:54:10
15404	MEMBRECOM	2017-09-25 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13160	2017-09-24 18:51:50	2017-10-04 18:54:05
15410	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13166	2017-09-24 19:16:18	2017-10-04 19:08:06
9540	MEMBRECOM	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8030	\N	2017-09-24 19:16:18
15412	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13168	2017-09-24 19:19:07	2017-10-04 19:05:32
15413	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13169	2017-09-24 19:19:07	2017-10-04 18:54:25
15414	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13170	2017-09-24 19:25:09	2017-10-04 18:56:58
15415	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13171	2017-09-24 19:25:09	2017-10-04 18:44:55
15416	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13172	2017-09-24 19:25:09	2017-10-04 19:04:26
15417	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13173	2017-09-24 19:25:09	2017-10-04 18:46:03
3829	MEMBRECOM	2005-07-05 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2918	\N	2017-09-24 19:25:10
12442	MEMBRECOM	2014-02-17 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10390	\N	2017-09-24 19:25:10
7905	RAPCOM	2008-10-29 00:00:00	2008-11-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6475	\N	2017-09-24 19:25:10
12080	MEMBRECOM	2014-10-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2614	2014-10-08 17:50:51	2017-09-24 19:25:10
11174	MEMBRECOM	2013-04-17 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9418	\N	2017-09-24 19:25:10
3778	MEMBRECOM	2005-05-04 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2867	\N	2017-09-24 19:25:10
4813	MEMBRECOM	2008-01-24 00:00:00	2008-01-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3898	\N	2017-09-24 19:25:10
5003	MEMBRECOM	2008-07-17 00:00:00	2008-07-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4088	\N	2017-09-24 19:25:10
11216	MEMBRECOM	2013-06-21 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9460	\N	2017-09-24 19:25:10
10958	MEMBRECOM	2013-04-02 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9245	\N	2017-09-24 19:25:10
12573	MEMBRECOM	2014-07-02 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10521	\N	2017-09-24 19:25:10
10327	MEMBRECOM	2012-02-20 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8680	\N	2017-09-24 19:25:10
13709	MEMBRECOM	2015-06-17 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11565	\N	2017-09-24 19:25:10
15420	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13176	2017-09-24 19:31:54	2017-10-04 18:43:54
15421	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13177	2017-09-24 19:31:54	2017-10-04 18:57:28
13941	MEMBRECOM	2015-11-24 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11797	\N	2017-09-24 19:31:54
12534	RAPCOM	2014-05-28 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10482	\N	2017-09-24 19:31:54
12395	RAPCOM	2014-02-03 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10343	\N	2017-09-24 19:31:54
12263	VICPDTCOM	2014-10-09 00:00:00	2017-09-30 00:00:00	3	ANCIEN	\N	\N	\N	\N	409	2014-10-09 13:56:56	2017-10-01 09:22:38
15429	MEMBRECOM	2017-10-01 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13184	2017-10-01 09:26:48	2017-10-04 19:10:14
16075	MEMBRECOM	2017-10-04 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13536	2017-10-04 20:31:04	\N
16086	VICPDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	3	ANCIEN	\N	\N	\N	\N	755	2017-10-05 14:25:51	2017-10-05 14:26:10
16084	VICPDTCOM	2017-10-05 00:00:00	2019-03-03 00:00:00	1	ANCIEN	\N	\N	\N	\N	3892	2017-10-05 14:24:48	2017-10-05 14:25:23
16087	VICPDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	2	ANCIEN	\N	\N	\N	\N	2607	2017-10-05 14:26:20	2017-10-05 14:26:25
16088	VICPDTCOM	2017-10-05 00:00:00	2020-09-30 00:00:00	5	ANCIEN	\N	\N	\N	\N	10129	2017-10-05 14:26:35	2017-10-05 14:26:41
16090	VICPDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	4	ANCIEN	\N	\N	\N	\N	10166	2017-10-05 14:26:50	2017-10-05 14:26:56
16092	VICPDTCOM	2017-10-05 00:00:00	2020-08-02 00:00:00	7	ANCIEN	\N	\N	\N	\N	7432	2017-10-05 14:27:13	2017-10-05 14:27:19
16094	VICPDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	8	ANCIEN	\N	\N	\N	\N	13400	2017-10-05 14:27:33	2017-10-05 14:27:39
16095	VICPDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	9	ANCIEN	\N	\N	\N	\N	13405	2017-10-05 14:27:53	2017-10-05 14:27:58
16096	VICPDTCOM	2017-10-05 00:00:00	2020-09-30 00:00:00	10	ANCIEN	\N	\N	\N	\N	2441	2017-10-05 14:28:11	2017-10-05 14:28:16
16098	VICPDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	11	ANCIEN	\N	\N	\N	\N	10168	2017-10-05 14:28:24	2017-10-05 14:28:30
12000	MEMBRECOM	2014-10-08 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10168	2014-10-08 17:19:13	2017-10-05 14:28:25
16103	SECRETCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	2	ANCIEN	\N	\N	\N	\N	13424	2017-10-05 14:29:16	2017-10-05 14:29:36
16107	SECRETCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	3	ANCIEN	\N	\N	\N	\N	13427	2017-10-05 14:29:50	2017-10-05 14:29:56
8379	MEMBRECOM	2009-09-29 00:00:00	2017-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6934	\N	2017-07-24 09:56:26
10964	MEMBRECOM	2013-04-02 00:00:00	2017-07-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9251	\N	2017-07-24 09:56:26
15282	MEMBRECOM	2017-07-22 00:00:00	2017-07-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13045	2017-07-24 10:01:14	2017-07-26 15:50:28
13904	MEMBRECOM	2015-11-12 00:00:00	2017-08-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11760	\N	2017-08-07 16:31:39
13652	MEMBRECOM	2015-06-25 00:00:00	2017-08-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11516	\N	2017-08-07 16:31:39
15321	MEMBRECOM	2017-08-07 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13080	2017-08-07 17:15:07	2017-09-24 17:18:03
15322	MEMBRECOM	2017-09-22 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13081	2017-09-22 10:59:04	2017-10-04 18:55:06
15333	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13091	2017-09-24 16:43:41	2017-10-04 18:55:38
9292	MEMBRECOM	2011-06-14 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7789	\N	2017-09-24 16:43:43
3249	MEMBRECOM	2004-07-09 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2396	\N	2017-09-24 16:43:43
4296	MEMBRECOM	2006-11-23 00:00:00	2006-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3377	\N	2017-09-24 16:43:43
9950	MEMBRECOM	2011-11-14 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8324	\N	2017-09-24 16:43:43
9194	MEMBRECOM	2011-01-25 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7695	\N	2017-09-24 16:43:43
15334	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13092	2017-09-24 16:45:25	2017-10-04 19:06:20
15335	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13093	2017-09-24 16:45:25	2017-10-04 18:40:00
10424	MEMBRECOM	2012-02-15 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8777	\N	2017-09-24 16:45:26
13931	RAPCOM	2015-11-24 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11787	\N	2017-09-24 16:45:26
15337	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13095	2017-09-24 17:06:55	2017-10-04 18:55:46
15338	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13096	2017-09-24 17:06:55	2017-10-04 19:04:56
15339	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13097	2017-09-24 17:06:55	2017-10-04 19:02:31
12490	MEMBRECOM	2014-05-12 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10438	\N	2017-09-24 17:06:55
10480	MEMBRECOM	2012-02-22 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8793	\N	2017-09-24 17:06:55
10762	MEMBRECOM	2012-12-13 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9049	\N	2017-09-24 17:06:55
13684	MEMBRECOM	2015-12-16 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11548	2015-12-16 17:19:49	2017-09-24 17:06:55
11240	MEMBRECOM	2013-07-12 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9484	\N	2017-09-24 17:06:55
10749	MEMBRECOM	2012-11-29 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9036	\N	2017-09-24 17:06:55
14124	MEMBRECOM	2016-01-19 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11977	2016-02-23 15:39:18	2017-09-24 17:06:55
13815	MEMBRECOM	2015-10-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11671	\N	2017-09-24 17:06:55
13848	MEMBRECOM	2015-11-05 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11704	\N	2017-09-24 17:06:55
15346	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13104	2017-09-24 17:15:14	2017-10-04 18:56:23
15347	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13105	2017-09-24 17:15:14	2017-10-04 18:45:15
15348	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13106	2017-09-24 17:15:14	2017-10-04 19:10:26
12252	SECRETCOM	2014-10-09 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8095	2014-10-09 13:52:12	2017-09-24 17:15:15
8365	MEMBRECOM	2009-09-29 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6920	\N	2017-09-24 17:15:15
4485	MEMBRECOM	2007-02-07 00:00:00	2007-02-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3567	\N	2017-09-24 17:15:15
4040	MEMBRECOM	2005-12-15 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3120	\N	2017-09-24 17:15:15
4252	MEMBRECOM	2006-06-16 00:00:00	2006-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3333	\N	2017-09-24 17:15:15
10414	MEMBRECOM	2012-02-15 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8767	\N	2017-09-24 17:15:15
8862	MEMBRECOM	2010-07-06 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7362	\N	2017-09-24 17:15:15
11518	MEMBRECOM	2013-11-29 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9742	\N	2017-09-24 17:15:15
10821	MEMBRECOM	2012-12-15 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9108	\N	2017-09-24 17:15:15
9891	MEMBRECOM	2011-10-20 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8268	\N	2017-09-24 17:15:15
12493	MEMBRECOM	2014-05-12 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10441	\N	2017-09-24 17:15:15
11241	MEMBRECOM	2013-07-12 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9485	\N	2017-09-24 17:15:15
10027	MEMBRECOM	2011-12-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8381	\N	2017-09-24 17:15:15
10033	MEMBRECOM	2011-12-19 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8387	\N	2017-09-24 17:15:15
13957	MEMBRECOM	2015-11-19 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11813	\N	2017-09-24 17:15:15
12169	VICPDTCOM	2014-10-09 00:00:00	2017-10-01 00:00:00	10	ANCIEN	\N	\N	\N	\N	8093	2014-10-09 10:45:56	2017-09-24 17:15:15
10489	MEMBRECOM	2012-02-22 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8802	\N	2017-09-24 17:15:15
15351	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13109	2017-09-24 17:19:41	2017-10-04 18:55:47
15352	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13110	2017-09-24 17:19:41	2017-10-04 18:56:31
4005	MEMBRECOM	2005-12-15 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3085	\N	2017-09-24 17:19:42
11203	MEMBRECOM	2013-06-05 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9447	\N	2017-09-24 17:19:42
9061	MEMBRECOM	2010-12-17 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7561	\N	2017-09-24 17:19:42
13849	MEMBRECOM	2015-11-05 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11705	\N	2017-09-24 17:19:42
9307	MEMBRECOM	2011-06-14 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7804	\N	2017-09-24 17:19:42
8317	MEMBRECOM	2009-07-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6875	\N	2017-09-24 17:19:42
15354	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13112	2017-09-24 17:29:36	2017-10-04 18:46:10
15355	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13113	2017-09-24 17:29:36	2017-10-04 18:56:02
15356	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13114	2017-09-24 17:29:36	2017-10-04 18:51:02
15357	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13115	2017-09-24 17:35:13	2017-10-04 18:45:29
15358	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13116	2017-09-24 17:35:13	2017-10-04 18:59:46
15359	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13117	2017-09-24 17:35:13	2017-10-04 18:55:19
12056	MEMBRECOM	2014-10-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	669	2014-10-08 17:46:28	2017-09-24 17:35:15
3653	RAPCOM	2004-10-20 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2741	\N	2017-09-24 17:35:15
8378	MEMBRECOM	2009-09-29 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6933	\N	2017-09-24 17:35:15
11399	MEMBRECOM	2013-10-03 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9635	\N	2017-09-24 17:35:15
13739	MEMBRECOM	2015-07-09 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11595	\N	2017-09-24 17:35:15
10983	PDTCOM	2013-04-04 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9270	\N	2017-09-24 17:35:15
4659	MEMBRECOM	2007-07-31 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3743	\N	2017-09-24 17:35:15
10599	VICPDTCOM	2012-09-26 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8902	\N	2017-09-24 17:35:15
12706	MEMBRECOM	2014-10-14 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10654	\N	2017-09-24 17:35:15
9491	MEMBRECOM	2011-07-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7979	\N	2017-09-24 17:35:15
8955	MEMBRECOM	2010-10-22 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7455	\N	2017-09-24 17:35:15
11444	VICPDTCOM	2013-11-05 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9669	\N	2017-09-24 17:35:15
15276	MEMBRECOM	2017-07-12 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2966	2017-07-12 14:22:32	2017-10-04 19:11:48
12256	PDTCOM	2014-10-09 00:00:00	2017-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2966	2014-10-09 13:55:17	2017-07-12 14:22:32
15277	PDTCOM	2017-07-12 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3944	2017-07-12 14:22:38	2017-10-04 18:49:03
15278	VICPDTCOM	2017-07-12 00:00:00	2017-10-04 00:00:00	1	ANCIEN	\N	\N	\N	\N	10202	2017-07-12 14:23:08	2017-10-04 18:49:06
15281	MEMBRECOM	2017-07-11 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13044	2017-07-12 17:43:49	\N
15316	MEMBRECOM	2017-08-01 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13079	2017-08-01 16:20:18	\N
15315	MEMBRECOM	2017-08-01 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13078	2017-08-01 14:55:02	2017-09-24 17:55:12
11755	MEMBRECOM	2014-05-07 00:00:00	2017-07-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9937	2014-05-09 17:32:03	2017-08-03 11:38:41
15324	MEMBRECOM	2017-09-23 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13083	2017-09-24 11:11:57	2017-10-04 19:02:49
15327	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13086	2017-09-24 12:57:08	2017-10-04 19:03:39
13866	MEMBRECOM	2015-10-15 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11722	\N	2017-09-24 12:57:09
13912	MEMBRECOM	2015-11-12 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11768	\N	2017-09-24 12:57:09
10611	MEMBRECOM	2012-09-26 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8914	\N	2017-09-24 12:57:09
13762	MEMBRECOM	2015-07-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11618	\N	2017-09-24 12:57:09
15328	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	817	2017-09-24 13:20:36	2017-10-04 18:55:25
10793	MEMBRECOM	2012-12-13 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9080	\N	2017-09-24 13:29:42
9365	MEMBRECOM	2011-06-28 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7862	\N	2017-09-24 13:29:42
9915	MEMBRECOM	2011-11-02 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8289	\N	2017-09-24 13:29:42
11327	MEMBRECOM	2013-10-03 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9563	\N	2017-09-24 13:29:42
10099	MEMBRECOM	2012-01-12 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8453	\N	2017-09-24 13:29:42
10204	MEMBRECOM	2012-02-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8557	\N	2017-09-24 13:29:42
10085	MEMBRECOM	2012-12-21 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8439	\N	2017-09-24 13:29:42
14090	MEMBRECOM	2016-02-10 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11943	2016-02-23 15:21:54	2017-09-24 13:29:42
8767	MEMBRECOM	2010-04-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7283	\N	2017-09-24 13:29:42
9412	MEMBRECOM	2011-06-29 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7900	\N	2017-09-24 13:29:42
11312	MEMBRECOM	2013-10-03 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9548	\N	2017-09-24 13:29:42
4474	MEMBRECOM	2007-02-07 00:00:00	2007-02-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3556	\N	2017-09-24 13:29:42
10087	RAPCOM	2012-01-12 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8441	\N	2017-09-24 13:42:35
9920	MEMBRECOM	2011-11-02 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8294	\N	2017-09-24 13:42:35
11517	MEMBRECOM	2013-11-29 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9741	\N	2017-09-24 13:47:46
12501	MEMBRECOM	2014-05-12 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10449	\N	2017-09-24 13:47:46
3747	MEMBRECOM	2005-03-19 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2836	\N	2017-09-24 17:35:15
9937	PDTCOM	2011-11-07 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8311	\N	2017-09-24 17:35:15
12554	PDTCOM	2014-06-11 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10502	\N	2017-09-24 17:35:15
12394	VICPDTCOM	2014-02-03 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10342	\N	2017-09-24 17:35:15
15370	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13127	2017-09-24 17:48:20	2017-10-04 18:59:31
15371	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13128	2017-09-24 17:48:20	2017-10-04 18:55:32
10370	MEMBRECOM	2012-02-21 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8722	\N	2017-09-24 17:48:21
15379	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13136	2017-09-24 18:07:56	2017-10-04 19:04:00
15380	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13137	2017-09-24 18:07:56	2017-10-04 18:54:58
13943	MEMBRECOM	2015-11-24 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11799	\N	2017-09-24 18:07:57
10990	MEMBRECOM	2013-04-04 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9277	\N	2017-09-24 18:07:57
12559	MEMBRECOM	2014-06-11 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10507	\N	2017-09-24 18:07:57
9925	MEMBRECOM	2011-11-07 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8299	\N	2017-09-24 18:07:57
13810	MEMBRECOM	2015-10-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11666	\N	2017-09-24 18:07:57
11502	MEMBRECOM	2013-11-18 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9726	\N	2017-09-24 18:07:57
15382	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13139	2017-09-24 18:16:50	2017-10-04 19:11:04
15383	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13140	2017-09-24 18:16:50	2017-10-04 18:56:36
15384	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13141	2017-09-24 18:16:50	2017-10-04 18:54:59
17302	SECRETCOM	2018-10-11 00:00:00	2019-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14447	\N	\N
15385	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13142	2017-09-24 18:16:51	2017-10-04 19:03:32
15386	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13143	2017-09-24 18:16:51	2017-10-04 19:11:33
15387	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13144	2017-09-24 18:16:51	2017-10-04 18:56:43
15388	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13145	2017-09-24 18:16:51	2017-10-04 19:04:07
15389	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13146	2017-09-24 18:16:51	2017-10-04 19:11:49
15390	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13147	2017-09-24 18:16:51	2017-10-04 19:09:59
9525	MEMBRECOM	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8015	\N	2017-09-24 18:16:52
13780	MEMBRECOM	2015-09-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11636	\N	2017-09-24 18:16:52
2362	MEMBRECOM	2003-01-28 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1801	\N	2017-09-24 18:16:52
3950	MEMBRECOM	2005-11-04 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3042	\N	2017-09-24 18:16:52
11914	MEMBRECOM	2014-10-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10082	2014-10-08 16:42:07	2017-09-24 18:16:52
3863	MEMBRECOM	2005-07-07 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2952	\N	2017-09-24 18:16:52
10067	MEMBRECOM	2011-12-21 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8421	\N	2017-09-24 18:16:52
10081	MEMBRECOM	2012-12-21 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8435	\N	2017-09-24 18:16:52
12472	MEMBRECOM	2014-04-30 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10420	\N	2017-09-24 18:16:52
12328	VICPDTCOM	2014-10-13 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8241	2014-10-13 11:49:26	2017-09-24 18:16:52
10109	MEMBRECOM	2012-01-12 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8463	\N	2017-09-24 18:16:52
13826	MEMBRECOM	2015-10-28 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11682	\N	2017-09-24 18:16:52
4257	MEMBRECOM	2006-06-15 00:00:00	2006-06-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3338	\N	2017-09-24 18:16:52
2412	RAPCOM	2003-06-26 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	1850	\N	2017-09-24 18:16:52
9527	MEMBRECOM	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8017	\N	2017-09-24 18:16:52
10492	MEMBRECOM	2012-02-28 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8805	\N	2017-09-24 18:16:52
11613	RAPCOM	2013-12-16 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9818	\N	2017-09-24 18:16:52
12476	MEMBRECOM	2014-04-30 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10424	\N	2017-09-24 18:16:52
15392	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13148	2017-09-24 18:17:55	2017-10-04 18:57:37
15393	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13149	2017-09-24 18:17:55	2017-10-04 18:44:07
15394	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13150	2017-09-24 18:17:55	2017-10-04 18:54:36
10620	MEMBRECOM	2012-09-27 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8923	\N	2017-09-24 18:17:56
13693	MEMBRECOM	2015-12-16 00:00:00	2017-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11557	2015-12-16 17:20:57	2017-07-06 15:47:50
15288	MEMBRECOM	2017-07-26 00:00:00	2017-07-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13051	2017-07-27 11:23:43	2017-08-03 12:12:09
15289	MEMBRECOM	2017-07-26 00:00:00	2017-08-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13052	2017-07-27 11:23:47	2017-08-03 12:18:38
15286	MEMBRECOM	2017-07-26 00:00:00	2017-07-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13049	2017-07-27 11:23:30	2017-08-03 12:10:45
15287	MEMBRECOM	2017-07-26 00:00:00	2017-08-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13050	2017-07-27 11:23:38	2017-08-03 12:18:38
15290	MEMBRECOM	2017-07-26 00:00:00	2017-08-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13053	2017-07-27 11:23:52	2017-08-03 12:18:38
15291	MEMBRECOM	2017-07-26 00:00:00	2017-08-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13054	2017-07-27 11:23:56	2017-08-03 12:18:38
15292	MEMBRECOM	2017-07-26 00:00:00	2017-08-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13055	2017-07-27 11:24:01	2017-08-03 12:18:38
15293	MEMBRECOM	2017-07-26 00:00:00	2017-08-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13056	2017-07-27 11:24:08	2017-08-03 12:18:38
15294	MEMBRECOM	2017-07-26 00:00:00	2017-08-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13057	2017-07-27 11:24:15	2017-08-03 12:18:38
15295	MEMBRECOM	2017-07-26 00:00:00	2017-08-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13058	2017-07-27 11:24:19	2017-08-03 12:18:38
15296	MEMBRECOM	2017-07-26 00:00:00	2017-08-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13059	2017-07-27 11:24:47	2017-08-03 12:18:38
15297	MEMBRECOM	2017-07-26 00:00:00	2017-08-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13060	2017-07-27 11:24:51	2017-08-03 12:18:38
15298	MEMBRECOM	2017-07-26 00:00:00	2017-08-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13061	2017-07-27 11:25:50	2017-08-03 12:18:38
15299	MEMBRECOM	2017-07-26 00:00:00	2017-08-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13062	2017-07-27 11:26:09	2017-08-03 12:18:38
15300	MEMBRECOM	2017-07-26 00:00:00	2017-07-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13063	2017-07-27 11:30:40	2017-08-03 12:16:47
15301	MEMBRECOM	2017-07-26 00:00:00	2017-07-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13064	2017-07-27 11:30:45	2017-08-03 12:17:26
15302	MEMBRECOM	2017-07-26 00:00:00	2017-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13065	2017-07-27 11:30:50	2017-08-03 12:18:47
15303	MEMBRECOM	2017-07-26 00:00:00	2017-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13066	2017-07-27 11:30:57	2017-08-03 12:18:47
15304	MEMBRECOM	2017-07-26 00:00:00	2017-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13067	2017-07-27 11:31:02	2017-08-03 12:18:47
15305	MEMBRECOM	2017-07-26 00:00:00	2017-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13068	2017-07-27 11:31:07	2017-08-03 12:18:47
15306	MEMBRECOM	2017-07-26 00:00:00	2017-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13069	2017-07-27 11:31:12	2017-08-03 12:18:47
15307	MEMBRECOM	2017-07-26 00:00:00	2017-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13070	2017-07-27 11:31:17	2017-08-03 12:18:47
15308	MEMBRECOM	2017-07-26 00:00:00	2017-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13071	2017-07-27 11:31:24	2017-08-03 12:18:47
15309	MEMBRECOM	2017-07-26 00:00:00	2017-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13072	2017-07-27 11:31:31	2017-08-03 12:18:47
15310	MEMBRECOM	2017-07-26 00:00:00	2017-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13073	2017-07-27 11:31:38	2017-08-03 12:18:47
15311	MEMBRECOM	2017-07-26 00:00:00	2017-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13074	2017-07-27 11:31:45	2017-08-03 12:18:47
15312	MEMBRECOM	2017-07-26 00:00:00	2017-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13075	2017-07-27 11:31:52	2017-08-03 12:18:47
15313	MEMBRECOM	2017-07-26 00:00:00	2017-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13076	2017-07-27 11:32:02	2017-08-03 12:18:47
15317	VICPDTCOM	2017-07-31 00:00:00	2017-08-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13051	2017-08-03 12:13:57	2017-08-03 12:18:38
15318	RAPCOM	2017-07-31 00:00:00	2017-08-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13049	2017-08-03 12:15:00	2017-08-03 12:18:38
15319	VICPDTCOM	2017-08-01 00:00:00	2017-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13064	2017-08-03 12:15:58	2017-08-03 12:18:47
15320	RAPCOM	2017-08-01 00:00:00	2017-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13063	2017-08-03 12:16:41	2017-08-03 12:18:47
15323	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13082	2017-09-24 10:41:27	2017-10-04 18:55:24
13754	MEMBRECOM	2015-07-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11610	\N	2017-09-24 18:17:56
8957	MEMBRECOM	2010-10-22 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7457	\N	2017-09-24 18:17:56
9453	MEMBRECOM	2011-07-01 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7941	\N	2017-09-24 18:17:56
5020	MEMBRECOM	2008-07-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4105	\N	2017-09-24 18:17:56
3842	RAPCOM	2005-07-07 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2931	\N	2017-09-24 18:17:56
3771	MEMBRECOM	2005-05-04 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2860	\N	2017-09-24 18:17:56
4656	MEMBRECOM	2007-07-31 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3740	\N	2017-09-24 18:17:56
12244	VICPDTCOM	2014-10-09 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8142	2014-10-09 13:51:08	2017-09-24 18:17:56
11252	MEMBRECOM	2013-07-12 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9496	\N	2017-09-24 18:17:56
11350	RAPCOM	2013-10-03 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9586	\N	2017-09-24 18:17:56
11318	MEMBRECOM	2013-10-03 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9554	\N	2017-09-24 18:17:56
12054	MEMBRECOM	2014-10-08 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8213	2014-10-08 17:46:17	2017-09-24 18:17:56
11333	MEMBRECOM	2013-10-03 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9569	\N	2017-09-24 18:17:56
13717	MEMBRECOM	2015-06-17 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11573	\N	2017-09-24 18:17:56
15397	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13153	2017-09-24 18:23:21	2017-10-04 18:54:42
15398	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13154	2017-09-24 18:23:21	2017-10-04 19:06:33
13744	MEMBRECOM	2015-07-09 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11600	\N	2017-09-24 18:23:22
15399	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13155	2017-09-24 18:27:44	2017-10-04 19:02:26
15400	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13156	2017-09-24 18:41:37	2017-10-04 18:58:08
15401	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13157	2017-09-24 18:41:37	2017-10-04 19:11:10
15403	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13159	2017-09-24 18:49:56	2017-10-04 19:00:29
15405	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13161	2017-09-24 18:59:59	2017-10-04 19:06:14
15406	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13162	2017-09-24 18:59:59	2017-10-04 19:02:39
15407	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13163	2017-09-24 18:59:59	2017-10-04 18:54:30
8359	MEMBRECOM	2009-09-15 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6914	\N	2017-09-24 18:59:59
9481	MEMBRECOM	2011-07-06 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7969	\N	2017-09-24 18:59:59
9695	MEMBRECOM	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8183	\N	2017-09-24 18:59:59
15408	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13164	2017-09-24 19:05:36	2017-10-04 18:57:10
15409	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13165	2017-09-24 19:14:36	2017-10-04 19:04:32
15411	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13167	2017-09-24 19:17:41	2017-10-04 19:11:21
15418	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13174	2017-09-24 19:26:20	2017-10-04 18:45:58
15419	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13175	2017-09-24 19:26:20	2017-10-04 19:03:07
15423	MEMBRECOM	2017-09-25 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13178	2017-09-25 10:03:31	2017-10-01 10:37:45
10732	MEMBRECOM	2012-11-27 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9019	\N	2017-09-24 18:20:10
13539	PDTCOM	2015-05-27 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11397	2015-05-27 16:04:51	2017-10-01 09:41:22
10742	MEMBRECOM	2012-11-27 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9029	\N	2017-10-01 09:41:22
10566	MEMBRECOM	2012-07-26 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8868	\N	2017-10-01 09:41:22
8771	MEMBRECOM	2010-04-08 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7287	\N	2017-10-01 09:41:22
9392	MEMBRECOM	2011-06-27 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7880	\N	2017-10-01 09:41:22
11002	MEMBRECOM	2013-04-10 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9289	\N	2017-10-01 09:41:22
15430	MEMBRECOM	2017-10-01 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13185	2017-10-01 09:45:12	2017-10-04 18:50:26
9308	PDTCOM	2011-06-14 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7805	\N	2017-10-01 10:01:39
8871	RAPCOM	2010-07-06 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7371	\N	2017-10-01 10:01:39
5611	MEMBRECOM	2008-10-08 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4585	\N	2017-10-01 10:01:39
12019	MEMBRECOM	2014-10-08 00:00:00	2017-09-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10187	2014-10-08 17:33:34	2017-09-24 11:09:53
15325	MEMBRECOM	2017-09-23 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13084	2017-09-24 11:13:08	2017-10-04 18:55:55
15326	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13085	2017-09-24 12:39:58	2017-10-04 19:09:54
10502	MEMBRECOM	2012-02-28 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8815	\N	2017-10-01 10:01:39
12481	MEMBRECOM	2014-05-14 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10429	\N	2017-10-01 10:01:39
12388	MEMBRECOM	2014-01-29 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10336	\N	2017-10-01 10:01:39
3987	RAPCOM	2005-11-30 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3067	\N	2017-10-01 10:01:39
12596	MEMBRECOM	2014-07-10 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10544	\N	2017-10-01 10:01:39
12674	MEMBRECOM	2014-07-18 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10622	\N	2017-10-01 10:01:39
15431	MEMBRECOM	2017-10-01 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13186	2017-10-01 10:06:58	2017-10-04 18:57:20
10193	MEMBRECOM	2012-02-08 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8546	\N	2017-10-01 10:17:18
13915	RAPCOM	2015-11-05 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11771	\N	2017-10-01 10:17:18
13878	MEMBRECOM	2015-11-05 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11734	\N	2017-10-01 10:17:18
9231	MEMBRECOM	2011-02-10 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7728	\N	2017-10-01 10:17:18
8366	MEMBRECOM	2009-09-29 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6921	\N	2017-10-01 10:17:18
9278	MEMBRECOM	2011-04-27 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7775	\N	2017-10-01 10:17:18
9917	MEMBRECOM	2011-11-02 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8291	\N	2017-10-01 10:17:18
10714	MEMBRECOM	2012-11-28 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9001	\N	2017-10-01 10:20:50
12621	MEMBRECOM	2014-07-10 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10569	\N	2017-10-01 10:20:50
8439	MEMBRECOM	2009-10-07 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6998	\N	2017-10-01 10:20:50
8823	MEMBRECOM	2010-05-26 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7329	\N	2017-10-01 10:20:50
10432	MEMBRECOM	2012-02-15 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8785	\N	2017-10-01 10:39:22
10526	MEMBRECOM	2012-07-03 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8830	\N	2017-10-01 10:39:22
4626	RAPCOM	2007-07-26 00:00:00	2007-07-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3710	\N	2017-10-01 10:39:22
13888	MEMBRECOM	2015-11-05 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11744	\N	2017-10-01 10:42:05
13721	MEMBRECOM	2015-07-25 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11577	\N	2017-10-01 10:42:05
11960	MEMBRECOM	2014-10-08 00:00:00	2017-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10128	2014-10-08 16:57:41	2017-10-01 10:42:05
15432	MEMBRECOM	2017-10-01 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13187	2017-10-01 10:44:23	2017-10-04 19:10:41
15433	MEMBRECOM	2017-10-01 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13188	2017-10-01 10:54:01	2017-10-04 18:55:56
15434	MEMBRECOM	2017-10-01 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13189	2017-10-01 11:03:20	2017-10-04 19:11:27
15435	MEMBRECOM	2017-10-01 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13190	2017-10-01 11:13:13	2017-10-04 18:43:29
15436	MEMBRECOM	2017-10-01 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4135	2017-10-01 11:33:45	2017-10-04 18:40:04
15437	MEMBRECOM	2017-10-01 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13191	2017-10-01 11:41:24	2017-10-04 18:53:49
15438	MEMBRECOM	2017-10-01 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13192	2017-10-01 11:48:00	2017-10-05 12:49:33
15439	MEMBRECOM	2017-10-01 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13193	2017-10-01 11:57:14	2017-10-04 18:57:36
16083	PDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	1	ANCIEN	\N	\N	\N	\N	10163	2017-10-05 14:24:43	2017-10-05 14:25:14
11995	MEMBRECOM	2014-10-08 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10163	2014-10-08 17:15:25	2017-10-05 14:24:43
10387	MEMBRECOM	2012-02-21 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8740	\N	2017-10-04 18:52:41
16085	VICPDTCOM	2017-10-05 00:00:00	2020-09-30 00:00:00	2	ANCIEN	\N	\N	\N	\N	8712	2017-10-05 14:25:20	2017-10-05 14:25:25
16089	VICPDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	3	ANCIEN	\N	\N	\N	\N	10161	2017-10-05 14:26:39	2017-10-05 14:26:45
12166	VICPDTCOM	2014-10-09 00:00:00	2017-10-03 00:00:00	7	ANCIEN	\N	\N	\N	\N	10228	2014-10-09 10:45:22	2017-10-04 19:19:03
16091	VICPDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	4	ANCIEN	\N	\N	\N	\N	8696	2017-10-05 14:27:09	2017-10-05 14:27:15
16093	VICPDTCOM	2017-10-05 00:00:00	2020-06-15 00:00:00	5	ANCIEN	\N	\N	\N	\N	8689	2017-10-05 14:27:30	2017-10-05 14:27:36
16097	VICPDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	6	ANCIEN	\N	\N	\N	\N	10103	2017-10-05 14:28:16	2017-10-05 14:28:23
16099	VICPDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	7	ANCIEN	\N	\N	\N	\N	10096	2017-10-05 14:28:31	2017-10-05 14:28:35
16100	VICPDTCOM	2017-10-05 00:00:00	2020-09-30 00:00:00	8	ANCIEN	\N	\N	\N	\N	13505	2017-10-05 14:28:43	2017-10-05 14:28:47
16102	VICPDTCOM	2017-10-05 00:00:00	2020-03-03 00:00:00	9	ANCIEN	\N	\N	\N	\N	8834	2017-10-05 14:29:04	2017-10-05 14:29:10
16104	VICPDTCOM	2017-10-05 00:00:00	2020-10-06 00:00:00	10	ANCIEN	\N	\N	\N	\N	13478	2017-10-05 14:29:17	2017-10-05 14:29:24
12213	VICPDTCOM	2014-10-09 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10153	2014-10-09 11:52:03	2017-10-04 19:24:34
16105	VICPDTCOM	2017-10-05 00:00:00	2020-10-06 00:00:00	11	ANCIEN	\N	\N	\N	\N	13481	2017-10-05 14:29:30	2017-10-05 14:29:34
16106	SECRETCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	12	ANCIEN	\N	\N	\N	\N	8692	2017-10-05 14:29:44	2017-10-05 14:29:49
16108	SECRETCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	13	ANCIEN	\N	\N	\N	\N	10162	2017-10-05 14:29:56	2017-10-05 14:30:00
12221	VICPDTCOM	2014-10-09 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8747	2014-10-09 11:53:11	2017-10-04 18:35:38
16109	SECRETCOM	2017-10-05 00:00:00	2019-03-28 00:00:00	4	ANCIEN	\N	\N	\N	\N	7751	2017-10-05 14:30:07	2017-10-05 14:30:12
16113	PDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10123	2017-10-05 14:31:11	\N
16126	VICPDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	1	ANCIEN	\N	\N	\N	\N	8019	2017-10-05 14:33:48	2017-10-05 14:33:52
16132	VICPDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	2	ANCIEN	\N	\N	\N	\N	13439	2017-10-05 14:34:43	2017-10-05 14:55:05
16133	VICPDTCOM	2017-10-05 00:00:00	2020-09-30 00:00:00	3	ANCIEN	\N	\N	\N	\N	262	2017-10-05 14:34:58	2017-10-05 14:35:10
16138	VICPDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	4	ANCIEN	\N	\N	\N	\N	11501	2017-10-05 14:35:26	2017-10-05 14:35:31
16141	VICPDTCOM	2017-10-05 00:00:00	2019-06-23 00:00:00	5	ANCIEN	\N	\N	\N	\N	2820	2017-10-05 14:35:42	2017-10-05 14:35:47
12226	VICPDTCOM	2014-10-09 00:00:00	2017-10-04 00:00:00	4	ANCIEN	\N	\N	\N	\N	4326	2014-10-09 12:11:43	2017-10-04 18:36:22
16145	VICPDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	6	ANCIEN	\N	\N	\N	\N	7415	2017-10-05 14:35:59	2017-10-05 14:36:04
16148	VICPDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	7	ANCIEN	\N	\N	\N	\N	3633	2017-10-05 14:36:14	2017-10-05 14:36:18
16149	VICPDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	8	ANCIEN	\N	\N	\N	\N	10218	2017-10-05 14:36:29	2017-10-05 14:36:35
16151	VICPDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	10	ANCIEN	\N	\N	\N	\N	8205	2017-10-05 14:36:46	2017-10-05 14:36:52
16154	VICPDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	11	ANCIEN	\N	\N	\N	\N	10126	2017-10-05 14:37:02	2017-10-05 14:37:07
16156	SECRETCOM	2017-10-05 00:00:00	2020-09-30 00:00:00	1	ANCIEN	\N	\N	\N	\N	10122	2017-10-05 14:37:23	2017-10-05 14:37:27
16157	SECRETCOM	2017-10-05 00:00:00	2020-10-06 00:00:00	2	ANCIEN	\N	\N	\N	\N	13443	2017-10-05 14:37:35	2017-10-05 14:37:39
12192	VICPDTCOM	2014-10-09 00:00:00	2017-10-04 00:00:00	2	ANCIEN	\N	\N	\N	\N	8712	2014-10-09 11:03:19	2017-10-04 18:36:46
16158	SECRETCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	3	ANCIEN	\N	\N	\N	\N	427	2017-10-05 14:37:48	2017-10-05 14:37:54
16159	SECRETCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	4	ANCIEN	\N	\N	\N	\N	10219	2017-10-05 14:38:04	2017-10-05 14:38:08
16199	SECRETCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	15	ANCIEN	\N	\N	\N	\N	8128	2017-10-05 14:41:47	2017-10-05 14:41:49
16200	MEMBRECOM	2017-10-05 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13549	2017-10-05 14:41:50	\N
16201	VICPDTCOM	2017-10-05 00:00:00	2020-10-06 00:00:00	5	ANCIEN	\N	\N	\N	\N	10243	2017-10-05 14:41:58	2017-10-05 17:56:09
16202	MEMBRECOM	2017-10-05 00:00:00	2017-10-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13550	2017-10-05 14:42:03	2017-10-16 15:00:23
16203	VICPDTCOM	2017-10-05 00:00:00	2020-10-06 00:00:00	6	ANCIEN	\N	\N	\N	\N	4746	2017-10-05 14:42:10	2017-10-05 17:56:13
16204	MEMBRECOM	2017-10-05 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13551	2017-10-05 14:42:15	\N
12203	SECRETCOM	2014-10-09 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8724	2014-10-09 11:06:52	2017-10-04 18:37:11
9529	MEMBRECOM	2011-10-01 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8019	\N	2017-10-05 14:33:48
15274	MEMBRECOM	2017-07-04 00:00:00	2017-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13041	2017-07-04 15:35:17	2017-07-10 16:44:14
15275	MEMBRECOM	2017-07-10 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13042	2017-07-10 16:44:14	2017-09-24 18:16:52
15314	MEMBRECOM	2017-07-29 00:00:00	2017-07-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13077	2017-07-31 12:02:13	2017-08-01 14:55:03
15329	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13087	2017-09-24 16:24:50	2017-10-04 18:58:37
15330	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13088	2017-09-24 16:24:50	2017-10-04 18:54:52
15331	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13089	2017-09-24 16:24:50	2017-10-04 18:55:16
15332	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13090	2017-09-24 16:24:50	2017-10-04 18:54:04
10484	MEMBRECOM	2012-02-22 00:00:00	2017-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8797	\N	2017-09-25 09:56:00
10560	RAPCOM	2012-07-26 00:00:00	2017-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8862	\N	2017-09-25 09:56:00
9389	MEMBRECOM	2011-06-27 00:00:00	2017-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7877	\N	2017-09-25 09:56:00
10049	MEMBRECOM	2011-12-19 00:00:00	2017-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8403	\N	2017-09-25 09:56:00
12489	RAPCOM	2014-05-12 00:00:00	2017-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10437	\N	2017-09-25 09:56:00
13736	MEMBRECOM	2015-07-09 00:00:00	2017-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11592	\N	2017-09-25 09:56:00
12155	MEMBRECOM	2014-10-09 00:00:00	2017-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10242	2014-10-09 10:41:10	2017-09-25 09:56:00
8525	MEMBRECOM	2009-12-08 00:00:00	2017-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7076	\N	2017-09-25 09:56:00
3832	MEMBRECOM	2005-07-05 00:00:00	2017-09-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2921	\N	2017-09-25 09:56:00
15422	MEMBRECOM	2017-09-25 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4197	2017-09-25 09:57:06	2017-10-04 19:10:31
15424	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13179	2017-09-25 10:54:33	2017-10-04 19:06:25
15425	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13180	2017-09-25 10:54:33	2017-10-04 18:56:56
15426	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13181	2017-09-25 10:54:33	2017-10-04 18:45:06
10095	MEMBRECOM	2012-01-12 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8449	\N	2017-09-25 10:54:33
10167	MEMBRECOM	2012-01-26 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8525	\N	2017-09-25 10:54:33
15427	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13182	2017-09-25 10:56:48	2017-10-04 18:53:49
10161	MEMBRECOM	2012-01-26 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8519	\N	2017-09-25 10:58:49
10652	RAPCOM	2012-10-23 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8940	\N	2017-09-25 10:58:49
10361	MEMBRECOM	2012-02-21 00:00:00	2017-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8714	\N	2017-09-25 10:58:49
15428	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13183	2017-09-25 11:00:40	2017-10-04 19:03:14
12247	VICPDTCOM	2014-10-09 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4301	2014-10-09 13:51:32	2017-10-04 18:43:43
12251	SECRETCOM	2014-10-09 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	675	2014-10-09 13:52:05	2017-10-04 19:01:02
12089	MEMBRECOM	2014-10-08 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4247	2014-10-08 17:51:37	2017-10-04 19:12:49
11988	MEMBRECOM	2014-10-08 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10156	2014-10-08 17:10:07	2017-10-04 18:35:45
12020	MEMBRECOM	2014-10-08 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10188	2014-10-08 17:33:41	2017-10-04 18:35:50
5170	MEMBRECOM	2008-10-07 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4252	\N	2017-10-04 18:35:54
11924	MEMBRECOM	2014-10-08 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10092	2014-10-08 16:45:14	2017-10-04 19:14:01
11972	MEMBRECOM	2014-10-08 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10140	2014-10-08 17:03:34	2017-10-04 19:50:23
12023	MEMBRECOM	2014-10-08 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10191	2014-10-08 17:34:59	2017-10-04 19:14:26
12270	SECRETCOM	2014-10-09 00:00:00	2017-10-04 00:00:00	4	ANCIEN	\N	\N	\N	\N	8126	2014-10-09 13:58:09	2017-10-04 18:49:38
9696	MEMBRECOM	2011-10-01 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8184	\N	2017-10-04 18:38:38
5190	MEMBRECOM	2008-10-07 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4271	\N	2017-10-04 18:38:38
12027	MEMBRECOM	2014-10-08 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10195	2014-10-08 17:36:57	2017-10-04 18:38:40
11912	MEMBRECOM	2014-10-08 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10080	2014-10-08 16:40:46	2017-10-04 18:38:41
3438	MEMBRECOM	2004-10-06 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2589	\N	2017-10-04 18:38:45
11969	MEMBRECOM	2014-10-08 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10137	2014-10-08 17:01:47	2017-10-04 18:38:47
12026	MEMBRECOM	2014-10-08 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10194	2014-10-08 17:36:47	2017-10-04 18:38:49
16110	SECRETCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	14	ANCIEN	\N	\N	\N	\N	13537	2017-10-05 14:30:08	2017-10-05 14:30:14
16111	SECRETCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	15	ANCIEN	\N	\N	\N	\N	13465	2017-10-05 14:30:19	2017-10-05 14:30:23
16112	SECRETCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	16	ANCIEN	\N	\N	\N	\N	8724	2017-10-05 14:30:30	2017-10-05 14:30:35
16114	PDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	1	ANCIEN	\N	\N	\N	\N	8738	2017-10-05 14:31:23	2017-10-05 14:31:28
16115	VICPDTCOM	2017-10-05 00:00:00	2020-09-30 00:00:00	2	ANCIEN	\N	\N	\N	\N	11497	2017-10-05 14:31:34	2017-10-05 14:31:40
16116	VICPDTCOM	2017-10-05 00:00:00	2020-10-06 00:00:00	4	ANCIEN	\N	\N	\N	\N	10206	2017-10-05 14:31:47	2017-10-05 14:31:50
16117	VICPDTCOM	2017-10-05 00:00:00	2018-12-30 00:00:00	4	ANCIEN	\N	\N	\N	\N	8699	2017-10-05 14:31:59	2017-10-05 14:32:06
17303	RAPCOM	2018-10-11 00:00:00	2019-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14445	\N	\N
11954	MEMBRECOM	2014-10-08 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10122	2014-10-08 16:55:38	2017-10-04 18:39:13
16118	VICPDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	5	ANCIEN	\N	\N	\N	\N	8701	2017-10-05 14:32:13	2017-10-05 14:32:22
16119	VICPDTCOM	2017-10-05 00:00:00	2020-09-30 00:00:00	6	ANCIEN	\N	\N	\N	\N	8723	2017-10-05 14:32:28	2017-10-05 14:32:49
16120	VICPDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	7	ANCIEN	\N	\N	\N	\N	13399	2017-10-05 14:32:56	2017-10-05 14:33:18
16125	VICPDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	8	ANCIEN	\N	\N	\N	\N	10208	2017-10-05 14:33:42	2017-10-05 14:33:48
16127	VICPDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	9	ANCIEN	\N	\N	\N	\N	13414	2017-10-05 14:33:54	2017-10-05 14:34:02
16129	VICPDTCOM	2017-10-05 00:00:00	2020-09-30 00:00:00	10	ANCIEN	\N	\N	\N	\N	10117	2017-10-05 14:34:22	2017-10-05 14:34:29
16131	VICPDTCOM	2017-10-05 00:00:00	2020-09-30 00:00:00	11	ANCIEN	\N	\N	\N	\N	10211	2017-10-05 14:34:35	2017-10-05 14:34:43
12043	MEMBRECOM	2014-10-08 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10211	2014-10-08 17:41:01	2017-10-05 14:34:35
16134	SECRETCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	12	ANCIEN	\N	\N	\N	\N	10110	2017-10-05 14:35:10	2017-10-05 14:35:14
11942	MEMBRECOM	2014-10-08 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10110	2014-10-08 16:52:41	2017-10-05 14:35:10
13637	MEMBRECOM	2015-09-14 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11501	2015-09-14 14:28:13	2017-10-05 14:56:47
16136	SECRETCOM	2017-10-05 00:00:00	2019-01-15 00:00:00	13	ANCIEN	\N	\N	\N	\N	13379	2017-10-05 14:35:23	2017-10-05 14:35:28
16139	SECRETCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	14	ANCIEN	\N	\N	\N	\N	10106	2017-10-05 14:35:34	2017-10-05 14:35:39
8915	MEMBRECOM	2010-10-15 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7415	\N	2017-10-05 14:57:40
16143	SECRETCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	15	ANCIEN	\N	\N	\N	\N	11276	2017-10-05 14:35:46	2017-10-05 14:36:09
16160	MEMBRECOM	2017-10-05 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10231	2017-10-05 14:38:49	\N
16161	MEMBRECOM	2017-10-05 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13540	2017-10-05 14:38:56	\N
16162	PDTCOM	2017-10-05 00:00:00	2020-10-06 00:00:00	1	ANCIEN	\N	\N	\N	\N	4408	2017-10-05 14:39:03	2017-10-05 17:55:33
16163	VICPDTCOM	2017-10-05 00:00:00	2020-10-06 00:00:00	2	ANCIEN	\N	\N	\N	\N	10247	2017-10-05 14:39:15	2017-10-05 17:55:35
16164	MEMBRECOM	2017-10-05 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9120	2017-10-05 14:39:23	\N
11918	MEMBRECOM	2014-10-08 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10086	2014-10-08 16:43:21	2017-10-04 19:05:47
16166	MEMBRECOM	2017-10-05 00:00:00	2019-07-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10232	2017-10-05 14:39:30	\N
10576	MEMBRECOM	2012-09-25 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8878	\N	2017-10-04 18:41:49
16121	PDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	1	ANCIEN	\N	\N	\N	\N	2619	2017-10-05 14:33:05	2017-10-05 14:33:08
16122	RAPGENCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	2	ANCIEN	\N	\N	\N	\N	2577	2017-10-05 14:33:20	2017-10-05 14:33:26
16123	VICPDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	3	ANCIEN	\N	\N	\N	\N	8040	2017-10-05 14:33:34	2017-10-05 14:33:50
16144	VICPDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	11	ANCIEN	\N	\N	\N	\N	8153	2017-10-05 14:35:54	2017-10-05 14:36:01
16124	VICPDTCOM	2017-10-05 00:00:00	2020-09-30 00:00:00	4	ANCIEN	\N	\N	\N	\N	609	2017-10-05 14:33:41	2017-10-05 14:33:45
15750	MEMBRECOM	2017-10-04 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13381	2017-10-04 19:43:02	\N
15756	MEMBRECOM	2017-10-04 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13384	2017-10-04 19:43:18	\N
13523	MEMBRECOM	2015-05-06 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11413	2015-05-06 11:42:07	2017-10-04 18:49:44
16128	VICPDTCOM	2017-10-05 00:00:00	2020-09-24 00:00:00	5	ANCIEN	\N	\N	\N	\N	4326	2017-10-05 14:34:05	2017-10-05 14:34:08
16003	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13496	2017-10-04 00:00:00	\N
16006	MEMBRECOM	2017-10-04 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13499	2017-10-04 19:58:42	\N
15779	MEMBRECOM	2017-10-04 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13396	2017-10-04 19:44:12	\N
16130	VICPDTCOM	2017-10-05 00:00:00	2020-09-30 00:00:00	6	ANCIEN	\N	\N	\N	\N	4277	2017-10-05 14:34:32	2017-10-05 14:34:34
15786	MEMBRECOM	2017-10-04 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13402	2017-10-04 19:44:30	\N
16135	VICPDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	7	ANCIEN	\N	\N	\N	\N	8123	2017-10-05 14:35:11	2017-10-05 14:35:13
16009	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13501	2017-10-04 00:00:00	\N
15797	MEMBRECOM	2017-10-04 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2579	2017-10-04 19:44:58	\N
16012	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13503	2017-10-04 00:00:00	\N
15805	MEMBRECOM	2017-10-04 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13411	2017-10-04 19:45:20	\N
15815	MEMBRECOM	2017-10-04 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13415	2017-10-04 19:45:44	\N
16137	VICPDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	8	ANCIEN	\N	\N	\N	\N	10085	2017-10-05 14:35:24	2017-10-05 14:35:27
11981	MEMBRECOM	2014-10-08 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10149	2014-10-08 17:06:33	2017-10-04 18:50:28
16140	VICPDTCOM	2017-10-05 00:00:00	2020-08-02 00:00:00	9	ANCIEN	\N	\N	\N	\N	10088	2017-10-05 14:35:35	2017-10-05 14:35:38
15827	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13421	2017-10-04 00:00:00	\N
16142	VICPDTCOM	2017-10-05 00:00:00	2020-09-30 00:00:00	10	ANCIEN	\N	\N	\N	\N	13495	2017-10-05 14:35:43	2017-10-05 14:35:46
16146	VICPDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	12	ANCIEN	\N	\N	\N	\N	10170	2017-10-05 14:36:03	2017-10-05 14:36:05
16147	SECRETCOM	2017-10-05 00:00:00	2020-09-30 00:00:00	13	ANCIEN	\N	\N	\N	\N	10173	2017-10-05 14:36:14	2017-10-05 14:36:37
12005	MEMBRECOM	2014-10-08 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10173	2014-10-08 17:25:14	2017-10-05 14:36:14
16150	SECRETCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	14	ANCIEN	\N	\N	\N	\N	10174	2017-10-05 14:36:45	2017-10-05 14:36:48
15848	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13431	2017-10-04 00:00:00	\N
15849	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13432	2017-10-04 00:00:00	\N
16152	SECRETCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	15	ANCIEN	\N	\N	\N	\N	10175	2017-10-05 14:36:53	2017-10-05 14:36:58
15851	MEMBRECOM	2017-10-04 00:00:00	2018-04-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13433	2017-10-04 19:48:13	2018-04-13 17:54:29
15852	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13434	2017-10-04 00:00:00	\N
17460	MEMBRECOM	2018-12-11 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13456	\N	\N
15854	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13436	2017-10-04 00:00:00	\N
16153	SECRETCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	16	ANCIEN	\N	\N	\N	\N	11498	2017-10-05 14:37:01	2017-10-05 14:37:03
15866	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13440	2017-10-04 00:00:00	\N
16155	SECRETCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	17	ANCIEN	\N	\N	\N	\N	13516	2017-10-05 14:37:10	2017-10-05 14:37:14
15874	MEMBRECOM	2017-10-04 00:00:00	2022-11-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8077	2017-10-04 19:50:08	\N
16165	PDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	1	ANCIEN	\N	\N	\N	\N	2553	2017-10-05 14:39:23	2017-10-05 14:39:29
16167	VICPDTCOM	2017-10-05 00:00:00	2018-08-06 00:00:00	2	ANCIEN	\N	\N	\N	\N	235	2017-10-05 14:39:34	2017-10-05 14:39:37
15883	MEMBRECOM	2017-10-04 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8094	2017-10-04 19:50:42	\N
16168	MEMBRECOM	2017-10-05 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10233	2017-10-05 14:39:37	\N
16029	MEMBRECOM	2017-10-04 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13511	2017-10-04 20:00:42	\N
11948	MEMBRECOM	2014-10-08 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10116	2014-10-08 16:54:01	2017-10-04 18:53:00
16169	MEMBRECOM	2017-10-05 00:00:00	2018-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13541	2017-10-05 14:39:43	2018-05-31 10:52:17
16170	VICPDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	3	ANCIEN	\N	\N	\N	\N	3789	2017-10-05 14:39:45	2017-10-05 14:39:48
15897	MEMBRECOM	2017-10-04 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2825	2017-10-04 19:51:17	\N
15901	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13448	2017-10-04 00:00:00	\N
12911	MEMBRECOM	2015-01-27 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10857	2015-01-27 13:59:29	2017-10-04 18:48:32
16171	VICPDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	4	ANCIEN	\N	\N	\N	\N	10186	2017-10-05 14:39:51	2017-10-05 14:39:53
16172	MEMBRECOM	2017-10-05 00:00:00	2017-10-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13542	2017-10-05 14:39:52	2017-10-24 11:21:58
16173	MEMBRECOM	2017-10-05 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11438	2017-10-05 14:39:59	\N
16174	VICPDTCOM	2017-10-05 00:00:00	2020-09-30 00:00:00	5	ANCIEN	\N	\N	\N	\N	13390	2017-10-05 14:40:03	2017-10-05 14:40:07
16033	MEMBRECOM	2017-10-04 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13512	2017-10-04 20:01:45	\N
16175	MEMBRECOM	2017-10-05 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8243	2017-10-05 14:40:08	\N
16176	VICPDTCOM	2017-10-05 00:00:00	2020-10-06 00:00:00	3	ANCIEN	\N	\N	\N	\N	8244	2017-10-05 14:40:15	2017-10-05 17:55:39
16037	MEMBRECOM	2017-10-04 00:00:00	2020-06-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13513	2017-10-04 20:03:05	\N
16177	MEMBRECOM	2017-10-05 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13543	2017-10-05 14:40:19	\N
16039	MEMBRECOM	2017-10-04 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13514	2017-10-04 20:03:26	\N
16178	MEMBRECOM	2017-10-05 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10234	2017-10-05 14:40:25	\N
16179	VICPDTCOM	2017-10-05 00:00:00	2020-09-30 00:00:00	6	ANCIEN	\N	\N	\N	\N	4301	2017-10-05 14:40:27	2017-10-05 14:40:30
12042	MEMBRECOM	2014-10-08 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10210	2014-10-08 17:40:53	2017-10-04 18:52:55
16043	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13517	2017-10-04 00:00:00	\N
16044	MEMBRECOM	2017-10-04 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13518	2017-10-04 20:04:22	\N
16045	MEMBRECOM	2017-10-04 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13519	2017-10-04 20:04:30	\N
16046	MEMBRECOM	2017-10-04 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13520	2017-10-04 20:04:45	\N
16047	MEMBRECOM	2017-10-04 00:00:00	2019-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13521	2017-10-04 20:04:55	\N
16048	MEMBRECOM	2017-10-04 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13522	2017-10-04 20:05:05	\N
16049	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13523	2017-10-04 00:00:00	\N
16180	VICPDTCOM	2017-10-05 00:00:00	2020-09-30 00:00:00	7	ANCIEN	\N	\N	\N	\N	4333	2017-10-05 14:40:35	2017-10-05 14:40:39
16181	VICPDTCOM	2017-10-05 00:00:00	2020-10-06 00:00:00	10	ANCIEN	\N	\N	\N	\N	13544	2017-10-05 14:40:36	2017-10-05 17:56:37
16182	MEMBRECOM	2017-10-05 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13545	2017-10-05 14:40:42	\N
16053	MEMBRECOM	2017-10-04 00:00:00	2018-11-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13524	2017-10-04 20:05:59	\N
16183	VICPDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	8	ANCIEN	\N	\N	\N	\N	8085	2017-10-05 14:40:48	2017-10-05 14:40:51
16184	MEMBRECOM	2017-10-05 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10240	2017-10-05 14:40:49	\N
16056	MEMBRECOM	2017-10-04 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13525	2017-10-04 20:06:27	\N
16058	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13526	2017-10-04 00:00:00	\N
16185	VICPDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	9	ANCIEN	\N	\N	\N	\N	2631	2017-10-05 14:40:54	2017-10-05 14:40:57
16186	MEMBRECOM	2017-10-05 00:00:00	2018-01-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13546	2017-10-05 14:40:59	2018-02-08 14:32:21
16061	MEMBRECOM	2017-10-04 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13527	2017-10-04 20:07:06	\N
16062	MEMBRECOM	2017-10-04 00:00:00	2019-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13528	2017-10-04 20:07:14	\N
16063	MEMBRECOM	2017-10-04 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10150	2017-10-04 20:07:23	\N
16064	MEMBRECOM	2017-10-04 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13529	2017-10-04 20:07:33	\N
16187	VICPDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	10	ANCIEN	\N	\N	\N	\N	13416	2017-10-05 14:41:03	2017-10-05 14:41:05
16188	SECRETCOM	2017-10-05 00:00:00	2020-09-30 00:00:00	13	ANCIEN	\N	\N	\N	\N	13547	2017-10-05 14:41:06	2017-10-05 17:56:53
16189	VICPDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	11	ANCIEN	\N	\N	\N	\N	10142	2017-10-05 14:41:11	2017-10-05 14:41:13
16190	MEMBRECOM	2017-10-05 00:00:00	2020-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12092	2017-10-05 14:41:12	\N
16191	SECRETCOM	2017-10-05 00:00:00	2020-10-06 00:00:00	14	ANCIEN	\N	\N	\N	\N	10752	2017-10-05 14:41:18	2017-10-05 17:56:57
16192	SECRETCOM	2017-10-05 00:00:00	2020-09-30 00:00:00	12	ANCIEN	\N	\N	\N	\N	277	2017-10-05 14:41:21	2017-10-05 14:41:26
16193	VICPDTCOM	2017-10-05 00:00:00	2019-06-23 00:00:00	4	ANCIEN	\N	\N	\N	\N	4742	2017-10-05 14:41:26	2017-10-05 17:55:46
16194	SECRETCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	13	ANCIEN	\N	\N	\N	\N	10091	2017-10-05 14:41:30	2017-10-05 14:42:07
16195	MEMBRECOM	2017-10-05 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13548	2017-10-05 14:41:32	\N
16196	SECRETCOM	2017-10-05 00:00:00	2017-10-11 00:00:00	14	ANCIEN	\N	\N	\N	\N	10248	2017-10-05 14:41:37	2017-10-16 15:00:07
16622	MEMBRECOM	2018-02-07 00:00:00	2018-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13909	2018-02-06 16:33:28	\N
16197	SECRETCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	14	ANCIEN	\N	\N	\N	\N	4251	2017-10-05 14:41:38	2017-10-05 14:41:40
16198	MEMBRECOM	2017-10-05 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10241	2017-10-05 14:41:43	\N
11965	MEMBRECOM	2014-10-08 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10133	2014-10-08 17:00:52	2017-10-04 18:38:43
16253	MEMBRECOM	2017-10-24 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13574	2017-10-24 11:23:00	\N
16256	MEMBRECOM	2017-10-31 00:00:00	2017-12-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13577	2017-11-08 14:25:30	2017-12-21 10:15:39
16257	MEMBRECOM	2017-10-31 00:00:00	2017-12-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13578	2017-11-08 14:25:34	2017-12-21 10:15:39
16258	MEMBRECOM	2017-10-31 00:00:00	2017-12-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13579	2017-11-08 14:25:41	2017-12-21 10:15:39
16259	MEMBRECOM	2017-10-31 00:00:00	2017-12-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13580	2017-11-08 14:25:46	2017-12-21 10:15:39
16260	MEMBRECOM	2017-10-31 00:00:00	2017-12-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13581	2017-11-08 14:25:52	2017-12-21 10:15:39
16261	MEMBRECOM	2017-10-31 00:00:00	2017-12-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13582	2017-11-08 14:25:58	2017-12-21 10:15:39
16262	MEMBRECOM	2017-10-31 00:00:00	2017-12-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13583	2017-11-08 14:26:02	2017-12-21 10:15:39
16263	MEMBRECOM	2017-10-31 00:00:00	2017-12-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13584	2017-11-08 14:26:07	2017-12-21 10:15:39
16264	MEMBRECOM	2017-10-31 00:00:00	2017-12-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13585	2017-11-08 14:26:15	2017-12-21 10:15:39
16265	MEMBRECOM	2017-10-31 00:00:00	2017-12-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13586	2017-11-08 14:26:22	2017-12-21 10:15:39
16266	MEMBRECOM	2017-10-31 00:00:00	2017-12-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13587	2017-11-08 14:26:28	2017-12-21 10:15:39
16267	MEMBRECOM	2017-10-31 00:00:00	2017-12-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13588	2017-11-08 14:26:36	2017-12-21 10:15:39
16268	MEMBRECOM	2017-10-31 00:00:00	2017-12-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13589	2017-11-08 14:26:48	2017-12-21 10:15:39
16269	MEMBRECOM	2017-10-31 00:00:00	2017-12-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13590	2017-11-08 14:26:55	2017-12-21 10:15:39
16382	MEMBRECOM	2017-12-01 00:00:00	2017-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13694	2017-12-01 16:42:07	2017-12-07 10:07:02
16383	MEMBRECOM	2017-12-01 00:00:00	2017-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13695	2017-12-01 16:42:13	2017-12-07 10:07:02
16384	MEMBRECOM	2017-12-01 00:00:00	2017-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13696	2017-12-01 16:42:18	2017-12-07 10:07:02
16385	MEMBRECOM	2017-12-01 00:00:00	2017-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13697	2017-12-01 16:42:24	2017-12-07 10:07:02
16386	MEMBRECOM	2017-12-01 00:00:00	2017-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13698	2017-12-01 16:42:29	2017-12-07 10:07:02
16387	MEMBRECOM	2017-12-01 00:00:00	2017-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13699	2017-12-01 16:42:35	2017-12-07 10:07:02
16388	MEMBRECOM	2017-12-01 00:00:00	2017-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13700	2017-12-01 16:42:41	2017-12-07 10:07:02
16389	MEMBRECOM	2017-12-01 00:00:00	2017-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13701	2017-12-01 16:42:48	2017-12-07 10:07:02
16390	MEMBRECOM	2017-12-01 00:00:00	2017-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13702	2017-12-01 16:42:53	2017-12-07 10:07:02
16391	MEMBRECOM	2017-12-01 00:00:00	2017-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13703	2017-12-01 16:42:58	2017-12-07 10:07:02
16392	MEMBRECOM	2017-12-01 00:00:00	2017-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13704	2017-12-01 16:43:07	2017-12-07 10:07:02
16393	MEMBRECOM	2017-12-01 00:00:00	2017-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13705	2017-12-01 16:43:15	2017-12-07 10:07:02
16394	MEMBRECOM	2017-12-01 00:00:00	2017-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13706	2017-12-01 16:43:20	2017-12-07 10:07:02
16395	MEMBRECOM	2017-12-01 00:00:00	2017-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13707	2017-12-01 16:43:24	2017-12-07 10:07:02
16344	MEMBRECOM	2017-12-01 00:00:00	2017-12-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13665	2017-12-01 11:36:06	2017-12-07 10:05:49
16424	MEMBRECOM	2017-12-13 00:00:00	2017-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13736	2017-12-14 10:54:20	2017-12-20 10:15:11
16458	MEMBRECOM	2018-01-17 00:00:00	2018-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13770	2018-01-16 14:45:15	\N
16459	MEMBRECOM	2018-01-17 00:00:00	2018-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13771	2018-01-16 14:45:20	\N
16460	MEMBRECOM	2018-01-17 00:00:00	2018-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13772	2018-01-16 14:45:26	\N
16461	MEMBRECOM	2018-01-17 00:00:00	2018-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13773	2018-01-16 14:45:31	2018-01-31 11:37:31
16462	MEMBRECOM	2018-01-17 00:00:00	2018-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13774	2018-01-16 14:45:36	\N
16463	MEMBRECOM	2018-01-17 00:00:00	2018-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13775	2018-01-16 14:45:41	\N
16464	MEMBRECOM	2018-01-17 00:00:00	2018-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13776	2018-01-16 14:45:47	\N
16465	MEMBRECOM	2018-01-17 00:00:00	2018-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13777	2018-01-16 14:45:52	2018-01-31 11:44:40
16466	MEMBRECOM	2018-01-17 00:00:00	2018-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13778	2018-01-16 14:45:57	\N
16467	MEMBRECOM	2018-01-17 00:00:00	2018-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13779	2018-01-16 14:46:01	\N
16469	MEMBRECOM	2018-01-17 00:00:00	2018-01-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13781	2018-01-16 14:46:14	2018-01-31 11:41:44
16470	MEMBRECOM	2018-01-17 00:00:00	2018-01-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13782	2018-01-16 14:46:19	2018-01-31 11:36:30
16472	MEMBRECOM	2018-01-17 00:00:00	2018-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13784	2018-01-16 14:46:29	2018-01-31 11:42:48
16473	MEMBRECOM	2018-01-17 00:00:00	2018-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13785	2018-01-16 14:46:36	\N
16474	MEMBRECOM	2018-01-17 00:00:00	2018-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13786	2018-01-16 14:47:07	\N
16475	MEMBRECOM	2018-01-17 00:00:00	2018-01-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13787	2018-01-16 14:47:12	2018-01-31 11:41:15
16476	MEMBRECOM	2018-01-17 00:00:00	2018-01-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13788	2018-01-16 14:47:19	2018-01-31 11:42:13
16477	MEMBRECOM	2018-01-17 00:00:00	2018-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13789	2018-01-16 14:47:33	2018-01-31 11:44:02
16478	MEMBRECOM	2018-01-17 00:00:00	2018-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13790	2018-01-16 14:55:43	2018-02-02 09:30:09
16479	MEMBRECOM	2018-01-17 00:00:00	2018-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13791	2018-01-16 14:55:48	2018-02-02 09:30:09
16480	MEMBRECOM	2018-01-17 00:00:00	2018-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13792	2018-01-16 14:55:54	2018-02-02 09:30:09
16481	MEMBRECOM	2018-01-17 00:00:00	2018-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13793	2018-01-16 14:55:59	2018-02-02 09:30:09
16482	MEMBRECOM	2018-01-17 00:00:00	2018-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13794	2018-01-16 14:56:04	2018-01-25 13:12:05
16483	MEMBRECOM	2018-01-17 00:00:00	2018-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13795	2018-01-16 14:56:08	2018-02-02 09:30:09
16484	MEMBRECOM	2018-01-17 00:00:00	2018-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13796	2018-01-16 14:56:15	2018-02-02 09:30:09
16485	MEMBRECOM	2018-01-17 00:00:00	2018-01-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13797	2018-01-16 14:56:19	2018-01-25 13:10:11
16486	MEMBRECOM	2018-01-17 00:00:00	2018-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13798	2018-01-16 14:56:24	2018-01-25 13:09:09
16487	MEMBRECOM	2018-01-17 00:00:00	2018-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13799	2018-01-16 14:56:30	2018-01-25 13:13:43
16488	MEMBRECOM	2018-01-17 00:00:00	2018-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13800	2018-01-16 14:56:35	2018-02-02 09:30:09
16490	MEMBRECOM	2018-01-17 00:00:00	2018-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13802	2018-01-16 14:56:45	2018-02-02 09:30:09
16491	MEMBRECOM	2018-01-17 00:00:00	2018-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13803	2018-01-16 14:56:50	2018-02-02 09:30:09
16492	MEMBRECOM	2018-01-17 00:00:00	2018-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13804	2018-01-16 14:56:55	2018-02-02 09:30:09
16493	MEMBRECOM	2018-01-17 00:00:00	2018-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13805	2018-01-16 14:57:01	2018-01-25 13:16:40
16494	MEMBRECOM	2018-01-17 00:00:00	2018-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13806	2018-01-16 14:57:11	2018-01-25 13:17:38
16495	MEMBRECOM	2018-01-17 00:00:00	2018-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13807	2018-01-16 14:57:16	2018-02-02 10:12:16
16496	MEMBRECOM	2018-01-17 00:00:00	2018-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13808	2018-01-16 14:58:17	2018-02-02 09:30:09
16497	MEMBRECOM	2018-01-17 00:00:00	2018-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13809	2018-01-16 14:58:22	2018-01-25 13:14:16
16498	MEMBRECOM	2018-01-17 00:00:00	2018-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13810	2018-01-16 14:58:31	2018-02-02 09:30:09
16499	MEMBRECOM	2018-01-17 00:00:00	2018-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13811	2018-01-16 14:58:38	2018-02-02 09:30:09
16500	MEMBRECOM	2018-01-17 00:00:00	2018-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13812	2018-01-16 14:58:44	2018-01-25 13:14:43
16501	MEMBRECOM	2018-01-17 00:00:00	2018-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13813	2018-01-16 14:58:49	2018-02-02 09:30:09
16502	MEMBRECOM	2018-01-17 00:00:00	2018-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13814	2018-01-16 14:58:55	2018-01-25 13:15:12
16503	MEMBRECOM	2018-01-17 00:00:00	2018-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13815	2018-01-16 14:59:00	2018-01-25 13:16:16
16504	MEMBRECOM	2018-01-17 00:00:00	2018-01-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13816	2018-01-16 15:51:04	2018-01-31 11:39:35
16505	MEMBRECOM	2018-01-17 00:00:00	2018-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13817	2018-01-16 16:46:59	2018-02-02 09:30:09
16506	MEMBRECOM	2018-01-17 00:00:00	2018-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13818	2018-01-16 16:47:04	2018-01-25 13:11:23
16507	MEMBRECOM	2018-01-17 00:00:00	2018-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13819	2018-01-16 16:47:09	2018-02-02 09:30:09
16508	MEMBRECOM	2018-01-17 00:00:00	2018-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13820	2018-01-16 16:47:14	2018-02-02 09:30:09
16509	MEMBRECOM	2018-01-17 00:00:00	2018-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13821	2018-01-16 16:47:18	2018-02-02 09:30:09
16510	MEMBRECOM	2018-01-17 00:00:00	2018-01-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13822	2018-01-16 16:47:23	2018-01-25 13:12:51
16511	MEMBRECOM	2018-01-17 00:00:00	2018-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13823	2018-01-16 16:47:35	2018-01-25 13:17:19
16512	MEMBRECOM	2018-01-17 00:00:00	2018-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13824	2018-01-16 16:47:40	2018-02-02 09:30:09
16513	MEMBRECOM	2018-01-17 00:00:00	2018-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13825	2018-01-16 16:49:55	2018-02-02 09:30:09
16515	MEMBRECOM	2018-01-17 00:00:00	2018-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13827	2018-01-16 16:50:03	2018-01-25 13:15:43
16250	MEMBRECOM	2017-10-12 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10248	2017-10-16 15:00:07	\N
16251	SECRETCOM	2017-10-12 00:00:00	2020-10-06 00:00:00	15	ANCIEN	\N	\N	\N	\N	13550	2017-10-16 15:00:23	2017-10-16 15:00:27
16342	MEMBRECOM	2017-11-25 00:00:00	2017-11-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13663	2017-11-24 18:17:29	2017-11-28 15:56:05
16354	MEMBRECOM	2017-12-01 00:00:00	2017-12-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13675	2017-12-01 11:37:06	2017-12-07 10:05:49
16351	MEMBRECOM	2017-12-01 00:00:00	2017-12-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13672	2017-12-01 11:36:47	2017-12-07 10:05:49
16362	MEMBRECOM	2017-12-01 00:00:00	2017-12-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13683	2017-12-01 11:43:53	2017-12-07 10:05:57
16366	MEMBRECOM	2017-12-01 00:00:00	2017-12-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13687	2017-12-01 11:44:11	2017-12-07 10:05:57
16364	MEMBRECOM	2017-12-01 00:00:00	2017-12-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13685	2017-12-01 11:44:02	2017-12-07 10:05:57
16359	MEMBRECOM	2017-12-01 00:00:00	2017-12-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13680	2017-12-01 11:43:36	2017-12-07 10:05:57
16516	MEMBRECOM	2018-01-16 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13828	2018-01-16 00:00:00	\N
16517	MEMBRECOM	2018-01-16 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13829	2018-01-16 19:17:56	\N
16518	MEMBRECOM	2018-01-16 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13830	2018-01-16 00:00:00	\N
16519	MEMBRECOM	2018-01-16 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13831	2018-01-16 19:25:31	\N
16549	PDTCOM	2018-01-30 00:00:00	2018-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13782	2018-01-31 11:36:30	\N
16550	RAPCOM	2018-01-30 00:00:00	2018-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13773	2018-01-31 11:37:18	\N
16551	VICPDTCOM	2018-01-30 00:00:00	2018-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13816	2018-01-31 11:39:35	\N
16552	VICPDTCOM	2018-01-30 00:00:00	2018-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13787	2018-01-31 11:41:14	\N
16553	VICPDTCOM	2018-01-30 00:00:00	2018-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13781	2018-01-31 11:41:43	\N
16554	VICPDTCOM	2018-01-30 00:00:00	2018-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13788	2018-01-31 11:42:13	\N
16555	VICPDTCOM	2018-01-30 00:00:00	2018-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13784	2018-01-31 11:42:41	\N
16556	VICPDTCOM	2018-01-30 00:00:00	2018-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13789	2018-01-31 11:43:57	\N
16557	VICPDTCOM	2018-01-30 00:00:00	2018-02-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13777	2018-01-31 11:44:36	2018-02-07 11:35:41
16617	MEMBRECOM	2018-02-07 00:00:00	2018-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13904	2018-02-06 16:32:50	\N
16618	MEMBRECOM	2018-02-07 00:00:00	2018-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13905	2018-02-06 16:32:56	\N
16619	MEMBRECOM	2018-02-07 00:00:00	2018-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13906	2018-02-06 16:33:04	\N
16620	MEMBRECOM	2018-02-07 00:00:00	2018-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13907	2018-02-06 16:33:09	\N
16621	MEMBRECOM	2018-02-07 00:00:00	2018-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13908	2018-02-06 16:33:14	\N
16623	MEMBRECOM	2018-02-07 00:00:00	2018-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13910	2018-02-06 16:33:35	\N
16624	MEMBRECOM	2018-02-07 00:00:00	2018-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13911	2018-02-06 16:42:59	\N
16625	MEMBRECOM	2018-02-07 00:00:00	2018-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13912	2018-02-06 16:43:06	\N
16626	MEMBRECOM	2018-02-07 00:00:00	2018-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13913	2018-02-06 16:43:13	\N
16627	MEMBRECOM	2018-02-07 00:00:00	2018-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13914	2018-02-06 16:43:19	\N
16628	MEMBRECOM	2018-02-07 00:00:00	2018-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13915	2018-02-06 16:43:24	\N
16629	MEMBRECOM	2018-02-07 00:00:00	2018-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13916	2018-02-06 16:43:29	\N
16630	MEMBRECOM	2018-02-07 00:00:00	2018-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13917	2018-02-06 16:43:35	\N
16631	MEMBRECOM	2018-02-07 00:00:00	2018-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13918	2018-02-06 16:43:39	\N
16632	MEMBRECOM	2018-02-07 00:00:00	2018-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13919	2018-02-06 16:43:48	\N
16633	MEMBRECOM	2018-02-07 00:00:00	2018-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13920	2018-02-06 16:43:54	\N
16639	MEMBRECOM	2018-02-06 00:00:00	2018-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13926	2018-02-07 11:36:08	\N
16635	MEMBRECOM	2018-02-07 00:00:00	2018-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13922	2018-02-06 16:44:03	\N
16636	MEMBRECOM	2018-02-07 00:00:00	2018-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13923	2018-02-06 16:44:09	\N
16637	MEMBRECOM	2018-02-07 00:00:00	2018-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13924	2018-02-06 16:44:13	\N
16638	MEMBRECOM	2018-02-07 00:00:00	2018-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13925	2018-02-06 16:44:18	\N
16640	MEMBRECOM	2018-01-25 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13927	2018-02-08 13:07:48	2018-02-08 14:33:44
16641	MEMBRECOM	2018-02-07 00:00:00	2018-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13928	2018-02-14 10:47:30	2018-02-16 09:34:55
16642	MEMBRECOM	2018-02-07 00:00:00	2018-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13929	2018-02-14 10:47:35	2018-02-16 09:34:55
16643	MEMBRECOM	2018-02-07 00:00:00	2018-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13930	2018-02-14 10:47:41	2018-02-16 09:34:55
16644	MEMBRECOM	2018-02-07 00:00:00	2018-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13931	2018-02-14 10:47:46	2018-02-16 09:34:55
16645	MEMBRECOM	2018-02-07 00:00:00	2018-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13932	2018-02-14 10:47:54	2018-02-16 09:34:55
16646	MEMBRECOM	2018-02-07 00:00:00	2018-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13933	2018-02-14 10:48:02	2018-02-16 09:34:55
16647	MEMBRECOM	2018-02-07 00:00:00	2018-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13934	2018-02-14 10:48:07	2018-02-16 09:34:55
16648	MEMBRECOM	2018-02-07 00:00:00	2018-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13935	2018-02-14 10:48:15	2018-02-16 09:34:55
16649	MEMBRECOM	2018-02-07 00:00:00	2018-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13936	2018-02-14 10:48:23	2018-02-16 09:34:55
16650	MEMBRECOM	2018-02-07 00:00:00	2018-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13937	2018-02-14 10:48:31	2018-02-16 09:34:55
16651	MEMBRECOM	2018-02-07 00:00:00	2018-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13938	2018-02-14 10:48:38	2018-02-16 09:34:55
16652	MEMBRECOM	2018-02-07 00:00:00	2018-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13939	2018-02-14 10:48:45	2018-02-16 09:34:55
16653	MEMBRECOM	2018-02-07 00:00:00	2018-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13940	2018-02-14 10:48:53	2018-02-16 09:34:55
16654	MEMBRECOM	2018-02-07 00:00:00	2018-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13941	2018-02-14 10:49:02	2018-02-16 09:34:55
16655	MEMBRECOM	2018-02-07 00:00:00	2018-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13942	2018-02-14 10:53:03	2018-02-22 10:57:50
16656	MEMBRECOM	2018-02-07 00:00:00	2018-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13943	2018-02-14 10:53:10	2018-02-22 10:57:50
16657	MEMBRECOM	2018-02-07 00:00:00	2018-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13944	2018-02-14 10:53:15	2018-02-22 10:57:50
16658	MEMBRECOM	2018-02-07 00:00:00	2018-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13945	2018-02-14 10:53:19	2018-02-22 10:57:50
16659	MEMBRECOM	2018-02-07 00:00:00	2018-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13946	2018-02-14 10:53:24	2018-02-22 10:57:50
16660	MEMBRECOM	2018-02-07 00:00:00	2018-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13947	2018-02-14 10:53:30	2018-02-22 10:57:50
16661	MEMBRECOM	2018-02-07 00:00:00	2018-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13948	2018-02-14 10:53:35	2018-02-22 10:57:50
16663	MEMBRECOM	2018-02-07 00:00:00	2018-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13950	2018-02-14 10:54:15	2018-02-22 10:57:50
16664	MEMBRECOM	2018-02-07 00:00:00	2018-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13951	2018-02-14 10:54:23	2018-02-22 10:57:50
16665	MEMBRECOM	2018-02-07 00:00:00	2018-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13952	2018-02-14 10:54:30	2018-02-22 10:57:50
16666	MEMBRECOM	2018-02-07 00:00:00	2018-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13953	2018-02-14 10:54:40	2018-02-22 10:57:50
16667	MEMBRECOM	2018-02-07 00:00:00	2018-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13954	2018-02-14 10:54:44	2018-02-22 10:57:50
16668	MEMBRECOM	2018-02-07 00:00:00	2018-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13955	2018-02-14 10:54:49	2018-02-22 10:57:50
16669	MEMBRECOM	2018-02-07 00:00:00	2018-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13956	2018-02-14 10:54:54	2018-02-22 10:57:50
15722	MEMBRECOM	2017-10-04 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8074	2017-10-04 19:40:09	\N
15723	MEMBRECOM	2017-10-04 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2560	2017-10-04 19:40:15	\N
15724	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13372	2017-10-04 00:00:00	\N
15725	MEMBRECOM	2017-10-04 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4245	2017-10-04 19:40:28	\N
15726	MEMBRECOM	2017-10-04 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13373	2017-10-04 19:40:53	\N
15727	MEMBRECOM	2017-10-04 00:00:00	2018-09-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13374	2017-10-04 19:41:00	\N
15728	MEMBRECOM	2017-10-04 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4330	2017-10-04 19:41:07	\N
16234	MEMBRECOM	2017-10-04 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13439	2017-10-05 14:54:39	2017-10-05 14:55:26
15731	MEMBRECOM	2017-10-04 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10156	2017-10-04 19:42:00	\N
15733	MEMBRECOM	2017-10-04 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13376	2017-10-04 19:42:13	\N
15734	MEMBRECOM	2017-10-04 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13377	2017-10-04 19:42:14	\N
16548	MEMBRECOM	2018-01-24 00:00:00	2018-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13846	2018-01-31 09:48:22	2018-01-31 09:48:39
16603	MEMBRECOM	2018-01-31 00:00:00	2018-02-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13890	2018-02-06 12:22:27	2018-02-14 10:45:52
16604	MEMBRECOM	2018-01-31 00:00:00	2018-02-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13891	2018-02-06 12:22:32	2018-02-14 10:45:52
16605	MEMBRECOM	2018-01-31 00:00:00	2018-02-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13892	2018-02-06 12:22:37	2018-02-14 10:45:52
16606	MEMBRECOM	2018-01-31 00:00:00	2018-02-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13893	2018-02-06 12:22:42	2018-02-14 10:45:52
16607	MEMBRECOM	2018-01-31 00:00:00	2018-02-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13894	2018-02-06 12:22:47	2018-02-14 10:45:52
16608	MEMBRECOM	2018-01-31 00:00:00	2018-02-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13895	2018-02-06 12:22:51	2018-02-14 10:45:52
15745	MEMBRECOM	2017-10-04 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10185	2017-10-04 19:42:49	\N
16609	MEMBRECOM	2018-01-31 00:00:00	2018-02-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13896	2018-02-06 12:22:58	2018-02-14 10:45:52
15748	MEMBRECOM	2017-10-04 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8167	2017-10-04 19:42:59	\N
15749	MEMBRECOM	2017-10-04 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13380	2017-10-04 19:43:01	\N
15751	MEMBRECOM	2017-10-04 00:00:00	2020-08-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10139	2017-10-04 19:43:04	\N
16610	MEMBRECOM	2018-01-31 00:00:00	2018-02-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13897	2018-02-06 12:23:03	2018-02-14 10:45:52
15753	MEMBRECOM	2017-10-04 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13382	2017-10-04 19:43:11	\N
16611	MEMBRECOM	2018-01-31 00:00:00	2018-02-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13898	2018-02-06 12:23:09	2018-02-14 10:45:52
15755	MEMBRECOM	2017-10-04 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13383	2017-10-04 19:43:17	\N
15757	MEMBRECOM	2017-10-04 00:00:00	2018-11-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13385	2017-10-04 19:43:19	\N
16612	MEMBRECOM	2018-01-31 00:00:00	2018-02-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13899	2018-02-06 12:23:17	2018-02-14 10:45:52
15759	MEMBRECOM	2017-10-04 00:00:00	2021-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13386	2017-10-04 19:43:25	\N
15760	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13387	2017-10-04 00:00:00	\N
15762	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13388	2017-10-04 00:00:00	\N
16613	MEMBRECOM	2018-01-31 00:00:00	2018-02-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13900	2018-02-06 12:23:25	2018-02-14 10:45:52
15764	MEMBRECOM	2017-10-04 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10093	2017-10-04 19:43:38	\N
15765	MEMBRECOM	2017-10-04 00:00:00	2019-01-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13389	2017-10-04 19:43:39	\N
16614	MEMBRECOM	2018-01-31 00:00:00	2018-02-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13901	2018-02-06 12:23:33	2018-02-14 10:45:52
16615	MEMBRECOM	2018-01-31 00:00:00	2018-02-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13902	2018-02-06 12:23:41	2018-02-14 10:45:52
15769	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13391	2017-10-04 00:00:00	\N
15770	MEMBRECOM	2017-10-04 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13392	2017-10-04 19:43:52	\N
15771	MEMBRECOM	2017-10-04 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10188	2017-10-04 19:43:56	\N
15772	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13393	2017-10-04 00:00:00	\N
16616	MEMBRECOM	2018-01-31 00:00:00	2018-02-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13903	2018-02-06 12:23:48	2018-02-14 10:45:52
16670	MEMBRECOM	2018-02-22 00:00:00	2018-03-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13957	2018-02-22 10:59:20	2018-03-21 14:02:21
16671	MEMBRECOM	2018-02-22 00:00:00	2018-03-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13958	2018-02-22 10:59:26	2018-03-21 14:02:21
15777	MEMBRECOM	2017-10-04 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13394	2017-10-04 19:44:09	\N
15778	MEMBRECOM	2017-10-04 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13395	2017-10-04 19:44:09	\N
15780	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13397	2017-10-04 00:00:00	\N
15781	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13398	2017-10-04 00:00:00	\N
16672	MEMBRECOM	2018-02-22 00:00:00	2018-03-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13959	2018-02-22 10:59:30	2018-03-21 14:02:21
15784	MEMBRECOM	2017-10-04 00:00:00	2018-06-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8875	2017-10-04 19:44:22	2018-06-05 20:05:47
15785	MEMBRECOM	2017-10-04 00:00:00	2017-11-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13401	2017-10-04 19:44:26	2017-11-03 10:47:39
16673	MEMBRECOM	2018-02-22 00:00:00	2018-03-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13960	2018-02-22 10:59:35	2018-03-21 14:02:21
15788	MEMBRECOM	2017-10-04 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13403	2017-10-04 19:44:32	\N
16674	MEMBRECOM	2018-02-22 00:00:00	2018-03-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13961	2018-02-22 10:59:40	2018-03-21 14:02:21
15790	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13404	2017-10-04 00:00:00	\N
16675	MEMBRECOM	2018-02-22 00:00:00	2018-03-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13962	2018-02-22 10:59:46	2018-03-21 14:02:21
15793	MEMBRECOM	2017-10-04 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10189	2017-10-04 19:44:45	\N
15794	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13406	2017-10-04 00:00:00	\N
15796	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4252	2017-10-04 00:00:00	\N
16676	MEMBRECOM	2018-02-22 00:00:00	2018-03-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13963	2018-02-22 10:59:51	2018-03-21 14:02:21
15799	MEMBRECOM	2017-10-04 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13407	2017-10-04 19:44:59	\N
15800	MEMBRECOM	2017-10-04 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13408	2017-10-04 19:45:04	\N
15801	MEMBRECOM	2017-10-04 00:00:00	2017-11-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13409	2017-10-04 19:45:08	2017-11-24 23:59:34
15802	MEMBRECOM	2017-10-04 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10140	2017-10-04 19:45:08	\N
15804	MEMBRECOM	2017-10-04 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13410	2017-10-04 19:45:13	\N
16677	MEMBRECOM	2018-02-22 00:00:00	2018-03-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13964	2018-02-22 10:59:55	2018-03-21 14:02:21
16678	MEMBRECOM	2018-02-22 00:00:00	2018-03-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13965	2018-02-22 11:00:03	2018-03-21 14:02:21
15808	MEMBRECOM	2017-10-04 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13412	2017-10-04 19:45:24	\N
16679	MEMBRECOM	2018-02-22 00:00:00	2018-03-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13966	2018-02-22 11:00:11	2018-03-21 14:02:21
15810	MEMBRECOM	2017-10-04 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10141	2017-10-04 19:45:31	\N
16680	MEMBRECOM	2018-02-22 00:00:00	2018-03-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13967	2018-02-22 11:00:19	2018-03-21 14:02:21
16681	MEMBRECOM	2018-02-22 00:00:00	2018-03-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13968	2018-02-22 11:00:28	2018-03-21 14:02:21
16682	MEMBRECOM	2018-02-22 00:00:00	2018-03-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13969	2018-02-22 11:00:35	2018-03-21 14:02:21
16683	MEMBRECOM	2018-02-22 00:00:00	2018-03-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13970	2018-02-22 11:00:42	2018-03-21 14:02:21
15817	MEMBRECOM	2017-10-04 00:00:00	2022-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	740	2017-10-04 19:45:46	\N
16684	RAPCOM	2018-02-07 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13971	2018-02-23 16:12:59	2018-03-08 17:27:03
15821	MEMBRECOM	2017-10-04 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13417	2017-10-04 19:45:58	\N
15822	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13418	2017-10-04 00:00:00	\N
15825	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13419	2017-10-04 00:00:00	\N
15826	MEMBRECOM	2017-10-04 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13420	2017-10-04 19:46:13	\N
15828	MEMBRECOM	2017-10-04 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8747	2017-10-04 19:46:19	\N
15829	MEMBRECOM	2017-10-04 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2632	2017-10-04 19:46:22	2017-10-05 09:35:29
15831	MEMBRECOM	2017-10-04 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13422	2017-10-04 19:46:25	\N
15832	MEMBRECOM	2017-10-04 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13423	2017-10-04 19:46:29	\N
15833	MEMBRECOM	2017-10-04 00:00:00	2019-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8750	2017-10-04 19:46:33	\N
15835	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10193	2017-10-04 00:00:00	\N
15836	MEMBRECOM	2017-10-04 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13425	2017-10-04 19:46:37	\N
15839	MEMBRECOM	2017-10-04 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13426	2017-10-04 19:46:43	\N
15843	MEMBRECOM	2017-10-04 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13428	2017-10-04 19:46:52	\N
15847	MEMBRECOM	2017-10-04 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13430	2017-10-04 19:47:05	\N
15853	MEMBRECOM	2017-10-04 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13435	2017-10-04 19:48:33	\N
15855	MEMBRECOM	2017-10-04 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19	2017-10-04 19:48:46	\N
15856	MEMBRECOM	2017-10-04 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13437	2017-10-04 19:48:52	\N
15858	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13438	2017-10-04 00:00:00	\N
15860	MEMBRECOM	2017-10-04 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8201	2017-10-04 19:49:11	\N
15861	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10118	2017-10-04 00:00:00	\N
15863	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10119	2017-10-04 00:00:00	\N
15868	MEMBRECOM	2017-10-04 00:00:00	2021-07-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2597	2017-10-04 19:49:46	\N
15870	MEMBRECOM	2017-10-04 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8191	2017-10-04 19:49:52	\N
10374	MEMBRECOM	2012-02-21 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8726	\N	2017-10-04 19:01:41
16205	MEMBRECOM	2017-10-05 00:00:00	2018-04-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13552	2017-10-05 14:42:21	2018-04-05 09:46:46
16206	VICPDTCOM	2017-10-05 00:00:00	2020-10-06 00:00:00	11	ANCIEN	\N	\N	\N	\N	13553	2017-10-05 14:42:27	2017-10-05 17:56:42
15879	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8065	2017-10-04 00:00:00	\N
15880	MEMBRECOM	2017-10-04 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13441	2017-10-04 19:50:30	\N
15882	MEMBRECOM	2017-10-04 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13442	2017-10-04 19:50:36	\N
16219	PDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	1	ANCIEN	\N	\N	\N	\N	3944	2017-10-05 14:45:54	2017-10-05 14:46:03
16207	MEMBRECOM	2017-10-05 00:00:00	2019-04-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8252	2017-10-05 14:42:32	\N
16208	VICPDTCOM	2017-10-05 00:00:00	2020-10-06 00:00:00	7	ANCIEN	\N	\N	\N	\N	13554	2017-10-05 14:42:38	2017-10-05 17:56:18
16221	VICPDTCOM	2017-10-05 00:00:00	2020-09-30 00:00:00	3	ANCIEN	\N	\N	\N	\N	10131	2017-10-05 14:46:08	2017-10-05 14:46:14
16220	VICPDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	2	ANCIEN	\N	\N	\N	\N	12861	2017-10-05 14:46:00	2017-10-05 14:46:06
16070	MEMBRECOM	2017-10-04 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13531	2017-10-04 20:30:21	\N
15892	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13444	2017-10-04 00:00:00	\N
15894	MEMBRECOM	2017-10-04 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8184	2017-10-04 19:51:10	\N
15895	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13445	2017-10-04 00:00:00	\N
15896	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13446	2017-10-04 00:00:00	\N
15898	MEMBRECOM	2017-10-04 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4271	2017-10-04 19:51:20	\N
16209	MEMBRECOM	2017-10-05 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10237	2017-10-05 14:42:43	\N
15900	MEMBRECOM	2017-10-04 00:00:00	2019-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13447	2017-10-04 19:51:25	\N
15902	MEMBRECOM	2009-07-24 00:00:00	2009-07-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	843	2017-10-04 19:51:29	2017-10-24 16:15:15
16222	VICPDTCOM	2017-10-05 00:00:00	2018-11-13 00:00:00	4	ANCIEN	\N	\N	\N	\N	9930	2017-10-05 14:46:17	2017-10-05 14:46:41
15904	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13449	2017-10-04 00:00:00	\N
16223	VICPDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	4	ANCIEN	\N	\N	\N	\N	412	2017-10-05 14:46:52	2017-10-05 14:46:56
16210	SECRETCOM	2017-10-05 00:00:00	2019-07-24 00:00:00	15	ANCIEN	\N	\N	\N	\N	13555	2017-10-05 14:42:48	2017-10-05 17:57:05
16071	MEMBRECOM	2017-10-04 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13532	2017-10-04 20:30:26	\N
15908	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8151	2017-10-04 00:00:00	\N
16073	MEMBRECOM	2017-10-04 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13534	2017-10-04 20:30:42	\N
16231	SECRETCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	13	ANCIEN	\N	\N	\N	\N	2584	2017-10-05 14:49:11	2017-10-05 14:49:16
16224	VICPDTCOM	2017-10-05 00:00:00	2018-05-31 00:00:00	6	ANCIEN	\N	\N	\N	\N	13459	2017-10-05 14:47:06	2018-05-31 10:52:17
16074	MEMBRECOM	2017-10-04 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13535	2017-10-04 20:30:49	\N
15914	MEMBRECOM	2017-10-04 00:00:00	2019-07-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13452	2017-10-04 19:52:26	\N
15915	MEMBRECOM	2017-10-04 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13453	2017-10-04 19:52:35	\N
16211	MEMBRECOM	2017-10-05 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13556	2017-10-05 14:42:53	\N
16077	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8155	2017-10-04 00:00:00	\N
15918	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13454	2017-10-04 00:00:00	\N
15919	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13455	2017-10-04 00:00:00	\N
15920	MEMBRECOM	2017-10-04 00:00:00	2018-11-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13456	2017-10-04 19:53:04	\N
16080	MEMBRECOM	2017-10-04 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13538	2017-10-04 20:33:32	\N
16212	VICPDTCOM	2017-10-05 00:00:00	2020-10-06 00:00:00	8	ANCIEN	\N	\N	\N	\N	10238	2017-10-05 14:42:58	2017-10-05 17:56:51
15923	MEMBRECOM	2017-10-04 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13457	2017-10-04 19:53:14	\N
15924	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13458	2017-10-04 00:00:00	\N
16236	MEMBRECOM	2017-10-05 00:00:00	2017-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13559	2017-10-09 17:30:16	2017-10-10 10:43:53
16225	VICPDTCOM	2017-10-05 00:00:00	2019-07-09 00:00:00	5	ANCIEN	\N	\N	\N	\N	10080	2017-10-05 14:47:18	2017-10-05 14:47:25
16213	MEMBRECOM	2017-10-05 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13557	2017-10-05 14:43:07	\N
15873	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8004	2017-10-04 00:00:00	\N
15927	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10195	2017-10-04 00:00:00	\N
16214	VICPDTCOM	2017-10-05 00:00:00	2020-09-30 00:00:00	9	ANCIEN	\N	\N	\N	\N	4433	2017-10-05 14:43:13	2017-10-05 17:56:29
16215	MEMBRECOM	2017-10-05 00:00:00	2017-10-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13558	2017-10-05 14:43:18	2017-10-17 15:45:13
16232	SECRETCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	14	ANCIEN	\N	\N	\N	\N	7208	2017-10-05 14:49:21	2017-10-05 14:49:35
15930	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13460	2017-10-04 00:00:00	\N
15931	MEMBRECOM	2017-10-04 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13461	2017-10-04 19:53:44	\N
16226	VICPDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	6	ANCIEN	\N	\N	\N	\N	2530	2017-10-05 14:47:34	2017-10-05 14:47:39
15933	MEMBRECOM	2017-10-04 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13462	2017-10-04 19:53:49	\N
16216	PDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13530	2017-10-05 14:44:40	\N
15935	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10196	2017-10-04 00:00:00	\N
16227	VICPDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	7	ANCIEN	\N	\N	\N	\N	8126	2017-10-05 14:47:47	2017-10-05 14:47:53
16228	VICPDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	9	ANCIEN	\N	\N	\N	\N	10202	2017-10-05 14:48:02	2017-10-05 15:06:52
15938	MEMBRECOM	2017-10-04 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11414	2017-10-04 19:54:18	\N
15939	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10133	2017-10-04 00:00:00	\N
15940	MEMBRECOM	2017-10-04 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2589	2017-10-04 19:54:47	\N
15941	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13463	2017-10-04 00:00:00	\N
15942	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13464	2017-10-04 00:00:00	\N
16217	VICPDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11552	2017-10-05 14:44:50	\N
15944	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13466	2017-10-04 00:00:00	\N
15945	MEMBRECOM	2017-10-04 00:00:00	2018-07-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13467	2017-10-04 19:55:15	\N
15946	MEMBRECOM	2017-10-04 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4272	2017-10-04 19:55:18	\N
16218	RAPCOM	2017-10-05 00:00:00	2018-02-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13533	2017-10-05 14:44:56	2018-02-23 16:11:12
16229	VICPDTCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	10	ANCIEN	\N	\N	\N	\N	8156	2017-10-05 14:48:46	2017-10-05 14:48:51
16230	SECRETCOM	2017-10-05 00:00:00	2019-07-09 00:00:00	12	ANCIEN	\N	\N	\N	\N	13450	2017-10-05 14:49:00	2017-10-05 14:49:04
15950	MEMBRECOM	2017-10-04 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13469	2017-10-04 19:55:35	\N
16233	SECRETCOM	2017-10-05 00:00:00	2018-11-13 00:00:00	15	ANCIEN	\N	\N	\N	\N	13482	2017-10-05 14:49:40	2017-10-05 14:49:47
16237	MEMBRECOM	2017-10-05 00:00:00	2017-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13560	2017-10-09 17:30:25	2017-10-10 10:43:53
16238	MEMBRECOM	2017-10-05 00:00:00	2017-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13561	2017-10-09 17:30:30	2017-10-10 10:43:53
15954	MEMBRECOM	2017-10-04 00:00:00	2018-11-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10137	2017-10-04 19:55:45	\N
15955	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13470	2017-10-04 00:00:00	\N
16239	MEMBRECOM	2017-10-05 00:00:00	2017-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13562	2017-10-09 17:30:39	2017-10-10 10:43:53
16240	MEMBRECOM	2017-10-05 00:00:00	2017-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13563	2017-10-09 17:30:47	2017-10-10 10:43:53
15958	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13471	2017-10-04 00:00:00	\N
15959	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13472	2017-10-04 00:00:00	\N
15960	MEMBRECOM	2017-10-04 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13473	2017-10-04 19:56:01	\N
15961	MEMBRECOM	2017-10-04 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13474	2017-10-04 19:56:04	\N
15962	MEMBRECOM	2017-10-04 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13475	2017-10-04 19:56:07	\N
16241	MEMBRECOM	2017-10-05 00:00:00	2017-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13564	2017-10-09 17:34:41	2017-10-10 10:43:53
15964	MEMBRECOM	2017-10-04 00:00:00	2021-10-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13476	2017-10-04 19:56:13	\N
15965	MEMBRECOM	2017-10-04 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13477	2017-10-04 19:56:17	\N
16242	MEMBRECOM	2017-10-05 00:00:00	2017-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13565	2017-10-09 17:34:48	2017-10-10 10:43:53
16243	MEMBRECOM	2017-10-05 00:00:00	2017-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13566	2017-10-09 17:34:54	2017-10-10 10:43:53
16244	MEMBRECOM	2017-10-05 00:00:00	2017-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13567	2017-10-09 17:35:00	2017-10-10 10:43:53
15969	MEMBRECOM	2017-10-04 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13479	2017-10-04 19:56:30	\N
15970	MEMBRECOM	2017-10-04 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8846	2017-10-04 19:56:31	\N
15971	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13480	2017-10-04 00:00:00	\N
15974	MEMBRECOM	2017-10-04 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8702	2017-10-04 19:56:41	\N
15975	MEMBRECOM	2017-10-04 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13483	2017-10-04 19:56:47	\N
15976	MEMBRECOM	2017-10-04 00:00:00	2018-11-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13484	2017-10-04 19:56:51	\N
15978	MEMBRECOM	2017-10-04 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11502	2017-10-04 19:56:54	\N
15981	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13485	2017-10-04 00:00:00	\N
15982	MEMBRECOM	2017-10-04 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13486	2017-10-04 19:57:07	\N
15984	MEMBRECOM	2017-10-04 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13488	2017-10-04 19:57:12	\N
15985	MEMBRECOM	2017-10-04 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13489	2017-10-04 19:57:13	\N
15986	MEMBRECOM	2017-10-04 00:00:00	2019-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13490	2017-10-04 19:57:19	\N
15989	MEMBRECOM	2017-10-04 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10194	2017-10-04 19:57:27	\N
16235	RAPGENCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4318	2017-10-05 15:43:23	\N
15991	MEMBRECOM	2017-10-04 00:00:00	2020-02-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13491	2017-10-04 19:57:37	\N
15992	MEMBRECOM	2017-10-04 00:00:00	2022-09-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13492	2017-10-04 19:57:43	\N
15993	MEMBRECOM	2017-10-04 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8710	2017-10-04 19:57:47	\N
16245	MEMBRECOM	2017-10-05 00:00:00	2017-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13568	2017-10-09 17:35:20	2017-10-10 10:43:53
16246	MEMBRECOM	2017-10-05 00:00:00	2017-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13569	2017-10-09 17:35:25	2017-10-10 10:43:53
16247	MEMBRECOM	2017-10-05 00:00:00	2017-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13570	2017-10-09 17:35:30	2017-10-10 10:43:53
16248	MEMBRECOM	2017-10-05 00:00:00	2017-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13571	2017-10-09 17:35:36	2017-10-10 10:43:53
15998	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13493	2017-10-04 00:00:00	\N
15999	MEMBRECOM	2017-10-04 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13494	2017-10-04 19:58:22	\N
16249	MEMBRECOM	2017-10-05 00:00:00	2017-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13572	2017-10-09 17:35:41	2017-10-10 10:43:53
16004	MEMBRECOM	2017-10-04 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13497	2017-10-04 19:58:34	\N
16005	MEMBRECOM	2017-10-04 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13498	2017-10-04 19:58:39	\N
16299	MEMBRECOM	2017-11-20 00:00:00	2017-11-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13620	2017-11-20 10:43:18	2017-12-07 10:05:36
16008	MEMBRECOM	2017-10-04 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13500	2017-10-04 19:58:49	\N
16300	MEMBRECOM	2017-11-20 00:00:00	2017-11-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13621	2017-11-20 10:43:25	2017-12-07 10:05:36
16011	MEMBRECOM	2017-10-04 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13502	2017-10-04 19:59:02	\N
16301	MEMBRECOM	2017-11-20 00:00:00	2017-11-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13622	2017-11-20 10:43:30	2017-12-07 10:05:36
16019	MEMBRECOM	2017-10-04 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13504	2017-10-04 19:59:46	\N
16302	MEMBRECOM	2017-11-20 00:00:00	2017-11-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13623	2017-11-20 10:43:35	2017-12-07 10:05:36
16022	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13507	2017-10-04 00:00:00	\N
16024	MEMBRECOM	2017-10-04 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13508	2017-10-04 20:00:06	\N
16025	MEMBRECOM	2017-10-04 00:00:00	2018-11-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13509	2017-10-04 20:00:12	\N
16026	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13510	2017-10-04 00:00:00	\N
16303	MEMBRECOM	2017-11-20 00:00:00	2017-11-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13624	2017-11-20 10:43:40	2017-12-07 10:05:36
16304	MEMBRECOM	2017-11-20 00:00:00	2017-11-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13625	2017-11-20 10:43:45	2017-12-07 10:05:36
16305	MEMBRECOM	2017-11-20 00:00:00	2017-11-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13626	2017-11-20 10:43:49	2017-12-07 10:05:36
16306	MEMBRECOM	2017-11-20 00:00:00	2017-11-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13627	2017-11-20 10:43:54	2017-12-07 10:05:36
16307	MEMBRECOM	2017-11-20 00:00:00	2017-11-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13628	2017-11-20 10:44:02	2017-12-07 10:05:36
16308	MEMBRECOM	2017-11-20 00:00:00	2017-11-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13629	2017-11-20 10:44:12	2017-12-07 10:05:36
16309	MEMBRECOM	2017-11-20 00:00:00	2017-11-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13630	2017-11-20 10:44:20	2017-12-07 10:05:36
16310	MEMBRECOM	2017-11-20 00:00:00	2017-11-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13631	2017-11-20 10:44:27	2017-12-07 10:05:36
16311	MEMBRECOM	2017-11-20 00:00:00	2017-11-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13632	2017-11-20 10:44:34	2017-12-07 10:05:36
16312	MEMBRECOM	2017-11-20 00:00:00	2017-11-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13633	2017-11-20 10:44:42	2017-12-07 10:05:36
16376	VICPDTCOM	2017-11-29 00:00:00	2018-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13638	2017-12-01 14:42:21	\N
16377	VICPDTCOM	2017-11-29 00:00:00	2018-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13644	2017-12-01 14:43:04	2017-12-01 14:43:29
16378	VICPDTCOM	2017-11-29 00:00:00	2018-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13648	2017-12-01 14:44:22	\N
16379	VICPDTCOM	2017-11-29 00:00:00	2018-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13652	2017-12-01 14:44:57	\N
16380	VICPDTCOM	2017-11-29 00:00:00	2018-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13659	2017-12-01 14:45:33	\N
16381	VICPDTCOM	2017-11-29 00:00:00	2018-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13662	2017-12-01 14:46:12	\N
16396	MEMBRECOM	2017-12-07 00:00:00	2017-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13708	2017-12-08 15:34:34	2017-12-20 10:15:47
16397	MEMBRECOM	2017-12-07 00:00:00	2017-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13709	2017-12-08 15:34:40	2017-12-20 10:15:47
16398	MEMBRECOM	2017-12-07 00:00:00	2017-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13710	2017-12-08 15:34:49	2017-12-20 10:15:47
16399	MEMBRECOM	2017-12-07 00:00:00	2017-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13711	2017-12-08 15:34:53	2017-12-20 10:15:47
16400	MEMBRECOM	2017-12-07 00:00:00	2017-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13712	2017-12-08 15:34:58	2017-12-20 10:15:47
16401	MEMBRECOM	2017-12-07 00:00:00	2017-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13713	2017-12-08 15:35:02	2017-12-20 10:15:47
16402	MEMBRECOM	2017-12-07 00:00:00	2017-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13714	2017-12-08 15:35:08	2017-12-20 10:15:47
16403	MEMBRECOM	2017-12-07 00:00:00	2017-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13715	2017-12-08 15:35:12	2017-12-20 10:15:47
16404	MEMBRECOM	2017-12-07 00:00:00	2017-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13716	2017-12-08 15:35:21	2017-12-20 10:15:47
16405	MEMBRECOM	2017-12-07 00:00:00	2017-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13717	2017-12-08 15:35:25	2017-12-20 10:15:47
16406	MEMBRECOM	2017-12-07 00:00:00	2017-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13718	2017-12-08 15:35:29	2017-12-20 10:15:47
16407	MEMBRECOM	2017-12-07 00:00:00	2017-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13719	2017-12-08 15:35:34	2017-12-20 10:15:47
16408	MEMBRECOM	2017-12-07 00:00:00	2017-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13720	2017-12-08 15:35:38	2017-12-20 10:15:47
16409	MEMBRECOM	2017-12-07 00:00:00	2017-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13721	2017-12-08 15:35:44	2017-12-20 10:15:47
16410	MEMBRECOM	2017-12-07 00:00:00	2017-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13722	2017-12-08 15:38:42	2017-12-20 10:15:11
16411	MEMBRECOM	2017-12-07 00:00:00	2017-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13723	2017-12-08 15:38:49	2017-12-20 10:15:11
17295	VICPDTCOM	2018-10-11 00:00:00	2019-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14452	\N	\N
16412	MEMBRECOM	2017-12-07 00:00:00	2017-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13724	2017-12-08 15:38:54	2017-12-20 10:15:11
16413	MEMBRECOM	2017-12-07 00:00:00	2017-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13725	2017-12-08 15:38:59	2017-12-20 10:15:11
16414	MEMBRECOM	2017-12-07 00:00:00	2017-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13726	2017-12-08 15:39:06	2017-12-20 10:15:11
16415	MEMBRECOM	2017-12-07 00:00:00	2017-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13727	2017-12-08 15:39:10	2017-12-20 10:15:11
16416	MEMBRECOM	2017-12-07 00:00:00	2017-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13728	2017-12-08 15:39:16	2017-12-14 10:53:49
16417	MEMBRECOM	2017-12-07 00:00:00	2017-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13729	2017-12-08 15:39:24	2017-12-20 10:15:11
16418	MEMBRECOM	2017-12-07 00:00:00	2017-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13730	2017-12-08 15:39:29	2017-12-20 10:15:11
16419	MEMBRECOM	2017-12-07 00:00:00	2017-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13731	2017-12-08 15:39:34	2017-12-20 10:15:11
16420	MEMBRECOM	2017-12-07 00:00:00	2017-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13732	2017-12-08 15:39:41	2017-12-20 10:15:11
16421	MEMBRECOM	2017-12-07 00:00:00	2017-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13733	2017-12-08 15:39:46	2017-12-20 10:15:11
16422	MEMBRECOM	2017-12-07 00:00:00	2017-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13734	2017-12-08 15:39:53	2017-12-20 10:15:11
16423	MEMBRECOM	2017-12-07 00:00:00	2017-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13735	2017-12-08 15:39:58	2017-12-20 10:15:11
16439	MEMBRECOM	2017-12-18 00:00:00	2018-01-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13751	2017-12-18 14:31:40	2018-01-16 19:20:07
16441	MEMBRECOM	2017-12-18 00:00:00	2018-01-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13753	2017-12-18 14:52:08	2018-01-16 19:17:32
16534	VICPDTCOM	2018-01-24 00:00:00	2018-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13798	2018-01-25 13:09:09	2018-02-15 17:54:51
16535	PDTCOM	2018-01-24 00:00:00	2018-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13797	2018-01-25 13:09:37	2018-02-02 09:30:09
16536	VICPDTCOM	2018-01-24 00:00:00	2018-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13818	2018-01-25 13:11:23	2018-02-02 09:30:09
16537	VICPDTCOM	2018-01-24 00:00:00	2018-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13794	2018-01-25 13:12:05	2018-02-02 09:30:09
16538	VICPDTCOM	2018-01-24 00:00:00	2018-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13822	2018-01-25 13:12:42	2018-02-02 09:30:09
16539	VICPDTCOM	2018-01-24 00:00:00	2018-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13799	2018-01-25 13:13:43	2018-02-02 09:30:09
16540	VICPDTCOM	2018-01-24 00:00:00	2018-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13809	2018-01-25 13:14:16	2018-02-02 09:30:09
16541	VICPDTCOM	2018-01-24 00:00:00	2018-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13812	2018-01-25 13:14:43	2018-02-02 09:30:09
16542	VICPDTCOM	2018-01-24 00:00:00	2018-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13814	2018-01-25 13:15:12	2018-02-02 09:30:09
16543	VICPDTCOM	2018-01-24 00:00:00	2018-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13827	2018-01-25 13:15:43	2018-02-02 09:30:09
16544	VICPDTCOM	2018-01-24 00:00:00	2018-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13815	2018-01-25 13:16:16	2018-02-02 09:30:09
16545	SECRETCOM	2018-01-24 00:00:00	2018-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13805	2018-01-25 13:16:40	2018-02-02 09:30:09
16546	SECRETCOM	2018-01-24 00:00:00	2018-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13823	2018-01-25 13:17:19	2018-02-02 09:30:09
16547	SECRETCOM	2018-01-24 00:00:00	2018-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13806	2018-01-25 13:17:38	2018-02-02 09:30:09
12324	VICPDTCOM	2014-10-13 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4742	2014-10-13 11:49:05	2017-10-05 11:42:49
12326	VICPDTCOM	2014-10-13 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4433	2014-10-13 11:49:18	2017-10-05 11:42:51
12333	SECRETCOM	2014-10-13 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4746	2014-10-13 11:51:14	2017-10-05 11:42:52
12144	MEMBRECOM	2014-10-09 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10231	2014-10-09 09:39:20	2017-10-05 11:42:53
12205	MEMBRECOM	2014-10-09 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10247	2014-10-09 11:08:47	2017-10-05 11:42:54
12147	MEMBRECOM	2014-10-09 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10234	2014-10-09 09:39:55	2017-10-05 11:42:56
14239	MEMBRECOM	2016-04-26 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12092	2016-04-26 14:12:08	2017-10-05 11:42:57
12152	MEMBRECOM	2014-10-09 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10239	2014-10-09 09:41:00	2017-10-05 11:43:00
9873	MEMBRECOM	2011-10-01 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8254	\N	2017-10-05 11:43:01
16252	MEMBRECOM	2017-10-17 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13573	2017-10-17 15:45:33	\N
16254	MEMBRECOM	2017-11-03 00:00:00	2017-11-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13575	2017-11-03 10:52:37	2017-11-07 16:24:40
16270	MEMBRECOM	2017-11-09 00:00:00	2017-11-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13591	2017-11-09 18:38:17	2017-11-20 10:47:06
16271	MEMBRECOM	2017-11-09 00:00:00	2017-11-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13592	2017-11-09 18:38:24	2017-11-20 10:47:06
16272	MEMBRECOM	2017-11-09 00:00:00	2017-11-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13593	2017-11-09 18:39:23	2017-11-20 10:47:06
16273	MEMBRECOM	2017-11-09 00:00:00	2017-11-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13594	2017-11-09 18:39:29	2017-11-20 10:47:06
16274	MEMBRECOM	2017-11-09 00:00:00	2017-11-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13595	2017-11-09 18:39:34	2017-11-20 10:47:06
16275	MEMBRECOM	2017-11-09 00:00:00	2017-11-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13596	2017-11-09 18:39:40	2017-11-20 10:47:06
16291	MEMBRECOM	2017-11-15 00:00:00	2017-11-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13612	2017-11-16 10:16:39	2017-12-07 10:05:16
16277	MEMBRECOM	2017-11-09 00:00:00	2017-11-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13598	2017-11-09 18:40:00	2017-11-20 10:47:06
16278	MEMBRECOM	2017-11-09 00:00:00	2017-11-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13599	2017-11-09 18:40:05	2017-11-20 10:47:06
16279	MEMBRECOM	2017-11-09 00:00:00	2017-11-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13600	2017-11-09 18:40:09	2017-11-20 10:47:06
16280	MEMBRECOM	2017-11-09 00:00:00	2017-11-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13601	2017-11-09 18:40:14	2017-11-20 10:47:06
16281	MEMBRECOM	2017-11-09 00:00:00	2017-11-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13602	2017-11-09 18:40:18	2017-11-20 10:47:06
16282	MEMBRECOM	2017-11-09 00:00:00	2017-11-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13603	2017-11-09 18:40:24	2017-11-20 10:47:06
16283	MEMBRECOM	2017-11-09 00:00:00	2017-11-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13604	2017-11-09 18:40:29	2017-11-20 10:47:06
16284	MEMBRECOM	2017-11-09 00:00:00	2017-11-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13605	2017-11-09 18:40:34	2017-11-20 10:47:06
16285	MEMBRECOM	2017-11-15 00:00:00	2017-11-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13606	2017-11-16 10:16:04	2017-12-07 10:05:16
17296	VICPDTCOM	2018-10-11 00:00:00	2019-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14441	\N	\N
16286	MEMBRECOM	2017-11-15 00:00:00	2017-11-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13607	2017-11-16 10:16:10	2017-12-07 10:05:16
16287	MEMBRECOM	2017-11-15 00:00:00	2017-11-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13608	2017-11-16 10:16:17	2017-12-07 10:05:16
16288	MEMBRECOM	2017-11-15 00:00:00	2017-11-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13609	2017-11-16 10:16:22	2017-12-07 10:05:16
16289	MEMBRECOM	2017-11-15 00:00:00	2017-11-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13610	2017-11-16 10:16:29	2017-12-07 10:05:16
16290	MEMBRECOM	2017-11-15 00:00:00	2017-11-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13611	2017-11-16 10:16:34	2017-12-07 10:05:16
16292	MEMBRECOM	2017-11-15 00:00:00	2017-11-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13613	2017-11-16 10:16:44	2017-12-07 10:05:16
16293	MEMBRECOM	2017-11-15 00:00:00	2017-11-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13614	2017-11-16 10:18:36	2017-12-07 10:05:16
16294	MEMBRECOM	2017-11-15 00:00:00	2017-11-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13615	2017-11-16 10:18:43	2017-12-07 10:05:16
16295	MEMBRECOM	2017-11-15 00:00:00	2017-11-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13616	2017-11-16 10:18:47	2017-12-07 10:05:16
16296	MEMBRECOM	2017-11-15 00:00:00	2017-11-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13617	2017-11-16 10:18:52	2017-12-07 10:05:16
16297	MEMBRECOM	2017-11-15 00:00:00	2017-11-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13618	2017-11-16 10:18:56	2017-12-07 10:05:16
16298	MEMBRECOM	2017-11-15 00:00:00	2017-11-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13619	2017-11-16 10:19:01	2017-12-07 10:05:16
16315	MEMBRECOM	2017-11-22 00:00:00	2017-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13636	2017-11-21 15:45:25	2017-12-01 14:26:41
16326	MEMBRECOM	2017-11-22 00:00:00	2018-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13647	2017-11-21 15:46:39	\N
16317	MEMBRECOM	2017-11-22 00:00:00	2017-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13638	2017-11-21 15:45:38	2017-12-01 14:41:55
16318	MEMBRECOM	2017-11-22 00:00:00	2017-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13639	2017-11-21 15:45:43	2017-12-01 14:25:48
16319	MEMBRECOM	2017-11-22 00:00:00	2017-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13640	2017-11-21 15:45:50	2017-12-01 14:23:06
16320	MEMBRECOM	2017-11-22 00:00:00	2018-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13641	2017-11-21 15:46:07	\N
16321	MEMBRECOM	2017-11-22 00:00:00	2018-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13642	2017-11-21 15:46:12	\N
16322	MEMBRECOM	2017-11-22 00:00:00	2018-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13643	2017-11-21 15:46:19	\N
16323	MEMBRECOM	2017-11-22 00:00:00	2017-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13644	2017-11-21 15:46:23	2017-12-01 14:43:29
16324	MEMBRECOM	2017-11-22 00:00:00	2018-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13645	2017-11-21 15:46:29	\N
16325	MEMBRECOM	2017-11-22 00:00:00	2018-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13646	2017-11-21 15:46:34	\N
16327	MEMBRECOM	2017-11-22 00:00:00	2017-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13648	2017-11-21 15:46:44	2017-12-01 14:44:00
16328	MEMBRECOM	2017-11-22 00:00:00	2018-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13649	2017-11-21 15:46:51	\N
16329	MEMBRECOM	2017-11-22 00:00:00	2017-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13650	2017-11-21 15:46:56	2017-12-20 13:59:56
16330	MEMBRECOM	2017-11-22 00:00:00	2018-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13651	2017-11-21 15:47:02	\N
16331	MEMBRECOM	2017-11-22 00:00:00	2017-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13652	2017-11-21 15:47:13	2017-12-01 14:44:43
16332	MEMBRECOM	2017-11-22 00:00:00	2018-01-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13653	2017-11-21 15:47:18	2018-01-31 09:47:00
16333	MEMBRECOM	2017-11-22 00:00:00	2018-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13654	2017-11-21 15:47:22	\N
16335	MEMBRECOM	2017-11-22 00:00:00	2018-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13656	2017-11-21 15:47:37	\N
16336	MEMBRECOM	2017-11-22 00:00:00	2018-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13657	2017-11-21 15:47:42	\N
16337	MEMBRECOM	2017-11-22 00:00:00	2018-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13658	2017-11-21 15:47:47	\N
16338	MEMBRECOM	2017-11-22 00:00:00	2017-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13659	2017-11-21 15:47:52	2017-12-01 14:45:19
16339	MEMBRECOM	2017-11-22 00:00:00	2018-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13660	2017-11-21 15:47:56	\N
16340	MEMBRECOM	2017-11-22 00:00:00	2018-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13661	2017-11-21 15:48:02	\N
16341	MEMBRECOM	2017-11-22 00:00:00	2017-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13662	2017-11-21 15:48:09	2017-12-01 14:45:54
16345	MEMBRECOM	2017-12-01 00:00:00	2017-12-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13666	2017-12-01 11:36:11	2017-12-07 10:05:49
16346	MEMBRECOM	2017-12-01 00:00:00	2017-12-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13667	2017-12-01 11:36:16	2017-12-07 10:05:49
16347	MEMBRECOM	2017-12-01 00:00:00	2017-12-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13668	2017-12-01 11:36:22	2017-12-07 10:05:49
16348	MEMBRECOM	2017-12-01 00:00:00	2017-12-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13669	2017-12-01 11:36:27	2017-12-07 10:05:49
16349	MEMBRECOM	2017-12-01 00:00:00	2017-12-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13670	2017-12-01 11:36:31	2017-12-07 10:05:49
16350	MEMBRECOM	2017-12-01 00:00:00	2017-12-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13671	2017-12-01 11:36:41	2017-12-07 10:05:49
16352	MEMBRECOM	2017-12-01 00:00:00	2017-12-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13673	2017-12-01 11:36:54	2017-12-07 10:05:49
16353	MEMBRECOM	2017-12-01 00:00:00	2017-12-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13674	2017-12-01 11:37:00	2017-12-07 10:05:49
16355	MEMBRECOM	2017-12-01 00:00:00	2017-12-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13676	2017-12-01 11:37:11	2017-12-07 10:05:49
16356	MEMBRECOM	2017-12-01 00:00:00	2017-12-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13677	2017-12-01 11:37:15	2017-12-07 10:05:49
16357	MEMBRECOM	2017-12-01 00:00:00	2017-12-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13678	2017-12-01 11:37:20	2017-12-07 10:05:49
16358	MEMBRECOM	2017-12-01 00:00:00	2017-12-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13679	2017-12-01 11:43:31	2017-12-07 10:05:57
16360	MEMBRECOM	2017-12-01 00:00:00	2017-12-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13681	2017-12-01 11:43:42	2017-12-07 10:05:57
16361	MEMBRECOM	2017-12-01 00:00:00	2017-12-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13682	2017-12-01 11:43:47	2017-12-07 10:05:57
16363	MEMBRECOM	2017-12-01 00:00:00	2017-12-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13684	2017-12-01 11:43:58	2017-12-07 10:05:57
16365	MEMBRECOM	2017-12-01 00:00:00	2017-12-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13686	2017-12-01 11:44:06	2017-12-07 10:05:57
16367	MEMBRECOM	2017-12-01 00:00:00	2017-12-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13688	2017-12-01 11:44:15	2017-12-07 10:05:57
16368	MEMBRECOM	2017-12-01 00:00:00	2017-12-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13689	2017-12-01 11:44:23	2017-12-07 10:05:57
16369	MEMBRECOM	2017-12-01 00:00:00	2017-12-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13690	2017-12-01 11:44:27	2017-12-07 10:05:57
16370	MEMBRECOM	2017-12-01 00:00:00	2017-12-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13691	2017-12-01 11:44:32	2017-12-07 10:05:57
16255	MEMBRECOM	2017-11-07 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13576	2017-11-07 00:00:00	\N
16343	MEMBRECOM	2017-11-28 00:00:00	2018-01-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13664	2017-11-28 15:56:04	2018-01-16 19:24:26
16371	MEMBRECOM	2017-12-01 00:00:00	2017-12-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13692	2017-12-01 11:44:37	2017-12-07 10:05:57
16375	VICPDTCOM	2017-11-29 00:00:00	2018-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13636	2017-12-01 14:27:03	\N
16373	PDTCOM	2017-11-29 00:00:00	2018-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13693	2017-12-01 14:23:39	\N
16374	RAPCOM	2017-11-29 00:00:00	2018-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13639	2017-12-01 14:26:15	\N
16425	MEMBRECOM	2017-12-14 00:00:00	2017-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13737	2017-12-18 09:21:26	2017-12-20 10:16:50
16426	MEMBRECOM	2017-12-14 00:00:00	2017-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13738	2017-12-18 09:21:41	2017-12-20 10:16:50
16427	MEMBRECOM	2017-12-14 00:00:00	2017-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13739	2017-12-18 09:21:46	2017-12-20 10:16:50
16428	MEMBRECOM	2017-12-14 00:00:00	2017-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13740	2017-12-18 09:21:51	2017-12-20 10:16:50
16429	MEMBRECOM	2017-12-14 00:00:00	2017-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13741	2017-12-18 09:21:56	2017-12-20 10:16:50
16430	MEMBRECOM	2017-12-14 00:00:00	2017-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13742	2017-12-18 09:22:01	2017-12-20 10:16:50
16431	MEMBRECOM	2017-12-14 00:00:00	2017-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13743	2017-12-18 09:22:07	2017-12-20 10:16:50
16432	MEMBRECOM	2017-12-14 00:00:00	2017-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13744	2017-12-18 09:22:12	2017-12-20 10:16:50
16433	MEMBRECOM	2017-12-14 00:00:00	2017-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13745	2017-12-18 09:22:16	2017-12-20 10:16:50
16434	MEMBRECOM	2017-12-14 00:00:00	2017-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13746	2017-12-18 09:22:21	2017-12-20 10:16:50
16435	MEMBRECOM	2017-12-14 00:00:00	2017-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13747	2017-12-18 09:22:26	2017-12-20 10:16:50
16436	MEMBRECOM	2017-12-14 00:00:00	2017-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13748	2017-12-18 09:22:32	2017-12-20 10:16:50
16437	MEMBRECOM	2017-12-14 00:00:00	2017-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13749	2017-12-18 09:22:37	2017-12-20 10:16:50
16438	MEMBRECOM	2017-12-14 00:00:00	2017-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13750	2017-12-18 09:22:41	2017-12-20 10:16:50
16440	MEMBRECOM	2017-12-18 00:00:00	2018-01-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13752	2017-12-18 14:43:34	2018-01-16 19:14:10
16442	MEMBRECOM	2017-12-19 00:00:00	2017-12-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13754	2017-12-20 10:09:29	2017-12-20 10:16:57
16443	MEMBRECOM	2017-12-19 00:00:00	2017-12-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13755	2017-12-20 10:09:34	2017-12-20 10:16:57
16444	MEMBRECOM	2017-12-19 00:00:00	2017-12-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13756	2017-12-20 10:09:40	2017-12-20 10:16:57
16445	MEMBRECOM	2017-12-19 00:00:00	2017-12-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13757	2017-12-20 10:09:45	2017-12-20 10:16:57
16446	MEMBRECOM	2017-12-19 00:00:00	2017-12-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13758	2017-12-20 10:09:51	2017-12-20 10:16:57
16447	MEMBRECOM	2017-12-19 00:00:00	2017-12-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13759	2017-12-20 10:10:00	2017-12-20 10:16:57
16457	MEMBRECOM	2017-12-19 00:00:00	2018-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13769	2017-12-20 13:58:45	2017-12-20 13:59:06
16449	MEMBRECOM	2017-12-19 00:00:00	2017-12-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13761	2017-12-20 10:11:17	2017-12-20 10:16:57
16450	MEMBRECOM	2017-12-19 00:00:00	2017-12-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13762	2017-12-20 10:11:27	2017-12-20 10:16:57
16451	MEMBRECOM	2017-12-19 00:00:00	2017-12-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13763	2017-12-20 10:11:37	2017-12-20 10:16:57
16452	MEMBRECOM	2017-12-19 00:00:00	2017-12-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13764	2017-12-20 10:11:42	2017-12-20 10:16:57
16453	MEMBRECOM	2017-12-19 00:00:00	2017-12-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13765	2017-12-20 10:11:47	2017-12-20 10:16:57
16454	MEMBRECOM	2017-12-19 00:00:00	2017-12-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13766	2017-12-20 10:11:53	2017-12-20 10:16:57
16455	MEMBRECOM	2017-12-19 00:00:00	2017-12-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13767	2017-12-20 10:12:00	2017-12-20 10:16:57
16456	MEMBRECOM	2017-12-19 00:00:00	2017-12-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13768	2017-12-20 10:12:05	2017-12-20 10:16:57
16520	MEMBRECOM	2018-01-24 00:00:00	2018-02-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13832	2018-01-24 17:41:42	2018-02-06 12:25:06
16521	MEMBRECOM	2018-01-24 00:00:00	2018-02-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13833	2018-01-24 17:41:46	2018-02-06 12:25:06
16522	MEMBRECOM	2018-01-24 00:00:00	2018-02-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13834	2018-01-24 17:41:50	2018-02-06 12:25:06
16523	MEMBRECOM	2018-01-24 00:00:00	2018-02-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13835	2018-01-24 17:41:57	2018-02-06 12:25:06
16524	MEMBRECOM	2018-01-24 00:00:00	2018-02-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13836	2018-01-24 17:42:02	2018-02-06 12:25:06
16525	MEMBRECOM	2018-01-24 00:00:00	2018-02-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13837	2018-01-24 17:42:06	2018-02-06 12:25:06
16526	MEMBRECOM	2018-01-24 00:00:00	2018-02-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13838	2018-01-24 17:42:12	2018-02-06 12:25:06
16527	MEMBRECOM	2018-01-24 00:00:00	2018-02-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13839	2018-01-24 17:42:17	2018-02-06 12:25:06
16528	MEMBRECOM	2018-01-24 00:00:00	2018-02-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13840	2018-01-24 17:42:22	2018-02-06 12:25:06
16529	MEMBRECOM	2018-01-24 00:00:00	2018-02-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13841	2018-01-24 17:42:27	2018-02-06 12:25:06
16530	MEMBRECOM	2018-01-24 00:00:00	2018-02-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13842	2018-01-24 17:42:31	2018-02-06 12:25:06
16531	MEMBRECOM	2018-01-24 00:00:00	2018-02-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13843	2018-01-24 17:42:36	2018-02-06 12:25:06
16532	MEMBRECOM	2018-01-24 00:00:00	2018-02-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13844	2018-01-24 17:42:40	2018-02-06 12:25:06
16533	MEMBRECOM	2018-01-24 00:00:00	2018-02-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13845	2018-01-24 17:42:45	2018-02-06 12:25:06
16489	MEMBRECOM	2018-01-17 00:00:00	2018-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13801	2018-01-16 14:56:40	2018-02-02 09:30:09
16558	MEMBRECOM	2018-01-31 00:00:00	2018-08-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13847	2018-02-02 09:38:52	2018-02-02 10:09:55
16559	VICPDTCOM	2018-01-31 00:00:00	2018-08-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13848	2018-02-02 09:39:05	2018-02-02 10:07:29
16560	MEMBRECOM	2018-01-31 00:00:00	2018-08-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13849	2018-02-02 09:39:12	\N
16561	MEMBRECOM	2018-01-31 00:00:00	2018-08-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13850	2018-02-02 09:39:23	\N
16562	MEMBRECOM	2018-01-31 00:00:00	2018-08-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13851	2018-02-02 09:39:29	\N
16563	VICPDTCOM	2018-01-31 00:00:00	2018-08-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13852	2018-02-02 09:39:34	2018-02-02 10:15:13
16564	VICPDTCOM	2018-01-31 00:00:00	2018-08-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13853	2018-02-02 09:39:45	2018-02-02 10:07:38
16565	MEMBRECOM	2018-01-31 00:00:00	2018-08-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13854	2018-02-02 09:39:49	\N
16566	VICPDTCOM	2018-01-31 00:00:00	2018-08-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13855	2018-02-02 09:39:55	2018-02-02 10:15:01
16567	MEMBRECOM	2018-01-31 00:00:00	2018-08-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13856	2018-02-02 09:40:37	\N
16568	MEMBRECOM	2018-01-31 00:00:00	2018-08-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13857	2018-02-02 09:40:48	\N
16599	VICPDTCOM	2018-01-31 00:00:00	2018-08-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13886	2018-02-02 10:29:18	2018-02-02 10:29:21
16570	MEMBRECOM	2018-01-31 00:00:00	2018-08-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13859	2018-02-02 09:41:02	\N
16571	MEMBRECOM	2018-01-31 00:00:00	2018-08-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13860	2018-02-02 09:41:09	\N
16602	VICPDTCOM	2018-01-31 00:00:00	2018-08-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13889	2018-02-02 10:39:32	\N
16573	RAPCOM	2018-01-31 00:00:00	2018-08-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13862	2018-02-02 09:41:22	2018-02-02 09:55:36
16574	MEMBRECOM	2018-01-31 00:00:00	2018-08-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13863	2018-02-02 09:41:29	\N
16596	RAPCOM	2018-01-31 00:00:00	2018-08-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13868	2018-02-02 09:56:17	2018-02-02 10:33:59
16600	VICPDTCOM	2018-01-31 00:00:00	2018-08-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13887	2018-02-02 10:36:55	\N
16578	VICPDTCOM	2018-01-31 00:00:00	2018-08-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13867	2018-02-02 09:41:49	2018-02-02 10:31:05
16597	VICPDTCOM	2018-01-31 00:00:00	2018-08-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13884	2018-02-02 10:20:53	\N
16580	MEMBRECOM	2018-01-31 00:00:00	2018-08-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13869	2018-02-02 09:41:59	\N
16581	MEMBRECOM	2018-01-31 00:00:00	2018-08-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13870	2018-02-02 09:42:05	\N
16582	MEMBRECOM	2018-01-31 00:00:00	2018-08-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13871	2018-02-02 09:42:11	\N
16584	MEMBRECOM	2018-01-31 00:00:00	2018-08-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13873	2018-02-02 09:43:26	\N
16585	MEMBRECOM	2018-01-31 00:00:00	2018-08-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13874	2018-02-02 09:43:32	\N
16586	MEMBRECOM	2018-01-31 00:00:00	2018-08-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13875	2018-02-02 09:43:38	\N
16587	SECRETCOM	2018-01-31 00:00:00	2018-08-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13876	2018-02-02 09:43:50	2018-02-02 10:33:42
16588	MEMBRECOM	2018-01-31 00:00:00	2018-08-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13877	2018-02-02 09:43:58	\N
16589	MEMBRECOM	2018-01-31 00:00:00	2018-08-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13878	2018-02-02 09:44:04	\N
16590	MEMBRECOM	2018-01-31 00:00:00	2018-08-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13879	2018-02-02 09:44:12	\N
16591	SECRETCOM	2018-01-31 00:00:00	2018-08-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13880	2018-02-02 09:44:17	2018-02-02 10:13:31
16592	MEMBRECOM	2018-01-31 00:00:00	2018-08-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13881	2018-02-02 09:44:23	\N
16593	SECRETCOM	2018-01-31 00:00:00	2018-08-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13882	2018-02-02 09:44:27	2018-02-02 10:31:26
16595	PDTCOM	2018-01-31 00:00:00	2018-08-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13883	2018-02-02 09:53:31	2018-02-02 09:54:35
16601	VICPDTCOM	2018-01-31 00:00:00	2018-08-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13888	2018-02-02 10:38:14	\N
16790	MEMBRECOM	2018-04-04 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14068	2018-04-05 09:49:39	\N
12751	MEMBRECOM	2014-11-20 00:00:00	2018-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10699	\N	2018-05-31 10:52:17
10046	MEMBRECOM	2011-12-19 00:00:00	2018-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8400	\N	2018-05-31 10:52:17
9391	MEMBRECOM	2011-06-27 00:00:00	2018-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7879	\N	2018-05-31 10:52:17
3629	MEMBRECOM	2004-12-14 00:00:00	2018-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2717	\N	2018-05-31 10:52:17
9017	MEMBRECOM	2010-12-07 00:00:00	2018-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7517	\N	2018-05-31 10:52:17
16940	MEMBRECOM	2018-06-01 00:00:00	2018-06-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14209	2018-05-31 11:00:21	2018-06-05 20:09:48
16958	MEMBRECOM	2018-06-19 00:00:00	2018-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14227	\N	\N
16959	MEMBRECOM	2018-06-19 00:00:00	2018-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14228	\N	\N
16960	MEMBRECOM	2018-06-19 00:00:00	2018-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14229	\N	\N
16961	MEMBRECOM	2018-06-19 00:00:00	2018-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14230	\N	\N
17041	PDTCOM	2018-06-28 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14260	\N	\N
16963	MEMBRECOM	2018-06-19 00:00:00	2018-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14232	\N	\N
16964	MEMBRECOM	2018-06-19 00:00:00	2018-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14233	\N	\N
16965	MEMBRECOM	2018-06-19 00:00:00	2018-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14234	\N	\N
16966	MEMBRECOM	2018-06-19 00:00:00	2018-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14235	\N	\N
16967	MEMBRECOM	2018-06-19 00:00:00	2018-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14236	\N	\N
16968	MEMBRECOM	2018-06-19 00:00:00	2018-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14237	\N	\N
16969	MEMBRECOM	2018-06-19 00:00:00	2018-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14238	\N	\N
16970	MEMBRECOM	2018-06-19 00:00:00	2018-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14239	\N	\N
16971	MEMBRECOM	2018-06-19 00:00:00	2018-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14240	\N	\N
16972	MEMBRECOM	2018-06-19 00:00:00	2018-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14241	\N	\N
17042	RAPCOM	2018-06-28 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14277	\N	\N
17043	VICPDTCOM	2018-06-28 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14264	\N	\N
17044	VICPDTCOM	2018-06-28 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14268	\N	\N
17045	VICPDTCOM	2018-06-28 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14263	\N	\N
17046	VICPDTCOM	2018-06-28 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14274	\N	\N
17047	VICPDTCOM	2018-06-28 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14278	\N	\N
17048	VICPDTCOM	2018-06-28 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14273	\N	\N
17049	VICPDTCOM	2018-06-28 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14258	\N	\N
17130	MEMBRECOM	2018-09-14 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14389	\N	\N
17131	MEMBRECOM	2018-09-14 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14390	\N	\N
17132	VICPDTCOM	2018-09-19 00:00:00	2020-10-05 00:00:00	2	ANCIEN	\N	\N	\N	\N	13374	\N	\N
17289	PDTCOM	2018-10-11 00:00:00	2019-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14433	\N	\N
17290	VICPDTCOM	2018-10-11 00:00:00	2019-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14522	\N	\N
17291	VICPDTCOM	2018-10-11 00:00:00	2019-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14449	\N	\N
17292	VICPDTCOM	2018-10-11 00:00:00	2019-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14438	\N	\N
17293	VICPDTCOM	2018-10-11 00:00:00	2019-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14440	\N	\N
17294	VICPDTCOM	2018-10-11 00:00:00	2019-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14458	\N	\N
11204	MEMBRECOM	2013-06-05 00:00:00	2018-12-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9448	\N	\N
13839	MEMBRECOM	2015-10-26 00:00:00	2018-12-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11695	\N	\N
17477	MEMBRECOM	2018-12-31 00:00:00	2019-01-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14665	\N	\N
17536	MEMBRECOM	2019-01-30 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14722	\N	\N
17537	MEMBRECOM	2019-01-30 00:00:00	2019-02-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14723	\N	\N
17538	MEMBRECOM	2019-01-30 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14724	\N	\N
17539	MEMBRECOM	2019-01-30 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14725	\N	\N
17540	MEMBRECOM	2019-01-30 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14726	\N	\N
17541	MEMBRECOM	2019-01-30 00:00:00	2019-02-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14727	\N	\N
17542	MEMBRECOM	2019-01-30 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14728	\N	\N
17543	MEMBRECOM	2019-01-30 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14729	\N	\N
17544	MEMBRECOM	2019-01-30 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14730	\N	\N
17545	MEMBRECOM	2019-01-30 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14731	\N	\N
17546	MEMBRECOM	2019-01-30 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14732	\N	\N
17547	MEMBRECOM	2019-01-30 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14733	\N	\N
17548	MEMBRECOM	2019-01-30 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14734	\N	\N
17549	MEMBRECOM	2019-01-30 00:00:00	2019-01-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14735	\N	\N
17550	MEMBRECOM	2019-01-30 00:00:00	2019-02-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14736	\N	\N
17551	MEMBRECOM	2019-01-30 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14737	\N	\N
17552	MEMBRECOM	2019-01-30 00:00:00	2019-02-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14738	\N	\N
17553	MEMBRECOM	2019-01-30 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14739	\N	\N
17554	MEMBRECOM	2019-01-30 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14740	\N	\N
17555	MEMBRECOM	2019-01-30 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14741	\N	\N
17556	MEMBRECOM	2019-01-30 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14742	\N	\N
17557	MEMBRECOM	2019-01-30 00:00:00	2019-02-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14743	\N	\N
17558	MEMBRECOM	2019-01-30 00:00:00	2019-02-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14744	\N	\N
17559	MEMBRECOM	2019-01-30 00:00:00	2019-02-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14745	\N	\N
17560	MEMBRECOM	2019-01-30 00:00:00	2019-02-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14746	\N	\N
17643	PDTCOM	2019-04-02 00:00:00	2019-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14793	\N	\N
17644	RAPCOM	2019-04-02 00:00:00	2019-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14776	\N	\N
17645	VICPDTCOM	2019-04-02 00:00:00	2019-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14771	\N	\N
17646	VICPDTCOM	2019-04-02 00:00:00	2019-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14772	\N	\N
17647	VICPDTCOM	2019-04-02 00:00:00	2019-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14778	\N	\N
17648	VICPDTCOM	2019-04-02 00:00:00	2019-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14781	\N	\N
17649	VICPDTCOM	2019-04-02 00:00:00	2019-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14782	\N	\N
17650	VICPDTCOM	2019-04-02 00:00:00	2019-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14785	\N	\N
17651	VICPDTCOM	2019-04-02 00:00:00	2019-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14794	\N	\N
17652	MEMBRECOM	2019-04-03 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14823	\N	\N
8020	VICPDTCOM	2009-02-11 00:00:00	2009-02-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6588	\N	2014-09-28 18:58:21
8032	MEMBRECOM	2009-02-11 00:00:00	2009-02-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6600	\N	\N
7976	MEMBRECOM	2008-12-19 00:00:00	2008-12-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6544	\N	\N
5021	MEMBRECOM	2008-07-18 00:00:00	2008-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4106	\N	\N
4878	MEMBRECOM	2008-05-14 00:00:00	2008-05-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3965	\N	\N
4849	MEMBRECOM	2008-01-31 00:00:00	2008-02-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3934	\N	\N
4694	MEMBRECOM	2007-11-16 00:00:00	2007-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3775	\N	\N
4360	MEMBRECOM	2006-12-19 00:00:00	2006-12-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3441	\N	\N
4340	RAPCOM	2006-12-14 00:00:00	2006-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3421	\N	\N
4662	MEMBRECOM	2007-07-31 00:00:00	2007-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3746	\N	\N
4471	MEMBRECOM	2007-02-01 00:00:00	2007-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3553	\N	\N
4442	MEMBRECOM	2007-01-25 00:00:00	2007-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3524	\N	\N
4310	MEMBRECOM	2006-11-17 00:00:00	2006-11-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3391	\N	\N
4253	MEMBRECOM	2006-06-16 00:00:00	2006-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3334	\N	\N
4967	VICPDTCOM	2008-07-10 00:00:00	2008-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4052	\N	\N
4500	MEMBRECOM	2007-02-12 00:00:00	2007-02-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3582	\N	\N
4988	MEMBRECOM	2008-07-09 00:00:00	2008-07-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4073	\N	\N
4472	MEMBRECOM	2007-02-01 00:00:00	2007-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3554	\N	\N
17671	MEMBRECOM	2019-04-10 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14842	\N	\N
17672	MEMBRECOM	2019-04-10 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14843	\N	\N
17673	MEMBRECOM	2019-04-10 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14844	\N	\N
17656	MEMBRECOM	2019-04-10 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14827	\N	\N
17657	MEMBRECOM	2019-04-10 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14828	\N	\N
17658	MEMBRECOM	2019-04-10 00:00:00	2019-05-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14829	\N	\N
17659	MEMBRECOM	2019-04-10 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14830	\N	\N
17660	MEMBRECOM	2019-04-10 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14831	\N	\N
17661	MEMBRECOM	2019-04-10 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14832	\N	\N
17662	MEMBRECOM	2019-04-10 00:00:00	2019-05-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14833	\N	\N
17663	MEMBRECOM	2019-04-10 00:00:00	2019-05-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14834	\N	\N
17664	MEMBRECOM	2019-04-10 00:00:00	2019-05-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14835	\N	\N
17665	MEMBRECOM	2019-04-10 00:00:00	2019-05-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14836	\N	\N
17666	MEMBRECOM	2019-04-10 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14837	\N	\N
17667	MEMBRECOM	2019-04-10 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14838	\N	\N
17668	MEMBRECOM	2019-04-10 00:00:00	2019-05-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14839	\N	\N
17669	MEMBRECOM	2019-04-10 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14840	\N	\N
17670	MEMBRECOM	2019-04-10 00:00:00	2019-05-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14841	\N	\N
16990	MEMBRECOM	2018-06-27 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14259	\N	\N
16991	MEMBRECOM	2018-06-27 00:00:00	2018-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14260	\N	\N
16989	MEMBRECOM	2018-06-27 00:00:00	2018-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14258	\N	\N
16992	MEMBRECOM	2018-06-27 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14261	\N	\N
16993	MEMBRECOM	2018-06-27 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14262	\N	\N
16994	MEMBRECOM	2018-06-27 00:00:00	2018-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14263	\N	\N
16995	MEMBRECOM	2018-06-27 00:00:00	2018-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14264	\N	\N
16996	MEMBRECOM	2018-06-27 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14265	\N	\N
16997	MEMBRECOM	2018-06-27 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14266	\N	\N
16998	MEMBRECOM	2018-06-27 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14267	\N	\N
16999	MEMBRECOM	2018-06-27 00:00:00	2018-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14268	\N	\N
17000	MEMBRECOM	2018-06-27 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14269	\N	\N
17001	MEMBRECOM	2018-06-27 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14270	\N	\N
17002	MEMBRECOM	2018-06-27 00:00:00	2018-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14271	\N	\N
17003	MEMBRECOM	2018-06-27 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14272	\N	\N
17004	MEMBRECOM	2018-06-27 00:00:00	2018-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14273	\N	\N
17005	MEMBRECOM	2018-06-27 00:00:00	2018-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14274	\N	\N
17006	MEMBRECOM	2018-06-27 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14275	\N	\N
17007	MEMBRECOM	2018-06-27 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14276	\N	\N
17008	MEMBRECOM	2018-06-27 00:00:00	2018-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14277	\N	\N
17010	VICPDTCOM	2018-06-27 00:00:00	2020-10-05 00:00:00	8	ANCIEN	\N	\N	\N	\N	14210	\N	\N
17056	MEMBRECOM	2018-07-03 00:00:00	2018-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14315	\N	\N
17057	MEMBRECOM	2018-07-03 00:00:00	2018-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14316	\N	\N
17058	MEMBRECOM	2018-07-03 00:00:00	2018-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14317	\N	\N
17059	MEMBRECOM	2018-07-03 00:00:00	2018-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14318	\N	\N
17060	MEMBRECOM	2018-07-03 00:00:00	2018-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14319	\N	\N
17061	MEMBRECOM	2018-07-03 00:00:00	2018-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14320	\N	\N
17062	MEMBRECOM	2018-07-03 00:00:00	2018-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14321	\N	\N
17063	MEMBRECOM	2018-07-03 00:00:00	2018-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14322	\N	\N
17064	MEMBRECOM	2018-07-03 00:00:00	2018-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14323	\N	\N
17065	MEMBRECOM	2018-07-03 00:00:00	2018-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14324	\N	\N
17066	MEMBRECOM	2018-07-03 00:00:00	2018-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14325	\N	\N
17067	MEMBRECOM	2018-07-03 00:00:00	2018-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14326	\N	\N
17068	MEMBRECOM	2018-07-03 00:00:00	2018-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14327	\N	\N
17069	MEMBRECOM	2018-07-03 00:00:00	2018-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14328	\N	\N
17070	MEMBRECOM	2018-07-13 00:00:00	2018-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14329	\N	\N
17071	MEMBRECOM	2018-07-13 00:00:00	2018-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14330	\N	\N
17072	MEMBRECOM	2018-07-13 00:00:00	2018-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14331	\N	\N
17073	MEMBRECOM	2018-07-13 00:00:00	2018-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14332	\N	\N
17074	MEMBRECOM	2018-07-13 00:00:00	2018-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14333	\N	\N
17075	MEMBRECOM	2018-07-13 00:00:00	2018-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14334	\N	\N
17076	MEMBRECOM	2018-07-13 00:00:00	2018-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14335	\N	\N
17077	MEMBRECOM	2018-07-13 00:00:00	2018-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14336	\N	\N
17078	MEMBRECOM	2018-07-13 00:00:00	2018-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14337	\N	\N
17079	MEMBRECOM	2018-07-13 00:00:00	2018-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14338	\N	\N
17080	MEMBRECOM	2018-07-13 00:00:00	2018-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14339	\N	\N
17081	MEMBRECOM	2018-07-13 00:00:00	2018-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14340	\N	\N
17082	MEMBRECOM	2018-07-13 00:00:00	2018-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14341	\N	\N
17083	MEMBRECOM	2018-07-13 00:00:00	2018-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14342	\N	\N
17084	MEMBRECOM	2018-07-10 00:00:00	2018-07-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14343	\N	\N
17085	MEMBRECOM	2018-07-10 00:00:00	2018-07-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14344	\N	\N
17086	MEMBRECOM	2018-07-10 00:00:00	2018-07-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14345	\N	\N
17087	MEMBRECOM	2018-07-10 00:00:00	2018-07-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14346	\N	\N
17088	MEMBRECOM	2018-07-10 00:00:00	2018-07-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14347	\N	\N
17089	MEMBRECOM	2018-07-10 00:00:00	2018-07-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14348	\N	\N
17090	MEMBRECOM	2018-07-10 00:00:00	2018-07-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14349	\N	\N
17091	MEMBRECOM	2018-07-10 00:00:00	2018-07-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14350	\N	\N
17092	MEMBRECOM	2018-07-10 00:00:00	2018-07-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14351	\N	\N
17093	MEMBRECOM	2018-07-10 00:00:00	2018-07-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14352	\N	\N
17094	MEMBRECOM	2018-07-10 00:00:00	2018-07-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14353	\N	\N
17095	MEMBRECOM	2018-07-10 00:00:00	2018-07-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14354	\N	\N
17096	MEMBRECOM	2018-07-10 00:00:00	2018-07-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14355	\N	\N
17097	MEMBRECOM	2018-07-10 00:00:00	2018-07-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14356	\N	\N
17384	MEMBRECOM	2018-11-20 00:00:00	2018-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14577	\N	\N
17505	MEMBRECOM	2019-01-16 00:00:00	2019-01-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14693	\N	\N
17506	MEMBRECOM	2019-01-16 00:00:00	2019-01-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14694	\N	\N
17507	MEMBRECOM	2019-01-16 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14695	\N	\N
17508	MEMBRECOM	2019-01-16 00:00:00	2019-01-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14696	\N	\N
17509	MEMBRECOM	2019-01-16 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14697	\N	\N
17510	MEMBRECOM	2019-01-16 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14698	\N	\N
17511	MEMBRECOM	2019-01-16 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14699	\N	\N
17512	MEMBRECOM	2019-01-16 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14700	\N	\N
17513	MEMBRECOM	2019-01-16 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14701	\N	\N
17514	MEMBRECOM	2019-01-16 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14702	\N	\N
17515	MEMBRECOM	2019-01-16 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14703	\N	\N
17516	MEMBRECOM	2019-01-16 00:00:00	2019-01-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14704	\N	\N
17517	MEMBRECOM	2019-01-16 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14705	\N	\N
17518	MEMBRECOM	2019-01-16 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14706	\N	\N
17519	MEMBRECOM	2019-01-16 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14707	\N	\N
17520	MEMBRECOM	2019-01-16 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14708	\N	\N
17521	MEMBRECOM	2019-01-16 00:00:00	2019-01-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14709	\N	\N
17522	MEMBRECOM	2019-01-16 00:00:00	2019-01-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14710	\N	\N
17523	MEMBRECOM	2019-01-16 00:00:00	2019-01-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14711	\N	\N
17524	MEMBRECOM	2019-01-16 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14712	\N	\N
17525	MEMBRECOM	2019-01-16 00:00:00	2019-01-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14713	\N	\N
17526	MEMBRECOM	2019-01-16 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14714	\N	\N
17527	MEMBRECOM	2019-01-16 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14715	\N	\N
17528	MEMBRECOM	2019-01-16 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14716	\N	\N
17529	MEMBRECOM	2019-01-16 00:00:00	2019-01-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14717	\N	\N
17530	MEMBRECOM	2019-01-16 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14718	\N	\N
17531	MEMBRECOM	2019-01-16 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14719	\N	\N
17533	MEMBRECOM	2018-12-06 00:00:00	2020-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14006	\N	\N
17566	MEMBRECOM	2019-02-12 00:00:00	2019-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14750	\N	\N
17567	MEMBRECOM	2019-02-12 00:00:00	2019-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14751	\N	\N
17568	MEMBRECOM	2019-02-12 00:00:00	2019-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14752	\N	\N
17569	MEMBRECOM	2019-02-12 00:00:00	2019-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14753	\N	\N
17570	MEMBRECOM	2019-02-12 00:00:00	2019-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14754	\N	\N
17571	MEMBRECOM	2019-02-12 00:00:00	2019-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14755	\N	\N
17572	MEMBRECOM	2019-02-12 00:00:00	2019-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14756	\N	\N
17573	MEMBRECOM	2019-02-12 00:00:00	2019-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14757	\N	\N
17574	MEMBRECOM	2019-02-12 00:00:00	2019-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14758	\N	\N
17575	MEMBRECOM	2019-02-12 00:00:00	2019-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14759	\N	\N
17576	MEMBRECOM	2019-02-12 00:00:00	2019-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14760	\N	\N
17577	MEMBRECOM	2019-02-12 00:00:00	2019-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14761	\N	\N
17578	MEMBRECOM	2019-02-12 00:00:00	2019-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14762	\N	\N
17579	MEMBRECOM	2019-02-12 00:00:00	2019-02-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14763	\N	\N
17613	SECRETCOM	2019-03-29 00:00:00	2020-10-05 00:00:00	4	ANCIEN	\N	\N	\N	\N	11436	\N	\N
17614	VICPDTCOM	2019-03-29 00:00:00	2020-10-05 00:00:00	6	ANCIEN	\N	\N	\N	\N	7751	\N	\N
17674	MEMBRECOM	2019-04-10 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14845	\N	\N
17675	MEMBRECOM	2019-04-10 00:00:00	2019-05-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14846	\N	\N
17676	MEMBRECOM	2019-04-10 00:00:00	2019-05-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14847	\N	\N
17677	MEMBRECOM	2019-04-30 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14848	\N	\N
17678	MEMBRECOM	2019-04-30 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14849	\N	\N
17679	MEMBRECOM	2019-04-30 00:00:00	2019-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14850	\N	\N
17680	MEMBRECOM	2019-04-30 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14851	\N	\N
17681	MEMBRECOM	2019-04-30 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14852	\N	\N
17685	MEMBRECOM	2019-04-30 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14856	\N	\N
17683	MEMBRECOM	2019-04-30 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14854	\N	\N
17684	MEMBRECOM	2019-04-30 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14855	\N	\N
17686	MEMBRECOM	2019-04-30 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14857	\N	\N
17687	MEMBRECOM	2019-04-30 00:00:00	2019-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14858	\N	\N
17688	MEMBRECOM	2019-04-30 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14859	\N	\N
17689	MEMBRECOM	2019-04-30 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14860	\N	\N
17690	MEMBRECOM	2019-04-30 00:00:00	2019-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14861	\N	\N
17691	MEMBRECOM	2019-04-30 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14862	\N	\N
17692	MEMBRECOM	2019-04-30 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14863	\N	\N
17693	MEMBRECOM	2019-04-30 00:00:00	2019-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14864	\N	\N
17694	MEMBRECOM	2019-04-30 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14865	\N	\N
17695	MEMBRECOM	2019-04-30 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14866	\N	\N
17696	MEMBRECOM	2019-04-30 00:00:00	2019-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14867	\N	\N
17697	MEMBRECOM	2019-04-30 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14868	\N	\N
17698	MEMBRECOM	2019-04-30 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14869	\N	\N
17699	MEMBRECOM	2019-04-30 00:00:00	2019-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14870	\N	\N
17700	MEMBRECOM	2019-04-30 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14871	\N	\N
17701	MEMBRECOM	2019-04-30 00:00:00	2019-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14872	\N	\N
16726	MEMBRECOM	2018-03-14 00:00:00	2018-03-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14013	2018-03-13 16:56:38	2018-03-22 12:01:04
16727	MEMBRECOM	2018-03-14 00:00:00	2018-03-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14014	2018-03-13 16:56:46	2018-03-22 12:04:25
16728	MEMBRECOM	2018-03-14 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14015	2018-03-13 16:56:53	\N
16729	MEMBRECOM	2018-03-14 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14016	2018-03-13 16:56:58	\N
16730	MEMBRECOM	2018-03-14 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14017	2018-03-13 16:57:08	\N
16731	MEMBRECOM	2018-03-14 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14018	2018-03-13 16:57:13	\N
16732	MEMBRECOM	2018-03-14 00:00:00	2018-03-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14019	2018-03-13 16:57:19	2018-03-22 12:05:21
16733	MEMBRECOM	2018-03-14 00:00:00	2018-03-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14020	2018-03-13 16:57:24	2018-03-22 12:07:22
16734	MEMBRECOM	2018-03-14 00:00:00	2018-03-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14021	2018-03-13 16:57:29	2018-03-22 12:07:57
16735	MEMBRECOM	2018-03-14 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14022	2018-03-13 16:57:35	\N
16736	MEMBRECOM	2018-03-14 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14023	2018-03-13 16:57:42	\N
16737	MEMBRECOM	2018-03-14 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14024	2018-03-13 16:57:47	\N
16738	MEMBRECOM	2018-03-14 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14025	2018-03-13 16:57:55	\N
16739	MEMBRECOM	2018-03-14 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14026	2018-03-13 16:58:01	\N
16740	MEMBRECOM	2018-03-14 00:00:00	2018-03-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14027	2018-03-13 16:58:07	2018-03-22 12:09:25
16741	MEMBRECOM	2018-03-14 00:00:00	2018-03-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14028	2018-03-13 16:58:13	2018-03-22 12:11:03
16742	MEMBRECOM	2018-03-14 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14029	2018-03-13 16:58:19	\N
16743	MEMBRECOM	2018-03-14 00:00:00	2018-05-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14030	2018-03-13 16:58:25	2018-05-30 15:33:57
16744	MEMBRECOM	2018-03-14 00:00:00	2018-04-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14031	2018-03-13 16:58:31	2018-04-10 16:18:44
16745	MEMBRECOM	2018-03-14 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14032	2018-03-13 16:58:50	\N
16746	MEMBRECOM	2018-03-14 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14033	2018-03-13 16:58:56	\N
16747	MEMBRECOM	2018-03-14 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14034	2018-03-13 16:59:01	\N
16748	MEMBRECOM	2018-03-14 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14035	2018-03-13 16:59:08	\N
16749	MEMBRECOM	2018-03-14 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14036	2018-03-13 16:59:14	\N
16750	MEMBRECOM	2018-03-14 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14037	2018-03-13 16:59:19	\N
17344	MEMBRECOM	2018-10-31 00:00:00	2018-11-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14554	\N	\N
16751	MEMBRECOM	2018-03-14 00:00:00	2018-03-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14038	2018-03-13 16:59:24	2018-03-22 12:11:32
16752	MEMBRECOM	2018-03-14 00:00:00	2018-03-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14039	2018-03-13 16:59:29	2018-03-22 12:00:39
16941	MEMBRECOM	2018-06-05 00:00:00	2018-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14210	2018-06-05 20:06:03	\N
16938	MEMBRECOM	2018-05-30 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14207	2018-05-30 15:37:08	\N
16942	MEMBRECOM	2018-06-05 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14211	2018-06-05 20:07:04	\N
16943	MEMBRECOM	2018-06-05 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14212	2018-06-05 00:00:00	\N
17197	MEMBRECOM	2018-10-10 00:00:00	2019-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14455	\N	\N
17198	MEMBRECOM	2018-10-10 00:00:00	2018-11-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14456	\N	\N
17199	MEMBRECOM	2018-10-10 00:00:00	2019-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14457	\N	\N
17200	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14458	\N	\N
17201	MEMBRECOM	2018-10-10 00:00:00	2019-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14459	\N	\N
17202	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14460	\N	\N
17203	MEMBRECOM	2018-10-10 00:00:00	2019-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14461	\N	\N
17204	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14462	\N	\N
17205	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14463	\N	\N
17206	MEMBRECOM	2018-10-10 00:00:00	2018-11-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14464	\N	\N
17207	MEMBRECOM	2018-10-10 00:00:00	2018-11-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14465	\N	\N
17208	MEMBRECOM	2018-10-10 00:00:00	2018-11-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14466	\N	\N
17209	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14467	\N	\N
17210	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14468	\N	\N
17211	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14469	\N	\N
17212	MEMBRECOM	2018-10-10 00:00:00	2018-11-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14470	\N	\N
17213	MEMBRECOM	2018-10-10 00:00:00	2018-11-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14471	\N	\N
17214	MEMBRECOM	2018-10-10 00:00:00	2018-11-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14472	\N	\N
17215	MEMBRECOM	2018-10-10 00:00:00	2018-11-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14473	\N	\N
17216	MEMBRECOM	2018-10-10 00:00:00	2018-11-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14474	\N	\N
17217	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14475	\N	\N
17218	MEMBRECOM	2018-10-10 00:00:00	2018-11-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14476	\N	\N
17219	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14477	\N	\N
17220	MEMBRECOM	2018-10-10 00:00:00	2018-11-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14478	\N	\N
17221	MEMBRECOM	2018-10-10 00:00:00	2018-11-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14479	\N	\N
17222	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14480	\N	\N
17223	MEMBRECOM	2018-10-10 00:00:00	2018-11-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14481	\N	\N
17224	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14482	\N	\N
17225	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14483	\N	\N
17226	MEMBRECOM	2018-10-10 00:00:00	2018-11-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14484	\N	\N
17227	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14485	\N	\N
17228	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14486	\N	\N
17229	MEMBRECOM	2018-10-10 00:00:00	2018-11-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14487	\N	\N
17230	MEMBRECOM	2018-10-10 00:00:00	2018-11-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14488	\N	\N
17231	MEMBRECOM	2018-10-10 00:00:00	2018-11-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14489	\N	\N
17232	MEMBRECOM	2018-10-10 00:00:00	2018-11-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14490	\N	\N
17233	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14491	\N	\N
17234	MEMBRECOM	2018-10-10 00:00:00	2019-05-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14492	\N	\N
17235	MEMBRECOM	2018-10-10 00:00:00	2019-05-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14493	\N	\N
17236	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14494	\N	\N
17237	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14495	\N	\N
17238	MEMBRECOM	2018-10-10 00:00:00	2019-05-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14496	\N	\N
17239	MEMBRECOM	2018-10-10 00:00:00	2019-05-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14497	\N	\N
17240	MEMBRECOM	2018-10-10 00:00:00	2019-05-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14498	\N	\N
17241	MEMBRECOM	2018-10-10 00:00:00	2019-05-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14499	\N	\N
17242	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14500	\N	\N
17243	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14501	\N	\N
17244	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14502	\N	\N
17245	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14503	\N	\N
17246	MEMBRECOM	2018-10-10 00:00:00	2019-05-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14504	\N	\N
17247	MEMBRECOM	2018-10-10 00:00:00	2019-05-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14505	\N	\N
17248	MEMBRECOM	2018-10-10 00:00:00	2019-05-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14506	\N	\N
17249	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14507	\N	\N
17250	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14508	\N	\N
17251	MEMBRECOM	2018-10-10 00:00:00	2019-05-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14509	\N	\N
17252	MEMBRECOM	2018-10-10 00:00:00	2019-05-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14510	\N	\N
17253	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14511	\N	\N
17254	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14512	\N	\N
17255	MEMBRECOM	2018-10-10 00:00:00	2019-05-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14513	\N	\N
17256	MEMBRECOM	2018-10-10 00:00:00	2019-05-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14514	\N	\N
17257	MEMBRECOM	2018-10-10 00:00:00	2019-05-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14515	\N	\N
17258	MEMBRECOM	2018-10-10 00:00:00	2019-05-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14516	\N	\N
17259	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14517	\N	\N
17260	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14518	\N	\N
17261	MEMBRECOM	2018-10-10 00:00:00	2019-05-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14519	\N	\N
17262	MEMBRECOM	2018-10-10 00:00:00	2019-05-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14520	\N	\N
17263	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14521	\N	\N
17337	MEMBRECOM	2018-10-31 00:00:00	2018-11-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14547	\N	\N
17338	MEMBRECOM	2018-10-31 00:00:00	2019-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14548	\N	\N
17339	MEMBRECOM	2018-10-31 00:00:00	2019-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14549	\N	\N
17340	MEMBRECOM	2018-10-31 00:00:00	2019-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14550	\N	\N
17341	MEMBRECOM	2018-10-31 00:00:00	2018-11-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14551	\N	\N
17342	MEMBRECOM	2018-10-31 00:00:00	2018-11-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14552	\N	\N
17343	MEMBRECOM	2018-10-31 00:00:00	2019-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14553	\N	\N
17345	MEMBRECOM	2018-10-31 00:00:00	2018-11-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14555	\N	\N
17346	MEMBRECOM	2018-10-31 00:00:00	2018-11-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14556	\N	\N
17347	MEMBRECOM	2018-10-31 00:00:00	2019-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14557	\N	\N
17348	MEMBRECOM	2018-10-31 00:00:00	2019-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14558	\N	\N
17349	MEMBRECOM	2018-10-31 00:00:00	2018-11-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14559	\N	\N
17350	MEMBRECOM	2018-10-31 00:00:00	2018-11-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14560	\N	\N
17351	MEMBRECOM	2018-10-31 00:00:00	2019-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14561	\N	\N
17352	MEMBRECOM	2018-10-31 00:00:00	2019-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14562	\N	\N
17353	MEMBRECOM	2018-10-31 00:00:00	2019-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14563	\N	\N
17354	MEMBRECOM	2018-10-31 00:00:00	2019-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14564	\N	\N
17355	MEMBRECOM	2018-10-31 00:00:00	2019-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14565	\N	\N
17356	MEMBRECOM	2018-10-31 00:00:00	2018-11-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14566	\N	\N
17357	MEMBRECOM	2018-10-31 00:00:00	2019-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14567	\N	\N
17358	MEMBRECOM	2018-10-31 00:00:00	2019-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14568	\N	\N
17359	MEMBRECOM	2018-10-31 00:00:00	2019-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14569	\N	\N
17360	MEMBRECOM	2018-10-31 00:00:00	2019-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14570	\N	\N
17361	MEMBRECOM	2018-10-31 00:00:00	2018-11-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14571	\N	\N
17362	MEMBRECOM	2018-10-31 00:00:00	2019-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14572	\N	\N
17363	MEMBRECOM	2018-10-31 00:00:00	2018-11-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14573	\N	\N
16944	MEMBRECOM	2018-06-07 00:00:00	2018-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14213	2018-06-07 17:07:24	\N
16945	MEMBRECOM	2018-06-07 00:00:00	2018-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14214	2018-06-07 17:07:29	\N
16946	MEMBRECOM	2018-06-07 00:00:00	2018-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14215	2018-06-07 17:07:34	\N
16947	MEMBRECOM	2018-06-07 00:00:00	2018-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14216	2018-06-07 17:07:39	\N
16948	MEMBRECOM	2018-06-07 00:00:00	2018-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14217	2018-06-07 17:07:45	\N
16949	MEMBRECOM	2018-06-07 00:00:00	2018-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14218	2018-06-07 17:07:51	\N
16950	MEMBRECOM	2018-06-07 00:00:00	2018-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14219	2018-06-07 17:07:57	\N
16951	MEMBRECOM	2018-06-07 00:00:00	2018-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14220	2018-06-07 17:08:02	\N
16952	MEMBRECOM	2018-06-07 00:00:00	2018-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14221	2018-06-07 17:08:09	\N
16953	MEMBRECOM	2018-06-07 00:00:00	2018-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14222	2018-06-07 17:08:17	\N
16954	MEMBRECOM	2018-06-07 00:00:00	2018-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14223	2018-06-07 17:08:25	\N
16955	MEMBRECOM	2018-06-07 00:00:00	2018-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14224	2018-06-07 17:08:33	\N
16956	MEMBRECOM	2018-06-07 00:00:00	2018-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14225	2018-06-07 17:08:41	\N
16957	MEMBRECOM	2018-06-07 00:00:00	2018-06-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14226	2018-06-07 17:08:49	\N
16973	MEMBRECOM	2018-06-19 00:00:00	2018-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14242	\N	\N
16974	MEMBRECOM	2018-06-19 00:00:00	2018-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14243	\N	\N
16975	MEMBRECOM	2018-06-19 00:00:00	2018-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14244	\N	\N
16976	MEMBRECOM	2018-06-19 00:00:00	2018-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14245	\N	\N
16977	MEMBRECOM	2018-06-19 00:00:00	2018-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14246	\N	\N
16978	MEMBRECOM	2018-06-19 00:00:00	2018-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14247	\N	\N
16979	MEMBRECOM	2018-06-19 00:00:00	2018-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14248	\N	\N
16980	MEMBRECOM	2018-06-19 00:00:00	2018-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14249	\N	\N
16981	MEMBRECOM	2018-06-19 00:00:00	2018-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14250	\N	\N
16982	MEMBRECOM	2018-06-19 00:00:00	2018-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14251	\N	\N
16983	MEMBRECOM	2018-06-19 00:00:00	2018-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14252	\N	\N
16984	MEMBRECOM	2018-06-19 00:00:00	2018-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14253	\N	\N
16985	MEMBRECOM	2018-06-19 00:00:00	2018-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14254	\N	\N
16986	MEMBRECOM	2018-06-19 00:00:00	2018-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14255	\N	\N
13936	MEMBRECOM	2015-11-24 00:00:00	2018-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11792	\N	\N
17050	MEMBRECOM	2018-07-01 00:00:00	2018-07-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14309	\N	\N
17051	MEMBRECOM	2018-07-01 00:00:00	2018-07-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14310	\N	\N
17053	MEMBRECOM	2018-07-04 00:00:00	2020-06-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14312	\N	\N
17113	MEMBRECOM	2018-07-27 00:00:00	2018-09-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14372	\N	\N
17114	MEMBRECOM	2018-07-27 00:00:00	2018-09-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14373	\N	\N
17115	MEMBRECOM	2018-07-27 00:00:00	2018-09-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14374	\N	\N
17116	MEMBRECOM	2018-07-27 00:00:00	2018-09-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14375	\N	\N
17117	MEMBRECOM	2018-07-27 00:00:00	2018-09-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14376	\N	\N
17118	MEMBRECOM	2018-07-27 00:00:00	2018-09-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14377	\N	\N
17119	MEMBRECOM	2018-07-27 00:00:00	2018-09-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14378	\N	\N
17120	MEMBRECOM	2018-07-27 00:00:00	2018-09-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14379	\N	\N
17121	MEMBRECOM	2018-07-27 00:00:00	2018-09-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14380	\N	\N
17122	MEMBRECOM	2018-07-27 00:00:00	2018-09-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14381	\N	\N
17123	MEMBRECOM	2018-07-27 00:00:00	2018-09-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14382	\N	\N
17124	MEMBRECOM	2018-07-27 00:00:00	2018-09-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14383	\N	\N
17125	MEMBRECOM	2018-07-27 00:00:00	2018-09-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14384	\N	\N
17126	MEMBRECOM	2018-07-27 00:00:00	2018-09-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14385	\N	\N
17150	MEMBRECOM	2018-09-25 00:00:00	2018-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14408	\N	\N
17147	MEMBRECOM	2018-09-25 00:00:00	2018-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14405	\N	\N
17148	MEMBRECOM	2018-09-25 00:00:00	2018-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14406	\N	\N
17149	MEMBRECOM	2018-09-25 00:00:00	2018-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14407	\N	\N
17151	MEMBRECOM	2018-09-25 00:00:00	2018-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14409	\N	\N
17152	MEMBRECOM	2018-09-25 00:00:00	2018-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14410	\N	\N
17153	MEMBRECOM	2018-09-25 00:00:00	2018-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14411	\N	\N
17154	MEMBRECOM	2018-09-25 00:00:00	2018-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14412	\N	\N
17155	MEMBRECOM	2018-09-25 00:00:00	2018-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14413	\N	\N
17156	MEMBRECOM	2018-09-25 00:00:00	2018-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14414	\N	\N
17157	MEMBRECOM	2018-09-25 00:00:00	2018-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14415	\N	\N
17158	MEMBRECOM	2018-09-25 00:00:00	2018-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14416	\N	\N
17159	MEMBRECOM	2018-09-25 00:00:00	2018-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14417	\N	\N
17160	MEMBRECOM	2018-09-25 00:00:00	2018-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14418	\N	\N
17161	MEMBRECOM	2018-10-02 00:00:00	2018-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14419	\N	\N
17162	MEMBRECOM	2018-10-02 00:00:00	2018-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14420	\N	\N
17163	MEMBRECOM	2018-10-02 00:00:00	2018-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14421	\N	\N
17164	MEMBRECOM	2018-10-02 00:00:00	2018-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14422	\N	\N
17165	MEMBRECOM	2018-10-02 00:00:00	2018-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14423	\N	\N
17166	MEMBRECOM	2018-10-02 00:00:00	2018-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14424	\N	\N
17167	MEMBRECOM	2018-10-02 00:00:00	2018-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14425	\N	\N
17168	MEMBRECOM	2018-10-02 00:00:00	2018-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14426	\N	\N
17169	MEMBRECOM	2018-10-02 00:00:00	2018-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14427	\N	\N
17170	MEMBRECOM	2018-10-02 00:00:00	2018-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14428	\N	\N
17171	MEMBRECOM	2018-10-02 00:00:00	2018-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14429	\N	\N
17172	MEMBRECOM	2018-10-02 00:00:00	2018-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14430	\N	\N
17173	MEMBRECOM	2018-10-02 00:00:00	2018-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14431	\N	\N
17174	MEMBRECOM	2018-10-02 00:00:00	2018-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14432	\N	\N
17364	MEMBRECOM	2018-10-31 00:00:00	2019-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14574	\N	\N
16471	MEMBRECOM	2018-01-17 00:00:00	2018-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13783	2018-01-16 14:46:24	\N
17365	MEMBRECOM	2018-11-04 00:00:00	2018-12-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14575	\N	\N
17366	VICPDTCOM	2018-11-14 00:00:00	2020-10-05 00:00:00	11	ANCIEN	\N	\N	\N	\N	13484	\N	\N
17367	MEMBRECOM	2018-11-14 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9930	\N	\N
17368	SECRETCOM	2018-11-14 00:00:00	2020-09-30 00:00:00	15	ANCIEN	\N	\N	\N	\N	10137	\N	\N
17369	MEMBRECOM	2018-11-14 00:00:00	2022-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13482	\N	\N
17385	MEMBRECOM	2018-11-20 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14578	\N	\N
17386	MEMBRECOM	2018-11-20 00:00:00	2022-07-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14579	\N	\N
17387	MEMBRECOM	2018-11-21 00:00:00	2020-08-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14580	\N	\N
17396	MEMBRECOM	2018-11-19 00:00:00	2018-11-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14589	\N	\N
17397	MEMBRECOM	2018-11-19 00:00:00	2018-11-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14590	\N	\N
17398	MEMBRECOM	2018-11-19 00:00:00	2018-11-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14591	\N	\N
17399	MEMBRECOM	2018-11-19 00:00:00	2018-11-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14592	\N	\N
17400	MEMBRECOM	2018-11-19 00:00:00	2018-11-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14593	\N	\N
17401	MEMBRECOM	2018-11-19 00:00:00	2018-11-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14594	\N	\N
17402	MEMBRECOM	2018-11-15 00:00:00	2018-11-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14595	\N	\N
17403	MEMBRECOM	2018-11-15 00:00:00	2018-11-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14596	\N	\N
17404	MEMBRECOM	2018-11-15 00:00:00	2018-11-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14597	\N	\N
17405	MEMBRECOM	2018-11-15 00:00:00	2018-11-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14598	\N	\N
17406	MEMBRECOM	2018-11-15 00:00:00	2018-11-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14599	\N	\N
17407	MEMBRECOM	2018-11-15 00:00:00	2018-11-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14600	\N	\N
17408	MEMBRECOM	2018-11-15 00:00:00	2018-11-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14601	\N	\N
17409	MEMBRECOM	2018-11-15 00:00:00	2018-11-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14602	\N	\N
17410	MEMBRECOM	2018-11-15 00:00:00	2018-11-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14603	\N	\N
17411	MEMBRECOM	2018-11-15 00:00:00	2018-11-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14604	\N	\N
17412	MEMBRECOM	2018-11-15 00:00:00	2018-11-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14605	\N	\N
17413	MEMBRECOM	2018-11-15 00:00:00	2018-11-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14606	\N	\N
17414	MEMBRECOM	2018-11-15 00:00:00	2018-11-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14607	\N	\N
17415	MEMBRECOM	2018-11-15 00:00:00	2018-11-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14608	\N	\N
17445	MEMBRECOM	2018-12-07 00:00:00	2018-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14637	\N	\N
17446	MEMBRECOM	2018-12-07 00:00:00	2018-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14638	\N	\N
17447	MEMBRECOM	2018-12-07 00:00:00	2018-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14639	\N	\N
17448	MEMBRECOM	2018-12-07 00:00:00	2018-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14640	\N	\N
17449	MEMBRECOM	2018-12-07 00:00:00	2018-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14641	\N	\N
17450	MEMBRECOM	2018-12-07 00:00:00	2018-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14642	\N	\N
17451	MEMBRECOM	2018-12-07 00:00:00	2018-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14643	\N	\N
17452	MEMBRECOM	2018-12-07 00:00:00	2018-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14644	\N	\N
17453	MEMBRECOM	2018-12-07 00:00:00	2018-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14645	\N	\N
17454	MEMBRECOM	2018-12-07 00:00:00	2018-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14646	\N	\N
17455	MEMBRECOM	2018-12-07 00:00:00	2018-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14647	\N	\N
17456	MEMBRECOM	2018-12-07 00:00:00	2018-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14648	\N	\N
17457	MEMBRECOM	2018-12-07 00:00:00	2018-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14649	\N	\N
17458	MEMBRECOM	2018-12-07 00:00:00	2018-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14650	\N	\N
17459	MEMBRECOM	2018-12-06 00:00:00	2019-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14456	\N	\N
17463	MEMBRECOM	2018-12-12 00:00:00	2018-12-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14653	\N	\N
17464	MEMBRECOM	2018-12-12 00:00:00	2018-12-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14654	\N	\N
16706	MEMBRECOM	2017-11-08 00:00:00	2020-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13993	2018-03-12 16:11:16	\N
16707	MEMBRECOM	2017-11-08 00:00:00	2018-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13994	2018-03-12 16:11:21	2018-05-31 10:52:17
16708	MEMBRECOM	2017-11-08 00:00:00	2020-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13995	2018-03-12 16:11:26	\N
16709	MEMBRECOM	2017-11-08 00:00:00	2020-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13996	2018-03-12 16:11:32	\N
16710	MEMBRECOM	2017-11-08 00:00:00	2019-06-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13997	2018-03-12 16:11:36	\N
16711	MEMBRECOM	2017-11-08 00:00:00	2020-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13998	2018-03-12 16:11:42	\N
16712	MEMBRECOM	2017-11-08 00:00:00	2020-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13999	2018-03-12 16:11:48	\N
16713	MEMBRECOM	2017-11-08 00:00:00	2020-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14000	2018-03-12 16:11:55	\N
16714	MEMBRECOM	2017-11-08 00:00:00	2020-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14001	2018-03-12 16:12:00	\N
16715	MEMBRECOM	2017-11-08 00:00:00	2020-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14002	2018-03-12 16:12:05	\N
16716	MEMBRECOM	2017-11-08 00:00:00	2020-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14003	2018-03-12 16:12:10	\N
16717	MEMBRECOM	2017-11-08 00:00:00	2020-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14004	2018-03-12 16:12:14	\N
16718	MEMBRECOM	2017-11-08 00:00:00	2020-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14005	2018-03-12 16:12:19	\N
16719	MEMBRECOM	2017-11-08 00:00:00	2018-11-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14006	2018-03-12 16:12:26	\N
16720	MEMBRECOM	2017-11-08 00:00:00	2020-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14007	2018-03-12 16:12:31	\N
16721	MEMBRECOM	2017-11-08 00:00:00	2020-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14008	2018-03-12 16:12:37	\N
16722	MEMBRECOM	2017-11-08 00:00:00	2020-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14009	2018-03-12 16:12:42	\N
16723	MEMBRECOM	2017-11-08 00:00:00	2020-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14010	2018-03-12 16:12:49	\N
16724	MEMBRECOM	2017-11-08 00:00:00	2020-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14011	2018-03-12 16:12:55	\N
16725	MEMBRECOM	2017-11-08 00:00:00	2020-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14012	2018-03-12 16:12:59	\N
16753	MEMBRECOM	2018-03-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	14040	2018-03-21 14:05:53	\N
16754	MEMBRECOM	2018-03-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	14041	2018-03-21 14:05:58	\N
16755	MEMBRECOM	2018-03-14 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14042	2018-03-21 14:06:02	\N
16756	MEMBRECOM	2018-03-14 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14043	2018-03-21 14:06:08	\N
16757	MEMBRECOM	2018-03-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	14044	2018-03-21 14:06:13	\N
16758	MEMBRECOM	2018-03-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	14045	2018-03-21 14:06:18	\N
16759	MEMBRECOM	2018-03-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	14046	2018-03-21 14:06:24	\N
16760	MEMBRECOM	2018-03-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	14047	2018-03-21 14:06:29	\N
16761	MEMBRECOM	2018-03-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	14048	2018-03-21 14:06:35	\N
16762	MEMBRECOM	2018-03-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	14049	2018-03-21 14:06:44	\N
16763	MEMBRECOM	2018-03-14 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14050	2018-03-21 14:06:49	\N
16764	MEMBRECOM	2018-03-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	14051	2018-03-21 14:06:54	\N
16765	MEMBRECOM	2018-03-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	14052	2018-03-21 14:06:59	\N
16766	MEMBRECOM	2018-03-14 00:00:00	2022-07-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14053	2018-03-21 14:07:04	\N
16800	MEMBRECOM	2018-04-11 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14078	2018-04-10 16:04:41	\N
16801	MEMBRECOM	2018-04-11 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14079	2018-04-10 16:04:47	\N
16802	MEMBRECOM	2018-04-11 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14080	2018-04-10 16:04:55	\N
16803	MEMBRECOM	2018-04-11 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14081	2018-04-10 16:05:02	\N
16804	MEMBRECOM	2018-04-11 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14082	2018-04-10 16:05:11	\N
16805	MEMBRECOM	2018-04-11 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14083	2018-04-10 16:05:16	\N
16806	MEMBRECOM	2018-04-11 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14084	2018-04-10 16:05:20	\N
16807	MEMBRECOM	2018-04-11 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14085	2018-04-10 16:05:27	\N
16808	MEMBRECOM	2018-04-11 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14086	2018-04-10 16:05:34	\N
16809	MEMBRECOM	2018-04-11 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14087	2018-04-10 16:05:39	\N
16810	MEMBRECOM	2018-04-11 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14088	2018-04-10 16:05:45	\N
16811	MEMBRECOM	2018-04-11 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14089	2018-04-10 16:06:13	\N
16812	MEMBRECOM	2018-04-11 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14090	2018-04-10 16:06:18	\N
16813	MEMBRECOM	2018-04-11 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14091	2018-04-10 16:06:32	\N
16814	MEMBRECOM	2018-04-11 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14092	2018-04-10 16:06:39	\N
16815	MEMBRECOM	2018-04-11 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14093	2018-04-10 16:06:48	\N
16816	MEMBRECOM	2018-04-11 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14094	2018-04-10 16:06:56	\N
16817	MEMBRECOM	2018-04-11 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14095	2018-04-10 16:07:01	\N
16818	MEMBRECOM	2018-04-11 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14096	2018-04-10 16:07:13	\N
16819	MEMBRECOM	2018-04-11 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14097	2018-04-10 16:07:36	\N
16820	MEMBRECOM	2018-04-11 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14098	2018-04-10 16:07:41	\N
16821	MEMBRECOM	2018-04-11 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14099	2018-04-10 16:07:47	\N
16822	MEMBRECOM	2018-04-11 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14100	2018-04-10 16:07:51	\N
16823	MEMBRECOM	2018-04-11 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14101	2018-04-10 16:07:55	\N
16824	MEMBRECOM	2018-04-11 00:00:00	2018-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14102	2018-04-10 16:08:01	\N
16825	MEMBRECOM	2018-04-11 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14103	2018-04-10 16:08:07	\N
16826	MEMBRECOM	2018-04-11 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14104	2018-04-10 16:08:15	\N
16850	MEMBRECOM	2018-04-11 00:00:00	2018-04-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14128	2018-04-10 16:14:33	2018-04-18 11:37:33
16851	MEMBRECOM	2018-04-11 00:00:00	2018-04-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14129	2018-04-10 16:14:41	2018-04-18 11:31:44
16852	MEMBRECOM	2018-04-11 00:00:00	2018-04-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14130	2018-04-10 16:14:48	2018-04-18 11:37:11
16853	MEMBRECOM	2018-04-11 00:00:00	2018-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14131	2018-04-10 16:14:56	\N
16854	MEMBRECOM	2018-04-11 00:00:00	2018-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14132	2018-04-10 16:15:01	\N
16855	MEMBRECOM	2018-04-11 00:00:00	2018-04-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14133	2018-04-10 16:15:05	2018-04-18 11:32:13
16856	MEMBRECOM	2018-04-11 00:00:00	2018-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14134	2018-04-10 16:15:09	\N
16857	MEMBRECOM	2018-04-11 00:00:00	2018-04-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14135	2018-04-10 16:15:14	2018-04-18 11:34:05
16858	MEMBRECOM	2018-04-11 00:00:00	2018-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14136	2018-04-10 16:15:19	\N
16859	MEMBRECOM	2018-04-11 00:00:00	2018-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14137	2018-04-10 16:15:24	\N
16860	MEMBRECOM	2018-04-11 00:00:00	2018-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14138	2018-04-10 16:15:33	\N
16861	MEMBRECOM	2018-04-11 00:00:00	2018-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14139	2018-04-10 16:15:38	\N
16862	MEMBRECOM	2018-04-11 00:00:00	2018-04-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14140	2018-04-10 16:16:06	2018-04-18 11:36:47
16863	MEMBRECOM	2018-04-11 00:00:00	2018-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14141	2018-04-10 16:16:14	\N
16864	MEMBRECOM	2018-04-11 00:00:00	2018-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14142	2018-04-10 16:16:21	\N
16865	MEMBRECOM	2018-04-11 00:00:00	2018-04-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14143	2018-04-10 16:16:27	2018-04-18 11:31:08
16866	MEMBRECOM	2018-04-11 00:00:00	2018-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14144	2018-04-10 16:16:35	\N
16867	MEMBRECOM	2018-04-11 00:00:00	2018-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14145	2018-04-10 16:16:40	\N
16868	MEMBRECOM	2018-04-11 00:00:00	2018-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14146	2018-04-10 16:16:46	\N
16869	MEMBRECOM	2018-04-11 00:00:00	2018-04-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14147	2018-04-10 16:16:54	2018-04-18 11:36:22
16870	MEMBRECOM	2018-04-11 00:00:00	2018-04-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14148	2018-04-10 16:17:00	2018-04-18 11:35:59
16871	MEMBRECOM	2018-04-10 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14149	2018-04-10 16:19:34	\N
16316	MEMBRECOM	2017-11-22 00:00:00	2018-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13637	2017-11-21 15:45:31	\N
16334	MEMBRECOM	2017-11-22 00:00:00	2018-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13655	2017-11-21 15:47:29	\N
16468	MEMBRECOM	2018-01-17 00:00:00	2018-06-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13780	2018-01-16 14:46:05	\N
17370	PDTCOM	2018-11-15 00:00:00	2019-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14566	\N	\N
17371	RAPCOM	2018-11-15 00:00:00	2019-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14571	\N	\N
17372	RAPCOM	2018-11-15 00:00:00	2019-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14560	\N	\N
17373	RAPCOM	2018-11-15 00:00:00	2019-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14552	\N	\N
17374	VICPDTCOM	2018-11-15 00:00:00	2019-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14559	\N	\N
17375	VICPDTCOM	2018-11-15 00:00:00	2019-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14554	\N	\N
17376	VICPDTCOM	2018-11-15 00:00:00	2019-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14547	\N	\N
17377	VICPDTCOM	2018-11-15 00:00:00	2019-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14555	\N	\N
17378	VICPDTCOM	2018-11-15 00:00:00	2019-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14556	\N	\N
17379	SECRETCOM	2018-11-15 00:00:00	2019-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14573	\N	\N
17380	SECRETCOM	2018-11-15 00:00:00	2019-05-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14551	\N	\N
17388	MEMBRECOM	2018-11-19 00:00:00	2018-11-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14581	\N	\N
17389	MEMBRECOM	2018-11-19 00:00:00	2018-11-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14582	\N	\N
17390	MEMBRECOM	2018-11-19 00:00:00	2018-11-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14583	\N	\N
16909	MEMBRECOM	2018-05-22 00:00:00	2018-05-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14178	2018-05-22 16:46:11	2018-06-07 17:10:53
16910	MEMBRECOM	2018-05-22 00:00:00	2018-05-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14179	2018-05-22 16:46:15	2018-06-07 17:10:53
16911	MEMBRECOM	2018-05-22 00:00:00	2018-05-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14180	2018-05-22 16:46:21	2018-06-07 17:10:53
16912	MEMBRECOM	2018-05-22 00:00:00	2018-05-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14181	2018-05-22 16:46:28	2018-06-07 17:10:53
16913	MEMBRECOM	2018-05-22 00:00:00	2018-05-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14182	2018-05-22 16:46:35	2018-06-07 17:10:53
16914	MEMBRECOM	2018-05-22 00:00:00	2018-05-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14183	2018-05-22 16:46:39	2018-06-07 17:10:53
16915	MEMBRECOM	2018-05-22 00:00:00	2018-05-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14184	2018-05-22 16:46:48	2018-06-07 17:10:53
16916	MEMBRECOM	2018-05-22 00:00:00	2018-05-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14185	2018-05-22 16:46:57	2018-06-07 17:10:53
16917	MEMBRECOM	2018-05-22 00:00:00	2018-05-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14186	2018-05-22 16:47:03	2018-06-07 17:10:53
16918	MEMBRECOM	2018-05-22 00:00:00	2018-05-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14187	2018-05-22 16:47:09	2018-06-07 17:10:53
16919	MEMBRECOM	2018-05-22 00:00:00	2018-05-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14188	2018-05-22 16:47:15	2018-06-07 17:10:53
16920	MEMBRECOM	2018-05-22 00:00:00	2018-05-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14189	2018-05-22 16:47:20	2018-06-07 17:10:53
16921	MEMBRECOM	2018-05-22 00:00:00	2018-05-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14190	2018-05-22 16:47:28	2018-06-07 17:10:53
16922	MEMBRECOM	2018-05-22 00:00:00	2018-05-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14191	2018-05-22 16:47:33	2018-06-07 17:10:53
16923	MEMBRECOM	2018-04-18 00:00:00	2018-05-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14192	2018-05-22 16:49:50	2018-06-07 17:11:04
16924	MEMBRECOM	2018-04-18 00:00:00	2018-05-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14193	2018-05-22 16:49:56	2018-06-07 17:11:04
16925	MEMBRECOM	2018-04-18 00:00:00	2018-05-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14194	2018-05-22 16:50:04	2018-06-07 17:11:04
16926	MEMBRECOM	2018-04-18 00:00:00	2018-05-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14195	2018-05-22 16:50:09	2018-06-07 17:11:04
16927	MEMBRECOM	2018-04-18 00:00:00	2018-05-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14196	2018-05-22 16:50:15	2018-06-07 17:11:04
16928	MEMBRECOM	2018-04-18 00:00:00	2018-05-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14197	2018-05-22 16:50:20	2018-06-07 17:11:04
16929	MEMBRECOM	2018-04-18 00:00:00	2018-05-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14198	2018-05-22 16:50:26	2018-06-07 17:11:04
16930	MEMBRECOM	2018-04-18 00:00:00	2018-05-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14199	2018-05-22 16:50:31	2018-06-07 17:11:04
16931	MEMBRECOM	2018-04-18 00:00:00	2018-05-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14200	2018-05-22 16:50:38	2018-06-07 17:11:04
16932	MEMBRECOM	2018-04-18 00:00:00	2018-05-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14201	2018-05-22 16:50:47	2018-06-07 17:11:04
16933	MEMBRECOM	2018-04-18 00:00:00	2018-05-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14202	2018-05-22 16:50:54	2018-06-07 17:11:04
16934	MEMBRECOM	2018-04-18 00:00:00	2018-05-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14203	2018-05-22 16:51:02	2018-06-07 17:11:04
16935	MEMBRECOM	2018-04-18 00:00:00	2018-05-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14204	2018-05-22 16:51:11	2018-06-07 17:11:04
16936	MEMBRECOM	2018-04-18 00:00:00	2018-05-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14205	2018-05-22 16:51:20	2018-06-07 17:11:04
17054	MEMBRECOM	2018-07-10 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14313	\N	\N
17055	MEMBRECOM	2018-07-11 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14314	\N	\N
17133	MEMBRECOM	2018-09-25 00:00:00	2018-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14391	\N	\N
17134	MEMBRECOM	2018-09-25 00:00:00	2018-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14392	\N	\N
17135	MEMBRECOM	2018-09-25 00:00:00	2018-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14393	\N	\N
17136	MEMBRECOM	2018-09-25 00:00:00	2018-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14394	\N	\N
17137	MEMBRECOM	2018-09-25 00:00:00	2018-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14395	\N	\N
17138	MEMBRECOM	2018-09-25 00:00:00	2018-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14396	\N	\N
17139	MEMBRECOM	2018-09-25 00:00:00	2018-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14397	\N	\N
17140	MEMBRECOM	2018-09-25 00:00:00	2018-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14398	\N	\N
17141	MEMBRECOM	2018-09-25 00:00:00	2018-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14399	\N	\N
17142	MEMBRECOM	2018-09-25 00:00:00	2018-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14400	\N	\N
17143	MEMBRECOM	2018-09-25 00:00:00	2018-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14401	\N	\N
17144	MEMBRECOM	2018-09-25 00:00:00	2018-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14402	\N	\N
17145	MEMBRECOM	2018-09-25 00:00:00	2018-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14403	\N	\N
17146	MEMBRECOM	2018-09-25 00:00:00	2018-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14404	\N	\N
17304	PDTCOM	2018-10-11 00:00:00	2018-11-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14468	\N	\N
17381	MEMBRECOM	2018-11-17 00:00:00	2018-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4205	\N	\N
17382	MEMBRECOM	2018-11-17 00:00:00	2018-11-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14576	\N	\N
17391	MEMBRECOM	2018-11-19 00:00:00	2018-11-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14584	\N	\N
17392	MEMBRECOM	2018-11-19 00:00:00	2018-11-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14585	\N	\N
17393	MEMBRECOM	2018-11-19 00:00:00	2018-11-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14586	\N	\N
17394	MEMBRECOM	2018-11-19 00:00:00	2018-11-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14587	\N	\N
17395	MEMBRECOM	2018-11-19 00:00:00	2018-11-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14588	\N	\N
17416	MEMBRECOM	2018-11-26 00:00:00	2018-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14609	\N	\N
17417	MEMBRECOM	2018-11-26 00:00:00	2018-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14610	\N	\N
17418	MEMBRECOM	2018-11-26 00:00:00	2018-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14611	\N	\N
17419	MEMBRECOM	2018-11-26 00:00:00	2018-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14612	\N	\N
17420	MEMBRECOM	2018-11-26 00:00:00	2018-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14613	\N	\N
17421	MEMBRECOM	2018-11-26 00:00:00	2018-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14614	\N	\N
17422	MEMBRECOM	2018-11-26 00:00:00	2018-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14615	\N	\N
17423	MEMBRECOM	2018-11-26 00:00:00	2018-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14616	\N	\N
17424	MEMBRECOM	2018-11-26 00:00:00	2018-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14617	\N	\N
17425	MEMBRECOM	2018-11-26 00:00:00	2018-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14618	\N	\N
17426	MEMBRECOM	2018-11-26 00:00:00	2018-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14619	\N	\N
17427	MEMBRECOM	2018-11-26 00:00:00	2018-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14620	\N	\N
17428	MEMBRECOM	2018-11-26 00:00:00	2018-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14621	\N	\N
17429	MEMBRECOM	2018-11-26 00:00:00	2018-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14622	\N	\N
17430	MEMBRECOM	2018-11-26 00:00:00	2018-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14623	\N	\N
17431	MEMBRECOM	2018-11-26 00:00:00	2018-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14624	\N	\N
17432	MEMBRECOM	2018-11-26 00:00:00	2018-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14625	\N	\N
17433	MEMBRECOM	2018-11-26 00:00:00	2018-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14626	\N	\N
17434	MEMBRECOM	2018-11-26 00:00:00	2018-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14627	\N	\N
17435	MEMBRECOM	2018-11-26 00:00:00	2018-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14628	\N	\N
17436	MEMBRECOM	2018-11-26 00:00:00	2018-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14629	\N	\N
17437	MEMBRECOM	2018-11-26 00:00:00	2018-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14630	\N	\N
17438	MEMBRECOM	2018-11-26 00:00:00	2018-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14631	\N	\N
17439	MEMBRECOM	2018-11-26 00:00:00	2018-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14632	\N	\N
17440	MEMBRECOM	2018-11-26 00:00:00	2018-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14633	\N	\N
17441	MEMBRECOM	2018-11-26 00:00:00	2018-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14634	\N	\N
17442	MEMBRECOM	2018-11-26 00:00:00	2018-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14635	\N	\N
17443	MEMBRECOM	2018-11-26 00:00:00	2018-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14636	\N	\N
17465	MEMBRECOM	2018-12-12 00:00:00	2018-12-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14655	\N	\N
17466	MEMBRECOM	2018-12-12 00:00:00	2018-12-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14656	\N	\N
17467	MEMBRECOM	2018-12-12 00:00:00	2018-12-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14657	\N	\N
17468	MEMBRECOM	2018-12-12 00:00:00	2018-12-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14658	\N	\N
17469	MEMBRECOM	2018-12-12 00:00:00	2018-12-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14659	\N	\N
17470	MEMBRECOM	2018-12-12 00:00:00	2018-12-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14660	\N	\N
17471	MEMBRECOM	2018-12-12 00:00:00	2018-12-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14661	\N	\N
17472	MEMBRECOM	2018-12-12 00:00:00	2018-12-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14662	\N	\N
17473	MEMBRECOM	2018-12-12 00:00:00	2018-12-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14663	\N	\N
17474	MEMBRECOM	2018-12-12 00:00:00	2018-12-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14664	\N	\N
17475	MEMBRECOM	2018-12-12 00:00:00	2018-12-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14651	\N	\N
17476	MEMBRECOM	2018-12-12 00:00:00	2018-12-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14652	\N	\N
17563	MEMBRECOM	2019-01-31 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14749	\N	\N
17564	VICPDTCOM	2019-01-16 00:00:00	2020-06-17 00:00:00	3	ANCIEN	\N	\N	\N	\N	13379	\N	\N
17565	SECRETCOM	2019-01-16 00:00:00	2020-10-05 00:00:00	13	ANCIEN	\N	\N	\N	\N	13389	\N	\N
9361	MEMBRECOM	2011-04-06 00:00:00	2019-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7858	\N	\N
17580	MEMBRECOM	2019-03-04 00:00:00	2019-03-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13032	\N	\N
17581	MEMBRECOM	2019-03-04 00:00:00	2019-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14764	\N	\N
17582	MEMBRECOM	2019-03-05 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13037	\N	\N
17585	MEMBRECOM	2019-03-06 00:00:00	2019-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14767	\N	\N
17586	MEMBRECOM	2019-03-06 00:00:00	2019-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14768	\N	\N
17587	MEMBRECOM	2019-03-06 00:00:00	2019-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14769	\N	\N
17588	MEMBRECOM	2019-03-06 00:00:00	2019-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14770	\N	\N
17589	MEMBRECOM	2019-03-06 00:00:00	2019-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14771	\N	\N
17590	MEMBRECOM	2019-03-06 00:00:00	2019-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14772	\N	\N
17591	MEMBRECOM	2019-03-06 00:00:00	2019-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14773	\N	\N
17592	MEMBRECOM	2019-03-06 00:00:00	2019-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14774	\N	\N
17593	MEMBRECOM	2019-03-06 00:00:00	2019-03-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14775	\N	\N
17594	MEMBRECOM	2019-03-06 00:00:00	2019-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14776	\N	\N
17595	MEMBRECOM	2019-03-06 00:00:00	2019-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14777	\N	\N
16872	PDTCOM	2018-04-17 00:00:00	2018-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14143	2018-04-18 11:31:08	\N
16873	RAPCOM	2018-04-17 00:00:00	2018-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14129	2018-04-18 11:31:57	\N
16874	VICPDTCOM	2018-04-17 00:00:00	2018-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14133	2018-04-18 11:32:23	\N
16875	VICPDTCOM	2018-04-17 00:00:00	2018-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14135	2018-04-18 11:34:16	\N
16876	VICPDTCOM	2018-04-17 00:00:00	2018-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14148	2018-04-18 11:36:06	\N
16877	VICPDTCOM	2018-04-17 00:00:00	2018-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14147	2018-04-18 11:36:29	\N
16878	VICPDTCOM	2018-04-17 00:00:00	2018-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14140	2018-04-18 11:36:55	\N
16879	VICPDTCOM	2018-04-17 00:00:00	2018-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14130	2018-04-18 11:37:17	\N
16880	VICPDTCOM	2018-04-17 00:00:00	2018-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14128	2018-04-18 11:37:39	\N
16881	MEMBRECOM	2018-04-18 00:00:00	2018-04-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14150	2018-04-18 11:42:06	2018-05-22 16:39:12
16882	MEMBRECOM	2018-04-18 00:00:00	2018-04-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14151	2018-04-18 11:42:12	2018-05-22 16:39:12
16883	MEMBRECOM	2018-04-18 00:00:00	2018-04-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14152	2018-04-18 11:42:19	2018-05-22 16:39:12
16884	MEMBRECOM	2018-04-18 00:00:00	2018-04-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14153	2018-04-18 11:42:24	2018-05-22 16:39:12
16885	MEMBRECOM	2018-04-18 00:00:00	2018-04-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14154	2018-04-18 11:42:32	2018-05-22 16:39:12
16886	MEMBRECOM	2018-04-18 00:00:00	2018-04-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14155	2018-04-18 11:42:36	2018-05-22 16:39:12
16887	MEMBRECOM	2018-04-18 00:00:00	2018-04-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14156	2018-04-18 11:42:41	2018-05-22 16:39:12
16888	MEMBRECOM	2018-04-18 00:00:00	2018-04-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14157	2018-04-18 11:42:49	2018-05-22 16:39:12
16889	MEMBRECOM	2018-04-18 00:00:00	2018-04-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14158	2018-04-18 11:42:59	2018-05-22 16:39:12
16890	MEMBRECOM	2018-04-18 00:00:00	2018-04-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14159	2018-04-18 11:45:34	2018-05-22 16:39:12
16891	MEMBRECOM	2018-04-18 00:00:00	2018-04-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14160	2018-04-18 11:45:44	2018-05-22 16:39:12
16892	MEMBRECOM	2018-04-18 00:00:00	2018-04-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14161	2018-04-18 11:45:51	2018-05-22 16:39:12
16893	MEMBRECOM	2018-04-18 00:00:00	2018-04-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14162	2018-04-18 11:47:04	2018-05-22 16:39:12
16894	MEMBRECOM	2018-04-18 00:00:00	2018-04-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14163	2018-04-18 11:47:11	2018-05-22 16:39:12
16895	MEMBRECOM	2018-04-17 00:00:00	2018-04-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14164	2018-04-18 11:49:27	2018-05-22 16:39:37
16896	MEMBRECOM	2018-04-17 00:00:00	2018-04-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14165	2018-04-18 11:49:31	2018-05-22 16:39:37
16897	MEMBRECOM	2018-04-17 00:00:00	2018-04-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14166	2018-04-18 11:49:35	2018-05-22 16:39:37
16898	MEMBRECOM	2018-04-17 00:00:00	2018-04-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14167	2018-04-18 11:49:40	2018-05-22 16:39:37
16899	MEMBRECOM	2018-04-17 00:00:00	2018-04-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14168	2018-04-18 11:49:45	2018-05-22 16:39:37
16900	MEMBRECOM	2018-04-17 00:00:00	2018-04-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14169	2018-04-18 11:49:50	2018-05-22 16:39:37
16901	MEMBRECOM	2018-04-17 00:00:00	2018-04-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14170	2018-04-18 11:49:56	2018-05-22 16:39:37
16902	MEMBRECOM	2018-04-17 00:00:00	2018-04-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14171	2018-04-18 11:50:02	2018-05-22 16:39:37
16903	MEMBRECOM	2018-04-17 00:00:00	2018-04-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14172	2018-04-18 11:50:16	2018-05-22 16:39:37
16904	MEMBRECOM	2018-04-17 00:00:00	2018-04-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14173	2018-04-18 11:50:24	2018-05-22 16:39:37
16905	MEMBRECOM	2018-04-17 00:00:00	2018-04-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14174	2018-04-18 11:50:34	2018-05-22 16:39:37
16906	MEMBRECOM	2018-04-17 00:00:00	2018-04-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14175	2018-04-18 11:50:43	2018-05-22 16:39:37
16907	MEMBRECOM	2018-04-17 00:00:00	2018-04-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14176	2018-04-18 11:50:58	2018-05-22 16:39:37
16908	MEMBRECOM	2018-04-17 00:00:00	2018-04-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14177	2018-04-18 11:51:05	2018-05-22 16:39:37
17009	MEMBRECOM	2018-06-27 00:00:00	2018-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14278	\N	\N
17011	MEMBRECOM	2018-06-28 00:00:00	2018-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14279	\N	\N
17012	MEMBRECOM	2018-06-28 00:00:00	2018-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14280	\N	\N
17013	MEMBRECOM	2018-06-28 00:00:00	2018-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14281	\N	\N
17014	MEMBRECOM	2018-06-28 00:00:00	2018-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14282	\N	\N
17015	MEMBRECOM	2018-06-28 00:00:00	2018-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14283	\N	\N
17016	MEMBRECOM	2018-06-28 00:00:00	2018-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14284	\N	\N
17017	MEMBRECOM	2018-06-28 00:00:00	2018-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14285	\N	\N
17018	MEMBRECOM	2018-06-28 00:00:00	2018-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14286	\N	\N
17019	MEMBRECOM	2018-06-28 00:00:00	2018-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14287	\N	\N
17020	MEMBRECOM	2018-06-28 00:00:00	2018-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14288	\N	\N
17021	MEMBRECOM	2018-06-28 00:00:00	2018-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14289	\N	\N
17022	MEMBRECOM	2018-06-28 00:00:00	2018-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14290	\N	\N
17023	MEMBRECOM	2018-06-28 00:00:00	2018-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14291	\N	\N
17024	MEMBRECOM	2018-06-28 00:00:00	2018-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14292	\N	\N
17025	MEMBRECOM	2018-06-28 00:00:00	2018-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14293	\N	\N
17026	MEMBRECOM	2018-06-28 00:00:00	2018-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14294	\N	\N
17027	MEMBRECOM	2018-06-28 00:00:00	2018-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14295	\N	\N
17028	MEMBRECOM	2018-06-28 00:00:00	2018-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14296	\N	\N
17029	MEMBRECOM	2018-06-28 00:00:00	2018-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14297	\N	\N
17030	MEMBRECOM	2018-06-28 00:00:00	2018-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14298	\N	\N
17031	MEMBRECOM	2018-06-28 00:00:00	2018-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14299	\N	\N
17032	MEMBRECOM	2018-06-28 00:00:00	2018-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14300	\N	\N
17033	MEMBRECOM	2018-06-28 00:00:00	2018-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14301	\N	\N
17034	MEMBRECOM	2018-06-28 00:00:00	2018-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14302	\N	\N
17035	MEMBRECOM	2018-06-28 00:00:00	2018-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14303	\N	\N
17036	MEMBRECOM	2018-06-28 00:00:00	2018-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14304	\N	\N
17037	MEMBRECOM	2018-06-28 00:00:00	2018-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14305	\N	\N
17038	MEMBRECOM	2018-06-28 00:00:00	2018-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14306	\N	\N
17039	MEMBRECOM	2018-06-28 00:00:00	2018-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14307	\N	\N
17040	MEMBRECOM	2018-06-28 00:00:00	2018-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14308	\N	\N
17052	MEMBRECOM	2018-07-02 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14311	\N	\N
17098	MEMBRECOM	2018-07-16 00:00:00	2018-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14357	\N	\N
17175	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14433	\N	\N
17100	MEMBRECOM	2018-07-16 00:00:00	2018-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14359	\N	\N
17101	MEMBRECOM	2018-07-16 00:00:00	2018-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14360	\N	\N
17102	MEMBRECOM	2018-07-16 00:00:00	2018-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14361	\N	\N
17103	MEMBRECOM	2018-07-16 00:00:00	2018-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14362	\N	\N
17104	MEMBRECOM	2018-07-16 00:00:00	2018-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14363	\N	\N
17105	MEMBRECOM	2018-07-16 00:00:00	2018-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14364	\N	\N
17106	MEMBRECOM	2018-07-16 00:00:00	2018-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14365	\N	\N
17107	MEMBRECOM	2018-07-16 00:00:00	2018-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14366	\N	\N
17108	MEMBRECOM	2018-07-16 00:00:00	2018-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14367	\N	\N
17109	MEMBRECOM	2018-07-16 00:00:00	2018-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14368	\N	\N
17110	MEMBRECOM	2018-07-16 00:00:00	2018-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14369	\N	\N
17111	MEMBRECOM	2018-07-16 00:00:00	2018-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14370	\N	\N
17112	MEMBRECOM	2018-07-16 00:00:00	2018-07-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14371	\N	\N
17127	MEMBRECOM	2018-07-28 00:00:00	2018-09-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14386	\N	\N
17176	MEMBRECOM	2018-10-10 00:00:00	2019-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14434	\N	\N
17177	MEMBRECOM	2018-10-10 00:00:00	2019-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14435	\N	\N
17178	MEMBRECOM	2018-10-10 00:00:00	2019-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14436	\N	\N
17179	MEMBRECOM	2018-10-10 00:00:00	2019-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14437	\N	\N
17180	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14438	\N	\N
17181	MEMBRECOM	2018-10-10 00:00:00	2019-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14439	\N	\N
17182	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14440	\N	\N
17183	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14441	\N	\N
17184	MEMBRECOM	2018-10-10 00:00:00	2019-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14442	\N	\N
17185	MEMBRECOM	2018-10-10 00:00:00	2019-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14443	\N	\N
17186	MEMBRECOM	2018-10-10 00:00:00	2019-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14444	\N	\N
17187	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14445	\N	\N
17188	MEMBRECOM	2018-10-10 00:00:00	2019-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14446	\N	\N
17189	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14447	\N	\N
17190	MEMBRECOM	2018-10-10 00:00:00	2019-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14448	\N	\N
17191	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14449	\N	\N
17192	MEMBRECOM	2018-10-10 00:00:00	2019-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14450	\N	\N
17193	MEMBRECOM	2018-10-10 00:00:00	2019-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14451	\N	\N
17194	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14452	\N	\N
17195	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14453	\N	\N
17196	MEMBRECOM	2018-10-10 00:00:00	2019-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14454	\N	\N
17305	VICPDTCOM	2018-10-11 00:00:00	2018-11-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14463	\N	\N
17306	VICPDTCOM	2018-10-11 00:00:00	2018-11-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14483	\N	\N
17307	VICPDTCOM	2018-10-11 00:00:00	2018-11-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14469	\N	\N
16767	PDTCOM	2018-03-21 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14039	2018-03-22 12:00:39	\N
16768	RAPCOM	2018-03-21 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14013	2018-03-22 12:02:08	\N
16769	VICPDTCOM	2018-03-21 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14014	2018-03-22 12:04:42	\N
16770	VICPDTCOM	2018-03-21 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14019	2018-03-22 12:05:43	\N
16771	VICPDTCOM	2018-03-21 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14020	2018-03-22 12:07:32	\N
16772	VICPDTCOM	2018-03-21 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14021	2018-03-22 12:08:08	\N
16773	VICPDTCOM	2018-03-21 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14027	2018-03-22 12:09:35	\N
16774	VICPDTCOM	2018-03-21 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14028	2018-03-22 12:11:14	\N
16775	VICPDTCOM	2018-03-21 00:00:00	2018-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14038	2018-03-22 12:11:41	\N
16776	MEMBRECOM	2018-03-29 00:00:00	2018-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14054	2018-03-29 17:21:55	2018-05-22 16:40:01
16777	MEMBRECOM	2018-03-29 00:00:00	2018-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14055	2018-03-29 17:22:00	2018-05-22 16:40:01
16778	MEMBRECOM	2018-03-29 00:00:00	2018-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14056	2018-03-29 17:22:05	2018-05-22 16:40:01
16779	MEMBRECOM	2018-03-29 00:00:00	2018-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14057	2018-03-29 17:22:10	2018-05-22 16:40:01
16780	MEMBRECOM	2018-03-29 00:00:00	2018-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14058	2018-03-29 17:22:15	2018-05-22 16:40:01
16781	MEMBRECOM	2018-03-29 00:00:00	2018-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14059	2018-03-29 17:22:19	2018-05-22 16:40:01
16782	MEMBRECOM	2018-03-29 00:00:00	2018-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14060	2018-03-29 17:22:24	2018-05-22 16:40:01
16783	MEMBRECOM	2018-03-29 00:00:00	2018-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14061	2018-03-29 17:22:30	2018-05-22 16:40:01
16784	MEMBRECOM	2018-03-29 00:00:00	2018-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14062	2018-03-29 17:22:37	2018-05-22 16:40:01
16785	MEMBRECOM	2018-03-29 00:00:00	2018-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14063	2018-03-29 17:22:42	2018-05-22 16:40:01
16786	MEMBRECOM	2018-03-29 00:00:00	2018-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14064	2018-03-29 17:22:46	2018-05-22 16:40:01
16787	MEMBRECOM	2018-03-29 00:00:00	2018-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14065	2018-03-29 17:22:53	2018-05-22 16:40:01
16788	MEMBRECOM	2018-03-29 00:00:00	2018-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14066	2018-03-29 17:22:59	2018-05-22 16:40:01
16789	MEMBRECOM	2018-03-29 00:00:00	2018-04-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14067	2018-03-29 17:23:05	2018-05-22 16:40:01
17128	MEMBRECOM	2018-08-07 00:00:00	2018-09-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14387	\N	\N
17264	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14522	\N	\N
17265	MEMBRECOM	2018-10-10 00:00:00	2019-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14523	\N	\N
17269	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14527	\N	\N
17267	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14525	\N	\N
17268	MEMBRECOM	2018-10-10 00:00:00	2018-11-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14526	\N	\N
17270	MEMBRECOM	2018-10-10 00:00:00	2019-05-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14528	\N	\N
17271	MEMBRECOM	2018-10-10 00:00:00	2019-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14529	\N	\N
17272	MEMBRECOM	2018-10-10 00:00:00	2019-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14530	\N	\N
17273	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14531	\N	\N
17274	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14532	\N	\N
17275	MEMBRECOM	2018-10-10 00:00:00	2019-01-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14533	\N	\N
17276	MEMBRECOM	2018-10-10 00:00:00	2019-05-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14534	\N	\N
17277	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14535	\N	\N
17278	MEMBRECOM	2018-10-10 00:00:00	2019-05-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14536	\N	\N
17279	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14537	\N	\N
17280	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14538	\N	\N
17284	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14542	\N	\N
17286	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14544	\N	\N
17285	MEMBRECOM	2018-10-10 00:00:00	2018-11-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14543	\N	\N
17287	MEMBRECOM	2018-10-10 00:00:00	2018-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14545	\N	\N
17288	MEMBRECOM	2018-10-10 00:00:00	2018-11-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14546	\N	\N
17308	VICPDTCOM	2018-10-11 00:00:00	2018-11-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14525	\N	\N
17309	VICPDTCOM	2018-10-11 00:00:00	2018-11-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14486	\N	\N
17310	VICPDTCOM	2018-10-11 00:00:00	2018-11-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14482	\N	\N
17311	VICPDTCOM	2018-10-11 00:00:00	2018-11-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14545	\N	\N
17312	VICPDTCOM	2018-10-11 00:00:00	2018-11-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14477	\N	\N
17313	VICPDTCOM	2018-10-11 00:00:00	2018-11-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14480	\N	\N
17314	VICPDTCOM	2018-10-11 00:00:00	2018-11-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14491	\N	\N
17315	SECRETCOM	2018-10-11 00:00:00	2018-11-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14485	\N	\N
17316	SECRETCOM	2018-10-11 00:00:00	2018-11-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14475	\N	\N
17317	SECRETCOM	2018-10-11 00:00:00	2018-11-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14544	\N	\N
17318	RAPCOM	2018-10-11 00:00:00	2018-11-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14542	\N	\N
17319	RAPCOM	2018-10-11 00:00:00	2018-11-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14467	\N	\N
17320	RAPCOM	2018-10-11 00:00:00	2019-05-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14535	\N	\N
17321	RAPCOM	2018-10-11 00:00:00	2019-05-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14500	\N	\N
17322	RAPCOM	2018-10-11 00:00:00	2019-05-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14501	\N	\N
17323	PDTCOM	2018-10-11 00:00:00	2019-05-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14537	\N	\N
17324	VICPDTCOM	2018-10-11 00:00:00	2019-05-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14494	\N	\N
17325	VICPDTCOM	2018-10-11 00:00:00	2019-05-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14495	\N	\N
17326	VICPDTCOM	2018-10-11 00:00:00	2019-05-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14502	\N	\N
17327	VICPDTCOM	2018-10-11 00:00:00	2019-05-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14503	\N	\N
17328	VICPDTCOM	2018-10-11 00:00:00	2019-05-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14517	\N	\N
17329	VICPDTCOM	2018-10-11 00:00:00	2019-05-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14518	\N	\N
17330	VICPDTCOM	2018-10-11 00:00:00	2019-05-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14508	\N	\N
17331	VICPDTCOM	2018-10-11 00:00:00	2019-05-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14527	\N	\N
17332	VICPDTCOM	2018-10-11 00:00:00	2019-05-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14512	\N	\N
17333	SECRETCOM	2018-10-11 00:00:00	2019-05-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14507	\N	\N
17334	SECRETCOM	2018-10-11 00:00:00	2019-05-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14521	\N	\N
17335	SECRETCOM	2018-10-11 00:00:00	2019-05-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14538	\N	\N
17336	VICPDTCOM	2018-10-11 00:00:00	2019-05-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14511	\N	\N
17383	MEMBRECOM	2018-11-19 00:00:00	2019-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4297	\N	\N
17444	MEMBRECOM	2018-12-06 00:00:00	2018-12-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13031	\N	\N
17532	MEMBRECOM	2019-01-15 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14720	\N	\N
17534	MEMBRECOM	2019-01-24 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8726	\N	\N
17535	MEMBRECOM	2019-01-24 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14721	\N	\N
17561	MEMBRECOM	2019-01-30 00:00:00	2019-02-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14747	\N	\N
17562	MEMBRECOM	2019-01-30 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14748	\N	\N
17583	MEMBRECOM	2019-03-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14765	\N	\N
17584	MEMBRECOM	2019-03-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14766	\N	\N
17596	MEMBRECOM	2019-03-06 00:00:00	2019-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14778	\N	\N
17597	MEMBRECOM	2019-03-06 00:00:00	2019-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14779	\N	\N
17598	MEMBRECOM	2019-03-06 00:00:00	2019-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14780	\N	\N
17599	MEMBRECOM	2019-03-06 00:00:00	2019-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14781	\N	\N
17600	MEMBRECOM	2019-03-06 00:00:00	2019-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14782	\N	\N
17601	MEMBRECOM	2019-03-06 00:00:00	2019-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14783	\N	\N
17602	MEMBRECOM	2019-03-06 00:00:00	2019-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14784	\N	\N
17603	MEMBRECOM	2019-03-06 00:00:00	2019-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14785	\N	\N
17604	MEMBRECOM	2019-03-06 00:00:00	2019-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14786	\N	\N
17605	MEMBRECOM	2019-03-06 00:00:00	2019-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14787	\N	\N
17606	MEMBRECOM	2019-03-06 00:00:00	2019-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14788	\N	\N
17607	MEMBRECOM	2019-03-06 00:00:00	2019-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14789	\N	\N
17608	MEMBRECOM	2019-03-06 00:00:00	2019-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14790	\N	\N
17609	MEMBRECOM	2019-03-06 00:00:00	2019-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14791	\N	\N
17610	MEMBRECOM	2019-03-06 00:00:00	2019-09-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14792	\N	\N
17611	MEMBRECOM	2019-03-06 00:00:00	2019-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14793	\N	\N
17612	MEMBRECOM	2019-03-13 00:00:00	2019-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14794	\N	\N
17615	MEMBRECOM	2019-03-20 00:00:00	2019-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14795	\N	\N
17616	MEMBRECOM	2019-03-20 00:00:00	2019-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14796	\N	\N
17617	MEMBRECOM	2019-03-20 00:00:00	2019-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14797	\N	\N
17618	MEMBRECOM	2019-03-20 00:00:00	2019-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14798	\N	\N
17619	MEMBRECOM	2019-03-20 00:00:00	2019-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14799	\N	\N
17620	MEMBRECOM	2019-03-20 00:00:00	2019-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14800	\N	\N
17621	MEMBRECOM	2019-03-20 00:00:00	2019-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14801	\N	\N
17622	MEMBRECOM	2019-03-20 00:00:00	2019-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14802	\N	\N
17623	MEMBRECOM	2019-03-20 00:00:00	2019-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14803	\N	\N
17624	MEMBRECOM	2019-03-20 00:00:00	2019-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14804	\N	\N
17625	MEMBRECOM	2019-03-20 00:00:00	2019-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14805	\N	\N
17626	MEMBRECOM	2019-03-20 00:00:00	2019-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14806	\N	\N
17627	MEMBRECOM	2019-03-20 00:00:00	2019-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14807	\N	\N
17628	MEMBRECOM	2019-03-20 00:00:00	2019-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14808	\N	\N
17629	MEMBRECOM	2019-03-20 00:00:00	2019-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14809	\N	\N
17630	MEMBRECOM	2019-03-20 00:00:00	2019-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14810	\N	\N
17631	MEMBRECOM	2019-03-20 00:00:00	2019-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14811	\N	\N
17632	MEMBRECOM	2019-03-20 00:00:00	2019-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14812	\N	\N
17633	MEMBRECOM	2019-03-20 00:00:00	2019-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14813	\N	\N
17634	MEMBRECOM	2019-03-20 00:00:00	2019-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14814	\N	\N
17635	MEMBRECOM	2019-03-20 00:00:00	2019-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14815	\N	\N
17636	MEMBRECOM	2019-03-20 00:00:00	2019-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14816	\N	\N
17637	MEMBRECOM	2019-03-20 00:00:00	2019-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14817	\N	\N
17638	MEMBRECOM	2019-03-20 00:00:00	2019-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14818	\N	\N
17639	MEMBRECOM	2019-03-20 00:00:00	2019-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14819	\N	\N
17640	MEMBRECOM	2019-03-20 00:00:00	2019-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14820	\N	\N
17641	MEMBRECOM	2019-03-20 00:00:00	2019-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14821	\N	\N
17642	MEMBRECOM	2019-03-20 00:00:00	2019-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14822	\N	\N
18156	MEMBRECOM	2019-10-23 00:00:00	2021-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15264	\N	\N
18446	PDTCOM	2020-02-25 00:00:00	2020-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15499	\N	\N
18447	RAPCOM	2020-02-25 00:00:00	2020-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15512	\N	\N
18448	VICPDTCOM	2020-02-25 00:00:00	2020-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15513	\N	\N
18449	VICPDTCOM	2020-02-25 00:00:00	2020-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15516	\N	\N
18450	VICPDTCOM	2020-02-25 00:00:00	2020-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15509	\N	\N
18451	VICPDTCOM	2020-02-25 00:00:00	2020-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15511	\N	\N
18452	VICPDTCOM	2020-02-25 00:00:00	2020-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15517	\N	\N
18453	VICPDTCOM	2020-02-25 00:00:00	2020-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15506	\N	\N
18454	VICPDTCOM	2020-02-25 00:00:00	2020-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15497	\N	\N
18506	MEMBRECOM	2020-05-13 00:00:00	2020-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15569	\N	\N
18507	MEMBRECOM	2020-05-13 00:00:00	2020-05-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15570	\N	\N
18508	MEMBRECOM	2020-05-13 00:00:00	2020-05-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15571	\N	\N
18509	MEMBRECOM	2020-05-13 00:00:00	2020-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15572	\N	\N
18510	MEMBRECOM	2020-05-13 00:00:00	2020-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15573	\N	\N
18511	MEMBRECOM	2020-05-13 00:00:00	2020-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15574	\N	\N
18512	MEMBRECOM	2020-05-13 00:00:00	2020-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15575	\N	\N
18513	MEMBRECOM	2020-05-13 00:00:00	2020-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15576	\N	\N
18514	MEMBRECOM	2020-05-13 00:00:00	2020-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15577	\N	\N
18515	MEMBRECOM	2020-05-13 00:00:00	2020-05-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15578	\N	\N
18516	MEMBRECOM	2020-05-13 00:00:00	2020-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15579	\N	\N
18517	MEMBRECOM	2020-05-13 00:00:00	2020-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15580	\N	\N
18518	MEMBRECOM	2020-05-13 00:00:00	2020-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15581	\N	\N
18519	MEMBRECOM	2020-05-13 00:00:00	2020-05-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15582	\N	\N
18520	MEMBRECOM	2020-05-13 00:00:00	2020-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15583	\N	\N
18521	MEMBRECOM	2020-05-13 00:00:00	2020-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15584	\N	\N
18522	MEMBRECOM	2020-05-13 00:00:00	2020-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15585	\N	\N
18523	MEMBRECOM	2020-05-13 00:00:00	2020-05-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15586	\N	\N
18524	MEMBRECOM	2020-05-13 00:00:00	2020-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15587	\N	\N
18525	MEMBRECOM	2020-05-13 00:00:00	2020-05-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15588	\N	\N
18526	MEMBRECOM	2020-05-13 00:00:00	2020-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15589	\N	\N
18527	MEMBRECOM	2020-05-13 00:00:00	2020-05-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15590	\N	\N
18528	MEMBRECOM	2020-05-13 00:00:00	2020-05-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15591	\N	\N
19478	PDTCOM	2020-10-13 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16134	\N	\N
19479	VICPDTCOM	2020-10-13 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16139	\N	\N
19480	RAPCOM	2020-10-13 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16138	\N	\N
18847	MEMBRECOM	2020-08-09 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15873	\N	\N
18848	MEMBRECOM	2020-08-09 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15874	\N	\N
18849	MEMBRECOM	2020-08-09 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15875	\N	\N
19558	MEMBRECOM	2020-10-16 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15743	\N	\N
22873	MEMBRECOM	2023-11-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19025	\N	\N
22875	MEMBRECOM	2023-11-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19027	\N	\N
22878	MEMBRECOM	2023-11-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19030	\N	\N
22879	MEMBRECOM	2023-11-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19031	\N	\N
22880	MEMBRECOM	2023-11-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19032	\N	\N
22881	MEMBRECOM	2023-11-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19033	\N	\N
22882	MEMBRECOM	2023-11-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19034	\N	\N
22883	MEMBRECOM	2023-11-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19035	\N	\N
22884	MEMBRECOM	2023-11-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19036	\N	\N
22885	MEMBRECOM	2023-11-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19037	\N	\N
22887	MEMBRECOM	2023-11-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19039	\N	\N
22888	MEMBRECOM	2023-11-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19040	\N	\N
22890	MEMBRECOM	2023-11-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19042	\N	\N
22892	MEMBRECOM	2023-11-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19044	\N	\N
22893	MEMBRECOM	2023-11-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19045	\N	\N
22894	MEMBRECOM	2023-11-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19046	\N	\N
22896	MEMBRECOM	2023-11-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19048	\N	\N
22897	MEMBRECOM	2023-11-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19049	\N	\N
22898	MEMBRECOM	2023-11-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19050	\N	\N
22900	MEMBRECOM	2023-11-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19052	\N	\N
22902	MEMBRECOM	2023-11-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19054	\N	\N
22903	MEMBRECOM	2023-11-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19055	\N	\N
22905	MEMBRECOM	2023-11-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19057	\N	\N
23415	PDTCOM	2024-03-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19444	\N	\N
23416	RAPCOM	2024-03-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19452	\N	\N
23417	VICPDTCOM	2024-03-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19434	\N	\N
23418	VICPDTCOM	2024-03-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19436	\N	\N
23419	VICPDTCOM	2024-03-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19446	\N	\N
23420	VICPDTCOM	2024-03-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19448	\N	\N
23421	VICPDTCOM	2024-03-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19451	\N	\N
23422	VICPDTCOM	2024-03-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19453	\N	\N
23423	VICPDTCOM	2024-03-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19454	\N	\N
23424	SECRETCOM	2024-03-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19439	\N	\N
23425	SECRETCOM	2024-03-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19445	\N	\N
23426	VICPDTCOM	2024-03-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19455	\N	\N
23443	MEMBRECOM	2024-03-07 00:00:00	2024-03-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19483	\N	\N
23444	MEMBRECOM	2024-03-07 00:00:00	2024-03-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19484	\N	\N
23445	MEMBRECOM	2024-03-07 00:00:00	2024-03-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19485	\N	\N
23446	MEMBRECOM	2024-03-07 00:00:00	2024-03-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19486	\N	\N
23447	MEMBRECOM	2024-03-07 00:00:00	2024-03-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19487	\N	\N
23448	MEMBRECOM	2024-03-07 00:00:00	2024-03-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19488	\N	\N
23449	MEMBRECOM	2024-03-07 00:00:00	2024-03-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19489	\N	\N
23452	MEMBRECOM	2024-03-07 00:00:00	2024-03-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19492	\N	\N
23453	MEMBRECOM	2024-03-07 00:00:00	2024-03-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19493	\N	\N
23454	MEMBRECOM	2024-03-07 00:00:00	2024-03-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19494	\N	\N
23455	MEMBRECOM	2024-03-07 00:00:00	2024-03-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19495	\N	\N
23456	MEMBRECOM	2024-03-07 00:00:00	2024-03-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19496	\N	\N
23457	MEMBRECOM	2024-03-12 00:00:00	2024-03-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19497	\N	\N
23458	MEMBRECOM	2024-03-12 00:00:00	2024-03-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19498	\N	\N
23459	MEMBRECOM	2024-03-12 00:00:00	2024-03-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19499	\N	\N
23460	MEMBRECOM	2024-03-12 00:00:00	2024-03-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19500	\N	\N
23461	MEMBRECOM	2024-03-12 00:00:00	2024-03-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19501	\N	\N
23462	MEMBRECOM	2024-03-12 00:00:00	2024-03-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19502	\N	\N
23463	MEMBRECOM	2024-03-12 00:00:00	2024-03-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19503	\N	\N
23465	MEMBRECOM	2024-03-12 00:00:00	2024-03-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19505	\N	\N
23466	MEMBRECOM	2024-03-12 00:00:00	2024-03-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19506	\N	\N
23468	MEMBRECOM	2024-03-12 00:00:00	2024-03-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19508	\N	\N
23469	MEMBRECOM	2024-03-12 00:00:00	2024-03-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19509	\N	\N
23470	MEMBRECOM	2024-03-12 00:00:00	2024-03-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19510	\N	\N
18047	SECRETCOM	2019-07-25 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10232	\N	\N
18048	VICPDTCOM	2019-07-25 00:00:00	2020-10-06 00:00:00	12	ANCIEN	\N	\N	\N	\N	13555	\N	\N
19460	MEMBRECOM	2020-10-07 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15744	\N	\N
19461	MEMBRECOM	2020-10-07 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15734	\N	\N
19462	VICPDTCOM	2020-10-07 00:00:00	2021-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15231	\N	\N
19463	VICPDTCOM	2020-10-07 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15477	\N	\N
19464	VICPDTCOM	2020-10-07 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15492	\N	\N
20299	MEMBRECOM	2021-05-25 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16887	\N	\N
20300	MEMBRECOM	2021-05-25 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16888	\N	\N
20301	MEMBRECOM	2021-05-25 00:00:00	2022-07-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16889	\N	\N
22920	PDTCOM	2023-11-15 00:00:00	2023-11-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19058	\N	\N
22921	RAPCOM	2023-11-15 00:00:00	2023-11-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19059	\N	\N
22922	MEMBRECOM	2023-11-15 00:00:00	2023-11-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19060	\N	\N
22923	MEMBRECOM	2023-11-15 00:00:00	2023-11-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19061	\N	\N
22924	MEMBRECOM	2023-11-15 00:00:00	2023-11-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19062	\N	\N
22925	MEMBRECOM	2023-11-15 00:00:00	2023-11-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19063	\N	\N
22926	MEMBRECOM	2023-11-15 00:00:00	2023-11-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19064	\N	\N
22927	MEMBRECOM	2023-11-15 00:00:00	2023-11-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19065	\N	\N
22928	MEMBRECOM	2023-11-15 00:00:00	2023-11-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19066	\N	\N
22929	MEMBRECOM	2023-11-15 00:00:00	2023-11-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19067	\N	\N
22930	MEMBRECOM	2023-11-15 00:00:00	2023-11-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19068	\N	\N
22931	MEMBRECOM	2023-11-15 00:00:00	2023-11-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19069	\N	\N
22932	MEMBRECOM	2023-11-15 00:00:00	2023-11-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19070	\N	\N
22933	MEMBRECOM	2023-11-15 00:00:00	2023-11-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19071	\N	\N
17971	MEMBRECOM	2019-07-03 00:00:00	2019-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15097	\N	\N
17972	MEMBRECOM	2019-07-03 00:00:00	2019-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15098	\N	\N
17973	MEMBRECOM	2019-07-03 00:00:00	2019-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15099	\N	\N
17974	MEMBRECOM	2019-07-03 00:00:00	2019-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15100	\N	\N
17975	MEMBRECOM	2019-07-03 00:00:00	2019-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15101	\N	\N
17976	MEMBRECOM	2019-07-03 00:00:00	2019-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15102	\N	\N
17977	MEMBRECOM	2019-07-03 00:00:00	2019-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15103	\N	\N
17978	MEMBRECOM	2019-07-03 00:00:00	2019-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15104	\N	\N
17979	MEMBRECOM	2019-07-03 00:00:00	2019-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15105	\N	\N
17980	MEMBRECOM	2019-07-03 00:00:00	2019-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15106	\N	\N
17981	MEMBRECOM	2019-07-03 00:00:00	2019-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15107	\N	\N
17982	MEMBRECOM	2019-07-03 00:00:00	2019-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15108	\N	\N
17983	MEMBRECOM	2019-07-03 00:00:00	2019-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15109	\N	\N
17984	MEMBRECOM	2019-07-03 00:00:00	2019-07-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15110	\N	\N
17985	MEMBRECOM	2019-07-02 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15111	\N	\N
17986	MEMBRECOM	2019-07-02 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15112	\N	\N
17987	MEMBRECOM	2019-07-02 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15113	\N	\N
17988	MEMBRECOM	2019-07-02 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15114	\N	\N
17989	MEMBRECOM	2019-07-02 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15115	\N	\N
17990	MEMBRECOM	2019-07-02 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15116	\N	\N
17991	MEMBRECOM	2019-07-02 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15117	\N	\N
17992	MEMBRECOM	2019-07-02 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15118	\N	\N
17993	MEMBRECOM	2019-07-02 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15119	\N	\N
17994	MEMBRECOM	2019-07-02 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15120	\N	\N
17995	MEMBRECOM	2019-07-02 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15121	\N	\N
17996	MEMBRECOM	2019-07-02 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15122	\N	\N
17997	MEMBRECOM	2019-07-02 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15123	\N	\N
17998	MEMBRECOM	2019-07-02 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15124	\N	\N
17999	VICPDTCOM	2019-07-04 00:00:00	2020-10-05 00:00:00	9	ANCIEN	\N	\N	\N	\N	13452	\N	\N
18196	MEMBRECOM	2019-11-14 00:00:00	2019-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15286	\N	\N
18197	MEMBRECOM	2019-11-14 00:00:00	2019-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15287	\N	\N
18198	MEMBRECOM	2019-11-14 00:00:00	2019-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15288	\N	\N
18199	MEMBRECOM	2019-11-14 00:00:00	2019-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15289	\N	\N
18200	MEMBRECOM	2019-11-14 00:00:00	2019-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15290	\N	\N
18201	MEMBRECOM	2019-11-14 00:00:00	2019-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15291	\N	\N
18202	MEMBRECOM	2019-11-14 00:00:00	2019-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15292	\N	\N
18203	MEMBRECOM	2019-11-14 00:00:00	2019-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15293	\N	\N
18204	MEMBRECOM	2019-11-14 00:00:00	2019-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15294	\N	\N
18205	MEMBRECOM	2019-11-14 00:00:00	2019-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15295	\N	\N
18206	MEMBRECOM	2019-11-14 00:00:00	2019-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15296	\N	\N
18207	MEMBRECOM	2019-11-14 00:00:00	2019-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15297	\N	\N
18208	MEMBRECOM	2019-11-14 00:00:00	2019-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15298	\N	\N
18209	MEMBRECOM	2019-11-14 00:00:00	2019-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15299	\N	\N
18459	MEMBRECOM	2020-03-04 00:00:00	2020-03-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15522	\N	\N
19544	MEMBRECOM	2020-11-01 00:00:00	2020-11-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16207	\N	\N
19745	MEMBRECOM	2021-02-09 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16383	\N	\N
20697	VICPDTCOM	2022-07-13 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17177	\N	\N
23538	MEMBRECOM	2024-03-22 00:00:00	2024-03-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19570	\N	\N
23539	MEMBRECOM	2024-03-22 00:00:00	2024-03-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19571	\N	\N
23540	MEMBRECOM	2024-03-22 00:00:00	2024-03-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19572	\N	\N
23541	MEMBRECOM	2024-03-22 00:00:00	2024-03-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19573	\N	\N
23542	MEMBRECOM	2024-03-22 00:00:00	2024-03-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19574	\N	\N
23543	MEMBRECOM	2024-03-22 00:00:00	2024-03-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19575	\N	\N
23544	MEMBRECOM	2024-03-22 00:00:00	2024-03-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19576	\N	\N
23545	MEMBRECOM	2024-03-22 00:00:00	2024-03-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19577	\N	\N
23546	MEMBRECOM	2024-03-22 00:00:00	2024-03-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19578	\N	\N
23547	MEMBRECOM	2024-03-22 00:00:00	2024-03-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19579	\N	\N
23548	MEMBRECOM	2024-03-22 00:00:00	2024-03-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19580	\N	\N
23555	MEMBRECOM	2024-03-22 00:00:00	2024-03-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19587	\N	\N
23550	MEMBRECOM	2024-03-22 00:00:00	2024-03-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19582	\N	\N
23551	MEMBRECOM	2024-03-22 00:00:00	2024-03-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19583	\N	\N
23552	MEMBRECOM	2024-03-22 00:00:00	2024-03-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19584	\N	\N
23553	MEMBRECOM	2024-03-22 00:00:00	2024-03-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19585	\N	\N
23554	MEMBRECOM	2024-03-22 00:00:00	2024-03-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19586	\N	\N
23556	MEMBRECOM	2024-03-22 00:00:00	2024-03-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19588	\N	\N
23557	MEMBRECOM	2024-03-22 00:00:00	2024-03-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19589	\N	\N
23558	MEMBRECOM	2024-03-22 00:00:00	2024-03-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19590	\N	\N
23559	MEMBRECOM	2024-03-22 00:00:00	2024-03-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19591	\N	\N
23560	MEMBRECOM	2024-03-22 00:00:00	2024-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19592	\N	\N
23561	MEMBRECOM	2024-03-22 00:00:00	2024-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19593	\N	\N
23562	MEMBRECOM	2024-03-22 00:00:00	2024-03-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19594	\N	\N
23563	MEMBRECOM	2024-03-22 00:00:00	2024-03-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19595	\N	\N
23564	MEMBRECOM	2024-03-22 00:00:00	2024-03-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19596	\N	\N
23565	MEMBRECOM	2024-03-22 00:00:00	2024-03-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19597	\N	\N
23566	MEMBRECOM	2024-03-22 00:00:00	2024-03-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19598	\N	\N
17733	PDTCOM	2019-05-14 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14861	\N	\N
17734	RAPCOM	2019-05-14 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14872	\N	\N
17802	VICPDTCOM	2019-05-28 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14941	\N	\N
17803	VICPDTCOM	2019-05-28 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14921	\N	\N
17804	VICPDTCOM	2019-05-28 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14920	\N	\N
17944	PDTCOM	2019-05-07 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14833	\N	\N
17945	RAPCOM	2019-05-07 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14841	\N	\N
17946	VICPDTCOM	2019-05-07 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14839	\N	\N
17947	VICPDTCOM	2019-05-07 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14834	\N	\N
17948	VICPDTCOM	2019-05-07 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14829	\N	\N
17949	VICPDTCOM	2019-05-07 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14836	\N	\N
17950	VICPDTCOM	2019-05-07 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14847	\N	\N
17951	VICPDTCOM	2019-05-07 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14846	\N	\N
17952	VICPDTCOM	2019-05-07 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14835	\N	\N
17953	PDTCOM	2019-02-06 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14738	\N	\N
17954	RAPCOM	2019-02-06 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14723	\N	\N
17955	VICPDTCOM	2019-02-06 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14736	\N	\N
17956	VICPDTCOM	2019-02-06 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14727	\N	\N
17957	VICPDTCOM	2019-02-06 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14744	\N	\N
17958	VICPDTCOM	2019-02-06 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14743	\N	\N
17959	VICPDTCOM	2019-02-06 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14747	\N	\N
17960	VICPDTCOM	2019-02-06 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14745	\N	\N
17961	VICPDTCOM	2019-02-06 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14746	\N	\N
17962	PDTCOM	2019-01-22 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14704	\N	\N
17963	RAPCOM	2019-01-22 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14713	\N	\N
17964	VICPDTCOM	2019-01-22 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14696	\N	\N
17965	VICPDTCOM	2019-01-22 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14717	\N	\N
17966	VICPDTCOM	2019-01-22 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14709	\N	\N
17967	VICPDTCOM	2019-01-22 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14711	\N	\N
18238	PDTCOM	2019-11-26 00:00:00	2020-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15282	\N	\N
18239	RAPCOM	2019-11-26 00:00:00	2020-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15275	\N	\N
18240	VICPDTCOM	2019-11-26 00:00:00	2020-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15283	\N	\N
18241	VICPDTCOM	2019-11-26 00:00:00	2020-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15285	\N	\N
18242	VICPDTCOM	2019-11-26 00:00:00	2020-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15267	\N	\N
18243	VICPDTCOM	2019-11-26 00:00:00	2020-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15281	\N	\N
18244	VICPDTCOM	2019-11-26 00:00:00	2020-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15269	\N	\N
18245	VICPDTCOM	2019-11-26 00:00:00	2020-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15276	\N	\N
18246	VICPDTCOM	2019-11-26 00:00:00	2020-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15271	\N	\N
18247	VICPDTCOM	2019-11-26 00:00:00	2020-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15284	\N	\N
18424	MEMBRECOM	2020-02-06 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15496	\N	\N
18862	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15887	\N	\N
19483	PDTCOM	2020-10-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16146	\N	\N
19484	RAPCOM	2020-10-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16147	\N	\N
19485	MEMBRECOM	2020-10-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16148	\N	\N
19486	MEMBRECOM	2020-10-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16149	\N	\N
19487	MEMBRECOM	2020-10-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16150	\N	\N
19488	MEMBRECOM	2020-10-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16151	\N	\N
19489	MEMBRECOM	2020-10-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16152	\N	\N
19490	MEMBRECOM	2020-10-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16153	\N	\N
19491	MEMBRECOM	2020-10-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16154	\N	\N
19492	MEMBRECOM	2020-10-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16155	\N	\N
19493	MEMBRECOM	2020-10-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16156	\N	\N
19494	MEMBRECOM	2020-10-21 00:00:00	2021-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16157	\N	\N
19495	MEMBRECOM	2020-10-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16158	\N	\N
19496	MEMBRECOM	2020-10-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16159	\N	\N
20757	MEMBRECOM	2023-01-24 00:00:00	2023-02-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17231	\N	\N
20758	MEMBRECOM	2023-01-24 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17232	\N	\N
20759	MEMBRECOM	2023-01-24 00:00:00	2023-02-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17233	\N	\N
20760	MEMBRECOM	2023-01-24 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17234	\N	\N
20761	MEMBRECOM	2023-01-24 00:00:00	2023-02-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17235	\N	\N
20762	MEMBRECOM	2023-01-24 00:00:00	2023-02-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17236	\N	\N
20763	MEMBRECOM	2023-01-24 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17237	\N	\N
20764	MEMBRECOM	2023-01-24 00:00:00	2023-02-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17238	\N	\N
20765	MEMBRECOM	2023-01-24 00:00:00	2023-02-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17239	\N	\N
20766	MEMBRECOM	2023-01-24 00:00:00	2023-02-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17240	\N	\N
20767	MEMBRECOM	2023-01-24 00:00:00	2023-02-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17241	\N	\N
20768	MEMBRECOM	2023-01-24 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17242	\N	\N
20769	MEMBRECOM	2023-01-24 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17243	\N	\N
20770	MEMBRECOM	2023-01-24 00:00:00	2023-02-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17244	\N	\N
20771	MEMBRECOM	2023-01-24 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17245	\N	\N
20772	MEMBRECOM	2023-01-24 00:00:00	2023-02-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17246	\N	\N
20773	MEMBRECOM	2023-01-24 00:00:00	2023-02-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17247	\N	\N
20774	MEMBRECOM	2023-01-24 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17248	\N	\N
20775	MEMBRECOM	2023-01-24 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17249	\N	\N
20776	MEMBRECOM	2023-01-24 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17250	\N	\N
20777	MEMBRECOM	2023-01-24 00:00:00	2023-02-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17251	\N	\N
23571	PDTCOM	2024-03-27 00:00:00	2024-03-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19562	\N	\N
23572	RAPCOM	2024-03-27 00:00:00	2024-03-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19563	\N	\N
23573	RAPCOM	2024-03-27 00:00:00	2024-03-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19557	\N	\N
23667	MEMBRECOM	2024-03-07 00:00:00	2024-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19684	\N	\N
23668	MEMBRECOM	2024-03-07 00:00:00	2024-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19685	\N	\N
23669	MEMBRECOM	2024-03-07 00:00:00	2024-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19686	\N	\N
23670	MEMBRECOM	2024-03-07 00:00:00	2024-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19687	\N	\N
23671	MEMBRECOM	2024-03-07 00:00:00	2024-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19688	\N	\N
23672	MEMBRECOM	2024-03-07 00:00:00	2024-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19689	\N	\N
23673	MEMBRECOM	2024-03-07 00:00:00	2024-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19690	\N	\N
23674	MEMBRECOM	2024-03-07 00:00:00	2024-04-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19691	\N	\N
23675	MEMBRECOM	2024-03-07 00:00:00	2024-04-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19692	\N	\N
23676	MEMBRECOM	2024-03-07 00:00:00	2024-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19693	\N	\N
23677	MEMBRECOM	2024-03-07 00:00:00	2024-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19694	\N	\N
23678	MEMBRECOM	2024-03-07 00:00:00	2024-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19695	\N	\N
23679	MEMBRECOM	2024-03-07 00:00:00	2024-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19696	\N	\N
23680	MEMBRECOM	2024-03-07 00:00:00	2024-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19697	\N	\N
23681	PDTCOM	2024-04-03 00:00:00	2024-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19691	\N	\N
23682	RAPCOM	2024-04-03 00:00:00	2024-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19692	\N	\N
21565	MEMBRECOM	2022-12-15 00:00:00	2022-12-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17887	\N	\N
21568	MEMBRECOM	2022-12-06 00:00:00	2022-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17890	\N	\N
21577	MEMBRECOM	2022-12-06 00:00:00	2022-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17899	\N	\N
21582	MEMBRECOM	2022-12-01 00:00:00	2022-12-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17904	\N	\N
21590	RAPCOM	2022-12-01 00:00:00	2022-12-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17912	\N	\N
17759	MEMBRECOM	2019-05-22 00:00:00	2019-05-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14921	\N	\N
17784	PDTCOM	2019-05-28 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14925	\N	\N
17758	MEMBRECOM	2019-05-22 00:00:00	2019-05-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14920	\N	\N
17795	VICPDTCOM	2019-05-28 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14924	\N	\N
17787	RAPCOM	2019-05-28 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14932	\N	\N
17797	VICPDTCOM	2019-05-28 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14922	\N	\N
17799	VICPDTCOM	2019-05-28 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14935	\N	\N
20264	PDTCOM	2021-04-08 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16362	\N	\N
17800	VICPDTCOM	2019-05-28 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14930	\N	\N
20265	RAPCOM	2021-04-08 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16379	\N	\N
20266	VICPDTCOM	2021-04-08 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16361	\N	\N
20267	VICPDTCOM	2021-04-08 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16376	\N	\N
20268	VICPDTCOM	2021-04-08 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16377	\N	\N
20269	VICPDTCOM	2021-04-08 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16373	\N	\N
20270	VICPDTCOM	2021-04-08 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16378	\N	\N
20271	VICPDTCOM	2021-04-08 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16381	\N	\N
20272	VICPDTCOM	2021-04-08 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16380	\N	\N
20273	VICPDTCOM	2021-04-08 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16382	\N	\N
20274	VICPDTCOM	2021-04-08 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16363	\N	\N
20275	VICPDTCOM	2021-04-08 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16372	\N	\N
20811	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17273	\N	\N
18597	MEMBRECOM	2020-05-04 00:00:00	2020-05-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15634	\N	\N
18598	MEMBRECOM	2020-05-04 00:00:00	2020-05-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15635	\N	\N
18599	MEMBRECOM	2020-05-04 00:00:00	2020-05-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15636	\N	\N
18600	MEMBRECOM	2020-05-04 00:00:00	2020-05-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15637	\N	\N
18601	MEMBRECOM	2020-05-04 00:00:00	2020-05-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15638	\N	\N
18602	MEMBRECOM	2020-05-04 00:00:00	2020-05-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15639	\N	\N
18603	MEMBRECOM	2020-05-04 00:00:00	2020-05-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15640	\N	\N
18604	MEMBRECOM	2020-05-04 00:00:00	2020-05-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15641	\N	\N
18605	MEMBRECOM	2020-05-04 00:00:00	2020-05-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15642	\N	\N
18606	MEMBRECOM	2020-05-04 00:00:00	2020-05-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15643	\N	\N
18607	MEMBRECOM	2020-05-04 00:00:00	2020-05-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15644	\N	\N
18608	MEMBRECOM	2020-05-04 00:00:00	2020-05-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15645	\N	\N
18609	MEMBRECOM	2020-05-04 00:00:00	2020-05-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15646	\N	\N
18610	MEMBRECOM	2020-05-04 00:00:00	2020-05-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15647	\N	\N
18780	MEMBRECOM	2020-07-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15806	\N	\N
18781	MEMBRECOM	2020-07-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15807	\N	\N
18782	MEMBRECOM	2020-07-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15808	\N	\N
18783	MEMBRECOM	2020-07-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15809	\N	\N
18784	MEMBRECOM	2020-07-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15810	\N	\N
18785	MEMBRECOM	2020-07-08 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15811	\N	\N
18786	MEMBRECOM	2020-07-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15812	\N	\N
18787	MEMBRECOM	2020-07-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15813	\N	\N
18788	MEMBRECOM	2020-07-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15814	\N	\N
18789	MEMBRECOM	2020-07-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15815	\N	\N
18790	MEMBRECOM	2020-07-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15816	\N	\N
18791	MEMBRECOM	2020-07-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15817	\N	\N
18792	MEMBRECOM	2020-07-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15818	\N	\N
18793	MEMBRECOM	2020-07-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15819	\N	\N
20824	MEMBRECOM	2023-02-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17274	\N	\N
20867	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17317	\N	\N
20868	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17318	\N	\N
20869	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17319	\N	\N
20870	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17320	\N	\N
20871	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17321	\N	\N
20872	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17322	\N	\N
20873	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17323	\N	\N
20874	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17324	\N	\N
20875	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17325	\N	\N
20876	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17326	\N	\N
20877	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17327	\N	\N
20878	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17328	\N	\N
20879	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17329	\N	\N
20880	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17330	\N	\N
20884	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17334	\N	\N
20882	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17332	\N	\N
20883	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17333	\N	\N
20885	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17335	\N	\N
20886	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17336	\N	\N
20887	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17337	\N	\N
20888	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17338	\N	\N
20889	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17339	\N	\N
20890	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17340	\N	\N
20891	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17341	\N	\N
20892	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17342	\N	\N
20893	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17343	\N	\N
20894	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17344	\N	\N
20895	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17345	\N	\N
20896	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17346	\N	\N
20897	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17347	\N	\N
20898	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17348	\N	\N
20899	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17349	\N	\N
20900	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17350	\N	\N
20901	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17351	\N	\N
20902	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17352	\N	\N
20903	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17353	\N	\N
20904	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17354	\N	\N
20905	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17355	\N	\N
20909	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17359	\N	\N
20907	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17357	\N	\N
20908	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17358	\N	\N
20910	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17360	\N	\N
20911	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17361	\N	\N
20912	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17362	\N	\N
20913	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17363	\N	\N
20914	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17364	\N	\N
20915	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17365	\N	\N
20916	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17366	\N	\N
20917	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17367	\N	\N
20918	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17368	\N	\N
20919	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17369	\N	\N
20920	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17370	\N	\N
20921	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17371	\N	\N
20922	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17372	\N	\N
20923	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17373	\N	\N
20924	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17374	\N	\N
20925	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17375	\N	\N
20926	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17376	\N	\N
20927	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17377	\N	\N
20928	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17378	\N	\N
20929	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17379	\N	\N
20930	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17380	\N	\N
20931	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17381	\N	\N
20932	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17382	\N	\N
20933	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17383	\N	\N
20934	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17384	\N	\N
20935	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17385	\N	\N
20936	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17386	\N	\N
20937	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17387	\N	\N
20938	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17388	\N	\N
20939	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17389	\N	\N
20940	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17390	\N	\N
20941	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17391	\N	\N
20942	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17392	\N	\N
22423	VICPDTCOM	2023-10-05 00:00:00	\N	1	ACTIF	\N	\N	\N	\N	18515	\N	\N
22424	VICPDTCOM	2023-10-05 00:00:00	\N	2	ACTIF	\N	\N	\N	\N	18364	\N	\N
22435	SECRETCOM	2023-10-05 00:00:00	\N	3	ACTIF	\N	\N	\N	\N	18521	\N	\N
23242	MEMBRECOM	2024-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19330	\N	\N
23243	MEMBRECOM	2024-02-01 00:00:00	2024-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19331	\N	\N
23244	MEMBRECOM	2024-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19332	\N	\N
23369	MEMBRECOM	2024-02-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19433	\N	\N
23246	MEMBRECOM	2024-02-01 00:00:00	2024-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19334	\N	\N
23247	MEMBRECOM	2024-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19335	\N	\N
23248	MEMBRECOM	2024-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19336	\N	\N
23249	MEMBRECOM	2024-02-01 00:00:00	2024-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19337	\N	\N
23250	MEMBRECOM	2024-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19338	\N	\N
23251	MEMBRECOM	2024-02-01 00:00:00	2024-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19339	\N	\N
23252	MEMBRECOM	2024-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19340	\N	\N
23253	MEMBRECOM	2024-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19341	\N	\N
23254	MEMBRECOM	2024-02-01 00:00:00	2024-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19342	\N	\N
23255	MEMBRECOM	2024-02-01 00:00:00	2024-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19343	\N	\N
23256	MEMBRECOM	2024-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19344	\N	\N
23257	MEMBRECOM	2024-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19345	\N	\N
23258	MEMBRECOM	2024-02-01 00:00:00	2024-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19346	\N	\N
23259	MEMBRECOM	2024-02-01 00:00:00	2024-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19347	\N	\N
23260	MEMBRECOM	2024-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19348	\N	\N
23261	MEMBRECOM	2024-02-01 00:00:00	2024-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19349	\N	\N
23370	MEMBRECOM	2024-02-28 00:00:00	2024-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19434	\N	\N
23263	MEMBRECOM	2024-02-01 00:00:00	2024-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19351	\N	\N
23264	MEMBRECOM	2024-02-01 00:00:00	2024-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19352	\N	\N
23265	MEMBRECOM	2024-02-01 00:00:00	2024-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19353	\N	\N
23371	MEMBRECOM	2024-02-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19435	\N	\N
23372	MEMBRECOM	2024-02-28 00:00:00	2024-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19436	\N	\N
23373	MEMBRECOM	2024-02-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19437	\N	\N
23374	MEMBRECOM	2024-02-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19438	\N	\N
23375	MEMBRECOM	2024-02-28 00:00:00	2024-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19439	\N	\N
23376	MEMBRECOM	2024-02-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19440	\N	\N
23377	MEMBRECOM	2024-02-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19441	\N	\N
23378	MEMBRECOM	2024-02-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19442	\N	\N
17821	MEMBRECOM	2019-06-05 00:00:00	2019-06-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14974	\N	\N
17822	MEMBRECOM	2019-06-05 00:00:00	2019-06-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14975	\N	\N
17823	MEMBRECOM	2019-06-05 00:00:00	2019-06-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14976	\N	\N
17824	MEMBRECOM	2019-06-05 00:00:00	2019-06-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14977	\N	\N
17825	MEMBRECOM	2019-06-05 00:00:00	2019-06-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14978	\N	\N
17826	MEMBRECOM	2019-06-05 00:00:00	2019-06-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14979	\N	\N
17827	MEMBRECOM	2019-06-05 00:00:00	2019-06-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14980	\N	\N
17828	MEMBRECOM	2019-06-05 00:00:00	2019-06-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14981	\N	\N
17829	MEMBRECOM	2019-06-05 00:00:00	2019-06-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14982	\N	\N
17830	MEMBRECOM	2019-06-05 00:00:00	2019-06-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14983	\N	\N
17831	MEMBRECOM	2019-06-05 00:00:00	2019-06-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14984	\N	\N
17832	MEMBRECOM	2019-06-05 00:00:00	2019-06-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14985	\N	\N
17833	MEMBRECOM	2019-06-05 00:00:00	2019-06-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14986	\N	\N
17834	MEMBRECOM	2019-06-05 00:00:00	2019-06-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14987	\N	\N
17835	MEMBRECOM	2019-06-05 00:00:00	2019-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14988	\N	\N
17836	MEMBRECOM	2019-06-05 00:00:00	2019-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14989	\N	\N
17837	MEMBRECOM	2019-06-05 00:00:00	2019-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14990	\N	\N
17838	MEMBRECOM	2019-06-05 00:00:00	2019-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14991	\N	\N
17839	MEMBRECOM	2019-06-05 00:00:00	2019-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14992	\N	\N
17840	MEMBRECOM	2019-06-05 00:00:00	2019-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14993	\N	\N
17841	MEMBRECOM	2019-06-05 00:00:00	2019-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14994	\N	\N
17842	MEMBRECOM	2019-06-05 00:00:00	2019-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14995	\N	\N
17843	MEMBRECOM	2019-06-05 00:00:00	2019-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14996	\N	\N
17844	MEMBRECOM	2019-06-05 00:00:00	2019-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14997	\N	\N
17845	MEMBRECOM	2019-06-05 00:00:00	2019-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14998	\N	\N
17846	MEMBRECOM	2019-06-05 00:00:00	2019-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14999	\N	\N
17847	MEMBRECOM	2019-06-05 00:00:00	2019-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15000	\N	\N
17848	MEMBRECOM	2019-06-05 00:00:00	2019-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15001	\N	\N
20514	MEMBRECOM	2021-11-23 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17059	\N	\N
20515	MEMBRECOM	2021-11-23 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17060	\N	\N
20516	MEMBRECOM	2021-11-23 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17061	\N	\N
20517	MEMBRECOM	2021-11-23 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17062	\N	\N
20518	MEMBRECOM	2021-11-23 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17063	\N	\N
20519	MEMBRECOM	2021-11-23 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17064	\N	\N
20520	MEMBRECOM	2021-11-23 00:00:00	2021-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17065	\N	\N
20521	MEMBRECOM	2021-11-23 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17066	\N	\N
20522	MEMBRECOM	2021-11-23 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17067	\N	\N
20523	MEMBRECOM	2021-11-23 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17068	\N	\N
20524	MEMBRECOM	2021-11-23 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17069	\N	\N
20525	MEMBRECOM	2021-11-23 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17070	\N	\N
20526	MEMBRECOM	2021-11-23 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17071	\N	\N
20527	MEMBRECOM	2021-11-23 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17072	\N	\N
20528	MEMBRECOM	2021-11-23 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17073	\N	\N
20529	MEMBRECOM	2021-11-23 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17074	\N	\N
20530	MEMBRECOM	2021-11-23 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17075	\N	\N
20531	MEMBRECOM	2021-11-23 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17076	\N	\N
20532	MEMBRECOM	2021-11-23 00:00:00	2021-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17077	\N	\N
20533	MEMBRECOM	2021-11-23 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17078	\N	\N
20534	MEMBRECOM	2021-11-23 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17079	\N	\N
23142	MEMBRECOM	2023-11-15 00:00:00	2023-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19242	\N	\N
23143	MEMBRECOM	2023-11-15 00:00:00	2023-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19243	\N	\N
23144	MEMBRECOM	2023-11-15 00:00:00	2023-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19244	\N	\N
23145	MEMBRECOM	2023-11-15 00:00:00	2023-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19245	\N	\N
23146	MEMBRECOM	2023-11-15 00:00:00	2023-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19246	\N	\N
23147	MEMBRECOM	2023-11-15 00:00:00	2023-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19247	\N	\N
23148	MEMBRECOM	2023-11-15 00:00:00	2023-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19248	\N	\N
23149	MEMBRECOM	2023-11-15 00:00:00	2023-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19249	\N	\N
23150	MEMBRECOM	2023-11-15 00:00:00	2023-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19250	\N	\N
23151	MEMBRECOM	2023-11-15 00:00:00	2023-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19251	\N	\N
23152	MEMBRECOM	2023-11-15 00:00:00	2023-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19252	\N	\N
23153	MEMBRECOM	2023-11-15 00:00:00	2023-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19253	\N	\N
23154	MEMBRECOM	2023-11-15 00:00:00	2023-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19254	\N	\N
23155	MEMBRECOM	2023-11-15 00:00:00	2023-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19255	\N	\N
23156	MEMBRECOM	2023-11-15 00:00:00	2023-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19256	\N	\N
23160	MEMBRECOM	2024-01-20 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19260	\N	\N
23158	MEMBRECOM	2024-01-20 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19258	\N	\N
23159	MEMBRECOM	2024-01-20 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19259	\N	\N
23161	MEMBRECOM	2024-01-20 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19261	\N	\N
23162	MEMBRECOM	2024-01-20 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19262	\N	\N
23163	MEMBRECOM	2024-01-20 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19263	\N	\N
23164	MEMBRECOM	2024-01-20 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19264	\N	\N
23165	MEMBRECOM	2024-01-20 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19265	\N	\N
23166	MEMBRECOM	2024-01-20 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19266	\N	\N
23167	MEMBRECOM	2024-01-20 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19267	\N	\N
23168	MEMBRECOM	2024-01-20 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19268	\N	\N
23169	MEMBRECOM	2024-01-20 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19269	\N	\N
23170	MEMBRECOM	2023-10-19 00:00:00	2023-10-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19270	\N	\N
23171	MEMBRECOM	2023-10-19 00:00:00	2023-10-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19271	\N	\N
23172	MEMBRECOM	2023-10-19 00:00:00	2023-10-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19272	\N	\N
23173	MEMBRECOM	2023-10-19 00:00:00	2023-10-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19273	\N	\N
23174	MEMBRECOM	2023-10-19 00:00:00	2023-10-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19274	\N	\N
23175	MEMBRECOM	2023-10-19 00:00:00	2023-10-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19275	\N	\N
23176	MEMBRECOM	2023-10-19 00:00:00	2023-10-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19276	\N	\N
23177	MEMBRECOM	2023-10-19 00:00:00	2023-10-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19277	\N	\N
23178	MEMBRECOM	2023-10-19 00:00:00	2023-10-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19278	\N	\N
23185	MEMBRECOM	2023-10-06 00:00:00	2023-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19285	\N	\N
23180	MEMBRECOM	2023-10-19 00:00:00	2023-10-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19280	\N	\N
23181	MEMBRECOM	2023-10-19 00:00:00	2023-10-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19281	\N	\N
23182	MEMBRECOM	2023-10-19 00:00:00	2023-10-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19282	\N	\N
23183	MEMBRECOM	2023-10-19 00:00:00	2023-10-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19283	\N	\N
23187	MEMBRECOM	2023-10-06 00:00:00	2023-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19287	\N	\N
23186	MEMBRECOM	2023-10-06 00:00:00	2023-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19286	\N	\N
23188	MEMBRECOM	2023-10-06 00:00:00	2023-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19288	\N	\N
23189	MEMBRECOM	2023-10-06 00:00:00	2023-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19289	\N	\N
23190	MEMBRECOM	2023-10-06 00:00:00	2023-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19290	\N	\N
23191	MEMBRECOM	2023-10-06 00:00:00	2023-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19291	\N	\N
23192	MEMBRECOM	2023-10-06 00:00:00	2023-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19292	\N	\N
23193	MEMBRECOM	2023-10-06 00:00:00	2023-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19293	\N	\N
23194	MEMBRECOM	2023-10-06 00:00:00	2023-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19294	\N	\N
23195	MEMBRECOM	2023-10-06 00:00:00	2023-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19295	\N	\N
23196	MEMBRECOM	2023-10-06 00:00:00	2023-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19296	\N	\N
23197	MEMBRECOM	2023-10-06 00:00:00	2023-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19297	\N	\N
23198	MEMBRECOM	2023-10-06 00:00:00	2023-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19298	\N	\N
23199	MEMBRECOM	2023-10-06 00:00:00	2023-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19299	\N	\N
23200	MEMBRECOM	2023-10-05 00:00:00	2023-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19300	\N	\N
23201	MEMBRECOM	2023-10-05 00:00:00	2023-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19301	\N	\N
23202	MEMBRECOM	2023-10-05 00:00:00	2023-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19302	\N	\N
23203	MEMBRECOM	2023-10-05 00:00:00	2023-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19303	\N	\N
23204	MEMBRECOM	2023-10-05 00:00:00	2023-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19304	\N	\N
23205	MEMBRECOM	2023-10-05 00:00:00	2023-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19305	\N	\N
23206	MEMBRECOM	2023-10-05 00:00:00	2023-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19306	\N	\N
23207	MEMBRECOM	2023-10-05 00:00:00	2023-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19307	\N	\N
23208	MEMBRECOM	2023-10-05 00:00:00	2023-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19308	\N	\N
23209	MEMBRECOM	2023-10-05 00:00:00	2023-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19309	\N	\N
23210	MEMBRECOM	2023-10-05 00:00:00	2023-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19310	\N	\N
23211	MEMBRECOM	2023-10-05 00:00:00	2023-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19311	\N	\N
23212	MEMBRECOM	2023-10-05 00:00:00	2023-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19312	\N	\N
23213	MEMBRECOM	2023-10-05 00:00:00	2023-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19313	\N	\N
23214	MEMBRECOM	2023-10-05 00:00:00	2023-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19314	\N	\N
23219	MEMBRECOM	2023-10-05 00:00:00	2023-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19319	\N	\N
23216	MEMBRECOM	2023-10-05 00:00:00	2023-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19316	\N	\N
23217	MEMBRECOM	2023-10-05 00:00:00	2023-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19317	\N	\N
23218	MEMBRECOM	2023-10-05 00:00:00	2023-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19318	\N	\N
23220	MEMBRECOM	2023-10-05 00:00:00	2023-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19320	\N	\N
23221	MEMBRECOM	2023-10-05 00:00:00	2023-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19321	\N	\N
23222	MEMBRECOM	2023-10-05 00:00:00	2023-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19322	\N	\N
23223	MEMBRECOM	2023-10-05 00:00:00	2023-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19323	\N	\N
23224	MEMBRECOM	2023-10-05 00:00:00	2023-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19324	\N	\N
23225	MEMBRECOM	2023-10-05 00:00:00	2023-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19325	\N	\N
23226	MEMBRECOM	2023-10-05 00:00:00	2023-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19326	\N	\N
23227	MEMBRECOM	2023-10-05 00:00:00	2023-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19327	\N	\N
23228	MEMBRECOM	2023-10-05 00:00:00	2023-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19328	\N	\N
18853	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15878	\N	\N
18855	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15880	\N	\N
9947	MEMBRECOM	2011-11-14 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8321	\N	\N
13834	MEMBRECOM	2015-10-26 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11690	\N	\N
18859	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15884	\N	\N
4107	MEMBRECOM	2006-01-26 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3188	\N	\N
8938	MEMBRECOM	2010-10-19 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7438	\N	\N
10803	MEMBRECOM	2012-12-18 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9090	\N	\N
12385	MEMBRECOM	2014-01-29 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10333	\N	\N
3630	MEMBRECOM	2004-12-14 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2718	\N	\N
3645	MEMBRECOM	2004-12-20 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2733	\N	\N
12415	MEMBRECOM	2014-01-29 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10363	\N	\N
18860	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15885	\N	\N
10345	MEMBRECOM	2012-02-21 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8698	\N	\N
14075	MEMBRECOM	2016-02-10 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11928	2016-02-23 15:17:57	\N
19915	PDTCOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16515	\N	\N
19916	RAPCOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16516	\N	\N
19917	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16517	\N	\N
19918	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16518	\N	\N
19919	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16519	\N	\N
19920	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16520	\N	\N
19921	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16521	\N	\N
19922	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16522	\N	\N
19923	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16523	\N	\N
19924	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16524	\N	\N
19925	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16525	\N	\N
19926	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16526	\N	\N
19927	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16527	\N	\N
19928	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16528	\N	\N
19929	PDTCOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16529	\N	\N
19930	RAPCOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16530	\N	\N
19931	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16531	\N	\N
19932	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16532	\N	\N
19933	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16533	\N	\N
19934	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16534	\N	\N
19935	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16535	\N	\N
19936	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16536	\N	\N
19937	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16537	\N	\N
19938	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16538	\N	\N
19939	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16539	\N	\N
19940	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16540	\N	\N
19941	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16541	\N	\N
19942	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16542	\N	\N
19943	VICPDTCOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16543	\N	\N
19944	RAPCOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16544	\N	\N
19945	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16545	\N	\N
19946	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16546	\N	\N
19947	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16547	\N	\N
19948	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16548	\N	\N
19949	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16549	\N	\N
19950	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16550	\N	\N
19951	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16551	\N	\N
19952	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16552	\N	\N
19953	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16553	\N	\N
19954	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16554	\N	\N
19955	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16555	\N	\N
19956	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16556	\N	\N
19957	PDTCOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16557	\N	\N
19958	RAPCOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16558	\N	\N
19959	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16559	\N	\N
19960	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16560	\N	\N
19973	RAPCOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16573	\N	\N
19962	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16562	\N	\N
19963	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16563	\N	\N
19964	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16564	\N	\N
19965	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16565	\N	\N
19966	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16566	\N	\N
19967	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16567	\N	\N
19968	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16568	\N	\N
19969	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16569	\N	\N
19970	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16570	\N	\N
19971	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16571	\N	\N
19972	VICPDTCOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16572	\N	\N
19974	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16574	\N	\N
19975	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16575	\N	\N
19976	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16576	\N	\N
19977	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16577	\N	\N
19978	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16578	\N	\N
19979	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16579	\N	\N
19980	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16580	\N	\N
19981	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16581	\N	\N
19982	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16582	\N	\N
19983	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16583	\N	\N
19984	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16584	\N	\N
19985	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16585	\N	\N
21675	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17997	2023-09-24 00:00:00	\N
23379	MEMBRECOM	2024-02-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19443	\N	\N
23380	MEMBRECOM	2024-02-28 00:00:00	2024-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19444	\N	\N
23381	MEMBRECOM	2024-02-28 00:00:00	2024-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19445	\N	\N
23382	MEMBRECOM	2024-02-28 00:00:00	2024-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19446	\N	\N
23383	MEMBRECOM	2024-02-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19447	\N	\N
23384	MEMBRECOM	2024-02-28 00:00:00	2024-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19448	\N	\N
23385	MEMBRECOM	2024-02-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19449	\N	\N
23386	MEMBRECOM	2024-02-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19450	\N	\N
23387	MEMBRECOM	2024-02-28 00:00:00	2024-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19451	\N	\N
23388	MEMBRECOM	2024-02-28 00:00:00	2024-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19452	\N	\N
23389	MEMBRECOM	2024-02-28 00:00:00	2024-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19453	\N	\N
23390	MEMBRECOM	2024-02-28 00:00:00	2024-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19454	\N	\N
23391	MEMBRECOM	2024-02-28 00:00:00	2024-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19455	\N	\N
23392	MEMBRECOM	2024-02-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19456	\N	\N
23393	MEMBRECOM	2024-02-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19457	\N	\N
23394	MEMBRECOM	2024-02-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19458	\N	\N
23395	MEMBRECOM	2024-02-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19459	\N	\N
23396	MEMBRECOM	2024-02-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19460	\N	\N
23397	MEMBRECOM	2024-02-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19461	\N	\N
23398	MEMBRECOM	2024-02-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19462	\N	\N
23399	MEMBRECOM	2024-02-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19463	\N	\N
23400	MEMBRECOM	2024-02-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19464	\N	\N
23401	MEMBRECOM	2024-02-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19465	\N	\N
23402	MEMBRECOM	2024-02-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19466	\N	\N
23403	MEMBRECOM	2024-02-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19467	\N	\N
23404	MEMBRECOM	2024-02-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19468	\N	\N
23405	MEMBRECOM	2024-02-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19469	\N	\N
23406	MEMBRECOM	2024-02-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19470	\N	\N
23407	MEMBRECOM	2024-02-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19471	\N	\N
23408	MEMBRECOM	2024-02-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19472	\N	\N
23409	MEMBRECOM	2024-02-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19473	\N	\N
23410	MEMBRECOM	2024-02-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19474	\N	\N
23411	MEMBRECOM	2024-02-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19475	\N	\N
23412	MEMBRECOM	2024-02-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19476	\N	\N
23413	MEMBRECOM	2024-02-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19477	\N	\N
23414	MEMBRECOM	2024-02-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19478	\N	\N
18655	MEMBRECOM	2020-06-17 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15692	\N	\N
11197	MEMBRECOM	2013-06-05 00:00:00	2020-11-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9441	\N	\N
12523	MEMBRECOM	2014-05-28 00:00:00	2020-11-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10471	\N	\N
12614	MEMBRECOM	2014-07-10 00:00:00	2020-11-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10562	\N	\N
12624	MEMBRECOM	2014-07-10 00:00:00	2020-11-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10572	\N	\N
19552	MEMBRECOM	2020-12-01 00:00:00	2020-12-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16215	\N	\N
20315	MEMBRECOM	2021-06-18 00:00:00	2021-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16891	\N	\N
20316	MEMBRECOM	2021-06-18 00:00:00	2021-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16892	\N	\N
20317	MEMBRECOM	2021-06-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16893	\N	\N
20318	MEMBRECOM	2021-06-18 00:00:00	2021-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16894	\N	\N
20319	MEMBRECOM	2021-06-18 00:00:00	2021-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16895	\N	\N
20320	MEMBRECOM	2021-06-18 00:00:00	2021-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16896	\N	\N
20321	MEMBRECOM	2021-06-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16897	\N	\N
20322	MEMBRECOM	2021-06-18 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16898	\N	\N
20323	MEMBRECOM	2021-06-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16899	\N	\N
20324	MEMBRECOM	2021-06-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16900	\N	\N
20325	MEMBRECOM	2021-06-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16901	\N	\N
20326	MEMBRECOM	2021-06-18 00:00:00	2021-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16902	\N	\N
20327	MEMBRECOM	2021-06-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16903	\N	\N
20328	MEMBRECOM	2021-06-18 00:00:00	2021-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16904	\N	\N
20329	MEMBRECOM	2021-06-18 00:00:00	2021-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16905	\N	\N
20330	MEMBRECOM	2021-06-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16906	\N	\N
20331	MEMBRECOM	2021-06-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16907	\N	\N
20332	MEMBRECOM	2021-06-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16908	\N	\N
20333	MEMBRECOM	2021-06-18 00:00:00	2021-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16909	\N	\N
20334	MEMBRECOM	2021-06-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16910	\N	\N
20335	MEMBRECOM	2021-06-18 00:00:00	2021-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16911	\N	\N
20336	MEMBRECOM	2021-06-18 00:00:00	2021-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16912	\N	\N
20337	MEMBRECOM	2021-06-18 00:00:00	2021-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16913	\N	\N
20691	MEMBRECOM	2022-06-21 00:00:00	2022-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17174	\N	\N
20692	MEMBRECOM	2022-06-17 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17175	\N	\N
23314	MEMBRECOM	2024-02-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19378	\N	\N
23315	MEMBRECOM	2024-02-15 00:00:00	2024-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19379	\N	\N
23316	MEMBRECOM	2024-02-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19380	\N	\N
23317	MEMBRECOM	2024-02-15 00:00:00	2024-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19381	\N	\N
23318	MEMBRECOM	2024-02-15 00:00:00	2024-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19382	\N	\N
23319	MEMBRECOM	2024-02-15 00:00:00	2024-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19383	\N	\N
23320	MEMBRECOM	2024-02-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19384	\N	\N
23321	MEMBRECOM	2024-02-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19385	\N	\N
23322	MEMBRECOM	2024-02-15 00:00:00	2024-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19386	\N	\N
23323	MEMBRECOM	2024-02-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19387	\N	\N
23324	MEMBRECOM	2024-02-15 00:00:00	2024-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19388	\N	\N
23325	MEMBRECOM	2024-02-15 00:00:00	2024-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19389	\N	\N
23326	MEMBRECOM	2024-02-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19390	\N	\N
23327	MEMBRECOM	2024-02-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19391	\N	\N
23328	MEMBRECOM	2024-02-15 00:00:00	2024-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19392	\N	\N
23329	MEMBRECOM	2024-02-15 00:00:00	2024-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19393	\N	\N
23330	MEMBRECOM	2024-02-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19394	\N	\N
23331	MEMBRECOM	2024-02-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19395	\N	\N
23332	MEMBRECOM	2024-02-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19396	\N	\N
23333	MEMBRECOM	2024-02-15 00:00:00	2024-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19397	\N	\N
23334	MEMBRECOM	2024-02-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19398	\N	\N
23335	MEMBRECOM	2024-02-15 00:00:00	2024-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19399	\N	\N
23336	MEMBRECOM	2024-02-15 00:00:00	2024-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19400	\N	\N
17760	MEMBRECOM	2019-05-22 00:00:00	2019-05-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14922	\N	\N
17761	MEMBRECOM	2019-05-22 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14923	\N	\N
17762	MEMBRECOM	2019-05-22 00:00:00	2019-05-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14924	\N	\N
17763	MEMBRECOM	2019-05-22 00:00:00	2019-05-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14925	\N	\N
17764	MEMBRECOM	2019-05-22 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14926	\N	\N
17765	MEMBRECOM	2019-05-22 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14927	\N	\N
17766	MEMBRECOM	2019-05-22 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14928	\N	\N
17767	MEMBRECOM	2019-05-22 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14929	\N	\N
17768	MEMBRECOM	2019-05-22 00:00:00	2019-05-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14930	\N	\N
17772	MEMBRECOM	2019-05-22 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14934	\N	\N
17770	MEMBRECOM	2019-05-22 00:00:00	2019-05-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14932	\N	\N
17771	MEMBRECOM	2019-05-22 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14933	\N	\N
17773	MEMBRECOM	2019-05-22 00:00:00	2019-05-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14935	\N	\N
17774	MEMBRECOM	2019-05-22 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14936	\N	\N
17775	MEMBRECOM	2019-05-22 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14937	\N	\N
17776	MEMBRECOM	2019-05-22 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14938	\N	\N
17777	MEMBRECOM	2019-05-22 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14939	\N	\N
17778	MEMBRECOM	2019-05-22 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14940	\N	\N
17779	MEMBRECOM	2019-05-22 00:00:00	2019-05-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14941	\N	\N
18657	MEMBRECOM	2020-06-26 00:00:00	2020-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15694	\N	\N
19189	SECRETCOM	2017-10-05 00:00:00	2020-10-05 00:00:00	1	ANCIEN	\N	\N	\N	\N	6826	\N	\N
19190	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6826	\N	\N
19191	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	4	ANCIEN	\N	\N	\N	\N	6826	\N	\N
19832	PDTCOM	2021-03-04 00:00:00	2021-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16439	\N	\N
19833	RAPCOM	2021-03-04 00:00:00	2021-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16434	\N	\N
19834	VICPDTCOM	2021-03-04 00:00:00	2021-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16421	\N	\N
19835	VICPDTCOM	2021-03-04 00:00:00	2021-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16427	\N	\N
19836	VICPDTCOM	2021-03-04 00:00:00	2021-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16428	\N	\N
19837	VICPDTCOM	2021-03-04 00:00:00	2021-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16431	\N	\N
19838	VICPDTCOM	2021-03-04 00:00:00	2021-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16436	\N	\N
19839	VICPDTCOM	2021-03-04 00:00:00	2021-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16440	\N	\N
19840	VICPDTCOM	2021-03-04 00:00:00	2021-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16442	\N	\N
19841	VICPDTCOM	2021-03-04 00:00:00	2021-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16443	\N	\N
19842	SECRETCOM	2021-03-04 00:00:00	2021-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16425	\N	\N
19843	SECRETCOM	2021-03-04 00:00:00	2021-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16437	\N	\N
20705	MEMBRECOM	2022-10-11 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8156	\N	\N
20706	MEMBRECOM	2022-10-11 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13484	\N	\N
20707	VICPDTCOM	2022-10-11 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15991	\N	\N
20708	VICPDTCOM	2022-10-11 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13482	\N	\N
18355	MEMBRECOM	2020-02-04 00:00:00	2020-02-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15435	\N	\N
20302	PDTCOM	2021-05-27 00:00:00	2021-09-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16881	\N	\N
20303	RAPCOM	2021-05-27 00:00:00	2021-09-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16884	\N	\N
20304	VICPDTCOM	2021-05-27 00:00:00	2021-09-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16865	\N	\N
20305	VICPDTCOM	2021-05-27 00:00:00	2021-09-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16871	\N	\N
20306	VICPDTCOM	2021-05-27 00:00:00	2021-09-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16880	\N	\N
20307	VICPDTCOM	2021-05-27 00:00:00	2021-09-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16875	\N	\N
20308	VICPDTCOM	2021-05-27 00:00:00	2021-09-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16886	\N	\N
20309	VICPDTCOM	2021-05-27 00:00:00	2021-09-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16883	\N	\N
20310	VICPDTCOM	2021-05-27 00:00:00	2021-09-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16882	\N	\N
20311	VICPDTCOM	2021-05-27 00:00:00	2021-09-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16885	\N	\N
20312	SECRETCOM	2021-05-27 00:00:00	2021-09-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16869	\N	\N
20313	SECRETCOM	2021-05-27 00:00:00	2021-09-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16876	\N	\N
20967	MEMBRECOM	2023-02-07 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17393	\N	\N
20968	MEMBRECOM	2023-02-07 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17394	\N	\N
22036	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18356	\N	\N
22037	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18357	\N	\N
22038	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18358	\N	\N
22207	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18527	\N	\N
22208	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18528	\N	\N
22209	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18529	\N	\N
22276	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18596	\N	\N
22277	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18597	\N	\N
22278	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18598	\N	\N
22279	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18599	\N	\N
22280	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18600	\N	\N
22281	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18601	\N	\N
22286	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18606	\N	\N
22287	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18607	\N	\N
22288	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18608	\N	\N
22289	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18609	\N	\N
22290	MEMBRECOM	2023-10-04 00:00:00	2029-11-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	18610	\N	\N
22291	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18611	\N	\N
22292	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18612	\N	\N
22293	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18613	\N	\N
22294	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18614	\N	\N
22295	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18615	\N	\N
22296	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18616	\N	\N
22431	VICPDTCOM	2023-10-05 00:00:00	\N	9	ACTIF	\N	\N	\N	\N	18337	\N	\N
22346	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18618	\N	\N
22347	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18619	\N	\N
22348	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18620	\N	\N
22349	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18621	\N	\N
22350	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18622	\N	\N
22351	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18623	\N	\N
22352	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18624	\N	\N
22353	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18625	\N	\N
22354	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18626	\N	\N
22355	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18627	\N	\N
22356	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18628	\N	\N
22357	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18629	\N	\N
22358	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18630	\N	\N
22359	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18631	\N	\N
22360	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18632	\N	\N
22361	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18633	\N	\N
22362	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18634	\N	\N
22363	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18635	\N	\N
22364	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18636	\N	\N
22365	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18637	\N	\N
22366	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18638	\N	\N
22367	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18640	\N	\N
22368	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18641	\N	\N
22369	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18642	\N	\N
22370	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18643	\N	\N
22371	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18644	\N	\N
22372	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18645	\N	\N
22373	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18646	\N	\N
22374	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18647	\N	\N
22375	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18648	\N	\N
22376	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18649	\N	\N
22377	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18650	\N	\N
22378	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18651	\N	\N
22379	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18652	\N	\N
22380	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18653	\N	\N
22381	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18654	\N	\N
22382	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18655	\N	\N
22383	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18656	\N	\N
22384	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18657	\N	\N
22385	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18658	\N	\N
22386	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18659	\N	\N
22387	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18660	\N	\N
22388	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18661	\N	\N
22389	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18662	\N	\N
22390	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18663	\N	\N
22391	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18664	\N	\N
22392	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18665	\N	\N
22393	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18666	\N	\N
22394	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18667	\N	\N
22395	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18668	\N	\N
22396	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18669	\N	\N
22397	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18670	\N	\N
22421	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18689	\N	\N
22430	VICPDTCOM	2023-10-05 00:00:00	\N	8	ACTIF	\N	\N	\N	\N	18361	\N	\N
22436	SECRETCOM	2023-10-05 00:00:00	\N	4	ACTIF	\N	\N	\N	\N	18421	\N	\N
22437	VICPDTCOM	2023-10-05 00:00:00	\N	11	ACTIF	\N	\N	\N	\N	18340	\N	\N
22438	SECRETCOM	2023-10-05 00:00:00	\N	3	ACTIF	\N	\N	\N	\N	18432	\N	\N
22439	PDTCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18431	\N	\N
22440	VICPDTCOM	2023-10-05 00:00:00	\N	4	ACTIF	\N	\N	\N	\N	18395	\N	\N
22441	VICPDTCOM	2023-10-05 00:00:00	\N	2	ACTIF	\N	\N	\N	\N	18392	\N	\N
22442	SECRETCOM	2023-10-05 00:00:00	\N	2	ACTIF	\N	\N	\N	\N	18391	\N	\N
22443	VICPDTCOM	2023-10-05 00:00:00	\N	5	ACTIF	\N	\N	\N	\N	18481	\N	\N
22444	SECRETCOM	2023-10-05 00:00:00	\N	1	ACTIF	\N	\N	\N	\N	18478	\N	\N
23683	PDTCOM	2024-04-10 00:00:00	2024-04-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19652	\N	\N
22446	VICPDTCOM	2023-10-05 00:00:00	\N	3	ACTIF	\N	\N	\N	\N	18470	\N	\N
22447	VICPDTCOM	2023-10-05 00:00:00	\N	7	ACTIF	\N	\N	\N	\N	18469	\N	\N
22448	SECRETCOM	2023-10-05 00:00:00	\N	4	ACTIF	\N	\N	\N	\N	18467	\N	\N
22449	VICPDTCOM	2023-10-05 00:00:00	\N	10	ACTIF	\N	\N	\N	\N	18351	\N	\N
22450	VICPDTCOM	2023-10-05 00:00:00	\N	9	ACTIF	\N	\N	\N	\N	18670	\N	\N
22451	VICPDTCOM	2023-10-05 00:00:00	\N	6	ACTIF	\N	\N	\N	\N	18612	\N	\N
22452	VICPDTCOM	2023-10-05 00:00:00	\N	8	ACTIF	\N	\N	\N	\N	18529	\N	\N
22453	VICPDTPRECOM	2023-10-05 00:00:00	\N	1	ACTIF	\N	\N	\N	\N	18473	\N	\N
23684	RAPCOM	2024-04-10 00:00:00	2024-04-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19653	\N	\N
17705	MEMBRECOM	2019-04-30 00:00:00	2019-05-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14876	\N	\N
17706	MEMBRECOM	2019-04-30 00:00:00	2019-05-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14877	\N	\N
17707	MEMBRECOM	2019-04-30 00:00:00	2019-05-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14878	\N	\N
17708	MEMBRECOM	2019-04-30 00:00:00	2019-05-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14879	\N	\N
17709	MEMBRECOM	2019-04-30 00:00:00	2019-05-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14880	\N	\N
17710	MEMBRECOM	2019-04-30 00:00:00	2019-05-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14881	\N	\N
17711	MEMBRECOM	2019-04-30 00:00:00	2019-05-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14882	\N	\N
17712	MEMBRECOM	2019-04-30 00:00:00	2019-05-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14883	\N	\N
17713	MEMBRECOM	2019-04-30 00:00:00	2019-05-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14884	\N	\N
17714	MEMBRECOM	2019-04-30 00:00:00	2019-05-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14885	\N	\N
17715	MEMBRECOM	2019-04-30 00:00:00	2019-05-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14886	\N	\N
17716	MEMBRECOM	2019-04-30 00:00:00	2019-05-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14887	\N	\N
17717	MEMBRECOM	2019-04-30 00:00:00	2019-05-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14888	\N	\N
17718	MEMBRECOM	2019-04-30 00:00:00	2019-05-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14889	\N	\N
18656	MEMBRECOM	2020-06-25 00:00:00	2020-06-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15693	\N	\N
18366	MEMBRECOM	2020-02-05 00:00:00	2020-09-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15438	\N	\N
18078	MEMBRECOM	2019-08-28 00:00:00	2019-09-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15198	\N	\N
18367	MEMBRECOM	2020-02-05 00:00:00	2020-09-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15439	\N	\N
18368	MEMBRECOM	2020-02-05 00:00:00	2020-09-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15440	\N	\N
18369	MEMBRECOM	2020-02-05 00:00:00	2020-09-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15441	\N	\N
18370	MEMBRECOM	2020-02-05 00:00:00	2020-09-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15442	\N	\N
18371	MEMBRECOM	2020-02-05 00:00:00	2020-09-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15443	\N	\N
18372	MEMBRECOM	2020-02-05 00:00:00	2020-09-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15444	\N	\N
18373	MEMBRECOM	2020-02-05 00:00:00	2020-09-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15445	\N	\N
18374	MEMBRECOM	2020-02-05 00:00:00	2020-09-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15446	\N	\N
18375	MEMBRECOM	2020-02-05 00:00:00	2020-09-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15447	\N	\N
18376	MEMBRECOM	2020-02-05 00:00:00	2020-09-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15448	\N	\N
18377	MEMBRECOM	2020-02-05 00:00:00	2020-09-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15449	\N	\N
18378	MEMBRECOM	2020-02-05 00:00:00	2020-09-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15450	\N	\N
18379	MEMBRECOM	2020-02-05 00:00:00	2020-09-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15451	\N	\N
18380	MEMBRECOM	2020-02-05 00:00:00	2020-09-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15452	\N	\N
18381	MEMBRECOM	2020-02-05 00:00:00	2020-09-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15453	\N	\N
18382	MEMBRECOM	2020-02-05 00:00:00	2020-09-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15454	\N	\N
18383	MEMBRECOM	2020-02-05 00:00:00	2020-09-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15455	\N	\N
18384	MEMBRECOM	2020-02-05 00:00:00	2020-09-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15456	\N	\N
18385	MEMBRECOM	2020-02-05 00:00:00	2020-09-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15457	\N	\N
18386	MEMBRECOM	2020-02-05 00:00:00	2020-09-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15458	\N	\N
18625	MEMBRECOM	2020-06-10 00:00:00	2020-06-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15662	\N	\N
18626	MEMBRECOM	2020-06-10 00:00:00	2020-06-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15663	\N	\N
18627	MEMBRECOM	2020-06-10 00:00:00	2020-06-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15664	\N	\N
18628	MEMBRECOM	2020-06-10 00:00:00	2020-06-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15665	\N	\N
18629	MEMBRECOM	2020-06-10 00:00:00	2020-06-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15666	\N	\N
18630	MEMBRECOM	2020-06-10 00:00:00	2020-06-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15667	\N	\N
18631	MEMBRECOM	2020-06-10 00:00:00	2020-06-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15668	\N	\N
18632	MEMBRECOM	2020-06-10 00:00:00	2020-06-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15669	\N	\N
18633	MEMBRECOM	2020-06-10 00:00:00	2020-06-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15670	\N	\N
18634	MEMBRECOM	2020-06-10 00:00:00	2020-06-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15671	\N	\N
18635	MEMBRECOM	2020-06-10 00:00:00	2020-06-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15672	\N	\N
18636	MEMBRECOM	2020-06-10 00:00:00	2020-06-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15673	\N	\N
18637	MEMBRECOM	2020-06-10 00:00:00	2020-06-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15674	\N	\N
18638	MEMBRECOM	2020-06-10 00:00:00	2020-06-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15675	\N	\N
18738	MEMBRECOM	2020-06-24 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15764	\N	\N
18739	MEMBRECOM	2020-06-24 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15765	\N	\N
18740	MEMBRECOM	2020-06-24 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15766	\N	\N
18741	MEMBRECOM	2020-06-24 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15767	\N	\N
18742	MEMBRECOM	2020-06-24 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15768	\N	\N
18743	MEMBRECOM	2020-06-24 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15769	\N	\N
18744	MEMBRECOM	2020-06-24 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15770	\N	\N
18745	MEMBRECOM	2020-06-24 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15771	\N	\N
18746	MEMBRECOM	2020-06-24 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15772	\N	\N
18747	MEMBRECOM	2020-06-24 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15773	\N	\N
18748	MEMBRECOM	2020-06-24 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15774	\N	\N
18749	MEMBRECOM	2020-06-24 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15775	\N	\N
18750	MEMBRECOM	2020-06-24 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15776	\N	\N
18751	MEMBRECOM	2020-06-24 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15777	\N	\N
20437	MEMBRECOM	2021-10-05 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16987	\N	\N
20438	MEMBRECOM	2021-10-05 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16988	\N	\N
20439	MEMBRECOM	2021-10-05 00:00:00	2022-07-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16989	\N	\N
20440	MEMBRECOM	2021-10-05 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16990	\N	\N
22022	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18342	\N	\N
22023	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18343	\N	\N
22024	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18344	\N	\N
22025	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18345	\N	\N
22026	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18346	\N	\N
22027	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18347	\N	\N
22028	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18348	\N	\N
22029	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18349	\N	\N
22030	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18350	\N	\N
22031	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18351	\N	\N
22032	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18352	\N	\N
22039	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18359	\N	\N
22040	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18360	\N	\N
22041	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18361	\N	\N
22042	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18362	\N	\N
22043	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18363	\N	\N
22044	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18364	\N	\N
22045	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18365	\N	\N
22046	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18366	\N	\N
22047	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18367	\N	\N
22048	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18368	\N	\N
22049	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18369	\N	\N
22050	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18370	\N	\N
22051	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18371	\N	\N
22052	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18372	\N	\N
22053	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18373	\N	\N
22054	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18374	\N	\N
22055	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18375	\N	\N
22056	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18376	\N	\N
22057	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18377	\N	\N
22058	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18378	\N	\N
22059	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18379	\N	\N
22138	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18458	\N	\N
22139	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18459	\N	\N
22140	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18460	\N	\N
22141	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18461	\N	\N
22142	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18462	\N	\N
22143	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18463	\N	\N
22144	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18464	\N	\N
22145	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18465	\N	\N
22146	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18466	\N	\N
22147	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18467	\N	\N
22148	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18468	\N	\N
22149	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18469	\N	\N
22150	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18470	\N	\N
22151	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18471	\N	\N
22152	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18472	\N	\N
22153	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18473	\N	\N
22154	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18474	\N	\N
22155	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18475	\N	\N
22156	MEMBRECOM	2023-10-04 00:00:00	2023-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18476	\N	\N
22157	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18477	\N	\N
22158	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18478	\N	\N
22159	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18479	\N	\N
22160	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18480	\N	\N
22161	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18481	\N	\N
22162	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18482	\N	\N
22163	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18483	\N	\N
22164	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18484	\N	\N
22165	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18485	\N	\N
22166	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18486	\N	\N
22167	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18487	\N	\N
22168	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18488	\N	\N
22169	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18489	\N	\N
22170	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18490	\N	\N
22171	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18491	\N	\N
22172	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18492	\N	\N
22173	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18493	\N	\N
22174	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18494	\N	\N
22175	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18495	\N	\N
22176	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18496	\N	\N
22177	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18497	\N	\N
22178	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18498	\N	\N
22179	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18499	\N	\N
22180	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18500	\N	\N
22181	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18501	\N	\N
22182	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18502	\N	\N
22183	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18503	\N	\N
22184	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18504	\N	\N
22185	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18505	\N	\N
22186	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18506	\N	\N
22187	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18507	\N	\N
22188	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18508	\N	\N
22189	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18509	\N	\N
22190	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18510	\N	\N
22191	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18511	\N	\N
22192	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18512	\N	\N
22193	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18513	\N	\N
22194	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18514	\N	\N
22195	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18515	\N	\N
22196	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18516	\N	\N
22197	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18517	\N	\N
22198	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18518	\N	\N
22199	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18519	\N	\N
22200	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18520	\N	\N
12984	MEMBRECOM	2015-01-30 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10901	2015-01-30 09:33:26	\N
18925	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15950	\N	\N
18927	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15952	\N	\N
8801	MEMBRECOM	2010-05-20 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7307	\N	\N
9268	MEMBRECOM	2011-03-31 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7765	\N	\N
19481	MEMBRECOM	2020-10-15 00:00:00	2021-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16144	\N	\N
23266	MEMBRECOM	2024-02-01 00:00:00	2024-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19354	\N	\N
23267	MEMBRECOM	2024-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19355	\N	\N
23268	MEMBRECOM	2024-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19356	\N	\N
23269	MEMBRECOM	2024-02-01 00:00:00	2024-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19357	\N	\N
23270	MEMBRECOM	2024-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19358	\N	\N
23271	MEMBRECOM	2024-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19359	\N	\N
23272	MEMBRECOM	2024-02-01 00:00:00	2024-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19360	\N	\N
23273	MEMBRECOM	2024-02-01 00:00:00	2024-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19361	\N	\N
23274	MEMBRECOM	2024-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19362	\N	\N
23471	PDTCOM	2024-03-08 00:00:00	2024-03-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19490	\N	\N
23276	MEMBRECOM	2024-02-01 00:00:00	2024-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19364	\N	\N
23277	MEMBRECOM	2024-02-01 00:00:00	2024-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19365	\N	\N
23472	RAPCOM	2024-03-08 00:00:00	2024-03-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19491	\N	\N
23279	MEMBRECOM	2024-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19367	\N	\N
23280	MEMBRECOM	2024-02-01 00:00:00	2024-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19368	\N	\N
23281	MEMBRECOM	2024-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19369	\N	\N
23282	MEMBRECOM	2024-02-01 00:00:00	2024-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19370	\N	\N
23473	MEMBRECOM	2024-03-08 00:00:00	2024-03-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19511	\N	\N
23284	MEMBRECOM	2024-02-01 00:00:00	2024-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19372	\N	\N
23285	MEMBRECOM	2024-02-01 00:00:00	2024-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19373	\N	\N
23286	MEMBRECOM	2024-02-01 00:00:00	2024-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19374	\N	\N
23287	MEMBRECOM	2024-02-01 00:00:00	2024-02-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19375	\N	\N
23474	MEMBRECOM	2024-03-08 00:00:00	2024-03-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19512	\N	\N
23475	MEMBRECOM	2024-03-08 00:00:00	2024-03-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19513	\N	\N
23476	MEMBRECOM	2024-03-08 00:00:00	2024-03-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19514	\N	\N
23477	MEMBRECOM	2024-03-08 00:00:00	2024-03-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19515	\N	\N
23478	MEMBRECOM	2024-03-08 00:00:00	2024-03-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19516	\N	\N
23479	MEMBRECOM	2024-03-08 00:00:00	2024-03-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19517	\N	\N
23480	MEMBRECOM	2024-03-08 00:00:00	2024-03-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19518	\N	\N
23481	MEMBRECOM	2024-03-08 00:00:00	2024-03-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19519	\N	\N
23482	MEMBRECOM	2024-03-08 00:00:00	2024-03-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19520	\N	\N
23483	MEMBRECOM	2024-03-08 00:00:00	2024-03-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19521	\N	\N
23484	MEMBRECOM	2024-03-08 00:00:00	2024-03-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19522	\N	\N
23485	MEMBRECOM	2024-03-08 00:00:00	2024-03-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19523	\N	\N
23486	MEMBRECOM	2024-03-08 00:00:00	2024-03-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19524	\N	\N
23616	VICPDTCOM	2024-03-29 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19577	\N	\N
23617	RAPCOM	2024-03-29 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19578	\N	\N
18691	MEMBRECOM	2020-07-01 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15728	\N	\N
18692	MEMBRECOM	2020-07-01 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15729	\N	\N
18693	MEMBRECOM	2020-07-01 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15730	\N	\N
18694	MEMBRECOM	2020-07-01 00:00:00	2020-07-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15731	\N	\N
18695	MEMBRECOM	2020-07-01 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15732	\N	\N
18696	MEMBRECOM	2020-07-01 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15733	\N	\N
18697	MEMBRECOM	2020-07-01 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15734	\N	\N
18698	MEMBRECOM	2020-07-01 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15735	\N	\N
18699	MEMBRECOM	2020-07-01 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15736	\N	\N
18700	MEMBRECOM	2020-07-01 00:00:00	2020-07-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15737	\N	\N
18701	MEMBRECOM	2020-07-01 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15738	\N	\N
18702	MEMBRECOM	2020-07-01 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15739	\N	\N
18703	MEMBRECOM	2020-07-01 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15740	\N	\N
18704	MEMBRECOM	2020-07-01 00:00:00	2020-07-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15741	\N	\N
18705	MEMBRECOM	2020-07-01 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15742	\N	\N
18706	MEMBRECOM	2020-07-01 00:00:00	2020-10-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15743	\N	\N
18707	MEMBRECOM	2020-07-01 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15744	\N	\N
18708	MEMBRECOM	2020-07-01 00:00:00	2020-07-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15745	\N	\N
18709	MEMBRECOM	2020-07-01 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15746	\N	\N
18710	MEMBRECOM	2020-07-01 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15747	\N	\N
18711	MEMBRECOM	2020-07-01 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15748	\N	\N
18712	MEMBRECOM	2020-07-01 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15749	\N	\N
18713	MEMBRECOM	2020-07-01 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15750	\N	\N
18714	MEMBRECOM	2020-07-01 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15751	\N	\N
18715	MEMBRECOM	2020-07-01 00:00:00	2020-07-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15752	\N	\N
18716	MEMBRECOM	2020-07-01 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15753	\N	\N
18717	MEMBRECOM	2020-07-01 00:00:00	2020-07-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15754	\N	\N
18718	MEMBRECOM	2020-07-01 00:00:00	2020-07-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15755	\N	\N
18719	MEMBRECOM	2020-07-01 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15756	\N	\N
18720	MEMBRECOM	2020-07-01 00:00:00	2020-07-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15757	\N	\N
18721	MEMBRECOM	2020-07-01 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15758	\N	\N
18722	MEMBRECOM	2020-07-01 00:00:00	2020-07-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15759	\N	\N
18723	MEMBRECOM	2020-07-01 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15760	\N	\N
18724	MEMBRECOM	2020-07-01 00:00:00	2020-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15761	\N	\N
18725	MEMBRECOM	2020-07-01 00:00:00	2020-07-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15762	\N	\N
18726	MEMBRECOM	2020-07-01 00:00:00	2020-07-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15763	\N	\N
19550	MEMBRECOM	2020-11-05 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16213	\N	\N
19820	PDTCOM	2021-03-04 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16404	\N	\N
19821	RAPCOM	2021-03-04 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16419	\N	\N
20385	MEMBRECOM	2021-06-30 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16949	\N	\N
22201	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18521	\N	\N
22202	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18522	\N	\N
22203	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18523	\N	\N
22204	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18524	\N	\N
22205	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18525	\N	\N
22206	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18526	\N	\N
22249	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18569	\N	\N
22250	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18570	\N	\N
22251	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18571	\N	\N
22252	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18572	\N	\N
22253	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18573	\N	\N
22254	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18574	\N	\N
22255	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18575	\N	\N
22256	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18576	\N	\N
22257	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18577	\N	\N
22258	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18578	\N	\N
22259	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18579	\N	\N
22260	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18580	\N	\N
22261	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18581	\N	\N
22262	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18582	\N	\N
22263	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18583	\N	\N
22264	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18584	\N	\N
22265	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18585	\N	\N
22266	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18586	\N	\N
22267	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18587	\N	\N
22268	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18588	\N	\N
22269	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18589	\N	\N
22270	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18590	\N	\N
22271	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18591	\N	\N
22272	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18592	\N	\N
22282	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18602	\N	\N
22283	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18603	\N	\N
22284	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18604	\N	\N
22285	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18605	\N	\N
22400	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18673	\N	\N
22401	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18674	\N	\N
22402	MEMBRECOM	2023-10-04 00:00:00	2024-04-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18675	\N	\N
22403	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18676	\N	\N
22404	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18677	\N	\N
22405	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18678	\N	\N
22454	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18690	\N	\N
22455	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18691	\N	\N
22456	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18692	\N	\N
22457	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18693	\N	\N
22458	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18694	\N	\N
22459	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18695	\N	\N
22460	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18696	\N	\N
22461	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18697	\N	\N
22462	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18698	\N	\N
22463	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18699	\N	\N
22464	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18700	\N	\N
22465	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18701	\N	\N
22466	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18702	\N	\N
22467	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18703	\N	\N
22468	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18704	\N	\N
22469	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18705	\N	\N
22470	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18706	\N	\N
22471	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18707	\N	\N
22472	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18708	\N	\N
22473	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18709	\N	\N
22474	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18710	\N	\N
22475	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18711	\N	\N
22476	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18712	\N	\N
22477	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18713	\N	\N
22478	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18714	\N	\N
22479	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18715	\N	\N
22480	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18716	\N	\N
22481	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18717	\N	\N
22482	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18718	\N	\N
22483	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18719	\N	\N
22484	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18720	\N	\N
22485	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18721	\N	\N
22486	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18722	\N	\N
22487	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18723	\N	\N
22488	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18724	\N	\N
22489	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18725	\N	\N
22490	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18726	\N	\N
23569	MEMBRECOM	2024-03-27 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19599	2024-03-26 00:00:00	\N
18082	MEMBRECOM	2017-11-08 00:00:00	2020-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15202	\N	\N
18611	MEMBRECOM	2020-05-27 00:00:00	2020-06-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15648	\N	\N
18612	MEMBRECOM	2020-05-27 00:00:00	2020-06-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15649	\N	\N
18613	MEMBRECOM	2020-05-27 00:00:00	2020-06-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15650	\N	\N
18614	MEMBRECOM	2020-05-27 00:00:00	2020-06-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15651	\N	\N
18615	MEMBRECOM	2020-05-27 00:00:00	2020-06-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15652	\N	\N
18616	MEMBRECOM	2020-05-27 00:00:00	2020-06-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15653	\N	\N
18617	MEMBRECOM	2020-05-27 00:00:00	2020-06-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15654	\N	\N
18618	MEMBRECOM	2020-05-27 00:00:00	2020-06-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15655	\N	\N
18619	MEMBRECOM	2020-05-27 00:00:00	2020-06-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15656	\N	\N
18620	MEMBRECOM	2020-05-27 00:00:00	2020-06-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15657	\N	\N
18621	MEMBRECOM	2020-05-27 00:00:00	2020-06-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15658	\N	\N
18622	MEMBRECOM	2020-05-27 00:00:00	2020-06-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15659	\N	\N
18623	MEMBRECOM	2020-05-27 00:00:00	2020-06-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15660	\N	\N
18624	MEMBRECOM	2020-05-27 00:00:00	2020-06-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15661	\N	\N
18641	MEMBRECOM	2020-06-22 00:00:00	2020-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15678	\N	\N
18642	MEMBRECOM	2020-06-22 00:00:00	2020-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15679	\N	\N
18643	MEMBRECOM	2020-06-22 00:00:00	2020-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15680	\N	\N
18644	MEMBRECOM	2020-06-22 00:00:00	2020-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15681	\N	\N
18645	MEMBRECOM	2020-06-22 00:00:00	2020-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15682	\N	\N
18646	MEMBRECOM	2020-06-22 00:00:00	2020-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15683	\N	\N
18647	MEMBRECOM	2020-06-22 00:00:00	2020-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15684	\N	\N
18648	MEMBRECOM	2020-06-22 00:00:00	2020-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15685	\N	\N
18649	MEMBRECOM	2020-06-22 00:00:00	2020-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15686	\N	\N
18650	MEMBRECOM	2020-06-22 00:00:00	2020-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15687	\N	\N
18651	MEMBRECOM	2020-06-22 00:00:00	2020-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15688	\N	\N
18652	MEMBRECOM	2020-06-22 00:00:00	2020-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15689	\N	\N
18653	MEMBRECOM	2020-06-22 00:00:00	2020-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15690	\N	\N
18654	MEMBRECOM	2020-06-22 00:00:00	2020-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15691	\N	\N
20386	MEMBRECOM	2021-07-06 00:00:00	2021-07-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16950	\N	\N
18935	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10161	\N	\N
20399	MEMBRECOM	2021-07-08 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2577	\N	\N
20400	RAPGENCOM	2021-07-08 00:00:00	2023-10-01 00:00:00	2	ANCIEN	\N	\N	\N	\N	10085	\N	\N
20798	MEMBRECOM	2023-01-25 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17272	\N	\N
23229	VICPDTCOM	2024-01-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19221	\N	\N
23230	VICPDTCOM	2024-01-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19225	\N	\N
18941	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8692	\N	\N
23231	VICPDTCOM	2024-01-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19227	\N	\N
18943	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13537	\N	\N
23232	VICPDTCOM	2024-01-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19229	\N	\N
18945	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8724	\N	\N
23233	VICPDTCOM	2024-01-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19231	\N	\N
23234	VICPDTCOM	2024-01-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19232	\N	\N
23235	VICPDTCOM	2024-01-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19234	\N	\N
23236	VICPDTCOM	2024-01-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19239	\N	\N
23237	VICPDTCOM	2024-01-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19240	\N	\N
23238	VICPDTCOM	2024-01-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19241	\N	\N
23239	RAPCOM	2024-01-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19223	\N	\N
23240	PDTCOM	2024-01-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19236	\N	\N
18961	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8040	\N	\N
18962	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8123	\N	\N
18963	MEMBRECOM	2020-10-06 00:00:00	2021-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10085	\N	\N
18966	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10174	\N	\N
18967	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10175	\N	\N
18970	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2553	\N	\N
18973	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10186	\N	\N
18974	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8085	\N	\N
18975	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2631	\N	\N
18978	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10091	\N	\N
18979	MEMBRECOM	2020-10-06 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4251	\N	\N
18984	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13399	\N	\N
18996	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7415	\N	\N
19000	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8205	\N	\N
19003	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	427	\N	\N
19005	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8037	\N	\N
19007	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	755	\N	\N
19010	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13400	\N	\N
19011	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13405	\N	\N
19015	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13427	\N	\N
19016	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11436	\N	\N
19017	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15959	\N	\N
19018	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15960	\N	\N
19019	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15961	\N	\N
19020	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15962	\N	\N
19021	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15963	\N	\N
19022	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15964	\N	\N
19023	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15965	\N	\N
19024	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15966	\N	\N
19025	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15967	\N	\N
19026	MEMBRECOM	2020-10-06 00:00:00	2021-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15968	\N	\N
19027	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15969	\N	\N
19028	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15970	\N	\N
19029	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15971	\N	\N
19030	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15972	\N	\N
19031	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15973	\N	\N
19032	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15974	\N	\N
19034	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15976	\N	\N
19035	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15977	\N	\N
19036	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15978	\N	\N
19037	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15979	\N	\N
19038	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15980	\N	\N
19039	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15981	\N	\N
19040	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15982	\N	\N
19042	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15984	\N	\N
19043	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15985	\N	\N
19044	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15986	\N	\N
19045	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15987	\N	\N
19046	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15988	\N	\N
19047	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15989	\N	\N
19048	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15990	\N	\N
19049	MEMBRECOM	2020-10-06 00:00:00	2022-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15991	\N	\N
19050	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15992	\N	\N
19051	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15993	\N	\N
19052	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15994	\N	\N
19053	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15995	\N	\N
19054	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15996	\N	\N
19055	MEMBRECOM	2020-10-06 00:00:00	2022-02-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15997	\N	\N
19056	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15998	\N	\N
18658	MEMBRECOM	2020-06-28 00:00:00	2020-06-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15695	\N	\N
18794	MEMBRECOM	2020-07-14 00:00:00	2020-07-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15820	\N	\N
19387	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8128	\N	\N
19388	SECRETCOM	2020-10-07 00:00:00	2021-10-19 00:00:00	14	ANCIEN	\N	\N	\N	\N	8128	\N	\N
19389	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10142	\N	\N
19394	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	6	ANCIEN	\N	\N	\N	\N	10142	\N	\N
19398	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13374	\N	\N
19399	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	2	ANCIEN	\N	\N	\N	\N	13374	\N	\N
19401	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13416	\N	\N
19402	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	9	ANCIEN	\N	\N	\N	\N	13416	\N	\N
20535	PDTCOM	2021-11-25 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17029	\N	\N
20536	VICPDTCOM	2021-11-25 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17027	\N	\N
20537	VICPDTCOM	2021-11-25 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17020	\N	\N
20538	VICPDTCOM	2021-11-25 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17028	\N	\N
20539	VICPDTCOM	2021-11-25 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17030	\N	\N
20540	VICPDTCOM	2021-11-25 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17033	\N	\N
20541	VICPDTCOM	2021-11-25 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17017	\N	\N
20542	VICPDTCOM	2021-11-25 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17025	\N	\N
20543	VICPDTCOM	2021-11-25 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17023	\N	\N
20544	VICPDTCOM	2021-11-25 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17036	\N	\N
20545	VICPDTCOM	2021-11-25 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17031	\N	\N
20546	RAPCOM	2021-11-25 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17016	\N	\N
22990	MEMBRECOM	2023-12-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19102	\N	\N
22991	MEMBRECOM	2023-12-14 00:00:00	2024-01-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19103	\N	\N
22992	MEMBRECOM	2023-12-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19104	\N	\N
22993	MEMBRECOM	2023-12-14 00:00:00	2024-01-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19105	\N	\N
22994	MEMBRECOM	2023-12-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19106	\N	\N
22995	MEMBRECOM	2023-12-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19107	\N	\N
22996	MEMBRECOM	2023-12-14 00:00:00	2024-01-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19108	\N	\N
22997	MEMBRECOM	2023-12-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19109	\N	\N
22998	MEMBRECOM	2023-12-14 00:00:00	2024-01-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19110	\N	\N
22999	MEMBRECOM	2023-12-14 00:00:00	2024-01-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19111	\N	\N
23000	MEMBRECOM	2023-12-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19112	\N	\N
23001	MEMBRECOM	2023-12-14 00:00:00	2024-01-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19113	\N	\N
23002	MEMBRECOM	2023-12-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19114	\N	\N
23003	MEMBRECOM	2023-12-14 00:00:00	2024-01-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19115	\N	\N
23004	MEMBRECOM	2023-12-14 00:00:00	2024-01-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19116	\N	\N
23005	MEMBRECOM	2023-12-14 00:00:00	2024-01-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19117	\N	\N
23006	MEMBRECOM	2023-12-14 00:00:00	2024-01-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19118	\N	\N
23007	MEMBRECOM	2023-12-14 00:00:00	2024-01-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19119	\N	\N
23008	MEMBRECOM	2023-12-14 00:00:00	2024-01-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19120	\N	\N
19482	MEMBRECOM	2020-10-20 00:00:00	2021-06-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16145	\N	\N
19058	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16000	\N	\N
19059	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16001	\N	\N
19060	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16002	\N	\N
19061	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16003	\N	\N
19062	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16004	\N	\N
10157	MEMBRECOM	2012-01-25 00:00:00	2022-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8515	\N	\N
19129	MEMBRECOM	2020-10-06 00:00:00	2021-05-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16066	\N	\N
20711	MEMBRECOM	2023-01-01 00:00:00	2023-01-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17185	\N	\N
19128	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16065	\N	\N
13686	MEMBRECOM	2015-12-16 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11550	2015-12-16 17:20:05	\N
19131	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16068	\N	\N
19070	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16009	\N	\N
19188	MEMBRECOM	2017-10-04 00:00:00	2017-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6826	\N	\N
19072	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16011	\N	\N
19073	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16012	\N	\N
21786	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18108	2023-09-24 00:00:00	\N
19075	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16014	\N	\N
19076	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16015	\N	\N
19132	MEMBRECOM	2020-10-06 00:00:00	2020-11-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16069	\N	\N
21787	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18109	2023-09-24 00:00:00	\N
21788	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18111	2023-09-24 00:00:00	\N
19080	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16018	\N	\N
22011	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18331	\N	\N
19082	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16020	\N	\N
19083	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16021	\N	\N
19084	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16022	\N	\N
22012	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18332	\N	\N
19086	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16023	\N	\N
19087	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16024	\N	\N
19088	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16025	\N	\N
19089	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16026	\N	\N
19090	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16027	\N	\N
19092	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16029	\N	\N
19093	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16030	\N	\N
19094	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16031	\N	\N
19095	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16032	\N	\N
19096	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16033	\N	\N
19097	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16034	\N	\N
19098	MEMBRECOM	2020-10-06 00:00:00	2020-11-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16035	\N	\N
19099	MEMBRECOM	2020-10-06 00:00:00	2021-10-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16036	\N	\N
19100	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16037	\N	\N
19101	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16038	\N	\N
19102	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16039	\N	\N
19103	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16040	\N	\N
19104	MEMBRECOM	2020-10-06 00:00:00	2021-09-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16041	\N	\N
19105	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16042	\N	\N
19106	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16043	\N	\N
19107	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16044	\N	\N
19108	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16045	\N	\N
19109	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16046	\N	\N
19110	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16047	\N	\N
19111	MEMBRECOM	2020-10-06 00:00:00	2021-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16048	\N	\N
19112	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16049	\N	\N
19113	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16050	\N	\N
19114	MEMBRECOM	2020-10-06 00:00:00	2020-10-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16051	\N	\N
19115	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16052	\N	\N
19116	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16053	\N	\N
19118	MEMBRECOM	2020-10-06 00:00:00	2020-11-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16055	\N	\N
19119	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16056	\N	\N
19120	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16057	\N	\N
19121	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16058	\N	\N
19122	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16059	\N	\N
19123	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16060	\N	\N
19124	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16061	\N	\N
19125	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16062	\N	\N
19126	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16063	\N	\N
19127	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16064	\N	\N
19133	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16070	\N	\N
19134	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16071	\N	\N
19135	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8074	\N	\N
19137	MEMBRECOM	2020-10-06 00:00:00	2020-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16073	\N	\N
19138	MEMBRECOM	2020-10-06 00:00:00	2020-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16074	\N	\N
19140	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16076	\N	\N
19141	MEMBRECOM	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16077	\N	\N
19144	MEMBRECOM	2020-10-06 00:00:00	2021-05-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16080	\N	\N
19145	MEMBRECOM	2020-10-06 00:00:00	2021-05-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16081	\N	\N
19146	MEMBRECOM	2020-10-06 00:00:00	2020-11-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16082	\N	\N
18005	MEMBRECOM	2019-07-11 00:00:00	2019-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15127	\N	\N
18006	MEMBRECOM	2019-07-11 00:00:00	2019-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15128	\N	\N
18007	MEMBRECOM	2019-07-11 00:00:00	2019-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15129	\N	\N
18008	MEMBRECOM	2019-07-11 00:00:00	2019-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15130	\N	\N
18009	MEMBRECOM	2019-07-11 00:00:00	2019-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15131	\N	\N
18010	MEMBRECOM	2019-07-11 00:00:00	2019-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15132	\N	\N
18011	MEMBRECOM	2019-07-11 00:00:00	2019-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15133	\N	\N
18012	MEMBRECOM	2019-07-11 00:00:00	2019-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15134	\N	\N
18013	MEMBRECOM	2019-07-11 00:00:00	2019-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15135	\N	\N
18014	MEMBRECOM	2019-07-11 00:00:00	2019-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15136	\N	\N
18015	MEMBRECOM	2019-07-11 00:00:00	2019-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15137	\N	\N
18016	MEMBRECOM	2019-07-11 00:00:00	2019-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15138	\N	\N
18017	MEMBRECOM	2019-07-11 00:00:00	2019-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15139	\N	\N
18018	MEMBRECOM	2019-07-11 00:00:00	2019-07-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15140	\N	\N
18145	MEMBRECOM	2019-10-16 00:00:00	2019-10-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15263	\N	\N
18146	RAPCOM	2019-10-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15251	\N	\N
18149	RAPCOM	2019-10-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15244	\N	\N
18148	PDTCOM	2019-10-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15263	\N	\N
18150	VICPDTCOM	2019-10-17 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15249	\N	\N
18151	VICPDTCOM	2019-10-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15248	\N	\N
18152	VICPDTCOM	2019-10-17 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15260	\N	\N
18153	VICPDTCOM	2019-10-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15250	\N	\N
18154	VICPDTCOM	2019-10-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15257	\N	\N
18155	VICPDTCOM	2019-10-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15246	\N	\N
20364	MEMBRECOM	2021-06-30 00:00:00	2021-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16928	\N	\N
20365	MEMBRECOM	2021-06-30 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16929	\N	\N
20366	MEMBRECOM	2021-06-30 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16930	\N	\N
20367	MEMBRECOM	2021-06-30 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16931	\N	\N
20368	MEMBRECOM	2021-06-30 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16932	\N	\N
20369	MEMBRECOM	2021-06-30 00:00:00	2021-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16933	\N	\N
20370	MEMBRECOM	2021-06-30 00:00:00	2021-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16934	\N	\N
20371	MEMBRECOM	2021-06-30 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16935	\N	\N
20372	MEMBRECOM	2021-06-30 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16936	\N	\N
20373	MEMBRECOM	2021-06-30 00:00:00	2021-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16937	\N	\N
20374	MEMBRECOM	2021-06-30 00:00:00	2021-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16938	\N	\N
20375	MEMBRECOM	2021-06-30 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16939	\N	\N
20376	MEMBRECOM	2021-06-30 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16940	\N	\N
20377	MEMBRECOM	2021-06-30 00:00:00	2021-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16941	\N	\N
20378	MEMBRECOM	2021-06-30 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16942	\N	\N
20379	MEMBRECOM	2021-06-30 00:00:00	2021-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16943	\N	\N
20380	MEMBRECOM	2021-06-30 00:00:00	2021-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16944	\N	\N
20381	MEMBRECOM	2021-06-30 00:00:00	2021-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16945	\N	\N
20382	MEMBRECOM	2021-06-30 00:00:00	2021-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16946	\N	\N
20383	MEMBRECOM	2021-06-30 00:00:00	2021-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16947	\N	\N
20384	MEMBRECOM	2021-06-30 00:00:00	2021-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16948	\N	\N
20401	MEMBRECOM	2021-07-15 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16951	\N	\N
21146	VICPDTCOM	2023-03-30 00:00:00	2023-07-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17459	\N	\N
21147	RAPGENCOM	2023-03-30 00:00:00	2023-07-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17462	\N	\N
21148	RAPCOM	2023-03-30 00:00:00	2023-07-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17460	\N	\N
21719	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18041	2023-09-24 00:00:00	\N
21720	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18042	2023-09-24 00:00:00	\N
21721	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18043	2023-09-24 00:00:00	\N
21722	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18044	2023-09-24 00:00:00	\N
21789	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18110	2023-09-24 00:00:00	\N
21790	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18112	2023-09-24 00:00:00	\N
21791	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18113	2023-09-24 00:00:00	\N
21792	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18114	2023-09-24 00:00:00	\N
21793	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18115	2023-09-24 00:00:00	\N
15979	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8682	2017-10-04 00:00:00	\N
22591	VICPDTCOM	2023-10-05 00:00:00	\N	12	ACTIF	\N	\N	\N	\N	18333	\N	\N
22592	VICPDTCOM	2023-10-05 00:00:00	\N	7	ACTIF	\N	\N	\N	\N	18439	\N	\N
22593	RAPGENCOM	2023-10-05 00:00:00	\N	2	ACTIF	\N	\N	\N	\N	18436	\N	\N
22594	VICPDTCOM	2023-10-05 00:00:00	\N	8	ACTIF	\N	\N	\N	\N	18602	\N	\N
22595	VICPDTCOM	2023-10-05 00:00:00	\N	9	ACTIF	\N	\N	\N	\N	18524	\N	\N
22596	VICPDTCOM	2023-10-05 00:00:00	\N	4	ACTIF	\N	\N	\N	\N	18504	\N	\N
22597	VICPDTCOM	2023-10-05 00:00:00	\N	3	ACTIF	\N	\N	\N	\N	18492	\N	\N
22598	VICPDTCOM	2023-10-05 00:00:00	\N	5	ACTIF	\N	\N	\N	\N	18376	\N	\N
22599	VICPDTCOM	2023-10-05 00:00:00	\N	6	ACTIF	\N	\N	\N	\N	18375	\N	\N
22600	VICPDTCOM	2023-10-05 00:00:00	\N	11	ACTIF	\N	\N	\N	\N	18345	\N	\N
22601	VICPDTCOM	2023-10-05 00:00:00	\N	10	ACTIF	\N	\N	\N	\N	18666	\N	\N
18640	MEMBRECOM	2020-06-18 00:00:00	2020-06-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15677	\N	\N
19545	MEMBRECOM	2020-11-02 00:00:00	2020-11-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16208	\N	\N
19822	VICPDTCOM	2021-03-04 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16414	\N	\N
19823	VICPDTCOM	2021-03-04 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16415	\N	\N
19824	VICPDTCOM	2021-03-04 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16403	\N	\N
19825	VICPDTCOM	2021-03-04 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16401	\N	\N
19826	VICPDTCOM	2021-03-04 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16400	\N	\N
19827	VICPDTCOM	2021-03-04 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16411	\N	\N
19828	VICPDTCOM	2021-03-04 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16413	\N	\N
19829	VICPDTCOM	2021-03-04 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16402	\N	\N
19830	SECRETCOM	2021-03-04 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16412	\N	\N
19831	SECRETCOM	2021-03-04 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16418	\N	\N
20693	MEMBRECOM	2022-07-04 00:00:00	2022-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17176	\N	\N
21190	MEMBRECOM	2023-04-20 00:00:00	2023-05-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17529	\N	\N
21191	MEMBRECOM	2023-04-20 00:00:00	2023-05-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17530	\N	\N
21192	MEMBRECOM	2023-04-20 00:00:00	2023-05-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17531	\N	\N
21193	MEMBRECOM	2023-04-20 00:00:00	2023-05-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17532	\N	\N
21194	MEMBRECOM	2023-04-20 00:00:00	2023-05-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17533	\N	\N
21195	MEMBRECOM	2023-04-20 00:00:00	2023-05-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17534	\N	\N
21196	MEMBRECOM	2023-04-20 00:00:00	2023-05-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17535	\N	\N
21197	MEMBRECOM	2023-04-20 00:00:00	2023-05-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17536	\N	\N
21198	MEMBRECOM	2023-04-20 00:00:00	2023-05-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17537	\N	\N
21199	MEMBRECOM	2023-04-20 00:00:00	2023-05-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17538	\N	\N
21200	MEMBRECOM	2023-04-20 00:00:00	2023-05-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17539	\N	\N
21201	MEMBRECOM	2023-04-20 00:00:00	2023-05-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17540	\N	\N
21202	MEMBRECOM	2023-04-20 00:00:00	2023-05-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17541	\N	\N
21203	MEMBRECOM	2023-04-20 00:00:00	2023-05-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17542	\N	\N
21286	MEMBRECOM	2023-07-10 00:00:00	2023-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17608	\N	\N
21287	MEMBRECOM	2023-07-10 00:00:00	2023-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17609	\N	\N
21288	MEMBRECOM	2023-07-10 00:00:00	2023-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17610	\N	\N
21289	MEMBRECOM	2023-07-10 00:00:00	2023-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17611	\N	\N
21290	MEMBRECOM	2023-07-10 00:00:00	2023-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17612	\N	\N
21291	MEMBRECOM	2023-07-10 00:00:00	2023-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17613	\N	\N
21292	MEMBRECOM	2023-07-10 00:00:00	2023-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17614	\N	\N
21293	VICPDTCOM	2023-07-10 00:00:00	2023-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17615	\N	\N
21294	RAPCOM	2023-07-10 00:00:00	2023-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17616	\N	\N
21295	MEMBRECOM	2023-07-10 00:00:00	2023-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17617	\N	\N
21296	MEMBRECOM	2023-07-10 00:00:00	2023-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17618	\N	\N
21297	MEMBRECOM	2023-07-10 00:00:00	2023-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17619	\N	\N
21298	MEMBRECOM	2023-07-10 00:00:00	2023-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17620	\N	\N
21299	MEMBRECOM	2023-07-10 00:00:00	2023-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17621	\N	\N
21310	MEMBRECOM	2023-07-06 00:00:00	2023-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17632	\N	\N
21308	MEMBRECOM	2023-07-06 00:00:00	2023-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17630	\N	\N
21309	MEMBRECOM	2023-07-06 00:00:00	2023-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17631	\N	\N
21311	MEMBRECOM	2023-07-06 00:00:00	2023-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17633	\N	\N
21312	MEMBRECOM	2023-07-06 00:00:00	2023-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17634	\N	\N
21313	MEMBRECOM	2023-07-06 00:00:00	2023-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17635	\N	\N
21314	MEMBRECOM	2023-07-06 00:00:00	2023-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17636	\N	\N
21315	PDTCOM	2023-07-06 00:00:00	2023-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17637	\N	\N
21316	RAPCOM	2023-07-06 00:00:00	2023-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17638	\N	\N
21317	MEMBRECOM	2023-07-06 00:00:00	2023-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17639	\N	\N
21318	MEMBRECOM	2023-07-06 00:00:00	2023-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17640	\N	\N
21319	MEMBRECOM	2023-07-06 00:00:00	2023-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17641	\N	\N
21320	MEMBRECOM	2023-07-06 00:00:00	2023-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17642	\N	\N
21321	MEMBRECOM	2023-07-06 00:00:00	2023-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17643	\N	\N
21322	MEMBRECOM	2023-06-28 00:00:00	2023-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17644	\N	\N
21323	MEMBRECOM	2023-06-28 00:00:00	2023-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17645	\N	\N
21324	MEMBRECOM	2023-06-28 00:00:00	2023-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17646	\N	\N
21325	MEMBRECOM	2023-06-28 00:00:00	2023-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17647	\N	\N
21326	MEMBRECOM	2023-06-28 00:00:00	2023-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17648	\N	\N
21327	MEMBRECOM	2023-06-28 00:00:00	2023-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17649	\N	\N
21328	MEMBRECOM	2023-06-28 00:00:00	2023-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17650	\N	\N
21329	VICPDTCOM	2023-06-28 00:00:00	2023-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17651	\N	\N
21330	RAPCOM	2023-06-28 00:00:00	2023-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17652	\N	\N
21331	MEMBRECOM	2023-06-28 00:00:00	2023-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17653	\N	\N
21332	MEMBRECOM	2023-06-28 00:00:00	2023-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17654	\N	\N
21333	MEMBRECOM	2023-06-28 00:00:00	2023-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17655	\N	\N
21334	MEMBRECOM	2023-06-28 00:00:00	2023-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17656	\N	\N
21335	MEMBRECOM	2023-06-28 00:00:00	2023-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17657	\N	\N
21336	MEMBRECOM	2023-06-28 00:00:00	2023-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17658	\N	\N
21337	MEMBRECOM	2023-06-28 00:00:00	2023-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17659	\N	\N
21338	MEMBRECOM	2023-06-28 00:00:00	2023-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17660	\N	\N
21339	MEMBRECOM	2023-06-28 00:00:00	2023-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17661	\N	\N
21340	MEMBRECOM	2023-06-28 00:00:00	2023-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17662	\N	\N
21341	MEMBRECOM	2023-06-28 00:00:00	2023-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17663	\N	\N
21342	MEMBRECOM	2023-06-28 00:00:00	2023-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17664	\N	\N
21343	VICPDTCOM	2023-06-28 00:00:00	2023-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17665	\N	\N
21344	RAPCOM	2023-06-28 00:00:00	2023-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17666	\N	\N
21345	MEMBRECOM	2023-06-28 00:00:00	2023-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17667	\N	\N
21346	MEMBRECOM	2023-06-28 00:00:00	2023-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17668	\N	\N
21347	MEMBRECOM	2023-06-28 00:00:00	2023-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17669	\N	\N
21348	MEMBRECOM	2023-06-28 00:00:00	2023-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17670	\N	\N
21349	MEMBRECOM	2023-06-28 00:00:00	2023-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17671	\N	\N
21350	MEMBRECOM	2023-06-28 00:00:00	2023-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17672	\N	\N
21351	MEMBRECOM	2023-06-28 00:00:00	2023-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17673	\N	\N
21352	MEMBRECOM	2023-06-28 00:00:00	2023-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17674	\N	\N
21353	MEMBRECOM	2023-06-28 00:00:00	2023-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17675	\N	\N
21354	MEMBRECOM	2023-06-28 00:00:00	2023-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17676	\N	\N
21355	MEMBRECOM	2023-06-28 00:00:00	2023-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17677	\N	\N
21356	MEMBRECOM	2023-06-28 00:00:00	2023-06-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17678	\N	\N
21357	PDTCOM	2023-06-20 00:00:00	2023-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17679	\N	\N
21358	MEMBRECOM	2023-06-20 00:00:00	2023-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17680	\N	\N
21359	MEMBRECOM	2023-06-20 00:00:00	2023-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17681	\N	\N
21360	MEMBRECOM	2023-06-20 00:00:00	2023-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17682	\N	\N
21361	MEMBRECOM	2023-06-20 00:00:00	2023-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17683	\N	\N
21362	MEMBRECOM	2023-06-20 00:00:00	2023-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17684	\N	\N
21363	MEMBRECOM	2023-06-20 00:00:00	2023-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17685	\N	\N
21364	MEMBRECOM	2023-06-20 00:00:00	2023-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17686	\N	\N
21365	RAPCOM	2023-06-20 00:00:00	2023-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17687	\N	\N
21366	MEMBRECOM	2023-06-20 00:00:00	2023-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17688	\N	\N
21367	MEMBRECOM	2023-06-20 00:00:00	2023-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17689	\N	\N
21368	MEMBRECOM	2023-06-20 00:00:00	2023-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17690	\N	\N
21369	MEMBRECOM	2023-06-20 00:00:00	2023-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17691	\N	\N
21370	MEMBRECOM	2023-06-20 00:00:00	2023-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17692	\N	\N
21371	MEMBRECOM	2023-06-19 00:00:00	2023-06-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17693	\N	\N
21372	MEMBRECOM	2023-06-19 00:00:00	2023-06-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17694	\N	\N
21373	MEMBRECOM	2023-06-19 00:00:00	2023-06-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17695	\N	\N
21374	RAPCOM	2023-06-19 00:00:00	2023-06-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17696	\N	\N
21375	MEMBRECOM	2023-06-19 00:00:00	2023-06-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17697	\N	\N
21376	MEMBRECOM	2023-06-19 00:00:00	2023-06-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17698	\N	\N
21377	MEMBRECOM	2023-06-19 00:00:00	2023-06-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17699	\N	\N
21378	PDTCOM	2023-06-19 00:00:00	2023-06-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17700	\N	\N
21379	RAPCOM	2023-06-19 00:00:00	2023-06-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17701	\N	\N
21380	RAPCOM	2023-06-19 00:00:00	2023-06-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17702	\N	\N
21381	MEMBRECOM	2023-06-19 00:00:00	2023-06-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17703	\N	\N
21382	MEMBRECOM	2023-06-19 00:00:00	2023-06-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17704	\N	\N
21383	MEMBRECOM	2023-06-19 00:00:00	2023-06-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17705	\N	\N
21384	MEMBRECOM	2023-06-19 00:00:00	2023-06-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17706	\N	\N
21833	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18153	2023-10-03 00:00:00	\N
21834	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18154	2023-10-03 00:00:00	\N
21835	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18155	2023-10-03 00:00:00	\N
21836	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18156	2023-10-03 00:00:00	\N
21837	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18157	2023-10-03 00:00:00	\N
21838	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18158	2023-10-03 00:00:00	\N
21839	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18159	2023-10-03 00:00:00	\N
21840	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18160	2023-10-03 00:00:00	\N
21841	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18161	2023-10-03 00:00:00	\N
21842	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18162	2023-10-03 00:00:00	\N
21843	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18163	2023-10-03 00:00:00	\N
21844	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18164	2023-10-03 00:00:00	\N
18305	MEMBRECOM	2020-01-29 00:00:00	2020-09-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15385	\N	\N
18306	MEMBRECOM	2020-01-29 00:00:00	2020-09-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15386	\N	\N
18307	MEMBRECOM	2020-01-29 00:00:00	2020-09-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15387	\N	\N
18308	MEMBRECOM	2020-01-29 00:00:00	2020-09-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15388	\N	\N
18309	MEMBRECOM	2020-01-29 00:00:00	2020-09-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15389	\N	\N
18310	MEMBRECOM	2020-01-29 00:00:00	2020-09-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15390	\N	\N
18311	MEMBRECOM	2020-01-29 00:00:00	2020-02-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15391	\N	\N
18312	MEMBRECOM	2020-01-29 00:00:00	2020-09-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15392	\N	\N
18313	MEMBRECOM	2020-01-29 00:00:00	2020-02-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15393	\N	\N
18314	MEMBRECOM	2020-01-29 00:00:00	2020-02-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15394	\N	\N
18315	MEMBRECOM	2020-01-29 00:00:00	2020-09-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15395	\N	\N
18316	MEMBRECOM	2020-01-29 00:00:00	2020-09-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15396	\N	\N
18317	MEMBRECOM	2020-01-29 00:00:00	2020-02-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15397	\N	\N
18318	MEMBRECOM	2020-01-29 00:00:00	2020-09-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15398	\N	\N
18319	MEMBRECOM	2020-01-29 00:00:00	2020-02-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15399	\N	\N
18320	MEMBRECOM	2020-01-29 00:00:00	2020-02-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15400	\N	\N
18321	MEMBRECOM	2020-01-29 00:00:00	2020-09-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15401	\N	\N
18322	MEMBRECOM	2020-01-29 00:00:00	2020-09-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15402	\N	\N
18323	MEMBRECOM	2020-01-29 00:00:00	2020-02-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15403	\N	\N
18324	MEMBRECOM	2020-01-29 00:00:00	2020-02-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15404	\N	\N
18325	MEMBRECOM	2020-01-29 00:00:00	2020-02-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15405	\N	\N
19556	MEMBRECOM	2020-12-02 00:00:00	2020-12-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16219	\N	\N
18863	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15888	\N	\N
18864	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15889	\N	\N
18867	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15892	\N	\N
18868	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15893	\N	\N
18871	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15896	\N	\N
18872	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15897	\N	\N
18874	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15899	\N	\N
18876	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15901	\N	\N
18880	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15905	\N	\N
18882	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15907	\N	\N
18888	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15913	\N	\N
18891	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15916	\N	\N
18892	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15917	\N	\N
11231	MEMBRECOM	2013-07-04 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9475	\N	\N
18896	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15921	\N	\N
18900	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15925	\N	\N
18901	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15926	\N	\N
18902	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15927	\N	\N
8011	MEMBRECOM	2009-02-27 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6579	\N	\N
11622	MEMBRECOM	2013-12-09 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9827	\N	\N
13399	MEMBRECOM	2015-02-18 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11306	2015-02-18 17:53:55	\N
18903	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15928	\N	\N
18911	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15936	\N	\N
3785	MEMBRECOM	2005-05-11 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2874	\N	\N
18912	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15937	\N	\N
18915	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15940	\N	\N
18916	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15941	\N	\N
18917	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15942	\N	\N
4153	MEMBRECOM	2006-02-28 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3234	\N	\N
8812	MEMBRECOM	2010-06-02 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7318	\N	\N
9284	MEMBRECOM	2011-04-27 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7781	\N	\N
9327	MEMBRECOM	2011-06-21 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7824	\N	\N
11361	MEMBRECOM	2013-10-03 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9597	\N	\N
13720	MEMBRECOM	2015-07-25 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11576	\N	\N
19192	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15975	\N	\N
19193	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16010	\N	\N
19194	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10168	\N	\N
19195	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16016	\N	\N
19196	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7751	\N	\N
19197	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13424	\N	\N
19198	PDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	1	ANCIEN	\N	\N	\N	\N	7399	\N	\N
19199	RAPGENCOM	2020-10-07 00:00:00	2021-07-07 00:00:00	2	ANCIEN	\N	\N	\N	\N	2577	\N	\N
19200	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	3	ANCIEN	\N	\N	\N	\N	10179	\N	\N
19201	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	4	ANCIEN	\N	\N	\N	\N	10171	\N	\N
19202	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	5	ANCIEN	\N	\N	\N	\N	2619	\N	\N
19203	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	6	ANCIEN	\N	\N	\N	\N	13518	\N	\N
19204	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	7	ANCIEN	\N	\N	\N	\N	13522	\N	\N
19205	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	8	ANCIEN	\N	\N	\N	\N	13516	\N	\N
19206	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	9	ANCIEN	\N	\N	\N	\N	13520	\N	\N
19207	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	10	ANCIEN	\N	\N	\N	\N	8153	\N	\N
19208	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	11	ANCIEN	\N	\N	\N	\N	13515	\N	\N
16040	MEMBRECOM	2017-10-04 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13515	2017-10-04 20:03:35	\N
19209	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	12	ANCIEN	\N	\N	\N	\N	10170	\N	\N
19210	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	13	ANCIEN	\N	\N	\N	\N	16017	\N	\N
19211	SECRETCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	14	ANCIEN	\N	\N	\N	\N	13519	\N	\N
19212	SECRETCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	15	ANCIEN	\N	\N	\N	\N	13525	\N	\N
19213	SECRETCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	16	ANCIEN	\N	\N	\N	\N	13527	\N	\N
19214	SECRETCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	17	ANCIEN	\N	\N	\N	\N	11498	\N	\N
19215	SECRETCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	18	ANCIEN	\N	\N	\N	\N	13514	\N	\N
19216	PDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	1	ANCIEN	\N	\N	\N	\N	10163	\N	\N
19217	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	2	ANCIEN	\N	\N	\N	\N	8696	\N	\N
19218	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	3	ANCIEN	\N	\N	\N	\N	10160	\N	\N
19219	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	4	ANCIEN	\N	\N	\N	\N	16067	\N	\N
19220	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	5	ANCIEN	\N	\N	\N	\N	13465	\N	\N
19221	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	6	ANCIEN	\N	\N	\N	\N	10103	\N	\N
19222	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	7	ANCIEN	\N	\N	\N	\N	10096	\N	\N
19223	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	8	ANCIEN	\N	\N	\N	\N	13500	\N	\N
19224	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	9	ANCIEN	\N	\N	\N	\N	15876	\N	\N
19225	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	10	ANCIEN	\N	\N	\N	\N	13489	\N	\N
19226	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	11	ANCIEN	\N	\N	\N	\N	10099	\N	\N
19227	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	12	ANCIEN	\N	\N	\N	\N	13498	\N	\N
19228	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	13	ANCIEN	\N	\N	\N	\N	8710	\N	\N
19229	SECRETCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	14	ANCIEN	\N	\N	\N	\N	13483	\N	\N
19230	SECRETCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	15	ANCIEN	\N	\N	\N	\N	10162	\N	\N
19231	SECRETCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	16	ANCIEN	\N	\N	\N	\N	14390	\N	\N
19232	SECRETCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	17	ANCIEN	\N	\N	\N	\N	15983	\N	\N
19233	SECRETCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	18	ANCIEN	\N	\N	\N	\N	13494	\N	\N
19234	PDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	1	ANCIEN	\N	\N	\N	\N	10106	\N	\N
19235	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	2	ANCIEN	\N	\N	\N	\N	10208	\N	\N
19236	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	3	ANCIEN	\N	\N	\N	\N	10110	\N	\N
19237	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	4	ANCIEN	\N	\N	\N	\N	13389	\N	\N
19238	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	5	ANCIEN	\N	\N	\N	\N	13538	\N	\N
19239	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	6	ANCIEN	\N	\N	\N	\N	8747	\N	\N
19240	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	7	ANCIEN	\N	\N	\N	\N	13414	\N	\N
19241	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	8	ANCIEN	\N	\N	\N	\N	13382	\N	\N
19242	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	9	ANCIEN	\N	\N	\N	\N	16013	\N	\N
19243	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	10	ANCIEN	\N	\N	\N	\N	13383	\N	\N
19244	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	11	ANCIEN	\N	\N	\N	\N	10107	\N	\N
19245	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	12	ANCIEN	\N	\N	\N	\N	8701	\N	\N
19246	SECRETCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	13	ANCIEN	\N	\N	\N	\N	11276	\N	\N
19247	SECRETCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	14	ANCIEN	\N	\N	\N	\N	13422	\N	\N
19248	SECRETCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	15	ANCIEN	\N	\N	\N	\N	15201	\N	\N
19249	SECRETCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	16	ANCIEN	\N	\N	\N	\N	16054	\N	\N
19250	PDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	1	ANCIEN	\N	\N	\N	\N	13395	\N	\N
21498	MEMBRECOM	2023-07-06 00:00:00	2023-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17820	\N	\N
19252	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	3	ANCIEN	\N	\N	\N	\N	13376	\N	\N
19253	VICPDTCOM	2020-10-07 00:00:00	2021-10-12 00:00:00	4	ANCIEN	\N	\N	\N	\N	3789	\N	\N
19254	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	4	ANCIEN	\N	\N	\N	\N	13420	\N	\N
21499	MEMBRECOM	2023-07-06 00:00:00	2023-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17821	\N	\N
19256	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	7	ANCIEN	\N	\N	\N	\N	2560	\N	\N
19257	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	8	ANCIEN	\N	\N	\N	\N	16078	\N	\N
21500	MEMBRECOM	2023-07-06 00:00:00	2023-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17822	\N	\N
21501	MEMBRECOM	2023-07-06 00:00:00	2023-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17823	\N	\N
19260	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	11	ANCIEN	\N	\N	\N	\N	16005	\N	\N
19261	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	12	ANCIEN	\N	\N	\N	\N	16019	\N	\N
19262	SECRETCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	13	ANCIEN	\N	\N	\N	\N	13373	\N	\N
21502	MEMBRECOM	2023-07-06 00:00:00	2023-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17824	\N	\N
19264	SECRETCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	15	ANCIEN	\N	\N	\N	\N	10141	\N	\N
19265	SECRETCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	16	ANCIEN	\N	\N	\N	\N	13430	\N	\N
19266	PDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	1	ANCIEN	\N	\N	\N	\N	3944	\N	\N
19267	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12861	\N	\N
19268	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13447	\N	\N
19269	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13450	\N	\N
19270	VICPDTCOM	2020-10-07 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	412	\N	\N
19271	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16079	\N	\N
19272	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16075	\N	\N
19273	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2530	\N	\N
19274	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8126	\N	\N
19275	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14210	\N	\N
19276	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10202	\N	\N
19277	VICPDTCOM	2020-10-07 00:00:00	2022-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8156	\N	\N
19278	VICPDTCOM	2020-10-07 00:00:00	2022-10-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13484	\N	\N
21503	MEMBRECOM	2023-07-06 00:00:00	2023-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17825	\N	\N
21504	MEMBRECOM	2023-07-06 00:00:00	2023-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17826	\N	\N
21505	PDTCOM	2023-07-06 00:00:00	2023-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17827	\N	\N
21506	RAPCOM	2023-07-06 00:00:00	2023-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17828	\N	\N
21507	MEMBRECOM	2023-07-06 00:00:00	2023-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17829	\N	\N
21508	MEMBRECOM	2023-07-06 00:00:00	2023-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17830	\N	\N
21509	MEMBRECOM	2023-07-06 00:00:00	2023-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17831	\N	\N
21510	MEMBRECOM	2023-07-06 00:00:00	2023-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17832	\N	\N
21511	MEMBRECOM	2023-07-06 00:00:00	2023-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17833	\N	\N
18505	MEMBRECOM	2020-03-25 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15568	\N	\N
18659	MEMBRECOM	2020-06-29 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15696	\N	\N
21385	MEMBRECOM	2023-06-01 00:00:00	2023-06-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17707	\N	\N
21386	MEMBRECOM	2023-06-01 00:00:00	2023-06-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17708	\N	\N
21387	MEMBRECOM	2023-06-01 00:00:00	2023-06-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17709	\N	\N
21388	MEMBRECOM	2023-06-01 00:00:00	2023-06-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17710	\N	\N
21389	MEMBRECOM	2023-06-01 00:00:00	2023-06-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17711	\N	\N
21390	MEMBRECOM	2023-06-01 00:00:00	2023-06-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17712	\N	\N
21391	MEMBRECOM	2023-06-01 00:00:00	2023-06-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17713	\N	\N
21392	VICPDTCOM	2023-06-01 00:00:00	2023-06-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17714	\N	\N
21393	RAPCOM	2023-06-01 00:00:00	2023-06-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17715	\N	\N
21394	MEMBRECOM	2023-06-01 00:00:00	2023-06-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17716	\N	\N
21395	MEMBRECOM	2023-06-01 00:00:00	2023-06-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17717	\N	\N
21396	MEMBRECOM	2023-06-01 00:00:00	2023-06-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17718	\N	\N
21397	MEMBRECOM	2023-06-01 00:00:00	2023-06-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17719	\N	\N
21398	MEMBRECOM	2023-06-01 00:00:00	2023-06-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17720	\N	\N
21413	MEMBRECOM	2023-05-25 00:00:00	2023-05-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17735	\N	\N
21414	MEMBRECOM	2023-05-25 00:00:00	2023-05-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17736	\N	\N
21415	MEMBRECOM	2023-05-25 00:00:00	2023-05-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17737	\N	\N
21416	MEMBRECOM	2023-05-25 00:00:00	2023-05-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17738	\N	\N
21417	MEMBRECOM	2023-05-25 00:00:00	2023-05-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17739	\N	\N
21418	MEMBRECOM	2023-05-25 00:00:00	2023-05-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17740	\N	\N
21419	MEMBRECOM	2023-05-25 00:00:00	2023-05-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17741	\N	\N
21420	PDTCOM	2023-05-25 00:00:00	2023-05-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17742	\N	\N
21421	RAPCOM	2023-05-25 00:00:00	2023-05-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17743	\N	\N
21422	MEMBRECOM	2023-05-25 00:00:00	2023-05-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17744	\N	\N
21423	MEMBRECOM	2023-05-25 00:00:00	2023-05-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17745	\N	\N
21424	MEMBRECOM	2023-05-25 00:00:00	2023-05-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17746	\N	\N
21425	MEMBRECOM	2023-05-25 00:00:00	2023-05-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17747	\N	\N
21426	MEMBRECOM	2023-05-25 00:00:00	2023-05-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17748	\N	\N
21427	MEMBRECOM	2023-05-04 00:00:00	2023-05-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17749	\N	\N
21428	MEMBRECOM	2023-05-04 00:00:00	2023-05-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17750	\N	\N
21429	MEMBRECOM	2023-05-04 00:00:00	2023-05-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17751	\N	\N
21430	MEMBRECOM	2023-05-04 00:00:00	2023-05-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17752	\N	\N
21431	MEMBRECOM	2023-05-04 00:00:00	2023-05-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17753	\N	\N
21432	MEMBRECOM	2023-05-04 00:00:00	2023-05-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17754	\N	\N
21433	MEMBRECOM	2023-05-04 00:00:00	2023-05-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17755	\N	\N
21434	VICPDTCOM	2023-05-04 00:00:00	2023-05-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17756	\N	\N
21435	RAPCOM	2023-05-04 00:00:00	2023-05-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17757	\N	\N
21436	MEMBRECOM	2023-05-04 00:00:00	2023-05-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17758	\N	\N
21437	MEMBRECOM	2023-05-04 00:00:00	2023-05-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17759	\N	\N
21438	MEMBRECOM	2023-05-04 00:00:00	2023-05-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17760	\N	\N
21439	MEMBRECOM	2023-05-04 00:00:00	2023-05-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17761	\N	\N
21440	MEMBRECOM	2023-05-04 00:00:00	2023-05-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17762	\N	\N
21441	MEMBRECOM	2023-04-04 00:00:00	2023-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17763	\N	\N
21442	MEMBRECOM	2023-04-04 00:00:00	2023-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17764	\N	\N
21443	MEMBRECOM	2023-04-04 00:00:00	2023-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17765	\N	\N
21444	MEMBRECOM	2023-04-04 00:00:00	2023-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17766	\N	\N
21445	MEMBRECOM	2023-04-04 00:00:00	2023-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17767	\N	\N
21446	MEMBRECOM	2023-04-04 00:00:00	2023-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17768	\N	\N
21447	MEMBRECOM	2023-04-04 00:00:00	2023-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17769	\N	\N
21448	PDTCOM	2023-04-04 00:00:00	2023-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17770	\N	\N
21449	RAPCOM	2023-04-04 00:00:00	2023-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17771	\N	\N
21450	MEMBRECOM	2023-04-04 00:00:00	2023-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17772	\N	\N
21451	MEMBRECOM	2023-04-04 00:00:00	2023-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17773	\N	\N
21452	MEMBRECOM	2023-04-04 00:00:00	2023-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17774	\N	\N
21453	MEMBRECOM	2023-04-04 00:00:00	2023-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17775	\N	\N
21454	MEMBRECOM	2023-04-04 00:00:00	2023-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17776	\N	\N
21455	MEMBRECOM	2023-03-15 00:00:00	2023-03-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17777	\N	\N
21456	MEMBRECOM	2023-03-15 00:00:00	2023-03-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17778	\N	\N
21457	MEMBRECOM	2023-03-15 00:00:00	2023-03-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17779	\N	\N
21458	MEMBRECOM	2023-03-15 00:00:00	2023-03-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17780	\N	\N
21459	MEMBRECOM	2023-03-15 00:00:00	2023-03-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17781	\N	\N
21460	MEMBRECOM	2023-03-15 00:00:00	2023-03-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17782	\N	\N
21461	MEMBRECOM	2023-03-15 00:00:00	2023-03-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17783	\N	\N
21462	VICPDTCOM	2023-03-15 00:00:00	2023-03-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17784	\N	\N
21463	RAPCOM	2023-03-15 00:00:00	2023-03-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17785	\N	\N
21464	MEMBRECOM	2023-03-15 00:00:00	2023-03-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17786	\N	\N
21465	RAPCOM	2023-03-15 00:00:00	2023-03-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17787	\N	\N
21466	MEMBRECOM	2023-03-15 00:00:00	2023-03-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17788	\N	\N
21467	MEMBRECOM	2023-03-15 00:00:00	2023-03-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17789	\N	\N
21468	MEMBRECOM	2023-03-15 00:00:00	2023-03-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17790	\N	\N
21469	MEMBRECOM	2023-04-06 00:00:00	2023-04-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17791	\N	\N
21470	MEMBRECOM	2023-04-06 00:00:00	2023-04-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17792	\N	\N
21471	MEMBRECOM	2023-04-06 00:00:00	2023-04-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17793	\N	\N
21472	MEMBRECOM	2023-04-06 00:00:00	2023-04-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17794	\N	\N
21473	MEMBRECOM	2023-04-06 00:00:00	2023-04-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17795	\N	\N
21474	MEMBRECOM	2023-04-06 00:00:00	2023-04-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17796	\N	\N
21475	MEMBRECOM	2023-04-06 00:00:00	2023-04-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17797	\N	\N
21476	PDTCOM	2023-04-06 00:00:00	2023-04-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17798	\N	\N
21477	RAPCOM	2023-04-06 00:00:00	2023-04-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17799	\N	\N
21478	MEMBRECOM	2023-04-06 00:00:00	2023-04-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17800	\N	\N
21479	MEMBRECOM	2023-04-06 00:00:00	2023-04-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17801	\N	\N
21480	MEMBRECOM	2023-04-06 00:00:00	2023-04-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17802	\N	\N
21664	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17986	2023-09-24 00:00:00	\N
21482	MEMBRECOM	2023-04-06 00:00:00	2023-04-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17804	\N	\N
21483	MEMBRECOM	2023-04-06 00:00:00	2023-04-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17805	\N	\N
21665	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17987	2023-09-24 00:00:00	\N
21666	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17988	2023-09-24 00:00:00	\N
21677	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17999	2023-09-24 00:00:00	\N
21678	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18000	2023-09-24 00:00:00	\N
22408	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18681	\N	\N
22409	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	13531	\N	\N
22410	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18682	\N	\N
22411	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18683	\N	\N
22412	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18684	\N	\N
23107	MEMBRECOM	2024-01-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19219	\N	\N
22414	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18685	\N	\N
22415	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16139	\N	\N
23108	MEMBRECOM	2024-01-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19220	\N	\N
23109	MEMBRECOM	2024-01-17 00:00:00	2024-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19221	\N	\N
22418	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18687	\N	\N
22419	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	13535	\N	\N
22420	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18688	\N	\N
23110	MEMBRECOM	2024-01-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19222	\N	\N
23111	MEMBRECOM	2024-01-17 00:00:00	2024-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19223	\N	\N
23112	MEMBRECOM	2024-01-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19224	\N	\N
23113	MEMBRECOM	2024-01-17 00:00:00	2024-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19225	\N	\N
23114	MEMBRECOM	2024-01-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19226	\N	\N
23115	MEMBRECOM	2024-01-17 00:00:00	2024-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19227	\N	\N
23116	MEMBRECOM	2024-01-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19228	\N	\N
23117	MEMBRECOM	2024-01-17 00:00:00	2024-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19229	\N	\N
23118	MEMBRECOM	2024-01-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19230	\N	\N
23119	MEMBRECOM	2024-01-17 00:00:00	2024-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19231	\N	\N
23120	MEMBRECOM	2024-01-17 00:00:00	2024-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19232	\N	\N
23121	MEMBRECOM	2024-01-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19233	\N	\N
23122	MEMBRECOM	2024-01-17 00:00:00	2024-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19234	\N	\N
23123	MEMBRECOM	2024-01-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19235	\N	\N
23124	MEMBRECOM	2024-01-17 00:00:00	2024-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19236	\N	\N
23125	MEMBRECOM	2024-01-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19237	\N	\N
23126	MEMBRECOM	2024-01-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19238	\N	\N
23127	MEMBRECOM	2024-01-17 00:00:00	2024-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19239	\N	\N
23128	MEMBRECOM	2024-01-17 00:00:00	2024-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19240	\N	\N
23129	MEMBRECOM	2024-01-17 00:00:00	2024-01-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19241	\N	\N
18933	MEMBRECOM	2017-10-04 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15958	\N	\N
20663	MEMBRECOM	2022-01-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17170	\N	\N
18932	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15957	\N	\N
21512	MEMBRECOM	2023-03-09 00:00:00	2023-03-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17834	\N	\N
21513	MEMBRECOM	2023-03-09 00:00:00	2023-03-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17835	\N	\N
21514	MEMBRECOM	2023-03-09 00:00:00	2023-03-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17836	\N	\N
21515	MEMBRECOM	2023-03-09 00:00:00	2023-03-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17837	\N	\N
21516	MEMBRECOM	2023-03-09 00:00:00	2023-03-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17838	\N	\N
21518	MEMBRECOM	2023-03-09 00:00:00	2023-03-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17840	\N	\N
21519	VICPDTCOM	2023-03-09 00:00:00	2023-03-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17841	\N	\N
21520	RAPCOM	2023-03-09 00:00:00	2023-03-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17842	\N	\N
21521	MEMBRECOM	2023-03-09 00:00:00	2023-03-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17843	\N	\N
21522	MEMBRECOM	2023-03-09 00:00:00	2023-03-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17844	\N	\N
21523	MEMBRECOM	2023-03-09 00:00:00	2023-03-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17845	\N	\N
21524	MEMBRECOM	2023-03-09 00:00:00	2023-03-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17846	\N	\N
21525	MEMBRECOM	2023-03-09 00:00:00	2023-03-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17847	\N	\N
21526	MEMBRECOM	2023-02-09 00:00:00	2023-02-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17848	\N	\N
21527	MEMBRECOM	2023-02-09 00:00:00	2023-02-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17849	\N	\N
21528	MEMBRECOM	2023-02-09 00:00:00	2023-02-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17850	\N	\N
21529	MEMBRECOM	2023-02-09 00:00:00	2023-02-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17851	\N	\N
21530	MEMBRECOM	2023-02-09 00:00:00	2023-02-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17852	\N	\N
21531	MEMBRECOM	2023-02-09 00:00:00	2023-02-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17853	\N	\N
21532	MEMBRECOM	2023-02-09 00:00:00	2023-02-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17854	\N	\N
21533	PDTCOM	2023-02-09 00:00:00	2023-02-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17855	\N	\N
21534	RAPCOM	2023-02-09 00:00:00	2023-02-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17856	\N	\N
21535	MEMBRECOM	2023-02-09 00:00:00	2023-02-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17857	\N	\N
21536	MEMBRECOM	2023-02-09 00:00:00	2023-02-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17858	\N	\N
21537	MEMBRECOM	2023-02-09 00:00:00	2023-02-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17859	\N	\N
21538	MEMBRECOM	2023-02-09 00:00:00	2023-02-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17860	\N	\N
21539	MEMBRECOM	2023-02-09 00:00:00	2023-02-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17861	\N	\N
21540	MEMBRECOM	2023-01-24 00:00:00	2023-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17862	\N	\N
21541	MEMBRECOM	2023-01-24 00:00:00	2023-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17863	\N	\N
21542	MEMBRECOM	2023-01-24 00:00:00	2023-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17864	\N	\N
21543	VICPDTCOM	2023-01-24 00:00:00	2023-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17865	\N	\N
21544	MEMBRECOM	2023-01-24 00:00:00	2023-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17866	\N	\N
21545	MEMBRECOM	2023-01-24 00:00:00	2023-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17867	\N	\N
21546	MEMBRECOM	2023-01-24 00:00:00	2023-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17868	\N	\N
21547	RAPCOM	2023-01-24 00:00:00	2023-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17869	\N	\N
21548	RAPCOM	2023-01-24 00:00:00	2023-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17870	\N	\N
21549	MEMBRECOM	2023-01-24 00:00:00	2023-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17871	\N	\N
21550	MEMBRECOM	2023-01-24 00:00:00	2023-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17872	\N	\N
21551	MEMBRECOM	2023-01-24 00:00:00	2023-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17873	\N	\N
21552	MEMBRECOM	2023-01-24 00:00:00	2023-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17874	\N	\N
21553	MEMBRECOM	2023-01-24 00:00:00	2023-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17875	\N	\N
21554	MEMBRECOM	2022-12-15 00:00:00	2022-12-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17876	\N	\N
21555	MEMBRECOM	2022-12-15 00:00:00	2022-12-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17877	\N	\N
21556	MEMBRECOM	2022-12-15 00:00:00	2022-12-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17878	\N	\N
21557	MEMBRECOM	2022-12-15 00:00:00	2022-12-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17879	\N	\N
21558	MEMBRECOM	2022-12-15 00:00:00	2022-12-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17880	\N	\N
21559	MEMBRECOM	2022-12-15 00:00:00	2022-12-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17881	\N	\N
21560	MEMBRECOM	2022-12-15 00:00:00	2022-12-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17882	\N	\N
21561	PDTCOM	2022-12-15 00:00:00	2022-12-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17883	\N	\N
21562	RAPCOM	2022-12-15 00:00:00	2022-12-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17884	\N	\N
21564	MEMBRECOM	2022-12-15 00:00:00	2022-12-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17886	\N	\N
21566	MEMBRECOM	2022-12-15 00:00:00	2022-12-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17888	\N	\N
21567	MEMBRECOM	2022-12-15 00:00:00	2022-12-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17889	\N	\N
21569	MEMBRECOM	2022-12-06 00:00:00	2022-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17891	\N	\N
21570	MEMBRECOM	2022-12-06 00:00:00	2022-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17892	\N	\N
21571	MEMBRECOM	2022-12-06 00:00:00	2022-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17893	\N	\N
21572	MEMBRECOM	2022-12-06 00:00:00	2022-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17894	\N	\N
21573	MEMBRECOM	2022-12-06 00:00:00	2022-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17895	\N	\N
21574	MEMBRECOM	2022-12-06 00:00:00	2022-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17896	\N	\N
21575	VICPDTCOM	2022-12-06 00:00:00	2022-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17897	\N	\N
21576	RAPCOM	2022-12-06 00:00:00	2022-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17898	\N	\N
21578	MEMBRECOM	2022-12-06 00:00:00	2022-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17900	\N	\N
21579	MEMBRECOM	2022-12-06 00:00:00	2022-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17901	\N	\N
21580	MEMBRECOM	2022-12-06 00:00:00	2022-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17902	\N	\N
21581	MEMBRECOM	2022-12-06 00:00:00	2022-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17903	\N	\N
21583	MEMBRECOM	2022-12-01 00:00:00	2022-12-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17905	\N	\N
21584	MEMBRECOM	2022-12-01 00:00:00	2022-12-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17906	\N	\N
21585	MEMBRECOM	2022-12-01 00:00:00	2022-12-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17907	\N	\N
21586	MEMBRECOM	2022-12-01 00:00:00	2022-12-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17908	\N	\N
21587	MEMBRECOM	2022-12-01 00:00:00	2022-12-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17909	\N	\N
21588	MEMBRECOM	2022-12-01 00:00:00	2022-12-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17910	\N	\N
21589	PDTCOM	2022-12-01 00:00:00	2022-12-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17911	\N	\N
21591	RAPCOM	2022-12-01 00:00:00	2022-12-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17913	\N	\N
21592	MEMBRECOM	2022-12-01 00:00:00	2022-12-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17914	\N	\N
21593	MEMBRECOM	2022-12-01 00:00:00	2022-12-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17915	\N	\N
21594	MEMBRECOM	2022-12-01 00:00:00	2022-12-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17916	\N	\N
21595	MEMBRECOM	2022-12-01 00:00:00	2022-12-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17917	\N	\N
21596	MEMBRECOM	2022-11-22 00:00:00	2022-11-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17918	\N	\N
21597	MEMBRECOM	2022-11-22 00:00:00	2022-11-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17919	\N	\N
21598	MEMBRECOM	2022-11-22 00:00:00	2022-11-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17920	\N	\N
21599	MEMBRECOM	2022-11-22 00:00:00	2022-11-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17921	\N	\N
21600	MEMBRECOM	2022-11-22 00:00:00	2022-11-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17922	\N	\N
21601	MEMBRECOM	2022-11-22 00:00:00	2022-11-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17923	\N	\N
21602	MEMBRECOM	2022-11-22 00:00:00	2022-11-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17924	\N	\N
21603	PDTCOM	2022-11-22 00:00:00	2022-11-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17925	\N	\N
21604	RAPCOM	2022-11-22 00:00:00	2022-11-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17926	\N	\N
21605	MEMBRECOM	2022-11-22 00:00:00	2022-11-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17927	\N	\N
21606	MEMBRECOM	2022-11-22 00:00:00	2022-11-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17928	\N	\N
21607	MEMBRECOM	2022-11-22 00:00:00	2022-11-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17929	\N	\N
21608	MEMBRECOM	2022-11-22 00:00:00	2022-11-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17930	\N	\N
21609	MEMBRECOM	2022-11-22 00:00:00	2022-11-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17931	\N	\N
21610	MEMBRECOM	2022-11-09 00:00:00	2022-11-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17932	\N	\N
21611	MEMBRECOM	2022-11-09 00:00:00	2022-11-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17933	\N	\N
21612	MEMBRECOM	2022-11-09 00:00:00	2022-11-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17934	\N	\N
21613	MEMBRECOM	2022-11-09 00:00:00	2022-11-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17935	\N	\N
21615	MEMBRECOM	2022-11-09 00:00:00	2022-11-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17937	\N	\N
21616	MEMBRECOM	2022-11-09 00:00:00	2022-11-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17938	\N	\N
21617	PDTCOM	2022-11-09 00:00:00	2022-11-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17939	\N	\N
21618	RAPCOM	2022-11-09 00:00:00	2022-11-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17940	\N	\N
21619	RAPCOM	2022-11-09 00:00:00	2022-11-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17941	\N	\N
21620	RAPCOM	2022-11-09 00:00:00	2022-11-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17942	\N	\N
21621	MEMBRECOM	2022-11-09 00:00:00	2022-11-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17943	\N	\N
21622	MEMBRECOM	2022-11-09 00:00:00	2022-11-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17944	\N	\N
21623	MEMBRECOM	2022-11-09 00:00:00	2022-11-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17945	\N	\N
21624	MEMBRECOM	2022-11-15 00:00:00	2022-11-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17946	\N	\N
21625	MEMBRECOM	2022-11-15 00:00:00	2022-11-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17947	\N	\N
21626	MEMBRECOM	2022-11-15 00:00:00	2022-11-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17948	\N	\N
21627	MEMBRECOM	2022-11-15 00:00:00	2022-11-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17949	\N	\N
21628	MEMBRECOM	2022-11-15 00:00:00	2022-11-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17950	\N	\N
21629	MEMBRECOM	2022-11-15 00:00:00	2022-11-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17951	\N	\N
21630	MEMBRECOM	2022-11-15 00:00:00	2022-11-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17952	\N	\N
21631	VICPDTCOM	2022-11-15 00:00:00	2022-11-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17953	\N	\N
21632	RAPCOM	2022-11-15 00:00:00	2022-11-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17954	\N	\N
21633	MEMBRECOM	2022-11-15 00:00:00	2022-11-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17955	\N	\N
21634	MEMBRECOM	2022-11-15 00:00:00	2022-11-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17956	\N	\N
21635	MEMBRECOM	2022-11-15 00:00:00	2022-11-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17957	\N	\N
21636	MEMBRECOM	2022-11-15 00:00:00	2022-11-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17958	\N	\N
21637	MEMBRECOM	2022-11-15 00:00:00	2022-11-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17959	\N	\N
21845	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18165	2023-10-03 00:00:00	\N
21846	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18166	2023-10-03 00:00:00	\N
21847	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18167	2023-10-03 00:00:00	\N
21848	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18168	2023-10-03 00:00:00	\N
21849	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18169	2023-10-03 00:00:00	\N
21850	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18170	2023-10-03 00:00:00	\N
21851	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18171	2023-10-03 00:00:00	\N
21852	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18172	2023-10-03 00:00:00	\N
21853	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18173	2023-10-03 00:00:00	\N
21854	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18174	2023-10-03 00:00:00	\N
21855	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18175	2023-10-03 00:00:00	\N
21856	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18176	2023-10-03 00:00:00	\N
21857	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18177	2023-10-03 00:00:00	\N
21858	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18178	2023-10-03 00:00:00	\N
21859	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18179	2023-10-03 00:00:00	\N
21860	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18180	2023-10-03 00:00:00	\N
21861	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18181	2023-10-03 00:00:00	\N
21862	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18182	2023-10-03 00:00:00	\N
18019	MEMBRECOM	2019-07-17 00:00:00	2019-07-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15141	\N	\N
18020	MEMBRECOM	2019-07-17 00:00:00	2019-07-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15142	\N	\N
18021	MEMBRECOM	2019-07-17 00:00:00	2019-07-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15143	\N	\N
18022	MEMBRECOM	2019-07-17 00:00:00	2019-07-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15144	\N	\N
18023	MEMBRECOM	2019-07-17 00:00:00	2019-07-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15145	\N	\N
18024	MEMBRECOM	2019-07-17 00:00:00	2019-07-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15146	\N	\N
18025	MEMBRECOM	2019-07-17 00:00:00	2019-07-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15147	\N	\N
18026	MEMBRECOM	2019-07-17 00:00:00	2019-07-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15148	\N	\N
18027	MEMBRECOM	2019-07-17 00:00:00	2019-07-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15149	\N	\N
18028	MEMBRECOM	2019-07-17 00:00:00	2019-07-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15150	\N	\N
18029	MEMBRECOM	2019-07-17 00:00:00	2019-07-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15151	\N	\N
18030	MEMBRECOM	2019-07-17 00:00:00	2019-07-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15152	\N	\N
18031	MEMBRECOM	2019-07-17 00:00:00	2019-07-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15153	\N	\N
18032	MEMBRECOM	2019-07-17 00:00:00	2019-07-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15154	\N	\N
18033	MEMBRECOM	2019-07-17 00:00:00	2019-07-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15155	\N	\N
18034	MEMBRECOM	2019-07-17 00:00:00	2019-07-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15156	\N	\N
18035	MEMBRECOM	2019-07-17 00:00:00	2019-07-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15157	\N	\N
18036	MEMBRECOM	2019-07-17 00:00:00	2019-07-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15158	\N	\N
18037	MEMBRECOM	2019-07-17 00:00:00	2019-07-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15159	\N	\N
18038	MEMBRECOM	2019-07-17 00:00:00	2019-07-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15160	\N	\N
18039	MEMBRECOM	2019-07-17 00:00:00	2019-07-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15161	\N	\N
18040	MEMBRECOM	2019-07-17 00:00:00	2019-07-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15162	\N	\N
18041	MEMBRECOM	2019-07-17 00:00:00	2019-07-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15163	\N	\N
18042	MEMBRECOM	2019-07-17 00:00:00	2019-07-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15164	\N	\N
18043	MEMBRECOM	2019-07-17 00:00:00	2019-07-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15165	\N	\N
18044	MEMBRECOM	2019-07-17 00:00:00	2019-07-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15166	\N	\N
18045	MEMBRECOM	2019-07-17 00:00:00	2019-07-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15167	\N	\N
18046	MEMBRECOM	2019-07-17 00:00:00	2019-07-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15168	\N	\N
19553	MEMBRECOM	2020-12-01 00:00:00	2021-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16216	\N	\N
19554	MEMBRECOM	2020-12-01 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16217	\N	\N
19555	MEMBRECOM	2020-12-01 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16218	\N	\N
19630	MEMBRECOM	2020-12-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16292	\N	\N
20402	MEMBRECOM	2021-07-28 00:00:00	2021-09-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16952	\N	\N
20441	MEMBRECOM	2021-10-13 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16991	\N	\N
20442	MEMBRECOM	2021-10-13 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16992	\N	\N
20443	MEMBRECOM	2021-10-13 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16993	\N	\N
20444	MEMBRECOM	2021-10-13 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16994	\N	\N
21662	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17984	2023-09-24 00:00:00	\N
21663	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17985	2023-09-24 00:00:00	\N
21815	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18137	2023-09-24 00:00:00	\N
21816	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18138	2023-09-24 00:00:00	\N
21817	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18139	2023-09-24 00:00:00	\N
21818	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18140	2023-09-24 00:00:00	\N
21819	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18141	2023-09-24 00:00:00	\N
21820	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18142	2023-09-24 00:00:00	\N
21821	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18143	2023-09-24 00:00:00	\N
19184	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2607	\N	\N
19631	MEMBRECOM	2021-01-12 00:00:00	2021-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16293	\N	\N
20511	MEMBRECOM	2021-11-18 00:00:00	2022-06-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17056	\N	\N
20512	MEMBRECOM	2021-11-18 00:00:00	2022-06-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17057	\N	\N
21863	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18183	2023-10-03 00:00:00	\N
21864	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18184	2023-10-03 00:00:00	\N
21865	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18185	2023-10-03 00:00:00	\N
21866	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18186	2023-10-03 00:00:00	\N
21867	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18187	2023-10-03 00:00:00	\N
21868	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18188	2023-10-03 00:00:00	\N
21869	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18189	2023-10-03 00:00:00	\N
21870	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18190	2023-10-03 00:00:00	\N
21871	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18191	2023-10-03 00:00:00	\N
21872	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18192	2023-10-03 00:00:00	\N
21873	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18193	2023-10-03 00:00:00	\N
21874	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18194	2023-10-03 00:00:00	\N
21875	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18195	2023-10-03 00:00:00	\N
21876	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18196	2023-10-03 00:00:00	\N
21877	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18197	2023-10-03 00:00:00	\N
21878	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18198	2023-10-03 00:00:00	\N
21879	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18199	2023-10-03 00:00:00	\N
21880	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18200	2023-10-03 00:00:00	\N
21881	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18201	2023-10-03 00:00:00	\N
21882	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18202	2023-10-03 00:00:00	\N
21883	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18203	2023-10-03 00:00:00	\N
21884	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18204	2023-10-03 00:00:00	\N
21885	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18205	2023-10-03 00:00:00	\N
21886	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18206	2023-10-03 00:00:00	\N
21887	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18207	2023-10-03 00:00:00	\N
21888	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18208	2023-10-03 00:00:00	\N
21889	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18209	2023-10-03 00:00:00	\N
21890	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18210	2023-10-03 00:00:00	\N
21891	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18211	2023-10-03 00:00:00	\N
21892	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18212	2023-10-03 00:00:00	\N
21916	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18236	2023-10-03 00:00:00	\N
21917	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18237	2023-10-03 00:00:00	\N
21918	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18238	2023-10-03 00:00:00	\N
21919	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18239	2023-10-03 00:00:00	\N
21920	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18240	2023-10-03 00:00:00	\N
21921	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18241	2023-10-03 00:00:00	\N
21922	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18242	2023-10-03 00:00:00	\N
21923	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18243	2023-10-03 00:00:00	\N
21924	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18244	2023-10-03 00:00:00	\N
21925	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18245	2023-10-03 00:00:00	\N
21926	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18246	2023-10-03 00:00:00	\N
21927	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18247	2023-10-03 00:00:00	\N
21928	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18248	2023-10-03 00:00:00	\N
21929	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18249	2023-10-03 00:00:00	\N
21930	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18250	2023-10-03 00:00:00	\N
21931	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18251	2023-10-03 00:00:00	\N
21932	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18252	2023-10-03 00:00:00	\N
21933	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18253	2023-10-03 00:00:00	\N
21934	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18254	2023-10-03 00:00:00	\N
21935	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18255	2023-10-03 00:00:00	\N
21936	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18256	2023-10-03 00:00:00	\N
21964	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18284	2023-10-03 00:00:00	\N
21965	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18285	2023-10-03 00:00:00	\N
21966	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18286	2023-10-03 00:00:00	\N
21967	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18287	2023-10-03 00:00:00	\N
21968	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18288	2023-10-03 00:00:00	\N
21969	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18289	2023-10-03 00:00:00	\N
21970	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18290	2023-10-03 00:00:00	\N
21971	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18291	2023-10-03 00:00:00	\N
21972	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18292	2023-10-03 00:00:00	\N
21973	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18293	2023-10-03 00:00:00	\N
21974	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18294	2023-10-03 00:00:00	\N
21975	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18295	2023-10-03 00:00:00	\N
21976	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18296	2023-10-03 00:00:00	\N
21977	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18297	2023-10-03 00:00:00	\N
21978	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18298	2023-10-03 00:00:00	\N
21979	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18299	2023-10-03 00:00:00	\N
21980	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18300	2023-10-03 00:00:00	\N
21981	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18301	2023-10-03 00:00:00	\N
21982	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18302	2023-10-03 00:00:00	\N
21983	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18303	2023-10-03 00:00:00	\N
21984	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18304	2023-10-03 00:00:00	\N
12052	MEMBRECOM	2014-10-08 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10220	2014-10-08 00:00:00	\N
21985	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18305	2023-10-03 00:00:00	\N
22033	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18353	\N	\N
22034	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18354	\N	\N
22035	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18355	\N	\N
22060	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18380	\N	\N
22061	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18381	\N	\N
22071	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18391	\N	\N
22072	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18392	\N	\N
22073	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18393	\N	\N
22074	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18394	\N	\N
22075	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18395	\N	\N
22076	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18396	\N	\N
22077	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18397	\N	\N
22078	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18398	\N	\N
22079	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18399	\N	\N
22090	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18410	\N	\N
22091	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18411	\N	\N
22092	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18412	\N	\N
22093	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18413	\N	\N
22094	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18414	\N	\N
22095	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18415	\N	\N
22096	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18416	\N	\N
22097	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18417	\N	\N
22098	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18418	\N	\N
22115	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18435	\N	\N
22116	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18436	\N	\N
22117	MEMBRECOM	2023-10-04 00:00:00	2023-10-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18437	\N	\N
22118	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18438	\N	\N
22119	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18439	\N	\N
22120	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18440	\N	\N
22121	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18441	\N	\N
22122	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18442	\N	\N
22131	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18451	\N	\N
22132	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18452	\N	\N
22133	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18453	\N	\N
22134	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18454	\N	\N
22135	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18455	\N	\N
22136	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18456	\N	\N
22137	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18457	\N	\N
22398	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18671	\N	\N
22399	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18672	\N	\N
22429	VICPDTCOM	2023-10-05 00:00:00	\N	7	ACTIF	\N	\N	\N	\N	18531	\N	\N
21517	MEMBRECOM	2023-03-09 00:00:00	2023-03-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17839	\N	\N
22422	PDTCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18508	\N	\N
22427	VICPDTCOM	2023-10-05 00:00:00	\N	5	ACTIF	\N	\N	\N	\N	18420	\N	\N
22573	PDTCOM	2023-10-05 00:00:00	\N	1	ACTIF	\N	\N	\N	\N	18499	\N	\N
22574	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18435	\N	\N
21563	MEMBRECOM	2022-12-15 00:00:00	2022-12-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17885	\N	\N
18262	MEMBRECOM	2019-12-06 00:00:00	2019-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15342	\N	\N
18263	MEMBRECOM	2019-12-06 00:00:00	2019-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15343	\N	\N
18264	MEMBRECOM	2019-12-06 00:00:00	2019-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15344	\N	\N
18265	MEMBRECOM	2019-12-06 00:00:00	2019-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15345	\N	\N
18266	MEMBRECOM	2019-12-06 00:00:00	2019-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15346	\N	\N
18267	MEMBRECOM	2019-12-06 00:00:00	2019-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15347	\N	\N
18268	MEMBRECOM	2019-12-06 00:00:00	2019-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15348	\N	\N
18269	MEMBRECOM	2019-12-06 00:00:00	2019-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15349	\N	\N
18270	MEMBRECOM	2019-12-06 00:00:00	2019-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15350	\N	\N
18271	MEMBRECOM	2019-12-06 00:00:00	2019-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15351	\N	\N
18272	MEMBRECOM	2019-12-06 00:00:00	2019-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15352	\N	\N
18273	MEMBRECOM	2019-12-06 00:00:00	2019-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15353	\N	\N
18274	MEMBRECOM	2019-12-06 00:00:00	2019-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15354	\N	\N
18275	MEMBRECOM	2019-12-06 00:00:00	2019-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15355	\N	\N
18850	MEMBRECOM	2020-08-13 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15876	\N	\N
18854	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15879	\N	\N
11932	MEMBRECOM	2014-10-08 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10100	2014-10-08 16:49:11	\N
18856	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15881	\N	\N
18857	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15882	\N	\N
18858	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15883	\N	\N
19546	MEMBRECOM	2020-11-02 00:00:00	2020-11-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16209	\N	\N
19551	MEMBRECOM	2020-11-26 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16214	\N	\N
21241	RAPCOM	2023-06-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17547	\N	\N
21242	PDTCOM	2023-06-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17563	\N	\N
21243	RAPCOM	2023-06-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17560	\N	\N
21244	SECRETCOM	2023-06-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17566	\N	\N
21245	SECRETCOM	2023-06-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17543	\N	\N
21246	SECRETCOM	2023-06-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17562	\N	\N
21247	VICPDTCOM	2023-06-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17564	\N	\N
21248	VICPDTCOM	2023-06-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17544	\N	\N
21249	VICPDTCOM	2023-06-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17545	\N	\N
21250	VICPDTCOM	2023-06-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17550	\N	\N
21251	VICPDTCOM	2023-06-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17571	\N	\N
21252	VICPDTCOM	2023-06-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17551	\N	\N
21253	VICPDTCOM	2023-06-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17577	\N	\N
21254	VICPDTCOM	2023-06-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17574	\N	\N
21255	VICPDTCOM	2023-06-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17569	\N	\N
21256	VICPDTCOM	2023-06-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17578	\N	\N
21257	VICPDTCOM	2023-06-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17579	\N	\N
21827	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18149	2023-09-25 00:00:00	\N
21828	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18150	2023-09-25 00:00:00	\N
22556	VICPDTCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18593	\N	\N
22557	SECRETCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18567	\N	\N
22558	VICPDTCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18566	\N	\N
22559	SECRETCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18561	\N	\N
22560	VICPDTCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18560	\N	\N
22561	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18556	\N	\N
22562	VICPDTCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18554	\N	\N
22563	SECRETCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18456	\N	\N
22564	PDTCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18452	\N	\N
22565	VICPDTCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18415	\N	\N
22566	VICPDTCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18411	\N	\N
22567	SECRETCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18410	\N	\N
22568	VICPDTCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18380	\N	\N
22569	VICPDTCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18674	\N	\N
22570	VICPDTCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18596	\N	\N
22571	VICPDTCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18357	\N	\N
19147	PDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	1	ANCIEN	\N	\N	\N	\N	10126	\N	\N
19148	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8019	\N	\N
19149	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13439	\N	\N
19150	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11501	\N	\N
19151	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10123	\N	\N
19152	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3633	\N	\N
19153	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13452	\N	\N
19154	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8191	\N	\N
19155	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4318	\N	\N
19156	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13457	\N	\N
19157	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10152	\N	\N
19158	VICPDTCOM	2020-10-07 00:00:00	2022-07-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13461	\N	\N
19159	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13462	\N	\N
19160	RAPGENCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10218	\N	\N
19161	SECRETCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13831	\N	\N
19162	SECRETCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13441	\N	\N
19163	SECRETCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10219	\N	\N
19164	SECRETCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16028	\N	\N
19165	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	2	ANCIEN	\N	\N	\N	\N	10166	\N	\N
19166	PDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	1	ANCIEN	\N	\N	\N	\N	2607	\N	\N
19167	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	3	ANCIEN	\N	\N	\N	\N	13402	\N	\N
20338	PDTCOM	2021-06-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16892	\N	\N
19169	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	5	ANCIEN	\N	\N	\N	\N	13411	\N	\N
19170	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	6	ANCIEN	\N	\N	\N	\N	13396	\N	\N
19171	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	7	ANCIEN	\N	\N	\N	\N	13079	\N	\N
19172	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	8	ANCIEN	\N	\N	\N	\N	15975	\N	\N
19173	VICPDTCOM	2020-10-07 00:00:00	2022-11-08 00:00:00	9	ANCIEN	\N	\N	\N	\N	8094	\N	\N
23340	MEMBRECOM	2024-02-15 00:00:00	2024-02-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19404	\N	\N
19174	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	10	ANCIEN	\N	\N	\N	\N	16010	\N	\N
19175	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	11	ANCIEN	\N	\N	\N	\N	13384	\N	\N
19176	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	12	ANCIEN	\N	\N	\N	\N	10168	\N	\N
19177	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	13	ANCIEN	\N	\N	\N	\N	16016	\N	\N
19178	SECRETCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	14	ANCIEN	\N	\N	\N	\N	7751	\N	\N
19179	SECRETCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	15	ANCIEN	\N	\N	\N	\N	13424	\N	\N
19180	SECRETCOM	2020-10-07 00:00:00	2021-09-30 00:00:00	16	ANCIEN	\N	\N	\N	\N	10165	\N	\N
11997	MEMBRECOM	2014-10-08 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10165	2014-10-08 17:18:26	\N
19181	SECRETCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	17	ANCIEN	\N	\N	\N	\N	13381	\N	\N
19185	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10166	\N	\N
20339	RAPCOM	2021-06-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16911	\N	\N
20340	VICPDTCOM	2021-06-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16909	\N	\N
20341	VICPDTCOM	2021-06-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16904	\N	\N
20342	VICPDTCOM	2021-06-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16905	\N	\N
20343	VICPDTCOM	2021-06-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16895	\N	\N
20344	VICPDTCOM	2021-06-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16902	\N	\N
20345	VICPDTCOM	2021-06-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16891	\N	\N
20346	VICPDTCOM	2021-06-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16896	\N	\N
20347	VICPDTCOM	2021-06-22 00:00:00	2022-07-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16912	\N	\N
20348	SECRETCOM	2021-06-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16894	\N	\N
20349	SECRETCOM	2021-06-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16913	\N	\N
22515	SECRETCOM	2023-10-05 00:00:00	\N	14	ACTIF	\N	\N	\N	\N	18734	\N	\N
22516	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18735	\N	\N
22517	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18736	\N	\N
22518	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18737	\N	\N
22519	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18738	\N	\N
22520	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18739	\N	\N
22521	SECRETCOM	2023-10-05 00:00:00	\N	17	ACTIF	\N	\N	\N	\N	18740	\N	\N
22575	SECRETCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18549	\N	\N
22523	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18742	\N	\N
22524	SECRETCOM	2023-10-05 00:00:00	\N	15	ACTIF	\N	\N	\N	\N	18743	\N	\N
22525	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18744	\N	\N
22526	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18745	\N	\N
22576	PDTCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18547	\N	\N
22528	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18747	\N	\N
22529	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18748	\N	\N
22530	VICPDTCOM	2023-10-05 00:00:00	\N	5	ACTIF	\N	\N	\N	\N	18749	\N	\N
22531	VICPDTCOM	2023-10-05 00:00:00	\N	7	ACTIF	\N	\N	\N	\N	18750	\N	\N
22577	VICPDTCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18546	\N	\N
22533	VICPDTCOM	2023-10-05 00:00:00	\N	13	ACTIF	\N	\N	\N	\N	18752	\N	\N
22534	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18753	\N	\N
22535	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18754	\N	\N
22536	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18755	\N	\N
22537	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18756	\N	\N
22538	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18757	\N	\N
22539	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18758	\N	\N
22540	VICPDTCOM	2023-10-05 00:00:00	\N	6	ACTIF	\N	\N	\N	\N	18759	\N	\N
22541	VICPDTCOM	2023-10-05 00:00:00	\N	8	ACTIF	\N	\N	\N	\N	18760	\N	\N
22542	VICPDTCOM	2023-10-05 00:00:00	\N	12	ACTIF	\N	\N	\N	\N	18761	\N	\N
22543	VICPDTCOM	2023-10-05 00:00:00	\N	9	ACTIF	\N	\N	\N	\N	18762	\N	\N
22578	SECRETCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18543	\N	\N
22545	VICPDTCOM	2023-10-05 00:00:00	\N	3	ACTIF	\N	\N	\N	\N	18764	\N	\N
22546	PDTCOM	2023-10-05 00:00:00	\N	1	ACTIF	\N	\N	\N	\N	18765	\N	\N
22579	VICPDTCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18537	\N	\N
22548	VICPDTCOM	2023-10-05 00:00:00	\N	4	ACTIF	\N	\N	\N	\N	18767	\N	\N
22549	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18768	\N	\N
22580	VICPDTCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18532	\N	\N
22551	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18770	\N	\N
22552	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18771	\N	\N
22553	VICPDTCOM	2023-10-05 00:00:00	\N	11	ACTIF	\N	\N	\N	\N	18772	\N	\N
21614	MEMBRECOM	2022-11-09 00:00:00	2022-11-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17936	\N	\N
22555	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18774	\N	\N
22581	VICPDTCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18444	\N	\N
22582	SECRETCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18443	\N	\N
22583	SECRETCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18390	\N	\N
22584	VICPDTCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18388	\N	\N
22585	VICPDTCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18383	\N	\N
22586	VICPDTCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18335	\N	\N
22587	VICPDTCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18353	\N	\N
22588	VICPDTCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18591	\N	\N
22589	VICPDTCOM	2023-10-05 00:00:00	2024-03-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18615	\N	\N
22590	VICPDTCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18606	\N	\N
23130	RAPCOM	2024-01-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19120	\N	\N
23131	PDTCOM	2024-01-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19105	\N	\N
23132	VICPDTCOM	2024-01-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19118	\N	\N
23133	VICPDTCOM	2024-01-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19116	\N	\N
23134	VICPDTCOM	2024-01-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19103	\N	\N
23135	VICPDTCOM	2024-01-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19110	\N	\N
23136	VICPDTCOM	2024-01-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19111	\N	\N
23137	VICPDTCOM	2024-01-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19117	\N	\N
23138	VICPDTCOM	2024-01-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19119	\N	\N
23139	VICPDTCOM	2024-01-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19108	\N	\N
23140	VICPDTCOM	2024-01-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19113	\N	\N
23141	VICPDTCOM	2024-01-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19115	\N	\N
23337	PDTCOM	2024-02-15 00:00:00	2024-02-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19401	\N	\N
23338	RAPCOM	2024-02-15 00:00:00	2024-02-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19402	\N	\N
23339	MEMBRECOM	2024-02-15 00:00:00	2024-02-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19403	\N	\N
23341	MEMBRECOM	2024-02-15 00:00:00	2024-02-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19405	\N	\N
23342	MEMBRECOM	2024-02-15 00:00:00	2024-02-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19406	\N	\N
23343	MEMBRECOM	2024-02-15 00:00:00	2024-02-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19407	\N	\N
23344	MEMBRECOM	2024-02-15 00:00:00	2024-02-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19408	\N	\N
23345	MEMBRECOM	2024-02-15 00:00:00	2024-02-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19409	\N	\N
23346	MEMBRECOM	2024-02-15 00:00:00	2024-02-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19410	\N	\N
23347	MEMBRECOM	2024-02-15 00:00:00	2024-02-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19411	\N	\N
23348	MEMBRECOM	2024-02-15 00:00:00	2024-02-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19412	\N	\N
23349	MEMBRECOM	2024-02-15 00:00:00	2024-02-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19413	\N	\N
23350	MEMBRECOM	2024-02-15 00:00:00	2024-02-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19414	\N	\N
23351	MEMBRECOM	2024-02-27 00:00:00	2024-02-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19415	\N	\N
23352	MEMBRECOM	2024-02-27 00:00:00	2024-02-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19416	\N	\N
23353	MEMBRECOM	2024-02-27 00:00:00	2024-02-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19417	\N	\N
23354	MEMBRECOM	2024-02-27 00:00:00	2024-02-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19418	\N	\N
23355	MEMBRECOM	2024-02-27 00:00:00	2024-02-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19419	\N	\N
23356	MEMBRECOM	2024-02-27 00:00:00	2024-02-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19420	\N	\N
23357	MEMBRECOM	2024-02-27 00:00:00	2024-02-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19421	\N	\N
23358	VICPDTCOM	2024-02-27 00:00:00	2024-02-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19422	\N	\N
23359	RAPCOM	2024-02-27 00:00:00	2024-02-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19423	\N	\N
23360	MEMBRECOM	2024-02-27 00:00:00	2024-02-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19424	\N	\N
23361	MEMBRECOM	2024-02-27 00:00:00	2024-02-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19425	\N	\N
23362	MEMBRECOM	2024-02-27 00:00:00	2024-02-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19426	\N	\N
23363	MEMBRECOM	2024-02-27 00:00:00	2024-02-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19427	\N	\N
23364	MEMBRECOM	2024-02-27 00:00:00	2024-02-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19428	\N	\N
18080	MEMBRECOM	2019-10-01 00:00:00	2019-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15200	\N	\N
19279	PDTCOM	2020-10-07 00:00:00	2021-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15217	\N	\N
19280	VICPDTCOM	2020-10-07 00:00:00	2021-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15203	\N	\N
19281	VICPDTCOM	2020-10-07 00:00:00	2021-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15233	\N	\N
19282	VICPDTCOM	2020-10-07 00:00:00	2021-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15207	\N	\N
19283	SECRETCOM	2020-10-07 00:00:00	2021-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15205	\N	\N
19284	VICPDTCOM	2020-10-07 00:00:00	2021-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15219	\N	\N
19285	VICPDTCOM	2020-10-07 00:00:00	2021-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15229	\N	\N
19286	VICPDTCOM	2020-10-07 00:00:00	2021-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15235	\N	\N
19287	VICPDTCOM	2020-10-07 00:00:00	2021-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15215	\N	\N
19288	VICPDTCOM	2020-10-07 00:00:00	2021-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15226	\N	\N
19289	SECRETCOM	2020-10-07 00:00:00	2021-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15240	\N	\N
19290	VICPDTCOM	2020-10-07 00:00:00	2021-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15223	\N	\N
19291	RAPCOM	2020-10-07 00:00:00	2021-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15237	\N	\N
19292	RAPCOM	2020-10-07 00:00:00	2021-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15211	\N	\N
19293	RAPCOM	2020-10-07 00:00:00	2021-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15225	\N	\N
19294	RAPCOM	2020-10-07 00:00:00	2021-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15212	\N	\N
19295	MEMBRECOM	2020-10-07 00:00:00	2020-10-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16085	\N	\N
19296	MEMBRECOM	2020-10-07 00:00:00	2021-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16086	\N	\N
19297	MEMBRECOM	2020-10-07 00:00:00	2021-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16087	\N	\N
19298	SECRETCOM	2020-10-07 00:00:00	2021-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16088	\N	\N
19299	MEMBRECOM	2020-10-07 00:00:00	2021-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16089	\N	\N
19300	MEMBRECOM	2020-10-07 00:00:00	2021-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16090	\N	\N
19301	VICPDTCOM	2020-10-07 00:00:00	2021-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16091	\N	\N
19302	PDTCOM	2020-10-07 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15475	\N	\N
19303	VICPDTCOM	2020-10-07 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15464	\N	\N
19304	VICPDTCOM	2020-10-07 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15478	\N	\N
19305	VICPDTCOM	2020-10-07 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15462	\N	\N
19306	VICPDTCOM	2020-10-07 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15480	\N	\N
19307	VICPDTCOM	2020-10-07 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15483	\N	\N
19308	VICPDTCOM	2020-10-07 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15460	\N	\N
19309	VICPDTCOM	2020-10-07 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15494	\N	\N
19310	SECRETCOM	2020-10-07 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15476	\N	\N
19311	SECRETCOM	2020-10-07 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15470	\N	\N
19312	SECRETCOM	2020-10-07 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15487	\N	\N
19313	VICPDTCOM	2020-10-07 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15471	\N	\N
19314	VICPDTCOM	2020-10-07 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16092	\N	\N
19315	MEMBRECOM	2020-10-07 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16093	\N	\N
19316	MEMBRECOM	2020-10-07 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16094	\N	\N
19317	MEMBRECOM	2020-10-07 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16095	\N	\N
19318	MEMBRECOM	2020-10-07 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16096	\N	\N
19319	RAPCOM	2020-10-07 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16097	\N	\N
19320	MEMBRECOM	2020-10-07 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16098	\N	\N
19321	MEMBRECOM	2020-10-07 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16099	\N	\N
19322	PDTCOM	2020-10-07 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15737	\N	\N
19323	VICPDTCOM	2020-10-07 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15759	\N	\N
19324	VICPDTCOM	2020-10-07 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15762	\N	\N
19325	VICPDTCOM	2020-10-07 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15755	\N	\N
19326	VICPDTCOM	2020-10-07 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15741	\N	\N
19327	RAPCOM	2020-10-07 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15731	\N	\N
19328	VICPDTCOM	2020-10-07 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15757	\N	\N
19329	VICPDTCOM	2020-10-07 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15754	\N	\N
19330	RAPCOM	2020-10-07 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15752	\N	\N
19331	RAPCOM	2020-10-07 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15745	\N	\N
19332	MEMBRECOM	2020-10-07 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16100	\N	\N
19333	VICPDTCOM	2020-10-07 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16101	\N	\N
19334	MEMBRECOM	2020-10-07 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16102	\N	\N
19760	PDTCOM	2021-02-16 00:00:00	2021-09-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16349	\N	\N
19761	RAPCOM	2021-02-16 00:00:00	2021-09-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16352	\N	\N
19762	VICPDTCOM	2021-02-16 00:00:00	2021-09-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16342	\N	\N
19763	VICPDTCOM	2021-02-16 00:00:00	2021-09-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16351	\N	\N
19764	VICPDTCOM	2021-02-16 00:00:00	2021-09-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16338	\N	\N
19765	VICPDTCOM	2021-02-16 00:00:00	2021-09-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16355	\N	\N
19766	VICPDTCOM	2021-02-16 00:00:00	2021-09-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16357	\N	\N
19767	VICPDTCOM	2021-02-16 00:00:00	2021-09-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16356	\N	\N
19768	VICPDTCOM	2021-02-16 00:00:00	2021-09-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16358	\N	\N
19769	VICPDTCOM	2021-02-16 00:00:00	2021-09-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16359	\N	\N
19770	SECRETCOM	2021-02-16 00:00:00	2021-09-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16343	\N	\N
19771	SECRETCOM	2021-02-16 00:00:00	2021-09-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16347	\N	\N
19844	VICPDTCOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16444	\N	\N
19845	RAPCOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16445	\N	\N
19846	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16446	\N	\N
19847	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16447	\N	\N
19848	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16448	\N	\N
19849	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16449	\N	\N
19850	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16450	\N	\N
19851	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16451	\N	\N
19852	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16452	\N	\N
19853	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16453	\N	\N
19854	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16454	\N	\N
19855	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16455	\N	\N
19856	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16456	\N	\N
19857	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16457	\N	\N
19860	RAPCOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16460	\N	\N
19859	PDTCOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16459	\N	\N
19861	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16461	\N	\N
19862	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16462	\N	\N
19863	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16463	\N	\N
19864	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16464	\N	\N
19865	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16465	\N	\N
19866	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16466	\N	\N
19867	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16467	\N	\N
19868	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16468	\N	\N
19869	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16469	\N	\N
19870	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16470	\N	\N
19871	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16471	\N	\N
19872	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16472	\N	\N
19873	PDTCOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16473	\N	\N
19874	RAPCOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16474	\N	\N
19875	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16475	\N	\N
19876	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16476	\N	\N
19877	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16477	\N	\N
19878	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16478	\N	\N
19879	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16479	\N	\N
19880	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16480	\N	\N
19881	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16481	\N	\N
19882	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16482	\N	\N
19883	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16483	\N	\N
19884	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16484	\N	\N
19885	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16485	\N	\N
19886	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16486	\N	\N
19887	VICPDTCOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16487	\N	\N
19888	RAPCOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16488	\N	\N
19889	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16489	\N	\N
19890	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16490	\N	\N
19891	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16491	\N	\N
19892	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16492	\N	\N
19893	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16493	\N	\N
19894	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16494	\N	\N
19895	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16495	\N	\N
19896	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16496	\N	\N
19897	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16497	\N	\N
19898	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16498	\N	\N
19899	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16499	\N	\N
19900	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16500	\N	\N
19901	VICPDTCOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16501	\N	\N
19902	RAPCOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16502	\N	\N
19903	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16503	\N	\N
19904	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16504	\N	\N
19905	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16505	\N	\N
19906	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16506	\N	\N
19907	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16507	\N	\N
19908	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16508	\N	\N
19909	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16509	\N	\N
19910	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16510	\N	\N
19911	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16511	\N	\N
19912	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16512	\N	\N
19913	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16513	\N	\N
19914	MEMBRECOM	2021-03-11 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16514	\N	\N
20405	MEMBRECOM	2021-10-01 00:00:00	2021-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16955	\N	\N
20406	MEMBRECOM	2021-10-01 00:00:00	2021-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16956	\N	\N
20407	MEMBRECOM	2021-10-01 00:00:00	2021-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16957	\N	\N
20408	MEMBRECOM	2021-10-01 00:00:00	2021-10-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16958	\N	\N
8768	MEMBRECOM	2010-04-08 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7284	\N	\N
10766	MEMBRECOM	2012-12-13 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9053	\N	\N
11223	RAPCOM	2013-07-04 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9467	\N	\N
12787	MEMBRECOM	2014-12-06 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10735	\N	\N
14180	MEMBRECOM	2016-03-02 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12033	2016-03-11 11:50:14	\N
11394	MEMBRECOM	2013-10-03 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9630	\N	\N
20664	VICPDTCOM	2022-01-11 00:00:00	2022-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17128	\N	\N
20665	VICPDTCOM	2022-01-11 00:00:00	2022-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17136	\N	\N
20666	VICPDTCOM	2022-01-11 00:00:00	2022-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17143	\N	\N
20667	VICPDTCOM	2022-01-11 00:00:00	2022-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17135	\N	\N
20668	PDTCOM	2022-01-11 00:00:00	2022-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17129	\N	\N
20669	RAPCOM	2022-01-11 00:00:00	2022-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17146	\N	\N
20670	VICPDTCOM	2022-01-11 00:00:00	2022-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17126	\N	\N
20671	VICPDTCOM	2022-01-11 00:00:00	2022-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17138	\N	\N
20672	VICPDTCOM	2022-01-11 00:00:00	2022-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17134	\N	\N
20673	VICPDTCOM	2022-01-11 00:00:00	2022-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17132	\N	\N
20674	SECRETCOM	2022-01-11 00:00:00	2022-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17139	\N	\N
20675	SECRETCOM	2022-01-11 00:00:00	2022-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17141	\N	\N
20676	PDTCOM	2022-01-11 00:00:00	2022-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17166	\N	\N
20677	RAPCOM	2022-01-11 00:00:00	2022-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17164	\N	\N
20678	VICPDTCOM	2022-01-11 00:00:00	2022-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17147	\N	\N
20679	VICPDTCOM	2022-01-11 00:00:00	2022-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17151	\N	\N
20680	VICPDTCOM	2022-01-11 00:00:00	2022-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17158	\N	\N
20681	VICPDTCOM	2022-01-11 00:00:00	2022-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17161	\N	\N
20682	VICPDTCOM	2022-01-11 00:00:00	2022-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17162	\N	\N
20683	VICPDTCOM	2022-01-11 00:00:00	2022-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17160	\N	\N
20684	VICPDTCOM	2022-01-11 00:00:00	2022-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17163	\N	\N
20685	VICPDTCOM	2022-01-11 00:00:00	2022-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17167	\N	\N
20686	SECRETCOM	2022-01-11 00:00:00	2022-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17165	\N	\N
20687	SECRETCOM	2022-01-11 00:00:00	2022-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17157	\N	\N
20943	RAPCOM	2023-02-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17204	\N	\N
20944	PDTCOM	2023-02-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17211	\N	\N
20945	VICPDTCOM	2023-02-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17206	\N	\N
20946	VICPDTCOM	2023-02-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17227	\N	\N
20947	VICPDTCOM	2023-02-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17225	\N	\N
20948	VICPDTCOM	2023-02-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17219	\N	\N
20949	VICPDTCOM	2023-02-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17201	\N	\N
20950	VICPDTCOM	2023-02-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17202	\N	\N
20951	VICPDTCOM	2023-02-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17221	\N	\N
20952	VICPDTCOM	2023-02-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17226	\N	\N
20953	SECRETCOM	2023-02-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17196	\N	\N
20954	SECRETCOM	2023-02-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17228	\N	\N
20955	PDTCOM	2023-02-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17235	\N	\N
20956	RAPCOM	2023-02-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17239	\N	\N
20957	VICPDTCOM	2023-02-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17236	\N	\N
20958	VICPDTCOM	2023-02-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17241	\N	\N
20959	VICPDTCOM	2023-02-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17246	\N	\N
20960	VICPDTCOM	2023-02-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17247	\N	\N
20961	VICPDTCOM	2023-02-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17238	\N	\N
20962	VICPDTCOM	2023-02-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17231	\N	\N
20963	VICPDTCOM	2023-02-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17244	\N	\N
20964	VICPDTCOM	2023-02-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17233	\N	\N
20965	SECRETCOM	2023-02-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17240	\N	\N
20966	SECRETCOM	2023-02-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17251	\N	\N
21039	MEMBRECOM	2023-03-01 00:00:00	2023-03-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17418	\N	\N
21829	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18151	2023-09-25 00:00:00	\N
21041	MEMBRECOM	2023-03-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17420	\N	\N
21042	MEMBRECOM	2023-03-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17421	\N	\N
21043	MEMBRECOM	2023-03-01 00:00:00	2023-03-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17422	\N	\N
21044	MEMBRECOM	2023-03-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17423	\N	\N
21045	MEMBRECOM	2023-03-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17424	\N	\N
21046	MEMBRECOM	2023-03-01 00:00:00	2023-03-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17425	\N	\N
21047	MEMBRECOM	2023-03-01 00:00:00	2023-03-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17426	\N	\N
21048	MEMBRECOM	2023-03-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17427	\N	\N
21049	MEMBRECOM	2023-03-01 00:00:00	2023-03-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17428	\N	\N
21050	MEMBRECOM	2023-03-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17429	\N	\N
21051	MEMBRECOM	2023-03-01 00:00:00	2023-03-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17430	\N	\N
21052	MEMBRECOM	2023-03-01 00:00:00	2023-03-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17431	\N	\N
21053	MEMBRECOM	2023-03-01 00:00:00	2023-03-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17432	\N	\N
21054	MEMBRECOM	2023-03-01 00:00:00	2023-03-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17433	\N	\N
21055	MEMBRECOM	2023-03-01 00:00:00	2023-03-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17434	\N	\N
21056	MEMBRECOM	2023-03-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17435	\N	\N
21057	MEMBRECOM	2023-03-01 00:00:00	2023-03-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17436	\N	\N
21058	MEMBRECOM	2023-03-01 00:00:00	2023-03-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17437	\N	\N
21830	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18152	2023-09-25 00:00:00	\N
23535	MEMBRECOM	2024-03-21 00:00:00	2024-04-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19569	2024-03-21 00:00:00	\N
23536	PDTCOM	2024-03-21 00:00:00	2024-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19541	\N	\N
23537	RAPCOM	2024-03-21 00:00:00	2024-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19542	\N	\N
23602	VICPDTCOM	2024-04-04 00:00:00	2024-04-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19629	\N	\N
23603	MEMBRECOM	2024-04-04 00:00:00	2024-04-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19630	\N	\N
23604	MEMBRECOM	2024-04-04 00:00:00	2024-04-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19631	\N	\N
23605	MEMBRECOM	2024-04-04 00:00:00	2024-04-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19632	\N	\N
23606	MEMBRECOM	2024-04-04 00:00:00	2024-04-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19633	\N	\N
23607	MEMBRECOM	2024-04-04 00:00:00	2024-04-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19634	\N	\N
23608	MEMBRECOM	2024-04-04 00:00:00	2024-04-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19635	\N	\N
23609	MEMBRECOM	2024-04-04 00:00:00	2024-04-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19636	\N	\N
23610	RAPCOM	2024-04-04 00:00:00	2024-04-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19637	\N	\N
23611	RAPCOM	2024-04-04 00:00:00	2024-04-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19638	\N	\N
23612	MEMBRECOM	2024-04-04 00:00:00	2024-04-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19639	\N	\N
23613	MEMBRECOM	2024-04-04 00:00:00	2024-04-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19640	\N	\N
23614	MEMBRECOM	2024-04-04 00:00:00	2024-04-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19641	\N	\N
23615	MEMBRECOM	2024-04-04 00:00:00	2024-04-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19642	\N	\N
23619	MEMBRECOM	2024-04-03 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19644	\N	\N
23620	MEMBRECOM	2024-04-03 00:00:00	2024-04-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19645	\N	\N
23621	MEMBRECOM	2024-04-03 00:00:00	2024-04-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19646	\N	\N
23622	MEMBRECOM	2024-04-03 00:00:00	2024-04-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19647	\N	\N
23623	MEMBRECOM	2024-04-03 00:00:00	2024-04-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19648	\N	\N
23624	MEMBRECOM	2024-04-03 00:00:00	2024-04-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19649	\N	\N
23625	MEMBRECOM	2024-04-03 00:00:00	2024-04-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19650	\N	\N
23626	MEMBRECOM	2024-04-03 00:00:00	2024-04-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19651	\N	\N
23627	MEMBRECOM	2024-04-03 00:00:00	2024-04-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19652	\N	\N
23628	MEMBRECOM	2024-04-03 00:00:00	2024-04-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19653	\N	\N
23629	MEMBRECOM	2024-04-03 00:00:00	2024-04-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19654	\N	\N
23630	MEMBRECOM	2024-04-03 00:00:00	2024-04-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19655	\N	\N
23631	MEMBRECOM	2024-04-03 00:00:00	2024-04-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19656	\N	\N
23632	MEMBRECOM	2024-04-03 00:00:00	2024-04-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19657	\N	\N
23633	MEMBRECOM	2024-04-03 00:00:00	2024-04-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19658	\N	\N
17702	MEMBRECOM	2019-04-30 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14873	\N	\N
17703	MEMBRECOM	2019-04-30 00:00:00	2019-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14874	\N	\N
17704	MEMBRECOM	2019-04-30 00:00:00	2019-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14875	\N	\N
19632	MEMBRECOM	2021-01-13 00:00:00	2021-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16294	\N	\N
19634	MEMBRECOM	2021-01-13 00:00:00	2021-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16296	\N	\N
19633	MEMBRECOM	2021-01-13 00:00:00	2021-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16295	\N	\N
19635	MEMBRECOM	2021-01-13 00:00:00	2021-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16297	\N	\N
19636	MEMBRECOM	2021-01-13 00:00:00	2021-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16298	\N	\N
19637	MEMBRECOM	2021-01-13 00:00:00	2021-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16299	\N	\N
19638	MEMBRECOM	2021-01-13 00:00:00	2021-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16300	\N	\N
19639	MEMBRECOM	2021-01-13 00:00:00	2021-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16301	\N	\N
19640	MEMBRECOM	2021-01-13 00:00:00	2021-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16302	\N	\N
19641	MEMBRECOM	2021-01-13 00:00:00	2021-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16303	\N	\N
19642	MEMBRECOM	2021-01-13 00:00:00	2021-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16304	\N	\N
19643	MEMBRECOM	2021-01-13 00:00:00	2021-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16305	\N	\N
19644	MEMBRECOM	2021-01-13 00:00:00	2021-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16306	\N	\N
19645	MEMBRECOM	2021-01-13 00:00:00	2021-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16307	\N	\N
19646	MEMBRECOM	2021-01-13 00:00:00	2021-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16308	\N	\N
19647	MEMBRECOM	2021-01-13 00:00:00	2021-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16309	\N	\N
19648	MEMBRECOM	2021-01-13 00:00:00	2021-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16310	\N	\N
19649	MEMBRECOM	2021-01-13 00:00:00	2021-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16311	\N	\N
19650	MEMBRECOM	2021-01-13 00:00:00	2021-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16312	\N	\N
19651	MEMBRECOM	2021-01-13 00:00:00	2021-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16313	\N	\N
19652	MEMBRECOM	2021-01-13 00:00:00	2021-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16314	\N	\N
19653	MEMBRECOM	2021-01-13 00:00:00	2021-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16315	\N	\N
19654	MEMBRECOM	2021-01-13 00:00:00	2021-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16316	\N	\N
19655	MEMBRECOM	2021-01-13 00:00:00	2021-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16317	\N	\N
19656	MEMBRECOM	2021-01-13 00:00:00	2021-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16318	\N	\N
19657	MEMBRECOM	2021-01-13 00:00:00	2021-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16319	\N	\N
19658	MEMBRECOM	2021-01-13 00:00:00	2021-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16320	\N	\N
19659	MEMBRECOM	2021-01-13 00:00:00	2021-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16321	\N	\N
19660	MEMBRECOM	2021-01-13 00:00:00	2021-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16322	\N	\N
19661	MEMBRECOM	2021-01-13 00:00:00	2021-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16323	\N	\N
19662	MEMBRECOM	2021-01-13 00:00:00	2021-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16324	\N	\N
19663	MEMBRECOM	2021-01-13 00:00:00	2021-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16325	\N	\N
19664	MEMBRECOM	2021-01-13 00:00:00	2021-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16326	\N	\N
19665	MEMBRECOM	2021-01-13 00:00:00	2021-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16327	\N	\N
19666	MEMBRECOM	2021-01-13 00:00:00	2021-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16328	\N	\N
19667	MEMBRECOM	2021-01-13 00:00:00	2021-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16329	\N	\N
19668	MEMBRECOM	2021-01-13 00:00:00	2021-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16330	\N	\N
19669	MEMBRECOM	2021-01-13 00:00:00	2021-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16331	\N	\N
19670	MEMBRECOM	2021-01-13 00:00:00	2021-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16332	\N	\N
19671	MEMBRECOM	2021-01-13 00:00:00	2021-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16333	\N	\N
19672	MEMBRECOM	2021-01-13 00:00:00	2021-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16334	\N	\N
19673	MEMBRECOM	2021-01-13 00:00:00	2021-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16335	\N	\N
20604	MEMBRECOM	2021-12-08 00:00:00	2022-01-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17125	\N	\N
20605	MEMBRECOM	2021-12-09 00:00:00	2022-01-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17126	\N	\N
20606	MEMBRECOM	2021-12-09 00:00:00	2022-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17127	\N	\N
20607	MEMBRECOM	2021-12-09 00:00:00	2022-01-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17128	\N	\N
20608	MEMBRECOM	2021-12-09 00:00:00	2022-01-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17129	\N	\N
20612	MEMBRECOM	2021-12-09 00:00:00	2022-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17133	\N	\N
20610	MEMBRECOM	2021-12-09 00:00:00	2022-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17131	\N	\N
20611	MEMBRECOM	2021-12-09 00:00:00	2022-01-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17132	\N	\N
20613	MEMBRECOM	2021-12-09 00:00:00	2022-01-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17134	\N	\N
20614	MEMBRECOM	2021-12-09 00:00:00	2022-01-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17135	\N	\N
20615	MEMBRECOM	2021-12-09 00:00:00	2022-01-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17136	\N	\N
20616	MEMBRECOM	2021-12-09 00:00:00	2022-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17137	\N	\N
20617	MEMBRECOM	2021-12-09 00:00:00	2022-01-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17138	\N	\N
20618	MEMBRECOM	2021-12-09 00:00:00	2022-01-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17139	\N	\N
20619	MEMBRECOM	2021-12-09 00:00:00	2022-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17140	\N	\N
20620	MEMBRECOM	2021-12-09 00:00:00	2022-01-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17141	\N	\N
20621	MEMBRECOM	2021-12-09 00:00:00	2022-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17142	\N	\N
20622	MEMBRECOM	2021-12-09 00:00:00	2022-01-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17143	\N	\N
20623	MEMBRECOM	2021-12-09 00:00:00	2022-06-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17144	\N	\N
20627	MEMBRECOM	2021-12-09 00:00:00	2022-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17148	\N	\N
20625	MEMBRECOM	2021-12-09 00:00:00	2022-01-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17146	\N	\N
20626	MEMBRECOM	2021-12-09 00:00:00	2022-01-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17147	\N	\N
20628	MEMBRECOM	2021-12-09 00:00:00	2022-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17149	\N	\N
20629	MEMBRECOM	2021-12-09 00:00:00	2022-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17150	\N	\N
20630	MEMBRECOM	2021-12-09 00:00:00	2022-01-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17151	\N	\N
20631	MEMBRECOM	2021-12-09 00:00:00	2022-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17152	\N	\N
20632	MEMBRECOM	2021-12-09 00:00:00	2022-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17153	\N	\N
20633	MEMBRECOM	2021-12-09 00:00:00	2022-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17154	\N	\N
20637	MEMBRECOM	2021-12-09 00:00:00	2022-01-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17158	\N	\N
20638	MEMBRECOM	2021-12-09 00:00:00	2022-06-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17159	\N	\N
20636	MEMBRECOM	2021-12-09 00:00:00	2022-01-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17157	\N	\N
20639	MEMBRECOM	2021-12-09 00:00:00	2022-01-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17160	\N	\N
20640	MEMBRECOM	2021-12-09 00:00:00	2022-01-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17161	\N	\N
20641	MEMBRECOM	2021-12-09 00:00:00	2022-01-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17162	\N	\N
20642	MEMBRECOM	2021-12-09 00:00:00	2022-01-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17163	\N	\N
20643	MEMBRECOM	2021-12-09 00:00:00	2022-01-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17164	\N	\N
20644	MEMBRECOM	2021-12-09 00:00:00	2022-01-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17165	\N	\N
20645	MEMBRECOM	2021-12-09 00:00:00	2022-01-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17166	\N	\N
20646	MEMBRECOM	2021-12-09 00:00:00	2022-01-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17167	\N	\N
20781	MEMBRECOM	2023-01-24 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17255	\N	\N
20779	MEMBRECOM	2023-01-24 00:00:00	2023-01-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17253	\N	\N
20780	MEMBRECOM	2023-01-24 00:00:00	2023-01-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17254	\N	\N
20782	MEMBRECOM	2023-01-24 00:00:00	2023-01-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17256	\N	\N
20783	MEMBRECOM	2023-01-24 00:00:00	2023-02-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17257	\N	\N
20784	MEMBRECOM	2023-01-24 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17258	\N	\N
20785	MEMBRECOM	2023-01-24 00:00:00	2023-01-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17259	\N	\N
20786	MEMBRECOM	2023-01-24 00:00:00	2023-01-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17260	\N	\N
20787	MEMBRECOM	2023-01-24 00:00:00	2023-01-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17261	\N	\N
20788	MEMBRECOM	2023-01-24 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17262	\N	\N
20789	MEMBRECOM	2023-01-24 00:00:00	2023-01-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17263	\N	\N
20790	MEMBRECOM	2023-01-24 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17264	\N	\N
20791	MEMBRECOM	2023-01-24 00:00:00	2023-01-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17265	\N	\N
20792	MEMBRECOM	2023-01-24 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17266	\N	\N
20793	MEMBRECOM	2023-01-24 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17267	\N	\N
20794	MEMBRECOM	2023-01-24 00:00:00	2023-01-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17268	\N	\N
20795	MEMBRECOM	2023-01-24 00:00:00	2023-01-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17269	\N	\N
20796	MEMBRECOM	2023-01-24 00:00:00	2023-01-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17270	\N	\N
20797	MEMBRECOM	2023-01-24 00:00:00	2023-01-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17271	\N	\N
22491	VICPDTCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18663	\N	\N
22492	VICPDTCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18662	\N	\N
22493	VICPDTCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18661	\N	\N
22494	VICPDTCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18658	\N	\N
22495	VICPDTCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18655	\N	\N
22496	SECRETCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18651	\N	\N
22497	VICPDTCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18643	\N	\N
22498	SECRETCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18640	\N	\N
22499	VICPDTCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18638	\N	\N
22500	SECRETCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18633	\N	\N
22501	VICPDTCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18631	\N	\N
22502	VICPDTCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18629	\N	\N
22503	SECRETCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18623	\N	\N
22504	VICPDTCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18620	\N	\N
22505	RAPGENCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18619	\N	\N
22506	PDTCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18618	\N	\N
22507	VICPDTCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18673	\N	\N
22632	MEMBRECOM	2023-10-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18790	\N	\N
18663	MEMBRECOM	2020-06-24 00:00:00	2020-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15700	\N	\N
18664	MEMBRECOM	2020-06-24 00:00:00	2020-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15701	\N	\N
18665	MEMBRECOM	2020-06-24 00:00:00	2020-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15702	\N	\N
18666	MEMBRECOM	2020-06-24 00:00:00	2020-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15703	\N	\N
18667	MEMBRECOM	2020-06-24 00:00:00	2020-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15704	\N	\N
18668	MEMBRECOM	2020-06-24 00:00:00	2020-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15705	\N	\N
18669	MEMBRECOM	2020-06-24 00:00:00	2020-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15706	\N	\N
18670	MEMBRECOM	2020-06-24 00:00:00	2020-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15707	\N	\N
18671	MEMBRECOM	2020-06-24 00:00:00	2020-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15708	\N	\N
18672	MEMBRECOM	2020-06-24 00:00:00	2020-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15709	\N	\N
18673	MEMBRECOM	2020-06-24 00:00:00	2020-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15710	\N	\N
18674	MEMBRECOM	2020-06-24 00:00:00	2020-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15711	\N	\N
18675	MEMBRECOM	2020-06-24 00:00:00	2020-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15712	\N	\N
18676	MEMBRECOM	2020-06-24 00:00:00	2020-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15713	\N	\N
18677	MEMBRECOM	2020-06-24 00:00:00	2020-07-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15714	\N	\N
18678	MEMBRECOM	2020-06-24 00:00:00	2020-07-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15715	\N	\N
18679	MEMBRECOM	2020-06-24 00:00:00	2020-07-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15716	\N	\N
18680	MEMBRECOM	2020-06-24 00:00:00	2020-07-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15717	\N	\N
18681	MEMBRECOM	2020-06-24 00:00:00	2020-07-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15718	\N	\N
18682	MEMBRECOM	2020-06-24 00:00:00	2020-07-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15719	\N	\N
18683	MEMBRECOM	2020-06-24 00:00:00	2020-07-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15720	\N	\N
18684	MEMBRECOM	2020-06-24 00:00:00	2020-07-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15721	\N	\N
18685	MEMBRECOM	2020-06-24 00:00:00	2020-07-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15722	\N	\N
18686	MEMBRECOM	2020-06-24 00:00:00	2020-07-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15723	\N	\N
18687	MEMBRECOM	2020-06-24 00:00:00	2020-07-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15724	\N	\N
18688	MEMBRECOM	2020-06-24 00:00:00	2020-07-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15725	\N	\N
18689	MEMBRECOM	2020-06-24 00:00:00	2020-07-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15726	\N	\N
18690	MEMBRECOM	2020-06-24 00:00:00	2020-07-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15727	\N	\N
18866	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15891	\N	\N
12892	PDTCOM	2014-07-10 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10840	2015-01-23 15:51:20	2015-01-23 15:51:33
18869	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15894	\N	\N
18883	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15908	\N	\N
18884	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15909	\N	\N
18885	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15910	\N	\N
18886	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15911	\N	\N
18887	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15912	\N	\N
4037	MEMBRECOM	2005-12-15 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3117	\N	\N
8383	MEMBRECOM	2009-09-29 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6938	\N	\N
10963	MEMBRECOM	2013-04-02 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9250	\N	\N
11614	MEMBRECOM	2013-12-16 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9819	\N	\N
13899	MEMBRECOM	2015-11-05 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11755	\N	\N
14184	MEMBRECOM	2016-03-02 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12037	2016-03-11 11:51:09	\N
18889	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15914	\N	\N
18890	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15915	\N	\N
18897	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15922	\N	\N
13873	MEMBRECOM	2015-11-05 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11729	\N	\N
18898	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15923	\N	\N
18899	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15924	\N	\N
18909	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15934	\N	\N
18910	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15935	\N	\N
18914	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15939	\N	\N
8941	MEMBRECOM	2010-10-19 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7441	\N	\N
9474	MEMBRECOM	2011-07-06 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7962	\N	\N
11447	MEMBRECOM	2013-11-05 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9672	\N	\N
12561	MEMBRECOM	2014-06-11 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10509	\N	\N
13807	MEMBRECOM	2015-10-08 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11663	\N	\N
18922	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15947	\N	\N
18923	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15948	\N	\N
18924	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15949	\N	\N
8319	MEMBRECOM	2009-07-08 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6877	\N	\N
18928	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15953	\N	\N
18929	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15954	\N	\N
18930	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15955	\N	\N
20688	MEMBRECOM	2022-02-03 00:00:00	2022-02-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17171	\N	\N
20712	MEMBRECOM	2023-01-10 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17186	\N	\N
21258	VICPDTCOM	2023-06-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17580	\N	\N
21259	RAPCOM	2023-06-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17581	\N	\N
21260	MEMBRECOM	2023-06-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17582	\N	\N
21261	MEMBRECOM	2023-06-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17583	\N	\N
21262	MEMBRECOM	2023-06-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17584	\N	\N
21263	MEMBRECOM	2023-06-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17585	\N	\N
21264	MEMBRECOM	2023-06-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17586	\N	\N
21265	MEMBRECOM	2023-06-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17587	\N	\N
21266	MEMBRECOM	2023-06-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17588	\N	\N
21267	MEMBRECOM	2023-06-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17589	\N	\N
21268	MEMBRECOM	2023-06-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17590	\N	\N
21269	MEMBRECOM	2023-06-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17591	\N	\N
21270	MEMBRECOM	2023-06-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17592	\N	\N
21271	MEMBRECOM	2023-06-12 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17593	\N	\N
23009	VICPDTCOM	2023-12-18 00:00:00	2023-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19121	\N	\N
23010	RAPCOM	2023-12-18 00:00:00	2023-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19122	\N	\N
23011	RAPCOM	2023-12-18 00:00:00	2023-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19123	\N	\N
23012	MEMBRECOM	2023-12-18 00:00:00	2023-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19124	\N	\N
23013	MEMBRECOM	2023-12-18 00:00:00	2023-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19125	\N	\N
23014	MEMBRECOM	2023-12-18 00:00:00	2023-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19126	\N	\N
23015	MEMBRECOM	2023-12-18 00:00:00	2023-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19127	\N	\N
23016	MEMBRECOM	2023-12-18 00:00:00	2023-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19128	\N	\N
23017	MEMBRECOM	2023-12-18 00:00:00	2023-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19129	\N	\N
23018	MEMBRECOM	2023-12-18 00:00:00	2023-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19130	\N	\N
23019	MEMBRECOM	2023-12-18 00:00:00	2023-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19131	\N	\N
23020	MEMBRECOM	2023-12-18 00:00:00	2023-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19132	\N	\N
23021	MEMBRECOM	2023-12-18 00:00:00	2023-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19133	\N	\N
23022	MEMBRECOM	2023-12-18 00:00:00	2023-12-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19134	\N	\N
23023	MEMBRECOM	2023-12-12 00:00:00	2023-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19135	\N	\N
23024	MEMBRECOM	2023-12-12 00:00:00	2023-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19136	\N	\N
23025	MEMBRECOM	2023-12-12 00:00:00	2023-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19137	\N	\N
23026	MEMBRECOM	2023-12-12 00:00:00	2023-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19138	\N	\N
23027	MEMBRECOM	2023-12-12 00:00:00	2023-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19139	\N	\N
23028	MEMBRECOM	2023-12-12 00:00:00	2023-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19140	\N	\N
23029	MEMBRECOM	2023-12-12 00:00:00	2023-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19141	\N	\N
23030	VICPDTCOM	2023-12-12 00:00:00	2023-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19142	\N	\N
23031	RAPGENCOM	2023-12-12 00:00:00	2023-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19143	\N	\N
23032	MEMBRECOM	2023-12-12 00:00:00	2023-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19144	\N	\N
23033	MEMBRECOM	2023-12-12 00:00:00	2023-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19145	\N	\N
23034	MEMBRECOM	2023-12-12 00:00:00	2023-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19146	\N	\N
23035	MEMBRECOM	2023-12-12 00:00:00	2023-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19147	\N	\N
23036	MEMBRECOM	2023-12-12 00:00:00	2023-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19148	\N	\N
23037	MEMBRECOM	2023-12-06 00:00:00	2023-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19149	\N	\N
23038	MEMBRECOM	2023-12-06 00:00:00	2023-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19150	\N	\N
23039	MEMBRECOM	2023-12-06 00:00:00	2023-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19151	\N	\N
23040	MEMBRECOM	2023-12-06 00:00:00	2023-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19152	\N	\N
23041	MEMBRECOM	2023-12-06 00:00:00	2023-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19153	\N	\N
23042	MEMBRECOM	2023-12-06 00:00:00	2023-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19154	\N	\N
23043	MEMBRECOM	2023-12-06 00:00:00	2023-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19155	\N	\N
23044	PDTCOM	2023-12-06 00:00:00	2023-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19156	\N	\N
23045	RAPCOM	2023-12-06 00:00:00	2023-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19157	\N	\N
23046	MEMBRECOM	2023-12-06 00:00:00	2023-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19158	\N	\N
23047	MEMBRECOM	2023-12-06 00:00:00	2023-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19159	\N	\N
23048	MEMBRECOM	2023-12-06 00:00:00	2023-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19160	\N	\N
23049	MEMBRECOM	2023-12-06 00:00:00	2023-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19161	\N	\N
23050	MEMBRECOM	2023-12-06 00:00:00	2023-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19162	\N	\N
23051	MEMBRECOM	2023-11-21 00:00:00	2023-11-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19163	\N	\N
23052	MEMBRECOM	2023-11-21 00:00:00	2023-11-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19164	\N	\N
23053	MEMBRECOM	2023-11-21 00:00:00	2023-11-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19165	\N	\N
23054	MEMBRECOM	2023-11-21 00:00:00	2023-11-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19166	\N	\N
23055	MEMBRECOM	2023-11-21 00:00:00	2023-11-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19167	\N	\N
20409	RAPCOM	2021-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16959	\N	\N
20410	MEMBRECOM	2021-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16960	\N	\N
20411	MEMBRECOM	2021-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16961	\N	\N
20412	MEMBRECOM	2021-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16962	\N	\N
20413	MEMBRECOM	2021-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16963	\N	\N
20414	MEMBRECOM	2021-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16964	\N	\N
20415	PDTCOM	2021-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16965	\N	\N
20416	MEMBRECOM	2021-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16966	\N	\N
20417	MEMBRECOM	2021-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16967	\N	\N
20418	MEMBRECOM	2021-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16968	\N	\N
20419	MEMBRECOM	2021-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16969	\N	\N
20420	MEMBRECOM	2021-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16970	\N	\N
20421	MEMBRECOM	2021-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16971	\N	\N
20422	MEMBRECOM	2021-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16972	\N	\N
20423	MEMBRECOM	2021-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16973	\N	\N
20424	MEMBRECOM	2021-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16974	\N	\N
20425	MEMBRECOM	2021-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16975	\N	\N
20426	MEMBRECOM	2021-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16976	\N	\N
20427	MEMBRECOM	2021-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16977	\N	\N
20428	MEMBRECOM	2021-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16978	\N	\N
20429	MEMBRECOM	2021-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16979	\N	\N
20430	MEMBRECOM	2021-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16980	\N	\N
20431	MEMBRECOM	2021-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16981	\N	\N
20432	MEMBRECOM	2021-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16982	\N	\N
20433	MEMBRECOM	2021-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16983	\N	\N
20434	MEMBRECOM	2021-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16984	\N	\N
20435	MEMBRECOM	2021-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16985	\N	\N
20436	MEMBRECOM	2021-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16986	\N	\N
22715	MEMBRECOM	2021-05-12 00:00:00	2021-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18871	\N	\N
22716	MEMBRECOM	2021-05-12 00:00:00	2021-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18872	\N	\N
22717	MEMBRECOM	2021-05-12 00:00:00	2021-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18873	\N	\N
22718	MEMBRECOM	2021-05-12 00:00:00	2021-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18874	\N	\N
22719	MEMBRECOM	2021-05-12 00:00:00	2021-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18875	\N	\N
22720	MEMBRECOM	2021-05-12 00:00:00	2021-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18876	\N	\N
22721	MEMBRECOM	2021-05-12 00:00:00	2021-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18877	\N	\N
22722	PDTCOM	2021-05-12 00:00:00	2021-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18878	\N	\N
22723	RAPCOM	2021-05-12 00:00:00	2021-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18879	\N	\N
22724	MEMBRECOM	2021-05-12 00:00:00	2021-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18880	\N	\N
22725	RAPCOM	2021-05-12 00:00:00	2021-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18881	\N	\N
22726	MEMBRECOM	2021-05-12 00:00:00	2021-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18882	\N	\N
22727	MEMBRECOM	2021-05-12 00:00:00	2021-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18883	\N	\N
22728	MEMBRECOM	2021-05-12 00:00:00	2021-05-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18884	\N	\N
22729	MEMBRECOM	2021-05-20 00:00:00	2021-05-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18885	\N	\N
22730	MEMBRECOM	2021-05-20 00:00:00	2021-05-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18886	\N	\N
22731	MEMBRECOM	2021-05-20 00:00:00	2021-05-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18887	\N	\N
22732	MEMBRECOM	2021-05-20 00:00:00	2021-05-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18888	\N	\N
22733	MEMBRECOM	2021-05-20 00:00:00	2021-05-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18889	\N	\N
22734	MEMBRECOM	2021-05-20 00:00:00	2021-05-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18890	\N	\N
22735	MEMBRECOM	2021-05-20 00:00:00	2021-05-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18891	\N	\N
22736	PDTCOM	2021-05-20 00:00:00	2021-05-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18892	\N	\N
22737	RAPCOM	2021-05-20 00:00:00	2021-05-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18893	\N	\N
22738	MEMBRECOM	2021-05-20 00:00:00	2021-05-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18894	\N	\N
22739	MEMBRECOM	2021-05-20 00:00:00	2021-05-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18895	\N	\N
22740	MEMBRECOM	2021-05-20 00:00:00	2021-05-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18896	\N	\N
22741	MEMBRECOM	2021-05-20 00:00:00	2021-05-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18897	\N	\N
22742	MEMBRECOM	2021-05-20 00:00:00	2021-05-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18898	\N	\N
22743	MEMBRECOM	2021-07-12 00:00:00	2021-07-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18899	\N	\N
22744	MEMBRECOM	2021-07-12 00:00:00	2021-07-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18900	\N	\N
22745	MEMBRECOM	2021-07-12 00:00:00	2021-07-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18901	\N	\N
22746	RAPCOM	2021-07-12 00:00:00	2021-07-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18902	\N	\N
22747	MEMBRECOM	2021-07-12 00:00:00	2021-07-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18903	\N	\N
22748	MEMBRECOM	2021-07-12 00:00:00	2021-07-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18904	\N	\N
22749	MEMBRECOM	2021-07-12 00:00:00	2021-07-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18905	\N	\N
22750	MEMBRECOM	2021-07-12 00:00:00	2021-07-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18906	\N	\N
22751	RAPCOM	2021-07-12 00:00:00	2021-07-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18907	\N	\N
22752	RAPCOM	2021-07-12 00:00:00	2021-07-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18908	\N	\N
22753	RAPCOM	2021-07-12 00:00:00	2021-07-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18909	\N	\N
22754	MEMBRECOM	2021-07-12 00:00:00	2021-07-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18910	\N	\N
22755	MEMBRECOM	2021-07-12 00:00:00	2021-07-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18911	\N	\N
22756	MEMBRECOM	2021-07-12 00:00:00	2021-07-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18912	\N	\N
22757	MEMBRECOM	2021-07-05 00:00:00	2021-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18913	\N	\N
22758	MEMBRECOM	2021-07-05 00:00:00	2021-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18914	\N	\N
22759	MEMBRECOM	2021-07-05 00:00:00	2021-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18915	\N	\N
22760	MEMBRECOM	2021-07-05 00:00:00	2021-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18916	\N	\N
22761	MEMBRECOM	2021-07-05 00:00:00	2021-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18917	\N	\N
22762	MEMBRECOM	2021-07-05 00:00:00	2021-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18918	\N	\N
22763	MEMBRECOM	2021-07-05 00:00:00	2021-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18919	\N	\N
22764	PDTCOM	2021-07-05 00:00:00	2021-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18920	\N	\N
22765	RAPCOM	2021-07-05 00:00:00	2021-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18921	\N	\N
22766	MEMBRECOM	2021-07-05 00:00:00	2021-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18922	\N	\N
22767	MEMBRECOM	2021-07-05 00:00:00	2021-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18923	\N	\N
22768	MEMBRECOM	2021-07-05 00:00:00	2021-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18924	\N	\N
22769	MEMBRECOM	2021-07-05 00:00:00	2021-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18925	\N	\N
22770	MEMBRECOM	2021-07-05 00:00:00	2021-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18926	\N	\N
22771	MEMBRECOM	2021-07-01 00:00:00	2021-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18927	\N	\N
22772	MEMBRECOM	2021-07-01 00:00:00	2021-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18928	\N	\N
22773	MEMBRECOM	2021-07-01 00:00:00	2021-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18929	\N	\N
22774	MEMBRECOM	2021-07-01 00:00:00	2021-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18930	\N	\N
22775	MEMBRECOM	2021-07-01 00:00:00	2021-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18931	\N	\N
22776	MEMBRECOM	2021-07-01 00:00:00	2021-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18932	\N	\N
22777	MEMBRECOM	2021-07-01 00:00:00	2021-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18933	\N	\N
22778	PDTCOM	2021-07-01 00:00:00	2021-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18934	\N	\N
22779	RAPCOM	2021-07-01 00:00:00	2021-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18935	\N	\N
22780	MEMBRECOM	2021-07-01 00:00:00	2021-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18936	\N	\N
22781	MEMBRECOM	2021-07-01 00:00:00	2021-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18937	\N	\N
22782	MEMBRECOM	2021-07-01 00:00:00	2021-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18938	\N	\N
22783	MEMBRECOM	2021-07-01 00:00:00	2021-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18939	\N	\N
22784	MEMBRECOM	2021-07-01 00:00:00	2021-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18940	\N	\N
22785	MEMBRECOM	2021-07-01 00:00:00	2021-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18941	\N	\N
22786	MEMBRECOM	2021-07-01 00:00:00	2021-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18942	\N	\N
22787	MEMBRECOM	2021-07-01 00:00:00	2021-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18943	\N	\N
22788	MEMBRECOM	2021-07-01 00:00:00	2021-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18944	\N	\N
22789	MEMBRECOM	2021-07-01 00:00:00	2021-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18945	\N	\N
22790	MEMBRECOM	2021-07-01 00:00:00	2021-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18946	\N	\N
22791	MEMBRECOM	2021-07-01 00:00:00	2021-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18947	\N	\N
22792	PDTCOM	2021-07-01 00:00:00	2021-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18948	\N	\N
22793	RAPCOM	2021-07-01 00:00:00	2021-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18949	\N	\N
22794	MEMBRECOM	2021-07-01 00:00:00	2021-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18950	\N	\N
22795	MEMBRECOM	2021-07-01 00:00:00	2021-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18951	\N	\N
22796	MEMBRECOM	2021-07-01 00:00:00	2021-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18952	\N	\N
22797	MEMBRECOM	2021-07-01 00:00:00	2021-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18953	\N	\N
22798	MEMBRECOM	2021-07-01 00:00:00	2021-07-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18954	\N	\N
22799	MEMBRECOM	2021-06-24 00:00:00	2021-06-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18955	\N	\N
22800	MEMBRECOM	2021-06-24 00:00:00	2021-06-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18956	\N	\N
22801	MEMBRECOM	2021-06-24 00:00:00	2021-06-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18957	\N	\N
22802	MEMBRECOM	2021-06-24 00:00:00	2021-06-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18958	\N	\N
22803	MEMBRECOM	2021-06-24 00:00:00	2021-06-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18959	\N	\N
22804	MEMBRECOM	2021-06-24 00:00:00	2021-06-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18960	\N	\N
22805	MEMBRECOM	2021-06-24 00:00:00	2021-06-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18961	\N	\N
22806	PDTCOM	2021-06-24 00:00:00	2021-06-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18962	\N	\N
22807	RAPCOM	2021-06-24 00:00:00	2021-06-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18963	\N	\N
22808	RAPCOM	2021-06-24 00:00:00	2021-06-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18964	\N	\N
22809	MEMBRECOM	2021-06-24 00:00:00	2021-06-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18965	\N	\N
22810	MEMBRECOM	2021-06-24 00:00:00	2021-06-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18966	\N	\N
22811	MEMBRECOM	2021-06-24 00:00:00	2021-06-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18967	\N	\N
22812	MEMBRECOM	2021-06-24 00:00:00	2021-06-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18968	\N	\N
20298	MEMBRECOM	2021-05-12 00:00:00	2021-05-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16886	\N	\N
23056	MEMBRECOM	2023-11-21 00:00:00	2023-11-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19168	\N	\N
23057	MEMBRECOM	2023-11-21 00:00:00	2023-11-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19169	\N	\N
23058	PDTCOM	2023-11-21 00:00:00	2023-11-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19170	\N	\N
23059	RAPGENCOM	2023-11-21 00:00:00	2023-11-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19171	\N	\N
23060	MEMBRECOM	2023-11-21 00:00:00	2023-11-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19172	\N	\N
23061	MEMBRECOM	2023-11-21 00:00:00	2023-11-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19173	\N	\N
23062	MEMBRECOM	2023-11-21 00:00:00	2023-11-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19174	\N	\N
23063	MEMBRECOM	2023-11-21 00:00:00	2023-11-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19175	\N	\N
23064	MEMBRECOM	2023-11-21 00:00:00	2023-11-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19176	\N	\N
23065	MEMBRECOM	2023-12-13 00:00:00	2023-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19177	\N	\N
23066	MEMBRECOM	2023-12-13 00:00:00	2023-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19178	\N	\N
23067	MEMBRECOM	2023-12-13 00:00:00	2023-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19179	\N	\N
23068	MEMBRECOM	2023-12-13 00:00:00	2023-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19180	\N	\N
23069	MEMBRECOM	2023-12-13 00:00:00	2023-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19181	\N	\N
23070	MEMBRECOM	2023-12-13 00:00:00	2023-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19182	\N	\N
23071	MEMBRECOM	2023-12-13 00:00:00	2023-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19183	\N	\N
23072	PDTCOM	2023-12-13 00:00:00	2023-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19184	\N	\N
23073	RAPCOM	2023-12-13 00:00:00	2023-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19185	\N	\N
23074	MEMBRECOM	2023-12-13 00:00:00	2023-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19186	\N	\N
23075	MEMBRECOM	2023-12-13 00:00:00	2023-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19187	\N	\N
23076	MEMBRECOM	2023-12-13 00:00:00	2023-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19188	\N	\N
23077	MEMBRECOM	2023-12-13 00:00:00	2023-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19189	\N	\N
23078	MEMBRECOM	2023-12-13 00:00:00	2023-12-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19190	\N	\N
23079	MEMBRECOM	2023-12-06 00:00:00	2023-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19191	\N	\N
23080	MEMBRECOM	2023-12-06 00:00:00	2023-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19192	\N	\N
23081	MEMBRECOM	2023-12-06 00:00:00	2023-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19193	\N	\N
23082	MEMBRECOM	2023-12-06 00:00:00	2023-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19194	\N	\N
23083	MEMBRECOM	2023-12-06 00:00:00	2023-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19195	\N	\N
23084	MEMBRECOM	2023-12-06 00:00:00	2023-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19196	\N	\N
23085	MEMBRECOM	2023-12-06 00:00:00	2023-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19197	\N	\N
23086	PDTCOM	2023-12-06 00:00:00	2023-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19198	\N	\N
23087	RAPCOM	2023-12-06 00:00:00	2023-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19199	\N	\N
23088	MEMBRECOM	2023-12-06 00:00:00	2023-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19200	\N	\N
23089	MEMBRECOM	2023-12-06 00:00:00	2023-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19201	\N	\N
23090	MEMBRECOM	2023-12-06 00:00:00	2023-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19202	\N	\N
23091	MEMBRECOM	2023-12-06 00:00:00	2023-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19203	\N	\N
23092	MEMBRECOM	2023-12-06 00:00:00	2023-12-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19204	\N	\N
23093	MEMBRECOM	2023-12-07 00:00:00	2023-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19205	\N	\N
23094	MEMBRECOM	2023-12-07 00:00:00	2023-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19206	\N	\N
23095	MEMBRECOM	2023-12-07 00:00:00	2023-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19207	\N	\N
23096	MEMBRECOM	2023-12-07 00:00:00	2023-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19208	\N	\N
23097	MEMBRECOM	2023-12-07 00:00:00	2023-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19209	\N	\N
23098	MEMBRECOM	2023-12-07 00:00:00	2023-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19210	\N	\N
23099	MEMBRECOM	2023-12-07 00:00:00	2023-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19211	\N	\N
23100	PDTCOM	2023-12-07 00:00:00	2023-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19212	\N	\N
23101	RAPCOM	2023-12-07 00:00:00	2023-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19213	\N	\N
23102	MEMBRECOM	2023-12-07 00:00:00	2023-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19214	\N	\N
23103	MEMBRECOM	2023-12-07 00:00:00	2023-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19215	\N	\N
23104	MEMBRECOM	2023-12-07 00:00:00	2023-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19216	\N	\N
23105	MEMBRECOM	2023-12-07 00:00:00	2023-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19217	\N	\N
23106	MEMBRECOM	2023-12-07 00:00:00	2023-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19218	\N	\N
20700	MEMBRECOM	2022-08-01 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17180	\N	\N
20701	MEMBRECOM	2022-08-01 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17181	\N	\N
20702	MEMBRECOM	2022-08-01 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17182	\N	\N
23487	VICPDTCOM	2024-03-13 00:00:00	2024-03-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19504	\N	\N
23488	RAPCOM	2024-03-13 00:00:00	2024-03-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19514	\N	\N
23494	MEMBRECOM	2024-03-14 00:00:00	2024-03-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19528	\N	\N
23490	RAPCOM	2024-03-13 00:00:00	2024-03-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19512	\N	\N
23492	MEMBRECOM	2024-03-14 00:00:00	2024-03-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19526	\N	\N
23493	MEMBRECOM	2024-03-14 00:00:00	2024-03-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19527	\N	\N
23495	MEMBRECOM	2024-03-14 00:00:00	2024-03-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19529	\N	\N
23496	MEMBRECOM	2024-03-14 00:00:00	2024-03-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19530	\N	\N
23497	MEMBRECOM	2024-03-14 00:00:00	2024-03-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19531	\N	\N
23498	MEMBRECOM	2024-03-14 00:00:00	2024-03-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19532	\N	\N
23499	VICPDTCOM	2024-03-14 00:00:00	2024-03-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19533	\N	\N
23500	RAPCOM	2024-03-14 00:00:00	2024-03-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19534	\N	\N
23501	MEMBRECOM	2024-03-14 00:00:00	2024-03-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19535	\N	\N
23502	MEMBRECOM	2024-03-14 00:00:00	2024-03-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19536	\N	\N
23503	MEMBRECOM	2024-03-14 00:00:00	2024-03-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19537	\N	\N
23504	MEMBRECOM	2024-03-14 00:00:00	2024-03-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19538	\N	\N
23505	MEMBRECOM	2024-03-14 00:00:00	2024-03-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19539	\N	\N
20445	MEMBRECOM	2021-10-14 00:00:00	2021-12-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16995	\N	\N
20722	MEMBRECOM	2023-01-17 00:00:00	2023-02-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17196	\N	\N
20723	MEMBRECOM	2023-01-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17197	\N	\N
20725	MEMBRECOM	2023-01-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17199	\N	\N
20727	MEMBRECOM	2023-01-17 00:00:00	2023-02-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17201	\N	\N
20728	MEMBRECOM	2023-01-17 00:00:00	2023-02-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17202	\N	\N
20730	MEMBRECOM	2023-01-17 00:00:00	2023-02-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17204	\N	\N
20732	MEMBRECOM	2023-01-17 00:00:00	2023-02-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17206	\N	\N
20734	MEMBRECOM	2023-01-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17208	\N	\N
20735	MEMBRECOM	2023-01-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17209	\N	\N
20737	MEMBRECOM	2023-01-17 00:00:00	2023-02-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17211	\N	\N
20739	MEMBRECOM	2023-01-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17213	\N	\N
23567	VICPDTCOM	2024-03-26 00:00:00	2024-03-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19592	\N	\N
20742	MEMBRECOM	2023-01-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17216	\N	\N
23568	RAPCOM	2024-03-26 00:00:00	2024-03-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19593	\N	\N
20745	MEMBRECOM	2023-01-17 00:00:00	2023-02-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17219	\N	\N
20746	MEMBRECOM	2023-01-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17220	\N	\N
20747	MEMBRECOM	2023-01-17 00:00:00	2023-02-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17221	\N	\N
20748	MEMBRECOM	2023-01-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17222	\N	\N
20749	MEMBRECOM	2023-01-17 00:00:00	2023-02-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17223	\N	\N
20750	MEMBRECOM	2023-01-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17224	\N	\N
20751	MEMBRECOM	2023-01-17 00:00:00	2023-02-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17225	\N	\N
20752	MEMBRECOM	2023-01-17 00:00:00	2023-02-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17226	\N	\N
20753	MEMBRECOM	2023-01-17 00:00:00	2023-02-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17227	\N	\N
20754	MEMBRECOM	2023-01-17 00:00:00	2023-02-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17228	\N	\N
20755	MEMBRECOM	2023-01-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17229	\N	\N
18660	MEMBRECOM	2020-06-30 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15697	\N	\N
18661	MEMBRECOM	2020-06-30 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15698	\N	\N
18662	MEMBRECOM	2020-06-30 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15699	\N	\N
19703	MEMBRECOM	2021-02-03 00:00:00	2021-09-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16341	\N	\N
19699	MEMBRECOM	2021-02-03 00:00:00	2021-09-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16337	\N	\N
19700	MEMBRECOM	2021-02-03 00:00:00	2021-02-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16338	\N	\N
19701	MEMBRECOM	2021-02-03 00:00:00	2021-09-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16339	\N	\N
19702	MEMBRECOM	2021-02-03 00:00:00	2021-09-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16340	\N	\N
19704	MEMBRECOM	2021-02-03 00:00:00	2021-02-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16342	\N	\N
19705	MEMBRECOM	2021-02-03 00:00:00	2021-02-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16343	\N	\N
19706	MEMBRECOM	2021-02-03 00:00:00	2021-09-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16344	\N	\N
19707	MEMBRECOM	2021-02-03 00:00:00	2021-09-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16345	\N	\N
19708	MEMBRECOM	2021-02-03 00:00:00	2021-09-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16346	\N	\N
19709	MEMBRECOM	2021-02-03 00:00:00	2021-02-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16347	\N	\N
19710	MEMBRECOM	2021-02-03 00:00:00	2021-09-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16348	\N	\N
19711	MEMBRECOM	2021-02-03 00:00:00	2021-02-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16349	\N	\N
19712	MEMBRECOM	2021-02-03 00:00:00	2021-09-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16350	\N	\N
19713	MEMBRECOM	2021-02-03 00:00:00	2021-02-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16351	\N	\N
19714	MEMBRECOM	2021-02-03 00:00:00	2021-02-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16352	\N	\N
19715	MEMBRECOM	2021-02-03 00:00:00	2021-09-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16353	\N	\N
19716	MEMBRECOM	2021-02-03 00:00:00	2021-09-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16354	\N	\N
19717	MEMBRECOM	2021-02-03 00:00:00	2021-02-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16355	\N	\N
19718	MEMBRECOM	2021-02-03 00:00:00	2021-02-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16356	\N	\N
19719	MEMBRECOM	2021-02-03 00:00:00	2021-02-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16357	\N	\N
19720	MEMBRECOM	2021-02-03 00:00:00	2021-02-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16358	\N	\N
19721	MEMBRECOM	2021-02-03 00:00:00	2021-02-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16359	\N	\N
20713	MEMBRECOM	2023-01-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17187	\N	\N
20714	MEMBRECOM	2023-01-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17188	\N	\N
20715	MEMBRECOM	2023-01-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17189	\N	\N
20716	MEMBRECOM	2023-01-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17190	\N	\N
20717	MEMBRECOM	2023-01-17 00:00:00	2023-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17191	\N	\N
20718	MEMBRECOM	2023-01-17 00:00:00	2023-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17192	\N	\N
20719	MEMBRECOM	2023-01-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17193	\N	\N
20720	MEMBRECOM	2023-01-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17194	\N	\N
20721	MEMBRECOM	2023-01-17 00:00:00	2023-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17195	\N	\N
20724	MEMBRECOM	2023-01-17 00:00:00	2023-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17198	\N	\N
20726	MEMBRECOM	2023-01-17 00:00:00	2023-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17200	\N	\N
20729	MEMBRECOM	2023-01-17 00:00:00	2023-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17203	\N	\N
20731	MEMBRECOM	2023-01-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17205	\N	\N
20733	MEMBRECOM	2023-01-17 00:00:00	2023-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17207	\N	\N
20736	MEMBRECOM	2023-01-17 00:00:00	2023-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17210	\N	\N
20738	MEMBRECOM	2023-01-17 00:00:00	2023-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17212	\N	\N
20741	MEMBRECOM	2023-01-17 00:00:00	2023-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17215	\N	\N
20744	MEMBRECOM	2023-01-17 00:00:00	2023-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17218	\N	\N
20756	MEMBRECOM	2023-01-17 00:00:00	2023-01-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17230	\N	\N
22813	MEMBRECOM	2023-10-31 00:00:00	2023-11-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18969	\N	\N
22814	MEMBRECOM	2023-10-31 00:00:00	2023-11-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18970	\N	\N
22815	MEMBRECOM	2023-10-31 00:00:00	2023-11-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18971	\N	\N
22816	MEMBRECOM	2023-10-31 00:00:00	2023-11-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18972	\N	\N
22817	MEMBRECOM	2023-10-31 00:00:00	2023-11-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18973	\N	\N
22818	MEMBRECOM	2023-10-31 00:00:00	2023-11-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18974	\N	\N
22819	MEMBRECOM	2023-10-31 00:00:00	2023-11-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18975	\N	\N
22820	MEMBRECOM	2023-10-31 00:00:00	2023-11-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18976	\N	\N
22821	MEMBRECOM	2023-10-31 00:00:00	2023-11-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18977	\N	\N
22822	MEMBRECOM	2023-10-31 00:00:00	2023-11-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18978	\N	\N
22823	MEMBRECOM	2023-10-31 00:00:00	2023-11-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18979	\N	\N
22824	MEMBRECOM	2023-10-31 00:00:00	2023-11-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18980	\N	\N
22825	MEMBRECOM	2023-10-31 00:00:00	2023-11-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18981	\N	\N
22826	MEMBRECOM	2023-10-31 00:00:00	2023-11-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18982	\N	\N
18003	MEMBRECOM	2019-07-11 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15125	\N	\N
18004	MEMBRECOM	2019-07-11 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15126	\N	\N
18128	MEMBRECOM	2019-10-16 00:00:00	2019-10-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15248	\N	\N
18129	MEMBRECOM	2019-10-16 00:00:00	2019-10-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15249	\N	\N
18130	MEMBRECOM	2019-10-16 00:00:00	2019-10-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15250	\N	\N
18131	MEMBRECOM	2019-10-16 00:00:00	2019-10-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15251	\N	\N
18132	MEMBRECOM	2019-10-16 00:00:00	2020-06-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15252	\N	\N
18133	MEMBRECOM	2019-10-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15253	\N	\N
18134	MEMBRECOM	2019-10-16 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15254	\N	\N
18135	MEMBRECOM	2019-10-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15255	\N	\N
18136	MEMBRECOM	2019-10-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15256	\N	\N
18137	MEMBRECOM	2019-10-16 00:00:00	2019-10-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15257	\N	\N
18138	MEMBRECOM	2019-10-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15258	\N	\N
18139	MEMBRECOM	2019-10-16 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15259	\N	\N
18140	MEMBRECOM	2019-10-16 00:00:00	2019-10-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15260	\N	\N
18141	MEMBRECOM	2019-10-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15261	\N	\N
18555	MEMBRECOM	2020-03-19 00:00:00	2020-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15592	\N	\N
18556	MEMBRECOM	2020-03-19 00:00:00	2020-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15593	\N	\N
18557	MEMBRECOM	2020-03-19 00:00:00	2020-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15594	\N	\N
18558	MEMBRECOM	2020-03-19 00:00:00	2020-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15595	\N	\N
18559	MEMBRECOM	2020-03-19 00:00:00	2020-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15596	\N	\N
18560	MEMBRECOM	2020-03-19 00:00:00	2020-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15597	\N	\N
18561	MEMBRECOM	2020-03-19 00:00:00	2020-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15598	\N	\N
18562	MEMBRECOM	2020-03-19 00:00:00	2020-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15599	\N	\N
18563	MEMBRECOM	2020-03-19 00:00:00	2020-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15600	\N	\N
18564	MEMBRECOM	2020-03-19 00:00:00	2020-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15601	\N	\N
18565	MEMBRECOM	2020-03-19 00:00:00	2020-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15602	\N	\N
18566	MEMBRECOM	2020-03-19 00:00:00	2020-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15603	\N	\N
18567	MEMBRECOM	2020-03-19 00:00:00	2020-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15604	\N	\N
18568	MEMBRECOM	2020-03-19 00:00:00	2020-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15605	\N	\N
18569	MEMBRECOM	2020-04-21 00:00:00	2020-04-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15606	\N	\N
18570	MEMBRECOM	2020-04-21 00:00:00	2020-04-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15607	\N	\N
18571	MEMBRECOM	2020-04-21 00:00:00	2020-04-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15608	\N	\N
18572	MEMBRECOM	2020-04-21 00:00:00	2020-04-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15609	\N	\N
18573	MEMBRECOM	2020-04-21 00:00:00	2020-04-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15610	\N	\N
18574	MEMBRECOM	2020-04-21 00:00:00	2020-04-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15611	\N	\N
18575	MEMBRECOM	2020-04-21 00:00:00	2020-04-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15612	\N	\N
18576	MEMBRECOM	2020-04-21 00:00:00	2020-04-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15613	\N	\N
18577	MEMBRECOM	2020-04-21 00:00:00	2020-04-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15614	\N	\N
18578	MEMBRECOM	2020-04-21 00:00:00	2020-04-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15615	\N	\N
18579	MEMBRECOM	2020-04-21 00:00:00	2020-04-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15616	\N	\N
18580	MEMBRECOM	2020-04-21 00:00:00	2020-04-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15617	\N	\N
18581	MEMBRECOM	2020-04-21 00:00:00	2020-04-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15618	\N	\N
18582	MEMBRECOM	2020-04-21 00:00:00	2020-04-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15619	\N	\N
18851	RAPCOM	2020-09-11 00:00:00	2020-09-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15444	\N	\N
19772	MEMBRECOM	2021-02-17 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16398	\N	\N
19773	MEMBRECOM	2021-02-17 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16399	\N	\N
19774	MEMBRECOM	2021-02-17 00:00:00	2021-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16400	\N	\N
19775	MEMBRECOM	2021-02-17 00:00:00	2021-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16401	\N	\N
19776	MEMBRECOM	2021-02-17 00:00:00	2021-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16402	\N	\N
19777	MEMBRECOM	2021-02-17 00:00:00	2021-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16403	\N	\N
19778	MEMBRECOM	2021-02-17 00:00:00	2021-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16404	\N	\N
19779	MEMBRECOM	2021-02-17 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16405	\N	\N
19780	MEMBRECOM	2021-02-17 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16406	\N	\N
19781	MEMBRECOM	2021-02-17 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16407	\N	\N
19782	MEMBRECOM	2021-02-17 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16408	\N	\N
19783	MEMBRECOM	2021-02-17 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16409	\N	\N
19784	MEMBRECOM	2021-02-17 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16410	\N	\N
19785	MEMBRECOM	2021-02-17 00:00:00	2021-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16411	\N	\N
19786	MEMBRECOM	2021-02-17 00:00:00	2021-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16412	\N	\N
19787	MEMBRECOM	2021-02-17 00:00:00	2021-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16413	\N	\N
19788	MEMBRECOM	2021-02-17 00:00:00	2021-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16414	\N	\N
19789	MEMBRECOM	2021-02-17 00:00:00	2021-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16415	\N	\N
19790	MEMBRECOM	2021-02-17 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16416	\N	\N
19791	MEMBRECOM	2021-02-17 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16417	\N	\N
19792	MEMBRECOM	2021-02-17 00:00:00	2021-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16418	\N	\N
19793	MEMBRECOM	2021-02-17 00:00:00	2021-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16419	\N	\N
19794	MEMBRECOM	2021-02-17 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16420	\N	\N
19795	MEMBRECOM	2021-02-17 00:00:00	2021-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16421	\N	\N
19796	MEMBRECOM	2021-02-17 00:00:00	2021-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16422	\N	\N
19797	MEMBRECOM	2021-02-17 00:00:00	2021-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16423	\N	\N
19798	MEMBRECOM	2021-02-17 00:00:00	2021-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16424	\N	\N
19799	MEMBRECOM	2021-02-17 00:00:00	2021-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16425	\N	\N
19800	MEMBRECOM	2021-02-17 00:00:00	2021-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16426	\N	\N
19801	MEMBRECOM	2021-02-17 00:00:00	2021-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16427	\N	\N
19802	MEMBRECOM	2021-02-17 00:00:00	2021-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16428	\N	\N
19803	MEMBRECOM	2021-02-17 00:00:00	2021-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16429	\N	\N
19804	MEMBRECOM	2021-02-17 00:00:00	2021-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16430	\N	\N
19805	MEMBRECOM	2021-02-17 00:00:00	2021-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16431	\N	\N
19806	MEMBRECOM	2021-02-17 00:00:00	2021-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16432	\N	\N
19807	MEMBRECOM	2021-02-17 00:00:00	2021-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16433	\N	\N
19808	MEMBRECOM	2021-02-17 00:00:00	2021-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16434	\N	\N
19809	MEMBRECOM	2021-02-17 00:00:00	2021-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16435	\N	\N
19810	MEMBRECOM	2021-02-17 00:00:00	2021-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16436	\N	\N
19811	MEMBRECOM	2021-02-17 00:00:00	2021-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16437	\N	\N
19812	MEMBRECOM	2021-02-17 00:00:00	2021-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16438	\N	\N
19813	MEMBRECOM	2021-02-17 00:00:00	2021-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16439	\N	\N
19814	MEMBRECOM	2021-02-17 00:00:00	2021-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16440	\N	\N
19815	MEMBRECOM	2021-02-17 00:00:00	2021-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16441	\N	\N
19816	MEMBRECOM	2021-02-17 00:00:00	2021-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16442	\N	\N
19817	MEMBRECOM	2021-02-17 00:00:00	2021-03-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16443	\N	\N
20690	MEMBRECOM	2022-03-01 00:00:00	2022-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17173	\N	\N
22013	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18333	\N	\N
22014	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18334	\N	\N
22015	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18335	\N	\N
22016	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18336	\N	\N
22017	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18337	\N	\N
22018	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18338	\N	\N
22019	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18339	\N	\N
22062	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18382	\N	\N
22063	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18383	\N	\N
22064	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18384	\N	\N
22065	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18385	\N	\N
22066	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18386	\N	\N
22067	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18387	\N	\N
22068	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18388	\N	\N
22069	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18389	\N	\N
22070	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18390	\N	\N
22080	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18400	\N	\N
22081	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18401	\N	\N
22082	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18402	\N	\N
22083	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18403	\N	\N
22084	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18404	\N	\N
22085	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18405	\N	\N
22086	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18406	\N	\N
22087	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18407	\N	\N
22088	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18408	\N	\N
22089	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18409	\N	\N
22099	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18419	\N	\N
22100	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18420	\N	\N
22101	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18421	\N	\N
22102	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18422	\N	\N
22103	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18423	\N	\N
22104	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18424	\N	\N
22105	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18425	\N	\N
22106	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18426	\N	\N
22107	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18427	\N	\N
22108	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18428	\N	\N
22109	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18429	\N	\N
22110	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18430	\N	\N
22111	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18431	\N	\N
22112	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18432	\N	\N
22113	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18433	\N	\N
22114	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18434	\N	\N
22123	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18443	\N	\N
22124	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18444	\N	\N
22125	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18445	\N	\N
17742	MEMBRECOM	2019-05-02 00:00:00	2019-05-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14904	\N	\N
17743	MEMBRECOM	2019-05-02 00:00:00	2019-05-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14905	\N	\N
17744	MEMBRECOM	2019-05-02 00:00:00	2019-05-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14906	\N	\N
17745	MEMBRECOM	2019-05-02 00:00:00	2019-05-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14907	\N	\N
17746	MEMBRECOM	2019-05-02 00:00:00	2019-05-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14908	\N	\N
17747	MEMBRECOM	2019-05-02 00:00:00	2019-05-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14909	\N	\N
17748	MEMBRECOM	2019-05-02 00:00:00	2019-05-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14910	\N	\N
17749	MEMBRECOM	2019-05-02 00:00:00	2019-05-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14911	\N	\N
17750	MEMBRECOM	2019-05-02 00:00:00	2019-05-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14912	\N	\N
17751	MEMBRECOM	2019-05-02 00:00:00	2019-05-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14913	\N	\N
17752	MEMBRECOM	2019-05-02 00:00:00	2019-05-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14914	\N	\N
17753	MEMBRECOM	2019-05-02 00:00:00	2019-05-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14915	\N	\N
17754	MEMBRECOM	2019-05-02 00:00:00	2019-05-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14916	\N	\N
17755	MEMBRECOM	2019-05-02 00:00:00	2019-05-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14917	\N	\N
18248	MEMBRECOM	2019-11-28 00:00:00	2019-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15328	\N	\N
18249	MEMBRECOM	2019-11-28 00:00:00	2019-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15329	\N	\N
18250	MEMBRECOM	2019-11-28 00:00:00	2019-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15330	\N	\N
18251	MEMBRECOM	2019-11-28 00:00:00	2019-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15331	\N	\N
18252	MEMBRECOM	2019-11-28 00:00:00	2019-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15332	\N	\N
18253	MEMBRECOM	2019-11-28 00:00:00	2019-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15333	\N	\N
18254	MEMBRECOM	2019-11-28 00:00:00	2019-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15334	\N	\N
18255	MEMBRECOM	2019-11-28 00:00:00	2019-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15335	\N	\N
18256	MEMBRECOM	2019-11-28 00:00:00	2019-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15336	\N	\N
18257	MEMBRECOM	2019-11-28 00:00:00	2019-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15337	\N	\N
18258	MEMBRECOM	2019-11-28 00:00:00	2019-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15338	\N	\N
18259	MEMBRECOM	2019-11-28 00:00:00	2019-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15339	\N	\N
18260	MEMBRECOM	2019-11-28 00:00:00	2019-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15340	\N	\N
18261	MEMBRECOM	2019-11-28 00:00:00	2019-12-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15341	\N	\N
18425	MEMBRECOM	2020-02-19 00:00:00	2020-02-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15497	\N	\N
18426	MEMBRECOM	2020-02-19 00:00:00	2020-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15498	\N	\N
18427	MEMBRECOM	2020-02-19 00:00:00	2020-02-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15499	\N	\N
18428	MEMBRECOM	2020-02-19 00:00:00	2020-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15500	\N	\N
18429	MEMBRECOM	2020-02-19 00:00:00	2020-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15501	\N	\N
18430	MEMBRECOM	2020-02-19 00:00:00	2020-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15502	\N	\N
18431	MEMBRECOM	2020-02-19 00:00:00	2020-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15503	\N	\N
18432	MEMBRECOM	2020-02-19 00:00:00	2020-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15504	\N	\N
18433	MEMBRECOM	2020-02-19 00:00:00	2020-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15505	\N	\N
18434	MEMBRECOM	2020-02-19 00:00:00	2020-02-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15506	\N	\N
18435	MEMBRECOM	2020-02-19 00:00:00	2020-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15507	\N	\N
18436	MEMBRECOM	2020-02-19 00:00:00	2020-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15508	\N	\N
18437	MEMBRECOM	2020-02-19 00:00:00	2020-02-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15509	\N	\N
18438	MEMBRECOM	2020-02-19 00:00:00	2020-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15510	\N	\N
18439	MEMBRECOM	2020-02-19 00:00:00	2020-02-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15511	\N	\N
18440	MEMBRECOM	2020-02-19 00:00:00	2020-02-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15512	\N	\N
18441	MEMBRECOM	2020-02-19 00:00:00	2020-02-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15513	\N	\N
18442	MEMBRECOM	2020-02-19 00:00:00	2020-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15514	\N	\N
18443	MEMBRECOM	2020-02-19 00:00:00	2020-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15515	\N	\N
18444	MEMBRECOM	2020-02-19 00:00:00	2020-02-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15516	\N	\N
18445	MEMBRECOM	2020-02-19 00:00:00	2020-02-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15517	\N	\N
18727	PDTCOM	2020-07-02 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15737	\N	\N
18728	RAPCOM	2020-07-02 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15731	\N	\N
18729	RAPCOM	2020-07-02 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15752	\N	\N
18730	RAPCOM	2020-07-02 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15745	\N	\N
18731	VICPDTCOM	2020-07-02 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15763	\N	\N
18732	VICPDTCOM	2020-07-02 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15759	\N	\N
18733	VICPDTCOM	2020-07-02 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15762	\N	\N
18734	VICPDTCOM	2020-07-02 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15757	\N	\N
18735	VICPDTCOM	2020-07-02 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15755	\N	\N
18736	VICPDTCOM	2020-07-02 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15754	\N	\N
18737	VICPDTCOM	2020-07-02 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15741	\N	\N
22699	VICPDTCOM	2023-10-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18840	\N	\N
22700	RAPCOM	2023-10-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18841	\N	\N
17941	MEMBRECOM	2019-06-27 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15094	\N	\N
17942	MEMBRECOM	2019-06-27 00:00:00	2020-11-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15095	\N	\N
18175	MEMBRECOM	2019-11-14 00:00:00	2020-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15265	\N	\N
18176	MEMBRECOM	2019-11-14 00:00:00	2020-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15266	\N	\N
18177	MEMBRECOM	2019-11-14 00:00:00	2019-11-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15267	\N	\N
18178	MEMBRECOM	2019-11-14 00:00:00	2020-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15268	\N	\N
18179	MEMBRECOM	2019-11-14 00:00:00	2019-11-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15269	\N	\N
18180	MEMBRECOM	2019-11-14 00:00:00	2020-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15270	\N	\N
18181	MEMBRECOM	2019-11-14 00:00:00	2019-11-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15271	\N	\N
18182	MEMBRECOM	2019-11-14 00:00:00	2020-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15272	\N	\N
18183	MEMBRECOM	2019-11-14 00:00:00	2020-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15273	\N	\N
18184	MEMBRECOM	2019-11-14 00:00:00	2020-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15274	\N	\N
18185	MEMBRECOM	2019-11-14 00:00:00	2019-11-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15275	\N	\N
18186	MEMBRECOM	2019-11-14 00:00:00	2019-11-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15276	\N	\N
18187	MEMBRECOM	2019-11-14 00:00:00	2020-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15277	\N	\N
18188	MEMBRECOM	2019-11-14 00:00:00	2020-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15278	\N	\N
18189	MEMBRECOM	2019-11-14 00:00:00	2020-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15279	\N	\N
18190	MEMBRECOM	2019-11-14 00:00:00	2020-07-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15280	\N	\N
18191	MEMBRECOM	2019-11-14 00:00:00	2019-11-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15281	\N	\N
18192	MEMBRECOM	2019-11-14 00:00:00	2019-11-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15282	\N	\N
18193	MEMBRECOM	2019-11-14 00:00:00	2019-11-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15283	\N	\N
18194	MEMBRECOM	2019-11-14 00:00:00	2019-11-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15284	\N	\N
18195	MEMBRECOM	2019-11-14 00:00:00	2019-11-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15285	\N	\N
22126	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18446	\N	\N
22127	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18447	\N	\N
22128	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18448	\N	\N
22129	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18449	\N	\N
22130	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18450	\N	\N
22827	PDTCOM	2023-11-07 00:00:00	2023-11-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18969	\N	\N
22828	RAPCOM	2023-11-07 00:00:00	2023-11-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18970	\N	\N
22829	MEMBRECOM	2023-11-07 00:00:00	2023-11-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18983	\N	\N
22830	MEMBRECOM	2023-11-07 00:00:00	2023-11-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18984	\N	\N
22831	MEMBRECOM	2023-11-07 00:00:00	2023-11-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18985	\N	\N
22832	MEMBRECOM	2023-11-07 00:00:00	2023-11-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18986	\N	\N
22833	MEMBRECOM	2023-11-07 00:00:00	2023-11-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18987	\N	\N
22834	MEMBRECOM	2023-11-07 00:00:00	2023-11-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18988	\N	\N
22835	MEMBRECOM	2023-11-07 00:00:00	2023-11-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18989	\N	\N
22836	MEMBRECOM	2023-11-07 00:00:00	2023-11-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18990	\N	\N
22837	MEMBRECOM	2023-11-07 00:00:00	2023-11-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18991	\N	\N
22838	MEMBRECOM	2023-11-07 00:00:00	2023-11-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18992	\N	\N
22839	MEMBRECOM	2023-11-07 00:00:00	2023-11-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18993	\N	\N
22840	MEMBRECOM	2023-11-07 00:00:00	2023-11-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18994	\N	\N
22841	MEMBRECOM	2023-11-07 00:00:00	2023-11-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18995	\N	\N
22842	MEMBRECOM	2023-11-07 00:00:00	2023-11-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18996	\N	\N
22843	MEMBRECOM	2023-11-08 00:00:00	2023-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18997	\N	\N
22844	MEMBRECOM	2023-11-08 00:00:00	2023-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18998	\N	\N
22845	MEMBRECOM	2023-11-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18999	\N	\N
22846	MEMBRECOM	2023-11-08 00:00:00	2023-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19000	\N	\N
22847	MEMBRECOM	2023-11-08 00:00:00	2023-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19001	\N	\N
22848	MEMBRECOM	2023-11-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19002	\N	\N
22849	MEMBRECOM	2023-11-08 00:00:00	2023-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19003	\N	\N
22850	MEMBRECOM	2023-11-08 00:00:00	2023-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19004	\N	\N
22852	MEMBRECOM	2023-11-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19006	\N	\N
22853	MEMBRECOM	2023-11-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19007	\N	\N
22854	MEMBRECOM	2023-11-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19008	\N	\N
22855	MEMBRECOM	2023-11-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19009	\N	\N
22856	MEMBRECOM	2023-11-08 00:00:00	2023-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19010	\N	\N
22857	MEMBRECOM	2023-11-08 00:00:00	2024-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19011	\N	\N
22858	MEMBRECOM	2023-11-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19012	\N	\N
22859	MEMBRECOM	2023-11-08 00:00:00	2023-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19013	\N	\N
22860	MEMBRECOM	2023-11-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19014	\N	\N
22861	MEMBRECOM	2023-11-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19015	\N	\N
22862	MEMBRECOM	2023-11-08 00:00:00	2023-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19016	\N	\N
22863	MEMBRECOM	2023-11-08 00:00:00	2023-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19017	\N	\N
22864	MEMBRECOM	2023-11-08 00:00:00	2023-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19018	\N	\N
22865	MEMBRECOM	2023-11-08 00:00:00	2023-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19019	\N	\N
22866	MEMBRECOM	2023-11-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19020	\N	\N
18083	MEMBRECOM	2019-10-16 00:00:00	2019-10-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15203	\N	\N
18084	MEMBRECOM	2019-10-16 00:00:00	2021-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15204	\N	\N
18085	MEMBRECOM	2019-10-16 00:00:00	2019-10-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15205	\N	\N
18086	MEMBRECOM	2019-10-16 00:00:00	2021-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15206	\N	\N
18087	MEMBRECOM	2019-10-16 00:00:00	2019-10-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15207	\N	\N
18088	MEMBRECOM	2019-10-16 00:00:00	2021-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15208	\N	\N
18089	MEMBRECOM	2019-10-16 00:00:00	2021-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15209	\N	\N
18090	MEMBRECOM	2019-10-16 00:00:00	2021-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15210	\N	\N
18091	MEMBRECOM	2019-10-16 00:00:00	2019-10-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15211	\N	\N
18092	MEMBRECOM	2019-10-16 00:00:00	2019-10-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15212	\N	\N
18093	MEMBRECOM	2019-10-16 00:00:00	2021-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15213	\N	\N
18094	MEMBRECOM	2019-10-16 00:00:00	2021-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15214	\N	\N
18095	MEMBRECOM	2019-10-16 00:00:00	2019-10-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15215	\N	\N
18096	MEMBRECOM	2019-10-16 00:00:00	2021-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15216	\N	\N
18097	MEMBRECOM	2019-10-16 00:00:00	2019-10-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15217	\N	\N
18098	MEMBRECOM	2019-10-16 00:00:00	2020-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15218	\N	\N
18099	MEMBRECOM	2019-10-16 00:00:00	2019-10-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15219	\N	\N
18100	MEMBRECOM	2019-10-16 00:00:00	2019-10-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15220	\N	\N
18101	MEMBRECOM	2019-10-16 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15221	\N	\N
18102	MEMBRECOM	2019-10-16 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15222	\N	\N
18103	MEMBRECOM	2019-10-16 00:00:00	2019-10-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15223	\N	\N
18104	MEMBRECOM	2019-10-16 00:00:00	2019-10-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15224	\N	\N
18105	MEMBRECOM	2019-10-16 00:00:00	2019-10-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15225	\N	\N
18106	MEMBRECOM	2019-10-16 00:00:00	2019-10-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15226	\N	\N
18107	MEMBRECOM	2019-10-16 00:00:00	2021-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15227	\N	\N
18108	MEMBRECOM	2019-10-16 00:00:00	2020-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15228	\N	\N
18109	MEMBRECOM	2019-10-16 00:00:00	2019-10-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15229	\N	\N
18110	MEMBRECOM	2019-10-16 00:00:00	2019-10-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15230	\N	\N
18111	MEMBRECOM	2019-10-16 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15231	\N	\N
18112	MEMBRECOM	2019-10-16 00:00:00	2021-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15232	\N	\N
18113	MEMBRECOM	2019-10-16 00:00:00	2019-10-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15233	\N	\N
18114	MEMBRECOM	2019-10-16 00:00:00	2020-10-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15234	\N	\N
18115	MEMBRECOM	2019-10-16 00:00:00	2019-10-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15235	\N	\N
18123	MEMBRECOM	2019-10-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15243	\N	\N
18117	MEMBRECOM	2019-10-16 00:00:00	2019-10-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15237	\N	\N
18118	MEMBRECOM	2019-10-16 00:00:00	2021-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15238	\N	\N
18119	MEMBRECOM	2019-10-16 00:00:00	2020-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15239	\N	\N
18120	MEMBRECOM	2019-10-16 00:00:00	2019-10-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15240	\N	\N
21084	MEMBRECOM	2020-01-31 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17439	\N	\N
18122	MEMBRECOM	2019-10-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15242	\N	\N
18124	MEMBRECOM	2019-10-16 00:00:00	2019-10-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15244	\N	\N
18125	MEMBRECOM	2019-10-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15245	\N	\N
18126	MEMBRECOM	2019-10-16 00:00:00	2019-10-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15246	\N	\N
18127	MEMBRECOM	2019-10-16 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15247	\N	\N
21085	MEMBRECOM	2020-01-31 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17440	\N	\N
21086	MEMBRECOM	2020-01-31 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17441	\N	\N
21087	MEMBRECOM	2020-01-31 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17442	\N	\N
21088	MEMBRECOM	2020-01-31 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17443	\N	\N
21089	MEMBRECOM	2020-01-31 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17444	\N	\N
21090	MEMBRECOM	2020-01-31 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17445	\N	\N
21091	MEMBRECOM	2020-01-31 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17446	\N	\N
21092	MEMBRECOM	2020-01-31 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17447	\N	\N
21093	MEMBRECOM	2020-01-31 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17448	\N	\N
21094	MEMBRECOM	2020-01-31 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17449	\N	\N
21095	MEMBRECOM	2020-01-31 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17450	\N	\N
21096	MEMBRECOM	2020-01-31 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17451	\N	\N
21097	MEMBRECOM	2020-01-31 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17452	\N	\N
21098	MEMBRECOM	2020-01-31 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17453	\N	\N
21099	MEMBRECOM	2020-01-31 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17454	\N	\N
21100	MEMBRECOM	2020-01-31 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17455	\N	\N
21101	MEMBRECOM	2020-01-31 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17456	\N	\N
21102	MEMBRECOM	2020-01-31 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17457	\N	\N
21103	MEMBRECOM	2020-01-31 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17458	\N	\N
21204	MEMBRECOM	2023-06-01 00:00:00	2023-06-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17543	\N	\N
21205	MEMBRECOM	2023-06-01 00:00:00	2023-06-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17544	\N	\N
21206	MEMBRECOM	2023-06-01 00:00:00	2023-06-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17545	\N	\N
21207	MEMBRECOM	2023-06-01 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17546	\N	\N
21208	MEMBRECOM	2023-06-01 00:00:00	2023-06-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17547	\N	\N
21209	MEMBRECOM	2023-06-01 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17548	\N	\N
21210	MEMBRECOM	2023-06-01 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17549	\N	\N
21211	MEMBRECOM	2023-06-01 00:00:00	2023-06-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17550	\N	\N
21212	MEMBRECOM	2023-06-01 00:00:00	2023-06-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17551	\N	\N
21213	MEMBRECOM	2023-06-01 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17552	\N	\N
21214	MEMBRECOM	2023-06-01 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17553	\N	\N
21215	MEMBRECOM	2023-06-01 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17554	\N	\N
21216	MEMBRECOM	2023-06-01 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17555	\N	\N
21217	MEMBRECOM	2023-06-01 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17556	\N	\N
21218	MEMBRECOM	2023-06-01 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17557	\N	\N
21219	MEMBRECOM	2023-06-01 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17558	\N	\N
21220	MEMBRECOM	2023-06-01 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17559	\N	\N
21221	MEMBRECOM	2023-06-01 00:00:00	2023-06-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17560	\N	\N
21222	MEMBRECOM	2023-06-01 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17561	\N	\N
21223	MEMBRECOM	2023-06-01 00:00:00	2023-06-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17562	\N	\N
21224	MEMBRECOM	2023-06-01 00:00:00	2023-06-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17563	\N	\N
21225	MEMBRECOM	2023-06-01 00:00:00	2023-06-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17564	\N	\N
21226	MEMBRECOM	2023-06-01 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17565	\N	\N
21227	MEMBRECOM	2023-06-01 00:00:00	2023-06-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17566	\N	\N
21228	MEMBRECOM	2023-06-01 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17567	\N	\N
21229	MEMBRECOM	2023-06-01 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17568	\N	\N
21230	MEMBRECOM	2023-06-01 00:00:00	2023-06-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17569	\N	\N
21231	MEMBRECOM	2023-06-01 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17570	\N	\N
21232	MEMBRECOM	2023-06-01 00:00:00	2023-06-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17571	\N	\N
21233	MEMBRECOM	2023-06-01 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17572	\N	\N
21234	MEMBRECOM	2023-06-01 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17573	\N	\N
21235	MEMBRECOM	2023-06-01 00:00:00	2023-06-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17574	\N	\N
21236	MEMBRECOM	2023-06-01 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17575	\N	\N
21237	MEMBRECOM	2023-06-01 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17576	\N	\N
21238	MEMBRECOM	2023-06-01 00:00:00	2023-06-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17577	\N	\N
21239	MEMBRECOM	2023-06-01 00:00:00	2023-06-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17578	\N	\N
21240	MEMBRECOM	2023-06-01 00:00:00	2023-06-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17579	\N	\N
17808	MEMBRECOM	2019-05-28 00:00:00	2019-06-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14961	\N	\N
17806	MEMBRECOM	2019-05-28 00:00:00	2019-06-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14959	\N	\N
17807	MEMBRECOM	2019-05-28 00:00:00	2019-06-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14960	\N	\N
17809	MEMBRECOM	2019-05-28 00:00:00	2019-06-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14962	\N	\N
17810	MEMBRECOM	2019-05-28 00:00:00	2019-06-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14963	\N	\N
17811	MEMBRECOM	2019-05-28 00:00:00	2019-06-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14964	\N	\N
17812	MEMBRECOM	2019-05-28 00:00:00	2019-06-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14965	\N	\N
17813	MEMBRECOM	2019-05-28 00:00:00	2019-06-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14966	\N	\N
17814	MEMBRECOM	2019-05-28 00:00:00	2019-06-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14967	\N	\N
17815	MEMBRECOM	2019-05-28 00:00:00	2019-06-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14968	\N	\N
13836	MEMBRECOM	2015-10-26 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11692	\N	\N
17817	MEMBRECOM	2019-05-28 00:00:00	2019-06-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14970	\N	\N
17818	MEMBRECOM	2019-05-28 00:00:00	2019-06-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14971	\N	\N
17819	MEMBRECOM	2019-05-28 00:00:00	2019-06-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14972	\N	\N
17820	MEMBRECOM	2019-05-28 00:00:00	2019-06-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14973	\N	\N
18926	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15951	\N	\N
19547	MEMBRECOM	2020-11-03 00:00:00	2021-12-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16210	\N	\N
19548	MEMBRECOM	2020-11-03 00:00:00	2022-06-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16211	\N	\N
19549	MEMBRECOM	2020-11-03 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16212	\N	\N
19560	VICPDTCOM	2020-10-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16222	\N	\N
19561	RAPCOM	2020-10-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16223	\N	\N
19562	MEMBRECOM	2020-10-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16224	\N	\N
19563	MEMBRECOM	2020-10-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16225	\N	\N
19564	MEMBRECOM	2020-10-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16226	\N	\N
19565	MEMBRECOM	2020-10-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16227	\N	\N
19566	MEMBRECOM	2020-10-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16228	\N	\N
19567	MEMBRECOM	2020-10-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16229	\N	\N
19568	MEMBRECOM	2020-10-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16230	\N	\N
19569	MEMBRECOM	2020-10-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16231	\N	\N
19570	MEMBRECOM	2020-10-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16232	\N	\N
19571	MEMBRECOM	2020-10-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16233	\N	\N
19572	MEMBRECOM	2020-10-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16234	\N	\N
19573	MEMBRECOM	2020-10-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16235	\N	\N
21893	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18213	2023-10-03 00:00:00	\N
21894	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18214	2023-10-03 00:00:00	\N
21895	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18215	2023-10-03 00:00:00	\N
21896	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18216	2023-10-03 00:00:00	\N
21897	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18217	2023-10-03 00:00:00	\N
21898	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18218	2023-10-03 00:00:00	\N
21899	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18219	2023-10-03 00:00:00	\N
21900	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18220	2023-10-03 00:00:00	\N
21901	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18221	2023-10-03 00:00:00	\N
21902	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18222	2023-10-03 00:00:00	\N
21903	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18223	2023-10-03 00:00:00	\N
21904	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18224	2023-10-03 00:00:00	\N
21905	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18225	2023-10-03 00:00:00	\N
21906	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18226	2023-10-03 00:00:00	\N
21907	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18227	2023-10-03 00:00:00	\N
21908	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18228	2023-10-03 00:00:00	\N
21909	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18229	2023-10-03 00:00:00	\N
21910	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18230	2023-10-03 00:00:00	\N
21911	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18231	2023-10-03 00:00:00	\N
21912	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18232	2023-10-03 00:00:00	\N
21913	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18233	2023-10-03 00:00:00	\N
21914	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18234	2023-10-03 00:00:00	\N
21915	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18235	2023-10-03 00:00:00	\N
18293	MEMBRECOM	2019-12-18 00:00:00	2020-01-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15373	\N	\N
18291	MEMBRECOM	2019-12-18 00:00:00	2020-01-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15371	\N	\N
18292	MEMBRECOM	2019-12-18 00:00:00	2020-01-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15372	\N	\N
18294	MEMBRECOM	2019-12-18 00:00:00	2020-01-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15374	\N	\N
18295	MEMBRECOM	2019-12-18 00:00:00	2020-01-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15375	\N	\N
18296	MEMBRECOM	2019-12-18 00:00:00	2020-01-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15376	\N	\N
18297	MEMBRECOM	2019-12-18 00:00:00	2020-01-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15377	\N	\N
18298	MEMBRECOM	2019-12-18 00:00:00	2020-01-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15378	\N	\N
18299	MEMBRECOM	2019-12-18 00:00:00	2020-01-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15379	\N	\N
18300	MEMBRECOM	2019-12-18 00:00:00	2020-01-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15380	\N	\N
18301	MEMBRECOM	2019-12-18 00:00:00	2020-01-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15381	\N	\N
18302	MEMBRECOM	2019-12-18 00:00:00	2020-01-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15382	\N	\N
18303	MEMBRECOM	2019-12-18 00:00:00	2020-01-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15383	\N	\N
18304	MEMBRECOM	2019-12-18 00:00:00	2020-01-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15384	\N	\N
20812	VICPDTCOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17259	\N	\N
20813	VICPDTCOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17253	\N	\N
20586	MEMBRECOM	2021-12-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17119	\N	\N
20587	MEMBRECOM	2021-12-01 00:00:00	2021-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17120	\N	\N
20588	MEMBRECOM	2021-12-01 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17121	\N	\N
20589	MEMBRECOM	2021-12-01 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17122	\N	\N
20590	MEMBRECOM	2021-12-01 00:00:00	2021-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17123	\N	\N
20591	MEMBRECOM	2021-12-01 00:00:00	2021-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17124	\N	\N
20814	VICPDTCOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17254	\N	\N
20815	VICPDTCOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17260	\N	\N
20816	VICPDTCOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17263	\N	\N
20817	VICPDTCOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17270	\N	\N
20818	VICPDTCOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17271	\N	\N
20819	VICPDTCOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17268	\N	\N
20820	PDTCOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17265	\N	\N
20821	RAPCOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17256	\N	\N
20822	SECRETCOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17261	\N	\N
20823	SECRETCOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17269	\N	\N
21684	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18006	2023-09-24 00:00:00	\N
21685	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18007	2023-09-24 00:00:00	\N
21686	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18008	2023-09-24 00:00:00	\N
21687	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18009	2023-09-24 00:00:00	\N
21688	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18010	2023-09-24 00:00:00	\N
21689	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18011	2023-09-24 00:00:00	\N
21707	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18029	2023-09-24 00:00:00	\N
21712	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18034	2023-09-24 00:00:00	\N
21713	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18035	2023-09-24 00:00:00	\N
21714	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18036	2023-09-24 00:00:00	\N
21715	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18037	2023-09-24 00:00:00	\N
21716	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18038	2023-09-24 00:00:00	\N
21717	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18039	2023-09-24 00:00:00	\N
21718	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18040	2023-09-24 00:00:00	\N
21762	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18084	2023-09-24 00:00:00	\N
21763	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18085	2023-09-24 00:00:00	\N
21766	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18088	2023-09-24 00:00:00	\N
21767	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18089	2023-09-24 00:00:00	\N
21769	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18091	2023-09-24 00:00:00	\N
21771	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18093	2023-09-24 00:00:00	\N
21772	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18094	2023-09-24 00:00:00	\N
21773	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18095	2023-09-24 00:00:00	\N
21774	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18096	2023-09-24 00:00:00	\N
21775	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18097	2023-09-24 00:00:00	\N
21779	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18101	2023-09-24 00:00:00	\N
21802	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18124	2023-09-24 00:00:00	\N
21803	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18125	2023-09-24 00:00:00	\N
21804	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18126	2023-09-24 00:00:00	\N
21805	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18127	2023-09-24 00:00:00	\N
21806	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18128	2023-09-24 00:00:00	\N
21807	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18129	2023-09-24 00:00:00	\N
15811	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13413	2017-10-04 00:00:00	\N
21808	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18130	2023-09-24 00:00:00	\N
21811	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18133	2023-09-24 00:00:00	\N
21812	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18134	2023-09-24 00:00:00	\N
21814	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18136	2023-09-24 00:00:00	\N
21822	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18144	2023-09-24 00:00:00	\N
21823	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18145	2023-09-24 00:00:00	\N
21824	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18146	2023-09-24 00:00:00	\N
21825	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18147	2023-09-24 00:00:00	\N
21826	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18148	2023-09-24 00:00:00	\N
12784	MEMBRECOM	2014-12-06 00:00:00	2020-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10732	\N	\N
12799	MEMBRECOM	2014-12-12 00:00:00	2020-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10747	\N	\N
19335	MEMBRECOM	2020-10-07 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10231	\N	\N
19336	MEMBRECOM	2020-10-07 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16103	\N	\N
19337	MEMBRECOM	2020-10-07 00:00:00	2022-07-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16104	\N	\N
19338	MEMBRECOM	2020-10-07 00:00:00	2020-11-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4408	\N	\N
19339	MEMBRECOM	2020-10-07 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10247	\N	\N
19340	VICPDTCOM	2020-10-07 00:00:00	2022-06-16 00:00:00	9	ANCIEN	\N	\N	\N	\N	16105	\N	\N
19341	VICPDTCOM	2020-10-07 00:00:00	2023-10-03 00:00:00	2	ANCIEN	\N	\N	\N	\N	16106	\N	\N
19342	SECRETCOM	2020-10-07 00:00:00	2023-10-03 00:00:00	13	ANCIEN	\N	\N	\N	\N	16107	\N	\N
19343	SECRETCOM	2020-10-07 00:00:00	2023-10-03 00:00:00	14	ANCIEN	\N	\N	\N	\N	16108	\N	\N
19344	MEMBRECOM	2020-10-07 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13573	\N	\N
19345	MEMBRECOM	2020-10-07 00:00:00	2023-02-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16109	\N	\N
19346	VICPDTCOM	2020-10-07 00:00:00	2023-10-03 00:00:00	12	ANCIEN	\N	\N	\N	\N	16110	\N	\N
19347	SECRETCOM	2020-10-07 00:00:00	2021-12-07 00:00:00	16	ANCIEN	\N	\N	\N	\N	16111	\N	\N
19348	MEMBRECOM	2020-10-07 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11438	\N	\N
19349	MEMBRECOM	2020-10-07 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8243	\N	\N
19350	VICPDTCOM	2020-10-07 00:00:00	2023-10-03 00:00:00	8	ANCIEN	\N	\N	\N	\N	8244	\N	\N
19351	MEMBRECOM	2020-10-07 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13543	\N	\N
19352	MEMBRECOM	2020-10-07 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10234	\N	\N
19353	MEMBRECOM	2020-10-07 00:00:00	2022-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13544	\N	\N
19354	MEMBRECOM	2020-10-07 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13545	\N	\N
19355	MEMBRECOM	2020-10-07 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16112	\N	\N
19356	MEMBRECOM	2020-10-07 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16113	\N	\N
19357	VICPDTCOM	2020-10-07 00:00:00	2023-10-03 00:00:00	6	ANCIEN	\N	\N	\N	\N	10752	\N	\N
19358	VICPDTCOM	2020-10-07 00:00:00	2023-10-03 00:00:00	7	ANCIEN	\N	\N	\N	\N	10248	\N	\N
19359	VICPDTCOM	2020-10-07 00:00:00	2023-10-03 00:00:00	10	ANCIEN	\N	\N	\N	\N	14211	\N	\N
19360	SECRETCOM	2020-10-07 00:00:00	2023-10-03 00:00:00	15	ANCIEN	\N	\N	\N	\N	10241	\N	\N
19361	MEMBRECOM	2020-10-07 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16114	\N	\N
19362	MEMBRECOM	2020-10-07 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16115	\N	\N
19363	VICPDTCOM	2020-10-07 00:00:00	2023-10-03 00:00:00	5	ANCIEN	\N	\N	\N	\N	10243	\N	\N
19364	MEMBRECOM	2020-10-07 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16116	\N	\N
19365	MEMBRECOM	2020-10-07 00:00:00	2021-02-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13550	\N	\N
19366	VICPDTCOM	2020-10-07 00:00:00	2023-10-03 00:00:00	11	ANCIEN	\N	\N	\N	\N	4746	\N	\N
19367	MEMBRECOM	2020-10-07 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16117	\N	\N
19368	MEMBRECOM	2020-10-07 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16118	\N	\N
19369	VICPDTCOM	2020-10-07 00:00:00	2023-10-03 00:00:00	3	ANCIEN	\N	\N	\N	\N	13554	\N	\N
19370	PDTCOM	2020-10-07 00:00:00	2023-10-03 00:00:00	1	ANCIEN	\N	\N	\N	\N	13555	\N	\N
19371	VICPDTCOM	2020-10-07 00:00:00	2023-10-03 00:00:00	4	ANCIEN	\N	\N	\N	\N	10238	\N	\N
19372	MEMBRECOM	2020-10-07 00:00:00	2020-10-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16119	\N	\N
19373	MEMBRECOM	2020-10-07 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16120	\N	\N
19374	MEMBRECOM	2020-10-07 00:00:00	2020-11-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16121	\N	\N
19375	MEMBRECOM	2020-10-07 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16122	\N	\N
19376	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3789	\N	\N
19377	SECRETCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9930	\N	\N
19378	SECRETCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2584	\N	\N
19379	SECRETCOM	2020-10-07 00:00:00	2021-10-19 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7208	\N	\N
19380	SECRETCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13479	\N	\N
19381	MEMBRECOM	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16123	\N	\N
19383	MEMBRECOM	2007-12-03 00:00:00	2011-01-11 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16124	\N	\N
19384	SECRETCOM	2011-01-12 00:00:00	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16124	\N	\N
19588	MEMBRECOM	2020-10-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16250	\N	\N
19386	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10218	\N	\N
19390	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10219	\N	\N
19391	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10123	\N	\N
19392	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10126	\N	\N
19393	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11501	\N	\N
19395	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13439	\N	\N
19396	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13452	\N	\N
19397	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16028	\N	\N
19400	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2577	\N	\N
19403	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2619	\N	\N
19404	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7399	\N	\N
19405	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8153	\N	\N
19406	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10170	\N	\N
19407	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11498	\N	\N
19408	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13516	\N	\N
19409	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16017	\N	\N
19410	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8696	\N	\N
19412	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10162	\N	\N
19413	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10163	\N	\N
19414	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10096	\N	\N
19415	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10103	\N	\N
19416	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13465	\N	\N
19417	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15983	\N	\N
19420	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16067	\N	\N
19421	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8701	\N	\N
19423	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11276	\N	\N
19424	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10208	\N	\N
19426	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10106	\N	\N
19427	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10110	\N	\N
19428	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13389	\N	\N
19429	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13414	\N	\N
19431	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16013	\N	\N
19432	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16054	\N	\N
19436	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2584	\N	\N
19438	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7208	\N	\N
19589	PDTCOM	2020-10-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16251	\N	\N
19590	RAPCOM	2020-10-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16252	\N	\N
19591	MEMBRECOM	2020-10-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16253	\N	\N
19592	MEMBRECOM	2020-10-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16254	\N	\N
19593	MEMBRECOM	2020-10-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16255	\N	\N
19594	MEMBRECOM	2020-10-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16256	\N	\N
19595	MEMBRECOM	2020-10-30 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16257	\N	\N
19596	MEMBRECOM	2020-10-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16258	\N	\N
19597	MEMBRECOM	2020-10-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16259	\N	\N
19598	MEMBRECOM	2020-10-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16260	\N	\N
19599	MEMBRECOM	2020-10-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16261	\N	\N
19600	MEMBRECOM	2020-10-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16262	\N	\N
19601	MEMBRECOM	2020-10-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16263	\N	\N
19602	PDTCOM	2020-10-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16264	\N	\N
19603	RAPCOM	2020-10-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16265	\N	\N
19604	MEMBRECOM	2020-10-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16266	\N	\N
19605	MEMBRECOM	2020-10-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16267	\N	\N
19606	MEMBRECOM	2020-10-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16268	\N	\N
19607	MEMBRECOM	2020-10-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16269	\N	\N
19608	MEMBRECOM	2020-10-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16270	\N	\N
19609	MEMBRECOM	2020-10-30 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16271	\N	\N
19610	MEMBRECOM	2020-10-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16272	\N	\N
19611	MEMBRECOM	2020-10-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16273	\N	\N
19612	MEMBRECOM	2020-10-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16274	\N	\N
19613	MEMBRECOM	2020-10-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16275	\N	\N
19614	MEMBRECOM	2020-10-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16276	\N	\N
19615	MEMBRECOM	2020-10-30 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16277	\N	\N
19616	PDTRAPCOM	2020-10-29 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16278	\N	\N
19617	MEMBRECOM	2020-10-29 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16279	\N	\N
19618	MEMBRECOM	2020-10-29 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16280	\N	\N
19619	MEMBRECOM	2020-10-29 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16281	\N	\N
19620	MEMBRECOM	2020-10-29 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16282	\N	\N
19621	MEMBRECOM	2020-10-29 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16283	\N	\N
19622	MEMBRECOM	2020-10-29 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16284	\N	\N
19623	MEMBRECOM	2020-10-29 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16285	\N	\N
19624	MEMBRECOM	2020-10-29 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16286	\N	\N
19625	MEMBRECOM	2020-10-29 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16287	\N	\N
19626	MEMBRECOM	2020-10-29 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16288	\N	\N
19627	MEMBRECOM	2020-10-29 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16289	\N	\N
19628	MEMBRECOM	2020-10-29 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16290	\N	\N
19629	MEMBRECOM	2020-10-29 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16291	\N	\N
19674	PDTCOM	2021-01-26 00:00:00	2021-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16324	\N	\N
19675	RAPCOM	2021-01-26 00:00:00	2021-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16317	\N	\N
19676	RAPCOM	2021-01-26 00:00:00	2021-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16326	\N	\N
19677	VICPDTCOM	2021-01-26 00:00:00	2021-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16318	\N	\N
19678	VICPDTCOM	2021-01-26 00:00:00	2021-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16319	\N	\N
19679	VICPDTCOM	2021-01-26 00:00:00	2021-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16320	\N	\N
19680	VICPDTCOM	2021-01-26 00:00:00	2021-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16328	\N	\N
19681	VICPDTCOM	2021-01-26 00:00:00	2021-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16329	\N	\N
19682	VICPDTCOM	2021-01-26 00:00:00	2021-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16333	\N	\N
19683	VICPDTCOM	2021-01-26 00:00:00	2021-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16335	\N	\N
19684	SECRETCOM	2021-01-26 00:00:00	2021-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16327	\N	\N
19685	SECRETCOM	2021-01-26 00:00:00	2021-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16331	\N	\N
19686	PDTCOM	2021-01-26 00:00:00	2021-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16304	\N	\N
18326	MEMBRECOM	2019-11-28 00:00:00	2020-01-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15406	\N	\N
18357	RAPCOM	2020-02-04 00:00:00	2020-09-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15400	\N	\N
18358	VICPDTCOM	2020-02-04 00:00:00	2020-09-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15403	\N	\N
18359	VICPDTCOM	2020-02-04 00:00:00	2020-09-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15397	\N	\N
18360	VICPDTCOM	2020-02-04 00:00:00	2020-09-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15404	\N	\N
18361	VICPDTCOM	2020-02-04 00:00:00	2020-09-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15399	\N	\N
18362	VICPDTCOM	2020-02-04 00:00:00	2020-09-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15391	\N	\N
18363	VICPDTCOM	2020-02-04 00:00:00	2020-09-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15393	\N	\N
18364	VICPDTCOM	2020-02-04 00:00:00	2020-09-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15394	\N	\N
18365	PDTCOM	2020-02-04 00:00:00	2020-09-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15437	\N	\N
18842	MEMBRECOM	2020-08-03 00:00:00	2020-08-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15868	\N	\N
19746	PDTCOM	2021-02-15 00:00:00	2021-03-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16384	\N	\N
19747	RAPCOM	2021-02-15 00:00:00	2021-03-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16385	\N	\N
19748	MEMBRECOM	2021-02-15 00:00:00	2021-03-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16386	\N	\N
19749	MEMBRECOM	2021-02-15 00:00:00	2021-03-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16387	\N	\N
19750	MEMBRECOM	2021-02-15 00:00:00	2021-03-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16388	\N	\N
19751	MEMBRECOM	2021-02-15 00:00:00	2021-03-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16389	\N	\N
19752	MEMBRECOM	2021-02-15 00:00:00	2021-03-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16390	\N	\N
19753	MEMBRECOM	2021-02-15 00:00:00	2021-03-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16391	\N	\N
19754	MEMBRECOM	2021-02-15 00:00:00	2021-03-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16392	\N	\N
19755	MEMBRECOM	2021-02-15 00:00:00	2021-03-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16393	\N	\N
19756	MEMBRECOM	2021-02-15 00:00:00	2021-03-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16394	\N	\N
19757	MEMBRECOM	2021-02-15 00:00:00	2021-03-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16395	\N	\N
19758	MEMBRECOM	2021-02-15 00:00:00	2021-03-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16396	\N	\N
19759	MEMBRECOM	2021-02-15 00:00:00	2021-03-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16397	\N	\N
22607	PDTCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18686	\N	\N
20583	MEMBRECOM	2021-12-01 00:00:00	2021-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17116	\N	\N
22608	VICPDTCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16141	\N	\N
21106	MEMBRECOM	2023-03-29 00:00:00	2023-07-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17461	\N	\N
22609	RAPCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16138	\N	\N
21108	MEMBRECOM	2023-03-29 00:00:00	2023-07-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17463	\N	\N
21109	MEMBRECOM	2023-03-29 00:00:00	2023-07-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17464	\N	\N
21110	MEMBRECOM	2023-03-29 00:00:00	2023-07-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17465	\N	\N
21111	MEMBRECOM	2023-03-29 00:00:00	2023-07-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17466	\N	\N
21112	MEMBRECOM	2023-03-29 00:00:00	2023-07-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17467	\N	\N
21113	MEMBRECOM	2023-03-29 00:00:00	2023-07-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17468	\N	\N
21114	MEMBRECOM	2023-03-29 00:00:00	2023-07-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17469	\N	\N
21115	MEMBRECOM	2023-03-29 00:00:00	2023-07-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17470	\N	\N
21116	MEMBRECOM	2023-03-29 00:00:00	2023-07-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17471	\N	\N
21117	MEMBRECOM	2023-03-29 00:00:00	2023-07-13 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17472	\N	\N
21132	MEMBRECOM	2023-03-15 00:00:00	2023-03-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17487	\N	\N
21133	MEMBRECOM	2023-03-15 00:00:00	2023-03-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17488	\N	\N
21134	MEMBRECOM	2023-03-15 00:00:00	2023-03-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17489	\N	\N
21135	MEMBRECOM	2023-03-15 00:00:00	2023-03-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17490	\N	\N
21136	MEMBRECOM	2023-03-15 00:00:00	2023-03-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17491	\N	\N
21137	MEMBRECOM	2023-03-15 00:00:00	2023-03-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17492	\N	\N
21138	MEMBRECOM	2023-03-15 00:00:00	2023-03-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17493	\N	\N
21139	PDTCOM	2023-03-15 00:00:00	2023-03-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17494	\N	\N
21140	MEMBRECOM	2023-03-15 00:00:00	2023-03-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17495	\N	\N
21141	MEMBRECOM	2023-03-15 00:00:00	2023-03-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17496	\N	\N
21142	RAPCOM	2023-03-15 00:00:00	2023-03-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17497	\N	\N
21143	MEMBRECOM	2023-03-15 00:00:00	2023-03-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17498	\N	\N
21144	MEMBRECOM	2023-03-15 00:00:00	2023-03-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17499	\N	\N
21145	MEMBRECOM	2023-03-15 00:00:00	2023-03-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17500	\N	\N
18813	MEMBRECOM	2020-07-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15839	\N	\N
18811	MEMBRECOM	2020-07-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15837	\N	\N
18812	MEMBRECOM	2020-07-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15838	\N	\N
18814	MEMBRECOM	2020-07-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15840	\N	\N
18815	MEMBRECOM	2020-07-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15841	\N	\N
18816	MEMBRECOM	2020-07-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15842	\N	\N
18817	MEMBRECOM	2020-07-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15843	\N	\N
18818	MEMBRECOM	2020-07-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15844	\N	\N
18819	MEMBRECOM	2020-07-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15845	\N	\N
18820	MEMBRECOM	2020-07-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15846	\N	\N
18821	MEMBRECOM	2020-07-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15847	\N	\N
18822	MEMBRECOM	2020-07-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15848	\N	\N
18823	MEMBRECOM	2020-07-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15849	\N	\N
18824	MEMBRECOM	2020-07-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15850	\N	\N
18825	MEMBRECOM	2020-07-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15851	\N	\N
18826	MEMBRECOM	2020-07-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15852	\N	\N
18827	MEMBRECOM	2020-07-21 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15853	\N	\N
18828	MEMBRECOM	2020-07-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15854	\N	\N
18829	MEMBRECOM	2020-07-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15855	\N	\N
18830	MEMBRECOM	2020-07-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15856	\N	\N
18831	MEMBRECOM	2020-07-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15857	\N	\N
18832	MEMBRECOM	2020-07-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15858	\N	\N
18833	MEMBRECOM	2020-07-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15859	\N	\N
18834	MEMBRECOM	2020-07-21 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15860	\N	\N
18835	MEMBRECOM	2020-07-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15861	\N	\N
18836	MEMBRECOM	2020-07-21 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15862	\N	\N
18837	MEMBRECOM	2020-07-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15863	\N	\N
18838	MEMBRECOM	2020-07-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	15864	\N	\N
18852	MEMBRECOM	2020-09-25 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15877	\N	\N
18865	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15890	\N	\N
18870	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15895	\N	\N
18873	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15898	\N	\N
18875	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15900	\N	\N
10377	MEMBRECOM	2012-02-21 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8731	\N	\N
18877	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15902	\N	\N
18878	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15903	\N	\N
18879	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15904	\N	\N
8009	MEMBRECOM	2009-02-27 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	6577	\N	\N
18881	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15906	\N	\N
18893	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15918	\N	\N
18894	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15919	\N	\N
5223	MEMBRECOM	2008-10-07 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	459	\N	\N
11360	MEMBRECOM	2013-10-03 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9596	\N	\N
18895	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15920	\N	\N
18904	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15929	\N	\N
18905	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15930	\N	\N
18906	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15931	\N	\N
18907	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15932	\N	\N
18908	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15933	\N	\N
18913	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15938	\N	\N
3783	PDTCOM	2005-05-11 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2872	\N	2014-09-28 18:58:21
8788	PDTCOM	2010-05-20 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7294	\N	2014-09-28 18:58:21
18918	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15943	\N	\N
18919	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15944	\N	\N
19696	SECRETCOM	2021-01-26 00:00:00	2021-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16313	\N	\N
18921	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15946	\N	\N
10617	MEMBRECOM	2012-09-27 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8920	\N	\N
19687	RAPCOM	2021-01-26 00:00:00	2021-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16311	\N	\N
19688	VICPDTCOM	2021-01-26 00:00:00	2021-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16315	\N	\N
19689	VICPDTCOM	2021-01-26 00:00:00	2021-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16307	\N	\N
19690	VICPDTCOM	2021-01-26 00:00:00	2021-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16303	\N	\N
19691	VICPDTCOM	2021-01-26 00:00:00	2021-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16314	\N	\N
19692	VICPDTCOM	2021-01-26 00:00:00	2021-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16294	\N	\N
19693	VICPDTCOM	2021-01-26 00:00:00	2021-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16295	\N	\N
19694	VICPDTCOM	2021-01-26 00:00:00	2021-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16316	\N	\N
19695	VICPDTCOM	2021-01-26 00:00:00	2021-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16309	\N	\N
19697	SECRETCOM	2021-01-26 00:00:00	2021-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16301	\N	\N
21667	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17989	2023-09-24 00:00:00	\N
21668	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17990	2023-09-24 00:00:00	\N
21694	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18016	2023-09-24 00:00:00	\N
21670	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17992	2023-09-24 00:00:00	\N
21674	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17996	2023-09-24 00:00:00	\N
21695	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18017	2023-09-24 00:00:00	\N
21700	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18022	2023-09-24 00:00:00	\N
21701	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18023	2023-09-24 00:00:00	\N
21702	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18024	2023-09-24 00:00:00	\N
21783	MEMBRECOM	2023-10-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18105	2023-09-24 00:00:00	\N
21784	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18106	2023-09-24 00:00:00	\N
21785	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18107	2023-09-24 00:00:00	\N
23289	MEMBRECOM	2024-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19377	\N	\N
17719	MEMBRECOM	2019-04-30 00:00:00	2019-05-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14890	\N	\N
17720	MEMBRECOM	2019-04-30 00:00:00	2019-05-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14891	\N	\N
17721	MEMBRECOM	2019-04-30 00:00:00	2019-05-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14892	\N	\N
17722	MEMBRECOM	2019-04-30 00:00:00	2019-05-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14893	\N	\N
17723	MEMBRECOM	2019-04-30 00:00:00	2019-05-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14894	\N	\N
17724	MEMBRECOM	2019-04-30 00:00:00	2019-05-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14895	\N	\N
17725	MEMBRECOM	2019-04-30 00:00:00	2019-05-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14896	\N	\N
17726	MEMBRECOM	2019-04-30 00:00:00	2019-05-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14897	\N	\N
17727	MEMBRECOM	2019-04-30 00:00:00	2019-05-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14898	\N	\N
17728	MEMBRECOM	2019-04-30 00:00:00	2019-05-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14899	\N	\N
17729	MEMBRECOM	2019-04-30 00:00:00	2019-05-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14900	\N	\N
17730	MEMBRECOM	2019-04-30 00:00:00	2019-05-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14901	\N	\N
17731	MEMBRECOM	2019-04-30 00:00:00	2019-05-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14902	\N	\N
17732	MEMBRECOM	2019-04-30 00:00:00	2019-05-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14903	\N	\N
18000	SECRETCOM	2019-07-10 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13447	\N	\N
18001	VICPDTCOM	2019-07-10 00:00:00	2020-10-05 00:00:00	4	ANCIEN	\N	\N	\N	\N	13450	\N	\N
18002	MEMBRECOM	2019-07-10 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10080	\N	\N
18387	MEMBRECOM	2020-02-06 00:00:00	2020-08-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15459	\N	\N
18388	VICPDTCOM	2020-02-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15460	\N	\N
18389	MEMBRECOM	2020-02-06 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15461	\N	\N
18390	VICPDTCOM	2020-02-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15462	\N	\N
18391	MEMBRECOM	2020-02-06 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15463	\N	\N
18392	VICPDTCOM	2020-02-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15464	\N	\N
18393	MEMBRECOM	2020-02-06 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15465	\N	\N
18394	MEMBRECOM	2020-02-06 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15466	\N	\N
18395	MEMBRECOM	2020-02-06 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15467	\N	\N
18396	MEMBRECOM	2020-02-06 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15468	\N	\N
18397	MEMBRECOM	2020-02-06 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15469	\N	\N
18398	SECRETCOM	2020-02-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15470	\N	\N
18399	VICPDTCOM	2020-02-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15471	\N	\N
18400	MEMBRECOM	2020-02-06 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15472	\N	\N
18401	MEMBRECOM	2020-02-06 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15473	\N	\N
18402	MEMBRECOM	2020-02-06 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15474	\N	\N
18403	PDTCOM	2020-02-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15475	\N	\N
18404	SECRETCOM	2020-02-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15476	\N	\N
18405	MEMBRECOM	2020-02-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15477	\N	\N
18406	VICPDTCOM	2020-02-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15478	\N	\N
18407	MEMBRECOM	2020-02-06 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15479	\N	\N
18408	VICPDTCOM	2020-02-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15480	\N	\N
18409	MEMBRECOM	2020-02-06 00:00:00	2020-02-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15481	\N	\N
18410	VICPDTCOM	2020-02-06 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15482	\N	\N
18411	VICPDTCOM	2020-02-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15483	\N	\N
18412	MEMBRECOM	2020-02-06 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15484	\N	\N
18413	MEMBRECOM	2020-02-06 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15485	\N	\N
18414	MEMBRECOM	2020-02-06 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15486	\N	\N
18415	SECRETCOM	2020-02-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15487	\N	\N
18416	RAPCOM	2020-02-06 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15488	\N	\N
18417	MEMBRECOM	2020-02-06 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15489	\N	\N
18418	MEMBRECOM	2020-02-06 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15490	\N	\N
18419	MEMBRECOM	2020-02-06 00:00:00	2020-12-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15491	\N	\N
18420	MEMBRECOM	2020-02-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15492	\N	\N
18421	VICPDTCOM	2020-02-06 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15493	\N	\N
18422	VICPDTCOM	2020-02-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15494	\N	\N
18423	MEMBRECOM	2020-02-06 00:00:00	2020-10-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15495	\N	\N
20000	MEMBRECOM	2021-03-02 00:00:00	2021-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16600	\N	\N
20001	MEMBRECOM	2021-03-02 00:00:00	2021-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16601	\N	\N
20002	MEMBRECOM	2021-03-02 00:00:00	2021-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16602	\N	\N
20003	MEMBRECOM	2021-03-02 00:00:00	2021-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16603	\N	\N
20004	MEMBRECOM	2021-03-02 00:00:00	2021-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16604	\N	\N
20005	MEMBRECOM	2021-03-02 00:00:00	2021-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16605	\N	\N
20006	MEMBRECOM	2021-03-02 00:00:00	2021-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16606	\N	\N
20007	PDTCOM	2021-03-02 00:00:00	2021-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16607	\N	\N
20008	RAPCOM	2021-03-02 00:00:00	2021-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16608	\N	\N
20016	MEMBRECOM	2020-10-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16616	\N	\N
20010	MEMBRECOM	2021-03-02 00:00:00	2021-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16610	\N	\N
20011	MEMBRECOM	2021-03-02 00:00:00	2021-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16611	\N	\N
20012	MEMBRECOM	2021-03-02 00:00:00	2021-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16612	\N	\N
20013	MEMBRECOM	2021-03-02 00:00:00	2021-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16613	\N	\N
20014	MEMBRECOM	2021-03-02 00:00:00	2021-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16614	\N	\N
20015	MEMBRECOM	2020-10-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16615	\N	\N
20017	MEMBRECOM	2020-10-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16617	\N	\N
20018	MEMBRECOM	2020-10-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16618	\N	\N
20019	MEMBRECOM	2020-10-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16619	\N	\N
20020	MEMBRECOM	2020-10-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16620	\N	\N
20021	MEMBRECOM	2020-10-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16621	\N	\N
20022	RAPCOM	2020-10-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16622	\N	\N
20023	RAPCOM	2020-10-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16623	\N	\N
20024	PDTCOM	2020-10-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16624	\N	\N
20025	MEMBRECOM	2020-10-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16625	\N	\N
20026	MEMBRECOM	2020-10-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16626	\N	\N
20027	MEMBRECOM	2020-10-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16627	\N	\N
20028	MEMBRECOM	2020-10-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16628	\N	\N
20029	MEMBRECOM	2020-11-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16629	\N	\N
20030	MEMBRECOM	2020-11-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16630	\N	\N
20031	MEMBRECOM	2020-11-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16631	\N	\N
20032	MEMBRECOM	2020-11-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16632	\N	\N
20033	MEMBRECOM	2020-11-09 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16633	\N	\N
20034	MEMBRECOM	2020-11-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16634	\N	\N
20035	MEMBRECOM	2020-11-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16635	\N	\N
20036	PDTCOM	2020-11-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16636	\N	\N
20037	RAPCOM	2020-11-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16637	\N	\N
20038	MEMBRECOM	2020-11-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16638	\N	\N
20039	MEMBRECOM	2020-11-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16639	\N	\N
20040	MEMBRECOM	2020-11-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16640	\N	\N
20041	MEMBRECOM	2020-11-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16641	\N	\N
20042	MEMBRECOM	2020-11-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16642	\N	\N
20043	MEMBRECOM	2020-11-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16643	\N	\N
20044	MEMBRECOM	2020-11-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16644	\N	\N
20045	MEMBRECOM	2020-11-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16645	\N	\N
20046	MEMBRECOM	2020-11-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16646	\N	\N
20047	MEMBRECOM	2020-11-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16647	\N	\N
20048	MEMBRECOM	2020-11-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16648	\N	\N
20049	MEMBRECOM	2020-11-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16649	\N	\N
20050	PDTCOM	2020-11-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16650	\N	\N
20051	RAPCOM	2020-11-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16651	\N	\N
20052	MEMBRECOM	2020-11-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16652	\N	\N
20053	MEMBRECOM	2020-11-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16653	\N	\N
20054	MEMBRECOM	2020-11-19 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16654	\N	\N
20055	MEMBRECOM	2020-11-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16655	\N	\N
20056	MEMBRECOM	2020-11-19 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16656	\N	\N
20057	MEMBRECOM	2020-11-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16657	\N	\N
20058	MEMBRECOM	2020-11-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16658	\N	\N
20059	MEMBRECOM	2020-11-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16659	\N	\N
20060	MEMBRECOM	2020-11-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16660	\N	\N
20061	MEMBRECOM	2020-11-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16661	\N	\N
20062	MEMBRECOM	2020-11-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16662	\N	\N
20063	MEMBRECOM	2020-11-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16663	\N	\N
20064	PDTCOM	2020-11-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16664	\N	\N
20065	RAPCOM	2020-11-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16665	\N	\N
20066	MEMBRECOM	2020-11-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16666	\N	\N
20067	MEMBRECOM	2020-11-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16667	\N	\N
20068	MEMBRECOM	2020-11-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16668	\N	\N
20069	MEMBRECOM	2020-11-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16669	\N	\N
20070	MEMBRECOM	2020-11-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16670	\N	\N
20071	MEMBRECOM	2020-11-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16671	\N	\N
20072	MEMBRECOM	2020-11-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16672	\N	\N
18546	PDTCOM	2020-06-02 00:00:00	2020-09-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15531	\N	\N
18547	RAPCOM	2020-06-02 00:00:00	2020-09-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15529	\N	\N
18548	VICPDTCOM	2020-06-02 00:00:00	2020-09-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15537	\N	\N
18549	VICPDTCOM	2020-06-02 00:00:00	2020-09-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15540	\N	\N
18550	VICPDTCOM	2020-06-02 00:00:00	2020-09-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15533	\N	\N
18551	VICPDTCOM	2020-06-02 00:00:00	2020-09-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15526	\N	\N
18552	VICPDTCOM	2020-06-02 00:00:00	2020-09-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15543	\N	\N
18553	VICPDTCOM	2020-06-02 00:00:00	2020-09-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15524	\N	\N
18554	VICPDTCOM	2020-06-02 00:00:00	2020-09-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15544	\N	\N
18752	MEMBRECOM	2020-07-01 00:00:00	2020-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15778	\N	\N
18753	MEMBRECOM	2020-07-01 00:00:00	2020-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15779	\N	\N
18754	MEMBRECOM	2020-07-01 00:00:00	2020-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15780	\N	\N
18755	MEMBRECOM	2020-07-01 00:00:00	2020-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15781	\N	\N
18756	MEMBRECOM	2020-07-01 00:00:00	2020-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15782	\N	\N
18757	MEMBRECOM	2020-07-01 00:00:00	2020-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15783	\N	\N
18758	MEMBRECOM	2020-07-01 00:00:00	2020-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15784	\N	\N
18759	MEMBRECOM	2020-07-01 00:00:00	2020-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15785	\N	\N
18760	MEMBRECOM	2020-07-01 00:00:00	2020-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15786	\N	\N
18761	MEMBRECOM	2020-07-01 00:00:00	2020-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15787	\N	\N
18762	MEMBRECOM	2020-07-01 00:00:00	2020-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15788	\N	\N
18763	MEMBRECOM	2020-07-01 00:00:00	2020-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15789	\N	\N
18764	MEMBRECOM	2020-07-01 00:00:00	2020-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15790	\N	\N
18765	MEMBRECOM	2020-07-01 00:00:00	2020-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15791	\N	\N
18766	MEMBRECOM	2020-07-01 00:00:00	2020-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15792	\N	\N
18767	MEMBRECOM	2020-07-01 00:00:00	2020-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15793	\N	\N
18768	MEMBRECOM	2020-07-01 00:00:00	2020-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15794	\N	\N
18769	MEMBRECOM	2020-07-01 00:00:00	2020-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15795	\N	\N
18770	MEMBRECOM	2020-07-01 00:00:00	2020-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15796	\N	\N
18771	MEMBRECOM	2020-07-01 00:00:00	2020-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15797	\N	\N
18772	MEMBRECOM	2020-07-01 00:00:00	2020-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15798	\N	\N
18773	MEMBRECOM	2020-07-01 00:00:00	2020-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15799	\N	\N
18774	MEMBRECOM	2020-07-01 00:00:00	2020-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15800	\N	\N
18775	MEMBRECOM	2020-07-01 00:00:00	2020-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15801	\N	\N
18776	MEMBRECOM	2020-07-01 00:00:00	2020-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15802	\N	\N
18777	MEMBRECOM	2020-07-01 00:00:00	2020-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15803	\N	\N
18778	MEMBRECOM	2020-07-01 00:00:00	2020-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15804	\N	\N
18779	MEMBRECOM	2020-07-01 00:00:00	2020-07-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15805	\N	\N
20387	PDTCOM	2021-07-06 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16928	\N	\N
20388	RAPCOM	2021-07-06 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16944	\N	\N
20389	VICPDTCOM	2021-07-06 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16945	\N	\N
20390	VICPDTCOM	2021-07-06 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16948	\N	\N
20391	VICPDTCOM	2021-07-06 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16937	\N	\N
20392	VICPDTCOM	2021-07-06 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16941	\N	\N
20393	VICPDTCOM	2021-07-06 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16934	\N	\N
20394	VICPDTCOM	2021-07-06 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16947	\N	\N
20395	VICPDTCOM	2021-07-06 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16946	\N	\N
20396	SECRETCOM	2021-07-06 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16933	\N	\N
20397	SECRETCOM	2021-07-06 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16938	\N	\N
20398	VICPDTCOM	2021-07-06 00:00:00	2021-09-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16943	\N	\N
21072	PDTCOM	2023-03-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17437	\N	\N
21073	RAPCOM	2023-03-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17430	\N	\N
21074	VICPDTCOM	2023-03-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17422	\N	\N
21075	VICPDTCOM	2023-03-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17434	\N	\N
21076	VICPDTCOM	2023-03-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17431	\N	\N
21077	VICPDTCOM	2023-03-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17432	\N	\N
21078	VICPDTCOM	2023-03-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17428	\N	\N
21079	VICPDTCOM	2023-03-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17436	\N	\N
21080	VICPDTCOM	2023-03-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17426	\N	\N
21081	VICPDTCOM	2023-03-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17433	\N	\N
21082	VICPDTCOM	2023-03-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17418	\N	\N
21083	VICPDTCOM	2023-03-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17425	\N	\N
21660	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17982	2023-09-24 00:00:00	\N
21661	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17983	2023-09-24 00:00:00	\N
21671	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17993	2023-09-24 00:00:00	\N
21672	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17994	2023-09-24 00:00:00	\N
21673	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17995	2023-09-24 00:00:00	\N
21682	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18004	2023-09-24 00:00:00	\N
21697	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18019	2023-09-24 00:00:00	\N
21723	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18045	2023-09-24 00:00:00	\N
21724	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18046	2023-09-24 00:00:00	\N
21725	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18047	2023-09-24 00:00:00	\N
21726	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18048	2023-09-24 00:00:00	\N
21727	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18049	2023-09-24 00:00:00	\N
21728	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18050	2023-09-24 00:00:00	\N
21729	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18051	2023-09-24 00:00:00	\N
21730	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18052	2023-09-24 00:00:00	\N
21732	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18054	2023-09-24 00:00:00	\N
21733	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18055	2023-09-24 00:00:00	\N
21734	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18056	2023-09-24 00:00:00	\N
21735	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18057	2023-09-24 00:00:00	\N
21736	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18058	2023-09-24 00:00:00	\N
21737	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18059	2023-09-24 00:00:00	\N
21739	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18061	2023-09-24 00:00:00	\N
21740	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18062	2023-09-24 00:00:00	\N
21809	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18131	2023-09-24 00:00:00	\N
21810	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18132	2023-09-24 00:00:00	\N
21813	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18135	2023-09-24 00:00:00	\N
22425	VICPDTCOM	2023-10-05 00:00:00	\N	3	ACTIF	\N	\N	\N	\N	18511	\N	\N
22434	SECRETCOM	2023-10-05 00:00:00	\N	2	ACTIF	\N	\N	\N	\N	18517	\N	\N
17926	MEMBRECOM	2019-06-24 00:00:00	2019-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15079	\N	\N
18463	MEMBRECOM	2020-03-04 00:00:00	2020-06-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15526	\N	\N
18461	MEMBRECOM	2020-03-04 00:00:00	2020-06-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15524	\N	\N
18462	MEMBRECOM	2020-03-04 00:00:00	2020-09-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15525	\N	\N
18464	MEMBRECOM	2020-03-04 00:00:00	2020-09-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15527	\N	\N
18465	MEMBRECOM	2020-03-04 00:00:00	2020-09-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15528	\N	\N
18466	MEMBRECOM	2020-03-04 00:00:00	2020-06-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15529	\N	\N
18467	MEMBRECOM	2020-03-04 00:00:00	2020-09-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15530	\N	\N
18468	MEMBRECOM	2020-03-04 00:00:00	2020-06-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15531	\N	\N
18469	MEMBRECOM	2020-03-04 00:00:00	2020-09-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15532	\N	\N
18470	MEMBRECOM	2020-03-04 00:00:00	2020-06-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15533	\N	\N
18471	MEMBRECOM	2020-03-04 00:00:00	2020-09-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15534	\N	\N
18472	MEMBRECOM	2020-03-04 00:00:00	2020-09-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15535	\N	\N
18473	MEMBRECOM	2020-03-04 00:00:00	2020-09-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15536	\N	\N
18474	MEMBRECOM	2020-03-04 00:00:00	2020-06-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15537	\N	\N
18475	MEMBRECOM	2020-03-04 00:00:00	2020-09-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15538	\N	\N
18476	MEMBRECOM	2020-03-04 00:00:00	2020-09-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15539	\N	\N
18477	MEMBRECOM	2020-03-04 00:00:00	2020-06-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15540	\N	\N
18478	MEMBRECOM	2020-03-04 00:00:00	2020-09-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15541	\N	\N
18479	MEMBRECOM	2020-03-04 00:00:00	2020-09-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15542	\N	\N
18480	MEMBRECOM	2020-03-04 00:00:00	2020-06-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15543	\N	\N
18481	MEMBRECOM	2020-03-04 00:00:00	2020-06-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15544	\N	\N
19435	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16129	\N	\N
19441	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16005	\N	\N
19439	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16130	\N	\N
19440	VICPDTCOM	2020-10-07 00:00:00	2023-10-01 00:00:00	10	ANCIEN	\N	\N	\N	\N	16130	\N	\N
19442	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16019	\N	\N
19443	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16078	\N	\N
19444	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	412	\N	\N
19445	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	2530	\N	\N
19446	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3944	\N	\N
19447	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8126	\N	\N
19448	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8156	\N	\N
19449	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10202	\N	\N
19450	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	12861	\N	\N
19451	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13447	\N	\N
19452	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13450	\N	\N
19453	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13484	\N	\N
19454	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14210	\N	\N
19455	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16075	\N	\N
19456	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16079	\N	\N
19457	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	3633	\N	\N
19458	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	4318	\N	\N
19459	MEMBRECOM	2020-10-06 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8019	\N	\N
20073	MEMBRECOM	2020-11-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16673	\N	\N
20074	MEMBRECOM	2020-11-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16674	\N	\N
20075	MEMBRECOM	2020-11-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16675	\N	\N
20076	MEMBRECOM	2020-11-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16676	\N	\N
20077	MEMBRECOM	2020-11-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16677	\N	\N
20078	PDTCOM	2020-11-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16678	\N	\N
20079	RAPCOM	2020-11-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16679	\N	\N
20080	MEMBRECOM	2020-11-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16680	\N	\N
20081	MEMBRECOM	2020-11-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16681	\N	\N
20082	MEMBRECOM	2020-11-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16682	\N	\N
20083	MEMBRECOM	2020-11-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16683	\N	\N
20084	MEMBRECOM	2020-11-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16684	\N	\N
20085	MEMBRECOM	2020-12-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16685	\N	\N
20086	MEMBRECOM	2020-12-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16686	\N	\N
20087	MEMBRECOM	2020-12-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16687	\N	\N
20088	MEMBRECOM	2020-12-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16688	\N	\N
20089	MEMBRECOM	2020-12-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16689	\N	\N
20090	MEMBRECOM	2020-12-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16690	\N	\N
20091	MEMBRECOM	2020-12-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16691	\N	\N
20092	VICPDTCOM	2020-12-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16692	\N	\N
20093	RAPCOM	2020-12-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16693	\N	\N
20094	MEMBRECOM	2020-12-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16694	\N	\N
20095	MEMBRECOM	2020-12-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16695	\N	\N
20096	MEMBRECOM	2020-12-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16696	\N	\N
20097	MEMBRECOM	2020-12-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16697	\N	\N
20098	MEMBRECOM	2020-12-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16698	\N	\N
20099	PDTCOM	2020-12-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16699	\N	\N
20100	RAPCOM	2020-12-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16700	\N	\N
20101	MEMBRECOM	2020-12-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16701	\N	\N
20102	MEMBRECOM	2020-12-10 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16702	\N	\N
20103	MEMBRECOM	2020-12-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16703	\N	\N
20104	MEMBRECOM	2020-12-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16704	\N	\N
20105	MEMBRECOM	2020-12-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16705	\N	\N
20106	MEMBRECOM	2020-12-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16706	\N	\N
20107	MEMBRECOM	2020-12-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16707	\N	\N
20108	MEMBRECOM	2020-12-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16708	\N	\N
20109	MEMBRECOM	2020-12-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16709	\N	\N
20110	MEMBRECOM	2020-12-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16710	\N	\N
20111	MEMBRECOM	2020-12-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16711	\N	\N
20112	MEMBRECOM	2020-12-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16712	\N	\N
20113	MEMBRECOM	2020-12-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16713	\N	\N
20114	MEMBRECOM	2020-12-10 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16714	\N	\N
20115	MEMBRECOM	2020-12-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16715	\N	\N
20116	MEMBRECOM	2020-12-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16716	\N	\N
20117	MEMBRECOM	2020-12-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16717	\N	\N
20118	MEMBRECOM	2020-12-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16718	\N	\N
20119	MEMBRECOM	2020-12-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16719	\N	\N
20120	VICPDTCOM	2020-12-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16720	\N	\N
20121	MEMBRECOM	2020-12-15 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16721	\N	\N
20122	MEMBRECOM	2020-12-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16722	\N	\N
20123	MEMBRECOM	2020-12-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16723	\N	\N
20124	MEMBRECOM	2020-12-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16724	\N	\N
20125	MEMBRECOM	2020-12-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16725	\N	\N
20129	PDTCOM	2020-12-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16729	\N	\N
20127	MEMBRECOM	2020-12-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16727	\N	\N
20128	MEMBRECOM	2020-12-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16728	\N	\N
20130	RAPCOM	2020-12-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16730	\N	\N
20131	MEMBRECOM	2020-12-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16731	\N	\N
20132	MEMBRECOM	2020-12-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16732	\N	\N
20133	MEMBRECOM	2020-12-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16733	\N	\N
20134	MEMBRECOM	2020-12-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16734	\N	\N
20135	MEMBRECOM	2020-12-15 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16735	\N	\N
20136	MEMBRECOM	2021-01-28 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16736	\N	\N
20137	MEMBRECOM	2021-01-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16737	\N	\N
20138	MEMBRECOM	2021-01-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16738	\N	\N
20139	MEMBRECOM	2021-01-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16739	\N	\N
20140	MEMBRECOM	2021-01-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16740	\N	\N
20141	MEMBRECOM	2021-01-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16741	\N	\N
20142	MEMBRECOM	2021-01-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16742	\N	\N
20143	PDTCOM	2021-01-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16743	\N	\N
20144	RAPCOM	2021-01-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16744	\N	\N
20145	MEMBRECOM	2021-01-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16745	\N	\N
20146	MEMBRECOM	2021-01-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16746	\N	\N
20147	MEMBRECOM	2021-01-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16747	\N	\N
20148	MEMBRECOM	2021-01-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16748	\N	\N
20149	MEMBRECOM	2021-01-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16749	\N	\N
20150	MEMBRECOM	2021-01-28 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16750	\N	\N
20151	MEMBRECOM	2021-02-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16751	\N	\N
20152	MEMBRECOM	2021-02-04 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16752	\N	\N
20153	MEMBRECOM	2021-02-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16753	\N	\N
20154	MEMBRECOM	2021-02-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16754	\N	\N
20155	MEMBRECOM	2021-02-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16755	\N	\N
20156	MEMBRECOM	2021-02-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16756	\N	\N
20157	MEMBRECOM	2021-02-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16757	\N	\N
20158	PDTCOM	2021-02-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16758	\N	\N
20159	RAPCOM	2021-02-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16759	\N	\N
20160	MEMBRECOM	2021-02-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16760	\N	\N
20161	MEMBRECOM	2021-02-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16761	\N	\N
20162	MEMBRECOM	2021-02-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16762	\N	\N
20163	MEMBRECOM	2021-02-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16763	\N	\N
20164	MEMBRECOM	2021-02-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16764	\N	\N
20165	MEMBRECOM	2021-02-11 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16765	\N	\N
20166	MEMBRECOM	2021-02-11 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16766	\N	\N
20167	MEMBRECOM	2021-02-11 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16767	\N	\N
20168	MEMBRECOM	2021-02-11 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16768	\N	\N
20169	MEMBRECOM	2021-02-11 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16769	\N	\N
20170	MEMBRECOM	2021-02-11 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16770	\N	\N
20171	MEMBRECOM	2021-02-11 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16771	\N	\N
20172	VICPDTCOM	2021-02-11 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16772	\N	\N
18157	PDTCOM	2019-10-24 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15217	\N	\N
18158	VICPDTCOM	2019-10-24 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15203	\N	\N
18159	VICPDTCOM	2019-10-24 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15220	\N	\N
18160	VICPDTCOM	2019-10-24 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15207	\N	\N
18161	VICPDTCOM	2019-10-24 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15215	\N	\N
18162	VICPDTCOM	2019-10-24 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15226	\N	\N
18163	VICPDTCOM	2019-10-24 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15235	\N	\N
18164	VICPDTCOM	2019-10-24 00:00:00	2020-08-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15230	\N	\N
18165	VICPDTCOM	2019-10-24 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15229	\N	\N
18166	VICPDTCOM	2019-10-24 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15219	\N	\N
18167	VICPDTCOM	2019-10-24 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15233	\N	\N
18168	SECRETCOM	2019-10-24 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15205	\N	\N
18169	SECRETCOM	2019-10-24 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15223	\N	\N
18170	SECRETCOM	2019-10-24 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15240	\N	\N
18171	RAPCOM	2019-10-24 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15237	\N	\N
18172	RAPCOM	2019-10-24 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15211	\N	\N
18173	RAPCOM	2019-10-24 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15225	\N	\N
18174	RAPCOM	2019-10-24 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15212	\N	\N
13453	RAPCOM	2015-03-18 00:00:00	2021-01-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	11344	2015-03-18 17:03:18	2015-03-18 17:03:25
18529	PDTCOM	2020-05-19 00:00:00	2020-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15578	\N	\N
18530	VICPDTCOM	2020-05-19 00:00:00	2020-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15570	\N	\N
18531	VICPDTCOM	2020-05-19 00:00:00	2020-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15571	\N	\N
18532	VICPDTCOM	2020-05-19 00:00:00	2020-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15582	\N	\N
18533	VICPDTCOM	2020-05-19 00:00:00	2020-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15588	\N	\N
18534	VICPDTCOM	2020-05-19 00:00:00	2020-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15590	\N	\N
18535	VICPDTCOM	2020-05-19 00:00:00	2020-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15591	\N	\N
18536	RAPCOM	2020-05-19 00:00:00	2020-09-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15586	\N	\N
18537	PDTCOM	2020-05-13 00:00:00	2020-09-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15553	\N	\N
18538	RAPCOM	2020-05-13 00:00:00	2020-09-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15566	\N	\N
18539	VICPDTCOM	2020-05-13 00:00:00	2020-09-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15555	\N	\N
18540	VICPDTCOM	2020-05-13 00:00:00	2020-09-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15556	\N	\N
18541	VICPDTCOM	2020-05-13 00:00:00	2020-09-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15547	\N	\N
18542	VICPDTCOM	2020-05-13 00:00:00	2020-09-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15550	\N	\N
18543	VICPDTCOM	2020-05-13 00:00:00	2020-09-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15546	\N	\N
18544	VICPDTCOM	2020-05-13 00:00:00	2020-09-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15567	\N	\N
18545	VICPDTCOM	2020-05-13 00:00:00	2020-09-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15564	\N	\N
20175	MEMBRECOM	2021-02-11 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16775	\N	\N
20174	RAPCOM	2021-02-11 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16774	\N	\N
20176	MEMBRECOM	2021-02-11 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16776	\N	\N
20177	MEMBRECOM	2021-02-11 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16777	\N	\N
20178	MEMBRECOM	2021-02-11 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16778	\N	\N
20179	MEMBRECOM	2021-02-11 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16779	\N	\N
20180	VICPDTCOM	2021-02-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16780	\N	\N
20181	MEMBRECOM	2021-02-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16781	\N	\N
20182	MEMBRECOM	2021-02-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16782	\N	\N
20183	MEMBRECOM	2021-02-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16783	\N	\N
20184	MEMBRECOM	2021-02-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16784	\N	\N
20185	MEMBRECOM	2021-02-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16785	\N	\N
20186	MEMBRECOM	2021-02-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16786	\N	\N
20187	MEMBRECOM	2021-02-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16787	\N	\N
20188	RAPCOM	2021-02-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16788	\N	\N
20189	MEMBRECOM	2021-02-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16789	\N	\N
20190	MEMBRECOM	2021-02-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16790	\N	\N
20191	MEMBRECOM	2021-02-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16791	\N	\N
20192	MEMBRECOM	2021-02-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16792	\N	\N
20193	MEMBRECOM	2021-02-17 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16793	\N	\N
20194	MEMBRECOM	2021-03-10 00:00:00	2021-03-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16794	\N	\N
20195	MEMBRECOM	2021-03-10 00:00:00	2021-03-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16795	\N	\N
20196	MEMBRECOM	2021-03-10 00:00:00	2021-03-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16796	\N	\N
20197	MEMBRECOM	2021-03-10 00:00:00	2021-03-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16797	\N	\N
20198	MEMBRECOM	2021-03-10 00:00:00	2021-03-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16798	\N	\N
20199	MEMBRECOM	2021-03-10 00:00:00	2021-03-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16799	\N	\N
20200	MEMBRECOM	2021-03-10 00:00:00	2021-03-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16800	\N	\N
20201	VICPDTCOM	2021-03-10 00:00:00	2021-03-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16801	\N	\N
20202	MEMBRECOM	2021-03-10 00:00:00	2021-03-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16802	\N	\N
20203	RAPCOM	2021-03-10 00:00:00	2021-03-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16803	\N	\N
20204	MEMBRECOM	2021-03-10 00:00:00	2021-03-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16804	\N	\N
20205	MEMBRECOM	2021-03-10 00:00:00	2021-03-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16805	\N	\N
20206	MEMBRECOM	2021-03-10 00:00:00	2021-03-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16806	\N	\N
20207	MEMBRECOM	2021-03-10 00:00:00	2021-03-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16807	\N	\N
20208	MEMBRECOM	2021-03-02 00:00:00	2021-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16808	\N	\N
20209	MEMBRECOM	2021-03-02 00:00:00	2021-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16809	\N	\N
20210	MEMBRECOM	2021-03-02 00:00:00	2021-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16810	\N	\N
20211	MEMBRECOM	2021-03-02 00:00:00	2021-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16811	\N	\N
20212	MEMBRECOM	2021-03-02 00:00:00	2021-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16812	\N	\N
20213	MEMBRECOM	2021-03-02 00:00:00	2021-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16813	\N	\N
20214	MEMBRECOM	2021-03-02 00:00:00	2021-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16814	\N	\N
20215	VICPDTCOM	2021-03-02 00:00:00	2021-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16815	\N	\N
20216	MEMBRECOM	2021-03-02 00:00:00	2021-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16816	\N	\N
20217	MEMBRECOM	2021-03-02 00:00:00	2021-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16817	\N	\N
20218	RAPCOM	2021-03-02 00:00:00	2021-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16818	\N	\N
20219	MEMBRECOM	2021-03-02 00:00:00	2021-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16819	\N	\N
20220	MEMBRECOM	2021-03-02 00:00:00	2021-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16820	\N	\N
20221	MEMBRECOM	2021-03-02 00:00:00	2021-03-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16821	\N	\N
20222	MEMBRECOM	2021-03-04 00:00:00	2021-03-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16822	\N	\N
20223	MEMBRECOM	2021-03-04 00:00:00	2021-03-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16823	\N	\N
20224	MEMBRECOM	2021-03-04 00:00:00	2021-03-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16824	\N	\N
20225	MEMBRECOM	2021-03-04 00:00:00	2021-03-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16825	\N	\N
20226	MEMBRECOM	2021-03-04 00:00:00	2021-03-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16826	\N	\N
20227	MEMBRECOM	2021-03-04 00:00:00	2021-03-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16827	\N	\N
20228	MEMBRECOM	2021-03-04 00:00:00	2021-03-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16828	\N	\N
20229	VICPDTCOM	2021-03-04 00:00:00	2021-03-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16829	\N	\N
20230	RAPCOM	2021-03-04 00:00:00	2021-03-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16830	\N	\N
20231	MEMBRECOM	2021-03-04 00:00:00	2021-03-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16831	\N	\N
20232	MEMBRECOM	2021-03-04 00:00:00	2021-03-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16832	\N	\N
20233	MEMBRECOM	2021-03-04 00:00:00	2021-03-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16833	\N	\N
20234	MEMBRECOM	2021-03-04 00:00:00	2021-03-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16834	\N	\N
20235	MEMBRECOM	2021-03-04 00:00:00	2021-03-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16835	\N	\N
20236	MEMBRECOM	2021-03-23 00:00:00	2021-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16836	\N	\N
20237	MEMBRECOM	2021-03-23 00:00:00	2021-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16837	\N	\N
20238	MEMBRECOM	2021-03-23 00:00:00	2021-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16838	\N	\N
20239	MEMBRECOM	2021-03-23 00:00:00	2021-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16839	\N	\N
20240	MEMBRECOM	2021-03-23 00:00:00	2021-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16840	\N	\N
20241	MEMBRECOM	2021-03-23 00:00:00	2021-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16841	\N	\N
20242	MEMBRECOM	2021-03-23 00:00:00	2021-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16842	\N	\N
20243	PDTCOM	2021-03-23 00:00:00	2021-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16843	\N	\N
20244	RAPCOM	2021-03-23 00:00:00	2021-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16844	\N	\N
20245	MEMBRECOM	2021-03-23 00:00:00	2021-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16845	\N	\N
20246	MEMBRECOM	2021-03-23 00:00:00	2021-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16846	\N	\N
20247	MEMBRECOM	2021-03-23 00:00:00	2021-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16847	\N	\N
20248	MEMBRECOM	2021-03-23 00:00:00	2021-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16848	\N	\N
20249	MEMBRECOM	2021-03-23 00:00:00	2021-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16849	\N	\N
20250	MEMBRECOM	2021-03-23 00:00:00	2021-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16850	\N	\N
20251	MEMBRECOM	2021-03-23 00:00:00	2021-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16851	\N	\N
20252	MEMBRECOM	2021-03-23 00:00:00	2021-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16852	\N	\N
20253	MEMBRECOM	2021-03-23 00:00:00	2021-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16853	\N	\N
20254	MEMBRECOM	2021-03-23 00:00:00	2021-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16854	\N	\N
20255	MEMBRECOM	2021-03-23 00:00:00	2021-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16855	\N	\N
20256	MEMBRECOM	2021-03-23 00:00:00	2021-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16856	\N	\N
20257	PDTCOM	2021-03-23 00:00:00	2021-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16857	\N	\N
20258	RAPCOM	2021-03-23 00:00:00	2021-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16858	\N	\N
20259	MEMBRECOM	2021-03-23 00:00:00	2021-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16859	\N	\N
20260	MEMBRECOM	2021-03-23 00:00:00	2021-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16860	\N	\N
20261	MEMBRECOM	2021-03-23 00:00:00	2021-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16861	\N	\N
20262	MEMBRECOM	2021-03-23 00:00:00	2021-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16862	\N	\N
20263	MEMBRECOM	2021-03-23 00:00:00	2021-03-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16863	\N	\N
20276	MEMBRECOM	2021-05-12 00:00:00	2021-09-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16864	\N	\N
20277	MEMBRECOM	2021-05-12 00:00:00	2021-05-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16865	\N	\N
20278	MEMBRECOM	2021-05-12 00:00:00	2021-09-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16866	\N	\N
20279	MEMBRECOM	2021-05-12 00:00:00	2021-09-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16867	\N	\N
20280	MEMBRECOM	2021-05-12 00:00:00	2021-09-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16868	\N	\N
20281	MEMBRECOM	2021-05-12 00:00:00	2021-05-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16869	\N	\N
20282	MEMBRECOM	2021-05-12 00:00:00	2021-09-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16870	\N	\N
20283	MEMBRECOM	2021-05-12 00:00:00	2021-05-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16871	\N	\N
20284	MEMBRECOM	2021-05-12 00:00:00	2021-09-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16872	\N	\N
20285	MEMBRECOM	2021-05-12 00:00:00	2021-09-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16873	\N	\N
20286	MEMBRECOM	2021-05-12 00:00:00	2021-09-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16874	\N	\N
20287	MEMBRECOM	2021-05-12 00:00:00	2021-05-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16875	\N	\N
20288	MEMBRECOM	2021-05-12 00:00:00	2021-05-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16876	\N	\N
20289	MEMBRECOM	2021-05-12 00:00:00	2021-09-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16877	\N	\N
20290	MEMBRECOM	2021-05-12 00:00:00	2021-09-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16878	\N	\N
20291	MEMBRECOM	2021-05-12 00:00:00	2021-09-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16879	\N	\N
20292	MEMBRECOM	2021-05-12 00:00:00	2021-05-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16880	\N	\N
20293	MEMBRECOM	2021-05-12 00:00:00	2021-05-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16881	\N	\N
20294	MEMBRECOM	2021-05-12 00:00:00	2021-05-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16882	\N	\N
20295	MEMBRECOM	2021-05-12 00:00:00	2021-05-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16883	\N	\N
20296	MEMBRECOM	2021-05-12 00:00:00	2021-05-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16884	\N	\N
20297	MEMBRECOM	2021-05-12 00:00:00	2021-05-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16885	\N	\N
20314	MEMBRECOM	2021-06-03 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16890	\N	\N
19722	MEMBRECOM	2021-02-03 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16360	\N	\N
19723	MEMBRECOM	2021-02-03 00:00:00	2021-04-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16361	\N	\N
19724	MEMBRECOM	2021-02-03 00:00:00	2021-04-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16362	\N	\N
19725	MEMBRECOM	2021-02-03 00:00:00	2021-04-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16363	\N	\N
19726	MEMBRECOM	2021-02-03 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16364	\N	\N
19727	MEMBRECOM	2021-02-03 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16365	\N	\N
19728	MEMBRECOM	2021-02-03 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16366	\N	\N
19729	MEMBRECOM	2021-02-03 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16367	\N	\N
19730	MEMBRECOM	2021-02-03 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16368	\N	\N
19731	MEMBRECOM	2021-02-03 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16369	\N	\N
19732	MEMBRECOM	2021-02-03 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16370	\N	\N
19733	MEMBRECOM	2021-02-03 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16371	\N	\N
19734	MEMBRECOM	2021-02-03 00:00:00	2021-04-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16372	\N	\N
19735	MEMBRECOM	2021-02-03 00:00:00	2021-04-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16373	\N	\N
19736	MEMBRECOM	2021-02-03 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16374	\N	\N
19737	MEMBRECOM	2021-02-03 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16375	\N	\N
19738	MEMBRECOM	2021-02-03 00:00:00	2021-04-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16376	\N	\N
19739	MEMBRECOM	2021-02-03 00:00:00	2021-04-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16377	\N	\N
19740	MEMBRECOM	2021-02-03 00:00:00	2021-04-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16378	\N	\N
19741	MEMBRECOM	2021-02-03 00:00:00	2021-04-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16379	\N	\N
19742	MEMBRECOM	2021-02-03 00:00:00	2021-04-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16380	\N	\N
19743	MEMBRECOM	2021-02-03 00:00:00	2021-04-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16381	\N	\N
19744	MEMBRECOM	2021-02-03 00:00:00	2021-04-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16382	\N	\N
21071	MEMBRECOM	2023-03-01 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17438	\N	\N
21149	PDTCOM	2023-04-11 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17293	\N	\N
21150	RAPCOM	2023-04-11 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17283	\N	\N
21151	VICPDTCOM	2023-04-11 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17278	\N	\N
21152	VICPDTCOM	2023-04-11 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17276	\N	\N
21153	VICPDTCOM	2023-04-11 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17279	\N	\N
21154	VICPDTCOM	2023-04-11 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17285	\N	\N
21155	VICPDTCOM	2023-04-11 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17284	\N	\N
21156	VICPDTCOM	2023-04-11 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17288	\N	\N
21157	VICPDTCOM	2023-04-11 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17291	\N	\N
21158	VICPDTCOM	2023-04-11 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17295	\N	\N
21159	SECRETCOM	2023-04-11 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17287	\N	\N
21160	SECRETCOM	2023-04-11 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17292	\N	\N
22426	VICPDTCOM	2023-10-05 00:00:00	\N	4	ACTIF	\N	\N	\N	\N	18365	\N	\N
22428	VICPDTCOM	2023-10-05 00:00:00	\N	6	ACTIF	\N	\N	\N	\N	18599	\N	\N
22610	VICPDTCOM	2023-10-05 00:00:00	\N	4	ACTIF	\N	\N	\N	\N	18405	\N	\N
22611	SECRETCOM	2023-10-05 00:00:00	\N	4	ACTIF	\N	\N	\N	\N	18402	\N	\N
22612	VICPDTCOM	2023-10-05 00:00:00	\N	3	ACTIF	\N	\N	\N	\N	18400	\N	\N
22613	VICPDTCOM	2023-10-05 00:00:00	\N	10	ACTIF	\N	\N	\N	\N	18678	\N	\N
22614	VICPDTCOM	2023-10-05 00:00:00	\N	7	ACTIF	\N	\N	\N	\N	18589	\N	\N
22615	SECRETCOM	2023-10-05 00:00:00	\N	3	ACTIF	\N	\N	\N	\N	18584	\N	\N
22616	SECRETCOM	2023-10-05 00:00:00	\N	2	ACTIF	\N	\N	\N	\N	18583	\N	\N
22617	VICPDTCOM	2023-10-05 00:00:00	\N	2	ACTIF	\N	\N	\N	\N	18581	\N	\N
22618	PDTCOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18579	\N	\N
22619	SECRETCOM	2023-10-05 00:00:00	\N	1	ACTIF	\N	\N	\N	\N	18578	\N	\N
22620	VICPDTCOM	2023-10-05 00:00:00	\N	1	ACTIF	\N	\N	\N	\N	18576	\N	\N
22621	VICPDTCOM	2023-10-05 00:00:00	\N	5	ACTIF	\N	\N	\N	\N	18466	\N	\N
22622	SECRETCOM	2023-10-05 00:00:00	\N	5	ACTIF	\N	\N	\N	\N	18465	\N	\N
22623	VICPDTCOM	2023-10-05 00:00:00	\N	8	ACTIF	\N	\N	\N	\N	18350	\N	\N
22624	VICPDTCOM	2023-10-05 00:00:00	\N	9	ACTIF	\N	\N	\N	\N	18342	\N	\N
22625	VICPDTCOM	2023-10-05 00:00:00	\N	6	ACTIF	\N	\N	\N	\N	18609	\N	\N
23290	PDTCOM	2024-02-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19334	\N	\N
23291	VICPDTCOM	2024-02-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19337	\N	\N
23292	VICPDTCOM	2024-02-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19331	\N	\N
23293	RAPCOM	2024-02-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19346	\N	\N
23294	VICPDTCOM	2024-02-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19343	\N	\N
23295	VICPDTCOM	2024-02-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19342	\N	\N
23296	VICPDTCOM	2024-02-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19339	\N	\N
23297	VICPDTCOM	2024-02-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19347	\N	\N
23298	VICPDTCOM	2024-02-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19349	\N	\N
23299	VICPDTCOM	2024-02-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19351	\N	\N
23300	VICPDTCOM	2024-02-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19352	\N	\N
23301	VICPDTCOM	2024-02-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19353	\N	\N
23302	PDTCOM	2024-02-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19364	\N	\N
23303	RAPCOM	2024-02-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19373	\N	\N
23304	VICPDTCOM	2024-02-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19354	\N	\N
23305	VICPDTCOM	2024-02-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19357	\N	\N
23306	VICPDTCOM	2024-02-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19360	\N	\N
23307	VICPDTCOM	2024-02-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19365	\N	\N
23308	VICPDTCOM	2024-02-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19368	\N	\N
23309	VICPDTCOM	2024-02-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19361	\N	\N
23310	VICPDTCOM	2024-02-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19370	\N	\N
23311	VICPDTCOM	2024-02-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19374	\N	\N
23312	VICPDTCOM	2024-02-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19375	\N	\N
23313	VICPDTCOM	2024-02-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19372	\N	\N
8813	MEMBRECOM	2010-06-02 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7319	\N	\N
9429	MEMBRECOM	2011-07-01 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7917	\N	\N
11375	MEMBRECOM	2013-10-03 00:00:00	2020-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	9611	\N	\N
18861	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15886	\N	\N
20548	MEMBRECOM	2021-12-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17081	\N	\N
20597	VICPDTCOM	2021-12-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17117	\N	\N
20550	MEMBRECOM	2021-12-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17083	\N	\N
20598	VICPDTCOM	2021-12-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17118	\N	\N
20552	MEMBRECOM	2021-12-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17085	\N	\N
20553	MEMBRECOM	2021-12-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17086	\N	\N
20599	VICPDTCOM	2021-12-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17115	\N	\N
20555	MEMBRECOM	2021-12-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17088	\N	\N
20689	MEMBRECOM	2022-02-15 00:00:00	2022-09-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17172	\N	\N
20557	MEMBRECOM	2021-12-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17090	\N	\N
20600	VICPDTCOM	2021-12-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17080	\N	\N
20602	VICPDTCOM	2021-12-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17113	\N	\N
20560	MEMBRECOM	2021-12-01 00:00:00	2021-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17093	\N	\N
20592	PDTCOM	2021-12-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17091	\N	\N
20562	MEMBRECOM	2021-12-01 00:00:00	2021-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17095	\N	\N
20563	MEMBRECOM	2021-12-01 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17096	\N	\N
20564	MEMBRECOM	2021-12-01 00:00:00	2021-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17097	\N	\N
20565	MEMBRECOM	2021-12-01 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17098	\N	\N
20566	MEMBRECOM	2021-12-01 00:00:00	2021-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17099	\N	\N
20567	MEMBRECOM	2021-12-01 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17100	\N	\N
20568	MEMBRECOM	2021-12-01 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17101	\N	\N
20569	MEMBRECOM	2021-12-01 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17102	\N	\N
20570	MEMBRECOM	2021-12-01 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17103	\N	\N
20571	MEMBRECOM	2021-12-01 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17104	\N	\N
20572	MEMBRECOM	2021-12-01 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17105	\N	\N
20573	MEMBRECOM	2021-12-01 00:00:00	2021-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17106	\N	\N
20574	MEMBRECOM	2021-12-01 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17107	\N	\N
20575	MEMBRECOM	2021-12-01 00:00:00	2021-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17108	\N	\N
20576	MEMBRECOM	2021-12-01 00:00:00	2021-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17109	\N	\N
20593	RAPCOM	2021-12-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17082	\N	\N
20594	VICPDTCOM	2021-12-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17084	\N	\N
20579	MEMBRECOM	2021-12-01 00:00:00	2021-12-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17112	\N	\N
20703	MEMBRECOM	2022-09-10 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17183	\N	\N
20704	MEMBRECOM	2022-09-10 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17184	\N	\N
20595	VICPDTCOM	2021-12-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17087	\N	\N
20596	VICPDTCOM	2021-12-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17092	\N	\N
20601	VICPDTCOM	2021-12-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17089	\N	\N
20603	VICPDTCOM	2021-12-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17114	\N	\N
20799	PDTCOM	2023-01-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17191	\N	\N
20800	VICPDTCOM	2023-01-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17230	\N	\N
20801	VICPDTCOM	2023-01-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17200	\N	\N
20802	VICPDTCOM	2023-01-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17195	\N	\N
20803	VICPDTCOM	2023-01-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17207	\N	\N
20804	VICPDTCOM	2023-01-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17210	\N	\N
20805	RAPCOM	2023-01-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17218	\N	\N
20806	VICPDTCOM	2023-01-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17192	\N	\N
20807	VICPDTCOM	2023-01-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17203	\N	\N
20808	VICPDTCOM	2023-01-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17198	\N	\N
20809	VICPDTCOM	2023-01-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17212	\N	\N
20810	VICPDTCOM	2023-01-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17215	\N	\N
20825	MEMBRECOM	2023-02-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17275	\N	\N
20826	MEMBRECOM	2023-02-02 00:00:00	2023-04-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17276	\N	\N
20827	MEMBRECOM	2023-02-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17277	\N	\N
20828	MEMBRECOM	2023-02-02 00:00:00	2023-04-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17278	\N	\N
20829	MEMBRECOM	2023-02-02 00:00:00	2023-04-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17279	\N	\N
20830	MEMBRECOM	2023-02-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17280	\N	\N
20831	MEMBRECOM	2023-02-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17281	\N	\N
20832	MEMBRECOM	2023-02-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17282	\N	\N
20833	MEMBRECOM	2023-02-02 00:00:00	2023-04-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17283	\N	\N
20834	MEMBRECOM	2023-02-02 00:00:00	2023-04-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17284	\N	\N
20835	MEMBRECOM	2023-02-02 00:00:00	2023-04-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17285	\N	\N
20836	MEMBRECOM	2023-02-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17286	\N	\N
20837	MEMBRECOM	2023-02-02 00:00:00	2023-04-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17287	\N	\N
20838	MEMBRECOM	2023-02-02 00:00:00	2023-04-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17288	\N	\N
20839	MEMBRECOM	2023-02-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17289	\N	\N
20840	MEMBRECOM	2023-02-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17290	\N	\N
20841	MEMBRECOM	2023-02-02 00:00:00	2023-04-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17291	\N	\N
20842	MEMBRECOM	2023-02-02 00:00:00	2023-04-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17292	\N	\N
20843	MEMBRECOM	2023-02-02 00:00:00	2023-04-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17293	\N	\N
20844	MEMBRECOM	2023-02-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17294	\N	\N
20845	MEMBRECOM	2023-02-02 00:00:00	2023-04-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17295	\N	\N
20846	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17296	\N	\N
20847	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17297	\N	\N
20848	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17298	\N	\N
20849	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17299	\N	\N
20850	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17300	\N	\N
20851	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17301	\N	\N
20852	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17302	\N	\N
20853	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17303	\N	\N
20854	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17304	\N	\N
20855	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17305	\N	\N
20856	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17306	\N	\N
20857	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17307	\N	\N
20858	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17308	\N	\N
20859	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17309	\N	\N
20860	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17310	\N	\N
20861	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17311	\N	\N
20862	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17312	\N	\N
20863	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17313	\N	\N
20864	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17314	\N	\N
20865	MEMBRECOM	2023-02-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17315	\N	\N
20866	MEMBRECOM	2023-02-01 00:00:00	2023-02-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17316	\N	\N
21003	MEMBRECOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17296	\N	\N
21004	VICPDTCOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17304	\N	\N
21005	PDTCOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17313	\N	\N
21006	RAPCOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17307	\N	\N
21007	VICPDTCOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17299	\N	\N
21008	VICPDTCOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17300	\N	\N
21009	VICPDTCOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17302	\N	\N
21010	VICPDTCOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17311	\N	\N
21011	VICPDTCOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17312	\N	\N
21012	VICPDTCOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17314	\N	\N
21013	VICPDTCOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17316	\N	\N
21014	SECRETCOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17305	\N	\N
21015	SECRETCOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17306	\N	\N
21161	RAPCOM	2023-04-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17501	\N	\N
21162	MEMBRECOM	2023-03-28 00:00:00	2023-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17502	\N	\N
21163	MEMBRECOM	2023-03-28 00:00:00	2023-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17503	\N	\N
21164	MEMBRECOM	2023-03-28 00:00:00	2023-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17504	\N	\N
21165	MEMBRECOM	2023-03-28 00:00:00	2023-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17505	\N	\N
21166	MEMBRECOM	2023-03-28 00:00:00	2023-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17506	\N	\N
21167	MEMBRECOM	2023-03-28 00:00:00	2023-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17507	\N	\N
21168	MEMBRECOM	2023-03-28 00:00:00	2023-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17508	\N	\N
21169	MEMBRECOM	2023-03-28 00:00:00	2023-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17509	\N	\N
21170	MEMBRECOM	2023-03-28 00:00:00	2023-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17510	\N	\N
21171	MEMBRECOM	2023-03-28 00:00:00	2023-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17511	\N	\N
21172	MEMBRECOM	2023-03-28 00:00:00	2023-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17512	\N	\N
21173	MEMBRECOM	2023-03-28 00:00:00	2023-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17513	\N	\N
21174	MEMBRECOM	2023-03-28 00:00:00	2023-03-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17514	\N	\N
21175	PDTCOM	2023-04-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17504	\N	\N
21176	PDTCOM	2023-04-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17515	\N	\N
21177	MEMBRECOM	2023-04-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17516	\N	\N
21178	MEMBRECOM	2023-04-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17517	\N	\N
21179	RAPCOM	2023-04-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17518	\N	\N
21180	MEMBRECOM	2023-04-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17519	\N	\N
21181	MEMBRECOM	2023-04-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17520	\N	\N
21182	MEMBRECOM	2023-04-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17521	\N	\N
21183	MEMBRECOM	2023-04-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17522	\N	\N
21184	MEMBRECOM	2023-04-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17523	\N	\N
21185	MEMBRECOM	2023-04-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17524	\N	\N
21186	MEMBRECOM	2023-04-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17525	\N	\N
21187	MEMBRECOM	2023-04-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17526	\N	\N
21188	MEMBRECOM	2023-04-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17527	\N	\N
18081	MEMBRECOM	2019-10-02 00:00:00	2020-10-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15201	\N	\N
18844	MEMBRECOM	2020-08-07 00:00:00	2020-08-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15870	\N	\N
20448	VICPDTCOM	2021-10-20 00:00:00	2023-10-01 00:00:00	5	ANCIEN	\N	\N	\N	\N	8128	\N	\N
20449	SECRETCOM	2021-10-20 00:00:00	2023-10-01 00:00:00	14	ANCIEN	\N	\N	\N	\N	16036	\N	\N
21016	MEMBRECOM	2023-02-16 00:00:00	2023-02-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17395	\N	\N
21017	MEMBRECOM	2023-02-16 00:00:00	2023-02-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17396	\N	\N
21018	MEMBRECOM	2023-02-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17397	\N	\N
21019	MEMBRECOM	2023-02-16 00:00:00	2023-02-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17398	\N	\N
21020	MEMBRECOM	2023-02-16 00:00:00	2023-02-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17399	\N	\N
21021	MEMBRECOM	2023-02-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17400	\N	\N
21022	MEMBRECOM	2023-02-16 00:00:00	2023-02-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17401	\N	\N
21023	MEMBRECOM	2023-02-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17402	\N	\N
21024	MEMBRECOM	2023-02-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17403	\N	\N
21025	MEMBRECOM	2023-02-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17404	\N	\N
21026	MEMBRECOM	2023-02-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17405	\N	\N
21027	MEMBRECOM	2023-02-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17406	\N	\N
21028	MEMBRECOM	2023-02-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17407	\N	\N
21029	MEMBRECOM	2023-02-16 00:00:00	2023-02-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17408	\N	\N
21030	MEMBRECOM	2023-02-16 00:00:00	2023-02-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17409	\N	\N
21031	MEMBRECOM	2023-02-16 00:00:00	2023-02-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17410	\N	\N
21032	MEMBRECOM	2023-02-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17411	\N	\N
21033	MEMBRECOM	2023-02-16 00:00:00	2023-02-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17412	\N	\N
21034	MEMBRECOM	2023-02-16 00:00:00	2023-02-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17413	\N	\N
21035	MEMBRECOM	2023-02-16 00:00:00	2023-02-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17414	\N	\N
21036	MEMBRECOM	2023-02-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17415	\N	\N
21037	MEMBRECOM	2023-02-16 00:00:00	2023-02-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17416	\N	\N
21038	MEMBRECOM	2023-02-16 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17417	\N	\N
15983	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13487	2017-10-04 00:00:00	\N
21676	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17998	2023-09-24 00:00:00	\N
21746	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18068	2023-09-24 00:00:00	\N
21747	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18069	2023-09-24 00:00:00	\N
21748	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18070	2023-09-24 00:00:00	\N
21749	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18071	2023-09-24 00:00:00	\N
21750	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18072	2023-09-24 00:00:00	\N
21751	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18073	2023-09-24 00:00:00	\N
22212	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18532	\N	\N
22213	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18533	\N	\N
22214	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18534	\N	\N
22215	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18535	\N	\N
22216	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18536	\N	\N
22217	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18537	\N	\N
22218	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18538	\N	\N
22219	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18539	\N	\N
22220	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18540	\N	\N
22221	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18541	\N	\N
22222	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18542	\N	\N
22223	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18543	\N	\N
22224	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18544	\N	\N
22225	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18545	\N	\N
22226	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18546	\N	\N
22227	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18547	\N	\N
22228	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18548	\N	\N
22229	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18549	\N	\N
22230	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18550	\N	\N
22231	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18551	\N	\N
22232	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18552	\N	\N
22233	MEMBRECOM	2023-10-04 00:00:00	2023-12-31 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18553	\N	\N
22234	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18554	\N	\N
22235	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18555	\N	\N
22236	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18556	\N	\N
22237	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18557	\N	\N
22238	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18558	\N	\N
22239	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18559	\N	\N
22240	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18560	\N	\N
22241	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18561	\N	\N
22242	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18562	\N	\N
22243	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18563	\N	\N
22244	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18564	\N	\N
22245	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18565	\N	\N
22246	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18566	\N	\N
22247	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18567	\N	\N
22248	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18568	\N	\N
22273	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18593	\N	\N
22274	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18594	\N	\N
22275	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18595	\N	\N
23241	MEMBRECOM	2024-01-23 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19329	\N	\N
17905	MEMBRECOM	2019-06-26 00:00:00	2019-10-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15058	\N	\N
17906	MEMBRECOM	2019-06-26 00:00:00	2019-10-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15059	\N	\N
17907	MEMBRECOM	2019-06-26 00:00:00	2019-10-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15060	\N	\N
17908	MEMBRECOM	2019-06-26 00:00:00	2019-10-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15061	\N	\N
17909	MEMBRECOM	2019-06-26 00:00:00	2019-10-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15062	\N	\N
17910	MEMBRECOM	2019-06-26 00:00:00	2019-10-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15063	\N	\N
17911	MEMBRECOM	2019-06-26 00:00:00	2019-10-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15064	\N	\N
17912	MEMBRECOM	2019-06-26 00:00:00	2019-10-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15065	\N	\N
17913	MEMBRECOM	2019-06-26 00:00:00	2019-10-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15066	\N	\N
17914	MEMBRECOM	2019-06-26 00:00:00	2019-10-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15067	\N	\N
17915	MEMBRECOM	2019-06-26 00:00:00	2019-10-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15068	\N	\N
17916	MEMBRECOM	2019-06-26 00:00:00	2019-10-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15069	\N	\N
17917	MEMBRECOM	2019-06-26 00:00:00	2019-10-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15070	\N	\N
17918	MEMBRECOM	2019-06-26 00:00:00	2019-10-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15071	\N	\N
17919	MEMBRECOM	2019-06-26 00:00:00	2019-10-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15072	\N	\N
17920	MEMBRECOM	2019-06-26 00:00:00	2019-10-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15073	\N	\N
18931	MEMBRECOM	2020-10-01 00:00:00	2020-10-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15956	\N	\N
17922	MEMBRECOM	2019-06-26 00:00:00	2019-10-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15075	\N	\N
17923	MEMBRECOM	2019-06-26 00:00:00	2019-10-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15076	\N	\N
17924	MEMBRECOM	2019-06-26 00:00:00	2019-10-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15077	\N	\N
17925	MEMBRECOM	2019-06-26 00:00:00	2019-10-22 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15078	\N	\N
17943	MEMBRECOM	2019-07-01 00:00:00	2019-07-10 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15096	\N	\N
21189	MEMBRECOM	2023-04-14 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17528	\N	\N
16021	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13506	2017-10-04 00:00:00	\N
21679	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18001	2023-09-24 00:00:00	\N
21680	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18002	2023-09-24 00:00:00	\N
21681	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18003	2023-09-24 00:00:00	\N
21683	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18005	2023-09-24 00:00:00	\N
21690	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18012	2023-09-24 00:00:00	\N
21691	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18013	2023-09-24 00:00:00	\N
21692	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18014	2023-09-24 00:00:00	\N
21693	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18015	2023-09-24 00:00:00	\N
21696	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18018	2023-09-24 00:00:00	\N
21698	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18020	2023-09-24 00:00:00	\N
21699	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18021	2023-09-24 00:00:00	\N
21703	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18025	2023-09-24 00:00:00	\N
21704	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18026	2023-09-24 00:00:00	\N
21705	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18027	2023-09-24 00:00:00	\N
21706	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18028	2023-09-24 00:00:00	\N
21708	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18030	2023-09-24 00:00:00	\N
21709	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18031	2023-09-24 00:00:00	\N
21710	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18032	2023-09-24 00:00:00	\N
21711	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18033	2023-09-24 00:00:00	\N
21731	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18053	2023-09-24 00:00:00	\N
15912	MEMBRECOM	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13451	2017-10-04 00:00:00	\N
21738	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18060	2023-09-24 00:00:00	\N
21741	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18063	2023-09-24 00:00:00	\N
21742	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18064	2023-09-24 00:00:00	\N
21743	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18065	2023-09-24 00:00:00	\N
21744	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18066	2023-09-24 00:00:00	\N
21745	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18067	2023-09-24 00:00:00	\N
21752	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18074	2023-09-24 00:00:00	\N
21753	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18075	2023-09-24 00:00:00	\N
21754	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18076	2023-09-24 00:00:00	\N
21755	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18077	2023-09-24 00:00:00	\N
21756	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18078	2023-09-24 00:00:00	\N
21757	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18079	2023-09-24 00:00:00	\N
21758	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18080	2023-09-24 00:00:00	\N
21759	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18081	2023-09-24 00:00:00	\N
21760	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18082	2023-09-24 00:00:00	\N
21761	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18083	2023-09-24 00:00:00	\N
21764	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18086	2023-09-24 00:00:00	\N
21765	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18087	2023-09-24 00:00:00	\N
21768	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18090	2023-09-24 00:00:00	\N
21770	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18092	2023-09-24 00:00:00	\N
21776	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18098	2023-09-24 00:00:00	\N
21777	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18099	2023-09-24 00:00:00	\N
21778	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18100	2023-09-24 00:00:00	\N
21780	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18102	2023-09-24 00:00:00	\N
21781	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18103	2023-09-24 00:00:00	\N
21782	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18104	2023-09-24 00:00:00	\N
21794	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18116	2023-09-24 00:00:00	\N
21795	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18117	2023-09-24 00:00:00	\N
21796	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18118	2023-09-24 00:00:00	\N
21797	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18119	2023-09-24 00:00:00	\N
21798	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18120	2023-09-24 00:00:00	\N
21799	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18121	2023-09-24 00:00:00	\N
21800	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18122	2023-09-24 00:00:00	\N
21801	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18123	2023-09-24 00:00:00	\N
21937	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18257	2023-10-03 00:00:00	\N
21938	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18258	2023-10-03 00:00:00	\N
21939	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18259	2023-10-03 00:00:00	\N
21940	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18260	2023-10-03 00:00:00	\N
21941	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18261	2023-10-03 00:00:00	\N
21942	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18262	2023-10-03 00:00:00	\N
21943	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18263	2023-10-03 00:00:00	\N
21944	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18264	2023-10-03 00:00:00	\N
21945	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18265	2023-10-03 00:00:00	\N
21946	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18266	2023-10-03 00:00:00	\N
21947	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18267	2023-10-03 00:00:00	\N
21948	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18268	2023-10-03 00:00:00	\N
21949	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18269	2023-10-03 00:00:00	\N
21950	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18270	2023-10-03 00:00:00	\N
21951	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18271	2023-10-03 00:00:00	\N
21952	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18272	2023-10-03 00:00:00	\N
21953	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18273	2023-10-03 00:00:00	\N
21954	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18274	2023-10-03 00:00:00	\N
21955	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18275	2023-10-03 00:00:00	\N
21956	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18276	2023-10-03 00:00:00	\N
21957	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18277	2023-10-03 00:00:00	\N
21958	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18278	2023-10-03 00:00:00	\N
21959	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18279	2023-10-03 00:00:00	\N
21960	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18280	2023-10-03 00:00:00	\N
21961	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18281	2023-10-03 00:00:00	\N
21962	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18282	2023-10-03 00:00:00	\N
21963	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18283	2023-10-03 00:00:00	\N
21986	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18306	2023-10-03 00:00:00	\N
21987	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18307	2023-10-03 00:00:00	\N
21988	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18308	2023-10-03 00:00:00	\N
21989	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18309	2023-10-03 00:00:00	\N
21990	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18310	2023-10-03 00:00:00	\N
21991	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18311	2023-10-03 00:00:00	\N
21992	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18312	2023-10-03 00:00:00	\N
21993	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18313	2023-10-03 00:00:00	\N
21994	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18314	2023-10-03 00:00:00	\N
21995	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18315	2023-10-03 00:00:00	\N
21996	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18316	2023-10-03 00:00:00	\N
21997	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18317	2023-10-03 00:00:00	\N
21998	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18318	2023-10-03 00:00:00	\N
21999	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18319	2023-10-03 00:00:00	\N
22000	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18320	2023-10-03 00:00:00	\N
22001	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18321	2023-10-03 00:00:00	\N
22002	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18322	2023-10-03 00:00:00	\N
22003	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18323	2023-10-03 00:00:00	\N
22004	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18324	2023-10-03 00:00:00	\N
22005	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18325	2023-10-03 00:00:00	\N
22006	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18326	2023-10-03 00:00:00	\N
22007	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18327	2023-10-03 00:00:00	\N
22008	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18328	2023-10-03 00:00:00	\N
22009	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18329	2023-10-03 00:00:00	\N
18210	MEMBRECOM	2019-11-15 00:00:00	2019-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15300	\N	\N
18211	MEMBRECOM	2019-11-15 00:00:00	2019-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15301	\N	\N
18212	MEMBRECOM	2019-11-15 00:00:00	2019-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15302	\N	\N
18213	MEMBRECOM	2019-11-15 00:00:00	2019-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15303	\N	\N
18214	MEMBRECOM	2019-11-15 00:00:00	2019-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15304	\N	\N
18215	MEMBRECOM	2019-11-15 00:00:00	2019-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15305	\N	\N
18216	MEMBRECOM	2019-11-15 00:00:00	2019-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15306	\N	\N
18217	MEMBRECOM	2019-11-15 00:00:00	2019-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15307	\N	\N
18218	MEMBRECOM	2019-11-15 00:00:00	2019-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15308	\N	\N
18219	MEMBRECOM	2019-11-15 00:00:00	2019-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15309	\N	\N
18220	MEMBRECOM	2019-11-15 00:00:00	2019-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15310	\N	\N
18221	MEMBRECOM	2019-11-15 00:00:00	2019-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15311	\N	\N
18222	MEMBRECOM	2019-11-15 00:00:00	2019-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15312	\N	\N
18223	MEMBRECOM	2019-11-15 00:00:00	2019-11-20 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15313	\N	\N
18327	MEMBRECOM	2020-01-28 00:00:00	2020-02-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15407	\N	\N
18328	MEMBRECOM	2020-01-28 00:00:00	2020-02-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15408	\N	\N
18329	MEMBRECOM	2020-01-28 00:00:00	2020-02-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15409	\N	\N
18330	MEMBRECOM	2020-01-28 00:00:00	2020-02-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15410	\N	\N
18331	MEMBRECOM	2020-01-28 00:00:00	2020-02-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15411	\N	\N
18332	MEMBRECOM	2020-01-28 00:00:00	2020-02-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15412	\N	\N
18333	MEMBRECOM	2020-01-28 00:00:00	2020-02-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15413	\N	\N
18334	MEMBRECOM	2020-01-28 00:00:00	2020-02-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15414	\N	\N
18335	MEMBRECOM	2020-01-28 00:00:00	2020-02-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15415	\N	\N
18336	MEMBRECOM	2020-01-28 00:00:00	2020-02-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15416	\N	\N
18337	MEMBRECOM	2020-01-28 00:00:00	2020-02-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15417	\N	\N
18338	MEMBRECOM	2020-01-28 00:00:00	2020-02-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15418	\N	\N
18339	MEMBRECOM	2020-01-28 00:00:00	2020-02-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15419	\N	\N
18340	MEMBRECOM	2020-01-28 00:00:00	2020-02-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15420	\N	\N
18341	MEMBRECOM	2020-01-28 00:00:00	2020-02-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15421	\N	\N
18342	MEMBRECOM	2020-01-28 00:00:00	2020-02-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15422	\N	\N
18343	MEMBRECOM	2020-01-28 00:00:00	2020-02-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15423	\N	\N
18344	MEMBRECOM	2020-01-28 00:00:00	2020-02-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15424	\N	\N
18345	MEMBRECOM	2020-01-28 00:00:00	2020-02-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15425	\N	\N
18346	MEMBRECOM	2020-01-28 00:00:00	2020-02-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15426	\N	\N
18347	MEMBRECOM	2020-01-28 00:00:00	2020-02-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15427	\N	\N
18348	MEMBRECOM	2020-01-28 00:00:00	2020-02-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15428	\N	\N
18349	MEMBRECOM	2020-01-28 00:00:00	2020-02-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15429	\N	\N
18350	MEMBRECOM	2020-01-28 00:00:00	2020-02-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15430	\N	\N
18351	MEMBRECOM	2020-01-28 00:00:00	2020-02-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15431	\N	\N
18352	MEMBRECOM	2020-01-28 00:00:00	2020-02-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15432	\N	\N
18353	MEMBRECOM	2020-01-28 00:00:00	2020-02-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15433	\N	\N
18354	MEMBRECOM	2020-01-28 00:00:00	2020-02-05 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15434	\N	\N
18457	MEMBRECOM	2020-02-26 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15520	\N	\N
18458	MEMBRECOM	2020-02-26 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15521	\N	\N
19465	MEMBRECOM	2020-10-13 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16131	\N	\N
19466	MEMBRECOM	2020-10-13 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16132	\N	\N
19467	MEMBRECOM	2020-10-13 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16133	\N	\N
19497	PDTCOM	2020-10-23 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16160	\N	\N
19469	MEMBRECOM	2020-10-13 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16135	\N	\N
19470	MEMBRECOM	2020-10-13 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16136	\N	\N
19471	MEMBRECOM	2020-10-13 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16137	\N	\N
19499	RAPCOM	2020-10-23 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16162	\N	\N
19498	RAPCOM	2020-10-23 00:00:00	2020-11-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16161	\N	\N
19474	MEMBRECOM	2020-10-13 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16140	\N	\N
19475	MEMBRECOM	2020-10-13 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16141	\N	\N
19476	MEMBRECOM	2020-10-13 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16142	\N	\N
19477	MEMBRECOM	2020-10-13 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16143	\N	\N
19500	MEMBRECOM	2020-10-23 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16163	\N	\N
19501	MEMBRECOM	2020-10-23 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16164	\N	\N
19502	MEMBRECOM	2020-10-23 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16165	\N	\N
19503	MEMBRECOM	2020-10-23 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16166	\N	\N
19504	MEMBRECOM	2020-10-23 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16167	\N	\N
19505	MEMBRECOM	2020-10-23 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16168	\N	\N
19506	MEMBRECOM	2020-10-23 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16169	\N	\N
19507	MEMBRECOM	2020-10-23 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16170	\N	\N
19508	MEMBRECOM	2020-10-23 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16171	\N	\N
19509	MEMBRECOM	2020-10-23 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16172	\N	\N
19510	MEMBRECOM	2020-10-23 00:00:00	2021-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16173	\N	\N
19530	VICPDTCOM	2020-10-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16193	\N	\N
19531	RAPCOM	2020-10-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16194	\N	\N
19532	MEMBRECOM	2020-10-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16195	\N	\N
19533	MEMBRECOM	2020-10-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16196	\N	\N
19534	MEMBRECOM	2020-10-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16197	\N	\N
19535	MEMBRECOM	2020-10-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16198	\N	\N
19536	MEMBRECOM	2020-10-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16199	\N	\N
19537	MEMBRECOM	2020-10-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16200	\N	\N
19538	MEMBRECOM	2020-10-22 00:00:00	2021-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16201	\N	\N
19539	MEMBRECOM	2020-10-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16202	\N	\N
19540	MEMBRECOM	2020-10-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16203	\N	\N
19541	MEMBRECOM	2020-10-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16204	\N	\N
19542	MEMBRECOM	2020-10-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16205	\N	\N
19543	MEMBRECOM	2020-10-22 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	16206	\N	\N
20709	MEMBRECOM	2022-11-09 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8094	\N	\N
20710	VICPDTCOM	2022-11-09 00:00:00	2023-10-01 00:00:00	9	ANCIEN	\N	\N	\N	\N	8077	\N	\N
20969	RAPCOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17360	\N	\N
20970	VICPDTCOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17357	\N	\N
20971	VICPDTCOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17364	\N	\N
20972	VICPDTCOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17363	\N	\N
20973	SECRETCOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17355	\N	\N
20974	VICPDTCOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17366	\N	\N
20975	SECRETCOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17367	\N	\N
20976	VICPDTCOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17370	\N	\N
20977	VICPDTCOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17373	\N	\N
20978	PDTCOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17378	\N	\N
20979	VICPDTCOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17377	\N	\N
20980	VICPDTCOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17386	\N	\N
20981	VICPDTCOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17390	\N	\N
20982	SECRETCOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17376	\N	\N
20983	VICPDTCOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17387	\N	\N
20984	VICPDTCOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17388	\N	\N
20985	PDTCOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17317	\N	\N
20986	VICPDTCOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17322	\N	\N
20987	VICPDTCOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17326	\N	\N
20988	VICPDTCOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17328	\N	\N
20989	SECRETCOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17329	\N	\N
20990	VICPDTCOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17332	\N	\N
20991	VICPDTCOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17336	\N	\N
20992	VICPDTCOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17339	\N	\N
20993	SECRETCOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17341	\N	\N
20994	RAPCOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17342	\N	\N
20995	VICPDTCOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17340	\N	\N
20996	SECRETCOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17348	\N	\N
20997	VICPDTCOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17346	\N	\N
20998	RAPCOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17344	\N	\N
20999	RAPCOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17350	\N	\N
21000	VICPDTCOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17354	\N	\N
21001	VICPDTCOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17343	\N	\N
21002	VICPDTCOM	2023-02-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17351	\N	\N
22962	RAPCOM	2023-11-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18998	\N	\N
22963	VICPDTCOM	2023-11-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19000	\N	\N
22964	VICPDTCOM	2023-11-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19004	\N	\N
22965	VICPDTCOM	2023-11-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19013	\N	\N
22966	PDTCOM	2023-11-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19010	\N	\N
22967	VICPDTCOM	2023-11-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19003	\N	\N
22968	VICPDTCOM	2023-11-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19017	\N	\N
22969	VICPDTCOM	2023-11-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19019	\N	\N
22970	VICPDTCOM	2023-11-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19001	\N	\N
22971	VICPDTCOM	2023-11-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19018	\N	\N
22972	VICPDTCOM	2023-11-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18997	\N	\N
22973	VICPDTCOM	2023-11-21 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19016	\N	\N
17849	MEMBRECOM	2019-06-05 00:00:00	2019-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15002	\N	\N
17850	MEMBRECOM	2019-06-05 00:00:00	2019-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15003	\N	\N
17851	MEMBRECOM	2019-06-05 00:00:00	2019-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15004	\N	\N
17852	MEMBRECOM	2019-06-05 00:00:00	2019-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15005	\N	\N
17853	MEMBRECOM	2019-06-05 00:00:00	2019-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15006	\N	\N
17854	MEMBRECOM	2019-06-05 00:00:00	2019-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15007	\N	\N
17855	MEMBRECOM	2019-06-05 00:00:00	2019-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15008	\N	\N
17856	MEMBRECOM	2019-06-05 00:00:00	2019-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15009	\N	\N
17857	MEMBRECOM	2019-06-05 00:00:00	2019-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15010	\N	\N
17858	MEMBRECOM	2019-06-05 00:00:00	2019-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15011	\N	\N
17859	MEMBRECOM	2019-06-05 00:00:00	2019-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15012	\N	\N
17860	MEMBRECOM	2019-06-05 00:00:00	2019-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15013	\N	\N
17861	MEMBRECOM	2019-06-05 00:00:00	2019-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15014	\N	\N
17862	MEMBRECOM	2019-06-05 00:00:00	2019-06-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15015	\N	\N
17863	MEMBRECOM	2019-05-22 00:00:00	2019-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15016	\N	\N
17864	MEMBRECOM	2019-05-22 00:00:00	2019-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15017	\N	\N
17865	MEMBRECOM	2019-05-22 00:00:00	2019-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15018	\N	\N
17866	MEMBRECOM	2019-05-22 00:00:00	2019-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15019	\N	\N
17867	MEMBRECOM	2019-05-22 00:00:00	2019-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15020	\N	\N
17868	MEMBRECOM	2019-05-22 00:00:00	2019-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15021	\N	\N
17869	MEMBRECOM	2019-05-22 00:00:00	2019-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15022	\N	\N
17870	MEMBRECOM	2019-05-22 00:00:00	2019-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15023	\N	\N
17871	MEMBRECOM	2019-05-22 00:00:00	2019-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15024	\N	\N
17872	MEMBRECOM	2019-05-22 00:00:00	2019-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15025	\N	\N
17873	MEMBRECOM	2019-05-22 00:00:00	2019-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15026	\N	\N
17874	MEMBRECOM	2019-05-22 00:00:00	2019-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15027	\N	\N
17875	MEMBRECOM	2019-05-22 00:00:00	2019-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15028	\N	\N
17876	MEMBRECOM	2019-05-22 00:00:00	2019-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15029	\N	\N
17877	MEMBRECOM	2019-06-20 00:00:00	2019-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15030	\N	\N
17878	MEMBRECOM	2019-06-20 00:00:00	2019-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15031	\N	\N
17879	MEMBRECOM	2019-06-20 00:00:00	2019-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15032	\N	\N
17880	MEMBRECOM	2019-06-20 00:00:00	2019-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15033	\N	\N
17881	MEMBRECOM	2019-06-20 00:00:00	2019-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15034	\N	\N
17882	MEMBRECOM	2019-06-20 00:00:00	2019-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15035	\N	\N
17883	MEMBRECOM	2019-06-20 00:00:00	2019-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15036	\N	\N
17884	MEMBRECOM	2019-06-20 00:00:00	2019-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15037	\N	\N
17885	MEMBRECOM	2019-06-20 00:00:00	2019-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15038	\N	\N
17886	MEMBRECOM	2019-06-20 00:00:00	2019-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15039	\N	\N
17887	MEMBRECOM	2019-06-20 00:00:00	2019-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15040	\N	\N
17888	MEMBRECOM	2019-06-20 00:00:00	2019-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15041	\N	\N
17889	MEMBRECOM	2019-06-20 00:00:00	2019-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15042	\N	\N
17890	MEMBRECOM	2019-06-20 00:00:00	2019-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15043	\N	\N
17891	MEMBRECOM	2019-05-22 00:00:00	2019-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15044	\N	\N
17892	MEMBRECOM	2019-05-22 00:00:00	2019-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15045	\N	\N
17893	MEMBRECOM	2019-05-22 00:00:00	2019-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15046	\N	\N
17894	MEMBRECOM	2019-05-22 00:00:00	2019-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15047	\N	\N
17895	MEMBRECOM	2019-05-22 00:00:00	2019-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15048	\N	\N
17896	MEMBRECOM	2019-05-22 00:00:00	2019-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15049	\N	\N
17897	MEMBRECOM	2019-05-22 00:00:00	2019-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15050	\N	\N
17898	MEMBRECOM	2019-05-22 00:00:00	2019-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15051	\N	\N
17899	MEMBRECOM	2019-05-22 00:00:00	2019-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15052	\N	\N
17900	MEMBRECOM	2019-05-22 00:00:00	2019-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15053	\N	\N
17901	MEMBRECOM	2019-05-22 00:00:00	2019-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15054	\N	\N
17902	MEMBRECOM	2019-05-22 00:00:00	2019-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15055	\N	\N
17903	MEMBRECOM	2019-05-22 00:00:00	2019-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15056	\N	\N
17904	MEMBRECOM	2019-05-22 00:00:00	2019-06-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15057	\N	\N
17968	VICPDTCOM	2019-01-22 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14694	\N	\N
17969	VICPDTCOM	2019-01-22 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14710	\N	\N
17970	VICPDTCOM	2019-01-22 00:00:00	2019-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14693	\N	\N
20350	VICPDTCOM	2021-03-29 00:00:00	2021-04-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16914	\N	\N
20351	VICPDTCOM	2021-03-29 00:00:00	2021-04-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16915	\N	\N
20352	MEMBRECOM	2021-03-29 00:00:00	2021-04-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16916	\N	\N
20353	VICPDTCOM	2021-03-29 00:00:00	2021-04-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16917	\N	\N
20354	MEMBRECOM	2021-03-29 00:00:00	2021-04-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16918	\N	\N
20355	MEMBRECOM	2021-03-29 00:00:00	2021-04-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16919	\N	\N
20356	MEMBRECOM	2021-03-29 00:00:00	2021-04-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16920	\N	\N
20357	MEMBRECOM	2021-03-29 00:00:00	2021-04-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16921	\N	\N
20358	MEMBRECOM	2021-03-29 00:00:00	2021-04-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16922	\N	\N
20359	MEMBRECOM	2021-03-29 00:00:00	2021-04-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16923	\N	\N
20360	MEMBRECOM	2021-03-29 00:00:00	2021-04-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16924	\N	\N
20361	MEMBRECOM	2021-03-29 00:00:00	2021-04-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16925	\N	\N
20362	MEMBRECOM	2021-03-29 00:00:00	2021-04-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16926	\N	\N
20363	MEMBRECOM	2021-03-29 00:00:00	2021-04-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16927	\N	\N
20450	SECRETCOM	2021-10-29 00:00:00	2023-10-01 00:00:00	16	ANCIEN	\N	\N	\N	\N	13539	\N	\N
16081	MEMBRECOM	2017-10-04 00:00:00	2021-10-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13539	2017-10-04 21:04:08	\N
22010	MEMBRECOM	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18330	2023-10-03 00:00:00	\N
22602	SECRETCOM	2023-10-05 00:00:00	\N	5	ACTIF	\N	\N	\N	\N	18438	\N	\N
22603	SECRETCOM	2023-10-05 00:00:00	\N	2	ACTIF	\N	\N	\N	\N	18501	\N	\N
22604	SECRETCOM	2023-10-05 00:00:00	\N	1	ACTIF	\N	\N	\N	\N	18496	\N	\N
22605	SECRETCOM	2023-10-05 00:00:00	\N	3	ACTIF	\N	\N	\N	\N	18493	\N	\N
22606	SECRETCOM	2023-10-05 00:00:00	\N	4	ACTIF	\N	\N	\N	\N	18373	\N	\N
23650	MEMBRECOM	2024-03-07 00:00:00	2024-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19670	\N	\N
23651	MEMBRECOM	2024-03-07 00:00:00	2024-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19671	\N	\N
23652	MEMBRECOM	2024-03-07 00:00:00	2024-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19672	\N	\N
23653	MEMBRECOM	2024-03-07 00:00:00	2024-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19673	\N	\N
23654	MEMBRECOM	2024-03-07 00:00:00	2024-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19674	\N	\N
23655	MEMBRECOM	2024-03-07 00:00:00	2024-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19675	\N	\N
23656	MEMBRECOM	2024-03-07 00:00:00	2024-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19676	\N	\N
23657	MEMBRECOM	2024-03-07 00:00:00	2024-04-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19677	\N	\N
23658	MEMBRECOM	2024-03-07 00:00:00	2024-04-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19678	\N	\N
23659	MEMBRECOM	2024-03-07 00:00:00	2024-04-02 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19679	\N	\N
23660	MEMBRECOM	2024-03-07 00:00:00	2024-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19680	\N	\N
23661	MEMBRECOM	2024-03-07 00:00:00	2024-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19681	\N	\N
23662	MEMBRECOM	2024-03-07 00:00:00	2024-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19682	\N	\N
22682	MEMBRECOM	2023-10-20 00:00:00	2023-10-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18840	\N	\N
22683	MEMBRECOM	2023-10-20 00:00:00	2023-10-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18841	\N	\N
22684	MEMBRECOM	2023-10-20 00:00:00	2023-10-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18842	\N	\N
22685	MEMBRECOM	2023-10-20 00:00:00	2023-10-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18843	\N	\N
22686	MEMBRECOM	2023-10-20 00:00:00	2023-10-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18844	\N	\N
22691	MEMBRECOM	2023-10-20 00:00:00	2023-10-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18849	\N	\N
22688	MEMBRECOM	2023-10-20 00:00:00	2023-10-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18846	\N	\N
22689	MEMBRECOM	2023-10-20 00:00:00	2023-10-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18847	\N	\N
22690	MEMBRECOM	2023-10-20 00:00:00	2023-10-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18848	\N	\N
22692	MEMBRECOM	2023-10-20 00:00:00	2023-10-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18850	\N	\N
22693	MEMBRECOM	2023-10-20 00:00:00	2023-10-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18851	\N	\N
22694	MEMBRECOM	2023-10-20 00:00:00	2023-10-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18852	\N	\N
22695	MEMBRECOM	2023-10-20 00:00:00	2023-10-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18853	\N	\N
22696	MEMBRECOM	2023-10-20 00:00:00	2023-10-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18854	\N	\N
22867	VICPDTCOM	2023-11-09 00:00:00	2023-11-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18983	\N	\N
22868	RAPCOM	2023-11-09 00:00:00	2023-11-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18984	\N	\N
22979	VICPDTCOM	2023-11-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19026	\N	\N
22975	PDTCOM	2023-11-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19100	\N	\N
22976	VICPDTCOM	2023-11-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19041	\N	\N
22977	VICPDTCOM	2023-11-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19056	\N	\N
22978	VICPDTCOM	2023-11-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19022	\N	\N
22980	VICPDTCOM	2023-11-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19047	\N	\N
22981	VICPDTCOM	2023-11-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19053	\N	\N
22982	VICPDTCOM	2023-11-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19023	\N	\N
22983	VICPDTCOM	2023-11-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19038	\N	\N
22984	VICPDTCOM	2023-11-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19043	\N	\N
22985	VICPDTCOM	2023-11-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19029	\N	\N
22986	SECRETCOM	2023-11-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19024	\N	\N
22987	SECRETCOM	2023-11-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19028	\N	\N
22988	SECRETCOM	2023-11-09 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19051	\N	\N
23663	MEMBRECOM	2024-03-07 00:00:00	2024-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19683	\N	\N
23664	PDTCOM	2024-04-03 00:00:00	2024-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19677	\N	\N
23665	RAPCOM	2024-04-03 00:00:00	2024-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19679	\N	\N
23666	RAPCOM	2024-04-03 00:00:00	2024-04-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19678	\N	\N
17735	VICPDTCOM	2019-05-14 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14864	\N	\N
17736	VICPDTCOM	2019-05-14 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14850	\N	\N
17737	VICPDTCOM	2019-05-14 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14874	\N	\N
17738	VICPDTCOM	2019-05-14 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14867	\N	\N
17739	VICPDTCOM	2019-05-14 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14875	\N	\N
17740	VICPDTCOM	2019-05-14 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14858	\N	\N
17741	VICPDTCOM	2019-05-14 00:00:00	2019-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	14870	\N	\N
18839	MEMBRECOM	2020-08-03 00:00:00	2020-08-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15865	\N	\N
8556	MEMBRECOM	2009-12-17 00:00:00	2021-07-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7108	\N	\N
10481	MEMBRECOM	2012-02-22 00:00:00	2021-07-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8794	\N	\N
12763	MEMBRECOM	2014-11-20 00:00:00	2021-07-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	10711	\N	\N
20403	MEMBRECOM	2021-09-09 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16953	\N	\N
20404	MEMBRECOM	2021-09-09 00:00:00	2021-10-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16954	\N	\N
20446	VICPDTCOM	2021-10-20 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	7208	\N	\N
20447	SECRETCOM	2021-10-20 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13476	\N	\N
20647	PDTCOM	2021-12-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17065	\N	\N
20648	RAPCOM	2021-12-08 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17077	\N	\N
20694	MEMBRECOM	2022-07-06 00:00:00	2022-07-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17177	\N	\N
20695	MEMBRECOM	2022-07-06 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17178	\N	\N
20696	MEMBRECOM	2022-07-06 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17179	\N	\N
21059	PDTCOM	2023-03-01 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17396	\N	\N
21060	RAPCOM	2023-03-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17409	\N	\N
21061	VICPDTCOM	2023-03-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17395	\N	\N
21062	VICPDTCOM	2023-03-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17401	\N	\N
21063	VICPDTCOM	2023-03-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17408	\N	\N
21064	VICPDTCOM	2023-03-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17412	\N	\N
21065	VICPDTCOM	2023-03-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17410	\N	\N
21066	VICPDTCOM	2023-03-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17414	\N	\N
21067	VICPDTCOM	2023-03-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17416	\N	\N
21068	VICPDTCOM	2023-03-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17399	\N	\N
21069	SECRETCOM	2023-03-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17413	\N	\N
21070	SECRETCOM	2023-03-01 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17398	\N	\N
22020	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18340	\N	\N
22021	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18341	\N	\N
22432	VICPDTCOM	2023-10-05 00:00:00	\N	10	ACTIF	\N	\N	\N	\N	18672	\N	\N
22433	SECRETCOM	2023-10-05 00:00:00	\N	1	ACTIF	\N	\N	\N	\N	18509	\N	\N
23570	MEMBRECOM	2024-03-26 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19600	\N	\N
22907	MEMBRECOM	2023-11-14 00:00:00	2023-11-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19041	\N	\N
22908	MEMBRECOM	2023-11-14 00:00:00	2023-11-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19056	\N	\N
22909	MEMBRECOM	2023-11-14 00:00:00	2023-11-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19022	\N	\N
22910	MEMBRECOM	2023-11-14 00:00:00	2023-11-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19026	\N	\N
22911	MEMBRECOM	2023-11-14 00:00:00	2023-11-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19047	\N	\N
22912	MEMBRECOM	2023-11-14 00:00:00	2023-11-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19053	\N	\N
22913	MEMBRECOM	2023-11-14 00:00:00	2023-11-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19023	\N	\N
22914	MEMBRECOM	2023-11-14 00:00:00	2023-11-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19038	\N	\N
22915	MEMBRECOM	2023-11-14 00:00:00	2023-11-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19029	\N	\N
22916	MEMBRECOM	2023-11-14 00:00:00	2023-11-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19043	\N	\N
22917	MEMBRECOM	2023-11-14 00:00:00	2023-11-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19024	\N	\N
22918	MEMBRECOM	2023-11-14 00:00:00	2023-11-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19028	\N	\N
22919	MEMBRECOM	2023-11-14 00:00:00	2023-11-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19051	\N	\N
23509	MEMBRECOM	2024-03-20 00:00:00	2024-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19543	\N	\N
23510	MEMBRECOM	2024-03-20 00:00:00	2024-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19544	\N	\N
23511	MEMBRECOM	2024-03-20 00:00:00	2024-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19545	\N	\N
23512	MEMBRECOM	2024-03-20 00:00:00	2024-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19546	\N	\N
23513	MEMBRECOM	2024-03-20 00:00:00	2024-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19547	\N	\N
23514	MEMBRECOM	2024-03-20 00:00:00	2024-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19548	\N	\N
23515	MEMBRECOM	2024-03-20 00:00:00	2024-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19549	\N	\N
23516	MEMBRECOM	2024-03-20 00:00:00	2024-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19550	\N	\N
23517	MEMBRECOM	2024-03-20 00:00:00	2024-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19551	\N	\N
23518	MEMBRECOM	2024-03-20 00:00:00	2024-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19552	\N	\N
23519	MEMBRECOM	2024-03-20 00:00:00	2024-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19553	\N	\N
23520	MEMBRECOM	2024-03-20 00:00:00	2024-03-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19554	\N	\N
23521	MEMBRECOM	2024-03-20 00:00:00	2024-03-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19555	\N	\N
23522	MEMBRECOM	2024-03-20 00:00:00	2024-03-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19556	\N	\N
23523	MEMBRECOM	2024-03-20 00:00:00	2024-03-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19557	\N	\N
23524	MEMBRECOM	2024-03-20 00:00:00	2024-03-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19558	\N	\N
23525	MEMBRECOM	2024-03-20 00:00:00	2024-03-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19559	\N	\N
23526	MEMBRECOM	2024-03-20 00:00:00	2024-03-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19560	\N	\N
23527	MEMBRECOM	2024-03-20 00:00:00	2024-03-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19561	\N	\N
23528	MEMBRECOM	2024-03-20 00:00:00	2024-03-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19562	\N	\N
23529	MEMBRECOM	2024-03-20 00:00:00	2024-03-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19563	\N	\N
23530	MEMBRECOM	2024-03-20 00:00:00	2024-03-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19564	\N	\N
23531	MEMBRECOM	2024-03-20 00:00:00	2024-03-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19565	\N	\N
23532	MEMBRECOM	2024-03-20 00:00:00	2024-03-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19566	\N	\N
23533	MEMBRECOM	2024-03-20 00:00:00	2024-03-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19567	\N	\N
23534	MEMBRECOM	2024-03-20 00:00:00	2024-03-27 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19568	\N	\N
18079	MEMBRECOM	2019-09-20 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15199	\N	\N
18843	MEMBRECOM	2020-08-04 00:00:00	2020-08-08 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15869	\N	\N
22934	MEMBRECOM	2023-11-17 00:00:00	2023-11-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19072	\N	\N
22935	MEMBRECOM	2023-11-17 00:00:00	2023-11-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19073	\N	\N
22936	MEMBRECOM	2023-11-17 00:00:00	2023-11-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19074	\N	\N
22937	MEMBRECOM	2023-11-17 00:00:00	2023-11-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19075	\N	\N
22938	MEMBRECOM	2023-11-17 00:00:00	2023-11-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19076	\N	\N
22939	MEMBRECOM	2023-11-17 00:00:00	2023-11-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19077	\N	\N
22940	MEMBRECOM	2023-11-17 00:00:00	2023-11-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19078	\N	\N
22941	MEMBRECOM	2023-11-17 00:00:00	2023-11-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19079	\N	\N
22942	MEMBRECOM	2023-11-17 00:00:00	2023-11-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19080	\N	\N
22943	MEMBRECOM	2023-11-17 00:00:00	2023-11-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19081	\N	\N
22944	MEMBRECOM	2023-11-17 00:00:00	2023-11-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19082	\N	\N
22945	MEMBRECOM	2023-11-17 00:00:00	2023-11-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19083	\N	\N
22946	MEMBRECOM	2023-11-17 00:00:00	2023-11-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19084	\N	\N
22947	MEMBRECOM	2023-11-17 00:00:00	2023-11-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19085	\N	\N
22948	MEMBRECOM	2023-11-17 00:00:00	2023-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19086	\N	\N
22949	MEMBRECOM	2023-11-17 00:00:00	2023-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19087	\N	\N
22950	MEMBRECOM	2023-11-17 00:00:00	2023-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19088	\N	\N
22951	MEMBRECOM	2023-11-17 00:00:00	2023-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19089	\N	\N
22952	MEMBRECOM	2023-11-17 00:00:00	2023-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19090	\N	\N
22953	MEMBRECOM	2023-11-17 00:00:00	2023-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19091	\N	\N
22954	MEMBRECOM	2023-11-17 00:00:00	2023-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19092	\N	\N
22955	MEMBRECOM	2023-11-17 00:00:00	2023-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19093	\N	\N
22956	MEMBRECOM	2023-11-17 00:00:00	2023-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19094	\N	\N
22957	MEMBRECOM	2023-11-17 00:00:00	2023-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19095	\N	\N
22958	MEMBRECOM	2023-11-17 00:00:00	2023-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19096	\N	\N
22959	MEMBRECOM	2023-11-17 00:00:00	2023-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19097	\N	\N
22960	MEMBRECOM	2023-11-17 00:00:00	2023-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19098	\N	\N
22961	MEMBRECOM	2023-11-17 00:00:00	2023-11-18 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19099	\N	\N
23506	MEMBRECOM	2024-03-18 00:00:00	2024-03-26 00:00:00	\N	ANCIEN	\N	\N	\N	\N	19540	2024-03-18 00:00:00	\N
23685	MEMBRECOM	2024-04-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19698	\N	\N
23686	MEMBRECOM	2024-04-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19699	\N	\N
23687	MEMBRECOM	2024-04-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19700	\N	\N
23688	MEMBRECOM	2024-04-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19701	\N	\N
23689	MEMBRECOM	2024-04-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19702	\N	\N
23690	MEMBRECOM	2024-04-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19703	\N	\N
23691	MEMBRECOM	2024-04-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19704	\N	\N
23692	MEMBRECOM	2024-04-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19705	\N	\N
23698	MEMBRECOM	2024-04-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19711	\N	\N
23694	MEMBRECOM	2024-04-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19707	\N	\N
23695	MEMBRECOM	2024-04-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19708	\N	\N
23696	MEMBRECOM	2024-04-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19709	\N	\N
23697	MEMBRECOM	2024-04-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19710	\N	\N
23699	MEMBRECOM	2024-04-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19712	\N	\N
18049	MEMBRECOM	2019-07-24 00:00:00	2019-09-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15169	\N	\N
18050	MEMBRECOM	2019-07-24 00:00:00	2019-09-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15170	\N	\N
18051	MEMBRECOM	2019-07-24 00:00:00	2019-09-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15171	\N	\N
18052	MEMBRECOM	2019-07-24 00:00:00	2019-09-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15172	\N	\N
18053	MEMBRECOM	2019-07-24 00:00:00	2019-09-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15173	\N	\N
18054	MEMBRECOM	2019-07-24 00:00:00	2019-09-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15174	\N	\N
18055	MEMBRECOM	2019-07-24 00:00:00	2019-09-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15175	\N	\N
18056	MEMBRECOM	2019-07-24 00:00:00	2019-09-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15176	\N	\N
18057	MEMBRECOM	2019-07-24 00:00:00	2019-09-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15177	\N	\N
18058	MEMBRECOM	2019-07-24 00:00:00	2019-09-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15178	\N	\N
18059	MEMBRECOM	2019-07-24 00:00:00	2019-09-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15179	\N	\N
18060	MEMBRECOM	2019-07-24 00:00:00	2019-09-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15180	\N	\N
18061	MEMBRECOM	2019-07-24 00:00:00	2019-09-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15181	\N	\N
18062	MEMBRECOM	2019-07-24 00:00:00	2019-09-14 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15182	\N	\N
18063	MEMBRECOM	2019-07-24 00:00:00	2019-09-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15183	\N	\N
18064	MEMBRECOM	2019-07-24 00:00:00	2019-09-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15184	\N	\N
18065	MEMBRECOM	2019-07-24 00:00:00	2019-09-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15185	\N	\N
18066	MEMBRECOM	2019-07-24 00:00:00	2019-09-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15186	\N	\N
18067	MEMBRECOM	2019-07-24 00:00:00	2019-09-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15187	\N	\N
18068	MEMBRECOM	2019-07-24 00:00:00	2019-09-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15188	\N	\N
18069	MEMBRECOM	2019-07-24 00:00:00	2019-09-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15189	\N	\N
18070	MEMBRECOM	2019-07-24 00:00:00	2019-09-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15190	\N	\N
18071	MEMBRECOM	2019-07-24 00:00:00	2019-09-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15191	\N	\N
18072	MEMBRECOM	2019-07-24 00:00:00	2019-09-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15192	\N	\N
18073	MEMBRECOM	2019-07-24 00:00:00	2019-09-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15193	\N	\N
18074	MEMBRECOM	2019-07-24 00:00:00	2019-09-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15194	\N	\N
18075	MEMBRECOM	2019-07-24 00:00:00	2019-09-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15195	\N	\N
18076	MEMBRECOM	2019-07-24 00:00:00	2019-09-25 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15196	\N	\N
10658	MEMBRECOM	2012-10-23 00:00:00	2020-06-15 00:00:00	\N	ANCIEN	\N	\N	\N	\N	8946	\N	\N
18639	MEMBRECOM	2020-06-16 00:00:00	2020-06-16 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15676	\N	\N
18795	MEMBRECOM	2020-07-16 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15821	\N	\N
22508	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18727	\N	\N
22509	VICPDTCOM	2023-10-05 00:00:00	\N	10	ACTIF	\N	\N	\N	\N	18728	\N	\N
22510	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18729	\N	\N
22511	SECRETCOM	2023-10-05 00:00:00	\N	16	ACTIF	\N	\N	\N	\N	18730	\N	\N
22512	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18731	\N	\N
22513	MEMBRECOM	2023-10-05 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18732	\N	\N
22514	VICPDTCOM	2023-10-05 00:00:00	\N	2	ACTIF	\N	\N	\N	\N	18733	\N	\N
20451	MEMBRECOM	2021-11-18 00:00:00	2022-06-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16996	\N	\N
20455	MEMBRECOM	2021-11-18 00:00:00	2022-06-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17000	\N	\N
20453	MEMBRECOM	2021-11-18 00:00:00	2022-06-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16998	\N	\N
20454	MEMBRECOM	2021-11-18 00:00:00	2022-06-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	16999	\N	\N
20456	MEMBRECOM	2021-11-18 00:00:00	2022-06-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17001	\N	\N
20457	MEMBRECOM	2021-11-18 00:00:00	2022-06-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17002	\N	\N
20458	MEMBRECOM	2021-11-18 00:00:00	2022-06-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17003	\N	\N
20459	MEMBRECOM	2021-11-18 00:00:00	2022-06-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17004	\N	\N
20460	MEMBRECOM	2021-11-18 00:00:00	2022-06-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17005	\N	\N
20461	MEMBRECOM	2021-11-18 00:00:00	2022-06-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17006	\N	\N
20462	MEMBRECOM	2021-11-18 00:00:00	2022-06-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17007	\N	\N
20463	MEMBRECOM	2021-11-18 00:00:00	2022-06-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17008	\N	\N
20464	MEMBRECOM	2021-11-18 00:00:00	2022-06-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17009	\N	\N
20465	MEMBRECOM	2021-11-18 00:00:00	2022-06-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17010	\N	\N
20466	MEMBRECOM	2021-11-18 00:00:00	2022-06-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17011	\N	\N
20467	MEMBRECOM	2021-11-18 00:00:00	2022-06-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17012	\N	\N
20468	MEMBRECOM	2021-11-18 00:00:00	2022-06-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17013	\N	\N
20469	MEMBRECOM	2021-11-18 00:00:00	2022-06-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17014	\N	\N
20470	MEMBRECOM	2021-11-18 00:00:00	2022-06-07 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17015	\N	\N
20471	MEMBRECOM	2021-11-18 00:00:00	2021-11-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17016	\N	\N
20472	MEMBRECOM	2021-11-18 00:00:00	2021-11-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17017	\N	\N
20473	MEMBRECOM	2021-11-18 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17018	\N	\N
20474	MEMBRECOM	2021-11-18 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17019	\N	\N
20475	MEMBRECOM	2021-11-18 00:00:00	2021-11-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17020	\N	\N
20476	MEMBRECOM	2021-11-18 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17021	\N	\N
20477	MEMBRECOM	2021-11-18 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17022	\N	\N
20478	MEMBRECOM	2021-11-18 00:00:00	2021-11-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17023	\N	\N
20479	MEMBRECOM	2021-11-18 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17024	\N	\N
20480	MEMBRECOM	2021-11-18 00:00:00	2021-11-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17025	\N	\N
20481	MEMBRECOM	2021-11-18 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17026	\N	\N
20482	MEMBRECOM	2021-11-18 00:00:00	2021-11-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17027	\N	\N
20483	MEMBRECOM	2021-11-18 00:00:00	2021-11-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17028	\N	\N
20484	MEMBRECOM	2021-11-18 00:00:00	2021-11-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17029	\N	\N
20485	MEMBRECOM	2021-11-18 00:00:00	2021-11-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17030	\N	\N
20486	MEMBRECOM	2021-11-18 00:00:00	2021-11-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17031	\N	\N
20487	MEMBRECOM	2021-11-18 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17032	\N	\N
20488	MEMBRECOM	2021-11-18 00:00:00	2021-11-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17033	\N	\N
20489	MEMBRECOM	2021-11-18 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17034	\N	\N
20490	MEMBRECOM	2021-11-18 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17035	\N	\N
20491	MEMBRECOM	2021-11-18 00:00:00	2021-11-24 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17036	\N	\N
20492	MEMBRECOM	2021-11-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17037	\N	\N
20493	MEMBRECOM	2021-11-18 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17038	\N	\N
20494	MEMBRECOM	2021-11-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17039	\N	\N
20495	MEMBRECOM	2021-11-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17040	\N	\N
20496	MEMBRECOM	2021-11-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17041	\N	\N
20497	MEMBRECOM	2021-11-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17042	\N	\N
20498	MEMBRECOM	2021-11-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17043	\N	\N
20499	MEMBRECOM	2021-11-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17044	\N	\N
20500	MEMBRECOM	2021-11-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17045	\N	\N
20501	MEMBRECOM	2021-11-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17046	\N	\N
20502	MEMBRECOM	2021-11-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17047	\N	\N
20503	MEMBRECOM	2021-11-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17048	\N	\N
20504	MEMBRECOM	2021-11-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17049	\N	\N
20505	MEMBRECOM	2021-11-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17050	\N	\N
20506	MEMBRECOM	2021-11-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17051	\N	\N
20507	MEMBRECOM	2021-11-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17052	\N	\N
20508	MEMBRECOM	2021-11-18 00:00:00	2022-07-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17053	\N	\N
20509	MEMBRECOM	2021-11-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17054	\N	\N
20510	MEMBRECOM	2021-11-18 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	17055	\N	\N
20649	PDTCOM	2021-12-15 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17093	\N	\N
20650	RAPCOM	2021-12-15 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17120	\N	\N
20651	VICPDTCOM	2021-12-15 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17106	\N	\N
20652	VICPDTCOM	2021-12-15 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17108	\N	\N
20653	VICPDTCOM	2021-12-15 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17095	\N	\N
20654	VICPDTCOM	2021-12-15 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17097	\N	\N
20655	VICPDTCOM	2021-12-15 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17116	\N	\N
20656	VICPDTCOM	2021-12-15 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17124	\N	\N
20657	VICPDTCOM	2021-12-15 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17112	\N	\N
20658	VICPDTCOM	2021-12-15 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17099	\N	\N
20659	SECRETCOM	2021-12-15 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17123	\N	\N
20660	SECRETCOM	2021-12-15 00:00:00	2022-03-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17109	\N	\N
20661	MEMBRECOM	2021-12-16 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17168	\N	\N
20662	MEMBRECOM	2021-12-16 00:00:00	2023-10-01 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17169	\N	\N
20698	VICPDTCOM	2022-07-07 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	13544	\N	\N
20699	SECRETCOM	2022-07-07 00:00:00	2023-10-03 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17173	\N	\N
21639	VICPDTCOM	2023-07-06 00:00:00	2023-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17961	\N	\N
21640	RAPCOM	2023-07-06 00:00:00	2023-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17962	\N	\N
21641	MEMBRECOM	2023-07-06 00:00:00	2023-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17963	\N	\N
21642	MEMBRECOM	2023-07-06 00:00:00	2023-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17964	\N	\N
21643	MEMBRECOM	2023-07-06 00:00:00	2023-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17965	\N	\N
21644	MEMBRECOM	2023-07-06 00:00:00	2023-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17966	\N	\N
21645	MEMBRECOM	2023-07-06 00:00:00	2023-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17967	\N	\N
21646	MEMBRECOM	2023-07-06 00:00:00	2023-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17968	\N	\N
21647	MEMBRECOM	2023-07-06 00:00:00	2023-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17969	\N	\N
21648	MEMBRECOM	2023-07-06 00:00:00	2023-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17970	\N	\N
21649	MEMBRECOM	2023-07-06 00:00:00	2023-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17971	\N	\N
21650	MEMBRECOM	2023-07-06 00:00:00	2023-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17972	\N	\N
21651	MEMBRECOM	2023-07-06 00:00:00	2023-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17973	\N	\N
21652	MEMBRECOM	2023-07-06 00:00:00	2023-07-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17974	\N	\N
21653	PDTCOM	2023-06-28 00:00:00	2023-06-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17975	\N	\N
21654	RAPCOM	2023-06-28 00:00:00	2023-06-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17976	\N	\N
21655	MEMBRECOM	2023-06-28 00:00:00	2023-06-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17977	\N	\N
21656	MEMBRECOM	2023-06-28 00:00:00	2023-06-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17978	\N	\N
21657	MEMBRECOM	2023-06-28 00:00:00	2023-06-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17979	\N	\N
21658	MEMBRECOM	2023-06-28 00:00:00	2023-06-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17980	\N	\N
21659	MEMBRECOM	2023-06-28 00:00:00	2023-06-29 00:00:00	\N	ANCIEN	\N	\N	\N	\N	17981	\N	\N
23427	PDTCOM	2024-03-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19382	\N	\N
23428	RAPCOM	2024-03-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19388	\N	\N
23429	VICPDTCOM	2024-03-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19392	\N	\N
23430	VICPDTCOM	2024-03-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19381	\N	\N
23431	VICPDTCOM	2024-03-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19389	\N	\N
23432	VICPDTCOM	2024-03-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19386	\N	\N
23433	VICPDTCOM	2024-03-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19397	\N	\N
23434	VICPDTCOM	2024-03-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19393	\N	\N
23435	VICPDTCOM	2024-03-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19399	\N	\N
23436	VICPDTCOM	2024-03-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19400	\N	\N
23437	SECRETCOM	2024-03-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19379	\N	\N
23438	SECRETCOM	2024-03-06 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19383	\N	\N
23618	MEMBRECOM	2024-04-02 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	19643	\N	\N
17927	MEMBRECOM	2019-06-26 00:00:00	2019-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15080	\N	\N
17928	MEMBRECOM	2019-06-26 00:00:00	2019-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15081	\N	\N
17929	MEMBRECOM	2019-06-26 00:00:00	2019-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15082	\N	\N
17930	MEMBRECOM	2019-06-26 00:00:00	2019-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15083	\N	\N
17931	MEMBRECOM	2019-06-26 00:00:00	2019-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15084	\N	\N
17932	MEMBRECOM	2019-06-26 00:00:00	2019-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15085	\N	\N
17933	MEMBRECOM	2019-06-26 00:00:00	2019-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15086	\N	\N
17934	MEMBRECOM	2019-06-26 00:00:00	2019-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15087	\N	\N
17935	MEMBRECOM	2019-06-26 00:00:00	2019-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15088	\N	\N
17936	MEMBRECOM	2019-06-26 00:00:00	2019-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15089	\N	\N
17937	MEMBRECOM	2019-06-26 00:00:00	2019-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15090	\N	\N
17938	MEMBRECOM	2019-06-26 00:00:00	2019-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15091	\N	\N
17939	MEMBRECOM	2019-06-26 00:00:00	2019-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15092	\N	\N
17940	MEMBRECOM	2019-06-26 00:00:00	2019-07-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15093	\N	\N
18224	MEMBRECOM	2019-11-21 00:00:00	2019-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15314	\N	\N
18225	MEMBRECOM	2019-11-21 00:00:00	2019-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15315	\N	\N
18226	MEMBRECOM	2019-11-21 00:00:00	2019-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15316	\N	\N
18227	MEMBRECOM	2019-11-21 00:00:00	2019-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15317	\N	\N
18228	MEMBRECOM	2019-11-21 00:00:00	2019-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15318	\N	\N
18229	MEMBRECOM	2019-11-21 00:00:00	2019-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15319	\N	\N
18230	MEMBRECOM	2019-11-21 00:00:00	2019-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15320	\N	\N
18231	MEMBRECOM	2019-11-21 00:00:00	2019-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15321	\N	\N
18232	MEMBRECOM	2019-11-21 00:00:00	2019-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15322	\N	\N
18233	MEMBRECOM	2019-11-21 00:00:00	2019-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15323	\N	\N
18234	MEMBRECOM	2019-11-21 00:00:00	2019-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15324	\N	\N
18235	MEMBRECOM	2019-11-21 00:00:00	2019-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15325	\N	\N
18236	MEMBRECOM	2019-11-21 00:00:00	2019-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15326	\N	\N
18237	MEMBRECOM	2019-11-21 00:00:00	2019-11-28 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15327	\N	\N
18276	MEMBRECOM	2019-12-18 00:00:00	2020-01-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15356	\N	\N
18277	MEMBRECOM	2019-12-18 00:00:00	2020-01-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15357	\N	\N
18278	MEMBRECOM	2019-12-18 00:00:00	2020-01-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15358	\N	\N
18279	MEMBRECOM	2019-12-18 00:00:00	2020-01-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15359	\N	\N
18280	MEMBRECOM	2019-12-18 00:00:00	2020-01-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15360	\N	\N
18281	MEMBRECOM	2019-12-18 00:00:00	2020-01-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15361	\N	\N
18282	MEMBRECOM	2019-12-18 00:00:00	2020-01-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15362	\N	\N
18283	MEMBRECOM	2019-12-18 00:00:00	2020-01-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15363	\N	\N
18284	MEMBRECOM	2019-12-18 00:00:00	2020-01-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15364	\N	\N
18285	MEMBRECOM	2019-12-18 00:00:00	2020-01-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15365	\N	\N
18286	MEMBRECOM	2019-12-18 00:00:00	2020-01-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15366	\N	\N
18287	MEMBRECOM	2019-12-18 00:00:00	2020-01-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15367	\N	\N
18288	MEMBRECOM	2019-12-18 00:00:00	2020-01-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15368	\N	\N
18289	MEMBRECOM	2019-12-18 00:00:00	2020-01-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15369	\N	\N
18482	MEMBRECOM	2020-03-04 00:00:00	2020-09-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15545	\N	\N
18483	MEMBRECOM	2020-03-04 00:00:00	2020-05-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15546	\N	\N
18484	MEMBRECOM	2020-03-04 00:00:00	2020-05-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15547	\N	\N
18485	MEMBRECOM	2020-03-04 00:00:00	2020-09-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15548	\N	\N
18486	MEMBRECOM	2020-03-04 00:00:00	2020-09-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15549	\N	\N
18487	MEMBRECOM	2020-03-04 00:00:00	2020-05-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15550	\N	\N
18488	MEMBRECOM	2020-03-04 00:00:00	2020-09-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15551	\N	\N
18489	MEMBRECOM	2020-03-04 00:00:00	2020-09-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15552	\N	\N
18490	MEMBRECOM	2020-03-04 00:00:00	2020-05-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15553	\N	\N
18491	MEMBRECOM	2020-03-04 00:00:00	2020-09-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15554	\N	\N
18492	MEMBRECOM	2020-03-04 00:00:00	2020-05-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15555	\N	\N
18493	MEMBRECOM	2020-03-04 00:00:00	2020-05-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15556	\N	\N
18494	MEMBRECOM	2020-03-04 00:00:00	2020-09-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15557	\N	\N
18495	MEMBRECOM	2020-03-04 00:00:00	2020-09-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15558	\N	\N
18496	MEMBRECOM	2020-03-04 00:00:00	2020-09-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15559	\N	\N
18497	MEMBRECOM	2020-03-04 00:00:00	2020-09-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15560	\N	\N
18498	MEMBRECOM	2020-03-04 00:00:00	2020-09-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15561	\N	\N
18499	MEMBRECOM	2020-03-04 00:00:00	2020-09-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15562	\N	\N
18500	MEMBRECOM	2020-03-04 00:00:00	2020-09-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15563	\N	\N
18501	MEMBRECOM	2020-03-04 00:00:00	2020-05-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15564	\N	\N
18502	MEMBRECOM	2020-03-04 00:00:00	2020-09-17 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15565	\N	\N
18503	MEMBRECOM	2020-03-04 00:00:00	2020-05-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15566	\N	\N
18504	MEMBRECOM	2020-03-04 00:00:00	2020-05-12 00:00:00	\N	ANCIEN	\N	\N	\N	\N	15567	\N	\N
22210	MEMBRECOM	2023-10-04 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18530	\N	\N
22211	MEMBRECOM	2023-10-04 00:00:00	2023-10-04 00:00:00	\N	ANCIEN	\N	\N	\N	\N	18531	\N	\N
22630	MEMBRECOM	2023-10-10 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	18788	\N	\N
\.


--
-- Data for Name: fonmemdelega; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY fonmemdelega (fonmemdelid, fondelcod, fonmemdeldatdeb, fonmemdeldatfin, temvalcod, evelic, evelib, evelil, eveobs, memdelegaid, fonmemdelrngele, syscredat, sysmajdat) FROM stdin;
756	DELEGUEDEL	1999-10-13 00:00:00	1999-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	728	\N	\N	\N
757	DELEGUEDEL	1999-10-13 00:00:00	1999-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	729	\N	\N	\N
758	DELEGUEDEL	1999-10-13 00:00:00	1999-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	730	\N	\N	\N
759	DELEGUEDEL	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	731	\N	\N	\N
760	DELEGUEDEL	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	732	\N	\N	\N
761	DELEGUEDEL	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	733	\N	\N	\N
762	DELEGUEDEL	1999-10-13 00:00:00	1999-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	734	\N	\N	\N
763	DELEGUEDEL	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	735	\N	\N	\N
764	DELEGUEDEL	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	736	\N	\N	\N
765	DELEGUEDEL	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	737	\N	\N	\N
766	DELEGUEDEL	1999-10-13 00:00:00	1999-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	738	\N	\N	\N
767	DELEGUEDEL	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	739	\N	\N	\N
768	DELEGUEDEL	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	740	\N	\N	\N
769	DELEGUEDEL	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	741	\N	\N	\N
770	DELEGUEDEL	1999-10-13 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	742	\N	\N	\N
771	DELEGUEDEL	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	743	\N	\N	\N
735	DELEGUEDEL	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	710	\N	\N	\N
736	DELEGUEDEL	1999-10-13 00:00:00	1999-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	711	\N	\N	\N
738	DELEGUEDEL	1999-10-13 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	713	\N	\N	\N
739	DELEGUEDEL	1999-10-13 00:00:00	1999-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	714	\N	\N	\N
740	DELEGUEDEL	1999-10-13 00:00:00	1999-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	715	\N	\N	\N
741	DELEGUEDEL	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	716	\N	\N	\N
742	DELEGUEDEL	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	717	\N	\N	\N
743	DELEGUEDEL	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	718	\N	\N	\N
744	DELEGUEDEL	1999-10-13 00:00:00	1999-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	719	\N	\N	\N
745	DELEGUEDEL	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	720	\N	\N	\N
746	DELEGUEDEL	1999-10-13 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	721	\N	\N	\N
753	DELEGUEDEL	1999-10-13 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	725	\N	\N	\N
754	DELEGUEDEL	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	726	\N	\N	\N
755	DELEGUEDEL	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	727	\N	\N	\N
720	DELEGUEDEL	\N	1999-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	703	\N	\N	\N
721	DELEGUEDEL	\N	1999-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	691	\N	\N	\N
722	VICPDTDEL	1999-05-06 00:00:00	2001-10-24 00:00:00	ANCIEN	\N	\N	\N	\N	663	\N	\N	\N
723	VICPDTDEL	1999-05-06 00:00:00	2001-10-24 00:00:00	ANCIEN	\N	\N	\N	\N	666	\N	\N	\N
724	SECRETDEL	1999-05-06 00:00:00	2000-03-28 00:00:00	ANCIEN	\N	\N	\N	\N	667	\N	\N	\N
725	DELEGUEDEL	1999-10-05 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	704	\N	\N	\N
751	DELEGUEDEL	1999-10-13 00:00:00	1999-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	723	\N	\N	\N
732	DELEGUEDEL	1999-10-13 00:00:00	1999-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	708	\N	\N	\N
733	DELEGUEDEL	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	709	\N	\N	\N
706	VICPDTDEL	1999-02-17 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	691	\N	\N	\N
707	DELEGUEDEL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	692	\N	\N	\N
709	VICPDTDEL	2001-11-29 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	694	\N	\N	\N
710	SECRETDEL	1995-10-12 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	695	\N	\N	\N
712	DELEGUEDEL	1998-10-21 00:00:00	1998-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	699	\N	\N	\N
713	PDTDEL	1998-11-18 00:00:00	2000-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	699	\N	\N	\N
714	VICPDTDEL	1998-11-18 00:00:00	2000-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	651	\N	\N	\N
715	SECRETDEL	1998-11-18 00:00:00	2000-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	656	\N	\N	\N
716	SECRETDEL	1998-11-18 00:00:00	2000-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	653	\N	\N	\N
717	VICPDTDEL	1998-12-08 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	700	\N	\N	\N
718	VICPDTDEL	1998-12-08 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	701	\N	\N	\N
685	DELSUPDEL	1998-10-20 00:00:00	1998-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	684	\N	\N	\N
688	SECRETDEL	1998-10-21 00:00:00	1999-10-13 00:00:00	ANCIEN	\N	\N	\N	\N	588	\N	\N	\N
690	SECRETDEL	1998-10-21 00:00:00	1999-10-13 00:00:00	ANCIEN	\N	\N	\N	\N	589	\N	\N	\N
691	AUTFONDEL	1998-10-21 00:00:00	1999-10-13 00:00:00	ANCIEN	\N	\N	\N	\N	592	\N	\N	\N
703	DELTITDEL	1998-10-20 00:00:00	1998-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	689	\N	\N	\N
704	PDTDEL	1998-10-27 00:00:00	2001-10-23 00:00:00	ANCIEN	\N	\N	\N	\N	689	\N	\N	\N
696	VICPDTDEL	1998-10-27 00:00:00	2001-10-23 00:00:00	ANCIEN	\N	\N	\N	\N	684	\N	\N	\N
705	DELSUPDEL	1998-10-20 00:00:00	2001-10-23 00:00:00	ANCIEN	\N	\N	\N	\N	690	\N	\N	\N
582	DELTITDEL	1998-10-14 00:00:00	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	589	\N	\N	\N
583	DELTITDEL	1998-10-14 00:00:00	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	590	\N	\N	\N
584	DELTITDEL	1998-10-14 00:00:00	1999-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	591	\N	\N	\N
585	DELTITDEL	1998-10-14 00:00:00	1999-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	592	\N	\N	\N
586	DELTITDEL	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	593	\N	\N	\N
587	DELSUPDEL	1998-10-14 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	594	\N	\N	\N
588	DELSUPDEL	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	595	\N	\N	\N
589	DELSUPDEL	1998-10-14 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	596	\N	\N	\N
594	DELSUPDEL	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	601	\N	\N	\N
595	DELSUPDEL	1998-10-14 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	602	\N	\N	\N
597	DELEGUEDEL	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	604	\N	\N	\N
598	DELSUPDEL	1998-10-14 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	605	\N	\N	\N
601	DELTITDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	\N	608	\N	\N	\N
604	DELEGUEDEL	1998-10-14 00:00:00	1992-09-26 00:00:00	ANCIEN	\N	\N	\N	\N	611	\N	\N	\N
605	DELEGUEDEL	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	612	\N	\N	\N
606	DELEGUEDEL	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	613	\N	\N	\N
607	DELEGUEDEL	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	614	\N	\N	\N
608	DELEGUEDEL	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	615	\N	\N	\N
609	DELEGUEDEL	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	616	\N	\N	\N
610	DELEGUEDEL	1998-10-14 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	617	\N	\N	\N
614	DELEGUEDEL	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	621	\N	\N	\N
616	DELEGUEDEL	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	623	\N	\N	\N
631	DELEGUEDEL	1998-10-21 00:00:00	2000-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	640	\N	\N	\N
633	DELEGUEDEL	1998-10-21 00:00:00	1992-09-26 00:00:00	ANCIEN	\N	\N	\N	\N	642	\N	\N	\N
634	DELEGUEDEL	1998-10-21 00:00:00	2000-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	643	\N	\N	\N
635	DELTITDEL	1998-10-21 00:00:00	2000-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	644	\N	\N	\N
636	DELEGUEDEL	1998-10-21 00:00:00	2000-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	645	\N	\N	\N
637	DELEGUEDEL	1998-10-21 00:00:00	2000-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	646	\N	\N	\N
638	DELEGUEDEL	1998-10-21 00:00:00	2000-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	647	\N	\N	\N
639	DELEGUEDEL	1998-10-21 00:00:00	2000-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	648	\N	\N	\N
643	DELEGUEDEL	1998-10-21 00:00:00	2000-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	650	\N	\N	\N
645	DELEGUEDEL	1998-10-21 00:00:00	1998-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	651	\N	\N	\N
646	DELEGUEDEL	1998-10-21 00:00:00	2000-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	652	\N	\N	\N
647	DELEGUEDEL	1998-10-21 00:00:00	1998-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	653	\N	\N	\N
648	DELEGUEDEL	1998-10-21 00:00:00	2000-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	654	\N	\N	\N
649	DELEGUEDEL	1998-10-21 00:00:00	2000-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	655	\N	\N	\N
650	DELEGUEDEL	1998-10-21 00:00:00	1998-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	656	\N	\N	\N
652	DELTITDEL	1998-10-21 00:00:00	2001-10-24 00:00:00	ANCIEN	\N	\N	\N	\N	658	\N	\N	\N
654	DELTITDEL	1998-10-21 00:00:00	2001-10-24 00:00:00	ANCIEN	\N	\N	\N	\N	660	\N	\N	\N
655	DELTITDEL	1998-10-21 00:00:00	2001-10-24 00:00:00	ANCIEN	\N	\N	\N	\N	661	\N	\N	\N
656	DELTITDEL	1998-10-21 00:00:00	2001-10-24 00:00:00	ANCIEN	\N	\N	\N	\N	662	\N	\N	\N
657	DELTITDEL	1998-10-21 00:00:00	1999-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	663	\N	\N	\N
658	DELTITDEL	1998-10-21 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	664	\N	\N	\N
659	DELTITDEL	1998-10-21 00:00:00	2001-10-24 00:00:00	ANCIEN	\N	\N	\N	\N	665	\N	\N	\N
660	DELTITDEL	1998-10-21 00:00:00	1999-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	666	\N	\N	\N
661	DELTITDEL	1998-10-21 00:00:00	1999-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	667	\N	\N	\N
662	DELTITDEL	1998-10-21 00:00:00	2001-10-24 00:00:00	ANCIEN	\N	\N	\N	\N	668	\N	\N	\N
663	DELTITDEL	1998-10-21 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	669	\N	\N	\N
664	DELTITDEL	1998-10-21 00:00:00	2001-10-24 00:00:00	ANCIEN	\N	\N	\N	\N	670	\N	\N	\N
665	DELTITDEL	1998-10-21 00:00:00	2001-10-24 00:00:00	ANCIEN	\N	\N	\N	\N	671	\N	\N	\N
666	PDTDEL	1998-10-20 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	564	\N	\N	\N
667	VICPDTDEL	1998-10-20 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	571	\N	\N	\N
668	VICPDTDEL	1998-10-20 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	572	\N	\N	\N
670	VICPDTDEL	1998-10-20 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	576	\N	\N	\N
671	SECRETDEL	1998-10-20 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	580	\N	\N	\N
672	SECRETDEL	1998-10-20 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	\N	566	\N	\N	\N
701	DELTITDEL	1998-10-20 00:00:00	1998-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	688	\N	\N	\N
675	DELTITDEL	1998-10-20 00:00:00	2001-10-23 00:00:00	ANCIEN	\N	\N	\N	\N	674	\N	\N	\N
676	DELTITDEL	1998-10-20 00:00:00	2001-10-23 00:00:00	ANCIEN	\N	\N	\N	\N	675	\N	\N	\N
699	DELTITDEL	1998-10-20 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	673	\N	\N	\N
700	VICPDTDEL	1998-10-27 00:00:00	2001-10-23 00:00:00	ANCIEN	\N	\N	\N	\N	680	\N	\N	\N
679	DELSUPDEL	1998-10-20 00:00:00	2001-10-23 00:00:00	ANCIEN	\N	\N	\N	\N	678	\N	\N	\N
680	DELSUPDEL	1998-10-20 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	679	\N	\N	\N
681	DELSUPDEL	1998-10-20 00:00:00	1998-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	680	\N	\N	\N
702	SECRETGENDEL	1998-10-27 00:00:00	2001-10-23 00:00:00	ANCIEN	\N	\N	\N	\N	688	\N	\N	\N
684	DELSUPDEL	1998-10-20 00:00:00	2001-10-23 00:00:00	ANCIEN	\N	\N	\N	\N	683	\N	\N	\N
181	DELEGUEDEL	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'evaluation de la legislation/ 	181	\N	\N	\N
182	DELEGUEDEL	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'evaluation de la legislation/ 	182	\N	\N	\N
183	DELEGUEDEL	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Problemes demographiques/ Office parlementaire d'evaluation de la legislation/ 	183	\N	\N	\N
184	DELEGUEDEL	\N	1998-10-02 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'evaluation de la legislation/ 	184	\N	\N	\N
185	DELEGUEDEL	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'evaluation de la legislation/ 	185	\N	\N	\N
186	DELEGUEDEL	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'evaluation de la legislation/ 	186	\N	\N	\N
187	DELEGUEDEL	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'evaluation de la legislation/ 	187	\N	\N	\N
188	DELEGUEDEL	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'evaluation de la legislation/ 	188	\N	\N	\N
504	DELEGUEDEL	1998-10-14 00:00:00	2000-10-16 00:00:00	ANCIEN	\N	\N	\N	\N	509	\N	\N	\N
505	DELEGUEDEL	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	510	\N	\N	\N
538	VICPDTDEL	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	544	\N	\N	\N
514	DELEGUEDEL	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	520	\N	\N	\N
511	DELEGUEDEL	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	517	\N	\N	\N
512	DELEGUEDEL	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	518	\N	\N	\N
516	DELTITDEL	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	522	\N	\N	\N
518	SECRETDEL	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	524	\N	\N	\N
519	DELEGUEDEL	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	525	\N	\N	\N
521	DELEGUEDEL	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	527	\N	\N	\N
523	DELEGUEDEL	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	529	\N	\N	\N
525	DELEGUEDEL	1998-10-14 00:00:00	1999-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	531	\N	\N	\N
527	DELEGUEDEL	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	533	\N	\N	\N
529	DELEGUEDEL	1998-10-14 00:00:00	2000-10-24 00:00:00	ANCIEN	\N	\N	\N	\N	535	\N	\N	\N
531	DELEGUEDEL	1998-10-14 00:00:00	1998-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	537	\N	\N	\N
533	DELEGUEDEL	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	539	\N	\N	\N
535	DELEGUEDEL	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	541	\N	\N	\N
537	VICPDTDEL	1998-10-14 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	543	\N	\N	\N
539	VICPDTDEL	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	545	\N	\N	\N
540	SECRETDEL	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	546	\N	\N	\N
541	DELEGUEDEL	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	547	\N	\N	\N
542	DELEGUEDEL	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	548	\N	\N	\N
543	PDTDEL	1998-10-14 00:00:00	1999-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	549	\N	\N	\N
545	SECRETDEL	1998-10-14 00:00:00	1998-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	551	\N	\N	\N
546	DELEGUEDEL	1998-10-14 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	552	\N	\N	\N
547	DELTITDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	\N	553	\N	\N	\N
548	DELEGUEDEL	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	554	\N	\N	\N
549	DELEGUEDEL	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	555	\N	\N	\N
550	VICPDTDEL	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	556	\N	\N	\N
551	DELEGUEDEL	1998-10-14 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	557	\N	\N	\N
552	DELEGUEDEL	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	558	\N	\N	\N
553	DELEGUEDEL	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	559	\N	\N	\N
554	DELEGUEDEL	1998-10-14 00:00:00	1999-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	560	\N	\N	\N
555	DELEGUEDEL	1998-10-14 00:00:00	2000-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	561	\N	\N	\N
557	DELEGUEDEL	1998-10-14 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	563	\N	\N	\N
558	DELEGUEDEL	1998-10-14 00:00:00	1998-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	564	\N	\N	\N
559	DELEGUEDEL	1998-10-14 00:00:00	2000-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	565	\N	\N	\N
560	DELEGUEDEL	1998-10-14 00:00:00	1998-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	566	\N	\N	\N
567	DELEGUEDEL	1998-10-14 00:00:00	1998-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	573	\N	\N	\N
562	DELEGUEDEL	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	568	\N	\N	\N
563	DELEGUEDEL	1998-10-14 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	569	\N	\N	\N
565	DELEGUEDEL	1998-10-14 00:00:00	1998-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	571	\N	\N	\N
566	DELEGUEDEL	1998-10-14 00:00:00	1998-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	572	\N	\N	\N
568	DELEGUEDEL	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	574	\N	\N	\N
581	DELTITDEL	1998-10-14 00:00:00	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	588	\N	\N	\N
570	DELEGUEDEL	1998-10-14 00:00:00	1998-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	576	\N	\N	\N
571	DELEGUEDEL	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	577	\N	\N	\N
577	DELEGUEDEL	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	583	\N	\N	\N
574	DELEGUEDEL	1998-10-14 00:00:00	1998-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	580	\N	\N	\N
575	DELEGUEDEL	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	581	\N	\N	\N
578	DELTITDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	\N	584	\N	\N	\N
580	DELTITDEL	1998-10-14 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	587	\N	\N	\N
147	DELSUPDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Choix scientifiques et technologiques (suppleant)/ Office parlementaire d'evaluation de la legislation/ 	147	\N	\N	\N
149	DELSUPDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	choix scientifiques et technologiques (suppleant)/ 	149	\N	\N	\N
151	DELSUPDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Choix scientifiques et technologiques (suppleant)/ 	151	\N	\N	\N
1003	DELEGUEDEL	2001-10-10 00:00:00	2001-10-30 00:00:00	ANCIEN	\N	\N	\N	\N	909	\N	\N	\N
1004	DELEGUEDEL	2001-10-10 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	910	\N	\N	\N
1005	DELEGUEDEL	2001-10-10 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	911	\N	\N	\N
1006	DELEGUEDEL	2001-10-10 00:00:00	2001-10-30 00:00:00	ANCIEN	\N	\N	\N	\N	912	\N	\N	\N
1007	DELEGUEDEL	2001-10-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	913	\N	\N	\N
1008	DELEGUEDEL	2001-10-10 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	914	\N	\N	\N
1009	DELEGUEDEL	2001-10-10 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	915	\N	\N	\N
1010	DELEGUEDEL	2001-10-10 00:00:00	2004-10-13 00:00:00	ANCIEN	\N	\N	\N	\N	916	\N	\N	\N
1011	DELTITDEL	2001-10-10 00:00:00	2001-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	918	\N	\N	\N
1012	DELEGUEDEL	2001-10-10 00:00:00	2004-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	920	\N	\N	\N
1013	DELEGUEDEL	2001-10-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	921	\N	\N	\N
1014	DELEGUEDEL	2001-10-10 00:00:00	2001-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	922	\N	\N	\N
1015	DELTITDEL	2001-10-10 00:00:00	2001-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	923	\N	\N	\N
1016	DELEGUEDEL	2001-10-10 00:00:00	2004-10-13 00:00:00	ANCIEN	\N	\N	\N	\N	924	\N	\N	\N
1017	DELEGUEDEL	2001-10-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	925	\N	\N	\N
1018	DELSUPDEL	2001-10-10 00:00:00	2002-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	926	\N	\N	\N
1019	DELEGUEDEL	2001-10-10 00:00:00	2004-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	927	\N	\N	\N
1020	VICPDTDEL	2001-10-10 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	928	\N	\N	\N
1021	DELSUPDEL	2001-10-10 00:00:00	2002-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	929	\N	\N	\N
1022	DELEGUEDEL	2001-10-10 00:00:00	2004-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	930	\N	\N	\N
1023	DELEGUEDEL	2001-10-10 00:00:00	2004-10-13 00:00:00	ANCIEN	\N	\N	\N	\N	931	\N	\N	\N
1024	DELEGUEDEL	2001-10-10 00:00:00	2004-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	932	\N	\N	\N
1025	DELTITDEL	2001-10-10 00:00:00	2001-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	917	\N	\N	\N
1027	DELEGUEDEL	2001-10-10 00:00:00	2001-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	866	\N	\N	\N
1028	DELEGUEDEL	2001-10-10 00:00:00	2001-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	853	\N	\N	\N
1029	DELEGUEDEL	2001-10-10 00:00:00	2001-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	860	\N	\N	\N
1030	VICPDTDEL	2001-10-11 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	870	\N	\N	\N
1031	VICPDTDEL	2001-10-11 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	884	\N	\N	\N
1032	SECRETDEL	2001-10-11 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	867	\N	\N	\N
1033	SECRETDEL	2001-10-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	852	1	\N	\N
1034	SECRETDEL	2001-10-11 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	864	\N	\N	\N
1035	VICPDTDEL	2001-10-11 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	874	\N	\N	\N
1036	PDTDEL	2001-10-17 00:00:00	2002-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	898	\N	\N	\N
1038	VICPDTDEL	2001-10-17 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	888	3	\N	\N
1039	VICPDTDEL	2001-10-17 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	889	\N	\N	\N
1040	VICPDTDEL	2001-10-17 00:00:00	2002-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	890	\N	\N	\N
1041	VICPDTDEL	2001-10-17 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	894	\N	\N	\N
1042	SECRETDEL	2001-10-17 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	892	\N	\N	\N
1043	VICPDTPREDEL	2001-10-17 00:00:00	2004-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	922	\N	\N	\N
1044	VICPDTDEL	2001-10-17 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	917	1	\N	\N
1045	VICPDTDEL	2001-10-17 00:00:00	2004-10-13 00:00:00	ANCIEN	\N	\N	\N	\N	918	\N	\N	\N
1046	VICPDTDEL	2001-10-17 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	923	\N	\N	\N
1047	DELEGUEDEL	2001-10-18 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	934	\N	\N	\N
69	DELEGUEDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'evaluation de la legislation/ Union Europeenne/ 	69	\N	\N	\N
70	DELEGUEDEL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	70	\N	\N	\N
71	DELEGUEDEL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	71	\N	\N	\N
72	DELEGUEDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	72	\N	\N	\N
73	PDTDEL	1979-10-11 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	73	\N	\N	\N
74	DELEGUEDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	74	\N	\N	\N
75	DELEGUEDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	75	\N	\N	\N
76	DELEGUEDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	76	\N	\N	\N
77	DELEGUEDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ Office parlementaire d'evaluation de la legislation/ 	77	\N	\N	\N
78	DELEGUEDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	78	\N	\N	\N
79	VICPDTDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ Office parlementaire d'evaluation des politiques publiques/ 	79	\N	\N	\N
80	VICPDTDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ Office parlementaire d'evaluation des politiques publiques/ 	80	\N	\N	\N
81	DELEGUEDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Problemes demographiques/ Union  europeenne/ 	81	\N	\N	\N
82	DELEGUEDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	82	\N	\N	\N
83	DELEGUEDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	83	\N	\N	\N
84	VICPDTDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	84	\N	\N	\N
85	DELEGUEDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	85	\N	\N	\N
86	DELEGUEDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	86	\N	\N	\N
87	DELEGUEDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union europeenne/ 	87	\N	\N	\N
88	DELEGUEDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	88	\N	\N	\N
89	DELEGUEDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ Choix scientifiques et technologiques (titulaire)/ 	89	\N	\N	\N
90	DELEGUEDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	90	\N	\N	\N
91	DELEGUEDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union europeenne/ 	91	\N	\N	\N
92	DELEGUEDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union europeenne/ 	92	\N	\N	\N
93	DELEGUEDEL	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	93	\N	\N	\N
94	DELEGUEDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	94	\N	\N	\N
95	DELEGUEDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	95	\N	\N	\N
96	DELEGUEDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne / 	96	\N	\N	\N
97	DELEGUEDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	97	\N	\N	\N
98	DELEGUEDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	98	\N	\N	\N
99	SECRETDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	99	\N	\N	\N
1076	PDTDEL	2001-10-30 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	903	\N	\N	\N
1077	VICPDTDEL	2001-10-30 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	908	\N	\N	\N
1078	VICPDTDEL	2001-10-30 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	912	\N	\N	\N
1079	VICPDTDEL	2001-10-30 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	909	\N	\N	\N
1081	SECRETDEL	2001-10-30 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	904	\N	\N	\N
1082	SECRETDEL	2001-10-30 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	901	\N	\N	\N
1083	VICPDTDEL	2001-11-20 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	879	\N	\N	\N
1085	VICPDTDEL	2001-12-05 00:00:00	2002-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	958	\N	\N	\N
1086	VICPDTDEL	2001-12-05 00:00:00	2004-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	954	\N	\N	\N
1087	SECRETDEL	2001-12-05 00:00:00	2004-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	957	\N	\N	\N
1088	DELEGUEDEL	2001-10-10 00:00:00	2002-10-15 00:00:00	ANCIEN	\N	\N	\N	\N	806	\N	\N	\N
1089	DELEGUEDEL	2001-10-10 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	809	\N	\N	\N
1090	DELEGUEDEL	2001-10-10 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	824	\N	\N	\N
1091	DELEGUEDEL	2001-10-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	831	\N	\N	\N
1092	DELEGUEDEL	2001-10-10 00:00:00	2009-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	963	\N	\N	\N
1093	DELEGUEDEL	2002-02-19 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	964	\N	\N	\N
1094	DELEGUEDEL	2002-02-19 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	965	\N	\N	\N
1095	PDTDEL	2002-02-20 00:00:00	2008-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	866	\N	\N	\N
737	DELEGUEDEL	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	712	\N	\N	\N
968	DELEGUEDEL	2001-10-10 00:00:00	2001-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	874	\N	\N	\N
970	DELEGUEDEL	2001-10-10 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	876	\N	\N	\N
971	DELEGUEDEL	2001-10-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	877	\N	\N	\N
972	DELEGUEDEL	2001-10-10 00:00:00	2002-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	878	\N	\N	\N
973	DELEGUEDEL	2001-10-10 00:00:00	2001-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	879	\N	\N	\N
974	DELEGUEDEL	2001-10-10 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	880	\N	\N	\N
975	DELEGUEDEL	2001-10-10 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	881	\N	\N	\N
977	DELEGUEDEL	2001-10-10 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	883	\N	\N	\N
978	DELEGUEDEL	2001-10-10 00:00:00	2001-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	884	\N	\N	\N
979	DELEGUEDEL	2001-10-10 00:00:00	2004-10-13 00:00:00	ANCIEN	\N	\N	\N	\N	885	\N	\N	\N
980	DELEGUEDEL	2001-10-10 00:00:00	2001-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	886	\N	\N	\N
982	DELEGUEDEL	2001-10-10 00:00:00	2001-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	888	\N	\N	\N
983	DELEGUEDEL	2001-10-10 00:00:00	2001-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	889	\N	\N	\N
984	DELEGUEDEL	2001-10-10 00:00:00	2001-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	890	\N	\N	\N
985	DELEGUEDEL	2001-10-10 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	891	\N	\N	\N
986	DELEGUEDEL	2001-10-10 00:00:00	2001-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	892	\N	\N	\N
987	DELEGUEDEL	2001-10-10 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	893	\N	\N	\N
988	DELEGUEDEL	2001-10-10 00:00:00	2001-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	894	\N	\N	\N
991	DELEGUEDEL	2001-10-10 00:00:00	2004-10-13 00:00:00	ANCIEN	\N	\N	\N	\N	897	\N	\N	\N
992	DELEGUEDEL	2001-09-10 00:00:00	2001-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	898	\N	\N	\N
993	DELEGUEDEL	2001-10-10 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	899	\N	\N	\N
994	DELEGUEDEL	2001-09-10 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	900	\N	\N	\N
995	DELEGUEDEL	2001-10-10 00:00:00	2001-10-30 00:00:00	ANCIEN	\N	\N	\N	\N	901	\N	\N	\N
996	DELEGUEDEL	2001-10-10 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	902	\N	\N	\N
997	DELEGUEDEL	2001-10-10 00:00:00	2001-10-30 00:00:00	ANCIEN	\N	\N	\N	\N	903	\N	\N	\N
998	DELEGUEDEL	2001-10-10 00:00:00	2001-10-30 00:00:00	ANCIEN	\N	\N	\N	\N	904	\N	\N	\N
999	DELEGUEDEL	2001-10-10 00:00:00	2001-10-30 00:00:00	ANCIEN	\N	\N	\N	\N	905	\N	\N	\N
1000	DELEGUEDEL	2001-10-10 00:00:00	2004-10-19 00:00:00	ANCIEN	\N	\N	\N	\N	906	\N	\N	\N
1001	DELEGUEDEL	\N	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	\N	907	\N	\N	\N
1002	DELEGUEDEL	2001-10-10 00:00:00	2001-10-30 00:00:00	ANCIEN	\N	\N	\N	\N	908	\N	\N	\N
772	DELEGUEDEL	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	744	\N	\N	\N
1315	DELEGUEDEL	2004-10-13 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1133	\N	\N	\N
1156	DELSUPDEL	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	 Conseil de l'Europe (délégué suppléant)/ Union de l'Europe occidentale (délégué suppléant)/	1018	\N	\N	2015-10-08 16:19:10
1157	DELSUPDEL	\N	2011-06-18 00:00:00	ANCIEN	\N	\N	\N	 Conseil de l'Europe (délégué suppléant)/ Union de l'Europe occidentale (délégué suppléant)/	1021	\N	\N	\N
1158	DELSUPDEL	\N	2001-01-26 00:00:00	ANCIEN	\N	\N	\N	 Conseil de l'Europe (délégué suppléant)/ Union de l'Europe occidentale (délégué suppléant)/	1022	\N	\N	\N
1214	DELTITDEL	\N	2005-09-22 00:00:00	ANCIEN	\N	\N	\N	Union Européenne/	1044	\N	\N	\N
1215	DELTITDEL	\N	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	Union Européenne/	1045	\N	\N	\N
1216	DELTITDEL	\N	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	Union Européenne/	1046	\N	\N	\N
1217	DELTITDEL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	Union Européenne/	1047	\N	\N	\N
1218	DELTITDEL	\N	1997-06-19 00:00:00	ANCIEN	\N	\N	\N	Union Européenne/ Problèmes démographiques/	1048	\N	\N	\N
1219	DELTITDEL	\N	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	Union Européenne/	1049	\N	\N	\N
1220	DELTITDEL	\N	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	Union Européenne/	1050	\N	\N	\N
1221	DELTITDEL	\N	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	Union Européenne/	1051	\N	\N	\N
1222	DELTITDEL	\N	2000-04-21 00:00:00	ANCIEN	\N	\N	\N	Union Européenne/	1052	\N	\N	\N
1223	DELTITDEL	\N	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	Union européenne/	1053	\N	\N	\N
1224	DELTITDEL	\N	1998-09-25 00:00:00	ANCIEN	\N	\N	\N	Union Européenne/	1054	\N	\N	\N
1225	DELTITDEL	\N	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	Union Européenne/	1055	\N	\N	\N
1226	DELTITDEL	\N	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'évaluation des choix scientifiques et technologiques/ Union Européenne/	1056	\N	\N	\N
1227	VICPDTDEL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	Union Européenne/	1057	\N	\N	\N
1228	DELTITDEL	\N	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	Union Européenne/	1058	\N	\N	\N
1229	DELTITDEL	\N	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	Union Européenne/	1059	\N	\N	\N
1230	DELTITDEL	\N	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'évaluation de la législation/ Union Européenne/	1060	\N	\N	\N
1231	DELTITDEL	\N	1996-05-15 00:00:00	ANCIEN	\N	\N	\N	Union Européenne/	1061	\N	\N	\N
1232	DELTITDEL	\N	1999-07-13 00:00:00	ANCIEN	\N	\N	\N	Union Européenne/	1062	\N	\N	\N
1233	DELTITDEL	\N	2009-06-25 00:00:00	ANCIEN	\N	\N	\N	Problèmes démographiques/	1069	\N	\N	\N
1235	DELTITDEL	\N	2009-06-25 00:00:00	ANCIEN	\N	\N	\N	Problèmes démographiques/	1071	\N	\N	\N
1236	DELTITDEL	\N	1997-06-19 00:00:00	ANCIEN	\N	\N	\N	Union Européenne/ Problèmes démographiques/	1072	\N	\N	\N
1237	DELTITDEL	\N	2009-06-25 00:00:00	ANCIEN	\N	\N	\N	Problèmes démographiques/	1073	\N	\N	\N
1238	DELTITDEL	\N	2006-04-25 00:00:00	ANCIEN	\N	\N	\N	Problèmes démographiques/	1074	\N	\N	\N
1239	DELTITDEL	\N	2002-01-27 00:00:00	ANCIEN	\N	\N	\N	Problèmes démographiques/ Planification/	1075	\N	\N	\N
1249	DELTITDEL	\N	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	Planification/	1076	\N	\N	\N
1250	DELTITDEL	\N	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	Planification/	1077	\N	\N	\N
1251	DELTITDEL	\N	2009-05-09 00:00:00	ANCIEN	\N	\N	\N	Planification/	1078	\N	\N	\N
1252	DELTITDEL	\N	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	Planification/	1079	\N	\N	\N
1253	DELTITDEL	\N	1999-07-22 00:00:00	ANCIEN	\N	\N	\N	Planification/	1080	\N	\N	\N
1254	DELTITDEL	\N	2002-01-27 00:00:00	ANCIEN	\N	\N	\N	Problèmes démographiques/ Planification/	1081	\N	\N	\N
1255	DELTITDEL	\N	2007-05-17 00:00:00	ANCIEN	\N	\N	\N	Planification/	1082	\N	\N	\N
1256	DELTITDEL	\N	2009-02-15 00:00:00	ANCIEN	\N	\N	\N	Planification/	1083	\N	\N	\N
1257	DELTITDEL	\N	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	Planification/	1084	\N	\N	\N
1284	VICPDTDEL	2003-05-06 00:00:00	2010-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	1103	\N	\N	\N
1286	DELEGUEDEL	2003-10-08 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	1105	\N	\N	\N
1288	DELEGUEDEL	2003-11-20 00:00:00	2004-10-13 00:00:00	ANCIEN	\N	\N	\N	\N	1107	\N	\N	\N
1346	DELEGUEDEL	2004-10-13 00:00:00	2008-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	1164	\N	\N	\N
1289	DELTITDEL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1093	\N	\N	\N
966	DELEGUEDEL	2001-10-10 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	872	\N	\N	\N
3949	DELEGUEDEL	2010-05-12 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3248	\N	\N	\N
1280	DELTITDEL	\N	2014-08-20 00:00:00	ANCIEN	\N	\N	\N	choix scientifiques et technologiques/	1096	\N	\N	\N
1282	DELEGUEDEL	\N	1997-06-30 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'évaluation des politiques publiques/	1101	\N	\N	\N
1290	DELEGUEDEL	2004-05-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1108	\N	\N	\N
1291	DELEGUEDEL	2004-05-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1109	\N	\N	\N
1292	DELEGUEDEL	2004-05-18 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	1110	\N	\N	\N
1293	DELTITDEL	2004-05-18 00:00:00	2004-10-13 00:00:00	ANCIEN	\N	\N	\N	\N	1111	\N	\N	\N
924	VICPDTDEL	2001-10-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	828	\N	\N	\N
989	DELEGUEDEL	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	895	\N	\N	\N
901	DELEGUEDEL	2001-10-10 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	801	\N	\N	\N
1294	DELEGUEDEL	2004-10-13 00:00:00	2008-11-11 00:00:00	ANCIEN	\N	\N	\N	\N	1112	\N	\N	\N
1295	DELEGUEDEL	2004-10-13 00:00:00	2008-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	1113	\N	\N	\N
1296	DELEGUEDEL	2004-10-13 00:00:00	2004-10-19 00:00:00	ANCIEN	\N	\N	\N	\N	1114	\N	\N	\N
1297	DELEGUEDEL	2004-10-13 00:00:00	2004-10-19 00:00:00	ANCIEN	\N	\N	\N	\N	1115	\N	\N	\N
1298	DELEGUEDEL	2004-10-13 00:00:00	2008-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	1116	\N	\N	\N
1299	DELEGUEDEL	2004-10-13 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	1117	\N	\N	\N
1301	SECRETDEL	2004-10-13 00:00:00	2008-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	1119	3	\N	\N
1302	SECRETDEL	2004-10-13 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1120	4	\N	\N
915	DELEGUEDEL	2001-10-10 00:00:00	2004-10-13 00:00:00	ANCIEN	\N	\N	\N	\N	818	\N	\N	\N
1303	VICPDTDEL	2004-10-13 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1121	5	\N	\N
1304	DELEGUEDEL	2004-10-13 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	1122	\N	\N	\N
1305	DELEGUEDEL	2004-10-13 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	1123	\N	\N	\N
1306	DELEGUEDEL	2004-10-13 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	1124	\N	\N	\N
1308	DELEGUEDEL	2004-10-13 00:00:00	2006-11-09 00:00:00	ANCIEN	\N	\N	\N	\N	1126	\N	\N	\N
1311	DELEGUEDEL	2004-10-13 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	1129	\N	\N	\N
1313	SECRETDEL	2004-10-13 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1131	1	\N	\N
1314	DELEGUEDEL	2004-10-13 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1132	\N	\N	\N
1316	DELEGUEDEL	2004-10-13 00:00:00	2012-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	1134	\N	\N	\N
1317	DELEGUEDEL	2004-10-13 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	1135	\N	\N	\N
1318	DELEGUEDEL	2004-10-13 00:00:00	2008-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	1136	\N	\N	\N
1319	DELEGUEDEL	2004-10-13 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	1137	\N	\N	\N
1320	DELEGUEDEL	2004-10-13 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	1138	\N	\N	\N
1322	DELEGUEDEL	2004-10-13 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1140	\N	\N	\N
1323	DELEGUEDEL	2004-10-13 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	1141	\N	\N	\N
1324	DELEGUEDEL	2004-10-13 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	1142	\N	\N	\N
1325	DELEGUEDEL	2004-10-13 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	\N	1143	\N	\N	\N
1326	DELEGUEDEL	\N	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	1144	\N	\N	\N
1327	DELEGUEDEL	2004-10-13 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	1145	\N	\N	\N
1328	DELEGUEDEL	2004-10-13 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	1146	\N	\N	\N
1329	DELEGUEDEL	2004-10-13 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	1147	\N	\N	\N
1330	DELEGUEDEL	2004-10-13 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	1148	\N	\N	\N
1331	DELEGUEDEL	2004-10-13 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	1149	\N	\N	\N
1332	DELEGUEDEL	2004-10-13 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	1150	\N	\N	\N
1333	DELEGUEDEL	2004-10-13 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1151	\N	\N	\N
1334	DELEGUEDEL	2004-10-13 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	1152	\N	\N	\N
1336	DELEGUEDEL	2004-10-13 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	1154	\N	\N	\N
1337	DELEGUEDEL	2004-10-13 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	1155	\N	\N	\N
949	DELEGUEDEL	2001-10-10 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	855	\N	\N	\N
1338	DELEGUEDEL	2004-10-13 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	1156	\N	\N	\N
1340	SECRETDEL	2004-10-13 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	1158	2	\N	\N
969	DELEGUEDEL	2001-10-10 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	875	\N	\N	\N
1341	DELEGUEDEL	2004-10-13 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1159	\N	\N	\N
1343	VICPDTDEL	2004-10-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1161	\N	\N	\N
1344	DELEGUEDEL	2004-10-13 00:00:00	2012-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	1162	\N	\N	\N
1345	DELEGUEDEL	2004-10-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1163	\N	\N	\N
1347	DELEGUEDEL	2004-10-13 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1165	\N	\N	\N
1348	DELEGUEDEL	2004-10-13 00:00:00	2010-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	1166	\N	\N	\N
1350	DELEGUEDEL	2004-10-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1168	\N	\N	\N
1352	VICPDTDEL	2004-10-13 00:00:00	2008-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	880	4	\N	\N
1353	VICPDTDEL	2004-10-13 00:00:00	2008-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	934	6	\N	\N
1354	VICPDTDEL	2004-10-13 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	808	2	\N	\N
1355	VICPDTDEL	2004-10-13 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	809	3	\N	\N
1356	VICPDTDEL	2004-10-13 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	992	5	\N	\N
1357	VICPDTDEL	2004-10-13 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	833	6	\N	\N
926	DELEGUEDEL	2001-10-10 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	830	\N	\N	\N
1358	SECRETDEL	2004-10-13 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	830	2	\N	\N
1359	VICPDTDEL	2004-10-13 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	892	2	\N	\N
1360	VICPDTDEL	2004-10-13 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	891	4	\N	\N
1362	SECRETDEL	2004-10-13 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	981	3	\N	\N
1363	DELEGUEDEL	2004-10-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	859	\N	\N	\N
1364	DELEGUEDEL	2004-10-13 00:00:00	2004-10-19 00:00:00	ANCIEN	\N	\N	\N	\N	901	\N	\N	\N
1365	DELEGUEDEL	2004-10-13 00:00:00	2004-10-19 00:00:00	ANCIEN	\N	\N	\N	\N	903	\N	\N	\N
1366	DELEGUEDEL	2004-10-13 00:00:00	2004-10-19 00:00:00	ANCIEN	\N	\N	\N	\N	904	\N	\N	\N
1080	VICPDTDEL	2001-10-30 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	905	\N	\N	\N
1367	DELEGUEDEL	2004-10-13 00:00:00	2004-10-19 00:00:00	ANCIEN	\N	\N	\N	\N	905	\N	\N	\N
1368	DELEGUEDEL	2004-10-13 00:00:00	2007-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	909	\N	\N	\N
1369	DELEGUEDEL	2004-10-19 00:00:00	2005-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	943	\N	\N	\N
1370	DELEGUEDEL	2004-10-19 00:00:00	2004-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	944	\N	\N	\N
1371	DELEGUEDEL	2004-10-19 00:00:00	2004-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	945	\N	\N	\N
1059	DELEGUEDEL	2001-10-23 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	946	\N	\N	\N
1372	DELSUPDEL	2004-10-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	946	\N	\N	\N
1373	DELTITDEL	2004-10-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	947	\N	\N	\N
1375	DELSUPDEL	2004-10-19 00:00:00	2004-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	937	\N	\N	\N
1376	DELSUPDEL	2004-10-19 00:00:00	2004-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	938	\N	\N	\N
1377	DELEGUEDEL	2004-10-19 00:00:00	2004-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	939	\N	\N	\N
1053	DELSUPDEL	2001-10-23 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	940	\N	\N	\N
1378	DELEGUEDEL	2004-10-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1169	\N	\N	\N
1379	DELSUPDEL	2004-10-19 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	1170	\N	\N	\N
1380	DELSUPDEL	2004-10-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1171	\N	\N	\N
1068	DELEGUEDEL	2001-10-24 00:00:00	2004-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	956	\N	\N	\N
1381	PDTDEL	2004-10-20 00:00:00	2008-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	903	\N	\N	\N
1382	VICPDTDEL	2004-10-20 00:00:00	2008-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	901	1	\N	\N
1383	VICPDTDEL	2004-10-20 00:00:00	2008-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	905	2	\N	\N
1384	VICPDTDEL	2004-10-20 00:00:00	2008-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	906	3	\N	\N
1385	VICPDTDEL	2004-10-20 00:00:00	2008-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	1114	4	\N	\N
1386	SECRETDEL	2004-10-20 00:00:00	2008-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	904	1	\N	\N
1387	SECRETDEL	2004-10-20 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1115	2	\N	\N
1388	DELEGUEDEL	2004-10-20 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1172	3	\N	\N
1389	DELEGUEDEL	2004-10-20 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	1173	5	\N	\N
1392	DELEGUEDEL	2004-10-20 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1176	\N	\N	\N
1393	DELEGUEDEL	2004-10-20 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	1177	\N	\N	\N
1394	DELEGUEDEL	2004-10-20 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	1178	\N	\N	\N
1395	DELEGUEDEL	2004-10-20 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	1179	\N	\N	\N
1396	DELEGUEDEL	2004-10-20 00:00:00	2008-09-07 00:00:00	ANCIEN	\N	\N	\N	\N	1180	\N	\N	\N
1398	DELEGUEDEL	2004-10-20 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	1182	\N	\N	\N
1399	DELEGUEDEL	2004-10-20 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	1183	\N	\N	\N
1400	DELEGUEDEL	2004-10-20 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	1184	\N	\N	\N
1402	DELEGUEDEL	2004-10-20 00:00:00	2004-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	1186	\N	\N	\N
1403	DELEGUEDEL	2004-10-20 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	1187	\N	\N	\N
1404	DELEGUEDEL	2004-10-20 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	1188	\N	\N	\N
1405	PDTDEL	2004-10-20 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	922	\N	\N	\N
1406	VICPDTDEL	2004-10-20 00:00:00	2008-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	932	3	\N	\N
1407	VICPDTDEL	2004-10-20 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	927	2	\N	\N
1084	PDTDEL	2001-12-05 00:00:00	2004-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	948	\N	\N	\N
1408	PDTDEL	2004-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	1005	\N	\N	\N
1409	VICPDTDEL	2004-10-26 00:00:00	2008-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	994	1	\N	\N
1410	VICPDTDEL	2004-10-26 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1001	2	\N	\N
1411	SECRETDEL	2004-10-26 00:00:00	2008-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	1186	\N	\N	\N
1413	VICPDTDEL	2004-11-02 00:00:00	2008-09-07 00:00:00	ANCIEN	\N	\N	\N	\N	937	1	\N	\N
1414	VICPDTDEL	2004-11-02 00:00:00	2007-02-25 00:00:00	ANCIEN	\N	\N	\N	\N	938	2	\N	\N
1415	VICPDTDEL	2004-11-02 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	944	\N	\N	\N
1416	VICPDTDEL	2004-11-02 00:00:00	2008-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	945	4	\N	\N
1419	PDTDEL	2005-01-19 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1191	\N	\N	\N
1420	VICPDTDEL	2005-01-19 00:00:00	2009-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	1192	\N	\N	\N
1421	VICPDTDEL	2005-01-19 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1193	\N	\N	\N
1422	VICPDTDEL	2005-01-19 00:00:00	2007-06-24 00:00:00	ANCIEN	\N	\N	\N	\N	1194	\N	\N	\N
686	DELSUPDEL	1998-10-20 00:00:00	2001-10-23 00:00:00	ANCIEN	\N	\N	\N	\N	685	\N	\N	\N
1048	DELSUPDEL	2001-10-23 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	936	\N	\N	\N
1049	VICPDTDEL	2001-10-23 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	937	\N	\N	\N
1050	DELSUPDEL	2001-10-23 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	938	\N	\N	\N
1052	DELSUPDEL	2001-10-23 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	939	\N	\N	\N
1054	DELSUPDEL	2001-10-23 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	941	\N	\N	\N
1055	VICPDTDEL	2001-10-23 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	942	\N	\N	\N
1056	PDTDEL	2001-10-23 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	943	\N	\N	\N
1057	SECRETGENDEL	2001-10-23 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	944	\N	\N	\N
1058	DELEGUEDEL	2001-10-23 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	945	\N	\N	\N
651	DELTITDEL	1998-10-21 00:00:00	2001-10-24 00:00:00	ANCIEN	\N	\N	\N	\N	657	\N	\N	\N
653	DELTITDEL	1998-10-21 00:00:00	2001-10-24 00:00:00	ANCIEN	\N	\N	\N	\N	659	\N	\N	\N
1061	DELEGUEDEL	2001-10-24 00:00:00	2001-12-05 00:00:00	ANCIEN	\N	\N	\N	\N	948	\N	\N	\N
1062	DELEGUEDEL	2001-10-24 00:00:00	2004-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	949	\N	\N	\N
1063	DELEGUEDEL	2001-10-24 00:00:00	2004-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	950	\N	\N	\N
1064	DELEGUEDEL	2001-10-24 00:00:00	2004-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	951	\N	\N	\N
1065	DELTITDEL	2001-10-24 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	952	\N	\N	\N
1067	DELEGUEDEL	2001-10-24 00:00:00	2001-12-05 00:00:00	ANCIEN	\N	\N	\N	\N	954	\N	\N	\N
1069	DELEGUEDEL	2001-10-24 00:00:00	2001-12-05 00:00:00	ANCIEN	\N	\N	\N	\N	957	\N	\N	\N
1070	DELEGUEDEL	2001-10-24 00:00:00	2001-12-05 00:00:00	ANCIEN	\N	\N	\N	\N	958	\N	\N	\N
1071	DELEGUEDEL	2001-10-24 00:00:00	2004-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	959	\N	\N	\N
1072	DELEGUEDEL	2001-10-24 00:00:00	2004-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	960	\N	\N	\N
1073	DELEGUEDEL	2001-10-24 00:00:00	2004-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	961	\N	\N	\N
1075	DELEGUEDEL	2001-10-24 00:00:00	2004-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	955	\N	\N	\N
921	PDTDEL	1999-10-10 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	825	\N	\N	\N
922	DELEGUEDEL	2001-10-10 00:00:00	2003-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	826	\N	\N	\N
923	DELEGUEDEL	2001-10-10 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	827	\N	\N	\N
925	DELEGUEDEL	2001-10-10 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	829	\N	\N	\N
927	DELEGUEDEL	2001-10-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	832	\N	\N	\N
928	DELEGUEDEL	2001-10-10 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	833	\N	\N	\N
929	DELEGUEDEL	2001-10-10 00:00:00	2004-10-13 00:00:00	ANCIEN	\N	\N	\N	\N	834	\N	\N	\N
930	DELEGUEDEL	2001-10-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	835	\N	\N	\N
931	DELEGUEDEL	2001-10-10 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	836	\N	\N	\N
932	DELEGUEDEL	2001-10-10 00:00:00	2004-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	837	\N	\N	\N
933	DELEGUEDEL	2001-10-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	838	\N	\N	\N
934	DELEGUEDEL	2001-10-10 00:00:00	2009-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	839	\N	\N	\N
935	DELEGUEDEL	2001-10-10 00:00:00	2009-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	840	\N	\N	\N
936	DELEGUEDEL	2001-10-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	841	\N	\N	\N
937	DELEGUEDEL	2001-10-10 00:00:00	2009-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	842	\N	\N	\N
938	DELEGUEDEL	2001-10-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	843	\N	\N	\N
939	DELEGUEDEL	2001-10-10 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	844	\N	\N	\N
941	DELEGUEDEL	2001-10-10 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	846	\N	\N	\N
942	DELEGUEDEL	2001-10-10 00:00:00	2004-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	847	\N	\N	\N
943	DELEGUEDEL	2001-10-10 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	848	\N	\N	\N
944	DELEGUEDEL	2001-10-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	850	\N	\N	\N
945	DELEGUEDEL	2001-10-10 00:00:00	2001-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	851	\N	\N	\N
946	DELEGUEDEL	2001-10-10 00:00:00	2001-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	852	\N	\N	\N
947	VICPDTDEL	2001-10-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	853	1	\N	\N
950	DELEGUEDEL	2001-10-10 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	856	\N	\N	\N
951	DELEGUEDEL	2001-10-10 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	857	\N	\N	\N
953	VICPDTDEL	2001-10-10 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	859	\N	\N	\N
954	PDTDEL	2001-10-11 00:00:00	2002-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	860	\N	\N	\N
955	DELEGUEDEL	2001-10-10 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	861	\N	\N	\N
956	DELEGUEDEL	2001-10-10 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	862	\N	\N	\N
957	DELEGUEDEL	2001-10-10 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	863	\N	\N	\N
958	DELEGUEDEL	2001-10-10 00:00:00	2001-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	864	\N	\N	\N
960	VICPDTDEL	2001-10-12 00:00:00	2002-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	866	\N	\N	\N
961	DELEGUEDEL	2001-10-10 00:00:00	2001-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	867	\N	\N	\N
963	DELEGUEDEL	2001-10-10 00:00:00	2008-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	869	\N	\N	\N
964	DELEGUEDEL	2001-10-10 00:00:00	2001-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	870	\N	\N	\N
965	DELEGUEDEL	2001-10-10 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	871	\N	\N	\N
967	DELEGUEDEL	2001-10-10 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	873	\N	\N	\N
773	DELEGUEDEL	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	745	\N	\N	\N
774	DELEGUEDEL	1999-10-13 00:00:00	1999-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	746	\N	\N	\N
775	DELEGUEDEL	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	747	\N	\N	\N
776	DELEGUEDEL	1999-10-13 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	748	\N	\N	\N
777	DELEGUEDEL	1999-10-13 00:00:00	1999-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	749	\N	\N	\N
789	VICPDTDEL	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	589	\N	\N	\N
779	DELEGUEDEL	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	751	\N	\N	\N
780	DELEGUEDEL	1999-10-13 00:00:00	1999-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	752	\N	\N	\N
781	DELEGUEDEL	1999-10-13 00:00:00	2000-10-24 00:00:00	ANCIEN	\N	\N	\N	\N	753	\N	\N	\N
782	DELEGUEDEL	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	754	\N	\N	\N
783	DELEGUEDEL	1999-10-13 00:00:00	1999-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	755	\N	\N	\N
784	DELEGUEDEL	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	756	\N	\N	\N
785	DELEGUEDEL	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	757	\N	\N	\N
786	DELEGUEDEL	1999-10-13 00:00:00	1999-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	758	\N	\N	\N
787	DELEGUEDEL	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	759	\N	\N	\N
788	VICPDTDEL	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	588	\N	\N	\N
790	VICPDTDEL	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	592	\N	\N	\N
791	DELEGUEDEL	1999-10-20 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	760	\N	\N	\N
792	DELEGUEDEL	1999-10-13 00:00:00	1999-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	707	\N	\N	\N
793	PDTDEL	1999-10-27 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	719	\N	\N	\N
794	VICPDTDEL	1999-10-27 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	711	\N	\N	\N
795	VICPDTDEL	1999-10-27 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	708	\N	\N	\N
796	VICPDTDEL	1999-10-27 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	714	\N	\N	\N
797	VICPDTDEL	1999-10-27 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	707	\N	\N	\N
798	SECRETDEL	1999-10-27 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	715	\N	\N	\N
799	DELEGUEDEL	1999-11-03 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	761	\N	\N	\N
800	PDTDEL	1999-11-04 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	734	\N	\N	\N
801	AUTFONDEL	1999-11-04 00:00:00	1999-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	729	\N	\N	\N
802	AUTFONDEL	1999-11-04 00:00:00	1999-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	746	\N	\N	\N
803	AUTFONDEL	1999-11-04 00:00:00	1999-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	723	\N	\N	\N
804	AUTFONDEL	1999-11-04 00:00:00	1999-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	730	\N	\N	\N
805	AUTFONDEL	1999-11-04 00:00:00	1999-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	758	\N	\N	\N
806	DELTITDEL	1999-12-01 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	762	\N	\N	\N
807	VICPDTDEL	1999-11-30 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	729	\N	\N	\N
808	VICPDTDEL	1999-11-30 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	746	\N	\N	\N
809	VICPDTDEL	1999-11-30 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	723	\N	\N	\N
810	VICPDTDEL	1999-11-30 00:00:00	2001-06-04 00:00:00	ANCIEN	\N	\N	\N	\N	730	\N	\N	\N
811	VICPDTDEL	1999-11-30 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	755	\N	\N	\N
812	VICPDTDEL	1999-11-30 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	758	\N	\N	\N
813	SECRETDEL	1999-11-30 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	752	\N	\N	\N
814	SECRETDEL	1999-11-30 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	728	\N	\N	\N
815	SECRETDEL	1999-11-30 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	738	\N	\N	\N
816	DELEGUEDEL	2000-03-22 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	763	\N	\N	\N
817	DELEGUEDEL	2000-05-03 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	764	\N	\N	\N
818	DELEGUEDEL	2000-05-03 00:00:00	2000-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	765	\N	\N	\N
819	DELTITDEL	2000-05-03 00:00:00	2001-10-24 00:00:00	ANCIEN	\N	\N	\N	\N	766	\N	\N	\N
820	DELEGUEDEL	2000-06-14 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	767	\N	\N	\N
821	SECRETDEL	2000-10-17 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	768	\N	\N	\N
822	DELEGUEDEL	2000-10-25 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	769	\N	\N	\N
823	DELEGUEDEL	2000-10-25 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	770	\N	\N	\N
900	DELTITDEL	2001-06-25 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	800	\N	\N	\N
902	DELEGUEDEL	2001-10-10 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	802	\N	\N	\N
903	VICPDTDEL	2001-10-10 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	803	1	\N	\N
904	DELEGUEDEL	2001-10-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	804	\N	\N	\N
905	VICPDTDEL	2001-10-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	807	\N	\N	\N
906	DELEGUEDEL	2001-10-10 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	808	\N	\N	\N
907	DELEGUEDEL	2001-10-10 00:00:00	2004-10-13 00:00:00	ANCIEN	\N	\N	\N	\N	810	\N	\N	\N
908	DELEGUEDEL	2001-10-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	811	\N	\N	\N
909	DELEGUEDEL	2001-10-10 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	812	\N	\N	\N
910	DELEGUEDEL	2001-10-10 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	813	\N	\N	\N
911	DELEGUEDEL	2001-11-29 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	814	\N	\N	\N
912	DELEGUEDEL	2001-10-10 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	815	\N	\N	\N
913	VICPDTDEL	2001-10-10 00:00:00	2004-10-13 00:00:00	ANCIEN	\N	\N	\N	\N	816	\N	\N	\N
914	SECRETDEL	2001-10-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	817	\N	\N	\N
916	VICPDTDEL	2001-10-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	819	\N	\N	\N
917	DELEGUEDEL	2001-10-10 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	820	\N	\N	\N
919	DELEGUEDEL	2001-10-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	822	\N	\N	\N
920	VICPDTDEL	2001-10-10 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	823	4	\N	\N
981	DELEGUEDEL	2001-09-10 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	887	\N	\N	\N
1104	DELEGUEDEL	2002-07-04 00:00:00	2004-10-13 00:00:00	ANCIEN	\N	\N	\N	\N	974	\N	\N	\N
1106	DELEGUEDEL	2002-07-04 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	978	\N	\N	\N
1111	DELEGUEDEL	2002-07-04 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	985	\N	\N	\N
1112	DELEGUEDEL	2002-07-04 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	981	\N	\N	\N
1113	DELEGUEDEL	2002-07-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	983	\N	\N	\N
1114	DELEGUEDEL	2002-07-04 00:00:00	2003-05-06 00:00:00	ANCIEN	\N	\N	\N	\N	979	\N	\N	\N
612	DELEGUEDEL	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	619	\N	\N	\N
752	DELEGUEDEL	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	724	\N	\N	\N
952	DELEGUEDEL	2001-10-10 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	858	\N	\N	\N
962	DELEGUEDEL	2001-10-10 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	868	\N	\N	\N
1117	PDTDEL	2002-07-24 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	890	\N	\N	\N
1122	DELEGUEDEL	2002-10-16 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	992	\N	\N	\N
1123	DELEGUEDEL	2003-01-21 00:00:00	2004-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	994	\N	\N	\N
1124	DELEGUEDEL	2003-01-21 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	995	\N	\N	\N
1127	DELEGUEDEL	2003-01-21 00:00:00	2004-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	998	\N	\N	\N
1128	DELEGUEDEL	2003-01-21 00:00:00	2004-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	999	\N	\N	\N
1129	DELEGUEDEL	2003-01-21 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1000	\N	\N	\N
1130	DELEGUEDEL	2003-01-21 00:00:00	2004-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	1001	\N	\N	\N
1131	DELEGUEDEL	2003-01-21 00:00:00	2004-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	1002	\N	\N	\N
3021	DELEGUEDEL	\N	2004-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	2532	\N	\N	\N
3022	DELEGUEDEL	\N	2014-09-29 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	2534	\N	\N	2014-09-29 13:43:10
3023	DELEGUEDEL	\N	2015-02-12 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	2535	\N	\N	2015-02-13 16:06:23
3024	DELEGUEDEL	\N	2014-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	2536	\N	\N	2014-09-28 13:16:32
3025	DELEGUEDEL	\N	2014-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	2538	\N	\N	2014-09-28 17:40:23
3026	DELEGUEDEL	\N	2004-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	2539	\N	\N	\N
3027	DELEGUEDEL	\N	2010-10-18 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	2540	\N	\N	\N
3028	DELEGUEDEL	\N	2015-02-12 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	2541	\N	\N	2015-02-13 16:06:29
3029	DELEGUEDEL	\N	2015-02-12 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	2542	\N	\N	2015-02-13 16:06:32
3159	DELEGUEDEL	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2666	\N	\N	\N
3160	DELEGUEDEL	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2667	\N	\N	\N
3161	DELEGUEDEL	\N	2012-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2668	\N	\N	\N
3162	DELEGUEDEL	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2669	\N	\N	\N
3163	DELEGUEDEL	\N	2007-02-25 00:00:00	ANCIEN	\N	\N	\N	\N	2670	\N	\N	\N
3164	DELEGUEDEL	\N	2015-10-15 00:00:00	ANCIEN	\N	\N	\N	\N	2671	\N	\N	2015-10-15 17:58:15
3165	DELEGUEDEL	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2672	\N	\N	\N
3166	DELEGUEDEL	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2673	\N	\N	\N
3410	DELEGUEDEL	2008-10-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2869	\N	\N	\N
3181	DELEGUEDEL	2006-11-09 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2681	\N	\N	\N
3411	DELEGUEDEL	2008-10-08 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2870	\N	\N	2014-09-28 17:07:41
3412	DELEGUEDEL	2008-10-09 00:00:00	2008-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	2871	\N	\N	\N
3413	VICPDTDEL	2008-10-08 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2872	2	\N	2014-09-28 17:34:16
918	DELEGUEDEL	2001-10-10 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	821	\N	\N	\N
1074	DELEGUEDEL	2001-10-24 00:00:00	2004-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	962	\N	\N	\N
948	DELEGUEDEL	2001-10-10 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	854	\N	\N	\N
959	DELEGUEDEL	2001-10-10 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	865	\N	\N	\N
1234	DELTITDEL	\N	2009-06-25 00:00:00	ANCIEN	\N	\N	\N	Problèmes démographiques/	1070	\N	\N	\N
1300	DELEGUEDEL	2004-10-13 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1118	\N	\N	\N
1309	DELEGUEDEL	2004-10-13 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	1127	\N	\N	\N
1321	DELEGUEDEL	2004-10-13 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1139	\N	\N	\N
1335	DELEGUEDEL	2004-10-13 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1153	\N	\N	\N
1342	DELEGUEDEL	2004-10-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1160	\N	\N	\N
1351	VICPDTDEL	2004-10-13 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	881	2	\N	\N
1361	SECRETDEL	2004-10-13 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	889	1	\N	\N
1374	DELSUPDEL	2004-10-19 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	936	\N	\N	\N
1066	DELEGUEDEL	2001-10-24 00:00:00	2004-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	953	\N	\N	\N
1391	DELEGUEDEL	2004-10-20 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	1175	\N	\N	\N
1417	DELEGUEDEL	2004-12-02 00:00:00	2006-03-07 00:00:00	ANCIEN	\N	\N	\N	\N	1189	\N	\N	\N
1427	DELEGUEDEL	2005-01-19 00:00:00	2009-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	1199	\N	\N	\N
1435	DELEGUEDEL	2005-03-02 00:00:00	2005-03-24 00:00:00	ANCIEN	\N	\N	\N	\N	944	\N	\N	\N
1126	DELEGUEDEL	2003-01-21 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	997	\N	\N	\N
3086	DELEGUEDEL	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2591	\N	\N	\N
3092	DELEGUEDEL	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2597	\N	\N	\N
3429	VICPDTDEL	2008-10-22 00:00:00	2011-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	2795	\N	\N	\N
3430	SECRETDEL	2008-10-22 00:00:00	2011-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	2871	\N	\N	\N
3431	SECRETDEL	2008-10-22 00:00:00	2011-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	2797	\N	\N	\N
3100	VICPDTDEL	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2605	3	\N	\N
3106	DELEGUEDEL	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2611	\N	\N	\N
3649	PDTDEL	2009-01-01 00:00:00	2011-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	2772	\N	\N	\N
3690	DELEGUEDEL	2009-07-08 00:00:00	2011-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	2989	\N	\N	\N
3113	AUTFONDEL	\N	2009-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	2618	9	\N	\N
3711	DELEGUEDEL	2009-09-22 00:00:00	2009-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	3014	\N	\N	\N
3712	DELEGUEDEL	2009-09-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3015	\N	\N	2014-09-28 17:03:42
3714	DELEGUEDEL	2009-09-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3017	\N	\N	\N
3715	DELEGUEDEL	2009-09-23 00:00:00	2009-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	3018	\N	\N	\N
3716	DELEGUEDEL	2009-09-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3019	\N	\N	\N
3717	DELEGUEDEL	2009-09-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3020	\N	\N	\N
3718	DELEGUEDEL	2009-09-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3021	\N	\N	\N
3719	DELEGUEDEL	2009-09-23 00:00:00	2009-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	3022	\N	\N	\N
3720	DELEGUEDEL	2009-09-23 00:00:00	2011-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	3023	\N	\N	\N
3721	DELEGUEDEL	2009-09-23 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	3024	\N	\N	\N
3722	DELEGUEDEL	2009-09-23 00:00:00	2011-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	3025	\N	\N	\N
3723	DELEGUEDEL	2009-09-23 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	3026	\N	\N	\N
3724	DELEGUEDEL	2009-09-23 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	3027	\N	\N	\N
3725	DELEGUEDEL	2009-09-23 00:00:00	2009-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	3028	\N	\N	\N
3726	DELEGUEDEL	2009-09-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3031	\N	\N	2014-09-28 17:34:16
3727	DELEGUEDEL	2009-09-23 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	3032	\N	\N	\N
3728	DELEGUEDEL	2009-09-23 00:00:00	2009-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	3034	\N	\N	\N
3729	DELEGUEDEL	2009-09-23 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	3035	\N	\N	\N
3730	DELEGUEDEL	2009-09-23 00:00:00	2009-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	3036	\N	\N	\N
3731	DELEGUEDEL	2009-09-23 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	3037	\N	\N	\N
3732	DELEGUEDEL	2009-09-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3038	\N	\N	\N
3733	DELEGUEDEL	2009-09-23 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	3039	\N	\N	\N
3734	DELEGUEDEL	2009-09-23 00:00:00	2009-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	3041	\N	\N	\N
3735	DELEGUEDEL	2009-09-23 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	3042	\N	\N	\N
3736	DELEGUEDEL	2009-09-23 00:00:00	2009-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	3043	\N	\N	\N
3737	DELEGUEDEL	2009-09-23 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	3044	\N	\N	\N
3738	DELEGUEDEL	2009-09-23 00:00:00	2009-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	3045	\N	\N	\N
3739	DELEGUEDEL	2009-09-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3046	\N	\N	\N
3740	DELEGUEDEL	2009-09-23 00:00:00	2010-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	3012	\N	\N	\N
3750	DELEGUEDEL	2009-09-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3049	\N	\N	2014-09-28 17:15:42
3742	DELEGUEDEL	2009-09-23 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	3013	\N	\N	\N
3743	DELEGUEDEL	2009-09-23 00:00:00	2009-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	3016	\N	\N	\N
3744	DELEGUEDEL	2009-09-23 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	3029	\N	\N	\N
3745	DELEGUEDEL	2009-09-23 00:00:00	2011-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	3040	\N	\N	\N
3746	DELEGUEDEL	2009-09-23 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	3030	\N	\N	\N
3747	DELEGUEDEL	2009-09-23 00:00:00	2009-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	3033	\N	\N	\N
3748	DELEGUEDEL	2009-09-23 00:00:00	2009-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	3047	\N	\N	\N
3749	DELEGUEDEL	2009-09-23 00:00:00	2009-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	3048	\N	\N	\N
3751	DELEGUEDEL	2009-09-23 00:00:00	2009-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	3050	\N	\N	\N
3752	DELEGUEDEL	2009-09-23 00:00:00	2009-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	3051	\N	\N	\N
3753	DELEGUEDEL	2009-09-23 00:00:00	2009-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	3052	\N	\N	\N
3754	DELEGUEDEL	2009-09-23 00:00:00	2009-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	3053	\N	\N	\N
3755	DELEGUEDEL	2009-09-23 00:00:00	2009-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	3054	\N	\N	\N
3756	DELEGUEDEL	2009-09-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3055	\N	\N	2014-09-28 13:39:21
3757	DELEGUEDEL	2009-09-23 00:00:00	2012-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	3056	\N	\N	\N
3758	DELEGUEDEL	2009-09-23 00:00:00	2012-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	3057	\N	\N	\N
3759	DELEGUEDEL	2009-09-23 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	3058	\N	\N	\N
3760	DELEGUEDEL	2009-09-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3059	\N	\N	\N
3761	DELEGUEDEL	2009-09-23 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	3060	\N	\N	\N
3762	DELEGUEDEL	2009-09-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3062	\N	\N	\N
3763	DELEGUEDEL	2009-09-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3064	\N	\N	\N
3764	DELEGUEDEL	2009-09-23 00:00:00	2009-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	3065	\N	\N	\N
3765	DELEGUEDEL	2009-09-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3066	\N	\N	\N
3766	DELEGUEDEL	2009-09-23 00:00:00	2009-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	3067	\N	\N	\N
3767	DELEGUEDEL	2009-09-23 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	3068	\N	\N	\N
3768	DELEGUEDEL	2009-09-23 00:00:00	2009-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	3069	\N	\N	\N
3769	DELEGUEDEL	2009-09-23 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	\N	3070	\N	\N	\N
3770	DELEGUEDEL	2009-09-23 00:00:00	2012-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	3071	\N	\N	\N
3771	DELEGUEDEL	2009-09-23 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	3072	\N	\N	\N
3772	DELEGUEDEL	2009-09-23 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	3073	\N	\N	\N
3773	DELEGUEDEL	2009-09-23 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	3074	\N	\N	\N
3030	DELEGUEDEL	\N	2015-02-12 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	2543	\N	\N	2015-02-13 16:06:32
3031	DELEGUEDEL	\N	2004-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	2544	\N	\N	\N
3032	DELEGUEDEL	\N	2014-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	2546	\N	\N	2014-09-28 16:59:41
3033	DELEGUEDEL	\N	2013-12-31 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	2548	\N	\N	\N
3034	DELEGUEDEL	\N	2004-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	2549	\N	\N	\N
3035	DELEGUEDEL	\N	2011-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	2550	\N	\N	\N
4233	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3544	\N	\N	\N
4234	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3545	\N	\N	2014-09-28 17:27:29
3036	SECRETDEL	\N	2008-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	2551	2	\N	\N
3037	DELEGUEDEL	\N	2004-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	2552	\N	\N	\N
3038	DELEGUEDEL	\N	2011-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	2553	\N	\N	\N
3039	DELEGUEDEL	\N	2015-02-12 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	2554	\N	\N	2015-02-13 16:06:36
3040	DELEGUEDEL	\N	2007-09-03 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	2555	\N	\N	\N
3041	DELEGUEDEL	\N	2004-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	2557	\N	\N	\N
4149	DELEGUEDEL	2011-11-16 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	3448	\N	\N	2015-01-12 18:27:48
4150	PDTDEL	2011-11-16 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	3449	\N	\N	2015-01-12 18:27:37
4170	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3470	\N	\N	\N
4171	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3471	\N	\N	\N
4172	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3472	\N	\N	\N
4175	DELEGUEDEL	2011-11-30 00:00:00	2012-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	3475	\N	\N	\N
4176	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3476	\N	\N	\N
4177	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3477	\N	\N	\N
4178	DELEGUEDEL	2011-11-30 00:00:00	2013-02-26 00:00:00	ANCIEN	\N	\N	\N	\N	3478	\N	\N	\N
4179	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3479	\N	\N	\N
4181	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3482	\N	\N	2014-09-28 12:21:28
4182	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3480	\N	\N	2014-09-28 17:40:23
4183	DELEGUEDEL	2011-11-30 00:00:00	2012-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	3483	\N	\N	\N
4184	DELEGUEDEL	2011-11-30 00:00:00	2012-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	3484	\N	\N	\N
4185	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3485	\N	\N	\N
4186	DELEGUEDEL	2011-11-30 00:00:00	2014-08-26 00:00:00	ANCIEN	\N	\N	\N	\N	3486	\N	\N	2014-08-27 16:33:38
4187	DELEGUEDEL	2011-11-30 00:00:00	2012-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	3487	\N	\N	\N
4188	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3488	\N	\N	\N
4189	DELEGUEDEL	2011-11-30 00:00:00	2011-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	3489	\N	\N	\N
4190	DELEGUEDEL	2011-11-30 00:00:00	2012-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	3490	\N	\N	\N
4191	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3491	\N	\N	\N
4192	DELEGUEDEL	2011-11-30 00:00:00	2013-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	3492	\N	\N	\N
4193	DELEGUEDEL	2011-11-30 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	3493	\N	\N	\N
4194	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3495	\N	\N	\N
4195	DELEGUEDEL	2011-11-30 00:00:00	2012-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	3496	\N	\N	\N
4196	DELEGUEDEL	2011-11-30 00:00:00	2011-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	3497	\N	\N	\N
4197	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3498	\N	\N	\N
4198	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3499	\N	\N	\N
4199	DELEGUEDEL	2011-11-30 00:00:00	2012-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	3500	\N	\N	\N
4200	DELEGUEDEL	2011-11-30 00:00:00	2014-07-01 00:00:00	ANCIEN	\N	\N	\N	\N	3501	\N	\N	2014-07-01 09:29:54
4201	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3503	\N	\N	\N
4202	DELEGUEDEL	2011-11-30 00:00:00	2011-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	3505	\N	\N	\N
4203	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3508	\N	\N	\N
4205	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3509	\N	\N	2014-09-28 17:27:35
4206	DELEGUEDEL	2011-11-30 00:00:00	2012-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	3510	\N	\N	\N
4209	DELEGUEDEL	2011-11-30 00:00:00	2011-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	3516	\N	\N	\N
4204	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3507	\N	\N	\N
4208	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3515	\N	\N	\N
4210	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3517	\N	\N	\N
4211	DELEGUEDEL	2011-11-30 00:00:00	2011-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	3518	\N	\N	\N
4212	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3519	\N	\N	\N
4213	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3520	\N	\N	\N
4214	DELEGUEDEL	2011-11-30 00:00:00	2011-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	3521	\N	\N	\N
4215	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3523	\N	\N	\N
4216	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3524	\N	\N	2014-09-29 09:05:47
4217	DELEGUEDEL	2011-11-30 00:00:00	2011-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	3525	\N	\N	\N
4218	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3528	\N	\N	\N
4219	DELEGUEDEL	2011-11-30 00:00:00	2011-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	3529	\N	\N	\N
4220	DELEGUEDEL	2011-11-30 00:00:00	2011-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	3530	\N	\N	\N
4221	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3531	\N	\N	2014-09-28 17:00:59
4222	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3532	\N	\N	\N
4223	DELEGUEDEL	2011-11-30 00:00:00	2011-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	3533	\N	\N	\N
4224	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3534	\N	\N	\N
4226	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3536	\N	\N	2014-09-28 17:38:26
4227	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3537	\N	\N	\N
4228	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3538	\N	\N	\N
4229	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3539	\N	\N	2014-09-28 13:09:05
4230	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3540	\N	\N	\N
4231	DELEGUEDEL	2011-11-30 00:00:00	2011-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	3542	\N	\N	\N
4232	DELEGUEDEL	2011-11-30 00:00:00	2011-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	3543	\N	\N	\N
4235	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3546	\N	\N	\N
4236	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3548	\N	\N	\N
4237	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3549	\N	\N	2014-10-01 11:16:13
4238	DELEGUEDEL	2011-11-30 00:00:00	2011-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	3550	\N	\N	\N
4239	DELEGUEDEL	2011-11-30 00:00:00	2011-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	3551	\N	\N	\N
4240	DELEGUEDEL	2011-11-30 00:00:00	2012-10-30 00:00:00	ANCIEN	\N	\N	\N	\N	3552	\N	\N	\N
4242	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3554	\N	\N	2014-09-28 17:34:16
4243	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3555	\N	\N	\N
4244	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3556	\N	\N	2014-09-28 16:59:41
4245	DELEGUEDEL	2011-11-30 00:00:00	2013-02-26 00:00:00	ANCIEN	\N	\N	\N	\N	3557	\N	\N	\N
4246	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3558	\N	\N	\N
4247	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3559	\N	\N	\N
4248	DELEGUEDEL	2011-11-30 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	3560	\N	\N	\N
4249	DELEGUEDEL	2011-11-30 00:00:00	2011-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	3561	\N	\N	\N
4250	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3562	\N	\N	\N
4251	DELEGUEDEL	2011-11-30 00:00:00	2011-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	3563	\N	\N	\N
4252	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3564	\N	\N	\N
4253	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3565	\N	\N	2014-09-29 09:05:47
4254	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3566	\N	\N	\N
4255	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3567	\N	\N	\N
4256	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3568	\N	\N	\N
4257	DELEGUEDEL	2011-11-30 00:00:00	2014-07-01 00:00:00	ANCIEN	\N	\N	\N	\N	3569	\N	\N	2014-07-01 09:29:54
4258	DELEGUEDEL	2011-11-30 00:00:00	2013-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3570	\N	\N	\N
4259	DELEGUEDEL	2011-11-30 00:00:00	2014-09-16 00:00:00	ANCIEN	\N	\N	\N	\N	3571	\N	\N	2014-09-16 14:55:28
4260	DELEGUEDEL	2011-11-30 00:00:00	2011-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	3572	\N	\N	\N
4261	DELEGUEDEL	2011-11-30 00:00:00	2011-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	3573	\N	\N	\N
4262	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3574	\N	\N	\N
4263	DELEGUEDEL	2011-11-30 00:00:00	2011-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	3575	\N	\N	\N
4264	DELEGUEDEL	2011-11-30 00:00:00	2011-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	3576	\N	\N	\N
4265	DELEGUEDEL	2011-11-30 00:00:00	2011-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	3579	\N	\N	\N
4267	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3581	\N	\N	\N
4268	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3582	\N	\N	\N
4269	DELEGUEDEL	2011-11-30 00:00:00	2011-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	3583	\N	\N	\N
4270	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3584	\N	\N	\N
4271	DELEGUEDEL	2011-11-30 00:00:00	2011-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	3585	\N	\N	\N
4272	DELEGUEDEL	2011-11-30 00:00:00	2011-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	3586	\N	\N	\N
4370	VICPDTDEL	2011-12-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3525	\N	\N	2014-09-28 17:05:42
4330	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1136	\N	\N	\N
4331	DELEGUEDEL	2011-11-30 00:00:00	2011-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	2958	\N	\N	\N
4332	DELEGUEDEL	2011-11-30 00:00:00	2011-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	880	\N	\N	\N
4349	DELEGUEDEL	2011-11-30 00:00:00	2011-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	3547	\N	\N	\N
4369	PDTDEL	2011-12-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3040	\N	\N	\N
4371	VICPDTDEL	2011-12-07 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	3529	\N	\N	\N
4372	VICPDTDEL	2011-12-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3530	\N	\N	\N
4373	VICPDTDEL	2011-12-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3033	\N	\N	2014-09-28 13:40:33
4374	VICPDTDEL	2011-12-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3023	\N	\N	\N
4376	VICPDTDEL	2011-12-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3036	\N	\N	2014-09-28 13:21:47
4377	VICPDTDEL	2011-12-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3025	\N	\N	\N
4378	VICPDTDEL	2011-12-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3542	\N	\N	\N
4379	SECRETDEL	2011-12-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3018	\N	\N	\N
4380	SECRETDEL	2011-12-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3533	\N	\N	\N
4381	PDTDEL	2011-12-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3575	\N	\N	\N
4382	VICPDTDEL	2011-12-07 00:00:00	2012-10-30 00:00:00	ANCIEN	\N	\N	\N	\N	3547	\N	\N	\N
4384	VICPDTDEL	2011-12-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3550	\N	\N	\N
4385	VICPDTDEL	2011-12-07 00:00:00	2014-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	3551	\N	\N	2014-02-21 11:14:03
4387	VICPDTDEL	2011-12-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3573	\N	\N	\N
4388	VICPDTDEL	2011-12-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3579	\N	\N	\N
4390	VICPDTDEL	2011-12-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3583	\N	\N	2014-09-29 09:08:32
4391	VICPDTDEL	2011-12-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3585	\N	\N	\N
4289	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3588	\N	\N	\N
4291	DELEGUEDEL	2011-11-30 00:00:00	2012-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	3590	\N	\N	\N
4292	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3593	\N	\N	\N
4307	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3597	\N	\N	2014-09-28 17:07:07
4294	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3016	\N	\N	\N
4295	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3594	\N	\N	2014-09-28 17:03:41
4308	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3598	\N	\N	2014-09-28 17:27:35
4297	DELEGUEDEL	2011-11-30 00:00:00	2011-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	3018	\N	\N	\N
4299	DELEGUEDEL	2011-11-30 00:00:00	2011-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	3033	\N	\N	\N
4300	DELEGUEDEL	2011-11-30 00:00:00	2011-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	3041	\N	\N	\N
4310	DELEGUEDEL	2011-11-30 00:00:00	2013-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	3511	\N	\N	\N
4302	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3045	\N	\N	\N
4303	DELEGUEDEL	2011-11-30 00:00:00	2011-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	3036	\N	\N	\N
4304	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3541	\N	\N	\N
4305	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3595	\N	\N	\N
4306	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3596	\N	\N	\N
4312	DELEGUEDEL	2011-11-30 00:00:00	2012-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	3053	\N	\N	\N
4313	DELEGUEDEL	2011-11-30 00:00:00	2012-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	3051	\N	\N	\N
4314	DELEGUEDEL	2011-11-30 00:00:00	2012-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	3067	\N	\N	\N
4315	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3077	\N	\N	\N
4316	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3469	\N	\N	\N
4317	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3473	\N	\N	\N
4318	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3474	\N	\N	\N
4319	DELEGUEDEL	2011-11-30 00:00:00	2012-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	2941	\N	\N	\N
4320	DELEGUEDEL	2011-11-30 00:00:00	2012-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	1166	\N	\N	\N
4395	SECRETDEL	2011-12-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3576	\N	\N	\N
4396	VICPDTDEL	2011-12-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3561	\N	\N	\N
4410	DELEGUEDEL	2011-12-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3628	\N	\N	2014-09-28 13:39:21
4411	DELEGUEDEL	2011-12-07 00:00:00	2014-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	3629	\N	\N	2014-12-10 16:23:35
4429	DELEGUEDEL	2011-12-07 00:00:00	2011-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	2795	\N	\N	2016-01-27 14:17:27
4470	VICPDTDEL	2011-12-14 00:00:00	2014-10-28 00:00:00	ANCIEN	\N	\N	\N	\N	2954	\N	\N	2014-10-29 11:08:36
4417	DELEGUEDEL	2011-12-07 00:00:00	2017-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	3632	\N	\N	2017-11-28 10:07:59
4418	DELEGUEDEL	2011-12-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	3633	\N	\N	2017-09-24 16:43:43
4419	DELEGUEDEL	2011-12-07 00:00:00	2012-10-23 00:00:00	ANCIEN	\N	\N	\N	\N	3634	\N	\N	\N
4420	DELEGUEDEL	2011-12-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3635	\N	\N	2014-09-28 17:38:26
4421	DELEGUEDEL	2011-12-07 00:00:00	2012-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	3636	\N	\N	\N
4422	SECRETDEL	2011-12-07 00:00:00	2013-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	3637	\N	\N	\N
4423	VICPDTDEL	2011-12-07 00:00:00	2014-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	3638	1	\N	2014-12-10 16:22:21
4424	DELEGUEDEL	2011-12-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3639	\N	\N	2014-09-28 17:52:18
4469	PDTDEL	2011-12-14 00:00:00	2014-10-28 00:00:00	ANCIEN	\N	\N	\N	\N	3516	\N	\N	2014-10-29 11:07:25
4471	VICPDTDEL	2011-12-14 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3497	\N	\N	2014-09-28 17:07:41
4472	VICPDTDEL	2011-12-14 00:00:00	2014-10-28 00:00:00	ANCIEN	\N	\N	\N	\N	3505	\N	\N	2014-10-29 11:08:42
4473	VICPDTDEL	2011-12-14 00:00:00	2014-10-28 00:00:00	ANCIEN	\N	\N	\N	\N	869	\N	\N	2014-10-29 11:08:39
4474	VICPDTDEL	2011-12-14 00:00:00	2014-10-28 00:00:00	ANCIEN	\N	\N	\N	\N	3148	\N	\N	2014-10-29 11:08:46
4475	VICPDTDEL	2011-12-14 00:00:00	2014-10-28 00:00:00	ANCIEN	\N	\N	\N	\N	3518	\N	\N	2014-10-29 11:08:48
4477	VICPDTDEL	2011-12-14 00:00:00	2014-09-01 00:00:00	ANCIEN	\N	\N	\N	\N	880	\N	\N	2014-09-01 10:21:13
4478	SECRETDEL	2011-12-14 00:00:00	2014-10-28 00:00:00	ANCIEN	\N	\N	\N	\N	3489	\N	\N	2014-11-03 09:53:41
4491	DELEGUEDEL	2011-11-01 00:00:00	2014-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	3670	\N	\N	2014-12-09 17:05:07
4531	DELTITDEL	2011-12-13 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3710	\N	\N	\N
4532	DELTITDEL	2011-12-13 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	943	\N	\N	\N
4533	DELTITDEL	2011-12-13 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2892	\N	\N	\N
4534	DELTITDEL	2011-12-13 00:00:00	2013-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	3711	\N	\N	\N
4535	DELSUPDEL	2011-12-13 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3712	\N	\N	2014-09-28 12:44:31
1423	VICPDTDEL	2005-01-19 00:00:00	2009-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	1195	\N	\N	\N
1424	DELEGUEDEL	2005-01-19 00:00:00	2009-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	1196	\N	\N	\N
1425	DELEGUEDEL	2005-01-19 00:00:00	2009-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	1197	\N	\N	\N
1428	DELEGUEDEL	2005-01-19 00:00:00	2009-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	1200	\N	\N	\N
1429	DELEGUEDEL	2005-01-19 00:00:00	2009-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	1201	\N	\N	\N
1430	DELEGUEDEL	2005-01-19 00:00:00	2009-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	1202	\N	\N	\N
1431	DELEGUEDEL	2005-01-19 00:00:00	2009-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	1203	\N	\N	\N
1432	DELEGUEDEL	2005-01-19 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1204	\N	\N	\N
1433	DELEGUEDEL	2005-01-19 00:00:00	2009-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	1205	\N	\N	\N
1436	DELEGUEDEL	2005-03-02 00:00:00	2010-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	1149	\N	\N	\N
1437	DELEGUEDEL	2005-03-02 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	1142	\N	\N	\N
1438	DELEGUEDEL	2005-03-02 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	1152	\N	\N	\N
2950	VICPDTPREDEL	\N	2009-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	2379	\N	\N	\N
2951	VICPDTDEL	\N	2009-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	2380	1	\N	\N
2952	DELEGUEDEL	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2381	\N	\N	\N
3189	DELEGUEDEL	2007-07-25 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	2688	\N	\N	\N
3269	PDTDEL	2007-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2374	\N	\N	\N
3289	DELEGUEDEL	2007-10-10 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	2773	\N	\N	\N
3290	DELEGUEDEL	2007-10-10 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	2774	\N	\N	2015-06-12 16:01:25
3291	DELEGUEDEL	2007-10-10 00:00:00	2012-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2775	\N	\N	\N
3292	DELEGUEDEL	2011-01-02 00:00:00	2011-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2772	\N	\N	\N
3310	PDTDRTDEL	2006-01-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2791	\N	\N	\N
3314	DELEGUEDEL	2006-01-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2794	\N	\N	\N
3312	DELEGUEDEL	2006-01-23 00:00:00	2011-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	2792	\N	\N	\N
3313	DELEGUEDEL	2006-01-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2793	\N	\N	\N
3315	DELEGUEDEL	2006-01-23 00:00:00	2008-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	2795	\N	\N	\N
3316	DELEGUEDEL	2006-01-23 00:00:00	2008-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	2796	\N	\N	\N
3317	DELEGUEDEL	2006-01-23 00:00:00	2008-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	2797	\N	\N	\N
3318	DELEGUEDEL	2006-01-23 00:00:00	2008-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	2798	\N	\N	\N
3319	DELEGUEDEL	2006-01-23 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2799	\N	\N	\N
3320	SECRETDEL	2006-01-23 00:00:00	2014-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	2800	\N	\N	2014-12-10 16:22:59
3321	DELEGUEDEL	2006-01-23 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	2801	\N	\N	\N
3322	VICPDTPREDEL	2007-12-12 00:00:00	2008-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2772	\N	\N	\N
3449	DELTITDEL	2008-10-28 00:00:00	2011-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	944	\N	\N	\N
3450	VICPDTDEL	2008-10-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	939	3	\N	\N
3451	DELTITDEL	2008-10-28 00:00:00	2008-11-25 00:00:00	ANCIEN	\N	\N	\N	\N	2888	\N	\N	\N
3454	DELSUPDEL	2008-10-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2890	\N	\N	\N
3455	DELSUPDEL	2008-10-28 00:00:00	2014-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	2891	\N	\N	2014-10-21 17:13:50
3456	VICPDTDEL	2008-10-28 00:00:00	2011-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	2892	1	\N	\N
3489	DELEGUEDEL	2008-11-04 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	2929	\N	\N	\N
3490	DELEGUEDEL	2008-11-04 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	2931	\N	\N	\N
3491	DELEGUEDEL	2008-11-04 00:00:00	2008-11-11 00:00:00	ANCIEN	\N	\N	\N	\N	2932	\N	\N	\N
3492	DELEGUEDEL	2008-11-04 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	2933	\N	\N	\N
3493	DELEGUEDEL	2008-11-04 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	2934	\N	\N	\N
3495	DELEGUEDEL	2008-11-04 00:00:00	2008-11-11 00:00:00	ANCIEN	\N	\N	\N	\N	2936	\N	\N	\N
3470	PDTDEL	2008-11-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2909	\N	\N	\N
3497	DELEGUEDEL	2008-11-04 00:00:00	2008-11-11 00:00:00	ANCIEN	\N	\N	\N	\N	901	\N	\N	\N
3499	DELEGUEDEL	2008-11-04 00:00:00	2008-11-11 00:00:00	ANCIEN	\N	\N	\N	\N	904	\N	\N	\N
3500	DELEGUEDEL	2008-11-04 00:00:00	2008-11-11 00:00:00	ANCIEN	\N	\N	\N	\N	905	\N	\N	\N
3501	DELEGUEDEL	2008-11-04 00:00:00	2008-11-11 00:00:00	ANCIEN	\N	\N	\N	\N	906	\N	\N	\N
3529	PDTDEL	2008-11-12 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	2936	\N	\N	\N
3504	DELEGUEDEL	2008-11-04 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2939	\N	\N	\N
3505	DELEGUEDEL	2008-11-04 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	2940	\N	\N	\N
3506	DELEGUEDEL	2008-11-04 00:00:00	2011-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	2941	\N	\N	\N
3507	VICPDTPREDEL	2008-11-04 00:00:00	2010-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	932	\N	\N	\N
3531	VICPDTDEL	2008-11-12 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	901	\N	\N	\N
3509	DELEGUEDEL	2008-11-04 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2944	\N	\N	2014-09-28 13:39:20
3510	DELEGUEDEL	2008-11-04 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	2945	\N	\N	\N
3511	DELEGUEDEL	2008-11-04 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	1005	\N	\N	\N
3513	DELEGUEDEL	2008-11-04 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	2946	\N	\N	\N
3514	DELEGUEDEL	2008-11-04 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	1186	\N	\N	\N
3515	DELEGUEDEL	2008-11-04 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	2947	\N	\N	\N
3530	VICPDTDEL	2008-11-12 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	1112	\N	\N	\N
3532	VICPDTDEL	2008-11-12 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	906	\N	\N	\N
3533	VICPDTDEL	2008-11-12 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	905	\N	\N	\N
3534	SECRETDEL	2008-11-12 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	904	\N	\N	\N
3535	SECRETDEL	2008-11-12 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	2932	\N	\N	\N
4329	DELEGUEDEL	2011-11-30 00:00:00	2011-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	869	\N	\N	\N
1312	VICPDTDEL	2004-10-13 00:00:00	2008-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	1130	3	\N	\N
3589	VICPDTDEL	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2888	2	\N	\N
3609	PDTDEL	2008-12-03 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	2949	\N	\N	\N
3610	VICPDTDEL	2008-12-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2962	1	\N	\N
3611	VICPDTDEL	2008-12-03 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	869	2	\N	\N
3612	VICPDTDEL	2008-12-03 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	1136	3	\N	\N
3613	VICPDTDEL	2008-12-03 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	880	4	\N	\N
3614	VICPDTDEL	2008-12-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1119	5	\N	\N
3615	VICPDTDEL	2008-12-03 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	2961	6	\N	\N
3616	VICPDTDEL	2008-12-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2729	7	\N	\N
3617	VICPDTDEL	2008-12-03 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	2958	8	\N	\N
152	DELSUPDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Problemes demographiques/ Choix scientifiques et technologiques (suppleant)/ 	152	\N	\N	\N
153	DELEGUEDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Problemes demographiques/ Choix scientifiques et technologiques (suppleant)/ 	153	\N	\N	\N
158	DELEGUEDEL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'evaluation des politiques publiques/ 	158	\N	\N	\N
159	DELEGUEDEL	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'evaluation des politiques publiques/ 	159	\N	\N	\N
160	DELEGUEDEL	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'evaluation des politiques publiques/ 	160	\N	\N	\N
161	DELEGUEDEL	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Choix scientifiques et technologiques (titulaire)/ Office parlementaire d'evaluation des politiques publiques/ 	161	\N	\N	\N
162	DELEGUEDEL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	Planification/ Office parlementaire d'evaluation des politiques publiques/ 	162	\N	\N	\N
163	DELEGUEDEL	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'evaluation des politiques publiques/ 	163	\N	\N	\N
164	DELEGUEDEL	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ Office parlementaire d'evaluation des politiques publiques/ 	164	\N	\N	\N
165	DELEGUEDEL	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Choix scientifiques et technologiques (titulaire)/ Office parlementaire d'evaluation des politiques publiques/ 	165	\N	\N	\N
166	DELEGUEDEL	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ Office parlementaire d'evaluation des politiques publiques/ 	166	\N	\N	\N
167	DELEGUEDEL	\N	1992-09-26 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'evaluation des politiques publiques/ 	167	\N	\N	\N
168	DELEGUEDEL	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'evaluation des politiques publiques/ 	168	\N	\N	\N
169	DELEGUEDEL	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'evaluation des politiques publiques/ 	169	\N	\N	\N
170	DELEGUEDEL	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Planification/ Office parlementaire d'evaluation des politiques publiques/ 	170	\N	\N	\N
171	DELEGUEDEL	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'evaluation des politiques publiques/ 	171	\N	\N	\N
172	DELEGUEDEL	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'evaluation des politiques publiques/ 	172	\N	\N	\N
173	DELEGUEDEL	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'evaluation des politiques publiques/ 	173	\N	\N	\N
174	DELEGUEDEL	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'evaluation de la legislation/ Union Europeenne/ 	174	\N	\N	\N
175	DELEGUEDEL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'evaluation de la legislation/ 	175	\N	\N	\N
176	DELEGUEDEL	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Problemes demographiques/ Office parlementaire d'evaluation de la legislation/ 	176	\N	\N	\N
177	DELEGUEDEL	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Choix scientifiques et technologiques (suppleant)/ Office parlementaire d'evaluation de la legislation/ 	177	\N	\N	\N
178	DELEGUEDEL	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ Office parlementaire d'evaluation de la legislation/ 	178	\N	\N	\N
179	DELEGUEDEL	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'evaluation de la legislation/ 	179	\N	\N	\N
180	DELEGUEDEL	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'evaluation de la legislation/ 	180	\N	\N	\N
100	DELEGUEDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	100	\N	\N	\N
101	DELEGUEDEL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	101	\N	\N	\N
102	DELEGUEDEL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	102	\N	\N	\N
103	DELEGUEDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	103	\N	\N	\N
104	DELEGUEDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Problemes demographiques/ Office parlementaire d'evaluation de la legislation/ 	104	\N	\N	\N
105	DELEGUEDEL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	Problemes demographiques/ 	105	\N	\N	\N
106	DELEGUEDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Problemes demographiques/ Union  europeenne/ 	106	\N	\N	\N
107	DELEGUEDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Problemes demographiques/ Choix scientifiques et technologiques (suppleant)/ 	107	\N	\N	\N
109	DELEGUEDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Problemes demographiques/ 	109	\N	\N	\N
110	DELEGUEDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Problemes demographiques/ 	110	\N	\N	\N
111	DELEGUEDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Problemes demographiques/ Choix scientifiques et technologiques (suppleant)/ 	111	\N	\N	\N
112	DELEGUEDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Problemes demographiques/ 	112	\N	\N	\N
113	DELEGUEDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Problemes demographiques/ Office parlementaire d'evaluation de la legislation/ 	113	\N	\N	\N
114	DELEGUEDEL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	Planification/ 	114	\N	\N	\N
115	DELEGUEDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Planification/ 	115	\N	\N	\N
116	DELEGUEDEL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	Planification/ 	116	\N	\N	\N
117	DELEGUEDEL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	Planification/ 	117	\N	\N	\N
118	DELEGUEDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Planification/ 	118	\N	\N	\N
119	DELEGUEDEL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	Planification/ Office parlementaire d'evaluation des politiques publiques/ 	119	\N	\N	\N
120	DELEGUEDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Planification/ 	120	\N	\N	\N
121	DELEGUEDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Planification/ 	121	\N	\N	\N
122	DELEGUEDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Planification/ 	122	\N	\N	\N
123	DELEGUEDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Planification/ 	123	\N	\N	\N
124	DELEGUEDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Planification/ 	124	\N	\N	\N
125	DELEGUEDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Planification/ Office parlementaire d'evaluation des politiques publiques/ 	125	\N	\N	\N
126	DELEGUEDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Planification/ 	126	\N	\N	\N
127	DELEGUEDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Planification/ 	127	\N	\N	\N
128	DELEGUEDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Planification/ 	128	\N	\N	\N
142	DELTITDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Choix scientifiques et technologiques (titulaire)/ 	142	\N	\N	\N
143	DELTITDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Choix scientifiques et technologiques (titulaire)/ 	143	\N	\N	\N
144	DELTITDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Choix scientifiques et technologiques (titulaire)/ Office parlementaire d'evaluation des politiques publiques/ 	144	\N	\N	\N
148	DELTITDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Choix scientifiques et technologiques (titulaire)/ Office parlementaire d'evaluation des politiques publiques/ 	148	\N	\N	\N
150	DELTITDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Choix scientifiques et technologiques (titulaire)/ 	150	\N	\N	\N
155	DELTITDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ Choix scientifiques et technologiques (titulaire)/ 	155	\N	\N	\N
156	DELTITDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Choix scientifiques et technologiques (titulaire)/ 	156	\N	\N	\N
157	DELTITDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Choix scientifiques et technologiques (titulaire)/ 	157	\N	\N	\N
145	DELSUPDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Choix scientifiques et technologiques (suppleant)/ 	145	\N	\N	\N
146	DELSUPDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Choix scientifiques et technologiques (suppleant)/ 	146	\N	\N	\N
23	DELTITDEL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	Conseil de l'Europe (delegue titulaire)/ Union de l'Europe occidentale (delegue titulaire)/ 	23	\N	\N	\N
27	DELTITDEL	\N	1998-10-20 00:00:00	ANCIEN	\N	\N	\N	Conseil de l'Europe (delegue titulaire)/ Union de l'Europe occidentale (delegue titulaire)/ Haute Cour de Justice (juge titulaire)/ 	27	\N	\N	\N
28	DELTITDEL	\N	1998-10-20 00:00:00	ANCIEN	\N	\N	\N	Conseil de l'Europe (delegue titulaire)/ Union de l'Europe occidentale (delegue titulaire)/ 	28	\N	\N	\N
31	DELTITDEL	\N	1998-10-20 00:00:00	ANCIEN	\N	\N	\N	Conseil de l'Europe (delegue titulaire)/ Union de l'Europe occidentale (delegue titulaire)/ 	31	\N	\N	\N
24	DELSUPDEL	\N	1998-10-20 00:00:00	ANCIEN	\N	\N	\N	Conseil de l'Europe (delegue suppleant)/ Union de l'Europe occidentale (delegue suppleant)/ 	24	\N	\N	\N
25	DELSUPDEL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	Conseil de l'Europe (delegue suppleant)/ Union de l'Europe occidentale (delegue suppleant)/ 	25	\N	\N	\N
26	DELSUPDEL	\N	1998-10-20 00:00:00	ANCIEN	\N	\N	\N	Conseil de l'Europe (delegue suppleant)/ Union de l'Europe occidentale (delegue suppleant)/ 	26	\N	\N	\N
29	DELSUPDEL	\N	1998-10-20 00:00:00	ANCIEN	\N	\N	\N	Conseil de l'Europe (delegue suppleant)/ Union de l'Europe occidentale (delegue suppleant)/ 	29	\N	\N	\N
68	DELEGUEDEL	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	68	\N	\N	\N
3052	AUTFONDEL	\N	2008-04-18 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre du bureau de la section française de l'Assemblée Parlementaire de la Francophonie	Membre du bureau de la section française de l'Assemblée Parlementaire de la Francophonie	2533	\N	\N	\N
3053	DELEGUEDEL	\N	2011-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre du bureau de la section française de l'Assemblée Parlementaire de la Francophonie	Membre du bureau de la section française de l'Assemblée Parlementaire de la Francophonie	2537	\N	\N	\N
3350	DELEGUEDEL	2007-10-10 00:00:00	2011-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	2829	\N	\N	\N
3054	AUTFONDEL	\N	2011-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre du bureau de la section française de l'Assemblée Parlementaire de la Francophonie	Membre du bureau de la section française de l'Assemblée Parlementaire de la Francophonie	2545	7	\N	\N
3055	AUTFONDEL	\N	2004-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre du bureau de la section française de l'Assemblée Parlementaire de la Francophonie	Membre du bureau de la section française de l'Assemblée Parlementaire de la Francophonie	2559	\N	\N	\N
4009	DELEGUEDEL	\N	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	3308	\N	\N	2015-02-13 16:06:24
4010	DELEGUEDEL	\N	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	3309	\N	\N	2015-02-13 16:06:24
3056	AUTFONDEL	\N	2004-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre du bureau de la section française de l'Assemblée Parlementaire de la Francophonie	Membre du bureau de la section française de l'Assemblée Parlementaire de la Francophonie	2561	\N	\N	\N
3057	VICPDTPREDEL	\N	2004-09-30 00:00:00	ANCIEN	\N	1er VP de la section française de l'Assemblée Parlementaire 	Premier vice-président de la section française de l'Assemblée Parlementaire de la Francophonie	Premier vice-président de la section française de l'Assemblée Parlementaire de la Francophonie	2568	\N	\N	\N
3058	DELEGUEDEL	\N	2011-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Secrétaire de la section française de l'Assemblée Parlementaire de la Francophonie	Secrétaire de la section française de l'Assemblée Parlementaire de la Francophonie	2512	\N	\N	\N
3059	DELEGUEDEL	\N	2008-09-07 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Secrétaire de la section française de l'Assemblée Parlementaire de la Francophonie	Secrétaire de la section française de l'Assemblée Parlementaire de la Francophonie	2528	\N	\N	\N
3229	DELEGUEDEL	2007-10-03 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2731	\N	\N	\N
3774	DELEGUEDEL	2009-09-23 00:00:00	2009-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	3075	\N	\N	\N
3775	DELEGUEDEL	2009-09-23 00:00:00	2009-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	3076	\N	\N	\N
3776	DELEGUEDEL	2009-09-23 00:00:00	2009-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	3077	\N	\N	\N
3777	DELEGUEDEL	2009-09-23 00:00:00	2009-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	3078	\N	\N	\N
3778	DELEGUEDEL	2009-09-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3079	\N	\N	\N
3779	DELEGUEDEL	2009-09-23 00:00:00	2009-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	3080	\N	\N	\N
3780	DELEGUEDEL	2009-09-23 00:00:00	2009-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	3083	\N	\N	\N
3809	PDTDEL	2009-10-07 00:00:00	2010-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	3022	\N	\N	\N
3810	VICPDTDEL	2009-10-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3014	\N	\N	\N
3811	VICPDTDEL	2009-10-07 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	3018	\N	\N	\N
3812	VICPDTDEL	2009-10-07 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	3033	\N	\N	\N
3813	VICPDTDEL	2009-10-07 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	3041	\N	\N	\N
3814	VICPDTDEL	2009-10-07 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	3045	\N	\N	\N
3815	VICPDTDEL	2009-10-07 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	3036	\N	\N	\N
3816	VICPDTDEL	2009-10-07 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	3047	\N	\N	\N
3817	VICPDTDEL	2009-10-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3043	\N	\N	\N
3818	SECRETDEL	2009-10-07 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	3016	\N	\N	\N
3819	SECRETDEL	2009-10-07 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	3028	\N	\N	\N
3080	DELEGUEDEL	\N	2009-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	2585	\N	\N	\N
3990	AUTFONDEL	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3289	\N	\N	\N
3972	DELEGUEDEL	\N	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	3270	\N	\N	2015-02-13 16:06:14
3991	DELEGUEDEL	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3290	\N	\N	\N
3992	DELEGUEDEL	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3291	\N	\N	2014-09-28 16:50:17
3995	DELEGUEDEL	\N	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	3294	\N	\N	2015-02-13 16:06:19
3996	DELEGUEDEL	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3295	\N	\N	2014-09-28 13:21:47
3997	DELEGUEDEL	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3296	\N	\N	\N
3998	DELEGUEDEL	\N	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	3297	\N	\N	2015-02-13 16:06:31
4002	DELEGUEDEL	\N	2015-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	3301	\N	\N	2015-02-13 16:06:35
4003	DELEGUEDEL	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3302	\N	\N	2014-09-28 16:50:17
4004	DELEGUEDEL	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3303	\N	\N	\N
4005	DELEGUEDEL	\N	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	3304	\N	\N	2015-02-13 16:06:16
4006	DELEGUEDEL	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3305	\N	\N	2014-09-28 12:32:23
3060	SECRETDEL	\N	2011-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Secrétaire de la section française de l'Assemblée Parlementaire de la Francophonie	Secrétaire de la section française de l'Assemblée Parlementaire de la Francophonie	2560	3	\N	\N
3061	DELEGUEDEL	\N	2008-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Secrétaire de la section française de l'Assemblée Parlementaire de la Francophonie	Secrétaire de la section française de l'Assemblée Parlementaire de la Francophonie	2567	\N	\N	\N
3062	SECRETGENDEL	\N	2015-01-08 00:00:00	ANCIEN	\N	Secrét de la section française de l'Assemblée Parlementaire 	Secrétaire général de la section française de l'Assemblée Parlementaire de la Francophonie	Secrétaire général de la section française de l'Assemblée Parlementaire de la Francophonie	2547	\N	\N	2015-01-08 17:14:29
3015	SECRETDEL	\N	2011-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	2525	4	\N	\N
3016	DELEGUEDEL	\N	2015-02-12 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	2526	\N	\N	2015-02-13 16:06:20
3017	DELEGUEDEL	\N	2009-03-01 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	2527	\N	\N	\N
3018	DELEGUEDEL	\N	2015-02-12 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	2529	\N	\N	2015-02-13 16:06:21
3019	DELEGUEDEL	\N	2008-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	2530	\N	\N	\N
3020	TRESORDEL	\N	2015-02-12 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	2531	\N	\N	2015-02-13 16:06:07
3063	VICPDTDELDEL	\N	2014-09-30 00:00:00	ANCIEN	\N	Trésorier de la sect° française de l'Assemblée Parlement 	Trésorier de la section française de l'Assemblée Parlementaire de la Francophonie	Trésorier de la section française de l'Assemblée Parlementaire de la Francophonie	2517	\N	\N	2014-09-28 18:19:47
3064	TRESORADJDEL	\N	2002-06-07 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Trésorier adjoint de la section française de l'Assemblée Parlementaire de la Francophonie	Trésorier adjoint de la section française de l'Assemblée Parlementaire de la Francophonie	2523	\N	\N	\N
3065	VICPDTDELDEL	\N	2004-09-30 00:00:00	ANCIEN	\N	VP dél de la section française de l'Assemblée Parlementaire 	Vice président délégué de la section française de l'Assemblée Parlementaire de la Francophonie	Vice président délégué de la section française de l'Assemblée Parlementaire de la Francophonie	2556	\N	\N	\N
3156	DELEGUEDEL	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2663	\N	\N	\N
3157	DELEGUEDEL	\N	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	\N	2664	\N	\N	\N
3158	DELEGUEDEL	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2665	\N	\N	\N
3067	DELEGUEDEL	2002-02-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	Membre de la délégation au Comité des régions de l'Union eur	Membre de la délégation au Comité des régions de l'Union européenne	Membre de la délégation au Comité des régions de l'Union européenne	2570	\N	\N	\N
3073	AUTFONDEL	\N	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	2577	\N	\N	2015-02-13 16:06:09
3074	DELEGUEDEL	\N	2015-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	2579	\N	\N	2015-02-13 15:49:59
3076	DELEGUEDEL	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2581	\N	\N	2014-09-28 17:27:35
3077	DELEGUEDEL	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2582	\N	\N	\N
3078	VICPDTDEL	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2583	1	\N	\N
3079	DELEGUEDEL	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2584	\N	\N	2014-09-28 16:50:17
3082	DELEGUEDEL	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2587	\N	\N	\N
3083	DELEGUEDEL	\N	2012-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2588	\N	\N	\N
3084	DELEGUEDEL	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2589	\N	\N	\N
3085	DELEGUEDEL	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2590	\N	\N	\N
3087	SECRETDEL	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2592	1	\N	\N
3088	DELEGUEDEL	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2593	\N	\N	\N
3089	DELEGUEDEL	\N	2015-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	2594	\N	\N	2015-02-13 15:49:55
3090	DELEGUEDEL	\N	2015-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	2595	\N	\N	2015-02-13 15:49:56
3091	DELEGUEDEL	\N	2015-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	2596	\N	\N	2015-02-13 15:49:58
3093	DELEGUEDEL	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2598	\N	\N	2014-09-28 13:21:47
3094	DELEGUEDEL	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2599	\N	\N	\N
3095	DELEGUEDEL	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2600	\N	\N	2014-09-28 12:56:42
3096	DELEGUEDEL	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2601	\N	\N	2014-09-28 16:42:05
3097	DELEGUEDEL	\N	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	2602	\N	\N	\N
3098	VICPDTDEL	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2603	2	\N	\N
3099	DELEGUEDEL	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2604	\N	\N	\N
3101	DELEGUEDEL	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2606	\N	\N	\N
3102	DELEGUEDEL	\N	2007-02-25 00:00:00	ANCIEN	\N	\N	\N	\N	2607	\N	\N	\N
3103	DELEGUEDEL	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2608	\N	\N	\N
3104	DELEGUEDEL	\N	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	2609	\N	\N	\N
3105	DELEGUEDEL	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2610	\N	\N	\N
3107	SECRETDEL	\N	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	\N	2612	2	\N	\N
3108	SECRETDEL	\N	2015-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	2613	3	\N	2015-02-13 15:49:51
3109	DELEGUEDEL	\N	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	2614	\N	\N	2015-06-12 15:59:49
3110	SECRETDEL	\N	2015-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	2615	4	\N	2015-02-13 15:49:52
3111	SECRETDEL	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2616	5	\N	\N
3112	DELEGUEDEL	\N	2015-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	2617	\N	\N	2015-02-13 15:49:50
3114	VICPDTDEL	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2619	4	\N	\N
3115	DELEGUEDEL	\N	2017-11-07 00:00:00	ANCIEN	\N	\N	\N	\N	2620	\N	\N	2017-11-14 11:42:48
3116	DELEGUEDEL	\N	2015-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	2621	\N	\N	2015-02-13 15:49:48
3117	DELEGUEDEL	\N	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	2622	\N	\N	\N
3121	PDTDRTDEL	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2626	\N	\N	2014-09-28 12:52:11
3120	PDTEXECUTDEL	\N	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	2625	\N	\N	\N
3123	PDTDEL	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2629	\N	\N	\N
3127	DELTITDEL	2008-11-04 00:00:00	2015-10-15 00:00:00	ANCIEN	\N	\N	\N	\N	2634	\N	\N	2015-10-15 18:04:19
3128	AUTFONDEL	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2635	6	\N	\N
3129	SECRETDEL	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2636	8	\N	\N
3131	DELEGUEDEL	\N	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	2637	\N	\N	2015-01-08 17:14:29
3132	SECRETDEL	\N	2008-09-07 00:00:00	ANCIEN	\N	\N	\N	\N	2638	1	\N	\N
3133	SECRETDEL	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2639	4	\N	\N
3134	AUTFONDEL	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2640	5	\N	\N
3135	TRESORADJDEL	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2641	\N	\N	\N
3136	DELEGUEDEL	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2642	\N	\N	2014-09-28 16:59:41
3137	DELEGUEDEL	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2643	\N	\N	2014-10-01 11:15:39
3138	AUTFONDEL	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2644	\N	\N	\N
3139	DELEGUEDEL	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2645	\N	\N	2014-09-28 13:19:48
3140	DELEGUEDEL	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2646	\N	\N	\N
3141	DELEGUEDEL	\N	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	2647	\N	\N	2014-09-29 13:43:10
3142	DELEGUEDEL	\N	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	2648	\N	\N	2015-02-13 16:06:25
3143	DELEGUEDEL	\N	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	2649	\N	\N	2015-02-13 16:06:27
3144	DELEGUEDEL	\N	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	2650	\N	\N	2015-02-13 16:06:28
3145	DELEGUEDEL	\N	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	\N	2651	\N	\N	\N
3146	AUTFONDEL	\N	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	2652	\N	\N	2015-02-13 16:06:10
3147	DELEGUEDEL	\N	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	2653	\N	\N	2015-02-13 16:06:35
3148	DELEGUEDEL	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2654	\N	\N	\N
3149	DELEGUEDEL	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2655	\N	\N	\N
3150	AUTFONDEL	\N	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	2656	\N	\N	2015-02-13 16:06:11
3151	AUTFONDEL	\N	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	2657	\N	\N	2015-02-13 16:06:12
3153	DELEGUEDEL	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2659	\N	\N	2014-09-28 13:21:47
4069	PDTDEL	2010-11-23 00:00:00	2011-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	3012	\N	\N	\N
3006	DELEGUEDEL	\N	2011-01-23 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	2509	\N	\N	\N
3007	DELEGUEDEL	\N	2011-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	2511	\N	\N	\N
3008	DELEGUEDEL	\N	2008-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	2514	\N	\N	\N
3009	DELEGUEDEL	\N	2004-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	2515	\N	\N	\N
3010	DELEGUEDEL	\N	2007-07-04 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	2516	\N	\N	\N
3011	DELEGUEDEL	\N	2008-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	2518	\N	\N	\N
3012	AUTFONDEL	\N	2008-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	2519	2	\N	\N
3013	DELEGUEDEL	\N	2015-02-13 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	2520	\N	\N	2015-02-13 15:49:54
3014	DELEGUEDEL	\N	2015-02-12 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	2522	\N	\N	2015-02-13 16:06:18
1132	DELEGUEDEL	2003-01-21 00:00:00	2004-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	1003	\N	\N	\N
1133	DELEGUEDEL	2003-01-21 00:00:00	2003-02-27 00:00:00	ANCIEN	\N	\N	\N	\N	1005	\N	\N	\N
1134	DELEGUEDEL	2003-01-21 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	1006	\N	\N	\N
1136	VICPDTPREDEL	2003-02-27 00:00:00	2003-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	1005	\N	\N	\N
1146	DELTITDEL	\N	1986-12-18 00:00:00	ANCIEN	\N	\N	\N	 Conseil de l'Europe (délégué titulaire)/ Union de l'Europe occidentale (délégué titulaire)/ Secrétaire du groupe des sénateurs-maires/	1011	\N	\N	2015-10-08 16:11:30
1147	DELTITDEL	\N	1998-12-12 00:00:00	ANCIEN	\N	\N	\N	 Conseil de l'Europe (délégué titulaire)/ Union de l'Europe occidentale (délégué titulaire)/	1012	\N	\N	\N
1148	DELTITDEL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	 Conseil de l'Europe (délégué titulaire)/ Union de l'Europe occidentale (délégué titulaire)/	1014	\N	\N	2015-10-08 16:12:20
1150	DELTITDEL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	 Conseil de l'Europe (délégué titulaire)/ Union de l'Europe occidentale ((délégué titulaire)/	1017	\N	\N	2015-10-08 16:13:13
1151	DELTITDEL	\N	1992-03-20 00:00:00	ANCIEN	\N	\N	\N	 Conseil de l'Europe (délégué titulaire)/ Union de l'Europe occidentale (délégué titulaire)/	1019	\N	\N	2015-10-08 16:15:31
1152	DELTITDEL	\N	2009-06-12 00:00:00	ANCIEN	\N	\N	\N	 Conseil de l'Europe (délégué titulaire)/ Union de l'Europe occidentale (délégué titulaire)/	1020	\N	\N	\N
1153	DELTITDEL	\N	2005-05-16 00:00:00	ANCIEN	\N	\N	\N	 Haute Cour de justice (juge titulaire)/ Conseil de l'Europe (délégué titulaire)/ Union de l'Europe occidentale (délégué titulaire)/	1023	\N	\N	\N
1154	DELTITDEL	\N	1999-07-13 00:00:00	ANCIEN	\N	\N	\N	 Conseil de l'Europe (délégué titulaire)/ Union de l'Europe occidentale (délégué titulaire)/	1024	\N	\N	\N
1155	DELSUPDEL	\N	2008-05-22 00:00:00	ANCIEN	\N	\N	\N	 Conseil de l'Europe (délégué suppléant)/ Union de l'Europe occidentale (délégué suppléant)/	1015	\N	\N	\N
2940	PDTDELDEL	2006-01-01 00:00:00	2011-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	943	\N	\N	\N
3498	DELEGUEDEL	2008-11-04 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	2930	\N	\N	\N
3494	DELEGUEDEL	2008-11-04 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	2935	\N	\N	\N
1037	VICPDTDEL	2001-10-17 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	886	1	\N	\N
990	DELEGUEDEL	2001-10-10 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	896	\N	\N	\N
1339	DELEGUEDEL	2004-10-13 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	1157	\N	\N	\N
1426	DELEGUEDEL	2005-01-19 00:00:00	2009-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	1198	\N	\N	\N
1434	DELEGUEDEL	2005-01-19 00:00:00	2009-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	1206	\N	\N	\N
3369	DELEGUEDEL	2008-04-01 00:00:00	2009-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	2848	\N	\N	\N
1283	DELEGUEDEL	\N	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'évaluation de la législation/ Union Européenne/	1102	\N	\N	\N
1390	DELEGUEDEL	2004-10-20 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	1174	6	\N	\N
1397	DELEGUEDEL	2004-10-20 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	1181	\N	\N	\N
3512	DELEGUEDEL	2008-11-04 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	994	\N	\N	\N
1125	DELEGUEDEL	2003-01-21 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	996	\N	\N	\N
4029	DELEGUEDEL	2010-10-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3328	\N	\N	\N
3432	VICPDTDEL	2008-10-01 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	2374	\N	\N	\N
3182	DELEGUEDEL	2007-02-14 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	2683	\N	\N	\N
3249	DELEGUEDEL	2007-10-03 00:00:00	2008-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	2729	\N	\N	\N
4089	DELEGUEDEL	2010-12-08 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	3368	\N	\N	\N
4090	DELEGUEDEL	2010-12-08 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	3369	\N	\N	\N
4091	DELEGUEDEL	2010-12-08 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3370	\N	\N	\N
4092	DELEGUEDEL	2010-12-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3371	\N	\N	\N
4093	DELEGUEDEL	2010-12-08 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	3372	\N	\N	\N
3619	SECRETDEL	2008-12-03 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	1130	2	\N	\N
3989	SECRETDEL	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3288	\N	\N	2014-09-28 17:27:35
4007	DELEGUEDEL	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3306	\N	\N	2014-09-28 16:42:05
4008	DELEGUEDEL	\N	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	3307	\N	\N	2015-02-13 16:06:22
4011	DELEGUEDEL	\N	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	3310	\N	\N	2015-02-13 16:06:33
4012	DELEGUEDEL	\N	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	3311	\N	\N	2015-02-13 16:06:37
3629	VICPDTPREDEL	2009-01-14 00:00:00	2012-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	2380	\N	\N	\N
3630	VICPDTDEL	2009-01-14 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	968	\N	\N	\N
3631	DELEGUEDEL	2009-01-14 00:00:00	2012-06-18 00:00:00	ANCIEN	\N	\N	\N	\N	2968	\N	\N	\N
3632	DELEGUEDEL	2009-01-14 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2969	\N	\N	2014-09-28 17:27:35
3210	DELSUPDEL	2007-07-31 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2709	\N	\N	\N
3211	DELSUPDEL	2007-07-31 00:00:00	2008-10-28 00:00:00	ANCIEN	\N	\N	\N	\N	2710	\N	\N	\N
4131	PDTDEL	2011-01-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2829	\N	\N	\N
3820	PDTDEL	2009-10-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3048	\N	\N	2014-09-28 18:19:47
3821	VICPDTDEL	2009-10-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3050	\N	\N	\N
3822	VICPDTDEL	2009-10-07 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	3053	\N	\N	\N
3823	VICPDTDEL	2009-10-07 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	3051	\N	\N	\N
3824	VICPDTDEL	2009-10-07 00:00:00	2010-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	3065	\N	\N	\N
3825	VICPDTDEL	2009-10-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3052	\N	\N	\N
3826	VICPDTDEL	2009-10-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3069	\N	\N	\N
3827	VICPDTDEL	2009-10-07 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	3075	\N	\N	\N
3828	SECRETDEL	2009-10-07 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	3083	\N	\N	\N
3829	SECRETDEL	2009-10-07 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	3054	\N	\N	\N
3830	SECRETDEL	2009-10-07 00:00:00	2010-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	3080	\N	\N	\N
3831	SECRETDEL	2009-10-07 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	3067	\N	\N	\N
3832	SECRETDEL	2009-10-07 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	3076	\N	\N	\N
3833	SECRETDEL	2009-10-07 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	3078	\N	\N	\N
3834	SECRETDEL	2009-10-07 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	3077	\N	\N	\N
3869	DELEGUEDEL	2010-01-13 00:00:00	2011-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	3148	\N	\N	\N
3889	PDTDEL	2010-02-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3168	\N	\N	\N
3890	VICPDTDEL	2010-02-10 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	3169	\N	\N	2015-01-12 18:27:44
3891	DELEGUEDEL	2010-02-10 00:00:00	2012-09-19 00:00:00	ANCIEN	\N	\N	\N	\N	3170	\N	\N	\N
3892	DELEGUEDEL	2010-02-10 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	3171	\N	\N	\N
3893	DELEGUEDEL	2010-02-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3172	\N	\N	\N
4049	DELSUPDEL	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3348	\N	\N	2014-09-28 12:56:42
4050	DELSUPDEL	\N	2013-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	3349	\N	\N	2013-12-18 11:38:21
2938	PDTDEL	2005-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2372	\N	\N	\N
2939	DELEGUEDEL	2006-03-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2373	\N	\N	2014-09-28 16:59:41
3330	DELEGUEDEL	2008-01-22 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	2809	\N	\N	\N
4051	DELSUPDEL	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3350	\N	\N	\N
4052	DELEGUEDEL	\N	2015-10-15 00:00:00	ANCIEN	\N	\N	\N	\N	3351	\N	\N	2015-10-15 17:58:13
4054	DELSUPDEL	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3353	\N	\N	2014-09-28 17:31:42
4055	DELSUPDEL	\N	2015-10-15 00:00:00	ANCIEN	\N	\N	\N	\N	3354	\N	\N	2015-10-15 17:58:12
3183	VICPDTPREDEL	2006-10-01 00:00:00	2007-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2374	\N	\N	\N
3184	VICPDTPREDEL	2007-01-01 00:00:00	2008-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	1005	\N	\N	\N
3185	PDTDEL	2006-12-01 00:00:00	2006-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2374	\N	\N	\N
3785	DELEGUEDEL	2009-09-23 00:00:00	2012-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	3063	\N	\N	\N
3786	DELEGUEDEL	2009-09-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3082	\N	\N	2014-09-28 12:32:23
3787	DELEGUEDEL	2009-09-23 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	3061	\N	\N	\N
3788	DELEGUEDEL	2009-09-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3081	\N	\N	\N
3550	DELEGUEDEL	2008-11-18 00:00:00	2008-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	2949	\N	\N	\N
3551	DELEGUEDEL	2008-11-18 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2950	\N	\N	\N
3552	DELEGUEDEL	2008-11-18 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2951	\N	\N	2014-09-28 17:03:42
3553	DELEGUEDEL	2008-11-18 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2952	\N	\N	\N
3554	DELEGUEDEL	2008-11-18 00:00:00	2010-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	2953	\N	\N	\N
3555	DELEGUEDEL	2008-11-18 00:00:00	2011-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	2954	\N	\N	\N
3556	DELEGUEDEL	2008-11-18 00:00:00	2012-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	2955	\N	\N	\N
3557	DELEGUEDEL	2008-11-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2956	\N	\N	\N
3558	DELEGUEDEL	2008-11-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2957	\N	\N	\N
3559	DELEGUEDEL	2008-11-18 00:00:00	2008-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	2958	\N	\N	\N
3563	DELEGUEDEL	2008-11-18 00:00:00	2008-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	2962	\N	\N	\N
3566	DELEGUEDEL	2008-11-18 00:00:00	2008-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	1119	\N	\N	\N
3567	DELEGUEDEL	2008-11-18 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	934	\N	\N	\N
3570	DELEGUEDEL	2008-11-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	866	\N	\N	\N
3571	DELEGUEDEL	2008-11-18 00:00:00	2008-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	1130	\N	\N	\N
3572	DELEGUEDEL	2008-11-18 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	2959	\N	\N	\N
3573	DELEGUEDEL	2008-11-18 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2960	\N	\N	\N
3574	DELEGUEDEL	2008-11-18 00:00:00	2008-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	880	\N	\N	\N
3575	DELEGUEDEL	2008-11-18 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	2963	\N	\N	\N
3789	DELEGUEDEL	2009-10-06 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	3088	\N	\N	\N
3909	DELEGUEDEL	2008-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	3188	\N	\N	2015-02-13 15:55:45
3929	DELEGUEDEL	2010-03-31 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	3209	\N	\N	2015-01-12 18:27:45
2941	PDTDEL	2004-10-20 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2374	1	\N	\N
2942	DELEGUEDEL	2004-10-20 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	2375	2	\N	\N
2943	DELEGUEDEL	2004-10-20 00:00:00	2007-02-25 00:00:00	ANCIEN	\N	\N	\N	\N	2376	4	\N	\N
2944	DELEGUEDEL	2004-10-20 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	2377	7	\N	\N
2945	VICPDTPREDEL	2005-01-01 00:00:00	2005-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	1005	\N	\N	\N
2946	PDTDEL	2006-01-01 00:00:00	2006-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	1005	\N	\N	\N
2947	VICPDTDEL	2004-11-02 00:00:00	2008-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	939	\N	\N	\N
2948	VICPDTDEL	2005-03-25 00:00:00	2008-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	944	3	\N	\N
3187	DELEGUEDEL	\N	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	2686	\N	\N	2015-02-13 16:06:15
3188	DELEGUEDEL	\N	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	2687	\N	\N	2015-02-13 16:06:37
4109	VICPDTPREDEL	2011-01-11 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	1166	\N	\N	\N
4110	VICPDTDEL	2011-01-11 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	2941	\N	\N	\N
3042	DELEGUEDEL	\N	2014-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	2558	\N	\N	2014-09-28 12:52:11
3043	DELEGUEDEL	\N	2008-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	2562	\N	\N	\N
3044	DELEGUEDEL	\N	2008-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	2563	\N	\N	\N
3045	DELEGUEDEL	\N	2004-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	2564	\N	\N	\N
3046	DELEGUEDEL	\N	2008-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	2565	\N	\N	\N
3047	DELEGUEDEL	\N	2008-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	2566	\N	\N	\N
3048	VICPDTDEL	\N	2015-02-12 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre du bureau de la section française de l'Assemblée Parlementaire de la Francophonie	Membre du bureau de la section française de l'Assemblée Parlementaire de la Francophonie	2510	\N	\N	2015-02-13 16:06:06
3049	AUTFONDEL	\N	2014-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre du bureau de la section française de l'Assemblée Parlementaire de la Francophonie	Membre du bureau de la section française de l'Assemblée Parlementaire de la Francophonie	2513	1	\N	2014-09-28 12:56:42
3050	DELEGUEDEL	\N	2015-02-12 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre du bureau de la section française de l'Assemblée Parlementaire de la Francophonie	Membre du bureau de la section française de l'Assemblée Parlementaire de la Francophonie	2521	3	\N	2015-02-13 16:06:17
3051	DELEGUEDEL	\N	2014-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre du bureau de la section française de l'Assemblée Parlementaire de la Francophonie	Membre du bureau de la section française de l'Assemblée Parlementaire de la Francophonie	2524	\N	\N	2014-09-28 16:40:50
4829	DELEGUEDEL	2012-10-23 00:00:00	2014-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	3968	\N	\N	2014-12-09 17:05:06
4869	DELEGUEDEL	2012-11-06 00:00:00	2014-05-11 00:00:00	ANCIEN	\N	\N	\N	\N	3988	\N	\N	2014-05-12 09:52:22
4889	DELEGUEDEL	2013-02-05 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3074	\N	\N	\N
4909	DELTITDEL	\N	2015-10-15 00:00:00	ANCIEN	\N	\N	\N	\N	3352	\N	\N	2015-10-15 17:58:10
4929	DELEGUEDEL	2013-02-27 00:00:00	2013-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	4008	\N	\N	2013-10-04 14:27:11
4930	DELEGUEDEL	2013-02-27 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4009	\N	\N	\N
669	VICPDTDEL	1998-10-20 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	573	\N	\N	\N
689	PDTDEL	1998-10-21 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	590	\N	\N	\N
596	DELSUPDEL	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	603	\N	\N	\N
556	DELEGUEDEL	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	562	\N	\N	\N
976	DELEGUEDEL	2001-10-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	882	\N	\N	\N
1096	DELEGUEDEL	2001-10-23 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	947	\N	\N	\N
1098	DELEGUEDEL	2001-11-29 00:00:00	2009-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	968	\N	\N	\N
1099	VICPDTDEL	2001-11-29 00:00:00	2012-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	969	2	\N	\N
708	VICPDTDEL	2001-11-29 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	693	\N	\N	\N
544	DELEGUEDEL	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	550	\N	\N	\N
1101	DELEGUEDEL	2002-07-04 00:00:00	2004-10-13 00:00:00	ANCIEN	\N	\N	\N	\N	973	\N	\N	\N
4949	DELEGUEDEL	2013-09-13 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4028	\N	2013-09-13 16:56:09	\N
4969	DELEGUEDEL	2013-10-03 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4048	\N	2013-10-04 14:28:09	\N
4989	DELEGUEDEL	2013-10-08 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4068	\N	2013-10-08 18:14:35	\N
5012	DELEGUEDEL	2013-10-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4091	\N	2013-10-15 10:37:30	2013-10-15 10:38:19
4536	DELSUPDEL	2011-12-13 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3713	\N	\N	\N
4537	DELSUPDEL	2011-12-13 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3714	\N	\N	2014-09-28 13:40:33
4550	PDTDEL	2012-01-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1166	\N	\N	\N
4551	VICPDTDEL	2012-01-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1162	\N	\N	\N
4553	VICPDTDEL	2012-01-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2941	\N	\N	2014-09-28 17:09:16
4555	VICPDTDEL	2012-01-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3475	\N	\N	2014-09-28 17:34:16
4569	DELEGUEDEL	2012-01-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3061	\N	\N	\N
4570	VICPDTDEL	2012-01-11 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3484	\N	\N	\N
4582	VICPDTDEL	2012-01-11 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3496	\N	\N	\N
4572	VICPDTDEL	2012-01-11 00:00:00	2012-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	3057	\N	\N	\N
4584	VICPDTDEL	2012-01-11 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3067	\N	\N	\N
4586	VICPDTDEL	2012-01-11 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3500	\N	\N	2014-09-28 17:38:26
4576	VICPDTDEL	2012-01-11 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3487	\N	\N	\N
4578	VICPDTDEL	2012-01-11 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3053	\N	\N	\N
4580	VICPDTDEL	2012-01-11 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3051	\N	\N	\N
4588	VICPDTDEL	2012-01-11 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3510	\N	\N	\N
4590	SECRETDEL	2012-01-11 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3056	\N	\N	\N
4592	SECRETDEL	2012-01-11 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3490	\N	\N	\N
4609	DELEGUEDEL	2012-01-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3728	\N	\N	\N
4610	DELEGUEDEL	2012-01-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3730	\N	\N	2014-09-28 17:31:41
4630	DELEGUEDEL	2012-01-25 00:00:00	2014-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	3749	\N	\N	2014-12-10 16:24:10
4649	DELEGUEDEL	2012-02-01 00:00:00	2013-09-12 00:00:00	ANCIEN	\N	\N	\N	\N	3770	\N	\N	2013-09-13 16:56:51
4669	DELEGUEDEL	2012-02-20 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3788	\N	\N	2014-09-28 12:44:31
4691	DELEGUEDEL	\N	2015-10-15 00:00:00	ANCIEN	\N	\N	\N	\N	3811	\N	\N	2015-10-15 17:58:14
4671	DELEGUEDEL	2012-02-20 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3789	\N	\N	2014-09-28 13:09:05
4689	CHEFDEL	\N	2015-10-15 00:00:00	ANCIEN	\N	\N	\N	\N	3808	\N	\N	2015-10-15 17:58:08
4690	DELTITDEL	\N	2015-06-02 00:00:00	ANCIEN	\N	\N	\N	\N	3809	\N	\N	2015-10-15 18:03:50
4692	DELSUPDEL	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3812	\N	\N	2014-09-28 13:39:20
4693	DELSUPDEL	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3813	\N	\N	2014-09-28 16:50:17
4694	DELSUPDEL	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3814	\N	\N	2014-09-28 17:55:39
4695	DELSUPDEL	\N	2015-10-15 00:00:00	ANCIEN	\N	\N	\N	\N	3815	\N	\N	2015-10-15 18:00:24
4709	DELEGUEDEL	2012-02-22 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3850	\N	\N	\N
4729	DELTITDEL	2012-06-26 00:00:00	2014-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	3868	\N	\N	2014-12-10 16:23:15
4749	DELEGUEDEL	2012-07-24 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	3888	\N	\N	2014-05-05 10:35:23
4750	DELEGUEDEL	2012-07-24 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3889	\N	\N	\N
4769	VICPDTDEL	2012-06-19 00:00:00	2015-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	2968	\N	\N	2015-06-16 18:05:16
4770	PDTDEL	2012-06-16 00:00:00	2013-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	3908	\N	\N	2013-06-17 16:36:34
4771	VICPDTDEL	2012-06-16 00:00:00	2015-02-26 00:00:00	ANCIEN	\N	\N	\N	\N	3909	\N	\N	2015-02-27 10:26:14
4772	DELEGUEDEL	2012-06-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	3911	\N	\N	2017-09-24 17:47:27
4789	DELEGUEDEL	2012-10-10 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	3928	\N	\N	2014-05-05 10:34:09
4790	DELEGUEDEL	2012-10-10 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	3929	\N	\N	2015-01-12 18:27:47
4809	DELEGUEDEL	2012-09-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3948	\N	\N	\N
4850	DELEGUEDEL	2012-10-31 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3547	\N	\N	\N
4851	VICPDTDEL	2012-10-31 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3552	\N	\N	\N
5389	DELEGUEDEL	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4408	\N	2014-10-29 17:00:31	2017-10-01 10:34:22
5390	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4409	\N	2014-10-29 17:00:44	2017-10-17 09:38:29
5391	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4410	\N	2014-10-29 17:00:51	2017-10-17 09:38:31
5392	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4411	\N	2014-10-29 17:00:58	2017-10-17 09:38:33
5393	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4412	\N	2014-10-29 17:01:15	2017-10-17 09:38:35
5394	DELEGUEDEL	2014-10-29 00:00:00	2014-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	4413	\N	2014-10-29 17:01:24	2014-11-05 11:37:37
5395	DELEGUEDEL	2014-10-29 00:00:00	2014-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	4414	\N	2014-10-29 17:01:33	2014-11-05 11:36:47
5396	DELEGUEDEL	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4415	\N	2014-10-29 17:01:41	2017-09-24 18:16:52
5397	DELEGUEDEL	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4416	\N	2014-10-29 17:01:48	2017-09-24 18:05:41
5398	DELEGUEDEL	2014-10-29 00:00:00	2014-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	4417	\N	2014-10-29 17:01:54	2014-11-05 11:37:04
5399	DELEGUEDEL	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4418	\N	2014-10-29 17:02:02	2017-09-24 17:15:15
5400	DELEGUEDEL	2014-10-29 00:00:00	2016-03-08 00:00:00	ANCIEN	\N	\N	\N	\N	4419	\N	2014-10-29 17:02:10	2016-03-15 15:59:26
5401	DELEGUEDEL	2014-10-29 00:00:00	2016-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	4420	\N	2014-10-29 17:02:18	2016-03-15 17:20:27
5402	DELEGUEDEL	2014-10-29 00:00:00	2014-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	4421	\N	2014-10-29 17:02:24	2014-11-05 11:37:26
5403	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4422	\N	2014-10-29 17:02:32	2017-10-17 09:38:39
5404	DELEGUEDEL	2014-10-29 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	4423	\N	2014-10-29 17:02:40	2015-02-23 15:04:07
5405	DELEGUEDEL	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4424	\N	2014-10-29 17:02:47	2017-09-24 13:44:49
5406	DELEGUEDEL	2014-10-29 00:00:00	2016-04-28 00:00:00	ANCIEN	\N	\N	\N	\N	4425	\N	2014-10-29 17:02:57	2016-04-29 16:27:53
5407	DELTITDEL	2014-10-29 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	4426	\N	2014-10-29 00:00:00	\N
4529	DELTITDEL	2011-12-12 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1170	\N	\N	\N
5449	VICPDTPREDEL	2014-11-05 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4414	\N	2014-11-05 11:36:47	2017-10-17 09:38:14
5450	VICPDTDEL	2014-11-05 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4417	\N	2014-11-05 11:37:04	2017-10-17 09:38:17
5451	VICPDTDEL	2014-11-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4421	\N	2014-11-05 11:37:26	2017-09-24 19:16:18
5452	VICPDTDEL	2014-11-05 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4413	\N	2014-11-05 11:37:37	2017-10-17 09:38:19
5769	DELEGUEDEL	2015-01-13 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4648	\N	2015-01-13 12:01:31	2017-10-17 09:41:02
3075	DELEGUEDEL	\N	2015-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	2580	\N	\N	2015-02-13 15:49:53
5969	DELEGUEDEL	2015-02-20 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	4808	\N	2015-02-23 15:04:33	2017-06-19 16:04:13
6189	DELEGUEDEL	2014-11-04 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4908	\N	2015-08-25 15:10:09	2017-10-01 10:20:50
6209	DELTITDEL	2015-09-16 00:00:00	2015-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	4928	\N	2015-09-16 15:50:28	2015-10-08 14:53:33
6351	DELTITDEL	2015-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	5070	\N	2015-10-16 11:10:38	2017-09-24 17:19:42
6352	DELSUPDEL	2015-10-16 00:00:00	2017-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	5071	\N	2015-10-16 11:10:49	2017-02-20 10:15:04
6369	DELEGUEDEL	2015-10-21 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	5088	\N	2015-10-21 10:24:58	2017-10-17 09:40:11
6389	DELEGUEDEL	2015-10-14 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	5108	\N	2015-11-03 17:06:52	2017-10-17 09:40:38
6409	DELEGUEDEL	2015-11-17 00:00:00	2016-06-09 00:00:00	ANCIEN	\N	\N	\N	\N	5128	\N	2015-11-17 15:27:56	2016-06-10 17:08:39
6410	DELEGUEDEL	2015-11-17 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	5129	\N	2015-11-17 21:41:41	2017-10-17 09:39:28
6429	DELEGUEDEL	2015-11-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	5148	\N	2015-11-30 17:14:51	\N
6430	DELEGUEDEL	2015-11-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5149	\N	2015-11-30 17:14:58	\N
6431	DELEGUEDEL	2015-11-30 00:00:00	2017-11-07 00:00:00	ANCIEN	\N	\N	\N	\N	5150	\N	2015-11-30 17:15:08	2017-11-14 11:41:29
8343	DELEGUEDEL	2020-10-20 00:00:00	2021-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	6342	\N	\N	\N
6449	DELEGUEDEL	2015-12-08 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	5168	\N	2015-12-09 10:31:52	2017-10-17 09:39:30
6469	PDTDEL	2015-12-18 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	5188	\N	2015-12-18 10:06:14	2015-12-18 10:06:32
6489	DELEGUEDEL	2016-01-12 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	5208	\N	2016-01-12 18:24:02	2017-10-17 09:39:30
6509	DELEGUEDEL	2016-01-19 00:00:00	2017-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	5228	\N	2016-01-19 10:42:39	2017-09-24 11:09:53
5220	DELEGUEDEL	2014-10-29 00:00:00	2016-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	4239	\N	2014-10-29 12:16:51	2016-01-19 10:43:00
6529	VICPDTDEL	2016-01-28 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4241	\N	2016-01-29 10:11:58	2017-10-17 09:39:21
6530	SECRETDEL	2016-01-28 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4228	\N	2016-01-29 10:12:14	2017-10-17 09:39:22
6549	DELEGUEDEL	2016-02-08 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	5248	\N	2016-02-08 10:46:47	2017-10-17 09:39:25
6569	VICPDTDEL	2016-02-12 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4512	\N	2016-02-12 14:22:38	2017-10-17 09:40:52
6570	SECRETDEL	2016-02-12 00:00:00	2017-08-06 00:00:00	ANCIEN	\N	\N	\N	\N	4510	\N	2016-02-12 14:22:59	2017-08-07 16:31:39
6589	DELEGUEDEL	2016-03-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	5268	\N	2016-03-15 15:53:10	2017-09-24 17:42:25
6590	DELEGUEDEL	2016-03-10 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	5269	\N	2016-03-15 15:53:45	2017-10-17 09:38:37
6609	DELEGUEDEL	2016-04-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	5288	\N	2016-04-21 12:03:43	\N
6709	DELEGUEDEL	1995-09-01 00:00:00	1995-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1013	\N	2016-06-23 09:52:35	2016-06-23 09:52:49
6649	DELEGUEDEL	2016-04-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	5328	\N	2016-04-29 16:28:05	2017-09-24 17:42:26
6729	DELEGUEDEL	2016-06-30 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	5348	\N	2016-06-30 11:52:27	\N
6671	VICPDTDEL	2016-06-09 00:00:00	2017-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4570	\N	2016-06-09 09:38:54	2017-03-02 15:44:03
6689	DELEGUEDEL	2016-06-10 00:00:00	2017-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	4569	\N	2016-06-10 17:08:29	2017-07-17 17:40:37
6690	DELEGUEDEL	2016-06-10 00:00:00	2019-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	5128	\N	2016-06-10 17:08:39	2016-06-10 17:08:55
6691	VICPDTPREDEL	2016-06-10 00:00:00	2017-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4568	\N	2016-06-10 17:08:47	2017-03-02 15:44:06
6730	DELEGUEDEL	2016-06-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	5349	\N	2016-06-30 11:52:44	2017-09-24 18:20:10
6731	DELEGUEDEL	2016-06-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	5350	\N	2016-06-30 11:52:59	2017-09-24 13:42:36
6749	DELEGUEDEL	2016-07-05 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	5368	\N	2016-07-05 09:41:25	2017-10-17 09:41:02
6769	DELEGUEDEL	2016-07-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	3293	\N	2016-07-05 10:57:47	2017-09-24 17:18:03
6789	DELEGUEDEL	2016-11-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	5388	\N	2016-11-16 18:41:45	2017-09-24 16:24:51
6809	DELEGUEDEL	2016-11-22 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	5408	\N	2016-11-22 16:43:22	2017-10-17 09:39:49
6829	DELEGUEDEL	2017-01-30 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5428	\N	2017-01-30 11:22:17	\N
6849	DELEGUEDEL	2017-01-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	5071	\N	2017-02-20 10:15:04	2017-09-24 17:04:02
6869	DELEGUEDEL	2017-03-02 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4570	2	2017-03-02 15:44:03	\N
6870	PDTDEL	2017-03-02 00:00:00	2018-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	4568	\N	2017-03-02 15:44:06	\N
5299	DELEGUEDEL	2014-10-29 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	4318	\N	2014-10-29 12:33:11	2017-06-19 16:06:51
6889	DELEGUEDEL	2017-06-30 00:00:00	2017-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	5448	\N	2017-06-30 09:52:24	2017-11-09 14:47:31
6909	DELEGUEDEL	2017-07-03 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	3988	\N	2017-07-03 10:16:14	2017-10-17 09:39:31
6929	DELEGUEDEL	2017-07-10 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	5468	\N	2017-07-11 09:58:44	2017-10-17 09:39:50
6949	DELEGUEDEL	2017-07-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5488	\N	2017-07-12 18:08:58	\N
7029	DELEGUEDEL	2017-07-12 00:00:00	2019-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	5548	\N	2017-07-17 17:41:09	\N
5295	DELEGUEDEL	2014-10-29 00:00:00	2017-07-28 00:00:00	ANCIEN	\N	\N	\N	\N	4314	\N	2014-10-29 12:32:45	2017-08-03 11:38:41
4409	SECRETDEL	2011-12-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2871	5	\N	2017-09-24 13:44:49
5283	DELEGUEDEL	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4302	\N	2014-10-29 12:31:31	2017-09-24 17:28:55
6989	DELEGUEDEL	2017-07-12 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	5528	\N	2017-07-12 22:11:20	2017-10-17 09:38:42
5169	DELTITDEL	2014-10-21 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2891	\N	2014-10-21 17:13:50	\N
5529	DELEGUEDEL	2014-11-18 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	4468	\N	2014-11-18 16:23:03	2015-02-13 16:06:20
5549	PDTDEL	2014-11-20 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4389	\N	2014-11-20 19:02:29	2017-10-17 09:40:27
5550	VICPDTDEL	2014-11-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4374	\N	2014-11-20 19:02:41	2017-09-24 18:07:57
5551	VICPDTDEL	2014-11-20 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4377	\N	2014-11-20 19:02:56	2017-10-18 17:37:10
5553	VICPDTDEL	2014-11-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4378	\N	2014-11-20 19:03:19	2017-09-25 10:56:48
5554	VICPDTDEL	2014-11-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4338	\N	2014-11-20 19:03:26	2017-09-24 17:28:55
5555	VICPDTDEL	2014-11-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4382	\N	2014-11-20 19:03:36	2017-09-24 16:24:51
5557	VICPDTDEL	2014-11-20 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4370	\N	2014-11-20 19:03:55	2017-10-17 09:40:29
5558	VICPDTDEL	2014-11-20 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4386	\N	2014-11-20 19:04:05	2017-10-18 17:40:15
5559	VICPDTDEL	2014-11-20 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4390	\N	2014-11-20 19:04:14	2017-10-17 09:40:30
5560	SECRETDEL	2014-11-20 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4335	\N	2014-11-20 19:04:25	2017-10-17 09:40:30
5561	SECRETDEL	2014-11-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4345	\N	2014-11-20 19:04:33	2017-09-24 17:14:26
5563	SECRETDEL	2014-11-20 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4368	\N	2014-11-20 19:04:49	2017-10-17 09:40:31
5569	VICPDTPRESIM	2014-11-25 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4311	\N	2014-11-25 12:05:57	2017-10-17 09:39:45
5709	DELEGUEDEL	2014-12-10 00:00:00	2017-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	3630	\N	2014-12-10 16:21:51	2017-11-28 10:07:58
4412	PDTDEL	2011-12-07 00:00:00	2014-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	3630	\N	\N	2014-12-10 16:21:51
5710	DELEGUEDEL	2014-12-10 00:00:00	2017-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	3638	\N	2014-12-10 16:22:21	2017-11-28 10:08:00
5712	DELEGUEDEL	2014-12-10 00:00:00	2017-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	3868	\N	2014-12-10 16:23:15	2017-11-28 10:08:02
5713	PDTDEL	2014-12-10 00:00:00	2017-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	3629	1	2014-12-10 16:23:35	2017-11-28 10:07:54
5714	SECRETDEL	2014-12-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	3631	4	2014-12-10 16:23:48	2017-09-24 17:35:15
4414	DELEGUEDEL	2011-12-07 00:00:00	2014-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	3631	\N	\N	2014-12-10 16:23:48
5716	SECRETDEL	2014-12-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4589	6	2014-12-10 16:25:47	2017-09-24 18:07:57
5721	DELEGUEDEL	2014-12-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4593	\N	2014-12-10 16:30:39	2017-09-24 19:31:54
5718	DELEGUEDEL	2014-12-10 00:00:00	2017-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	4591	\N	2014-12-10 16:28:29	2017-11-28 10:07:57
5719	DELEGUEDEL	2014-12-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4592	\N	2014-12-10 16:28:52	2017-09-24 17:29:37
5722	DELEGUEDEL	2014-12-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4594	\N	2014-12-10 16:31:04	2017-09-24 17:42:25
5749	DELEGUEDEL	2014-11-04 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4628	\N	2015-01-12 19:00:49	\N
5724	DELEGUEDEL	2014-12-10 00:00:00	2017-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	4596	\N	2014-12-10 16:32:00	2017-11-28 10:08:01
5725	DELEGUEDEL	2014-12-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4597	\N	2014-12-10 16:32:10	2017-09-24 12:57:09
5909	DELEGUEDEL	2015-02-13 00:00:00	2018-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	4748	\N	2015-02-13 16:09:07	2018-01-09 14:21:23
5752	DELEGUEDEL	2014-11-04 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	4631	\N	2015-01-12 19:01:11	2017-06-19 12:20:59
5754	DELEGUEDEL	2014-11-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4633	\N	2015-01-12 19:01:26	2017-09-24 17:15:15
5755	DELEGUEDEL	2014-11-04 00:00:00	2017-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	4634	\N	2015-01-12 19:01:33	2017-11-09 14:47:45
5757	DELEGUEDEL	2014-11-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4636	\N	2015-01-12 19:01:45	2017-09-24 13:25:54
5758	DELEGUEDEL	2014-11-04 00:00:00	2017-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	4637	\N	2015-01-12 19:01:51	2017-11-09 14:47:51
5759	DELEGUEDEL	2014-11-04 00:00:00	2017-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	4638	\N	2015-01-12 19:01:57	2017-11-09 14:47:36
5789	PDTDEL	2014-11-05 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	4630	\N	2015-01-13 16:17:36	2015-10-13 14:17:21
5911	DELEGUEDEL	2015-02-13 00:00:00	2017-11-13 00:00:00	ANCIEN	\N	\N	\N	\N	4750	\N	2015-02-13 16:09:24	2017-11-14 14:41:13
5912	DELEGUEDEL	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4751	\N	2015-02-13 16:09:53	2017-09-24 18:59:59
5913	DELEGUEDEL	2015-02-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	4752	\N	2015-02-13 16:10:04	\N
5914	DELEGUEDEL	2015-02-13 00:00:00	2018-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	4753	\N	2015-02-13 16:10:18	2018-01-09 14:21:47
5915	DELEGUEDEL	2015-02-13 00:00:00	2018-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	4754	\N	2015-02-13 16:10:29	2018-01-09 14:26:50
5916	DELEGUEDEL	2015-02-13 00:00:00	2018-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	4755	\N	2015-02-13 16:10:38	2018-01-09 14:21:55
5917	DELEGUEDEL	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4756	\N	2015-02-13 16:10:45	2017-09-24 17:47:27
5918	DELEGUEDEL	2015-02-13 00:00:00	2016-04-14 00:00:00	ANCIEN	\N	\N	\N	\N	4757	\N	2015-02-13 16:10:55	2016-04-21 12:13:50
5919	DELEGUEDEL	2015-02-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4758	\N	2015-02-13 16:11:00	\N
5920	DELEGUEDEL	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4759	\N	2015-02-13 16:11:06	2017-09-24 18:59:59
5921	DELEGUEDEL	2015-02-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4760	\N	2015-02-13 00:00:00	\N
5922	DELEGUEDEL	2015-02-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4761	\N	2015-02-13 00:00:00	\N
5923	DELEGUEDEL	2015-02-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4762	\N	2015-02-13 00:00:00	\N
5924	DELEGUEDEL	2015-02-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	4763	\N	2015-02-13 16:11:29	\N
5926	DELEGUEDEL	2015-02-13 00:00:00	2015-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	4765	\N	2015-02-13 16:11:39	2015-04-07 16:50:27
5927	DELEGUEDEL	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4766	\N	2015-02-13 16:11:49	2017-09-24 13:42:36
5929	DELEGUEDEL	2015-02-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	4768	\N	2015-02-13 16:12:11	\N
5930	DELEGUEDEL	2015-02-13 00:00:00	2018-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	4769	\N	2015-02-13 16:12:21	2018-01-09 14:23:05
5931	DELEGUEDEL	2015-02-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4770	\N	2015-02-13 16:12:27	\N
5932	DELEGUEDEL	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4771	\N	2015-02-13 16:12:36	2017-09-24 18:59:59
5933	DELEGUEDEL	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4772	\N	2015-02-13 16:12:47	2017-09-25 10:58:49
5934	DELEGUEDEL	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4773	\N	2015-02-13 16:12:53	2017-09-24 18:16:52
5936	DELEGUEDEL	2015-02-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4775	\N	2015-02-13 16:13:01	\N
5937	DELEGUEDEL	2015-02-13 00:00:00	2017-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	4776	\N	2015-02-13 16:13:04	2017-07-24 09:58:00
5938	DELEGUEDEL	2015-02-13 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4777	\N	2015-02-13 16:13:08	\N
8344	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6343	\N	\N	\N
5939	DELEGUEDEL	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4778	\N	2015-02-13 16:13:15	2017-09-24 17:48:21
5945	DELEGUEDEL	2015-02-13 00:00:00	2023-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	4784	\N	2015-02-13 16:14:25	\N
5941	DELEGUEDEL	2015-02-13 00:00:00	2018-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	4780	\N	2015-02-13 16:13:41	2018-01-09 14:23:50
5943	DELEGUEDEL	2015-02-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	4782	\N	2015-02-13 16:14:08	\N
5944	DELEGUEDEL	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4783	\N	2015-02-13 16:14:19	2017-09-24 18:20:10
5946	DELEGUEDEL	2015-02-13 00:00:00	2018-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	4785	\N	2015-02-13 16:14:32	2018-01-09 14:24:51
5947	DELEGUEDEL	2015-02-13 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	4786	\N	2015-02-13 16:14:38	2016-03-11 18:02:50
5948	DELEGUEDEL	2015-02-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4787	\N	2015-02-13 00:00:00	\N
5949	DELEGUEDEL	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4788	\N	2015-02-13 16:14:56	2017-09-24 17:09:24
5950	DELEGUEDEL	2015-02-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	4789	\N	2015-02-13 16:15:05	\N
5951	DELEGUEDEL	2015-02-13 00:00:00	2018-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	4790	\N	2015-02-13 16:15:09	2018-01-09 14:25:18
5952	DELEGUEDEL	2015-02-13 00:00:00	2018-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	4791	\N	2015-02-13 16:15:15	2018-01-09 14:25:27
5953	DELEGUEDEL	2015-02-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4792	\N	2015-02-13 00:00:00	\N
5955	DELEGUEDEL	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4794	\N	2015-02-13 16:15:32	2017-09-24 18:17:56
5956	DELEGUEDEL	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4795	\N	2015-02-13 16:15:38	2017-09-24 18:16:52
5957	DELEGUEDEL	2015-02-13 00:00:00	2018-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	4796	\N	2015-02-13 16:15:42	2018-01-09 14:25:40
5958	DELEGUEDEL	2015-02-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4797	\N	2015-02-13 16:15:48	\N
5989	PDTEXECUTDEL	2015-02-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4828	2	2015-02-25 16:03:13	2017-09-24 18:20:10
5990	DELEGUEDEL	2015-02-25 00:00:00	2017-11-07 00:00:00	ANCIEN	\N	\N	\N	\N	4829	\N	2015-02-25 16:05:17	2017-11-14 11:40:44
5991	DELEGUEDEL	2015-02-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4830	\N	2015-02-25 16:05:22	2017-09-24 18:05:41
5992	DELEGUEDEL	2015-02-25 00:00:00	2017-11-07 00:00:00	ANCIEN	\N	\N	\N	\N	4831	\N	2015-02-25 16:06:01	2017-11-14 11:41:13
5993	DELEGUEDEL	2015-02-25 00:00:00	2018-08-06 00:00:00	ANCIEN	\N	\N	\N	\N	4832	\N	2015-02-25 16:06:07	\N
5995	DELEGUEDEL	2015-02-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4834	\N	2015-02-25 16:06:54	2017-09-24 18:16:52
5996	DELEGUEDEL	2015-02-25 00:00:00	2015-02-27 00:00:00	ANCIEN	\N	\N	\N	\N	4835	\N	2015-02-25 16:06:58	2015-02-27 14:21:27
5997	DELEGUEDEL	2015-02-25 00:00:00	2017-11-07 00:00:00	ANCIEN	\N	\N	\N	\N	4836	\N	2015-02-25 16:07:28	2017-11-14 11:41:40
5998	DELEGUEDEL	2015-02-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4837	\N	2015-02-25 16:07:48	2017-09-24 12:39:59
5999	DELEGUEDEL	2015-02-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4838	\N	2015-02-25 16:09:01	2017-09-24 19:25:10
6000	DELEGUEDEL	2015-02-25 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	4839	\N	2015-02-25 16:10:01	\N
6029	DELEGUEDEL	2015-03-16 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	4524	\N	2015-03-16 12:03:56	2017-06-19 16:06:01
5149	DELEGUEDEL	2014-07-09 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4208	\N	2014-07-09 11:17:14	\N
5189	DELEGUEDEL	2014-10-29 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	3516	\N	2014-10-29 00:00:00	\N
5190	DELEGUEDEL	2014-10-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2954	\N	2014-10-29 11:08:36	\N
5191	DELEGUEDEL	2014-10-29 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	869	\N	2014-10-29 00:00:00	\N
5192	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	3505	\N	2014-10-29 11:08:42	2017-10-18 17:42:27
5193	DELEGUEDEL	2014-10-29 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3148	\N	2014-10-29 11:08:46	2017-10-19 18:17:01
5194	DELEGUEDEL	2014-10-29 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	3518	\N	2014-10-29 00:00:00	\N
4476	VICPDTDEL	2011-12-14 00:00:00	2014-10-28 00:00:00	ANCIEN	\N	\N	\N	\N	2958	\N	\N	2014-10-29 11:08:51
5593	DELEGUEDEL	2014-11-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4492	\N	2014-11-26 13:26:09	2017-09-24 17:15:15
5197	DELEGUEDEL	2014-10-29 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	3521	\N	2014-10-29 00:00:00	\N
4479	SECRETDEL	2011-12-14 00:00:00	2014-10-28 00:00:00	ANCIEN	\N	\N	\N	\N	3521	\N	\N	2014-10-29 11:08:57
5589	DELEGUEDEL	2014-11-26 00:00:00	2014-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	4488	\N	2014-11-26 13:25:47	2014-12-04 14:57:54
5590	DELEGUEDEL	2014-11-26 00:00:00	2014-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	4489	\N	2014-11-26 13:25:53	2014-12-08 11:43:42
5591	DELEGUEDEL	2014-11-26 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4490	\N	2014-11-26 13:25:58	2017-10-17 09:40:58
5592	DELEGUEDEL	2014-11-26 00:00:00	2014-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	4491	\N	2014-11-26 13:26:04	2014-12-04 14:58:02
5594	DELEGUEDEL	2014-11-26 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4493	\N	2014-11-26 13:26:15	2017-10-17 09:40:59
5595	DELEGUEDEL	2014-11-26 00:00:00	2014-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	4494	\N	2014-11-26 13:26:20	2014-12-04 14:57:15
5596	DELEGUEDEL	2014-11-26 00:00:00	2014-12-27 00:00:00	ANCIEN	\N	\N	\N	\N	4495	\N	2014-11-26 13:26:26	2014-12-29 15:40:09
5597	DELEGUEDEL	2014-11-26 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4496	\N	2014-11-26 13:26:30	2017-10-17 09:40:59
5598	DELEGUEDEL	2014-11-26 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4497	\N	2014-11-26 13:26:36	2017-10-17 09:41:00
5599	DELEGUEDEL	2014-11-26 00:00:00	2014-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	4498	\N	2014-11-26 13:26:42	2014-12-04 14:57:20
5601	DELEGUEDEL	2014-11-26 00:00:00	2014-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	4500	\N	2014-11-26 13:27:01	2014-12-04 14:56:11
5602	DELEGUEDEL	2014-11-26 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4501	\N	2014-11-26 13:27:15	2017-10-17 09:41:03
5603	DELEGUEDEL	2014-11-26 00:00:00	2014-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	4502	\N	2014-11-26 13:27:21	2014-12-04 14:57:44
5604	DELEGUEDEL	2014-11-26 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4503	\N	2014-11-26 13:27:27	2017-10-17 09:41:03
5605	DELEGUEDEL	2014-11-26 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4504	\N	2014-11-26 13:27:34	2017-10-17 09:41:03
5606	DELEGUEDEL	2014-11-26 00:00:00	2014-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	4505	\N	2014-11-26 13:27:41	2014-12-04 14:56:37
5607	DELEGUEDEL	2014-11-26 00:00:00	2016-01-04 00:00:00	ANCIEN	\N	\N	\N	\N	4506	\N	2014-11-26 13:27:46	2016-01-05 11:34:09
5608	DELEGUEDEL	2014-11-26 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4507	\N	2014-11-26 13:27:52	2017-10-17 09:40:56
5609	DELEGUEDEL	2014-11-26 00:00:00	2016-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	4508	\N	2014-11-26 13:27:58	2016-01-27 16:39:45
5610	DELEGUEDEL	2014-11-26 00:00:00	2014-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	4509	\N	2014-11-26 13:28:03	2014-12-04 14:56:51
5611	DELEGUEDEL	2014-11-26 00:00:00	2014-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	4510	\N	2014-11-26 13:28:09	2014-12-04 14:57:01
5612	DELEGUEDEL	2014-11-26 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4511	\N	2014-11-26 13:28:15	2017-10-17 09:40:57
5613	DELEGUEDEL	2014-11-26 00:00:00	2014-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	4512	\N	2014-11-26 13:28:22	2014-12-04 14:58:10
5615	DELEGUEDEL	2014-11-26 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	4514	\N	2014-11-26 13:28:35	2015-06-23 09:37:29
5616	DELEGUEDEL	2014-11-26 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4515	\N	2014-11-26 13:28:41	2017-10-17 09:41:01
5617	DELEGUEDEL	2014-11-26 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4516	\N	2014-11-26 13:28:49	2017-10-17 09:41:01
5618	DELEGUEDEL	2014-11-26 00:00:00	2016-01-04 00:00:00	ANCIEN	\N	\N	\N	\N	4517	\N	2014-11-26 13:28:55	2016-01-05 11:34:16
5619	DELEGUEDEL	2014-11-26 00:00:00	2014-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	4518	\N	2014-11-26 13:29:00	2014-12-04 14:58:17
5620	DELEGUEDEL	2014-11-26 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4519	\N	2014-11-26 13:29:06	2017-10-17 09:40:57
5621	DELEGUEDEL	2014-11-26 00:00:00	2014-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	4520	\N	2014-11-26 13:29:12	2014-12-04 14:57:06
5622	DELEGUEDEL	2014-11-26 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4521	\N	2014-11-26 13:29:19	2017-10-17 09:40:58
5624	DELEGUEDEL	2014-11-26 00:00:00	2016-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	4523	\N	2014-11-26 13:29:36	2016-07-05 09:50:11
5625	DELEGUEDEL	2014-11-26 00:00:00	2014-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	4524	\N	2014-11-26 13:29:45	2014-12-04 14:56:44
5626	DELEGUEDEL	2014-11-26 00:00:00	2015-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	4525	\N	2014-11-26 13:29:51	2015-03-16 12:04:08
5627	DELEGUEDEL	2014-11-26 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4526	\N	2014-11-26 13:29:58	2017-10-17 09:40:56
5628	DELEGUEDEL	2014-11-26 00:00:00	2014-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	4527	\N	2014-11-26 13:30:05	2014-12-04 14:57:29
5629	DELEGUEDEL	2014-11-26 00:00:00	2014-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	4528	\N	2014-11-26 13:30:14	2014-12-04 14:57:36
5630	DELEGUEDEL	2014-11-26 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4529	\N	2014-11-26 13:30:20	2017-10-17 09:40:55
5849	PDTDRTDEL	2015-02-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4688	1	2015-02-13 00:00:00	2015-02-25 00:00:00
5850	DELEGUEDEL	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4689	\N	2015-02-13 15:50:22	2017-09-24 18:20:10
5851	DELEGUEDEL	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4690	\N	2015-02-13 15:50:51	2017-09-24 17:47:28
5852	DELEGUEDEL	2015-02-13 00:00:00	2015-02-25 00:00:00	ANCIEN	\N	\N	\N	\N	4691	\N	2015-02-13 15:51:00	2015-02-25 16:04:41
5853	DELEGUEDEL	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4692	\N	2015-02-13 15:51:27	2017-09-24 18:05:41
5854	DELEGUEDEL	2015-02-13 00:00:00	2017-11-07 00:00:00	ANCIEN	\N	\N	\N	\N	4693	\N	2015-02-13 15:51:31	2017-12-06 16:54:25
5855	DELEGUEDEL	2015-02-13 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	4694	\N	2015-02-13 15:51:35	\N
5856	SECRETDEL	2015-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4695	\N	2015-02-13 15:51:39	2017-09-24 17:18:03
5857	DELEGUEDEL	2015-02-13 00:00:00	2017-11-07 00:00:00	ANCIEN	\N	\N	\N	\N	4697	\N	2015-02-13 15:51:47	2017-11-14 11:40:58
5858	DELEGUEDEL	2015-02-13 00:00:00	2015-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	4698	\N	2015-02-13 15:51:56	2015-11-30 17:14:40
5860	DELEGUEDEL	2015-02-13 00:00:00	2018-08-06 00:00:00	ANCIEN	\N	\N	\N	\N	4700	\N	2015-02-13 15:52:11	\N
5861	DELEGUEDEL	2015-02-13 00:00:00	2017-07-28 00:00:00	ANCIEN	\N	\N	\N	\N	4701	\N	2015-02-13 15:52:14	2017-08-03 11:38:41
5864	DELEGUEDEL	2015-02-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4704	\N	2015-02-13 15:52:46	\N
5865	DELEGUEDEL	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4705	\N	2015-02-13 15:52:50	2017-09-24 19:25:10
5866	DELEGUEDEL	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4706	\N	2015-02-13 15:52:55	2017-09-24 18:16:52
5867	DELEGUEDEL	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4708	\N	2015-02-13 15:53:09	2017-09-24 18:16:52
5868	DELEGUEDEL	2015-02-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4709	\N	2015-02-13 00:00:00	\N
5869	DELEGUEDEL	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4710	\N	2015-02-13 15:53:27	2017-09-24 12:39:59
5870	DELEGUEDEL	2015-02-13 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	4711	\N	2015-02-13 15:53:40	\N
5871	DELEGUEDEL	2015-02-13 00:00:00	2016-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4712	\N	2015-02-13 15:53:47	2017-01-03 11:09:24
5872	DELEGUEDEL	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4713	\N	2015-02-13 15:53:50	2017-09-24 17:42:25
5873	DELEGUEDEL	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4714	\N	2015-02-13 15:54:03	2017-09-24 17:15:15
5874	DELEGUEDEL	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4715	\N	2015-02-13 15:54:13	2017-09-24 18:17:56
5875	DELEGUEDEL	2015-02-13 00:00:00	2017-11-07 00:00:00	ANCIEN	\N	\N	\N	\N	4716	\N	2015-02-13 15:54:17	2017-11-14 11:41:58
5876	DELEGUEDEL	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4717	\N	2015-02-13 15:54:31	2017-09-24 17:15:15
5877	DELEGUEDEL	2015-02-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	4718	\N	2015-02-13 15:54:40	2017-11-14 11:44:49
5878	DELEGUEDEL	2015-02-13 00:00:00	2017-11-07 00:00:00	ANCIEN	\N	\N	\N	\N	4719	\N	2015-02-13 15:54:47	2017-11-14 11:42:04
5879	DELEGUEDEL	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4720	\N	2015-02-13 15:54:53	2017-09-24 19:25:10
5881	DELEGUEDEL	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4722	\N	2015-02-13 15:55:11	2017-09-24 18:16:52
5882	DELEGUEDEL	2015-02-13 00:00:00	2017-11-07 00:00:00	ANCIEN	\N	\N	\N	\N	4723	\N	2015-02-13 15:55:18	2017-11-14 11:42:11
5883	DELEGUEDEL	2015-02-13 00:00:00	2017-11-07 00:00:00	ANCIEN	\N	\N	\N	\N	4724	\N	2015-02-13 15:55:28	2017-11-14 11:42:13
5884	DELEGUEDEL	2015-02-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	4725	\N	2015-02-13 15:55:34	\N
5885	DELEGUEDEL	2015-02-13 00:00:00	2018-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	4728	\N	2015-02-13 15:56:03	2018-01-09 14:24:40
5886	DELEGUEDEL	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4729	\N	2015-02-13 15:56:19	2017-09-24 17:47:27
5887	DELEGUEDEL	2015-02-13 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	4730	\N	2015-02-13 15:56:23	\N
5888	DELEGUEDEL	2015-02-13 00:00:00	2017-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	4731	\N	2015-02-13 15:56:30	2017-10-05 09:36:37
8345	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6344	\N	\N	\N
5889	DELEGUEDEL	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4732	\N	2015-02-13 15:56:34	2017-10-01 10:32:58
5890	DELEGUEDEL	2015-02-13 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	4733	\N	2015-02-13 15:56:38	\N
5891	DELEGUEDEL	2015-02-13 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	4734	\N	2015-02-13 15:56:47	\N
3973	DELEGUEDEL	\N	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	3271	\N	\N	2015-02-13 16:06:26
4001	DELEGUEDEL	\N	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	3300	\N	\N	2015-02-13 16:06:34
6030	VICPDTDEL	2015-03-16 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4525	\N	2015-03-16 12:04:08	2017-10-17 09:40:54
5029	DELEGUEDEL	2014-02-21 00:00:00	2014-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	4108	\N	2014-02-21 11:14:13	2014-04-09 16:52:36
5069	DELEGUEDEL	2014-05-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4128	\N	2014-05-07 09:40:20	2014-09-28 19:03:23
5109	DELEGUEDEL	2014-05-21 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	4168	\N	2014-05-22 10:58:21	2015-01-12 18:27:49
5470	VICPDTDEL	2014-11-05 00:00:00	2015-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	4315	\N	2014-11-05 15:26:45	2015-06-18 18:17:05
5471	VICPDTDEL	2014-11-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4330	\N	2014-11-05 15:26:52	2017-09-24 17:55:12
5472	VICPDTDEL	2014-11-05 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4303	\N	2014-11-05 15:27:03	2017-10-17 09:39:46
5473	VICPDTDEL	2014-11-05 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4304	\N	2014-11-05 15:27:14	2017-10-17 09:39:46
5475	SECRETDEL	2014-11-05 00:00:00	2015-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	4319	\N	2014-11-05 15:27:34	2015-06-18 18:16:48
5476	VICPDTDEL	2014-11-05 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4306	\N	2014-11-05 15:27:47	2017-10-17 09:39:47
5477	VICPDTDEL	2014-11-05 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	4332	\N	2014-11-05 15:27:55	2017-06-19 12:20:59
5478	VICPDTDEL	2014-11-05 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4321	\N	2014-11-05 15:28:04	2017-10-17 09:39:47
5479	VICPDTDEL	2014-11-05 00:00:00	2014-11-24 00:00:00	ANCIEN	\N	\N	\N	\N	4311	\N	2014-11-05 15:28:13	2014-11-25 12:05:57
5480	VICPDTDEL	2014-11-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4325	\N	2014-11-05 15:28:23	2017-09-24 18:16:52
5481	SECRETDEL	2014-11-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4300	\N	2014-11-05 15:28:31	2017-09-24 17:29:37
5509	PDTDEL	2014-11-10 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4274	\N	2014-11-10 10:47:03	2017-10-17 09:40:07
5510	VICPDTDEL	2014-11-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4263	\N	2014-11-10 10:47:12	2017-09-24 13:44:49
5511	VICPDTDEL	2014-11-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4297	\N	2014-11-10 10:47:20	2017-09-24 17:09:24
5649	PDTDEL	2014-12-04 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4500	\N	2014-12-04 14:56:11	2017-10-17 09:40:50
5513	VICPDTDEL	2014-11-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4293	\N	2014-11-10 10:48:21	2017-09-24 17:35:15
5514	VICPDTDEL	2014-11-10 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4271	\N	2014-11-10 10:48:29	2017-10-17 09:40:08
5650	VICPDTDEL	2014-12-04 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	4505	\N	2014-12-04 14:56:37	2015-06-12 15:59:18
5516	VICPDTDEL	2014-11-10 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4275	\N	2014-11-10 10:48:47	2017-10-17 09:40:08
5651	VICPDTDEL	2014-12-04 00:00:00	2015-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	4524	\N	2014-12-04 14:56:44	2015-03-16 12:03:56
5519	VICPDTDEL	2014-11-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4292	\N	2014-11-10 10:49:32	2017-09-24 13:25:54
5520	VICPDTDEL	2014-11-05 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4288	\N	2014-11-10 10:49:45	2017-10-17 09:40:09
5269	DELEGUEDEL	2014-10-29 00:00:00	2014-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	4288	\N	2014-10-29 12:27:34	2014-11-10 10:49:45
5521	SECRETDEL	2014-11-05 00:00:00	2015-05-20 00:00:00	ANCIEN	\N	\N	\N	\N	4264	\N	2014-11-10 10:49:57	2015-05-20 17:52:24
5522	SECRETDEL	2014-11-05 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4282	\N	2014-11-10 10:50:04	2017-10-17 09:40:10
5258	DELEGUEDEL	2014-10-29 00:00:00	2014-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	4277	\N	2014-10-29 12:25:06	2014-11-10 10:50:11
5525	VICPDTDEL	2014-11-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4281	\N	2014-11-10 10:52:17	2017-09-24 19:25:10
5653	VICPDTDEL	2014-12-04 00:00:00	2016-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	4510	\N	2014-12-04 14:57:01	2016-02-12 14:22:59
5654	VICPDTDEL	2014-12-04 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4520	\N	2014-12-04 14:57:06	2017-10-17 09:40:51
5655	VICPDTDEL	2014-12-04 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4494	\N	2014-12-04 14:57:15	2017-10-17 09:40:52
5657	VICPDTDEL	2014-12-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4527	\N	2014-12-04 14:57:29	2017-09-24 18:49:56
5658	VICPDTDEL	2014-12-04 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	4528	\N	2014-12-04 14:57:36	2016-03-11 18:02:50
5659	VICPDTDEL	2014-12-04 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4502	\N	2014-12-04 14:57:44	2017-10-17 09:40:53
5660	SECRETDEL	2014-12-04 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4488	\N	2014-12-04 14:57:54	2017-10-17 09:40:54
5661	SECRETDEL	2014-12-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4491	\N	2014-12-04 14:58:02	2017-09-24 18:05:41
5662	SECRETDEL	2014-12-04 00:00:00	2016-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	4512	\N	2014-12-04 14:58:10	2016-02-12 14:22:38
6050	DELEGUEDEL	2015-05-04 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4849	\N	2015-05-05 16:31:21	2017-10-17 09:40:38
6069	DELEGUEDEL	2015-05-20 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4868	\N	2015-05-20 17:54:48	2017-10-17 09:40:16
6129	VICPDTDEL	2015-06-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4319	\N	2015-06-18 18:16:48	2017-09-24 16:45:26
6130	SECRETDEL	2015-06-18 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4315	\N	2015-06-18 18:17:05	2017-10-17 09:39:48
6149	DELEGUEDEL	\N	1995-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1095	\N	2015-07-01 09:33:11	2015-07-01 09:33:35
6150	DELEGUEDEL	\N	1986-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1097	\N	2015-07-01 09:35:45	2015-07-01 09:36:13
6151	DELEGUEDEL	\N	1986-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1099	\N	2015-07-01 09:36:48	2015-07-01 09:37:10
6152	DELEGUEDEL	\N	1995-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1100	\N	2015-07-01 09:38:03	2015-07-01 09:38:23
6160	DELEGUEDEL	2015-07-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4895	\N	2015-07-01 18:11:13	\N
6229	DELEGUEDEL	2014-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4948	\N	2015-09-16 00:00:00	\N
6230	DELEGUEDEL	2014-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4949	\N	2015-09-16 23:41:31	2017-10-01 10:34:22
6231	DELEGUEDEL	2014-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4950	\N	2015-09-16 23:41:41	\N
6249	DELEGUEDEL	2015-09-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4968	\N	2015-09-24 09:51:06	2017-09-24 17:29:37
6250	SECRETDEL	2015-09-24 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4273	\N	2015-09-24 09:53:06	2017-10-17 09:40:09
5254	DELEGUEDEL	2014-10-29 00:00:00	2015-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	4273	\N	2014-10-29 12:23:44	2015-09-24 09:53:06
6269	DELEGUEDEL	2015-09-28 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4988	\N	2015-09-28 09:39:25	2017-10-17 09:40:34
6309	DELTITDEL	2015-10-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5028	\N	2015-10-08 14:47:23	2015-10-08 14:49:18
6310	DELTITDEL	2015-10-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5029	\N	2015-10-08 14:47:42	2015-10-08 14:49:21
6311	DELTITDEL	2015-10-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	5030	\N	2015-10-08 14:47:53	2017-09-24 12:39:59
6312	DELTITDEL	2015-10-08 00:00:00	2018-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	5031	\N	2015-10-08 14:48:08	2015-10-08 14:49:34
6313	DELTITDEL	2015-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	5032	\N	2015-10-08 00:00:00	2015-10-08 00:00:00
6314	DELTITDEL	2015-10-08 00:00:00	2020-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	5033	\N	2015-10-08 14:48:29	2015-10-08 14:49:37
6315	DELSUPDEL	2015-10-08 00:00:00	2017-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	5034	\N	2015-10-08 14:48:45	2017-11-07 18:31:53
6316	DELSUPDEL	2015-10-08 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	5035	\N	2015-10-08 14:49:56	2016-12-12 16:10:15
6318	DELSUPDEL	2015-10-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	5037	\N	2015-10-08 14:50:43	2017-09-24 18:16:52
6319	DELSUPDEL	2015-10-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	5038	\N	2015-10-08 14:50:57	2017-09-24 17:47:27
6320	DELSUPDEL	2015-10-08 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	5039	\N	2015-10-08 14:51:12	2015-10-08 14:51:16
6332	DELTITDEL	2015-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	5048	\N	2015-10-15 18:03:08	2017-09-24 18:16:52
6330	CHEFDEL	2015-10-16 00:00:00	2016-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3351	\N	2015-10-15 18:01:27	2017-01-03 11:09:24
6331	DELTITDEL	2015-10-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3815	\N	2015-10-15 18:02:15	2015-10-15 18:02:26
6334	DELSUPDEL	2015-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	5050	\N	2015-10-15 18:06:07	2017-09-24 17:18:03
6335	DELSUPDEL	2015-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	5051	\N	2015-10-15 00:00:00	2015-10-15 00:00:00
6337	DELSUPDEL	2015-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	5053	\N	2015-10-15 18:07:05	2017-09-24 18:17:56
5219	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4238	\N	2014-10-29 12:16:42	2017-10-17 09:39:29
4375	VICPDTDEL	2011-12-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3041	\N	\N	\N
4309	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3506	\N	\N	\N
4225	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3535	\N	\N	\N
4394	SECRETDEL	2011-12-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3543	\N	\N	\N
4241	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3553	\N	\N	\N
4389	VICPDTDEL	2011-12-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3563	\N	\N	\N
4386	VICPDTDEL	2011-12-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3572	\N	\N	\N
4266	DELEGUEDEL	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3580	\N	\N	\N
4392	VICPDTDEL	2011-12-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3586	\N	\N	\N
5209	DELEGUEDEL	2014-10-29 00:00:00	2014-11-05 00:00:00	ANCIEN	\N	\N	\N	\N	4228	\N	2014-10-29 12:14:47	2014-11-06 18:54:39
5210	DELEGUEDEL	2014-10-29 00:00:00	2014-11-05 00:00:00	ANCIEN	\N	\N	\N	\N	4229	\N	2014-10-29 12:14:54	2014-11-06 18:55:48
5211	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4230	\N	2014-10-29 12:15:02	2017-10-17 09:39:26
5214	DELEGUEDEL	2014-10-29 00:00:00	2014-11-05 00:00:00	ANCIEN	\N	\N	\N	\N	4233	\N	2014-10-29 12:15:58	2014-11-06 18:54:50
5215	DELEGUEDEL	2014-10-29 00:00:00	2015-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	4234	\N	2014-10-29 12:16:07	2015-12-09 10:32:07
5216	DELEGUEDEL	2014-10-29 00:00:00	2014-11-05 00:00:00	ANCIEN	\N	\N	\N	\N	4235	\N	2014-10-29 12:16:13	2014-11-06 18:55:09
5217	DELEGUEDEL	2014-10-29 00:00:00	2016-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	4236	\N	2014-10-29 12:16:25	2016-02-08 10:46:36
5218	DELEGUEDEL	2014-10-29 00:00:00	2014-11-05 00:00:00	ANCIEN	\N	\N	\N	\N	4237	\N	2014-10-29 12:16:35	2014-11-06 18:55:17
5221	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4240	\N	2014-10-29 12:17:07	2017-10-17 09:39:31
5222	DELEGUEDEL	2014-10-29 00:00:00	2014-11-05 00:00:00	ANCIEN	\N	\N	\N	\N	4241	\N	2014-10-29 12:17:12	2014-11-06 18:56:03
5223	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4242	\N	2014-10-29 12:17:20	2017-10-17 09:39:24
8346	DELEGUEDEL	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6345	\N	\N	\N
5225	DELEGUEDEL	2014-10-29 00:00:00	2014-11-05 00:00:00	ANCIEN	\N	\N	\N	\N	4244	\N	2014-10-29 12:17:32	2014-11-06 18:54:25
5226	DELEGUEDEL	2014-10-29 00:00:00	2014-11-05 00:00:00	ANCIEN	\N	\N	\N	\N	4245	\N	2014-10-29 12:17:37	2014-11-06 18:54:32
5227	DELEGUEDEL	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4246	\N	2014-10-29 12:18:05	2017-09-24 19:31:54
5228	DELEGUEDEL	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4247	\N	2014-10-29 12:18:11	2017-09-24 17:42:25
5229	DELEGUEDEL	2014-10-29 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	4248	\N	2014-10-29 12:18:18	2017-06-19 16:06:51
5230	DELEGUEDEL	2014-10-29 00:00:00	2015-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	4249	\N	2014-10-29 12:18:24	2015-11-17 21:42:15
5232	DELEGUEDEL	2014-10-29 00:00:00	2014-11-05 00:00:00	ANCIEN	\N	\N	\N	\N	4251	\N	2014-10-29 12:18:35	2014-11-06 18:55:34
5233	DELEGUEDEL	2014-10-29 00:00:00	2014-11-05 00:00:00	ANCIEN	\N	\N	\N	\N	4252	\N	2014-10-29 12:18:42	2014-11-06 18:55:56
5234	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4253	\N	2014-10-29 12:18:46	2017-10-17 09:39:30
5235	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4254	\N	2014-10-29 12:18:53	2017-10-17 09:39:23
5237	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4256	\N	2014-10-29 12:19:09	2017-10-17 09:39:29
5238	DELEGUEDEL	2014-10-29 00:00:00	2014-11-05 00:00:00	ANCIEN	\N	\N	\N	\N	4257	\N	2014-10-29 12:19:15	2014-11-06 18:54:03
5239	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4258	\N	2014-10-29 12:19:46	2017-10-17 09:39:26
5240	DELEGUEDEL	2014-10-29 00:00:00	2014-11-05 00:00:00	ANCIEN	\N	\N	\N	\N	4259	\N	2014-10-29 12:19:51	2014-11-06 18:55:00
5241	DELEGUEDEL	2014-10-29 00:00:00	2014-11-05 00:00:00	ANCIEN	\N	\N	\N	\N	4260	\N	2014-10-29 12:19:58	2014-11-06 18:55:26
5242	DELEGUEDEL	2014-10-29 00:00:00	2014-11-05 00:00:00	ANCIEN	\N	\N	\N	\N	4261	\N	2014-10-29 12:20:07	2014-11-06 18:54:16
5244	DELEGUEDEL	2014-10-29 00:00:00	2014-11-09 00:00:00	ANCIEN	\N	\N	\N	\N	4263	\N	2014-10-29 12:22:36	2014-11-10 10:47:12
5245	DELEGUEDEL	2014-10-29 00:00:00	2014-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	4264	\N	2014-10-29 12:22:41	2014-11-10 10:49:57
5246	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4265	\N	2014-10-29 12:22:49	2017-10-17 09:40:12
5247	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4266	\N	2014-10-29 12:22:55	2017-10-17 09:40:12
5248	DELEGUEDEL	2014-10-29 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	4267	\N	2014-10-29 12:23:01	2015-06-12 16:01:25
5249	DELEGUEDEL	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4268	\N	2014-10-29 12:23:12	2017-09-24 17:15:15
5250	DELEGUEDEL	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4269	\N	2014-10-29 12:23:17	2017-09-24 18:59:59
5251	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4270	\N	2014-10-29 12:23:23	2017-10-17 09:40:13
5252	DELEGUEDEL	2014-10-29 00:00:00	2014-11-09 00:00:00	ANCIEN	\N	\N	\N	\N	4271	\N	2014-10-29 12:23:30	2014-11-10 10:48:29
5253	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4272	\N	2014-10-29 12:23:37	2017-10-17 09:40:14
5255	DELEGUEDEL	2014-10-29 00:00:00	2014-11-09 00:00:00	ANCIEN	\N	\N	\N	\N	4274	\N	2014-10-29 12:23:52	2014-11-10 10:47:03
5256	DELEGUEDEL	2014-10-29 00:00:00	2014-11-09 00:00:00	ANCIEN	\N	\N	\N	\N	4275	\N	2014-10-29 12:24:54	2014-11-10 10:48:47
5260	DELEGUEDEL	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4279	\N	2014-10-29 12:25:20	2017-09-24 17:15:15
5261	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4280	\N	2014-10-29 12:25:29	2017-10-17 09:40:14
5262	DELEGUEDEL	2014-10-29 00:00:00	2014-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	4281	\N	2014-10-29 12:25:35	2014-11-10 10:52:17
5263	DELEGUEDEL	2014-10-29 00:00:00	2014-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	4282	\N	2014-10-29 12:25:42	2014-11-10 10:50:04
5265	DELEGUEDEL	2014-10-29 00:00:00	2014-11-09 00:00:00	ANCIEN	\N	\N	\N	\N	4284	\N	2014-10-29 12:25:58	2014-11-10 10:48:54
5266	DELEGUEDEL	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4285	\N	2014-10-29 12:26:05	2017-09-24 17:29:37
5267	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4286	\N	2014-10-29 12:27:22	2017-10-17 09:40:16
5268	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4287	\N	2014-10-29 12:27:28	2017-10-17 09:40:16
5271	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4290	\N	2014-10-29 12:27:50	2017-10-17 09:40:15
5272	DELEGUEDEL	2014-10-29 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	4291	\N	2014-10-29 12:27:57	2015-06-12 15:59:49
5273	DELEGUEDEL	2014-10-29 00:00:00	2014-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	4292	\N	2014-10-29 12:28:03	2014-11-10 10:49:32
5274	DELEGUEDEL	2014-10-29 00:00:00	2014-11-09 00:00:00	ANCIEN	\N	\N	\N	\N	4293	\N	2014-10-29 12:28:10	2014-11-10 10:48:21
5275	DELEGUEDEL	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4294	\N	2014-10-29 12:28:19	2017-09-24 17:19:42
5276	DELEGUEDEL	2014-10-29 00:00:00	2014-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	4295	\N	2014-10-29 12:28:34	2014-11-10 10:50:28
5278	DELEGUEDEL	2014-10-29 00:00:00	2014-11-09 00:00:00	ANCIEN	\N	\N	\N	\N	4297	\N	2014-10-29 12:28:48	2014-11-10 10:47:20
5279	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4298	\N	2014-10-29 12:28:55	2017-10-17 09:40:15
5280	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4299	\N	2014-10-29 12:31:14	2017-10-17 09:39:50
5281	DELEGUEDEL	2014-10-29 00:00:00	2014-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	4300	\N	2014-10-29 12:31:20	2014-11-05 15:28:31
5282	DELEGUEDEL	2014-10-29 00:00:00	2014-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	4301	\N	2014-10-29 12:31:25	2014-11-05 15:28:41
5284	DELEGUEDEL	2014-10-29 00:00:00	2014-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	4303	\N	2014-10-29 12:31:36	2014-11-05 15:27:03
5285	DELEGUEDEL	2014-10-29 00:00:00	2014-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	4304	\N	2014-10-29 12:31:42	2014-11-05 15:27:14
5286	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4305	\N	2014-10-29 12:31:48	2017-10-17 09:39:52
5287	DELEGUEDEL	2014-10-29 00:00:00	2014-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	4306	\N	2014-10-29 12:31:54	2014-11-05 15:27:47
5288	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4307	\N	2014-10-29 12:32:00	2017-10-17 09:39:55
5289	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4308	\N	2014-10-29 12:32:06	2017-10-17 09:39:53
5290	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4309	\N	2014-10-29 12:32:14	2017-10-17 09:39:53
5291	DELEGUEDEL	2014-10-29 00:00:00	2016-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	4310	\N	2014-10-29 12:32:20	2016-11-18 12:37:50
5292	DELEGUEDEL	2014-10-29 00:00:00	2014-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	4311	\N	2014-10-29 12:32:28	2014-11-05 15:28:13
5294	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4313	\N	2014-10-29 12:32:38	2017-10-17 09:39:55
5296	DELEGUEDEL	2014-10-29 00:00:00	2014-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	4315	\N	2014-10-29 12:32:50	2014-11-05 15:26:45
5297	DELEGUEDEL	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4316	\N	2014-10-29 12:32:57	2017-09-24 18:16:52
5298	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4317	\N	2014-10-29 12:33:04	2017-10-17 09:39:55
5300	DELEGUEDEL	2014-10-29 00:00:00	2014-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	4319	\N	2014-10-29 12:33:18	2014-11-05 15:27:34
5302	DELEGUEDEL	2014-10-29 00:00:00	2014-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	4321	\N	2014-10-29 12:33:32	2014-11-05 15:28:04
5304	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4323	\N	2014-10-29 12:34:56	2017-10-17 09:39:54
5305	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4324	\N	2014-10-29 12:35:03	2017-10-17 09:39:54
5306	DELEGUEDEL	2014-10-29 00:00:00	2014-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	4325	\N	2014-10-29 12:35:10	2014-11-05 15:28:23
5307	DELEGUEDEL	2014-10-29 00:00:00	2014-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	4326	\N	2014-10-29 12:35:18	2014-11-05 15:26:29
5049	VICPDTDEL	2014-04-08 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4108	\N	2014-04-09 16:52:36	\N
5129	DELEGUEDEL	2014-07-03 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4188	\N	2014-07-03 15:21:31	\N
5308	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4327	\N	2014-10-29 12:35:24	2017-10-17 09:39:51
5309	DELEGUEDEL	2014-10-29 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	4328	\N	2014-10-29 12:36:20	2015-06-12 16:01:58
5310	DELEGUEDEL	2014-10-29 00:00:00	2015-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	4329	\N	2014-10-29 12:36:28	2015-10-07 11:00:33
5311	DELEGUEDEL	2014-10-29 00:00:00	2014-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	4330	\N	2014-10-29 12:36:35	2014-11-05 15:26:52
5312	DELEGUEDEL	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4331	\N	2014-10-29 12:36:43	2017-09-24 17:14:26
5313	DELEGUEDEL	2014-10-29 00:00:00	2014-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	4332	\N	2014-10-29 12:36:50	2014-11-05 15:27:55
5314	DELEGUEDEL	2014-10-29 00:00:00	2014-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	4333	\N	2014-10-29 12:36:58	2014-11-05 15:27:27
5315	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4334	\N	2014-10-29 12:37:03	2017-10-17 09:39:53
5316	DELEGUEDEL	2014-10-29 00:00:00	2014-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	4335	\N	2014-10-29 12:37:56	2014-11-20 19:04:25
5317	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4336	\N	2014-10-29 12:38:06	2017-10-17 09:40:33
5318	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4337	\N	2014-10-29 12:38:12	2017-10-17 09:40:33
5319	DELEGUEDEL	2014-10-29 00:00:00	2014-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	4338	\N	2014-10-29 12:38:18	2014-11-20 19:03:26
5320	DELEGUEDEL	2014-10-29 00:00:00	2015-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	4339	\N	2014-10-29 12:38:23	2015-11-03 17:06:46
5321	DELEGUEDEL	2014-10-29 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	4340	\N	2014-10-29 12:38:32	2017-09-25 09:57:52
5322	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4341	\N	2014-10-29 12:38:40	2017-10-17 09:40:35
5323	DELEGUEDEL	2014-10-29 00:00:00	2015-09-28 00:00:00	ANCIEN	\N	\N	\N	\N	4342	\N	2014-10-29 12:38:45	2015-09-28 09:39:18
5324	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4343	\N	2014-10-29 12:38:51	2017-10-17 09:40:37
5325	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4344	\N	2014-10-29 12:38:57	2017-10-17 09:40:38
5326	DELEGUEDEL	2014-10-29 00:00:00	2014-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	4345	\N	2014-10-29 12:39:03	2014-11-20 19:04:33
5328	DELEGUEDEL	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4347	\N	2014-10-29 12:39:18	2017-09-24 19:14:37
5410	DELTITDEL	2014-10-29 00:00:00	2015-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	4429	\N	2014-10-29 19:32:59	2015-10-08 14:53:29
5349	DELEGUEDEL	2014-10-29 00:00:00	2014-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	4368	\N	2014-10-29 12:46:19	2014-11-20 19:04:49
5350	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4369	\N	2014-10-29 12:46:26	2017-10-17 09:40:35
5351	DELEGUEDEL	2014-10-29 00:00:00	2014-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	4370	\N	2014-10-29 12:46:35	2014-11-20 19:03:55
5352	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4371	\N	2014-10-29 12:46:44	2017-10-17 09:40:37
5353	DELEGUEDEL	2014-10-29 00:00:00	2014-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	4372	\N	2014-10-29 12:46:51	2014-11-20 19:03:09
5355	DELEGUEDEL	2014-10-29 00:00:00	2014-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	4374	\N	2014-10-29 12:47:06	2014-11-20 19:02:41
5358	DELEGUEDEL	2014-10-29 00:00:00	2014-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	4377	\N	2014-10-29 12:47:34	2014-11-20 19:02:56
5359	DELEGUEDEL	2014-10-29 00:00:00	2014-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	4378	\N	2014-10-29 12:47:47	2014-11-20 19:03:19
5360	DELEGUEDEL	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4379	\N	2014-10-29 12:47:59	2017-09-25 10:54:33
5361	DELEGUEDEL	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4380	\N	2014-10-29 12:48:08	2017-09-25 10:54:33
5362	DELEGUEDEL	2014-10-29 00:00:00	2015-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	4381	\N	2014-10-29 12:48:23	2015-02-06 14:27:55
5363	DELEGUEDEL	2014-10-29 00:00:00	2014-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	4382	\N	2014-10-29 12:48:34	2014-11-20 19:03:36
5364	DELEGUEDEL	2014-10-29 00:00:00	2014-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	4383	\N	2014-10-29 12:48:45	2014-11-20 19:03:45
5365	DELEGUEDEL	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4384	\N	2014-10-29 12:48:56	2017-09-25 10:54:33
5366	DELEGUEDEL	2014-10-29 00:00:00	2015-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	4385	\N	2014-10-29 12:49:08	2015-02-06 14:32:44
5367	DELEGUEDEL	2014-10-29 00:00:00	2014-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	4386	\N	2014-10-29 12:49:20	2014-11-20 19:04:05
5368	DELEGUEDEL	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4387	\N	2014-10-29 12:49:30	2017-09-25 10:58:49
5369	DELEGUEDEL	2014-10-29 00:00:00	2014-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	4388	\N	2014-10-29 12:49:44	2014-11-20 19:04:42
5370	DELEGUEDEL	2014-10-29 00:00:00	2014-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	4389	\N	2014-10-29 12:49:53	2014-11-20 19:02:29
5371	DELEGUEDEL	2014-10-29 00:00:00	2014-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	4390	\N	2014-10-29 12:50:07	2014-11-20 19:04:14
5372	DELEGUEDEL	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4391	\N	2014-10-29 12:50:25	2017-09-24 18:16:33
5373	DELEGUEDEL	2014-10-29 00:00:00	2017-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	4392	\N	2014-10-29 12:50:35	2017-10-17 09:40:37
8347	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6346	\N	\N	\N
5374	DELEGUEDEL	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4393	\N	2014-10-29 12:50:45	2017-09-24 16:24:51
5375	DELEGUEDEL	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4394	\N	2014-10-29 12:51:01	2017-09-24 10:41:28
5376	DELEGUEDEL	2014-10-29 00:00:00	2016-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	4395	\N	2014-10-29 12:51:10	2016-11-14 11:07:47
5377	DELEGUEDEL	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4396	\N	2014-10-29 12:51:18	2017-09-24 16:24:51
5409	DELTITDEL	2014-10-29 00:00:00	2015-09-16 00:00:00	ANCIEN	\N	\N	\N	\N	4428	\N	2014-10-29 19:32:44	2015-09-16 15:50:22
5411	DELTITDEL	2014-10-29 00:00:00	2015-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	4430	\N	2014-10-29 19:33:10	2015-10-08 14:53:31
5412	DELTITDEL	2014-10-29 00:00:00	2015-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	4431	\N	2014-10-29 19:33:22	2015-10-08 14:53:32
5413	DELTITDEL	2014-10-29 00:00:00	2015-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	4432	\N	2014-10-29 19:33:38	2015-10-08 14:53:35
5414	DELTITDEL	2014-10-29 00:00:00	2014-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	4433	\N	2014-10-29 19:33:48	2014-12-18 16:15:04
5415	DELSUPDEL	2014-10-29 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	4434	\N	2014-10-29 19:34:05	2015-02-04 15:35:55
5416	DELSUPDEL	2014-10-29 00:00:00	2015-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	4435	\N	2014-10-29 19:34:11	2015-10-08 14:53:38
5417	DELSUPDEL	2014-10-29 00:00:00	2015-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	4436	\N	2014-10-29 19:34:18	2015-10-08 14:53:39
5418	DELSUPDEL	2014-10-29 00:00:00	2015-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	4437	\N	2014-10-29 19:34:25	2015-10-08 14:53:41
5419	DELSUPDEL	2014-10-29 00:00:00	2015-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	4438	\N	2014-10-29 19:34:33	2015-10-08 14:53:42
5420	DELSUPDEL	2014-10-29 00:00:00	2015-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	4439	\N	2014-10-29 19:34:41	2015-10-08 14:53:43
5429	DELEGUEDEL	2014-10-29 00:00:00	2016-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	4448	\N	2014-10-30 10:08:56	2016-01-12 18:23:53
5489	PDTDEL	2014-11-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4257	\N	2014-11-06 18:54:03	2017-09-24 17:47:27
5490	VICPDTDEL	2014-11-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4261	\N	2014-11-06 18:54:16	2017-09-24 17:09:24
5491	VICPDTDEL	2014-11-06 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4244	\N	2014-11-06 18:54:25	2017-10-17 09:39:16
5492	VICPDTDEL	2014-11-06 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4245	\N	2014-11-06 18:54:32	2017-10-17 09:39:17
5493	VICPDTDEL	2014-11-06 00:00:00	2016-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	4228	\N	2014-11-06 18:54:39	2016-01-29 10:12:14
5494	VICPDTDEL	2014-11-06 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4233	\N	2014-11-06 18:54:50	2017-10-17 09:39:18
5495	VICPDTDEL	2014-11-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4259	\N	2014-11-06 18:55:00	2017-09-24 19:25:10
5496	VICPDTDEL	2014-11-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4235	\N	2014-11-06 18:55:08	2017-09-24 18:17:56
5497	VICPDTDEL	2014-11-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4237	\N	2014-11-06 18:55:17	2017-09-24 18:59:59
5498	VICPDTDEL	2014-11-06 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4260	\N	2014-11-06 18:55:26	2017-10-17 09:39:19
5499	VICPDTDEL	2014-11-06 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4251	\N	2014-11-06 18:55:34	2017-10-17 09:39:20
5500	SECRETDEL	2014-11-06 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4229	\N	2014-11-06 18:55:48	2017-10-17 09:39:23
5501	SECRETDEL	2014-11-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4252	\N	2014-11-06 18:55:56	2017-09-24 13:14:55
5502	SECRETDEL	2014-11-06 00:00:00	2016-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	4241	\N	2014-11-06 18:56:03	2016-01-29 10:11:58
4490	PDTDEL	2011-11-01 00:00:00	2014-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	3669	\N	\N	2014-12-09 17:05:04
5689	DELEGUEDEL	2014-12-09 00:00:00	2016-06-08 00:00:00	ANCIEN	\N	\N	\N	\N	4568	\N	2014-12-09 17:05:13	2016-06-09 09:38:45
5690	DELEGUEDEL	2014-12-09 00:00:00	2015-01-14 00:00:00	ANCIEN	\N	\N	\N	\N	4569	\N	2014-12-09 17:05:35	2015-01-15 15:40:13
5691	DELEGUEDEL	2014-12-09 00:00:00	2015-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	4570	\N	2014-12-09 17:05:52	2015-01-15 15:40:37
5809	PDTDEL	2015-01-15 00:00:00	2016-06-08 00:00:00	ANCIEN	\N	\N	\N	\N	4569	\N	2015-01-15 15:40:13	2016-06-09 09:38:34
5810	VICPDTDEL	2015-01-14 00:00:00	2016-06-08 00:00:00	ANCIEN	\N	\N	\N	\N	4570	\N	2015-01-15 15:40:37	2016-06-09 09:38:54
5829	DELTITDEL	2015-02-03 00:00:00	2015-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	4434	\N	2015-02-04 15:35:55	2015-10-08 14:53:28
5830	DELSUPDEL	2015-02-03 00:00:00	2015-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	4668	\N	2015-02-04 15:36:14	2015-10-08 14:53:36
6089	RAPGEN	2015-06-03 00:00:00	2015-10-15 00:00:00	ANCIEN	\N	\N	\N	\N	3809	\N	2015-06-03 18:46:47	2015-10-15 17:58:16
6109	SECRETDEL	2015-06-15 00:00:00	2016-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	3293	\N	2015-06-16 18:12:48	2016-07-05 10:57:47
6289	DELEGUEDEL	2015-10-07 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	5008	\N	2015-10-07 11:00:47	2017-10-17 09:39:51
6338	DELSUPDEL	2015-10-15 00:00:00	2017-11-07 00:00:00	ANCIEN	\N	\N	\N	\N	5054	\N	2015-10-15 18:07:18	2017-11-14 11:35:39
6339	DELSUPDEL	2015-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	5055	\N	2015-10-15 18:07:30	2017-09-24 17:47:27
6340	DELSUPDEL	2015-10-15 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	5056	\N	2015-10-15 18:07:43	2015-10-15 18:07:46
6350	DELTITDEL	2015-10-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5069	\N	2015-10-16 11:10:29	2017-10-01 09:22:38
7378	PDTDEL	2017-11-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4412	\N	2017-11-09 17:40:30	\N
7379	VICPDTDEL	2017-11-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4417	\N	2017-11-09 17:40:51	\N
7380	VICPDTDEL	2017-11-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4422	\N	2017-11-09 17:41:10	\N
7381	VICPDTDEL	2017-11-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1165	\N	2017-11-09 17:41:21	\N
7469	DELEGUEDEL	2017-11-21 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5808	\N	2017-11-21 18:25:57	\N
7507	VICPDTDEL	2017-11-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5835	2	2017-11-29 18:28:13	2017-11-29 18:29:45
7508	VICPDTDEL	2017-11-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2800	3	2017-11-29 18:28:18	2017-11-29 18:29:47
7509	SECRETDEL	2017-11-29 00:00:00	2020-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	5828	4	2017-11-29 18:29:03	2017-11-29 18:29:49
7510	SECRETDEL	2017-11-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5834	7	2017-11-29 18:29:12	2017-11-29 18:30:01
7511	SECRETDEL	2017-11-29 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	5836	6	2017-11-29 18:29:23	2017-11-29 18:29:58
7512	SECRETDEL	2017-11-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5830	5	2017-11-29 18:29:30	2017-11-29 18:29:54
5928	DELEGUEDEL	2015-02-13 00:00:00	2018-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	4767	\N	2015-02-13 16:12:01	2018-01-09 14:22:40
5942	DELEGUEDEL	2015-02-13 00:00:00	2018-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	4781	\N	2015-02-13 16:13:49	2018-01-09 14:24:10
5954	DELEGUEDEL	2015-02-13 00:00:00	2018-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	4793	\N	2015-02-13 16:15:28	2018-01-09 14:25:36
7549	DELEGUEDEL	2018-01-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5868	\N	2018-01-09 14:28:52	\N
7550	DELEGUEDEL	2018-01-08 00:00:00	2020-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	5869	\N	2018-01-09 14:28:58	\N
7551	DELEGUEDEL	2018-01-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	5870	\N	2018-01-09 00:00:00	\N
7552	DELEGUEDEL	2018-01-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5871	\N	2018-01-09 14:29:29	\N
7553	DELEGUEDEL	2018-01-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5872	\N	2018-01-09 14:29:35	\N
7554	DELEGUEDEL	2018-01-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	5873	\N	2018-01-09 00:00:00	\N
7555	DELEGUEDEL	2018-01-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	5874	\N	2018-01-09 00:00:00	\N
7556	DELEGUEDEL	2018-01-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	5875	\N	2018-01-09 00:00:00	\N
7557	DELEGUEDEL	2018-01-08 00:00:00	2018-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	5876	\N	2018-01-09 14:30:19	\N
7558	DELEGUEDEL	2018-01-08 00:00:00	2023-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	5877	\N	2018-01-09 14:30:27	\N
7559	DELEGUEDEL	2018-01-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5878	\N	2018-01-09 14:30:32	\N
7560	DELEGUEDEL	2018-01-08 00:00:00	2020-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	5879	\N	2018-01-09 14:30:54	\N
7561	DELEGUEDEL	2018-01-08 00:00:00	2018-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	5880	\N	2018-01-09 14:31:07	\N
7562	DELEGUEDEL	2018-01-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	5881	\N	2018-01-09 00:00:00	\N
7563	DELEGUEDEL	2018-01-08 00:00:00	2020-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	5882	\N	2018-01-09 14:33:49	\N
7564	DELEGUEDEL	2018-01-08 00:00:00	2018-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	5883	\N	2018-01-09 14:33:52	2018-05-31 10:52:17
7571	DELEGUEDEL	2018-01-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	5890	\N	2018-01-09 14:35:41	\N
7566	DELEGUEDEL	2018-01-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	5885	\N	2018-01-09 00:00:00	\N
7567	DELEGUEDEL	2018-01-08 00:00:00	2020-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	5886	\N	2018-01-09 14:34:38	\N
7568	DELEGUEDEL	2018-01-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5887	\N	2018-01-09 14:35:07	\N
7569	DELEGUEDEL	2018-01-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	5888	\N	2018-01-09 00:00:00	\N
7570	DELEGUEDEL	2018-01-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	5889	\N	2018-01-09 14:35:26	\N
7572	DELEGUEDEL	2018-01-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	5891	\N	2018-01-09 00:00:00	\N
7573	DELEGUEDEL	2018-01-08 00:00:00	2020-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	5892	\N	2018-01-09 14:36:04	\N
7574	DELEGUEDEL	2018-01-08 00:00:00	2020-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	5893	\N	2018-01-09 14:36:21	\N
7575	DELEGUEDEL	2018-01-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	5894	\N	2018-01-09 14:36:34	\N
7576	DELEGUEDEL	2018-01-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5895	\N	2018-01-09 14:36:43	\N
7577	DELEGUEDEL	2018-01-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	5896	\N	2018-01-09 00:00:00	\N
7578	DELEGUEDEL	2018-01-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	5897	\N	2018-01-09 00:00:00	\N
7579	DELEGUEDEL	2018-01-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	5898	\N	2018-01-09 14:37:19	\N
7580	DELEGUEDEL	2018-01-08 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	5899	\N	2018-01-09 14:37:23	\N
7581	DELEGUEDEL	2018-01-08 00:00:00	2020-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	5900	\N	2018-01-09 14:38:11	\N
7582	DELEGUEDEL	2018-01-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5901	\N	2018-01-09 14:38:46	\N
7583	DELEGUEDEL	2018-01-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	5902	\N	2018-01-09 00:00:00	\N
7584	DELEGUEDEL	2018-01-08 00:00:00	2020-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	5903	\N	2018-01-09 14:39:00	\N
7585	DELEGUEDEL	2018-01-08 00:00:00	2020-08-03 00:00:00	ANCIEN	\N	\N	\N	\N	5904	\N	2018-01-09 14:42:57	\N
7589	DELEGUEDEL	2018-01-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5908	\N	2018-02-01 20:32:15	\N
7669	DELSUPDEL	2018-06-25 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	5968	\N	\N	\N
7689	DELEGUEDEL	2018-07-20 00:00:00	2020-06-10 00:00:00	ANCIEN	\N	\N	\N	\N	4568	\N	\N	\N
7709	DELEGUEDEL	2018-07-23 00:00:00	2018-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	3271	\N	\N	\N
7809	VICPDTDEL	2018-11-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3988	\N	\N	\N
7909	SECRETDEL	2018-12-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6088	\N	\N	\N
7949	DELEGUEDEL	2018-12-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	5880	\N	\N	\N
8009	DELEGUEDEL	2019-03-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6108	\N	\N	\N
8013	DELEGUEDEL	2019-03-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6111	\N	\N	\N
8049	DELEGUEDEL	2019-05-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6128	\N	\N	\N
8050	PDTDEL	2019-05-17 00:00:00	2020-06-10 00:00:00	ANCIEN	\N	\N	\N	\N	5548	\N	\N	\N
8051	VICPDTDEL	2019-05-17 00:00:00	2020-06-10 00:00:00	ANCIEN	\N	\N	\N	\N	5128	\N	\N	\N
8149	DELEGUEDEL	2019-10-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6208	\N	\N	\N
8249	VICPDTDEL	2020-04-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5653	\N	\N	\N
8269	VICPDTPREDEL	2020-06-11 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4568	\N	\N	\N
8270	DELEGUEDEL	2020-06-11 00:00:00	2022-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	5548	\N	\N	\N
8271	DELEGUEDEL	2020-06-11 00:00:00	2020-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	5128	\N	\N	\N
8289	DELEGUEDEL	2020-06-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6288	\N	\N	\N
7128	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4496	\N	2017-10-18 16:20:11	\N
8329	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6328	\N	\N	\N
8330	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6329	\N	\N	\N
8331	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6330	\N	\N	\N
8332	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6331	\N	\N	\N
8333	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6332	\N	\N	\N
8334	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6333	\N	\N	\N
8335	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6334	\N	\N	\N
8336	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6335	\N	\N	\N
8337	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6336	\N	\N	\N
8338	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6337	\N	\N	\N
8339	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6338	\N	\N	\N
8340	DELEGUEDEL	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6339	\N	\N	\N
8341	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6340	\N	\N	\N
8342	DELEGUEDEL	2020-10-20 00:00:00	2021-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	6341	\N	\N	\N
8348	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6347	\N	\N	\N
8349	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6348	\N	\N	\N
8350	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6349	\N	\N	\N
8351	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6350	\N	\N	\N
8352	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6351	\N	\N	\N
8353	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6352	\N	\N	\N
8354	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6353	\N	\N	\N
8364	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6363	\N	\N	\N
8356	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6355	\N	\N	\N
8357	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6356	\N	\N	\N
8358	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6357	\N	\N	\N
8359	DELEGUEDEL	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6358	\N	\N	\N
8360	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6359	\N	\N	\N
8361	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6360	\N	\N	\N
8362	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6361	\N	\N	\N
8363	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6362	\N	\N	\N
8365	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6364	\N	\N	\N
7067	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3058	\N	2017-10-18 16:02:09	\N
7071	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3077	\N	2017-10-18 16:03:45	\N
8366	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6365	\N	\N	\N
8367	DELEGUEDEL	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6366	\N	\N	\N
8368	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6367	\N	\N	\N
8369	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6368	\N	\N	\N
8370	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6369	\N	\N	\N
8371	DELEGUEDEL	2020-10-20 00:00:00	2021-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	6370	\N	\N	\N
8372	DELEGUEDEL	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6371	\N	\N	\N
8373	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6372	\N	\N	\N
8374	DELEGUEDEL	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6373	\N	\N	\N
8375	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6374	\N	\N	\N
8376	DELEGUEDEL	2020-10-20 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	6375	\N	\N	\N
5750	DELEGUEDEL	2014-11-04 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4629	\N	2015-01-12 19:00:59	2017-10-01 09:41:22
5236	DELEGUEDEL	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4255	\N	2014-10-29 12:19:02	2017-10-01 10:39:22
5224	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4243	\N	2014-10-29 12:17:24	2017-10-17 09:39:25
5212	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4231	\N	2014-10-29 12:15:33	2017-10-17 09:39:27
5243	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4262	\N	2014-10-29 12:20:13	2017-10-17 09:39:29
5231	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4250	\N	2014-10-29 12:18:28	2017-10-17 09:39:32
5469	PDTDEL	2014-11-05 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4326	\N	2014-11-05 15:26:29	2017-10-17 09:39:44
5474	VICPDTDEL	2014-11-05 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4333	\N	2014-11-05 15:27:27	2017-10-17 09:39:46
5482	SECRETDEL	2014-11-05 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4301	\N	2014-11-05 15:28:41	2017-10-17 09:39:48
6290	DELEGUEDEL	2015-10-07 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	5009	\N	2015-10-07 11:01:00	2017-10-17 09:39:51
5301	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4320	\N	2014-10-29 12:33:24	2017-10-17 09:39:52
5303	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4322	\N	2014-10-29 12:34:49	2017-10-17 09:39:54
5293	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4312	\N	2014-10-29 12:32:33	2017-10-17 09:39:55
5524	VICPDTDEL	2014-11-05 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4295	\N	2014-11-10 10:50:28	2017-10-17 09:40:07
5517	VICPDTDEL	2014-11-10 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4284	\N	2014-11-10 10:48:54	2017-10-17 09:40:08
5523	SECRETDEL	2014-11-05 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4277	\N	2014-11-10 10:50:11	2017-10-17 09:40:10
5259	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4278	\N	2014-10-29 12:25:15	2017-10-17 09:40:11
5277	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4296	\N	2014-10-29 12:28:41	2017-10-17 09:40:13
5270	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4289	\N	2014-10-29 12:27:43	2017-10-17 09:40:14
5264	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4283	\N	2014-10-29 12:25:48	2017-10-17 09:40:15
5552	VICPDTDEL	2014-11-20 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4372	\N	2014-11-20 19:03:09	2017-10-17 09:40:28
5556	VICPDTDEL	2014-11-20 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4383	\N	2014-11-20 19:03:45	2017-10-17 09:40:29
5562	SECRETDEL	2014-11-20 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4388	\N	2014-11-20 19:04:42	2017-10-17 09:40:31
5357	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4376	\N	2014-10-29 12:47:22	2017-10-17 09:40:32
5354	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4373	\N	2014-10-29 12:46:59	2017-10-17 09:40:34
5327	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4346	\N	2014-10-29 12:39:10	2017-10-17 09:40:36
6049	DELEGUEDEL	2015-05-04 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4848	\N	2015-05-05 16:30:42	2017-10-17 09:40:36
5356	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4375	\N	2014-10-29 12:47:12	2017-10-17 09:40:38
5652	VICPDTDEL	2014-12-04 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4509	\N	2014-12-04 14:56:51	2017-10-17 09:40:51
5656	VICPDTDEL	2014-12-04 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4498	\N	2014-12-04 14:57:20	2017-10-17 09:40:53
5663	SECRETDEL	2014-12-04 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4518	\N	2014-12-04 14:58:17	2017-10-17 09:40:55
5614	DELEGUEDEL	2014-11-26 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4513	\N	2014-11-26 13:28:29	2017-10-17 09:40:59
5623	DELEGUEDEL	2014-11-26 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4522	\N	2014-11-26 13:29:28	2017-10-17 09:41:00
5600	DELEGUEDEL	2014-11-26 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4499	\N	2014-11-26 13:26:55	2017-10-17 09:41:02
8029	VICPDTDEL	2019-03-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5468	\N	\N	\N
5669	DELEGUEDEL	2014-12-03 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4548	\N	2014-12-08 11:43:49	2017-10-17 09:41:03
7073	DELEGUEDEL	2017-10-18 00:00:00	2017-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	5584	\N	2017-10-18 16:04:19	2017-11-03 10:47:40
7389	DELEGUEDEL	2017-11-14 00:00:00	2023-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	5728	\N	2017-11-14 00:00:00	\N
7390	DELEGUEDEL	2017-11-07 00:00:00	2017-11-13 00:00:00	ANCIEN	\N	\N	\N	\N	5728	\N	2017-11-14 11:32:25	2017-11-14 11:32:57
7391	DELEGUEDEL	2017-11-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5729	\N	2017-11-14 11:34:04	\N
7392	DELEGUEDEL	2017-11-07 00:00:00	2018-09-20 00:00:00	ANCIEN	\N	\N	\N	\N	5730	\N	2017-11-14 11:34:10	\N
7393	DELEGUEDEL	2017-11-07 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	5731	\N	2017-11-14 11:34:16	\N
7394	DELTITDEL	2017-11-07 00:00:00	2019-03-04 00:00:00	ANCIEN	\N	\N	\N	\N	5732	\N	2017-11-14 11:35:46	2017-11-14 11:35:55
7395	DELTITDEL	2017-11-07 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	5733	\N	2017-11-14 11:36:09	2017-11-14 11:36:12
7396	DELTITDEL	2017-11-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	5734	\N	2017-11-14 11:36:20	2017-11-14 11:36:24
7397	DELTITDEL	2017-11-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	5735	\N	2017-11-14 00:00:00	2017-11-14 00:00:00
7398	DELSUPDEL	2017-11-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	5736	\N	2017-11-14 11:36:47	2017-11-14 11:37:09
7399	DELSUPDEL	2017-11-07 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	5737	\N	2017-11-14 11:37:27	2017-11-14 11:37:32
7400	DELSUPDEL	2017-11-07 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	5738	\N	2017-11-14 11:37:39	2017-11-14 11:37:46
7401	DELSUPDEL	2017-11-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5739	\N	2017-11-14 11:37:57	2017-11-14 11:38:01
7424	DELEGUEDEL	2017-11-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	5762	\N	2017-11-14 00:00:00	\N
7403	DELEGUEDEL	2017-11-14 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	5741	\N	2017-11-14 11:39:32	\N
5862	DELEGUEDEL	2015-02-13 00:00:00	2017-11-07 00:00:00	ANCIEN	\N	\N	\N	\N	4702	\N	2015-02-13 15:52:20	2017-11-14 11:41:28
5994	DELEGUEDEL	2015-02-25 00:00:00	2017-11-07 00:00:00	ANCIEN	\N	\N	\N	\N	4833	\N	2015-02-25 16:06:22	2017-11-14 11:41:33
5880	DELEGUEDEL	2015-02-13 00:00:00	2017-11-07 00:00:00	ANCIEN	\N	\N	\N	\N	4721	\N	2015-02-13 15:55:02	2017-11-14 11:42:08
5892	DELEGUEDEL	2015-02-13 00:00:00	2017-11-07 00:00:00	ANCIEN	\N	\N	\N	\N	4736	\N	2015-02-13 15:57:01	2017-11-14 11:42:51
7404	DELEGUEDEL	2017-11-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5742	\N	2017-11-14 11:43:02	\N
7405	DELEGUEDEL	2017-11-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5743	\N	2017-11-14 11:43:07	\N
7406	DELEGUEDEL	2017-11-07 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	5744	\N	2017-11-14 11:43:14	\N
7407	DELEGUEDEL	2017-11-07 00:00:00	2023-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	5745	\N	2017-11-14 00:00:00	\N
7408	DELEGUEDEL	2017-11-07 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	5746	\N	2017-11-14 11:43:28	\N
7409	DELEGUEDEL	2017-11-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5747	\N	2017-11-14 11:43:33	\N
7410	DELEGUEDEL	2017-11-07 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	5748	\N	2017-11-14 11:43:38	\N
7411	DELEGUEDEL	2017-11-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5749	\N	2017-11-14 11:43:56	\N
7412	DELEGUEDEL	2017-11-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	5750	\N	2017-11-14 00:00:00	\N
7413	DELEGUEDEL	2017-11-07 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	5751	\N	2017-11-14 11:44:09	\N
7414	DELEGUEDEL	2017-11-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	5752	\N	2017-11-14 00:00:00	\N
7415	DELEGUEDEL	2017-11-07 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	5753	\N	2017-11-14 11:44:23	\N
7416	DELEGUEDEL	2017-11-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	5754	\N	2017-11-14 00:00:00	\N
7417	DELEGUEDEL	2017-11-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5755	\N	2017-11-14 11:44:37	\N
7418	DELEGUEDEL	2017-11-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	5756	\N	2017-11-14 00:00:00	\N
7419	DELEGUEDEL	2017-11-07 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	5757	\N	2017-11-14 11:44:54	\N
7420	DELEGUEDEL	2017-11-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5758	\N	2017-11-14 11:44:59	\N
7421	DELEGUEDEL	2017-11-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5759	\N	2017-11-14 11:45:12	\N
7422	DELEGUEDEL	2017-11-07 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	5760	\N	2017-11-14 11:45:17	\N
7423	DELEGUEDEL	2017-11-07 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	5761	\N	2017-11-14 11:45:27	\N
7425	DELEGUEDEL	2017-11-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	5763	\N	2017-11-14 11:45:38	\N
5257	DELEGUEDEL	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4276	\N	2014-10-29 12:25:00	2017-09-24 17:48:21
7426	DELEGUEDEL	2017-11-07 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	5764	\N	2017-11-14 11:45:43	\N
7427	DELEGUEDEL	2017-11-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5765	\N	2017-11-14 11:45:49	\N
7428	DELEGUEDEL	2017-11-07 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	5766	\N	2017-11-14 11:45:55	\N
7429	DELEGUEDEL	2017-11-07 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	5767	\N	2017-11-14 11:46:00	\N
7430	DELEGUEDEL	2017-11-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5768	\N	2017-11-14 11:46:06	\N
7431	DELEGUEDEL	2017-11-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5769	\N	2017-11-14 11:46:11	\N
7432	DELEGUEDEL	2017-11-07 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	5770	\N	2017-11-14 11:46:16	\N
7433	DELEGUEDEL	2017-11-07 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	5771	\N	2017-11-14 11:46:25	\N
7434	DELEGUEDEL	2017-11-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5772	\N	2017-11-14 11:46:30	\N
7435	DELEGUEDEL	2017-11-07 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	5773	\N	2017-11-14 11:46:35	\N
5711	VICPDTDEL	2014-12-10 00:00:00	2017-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	2800	3	2014-12-10 16:22:59	2017-11-28 10:07:57
7609	DELEGUEDEL	2018-02-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5928	\N	2018-02-06 19:00:24	\N
5925	SECRETGENDEL	2015-02-13 00:00:00	2020-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	4764	\N	2015-02-13 16:11:35	2018-02-20 20:12:11
7729	DELEGUEDEL	2018-09-21 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	5988	\N	\N	\N
7769	DELTITDEL	2018-10-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	5711	\N	\N	\N
7770	DELSUPDEL	2018-10-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6028	\N	\N	\N
8069	PDTDEL	2019-06-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6148	\N	\N	\N
7872	DELEGUEDEL	2018-11-21 00:00:00	2018-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	6048	\N	\N	\N
7873	VICPDTDEL	2018-11-22 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	6048	\N	\N	\N
7890	DELEGUEDEL	2018-12-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6069	\N	\N	\N
7969	DELEGUEDEL	2019-03-12 00:00:00	2019-03-28 00:00:00	ANCIEN	\N	\N	\N	\N	5468	\N	\N	\N
8109	DELEGUEDEL	2019-09-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6168	\N	\N	\N
8129	DELEGUEDEL	2019-10-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6188	\N	\N	\N
8169	DELEGUEDEL	2019-12-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6228	\N	\N	\N
8229	DELEGUEDEL	2017-07-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6268	\N	\N	\N
8230	PDTDEL	2019-04-04 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6269	\N	\N	\N
8377	DELEGUEDEL	2020-10-20 00:00:00	2021-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	6376	\N	\N	\N
8378	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6377	\N	\N	\N
8379	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6378	\N	\N	\N
8380	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6379	\N	\N	\N
8381	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6380	\N	\N	\N
8382	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6381	\N	\N	\N
8383	DELEGUEDEL	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6382	\N	\N	\N
8384	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6383	\N	\N	\N
8385	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6384	\N	\N	\N
8386	DELEGUEDEL	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6385	\N	\N	\N
8387	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6386	\N	\N	\N
8388	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6387	\N	\N	\N
8389	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6388	\N	\N	\N
8390	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6389	\N	\N	\N
8391	DELEGUEDEL	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6390	\N	\N	\N
8392	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6391	\N	\N	\N
8393	DELEGUEDEL	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6392	\N	\N	\N
8394	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6393	\N	\N	\N
8395	DELEGUEDEL	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6394	\N	\N	\N
8396	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6395	\N	\N	\N
8397	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6396	\N	\N	\N
8398	DELEGUEDEL	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6397	\N	\N	\N
8399	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6398	\N	\N	\N
8400	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6399	\N	\N	\N
8401	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6400	\N	\N	\N
8402	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6401	\N	\N	\N
8403	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6402	\N	\N	\N
8404	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6403	\N	\N	\N
8405	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6404	\N	\N	\N
8406	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6405	\N	\N	\N
8407	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6406	\N	\N	\N
8408	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6407	\N	\N	\N
8409	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6408	\N	\N	\N
8410	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6409	\N	\N	\N
8411	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6410	\N	\N	\N
8412	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6411	\N	\N	\N
8413	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6412	\N	\N	\N
8415	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6414	\N	\N	\N
8417	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6416	\N	\N	\N
8418	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6417	\N	\N	\N
8419	DELEGUEDEL	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6418	\N	\N	\N
8420	DELEGUEDEL	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6419	\N	\N	\N
8421	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6420	\N	\N	\N
8422	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6421	\N	\N	\N
8423	DELEGUEDEL	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6422	\N	\N	\N
8424	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6423	\N	\N	\N
8426	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6425	\N	\N	\N
8427	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6426	\N	\N	\N
8428	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6427	\N	\N	\N
8429	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6428	\N	\N	\N
8430	DELEGUEDEL	2020-10-20 00:00:00	2021-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	6429	\N	\N	\N
8431	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6430	\N	\N	\N
8432	DELEGUEDEL	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6431	\N	\N	\N
8433	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6432	\N	\N	\N
8434	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6433	\N	\N	\N
8435	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6434	\N	\N	\N
8436	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6435	\N	\N	\N
8437	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6436	\N	\N	\N
8438	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6437	\N	\N	\N
8439	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6438	\N	\N	\N
8440	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6439	\N	\N	\N
8441	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6440	\N	\N	\N
8442	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6441	\N	\N	\N
8443	DELEGUEDEL	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6442	\N	\N	\N
8459	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6458	\N	\N	\N
8445	DELEGUEDEL	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6444	\N	\N	\N
8446	DELEGUEDEL	2020-10-20 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6445	\N	\N	\N
8447	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6446	\N	\N	\N
8448	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6447	\N	\N	\N
8449	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6448	\N	\N	\N
8450	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6449	\N	\N	\N
8451	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6450	\N	\N	\N
8452	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6451	\N	\N	\N
8453	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6452	\N	\N	\N
8454	DELEGUEDEL	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6453	\N	\N	\N
8455	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6454	\N	\N	\N
8456	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6455	\N	\N	\N
8457	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6456	\N	\N	\N
8458	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6457	\N	\N	\N
8460	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6459	\N	\N	\N
8461	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6460	\N	\N	\N
8462	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6461	\N	\N	\N
8463	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6462	\N	\N	\N
8464	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6463	\N	\N	\N
8465	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6464	\N	\N	\N
8466	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6465	\N	\N	\N
8467	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6466	\N	\N	\N
8468	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6467	\N	\N	\N
8469	DELEGUEDEL	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6468	\N	\N	\N
8470	DELEGUEDEL	2020-10-20 00:00:00	2022-11-16 00:00:00	ANCIEN	\N	\N	\N	démissionnaire	6469	\N	\N	\N
8471	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6470	\N	\N	\N
8472	DELEGUEDEL	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6471	\N	\N	\N
8473	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6472	\N	\N	\N
8474	DELEGUEDEL	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6473	\N	\N	\N
8475	DELEGUEDEL	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6474	\N	\N	\N
8476	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6475	\N	\N	\N
8477	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6476	\N	\N	\N
8478	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6477	\N	\N	\N
8479	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6478	\N	\N	\N
8480	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6479	\N	\N	\N
8481	DELEGUEDEL	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6480	\N	\N	\N
8482	DELEGUEDEL	2020-10-20 00:00:00	2021-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	6481	\N	\N	\N
7269	DELEGUEDEL	2017-10-24 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	5688	\N	2017-10-24 11:25:41	2017-10-26 17:33:57
7529	DELEGUEDEL	2017-11-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	5848	\N	2017-12-06 00:00:00	\N
7749	DELEGUEDEL	2018-10-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6008	\N	\N	\N
7929	CHEFDEL	2019-03-05 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	5732	\N	\N	\N
7989	DELEGUEDEL	2019-03-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2952	\N	\N	\N
7114	DELEGUEDEL	2017-10-18 00:00:00	2019-03-13 00:00:00	ANCIEN	\N	\N	\N	\N	5610	\N	2017-10-18 16:18:17	\N
8010	DELEGUEDEL	2019-03-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2522	\N	\N	\N
8011	DELEGUEDEL	2019-03-26 00:00:00	2020-09-17 00:00:00	ANCIEN	\N	\N	\N	\N	6109	\N	\N	\N
8012	DELEGUEDEL	2019-03-26 00:00:00	2020-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	6110	\N	\N	\N
8089	VICPDTDEL	2019-07-19 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5576	\N	\N	\N
8189	DELEGUEDEL	2020-01-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6248	\N	\N	\N
7157	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4516	\N	2017-10-18 16:24:05	\N
5863	DELEGUEDEL	2015-02-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4703	\N	2015-02-13 15:52:28	\N
6317	DELSUPDEL	2015-10-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5036	\N	2015-10-08 14:50:13	2015-10-08 14:50:33
8484	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6483	\N	\N	\N
8487	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6486	\N	\N	\N
8488	DELEGUEDEL	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6487	\N	\N	\N
8489	DELEGUEDEL	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6488	\N	\N	\N
8490	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6489	\N	\N	\N
8491	DELEGUEDEL	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6490	\N	\N	\N
8493	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6492	\N	\N	\N
8494	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6493	\N	\N	\N
8495	DELEGUEDEL	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6494	\N	\N	\N
8496	DELEGUEDEL	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6495	\N	\N	\N
8497	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6496	\N	\N	\N
8498	DELEGUEDEL	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6497	\N	\N	\N
8499	DELEGUEDEL	2020-10-20 00:00:00	2020-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	6498	\N	\N	\N
8500	DELEGUEDEL	2020-10-20 00:00:00	2020-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	6499	\N	\N	\N
8501	DELEGUEDEL	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6500	\N	\N	\N
8502	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6501	\N	\N	\N
8503	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6502	\N	\N	\N
8504	DELEGUEDEL	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6503	\N	\N	\N
8505	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6504	\N	\N	\N
8506	DELEGUEDEL	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6505	\N	\N	\N
8507	DELEGUEDEL	2020-10-20 00:00:00	2020-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	6506	\N	\N	\N
8508	DELEGUEDEL	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6507	\N	\N	\N
8509	DELEGUEDEL	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6508	\N	\N	\N
8510	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6509	\N	\N	\N
8512	DELEGUEDEL	2020-10-20 00:00:00	2020-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	6511	\N	\N	\N
8514	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6513	\N	\N	\N
8515	DELEGUEDEL	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6514	\N	\N	\N
8516	DELEGUEDEL	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6515	\N	\N	\N
8517	DELEGUEDEL	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6516	\N	\N	\N
8518	DELEGUEDEL	2020-10-20 00:00:00	2020-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	6517	\N	\N	\N
8519	DELEGUEDEL	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6518	\N	\N	\N
8520	DELEGUEDEL	2020-10-20 00:00:00	2020-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	6519	\N	\N	\N
8522	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6521	\N	\N	\N
8524	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6523	\N	\N	\N
8525	DELEGUEDEL	2020-10-20 00:00:00	2020-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	6524	\N	\N	\N
8526	DELEGUEDEL	2020-10-20 00:00:00	2020-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	6525	\N	\N	\N
8527	DELEGUEDEL	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6526	\N	\N	\N
7195	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5649	\N	2017-10-18 16:27:13	\N
8529	DELEGUEDEL	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6528	\N	\N	\N
8530	DELEGUEDEL	2020-10-20 00:00:00	2020-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	6529	\N	\N	\N
8531	DELEGUEDEL	2020-10-20 00:00:00	2020-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	6530	\N	\N	\N
8532	DELEGUEDEL	2020-10-20 00:00:00	2020-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	6531	\N	\N	\N
8533	DELEGUEDEL	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6532	\N	\N	\N
8534	DELEGUEDEL	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6533	\N	\N	\N
8535	DELEGUEDEL	2020-10-20 00:00:00	2020-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	6534	\N	\N	\N
8536	DELEGUEDEL	2020-10-20 00:00:00	2020-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	6535	\N	\N	\N
8537	DELEGUEDEL	2020-10-20 00:00:00	2020-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	6536	\N	\N	\N
8538	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6537	\N	\N	\N
8539	DELEGUEDEL	2020-10-20 00:00:00	2020-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	6538	\N	\N	\N
8540	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6539	\N	\N	\N
8541	DELEGUEDEL	2020-10-20 00:00:00	2020-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	6540	\N	\N	\N
8542	DELEGUEDEL	2020-10-20 00:00:00	2020-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	6541	\N	\N	\N
8555	VICPDTDEL	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6440	\N	\N	\N
8549	PDTDEL	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6437	\N	\N	\N
8550	VICPDTDEL	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6472	\N	\N	\N
8551	VICPDTDEL	2020-10-22 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6438	\N	\N	\N
8552	VICPDTDEL	2020-10-22 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6456	\N	\N	\N
8554	VICPDTDEL	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6476	\N	\N	\N
8556	VICPDTDEL	2020-10-22 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6459	\N	\N	\N
8558	VICPDTDEL	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6475	\N	\N	\N
8559	VICPDTDEL	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6467	\N	\N	\N
8560	VICPDTDEL	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6470	\N	\N	\N
8561	SECRETDEL	2020-10-22 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6458	\N	\N	\N
8562	SECRETDEL	2020-10-22 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6466	\N	\N	\N
8563	SECRETDEL	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6450	\N	\N	\N
8565	PDTDEL	2020-10-22 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6369	\N	\N	\N
8566	VICPDTDEL	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6393	\N	\N	\N
8567	VICPDTDEL	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6387	\N	\N	\N
8570	VICPDTDEL	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6400	\N	\N	\N
8571	VICPDTDEL	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6396	\N	\N	\N
8572	VICPDTDEL	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6372	\N	\N	\N
8573	VICPDTDEL	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6374	\N	\N	\N
8574	VICPDTDEL	2020-10-22 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6391	\N	\N	\N
8575	VICPDTDEL	2020-10-22 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6399	\N	\N	\N
8576	VICPDTDEL	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6379	\N	\N	\N
8577	VICPDTDEL	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6386	\N	\N	\N
8578	SECRETDEL	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6367	\N	\N	\N
8579	SECRETDEL	2020-10-22 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6384	\N	\N	\N
8580	SECRETDEL	2020-10-22 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6377	\N	\N	\N
8581	PDTDEL	2020-10-22 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6351	\N	\N	\N
8582	VICPDTPRESIM	2020-10-22 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6340	\N	\N	\N
8583	VICPDTDEL	2020-10-22 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6364	\N	\N	\N
8584	VICPDTDEL	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6359	\N	\N	\N
8585	VICPDTDEL	2020-10-22 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	6332	\N	\N	\N
8586	VICPDTDEL	2020-10-22 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6350	\N	\N	\N
8587	VICPDTDEL	2020-10-22 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6344	\N	\N	\N
8588	VICPDTDEL	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6362	\N	\N	\N
8589	VICPDTDEL	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6336	\N	\N	\N
8590	VICPDTDEL	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6346	\N	\N	\N
8592	VICPDTDEL	2020-10-22 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6357	\N	\N	\N
8593	VICPDTDEL	2020-10-22 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6363	\N	\N	\N
8595	SECRETDEL	2020-10-22 00:00:00	2021-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	6331	\N	\N	\N
8596	SECRETDEL	2020-10-22 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6347	\N	\N	\N
8597	PDTDEL	2020-10-22 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6424	\N	\N	\N
8598	VICPDTDEL	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6404	\N	\N	\N
8599	VICPDTDEL	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6433	\N	\N	\N
8600	VICPDTDEL	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6405	\N	\N	\N
8601	VICPDTDEL	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6417	\N	\N	\N
8602	VICPDTDEL	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6407	\N	\N	\N
8604	VICPDTDEL	2020-10-22 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6410	\N	\N	\N
8605	VICPDTDEL	2020-10-22 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6435	\N	\N	\N
8606	VICPDTDEL	2020-10-22 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6421	\N	\N	\N
8607	VICPDTDEL	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6432	\N	\N	\N
8608	VICPDTDEL	2020-10-22 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6436	\N	\N	\N
8609	VICPDTDEL	2020-10-22 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6428	\N	\N	\N
8610	SECRETDEL	2020-10-22 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6420	\N	\N	\N
8611	SECRETDEL	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6411	\N	\N	\N
8612	SECRETDEL	2020-10-22 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6412	\N	\N	\N
8614	VICPDTDEL	2020-10-22 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6486	\N	\N	\N
8615	VICPDTDEL	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6492	\N	\N	\N
8616	VICPDTDEL	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6489	\N	\N	\N
8617	DELEGUEDEL	2020-10-01 00:00:00	2022-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	5488	\N	\N	\N
8624	DELEGUEDEL	2020-10-01 00:00:00	2022-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	4895	\N	\N	\N
7649	SECRETDEL	2018-06-22 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5676	\N	\N	\N
7650	DELEGUEDEL	2018-06-22 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5665	\N	\N	\N
7750	DELEGUEDEL	2018-10-10 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	6009	\N	\N	\N
7789	DELEGUEDEL	2018-10-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4251	\N	\N	\N
8209	DELEGUEDEL	2020-01-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6249	\N	\N	\N
8309	DELEGUEDEL	2020-09-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	6308	\N	\N	\N
7100	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5604	\N	2017-10-18 16:13:44	\N
7156	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4336	\N	2017-10-18 16:24:04	\N
7187	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5647	\N	2017-10-18 16:26:37	\N
7256	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4390	\N	2017-10-18 16:34:46	\N
7136	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4501	\N	2017-10-18 16:21:19	\N
7152	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4521	\N	2017-10-18 16:23:27	\N
7330	SECRETDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5619	\N	2017-10-26 17:32:37	\N
7232	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5669	\N	2017-10-18 16:31:12	\N
7496	DELEGUEDEL	2017-11-21 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5831	\N	2017-11-28 10:09:01	\N
8649	DELEGUEDEL	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	6568	\N	\N	\N
8650	DELEGUEDEL	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	6569	\N	\N	\N
8651	DELEGUEDEL	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6570	\N	\N	\N
8652	DELEGUEDEL	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6571	\N	\N	\N
8653	DELEGUEDEL	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6572	\N	\N	\N
8654	DELEGUEDEL	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6573	\N	\N	\N
8655	DELEGUEDEL	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6574	\N	\N	\N
8656	DELEGUEDEL	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	6575	\N	\N	\N
8657	DELEGUEDEL	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6576	\N	\N	\N
8658	DELEGUEDEL	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	6577	\N	\N	\N
8659	DELEGUEDEL	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	6578	\N	\N	\N
8660	DELEGUEDEL	2020-10-28 00:00:00	2023-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	6579	\N	\N	\N
8661	DELEGUEDEL	2020-10-28 00:00:00	2021-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	6580	\N	\N	\N
8662	DELEGUEDEL	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6581	\N	\N	\N
8663	DELEGUEDEL	2020-10-28 00:00:00	2023-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	6582	\N	\N	\N
8664	DELEGUEDEL	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	6583	\N	\N	\N
8665	DELEGUEDEL	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	6584	\N	\N	\N
8666	DELEGUEDEL	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6585	\N	\N	\N
8667	DELEGUEDEL	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6586	\N	\N	\N
8668	DELEGUEDEL	2020-10-28 00:00:00	2023-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	6587	\N	\N	\N
8669	DELEGUEDEL	2020-10-28 00:00:00	2023-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	6588	\N	\N	\N
8670	DELEGUEDEL	2020-10-28 00:00:00	2023-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	6589	\N	\N	\N
8671	DELEGUEDEL	2020-10-28 00:00:00	2023-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	6590	\N	\N	\N
8672	DELEGUEDEL	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6591	\N	\N	\N
8673	DELEGUEDEL	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	6592	\N	\N	\N
8674	DELEGUEDEL	2020-10-28 00:00:00	2023-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	6593	\N	\N	\N
8675	DELEGUEDEL	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	6594	\N	\N	\N
8676	DELEGUEDEL	2020-10-28 00:00:00	2023-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	6595	\N	\N	\N
8677	DELEGUEDEL	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6596	\N	\N	\N
8678	DELEGUEDEL	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	6597	\N	\N	\N
8679	DELEGUEDEL	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6598	\N	\N	\N
8680	DELEGUEDEL	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6599	\N	\N	\N
8681	DELEGUEDEL	2020-10-28 00:00:00	2023-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	6600	\N	\N	\N
8682	DELEGUEDEL	2020-10-28 00:00:00	2023-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	6601	\N	\N	\N
8684	DELTITDEL	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6603	\N	\N	\N
8685	DELTITDEL	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	6604	\N	\N	\N
8686	DELTITDEL	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	5712	\N	\N	\N
8687	DELSUPDEL	2020-10-28 00:00:00	2024-02-26 00:00:00	ANCIEN	\N	\N	\N	\N	6605	\N	\N	\N
8688	DELSUPDEL	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	6606	\N	\N	\N
8689	DELSUPDEL	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	6607	\N	\N	\N
8690	DELSUPDEL	2020-10-28 00:00:00	2024-02-27 00:00:00	ANCIEN	\N	\N	\N	\N	6608	\N	\N	\N
8691	DELTITDEL	2020-10-28 00:00:00	2020-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	6609	\N	\N	\N
8692	CHEFDEL	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	5732	\N	\N	\N
8693	DELTITDEL	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	6610	\N	\N	\N
8694	DELSUPDEL	2020-10-28 00:00:00	2023-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	6611	\N	\N	\N
8695	DELTITDEL	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6612	\N	\N	\N
8696	DELTITDEL	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6613	\N	\N	\N
8697	DELTITDEL	2020-10-28 00:00:00	2024-02-26 00:00:00	ANCIEN	\N	\N	\N	\N	5737	\N	\N	\N
8698	DELTITDEL	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	5738	\N	\N	\N
8699	DELTITDEL	2020-10-28 00:00:00	2020-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	6614	\N	\N	\N
6009	DELEGUEDEL	2015-02-27 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	3909	\N	2015-02-27 10:26:14	\N
8700	DELEGUEDEL	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	6615	\N	\N	\N
8701	DELEGUEDEL	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	6616	\N	\N	\N
8702	DELEGUEDEL	2020-10-28 00:00:00	2022-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6617	\N	\N	\N
8703	DELEGUEDEL	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6618	\N	\N	\N
8704	DELEGUEDEL	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	6619	\N	\N	\N
8705	DELEGUEDEL	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	6620	\N	\N	\N
8709	DELEGUEDEL	2020-11-05 00:00:00	2022-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	6628	\N	\N	\N
8710	DELEGUEDEL	2020-11-05 00:00:00	2021-07-01 00:00:00	ANCIEN	\N	\N	\N	\N	6629	\N	\N	\N
8711	DELEGUEDEL	2020-11-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	6630	\N	\N	\N
8729	PDTDEL	2020-12-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6536	1	\N	\N
8713	VICPDTPREDEL	2020-11-05 00:00:00	2021-07-01 00:00:00	ANCIEN	\N	\N	\N	\N	5128	\N	\N	\N
8714	PDTDEL	2020-11-05 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	6632	\N	\N	\N
8715	DELEGUEDEL	2020-11-05 00:00:00	2022-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	6633	\N	\N	\N
8716	DELEGUEDEL	2020-11-05 00:00:00	2022-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	6634	\N	\N	\N
8730	VICPDTDEL	2020-12-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6525	2	\N	\N
8731	VICPDTDEL	2020-12-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6499	3	\N	\N
8732	VICPDTDEL	2020-12-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6529	4	\N	\N
8733	VICPDTDEL	2020-12-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6540	5	\N	\N
8734	VICPDTDEL	2020-12-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6498	6	\N	\N
8735	VICPDTDEL	2020-12-03 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6534	7	\N	\N
8736	VICPDTDEL	2020-12-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6517	8	\N	\N
8737	VICPDTDEL	2020-12-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6530	9	\N	\N
8738	VICPDTDEL	2020-12-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6531	10	\N	\N
8739	VICPDTDEL	2020-12-03 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6535	11	\N	\N
8740	VICPDTDEL	2020-12-03 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6538	12	\N	\N
8741	VICPDTDEL	2020-12-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6519	13	\N	\N
8742	SECRETDEL	2020-12-03 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6506	14	\N	\N
8743	SECRETDEL	2020-12-03 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6511	15	\N	\N
8744	SECRETDEL	2020-12-03 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6524	16	\N	\N
8745	SECRETDEL	2020-12-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6541	17	\N	\N
8749	DELEGUEDEL	2020-12-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6648	\N	\N	\N
8750	DELEGUEDEL	2020-12-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	6649	\N	\N	\N
8751	DELEGUEDEL	2020-12-11 00:00:00	2023-12-26 00:00:00	ANCIEN	\N	\N	\N	\N	6650	\N	\N	\N
8752	DELEGUEDEL	2020-12-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6651	\N	\N	\N
8753	DELEGUEDEL	2020-12-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	6652	\N	\N	\N
8754	DELEGUEDEL	2020-12-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	6653	\N	\N	\N
8755	DELEGUEDEL	2020-12-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	6654	\N	\N	\N
8756	DELEGUEDEL	2020-12-11 00:00:00	2023-12-26 00:00:00	ANCIEN	\N	\N	\N	\N	6655	\N	\N	\N
8757	DELEGUEDEL	2020-12-11 00:00:00	2023-12-26 00:00:00	ANCIEN	\N	\N	\N	\N	6656	\N	\N	\N
8758	DELEGUEDEL	2020-12-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6657	\N	\N	\N
8759	DELEGUEDEL	2020-12-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6658	\N	\N	\N
8773	DELEGUEDEL	2020-12-11 00:00:00	2021-06-22 00:00:00	ANCIEN	\N	\N	\N	\N	4764	\N	\N	\N
8761	DELEGUEDEL	2020-12-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	6660	\N	\N	\N
8762	DELEGUEDEL	2020-12-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6661	\N	\N	\N
8763	DELEGUEDEL	2020-12-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6662	\N	\N	\N
8764	DELEGUEDEL	2020-12-11 00:00:00	2023-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	6663	\N	\N	\N
8765	DELEGUEDEL	2020-12-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6664	\N	\N	\N
8766	DELEGUEDEL	2020-12-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6665	\N	\N	\N
8774	DELEGUEDEL	2020-12-11 00:00:00	2020-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	6672	\N	\N	\N
8768	DELEGUEDEL	2020-12-11 00:00:00	2023-12-26 00:00:00	ANCIEN	\N	\N	\N	\N	6667	\N	\N	\N
8769	DELEGUEDEL	2020-12-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	6668	\N	\N	\N
8770	DELEGUEDEL	2020-12-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6669	\N	\N	\N
8771	DELEGUEDEL	2020-12-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6670	\N	\N	\N
8772	DELEGUEDEL	2020-12-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6671	\N	\N	\N
7049	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5568	\N	2017-10-18 15:57:06	\N
7053	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5572	\N	2017-10-18 15:58:04	\N
7051	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5570	\N	2017-10-18 15:57:37	\N
7052	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5571	\N	2017-10-18 15:57:50	\N
7054	DELEGUEDEL	2017-10-18 00:00:00	2020-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	5573	\N	2017-10-18 15:58:36	\N
7055	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5574	\N	2017-10-18 15:58:51	\N
7056	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5575	\N	2017-10-18 15:59:03	\N
7057	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	4274	\N	2017-10-18 15:59:15	2017-10-26 17:24:58
7058	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	3067	\N	2017-10-18 15:59:29	2017-10-26 17:26:15
7059	DELEGUEDEL	2017-10-18 00:00:00	2019-07-18 00:00:00	ANCIEN	\N	\N	\N	\N	5576	\N	2017-10-18 15:59:48	\N
7060	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	3061	\N	2017-10-18 16:00:02	2017-10-26 17:27:10
7061	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	5577	\N	2017-10-18 16:00:29	2017-10-26 17:26:29
7062	DELEGUEDEL	2017-10-18 00:00:00	2020-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	5578	\N	2017-10-18 16:00:45	\N
9664	DELEGUEDEL	2023-10-18 00:00:00	2023-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	7170	\N	\N	\N
7063	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5579	\N	2017-10-18 16:00:56	\N
7064	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	5580	\N	2017-10-18 16:01:10	2017-10-26 17:26:37
7065	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5581	\N	2017-10-18 16:01:24	\N
7066	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5582	\N	2017-10-18 16:01:49	\N
7068	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5583	\N	2017-10-18 16:02:52	\N
7069	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	3060	\N	2017-10-18 16:03:13	2017-10-26 17:26:21
7070	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	4286	\N	2017-10-18 16:03:29	2017-10-26 17:27:27
7072	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	3510	\N	2017-10-18 16:03:59	2017-10-26 17:26:42
7074	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	5585	\N	2017-10-18 16:04:40	2017-10-26 17:26:57
7075	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5586	\N	2017-10-18 16:04:58	\N
7076	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5587	\N	2017-10-18 16:05:23	\N
7077	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	5588	\N	2017-10-18 16:05:40	2017-10-26 17:26:47
7078	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	5589	\N	2017-10-18 16:05:57	2017-10-26 17:25:13
7079	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5590	\N	2017-10-18 16:06:34	\N
7080	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5591	\N	2017-10-18 16:06:58	\N
7081	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	5592	\N	2017-10-18 16:07:32	2017-10-26 17:25:45
7082	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	4296	\N	2017-10-18 16:07:46	2017-10-26 17:25:35
7083	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3488	\N	2017-10-18 16:08:03	\N
7084	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	3496	\N	2017-10-18 16:08:22	2017-10-26 17:25:55
7085	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5593	\N	2017-10-18 16:08:42	\N
7086	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5594	\N	2017-10-18 16:10:37	\N
7087	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5595	\N	2017-10-18 16:10:50	\N
7088	DELEGUEDEL	2017-10-18 00:00:00	2017-10-23 00:00:00	ANCIEN	\N	\N	\N	\N	5596	\N	2017-10-18 16:11:00	2017-10-24 11:24:44
7089	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5597	\N	2017-10-18 16:11:11	\N
7090	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2951	\N	2017-10-18 16:11:25	\N
7091	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5598	\N	2017-10-18 16:11:37	\N
7093	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	5600	\N	2017-10-18 16:12:02	2017-10-26 17:34:14
7094	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4230	\N	2017-10-18 16:12:11	\N
7095	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5601	\N	2017-10-18 16:12:26	\N
7096	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5602	\N	2017-10-18 16:12:50	\N
7097	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	3505	\N	2017-10-18 16:13:04	2017-10-26 17:34:18
7098	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	4238	\N	2017-10-18 16:13:14	2017-10-26 17:34:29
7099	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5603	\N	2017-10-18 16:13:25	\N
7101	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	3248	\N	2017-10-18 16:13:57	2017-10-26 17:35:25
7102	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	2952	\N	2017-10-18 16:14:19	2017-10-26 17:34:02
7104	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5605	\N	2017-10-18 16:14:58	\N
7105	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5606	\N	2017-10-18 16:15:11	\N
7106	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	4250	\N	2017-10-18 16:15:24	2017-10-26 17:34:36
7107	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4253	\N	2017-10-18 16:15:37	\N
7108	DELEGUEDEL	2017-10-18 00:00:00	2018-11-07 00:00:00	ANCIEN	\N	\N	\N	\N	3988	\N	2017-10-18 16:15:57	\N
7109	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	4254	\N	2017-10-18 16:16:08	2017-10-26 17:33:51
7110	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	5607	\N	2017-10-18 16:16:20	2017-10-26 17:35:41
7111	DELEGUEDEL	2017-10-18 00:00:00	2018-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	5608	\N	2017-10-18 16:16:35	2018-02-06 18:53:04
7112	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5609	\N	2017-10-18 16:16:51	\N
7113	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	873	\N	2017-10-18 16:17:30	\N
7115	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	5611	\N	2017-10-18 16:18:30	2017-10-26 17:35:08
7116	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	2958	\N	2017-10-18 16:19:02	2017-10-26 17:34:24
7117	DELEGUEDEL	2017-10-18 00:00:00	2019-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	5612	\N	2017-10-18 16:19:15	\N
7118	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	3491	\N	2017-10-18 16:19:30	2017-10-26 17:34:08
7119	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5613	\N	2017-10-18 16:19:31	\N
7120	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	4488	\N	2017-10-18 16:19:38	2017-10-26 17:31:14
7121	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5614	\N	2017-10-18 16:19:44	\N
7122	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5615	\N	2017-10-18 16:19:49	\N
7123	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5616	\N	2017-10-18 16:19:50	\N
7124	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4490	\N	2017-10-18 16:19:55	\N
7125	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4493	\N	2017-10-18 16:20:00	\N
7126	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	5617	\N	2017-10-18 16:20:03	2017-10-26 17:34:59
7127	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5618	\N	2017-10-18 16:20:05	\N
7129	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	5619	\N	2017-10-18 16:20:15	2017-10-26 17:32:37
7130	DELEGUEDEL	2017-10-18 00:00:00	2018-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	5620	\N	2017-10-18 16:20:17	2018-02-01 20:26:59
7131	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4499	\N	2017-10-18 16:20:21	\N
7132	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	4500	\N	2017-10-18 16:20:26	2017-10-26 17:31:03
7133	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5621	\N	2017-10-18 16:20:46	\N
7134	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5622	\N	2017-10-18 16:20:58	\N
7135	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	4648	\N	2017-10-18 16:21:13	2017-10-26 17:31:54
7137	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5623	\N	2017-10-18 16:21:25	\N
7138	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	5624	\N	2017-10-18 16:21:46	2017-10-26 17:32:44
7139	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	4504	\N	2017-10-18 16:21:53	2017-10-26 17:32:12
7140	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	5625	\N	2017-10-18 16:22:02	2017-10-26 17:32:27
7142	DELEGUEDEL	2017-10-18 00:00:00	2020-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	4509	\N	2017-10-18 16:22:07	\N
7143	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4512	\N	2017-10-18 16:22:15	\N
7144	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	5626	\N	2017-10-18 16:22:23	2017-10-26 17:31:43
7145	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4515	\N	2017-10-18 16:22:43	\N
7146	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5627	\N	2017-10-18 16:22:53	\N
7147	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	5628	\N	2017-10-18 16:22:58	2017-10-26 17:32:04
7148	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5629	\N	2017-10-18 16:23:04	\N
7149	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5630	\N	2017-10-18 16:23:09	\N
7150	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4519	\N	2017-10-18 16:23:15	\N
7151	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	4520	\N	2017-10-18 16:23:19	2017-10-26 17:31:19
7153	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	5631	\N	2017-10-18 16:23:35	2017-10-26 17:32:33
7154	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5632	\N	2017-10-18 16:23:42	\N
7155	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5368	\N	2017-10-18 16:23:58	\N
7158	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	5633	\N	2017-10-18 16:24:11	2017-10-26 17:32:17
7159	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5634	\N	2017-10-18 16:24:14	\N
7160	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4526	\N	2017-10-18 16:24:25	\N
7161	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4988	\N	2017-10-18 16:24:26	\N
7162	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4522	\N	2017-10-18 16:24:33	\N
7163	DELEGUEDEL	2017-10-18 00:00:00	2017-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	5635	\N	2017-10-18 16:24:36	2017-11-09 14:27:26
7164	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	5636	\N	2017-10-18 16:24:41	2017-10-26 17:31:46
7165	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4341	\N	2017-10-18 16:24:47	\N
7166	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4529	\N	2017-10-18 16:24:52	\N
7167	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5637	\N	2017-10-18 16:24:58	\N
7168	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5638	\N	2017-10-18 16:25:04	\N
7169	DELEGUEDEL	2017-10-18 00:00:00	2017-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	4343	\N	2017-10-18 16:25:08	2017-11-09 14:26:48
7170	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	5639	\N	2017-10-18 16:25:11	2017-10-26 17:31:38
7171	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	5640	\N	2017-10-18 16:25:16	2017-10-26 17:31:26
7172	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3559	\N	2017-10-18 16:25:25	\N
7173	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5641	\N	2017-10-18 16:25:37	\N
7174	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	5408	\N	2017-10-18 16:25:50	2017-10-26 17:30:00
7175	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5642	\N	2017-10-18 16:25:53	\N
7176	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4299	\N	2017-10-18 16:25:56	\N
7177	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4301	\N	2017-10-18 16:26:01	\N
7178	DELEGUEDEL	2017-10-18 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4344	\N	2017-10-18 16:26:03	\N
7179	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	5643	\N	2017-10-18 16:26:08	2017-10-26 17:28:44
7180	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5644	\N	2017-10-18 16:26:14	\N
7181	DELEGUEDEL	2017-10-18 00:00:00	2020-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	5645	\N	2017-10-18 16:26:14	\N
7182	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	4303	\N	2017-10-18 16:26:18	2017-10-26 17:29:19
7183	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5646	\N	2017-10-18 16:26:24	\N
7184	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	4304	\N	2017-10-18 16:26:24	2017-10-26 17:29:25
7185	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4305	\N	2017-10-18 16:26:30	\N
7186	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	4306	\N	2017-10-18 16:26:36	2017-10-26 17:29:30
7188	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4307	\N	2017-10-18 16:26:42	\N
7189	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4308	\N	2017-10-18 16:26:49	\N
7190	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4309	\N	2017-10-18 16:26:54	\N
7191	DELEGUEDEL	2017-10-18 00:00:00	2018-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	5648	\N	2017-10-18 16:26:57	\N
7192	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4311	\N	2017-10-18 16:26:59	\N
7193	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4312	\N	2017-10-18 16:27:04	\N
7194	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4313	\N	2017-10-18 16:27:09	\N
7196	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4346	\N	2017-10-18 16:27:16	\N
7197	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	4315	\N	2017-10-18 16:27:18	2017-10-26 17:29:10
7198	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5650	\N	2017-10-18 16:27:23	\N
9674	DELEGUEDEL	2023-10-18 00:00:00	2023-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	7163	\N	\N	\N
7199	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5651	\N	2017-10-18 16:27:29	\N
7200	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5652	\N	2017-10-18 16:27:32	\N
7201	DELEGUEDEL	2017-10-18 00:00:00	2020-04-15 00:00:00	ANCIEN	\N	\N	\N	\N	5653	\N	2017-10-18 16:27:33	\N
7202	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	4320	\N	2017-10-18 16:27:37	2017-10-26 17:30:10
7203	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5654	\N	2017-10-18 16:27:42	\N
7204	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	4321	\N	2017-10-18 16:27:47	2017-10-26 17:29:40
7205	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3889	\N	2017-10-18 16:27:51	\N
7206	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	4326	\N	2017-10-18 16:27:52	2017-10-26 17:28:37
7207	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	5008	\N	2017-10-18 16:27:58	2017-10-26 17:30:04
7208	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4327	\N	2017-10-18 16:28:04	\N
7209	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5655	\N	2017-10-18 16:28:08	\N
7210	DELEGUEDEL	2017-10-18 00:00:00	2017-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	4371	\N	2017-10-18 16:28:14	2017-11-09 14:26:40
7211	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5656	\N	2017-10-18 16:28:15	\N
7212	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	3541	\N	2017-10-18 16:28:25	2017-10-26 17:29:44
7213	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4323	\N	2017-10-18 16:28:31	\N
7214	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5657	\N	2017-10-18 16:28:34	\N
7215	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	5468	\N	2017-10-18 16:28:36	2017-10-26 17:29:02
7216	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5658	\N	2017-10-18 16:28:42	\N
7217	DELEGUEDEL	2017-10-18 00:00:00	2017-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	5659	\N	2017-10-18 16:28:47	2017-11-09 14:26:07
7218	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5660	\N	2017-10-18 16:28:47	\N
7219	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	5661	\N	2017-10-18 16:28:53	2017-10-26 17:29:50
7220	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	5662	\N	2017-10-18 16:28:58	2017-10-26 17:28:56
7221	DELEGUEDEL	2017-10-18 00:00:00	2017-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	3564	\N	2017-10-18 16:29:01	2017-11-09 14:25:44
7222	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3537	\N	2017-10-18 16:29:02	\N
7223	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4377	\N	2017-10-18 16:30:00	\N
7224	DELEGUEDEL	2017-10-18 00:00:00	2017-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	5663	\N	2017-10-18 16:30:21	2017-11-09 14:25:57
7225	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5664	\N	2017-10-18 16:30:45	\N
7226	DELEGUEDEL	2017-10-18 00:00:00	2018-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	3474	\N	2017-10-18 16:30:49	\N
7227	DELEGUEDEL	2017-10-18 00:00:00	2017-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	5665	\N	2017-10-18 16:30:52	2017-11-09 14:27:19
7228	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5666	\N	2017-10-18 16:30:55	\N
7229	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5667	\N	2017-10-18 16:31:00	\N
7230	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5668	\N	2017-10-18 16:31:03	\N
7231	DELEGUEDEL	2017-10-18 00:00:00	2017-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	4412	\N	2017-10-18 16:31:06	2017-11-09 17:40:30
7233	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5670	\N	2017-10-18 16:31:16	\N
7234	DELEGUEDEL	2017-10-18 00:00:00	2017-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	1165	\N	2017-10-18 16:31:17	2017-11-09 17:41:21
7235	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1166	\N	2017-10-18 16:31:21	\N
7236	DELEGUEDEL	2017-10-18 00:00:00	2017-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	4417	\N	2017-10-18 16:31:26	2017-11-09 17:40:51
7237	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5671	\N	2017-10-18 16:31:32	\N
7238	DELEGUEDEL	2017-10-18 00:00:00	2017-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	4383	\N	2017-10-18 16:31:33	2017-11-09 14:26:16
7239	DELEGUEDEL	2017-10-18 00:00:00	2017-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	5269	\N	2017-10-18 16:31:39	2017-11-28 15:53:47
7240	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5672	\N	2017-10-18 16:31:48	\N
7241	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5673	\N	2017-10-18 16:31:54	\N
7242	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5674	\N	2017-10-18 16:31:55	\N
7243	DELEGUEDEL	2017-10-18 00:00:00	2017-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	4422	\N	2017-10-18 16:32:00	2017-11-09 17:41:10
7244	DELEGUEDEL	2017-10-18 00:00:00	2020-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	5675	\N	2017-10-18 16:32:07	\N
7245	DELEGUEDEL	2017-10-18 00:00:00	2018-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	5676	\N	2017-10-18 16:32:10	\N
7246	DELEGUEDEL	2017-10-18 00:00:00	2017-11-15 00:00:00	ANCIEN	\N	\N	\N	\N	5677	\N	2017-10-18 16:32:14	2017-11-16 16:21:16
7247	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5678	\N	2017-10-18 16:32:21	\N
7349	DELTITDEL	2017-11-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5708	\N	2017-11-07 18:29:29	2017-11-07 18:29:33
7249	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5679	\N	2017-10-18 16:32:31	\N
7250	DELEGUEDEL	2017-10-18 00:00:00	2017-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	5680	\N	2017-10-18 16:32:35	2017-11-09 14:26:25
7251	DELEGUEDEL	2017-10-18 00:00:00	2017-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	3576	\N	2017-10-18 16:32:52	2017-11-09 14:26:33
7252	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4848	\N	2017-10-18 16:33:37	\N
7253	DELEGUEDEL	2017-10-18 00:00:00	2017-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	5681	\N	2017-10-18 16:33:53	2017-11-09 14:26:54
7254	DELEGUEDEL	2017-10-18 00:00:00	2017-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	4389	\N	2017-10-18 16:34:11	2017-11-09 14:25:30
7255	DELEGUEDEL	2017-10-18 00:00:00	2017-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	5682	\N	2017-10-18 16:34:30	2017-11-09 14:27:37
7257	DELEGUEDEL	2017-10-18 00:00:00	2020-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	4392	\N	2017-10-18 16:35:07	\N
7258	DELEGUEDEL	2017-10-18 00:00:00	2017-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	5683	\N	2017-10-18 16:35:24	2017-11-09 14:27:47
7259	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4849	\N	2017-10-18 16:35:36	\N
7260	DELEGUEDEL	2017-10-18 00:00:00	2017-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	5684	\N	2017-10-18 16:35:51	2017-11-09 14:27:09
7350	DELSUPDEL	2017-11-07 00:00:00	2018-06-24 00:00:00	ANCIEN	\N	\N	\N	\N	5709	\N	2017-11-07 18:30:08	2017-11-07 18:30:14
7262	DELEGUEDEL	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4386	\N	2017-10-18 16:40:23	\N
5195	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	2958	\N	2014-10-29 11:08:51	2017-10-18 17:45:05
7351	DELSUPDEL	2017-11-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	5710	\N	2017-11-07 00:00:00	2017-11-07 00:00:00
5213	DELEGUEDEL	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	4232	\N	2014-10-29 12:15:50	2017-10-17 09:39:27
7289	PDTDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4274	\N	2017-10-26 17:24:58	\N
7290	VICPDTDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5589	\N	2017-10-26 17:25:13	\N
7291	VICPDTDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4296	\N	2017-10-26 17:25:35	\N
7292	VICPDTDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5592	\N	2017-10-26 17:25:45	\N
7293	VICPDTDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3496	\N	2017-10-26 17:25:55	\N
7294	VICPDTDEL	2017-10-26 00:00:00	2019-06-23 00:00:00	ANCIEN	\N	\N	\N	\N	3067	\N	2017-10-26 17:26:15	\N
7295	VICPDTDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3060	\N	2017-10-26 17:26:21	\N
7296	VICPDTDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5577	\N	2017-10-26 17:26:29	\N
7297	VICPDTDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5580	\N	2017-10-26 17:26:37	\N
7298	VICPDTDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3510	\N	2017-10-26 17:26:42	\N
7299	VICPDTDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5588	\N	2017-10-26 17:26:47	\N
7300	SECRETDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5585	\N	2017-10-26 17:26:57	\N
7301	SECRETDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3061	\N	2017-10-26 17:27:10	\N
7302	SECRETDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4286	\N	2017-10-26 17:27:27	\N
7303	PDTDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4326	\N	2017-10-26 17:28:37	\N
7304	VICPDTPRESIM	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5643	\N	2017-10-26 17:28:44	\N
7305	VICPDTDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5662	\N	2017-10-26 17:28:56	\N
7306	VICPDTDEL	2017-10-26 00:00:00	2018-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	5468	\N	2017-10-26 17:29:02	\N
7307	VICPDTDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4315	\N	2017-10-26 17:29:10	\N
7308	VICPDTDEL	2017-10-26 00:00:00	2020-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	4303	\N	2017-10-26 17:29:19	\N
7309	VICPDTDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4304	\N	2017-10-26 17:29:25	\N
7310	VICPDTDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4306	\N	2017-10-26 17:29:30	\N
7311	VICPDTDEL	2017-10-26 00:00:00	2019-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	4321	\N	2017-10-26 17:29:40	\N
7312	VICPDTDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3541	\N	2017-10-26 17:29:44	\N
7313	VICPDTDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5661	\N	2017-10-26 17:29:50	\N
7314	SECRETDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5408	\N	2017-10-26 17:30:00	\N
7315	SECRETDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5008	\N	2017-10-26 17:30:04	\N
7316	SECRETDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4320	\N	2017-10-26 17:30:10	\N
7317	PDTDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4500	\N	2017-10-26 17:31:02	\N
7318	VICPDTDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4488	\N	2017-10-26 17:31:14	\N
7319	VICPDTDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4520	\N	2017-10-26 17:31:19	\N
7320	VICPDTDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5640	\N	2017-10-26 17:31:26	\N
7321	VICPDTDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5639	\N	2017-10-26 17:31:38	\N
7322	VICPDTDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5626	\N	2017-10-26 17:31:43	\N
7323	VICPDTDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5636	\N	2017-10-26 17:31:46	\N
7324	VICPDTDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4648	\N	2017-10-26 17:31:53	\N
7325	VICPDTDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5628	\N	2017-10-26 17:32:04	\N
7326	VICPDTDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4504	\N	2017-10-26 17:32:12	\N
7327	VICPDTDEL	2017-10-26 00:00:00	2018-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	5633	\N	2017-10-26 17:32:17	\N
7328	SECRETDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5625	\N	2017-10-26 17:32:27	\N
7329	SECRETDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5631	\N	2017-10-26 17:32:33	\N
7331	SECRETDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5624	\N	2017-10-26 17:32:44	\N
7332	PDTDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4254	\N	2017-10-26 17:33:51	\N
7333	VICPDTDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5688	\N	2017-10-26 17:33:57	\N
7334	VICPDTDEL	2017-10-26 00:00:00	2018-10-16 00:00:00	ANCIEN	\N	\N	\N	\N	2952	\N	2017-10-26 17:34:02	\N
7335	VICPDTDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3491	\N	2017-10-26 17:34:08	\N
7336	VICPDTDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5600	\N	2017-10-26 17:34:14	\N
7337	VICPDTDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3505	\N	2017-10-26 17:34:18	\N
7338	VICPDTDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2958	\N	2017-10-26 17:34:24	\N
7339	VICPDTDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4238	\N	2017-10-26 17:34:29	\N
7340	VICPDTDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4250	\N	2017-10-26 17:34:36	\N
7341	VICPDTDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5617	\N	2017-10-26 17:34:59	\N
7342	VICPDTDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5611	\N	2017-10-26 17:35:08	\N
7343	SECRETDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3248	\N	2017-10-26 17:35:25	\N
7344	SECRETDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5599	\N	2017-10-26 17:35:33	\N
7092	DELEGUEDEL	2017-10-18 00:00:00	2017-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	5599	\N	2017-10-18 16:11:50	2017-10-26 17:35:33
7345	SECRETDEL	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5607	\N	2017-10-26 17:35:41	\N
7352	DELSUPDEL	2017-11-07 00:00:00	2018-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	5711	\N	2017-11-07 18:30:42	2017-11-07 18:30:45
7353	DELSUPDEL	2017-11-07 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	5712	\N	2017-11-07 18:31:06	2017-11-07 18:31:09
7355	PDTDEL	2017-11-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4389	\N	2017-11-09 14:25:30	\N
7356	VICPDTDEL	2017-11-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3564	\N	2017-11-09 14:25:44	\N
7357	VICPDTDEL	2017-11-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5663	\N	2017-11-09 14:25:57	\N
7358	VICPDTDEL	2017-11-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5659	\N	2017-11-09 14:26:07	\N
7359	VICPDTDEL	2017-11-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4383	\N	2017-11-09 14:26:16	\N
7360	VICPDTDEL	2017-11-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5680	\N	2017-11-09 14:26:25	\N
7361	VICPDTDEL	2017-11-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3576	\N	2017-11-09 14:26:33	\N
7362	VICPDTDEL	2017-11-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4371	\N	2017-11-09 14:26:40	\N
7363	VICPDTDEL	2017-11-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4343	\N	2017-11-09 14:26:48	\N
7364	VICPDTDEL	2017-11-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5681	\N	2017-11-09 14:26:54	\N
7365	VICPDTDEL	2017-11-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5684	\N	2017-11-09 14:27:09	\N
7366	SECRETDEL	2017-11-09 00:00:00	2018-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	5665	\N	2017-11-09 14:27:19	\N
7367	SECRETDEL	2017-11-09 00:00:00	2020-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	5635	\N	2017-11-09 14:27:26	\N
7368	SECRETDEL	2017-11-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5682	\N	2017-11-09 14:27:37	\N
7369	SECRETDEL	2017-11-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5683	\N	2017-11-09 14:27:47	\N
5753	DELEGUEDEL	2014-11-04 00:00:00	2017-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	4632	\N	2015-01-12 19:01:18	2017-11-09 14:47:40
7370	DELEGUEDEL	2017-11-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4635	\N	2017-11-09 14:47:57	\N
5790	VICPDTDEL	2014-11-05 00:00:00	2017-11-07 00:00:00	ANCIEN	\N	\N	\N	\N	4635	\N	2015-01-13 16:17:44	2017-11-09 14:47:57
7371	DELEGUEDEL	2017-11-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5714	\N	2017-11-09 14:48:12	\N
7372	VICPDTDEL	2017-11-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5715	\N	2017-11-09 14:48:19	2017-11-09 14:48:23
7374	DELEGUEDEL	2017-11-09 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	5717	\N	2017-11-09 00:00:00	\N
7375	DELEGUEDEL	2017-11-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5718	\N	2017-11-09 14:48:43	\N
7376	DELEGUEDEL	2017-11-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5719	\N	2017-11-09 15:24:49	\N
7449	DELEGUEDEL	2017-11-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5788	\N	2017-11-16 16:21:36	\N
5715	VICPDTDEL	2014-12-10 00:00:00	2017-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	4588	2	2014-12-10 16:24:51	2017-11-28 10:07:56
5720	DELEGUEDEL	2014-12-10 00:00:00	2017-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	2792	\N	2014-12-10 16:29:21	2017-11-28 10:08:00
7489	DELEGUEDEL	2017-11-21 00:00:00	2017-11-28 00:00:00	ANCIEN	\N	\N	\N	\N	5828	\N	2017-11-28 10:08:14	2017-11-29 18:29:03
7490	DELEGUEDEL	2017-11-21 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5829	\N	2017-11-28 10:08:21	\N
7491	DELEGUEDEL	2017-11-21 00:00:00	2017-11-28 00:00:00	ANCIEN	\N	\N	\N	\N	3629	\N	2017-11-28 10:08:26	2017-11-29 18:28:02
7492	DELEGUEDEL	2017-11-21 00:00:00	2017-11-28 00:00:00	ANCIEN	\N	\N	\N	\N	5830	\N	2017-11-28 10:08:31	2017-11-29 18:29:30
7493	DELEGUEDEL	2017-11-21 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3630	\N	2017-11-28 10:08:40	\N
7494	DELEGUEDEL	2017-11-21 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2792	\N	2017-11-28 10:08:46	\N
7495	DELEGUEDEL	2017-11-21 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3632	\N	2017-11-28 10:08:53	\N
7497	DELEGUEDEL	2017-11-21 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5832	\N	2017-11-28 10:09:07	\N
7498	DELEGUEDEL	2017-11-21 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5833	\N	2017-11-28 10:09:14	\N
7499	DELEGUEDEL	2017-11-21 00:00:00	2017-11-28 00:00:00	ANCIEN	\N	\N	\N	\N	5834	\N	2017-11-28 10:09:19	2017-11-29 18:29:12
7500	DELEGUEDEL	2017-11-21 00:00:00	2017-11-28 00:00:00	ANCIEN	\N	\N	\N	\N	5835	\N	2017-11-28 10:09:27	2017-11-29 18:28:13
7501	DELEGUEDEL	2017-11-21 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3638	\N	2017-11-28 10:09:31	2017-11-29 18:31:45
7502	DELEGUEDEL	2017-11-21 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3868	\N	2017-11-28 10:10:05	\N
7503	DELEGUEDEL	2017-11-21 00:00:00	2017-11-28 00:00:00	ANCIEN	\N	\N	\N	\N	2800	\N	2017-11-28 10:10:10	2017-11-29 18:28:18
7504	DELEGUEDEL	2017-11-21 00:00:00	2017-11-28 00:00:00	ANCIEN	\N	\N	\N	\N	5836	\N	2017-11-28 10:10:16	2017-11-29 18:29:23
7505	DELEGUEDEL	2017-11-28 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5837	\N	2017-11-28 15:53:59	\N
7506	PDTDEL	2017-11-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3629	1	2017-11-29 18:28:02	2017-11-29 18:29:42
8775	DELEGUEDEL	2020-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	6673	\N	\N	\N
6349	DELTITDEL	2015-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	5068	\N	2015-10-16 00:00:00	2015-10-16 00:00:00
7373	DELEGUEDEL	2017-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	5716	\N	2017-11-09 00:00:00	\N
8523	DELEGUEDEL	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6522	\N	\N	\N
8485	DELEGUEDEL	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6484	\N	\N	\N
9644	PDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7157	\N	\N	\N
9645	VICPDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7187	\N	\N	\N
9646	DELEGUEDEL	2023-10-18 00:00:00	2023-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	7155	\N	\N	\N
9647	VICPDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7155	\N	\N	\N
9648	DELEGUEDEL	2023-10-18 00:00:00	2023-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	7165	\N	\N	\N
9649	DELEGUEDEL	2023-10-18 00:00:00	2023-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	7167	\N	\N	\N
9650	DELEGUEDEL	2023-10-18 00:00:00	2023-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	7162	\N	\N	\N
9651	VICPDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7165	\N	\N	\N
9652	VICPDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7162	\N	\N	\N
9653	VICPDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7167	\N	\N	\N
9782	DELEGUEDEL	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	7363	\N	\N	\N
9694	VICPDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7200	\N	\N	\N
9656	DELEGUEDEL	2023-10-18 00:00:00	2023-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	7160	\N	\N	\N
9657	DELEGUEDEL	2023-10-18 00:00:00	2023-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	7149	\N	\N	\N
9658	DELEGUEDEL	2023-10-18 00:00:00	2023-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	7192	\N	\N	\N
9659	DELEGUEDEL	2023-10-18 00:00:00	2023-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	7186	\N	\N	\N
9660	DELEGUEDEL	2023-10-18 00:00:00	2023-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	7184	\N	\N	\N
9661	DELEGUEDEL	2023-10-18 00:00:00	2023-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	7180	\N	\N	\N
9662	DELEGUEDEL	2023-10-18 00:00:00	2023-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	7175	\N	\N	\N
9663	DELEGUEDEL	2023-10-18 00:00:00	2023-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	7173	\N	\N	\N
9675	SECRETDEL	2023-10-18 00:00:00	2025-03-31 00:00:00	ACTIF	\N	\N	\N	\N	7163	\N	\N	\N
9695	VICPDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7215	\N	\N	\N
9696	VICPDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7211	\N	\N	\N
9697	VICPDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7201	\N	\N	\N
9698	VICPDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7210	\N	\N	\N
9699	VICPDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7228	\N	\N	\N
9700	PDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7218	\N	\N	\N
9701	VICPDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7223	\N	\N	\N
9702	VICPDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7196	\N	\N	\N
9703	VICPDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7204	\N	\N	\N
9704	VICPDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7226	\N	\N	\N
9705	VICPDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7221	\N	\N	\N
9706	SECRETDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7193	\N	\N	\N
9707	VICPDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7220	\N	\N	\N
9708	SECRETDEL	2023-10-18 00:00:00	2023-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	7207	\N	\N	\N
9709	SECRETDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7194	\N	\N	\N
9710	DELEGUEDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7207	\N	\N	\N
9783	PDTDEL	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	6708	\N	\N	\N
9715	PDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7289	\N	\N	\N
9713	DELEGUEDEL	2023-10-18 00:00:00	2023-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	7335	\N	\N	\N
9714	SECRETDEL	2023-10-18 00:00:00	2025-03-31 00:00:00	ACTIF	\N	\N	\N	\N	7335	\N	\N	\N
9716	VICPDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7277	\N	\N	\N
9717	VICPDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7279	\N	\N	\N
9718	VICPDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7282	\N	\N	\N
9721	VICPDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7292	\N	\N	\N
9722	VICPDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7298	\N	\N	\N
9728	SECRETDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7281	\N	\N	\N
9729	SECRETDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7302	\N	\N	\N
9832	VICPDTDEL	2023-11-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	7371	\N	\N	\N
9833	VICPDTDEL	2023-11-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	7383	\N	\N	\N
10019	PDTEXECUTDEL	2024-02-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7562	\N	\N	\N
8829	DELEGUEDEL	2021-01-28 00:00:00	2023-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	6708	\N	\N	\N
8889	DELEGUEDEL	2021-03-03 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6768	\N	\N	\N
9170	SECRETDEL	2021-10-21 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6341	\N	\N	\N
9171	VICPDTDEL	2021-10-21 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6331	\N	\N	\N
9172	SECRETDEL	2021-10-21 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6342	\N	\N	\N
5859	DELEGUEDEL	2015-02-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	4699	\N	2015-02-13 00:00:00	\N
8511	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6510	\N	\N	\N
8521	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6520	\N	\N	\N
8553	VICPDTDEL	2020-10-22 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6439	\N	\N	\N
8557	VICPDTDEL	2020-10-22 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6478	\N	\N	\N
9724	VICPDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7309	\N	\N	\N
9731	VICPDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7312	\N	\N	\N
9750	SECRETDEL	2025-04-01 00:00:00	\N	FUTUR	\N	\N	\N	\N	7213	\N	\N	\N
9789	DELEGUEDEL	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	7368	\N	\N	\N
9790	DELEGUEDEL	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	7369	\N	\N	\N
9791	DELEGUEDEL	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	7370	\N	\N	\N
9792	DELEGUEDEL	2023-11-08 00:00:00	2023-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	7371	\N	\N	\N
9793	DELEGUEDEL	2023-11-08 00:00:00	2023-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	7372	\N	\N	\N
9794	DELEGUEDEL	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	7373	\N	\N	\N
9795	DELEGUEDEL	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	7374	\N	\N	\N
9796	DELEGUEDEL	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	7375	\N	\N	\N
9797	DELEGUEDEL	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	7376	\N	\N	\N
9798	DELEGUEDEL	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	7377	\N	\N	\N
9799	DELEGUEDEL	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	7378	\N	\N	\N
9800	DELEGUEDEL	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	7379	\N	\N	\N
9801	DELEGUEDEL	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	7380	\N	\N	\N
9802	DELEGUEDEL	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	7381	\N	\N	\N
9803	DELEGUEDEL	2023-11-08 00:00:00	2029-11-27 00:00:00	ACTIF	\N	\N	\N	\N	7382	\N	\N	\N
9804	DELEGUEDEL	2023-11-08 00:00:00	2023-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	7383	\N	\N	\N
9805	DELEGUEDEL	2023-11-08 00:00:00	2023-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	7384	\N	\N	\N
9806	DELEGUEDEL	2023-11-08 00:00:00	2023-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	7385	\N	\N	\N
9807	DELEGUEDEL	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	7386	\N	\N	\N
9808	DELEGUEDEL	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	7387	\N	\N	\N
9809	DELEGUEDEL	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	7388	\N	\N	\N
9810	DELEGUEDEL	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	7389	\N	\N	\N
9811	DELEGUEDEL	2023-11-08 00:00:00	2023-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	7390	\N	\N	\N
9812	DELEGUEDEL	2023-11-08 00:00:00	2023-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	7391	\N	\N	\N
9813	DELEGUEDEL	2023-11-08 00:00:00	2023-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	7392	\N	\N	\N
9814	DELEGUEDEL	2023-11-08 00:00:00	2023-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	7393	\N	\N	\N
9815	DELEGUEDEL	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	7394	\N	\N	\N
9816	DELEGUEDEL	2023-11-08 00:00:00	2023-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	7395	\N	\N	\N
9817	DELEGUEDEL	2023-11-08 00:00:00	2023-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	7396	\N	\N	\N
9818	DELEGUEDEL	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	7397	\N	\N	\N
9819	DELEGUEDEL	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	7398	\N	\N	\N
9820	DELEGUEDEL	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	7399	\N	\N	\N
9821	DELEGUEDEL	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	7400	\N	\N	\N
9822	DELEGUEDEL	2023-11-08 00:00:00	2023-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	7401	\N	\N	\N
9823	DELEGUEDEL	2023-11-08 00:00:00	2023-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	7402	\N	\N	\N
9824	DELEGUEDEL	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	7403	\N	\N	\N
9825	DELEGUEDEL	2023-11-08 00:00:00	2023-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	7404	\N	\N	\N
9826	DELEGUEDEL	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	7405	\N	\N	\N
9827	DELEGUEDEL	2023-11-08 00:00:00	2023-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	7406	\N	\N	\N
9828	DELEGUEDEL	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	7407	\N	\N	\N
9829	DELEGUEDEL	2023-11-08 00:00:00	2023-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	7408	\N	\N	\N
9830	DELEGUEDEL	2023-11-08 00:00:00	2023-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	7409	\N	\N	\N
9834	VICPDTDEL	2023-11-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	7384	\N	\N	\N
9839	VICPDTDEL	2023-11-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	7402	\N	\N	\N
9841	VICPDTDEL	2023-11-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	7406	\N	\N	\N
9842	VICPDTDEL	2023-11-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	7408	\N	\N	\N
9845	SECRETDEL	2023-11-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	7390	\N	\N	\N
9846	SECRETDEL	2023-11-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	7395	\N	\N	\N
9847	SECRETDEL	2023-11-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	7396	\N	\N	\N
9985	DELEGUEDEL	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	7546	\N	\N	\N
9986	DELEGUEDEL	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	7547	\N	\N	\N
9987	DELEGUEDEL	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	7548	\N	\N	\N
9988	DELEGUEDEL	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	7549	\N	\N	\N
9989	DELEGUEDEL	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	7550	\N	\N	\N
9990	DELEGUEDEL	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	7551	\N	\N	\N
9991	DELEGUEDEL	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	7552	\N	\N	\N
9992	DELEGUEDEL	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	7553	\N	\N	\N
9993	DELEGUEDEL	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	7554	\N	\N	\N
9994	DELEGUEDEL	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	7555	\N	\N	\N
9995	DELEGUEDEL	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	7556	\N	\N	\N
9996	DELEGUEDEL	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	7557	\N	\N	\N
9997	DELEGUEDEL	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	7558	\N	\N	\N
9998	DELEGUEDEL	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	7559	\N	\N	\N
9999	DELEGUEDEL	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	7560	\N	\N	\N
10000	DELEGUEDEL	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	7561	\N	\N	\N
10001	DELEGUEDEL	2023-10-26 00:00:00	2024-02-26 00:00:00	ANCIEN	\N	\N	\N	\N	7562	\N	\N	\N
10002	DELEGUEDEL	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	7563	\N	\N	\N
10003	DELEGUEDEL	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	7564	\N	\N	\N
10004	DELEGUEDEL	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	7565	\N	\N	\N
10005	DELEGUEDEL	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	7566	\N	\N	\N
10006	DELEGUEDEL	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	7567	\N	\N	\N
10007	DELEGUEDEL	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	7568	\N	\N	\N
10008	DELEGUEDEL	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	7569	\N	\N	\N
10009	DELEGUEDEL	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	7570	\N	\N	\N
10010	DELEGUEDEL	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	7571	\N	\N	\N
10011	DELEGUEDEL	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	7572	\N	\N	\N
10012	DELEGUEDEL	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	7573	\N	\N	\N
10013	DELEGUEDEL	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	7574	\N	\N	\N
10014	DELEGUEDEL	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	7575	\N	\N	\N
10015	DELEGUEDEL	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	7576	\N	\N	\N
10016	DELEGUEDEL	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	7577	\N	\N	\N
10017	DELEGUEDEL	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	7578	\N	\N	\N
10018	DELEGUEDEL	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	7579	\N	\N	\N
10020	DELEGUEDEL	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7580	\N	\N	\N
10021	DELEGUEDEL	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7581	\N	\N	\N
10022	DELEGUEDEL	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7582	\N	\N	\N
10023	DELEGUEDEL	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7583	\N	\N	\N
10024	DELEGUEDEL	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7584	\N	\N	\N
10025	DELEGUEDEL	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7585	\N	\N	\N
10026	DELEGUEDEL	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7586	\N	\N	\N
10027	DELEGUEDEL	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7587	\N	\N	\N
10028	DELEGUEDEL	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7588	\N	\N	\N
10029	DELEGUEDEL	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7589	\N	\N	\N
10030	DELEGUEDEL	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7590	\N	\N	\N
10031	DELEGUEDEL	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7591	\N	\N	\N
10032	DELEGUEDEL	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7592	\N	\N	\N
10033	DELEGUEDEL	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7593	\N	\N	\N
10034	DELEGUEDEL	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7594	\N	\N	\N
10035	DELEGUEDEL	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7595	\N	\N	\N
10036	DELEGUEDEL	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7596	\N	\N	\N
10037	DELEGUEDEL	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7597	\N	\N	\N
10038	DELEGUEDEL	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7598	\N	\N	\N
10039	DELEGUEDEL	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7599	\N	\N	\N
10040	DELEGUEDEL	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7600	\N	\N	\N
10041	DELEGUEDEL	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7601	\N	\N	\N
10042	DELEGUEDEL	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7602	\N	\N	\N
10043	DELEGUEDEL	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7603	\N	\N	\N
10044	DELEGUEDEL	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7604	\N	\N	\N
10045	DELEGUEDEL	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7605	\N	\N	\N
10046	DELEGUEDEL	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7606	\N	\N	\N
10047	DELEGUEDEL	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7607	\N	\N	\N
10048	DELEGUEDEL	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7608	\N	\N	\N
10049	DELEGUEDEL	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7609	\N	\N	\N
10050	DELEGUEDEL	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7610	\N	\N	\N
10051	DELEGUEDEL	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7611	\N	\N	\N
10052	DELEGUEDEL	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7612	\N	\N	\N
10053	DELEGUEDEL	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7613	\N	\N	\N
10054	DELEGUEDEL	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7614	\N	\N	\N
10055	DELEGUEDEL	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7615	\N	\N	\N
10056	DELEGUEDEL	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7616	\N	\N	\N
10057	DELEGUEDEL	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7617	\N	\N	\N
10058	DELEGUEDEL	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7618	\N	\N	\N
10059	DELEGUEDEL	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7619	\N	\N	\N
5935	DELEGUEDEL	2015-02-13 00:00:00	2023-12-26 00:00:00	ANCIEN	\N	\N	\N	\N	4774	\N	2015-02-13 00:00:00	\N
8930	PDTDEL	2021-07-02 00:00:00	2022-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	5128	\N	\N	\N
8931	VICPDTDEL	2021-07-02 00:00:00	2022-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	6629	\N	\N	\N
9069	DELEGUEDEL	2021-11-05 00:00:00	2023-12-26 00:00:00	ANCIEN	\N	\N	\N	\N	6888	\N	\N	\N
9129	DELEGUEDEL	2022-01-05 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6928	\N	\N	\N
9229	DELEGUEDEL	2020-10-20 00:00:00	2020-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	6424	\N	\N	\N
9309	DELEGUEDEL	2022-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	7028	\N	\N	\N
9409	DELEGUEDEL	2023-05-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	7128	\N	\N	\N
6333	DELTITDEL	2015-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	5049	\N	2015-10-15 00:00:00	\N
8492	DELEGUEDEL	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6491	\N	\N	\N
8613	VICPDTPREDEL	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6493	\N	\N	\N
9667	VICPDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7180	\N	\N	\N
9668	VICPDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7184	\N	\N	\N
9669	VICPDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7175	\N	\N	\N
9670	SECRETDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7160	\N	\N	\N
9671	VICPDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7173	\N	\N	\N
9672	VICPDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7192	\N	\N	\N
9673	VICPDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7186	\N	\N	\N
9749	DELEGUEDEL	2023-10-17 00:00:00	2025-03-31 00:00:00	ACTIF	\N	\N	\N	\N	7213	\N	\N	\N
9780	PDTDEL	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	7361	\N	\N	\N
9781	VICPDTDEL	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	7362	\N	\N	\N
9831	PDTDEL	2023-11-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	7385	\N	\N	\N
9836	VICPDTDEL	2023-11-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	7392	\N	\N	\N
9840	VICPDTDEL	2023-11-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	7404	\N	\N	\N
9844	SECRETDEL	2023-11-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	7372	\N	\N	\N
9964	DELEGUEDEL	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	7535	\N	\N	\N
9965	DELEGUEDEL	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	7536	\N	\N	\N
8789	SECRETDEL	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6688	5	\N	\N
8790	DELEGUEDEL	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6689	\N	\N	\N
8791	SECRETDEL	2020-12-15 00:00:00	2023-12-05 00:00:00	ANCIEN	\N	\N	\N	\N	6690	7	\N	\N
8792	DELEGUEDEL	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6691	\N	\N	\N
8793	DELEGUEDEL	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6692	\N	\N	\N
8794	SECRETDEL	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6693	6	\N	\N
8795	DELEGUEDEL	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	6694	\N	\N	\N
8796	DELEGUEDEL	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	6695	\N	\N	\N
8800	SECRETDEL	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6699	4	\N	\N
8798	DELEGUEDEL	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6697	\N	\N	\N
8799	DELEGUEDEL	2020-12-15 00:00:00	2023-12-11 00:00:00	ANCIEN	\N	\N	\N	\N	6698	\N	\N	\N
8801	VICPDTDEL	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6700	3	\N	\N
8802	DELEGUEDEL	2020-12-15 00:00:00	2023-12-11 00:00:00	ANCIEN	\N	\N	\N	\N	6701	\N	\N	\N
8803	DELEGUEDEL	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	6702	\N	\N	\N
8804	SECRETDEL	2020-12-15 00:00:00	2023-12-05 00:00:00	ANCIEN	\N	\N	\N	\N	6703	8	\N	\N
8805	PDTDEL	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6704	1	\N	\N
8806	VICPDTDEL	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6705	2	\N	\N
8807	DELEGUEDEL	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6706	\N	\N	\N
8849	VICPDTDEL	2021-02-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6728	\N	\N	\N
8850	DELEGUEDEL	2021-02-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6729	\N	\N	\N
8851	DELEGUEDEL	2021-02-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6730	\N	\N	\N
8852	DELEGUEDEL	2021-02-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6731	\N	\N	\N
8989	DELEGUEDEL	2021-10-12 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6828	\N	\N	\N
8854	DELEGUEDEL	2021-02-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6733	\N	\N	\N
8909	DELEGUEDEL	2021-06-23 00:00:00	2023-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	4764	\N	\N	\N
8856	DELEGUEDEL	2021-02-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6735	\N	\N	\N
8568	VICPDTDEL	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6380	\N	\N	\N
9720	VICPDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7301	\N	\N	\N
9730	SECRETDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7294	\N	\N	\N
9751	DELEGUEDEL	2023-10-17 00:00:00	2025-03-31 00:00:00	ACTIF	\N	\N	\N	\N	7171	\N	\N	\N
9955	DELSUPDEL	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	6948	\N	\N	\N
9956	DELTITDEL	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	6608	\N	\N	\N
9957	DELTITDEL	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	7528	\N	\N	\N
9958	DELTITDEL	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	7529	\N	\N	\N
9959	DELTITDEL	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	7530	\N	\N	\N
9960	DELSUPDEL	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	7531	\N	\N	\N
9961	DELSUPDEL	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	7532	\N	\N	\N
9962	DELSUPDEL	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	7533	\N	\N	\N
9966	DELEGUEDEL	2023-10-26 00:00:00	2024-02-26 00:00:00	ANCIEN	\N	\N	\N	\N	7537	\N	\N	\N
9967	DELEGUEDEL	2023-10-26 00:00:00	2024-02-26 00:00:00	ANCIEN	\N	\N	\N	\N	7538	\N	\N	\N
9968	DELEGUEDEL	2023-10-26 00:00:00	2024-02-26 00:00:00	ANCIEN	\N	\N	\N	\N	7539	\N	\N	\N
9969	DELEGUEDEL	2023-10-26 00:00:00	2024-02-26 00:00:00	ANCIEN	\N	\N	\N	\N	7540	\N	\N	\N
9970	DELEGUEDEL	2023-10-26 00:00:00	2024-02-26 00:00:00	ANCIEN	\N	\N	\N	\N	7541	\N	\N	\N
9971	DELEGUEDEL	2023-10-26 00:00:00	2024-02-26 00:00:00	ANCIEN	\N	\N	\N	\N	7542	\N	\N	\N
9972	DELEGUEDEL	2023-10-26 00:00:00	2024-02-26 00:00:00	ANCIEN	\N	\N	\N	\N	7543	\N	\N	\N
9973	DELEGUEDEL	2023-10-26 00:00:00	2024-02-26 00:00:00	ANCIEN	\N	\N	\N	\N	7544	\N	\N	\N
9974	DELEGUEDEL	2023-10-26 00:00:00	2024-02-26 00:00:00	ANCIEN	\N	\N	\N	\N	7545	\N	\N	\N
9975	DELSUPDEL	2024-02-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	5737	\N	\N	\N
9976	DELTITDEL	2024-02-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7537	\N	\N	\N
9977	DELTITDEL	2024-02-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7538	\N	\N	\N
9978	DELTITDEL	2024-02-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7539	\N	\N	\N
9979	DELTITDEL	2024-02-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7540	\N	\N	\N
9980	DELSUPDEL	2024-02-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7541	\N	\N	\N
9981	DELSUPDEL	2024-02-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7542	\N	\N	\N
9982	DELSUPDEL	2024-02-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7543	\N	\N	\N
9983	DELSUPDEL	2024-02-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7544	\N	\N	\N
9984	DELSUPDEL	2024-02-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7545	\N	\N	\N
8809	VICPDTPREDEL	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	5348	\N	\N	\N
8869	DELEGUEDEL	2021-02-09 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6748	\N	\N	\N
8949	DELEGUEDEL	2021-08-06 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6788	\N	\N	\N
5959	DELEGUEDEL	2015-02-13 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4798	\N	2015-02-13 16:15:53	\N
3669	DELEGUEDEL	2009-03-02 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2625	\N	\N	2015-02-13 15:53:04
9329	DELEGUEDEL	2022-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	7048	\N	\N	\N
9726	VICPDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7313	\N	\N	\N
9727	SECRETDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7275	\N	\N	\N
9752	SECRETDEL	2025-04-01 00:00:00	\N	FUTUR	\N	\N	\N	\N	7171	\N	\N	\N
9843	VICPDTDEL	2023-11-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	7409	\N	\N	\N
9466	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7185	\N	\N	\N
9468	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7187	\N	\N	\N
9850	DELEGUEDEL	2023-11-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7448	\N	\N	\N
9889	DELEGUEDEL	2023-12-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	7488	\N	\N	\N
9474	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7157	\N	\N	\N
9475	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7158	\N	\N	\N
9476	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7159	\N	\N	\N
9477	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7160	\N	\N	\N
9478	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7161	\N	\N	\N
9479	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7162	\N	\N	\N
9480	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7163	\N	\N	\N
9481	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7164	\N	\N	\N
9482	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7165	\N	\N	\N
9483	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7166	\N	\N	\N
9484	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7167	\N	\N	\N
9485	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7168	\N	\N	\N
9486	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7169	\N	\N	\N
9487	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7170	\N	\N	\N
9890	DELEGUEDEL	2023-12-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	7489	\N	\N	\N
9489	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7172	\N	\N	\N
9490	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7173	\N	\N	\N
9491	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7174	\N	\N	\N
9492	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7175	\N	\N	\N
9493	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7177	\N	\N	\N
9494	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7178	\N	\N	\N
9495	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7180	\N	\N	\N
9496	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7182	\N	\N	\N
9497	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7184	\N	\N	\N
9498	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7186	\N	\N	\N
9499	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7188	\N	\N	\N
9500	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7190	\N	\N	\N
9501	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7192	\N	\N	\N
9502	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7193	\N	\N	\N
9503	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7194	\N	\N	\N
9504	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7195	\N	\N	\N
9505	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7196	\N	\N	\N
9506	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7197	\N	\N	\N
9507	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7198	\N	\N	\N
9508	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7199	\N	\N	\N
9509	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7200	\N	\N	\N
9510	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7201	\N	\N	\N
9511	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7202	\N	\N	\N
9512	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7203	\N	\N	\N
9513	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7204	\N	\N	\N
9514	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7205	\N	\N	\N
9515	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7206	\N	\N	\N
9516	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7207	\N	\N	\N
9517	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7208	\N	\N	\N
9891	DELEGUEDEL	2023-12-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	7490	\N	\N	\N
9519	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7210	\N	\N	\N
9520	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7211	\N	\N	\N
9521	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7212	\N	\N	\N
9892	DELEGUEDEL	2023-12-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	7491	\N	\N	\N
9523	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7214	\N	\N	\N
9524	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7215	\N	\N	\N
9525	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7216	\N	\N	\N
9526	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7217	\N	\N	\N
9527	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7218	\N	\N	\N
9528	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7219	\N	\N	\N
9529	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7220	\N	\N	\N
9530	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7221	\N	\N	\N
9531	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7222	\N	\N	\N
9532	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7223	\N	\N	\N
9533	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7224	\N	\N	\N
9534	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7225	\N	\N	\N
9535	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7226	\N	\N	\N
9536	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7227	\N	\N	\N
9537	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7228	\N	\N	\N
9584	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7275	\N	\N	\N
9585	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7276	\N	\N	\N
9586	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7277	\N	\N	\N
9587	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7278	\N	\N	\N
9588	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7279	\N	\N	\N
9589	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7280	\N	\N	\N
9590	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7281	\N	\N	\N
9591	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7282	\N	\N	\N
9592	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7283	\N	\N	\N
9593	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7284	\N	\N	\N
9594	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7285	\N	\N	\N
9595	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7286	\N	\N	\N
9596	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7287	\N	\N	\N
9597	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7288	\N	\N	\N
9598	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7289	\N	\N	\N
9599	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7290	\N	\N	\N
9600	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7291	\N	\N	\N
9601	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7292	\N	\N	\N
9602	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7293	\N	\N	\N
9603	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7294	\N	\N	\N
9604	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7295	\N	\N	\N
9605	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7296	\N	\N	\N
9606	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7297	\N	\N	\N
9607	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7298	\N	\N	\N
9608	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7299	\N	\N	\N
9609	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7300	\N	\N	\N
9610	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7301	\N	\N	\N
9611	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7302	\N	\N	\N
9612	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7303	\N	\N	\N
9613	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7304	\N	\N	\N
9614	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7305	\N	\N	\N
9615	DELEGUEDEL	2023-10-17 00:00:00	2029-11-27 00:00:00	ACTIF	\N	\N	\N	\N	7306	\N	\N	\N
9616	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7307	\N	\N	\N
9617	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7308	\N	\N	\N
9618	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7309	\N	\N	\N
9619	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7310	\N	\N	\N
9620	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7311	\N	\N	\N
9621	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7312	\N	\N	\N
9622	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7313	\N	\N	\N
9623	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7314	\N	\N	\N
9624	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7315	\N	\N	\N
9625	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7316	\N	\N	\N
9893	DELEGUEDEL	2023-12-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	7492	\N	\N	\N
9894	DELEGUEDEL	2023-12-06 00:00:00	2023-12-11 00:00:00	ANCIEN	\N	\N	\N	\N	7493	\N	\N	\N
9895	DELEGUEDEL	2023-12-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	7494	\N	\N	\N
9896	DELEGUEDEL	2023-12-06 00:00:00	2023-12-11 00:00:00	ANCIEN	\N	\N	\N	\N	7495	\N	\N	\N
9897	DELEGUEDEL	2023-12-06 00:00:00	2023-12-11 00:00:00	ANCIEN	\N	\N	\N	\N	7496	\N	\N	\N
9898	DELEGUEDEL	2023-12-06 00:00:00	2023-12-11 00:00:00	ANCIEN	\N	\N	\N	\N	7497	\N	\N	\N
9899	DELEGUEDEL	2023-12-06 00:00:00	2023-12-11 00:00:00	ANCIEN	\N	\N	\N	\N	7498	\N	\N	\N
9900	DELEGUEDEL	2023-12-06 00:00:00	2023-12-11 00:00:00	ANCIEN	\N	\N	\N	\N	6703	0	\N	\N
9009	DELEGUEDEL	2021-10-14 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6829	\N	\N	\N
9010	DELEGUEDEL	2021-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6830	\N	\N	\N
9011	DELEGUEDEL	2021-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6831	\N	\N	\N
9012	DELEGUEDEL	2021-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6832	\N	\N	\N
9013	DELEGUEDEL	2021-10-14 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6833	\N	\N	\N
9014	DELEGUEDEL	2021-10-14 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6834	\N	\N	\N
9015	DELEGUEDEL	2021-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6835	\N	\N	\N
9016	DELEGUEDEL	2021-10-14 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6836	\N	\N	\N
9017	DELEGUEDEL	2021-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6837	\N	\N	\N
9018	DELEGUEDEL	2021-10-14 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6838	\N	\N	\N
9049	DELEGUEDEL	2021-10-20 00:00:00	2023-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	6868	\N	\N	\N
9050	DELEGUEDEL	2021-10-20 00:00:00	2023-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	6869	\N	\N	\N
9051	DELEGUEDEL	2021-10-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	6870	\N	\N	\N
9149	DELTITDEL	2020-11-02 00:00:00	2024-02-27 00:00:00	ANCIEN	\N	\N	\N	\N	6948	\N	\N	\N
9289	PDTDEL	2022-07-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6633	\N	\N	\N
9296	DELEGUEDEL	2022-07-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	5128	\N	\N	\N
9297	DELEGUEDEL	2022-07-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6629	\N	\N	\N
9298	VICPDTPREDEL	2022-07-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	5548	\N	\N	\N
9369	DELEGUEDEL	2023-01-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	7088	\N	\N	\N
9370	DELEGUEDEL	2023-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	7089	\N	\N	\N
9371	DELEGUEDEL	2023-01-02 00:00:00	2023-12-26 00:00:00	ANCIEN	\N	\N	\N	\N	7090	\N	\N	\N
9389	SECRETGENDEL	2023-03-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	7108	\N	\N	\N
8564	SECRETDEL	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6455	\N	\N	\N
8569	VICPDTDEL	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6398	\N	\N	\N
8603	VICPDTDEL	2020-10-22 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6430	\N	\N	\N
8414	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6413	\N	\N	\N
8416	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6415	\N	\N	\N
8591	VICPDTDEL	2020-10-22 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6337	\N	\N	\N
8594	SECRETDEL	2020-10-22 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6329	\N	\N	\N
8486	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6485	\N	\N	\N
8483	DELEGUEDEL	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6482	\N	\N	\N
9430	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7149	\N	\N	\N
9431	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7150	\N	\N	\N
9432	DELEGUEDEL	2023-10-17 00:00:00	2023-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	7151	\N	\N	\N
9433	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7152	\N	\N	\N
9725	VICPDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7316	\N	\N	\N
9835	VICPDTDEL	2023-11-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	7391	\N	\N	\N
9436	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7155	\N	\N	\N
9437	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7156	\N	\N	\N
9438	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7157	\N	\N	\N
9439	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7158	\N	\N	\N
9440	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7159	\N	\N	\N
9441	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7160	\N	\N	\N
9442	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7161	\N	\N	\N
9443	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7162	\N	\N	\N
9444	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7163	\N	\N	\N
9445	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7164	\N	\N	\N
9446	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7165	\N	\N	\N
9447	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7166	\N	\N	\N
9448	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7167	\N	\N	\N
9449	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7168	\N	\N	\N
9450	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7169	\N	\N	\N
9451	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7170	\N	\N	\N
9837	VICPDTDEL	2023-11-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	7393	\N	\N	\N
9453	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7172	\N	\N	\N
9454	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7173	\N	\N	\N
9455	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7174	\N	\N	\N
9456	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7175	\N	\N	\N
9458	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7177	\N	\N	\N
9459	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7178	\N	\N	\N
9461	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7180	\N	\N	\N
9463	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7182	\N	\N	\N
9465	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7184	\N	\N	\N
9467	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7186	\N	\N	\N
9469	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7188	\N	\N	\N
9471	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7190	\N	\N	\N
9472	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7192	\N	\N	\N
9838	VICPDTDEL	2023-11-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	7401	\N	\N	\N
9849	DELEGUEDEL	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	7428	\N	\N	\N
9870	PDTDEL	2023-11-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	7322	\N	\N	\N
9909	VICPDTDEL	2023-12-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	6698	3	\N	\N
9910	PDTDEL	2023-12-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	6701	1	\N	\N
9911	SECRETDEL	2023-12-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	6703	8	\N	\N
9912	VICPDTDEL	2023-12-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	7493	2	\N	\N
9913	SECRETDEL	2023-12-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	7495	4	\N	\N
9914	SECRETDEL	2023-12-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	7496	5	\N	\N
9915	SECRETDEL	2023-12-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	7497	6	\N	\N
9916	SECRETDEL	2023-12-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	7498	7	\N	\N
9929	DELEGUEDEL	2024-02-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	7508	\N	\N	\N
9963	DELEGUEDEL	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	7534	\N	\N	\N
8969	DELEGUEDEL	2021-10-06 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6808	\N	\N	\N
9029	DELEGUEDEL	2021-10-26 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	6848	\N	\N	\N
9089	DELEGUEDEL	2021-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	6908	\N	\N	\N
9538	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7229	\N	\N	\N
9539	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7230	\N	\N	\N
9540	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7231	\N	\N	\N
9541	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7232	\N	\N	\N
9542	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7233	\N	\N	\N
9543	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7234	\N	\N	\N
9544	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7235	\N	\N	\N
9949	DELEGUEDEL	2024-02-27 00:00:00	2024-02-27 00:00:00	ANCIEN	\N	\N	\N	\N	7528	\N	\N	\N
9546	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7237	\N	\N	\N
9547	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7238	\N	\N	\N
9548	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7239	\N	\N	\N
9549	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7240	\N	\N	\N
9550	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7241	\N	\N	\N
9551	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7242	\N	\N	\N
9552	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7243	\N	\N	\N
9553	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7244	\N	\N	\N
9554	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7245	\N	\N	\N
9555	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7246	\N	\N	\N
9556	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7247	\N	\N	\N
9557	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7248	\N	\N	\N
9558	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7249	\N	\N	\N
9559	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7250	\N	\N	\N
9560	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7251	\N	\N	\N
9561	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7252	\N	\N	\N
9562	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7253	\N	\N	\N
9563	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7254	\N	\N	\N
9564	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7255	\N	\N	\N
9565	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7256	\N	\N	\N
9566	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7257	\N	\N	\N
9567	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7258	\N	\N	\N
9568	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7259	\N	\N	\N
9569	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7260	\N	\N	\N
9570	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7261	\N	\N	\N
9571	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7262	\N	\N	\N
9572	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7263	\N	\N	\N
9573	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7264	\N	\N	\N
9574	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7265	\N	\N	\N
9575	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7266	\N	\N	\N
9576	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7267	\N	\N	\N
9577	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7268	\N	\N	\N
9578	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7269	\N	\N	\N
9950	DELEGUEDEL	2024-02-27 00:00:00	2024-02-27 00:00:00	ANCIEN	\N	\N	\N	\N	7529	\N	\N	\N
9580	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7271	\N	\N	\N
9581	DELEGUEDEL	2023-10-17 00:00:00	2023-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	7272	\N	\N	\N
9582	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7273	\N	\N	\N
9583	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7274	\N	\N	\N
9626	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7317	\N	\N	\N
9627	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7318	\N	\N	\N
9628	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7319	\N	\N	\N
9629	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7320	\N	\N	\N
9630	DELEGUEDEL	2023-10-17 00:00:00	2023-10-24 00:00:00	ANCIEN	\N	\N	\N	\N	7321	\N	\N	\N
9631	DELEGUEDEL	2023-10-17 00:00:00	2023-10-24 00:00:00	ANCIEN	\N	\N	\N	\N	7322	\N	\N	\N
9632	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7323	\N	\N	\N
9633	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7324	\N	\N	\N
9634	DELEGUEDEL	2023-10-17 00:00:00	2023-10-24 00:00:00	ANCIEN	\N	\N	\N	\N	7325	\N	\N	\N
9635	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7326	\N	\N	\N
9636	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7327	\N	\N	\N
9637	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7328	\N	\N	\N
9638	DELEGUEDEL	2023-10-17 00:00:00	2023-10-24 00:00:00	ANCIEN	\N	\N	\N	\N	7329	\N	\N	\N
9639	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7330	\N	\N	\N
9640	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7331	\N	\N	\N
9641	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7332	\N	\N	\N
9642	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7333	\N	\N	\N
9643	DELEGUEDEL	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	7334	\N	\N	\N
9665	SECRETDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7149	\N	\N	\N
9666	VICPDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7170	\N	\N	\N
9677	VICPDTPREDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7242	\N	\N	\N
9678	VICPDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7234	\N	\N	\N
9679	SECRETDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7246	\N	\N	\N
9680	SECRETDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7256	\N	\N	\N
9681	PDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7257	\N	\N	\N
9682	VICPDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7249	\N	\N	\N
9683	SECRETDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7250	\N	\N	\N
9684	VICPDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7272	\N	\N	\N
9685	VICPDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7245	\N	\N	\N
9686	VICPDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7267	\N	\N	\N
9687	VICPDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7264	\N	\N	\N
9688	VICPDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7252	\N	\N	\N
9689	SECRETDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7233	\N	\N	\N
9690	VICPDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7271	\N	\N	\N
9691	VICPDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7269	\N	\N	\N
9692	VICPDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7237	\N	\N	\N
9756	PDTDEL	2023-10-25 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	7322	\N	\N	\N
9719	VICPDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7300	\N	\N	\N
9723	VICPDTDEL	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	7307	\N	\N	\N
9758	VICPDTDEL	2023-10-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	7321	\N	\N	\N
9759	VICPDTDEL	2023-10-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	7329	\N	\N	\N
9760	VICPDTDEL	2023-10-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	7325	\N	\N	\N
9767	DELEGUEDEL	2023-10-25 00:00:00	2023-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	7352	\N	\N	\N
9768	DELEGUEDEL	2023-10-25 00:00:00	2023-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	7353	\N	\N	\N
9769	DELEGUEDEL	2023-10-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	7354	\N	\N	\N
9770	DELEGUEDEL	2023-10-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	7355	\N	\N	\N
9771	DELEGUEDEL	2023-10-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	7356	\N	\N	\N
9772	DELEGUEDEL	2023-10-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	7357	\N	\N	\N
9773	DELEGUEDEL	2023-10-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	7358	\N	\N	\N
9774	DELEGUEDEL	2023-10-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	7359	\N	\N	\N
9775	DELEGUEDEL	2023-10-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	7360	\N	\N	\N
9776	PDTDEL	2023-10-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	7352	\N	\N	\N
9777	VICPDTDEL	2023-10-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	7353	\N	\N	\N
9951	DELEGUEDEL	2024-02-27 00:00:00	2024-02-27 00:00:00	ANCIEN	\N	\N	\N	\N	7530	\N	\N	\N
9952	DELEGUEDEL	2024-02-27 00:00:00	2024-02-27 00:00:00	ANCIEN	\N	\N	\N	\N	7531	\N	\N	\N
9953	DELEGUEDEL	2024-02-27 00:00:00	2024-02-27 00:00:00	ANCIEN	\N	\N	\N	\N	7532	\N	\N	\N
9954	DELEGUEDEL	2024-02-27 00:00:00	2024-02-27 00:00:00	ANCIEN	\N	\N	\N	\N	7533	\N	\N	\N
\.


--
-- Data for Name: fonmemgrppol; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY fonmemgrppol (fonmemgrppolid, fongrppolcod, fonmemgrppoldatdeb, fonmemgrppoldatfin, temvalcod, evelic, evelib, evelil, eveobs, memgrppolid, syscredat, sysmajdat) FROM stdin;
278	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	278	\N	\N
279	MEMBREPOL	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	279	\N	2014-09-28 16:40:50
280	MEMBREPOL	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	280	\N	\N
281	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	281	\N	\N
282	MEMBREPOL	\N	2002-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	282	\N	\N
283	MEMBREPOL	1990-10-02 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	283	\N	2014-09-28 13:21:47
284	MEMBREPOL	1995-10-02 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	284	\N	2014-09-28 13:21:47
285	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	285	\N	\N
286	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	286	\N	\N
287	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	287	\N	\N
289	MEMBREPOL	\N	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	289	\N	\N
290	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	290	\N	\N
291	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	291	\N	\N
292	MEMBREPOL	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	292	\N	\N
293	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	293	\N	\N
294	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	294	\N	\N
295	MEMBREPOL	\N	2002-09-09 00:00:00	ANCIEN	\N	\N	\N	\N	295	\N	\N
296	MEMBREPOL	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	296	\N	\N
297	MEMBREPOL	\N	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	297	\N	\N
298	MEMBREPOL	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	298	\N	\N
299	MEMBREPOL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	299	\N	\N
300	MEMBREPOL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	300	\N	\N
302	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	302	\N	\N
303	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	303	\N	\N
304	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	304	\N	\N
306	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	306	\N	\N
307	DELPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	307	\N	\N
308	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	308	\N	\N
309	MEMBREPOL	\N	2001-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	309	\N	\N
310	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	310	\N	\N
311	MEMBREPOL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	311	\N	\N
314	MEMBREPOL	\N	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	314	\N	\N
315	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	315	\N	\N
316	MEMBREPOL	\N	2000-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	316	\N	\N
317	MEMBREPOL	\N	2002-07-16 00:00:00	ANCIEN	\N	\N	\N	\N	317	\N	\N
318	MEMBREPOL	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	318	\N	\N
319	MEMBREPOL	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	319	\N	\N
323	MEMBREPOL	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	323	\N	\N
324	MEMBREPOL	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	324	\N	\N
325	MEMBREPOL	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	325	\N	\N
326	MEMBREPOL	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	326	\N	\N
327	MEMBREPOL	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	327	\N	\N
328	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	328	\N	\N
329	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	329	\N	\N
330	MEMBREPOL	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	330	\N	\N
331	MEMBREPOL	1989-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	331	\N	\N
332	MEMBREPOL	1998-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	332	\N	\N
333	MEMBREPOL	1998-10-01 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	333	\N	\N
334	MEMBREPOL	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	334	\N	\N
335	MEMBREPOL	1998-10-01 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	335	\N	\N
340	MEMBREPOL	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	339	\N	\N
339	MEMBREPOL	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	338	\N	\N
341	MEMBREPOL	1998-10-01 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	340	\N	\N
342	MEMBREPOL	1998-10-01 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	341	\N	\N
343	MEMBREPOL	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	342	\N	\N
345	MEMBREPOL	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	343	\N	\N
346	MEMBREPOL	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	344	\N	\N
348	MEMBREPOL	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	345	\N	\N
349	MEMBREPOL	1998-10-01 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	346	\N	2017-06-29 09:53:37
350	MEMBREPOL	1998-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	347	\N	2014-09-28 13:19:48
351	MEMBREPOL	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	348	\N	\N
352	MEMBREPOL	1998-10-05 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	349	\N	\N
353	MEMBREPOL	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	350	\N	\N
354	MEMBREPOL	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	351	\N	\N
355	MEMBREPOL	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	352	\N	\N
356	MEMBREPOL	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	353	\N	\N
357	MEMBREPOL	1998-10-01 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	354	\N	\N
358	MEMBREPOL	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	355	\N	\N
359	MEMBREPOL	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	356	\N	\N
360	MEMBREPOL	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	357	\N	\N
361	MEMBREPOL	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	358	\N	\N
362	MEMBREPOL	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	359	\N	\N
363	MEMBREPOL	1998-10-01 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	360	\N	\N
365	MEMBREPOL	1998-10-01 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	361	\N	\N
366	MEMBREPOL	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	362	\N	\N
368	MEMBREPOL	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	363	\N	\N
369	MEMBREPOL	1998-10-01 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	364	\N	\N
370	MEMBREPOL	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	365	\N	\N
371	MEMBREPOL	1998-10-01 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	366	\N	\N
372	MEMBREPOL	1998-10-01 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	367	\N	\N
374	MEMBREPOL	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	368	\N	\N
376	MEMBREPOL	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	369	\N	\N
377	MEMBREPOL	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	370	\N	\N
378	MEMBREPOL	\N	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	371	\N	\N
379	MEMBREPOL	1998-10-03 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	372	\N	\N
380	MEMBREPOL	1998-10-05 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	373	\N	\N
381	MEMBREPOL	1998-10-05 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	374	\N	\N
382	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	375	\N	\N
383	MEMBREPOL	1998-10-05 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	376	\N	\N
384	MEMBREPOL	1998-10-05 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	377	\N	\N
385	MEMBREPOL	1998-10-05 00:00:00	2002-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	378	\N	\N
386	MEMBREPOL	1998-10-05 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	379	\N	\N
387	MEMBREPOL	1998-10-05 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	380	\N	\N
388	MEMBREPOL	1998-10-05 00:00:00	2002-05-09 00:00:00	ANCIEN	\N	\N	\N	\N	381	\N	\N
389	MEMBREPOL	1998-10-05 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	382	\N	\N
390	MEMBREPOL	1998-10-05 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	383	\N	\N
391	MEMBREPOL	1998-10-05 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	384	\N	\N
392	MEMBREPOL	1998-10-05 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	385	\N	\N
393	MEMBREPOL	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	386	\N	\N
394	MEMBREPOL	1998-10-05 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	387	\N	\N
395	MEMBREPOL	1998-10-05 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	388	\N	\N
396	MEMBREPOL	1998-10-05 00:00:00	2001-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	389	\N	\N
397	MEMBREPOL	1998-10-05 00:00:00	2004-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	390	\N	\N
398	MEMBREPOL	1998-10-05 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	391	\N	\N
399	MEMBREPOL	1998-10-05 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	392	\N	\N
400	MEMBREPOL	1998-10-05 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	393	\N	2014-10-07 17:17:30
402	MEMBREPOL	1998-10-05 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	394	\N	\N
403	MEMBREPOL	1998-10-05 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	395	\N	\N
404	MEMBREPOL	1998-10-05 00:00:00	2009-09-09 00:00:00	ANCIEN	\N	\N	\N	\N	396	\N	\N
405	MEMBREPOL	1998-10-05 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	397	\N	2017-09-25 09:56:00
406	MEMBREPOL	1998-10-05 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	398	\N	\N
409	MEMBREPOL	1998-10-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	401	\N	\N
408	MEMBREPOL	1998-10-05 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	400	\N	\N
410	MEMBREPOL	1998-10-05 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	402	\N	2014-09-28 14:31:42
411	MEMBREPOL	1998-10-05 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	403	\N	\N
412	MEMBREPOL	1998-10-05 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	404	\N	\N
413	MEMBREPOL	1998-10-05 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	405	\N	\N
415	MEMBREPOL	1998-10-05 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	406	\N	\N
416	MEMBREPOL	1998-10-05 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	407	\N	\N
417	MEMBREPOL	1998-10-05 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	408	\N	\N
418	MEMBREPOL	1998-10-05 00:00:00	1999-05-12 00:00:00	ANCIEN	\N	\N	\N	\N	409	\N	\N
419	MEMBREPOL	1998-10-05 00:00:00	2018-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	410	\N	2018-05-31 10:52:17
424	DELPOL	1998-10-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19	\N	2017-10-03 17:27:53
421	MEMBREPOL	1998-10-05 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	411	\N	2014-09-28 17:38:26
423	PDTPOL	1998-09-29 00:00:00	2002-07-16 00:00:00	ANCIEN	\N	\N	\N	\N	149	\N	\N
425	MEMBREPOL	1998-10-05 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	17	\N	\N
427	MEMBREPOL	1998-10-08 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	412	\N	\N
23	MEMBREPOL	\N	1998-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	23	\N	\N
429	MEMBREPOL	1998-10-08 00:00:00	1998-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	413	\N	\N
430	MEMBREPOL	1998-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	322	\N	\N
431	MEMBREPOL	1998-10-09 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	414	\N	\N
432	MEMBREPOL	1998-11-03 00:00:00	1998-11-09 00:00:00	ANCIEN	\N	\N	\N	\N	415	\N	\N
433	MEMBREPOL	1998-11-09 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	416	\N	\N
8	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8	\N	\N
18	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	18	\N	\N
29	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29	\N	\N
39	MEMBREPOL	\N	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	39	\N	\N
46	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	46	\N	\N
56	MEMBREPOL	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	56	\N	\N
64	MEMBREPOL	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	64	\N	\N
71	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	71	\N	\N
81	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	81	\N	\N
91	MEMBREPOL	\N	2000-03-28 00:00:00	ANCIEN	\N	\N	\N	\N	91	\N	\N
98	MEMBREPOL	\N	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	98	\N	\N
108	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	108	\N	\N
116	MEMBREPOL	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	116	\N	\N
305	MEMBREPOL	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	305	\N	\N
313	MEMBREPOL	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	313	\N	\N
321	MEMBREPOL	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	321	\N	\N
337	MEMBREPOL	1998-10-01 00:00:00	2004-12-23 00:00:00	ANCIEN	\N	\N	\N	\N	336	\N	\N
263	PDTPOL	1979-01-01 00:00:00	2001-04-03 00:00:00	ANCIEN	\N	\N	\N	\N	263	\N	\N
434	MEMBREPOL	1999-05-12 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	417	\N	\N
435	MEMBREPOL	1999-10-17 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	418	\N	\N
436	MEMBREPOL	1999-11-02 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	419	\N	2017-06-19 12:20:22
437	MEMBREPOL	1999-11-14 00:00:00	1999-11-15 00:00:00	ANCIEN	\N	\N	\N	\N	420	\N	\N
438	MEMBREPOL	1995-11-02 00:00:00	1997-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	421	\N	\N
439	MEMBREPOL	1999-11-16 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	422	\N	\N
440	MEMBREPOL	1999-11-28 00:00:00	1999-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	423	\N	\N
441	MEMBREPOL	1999-12-09 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	424	\N	\N
442	MEMBREPOL	1999-12-17 00:00:00	1999-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	425	\N	\N
443	MEMBREPOL	1999-12-21 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	426	\N	\N
444	MEMBREPOL	2000-01-27 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	427	\N	\N
445	MEMBREPOL	2000-01-27 00:00:00	2001-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	428	\N	\N
446	MEMBREPOL	2000-01-28 00:00:00	2000-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	429	\N	\N
447	MEMBREPOL	2000-02-04 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	430	\N	\N
448	MEMBREPOL	2000-03-19 00:00:00	2000-03-24 00:00:00	ANCIEN	\N	\N	\N	\N	431	\N	\N
449	MEMBREPOL	2000-03-24 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	432	\N	\N
450	MEMBREPOL	2000-03-29 00:00:00	2000-04-03 00:00:00	ANCIEN	\N	\N	\N	\N	433	\N	\N
451	MEMBREPOL	2000-04-03 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	434	\N	\N
452	MEMBREPOL	2000-04-28 00:00:00	2000-05-02 00:00:00	ANCIEN	\N	\N	\N	\N	435	\N	\N
453	MEMBREPOL	2000-05-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	436	\N	2017-09-24 18:05:41
454	MEMBREPOL	2000-04-29 00:00:00	2000-05-17 00:00:00	ANCIEN	\N	\N	\N	\N	437	\N	\N
455	MEMBREPOL	2000-05-17 00:00:00	2001-08-29 00:00:00	ANCIEN	\N	\N	\N	\N	438	\N	\N
456	MEMBREPOL	2001-01-17 00:00:00	2001-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	439	\N	\N
457	MEMBREPOL	2001-01-18 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	440	\N	\N
458	MEMBREPOL	2001-02-08 00:00:00	2001-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	441	\N	\N
459	MEMBREPOL	2001-02-13 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	442	\N	\N
460	MEMBREPOL	2001-03-03 00:00:00	2001-03-19 00:00:00	ANCIEN	\N	\N	\N	\N	443	\N	\N
500	MEMBREPOL	2001-03-20 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	502	\N	2017-05-16 15:18:13
502	MEMBREPOL	2001-03-28 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	504	\N	\N
504	PDTPOL	2001-04-03 00:00:00	2012-09-18 00:00:00	ANCIEN	\N	\N	\N	\N	183	\N	\N
505	MEMBREPOL	2001-04-04 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	\N	263	\N	\N
506	MEMBREPOL	2001-08-29 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	506	\N	\N
507	MEMBREPOL	2001-08-23 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	507	\N	\N
508	MEMBREPOL	2001-09-04 00:00:00	2005-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	509	\N	\N
511	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	512	\N	\N
512	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	513	\N	\N
513	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	514	\N	\N
514	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	515	\N	\N
515	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	516	\N	\N
516	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	517	\N	\N
517	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	518	\N	\N
518	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	519	\N	\N
519	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	520	\N	\N
520	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	521	\N	\N
521	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	522	\N	\N
522	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	523	\N	\N
523	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	524	\N	\N
524	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	525	\N	\N
525	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	526	\N	\N
526	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	527	\N	\N
527	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	528	\N	\N
528	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	529	\N	\N
529	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	530	\N	\N
530	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	531	\N	\N
531	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	532	\N	\N
532	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	533	\N	\N
533	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	534	\N	\N
534	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	535	\N	\N
535	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	536	\N	\N
536	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	537	\N	\N
537	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	538	\N	\N
538	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	539	\N	\N
539	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	540	\N	\N
540	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	541	\N	\N
541	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	542	\N	\N
542	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	543	\N	\N
543	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	544	\N	\N
544	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	545	\N	\N
545	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	546	\N	\N
546	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	547	\N	\N
1	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	1	\N	\N
2	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	2	\N	\N
3	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3	\N	\N
4	MEMBREPOL	1998-10-05 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	4	\N	\N
5	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5	\N	\N
6	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6	\N	\N
7	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	7	\N	\N
9	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	9	\N	\N
10	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	10	\N	\N
11	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11	\N	\N
12	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	12	\N	\N
13	MEMBREPOL	\N	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	\N	13	\N	\N
14	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	14	\N	\N
15	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	15	\N	\N
16	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	16	\N	\N
17	PDTPOL	\N	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	17	\N	\N
19	MEMBREPOL	\N	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	19	\N	\N
20	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	20	\N	\N
21	MEMBREPOL	\N	2006-08-11 00:00:00	ANCIEN	\N	\N	\N	\N	21	\N	\N
22	MEMBREPOL	1980-10-02 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22	\N	\N
24	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	24	\N	\N
25	MEMBREPOL	\N	2008-09-07 00:00:00	ANCIEN	\N	\N	\N	\N	25	\N	\N
26	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26	\N	\N
27	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	27	\N	\N
28	MEMBREPOL	2004-10-05 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	28	\N	\N
30	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	30	\N	\N
31	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	31	\N	\N
32	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	32	\N	\N
33	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	33	\N	\N
34	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	34	\N	\N
35	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	35	\N	\N
36	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	36	\N	\N
37	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	37	\N	\N
38	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	38	\N	\N
40	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	40	\N	\N
41	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	41	\N	\N
42	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	42	\N	\N
43	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	43	\N	\N
44	VICPDTDELPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	44	\N	\N
45	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	45	\N	\N
47	MEMBREPOL	\N	2001-09-20 00:00:00	ANCIEN	\N	\N	\N	\N	47	\N	\N
48	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	48	\N	\N
49	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	49	\N	\N
50	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	50	\N	\N
51	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	51	\N	\N
52	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	52	\N	\N
680	MEMBREPOL	2002-12-11 00:00:00	2020-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	684	\N	\N
681	PDTPOL	2002-12-11 00:00:00	2008-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	685	\N	\N
682	MEMBREPOL	2002-12-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	686	\N	2017-09-24 18:16:52
683	MEMBREPOL	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	687	\N	\N
684	MEMBREPOL	2002-12-11 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	688	\N	2015-01-08 17:14:29
685	MEMBREPOL	2002-12-11 00:00:00	2007-02-25 00:00:00	ANCIEN	\N	\N	\N	\N	689	\N	\N
686	MEMBREPOL	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	690	\N	\N
687	MEMBREPOL	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	691	\N	\N
688	MEMBREPOL	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	692	\N	\N
689	MEMBREPOL	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	693	\N	\N
690	MEMBREPOL	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	694	\N	\N
691	MEMBREPOL	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	695	\N	\N
693	MEMBREPOL	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	697	\N	\N
694	MEMBREPOL	2002-12-11 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	698	\N	\N
695	MEMBREPOL	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	699	\N	\N
696	MEMBREPOL	2002-12-11 00:00:00	2003-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	700	\N	\N
697	MEMBREPOL	2002-12-11 00:00:00	2008-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	701	\N	\N
698	MEMBREPOL	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	702	\N	\N
699	MEMBREPOL	2002-12-11 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	703	\N	2014-09-28 18:00:58
1179	MEMBREPOL	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	919	\N	\N
1180	MEMBREPOL	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	920	\N	\N
1181	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	921	\N	\N
1182	MEMBREPOL	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	922	\N	\N
1183	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	923	\N	\N
1184	MEMBREPOL	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	924	\N	\N
1185	MEMBREPOL	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	925	\N	\N
1186	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	926	\N	\N
1187	MEMBREPOL	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	927	\N	\N
1188	MEMBREPOL	\N	1995-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	928	\N	\N
1189	MEMBREPOL	\N	1974-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	929	\N	\N
1190	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	930	\N	\N
1191	MEMBREPOL	\N	1962-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	931	\N	\N
1192	MEMBREPOL	\N	1969-08-22 00:00:00	ANCIEN	\N	\N	\N	\N	932	\N	\N
1193	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	933	\N	\N
1195	MEMBREPOL	\N	1962-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	935	\N	\N
1196	MEMBREPOL	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	936	\N	\N
1197	MEMBREPOL	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	937	\N	\N
1199	MEMBREPOL	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	939	\N	\N
1200	MEMBREPOL	\N	1959-07-14 00:00:00	ANCIEN	\N	\N	\N	\N	940	\N	\N
1201	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	941	\N	\N
1202	MEMBREPOL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	942	\N	\N
1204	MEMBREPOL	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	944	\N	\N
1205	MEMBREPOL	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	945	\N	\N
1206	MEMBREPOL	\N	1995-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	946	\N	\N
1207	MEMBREPOL	\N	1977-09-25 00:00:00	ANCIEN	\N	\N	\N	\N	947	\N	\N
1209	MEMBREPOL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	949	\N	\N
1210	MEMBREPOL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	950	\N	\N
1211	MEMBREPOL	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	951	\N	\N
1213	MEMBREPOL	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	953	\N	\N
1214	MEMBREPOL	\N	1995-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	954	\N	\N
1215	MEMBREPOL	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	955	\N	\N
1216	MEMBREPOL	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	956	\N	\N
1218	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	958	\N	\N
1219	MEMBREPOL	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	959	\N	\N
1220	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	960	\N	\N
1222	MEMBREPOL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	962	\N	\N
1223	MEMBREPOL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	963	\N	\N
1224	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	964	\N	\N
1225	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	965	\N	\N
1227	MEMBREPOL	\N	1994-09-09 00:00:00	ANCIEN	\N	\N	\N	\N	967	\N	\N
1228	MEMBREPOL	\N	1974-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	968	\N	\N
1229	MEMBREPOL	\N	1995-11-09 00:00:00	ANCIEN	\N	\N	\N	\N	969	\N	\N
1231	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	971	\N	\N
1232	MEMBREPOL	\N	1974-08-26 00:00:00	ANCIEN	\N	\N	\N	\N	972	\N	\N
1233	MEMBREPOL	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	973	\N	\N
1234	MEMBREPOL	\N	1967-03-08 00:00:00	ANCIEN	\N	\N	\N	\N	974	\N	\N
1236	MEMBREPOL	\N	1979-06-11 00:00:00	ANCIEN	\N	\N	\N	\N	976	\N	\N
1237	MEMBREPOL	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	977	\N	\N
1238	MEMBREPOL	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	978	\N	\N
1239	MEMBREPOL	\N	1972-09-14 00:00:00	ANCIEN	\N	\N	\N	\N	979	\N	\N
1240	MEMBREPOL	\N	1962-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	980	\N	\N
1241	MEMBREPOL	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	981	\N	\N
1242	MEMBREPOL	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	982	\N	\N
1243	MEMBREPOL	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	983	\N	\N
1244	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	984	\N	\N
1245	MEMBREPOL	\N	1981-04-23 00:00:00	ANCIEN	\N	\N	\N	\N	985	\N	\N
1246	MEMBREPOL	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	986	\N	\N
1247	MEMBREPOL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	987	\N	\N
1248	MEMBREPOL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	988	\N	\N
1249	MEMBREPOL	\N	1967-08-03 00:00:00	ANCIEN	\N	\N	\N	\N	989	\N	\N
1250	MEMBREPOL	\N	1978-08-29 00:00:00	ANCIEN	\N	\N	\N	\N	990	\N	\N
1251	MEMBREPOL	\N	1988-05-13 00:00:00	ANCIEN	\N	\N	\N	\N	991	\N	\N
1252	MEMBREPOL	\N	1976-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	992	\N	\N
1253	MEMBREPOL	\N	1994-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	993	\N	\N
1254	MEMBREPOL	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	994	\N	\N
1255	MEMBREPOL	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	995	\N	\N
1256	MEMBREPOL	\N	1962-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	996	\N	\N
1257	MEMBREPOL	\N	1996-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	997	\N	\N
1258	MEMBREPOL	\N	1968-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	998	\N	\N
1259	MEMBREPOL	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	999	\N	\N
1260	MEMBREPOL	\N	1977-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1000	\N	\N
1261	MEMBREPOL	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1001	\N	\N
1262	MEMBREPOL	\N	1974-09-20 00:00:00	ANCIEN	\N	\N	\N	\N	1002	\N	\N
1263	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1003	\N	\N
1264	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1004	\N	\N
1265	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1005	\N	\N
1266	MEMBREPOL	\N	1998-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	1006	\N	\N
1267	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1007	\N	\N
1268	MEMBREPOL	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1008	\N	\N
1269	MEMBREPOL	\N	1995-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	1009	\N	\N
1270	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1010	\N	\N
1271	MEMBREPOL	\N	1992-01-06 00:00:00	ANCIEN	\N	\N	\N	\N	1011	\N	\N
1272	MEMBREPOL	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1012	\N	\N
1273	MEMBREPOL	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1013	\N	\N
1274	MEMBREPOL	\N	1978-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1014	\N	\N
1275	MEMBREPOL	\N	1979-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	1015	\N	\N
1276	MEMBREPOL	\N	1974-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	1016	\N	\N
1277	MEMBREPOL	\N	1962-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	1017	\N	\N
1278	MEMBREPOL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1018	\N	\N
1279	MEMBREPOL	\N	1974-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	1019	\N	\N
1280	MEMBREPOL	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1020	\N	\N
1281	MEMBREPOL	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1021	\N	\N
1282	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1022	\N	\N
1283	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1023	\N	\N
1284	MEMBREPOL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1024	\N	\N
1285	MEMBREPOL	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1025	\N	\N
1286	MEMBREPOL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1026	\N	\N
1287	MEMBREPOL	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1027	\N	\N
1288	MEMBREPOL	\N	1997-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	1028	\N	\N
1289	MEMBREPOL	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1029	\N	\N
1290	MEMBREPOL	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1030	\N	\N
1291	MEMBREPOL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1031	\N	\N
1292	MEMBREPOL	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1032	\N	\N
1293	MEMBREPOL	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1033	\N	\N
1295	MEMBREPOL	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1035	\N	\N
1296	MEMBREPOL	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1036	\N	\N
1297	MEMBREPOL	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1037	\N	\N
1299	MEMBREPOL	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1039	\N	\N
1300	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1040	\N	\N
1301	MEMBREPOL	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	1041	\N	\N
1302	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1042	\N	\N
1304	MEMBREPOL	\N	1988-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	1044	\N	\N
1305	MEMBREPOL	\N	1983-03-28 00:00:00	ANCIEN	\N	\N	\N	\N	1045	\N	\N
1306	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1046	\N	\N
1307	MEMBREPOL	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1047	\N	\N
1309	MEMBREPOL	\N	1981-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	1049	\N	\N
1310	MEMBREPOL	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1050	\N	\N
1311	MEMBREPOL	\N	1988-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	1051	\N	\N
1313	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1053	\N	\N
1314	MEMBREPOL	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1054	\N	\N
1315	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1055	\N	\N
1316	MEMBREPOL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1056	\N	\N
1318	MEMBREPOL	\N	1971-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	1058	\N	\N
1319	MEMBREPOL	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1059	\N	\N
1320	MEMBREPOL	\N	1962-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1060	\N	\N
1322	MEMBREPOL	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1062	\N	\N
1323	MEMBREPOL	\N	1988-03-30 00:00:00	ANCIEN	\N	\N	\N	\N	1063	\N	\N
1324	MEMBREPOL	\N	1988-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	1064	\N	\N
1325	MEMBREPOL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1065	\N	\N
1327	MEMBREPOL	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	1067	\N	\N
1328	MEMBREPOL	\N	1962-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1068	\N	\N
1329	MEMBREPOL	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1069	\N	\N
1331	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1071	\N	\N
1332	MEMBREPOL	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1072	\N	\N
1333	MEMBREPOL	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1073	\N	\N
1334	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1074	\N	\N
1336	MEMBREPOL	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1076	\N	\N
1337	MEMBREPOL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1077	\N	\N
1338	MEMBREPOL	\N	1997-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	1078	\N	\N
1339	MEMBREPOL	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1079	\N	\N
1340	MEMBREPOL	\N	1995-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	1080	\N	\N
1341	MEMBREPOL	\N	1992-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	1081	\N	\N
1342	MEMBREPOL	\N	1980-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	1082	\N	\N
1343	MEMBREPOL	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1083	\N	\N
1344	MEMBREPOL	\N	1962-10-31 00:00:00	ANCIEN	\N	\N	\N	\N	1084	\N	\N
1345	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1085	\N	\N
1346	MEMBREPOL	\N	1972-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	1086	\N	\N
1347	MEMBREPOL	\N	1996-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	1087	\N	\N
1348	MEMBREPOL	\N	1978-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	1088	\N	\N
1349	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1089	\N	\N
1350	MEMBREPOL	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1090	\N	\N
1351	MEMBREPOL	\N	1995-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	1091	\N	\N
1352	MEMBREPOL	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1092	\N	\N
700	MEMBREPOL	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	704	\N	\N
701	MEMBREPOL	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	705	\N	\N
703	MEMBREPOL	2002-12-11 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	707	\N	2014-09-28 17:09:16
704	MEMBREPOL	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	708	\N	\N
705	MEMBREPOL	2002-12-11 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	709	\N	\N
706	MEMBREPOL	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	710	\N	\N
707	MEMBREPOL	2002-12-11 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	711	\N	2014-09-28 17:35:38
708	MEMBREPOL	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	712	\N	\N
709	MEMBREPOL	2002-12-11 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	713	\N	2014-09-28 12:52:11
710	MEMBREPOL	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	714	\N	\N
711	MEMBREPOL	2002-12-11 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	715	\N	\N
712	MEMBREPOL	2002-12-11 00:00:00	2011-10-30 00:00:00	ANCIEN	\N	\N	\N	\N	716	\N	\N
713	MEMBREPOL	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	717	\N	\N
714	MEMBREPOL	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	718	\N	\N
715	MEMBREPOL	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	719	\N	\N
716	MEMBREPOL	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	720	\N	\N
717	MEMBREPOL	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	721	\N	\N
718	MEMBREPOL	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	722	\N	\N
719	MEMBREPOL	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	723	\N	\N
720	MEMBREPOL	2002-12-11 00:00:00	2018-12-30 00:00:00	ANCIEN	\N	\N	\N	\N	724	\N	\N
721	MEMBREPOL	2002-12-11 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	725	\N	2014-09-28 17:15:42
722	MEMBREPOL	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	726	\N	\N
723	MEMBREPOL	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	727	\N	\N
724	MEMBREPOL	2002-12-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	728	\N	2017-10-01 10:01:39
725	MEMBREPOL	2002-12-11 00:00:00	2008-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	729	\N	\N
726	MEMBREPOL	2002-12-11 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	730	\N	\N
727	MEMBREPOL	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	731	\N	\N
728	MEMBREPOL	2002-12-11 00:00:00	2005-03-19 00:00:00	ANCIEN	\N	\N	\N	\N	732	\N	\N
729	MEMBREPOL	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	733	\N	\N
730	MEMBREPOL	2002-12-11 00:00:00	2003-01-14 00:00:00	ANCIEN	\N	\N	\N	\N	734	\N	\N
731	MEMBREPOL	2002-12-11 00:00:00	2018-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	735	\N	\N
733	MEMBREPOL	2002-12-11 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	737	\N	\N
734	MEMBREPOL	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	738	\N	\N
735	MEMBREPOL	2002-12-11 00:00:00	2007-06-24 00:00:00	ANCIEN	\N	\N	\N	\N	739	\N	\N
736	MEMBREPOL	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	740	\N	\N
737	MEMBREPOL	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	741	\N	\N
738	MEMBREPOL	2002-12-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	742	\N	2017-09-24 13:44:49
739	MEMBREPOL	2002-12-11 00:00:00	2011-10-30 00:00:00	ANCIEN	\N	\N	\N	\N	743	\N	\N
740	MEMBREPOL	2002-12-11 00:00:00	2003-01-14 00:00:00	ANCIEN	\N	\N	\N	\N	744	\N	\N
742	MEMBREPOL	2002-12-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	746	\N	\N
743	MEMBREPOL	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	747	\N	\N
744	MEMBREPOL	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	748	\N	\N
745	MEMBREPOL	2002-12-11 00:00:00	2015-04-21 00:00:00	ANCIEN	\N	\N	\N	\N	749	\N	2015-04-21 17:14:30
746	MEMBREPOL	2002-12-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	750	\N	2017-09-24 17:48:21
747	MEMBREPOL	2002-12-11 00:00:00	2003-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	751	\N	\N
748	MEMBREPOL	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	752	\N	\N
749	MEMBREPOL	2002-12-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	753	\N	\N
750	MEMBREPOL	2002-12-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	754	\N	2017-09-24 17:04:02
751	MEMBREPOL	2002-12-11 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	755	\N	2014-09-29 13:41:53
140	MEMBREPOL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	140	\N	\N
141	MEMBREPOL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	141	\N	\N
142	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	142	\N	\N
143	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	143	\N	\N
144	MEMBREPOL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	144	\N	\N
145	MEMBREPOL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	145	\N	\N
146	MEMBREPOL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	146	\N	\N
147	MEMBREPOL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	147	\N	\N
148	MEMBREPOL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	148	\N	\N
149	MEMBREPOL	\N	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	149	\N	\N
150	MEMBREPOL	\N	2001-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	150	\N	\N
151	MEMBREPOL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	151	\N	\N
152	MEMBREPOL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	152	\N	\N
153	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	153	\N	\N
154	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	154	\N	\N
155	MEMBREPOL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	155	\N	\N
156	MEMBREPOL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	156	\N	\N
157	MEMBREPOL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	157	\N	\N
158	PDTPOL	1993-04-06 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	158	\N	\N
159	MEMBREPOL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	159	\N	\N
160	MEMBREPOL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	160	\N	\N
161	MEMBREPOL	\N	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	\N	161	\N	\N
162	MEMBREPOL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	162	\N	\N
163	MEMBREPOL	1996-09-10 00:00:00	2014-09-01 00:00:00	ANCIEN	\N	\N	\N	\N	163	\N	2014-09-01 10:21:13
164	MEMBREPOL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	164	\N	\N
165	MEMBREPOL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	165	\N	\N
166	MEMBREPOL	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	166	\N	\N
167	MEMBREPOL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	167	\N	\N
168	MEMBREPOL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	168	\N	\N
169	MEMBREPOL	\N	2002-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	169	\N	\N
171	MEMBREPOL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	171	\N	\N
172	MEMBREPOL	\N	1999-10-16 00:00:00	ANCIEN	\N	\N	\N	\N	172	\N	\N
173	MEMBREPOL	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	173	\N	\N
174	MEMBREPOL	\N	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	174	\N	2017-09-24 18:16:52
175	MEMBREPOL	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	175	\N	\N
176	MEMBREPOL	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	176	\N	\N
177	MEMBREPOL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	177	\N	\N
178	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	178	\N	\N
179	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	179	\N	\N
180	MEMBREPOL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	180	\N	\N
181	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	181	\N	\N
182	MEMBREPOL	\N	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	182	\N	\N
183	MEMBREPOL	1995-10-02 00:00:00	2001-04-02 00:00:00	ANCIEN	\N	\N	\N	\N	183	\N	\N
185	PDTPOL	1988-07-05 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	185	\N	\N
186	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	186	\N	\N
1124	MEMBREPOL	\N	1971-02-25 00:00:00	ANCIEN	\N	\N	\N	\N	864	\N	\N
1125	MEMBREPOL	\N	1993-08-27 00:00:00	ANCIEN	\N	\N	\N	\N	865	\N	\N
1126	MEMBREPOL	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	866	\N	\N
1127	MEMBREPOL	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	867	\N	\N
1128	MEMBREPOL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	868	\N	\N
1129	MEMBREPOL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	869	\N	\N
1130	MEMBREPOL	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	870	\N	\N
1131	MEMBREPOL	\N	1973-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	871	\N	\N
1132	MEMBREPOL	\N	1981-01-03 00:00:00	ANCIEN	\N	\N	\N	\N	872	\N	\N
1133	MEMBREPOL	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	873	\N	\N
1134	MEMBREPOL	\N	1969-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	874	\N	\N
1135	MEMBREPOL	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	875	\N	\N
1136	MEMBREPOL	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	876	\N	\N
1137	MEMBREPOL	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	877	\N	\N
1138	MEMBREPOL	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	878	\N	\N
1139	MEMBREPOL	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	879	\N	\N
1140	MEMBREPOL	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	880	\N	\N
1141	MEMBREPOL	\N	1961-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	881	\N	\N
1142	MEMBREPOL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	882	\N	\N
1143	MEMBREPOL	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	883	\N	\N
1144	MEMBREPOL	\N	1988-06-24 00:00:00	ANCIEN	\N	\N	\N	\N	884	\N	\N
1145	MEMBREPOL	\N	1967-04-03 00:00:00	ANCIEN	\N	\N	\N	\N	885	\N	\N
1146	MEMBREPOL	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	886	\N	\N
1147	MEMBREPOL	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	887	\N	\N
1148	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	888	\N	\N
1149	MEMBREPOL	\N	1973-09-20 00:00:00	ANCIEN	\N	\N	\N	\N	889	\N	\N
1150	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	890	\N	\N
1151	MEMBREPOL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	891	\N	\N
1152	MEMBREPOL	\N	1961-09-19 00:00:00	ANCIEN	\N	\N	\N	\N	892	\N	\N
1153	MEMBREPOL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	893	\N	\N
1154	MEMBREPOL	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	894	\N	\N
1155	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	895	\N	\N
1156	MEMBREPOL	\N	1997-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	896	\N	\N
1157	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	897	\N	\N
1158	MEMBREPOL	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	898	\N	\N
1159	MEMBREPOL	\N	1971-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	899	\N	\N
1160	MEMBREPOL	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	900	\N	\N
1161	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	901	\N	\N
1162	MEMBREPOL	\N	1998-02-25 00:00:00	ANCIEN	\N	\N	\N	\N	902	\N	\N
1163	MEMBREPOL	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	903	\N	\N
1164	MEMBREPOL	\N	1973-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	904	\N	\N
1165	MEMBREPOL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	905	\N	\N
1166	MEMBREPOL	\N	1975-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	906	\N	\N
1167	MEMBREPOL	\N	1990-04-11 00:00:00	ANCIEN	\N	\N	\N	\N	907	\N	\N
1168	MEMBREPOL	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	908	\N	\N
1169	MEMBREPOL	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	909	\N	\N
1170	MEMBREPOL	\N	1967-04-03 00:00:00	ANCIEN	\N	\N	\N	\N	910	\N	\N
1171	MEMBREPOL	\N	1992-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	911	\N	\N
1172	MEMBREPOL	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	912	\N	\N
1173	MEMBREPOL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	913	\N	\N
1174	MEMBREPOL	\N	1986-09-09 00:00:00	ANCIEN	\N	\N	\N	\N	914	\N	\N
1175	MEMBREPOL	\N	1986-04-02 00:00:00	ANCIEN	\N	\N	\N	\N	915	\N	\N
1176	MEMBREPOL	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	916	\N	\N
1177	MEMBREPOL	\N	1973-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	917	\N	\N
1178	MEMBREPOL	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	918	\N	\N
53	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	53	\N	\N
54	MEMBREPOL	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	54	\N	\N
55	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	55	\N	\N
57	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	57	\N	\N
58	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	58	\N	\N
59	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	59	\N	\N
60	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	60	\N	\N
61	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	61	\N	\N
62	MEMBREPOL	1989-10-02 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	62	\N	2014-09-28 16:50:17
63	MEMBREPOL	1996-09-04 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	63	\N	2014-09-28 16:50:17
65	MEMBREPOL	\N	2001-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	65	\N	\N
66	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	66	\N	\N
67	MEMBREPOL	\N	2000-04-27 00:00:00	ANCIEN	\N	\N	\N	\N	67	\N	\N
68	MEMBREPOL	\N	2000-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	68	\N	\N
69	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	69	\N	\N
70	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	70	\N	\N
72	MEMBREPOL	\N	2001-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	72	\N	\N
73	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	73	\N	\N
74	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	74	\N	\N
75	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	75	\N	\N
76	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	76	\N	\N
77	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77	\N	\N
78	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	78	\N	\N
79	MEMBREPOL	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	79	\N	\N
80	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80	\N	\N
82	MEMBREPOL	1980-10-02 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	82	\N	\N
83	MEMBREPOL	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83	\N	\N
84	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	84	\N	\N
85	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	85	\N	\N
86	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86	\N	\N
87	MEMBREPOL	\N	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	87	\N	\N
88	MEMBREPOL	1980-09-28 00:00:00	2019-08-27 00:00:00	ANCIEN	\N	\N	\N	\N	88	\N	\N
89	MEMBREPOL	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89	\N	\N
90	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	90	\N	\N
92	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	92	\N	\N
94	MEMBREPOL	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	94	\N	\N
95	MEMBREPOL	\N	1998-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	95	\N	\N
96	PDTPOL	\N	1999-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	96	\N	\N
97	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	97	\N	\N
99	MEMBREPOL	\N	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	99	\N	\N
100	MEMBREPOL	\N	2005-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	100	\N	\N
101	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	101	\N	\N
102	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	102	\N	\N
103	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	103	\N	\N
104	MEMBREPOL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	104	\N	\N
105	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	105	\N	\N
106	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	106	\N	\N
107	MEMBREPOL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	107	\N	\N
109	MEMBREPOL	\N	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	109	\N	\N
110	PDTPOL	1995-04-05 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	110	\N	\N
111	MEMBREPOL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	111	\N	\N
112	MEMBREPOL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	112	\N	\N
113	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	113	\N	\N
114	MEMBREPOL	\N	2001-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	114	\N	\N
115	MEMBREPOL	\N	2001-08-22 00:00:00	ANCIEN	\N	\N	\N	\N	115	\N	\N
117	MEMBREPOL	1992-10-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	117	\N	2017-09-24 13:14:55
118	MEMBREPOL	\N	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	118	\N	\N
119	MEMBREPOL	\N	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	119	\N	\N
120	MEMBREPOL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	120	\N	\N
121	MEMBREPOL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	121	\N	\N
122	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	122	\N	\N
123	MEMBREPOL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	123	\N	\N
125	MEMBREPOL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	125	\N	\N
126	MEMBREPOL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	126	\N	\N
128	MEMBREPOL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	128	\N	\N
129	MEMBREPOL	\N	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	129	\N	\N
130	MEMBREPOL	\N	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	130	\N	\N
131	MEMBREPOL	\N	2000-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	131	\N	\N
132	MEMBREPOL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	132	\N	\N
133	MEMBREPOL	\N	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	133	\N	2017-06-29 09:54:43
134	MEMBREPOL	\N	2008-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	134	\N	\N
135	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	135	\N	\N
136	MEMBREPOL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	136	\N	\N
137	MEMBREPOL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	137	\N	\N
138	MEMBREPOL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	138	\N	\N
139	MEMBREPOL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	139	\N	\N
188	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	188	\N	\N
189	MEMBREPOL	\N	2001-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	189	\N	\N
190	MEMBREPOL	\N	2002-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	190	\N	\N
192	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	192	\N	\N
193	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	193	\N	\N
194	MEMBREPOL	\N	2000-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	194	\N	\N
195	MEMBREPOL	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	195	\N	\N
197	MEMBREPOL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	197	\N	\N
198	MEMBREPOL	\N	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	198	\N	\N
199	MEMBREPOL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	199	\N	\N
200	MEMBREPOL	1983-10-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	200	\N	2017-09-24 17:42:26
201	MEMBREPOL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	201	\N	\N
202	MEMBREPOL	\N	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	202	\N	\N
203	MEMBREPOL	\N	2008-06-03 00:00:00	ANCIEN	\N	\N	\N	\N	203	\N	\N
205	MEMBREPOL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	205	\N	\N
206	MEMBREPOL	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	206	\N	\N
207	MEMBREPOL	1992-10-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	207	\N	2017-09-24 12:39:59
208	MEMBREPOL	\N	2001-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	208	\N	\N
209	MEMBREPOL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	209	\N	\N
210	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	210	\N	\N
212	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	212	\N	\N
213	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	213	\N	\N
214	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	214	\N	\N
215	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	215	\N	\N
216	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	216	\N	\N
217	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	217	\N	\N
218	MEMBREPOL	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	218	\N	\N
219	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	219	\N	\N
220	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	220	\N	\N
221	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	221	\N	\N
222	MEMBREPOL	\N	1999-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	222	\N	\N
223	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	223	\N	\N
224	MEMBREPOL	1995-10-02 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	224	\N	2014-09-28 17:07:41
225	MEMBREPOL	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	225	\N	\N
226	MEMBREPOL	\N	2002-06-18 00:00:00	ANCIEN	\N	\N	\N	\N	226	\N	\N
227	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	227	\N	\N
228	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	228	\N	\N
230	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	230	\N	\N
231	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	231	\N	\N
232	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	232	\N	\N
233	MEMBREPOL	\N	1999-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	233	\N	\N
234	MEMBREPOL	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	234	\N	\N
235	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	235	\N	\N
236	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	236	\N	\N
237	MEMBREPOL	1995-10-02 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	237	\N	2014-09-28 17:40:23
239	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	239	\N	\N
241	MEMBREPOL	1995-07-06 00:00:00	2013-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	241	\N	\N
242	MEMBREPOL	\N	1998-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	242	\N	\N
243	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	243	\N	\N
244	MEMBREPOL	\N	1999-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	244	\N	\N
245	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	245	\N	\N
246	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	246	\N	\N
247	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	247	\N	\N
248	MEMBREPOL	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	248	\N	\N
249	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	249	\N	\N
250	MEMBREPOL	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	250	\N	\N
252	MEMBREPOL	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	252	\N	\N
253	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	253	\N	\N
254	MEMBREPOL	\N	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	254	\N	\N
256	MEMBREPOL	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	256	\N	\N
257	MEMBREPOL	1995-10-02 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	257	\N	2014-09-28 17:09:16
258	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	258	\N	\N
259	MEMBREPOL	\N	1998-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	259	\N	\N
260	MEMBREPOL	1995-10-02 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	260	\N	2014-09-28 13:39:20
261	MEMBREPOL	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	261	\N	2014-09-28 19:03:04
262	MEMBREPOL	\N	2008-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	262	\N	\N
264	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	264	\N	\N
265	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	265	\N	\N
266	MEMBREPOL	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	266	\N	\N
267	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	267	\N	\N
268	MEMBREPOL	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	268	\N	\N
269	MEMBREPOL	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	269	\N	\N
270	MEMBREPOL	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	270	\N	\N
271	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	271	\N	\N
272	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	272	\N	\N
273	MEMBREPOL	\N	2002-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	273	\N	\N
274	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	274	\N	\N
275	MEMBREPOL	1986-09-28 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	275	\N	\N
276	MEMBREPOL	1995-10-01 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	276	\N	2017-06-29 09:54:19
277	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	277	\N	\N
2408	MEMBREPOL	2011-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2130	\N	2017-10-03 16:59:24
2409	MEMBREPOL	2011-10-01 00:00:00	2017-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	2131	\N	2017-07-17 11:07:22
2410	MEMBREPOL	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2132	\N	2017-09-24 17:09:24
2411	MEMBREPOL	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2133	\N	2017-09-24 17:35:15
2412	MEMBREPOL	2011-10-01 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	2134	\N	2017-06-29 09:55:44
2685	MEMBREPOL	2009-09-10 00:00:00	2009-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	2365	\N	\N
2544	MEMBREPOL	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2270	\N	\N
2545	MEMBREPOL	2011-10-01 00:00:00	2014-05-11 00:00:00	ANCIEN	\N	\N	\N	\N	2271	\N	2014-05-12 09:51:40
2687	MEMBREPOL	2011-10-01 00:00:00	2011-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	2367	\N	\N
2688	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	2368	\N	\N
2689	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	2369	\N	\N
2562	MEMBREPOL	2011-10-01 00:00:00	2018-10-15 00:00:00	ANCIEN	\N	\N	\N	\N	2288	\N	\N
2566	MEMBREPOL	2011-10-01 00:00:00	2012-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	2292	\N	\N
2567	MEMBREPOL	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2293	\N	\N
2568	MEMBREPOL	2011-10-01 00:00:00	2011-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	2294	\N	\N
2569	MEMBREPOL	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2295	\N	\N
2570	MEMBREPOL	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2296	\N	2017-09-24 17:55:12
2571	MEMBREPOL	2011-10-01 00:00:00	2012-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	2297	\N	\N
2572	MEMBREPOL	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2298	\N	\N
2573	MEMBREPOL	2011-10-01 00:00:00	2012-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	2299	\N	\N
2417	MEMBREPOL	2011-10-01 00:00:00	2012-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	3019	\N	\N
2618	MEMBREPOL	2011-10-01 00:00:00	2017-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	598	\N	2017-07-24 09:56:26
2620	MEMBREPOL	2011-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1738	\N	\N
2420	MEMBREPOL	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2146	\N	\N
2421	MEMBREPOL	2011-10-01 00:00:00	2015-06-09 00:00:00	ANCIEN	\N	\N	\N	\N	2147	\N	2015-06-11 18:55:21
2674	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	2353	\N	\N
2423	MEMBREPOL	2011-10-01 00:00:00	2013-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	2149	\N	2013-10-22 16:15:00
2691	MEMBREPOL	2012-03-19 00:00:00	2020-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	2371	\N	\N
2428	MEMBREPOL	2011-10-01 00:00:00	2020-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	2154	\N	\N
2429	MEMBREPOL	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2155	\N	2017-09-24 18:16:52
2430	MEMBREPOL	2011-10-01 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	2156	\N	2017-06-29 09:53:19
2431	MEMBREPOL	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2157	\N	2017-09-24 18:16:52
2433	MEMBREPOL	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2159	\N	2017-09-24 18:16:52
2435	MEMBREPOL	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2161	\N	\N
2439	MEMBREPOL	2011-10-01 00:00:00	2012-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	2165	\N	\N
2441	MEMBREPOL	2011-10-01 00:00:00	2013-09-10 00:00:00	ANCIEN	\N	\N	\N	\N	2167	\N	2013-09-11 15:01:59
2444	MEMBREPOL	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2170	\N	2017-09-24 13:25:54
2445	MEMBREPOL	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2171	\N	2017-09-24 13:25:54
2446	MEMBREPOL	2011-10-01 00:00:00	2011-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	2172	\N	\N
2448	MEMBREPOL	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2174	\N	2017-09-24 17:14:26
2449	MEMBREPOL	2011-10-01 00:00:00	2012-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	2175	\N	\N
2450	MEMBREPOL	2011-10-04 00:00:00	2011-12-22 00:00:00	ANCIEN	\N	\N	\N	\N	2176	\N	\N
2453	MEMBREPOL	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2179	\N	\N
2456	MEMBREPOL	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2182	\N	\N
752	MEMBREPOL	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	756	\N	\N
753	MEMBREPOL	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	757	\N	\N
754	MEMBREPOL	2002-12-11 00:00:00	2002-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	758	\N	\N
755	MEMBREPOL	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	759	\N	\N
124	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	124	\N	\N
170	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	170	\N	\N
187	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	187	\N	\N
204	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	204	\N	\N
756	MEMBREPOL	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	760	\N	\N
757	MEMBREPOL	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	761	\N	\N
758	MEMBREPOL	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	762	\N	\N
759	MEMBREPOL	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	763	\N	\N
760	MEMBREPOL	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	764	\N	\N
761	MEMBREPOL	2002-12-11 00:00:00	2011-10-30 00:00:00	ANCIEN	\N	\N	\N	\N	765	\N	\N
762	MEMBREPOL	2002-12-11 00:00:00	2004-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	766	\N	\N
763	MEMBREPOL	2002-12-11 00:00:00	2004-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	767	\N	\N
764	MEMBREPOL	2002-12-11 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	768	\N	\N
765	MEMBREPOL	2002-12-11 00:00:00	2014-06-10 00:00:00	ANCIEN	\N	\N	\N	\N	769	\N	2014-06-11 18:22:49
766	MEMBREPOL	2002-12-11 00:00:00	2022-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	770	\N	\N
767	MEMBREPOL	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	771	\N	\N
768	MEMBREPOL	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	772	\N	\N
769	MEMBREPOL	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	773	\N	\N
770	MEMBREPOL	2002-12-11 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	774	\N	2014-09-28 18:58:21
771	MEMBREPOL	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	775	\N	\N
772	MEMBREPOL	2002-12-11 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	776	\N	2014-09-28 16:59:41
773	MEMBREPOL	2002-12-11 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	777	\N	2014-09-28 16:59:41
774	MEMBREPOL	2002-12-11 00:00:00	2018-08-06 00:00:00	ANCIEN	\N	\N	\N	\N	778	\N	\N
775	MEMBREPOL	2002-12-11 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	779	\N	\N
776	MEMBREPOL	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	780	\N	\N
777	MEMBREPOL	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	781	\N	\N
778	MEMBREPOL	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	782	\N	\N
779	MEMBREPOL	2002-12-11 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	783	\N	2014-09-28 18:03:38
780	VICPDTDELPOL	2002-12-11 00:00:00	2008-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	784	\N	\N
781	MEMBREPOL	2002-12-11 00:00:00	2011-03-07 00:00:00	ANCIEN	\N	\N	\N	\N	785	\N	\N
1650	MEMBREPOL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1390	\N	\N
1651	MEMBREPOL	\N	1984-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	1391	\N	\N
1652	MEMBREPOL	\N	1981-09-09 00:00:00	ANCIEN	\N	\N	\N	\N	1392	\N	\N
1653	MEMBREPOL	\N	1996-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	1393	\N	\N
1654	MEMBREPOL	\N	1983-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	1394	\N	\N
1655	MEMBREPOL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1395	\N	\N
1656	MEMBREPOL	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1396	\N	\N
1657	MEMBREPOL	\N	1982-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	1397	\N	\N
1658	MEMBREPOL	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1398	\N	\N
1659	MEMBREPOL	\N	1988-05-10 00:00:00	ANCIEN	\N	\N	\N	\N	1399	\N	\N
1660	MEMBREPOL	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1400	\N	\N
1661	MEMBREPOL	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1401	\N	\N
1662	MEMBREPOL	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1402	\N	\N
1663	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1403	\N	\N
1664	MEMBREPOL	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1404	\N	\N
1665	MEMBREPOL	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1405	\N	\N
1666	MEMBREPOL	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1406	\N	\N
1667	MEMBREPOL	\N	1974-10-19 00:00:00	ANCIEN	\N	\N	\N	\N	1407	\N	\N
1668	MEMBREPOL	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1408	\N	\N
1669	MEMBREPOL	\N	1980-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	1409	\N	\N
1670	MEMBREPOL	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1410	\N	\N
1671	MEMBREPOL	\N	1975-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	1411	\N	\N
1672	MEMBREPOL	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1412	\N	\N
1673	MEMBREPOL	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1413	\N	\N
1674	MEMBREPOL	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1414	\N	\N
1675	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1415	\N	\N
1676	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1416	\N	\N
1677	MEMBREPOL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1417	\N	\N
1678	MEMBREPOL	\N	1981-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	1418	\N	\N
1679	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1419	\N	\N
1680	MEMBREPOL	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1420	\N	\N
1681	MEMBREPOL	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	1421	\N	\N
1682	MEMBREPOL	\N	1979-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	1422	\N	\N
1683	MEMBREPOL	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1423	\N	\N
1684	MEMBREPOL	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1424	\N	\N
1685	MEMBREPOL	\N	1998-07-14 00:00:00	ANCIEN	\N	\N	\N	\N	1425	\N	\N
1686	MEMBREPOL	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1426	\N	\N
1687	MEMBREPOL	\N	1986-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	1427	\N	\N
1688	MEMBREPOL	\N	1986-07-16 00:00:00	ANCIEN	\N	\N	\N	\N	1428	\N	\N
1689	MEMBREPOL	\N	1960-10-23 00:00:00	ANCIEN	\N	\N	\N	\N	1429	\N	\N
1690	MEMBREPOL	\N	1983-05-10 00:00:00	ANCIEN	\N	\N	\N	\N	1430	\N	\N
1691	MEMBREPOL	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1431	\N	\N
1692	MEMBREPOL	\N	1976-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	1432	\N	\N
1693	MEMBREPOL	\N	1996-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	1433	\N	\N
1695	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1435	\N	\N
1696	MEMBREPOL	\N	1982-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	1436	\N	\N
1697	MEMBREPOL	\N	1979-05-28 00:00:00	ANCIEN	\N	\N	\N	\N	1437	\N	\N
1699	MEMBREPOL	\N	1973-09-09 00:00:00	ANCIEN	\N	\N	\N	\N	1439	\N	\N
1700	MEMBREPOL	\N	1975-12-29 00:00:00	ANCIEN	\N	\N	\N	\N	1440	\N	\N
1701	MEMBREPOL	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1441	\N	\N
1702	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1442	\N	\N
1704	MEMBREPOL	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1444	\N	\N
1705	MEMBREPOL	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1445	\N	\N
1706	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1446	\N	\N
1707	MEMBREPOL	\N	1976-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	1447	\N	\N
1709	MEMBREPOL	\N	1987-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	1449	\N	\N
1710	MEMBREPOL	\N	1988-07-29 00:00:00	ANCIEN	\N	\N	\N	\N	1450	\N	\N
1711	MEMBREPOL	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1451	\N	\N
1713	MEMBREPOL	\N	1995-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	1453	\N	\N
1714	MEMBREPOL	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1454	\N	\N
1715	MEMBREPOL	\N	1979-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	1455	\N	\N
1716	MEMBREPOL	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1456	\N	\N
1718	MEMBREPOL	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1458	\N	\N
1719	MEMBREPOL	\N	1985-09-01 00:00:00	ANCIEN	\N	\N	\N	\N	1459	\N	\N
1720	MEMBREPOL	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1460	\N	\N
1722	MEMBREPOL	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1462	\N	\N
1723	MEMBREPOL	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1463	\N	\N
1724	MEMBREPOL	\N	1967-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	1464	\N	\N
1725	MEMBREPOL	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1465	\N	\N
1727	MEMBREPOL	\N	1966-12-22 00:00:00	ANCIEN	\N	\N	\N	\N	1467	\N	\N
1728	MEMBREPOL	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1468	\N	\N
1729	MEMBREPOL	\N	1959-08-28 00:00:00	ANCIEN	\N	\N	\N	\N	1469	\N	\N
1731	MEMBREPOL	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1471	\N	\N
1732	MEMBREPOL	\N	1970-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	1472	\N	\N
1733	MEMBREPOL	\N	1961-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	1473	\N	\N
1734	MEMBREPOL	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1474	\N	\N
1736	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1476	\N	\N
1737	MEMBREPOL	\N	1962-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	1477	\N	\N
1738	MEMBREPOL	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1478	\N	\N
1739	MEMBREPOL	\N	1979-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	1479	\N	\N
1740	MEMBREPOL	\N	1966-05-26 00:00:00	ANCIEN	\N	\N	\N	\N	1480	\N	\N
1741	MEMBREPOL	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1481	\N	\N
1742	MEMBREPOL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1482	\N	\N
1743	MEMBREPOL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1483	\N	\N
1744	MEMBREPOL	\N	1966-03-09 00:00:00	ANCIEN	\N	\N	\N	\N	1484	\N	\N
1745	MEMBREPOL	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1485	\N	\N
1746	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1486	\N	\N
1747	MEMBREPOL	\N	1976-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	1487	\N	\N
1748	MEMBREPOL	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1488	\N	\N
1749	MEMBREPOL	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1489	\N	\N
1750	MEMBREPOL	\N	1969-01-11 00:00:00	ANCIEN	\N	\N	\N	\N	1490	\N	\N
1751	MEMBREPOL	\N	1966-03-09 00:00:00	ANCIEN	\N	\N	\N	\N	1491	\N	\N
1752	MEMBREPOL	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1492	\N	\N
1753	MEMBREPOL	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1493	\N	\N
1754	MEMBREPOL	\N	1975-04-25 00:00:00	ANCIEN	\N	\N	\N	\N	1494	\N	\N
1755	MEMBREPOL	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1495	\N	\N
1756	MEMBREPOL	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1496	\N	\N
1757	MEMBREPOL	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	1497	\N	\N
1758	MEMBREPOL	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1498	\N	\N
1759	MEMBREPOL	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1499	\N	\N
1760	MEMBREPOL	\N	1968-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	1500	\N	\N
1761	MEMBREPOL	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1501	\N	\N
1763	MEMBREPOL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1503	\N	\N
1764	MEMBREPOL	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1504	\N	\N
1765	MEMBREPOL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1505	\N	\N
1766	MEMBREPOL	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1506	\N	\N
1767	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1507	\N	\N
1768	MEMBREPOL	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1508	\N	\N
1769	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1509	\N	\N
1770	MEMBREPOL	\N	1970-10-24 00:00:00	ANCIEN	\N	\N	\N	\N	1510	\N	\N
1771	MEMBREPOL	\N	1964-08-07 00:00:00	ANCIEN	\N	\N	\N	\N	1511	\N	\N
1772	MEMBREPOL	\N	1976-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	1512	\N	\N
1773	MEMBREPOL	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1513	\N	\N
1774	MEMBREPOL	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1514	\N	\N
1775	MEMBREPOL	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1515	\N	\N
1776	MEMBREPOL	\N	1971-10-28 00:00:00	ANCIEN	\N	\N	\N	\N	1516	\N	\N
1777	MEMBREPOL	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1517	\N	\N
1778	MEMBREPOL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1518	\N	\N
1779	MEMBREPOL	\N	1962-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	1519	\N	\N
1780	MEMBREPOL	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1520	\N	\N
1781	MEMBREPOL	\N	1968-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	1521	\N	\N
1782	MEMBREPOL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1522	\N	\N
1783	MEMBREPOL	\N	1972-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	1523	\N	\N
2113	MEMBREPOL	2006-07-09 00:00:00	2006-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	1835	\N	\N
2114	MEMBREPOL	2006-07-20 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1836	\N	\N
2139	MEMBREPOL	2007-07-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1860	\N	2017-09-24 19:25:10
2140	MEMBREPOL	2007-07-04 00:00:00	2013-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1861	\N	\N
2143	MEMBREPOL	2007-07-20 00:00:00	2007-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	1864	\N	\N
2144	MEMBREPOL	2007-07-20 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	1865	\N	\N
2159	MEMBREPOL	2007-12-17 00:00:00	2008-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	1881	\N	\N
2174	MEMBREPOL	2008-09-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1890	\N	\N
2372	MEMBREPOL	2010-03-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2100	\N	2014-09-28 17:38:26
2383	MEMBREPOL	2010-10-13 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2109	\N	2014-10-07 15:49:19
2122	MEMBREPOL	2007-01-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1843	\N	\N
2131	MEMBREPOL	2007-06-18 00:00:00	2007-06-19 00:00:00	ANCIEN	\N	\N	\N	\N	1851	\N	\N
2141	MEMBREPOL	2007-07-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1862	\N	\N
2148	MEMBREPOL	2007-09-04 00:00:00	2022-07-27 00:00:00	ANCIEN	\N	\N	\N	Membre à part entière puis apparenté depuis le 28 juillet 2022	1870	\N	\N
2152	PDTPOL	2007-09-19 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13	\N	\N
2154	MEMBREPOL	2007-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1875	\N	\N
2388	MEMBREPOL	2010-12-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2115	\N	\N
2370	MEMBREPOL	2010-03-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2097	\N	\N
2179	MEMBREPOL	2008-10-01 00:00:00	2010-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	1895	\N	\N
2180	MEMBREPOL	2008-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1896	\N	\N
2389	MEMBREPOL	2010-12-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2116	\N	\N
2187	MEMBREPOL	2008-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1903	\N	2014-09-28 17:03:42
2390	MEMBREPOL	2010-12-14 00:00:00	2017-09-21 00:00:00	ANCIEN	\N	\N	\N	\N	2117	\N	2017-09-22 10:42:23
2233	MEMBREPOL	2008-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1958	\N	2014-09-28 12:32:23
2240	MEMBREPOL	2008-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1966	\N	\N
2258	MEMBREPOL	2008-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1987	\N	2014-09-28 14:31:42
2125	MEMBREPOL	1983-10-03 00:00:00	1995-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	110	\N	\N
2348	PDTPOL	2008-10-02 00:00:00	2011-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	262	\N	\N
2164	VICPDTDELPOL	2008-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	701	\N	\N
2165	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	229	\N	\N
2356	PDTPOL	2009-07-07 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	1626	\N	\N
2357	PDTPOL	2009-07-07 00:00:00	2011-03-07 00:00:00	ANCIEN	\N	\N	\N	\N	795	\N	\N
2358	MEMBREPOL	2009-07-07 00:00:00	2009-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	223	\N	\N
741	MEMBREPOL	2002-12-11 00:00:00	2010-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	745	\N	\N
2385	MEMBREPOL	2010-11-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2112	\N	\N
2126	MEMBREPOL	1992-10-02 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1846	\N	\N
2134	MEMBREPOL	2007-06-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1854	\N	2014-09-28 16:59:41
2149	MEMBREPOL	2007-09-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1871	\N	2014-09-28 17:03:41
2158	MEMBREPOL	2007-11-30 00:00:00	2016-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	1880	\N	2016-11-18 12:37:50
2166	MEMBREPOL	2008-01-16 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	1883	\N	\N
2342	MEMBREPOL	2008-10-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2071	\N	\N
2343	MEMBREPOL	2008-10-02 00:00:00	2010-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2073	\N	\N
2345	MEMBREPOL	2008-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2075	\N	2014-09-28 17:27:35
2346	MEMBREPOL	2008-10-01 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	\N	2076	\N	\N
2347	MEMBREPOL	2008-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2077	\N	2014-09-28 17:03:42
2386	MEMBREPOL	2010-01-08 00:00:00	2010-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	2113	\N	\N
2376	MEMBREPOL	2010-05-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2103	\N	\N
2399	MEMBREPOL	2011-03-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2122	\N	\N
2156	MEMBREPOL	2007-11-22 00:00:00	2007-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	1877	\N	\N
2160	PDTPOL	2008-01-15 00:00:00	2009-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	784	\N	\N
2161	MEMBREPOL	2008-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	685	\N	\N
93	MEMBREPOL	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	93	\N	\N
2173	MEMBREPOL	2008-09-08 00:00:00	2008-09-10 00:00:00	ANCIEN	\N	\N	\N	\N	1889	\N	\N
692	MEMBREPOL	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	696	\N	\N
732	MEMBREPOL	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	736	\N	\N
1121	MEMBREPOL	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	861	\N	\N
2374	MEMBREPOL	2010-04-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2102	\N	\N
2384	MEMBREPOL	2010-10-12 00:00:00	2010-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	2110	\N	\N
2123	MEMBREPOL	2007-01-26 00:00:00	2007-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	1844	\N	\N
2127	MEMBREPOL	2007-02-26 00:00:00	2007-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	1848	\N	\N
2392	MEMBREPOL	2011-01-23 00:00:00	2011-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	2119	\N	\N
2395	PDTPOL	2011-02-08 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	632	\N	2014-10-07 15:50:54
2168	MEMBREPOL	2008-04-19 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	1886	\N	\N
2393	MEMBREPOL	2011-01-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2120	\N	\N
1474	MEMBREPOL	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1214	\N	\N
1475	MEMBREPOL	\N	1993-11-07 00:00:00	ANCIEN	\N	\N	\N	\N	1215	\N	\N
1476	MEMBREPOL	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1216	\N	\N
1477	MEMBREPOL	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1217	\N	\N
1478	MEMBREPOL	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1218	\N	\N
1479	MEMBREPOL	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1219	\N	\N
1480	MEMBREPOL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1220	\N	\N
1481	MEMBREPOL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1221	\N	\N
1482	MEMBREPOL	\N	1997-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	1222	\N	\N
1483	MEMBREPOL	\N	1982-03-20 00:00:00	ANCIEN	\N	\N	\N	\N	1223	\N	\N
1484	MEMBREPOL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1224	\N	\N
1485	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1225	\N	\N
1486	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1226	\N	\N
1487	MEMBREPOL	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1227	\N	\N
1488	MEMBREPOL	\N	1970-08-19 00:00:00	ANCIEN	\N	\N	\N	\N	1228	\N	\N
1489	MEMBREPOL	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1229	\N	\N
1490	MEMBREPOL	\N	1988-06-24 00:00:00	ANCIEN	\N	\N	\N	\N	1230	\N	\N
1491	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1231	\N	\N
1492	MEMBREPOL	\N	1979-06-05 00:00:00	ANCIEN	\N	\N	\N	\N	1232	\N	\N
1493	MEMBREPOL	\N	1996-09-10 00:00:00	ANCIEN	\N	\N	\N	\N	1233	\N	\N
1494	MEMBREPOL	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1234	\N	\N
1496	MEMBREPOL	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1236	\N	\N
1497	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1237	\N	\N
1498	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1238	\N	\N
1500	MEMBREPOL	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1240	\N	\N
1501	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1241	\N	\N
1502	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1242	\N	\N
1503	MEMBREPOL	\N	1981-08-29 00:00:00	ANCIEN	\N	\N	\N	\N	1243	\N	\N
1505	PDTPOL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1245	\N	\N
1506	MEMBREPOL	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	1246	\N	\N
1507	MEMBREPOL	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1247	\N	\N
1509	MEMBREPOL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1249	\N	\N
1510	MEMBREPOL	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1250	\N	\N
1511	MEMBREPOL	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1251	\N	\N
1512	MEMBREPOL	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1252	\N	\N
1514	MEMBREPOL	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1254	\N	\N
1515	MEMBREPOL	\N	1995-07-01 00:00:00	ANCIEN	\N	\N	\N	\N	1255	\N	\N
1516	MEMBREPOL	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1256	\N	\N
1517	MEMBREPOL	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1257	\N	\N
1519	MEMBREPOL	\N	1971-08-10 00:00:00	ANCIEN	\N	\N	\N	\N	1259	\N	\N
2054	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1790	\N	\N
2055	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1791	\N	\N
2056	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1792	\N	\N
2057	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1793	\N	\N
2058	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1794	\N	\N
2059	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1795	\N	\N
2063	MEMBREPOL	2004-10-21 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1799	\N	2014-10-08 09:41:10
2064	VICPDTDELPOL	2004-10-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	820	\N	\N
2065	VICPDTPOL	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	390	\N	\N
2066	VICPDTPOL	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	630	\N	\N
2067	VICPDTDELPOL	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	645	\N	\N
2068	VICPDTPOL	2004-10-06 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	39	\N	\N
2069	VICPDTPOL	2004-10-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	576	\N	\N
2070	MEMBREPOL	2004-10-06 00:00:00	2014-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	584	\N	2014-11-04 11:22:47
2071	VICPDTPOL	2004-10-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1738	\N	\N
2072	VICPDTPOL	2004-10-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	788	\N	\N
2073	VICPDTPOL	2004-10-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	592	\N	\N
2074	VICPDTPOL	2004-10-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	598	\N	\N
2075	VICPDTPOL	2004-10-06 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	609	\N	\N
2076	VICPDTPOL	2004-10-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	830	\N	\N
2077	VICPDTPOL	2004-10-06 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	332	\N	\N
2079	MEMBREPOL	2004-11-02 00:00:00	2005-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	1801	\N	\N
2080	MEMBREPOL	2004-11-02 00:00:00	2005-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	1802	\N	\N
2081	MEMBREPOL	2004-11-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1803	\N	\N
2082	MEMBREPOL	2004-12-24 00:00:00	2005-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	1804	\N	\N
2083	MEMBREPOL	2005-01-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1805	\N	\N
2084	MEMBREPOL	2005-02-21 00:00:00	2005-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	1806	\N	\N
2085	MEMBREPOL	2005-02-21 00:00:00	2005-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	1807	\N	\N
2086	MEMBREPOL	2005-02-21 00:00:00	2005-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	1808	\N	\N
2087	MEMBREPOL	2005-02-21 00:00:00	2005-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	1809	\N	\N
2088	MEMBREPOL	2005-02-21 00:00:00	2005-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	1810	\N	\N
2089	MEMBREPOL	2005-02-22 00:00:00	2012-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	1811	\N	\N
301	MEMBREPOL	\N	2004-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	301	\N	\N
2091	MEMBREPOL	2005-02-22 00:00:00	2010-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	1813	\N	\N
2092	MEMBREPOL	2005-02-22 00:00:00	2005-11-15 00:00:00	ANCIEN	\N	\N	\N	\N	1814	\N	\N
2093	MEMBREPOL	2005-02-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1815	\N	2014-09-28 17:31:42
2094	MEMBREPOL	2005-02-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1816	\N	\N
2095	MEMBREPOL	2005-02-22 00:00:00	2011-10-30 00:00:00	ANCIEN	\N	\N	\N	\N	1817	\N	\N
2097	MEMBREPOL	2005-03-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1818	\N	\N
2098	MEMBREPOL	2005-03-22 00:00:00	2010-05-17 00:00:00	ANCIEN	\N	\N	\N	\N	1819	\N	\N
2099	MEMBREPOL	2005-06-19 00:00:00	2005-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	1820	\N	\N
2100	MEMBREPOL	2005-06-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1821	\N	2014-09-28 13:47:05
2101	MEMBREPOL	2005-06-28 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	1822	\N	\N
2103	MEMBREPOL	2005-09-19 00:00:00	2005-09-21 00:00:00	ANCIEN	\N	\N	\N	\N	1824	\N	\N
2104	MEMBREPOL	2005-09-19 00:00:00	2005-09-21 00:00:00	ANCIEN	\N	\N	\N	\N	1826	\N	\N
2105	MEMBREPOL	2005-09-19 00:00:00	2005-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	1827	\N	\N
2106	MEMBREPOL	2005-09-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	1828	\N	\N
2107	MEMBREPOL	2005-09-22 00:00:00	2007-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	1829	\N	\N
2108	MEMBREPOL	2005-09-23 00:00:00	2017-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1830	\N	2017-10-05 09:36:59
2109	MEMBREPOL	2005-11-16 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1831	\N	2014-09-28 17:31:41
2110	MEMBREPOL	1961-11-13 00:00:00	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	1832	\N	\N
2111	MEMBREPOL	2006-05-17 00:00:00	2006-05-22 00:00:00	ANCIEN	\N	\N	\N	\N	1833	\N	\N
2112	MEMBREPOL	2006-05-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1834	\N	\N
2121	MEMBREPOL	2007-01-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1842	\N	\N
2137	MEMBREPOL	2007-06-29 00:00:00	2007-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	1858	\N	\N
2138	MEMBREPOL	2007-06-29 00:00:00	2007-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	1859	\N	\N
2145	MEMBREPOL	2007-07-24 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	1866	\N	\N
2359	MEMBREPOL	2009-07-07 00:00:00	2009-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	784	\N	\N
2350	VICPDTPOL	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	373	\N	\N
2360	MEMBREPOL	2009-07-24 00:00:00	2012-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	2083	\N	\N
2361	MEMBREPOL	2009-07-24 00:00:00	2012-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	2084	\N	\N
2364	MEMBREPOL	2009-09-16 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2087	\N	2014-09-28 13:09:05
2366	MEMBREPOL	2010-01-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2093	\N	\N
2368	MEMBREPOL	2010-03-07 00:00:00	2010-03-08 00:00:00	ANCIEN	\N	\N	\N	\N	2095	\N	\N
2235	MEMBREPOL	2008-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1960	\N	2014-09-28 17:52:18
2378	MEMBREPOL	2010-05-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2105	\N	\N
2380	MEMBREPOL	2010-10-01 00:00:00	2011-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	2107	\N	\N
1995	MEMBREPOL	2004-09-27 00:00:00	2010-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	1733	\N	\N
2391	MEMBREPOL	2010-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	2118	\N	\N
2260	MEMBREPOL	2008-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1989	\N	2014-09-28 17:27:29
2278	MEMBREPOL	2008-10-01 00:00:00	2011-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	2007	\N	\N
2116	MEMBREPOL	2006-08-21 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1838	\N	2014-09-28 13:32:35
2167	MEMBREPOL	1965-08-20 00:00:00	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1884	\N	\N
2275	MEMBREPOL	2008-10-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2004	\N	\N
2277	MEMBREPOL	2008-10-02 00:00:00	2014-09-16 00:00:00	ANCIEN	\N	\N	\N	\N	2006	\N	2014-09-16 14:55:28
2279	MEMBREPOL	2008-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	2008	\N	\N
2282	MEMBREPOL	2008-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	2011	\N	\N
2284	MEMBREPOL	2008-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2013	\N	2014-10-07 16:59:15
2285	MEMBREPOL	2008-10-01 00:00:00	2013-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2014	\N	\N
2286	MEMBREPOL	2008-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2015	\N	2014-09-28 17:34:16
2287	MEMBREPOL	2008-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	2016	\N	\N
2288	MEMBREPOL	2008-10-01 00:00:00	2013-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	2017	\N	2013-06-04 17:13:21
2289	MEMBREPOL	2008-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	2018	\N	\N
2290	MEMBREPOL	2008-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2019	\N	2014-09-28 17:34:16
2293	MEMBREPOL	2008-10-01 00:00:00	2011-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	2022	\N	\N
2294	MEMBREPOL	2008-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2023	\N	2014-09-28 19:07:43
2295	MEMBREPOL	2008-10-01 00:00:00	2011-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	2024	\N	\N
2296	MEMBREPOL	2008-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2025	\N	2014-09-28 12:39:09
2298	MEMBREPOL	2008-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2027	\N	2014-09-28 17:07:07
2299	MEMBREPOL	2008-10-01 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	2028	\N	2017-09-25 09:57:52
2300	MEMBREPOL	2008-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2029	\N	2014-09-28 17:22:11
2301	MEMBREPOL	2008-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	2030	\N	\N
2302	MEMBREPOL	2008-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	2031	\N	\N
2303	MEMBREPOL	2008-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	2032	\N	\N
2304	MEMBREPOL	2008-10-01 00:00:00	2014-04-14 00:00:00	ANCIEN	\N	\N	\N	\N	2033	\N	2014-04-15 16:21:15
2305	MEMBREPOL	2008-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2034	\N	2014-09-28 17:52:18
2306	MEMBREPOL	2008-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2035	\N	2014-09-28 17:52:18
2307	MEMBREPOL	2008-10-01 00:00:00	2011-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	2036	\N	\N
2308	MEMBREPOL	2008-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2037	\N	2014-10-07 15:53:46
2309	MEMBREPOL	2008-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2038	\N	\N
2310	MEMBREPOL	2008-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2039	\N	\N
2311	MEMBREPOL	2008-10-01 00:00:00	2010-05-02 00:00:00	ANCIEN	\N	\N	\N	\N	2040	\N	\N
2313	MEMBREPOL	2008-10-01 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	2042	\N	2017-06-29 09:52:44
2314	MEMBREPOL	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2043	\N	2014-10-02 09:58:37
2315	MEMBREPOL	2008-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2044	\N	2014-10-07 19:31:51
2117	MEMBREPOL	2006-09-25 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1839	\N	\N
2142	MEMBREPOL	2007-07-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1863	\N	\N
2146	MEMBREPOL	2007-08-27 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	1868	\N	\N
2147	MEMBREPOL	2007-08-27 00:00:00	2007-09-10 00:00:00	ANCIEN	\N	\N	\N	\N	1869	\N	\N
2170	MEMBREPOL	2008-06-04 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	1887	\N	\N
2362	MEMBREPOL	2009-07-24 00:00:00	2009-07-28 00:00:00	ANCIEN	\N	\N	\N	\N	2085	\N	\N
2363	MEMBREPOL	2009-07-29 00:00:00	2016-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2086	\N	2017-01-03 11:09:24
2273	MEMBREPOL	2008-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2002	\N	2014-09-29 09:05:47
2316	MEMBREPOL	2008-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2045	\N	2014-09-29 09:08:32
2318	MEMBREPOL	2008-10-01 00:00:00	2015-06-09 00:00:00	ANCIEN	\N	\N	\N	\N	2047	\N	2015-06-11 19:01:58
2325	MEMBREPOL	2008-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2054	\N	\N
2326	MEMBREPOL	2008-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2055	\N	2014-09-28 17:27:35
2327	MEMBREPOL	2008-10-01 00:00:00	2013-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	2056	\N	\N
2329	MEMBREPOL	2008-10-01 00:00:00	2011-10-30 00:00:00	ANCIEN	\N	\N	\N	\N	2058	\N	\N
2330	MEMBREPOL	2008-10-01 00:00:00	2011-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2059	\N	\N
2331	MEMBREPOL	2008-10-01 00:00:00	2011-10-30 00:00:00	ANCIEN	\N	\N	\N	\N	2060	\N	\N
2332	MEMBREPOL	2008-10-01 00:00:00	2014-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	2061	\N	\N
2338	MEMBREPOL	2008-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2067	\N	\N
2340	MEMBREPOL	2008-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2069	\N	2014-09-28 19:03:23
2115	MEMBREPOL	2006-08-12 00:00:00	2006-08-20 00:00:00	ANCIEN	\N	\N	\N	\N	1837	\N	\N
2124	MEMBREPOL	2007-02-05 00:00:00	2011-09-25 00:00:00	ANCIEN	\N	\N	\N	\N	1845	\N	\N
2151	MEMBREPOL	2007-09-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1873	\N	\N
2157	MEMBREPOL	2007-11-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1878	\N	\N
2355	MEMBREPOL	2009-05-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2082	\N	\N
2371	MEMBREPOL	2010-03-10 00:00:00	2013-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	2098	\N	\N
2118	MEMBREPOL	2007-01-03 00:00:00	2007-01-04 00:00:00	ANCIEN	\N	\N	\N	\N	1840	\N	\N
2119	MEMBREPOL	2007-01-02 00:00:00	2007-01-03 00:00:00	ANCIEN	\N	\N	\N	\N	1841	\N	\N
2129	MEMBREPOL	2007-03-06 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1850	\N	\N
2135	MEMBREPOL	\N	2007-07-10 00:00:00	ANCIEN	\N	\N	\N	\N	1856	\N	\N
2397	PDTPOL	2011-03-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	785	\N	\N
1353	MEMBREPOL	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	1093	\N	\N
1354	MEMBREPOL	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1094	\N	\N
1355	MEMBREPOL	\N	1997-03-07 00:00:00	ANCIEN	\N	\N	\N	\N	1095	\N	\N
1356	MEMBREPOL	\N	1988-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	1096	\N	\N
1357	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1097	\N	\N
1358	MEMBREPOL	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1098	\N	\N
1359	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1099	\N	\N
1360	MEMBREPOL	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1100	\N	\N
1361	MEMBREPOL	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1101	\N	\N
1362	MEMBREPOL	\N	1992-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	1102	\N	\N
1363	MEMBREPOL	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1103	\N	\N
1364	MEMBREPOL	\N	1978-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	1104	\N	\N
1365	MEMBREPOL	\N	1978-05-08 00:00:00	ANCIEN	\N	\N	\N	\N	1105	\N	\N
1366	MEMBREPOL	\N	1988-07-01 00:00:00	ANCIEN	\N	\N	\N	\N	1106	\N	\N
1367	MEMBREPOL	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1107	\N	\N
1368	MEMBREPOL	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1108	\N	\N
1369	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1109	\N	\N
1370	MEMBREPOL	\N	1982-10-22 00:00:00	ANCIEN	\N	\N	\N	\N	1110	\N	\N
1371	MEMBREPOL	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1111	\N	\N
1372	MEMBREPOL	\N	1985-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	1112	\N	\N
1373	MEMBREPOL	\N	1977-03-04 00:00:00	ANCIEN	\N	\N	\N	\N	1113	\N	\N
1374	MEMBREPOL	\N	1997-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	1114	\N	\N
1375	MEMBREPOL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1115	\N	\N
1376	MEMBREPOL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1116	\N	\N
1377	MEMBREPOL	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	1117	\N	\N
1378	MEMBREPOL	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1118	\N	\N
1379	MEMBREPOL	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1119	\N	\N
1380	MEMBREPOL	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1120	\N	\N
1381	MEMBREPOL	\N	1967-04-03 00:00:00	ANCIEN	\N	\N	\N	\N	1121	\N	\N
1382	MEMBREPOL	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1122	\N	\N
1383	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1123	\N	\N
1384	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1124	\N	\N
1385	MEMBREPOL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1125	\N	\N
1386	MEMBREPOL	\N	1978-08-27 00:00:00	ANCIEN	\N	\N	\N	\N	1126	\N	\N
1387	MEMBREPOL	\N	1995-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	1127	\N	\N
1388	MEMBREPOL	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1128	\N	\N
1389	MEMBREPOL	\N	1981-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	1129	\N	\N
1390	MEMBREPOL	\N	1993-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	1130	\N	\N
1391	MEMBREPOL	\N	1978-06-09 00:00:00	ANCIEN	\N	\N	\N	\N	1131	\N	\N
1392	MEMBREPOL	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1132	\N	\N
1393	MEMBREPOL	\N	1981-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	1133	\N	\N
1395	MEMBREPOL	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1135	\N	\N
1396	MEMBREPOL	\N	1983-04-18 00:00:00	ANCIEN	\N	\N	\N	\N	1136	\N	\N
1397	MEMBREPOL	\N	1975-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	1137	\N	\N
1399	MEMBREPOL	\N	1986-04-02 00:00:00	ANCIEN	\N	\N	\N	\N	1139	\N	\N
1400	MEMBREPOL	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1140	\N	\N
1401	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1141	\N	\N
1402	MEMBREPOL	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1142	\N	\N
1404	MEMBREPOL	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1144	\N	\N
1405	MEMBREPOL	\N	1983-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	1145	\N	\N
1406	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1146	\N	\N
1407	MEMBREPOL	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1147	\N	\N
1409	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1149	\N	\N
1410	MEMBREPOL	\N	1991-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	1150	\N	\N
1411	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1151	\N	\N
1413	MEMBREPOL	\N	1962-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	1153	\N	\N
1414	MEMBREPOL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1154	\N	\N
1415	MEMBREPOL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1155	\N	\N
1416	MEMBREPOL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1156	\N	\N
1418	MEMBREPOL	\N	1981-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	1158	\N	\N
1419	MEMBREPOL	\N	1975-07-29 00:00:00	ANCIEN	\N	\N	\N	\N	1159	\N	\N
1420	MEMBREPOL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1160	\N	\N
1422	MEMBREPOL	\N	1967-04-18 00:00:00	ANCIEN	\N	\N	\N	\N	1162	\N	\N
1423	MEMBREPOL	\N	1974-10-13 00:00:00	ANCIEN	\N	\N	\N	\N	1163	\N	\N
1424	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1164	\N	\N
1425	MEMBREPOL	\N	1998-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	1165	\N	\N
1427	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1167	\N	\N
1428	MEMBREPOL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1168	\N	\N
1429	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1169	\N	\N
1431	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1171	\N	\N
1432	MEMBREPOL	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1172	\N	\N
1433	MEMBREPOL	\N	1994-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	1173	\N	\N
1434	MEMBREPOL	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1174	\N	\N
1436	MEMBREPOL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1176	\N	\N
1437	MEMBREPOL	\N	1972-12-05 00:00:00	ANCIEN	\N	\N	\N	\N	1177	\N	\N
1438	MEMBREPOL	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1178	\N	\N
1439	MEMBREPOL	\N	1983-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	1179	\N	\N
1440	MEMBREPOL	\N	1981-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	1180	\N	\N
1441	MEMBREPOL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1181	\N	\N
1442	MEMBREPOL	\N	1993-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	1182	\N	\N
1443	MEMBREPOL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1183	\N	\N
1444	MEMBREPOL	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1184	\N	\N
1445	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1185	\N	\N
1446	MEMBREPOL	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1186	\N	\N
1447	MEMBREPOL	\N	1989-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	1187	\N	\N
1448	MEMBREPOL	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1188	\N	\N
1449	MEMBREPOL	\N	1995-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	1189	\N	\N
1450	MEMBREPOL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1190	\N	\N
1451	MEMBREPOL	\N	1995-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	1191	\N	\N
1452	MEMBREPOL	\N	1978-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1192	\N	\N
1453	MEMBREPOL	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1193	\N	\N
1454	MEMBREPOL	\N	1997-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	1194	\N	\N
1455	MEMBREPOL	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1195	\N	\N
1456	MEMBREPOL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1196	\N	\N
1457	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1197	\N	\N
1458	MEMBREPOL	\N	1969-03-20 00:00:00	ANCIEN	\N	\N	\N	\N	1198	\N	\N
1459	MEMBREPOL	\N	1990-08-11 00:00:00	ANCIEN	\N	\N	\N	\N	1199	\N	\N
1460	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1200	\N	\N
1461	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1201	\N	\N
1462	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1202	\N	\N
1463	PDTPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1203	\N	\N
1464	MEMBREPOL	\N	1982-08-15 00:00:00	ANCIEN	\N	\N	\N	\N	1204	\N	\N
1465	MEMBREPOL	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1205	\N	\N
1466	MEMBREPOL	\N	1973-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	1206	\N	\N
1467	MEMBREPOL	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1207	\N	\N
1468	MEMBREPOL	\N	1981-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	1208	\N	\N
1469	MEMBREPOL	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	1209	\N	\N
1470	MEMBREPOL	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1210	\N	\N
1471	MEMBREPOL	\N	1962-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	1211	\N	\N
1472	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1212	\N	\N
1473	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1213	\N	\N
547	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	548	\N	\N
548	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	549	\N	\N
549	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	550	\N	\N
551	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	552	\N	\N
552	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	553	\N	\N
553	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	554	\N	\N
554	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	555	\N	\N
555	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	556	\N	\N
556	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	557	\N	\N
557	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	558	\N	\N
558	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	559	\N	\N
559	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	560	\N	\N
127	MEMBREPOL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	127	\N	\N
560	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	561	\N	\N
561	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	562	\N	\N
562	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	563	\N	\N
563	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	564	\N	\N
564	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	565	\N	\N
565	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	566	\N	\N
566	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	567	\N	\N
567	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	568	\N	\N
568	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	569	\N	\N
569	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	570	\N	\N
570	MEMBREPOL	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	571	\N	\N
571	MEMBREPOL	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	572	\N	\N
572	MEMBREPOL	2001-10-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	573	\N	2017-09-24 18:20:10
573	MEMBREPOL	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	574	\N	\N
574	MEMBREPOL	2001-10-02 00:00:00	2017-05-22 00:00:00	ANCIEN	\N	\N	\N	\N	575	\N	2017-06-01 16:12:41
575	MEMBREPOL	2001-10-02 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	576	\N	\N
576	MEMBREPOL	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	577	\N	\N
577	MEMBREPOL	2001-10-02 00:00:00	2012-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	578	\N	\N
578	MEMBREPOL	2001-10-02 00:00:00	2012-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	579	\N	\N
579	MEMBREPOL	2001-10-02 00:00:00	2007-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	580	\N	\N
580	MEMBREPOL	2001-10-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	581	\N	\N
581	MEMBREPOL	2001-10-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	582	\N	2017-09-24 17:35:15
582	MEMBREPOL	2001-10-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	583	\N	2017-09-24 17:06:55
583	MEMBREPOL	2001-10-02 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	584	\N	\N
584	MEMBREPOL	2001-10-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	585	\N	\N
585	MEMBREPOL	2001-10-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	586	\N	2017-09-24 17:19:42
586	MEMBREPOL	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	588	\N	\N
587	MEMBREPOL	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	589	\N	\N
588	MEMBREPOL	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	591	\N	\N
589	MEMBREPOL	2001-10-02 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	592	\N	\N
590	MEMBREPOL	2001-10-02 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	593	\N	2016-12-12 16:10:15
591	MEMBREPOL	2001-10-02 00:00:00	2010-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	594	\N	\N
592	MEMBREPOL	2001-10-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	595	\N	\N
593	VICPDTPOL	2001-10-02 00:00:00	2007-01-07 00:00:00	ANCIEN	\N	\N	\N	\N	596	\N	\N
594	MEMBREPOL	2001-10-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	597	\N	2017-09-24 16:43:43
595	MEMBREPOL	2001-10-02 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	598	\N	\N
596	MEMBREPOL	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	599	\N	\N
597	MEMBREPOL	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	600	\N	\N
598	MEMBREPOL	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	601	\N	\N
599	MEMBREPOL	2001-10-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	602	\N	2017-09-24 17:14:26
600	MEMBREPOL	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	603	\N	\N
601	MEMBREPOL	2001-10-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	604	\N	\N
602	MEMBREPOL	2001-10-02 00:00:00	2006-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	605	\N	\N
603	MEMBREPOL	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	606	\N	\N
604	MEMBREPOL	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	607	\N	\N
605	MEMBREPOL	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	608	\N	\N
606	MEMBREPOL	2001-10-02 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	609	\N	\N
607	MEMBREPOL	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	610	\N	\N
608	MEMBREPOL	2001-10-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	611	\N	\N
609	MEMBREPOL	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	612	\N	\N
610	MEMBREPOL	2001-10-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	613	\N	\N
611	MEMBREPOL	2001-10-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	614	\N	\N
612	MEMBREPOL	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	615	\N	\N
613	MEMBREPOL	2001-10-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	616	\N	\N
614	MEMBREPOL	2001-10-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	617	\N	2017-09-24 17:09:24
615	MEMBREPOL	2001-10-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	619	\N	2017-09-24 17:19:42
616	MEMBREPOL	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	620	\N	\N
617	MEMBREPOL	2001-10-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	621	\N	\N
618	MEMBREPOL	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	622	\N	\N
619	MEMBREPOL	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	623	\N	\N
620	MEMBREPOL	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	624	\N	\N
621	MEMBREPOL	2001-10-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	625	\N	\N
622	MEMBREPOL	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	626	\N	\N
623	MEMBREPOL	2001-10-02 00:00:00	2014-12-21 00:00:00	ANCIEN	\N	\N	\N	\N	627	\N	2015-05-18 17:56:14
624	MEMBREPOL	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	628	\N	\N
625	MEMBREPOL	2001-10-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	629	\N	\N
626	MEMBREPOL	2001-10-02 00:00:00	2004-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	630	\N	\N
627	MEMBREPOL	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	631	\N	\N
628	MEMBREPOL	2001-10-02 00:00:00	2011-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	632	\N	\N
629	MEMBREPOL	1992-10-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	633	\N	2017-09-24 18:16:52
630	MEMBREPOL	2001-10-02 00:00:00	2009-05-12 00:00:00	ANCIEN	\N	\N	\N	\N	634	\N	\N
631	MEMBREPOL	2001-10-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	635	\N	\N
632	MEMBREPOL	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	636	\N	\N
633	MEMBREPOL	2001-10-02 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	637	\N	\N
634	PDTPOL	2001-10-02 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	374	\N	\N
635	MEMBREPOL	2001-10-10 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	638	\N	\N
636	MEMBREPOL	2001-10-15 00:00:00	2001-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	639	\N	\N
637	MEMBREPOL	2001-11-06 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	640	\N	\N
638	MEMBREPOL	2001-11-22 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	641	\N	\N
639	MEMBREPOL	2001-12-02 00:00:00	2001-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	642	\N	\N
640	MEMBREPOL	2001-12-04 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	643	\N	2014-09-28 12:09:44
641	MEMBREPOL	2002-01-20 00:00:00	2002-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	644	\N	\N
642	MEMBREPOL	2002-01-25 00:00:00	2004-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	645	\N	\N
643	MEMBREPOL	2002-06-07 00:00:00	2002-06-19 00:00:00	ANCIEN	\N	\N	\N	\N	646	\N	\N
196	MEMBREPOL	\N	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	196	\N	\N
644	MEMBREPOL	2002-06-08 00:00:00	2002-06-10 00:00:00	ANCIEN	\N	\N	\N	\N	647	\N	\N
645	MEMBREPOL	2002-06-08 00:00:00	2002-06-19 00:00:00	ANCIEN	\N	\N	\N	\N	648	\N	\N
646	MEMBREPOL	2002-06-08 00:00:00	2002-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	649	\N	\N
647	MEMBREPOL	2002-06-10 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	650	\N	\N
648	MEMBREPOL	2002-06-19 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	651	\N	\N
649	MEMBREPOL	2002-06-20 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	652	\N	\N
650	MEMBREPOL	2002-06-28 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	655	\N	\N
654	PDTPOL	2002-07-17 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	317	\N	\N
655	MEMBREPOL	2002-07-18 00:00:00	2002-07-30 00:00:00	ANCIEN	\N	\N	\N	\N	660	\N	\N
656	MEMBREPOL	2002-07-17 00:00:00	2014-07-01 00:00:00	ANCIEN	\N	\N	\N	\N	149	\N	2014-07-01 09:25:11
657	MEMBREPOL	2002-07-30 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	661	\N	\N
658	MEMBREPOL	2002-09-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	662	\N	\N
659	MEMBREPOL	2002-10-01 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	664	\N	\N
660	MEMBREPOL	2002-10-01 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	665	\N	\N
662	MEMBREPOL	2002-12-11 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	\N	666	\N	\N
663	MEMBREPOL	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	667	\N	\N
664	MEMBREPOL	2002-12-11 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	668	\N	\N
665	MEMBREPOL	2002-12-11 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	669	\N	2014-09-28 13:16:32
666	MEMBREPOL	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	670	\N	\N
667	MEMBREPOL	2002-12-11 00:00:00	2014-04-24 00:00:00	ANCIEN	\N	\N	\N	\N	671	\N	2014-04-25 17:05:01
668	MEMBREPOL	2002-12-11 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	672	\N	\N
669	MEMBREPOL	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	673	\N	\N
670	MEMBREPOL	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	674	\N	\N
671	MEMBREPOL	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	675	\N	\N
672	MEMBREPOL	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	676	\N	\N
673	MEMBREPOL	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	677	\N	\N
674	MEMBREPOL	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	678	\N	\N
675	MEMBREPOL	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	679	\N	\N
676	MEMBREPOL	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	680	\N	\N
677	MEMBREPOL	2002-12-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	681	\N	\N
678	MEMBREPOL	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	682	\N	\N
679	MEMBREPOL	2002-12-11 00:00:00	2011-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	683	\N	\N
1735	MEMBREPOL	\N	1965-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	1475	\N	\N
1793	MEMBREPOL	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1533	\N	\N
1797	MEMBREPOL	\N	1979-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	1537	\N	\N
1802	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1542	\N	\N
1906	MEMBREPOL	2004-05-01 00:00:00	2004-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	1641	\N	\N
1811	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1551	\N	\N
1816	MEMBREPOL	\N	1992-04-06 00:00:00	ANCIEN	\N	\N	\N	\N	1556	\N	\N
1820	MEMBREPOL	\N	1966-06-02 00:00:00	ANCIEN	\N	\N	\N	\N	1560	\N	\N
1825	MEMBREPOL	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1565	\N	\N
1829	MEMBREPOL	\N	1986-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	1569	\N	\N
1835	MEMBREPOL	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1575	\N	\N
1888	MEMBREPOL	2003-08-02 00:00:00	2009-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	1626	\N	\N
1890	MEMBREPOL	2003-08-29 00:00:00	2003-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	1627	\N	\N
1891	MEMBREPOL	2003-09-04 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1628	\N	\N
1894	PDTDELPOL	2002-05-10 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	381	\N	\N
1897	MEMBREPOL	2003-11-05 00:00:00	2003-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	1632	\N	\N
1898	MEMBREPOL	2003-11-07 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1633	\N	\N
1899	MEMBREPOL	2003-11-13 00:00:00	2004-04-06 00:00:00	ANCIEN	\N	\N	\N	\N	1634	\N	\N
1900	MEMBREPOL	1986-10-02 00:00:00	1995-11-13 00:00:00	ANCIEN	\N	\N	\N	\N	288	\N	\N
1901	MEMBREPOL	2004-02-13 00:00:00	2004-02-23 00:00:00	ANCIEN	\N	\N	\N	\N	1636	\N	\N
1903	MEMBREPOL	2004-02-24 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1637	\N	\N
1904	MEMBREPOL	2004-04-07 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1638	\N	\N
1905	MEMBREPOL	2004-04-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1639	\N	\N
1907	MEMBREPOL	2004-05-01 00:00:00	2004-05-03 00:00:00	ANCIEN	\N	\N	\N	\N	1642	\N	\N
1908	MEMBREPOL	2004-05-01 00:00:00	2004-05-03 00:00:00	ANCIEN	\N	\N	\N	\N	1643	\N	\N
1909	MEMBREPOL	2004-05-04 00:00:00	2005-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	1644	\N	\N
1910	MEMBREPOL	2004-05-04 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1645	\N	\N
1911	MEMBREPOL	2004-05-05 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1646	\N	\N
191	MEMBREPOL	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	191	\N	\N
1913	MEMBREPOL	2004-05-17 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1647	\N	\N
240	MEMBREPOL	\N	2004-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	240	\N	\N
251	MEMBREPOL	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	251	\N	\N
1914	MEMBREPOL	2004-10-01 00:00:00	2004-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	1649	\N	\N
1915	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1650	\N	\N
1916	MEMBREPOL	2004-09-26 00:00:00	2004-09-26 00:00:00	ANCIEN	\N	\N	\N	\N	1651	\N	\N
1918	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1653	\N	\N
1919	MEMBREPOL	2004-10-05 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	1654	\N	2017-06-29 09:55:49
1922	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1658	\N	\N
1923	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1659	\N	\N
1924	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1660	\N	\N
1926	MEMBREPOL	2004-10-05 00:00:00	2011-10-26 00:00:00	ANCIEN	\N	\N	\N	\N	1662	\N	\N
1927	MEMBREPOL	2004-10-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1663	\N	\N
1928	MEMBREPOL	2004-10-05 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	1664	\N	\N
1930	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1667	\N	\N
1931	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1668	\N	\N
1933	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1670	\N	\N
1934	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1671	\N	\N
1935	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1672	\N	\N
1936	MEMBREPOL	2004-10-05 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	1673	\N	2017-06-29 09:55:22
1939	MEMBREPOL	2004-10-05 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1676	\N	2014-09-28 17:07:41
1940	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1677	\N	\N
1942	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1679	\N	\N
1943	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1680	\N	\N
1944	MEMBREPOL	2004-10-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1681	\N	\N
1945	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1682	\N	\N
1946	MEMBREPOL	2004-10-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1683	\N	\N
1947	MEMBREPOL	2004-10-05 00:00:00	2012-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	1684	\N	\N
1948	MEMBREPOL	2004-10-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1686	\N	2017-09-24 17:18:03
1949	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1687	\N	\N
1950	VICPDTPOL	2004-10-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1688	\N	\N
1951	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1689	\N	\N
1952	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1690	\N	\N
1953	MEMBREPOL	2004-10-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1691	\N	\N
1954	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1692	\N	\N
1956	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1694	\N	\N
1957	MEMBREPOL	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1695	\N	\N
1959	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1697	\N	\N
1960	MEMBREPOL	2004-10-05 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	1698	\N	\N
1961	MEMBREPOL	2004-10-05 00:00:00	2011-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	1699	\N	\N
238	MEMBREPOL	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	238	\N	\N
1962	MEMBREPOL	2004-10-05 00:00:00	2012-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	1700	\N	\N
1963	MEMBREPOL	2004-10-05 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	1701	\N	\N
1964	MEMBREPOL	2004-10-01 00:00:00	2008-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	1702	\N	\N
1965	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1703	\N	\N
1966	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1704	\N	\N
1967	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1705	\N	\N
1968	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1706	\N	\N
1969	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1707	\N	\N
1970	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1708	\N	\N
1971	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1709	\N	\N
1972	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1710	\N	\N
1973	MEMBREPOL	2004-10-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1711	\N	\N
1974	MEMBREPOL	2004-10-05 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	1712	\N	2017-06-29 09:54:25
1975	MEMBREPOL	2004-10-05 00:00:00	2012-09-13 00:00:00	ANCIEN	\N	\N	\N	\N	1713	\N	\N
1976	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1714	\N	\N
1977	MEMBREPOL	2004-10-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1715	\N	2017-09-24 17:47:27
1978	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1716	\N	\N
1979	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1717	\N	\N
1980	MEMBREPOL	2004-10-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1718	\N	\N
1981	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1719	\N	\N
1982	MEMBREPOL	2004-10-05 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1720	\N	2014-09-28 13:40:33
1983	MEMBREPOL	2004-10-05 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1721	\N	\N
1984	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1722	\N	\N
1985	MEMBREPOL	2004-10-05 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1723	\N	2014-09-28 13:39:21
1986	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1724	\N	\N
1987	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1725	\N	\N
1988	MEMBREPOL	2004-10-05 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	1726	\N	\N
1989	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1727	\N	\N
1990	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1728	\N	\N
1606	MEMBREPOL	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1346	\N	\N
1607	MEMBREPOL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1347	\N	\N
1609	MEMBREPOL	\N	1985-05-26 00:00:00	ANCIEN	\N	\N	\N	\N	1349	\N	\N
1610	MEMBREPOL	\N	1997-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	1350	\N	\N
1611	MEMBREPOL	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1351	\N	\N
1613	MEMBREPOL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1353	\N	\N
1614	MEMBREPOL	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	1354	\N	\N
1615	MEMBREPOL	\N	1983-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	1355	\N	\N
1616	MEMBREPOL	\N	1989-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	1356	\N	\N
1618	MEMBREPOL	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1358	\N	\N
1619	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1359	\N	\N
1620	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1360	\N	\N
1622	MEMBREPOL	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1362	\N	\N
1623	MEMBREPOL	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1363	\N	\N
1624	MEMBREPOL	\N	1998-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	1364	\N	\N
1625	MEMBREPOL	\N	1960-05-09 00:00:00	ANCIEN	\N	\N	\N	\N	1365	\N	\N
1627	MEMBREPOL	\N	1995-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	1367	\N	\N
1628	MEMBREPOL	\N	1992-02-23 00:00:00	ANCIEN	\N	\N	\N	\N	1368	\N	\N
1629	MEMBREPOL	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1369	\N	\N
1631	MEMBREPOL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1371	\N	\N
1632	MEMBREPOL	\N	1993-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	1372	\N	\N
1633	MEMBREPOL	\N	1980-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	1373	\N	\N
1634	MEMBREPOL	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1374	\N	\N
1636	MEMBREPOL	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1376	\N	\N
1637	MEMBREPOL	\N	1974-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	1377	\N	\N
1638	MEMBREPOL	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1378	\N	\N
1639	MEMBREPOL	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1379	\N	\N
1640	MEMBREPOL	\N	1983-08-20 00:00:00	ANCIEN	\N	\N	\N	\N	1380	\N	\N
1641	MEMBREPOL	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1381	\N	\N
1642	MEMBREPOL	\N	1966-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	1382	\N	\N
1643	MEMBREPOL	\N	1971-08-01 00:00:00	ANCIEN	\N	\N	\N	\N	1383	\N	\N
1644	MEMBREPOL	\N	1986-06-23 00:00:00	ANCIEN	\N	\N	\N	\N	1384	\N	\N
1645	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1385	\N	\N
1646	MEMBREPOL	\N	1984-03-20 00:00:00	ANCIEN	\N	\N	\N	\N	1386	\N	\N
1647	MEMBREPOL	\N	1975-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	1387	\N	\N
1648	MEMBREPOL	\N	1978-10-13 00:00:00	ANCIEN	\N	\N	\N	\N	1388	\N	\N
1649	MEMBREPOL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1389	\N	\N
1991	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1729	\N	\N
1992	MEMBREPOL	2004-10-05 00:00:00	2015-06-09 00:00:00	ANCIEN	\N	\N	\N	\N	1730	\N	2015-06-11 19:01:25
1996	MEMBREPOL	2004-10-05 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1734	\N	2014-09-28 17:55:39
1997	MEMBREPOL	2004-10-05 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1735	\N	2014-09-28 18:58:25
1998	MEMBREPOL	2004-10-05 00:00:00	2011-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	1736	\N	\N
1999	MEMBREPOL	2004-10-05 00:00:00	2011-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	1737	\N	\N
2001	MEMBREPOL	2004-10-05 00:00:00	2004-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	1738	\N	\N
2000	PDTPOL	2004-10-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	322	\N	\N
2002	MEMBREPOL	2004-10-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1739	\N	\N
2003	MEMBREPOL	2004-10-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1740	\N	2017-09-24 18:05:41
2004	MEMBREPOL	2004-10-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1741	\N	\N
2005	MEMBREPOL	2004-10-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1742	\N	2017-09-24 19:25:10
2006	MEMBREPOL	2004-10-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1743	\N	\N
2007	MEMBREPOL	2004-10-05 00:00:00	2011-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	1744	\N	\N
2008	MEMBREPOL	2004-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	1745	\N	\N
2009	MEMBREPOL	2004-10-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1746	\N	2017-09-24 17:47:27
2010	MEMBREPOL	2004-10-05 00:00:00	2008-04-18 00:00:00	ANCIEN	\N	\N	\N	\N	1747	\N	\N
2011	MEMBREPOL	2004-10-05 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1748	\N	\N
2012	MEMBREPOL	2004-10-05 00:00:00	2004-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	1749	\N	\N
2013	MEMBREPOL	2004-10-05 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1750	\N	\N
2014	MEMBREPOL	2004-10-05 00:00:00	2008-03-30 00:00:00	ANCIEN	\N	\N	\N	\N	1751	\N	\N
2016	MEMBREPOL	2004-10-05 00:00:00	2011-10-30 00:00:00	ANCIEN	\N	\N	\N	\N	1753	\N	\N
2017	MEMBREPOL	2004-10-05 00:00:00	2007-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	1754	\N	\N
2018	MEMBREPOL	2004-10-05 00:00:00	2007-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1755	\N	\N
2019	MEMBREPOL	2004-10-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1756	\N	\N
2020	MEMBREPOL	2004-10-05 00:00:00	2016-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	1757	\N	2016-12-01 10:36:51
2021	MEMBREPOL	2004-10-05 00:00:00	2017-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	1758	\N	2017-09-24 11:09:53
2022	MEMBREPOL	2004-10-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1759	\N	\N
2024	MEMBREPOL	2004-10-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1760	\N	2017-09-24 18:59:59
2025	MEMBREPOL	2004-10-05 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	1761	\N	\N
2026	MEMBREPOL	2004-10-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1762	\N	\N
2027	MEMBREPOL	2004-10-05 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1763	\N	2017-10-03 16:54:49
2028	MEMBREPOL	2004-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	1764	\N	\N
2029	MEMBREPOL	2004-10-05 00:00:00	2004-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	1765	\N	\N
2030	MEMBREPOL	2004-10-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1766	\N	\N
2031	MEMBREPOL	2004-10-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1767	\N	2017-09-24 17:15:15
2032	MEMBREPOL	2004-10-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1768	\N	\N
2033	MEMBREPOL	2004-10-05 00:00:00	2011-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	1769	\N	\N
2034	MEMBREPOL	2004-10-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1770	\N	\N
2035	MEMBREPOL	2004-10-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1771	\N	\N
2036	MEMBREPOL	2004-10-05 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	1772	\N	\N
2037	MEMBREPOL	2004-10-05 00:00:00	2011-10-30 00:00:00	ANCIEN	\N	\N	\N	\N	1773	\N	\N
2038	MEMBREPOL	2004-10-05 00:00:00	2005-02-24 00:00:00	ANCIEN	\N	\N	\N	\N	1774	\N	\N
2039	MEMBREPOL	2004-10-05 00:00:00	2007-07-16 00:00:00	ANCIEN	\N	\N	\N	\N	1775	\N	\N
2040	MEMBREPOL	2004-10-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1776	\N	\N
2041	MEMBREPOL	2004-10-05 00:00:00	2004-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	1777	\N	\N
2042	MEMBREPOL	2004-10-06 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1778	\N	\N
2043	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1779	\N	\N
2045	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1781	\N	\N
2046	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1782	\N	\N
2047	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1783	\N	\N
2048	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1784	\N	\N
2049	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1785	\N	\N
2050	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1786	\N	\N
2051	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1787	\N	\N
2052	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1788	\N	\N
2053	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	1789	\N	\N
1520	MEMBREPOL	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1260	\N	\N
1521	MEMBREPOL	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1261	\N	\N
1523	MEMBREPOL	\N	1975-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	1263	\N	\N
1524	MEMBREPOL	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1264	\N	\N
1525	MEMBREPOL	\N	1967-04-03 00:00:00	ANCIEN	\N	\N	\N	\N	1265	\N	\N
1526	MEMBREPOL	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1266	\N	\N
1528	MEMBREPOL	\N	1963-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	1268	\N	\N
1529	MEMBREPOL	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1269	\N	\N
1530	MEMBREPOL	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1270	\N	\N
1532	MEMBREPOL	\N	1977-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	1272	\N	\N
1533	MEMBREPOL	\N	1994-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	1273	\N	\N
1534	MEMBREPOL	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1274	\N	\N
1535	MEMBREPOL	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	1275	\N	\N
1536	MEMBREPOL	\N	1989-05-18 00:00:00	ANCIEN	\N	\N	\N	\N	1276	\N	\N
1537	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1277	\N	\N
1538	MEMBREPOL	\N	1985-05-13 00:00:00	ANCIEN	\N	\N	\N	\N	1278	\N	\N
1539	MEMBREPOL	\N	1981-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	1279	\N	\N
1540	MEMBREPOL	\N	1998-04-05 00:00:00	ANCIEN	\N	\N	\N	\N	1280	\N	\N
1541	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1281	\N	\N
1542	MEMBREPOL	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1282	\N	\N
1543	MEMBREPOL	\N	1979-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	1283	\N	\N
1544	MEMBREPOL	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1284	\N	\N
1545	MEMBREPOL	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1285	\N	\N
1546	MEMBREPOL	\N	1973-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	1286	\N	\N
1547	MEMBREPOL	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1287	\N	\N
1548	MEMBREPOL	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1288	\N	\N
1549	MEMBREPOL	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1289	\N	\N
1550	MEMBREPOL	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1290	\N	\N
1551	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1291	\N	\N
1552	MEMBREPOL	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1292	\N	\N
1553	MEMBREPOL	\N	1978-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	1293	\N	\N
1554	MEMBREPOL	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1294	\N	\N
1555	MEMBREPOL	\N	1977-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	1295	\N	\N
1556	MEMBREPOL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1296	\N	\N
1557	MEMBREPOL	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1297	\N	\N
1558	MEMBREPOL	\N	1995-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	1298	\N	\N
1559	MEMBREPOL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1299	\N	\N
1560	MEMBREPOL	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1300	\N	\N
1561	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1301	\N	\N
1562	MEMBREPOL	\N	1990-06-14 00:00:00	ANCIEN	\N	\N	\N	\N	1302	\N	\N
1563	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1303	\N	\N
1564	MEMBREPOL	\N	1973-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	1304	\N	\N
1565	MEMBREPOL	\N	1981-05-26 00:00:00	ANCIEN	\N	\N	\N	\N	1305	\N	\N
1566	MEMBREPOL	\N	1998-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	1306	\N	\N
1567	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1307	\N	\N
1568	MEMBREPOL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1308	\N	\N
1569	MEMBREPOL	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1309	\N	\N
1570	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1310	\N	\N
1571	MEMBREPOL	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1311	\N	\N
1572	MEMBREPOL	\N	1992-03-20 00:00:00	ANCIEN	\N	\N	\N	\N	1312	\N	\N
1573	MEMBREPOL	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1313	\N	\N
1574	MEMBREPOL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1314	\N	\N
1575	MEMBREPOL	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1315	\N	\N
1576	MEMBREPOL	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1316	\N	\N
1577	MEMBREPOL	\N	1997-09-11 00:00:00	ANCIEN	\N	\N	\N	\N	1317	\N	\N
1578	MEMBREPOL	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1318	\N	\N
1579	MEMBREPOL	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1319	\N	\N
1580	MEMBREPOL	\N	1978-03-12 00:00:00	ANCIEN	\N	\N	\N	\N	1320	\N	\N
1581	MEMBREPOL	\N	1977-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1321	\N	\N
1582	MEMBREPOL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1322	\N	\N
1583	MEMBREPOL	\N	1959-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	1323	\N	\N
1584	MEMBREPOL	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1324	\N	\N
1585	MEMBREPOL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1325	\N	\N
1586	MEMBREPOL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1326	\N	\N
1587	MEMBREPOL	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1327	\N	\N
1588	MEMBREPOL	\N	1976-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	1328	\N	\N
1589	MEMBREPOL	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1329	\N	\N
1590	MEMBREPOL	\N	1997-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	1330	\N	\N
1591	MEMBREPOL	\N	1967-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	1331	\N	\N
1592	MEMBREPOL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1332	\N	\N
1593	MEMBREPOL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1333	\N	\N
1595	MEMBREPOL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1335	\N	\N
1596	MEMBREPOL	\N	1984-12-25 00:00:00	ANCIEN	\N	\N	\N	\N	1336	\N	\N
1597	MEMBREPOL	\N	1997-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	1337	\N	\N
1599	MEMBREPOL	\N	1959-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	1339	\N	\N
1600	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1340	\N	\N
1601	MEMBREPOL	\N	1969-09-12 00:00:00	ANCIEN	\N	\N	\N	\N	1341	\N	\N
1602	MEMBREPOL	\N	1995-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	1342	\N	\N
1604	MEMBREPOL	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1344	\N	\N
1605	MEMBREPOL	\N	1974-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	1345	\N	\N
782	MEMBREPOL	2002-12-11 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	786	\N	2014-09-29 13:43:10
783	MEMBREPOL	2002-12-11 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	787	\N	2014-09-28 16:42:05
784	MEMBREPOL	2002-12-11 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	788	\N	\N
785	MEMBREPOL	2002-12-11 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	789	\N	2014-09-28 17:22:11
786	MEMBREPOL	2002-12-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	790	\N	2017-10-01 09:22:38
787	MEMBREPOL	2002-12-11 00:00:00	2011-10-30 00:00:00	ANCIEN	\N	\N	\N	\N	791	\N	\N
788	MEMBREPOL	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	792	\N	\N
789	MEMBREPOL	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	793	\N	\N
790	MEMBREPOL	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	794	\N	\N
791	MEMBREPOL	2002-12-11 00:00:00	2009-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	795	\N	\N
792	MEMBREPOL	2002-12-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	796	\N	2017-09-24 17:35:15
793	MEMBREPOL	2002-12-11 00:00:00	2003-08-01 00:00:00	ANCIEN	\N	\N	\N	\N	797	\N	\N
794	MEMBREPOL	2002-12-11 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	798	\N	2014-09-28 17:12:41
795	MEMBREPOL	2002-12-11 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	799	\N	2017-10-03 16:54:03
796	MEMBREPOL	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	800	\N	\N
184	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	184	\N	\N
288	PDTPOL	1995-11-14 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	288	\N	\N
797	MEMBREPOL	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	801	\N	\N
798	VICPDTDELPOL	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	802	\N	\N
799	MEMBREPOL	2002-12-11 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	803	\N	\N
800	MEMBREPOL	2002-12-11 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	804	\N	\N
801	MEMBREPOL	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	805	\N	\N
802	MEMBREPOL	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	806	\N	\N
803	MEMBREPOL	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	807	\N	\N
804	MEMBREPOL	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	808	\N	\N
805	MEMBREPOL	2002-12-11 00:00:00	2004-06-01 00:00:00	ANCIEN	\N	\N	\N	\N	809	\N	\N
806	MEMBREPOL	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	810	\N	\N
807	MEMBREPOL	2002-12-11 00:00:00	2007-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	811	\N	\N
808	MEMBREPOL	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	812	\N	\N
809	MEMBREPOL	2002-12-11 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	813	\N	2015-10-13 14:17:47
810	MEMBREPOL	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	814	\N	\N
811	MEMBREPOL	2002-12-11 00:00:00	2011-10-30 00:00:00	ANCIEN	\N	\N	\N	\N	815	\N	\N
812	MEMBREPOL	2002-12-11 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	816	\N	\N
813	MEMBREPOL	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	817	\N	\N
814	MEMBREPOL	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	818	\N	\N
815	MEMBREPOL	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	819	\N	\N
816	MEMBREPOL	2002-12-11 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	820	\N	\N
817	MEMBREPOL	2002-12-11 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	821	\N	\N
818	MEMBREPOL	2002-12-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	822	\N	2017-09-24 18:59:59
819	MEMBREPOL	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	823	\N	\N
820	MEMBREPOL	2002-12-11 00:00:00	2007-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	824	\N	\N
821	MEMBREPOL	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	825	\N	\N
822	MEMBREPOL	2002-12-11 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	826	\N	2014-09-28 12:56:42
823	MEMBREPOL	2002-12-11 00:00:00	2007-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	827	\N	\N
824	MEMBREPOL	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	828	\N	\N
825	MEMBREPOL	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	829	\N	\N
211	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	211	\N	\N
255	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	255	\N	\N
312	MEMBREPOL	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	312	\N	\N
826	MEMBREPOL	2002-12-11 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	830	\N	\N
827	MEMBREPOL	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	831	\N	\N
828	MEMBREPOL	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	832	\N	\N
829	MEMBREPOL	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	833	\N	\N
830	MEMBREPOL	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	834	\N	\N
831	MEMBREPOL	2002-12-11 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	835	\N	\N
832	PDTPOL	2002-12-11 00:00:00	2009-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	223	\N	\N
835	MEMBREPOL	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	836	\N	\N
838	MEMBREPOL	2003-01-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	840	\N	2017-09-24 18:59:59
837	MEMBREPOL	2003-01-15 00:00:00	2014-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	839	\N	2014-07-09 18:28:14
847	MEMBREPOL	2003-02-09 00:00:00	2003-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	855	\N	\N
848	MEMBREPOL	2003-02-12 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	856	\N	2014-09-28 13:40:33
1119	MEMBREPOL	\N	1997-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	859	\N	\N
1120	MEMBREPOL	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	860	\N	\N
1122	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	862	\N	\N
1123	MEMBREPOL	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	863	\N	\N
1784	MEMBREPOL	\N	1963-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	1524	\N	\N
1785	MEMBREPOL	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1525	\N	\N
1786	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1526	\N	\N
1787	MEMBREPOL	\N	1974-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	1527	\N	\N
1788	MEMBREPOL	\N	1993-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	1528	\N	\N
1789	MEMBREPOL	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1529	\N	\N
1790	MEMBREPOL	\N	1968-10-29 00:00:00	ANCIEN	\N	\N	\N	\N	1530	\N	\N
1791	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1531	\N	\N
1792	MEMBREPOL	\N	1965-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	1532	\N	\N
1794	MEMBREPOL	\N	1972-10-19 00:00:00	ANCIEN	\N	\N	\N	\N	1534	\N	\N
1795	MEMBREPOL	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1535	\N	\N
1796	MEMBREPOL	\N	1968-09-19 00:00:00	ANCIEN	\N	\N	\N	\N	1536	\N	\N
1798	MEMBREPOL	\N	1961-08-22 00:00:00	ANCIEN	\N	\N	\N	\N	1538	\N	\N
1799	MEMBREPOL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1539	\N	\N
1800	MEMBREPOL	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1540	\N	\N
1801	MEMBREPOL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1541	\N	\N
1803	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1543	\N	\N
1804	MEMBREPOL	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1544	\N	\N
1805	MEMBREPOL	\N	1971-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	1545	\N	\N
1806	MEMBREPOL	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1546	\N	\N
1808	MEMBREPOL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1548	\N	\N
1809	MEMBREPOL	\N	1966-04-24 00:00:00	ANCIEN	\N	\N	\N	\N	1549	\N	\N
1810	MEMBREPOL	\N	1973-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	1550	\N	\N
1812	MEMBREPOL	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1552	\N	\N
1813	MEMBREPOL	\N	1968-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	1553	\N	\N
1814	MEMBREPOL	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1554	\N	\N
1815	MEMBREPOL	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1555	\N	\N
1817	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1557	\N	\N
1818	MEMBREPOL	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1558	\N	\N
1819	MEMBREPOL	\N	1962-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1559	\N	\N
1821	MEMBREPOL	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1561	\N	\N
1822	MEMBREPOL	\N	1959-04-29 00:00:00	ANCIEN	\N	\N	\N	\N	1562	\N	\N
1823	MEMBREPOL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1563	\N	\N
1824	MEMBREPOL	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1564	\N	\N
1826	MEMBREPOL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1566	\N	\N
1827	MEMBREPOL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1567	\N	\N
1828	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1568	\N	\N
1830	MEMBREPOL	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1570	\N	\N
1831	MEMBREPOL	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	1571	\N	\N
1832	MEMBREPOL	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	1572	\N	\N
1833	MEMBREPOL	\N	1996-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	1573	\N	\N
1834	MEMBREPOL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1574	\N	\N
1836	MEMBREPOL	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1576	\N	\N
1837	MEMBREPOL	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1577	\N	\N
1838	MEMBREPOL	\N	1974-05-22 00:00:00	ANCIEN	\N	\N	\N	\N	1578	\N	\N
1839	MEMBREPOL	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	1579	\N	\N
1840	MEMBREPOL	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1580	\N	\N
1841	MEMBREPOL	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1581	\N	\N
1842	MEMBREPOL	\N	1995-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	1582	\N	\N
1843	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1583	\N	\N
1844	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1584	\N	\N
1845	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1585	\N	\N
1846	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1586	\N	\N
1847	MEMBREPOL	\N	1961-07-18 00:00:00	ANCIEN	\N	\N	\N	\N	1587	\N	\N
1848	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1588	\N	\N
1849	MEMBREPOL	\N	1961-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	1589	\N	\N
1850	MEMBREPOL	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1590	\N	\N
1851	MEMBREPOL	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	1591	\N	\N
1852	MEMBREPOL	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	1592	\N	\N
1853	MEMBREPOL	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	1593	\N	\N
1854	MEMBREPOL	\N	1987-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	1594	\N	\N
1855	MEMBREPOL	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	1595	\N	\N
1856	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1596	\N	\N
1857	MEMBREPOL	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	1597	\N	\N
1858	MEMBREPOL	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1598	\N	\N
1859	MEMBREPOL	\N	1990-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	1599	\N	\N
1860	MEMBREPOL	\N	1996-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	1600	\N	\N
1861	MEMBREPOL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1601	\N	\N
1862	MEMBREPOL	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	1602	\N	\N
1863	MEMBREPOL	\N	1995-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	1603	\N	\N
1864	MEMBREPOL	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1604	\N	\N
1865	MEMBREPOL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1605	\N	\N
1866	MEMBREPOL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1606	\N	\N
1867	MEMBREPOL	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	1607	\N	\N
1868	MEMBREPOL	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	1608	\N	\N
1869	MEMBREPOL	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	1609	\N	\N
1870	MEMBREPOL	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1610	\N	\N
1871	MEMBREPOL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1611	\N	\N
1872	MEMBREPOL	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1612	\N	\N
1873	MEMBREPOL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1613	\N	\N
1874	MEMBREPOL	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1614	\N	\N
1875	MEMBREPOL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1615	\N	\N
1876	MEMBREPOL	\N	1969-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	1616	\N	\N
1877	MEMBREPOL	\N	1968-10-24 00:00:00	ANCIEN	\N	\N	\N	\N	1617	\N	\N
1878	MEMBREPOL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1618	\N	\N
1879	MEMBREPOL	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1619	\N	\N
1880	MEMBREPOL	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	1620	\N	\N
1881	MEMBREPOL	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	1621	\N	\N
1882	MEMBREPOL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1622	\N	\N
1883	MEMBREPOL	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	1623	\N	\N
1194	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	934	\N	\N
1198	MEMBREPOL	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	938	\N	\N
1203	MEMBREPOL	\N	1989-09-17 00:00:00	ANCIEN	\N	\N	\N	\N	943	\N	\N
1208	MEMBREPOL	\N	1976-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	948	\N	\N
1212	MEMBREPOL	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	952	\N	\N
1217	MEMBREPOL	\N	1987-02-27 00:00:00	ANCIEN	\N	\N	\N	\N	957	\N	\N
1221	MEMBREPOL	\N	1990-01-14 00:00:00	ANCIEN	\N	\N	\N	\N	961	\N	\N
1226	MEMBREPOL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	966	\N	\N
1230	MEMBREPOL	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	970	\N	\N
1235	MEMBREPOL	\N	1965-08-19 00:00:00	ANCIEN	\N	\N	\N	\N	975	\N	\N
1294	MEMBREPOL	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1034	\N	\N
1298	MEMBREPOL	\N	1973-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	1038	\N	\N
1303	MEMBREPOL	\N	1984-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1043	\N	\N
1308	MEMBREPOL	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1048	\N	\N
1312	MEMBREPOL	\N	1967-05-11 00:00:00	ANCIEN	\N	\N	\N	\N	1052	\N	\N
1317	MEMBREPOL	\N	1985-04-02 00:00:00	ANCIEN	\N	\N	\N	\N	1057	\N	\N
1321	MEMBREPOL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1061	\N	\N
1326	MEMBREPOL	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1066	\N	\N
1330	MEMBREPOL	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1070	\N	\N
1335	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1075	\N	\N
1394	MEMBREPOL	\N	1965-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	1134	\N	\N
1398	MEMBREPOL	\N	1983-07-28 00:00:00	ANCIEN	\N	\N	\N	\N	1138	\N	\N
1403	MEMBREPOL	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1143	\N	\N
1408	MEMBREPOL	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1148	\N	\N
1412	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1152	\N	\N
1417	MEMBREPOL	\N	1980-07-28 00:00:00	ANCIEN	\N	\N	\N	\N	1157	\N	\N
1421	MEMBREPOL	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1161	\N	\N
1426	MEMBREPOL	\N	1967-04-03 00:00:00	ANCIEN	\N	\N	\N	\N	1166	\N	\N
1430	MEMBREPOL	\N	1995-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	1170	\N	\N
1435	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1175	\N	\N
1495	MEMBREPOL	\N	1959-05-28 00:00:00	ANCIEN	\N	\N	\N	\N	1235	\N	\N
1499	MEMBREPOL	\N	1962-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1239	\N	\N
1504	MEMBREPOL	\N	1962-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	1244	\N	\N
1508	MEMBREPOL	\N	1977-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	1248	\N	\N
1513	MEMBREPOL	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1253	\N	\N
1518	MEMBREPOL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1258	\N	\N
1522	MEMBREPOL	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	1262	\N	\N
1527	MEMBREPOL	\N	1972-05-08 00:00:00	ANCIEN	\N	\N	\N	\N	1267	\N	\N
1531	MEMBREPOL	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1271	\N	\N
1594	MEMBREPOL	\N	1997-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	1334	\N	\N
1598	MEMBREPOL	\N	1962-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	1338	\N	\N
1603	MEMBREPOL	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1343	\N	\N
1608	MEMBREPOL	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1348	\N	\N
1612	MEMBREPOL	\N	1992-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	1352	\N	\N
1617	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1357	\N	\N
1621	MEMBREPOL	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1361	\N	\N
1626	MEMBREPOL	\N	1988-06-24 00:00:00	ANCIEN	\N	\N	\N	\N	1366	\N	\N
1630	MEMBREPOL	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1370	\N	\N
1635	MEMBREPOL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1375	\N	\N
1694	MEMBREPOL	\N	1987-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1434	\N	\N
1698	MEMBREPOL	\N	1988-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	1438	\N	\N
1703	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1443	\N	\N
1708	MEMBREPOL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1448	\N	\N
1712	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1452	\N	\N
1717	MEMBREPOL	\N	1996-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	1457	\N	\N
1721	MEMBREPOL	\N	1970-06-13 00:00:00	ANCIEN	\N	\N	\N	\N	1461	\N	\N
1726	MEMBREPOL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1466	\N	\N
1730	MEMBREPOL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1470	\N	\N
2404	MEMBREPOL	2011-10-01 00:00:00	2011-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	2126	\N	\N
2405	MEMBREPOL	2011-10-04 00:00:00	2014-08-26 00:00:00	ANCIEN	\N	\N	\N	\N	2127	\N	2014-08-27 16:33:38
2407	MEMBREPOL	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2129	\N	2017-09-24 13:14:55
2718	MEMBREPOL	2013-09-11 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2398	2013-09-11 15:03:01	2014-10-07 19:25:11
2716	MEMBREPOL	2013-06-05 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2395	2013-06-04 17:13:39	2014-09-28 17:34:16
2717	MEMBREPOL	2013-06-29 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2397	2013-07-01 09:35:52	2014-09-28 17:14:21
2722	MEMBREPOL	2013-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2402	2013-10-22 16:16:09	2017-09-24 18:17:56
2398	MEMBREPOL	2011-03-08 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	795	\N	\N
2190	MEMBREPOL	2008-10-01 00:00:00	2011-10-30 00:00:00	ANCIEN	\N	\N	\N	\N	1906	\N	\N
2192	MEMBREPOL	2008-10-01 00:00:00	2011-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	1908	\N	\N
2193	MEMBREPOL	2008-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1909	\N	2017-10-01 10:17:18
2207	MEMBREPOL	2008-10-01 00:00:00	2011-10-30 00:00:00	ANCIEN	\N	\N	\N	\N	1928	\N	\N
2232	MEMBREPOL	2008-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1957	\N	\N
2248	MEMBREPOL	2008-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1975	\N	2014-09-28 12:44:31
2250	MEMBREPOL	2008-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1977	\N	\N
2253	MEMBREPOL	2008-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1980	\N	\N
2259	MEMBREPOL	2008-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1988	\N	\N
2261	MEMBREPOL	2008-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	1990	\N	\N
2265	VICPDTPOL	2008-10-01 00:00:00	2011-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	1994	\N	\N
2269	MEMBREPOL	2008-10-01 00:00:00	2020-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	1998	\N	\N
2136	MEMBREPOL	2007-06-25 00:00:00	2009-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	1857	\N	\N
2354	MEMBREPOL	2008-11-28 00:00:00	2010-01-07 00:00:00	ANCIEN	\N	\N	\N	\N	2081	\N	\N
2369	MEMBREPOL	2010-03-07 00:00:00	2010-03-09 00:00:00	ANCIEN	\N	\N	\N	\N	2096	\N	\N
2413	MEMBREPOL	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2135	\N	\N
2401	MEMBREPOL	2011-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2123	\N	\N
2402	MEMBREPOL	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2124	\N	\N
2403	MEMBREPOL	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2125	\N	2017-09-24 10:41:28
2414	MEMBREPOL	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2136	\N	\N
2589	MEMBREPOL	2011-10-01 00:00:00	2012-10-22 00:00:00	ANCIEN	\N	\N	\N	\N	2315	\N	\N
2614	MEMBREPOL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2330	\N	2014-09-28 17:05:42
2616	PDTPOL	2011-10-01 00:00:00	2014-04-14 00:00:00	ANCIEN	\N	\N	\N	\N	2043	\N	2014-04-15 16:20:59
2466	MEMBREPOL	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2192	\N	2017-09-24 19:14:37
2646	VICPDTPOL	2011-11-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	1928	\N	2014-10-07 15:28:17
2647	VICPDTPOL	2011-11-01 00:00:00	2011-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	1773	\N	\N
2648	VICPDTPOL	2011-11-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	1906	\N	2014-10-07 15:28:15
2649	VICPDTPOL	2011-11-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	743	\N	2014-10-07 15:27:46
2472	MEMBREPOL	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2198	\N	\N
2650	VICPDTPOL	2011-11-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	765	\N	2014-09-28 16:42:05
2651	VICPDTPOL	2011-11-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	1753	\N	2014-10-07 15:28:13
2652	VICPDTPOL	2011-11-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	716	\N	2014-10-07 15:28:11
2653	VICPDTPOL	2011-11-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	815	\N	2014-09-28 17:40:23
2480	MEMBREPOL	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2206	\N	2017-09-24 16:45:26
2481	MEMBREPOL	2011-10-01 00:00:00	2011-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	2207	\N	\N
2654	VICPDTPOL	2011-11-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	1817	\N	2014-10-07 15:28:09
2655	VICPDTPOL	2011-11-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2058	\N	2014-10-07 15:28:04
2656	VICPDTPOL	2011-11-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2060	\N	2014-10-07 15:28:07
2487	MEMBREPOL	2011-10-01 00:00:00	2015-06-10 00:00:00	ANCIEN	\N	\N	\N	\N	2213	\N	2015-06-11 18:55:48
2488	MEMBREPOL	2011-10-01 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	2214	\N	2017-06-29 09:53:49
2657	VICPDTPOL	2011-11-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	791	\N	2014-10-07 15:27:54
2490	MEMBREPOL	2011-10-01 00:00:00	2015-06-09 00:00:00	ANCIEN	\N	\N	\N	\N	2216	\N	2015-06-11 18:53:33
2663	PDTPOL	2012-01-11 00:00:00	2015-11-05 00:00:00	ANCIEN	\N	\N	\N	\N	2342	\N	2015-11-05 19:31:11
2664	VICPDTPOL	2012-01-11 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	2343	\N	2015-02-19 10:38:10
2665	MEMBREPOL	2012-01-11 00:00:00	2016-05-03 00:00:00	ANCIEN	\N	\N	\N	\N	2344	\N	2016-05-04 12:32:27
2666	MEMBREPOL	2012-01-11 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	2345	\N	2015-02-19 10:38:18
2498	MEMBREPOL	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2224	\N	2017-09-24 13:57:40
2500	MEMBREPOL	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2226	\N	2017-09-24 18:20:10
2501	MEMBREPOL	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2227	\N	\N
2502	MEMBREPOL	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	2228	\N	\N
2503	MEMBREPOL	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2229	\N	\N
2667	MEMBREPOL	2012-01-11 00:00:00	2017-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	2346	\N	2017-06-30 09:52:11
2669	MEMBREPOL	2012-01-11 00:00:00	2017-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	2348	\N	2017-06-30 09:52:11
2670	MEMBREPOL	2012-01-11 00:00:00	2017-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	2349	\N	2017-06-30 09:52:11
2671	MEMBREPOL	2012-01-11 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	2350	\N	2017-06-29 09:54:06
2510	MEMBREPOL	2011-10-01 00:00:00	2011-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	2236	\N	\N
2513	MEMBREPOL	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2239	\N	2017-09-24 16:24:51
2514	MEMBREPOL	2011-10-01 00:00:00	2014-07-01 00:00:00	ANCIEN	\N	\N	\N	\N	2240	\N	2014-07-01 09:29:54
2675	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	2354	\N	\N
2676	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	2355	\N	\N
2677	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	2356	\N	\N
2678	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	2357	\N	\N
2520	MEMBREPOL	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2246	\N	2017-09-24 17:29:37
2521	MEMBREPOL	2011-10-01 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	2247	\N	2017-06-29 09:55:16
2522	MEMBREPOL	2011-10-01 00:00:00	2014-05-11 00:00:00	ANCIEN	\N	\N	\N	\N	2248	\N	2014-05-12 09:52:22
2679	MEMBREPOL	2011-10-01 00:00:00	2011-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	2358	\N	\N
2525	MEMBREPOL	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2251	\N	2017-09-24 17:42:26
2526	MEMBREPOL	2011-10-01 00:00:00	2013-02-28 00:00:00	ANCIEN	\N	\N	\N	\N	2252	\N	\N
2680	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	2359	\N	\N
2529	MEMBREPOL	2011-10-01 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	2255	\N	\N
2681	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	2360	\N	\N
2682	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	2361	\N	\N
2683	MEMBREPOL	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	2363	\N	\N
2533	MEMBREPOL	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2259	\N	\N
2684	MEMBREPOL	2010-03-16 00:00:00	2010-03-21 00:00:00	ANCIEN	\N	\N	\N	\N	2364	\N	\N
2538	MEMBREPOL	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2264	\N	\N
2539	MEMBREPOL	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2265	\N	\N
2540	MEMBREPOL	2011-10-01 00:00:00	2012-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	2266	\N	\N
2542	MEMBREPOL	2011-10-01 00:00:00	2011-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	2268	\N	\N
2662	VICPDTPOL	2012-01-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2059	\N	2014-10-07 15:27:49
2591	MEMBREPOL	2011-10-04 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	262	\N	\N
2592	MEMBREPOL	2011-10-04 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	1994	\N	\N
2595	MEMBREPOL	2011-10-01 00:00:00	2019-06-13 00:00:00	ANCIEN	\N	\N	\N	\N	2318	\N	\N
2705	MEMBREPOL	2012-09-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2384	\N	\N
2599	MEMBREPOL	2011-10-01 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	2321	\N	2015-06-12 15:59:49
2602	MEMBREPOL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	820	\N	2014-09-28 12:56:42
2603	PDTPOL	2011-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	785	\N	2014-10-07 15:27:42
2609	MEMBREPOL	2011-10-01 00:00:00	2012-11-09 00:00:00	ANCIEN	\N	\N	\N	\N	2328	\N	\N
2588	MEMBREPOL	2011-09-26 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2314	\N	2014-09-28 12:21:28
2628	VICPDTPOL	2011-11-02 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1737	\N	2014-09-28 17:07:41
2629	VICPDTPOL	2011-11-02 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	592	\N	2014-10-07 15:50:58
2630	VICPDTPOL	2011-11-02 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2107	\N	2014-10-07 15:51:05
2631	VICPDTPOL	2011-11-02 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2310	\N	2014-10-07 15:51:00
2632	VICPDTPOL	2011-11-02 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1744	\N	2014-09-28 16:40:50
2635	VICPDTDELPOL	2011-11-02 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	1736	\N	2014-10-07 15:28:02
2636	VICPDTDELPOL	2011-11-02 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	1769	\N	2014-10-07 15:27:58
2704	MEMBREPOL	2012-09-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2383	\N	2017-09-24 17:15:15
2709	MEMBREPOL	2012-11-07 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2386	\N	2014-10-07 15:49:04
2587	MEMBREPOL	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2313	\N	\N
2706	PDTPOL	2012-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	1721	\N	2017-10-03 16:43:31
2638	VICPDTDELPOL	2011-11-02 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	1908	\N	2014-10-07 16:59:24
2639	VICPDTPOL	2011-11-02 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	390	\N	2014-09-28 17:27:35
2640	VICPDTPOL	2011-11-02 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2036	\N	2014-10-07 16:59:29
2641	VICPDTPOL	2011-11-02 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2236	\N	2014-10-07 16:59:28
2642	VICPDTPOL	2011-11-02 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2294	\N	2014-10-07 16:59:34
2643	VICPDTPOL	2011-11-02 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2022	\N	2014-09-28 17:00:59
2619	MEMBREPOL	2011-10-01 00:00:00	2011-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	592	\N	\N
2575	MEMBREPOL	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2301	\N	\N
2581	MEMBREPOL	2011-10-01 00:00:00	2011-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	2307	\N	\N
2583	MEMBREPOL	2011-10-01 00:00:00	2012-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	2309	\N	\N
2584	MEMBREPOL	2011-10-01 00:00:00	2011-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	2310	\N	\N
2707	MEMBREPOL	2012-09-19 00:00:00	2012-09-19 00:00:00	ANCIEN	\N	\N	\N	\N	183	\N	\N
2701	MEMBREPOL	2012-07-22 00:00:00	2014-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	2380	\N	2014-05-05 10:35:50
2702	MEMBREPOL	2012-07-22 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	2381	\N	2014-05-05 10:35:23
2703	MEMBREPOL	2012-07-22 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	2382	\N	2014-05-05 10:33:42
2611	MEMBREPOL	2011-10-01 00:00:00	2011-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	390	\N	\N
2612	MEMBREPOL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	322	\N	2014-09-28 12:54:15
2613	MEMBREPOL	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1688	\N	2017-09-24 18:17:56
2714	MEMBREPOL	2013-03-01 00:00:00	2016-03-08 00:00:00	ANCIEN	\N	\N	\N	\N	2393	\N	2016-03-09 11:10:19
2661	VICPDTPOL	2011-12-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2341	\N	2014-10-07 15:27:44
2622	MEMBREPOL	2011-10-11 00:00:00	2011-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	2332	\N	\N
2626	MEMBREPOL	2011-11-02 00:00:00	2012-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	2336	\N	\N
2712	MEMBREPOL	2012-12-04 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2389	\N	2014-09-28 17:31:42
2590	MEMBREPOL	2011-10-01 00:00:00	2016-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	2316	\N	2016-11-14 11:07:47
2698	MEMBREPOL	2012-06-17 00:00:00	2014-04-23 00:00:00	ANCIEN	\N	\N	\N	\N	2376	\N	2014-04-23 09:56:25
2699	MEMBREPOL	2012-06-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2377	\N	\N
2700	MEMBREPOL	2012-06-17 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2378	\N	2014-10-09 09:10:11
2693	MEMBREPOL	2012-06-17 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	2373	\N	2014-05-05 10:34:09
2708	MEMBREPOL	2012-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2385	\N	2017-09-24 17:47:27
2710	MEMBREPOL	2012-12-03 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	2388	\N	2017-06-29 09:53:55
2713	MEMBREPOL	2013-02-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2390	\N	2014-09-28 17:58:04
2720	MEMBREPOL	2013-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2400	2013-10-01 15:26:12	2014-09-28 18:00:58
2724	MEMBREPOL	2014-01-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	2409	2014-01-07 16:41:44	\N
2727	MEMBREPOL	2014-04-15 00:00:00	2014-05-02 00:00:00	ANCIEN	\N	\N	\N	\N	2043	2014-04-15 16:20:57	2014-05-05 14:01:35
2728	PDTPOL	2014-04-15 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	2033	2014-04-15 16:21:15	2018-01-23 16:14:49
2729	MEMBREPOL	2014-04-23 00:00:00	2014-04-27 00:00:00	ANCIEN	\N	\N	\N	\N	2412	2014-04-23 09:57:24	2014-04-28 10:39:24
2746	MEMBREPOL	2014-06-11 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2428	2014-06-11 18:26:34	2014-09-28 18:19:47
2750	MEMBREPOL	2014-08-27 00:00:00	2014-09-08 00:00:00	ANCIEN	\N	\N	\N	\N	2432	2014-08-27 16:32:46	2014-09-09 15:48:13
2753	MEMBREPOL	2014-09-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2435	2014-09-09 15:48:11	2017-09-24 18:49:56
2764	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2446	2014-09-28 14:31:41	2014-10-07 15:36:26
2818	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2500	2014-09-28 18:32:19	2014-10-07 15:40:07
2820	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2502	2014-09-28 18:44:07	2014-10-07 17:08:27
2826	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2508	2014-09-28 18:59:41	2014-10-07 17:37:28
2844	MEMBREPOL	2014-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2526	2014-10-07 14:47:48	\N
2845	MEMBREPOL	2014-10-07 00:00:00	2017-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	785	2014-10-07 15:27:42	2017-09-24 11:09:53
2846	VICPDTDELPOL	2014-10-07 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2341	2014-10-07 15:27:44	2017-10-03 17:15:04
2847	MEMBREPOL	2014-10-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	743	2014-10-07 15:27:46	2017-09-24 17:28:55
2848	MEMBREPOL	2014-10-07 00:00:00	2020-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	2059	2014-10-07 15:27:49	\N
2849	MEMBREPOL	2014-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	791	2014-10-07 15:27:54	\N
2850	MEMBREPOL	2014-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1769	2014-10-07 15:27:58	\N
2851	MEMBREPOL	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	1736	2014-10-07 15:28:02	\N
2852	MEMBREPOL	2014-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2058	2014-10-07 15:28:04	\N
2853	MEMBREPOL	2014-10-07 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2060	2014-10-07 15:28:07	2017-10-01 10:20:50
2854	MEMBREPOL	2014-10-07 00:00:00	2019-04-03 00:00:00	ANCIEN	\N	\N	\N	\N	1817	2014-10-07 15:28:09	\N
2855	MEMBREPOL	2014-10-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	716	2014-10-07 15:28:11	2017-09-24 18:17:56
2856	MEMBREPOL	2014-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1753	2014-10-07 00:00:00	\N
2857	MEMBREPOL	2014-10-07 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1906	2014-10-07 15:28:15	2017-10-01 09:41:22
2858	MEMBREPOL	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	1928	2014-10-07 15:28:17	\N
2859	MEMBREPOL	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	2527	2014-10-07 15:28:26	\N
2860	MEMBREPOL	2014-10-07 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2528	2014-10-07 15:28:35	2017-10-01 10:22:23
2861	MEMBREPOL	2014-10-07 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2529	2014-10-07 15:28:58	2017-10-03 16:53:31
2862	MEMBREPOL	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	2530	2014-10-07 15:29:12	\N
2863	MEMBREPOL	2014-10-07 00:00:00	2017-06-01 00:00:00	ANCIEN	\N	\N	\N	\N	2531	2014-10-07 15:29:28	2017-06-02 10:02:57
2864	MEMBREPOL	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	2532	2014-10-07 15:29:55	\N
2865	MEMBREPOL	2014-10-07 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2533	2014-10-07 15:30:26	2017-10-01 10:34:22
2866	MEMBREPOL	2014-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2534	2014-10-07 15:30:46	\N
2867	MEMBREPOL	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	2535	2014-10-07 15:31:07	\N
2868	MEMBREPOL	2014-10-07 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2536	2014-10-07 15:31:26	\N
2869	MEMBREPOL	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	2537	2014-10-07 15:32:16	\N
2979	MEMBREPOL	2015-01-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2628	2015-01-09 15:18:35	2017-09-24 17:29:37
2992	MEMBREPOL	2015-04-22 00:00:00	2017-06-04 00:00:00	ANCIEN	\N	\N	\N	\N	2639	2015-04-22 16:49:30	2017-06-07 09:38:00
2984	MEMBREPOL	2015-02-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2633	2015-02-13 10:24:27	\N
2994	MEMBREPOL	2015-05-04 00:00:00	2015-05-11 00:00:00	ANCIEN	\N	\N	\N	\N	2641	2015-05-04 10:29:04	2015-05-12 16:49:08
2995	MEMBREPOL	2015-05-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	2642	2015-05-12 16:49:00	\N
2996	MEMBREPOL	2015-05-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2643	2015-05-12 16:49:08	\N
3008	MEMBREPOL	2015-06-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	2647	2015-06-17 10:08:01	\N
3009	MEMBREPOL	2015-07-15 00:00:00	2024-03-20 00:00:00	ANCIEN	\N	\N	\N	\N	2648	2015-07-15 00:00:00	\N
3010	MEMBREPOL	2015-07-15 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2649	2015-07-15 14:47:20	\N
3011	MEMBREPOL	2015-07-15 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	2650	2015-07-15 14:47:27	2017-06-29 09:53:12
3021	MEMBREPOL	2015-12-14 00:00:00	2016-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	2345	2015-12-14 09:50:22	2016-02-15 09:57:45
3022	PDTPOL	2015-12-14 00:00:00	2016-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	2342	2015-12-14 09:50:26	2016-02-15 09:57:42
3026	MEMBREPOL	2016-03-09 00:00:00	2017-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	2659	2016-03-09 11:10:18	2017-06-30 09:52:11
3046	MEMBREPOL	2017-05-15 00:00:00	2017-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	2674	2017-05-16 16:19:32	2017-05-17 11:44:22
3049	MEMBREPOL	2017-05-17 00:00:00	2017-05-23 00:00:00	ANCIEN	\N	\N	\N	\N	2676	2017-05-17 11:44:22	2017-05-24 14:34:25
3051	PDTPOL	2017-05-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	575	2017-06-01 16:12:41	2017-09-24 13:44:49
3052	MEMBREPOL	2017-05-23 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	2024	2017-06-01 16:13:11	2017-06-19 12:20:59
2593	PDTPOL	2011-10-04 00:00:00	2017-05-22 00:00:00	ANCIEN	\N	\N	\N	\N	2024	\N	2017-06-01 16:13:11
3062	MEMBREPOL	2017-06-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2248	2017-06-19 00:00:00	\N
3054	MEMBREPOL	2017-06-05 00:00:00	2017-06-14 00:00:00	ANCIEN	\N	\N	\N	\N	2679	2017-06-07 16:00:03	2017-06-19 16:13:09
3064	MEMBREPOL	2017-06-18 00:00:00	2018-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	2683	2017-06-19 16:45:46	\N
3063	MEMBREPOL	2017-06-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2143	2017-06-19 16:01:53	2017-09-24 18:05:41
3065	MEMBREPOL	2017-06-18 00:00:00	2017-06-18 00:00:00	ANCIEN	\N	\N	\N	\N	2684	2017-06-19 16:48:14	2017-06-22 15:10:04
3071	MEMBREPOL	2017-06-19 00:00:00	2017-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	2689	2017-06-22 15:10:03	2017-06-27 16:44:35
3073	PDTPOL	2017-06-28 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2691	2017-06-29 09:52:44	2017-10-03 16:56:14
3069	MEMBREPOL	2017-06-15 00:00:00	2017-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	2687	2017-06-22 12:19:12	2017-06-22 12:19:42
3070	MEMBREPOL	2017-06-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2688	2017-06-22 12:19:42	2017-09-24 18:16:52
3074	MEMBREPOL	2017-06-28 00:00:00	2017-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	2692	2017-06-29 09:53:11	2017-06-30 10:02:52
3075	MEMBREPOL	2017-06-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2693	2017-06-29 09:53:18	2017-09-24 18:16:52
3076	MEMBREPOL	2017-06-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2694	2017-06-29 09:53:25	2017-09-24 18:05:41
3077	MEMBREPOL	2017-06-28 00:00:00	2017-08-06 00:00:00	ANCIEN	\N	\N	\N	\N	2695	2017-06-29 09:53:31	2017-08-07 16:31:39
3078	MEMBREPOL	2017-06-28 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2696	2017-06-29 09:53:37	\N
3079	MEMBREPOL	2017-06-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2697	2017-06-29 09:53:43	2017-09-25 10:54:33
3080	MEMBREPOL	2017-06-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2698	2017-06-29 09:53:49	2017-09-25 10:54:33
3081	MEMBREPOL	2017-06-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2699	2017-06-29 09:53:55	2017-09-24 19:31:54
3082	MEMBREPOL	2017-06-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2700	2017-06-29 09:54:00	2017-09-24 17:06:55
2477	MEMBREPOL	2011-10-01 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	2203	\N	2017-06-29 09:54:00
3083	MEMBREPOL	2017-06-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2701	2017-06-29 00:00:00	\N
3084	MEMBREPOL	2017-06-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2702	2017-06-29 09:54:13	2017-09-25 10:54:33
3085	MEMBREPOL	2017-06-28 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2703	2017-06-29 09:54:18	\N
3086	MEMBREPOL	2017-06-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2704	2017-06-29 09:54:25	2017-09-24 17:47:27
3087	MEMBREPOL	2017-06-28 00:00:00	2017-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	2705	2017-06-29 09:54:31	2017-07-24 09:58:00
3088	MEMBREPOL	2017-06-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2706	2017-06-29 09:54:37	2017-09-24 17:48:21
3089	MEMBREPOL	2017-06-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2707	2017-06-29 09:54:43	2017-09-24 13:47:46
3090	MEMBREPOL	2017-06-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2708	2017-06-29 00:00:00	\N
2493	MEMBREPOL	2011-10-01 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	2219	\N	2017-06-29 09:54:50
3091	MEMBREPOL	2017-06-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	2709	2017-06-29 09:54:57	\N
3092	MEMBREPOL	2017-06-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2710	2017-06-29 00:00:00	\N
3093	MEMBREPOL	2017-06-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2711	2017-06-29 09:55:10	2017-09-24 17:06:55
3094	MEMBREPOL	2017-06-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2712	2017-06-29 09:55:16	2017-09-24 17:29:37
3095	MEMBREPOL	2017-06-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	2713	2017-06-29 09:55:22	\N
3096	MEMBREPOL	2017-06-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2714	2017-06-29 09:55:31	2017-09-24 16:24:51
2516	MEMBREPOL	2011-10-01 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	2242	\N	2017-06-29 09:55:31
3097	MEMBREPOL	2017-06-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2715	2017-06-29 09:55:44	2017-09-24 18:23:22
3098	MEMBREPOL	2017-06-28 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2716	2017-06-29 09:55:49	\N
3099	MEMBREPOL	2017-06-28 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2717	2017-06-29 09:55:56	\N
3135	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2742	2017-09-24 10:41:27	2017-10-03 17:37:06
3122	MEMBREPOL	2017-07-04 00:00:00	2017-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	2729	2017-07-04 16:05:20	2017-07-05 17:48:06
3127	MEMBREPOL	2017-07-22 00:00:00	2017-07-24 00:00:00	ANCIEN	\N	\N	\N	\N	2734	2017-07-24 16:38:43	2017-07-25 12:14:19
3137	MEMBREPOL	2017-09-23 00:00:00	2017-09-26 00:00:00	ANCIEN	\N	\N	\N	\N	2744	2017-09-24 11:13:08	2017-09-27 18:53:55
3138	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2745	2017-09-24 12:39:58	2017-10-03 17:00:27
3139	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2746	2017-09-24 12:57:08	2017-10-03 17:20:12
2468	MEMBREPOL	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2194	\N	2017-09-24 12:57:09
2723	MEMBREPOL	2014-01-01 00:00:00	2014-01-06 00:00:00	ANCIEN	\N	\N	\N	\N	2408	2014-01-02 15:38:53	2014-01-07 16:41:44
2726	MEMBREPOL	2014-02-14 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2411	2014-02-14 17:27:28	2014-09-28 18:32:43
2757	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2439	2014-09-28 12:44:31	2014-10-07 15:41:50
2755	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2437	2014-09-28 12:32:22	2014-10-07 15:35:10
2756	MEMBREPOL	2014-09-29 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2438	2014-09-28 12:34:20	2014-10-20 10:49:17
2734	MEMBREPOL	2014-05-05 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2417	2014-05-05 10:32:43	2014-09-28 19:03:23
2735	MEMBREPOL	2014-05-05 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2418	2014-05-05 10:33:21	2014-09-28 19:29:39
2740	MEMBREPOL	2014-05-05 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2423	2014-05-05 10:59:01	2014-09-28 16:54:10
2758	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2440	2014-09-28 12:54:15	2014-10-07 17:06:10
2759	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2441	2014-09-28 13:06:30	2014-10-07 15:54:36
2760	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2442	2014-09-28 13:16:32	2014-10-07 15:28:36
2765	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2447	2014-09-28 16:40:49	2014-10-07 15:50:47
2766	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2448	2014-09-28 16:40:49	2014-10-07 15:40:21
2767	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2449	2014-09-28 16:42:03	2014-10-07 17:00:28
2768	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2450	2014-09-28 16:42:03	2014-10-07 15:28:26
2769	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2451	2014-09-28 16:49:55	2014-10-07 15:29:12
2770	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2452	2014-09-28 16:49:55	2014-10-07 16:58:47
2771	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2453	2014-09-28 16:54:08	2014-10-07 15:54:12
2819	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2501	2014-09-28 18:32:41	2014-10-07 15:34:53
2634	VICPDTPOL	2011-11-02 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2268	\N	2014-10-07 15:50:56
2971	MEMBREPOL	2014-10-07 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2620	2014-10-09 09:10:32	2017-10-01 10:32:58
2976	MEMBREPOL	2014-12-28 00:00:00	2015-01-07 00:00:00	ANCIEN	\N	\N	\N	\N	2625	2015-01-02 11:36:27	2017-02-01 16:24:19
2977	MEMBREPOL	2015-01-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2626	2015-01-05 11:56:04	\N
3018	MEMBREPOL	2015-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2657	2015-10-12 00:00:00	\N
2981	MEMBREPOL	2015-01-26 00:00:00	2015-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	2630	2015-01-26 17:11:41	2015-01-27 13:55:40
3014	MEMBREPOL	2015-09-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	2653	2015-09-10 15:45:51	\N
3015	MEMBREPOL	2015-09-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2654	2015-09-10 15:46:12	\N
3020	MEMBREPOL	2015-11-06 00:00:00	2015-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	2342	2015-11-05 19:31:11	2015-12-14 09:50:27
3019	PDTPOL	2015-11-06 00:00:00	2015-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	2345	2015-11-05 19:30:53	2015-12-14 09:50:22
3024	MEMBREPOL	2016-02-15 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	2342	2016-02-15 09:57:41	2016-03-11 18:02:50
3025	PDTPOL	2016-02-15 00:00:00	2016-05-03 00:00:00	ANCIEN	\N	\N	\N	\N	2345	2016-02-15 09:57:45	2016-05-04 12:32:24
3038	MEMBREPOL	2016-12-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2668	2016-12-05 00:00:00	\N
3043	MEMBREPOL	2017-01-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2673	2017-01-06 09:29:15	2017-09-24 19:25:10
3100	MEMBREPOL	2017-06-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2718	2017-06-30 09:47:44	2017-09-24 17:47:28
2668	MEMBREPOL	2012-01-11 00:00:00	2017-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	2347	\N	2017-06-30 09:52:11
2672	MEMBREPOL	2012-01-11 00:00:00	2017-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	2351	\N	2017-06-30 09:52:11
3802	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3381	2023-09-24 00:00:00	\N
3102	MEMBREPOL	2017-06-30 00:00:00	2017-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	2719	2017-06-30 09:59:47	2017-07-04 10:54:39
3103	MEMBREPOL	2017-06-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2720	2017-06-30 10:00:00	2017-09-24 18:07:57
3104	MEMBREPOL	2017-06-30 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2721	2017-06-30 10:00:08	2017-10-03 16:43:38
3105	MEMBREPOL	2017-06-30 00:00:00	2017-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	2722	2017-06-30 10:00:17	2017-07-04 15:08:09
3106	MEMBREPOL	2017-06-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2723	2017-06-30 10:00:25	2017-09-24 17:09:24
3107	MEMBREPOL	2017-06-30 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2724	2017-06-30 10:00:33	2017-10-03 16:56:55
3108	MEMBREPOL	2017-06-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2725	2017-06-30 10:00:55	2017-09-24 17:47:27
3109	MEMBREPOL	2017-06-30 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2726	2017-06-30 10:01:05	2017-10-03 16:58:46
3124	MEMBREPOL	2017-07-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2731	2017-07-11 10:14:30	2017-10-01 10:18:28
3125	MEMBREPOL	2017-07-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2732	2017-07-17 11:07:21	2017-09-25 10:56:48
2406	MEMBREPOL	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2128	\N	2017-09-24 13:42:36
3130	MEMBREPOL	2017-07-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2737	2017-07-31 12:04:06	2017-09-24 17:55:12
3172	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2778	2017-09-24 17:42:25	2017-10-03 17:12:37
3134	MEMBREPOL	2017-09-22 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2741	2017-09-22 11:11:24	2017-10-03 17:20:55
3148	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2754	2017-09-24 17:04:01	2017-10-03 17:25:01
3152	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2758	2017-09-24 17:09:23	2017-10-03 16:53:38
3153	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2759	2017-09-24 17:09:23	2017-10-03 17:05:35
3155	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2761	2017-09-24 17:14:26	2017-10-03 17:36:18
3156	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2762	2017-09-24 17:14:26	2017-10-03 17:21:30
3161	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2767	2017-09-24 17:18:02	2017-10-03 17:26:54
3162	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2768	2017-09-24 17:18:02	2017-10-03 16:56:37
3174	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2780	2017-09-24 17:42:25	2017-10-03 17:06:32
3175	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2781	2017-09-24 17:42:25	2017-10-03 16:56:33
2524	MEMBREPOL	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2250	\N	2017-09-24 17:42:25
3176	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2782	2017-09-24 17:47:26	2017-10-03 17:07:39
3177	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2783	2017-09-24 17:47:26	2017-10-03 17:19:59
3178	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2784	2017-09-24 17:47:26	2017-10-03 16:56:28
3179	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2785	2017-09-24 17:47:26	2017-10-03 17:16:21
3180	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2786	2017-09-24 17:47:26	2017-10-03 17:10:20
3181	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2787	2017-09-24 17:47:26	2017-10-03 17:08:07
3184	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2790	2017-09-24 17:55:12	2017-10-03 16:45:07
3186	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2792	2017-09-24 17:55:12	2017-10-03 17:12:05
3187	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2793	2017-09-24 18:05:40	2017-10-03 16:59:02
3188	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2794	2017-09-24 18:05:40	2017-10-03 17:35:10
3193	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2799	2017-09-24 18:16:33	2017-10-03 16:56:50
2492	MEMBREPOL	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2218	\N	2017-09-24 18:16:33
3207	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2813	2017-09-24 18:20:09	2017-10-03 16:57:58
3208	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2814	2017-09-24 18:20:09	2017-10-03 17:16:27
3212	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2818	2017-09-24 18:41:37	2017-10-03 17:11:00
3213	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2819	2017-09-24 18:41:37	2017-10-03 17:10:44
3214	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2820	2017-09-24 18:44:44	2017-10-03 17:17:08
3215	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2821	2017-09-24 18:49:56	2017-10-03 17:26:45
3216	MEMBREPOL	2017-09-25 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2822	2017-09-24 18:51:50	2017-10-03 17:15:44
3217	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2823	2017-09-24 18:59:59	2017-10-03 17:26:04
3218	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2824	2017-09-24 18:59:59	2017-10-03 17:15:31
3220	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2826	2017-09-24 19:05:36	2017-10-03 17:11:46
3221	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2827	2017-09-24 19:14:36	2017-10-03 17:35:32
3222	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2828	2017-09-24 19:16:18	2017-10-03 16:59:15
3223	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2829	2017-09-24 19:17:41	2017-10-03 17:23:08
3224	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2830	2017-09-24 19:19:07	2017-10-03 17:36:56
3225	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2831	2017-09-24 19:19:07	2017-10-03 17:15:57
3226	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2832	2017-09-24 19:25:09	2017-10-03 17:24:40
3227	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2833	2017-09-24 19:25:09	2017-10-03 17:22:29
3228	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2834	2017-09-24 19:25:09	2017-10-03 17:09:23
3229	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2835	2017-09-24 19:25:09	2017-10-03 16:44:56
2803	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2485	2014-09-28 17:35:38	2014-10-07 17:08:14
2744	MEMBREPOL	2014-05-12 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	2427	2014-05-12 11:26:56	2017-06-19 16:06:51
2748	MEMBREPOL	2014-07-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2430	2014-07-01 15:32:41	2017-09-24 16:24:51
2804	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2486	2014-09-28 17:38:25	2014-10-07 14:47:48
2805	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2487	2014-09-28 17:38:25	2014-10-07 15:36:50
2813	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2495	2014-09-28 17:58:04	2014-10-07 15:36:13
2814	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2496	2014-09-28 18:00:57	2014-10-07 17:03:06
2815	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2497	2014-09-28 18:00:57	2014-10-07 15:29:55
2816	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2498	2014-09-28 18:03:38	2014-10-07 17:07:43
2824	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2506	2014-09-28 18:58:20	2014-10-07 17:05:59
2828	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2510	2014-09-28 19:03:23	2014-10-07 15:45:08
2829	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2511	2014-09-28 19:05:58	2014-10-07 15:41:39
2830	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2512	2014-09-28 19:05:58	2014-10-07 15:40:52
2840	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2522	2014-09-29 09:03:10	2014-10-07 17:37:09
2841	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2523	2014-09-29 09:05:47	2014-10-07 16:59:58
2842	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2524	2014-09-29 09:08:32	2014-10-07 15:52:39
2843	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2525	2014-09-29 09:08:32	2014-10-07 15:53:35
2873	MEMBREPOL	2014-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2541	2014-10-07 15:35:34	\N
2874	MEMBREPOL	2014-10-07 00:00:00	2014-12-27 00:00:00	ANCIEN	\N	\N	\N	\N	2542	2014-10-07 15:36:04	2014-12-29 15:40:09
2876	MEMBREPOL	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	2544	2014-10-07 15:36:13	\N
2877	MEMBREPOL	2014-10-07 00:00:00	2020-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	2545	2014-10-07 15:36:25	\N
2878	MEMBREPOL	2014-10-07 00:00:00	2022-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	2546	2014-10-07 15:36:32	\N
2879	MEMBREPOL	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	2547	2014-10-07 15:36:41	\N
2881	MEMBREPOL	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	2549	2014-10-07 15:36:56	\N
2883	MEMBREPOL	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	2551	2014-10-07 15:39:04	\N
2884	MEMBREPOL	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	2552	2014-10-07 15:39:17	\N
2888	MEMBREPOL	2014-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2556	2014-10-07 15:39:42	\N
2889	MEMBREPOL	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	2557	2014-10-07 15:39:58	\N
2890	MEMBREPOL	2014-10-07 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2558	2014-10-07 15:40:07	2017-10-03 16:54:24
2891	MEMBREPOL	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	2559	2014-10-07 15:40:21	\N
2892	MEMBREPOL	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	2560	2014-10-07 15:40:33	\N
2893	MEMBREPOL	2014-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2561	2014-10-07 15:40:51	\N
2929	MEMBREPOL	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	2587	2014-10-07 16:56:22	\N
2897	MEMBREPOL	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	2565	2014-10-07 15:41:59	\N
2943	MEMBREPOL	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	2595	2014-10-07 17:00:43	\N
2930	MEMBREPOL	2014-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2588	2014-10-07 16:57:19	\N
2931	MEMBREPOL	2014-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2589	2014-10-07 16:58:03	\N
2932	MEMBREPOL	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	2590	2014-10-07 16:58:47	\N
2933	MEMBREPOL	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	2591	2014-10-07 16:58:54	\N
2934	MEMBREPOL	2014-10-07 00:00:00	2018-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	1908	2014-10-07 16:59:23	\N
2935	MEMBREPOL	2014-10-07 00:00:00	2017-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	1699	2014-10-07 16:59:26	2017-06-30 09:47:45
2637	VICPDTDELPOL	2011-11-02 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	1699	\N	2014-10-07 16:59:26
2936	MEMBREPOL	2014-10-07 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	2236	2014-10-07 16:59:28	2017-06-29 09:55:04
2937	MEMBREPOL	2014-10-07 00:00:00	2020-08-03 00:00:00	ANCIEN	\N	\N	\N	\N	2036	2014-10-07 16:59:29	\N
2938	MEMBREPOL	2014-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2207	2014-10-07 00:00:00	\N
2644	VICPDTPOL	2011-11-02 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2207	\N	2014-10-07 16:59:31
2939	MEMBREPOL	2014-10-07 00:00:00	2017-07-28 00:00:00	ANCIEN	\N	\N	\N	\N	2294	2014-10-07 16:59:33	2017-08-03 11:38:41
2941	MEMBREPOL	2014-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2593	2014-10-07 17:00:26	\N
2942	MEMBREPOL	2014-10-07 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	2594	2014-10-07 17:00:28	2015-06-12 15:59:18
2944	MEMBREPOL	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	2596	2014-10-07 17:01:23	\N
2945	MEMBREPOL	2014-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2597	2014-10-07 17:01:23	\N
2947	MEMBREPOL	2014-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2599	2014-10-07 17:03:06	\N
2948	MEMBREPOL	2014-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2600	2014-10-07 17:03:14	\N
2949	MEMBREPOL	2014-10-07 00:00:00	2017-07-10 00:00:00	ANCIEN	\N	\N	\N	\N	2601	2014-10-07 17:04:16	2017-07-11 10:14:31
2950	MEMBREPOL	2014-10-07 00:00:00	2019-04-29 00:00:00	ANCIEN	\N	\N	\N	\N	2602	2014-10-07 17:04:53	\N
2951	MEMBREPOL	2014-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2603	2014-10-07 17:05:13	\N
2952	MEMBREPOL	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	2604	2014-10-07 17:05:59	\N
2953	MEMBREPOL	2014-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2605	2014-10-07 17:06:10	\N
2969	MEMBREPOL	2014-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2618	2014-10-07 00:00:00	\N
2970	MEMBREPOL	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	2619	2014-10-07 19:32:02	\N
2974	MEMBREPOL	2014-12-22 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	2623	2014-12-22 15:50:06	2017-06-19 16:04:13
2963	MEMBREPOL	2014-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2612	2014-10-07 17:08:00	\N
2964	MEMBREPOL	2014-10-07 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	2613	2014-10-07 17:08:14	2015-02-12 15:03:17
2965	MEMBREPOL	2014-10-07 00:00:00	2019-05-27 00:00:00	ANCIEN	\N	\N	\N	\N	2614	2014-10-07 17:08:27	\N
2966	MEMBREPOL	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	2615	2014-10-07 17:08:34	\N
2983	MEMBREPOL	2015-02-12 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	2632	2015-02-12 15:04:38	2015-02-13 10:24:28
3006	MEMBREPOL	2015-06-12 00:00:00	2015-06-14 00:00:00	ANCIEN	\N	\N	\N	\N	2645	2015-06-12 15:40:17	2015-06-15 18:12:01
2989	MEMBREPOL	2015-03-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2636	2015-03-10 16:55:27	2017-09-24 18:07:57
2478	MEMBREPOL	2011-10-01 00:00:00	2015-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	2204	\N	2015-04-07 16:50:27
2990	MEMBREPOL	2015-04-08 00:00:00	2015-04-14 00:00:00	ANCIEN	\N	\N	\N	\N	2637	2015-04-07 17:15:52	2015-04-15 12:04:30
2528	MEMBREPOL	2011-10-01 00:00:00	2016-01-11 00:00:00	ANCIEN	\N	\N	\N	\N	2254	\N	2016-01-11 17:34:09
3027	MEMBREPOL	2016-03-12 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	2660	2016-03-11 18:10:19	2017-06-19 16:03:48
3030	MEMBREPOL	2016-11-13 00:00:00	2016-11-13 00:00:00	ANCIEN	\N	\N	\N	\N	2661	2016-11-14 18:40:41	2016-11-14 18:54:33
3031	MEMBREPOL	2016-11-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2662	2016-11-14 18:54:33	2017-09-24 16:24:51
3034	MEMBREPOL	2016-11-18 00:00:00	2016-11-24 00:00:00	ANCIEN	\N	\N	\N	\N	2664	2016-11-18 15:46:10	2016-11-25 14:59:02
3035	MEMBREPOL	2016-11-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	2665	2016-11-25 14:56:53	\N
3040	MEMBREPOL	2016-12-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2670	2016-12-14 18:37:18	2017-09-24 18:23:22
3058	MEMBREPOL	2017-06-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2271	2017-06-19 00:00:00	\N
3059	MEMBREPOL	2017-06-18 00:00:00	2017-06-18 00:00:00	ANCIEN	\N	\N	\N	\N	3020	2017-06-19 15:56:02	2017-06-19 15:56:26
3060	MEMBREPOL	2017-06-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	3021	2017-06-19 00:00:00	\N
3128	MEMBREPOL	2017-07-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2735	2017-07-25 12:14:19	\N
2623	MEMBREPOL	2011-10-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2334	\N	2017-09-24 19:25:10
3230	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2836	2017-09-24 19:26:20	2017-10-03 17:37:37
3231	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2837	2017-09-24 19:26:20	2017-10-03 17:17:02
3232	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2838	2017-09-24 19:31:54	2017-10-03 17:10:10
3233	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2839	2017-09-24 19:31:54	2017-10-03 17:37:26
3234	MEMBREPOL	2017-09-25 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2840	2017-09-25 09:57:06	2017-10-03 17:08:23
3235	MEMBREPOL	2017-09-25 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2841	2017-09-25 10:03:31	2017-10-01 10:37:45
3236	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2842	2017-09-25 10:54:33	2017-10-03 16:57:54
3237	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2843	2017-09-25 10:54:33	2017-10-03 17:10:01
3238	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2844	2017-09-25 10:54:33	2017-10-03 17:11:14
3239	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2845	2017-09-25 10:56:48	2017-10-03 16:56:02
2749	MEMBREPOL	2014-07-09 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2431	2014-07-09 18:28:40	\N
2754	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2436	2014-09-28 12:09:44	2014-10-07 15:39:32
2761	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2443	2014-09-28 13:32:34	2014-10-07 17:08:34
2775	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2457	2014-09-28 17:00:59	2014-10-07 15:51:37
2776	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2458	2014-09-28 17:03:41	2014-10-07 17:04:53
2777	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2459	2014-09-28 17:03:41	2014-10-07 15:30:26
2778	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2460	2014-09-28 17:03:41	2014-10-07 15:36:33
2781	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2463	2014-09-28 17:07:07	2014-10-07 15:39:58
2786	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2468	2014-09-28 17:09:16	2014-10-07 15:28:58
2787	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2469	2014-09-28 17:09:16	2014-10-07 16:58:03
2821	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2503	2014-09-28 18:46:12	2014-10-07 15:51:30
2822	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2504	2014-09-28 18:46:12	2014-10-07 15:31:26
2831	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2513	2014-09-28 19:07:43	2014-10-07 16:58:54
2835	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2517	2014-09-28 19:19:39	2014-10-07 15:53:01
2836	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2518	2014-09-28 19:19:39	2014-10-07 17:00:26
2838	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2520	2014-09-28 19:29:38	2014-10-07 15:29:28
2940	MEMBREPOL	2014-10-07 00:00:00	2015-06-10 00:00:00	ANCIEN	\N	\N	\N	\N	2592	2014-10-07 16:59:58	2015-06-11 19:00:39
2956	MEMBREPOL	2014-10-07 00:00:00	2015-07-14 00:00:00	ANCIEN	\N	\N	\N	\N	2606	2014-10-07 17:06:29	2015-07-15 14:47:28
2958	MEMBREPOL	2014-10-07 00:00:00	2015-07-14 00:00:00	ANCIEN	\N	\N	\N	\N	2607	2014-10-07 17:06:40	2015-07-15 14:47:14
2959	MEMBREPOL	2014-10-07 00:00:00	2015-07-14 00:00:00	ANCIEN	\N	\N	\N	\N	2608	2014-10-07 17:06:50	2015-07-15 14:47:21
2960	MEMBREPOL	2014-10-07 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2609	2014-10-07 17:07:33	2017-10-03 16:58:35
2961	MEMBREPOL	2014-10-07 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2610	2014-10-07 17:07:43	2017-10-01 10:25:16
2962	MEMBREPOL	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	2611	2014-10-07 17:07:51	\N
2967	MEMBREPOL	2014-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2616	2014-10-07 17:37:09	\N
2968	MEMBREPOL	2014-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2617	2014-10-07 17:37:28	\N
2998	MEMBREPOL	2015-06-10 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	2147	2015-06-11 18:55:15	2017-06-29 09:53:25
2988	MEMBREPOL	2015-03-04 00:00:00	2015-03-09 00:00:00	ANCIEN	\N	\N	\N	\N	2635	2015-03-04 16:36:00	2015-03-10 16:55:28
2999	MEMBREPOL	2015-06-11 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	2213	2015-06-11 18:55:48	2017-06-29 09:53:43
3002	MEMBREPOL	2015-06-10 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	2592	2015-06-11 19:00:39	2017-06-29 09:55:57
2486	MEMBREPOL	\N	2015-06-10 00:00:00	ANCIEN	\N	\N	\N	\N	2212	\N	2015-06-11 18:59:22
3001	MEMBREPOL	2015-06-10 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	2212	2015-06-11 18:59:22	2017-06-29 09:54:14
3003	MEMBREPOL	2015-06-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1730	2015-06-11 19:01:21	2017-09-25 10:58:49
3004	MEMBREPOL	2015-06-10 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	2047	2015-06-11 19:01:54	2017-06-29 09:54:57
3005	MEMBREPOL	2015-06-12 00:00:00	2015-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	2644	2015-06-12 15:35:57	2015-06-17 10:08:02
2600	MEMBREPOL	2011-10-01 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	701	\N	2015-06-12 16:01:25
3007	MEMBREPOL	2015-06-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	2646	2015-06-15 18:12:01	\N
3012	MEMBREPOL	2015-09-07 00:00:00	2015-09-09 00:00:00	ANCIEN	\N	\N	\N	\N	2651	2015-09-07 16:07:43	2015-09-10 15:46:13
3013	MEMBREPOL	2015-09-07 00:00:00	2015-09-09 00:00:00	ANCIEN	\N	\N	\N	\N	2652	2015-09-07 16:16:32	2015-09-10 15:45:53
3023	MEMBREPOL	2016-01-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2658	2016-01-12 00:00:00	\N
3028	MEMBREPOL	2016-05-04 00:00:00	2017-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	2345	2016-05-04 12:32:23	2017-06-30 09:52:11
3029	PDTPOL	2016-05-04 00:00:00	2017-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	2344	2016-05-04 12:32:27	2017-06-30 09:52:11
3042	MEMBREPOL	2017-01-01 00:00:00	2017-01-04 00:00:00	ANCIEN	\N	\N	\N	\N	2672	2017-01-04 10:02:09	2017-01-06 09:29:16
3037	MEMBREPOL	2016-12-01 00:00:00	2016-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	2667	2016-12-01 18:23:34	2016-12-05 18:12:01
3039	MEMBREPOL	2016-12-11 00:00:00	2016-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	2669	2016-12-12 15:59:30	2016-12-14 18:37:23
3050	MEMBREPOL	2017-05-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2677	2017-05-24 14:34:24	2017-09-24 12:39:59
3072	MEMBREPOL	2017-06-27 00:00:00	2018-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	2690	2017-06-27 16:44:34	\N
3119	MEMBREPOL	2017-06-30 00:00:00	2020-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	2692	2017-06-30 10:59:13	\N
3120	MEMBREPOL	2017-07-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2727	2017-07-04 10:54:38	2017-09-24 17:47:28
3123	MEMBREPOL	2017-07-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2730	2017-07-05 17:48:05	2017-09-24 18:16:52
3147	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2753	2017-09-24 16:45:25	2017-10-03 17:16:33
3132	MEMBREPOL	2017-08-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2739	2017-08-07 17:16:36	2017-09-24 17:18:03
3141	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2747	2017-09-24 16:24:50	2017-10-03 17:23:31
3142	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2748	2017-09-24 16:24:50	2017-10-03 16:56:42
3143	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2749	2017-09-24 16:24:50	2017-10-03 17:34:20
3144	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2750	2017-09-24 16:24:50	2017-10-03 16:54:14
3145	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2751	2017-09-24 16:43:41	2017-10-03 17:09:16
2475	MEMBREPOL	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2201	\N	2017-09-24 16:45:26
3149	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2755	2017-09-24 17:06:55	2017-10-03 17:25:49
3150	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2756	2017-09-24 17:06:55	2017-10-03 17:36:30
3151	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2757	2017-09-24 17:06:55	2017-10-03 17:15:26
3157	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2763	2017-09-24 17:15:14	2017-10-03 17:15:38
3158	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2764	2017-09-24 17:15:14	2017-10-03 17:12:11
3159	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2765	2017-09-24 17:15:14	2017-10-03 17:23:50
3160	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2766	2017-09-24 17:15:14	2017-10-03 17:20:33
2511	MEMBREPOL	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2237	\N	2017-09-24 17:15:15
2509	MEMBREPOL	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2235	\N	2017-09-24 17:15:15
3163	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2769	2017-09-24 17:19:41	2017-10-03 17:09:46
3164	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2770	2017-09-24 17:19:41	2017-10-03 16:58:13
3167	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2773	2017-09-24 17:29:36	2017-10-03 17:22:46
3168	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2774	2017-09-24 17:29:36	2017-10-03 17:18:14
3169	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2775	2017-09-24 17:35:13	2017-10-03 16:57:32
3170	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2776	2017-09-24 17:35:13	2017-10-03 17:25:23
3171	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2777	2017-09-24 17:35:13	2017-10-03 16:44:20
3182	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2788	2017-09-24 17:48:20	2017-10-03 17:36:48
3183	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2789	2017-09-24 17:48:20	2017-10-03 17:41:07
3191	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2797	2017-09-24 18:07:56	2017-10-03 16:44:13
3192	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2798	2017-09-24 18:07:56	2017-10-03 17:19:06
3194	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2800	2017-09-24 18:16:50	2017-10-03 17:10:33
3195	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2801	2017-09-24 18:16:50	2017-10-03 16:57:10
3196	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2802	2017-09-24 18:16:50	2017-10-03 17:08:35
3197	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2803	2017-09-24 18:16:51	2017-10-03 16:53:56
3198	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2804	2017-09-24 18:16:51	2017-10-03 17:23:19
3199	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2805	2017-09-24 18:16:51	2017-10-03 17:35:15
3200	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2806	2017-09-24 18:16:51	2017-10-03 16:44:36
3201	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2807	2017-09-24 18:16:51	2017-10-03 16:54:55
3202	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2808	2017-09-24 18:16:51	2017-10-03 17:18:56
3204	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2810	2017-09-24 18:17:55	2017-10-03 16:57:04
3206	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2812	2017-09-24 18:17:55	2017-10-03 17:17:16
2615	MEMBREPOL	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2331	\N	2017-09-24 18:17:56
3209	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2815	2017-09-24 18:23:21	2017-10-03 17:16:05
3210	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2816	2017-09-24 18:23:21	2017-10-03 17:12:17
3211	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2817	2017-09-24 18:27:44	2017-10-03 17:05:06
2730	MEMBREPOL	2014-04-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2413	2014-04-28 10:39:23	2014-09-28 17:07:41
2742	MEMBREPOL	2014-05-10 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	2425	2014-05-09 11:36:02	2017-06-19 16:06:01
2743	MEMBREPOL	2014-05-09 00:00:00	2014-05-11 00:00:00	ANCIEN	\N	\N	\N	\N	2426	2014-05-09 11:37:36	2014-05-12 11:26:57
2738	MEMBREPOL	2014-05-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2421	2014-05-05 00:00:00	\N
2739	MEMBREPOL	2014-05-05 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	2422	2014-05-05 10:41:54	2017-06-29 09:53:31
2752	MEMBREPOL	2014-09-01 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	2434	2014-09-01 11:40:21	2017-06-29 09:54:38
2747	MEMBREPOL	2014-06-25 00:00:00	2014-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	2429	2014-06-25 15:52:44	2014-07-01 15:32:42
2762	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2444	2014-09-28 13:40:32	2014-10-07 15:36:13
2763	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2445	2014-09-28 13:40:32	2014-10-07 15:39:17
2772	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2454	2014-09-28 16:59:40	2014-10-07 16:56:24
2773	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2455	2014-09-28 16:59:40	2014-10-07 17:04:16
2774	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2456	2014-09-28 16:59:40	2014-10-07 15:41:59
2779	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2461	2014-09-28 17:05:42	2014-10-07 15:42:12
2780	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2462	2014-09-28 17:05:42	2014-10-07 16:57:19
2782	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2464	2014-09-28 17:07:40	2014-10-07 15:46:18
2783	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2465	2014-09-28 17:07:40	2014-10-07 15:55:04
2784	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2466	2014-09-28 17:07:40	2014-10-07 17:08:00
2785	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2467	2014-09-28 17:07:40	2014-10-07 15:39:19
2788	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2470	2014-09-28 17:12:40	2014-10-07 15:32:17
2789	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2471	2014-09-28 17:14:20	2014-10-07 15:30:46
2790	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2472	2014-09-28 17:15:41	2014-10-07 15:39:04
2791	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2473	2014-09-28 17:22:10	2014-10-07 15:54:21
2792	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2474	2014-09-28 17:22:10	2014-10-07 15:36:56
2793	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2475	2014-09-28 17:27:28	2014-10-07 15:39:01
2794	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2476	2014-09-28 17:27:34	2014-10-07 15:54:56
2795	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2477	2014-09-28 17:27:34	2014-10-07 15:40:33
2796	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2478	2014-09-28 17:27:34	2014-10-07 17:00:43
2797	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2479	2014-09-28 17:31:41	2014-10-07 15:54:00
2798	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2480	2014-09-28 17:31:41	2014-10-07 17:01:24
2799	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2481	2014-09-28 17:31:41	2014-10-07 15:39:42
2800	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2482	2014-09-28 17:34:15	2014-10-07 17:03:14
2801	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2483	2014-09-28 17:34:15	2014-10-07 17:01:23
2802	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2484	2014-09-28 17:34:15	2014-10-07 15:53:09
2806	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2488	2014-09-28 17:40:23	2014-10-07 15:35:03
2807	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2489	2014-09-28 17:40:23	2014-10-07 15:53:26
2808	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2490	2014-09-28 17:52:17	2014-10-07 17:06:22
2809	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2491	2014-09-28 17:52:17	2014-10-07 17:17:59
2810	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2492	2014-09-28 17:52:17	2014-10-07 17:07:51
2870	MEMBREPOL	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	2538	2014-10-07 15:34:52	\N
2871	MEMBREPOL	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	2539	2014-10-07 15:35:03	\N
2817	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2499	2014-09-28 18:19:47	2014-10-07 15:35:35
2823	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2505	2014-09-28 18:47:00	2014-10-07 15:36:42
2825	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2507	2014-09-28 18:58:25	2014-10-07 15:39:27
2827	MEMBREPOL	2014-10-01 00:00:00	2014-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	2509	2014-09-28 19:03:03	2017-02-01 16:24:19
2832	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2514	2014-09-28 19:09:43	2014-10-07 17:02:06
2833	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2515	2014-09-28 19:13:08	2014-10-07 17:05:13
2834	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2516	2014-09-28 19:13:08	2014-10-07 15:51:19
2837	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2519	2014-09-28 19:20:16	2014-10-07 15:31:07
2839	MEMBREPOL	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2521	2014-09-28 19:45:29	2014-10-07 15:36:04
2872	MEMBREPOL	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	2540	2014-10-07 15:35:10	\N
2875	MEMBREPOL	2014-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2543	2014-10-07 15:36:13	\N
2880	MEMBREPOL	2014-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2548	2014-10-07 15:36:50	\N
2882	MEMBREPOL	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	2550	2014-10-07 15:39:00	\N
2885	MEMBREPOL	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	2553	2014-10-07 15:39:19	\N
2886	MEMBREPOL	2014-10-07 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	2554	2014-10-07 15:39:26	2017-06-29 09:54:31
2887	MEMBREPOL	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	2555	2014-10-07 15:39:32	\N
2895	MEMBREPOL	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	2563	2014-10-07 15:41:42	2017-02-01 16:22:46
3278	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2882	2017-10-03 00:00:00	\N
2896	MEMBREPOL	2014-10-07 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2564	2014-10-07 15:41:50	2017-10-03 16:53:48
2898	MEMBREPOL	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	2566	2014-10-07 15:42:12	\N
2900	MEMBREPOL	2014-10-07 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2568	2014-10-07 15:45:08	2017-10-03 16:54:40
2901	MEMBREPOL	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	2567	2014-10-07 15:46:08	2014-10-07 16:25:38
2902	MEMBREPOL	2014-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2569	2014-10-07 15:46:17	\N
2903	PDTPOL	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	2386	2014-10-07 15:49:04	\N
2904	VICPDTDELPOL	2014-10-07 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2109	2014-10-07 15:49:19	2017-10-03 17:15:07
2905	MEMBREPOL	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	2570	2014-10-07 15:50:47	\N
2906	PDTPOL	2014-10-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	632	2014-10-07 15:50:53	2017-09-24 13:29:42
2907	MEMBREPOL	2014-10-07 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2268	2014-10-07 15:50:56	2017-10-03 16:54:08
2908	MEMBREPOL	2014-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	592	2014-10-07 00:00:00	\N
2909	MEMBREPOL	2014-10-07 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2310	2014-10-07 15:51:00	2017-10-03 17:33:47
2910	MEMBREPOL	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	2007	2014-10-07 15:51:03	\N
2627	VICPDTPOL	2011-11-02 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2007	\N	2014-10-07 15:51:03
2911	MEMBREPOL	2014-10-07 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	2107	2014-10-07 15:51:05	2015-06-12 16:01:58
2912	MEMBREPOL	2014-10-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2172	2014-10-07 15:51:08	2017-09-24 19:16:18
2633	VICPDTPOL	2011-11-02 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	2172	\N	2014-10-07 15:51:08
2913	MEMBREPOL	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	2571	2014-10-07 15:51:19	\N
2914	MEMBREPOL	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	2572	2014-10-07 15:51:30	\N
2915	MEMBREPOL	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	2573	2014-10-07 15:51:36	\N
2916	MEMBREPOL	2014-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2574	2014-10-07 00:00:00	\N
2917	MEMBREPOL	2014-10-07 00:00:00	2015-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	2575	2014-10-07 15:52:38	2015-02-06 14:27:55
2918	MEMBREPOL	2014-10-07 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2576	2014-10-07 15:53:01	2017-10-03 16:57:46
2919	MEMBREPOL	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	2577	2014-10-07 15:53:09	\N
2920	MEMBREPOL	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	2578	2014-10-07 15:53:26	\N
2921	MEMBREPOL	2014-10-07 00:00:00	2015-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	2579	2014-10-07 15:53:35	2015-02-06 14:32:44
2922	MEMBREPOL	2014-10-07 00:00:00	2020-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	2580	2014-10-07 15:53:46	\N
2923	MEMBREPOL	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	2581	2014-10-07 15:54:00	\N
2924	MEMBREPOL	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	2582	2014-10-07 15:54:12	\N
2925	MEMBREPOL	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	2583	2014-10-07 15:54:21	\N
2926	MEMBREPOL	2014-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2584	2014-10-07 15:54:36	\N
2927	MEMBREPOL	2014-10-07 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	2585	2014-10-07 15:54:56	\N
2928	MEMBREPOL	2014-10-07 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2586	2014-10-07 15:55:04	2017-10-01 10:42:05
2986	VICPDTPOL	2015-02-19 00:00:00	2015-11-05 00:00:00	ANCIEN	\N	\N	\N	\N	2345	2015-02-19 10:38:18	2015-11-05 19:30:54
2982	MEMBREPOL	2015-01-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2631	2015-01-27 00:00:00	\N
2985	MEMBREPOL	2015-02-19 00:00:00	2017-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	2343	2015-02-19 10:38:09	2017-06-30 09:52:11
2574	MEMBREPOL	2011-10-01 00:00:00	2015-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	2300	\N	2015-03-03 10:16:55
2991	MEMBREPOL	2015-04-15 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	2638	2015-04-15 12:04:29	2017-06-29 09:55:10
2993	MEMBREPOL	2015-05-04 00:00:00	2015-05-11 00:00:00	ANCIEN	\N	\N	\N	\N	2640	2015-05-04 10:27:12	2015-05-12 16:49:01
3243	MEMBREPOL	2017-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2849	2017-10-01 09:26:48	2017-10-03 16:57:16
3254	PDTPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1721	2017-10-03 00:00:00	2017-10-03 00:00:00
3255	MEMBREPOL	2017-10-03 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	2860	2017-10-03 16:43:38	\N
3256	MEMBREPOL	2017-10-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2861	2017-10-03 16:43:56	\N
2624	MEMBREPOL	2011-10-27 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2335	\N	2017-10-03 16:43:56
3257	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2862	2017-10-03 00:00:00	\N
3258	MEMBREPOL	2017-10-03 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	2863	2017-10-03 16:44:20	\N
3259	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2864	2017-10-03 00:00:00	\N
3260	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2865	2017-10-03 00:00:00	\N
3261	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2866	2017-10-03 00:00:00	\N
3262	MEMBREPOL	2017-10-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2867	2017-10-03 16:53:31	\N
3263	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2868	2017-10-03 00:00:00	\N
3264	MEMBREPOL	2017-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	2869	2017-10-03 16:53:47	\N
3265	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2870	2017-10-03 00:00:00	\N
3266	MEMBREPOL	2017-10-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2871	2017-10-03 16:54:02	\N
3267	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2872	2017-10-03 00:00:00	\N
3268	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2873	2017-10-03 00:00:00	\N
3269	PDTPOL	2017-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	2874	2017-10-03 16:54:24	2017-10-03 17:43:01
3270	MEMBREPOL	2017-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	2875	2017-10-03 16:54:40	\N
3271	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2876	2017-10-03 00:00:00	\N
3272	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2877	2017-10-03 00:00:00	\N
3274	PDTPOL	2017-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	2691	2017-10-03 16:56:14	2017-10-03 17:01:57
3275	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2879	2017-10-03 00:00:00	\N
3277	MEMBREPOL	2017-10-03 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	2881	2017-10-03 16:56:36	\N
3279	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2883	2017-10-03 00:00:00	\N
3281	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2885	2017-10-03 00:00:00	\N
3282	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2886	2017-10-03 00:00:00	\N
3284	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2888	2017-10-03 00:00:00	\N
3286	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2890	2017-10-03 00:00:00	\N
3289	MEMBREPOL	2017-10-03 00:00:00	2019-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	2893	2017-10-03 16:58:35	\N
3295	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2898	2017-10-03 00:00:00	\N
3296	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2899	2017-10-03 00:00:00	\N
3324	MEMBREPOL	2017-10-03 00:00:00	2018-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	2924	2017-10-03 17:15:31	\N
3298	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2901	2017-10-03 00:00:00	\N
3299	MEMBREPOL	2017-10-03 00:00:00	2021-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	2902	2017-10-03 17:06:32	\N
3300	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2903	2017-10-03 00:00:00	\N
3301	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2904	2017-10-03 00:00:00	\N
3302	MEMBREPOL	2017-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3042	2017-10-03 17:08:23	\N
3303	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2905	2017-10-03 00:00:00	\N
3304	MEMBREPOL	2017-10-03 00:00:00	2020-06-24 00:00:00	ANCIEN	\N	\N	\N	\N	2906	2017-10-03 17:08:45	\N
3305	MEMBREPOL	2017-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	2907	2017-10-03 17:09:07	\N
3306	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2908	2017-10-03 00:00:00	\N
3307	MEMBREPOL	2017-10-03 00:00:00	2019-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	2909	2017-10-03 17:09:23	\N
3308	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2910	2017-10-03 00:00:00	\N
3309	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2911	2017-10-03 00:00:00	\N
3310	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2912	2017-10-03 00:00:00	\N
3311	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2913	2017-10-03 00:00:00	\N
3312	MEMBREPOL	2017-10-03 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	2914	2017-10-03 17:10:33	2018-01-23 16:16:04
3313	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2915	2017-10-03 00:00:00	\N
3314	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2916	2017-10-03 00:00:00	\N
3315	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2917	2017-10-03 00:00:00	\N
3316	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2918	2017-10-03 00:00:00	\N
3317	MEMBREPOL	2017-10-03 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	2919	2017-10-03 17:12:04	\N
3318	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2920	2017-10-03 00:00:00	\N
3319	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2921	2017-10-03 00:00:00	\N
3320	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2922	2017-10-03 00:00:00	\N
3321	MEMBREPOL	2017-10-03 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	2341	2017-10-03 17:15:04	\N
3322	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2109	2017-10-03 00:00:00	\N
3323	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2923	2017-10-03 00:00:00	\N
3325	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2925	2017-10-03 00:00:00	\N
3326	MEMBREPOL	2017-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	2926	2017-10-03 17:15:43	\N
3327	MEMBREPOL	2017-10-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2927	2017-10-03 17:15:49	\N
3328	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2928	2017-10-03 00:00:00	\N
3329	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2929	2017-10-03 00:00:00	\N
3330	MEMBREPOL	2017-10-03 00:00:00	2020-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	2930	2017-10-03 17:16:11	\N
3331	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2931	2017-10-03 00:00:00	\N
3332	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2932	2017-10-03 00:00:00	\N
3333	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2933	2017-10-03 00:00:00	\N
3335	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2934	2017-10-03 00:00:00	\N
3336	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2935	2017-10-03 00:00:00	\N
3337	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2936	2017-10-03 00:00:00	\N
3339	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2938	2017-10-03 00:00:00	\N
3340	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2939	2017-10-03 00:00:00	\N
3190	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2796	2017-09-24 18:05:40	2017-10-03 17:18:45
3341	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2940	2017-10-03 00:00:00	\N
3342	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2941	2017-10-03 00:00:00	\N
3343	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	3041	2017-10-03 00:00:00	\N
3344	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2942	2017-10-03 00:00:00	\N
3345	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2943	2017-10-03 00:00:00	\N
3346	MEMBREPOL	2017-10-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2944	2017-10-03 17:20:55	\N
3347	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2945	2017-10-03 00:00:00	\N
3189	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2795	2017-09-24 18:05:40	2017-10-03 17:21:18
3348	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2946	2017-10-03 00:00:00	\N
3349	MEMBREPOL	2017-10-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2947	2017-10-03 17:22:09	\N
3350	MEMBREPOL	2017-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	2948	2017-10-03 17:22:19	\N
3351	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2949	2017-10-03 00:00:00	\N
3352	MEMBREPOL	2017-10-03 00:00:00	2017-11-24 00:00:00	ANCIEN	\N	\N	\N	\N	2950	2017-10-03 17:22:46	2017-11-24 23:59:34
3353	MEMBREPOL	2017-10-03 00:00:00	2018-06-04 00:00:00	ANCIEN	\N	\N	\N	\N	2951	2017-10-03 17:23:00	2018-06-06 09:15:39
3219	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2825	2017-09-24 18:59:59	2017-10-03 17:23:00
3354	MEMBREPOL	2017-10-03 00:00:00	2018-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	2952	2017-10-03 17:23:07	2018-04-13 17:54:29
3355	MEMBREPOL	2017-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	2953	2017-10-03 17:23:14	\N
3356	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2954	2017-10-03 00:00:00	\N
3357	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2955	2017-10-03 00:00:00	\N
3358	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2956	2017-10-03 00:00:00	\N
3359	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2957	2017-10-03 00:00:00	\N
3166	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2772	2017-09-24 17:29:36	2017-10-03 17:24:30
3360	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2958	2017-10-03 00:00:00	\N
3361	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2959	2017-10-03 00:00:00	\N
3154	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2760	2017-09-24 17:09:23	2017-10-03 17:24:48
3362	MEMBREPOL	2017-10-03 00:00:00	2020-10-31 00:00:00	ANCIEN	\N	\N	\N	\N	2960	2017-10-03 17:25:01	\N
3363	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2961	2017-10-03 00:00:00	\N
3364	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2962	2017-10-03 00:00:00	\N
3365	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2963	2017-10-03 00:00:00	\N
3366	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2964	2017-10-03 00:00:00	\N
3165	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2771	2017-09-24 17:28:55	2017-10-03 17:26:26
3244	MEMBREPOL	2017-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2850	2017-10-01 09:45:12	2017-10-03 17:34:07
3245	MEMBREPOL	2017-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2851	2017-10-01 10:06:58	2017-10-03 17:22:19
2621	MEMBREPOL	2011-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	788	\N	2017-10-01 10:39:22
3246	MEMBREPOL	2017-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2852	2017-10-01 10:44:23	2017-10-03 17:09:07
3247	MEMBREPOL	2017-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2853	2017-10-01 10:54:01	2017-10-03 17:08:45
3248	MEMBREPOL	2017-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2854	2017-10-01 11:03:20	2017-10-03 17:23:14
3249	MEMBREPOL	2017-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2855	2017-10-01 11:13:13	2017-10-03 17:40:49
3399	MEMBREPOL	2017-11-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2993	2017-11-27 00:00:00	\N
3251	MEMBREPOL	2017-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2857	2017-10-01 11:41:24	2017-10-03 17:16:11
3252	MEMBREPOL	2017-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2858	2017-10-01 11:48:00	2017-10-03 17:37:12
3253	MEMBREPOL	2017-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2859	2017-10-01 11:57:14	2017-10-03 17:37:42
3467	MEMBREPOL	2019-09-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3056	\N	\N
3405	MEMBREPOL	2017-12-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	2999	2017-12-19 14:46:02	\N
3406	MEMBREPOL	2017-12-19 00:00:00	2023-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3000	2017-12-19 00:00:00	\N
3413	MEMBREPOL	2018-07-01 00:00:00	2018-07-01 00:00:00	ANCIEN	\N	\N	\N	\N	3004	\N	\N
3428	MEMBREPOL	2018-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	3022	\N	\N
3415	MEMBREPOL	2018-07-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	3006	\N	\N
3417	MEMBREPOL	2018-07-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	3008	\N	\N
3420	MEMBREPOL	2014-10-07 00:00:00	2018-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	3010	\N	\N
3434	MEMBREPOL	2018-12-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3027	\N	\N
3430	MEMBREPOL	2018-11-04 00:00:00	2018-12-05 00:00:00	ANCIEN	\N	\N	\N	\N	3024	\N	\N
3444	MEMBREPOL	2019-03-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3039	\N	\N
3432	MEMBREPOL	2018-11-17 00:00:00	2020-08-06 00:00:00	ANCIEN	\N	\N	\N	\N	3026	\N	\N
3433	MEMBREPOL	2018-11-17 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	2024	\N	\N
3439	MEMBREPOL	2019-01-11 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3031	\N	\N
3461	MEMBREPOL	2019-06-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3050	\N	\N
3485	MEMBREPOL	2020-06-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3070	\N	\N
3492	MEMBREPOL	2020-08-03 00:00:00	2020-08-05 00:00:00	ANCIEN	\N	\N	\N	\N	3077	\N	\N
3511	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3096	\N	\N
3503	MEMBREPOL	2020-08-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	3088	\N	\N
3505	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3090	\N	\N
3507	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3092	\N	\N
3512	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3097	\N	\N
3688	MEMBREPOL	2020-12-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	3272	\N	\N
3727	MEMBREPOL	2023-01-01 00:00:00	2023-01-04 00:00:00	ANCIEN	\N	\N	\N	\N	3306	\N	\N
2997	MEMBREPOL	2015-06-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2216	2015-06-11 00:00:00	2015-06-11 00:00:00
3726	MEMBREPOL	2022-07-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	3305	\N	\N
3729	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3308	2023-09-24 00:00:00	\N
3730	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3309	2023-09-24 00:00:00	\N
3731	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3310	2023-09-24 00:00:00	\N
3732	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3311	2023-09-24 00:00:00	\N
3740	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3319	2023-09-24 00:00:00	\N
3741	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3320	2023-09-24 00:00:00	\N
3742	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3321	2023-09-24 00:00:00	\N
3751	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3330	2023-09-24 00:00:00	\N
3766	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3345	2023-09-24 00:00:00	\N
3792	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3371	2023-09-24 00:00:00	\N
3793	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3372	2023-09-24 00:00:00	\N
3794	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3373	2023-09-24 00:00:00	\N
3795	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3374	2023-09-24 00:00:00	\N
3796	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3375	2023-09-24 00:00:00	\N
3797	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3376	2023-09-24 00:00:00	\N
3798	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3377	2023-09-24 00:00:00	\N
3799	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3378	2023-09-24 00:00:00	\N
3801	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3380	2023-09-24 00:00:00	\N
3803	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3382	2023-09-24 00:00:00	\N
3804	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3383	2023-09-24 00:00:00	\N
3805	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3384	2023-09-24 00:00:00	\N
3806	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3385	2023-09-24 00:00:00	\N
3808	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3387	2023-09-24 00:00:00	\N
3809	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3388	2023-09-24 00:00:00	\N
3878	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3457	2023-09-24 00:00:00	\N
3879	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3458	2023-09-24 00:00:00	\N
3882	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3461	2023-09-24 00:00:00	\N
3967	PDTPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3538	\N	\N
4031	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3607	\N	\N
4032	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3608	\N	\N
4033	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3609	\N	\N
4034	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3610	\N	\N
4035	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3611	\N	\N
4036	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3612	\N	\N
4037	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3613	\N	\N
4038	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3614	\N	\N
4039	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3615	\N	\N
4040	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3616	\N	\N
4041	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3617	\N	\N
4042	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3618	\N	\N
4043	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3619	\N	\N
4094	MEMBREPOL	2024-04-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	3668	\N	\N
4045	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3621	\N	\N
4046	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3622	\N	\N
4047	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3623	\N	\N
4048	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3624	\N	\N
4049	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3625	\N	\N
4050	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3626	\N	\N
4051	PDTPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3620	\N	\N
4053	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3628	\N	\N
4054	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3629	\N	\N
4055	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3630	\N	\N
4056	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3631	\N	\N
4057	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3632	\N	\N
4058	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3633	\N	\N
4059	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3634	\N	\N
4060	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3635	\N	\N
4062	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3636	\N	\N
4063	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3637	\N	\N
4064	MEMBREPOL	2023-10-03 00:00:00	2029-11-27 00:00:00	ACTIF	\N	\N	\N	\N	3638	\N	\N
4065	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3639	\N	\N
4066	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3640	\N	\N
4067	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3641	\N	\N
4068	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3642	\N	\N
4069	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3643	\N	\N
4070	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3644	\N	\N
4071	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3645	\N	\N
4075	DELPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3648	\N	\N
3408	PDTPOL	2018-01-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2914	2018-01-23 00:00:00	\N
3398	MEMBREPOL	2017-11-25 00:00:00	2017-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	2992	2017-11-24 18:20:10	2017-11-27 18:37:30
3407	MEMBREPOL	2018-01-23 00:00:00	2018-05-21 00:00:00	ANCIEN	\N	\N	\N	\N	2033	2018-01-23 16:15:06	2018-05-22 17:59:38
3437	MEMBREPOL	2018-12-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	2683	\N	\N
3438	MEMBREPOL	2018-12-31 00:00:00	2019-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	3030	\N	\N
3460	MEMBREPOL	2019-06-24 00:00:00	2019-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	3049	\N	\N
3449	MEMBREPOL	2019-04-04 00:00:00	2019-06-23 00:00:00	ANCIEN	\N	\N	\N	\N	3035	\N	\N
3458	MEMBREPOL	2019-06-14 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3047	\N	\N
3468	MEMBREPOL	2019-10-01 00:00:00	2019-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	3057	\N	\N
3488	MEMBREPOL	2020-07-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3073	\N	\N
3583	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3168	\N	\N
3584	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3169	\N	\N
3585	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3170	\N	\N
3586	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3171	\N	\N
3587	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3172	\N	\N
3588	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3173	\N	\N
3589	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3174	\N	\N
3590	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3175	\N	\N
3591	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3176	\N	\N
3592	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3177	\N	\N
3593	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3178	\N	\N
3625	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3210	\N	\N
3595	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3180	\N	\N
3596	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3181	\N	\N
3597	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3182	\N	\N
3598	MEMBREPOL	2020-10-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	3183	\N	\N
3599	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3184	\N	\N
3600	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3185	\N	\N
3601	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3186	\N	\N
3602	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3187	\N	\N
3603	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3188	\N	\N
3604	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3189	\N	\N
3605	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3190	\N	\N
3606	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3191	\N	\N
3607	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3192	\N	\N
3608	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3193	\N	\N
3609	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3194	\N	\N
3610	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3195	\N	\N
3611	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3196	\N	\N
3612	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3197	\N	\N
3613	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3198	\N	\N
3614	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3199	\N	\N
3615	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3200	\N	\N
3616	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3201	\N	\N
3617	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3202	\N	\N
3618	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3203	\N	\N
3619	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3204	\N	\N
3620	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3205	\N	\N
3621	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3206	\N	\N
3622	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3207	\N	\N
3623	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3208	\N	\N
3627	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3212	\N	\N
3626	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3211	\N	\N
3628	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3213	\N	\N
3629	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3214	\N	\N
3630	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3215	\N	\N
3631	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3216	\N	\N
3632	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3217	\N	\N
3633	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3218	\N	\N
3634	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3219	\N	\N
3635	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3220	\N	\N
3636	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3221	\N	\N
3637	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3222	\N	\N
3638	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3223	\N	\N
3639	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3224	\N	\N
3643	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3228	\N	\N
3641	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3226	\N	\N
3642	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3227	\N	\N
3644	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3229	\N	\N
3645	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3230	\N	\N
3646	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3231	\N	\N
3647	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3232	\N	\N
3648	MEMBREPOL	2020-10-05 00:00:00	2020-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	3233	\N	\N
3649	MEMBREPOL	2020-10-05 00:00:00	2020-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	3234	\N	\N
3650	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3235	\N	\N
3651	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3236	\N	\N
3652	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3237	\N	\N
3653	PDTPOL	2020-10-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	3238	\N	\N
3654	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3239	\N	\N
3658	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3243	\N	\N
3656	MEMBREPOL	2020-10-05 00:00:00	2021-09-14 00:00:00	ANCIEN	\N	\N	\N	\N	3241	\N	\N
3657	MEMBREPOL	2020-10-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	3242	\N	\N
3659	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3244	\N	\N
3660	MEMBREPOL	2020-10-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	3245	\N	\N
3661	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3246	\N	\N
3662	MEMBREPOL	2020-10-05 00:00:00	2023-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	3247	\N	\N
3663	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3248	\N	\N
3664	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3249	\N	\N
3665	MEMBREPOL	2020-10-05 00:00:00	2022-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	3250	\N	\N
3666	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3251	\N	\N
3667	MEMBREPOL	2020-10-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	3252	\N	\N
3668	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3253	\N	\N
3669	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3254	\N	\N
3670	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3255	\N	\N
3671	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3256	\N	\N
3672	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3257	\N	\N
3673	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3258	\N	\N
3674	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3259	\N	\N
3675	MEMBREPOL	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	3260	\N	\N
3694	MEMBREPOL	2021-07-28 00:00:00	2021-09-07 00:00:00	ANCIEN	\N	\N	\N	\N	3278	\N	\N
3701	MEMBREPOL	2021-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	3285	\N	\N
3702	MEMBREPOL	2021-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	3286	\N	\N
3744	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3323	2023-09-24 00:00:00	\N
3833	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3412	2023-09-24 00:00:00	\N
3705	MEMBREPOL	2021-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	3289	\N	\N
3707	MEMBREPOL	2021-12-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	3291	\N	\N
2605	MEMBREPOL	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2324	\N	\N
3834	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3413	2023-09-24 00:00:00	\N
3837	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3416	2023-09-24 00:00:00	\N
3839	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3418	2023-09-24 00:00:00	\N
3845	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3424	2023-09-24 00:00:00	\N
3846	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3425	2023-09-24 00:00:00	\N
3847	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3426	2023-09-24 00:00:00	\N
3849	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3428	2023-09-24 00:00:00	\N
3850	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3429	2023-09-24 00:00:00	\N
3855	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3434	2023-09-24 00:00:00	\N
3856	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3435	2023-09-24 00:00:00	\N
3857	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3437	2023-09-24 00:00:00	\N
3884	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3463	2023-09-24 00:00:00	\N
3885	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3464	2023-09-24 00:00:00	\N
3886	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3465	2023-09-24 00:00:00	\N
3887	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3466	2023-09-24 00:00:00	\N
3888	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3467	2023-09-24 00:00:00	\N
3889	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3468	2023-09-24 00:00:00	\N
3890	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3469	2023-09-24 00:00:00	\N
4088	MEMBREPOL	2024-03-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	3662	\N	\N
4089	MEMBREPOL	2024-03-18 00:00:00	2024-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	3663	2024-03-18 00:00:00	\N
4091	MEMBREPOL	2024-03-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	3665	\N	\N
3241	MEMBREPOL	2017-09-27 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2847	2017-09-27 18:53:55	2017-10-03 17:22:09
3242	MEMBREPOL	2017-09-23 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2848	2017-09-27 18:58:16	2017-10-03 17:15:49
3273	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2878	2017-10-03 00:00:00	\N
3276	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2880	2017-10-03 00:00:00	\N
3280	MEMBREPOL	2017-10-03 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	2884	2017-10-03 16:56:55	\N
3283	MEMBREPOL	2017-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	2887	2017-10-03 16:57:16	\N
3285	MEMBREPOL	2017-10-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2889	2017-10-03 16:57:46	\N
3287	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2891	2017-10-03 00:00:00	\N
3288	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2892	2017-10-03 00:00:00	\N
3290	MEMBREPOL	2017-10-03 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	2894	2017-10-03 16:58:46	\N
3291	MEMBREPOL	2017-10-03 00:00:00	2022-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	2895	2017-10-03 16:59:02	\N
3292	MEMBREPOL	2017-10-03 00:00:00	2019-05-14 00:00:00	ANCIEN	\N	\N	\N	\N	2896	2017-10-03 16:59:15	\N
3293	PDTPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2130	2017-10-03 00:00:00	2017-10-03 00:00:00
3294	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2897	2017-10-03 00:00:00	\N
3424	MEMBREPOL	2018-08-07 00:00:00	2018-08-08 00:00:00	ANCIEN	\N	\N	\N	\N	3014	\N	\N
3443	MEMBREPOL	2019-03-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	3033	\N	\N
3480	MEMBREPOL	2020-06-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3065	\N	\N
3442	MEMBREPOL	2019-03-04 00:00:00	2019-03-04 00:00:00	ANCIEN	\N	\N	\N	\N	3040	\N	\N
3452	MEMBREPOL	2019-04-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	3037	\N	\N
3483	MEMBREPOL	2020-06-25 00:00:00	2020-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	3068	\N	\N
3515	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3100	\N	\N
3519	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3104	\N	\N
3498	MEMBREPOL	2020-08-04 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3083	\N	\N
3516	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3101	\N	\N
3520	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3105	\N	\N
3523	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3108	\N	\N
3524	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3109	\N	\N
3526	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3111	\N	\N
3528	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3113	\N	\N
3532	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3117	\N	\N
3534	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3119	\N	\N
3540	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3125	\N	\N
3543	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3128	\N	\N
3544	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3129	\N	\N
3548	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3133	\N	\N
3552	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3137	\N	\N
3553	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3138	\N	\N
3554	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3139	\N	\N
3555	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3140	\N	\N
3563	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3148	\N	\N
3564	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3149	\N	\N
3567	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3152	\N	\N
3568	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3153	\N	\N
3569	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3154	\N	\N
2594	MEMBREPOL	2011-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2317	\N	\N
3676	DELPOL	2020-10-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	1638	\N	\N
3682	MEMBREPOL	2020-11-02 00:00:00	2022-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	3266	\N	\N
3683	MEMBREPOL	2020-11-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	3267	\N	\N
3684	MEMBREPOL	2020-12-01 00:00:00	2020-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	3268	\N	\N
3706	MEMBREPOL	2021-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	3290	\N	\N
3693	MEMBREPOL	2021-07-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	3277	\N	\N
3708	MEMBREPOL	2021-12-08 00:00:00	2021-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	3292	\N	\N
3714	MEMBREPOL	2022-06-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	3298	\N	\N
3748	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3327	2023-09-24 00:00:00	\N
3749	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3328	2023-09-24 00:00:00	\N
3750	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3329	2023-09-24 00:00:00	\N
3752	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3331	2023-09-24 00:00:00	\N
3759	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3338	2023-09-24 00:00:00	\N
3760	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3339	2023-09-24 00:00:00	\N
3761	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3340	2023-09-24 00:00:00	\N
3762	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3341	2023-09-24 00:00:00	\N
3765	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3344	2023-09-24 00:00:00	\N
3772	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3351	2023-09-24 00:00:00	\N
3773	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3352	2023-09-24 00:00:00	\N
3774	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3353	2023-09-24 00:00:00	\N
3775	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3354	2023-09-24 00:00:00	\N
3777	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3356	2023-09-24 00:00:00	\N
3778	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3357	2023-09-24 00:00:00	\N
3779	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3358	2023-09-24 00:00:00	\N
3780	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3359	2023-09-24 00:00:00	\N
3788	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3367	2023-09-24 00:00:00	\N
3789	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3368	2023-09-24 00:00:00	\N
3790	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3369	2023-09-24 00:00:00	\N
3791	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3370	2023-09-24 00:00:00	\N
3800	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3379	2023-09-24 00:00:00	\N
3807	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3386	2023-09-24 00:00:00	\N
3810	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3389	2023-09-24 00:00:00	\N
3811	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3390	2023-09-24 00:00:00	\N
3812	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3391	2023-09-24 00:00:00	\N
3813	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3392	2023-09-24 00:00:00	\N
3814	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3393	2023-09-24 00:00:00	\N
3821	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3400	2023-09-24 00:00:00	\N
3822	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3401	2023-09-24 00:00:00	\N
3823	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3402	2023-09-24 00:00:00	\N
3824	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3403	2023-09-24 00:00:00	\N
3825	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3404	2023-09-24 00:00:00	\N
3826	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3405	2023-09-24 00:00:00	\N
3827	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3406	2023-09-24 00:00:00	\N
3828	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3407	2023-09-24 00:00:00	\N
3829	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3408	2023-09-24 00:00:00	\N
3830	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3409	2023-09-24 00:00:00	\N
3851	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3430	2023-09-24 00:00:00	\N
3863	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3442	2023-09-24 00:00:00	\N
3864	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3443	2023-09-24 00:00:00	\N
3865	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3444	2023-09-24 00:00:00	\N
3866	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3445	2023-09-24 00:00:00	\N
3867	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3446	2023-09-24 00:00:00	\N
3868	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3447	2023-09-24 00:00:00	\N
3869	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3448	2023-09-24 00:00:00	\N
3870	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3449	2023-09-24 00:00:00	\N
3953	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3532	\N	\N
3954	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3533	\N	\N
3955	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3534	\N	\N
3956	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3535	\N	\N
3957	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3536	\N	\N
3958	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3537	\N	\N
3960	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3539	\N	\N
3961	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3540	\N	\N
3962	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3541	\N	\N
3963	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3542	\N	\N
3964	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3543	\N	\N
3965	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3544	\N	\N
3966	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3545	\N	\N
3968	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3546	\N	\N
3969	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3547	\N	\N
3970	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3548	\N	\N
3971	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3549	\N	\N
3972	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3550	\N	\N
3973	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3551	\N	\N
3974	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3552	\N	\N
3975	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3553	\N	\N
3976	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3554	\N	\N
3977	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3555	\N	\N
3978	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3556	\N	\N
3979	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3557	\N	\N
3980	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3558	\N	\N
3981	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3559	\N	\N
3982	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3560	\N	\N
3983	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3561	\N	\N
3985	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3563	\N	\N
3986	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3564	\N	\N
3987	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3565	\N	\N
3988	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3566	\N	\N
3989	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3567	\N	\N
3990	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3568	\N	\N
3416	MEMBREPOL	2018-07-02 00:00:00	2018-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	3007	\N	\N
3395	MEMBREPOL	2017-11-03 00:00:00	2017-11-05 00:00:00	ANCIEN	\N	\N	\N	\N	2989	2017-11-06 15:15:01	2017-11-06 15:15:19
3396	MEMBREPOL	2017-11-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2990	2017-11-06 00:00:00	\N
3422	MEMBREPOL	2018-07-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	3012	\N	\N
3426	MEMBREPOL	2018-09-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	Devenu membre à part entière du groupe le 9 février 2023 après y avoir été simplement rattaché.	3016	\N	\N
3476	MEMBREPOL	2020-03-03 00:00:00	2020-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	3061	\N	\N
3692	MEMBREPOL	2021-07-06 00:00:00	2021-07-14 00:00:00	ANCIEN	\N	\N	\N	\N	3276	\N	\N
3717	MEMBREPOL	2022-07-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	3301	\N	\N
3681	MEMBREPOL	2020-11-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	3265	\N	\N
3728	MEMBREPOL	2023-01-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	3307	\N	\N
3763	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3342	2023-09-24 00:00:00	\N
3764	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3343	2023-09-24 00:00:00	\N
3767	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3346	2023-09-24 00:00:00	\N
3768	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3347	2023-09-24 00:00:00	\N
3769	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3348	2023-09-24 00:00:00	\N
3770	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3349	2023-09-24 00:00:00	\N
3771	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3350	2023-09-24 00:00:00	\N
3852	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3431	2023-09-24 00:00:00	\N
3853	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3432	2023-09-24 00:00:00	\N
3854	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3433	2023-09-24 00:00:00	\N
3858	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3436	2023-09-24 00:00:00	\N
3859	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3438	2023-09-24 00:00:00	\N
3860	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3439	2023-09-24 00:00:00	\N
3861	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3440	2023-09-24 00:00:00	\N
3862	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3441	2023-09-24 00:00:00	\N
3991	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3569	\N	\N
3992	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3570	\N	\N
3993	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3571	\N	\N
3994	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3572	\N	\N
3995	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3573	\N	\N
3996	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3574	\N	\N
3997	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3575	\N	\N
3998	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3576	\N	\N
3999	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3577	\N	\N
4000	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3578	\N	\N
4087	MEMBREPOL	2023-12-14 00:00:00	2024-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	3661	\N	\N
3203	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2809	2017-09-24 18:17:55	2017-10-03 17:26:36
3368	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2965	2017-10-03 00:00:00	\N
3369	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2966	2017-10-03 00:00:00	\N
3370	MEMBREPOL	2017-10-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1903	2017-10-03 17:31:16	\N
3371	PDTPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2310	2017-10-03 00:00:00	\N
3372	MEMBREPOL	2017-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	2967	2017-10-03 17:34:07	\N
3373	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2968	2017-10-03 00:00:00	\N
3374	MEMBREPOL	2017-10-03 00:00:00	2021-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	2969	2017-10-03 17:34:36	\N
3173	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2779	2017-09-24 17:42:25	2017-10-03 17:34:36
3375	MEMBREPOL	2017-10-03 00:00:00	2017-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	598	2017-10-03 17:35:01	2017-11-03 10:47:40
3376	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2970	2017-10-03 00:00:00	\N
3377	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2971	2017-10-03 00:00:00	\N
3378	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2972	2017-10-03 00:00:00	\N
3379	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2973	2017-10-03 00:00:00	\N
3185	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2791	2017-09-24 17:55:12	2017-10-03 17:36:04
3380	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2974	2017-10-03 00:00:00	\N
3205	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2811	2017-09-24 18:17:55	2017-10-03 17:36:10
3381	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2975	2017-10-03 00:00:00	\N
3382	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2976	2017-10-03 00:00:00	\N
3383	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2977	2017-10-03 00:00:00	\N
3384	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2978	2017-10-03 00:00:00	\N
3385	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2979	2017-10-03 00:00:00	\N
3386	MEMBREPOL	2017-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	2980	2017-10-03 17:37:12	\N
3387	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2981	2017-10-03 00:00:00	\N
3146	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2752	2017-09-24 16:45:25	2017-10-03 17:37:19
3388	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2982	2017-10-03 00:00:00	\N
3389	MEMBREPOL	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2983	2017-10-03 00:00:00	\N
3390	MEMBREPOL	2017-10-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2984	2017-10-03 17:37:42	\N
3391	MEMBREPOL	2017-10-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2985	2017-10-03 17:40:49	\N
3392	MEMBREPOL	2017-10-03 00:00:00	2021-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	2986	2017-10-03 17:41:07	\N
3411	MEMBREPOL	2018-06-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	3003	2018-06-01 18:48:36	\N
3402	MEMBREPOL	2017-12-18 00:00:00	2017-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	2996	2017-12-18 14:52:08	2018-01-22 17:49:37
3403	MEMBREPOL	2017-12-18 00:00:00	2018-07-24 00:00:00	ANCIEN	\N	\N	\N	\N	2997	2017-12-18 15:11:04	\N
3453	MEMBREPOL	2019-05-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	3038	\N	\N
3455	MEMBREPOL	2017-10-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3043	\N	\N
3456	MEMBREPOL	2019-05-28 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3045	\N	\N
3477	MEMBREPOL	2020-03-04 00:00:00	2020-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	3062	\N	\N
3466	MEMBREPOL	2019-08-28 00:00:00	2019-09-02 00:00:00	ANCIEN	\N	\N	\N	\N	3055	\N	\N
3478	MEMBREPOL	2020-03-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	3063	\N	\N
3490	MEMBREPOL	2020-07-14 00:00:00	2020-07-14 00:00:00	ANCIEN	\N	\N	\N	\N	3075	\N	\N
3491	MEMBREPOL	2020-07-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	3076	\N	\N
3504	MEMBREPOL	2020-09-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3089	\N	\N
3506	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3091	\N	\N
3508	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3093	\N	\N
3509	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3094	\N	\N
3510	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3095	\N	\N
3513	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3098	\N	\N
3517	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3102	\N	\N
3522	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3107	\N	\N
3525	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3110	\N	\N
3527	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3112	\N	\N
3529	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3114	\N	\N
3530	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3115	\N	\N
3531	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3116	\N	\N
3533	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3118	\N	\N
3545	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3130	\N	\N
3546	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3131	\N	\N
3547	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3132	\N	\N
3556	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3141	\N	\N
3557	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3142	\N	\N
3558	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3143	\N	\N
3559	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3144	\N	\N
3560	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3145	\N	\N
3565	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3150	\N	\N
3570	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3155	\N	\N
3571	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3156	\N	\N
3572	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3157	\N	\N
3573	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3158	\N	\N
3578	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3163	\N	\N
3580	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3165	\N	\N
3581	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3166	\N	\N
3582	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3167	\N	\N
3689	MEMBREPOL	2021-02-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	3273	\N	\N
3696	MEMBREPOL	2021-09-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	3280	\N	\N
3709	MEMBREPOL	2021-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	3293	\N	\N
3710	MEMBREPOL	2022-02-03 00:00:00	2022-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	3294	\N	\N
3733	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3312	2023-09-24 00:00:00	\N
3734	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3313	2023-09-24 00:00:00	\N
2319	MEMBREPOL	2008-10-01 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2048	\N	\N
3735	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3314	2023-09-24 00:00:00	\N
3746	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3325	2023-09-24 00:00:00	\N
3737	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3316	2023-09-24 00:00:00	\N
3738	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3317	2023-09-24 00:00:00	\N
3739	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3318	2023-09-24 00:00:00	\N
3743	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3322	2023-09-24 00:00:00	\N
3747	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3326	2023-09-24 00:00:00	\N
3753	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3332	2023-09-24 00:00:00	\N
3754	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3333	2023-09-24 00:00:00	\N
3755	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3334	2023-09-24 00:00:00	\N
3756	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3335	2023-09-24 00:00:00	\N
3757	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3336	2023-09-24 00:00:00	\N
3758	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3337	2023-09-24 00:00:00	\N
3776	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3355	2023-09-24 00:00:00	\N
3781	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3360	2023-09-24 00:00:00	\N
3782	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3361	2023-09-24 00:00:00	\N
3783	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3362	2023-09-24 00:00:00	\N
3784	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3363	2023-09-24 00:00:00	\N
3785	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3364	2023-09-24 00:00:00	\N
3786	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3365	2023-09-24 00:00:00	\N
3787	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3366	2023-09-24 00:00:00	\N
3831	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3410	2023-09-24 00:00:00	\N
3832	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3411	2023-09-24 00:00:00	\N
3835	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3414	2023-09-24 00:00:00	\N
3836	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3415	2023-09-24 00:00:00	\N
3838	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3417	2023-09-24 00:00:00	\N
3840	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3419	2023-09-24 00:00:00	\N
3841	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3420	2023-09-24 00:00:00	\N
3842	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3421	2023-09-24 00:00:00	\N
3843	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3422	2023-09-24 00:00:00	\N
3844	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3423	2023-09-24 00:00:00	\N
3848	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3427	2023-09-24 00:00:00	\N
3871	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3450	2023-09-24 00:00:00	\N
3872	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3451	2023-09-24 00:00:00	\N
3873	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3452	2023-09-24 00:00:00	\N
3874	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3453	2023-09-24 00:00:00	\N
3875	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3454	2023-09-24 00:00:00	\N
3876	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3455	2023-09-24 00:00:00	\N
3877	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3456	2023-09-24 00:00:00	\N
3880	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3459	2023-09-24 00:00:00	\N
3881	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3460	2023-09-24 00:00:00	\N
3883	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3462	2023-09-24 00:00:00	\N
3891	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3470	2023-09-24 00:00:00	\N
3410	MEMBREPOL	2018-06-01 00:00:00	2018-06-01 00:00:00	ANCIEN	\N	\N	\N	\N	3002	2018-05-31 11:00:21	2018-06-01 18:48:14
3412	MEMBREPOL	2018-06-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2951	2018-06-06 00:00:00	\N
3404	MEMBREPOL	2017-12-18 00:00:00	2017-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	2998	2017-12-18 15:12:00	2017-12-20 17:56:35
3463	MEMBREPOL	2019-07-01 00:00:00	2019-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	3052	\N	\N
3423	MEMBREPOL	2018-07-28 00:00:00	2018-09-02 00:00:00	ANCIEN	\N	\N	\N	\N	3013	\N	\N
3425	MEMBREPOL	2018-08-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	3015	\N	\N
3464	MEMBREPOL	2019-07-04 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3053	\N	\N
3475	MEMBREPOL	2019-11-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	3060	\N	\N
3474	MEMBREPOL	2019-10-28 00:00:00	2019-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	3059	\N	\N
3535	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3120	\N	\N
3482	MEMBREPOL	2020-06-18 00:00:00	2020-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	3067	\N	\N
3518	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3103	\N	\N
3521	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3106	\N	\N
3536	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3121	\N	\N
3537	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3122	\N	\N
3538	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3123	\N	\N
3539	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3124	\N	\N
3541	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3126	\N	\N
3542	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3127	\N	\N
3549	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3134	\N	\N
3550	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3135	\N	\N
3551	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3136	\N	\N
3561	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3146	\N	\N
3562	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3147	\N	\N
3566	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3151	\N	\N
3574	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3159	\N	\N
3575	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3160	\N	\N
3576	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3161	\N	\N
3577	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3162	\N	\N
3579	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3164	\N	\N
3685	MEMBREPOL	2020-12-02 00:00:00	2020-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	3269	\N	\N
3711	MEMBREPOL	2022-02-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	3295	\N	\N
2485	MEMBREPOL	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	2211	\N	\N
3716	MEMBREPOL	2022-07-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	3300	\N	\N
3745	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3324	2023-09-24 00:00:00	\N
3815	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3394	2023-09-24 00:00:00	\N
3816	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3395	2023-09-24 00:00:00	\N
3817	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3396	2023-09-24 00:00:00	\N
3818	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3397	2023-09-24 00:00:00	\N
3819	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3398	2023-09-24 00:00:00	\N
3820	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3399	2023-09-24 00:00:00	\N
3892	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3471	2023-09-24 00:00:00	\N
3893	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3472	2023-09-24 00:00:00	\N
3894	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3473	2023-09-24 00:00:00	\N
3895	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3474	2023-09-24 00:00:00	\N
3896	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3475	2023-09-25 00:00:00	\N
3897	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3476	2023-09-25 00:00:00	\N
3898	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3477	2023-09-25 00:00:00	\N
3899	MEMBREPOL	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	3478	2023-09-25 00:00:00	\N
3900	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3479	\N	\N
3901	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3480	\N	\N
3902	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3481	\N	\N
3903	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3482	\N	\N
3904	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3483	\N	\N
3905	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3484	\N	\N
3906	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3485	\N	\N
3907	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3486	\N	\N
3908	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3487	\N	\N
3909	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3488	\N	\N
3910	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3489	\N	\N
3911	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3490	\N	\N
3912	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3491	\N	\N
3913	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3492	\N	\N
3914	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3493	\N	\N
3915	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3494	\N	\N
3916	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3495	\N	\N
3917	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3496	\N	\N
3918	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3497	\N	\N
3919	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3498	\N	\N
3920	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3499	\N	\N
3921	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3500	\N	\N
3922	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3501	\N	\N
3923	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3502	\N	\N
3924	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3503	\N	\N
3925	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3504	\N	\N
3926	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3505	\N	\N
3927	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3506	\N	\N
3928	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3507	\N	\N
3929	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3508	\N	\N
3930	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3509	\N	\N
3931	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3510	\N	\N
3932	MEMBREPOL	2023-10-03 00:00:00	2023-11-13 00:00:00	ANCIEN	\N	\N	\N	\N	3511	\N	\N
3933	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3512	\N	\N
3934	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3513	\N	\N
3935	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3514	\N	\N
3936	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3515	\N	\N
3937	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3516	\N	\N
3938	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3517	\N	\N
3939	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3518	\N	\N
3940	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3519	\N	\N
3941	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3520	\N	\N
3942	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3521	\N	\N
3943	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3522	\N	\N
3944	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3523	\N	\N
3945	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3524	\N	\N
3946	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3525	\N	\N
3947	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3526	\N	\N
3948	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3527	\N	\N
3949	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3528	\N	\N
3950	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3529	\N	\N
3951	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3530	\N	\N
3952	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3531	\N	\N
4001	PDTPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3562	\N	\N
4002	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3579	\N	\N
4003	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3580	\N	\N
4004	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3581	\N	\N
4005	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3582	\N	\N
4006	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3583	\N	\N
4007	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3584	\N	\N
4008	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3585	\N	\N
4009	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3586	\N	\N
4010	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3587	\N	\N
4011	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3588	\N	\N
4012	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3589	\N	\N
4013	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3590	\N	\N
4014	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3591	\N	\N
4015	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3592	\N	\N
4016	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3593	\N	\N
4017	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3594	\N	\N
4018	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3595	\N	\N
4019	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3596	\N	\N
4085	MEMBREPOL	2023-11-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	3658	\N	\N
4021	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3598	\N	\N
4022	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3599	\N	\N
4023	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3600	\N	\N
4024	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3601	\N	\N
4025	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3602	\N	\N
4026	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3603	\N	\N
4027	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3604	\N	\N
4028	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3605	\N	\N
4029	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3606	\N	\N
4030	PDTPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3597	\N	\N
4061	PDTPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3627	\N	\N
4072	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3646	\N	\N
4073	MEMBREPOL	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	3647	\N	\N
4093	MEMBREPOL	2024-03-21 00:00:00	2024-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	3667	\N	\N
3240	MEMBREPOL	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	2846	2017-09-25 11:00:40	2017-10-03 17:06:12
3409	MEMBREPOL	2018-05-22 00:00:00	2018-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	3001	2018-05-22 18:00:01	\N
3419	MEMBREPOL	2018-07-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	3009	\N	\N
3421	MEMBREPOL	2018-07-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3011	\N	\N
3469	MEMBREPOL	2019-10-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	3058	\N	\N
3487	MEMBREPOL	2020-06-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3072	\N	\N
3486	MEMBREPOL	2020-06-28 00:00:00	2020-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	3071	\N	\N
3496	MEMBREPOL	2020-08-03 00:00:00	2021-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	3081	\N	\N
3499	MEMBREPOL	2020-08-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3084	\N	\N
3514	MEMBREPOL	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	3099	\N	\N
3501	MEMBREPOL	2020-08-07 00:00:00	2020-08-07 00:00:00	ANCIEN	\N	\N	\N	\N	3086	\N	\N
2320	MEMBREPOL	2008-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2049	\N	\N
3690	MEMBREPOL	1977-10-05 00:00:00	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	3274	2021-03-26 14:18:13	\N
3695	MEMBREPOL	2021-09-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	3279	\N	\N
4090	MEMBREPOL	2024-03-19 00:00:00	2024-03-19 00:00:00	ANCIEN	\N	\N	\N	\N	3664	\N	\N
\.


--
-- Data for Name: fonmemgrpsen; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY fonmemgrpsen (fonmemgrpsenid, fongrpsencod, fonmemgrpsendatdeb, fonmemgrpsendatfin, temvalcod, evelic, evelib, evelil, eveobs, memgrpsenid, fonmemgrpsenrngele, syscredat, sysmajdat) FROM stdin;
2881	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2914	\N	\N	\N
2882	MEMBRE	1999-01-01 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	2915	\N	\N	\N
2883	MEMBREBUR	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2916	23	\N	\N
2884	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2917	\N	\N	\N
2886	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2919	\N	\N	\N
2887	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2921	\N	\N	\N
2890	MEMBRE	1999-01-01 00:00:00	2002-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	2924	\N	\N	\N
2891	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2925	\N	\N	\N
2892	MEMBREBUR	1999-01-01 00:00:00	2002-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	2926	18	\N	\N
2894	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2928	\N	\N	\N
2895	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2929	\N	\N	\N
2896	MEMBRE	1999-01-01 00:00:00	2002-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	2930	\N	\N	\N
2897	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2931	\N	\N	\N
2900	MEMBRE	1999-01-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	2934	\N	\N	\N
2903	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2938	\N	\N	\N
2904	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2939	\N	\N	\N
2905	VICPDT	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2940	2	\N	\N
2907	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2942	3	\N	\N
2908	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2943	\N	\N	\N
2909	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2944	\N	\N	\N
2911	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2946	5	\N	\N
2699	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2719	\N	\N	\N
2700	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2721	\N	\N	\N
2702	MEMBRE	1999-01-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	\N	2723	\N	\N	\N
2703	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2724	\N	\N	\N
2706	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2727	6	\N	\N
2708	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2729	\N	\N	\N
2709	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2730	\N	\N	\N
2710	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2731	\N	\N	\N
2711	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	2732	\N	\N	\N
2712	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2733	\N	\N	\N
2713	VICPDT	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	2736	3	\N	\N
2714	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2737	\N	\N	\N
2717	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2740	\N	\N	\N
2719	MEMBRE	1999-01-01 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	2742	\N	\N	\N
2720	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	2743	\N	\N	\N
2721	TRESOR	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	2744	11	\N	\N
2722	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2745	6	\N	\N
2723	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2746	4	\N	\N
2725	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2748	\N	\N	\N
2726	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2749	\N	\N	\N
2727	MEMBRE	1999-01-01 00:00:00	2009-09-09 00:00:00	ANCIEN	\N	\N	\N	\N	2750	\N	\N	\N
2728	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2751	\N	\N	\N
2729	TRESOR	1999-01-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	2752	12	\N	\N
2731	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2754	\N	\N	\N
2732	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2755	\N	\N	\N
2733	MEMBRE	1999-01-01 00:00:00	1999-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	2756	\N	\N	\N
2734	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2757	\N	\N	\N
2735	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2759	\N	\N	\N
2736	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2760	14	\N	\N
2737	VICPDT	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	2761	15	\N	\N
2738	SECRET	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	2762	18	\N	\N
2739	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2763	19	\N	\N
2740	PDTDEL	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Tchad	\N	2764	13	\N	\N
2741	PDTDEL	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	Rwanda	\N	2765	12	\N	\N
2743	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	2767	\N	\N	\N
2744	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	2768	\N	\N	\N
2745	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2769	\N	\N	\N
2747	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	2771	\N	\N	\N
2748	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2772	\N	\N	\N
2749	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2773	20	\N	\N
2750	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2774	\N	\N	\N
2752	PDTDEL	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Ouganda	\N	2776	11	\N	\N
2753	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2777	\N	\N	\N
2754	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2778	\N	\N	\N
2755	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	2779	\N	\N	\N
2756	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2780	\N	\N	\N
2758	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2783	\N	\N	\N
2759	VICPDTDRT	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Afrique de l'Ouest	\N	2784	3	\N	\N
2760	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2785	\N	\N	\N
2761	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2786	\N	\N	\N
2763	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2788	\N	\N	\N
2764	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2789	\N	\N	\N
2767	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2792	\N	\N	\N
2768	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2793	\N	\N	\N
2771	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2796	\N	\N	\N
2772	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2797	\N	\N	\N
2773	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2798	\N	\N	\N
2774	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2799	\N	\N	\N
2776	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2802	\N	\N	\N
2778	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2804	\N	\N	\N
2780	PDTDEL	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Guinée équatoriale	\N	2806	10	\N	\N
2782	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2808	\N	\N	\N
2784	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2810	\N	\N	\N
2785	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2811	\N	\N	\N
2786	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2812	\N	\N	\N
2788	MEMBRE	1999-01-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	2814	\N	\N	\N
2789	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2815	\N	\N	\N
2791	MEMBREBUR	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2817	12	\N	\N
2793	MEMBRE	1999-01-01 00:00:00	2001-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	2819	\N	\N	\N
2794	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2821	\N	\N	\N
2795	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2822	\N	\N	\N
2798	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2826	\N	\N	\N
2799	MEMBRE	1999-01-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	2827	\N	\N	\N
2801	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2829	\N	\N	\N
2802	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2830	\N	\N	\N
2803	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2831	\N	\N	\N
2805	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2833	\N	\N	\N
2586	MEMBRE	1999-01-01 00:00:00	2002-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	2586	\N	\N	\N
2588	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	2588	\N	\N	\N
2589	MEMBRE	1999-01-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	2589	\N	\N	\N
2590	PDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2590	1	\N	\N
2591	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2591	\N	\N	\N
2592	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2592	\N	\N	\N
2616	VICPDT	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	2629	5	\N	\N
2595	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2595	\N	\N	\N
2597	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2599	\N	\N	\N
2598	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2600	\N	\N	\N
2599	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2601	\N	\N	\N
2600	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2602	\N	\N	\N
2601	VICPDT	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2603	4	\N	\N
2602	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2604	\N	\N	\N
2603	MEMBRE	1999-01-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	2605	\N	\N	\N
2604	MEMBRE	1999-01-01 00:00:00	2001-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	2606	\N	\N	\N
2606	MEMBRE	1999-01-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	2608	\N	\N	\N
2608	VICPDT	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2610	9	\N	\N
2609	MEMBRE	1999-01-01 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	2611	0	\N	\N
2610	MEMBRE	1999-01-01 00:00:00	2001-09-20 00:00:00	ANCIEN	\N	\N	\N	\N	2612	\N	\N	\N
2611	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2613	\N	\N	\N
2612	VICPDT	1999-01-01 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	2614	7	\N	\N
2613	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2615	9	\N	\N
2614	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2627	\N	\N	\N
2617	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2630	\N	\N	\N
2618	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	2631	\N	\N	\N
2619	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2632	\N	\N	\N
2624	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2637	4	\N	\N
2626	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2639	\N	\N	\N
2627	MEMBRE	1999-01-01 00:00:00	2009-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	2640	\N	\N	\N
2628	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2641	\N	\N	\N
2629	SECRET	1999-01-01 00:00:00	2000-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	2642	7	\N	\N
2631	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2644	\N	\N	\N
2633	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2646	\N	\N	\N
2635	MEMBRE	1999-01-01 00:00:00	1999-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2648	\N	\N	\N
2636	MEMBRE	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	2649	\N	\N	\N
2637	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2650	\N	\N	\N
2639	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2652	\N	\N	\N
2640	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2653	\N	\N	\N
2641	MEMBRE	1999-01-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	\N	2654	\N	\N	\N
2643	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2656	\N	\N	\N
2644	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2657	\N	\N	\N
2645	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2658	\N	\N	\N
2646	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2659	\N	\N	\N
2648	SECRET	1999-01-01 00:00:00	2001-10-30 00:00:00	ANCIEN	\N	\N	\N	\N	2661	12	\N	\N
2649	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2662	15	\N	\N
2650	MEMBRE	1999-01-01 00:00:00	2001-10-30 00:00:00	ANCIEN	\N	\N	\N	\N	2663	\N	\N	\N
2652	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2665	\N	\N	\N
2653	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2666	\N	\N	\N
2654	MEMBRE	1999-01-01 00:00:00	2001-10-30 00:00:00	ANCIEN	\N	\N	\N	\N	2667	\N	\N	\N
2657	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2670	\N	\N	\N
2658	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2671	\N	\N	\N
2661	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	2674	\N	\N	\N
2663	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2676	\N	\N	\N
2665	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2678	\N	\N	\N
2666	MEMBRE	1999-01-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	\N	2679	\N	\N	\N
2667	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2680	\N	\N	\N
2669	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2682	\N	\N	\N
2670	MEMBRE	1999-01-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	2683	\N	\N	\N
2671	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2684	\N	\N	\N
2674	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2687	\N	\N	\N
2675	MEMBRE	1999-01-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	2688	\N	\N	\N
2678	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2691	\N	\N	\N
2679	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2692	\N	\N	\N
2682	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2695	4	\N	\N
2683	MEMBRE	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	2697	\N	\N	\N
2684	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2698	\N	\N	\N
2687	SECRET	1999-01-01 00:00:00	2003-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	2705	8	\N	\N
2688	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2706	\N	\N	\N
2689	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2707	\N	\N	\N
2691	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2709	\N	\N	\N
2692	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2710	9	\N	\N
2695	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2713	\N	\N	\N
2696	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2715	\N	\N	\N
2697	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2716	\N	\N	\N
2573	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2573	\N	\N	\N
2574	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2574	\N	\N	\N
2576	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2576	\N	\N	\N
2578	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	2578	\N	\N	\N
2579	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2579	4	\N	\N
2580	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2580	\N	\N	\N
2582	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2582	\N	\N	\N
2585	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2585	\N	\N	\N
2477	SECRET	1998-10-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	2477	\N	\N	\N
2478	VICPDT	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2478	5	\N	\N
2479	SECRET	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2479	12	\N	\N
2480	MEMBRE	1998-10-01 00:00:00	2004-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	2480	\N	\N	\N
2482	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2482	\N	\N	\N
2483	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2483	\N	\N	\N
2484	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2484	\N	\N	\N
2485	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2485	\N	\N	\N
2487	MEMBRE	1998-10-01 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	2487	\N	\N	\N
2488	MEMBRE	1998-10-01 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	2488	\N	\N	\N
2489	SECRET	1998-10-01 00:00:00	2001-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	2489	12	\N	\N
2490	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2490	\N	\N	\N
2492	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2492	\N	\N	\N
2493	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2493	\N	\N	\N
2494	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2494	\N	\N	\N
2495	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2495	\N	\N	\N
2497	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2497	\N	\N	\N
2498	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2498	\N	\N	\N
2499	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2499	\N	\N	\N
2500	VICPDT	1998-10-01 00:00:00	2004-11-15 00:00:00	ANCIEN	\N	\N	\N	\N	2500	3	\N	\N
2502	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2502	\N	\N	\N
2503	MEMBRE	1998-10-01 00:00:00	2005-03-07 00:00:00	ANCIEN	\N	\N	\N	\N	2503	\N	\N	\N
2504	MEMBRE	1998-10-01 00:00:00	2004-11-09 00:00:00	ANCIEN	\N	\N	\N	\N	2504	\N	\N	\N
2505	MEMBRE	1998-10-01 00:00:00	2001-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	2505	\N	\N	\N
2507	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2507	\N	\N	\N
2508	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2508	\N	\N	\N
3018	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3058	\N	\N	\N
3023	MEMBRE	1999-01-01 00:00:00	2003-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	3064	\N	\N	\N
3021	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3061	\N	\N	\N
3022	MEMBRE	1999-01-01 00:00:00	2003-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	3062	\N	\N	\N
3025	TRESOR	1999-01-01 00:00:00	2003-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	3066	6	\N	\N
3026	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3067	\N	\N	\N
3027	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3068	\N	\N	\N
3028	VICPDT	1999-01-01 00:00:00	2001-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	3069	3	\N	\N
3029	MEMBRE	1999-01-01 00:00:00	2003-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	3070	\N	\N	\N
3030	MEMBRE	1999-01-01 00:00:00	2003-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	3071	\N	\N	\N
3031	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3072	\N	\N	\N
3034	MEMBRE	1999-01-01 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	3075	\N	\N	\N
3035	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3076	\N	\N	\N
3036	MEMBRE	1999-01-01 00:00:00	2004-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	3077	\N	\N	\N
3037	VICPDT	1999-01-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	3078	17	\N	\N
3038	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	3079	\N	\N	\N
3039	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3080	\N	\N	\N
3040	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3081	\N	\N	\N
3041	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3082	\N	\N	\N
3043	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3084	\N	\N	\N
3044	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3085	\N	\N	\N
3045	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3086	\N	\N	\N
3046	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3087	\N	\N	\N
3047	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3088	\N	\N	\N
3048	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3089	\N	\N	\N
3049	VICPDT	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3090	4	\N	\N
3051	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3092	\N	\N	\N
3053	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3095	\N	\N	\N
3054	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3096	\N	\N	\N
3055	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3097	\N	\N	\N
3056	MEMBRE	1999-01-01 00:00:00	2004-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	3098	\N	\N	\N
3057	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3099	\N	\N	\N
3058	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3100	\N	\N	\N
3059	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3101	\N	\N	\N
3060	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3102	\N	\N	\N
3061	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3103	\N	\N	\N
3062	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3104	\N	\N	\N
3063	MEMBRE	1999-01-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	\N	3105	\N	\N	\N
3064	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3106	\N	\N	\N
3066	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3108	\N	\N	\N
3067	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3109	\N	\N	\N
3068	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3110	\N	\N	\N
3069	MEMBRE	1999-01-01 00:00:00	2004-11-15 00:00:00	ANCIEN	\N	\N	\N	\N	3111	\N	\N	\N
3070	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3112	\N	\N	\N
3071	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3113	\N	\N	\N
3073	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3115	\N	\N	\N
2296	MEMBRE	1998-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2296	\N	\N	\N
2297	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2297	\N	\N	\N
2298	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2298	\N	\N	\N
2299	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2299	\N	\N	\N
2302	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2302	\N	\N	\N
2303	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2303	\N	\N	\N
2304	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2304	\N	\N	\N
2305	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2305	\N	\N	\N
2307	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2307	\N	\N	\N
2308	MEMBRE	1998-10-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	2308	\N	\N	\N
2309	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2309	\N	\N	\N
2310	MEMBRE	1998-10-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	2310	\N	\N	\N
2312	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2312	\N	\N	\N
2313	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2313	\N	\N	\N
2314	MEMBRE	1999-01-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	2314	\N	\N	\N
2316	MEMBRE	1998-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2316	\N	\N	\N
2318	MEMBRE	1998-10-01 00:00:00	2009-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	2318	\N	\N	\N
2319	MEMBRE	1999-01-01 00:00:00	2001-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	2319	\N	\N	\N
2320	MEMBRE	1999-01-01 00:00:00	2002-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	2320	\N	\N	\N
2321	MEMBREBUR	1998-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2321	12	\N	\N
2323	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2323	\N	\N	\N
2324	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2324	\N	\N	\N
2325	MEMBRE	1998-10-01 00:00:00	2000-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	2325	\N	\N	\N
2326	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2326	\N	\N	\N
2328	MEMBRE	1999-01-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	2328	\N	\N	\N
2329	MEMBRE	1998-10-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	2329	\N	\N	\N
2330	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2330	6	\N	\N
2331	MEMBRE	1998-10-01 00:00:00	1999-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	2331	\N	\N	\N
2333	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2333	\N	\N	\N
2334	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2334	\N	\N	\N
2335	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2335	\N	\N	\N
2336	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2336	\N	\N	\N
2338	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2338	\N	\N	\N
2339	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2339	\N	\N	\N
2341	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2341	\N	\N	\N
2342	SECRET	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2342	8	\N	\N
2344	VICPDT	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2344	4	\N	\N
2345	SECRET	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2345	9	\N	\N
2346	PDTDEL	1999-01-01 00:00:00	2001-12-17 00:00:00	ANCIEN	\N	\N	Mercosur	\N	2346	9	\N	\N
2347	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2347	\N	\N	\N
2349	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2349	\N	\N	\N
2350	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2350	\N	\N	\N
2352	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2352	\N	\N	\N
2353	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2353	\N	\N	\N
2356	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2356	\N	\N	\N
2357	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2357	14	\N	\N
2358	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2358	\N	\N	\N
2360	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2360	\N	\N	\N
2362	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2362	\N	\N	\N
2256	MEMBRE	1998-10-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	2256	\N	\N	\N
2257	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2257	\N	\N	\N
2258	MEMBRE	1999-01-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	2258	\N	\N	\N
2260	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2260	\N	\N	\N
2261	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2261	\N	\N	\N
2155	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2155	\N	\N	\N
2156	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2156	\N	\N	\N
2158	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2158	\N	\N	\N
2159	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2159	\N	\N	\N
2161	MEMBRE	1998-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	2161	\N	\N	\N
2162	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2162	\N	\N	\N
2164	MEMBRE	1998-10-01 00:00:00	2001-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	2164	\N	\N	\N
2165	MEMBRE	1998-10-01 00:00:00	2001-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	2165	\N	\N	\N
2166	MEMBRE	1998-10-01 00:00:00	2001-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	2166	\N	\N	\N
2167	MEMBRE	1998-10-01 00:00:00	2001-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	2167	\N	\N	\N
2169	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2169	\N	\N	\N
2952	SECRET	1999-01-01 00:00:00	2004-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	2988	11	\N	\N
2953	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2989	\N	\N	\N
2954	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2990	\N	\N	\N
2955	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2991	\N	\N	\N
2957	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2993	\N	\N	\N
2959	SECRET	1999-01-01 00:00:00	2004-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	2995	8	\N	\N
2960	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2996	\N	\N	\N
2961	MEMBRE	1999-01-01 00:00:00	2001-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	2997	\N	\N	\N
2962	MEMBRE	1999-01-01 00:00:00	2003-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	2998	\N	\N	\N
2963	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2999	\N	\N	\N
2964	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3000	\N	\N	\N
2965	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3001	\N	\N	\N
2966	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3002	\N	\N	\N
2967	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3003	\N	\N	\N
2970	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3006	\N	\N	\N
2973	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3010	\N	\N	\N
2975	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3012	7	\N	\N
2976	MEMBRE	1999-01-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	3014	\N	\N	\N
2977	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3015	\N	\N	\N
2979	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3017	\N	\N	\N
2980	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3018	\N	\N	\N
2981	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3019	\N	\N	\N
2983	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3021	\N	\N	\N
2984	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3023	\N	\N	\N
2985	SECRET	1999-01-01 00:00:00	2004-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	3024	9	\N	\N
2987	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3026	\N	\N	\N
2988	PDT	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3027	1	\N	\N
2989	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3028	3	\N	\N
2992	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3032	\N	\N	\N
2076	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2076	\N	\N	\N
2078	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2078	\N	\N	\N
2080	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2080	\N	\N	\N
2081	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2081	\N	\N	\N
2082	VICPDT	1998-10-01 00:00:00	2004-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	2082	3	\N	\N
2084	SECRET	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2084	12	\N	\N
2085	MEMBRE	1998-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	2085	\N	\N	\N
2086	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2086	\N	\N	\N
2087	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2087	\N	\N	\N
2090	VICPDT	1998-10-01 00:00:00	2004-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	2090	\N	\N	\N
2091	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2091	\N	\N	\N
2092	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2092	\N	\N	\N
2094	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2094	\N	\N	\N
2095	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2095	2	\N	\N
2096	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2096	\N	\N	\N
2097	MEMBRE	1998-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	2097	\N	\N	\N
2099	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	2099	\N	\N	\N
2100	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2100	4	\N	\N
2101	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2101	\N	\N	\N
2102	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	2102	\N	\N	\N
2104	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2104	\N	\N	\N
2105	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2105	\N	\N	\N
2106	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2106	\N	\N	\N
2107	MEMBRE	1999-01-01 00:00:00	2004-11-15 00:00:00	ANCIEN	\N	\N	\N	\N	2107	\N	\N	\N
2111	MEMBRE	1998-10-01 00:00:00	1999-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2111	\N	\N	\N
2112	MEMBRE	1999-01-01 00:00:00	1999-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	2112	\N	\N	\N
2113	MEMBRE	1998-10-01 00:00:00	1999-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	2113	\N	\N	\N
2114	MEMBRE	1998-10-01 00:00:00	1999-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2114	\N	\N	\N
2116	MEMBRE	1998-10-01 00:00:00	1999-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2116	\N	\N	\N
2117	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2117	\N	\N	\N
2118	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2118	\N	\N	\N
2119	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2119	\N	\N	\N
2121	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2121	\N	\N	\N
2122	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2122	\N	\N	\N
2124	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2124	\N	\N	\N
2125	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2125	\N	\N	\N
2127	MEMBRE	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2127	\N	\N	\N
2128	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2128	\N	\N	\N
2129	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2129	\N	\N	\N
2130	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2130	\N	\N	\N
2133	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2133	\N	\N	\N
2134	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2134	\N	\N	\N
2135	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2135	\N	\N	\N
2137	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2137	\N	\N	\N
2139	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2139	\N	\N	\N
2141	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2141	\N	\N	\N
2142	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2142	\N	\N	\N
2143	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2143	\N	\N	\N
2146	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2146	\N	\N	\N
2147	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2147	\N	\N	\N
2042	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2042	\N	\N	\N
2043	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2043	\N	\N	\N
2044	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2044	\N	\N	\N
2046	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2046	\N	\N	\N
2047	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2047	\N	\N	\N
1941	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1941	\N	\N	\N
1942	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1942	\N	\N	\N
1944	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1944	5	\N	\N
1945	SECRET	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1945	15	\N	\N
1946	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1946	\N	\N	\N
1947	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1947	\N	\N	\N
1949	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1949	\N	\N	\N
1950	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1950	\N	\N	\N
1951	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1951	\N	\N	\N
1952	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1952	9	\N	\N
1954	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1954	\N	\N	\N
1955	MEMBREBUR	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1955	23	\N	\N
1956	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1956	\N	\N	\N
1957	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1957	\N	\N	\N
1960	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1960	\N	\N	\N
1961	VICPDT	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1961	4	\N	\N
1963	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1963	\N	\N	\N
1965	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1965	\N	\N	\N
1966	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1966	\N	\N	\N
1967	PDTHON	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1967	2	\N	\N
1968	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1968	\N	\N	\N
1970	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1970	\N	\N	\N
1973	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1973	\N	\N	\N
1974	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1974	\N	\N	\N
1975	VICPDT	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1975	5	\N	\N
1977	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1977	\N	\N	\N
1978	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1978	\N	\N	\N
1979	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1979	\N	\N	\N
1980	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1980	\N	\N	\N
1982	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1982	\N	\N	\N
1983	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1983	\N	\N	\N
1984	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1984	\N	\N	\N
1985	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1985	\N	\N	\N
1987	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	1987	\N	\N	\N
1988	MEMBRE	1998-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	1988	\N	\N	\N
1990	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1990	\N	\N	\N
1993	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1993	\N	\N	\N
1994	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1994	\N	\N	\N
1995	VICPDT	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1995	5	\N	\N
1996	PDT	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1996	1	\N	\N
1998	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1998	\N	\N	\N
1999	TRESOR	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1999	8	\N	\N
2000	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2000	\N	\N	\N
2002	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2002	\N	\N	\N
2004	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2004	\N	\N	\N
2005	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2005	\N	\N	\N
2006	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2006	\N	\N	\N
2007	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2007	\N	\N	\N
2010	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2010	\N	\N	\N
2011	MEMBRE	1998-10-01 00:00:00	2004-11-09 00:00:00	ANCIEN	\N	\N	\N	\N	2011	\N	\N	\N
2013	TRESOR	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2013	8	\N	\N
2015	PDT	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2015	1	\N	\N
2016	MEMBRE	1999-01-01 00:00:00	2009-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	2016	\N	\N	\N
2017	SECRET	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2017	17	\N	\N
2018	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2018	\N	\N	\N
2020	MEMBRE	1998-10-01 00:00:00	2001-09-20 00:00:00	ANCIEN	\N	\N	\N	\N	2020	\N	\N	\N
2021	VICPDT	1998-10-01 00:00:00	2009-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	2021	13	\N	\N
2022	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2022	\N	\N	\N
2023	PDTDEL	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Ghana	\N	2023	7	\N	\N
2026	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2026	2	\N	\N
2027	VICPDT	1999-01-01 00:00:00	2004-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	2027	3	\N	\N
2028	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2028	\N	\N	\N
2030	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2030	\N	\N	\N
2032	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2032	\N	\N	\N
2034	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2034	\N	\N	\N
2035	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2035	\N	\N	\N
2036	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2036	\N	\N	\N
2039	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2039	\N	\N	\N
2040	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2040	\N	\N	\N
1936	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1936	\N	\N	\N
1937	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1937	\N	\N	\N
1939	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1939	\N	\N	\N
1940	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1940	\N	\N	\N
1834	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1834	\N	\N	\N
1835	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1835	\N	\N	\N
1837	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1837	\N	\N	\N
1838	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1838	\N	\N	\N
1839	MEMBRE	1998-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	1839	\N	\N	\N
1840	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1840	\N	\N	\N
1842	VICPDT	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1842	10	\N	\N
1843	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1843	\N	\N	\N
1844	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1844	\N	\N	\N
1845	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1845	7	\N	\N
1847	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1847	\N	\N	\N
1848	SECRET	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1848	10	\N	\N
1849	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1849	\N	\N	\N
1850	SECRET	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1850	16	\N	\N
1852	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1852	\N	\N	\N
1853	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1853	5	\N	\N
1854	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1854	\N	\N	\N
1855	MEMBREBUR	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1855	22	\N	\N
1857	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1857	\N	\N	\N
1859	VICPDT	2009-01-20 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	1859	7	\N	\N
1860	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1860	4	\N	\N
1861	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1861	\N	\N	\N
1863	MEMBRE	1998-10-01 00:00:00	2004-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	1863	\N	\N	\N
1864	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1864	\N	\N	\N
1866	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1866	6	\N	\N
1867	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1867	\N	\N	\N
1869	MEMBRE	1998-10-01 00:00:00	2007-02-25 00:00:00	ANCIEN	\N	\N	\N	\N	1869	\N	\N	\N
1870	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	1870	\N	\N	\N
1871	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1871	\N	\N	\N
1872	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1872	\N	\N	\N
1874	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1874	\N	\N	\N
1875	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1875	\N	\N	\N
1876	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1876	\N	\N	\N
1877	VICPDT	1999-01-01 00:00:00	2007-02-25 00:00:00	ANCIEN	\N	\N	\N	\N	1877	5	\N	\N
1881	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1881	3	\N	\N
1882	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1882	\N	\N	\N
1883	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1883	\N	\N	\N
1884	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1884	\N	\N	\N
1886	PDTDEL	1998-10-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	Mali	\N	1886	11	\N	\N
1887	MEMBRE	0098-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1887	\N	\N	\N
1888	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1888	\N	\N	\N
1889	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1889	\N	\N	\N
1892	TRESOR	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1892	6	\N	\N
1893	VICPDT	1998-10-01 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	1893	2	\N	\N
1894	PDTDEL	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Brunei	\N	1894	4	\N	\N
1895	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1895	\N	\N	\N
1897	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1897	\N	\N	\N
1898	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1898	\N	\N	\N
1900	TRESOR	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1900	6	\N	\N
1903	PDTDEL	1998-10-01 00:00:00	2004-11-09 00:00:00	ANCIEN	\N	\N	Kirghizstan et Tadjikistan	\N	1903	5	\N	\N
1904	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1904	\N	\N	\N
1905	PDT	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1905	1	\N	\N
1906	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1906	13	\N	\N
1908	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1908	\N	\N	\N
1909	VICPDT	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1909	5	\N	\N
1910	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1910	\N	\N	\N
1911	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1911	6	\N	\N
1913	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1913	\N	\N	\N
1915	MEMBREBUR	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1915	13	\N	\N
1916	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	1916	\N	\N	\N
1918	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1918	\N	\N	\N
1919	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1919	\N	\N	\N
1920	SECRET	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	1920	11	\N	\N
1921	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1921	\N	\N	\N
1923	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1923	\N	\N	\N
1924	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1924	\N	\N	\N
1927	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1927	\N	\N	\N
1931	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1931	\N	\N	\N
1932	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1932	\N	\N	\N
1933	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1933	\N	\N	\N
1935	SECRET	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1935	10	\N	\N
1828	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1828	\N	\N	\N
1830	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1830	\N	\N	\N
1831	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1831	\N	\N	\N
1832	VICPDT	1998-10-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	1832	7	\N	\N
1833	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1833	4	\N	\N
3074	MEMBRE	1999-01-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	3116	\N	\N	\N
3075	MEMBRE	1999-01-01 00:00:00	2001-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	3117	\N	\N	\N
3076	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3118	\N	\N	\N
3078	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3120	\N	\N	\N
3079	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3121	\N	\N	\N
3080	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3122	\N	\N	\N
3081	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3123	\N	\N	\N
3084	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3127	\N	\N	\N
3085	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3128	\N	\N	\N
3088	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3131	\N	\N	\N
3089	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3132	\N	\N	\N
3092	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	3135	\N	\N	\N
3093	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3136	\N	\N	\N
3095	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3138	\N	\N	\N
3096	SECRET	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3139	10	\N	\N
3097	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3140	\N	\N	\N
3098	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3141	\N	\N	\N
3100	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3143	10	\N	\N
3101	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3144	\N	\N	\N
3102	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3145	\N	\N	\N
3104	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3147	6	\N	\N
3109	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3152	\N	\N	\N
3110	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3153	\N	\N	\N
3113	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3156	\N	\N	\N
3114	SECRET	1999-01-01 00:00:00	2008-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	3157	12	\N	\N
3115	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3158	\N	\N	\N
3117	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3160	\N	\N	\N
3118	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3161	\N	\N	\N
3121	MEMBRE	1999-01-01 00:00:00	2004-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	3164	\N	\N	\N
3123	VICPDT	1999-01-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	3166	3	\N	\N
2912	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2948	\N	\N	\N
2913	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2949	\N	\N	\N
2915	PDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2951	1	\N	\N
2916	MEMBRE	1999-01-01 00:00:00	2004-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	2952	\N	\N	\N
2917	VICPDT	1999-01-01 00:00:00	2009-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	2953	4	\N	\N
2918	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2954	\N	\N	\N
2919	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2955	\N	\N	\N
2920	MEMBRE	1999-01-01 00:00:00	2004-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	2956	\N	\N	\N
2922	VICPDT	1999-01-01 00:00:00	2009-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	2958	6	\N	\N
2923	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2959	8	\N	\N
2924	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2960	\N	\N	\N
2925	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2961	7	\N	\N
2926	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2962	\N	\N	\N
2927	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2963	\N	\N	\N
2928	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	2964	\N	\N	\N
2929	MEMBRE	1999-01-01 00:00:00	2001-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	2965	\N	\N	\N
2930	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2966	\N	\N	\N
2932	MEMBRE	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	2968	\N	\N	\N
2933	VICPDT	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2969	5	\N	\N
2934	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2970	6	\N	\N
2935	SECRET	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	2971	13	\N	\N
2936	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2972	\N	\N	\N
2937	SECRET	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2973	8	\N	\N
2938	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2974	\N	\N	\N
2939	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2975	\N	\N	\N
2940	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2976	\N	\N	\N
2941	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2977	\N	\N	\N
2942	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2978	\N	\N	\N
2943	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2979	\N	\N	\N
2944	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2980	\N	\N	\N
2945	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2981	\N	\N	\N
2946	MEMBRE	1999-01-01 00:00:00	2001-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	2982	\N	\N	\N
2947	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2983	\N	\N	\N
2950	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2986	\N	\N	\N
2951	MEMBREBUR	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2987	16	\N	\N
2994	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3034	\N	\N	\N
2996	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3036	\N	\N	\N
2997	MEMBRE	1999-01-01 00:00:00	2009-10-19 00:00:00	ANCIEN	\N	\N	\N	\N	3037	\N	\N	\N
2998	MEMBRE	1999-01-01 00:00:00	2009-10-19 00:00:00	ANCIEN	\N	\N	\N	\N	3038	\N	\N	\N
3000	MEMBRE	1999-01-01 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	3040	\N	\N	\N
3002	VICPDT	1999-01-01 00:00:00	2009-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	3042	7	\N	\N
3003	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3043	\N	\N	\N
3005	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3045	15	\N	\N
3006	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3046	\N	\N	\N
3007	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3047	\N	\N	\N
3009	MEMBRE	1999-01-01 00:00:00	1999-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	3049	\N	\N	\N
3010	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3050	\N	\N	\N
3011	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3051	\N	\N	\N
3013	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3053	13	\N	\N
3014	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3054	\N	\N	\N
2806	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2834	\N	\N	\N
2807	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2835	\N	\N	\N
2809	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2837	\N	\N	\N
2811	MEMBRE	1999-01-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	2839	\N	\N	\N
2813	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2842	\N	\N	\N
2814	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2843	\N	\N	\N
2815	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2844	\N	\N	\N
2816	MEMBRE	1999-01-01 00:00:00	2001-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	2845	\N	\N	\N
2817	MEMBRE	1999-01-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	2846	\N	\N	\N
2818	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2848	\N	\N	\N
2819	MEMBRE	1999-01-01 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	2849	\N	\N	\N
2820	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2850	\N	\N	\N
2821	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2851	\N	\N	\N
2822	MEMBRE	1999-01-01 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	2852	0	\N	\N
2823	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2853	\N	\N	\N
2824	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2854	\N	\N	\N
2825	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2855	\N	\N	\N
2829	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2859	\N	\N	\N
2830	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2860	\N	\N	\N
2831	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2861	\N	\N	\N
2832	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2862	\N	\N	\N
2833	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2864	\N	\N	\N
2835	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2866	7	\N	\N
2836	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2867	\N	\N	\N
2837	VICPDT	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	2869	2	\N	\N
2839	VICPDT	1999-01-01 00:00:00	2002-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	2871	3	\N	\N
2840	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2872	\N	\N	\N
2841	SECRET	1999-01-01 00:00:00	2002-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	2873	8	\N	\N
2843	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2875	\N	\N	\N
2844	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2876	9	\N	\N
2845	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2877	\N	\N	\N
2846	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2878	\N	\N	\N
2847	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2879	\N	\N	\N
2848	MEMBRE	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	2880	\N	\N	\N
2849	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2882	\N	\N	\N
2850	MEMBRE	1999-01-01 00:00:00	2002-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	2883	\N	\N	\N
2851	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2884	\N	\N	\N
2852	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2885	\N	\N	\N
2853	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2886	\N	\N	\N
2854	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2887	\N	\N	\N
2856	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2889	\N	\N	\N
2857	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2890	\N	\N	\N
2858	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2891	\N	\N	\N
2859	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2892	\N	\N	\N
2860	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2893	\N	\N	\N
2861	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2894	\N	\N	\N
2862	SECRET	1999-01-01 00:00:00	2002-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	2895	8	\N	\N
2864	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2897	\N	\N	\N
2865	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2898	\N	\N	\N
2867	MEMBREBUR	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2900	15	\N	\N
2869	MEMBRE	1999-01-01 00:00:00	2002-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	2902	\N	\N	\N
2870	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2903	4	\N	\N
2871	MEMBRE	1999-01-01 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	2904	0	\N	\N
2873	VICPDT	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2906	3	\N	\N
2874	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2907	\N	\N	\N
2875	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2908	\N	\N	\N
2877	SECRET	1999-01-01 00:00:00	2002-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	2910	12	\N	\N
2878	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2911	\N	\N	\N
933	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	933	\N	\N	\N
934	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	934	\N	\N	\N
935	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	935	\N	\N	\N
936	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	936	\N	\N	\N
938	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	938	\N	\N	\N
939	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	939	\N	\N	\N
940	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	940	\N	\N	\N
941	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	941	\N	\N	\N
943	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	943	\N	\N	\N
944	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	944	\N	\N	\N
945	TRESOR	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	945	17	\N	\N
946	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	946	\N	\N	\N
948	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	948	\N	\N	\N
950	PDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	950	1	\N	\N
951	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	951	\N	\N	\N
952	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	952	12	\N	\N
954	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	954	\N	\N	\N
955	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	955	\N	\N	\N
956	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	956	\N	\N	\N
957	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	957	\N	\N	\N
959	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	959	\N	\N	\N
960	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	960	\N	\N	\N
964	MEMBRE	1998-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	964	\N	\N	\N
965	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	965	\N	\N	\N
967	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	967	\N	\N	\N
968	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	968	\N	\N	\N
969	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	969	\N	\N	\N
970	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	970	\N	\N	\N
972	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	972	\N	\N	\N
973	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	973	\N	\N	\N
974	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	974	\N	\N	\N
975	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	975	\N	\N	\N
869	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	869	\N	\N	\N
870	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	870	\N	\N	\N
871	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	871	\N	\N	\N
872	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	872	\N	\N	\N
767	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	767	\N	\N	\N
768	PDT	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	768	1	\N	\N
769	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	769	\N	\N	\N
770	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	770	\N	\N	\N
772	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	772	\N	\N	\N
773	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	773	\N	\N	\N
774	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	774	\N	\N	\N
775	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	775	\N	\N	\N
777	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	777	3	\N	\N
778	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	778	\N	\N	\N
779	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	779	\N	\N	\N
780	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	780	\N	\N	\N
782	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	782	\N	\N	\N
783	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	783	\N	\N	\N
784	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	784	\N	\N	\N
785	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	785	\N	\N	\N
787	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	787	\N	\N	\N
788	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	788	\N	\N	\N
789	VICPDT	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	789	5	\N	\N
790	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	790	\N	\N	\N
792	MEMBRE	1998-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	792	\N	\N	\N
793	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	793	\N	\N	\N
794	VICPDT	1998-10-01 00:00:00	2004-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	794	3	\N	\N
2170	SECRET	1999-01-01 00:00:00	2001-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	2170	8	\N	\N
2171	PDT	1998-10-01 00:00:00	2001-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	2171	1	\N	\N
2174	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2174	\N	\N	\N
2176	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2176	\N	\N	\N
2177	MEMBREBUR	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2177	10	\N	\N
2178	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2178	\N	\N	\N
2179	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2179	\N	\N	\N
2181	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2181	\N	\N	\N
2183	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2183	\N	\N	\N
2184	MEMBRE	1998-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2184	\N	\N	\N
2185	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2185	\N	\N	\N
2188	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2188	\N	\N	\N
2189	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2189	\N	\N	\N
2190	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2190	\N	\N	\N
2192	VICPDT	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2192	5	\N	\N
2193	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2193	\N	\N	\N
2194	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	2194	\N	\N	\N
2195	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2195	\N	\N	\N
2197	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2197	\N	\N	\N
2199	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2199	\N	\N	\N
2200	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2200	\N	\N	\N
2201	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2201	\N	\N	\N
2203	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2203	\N	\N	\N
2204	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2204	\N	\N	\N
2205	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2205	\N	\N	\N
2206	VICPDT	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2206	8	\N	\N
2208	MEMBRE	1998-10-01 00:00:00	2002-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	2208	\N	\N	\N
2209	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2209	\N	\N	\N
2210	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2210	\N	\N	\N
2211	MEMBRE	1999-01-01 00:00:00	2002-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	2211	\N	\N	\N
2214	MEMBRE	1998-10-01 00:00:00	2002-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	2214	\N	\N	\N
2215	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2215	\N	\N	\N
2216	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2216	\N	\N	\N
1428	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1428	\N	\N	\N
1429	MEMBRE	1999-01-01 00:00:00	2004-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	1429	\N	\N	\N
1430	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1430	\N	\N	\N
1432	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1432	\N	\N	\N
1433	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1433	\N	\N	\N
1434	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	1434	\N	\N	\N
1436	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1436	\N	\N	\N
1438	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1438	\N	\N	\N
1439	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1439	\N	\N	\N
1440	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1440	\N	\N	\N
1441	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1441	\N	\N	\N
1443	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1443	\N	\N	\N
1444	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1444	\N	\N	\N
1446	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1446	\N	\N	\N
1447	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1447	\N	\N	\N
1449	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1449	\N	\N	\N
1450	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1450	\N	\N	\N
1451	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1451	\N	\N	\N
1452	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1452	\N	\N	\N
1455	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1455	\N	\N	\N
1456	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1456	\N	\N	\N
1457	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1457	\N	\N	\N
1458	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	1458	\N	\N	\N
1460	PDTDEL	1999-01-01 00:00:00	2001-12-17 00:00:00	ANCIEN	\N	\N	Pays Andins	\N	1460	10	\N	\N
1461	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1461	\N	\N	\N
1462	MEMBREBUR	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1462	17	\N	\N
1463	SECRET	1998-10-01 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	1463	\N	\N	\N
1465	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1465	\N	\N	\N
1466	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1466	\N	\N	\N
1467	VICPDT	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1467	6	\N	\N
1469	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1469	\N	\N	\N
1471	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1471	\N	\N	\N
1472	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1472	\N	\N	\N
1473	VICPDT	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1473	5	\N	\N
1474	VICPDT	1998-10-01 00:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	1474	5	\N	\N
1476	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1476	\N	\N	\N
1477	SECRET	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1477	7	\N	\N
1478	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1478	\N	\N	\N
1479	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1479	7	\N	\N
1481	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1481	\N	\N	\N
1482	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1482	\N	\N	\N
1484	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1484	\N	\N	\N
1485	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1485	\N	\N	\N
1488	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1488	\N	\N	\N
1490	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1490	\N	\N	\N
1491	PDTDEL	1999-01-01 00:00:00	2009-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	1491	6	\N	\N
1493	MEMBRE	1999-01-01 00:00:00	2002-10-22 00:00:00	ANCIEN	\N	\N	\N	\N	1493	\N	\N	\N
1495	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1495	\N	\N	\N
1497	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1497	\N	\N	\N
1498	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1498	\N	\N	\N
1499	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1499	\N	\N	\N
1502	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1502	\N	\N	\N
1503	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1503	\N	\N	\N
1505	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1505	\N	\N	\N
1506	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1506	\N	\N	\N
1401	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1401	\N	\N	\N
1402	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	1402	\N	\N	\N
1403	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1403	\N	\N	\N
1404	VICPDT	1999-01-01 00:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	1404	7	\N	\N
1405	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1405	\N	\N	\N
1302	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1302	\N	\N	\N
1305	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1305	\N	\N	\N
1306	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1306	\N	\N	\N
1307	SECRET	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1307	9	\N	\N
1309	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1309	\N	\N	\N
1310	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1310	\N	\N	\N
1311	VICPDT	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1311	6	\N	\N
1312	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1312	\N	\N	\N
1314	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1314	10	\N	\N
1315	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1315	\N	\N	\N
1316	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1316	\N	\N	\N
1317	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1317	\N	\N	\N
1320	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1320	\N	\N	\N
1321	SECRET	1999-01-01 00:00:00	2002-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	1321	14	\N	\N
1322	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1322	\N	\N	\N
1323	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1323	5	\N	\N
1325	PDTDEL	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	Norvège	\N	1325	3	\N	\N
1327	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1327	\N	\N	\N
1329	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1329	\N	\N	\N
1331	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1331	\N	\N	\N
1332	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1332	\N	\N	\N
1333	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1333	\N	\N	\N
1334	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1334	\N	\N	\N
1336	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1336	\N	\N	\N
1338	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1338	\N	\N	\N
1339	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1339	\N	\N	\N
1340	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1340	\N	\N	\N
1341	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1341	\N	\N	\N
1343	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1343	\N	\N	\N
1344	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1344	\N	\N	\N
1345	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1345	\N	\N	\N
1348	MEMBRE	1999-01-01 00:00:00	2000-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	1348	\N	\N	\N
1350	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1350	\N	\N	\N
1351	MEMBRE	1998-10-01 00:00:00	2000-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	1351	\N	\N	\N
1352	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1352	\N	\N	\N
1353	MEMBRE	1998-10-01 00:00:00	2000-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	1353	\N	\N	\N
1355	MEMBRE	1999-01-01 00:00:00	2000-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	1355	\N	\N	\N
1356	MEMBRE	1999-01-01 00:00:00	2000-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	1356	\N	\N	\N
639	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	639	\N	\N	\N
640	SECRET	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	640	18	\N	\N
641	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	641	\N	\N	\N
642	SECRET	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	642	16	\N	\N
644	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	644	\N	\N	\N
645	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	645	\N	\N	\N
646	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	646	\N	\N	\N
649	VICPDT	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	649	2	\N	\N
650	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	650	\N	\N	\N
651	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	651	\N	\N	\N
654	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	654	\N	\N	\N
549	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	549	\N	\N	\N
550	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	550	5	\N	\N
551	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	551	\N	\N	\N
552	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	552	\N	\N	\N
553	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	553	\N	\N	\N
449	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	449	\N	\N	\N
450	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	450	\N	\N	\N
452	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	452	\N	\N	\N
453	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	453	\N	\N	\N
455	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	455	\N	\N	\N
456	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	456	\N	\N	\N
457	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	457	\N	\N	\N
459	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	459	\N	\N	\N
460	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	460	\N	\N	\N
461	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	461	\N	\N	\N
462	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	462	\N	\N	\N
464	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	464	\N	\N	\N
465	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	465	\N	\N	\N
468	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	468	\N	\N	\N
469	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	469	\N	\N	\N
471	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	471	\N	\N	\N
472	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	472	\N	\N	\N
473	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	473	\N	\N	\N
475	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	475	\N	\N	\N
477	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	477	\N	\N	\N
478	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	478	\N	\N	\N
479	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	479	\N	\N	\N
480	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	480	\N	\N	\N
482	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	482	\N	\N	\N
483	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	483	\N	\N	\N
484	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	484	\N	\N	\N
485	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	485	\N	\N	\N
487	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	487	\N	\N	\N
488	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	488	\N	\N	\N
489	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	489	\N	\N	\N
490	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	490	\N	\N	\N
492	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	492	\N	\N	\N
493	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	493	\N	\N	\N
494	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	494	\N	\N	\N
495	VICPDTDRT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	Caraïbes	\N	495	3	\N	\N
496	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	496	\N	\N	\N
498	PDT	1998-10-01 00:00:00	2008-09-07 00:00:00	ANCIEN	\N	\N	\N	\N	498	1	\N	\N
500	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	500	\N	\N	\N
501	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	501	\N	\N	\N
502	MEMBRE	1998-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	502	\N	\N	\N
505	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	505	\N	\N	\N
506	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	506	\N	\N	\N
507	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	507	\N	\N	\N
508	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	508	\N	\N	\N
510	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	510	\N	\N	\N
511	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	511	\N	\N	\N
513	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	513	\N	\N	\N
514	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	514	\N	\N	\N
516	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	516	\N	\N	\N
517	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	517	\N	\N	\N
518	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	518	\N	\N	\N
519	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	519	\N	\N	\N
521	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	521	\N	\N	\N
522	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	522	\N	\N	\N
523	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	523	\N	\N	\N
524	MEMBRE	1999-01-01 00:00:00	2004-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	524	\N	\N	\N
526	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	526	\N	\N	\N
527	MEMBRE	1998-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	527	\N	\N	\N
528	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	528	\N	\N	\N
529	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	529	\N	\N	\N
531	VICPDT	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	531	6	\N	\N
532	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	532	\N	\N	\N
533	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	533	\N	\N	\N
536	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	536	\N	\N	\N
538	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	538	\N	\N	\N
539	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	539	\N	\N	\N
540	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	540	\N	\N	\N
541	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	541	14	\N	\N
543	SECRET	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	543	7	\N	\N
544	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	544	\N	\N	\N
545	VICPDT	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	545	7	\N	\N
546	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	546	\N	\N	\N
111	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	111	\N	\N	\N
112	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	112	\N	\N	\N
114	SECRET	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	114	13	\N	\N
1	MEMBREBUR	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1	10	\N	\N
2	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2	\N	\N	\N
3	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3	\N	\N	\N
6	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6	\N	\N	\N
7	MEMBRE	1998-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	7	\N	\N	\N
8	PDTDEL	1998-10-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	Burkina Faso	\N	8	3	\N	\N
9	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9	\N	\N	\N
11	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11	\N	\N	\N
12	SECRET	1998-10-01 00:00:00	2001-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	12	11	\N	\N
13	MEMBRE	1998-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	13	\N	\N	\N
15	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	15	\N	\N	\N
16	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16	\N	\N	\N
17	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17	\N	\N	\N
19	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19	\N	\N	\N
21	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21	\N	\N	\N
22	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22	\N	\N	\N
23	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23	\N	\N	\N
25	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25	\N	\N	\N
27	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	27	\N	\N	\N
28	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	28	\N	\N	\N
29	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29	\N	\N	\N
30	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	30	\N	\N	\N
32	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	32	\N	\N	\N
33	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	33	\N	\N	\N
35	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	35	\N	\N	\N
36	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	36	\N	\N	\N
38	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	38	\N	\N	\N
39	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	39	\N	\N	\N
40	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	40	\N	\N	\N
41	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	41	\N	\N	\N
43	MEMBRE	1999-01-01 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	43	\N	\N	\N
45	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	45	\N	\N	\N
47	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	47	\N	\N	\N
48	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	48	\N	\N	\N
49	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	49	\N	\N	\N
50	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	50	\N	\N	\N
52	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	52	\N	\N	\N
53	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	53	\N	\N	\N
54	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	54	\N	\N	\N
55	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	55	\N	\N	\N
57	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	57	\N	\N	\N
58	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	58	\N	\N	\N
59	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	59	\N	\N	\N
60	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	60	\N	\N	\N
62	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	62	\N	\N	\N
63	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	63	\N	\N	\N
64	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	64	\N	\N	\N
65	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	65	\N	\N	\N
67	MEMBRE	1998-10-01 00:00:00	2001-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	67	\N	\N	\N
68	MEMBRE	1998-10-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	68	\N	\N	\N
69	VICPDT	1998-10-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	69	4	\N	\N
70	MEMBRE	1998-09-30 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	70	\N	\N	\N
72	VICPDT	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	72	4	\N	\N
73	MEMBRE	1998-10-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	73	\N	\N	\N
74	MEMBRE	1998-09-30 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	74	\N	\N	\N
76	SECRET	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	76	12	\N	\N
77	MEMBRE	1998-09-30 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	77	\N	\N	\N
78	SECRET	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	78	17	\N	\N
79	VICPDT	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	79	5	\N	\N
82	MEMBRE	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	82	\N	\N	\N
83	MEMBRE	1998-09-30 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	83	\N	\N	\N
87	VICPDT	1998-10-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	87	6	\N	\N
89	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89	\N	\N	\N
90	MEMBRE	1998-10-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	90	\N	\N	\N
93	MEMBRE	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	93	\N	\N	\N
94	MEMBREBUR	1998-10-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	94	8	\N	\N
95	SECRET	1998-10-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	95	10	\N	\N
97	VICPDT	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	97	11	\N	\N
100	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	100	\N	\N	\N
102	MEMBRE	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	102	\N	\N	\N
104	VICPDT	1998-10-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	104	4	\N	\N
106	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	106	\N	\N	\N
108	PDTHON	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	108	1	\N	\N
110	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	110	\N	\N	\N
115	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	115	\N	\N	\N
116	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	116	\N	\N	\N
117	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	117	\N	\N	\N
118	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	118	\N	\N	\N
119	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	119	\N	\N	\N
120	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	120	\N	\N	\N
122	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	122	\N	\N	\N
125	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	125	\N	\N	\N
126	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	126	\N	\N	\N
127	MEMBRE	1999-01-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	\N	127	\N	\N	\N
128	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	128	\N	\N	\N
130	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	130	\N	\N	\N
131	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	131	\N	\N	\N
132	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	132	\N	\N	\N
133	VICPDT	1999-01-01 00:00:00	2001-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	133	6	\N	\N
135	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	135	\N	\N	\N
136	VICPDTPRE	1999-01-01 00:00:00	2001-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	136	2	\N	\N
137	MEMBRE	1998-10-01 00:00:00	2001-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	137	\N	\N	\N
138	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	138	\N	\N	\N
141	MEMBRE	1998-10-01 00:00:00	2001-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	141	\N	\N	\N
142	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	142	\N	\N	\N
143	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	143	\N	\N	\N
144	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	144	\N	\N	\N
146	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	146	\N	\N	\N
147	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	147	\N	\N	\N
148	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	148	\N	\N	\N
150	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	150	\N	\N	\N
152	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	152	\N	\N	\N
153	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	153	\N	\N	\N
154	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	154	\N	\N	\N
155	PDT	1999-01-01 00:00:00	2001-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	155	1	\N	\N
157	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	157	\N	\N	\N
159	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	159	\N	\N	\N
160	PDT	1999-01-01 00:00:00	2001-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	160	1	\N	\N
162	MEMBRE	1999-01-01 00:00:00	2001-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	162	\N	\N	\N
163	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	163	\N	\N	\N
164	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	164	\N	\N	\N
165	MEMBRE	1999-01-01 00:00:00	2001-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	165	\N	\N	\N
167	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	167	\N	\N	\N
168	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	168	\N	\N	\N
169	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	169	\N	\N	\N
172	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	172	\N	\N	\N
174	MEMBRE	1998-09-30 00:00:00	1998-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	174	\N	\N	\N
176	MEMBRE	1998-09-30 00:00:00	1998-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	176	\N	\N	\N
177	MEMBRE	1998-09-30 00:00:00	1998-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	177	\N	\N	\N
178	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	178	\N	\N	\N
180	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	180	\N	\N	\N
181	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	181	\N	\N	\N
182	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	182	\N	\N	\N
183	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	183	\N	\N	\N
185	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	185	\N	\N	\N
186	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	186	\N	\N	\N
187	MEMBRE	1998-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	187	\N	\N	\N
190	VICPDT	1998-10-01 00:00:00	2004-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	190	4	\N	\N
191	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	191	\N	\N	\N
192	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	192	\N	\N	\N
193	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	193	\N	\N	\N
196	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	196	\N	\N	\N
197	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	197	\N	\N	\N
198	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	198	\N	\N	\N
199	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	199	\N	\N	\N
201	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	201	\N	\N	\N
1728	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1728	\N	\N	\N
1729	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1729	\N	\N	\N
1730	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1730	5	\N	\N
1733	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1733	\N	\N	\N
1734	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1734	\N	\N	\N
1736	SECRET	1999-01-01 00:00:00	2001-10-30 00:00:00	ANCIEN	\N	\N	\N	\N	1736	14	\N	\N
1738	VICPDT	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1738	5	\N	\N
1740	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1740	\N	\N	\N
1741	MEMBRE	1998-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	1741	\N	\N	\N
1744	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1744	\N	\N	\N
1746	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1746	\N	\N	\N
1747	MEMBRE	1998-09-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1747	\N	\N	\N
1748	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1748	\N	\N	\N
1749	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1749	\N	\N	\N
1751	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1751	\N	\N	\N
1752	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1752	\N	\N	\N
1753	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1753	\N	\N	\N
1754	MEMBREBUR	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1754	10	\N	\N
1756	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1756	\N	\N	\N
1757	MEMBRE	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	1757	\N	\N	\N
1758	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1758	\N	\N	\N
1759	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1759	\N	\N	\N
1761	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1761	\N	\N	\N
1764	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1764	\N	\N	\N
1765	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1765	\N	\N	\N
1766	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1766	\N	\N	\N
1768	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1768	\N	\N	\N
1769	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1769	\N	\N	\N
1770	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1770	11	\N	\N
1771	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1771	\N	\N	\N
1773	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1773	\N	\N	\N
1774	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1774	7	\N	\N
1775	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1775	6	\N	\N
1777	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1777	\N	\N	\N
1779	PDT	1998-10-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	1779	1	\N	\N
1780	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1780	\N	\N	\N
1781	MEMBRE	1998-10-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	1781	\N	\N	\N
1782	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1782	\N	\N	\N
1785	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1785	\N	\N	\N
1786	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1786	\N	\N	\N
1787	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1787	\N	\N	\N
1788	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1788	\N	\N	\N
1790	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1790	2	\N	\N
1791	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1791	\N	\N	\N
1792	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1792	\N	\N	\N
1793	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1793	\N	\N	\N
1795	SECRET	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1795	6	\N	\N
1796	MEMBREBUR	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1796	6	\N	\N
1797	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1797	\N	\N	\N
1798	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1798	\N	\N	\N
1800	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1800	\N	\N	\N
1801	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1801	\N	\N	\N
1802	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1802	\N	\N	\N
1803	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1803	\N	\N	\N
1805	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1805	\N	\N	\N
1806	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1806	\N	\N	\N
1807	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1807	\N	\N	\N
1808	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1808	\N	\N	\N
1810	SECRET	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1810	8	\N	\N
1811	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1811	\N	\N	\N
1812	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1812	9	\N	\N
1813	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1813	10	\N	\N
1815	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1815	\N	\N	\N
1816	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1816	\N	\N	\N
1818	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1818	\N	\N	\N
1819	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1819	\N	\N	\N
1821	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1821	\N	\N	\N
1822	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1822	\N	\N	\N
1823	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1823	\N	\N	\N
1824	TRESOR	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	1824	9	\N	\N
1827	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1827	\N	\N	\N
1723	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1723	8	\N	\N
1725	PDTHON	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1725	2	\N	\N
1726	MEMBREBUR	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1726	6	\N	\N
1621	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1621	\N	\N	\N
1622	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1622	\N	\N	\N
1623	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1623	\N	\N	\N
1624	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1624	\N	\N	\N
1626	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1626	\N	\N	\N
1627	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1627	\N	\N	\N
1628	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1628	\N	\N	\N
1629	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1629	\N	\N	\N
1631	PDT	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1631	1	\N	\N
1632	VICPDT	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1632	7	\N	\N
2510	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2510	\N	\N	\N
2512	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2512	\N	\N	\N
2513	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2513	\N	\N	\N
2514	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2514	\N	\N	\N
2515	SECRET	1998-10-01 00:00:00	2009-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	2515	16	\N	\N
2517	MEMBRE	1998-10-01 00:00:00	2004-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	2517	\N	\N	\N
2518	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2518	\N	\N	\N
2519	MEMBRE	1998-10-01 00:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	2519	0	\N	\N
2520	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2520	\N	\N	\N
2522	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2522	\N	\N	\N
2523	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2523	\N	\N	\N
2525	SECRET	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2525	9	\N	\N
2526	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2526	\N	\N	\N
2529	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2529	\N	\N	\N
2530	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2530	\N	\N	\N
2531	MEMBRE	1998-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	2531	\N	\N	\N
2533	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2533	\N	\N	\N
2535	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2535	\N	\N	\N
2537	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2537	\N	\N	\N
2538	MEMBRE	1998-10-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	2538	\N	\N	\N
2539	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2539	\N	\N	\N
2542	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2542	\N	\N	\N
2543	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2543	\N	\N	\N
2545	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2545	\N	\N	\N
2546	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2546	\N	\N	\N
2549	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2549	\N	\N	\N
2550	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2550	\N	\N	\N
2551	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2551	\N	\N	\N
2553	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2553	\N	\N	\N
2555	MEMBRE	1999-01-01 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	2555	\N	\N	\N
2557	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2557	\N	\N	\N
2558	MEMBRE	1998-10-01 00:00:00	2004-11-09 00:00:00	ANCIEN	\N	\N	\N	\N	2558	\N	\N	\N
2559	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2559	\N	\N	\N
2562	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2562	\N	\N	\N
2563	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2563	\N	\N	\N
2565	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2565	\N	\N	\N
2566	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2566	\N	\N	\N
2569	MEMBRE	1999-01-01 00:00:00	2004-11-09 00:00:00	ANCIEN	\N	\N	\N	\N	2569	\N	\N	\N
2570	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2570	\N	\N	\N
2571	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2571	\N	\N	\N
2471	MEMBRE	1998-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2471	\N	\N	\N
2472	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2472	\N	\N	\N
2473	MEMBRE	1998-10-01 00:00:00	2005-03-19 00:00:00	ANCIEN	\N	\N	\N	\N	2473	\N	\N	\N
2474	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2474	\N	\N	\N
2369	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2369	12	\N	\N
2371	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2371	\N	\N	\N
2372	VICPDT	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2372	7	\N	\N
2373	VICPDT	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2373	3	\N	\N
2375	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2375	6	\N	\N
2376	VICPDT	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2376	7	\N	\N
2377	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2377	\N	\N	\N
2378	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2378	\N	\N	\N
2381	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2381	\N	\N	\N
2382	SECRET	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2382	9	\N	\N
2383	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2383	4	\N	\N
2384	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2384	9	\N	\N
2386	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2386	5	\N	\N
2387	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2387	\N	\N	\N
2388	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2388	\N	\N	\N
2389	PDTDEL	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	Suède	\N	2389	3	\N	\N
2391	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2391	\N	\N	\N
2392	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2392	\N	\N	\N
2394	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2394	\N	\N	\N
2395	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2395	\N	\N	\N
2397	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2397	\N	\N	\N
2398	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2398	\N	\N	\N
2399	MEMBRE	1998-10-01 00:00:00	2009-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	2399	\N	\N	\N
2400	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2400	\N	\N	\N
2402	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2402	\N	\N	\N
2404	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2404	\N	\N	\N
2405	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2405	\N	\N	\N
2406	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2406	\N	\N	\N
2408	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2408	\N	\N	\N
2409	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2409	\N	\N	\N
2410	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2410	\N	\N	\N
2411	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2411	\N	\N	\N
2413	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2413	\N	\N	\N
2416	MEMBRE	1998-10-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	2416	\N	\N	\N
2417	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2417	\N	\N	\N
2418	MEMBRE	1998-10-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	2418	\N	\N	\N
2420	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2420	\N	\N	\N
2422	MEMBRE	1998-10-01 00:00:00	2004-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	2422	\N	\N	\N
2423	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2423	\N	\N	\N
2425	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2425	\N	\N	\N
2426	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2426	\N	\N	\N
2427	VICPDT	1998-10-01 00:00:00	2008-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	2427	8	\N	\N
2429	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2429	\N	\N	\N
2431	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	2431	\N	\N	\N
2432	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2432	\N	\N	\N
2433	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2433	\N	\N	\N
2434	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2434	\N	\N	\N
2436	SECRET	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2436	12	\N	\N
2437	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2437	\N	\N	\N
2438	MEMBRE	1998-10-01 00:00:00	2004-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	2438	\N	\N	\N
2439	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2439	\N	\N	\N
2441	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2441	\N	\N	\N
2442	PDTDEL	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	Liberia	\N	2442	10	\N	\N
2443	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2443	\N	\N	\N
2444	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2444	\N	\N	\N
2446	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2446	\N	\N	\N
2447	SECRET	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2447	14	\N	\N
2448	MEMBREBUR	1998-10-01 00:00:00	2002-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	2448	11	\N	\N
2449	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2449	\N	\N	\N
2451	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2451	\N	\N	\N
2453	MEMBRE	1998-10-01 00:00:00	2004-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	2453	\N	\N	\N
2454	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2454	\N	\N	\N
2456	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2456	\N	\N	\N
2457	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2457	\N	\N	\N
2459	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2459	\N	\N	\N
2460	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2460	\N	\N	\N
2463	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2463	\N	\N	\N
2464	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2464	\N	\N	\N
2465	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2465	\N	\N	\N
2467	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2467	\N	\N	\N
2469	MEMBRE	1998-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2469	\N	\N	\N
2364	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2364	\N	\N	\N
2365	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2365	\N	\N	\N
2366	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2366	\N	\N	\N
2367	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2367	\N	\N	\N
2263	MEMBRE	1998-09-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2263	\N	\N	\N
2264	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2264	\N	\N	\N
2265	VICPDT	1998-10-01 00:00:00	2005-03-07 00:00:00	ANCIEN	\N	\N	\N	\N	2265	5	\N	\N
2266	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2266	\N	\N	\N
2268	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2268	\N	\N	\N
2269	SECRET	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2269	7	\N	\N
2270	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2270	\N	\N	\N
2271	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2271	\N	\N	\N
2273	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2273	\N	\N	\N
2274	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2274	4	\N	\N
2275	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2275	\N	\N	\N
2276	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2276	\N	\N	\N
2279	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2279	\N	\N	\N
2280	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2280	\N	\N	\N
2281	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2281	\N	\N	\N
2282	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2282	\N	\N	\N
2284	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2284	\N	\N	\N
2285	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2285	\N	\N	\N
2287	SECRET	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2287	7	\N	\N
2291	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2291	\N	\N	\N
2292	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2292	\N	\N	\N
2293	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2293	\N	\N	\N
2294	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2294	\N	\N	\N
1141	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1141	\N	\N	\N
1143	MEMBRE	1998-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	1143	\N	\N	\N
1144	MEMBRE	1998-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	1144	\N	\N	\N
1145	MEMBRE	1998-10-01 00:00:00	2003-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	1145	\N	\N	\N
1146	MEMBRE	1998-10-01 00:00:00	2003-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	1146	\N	\N	\N
1148	MEMBRE	1999-01-01 00:00:00	2003-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	1148	\N	\N	\N
1149	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1149	\N	\N	\N
1150	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1150	\N	\N	\N
1151	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1151	\N	\N	\N
1153	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1153	\N	\N	\N
1154	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1154	\N	\N	\N
1155	MEMBREBUR	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1155	13	\N	\N
1156	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1156	\N	\N	\N
1158	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1158	\N	\N	\N
1159	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1159	\N	\N	\N
1160	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1160	\N	\N	\N
1161	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1161	6	\N	\N
1164	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1164	\N	\N	\N
1165	MEMBREBUR	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1165	14	\N	\N
1167	SECRET	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1167	14	\N	\N
1168	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1168	13	\N	\N
1171	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1171	\N	\N	\N
1172	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1172	\N	\N	\N
1173	MEMBRE	1998-10-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	\N	1173	\N	\N	\N
1175	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1175	\N	\N	\N
1177	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1177	\N	\N	\N
1179	MEMBRE	1998-10-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	\N	1179	\N	\N	\N
1180	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1180	\N	\N	\N
1181	MEMBRE	1998-10-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	\N	1181	\N	\N	\N
1184	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1184	\N	\N	\N
1185	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1185	7	\N	\N
1187	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1187	\N	\N	\N
1188	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1188	\N	\N	\N
1082	VICPDT	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1082	5	\N	\N
1083	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1083	\N	\N	\N
1084	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1084	\N	\N	\N
1086	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1086	\N	\N	\N
1087	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1087	\N	\N	\N
981	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	981	\N	\N	\N
982	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	982	\N	\N	\N
984	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	984	\N	\N	\N
985	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	985	\N	\N	\N
986	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	986	\N	\N	\N
987	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	987	\N	\N	\N
989	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	989	\N	\N	\N
991	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	991	\N	\N	\N
992	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	992	\N	\N	\N
993	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	993	\N	\N	\N
995	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	995	15	\N	\N
996	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	996	\N	\N	\N
997	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	997	\N	\N	\N
998	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	998	\N	\N	\N
1000	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1000	\N	\N	\N
1001	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1001	\N	\N	\N
1002	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1002	\N	\N	\N
1003	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1003	\N	\N	\N
1006	MEMBREBUR	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1006	10	\N	\N
1007	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1007	\N	\N	\N
1008	VICPDT	1998-10-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	1008	6	\N	\N
1009	VICPDT	1998-10-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	1009	18	\N	\N
1011	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1011	\N	\N	\N
1012	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1012	\N	\N	\N
1013	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1013	\N	\N	\N
1016	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1016	\N	\N	\N
1017	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1017	\N	\N	\N
1018	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1018	\N	\N	\N
1019	VICPDT	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	1019	3	\N	\N
1021	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1021	2	\N	\N
1023	MEMBRE	1998-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	1023	\N	\N	\N
1024	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1024	\N	\N	\N
1026	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1026	\N	\N	\N
1027	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1027	\N	\N	\N
1028	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1028	\N	\N	\N
1029	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1029	\N	\N	\N
1031	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1031	\N	\N	\N
1032	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1032	\N	\N	\N
1033	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1033	\N	\N	\N
1034	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1034	\N	\N	\N
1037	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1037	\N	\N	\N
1038	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1038	\N	\N	\N
1040	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1040	\N	\N	\N
1042	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1042	\N	\N	\N
1043	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1043	\N	\N	\N
1044	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1044	\N	\N	\N
1045	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1045	\N	\N	\N
1047	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1047	\N	\N	\N
1048	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1048	\N	\N	\N
1049	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	1049	\N	\N	\N
1050	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1050	\N	\N	\N
1052	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1052	\N	\N	\N
1053	MEMBREBUR	1999-01-01 00:00:00	2004-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	1053	21	\N	\N
1054	SECRET	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1054	\N	\N	\N
1055	MEMBRE	1998-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	1055	\N	\N	\N
1057	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1057	16	\N	\N
1058	MEMBRE	1999-01-01 00:00:00	2004-11-15 00:00:00	ANCIEN	\N	\N	\N	\N	1058	\N	\N	\N
1060	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	1060	\N	\N	\N
1061	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1061	\N	\N	\N
1064	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1064	\N	\N	\N
1596	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1596	\N	\N	\N
1597	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1597	\N	\N	\N
1598	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1598	\N	\N	\N
1599	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1599	\N	\N	\N
1601	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1601	\N	\N	\N
1602	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1602	\N	\N	\N
1603	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1603	\N	\N	\N
1604	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1604	\N	\N	\N
1607	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1607	\N	\N	\N
1608	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1608	\N	\N	\N
1609	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1609	\N	\N	\N
1610	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1610	\N	\N	\N
1612	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1612	\N	\N	\N
1509	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1509	\N	\N	\N
1510	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1510	\N	\N	\N
1511	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1511	\N	\N	\N
1512	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1512	\N	\N	\N
1514	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1514	\N	\N	\N
1408	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1408	\N	\N	\N
1409	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1409	\N	\N	\N
1410	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1410	\N	\N	\N
1412	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1412	\N	\N	\N
1413	SECRET	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1413	12	\N	\N
1414	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1414	\N	\N	\N
1417	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1417	\N	\N	\N
1418	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1418	\N	\N	\N
1419	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1419	\N	\N	\N
1420	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1420	\N	\N	\N
1422	SECRET	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1422	9	\N	\N
1423	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1423	\N	\N	\N
1424	MEMBRE	1999-01-01 00:00:00	2004-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	1424	\N	\N	\N
1425	SECRET	1999-01-01 00:00:00	2008-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	1425	7	\N	\N
1427	VICPDT	1998-10-01 00:00:00	2004-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	1427	5	\N	\N
1065	MEMBRE	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	1065	\N	\N	\N
1066	VICPDT	1998-10-01 00:00:00	2001-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	1066	7	\N	\N
1068	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1068	\N	\N	\N
1071	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	1071	\N	\N	\N
1073	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1073	\N	\N	\N
1074	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1074	\N	\N	\N
1079	SECRET	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1079	10	\N	\N
1080	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1080	\N	\N	\N
976	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	976	\N	\N	\N
977	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	977	\N	\N	\N
978	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	978	\N	\N	\N
979	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	979	\N	\N	\N
980	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	980	\N	\N	\N
874	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	874	\N	\N	\N
875	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	875	\N	\N	\N
877	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	877	13	\N	\N
878	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	878	\N	\N	\N
879	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	879	\N	\N	\N
880	PDTDEL	1998-10-01 00:00:00	2009-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	880	4	\N	\N
882	PDTDEL	1999-01-01 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	Laos	\N	882	2	\N	\N
883	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	883	\N	\N	\N
884	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	884	\N	\N	\N
885	SECRET	1998-10-01 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	885	\N	\N	\N
887	PDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	887	1	\N	\N
889	VICPDT	1998-10-01 00:00:00	2008-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	889	6	\N	\N
893	MEMBRE	1998-10-01 00:00:00	2004-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	893	\N	\N	\N
894	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	894	\N	\N	\N
895	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	895	\N	\N	\N
896	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	896	\N	\N	\N
899	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	899	\N	\N	\N
900	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	900	\N	\N	\N
901	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	901	\N	\N	\N
902	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	902	\N	\N	\N
904	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	904	\N	\N	\N
905	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	905	\N	\N	\N
906	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	906	\N	\N	\N
907	SECRET	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	907	12	\N	\N
910	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	910	\N	\N	\N
911	PDTDEL	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	Indonésie	\N	911	4	\N	\N
912	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	912	\N	\N	\N
913	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	913	\N	\N	\N
915	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	915	\N	\N	\N
916	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	916	\N	\N	\N
917	MEMBRE	1998-10-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	\N	917	\N	\N	\N
1679	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1679	\N	\N	\N
1681	SECRET	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1681	16	\N	\N
1683	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1683	\N	\N	\N
1684	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1684	\N	\N	\N
1685	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1685	\N	\N	\N
1687	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1687	\N	\N	\N
1689	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1689	\N	\N	\N
1690	MEMBRE	1998-10-01 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	1690	\N	\N	\N
1691	MEMBRE	1998-10-01 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	1691	\N	\N	\N
1694	MEMBRE	1999-01-01 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	1694	\N	\N	\N
1695	MEMBRE	1999-01-01 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	1695	\N	\N	\N
1697	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1697	\N	\N	\N
1698	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1698	\N	\N	\N
1701	PDT	1999-01-01 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	1701	1	\N	\N
1703	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1703	\N	\N	\N
1704	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1704	3	\N	\N
1706	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1706	\N	\N	\N
1708	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1708	\N	\N	\N
1710	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1710	7	\N	\N
1711	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1711	\N	\N	\N
1712	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1712	\N	\N	\N
1715	SECRET	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1715	7	\N	\N
1716	MEMBRE	1999-01-01 00:00:00	2002-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	1716	\N	\N	\N
1718	VICPDT	1999-01-01 00:00:00	2002-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	1718	4	\N	\N
1719	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1719	\N	\N	\N
1614	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1614	\N	\N	\N
1615	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1615	\N	\N	\N
1617	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1617	\N	\N	\N
1619	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1619	\N	\N	\N
1515	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1515	\N	\N	\N
1516	SECRET	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1516	9	\N	\N
1517	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1517	\N	\N	\N
1519	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1519	\N	\N	\N
1520	MEMBRE	1998-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	1520	\N	\N	\N
1521	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1521	\N	\N	\N
1522	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1522	\N	\N	\N
1525	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1525	\N	\N	\N
1526	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1526	\N	\N	\N
1527	PDTDEL	1999-01-01 00:00:00	2009-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	1527	\N	\N	\N
1530	VICPDT	1998-10-01 00:00:00	2004-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	1530	19	\N	\N
1531	VICPDT	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1531	4	\N	\N
1532	SECRET	1998-10-01 00:00:00	2004-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	1532	10	\N	\N
1533	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1533	\N	\N	\N
1536	SECRET	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1536	7	\N	\N
1537	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1537	\N	\N	\N
1538	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1538	\N	\N	\N
1540	VICPDT	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1540	3	\N	\N
1541	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1541	\N	\N	\N
1542	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1542	\N	\N	\N
1543	SECRET	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1543	7	\N	\N
1545	PDT	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1545	1	\N	\N
1546	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1546	3	\N	\N
1547	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1547	\N	\N	\N
1548	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1548	\N	\N	\N
1550	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1550	\N	\N	\N
1551	SECRET	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	1551	18	\N	\N
1552	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1552	\N	\N	\N
1553	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1553	\N	\N	\N
1556	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1556	\N	\N	\N
1557	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1557	11	\N	\N
1558	VICPDT	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1558	2	\N	\N
1560	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1560	\N	\N	\N
1561	SECRET	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1561	13	\N	\N
1562	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1562	\N	\N	\N
1563	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1563	\N	\N	\N
1566	VICPDT	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1566	4	\N	\N
1567	TRESOR	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1567	16	\N	\N
1568	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1568	4	\N	\N
1570	MEMBREBUR	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1570	11	\N	\N
1574	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1574	\N	\N	\N
1575	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1575	\N	\N	\N
1576	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1576	\N	\N	\N
1577	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1577	\N	\N	\N
1579	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1579	\N	\N	\N
1580	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1580	\N	\N	\N
1581	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1581	\N	\N	\N
1582	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1582	\N	\N	\N
1584	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1584	\N	\N	\N
1585	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1585	\N	\N	\N
1586	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1586	\N	\N	\N
1587	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1587	\N	\N	\N
1588	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1588	\N	\N	\N
1590	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1590	\N	\N	\N
1592	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1592	\N	\N	\N
1593	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1593	\N	\N	\N
1594	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1594	\N	\N	\N
2218	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2218	\N	\N	\N
2219	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2219	\N	\N	\N
2221	MEMBRE	1998-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	2221	\N	\N	\N
2222	MEMBRE	1998-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2222	\N	\N	\N
2224	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2224	\N	\N	\N
2225	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2225	\N	\N	\N
2226	PDT	1999-01-01 00:00:00	2004-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	2226	1	\N	\N
2227	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2227	\N	\N	\N
2229	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2229	\N	\N	\N
2230	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2230	\N	\N	\N
2231	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2231	\N	\N	\N
2232	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2232	\N	\N	\N
2234	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2234	\N	\N	\N
2235	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2235	\N	\N	\N
2236	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2236	\N	\N	\N
2237	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2237	\N	\N	\N
2240	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2240	\N	\N	\N
2241	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2241	\N	\N	\N
2242	PDT	1999-01-01 00:00:00	2009-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	2242	1	\N	\N
2244	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2244	\N	\N	\N
2246	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2246	\N	\N	\N
2248	MEMBRE	1999-01-01 00:00:00	2005-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	2248	\N	\N	\N
2249	PDTDEL	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Géorgie	\N	2249	3	\N	\N
2250	MEMBRE	1999-01-01 00:00:00	2004-11-15 00:00:00	ANCIEN	\N	\N	\N	\N	2250	\N	\N	\N
2253	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2253	\N	\N	\N
2254	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2254	\N	\N	\N
2149	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2149	\N	\N	\N
2150	MEMBRE	1998-10-01 00:00:00	1999-12-05 00:00:00	ANCIEN	\N	\N	\N	\N	2150	\N	\N	\N
2151	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2151	\N	\N	\N
2153	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2153	\N	\N	\N
2154	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2154	\N	\N	\N
2048	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2048	\N	\N	\N
2049	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2049	\N	\N	\N
2051	PDTDEL	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	Zimbabwe	\N	2051	7	\N	\N
2053	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2053	\N	\N	\N
2054	SECRET	1999-01-01 00:00:00	2004-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	2054	8	\N	\N
2055	PDT	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2055	1	\N	\N
2057	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2057	7	\N	\N
2058	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2058	\N	\N	\N
2059	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2059	\N	\N	\N
2060	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2060	\N	\N	\N
2062	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2062	\N	\N	\N
2063	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2063	\N	\N	\N
2064	MEMBRE	1998-09-30 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2064	\N	\N	\N
2065	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2065	\N	\N	\N
2067	VICPDT	1998-10-01 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	2067	\N	\N	\N
2069	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2069	\N	\N	\N
2070	SECRET	1998-10-01 00:00:00	2004-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	2070	10	\N	\N
2073	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2073	\N	\N	\N
2074	PDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2074	1	\N	\N
2075	TRESOR	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2075	13	\N	\N
1357	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1357	\N	\N	\N
1358	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1358	\N	\N	\N
1361	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1361	\N	\N	\N
1362	MEMBRE	1998-10-01 00:00:00	2008-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	1362	\N	\N	\N
1363	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1363	\N	\N	\N
1365	SECRET	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1365	12	\N	\N
1366	MEMBRE	1998-10-01 00:00:00	2004-10-26 00:00:00	ANCIEN	\N	\N	\N	\N	1366	\N	\N	\N
1368	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1368	\N	\N	\N
1369	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1369	\N	\N	\N
1371	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1371	\N	\N	\N
1372	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1372	\N	\N	\N
1373	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1373	\N	\N	\N
1374	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1374	\N	\N	\N
1377	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1377	\N	\N	\N
1378	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1378	\N	\N	\N
1379	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1379	\N	\N	\N
1380	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1380	\N	\N	\N
1382	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1382	\N	\N	\N
1383	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1383	\N	\N	\N
1385	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1385	\N	\N	\N
1386	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1386	\N	\N	\N
1388	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1388	\N	\N	\N
1389	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1389	\N	\N	\N
1390	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1390	\N	\N	\N
1391	MEMBRE	1998-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	1391	\N	\N	\N
1393	MEMBRE	1999-01-01 00:00:00	2008-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	1393	0	\N	\N
1394	MEMBRE	1998-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	1394	\N	\N	\N
1395	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1395	\N	\N	\N
1398	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1398	\N	\N	\N
1399	MEMBRE	1998-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	1399	\N	\N	\N
1400	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1400	\N	\N	\N
1296	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1296	\N	\N	\N
1297	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1297	3	\N	\N
1298	SECRET	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1298	8	\N	\N
1300	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1300	\N	\N	\N
1301	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1301	\N	\N	\N
1195	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1195	\N	\N	\N
1196	SECRET	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1196	18	\N	\N
1198	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1198	\N	\N	\N
1199	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1199	\N	\N	\N
1200	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1200	\N	\N	\N
1201	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1201	\N	\N	\N
1203	PDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1203	1	\N	\N
1204	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1204	\N	\N	\N
1205	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1205	\N	\N	\N
1207	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1207	\N	\N	\N
1209	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1209	\N	\N	\N
1210	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1210	\N	\N	\N
1211	PDTDEL	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	Niger	\N	1211	13	\N	\N
1212	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1212	\N	\N	\N
1214	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1214	\N	\N	\N
1215	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1215	\N	\N	\N
1216	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1216	\N	\N	\N
1217	PDT	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1217	1	\N	\N
1219	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1219	\N	\N	\N
1220	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	1220	\N	\N	\N
1221	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1221	\N	\N	\N
1222	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1222	\N	\N	\N
1224	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1224	\N	\N	\N
1226	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1226	\N	\N	\N
1227	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1227	\N	\N	\N
1228	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1228	\N	\N	\N
1230	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1230	\N	\N	\N
1231	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1231	\N	\N	\N
1232	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1232	\N	\N	\N
1233	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1233	\N	\N	\N
1235	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1235	\N	\N	\N
1236	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1236	\N	\N	\N
1237	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1237	\N	\N	\N
1238	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1238	\N	\N	\N
1240	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1240	\N	\N	\N
1241	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1241	\N	\N	\N
1243	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1243	\N	\N	\N
1245	MEMBRE	1998-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	1245	\N	\N	\N
1246	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1246	\N	\N	\N
1247	PDT	1998-10-01 00:00:00	2004-11-09 00:00:00	ANCIEN	\N	\N	\N	\N	1247	1	\N	\N
1248	PDTDEL	1998-10-01 00:00:00	2009-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	1248	17	\N	\N
1250	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1250	\N	\N	\N
1251	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1251	\N	\N	\N
1252	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1252	\N	\N	\N
1253	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1253	\N	\N	\N
1255	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1255	\N	\N	\N
1256	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1256	\N	\N	\N
1257	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1257	\N	\N	\N
1258	VICPDT	1998-10-01 00:00:00	2004-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	1258	4	\N	\N
1260	SECRET	1998-10-01 00:00:00	2004-11-09 00:00:00	ANCIEN	\N	\N	\N	\N	1260	19	\N	\N
1262	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1262	\N	\N	\N
1263	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1263	\N	\N	\N
1264	VICPDT	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1264	14	\N	\N
1267	VICPDT	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1267	3	\N	\N
1268	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1268	\N	\N	\N
1269	VICPDT	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1269	7	\N	\N
1271	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1271	\N	\N	\N
1272	VICPDT	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1272	10	\N	\N
1274	VICPDT	1999-01-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	1274	\N	\N	\N
1275	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1275	\N	\N	\N
1280	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1280	\N	\N	\N
1281	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1281	\N	\N	\N
1282	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1282	\N	\N	\N
1284	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1284	\N	\N	\N
1286	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1286	\N	\N	\N
1289	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1289	\N	\N	\N
1290	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1290	2	\N	\N
1293	SECRET	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1293	21	\N	\N
1294	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1294	\N	\N	\N
1189	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1189	\N	\N	\N
1191	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1191	\N	\N	\N
1192	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1192	\N	\N	\N
1193	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1193	\N	\N	\N
1194	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1194	\N	\N	\N
1089	MEMBRE	1998-09-30 00:00:00	1992-09-26 00:00:00	ANCIEN	\N	\N	\N	\N	1089	\N	\N	\N
1090	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1090	\N	\N	\N
1091	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1091	\N	\N	\N
1092	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1092	\N	\N	\N
1095	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1095	\N	\N	\N
1096	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1096	\N	\N	\N
1097	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1097	6	\N	\N
1098	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1098	\N	\N	\N
1100	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1100	\N	\N	\N
1101	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1101	\N	\N	\N
1103	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1103	\N	\N	\N
1104	VICPDT	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1104	5	\N	\N
1106	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1106	\N	\N	\N
1108	MEMBRE	1998-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	1108	\N	\N	\N
1109	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1109	\N	\N	\N
1111	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1111	\N	\N	\N
1113	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1113	\N	\N	\N
1114	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1114	\N	\N	\N
1117	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1117	\N	\N	\N
1118	SECRET	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1118	12	\N	\N
1119	MEMBRE	1998-10-01 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	1119	\N	\N	\N
1120	MEMBRE	1999-01-01 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	1120	\N	\N	\N
1122	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1122	\N	\N	\N
1123	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1123	\N	\N	\N
1124	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1124	\N	\N	\N
1125	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1125	\N	\N	\N
1127	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1127	\N	\N	\N
1128	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1128	\N	\N	\N
1129	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1129	\N	\N	\N
1130	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1130	\N	\N	\N
1133	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1133	\N	\N	\N
1134	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1134	\N	\N	\N
1135	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1135	\N	\N	\N
1136	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1136	\N	\N	\N
1139	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1139	2	\N	\N
1140	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1140	\N	\N	\N
922	MEMBRE	1998-10-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	\N	922	\N	\N	\N
923	MEMBRE	1999-01-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	\N	923	\N	\N	\N
924	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	924	\N	\N	\N
926	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	926	\N	\N	\N
928	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	928	\N	\N	\N
930	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	930	\N	\N	\N
931	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	931	\N	\N	\N
3627	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	3699	\N	\N	\N
3628	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3700	\N	\N	\N
3629	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	3701	\N	\N	\N
3630	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3702	\N	\N	\N
3631	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3703	\N	\N	\N
3632	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3704	16	\N	\N
3633	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3705	\N	\N	\N
3634	SECRET	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3706	18	\N	\N
3635	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3707	\N	\N	\N
3638	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3710	\N	\N	\N
3639	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3711	\N	\N	\N
3640	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3712	\N	\N	\N
3641	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3713	\N	\N	\N
3642	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3714	\N	\N	\N
3643	MEMBRE	1999-01-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	\N	3715	\N	\N	\N
3646	MEMBRE	1999-01-01 00:00:00	2005-04-11 00:00:00	ANCIEN	\N	\N	\N	\N	3718	\N	\N	\N
3647	VICPDTDRT	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Afrique de l'Ouest	\N	3719	4	\N	\N
3648	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3720	\N	\N	\N
3649	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3721	\N	\N	\N
3650	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3722	\N	\N	\N
3651	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3723	\N	\N	\N
3652	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3724	\N	\N	\N
3653	TRESOR	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3725	10	\N	\N
3654	PDTDEL	1999-01-01 00:00:00	2001-10-23 00:00:00	ANCIEN	\N	\N	Kenya	\N	3726	4	\N	\N
3655	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3727	\N	\N	\N
3657	MEMBRE	1999-01-01 00:00:00	2009-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	3729	\N	\N	\N
3659	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3732	\N	\N	\N
3661	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3734	\N	\N	\N
3662	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3735	\N	\N	\N
3664	MEMBRE	1999-01-01 00:00:00	2000-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	3737	\N	\N	\N
3666	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3739	\N	\N	\N
3668	PDTDEL	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	Mozambique	\N	3741	9	\N	\N
3670	VICPDT	1999-01-01 00:00:00	2005-04-11 00:00:00	ANCIEN	\N	\N	\N	\N	3743	14	\N	\N
3671	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3744	\N	\N	\N
3672	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3745	\N	\N	\N
3674	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3747	\N	\N	\N
3675	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3749	2	\N	\N
3676	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3750	3	\N	\N
3677	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3751	\N	\N	\N
3679	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3753	4	\N	\N
3680	VICPDT	1999-01-01 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	3754	2	\N	\N
3684	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3760	\N	\N	\N
3683	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3759	\N	\N	\N
3686	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3762	6	\N	\N
3688	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3764	\N	\N	\N
3689	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3765	\N	\N	\N
3690	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3766	\N	\N	\N
3692	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	3768	\N	\N	\N
3693	PDT	1999-01-01 00:00:00	2004-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	3769	1	\N	\N
3694	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3770	\N	\N	\N
3697	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3773	\N	\N	\N
3698	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3774	\N	\N	\N
3702	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3778	\N	\N	\N
3703	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3779	\N	\N	\N
3706	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3782	\N	\N	\N
3707	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3783	\N	\N	\N
3708	MEMBRE	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3784	\N	\N	\N
3709	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3785	\N	\N	\N
3710	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3786	\N	\N	\N
3712	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	3788	\N	\N	\N
3713	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	3789	\N	\N	\N
3715	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3791	\N	\N	\N
3716	MEMBRE	1999-01-01 00:00:00	1992-09-26 00:00:00	ANCIEN	\N	\N	\N	\N	3792	\N	\N	\N
3717	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3793	\N	\N	\N
3719	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3795	\N	\N	\N
3720	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3796	\N	\N	\N
3721	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3797	3	\N	\N
3722	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	3798	\N	\N	\N
3723	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3799	\N	\N	\N
3724	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3800	9	\N	\N
3727	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3803	10	\N	\N
3728	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3804	11	\N	\N
3729	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3805	4	\N	\N
3730	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	3806	\N	\N	\N
3731	MEMBRE	1999-01-01 00:00:00	1999-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3807	\N	\N	\N
3732	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3808	\N	\N	\N
3733	MEMBRE	1999-01-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	3809	\N	\N	\N
3734	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3810	\N	\N	\N
3735	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3811	\N	\N	\N
3736	MEMBRE	1999-01-01 00:00:00	2001-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	3812	\N	\N	\N
3737	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3813	\N	\N	\N
3738	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	3814	\N	\N	\N
3741	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3817	\N	\N	\N
3742	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3818	5	\N	\N
3743	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3819	\N	\N	\N
3744	VICPDT	1999-01-01 00:00:00	2004-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	3820	2	\N	\N
3745	MEMBRE	1999-01-01 00:00:00	2001-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	3821	\N	\N	\N
3746	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3822	\N	\N	\N
3747	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3823	\N	\N	\N
840	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	840	\N	\N	\N
841	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	841	\N	\N	\N
842	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	842	\N	\N	\N
844	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	844	\N	\N	\N
847	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	847	\N	\N	\N
848	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	848	\N	\N	\N
849	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	849	\N	\N	\N
853	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	853	\N	\N	\N
854	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	854	\N	\N	\N
856	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	856	\N	\N	\N
860	SECRET	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	860	11	\N	\N
861	TRESOR	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	861	15	\N	\N
862	SECRET	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	862	14	\N	\N
865	PDTDEL	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	Thaïlande	\N	865	7	\N	\N
867	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	867	2	\N	\N
761	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	761	\N	\N	\N
762	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	762	\N	\N	\N
764	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	764	\N	\N	\N
765	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	765	\N	\N	\N
766	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	766	\N	\N	\N
661	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	661	\N	\N	\N
665	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	665	\N	\N	\N
666	VICPDT	1998-10-01 00:00:00	2004-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	666	6	\N	\N
667	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	667	\N	\N	\N
670	VICPDT	1998-10-01 00:00:00	2004-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	670	5	\N	\N
671	VICPDT	1999-01-01 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	671	3	\N	\N
672	VICPDT	1998-10-01 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	672	3	\N	\N
673	VICPDT	1999-01-01 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	673	8	\N	\N
675	MEMBRE	0098-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	675	\N	\N	\N
676	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	676	\N	\N	\N
677	PDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	677	1	\N	\N
678	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	678	\N	\N	\N
680	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	680	\N	\N	\N
681	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	681	\N	\N	\N
682	PDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	682	1	\N	\N
683	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	683	\N	\N	\N
686	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	686	\N	\N	\N
687	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	687	\N	\N	\N
688	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	688	\N	\N	\N
689	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	689	\N	\N	\N
692	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	692	\N	\N	\N
693	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	693	\N	\N	\N
694	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	694	\N	\N	\N
695	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	695	\N	\N	\N
697	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	697	\N	\N	\N
698	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	698	\N	\N	\N
699	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	699	\N	\N	\N
700	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	700	\N	\N	\N
702	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	702	\N	\N	\N
703	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	703	\N	\N	\N
704	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	704	\N	\N	\N
705	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	705	\N	\N	\N
707	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	707	\N	\N	\N
708	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	708	6	\N	\N
709	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	709	\N	\N	\N
710	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	710	\N	\N	\N
712	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	712	\N	\N	\N
713	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	713	\N	\N	\N
714	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	714	\N	\N	\N
715	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	715	\N	\N	\N
717	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	717	\N	\N	\N
718	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	718	\N	\N	\N
720	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	720	\N	\N	\N
722	PDT	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	722	1	\N	\N
723	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	723	\N	\N	\N
724	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	724	\N	\N	\N
726	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	726	\N	\N	\N
729	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	729	\N	\N	\N
730	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	730	\N	\N	\N
731	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	731	\N	\N	\N
732	MEMBRE	1998-10-01 00:00:00	2001-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	732	\N	\N	\N
734	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	734	\N	\N	\N
735	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	735	\N	\N	\N
736	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	736	\N	\N	\N
737	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	737	\N	\N	\N
739	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	739	\N	\N	\N
740	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	740	\N	\N	\N
741	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	741	\N	\N	\N
742	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	742	\N	\N	\N
744	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	744	\N	\N	\N
745	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	745	\N	\N	\N
746	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	746	\N	\N	\N
748	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	748	\N	\N	\N
750	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	750	\N	\N	\N
752	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	752	11	\N	\N
753	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	753	2	\N	\N
754	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	754	\N	\N	\N
757	SECRET	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	757	10	\N	\N
758	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	758	\N	\N	\N
760	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	760	\N	\N	\N
655	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	655	\N	\N	\N
656	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	656	\N	\N	\N
658	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	658	\N	\N	\N
659	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	659	\N	\N	\N
660	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	660	\N	\N	\N
554	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	554	\N	\N	\N
556	SECRET	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	556	12	\N	\N
557	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	557	\N	\N	\N
558	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	558	5	\N	\N
559	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	559	\N	\N	\N
561	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	561	\N	\N	\N
562	VICPDT	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	562	8	\N	\N
564	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	564	\N	\N	\N
566	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	566	\N	\N	\N
568	PDTDEL	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	Sierra Leone	\N	568	16	\N	\N
569	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	569	\N	\N	\N
570	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	570	\N	\N	\N
571	VICPDT	1999-01-01 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	571	3	\N	\N
573	MEMBRE	1998-10-01 00:00:00	2004-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	573	\N	\N	\N
574	VICPDT	1999-01-01 00:00:00	2004-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	574	5	\N	\N
575	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	575	\N	\N	\N
576	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	576	\N	\N	\N
579	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	579	4	\N	\N
580	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	580	\N	\N	\N
581	MEMBREBUR	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	581	5	\N	\N
582	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	582	\N	\N	\N
585	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	585	\N	\N	\N
586	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	586	\N	\N	\N
587	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	587	\N	\N	\N
588	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	588	\N	\N	\N
590	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	590	\N	\N	\N
591	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	591	\N	\N	\N
592	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	592	\N	\N	\N
593	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	593	\N	\N	\N
595	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	595	\N	\N	\N
596	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	596	\N	\N	\N
597	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	597	\N	\N	\N
598	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	598	\N	\N	\N
599	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	599	\N	\N	\N
601	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	601	\N	\N	\N
603	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	603	\N	\N	\N
604	PDTDEL	2004-11-30 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	Guinée-Bissau	\N	604	9	\N	\N
606	MEMBRE	1999-01-01 00:00:00	2004-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	606	\N	\N	\N
607	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	607	\N	\N	\N
608	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	608	\N	\N	\N
609	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	609	\N	\N	\N
612	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	612	\N	\N	\N
613	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	613	\N	\N	\N
614	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	614	\N	\N	\N
615	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	615	\N	\N	\N
617	VICPDT	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	617	6	\N	\N
619	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	619	\N	\N	\N
621	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	621	\N	\N	\N
623	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	623	\N	\N	\N
624	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	624	\N	\N	\N
626	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	626	\N	\N	\N
627	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	627	\N	\N	\N
629	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	629	\N	\N	\N
630	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	630	\N	\N	\N
631	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	631	\N	\N	\N
632	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	632	\N	\N	\N
634	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	634	\N	\N	\N
635	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	635	\N	\N	\N
636	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	636	\N	\N	\N
637	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	637	\N	\N	\N
3344	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3407	5	\N	\N
3345	TRESORADJ	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3408	7	\N	\N
3347	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3410	\N	\N	\N
3348	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3411	\N	\N	\N
3349	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3412	\N	\N	\N
3351	MEMBRE	1999-01-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	\N	3414	\N	\N	\N
3355	MEMBRE	1999-01-01 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	3418	\N	\N	\N
3356	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3419	\N	\N	\N
3359	MEMBRE	1999-01-01 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	3422	\N	\N	\N
3361	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3424	\N	\N	\N
3363	MEMBRE	1999-01-01 00:00:00	2000-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	3426	\N	\N	\N
3364	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3427	10	\N	\N
3365	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3428	8	\N	\N
3369	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3433	\N	\N	\N
3370	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3434	\N	\N	\N
3372	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3436	\N	\N	\N
3373	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3437	\N	\N	\N
3374	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	3438	\N	\N	\N
3376	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3440	6	\N	\N
3377	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3441	\N	\N	\N
3378	MEMBRE	1999-01-01 00:00:00	2008-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	3442	\N	\N	\N
3380	MEMBRE	1999-01-01 00:00:00	2004-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	3444	\N	\N	\N
3381	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3445	12	\N	\N
3385	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3449	\N	\N	\N
3386	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3450	13	\N	\N
3387	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3451	\N	\N	\N
3389	PDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3453	1	\N	\N
3391	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3455	\N	\N	\N
3394	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3458	14	\N	\N
3395	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3459	\N	\N	\N
3397	MEMBRE	1999-01-01 00:00:00	2001-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	3461	\N	\N	\N
3398	TRESOR	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3462	17	\N	\N
3399	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3463	\N	\N	\N
3400	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3464	\N	\N	\N
3402	VICPDTDRT	1999-01-01 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	3466	5	\N	\N
3403	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3467	\N	\N	\N
3404	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3468	\N	\N	\N
3407	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3471	\N	\N	\N
3408	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3472	15	\N	\N
1459	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1459	\N	\N	\N
1464	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1464	\N	\N	\N
1470	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1470	\N	\N	\N
1475	PDT	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1475	2	\N	\N
1480	MEMBRE	1999-01-01 00:00:00	2002-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	1480	\N	\N	\N
1486	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1486	\N	\N	\N
1494	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1494	\N	\N	\N
1501	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1501	\N	\N	\N
1507	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1507	\N	\N	\N
1308	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1308	\N	\N	\N
1313	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1313	\N	\N	\N
1319	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1319	\N	\N	\N
1324	MEMBRE	1998-10-01 00:00:00	2001-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	1324	\N	\N	\N
1330	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1330	\N	\N	\N
1337	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1337	\N	\N	\N
1342	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1342	\N	\N	\N
1349	MEMBRE	1998-10-01 00:00:00	2000-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	1349	\N	\N	\N
1354	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1354	\N	\N	\N
1359	MEMBRE	1998-10-01 00:00:00	2000-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	1359	\N	\N	\N
1364	TRESOR	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1364	15	\N	\N
1370	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1370	\N	\N	\N
1375	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1375	\N	\N	\N
1381	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1381	\N	\N	\N
1387	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1387	\N	\N	\N
1392	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1392	\N	\N	\N
1397	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1397	\N	\N	\N
1299	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1299	7	\N	\N
1197	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1197	12	\N	\N
1202	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1202	\N	\N	\N
1208	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1208	\N	\N	\N
1213	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1213	\N	\N	\N
1218	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1218	\N	\N	\N
1223	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1223	\N	\N	\N
1229	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1229	\N	\N	\N
1234	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1234	\N	\N	\N
1239	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1239	\N	\N	\N
1244	VICPDT	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1244	8	\N	\N
1249	VICPDT	1998-10-01 00:00:00	2009-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	1249	9	\N	\N
1254	MEMBRE	1998-10-01 00:00:00	2004-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	1254	\N	\N	\N
1259	MEMBRE	1998-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	1259	\N	\N	\N
1265	VICPDT	1999-01-01 00:00:00	2009-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	1265	5	\N	\N
1270	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1270	9	\N	\N
1278	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1278	\N	\N	\N
1285	MEMBREBUR	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1285	11	\N	\N
1292	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1292	\N	\N	\N
1190	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1190	\N	\N	\N
1088	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1088	\N	\N	\N
1093	SECRET	1998-10-01 00:00:00	2005-03-07 00:00:00	ANCIEN	\N	\N	\N	\N	1093	11	\N	\N
1099	TRESOR	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1099	9	\N	\N
1105	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1105	\N	\N	\N
1110	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1110	\N	\N	\N
1116	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1116	\N	\N	\N
1121	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1121	\N	\N	\N
1126	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1126	\N	\N	\N
296	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	296	\N	\N	\N
298	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	298	\N	\N	\N
299	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	299	\N	\N	\N
300	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	300	\N	\N	\N
301	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	301	\N	\N	\N
303	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	303	\N	\N	\N
304	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	304	\N	\N	\N
305	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	305	\N	\N	\N
306	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	306	\N	\N	\N
308	MEMBRE	1998-10-01 00:00:00	1999-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	308	\N	\N	\N
309	MEMBRE	1998-10-01 00:00:00	1999-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	309	\N	\N	\N
310	MEMBRE	1998-10-01 00:00:00	1999-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	310	\N	\N	\N
795	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	795	\N	\N	\N
797	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	797	\N	\N	\N
798	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	798	\N	\N	\N
799	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	799	\N	\N	\N
800	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	800	\N	\N	\N
802	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	802	\N	\N	\N
803	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	803	\N	\N	\N
804	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	804	\N	\N	\N
805	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	805	\N	\N	\N
807	MEMBRE	1998-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	807	\N	\N	\N
808	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	808	\N	\N	\N
809	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	809	\N	\N	\N
810	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	810	\N	\N	\N
812	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	812	\N	\N	\N
813	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	813	\N	\N	\N
814	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	814	\N	\N	\N
815	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	815	\N	\N	\N
817	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	817	\N	\N	\N
818	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	818	\N	\N	\N
819	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	819	\N	\N	\N
821	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	821	\N	\N	\N
825	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	825	\N	\N	\N
826	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	826	\N	\N	\N
827	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	827	\N	\N	\N
828	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	828	6	\N	\N
830	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	830	\N	\N	\N
831	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	831	\N	\N	\N
832	SECRET	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	832	10	\N	\N
833	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	833	\N	\N	\N
835	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	835	\N	\N	\N
836	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	836	\N	\N	\N
837	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	837	\N	\N	\N
838	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	838	\N	\N	\N
374	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	374	\N	\N	\N
375	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	375	\N	\N	\N
377	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	377	\N	\N	\N
378	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	378	\N	\N	\N
379	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	379	\N	\N	\N
380	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	380	\N	\N	\N
382	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	382	\N	\N	\N
383	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	383	\N	\N	\N
384	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	384	\N	\N	\N
385	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	385	\N	\N	\N
388	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	388	\N	\N	\N
389	SECRET	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	389	8	\N	\N
390	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	390	\N	\N	\N
391	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	391	\N	\N	\N
393	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	393	\N	\N	\N
394	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	394	\N	\N	\N
395	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	395	\N	\N	\N
396	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	396	\N	\N	\N
398	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	398	\N	\N	\N
401	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	401	\N	\N	\N
402	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	402	\N	\N	\N
403	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	403	\N	\N	\N
405	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	405	\N	\N	\N
407	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	407	\N	\N	\N
409	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	409	\N	\N	\N
410	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	410	\N	\N	\N
412	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	412	\N	\N	\N
413	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	413	\N	\N	\N
414	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	414	\N	\N	\N
415	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	415	\N	\N	\N
417	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	417	\N	\N	\N
418	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	418	\N	\N	\N
419	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	419	\N	\N	\N
422	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	422	\N	\N	\N
424	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	424	\N	\N	\N
425	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	425	\N	\N	\N
426	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	426	\N	\N	\N
427	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	427	\N	\N	\N
429	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	429	\N	\N	\N
430	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	430	\N	\N	\N
431	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	431	\N	\N	\N
432	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	432	\N	\N	\N
434	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	434	\N	\N	\N
435	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	435	\N	\N	\N
436	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	436	\N	\N	\N
437	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	437	\N	\N	\N
438	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	438	\N	\N	\N
440	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	440	\N	\N	\N
441	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	441	\N	\N	\N
442	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	442	\N	\N	\N
443	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	443	\N	\N	\N
445	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	445	\N	\N	\N
446	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	446	\N	\N	\N
448	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	448	\N	\N	\N
3126	SECRET	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3169	10	\N	\N
3127	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3170	\N	\N	\N
3128	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3171	\N	\N	\N
3132	SECRET	1999-01-01 00:00:00	2001-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	3175	7	\N	\N
3133	MEMBRE	1999-01-01 00:00:00	2001-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	3176	\N	\N	\N
3134	PDT	1999-01-01 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	3177	1	\N	\N
3135	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3178	\N	\N	\N
3136	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3179	\N	\N	\N
3137	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	3180	\N	\N	\N
3138	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3181	\N	\N	\N
3139	MEMBRE	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3182	\N	\N	\N
3140	SECRET	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3183	9	\N	\N
3142	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	3185	\N	\N	\N
3145	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3188	\N	\N	\N
3146	MEMBRE	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3189	\N	\N	\N
3147	MEMBRE	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3190	\N	\N	\N
3148	MEMBRE	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3191	\N	\N	\N
3150	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3193	\N	\N	\N
3151	MEMBRE	1999-01-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	3194	\N	\N	\N
3152	MEMBRE	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3195	\N	\N	\N
3154	MEMBRE	1999-01-01 00:00:00	2005-03-07 00:00:00	ANCIEN	\N	\N	\N	\N	3197	\N	\N	\N
3156	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3199	\N	\N	\N
3158	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3201	\N	\N	\N
3159	PDTDEL	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	Lettonie	\N	3202	2	\N	\N
3160	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3203	\N	\N	\N
3162	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3205	\N	\N	\N
3164	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3207	5	\N	\N
3167	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3211	\N	\N	\N
3168	PDTDEL	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	Lituanie	\N	3212	4	\N	\N
3169	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3213	\N	\N	\N
3171	MEMBRE	1999-01-01 00:00:00	2009-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	3215	0	\N	\N
3172	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3216	\N	\N	\N
3175	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3225	\N	\N	\N
3176	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3226	8	\N	\N
3178	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3228	\N	\N	\N
3180	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3230	\N	\N	\N
3181	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3231	\N	\N	\N
3182	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3232	\N	\N	\N
3184	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3234	\N	\N	\N
3185	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3235	\N	\N	\N
3186	MEMBRE	1999-01-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	3236	\N	\N	\N
3188	MEMBRE	1999-01-01 00:00:00	2000-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	3238	\N	\N	\N
3189	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3239	7	\N	\N
3190	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3240	\N	\N	\N
3194	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3247	\N	\N	\N
3196	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3249	\N	\N	\N
3198	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3252	\N	\N	\N
3199	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3253	\N	\N	\N
3200	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3254	\N	\N	\N
3203	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3257	\N	\N	\N
3204	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3258	\N	\N	\N
3206	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3260	\N	\N	\N
3207	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3261	\N	\N	\N
3208	MEMBRE	1999-01-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	\N	3262	\N	\N	\N
3209	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3263	\N	\N	\N
3211	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3265	\N	\N	\N
3212	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3266	\N	\N	\N
3215	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3270	\N	\N	\N
3216	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3271	\N	\N	\N
3217	PDT	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3272	1	\N	\N
3219	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3274	\N	\N	\N
3220	SECRET	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	3275	10	\N	\N
3221	TRESOR	1999-01-01 00:00:00	2004-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	3276	7	\N	\N
3223	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	3278	\N	\N	\N
3224	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3279	\N	\N	\N
3225	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3280	\N	\N	\N
3228	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3283	\N	\N	\N
3229	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3285	\N	\N	\N
3232	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3290	\N	\N	\N
3233	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3291	\N	\N	\N
3234	SECRET	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	3292	7	\N	\N
3236	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3294	2	\N	\N
3237	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3296	\N	\N	\N
3238	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3297	\N	\N	\N
3239	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3298	\N	\N	\N
3241	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3300	\N	\N	\N
3242	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3301	\N	\N	\N
3245	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3304	\N	\N	\N
3246	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3305	\N	\N	\N
3247	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3306	\N	\N	\N
3249	VICPDT	1999-01-01 00:00:00	2001-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	3308	5	\N	\N
3250	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	3309	\N	\N	\N
3251	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3310	\N	\N	\N
3253	PDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3312	1	\N	\N
3255	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3314	\N	\N	\N
3257	MEMBRE	1999-01-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	3316	\N	\N	\N
3259	MEMBRE	1999-01-01 00:00:00	2000-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	3318	\N	\N	\N
3260	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3319	\N	\N	\N
3262	MEMBREBUR	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3321	10	\N	\N
3263	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3322	\N	\N	\N
3264	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3323	\N	\N	\N
3266	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3325	\N	\N	\N
3267	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3326	\N	\N	\N
3268	MEMBRE	1999-01-01 00:00:00	2001-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	3327	\N	\N	\N
3270	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3329	10	\N	\N
3271	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3330	\N	\N	\N
3274	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3333	\N	\N	\N
3275	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3334	\N	\N	\N
3276	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3335	\N	\N	\N
3281	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3342	\N	\N	\N
3283	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3344	\N	\N	\N
3284	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3345	\N	\N	\N
3285	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3346	6	\N	\N
3287	MEMBREBUR	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3348	21	\N	\N
3288	SECRET	1999-01-01 00:00:00	2004-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	3349	15	\N	\N
3289	MEMBRE	1999-01-01 00:00:00	2004-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	3350	\N	\N	\N
3290	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3351	\N	\N	\N
3293	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3354	\N	\N	\N
3294	MEMBRE	1999-01-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	\N	3355	\N	\N	\N
3296	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3357	\N	\N	\N
3297	VICPDT	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3358	8	\N	\N
3298	MEMBREBUR	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3359	24	\N	\N
3300	MEMBRE	1999-01-01 00:00:00	2011-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	3361	\N	\N	\N
3301	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3362	\N	\N	\N
3302	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3363	\N	\N	\N
3304	MEMBRE	1999-01-01 00:00:00	2004-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	3365	\N	\N	\N
3305	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3366	\N	\N	\N
3306	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3367	\N	\N	\N
3309	PDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3370	1	\N	\N
3311	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3372	\N	\N	\N
3313	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3374	\N	\N	\N
3315	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3376	\N	\N	\N
3317	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3378	5	\N	\N
3318	MEMBRE	1999-01-01 00:00:00	2001-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	3379	\N	\N	\N
3319	PDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3380	1	\N	\N
3322	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3383	\N	\N	\N
3323	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3384	\N	\N	\N
3324	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3385	4	\N	\N
3326	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	3387	\N	\N	\N
3327	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3388	\N	\N	\N
3328	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3389	6	\N	\N
3330	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3391	\N	\N	\N
3332	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3394	\N	\N	\N
3334	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3396	3	\N	\N
3335	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3397	\N	\N	\N
3336	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3398	\N	\N	\N
3337	PDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3399	1	\N	\N
3339	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3402	\N	\N	\N
3343	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3406	8	\N	\N
2889	MEMBRE	1999-01-01 00:00:00	2002-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	2923	\N	\N	\N
2893	MEMBRE	1999-01-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	\N	2927	\N	\N	\N
2898	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2932	\N	\N	\N
2902	MEMBRE	1999-01-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	2936	\N	\N	\N
2906	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2941	\N	\N	\N
2910	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2945	4	\N	\N
2757	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2781	\N	\N	\N
2762	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2787	\N	\N	\N
2766	MEMBRE	1999-01-01 00:00:00	2001-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	2791	\N	\N	\N
2775	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2800	\N	\N	\N
2779	PDTDEL	1999-01-01 00:00:00	2004-11-08 00:00:00	ANCIEN	\N	\N	République démocratique du Congo	\N	2805	9	\N	\N
2783	MEMBREBUR	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2809	9	\N	\N
2787	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2813	3	\N	\N
2792	SECRET	1999-01-01 00:00:00	2001-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	2818	12	\N	\N
2796	MEMBRE	1999-01-01 00:00:00	2001-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	2824	\N	\N	\N
2800	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2828	\N	\N	\N
2621	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2634	3	\N	\N
2625	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2638	8	\N	\N
2630	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2643	\N	\N	\N
2638	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2651	\N	\N	\N
2642	MEMBRE	1999-01-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	2655	\N	\N	\N
2647	MEMBRE	1999-01-01 00:00:00	2001-10-30 00:00:00	ANCIEN	\N	\N	\N	\N	2660	\N	\N	\N
2651	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2664	\N	\N	\N
2655	PDTDEL	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	Namibie	\N	2668	8	\N	\N
2660	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2673	\N	\N	\N
2664	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2677	\N	\N	\N
2668	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2681	\N	\N	\N
2672	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2685	\N	\N	\N
2677	MEMBRE	1999-01-01 00:00:00	2000-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	2690	\N	\N	\N
2685	VICPDT	1999-01-01 00:00:00	2003-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	2703	3	\N	\N
2690	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2708	6	\N	\N
2694	VICPDT	1999-01-01 00:00:00	2003-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	2712	5	\N	\N
2698	MEMBRE	1999-01-01 00:00:00	1999-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2718	\N	\N	\N
2572	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2572	\N	\N	\N
2577	VICPDT	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2577	2	\N	\N
2581	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2581	\N	\N	\N
2476	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2476	\N	\N	\N
2481	SECRET	1998-10-01 00:00:00	2004-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	2481	9	\N	\N
2486	MEMBRE	1998-10-01 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	2486	\N	\N	\N
2491	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2491	\N	\N	\N
2496	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2496	\N	\N	\N
2501	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2501	\N	\N	\N
2506	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2506	\N	\N	\N
2511	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2511	\N	\N	\N
2516	PDTDEL	1998-10-01 00:00:00	2004-11-29 00:00:00	ANCIEN	\N	\N	Guinée	\N	2516	8	\N	\N
2521	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2521	\N	\N	\N
2527	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2527	\N	\N	\N
2534	MEMBRE	1998-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	2534	\N	\N	\N
2541	SECRET	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2541	20	\N	\N
2547	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2547	\N	\N	\N
2554	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2554	\N	\N	\N
2561	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2561	\N	\N	\N
2567	MEMBRE	1998-10-01 00:00:00	2004-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	2567	\N	\N	\N
2470	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2470	\N	\N	\N
2475	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2475	\N	\N	\N
2374	MEMBREBUR	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2374	15	\N	\N
2379	VICPDT	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2379	8	\N	\N
2385	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2385	11	\N	\N
2390	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2390	\N	\N	\N
2396	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2396	\N	\N	\N
2401	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2401	\N	\N	\N
2407	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2407	\N	\N	\N
2412	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2412	\N	\N	\N
2419	MEMBRE	1998-10-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	2419	\N	\N	\N
2424	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2424	\N	\N	\N
2430	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2430	\N	\N	\N
2435	MEMBRE	1998-10-01 00:00:00	2004-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	2435	\N	\N	\N
2445	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2445	\N	\N	\N
2450	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2450	\N	\N	\N
2455	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2455	\N	\N	\N
2461	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2461	\N	\N	\N
2468	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2468	\N	\N	\N
2363	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2363	\N	\N	\N
2262	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	2262	\N	\N	\N
2267	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2267	\N	\N	\N
2272	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2272	\N	\N	\N
2278	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2278	\N	\N	\N
2283	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2283	\N	\N	\N
2289	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2289	\N	\N	\N
2295	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2295	\N	\N	\N
2301	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2301	\N	\N	\N
2306	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2306	\N	\N	\N
2311	MEMBRE	1998-10-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	2311	\N	\N	\N
2317	MEMBRE	1998-10-01 00:00:00	2005-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	2317	\N	\N	\N
2322	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2322	\N	\N	\N
2327	MEMBRE	1999-01-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	2327	\N	\N	\N
2332	MEMBRE	1999-01-01 00:00:00	1999-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	2332	\N	\N	\N
2337	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2337	\N	\N	\N
2343	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2343	\N	\N	\N
2348	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2348	\N	\N	\N
2354	MEMBREBUR	1999-01-01 00:00:00	2002-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	2354	20	\N	\N
2361	SECRET	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2361	13	\N	\N
2259	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2259	\N	\N	\N
2157	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2157	\N	\N	\N
2163	MEMBRE	1998-10-01 00:00:00	2001-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	2163	\N	\N	\N
2168	MEMBRE	1998-10-01 00:00:00	2001-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	2168	\N	\N	\N
2175	SECRET	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2175	28	\N	\N
2180	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2180	\N	\N	\N
2186	MEMBRE	1998-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	2186	\N	\N	\N
2191	MEMBRE	1998-10-01 00:00:00	2001-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	2191	\N	\N	\N
2196	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2196	\N	\N	\N
2202	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2202	\N	\N	\N
2207	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2207	\N	\N	\N
2212	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2212	\N	\N	\N
2217	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2217	\N	\N	\N
2223	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2223	\N	\N	\N
2233	SECRET	1998-10-01 00:00:00	2004-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	2233	8	\N	\N
2238	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2238	\N	\N	\N
2245	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2245	\N	\N	\N
2252	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2252	\N	\N	\N
2152	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2152	\N	\N	\N
2050	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2050	\N	\N	\N
2056	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2056	\N	\N	\N
2061	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2061	\N	\N	\N
202	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	202	\N	\N	\N
203	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	203	\N	\N	\N
204	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	204	\N	\N	\N
206	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	206	\N	\N	\N
207	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	207	\N	\N	\N
208	MEMBREBUR	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	208	20	\N	\N
210	PDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	210	1	\N	\N
212	MEMBRE	1998-10-01 00:00:00	2002-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	212	\N	\N	\N
213	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	213	\N	\N	\N
214	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	214	\N	\N	\N
215	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	215	\N	\N	\N
217	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	217	\N	\N	\N
219	PDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	219	1	\N	\N
220	PDTDEL	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	Malaisie	\N	220	2	\N	\N
221	MEMBRE	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	221	\N	\N	\N
223	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	223	5	\N	\N
224	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	224	\N	\N	\N
228	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	228	\N	\N	\N
229	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	229	\N	\N	\N
230	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	230	\N	\N	\N
231	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	231	\N	\N	\N
233	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	233	\N	\N	\N
234	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	234	\N	\N	\N
235	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	235	\N	\N	\N
236	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	236	\N	\N	\N
238	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	238	\N	\N	\N
239	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	239	\N	\N	\N
240	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	240	\N	\N	\N
243	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	243	\N	\N	\N
244	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	244	\N	\N	\N
245	PDT	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	245	1	\N	\N
246	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	246	\N	\N	\N
248	PDT	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	248	1	\N	\N
249	VICPDT	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	249	6	\N	\N
250	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	250	\N	\N	\N
251	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	251	\N	\N	\N
254	MEMBRE	1998-09-30 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	254	\N	\N	\N
255	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	255	\N	\N	\N
256	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	256	\N	\N	\N
257	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	257	\N	\N	\N
259	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	259	\N	\N	\N
261	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	261	\N	\N	\N
262	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	262	\N	\N	\N
263	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	263	\N	\N	\N
265	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	265	\N	\N	\N
267	PDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	267	1	\N	\N
268	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	268	\N	\N	\N
269	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	269	\N	\N	\N
271	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	271	\N	\N	\N
272	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	272	\N	\N	\N
273	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	273	\N	\N	\N
274	MEMBREBUR	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	274	14	\N	\N
276	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	276	\N	\N	\N
277	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	277	\N	\N	\N
278	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	278	\N	\N	\N
279	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	279	\N	\N	\N
281	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	281	\N	\N	\N
282	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	282	\N	\N	\N
285	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	285	\N	\N	\N
286	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	286	\N	\N	\N
288	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	288	\N	\N	\N
289	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	289	\N	\N	\N
290	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	290	\N	\N	\N
291	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	291	\N	\N	\N
293	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	293	\N	\N	\N
294	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	294	\N	\N	\N
1633	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1633	\N	\N	\N
1634	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1634	\N	\N	\N
1636	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1636	\N	\N	\N
1637	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1637	\N	\N	\N
1638	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1638	\N	\N	\N
1639	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1639	\N	\N	\N
1641	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1641	\N	\N	\N
1642	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1642	\N	\N	\N
1643	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1643	\N	\N	\N
1644	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	1644	\N	\N	\N
1646	MEMBRE	1998-10-01 00:00:00	2004-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	1646	\N	\N	\N
1647	VICPDT	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1647	5	\N	\N
1648	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1648	\N	\N	\N
1649	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1649	\N	\N	\N
1651	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1651	\N	\N	\N
1652	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1652	\N	\N	\N
1653	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1653	\N	\N	\N
1654	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1654	\N	\N	\N
1656	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1656	\N	\N	\N
1657	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1657	\N	\N	\N
1658	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1658	\N	\N	\N
1659	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1659	\N	\N	\N
1661	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1661	\N	\N	\N
1662	MEMBRE	1999-01-01 00:00:00	2004-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	1662	\N	\N	\N
1663	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1663	\N	\N	\N
1664	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1664	\N	\N	\N
1666	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1666	\N	\N	\N
1667	MEMBRE	1998-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	1667	\N	\N	\N
1668	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1668	\N	\N	\N
1669	MEMBRE	1998-09-30 00:00:00	2002-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	1669	\N	\N	\N
1671	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1671	\N	\N	\N
1672	MEMBRE	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	1672	\N	\N	\N
1673	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1673	\N	\N	\N
1674	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1674	\N	\N	\N
1676	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1676	\N	\N	\N
1677	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1677	\N	\N	\N
1678	MEMBRE	1998-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	1678	\N	\N	\N
918	MEMBRE	1998-10-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	\N	918	\N	\N	\N
921	MEMBRE	1999-01-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	\N	921	\N	\N	\N
3411	MEMBRE	1999-01-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	3475	\N	\N	\N
3412	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3476	\N	\N	\N
3415	MEMBRE	1999-01-01 00:00:00	2004-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	3479	\N	\N	\N
3416	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3480	16	\N	\N
3417	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3481	\N	\N	\N
3419	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3483	\N	\N	\N
3420	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3484	\N	\N	\N
3421	MEMBRE	1999-01-01 00:00:00	2004-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	3485	\N	\N	\N
3423	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3488	2	\N	\N
3425	MEMBRE	1999-01-01 00:00:00	2001-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	3491	\N	\N	\N
3429	MEMBRE	1999-01-01 00:00:00	2007-02-25 00:00:00	ANCIEN	\N	\N	\N	\N	3495	\N	\N	\N
3430	MEMBRE	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3496	\N	\N	\N
3432	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	3498	\N	\N	\N
3436	MEMBRE	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3502	\N	\N	\N
3438	MEMBRE	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3504	\N	\N	\N
3439	MEMBRE	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3505	\N	\N	\N
3442	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3508	\N	\N	\N
3443	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3510	7	\N	\N
3448	PDT	1999-01-01 00:00:00	2007-02-25 00:00:00	ANCIEN	\N	\N	\N	\N	3515	1	\N	\N
3449	MEMBRE	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3516	\N	\N	\N
3453	MEMBRE	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3520	\N	\N	\N
3455	PDTDEL	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	Emirats Arabes Unis	\N	3522	4	\N	\N
3456	PDTDEL	1999-01-01 00:00:00	2009-02-18 00:00:00	ANCIEN	\N	\N	Arabie saoudite	\N	3523	2	\N	\N
3458	MEMBRE	1999-01-01 00:00:00	2001-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	3525	\N	\N	\N
3461	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3528	\N	\N	\N
3462	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3529	\N	\N	\N
3468	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3536	\N	\N	\N
3469	VICPDT	1999-01-01 00:00:00	2001-10-23 00:00:00	ANCIEN	\N	\N	\N	\N	3537	3	\N	\N
3474	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3542	\N	\N	\N
3475	MEMBREBUR	1999-01-01 00:00:00	2004-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	3543	14	\N	\N
3476	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3544	\N	\N	\N
3479	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	3547	\N	\N	\N
3480	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3549	\N	\N	\N
3481	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3550	2	\N	\N
3484	VICPDT	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3553	3	\N	\N
3485	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3554	\N	\N	\N
3488	MEMBRE	1999-01-01 00:00:00	2007-02-25 00:00:00	ANCIEN	\N	\N	\N	\N	3558	\N	\N	\N
3489	SECRET	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3559	8	\N	\N
3490	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3560	4	\N	\N
3491	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3561	\N	\N	\N
3492	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3562	5	\N	\N
3494	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3564	\N	\N	\N
3495	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3565	\N	\N	\N
3496	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3566	\N	\N	\N
3497	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	3567	\N	\N	\N
3498	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3568	\N	\N	\N
3500	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3570	\N	\N	\N
3501	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3571	7	\N	\N
3502	VICPDT	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3572	3	\N	\N
3503	VICPDT	1999-01-01 00:00:00	2008-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	3573	2	\N	\N
3504	MEMBRE	1999-01-01 00:00:00	2004-11-15 00:00:00	ANCIEN	\N	\N	\N	\N	3574	\N	\N	\N
3506	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3576	5	\N	\N
3507	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3577	\N	\N	\N
3508	TRESOR	1999-01-01 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	3578	9	\N	\N
3509	PDT	1999-01-01 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	3579	1	\N	\N
3510	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3580	\N	\N	\N
3511	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3581	\N	\N	\N
3512	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3582	\N	\N	\N
3513	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3583	\N	\N	\N
3516	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3586	\N	\N	\N
3518	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3588	\N	\N	\N
3519	MEMBRE	1999-01-01 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	3589	\N	\N	\N
3520	MEMBRE	1999-01-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	3590	\N	\N	\N
3524	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3594	\N	\N	\N
3523	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3593	\N	\N	\N
3525	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3595	\N	\N	\N
3526	MEMBRE	1999-01-01 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	3596	\N	\N	\N
3527	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3597	\N	\N	\N
3528	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3598	\N	\N	\N
3530	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3600	\N	\N	\N
3531	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3601	\N	\N	\N
3533	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3603	\N	\N	\N
3534	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3604	\N	\N	\N
3535	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3605	\N	\N	\N
3536	MEMBRE	1999-01-01 00:00:00	2009-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	3606	\N	\N	\N
3537	PDTDEL	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	Islande	\N	3607	6	\N	\N
3539	VICPDT	1999-01-01 00:00:00	2009-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	3609	2	\N	\N
3541	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3611	\N	\N	\N
3542	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3612	\N	\N	\N
3544	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3614	\N	\N	\N
3545	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3615	\N	\N	\N
3547	MEMBRE	1999-01-01 00:00:00	2001-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	3617	\N	\N	\N
3549	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3619	\N	\N	\N
3550	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3620	\N	\N	\N
3551	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3621	\N	\N	\N
3553	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3623	\N	\N	\N
3554	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3624	\N	\N	\N
3555	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	3625	\N	\N	\N
3558	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3629	\N	\N	\N
3559	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3630	\N	\N	\N
3562	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3633	\N	\N	\N
3563	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3634	\N	\N	\N
3564	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3635	\N	\N	\N
3565	MEMBRE	1999-01-01 00:00:00	1999-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	3636	\N	\N	\N
3567	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3638	8	\N	\N
3568	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3639	\N	\N	\N
3569	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3640	\N	\N	\N
3571	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3642	\N	\N	\N
3748	MEMBRE	1999-01-01 00:00:00	2000-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	3824	\N	\N	\N
3749	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3825	7	\N	\N
3750	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3826	\N	\N	\N
3751	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3827	\N	\N	\N
3752	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3828	\N	\N	\N
3753	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3829	\N	\N	\N
3756	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3831	\N	\N	\N
3757	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	3832	\N	\N	\N
3758	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3833	\N	\N	\N
3759	MEMBRE	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3834	\N	\N	\N
3761	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3836	8	\N	\N
3762	MEMBRE	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3837	\N	\N	\N
3763	MEMBRE	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3838	\N	\N	\N
347	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	347	\N	\N	\N
349	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	349	\N	\N	\N
350	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	350	\N	\N	\N
351	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	351	\N	\N	\N
353	SECRET	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	353	14	\N	\N
355	VICPDT	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	355	6	\N	\N
356	VICPDT	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	356	2	\N	\N
357	VICPDT	1999-01-01 00:00:00	2001-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	357	5	\N	\N
358	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	358	4	\N	\N
360	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	360	\N	\N	\N
361	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	361	\N	\N	\N
362	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	362	\N	\N	\N
363	VICPDT	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	363	4	\N	\N
365	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	365	4	\N	\N
366	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	366	2	\N	\N
367	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	367	\N	\N	\N
368	VICPDT	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	368	4	\N	\N
372	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	372	\N	\N	\N
373	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	373	\N	\N	\N
3572	SECRET	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3643	10	\N	\N
3573	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3644	\N	\N	\N
3575	MEMBRE	1999-01-01 00:00:00	1999-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	3646	\N	\N	\N
3576	MEMBRE	1999-01-01 00:00:00	2004-11-24 00:00:00	ANCIEN	\N	\N	\N	\N	3647	\N	\N	\N
3577	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3648	\N	\N	\N
3578	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3649	\N	\N	\N
3580	VICPDT	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3651	5	\N	\N
3582	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3654	4	\N	\N
3584	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3656	\N	\N	\N
3586	MEMBRE	1999-01-01 00:00:00	2001-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	3658	\N	\N	\N
3588	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3660	\N	\N	\N
3589	VICPDT	1999-01-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	3661	2	\N	\N
3590	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3662	\N	\N	\N
3591	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3663	\N	\N	\N
3593	TRESOR	1999-01-01 00:00:00	2007-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	3665	18	\N	\N
3594	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3666	\N	\N	\N
3595	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3667	\N	\N	\N
3597	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3669	\N	\N	\N
3599	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3671	\N	\N	\N
3601	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3673	\N	\N	\N
3602	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3674	\N	\N	\N
3603	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3675	\N	\N	\N
3604	MEMBRE	1999-01-01 00:00:00	2009-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	3676	\N	\N	\N
3605	MEMBRE	1999-01-01 00:00:00	2010-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	3677	0	\N	\N
3606	MEMBRE	1999-01-01 00:00:00	2000-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	3678	\N	\N	\N
3607	MEMBRE	1999-01-01 00:00:00	2004-11-24 00:00:00	ANCIEN	\N	\N	\N	\N	3679	\N	\N	\N
3608	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3680	\N	\N	\N
3609	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3681	\N	\N	\N
3610	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3682	\N	\N	\N
3611	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3683	\N	\N	\N
3612	MEMBRE	1999-01-01 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	3684	\N	\N	\N
3613	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3685	\N	\N	\N
3614	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3686	\N	\N	\N
3615	SECRET	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	3687	12	\N	\N
3617	SECRET	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	3689	13	\N	\N
3618	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3690	18	\N	\N
3619	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3691	\N	\N	\N
3620	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3692	\N	\N	\N
3621	SECRET	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	3693	14	\N	\N
3623	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3695	11	\N	\N
3625	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3697	\N	\N	\N
4076	MEMBRE	2000-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4122	\N	\N	\N
4077	VICPDT	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4123	2	\N	\N
4078	MEMBRE	2000-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4124	\N	\N	\N
4079	MEMBRE	2000-11-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	4125	\N	\N	\N
4080	MEMBRE	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4126	\N	\N	\N
4081	VICPDT	2000-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4127	3	\N	\N
4083	MEMBRE	2000-11-01 00:00:00	2005-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	4129	\N	\N	\N
4084	VICPDT	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4130	4	\N	\N
4085	MEMBRE	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4131	\N	\N	\N
4086	MEMBRE	2000-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4132	\N	\N	\N
4087	MEMBRE	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4133	\N	\N	\N
4089	MEMBRE	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4135	\N	\N	\N
4090	MEMBRE	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4137	\N	\N	\N
4091	PDTDEL	2000-11-01 00:00:00	2005-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	4138	2	\N	\N
4092	MEMBRE	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4139	\N	\N	\N
4094	MEMBRE	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4141	\N	\N	\N
4095	VICPDT	2000-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4142	7	\N	\N
4096	MEMBRE	2000-10-20 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4143	\N	\N	\N
4097	MEMBRE	2000-11-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4144	\N	\N	\N
4098	MEMBRE	2000-11-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4145	\N	\N	\N
4100	MEMBRE	2000-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4147	\N	\N	\N
4101	MEMBRE	2000-11-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4148	\N	\N	\N
4102	MEMBRE	2000-11-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	4149	\N	\N	\N
4103	MEMBRE	2000-11-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4150	\N	\N	\N
4104	VICPDT	2000-11-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	4151	6	\N	\N
4105	MEMBRE	2000-11-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4152	\N	\N	\N
4106	MEMBRE	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4153	\N	\N	\N
4107	MEMBRE	2000-11-01 00:00:00	1992-09-26 00:00:00	ANCIEN	\N	\N	\N	\N	4154	\N	\N	\N
4108	MEMBRE	2000-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4156	\N	\N	\N
4109	MEMBRE	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4157	\N	\N	\N
4110	MEMBRE	2000-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4158	\N	\N	\N
4112	MEMBRE	2000-11-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4160	\N	\N	\N
4113	PDTDEL	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4161	2	\N	\N
4114	MEMBRE	2000-11-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4163	\N	\N	\N
4116	MEMBRE	2000-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4165	\N	\N	\N
4118	MEMBRE	2000-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4168	\N	\N	\N
4119	MEMBRE	2000-11-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4169	\N	\N	\N
4120	MEMBRE	2000-11-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4170	\N	\N	\N
4121	MEMBRE	2000-11-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4171	\N	\N	\N
4123	MEMBRE	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4173	\N	\N	\N
4124	MEMBRE	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4174	\N	\N	\N
4126	MEMBRE	2000-11-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4176	\N	\N	\N
4127	MEMBRE	2000-11-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4177	\N	\N	\N
4128	VICPDT	2000-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4178	7	\N	\N
4130	MEMBRE	2000-11-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4180	\N	\N	\N
4132	MEMBRE	2000-11-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	4182	\N	\N	\N
4133	MEMBRE	2000-11-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4183	\N	\N	\N
4135	MEMBRE	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4185	\N	\N	\N
4136	VICPDT	2000-11-01 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	4186	3	\N	\N
4137	PDT	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4187	1	\N	\N
919	MEMBRE	1998-10-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	\N	919	\N	\N	\N
925	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	925	\N	\N	\N
932	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	932	\N	\N	\N
937	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	937	14	\N	\N
942	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	942	\N	\N	\N
947	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	947	\N	\N	\N
953	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	953	\N	\N	\N
958	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	958	\N	\N	\N
966	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	966	\N	\N	\N
971	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	971	\N	\N	\N
868	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	868	9	\N	\N
873	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	873	\N	\N	\N
771	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	771	\N	\N	\N
776	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	776	\N	\N	\N
781	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	781	\N	\N	\N
786	VICPDT	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	786	20	\N	\N
791	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	791	\N	\N	\N
796	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	796	\N	\N	\N
801	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	801	\N	\N	\N
806	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	806	\N	\N	\N
811	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	811	\N	\N	\N
816	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	816	\N	\N	\N
822	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	822	\N	\N	\N
829	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	829	\N	\N	\N
834	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	834	\N	\N	\N
839	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	839	\N	\N	\N
845	VICPDT	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	845	4	\N	\N
852	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	852	\N	\N	\N
858	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	858	\N	\N	\N
866	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	866	\N	\N	\N
763	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	763	\N	\N	\N
664	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	664	\N	\N	\N
669	MEMBRE	1998-10-01 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	669	\N	\N	\N
674	VICPDTPRE	1999-01-01 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	674	3	\N	\N
679	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	679	\N	\N	\N
690	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	690	\N	\N	\N
696	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	696	\N	\N	\N
701	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	701	\N	\N	\N
706	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	706	\N	\N	\N
711	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	711	\N	\N	\N
716	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	716	\N	\N	\N
721	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	721	\N	\N	\N
728	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	728	\N	\N	\N
733	SECRET	1998-10-01 00:00:00	2001-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	733	10	\N	\N
738	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	738	\N	\N	\N
743	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	743	\N	\N	\N
749	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	749	\N	\N	\N
756	SECRET	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	756	8	\N	\N
657	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	657	\N	\N	\N
555	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	555	\N	\N	\N
560	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	560	\N	\N	\N
567	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	567	\N	\N	\N
572	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	572	\N	\N	\N
578	PDTHON	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	578	14	\N	\N
583	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	583	\N	\N	\N
589	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	589	\N	\N	\N
594	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	594	\N	\N	\N
600	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	600	\N	\N	\N
605	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	605	\N	\N	\N
610	MEMBRE	1998-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	610	\N	\N	\N
616	PDT	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	616	1	\N	\N
622	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	622	\N	\N	\N
628	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	628	\N	\N	\N
633	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	633	\N	\N	\N
638	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	638	\N	\N	\N
643	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	643	\N	\N	\N
648	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	648	\N	\N	\N
451	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	451	\N	\N	\N
458	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	458	\N	\N	\N
463	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	463	\N	\N	\N
470	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	470	\N	\N	\N
476	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	476	\N	\N	\N
486	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	486	\N	\N	\N
491	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	491	\N	\N	\N
497	MEMBRE	1998-10-01 00:00:00	2008-09-07 00:00:00	ANCIEN	\N	\N	\N	\N	497	\N	\N	\N
503	MEMBRE	1998-10-01 00:00:00	2009-09-09 00:00:00	ANCIEN	\N	\N	\N	\N	503	\N	\N	\N
509	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	509	\N	\N	\N
515	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	515	\N	\N	\N
520	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	520	\N	\N	\N
525	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	525	\N	\N	\N
530	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	530	\N	\N	\N
537	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	537	\N	\N	\N
542	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	542	\N	\N	\N
547	SECRET	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	547	13	\N	\N
113	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	113	\N	\N	\N
5	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5	\N	\N	\N
10	VICPDT	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10	6	\N	\N
14	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14	\N	\N	\N
20	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20	\N	\N	\N
26	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26	\N	\N	\N
31	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	31	\N	\N	\N
37	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	37	\N	\N	\N
42	PDT	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	42	1	\N	\N
46	PDT	1998-10-01 00:00:00	2004-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	46	1	\N	\N
51	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	51	\N	\N	\N
56	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	56	\N	\N	\N
61	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	61	\N	\N	\N
66	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	66	\N	\N	\N
71	SECRET	1998-10-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	71	21	\N	\N
75	VICPDT	1998-10-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	75	2	\N	\N
80	MEMBRE	1998-09-30 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	80	\N	\N	\N
86	SECRET	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	86	11	\N	\N
91	MEMBRE	1998-10-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	91	\N	\N	\N
98	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98	\N	\N	\N
107	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	107	\N	\N	\N
129	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	129	\N	\N	\N
134	MEMBRE	1998-10-01 00:00:00	2001-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	134	\N	\N	\N
139	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	139	\N	\N	\N
145	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	145	\N	\N	\N
151	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	151	\N	\N	\N
156	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	156	\N	\N	\N
161	MEMBRE	1999-01-01 00:00:00	2001-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	161	\N	\N	\N
166	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	166	\N	\N	\N
173	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	173	\N	\N	\N
179	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	179	\N	\N	\N
184	PDTDEL	1998-10-01 00:00:00	2009-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	184	15	\N	\N
189	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	189	\N	\N	\N
194	VICPDT	1998-10-01 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	194	\N	\N	\N
200	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	200	\N	\N	\N
205	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	205	\N	\N	\N
211	MEMBREBUR	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	211	9	\N	\N
216	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	216	\N	\N	\N
222	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	222	\N	\N	\N
227	VICPDT	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	227	3	\N	\N
232	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	232	\N	\N	\N
237	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	237	\N	\N	\N
242	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	242	\N	\N	\N
247	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	247	\N	\N	\N
252	VICPDTDRT	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Amérique du Sud	\N	252	3	\N	\N
258	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	258	\N	\N	\N
264	MEMBRE	1999-01-01 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	\N	264	\N	\N	\N
270	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	270	\N	\N	\N
275	VICPDT	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	275	3	\N	\N
280	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	280	\N	\N	\N
287	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	287	\N	\N	\N
292	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	292	\N	\N	\N
297	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	297	15	\N	\N
302	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	302	\N	\N	\N
307	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	307	\N	\N	\N
312	PDT	1998-10-01 00:00:00	2004-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	312	1	\N	\N
317	TRESORADJ	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	317	7	\N	\N
324	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	324	\N	\N	\N
331	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	331	\N	\N	\N
338	MEMBRE	1998-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	338	\N	\N	\N
348	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	348	\N	\N	\N
354	PDTDEL	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	Liberia	\N	354	10	\N	\N
359	VICPDT	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	359	2	\N	\N
364	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	364	7	\N	\N
370	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	370	\N	\N	\N
376	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	376	\N	\N	\N
381	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	381	\N	\N	\N
387	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	387	\N	\N	\N
392	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	392	\N	\N	\N
397	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	397	\N	\N	\N
404	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	404	\N	\N	\N
411	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	411	\N	\N	\N
416	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	416	\N	\N	\N
423	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	423	\N	\N	\N
428	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	428	\N	\N	\N
433	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	433	\N	\N	\N
439	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	439	\N	\N	\N
444	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	444	\N	\N	\N
3144	MEMBRE	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3187	\N	\N	\N
3149	MEMBRE	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3192	\N	\N	\N
3153	MEMBRE	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3196	\N	\N	\N
3161	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3204	\N	\N	\N
3166	MEMBRE	1999-01-01 00:00:00	2004-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	3210	\N	\N	\N
3170	MEMBRE	1999-01-01 00:00:00	2004-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	3214	\N	\N	\N
3174	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3224	\N	\N	\N
3179	PDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3229	1	\N	\N
3192	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3244	\N	\N	\N
3187	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3237	\N	\N	\N
3191	TRESOR	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3241	9	\N	\N
3197	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3251	\N	\N	\N
3205	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3259	\N	\N	\N
3210	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3264	\N	\N	\N
3214	MEMBRE	1999-01-01 00:00:00	2004-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	3268	\N	\N	\N
3218	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3273	\N	\N	\N
3222	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3277	4	\N	\N
3227	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3282	\N	\N	\N
3231	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3289	\N	\N	\N
3235	MEMBREBUR	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	3293	12	\N	\N
3240	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3299	\N	\N	\N
3243	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3302	\N	\N	\N
3248	MEMBREBUR	1999-01-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	\N	3307	\N	\N	\N
3252	MEMBREBUR	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3311	11	\N	\N
3256	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3315	4	\N	\N
3261	PDT	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3320	1	\N	\N
3265	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3324	2	\N	\N
3269	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3328	\N	\N	\N
3273	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3332	\N	\N	\N
3278	MEMBREBUR	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3339	18	\N	\N
3286	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3347	\N	\N	\N
3291	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3352	\N	\N	\N
3295	TRESOR	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3356	18	\N	\N
3299	MEMBRE	1999-01-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	3360	\N	\N	\N
3303	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3364	\N	\N	\N
3308	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3369	\N	\N	\N
3312	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3373	\N	\N	\N
3316	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3377	4	\N	\N
3321	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	3382	\N	\N	\N
3325	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3386	5	\N	\N
3329	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3390	\N	\N	\N
3333	MEMBRE	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	3395	\N	\N	\N
3342	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3405	\N	\N	\N
3352	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3415	\N	\N	\N
3358	MEMBRE	1999-01-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	3421	\N	\N	\N
3362	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3425	\N	\N	\N
3366	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3429	\N	\N	\N
3371	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3435	\N	\N	\N
3375	VICPDT	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	3439	6	\N	\N
3379	MEMBRE	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	3443	\N	\N	\N
3383	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3447	\N	\N	\N
3388	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3452	\N	\N	\N
3392	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3456	\N	\N	\N
3396	MEMBRE	1999-01-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	\N	3460	\N	\N	\N
3202	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3256	\N	\N	\N
2948	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2984	10	\N	\N
2593	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2593	\N	\N	\N
3538	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3608	\N	\N	\N
3050	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3091	\N	\N	\N
3410	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3474	10	\N	\N
3695	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3771	\N	\N	\N
3808	MEMBREBUR	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3885	9	\N	\N
2827	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2857	\N	\N	\N
3905	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3947	\N	\N	\N
2715	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2738	\N	\N	\N
158	MEMBRE	1999-01-01 00:00:00	2001-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	158	\N	\N	\N
4469	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4578	\N	\N	\N
4470	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4579	\N	\N	\N
4471	MEMBRE	2001-10-01 00:00:00	2004-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	4580	\N	\N	\N
4472	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4581	\N	\N	\N
4473	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4582	\N	\N	\N
4474	MEMBRE	2001-10-01 00:00:00	2004-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	4583	\N	\N	\N
4475	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4584	\N	\N	\N
4476	VICPDT	2001-10-01 00:00:00	2008-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	4585	19	\N	\N
4477	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4586	\N	\N	\N
4478	PDTDEL	2001-10-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	Mauritanie	\N	4587	12	\N	\N
4479	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4588	\N	\N	\N
4480	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4589	\N	\N	\N
4482	MEMBRE	2001-10-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	4591	\N	\N	\N
4483	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4592	\N	\N	\N
4484	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4593	29	\N	\N
4485	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4594	\N	\N	\N
4486	SECRET	2001-10-01 00:00:00	2009-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	4595	25	\N	\N
4487	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4596	\N	\N	\N
4488	MEMBRE	2001-10-01 00:00:00	2002-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4597	\N	\N	\N
4489	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4598	\N	\N	\N
4491	PDTDEL	2001-10-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	Gambie	\N	4600	6	\N	\N
4492	MEMBRE	2001-10-01 00:00:00	2004-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	4601	\N	\N	\N
4493	MEMBRE	2001-10-01 00:00:00	2004-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	4602	\N	\N	\N
4494	MEMBRE	2001-10-01 00:00:00	2004-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	4603	\N	\N	\N
4496	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4605	\N	\N	\N
4497	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4606	5	\N	\N
4499	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4609	\N	\N	\N
4500	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4610	\N	\N	\N
4501	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4611	\N	\N	\N
4502	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4612	\N	\N	\N
4503	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4613	\N	\N	\N
4504	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4614	\N	\N	\N
4505	MEMBRE	2001-10-01 00:00:00	2004-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	4615	\N	\N	\N
4507	MEMBRE	2001-10-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	4617	\N	\N	\N
4508	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4618	\N	\N	\N
4509	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4619	\N	\N	\N
4511	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4621	\N	\N	\N
4512	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4622	\N	\N	\N
4514	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4626	\N	\N	\N
4515	VICPDT	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4627	4	\N	\N
4517	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4629	\N	\N	\N
4518	MEMBRE	2001-10-01 00:00:00	2005-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	4630	\N	\N	\N
4519	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4631	\N	\N	\N
4520	VICPDT	2001-10-01 00:00:00	2005-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	4632	5	\N	\N
4521	VICPDT	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4633	5	\N	\N
4522	MEMBRE	2001-10-01 00:00:00	2005-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	4634	\N	\N	\N
4524	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4636	\N	\N	\N
4525	MEMBRE	2001-10-01 00:00:00	2008-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	4637	\N	\N	\N
4526	MEMBRE	2001-10-01 00:00:00	2004-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	4638	\N	\N	\N
4527	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4639	\N	\N	\N
4528	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4640	\N	\N	\N
4529	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4641	\N	\N	\N
4530	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4642	\N	\N	\N
4531	TRESORADJ	2001-10-01 00:00:00	2004-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	4643	12	\N	\N
4532	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4644	\N	\N	\N
4533	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4645	\N	\N	\N
4534	SECRET	2001-10-01 00:00:00	2004-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	4646	9	\N	\N
4535	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4647	\N	\N	\N
4536	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4649	\N	\N	\N
4538	MEMBRE	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4651	\N	\N	\N
4539	MEMBRE	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4652	\N	\N	\N
4540	MEMBRE	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4653	\N	\N	\N
4541	MEMBRE	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4654	\N	\N	\N
4542	MEMBRE	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4655	\N	\N	\N
4543	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4656	\N	\N	\N
4544	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4657	\N	\N	\N
4545	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4658	\N	\N	\N
4546	MEMBRE	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4659	\N	\N	\N
4548	MEMBRE	2001-10-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	4661	\N	\N	\N
4549	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4662	\N	\N	\N
4550	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4663	\N	\N	\N
4551	MEMBRE	2001-10-01 00:00:00	2004-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	4664	\N	\N	\N
4552	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4665	\N	\N	\N
4553	MEMBRE	2001-10-01 00:00:00	2004-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	4666	\N	\N	\N
4554	MEMBRE	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4667	\N	\N	\N
4556	MEMBRE	2001-10-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	4669	\N	\N	\N
4557	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4670	\N	\N	\N
4558	MEMBRE	2001-10-01 00:00:00	2008-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	4671	\N	\N	\N
4560	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4673	\N	\N	\N
4561	MEMBRE	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4674	\N	\N	\N
4562	MEMBREBUR	2001-10-01 00:00:00	2004-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	4675	13	\N	\N
4563	MEMBRE	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4676	\N	\N	\N
4567	VICPDT	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	354	18	\N	\N
4568	VICPDT	1998-10-01 00:00:00	2009-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	184	21	\N	\N
4569	VICPDT	1998-10-01 00:00:00	2004-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	880	22	\N	\N
4570	VICPDT	1998-10-01 00:00:00	2004-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	1248	24	\N	\N
4571	VICPDT	1998-10-01 00:00:00	2004-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	8	25	\N	\N
4572	VICPDT	2001-10-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	4587	26	\N	\N
4573	VICPDT	1998-10-01 00:00:00	2004-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	2023	27	\N	\N
4574	SECRET	1998-10-01 00:00:00	2004-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	2421	31	\N	\N
4576	MEMBREBUR	2001-10-24 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3537	8	\N	\N
3975	MEMBRE	1999-12-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4024	\N	\N	\N
3990	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4042	\N	\N	\N
3995	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4047	\N	\N	\N
4006	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4059	\N	\N	\N
4018	MEMBRE	1999-12-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4071	\N	\N	\N
4023	MEMBRE	2000-02-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	4075	\N	\N	\N
4029	MEMBRE	2000-02-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4081	\N	\N	\N
4039	MEMBRE	2000-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4091	\N	\N	\N
4044	MEMBRE	2000-03-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4095	\N	\N	\N
4125	MEMBRE	2000-11-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4175	\N	\N	\N
4129	MEMBRE	2000-11-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4179	\N	\N	\N
4134	MEMBRE	2000-11-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4184	\N	\N	\N
4140	MEMBRE	2000-11-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	\N	4190	\N	\N	\N
4145	MEMBRE	2000-11-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4195	\N	\N	\N
4151	SECRET	2000-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4202	8	\N	\N
4156	MEMBRE	2000-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4207	\N	\N	\N
4160	MEMBRE	2000-11-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4211	\N	\N	\N
4169	MEMBRE	2000-11-10 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4220	\N	\N	\N
4174	MEMBRE	2000-11-10 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4225	\N	\N	\N
4179	MEMBRE	2000-11-10 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4230	\N	\N	\N
4183	PDT	2000-11-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4234	1	\N	\N
4224	MEMBRE	1998-10-01 00:00:00	2004-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	4275	\N	\N	\N
4228	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4279	\N	\N	\N
4236	VICPDT	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4287	3	\N	\N
4241	MEMBRE	1998-10-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	4292	\N	\N	\N
4250	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4301	\N	\N	\N
4257	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4308	\N	\N	\N
4303	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4402	\N	\N	\N
4309	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4409	\N	\N	\N
4313	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4413	\N	\N	\N
4320	MEMBRE	2001-05-01 00:00:00	2005-03-07 00:00:00	ANCIEN	\N	\N	\N	\N	4421	\N	\N	\N
4325	MEMBRE	2001-05-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4427	\N	\N	\N
4332	MEMBRE	2001-05-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	4436	\N	\N	\N
4374	MEMBRE	2000-06-23 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4482	\N	\N	\N
4388	MEMBRE	2001-06-26 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4497	\N	\N	\N
4400	MEMBRE	2001-12-12 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4508	\N	\N	\N
4405	MEMBRE	2000-12-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4513	\N	\N	\N
4411	MEMBRE	2001-02-23 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4520	\N	\N	\N
4416	MEMBRE	2000-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4525	\N	\N	\N
4421	MEMBRE	2000-12-11 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4530	\N	\N	\N
4378	VICPDT	2000-06-20 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4486	7	\N	\N
4379	PDT	2000-06-06 00:00:00	2006-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	4488	1	\N	\N
4380	MEMBRE	2001-06-07 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4489	\N	\N	\N
4381	MEMBRE	2001-10-06 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4490	\N	\N	\N
4382	MEMBRE	2001-05-31 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4491	\N	\N	\N
4384	MEMBRE	2001-05-15 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4493	\N	\N	\N
2066	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2066	\N	\N	\N
2072	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2072	11	\N	\N
2077	PDTDEL	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	Danemark	\N	2077	4	\N	\N
2083	SECRET	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2083	8	\N	\N
2088	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2088	\N	\N	\N
2093	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2093	\N	\N	\N
2098	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2098	\N	\N	\N
2103	VICPDT	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2103	3	\N	\N
2110	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2110	\N	\N	\N
2120	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2120	\N	\N	\N
2126	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2126	\N	\N	\N
2131	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2131	\N	\N	\N
2138	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2138	\N	\N	\N
2145	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2145	\N	\N	\N
2045	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2045	\N	\N	\N
1943	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1943	\N	\N	\N
1948	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1948	\N	\N	\N
1953	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1953	\N	\N	\N
1959	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1959	\N	\N	\N
1964	PDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1964	1	\N	\N
1969	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1969	\N	\N	\N
1976	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1976	\N	\N	\N
1981	MEMBRE	1998-10-01 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	1981	0	\N	\N
1986	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1986	\N	\N	\N
1992	SECRET	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1992	7	\N	\N
1997	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1997	3	\N	\N
2003	VICPDT	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2003	2	\N	\N
2008	MEMBREBUR	1998-10-01 00:00:00	2004-11-09 00:00:00	ANCIEN	\N	\N	\N	\N	2008	9	\N	\N
2014	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	2014	\N	\N	\N
2019	MEMBRE	1999-01-01 00:00:00	2001-09-20 00:00:00	ANCIEN	\N	\N	\N	\N	2019	\N	\N	\N
2024	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2024	\N	\N	\N
2031	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2031	\N	\N	\N
2038	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2038	\N	\N	\N
1938	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1938	\N	\N	\N
1836	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1836	\N	\N	\N
1841	PDT	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1841	1	\N	\N
1846	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1846	4	\N	\N
1851	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1851	11	\N	\N
1856	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1856	\N	\N	\N
1862	MEMBRE	1998-10-01 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	1862	\N	\N	\N
1868	MEMBRE	1998-10-01 00:00:00	2007-02-25 00:00:00	ANCIEN	\N	\N	\N	\N	1868	\N	\N	\N
1873	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1873	\N	\N	\N
1878	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1878	\N	\N	\N
1885	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1885	\N	\N	\N
1891	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1891	\N	\N	\N
1896	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1896	\N	\N	\N
1902	SECRET	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1902	11	\N	\N
1907	TRESOR	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1907	8	\N	\N
1912	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1912	\N	\N	\N
1917	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1917	18	\N	\N
1922	SECRET	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1922	10	\N	\N
1929	VICPDT	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	1929	4	\N	\N
1727	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1727	\N	\N	\N
1732	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1732	\N	\N	\N
1739	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1739	\N	\N	\N
1745	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1745	\N	\N	\N
1750	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1750	\N	\N	\N
1755	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1755	\N	\N	\N
1760	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1760	\N	\N	\N
1767	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1767	\N	\N	\N
1772	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1772	10	\N	\N
1778	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1778	\N	\N	\N
1783	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1783	\N	\N	\N
1794	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1794	\N	\N	\N
1799	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1799	\N	\N	\N
1804	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1804	\N	\N	\N
1809	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1809	\N	\N	\N
1814	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1814	\N	\N	\N
1820	SECRET	1998-10-01 00:00:00	2005-03-07 00:00:00	ANCIEN	\N	\N	\N	\N	1820	9	\N	\N
1826	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1826	\N	\N	\N
1722	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1722	\N	\N	\N
1620	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1620	\N	\N	\N
1625	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1625	\N	\N	\N
1630	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1630	\N	\N	\N
1635	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1635	\N	\N	\N
1640	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1640	\N	\N	\N
1645	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1645	\N	\N	\N
1650	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1650	\N	\N	\N
1655	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1655	\N	\N	\N
1660	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1660	\N	\N	\N
1665	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1665	\N	\N	\N
1670	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	1670	\N	\N	\N
1675	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1675	\N	\N	\N
1680	MEMBRE	1998-10-01 00:00:00	2001-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	1680	\N	\N	\N
1686	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1686	\N	\N	\N
1693	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	1693	\N	\N	\N
1699	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1699	\N	\N	\N
1707	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1707	\N	\N	\N
1714	SECRET	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1714	10	\N	\N
1720	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1720	\N	\N	\N
1618	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1618	\N	\N	\N
1518	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1518	\N	\N	\N
1523	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	1523	\N	\N	\N
1529	MEMBRE	1998-10-01 00:00:00	2004-11-09 00:00:00	ANCIEN	\N	\N	\N	\N	1529	\N	\N	\N
1534	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1534	\N	\N	\N
1539	SECGEN	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1539	8	\N	\N
1544	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1544	\N	\N	\N
1549	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1549	\N	\N	\N
1559	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1559	9	\N	\N
1564	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1564	\N	\N	\N
1571	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1571	\N	\N	\N
1578	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1578	\N	\N	\N
1583	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1583	\N	\N	\N
1589	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1589	\N	\N	\N
1595	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1595	\N	\N	\N
1600	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1600	\N	\N	\N
1605	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1605	\N	\N	\N
1611	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1611	\N	\N	\N
1508	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1508	\N	\N	\N
1513	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1513	\N	\N	\N
1411	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1411	\N	\N	\N
1416	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1416	\N	\N	\N
1421	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1421	\N	\N	\N
1426	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1426	\N	\N	\N
1431	MEMBRE	1999-01-01 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	1431	\N	\N	\N
1437	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1437	\N	\N	\N
1442	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1442	\N	\N	\N
1448	MEMBRE	1999-01-01 00:00:00	2001-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	1448	\N	\N	\N
1453	SECRET	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1453	11	\N	\N
3424	VICPDT	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	3489	3	\N	\N
3428	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3494	\N	\N	\N
3431	MEMBRE	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3497	\N	\N	\N
3434	MEMBRE	1999-01-01 00:00:00	2004-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	3500	\N	\N	\N
3437	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3503	7	\N	\N
3444	PDTDEL	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	Bahreïn	\N	3511	3	\N	\N
3447	MEMBRE	1999-01-01 00:00:00	2001-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	3514	\N	\N	\N
3450	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3517	\N	\N	\N
3454	MEMBRE	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3521	\N	\N	\N
3457	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3524	\N	\N	\N
3464	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3531	\N	\N	\N
3467	MEMBRE	1999-01-01 00:00:00	2004-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	3535	\N	\N	\N
3470	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3538	\N	\N	\N
3477	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3545	\N	\N	\N
3077	MEMBREBUR	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3119	15	\N	\N
3082	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3125	\N	\N	\N
3090	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3133	\N	\N	\N
3094	VICPDT	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	3137	3	\N	\N
3099	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3142	5	\N	\N
3103	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3146	\N	\N	\N
3107	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3150	\N	\N	\N
3112	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3155	\N	\N	\N
3116	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3159	\N	\N	\N
3120	MEMBRE	1999-01-01 00:00:00	2004-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	3163	\N	\N	\N
3124	VICPDT	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3167	4	\N	\N
2969	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3005	\N	\N	\N
2974	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3011	\N	\N	\N
2978	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3016	\N	\N	\N
2986	MEMBREBUR	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3025	15	\N	\N
2991	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3031	\N	\N	\N
2995	MEMBRE	1999-01-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	3035	\N	\N	\N
2999	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3039	\N	\N	\N
3004	MEMBRE	1999-01-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	3044	\N	\N	\N
3008	MEMBRE	1999-01-01 00:00:00	2002-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	3048	\N	\N	\N
3012	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3052	\N	\N	\N
3016	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3056	\N	\N	\N
2863	SECRET	1999-01-01 00:00:00	2004-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	2896	10	\N	\N
2868	MEMBRE	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	2901	\N	\N	\N
2872	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2905	\N	\N	\N
2876	MEMBREBUR	1999-01-01 00:00:00	2004-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	2909	15	\N	\N
2880	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2913	\N	\N	\N
2885	MEMBREBUR	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2918	16	\N	\N
3405	MEMBRE	1999-01-01 00:00:00	2004-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	3469	\N	\N	\N
3409	VICPDT	1999-01-01 00:00:00	2004-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	3473	10	\N	\N
3413	MEMBRE	1999-01-01 00:00:00	2004-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	3477	\N	\N	\N
3418	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3482	11	\N	\N
3422	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3486	\N	\N	\N
3427	MEMBRE	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3493	\N	\N	\N
3440	MEMBRE	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3506	\N	\N	\N
3446	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3513	\N	\N	\N
3452	VICPDT	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3519	\N	\N	\N
3459	MEMBRE	1999-01-01 00:00:00	2005-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	3526	\N	\N	\N
3465	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3533	\N	\N	\N
3471	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3539	\N	\N	\N
3478	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3546	6	\N	\N
3482	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	3551	\N	\N	\N
3543	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3613	\N	\N	\N
3548	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3618	\N	\N	\N
3552	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3622	8	\N	\N
3556	MEMBRE	1999-01-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	3626	\N	\N	\N
3561	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3632	9	\N	\N
3566	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3637	\N	\N	\N
3570	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3641	\N	\N	\N
3574	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3645	\N	\N	\N
3579	MEMBRE	1999-01-01 00:00:00	2004-11-24 00:00:00	ANCIEN	\N	\N	\N	\N	3650	\N	\N	\N
3583	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3655	\N	\N	\N
3587	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3659	\N	\N	\N
3592	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3664	\N	\N	\N
3596	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3668	\N	\N	\N
3656	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3728	\N	\N	\N
3660	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3733	\N	\N	\N
3665	MEMBRE	1999-01-01 00:00:00	2001-09-20 00:00:00	ANCIEN	\N	\N	\N	\N	3738	\N	\N	\N
3673	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3746	\N	\N	\N
3678	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3752	\N	\N	\N
3687	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3763	7	\N	\N
3691	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3767	\N	\N	\N
3696	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3772	\N	\N	\N
3700	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3776	\N	\N	\N
3704	MEMBRE	1999-01-01 00:00:00	1999-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	3780	\N	\N	\N
3760	MEMBRE	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3835	\N	\N	\N
3768	MEMBRE	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3843	\N	\N	\N
3773	MEMBRE	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3848	\N	\N	\N
3777	MEMBRE	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3852	\N	\N	\N
3781	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3858	\N	\N	\N
3786	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3863	3	\N	\N
3790	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3867	4	\N	\N
3794	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3871	\N	\N	\N
3798	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3875	\N	\N	\N
3803	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3880	\N	\N	\N
3807	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3884	\N	\N	\N
3875	SECRET	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3917	12	\N	\N
3879	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3921	5	\N	\N
3883	MEMBRE	1999-01-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	3925	\N	\N	\N
3887	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3929	7	\N	\N
3892	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3934	\N	\N	\N
3896	VICPDT	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	3938	3	\N	\N
3900	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3942	\N	\N	\N
4069	MEMBRE	2000-05-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	4116	\N	\N	\N
4070	MEMBRE	2000-05-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4117	\N	\N	\N
4071	VICPDT	2000-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4118	3	\N	\N
4072	MEMBRE	2000-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4119	\N	\N	\N
4073	PDTDEL	1998-10-01 00:00:00	2009-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	1905	14	\N	\N
2421	PDTDEL	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Bénin	\N	2421	2	\N	\N
2509	PDTDEL	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Côte d'Ivoire	\N	2509	5	\N	\N
1743	PDTDEL	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	Turkménistan	\N	1743	5	\N	\N
620	PDTDEL	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	Zambie	\N	620	6	\N	\N
1415	SECRET	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1415	8	\N	\N
2288	MEMBREBUR	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2288	8	\N	\N
1555	VICPDT	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1555	3	\N	\N
1266	VICPDT	1999-01-01 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	1266	\N	\N	\N
4074	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4120	\N	\N	\N
3105	SECRET	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3148	11	\N	\N
3851	SECRET	1999-01-01 00:00:00	2002-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	2920	11	\N	\N
2901	MEMBREBUR	1999-01-01 00:00:00	2002-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	2935	19	\N	\N
668	MEMBREBUR	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	668	22	\N	\N
2009	TRESOR	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2009	24	\N	\N
226	VICPDT	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	226	2	\N	\N
3472	MEMBREBUR	1999-01-01 00:00:00	2001-10-23 00:00:00	ANCIEN	\N	\N	\N	\N	3540	10	\N	\N
3940	SECRET	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3985	9	\N	\N
3895	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3937	2	\N	\N
3725	TRESOR	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3801	13	\N	\N
2213	VICPDT	1998-10-01 00:00:00	2002-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	2213	4	\N	\N
2596	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2598	5	\N	\N
2956	VICPDT	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2992	3	\N	\N
3624	SECRET	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	3696	15	\N	\N
3390	VICPDT	1999-01-01 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	3454	10	\N	\N
81	VICPDT	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	81	3	\N	\N
3163	PDTDEL	1999-01-01 00:00:00	2008-09-24 00:00:00	ANCIEN	\N	\N	Estonie	\N	3206	4	\N	\N
3904	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3946	7	\N	\N
3909	SECRET	1999-01-01 00:00:00	2004-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	3951	9	\N	\N
3913	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3955	\N	\N	\N
3917	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3959	\N	\N	\N
3926	SECRET	1999-01-01 00:00:00	2001-12-11 00:00:00	ANCIEN	\N	\N	\N	\N	3969	9	\N	\N
1925	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1925	\N	\N	\N
1705	SECRET	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1705	9	\N	\N
1492	MEMBRE	1998-10-01 00:00:00	2004-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	1492	\N	\N	\N
1291	VICPDT	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1291	5	\N	\N
1182	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1182	\N	\N	\N
1081	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1081	\N	\N	\N
3942	MEMBRE	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3988	\N	\N	\N
3947	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	3995	\N	\N	\N
3948	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3996	\N	\N	\N
3946	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3994	\N	\N	\N
3951	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4000	2	\N	\N
3952	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4001	\N	\N	\N
3955	MEMBRE	1999-12-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4004	\N	\N	\N
3956	MEMBRE	1999-12-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4005	\N	\N	\N
3957	MEMBRE	1999-12-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4006	\N	\N	\N
3958	MEMBRE	1999-12-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4007	\N	\N	\N
3959	MEMBRE	1999-12-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4008	\N	\N	\N
3960	MEMBRE	1999-12-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4009	\N	\N	\N
3961	MEMBRE	1999-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4010	\N	\N	\N
3963	MEMBRE	1999-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4012	\N	\N	\N
3964	MEMBRE	1999-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4013	\N	\N	\N
3965	MEMBRE	1999-12-01 00:00:00	2001-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	4014	\N	\N	\N
3966	MEMBRE	1999-12-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4015	\N	\N	\N
3967	MEMBRE	1999-12-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4016	\N	\N	\N
3968	MEMBRE	1999-12-01 00:00:00	2009-09-09 00:00:00	ANCIEN	\N	\N	\N	\N	4017	\N	\N	\N
3969	MEMBRE	1999-12-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4018	\N	\N	\N
3970	MEMBRE	1999-12-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	4019	\N	\N	\N
3971	MEMBRE	1999-12-01 00:00:00	2009-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	4020	\N	\N	\N
3972	MEMBRE	1999-12-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4021	\N	\N	\N
3973	MEMBRE	1999-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4022	\N	\N	\N
3974	MEMBRE	1999-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4023	\N	\N	\N
3976	MEMBRE	1998-10-01 00:00:00	1999-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4026	\N	\N	\N
3977	SECRET	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	4028	9	\N	\N
3978	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4029	\N	\N	\N
3980	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4031	\N	\N	\N
3981	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4033	4	\N	\N
3982	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4034	\N	\N	\N
3983	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4035	11	\N	\N
3984	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4036	\N	\N	\N
3985	PDT	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4037	1	\N	\N
3986	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4038	\N	\N	\N
3987	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4039	\N	\N	\N
3988	SECRET	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4040	10	\N	\N
3989	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4041	7	\N	\N
3991	MEMBRE	1999-01-01 00:00:00	2001-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	4043	\N	\N	\N
3992	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4044	\N	\N	\N
3993	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4045	\N	\N	\N
3994	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4046	\N	\N	\N
3996	MEMBRE	1999-01-01 00:00:00	2000-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	4048	\N	\N	\N
3998	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4050	7	\N	\N
3999	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4051	\N	\N	\N
4000	TRESOR	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4052	8	\N	\N
4001	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4053	\N	\N	\N
4002	VICPDT	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	4054	4	\N	\N
4003	MEMBRE	1999-12-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4055	\N	\N	\N
4008	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4061	\N	\N	\N
4005	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4058	\N	\N	\N
4007	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4060	\N	\N	\N
4009	MEMBRE	1998-10-01 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	4062	\N	\N	\N
4010	MEMBRE	2000-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4063	\N	\N	\N
4011	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4064	\N	\N	\N
4012	MEMBRE	2000-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4065	\N	\N	\N
4013	MEMBRE	2000-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4066	\N	\N	\N
4014	MEMBRE	2000-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	4067	\N	\N	\N
4015	MEMBRE	2000-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4068	\N	\N	\N
4016	MEMBRE	2000-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4069	\N	\N	\N
4017	MEMBRE	2000-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4070	\N	\N	\N
4021	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4073	\N	\N	\N
4022	MEMBRE	2000-02-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4074	\N	\N	\N
4024	MEMBRE	2000-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4076	\N	\N	\N
4025	MEMBRE	2000-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4077	\N	\N	\N
4026	MEMBRE	2000-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4078	\N	\N	\N
4027	MEMBRE	2000-02-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4079	\N	\N	\N
4028	MEMBRE	2000-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	4080	\N	\N	\N
4030	MEMBRE	2000-03-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4082	\N	\N	\N
4031	MEMBRE	2000-02-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4083	\N	\N	\N
4032	MEMBRE	2000-02-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4084	\N	\N	\N
4034	MEMBRE	2000-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4086	\N	\N	\N
4036	MEMBRE	2000-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4088	\N	\N	\N
4043	MEMBRE	2000-03-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4094	\N	\N	\N
4041	MEMBRE	2000-03-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4093	\N	\N	\N
4040	MEMBRE	2000-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4092	\N	\N	\N
3406	PDTDEL	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Amérique centrale	\N	3470	3	\N	\N
3393	PDTDEL	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	Mexique	\N	3457	4	\N	\N
890	VICPDTDRT	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Madagascar et pays de l'Océan indien	\N	890	8	\N	\N
1928	VICPDTDRT	1999-01-01 00:00:00	2005-02-01 00:00:00	ANCIEN	\N	\N	Afrique de l'Ouest	\N	1928	9	\N	\N
857	VICPDTDRT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	Mexique et pays d'Amérique centrale	\N	857	2	\N	\N
1107	MEMBREBUR	1998-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	1107	10	\N	\N
4046	PDTDEL	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	Gabon et St-Thomas-et-Prince	\N	2766	8	\N	\N
2751	VICPDTDRT	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Madagascar et pays de l'Océan indien	\N	2775	2	\N	\N
4047	PDTDEL	1999-01-01 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	Centrafrique	\N	2784	6	\N	\N
4048	PDTDEL	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	Burundi	\N	2803	4	\N	\N
4049	PDTDEL	1999-01-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	Cameroun	\N	2794	5	\N	\N
3626	VICPDTDRT	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Afrique centrale	\N	3698	2	\N	\N
4051	PDTDEL	1999-01-01 00:00:00	2004-11-22 00:00:00	ANCIEN	\N	\N	Sultanat d'Oman	\N	3515	6	\N	\N
3143	MEMBRE	1999-01-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	\N	3186	\N	\N	\N
3546	MEMBRE	1999-01-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	\N	3616	\N	\N	\N
3769	MEMBRE	1999-01-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	\N	3844	\N	\N	\N
3254	MEMBRE	1999-01-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	\N	3313	\N	\N	\N
647	TRESOR	1999-01-01 00:00:00	2001-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	647	16	\N	\N
1360	SECRET	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1360	13	\N	\N
4052	VICPDT	2000-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	4097	4	\N	\N
4053	MEMBRE	2000-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	4098	\N	\N	\N
4054	MEMBRE	2000-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4099	\N	\N	\N
4055	MEMBRE	2000-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4100	\N	\N	\N
4056	MEMBRE	2000-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4101	\N	\N	\N
4057	VICPDT	2000-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4102	6	\N	\N
4058	MEMBRE	2000-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4103	\N	\N	\N
4059	MEMBRE	1899-12-30 01:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4104	\N	\N	\N
4060	MEMBRE	2000-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4107	\N	\N	\N
4061	MEMBRE	2000-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4108	\N	\N	\N
4062	MEMBRE	2000-01-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	\N	4109	\N	\N	\N
4063	MEMBRE	2000-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4110	\N	\N	\N
4064	MEMBRE	2000-01-01 00:00:00	2004-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	4111	\N	\N	\N
4065	MEMBRE	2000-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4112	\N	\N	\N
4066	MEMBRE	2000-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4113	\N	\N	\N
4067	MEMBRE	2000-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4114	\N	\N	\N
386	VICPDT	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	386	3	\N	\N
84	VICPDT	1998-10-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	84	5	\N	\N
1039	VICPDT	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1039	7	\N	\N
4068	MEMBRE	2000-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4115	\N	\N	\N
3780	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3857	\N	\N	\N
3782	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3859	\N	\N	\N
3783	MEMBREBUR	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3860	11	\N	\N
3784	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3861	\N	\N	\N
3785	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3862	7	\N	\N
3787	MEMBREBUR	1999-01-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	3864	10	\N	\N
3788	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3865	6	\N	\N
3789	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3866	\N	\N	\N
3791	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3868	\N	\N	\N
3792	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3869	\N	\N	\N
3795	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3872	\N	\N	\N
3796	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3873	\N	\N	\N
3797	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3874	\N	\N	\N
3799	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3876	\N	\N	\N
3800	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3877	\N	\N	\N
3801	PDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3878	1	\N	\N
3802	VICPDT	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3879	3	\N	\N
3804	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3881	\N	\N	\N
3805	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3882	\N	\N	\N
3806	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3883	\N	\N	\N
3809	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3886	\N	\N	\N
3812	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3889	\N	\N	\N
3813	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3890	4	\N	\N
3814	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3891	\N	\N	\N
3815	MEMBRE	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	3893	\N	\N	\N
3816	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3894	2	\N	\N
3817	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3895	\N	\N	\N
3818	SECRET	1999-01-01 00:00:00	2005-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	3896	6	\N	\N
3819	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3897	5	\N	\N
3820	VICPDT	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3898	2	\N	\N
3821	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3899	\N	\N	\N
3822	MEMBRE	1999-01-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	2820	\N	\N	\N
3823	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2823	\N	\N	\N
3824	MEMBRE	1999-01-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	2841	\N	\N	\N
3825	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2847	\N	\N	\N
3826	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3627	9	\N	\N
3827	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2863	\N	\N	\N
3829	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2881	\N	\N	\N
3830	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3124	\N	\N	\N
3831	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2868	\N	\N	\N
3832	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2937	\N	\N	\N
3833	TRESOR	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3295	8	\N	\N
3834	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2947	3	\N	\N
3835	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2597	\N	\N	\N
3838	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3013	\N	\N	\N
3839	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3022	\N	\N	\N
3840	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3490	\N	\N	\N
3841	MEMBRE	1999-01-01 00:00:00	2008-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	3548	\N	\N	\N
3842	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3730	\N	\N	\N
3843	PDT	2009-10-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3030	1	\N	\N
3845	MEMBRE	1999-01-01 09:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3242	\N	\N	\N
3847	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2720	\N	\N	\N
3848	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3652	\N	\N	\N
3849	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3063	2	\N	\N
3850	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3337	\N	\N	\N
3852	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3094	\N	\N	\N
3853	VICPDT	1999-01-01 00:00:00	2003-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	3900	4	\N	\N
3862	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3904	\N	\N	\N
3865	VICPDT	1999-01-01 00:00:00	2009-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	3907	3	\N	\N
3864	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	3906	\N	\N	\N
3866	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3908	3	\N	\N
3867	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3909	\N	\N	\N
3868	SECRET	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3910	11	\N	\N
3869	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3911	\N	\N	\N
3870	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3912	\N	\N	\N
3871	TRESOR	1999-01-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	3913	16	\N	\N
3872	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3914	\N	\N	\N
3873	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3915	13	\N	\N
3874	MEMBRE	1999-01-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	3916	\N	\N	\N
3876	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3918	\N	\N	\N
3877	MEMBRE	1999-01-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	\N	3919	\N	\N	\N
3880	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3922	15	\N	\N
3881	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3923	\N	\N	\N
3882	PDTDEL	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3924	2	\N	\N
3884	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3926	\N	\N	\N
3885	MEMBRE	1999-01-01 00:00:00	2001-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	3927	\N	\N	\N
3886	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3928	8	\N	\N
3888	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3930	8	\N	\N
3889	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3931	\N	\N	\N
3891	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3933	\N	\N	\N
3893	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3935	\N	\N	\N
3894	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3936	\N	\N	\N
3897	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3939	\N	\N	\N
3898	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	3940	\N	\N	\N
3901	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3943	\N	\N	\N
3902	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3944	\N	\N	\N
3903	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3945	\N	\N	\N
3906	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3948	\N	\N	\N
3907	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3949	\N	\N	\N
3908	PDT	1999-01-01 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	3950	1	\N	\N
3910	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3952	\N	\N	\N
3911	SECRET	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3953	10	\N	\N
3914	MEMBRE	1999-01-01 00:00:00	2001-12-11 00:00:00	ANCIEN	\N	\N	\N	\N	3956	\N	\N	\N
3915	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3957	\N	\N	\N
3916	MEMBRE	1999-01-01 00:00:00	2001-12-11 00:00:00	ANCIEN	\N	\N	\N	\N	3958	\N	\N	\N
3918	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3960	\N	\N	\N
3921	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3964	\N	\N	\N
3923	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3966	\N	\N	\N
3927	MEMBRE	1999-01-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	3970	\N	\N	\N
3928	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3971	\N	\N	\N
3930	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3973	\N	\N	\N
3931	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3974	\N	\N	\N
3932	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3975	6	\N	\N
3933	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3976	\N	\N	\N
3934	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3977	\N	\N	\N
3935	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3978	\N	\N	\N
3936	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3979	\N	\N	\N
3937	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3980	13	\N	\N
3939	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3982	\N	\N	\N
3941	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3986	\N	\N	\N
2524	MEMBRE	1998-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	2524	\N	\N	\N
2528	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2528	\N	\N	\N
2532	SECRET	1998-10-01 00:00:00	2004-10-26 00:00:00	ANCIEN	\N	\N	\N	\N	2532	13	\N	\N
2536	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2536	\N	\N	\N
2540	TRESOR	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2540	18	\N	\N
2544	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2544	\N	\N	\N
2548	SECRET	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2548	14	\N	\N
2552	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2552	\N	\N	\N
2556	MEMBRE	1998-10-01 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	2556	\N	\N	\N
2560	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2560	\N	\N	\N
2564	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2564	\N	\N	\N
2568	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2568	\N	\N	\N
2458	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2458	\N	\N	\N
2462	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2462	\N	\N	\N
2466	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2466	\N	\N	\N
2351	VICPDT	1999-01-01 00:00:00	2002-07-30 00:00:00	ANCIEN	\N	\N	\N	\N	2351	6	\N	\N
2355	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2355	\N	\N	\N
2359	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2359	7	\N	\N
2239	VICPDT	1999-01-01 00:00:00	2004-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	2239	6	\N	\N
2243	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2243	\N	\N	\N
2247	SECRET	1998-10-01 00:00:00	2008-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	2247	13	\N	\N
2251	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2251	\N	\N	\N
2255	MEMBRE	1998-10-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	2255	\N	\N	\N
2132	MEMBRE	1999-01-01 00:00:00	2002-07-30 00:00:00	ANCIEN	\N	\N	\N	\N	2132	\N	\N	\N
2136	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2136	\N	\N	\N
2140	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2140	\N	\N	\N
2144	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2144	\N	\N	\N
2148	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2148	\N	\N	\N
2025	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2025	\N	\N	\N
2029	SECRET	1999-01-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	2029	10	\N	\N
2033	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2033	\N	\N	\N
2037	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2037	\N	\N	\N
2041	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2041	\N	\N	\N
1930	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1930	\N	\N	\N
1934	MEMBRE	1998-10-01 00:00:00	2004-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	1934	\N	\N	\N
1688	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	1688	\N	\N	\N
1692	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1692	\N	\N	\N
1696	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1696	\N	\N	\N
1700	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1700	\N	\N	\N
1709	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1709	\N	\N	\N
1713	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1713	5	\N	\N
1717	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1717	\N	\N	\N
1613	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1613	\N	\N	\N
1483	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1483	\N	\N	\N
1487	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1487	\N	\N	\N
1496	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1496	\N	\N	\N
1500	MEMBREBUR	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1500	7	\N	\N
1504	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1504	\N	\N	\N
1279	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1279	\N	\N	\N
1283	VICPDT	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1283	6	\N	\N
1287	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1287	\N	\N	\N
1295	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1295	\N	\N	\N
1162	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1162	\N	\N	\N
1166	VICPDT	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1166	5	\N	\N
1170	SECRET	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1170	16	\N	\N
1174	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1174	\N	\N	\N
1186	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1186	\N	\N	\N
1059	MEMBRE	1998-10-01 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	1059	0	\N	\N
1063	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1063	\N	\N	\N
1067	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1067	\N	\N	\N
1072	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	1072	\N	\N	\N
1076	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1076	\N	\N	\N
846	PDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	846	1	\N	\N
850	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	850	\N	\N	\N
855	SECRET	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	855	22	\N	\N
859	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	859	\N	\N	\N
864	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	864	\N	\N	\N
747	MEMBRE	1998-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	747	\N	\N	\N
751	VICPDT	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	751	3	\N	\N
755	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	755	\N	\N	\N
759	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	759	\N	\N	\N
653	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	653	\N	\N	\N
88	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	88	\N	\N	\N
92	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92	\N	\N	\N
96	MEMBRE	1998-10-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	96	\N	\N	\N
99	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	99	\N	\N	\N
105	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	105	\N	\N	\N
109	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	109	\N	\N	\N
318	VICPDT	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	318	3	\N	\N
322	PDT	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	322	1	\N	\N
326	VICPDT	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	326	6	\N	\N
330	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	330	\N	\N	\N
335	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	335	\N	\N	\N
3350	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3413	\N	\N	\N
3354	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3417	\N	\N	\N
3357	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3420	9	\N	\N
3360	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3423	\N	\N	\N
4427	MEMBRE	2001-01-10 00:00:00	2003-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	4536	\N	\N	\N
4435	MEMBRE	2000-12-11 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4544	\N	\N	\N
4555	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4668	\N	\N	\N
4559	MEMBRE	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4672	\N	\N	\N
4577	MEMBRE	2001-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2345	\N	\N	\N
4578	VICPDT	2001-10-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	2326	5	\N	\N
4579	MEMBREBUR	2001-10-01 00:00:00	2004-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	2502	11	\N	\N
4580	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4681	\N	\N	\N
4581	MEMBRE	2001-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4682	\N	\N	\N
4583	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4684	\N	\N	\N
4584	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4685	\N	\N	\N
4585	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4686	\N	\N	\N
4586	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4687	\N	\N	\N
4587	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4688	\N	\N	\N
4588	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4689	\N	\N	\N
4589	MEMBRE	2001-10-01 00:00:00	2007-02-25 00:00:00	ANCIEN	\N	\N	\N	\N	4690	\N	\N	\N
4590	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4691	\N	\N	\N
4591	MEMBRE	2001-10-01 00:00:00	2007-06-24 00:00:00	ANCIEN	\N	\N	\N	\N	4692	\N	\N	\N
4592	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4693	\N	\N	\N
4593	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4694	\N	\N	\N
4595	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4701	\N	\N	\N
4596	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4702	\N	\N	\N
4597	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4703	\N	\N	\N
4598	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4705	\N	\N	\N
4600	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4707	\N	\N	\N
4601	MEMBRE	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4708	\N	\N	\N
4602	MEMBRE	2001-10-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	4709	\N	\N	\N
4603	MEMBRE	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4710	\N	\N	\N
4604	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4711	\N	\N	\N
4605	MEMBRE	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4712	\N	\N	\N
4606	MEMBRE	2001-10-01 00:00:00	2004-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	4713	\N	\N	\N
4608	PDTDEL	2001-10-01 00:00:00	2009-02-09 00:00:00	ANCIEN	\N	\N	Lituanie	\N	4715	3	\N	\N
4610	VICPDT	2001-10-01 00:00:00	2004-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	4717	6	\N	\N
4611	MEMBRE	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4718	\N	\N	\N
4613	VICPDT	2001-10-01 00:00:00	2009-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	4720	9	\N	\N
4615	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4723	\N	\N	\N
4616	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4724	\N	\N	\N
4618	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4727	\N	\N	\N
4619	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4728	\N	\N	\N
4620	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4729	\N	\N	\N
4621	SECRET	2001-10-01 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	4730	8	\N	\N
4622	MEMBRE	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4731	\N	\N	\N
4623	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4732	\N	\N	\N
4624	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4733	\N	\N	\N
4625	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4734	\N	\N	\N
4626	VICPDT	2001-10-01 00:00:00	2008-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	4735	5	\N	\N
4627	MEMBRE	2001-10-01 00:00:00	2002-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4736	\N	\N	\N
4628	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4737	\N	\N	\N
4629	MEMBRE	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4738	\N	\N	\N
4630	MEMBRE	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4739	\N	\N	\N
4632	MEMBRE	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4741	\N	\N	\N
4633	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4742	\N	\N	\N
4634	MEMBRE	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4743	\N	\N	\N
4635	MEMBRE	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4744	\N	\N	\N
4636	MEMBRE	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4745	\N	\N	\N
4637	MEMBRE	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4746	\N	\N	\N
4638	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4747	\N	\N	\N
4639	MEMBRE	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4748	\N	\N	\N
4640	MEMBRE	2001-10-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	4749	\N	\N	\N
4641	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4750	\N	\N	\N
4643	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4752	\N	\N	\N
4645	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4755	\N	\N	\N
4646	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4756	\N	\N	\N
4647	VICPDT	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4757	2	\N	\N
4648	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4758	\N	\N	\N
4649	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4759	\N	\N	\N
311	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	311	\N	\N	\N
313	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	313	\N	\N	\N
314	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	314	\N	\N	\N
315	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	315	\N	\N	\N
316	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	316	\N	\N	\N
319	MEMBRE	1998-09-30 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	319	\N	\N	\N
320	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	320	\N	\N	\N
321	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	321	\N	\N	\N
323	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	323	\N	\N	\N
325	VICPDT	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	325	5	\N	\N
327	VICPDT	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	327	2	\N	\N
328	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	328	\N	\N	\N
329	VICPDT	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	329	5	\N	\N
332	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	332	\N	\N	\N
333	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	333	\N	\N	\N
336	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	336	\N	\N	\N
337	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	337	\N	\N	\N
339	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	339	\N	\N	\N
340	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	340	\N	\N	\N
341	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	341	\N	\N	\N
343	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	343	\N	\N	\N
344	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	344	\N	\N	\N
345	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	345	\N	\N	\N
346	MEMBRE	1998-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	346	\N	\N	\N
3765	MEMBRE	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3840	\N	\N	\N
3767	MEMBRE	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3842	\N	\N	\N
3770	MEMBRE	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3845	\N	\N	\N
3771	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3846	\N	\N	\N
3772	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3847	\N	\N	\N
3774	MEMBRE	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3849	\N	\N	\N
3775	MEMBRE	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3850	\N	\N	\N
3776	MEMBRE	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3851	\N	\N	\N
3779	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3855	\N	\N	\N
3846	VICPDT	1999-01-01 09:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2700	2	\N	\N
3451	PDTDEL	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	Etat du Qatar	\N	3518	5	\N	\N
1914	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1914	10	\N	\N
3015	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3055	9	\N	\N
2071	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2071	10	\N	\N
3755	PDT	1999-06-22 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3636	1	\N	\N
3598	VICPDT	1999-01-01 00:00:00	2009-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	3670	3	\N	\N
3600	SECRET	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3672	10	\N	\N
1112	VICPDT	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1112	3	\N	\N
3277	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3336	7	\N	\N
888	VICPDT	1999-01-01 00:00:00	2004-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	888	7	\N	\N
1731	SECRET	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1731	14	\N	\N
1989	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1989	16	\N	\N
3280	MEMBREBUR	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3341	19	\N	\N
994	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	994	\N	\N	\N
999	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	999	\N	\N	\N
1004	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1004	\N	\N	\N
1010	MEMBRE	1998-10-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	1010	\N	\N	\N
1015	VICPDT	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	1015	3	\N	\N
1020	PDTDEL	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	Malawi	\N	1020	4	\N	\N
1025	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1025	\N	\N	\N
1030	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1030	\N	\N	\N
1035	MEMBRE	1999-01-01 00:00:00	2001-10-30 00:00:00	ANCIEN	\N	\N	\N	\N	1035	\N	\N	\N
1041	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1041	\N	\N	\N
1046	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1046	\N	\N	\N
1051	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	1051	\N	\N	\N
1056	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1056	\N	\N	\N
1062	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1062	\N	\N	\N
1069	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1069	\N	\N	\N
1077	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1077	\N	\N	\N
881	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	881	\N	\N	\N
886	PDTDEL	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Philippines	\N	886	6	\N	\N
891	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	891	\N	\N	\N
897	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	897	\N	\N	\N
903	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	903	\N	\N	\N
908	VICPDT	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	908	8	\N	\N
914	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	914	\N	\N	\N
4138	MEMBRE	2000-11-01 00:00:00	2001-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	4188	\N	\N	\N
4139	MEMBRE	2000-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4189	\N	\N	\N
4141	MEMBRE	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4191	\N	\N	\N
4143	MEMBRE	2000-11-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	4193	\N	\N	\N
4146	MEMBRE	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4197	\N	\N	\N
4148	MEMBRE	2000-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4199	\N	\N	\N
4149	MEMBRE	2000-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4200	\N	\N	\N
4150	MEMBRE	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4201	\N	\N	\N
4152	MEMBRE	2000-11-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	4203	\N	\N	\N
4153	MEMBRE	2000-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4204	\N	\N	\N
4154	MEMBRE	2000-11-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4205	\N	\N	\N
4155	MEMBRE	2000-11-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	4206	\N	\N	\N
4157	MEMBRE	2000-11-01 00:00:00	2004-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	4208	\N	\N	\N
4158	MEMBRE	2000-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4209	\N	\N	\N
4159	MEMBRE	2000-11-01 00:00:00	2003-10-31 00:00:00	ANCIEN	\N	\N	\N	\N	4210	\N	\N	\N
4161	VICPDT	2000-11-01 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	4212	6	\N	\N
4162	MEMBRE	2000-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4213	\N	\N	\N
4163	MEMBRE	2000-11-01 00:00:00	2001-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	4214	\N	\N	\N
4164	MEMBRE	2000-11-01 00:00:00	2001-09-10 00:00:00	ANCIEN	\N	\N	\N	\N	4215	\N	\N	\N
1535	MEMBREBUR	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1535	9	\N	\N
1724	PDTDEL	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	Birmanie	\N	1724	6	\N	\N
4167	MEMBRE	2000-11-10 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4218	\N	\N	\N
4168	MEMBRE	2000-11-10 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4219	\N	\N	\N
4170	MEMBRE	2000-11-10 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4221	\N	\N	\N
4171	MEMBRE	2000-11-10 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4222	\N	\N	\N
4172	MEMBRE	2000-11-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4223	\N	\N	\N
4173	MEMBRE	2000-11-10 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4224	\N	\N	\N
4175	MEMBRE	2000-11-10 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4226	\N	\N	\N
4176	MEMBRE	2000-11-10 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4227	\N	\N	\N
4177	MEMBRE	2000-11-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4228	\N	\N	\N
4178	MEMBRE	2000-11-10 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4229	\N	\N	\N
4180	MEMBRE	2000-11-10 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4231	\N	\N	\N
4182	MEMBRE	2000-11-10 00:00:00	2004-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	4233	\N	\N	\N
4184	MEMBRE	2000-11-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4235	\N	\N	\N
4185	MEMBRE	2000-11-10 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4236	\N	\N	\N
4186	MEMBRE	2000-11-10 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4237	\N	\N	\N
4187	MEMBRE	2000-11-10 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4238	\N	\N	\N
4188	MEMBRE	2000-11-10 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4239	\N	\N	\N
4189	MEMBRE	2000-11-10 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	4240	\N	\N	\N
4190	MEMBRE	2000-11-10 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4241	\N	\N	\N
4191	MEMBRE	2000-11-10 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4242	\N	\N	\N
4192	MEMBRE	2000-11-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4243	\N	\N	\N
4193	MEMBRE	2000-11-10 00:00:00	2004-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	4244	\N	\N	\N
4194	MEMBRE	2000-11-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4245	\N	\N	\N
4195	MEMBRE	2000-10-03 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4246	\N	\N	\N
4196	MEMBREBUR	2000-10-16 00:00:00	2004-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	4247	15	\N	\N
4197	MEMBRE	2000-10-08 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	4248	\N	\N	\N
4198	MEMBRE	2000-12-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4249	\N	\N	\N
4199	MEMBRE	2000-12-06 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4250	\N	\N	\N
4200	MEMBRE	2000-11-28 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4251	\N	\N	\N
4201	MEMBRE	2000-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4252	\N	\N	\N
4202	TRESOR	2000-12-05 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2642	8	\N	\N
4203	MEMBRE	2000-12-18 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4253	\N	\N	\N
4205	MEMBRE	2000-12-14 00:00:00	2001-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	4255	\N	\N	\N
4206	MEMBRE	2000-12-14 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4256	\N	\N	\N
4207	MEMBRE	2000-12-20 00:00:00	2004-11-15 00:00:00	ANCIEN	\N	\N	\N	\N	4257	\N	\N	\N
4208	SECRET	2000-11-30 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4258	15	\N	\N
4209	PDTDEL	2000-11-23 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	4259	\N	\N	\N
4210	PDTHON	2000-11-28 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4260	20	\N	\N
2622	MEMBRE	1999-01-01 00:00:00	2001-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	2635	\N	\N	\N
4212	PDTDEL	2001-01-24 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	Azerbaïdjan	\N	768	2	\N	\N
4213	MEMBRE	2001-01-01 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	4262	0	\N	\N
4214	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4264	\N	\N	\N
4215	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4265	\N	\N	\N
4216	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4266	\N	\N	\N
4217	VICPDT	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4267	3	\N	\N
4218	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4268	\N	\N	\N
4219	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4269	\N	\N	\N
4221	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4272	\N	\N	\N
4222	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4273	\N	\N	\N
4223	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4274	\N	\N	\N
4227	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4278	\N	\N	\N
4229	VICPDT	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4280	7	\N	\N
4230	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4281	\N	\N	\N
4231	MEMBRE	1998-10-01 00:00:00	2009-01-14 00:00:00	ANCIEN	\N	\N	\N	\N	4282	\N	\N	\N
4232	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4283	\N	\N	\N
4233	MEMBRE	1998-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4284	\N	\N	\N
4234	TRESOR	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4285	11	\N	\N
4235	VICPDT	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4286	4	\N	\N
4237	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4288	\N	\N	\N
4239	VICPDT	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4290	6	\N	\N
4240	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4291	\N	\N	\N
4242	PDT	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4293	1	\N	\N
4243	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4294	\N	\N	\N
4244	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4295	\N	\N	\N
4245	MEMBRE	1998-10-01 00:00:00	2001-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	4296	\N	\N	\N
4247	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4298	\N	\N	\N
4248	MEMBRE	1998-10-01 00:00:00	2004-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	4299	\N	\N	\N
4251	VICPDT	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4302	\N	\N	\N
4252	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4303	\N	\N	\N
4253	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4304	\N	\N	\N
4254	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4305	\N	\N	\N
4255	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4306	\N	\N	\N
4256	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4307	\N	\N	\N
4258	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4309	\N	\N	\N
4300	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4400	\N	\N	\N
4301	PDT	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4401	1	\N	\N
4304	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4404	\N	\N	\N
4305	VICPDT	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4405	\N	\N	\N
4306	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4406	\N	\N	\N
4307	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4407	\N	\N	\N
4308	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4408	\N	\N	\N
4310	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4410	\N	\N	\N
4312	MEMBRE	1998-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4412	\N	\N	\N
4314	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4414	\N	\N	\N
4315	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4415	\N	\N	\N
4322	MEMBRE	2001-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4424	\N	\N	\N
4321	MEMBRE	2001-05-01 00:00:00	2001-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	4423	\N	\N	\N
4323	MEMBRE	2001-05-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4425	\N	\N	\N
4324	MEMBRE	2001-05-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	4426	\N	\N	\N
4326	MEMBRE	2001-05-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4428	\N	\N	\N
4327	MEMBRE	2001-05-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4429	\N	\N	\N
4328	VICPDT	2001-05-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4431	3	\N	\N
4329	MEMBRE	2001-05-01 00:00:00	2008-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	4432	0	\N	\N
4330	PDT	2001-05-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4434	1	\N	\N
4333	VICPDT	2001-05-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4437	2	\N	\N
4334	SECRET	2001-05-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4438	6	\N	\N
4335	MEMBRE	2001-05-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4439	\N	\N	\N
4336	MEMBRE	2001-05-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4440	\N	\N	\N
4337	MEMBRE	2001-05-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4441	\N	\N	\N
4338	MEMBRE	2001-05-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4442	\N	\N	\N
4339	MEMBRE	2001-05-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4443	\N	\N	\N
4341	MEMBRE	2001-05-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4445	\N	\N	\N
4342	SECRET	2001-05-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4446	5	\N	\N
4343	MEMBRE	2001-05-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4447	\N	\N	\N
4344	MEMBRE	2001-05-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4449	\N	\N	\N
4345	MEMBRE	2001-05-01 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	4450	\N	\N	\N
4347	MEMBRE	2001-05-29 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4454	\N	\N	\N
4348	MEMBRE	2000-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4455	\N	\N	\N
4349	MEMBRE	2001-06-27 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4456	\N	\N	\N
4350	MEMBRE	2001-07-04 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4457	\N	\N	\N
4351	VICPDT	2001-06-21 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	4458	3	\N	\N
4352	VICPDT	2001-06-26 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4459	2	\N	\N
4353	VICPDT	2001-06-12 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4460	3	\N	\N
4355	MEMBRE	2000-06-20 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4461	\N	\N	\N
4356	MEMBRE	2000-12-22 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4463	\N	\N	\N
4359	MEMBRE	2000-11-27 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4466	\N	\N	\N
4360	MEMBRE	2001-11-28 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4467	\N	\N	\N
4361	MEMBRE	2000-11-28 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4468	\N	\N	\N
4362	MEMBRE	2000-12-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4469	\N	\N	\N
4363	MEMBRE	2000-06-22 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4470	\N	\N	\N
4364	MEMBRE	2000-06-26 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4471	\N	\N	\N
4365	MEMBRE	2000-06-30 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4472	\N	\N	\N
4366	MEMBRE	2000-12-07 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4473	\N	\N	\N
4367	MEMBRE	2000-11-28 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4474	\N	\N	\N
4368	MEMBRE	2000-12-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4475	\N	\N	\N
4369	VICPDT	2000-06-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4476	2	\N	\N
4370	MEMBRE	2000-06-26 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4477	\N	\N	\N
4371	MEMBRE	2000-06-26 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4478	\N	\N	\N
4372	MEMBRE	2000-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4479	\N	\N	\N
4375	MEMBRE	2000-11-28 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4483	\N	\N	\N
4376	VICPDT	2000-06-20 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	4484	7	\N	\N
4377	MEMBRE	2000-11-28 00:00:00	2004-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	4485	\N	\N	\N
5809	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5854	\N	\N	\N
5811	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5856	\N	\N	\N
5812	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5857	\N	\N	\N
5813	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5858	\N	\N	\N
5814	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5859	\N	\N	\N
5816	MEMBRE	1998-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5861	\N	\N	\N
5817	MEMBRE	1998-10-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	\N	5862	\N	\N	\N
5819	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5864	\N	\N	\N
5820	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5865	\N	\N	\N
5821	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5866	\N	\N	\N
5822	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5867	\N	\N	\N
5823	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5868	\N	\N	\N
5824	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5870	\N	\N	\N
5825	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5871	\N	\N	\N
5826	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5872	8	\N	\N
5828	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5874	\N	\N	\N
5829	MEMBRE	2001-10-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	5875	\N	\N	\N
5830	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5876	12	\N	\N
5831	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5877	\N	\N	\N
5832	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5878	\N	\N	\N
5833	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5879	\N	\N	\N
5834	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5880	\N	\N	\N
5835	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5881	\N	\N	\N
5836	MEMBRE	2001-10-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	5882	\N	\N	\N
5837	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5883	\N	\N	\N
5838	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5884	\N	\N	\N
5840	MEMBRE	2001-10-01 00:00:00	2004-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	5886	\N	\N	\N
5841	SECRET	2001-10-01 00:00:00	2004-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	5887	13	\N	\N
5842	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5888	\N	\N	\N
5843	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5889	\N	\N	\N
5844	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5890	\N	\N	\N
5845	SECRET	2001-10-01 00:00:00	2004-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	5891	15	\N	\N
5846	MEMBRE	2001-10-01 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	5892	\N	\N	\N
5847	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5893	\N	\N	\N
5849	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5895	\N	\N	\N
5851	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5897	\N	\N	\N
5852	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5898	\N	\N	\N
5853	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5899	\N	\N	\N
5854	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5900	\N	\N	\N
5855	SECRET	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5901	7	\N	\N
5856	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5902	\N	\N	\N
5857	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5903	\N	\N	\N
5858	MEMBRE	2001-10-01 00:00:00	2004-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	5904	\N	\N	\N
5859	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5905	\N	\N	\N
5860	MEMBRE	2001-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	5906	\N	\N	\N
5861	MEMBRE	2001-10-01 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	5907	\N	\N	\N
5862	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5908	10	\N	\N
5864	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5910	\N	\N	\N
5865	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5911	\N	\N	\N
5866	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5912	\N	\N	\N
5867	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5913	\N	\N	\N
5868	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5914	\N	\N	\N
5869	MEMBRE	2001-10-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	5915	\N	\N	\N
5870	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5916	\N	\N	\N
5871	SECRET	2001-10-01 00:00:00	2004-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	5917	8	\N	\N
5872	MEMBRE	2001-10-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	5918	\N	\N	\N
5873	SECRET	2001-10-01 00:00:00	2004-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	5919	9	\N	\N
5874	VICPDT	2001-10-01 00:00:00	2009-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	5920	5	\N	\N
5876	MEMBRE	2001-05-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5922	\N	\N	\N
5877	MEMBRE	2001-05-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5923	\N	\N	\N
5878	SECRET	2001-10-01 00:00:00	2004-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	5924	6	\N	\N
5879	MEMBRE	2001-10-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	5925	\N	\N	\N
5880	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5926	\N	\N	\N
5881	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5928	\N	\N	\N
5882	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3622	4	\N	\N
5883	VICPDT	2001-10-01 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	667	6	\N	\N
4650	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4760	\N	\N	\N
4651	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4761	\N	\N	\N
4652	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4762	\N	\N	\N
4653	MEMBRE	2001-10-01 00:00:00	2004-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	4763	\N	\N	\N
4654	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4764	\N	\N	\N
4662	SECRET	2001-10-01 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	4775	9	\N	\N
4657	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4767	\N	\N	\N
4658	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4769	\N	\N	\N
4659	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4770	\N	\N	\N
4661	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4772	\N	\N	\N
4663	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4776	\N	\N	\N
4665	MEMBREBUR	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4778	12	\N	\N
4666	MEMBRE	2001-10-01 00:00:00	2004-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	4779	\N	\N	\N
4667	MEMBRE	2001-10-01 00:00:00	2004-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	4780	\N	\N	\N
4669	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4782	\N	\N	\N
4670	MEMBRE	2001-10-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	4783	\N	\N	\N
4671	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4784	\N	\N	\N
4672	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4785	\N	\N	\N
4673	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4786	\N	\N	\N
4674	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4787	\N	\N	\N
4676	MEMBRE	2001-10-01 00:00:00	2004-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	4789	\N	\N	\N
4677	MEMBRE	2001-10-01 00:00:00	2004-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	4790	\N	\N	\N
4678	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4791	\N	\N	\N
4680	MEMBREBUR	2001-10-01 00:00:00	2004-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	4793	19	\N	\N
4681	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4794	\N	\N	\N
4682	MEMBRE	2001-10-01 00:00:00	2004-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	4795	\N	\N	\N
4683	MEMBREBUR	2001-10-01 00:00:00	2004-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	4796	21	\N	\N
4684	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4797	\N	\N	\N
4685	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4798	\N	\N	\N
4686	MEMBRE	2001-10-01 00:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	4799	0	\N	\N
4687	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4800	\N	\N	\N
4689	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4802	\N	\N	\N
4690	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4803	\N	\N	\N
4693	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4806	\N	\N	\N
4695	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4814	\N	\N	\N
4696	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4815	\N	\N	\N
4699	MEMBRE	2001-10-01 00:00:00	2004-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	4818	\N	\N	\N
4700	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4819	\N	\N	\N
4701	VICPDT	2001-10-01 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	4820	10	\N	\N
4703	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4822	\N	\N	\N
4704	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4823	\N	\N	\N
4705	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4824	\N	\N	\N
4707	MEMBRE	2001-10-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	4826	\N	\N	\N
4708	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4827	\N	\N	\N
4709	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4828	\N	\N	\N
4711	VICPDT	2001-10-01 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	4830	3	\N	\N
4713	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4832	\N	\N	\N
4715	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4834	\N	\N	\N
4716	MEMBRE	2001-10-01 00:00:00	2004-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	4835	\N	\N	\N
4717	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4836	\N	\N	\N
4718	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4837	\N	\N	\N
4720	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4839	\N	\N	\N
4721	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4840	\N	\N	\N
4692	MEMBRE	2001-10-01 00:00:00	2004-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	4805	\N	\N	\N
4697	MEMBRE	2001-10-01 00:00:00	2004-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	4816	\N	\N	\N
4702	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4821	\N	\N	\N
4714	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4833	\N	\N	\N
4719	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4838	\N	\N	\N
4725	VICPDT	2001-10-01 00:00:00	2005-03-07 00:00:00	ANCIEN	\N	\N	\N	\N	547	6	\N	\N
4726	SECRET	2001-10-01 00:00:00	2005-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	2522	10	\N	\N
4727	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1316	13	\N	\N
4728	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1223	14	\N	\N
4729	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4842	\N	\N	\N
4730	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4843	\N	\N	\N
4731	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4844	\N	\N	\N
4732	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4845	\N	\N	\N
5261	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5322	\N	\N	\N
5260	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5321	\N	\N	\N
5262	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5323	\N	\N	\N
5264	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5325	\N	\N	\N
5265	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5326	\N	\N	\N
5267	MEMBRE	2001-10-01 00:00:00	2004-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	5328	\N	\N	\N
5268	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5329	\N	\N	\N
5270	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5331	\N	\N	\N
5271	MEMBRE	2001-10-01 00:00:00	2004-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	5332	\N	\N	\N
5272	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5333	\N	\N	\N
5273	MEMBRE	2001-10-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	\N	5334	\N	\N	\N
5274	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5335	\N	\N	\N
5275	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5336	\N	\N	\N
5276	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5337	\N	\N	\N
5277	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5338	\N	\N	\N
5278	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5339	\N	\N	\N
5279	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5340	\N	\N	\N
5280	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5341	\N	\N	\N
5281	VICPDT	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5342	3	\N	\N
5282	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5343	\N	\N	\N
5283	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5344	\N	\N	\N
5284	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5345	\N	\N	\N
5285	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5346	\N	\N	\N
5287	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5348	\N	\N	\N
5288	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5349	\N	\N	\N
5289	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5350	\N	\N	\N
5290	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5351	\N	\N	\N
5291	SECRET	2001-10-01 00:00:00	2004-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	5352	11	\N	\N
5292	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5353	\N	\N	\N
5293	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5354	\N	\N	\N
5294	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5355	\N	\N	\N
5295	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5356	\N	\N	\N
5296	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5357	\N	\N	\N
5297	MEMBRE	2001-10-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	5358	\N	\N	\N
5298	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5359	12	\N	\N
5299	MEMBRE	2001-10-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	\N	5360	\N	\N	\N
5300	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5361	\N	\N	\N
5304	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5365	\N	\N	\N
5305	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5366	\N	\N	\N
5306	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5367	\N	\N	\N
5307	VICPDT	2001-10-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	5368	7	\N	\N
5308	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5369	\N	\N	\N
5309	MEMBRE	2001-10-01 00:00:00	2004-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	5370	\N	\N	\N
5310	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5371	\N	\N	\N
5312	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5373	\N	\N	\N
5313	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5374	\N	\N	\N
5314	MEMBRE	2001-10-01 00:00:00	2004-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	5375	\N	\N	\N
5315	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5376	\N	\N	\N
5317	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5378	\N	\N	\N
5318	MEMBRE	2001-10-01 00:00:00	2004-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	5379	\N	\N	\N
5319	MEMBRE	2001-10-01 00:00:00	2004-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	5380	\N	\N	\N
5324	PDT	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1422	1	\N	\N
5322	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5383	\N	\N	\N
5325	PDTDEL	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Azerbaïdjan	\N	1422	2	\N	\N
5326	VICPDT	2001-10-01 00:00:00	2009-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	2539	\N	\N	\N
5327	SECRET	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1246	12	\N	\N
5328	VICPDT	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2496	8	\N	\N
5330	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2376	16	\N	\N
5331	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5385	\N	\N	\N
5332	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5386	\N	\N	\N
5333	MEMBRE	2001-10-01 00:00:00	2005-03-07 00:00:00	ANCIEN	\N	\N	\N	\N	5387	\N	\N	\N
5334	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5388	\N	\N	\N
5335	MEMBRE	2001-12-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5389	\N	\N	\N
5336	MEMBRE	2001-11-13 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5390	\N	\N	\N
5337	MEMBRE	2001-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5391	\N	\N	\N
5338	MEMBRE	2001-12-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5392	\N	\N	\N
5341	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5395	\N	\N	\N
5342	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5396	\N	\N	\N
5346	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5401	\N	\N	\N
5347	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5402	\N	\N	\N
5348	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5403	10	\N	\N
5349	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5404	\N	\N	\N
5350	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5405	\N	\N	\N
5351	SECRET	2001-10-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	\N	5406	11	\N	\N
5352	MEMBRE	2001-10-01 00:00:00	2005-03-07 00:00:00	ANCIEN	\N	\N	\N	\N	5407	\N	\N	\N
5354	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5409	\N	\N	\N
5359	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5414	\N	\N	\N
5360	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5415	\N	\N	\N
5366	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5421	\N	\N	\N
5367	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5422	\N	\N	\N
5368	MEMBRE	2001-12-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	5423	\N	\N	\N
5369	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5425	\N	\N	\N
5370	MEMBRE	2001-10-01 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	5427	\N	\N	\N
5371	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5428	\N	\N	\N
5372	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5429	\N	\N	\N
5381	SECRET	2001-10-01 00:00:00	2005-03-07 00:00:00	ANCIEN	\N	\N	\N	\N	3178	8	\N	\N
5383	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1415	\N	\N	\N
5385	VICPDT	2001-10-01 00:00:00	2009-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	3653	2	\N	\N
5386	VICPDT	2001-10-01 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	3632	4	\N	\N
5388	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4078	9	\N	\N
5389	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3637	12	\N	\N
5390	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3666	13	\N	\N
5391	SECRET	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3681	11	\N	\N
5392	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5437	\N	\N	\N
5393	MEMBRE	2001-10-01 00:00:00	2009-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	5438	\N	\N	\N
5394	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5439	\N	\N	\N
5395	MEMBRE	2001-10-01 00:00:00	2005-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	5440	\N	\N	\N
5396	MEMBRE	2001-10-01 00:00:00	2002-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	5441	\N	\N	\N
5397	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5442	\N	\N	\N
5398	MEMBRE	2001-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5443	\N	\N	\N
5399	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5444	\N	\N	\N
5400	SECRET	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5445	17	\N	\N
5401	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5448	\N	\N	\N
5402	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5449	\N	\N	\N
5404	SECRET	2001-10-01 00:00:00	2009-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	5451	18	\N	\N
5406	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5454	\N	\N	\N
5407	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5455	\N	\N	\N
5408	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5456	\N	\N	\N
5409	PDTDEL	2001-10-01 00:00:00	2008-09-24 00:00:00	ANCIEN	\N	\N	Malawi	\N	5457	4	\N	\N
5411	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5459	\N	\N	\N
5412	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5460	\N	\N	\N
5413	VICPDT	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5461	14	\N	\N
5414	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5462	\N	\N	\N
5415	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5463	\N	\N	\N
5416	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5464	\N	\N	\N
4785	MEMBRE	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4900	\N	\N	\N
4787	MEMBRE	2001-10-01 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	4902	\N	\N	\N
4788	MEMBRE	2001-10-01 00:00:00	2004-11-09 00:00:00	ANCIEN	\N	\N	\N	\N	4903	\N	\N	\N
4789	MEMBRE	2001-10-01 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	4904	\N	\N	\N
4791	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4907	\N	\N	\N
4792	MEMBRE	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4908	\N	\N	\N
4793	VICPDT	2001-10-01 00:00:00	2009-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	4909	8	\N	\N
4795	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4911	\N	\N	\N
4796	VICPDT	2001-10-01 00:00:00	2009-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	4912	10	\N	\N
4797	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4913	\N	\N	\N
4799	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4915	\N	\N	\N
4801	MEMBRE	2001-10-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	\N	4917	\N	\N	\N
4802	MEMBRE	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4918	\N	\N	\N
4804	SECRET	2001-10-01 00:00:00	2009-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	4920	18	\N	\N
4805	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4921	\N	\N	\N
4806	MEMBRE	2001-10-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	4922	\N	\N	\N
4808	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4924	11	\N	\N
4809	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4925	\N	\N	\N
4810	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4926	\N	\N	\N
4812	MEMBRE	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4928	\N	\N	\N
4813	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4929	\N	\N	\N
4815	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4931	\N	\N	\N
4817	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4933	\N	\N	\N
4818	MEMBRE	2001-10-01 00:00:00	2004-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	4934	\N	\N	\N
4819	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4935	\N	\N	\N
4820	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4936	\N	\N	\N
4821	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4937	\N	\N	\N
4822	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4938	\N	\N	\N
4823	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4939	\N	\N	\N
4825	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4941	\N	\N	\N
4826	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4942	\N	\N	\N
4828	VICPDT	2001-10-01 00:00:00	2009-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	4944	4	\N	\N
4829	TRESOR	2001-10-01 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	4945	9	\N	\N
4830	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4946	\N	\N	\N
4831	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4947	\N	\N	\N
4832	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4948	\N	\N	\N
4833	MEMBRE	2001-10-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	4949	\N	\N	\N
4834	MEMBRE	2001-10-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	\N	4950	\N	\N	\N
4836	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4952	\N	\N	\N
4837	MEMBRE	2001-10-01 00:00:00	2009-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	4953	0	\N	\N
4838	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4954	11	\N	\N
4839	SECRET	2001-10-01 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	4955	12	\N	\N
4840	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4956	\N	\N	\N
4841	MEMBRE	2001-10-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	4957	\N	\N	\N
4842	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4958	\N	\N	\N
4843	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4959	\N	\N	\N
4844	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4960	\N	\N	\N
4845	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4961	\N	\N	\N
4846	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4962	\N	\N	\N
4848	MEMBRE	2001-10-01 00:00:00	2004-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	4964	\N	\N	\N
4849	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4965	\N	\N	\N
4850	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4966	\N	\N	\N
4851	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4967	\N	\N	\N
4852	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4968	\N	\N	\N
4853	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4969	\N	\N	\N
4854	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4970	8	\N	\N
4855	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4971	\N	\N	\N
4857	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4973	\N	\N	\N
4858	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4974	\N	\N	\N
4860	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4976	\N	\N	\N
4861	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4977	\N	\N	\N
4862	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4978	\N	\N	\N
4863	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4979	11	\N	\N
4864	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4980	\N	\N	\N
4865	MEMBRE	2001-10-01 00:00:00	2004-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	4981	\N	\N	\N
4867	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4983	\N	\N	\N
4876	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4993	\N	\N	\N
4869	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4986	\N	\N	\N
4870	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4987	\N	\N	\N
4871	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4988	\N	\N	\N
4872	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4989	\N	\N	\N
4873	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4990	\N	\N	\N
4875	MEMBRE	2001-10-01 00:00:00	2004-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	4992	\N	\N	\N
4877	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4994	\N	\N	\N
4878	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4995	\N	\N	\N
4879	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4996	\N	\N	\N
4880	MEMBRE	2001-10-01 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	4997	\N	\N	\N
4881	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4998	\N	\N	\N
4882	MEMBRE	2001-10-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	4999	\N	\N	\N
4884	MEMBREBUR	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2136	8	\N	\N
4885	MEMBREBUR	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1418	9	\N	\N
4886	VICPDTDEU	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3138	3	\N	\N
4887	VICPDT	2001-10-01 00:00:00	2004-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	3143	3	\N	\N
4888	VICPDT	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3151	2	\N	\N
4889	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3141	9	\N	\N
4890	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	579	\N	\N	\N
4891	VICPDT	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3092	10	\N	\N
4892	VICPDT	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3081	8	\N	\N
4893	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1199	14	\N	\N
4919	PDT	2001-10-01 00:00:00	2004-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	569	1	\N	\N
4920	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1677	7	\N	\N
4928	MEMBRE	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	5031	\N	\N	\N
4929	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5032	\N	\N	\N
4931	MEMBRE	2001-10-01 00:00:00	2003-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	5033	\N	\N	\N
4932	MEMBRE	2001-09-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5034	\N	\N	\N
4933	MEMBRE	2001-09-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	5035	\N	\N	\N
4934	MEMBRE	2001-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	5036	\N	\N	\N
4935	MEMBRE	2001-09-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5037	\N	\N	\N
4936	VICPDT	2001-09-01 00:00:00	2004-08-31 00:00:00	ANCIEN	\N	\N	\N	\N	5038	5	\N	\N
4938	MEMBRE	2001-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5040	\N	\N	\N
4939	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5041	\N	\N	\N
4940	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5042	\N	\N	\N
4675	VICPDT	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4788	4	\N	\N
4942	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3341	3	\N	\N
4945	SECRET	2001-10-01 00:00:00	2004-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	3339	11	\N	\N
4946	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3359	17	\N	\N
4947	MEMBREBUR	2001-10-01 00:00:00	2004-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	3343	20	\N	\N
4948	MEMBREBUR	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1874	22	\N	\N
4949	MEMBREBUR	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3354	24	\N	\N
4950	MEMBREBUR	2001-10-01 00:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	3363	30	\N	\N
4951	MEMBREBUR	2001-10-01 00:00:00	2004-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	1068	27	\N	\N
4952	MEMBREBUR	2001-10-01 00:00:00	2004-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	1270	29	\N	\N
4953	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	3348	\N	\N	\N
4956	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5048	\N	\N	\N
4957	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5049	\N	\N	\N
4958	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5050	\N	\N	\N
4959	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5051	\N	\N	\N
4960	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5052	\N	\N	\N
4961	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5053	\N	\N	\N
4962	SECRET	2001-09-01 00:00:00	2002-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	5055	9	\N	\N
4963	MEMBRE	2001-10-01 00:00:00	2002-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	5062	\N	\N	\N
4964	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5063	\N	\N	\N
4966	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5065	\N	\N	\N
4967	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5066	\N	\N	\N
4968	PDT	2001-10-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	5067	1	\N	\N
4969	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5068	\N	\N	\N
4970	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5069	5	\N	\N
4971	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5070	\N	\N	\N
4972	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5073	\N	\N	\N
4973	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5074	\N	\N	\N
4974	SECRET	2001-10-01 00:00:00	2002-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	5075	8	\N	\N
4975	MEMBRE	2001-10-01 00:00:00	2007-09-25 00:00:00	ANCIEN	\N	\N	\N	\N	5076	\N	\N	\N
4976	SECRET	2001-09-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5077	6	\N	\N
4977	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5078	\N	\N	\N
4978	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5079	\N	\N	\N
4980	SECRET	2001-10-01 00:00:00	2004-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	5081	7	\N	\N
4981	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5082	\N	\N	\N
4982	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5083	\N	\N	\N
4983	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5084	\N	\N	\N
4984	MEMBRE	2001-10-01 00:00:00	2003-03-30 00:00:00	ANCIEN	\N	\N	\N	\N	5085	\N	\N	\N
4987	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5088	\N	\N	\N
4988	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5089	\N	\N	\N
4989	VICPDT	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5091	5	\N	\N
4990	VICPDT	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5092	5	\N	\N
4991	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5093	\N	\N	\N
4993	MEMBRE	2001-10-01 00:00:00	2004-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	5095	\N	\N	\N
4994	VICPDT	2001-10-01 00:00:00	2004-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	5096	5	\N	\N
4995	SECRET	2001-10-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	5097	8	\N	\N
4996	MEMBRE	2001-10-01 00:00:00	2003-03-30 00:00:00	ANCIEN	\N	\N	\N	\N	5098	\N	\N	\N
4997	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5101	\N	\N	\N
4998	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5102	\N	\N	\N
4999	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5103	\N	\N	\N
5001	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5105	\N	\N	\N
5003	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5107	\N	\N	\N
5004	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5108	\N	\N	\N
5006	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5111	\N	\N	\N
5007	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5112	\N	\N	\N
5008	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5113	\N	\N	\N
5010	MEMBRE	2001-10-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	5115	\N	\N	\N
5012	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5117	\N	\N	\N
5014	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5119	\N	\N	\N
5015	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5120	\N	\N	\N
5016	MEMBRE	2001-10-01 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	5121	\N	\N	\N
4786	SECRET	2001-10-01 00:00:00	2004-11-09 00:00:00	ANCIEN	\N	\N	\N	\N	4901	20	\N	\N
4794	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4910	\N	\N	\N
4803	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4919	\N	\N	\N
4807	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4923	\N	\N	\N
4811	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4927	\N	\N	\N
4816	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4932	\N	\N	\N
5000	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5104	\N	\N	\N
5005	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5109	\N	\N	\N
5009	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5114	\N	\N	\N
5013	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5118	\N	\N	\N
5019	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5126	\N	\N	\N
5020	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5127	\N	\N	\N
5021	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5128	\N	\N	\N
5022	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5129	\N	\N	\N
5024	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5131	\N	\N	\N
5025	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5132	\N	\N	\N
5026	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5133	\N	\N	\N
5027	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5134	\N	\N	\N
5028	MEMBRE	2001-10-01 00:00:00	2003-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	5135	\N	\N	\N
5029	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5136	\N	\N	\N
5030	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5137	\N	\N	\N
5031	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5138	\N	\N	\N
5033	MEMBRE	2001-10-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	5140	\N	\N	\N
5034	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5141	\N	\N	\N
5035	MEMBRE	2001-10-01 00:00:00	2004-11-24 00:00:00	ANCIEN	\N	\N	\N	\N	5142	\N	\N	\N
5036	MEMBRE	2001-10-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	5143	\N	\N	\N
5037	MEMBRE	2001-10-01 00:00:00	2004-11-24 00:00:00	ANCIEN	\N	\N	\N	\N	5144	\N	\N	\N
5038	VICPDT	2001-10-01 00:00:00	2002-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	5145	6	\N	\N
5039	MEMBRE	2001-10-01 00:00:00	2004-11-24 00:00:00	ANCIEN	\N	\N	\N	\N	5146	\N	\N	\N
5040	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5147	\N	\N	\N
5041	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5148	\N	\N	\N
5042	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5149	\N	\N	\N
5043	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5150	\N	\N	\N
5044	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5151	\N	\N	\N
5045	MEMBRE	2001-10-01 00:00:00	2004-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	5152	\N	\N	\N
5047	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5154	\N	\N	\N
5048	MEMBRE	2001-10-01 00:00:00	2008-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	5155	\N	\N	\N
5049	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5156	\N	\N	\N
5050	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5157	\N	\N	\N
5051	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5158	\N	\N	\N
5053	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5160	\N	\N	\N
5054	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5161	\N	\N	\N
5055	MEMBREBUR	2001-10-01 00:00:00	2003-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	5162	16	\N	\N
5056	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5163	\N	\N	\N
5057	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5164	\N	\N	\N
5058	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5166	\N	\N	\N
5060	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5168	\N	\N	\N
5061	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5169	\N	\N	\N
5062	MEMBRE	2001-10-01 00:00:00	2004-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	5170	\N	\N	\N
5722	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5783	\N	\N	\N
5723	PDTDEL	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	Suède	\N	5784	5	\N	\N
5724	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5785	\N	\N	\N
5725	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5786	\N	\N	\N
5726	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5787	\N	\N	\N
5727	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5788	\N	\N	\N
5728	MEMBRE	2001-10-01 00:00:00	2004-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	5789	\N	\N	\N
5730	VICPDT	2001-10-01 00:00:00	2008-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	5791	2	\N	\N
5731	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5792	\N	\N	\N
5732	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5793	\N	\N	\N
5733	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5794	\N	\N	\N
5735	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5796	\N	\N	\N
5736	TRESOR	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5797	14	\N	\N
5737	MEMBRE	2001-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	5798	\N	\N	\N
5738	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5799	\N	\N	\N
5739	VICPDT	2001-10-01 00:00:00	2009-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	5800	7	\N	\N
5740	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5801	\N	\N	\N
5742	PDT	2001-10-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	2668	1	\N	\N
5743	PDTDEL	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Namibie	\N	1275	5	\N	\N
5403	PDTDEL	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	Zimbabwe	\N	5450	7	\N	\N
5744	VICPDTPRE	2001-10-01 00:00:00	2009-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	210	10	\N	\N
5745	VICPDT	2001-10-01 00:00:00	2007-11-13 00:00:00	ANCIEN	\N	\N	\N	\N	1527	11	\N	\N
5746	VICPDT	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	620	13	\N	\N
5747	SECRET	2001-10-01 00:00:00	2008-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	5457	15	\N	\N
5748	SECRET	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1567	16	\N	\N
5749	SECRET	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1275	19	\N	\N
5751	PDTDEL	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Gabon	\N	2766	9	\N	\N
5752	PDTDEL	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	Rwanda	\N	2763	10	\N	\N
5753	PDTDEL	2001-10-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	Saint-Thomas et Prince	\N	2775	13	\N	\N
5457	SECRET	2001-10-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	5505	15	\N	\N
5754	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2760	\N	\N	\N
5756	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4274	4	\N	\N
5757	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4278	6	\N	\N
5758	TRESOR	2001-10-01 00:00:00	2004-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	4295	12	\N	\N
5759	SECGEN	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2199	8	\N	\N
5760	TRESOR	2001-10-01 00:00:00	2008-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	2854	11	\N	\N
5775	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5818	\N	\N	\N
5788	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5833	\N	\N	\N
5777	MEMBRE	1998-10-01 00:00:00	2004-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	5820	\N	\N	\N
5778	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5821	\N	\N	\N
5779	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5822	\N	\N	\N
5780	MEMBRE	1998-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5823	\N	\N	\N
5781	MEMBRE	1998-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	5824	\N	\N	\N
5782	VICPDT	2001-10-01 00:00:00	2004-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	5825	6	\N	\N
5783	MEMBRE	1998-10-01 00:00:00	2004-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	5826	\N	\N	\N
5785	MEMBRE	1998-10-01 00:00:00	2004-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	5828	\N	\N	\N
5786	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5829	\N	\N	\N
5774	MEMBRE	1998-10-01 00:00:00	2004-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	5817	\N	\N	\N
5787	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5825	\N	\N	\N
5789	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5834	\N	\N	\N
5790	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5835	\N	\N	\N
5791	MEMBRE	1998-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5836	\N	\N	\N
5792	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5837	\N	\N	\N
4385	MEMBRE	2001-04-26 00:00:00	2007-02-25 00:00:00	ANCIEN	\N	\N	\N	\N	4494	\N	\N	\N
4386	MEMBRE	2001-04-22 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	\N	4495	\N	\N	\N
4387	MEMBRE	2001-06-26 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4496	\N	\N	\N
4389	PDT	2001-07-19 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4498	1	\N	\N
4392	MEMBRE	2000-12-12 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4500	\N	\N	\N
4395	VICPDT	2000-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4503	2	\N	\N
4396	MEMBRE	2000-12-15 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4504	\N	\N	\N
4397	MEMBRE	2000-12-15 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4505	\N	\N	\N
4402	MEMBRE	2001-12-20 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4510	\N	\N	\N
4399	MEMBRE	2000-12-15 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4507	\N	\N	\N
4401	MEMBRE	2000-12-12 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	4509	\N	\N	\N
4403	MEMBRE	2000-12-10 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4511	\N	\N	\N
4404	MEMBRE	2000-12-12 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4512	\N	\N	\N
4406	MEMBRE	2000-12-14 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4514	\N	\N	\N
4409	MEMBRE	2000-12-11 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4518	\N	\N	\N
4410	MEMBRE	2000-12-12 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	4519	\N	\N	\N
4412	MEMBRE	2000-12-11 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4521	\N	\N	\N
4413	MEMBRE	2000-12-19 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4522	\N	\N	\N
4415	MEMBRE	2000-12-13 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4524	\N	\N	\N
4418	MEMBRE	2000-12-14 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4527	\N	\N	\N
4419	MEMBRE	2000-12-20 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4528	\N	\N	\N
4422	MEMBRE	2000-12-12 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4531	\N	\N	\N
4423	MEMBRE	2000-12-12 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4532	\N	\N	\N
4424	MEMBRE	2000-12-18 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4533	\N	\N	\N
4425	MEMBRE	2000-12-12 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4534	\N	\N	\N
4426	PDT	2000-12-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4535	1	\N	\N
4428	MEMBRE	2000-12-14 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4537	\N	\N	\N
4429	MEMBRE	2000-12-13 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4538	\N	\N	\N
4430	MEMBRE	2001-01-04 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4539	\N	\N	\N
4431	MEMBRE	2000-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4540	\N	\N	\N
4432	VICPDT	2000-12-14 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	4541	4	\N	\N
4433	MEMBRE	2000-12-14 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4542	\N	\N	\N
4436	MEMBRE	2000-12-13 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4545	\N	\N	\N
4437	MEMBRE	2001-01-10 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4546	\N	\N	\N
4438	MEMBRE	2000-12-19 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4547	\N	\N	\N
4439	MEMBRE	2000-12-12 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4548	\N	\N	\N
4440	VICPDT	2000-12-12 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4549	5	\N	\N
4441	MEMBRE	2000-12-12 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4550	\N	\N	\N
4442	MEMBRE	2000-12-12 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4551	\N	\N	\N
4443	MEMBRE	2000-12-11 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	4552	\N	\N	\N
4444	MEMBRE	2000-12-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4553	\N	\N	\N
4445	MEMBRE	2000-12-19 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4554	\N	\N	\N
4446	MEMBRE	2000-12-26 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4555	\N	\N	\N
4447	MEMBRE	2000-12-12 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4556	\N	\N	\N
4448	MEMBRE	2000-12-12 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4557	\N	\N	\N
4449	MEMBRE	2000-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4558	\N	\N	\N
4450	VICPDT	2001-01-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4559	5	\N	\N
4451	VICPDT	2000-12-20 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4560	7	\N	\N
4452	MEMBRE	2000-12-22 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4561	\N	\N	\N
4453	MEMBRE	2000-12-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4562	\N	\N	\N
4454	MEMBRE	2000-12-13 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4563	\N	\N	\N
4455	MEMBRE	2000-12-12 00:00:00	2004-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	4564	\N	\N	\N
4457	VICPDT	2000-12-14 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4566	8	\N	\N
4458	MEMBRE	2000-12-11 00:00:00	2000-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4567	\N	\N	\N
4459	MEMBRE	2000-12-13 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4568	\N	\N	\N
4460	MEMBRE	2000-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4569	\N	\N	\N
4461	MEMBRE	2000-12-15 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4570	\N	\N	\N
4462	MEMBRE	2000-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4571	\N	\N	\N
4463	MEMBRE	2000-12-12 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	4572	\N	\N	\N
4464	MEMBRE	2000-12-13 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4573	\N	\N	\N
4465	MEMBRE	2000-12-11 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4574	\N	\N	\N
2990	MEMBRE	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	3029	\N	\N	\N
3083	VICPDT	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	3126	4	\N	\N
2724	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2747	4	\N	\N
2662	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2675	10	\N	\N
3340	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3403	\N	\N	\N
3129	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3172	\N	\N	\N
3433	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3499	5	\N	\N
3532	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3602	\N	\N	\N
3924	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3967	\N	\N	\N
3622	MEMBRE	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	3694	\N	\N	\N
3718	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3794	8	\N	\N
2812	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2840	\N	\N	\N
3929	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3972	\N	\N	\N
3165	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3209	\N	\N	\N
3341	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3404	\N	\N	\N
3899	VICPDT	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	3941	4	\N	\N
2971	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3008	\N	\N	\N
2701	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2722	5	\N	\N
3514	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3584	\N	\N	\N
3087	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3130	\N	\N	\N
3667	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3740	\N	\N	\N
1014	MEMBRE	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	1014	\N	\N	\N
3499	VICPDT	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	3569	2	\N	\N
3714	VICPDT	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	3790	2	\N	\N
2705	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2726	\N	\N	\N
3086	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3129	\N	\N	\N
3644	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3716	\N	\N	\N
5063	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5171	\N	\N	\N
5064	MEMBRE	2001-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5172	\N	\N	\N
5065	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5173	\N	\N	\N
5066	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5174	\N	\N	\N
5067	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5175	\N	\N	\N
5222	VICPDT	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2565	4	\N	\N
5223	VICPDT	2001-10-01 00:00:00	2008-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	3530	7	\N	\N
5224	TRESOR	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1272	11	\N	\N
5226	VICPDT	2001-10-01 00:00:00	2004-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	887	2	\N	\N
5228	SECRET	2001-10-01 01:00:00	2002-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	1554	6	\N	\N
5229	SECRET	2001-10-01 00:00:00	2002-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	581	7	\N	\N
5230	MEMBRE	2001-10-01 00:00:00	2002-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	1726	\N	\N	\N
5231	VICPDT	2001-10-01 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	2094	\N	\N	\N
5232	VICPDT	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	324	8	\N	\N
5233	VICPDT	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2553	7	\N	\N
5234	SECRET	2001-10-01 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	1118	10	\N	\N
5235	SECRET	2001-10-01 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	4005	\N	\N	\N
5236	SECRET	2001-10-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	\N	4016	14	\N	\N
4986	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5087	9	\N	\N
5240	MEMBRE	2001-10-01 00:00:00	2004-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	5300	\N	\N	\N
5241	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5301	\N	\N	\N
5242	MEMBRE	2001-10-01 00:00:00	2010-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	5302	\N	\N	\N
5243	SECRET	2001-10-01 00:00:00	2004-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	5303	7	\N	\N
5244	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5304	\N	\N	\N
5245	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5305	\N	\N	\N
5246	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5306	\N	\N	\N
5247	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5307	\N	\N	\N
5248	VICPDT	2001-10-01 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	\N	5308	8	\N	\N
5249	MEMBRE	2001-10-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	5309	\N	\N	\N
5250	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5310	\N	\N	\N
5252	VICPDT	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5313	7	\N	\N
5253	PDTDEL	2001-10-01 00:00:00	2004-11-22 00:00:00	ANCIEN	\N	\N	Emirats arabes unis	\N	5314	4	\N	\N
5254	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5315	\N	\N	\N
5255	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5316	9	\N	\N
5256	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5317	\N	\N	\N
5257	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5318	\N	\N	\N
5258	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5319	8	\N	\N
5068	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5176	\N	\N	\N
5069	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5177	\N	\N	\N
5070	MEMBREBUR	2001-10-01 00:00:00	2003-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	5178	15	\N	\N
5071	MEMBRE	2001-10-01 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	5179	\N	\N	\N
5072	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5180	\N	\N	\N
5073	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5181	\N	\N	\N
5075	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5183	\N	\N	\N
5076	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5184	\N	\N	\N
5077	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5185	\N	\N	\N
5079	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5187	\N	\N	\N
5080	VICPDT	2001-10-01 00:00:00	2004-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	5188	5	\N	\N
5081	MEMBRE	2001-10-01 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	5189	\N	\N	\N
5087	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5195	\N	\N	\N
5088	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5196	\N	\N	\N
5089	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5198	\N	\N	\N
5090	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5199	\N	\N	\N
5092	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5201	\N	\N	\N
5093	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5202	\N	\N	\N
5094	MEMBRE	2001-10-01 00:00:00	2009-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	5203	\N	\N	\N
5096	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5205	\N	\N	\N
5098	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5207	\N	\N	\N
5100	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5209	\N	\N	\N
5102	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5211	\N	\N	\N
5104	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5213	\N	\N	\N
5105	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5214	\N	\N	\N
5106	MEMBRE	2001-10-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	\N	5215	\N	\N	\N
5107	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5216	\N	\N	\N
5109	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5218	\N	\N	\N
5111	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5220	10	\N	\N
5113	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5222	\N	\N	\N
5114	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5223	\N	\N	\N
5115	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5224	\N	\N	\N
5116	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5225	\N	\N	\N
5117	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5226	\N	\N	\N
5119	SECRET	2001-10-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	5228	10	\N	\N
5120	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5229	\N	\N	\N
5122	VICPDT	2001-10-01 00:00:00	2002-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	5231	6	\N	\N
5123	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5232	\N	\N	\N
5125	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5234	\N	\N	\N
5126	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5235	\N	\N	\N
5127	MEMBRE	2001-10-01 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	\N	5236	\N	\N	\N
5128	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5237	\N	\N	\N
5129	MEMBRE	2001-10-01 00:00:00	2004-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	5238	\N	\N	\N
5130	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5239	\N	\N	\N
5131	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5240	\N	\N	\N
5132	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5241	\N	\N	\N
5133	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5242	\N	\N	\N
5134	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5243	\N	\N	\N
5135	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5244	\N	\N	\N
5136	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5245	\N	\N	\N
5137	MEMBRE	2001-10-01 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	5246	\N	\N	\N
5187	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	361	6	\N	\N
5188	SECRET	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1409	10	\N	\N
5140	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5249	\N	\N	\N
5141	MEMBRE	2001-10-01 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	5250	\N	\N	\N
5142	MEMBRE	2001-10-01 00:00:00	2002-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5251	\N	\N	\N
5143	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5252	\N	\N	\N
5144	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5253	\N	\N	\N
5145	MEMBRE	2001-10-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	5254	\N	\N	\N
5147	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5256	\N	\N	\N
5148	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5257	\N	\N	\N
5149	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5258	\N	\N	\N
5150	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5259	\N	\N	\N
5151	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5260	\N	\N	\N
5153	MEMBRE	2001-10-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	5262	\N	\N	\N
5154	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5263	\N	\N	\N
5155	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5264	\N	\N	\N
5156	MEMBRE	2001-10-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	5265	\N	\N	\N
5157	MEMBRE	2001-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	5266	\N	\N	\N
5158	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5267	\N	\N	\N
5159	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5268	\N	\N	\N
5160	MEMBRE	2001-10-01 00:00:00	2007-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	5269	\N	\N	\N
5161	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5270	\N	\N	\N
5162	MEMBRE	2001-10-01 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	\N	5271	\N	\N	\N
5163	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5272	\N	\N	\N
5164	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5273	\N	\N	\N
5165	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5274	\N	\N	\N
5166	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5275	\N	\N	\N
5167	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5276	\N	\N	\N
5168	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5277	\N	\N	\N
5169	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5278	\N	\N	\N
5170	MEMBRE	2001-10-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	5279	\N	\N	\N
5171	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5280	\N	\N	\N
5172	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5281	\N	\N	\N
5173	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5282	\N	\N	\N
5174	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5283	\N	\N	\N
5175	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5284	\N	\N	\N
5176	SECRET	2001-10-01 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	\N	5285	\N	\N	\N
5177	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5286	\N	\N	\N
5178	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5287	\N	\N	\N
5179	SECRET	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5288	17	\N	\N
5180	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5289	\N	\N	\N
5181	MEMBRE	2001-10-01 00:00:00	2004-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	5290	\N	\N	\N
5182	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5291	\N	\N	\N
5189	SECRET	2001-10-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	2264	\N	\N	\N
5190	SECRET	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2566	14	\N	\N
5192	SECRET	2001-10-01 00:00:00	2003-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	3877	6	\N	\N
5194	MEMBREBUR	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3861	10	\N	\N
5195	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5294	\N	\N	\N
5196	SECRET	2001-10-01 00:00:00	2007-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	5295	12	\N	\N
5197	MEMBRE	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	5296	\N	\N	\N
5198	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5297	\N	\N	\N
5199	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5298	\N	\N	\N
5201	VICPDT	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4052	4	\N	\N
5202	VICPDT	2001-10-01 00:00:00	2002-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	208	4	\N	\N
5078	VICPDT	2001-10-01 00:00:00	2004-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	5186	4	\N	\N
5082	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5190	\N	\N	\N
5086	VICPDT	2001-10-01 00:00:00	2004-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	5194	3	\N	\N
5091	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5200	\N	\N	\N
5099	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5208	\N	\N	\N
5103	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5212	\N	\N	\N
5108	MEMBRE	2001-10-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	5217	\N	\N	\N
5112	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5221	\N	\N	\N
5203	VICPDT	2001-10-01 00:00:00	2003-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	3016	7	\N	\N
5204	SECRET	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3021	10	\N	\N
5205	SECRET	2001-10-01 00:00:00	2003-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	3001	12	\N	\N
5208	VICPDT	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1559	3	\N	\N
5209	VICPDT	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3328	4	\N	\N
5210	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2365	4	\N	\N
5211	SECRET	2001-10-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	1999	12	\N	\N
5212	MEMBRE	2001-10-01 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	3324	\N	\N	\N
5213	MEMBRE	2001-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	558	\N	\N	\N
5214	MEMBRE	2001-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1775	\N	\N	\N
5215	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3329	\N	\N	\N
5216	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	353	6	\N	\N
5217	PDTDEL	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Kazakhstan	\N	2540	3	\N	\N
5219	SECRET	2001-10-01 00:00:00	2009-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	1423	15	\N	\N
5220	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1710	\N	\N	\N
4644	VICPDT	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4753	4	\N	\N
5221	VICPDTDRT	2001-10-01 00:00:00	2004-10-26 00:00:00	ANCIEN	\N	\N	Mexique et pays d'Amérique centrale	\N	2532	2	\N	\N
4733	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4846	\N	\N	\N
4734	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4847	\N	\N	\N
4735	MEMBRE	2001-10-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	4848	\N	\N	\N
4736	MEMBRE	2001-10-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	4849	\N	\N	\N
4738	TRESOR	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4851	7	\N	\N
4739	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4852	\N	\N	\N
4740	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4853	\N	\N	\N
1131	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1131	\N	\N	\N
1137	SECRET	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1137	14	\N	\N
1142	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1142	\N	\N	\N
1147	MEMBRE	1998-10-01 00:00:00	2003-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	1147	\N	\N	\N
1152	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1152	\N	\N	\N
1157	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1157	\N	\N	\N
1163	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1163	\N	\N	\N
1169	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1169	\N	\N	\N
1176	MEMBRE	1998-10-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	\N	1176	\N	\N	\N
1183	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1183	\N	\N	\N
1085	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1085	\N	\N	\N
983	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	983	\N	\N	\N
988	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	988	\N	\N	\N
6576	SECRET	2002-12-03 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5991	14	\N	\N
6579	MEMBRE	2002-12-01 00:00:00	2007-02-25 00:00:00	ANCIEN	\N	\N	\N	\N	6448	\N	\N	\N
6580	PDT	2002-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6433	1	\N	\N
6581	PDTDEL	2002-12-10 00:00:00	2009-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	2871	\N	\N	\N
6583	SECRET	2002-12-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1718	9	\N	\N
6585	MEMBRE	2002-12-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	6451	\N	\N	\N
6586	MEMBRE	2002-12-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	6452	\N	\N	\N
6587	MEMBRE	2002-12-01 00:00:00	2005-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	6453	\N	\N	\N
6588	MEMBRE	2002-12-01 00:00:00	2007-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	6454	\N	\N	\N
6589	MEMBRE	2002-12-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6455	\N	\N	\N
6590	MEMBRE	2002-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6456	\N	\N	\N
6591	MEMBRE	2002-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6457	\N	\N	\N
6592	MEMBRE	2002-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6458	\N	\N	\N
6593	MEMBRE	2002-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6459	\N	\N	\N
6594	MEMBRE	2002-12-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6460	\N	\N	\N
6595	PDTDEL	2002-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	Djibouti	\N	6461	3	\N	\N
6596	MEMBRE	2002-12-01 00:00:00	2004-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	6462	\N	\N	\N
6597	MEMBRE	2002-12-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6463	\N	\N	\N
6599	MEMBRE	2002-12-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	6465	\N	\N	\N
6600	PDTDEL	2002-12-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	Erythrée	\N	6466	4	\N	\N
6601	TRESOR	2002-12-01 00:00:00	2004-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	6467	5	\N	\N
6602	SECRET	2002-12-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6468	8	\N	\N
6603	MEMBRE	2002-12-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6469	\N	\N	\N
6604	MEMBRE	2002-12-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6470	\N	\N	\N
6605	PDT	2003-01-27 00:00:00	2009-10-26 00:00:00	ANCIEN	\N	\N	\N	\N	6471	1	\N	\N
6606	MEMBRE	2003-01-15 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6472	\N	\N	\N
6607	MEMBRE	2003-01-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6473	\N	\N	\N
6609	MEMBRE	2002-04-07 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6475	\N	\N	\N
6611	VICPDT	2002-07-01 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	6477	3	\N	\N
6612	MEMBRE	2002-07-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6478	\N	\N	\N
6613	MEMBRE	2002-07-01 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	6479	\N	\N	\N
6614	VICPDT	2002-07-01 00:00:00	2005-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	6480	2	\N	\N
6615	MEMBRE	2002-07-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6481	\N	\N	\N
6616	VICPDT	2002-07-01 00:00:00	2005-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	6482	4	\N	\N
6617	MEMBRE	2002-07-01 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	6483	\N	\N	\N
6618	VICPDT	2002-07-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6484	5	\N	\N
6619	MEMBRE	2002-07-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6485	\N	\N	\N
6621	MEMBRE	2002-07-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6487	\N	\N	\N
6622	PDT	2002-07-01 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	6488	1	\N	\N
6623	MEMBRE	2002-07-01 00:00:00	2005-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	6489	\N	\N	\N
6624	MEMBRE	2002-07-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6490	\N	\N	\N
6625	MEMBRE	2003-01-29 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3016	\N	\N	\N
6626	VICPDT	2003-01-29 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2998	7	\N	\N
6627	SECRET	2003-01-29 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	5162	12	\N	\N
6628	TRESOR	2003-01-29 00:00:00	2003-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3001	13	\N	\N
6629	MEMBRE	2003-01-29 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3020	\N	\N	\N
6630	MEMBRE	2003-01-29 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5172	\N	\N	\N
6632	MEMBRE	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	6188	\N	\N	\N
6633	MEMBRE	2003-04-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6491	\N	\N	\N
6634	MEMBRE	2003-01-01 00:00:00	2004-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	6492	\N	\N	\N
6635	MEMBRE	2003-04-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6493	\N	\N	\N
6636	MEMBRE	2003-04-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6494	\N	\N	\N
6637	MEMBRE	2003-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6495	\N	\N	\N
6638	MEMBRE	2003-04-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6496	\N	\N	\N
6639	MEMBRE	2003-04-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6497	\N	\N	\N
6641	MEMBRE	2003-04-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6499	\N	\N	\N
6643	MEMBRE	2003-04-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6501	\N	\N	\N
6644	MEMBRE	2003-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6502	\N	\N	\N
6645	MEMBRE	2003-04-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6503	\N	\N	\N
6646	MEMBRE	2003-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6504	\N	\N	\N
6647	MEMBRE	2003-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6505	\N	\N	\N
6648	MEMBRE	2003-04-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6506	\N	\N	\N
6649	MEMBRE	2003-04-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6507	\N	\N	\N
6650	MEMBRE	2003-04-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6508	\N	\N	\N
6652	MEMBRE	2003-04-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6510	\N	\N	\N
6653	MEMBRE	2003-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6511	\N	\N	\N
6655	MEMBRE	2003-04-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6513	\N	\N	\N
6656	MEMBRE	2003-04-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6514	\N	\N	\N
6657	MEMBRE	2003-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6515	\N	\N	\N
6658	MEMBRE	2003-04-01 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	6516	0	\N	\N
6659	MEMBRE	2003-04-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6517	\N	\N	\N
6660	MEMBRE	2003-04-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6518	\N	\N	\N
6661	MEMBRE	2003-04-01 00:00:00	2007-02-25 00:00:00	ANCIEN	\N	\N	\N	\N	6519	\N	\N	\N
6662	MEMBRE	2003-04-01 00:00:00	2003-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	6520	\N	\N	\N
6663	MEMBRE	2003-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6521	\N	\N	\N
6664	MEMBRE	2003-04-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6522	\N	\N	\N
6666	MEMBRE	2003-04-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6524	\N	\N	\N
6668	MEMBRE	2003-04-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6526	\N	\N	\N
6669	MEMBRE	2003-04-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6527	\N	\N	\N
6670	MEMBRE	2003-04-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6528	\N	\N	\N
6671	MEMBRE	2003-04-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6529	\N	\N	\N
6672	MEMBRE	2003-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6530	\N	\N	\N
6673	MEMBRE	2003-04-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	6531	\N	\N	\N
6674	MEMBRE	2003-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6532	\N	\N	\N
6675	MEMBRE	2003-04-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	6533	\N	\N	\N
6676	MEMBRE	2003-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6534	\N	\N	\N
6677	MEMBRE	2003-04-01 00:00:00	2003-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	6535	\N	\N	\N
6678	MEMBRE	2003-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6536	\N	\N	\N
6679	MEMBRE	2003-04-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6537	\N	\N	\N
6680	MEMBRE	2003-04-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	6538	\N	\N	\N
6681	MEMBRE	2003-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6539	\N	\N	\N
6682	MEMBRE	2003-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6540	\N	\N	\N
6684	MEMBRE	2003-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6542	\N	\N	\N
6685	MEMBRE	2003-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6543	\N	\N	\N
6686	MEMBRE	2003-04-01 00:00:00	2004-10-26 00:00:00	ANCIEN	\N	\N	\N	\N	6544	\N	\N	\N
6687	MEMBRE	2003-04-01 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	\N	6545	\N	\N	\N
6689	SECRET	2003-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5085	8	\N	\N
6690	MEMBRE	2003-03-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6546	\N	\N	\N
6691	MEMBRE	2003-03-21 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	6547	\N	\N	\N
6692	MEMBRE	2003-03-21 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6548	\N	\N	\N
6693	MEMBRE	2003-03-21 00:00:00	2003-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	6549	\N	\N	\N
6694	MEMBRE	2003-03-21 00:00:00	2003-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	6550	\N	\N	\N
6095	MEMBRE	1999-01-01 00:00:00	2004-10-19 00:00:00	ANCIEN	\N	\N	\N	\N	6024	\N	\N	\N
6097	MEMBRE	2001-10-17 00:00:00	2005-03-19 00:00:00	ANCIEN	\N	\N	\N	\N	6026	\N	\N	\N
6098	MEMBRE	2001-10-16 00:00:00	2004-10-19 00:00:00	ANCIEN	\N	\N	\N	\N	6027	\N	\N	\N
6099	MEMBRE	2001-10-27 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6028	\N	\N	\N
6100	SECRET	2001-10-27 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	6029	9	\N	\N
6102	MEMBRE	2001-10-27 00:00:00	2004-10-19 00:00:00	ANCIEN	\N	\N	\N	\N	6031	\N	\N	\N
6103	MEMBRE	2001-10-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6032	\N	\N	\N
6104	MEMBRE	2001-10-27 00:00:00	2004-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	6033	\N	\N	\N
6105	MEMBRE	2001-10-27 00:00:00	2004-10-19 00:00:00	ANCIEN	\N	\N	\N	\N	6034	\N	\N	\N
6110	MEMBRE	2001-10-17 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6037	\N	\N	\N
6111	MEMBRE	2001-10-17 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	\N	6038	\N	\N	\N
6114	MEMBRE	2001-10-17 00:00:00	2004-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	6039	\N	\N	\N
6115	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6041	\N	\N	\N
6116	MEMBRE	2001-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	6042	\N	\N	\N
6121	MEMBRE	2002-02-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6044	\N	\N	\N
6122	MEMBRE	2002-04-29 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6045	\N	\N	\N
6143	MEMBRE	2000-11-01 00:00:00	2004-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	6073	\N	\N	\N
6144	MEMBRE	2000-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6074	\N	\N	\N
6145	MEMBRE	2000-11-01 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	6075	\N	\N	\N
6146	MEMBRE	2000-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6076	\N	\N	\N
6147	MEMBRE	2000-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6077	\N	\N	\N
6148	MEMBRE	2000-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6078	\N	\N	\N
6149	MEMBRE	2000-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6079	\N	\N	\N
6151	MEMBRE	2000-11-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6081	\N	\N	\N
6152	MEMBRE	2000-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6082	\N	\N	\N
6153	MEMBRE	2000-11-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6083	\N	\N	\N
6154	MEMBRE	2000-11-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	6084	\N	\N	\N
6155	MEMBRE	2000-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6085	\N	\N	\N
6157	SECRET	2001-11-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6092	12	\N	\N
6158	MEMBRE	2000-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6093	\N	\N	\N
6159	MEMBRE	2000-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6094	\N	\N	\N
6160	MEMBRE	2000-11-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6095	\N	\N	\N
6161	MEMBRE	2000-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6096	\N	\N	\N
6162	MEMBRE	2000-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6091	\N	\N	\N
6164	MEMBRE	2000-11-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6099	\N	\N	\N
6165	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6100	\N	\N	\N
6166	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6101	\N	\N	\N
6167	PDT	2002-01-23 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	6102	1	\N	\N
6168	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6103	\N	\N	\N
6169	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6104	\N	\N	\N
6170	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6105	\N	\N	\N
6171	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6106	\N	\N	\N
6172	SECRET	2002-01-23 00:00:00	2004-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	6107	14	\N	\N
6173	MEMBREBUR	2002-01-23 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6108	19	\N	\N
6175	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6110	\N	\N	\N
6176	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6111	\N	\N	\N
6178	MEMBRE	1999-01-01 00:00:00	2004-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	6113	\N	\N	\N
6179	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6114	\N	\N	\N
6180	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6115	\N	\N	\N
6181	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6116	\N	\N	\N
6182	MEMBRE	1999-01-01 00:00:00	2002-10-22 00:00:00	ANCIEN	\N	\N	\N	\N	6117	\N	\N	\N
6183	SECRET	2002-01-23 00:00:00	2004-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	6118	12	\N	\N
6184	VICPDT	2002-01-23 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6119	7	\N	\N
6185	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6120	\N	\N	\N
6186	MEMBRE	1999-01-01 00:00:00	2009-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	6121	0	\N	\N
6188	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6123	\N	\N	\N
6189	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6124	\N	\N	\N
6190	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6125	\N	\N	\N
6191	MEMBREBUR	2002-01-09 00:00:00	2004-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	6126	17	\N	\N
6192	SECRET	2002-01-09 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	6127	10	\N	\N
6193	SECRET	2002-01-09 00:00:00	2004-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	6128	13	\N	\N
6194	MEMBRE	1999-01-01 00:00:00	2004-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	6129	\N	\N	\N
6195	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6130	\N	\N	\N
6196	VICPDT	2002-01-09 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6131	4	\N	\N
6198	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6133	\N	\N	\N
6199	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6134	\N	\N	\N
6201	MEMBRE	1999-01-01 00:00:00	2004-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	6136	\N	\N	\N
6202	VICPDT	2002-01-09 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6137	5	\N	\N
6203	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6138	\N	\N	\N
6204	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6139	\N	\N	\N
6206	MEMBRE	1999-01-01 00:00:00	2004-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	6141	\N	\N	\N
6208	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6143	\N	\N	\N
6209	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6144	\N	\N	\N
6210	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6145	\N	\N	\N
6211	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6146	\N	\N	\N
6212	PDTDEL	2001-12-18 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	Paraguay	\N	6147	10	\N	\N
6213	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6148	\N	\N	\N
6214	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6149	\N	\N	\N
6215	MEMBRE	1999-01-01 00:00:00	2004-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	6150	\N	\N	\N
6216	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6151	\N	\N	\N
6217	MEMBRE	1999-01-01 00:00:00	2007-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	6152	\N	\N	\N
6218	VICPDTDRT	2001-12-18 00:00:00	2009-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	6153	2	\N	\N
6219	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6154	\N	\N	\N
6220	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6155	\N	\N	\N
6221	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6156	\N	\N	\N
6222	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6157	\N	\N	\N
6223	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6158	\N	\N	\N
6224	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6159	\N	\N	\N
6225	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6160	\N	\N	\N
6226	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6161	\N	\N	\N
6227	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6162	\N	\N	\N
6228	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6163	\N	\N	\N
6229	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6164	\N	\N	\N
6230	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6165	\N	\N	\N
6231	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6166	\N	\N	\N
6232	MEMBRE	1999-01-01 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	6167	\N	\N	\N
6233	TRESOR	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6168	12	\N	\N
6234	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6169	\N	\N	\N
6235	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6170	\N	\N	\N
6236	MEMBRE	1999-01-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	6171	\N	\N	\N
6237	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6172	\N	\N	\N
6238	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6173	\N	\N	\N
6239	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6174	\N	\N	\N
6241	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6176	\N	\N	\N
6242	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6177	\N	\N	\N
6243	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6178	\N	\N	\N
6245	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6180	\N	\N	\N
6246	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6181	\N	\N	\N
6247	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6182	\N	\N	\N
6248	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6183	\N	\N	\N
6249	MEMBRE	1999-01-01 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	6184	\N	\N	\N
6250	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6185	\N	\N	\N
6251	MEMBRE	1999-01-01 00:00:00	2004-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	6186	\N	\N	\N
6252	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2878	\N	\N	\N
6253	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6189	0	\N	\N
6254	PDT	2002-02-20 00:00:00	2008-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	6190	1	\N	\N
6255	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6191	\N	\N	\N
6257	MEMBRE	1999-01-01 00:00:00	2002-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	6193	\N	\N	\N
6258	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6194	\N	\N	\N
6259	SECRET	2002-02-20 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6195	6	\N	\N
6260	VICPDT	2002-02-20 00:00:00	2008-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	6196	2	\N	\N
6261	VICPDT	2002-02-20 00:00:00	2004-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	6197	3	\N	\N
6262	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6198	\N	\N	\N
6263	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6199	\N	\N	\N
6264	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6200	\N	\N	\N
6265	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6201	\N	\N	\N
6266	SECRET	2002-02-20 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6203	6	\N	\N
6268	SECRET	2002-02-20 00:00:00	2004-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	2883	4	\N	\N
6269	SECRET	2002-02-20 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6193	5	\N	\N
6270	SECRET	2002-02-20 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1716	7	\N	\N
6273	PDTDEL	2001-12-18 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	Bolivie	\N	357	5	\N	\N
6274	PDTDEL	2001-12-18 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	Chili	\N	2845	7	\N	\N
6275	PDTDEL	2001-12-18 00:00:00	2009-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	1460	8	\N	\N
6276	PDTDEL	2001-12-18 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	Equateur	\N	647	9	\N	\N
6277	PDTDEL	2001-12-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	Pérou	\N	2818	11	\N	\N
6278	PDTDEL	2001-12-18 00:00:00	2009-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	2819	12	\N	\N
6279	PDTDEL	2001-12-18 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	Venezuela	\N	2346	13	\N	\N
6280	TRESOR	2001-12-18 00:00:00	2004-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	2319	14	\N	\N
6281	VICPDT	2002-01-23 00:00:00	2002-10-22 00:00:00	ANCIEN	\N	\N	\N	\N	2895	2	\N	\N
6282	VICPDT	2002-01-23 00:00:00	2004-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	2924	4	\N	\N
6283	SECRET	2002-01-23 00:00:00	2004-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	2902	9	\N	\N
6284	SECRET	2002-01-23 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2354	11	\N	\N
6285	MEMBREBUR	2002-01-23 00:00:00	2004-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	2320	16	\N	\N
6287	MEMBREBUR	2002-01-23 00:00:00	2002-10-22 00:00:00	ANCIEN	\N	\N	\N	\N	2930	17	\N	\N
6289	MEMBRE	2002-01-23 00:00:00	2004-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	2910	\N	\N	\N
6290	MEMBRE	2002-01-23 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2926	\N	\N	\N
6291	MEMBRE	2002-01-23 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2935	\N	\N	\N
6292	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2584	10	\N	\N
6293	VICPDT	2002-01-09 00:00:00	2009-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	3048	2	\N	\N
6294	SECRET	2002-01-09 00:00:00	2004-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	1480	12	\N	\N
6295	SECRET	2002-01-09 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1669	13	\N	\N
6296	PDT	2000-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4128	1	\N	\N
6297	VICPDT	2001-11-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4214	7	\N	\N
6298	VICPDT	2001-11-07 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4188	5	\N	\N
6299	MEMBRE	2001-11-07 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	4167	\N	\N	\N
6301	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6209	\N	\N	\N
2686	SECRET	1999-01-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	2704	7	\N	\N
4688	MEMBREBUR	2001-10-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	4801	23	\N	\N
6303	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6211	\N	\N	\N
6304	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6212	\N	\N	\N
6306	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6214	\N	\N	\N
6307	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6215	\N	\N	\N
6308	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6216	\N	\N	\N
6309	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6218	\N	\N	\N
6310	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6219	\N	\N	\N
6311	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6220	\N	\N	\N
6312	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6221	\N	\N	\N
6313	MEMBRE	2001-10-01 00:00:00	2004-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	6222	\N	\N	\N
6315	MEMBRE	2001-10-01 00:00:00	2004-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	6224	\N	\N	\N
6316	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6225	\N	\N	\N
6317	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6226	\N	\N	\N
6318	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6229	\N	\N	\N
6319	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6230	\N	\N	\N
6320	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6231	\N	\N	\N
6321	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6232	\N	\N	\N
6322	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6233	2	\N	\N
6323	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1244	\N	\N	\N
6324	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6235	\N	\N	\N
6325	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6236	8	\N	\N
6327	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6238	\N	\N	\N
6328	MEMBRE	2001-10-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	6239	\N	\N	\N
6329	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6240	\N	\N	\N
6330	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6241	\N	\N	\N
6331	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6242	\N	\N	\N
6332	MEMBRE	2001-10-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	\N	6243	\N	\N	\N
6333	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6244	\N	\N	\N
6334	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6245	\N	\N	\N
6335	MEMBRE	2001-10-01 00:00:00	2004-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	6246	\N	\N	\N
6336	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6247	\N	\N	\N
6337	MEMBRE	2001-10-01 00:00:00	2004-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	6248	\N	\N	\N
6338	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6249	7	\N	\N
6339	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6250	\N	\N	\N
6341	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6252	5	\N	\N
6342	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6253	\N	\N	\N
6343	MEMBRE	2001-10-01 00:00:00	2004-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	6254	\N	\N	\N
6344	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6255	\N	\N	\N
6345	MEMBRE	2001-10-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	\N	6256	\N	\N	\N
6346	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6257	\N	\N	\N
6347	MEMBRE	2000-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6258	\N	\N	\N
6348	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6210	\N	\N	\N
6349	VICPDT	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4218	2	\N	\N
6350	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4220	4	\N	\N
6062	MEMBRE	2001-10-01 00:00:00	2002-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	5991	\N	\N	\N
6063	MEMBRE	2000-11-23 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5992	\N	\N	\N
6064	MEMBRE	2000-11-23 00:00:00	2002-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	5993	\N	\N	\N
6065	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5994	\N	\N	\N
6067	MEMBRE	1999-01-01 00:00:00	2005-03-21 00:00:00	ANCIEN	\N	\N	\N	\N	5996	\N	\N	\N
6068	MEMBRE	1999-01-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	5997	\N	\N	\N
6069	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5999	\N	\N	\N
6070	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6000	\N	\N	\N
6071	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6001	\N	\N	\N
6072	MEMBRE	1999-01-01 00:00:00	2002-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	6002	\N	\N	\N
6073	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6003	\N	\N	\N
6074	MEMBRE	1999-01-01 00:00:00	2002-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	6004	\N	\N	\N
6075	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6005	\N	\N	\N
6076	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6006	\N	\N	\N
6077	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6007	\N	\N	\N
6078	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2693	\N	\N	\N
6080	MEMBRE	2001-10-25 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6009	\N	\N	\N
6081	MEMBRE	2001-10-25 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6010	\N	\N	\N
6082	MEMBRE	2001-10-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6011	\N	\N	\N
6083	MEMBRE	2001-10-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6012	\N	\N	\N
6085	MEMBRE	2001-10-18 00:00:00	2002-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6014	\N	\N	\N
6086	MEMBRE	2001-10-18 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6015	\N	\N	\N
6087	MEMBRE	2001-10-18 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	6016	\N	\N	\N
6088	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6017	\N	\N	\N
6089	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6018	\N	\N	\N
6090	MEMBRE	2001-10-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6019	\N	\N	\N
6091	MEMBRE	2001-10-17 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6020	\N	\N	\N
6092	MEMBRE	2001-10-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6021	\N	\N	\N
6093	MEMBRE	2001-10-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6022	\N	\N	\N
6695	MEMBRE	2003-03-21 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6551	\N	\N	\N
6696	MEMBRE	2003-03-21 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6552	\N	\N	\N
6697	MEMBRE	2003-03-21 00:00:00	2003-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	6553	\N	\N	\N
6698	MEMBRE	2003-03-21 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6555	\N	\N	\N
6699	MEMBRE	2003-03-21 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6556	\N	\N	\N
6701	MEMBRE	2003-03-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6558	\N	\N	\N
6702	MEMBRE	2003-05-02 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	6559	\N	\N	\N
2452	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2452	\N	\N	\N
6703	VICPDT	2003-05-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6550	2	\N	\N
6704	VICPDT	2003-05-26 00:00:00	2009-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	6553	\N	\N	\N
6705	VICPDT	2003-05-26 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6549	5	\N	\N
6706	SECRET	2003-05-26 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	2712	6	\N	\N
6708	MEMBRE	2003-05-26 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	2705	\N	\N	\N
6709	PDTDEL	2003-05-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Bahreïn	\N	6560	2	\N	\N
6710	MEMBRE	2003-06-25 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6561	\N	\N	\N
6711	MEMBRE	2001-10-01 00:00:00	2004-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	6562	\N	\N	\N
6712	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6563	\N	\N	\N
6714	MEMBRE	2001-10-01 00:00:00	2003-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	6565	\N	\N	\N
6715	MEMBRE	2001-10-01 00:00:00	2009-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	6566	\N	\N	\N
6716	MEMBRE	2001-10-01 00:00:00	2003-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	6567	\N	\N	\N
6717	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6568	\N	\N	\N
6718	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6569	\N	\N	\N
6719	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6570	\N	\N	\N
6720	MEMBRE	2001-10-01 00:00:00	2003-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	6571	\N	\N	\N
6722	MEMBRE	2001-10-01 00:00:00	2003-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	6573	\N	\N	\N
6725	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6576	\N	\N	\N
6726	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6577	\N	\N	\N
6727	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6578	\N	\N	\N
6728	MEMBRE	2001-10-01 00:00:00	2003-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	6579	\N	\N	\N
6729	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6580	\N	\N	\N
6730	MEMBRE	2001-10-01 00:00:00	2003-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	6581	\N	\N	\N
6731	MEMBRE	2001-10-01 00:00:00	2005-03-19 00:00:00	ANCIEN	\N	\N	\N	\N	6582	\N	\N	\N
6732	MEMBRE	2001-10-01 00:00:00	2003-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	6583	\N	\N	\N
6733	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6584	\N	\N	\N
6734	MEMBRE	2001-10-01 00:00:00	2003-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	6585	\N	\N	\N
6735	MEMBRE	2001-10-01 00:00:00	2004-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	6586	\N	\N	\N
6737	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6588	\N	\N	\N
6738	MEMBRE	2001-10-01 00:00:00	2004-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	6589	\N	\N	\N
6739	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6590	\N	\N	\N
6740	MEMBRE	2001-10-01 00:00:00	2004-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	6591	\N	\N	\N
6741	MEMBRE	2002-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6592	\N	\N	\N
6742	MEMBRE	2002-04-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6593	\N	\N	\N
6743	MEMBRE	2002-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6594	\N	\N	\N
6744	MEMBRE	2003-04-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6595	\N	\N	\N
6745	MEMBRE	2003-04-01 00:00:00	2007-02-25 00:00:00	ANCIEN	\N	\N	\N	\N	6596	\N	\N	\N
6746	MEMBRE	2003-04-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6597	\N	\N	\N
6747	MEMBRE	2003-04-01 00:00:00	2004-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	6598	\N	\N	\N
6748	MEMBRE	2003-04-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6599	\N	\N	\N
6749	MEMBRE	2003-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6600	\N	\N	\N
6750	PDT	2003-07-07 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6583	\N	\N	\N
6751	VICPDT	2003-07-07 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6564	\N	\N	\N
6752	VICPDT	2003-07-07 00:00:00	2009-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	6585	\N	\N	\N
6753	VICPDT	2003-07-07 00:00:00	2004-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	6571	\N	\N	\N
6754	VICPDT	2003-07-07 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6565	\N	\N	\N
6755	VICPDT	2003-07-07 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6567	\N	\N	\N
6756	VICPDT	2003-07-07 00:00:00	2004-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	6573	\N	\N	\N
6757	SECRET	2003-07-07 00:00:00	2004-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	6581	\N	\N	\N
6758	TRESOR	2003-07-07 00:00:00	2004-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	6579	\N	\N	\N
6760	PDTDEL	2002-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	Mali	\N	4597	11	\N	\N
6761	PDTDEL	2002-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	Mauritanie	\N	1530	12	\N	\N
6762	MEMBRE	2003-06-25 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6602	\N	\N	\N
6763	MEMBRE	2003-06-25 00:00:00	2004-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	6603	\N	\N	\N
6764	MEMBRE	2003-06-25 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6604	\N	\N	\N
6766	MEMBRE	2003-06-25 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6606	\N	\N	\N
6767	MEMBRE	2003-06-25 00:00:00	2004-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	6607	\N	\N	\N
6768	MEMBRE	2003-06-25 00:00:00	2004-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	6608	\N	\N	\N
3272	MEMBRE	1999-01-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	\N	3331	\N	\N	\N
4516	MEMBRE	2001-10-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	\N	4628	\N	\N	\N
7078	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7221	\N	\N	\N
7083	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7226	\N	\N	\N
7295	MEMBRE	2002-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7398	\N	\N	\N
7296	MEMBRE	2002-01-01 00:00:00	2002-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	7399	\N	\N	\N
7297	MEMBRE	2002-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7400	\N	\N	\N
7298	MEMBRE	2002-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7401	\N	\N	\N
7299	PDT	2002-01-02 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	7384	\N	\N	\N
7300	VICPDT	2002-01-02 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7392	\N	\N	\N
7302	VICPDT	2002-01-02 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7373	\N	\N	\N
7303	SECRET	2002-01-02 00:00:00	2007-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	7374	\N	\N	\N
7304	SECRET	2002-01-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7365	\N	\N	\N
7305	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7402	\N	\N	\N
5795	MEMBRE	1998-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5840	\N	\N	\N
5796	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5841	\N	\N	\N
5797	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5842	\N	\N	\N
5798	MEMBRE	1998-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	5843	\N	\N	\N
5799	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5844	\N	\N	\N
5800	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5845	\N	\N	\N
5802	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5847	\N	\N	\N
5803	MEMBRE	1998-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5848	\N	\N	\N
5804	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5849	\N	\N	\N
5805	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5850	\N	\N	\N
5806	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5851	\N	\N	\N
5808	MEMBRE	1998-10-01 00:00:00	2004-11-24 00:00:00	ANCIEN	\N	\N	\N	\N	5853	\N	\N	\N
5470	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5518	\N	\N	\N
5471	MEMBRE	2001-10-01 00:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	5520	\N	\N	\N
5473	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5522	\N	\N	\N
5474	MEMBRE	2001-10-01 00:00:00	2008-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	5523	\N	\N	\N
5475	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5524	\N	\N	\N
5476	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5525	\N	\N	\N
5478	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5527	3	\N	\N
5479	MEMBRE	2001-10-01 00:00:00	2004-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	5528	\N	\N	\N
5480	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5529	\N	\N	\N
5483	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5532	\N	\N	\N
5484	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5533	\N	\N	\N
5505	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5555	\N	\N	\N
5506	VICPDT	2001-10-01 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	5556	2	\N	\N
5507	SECRET	2001-10-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	\N	5557	8	\N	\N
5508	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5558	10	\N	\N
5509	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5559	\N	\N	\N
5510	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5560	\N	\N	\N
5511	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5561	\N	\N	\N
5512	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5562	\N	\N	\N
5513	MEMBRE	2001-10-01 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	5563	\N	\N	\N
5515	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5565	\N	\N	\N
5517	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5567	\N	\N	\N
5518	MEMBRE	2001-10-01 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	5568	\N	\N	\N
5519	MEMBRE	2001-10-01 00:00:00	2004-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	5569	\N	\N	\N
5520	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5570	\N	\N	\N
5521	VICPDT	2001-10-01 00:00:00	2004-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	5571	3	\N	\N
5522	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5572	\N	\N	\N
5523	MEMBRE	2001-10-01 00:00:00	2004-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	5573	\N	\N	\N
5526	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5576	\N	\N	\N
5527	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5577	\N	\N	\N
5528	MEMBRE	2001-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5578	\N	\N	\N
5529	MEMBRE	2001-10-01 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	5579	\N	\N	\N
5530	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5580	\N	\N	\N
5531	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5582	\N	\N	\N
5533	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5584	\N	\N	\N
5534	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5585	\N	\N	\N
5535	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5586	\N	\N	\N
5536	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5587	\N	\N	\N
5537	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5588	\N	\N	\N
5538	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5590	\N	\N	\N
5539	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5591	\N	\N	\N
5541	MEMBRE	2001-10-01 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	5593	\N	\N	\N
5542	MEMBRE	2001-10-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	5594	\N	\N	\N
5543	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5595	\N	\N	\N
5544	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5596	\N	\N	\N
5545	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5597	\N	\N	\N
5546	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5598	\N	\N	\N
5547	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5599	\N	\N	\N
5548	MEMBRE	2001-10-01 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	5600	\N	\N	\N
5549	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5601	\N	\N	\N
5550	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5602	\N	\N	\N
5551	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5603	\N	\N	\N
5552	MEMBRE	2001-10-01 00:00:00	2002-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	5604	\N	\N	\N
5553	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5605	\N	\N	\N
5556	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5608	\N	\N	\N
5557	MEMBRE	2001-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5609	\N	\N	\N
5558	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5610	\N	\N	\N
5560	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5612	\N	\N	\N
5561	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5613	\N	\N	\N
5562	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5614	\N	\N	\N
5564	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5616	\N	\N	\N
5565	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5617	\N	\N	\N
5566	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5618	\N	\N	\N
5570	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5622	\N	\N	\N
5571	VICPDT	2001-10-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	5623	8	\N	\N
5573	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5625	\N	\N	\N
5574	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5626	\N	\N	\N
5575	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5627	\N	\N	\N
5577	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5629	\N	\N	\N
5579	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5631	\N	\N	\N
5582	VICPDT	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5634	4	\N	\N
5583	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5635	\N	\N	\N
5585	MEMBRE	2001-10-01 00:00:00	2002-07-30 00:00:00	ANCIEN	\N	\N	\N	\N	5637	\N	\N	\N
5586	MEMBRE	2001-10-01 00:00:00	2002-07-30 00:00:00	ANCIEN	\N	\N	\N	\N	5638	\N	\N	\N
5587	PDT	2001-10-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	5639	1	\N	\N
5588	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5640	\N	\N	\N
5590	SECRET	2001-10-01 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	5642	11	\N	\N
5591	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5643	10	\N	\N
5592	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5644	\N	\N	\N
5594	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5646	\N	\N	\N
5596	MEMBRE	2001-10-01 00:00:00	2004-11-15 00:00:00	ANCIEN	\N	\N	\N	\N	5648	\N	\N	\N
5598	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5650	\N	\N	\N
5599	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5651	\N	\N	\N
5600	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5652	\N	\N	\N
5601	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5653	\N	\N	\N
5603	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5655	\N	\N	\N
5604	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5656	\N	\N	\N
5605	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5657	\N	\N	\N
5606	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5658	\N	\N	\N
5607	VICPDT	2001-10-01 00:00:00	2004-11-15 00:00:00	ANCIEN	\N	\N	\N	\N	5659	5	\N	\N
5609	MEMBRE	2001-10-01 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	5661	\N	\N	\N
5610	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5662	\N	\N	\N
5612	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5664	\N	\N	\N
5613	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5665	\N	\N	\N
5614	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5666	\N	\N	\N
5615	SECRET	2001-10-01 00:00:00	2004-11-15 00:00:00	ANCIEN	\N	\N	\N	\N	5667	12	\N	\N
5617	MEMBRE	2001-10-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	5669	\N	\N	\N
5618	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5670	\N	\N	\N
5619	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5671	\N	\N	\N
6398	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6300	\N	\N	\N
6399	MEMBRE	2001-10-01 00:00:00	2010-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	6301	\N	\N	\N
6400	MEMBRE	2001-10-01 00:00:00	2004-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	6302	\N	\N	\N
6401	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6303	\N	\N	\N
6402	MEMBRE	2001-10-01 00:00:00	2004-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	6304	\N	\N	\N
6403	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6305	\N	\N	\N
6404	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6306	\N	\N	\N
6405	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6307	\N	\N	\N
6407	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6309	13	\N	\N
6408	SECRET	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6310	14	\N	\N
6409	VICPDT	2001-10-01 00:00:00	2009-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	6311	\N	\N	\N
6410	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6312	\N	\N	\N
6411	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6313	\N	\N	\N
6412	MEMBRE	2001-10-01 00:00:00	2004-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	6316	\N	\N	\N
6413	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6315	\N	\N	\N
6415	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6317	\N	\N	\N
6416	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6318	\N	\N	\N
6417	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6319	\N	\N	\N
6418	MEMBRE	2001-10-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	6320	0	\N	\N
6419	MEMBRE	2001-10-01 00:00:00	2004-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	6321	\N	\N	\N
6421	MEMBRE	2000-12-19 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4515	\N	\N	\N
6422	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6335	\N	\N	\N
6423	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6336	\N	\N	\N
6424	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6337	\N	\N	\N
6425	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6338	\N	\N	\N
6426	MEMBRE	2001-10-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	6339	\N	\N	\N
6427	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6340	\N	\N	\N
6429	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6342	\N	\N	\N
6430	MEMBRE	2001-10-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	\N	6343	\N	\N	\N
6431	MEMBRE	2001-10-01 00:00:00	2009-09-09 00:00:00	ANCIEN	\N	\N	\N	\N	6344	\N	\N	\N
6432	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6345	\N	\N	\N
6433	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6346	\N	\N	\N
6434	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6347	\N	\N	\N
5620	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5672	\N	\N	\N
5621	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5673	\N	\N	\N
5623	MEMBRE	2001-10-01 00:00:00	2002-06-18 00:00:00	ANCIEN	\N	\N	\N	\N	5675	\N	\N	\N
5624	MEMBRE	2001-10-01 00:00:00	2004-11-15 00:00:00	ANCIEN	\N	\N	\N	\N	5676	\N	\N	\N
5625	MEMBRE	2001-10-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	5677	\N	\N	\N
5626	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5678	\N	\N	\N
5627	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5680	\N	\N	\N
5629	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5682	\N	\N	\N
5630	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5683	\N	\N	\N
5631	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5684	\N	\N	\N
5633	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5686	\N	\N	\N
5634	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5687	\N	\N	\N
5635	MEMBRE	2001-10-01 00:00:00	2004-11-15 00:00:00	ANCIEN	\N	\N	\N	\N	5688	\N	\N	\N
5636	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5689	\N	\N	\N
5637	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5690	\N	\N	\N
5638	SECRET	2001-10-01 00:00:00	2004-11-15 00:00:00	ANCIEN	\N	\N	\N	\N	5691	18	\N	\N
5639	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5692	\N	\N	\N
5640	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5693	\N	\N	\N
5641	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5694	\N	\N	\N
5642	MEMBRE	2001-10-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	5695	\N	\N	\N
5644	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5697	\N	\N	\N
5645	MEMBRE	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	5698	\N	\N	\N
5646	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5700	\N	\N	\N
5647	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5701	\N	\N	\N
5648	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5702	\N	\N	\N
5649	MEMBRE	2001-10-01 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	5703	\N	\N	\N
5650	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5704	\N	\N	\N
5651	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5705	\N	\N	\N
5652	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5706	\N	\N	\N
5653	SECRET	2001-10-01 00:00:00	2004-11-15 00:00:00	ANCIEN	\N	\N	\N	\N	5707	20	\N	\N
5656	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5710	\N	\N	\N
5657	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5711	\N	\N	\N
5658	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5712	\N	\N	\N
5659	MEMBRE	2001-10-01 00:00:00	2007-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	5713	\N	\N	\N
5660	MEMBRE	2001-10-01 00:00:00	2008-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	5714	\N	\N	\N
5662	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5716	\N	\N	\N
5663	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5717	\N	\N	\N
5664	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5718	\N	\N	\N
5665	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5719	\N	\N	\N
5667	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5721	\N	\N	\N
5668	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5722	\N	\N	\N
5669	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5723	\N	\N	\N
5671	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5725	\N	\N	\N
5672	MEMBRE	2001-10-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	5726	\N	\N	\N
5673	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5727	\N	\N	\N
5675	MEMBRE	2001-10-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	5729	\N	\N	\N
5677	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5731	\N	\N	\N
5678	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5732	\N	\N	\N
5680	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5734	5	\N	\N
5681	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5735	\N	\N	\N
5682	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5736	7	\N	\N
5684	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5738	\N	\N	\N
5685	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5739	\N	\N	\N
5686	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5740	\N	\N	\N
5455	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5503	\N	\N	\N
5460	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5508	\N	\N	\N
5468	MEMBRE	2001-10-01 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	5516	\N	\N	\N
5477	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5526	\N	\N	\N
5481	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5530	\N	\N	\N
5485	VICPDT	2001-10-01 00:00:00	2004-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	5534	6	\N	\N
5554	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5606	\N	\N	\N
5559	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5611	\N	\N	\N
5563	MEMBRE	2001-10-01 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	5615	\N	\N	\N
5567	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5619	\N	\N	\N
5580	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5632	\N	\N	\N
5584	MEMBRE	2001-10-01 00:00:00	2002-07-30 00:00:00	ANCIEN	\N	\N	\N	\N	5636	\N	\N	\N
5589	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5641	\N	\N	\N
5593	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5645	\N	\N	\N
5597	VICPDT	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5649	5	\N	\N
5661	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5715	\N	\N	\N
5670	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5724	\N	\N	\N
5674	MEMBRE	2001-10-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	5728	\N	\N	\N
5679	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5733	\N	\N	\N
5683	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5737	\N	\N	\N
5687	MEMBRE	2001-10-01 00:00:00	2004-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	5741	\N	\N	\N
5689	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5743	\N	\N	\N
5690	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5744	\N	\N	\N
5691	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5745	\N	\N	\N
5692	MEMBRE	2001-10-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	\N	5746	\N	\N	\N
5693	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5747	\N	\N	\N
5694	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5748	\N	\N	\N
5695	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5749	\N	\N	\N
5696	MEMBRE	2001-10-01 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	5750	\N	\N	\N
5697	MEMBRE	2001-10-01 00:00:00	2004-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	5756	\N	\N	\N
5699	MEMBRE	2001-10-01 00:00:00	2004-11-09 00:00:00	ANCIEN	\N	\N	\N	\N	5759	\N	\N	\N
5700	VICPDT	2001-10-01 00:00:00	2007-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	5760	0	\N	\N
5701	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5761	\N	\N	\N
5702	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5762	\N	\N	\N
5703	MEMBRE	2001-10-01 00:00:00	2003-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	5763	\N	\N	\N
5704	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5764	\N	\N	\N
5705	VICPDT	2001-10-01 00:00:00	2004-11-09 00:00:00	ANCIEN	\N	\N	\N	\N	5765	8	\N	\N
5706	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5766	\N	\N	\N
5709	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5769	\N	\N	\N
5710	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5771	\N	\N	\N
5711	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5772	\N	\N	\N
5712	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5773	\N	\N	\N
5713	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5774	8	\N	\N
5714	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5775	\N	\N	\N
5715	MEMBRE	2001-10-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	5776	\N	\N	\N
5716	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5777	\N	\N	\N
5718	MEMBRE	2001-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	5779	\N	\N	\N
5719	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5780	\N	\N	\N
5720	PDTDEL	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	Islande	\N	5781	5	\N	\N
5721	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5782	\N	\N	\N
6365	MEMBRE	2001-10-01 00:00:00	2004-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	6265	\N	\N	\N
6366	MEMBRE	2001-10-01 00:00:00	2004-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	6266	\N	\N	\N
6368	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6268	\N	\N	\N
6369	MEMBRE	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	6269	\N	\N	\N
6370	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6270	\N	\N	\N
6372	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6272	\N	\N	\N
6373	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6273	\N	\N	\N
6375	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6275	\N	\N	\N
6376	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6276	\N	\N	\N
6377	MEMBRE	2001-10-01 00:00:00	2004-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	6277	\N	\N	\N
6392	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6294	\N	\N	\N
6379	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6281	\N	\N	\N
6380	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6282	\N	\N	\N
6381	TRESORADJ	2001-10-01 00:00:00	2004-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	6283	14	\N	\N
6382	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6284	\N	\N	\N
6383	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6285	\N	\N	\N
6385	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6287	\N	\N	\N
6386	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6288	\N	\N	\N
6387	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6289	\N	\N	\N
6388	MEMBRE	2001-10-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	6290	\N	\N	\N
6389	MEMBRE	2001-10-01 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	6291	\N	\N	\N
6390	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6292	\N	\N	\N
6391	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6293	\N	\N	\N
6393	MEMBRE	2001-10-01 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	6295	\N	\N	\N
6394	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6296	\N	\N	\N
6395	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6297	\N	\N	\N
6396	SECRET	2001-10-01 00:00:00	2004-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	6298	8	\N	\N
6397	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6299	\N	\N	\N
5933	MEMBRE	2001-10-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	2330	\N	\N	\N
5923	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3123	8	\N	\N
5924	VICPDT	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2013	11	\N	\N
5925	TRESOR	2001-10-01 00:00:00	2009-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	2811	12	\N	\N
5926	SECRET	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1754	16	\N	\N
5928	SECRET	2001-10-01 00:00:00	2004-11-15 00:00:00	ANCIEN	\N	\N	\N	\N	2817	14	\N	\N
5929	SECRET	2001-10-01 00:00:00	2009-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	1915	20	\N	\N
5930	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1165	16	\N	\N
5931	SECRET	2001-10-01 00:00:00	2004-11-15 00:00:00	ANCIEN	\N	\N	\N	\N	3119	17	\N	\N
5934	MEMBRE	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	1479	\N	\N	\N
5935	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3830	4	\N	\N
5936	VICPDT	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2227	3	\N	\N
5938	MEMBRE	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	1975	\N	\N	\N
5939	VICPDT	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4415	2	\N	\N
5940	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4411	4	\N	\N
5941	VICPDT	2001-10-01 00:00:00	2004-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	4309	5	\N	\N
5942	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5578	6	\N	\N
5943	SECRET	2001-10-01 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	4414	11	\N	\N
5944	TRESOR	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4410	9	\N	\N
5945	VICPDT	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3374	6	\N	\N
5946	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	3370	\N	\N	\N
5947	PDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3429	1	\N	\N
5948	PDTDEL	2001-10-01 00:00:00	2009-01-20 00:00:00	ANCIEN	\N	\N	Iles Fidji	\N	3405	2	\N	\N
5084	SECRET	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5192	8	\N	\N
5949	PDTDEL	2001-10-01 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	Papouasie-Nouvelle Guinée	\N	3428	3	\N	\N
5950	PDTDEL	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Vanuatu	\N	3416	2	\N	\N
5951	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3406	6	\N	\N
5952	VICPDT	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3415	6	\N	\N
5953	VICPDT	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3427	7	\N	\N
5954	SECRET	2001-10-01 00:00:00	2009-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	3431	11	\N	\N
5955	SECRET	2001-10-01 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	3411	13	\N	\N
5956	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3393	\N	\N	\N
5958	PDTHON	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5835	1	\N	\N
5959	PDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5851	2	\N	\N
5960	PDTDEL	2001-10-01 00:00:00	2004-11-24 00:00:00	ANCIEN	\N	\N	Luxembourg	\N	5839	3	\N	\N
5961	VICPDT	2001-10-01 00:00:00	2004-11-24 00:00:00	ANCIEN	\N	\N	\N	\N	5834	4	\N	\N
5962	VICPDT	2001-10-01 00:00:00	2004-11-24 00:00:00	ANCIEN	\N	\N	\N	\N	5841	5	\N	\N
5963	VICPDT	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5852	4	\N	\N
5964	VICPDT	2001-10-01 00:00:00	2004-11-24 00:00:00	ANCIEN	\N	\N	\N	\N	5854	7	\N	\N
5965	SECRET	2001-10-01 00:00:00	2004-11-24 00:00:00	ANCIEN	\N	\N	\N	\N	5847	8	\N	\N
5967	SECRET	2001-10-01 00:00:00	2004-11-24 00:00:00	ANCIEN	\N	\N	\N	\N	5857	10	\N	\N
5968	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1211	23	\N	\N
5969	SECRET	2001-10-01 00:00:00	2004-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	604	30	\N	\N
5970	TRESOR	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5867	18	\N	\N
5971	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5866	15	\N	\N
5972	VICPDT	2001-10-01 00:00:00	2004-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	5868	3	\N	\N
5973	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5929	\N	\N	\N
5974	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5930	\N	\N	\N
5975	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5931	\N	\N	\N
5976	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5932	\N	\N	\N
5978	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5934	\N	\N	\N
5979	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5935	\N	\N	\N
5980	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5936	\N	\N	\N
5981	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5937	\N	\N	\N
5982	VICPDT	2001-10-01 00:00:00	2009-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	5938	3	\N	\N
5984	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5940	\N	\N	\N
5985	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5941	\N	\N	\N
5986	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5942	\N	\N	\N
5987	MEMBRE	2001-10-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	\N	5943	\N	\N	\N
5988	MEMBRE	2001-10-01 00:00:00	2004-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	5944	\N	\N	\N
5989	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5946	\N	\N	\N
5990	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5947	\N	\N	\N
5991	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5948	9	\N	\N
5992	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5949	\N	\N	\N
5993	VICPDT	2001-10-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	5950	5	\N	\N
5994	VICPDT	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5951	3	\N	\N
5995	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5952	7	\N	\N
5998	MEMBREBUR	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5956	11	\N	\N
5999	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5957	\N	\N	\N
6000	VICPDT	2001-10-01 00:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	5958	4	\N	\N
6001	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5959	\N	\N	\N
6002	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5960	\N	\N	\N
6003	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5961	\N	\N	\N
6004	MEMBRE	2001-10-01 00:00:00	2010-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	5962	\N	\N	\N
6005	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5963	\N	\N	\N
6006	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5964	\N	\N	\N
6007	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5965	\N	\N	\N
6008	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5966	\N	\N	\N
6010	MEMBREBUR	2001-10-01 00:00:00	2004-11-09 00:00:00	ANCIEN	\N	\N	\N	\N	5968	13	\N	\N
6011	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5969	\N	\N	\N
6013	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5971	\N	\N	\N
6014	MEMBREBUR	2001-10-01 00:00:00	2004-11-09 00:00:00	ANCIEN	\N	\N	\N	\N	5972	12	\N	\N
6015	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5973	\N	\N	\N
6016	MEMBRE	2001-10-01 00:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	5974	0	\N	\N
6017	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5975	\N	\N	\N
6019	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5977	\N	\N	\N
6020	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5978	\N	\N	\N
6021	PDT	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1892	1	\N	\N
6022	VICPDTDEL	2001-10-01 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	42	2	\N	\N
6023	TRESOR	2001-10-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	9	7	\N	\N
6024	MEMBREBUR	2001-10-01 00:00:00	2004-11-09 00:00:00	ANCIEN	\N	\N	\N	\N	1252	8	\N	\N
6025	MEMBREBUR	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1412	14	\N	\N
6026	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1285	\N	\N	\N
6027	VICPDT	2001-10-01 00:00:00	2009-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	1919	7	\N	\N
6028	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3250	\N	\N	\N
6029	MEMBRE	2001-10-01 00:00:00	2004-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	3488	\N	\N	\N
6030	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1568	\N	\N	\N
6031	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3501	\N	\N	\N
6032	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3503	\N	\N	\N
6033	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5979	\N	\N	\N
6034	MEMBRE	2001-10-01 00:00:00	2009-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	5980	0	\N	\N
6035	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5981	\N	\N	\N
6036	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5982	\N	\N	\N
6037	PDT	2001-12-12 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3855	1	\N	\N
6038	PDTHON	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1964	2	\N	\N
6039	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2719	4	\N	\N
6040	VICPDT	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1668	4	\N	\N
6043	SECRET	2001-10-01 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	1692	9	\N	\N
6045	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1546	\N	\N	\N
6046	MEMBRE	2001-10-01 00:00:00	2009-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	1914	\N	\N	\N
6047	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1770	\N	\N	\N
6048	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1197	\N	\N	\N
6050	MEMBRE	2001-10-01 00:00:00	2009-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	1057	\N	\N	\N
6052	VICPDT	2001-10-01 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	3258	\N	\N	\N
6053	SECRET	2001-10-01 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	5929	\N	\N	\N
4741	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4854	\N	\N	\N
4742	VICPDT	2001-10-01 00:00:00	2004-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	4855	5	\N	\N
4743	MEMBRE	2001-10-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	4856	\N	\N	\N
4744	MEMBRE	2001-10-01 00:00:00	2004-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	4857	\N	\N	\N
4745	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4858	\N	\N	\N
4747	SECRET	2001-10-01 00:00:00	2008-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	4860	14	\N	\N
4748	MEMBRE	2001-10-01 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	4861	\N	\N	\N
4749	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4862	\N	\N	\N
4752	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4867	\N	\N	\N
4753	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4868	\N	\N	\N
4755	MEMBRE	2001-10-01 00:00:00	2004-11-09 00:00:00	ANCIEN	\N	\N	\N	\N	4869	\N	\N	\N
4756	MEMBRE	2001-10-01 00:00:00	2008-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	4871	\N	\N	\N
4757	MEMBRE	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4872	\N	\N	\N
4758	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4873	\N	\N	\N
4759	MEMBRE	2001-10-01 00:00:00	2004-11-09 00:00:00	ANCIEN	\N	\N	\N	\N	4874	\N	\N	\N
4760	MEMBRE	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4875	\N	\N	\N
4761	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4876	\N	\N	\N
4762	MEMBRE	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4877	\N	\N	\N
4763	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4878	\N	\N	\N
4764	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4879	\N	\N	\N
4765	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4880	\N	\N	\N
4767	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4882	\N	\N	\N
4768	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4883	\N	\N	\N
4769	MEMBRE	2001-10-01 00:00:00	2007-06-24 00:00:00	ANCIEN	\N	\N	\N	\N	4884	\N	\N	\N
4770	MEMBRE	2001-10-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	4885	\N	\N	\N
4771	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4886	\N	\N	\N
4772	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4887	\N	\N	\N
4774	MEMBRE	2001-10-01 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	4889	\N	\N	\N
4775	MEMBRE	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4890	\N	\N	\N
4776	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4891	\N	\N	\N
4777	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4892	\N	\N	\N
4778	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4893	15	\N	\N
4779	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4894	\N	\N	\N
4781	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4896	\N	\N	\N
4782	MEMBRE	2001-10-01 00:00:00	2004-11-09 00:00:00	ANCIEN	\N	\N	\N	\N	4897	\N	\N	\N
4783	MEMBRE	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4898	\N	\N	\N
5419	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5467	\N	\N	\N
5420	VICPDTPRE	2001-10-01 00:00:00	2004-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	3836	7	\N	\N
5421	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3510	\N	\N	\N
5422	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2960	9	\N	\N
4122	MEMBRE	2000-11-01 00:00:00	2002-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	4172	\N	\N	\N
4358	MEMBRE	2000-12-06 00:00:00	2002-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	4465	\N	\N	\N
5423	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5469	\N	\N	\N
5426	MEMBRE	2001-10-01 00:00:00	2004-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	5472	\N	\N	\N
5427	MEMBRE	2001-10-01 00:00:00	2002-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	5473	\N	\N	\N
5428	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5474	\N	\N	\N
5429	MEMBRE	2001-10-01 00:00:00	2004-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	5475	\N	\N	\N
5430	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5476	\N	\N	\N
5431	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5477	\N	\N	\N
5432	MEMBRE	2001-10-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	\N	5478	\N	\N	\N
5433	SECRET	2001-10-01 00:00:00	2004-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	5479	9	\N	\N
5434	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5480	\N	\N	\N
5435	SECRET	2001-10-01 00:00:00	2004-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	5481	10	\N	\N
5436	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5482	\N	\N	\N
5437	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5483	\N	\N	\N
5438	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5484	7	\N	\N
5439	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5485	\N	\N	\N
5441	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5487	\N	\N	\N
5442	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5488	\N	\N	\N
5443	MEMBRE	2001-10-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	5489	\N	\N	\N
5444	MEMBRE	2001-10-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	5490	\N	\N	\N
5445	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5491	\N	\N	\N
5446	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2807	\N	\N	\N
5447	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5494	\N	\N	\N
5448	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5496	\N	\N	\N
5449	MEMBRE	2001-10-01 00:00:00	2008-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	5497	\N	\N	\N
5450	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5498	\N	\N	\N
5451	PDTDEL	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	Congo-Brazzaville	\N	5499	7	\N	\N
5452	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5500	\N	\N	\N
5453	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5501	\N	\N	\N
5454	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5502	\N	\N	\N
5458	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5506	14	\N	\N
5459	MEMBRE	2001-10-01 00:00:00	2004-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	5507	\N	\N	\N
5461	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5509	\N	\N	\N
5462	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5510	\N	\N	\N
5463	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5511	\N	\N	\N
5465	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5513	\N	\N	\N
5466	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5514	\N	\N	\N
6351	VICPDT	2001-10-01 00:00:00	2004-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	4227	\N	\N	\N
6353	MEMBRE	2001-10-01 00:00:00	2004-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	3317	\N	\N	\N
6354	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	3321	\N	\N	\N
6355	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3311	\N	\N	\N
6356	PDT	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4161	1	\N	\N
6358	VICPDT	2001-10-01 00:00:00	2004-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	2731	5	\N	\N
6360	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1185	\N	\N	\N
6361	PDT	2002-07-09 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	5062	1	\N	\N
6363	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6263	\N	\N	\N
6364	MEMBRE	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	6264	\N	\N	\N
7350	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7447	\N	\N	\N
7352	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7449	\N	\N	\N
7353	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7450	\N	\N	\N
7354	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7451	\N	\N	\N
7355	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7452	\N	\N	\N
7356	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7453	\N	\N	\N
7357	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7454	\N	\N	\N
7358	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7455	\N	\N	\N
7359	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7456	\N	\N	\N
7360	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7457	\N	\N	\N
7362	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7459	\N	\N	\N
7363	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7460	\N	\N	\N
7364	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7461	\N	\N	\N
7365	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7462	\N	\N	\N
7366	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7463	\N	\N	\N
7369	MEMBRE	2001-10-01 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	7466	\N	\N	\N
7370	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7467	\N	\N	\N
7371	PDT	2001-10-02 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	7467	\N	\N	\N
7372	VICPDT	2003-09-25 00:00:00	2004-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	7464	\N	\N	\N
7373	VICPDT	2001-10-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7454	\N	\N	\N
7374	VICPDT	2001-10-02 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7465	\N	\N	\N
7376	VICPDT	2001-10-02 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7460	\N	\N	\N
7378	SECRET	2001-10-02 00:00:00	2007-04-03 00:00:00	ANCIEN	\N	\N	\N	\N	7453	\N	\N	\N
7379	SECRET	2001-10-02 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	\N	7458	\N	\N	\N
7380	SECRET	2001-10-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7459	\N	\N	\N
7381	SECRET	2001-10-02 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7462	\N	\N	\N
7383	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7468	\N	\N	\N
7384	MEMBRE	2001-10-01 00:00:00	2004-11-25 00:00:00	ANCIEN	\N	\N	\N	\N	7469	\N	\N	\N
7386	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7471	\N	\N	\N
7387	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7472	\N	\N	\N
7388	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7473	\N	\N	\N
7389	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7474	\N	\N	\N
7390	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7475	\N	\N	\N
7392	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7477	\N	\N	\N
7394	MEMBRE	2001-10-01 00:00:00	2004-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	7479	\N	\N	\N
7395	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7480	\N	\N	\N
7396	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7481	\N	\N	\N
7397	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7482	\N	\N	\N
7398	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7483	\N	\N	\N
7399	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7484	\N	\N	\N
7400	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7485	\N	\N	\N
7401	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7486	\N	\N	\N
7402	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7487	\N	\N	\N
7405	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7490	\N	\N	\N
7406	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7491	\N	\N	\N
7407	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7492	\N	\N	\N
7408	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7493	\N	\N	\N
7409	MEMBRE	2001-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	7494	\N	\N	\N
7410	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7495	\N	\N	\N
7411	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7496	\N	\N	\N
7412	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7497	\N	\N	\N
7413	MEMBRE	2001-10-01 00:00:00	2004-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	7498	\N	\N	\N
7414	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7499	\N	\N	\N
7416	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7501	\N	\N	\N
7417	MEMBRE	2001-10-01 00:00:00	2009-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	7502	\N	\N	\N
7418	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7503	\N	\N	\N
7420	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7505	\N	\N	\N
7421	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7506	\N	\N	\N
7423	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7508	\N	\N	\N
5884	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5822	4	\N	\N
5885	SECRET	2001-10-01 00:00:00	2004-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	5818	7	\N	\N
5887	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4429	2	\N	\N
5888	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4442	4	\N	\N
5889	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4444	5	\N	\N
5890	MEMBRE	2001-10-01 00:00:00	2004-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	4435	\N	\N	\N
5891	VICPDT	2001-10-01 00:00:00	2004-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	3593	7	\N	\N
5894	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	2638	\N	\N	\N
5895	PDT	2001-10-01 00:00:00	2004-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	3801	1	\N	\N
5896	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3802	6	\N	\N
5897	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3818	8	\N	\N
5898	TRESOR	2001-10-01 00:00:00	2004-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	3793	9	\N	\N
5899	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3805	\N	\N	\N
5900	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3800	\N	\N	\N
5901	MEMBRE	2001-10-01 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	3804	\N	\N	\N
5902	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3571	2	\N	\N
5903	VICPDT	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3587	6	\N	\N
5904	PDT	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3449	1	\N	\N
5905	VICPDT	2001-10-01 00:00:00	2004-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	3441	7	\N	\N
5906	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3476	11	\N	\N
5907	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3478	14	\N	\N
5908	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3483	16	\N	\N
5910	VICPDT	2001-10-01 00:00:00	2004-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	1557	2	\N	\N
5912	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1525	8	\N	\N
5913	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3281	9	\N	\N
5914	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3282	10	\N	\N
5915	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3376	3	\N	\N
5916	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3386	\N	\N	\N
5917	PDT	2001-10-01 00:00:00	2007-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	1965	1	\N	\N
5918	VICPDTPRE	2001-10-01 00:00:00	2009-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	3114	3	\N	\N
5919	VICPDTDEU	2001-10-01 00:00:00	2002-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	4087	3	\N	\N
5920	VICPDT	2001-10-01 00:00:00	2004-11-15 00:00:00	ANCIEN	\N	\N	\N	\N	2454	\N	\N	\N
6435	SECRET	2001-10-01 00:00:00	2004-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	6348	10	\N	\N
6436	MEMBRE	2001-10-01 00:00:00	2004-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	6349	\N	\N	\N
6437	MEMBRE	2001-10-01 00:00:00	2004-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	6350	\N	\N	\N
6438	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6351	\N	\N	\N
6439	MEMBRE	2001-10-01 00:00:00	2002-07-30 00:00:00	ANCIEN	\N	\N	\N	\N	6352	\N	\N	\N
6441	VICPDT	2002-07-31 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2132	2	\N	\N
6442	SECRET	2002-07-31 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	5637	10	\N	\N
6443	SECRET	2002-07-31 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5636	11	\N	\N
6445	MEMBREBUR	2002-07-31 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	5638	13	\N	\N
6447	MEMBREBUR	2002-07-09 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1554	6	\N	\N
6448	MEMBRE	2002-07-09 00:00:00	2004-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	5055	\N	\N	\N
6449	MEMBREBUR	2002-07-09 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1726	7	\N	\N
6451	MEMBREBUR	2002-07-09 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5075	9	\N	\N
6452	MEMBRE	2002-01-14 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6353	\N	\N	\N
6453	SECRET	2001-12-05 00:00:00	2004-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	4543	9	\N	\N
6454	VICPDT	2001-12-12 00:00:00	2004-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	3956	4	\N	\N
6455	VICPDT	2001-12-12 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	3958	5	\N	\N
6457	VICPDT	2001-12-12 00:00:00	2004-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	3969	6	\N	\N
6459	MEMBRE	2001-10-19 00:00:00	2004-10-23 00:00:00	ANCIEN	\N	\N	\N	\N	6355	\N	\N	\N
6460	MEMBRE	2001-10-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6356	\N	\N	\N
6461	MEMBRE	2001-10-24 00:00:00	2004-10-23 00:00:00	ANCIEN	\N	\N	\N	\N	6357	\N	\N	\N
6462	MEMBRE	2001-10-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6358	\N	\N	\N
6463	SECRET	2001-10-24 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6359	15	\N	\N
6464	MEMBRE	2001-10-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6360	\N	\N	\N
6465	SECRET	2001-10-24 00:00:00	2005-04-11 00:00:00	ANCIEN	\N	\N	\N	\N	6361	16	\N	\N
6467	MEMBRE	2001-10-24 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6363	\N	\N	\N
6468	MEMBRE	2001-10-24 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6364	\N	\N	\N
6469	MEMBRE	2001-10-24 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	6365	\N	\N	\N
6470	MEMBRE	2001-10-24 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	6366	\N	\N	\N
6471	MEMBRE	2001-10-24 00:00:00	2005-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6367	\N	\N	\N
6472	SECRET	2001-10-24 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6368	19	\N	\N
6473	VICPDT	2001-10-24 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6369	13	\N	\N
6474	MEMBRE	2001-10-24 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6370	\N	\N	\N
6476	MEMBRE	2001-10-24 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	6372	\N	\N	\N
6477	MEMBRE	2001-10-24 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6373	\N	\N	\N
6478	MEMBRE	2001-10-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6374	\N	\N	\N
6479	MEMBRE	2001-10-24 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6375	\N	\N	\N
6480	MEMBRE	2001-10-24 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6376	\N	\N	\N
6481	PDTDEL	2001-10-24 00:00:00	2004-07-19 00:00:00	ANCIEN	\N	\N	Comores	\N	6377	5	\N	\N
6482	PDTDEL	2001-10-24 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	Ile Maurice	\N	6378	6	\N	\N
6483	MEMBRE	2001-10-01 00:00:00	2004-11-09 00:00:00	ANCIEN	\N	\N	\N	\N	6379	\N	\N	\N
6484	MEMBRE	2002-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6381	\N	\N	\N
6485	MEMBRE	2002-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6382	\N	\N	\N
6487	MEMBRE	2002-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6384	\N	\N	\N
6488	VICPDT	2001-10-01 00:00:00	2004-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	4101	5	\N	\N
6489	VICPDT	2001-10-01 00:00:00	2009-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	3915	5	\N	\N
6490	VICPDT	2001-10-01 00:00:00	2009-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	3924	10	\N	\N
6491	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6267	11	\N	\N
6495	VICPDTDRT	2001-10-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	Afrique australe	\N	3731	3	\N	\N
6496	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3723	20	\N	\N
6497	SECRET	2001-10-01 00:00:00	2005-04-11 00:00:00	ANCIEN	\N	\N	\N	\N	3731	22	\N	\N
6498	TRESOR	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3734	23	\N	\N
6499	PDT	2002-10-23 00:00:00	2004-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	2895	1	\N	\N
6500	VICPDT	2002-10-23 00:00:00	2004-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	2930	2	\N	\N
6501	VICPDT	2002-10-23 00:00:00	2004-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	1493	8	\N	\N
6502	MEMBREBUR	2002-10-23 00:00:00	2004-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	6117	18	\N	\N
6504	MEMBRE	2002-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6387	\N	\N	\N
6505	MEMBRE	2002-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6388	\N	\N	\N
6506	VICPDT	2002-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6389	8	\N	\N
6507	MEMBRE	2002-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6390	\N	\N	\N
6508	MEMBRE	2002-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6391	\N	\N	\N
6509	MEMBRE	2002-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6392	\N	\N	\N
6510	MEMBRE	2002-11-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	6393	\N	\N	\N
6511	MEMBRE	2002-11-01 00:00:00	2004-11-15 00:00:00	ANCIEN	\N	\N	\N	\N	6394	\N	\N	\N
6512	MEMBRE	2002-11-01 00:00:00	2004-11-15 00:00:00	ANCIEN	\N	\N	\N	\N	6395	\N	\N	\N
6514	MEMBRE	2002-11-01 00:00:00	2004-11-15 00:00:00	ANCIEN	\N	\N	\N	\N	6397	\N	\N	\N
6515	MEMBRE	2002-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6398	\N	\N	\N
6516	MEMBRE	2002-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6399	\N	\N	\N
6517	SECRET	2002-11-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	6400	13	\N	\N
6518	MEMBRE	2002-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6401	\N	\N	\N
6519	SECRET	2002-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6402	11	\N	\N
6520	MEMBRE	2002-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6403	\N	\N	\N
6521	MEMBRE	2002-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6404	\N	\N	\N
6522	MEMBRE	2002-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6405	\N	\N	\N
6523	MEMBRE	2002-11-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	6406	\N	\N	\N
6524	MEMBRE	2002-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6407	\N	\N	\N
6526	MEMBRE	2002-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6409	\N	\N	\N
6527	MEMBRE	2002-11-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	\N	6411	\N	\N	\N
6528	MEMBRE	2002-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6412	\N	\N	\N
6529	MEMBRE	2002-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6413	\N	\N	\N
6530	MEMBRE	2002-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6414	\N	\N	\N
6531	MEMBRE	2002-11-01 00:00:00	2004-11-15 00:00:00	ANCIEN	\N	\N	\N	\N	6415	\N	\N	\N
6532	MEMBRE	2002-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6416	\N	\N	\N
6533	MEMBRE	2002-11-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	6417	\N	\N	\N
6534	MEMBRE	2002-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6418	\N	\N	\N
6535	MEMBRE	2002-11-01 00:00:00	2005-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	6419	\N	\N	\N
6536	MEMBRE	2002-11-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	6420	\N	\N	\N
6537	MEMBRE	2002-11-01 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	6421	\N	\N	\N
6538	MEMBRE	2002-11-01 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	6422	\N	\N	\N
6541	MEMBRE	2002-11-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6425	\N	\N	\N
6540	MEMBRE	2002-11-01 00:00:00	2004-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	6424	\N	\N	\N
6542	MEMBRE	2002-11-01 00:00:00	2009-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	6426	\N	\N	\N
6543	MEMBRE	2002-11-01 00:00:00	2008-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	6427	\N	\N	\N
6544	MEMBRE	2002-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6428	\N	\N	\N
6545	MEMBRE	2002-11-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6429	\N	\N	\N
6547	SECRET	2002-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6431	7	\N	\N
6548	MEMBRE	2002-11-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6432	\N	\N	\N
6549	MEMBRE	2002-11-01 00:00:00	2002-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	6433	\N	\N	\N
6550	MEMBRE	2002-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6434	\N	\N	\N
6551	MEMBRE	2002-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6435	\N	\N	\N
6552	MEMBRE	2002-11-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6436	\N	\N	\N
6553	MEMBRE	2002-11-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6438	\N	\N	\N
6554	MEMBRE	2002-11-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6439	\N	\N	\N
6555	MEMBRE	2002-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6440	\N	\N	\N
6558	VICPDT	2001-11-27 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1680	6	\N	\N
6559	VICPDT	2001-11-27 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2505	9	\N	\N
6561	SECRET	2001-11-27 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1324	12	\N	\N
6562	MEMBRE	2001-11-27 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	1066	\N	\N	\N
6564	MEMBRE	2001-11-27 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	2489	\N	\N	\N
6565	MEMBRE	2002-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6410	\N	\N	\N
6566	PDT	2002-11-01 00:00:00	2007-02-25 00:00:00	ANCIEN	\N	\N	\N	\N	6441	1	\N	\N
6567	VICPDT	2002-12-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	6442	7	\N	\N
6570	PDTDEL	2002-12-03 00:00:00	2009-05-19 00:00:00	ANCIEN	\N	\N	Indonésie	\N	5990	5	\N	\N
6569	MEMBRE	2002-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6444	\N	\N	\N
6572	PDTDEL	2002-12-03 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	Bangladesh	\N	6002	8	\N	\N
6573	VICPDT	2002-12-03 00:00:00	2005-03-21 00:00:00	ANCIEN	\N	\N	\N	\N	5993	10	\N	\N
6574	VICPDT	2002-12-03 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5995	11	\N	\N
6575	VICPDT	2002-12-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6004	13	\N	\N
7638	MEMBRE	2001-10-01 00:00:00	2004-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	7674	\N	\N	\N
7614	MEMBRE	2005-03-02 00:00:00	2007-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	7652	\N	\N	\N
7615	MEMBRE	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	7653	\N	\N	\N
7618	MEMBRE	2004-10-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7656	\N	\N	\N
7617	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7655	\N	\N	\N
7619	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	7657	\N	\N	\N
7623	MEMBRE	2001-10-01 00:00:00	2003-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	7661	\N	\N	\N
7624	MEMBRE	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	7662	\N	\N	\N
7625	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7663	\N	\N	\N
7626	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7664	\N	\N	\N
7628	MEMBRE	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	7666	\N	\N	\N
7629	MEMBRE	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	7667	\N	\N	\N
7630	MEMBRE	2001-10-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	7668	\N	\N	\N
7631	MEMBRE	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	7669	\N	\N	\N
7632	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7670	\N	\N	\N
7633	MEMBRE	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	7671	\N	\N	\N
7634	MEMBRE	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	7672	\N	\N	\N
7640	PDT	2001-10-01 00:00:00	2009-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	7673	\N	\N	\N
7641	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7667	\N	\N	\N
7642	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7671	\N	\N	\N
7643	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7672	\N	\N	\N
7644	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7666	\N	\N	\N
7645	VICPDT	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	7652	\N	\N	\N
7646	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7662	\N	\N	\N
7647	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7653	\N	\N	\N
7648	SECRET	2001-10-01 00:00:00	2004-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	7660	\N	\N	\N
7649	SECRET	2001-10-01 00:00:00	2004-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	7669	\N	\N	\N
7650	SECRET	2001-10-01 00:00:00	2004-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	7656	\N	\N	\N
14693	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13228	\N	\N	\N
14694	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13229	\N	\N	\N
14695	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13230	\N	\N	\N
14696	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13231	\N	\N	\N
14697	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13232	\N	\N	\N
7651	MEMBRE	2001-10-01 00:00:00	2008-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	7676	\N	\N	\N
7652	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7677	\N	\N	\N
7653	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7678	\N	\N	\N
7654	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7679	\N	\N	\N
7655	MEMBRE	2002-07-24 00:00:00	2002-07-24 00:00:00	ANCIEN	\N	\N	\N	\N	7680	\N	\N	\N
7656	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7681	\N	\N	\N
7657	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7682	\N	\N	\N
7658	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7683	\N	\N	\N
7659	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7684	\N	\N	\N
7660	MEMBRE	2001-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	7685	\N	\N	\N
7661	MEMBRE	2001-10-01 00:00:00	2003-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	7686	\N	\N	\N
7662	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7687	\N	\N	\N
7663	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7688	\N	\N	\N
7664	MEMBRE	2001-10-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	7689	\N	\N	\N
7667	MEMBRE	2001-10-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	7692	\N	\N	\N
7668	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7693	\N	\N	\N
7669	MEMBRE	2002-07-24 00:00:00	2002-07-24 00:00:00	ANCIEN	\N	\N	\N	\N	7694	\N	\N	\N
7670	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7695	\N	\N	\N
7671	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7696	\N	\N	\N
7672	MEMBRE	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	7697	\N	\N	\N
7674	MEMBRE	2001-10-01 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	7699	\N	\N	\N
7675	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7700	\N	\N	\N
7676	PDT	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7697	\N	\N	\N
7677	SECRET	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7691	\N	\N	\N
7678	VICPDT	2002-07-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7690	\N	\N	\N
7679	VICPDT	2002-07-24 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7680	\N	\N	\N
7680	VICPDT	2002-07-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7694	\N	\N	\N
7681	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7701	\N	\N	\N
7682	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7702	\N	\N	\N
7683	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7703	\N	\N	\N
7684	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7704	\N	\N	\N
7685	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7705	\N	\N	\N
7686	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7706	\N	\N	\N
7687	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7707	\N	\N	\N
7688	MEMBRE	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	7708	\N	\N	\N
7689	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7709	\N	\N	\N
7690	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7710	\N	\N	\N
7691	MEMBRE	2001-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	7711	\N	\N	\N
7692	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7712	\N	\N	\N
7693	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7713	\N	\N	\N
7694	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7714	\N	\N	\N
7695	MEMBRE	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	7715	\N	\N	\N
7696	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7716	\N	\N	\N
15744	MEMBRE	2009-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13971	\N	\N	\N
3001	MEMBRE	1999-01-01 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	3041	0	\N	\N
7712	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7727	\N	\N	\N
7713	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7728	\N	\N	\N
7714	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	7729	\N	\N	\N
7720	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	7735	\N	\N	\N
7665	MEMBRE	2002-07-24 00:00:00	2002-07-24 00:00:00	ANCIEN	\N	\N	\N	\N	7690	\N	\N	\N
6054	SECRET	2001-10-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	\N	3263	11	\N	\N
6055	MEMBRE	2001-10-01 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	2100	\N	\N	\N
6057	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5983	\N	\N	\N
6058	MEMBRE	2002-03-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5984	\N	\N	\N
6059	VICPDT	2002-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5985	14	\N	\N
6060	MEMBRE	2002-03-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5986	\N	\N	\N
6061	MEMBRE	2001-10-01 00:00:00	2002-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	5990	\N	\N	\N
7980	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7959	\N	\N	\N
7981	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7960	\N	\N	\N
7982	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7961	\N	\N	\N
7986	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7965	\N	\N	\N
7987	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7966	\N	\N	\N
7988	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7967	\N	\N	\N
7989	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7968	\N	\N	\N
7992	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7971	\N	\N	\N
7993	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7972	\N	\N	\N
7995	MEMBRE	2001-10-01 00:00:00	2002-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	7974	\N	\N	\N
7996	PDT	2002-10-22 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7781	\N	\N	\N
7997	VICPDT	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7866	\N	\N	\N
7998	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7870	\N	\N	\N
7999	VICPDT	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7874	\N	\N	\N
8000	VICPDT	2001-10-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	7877	\N	\N	\N
8001	VICPDT	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7879	\N	\N	\N
8002	VICPDT	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7888	\N	\N	\N
8003	SECRET	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7865	\N	\N	\N
8004	SECRET	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7868	\N	\N	\N
8005	SECRET	2003-10-08 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7889	\N	\N	\N
8006	PDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7883	\N	\N	\N
8007	MEMBRE	2003-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7975	\N	\N	\N
8008	PDT	2001-12-05 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7831	\N	\N	\N
8009	VICPDT	2001-12-05 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7839	\N	\N	\N
8010	VICPDT	2001-12-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7801	\N	\N	\N
8012	VICPDT	2001-12-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7814	\N	\N	\N
8015	SECRET	2001-12-05 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7792	\N	\N	\N
8016	SECRET	2001-12-05 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7797	\N	\N	\N
8017	SECRET	2001-12-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7810	\N	\N	\N
8018	SECRET	2001-12-05 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7817	\N	\N	\N
8020	MEMBREBUR	2001-12-05 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7833	\N	\N	\N
8024	MEMBRE	2003-06-25 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	7976	\N	\N	\N
8023	MEMBREBUR	2001-12-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7836	\N	\N	\N
8026	MEMBRE	2003-06-25 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	7978	2	\N	\N
8027	SECRET	2003-06-25 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7979	6	\N	\N
8028	MEMBRE	2003-06-25 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7980	\N	\N	\N
8030	SECRET	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7983	8	\N	\N
8031	MEMBRE	1999-01-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	7984	\N	\N	\N
8032	MEMBRE	1999-01-01 00:00:00	2005-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	7985	\N	\N	\N
8033	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7986	\N	\N	\N
8034	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7987	\N	\N	\N
8035	VICPDT	2002-10-22 00:00:00	2010-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	7777	\N	\N	\N
8036	VICPDT	2002-10-22 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7974	\N	\N	\N
8038	MEMBRE	2003-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7988	\N	\N	\N
8039	MEMBRE	2003-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7989	\N	\N	\N
8040	MEMBRE	2003-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7990	\N	\N	\N
8041	MEMBRE	2003-10-01 00:00:00	2003-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	7991	\N	\N	\N
8043	MEMBRE	2002-12-04 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7993	\N	\N	\N
8044	MEMBRE	2002-12-04 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7994	\N	\N	\N
8045	MEMBRE	2002-12-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7995	\N	\N	\N
8047	MEMBRE	2002-12-04 00:00:00	2002-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	7997	\N	\N	\N
8048	MEMBRE	2002-12-04 00:00:00	2002-12-05 00:00:00	ANCIEN	\N	\N	\N	\N	7998	\N	\N	\N
8049	MEMBRE	2002-12-04 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7999	\N	\N	\N
8050	MEMBRE	2002-12-04 00:00:00	2002-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	8000	\N	\N	\N
8051	MEMBRE	2002-12-04 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8001	\N	\N	\N
8052	MEMBRE	2002-12-04 00:00:00	2002-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	8002	\N	\N	\N
8053	MEMBRE	2002-12-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8003	\N	\N	\N
8054	MEMBRE	2002-12-04 00:00:00	2002-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	8004	\N	\N	\N
8055	MEMBRE	2002-12-04 00:00:00	2002-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	8005	\N	\N	\N
8056	MEMBRE	2002-12-04 00:00:00	2002-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	8006	\N	\N	\N
8057	PDT	2002-12-04 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	7996	\N	\N	\N
8058	VICPDT	2002-12-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7998	\N	\N	\N
8059	VICPDT	2002-12-05 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	8005	\N	\N	\N
8061	VICPDT	2002-12-05 00:00:00	2004-04-28 00:00:00	ANCIEN	\N	\N	\N	\N	8004	\N	\N	\N
8062	VICPDT	2002-12-05 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	8006	\N	\N	\N
8063	SECRET	2002-12-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8000	\N	\N	\N
8064	TRESOR	2002-12-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8002	\N	\N	\N
8065	MEMBRE	2002-12-04 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	8007	\N	\N	\N
7424	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7509	\N	\N	\N
7425	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7510	\N	\N	\N
7426	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7511	\N	\N	\N
7427	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7512	\N	\N	\N
7429	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7514	\N	\N	\N
7431	PDTHON	2001-10-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7486	\N	\N	\N
7432	PDT	2001-10-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7477	\N	\N	\N
7433	VICPDT	2001-10-02 00:00:00	2004-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	7476	\N	\N	\N
7434	VICPDT	2001-10-02 00:00:00	2004-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	7488	\N	\N	\N
7436	VICPDT	2001-10-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7483	\N	\N	\N
7437	SECRET	2001-10-02 00:00:00	2004-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	7500	\N	\N	\N
7438	PDT	2001-10-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7417	\N	\N	\N
7439	VICPDT	2001-10-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7438	\N	\N	\N
7440	VICPDT	2001-10-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7433	\N	\N	\N
7442	VICPDT	2001-10-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7439	\N	\N	\N
7445	MEMBRE	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	7516	\N	\N	\N
7446	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7517	\N	\N	\N
7447	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7518	\N	\N	\N
7448	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7519	\N	\N	\N
7450	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	7521	\N	\N	\N
7451	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7522	\N	\N	\N
7452	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7523	\N	\N	\N
7453	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7524	\N	\N	\N
7454	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7525	\N	\N	\N
7455	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7526	\N	\N	\N
7456	MEMBRE	2001-10-01 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	7527	\N	\N	\N
7458	MEMBRE	2001-10-01 00:00:00	2005-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7529	\N	\N	\N
7459	MEMBRE	2001-10-01 00:00:00	2005-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7530	\N	\N	\N
7460	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7531	\N	\N	\N
7461	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7532	\N	\N	\N
7463	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7534	\N	\N	\N
7464	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7535	\N	\N	\N
7465	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	7536	\N	\N	\N
7466	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7537	\N	\N	\N
7467	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7538	\N	\N	\N
7335	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7432	\N	\N	\N
7336	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7433	\N	\N	\N
7337	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7434	\N	\N	\N
7338	MEMBRE	2001-10-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	7435	\N	\N	\N
7339	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7436	\N	\N	\N
7340	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	7437	\N	\N	\N
7341	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7438	\N	\N	\N
7343	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7440	\N	\N	\N
7345	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	7442	\N	\N	\N
7346	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7443	\N	\N	\N
7347	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7444	\N	\N	\N
7348	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7445	\N	\N	\N
8082	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8024	\N	\N	\N
8083	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8025	\N	\N	\N
8084	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8026	\N	\N	\N
2810	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2838	\N	\N	\N
8087	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8029	\N	\N	\N
8088	MEMBRE	2001-10-01 00:00:00	2009-09-09 00:00:00	ANCIEN	\N	\N	\N	\N	8030	\N	\N	\N
8089	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8031	\N	\N	\N
8090	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8032	\N	\N	\N
8091	MEMBRE	2001-10-01 00:00:00	2005-03-19 00:00:00	ANCIEN	\N	\N	\N	\N	8033	\N	\N	\N
8116	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8049	\N	\N	\N
8093	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8035	\N	\N	\N
8117	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8050	\N	\N	\N
8096	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8038	\N	\N	\N
8098	MEMBRE	2001-10-01 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	8040	\N	\N	\N
8099	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8041	\N	\N	\N
8100	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8042	\N	\N	\N
8119	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8052	\N	\N	\N
8102	PDT	1995-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8014	\N	\N	\N
8104	VICPDT	1995-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8036	\N	\N	\N
8105	VICPDT	1995-10-01 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	8043	\N	\N	\N
8106	VICPDT	1995-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8039	\N	\N	\N
8108	SECRET	1995-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8034	\N	\N	\N
8109	TRESOR	1995-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8017	\N	\N	\N
8111	MEMBRE	1995-10-01 00:00:00	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	8044	\N	\N	\N
8120	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8053	\N	\N	\N
8122	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8055	\N	\N	\N
8123	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8056	\N	\N	\N
8125	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8058	\N	\N	\N
8127	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8060	\N	\N	\N
8129	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8062	\N	\N	\N
8131	MEMBRE	2001-10-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	8064	\N	\N	\N
8133	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8066	\N	\N	\N
8134	MEMBRE	2001-10-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	8067	\N	\N	\N
8135	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8068	\N	\N	\N
8138	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8071	\N	\N	\N
8141	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8074	\N	\N	\N
8140	MEMBRE	2001-10-01 00:00:00	2004-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	8073	\N	\N	\N
8144	MEMBREBUR	1995-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8044	\N	\N	\N
8143	PDT	2001-10-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8075	\N	\N	\N
8145	MEMBRE	2001-10-01 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	8076	\N	\N	\N
8147	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8078	\N	\N	\N
8148	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8079	\N	\N	\N
8149	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8080	\N	\N	\N
8150	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8081	\N	\N	\N
8151	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8082	\N	\N	\N
8152	MEMBRE	2001-10-01 00:00:00	2007-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	8083	\N	\N	\N
8153	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8084	\N	\N	\N
8154	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8085	\N	\N	\N
8155	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8086	\N	\N	\N
8156	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8087	\N	\N	\N
8157	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8088	\N	\N	\N
8161	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8092	\N	\N	\N
8163	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8094	\N	\N	\N
8164	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8095	\N	\N	\N
8165	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8096	\N	\N	\N
8166	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8097	\N	\N	\N
8168	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8099	\N	\N	\N
8169	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8100	\N	\N	\N
8170	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8101	\N	\N	\N
8171	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8102	\N	\N	\N
8172	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8103	\N	\N	\N
8173	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8104	\N	\N	\N
8174	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8105	\N	\N	\N
8176	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8107	\N	\N	\N
8177	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8108	\N	\N	\N
8178	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8109	\N	\N	\N
8179	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8110	\N	\N	\N
8180	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8111	\N	\N	\N
8182	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8113	\N	\N	\N
8183	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8114	\N	\N	\N
8184	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8115	\N	\N	\N
8185	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8116	\N	\N	\N
8189	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8120	\N	\N	\N
8190	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8121	\N	\N	\N
8192	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8123	\N	\N	\N
8193	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8124	\N	\N	\N
8194	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8125	\N	\N	\N
8195	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8126	\N	\N	\N
8197	MEMBRE	2001-10-01 00:00:00	2003-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	8128	\N	\N	\N
8198	MEMBRE	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	8129	\N	\N	\N
8199	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8130	\N	\N	\N
8200	MEMBRE	2001-10-01 00:00:00	2007-06-24 00:00:00	ANCIEN	\N	\N	\N	\N	8131	\N	\N	\N
8201	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8132	\N	\N	\N
8203	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8134	\N	\N	\N
8204	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8135	\N	\N	\N
8209	MEMBRE	2001-10-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	8140	\N	\N	\N
8214	MEMBRE	2001-10-01 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	\N	8145	\N	\N	\N
8215	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8146	\N	\N	\N
8216	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8147	\N	\N	\N
8217	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8148	\N	\N	\N
8218	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8149	\N	\N	\N
8220	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8151	\N	\N	\N
8221	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8152	\N	\N	\N
8222	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8153	\N	\N	\N
8223	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8154	\N	\N	\N
8224	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8155	\N	\N	\N
8226	MEMBRE	2001-10-01 00:00:00	2005-03-19 00:00:00	ANCIEN	\N	\N	\N	\N	8157	\N	\N	\N
8228	MEMBRE	2001-10-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	8159	\N	\N	\N
8229	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8160	\N	\N	\N
8230	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8161	\N	\N	\N
8231	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8162	\N	\N	\N
8233	MEMBRE	2001-10-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	8164	\N	\N	\N
8234	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8165	\N	\N	\N
8237	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8168	\N	\N	\N
8238	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8169	\N	\N	\N
8241	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8172	\N	\N	\N
8243	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8174	\N	\N	\N
8245	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8176	\N	\N	\N
8247	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8178	\N	\N	\N
8248	MEMBRE	2001-10-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	8179	\N	\N	\N
8249	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8180	\N	\N	\N
8251	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8182	\N	\N	\N
8252	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8183	\N	\N	\N
8253	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8184	\N	\N	\N
8255	MEMBRE	2001-10-01 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	8186	\N	\N	\N
8256	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8187	\N	\N	\N
8257	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8188	\N	\N	\N
8259	MEMBRE	2001-10-01 00:00:00	2004-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	8190	\N	\N	\N
8261	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8192	\N	\N	\N
8262	MEMBRE	2001-10-01 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	8193	\N	\N	\N
8263	MEMBRE	2001-10-01 00:00:00	2004-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	8194	\N	\N	\N
8264	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8171	\N	\N	\N
8265	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8195	\N	\N	\N
8266	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8196	\N	\N	\N
8267	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8197	\N	\N	\N
8268	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8198	\N	\N	\N
8269	MEMBRE	2001-10-01 00:00:00	2009-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	8199	\N	\N	\N
8270	MEMBRE	2001-10-01 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	8200	\N	\N	\N
8271	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8201	\N	\N	\N
8273	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8203	\N	\N	\N
8274	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8204	\N	\N	\N
8275	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8205	\N	\N	\N
8276	MEMBRE	2001-10-01 00:00:00	2003-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	8206	\N	\N	\N
8277	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8207	\N	\N	\N
8278	MEMBRE	2001-10-01 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	8208	\N	\N	\N
8279	MEMBRE	2001-10-01 00:00:00	2003-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	8209	\N	\N	\N
8281	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8211	\N	\N	\N
8283	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8213	\N	\N	\N
8284	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8214	\N	\N	\N
8285	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8215	\N	\N	\N
8287	MEMBRE	2001-10-01 00:00:00	2003-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	8217	\N	\N	\N
8288	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8218	\N	\N	\N
8290	MEMBRE	2001-10-01 00:00:00	2003-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	8220	\N	\N	\N
8291	MEMBRE	2001-10-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	8221	\N	\N	\N
8292	MEMBRE	2001-10-01 00:00:00	2003-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	8222	\N	\N	\N
8293	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8223	\N	\N	\N
8295	MEMBRE	2001-10-01 00:00:00	2007-02-25 00:00:00	ANCIEN	\N	\N	\N	\N	8225	\N	\N	\N
8296	MEMBRE	2001-10-01 00:00:00	2003-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	8226	\N	\N	\N
8298	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8228	\N	\N	\N
8299	MEMBRE	2001-10-01 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	8229	\N	\N	\N
8301	PDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8185	\N	\N	\N
8302	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8231	\N	\N	\N
8303	MEMBRE	2001-10-01 00:00:00	2003-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	8232	\N	\N	\N
8304	MEMBRE	2001-10-01 00:00:00	2003-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	8233	\N	\N	\N
8305	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8234	\N	\N	\N
8306	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8235	\N	\N	\N
8307	MEMBRE	2001-10-01 00:00:00	2003-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	8236	\N	\N	\N
8308	MEMBRE	2001-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	8237	\N	\N	\N
8309	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8238	\N	\N	\N
8310	MEMBRE	2001-10-01 00:00:00	2003-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	8239	\N	\N	\N
8311	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8240	\N	\N	\N
8312	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8241	\N	\N	\N
8314	MEMBRE	2001-10-01 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	8242	\N	\N	\N
8315	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8243	\N	\N	\N
8316	MEMBRE	2001-10-01 00:00:00	2005-03-19 00:00:00	ANCIEN	\N	\N	\N	\N	8244	\N	\N	\N
8317	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8245	\N	\N	\N
8318	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8246	\N	\N	\N
8320	MEMBRE	2001-10-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	8247	\N	\N	\N
8322	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8249	\N	\N	\N
8323	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8250	\N	\N	\N
8324	MEMBRE	2001-10-01 00:00:00	2003-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	8251	\N	\N	\N
8326	VICPDT	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8122	\N	\N	\N
8327	MEMBRE	2001-10-01 00:00:00	2003-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	8253	\N	\N	\N
8328	MEMBRE	2001-10-01 00:00:00	2009-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	8254	\N	\N	\N
8329	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8255	\N	\N	\N
8331	MEMBRE	2001-10-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	8257	\N	\N	\N
8332	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8258	\N	\N	\N
8333	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8259	\N	\N	\N
8334	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8260	\N	\N	\N
8336	VICPDT	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8133	\N	\N	\N
8337	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8262	\N	\N	\N
8339	MEMBRE	2001-10-01 00:00:00	2003-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	8264	\N	\N	\N
8340	VICPDT	2001-10-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	8136	\N	\N	\N
8341	VICPDT	2001-10-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	8163	\N	\N	\N
8342	VICPDT	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8167	\N	\N	\N
8343	PDT	2003-10-10 00:00:00	2009-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	8253	\N	\N	\N
8344	VICPDT	2003-10-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8236	\N	\N	\N
8345	VICPDT	2003-10-10 00:00:00	2009-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	8264	\N	\N	\N
8346	VICPDT	2003-10-10 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8209	\N	\N	\N
8349	VICPDT	2003-10-10 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	8248	\N	\N	\N
8350	VICPDT	2003-10-10 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8233	\N	\N	\N
8351	VICPDT	2003-10-10 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	8232	\N	\N	\N
8352	VICPDT	2003-10-10 00:00:00	2009-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	8206	\N	\N	\N
8354	SECRET	2003-10-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8222	\N	\N	\N
8355	VICPDT	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8177	\N	\N	\N
8356	SECRET	2003-10-10 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8220	\N	\N	\N
8357	SECRET	2003-10-10 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8217	\N	\N	\N
8359	VICPDT	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8189	\N	\N	\N
8360	SECRET	2003-10-10 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8239	\N	\N	\N
8362	MEMBRE	2001-10-01 00:00:00	2003-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	8265	\N	\N	\N
8363	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8266	\N	\N	\N
8364	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8267	\N	\N	\N
8368	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8270	\N	\N	\N
8366	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8268	\N	\N	\N
8367	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8269	\N	\N	\N
8370	SECRET	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8077	\N	\N	\N
8371	MEMBRE	2001-10-01 00:00:00	2003-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	8272	\N	\N	\N
8372	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8273	\N	\N	\N
8373	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8274	\N	\N	\N
8374	SECRET	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8093	\N	\N	\N
8375	MEMBRE	2001-10-01 00:00:00	2003-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	8275	\N	\N	\N
8378	MEMBRE	2001-10-01 00:00:00	2003-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	8278	\N	\N	\N
8379	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8279	\N	\N	\N
8380	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8280	\N	\N	\N
8382	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8282	\N	\N	\N
8383	MEMBRE	2001-10-01 00:00:00	2003-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	8283	\N	\N	\N
8385	MEMBRE	2001-10-01 00:00:00	2003-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	8285	\N	\N	\N
8386	MEMBRE	2001-10-01 00:00:00	2003-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	8286	\N	\N	\N
8387	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8287	\N	\N	\N
8388	MEMBRE	2001-10-01 00:00:00	2007-02-25 00:00:00	ANCIEN	\N	\N	\N	\N	8288	\N	\N	\N
8389	SECRET	2001-10-01 00:00:00	2008-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	8091	\N	\N	\N
8390	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8289	\N	\N	\N
8391	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8290	\N	\N	\N
8392	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8291	\N	\N	\N
8393	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8292	\N	\N	\N
8394	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8293	\N	\N	\N
8395	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8294	\N	\N	\N
8396	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8295	\N	\N	\N
8397	MEMBRE	2001-10-01 00:00:00	2004-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	8296	\N	\N	\N
8398	SECRET	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8119	\N	\N	\N
8399	SECRET	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8137	\N	\N	\N
8401	MEMBRE	2001-10-01 00:00:00	2004-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	8298	\N	\N	\N
8402	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8299	\N	\N	\N
8403	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8300	\N	\N	\N
8404	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8301	\N	\N	\N
8405	SECRET	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8139	\N	\N	\N
8407	MEMBRE	2001-10-01 00:00:00	2004-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	8303	\N	\N	\N
8408	MEMBRE	2001-10-01 00:00:00	2005-03-19 00:00:00	ANCIEN	\N	\N	\N	\N	8304	\N	\N	\N
8409	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8305	\N	\N	\N
8410	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8306	\N	\N	\N
8412	MEMBRE	2001-10-01 00:00:00	2003-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	8307	\N	\N	\N
8413	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8308	\N	\N	\N
8415	MEMBRE	2001-10-01 00:00:00	2003-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	8310	\N	\N	\N
8416	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8311	\N	\N	\N
8417	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8142	\N	\N	\N
8418	MEMBRE	2001-10-01 00:00:00	2005-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8312	\N	\N	\N
8419	MEMBRE	2001-10-01 00:00:00	2003-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	8313	\N	\N	\N
8420	MEMBRE	2001-10-01 00:00:00	2003-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	8314	\N	\N	\N
8422	MEMBRE	2001-10-01 00:00:00	2003-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	8316	\N	\N	\N
8423	MEMBRE	2001-10-01 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	8317	\N	\N	\N
8424	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8143	\N	\N	\N
8425	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8318	\N	\N	\N
8428	PDT	2003-10-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8285	\N	\N	\N
8429	VICPDT	2003-10-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8310	\N	\N	\N
8430	VICPDT	2003-10-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8313	\N	\N	\N
8431	SECRET	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8191	\N	\N	\N
8432	VICPDT	2003-10-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8307	\N	\N	\N
8433	VICPDT	2003-10-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8286	\N	\N	\N
8434	VICPDT	2003-10-10 00:00:00	2009-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	8278	\N	\N	\N
8435	VICPDT	2003-10-10 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	8316	\N	\N	\N
8436	VICPDT	2003-10-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8283	\N	\N	\N
8437	SECRET	2003-10-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8265	\N	\N	\N
8438	SECRET	2003-10-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8272	\N	\N	\N
8439	SECRET	2003-10-10 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8309	\N	\N	\N
8440	SECRET	2003-10-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8314	\N	\N	\N
8441	SECRET	2003-10-10 00:00:00	2009-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	8275	\N	\N	\N
12330	PDT	2007-11-06 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10700	\N	\N	\N
8443	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8321	\N	\N	\N
8444	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8322	\N	\N	\N
8447	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8325	\N	\N	\N
12337	MEMBRE	2007-11-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11599	\N	\N	\N
12338	MEMBRE	2007-11-01 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	11600	\N	\N	\N
12348	VICPDT	2007-10-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5765	12	\N	\N
12349	VICPDT	2007-10-24 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	9954	15	\N	\N
12351	MEMBRE	2007-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11602	\N	\N	\N
8454	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8332	\N	\N	\N
8455	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8333	\N	\N	\N
8456	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8334	\N	\N	\N
8457	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8335	\N	\N	\N
12352	MEMBRE	2007-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11603	\N	\N	\N
8460	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8338	\N	\N	\N
8461	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8339	\N	\N	\N
8462	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8340	\N	\N	\N
8463	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8341	\N	\N	\N
12356	MEMBRE	2007-12-01 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	11606	\N	\N	\N
12357	SECRET	2008-01-10 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11539	\N	\N	\N
8467	MEMBRE	2001-10-01 00:00:00	2010-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	8345	\N	\N	\N
8468	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8346	\N	\N	\N
8469	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8347	\N	\N	\N
8472	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8350	\N	\N	\N
8473	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8351	\N	\N	\N
8477	MEMBRE	2001-10-01 00:00:00	2003-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	8355	\N	\N	\N
7776	MEMBRE	2002-10-02 00:00:00	2002-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	7781	\N	\N	\N
7777	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7782	\N	\N	\N
7779	MEMBRE	2001-10-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	7784	\N	\N	\N
7780	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7785	\N	\N	\N
7781	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7786	\N	\N	\N
7782	MEMBRE	2001-10-01 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	7787	\N	\N	\N
7783	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7788	\N	\N	\N
7784	MEMBRE	2001-10-01 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	7789	\N	\N	\N
7785	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7790	\N	\N	\N
7786	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7791	\N	\N	\N
7787	MEMBRE	2001-10-01 00:00:00	2001-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	7792	\N	\N	\N
7788	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7793	\N	\N	\N
7789	MEMBRE	2001-10-01 00:00:00	2001-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	7794	\N	\N	\N
7790	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7795	\N	\N	\N
7791	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7796	\N	\N	\N
7792	MEMBRE	2001-10-01 00:00:00	2001-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	7797	\N	\N	\N
7794	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7799	\N	\N	\N
7795	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7800	\N	\N	\N
7797	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7802	\N	\N	\N
7798	MEMBRE	2001-10-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	7803	\N	\N	\N
7800	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7805	\N	\N	\N
7801	MEMBRE	2001-10-01 00:00:00	2004-11-11 00:00:00	ANCIEN	\N	\N	\N	\N	7806	\N	\N	\N
7802	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7807	\N	\N	\N
7803	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7808	\N	\N	\N
7805	MEMBRE	2001-10-01 00:00:00	2001-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	7810	\N	\N	\N
7806	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7811	\N	\N	\N
7809	MEMBRE	2001-10-01 00:00:00	2001-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	7814	\N	\N	\N
7810	MEMBRE	2001-10-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	7815	\N	\N	\N
7811	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7816	\N	\N	\N
7812	MEMBRE	2001-10-01 00:00:00	2001-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	7817	\N	\N	\N
7813	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7818	\N	\N	\N
7814	MEMBRE	2001-10-01 00:00:00	2001-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	7819	\N	\N	\N
7817	MEMBRE	2001-10-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	7822	\N	\N	\N
7818	MEMBRE	2001-10-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	7823	\N	\N	\N
7819	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7824	\N	\N	\N
7820	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7825	\N	\N	\N
7821	MEMBRE	2001-10-01 00:00:00	2004-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	7826	\N	\N	\N
7823	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7828	\N	\N	\N
7824	MEMBRE	2001-10-01 00:00:00	2001-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	7829	\N	\N	\N
7825	MEMBRE	2001-10-01 00:00:00	2004-11-11 00:00:00	ANCIEN	\N	\N	\N	\N	7830	\N	\N	\N
7826	MEMBRE	2001-10-01 00:00:00	2001-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	7831	\N	\N	\N
7827	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7832	\N	\N	\N
7828	MEMBRE	2001-10-01 00:00:00	2001-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	7833	\N	\N	\N
7831	MEMBRE	2001-10-01 00:00:00	2001-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	7836	\N	\N	\N
7832	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7837	\N	\N	\N
7834	MEMBRE	2001-10-01 00:00:00	2001-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	7839	\N	\N	\N
7843	MEMBRE	2001-10-01 00:00:00	2001-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	7844	\N	\N	\N
7838	MEMBRE	2001-10-01 00:00:00	2001-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	7842	\N	\N	\N
7839	VICPDT	2001-12-19 00:00:00	2005-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	7842	\N	\N	\N
7844	VICPDT	2001-12-19 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7844	\N	\N	\N
7846	VICPDT	2001-12-19 00:00:00	2009-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	7845	\N	\N	\N
7851	MEMBRE	2001-10-01 00:00:00	2001-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	7848	\N	\N	\N
7852	MEMBREBUR	2001-12-19 00:00:00	2009-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	7848	\N	\N	\N
7855	MEMBRE	2001-10-01 00:00:00	2001-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	7850	\N	\N	\N
7856	MEMBREBUR	2001-12-19 00:00:00	2005-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	7850	\N	\N	\N
7857	MEMBRE	2001-10-01 00:00:00	2009-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	7851	\N	\N	\N
7858	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7852	\N	\N	\N
7862	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7856	\N	\N	\N
7873	MEMBRE	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	7866	\N	\N	\N
7874	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7867	\N	\N	\N
7875	MEMBRE	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	7868	\N	\N	\N
7877	MEMBRE	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	7870	\N	\N	\N
7878	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7871	\N	\N	\N
7879	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7872	\N	\N	\N
7880	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7873	\N	\N	\N
7881	MEMBRE	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	7874	\N	\N	\N
7883	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7876	\N	\N	\N
7884	MEMBRE	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	7877	\N	\N	\N
7885	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7878	\N	\N	\N
7886	MEMBRE	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	7879	\N	\N	\N
7888	MEMBRE	2001-10-01 00:00:00	2003-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	7881	\N	\N	\N
7889	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7882	\N	\N	\N
7890	MEMBRE	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	7883	\N	\N	\N
7891	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7884	\N	\N	\N
7892	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7885	\N	\N	\N
7893	MEMBRE	2001-10-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	7886	\N	\N	\N
7895	MEMBRE	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	7888	\N	\N	\N
7896	MEMBRE	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	7889	\N	\N	\N
7897	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7890	\N	\N	\N
7898	MEMBRE	2001-10-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	7891	\N	\N	\N
7899	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7892	\N	\N	\N
7900	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7893	\N	\N	\N
7901	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7894	\N	\N	\N
7902	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7895	\N	\N	\N
7903	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7896	\N	\N	\N
7904	MEMBRE	2001-10-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	7897	\N	\N	\N
7905	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7898	\N	\N	\N
7906	MEMBRE	2001-10-01 00:00:00	2001-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	7899	\N	\N	\N
7907	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7900	\N	\N	\N
7908	MEMBRE	2001-10-01 00:00:00	2001-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	7901	\N	\N	\N
7909	MEMBRE	2001-10-01 00:00:00	2001-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	7902	\N	\N	\N
7910	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7903	\N	\N	\N
7911	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7904	\N	\N	\N
7913	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7906	\N	\N	\N
7914	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	7907	\N	\N	\N
7915	MEMBRE	2001-10-01 00:00:00	2001-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	7908	\N	\N	\N
7916	MEMBRE	2001-10-01 00:00:00	2001-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	7909	\N	\N	\N
7917	MEMBRE	2001-10-01 00:00:00	2001-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	7910	\N	\N	\N
7919	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7912	\N	\N	\N
7920	MEMBRE	2001-10-01 00:00:00	2005-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	7913	\N	\N	\N
7921	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7914	\N	\N	\N
7925	VICPDT	2001-12-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7899	\N	\N	\N
7923	VICPDT	2001-12-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7908	\N	\N	\N
7927	VICPDT	2001-12-19 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7901	\N	\N	\N
7928	VICPDT	2001-12-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7910	\N	\N	\N
7929	SECRET	2001-12-19 00:00:00	2005-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	7909	\N	\N	\N
7930	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7915	\N	\N	\N
7933	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7918	\N	\N	\N
7934	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7919	\N	\N	\N
7936	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7921	\N	\N	\N
7937	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7922	\N	\N	\N
7939	MEMBRE	2001-10-01 00:00:00	2003-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	7924	\N	\N	\N
7940	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7925	\N	\N	\N
7941	MEMBREBUR	2003-10-07 00:00:00	2004-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	7924	\N	\N	\N
7942	MEMBREBUR	2003-10-07 00:00:00	2004-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	7764	\N	\N	\N
7943	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7926	\N	\N	\N
7945	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7928	\N	\N	\N
7946	MEMBRE	2001-10-01 00:00:00	2007-02-25 00:00:00	ANCIEN	\N	\N	\N	\N	7929	\N	\N	\N
7947	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7930	\N	\N	\N
7949	MEMBRE	2001-10-01 00:00:00	2003-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	7932	\N	\N	\N
7950	MEMBREBUR	2003-10-07 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7932	\N	\N	\N
7951	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7933	\N	\N	\N
7952	MEMBRE	2001-10-01 00:00:00	2004-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	7934	\N	\N	\N
7953	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7935	\N	\N	\N
7954	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7936	\N	\N	\N
7955	MEMBRE	2001-10-01 00:00:00	2004-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	7937	\N	\N	\N
7957	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7939	\N	\N	\N
7958	MEMBRE	2001-10-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	7940	\N	\N	\N
7959	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7941	\N	\N	\N
7961	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7943	\N	\N	\N
7962	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7944	\N	\N	\N
7963	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7945	\N	\N	\N
7965	MEMBRE	2001-10-01 00:00:00	2004-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	7947	\N	\N	\N
7966	MEMBRE	2001-10-01 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	7948	\N	\N	\N
7967	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7949	\N	\N	\N
7968	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7950	\N	\N	\N
7969	MEMBRE	2001-10-01 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	7951	\N	\N	\N
7970	MEMBRE	2001-10-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	7952	\N	\N	\N
7971	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7953	\N	\N	\N
7976	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7955	\N	\N	\N
7974	MEMBRE	2001-10-01 00:00:00	2003-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7954	\N	\N	\N
7978	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7957	\N	\N	\N
9068	MEMBRE	2004-10-15 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	8873	\N	\N	\N
9069	MEMBRE	2004-10-15 00:00:00	2008-06-02 00:00:00	ANCIEN	\N	\N	\N	\N	8874	\N	\N	\N
9070	MEMBRE	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8875	\N	\N	\N
9071	MEMBRE	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8876	\N	\N	\N
9072	MEMBRE	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8877	\N	\N	\N
9073	MEMBRE	2004-10-15 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	8878	0	\N	\N
9074	MEMBRE	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8880	\N	\N	\N
9075	VICPDT	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8881	3	\N	\N
9076	MEMBRE	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8882	\N	\N	\N
9077	MEMBRE	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8883	\N	\N	\N
9078	MEMBRE	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8884	\N	\N	\N
9079	MEMBRE	2004-10-15 00:00:00	2007-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	8885	\N	\N	\N
9080	MEMBREBUR	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8886	9	\N	\N
9082	MEMBRE	2004-10-15 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	\N	8888	\N	\N	\N
9083	MEMBRE	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8889	\N	\N	\N
9084	MEMBREBUR	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8890	12	\N	\N
9085	MEMBRE	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8891	\N	\N	\N
9086	MEMBRE	2003-06-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8893	\N	\N	\N
9087	MEMBRE	2003-06-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8894	\N	\N	\N
9090	MEMBRE	2003-06-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8897	\N	\N	\N
9091	MEMBRE	2004-10-15 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	8898	\N	\N	\N
9092	MEMBRE	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8899	\N	\N	\N
9093	MEMBRE	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8900	\N	\N	\N
9094	MEMBRE	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8901	\N	\N	\N
9095	MEMBRE	2003-06-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8902	\N	\N	\N
9096	MEMBRE	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8903	\N	\N	\N
9099	MEMBRE	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8906	\N	\N	\N
9100	MEMBRE	2004-10-15 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	8907	\N	\N	\N
9101	MEMBRE	2003-06-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8908	\N	\N	\N
9102	MEMBRE	2003-06-30 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	8909	\N	\N	\N
9104	MEMBRE	2003-06-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8911	\N	\N	\N
9105	MEMBRE	2003-06-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8912	\N	\N	\N
9106	MEMBRE	2003-06-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8913	\N	\N	\N
9107	MEMBRE	2003-06-30 00:00:00	2005-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	8914	\N	\N	\N
9108	MEMBRE	2003-06-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8915	\N	\N	\N
9109	MEMBRE	2003-06-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8916	\N	\N	\N
9110	MEMBRE	2003-06-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8917	\N	\N	\N
9111	MEMBRE	2003-06-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8918	\N	\N	\N
9112	MEMBRE	2003-06-30 00:00:00	2010-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	8919	\N	\N	\N
9113	MEMBRE	2003-06-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8920	\N	\N	\N
9116	MEMBRE	2003-06-30 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	\N	8923	\N	\N	\N
9115	MEMBRE	2003-06-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8922	\N	\N	\N
9118	MEMBRE	2003-06-30 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	8925	\N	\N	\N
9119	MEMBRE	2003-06-30 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	8926	\N	\N	\N
9120	MEMBRE	2003-06-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8927	\N	\N	\N
9121	MEMBRE	2003-06-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8928	\N	\N	\N
9122	MEMBRE	2003-06-30 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8929	\N	\N	\N
9123	MEMBRE	2003-06-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8930	\N	\N	\N
9124	MEMBRE	2003-06-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8931	\N	\N	\N
9125	MEMBRE	2003-06-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8932	\N	\N	\N
9126	MEMBRE	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8933	\N	\N	\N
9127	MEMBRE	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8934	\N	\N	\N
9129	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1082	\N	\N	\N
9130	MEMBRE	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8936	\N	\N	\N
9131	MEMBRE	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8937	\N	\N	\N
9132	MEMBRE	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8938	\N	\N	\N
9133	MEMBRE	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8939	\N	\N	\N
7306	MEMBRE	2001-10-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	7403	\N	\N	\N
7308	MEMBRE	2001-10-01 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	\N	7405	\N	\N	\N
7309	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7406	\N	\N	\N
7311	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7408	\N	\N	\N
7312	MEMBRE	2001-10-01 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	\N	7409	\N	\N	\N
7313	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7410	\N	\N	\N
7314	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	7411	\N	\N	\N
7315	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7412	\N	\N	\N
7316	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	7413	\N	\N	\N
7317	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	7414	\N	\N	\N
7318	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	7415	\N	\N	\N
7319	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7416	\N	\N	\N
7321	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	7418	\N	\N	\N
7322	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	7419	\N	\N	\N
7323	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	7420	\N	\N	\N
7324	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7421	\N	\N	\N
7325	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7422	\N	\N	\N
7326	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	7423	\N	\N	\N
7327	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7424	\N	\N	\N
7329	MEMBRE	2001-10-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	7426	\N	\N	\N
7330	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7427	\N	\N	\N
7331	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7428	\N	\N	\N
7332	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	7429	\N	\N	\N
7333	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7430	\N	\N	\N
7085	MEMBRE	2001-10-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	7228	\N	\N	\N
7099	VICPDT	2001-10-01 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	7237	\N	\N	\N
7088	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7231	\N	\N	\N
7101	SECRET	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7233	\N	\N	\N
7091	MEMBRE	2001-10-01 00:00:00	2009-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	7234	\N	\N	\N
7093	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7236	\N	\N	\N
7095	PDT	2001-10-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	7235	\N	\N	\N
7107	PDT	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7241	\N	\N	\N
7104	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	7239	\N	\N	\N
7119	VICPDT	2003-09-20 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7250	\N	\N	\N
7114	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7248	\N	\N	\N
7117	VICPDT	2003-09-20 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7242	\N	\N	\N
7116	VICPDT	2003-09-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7249	\N	\N	\N
7121	VICPDT	2003-09-20 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	7251	\N	\N	\N
7122	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7252	\N	\N	\N
7124	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7254	\N	\N	\N
7125	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7255	\N	\N	\N
7126	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7256	\N	\N	\N
7128	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7258	\N	\N	\N
7129	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7259	\N	\N	\N
7131	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7261	\N	\N	\N
7132	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7262	\N	\N	\N
7135	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7265	\N	\N	\N
7136	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7266	\N	\N	\N
7137	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7267	\N	\N	\N
7138	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7268	\N	\N	\N
7141	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7271	\N	\N	\N
7143	PDT	2003-09-20 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7272	\N	\N	\N
7147	VICPDT	2003-09-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7274	\N	\N	\N
7149	VICPDT	2003-09-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7275	\N	\N	\N
7151	VICPDT	2003-09-20 00:00:00	2004-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	7276	\N	\N	\N
7155	VICPDT	2003-09-20 00:00:00	2004-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	7278	\N	\N	\N
7157	VICPDT	2003-09-20 00:00:00	2004-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	7279	\N	\N	\N
7159	SECRET	2003-09-20 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	7280	\N	\N	\N
7161	SECRET	2003-09-20 00:00:00	2004-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	7281	\N	\N	\N
7163	SECRET	2003-09-20 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7282	\N	\N	\N
7165	TRESOR	2003-09-20 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7283	\N	\N	\N
7167	TRESOR	2003-09-20 00:00:00	2004-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	7284	\N	\N	\N
7169	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7286	\N	\N	\N
7168	MEMBRE	2001-10-01 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	7285	\N	\N	\N
7170	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7287	\N	\N	\N
7171	MEMBRE	2001-10-01 00:00:00	2004-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	7288	\N	\N	\N
7172	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7289	\N	\N	\N
7173	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7290	\N	\N	\N
7174	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7291	\N	\N	\N
7175	MEMBRE	2001-10-01 00:00:00	2006-08-11 00:00:00	ANCIEN	\N	\N	\N	\N	7292	\N	\N	\N
7176	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7293	\N	\N	\N
7177	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7294	\N	\N	\N
7178	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7295	\N	\N	\N
7179	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7296	\N	\N	\N
7180	MEMBRE	2001-10-01 00:00:00	2010-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	7297	\N	\N	\N
7181	MEMBRE	2001-10-01 00:00:00	2004-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	7298	\N	\N	\N
7182	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7299	\N	\N	\N
7183	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7300	\N	\N	\N
7185	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7302	\N	\N	\N
7187	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7304	\N	\N	\N
7188	MEMBRE	2001-10-01 00:00:00	2009-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	7305	\N	\N	\N
7189	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7306	\N	\N	\N
7190	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7307	\N	\N	\N
7191	MEMBRE	2001-10-01 00:00:00	2005-03-19 00:00:00	ANCIEN	\N	\N	\N	\N	7308	\N	\N	\N
7192	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7309	\N	\N	\N
7193	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7310	\N	\N	\N
7194	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7311	\N	\N	\N
7195	MEMBRE	2001-10-01 00:00:00	2004-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	7312	\N	\N	\N
7197	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7314	\N	\N	\N
7198	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7315	\N	\N	\N
7199	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7316	\N	\N	\N
7203	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7320	\N	\N	\N
7204	MEMBREBUR	2003-09-22 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	7245	\N	\N	\N
7205	MEMBREBUR	2003-09-22 00:00:00	2004-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	7247	\N	\N	\N
7206	MEMBREBUR	2003-09-22 00:00:00	2004-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	7246	\N	\N	\N
7207	MEMBREBUR	2003-09-22 00:00:00	2004-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	7260	\N	\N	\N
7210	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7323	\N	\N	\N
7212	MEMBRE	2001-10-01 00:00:00	2004-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	7325	\N	\N	\N
7213	MEMBRE	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	7326	\N	\N	\N
7215	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7328	\N	\N	\N
7216	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7329	\N	\N	\N
7217	MEMBRE	2001-10-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	7330	\N	\N	\N
7218	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7331	\N	\N	\N
7221	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7334	\N	\N	\N
7222	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7335	\N	\N	\N
7224	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7337	\N	\N	\N
7225	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7338	\N	\N	\N
7226	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7339	\N	\N	\N
7227	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7340	\N	\N	\N
7228	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7341	\N	\N	\N
7229	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7342	\N	\N	\N
7230	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7343	\N	\N	\N
7231	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7344	\N	\N	\N
7232	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7345	\N	\N	\N
7233	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7346	\N	\N	\N
7235	MEMBRE	2001-10-01 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	7348	\N	\N	\N
7236	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7349	\N	\N	\N
7237	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7350	\N	\N	\N
7238	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7351	\N	\N	\N
7239	MEMBRE	2001-10-01 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	7352	\N	\N	\N
7240	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7353	\N	\N	\N
7241	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7354	\N	\N	\N
7242	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7355	\N	\N	\N
7243	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7356	\N	\N	\N
7244	MEMBRE	2001-10-01 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	7357	\N	\N	\N
7245	MEMBRE	2001-10-01 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	7358	\N	\N	\N
7246	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7359	\N	\N	\N
7247	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7360	\N	\N	\N
7249	PDT	2001-10-03 00:00:00	2004-05-14 00:00:00	ANCIEN	\N	\N	\N	\N	7346	\N	\N	\N
7251	VICPDT	2001-10-02 00:00:00	2004-10-30 00:00:00	ANCIEN	\N	\N	\N	\N	7335	\N	\N	\N
7252	VICPDT	2001-10-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7353	\N	\N	\N
7255	SECRET	2001-10-02 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7319	\N	\N	\N
7257	MEMBRE	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	7361	\N	\N	\N
7258	VICPDT	2001-10-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7361	\N	\N	\N
7259	MEMBRE	2002-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7362	\N	\N	\N
7261	MEMBRE	2002-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7364	\N	\N	\N
7262	MEMBRE	2002-01-01 00:00:00	2002-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	7365	\N	\N	\N
7263	MEMBRE	2002-01-01 00:00:00	2007-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	7366	\N	\N	\N
7264	MEMBRE	2002-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7367	\N	\N	\N
7265	MEMBRE	2002-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7368	\N	\N	\N
7266	MEMBRE	2002-01-01 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	7369	\N	\N	\N
7267	MEMBRE	2002-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7370	\N	\N	\N
7268	MEMBRE	2002-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7371	\N	\N	\N
7269	MEMBRE	2002-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7372	\N	\N	\N
7270	MEMBRE	2002-01-01 00:00:00	2002-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	7373	\N	\N	\N
7271	MEMBRE	2002-01-01 00:00:00	2002-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	7374	\N	\N	\N
7272	MEMBRE	2002-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7375	\N	\N	\N
7273	MEMBRE	2002-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7376	\N	\N	\N
7274	MEMBRE	2002-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7377	\N	\N	\N
7276	MEMBRE	2002-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7379	\N	\N	\N
7277	MEMBRE	2002-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7380	\N	\N	\N
7278	MEMBRE	2002-01-01 00:00:00	2010-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	7381	\N	\N	\N
7279	MEMBRE	2002-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7382	\N	\N	\N
7280	MEMBRE	2002-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7383	\N	\N	\N
7283	MEMBRE	2002-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7386	\N	\N	\N
7284	MEMBRE	2002-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7387	\N	\N	\N
7286	MEMBRE	2002-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7389	\N	\N	\N
7288	MEMBRE	2002-01-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	7391	\N	\N	\N
7289	MEMBRE	2002-01-01 00:00:00	2002-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	7392	\N	\N	\N
7290	MEMBRE	2002-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7393	\N	\N	\N
7291	MEMBRE	2002-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7394	\N	\N	\N
7292	MEMBRE	2002-01-01 00:00:00	2005-03-19 00:00:00	ANCIEN	\N	\N	\N	\N	7395	\N	\N	\N
7294	MEMBRE	2002-01-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	7397	\N	\N	\N
7468	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7539	\N	\N	\N
7469	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7540	\N	\N	\N
7470	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7541	\N	\N	\N
7471	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7542	\N	\N	\N
7472	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7543	\N	\N	\N
7473	MEMBRE	2001-10-01 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	7544	\N	\N	\N
7474	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7545	\N	\N	\N
7476	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7547	\N	\N	\N
7478	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	7549	\N	\N	\N
7479	PDT	2001-10-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7533	\N	\N	\N
7480	VICPDT	2001-10-02 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	7538	\N	\N	\N
7482	VICPDT	2001-10-02 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	7547	\N	\N	\N
7483	VICPDT	2001-10-02 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7520	\N	\N	\N
7484	VICPDT	2001-10-02 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	7548	\N	\N	\N
7485	VICPDT	2001-10-02 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	7531	\N	\N	\N
7486	VICPDT	2001-10-02 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	7516	\N	\N	\N
7487	SECRET	2001-10-02 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7539	\N	\N	\N
7491	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7552	\N	\N	\N
7493	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7554	\N	\N	\N
7494	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7555	\N	\N	\N
7496	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7557	\N	\N	\N
7497	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7558	\N	\N	\N
7498	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7559	\N	\N	\N
7499	MEMBRE	2001-10-01 00:00:00	2002-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7560	\N	\N	\N
7501	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7562	\N	\N	\N
7502	MEMBRE	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	7563	\N	\N	\N
7503	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7564	\N	\N	\N
7504	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7565	\N	\N	\N
7506	MEMBRE	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	7567	\N	\N	\N
7507	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7568	\N	\N	\N
7508	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7569	\N	\N	\N
7510	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7571	\N	\N	\N
7511	MEMBRE	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	7572	\N	\N	\N
7512	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7573	\N	\N	\N
7513	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7574	\N	\N	\N
7515	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7576	\N	\N	\N
7516	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7577	\N	\N	\N
7518	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7579	\N	\N	\N
7519	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7580	\N	\N	\N
7520	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7581	\N	\N	\N
7521	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7582	\N	\N	\N
7522	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7583	\N	\N	\N
7523	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7584	\N	\N	\N
7524	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7585	\N	\N	\N
7527	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7588	\N	\N	\N
7528	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7589	\N	\N	\N
7529	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7590	\N	\N	\N
7530	MEMBRE	2001-10-01 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	\N	7591	\N	\N	\N
7531	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7592	\N	\N	\N
7533	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7594	\N	\N	\N
7534	MEMBRE	2001-10-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	7595	\N	\N	\N
7535	MEMBRE	2001-10-01 00:00:00	2005-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	7596	\N	\N	\N
7536	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7598	\N	\N	\N
7537	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7597	\N	\N	\N
7538	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7599	\N	\N	\N
7540	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7601	\N	\N	\N
7541	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7602	\N	\N	\N
7542	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7603	\N	\N	\N
7543	MEMBRE	2001-10-01 00:00:00	2005-03-19 00:00:00	ANCIEN	\N	\N	\N	\N	7604	\N	\N	\N
7544	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7605	\N	\N	\N
7545	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7606	\N	\N	\N
7546	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7607	\N	\N	\N
7547	MEMBRE	2001-10-01 00:00:00	2009-09-09 00:00:00	ANCIEN	\N	\N	\N	\N	7608	\N	\N	\N
7548	MEMBRE	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	7609	\N	\N	\N
7549	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7610	\N	\N	\N
7551	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7612	\N	\N	\N
7552	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7613	\N	\N	\N
7553	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7614	\N	\N	\N
7554	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7615	\N	\N	\N
7555	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7616	\N	\N	\N
7558	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7619	\N	\N	\N
7560	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7621	\N	\N	\N
7561	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7622	\N	\N	\N
7562	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7623	\N	\N	\N
7564	MEMBRE	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	7625	\N	\N	\N
7565	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7626	\N	\N	\N
7567	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7628	\N	\N	\N
7568	MEMBRE	2001-10-01 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	\N	7629	\N	\N	\N
7569	MEMBRE	2001-10-01 00:00:00	2005-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	7630	\N	\N	\N
7571	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7632	\N	\N	\N
7572	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7633	\N	\N	\N
7573	MEMBRE	2001-10-01 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	7634	\N	\N	\N
7574	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7635	\N	\N	\N
7575	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7636	\N	\N	\N
7577	PDT	2002-10-02 00:00:00	2009-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	7560	\N	\N	\N
7579	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7638	\N	\N	\N
7580	VICPDT	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7611	\N	\N	\N
7581	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7639	\N	\N	\N
7582	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7640	\N	\N	\N
7583	VICPDT	2001-10-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	7609	\N	\N	\N
7585	VICPDT	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7625	\N	\N	\N
7586	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7567	\N	\N	\N
7587	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7641	\N	\N	\N
7588	MEMBRE	2001-10-01 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	7642	\N	\N	\N
7589	SECRET	2001-10-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	7572	\N	\N	\N
7590	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7643	\N	\N	\N
7591	SECRET	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7586	\N	\N	\N
7593	MEMBRE	2001-10-01 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	7645	\N	\N	\N
7594	PDT	2001-10-03 00:00:00	2005-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	7593	\N	\N	\N
7595	VICPDT	2001-10-02 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	7610	\N	\N	\N
7596	VICPDT	2001-10-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7612	\N	\N	\N
7597	VICPDT	2001-10-02 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7620	\N	\N	\N
7598	VICPDT	2001-10-02 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7622	\N	\N	\N
7599	SECRET	2001-10-02 00:00:00	2005-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	7566	\N	\N	\N
7600	SECRET	2001-10-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7592	\N	\N	\N
7601	MEMBREBUR	2001-10-02 00:00:00	2005-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	7568	\N	\N	\N
7602	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7646	\N	\N	\N
7603	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7647	\N	\N	\N
7605	TRESOR	2001-10-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7647	\N	\N	\N
7606	MEMBREBUR	2001-10-02 00:00:00	2007-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	7571	\N	\N	\N
7607	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7648	\N	\N	\N
7608	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7649	\N	\N	\N
7609	MEMBREBUR	2001-10-02 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7648	\N	\N	\N
7610	MEMBREBUR	2001-10-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7649	\N	\N	\N
7611	MEMBREBUR	2001-10-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7644	\N	\N	\N
9555	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9325	\N	\N	\N
9557	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9331	\N	\N	\N
9558	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9333	\N	\N	\N
9559	VICPDT	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9334	4	\N	\N
9560	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9332	\N	\N	\N
9561	PDTDEL	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Liberia	\N	9335	10	\N	\N
9562	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9336	\N	\N	\N
9563	PDTDEL	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Guinée	\N	9337	8	\N	\N
9565	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9339	\N	\N	\N
9566	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9340	\N	\N	\N
9567	VICPDT	2004-10-01 00:00:00	2009-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	9342	\N	\N	\N
9568	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9341	\N	\N	\N
9570	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9344	\N	\N	\N
9571	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9345	\N	\N	\N
9572	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9346	\N	\N	\N
9574	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9348	\N	\N	\N
9575	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9349	\N	\N	\N
9576	MEMBRE	2004-10-01 00:00:00	2009-09-09 00:00:00	ANCIEN	\N	\N	\N	\N	9350	\N	\N	\N
9577	MEMBRE	2004-10-01 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	\N	9351	\N	\N	\N
9578	SECRET	2004-10-01 00:00:00	2009-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	9353	\N	\N	\N
9579	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9352	\N	\N	\N
9580	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9354	\N	\N	\N
9581	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9355	\N	\N	\N
9582	VICPDT	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9356	20	\N	\N
9583	VICPDT	2004-10-01 00:00:00	2009-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	9358	\N	\N	\N
9584	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9357	\N	\N	\N
9586	VICPDT	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9360	11	\N	\N
9587	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9361	\N	\N	\N
9588	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9362	\N	\N	\N
9590	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9364	\N	\N	\N
9591	MEMBRE	2004-10-01 00:00:00	2009-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	9365	0	\N	\N
9592	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9366	\N	\N	\N
9593	PDTDEL	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	Niger	\N	9367	13	\N	\N
9594	SECRET	2004-10-22 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	8857	6	\N	\N
9595	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9369	\N	\N	\N
9596	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9370	\N	\N	\N
9597	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9371	\N	\N	\N
9598	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9372	\N	\N	\N
9599	SECRET	2004-10-01 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	9373	8	\N	\N
9601	MEMBRE	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	9374	\N	\N	\N
9602	VICPDT	2004-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	9376	5	\N	\N
9603	MEMBRE	2004-10-01 00:00:00	2009-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	9377	0	\N	\N
9606	MEMBRE	2004-10-01 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	9380	0	\N	\N
9607	MEMBRE	2004-10-01 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	9381	0	\N	\N
9608	MEMBRE	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	9382	\N	\N	\N
9609	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9383	\N	\N	\N
9610	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9383	\N	\N	\N
9611	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9385	\N	\N	\N
9612	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9386	\N	\N	\N
9613	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9387	\N	\N	\N
9614	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9388	\N	\N	\N
9616	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9389	\N	\N	\N
9617	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9391	\N	\N	\N
9618	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9392	\N	\N	\N
9619	MEMBRE	2004-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	9393	\N	\N	\N
9620	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9394	\N	\N	\N
9621	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9395	\N	\N	\N
9622	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9396	\N	\N	\N
9623	MEMBRE	2004-10-01 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	\N	9397	\N	\N	\N
9624	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9398	\N	\N	\N
9625	SECRET	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9399	12	\N	\N
9626	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9400	\N	\N	\N
9628	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9402	\N	\N	\N
9629	MEMBRE	2004-10-01 00:00:00	2009-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	9403	\N	\N	\N
9630	MEMBRE	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	9404	\N	\N	\N
9631	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9405	\N	\N	\N
9632	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9406	\N	\N	\N
9633	MEMBRE	2004-10-01 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	9407	0	\N	\N
9634	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9408	\N	\N	\N
9635	MEMBRE	2004-10-01 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	9409	\N	\N	\N
9636	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9410	\N	\N	\N
9637	PDT	2004-12-01 00:00:00	2009-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	4297	1	\N	\N
9639	VICPDT	2004-12-01 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	\N	5479	3	\N	\N
9640	VICPDT	2004-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4295	4	\N	\N
9642	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9412	\N	\N	\N
9643	SECRET	2004-12-01 00:00:00	2009-01-14 00:00:00	ANCIEN	\N	\N	\N	\N	4265	\N	\N	\N
9644	SECRET	2004-12-01 00:00:00	2009-01-14 00:00:00	ANCIEN	\N	\N	\N	\N	4275	\N	\N	\N
9645	SECRET	2004-12-01 00:00:00	2009-01-14 00:00:00	ANCIEN	\N	\N	\N	\N	6605	\N	\N	\N
9647	TRESOR	2004-12-01 00:00:00	2009-01-14 00:00:00	ANCIEN	\N	\N	\N	\N	5475	\N	\N	\N
9648	TRESOR	2004-12-01 00:00:00	2009-01-14 00:00:00	ANCIEN	\N	\N	\N	\N	4299	\N	\N	\N
9649	VICPDT	2004-11-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5300	4	\N	\N
9650	VICPDT	2004-11-24 00:00:00	2009-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	8522	\N	\N	\N
9651	VICPDT	2004-11-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8996	10	\N	\N
9653	MEMBRE	2004-12-07 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7956	\N	\N	\N
9659	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9417	\N	\N	\N
9655	VICPDT	2004-12-07 00:00:00	2010-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	9415	\N	\N	\N
9656	VICPDT	2004-12-07 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7970	\N	\N	\N
9657	VICPDT	2004-12-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8867	\N	\N	\N
9658	SECRET	2004-12-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9015	\N	\N	\N
9660	MEMBRE	2004-10-01 00:00:00	2008-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	9418	0	\N	\N
9661	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9419	\N	\N	\N
9662	MEMBRE	2004-10-01 00:00:00	2008-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	9420	0	\N	\N
9663	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9421	\N	\N	\N
9664	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9422	\N	\N	\N
9665	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9423	\N	\N	\N
9666	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9424	\N	\N	\N
9667	SECRET	2004-10-01 00:00:00	2008-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	9425	11	\N	\N
9668	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9426	\N	\N	\N
9669	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9427	\N	\N	\N
9670	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9428	\N	\N	\N
9671	MEMBRE	2004-10-01 00:00:00	2010-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	9429	\N	\N	\N
9672	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9430	\N	\N	\N
9673	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9431	\N	\N	\N
9674	MEMBRE	2004-10-01 00:00:00	2007-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	9432	\N	\N	\N
9675	MEMBRE	2004-10-01 00:00:00	2005-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	9433	\N	\N	\N
9676	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9436	\N	\N	\N
9677	SECRET	2004-10-01 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	9437	15	\N	\N
9678	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9438	\N	\N	\N
9679	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9439	\N	\N	\N
9681	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9441	\N	\N	\N
9684	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9444	\N	\N	\N
9685	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9445	\N	\N	\N
9686	MEMBRE	2004-10-01 00:00:00	2005-03-21 00:00:00	ANCIEN	\N	\N	\N	\N	9446	\N	\N	\N
9687	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9447	\N	\N	\N
9689	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9449	\N	\N	\N
9690	VICPDT	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9450	11	\N	\N
9692	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9452	\N	\N	\N
9694	MEMBRE	2004-10-01 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	9454	\N	\N	\N
9695	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9455	\N	\N	\N
9696	VICPDT	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9456	12	\N	\N
9697	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9457	\N	\N	\N
9698	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9458	\N	\N	\N
9699	MEMBRE	2004-10-01 00:00:00	2005-03-21 00:00:00	ANCIEN	\N	\N	\N	\N	9459	\N	\N	\N
9700	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9460	\N	\N	\N
9701	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9461	\N	\N	\N
9702	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9462	\N	\N	\N
9704	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9464	\N	\N	\N
9705	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9466	\N	\N	\N
9706	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9467	\N	\N	\N
9707	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9468	\N	\N	\N
9708	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9470	\N	\N	\N
9709	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9471	\N	\N	\N
9710	MEMBRE	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	9472	\N	\N	\N
9711	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9473	\N	\N	\N
9712	MEMBRE	2004-10-01 00:00:00	2005-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	9474	\N	\N	\N
9713	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9475	\N	\N	\N
9714	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9476	\N	\N	\N
9716	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9478	\N	\N	\N
9717	MEMBRE	2004-10-01 00:00:00	2007-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	9479	\N	\N	\N
9720	VICPDT	2004-10-27 00:00:00	2008-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	6544	9	\N	\N
9721	SECRET	2004-10-27 00:00:00	2008-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	1366	11	\N	\N
9722	SECRET	2004-10-26 00:00:00	2008-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	2438	14	\N	\N
9723	SECRET	2004-10-26 00:00:00	2008-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	4664	15	\N	\N
9725	VICPDT	2004-11-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4869	2	\N	\N
9726	VICPDT	2004-11-10 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2504	5	\N	\N
9727	VICPDT	2004-11-10 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	1260	\N	\N	\N
9728	VICPDT	2004-11-10 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	4901	\N	\N	\N
9729	SECRET	2004-11-10 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	6379	\N	\N	\N
9730	SECRET	2004-11-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4874	12	\N	\N
9732	SECRET	2004-11-10 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	4897	\N	\N	\N
9733	SECRET	2004-11-10 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	2011	\N	\N	\N
9734	SECRET	2004-11-10 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	4903	20	\N	\N
9735	MEMBRE	2004-11-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2512	\N	\N	\N
9736	VICPDT	2004-11-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4713	9	\N	\N
9739	SECRET	2004-11-24 00:00:00	2009-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	3214	14	\N	\N
9740	MEMBRE	2004-11-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4717	\N	\N	\N
9741	PDT	2004-11-18 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	8859	1	\N	\N
9742	VICPDT	2004-11-18 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	8393	2	\N	\N
9744	VICPDT	2004-11-18 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	8395	3	\N	\N
9745	VICPDT	2004-11-18 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	8861	4	\N	\N
9746	VICPDT	2004-11-18 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	8415	5	\N	\N
9748	SECRET	2004-11-18 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	8858	8	\N	\N
9749	MEMBRE	2004-11-18 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	8397	\N	\N	\N
9750	SECRET	2004-12-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	3163	6	\N	\N
9751	SECRET	2004-12-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	3164	8	\N	\N
9752	VICPDT	2004-11-16 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6397	4	\N	\N
9753	VICPDT	2004-11-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6395	4	\N	\N
9754	VICPDT	2004-11-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4257	2	\N	\N
9755	TRESOR	2004-11-16 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	6415	10	\N	\N
9756	SECRET	2004-11-16 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6394	11	\N	\N
9757	MEMBRE	2004-11-16 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2500	\N	\N	\N
9758	VICPDT	2004-10-26 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	5802	7	\N	\N
9760	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9484	\N	\N	\N
9764	SECRET	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9488	7	\N	\N
9765	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9489	\N	\N	\N
9766	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9490	\N	\N	\N
9767	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9491	\N	\N	\N
9768	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9492	\N	\N	\N
9769	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9493	\N	\N	\N
9770	MEMBRE	2004-10-01 00:00:00	2009-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	9494	0	\N	\N
9771	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9495	\N	\N	\N
9772	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9496	\N	\N	\N
9773	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9497	\N	\N	\N
9775	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9499	\N	\N	\N
9776	VICPDT	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9500	3	\N	\N
9777	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9501	\N	\N	\N
9779	MEMBRE	2004-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	9503	\N	\N	\N
9780	SECRET	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9504	8	\N	\N
9184	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8992	\N	\N	\N
9185	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8993	\N	\N	\N
9186	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8994	\N	\N	\N
9187	MEMBRE	2001-10-01 00:00:00	2004-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	8995	\N	\N	\N
9188	MEMBRE	2001-10-01 00:00:00	2004-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	8996	\N	\N	\N
9189	MEMBRE	2003-06-30 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8997	\N	\N	\N
9190	MEMBRE	2003-06-30 00:00:00	2007-02-25 00:00:00	ANCIEN	\N	\N	\N	\N	8998	\N	\N	\N
9192	MEMBRE	2003-06-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9000	\N	\N	\N
9193	MEMBRE	2003-06-30 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	\N	9001	\N	\N	\N
9194	MEMBRE	2003-06-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9002	\N	\N	\N
9195	MEMBRE	2003-06-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9003	\N	\N	\N
9196	PDTDEL	2004-10-01 00:00:00	2009-01-20 00:00:00	ANCIEN	\N	\N	Ouzbékistan	\N	9004	4	\N	\N
9197	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9005	\N	\N	\N
9198	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9006	\N	\N	\N
9199	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9007	\N	\N	\N
9200	SECRET	2004-10-01 00:00:00	2009-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	9008	19	\N	\N
9201	TRESOR	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9009	20	\N	\N
9202	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9010	\N	\N	\N
9203	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9011	\N	\N	\N
9204	MEMBRE	2001-10-01 00:00:00	2005-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	9012	\N	\N	\N
9205	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9013	\N	\N	\N
9206	MEMBRE	2001-10-01 00:00:00	2004-11-09 00:00:00	ANCIEN	\N	\N	\N	\N	9014	\N	\N	\N
9209	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9017	\N	\N	\N
9213	MEMBRE	2004-10-01 00:00:00	2007-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	9020	\N	\N	\N
9214	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9021	\N	\N	\N
9215	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9022	\N	\N	\N
9217	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9024	\N	\N	\N
9218	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9025	\N	\N	\N
9219	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9026	\N	\N	\N
9220	MEMBRE	2004-10-01 00:00:00	2009-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	9027	\N	\N	\N
9221	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9028	\N	\N	\N
9223	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9030	\N	\N	\N
9226	SECRET	2004-11-03 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8242	\N	\N	\N
9229	MEMBRE	2004-10-01 00:00:00	2004-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	9031	\N	\N	\N
9230	VICPDT	2004-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9031	\N	\N	\N
9232	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9033	\N	\N	\N
9233	MEMBRE	2004-10-01 00:00:00	2004-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	9034	\N	\N	\N
9236	MEMBRE	2004-10-01 00:00:00	2004-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	9035	\N	\N	\N
9237	VICPDT	2004-12-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9035	\N	\N	\N
9238	MEMBRE	2004-12-02 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6573	\N	\N	\N
9239	MEMBRE	2004-10-01 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	9036	\N	\N	\N
9240	VICPDT	2004-12-02 00:00:00	2009-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	6598	\N	\N	\N
9241	SECRET	2004-12-02 00:00:00	2009-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	6579	\N	\N	\N
9243	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9038	\N	\N	\N
9244	PDT	2004-12-02 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6586	\N	\N	\N
9245	VICPDT	2004-12-02 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	6589	\N	\N	\N
9246	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9039	\N	\N	\N
9247	VICPDT	2004-12-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9034	\N	\N	\N
9248	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9040	\N	\N	\N
9249	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9041	\N	\N	\N
9250	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9042	\N	\N	\N
9251	SECRET	2004-10-01 00:00:00	2009-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	9043	13	\N	\N
9252	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9044	\N	\N	\N
9253	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9045	\N	\N	\N
9254	MEMBRE	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	9046	\N	\N	\N
9256	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9048	\N	\N	\N
9257	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9049	\N	\N	\N
9258	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9050	\N	\N	\N
9259	MEMBRE	2004-10-01 00:00:00	2005-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	9051	\N	\N	\N
9260	MEMBRE	2004-10-01 00:00:00	2009-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	9052	0	\N	\N
9261	SECRET	2004-10-01 00:00:00	2009-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	9053	15	\N	\N
9262	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9054	\N	\N	\N
9263	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9055	\N	\N	\N
10260	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9880	\N	\N	\N
10261	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9881	\N	\N	\N
10262	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9882	\N	\N	\N
10263	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9883	\N	\N	\N
10264	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9884	\N	\N	\N
10265	MEMBRE	2004-10-01 00:00:00	2010-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	9885	\N	\N	\N
10266	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9888	\N	\N	\N
10268	MEMBRE	2004-10-01 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	9890	0	\N	\N
10269	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9891	\N	\N	\N
10270	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9892	\N	\N	\N
10271	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9893	\N	\N	\N
10272	MEMBRE	2004-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4276	\N	\N	\N
10274	VICPDT	2005-01-11 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	9894	\N	\N	\N
10275	MEMBRE	2004-12-01 00:00:00	2005-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	9895	\N	\N	\N
10276	MEMBREBUR	2005-01-11 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	9895	\N	\N	\N
10277	MEMBRE	2004-12-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	9896	\N	\N	\N
10278	MEMBRE	2004-12-01 00:00:00	2004-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	9897	\N	\N	\N
10280	MEMBRE	2004-12-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	9899	\N	\N	\N
10281	MEMBRE	2004-12-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	9900	\N	\N	\N
10283	MEMBRE	2004-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9902	\N	\N	\N
10284	MEMBRE	2004-12-01 00:00:00	2004-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	9903	\N	\N	\N
10285	VICPDT	2005-01-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7850	\N	\N	\N
10289	MEMBRE	2004-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9904	\N	\N	\N
10290	PDT	2004-11-25 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5839	1	\N	\N
10291	PDTDEL	2004-11-25 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Luxembourg	\N	5834	2	\N	\N
10293	VICPDT	2004-11-25 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	5847	\N	\N	\N
10294	VICPDT	2004-11-25 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	5857	\N	\N	\N
10295	TRESOR	2004-11-25 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5853	6	\N	\N
10296	MEMBRE	2004-11-25 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5854	\N	\N	\N
10297	MEMBRE	2004-11-25 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5841	\N	\N	\N
10300	VICPDT	2004-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4679	5	\N	\N
10303	MEMBREBUR	2004-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3535	8	\N	\N
10304	MEMBREBUR	2004-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5868	10	\N	\N
10305	MEMBREBUR	2004-12-01 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	670	13	\N	\N
10306	MEMBRE	2004-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4675	\N	\N	\N
10307	MEMBRE	2004-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3543	\N	\N	\N
10308	PDT	2004-10-01 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	9906	\N	\N	\N
10309	PDT	2004-11-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4779	1	\N	\N
10310	VICPDT	2004-11-18 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	2481	2	\N	\N
10311	VICPDT	2004-11-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2502	3	\N	\N
10312	VICPDT	2004-11-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1532	5	\N	\N
10313	VICPDT	2004-11-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4780	5	\N	\N
10314	SECRET	2004-11-18 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	666	14	\N	\N
10315	MEMBRE	2004-11-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	794	\N	\N	\N
10317	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9910	\N	\N	\N
10318	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9911	\N	\N	\N
10319	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9912	\N	\N	\N
10320	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9914	\N	\N	\N
10321	MEMBRE	2004-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	9915	\N	\N	\N
10322	MEMBRE	2004-10-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	9916	\N	\N	\N
10323	VICPDT	2004-10-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	9917	\N	\N	\N
10324	VICPDT	2004-10-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	9918	\N	\N	\N
10325	VICPDT	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9919	5	\N	\N
10326	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9920	\N	\N	\N
10327	VICPDT	2004-10-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	9921	\N	\N	\N
10328	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9922	\N	\N	\N
10330	VICPDT	2004-12-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5569	3	\N	\N
10331	VICPDT	2004-12-15 00:00:00	2009-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	6039	4	\N	\N
10332	VICPDT	2004-12-15 00:00:00	2009-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	5573	5	\N	\N
10333	SECRET	2004-12-15 00:00:00	2009-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	4309	14	\N	\N
10334	TRESOR	2004-12-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5571	10	\N	\N
10335	PDT	2004-10-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6034	1	\N	\N
10336	VICPDT	2004-10-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6024	3	\N	\N
10337	VICPDT	2004-10-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6027	5	\N	\N
10338	VICPDT	2004-10-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6031	9	\N	\N
10340	VICPDT	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	9924	3	\N	\N
10341	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9925	\N	\N	\N
10342	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9926	\N	\N	\N
10343	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9927	\N	\N	\N
10344	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9928	\N	\N	\N
10346	VICPDT	2004-10-01 00:00:00	2008-04-09 00:00:00	ANCIEN	\N	\N	\N	\N	9930	7	\N	\N
10347	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9931	\N	\N	\N
10348	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9932	\N	\N	\N
10350	MEMBRE	2004-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5194	\N	\N	\N
10351	MEMBRE	2004-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2720	\N	\N	\N
10352	VICPDT	2004-12-08 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5904	4	\N	\N
10353	SECRET	2004-12-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3268	10	\N	\N
10354	VICPDT	2004-11-03 00:00:00	2009-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	5642	5	\N	\N
10355	VICPDT	2004-11-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3428	8	\N	\N
10356	SECRET	2004-11-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3418	10	\N	\N
10357	SECRET	2004-11-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3422	12	\N	\N
10358	MEMBRE	2004-11-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3411	\N	\N	\N
10359	MEMBRE	2005-01-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9933	\N	\N	\N
10360	MEMBRE	2004-12-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9937	\N	\N	\N
10361	MEMBRE	2004-12-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9938	\N	\N	\N
10362	MEMBRE	2004-12-14 00:00:00	2005-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	9939	\N	\N	\N
10363	MEMBRE	2004-12-14 00:00:00	2004-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	9940	\N	\N	\N
10364	MEMBRE	2004-12-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9941	\N	\N	\N
10365	MEMBRE	2004-12-14 00:00:00	2005-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	9942	\N	\N	\N
10366	MEMBRE	2004-12-14 00:00:00	2007-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9943	\N	\N	\N
10368	MEMBRE	2004-12-14 00:00:00	2004-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	9945	\N	\N	\N
10369	MEMBRE	2004-12-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9946	\N	\N	\N
10370	MEMBRE	2004-12-14 00:00:00	2004-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	9947	\N	\N	\N
10371	MEMBRE	2004-12-14 00:00:00	2004-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	9948	\N	\N	\N
10372	MEMBRE	2004-12-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9949	\N	\N	\N
10373	MEMBRE	2004-12-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9950	\N	\N	\N
9863	SECRET	2004-10-01 00:00:00	2008-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	9562	7	\N	\N
9894	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9588	\N	\N	\N
9866	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9565	\N	\N	\N
9867	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9567	\N	\N	\N
9869	MEMBRE	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	9570	\N	\N	\N
9870	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9571	\N	\N	\N
9871	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9572	\N	\N	\N
9872	MEMBRE	2004-10-01 00:00:00	2010-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	9573	\N	\N	\N
9873	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9574	\N	\N	\N
9874	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9575	\N	\N	\N
9876	PDTDEL	2004-10-01 00:00:00	2009-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	9577	\N	\N	\N
9877	PDTDEL	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Norvège	\N	9578	4	\N	\N
9878	SECRET	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9579	8	\N	\N
9879	PDTDEL	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	Islande	\N	9580	3	\N	\N
9880	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9581	\N	\N	\N
9881	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9582	\N	\N	\N
9882	VICPDT	2004-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7932	\N	\N	\N
9883	VICPDT	2004-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7934	\N	\N	\N
9884	VICPDT	2004-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7924	\N	\N	\N
9888	VICPDT	2004-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7947	\N	\N	\N
9889	VICPDT	2004-12-16 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8553	\N	\N	\N
9890	SECRET	2004-12-16 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	\N	7764	\N	\N	\N
9891	SECRET	2004-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7766	\N	\N	\N
9893	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9587	\N	\N	\N
9896	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9590	\N	\N	\N
9897	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9591	\N	\N	\N
9898	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9592	\N	\N	\N
9899	MEMBRE	2004-10-01 00:00:00	2007-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9593	\N	\N	\N
9900	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9594	\N	\N	\N
9902	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9596	\N	\N	\N
9904	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9598	\N	\N	\N
9905	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9599	\N	\N	\N
9906	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9600	\N	\N	\N
9907	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9602	\N	\N	\N
10375	MEMBRE	2004-12-14 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	9952	\N	\N	\N
10376	PDT	2004-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9951	\N	\N	\N
10379	VICPDT	2004-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9947	\N	\N	\N
10380	SECRET	2004-12-16 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9948	\N	\N	\N
10381	SECRET	2004-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9940	\N	\N	\N
10384	MEMBRE	2004-10-01 00:00:00	2009-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	9955	0	\N	\N
10385	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9956	\N	\N	\N
10386	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9957	\N	\N	\N
10387	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9958	\N	\N	\N
10388	MEMBRE	2004-10-01 00:00:00	2005-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	9959	\N	\N	\N
10389	MEMBRE	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	9960	\N	\N	\N
10390	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9961	\N	\N	\N
10391	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9962	\N	\N	\N
10392	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9963	\N	\N	\N
10393	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9964	\N	\N	\N
10396	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9967	\N	\N	\N
10395	MEMBRE	2004-10-01 00:00:00	2004-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	9966	\N	\N	\N
10397	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9968	\N	\N	\N
10399	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9970	\N	\N	\N
10401	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9972	\N	\N	\N
10402	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9973	\N	\N	\N
10403	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9974	\N	\N	\N
10404	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9975	\N	\N	\N
10405	MEMBRE	2004-10-01 00:00:00	2005-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	9976	\N	\N	\N
10406	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9977	\N	\N	\N
10408	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9979	\N	\N	\N
10409	MEMBRE	2004-10-01 00:00:00	2004-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	9980	\N	\N	\N
10410	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9981	\N	\N	\N
10411	MEMBRE	2004-10-01 00:00:00	2005-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	9982	\N	\N	\N
10412	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9983	\N	\N	\N
9134	TRESOR	2004-10-15 00:00:00	2009-01-14 00:00:00	ANCIEN	\N	\N	\N	\N	8940	\N	\N	\N
9135	MEMBRE	2004-10-15 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	8941	\N	\N	\N
9137	MEMBRE	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8943	\N	\N	\N
9138	SECRET	2004-10-15 00:00:00	2009-01-14 00:00:00	ANCIEN	\N	\N	\N	\N	8944	\N	\N	\N
9140	VICPDT	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8946	5	\N	\N
7721	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	7736	\N	\N	\N
7723	MEMBRE	2001-10-01 00:00:00	2003-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	7738	\N	\N	\N
14762	MEMBRE	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13258	\N	\N	\N
14784	MEMBREDRT	2009-03-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7229	\N	\N	\N
7726	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	7741	\N	\N	\N
7730	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7745	\N	\N	\N
7731	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	7746	\N	\N	\N
7734	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7749	\N	\N	\N
7735	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7750	\N	\N	\N
7736	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	7751	\N	\N	\N
7738	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	7753	\N	\N	\N
7739	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	7754	\N	\N	\N
7741	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	7756	\N	\N	\N
7742	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	7757	\N	\N	\N
7744	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	7759	\N	\N	\N
7745	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7760	\N	\N	\N
7747	VICPDT	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	7731	\N	\N	\N
7748	VICPDT	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	7742	\N	\N	\N
7749	VICPDT	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	7744	\N	\N	\N
7750	VICPDT	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	7747	\N	\N	\N
7751	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7752	\N	\N	\N
7752	VICPDT	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	7758	\N	\N	\N
7753	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7743	\N	\N	\N
7755	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7762	\N	\N	\N
7756	MEMBRE	2001-10-01 00:00:00	2003-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	7763	\N	\N	\N
7757	PDT	2003-10-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7763	\N	\N	\N
7758	MEMBRE	2001-10-01 00:00:00	2003-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	7764	\N	\N	\N
7760	MEMBRE	2001-10-01 00:00:00	2004-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	7766	\N	\N	\N
7763	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7768	\N	\N	\N
7773	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7778	\N	\N	\N
7768	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7773	\N	\N	\N
7769	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7774	\N	\N	\N
7770	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7775	\N	\N	\N
7772	MEMBRE	2001-10-01 00:00:00	2002-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	7777	\N	\N	\N
7774	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7779	\N	\N	\N
7775	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7780	\N	\N	\N
12332	MEMBRE	2007-11-20 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10712	\N	\N	\N
8479	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8357	\N	\N	\N
8647	VICPDT	2003-12-09 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8493	\N	\N	\N
8649	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8516	\N	\N	\N
8654	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8519	\N	\N	\N
8655	MEMBRE	2001-10-01 00:00:00	2004-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	8520	\N	\N	\N
8657	MEMBRE	2004-01-27 00:00:00	2004-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	8522	\N	\N	\N
8658	MEMBRE	2004-01-27 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8523	\N	\N	\N
5207	PDT	2001-10-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	3336	1	\N	\N
8660	VICPDT	2004-01-29 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8525	9	\N	\N
8661	MEMBRE	2004-01-29 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8526	\N	\N	\N
8662	MEMBRE	2004-01-29 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8527	\N	\N	\N
8664	MEMBRE	2004-01-13 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8529	\N	\N	\N
8667	MEMBRE	2003-01-26 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	8533	\N	\N	\N
8668	MEMBRE	2003-01-26 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8534	\N	\N	\N
2914	MEMBRE	1999-01-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	2950	\N	\N	\N
3878	PDT	1999-01-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	3920	1	\N	\N
8670	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8536	\N	\N	\N
8672	MEMBRE	2004-04-01 00:00:00	2004-11-11 00:00:00	ANCIEN	\N	\N	\N	\N	8538	\N	\N	\N
8673	MEMBRE	2003-01-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8539	\N	\N	\N
8674	MEMBRE	2004-04-02 00:00:00	2004-06-08 00:00:00	ANCIEN	\N	\N	\N	\N	8541	\N	\N	\N
8675	MEMBRE	2004-04-29 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8543	\N	\N	\N
8676	PDT	2004-05-26 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4101	1	\N	\N
8677	MEMBRE	2004-06-01 00:00:00	2005-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	8544	\N	\N	\N
8678	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8545	\N	\N	\N
8681	PDT	2004-06-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8541	1	\N	\N
8680	MEMBRE	2004-06-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8547	\N	\N	\N
8682	MEMBRE	2004-06-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8548	\N	\N	\N
8685	MEMBRE	2004-05-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8551	\N	\N	\N
8684	MEMBRE	2004-07-20 00:00:00	2004-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	8550	\N	\N	\N
8686	MEMBRE	2004-05-06 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8552	\N	\N	\N
8688	MEMBRE	2004-09-09 00:00:00	2008-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	8554	0	\N	\N
3131	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3174	\N	\N	\N
5018	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5125	\N	\N	\N
3122	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3165	\N	\N	\N
12334	MEMBRE	2007-11-01 00:00:00	2009-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	11596	\N	\N	2015-11-12 15:26:22
8481	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8359	\N	\N	\N
8482	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8360	\N	\N	\N
8483	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8361	\N	\N	\N
12339	VICPDT	2007-10-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11381	2	\N	\N
8485	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8363	\N	\N	\N
8488	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8366	\N	\N	\N
8487	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8365	\N	\N	\N
8489	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8367	\N	\N	\N
12340	VICPDT	2007-10-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11396	5	\N	\N
8491	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8369	\N	\N	\N
8492	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8370	\N	\N	\N
8493	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8371	\N	\N	\N
12341	VICPDT	2007-10-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11397	7	\N	\N
8495	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8373	\N	\N	\N
12342	VICPDT	2007-10-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11399	6	\N	\N
8497	MEMBRE	2001-10-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	8375	\N	\N	\N
8498	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8376	\N	\N	\N
12343	VICPDT	2007-10-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11401	7	\N	\N
8500	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8378	\N	\N	\N
8501	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8379	\N	\N	\N
12344	VICPDT	2007-10-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11402	8	\N	\N
8503	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8381	\N	\N	\N
12345	VICPDT	2007-10-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11407	9	\N	\N
12346	VICPDT	2007-10-24 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	9118	12	\N	\N
8506	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8384	\N	\N	\N
8508	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8386	\N	\N	\N
8514	MEMBRE	2001-10-01 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	8392	\N	\N	\N
8515	SECRET	2003-06-30 00:00:00	2004-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	8393	4	\N	\N
8516	MEMBRE	2003-06-30 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8394	\N	\N	\N
8518	MEMBRE	2003-06-30 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	8396	\N	\N	\N
8519	VICPDT	2003-06-30 00:00:00	2004-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	8397	2	\N	\N
8520	MEMBRE	2003-06-30 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8398	\N	\N	\N
8522	MEMBRE	2003-06-30 00:00:00	2004-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	8400	\N	\N	\N
8523	MEMBRE	2003-06-30 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8401	\N	\N	\N
8524	MEMBRE	2003-06-30 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	8402	\N	\N	\N
8525	MEMBRE	2003-06-30 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	8403	\N	\N	\N
8526	MEMBRE	2003-06-30 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8404	\N	\N	\N
8527	MEMBRE	2003-06-30 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8405	\N	\N	\N
8528	MEMBRE	2003-06-30 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	8409	\N	\N	\N
8529	SECRET	2003-06-30 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8410	5	\N	\N
8530	MEMBRE	2003-06-30 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8411	\N	\N	\N
8531	MEMBRE	2003-06-30 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	8412	\N	\N	\N
8532	PDT	2003-06-30 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8413	1	\N	\N
8533	MEMBRE	2003-06-30 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8414	\N	\N	\N
8534	MEMBRE	2003-06-30 00:00:00	2004-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	8415	\N	\N	\N
8535	MEMBRE	2003-06-30 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8416	\N	\N	\N
8536	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8417	\N	\N	\N
14685	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13220	\N	\N	\N
14686	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13221	\N	\N	\N
14687	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13222	\N	\N	\N
14688	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13223	\N	\N	\N
14689	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13224	\N	\N	\N
14690	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13225	\N	\N	\N
14691	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13226	\N	\N	\N
14692	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13227	\N	\N	\N
7697	MEMBRE	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	7717	\N	\N	\N
7703	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7723	\N	\N	\N
7704	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7724	\N	\N	\N
7705	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7725	\N	\N	\N
7707	PDT	2001-10-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	7717	\N	\N	\N
7708	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7715	\N	\N	\N
7709	VICPDT	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7721	\N	\N	\N
7710	VICPDT	2001-10-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	7719	\N	\N	\N
7711	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7708	\N	\N	\N
8426	MEMBRE	2001-01-01 00:00:00	2001-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	8319	\N	\N	\N
8537	MEMBRE	2001-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8418	\N	\N	\N
8538	MEMBRE	2001-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8419	\N	\N	\N
8539	MEMBRE	2001-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8420	\N	\N	\N
8541	MEMBRE	2001-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8422	\N	\N	\N
8542	MEMBRE	2001-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8423	\N	\N	\N
8543	MEMBRE	2001-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8424	\N	\N	\N
8544	MEMBRE	2001-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8425	\N	\N	\N
8545	MEMBRE	2001-01-01 00:00:00	2001-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	8426	\N	\N	\N
8546	MEMBRE	2001-01-01 00:00:00	2001-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	8427	\N	\N	\N
8577	VICPDT	2001-12-18 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	3175	5	\N	\N
8578	VICPDT	2003-06-30 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8408	3	\N	\N
8579	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8451	\N	\N	\N
8580	MEMBRE	2001-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	8452	\N	\N	\N
8581	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8453	\N	\N	\N
8582	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8454	\N	\N	\N
8584	MEMBRE	2003-10-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8456	\N	\N	\N
8585	MEMBRE	2003-08-21 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8457	\N	\N	\N
8586	MEMBRE	2000-12-12 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4529	\N	\N	\N
8587	MEMBRE	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8460	\N	\N	\N
8588	MEMBRE	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8461	\N	\N	\N
8589	MEMBRE	2003-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8462	\N	\N	\N
8590	MEMBRE	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8463	\N	\N	\N
8591	MEMBRE	2003-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8464	\N	\N	\N
8592	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8465	\N	\N	\N
8650	VICPDT	2003-12-09 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8492	\N	\N	\N
8597	MEMBRE	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8470	\N	\N	\N
8596	MEMBRE	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8469	\N	\N	\N
8598	MEMBRE	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8471	\N	\N	\N
8599	MEMBRE	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8472	\N	\N	\N
8600	MEMBRE	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8473	\N	\N	\N
8601	MEMBRE	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8474	\N	\N	\N
8602	MEMBRE	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8475	\N	\N	\N
8604	MEMBRE	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8477	\N	\N	\N
8605	MEMBRE	2003-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8478	\N	\N	\N
8606	MEMBRE	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8479	\N	\N	\N
8607	MEMBRE	2003-10-01 00:00:00	2003-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	8480	\N	\N	\N
8608	MEMBRE	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8481	\N	\N	\N
8609	MEMBRE	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8482	\N	\N	\N
8611	MEMBRE	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8484	\N	\N	\N
8612	MEMBRE	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8485	\N	\N	\N
8613	MEMBRE	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8486	\N	\N	\N
8614	MEMBRE	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8487	\N	\N	\N
8615	MEMBRE	2003-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8488	\N	\N	\N
8616	MEMBRE	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8489	\N	\N	\N
8618	MEMBRE	2003-10-01 00:00:00	2003-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	8491	\N	\N	\N
8619	MEMBRE	2003-10-01 00:00:00	2003-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	8492	\N	\N	\N
8620	MEMBRE	2003-10-01 00:00:00	2003-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	8493	\N	\N	\N
8621	MEMBRE	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8494	\N	\N	\N
8622	MEMBRE	2003-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8495	\N	\N	\N
8623	MEMBRE	2003-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8496	\N	\N	\N
8624	MEMBRE	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8497	\N	\N	\N
8625	MEMBRE	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8498	\N	\N	\N
8627	MEMBRE	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8500	\N	\N	\N
8628	MEMBRE	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8501	\N	\N	\N
8629	MEMBRE	2003-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8502	\N	\N	\N
8630	MEMBRE	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8503	\N	\N	\N
8633	MEMBRE	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8506	\N	\N	\N
8634	MEMBRE	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8507	\N	\N	\N
8635	MEMBRE	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8508	\N	\N	\N
8637	MEMBRE	2003-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8510	\N	\N	\N
8638	MEMBRE	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8511	\N	\N	\N
8639	MEMBRE	2003-10-01 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	8512	\N	\N	\N
8640	MEMBRE	2003-10-01 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	8513	\N	\N	\N
8641	MEMBRE	2000-12-12 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8514	\N	\N	\N
8642	MEMBRE	2003-11-28 00:00:00	2004-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	8515	\N	\N	\N
8644	VICPDT	2003-12-09 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8478	\N	\N	\N
8646	VICPDT	2003-12-09 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8491	\N	\N	\N
8798	MEMBRE	2004-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8638	\N	\N	\N
8799	SECRET	2004-11-01 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	8639	7	\N	\N
8800	MEMBREBUR	2004-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8640	11	\N	\N
8801	MEMBRE	2004-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8641	\N	\N	\N
8802	MEMBRE	2004-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8642	\N	\N	\N
8803	MEMBRE	2004-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8643	\N	\N	\N
8804	VICPDT	2004-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8644	2	\N	\N
8808	MEMBRE	2004-10-15 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	8648	\N	\N	\N
8809	MEMBREBUR	2004-10-15 00:00:00	2008-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	8649	20	\N	\N
8810	MEMBRE	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8650	\N	\N	\N
8811	MEMBRE	2004-10-01 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	8651	\N	\N	\N
8812	VICPDT	2004-11-03 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8651	\N	\N	\N
8813	VICPDT	2004-11-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7544	\N	\N	\N
8815	VICPDT	2004-11-03 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8652	\N	\N	\N
8817	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8653	\N	\N	\N
8818	MEMBRE	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8654	\N	\N	\N
8819	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8655	\N	\N	\N
8820	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8656	\N	\N	\N
8821	MEMBRE	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8657	\N	\N	\N
8822	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8658	\N	\N	\N
8823	MEMBRE	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8659	\N	\N	\N
8824	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8660	\N	\N	\N
8826	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8662	\N	\N	\N
8827	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8663	\N	\N	\N
8828	MEMBRE	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8664	\N	\N	\N
8829	MEMBRE	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8665	\N	\N	\N
8830	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8666	\N	\N	\N
8831	MEMBRE	2004-10-01 00:00:00	2009-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	8667	\N	\N	\N
8832	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8668	\N	\N	\N
8834	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7318	\N	\N	\N
8835	MEMBRE	2004-10-15 00:00:00	2005-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	8670	\N	\N	\N
8836	MEMBRE	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8671	\N	\N	\N
8837	MEMBRE	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8672	\N	\N	\N
8838	MEMBREBUR	2004-10-15 00:00:00	2008-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	8673	19	\N	\N
8841	MEMBRE	2001-10-01 00:00:00	2004-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	8677	\N	\N	\N
8842	MEMBRE	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8676	\N	\N	\N
8843	VICPDT	2001-10-02 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8677	\N	\N	\N
8844	MEMBRE	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8678	\N	\N	\N
8845	MEMBRE	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8679	\N	\N	\N
8846	MEMBRE	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8680	\N	\N	\N
8848	MEMBRE	2004-10-15 00:00:00	2005-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	8682	\N	\N	\N
8849	MEMBRE	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8683	\N	\N	\N
8850	MEMBRE	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8684	\N	\N	\N
8874	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8708	\N	\N	\N
8852	MEMBRE	2004-10-15 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	8686	\N	\N	\N
8853	MEMBRE	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8687	\N	\N	\N
8854	SECRET	2004-10-15 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	8688	15	\N	\N
8855	MEMBRE	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8689	\N	\N	\N
8857	MEMBRE	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8691	\N	\N	\N
8858	VICPDT	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8692	2	\N	\N
8859	MEMBRE	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8693	\N	\N	\N
8860	MEMBRE	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8694	\N	\N	\N
8861	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5627	\N	\N	\N
8862	MEMBRE	2004-11-03 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8697	\N	\N	\N
8863	MEMBREBUR	2004-11-03 00:00:00	2008-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	8698	18	\N	\N
8864	MEMBREBUR	2004-11-03 00:00:00	2008-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	8699	17	\N	\N
8865	MEMBRE	2004-11-03 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8700	\N	\N	\N
8867	MEMBRE	2004-11-03 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8702	\N	\N	\N
8868	MEMBRE	2004-11-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8705	\N	\N	\N
8869	MEMBRE	2004-11-03 00:00:00	2008-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	8706	0	\N	\N
8870	MEMBRE	2004-10-15 00:00:00	2008-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	8696	0	\N	\N
8872	MEMBRE	2004-05-15 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7346	\N	\N	\N
8873	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8707	\N	\N	\N
8875	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8709	\N	\N	\N
8876	MEMBRE	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	8710	\N	\N	\N
8877	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8711	\N	\N	\N
8879	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8713	\N	\N	\N
8880	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8714	\N	\N	\N
8882	MEMBRE	2004-10-01 00:00:00	2005-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	8716	\N	\N	\N
8883	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8717	\N	\N	\N
8884	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8718	\N	\N	\N
8885	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8719	\N	\N	\N
8886	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8720	\N	\N	\N
8888	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8722	\N	\N	\N
8889	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8723	\N	\N	\N
8890	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8724	\N	\N	\N
8891	MEMBRE	2004-10-01 00:00:00	2005-03-19 00:00:00	ANCIEN	\N	\N	\N	\N	8725	\N	\N	\N
8893	MEMBRE	2004-10-01 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	8727	\N	\N	\N
8894	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8728	\N	\N	\N
8896	MEMBRE	2004-10-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	8730	\N	\N	\N
8897	MEMBRE	2004-10-01 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	8731	\N	\N	\N
8898	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8732	\N	\N	\N
8899	VICPDT	2004-10-26 00:00:00	2004-11-25 00:00:00	ANCIEN	\N	\N	\N	\N	7469	\N	\N	\N
8902	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7476	\N	\N	\N
8903	MEMBRE	2004-10-01 00:00:00	2004-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	7488	\N	\N	\N
8904	SECRET	2004-10-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7488	\N	\N	\N
8905	SECRET	2004-10-26 00:00:00	2009-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	7478	\N	\N	\N
8907	MEMBRE	2004-10-26 00:00:00	2007-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	7500	\N	\N	\N
8908	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8733	\N	\N	\N
8909	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8734	\N	\N	\N
8910	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8735	\N	\N	\N
8911	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8736	\N	\N	\N
8912	MEMBRE	2004-10-01 00:00:00	2004-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	8737	\N	\N	\N
8913	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8738	\N	\N	\N
8914	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8739	\N	\N	\N
8917	MEMBRE	2004-10-01 00:00:00	2007-02-25 00:00:00	ANCIEN	\N	\N	\N	\N	8742	\N	\N	\N
8918	MEMBRE	2004-10-01 00:00:00	2004-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	8743	\N	\N	\N
8919	MEMBRE	2004-10-01 00:00:00	2004-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	8744	\N	\N	\N
8920	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8745	\N	\N	\N
8921	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8746	\N	\N	\N
8922	MEMBRE	2004-10-01 00:00:00	2004-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	8747	\N	\N	\N
8923	MEMBRE	2004-10-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	8748	\N	\N	\N
8924	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8749	\N	\N	\N
8925	SECRET	2004-11-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7246	\N	\N	\N
8927	SECRET	2004-11-02 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8737	\N	\N	\N
8928	SECRET	2004-11-02 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7247	\N	\N	\N
8930	SECRET	2004-11-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8744	\N	\N	\N
8932	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8750	\N	\N	\N
8933	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8751	\N	\N	\N
8934	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8752	\N	\N	\N
8936	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8754	\N	\N	\N
8937	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8755	\N	\N	\N
8938	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8756	\N	\N	\N
8968	SECRET	2004-11-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7298	\N	\N	\N
8940	MEMBRE	2004-10-01 00:00:00	2004-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	8758	\N	\N	\N
8943	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8761	\N	\N	\N
8945	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8763	\N	\N	\N
8946	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8764	\N	\N	\N
8947	MEMBRE	2004-10-01 00:00:00	2004-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	8765	\N	\N	\N
8949	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8767	\N	\N	\N
8950	MEMBRE	2004-10-30 00:00:00	2004-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	8768	\N	\N	\N
8951	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8769	\N	\N	\N
8952	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8770	\N	\N	\N
8953	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8771	\N	\N	\N
8954	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8772	\N	\N	\N
8955	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8773	\N	\N	\N
8956	MEMBRE	2004-10-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	8774	\N	\N	\N
8957	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8775	\N	\N	\N
8958	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8776	\N	\N	\N
8960	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8778	\N	\N	\N
8961	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8779	\N	\N	\N
8966	VICPDT	2004-11-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8757	\N	\N	\N
8963	VICPDT	2004-11-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8768	\N	\N	\N
8967	VICPDT	2004-11-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7288	\N	\N	\N
8965	PDT	2004-11-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7273	\N	\N	\N
8969	SECRET	2004-11-02 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8758	\N	\N	\N
8970	SECRET	2004-11-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8762	\N	\N	\N
8971	SECRET	2004-11-02 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	8765	\N	\N	\N
8973	VICPDT	2004-11-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8759	\N	\N	\N
8974	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8780	\N	\N	\N
8975	MEMBRE	2004-11-02 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7276	\N	\N	\N
8976	MEMBRE	2004-11-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7278	\N	\N	\N
8977	MEMBRE	2004-11-02 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	7279	\N	\N	\N
8978	MEMBRE	2004-11-02 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7281	\N	\N	\N
8979	MEMBRE	2004-11-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7284	\N	\N	\N
8993	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8794	\N	\N	\N
8994	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8795	\N	\N	\N
8985	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8786	\N	\N	\N
8986	MEMBRE	2004-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	8787	\N	\N	\N
8987	MEMBRE	2004-10-01 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	8788	\N	\N	\N
8990	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8791	\N	\N	\N
4750	MEMBRE	2001-10-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	4863	\N	\N	\N
8995	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8796	\N	\N	\N
8996	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8797	\N	\N	\N
8997	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8798	\N	\N	\N
8998	MEMBRE	2004-10-01 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	8799	\N	\N	\N
9000	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8801	\N	\N	\N
9001	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8802	\N	\N	\N
9003	MEMBRE	2004-11-03 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	8804	0	\N	\N
9006	SECRET	2004-10-18 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	8807	8	\N	\N
9007	MEMBRE	2004-10-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8808	\N	\N	\N
9008	MEMBRE	2004-10-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8809	\N	\N	\N
9009	MEMBRE	2004-10-18 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	8810	0	\N	\N
9010	MEMBRE	2004-10-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8811	\N	\N	\N
9011	MEMBRE	2004-10-18 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	8812	0	\N	\N
9012	SECRET	2004-10-18 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	8813	9	\N	\N
9014	MEMBRE	2004-10-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8815	\N	\N	\N
9015	MEMBRE	2004-10-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8816	\N	\N	\N
9016	MEMBRE	2004-10-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8817	\N	\N	\N
9017	MEMBRE	2004-10-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8818	\N	\N	\N
9018	SECRET	2004-10-18 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	\N	8819	11	\N	\N
9019	MEMBRE	2004-10-18 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	8820	0	\N	\N
9020	MEMBRE	2004-10-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8821	\N	\N	\N
9021	MEMBRE	2004-10-18 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8822	\N	\N	\N
9022	MEMBRE	2004-10-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8823	\N	\N	\N
9023	MEMBRE	2004-10-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8824	\N	\N	\N
9025	MEMBRE	2004-10-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8827	\N	\N	\N
9026	MEMBRE	2004-10-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8828	\N	\N	\N
9027	MEMBRE	2004-10-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8829	\N	\N	\N
9028	MEMBRE	2004-10-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8830	\N	\N	\N
9029	MEMBRE	2004-10-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8831	\N	\N	\N
9030	MEMBRE	2004-10-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8832	\N	\N	\N
9033	MEMBRE	2004-10-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8835	\N	\N	\N
9035	MEMBRE	2004-10-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8837	\N	\N	\N
9036	MEMBRE	2004-10-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8838	\N	\N	\N
9037	MEMBRE	2004-10-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8839	\N	\N	\N
9038	MEMBRE	2004-10-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8840	\N	\N	\N
9039	MEMBRE	2004-10-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8841	\N	\N	\N
9040	MEMBRE	2004-10-18 00:00:00	2008-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	8842	0	\N	\N
9042	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1657	\N	\N	\N
9043	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8845	\N	\N	\N
9045	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8848	\N	\N	\N
9046	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8849	\N	\N	\N
9054	MEMBRE	2003-06-30 00:00:00	2004-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	8858	\N	\N	\N
9055	MEMBRE	2003-06-30 00:00:00	2004-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	8859	\N	\N	\N
9056	MEMBRE	2003-06-30 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	8860	\N	\N	\N
9057	MEMBRE	2003-06-30 00:00:00	2004-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	8861	\N	\N	\N
9058	MEMBRE	2003-06-30 00:00:00	2008-06-02 00:00:00	ANCIEN	\N	\N	\N	\N	8863	\N	\N	\N
9060	SECRET	2003-06-30 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	8865	7	\N	\N
9061	MEMBRE	2003-06-30 00:00:00	2005-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	8866	\N	\N	\N
9064	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8869	\N	\N	\N
9065	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8870	\N	\N	\N
9066	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8872	\N	\N	\N
9067	MEMBRE	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8871	\N	\N	\N
9264	VICPDT	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9056	6	\N	\N
9265	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9057	\N	\N	\N
9268	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9060	\N	\N	\N
9269	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9061	\N	\N	\N
9270	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9062	\N	\N	\N
9271	MEMBRE	2004-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	9063	\N	\N	\N
9272	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9064	\N	\N	\N
9273	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9065	\N	\N	\N
9275	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9067	\N	\N	\N
9276	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9068	\N	\N	\N
9277	MEMBRE	2004-10-01 00:00:00	2010-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	9069	\N	\N	\N
9278	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9070	\N	\N	\N
9279	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9071	\N	\N	\N
9280	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9072	\N	\N	\N
9281	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9073	\N	\N	\N
9282	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9074	\N	\N	\N
9284	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9076	\N	\N	\N
9285	SECRET	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9077	25	\N	\N
9286	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9078	\N	\N	\N
9287	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9079	\N	\N	\N
9288	SECRET	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9080	27	\N	\N
9296	MEMBRE	2004-12-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9088	\N	\N	\N
9291	SECRET	2004-10-01 00:00:00	2009-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	9083	28	\N	\N
9292	SECRET	2004-10-01 00:00:00	2009-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	9084	29	\N	\N
9293	VICPDT	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9085	9	\N	\N
9294	VICPDT	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9086	12	\N	\N
9297	MEMBRE	2004-12-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9089	\N	\N	\N
9299	VICPDT	2004-11-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5674	8	\N	\N
9300	SECRET	2004-11-16 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5659	14	\N	\N
9301	SECRET	2004-11-16 00:00:00	2009-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	2454	17	\N	\N
9302	SECRET	2004-11-16 00:00:00	2009-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	2250	18	\N	\N
9303	SECRET	2004-11-16 00:00:00	2009-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	5676	19	\N	\N
9304	SECRET	2004-11-16 00:00:00	2009-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	3111	21	\N	\N
9305	SECRET	2004-11-16 00:00:00	2009-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	5688	22	\N	\N
9306	SECRET	2004-11-16 00:00:00	2009-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	5691	23	\N	\N
9310	MEMBRE	2004-11-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2816	\N	\N	\N
9311	MEMBRE	2004-11-16 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2817	\N	\N	\N
9312	MEMBRE	2004-11-16 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	3119	\N	\N	\N
9313	MEMBRE	2004-11-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5707	\N	\N	\N
9314	PDT	2004-11-03 00:00:00	2008-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	882	1	\N	\N
9315	MEMBRE	2004-11-03 00:00:00	2008-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	4730	0	\N	\N
9316	MEMBRE	2004-11-03 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	571	\N	\N	\N
9317	SECRET	2004-11-03 00:00:00	2008-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	4740	6	\N	\N
9320	PDTDEL	2004-11-03 00:00:00	2008-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	8690	2	\N	\N
9321	VICPDT	2004-11-03 00:00:00	2008-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	5637	4	\N	\N
9322	VICPDT	2004-11-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5638	3	\N	\N
9324	SECRET	2004-11-03 00:00:00	2007-02-25 00:00:00	ANCIEN	\N	\N	\N	\N	6352	13	\N	\N
9325	SECRET	2004-11-03 00:00:00	2008-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	5593	16	\N	\N
9326	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9090	\N	\N	\N
9327	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9091	\N	\N	\N
9328	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9092	\N	\N	\N
9329	SECRET	2004-10-01 00:00:00	2007-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	9093	11	\N	\N
9330	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9094	\N	\N	\N
9331	SECRET	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9095	7	\N	\N
9332	VICPDT	2004-10-01 00:00:00	2009-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	9096	5	\N	\N
9333	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9097	\N	\N	\N
9334	VICPDT	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9098	4	\N	\N
9335	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9099	\N	\N	\N
9336	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9100	\N	\N	\N
9337	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9101	\N	\N	\N
9338	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9102	\N	\N	\N
9340	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9104	\N	\N	\N
9342	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9108	\N	\N	\N
9344	VICPDT	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9110	3	\N	\N
9345	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9111	\N	\N	\N
9346	VICPDT	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9112	3	\N	\N
8067	MEMBRE	1995-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8009	\N	\N	\N
8113	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8046	\N	\N	\N
8070	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8012	\N	\N	\N
8071	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8013	\N	\N	\N
8110	MEMBREBUR	1995-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8010	\N	\N	\N
8073	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8015	\N	\N	\N
8076	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8018	\N	\N	\N
8078	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8020	\N	\N	\N
8079	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8021	\N	\N	\N
8080	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8022	\N	\N	\N
8773	MEMBRE	2004-10-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8613	\N	\N	\N
8774	MEMBRE	2004-10-21 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8614	\N	\N	\N
8775	MEMBRE	2004-10-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8615	\N	\N	\N
8776	MEMBRE	2004-10-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8616	\N	\N	\N
8777	MEMBRE	2004-10-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8617	\N	\N	\N
8778	MEMBRE	2004-10-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8618	0	\N	\N
8779	MEMBRE	2004-10-21 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8619	\N	\N	\N
8780	VICPDT	2004-10-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8620	3	\N	\N
8781	MEMBRE	2004-10-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8621	\N	\N	\N
8782	MEMBRE	2004-10-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8622	\N	\N	\N
8783	MEMBRE	2004-10-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8623	\N	\N	\N
8784	MEMBRE	2004-10-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8624	\N	\N	\N
8786	PDTDEL	2004-10-21 00:00:00	2008-12-01 00:00:00	ANCIEN	\N	\N	Cambodge	\N	8626	2	\N	\N
8787	MEMBRE	2004-10-21 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8627	\N	\N	\N
8788	MEMBRE	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	571	\N	\N	\N
8789	MEMBRE	2004-11-01 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	8629	\N	\N	\N
8790	MEMBRE	2004-11-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	8630	\N	\N	\N
8791	MEMBRE	2004-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8631	\N	\N	\N
8792	MEMBRE	2004-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8632	\N	\N	\N
8793	MEMBREBUR	2004-11-01 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	8633	12	\N	\N
8794	SECRET	2004-11-01 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	8634	6	\N	\N
8795	MEMBRE	2004-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8635	\N	\N	\N
8796	MEMBRE	2004-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8636	\N	\N	\N
4798	TRESOR	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4914	18	\N	\N
5095	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5204	\N	\N	\N
2680	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2693	\N	\N	\N
1288	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1288	\N	\N	\N
3314	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3375	\N	\N	\N
2797	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2825	\N	\N	\N
2949	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2985	\N	\N	\N
2808	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2836	\N	\N	\N
3515	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3585	5	\N	\N
4506	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4616	\N	\N	\N
4115	MEMBRE	2000-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4164	\N	\N	\N
4220	SECRET	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4271	8	\N	\N
2659	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2672	\N	\N	\N
2575	VICPDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2575	2	\N	\N
4724	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	362	2	\N	\N
3663	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3736	\N	\N	\N
4565	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4678	\N	\N	\N
5083	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5191	\N	\N	\N
4408	MEMBRE	2000-12-13 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4517	\N	\N	\N
3836	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2596	\N	\N	\N
3739	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3815	\N	\N	\N
3460	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3527	\N	\N	\N
1326	SECRET	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1326	7	\N	\N
4723	TRESOR	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3230	9	\N	\N
4710	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4829	\N	\N	\N
3130	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3173	\N	\N	\N
5124	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5233	\N	\N	\N
8643	PDT	2003-12-09 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8480	\N	\N	\N
8691	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8556	\N	\N	\N
3106	PDT	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3149	1	\N	\N
4144	VICPDT	2000-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4194	3	\N	\N
2879	SECRET	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2912	13	\N	\N
3367	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3430	\N	\N	\N
2605	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2607	\N	\N	\N
5238	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1196	\N	\N	\N
8583	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8455	\N	\N	\N
4510	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4620	\N	\N	\N
8632	MEMBRE	2003-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8505	\N	\N	\N
7621	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	7659	\N	\N	\N
4668	MEMBRE	2001-10-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	4781	\N	\N	\N
5097	MEMBRE	2001-10-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	5206	\N	\N	\N
8689	PDT	2004-10-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8504	\N	\N	\N
8690	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8555	\N	\N	\N
8694	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8558	\N	\N	\N
8695	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8559	\N	\N	\N
8696	MEMBRE	2004-10-01 00:00:00	2005-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	8560	\N	\N	\N
8697	MEMBRE	2004-10-01 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	8561	\N	\N	\N
8698	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8562	\N	\N	\N
8699	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8563	\N	\N	\N
8702	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7244	\N	\N	\N
8718	PDT	2004-05-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7352	\N	\N	\N
8723	MEMBRE	2004-11-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7335	\N	\N	\N
8724	VICPDT	2004-11-03 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	7348	\N	\N	\N
8725	VICPDT	2004-11-03 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8561	\N	\N	\N
8729	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8579	\N	\N	\N
8731	MEMBRE	2004-10-01 00:00:00	2005-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	8581	\N	\N	\N
8735	MEMBRE	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8584	\N	\N	\N
8736	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8585	\N	\N	\N
8737	MEMBRE	2004-10-01 00:00:00	2004-11-11 00:00:00	ANCIEN	\N	\N	\N	\N	8586	\N	\N	\N
8739	MEMBRE	2004-10-01 00:00:00	2004-11-11 00:00:00	ANCIEN	\N	\N	\N	\N	8588	\N	\N	\N
8741	MEMBRE	2004-10-01 00:00:00	2007-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	8590	\N	\N	\N
8742	MEMBRE	2004-10-01 00:00:00	2004-11-11 00:00:00	ANCIEN	\N	\N	\N	\N	8591	\N	\N	\N
8743	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8592	\N	\N	\N
8744	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8593	\N	\N	\N
8745	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8594	\N	\N	\N
8746	MEMBRE	2004-10-01 00:00:00	2007-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8595	\N	\N	\N
8747	MEMBRE	2004-10-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	8596	\N	\N	\N
8748	MEMBRE	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8597	\N	\N	\N
8749	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8598	\N	\N	\N
8751	MEMBRE	2004-10-01 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	8600	\N	\N	\N
8752	MEMBRE	2004-10-01 00:00:00	2004-11-11 00:00:00	ANCIEN	\N	\N	\N	\N	8601	\N	\N	\N
8753	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8602	\N	\N	\N
8754	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8603	\N	\N	\N
8756	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8605	\N	\N	\N
8757	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8606	\N	\N	\N
8758	MEMBRE	2004-10-01 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	8607	\N	\N	\N
8759	MEMBREBUR	2004-11-12 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8588	\N	\N	\N
8760	VICPDT	2004-11-12 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8591	\N	\N	\N
8762	SECRET	2004-11-12 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8586	\N	\N	\N
8763	VICPDT	2004-11-12 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7806	\N	\N	\N
8765	MEMBREBUR	2004-11-12 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7820	\N	\N	\N
8766	MEMBREBUR	2004-11-12 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7826	\N	\N	\N
8768	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8608	\N	\N	\N
8769	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8609	\N	\N	\N
8770	MEMBRE	2004-10-01 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	8610	\N	\N	\N
9445	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9218	\N	\N	\N
9446	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9219	\N	\N	\N
9447	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9220	\N	\N	\N
9448	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9221	\N	\N	\N
9449	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9222	\N	\N	\N
9450	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9223	\N	\N	\N
9451	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9224	\N	\N	\N
9453	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9227	\N	\N	\N
9454	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9228	\N	\N	\N
9455	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9229	\N	\N	\N
9456	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9230	\N	\N	\N
9457	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9231	\N	\N	\N
9458	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9232	\N	\N	\N
9459	MEMBRE	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	9233	\N	\N	\N
9460	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9234	\N	\N	\N
9461	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9235	\N	\N	\N
9462	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9236	\N	\N	\N
9463	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9237	\N	\N	\N
9465	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9239	\N	\N	\N
9466	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9240	\N	\N	\N
9467	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9241	\N	\N	\N
9468	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9242	\N	\N	\N
9470	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9244	\N	\N	\N
9471	VICPDT	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9245	5	\N	\N
9472	MEMBRE	2004-10-01 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	9246	0	\N	\N
9473	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9247	\N	\N	\N
9474	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9248	\N	\N	\N
9475	MEMBRE	2004-10-01 00:00:00	2010-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	9249	\N	\N	\N
9476	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9250	\N	\N	\N
9478	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9252	\N	\N	\N
9479	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9253	\N	\N	\N
9481	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9255	\N	\N	\N
9482	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9256	\N	\N	\N
9483	SECRET	2004-10-01 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	9257	18	\N	\N
9485	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9259	\N	\N	\N
9486	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9260	\N	\N	\N
9488	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9262	\N	\N	\N
9489	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9263	\N	\N	\N
9490	SECRET	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9264	21	\N	\N
9491	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9265	\N	\N	\N
9492	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9266	\N	\N	\N
9493	SECRET	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9267	24	\N	\N
9494	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9268	\N	\N	\N
9495	SECRET	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9269	26	\N	\N
9496	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9270	\N	\N	\N
9497	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9271	\N	\N	\N
9499	VICPDT	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9273	10	\N	\N
9500	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9274	\N	\N	\N
9501	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9275	\N	\N	\N
9502	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9276	\N	\N	\N
9503	MEMBRE	2004-10-01 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	9277	\N	\N	\N
9504	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9278	\N	\N	\N
9505	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9279	\N	\N	\N
9506	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9280	\N	\N	\N
9507	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9281	\N	\N	\N
9508	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6313	\N	\N	\N
9509	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6313	\N	\N	\N
9510	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9289	\N	\N	\N
9511	MEMBRE	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	9290	\N	\N	\N
9512	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9291	\N	\N	\N
9514	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9293	\N	\N	\N
9515	SECRET	2004-10-01 00:00:00	2009-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	9294	\N	\N	\N
9516	SECRET	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9295	9	\N	\N
9517	MEMBRE	2004-10-01 00:00:00	2009-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	9296	\N	\N	\N
9518	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9297	\N	\N	\N
9519	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9298	\N	\N	\N
9520	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9299	\N	\N	\N
9521	VICPDT	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9300	7	\N	\N
9522	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9301	\N	\N	\N
9523	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9302	\N	\N	\N
9525	SECRET	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9304	12	\N	\N
9527	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9306	\N	\N	\N
9528	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9307	\N	\N	\N
9529	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9308	\N	\N	\N
9530	SECRET	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9309	14	\N	\N
9531	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9310	\N	\N	\N
9532	SECRET	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9311	10	\N	\N
9533	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9312	\N	\N	\N
9534	VICPDT	2004-10-26 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	3870	2	\N	\N
9535	TRESOR	2004-10-26 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3877	8	\N	\N
9536	PDT	2004-11-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4261	1	\N	\N
9538	VICPDT	2004-11-10 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8987	9	\N	\N
9540	VICPDT	2004-11-10 00:00:00	2009-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	2569	12	\N	\N
9541	SECRET	2004-11-10 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1529	14	\N	\N
9543	PDTDEL	2004-11-10 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	Tadjikistan	\N	2558	7	\N	\N
9544	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9313	\N	\N	\N
9546	MEMBRE	2004-10-01 00:00:00	2009-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	9315	\N	\N	\N
9547	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9317	\N	\N	\N
9548	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9318	\N	\N	\N
9549	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9319	\N	\N	\N
9550	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9320	\N	\N	\N
9551	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9321	\N	\N	\N
9552	MEMBRE	2004-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	9322	\N	\N	\N
9553	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9323	\N	\N	\N
9554	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9324	\N	\N	\N
10225	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9855	\N	\N	\N
10226	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9856	\N	\N	\N
10227	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9857	\N	\N	\N
10228	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9858	\N	\N	\N
10229	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9859	\N	\N	\N
10231	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9861	\N	\N	\N
10232	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9862	\N	\N	\N
10233	SECRET	2004-10-01 00:00:00	2008-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	9863	\N	\N	\N
10234	VICPDT	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9864	6	\N	\N
10236	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9866	\N	\N	\N
10237	MEMBRE	2004-11-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9867	\N	\N	\N
10238	VICPDT	2004-12-09 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	\N	4615	5	\N	\N
10240	PDT	2004-11-25 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3650	1	\N	\N
10241	VICPDT	2004-11-25 00:00:00	2009-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	3647	7	\N	\N
10243	SECRET	2004-11-25 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3679	12	\N	\N
10244	SECRET	2004-11-25 00:00:00	2009-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	5144	13	\N	\N
10245	SECRET	2004-11-25 00:00:00	2009-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	5146	14	\N	\N
10246	SECRET	2004-11-25 00:00:00	2010-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	5142	15	\N	\N
10247	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9868	\N	\N	\N
10251	SECRET	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	9871	11	\N	\N
10250	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9870	\N	\N	\N
10273	MEMBRE	2004-12-01 00:00:00	2004-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	9894	\N	\N	\N
10254	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9874	\N	\N	\N
10255	MEMBRE	2004-10-01 00:00:00	2007-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	9875	\N	\N	\N
10256	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9876	\N	\N	\N
10258	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9878	\N	\N	\N
10259	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9879	\N	\N	\N
11063	SECRET	2004-10-01 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	10483	11	\N	\N
11066	VICPDT	2004-10-01 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	10486	6	\N	\N
11067	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10487	\N	\N	\N
11068	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10488	\N	\N	\N
11070	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10490	\N	\N	\N
11072	MEMBRE	2004-10-01 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	10492	0	\N	\N
11073	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10493	\N	\N	\N
11074	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10494	\N	\N	\N
11075	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10495	\N	\N	\N
11076	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10496	\N	\N	\N
11078	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10498	\N	\N	\N
11079	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10499	\N	\N	\N
11080	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10500	\N	\N	\N
10468	SECRET	2004-10-01 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	10042	10	\N	\N
10469	MEMBRE	2004-10-01 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	10043	0	\N	\N
10470	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10044	\N	\N	\N
10471	SECRET	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10045	11	\N	\N
10473	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10047	\N	\N	\N
10474	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10048	\N	\N	\N
10475	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10049	\N	\N	\N
10476	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10050	\N	\N	\N
10477	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10051	\N	\N	\N
10478	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10052	\N	\N	\N
10479	SECRET	2004-10-01 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	10053	14	\N	\N
10480	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10054	\N	\N	\N
10481	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10055	\N	\N	\N
10482	MEMBRE	2004-10-01 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	10056	\N	\N	\N
10483	TRESOR	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10057	17	\N	\N
10484	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10060	\N	\N	\N
10485	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10061	\N	\N	\N
10486	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10062	\N	\N	\N
10488	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10064	\N	\N	\N
10491	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10067	\N	\N	\N
10492	MEMBRE	2004-10-01 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	10068	\N	\N	\N
10493	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10069	\N	\N	\N
10494	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10070	\N	\N	\N
10495	MEMBRE	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	10072	\N	\N	\N
10496	MEMBRE	1999-01-01 00:00:00	2004-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	3928	\N	\N	\N
10497	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10075	\N	\N	\N
10498	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10076	\N	\N	\N
10499	PDT	2000-01-01 00:00:00	2009-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	10077	1	\N	\N
10500	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10078	\N	\N	\N
10501	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10079	\N	\N	\N
10502	TRESORADJ	2004-10-01 00:00:00	2009-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	10080	16	\N	\N
10503	MEMBRE	2004-10-01 00:00:00	2005-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	10081	\N	\N	\N
10504	VICPDT	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10082	6	\N	\N
10506	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10084	\N	\N	\N
10508	TRESOR	2004-10-01 00:00:00	2009-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	10086	15	\N	\N
10509	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10087	\N	\N	\N
10510	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10089	\N	\N	\N
10512	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10095	\N	\N	\N
10513	MEMBRE	2004-10-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	10096	0	\N	\N
10514	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10097	\N	\N	\N
10515	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10098	\N	\N	\N
10516	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10099	\N	\N	\N
10517	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10100	\N	\N	\N
10518	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10101	\N	\N	\N
10519	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10102	\N	\N	\N
10521	MEMBREBUR	2004-10-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	10104	14	\N	\N
10523	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10106	\N	\N	\N
10524	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10107	\N	\N	\N
10525	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10108	\N	\N	\N
10526	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10109	\N	\N	\N
10527	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10110	\N	\N	\N
9347	MEMBRE	2004-10-01 00:00:00	2005-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	9113	\N	\N	\N
9348	MEMBRE	2004-10-01 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	9114	4	\N	\N
9349	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9115	\N	\N	\N
9350	VICPDT	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	9116	2	\N	\N
9351	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9117	\N	\N	\N
9352	MEMBRE	2004-10-01 00:00:00	2007-10-23 00:00:00	ANCIEN	\N	\N	\N	\N	9118	\N	\N	\N
9354	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9120	\N	\N	\N
9355	MEMBRE	2004-10-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	9123	\N	\N	\N
9356	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9124	\N	\N	\N
9357	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9126	\N	\N	\N
9358	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9128	\N	\N	\N
9359	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9129	\N	\N	\N
9361	MEMBRE	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	9131	\N	\N	\N
9364	MEMBRE	2004-10-01 00:00:00	2005-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	9134	\N	\N	\N
9365	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9135	\N	\N	\N
9367	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9138	\N	\N	\N
9368	VICPDT	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9139	10	\N	\N
9369	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9140	\N	\N	\N
9370	MEMBRE	2004-10-01 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	\N	9141	\N	\N	\N
9371	PDTDEL	2004-10-01 00:00:00	2009-03-09 00:00:00	ANCIEN	\N	\N	Sultanat d'Oman	\N	9142	5	\N	\N
9372	PDTDEL	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Qatar	\N	9143	6	\N	\N
9373	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9144	\N	\N	\N
9374	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9145	\N	\N	\N
9375	MEMBRE	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	9146	\N	\N	\N
9376	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9147	\N	\N	\N
9377	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9148	\N	\N	\N
9378	MEMBRE	2002-01-09 00:00:00	2004-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	6136	\N	\N	\N
9379	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9151	\N	\N	\N
9380	MEMBRE	2004-10-01 00:00:00	2009-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	9152	0	\N	\N
9381	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9153	\N	\N	\N
9382	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9154	\N	\N	\N
9383	MEMBRE	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	9155	\N	\N	\N
9908	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9603	\N	\N	\N
9909	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9604	\N	\N	\N
9910	MEMBRE	2004-10-01 00:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	9605	0	\N	\N
9911	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9606	\N	\N	\N
9912	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9607	\N	\N	\N
9913	SECRET	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	9608	16	\N	\N
9916	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9611	\N	\N	\N
9918	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9614	\N	\N	\N
9919	SECRET	2004-10-01 00:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	9616	18	\N	\N
9922	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9619	\N	\N	\N
9923	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9620	\N	\N	\N
9924	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9621	\N	\N	\N
9925	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9622	\N	\N	\N
9927	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9624	\N	\N	\N
9928	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9626	\N	\N	\N
9930	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9628	\N	\N	\N
9931	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9629	\N	\N	\N
9932	VICPDT	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9630	7	\N	\N
9933	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9631	\N	\N	\N
9934	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9632	\N	\N	\N
9935	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9633	\N	\N	\N
9936	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9634	\N	\N	\N
9938	VICPDT	2004-10-01 00:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	9636	10	\N	\N
9939	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9637	\N	\N	\N
9940	MEMBRE	2004-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	9638	\N	\N	\N
9941	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9639	\N	\N	\N
9943	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9641	\N	\N	\N
9944	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9642	\N	\N	\N
9945	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9643	\N	\N	\N
9946	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9644	\N	\N	\N
9948	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9646	\N	\N	\N
9949	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9647	\N	\N	\N
9950	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9648	\N	\N	\N
9952	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9650	\N	\N	\N
9953	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9651	\N	\N	\N
9954	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9652	\N	\N	\N
9982	PDT	2004-12-14 00:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	1989	1	\N	\N
9984	VICPDT	2001-10-01 00:00:00	2004-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	1989	5	\N	\N
9957	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9655	\N	\N	\N
9958	MEMBREBUR	2004-10-01 00:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	9656	27	\N	\N
9959	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9657	\N	\N	\N
9960	MEMBREBUR	2004-10-01 00:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	9658	29	\N	\N
9961	SECRET	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9659	19	\N	\N
9962	PDTHON	2004-10-01 00:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	9660	2	\N	\N
9963	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9661	\N	\N	\N
9964	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9662	\N	\N	\N
9966	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9664	\N	\N	\N
9967	MEMBREBUR	2004-10-01 00:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	9665	32	\N	\N
9968	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9666	\N	\N	\N
9969	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9667	\N	\N	\N
9970	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9668	\N	\N	\N
9971	MEMBREBUR	2004-10-01 00:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	9669	33	\N	\N
9972	SECRET	2004-10-01 00:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	9670	20	\N	\N
9973	VICPDT	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9671	14	\N	\N
9974	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9672	\N	\N	\N
9975	MEMBREBUR	2004-10-01 00:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	9673	35	\N	\N
9976	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9674	\N	\N	\N
9978	MEMBRE	2004-10-01 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	9676	\N	\N	\N
9979	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9677	\N	\N	\N
9980	MEMBRE	2004-10-01 00:00:00	2010-01-07 00:00:00	ANCIEN	\N	\N	\N	\N	9678	\N	\N	\N
9981	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9680	\N	\N	\N
9985	VICPDT	2004-12-14 00:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	3339	4	\N	\N
9986	VICPDT	2004-12-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4795	5	\N	\N
9987	VICPDT	2004-12-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3343	6	\N	\N
9989	VICPDT	2004-12-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1068	9	\N	\N
9990	VICPDT	2004-12-14 00:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	1270	15	\N	\N
9991	MEMBREBUR	2004-12-14 00:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	4789	21	\N	\N
9992	MEMBREBUR	2004-12-14 00:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	4790	22	\N	\N
9994	MEMBREBUR	2004-12-14 00:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	3349	25	\N	\N
9995	MEMBREBUR	2004-12-14 00:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	3350	26	\N	\N
9996	MEMBREBUR	2004-12-14 01:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	4805	28	\N	\N
9998	MEMBREBUR	2004-12-14 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	3365	34	\N	\N
10000	MEMBRE	2004-12-14 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1365	\N	\N	\N
10001	MEMBRE	2004-12-14 00:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	4793	0	\N	\N
10002	MEMBRE	2004-12-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4804	\N	\N	\N
10003	MEMBRE	2004-12-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4817	\N	\N	\N
10004	PDT	2004-11-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4855	1	\N	\N
10005	VICPDTPRE	2004-11-17 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3143	2	\N	\N
10006	VICPDT	2004-11-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6608	6	\N	\N
10007	VICPDT	2004-11-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4857	7	\N	\N
10008	TRESOR	2004-11-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6607	9	\N	\N
10009	SECRET	2004-11-17 00:00:00	2008-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	8550	9	\N	\N
10010	SECRET	2004-11-17 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8520	13	\N	\N
10012	VICPDT	2004-11-30 00:00:00	2009-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	4602	22	\N	\N
10013	VICPDT	2004-11-30 00:00:00	2009-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	4603	23	\N	\N
10014	VICPDT	2004-11-30 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2567	24	\N	\N
10016	SECRET	2004-11-30 00:00:00	2009-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	4583	27	\N	\N
10018	MEMBRE	2004-11-30 00:00:00	2009-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	2516	0	\N	\N
10019	VICPDT	2004-12-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4638	2	\N	\N
10020	VICPDT	2004-12-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	524	3	\N	\N
10021	VICPDT	2004-12-07 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	2054	6	\N	\N
10022	VICPDT	2004-12-07 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	4646	8	\N	\N
10023	SECRET	2004-12-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4635	6	\N	\N
10024	SECRET	2004-12-07 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	4643	10	\N	\N
10025	TRESORADJ	2004-12-07 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	606	13	\N	\N
10026	MEMBRE	2004-12-07 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	574	\N	\N	\N
10027	VICPDT	2004-12-08 00:00:00	2009-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	6298	\N	\N	\N
10028	VICPDT	2004-12-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6304	5	\N	\N
10029	VICPDT	2004-12-08 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6350	5	\N	\N
10030	SECRET	2004-12-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6302	10	\N	\N
10031	SECRET	2004-12-08 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6308	13	\N	\N
10032	MEMBRE	2004-12-08 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3956	\N	\N	\N
10033	MEMBRE	2004-12-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3969	\N	\N	\N
10034	MEMBRE	2004-12-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3951	\N	\N	\N
10035	MEMBRE	2004-12-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3963	\N	\N	\N
10036	PDT	2004-11-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2239	1	\N	\N
10037	VICPDT	2004-11-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1429	13	\N	\N
10038	VICPDT	2004-11-09 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3077	15	\N	\N
10042	PDT	2004-12-08 00:00:00	2009-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	5095	\N	\N	\N
10043	VICPDT	2004-12-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5080	2	\N	\N
10044	SECRET	2004-12-08 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5098	11	\N	\N
10046	MEMBRE	2004-12-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3769	\N	\N	\N
10048	SECRET	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9682	17	\N	\N
10049	MEMBREBUR	2004-10-01 00:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	9683	23	\N	\N
10050	VICPDT	2004-12-08 00:00:00	2008-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	6265	2	\N	\N
10051	VICPDT	2004-12-08 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4435	3	\N	\N
10052	VICPDT	2004-12-08 00:00:00	2008-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	6383	4	\N	\N
10053	SECRET	2004-12-08 00:00:00	2008-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	9557	5	\N	\N
10054	MEMBRE	2004-12-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5924	\N	\N	\N
10055	VICPDT	2004-11-23 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3836	8	\N	\N
10056	PDTDEL	2004-11-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Emirats arabes unis	\N	6609	3	\N	\N
10057	MEMBRE	2004-11-23 00:00:00	2007-06-05 00:00:00	ANCIEN	\N	\N	\N	\N	5314	0	\N	\N
10058	PDTDEL	2004-11-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	République démocratique du Congo	\N	5507	7	\N	\N
10059	MEMBRE	2004-11-09 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2805	\N	\N	\N
10060	VICPDT	2004-11-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5246	2	\N	\N
10062	VICPDT	2004-11-03 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1075	4	\N	\N
10063	SECRET	2004-11-03 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5250	8	\N	\N
10065	VICPDT	2004-11-04 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5789	6	\N	\N
10066	MEMBRE	2004-11-04 00:00:00	2009-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	3593	\N	\N	\N
10067	VICPDT	2004-11-10 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5759	5	\N	\N
10068	MEMBRE	2004-11-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5758	\N	\N	\N
10069	MEMBRE	2004-11-10 00:00:00	2007-10-23 00:00:00	ANCIEN	\N	\N	\N	\N	5765	\N	\N	\N
10070	MEMBRE	2004-10-01 00:00:00	2004-12-22 00:00:00	ANCIEN	\N	\N	\N	\N	9684	\N	\N	\N
10071	MEMBRE	2004-12-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9684	\N	\N	\N
10072	SECRET	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9690	5	\N	\N
10073	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9691	\N	\N	\N
10074	VICPDT	2004-10-01 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	9692	\N	\N	\N
10075	MEMBRE	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	9693	\N	\N	\N
10076	SECRET	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9694	8	\N	\N
10078	SECRET	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	9698	12	\N	\N
10079	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9699	\N	\N	\N
10080	VICPDT	2004-10-01 00:00:00	2009-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	9700	6	\N	\N
10082	VICPDT	2004-10-01 00:00:00	2009-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	9702	8	\N	\N
10083	SECRET	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9703	15	\N	\N
10084	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9704	\N	\N	\N
10085	VICPDT	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9705	6	\N	\N
10086	VICPDT	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9706	7	\N	\N
10087	SECRET	2004-10-01 00:00:00	2009-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	9707	16	\N	\N
10088	MEMBRE	2004-10-01 00:00:00	2008-09-07 00:00:00	ANCIEN	\N	\N	\N	\N	9708	\N	\N	\N
10089	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9709	\N	\N	\N
10090	MEMBRE	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	9711	\N	\N	\N
10091	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9712	\N	\N	\N
10719	SECRET	2004-10-26 00:00:00	2007-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	7665	\N	\N	\N
10720	MEMBRE	2004-10-01 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	10207	\N	\N	\N
10721	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10208	\N	\N	\N
10722	MEMBRE	2004-10-01 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	10210	\N	\N	\N
10772	MEMBRE	2004-10-01 00:00:00	2009-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	10247	\N	\N	\N
10773	PDTDEL	2004-10-01 00:00:00	2009-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	10248	\N	\N	\N
10725	MEMBRE	2004-10-01 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	10213	\N	\N	\N
10726	MEMBRE	2004-10-01 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	10214	\N	\N	\N
10727	VICPDT	2004-10-01 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	10215	3	\N	\N
10729	MEMBRE	2004-10-01 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	10217	\N	\N	\N
10730	MEMBRE	2004-10-01 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	10218	\N	\N	\N
10731	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10219	\N	\N	\N
10732	VICPDT	2004-10-01 00:00:00	2010-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	10220	3	\N	\N
10733	MEMBRE	2004-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	10221	\N	\N	\N
10734	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10223	\N	\N	\N
10735	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10224	\N	\N	\N
10736	VICPDT	2004-10-01 00:00:00	2005-03-19 00:00:00	ANCIEN	\N	\N	\N	\N	10225	6	\N	\N
10759	VICPDT	2004-12-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6222	3	\N	\N
10738	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10227	\N	\N	\N
10739	VICPDT	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10228	8	\N	\N
10740	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10230	\N	\N	\N
10741	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10233	\N	\N	\N
10742	VICPDT	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10234	2	\N	\N
10743	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10235	\N	\N	\N
10744	VICPDT	2004-10-01 00:00:00	2009-04-27 00:00:00	ANCIEN	\N	\N	\N	\N	10236	4	\N	\N
10745	VICPDT	2004-10-01 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	\N	10237	5	\N	\N
10746	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10238	\N	\N	\N
10747	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10239	\N	\N	\N
10748	VICPDT	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10240	2	\N	\N
10749	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10241	\N	\N	\N
10751	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10243	\N	\N	\N
10753	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10245	\N	\N	\N
10756	VICPDT	2004-12-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6254	4	\N	\N
10757	VICPDT	2004-12-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4233	5	\N	\N
10758	VICPDT	2004-12-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4244	7	\N	\N
10760	VICPDT	2004-12-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6224	3	\N	\N
10761	VICPDT	2004-12-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3317	7	\N	\N
10763	VICPDT	2004-12-07 00:00:00	2009-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	2226	3	\N	\N
10764	VICPDT	2004-12-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6246	6	\N	\N
18135	MEMBRE	2011-10-01 00:00:00	2012-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	16339	\N	\N	\N
10765	VICPDT	2004-12-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6248	7	\N	\N
10766	VICPDT	2005-02-09 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	6476	2	\N	\N
10768	TRESOR	2005-02-09 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	6480	5	\N	\N
10770	MEMBRE	2005-02-09 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	6482	\N	\N	\N
10774	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10249	\N	\N	\N
10775	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10250	\N	\N	\N
10776	PDTDEL	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Soudan	\N	10251	5	\N	\N
10777	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10252	\N	\N	\N
10778	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10253	\N	\N	\N
10779	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10254	\N	\N	\N
10780	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10255	\N	\N	\N
10781	MEMBRE	2004-10-01 00:00:00	2009-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	10257	0	\N	\N
10782	VICPDT	2004-10-01 00:00:00	2009-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	10258	4	\N	\N
10783	MEMBRE	2004-10-01 00:00:00	2009-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	10259	0	\N	\N
10784	SECRET	2004-12-16 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6467	8	\N	\N
10785	VICPDT	2004-12-08 00:00:00	2009-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	5939	6	\N	\N
10786	VICPDT	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10260	2	\N	\N
10787	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10261	\N	\N	\N
10788	MEMBRE	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	10262	\N	\N	\N
10789	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10263	\N	\N	\N
10790	VICPDT	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10264	4	\N	\N
10791	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10265	\N	\N	\N
10792	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10266	\N	\N	\N
10793	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10267	\N	\N	\N
10796	SECRET	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10270	9	\N	\N
10797	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10271	\N	\N	\N
10799	MEMBRE	2004-10-01 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	\N	10273	\N	\N	\N
10800	SECRET	2004-10-01 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	10274	11	\N	\N
10801	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10275	\N	\N	\N
10802	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10276	\N	\N	\N
10803	PDT	2004-10-01 00:00:00	2010-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	10277	1	\N	\N
18137	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16341	\N	\N	\N
10804	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10278	\N	\N	\N
10805	SECRET	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10279	12	\N	\N
10807	MEMBRE	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	10282	\N	\N	\N
10808	PDT	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10283	1	\N	\N
10809	MEMBRE	2004-10-01 00:00:00	2009-03-30 00:00:00	ANCIEN	\N	\N	\N	\N	10284	0	\N	\N
10810	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10286	\N	\N	\N
10811	MEMBRE	2004-10-01 00:00:00	2008-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	10287	\N	\N	\N
10812	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10288	\N	\N	\N
10813	SECRET	2004-10-01 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	10289	5	\N	\N
10814	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10290	\N	\N	\N
10815	VICPDT	2004-10-01 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	10291	\N	\N	\N
10816	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10293	\N	\N	\N
10817	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10294	\N	\N	\N
10818	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10295	\N	\N	\N
10819	MEMBRE	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	10296	\N	\N	\N
10820	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10297	\N	\N	\N
10822	MEMBRE	2004-10-01 00:00:00	2007-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	10299	\N	\N	\N
10823	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10300	\N	\N	\N
10824	MEMBRE	2005-02-15 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	7909	\N	\N	\N
10825	VICPDT	2005-02-15 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	7911	\N	\N	\N
10826	VICPDT	2005-02-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7913	\N	\N	\N
10827	SECRET	2005-02-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10298	\N	\N	\N
10828	SECRET	2005-01-19 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	6453	\N	\N	\N
10829	MEMBREBUR	2005-01-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2248	7	\N	\N
10830	MEMBREBUR	2005-01-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3896	9	\N	\N
10831	VICPDT	2004-12-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4763	3	\N	\N
10833	PDTHON	2004-12-07 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	46	9	\N	\N
10836	MEMBRE	2005-02-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10303	\N	\N	\N
10837	MEMBRE	2005-02-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10304	\N	\N	\N
10838	MEMBRE	2005-02-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10305	\N	\N	\N
10841	MEMBRE	2005-02-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10308	\N	\N	\N
10840	MEMBRE	2005-02-21 00:00:00	2010-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	10307	\N	\N	\N
10842	MEMBRE	2005-02-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10309	\N	\N	\N
10843	MEMBRE	2005-02-21 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	10310	\N	\N	\N
10845	SECRET	2005-02-21 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	10312	6	\N	\N
10846	MEMBRE	2005-02-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10314	\N	\N	\N
10847	MEMBRE	2005-02-21 00:00:00	2010-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	10315	\N	\N	\N
10848	MEMBRE	2005-02-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10316	\N	\N	\N
10849	MEMBRE	2005-02-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10318	\N	\N	\N
10850	MEMBRE	2005-02-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10319	\N	\N	\N
10851	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10320	\N	\N	\N
10852	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10321	\N	\N	\N
10853	VICPDT	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	10322	3	\N	\N
10854	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10323	\N	\N	\N
10855	MEMBRE	2004-10-01 00:00:00	2009-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	10324	\N	\N	\N
10856	VICPDT	2004-10-01 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	\N	10325	5	\N	\N
10857	VICPDT	2004-10-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	10326	7	\N	\N
10858	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10327	\N	\N	\N
10859	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10328	\N	\N	\N
10862	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10332	\N	\N	\N
10863	MEMBRE	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	10333	\N	\N	\N
10864	MEMBRE	2004-10-01 00:00:00	2009-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	10334	0	\N	\N
10865	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10335	\N	\N	\N
10866	PDTDEL	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Zimbabwe	\N	10336	7	\N	\N
10868	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10338	\N	\N	\N
10869	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10339	\N	\N	\N
10870	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10341	\N	\N	\N
10871	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10342	\N	\N	\N
10872	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10343	\N	\N	\N
10873	MEMBRE	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	10344	\N	\N	\N
10874	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10345	\N	\N	\N
10875	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10346	\N	\N	\N
10876	PDTDEL	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	Bolivie	\N	10347	5	\N	\N
18138	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16342	\N	\N	\N
10877	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10348	\N	\N	\N
10879	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10350	\N	\N	\N
10880	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10351	\N	\N	\N
10881	MEMBRE	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	10352	\N	\N	\N
10882	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10353	\N	\N	\N
10883	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10354	\N	\N	\N
10884	VICPDT	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10355	4	\N	\N
10885	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10356	\N	\N	\N
10886	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10357	\N	\N	\N
10887	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10358	\N	\N	\N
10888	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10359	\N	\N	\N
10889	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10360	\N	\N	\N
10891	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10362	\N	\N	\N
10892	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10363	\N	\N	\N
10893	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10364	\N	\N	\N
10894	SECRET	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10365	10	\N	\N
10895	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10367	\N	\N	\N
10896	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10368	\N	\N	\N
10897	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10369	\N	\N	\N
10899	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10372	\N	\N	\N
10900	SECRET	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10371	16	\N	\N
10902	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10375	\N	\N	\N
10903	MEMBRE	2005-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10376	\N	\N	\N
10904	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10377	\N	\N	\N
10905	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10378	\N	\N	\N
10906	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10379	\N	\N	\N
10907	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10380	\N	\N	\N
10908	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3272	\N	\N	\N
10909	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10382	\N	\N	\N
10910	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10384	\N	\N	\N
10911	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10385	\N	\N	\N
10912	MEMBRE	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	10386	\N	\N	\N
10914	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10388	\N	\N	\N
10916	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10390	\N	\N	\N
10917	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10391	\N	\N	\N
10920	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10394	\N	\N	\N
10921	PDT	2004-11-23 00:00:00	2009-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	2517	\N	\N	\N
10922	PDTHON	2004-11-23 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	569	2	\N	\N
10923	VICPDT	2004-11-23 00:00:00	2009-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	4981	6	\N	\N
10925	SECRET	2004-11-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4964	8	\N	\N
10926	PDTDEL	2004-11-24 00:00:00	2009-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	6141	7	\N	\N
10933	PDTDEL	2004-11-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	Equateur	\N	6150	9	\N	\N
10934	SECRET	2004-11-24 00:00:00	2009-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	1424	14	\N	\N
10935	MEMBRE	2004-11-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2319	\N	\N	\N
10944	VICPDT	2004-10-26 00:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	5531	\N	\N	\N
10937	VICPDT	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10396	2	\N	\N
10939	VICPDT	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10398	4	\N	\N
10940	VICPDT	2004-10-01 00:00:00	2010-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	10399	5	\N	\N
10941	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10400	\N	\N	\N
10942	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10401	\N	\N	\N
10943	VICPDT	2004-10-26 00:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	3276	\N	\N	\N
10945	SECRET	2004-10-26 00:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	5528	\N	\N	\N
10946	MEMBRE	2004-10-26 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1557	\N	\N	\N
10947	MEMBRE	2004-10-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5534	\N	\N	\N
10948	VICPDT	2005-03-08 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3178	2	\N	\N
10949	VICPDT	2005-03-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5407	\N	\N	\N
10950	VICPDT	2005-03-08 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3198	6	\N	\N
10951	SECRET	2005-03-08 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	5387	\N	\N	\N
10952	SECRET	2005-03-08 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3197	13	\N	\N
10953	VICPDT	2005-03-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4421	3	\N	\N
10954	SECRET	2005-03-08 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2503	8	\N	\N
10955	MEMBRE	2005-03-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2265	\N	\N	\N
10956	MEMBRE	2005-03-08 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	547	\N	\N	\N
10957	MEMBRE	2005-03-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1820	\N	\N	\N
10961	VICPDT	2005-02-02 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5440	12	\N	\N
10959	MEMBRE	2005-03-08 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1093	\N	\N	\N
10970	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10408	\N	\N	\N
10967	MEMBRE	2005-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10405	\N	\N	\N
10974	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10412	\N	\N	\N
10979	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10417	\N	\N	\N
10981	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10419	\N	\N	\N
10984	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10422	\N	\N	\N
10985	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10423	\N	\N	\N
10986	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10424	\N	\N	\N
10987	MEMBRE	2005-02-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10425	\N	\N	\N
10989	MEMBRE	2005-03-15 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	10427	\N	\N	\N
10990	MEMBRE	2005-03-15 00:00:00	2005-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	10428	\N	\N	\N
10991	MEMBRE	2005-03-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10429	\N	\N	\N
10992	MEMBRE	2005-03-15 00:00:00	2005-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	10430	\N	\N	\N
10994	MEMBRE	2005-03-15 00:00:00	2005-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	10432	\N	\N	\N
10995	MEMBRE	2005-03-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10433	\N	\N	\N
10997	MEMBRE	2005-03-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10435	\N	\N	\N
10998	MEMBRE	2005-03-15 00:00:00	2005-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	10436	\N	\N	\N
10999	MEMBRE	2005-03-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10437	\N	\N	\N
11000	MEMBRE	2005-03-15 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	10438	\N	\N	\N
11001	MEMBRE	2005-03-15 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	10439	\N	\N	\N
11002	MEMBRE	2005-03-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10440	\N	\N	\N
11003	MEMBRE	2005-03-15 00:00:00	2005-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	10441	\N	\N	\N
11004	MEMBRE	2005-03-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10442	\N	\N	\N
11005	MEMBRE	2005-03-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10443	\N	\N	\N
11006	MEMBRE	2005-03-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10444	\N	\N	\N
11007	MEMBRE	2005-03-15 00:00:00	2005-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	10445	\N	\N	\N
11009	PDT	2005-03-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10430	\N	\N	\N
11010	VICPDT	2005-03-16 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10445	\N	\N	\N
11012	VICPDT	2005-03-18 00:00:00	2005-03-22 00:00:00	ANCIEN	\N	\N	\N	\N	10446	\N	\N	\N
11015	SECRET	2005-03-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10441	\N	\N	\N
11018	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10448	\N	\N	\N
11019	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10449	\N	\N	\N
11021	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10451	\N	\N	\N
11022	MEMBRE	2004-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	10452	\N	\N	\N
11023	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10453	\N	\N	\N
11024	MEMBRE	2004-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	10454	\N	\N	\N
11026	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10456	\N	\N	\N
11027	MEMBRE	2004-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	10457	\N	\N	\N
11028	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10458	\N	\N	\N
11029	MEMBRE	2004-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	10459	\N	\N	\N
11030	MEMBRE	2004-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	10460	\N	\N	\N
11031	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10461	\N	\N	\N
11032	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10462	\N	\N	\N
11033	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10463	\N	\N	\N
11034	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10464	\N	\N	\N
11035	MEMBRE	2004-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	10465	\N	\N	\N
11036	MEMBRE	2004-10-01 00:00:00	2010-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	10466	\N	\N	\N
11037	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10467	\N	\N	\N
11038	MEMBRE	2004-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	10468	\N	\N	\N
11039	PDT	2005-03-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10463	\N	\N	\N
11040	MEMBRE	2004-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	10469	\N	\N	\N
11041	PDT	2005-03-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10469	\N	\N	\N
11042	VICPDT	2005-03-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10465	\N	\N	\N
11043	VICPDT	2005-03-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10457	\N	\N	\N
11044	VICPDT	2005-03-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10452	\N	\N	\N
11046	SECRET	2005-03-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10455	\N	\N	\N
11049	MEMBRE	2005-03-25 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10470	\N	\N	\N
11050	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10471	\N	\N	\N
11053	SECRET	2005-03-23 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10446	\N	\N	\N
11055	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10474	\N	\N	\N
11056	MEMBRE	2004-10-01 00:00:00	2005-03-30 00:00:00	ANCIEN	\N	\N	\N	\N	10475	\N	\N	\N
11057	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10476	\N	\N	\N
11064	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10484	\N	\N	\N
11065	MEMBRE	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	10485	\N	\N	\N
11492	MEMBRE	2005-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10839	\N	\N	\N
11493	MEMBRE	2005-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10840	\N	\N	\N
11494	MEMBRE	2005-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10841	\N	\N	\N
11495	MEMBRE	2005-12-01 00:00:00	2006-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	10842	\N	\N	\N
11496	MEMBRE	2005-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10843	\N	\N	\N
11498	MEMBRE	2005-12-01 00:00:00	2006-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	10845	\N	\N	\N
11499	MEMBRE	2005-12-01 00:00:00	2006-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	10846	\N	\N	\N
11500	MEMBRE	2005-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10847	\N	\N	\N
11503	MEMBRE	2005-12-01 00:00:00	2006-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	10850	\N	\N	\N
11504	MEMBRE	2005-12-01 00:00:00	2006-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	10851	\N	\N	\N
11505	MEMBRE	2005-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10852	\N	\N	\N
11506	VICPDT	2005-12-23 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	10565	\N	\N	\N
11507	MEMBRE	2005-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10853	\N	\N	\N
11508	MEMBRE	2005-12-01 00:00:00	2006-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	10854	\N	\N	\N
11509	MEMBRE	2005-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10855	\N	\N	\N
11510	MEMBRE	2005-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10856	\N	\N	\N
11511	MEMBRE	2005-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10857	\N	\N	\N
11513	MEMBRE	2005-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10859	\N	\N	\N
11514	MEMBRE	2005-12-01 00:00:00	2007-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	10860	\N	\N	\N
11516	MEMBRE	2005-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10862	\N	\N	\N
11517	MEMBRE	2005-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10863	\N	\N	\N
11518	MEMBRE	2005-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10864	\N	\N	\N
11519	MEMBRE	2005-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10865	\N	\N	\N
11520	MEMBRE	2005-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10866	\N	\N	\N
11521	MEMBRE	2005-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10867	\N	\N	\N
11522	MEMBRE	2005-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10868	\N	\N	\N
11523	MEMBRE	2005-12-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	10869	\N	\N	\N
11524	MEMBRE	2005-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10870	\N	\N	\N
11525	MEMBRE	2005-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10871	\N	\N	\N
11526	MEMBRE	2006-01-16 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10872	\N	\N	\N
11528	VICPDT	2006-01-18 00:00:00	2009-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	10854	\N	\N	\N
11529	VICPDT	2006-01-18 00:00:00	2009-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	10850	3	\N	\N
11531	SECRET	2006-01-18 00:00:00	2009-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	10838	5	\N	\N
11532	SECRET	2006-01-18 00:00:00	2009-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	10842	6	\N	\N
11534	SECRET	2006-01-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10846	7	\N	\N
11535	SECRET	2006-01-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10851	10	\N	\N
11536	MEMBRE	2006-01-31 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10873	\N	\N	\N
11537	MEMBRE	2006-01-31 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10874	\N	\N	\N
11538	MEMBRE	2006-01-31 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10875	\N	\N	\N
11539	MEMBRE	2006-01-31 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10876	\N	\N	\N
18641	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16844	\N	\N	\N
11541	MEMBRE	2006-01-31 00:00:00	2006-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	10878	\N	\N	\N
11543	MEMBRE	2006-01-31 00:00:00	2010-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	10880	\N	\N	\N
11544	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10881	\N	\N	\N
11546	MEMBRE	2006-01-31 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10883	\N	\N	\N
11547	MEMBRE	2006-01-31 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10884	\N	\N	\N
11548	MEMBRE	2006-01-31 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10885	\N	\N	\N
11549	MEMBRE	2006-02-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10886	\N	\N	\N
11550	MEMBRE	2006-02-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10887	\N	\N	\N
11551	MEMBRE	2006-02-01 00:00:00	2006-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	10888	\N	\N	\N
11552	MEMBRE	2005-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10889	\N	\N	\N
11553	MEMBRE	2005-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10890	\N	\N	\N
11555	MEMBRE	2005-12-01 00:00:00	2007-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10892	\N	\N	\N
11556	MEMBRE	2006-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10893	\N	\N	\N
11557	MEMBRE	2006-01-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10894	\N	\N	\N
11558	MEMBRE	2005-01-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10895	\N	\N	\N
11559	MEMBRE	2006-01-24 00:00:00	2007-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10896	\N	\N	\N
11560	MEMBRE	2006-01-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10897	\N	\N	\N
11561	MEMBRE	2006-01-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10899	\N	\N	\N
11562	MEMBRE	2006-01-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10900	\N	\N	\N
11563	MEMBRE	2006-02-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10901	\N	\N	\N
11565	MEMBRE	2006-02-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10903	\N	\N	\N
11568	MEMBRE	2006-01-31 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10906	\N	\N	\N
11569	MEMBRE	2006-01-31 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	10907	\N	\N	\N
11570	MEMBRE	2006-02-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10908	\N	\N	\N
11573	MEMBRE	2006-01-31 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10911	\N	\N	\N
11575	MEMBRE	2006-01-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10913	\N	\N	\N
11576	MEMBRE	2006-01-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10914	\N	\N	\N
11577	MEMBRE	2006-01-24 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	10915	\N	\N	\N
11578	MEMBRE	2006-01-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10916	\N	\N	\N
11579	MEMBRE	2006-01-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10917	\N	\N	\N
11580	MEMBRE	2006-01-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10918	\N	\N	\N
11581	MEMBRE	2006-01-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10919	\N	\N	\N
11582	MEMBRE	2006-01-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10920	\N	\N	\N
11584	SECRET	2006-01-24 00:00:00	2009-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	10922	\N	\N	\N
11585	MEMBRE	2006-01-24 00:00:00	2007-02-25 00:00:00	ANCIEN	\N	\N	\N	\N	10923	\N	\N	\N
11586	MEMBRE	2006-01-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10924	\N	\N	\N
11587	MEMBRE	2006-01-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10925	\N	\N	\N
11588	MEMBRE	2006-01-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10926	\N	\N	\N
11589	MEMBRE	2006-01-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10927	\N	\N	\N
11590	MEMBRE	2006-02-01 00:00:00	2006-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	10928	\N	\N	\N
11591	VICPDT	2006-02-07 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10928	\N	\N	\N
11592	PDT	2006-02-07 00:00:00	2009-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	10912	\N	\N	\N
11594	SECRET	2006-02-07 00:00:00	2009-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	10888	\N	\N	\N
11597	MEMBRE	2006-02-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10931	\N	\N	\N
11599	MEMBRE	2006-02-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10933	\N	\N	\N
11600	MEMBRE	2006-02-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10934	\N	\N	\N
11602	MEMBRE	2006-01-31 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10936	\N	\N	\N
11603	MEMBRE	2006-02-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10937	\N	\N	\N
11605	MEMBRE	2006-02-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10939	\N	\N	\N
11606	MEMBRE	2006-02-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10940	\N	\N	\N
11607	MEMBRE	2006-02-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10941	\N	\N	\N
11611	MEMBRE	2006-02-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10945	\N	\N	\N
11612	MEMBRE	2006-01-31 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10946	\N	\N	\N
11613	MEMBRE	2006-01-31 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10947	\N	\N	\N
11614	MEMBRE	2006-02-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10948	\N	\N	\N
10453	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10026	\N	\N	\N
10454	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10027	\N	\N	\N
10455	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10028	\N	\N	\N
10456	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10030	\N	\N	\N
10458	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10032	\N	\N	\N
10459	MEMBRE	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	10033	\N	\N	\N
10460	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10034	\N	\N	\N
10461	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10035	\N	\N	\N
10462	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10036	\N	\N	\N
10463	MEMBRE	2004-10-01 00:00:00	2005-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	10037	\N	\N	\N
10465	MEMBRE	2004-10-01 00:00:00	2006-08-11 00:00:00	ANCIEN	\N	\N	\N	\N	10039	\N	\N	\N
10467	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10041	\N	\N	\N
11083	PDTDEL	2005-03-23 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	Erythrée	\N	10503	3	\N	\N
11085	MEMBRE	2005-03-23 00:00:00	2010-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	10505	\N	\N	\N
11086	MEMBRE	2005-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10506	\N	\N	\N
11087	MEMBRE	2005-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10507	\N	\N	\N
11088	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10508	\N	\N	\N
11089	MEMBRE	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	10509	\N	\N	\N
11090	MEMBRE	2004-10-01 00:00:00	2005-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	10510	\N	\N	\N
11091	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10511	\N	\N	\N
11092	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10512	\N	\N	\N
11093	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10513	\N	\N	\N
11094	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10514	\N	\N	\N
11095	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10515	\N	\N	\N
11096	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10516	\N	\N	\N
11097	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10517	\N	\N	\N
11098	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10518	\N	\N	\N
11099	PDTDEL	2004-10-01 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	Kenya	\N	10519	7	\N	\N
11101	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10521	\N	\N	\N
11102	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10522	\N	\N	\N
11103	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10523	\N	\N	\N
11104	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10524	\N	\N	\N
10414	PDT	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9985	1	\N	\N
10415	MEMBRE	2004-10-01 00:00:00	2009-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	9986	\N	\N	\N
10417	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9988	\N	\N	\N
10418	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9989	\N	\N	\N
10419	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9990	\N	\N	\N
10420	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9991	\N	\N	\N
10421	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9992	\N	\N	\N
10423	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9997	\N	\N	\N
10424	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9998	\N	\N	\N
10425	VICPDT	2004-10-01 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	9995	4	\N	\N
10426	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10000	\N	\N	\N
9141	MEMBRE	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8947	\N	\N	\N
9142	MEMBRE	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8948	\N	\N	\N
9143	MEMBRE	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8949	\N	\N	\N
9144	MEMBRE	2004-10-15 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	8950	\N	\N	\N
9145	MEMBRE	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8951	\N	\N	\N
9146	MEMBRE	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8952	\N	\N	\N
9147	MEMBRE	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8953	\N	\N	\N
9148	MEMBRE	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8954	\N	\N	\N
9150	MEMBRE	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8956	\N	\N	\N
9151	MEMBRE	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8957	\N	\N	\N
9152	SECRET	2004-10-15 00:00:00	2009-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	8958	11	\N	\N
9154	MEMBRE	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8960	\N	\N	\N
9155	VICPDT	2004-10-15 00:00:00	2009-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	8961	8	\N	\N
9157	SECRET	2004-10-15 00:00:00	2009-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	8962	13	\N	\N
9158	MEMBRE	2003-06-30 00:00:00	2009-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	8964	0	\N	\N
9161	MEMBRE	2003-06-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8967	\N	\N	\N
9162	MEMBRE	2003-06-30 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	8968	\N	\N	\N
9163	MEMBRE	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8969	\N	\N	\N
9164	MEMBRE	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8970	\N	\N	\N
9165	MEMBRE	2004-10-15 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	8971	\N	\N	\N
9166	MEMBRE	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8972	\N	\N	\N
9167	MEMBRE	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8973	\N	\N	\N
9168	SECRET	2004-10-15 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	8974	8	\N	\N
9169	MEMBRE	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8975	\N	\N	\N
9170	MEMBRE	2001-10-01 00:00:00	2004-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	5554	\N	\N	\N
9171	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8979	\N	\N	\N
9172	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8980	\N	\N	\N
9174	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8982	\N	\N	\N
9175	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8983	\N	\N	\N
9176	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8984	\N	\N	\N
9177	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8985	\N	\N	\N
9178	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8986	\N	\N	\N
9179	MEMBRE	2003-06-30 00:00:00	2004-11-09 00:00:00	ANCIEN	\N	\N	\N	\N	8987	\N	\N	\N
9180	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8988	\N	\N	\N
9182	MEMBRE	2003-06-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8990	\N	\N	\N
9183	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8991	\N	\N	\N
9781	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9505	\N	\N	\N
9782	SECRET	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9506	9	\N	\N
9786	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9510	\N	\N	\N
9787	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9511	\N	\N	\N
9789	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9513	\N	\N	\N
9790	MEMBRE	2004-10-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	9515	0	\N	\N
9791	MEMBRE	2004-10-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	9516	0	\N	\N
9793	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9518	\N	\N	\N
9794	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9519	\N	\N	\N
9795	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9520	\N	\N	\N
9796	MEMBRE	2004-10-01 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	\N	9521	\N	\N	\N
9797	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9522	\N	\N	\N
9798	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9523	\N	\N	\N
9799	PDTDEL	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	Rwanda	\N	9524	12	\N	\N
9801	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9526	\N	\N	\N
9802	MEMBRE	2004-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9528	\N	\N	\N
9803	MEMBRE	2004-10-01 00:00:00	2009-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	9529	\N	\N	\N
9804	MEMBRE	2004-10-01 00:00:00	2004-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	9530	\N	\N	\N
9805	VICPDT	2004-10-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9530	\N	\N	\N
9806	MEMBRE	2004-12-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7464	\N	\N	\N
9807	MEMBRE	2004-10-01 00:00:00	2007-04-03 00:00:00	ANCIEN	\N	\N	\N	\N	9531	\N	\N	\N
9808	MEMBRE	2004-10-01 00:00:00	2007-04-03 00:00:00	ANCIEN	\N	\N	\N	\N	9532	\N	\N	\N
9809	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9533	\N	\N	\N
9811	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9535	\N	\N	\N
9812	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9536	\N	\N	\N
9813	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9537	\N	\N	\N
9814	MEMBRE	2004-10-01 00:00:00	2005-03-19 00:00:00	ANCIEN	\N	\N	\N	\N	9538	\N	\N	\N
9815	MEMBRE	2004-10-01 00:00:00	2007-04-03 00:00:00	ANCIEN	\N	\N	\N	\N	9539	\N	\N	\N
9817	MEMBRE	2004-10-01 00:00:00	2009-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	9541	\N	\N	\N
9818	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9542	\N	\N	\N
9820	MEMBRE	2004-10-01 00:00:00	2005-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	9544	\N	\N	\N
9821	PDT	2004-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8296	\N	\N	\N
9823	VICPDT	2004-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8298	\N	\N	\N
9824	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9545	\N	\N	\N
9827	TRESOR	2004-12-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	312	5	\N	\N
9826	PDT	2004-12-15 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	5554	1	\N	\N
9830	VICPDT	2004-11-17 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	2956	3	\N	\N
9831	SECRET	2004-11-17 00:00:00	2009-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	5182	8	\N	\N
9832	SECRET	2004-11-17 00:00:00	2009-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	2952	9	\N	\N
9833	MEMBRE	2004-11-17 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	5188	\N	\N	\N
9835	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9548	\N	\N	\N
9843	PDT	2004-11-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5826	1	\N	\N
9844	VICPDT	2004-11-24 00:00:00	2009-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	5817	\N	\N	\N
9845	VICPDT	2004-11-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5820	3	\N	\N
9846	VICPDT	2004-11-24 00:00:00	2009-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	2453	\N	\N	\N
9848	VICPDT	2004-11-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1646	8	\N	\N
9850	MEMBRE	2004-11-24 00:00:00	2009-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	2090	\N	\N	\N
9851	MEMBRE	2004-11-24 00:00:00	2009-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	5825	\N	\N	\N
9852	MEMBRE	2004-11-24 00:00:00	2009-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	5818	\N	\N	\N
9854	SECRET	2004-11-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1662	9	\N	\N
9855	MEMBRE	2004-11-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5917	\N	\N	\N
9856	MEMBRE	2004-11-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5919	\N	\N	\N
9857	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9556	\N	\N	\N
9858	MEMBRE	2004-10-01 00:00:00	2004-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	9557	\N	\N	\N
9859	SECRET	2004-10-01 00:00:00	2008-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	9558	6	\N	\N
9860	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9559	\N	\N	\N
9861	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9560	\N	\N	\N
9862	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9561	\N	\N	\N
9384	VICPDT	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9156	3	\N	\N
9385	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9157	\N	\N	\N
9386	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9158	\N	\N	\N
9387	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9159	\N	\N	\N
9388	MEMBRE	2004-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	9160	\N	\N	\N
9390	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9162	\N	\N	\N
9392	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9164	\N	\N	\N
9393	MEMBRE	2004-10-01 00:00:00	2009-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	9166	0	\N	\N
9395	SECRET	2004-10-01 00:00:00	2009-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	9168	10	\N	\N
9396	MEMBREBUR	2004-10-01 00:00:00	2009-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	9169	16	\N	\N
9397	MEMBRE	2004-10-01 00:00:00	2009-09-09 00:00:00	ANCIEN	\N	\N	\N	\N	9170	\N	\N	\N
9398	VICPDT	2004-10-01 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	\N	9171	8	\N	\N
9399	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9172	\N	\N	\N
9401	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9175	\N	\N	\N
9402	MEMBRE	2004-10-01 00:00:00	2010-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	9174	\N	\N	\N
9403	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9176	\N	\N	\N
9404	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9177	\N	\N	\N
9406	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9179	\N	\N	\N
9407	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9180	\N	\N	\N
9408	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9181	\N	\N	\N
9409	MEMBRE	2004-10-01 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	9182	\N	\N	\N
9410	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9183	\N	\N	\N
9411	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9184	\N	\N	\N
9412	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9185	\N	\N	\N
9413	MEMBRE	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	9186	\N	\N	\N
9414	VICPDT	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9187	14	\N	\N
9415	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9188	\N	\N	\N
9416	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9189	\N	\N	\N
9417	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9190	\N	\N	\N
9418	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9191	\N	\N	\N
9419	MEMBRE	2004-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	9192	\N	\N	\N
9420	VICPDT	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9193	2	\N	\N
9421	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9194	\N	\N	\N
9422	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9195	\N	\N	\N
9423	VICPDT	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9196	3	\N	\N
9424	VICPDT	2004-10-01 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	9197	18	\N	\N
9425	VICPDT	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9198	17	\N	\N
9427	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9200	\N	\N	\N
9428	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9201	\N	\N	\N
9430	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9203	\N	\N	\N
9431	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9204	\N	\N	\N
9432	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9205	\N	\N	\N
9433	MEMBRE	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	9206	\N	\N	\N
9434	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9207	\N	\N	\N
9435	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9208	\N	\N	\N
9436	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9209	\N	\N	\N
9437	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9210	\N	\N	\N
9438	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9211	\N	\N	\N
9439	MEMBRE	2004-10-01 00:00:00	2005-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	9212	\N	\N	\N
9440	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9213	\N	\N	\N
9443	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9216	\N	\N	\N
9444	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9217	\N	\N	\N
10092	SECRET	2004-10-01 00:00:00	2009-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	9713	17	\N	\N
10093	VICPDT	2004-10-01 00:00:00	2009-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	9714	9	\N	\N
10095	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9716	\N	\N	\N
10096	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9717	\N	\N	\N
10097	SECRET	2004-10-01 00:00:00	2009-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	9718	16	\N	\N
10098	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9719	\N	\N	\N
10099	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9720	\N	\N	\N
10101	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9722	\N	\N	\N
10102	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9723	\N	\N	\N
10103	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9724	\N	\N	\N
10104	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9725	\N	\N	\N
10105	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9726	\N	\N	\N
10106	SECRET	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9728	7	\N	\N
10108	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9730	\N	\N	\N
10109	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9731	\N	\N	\N
10110	VICPDT	2004-10-01 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	9732	4	\N	\N
10111	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9733	\N	\N	\N
10113	MEMBRE	2004-10-01 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	9735	0	\N	\N
10114	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9736	\N	\N	\N
10115	VICPDT	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9737	6	\N	\N
10116	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9738	\N	\N	\N
10117	MEMBRE	2004-10-01 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	9739	0	\N	\N
10119	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9741	\N	\N	\N
10120	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9742	\N	\N	\N
10122	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9745	\N	\N	\N
10123	MEMBRE	2004-10-01 00:00:00	2007-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9746	\N	\N	\N
10124	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9747	\N	\N	\N
10125	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9748	\N	\N	\N
10127	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9750	\N	\N	\N
10128	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9751	\N	\N	\N
10129	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9752	\N	\N	\N
10130	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9753	\N	\N	\N
10131	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9754	\N	\N	\N
10132	MEMBRE	2004-10-01 00:00:00	2009-09-09 00:00:00	ANCIEN	\N	\N	\N	\N	9755	\N	\N	\N
10133	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9756	\N	\N	\N
10135	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9758	\N	\N	\N
10136	VICPDT	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9760	3	\N	\N
10137	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9761	\N	\N	\N
10138	MEMBRE	2004-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	9762	\N	\N	\N
10139	TRESORADJ	2004-10-01 00:00:00	2009-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	9765	10	\N	\N
10140	MEMBRE	2004-10-01 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	\N	9766	\N	\N	\N
10141	PDTDEL	2004-10-01 00:00:00	2009-01-20 00:00:00	ANCIEN	\N	\N	Papouasie-Nouvelle-Guinée	\N	9767	3	\N	\N
10142	SECRET	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9768	14	\N	\N
10143	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9769	\N	\N	\N
10144	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9770	\N	\N	\N
10145	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9771	\N	\N	\N
10146	MEMBRE	2004-10-01 00:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	9773	\N	\N	\N
10148	MEMBREBUR	2004-10-01 00:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	9775	\N	\N	\N
10149	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9776	\N	\N	\N
10150	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9777	\N	\N	\N
10151	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9778	\N	\N	\N
10152	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9779	\N	\N	\N
10153	MEMBREBUR	2004-10-01 00:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	9780	\N	\N	\N
10154	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9781	\N	\N	\N
10155	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9782	\N	\N	\N
10156	MEMBRE	2004-10-01 00:00:00	2006-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	9783	\N	\N	\N
10157	VICPDT	2004-10-01 00:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	9784	\N	\N	\N
10158	MEMBREBUR	2004-10-01 00:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	9785	\N	\N	\N
10159	MEMBRE	2004-10-01 00:00:00	2006-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	9786	\N	\N	\N
10160	SECRET	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9788	12	\N	\N
10161	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9789	\N	\N	\N
10163	MEMBRE	2004-10-01 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	9791	\N	\N	\N
10165	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9793	\N	\N	\N
10166	MEMBRE	2004-10-01 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	9794	\N	\N	\N
10167	VICPDT	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9795	5	\N	\N
10168	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9796	\N	\N	\N
10169	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9797	\N	\N	\N
10171	MEMBRE	2004-10-01 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	\N	9799	\N	\N	\N
10172	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9800	\N	\N	\N
10174	SECRET	2004-10-01 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	9802	\N	\N	\N
10175	SECRET	2004-10-01 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	9803	\N	\N	\N
10177	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9805	\N	\N	\N
10178	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9807	\N	\N	\N
10179	VICPDT	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9808	2	\N	\N
10180	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9809	\N	\N	\N
10181	SECRET	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	9810	10	\N	\N
10182	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9811	\N	\N	\N
10183	MEMBRE	2004-10-01 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	9812	0	\N	\N
10184	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9813	\N	\N	\N
10185	SECRET	2004-10-01 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	9814	11	\N	\N
10186	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9815	\N	\N	\N
10187	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9816	\N	\N	\N
10188	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9817	\N	\N	\N
10189	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9818	\N	\N	\N
10190	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9819	\N	\N	\N
10191	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9820	\N	\N	\N
10192	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9821	\N	\N	\N
10193	VICPDT	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9822	7	\N	\N
10194	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9823	\N	\N	\N
10195	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9824	\N	\N	\N
10196	VICPDT	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9825	6	\N	\N
10198	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9827	\N	\N	\N
10199	MEMBRE	2004-10-01 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	9828	\N	\N	\N
10200	MEMBRE	2004-10-01 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	\N	9829	\N	\N	\N
10201	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9830	\N	\N	\N
10202	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9831	\N	\N	\N
10203	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9832	\N	\N	\N
10204	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9833	\N	\N	\N
10205	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9834	\N	\N	\N
10206	SECRET	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	9835	12	\N	\N
10207	SECRET	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9836	13	\N	\N
10208	MEMBRE	2004-10-01 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	9837	\N	\N	\N
10209	MEMBRE	2004-10-01 00:00:00	2010-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	9838	\N	\N	\N
10211	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9840	\N	\N	\N
10213	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9842	\N	\N	\N
10214	SECRET	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9843	11	\N	\N
10215	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9845	\N	\N	\N
10216	SECRET	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9846	12	\N	\N
10217	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9847	\N	\N	\N
10218	MEMBRE	2004-10-01 00:00:00	2007-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	9848	\N	\N	\N
10219	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9849	\N	\N	\N
10220	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9850	\N	\N	\N
10221	MEMBRE	2004-10-01 00:00:00	2007-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9851	\N	\N	\N
10222	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9852	\N	\N	\N
10223	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9853	\N	\N	\N
10224	MEMBRE	2004-10-01 00:00:00	2010-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	9854	\N	\N	\N
11868	MEMBRE	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11172	\N	\N	\N
11869	MEMBRE	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11173	\N	\N	\N
11870	MEMBRE	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11174	\N	\N	\N
11871	MEMBRE	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11175	\N	\N	\N
11872	MEMBRE	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11176	\N	\N	\N
11873	MEMBRE	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11177	\N	\N	\N
11874	MEMBRE	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11178	\N	\N	\N
11875	MEMBRE	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11179	\N	\N	\N
11877	MEMBRE	2006-11-28 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	11181	0	\N	\N
11878	MEMBRE	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11182	\N	\N	\N
11879	MEMBRE	2006-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11183	\N	\N	\N
11880	MEMBRE	2006-11-28 00:00:00	2010-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	11184	\N	\N	\N
11882	MEMBRE	2006-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11186	\N	\N	\N
11883	MEMBRE	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11187	\N	\N	\N
11884	MEMBRE	2006-11-28 00:00:00	2007-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	11188	\N	\N	\N
11885	MEMBRE	2006-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11189	\N	\N	\N
11886	MEMBRE	2006-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11190	\N	\N	\N
11887	MEMBRE	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11191	\N	\N	\N
11888	MEMBRE	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11192	\N	\N	\N
11891	MEMBRE	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11195	\N	\N	\N
11940	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11242	\N	\N	\N
11944	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11246	\N	\N	\N
12187	PDT	2007-09-26 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	10023	1	\N	\N
12188	VICPDT	2007-09-26 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	10018	4	\N	\N
12189	SECRET	2007-09-26 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	10021	6	\N	\N
12190	SECRET	2007-09-26 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5076	7	\N	\N
12191	MEMBREBUR	2007-09-26 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	887	8	\N	\N
12192	MEMBREBUR	2007-09-26 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	1895	9	\N	\N
12482	PDT	2008-12-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8626	1	\N	\N
12485	VICPDT	2008-12-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4740	6	\N	\N
12333	MEMBRE	2007-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11595	\N	\N	\N
12400	MEMBRE	2008-02-29 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11637	\N	\N	\N
12463	MEMBRE	2008-05-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11695	\N	\N	\N
12464	MEMBRE	2008-06-25 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11696	\N	\N	\N
12475	MEMBRE	2008-05-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11707	\N	\N	\N
12476	MEMBRE	2008-07-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11708	\N	\N	\N
12477	MEMBRE	2008-07-15 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	11709	\N	\N	\N
12478	MEMBRE	2008-07-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11710	\N	\N	\N
12479	MEMBRE	2008-07-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11711	\N	\N	\N
12483	PDTDEL	2008-12-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Laos	\N	882	2	\N	\N
12484	VICPDT	2008-12-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1393	5	\N	\N
12486	VICPDT	2008-12-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1425	7	\N	\N
12487	SECRET	2008-12-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8618	8	\N	\N
12491	PDT	2008-12-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2427	1	\N	\N
12492	PDT	2008-12-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4247	1	\N	\N
12493	PDT	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2054	1	\N	\N
12495	VICPDT	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11716	4	\N	\N
12496	VICPDT	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11717	5	\N	\N
12498	MEMBRE	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4646	0	\N	\N
12499	MEMBRE	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4643	0	\N	\N
12500	MEMBRE	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2753	0	\N	\N
12502	SECRET	2008-12-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11719	11	\N	\N
12503	SECRET	2008-12-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11720	12	\N	\N
12504	VICPDT	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6320	2	\N	\N
11770	MEMBRE	2006-06-23 00:00:00	2007-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	11093	\N	\N	\N
11774	MEMBRE	2006-07-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11097	\N	\N	\N
11775	MEMBRE	2006-09-12 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11098	\N	\N	\N
11776	MEMBRE	2006-09-12 00:00:00	2009-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	11099	\N	\N	\N
11892	MEMBRE	2006-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11196	\N	\N	\N
11893	MEMBRE	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11197	\N	\N	\N
11894	MEMBRE	2006-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11198	\N	\N	\N
11895	MEMBRE	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11199	\N	\N	\N
11896	MEMBRE	2006-11-28 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	11200	\N	\N	\N
11897	MEMBRE	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11201	\N	\N	\N
11898	MEMBRE	2006-11-28 00:00:00	2009-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	11202	\N	\N	\N
11899	MEMBRE	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11203	\N	\N	\N
11900	MEMBRE	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11204	\N	\N	\N
11901	MEMBRE	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11205	\N	\N	\N
11902	MEMBRE	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11206	\N	\N	\N
11903	MEMBRE	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11207	\N	\N	\N
11904	MEMBRE	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11208	\N	\N	\N
11905	MEMBRE	2006-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11209	\N	\N	\N
11906	MEMBRE	2006-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11210	\N	\N	\N
11907	MEMBRE	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11211	\N	\N	\N
11908	MEMBRE	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11212	\N	\N	\N
11946	MEMBRE	2007-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11248	\N	\N	\N
12171	MEMBRE	2007-07-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11453	\N	\N	\N
12172	MEMBRE	2007-07-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11454	\N	\N	\N
12173	MEMBRE	2007-07-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11455	\N	\N	\N
12212	MEMBRE	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11487	\N	\N	\N
12175	MEMBRE	2007-07-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11457	\N	\N	\N
12176	MEMBRE	2007-07-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11458	\N	\N	\N
12178	MEMBRE	2007-07-01 00:00:00	2009-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	11460	\N	\N	\N
12179	MEMBRE	2007-07-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11461	\N	\N	\N
12213	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11488	\N	\N	\N
12350	MEMBRE	2007-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11601	\N	\N	\N
12358	PDTDEL	2007-10-01 00:00:00	2008-12-10 00:00:00	ANCIEN	\N	\N	Cameroun	\N	2766	5	\N	\N
12369	MEMBRE	2008-02-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11616	\N	\N	\N
12430	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11666	\N	\N	\N
12390	MEMBRE	2008-02-12 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11636	\N	\N	\N
12459	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	604	\N	\N	\N
12460	PDT	2008-06-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8874	1	\N	\N
12461	SECRET	2008-06-03 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	8863	6	\N	\N
9228	TRESOR	2004-11-03 00:00:00	2009-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	8200	\N	\N	\N
9267	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9059	\N	\N	\N
9274	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9066	\N	\N	\N
9353	MEMBRE	2004-10-01 00:00:00	2007-10-23 00:00:00	ANCIEN	\N	\N	\N	\N	9119	\N	\N	\N
9360	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9130	\N	\N	\N
9391	SECRET	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9163	7	\N	\N
9400	MEMBRE	2004-10-01 00:00:00	2009-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	9173	0	\N	\N
9442	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9215	\N	\N	\N
10170	SECRET	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9798	8	\N	\N
10248	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5103	\N	\N	\N
10282	MEMBRE	2004-12-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	9901	\N	\N	\N
10287	MEMBREBUR	2005-01-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9897	\N	\N	\N
10367	MEMBRE	2004-12-14 00:00:00	2004-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	9944	\N	\N	\N
10374	MEMBRE	2004-12-14 00:00:00	2004-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	9951	\N	\N	\N
10407	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9978	\N	\N	\N
10413	MEMBRE	2004-10-01 00:00:00	2007-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9984	\N	\N	\N
10422	MEMBRE	2004-10-01 00:00:00	2004-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	9996	\N	\N	\N
9816	MEMBRE	2004-10-01 00:00:00	2009-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	9540	\N	\N	\N
9822	SECRET	2004-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8303	\N	\N	\N
9829	PDT	2004-11-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5186	1	\N	\N
11797	MEMBRE	2006-09-21 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	11113	0	\N	\N
11798	MEMBRE	2006-09-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11114	\N	\N	\N
11914	MEMBRE	2006-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11218	\N	\N	\N
11922	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11224	\N	\N	\N
11923	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11225	\N	\N	\N
11930	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11232	\N	\N	\N
11931	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11233	\N	\N	\N
11932	MEMBRE	2006-04-13 00:00:00	2008-04-18 00:00:00	ANCIEN	\N	\N	\N	\N	11234	\N	\N	\N
12039	MEMBRE	2007-02-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11335	\N	\N	\N
12047	MEMBRE	2007-04-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11343	\N	\N	\N
12196	MEMBRE	2007-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11471	\N	\N	\N
12197	MEMBRE	2007-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11472	\N	\N	\N
12198	MEMBRE	2007-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11473	\N	\N	\N
12199	MEMBRE	2007-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11474	\N	\N	\N
12200	MEMBRE	2007-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11475	\N	\N	\N
12201	MEMBRE	2007-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11476	\N	\N	\N
12203	MEMBRE	2007-09-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	11478	\N	\N	\N
12204	MEMBRE	2007-09-01 00:00:00	2007-10-30 00:00:00	ANCIEN	\N	\N	\N	\N	11479	\N	\N	\N
12218	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11493	\N	\N	\N
12220	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11495	\N	\N	\N
12221	MEMBRE	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11496	\N	\N	\N
12232	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11507	\N	\N	\N
12233	MEMBRE	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11508	\N	\N	\N
12234	MEMBRE	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11509	\N	\N	\N
12238	MEMBRE	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11513	\N	\N	\N
12239	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11514	\N	\N	\N
12240	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11515	\N	\N	\N
12241	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11516	\N	\N	\N
12242	MEMBRE	2006-09-01 00:00:00	2007-11-13 00:00:00	ANCIEN	\N	\N	\N	\N	11517	\N	\N	\N
12243	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11518	\N	\N	\N
12245	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11520	\N	\N	\N
12261	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11536	\N	\N	\N
12273	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11548	\N	\N	\N
12276	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11551	\N	\N	\N
12277	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11552	\N	\N	\N
12278	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11553	\N	\N	\N
12279	MEMBRE	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11554	\N	\N	\N
12292	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11567	\N	\N	\N
12293	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11568	\N	\N	\N
12295	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11570	\N	\N	\N
12296	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11571	\N	\N	\N
12298	MEMBRE	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11573	\N	\N	\N
12299	MEMBRE	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11574	\N	\N	\N
12300	MEMBRE	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11575	\N	\N	\N
12301	MEMBRE	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11576	\N	\N	\N
12302	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11577	\N	\N	\N
12303	MEMBRE	2006-09-01 00:00:00	2009-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	11578	\N	\N	\N
12304	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11579	\N	\N	\N
12305	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11580	\N	\N	\N
12306	MEMBRE	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11581	\N	\N	\N
12307	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11582	\N	\N	\N
12308	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11583	\N	\N	\N
12310	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11585	\N	\N	\N
12311	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11586	\N	\N	\N
12312	VICPDT	2007-10-31 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	11479	5	\N	\N
12326	SECRET	2007-11-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11503	\N	\N	\N
12327	SECRET	2007-11-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11517	\N	\N	\N
12328	PDT	2007-11-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1527	1	\N	\N
12401	MEMBRE	2008-02-01 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	11638	0	\N	\N
12371	MEMBRE	2005-02-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11618	\N	\N	\N
12402	MEMBRE	2008-02-01 00:00:00	2010-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	11639	\N	\N	2015-11-12 15:26:22
11740	MEMBRE	2006-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11069	\N	\N	\N
9875	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9576	\N	\N	\N
9914	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9609	\N	\N	\N
9921	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9618	\N	\N	\N
9965	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9663	\N	\N	\N
10011	VICPDT	2004-11-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4580	22	\N	\N
10045	SECRET	2004-12-08 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	5096	12	\N	\N
11924	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11226	\N	\N	\N
11925	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11227	\N	\N	\N
11926	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11228	\N	\N	\N
11976	SECRET	2007-02-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11279	9	\N	\N
8289	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8219	\N	\N	\N
11773	MEMBRE	2006-06-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11096	\N	\N	\N
11787	MEMBRE	0206-09-21 00:00:00	2008-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	11101	\N	\N	\N
11788	MEMBRE	2006-09-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11103	\N	\N	\N
11790	MEMBRE	2006-09-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11105	0	\N	\N
11799	MEMBRE	2006-10-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11115	\N	\N	\N
11800	MEMBRE	2006-10-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11116	\N	\N	\N
11802	MEMBRE	2006-10-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11118	\N	\N	\N
12018	MEMBRE	2006-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11320	\N	\N	\N
12019	MEMBRE	2006-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11321	\N	\N	\N
12020	MEMBRE	2006-10-01 00:00:00	2007-03-07 00:00:00	ANCIEN	\N	\N	\N	\N	11322	\N	\N	\N
12021	MEMBRE	2006-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11323	\N	\N	\N
12022	MEMBRE	2006-10-01 00:00:00	2007-03-07 00:00:00	ANCIEN	\N	\N	\N	\N	11324	\N	\N	\N
12023	MEMBRE	2006-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	11325	\N	\N	\N
12024	MEMBRE	2006-10-01 00:00:00	2007-03-07 00:00:00	ANCIEN	\N	\N	\N	\N	11326	\N	\N	\N
12025	MEMBRE	2006-10-01 00:00:00	2007-03-07 00:00:00	ANCIEN	\N	\N	\N	\N	11327	\N	\N	\N
12026	MEMBRE	2006-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11328	\N	\N	\N
12027	MEMBRE	2006-10-01 00:00:00	2007-03-07 00:00:00	ANCIEN	\N	\N	\N	\N	11329	\N	\N	\N
12028	MEMBRE	2006-10-01 00:00:00	2007-03-07 00:00:00	ANCIEN	\N	\N	\N	\N	11330	\N	\N	\N
12029	PDT	2007-03-08 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	11326	\N	\N	\N
12030	VICPDT	2007-03-08 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11324	\N	\N	\N
12031	VICPDT	2007-03-08 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11327	\N	\N	\N
12032	VICPDT	2007-03-08 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	11329	\N	\N	\N
12034	SECRET	2007-03-08 00:00:00	2009-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11322	\N	\N	\N
12165	MEMBRE	2007-07-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11448	\N	\N	\N
12223	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11498	\N	\N	\N
12224	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11499	\N	\N	\N
12247	MEMBRE	2006-09-01 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	11522	\N	\N	\N
12248	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11523	\N	\N	\N
12249	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11524	\N	\N	\N
12250	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11525	\N	\N	\N
11726	MEMBRE	2006-06-23 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11055	\N	\N	\N
12376	MEMBRE	2008-02-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11623	\N	\N	\N
12378	MEMBRE	2008-02-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11624	\N	\N	\N
8294	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8224	\N	\N	\N
12384	MEMBRE	2008-02-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11630	\N	\N	\N
8319	VICPDT	2001-10-01 00:00:00	2010-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	8117	\N	\N	\N
8325	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8252	\N	\N	\N
8330	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8256	\N	\N	\N
8338	MEMBRE	2001-10-01 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	8263	\N	\N	\N
8369	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8271	\N	\N	\N
8376	MEMBRE	2001-10-01 00:00:00	2006-08-11 00:00:00	ANCIEN	\N	\N	\N	\N	8276	\N	\N	\N
8384	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8284	\N	\N	\N
8406	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8302	\N	\N	\N
8414	MEMBRE	2001-10-01 00:00:00	2003-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	8309	\N	\N	\N
8421	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8315	\N	\N	\N
8427	SECRET	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8158	\N	\N	\N
8466	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8344	\N	\N	\N
7793	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7798	\N	\N	\N
7799	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7804	\N	\N	\N
7807	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7812	\N	\N	\N
7816	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7821	\N	\N	\N
7876	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7869	\N	\N	\N
7882	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7875	\N	\N	\N
7918	MEMBRE	2001-10-01 00:00:00	2005-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	7911	\N	\N	\N
7926	VICPDT	2001-12-19 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7905	\N	\N	\N
7935	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7920	\N	\N	\N
7975	PDT	2001-10-03 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	7954	\N	\N	\N
11909	MEMBRE	2006-12-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11213	\N	\N	\N
11910	MEMBRE	2006-12-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11214	\N	\N	\N
11918	MEMBRE	2006-12-29 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11221	\N	\N	\N
11928	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11230	\N	\N	\N
11936	MEMBRE	2004-10-01 00:00:00	2010-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	11238	\N	\N	\N
12161	PDT	2007-07-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5760	1	\N	\N
12205	MEMBRE	2007-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11480	\N	\N	\N
12206	MEMBRE	2007-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11481	\N	\N	\N
12207	MEMBRE	2007-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11482	\N	\N	\N
12208	MEMBRE	2005-10-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11483	\N	\N	\N
12364	MEMBRE	2008-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11608	\N	\N	\N
12365	MEMBRE	2004-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10729	\N	\N	\N
2826	PDTDEL	1999-01-01 00:00:00	2002-07-30 00:00:00	ANCIEN	\N	\N	Canada	\N	2856	2	\N	\N
7985	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7964	\N	\N	\N
8989	MEMBRE	2004-10-01 00:00:00	2005-03-30 00:00:00	ANCIEN	\N	\N	\N	\N	8790	\N	\N	\N
8999	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8800	\N	\N	\N
9004	MEMBRE	2004-11-03 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	8805	\N	\N	\N
9034	MEMBRE	2004-10-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8836	\N	\N	\N
9041	MEMBRE	2004-10-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8843	\N	\N	\N
9081	MEMBREBUR	2004-10-15 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	8887	11	\N	\N
9089	MEMBRE	2003-06-30 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8896	\N	\N	\N
9097	MEMBRE	2004-10-15 00:00:00	2007-02-25 00:00:00	ANCIEN	\N	\N	\N	\N	8904	\N	\N	\N
9139	MEMBRE	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8945	\N	\N	\N
8513	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8391	\N	\N	\N
8521	MEMBRE	2003-06-30 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8399	\N	\N	\N
12088	PDTHON	2007-06-27 00:00:00	2009-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	1965	2	\N	\N
12089	PDT	2007-06-26 00:00:00	2009-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	10797	1	\N	\N
12090	VICPDT	2007-06-06 00:00:00	2009-03-12 00:00:00	ANCIEN	\N	\N	\N	\N	11333	12	\N	2015-11-12 15:26:22
12092	VICPDT	2007-06-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9137	8	\N	\N
12093	VICPDT	2007-06-06 00:00:00	2009-03-09 00:00:00	ANCIEN	\N	\N	\N	\N	5314	10	\N	\N
12331	VICPDT	2007-11-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10698	\N	\N	\N
12414	MEMBRE	2008-02-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11651	\N	\N	\N
8013	VICPDT	2001-12-05 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	7819	\N	\N	\N
8021	MEMBREBUR	2001-12-05 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7835	\N	\N	\N
8029	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3174	\N	\N	\N
8069	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8011	\N	\N	\N
8081	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8023	\N	\N	\N
8806	MEMBRE	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8646	\N	\N	\N
8840	VICPDT	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8675	9	\N	\N
8847	MEMBRE	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8681	\N	\N	\N
3111	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3154	\N	\N	\N
1962	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1962	\N	\N	\N
2187	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2187	\N	\N	\N
1242	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1242	\N	\N	\N
1138	PDT	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1138	1	\N	\N
1022	MEMBRE	1998-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	1022	\N	\N	\N
1075	SECRET	1998-10-01 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	1075	11	\N	\N
1524	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1524	\N	\N	\N
1304	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1304	\N	\N	\N
241	MEMBRE	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	241	\N	\N	\N
3521	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3591	\N	\N	\N
12162	MEMBRE	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11445	\N	\N	\N
12387	MEMBRE	2008-02-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11633	\N	\N	\N
12420	MEMBRE	2008-03-31 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11656	\N	\N	\N
12417	MEMBRE	2008-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11653	\N	\N	\N
14952	MEMBRE	2008-10-01 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	13371	\N	\N	\N
14953	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13372	\N	\N	\N
14954	MEMBRE	2008-10-01 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	13373	\N	\N	\N
3177	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3227	\N	\N	\N
3230	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3286	\N	\N	\N
2440	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2440	\N	\N	\N
2228	SECRET	1998-10-01 00:00:00	2009-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	2228	17	\N	\N
1789	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1789	\N	\N	\N
1554	MEMBREBUR	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1554	7	\N	\N
3920	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3962	\N	\N	\N
1178	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1178	\N	\N	\N
4093	VICPDT	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4140	6	\N	\N
685	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	685	\N	\N	\N
481	MEMBRE	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	481	\N	\N	\N
3401	MEMBRE	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3465	\N	\N	\N
4607	MEMBRE	2001-10-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	4714	\N	\N	\N
4698	MEMBREBUR	2001-10-01 00:00:00	2004-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	4817	28	\N	\N
4407	MEMBRE	2000-12-19 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4515	\N	\N	\N
8856	MEMBRE	2004-10-15 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	8690	\N	\N	\N
8887	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8721	\N	\N	\N
8895	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8729	\N	\N	\N
8901	VICPDT	2004-10-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7498	\N	\N	\N
8929	VICPDT	2004-11-02 00:00:00	2010-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	8743	\N	\N	\N
8935	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8753	\N	\N	\N
8941	MEMBRE	2004-10-01 00:00:00	2004-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	8759	\N	\N	\N
8948	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8766	\N	\N	\N
8972	SECRET	2004-11-02 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7312	\N	\N	\N
8992	MEMBRE	2004-10-01 00:00:00	2005-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	8793	\N	\N	\N
11805	MEMBRE	2006-11-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11121	\N	\N	\N
11854	VICPDT	2006-11-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11143	\N	\N	\N
11809	MEMBRE	2006-11-15 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	11125	\N	\N	\N
11933	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11235	\N	\N	\N
11811	MEMBRE	2006-11-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11127	\N	\N	\N
11812	MEMBRE	2006-11-15 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	11128	\N	\N	\N
12035	MEMBRE	2007-02-14 00:00:00	2009-03-04 00:00:00	ANCIEN	\N	\N	\N	\N	11331	\N	\N	2015-11-12 15:26:22
11815	MEMBRE	2006-11-15 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	11131	\N	\N	\N
11817	MEMBRE	2006-11-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11133	\N	\N	\N
11818	MEMBRE	2006-11-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11134	\N	\N	\N
11819	MEMBRE	2006-11-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11135	\N	\N	\N
11820	MEMBRE	2006-11-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11136	\N	\N	\N
12037	MEMBRE	2007-02-14 00:00:00	2007-06-08 00:00:00	ANCIEN	\N	\N	\N	\N	11333	0	\N	2015-11-12 15:26:22
11825	MEMBRE	2006-11-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11141	\N	\N	\N
12038	MEMBRE	2007-02-14 00:00:00	2011-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	11334	\N	\N	2015-11-12 15:26:22
11828	MEMBRE	2006-11-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11144	\N	\N	\N
11829	MEMBRE	2006-11-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11145	\N	\N	\N
12070	MEMBRE	2007-04-22 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11360	\N	\N	\N
11831	MEMBRE	2006-11-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11147	\N	\N	\N
11832	MEMBRE	2006-11-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11148	\N	\N	\N
12071	MEMBRE	2007-04-22 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11361	\N	\N	\N
11834	MEMBRE	2006-11-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11150	\N	\N	\N
11836	MEMBRE	2006-11-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11152	\N	\N	\N
11838	MEMBRE	2006-11-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11154	\N	\N	\N
11839	MEMBRE	2006-11-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11155	\N	\N	\N
11841	MEMBRE	2006-11-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11157	\N	\N	\N
11842	MEMBRE	2006-11-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11158	\N	\N	\N
11843	PDT	2006-11-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11138	\N	\N	\N
11845	VICPDT	2006-11-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11126	\N	\N	\N
11846	VICPDT	2006-11-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11130	\N	\N	\N
11852	MEMBREBUR	2006-11-15 00:00:00	2008-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	11146	\N	\N	\N
11853	MEMBREBUR	2006-11-15 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	11149	\N	\N	\N
12072	MEMBRE	2007-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11362	\N	\N	\N
12074	MEMBRE	2007-04-22 00:00:00	2007-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11364	\N	\N	\N
12075	MEMBRE	2007-04-22 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11365	\N	\N	\N
12096	MEMBRE	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11380	\N	\N	\N
12097	MEMBRE	2007-06-01 00:00:00	2007-10-23 00:00:00	ANCIEN	\N	\N	\N	\N	11381	\N	\N	\N
12098	MEMBRE	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11382	\N	\N	\N
12099	MEMBRE	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11383	\N	\N	\N
12100	MEMBRE	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11384	\N	\N	\N
12101	MEMBRE	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11385	\N	\N	\N
12102	MEMBRE	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11386	\N	\N	\N
12103	MEMBRE	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11387	\N	\N	\N
12104	MEMBRE	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11388	\N	\N	\N
12105	MEMBRE	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11389	\N	\N	\N
12106	MEMBRE	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11390	\N	\N	\N
12107	MEMBRE	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11391	\N	\N	\N
12108	MEMBRE	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11392	\N	\N	\N
12109	MEMBRE	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11393	\N	\N	\N
12110	MEMBRE	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11394	\N	\N	\N
12111	MEMBRE	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11395	\N	\N	\N
12112	MEMBRE	2007-06-01 00:00:00	2007-10-23 00:00:00	ANCIEN	\N	\N	\N	\N	11396	\N	\N	\N
12113	MEMBRE	2007-06-01 00:00:00	2007-10-23 00:00:00	ANCIEN	\N	\N	\N	\N	11397	\N	\N	\N
12114	MEMBRE	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11398	\N	\N	\N
12115	MEMBRE	2007-06-01 00:00:00	2007-10-23 00:00:00	ANCIEN	\N	\N	\N	\N	11399	\N	\N	\N
12116	MEMBRE	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11400	\N	\N	\N
12118	MEMBRE	2007-06-01 00:00:00	2007-10-23 00:00:00	ANCIEN	\N	\N	\N	\N	11402	\N	\N	\N
12119	MEMBRE	2007-06-01 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	11403	0	\N	\N
12121	MEMBRE	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11405	\N	\N	\N
12122	MEMBRE	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11406	\N	\N	\N
12123	MEMBRE	2007-06-01 00:00:00	2007-10-23 00:00:00	ANCIEN	\N	\N	\N	\N	11407	\N	\N	\N
12124	MEMBRE	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11408	\N	\N	\N
12125	MEMBRE	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11409	\N	\N	\N
12126	MEMBRE	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11410	\N	\N	\N
12128	MEMBRE	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11412	\N	\N	\N
12129	MEMBRE	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11413	\N	\N	\N
12130	MEMBRE	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11414	\N	\N	\N
12131	MEMBRE	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11415	\N	\N	\N
12132	MEMBRE	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11416	\N	\N	\N
11808	MEMBRE	2006-11-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11124	\N	\N	\N
11840	MEMBRE	2006-11-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11156	\N	\N	\N
11938	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11240	\N	\N	\N
11939	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11241	\N	\N	\N
11942	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11244	\N	\N	\N
11943	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11245	\N	\N	\N
12134	MEMBRE	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11418	\N	\N	\N
12135	MEMBRE	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11419	\N	\N	\N
12136	MEMBRE	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11420	\N	\N	\N
11615	MEMBRE	2006-02-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10949	\N	\N	\N
11617	MEMBRE	2006-02-02 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10951	\N	\N	\N
11618	MEMBRE	2006-02-07 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10952	\N	\N	\N
11619	MEMBRE	2006-02-07 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10953	\N	\N	\N
11620	MEMBRE	2006-02-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10954	\N	\N	\N
11623	MEMBRE	2006-02-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10957	\N	\N	\N
11624	MEMBRE	2006-02-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4488	\N	\N	\N
11625	PDT	2006-02-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9786	1	\N	\N
11626	TRESOR	2006-02-08 00:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	4485	\N	\N	\N
11627	SECRET	2006-02-07 00:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	9783	\N	\N	\N
11628	MEMBRE	2006-03-10 00:00:00	2009-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	10958	\N	\N	\N
11629	MEMBRE	2006-03-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10959	\N	\N	\N
18643	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16846	\N	\N	2014-09-28 16:59:41
11631	MEMBRE	2006-01-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10961	\N	\N	\N
11633	MEMBRE	2006-03-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10963	\N	\N	\N
18644	MEMBRE	2011-10-01 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	16847	\N	\N	\N
11635	MEMBRE	2006-03-14 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	10965	\N	\N	\N
11637	MEMBRE	2006-01-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10967	\N	\N	\N
11638	MEMBRE	2006-03-12 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10968	\N	\N	\N
11639	MEMBRE	2006-03-12 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10969	\N	\N	\N
11640	MEMBRE	2006-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10970	\N	\N	\N
11641	MEMBRE	2006-03-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10971	\N	\N	\N
11642	MEMBRE	2006-03-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10972	\N	\N	\N
18702	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16905	\N	\N	2014-09-28 17:27:35
11645	MEMBRE	2006-03-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10975	\N	\N	\N
11646	MEMBRE	2006-03-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10976	\N	\N	\N
11647	MEMBRE	2006-03-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10977	\N	\N	\N
11648	MEMBRE	2006-03-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10978	\N	\N	\N
11650	MEMBRE	2006-03-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10980	\N	\N	\N
11651	MEMBRE	2006-03-16 00:00:00	2009-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	10981	\N	\N	\N
11652	MEMBRE	2006-03-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10982	\N	\N	\N
11655	MEMBRE	2006-03-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10985	\N	\N	\N
11656	MEMBRE	2006-03-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10986	\N	\N	\N
11657	MEMBRE	2006-03-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10987	\N	\N	\N
11660	MEMBRE	2006-03-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10990	\N	\N	\N
11663	MEMBRE	2006-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10991	\N	\N	\N
11662	MEMBRE	2005-03-07 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	2522	0	\N	\N
11664	MEMBRE	2006-03-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10992	\N	\N	\N
11666	MEMBRE	2006-03-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10994	\N	\N	\N
11667	MEMBRE	2006-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10995	\N	\N	\N
11668	MEMBRE	2006-03-01 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	10996	\N	\N	\N
11669	PDTDEL	2006-03-01 00:00:00	2009-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	10997	13	\N	\N
11670	MEMBRE	2006-03-01 00:00:00	2008-04-18 00:00:00	ANCIEN	\N	\N	\N	\N	11000	\N	\N	\N
11671	MEMBRE	2006-03-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11001	\N	\N	\N
11674	MEMBRE	2004-11-02 00:00:00	2004-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	7819	\N	\N	\N
11673	MEMBRE	2006-03-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11003	\N	\N	\N
11675	MEMBRE	2006-04-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8533	\N	\N	\N
11676	MEMBRE	2006-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11005	\N	\N	\N
11677	MEMBRE	2006-03-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11006	\N	\N	\N
11678	MEMBRE	2006-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11007	\N	\N	\N
11680	MEMBRE	2006-03-01 00:00:00	2009-09-09 00:00:00	ANCIEN	\N	\N	\N	\N	11009	\N	\N	\N
11681	MEMBRE	2006-03-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11010	\N	\N	\N
11682	MEMBRE	2006-03-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11011	\N	\N	\N
11683	MEMBRE	2006-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11012	\N	\N	\N
11684	MEMBRE	2006-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11013	\N	\N	\N
11685	MEMBRE	2006-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11014	\N	\N	\N
11686	MEMBRE	2006-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11015	\N	\N	\N
11687	MEMBRE	2006-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11016	\N	\N	\N
11688	MEMBRE	2006-04-13 00:00:00	2008-04-18 00:00:00	ANCIEN	\N	\N	\N	\N	11017	\N	\N	\N
11689	MEMBRE	2006-04-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11018	\N	\N	\N
11691	MEMBRE	2006-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11020	\N	\N	\N
11694	MEMBRE	2006-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11023	\N	\N	\N
11695	MEMBRE	2006-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11024	\N	\N	\N
11696	MEMBRE	2006-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11025	\N	\N	\N
11697	MEMBRE	2006-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11026	\N	\N	\N
11698	MEMBRE	2006-06-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11027	\N	\N	\N
11700	MEMBRE	2006-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11029	\N	\N	\N
11702	MEMBRE	2006-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11031	\N	\N	\N
11703	MEMBRE	2006-06-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11032	\N	\N	\N
11704	MEMBRE	2006-06-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11033	\N	\N	\N
11705	MEMBRE	2006-06-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11034	\N	\N	\N
11707	MEMBRE	2006-06-23 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	11036	\N	\N	\N
11709	MEMBRE	2006-06-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11038	\N	\N	\N
11711	MEMBRE	2006-06-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11040	\N	\N	\N
11712	MEMBRE	2006-06-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11041	\N	\N	\N
11713	MEMBRE	2006-06-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11042	\N	\N	\N
11714	MEMBRE	2006-06-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11043	\N	\N	\N
11716	MEMBRE	2006-06-23 00:00:00	2009-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	11045	\N	\N	\N
11717	MEMBRE	2006-06-23 00:00:00	2007-06-24 00:00:00	ANCIEN	\N	\N	\N	\N	11046	\N	\N	\N
11719	MEMBRE	2006-06-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11048	\N	\N	\N
11720	MEMBRE	2006-06-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11049	\N	\N	\N
11721	MEMBRE	2006-06-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11050	\N	\N	\N
11722	MEMBRE	2006-06-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11051	\N	\N	\N
11723	MEMBRE	2006-06-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11052	\N	\N	\N
11725	MEMBRE	2006-06-23 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11054	\N	\N	\N
11727	MEMBRE	2006-06-23 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11056	\N	\N	\N
11728	MEMBRE	2006-06-23 00:00:00	2007-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	11057	\N	\N	\N
11729	MEMBRE	2006-06-23 00:00:00	2007-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	11058	\N	\N	\N
11730	MEMBRE	2006-06-23 00:00:00	2009-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	11059	\N	\N	\N
11731	MEMBRE	2006-06-23 00:00:00	2007-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	11060	\N	\N	\N
11733	MEMBRE	2006-06-23 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11062	\N	\N	\N
11734	MEMBRE	2006-06-23 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11063	\N	\N	\N
11735	MEMBRE	2006-06-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11064	\N	\N	\N
11736	MEMBRE	2006-06-23 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11065	\N	\N	\N
11737	MEMBRE	2006-06-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11066	\N	\N	\N
11738	MEMBRE	2006-06-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11067	\N	\N	\N
11741	MEMBRE	2006-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11070	\N	\N	\N
11743	MEMBRE	2006-07-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11072	\N	\N	\N
11744	MEMBRE	2006-07-08 00:00:00	2006-07-10 00:00:00	ANCIEN	\N	\N	\N	\N	11073	\N	\N	\N
11745	MEMBRE	2006-07-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11074	\N	\N	\N
11746	MEMBRE	2006-07-08 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11075	\N	\N	\N
11747	MEMBRE	2006-07-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11076	\N	\N	\N
11748	MEMBRE	2006-07-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11077	\N	\N	\N
11750	MEMBRE	2006-07-08 00:00:00	2006-07-10 00:00:00	ANCIEN	\N	\N	\N	\N	11079	\N	\N	\N
11751	MEMBRE	2006-07-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11080	\N	\N	\N
11752	MEMBRE	2006-07-08 00:00:00	2006-07-10 00:00:00	ANCIEN	\N	\N	\N	\N	11081	\N	\N	\N
11753	MEMBRE	2006-07-08 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	11082	\N	\N	\N
11755	MEMBRE	2006-07-08 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11084	\N	\N	\N
11757	MEMBRE	2006-07-08 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11086	\N	\N	\N
10427	MEMBRE	2004-10-01 00:00:00	2008-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	9999	0	\N	\N
10429	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10003	\N	\N	\N
10430	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10002	\N	\N	\N
10431	MEMBRE	2004-10-01 00:00:00	2008-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	10004	0	\N	\N
10432	VICPDT	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10005	3	\N	\N
10433	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10006	\N	\N	\N
10434	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10007	\N	\N	\N
10436	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10009	\N	\N	\N
10437	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10010	\N	\N	\N
10438	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10011	\N	\N	\N
10439	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10012	\N	\N	\N
10440	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10013	\N	\N	\N
10441	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10014	\N	\N	\N
10442	VICPDT	2004-10-01 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	10015	2	\N	\N
10443	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10016	\N	\N	\N
10444	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10017	\N	\N	\N
10445	MEMBRE	2004-10-01 00:00:00	2007-09-25 00:00:00	ANCIEN	\N	\N	\N	\N	10018	\N	\N	\N
10446	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10019	\N	\N	\N
10447	MEMBRE	2004-10-01 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	10020	0	\N	\N
10448	MEMBRE	2004-10-01 00:00:00	2007-09-25 00:00:00	ANCIEN	\N	\N	\N	\N	10021	\N	\N	\N
10449	MEMBRE	2004-10-01 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	10022	0	\N	\N
10450	MEMBRE	2004-10-01 00:00:00	2007-09-25 00:00:00	ANCIEN	\N	\N	\N	\N	10023	\N	\N	\N
10452	VICPDT	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10025	5	\N	\N
10568	MEMBRE	2004-10-01 00:00:00	2005-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	10141	\N	\N	\N
10569	VICPDT	2005-01-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7593	\N	\N	\N
10570	PDT	2005-01-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7568	\N	\N	\N
10571	VICPDT	2005-01-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10134	\N	\N	\N
10572	VICPDT	2005-01-26 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10135	\N	\N	\N
10573	VICPDT	2005-01-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10128	\N	\N	\N
10575	TRESOR	2005-01-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10141	\N	\N	\N
10576	MEMBRE	2005-01-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7566	\N	\N	\N
10577	MEMBREBUR	2005-01-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7624	\N	\N	\N
10579	MEMBREBUR	2005-01-26 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7630	\N	\N	\N
10580	MEMBREBUR	2005-01-26 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10136	\N	\N	\N
10581	VICPDT	2004-12-07 00:00:00	2009-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	6266	2	\N	\N
10582	VICPDT	2004-12-07 00:00:00	2009-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	4111	7	\N	\N
10584	SECRET	2004-12-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6277	8	\N	\N
10585	SECRET	2004-12-07 00:00:00	2009-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	3928	14	\N	\N
10587	SECRET	2004-12-08 00:00:00	2008-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	6197	7	\N	\N
10588	VICPDT	2004-10-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5055	5	\N	\N
10591	MEMBRE	2004-10-26 00:00:00	2007-09-25 00:00:00	ANCIEN	\N	\N	\N	\N	887	\N	\N	\N
10592	MEMBRE	2004-10-26 00:00:00	2007-09-25 00:00:00	ANCIEN	\N	\N	\N	\N	1895	\N	\N	\N
10593	MEMBRE	2004-10-26 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	581	\N	\N	\N
10594	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10143	\N	\N	\N
10595	PDT	2004-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3820	1	\N	\N
10596	VICPDT	2004-12-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	5741	2	\N	\N
10597	VICPDT	2004-12-01 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	3793	4	\N	\N
10598	SECRET	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10144	8	\N	\N
10600	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10145	\N	\N	\N
10599	SECRET	2004-12-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	5708	5	\N	\N
10601	TRESOR	2004-12-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	3801	6	\N	\N
10603	SECRET	2004-10-01 00:00:00	2009-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	10147	\N	\N	\N
10604	MEMBRE	2004-10-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	10148	\N	\N	\N
10609	PDT	2004-12-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8515	1	\N	\N
10606	VICPDT	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10150	6	\N	\N
10607	VICPDT	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10151	6	\N	\N
10610	VICPDT	2004-12-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2923	2	\N	\N
10611	VICPDT	2004-12-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6117	5	\N	\N
10612	VICPDT	2004-12-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1053	6	\N	\N
10613	VICPDT	2004-12-14 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	2910	7	\N	\N
10614	VICPDT	2004-12-14 00:00:00	2011-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	2320	3	\N	\N
10615	SECRET	2004-12-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2909	9	\N	\N
10617	SECRET	2004-12-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6113	14	\N	\N
10619	MEMBRE	2004-12-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2930	\N	\N	\N
10620	MEMBRE	2004-12-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2924	\N	\N	\N
10621	MEMBRE	2004-12-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2902	\N	\N	\N
10622	MEMBRE	2004-12-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2896	\N	\N	\N
10623	MEMBRE	2004-12-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6118	\N	\N	\N
10624	MEMBRE	2004-12-14 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	6107	0	\N	\N
10625	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10153	\N	\N	\N
10626	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10154	\N	\N	\N
10627	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10155	\N	\N	\N
10628	MEMBRE	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	10156	\N	\N	\N
10629	MEMBRE	2004-12-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2895	\N	\N	\N
10630	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10157	\N	\N	\N
10632	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10159	\N	\N	\N
10633	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10160	\N	\N	\N
10634	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10161	\N	\N	\N
10644	PDTDEL	2004-12-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Mexique	\N	3473	2	\N	\N
10636	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10163	\N	\N	\N
10637	MEMBRE	2004-10-01 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	10164	\N	\N	\N
10639	MEMBRE	2004-10-01 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	10166	\N	\N	\N
10640	MEMBRE	2004-10-01 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	10167	\N	\N	\N
10641	MEMBRE	2001-11-07 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6094	\N	\N	\N
10642	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10169	\N	\N	\N
10643	VICPDT	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10170	5	\N	\N
10646	MEMBRE	2004-10-01 00:00:00	2005-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	10172	\N	\N	\N
10645	VICPDT	2004-12-14 00:00:00	2011-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	5886	4	\N	\N
10647	VICPDT	2004-12-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3484	5	\N	\N
10648	VICPDT	2004-12-14 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	3479	8	\N	\N
10649	SECRET	2004-12-14 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	3477	12	\N	\N
10650	SECRET	2004-12-14 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	3485	13	\N	\N
10651	SECRET	2004-12-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3444	14	\N	\N
10653	SECRET	2004-12-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3441	15	\N	\N
10655	MEMBRE	2004-12-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5887	\N	\N	\N
10656	MEMBRE	2004-12-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5891	\N	\N	\N
10658	SECRET	2004-11-16 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	3574	8	\N	\N
10659	VICPDT	2004-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3488	2	\N	\N
10661	VICPDT	2004-12-16 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	5327	\N	\N	\N
10662	VICPDT	2004-12-16 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	5332	\N	\N	\N
10663	VICPDT	2004-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3500	7	\N	\N
10664	VICPDT	2004-12-16 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	3507	\N	\N	\N
10665	PDT	2005-01-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4129	1	\N	\N
10666	VICPDT	2005-01-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4138	3	\N	\N
10667	VICPDT	2005-01-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4634	7	\N	\N
10668	SECRET	2005-01-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4630	10	\N	\N
10669	MEMBRE	2005-01-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4632	\N	\N	\N
10670	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10173	\N	\N	\N
10671	VICPDT	2004-10-01 00:00:00	2009-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	10174	3	\N	\N
10672	VICPDT	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10175	2	\N	\N
10673	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10176	\N	\N	\N
10674	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10177	\N	\N	\N
10676	SECRET	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10179	8	\N	\N
10677	SECRET	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10180	9	\N	\N
10678	VICPDT	2004-11-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6073	2	\N	\N
10679	VICPDT	2004-11-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4208	6	\N	\N
10680	SECRET	2004-11-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4198	9	\N	\N
10682	TRESOR	2004-11-16 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	5566	9	\N	\N
10683	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10181	\N	\N	\N
10684	PDTDEL	2004-10-01 00:00:00	2011-02-14 00:00:00	ANCIEN	\N	\N	Gambie	\N	10182	6	\N	\N
10685	VICPDT	2004-10-01 00:00:00	2008-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	10183	2	\N	\N
10686	VICPDT	2004-10-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	10184	4	\N	\N
10687	VICPDTPRE	2004-11-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6492	2	\N	\N
10688	VICPDT	2004-11-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5756	8	\N	\N
10690	TRESOR	2004-11-03 00:00:00	2009-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	4955	7	\N	\N
10691	MEMBRE	2004-10-01 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	10186	\N	\N	\N
10692	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10187	\N	\N	\N
10693	VICPDT	2004-12-15 00:00:00	2009-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	1480	4	\N	\N
10694	VICPDT	2004-12-15 00:00:00	2009-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	6122	5	\N	\N
10695	VICPDT	2004-12-15 00:00:00	2009-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	6128	6	\N	\N
10697	SECRET	2002-01-09 00:00:00	2009-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	6135	9	\N	\N
10698	SECRET	2004-12-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6129	9	\N	\N
10699	SECRET	2004-12-15 00:00:00	2009-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	6126	12	\N	\N
10701	MEMBREBUR	2004-12-15 00:00:00	2009-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	6136	17	\N	\N
10702	MEMBREBUR	2004-12-15 00:00:00	2009-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	6132	18	\N	\N
10706	SECRET	2004-10-01 00:00:00	2007-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	10198	11	\N	\N
10705	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10194	\N	\N	\N
10707	VICPDT	2004-10-01 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	10199	10	\N	\N
10709	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10202	\N	\N	\N
10710	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10203	\N	\N	\N
10711	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10204	\N	\N	\N
10712	MEMBRE	2004-10-01 00:00:00	2004-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	10205	\N	\N	\N
10713	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10206	\N	\N	\N
10714	VICPDT	2004-10-26 00:00:00	2009-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	7660	\N	\N	\N
10715	VICPDT	2004-10-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7674	\N	\N	\N
10716	VICPDT	2004-10-26 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7669	\N	\N	\N
11399	MEMBRE	2004-10-01 00:00:00	2004-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	10751	\N	\N	\N
11400	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10752	\N	\N	\N
11402	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10754	\N	\N	\N
11403	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10755	\N	\N	\N
11404	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10756	\N	\N	\N
11405	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10757	\N	\N	\N
11406	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10758	\N	\N	\N
11407	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10759	\N	\N	\N
11409	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10761	\N	\N	\N
11410	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10762	\N	\N	\N
11411	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10763	\N	\N	\N
11412	MEMBRE	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	10764	\N	\N	\N
11413	MEMBRE	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	10765	\N	\N	\N
11414	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10766	\N	\N	\N
11415	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10767	\N	\N	\N
11416	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10768	\N	\N	\N
11417	PDT	2004-12-14 00:00:00	2010-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	10751	\N	\N	\N
11418	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10749	\N	\N	\N
12361	VICPDT	2008-01-23 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8004	\N	\N	\N
11420	MEMBRE	2004-10-01 00:00:00	2007-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	10771	\N	\N	\N
11421	MEMBRE	2005-07-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10772	\N	\N	\N
11422	MEMBRE	2005-07-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10773	\N	\N	\N
11424	MEMBRE	2005-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10775	\N	\N	\N
11425	MEMBRE	2005-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10776	\N	\N	\N
11427	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10778	\N	\N	\N
11437	MEMBRE	2005-09-01 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	\N	10784	\N	\N	\N
11436	MEMBRE	2005-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10783	\N	\N	\N
11438	MEMBRE	2005-09-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	10785	\N	\N	\N
11439	MEMBRE	2005-09-01 00:00:00	2009-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	10786	\N	\N	\N
11440	MEMBRE	2005-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10787	\N	\N	\N
11441	MEMBRE	2005-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10788	\N	\N	\N
11442	MEMBRE	2005-10-01 00:00:00	2005-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	10789	\N	\N	\N
11443	MEMBRE	2005-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10790	\N	\N	\N
11445	MEMBRE	2005-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10792	\N	\N	\N
11447	MEMBRE	2005-10-26 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10794	\N	\N	\N
11448	MEMBRE	2005-10-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10795	\N	\N	\N
11450	MEMBRE	2005-10-01 00:00:00	2007-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	10797	0	\N	\N
11451	MEMBRE	2005-10-01 00:00:00	2007-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	10798	\N	\N	\N
11452	MEMBRE	2005-10-01 00:00:00	2008-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	10799	0	\N	\N
11453	MEMBRE	2005-10-01 00:00:00	2009-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	10800	\N	\N	\N
11454	MEMBRE	2005-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10801	\N	\N	\N
11455	MEMBRE	2005-10-01 00:00:00	2009-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	10802	\N	\N	\N
11456	MEMBRE	2005-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10803	\N	\N	\N
11457	MEMBRE	2005-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10804	\N	\N	\N
11458	MEMBRE	2005-10-01 00:00:00	2009-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	10805	0	\N	\N
11459	MEMBRE	2005-10-01 00:00:00	2009-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	10806	0	\N	\N
11460	MEMBRE	2005-10-01 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	10807	0	\N	\N
11461	MEMBRE	2005-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10808	\N	\N	\N
11462	MEMBRE	2005-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10809	\N	\N	\N
11463	MEMBRE	2005-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10810	\N	\N	\N
11465	MEMBRE	2005-10-27 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10812	\N	\N	\N
11466	MEMBRE	2005-11-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10813	\N	\N	\N
11467	MEMBRE	2005-11-22 00:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	10814	\N	\N	\N
11468	MEMBRE	2005-10-25 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10815	\N	\N	\N
11469	MEMBRE	2005-10-25 00:00:00	2009-03-09 00:00:00	ANCIEN	\N	\N	\N	\N	10816	0	\N	\N
11470	MEMBRE	2005-11-25 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	10817	\N	\N	\N
11471	MEMBRE	2005-11-25 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	10818	\N	\N	\N
11472	MEMBRE	2005-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10819	\N	\N	\N
11473	MEMBRE	2005-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10820	\N	\N	\N
11474	MEMBRE	2005-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10821	\N	\N	\N
11475	MEMBRE	2005-12-16 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10822	\N	\N	\N
11479	MEMBRE	2005-12-16 00:00:00	2007-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10826	\N	\N	\N
11480	MEMBRE	2005-12-16 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	10827	\N	\N	\N
11481	MEMBRE	2005-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10828	\N	\N	\N
11484	MEMBRE	2005-12-16 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10831	\N	\N	\N
11485	MEMBRE	2005-12-16 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10832	\N	\N	\N
11486	MEMBRE	2005-12-16 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	10833	\N	\N	\N
11487	PDT	2006-01-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10834	1	\N	\N
11489	MEMBRE	2005-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10836	\N	\N	\N
11490	MEMBRE	2005-12-01 00:00:00	2006-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	10837	\N	\N	\N
11491	MEMBRE	2005-12-01 00:00:00	2006-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	10838	\N	\N	\N
11977	MEMBRE	2007-02-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11280	\N	\N	\N
11978	MEMBRE	2007-02-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11281	\N	\N	\N
11979	TRESOR	2007-02-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11282	10	\N	\N
11980	MEMBRE	2007-02-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11283	\N	\N	\N
11981	VICPDTPRE	2007-02-14 00:00:00	2009-01-05 00:00:00	ANCIEN	\N	\N	et Rapporteur Kosovo	\N	11284	6	\N	\N
11982	PDTDEL	2007-02-14 00:00:00	2009-01-05 00:00:00	ANCIEN	\N	\N	Serbie	\N	11285	5	\N	\N
11983	MEMBRE	2007-02-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11286	\N	\N	\N
11984	SECRET	2007-02-14 00:00:00	2009-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	11287	12	\N	\N
11985	MEMBRE	2007-02-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11288	\N	\N	\N
11986	MEMBRE	2007-02-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11289	\N	\N	\N
11987	MEMBRE	2007-02-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11290	\N	\N	\N
11988	VICPDT	2007-02-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11291	10	\N	\N
11989	MEMBRE	2007-02-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11292	\N	\N	\N
11990	MEMBRE	2007-02-14 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	11293	\N	\N	\N
11991	PDTDEL	2007-02-14 00:00:00	2009-01-05 00:00:00	ANCIEN	\N	\N	Monténégro	\N	11294	4	\N	\N
11992	MEMBRE	2007-02-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11295	\N	\N	\N
11993	MEMBRE	2007-02-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11296	\N	\N	\N
11994	MEMBRE	2007-02-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11297	\N	\N	\N
11995	MEMBRE	2007-02-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11298	\N	\N	\N
11996	MEMBRE	2007-02-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11299	\N	\N	\N
11998	MEMBRE	2007-02-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11301	\N	\N	\N
11999	SECRET	2007-02-14 00:00:00	2009-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	11302	14	\N	\N
12000	PDTDEL	2007-02-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Bosnie-Herzégovine	\N	11303	2	\N	\N
12001	MEMBRE	2007-02-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11304	\N	\N	\N
12002	MEMBRE	2007-02-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11305	\N	\N	\N
12003	VICPDT	2007-02-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11306	7	\N	\N
12004	MEMBRE	2007-02-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11307	\N	\N	\N
12006	MEMBRE	2007-02-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11309	\N	\N	\N
12007	MEMBRE	2007-02-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11310	\N	\N	\N
12052	VICPDT	2007-04-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9532	\N	\N	\N
12059	VICPDT	2007-04-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7453	\N	\N	\N
12060	PDT	2007-06-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11339	1	\N	\N
12434	MEMBRE	2008-04-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11669	\N	\N	\N
12225	MEMBRE	2006-09-01 00:00:00	2007-11-13 00:00:00	ANCIEN	\N	\N	\N	\N	11500	\N	\N	\N
12226	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11501	\N	\N	\N
12228	MEMBRE	2006-09-01 00:00:00	2007-11-13 00:00:00	ANCIEN	\N	\N	\N	\N	11503	\N	\N	\N
12229	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11504	\N	\N	\N
12230	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11505	\N	\N	\N
12231	MEMBRE	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11506	\N	\N	\N
12280	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11555	\N	\N	\N
12281	MEMBRE	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11556	\N	\N	\N
12313	MEMBRE	2007-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11587	\N	\N	\N
12314	MEMBRE	2007-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11588	\N	\N	\N
12315	MEMBRE	2007-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11589	\N	\N	\N
12317	MEMBRE	2007-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11591	\N	\N	\N
12318	MEMBRE	2007-10-01 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	11592	\N	\N	\N
12319	MEMBRE	2007-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11593	\N	\N	\N
12415	MEMBRE	2004-11-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7516	\N	\N	\N
12433	MEMBRE	2008-04-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11668	\N	\N	\N
12435	MEMBRE	2008-04-24 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	11670	\N	\N	\N
12436	MEMBRE	2008-04-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11671	\N	\N	\N
12437	MEMBRE	2008-04-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11672	\N	\N	\N
12439	MEMBRE	2008-04-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11674	\N	\N	\N
12440	MEMBRE	2008-04-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11675	\N	\N	\N
12441	MEMBRE	2008-04-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11676	\N	\N	\N
12442	MEMBRE	2008-04-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11677	\N	\N	\N
12443	MEMBRE	2008-04-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11678	\N	\N	\N
12444	MEMBRE	2008-04-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11679	\N	\N	\N
12445	MEMBRE	2008-04-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11680	\N	\N	\N
12447	MEMBRE	2008-04-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11682	\N	\N	\N
12448	MEMBRE	2008-04-24 00:00:00	2009-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	11683	\N	\N	\N
12450	MEMBRE	2008-04-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11685	\N	\N	\N
12451	MEMBRE	2008-04-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11686	\N	\N	\N
12452	MEMBRE	2008-04-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11687	\N	\N	\N
10528	MEMBRE	2004-10-01 00:00:00	2005-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	10111	\N	\N	\N
10529	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10112	\N	\N	\N
10530	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10113	\N	\N	\N
10531	MEMBREBUR	2004-10-01 00:00:00	2007-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	10114	15	\N	\N
10532	MEMBRE	2004-10-01 00:00:00	2007-02-25 00:00:00	ANCIEN	\N	\N	\N	\N	10115	\N	\N	\N
10533	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10116	\N	\N	\N
10534	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10117	\N	\N	\N
10535	VICPDT	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10118	3	\N	\N
10536	MEMBRE	2004-10-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	10119	0	\N	\N
10537	MEMBRE	2004-10-01 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	10120	\N	\N	\N
10538	MEMBRE	2004-10-01 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	\N	10121	\N	\N	\N
10540	SECRET	2004-10-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	10123	11	\N	\N
10542	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10125	\N	\N	\N
10544	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10127	\N	\N	\N
10545	VICPDT	2004-11-17 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	4543	4	\N	\N
10547	VICPDT	2004-11-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6348	7	\N	\N
10549	MEMBREBUR	2004-11-17 00:00:00	2008-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	6321	13	\N	\N
10550	PDT	2004-11-09 00:00:00	2009-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	893	1	\N	\N
10552	SECRET	2004-10-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9980	\N	\N	\N
10553	SECRET	2004-10-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9966	\N	\N	\N
10554	MEMBRE	2004-10-01 00:00:00	2005-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	10128	\N	\N	\N
10555	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10129	\N	\N	\N
10557	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10131	\N	\N	\N
10558	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10132	\N	\N	\N
10559	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10133	\N	\N	\N
10560	MEMBRE	2004-10-01 00:00:00	2005-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	10134	\N	\N	\N
10561	MEMBRE	2004-10-01 00:00:00	2005-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	10135	\N	\N	\N
10562	MEMBRE	2004-10-01 00:00:00	2005-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	10136	\N	\N	\N
10563	VICPDT	2004-12-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9996	\N	\N	\N
10564	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10137	\N	\N	\N
10565	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10138	\N	\N	\N
10566	MEMBRE	2004-10-01 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	10139	\N	\N	\N
10567	MEMBRE	2004-10-01 00:00:00	2005-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	10140	\N	\N	\N
11105	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10525	\N	\N	\N
11107	MEMBRE	2004-10-01 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	10527	0	\N	\N
11108	MEMBRE	2004-10-01 00:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	10528	0	\N	\N
11110	MEMBRE	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	10529	\N	\N	\N
11111	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10531	\N	\N	\N
11112	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10532	\N	\N	\N
11113	VICPDT	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10533	2	\N	\N
11114	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10535	\N	\N	\N
11115	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10536	\N	\N	\N
11118	SECRET	2004-10-01 00:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	10539	13	\N	\N
11119	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10540	\N	\N	\N
11120	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10541	\N	\N	\N
11121	MEMBRE	2004-10-01 00:00:00	2007-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10542	\N	\N	\N
11122	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10543	\N	\N	\N
11123	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10544	\N	\N	\N
11124	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10545	\N	\N	\N
11126	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10547	\N	\N	\N
11127	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10548	\N	\N	\N
11128	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10549	\N	\N	\N
11129	SECRET	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10550	12	\N	\N
11130	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10530	\N	\N	\N
11131	SECRET	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10538	12	\N	\N
11132	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7938	\N	\N	\N
11133	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7931	\N	\N	\N
11134	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	7558	\N	\N	\N
11135	SECRET	2005-04-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	8790	\N	\N	\N
11136	PDT	2005-04-01 00:00:00	2010-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	10475	\N	\N	\N
11137	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10558	\N	\N	\N
11138	MEMBRE	2004-10-01 00:00:00	2008-04-18 00:00:00	ANCIEN	\N	\N	\N	\N	10559	\N	\N	\N
11139	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10560	\N	\N	\N
11140	VICPDT	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10561	4	\N	\N
11141	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10562	\N	\N	\N
11142	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10563	\N	\N	\N
11143	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10564	\N	\N	\N
11144	MEMBRE	2004-10-01 00:00:00	2005-12-22 00:00:00	ANCIEN	\N	\N	\N	\N	10565	\N	\N	\N
11147	MEMBRE	2005-04-11 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	10568	\N	\N	\N
11148	MEMBRE	2005-04-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10569	\N	\N	\N
11149	SECRET	2004-11-10 00:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	1252	8	\N	\N
11150	SECRET	2004-11-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2008	8	\N	\N
11152	SECRET	2004-11-10 00:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	5968	11	\N	\N
11153	VICPDT	2004-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6462	6	\N	\N
11156	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10571	\N	\N	\N
11157	MEMBRE	2004-10-01 00:00:00	2008-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	10572	\N	\N	\N
11158	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10573	\N	\N	\N
11159	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10574	\N	\N	\N
11160	MEMBRE	2005-04-11 00:00:00	2005-05-30 00:00:00	ANCIEN	\N	\N	\N	\N	10575	\N	\N	\N
11161	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10576	\N	\N	\N
11162	MEMBRE	2005-04-11 00:00:00	2005-05-30 00:00:00	ANCIEN	\N	\N	\N	\N	10577	\N	\N	\N
11164	MEMBRE	2005-04-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10579	\N	\N	\N
11165	MEMBRE	2005-04-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10580	\N	\N	\N
11166	PDTDEL	2005-03-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Malaisie	\N	5993	5	\N	\N
11167	PDTDEL	2005-03-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Thaïlande	\N	9459	8	\N	\N
11168	PDTDEL	2005-03-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Bangladesh	\N	9446	2	\N	\N
11169	VICPDT	2005-03-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5996	10	\N	\N
11170	VICPDT	2004-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2995	2	\N	\N
11171	VICPDT	2004-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3024	7	\N	\N
11172	SECRET	2004-12-01 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	5170	9	\N	\N
11173	MEMBREBUR	2004-12-01 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	5152	13	\N	\N
11174	TRESOR	2004-12-01 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	5178	15	\N	\N
11176	MEMBRE	2005-04-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10581	\N	\N	\N
11177	MEMBRE	2005-04-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10582	\N	\N	\N
11179	PDTDEL	2005-04-12 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	Tanzanie	\N	3718	10	\N	\N
11180	MEMBRE	2005-04-12 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3743	\N	\N	\N
11181	MEMBRE	2005-04-12 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6361	\N	\N	\N
11182	MEMBRE	2005-04-12 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	3731	\N	\N	\N
11183	MEMBRE	2005-04-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10584	\N	\N	\N
11184	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10585	\N	\N	\N
11185	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10586	\N	\N	\N
11187	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10588	\N	\N	\N
11188	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10589	\N	\N	\N
11189	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10590	\N	\N	\N
11190	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10591	\N	\N	\N
11191	MEMBRE	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	10592	\N	\N	\N
11192	MEMBRE	2004-10-01 00:00:00	2005-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	10593	\N	\N	\N
11195	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10596	\N	\N	\N
11196	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10597	\N	\N	\N
11198	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10599	\N	\N	\N
11199	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10600	\N	\N	\N
11200	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10601	\N	\N	\N
11202	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10603	\N	\N	\N
11204	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10605	\N	\N	\N
11206	MEMBRE	2001-10-01 00:00:00	2007-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	10607	\N	\N	\N
11207	MEMBRE	2004-10-01 00:00:00	2007-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10608	\N	\N	\N
11208	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10609	\N	\N	\N
11209	MEMBRE	2004-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	10610	\N	\N	\N
11210	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10611	\N	\N	\N
11211	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10612	\N	\N	\N
11212	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10613	\N	\N	\N
11214	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10615	\N	\N	\N
11215	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10616	\N	\N	\N
11216	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10617	\N	\N	\N
11217	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10618	\N	\N	\N
11219	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10620	\N	\N	\N
11220	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10621	\N	\N	\N
11222	MEMBRE	2001-10-01 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	10623	\N	\N	\N
11223	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10624	\N	\N	\N
11224	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10625	\N	\N	\N
11226	MEMBRE	2005-04-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10626	\N	\N	\N
11227	MEMBRE	2005-04-11 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	10627	\N	\N	\N
11228	MEMBRE	2005-04-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10628	\N	\N	\N
11229	VICPDT	2004-12-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5352	6	\N	\N
11230	VICPDT	2004-12-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5372	8	\N	\N
11231	VICPDT	2004-12-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5375	9	\N	\N
11233	SECRET	2004-12-07 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	190	13	\N	\N
11234	SECRET	2004-12-07 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	1427	14	\N	\N
11236	SECRET	2004-12-07 00:00:00	2009-09-09 00:00:00	ANCIEN	\N	\N	\N	\N	5362	18	\N	\N
11237	SECRET	2004-12-07 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	573	23	\N	\N
11238	SECRET	2004-12-07 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	5370	24	\N	\N
11239	SECRET	2004-12-07 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6424	25	\N	\N
11240	SECRET	2004-12-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1254	25	\N	\N
11241	MEMBRE	2005-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10629	\N	\N	\N
11244	MEMBRE	2005-04-11 00:00:00	2005-05-30 00:00:00	ANCIEN	\N	\N	\N	\N	10632	\N	\N	\N
11245	MEMBRE	2005-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10633	\N	\N	\N
11246	MEMBRE	2005-05-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10634	\N	\N	\N
11247	MEMBRE	2005-04-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	10635	\N	\N	\N
11248	MEMBRE	2005-04-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10636	\N	\N	\N
11249	MEMBRE	2005-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10637	\N	\N	\N
11250	MEMBRE	2005-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10638	\N	\N	\N
11251	MEMBRE	2005-02-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10639	\N	\N	\N
11252	MEMBRE	2004-11-01 00:00:00	2005-03-21 00:00:00	ANCIEN	\N	\N	\N	\N	10640	\N	\N	\N
11253	MEMBRE	2005-04-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10641	\N	\N	\N
11254	MEMBRE	2005-04-11 00:00:00	2005-05-30 00:00:00	ANCIEN	\N	\N	\N	\N	10642	\N	\N	\N
11255	PDT	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10426	\N	\N	\N
11261	VICPDT	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10447	\N	\N	\N
11260	VICPDT	2004-10-01 00:00:00	2010-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	10410	\N	\N	\N
11262	VICPDT	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10409	\N	\N	\N
11265	SECRET	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10413	\N	\N	\N
11266	SECRET	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10421	\N	\N	\N
11267	SECRET	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10404	\N	\N	\N
11268	SECRET	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10415	\N	\N	\N
11269	MEMBRE	2005-04-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10645	\N	\N	\N
11270	MEMBRE	2005-04-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10646	\N	\N	\N
11271	PDTDEL	2005-03-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Birmanie	\N	10640	3	\N	\N
11272	PDT	2005-05-31 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10575	\N	\N	\N
11273	VICPDT	2005-05-31 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10577	\N	\N	\N
11274	VICPDT	2005-05-31 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10642	\N	\N	\N
11275	VICPDT	2005-05-31 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10567	\N	\N	\N
11276	VICPDT	2005-05-31 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	10578	\N	\N	\N
11277	MEMBRE	2005-04-11 00:00:00	2005-05-30 00:00:00	ANCIEN	\N	\N	\N	\N	10647	\N	\N	\N
11278	PDT	2005-05-30 00:00:00	2005-05-30 00:00:00	ANCIEN	\N	\N	\N	\N	10647	\N	\N	\N
11279	VICPDT	2005-05-31 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10647	\N	\N	\N
11280	MEMBRE	2005-04-11 00:00:00	2005-05-30 00:00:00	ANCIEN	\N	\N	\N	\N	10648	\N	\N	\N
11281	SECRET	2005-05-31 00:00:00	2007-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	10648	\N	\N	\N
11291	MEMBRE	2005-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10657	\N	\N	\N
11292	MEMBRE	2005-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10658	\N	\N	\N
11293	MEMBRE	2005-06-01 00:00:00	2005-06-19 00:00:00	ANCIEN	\N	\N	\N	\N	10659	\N	\N	\N
11294	MEMBRE	2005-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10660	\N	\N	\N
11296	MEMBRE	2005-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10662	\N	\N	\N
11297	MEMBRE	2005-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10663	\N	\N	\N
11298	MEMBRE	2005-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10664	\N	\N	\N
11299	MEMBRE	2005-06-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	10665	\N	\N	\N
11301	MEMBRE	2005-06-01 00:00:00	2005-06-19 00:00:00	ANCIEN	\N	\N	\N	\N	10667	\N	\N	\N
11303	MEMBRE	2005-06-01 00:00:00	2005-06-19 00:00:00	ANCIEN	\N	\N	\N	\N	10669	\N	\N	\N
11304	MEMBRE	2005-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10670	\N	\N	\N
11305	MEMBRE	2005-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10671	\N	\N	\N
11306	MEMBRE	2005-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10672	\N	\N	\N
11308	MEMBRE	2005-06-01 00:00:00	2005-06-19 00:00:00	ANCIEN	\N	\N	\N	\N	10674	\N	\N	\N
11309	MEMBRE	2005-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10675	\N	\N	\N
11310	MEMBRE	2005-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10676	\N	\N	\N
11311	MEMBRE	2005-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10677	\N	\N	\N
11312	MEMBRE	2005-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10678	\N	\N	\N
11313	MEMBRE	2005-06-01 00:00:00	2008-09-07 00:00:00	ANCIEN	\N	\N	\N	\N	10679	\N	\N	\N
11314	MEMBRE	2005-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10680	\N	\N	\N
11315	MEMBRE	2005-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10681	\N	\N	\N
11316	MEMBRE	2005-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10682	\N	\N	\N
11317	MEMBRE	2005-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10683	\N	\N	\N
11318	MEMBRE	2005-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10684	\N	\N	\N
11319	MEMBRE	2005-06-01 00:00:00	2005-06-19 00:00:00	ANCIEN	\N	\N	\N	\N	10685	\N	\N	\N
11321	MEMBRE	2005-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10687	\N	\N	\N
11322	MEMBRE	2005-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10688	\N	\N	\N
11323	MEMBRE	2005-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10689	\N	\N	\N
11324	MEMBRE	2005-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10690	\N	\N	\N
11325	MEMBRE	2005-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10691	\N	\N	\N
11326	MEMBRE	2005-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10692	\N	\N	\N
11327	MEMBRE	2005-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10693	\N	\N	\N
11328	MEMBRE	2005-06-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	10694	\N	\N	\N
11331	MEMBRE	2005-06-01 00:00:00	2005-06-19 00:00:00	ANCIEN	\N	\N	\N	\N	10697	\N	\N	\N
11333	MEMBRE	2005-06-01 00:00:00	2005-06-19 00:00:00	ANCIEN	\N	\N	\N	\N	10699	\N	\N	\N
11334	MEMBRE	2005-06-01 00:00:00	2007-11-05 00:00:00	ANCIEN	\N	\N	\N	\N	10700	\N	\N	\N
11336	PDT	2005-06-10 00:00:00	2007-09-06 00:00:00	ANCIEN	\N	\N	\N	\N	10701	\N	\N	\N
11337	MEMBRE	2005-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10702	\N	\N	\N
11338	MEMBRE	2005-06-01 00:00:00	2005-06-19 00:00:00	ANCIEN	\N	\N	\N	\N	10703	\N	\N	\N
11339	MEMBRE	2005-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10704	\N	\N	\N
11340	MEMBRE	2005-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10705	\N	\N	\N
11342	MEMBRE	2005-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10707	\N	\N	\N
11345	MEMBRE	2005-06-01 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	10710	\N	\N	\N
11346	MEMBRE	2005-06-01 00:00:00	2005-06-19 00:00:00	ANCIEN	\N	\N	\N	\N	10711	\N	\N	\N
11347	MEMBRE	2005-06-01 00:00:00	2005-06-19 00:00:00	ANCIEN	\N	\N	\N	\N	10712	\N	\N	\N
11348	MEMBRE	2005-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10713	\N	\N	\N
11349	MEMBRE	2005-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10714	\N	\N	\N
11351	VICPDT	2005-06-20 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10669	\N	\N	\N
11353	VICPDT	2005-06-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10685	\N	\N	\N
11356	SECRET	2005-06-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10668	\N	\N	\N
11357	SECRET	2005-06-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10674	\N	\N	\N
11358	SECRET	2005-06-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10697	\N	\N	\N
11359	SECRET	2005-06-20 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10699	\N	\N	\N
11360	SECRET	2005-06-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10703	\N	\N	\N
11361	SECRET	2005-06-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10711	\N	\N	\N
11363	PDT	2005-06-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6419	1	\N	\N
11366	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10717	\N	\N	\N
11368	MEMBRE	2004-11-01 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	10719	\N	\N	\N
11369	PDT	2004-11-01 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	10721	\N	\N	\N
11370	MEMBRE	2004-11-01 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	10722	\N	\N	\N
11371	MEMBRE	2004-11-01 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	10723	\N	\N	\N
11372	MEMBRE	2004-11-01 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	10724	\N	\N	\N
11373	MEMBRE	2004-11-01 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	10725	\N	\N	\N
11375	MEMBRE	2004-11-01 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	10727	\N	\N	\N
11376	MEMBRE	2004-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10728	\N	\N	\N
11377	MEMBRE	2004-11-01 00:00:00	2007-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	10729	\N	\N	\N
11378	MEMBRE	2004-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10730	\N	\N	\N
11379	MEMBRE	2004-11-01 00:00:00	2008-08-30 00:00:00	ANCIEN	\N	\N	\N	\N	10731	\N	\N	\N
11380	MEMBRE	2004-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10732	\N	\N	\N
11381	MEMBRE	2004-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10733	\N	\N	\N
11382	MEMBRE	2004-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10734	\N	\N	\N
11383	MEMBRE	2004-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10735	\N	\N	\N
11384	MEMBRE	2004-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10736	\N	\N	\N
11385	MEMBRE	2004-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10737	\N	\N	\N
11387	MEMBRE	2004-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10739	\N	\N	\N
11388	MEMBRE	2004-11-01 00:00:00	2007-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	10740	\N	\N	\N
11389	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10741	\N	\N	\N
11390	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10742	\N	\N	\N
11391	MEMBRE	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	10743	\N	\N	\N
11392	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10744	\N	\N	\N
11394	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10746	\N	\N	\N
11395	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10747	\N	\N	\N
11396	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10748	\N	\N	\N
11398	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10750	\N	\N	\N
12359	MEMBRE	2008-01-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11607	\N	\N	\N
11857	MEMBRE	2006-11-28 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	11161	\N	\N	\N
11859	MEMBRE	2006-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11163	\N	\N	\N
11791	MEMBRE	2006-09-21 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	\N	11106	\N	\N	\N
11792	MEMBRE	2006-09-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11107	\N	\N	\N
11793	MEMBRE	2006-09-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11108	\N	\N	\N
11794	MEMBRE	2006-09-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11109	\N	\N	\N
11795	MEMBRE	2006-09-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11110	\N	\N	\N
11796	MEMBRE	2006-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11112	\N	\N	\N
11860	MEMBRE	2006-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11164	\N	\N	\N
11861	MEMBRE	2006-11-28 00:00:00	2007-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	11165	\N	\N	\N
11862	MEMBRE	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11166	\N	\N	\N
11863	MEMBRE	2006-11-28 00:00:00	2007-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	11167	\N	\N	\N
11864	MEMBRE	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11168	\N	\N	\N
11865	MEMBRE	2006-11-28 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	11169	\N	\N	\N
11866	MEMBRE	2006-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11170	\N	\N	\N
11867	MEMBRE	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11171	\N	\N	\N
12887	VICPDT	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11978	3	\N	\N
12888	VICPDT	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11979	4	\N	\N
12889	SECRET	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	887	6	\N	\N
12891	SECRET	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11981	7	\N	\N
12892	MEMBRE	2008-12-16 00:00:00	2010-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	10023	0	\N	\N
12893	MEMBRE	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10015	0	\N	\N
12894	MEMBRE	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10018	0	\N	\N
12895	MEMBRE	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10021	0	\N	\N
12896	MEMBRE	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1895	0	\N	\N
12902	VICPDT	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11986	4	\N	\N
12904	VICPDT	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11989	8	\N	\N
12905	SECRET	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10043	10	\N	\N
12906	SECRET	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6107	11	\N	\N
12907	SECRET	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2904	12	\N	\N
12908	SECRET	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11990	15	\N	\N
12909	SECRET	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11991	16	\N	\N
12910	MEMBRE	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10042	0	\N	\N
12911	MEMBRE	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10053	0	\N	\N
12912	PDT	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9739	1	\N	\N
12913	PDTHON	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3579	2	\N	\N
12914	VICPDT	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11992	3	\N	\N
12915	VICPDT	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11993	4	\N	\N
12916	VICPDT	2008-12-16 00:00:00	2011-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	11994	5	\N	\N
12917	SECRET	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5486	7	\N	\N
12918	SECRET	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4262	8	\N	\N
12919	SECRET	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9735	9	\N	\N
12920	MEMBRE	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9732	0	\N	\N
12921	MEMBRE	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3574	0	\N	\N
12922	MEMBRE	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3578	0	\N	\N
12923	VICPDT	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11995	5	\N	\N
12924	VICPDT	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11996	6	\N	\N
12925	VICPDT	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11997	9	\N	\N
12926	VICPDT	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11998	11	\N	\N
18133	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16337	\N	\N	\N
12453	MEMBRE	2008-04-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11688	\N	\N	\N
11920	VICPDT	2007-01-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8669	\N	\N	\N
11929	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11231	\N	\N	\N
12408	MEMBRE	2008-02-19 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11645	\N	\N	\N
12282	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11557	\N	\N	\N
12283	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11558	\N	\N	\N
12285	MEMBRE	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11560	\N	\N	\N
12286	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11561	\N	\N	\N
12287	MEMBRE	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11562	\N	\N	\N
12288	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11563	\N	\N	\N
12289	MEMBRE	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11564	\N	\N	\N
12290	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11565	\N	\N	\N
12291	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11566	\N	\N	\N
12362	PDT	2008-01-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7997	\N	\N	\N
12410	MEMBRE	2008-02-22 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11647	\N	\N	\N
12411	MEMBRE	2008-02-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11648	\N	\N	\N
12456	MEMBRE	2008-04-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11691	\N	\N	\N
12454	MEMBRE	2008-04-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11689	\N	\N	\N
12457	MEMBRE	2008-04-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11692	\N	\N	\N
12466	MEMBRE	2008-07-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11698	\N	\N	\N
12505	VICPDT	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11721	4	\N	\N
12506	SECRET	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10096	9	\N	\N
12507	SECRET	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11722	10	\N	\N
12508	SECRET	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11723	11	\N	\N
12509	SECRET	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10104	12	\N	\N
12511	SECRET	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4543	14	\N	\N
12512	SECRET	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11724	15	\N	\N
12515	MEMBRE	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10126	0	\N	\N
12516	PDT	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10483	1	\N	\N
12517	VICPDT	2008-12-09 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	\N	11725	4	\N	\N
12518	VICPDT	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6512	6	\N	\N
12519	VICPDT	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11726	7	\N	\N
12520	VICPDT	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11727	8	\N	\N
5152	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5261	\N	\N	\N
5193	SECRET	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3884	5	\N	\N
5200	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4036	6	\N	\N
5266	MEMBRE	2001-10-01 00:00:00	2004-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	5327	\N	\N	\N
5303	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5364	\N	\N	\N
5311	SECRET	2001-10-01 00:00:00	2004-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	5372	17	\N	\N
5410	MEMBRE	2001-10-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	5458	\N	\N	\N
5418	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5466	\N	\N	\N
4824	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4940	\N	\N	\N
4866	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4982	\N	\N	\N
4944	VICPDT	2001-10-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	3362	10	\N	\N
4985	MEMBRE	2001-10-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	5086	\N	\N	\N
5017	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5124	\N	\N	\N
5052	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5159	\N	\N	\N
5059	MEMBRE	2001-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	5167	\N	\N	\N
5810	MEMBRE	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5855	\N	\N	\N
5848	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5894	\N	\N	\N
5893	SECRET	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2641	8	\N	\N
6012	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5970	\N	\N	\N
6051	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4064	4	\N	\N
6049	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2357	\N	\N	\N
4773	MEMBRE	2001-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	4888	\N	\N	\N
4780	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4895	\N	\N	\N
5516	VICPDT	2001-10-01 00:00:00	2004-11-15 00:00:00	ANCIEN	\N	\N	\N	\N	5566	5	\N	\N
11786	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11100	\N	\N	\N
11855	MEMBRE	2006-10-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11159	\N	\N	\N
11915	MEMBRE	2006-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11215	\N	\N	\N
11941	MEMBRE	2005-02-21 00:00:00	2010-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	11243	\N	\N	\N
12355	MEMBRE	2002-01-15 00:00:00	2009-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	5231	\N	\N	\N
12395	MEMBRE	2008-02-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8506	\N	\N	\N
12396	MEMBRE	2008-02-26 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8507	\N	\N	\N
12397	MEMBRE	2008-02-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8508	\N	\N	\N
12398	MEMBRE	2008-02-26 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8509	\N	\N	\N
12399	MEMBRE	2008-02-26 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8511	\N	\N	\N
12407	MEMBRE	2008-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11644	\N	\N	\N
5524	MEMBRE	2001-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	5574	\N	\N	\N
5568	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5620	\N	\N	\N
5616	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5668	\N	\N	\N
5654	MEMBRE	2001-10-01 00:00:00	2004-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	5708	\N	\N	\N
5572	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5624	\N	\N	\N
5602	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5654	\N	\N	\N
6406	MEMBRE	2001-10-01 00:00:00	2004-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	6308	\N	\N	\N
6446	MEMBRE	2002-07-31 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2351	\N	\N	\N
6563	MEMBRE	2001-11-27 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	12	\N	\N	\N
6571	PDTDEL	2002-12-03 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	Thaïlande	\N	1321	7	\N	\N
6651	MEMBRE	2003-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6509	\N	\N	\N
6688	VICPDT	2003-04-01 00:00:00	2004-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	5098	4	\N	\N
6163	MEMBRE	2000-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6098	\N	\N	\N
6244	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6179	\N	\N	\N
6359	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	2727	\N	\N	\N
7361	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7458	\N	\N	\N
7368	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7465	\N	\N	\N
7375	VICPDT	2001-10-02 00:00:00	2007-04-03 00:00:00	ANCIEN	\N	\N	\N	\N	7447	\N	\N	\N
7382	TRESOR	2001-10-02 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7449	\N	\N	\N
7391	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7476	\N	\N	\N
7415	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7500	\N	\N	\N
7422	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7507	\N	\N	\N
7430	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7515	\N	\N	\N
7435	VICPDT	2001-10-02 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7508	\N	\N	\N
7475	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7546	\N	\N	\N
7481	VICPDT	2001-10-02 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7532	\N	\N	\N
7509	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7570	\N	\N	\N
7517	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7578	\N	\N	\N
7525	MEMBRE	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	7586	\N	\N	\N
7532	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7593	\N	\N	\N
7550	MEMBRE	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	7611	\N	\N	\N
7557	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7618	\N	\N	\N
7563	MEMBRE	2001-10-01 00:00:00	2005-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	7624	\N	\N	\N
7570	MEMBRE	2001-10-01 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	7631	\N	\N	\N
7578	VICPDT	2001-10-02 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	7636	\N	\N	\N
7639	MEMBRE	2001-10-01 00:00:00	2004-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	7675	\N	\N	\N
7620	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7658	\N	\N	\N
11759	MEMBRE	2006-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11088	\N	\N	\N
11760	MEMBRE	2006-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11089	\N	\N	\N
11912	MEMBRE	2006-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11216	\N	\N	\N
11916	MEMBRE	2006-12-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11219	\N	\N	\N
11945	MEMBRE	2007-02-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11247	\N	\N	\N
11974	MEMBRE	2007-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11277	\N	\N	\N
11975	MEMBRE	2007-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11278	\N	\N	\N
12008	MEMBRE	2007-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11311	\N	\N	\N
12009	SECRET	2007-01-15 00:00:00	2009-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	11312	11	\N	\N
12010	MEMBRE	2007-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11313	\N	\N	\N
12011	MEMBRE	2007-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11314	\N	\N	\N
12012	VICPDT	2007-01-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11315	8	\N	\N
12013	VICPDT	2007-02-14 00:00:00	2009-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	11316	9	\N	\N
12014	SECRET	2007-02-14 00:00:00	2009-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	11317	15	\N	\N
12015	SECRET	2007-02-14 00:00:00	2009-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	11318	16	\N	\N
12016	MEMBRE	2007-02-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11319	\N	\N	\N
12166	MEMBRE	2007-07-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11449	\N	\N	\N
12375	MEMBRE	2008-02-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11622	\N	\N	\N
12403	MEMBRE	2008-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11640	\N	\N	\N
12432	PDT	2008-04-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9930	1	\N	\N
12458	MEMBRE	2008-05-19 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	11693	\N	\N	\N
12481	MEMBRE	2008-10-29 00:00:00	2009-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	11713	\N	\N	\N
14682	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13217	\N	\N	\N
14683	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13218	\N	\N	\N
3517	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3587	\N	\N	\N
6094	MEMBRE	2001-10-17 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	6023	\N	\N	\N
6769	MEMBRE	2003-06-25 00:00:00	2004-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	6609	\N	\N	\N
7084	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7227	\N	\N	\N
7127	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7257	\N	\N	\N
7134	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7264	\N	\N	\N
7140	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7270	\N	\N	\N
7153	VICPDT	2003-09-20 00:00:00	2003-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	7277	\N	\N	\N
7202	MEMBRE	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	7319	\N	\N	\N
7209	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7322	\N	\N	\N
7253	VICPDT	2001-10-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7327	\N	\N	\N
7282	MEMBRE	2002-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7385	\N	\N	\N
7287	MEMBRE	2002-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7390	\N	\N	\N
7293	MEMBRE	2002-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7396	\N	\N	\N
7301	VICPDT	2002-01-02 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	7399	\N	\N	\N
7334	MEMBRE	2001-10-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	7431	\N	\N	\N
7342	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7439	\N	\N	\N
7349	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7446	\N	\N	\N
8095	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8037	\N	\N	\N
8103	VICPDT	1995-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8028	\N	\N	\N
8121	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8054	\N	\N	\N
8126	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8059	\N	\N	\N
8132	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8065	\N	\N	\N
8158	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8089	\N	\N	\N
8167	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8098	\N	\N	\N
8175	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8106	\N	\N	\N
8181	MEMBRE	2001-10-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	8112	\N	\N	\N
8213	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8144	\N	\N	\N
11758	MEMBRE	2006-07-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11087	\N	\N	\N
11762	VICPDT	2006-07-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11073	\N	\N	\N
11763	VICPDT	2006-07-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11079	\N	\N	\N
11764	VICPDT	2006-07-11 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	11082	\N	\N	\N
11766	SECRET	2006-07-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11081	\N	\N	\N
12040	MEMBRE	2007-02-14 00:00:00	2010-01-07 00:00:00	ANCIEN	\N	\N	\N	\N	11336	\N	\N	\N
12017	PDTDEL	2007-02-14 00:00:00	2009-01-05 00:00:00	ANCIEN	\N	\N	République de Macédoine	\N	11300	3	\N	\N
12041	MEMBRE	2007-02-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11337	\N	\N	\N
12042	MEMBRE	2007-02-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11338	\N	\N	\N
12043	MEMBRE	2007-02-14 00:00:00	2007-06-04 00:00:00	ANCIEN	\N	\N	\N	\N	11339	\N	\N	\N
12045	MEMBRE	2007-02-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11341	\N	\N	\N
12046	MEMBRE	2007-02-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11342	\N	\N	\N
12076	MEMBRE	2007-04-22 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11366	\N	\N	\N
12077	MEMBRE	2007-04-22 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11367	\N	\N	\N
12078	MEMBRE	2007-04-22 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11368	\N	\N	\N
12079	MEMBRE	2007-04-22 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11369	\N	\N	\N
12080	MEMBRE	2007-04-22 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11370	\N	\N	\N
12081	MEMBRE	2007-04-22 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11371	\N	\N	\N
12082	MEMBRE	2007-04-22 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11372	\N	\N	\N
12084	MEMBRE	2007-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11375	\N	\N	\N
12085	MEMBRE	2007-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11376	\N	\N	\N
12086	MEMBRE	2007-06-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11377	\N	\N	\N
12163	MEMBRE	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11446	\N	\N	\N
12164	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11447	\N	\N	\N
12167	VICPDT	2007-01-31 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10198	4	\N	\N
12186	MEMBRE	2007-10-01 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	11467	\N	\N	\N
12183	MEMBRE	2007-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11465	\N	\N	\N
12209	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11484	\N	\N	\N
12210	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11485	\N	\N	\N
12211	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11486	\N	\N	\N
12216	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11491	\N	\N	\N
12217	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11492	\N	\N	\N
12222	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11497	\N	\N	\N
12237	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11512	\N	\N	\N
12251	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11526	\N	\N	\N
12253	MEMBRE	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11528	\N	\N	\N
12728	PDT	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11808	1	\N	\N
12729	VICPDT	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2936	4	\N	\N
12730	VICPDT	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5265	5	\N	\N
12731	VICPDT	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2556	7	\N	\N
12732	VICPDT	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2477	8	\N	\N
12733	VICPDT	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11810	9	\N	\N
12734	SECRET	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11781	10	\N	\N
12735	SECRET	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11786	11	\N	\N
12736	SECRET	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11799	12	\N	\N
12737	MEMBRE	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5255	0	\N	\N
12738	MEMBRE	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2264	0	\N	\N
12739	PDT	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8909	1	\N	\N
12740	VICPDT	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11869	3	\N	\N
12741	VICPDT	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4881	4	\N	\N
12742	VICPDT	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9014	5	\N	\N
12743	VICPDT	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8925	6	\N	\N
12744	VICPDT	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11870	7	\N	\N
12745	SECRET	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11871	8	\N	\N
12746	SECRET	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8926	9	\N	\N
12747	SECRET	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11872	10	\N	\N
12748	SECRET	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4904	11	\N	\N
12749	MEMBRE	2008-12-09 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	2067	0	\N	\N
12750	MEMBRE	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2094	0	\N	\N
12751	MEMBRE	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	194	0	\N	\N
12752	MEMBRE	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1260	0	\N	\N
12753	MEMBRE	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4901	0	\N	\N
12754	MEMBRE	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6379	0	\N	\N
12755	MEMBRE	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4005	0	\N	\N
12756	MEMBRE	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1463	0	\N	\N
12757	MEMBRE	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	885	0	\N	\N
12758	MEMBRE	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4897	0	\N	\N
12759	MEMBRE	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2011	0	\N	\N
12760	VICPDT	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11873	3	\N	\N
12761	VICPDT	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11874	4	\N	\N
12762	VICPDT	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11875	5	\N	\N
13180	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12185	\N	\N	\N
13181	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12186	\N	\N	\N
13182	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12187	\N	\N	\N
13183	MEMBRE	2008-10-01 00:00:00	2009-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	12188	\N	\N	\N
13184	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12189	\N	\N	\N
13185	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12190	\N	\N	\N
13186	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12191	\N	\N	\N
13187	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12192	\N	\N	\N
13188	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12193	\N	\N	\N
13216	VICPDT	2009-01-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11285	8	\N	\N
13217	PDT	2007-02-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11300	1	\N	\N
13218	MEMBRE	2009-01-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11294	0	\N	\N
13219	MEMBRE	2009-01-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11316	0	\N	\N
13220	MEMBRE	2009-01-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11312	0	\N	\N
13221	MEMBRE	2009-01-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11287	0	\N	\N
13222	MEMBRE	2009-01-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11302	0	\N	\N
13223	MEMBRE	2009-01-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11317	0	\N	\N
13224	MEMBRE	2009-01-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11318	0	\N	\N
13225	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12220	\N	\N	\N
13226	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12221	\N	\N	\N
13227	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12222	\N	\N	\N
13228	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12223	\N	\N	\N
13229	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12224	\N	\N	\N
13230	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12225	\N	\N	\N
13231	MEMBRE	2008-10-01 00:00:00	2010-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	12226	\N	\N	\N
13232	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12227	\N	\N	\N
13233	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12228	\N	\N	\N
13234	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12229	\N	\N	\N
13235	MEMBRE	2008-10-01 00:00:00	2009-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	12230	\N	\N	\N
13236	MEMBRE	2008-10-01 00:00:00	2008-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	12231	\N	\N	\N
13237	MEMBRE	2008-10-01 00:00:00	2008-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	12232	\N	\N	\N
13238	MEMBRE	2008-10-01 00:00:00	2009-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	12233	\N	\N	\N
13239	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12234	\N	\N	\N
13240	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12235	\N	\N	\N
13241	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12236	\N	\N	\N
13242	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12237	\N	\N	\N
13243	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12238	\N	\N	\N
13244	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12239	\N	\N	\N
13245	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12240	\N	\N	\N
13246	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12241	\N	\N	\N
13247	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12242	\N	\N	\N
13248	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12243	\N	\N	\N
13249	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12244	\N	\N	\N
13250	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12245	\N	\N	\N
13251	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12246	\N	\N	\N
13252	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12247	\N	\N	\N
13253	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12248	\N	\N	\N
13254	MEMBRE	2008-10-01 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	12249	\N	\N	\N
13255	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12250	\N	\N	\N
13256	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12251	\N	\N	\N
13257	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12252	\N	\N	\N
13258	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12253	\N	\N	\N
13259	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12254	\N	\N	\N
13260	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12255	\N	\N	\N
13261	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12256	\N	\N	\N
13262	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12257	\N	\N	\N
13263	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12258	\N	\N	\N
13264	MEMBRE	2008-10-01 00:00:00	2010-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	12259	\N	\N	\N
13265	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12260	\N	\N	\N
13302	VICPDT	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12298	2	\N	\N
13303	VICPDT	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9695	3	\N	\N
13304	MEMBRE	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5847	0	\N	\N
13305	MEMBRE	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9692	0	\N	\N
13307	VICPDT	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12299	2	\N	\N
13308	VICPDT	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12300	6	\N	\N
13309	SECRET	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12301	11	\N	\N
13310	SECRET	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12302	13	\N	\N
13362	PDT	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8974	1	\N	\N
13363	VICPDT	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5554	2	\N	\N
12763	SECRET	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9773	6	\N	\N
12764	MEMBRE	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9784	0	\N	\N
12765	MEMBRE	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4485	0	\N	\N
12766	MEMBRE	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9783	0	\N	\N
12767	MEMBRE	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9775	0	\N	\N
12768	MEMBRE	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9780	0	\N	\N
12769	MEMBRE	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9785	0	\N	\N
12770	VICPDT	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5520	2	\N	\N
12771	VICPDT	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5528	3	\N	\N
12772	SECRET	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10814	4	\N	\N
12773	MEMBRE	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3276	0	\N	\N
12774	MEMBRE	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5531	0	\N	\N
13139	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12152	\N	\N	\N
13140	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12153	\N	\N	\N
13141	MEMBRE	2008-10-01 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	12154	\N	\N	\N
13142	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12155	\N	\N	\N
13143	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12156	\N	\N	\N
13144	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12157	\N	\N	\N
13145	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12158	\N	\N	\N
13146	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12159	\N	\N	\N
13147	MEMBRE	2008-10-01 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	12160	\N	\N	\N
13148	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12161	\N	\N	\N
13149	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12162	\N	\N	\N
13364	VICPDT	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11974	4	\N	\N
13365	SECRET	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11972	6	\N	\N
13366	SECRET	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11975	7	\N	\N
13367	MEMBRE	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5556	0	\N	\N
13368	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12350	\N	\N	\N
13369	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12351	\N	\N	\N
13370	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12352	\N	\N	\N
13385	VICPDT	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4254	2	\N	\N
13386	VICPDT	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11848	4	\N	\N
13387	VICPDT	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11638	5	\N	\N
13388	VICPDT	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11850	6	\N	\N
13389	VICPDT	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10274	7	\N	\N
12626	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11766	\N	\N	\N
12627	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11767	\N	\N	\N
12628	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11768	\N	\N	\N
12629	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11769	\N	\N	\N
12635	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11776	\N	\N	\N
12636	MEMBRE	2008-10-01 00:00:00	2009-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	11777	0	\N	\N
12637	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11778	\N	\N	\N
12638	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11779	\N	\N	\N
12639	MEMBRE	2008-10-01 00:00:00	2010-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	11780	\N	\N	\N
12640	MEMBRE	2008-10-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	11781	\N	\N	\N
12641	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11782	\N	\N	\N
12642	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11783	\N	\N	\N
12643	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11784	\N	\N	\N
12644	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11785	\N	\N	\N
12645	MEMBRE	2008-10-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	11786	\N	\N	\N
12646	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11787	\N	\N	\N
12647	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11788	\N	\N	\N
12648	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11789	\N	\N	\N
12649	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11790	\N	\N	\N
12650	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11791	\N	\N	\N
12651	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11792	\N	\N	\N
12652	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11793	\N	\N	\N
12653	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11794	\N	\N	\N
12654	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11795	\N	\N	\N
12655	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11796	\N	\N	\N
12656	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11797	\N	\N	\N
12657	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11798	\N	\N	\N
12658	MEMBRE	2008-10-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	11799	\N	\N	\N
12659	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11800	\N	\N	\N
12660	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11801	\N	\N	\N
12661	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11802	\N	\N	\N
12662	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11803	\N	\N	\N
12663	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11804	\N	\N	\N
12664	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11805	\N	\N	\N
12665	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11806	\N	\N	\N
12666	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11807	\N	\N	\N
12667	MEMBRE	2008-10-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	11808	\N	\N	\N
12668	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11809	\N	\N	\N
12669	MEMBRE	2008-10-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	11810	\N	\N	\N
12670	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11811	\N	\N	\N
12671	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11812	\N	\N	\N
12672	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11813	\N	\N	\N
12673	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11814	0	\N	\N
12674	MEMBRE	2008-10-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	11815	0	\N	\N
12675	MEMBRE	2008-10-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	11816	0	\N	\N
12676	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11817	0	\N	\N
12677	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11818	0	\N	\N
12678	MEMBRE	2008-10-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	11819	0	\N	\N
12679	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11820	0	\N	\N
12680	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11821	0	\N	\N
12681	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11822	0	\N	\N
12682	MEMBRE	2008-10-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	11823	0	\N	\N
12683	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11824	0	\N	\N
12684	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11825	0	\N	\N
12685	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11826	0	\N	\N
12686	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11827	0	\N	\N
12687	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11828	0	\N	\N
12688	MEMBRE	2008-10-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	11829	0	\N	\N
12689	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11830	0	\N	\N
12690	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11831	0	\N	\N
12691	MEMBRE	2008-10-01 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	\N	11832	0	\N	\N
12692	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11833	0	\N	\N
12693	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11834	\N	\N	\N
12694	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11835	\N	\N	\N
12695	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11836	\N	\N	\N
12696	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11837	\N	\N	\N
12697	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11838	\N	\N	\N
12698	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11839	\N	\N	\N
12699	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11840	\N	\N	\N
12700	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11841	\N	\N	\N
12702	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11843	\N	\N	\N
12703	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11844	\N	\N	\N
12704	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11845	\N	\N	\N
12705	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11846	\N	\N	\N
12706	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11847	\N	\N	\N
12707	MEMBRE	2008-10-01 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	11848	0	\N	\N
12708	MEMBRE	2008-10-01 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	11849	0	\N	\N
12709	MEMBRE	2008-10-01 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	11850	0	\N	\N
12710	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11851	\N	\N	\N
12711	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11852	\N	\N	\N
12712	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11853	\N	\N	\N
12713	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11854	\N	\N	\N
12714	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11855	\N	\N	\N
12715	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11856	\N	\N	\N
12716	MEMBRE	2008-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	11857	\N	\N	\N
12717	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11858	\N	\N	\N
12718	MEMBRE	2008-10-01 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	11859	0	\N	\N
12719	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11860	\N	\N	\N
12720	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11861	\N	\N	\N
12721	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11862	\N	\N	\N
12722	MEMBRE	2008-10-01 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	11863	0	\N	\N
12723	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11864	\N	\N	\N
12724	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11865	\N	\N	\N
12725	MEMBRE	2008-10-01 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	\N	11866	\N	\N	\N
12726	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11867	\N	\N	\N
12727	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11868	\N	\N	\N
12775	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11876	\N	\N	\N
12776	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11877	\N	\N	\N
12777	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11878	\N	\N	\N
12778	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11879	\N	\N	\N
12779	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11880	\N	\N	\N
12780	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11881	\N	\N	\N
12781	MEMBRE	2008-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	11882	\N	\N	\N
12782	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11883	\N	\N	\N
12783	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11884	\N	\N	\N
12784	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11885	\N	\N	\N
12785	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11886	\N	\N	\N
12786	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11887	\N	\N	\N
12787	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11888	\N	\N	\N
12788	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11889	\N	\N	\N
12789	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11890	\N	\N	\N
12790	MEMBRE	2008-10-01 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	11891	0	\N	\N
12791	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11892	\N	\N	\N
12792	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11893	\N	\N	\N
12793	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11894	\N	\N	\N
12794	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11895	\N	\N	\N
12795	MEMBRE	2008-10-01 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	11896	\N	\N	\N
12796	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11897	\N	\N	\N
12797	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11898	\N	\N	\N
12798	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11899	\N	\N	\N
12799	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11900	\N	\N	\N
12800	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11901	\N	\N	\N
13208	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12213	\N	\N	\N
13209	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12214	\N	\N	\N
13210	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12215	\N	\N	\N
13211	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12216	\N	\N	\N
13343	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12333	\N	\N	\N
13344	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12334	\N	\N	\N
13345	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12335	\N	\N	\N
13346	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12336	\N	\N	\N
13347	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12337	\N	\N	\N
13348	MEMBRE	2008-10-01 00:00:00	2010-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	12338	\N	\N	\N
13351	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12340	\N	\N	\N
13353	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12341	\N	\N	\N
13354	MEMBRE	2008-10-01 00:00:00	2009-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	12342	\N	\N	\N
13355	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12343	\N	\N	\N
13356	MEMBRE	2008-10-01 00:00:00	2009-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	12344	0	\N	\N
13357	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12345	\N	\N	\N
13358	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12346	\N	\N	\N
13359	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12347	\N	\N	\N
13360	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12348	\N	\N	\N
13361	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12349	\N	\N	\N
13428	VICPDT	2009-01-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11777	3	\N	\N
13429	VICPDT	2009-01-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10806	6	\N	\N
13473	VICPDT	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9114	4	\N	\N
13475	VICPDTDRT	2008-12-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Brésil	\N	12389	4	\N	\N
13476	VICPDTDRT	2008-12-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Mexique et pays d'Amérique centrale	\N	12390	3	\N	\N
13477	VICPDT	2008-12-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11967	7	\N	\N
13478	VICPDT	2008-12-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2438	8	\N	\N
13479	VICPDT	2008-12-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8842	9	\N	\N
13480	VICPDT	2008-12-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4664	10	\N	\N
13481	SECRET	2008-12-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11966	12	\N	\N
13482	SECRET	2008-12-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11950	13	\N	\N
13483	SECRET	2008-12-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11963	14	\N	\N
13484	SECRET	2008-12-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11961	15	\N	\N
13485	MEMBRE	2008-12-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	889	0	\N	\N
13486	MEMBRE	2008-12-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3530	0	\N	\N
13487	MEMBRE	2008-12-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6544	0	\N	\N
13488	MEMBRE	2008-12-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2247	0	\N	\N
13491	MEMBREBUR	2008-12-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12083	8	\N	\N
13492	MEMBREBUR	2008-12-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12089	12	\N	\N
13493	MEMBREBUR	2008-12-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4671	13	\N	\N
13494	MEMBREBUR	2008-12-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12092	14	\N	\N
13495	PDT	2009-01-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12392	1	\N	\N
13496	PDTHON	2009-01-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2517	2	\N	\N
13497	VICPDT	2009-01-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12393	3	\N	\N
13498	VICPDT	2009-01-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10324	4	\N	\N
13499	VICPDT	2009-01-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12394	5	\N	\N
13500	VICPDT	2009-01-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2399	6	\N	\N
13501	VICPDT	2009-01-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12395	7	\N	\N
13502	SECRET	2009-01-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12396	9	\N	\N
13503	SECRET	2009-01-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12397	10	\N	\N
13266	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12261	\N	\N	\N
13267	MEMBRE	2008-10-01 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	12262	\N	\N	\N
13268	MEMBRE	2008-10-01 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	12263	\N	\N	\N
13269	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12264	\N	\N	\N
13270	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12265	\N	\N	\N
13271	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12266	\N	\N	\N
13272	MEMBRE	2008-10-01 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	12267	\N	\N	\N
13273	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12268	\N	\N	\N
13274	MEMBRE	2008-10-01 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	12269	\N	\N	\N
13275	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12270	\N	\N	\N
13276	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12271	\N	\N	\N
13277	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12272	\N	\N	\N
13278	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12273	\N	\N	\N
13279	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12274	\N	\N	\N
13280	MEMBRE	2008-10-01 00:00:00	2009-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	12275	0	\N	\N
13281	MEMBRE	2008-10-01 00:00:00	2009-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	12276	0	\N	\N
13282	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12277	\N	\N	\N
13283	MEMBRE	2008-10-01 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	12278	\N	\N	\N
13284	MEMBRE	2008-10-01 00:00:00	2009-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	12279	\N	\N	\N
13285	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12280	\N	\N	\N
13286	MEMBRE	2008-10-01 00:00:00	2009-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	12281	0	\N	\N
13287	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12282	\N	\N	\N
13288	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12283	\N	\N	\N
13289	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12284	\N	\N	\N
13290	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12285	\N	\N	\N
13291	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12286	\N	\N	\N
13292	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12287	\N	\N	\N
13293	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12288	\N	\N	\N
13294	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12289	\N	\N	\N
13295	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12290	\N	\N	\N
13296	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12291	\N	\N	\N
13297	MEMBRE	2008-10-01 00:00:00	2009-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	12292	0	\N	\N
13298	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12293	\N	\N	\N
13299	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12294	\N	\N	\N
13300	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12296	\N	\N	\N
13301	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12297	\N	\N	\N
13431	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9573	\N	\N	\N
13507	MEMBRE	2009-01-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4981	\N	\N	\N
13508	MEMBRE	2009-01-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1249	\N	\N	\N
13504	SECRET	2009-01-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12398	11	\N	\N
13505	SECRET	2009-01-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12399	12	\N	\N
13506	SECRET	2009-01-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2422	13	\N	\N
13509	MEMBRE	2009-01-06 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	4963	\N	\N	\N
13510	MEMBRE	2009-01-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10329	\N	\N	\N
13446	SECRET	2009-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12380	7	\N	\N
13447	SECRET	2009-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12381	8	\N	\N
13448	SECRET	2009-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5481	9	\N	\N
13449	SECRET	2009-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12382	10	\N	\N
13450	MEMBRE	2009-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4265	0	\N	\N
13451	MEMBRE	2009-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6605	0	\N	\N
13452	MEMBRE	2009-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8944	0	\N	\N
13453	MEMBRE	2009-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8940	0	\N	\N
13454	VICPDT	2009-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5475	4	\N	\N
13455	MEMBRE	2009-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4299	0	\N	\N
13554	MEMBRE	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1423	0	\N	\N
13457	VICPDT	2008-12-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12231	3	\N	\N
13458	VICPDT	2008-12-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12232	4	\N	\N
13459	MEMBRE	2008-12-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5227	0	\N	\N
13460	MEMBRE	2008-12-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9863	0	\N	\N
13461	VICPDT	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12385	3	\N	\N
13462	SECRET	2008-12-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10572	4	\N	\N
13463	SECRET	2008-12-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10287	5	\N	\N
13464	MEMBREBUR	2008-12-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11101	6	\N	\N
13465	MEMBRE	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10291	0	\N	\N
13466	MEMBRE	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6453	0	\N	\N
13467	PDTDEL	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Comores	\N	10526	5	\N	\N
13469	PDTDEL	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Tanzanie	\N	12387	9	\N	\N
13470	PDTDEL	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Mozambique	\N	10527	8	\N	\N
13471	MEMBRE	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6378	0	\N	\N
13472	MEMBRE	2008-12-09 00:00:00	2010-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	10519	0	\N	\N
13552	MEMBRE	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2569	0	\N	\N
13553	MEMBRE	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2021	0	\N	\N
13522	MEMBREBUR	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10289	8	\N	\N
13555	MEMBRE	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2515	0	\N	\N
13556	MEMBRE	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2228	0	\N	\N
13560	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12425	\N	\N	\N
13513	VICPDT	2008-12-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12401	5	\N	\N
13514	VICPDT	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9380	2	\N	\N
13515	VICPDT	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2611	6	\N	\N
13516	VICPDT	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6029	7	\N	\N
13517	VICPDT	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6030	8	\N	\N
13518	SECRET	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9381	10	\N	\N
13519	SECRET	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11113	11	\N	\N
13520	SECRET	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12174	13	\N	\N
13521	SECRET	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9407	14	\N	\N
13523	MEMBRE	2009-01-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12402	\N	\N	\N
13524	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12403	\N	\N	\N
13525	MEMBRE	2009-01-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12404	\N	\N	\N
13526	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12405	\N	\N	\N
13527	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12406	\N	\N	\N
13528	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12407	\N	\N	\N
13529	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12408	\N	\N	\N
13530	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12409	\N	\N	\N
13531	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12410	\N	\N	\N
13532	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12411	\N	\N	\N
13533	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12412	\N	\N	\N
13534	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12413	\N	\N	\N
13535	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12414	\N	\N	\N
13536	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12415	\N	\N	\N
13537	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12416	\N	\N	\N
13538	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12417	\N	\N	\N
13559	MEMBRE	2008-10-01 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	12424	\N	\N	\N
10982	MEMBRE	2005-03-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10420	\N	\N	\N
11008	MEMBRE	2005-03-15 00:00:00	2005-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	10446	\N	\N	\N
11016	SECRET	2005-03-18 00:00:00	2005-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	10432	\N	\N	\N
11025	MEMBRE	2004-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	10455	\N	\N	\N
11069	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10489	\N	\N	\N
11077	MEMBREBUR	2004-10-01 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	10497	14	\N	\N
10505	MEMBRE	2004-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	10083	\N	\N	\N
10539	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10122	\N	\N	\N
10548	VICPDT	2004-11-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6349	8	\N	\N
10578	MEMBREBUR	2005-01-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7596	\N	\N	\N
10586	VICPDT	2004-12-08 00:00:00	2008-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	2883	5	\N	\N
10717	VICPDT	2004-10-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10205	\N	\N	\N
11423	MEMBRE	2005-09-09 00:00:00	2009-02-28 00:00:00	ANCIEN	\N	\N	\N	\N	10774	\N	\N	\N
11435	PDT	2005-09-20 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10782	\N	\N	\N
11444	MEMBRE	2005-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10791	\N	\N	\N
11476	MEMBRE	2005-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10823	\N	\N	\N
11482	MEMBRE	2005-12-16 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	10829	\N	\N	\N
11488	MEMBRE	2005-12-01 00:00:00	2009-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	10835	\N	\N	\N
11527	MEMBRE	2005-12-01 00:00:00	2006-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	10834	\N	\N	\N
11566	MEMBRE	2006-02-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10904	\N	\N	\N
11572	MEMBRE	2006-02-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10910	\N	\N	\N
11604	MEMBRE	2006-02-01 00:00:00	2009-09-09 00:00:00	ANCIEN	\N	\N	\N	\N	10938	\N	\N	\N
11610	MEMBRE	2006-02-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10944	\N	\N	\N
11616	MEMBRE	2006-01-31 00:00:00	2009-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	10950	\N	\N	\N
11658	MEMBRE	2006-03-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10988	\N	\N	\N
11665	MEMBRE	2006-03-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10993	\N	\N	\N
12137	MEMBRE	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11421	\N	\N	\N
12138	MEMBRE	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11422	\N	\N	\N
12139	MEMBRE	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11423	\N	\N	\N
12140	MEMBRE	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11424	\N	\N	\N
12141	MEMBRE	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11425	\N	\N	\N
12143	MEMBRE	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11427	\N	\N	\N
12144	MEMBRE	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11428	\N	\N	\N
12145	MEMBRE	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11429	\N	\N	\N
12146	MEMBRE	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11430	\N	\N	\N
12147	MEMBRE	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11431	\N	\N	\N
12148	MEMBRE	2007-06-01 00:00:00	2010-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	11432	\N	\N	\N
12149	MEMBRE	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11433	\N	\N	\N
12150	MEMBRE	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11434	\N	\N	\N
12152	MEMBRE	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11436	\N	\N	\N
12153	MEMBRE	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11437	\N	\N	\N
12154	MEMBRE	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11438	\N	\N	\N
12155	MEMBRE	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11439	\N	\N	\N
12156	MEMBRE	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11440	\N	\N	\N
12157	MEMBRE	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11441	\N	\N	\N
12158	MEMBRE	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11442	\N	\N	\N
12159	MEMBRE	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11443	\N	\N	\N
12160	MEMBRE	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11444	\N	\N	\N
12383	MEMBRE	2008-02-22 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11629	\N	\N	\N
12389	MEMBRE	2008-02-22 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	11635	\N	\N	\N
12467	MEMBRE	2008-05-19 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11699	\N	\N	\N
12468	MEMBRE	2008-05-19 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11700	\N	\N	\N
12470	MEMBRE	2008-05-19 00:00:00	2009-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	11702	0	\N	\N
12471	MEMBRE	2008-05-19 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	11703	\N	\N	\N
12472	MEMBRE	2008-05-19 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11704	\N	\N	\N
12473	MEMBRE	2008-05-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11705	\N	\N	\N
12474	MEMBRE	2008-05-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11706	\N	\N	\N
12613	PDT	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9803	1	\N	\N
12616	VICPDT	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9802	6	\N	\N
12617	VICPDT	2008-12-16 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	9906	7	\N	\N
12618	SECRET	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5427	9	\N	\N
12619	SECRET	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9791	10	\N	\N
12620	SECRET	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11763	11	\N	\N
12621	SECRET	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11764	13	\N	\N
12622	MEMBRE	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1266	0	\N	\N
12623	MEMBRE	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5387	0	\N	\N
2828	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2858	\N	\N	\N
2693	PDT	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2711	1	\N	\N
12521	SECRET	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10492	9	\N	\N
12522	SECRET	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10497	10	\N	\N
12523	SECRET	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6516	11	\N	\N
12094	MEMBRE	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11378	\N	\N	\N
12405	MEMBRE	2008-01-01 00:00:00	2011-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	11642	\N	\N	2015-11-12 15:26:22
12524	SECRET	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5152	12	\N	\N
18131	MEMBRE	2011-10-01 00:00:00	2012-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	16335	\N	\N	\N
12526	SECRET	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11729	14	\N	\N
12527	SECRET	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11730	15	\N	\N
12528	MEMBRE	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10486	0	\N	\N
12529	MEMBRE	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5170	0	\N	\N
12530	MEMBRE	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5162	0	\N	\N
12531	MEMBRE	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5178	0	\N	\N
12539	PDT	2008-12-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6383	1	\N	\N
12541	VICPDT	2008-12-04 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	9557	3	\N	\N
12542	VICPDT	2008-12-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9558	4	\N	\N
12543	VICPDT	2008-12-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11735	5	\N	\N
12544	SECRET	2008-12-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11736	6	\N	\N
12546	SECRET	2008-12-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11739	8	\N	\N
12547	MEMBRE	2008-12-04 00:00:00	2010-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	6265	0	\N	\N
12548	MEMBRE	2008-12-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9562	0	\N	\N
12549	VICPDT	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11740	2	\N	\N
12550	VICPDT	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11345	3	\N	\N
12551	SECRET	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11741	4	\N	\N
12552	MEMBRE	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5741	0	\N	\N
12553	MEMBRE	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5709	0	\N	\N
12558	VICPDT	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3168	4	\N	\N
12555	MEMBRE	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5708	\N	\N	\N
12556	MEMBRE	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3801	\N	\N	\N
12557	VICPDT	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3163	3	\N	\N
12559	SECRET	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11742	5	\N	\N
12560	SECRET	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11743	7	\N	\N
12562	SECRET	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8878	9	\N	\N
12563	SECRET	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11745	10	\N	\N
12564	MEMBRE	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3166	\N	\N	\N
12565	MEMBRE	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8863	\N	\N	\N
12566	MEMBRE	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8865	\N	\N	\N
12567	MEMBRE	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3164	\N	\N	\N
11934	MEMBRE	2004-10-01 00:00:00	2007-02-25 00:00:00	ANCIEN	\N	\N	\N	\N	11236	\N	\N	\N
11848	SECRET	2006-11-15 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	11129	\N	\N	\N
11919	MEMBRE	2007-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11222	\N	\N	\N
11935	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11237	\N	\N	\N
11937	MEMBRE	2001-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	11239	\N	\N	\N
12569	VICPDT	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11746	4	\N	\N
12570	VICPDT	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11747	6	\N	\N
12571	VICPDT	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3041	7	\N	\N
12572	SECRET	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1059	9	\N	\N
12573	SECRET	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11748	11	\N	\N
12574	MEMBRE	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1893	\N	\N	\N
12575	VICPDT	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8804	2	\N	\N
12576	VICPDT	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11749	3	\N	\N
12577	VICPDT	2008-12-10 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	8812	5	\N	\N
12578	SECRET	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11750	8	\N	\N
12579	SECRET	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11751	9	\N	\N
12581	SECRET	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5804	11	\N	\N
12583	SECRET	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8820	13	\N	\N
12584	TRESORADJ	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8806	15	\N	\N
12585	TRESORADJ	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11753	16	\N	\N
12586	MEMBRE	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5802	\N	\N	\N
12587	MEMBRE	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8807	\N	\N	\N
12588	MEMBRE	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8813	\N	\N	\N
12589	MEMBRE	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2029	\N	\N	\N
12590	MEMBRE	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1999	\N	\N	\N
10750	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10242	\N	\N	\N
10798	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10272	\N	\N	\N
10834	MEMBRE	2005-02-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10301	\N	\N	\N
10878	MEMBRE	2004-10-01 00:00:00	2005-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	10349	\N	\N	\N
10919	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10393	\N	\N	\N
10962	MEMBRE	2005-02-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1928	\N	\N	\N
12056	MEMBRE	2007-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11347	\N	\N	\N
12185	MEMBRE	2007-10-01 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	11466	\N	\N	\N
12591	VICPDT	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11754	3	\N	\N
12592	VICPDT	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11755	4	\N	\N
12593	VICPDT	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11709	5	\N	\N
12594	VICPDT	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11756	6	\N	\N
12595	VICPDT	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11757	8	\N	\N
12596	VICPDT	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11758	9	\N	\N
12597	SECRET	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11759	10	\N	\N
12598	SECRET	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11760	11	\N	\N
12599	MEMBRE	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5328	0	\N	\N
12600	MEMBRE	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5327	0	\N	\N
12601	MEMBRE	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5332	0	\N	\N
12602	MEMBRE	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3507	0	\N	\N
12603	VICPDT	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11761	3	\N	\N
12604	VICPDT	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9916	4	\N	\N
12605	VICPDT	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9923	7	\N	\N
12606	VICPDT	2008-12-10 00:00:00	2009-10-26 00:00:00	ANCIEN	\N	\N	\N	\N	11703	7	\N	\N
12607	SECRET	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11762	9	\N	\N
12608	SECRET	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3368	10	\N	\N
12609	SECRET	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9921	11	\N	\N
12610	MEMBRE	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9917	0	\N	\N
12611	MEMBRE	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9918	0	\N	\N
12612	MEMBRE	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1274	0	\N	\N
12614	VICPDT	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9801	3	\N	\N
12615	VICPDT	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1431	4	\N	\N
7701	MEMBRE	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	7721	\N	\N	\N
8595	MEMBRE	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8468	\N	\N	\N
8603	MEMBRE	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8476	\N	\N	\N
8610	MEMBRE	2003-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8483	\N	\N	\N
8659	MEMBRE	2004-01-29 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8524	\N	\N	\N
11767	MEMBRE	2006-06-01 00:00:00	2009-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	11090	0	\N	\N
11777	PDT	2006-09-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11037	\N	\N	\N
7699	MEMBRE	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	7719	\N	\N	\N
7700	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7720	\N	\N	\N
14614	MEMBRE	2009-02-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11093	\N	\N	\N
11782	SECRET	2006-09-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11060	\N	\N	\N
14620	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13171	\N	\N	\N
14659	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13194	\N	\N	\N
11921	MEMBRE	2007-01-17 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11223	\N	\N	\N
12386	MEMBRE	2008-02-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11632	\N	\N	\N
12391	MEMBRE	2008-02-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8494	\N	\N	\N
12392	MEMBRE	2008-02-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8500	\N	\N	\N
12393	MEMBRE	2008-02-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8501	\N	\N	\N
12394	MEMBRE	2008-02-26 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8503	\N	\N	\N
8764	MEMBREBUR	2004-11-12 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8601	\N	\N	\N
8771	MEMBRE	2004-10-19 00:00:00	2007-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	8611	\N	\N	\N
9477	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9251	\N	\N	\N
9484	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9258	\N	\N	\N
9524	MEMBRE	2004-10-01 00:00:00	2009-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	9303	\N	\N	\N
9564	MEMBRE	2004-10-01 00:00:00	2009-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	9338	0	\N	\N
9646	MEMBRE	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	9411	\N	\N	\N
9682	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9442	\N	\N	\N
9691	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9451	\N	\N	\N
9724	MEMBRE	2004-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9482	\N	\N	\N
9731	SECRET	2004-11-10 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	9014	\N	\N	\N
9211	MEMBRE	2004-10-01 00:00:00	2009-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	9018	\N	\N	\N
9216	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9023	\N	\N	\N
9222	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9029	\N	\N	\N
11948	MEMBRE	2007-01-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11250	\N	\N	\N
11949	MEMBRE	2007-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11251	\N	\N	\N
11950	PDT	2007-01-15 00:00:00	2009-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	11252	1	\N	\N
11951	MEMBRE	2007-01-15 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	11253	\N	\N	\N
11952	SECRET	2007-01-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11254	6	\N	\N
11953	MEMBRE	2007-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11255	\N	\N	\N
11954	MEMBRE	2007-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11256	\N	\N	\N
11955	VICPDT	2007-01-15 00:00:00	2009-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	11257	2	\N	\N
11956	MEMBRE	2007-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11258	\N	\N	\N
11957	MEMBRE	2007-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11259	\N	\N	\N
11958	MEMBRE	2007-01-15 00:00:00	2008-04-18 00:00:00	ANCIEN	\N	\N	\N	\N	11260	\N	\N	\N
11959	VICPDT	2007-01-15 00:00:00	2009-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	11261	3	\N	\N
11960	SECRET	2007-01-15 00:00:00	2009-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	11262	7	\N	\N
11961	MEMBRE	2007-01-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11263	\N	\N	\N
11962	MEMBRE	2007-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11264	\N	\N	\N
11963	MEMBRE	2007-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11265	\N	\N	\N
11964	MEMBRE	2007-01-15 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	11266	\N	\N	\N
11965	VICPDT	2007-01-15 00:00:00	2009-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	11267	4	\N	\N
11966	MEMBREBUR	2007-01-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11268	9	\N	\N
11968	MEMBRE	2007-01-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11270	\N	\N	\N
11969	SECRET	2007-01-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11271	8	\N	\N
11970	MEMBRE	2007-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11272	\N	\N	\N
11971	MEMBRE	2007-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11273	\N	\N	\N
11972	SECRET	2007-01-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11274	5	\N	\N
11973	MEMBRE	2007-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11275	\N	\N	\N
12048	MEMBRE	2007-03-07 00:00:00	2010-09-25 00:00:00	ANCIEN	\N	\N	\N	\N	11344	\N	\N	2015-11-12 15:26:22
12049	MEMBRE	2007-02-13 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	11345	0	\N	\N
12051	VICPDT	2007-04-04 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9531	\N	\N	\N
12053	MEMBRE	2007-04-04 00:00:00	2007-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	11346	\N	\N	\N
12054	VICPDT	2007-04-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11346	\N	\N	\N
12055	SECRET	2007-04-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9539	\N	\N	\N
12057	MEMBRE	2007-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11348	\N	\N	\N
12180	MEMBRE	2007-07-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11462	\N	\N	\N
12181	MEMBRE	2007-07-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11463	\N	\N	\N
12195	MEMBRE	2007-10-01 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	11470	\N	\N	\N
12254	MEMBRE	2006-09-01 00:00:00	2007-11-13 00:00:00	ANCIEN	\N	\N	\N	\N	11529	\N	\N	\N
12255	MEMBRE	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11530	\N	\N	\N
12256	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11531	\N	\N	\N
12257	MEMBRE	2006-09-01 00:00:00	2009-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	11532	\N	\N	\N
12258	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11533	\N	\N	\N
12259	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11534	\N	\N	\N
12260	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11535	\N	\N	\N
12262	MEMBRE	2006-09-01 00:00:00	2007-11-13 00:00:00	ANCIEN	\N	\N	\N	\N	11537	\N	\N	\N
12264	MEMBRE	2006-09-01 00:00:00	2008-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	11539	\N	\N	\N
12265	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11540	\N	\N	\N
12266	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11541	\N	\N	\N
12267	MEMBRE	2006-09-01 00:00:00	2007-11-13 00:00:00	ANCIEN	\N	\N	\N	\N	11542	\N	\N	\N
12268	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11543	\N	\N	\N
12269	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11544	\N	\N	\N
12270	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11545	\N	\N	\N
12272	MEMBRE	2006-09-01 00:00:00	2007-11-13 00:00:00	ANCIEN	\N	\N	\N	\N	11547	\N	\N	\N
12320	MEMBRE	2007-11-01 00:00:00	2009-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	11594	0	\N	\N
12321	PDT	2007-11-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11500	\N	\N	\N
12322	VICPDT	2007-11-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11537	\N	\N	\N
12323	VICPDT	2007-11-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11529	\N	\N	\N
12324	VICPDT	2007-11-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11542	\N	\N	\N
12325	VICPDT	2007-11-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11547	\N	\N	\N
12370	MEMBRE	2008-02-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11617	\N	\N	\N
12372	MEMBRE	2008-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11619	\N	\N	\N
12373	MEMBRE	2008-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11620	\N	\N	\N
12374	MEMBRE	2008-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11621	\N	\N	\N
12377	VICPDT	2004-11-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5303	6	\N	\N
12462	MEMBRE	2008-05-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11694	\N	\N	\N
8225	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8156	\N	\N	\N
8235	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8166	\N	\N	\N
8242	MEMBRE	2001-10-01 00:00:00	2009-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	8173	\N	\N	\N
8272	MEMBRE	2001-10-01 00:00:00	2008-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	8202	\N	\N	\N
8280	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8210	\N	\N	\N
12801	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11902	\N	\N	\N
12802	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11903	\N	\N	\N
12803	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11904	\N	\N	\N
12804	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11905	\N	\N	\N
12805	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11906	\N	\N	\N
12806	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11907	\N	\N	\N
12807	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11908	\N	\N	\N
12808	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11909	\N	\N	\N
12809	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11910	\N	\N	\N
12810	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4753	\N	\N	\N
12811	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11912	\N	\N	\N
12812	MEMBRE	2008-10-01 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	11913	\N	\N	\N
12813	MEMBRE	2008-10-01 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	11914	0	\N	\N
12814	MEMBRE	2008-10-01 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	11915	0	\N	\N
12815	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11916	\N	\N	\N
12816	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11917	\N	\N	\N
12817	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11918	\N	\N	\N
12818	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11919	\N	\N	\N
12819	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11920	\N	\N	\N
12820	MEMBRE	2008-10-01 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	\N	11921	\N	\N	\N
12821	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11922	\N	\N	\N
12822	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11923	\N	\N	\N
12873	VICPDT	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9812	3	\N	\N
12874	VICPDT	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11914	4	\N	\N
12877	SECRET	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11915	7	\N	\N
12881	MEMBRE	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2481	0	\N	\N
12882	MEMBRE	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4775	0	\N	\N
12883	MEMBRE	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9814	0	\N	\N
12884	PDT	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10022	1	\N	\N
12885	VICPDT	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10020	2	\N	\N
13938	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12696	\N	\N	\N
13939	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12697	\N	\N	\N
13940	MEMBRE	2008-10-01 00:00:00	2010-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	12698	\N	\N	\N
13941	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12699	\N	\N	\N
13942	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12700	\N	\N	\N
13943	MEMBRE	2008-10-01 00:00:00	2009-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	12701	\N	\N	\N
13945	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12703	\N	\N	\N
13946	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12704	\N	\N	\N
13947	MEMBRE	2008-10-01 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	12705	\N	\N	\N
13948	MEMBRE	2008-10-01 00:00:00	2009-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	12706	\N	\N	\N
13950	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12707	\N	\N	\N
13952	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12710	\N	\N	\N
11816	MEMBRE	2006-11-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11132	\N	\N	\N
3441	MEMBRE	1999-01-01 00:00:00	2004-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	3507	\N	\N	\N
13955	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12713	\N	\N	\N
13956	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12714	\N	\N	\N
13957	MEMBRE	2008-10-01 00:00:00	2009-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	12715	\N	\N	\N
13958	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12716	\N	\N	\N
13959	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12717	\N	\N	\N
13960	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12718	\N	\N	\N
13961	MEMBRE	2008-10-01 00:00:00	2009-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	12719	\N	\N	\N
14011	MEMBRE	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4944	\N	\N	\N
14012	MEMBRE	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10174	\N	\N	\N
14013	MEMBRE	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4945	\N	\N	\N
14014	MEMBRE	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4955	\N	\N	\N
14055	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12767	\N	\N	\N
14062	PDT	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12769	1	\N	\N
14063	PDT	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12770	1	\N	\N
14111	VICPDT	2009-02-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5231	6	\N	\N
14112	VICPDT	2009-02-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1914	7	\N	\N
14113	VICPDT	2009-02-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12230	8	\N	\N
14114	SECRET	2009-02-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1057	9	\N	\N
14115	SECRET	2009-02-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5203	10	\N	\N
14116	SECRET	2009-02-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12233	12	\N	\N
14117	MEMBRE	2008-10-01 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	12804	\N	\N	\N
14118	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12805	\N	\N	\N
14119	VICPDT	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12568	3	\N	\N
14120	VICPDT	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2640	4	\N	\N
14121	SECRET	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11459	5	\N	\N
14122	TRESOR	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11460	8	\N	\N
14123	SECRET	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12569	6	\N	\N
14124	SECRET	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2016	7	\N	\N
14125	PDTDEL	2009-02-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Angola	\N	1527	2	\N	\N
14126	PDTDEL	2009-02-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Botswana	\N	12279	3	\N	\N
14135	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12808	\N	\N	\N
14136	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12809	\N	\N	\N
14137	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12810	\N	\N	\N
8740	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8589	\N	\N	\N
14138	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12811	\N	\N	\N
3473	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3541	\N	\N	\N
13622	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12448	\N	\N	\N
13623	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12449	\N	\N	\N
13624	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12450	\N	\N	\N
13625	MEMBRE	2008-10-01 00:00:00	2009-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	12451	\N	\N	\N
13626	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12452	\N	\N	\N
13627	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12453	\N	\N	\N
13628	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12454	\N	\N	\N
13629	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12455	\N	\N	\N
13630	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12456	\N	\N	\N
13631	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12457	\N	\N	\N
13632	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12458	\N	\N	\N
13633	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12459	\N	\N	\N
13634	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12460	\N	\N	\N
13635	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12461	\N	\N	\N
14142	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12815	\N	\N	\N
13637	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12463	\N	\N	\N
13638	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12464	\N	\N	\N
13639	MEMBRE	2008-10-01 00:00:00	2009-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	12465	\N	\N	\N
13640	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12466	\N	\N	\N
13641	MEMBRE	2008-10-01 00:00:00	2009-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	12467	\N	\N	\N
13642	MEMBRE	2008-10-01 00:00:00	2009-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	12468	\N	\N	\N
13643	MEMBRE	2008-10-01 00:00:00	2009-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	12469	\N	\N	\N
13644	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12470	\N	\N	\N
13645	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12471	\N	\N	\N
13646	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12472	\N	\N	\N
13647	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12473	\N	\N	\N
13648	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12474	\N	\N	\N
13649	MEMBRE	2008-10-01 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	\N	12475	\N	\N	\N
13650	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9311	\N	\N	\N
14140	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12813	\N	\N	\N
14141	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12814	\N	\N	\N
14143	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12816	\N	\N	\N
14144	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12817	\N	\N	\N
14145	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12818	\N	\N	\N
14146	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12819	\N	\N	\N
14147	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12820	\N	\N	\N
14049	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12761	\N	\N	\N
14050	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12762	\N	\N	\N
14148	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12821	\N	\N	\N
14149	MEMBRE	2008-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	12822	\N	\N	\N
14150	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12823	\N	\N	\N
14151	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12824	\N	\N	\N
14152	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12825	\N	\N	\N
3844	SECRET	1900-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3250	8	\N	\N
14154	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12827	\N	\N	\N
14155	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12828	\N	\N	\N
14156	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12829	\N	\N	\N
14157	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12830	\N	\N	\N
14158	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12831	\N	\N	\N
12058	VICPDT	2004-11-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7819	\N	\N	\N
14159	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12832	\N	\N	\N
14160	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12833	\N	\N	\N
14161	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12834	\N	\N	\N
3861	MEMBRE	1999-01-01 00:00:00	2003-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	3903	\N	\N	\N
8767	MEMBREBUR	2004-11-12 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7830	\N	\N	\N
14164	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12837	\N	\N	\N
7829	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7834	\N	\N	\N
14165	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12838	\N	\N	\N
14166	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12839	\N	\N	\N
14243	PDTDEL	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Burundi	\N	9525	4	\N	\N
14244	PDTDEL	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Cameroun	\N	11932	5	\N	\N
14245	PDTDEL	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Centrafrique	\N	11927	6	\N	\N
14246	PDTDEL	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Congo	\N	11929	8	\N	\N
14247	PDTDEL	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Sao Tomé-et-Principe	\N	9516	12	\N	\N
14248	SECRET	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11181	14	\N	\N
14249	SECRET	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11194	15	\N	\N
14250	SECRET	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9515	16	\N	\N
14186	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12859	\N	\N	\N
14187	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12860	\N	\N	\N
14188	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12861	\N	\N	\N
14258	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12914	\N	\N	\N
14259	MEMBRE	2008-10-01 00:00:00	2009-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	12915	\N	\N	\N
14260	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12916	\N	\N	\N
14261	MEMBRE	2008-10-01 00:00:00	2009-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	12917	\N	\N	\N
14262	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12918	\N	\N	\N
14263	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12919	\N	\N	\N
14264	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12920	\N	\N	\N
14265	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12921	\N	\N	\N
14266	MEMBRE	2008-10-01 00:00:00	2009-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	12922	\N	\N	\N
14267	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12923	\N	\N	\N
14269	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12924	\N	\N	\N
14270	MEMBRE	2008-10-01 00:00:00	2009-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	12926	\N	\N	\N
14271	MEMBRE	2008-10-01 00:00:00	2009-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	12927	\N	\N	\N
14273	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12928	\N	\N	\N
14274	MEMBRE	2008-10-01 00:00:00	2009-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	12930	\N	\N	\N
14275	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12931	\N	\N	\N
14276	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12932	\N	\N	\N
13620	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12446	\N	\N	\N
13733	VICPDT	2009-01-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12451	2	\N	\N
13734	VICPDT	2009-01-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9296	3	\N	\N
14224	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12897	\N	\N	\N
13736	VICPDT	2009-01-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11202	6	\N	\N
13737	VICPDT	2009-01-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9303	7	\N	\N
13738	VICPDT	2009-01-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12468	8	\N	\N
13739	SECRET	2009-01-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12465	11	\N	\N
13740	SECRET	2009-01-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12467	12	\N	\N
13741	SECRET	2009-01-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12469	13	\N	\N
13742	MEMBRE	2009-01-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6298	0	\N	\N
13743	MEMBRE	2009-01-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6311	0	\N	\N
13744	MEMBRE	2009-01-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9294	0	\N	\N
14225	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12898	\N	\N	\N
2982	MEMBREBUR	1999-01-01 00:00:00	2003-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	3020	13	\N	\N
14227	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12900	\N	\N	\N
14234	VICPDT	2009-02-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12701	\N	\N	\N
14272	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12929	\N	\N	\N
14277	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12933	\N	\N	\N
14278	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12934	\N	\N	\N
14279	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12935	\N	\N	\N
14280	MEMBRE	2008-10-01 00:00:00	2009-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	12936	\N	\N	\N
14281	MEMBRE	2008-10-01 00:00:00	2009-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	12937	\N	\N	\N
14282	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12938	\N	\N	\N
14283	MEMBRE	2008-10-01 00:00:00	2009-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	12939	\N	\N	\N
14284	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12940	\N	\N	\N
14285	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12941	\N	\N	\N
14286	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12942	\N	\N	\N
14287	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12943	\N	\N	\N
14288	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12944	\N	\N	\N
14289	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12945	\N	\N	\N
14290	MEMBRE	2008-10-01 00:00:00	2009-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	12946	\N	\N	\N
14291	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12947	\N	\N	\N
14292	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12948	\N	\N	\N
14293	MEMBRE	2008-10-01 00:00:00	2009-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	12949	\N	\N	\N
14294	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12951	\N	\N	\N
14334	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12972	\N	\N	\N
14386	PDT	2009-02-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7829	\N	\N	\N
14353	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12982	\N	\N	\N
14351	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12981	\N	\N	\N
14354	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12983	\N	\N	\N
14355	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12984	\N	\N	\N
14356	MEMBRE	2008-10-01 00:00:00	2009-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	12985	\N	\N	\N
14357	SECRET	2009-02-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11454	\N	\N	\N
14358	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12986	\N	\N	\N
14378	SECRET	2009-02-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7305	\N	\N	\N
14385	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13001	\N	\N	\N
8014	VICPDT	2001-12-05 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7829	\N	\N	\N
14387	VICPDT	2009-02-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8533	\N	\N	\N
14398	MEMBRE	2009-02-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7817	\N	\N	\N
14399	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13002	\N	\N	\N
14400	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13003	\N	\N	\N
14401	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13004	\N	\N	\N
14402	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13005	\N	\N	\N
14403	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13006	\N	\N	\N
14465	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13062	\N	\N	\N
14466	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13063	\N	\N	\N
14467	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13064	\N	\N	\N
14468	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13065	\N	\N	\N
14469	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13066	\N	\N	\N
14474	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13071	\N	\N	\N
14475	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13072	\N	\N	\N
14476	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13073	\N	\N	\N
14477	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13074	\N	\N	\N
14478	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13075	\N	\N	\N
14479	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13076	\N	\N	\N
14480	MEMBRE	2008-10-01 00:00:00	2010-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	13077	\N	\N	\N
14481	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13078	\N	\N	\N
14496	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13093	\N	\N	\N
14498	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13095	\N	\N	\N
14499	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13096	\N	\N	\N
14500	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13097	\N	\N	\N
14501	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13098	\N	\N	\N
14502	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13099	\N	\N	\N
13593	TRESOR	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12312	14	\N	\N
13594	TRESORADJ	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5642	15	\N	\N
13595	MEMBRE	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3409	0	\N	\N
13596	MEMBRE	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9765	0	\N	\N
13597	VICPDT	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9955	4	\N	\N
13598	SECRET	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12440	8	\N	\N
13651	PDT	2009-01-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5944	1	\N	\N
14573	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13148	\N	\N	\N
14574	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13149	\N	\N	\N
14576	MEMBRE	2008-10-01 00:00:00	2009-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	13151	\N	\N	\N
14577	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13152	\N	\N	\N
14578	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13153	\N	\N	\N
13674	MEMBRE	2008-10-01 00:00:00	2009-03-30 00:00:00	ANCIEN	\N	\N	\N	\N	12497	\N	\N	\N
13675	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12498	\N	\N	\N
13677	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12500	\N	\N	\N
13678	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12501	\N	\N	\N
13679	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12502	\N	\N	\N
13680	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12503	\N	\N	\N
13681	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12504	\N	\N	\N
13682	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12505	\N	\N	\N
13683	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12506	\N	\N	\N
13684	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12507	\N	\N	\N
13685	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12508	\N	\N	\N
13686	MEMBRE	2008-10-01 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	\N	12509	\N	\N	\N
13687	MEMBRE	2008-10-01 00:00:00	2009-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	12510	0	\N	\N
13688	MEMBRE	2008-10-01 00:00:00	2009-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	12511	\N	\N	\N
13689	MEMBRE	2008-10-01 00:00:00	2010-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	12512	\N	\N	\N
13690	MEMBRE	2008-10-01 00:00:00	2009-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	12513	0	\N	\N
13691	MEMBRE	2008-10-01 00:00:00	2009-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	12514	\N	\N	\N
13692	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12515	\N	\N	\N
13693	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12516	\N	\N	\N
13694	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12517	\N	\N	\N
13695	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12518	\N	\N	\N
13696	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12519	\N	\N	\N
13697	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12520	\N	\N	\N
13698	MEMBRE	2008-10-01 00:00:00	2009-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	12521	0	\N	\N
13699	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12522	\N	\N	\N
13700	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12523	\N	\N	\N
13701	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12524	\N	\N	\N
13652	VICPDT	2009-01-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12477	3	\N	\N
13653	VICPDT	2009-01-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10259	4	\N	\N
13654	VICPDT	2009-01-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12478	5	\N	\N
13655	SECRET	2009-01-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12479	6	\N	\N
13657	PDTDEL	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Ile Maurice	\N	12480	6	\N	\N
13658	PDTDEL	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Kenya	\N	12481	7	\N	\N
13659	VICPDTDRT	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Afrique australe	\N	12482	2	\N	\N
13660	MEMBRE	2009-01-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12483	\N	\N	\N
13661	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12484	\N	\N	\N
13662	MEMBRE	2008-10-01 00:00:00	2009-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	12485	0	\N	\N
13663	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12486	\N	\N	\N
13664	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12487	\N	\N	\N
13665	MEMBRE	2008-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	12488	\N	\N	\N
13666	MEMBRE	2008-10-01 00:00:00	2009-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	12489	0	\N	\N
13667	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12490	\N	\N	\N
13668	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12491	\N	\N	\N
13669	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12492	\N	\N	\N
13670	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12493	\N	\N	\N
13671	MEMBRE	2008-10-01 00:00:00	2009-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	12494	0	\N	\N
13672	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12495	\N	\N	\N
13673	MEMBRE	2008-10-01 00:00:00	2009-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	12496	0	\N	\N
13730	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12553	\N	\N	\N
13731	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12554	\N	\N	\N
13732	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12555	\N	\N	\N
13944	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12702	\N	\N	\N
13949	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12708	\N	\N	\N
13951	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12709	\N	\N	\N
13953	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12711	\N	\N	\N
11804	MEMBRE	2006-11-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11120	\N	\N	\N
11823	MEMBRE	2006-11-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11139	\N	\N	\N
11849	SECRET	2006-11-15 00:00:00	2009-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	11142	\N	\N	\N
13962	PDTDEL	2009-02-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Lettonie	\N	4715	3	\N	\N
13963	PDTDEL	2009-02-10 00:00:00	2009-07-09 00:00:00	ANCIEN	\N	\N	Estonie	\N	12720	2	\N	\N
13964	PDTDEL	2009-02-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Lituanie	\N	8958	4	\N	\N
13965	VICPDT	2009-02-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3215	7	\N	\N
13967	VICPDT	2009-02-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12721	6	\N	\N
13968	VICPDT	2009-02-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12722	8	\N	\N
13969	SECRET	2009-02-10 00:00:00	2009-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	12723	10	\N	\N
13970	MEMBRE	2009-02-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8966	0	\N	\N
13971	MEMBRE	2009-02-10 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	\N	4720	0	\N	\N
13972	MEMBRE	2009-02-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3210	0	\N	\N
13973	MEMBRE	2009-02-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8962	0	\N	\N
13974	MEMBRE	2009-02-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3214	0	\N	\N
13975	MEMBRE	2009-02-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8961	0	\N	\N
13976	PDT	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12659	1	\N	\N
13977	PDTHON	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10797	2	\N	\N
13978	VICPDTDRT	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Canada	\N	9052	3	\N	\N
13979	VICPDT	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5688	4	\N	\N
13980	VICPDT	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9053	7	\N	\N
13981	VICPDT	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5676	9	\N	\N
13982	VICPDT	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12684	10	\N	\N
13983	VICPDT	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5648	11	\N	\N
13984	SECRET	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12657	13	\N	\N
13985	SECRET	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12672	14	\N	\N
13986	SECRET	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12686	15	\N	\N
13987	MEMBRE	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1965	0	\N	\N
13988	MEMBRE	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5667	0	\N	\N
13989	MEMBRE	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2811	0	\N	\N
13990	MEMBRE	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9043	0	\N	\N
13991	MEMBRE	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2454	0	\N	\N
13776	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12570	\N	\N	\N
13777	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12571	\N	\N	\N
13778	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12572	\N	\N	\N
13779	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12573	\N	\N	\N
13780	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12574	\N	\N	\N
13781	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12575	\N	\N	\N
13782	MEMBRE	2008-10-01 00:00:00	2009-03-09 00:00:00	ANCIEN	\N	\N	\N	\N	12576	0	\N	\N
13783	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12577	\N	\N	\N
13784	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12578	\N	\N	\N
13785	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12579	\N	\N	\N
13786	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12580	\N	\N	\N
13787	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12581	\N	\N	\N
13788	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12582	\N	\N	\N
13789	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12583	\N	\N	\N
13790	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12584	\N	\N	\N
13791	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12585	\N	\N	\N
13792	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12586	\N	\N	\N
13793	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12587	\N	\N	\N
13794	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12588	\N	\N	\N
13992	MEMBRE	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2250	0	\N	\N
13993	MEMBRE	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1915	0	\N	\N
13994	MEMBRE	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3111	0	\N	\N
13995	MEMBRE	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5691	0	\N	\N
13996	MEMBRE	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9083	0	\N	\N
13997	MEMBRE	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9084	0	\N	\N
13998	MEMBRE	2009-02-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5920	0	\N	\N
13999	PDT	2009-02-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3609	1	\N	\N
14000	VICPDT	2009-02-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2089	2	\N	\N
14001	VICPDT	2009-02-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12724	3	\N	\N
14002	VICPDT	2009-02-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12725	4	\N	\N
14003	SECRET	2009-02-10 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	9379	6	\N	\N
14004	SECRET	2009-02-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9377	7	\N	\N
14005	VICPDT	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4953	3	\N	\N
14006	SECRET	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12726	5	\N	\N
14007	SECRET	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12727	6	\N	\N
14038	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12751	\N	\N	\N
14039	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12752	\N	\N	\N
14485	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13082	\N	\N	\N
14295	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12952	\N	\N	\N
14296	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12954	\N	\N	\N
14314	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12962	\N	\N	\N
14317	VICPDT	2009-02-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7247	\N	\N	\N
14344	SECRET	2009-02-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8736	\N	\N	\N
14484	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13081	\N	\N	\N
14538	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13116	\N	\N	\N
14487	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13084	\N	\N	\N
14503	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13100	\N	\N	\N
14521	SECRET	2009-02-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9481	\N	\N	\N
14539	MEMBRE	2008-10-01 00:00:00	2009-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	13117	\N	\N	\N
14540	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13118	\N	\N	\N
14541	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13119	\N	\N	\N
14542	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13120	\N	\N	\N
14543	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13121	\N	\N	\N
14544	MEMBRE	2008-10-01 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	13122	\N	\N	\N
14545	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13123	\N	\N	\N
14546	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13124	\N	\N	\N
14547	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13125	\N	\N	\N
14554	VICPDT	2009-02-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13129	\N	\N	\N
14562	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13136	\N	\N	\N
14563	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13137	\N	\N	\N
14564	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13138	\N	\N	\N
14565	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13139	\N	\N	\N
14567	MEMBRE	2008-10-01 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	13142	\N	\N	\N
14568	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13143	\N	\N	\N
14569	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13144	\N	\N	\N
14570	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13145	\N	\N	\N
14571	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13146	\N	\N	\N
14572	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13147	\N	\N	\N
14612	MEMBRE	2009-02-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11057	\N	\N	\N
14613	MEMBRE	2009-02-23 00:00:00	2009-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	11058	\N	\N	\N
8561	MEMBRE	2001-01-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	8442	\N	\N	\N
8562	MEMBRE	2001-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8443	\N	\N	\N
8563	MEMBRE	2001-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8444	\N	\N	\N
14189	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12862	\N	\N	\N
14190	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12863	\N	\N	\N
14195	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12868	\N	\N	\N
14196	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12869	\N	\N	\N
14197	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12870	\N	\N	\N
14198	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12871	\N	\N	\N
14223	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12896	\N	\N	\N
14233	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12906	\N	\N	\N
14235	VICPDT	2009-02-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12715	\N	\N	\N
14236	VICPDT	2009-02-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12719	\N	\N	\N
14237	SECRET	2009-02-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11146	\N	\N	\N
14238	SECRET	2009-02-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12706	\N	\N	\N
8565	MEMBRE	2001-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8446	\N	\N	\N
8566	MEMBRE	2001-01-01 00:00:00	2001-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	8447	\N	\N	\N
8567	MEMBRE	2001-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8448	\N	\N	\N
11693	MEMBRE	2006-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11022	\N	\N	\N
11701	MEMBRE	2006-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11030	\N	\N	\N
11708	MEMBRE	2006-06-23 00:00:00	2007-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	11037	\N	\N	\N
11715	MEMBRE	2006-06-23 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11044	\N	\N	\N
11724	MEMBRE	2006-06-23 00:00:00	2007-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	11053	\N	\N	\N
11732	MEMBRE	2006-06-23 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11061	\N	\N	\N
11742	MEMBRE	2006-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11071	\N	\N	\N
11749	MEMBRE	2006-07-08 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11078	\N	\N	\N
10457	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10031	\N	\N	\N
10464	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10038	\N	\N	\N
11146	MEMBRE	2004-10-01 00:00:00	2005-05-30 00:00:00	ANCIEN	\N	\N	\N	\N	10567	\N	\N	\N
11155	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10570	\N	\N	\N
11163	MEMBRE	2005-04-11 00:00:00	2005-05-30 00:00:00	ANCIEN	\N	\N	\N	\N	10578	\N	\N	\N
11186	MEMBRE	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	10587	\N	\N	\N
11193	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10594	\N	\N	\N
11201	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10602	\N	\N	\N
11235	SECRET	2004-12-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2435	17	\N	\N
11243	MEMBRE	2005-04-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10631	\N	\N	\N
11295	MEMBRE	2005-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10661	\N	\N	\N
11302	MEMBRE	2005-06-01 00:00:00	2005-06-19 00:00:00	ANCIEN	\N	\N	\N	\N	10668	\N	\N	\N
11329	MEMBRE	2005-06-01 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	10695	\N	\N	\N
11335	MEMBRE	2005-06-01 00:00:00	2005-06-09 00:00:00	ANCIEN	\N	\N	\N	\N	10701	\N	\N	\N
11344	MEMBRE	2005-06-01 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	\N	10709	\N	\N	\N
11350	MEMBRE	2005-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10715	\N	\N	\N
11393	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10745	\N	\N	\N
11881	MEMBRE	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11185	\N	\N	\N
11889	MEMBRE	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11193	\N	\N	\N
12182	MEMBRE	2007-07-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11464	\N	\N	\N
12219	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11494	\N	\N	\N
12235	MEMBRE	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11510	\N	\N	\N
12244	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11519	\N	\N	\N
12275	MEMBRE	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11550	\N	\N	\N
12005	MEMBRE	2007-02-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11308	\N	\N	\N
12449	MEMBRE	2008-04-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11684	\N	\N	\N
12036	MEMBRE	2007-02-14 00:00:00	2011-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	11332	\N	\N	2015-11-12 15:26:22
11821	MEMBRE	2006-11-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11137	\N	\N	\N
12069	MEMBRE	2007-04-22 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11359	\N	\N	\N
11835	MEMBRE	2006-11-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11151	\N	\N	\N
11844	VICPDT	2006-11-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11123	\N	\N	\N
12073	MEMBRE	2007-04-22 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11363	\N	\N	\N
12127	MEMBRE	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11411	\N	\N	\N
12353	MEMBRE	2007-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11604	\N	\N	\N
12469	MEMBRE	2008-05-19 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11701	\N	\N	\N
12215	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11490	\N	\N	\N
12252	MEMBRE	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11527	\N	\N	\N
13349	MEMBRE	2004-10-01 00:00:00	2009-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	12339	\N	\N	\N
13378	PDTHON	2009-01-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2242	2	\N	\N
13379	PDT	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4186	1	\N	\N
13380	VICPDT	2008-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6190	3	\N	\N
13381	PDT	2008-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6196	1	\N	\N
13382	MEMBRE	2009-01-14 00:00:00	2009-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	2089	0	\N	\N
13383	MEMBRE	2009-01-14 00:00:00	2009-10-19 00:00:00	ANCIEN	\N	\N	\N	\N	3033	\N	\N	\N
13384	MEMBRE	2009-01-14 00:00:00	2009-01-14 00:00:00	ANCIEN	\N	\N	\N	\N	4297	\N	\N	\N
13437	MEMBRE	2009-01-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12375	\N	\N	\N
13438	MEMBRE	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12376	\N	\N	\N
13439	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12377	\N	\N	\N
13542	VICPDT	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9004	8	\N	\N
13441	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12379	\N	\N	\N
13474	MEMBRE	2008-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12388	\N	\N	\N
13539	PDTDEL	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Kirghizistan	\N	12418	4	\N	\N
13540	PDTDEL	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Ouzbékistan	\N	12419	5	\N	\N
13541	PDTDEL	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Tadjikistan	\N	12420	6	\N	\N
13543	VICPDT	2000-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8964	9	\N	\N
13544	VICPDT	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12421	10	\N	\N
13546	VICPDT	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12422	11	\N	\N
13547	SECRET	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12423	12	\N	\N
13548	MEMBRE	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1903	0	\N	\N
13549	MEMBRE	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4909	0	\N	\N
13550	MEMBRE	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4912	0	\N	\N
13551	MEMBRE	2009-01-21 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	4916	0	\N	\N
12624	SECRET	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11744	8	\N	\N
13442	PDT	2009-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4282	1	\N	\N
13443	VICPDT	2009-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4275	3	\N	\N
13444	VICPDT	2009-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4297	5	\N	\N
13445	SECRET	2009-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8942	6	\N	\N
12964	SECRET	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12011	13	\N	\N
12966	SECRET	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3363	14	\N	\N
12969	MEMBRE	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3339	0	\N	\N
12971	MEMBRE	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1404	0	\N	\N
12972	MEMBRE	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4796	0	\N	\N
12973	MEMBRE	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9636	0	\N	\N
12975	MEMBRE	2008-12-17 00:00:00	2010-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	9645	0	\N	\N
12976	MEMBRE	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1270	0	\N	\N
12978	MEMBRE	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9616	0	\N	\N
12980	MEMBRE	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9670	0	\N	\N
12982	MEMBRE	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4789	0	\N	\N
12983	MEMBRE	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9683	0	\N	\N
12986	MEMBRE	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9617	0	\N	\N
12988	MEMBRE	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3349	0	\N	\N
12990	MEMBRE	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3350	0	\N	\N
12991	MEMBRE	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9656	0	\N	\N
12992	MEMBRE	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4805	0	\N	\N
12993	MEMBRE	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4816	0	\N	\N
12994	MEMBRE	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9665	0	\N	\N
12995	MEMBRE	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9669	0	\N	\N
12996	MEMBRE	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9673	0	\N	\N
12997	VICPDT	2008-12-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8696	5	\N	\N
12998	VICPDT	2008-12-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12024	6	\N	\N
12999	MEMBRE	2008-12-18 00:00:00	2010-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	8690	\N	\N	\N
13001	SECRET	2008-12-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2854	10	\N	\N
13002	TRESOR	2008-12-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8701	8	\N	\N
13003	SECRET	2008-12-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8706	11	\N	\N
13004	SECRET	2008-12-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11652	12	\N	\N
13005	SECRET	2008-12-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8698	13	\N	\N
13006	SECRET	2008-12-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8673	14	\N	\N
13007	SECRET	2008-12-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10799	15	\N	\N
13008	SECRET	2008-12-18 00:00:00	2010-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	12025	16	\N	\N
13009	MEMBRE	2008-12-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5637	0	\N	\N
13010	MEMBRE	2008-12-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8645	0	\N	\N
13011	MEMBRE	2008-12-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5593	0	\N	\N
13012	MEMBRE	2008-12-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8699	0	\N	\N
13013	MEMBRE	2008-12-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8649	0	\N	\N
13014	MEMBRE	2008-10-01 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	12026	\N	\N	\N
13015	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12027	\N	\N	\N
13016	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12028	\N	\N	\N
13018	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12030	\N	\N	\N
13019	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12031	\N	\N	\N
13020	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12032	\N	\N	\N
13021	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12033	\N	\N	\N
13022	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12034	\N	\N	\N
13023	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12035	\N	\N	\N
13024	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12036	\N	\N	\N
13025	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12037	\N	\N	\N
13026	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12038	\N	\N	\N
13027	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12039	\N	\N	\N
13028	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12040	\N	\N	\N
13029	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12041	\N	\N	\N
13030	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12042	\N	\N	\N
13031	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12043	\N	\N	\N
13032	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12044	\N	\N	\N
13033	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12045	\N	\N	\N
13034	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12046	\N	\N	\N
13035	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12047	\N	\N	\N
13036	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12048	\N	\N	\N
13037	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12049	\N	\N	\N
13038	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12050	\N	\N	\N
13039	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12051	\N	\N	\N
13040	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12052	\N	\N	\N
13041	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12053	\N	\N	\N
13042	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12054	\N	\N	\N
13043	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12055	\N	\N	\N
13044	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12056	\N	\N	\N
13045	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12057	\N	\N	\N
13046	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12058	\N	\N	\N
13106	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12119	\N	\N	\N
13107	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12120	\N	\N	\N
13108	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12121	\N	\N	\N
13109	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12122	\N	\N	\N
13110	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12123	\N	\N	\N
13111	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12124	\N	\N	\N
13112	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12125	\N	\N	\N
13113	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12126	\N	\N	\N
13114	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12127	\N	\N	\N
13115	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12128	\N	\N	\N
13116	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12129	\N	\N	\N
13117	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12130	\N	\N	\N
13118	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12131	\N	\N	\N
13119	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12132	\N	\N	\N
13120	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12133	\N	\N	\N
13121	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12134	\N	\N	\N
13122	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12135	\N	\N	\N
13123	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12136	\N	\N	\N
13124	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12137	\N	\N	\N
13125	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12138	\N	\N	\N
13126	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12139	\N	\N	\N
13127	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12140	\N	\N	\N
13128	MEMBRE	2008-10-01 00:00:00	2010-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	12141	\N	\N	\N
13129	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12142	\N	\N	\N
13130	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12143	\N	\N	\N
13131	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12144	\N	\N	\N
13132	MEMBRE	2008-10-01 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	12145	\N	\N	\N
13133	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12146	\N	\N	\N
13134	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12147	\N	\N	\N
13135	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12148	\N	\N	\N
13136	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12149	\N	\N	\N
13137	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12150	\N	\N	\N
13138	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12151	\N	\N	\N
13150	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12163	\N	\N	\N
13151	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12164	\N	\N	\N
13152	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12165	\N	\N	\N
13153	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12166	\N	\N	\N
13154	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12167	\N	\N	\N
13155	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12168	\N	\N	\N
13156	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12169	\N	\N	\N
13157	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12170	\N	\N	\N
13158	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12171	\N	\N	\N
13159	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12172	\N	\N	\N
13160	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12173	\N	\N	\N
13161	MEMBRE	2008-10-01 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	12174	0	\N	\N
13162	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12175	\N	\N	\N
13163	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12176	\N	\N	\N
13164	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12177	\N	\N	\N
13165	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12178	\N	\N	\N
13166	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12179	\N	\N	\N
13167	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12180	\N	\N	\N
3529	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3599	\N	\N	\N
13169	VICPDT	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12182	3	\N	\N
13170	VICPDT	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2519	4	\N	\N
13171	VICPDT	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5968	5	\N	\N
13172	VICPDT	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5974	6	\N	\N
13173	SECRET	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12183	10	\N	\N
13174	SECRET	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10528	13	\N	\N
13175	SECRET	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12184	14	\N	\N
13176	MEMBRE	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5958	0	\N	\N
13177	MEMBRE	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1474	0	\N	\N
13178	MEMBRE	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1252	0	\N	\N
13179	MEMBRE	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10539	0	\N	\N
13212	PDTDEL	2009-01-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Kosovo	\N	11284	3	\N	\N
13213	PDTDEL	2009-01-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	République de Macédoine	\N	12217	4	\N	\N
13214	PDTDEL	2009-01-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Monténégro	\N	12218	5	\N	\N
13215	PDTDEL	2009-01-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Serbie	\N	12219	6	\N	\N
13077	MEMBRE	2008-10-01 00:00:00	2008-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	12089	\N	\N	\N
13078	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12090	\N	\N	\N
13079	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12091	\N	\N	\N
13080	MEMBRE	2008-10-01 00:00:00	2008-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	12092	\N	\N	\N
13081	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12093	\N	\N	\N
13082	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12094	\N	\N	\N
13083	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12095	\N	\N	\N
13084	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12096	\N	\N	\N
13085	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12097	\N	\N	\N
13086	MEMBRE	2008-10-01 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	12098	\N	\N	\N
13087	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12099	\N	\N	\N
13088	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12100	\N	\N	\N
13089	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12101	\N	\N	\N
13090	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12102	\N	\N	\N
13091	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12103	\N	\N	\N
13092	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12104	\N	\N	\N
13093	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12105	\N	\N	\N
13094	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12106	\N	\N	\N
13095	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12108	\N	\N	\N
13096	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12109	\N	\N	\N
13097	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12110	\N	\N	\N
13098	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12111	\N	\N	\N
13099	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12112	\N	\N	\N
13100	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12113	\N	\N	\N
13101	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12114	\N	\N	\N
13102	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12115	\N	\N	\N
13103	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12116	\N	\N	\N
13104	MEMBRE	2008-10-01 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	\N	12117	\N	\N	\N
13105	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12118	\N	\N	\N
13371	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12354	\N	\N	\N
13372	MEMBRE	2009-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12355	\N	\N	\N
13373	MEMBRE	2009-01-09 00:00:00	2009-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	12356	0	\N	2015-11-12 15:26:22
13374	MEMBRE	2009-01-12 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	12357	0	\N	\N
13375	MEMBRE	2009-01-13 00:00:00	2009-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	12358	\N	\N	\N
13376	MEMBRE	2009-01-14 00:00:00	2009-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	11252	0	\N	\N
13377	MEMBRE	2009-01-14 00:00:00	2009-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	10797	0	\N	\N
13189	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12194	\N	\N	\N
13190	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12195	\N	\N	\N
13191	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12196	\N	\N	\N
13192	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12197	\N	\N	\N
13193	MEMBRE	2008-10-01 00:00:00	2008-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	12198	\N	\N	\N
13194	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12199	\N	\N	\N
13195	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12200	\N	\N	\N
13196	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12201	\N	\N	\N
13197	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12202	\N	\N	\N
13198	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12203	\N	\N	\N
13199	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12204	\N	\N	\N
13200	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12205	\N	\N	\N
13201	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12206	\N	\N	\N
13202	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12207	\N	\N	\N
13203	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12208	\N	\N	\N
13204	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12209	\N	\N	\N
13205	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12210	\N	\N	\N
13206	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12211	\N	\N	\N
13207	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12212	\N	\N	\N
14192	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12865	\N	\N	\N
14193	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12866	\N	\N	\N
14194	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12867	\N	\N	\N
14251	MEMBRE	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5505	0	\N	\N
14325	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12965	\N	\N	\N
14333	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12971	\N	\N	\N
14380	MEMBREBUR	2009-02-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11142	\N	\N	\N
14382	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12998	\N	\N	\N
14383	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12999	\N	\N	\N
14384	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13000	\N	\N	\N
14388	VICPDT	2009-02-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12826	\N	\N	\N
14389	VICPDT	2009-02-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7834	\N	\N	\N
14390	VICPDT	2009-02-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8609	\N	\N	\N
14391	SECRET	2009-02-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12812	\N	\N	\N
14392	SECRET	2009-02-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12836	\N	\N	\N
14393	SECRET	2009-02-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7835	\N	\N	\N
14394	MEMBREBUR	2009-02-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11556	\N	\N	\N
14395	MEMBREBUR	2009-02-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11575	\N	\N	\N
14396	MEMBRE	2009-02-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7797	\N	\N	\N
14397	MEMBRE	2009-02-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7806	\N	\N	\N
14404	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13007	\N	\N	\N
14405	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13008	\N	\N	\N
14406	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13009	\N	\N	\N
14407	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13010	\N	\N	\N
14408	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13011	\N	\N	\N
14409	MEMBRE	2008-10-01 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	13012	\N	\N	\N
14410	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13013	\N	\N	\N
14411	MEMBRE	2008-10-01 00:00:00	2010-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	13014	\N	\N	\N
14412	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13015	\N	\N	\N
14414	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13017	\N	\N	\N
14415	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13018	\N	\N	\N
14416	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13019	\N	\N	\N
14417	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13020	\N	\N	\N
14419	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13022	\N	\N	\N
14420	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13023	\N	\N	\N
14421	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13024	\N	\N	\N
14297	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12955	\N	\N	\N
14298	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12956	\N	\N	\N
14423	MEMBRE	2008-10-01 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	13026	\N	\N	\N
3890	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	3932	\N	\N	\N
14425	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13028	\N	\N	\N
14426	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13029	\N	\N	\N
14427	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13030	\N	\N	\N
14428	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13031	\N	\N	\N
14429	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13032	\N	\N	\N
14430	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13033	\N	\N	\N
14431	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13034	\N	\N	\N
14434	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13037	\N	\N	\N
14435	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13038	\N	\N	\N
14436	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13039	\N	\N	\N
14437	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13040	\N	\N	\N
14438	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13041	\N	\N	\N
14439	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13042	\N	\N	\N
14441	MEMBRE	2008-10-01 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	\N	13044	\N	\N	\N
14462	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13059	\N	\N	\N
14463	MEMBRE	2008-10-01 00:00:00	2009-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	13060	\N	\N	\N
14464	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13061	\N	\N	\N
14470	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13067	\N	\N	\N
14471	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13068	\N	\N	\N
14472	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13069	\N	\N	\N
14520	SECRET	2009-02-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13092	\N	\N	\N
14593	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13161	\N	\N	\N
14594	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13162	\N	\N	\N
14595	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13163	\N	\N	\N
14596	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13164	\N	\N	\N
8554	MEMBRE	2001-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8435	\N	\N	\N
14598	MEMBRE	2008-10-01 00:00:00	2009-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	13166	\N	\N	\N
14637	MEMBRE	2009-02-17 00:00:00	2009-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	13188	\N	\N	\N
8555	MEMBRE	2001-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8436	\N	\N	\N
8556	MEMBRE	2001-01-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	8437	\N	\N	\N
12927	VICPDT	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9199	12	\N	\N
12928	SECRET	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11999	15	\N	\N
12929	SECRET	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12000	16	\N	\N
12930	SECRET	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12001	17	\N	\N
12931	SECRET	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12003	19	\N	\N
12932	MEMBRE	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4830	0	\N	\N
12933	MEMBRE	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4820	0	\N	\N
12934	MEMBRE	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9197	0	\N	\N
12935	VICPDT	2008-12-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9420	3	\N	\N
12936	VICPDT	2008-12-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9418	4	\N	\N
12937	VICPDT	2008-12-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3157	5	\N	\N
12938	VICPDT	2008-12-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8550	8	\N	\N
12939	SECRET	2008-12-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10811	10	\N	\N
12940	SECRET	2008-12-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8554	11	\N	\N
12941	MEMBRE	2008-12-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4859	0	\N	\N
12942	MEMBRE	2008-12-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9425	0	\N	\N
12943	MEMBRE	2008-12-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4860	0	\N	\N
12944	VICPDT	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11815	5	\N	\N
12945	VICPDT	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11816	6	\N	\N
12946	VICPDT	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11819	7	\N	\N
12947	SECRET	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11823	9	\N	\N
12948	TRESOR	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11829	11	\N	\N
12949	MEMBRE	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6415	0	\N	\N
12950	MEMBRE	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6400	0	\N	\N
12951	PDT	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9660	1	\N	\N
12952	VICPDT	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9658	2	\N	\N
12953	VICPDT	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1989	3	\N	\N
12955	VICPDT	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12006	5	\N	\N
12956	VICPDT	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9605	6	\N	\N
12959	SECRET	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4793	10	\N	\N
12960	SECRET	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4799	11	\N	\N
12962	SECRET	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4790	12	\N	\N
13557	MEMBRE	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4920	0	\N	\N
13558	MEMBRE	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9008	0	\N	\N
13561	MEMBRE	2008-10-01 00:00:00	2009-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	12426	\N	\N	\N
13562	MEMBRE	2008-10-01 00:00:00	2009-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	12427	\N	\N	\N
13563	MEMBRE	2008-10-01 00:00:00	2009-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	12428	\N	\N	\N
13564	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12429	\N	\N	\N
13565	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12430	\N	\N	\N
13566	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12431	\N	\N	\N
13567	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12432	\N	\N	\N
13568	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12433	\N	\N	\N
13569	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12434	\N	\N	\N
13570	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12435	\N	\N	\N
13571	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12436	\N	\N	\N
13572	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12437	\N	\N	\N
13573	MEMBRE	2008-10-01 00:00:00	2009-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	12438	\N	\N	\N
13574	MEMBRE	2008-10-01 00:00:00	2009-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	12439	\N	\N	\N
13575	VICPDT	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12426	2	\N	\N
13576	VICPDT	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12427	3	\N	\N
13578	VICPDT	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10147	5	\N	\N
13579	VICPDT	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12438	7	\N	\N
13580	SECRET	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4625	8	\N	\N
13581	SECRET	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12428	9	\N	\N
13582	SECRET	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12439	10	\N	\N
13583	PDT	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3405	1	\N	\N
13585	PDTDEL	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Fidji	\N	3431	3	\N	\N
13586	PDTDEL	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Papouasie-Nouvelle Guinée	\N	12317	4	\N	\N
13587	VICPDT	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12311	5	\N	\N
13588	VICPDT	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9767	7	\N	\N
13589	VICPDT	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12315	8	\N	\N
13590	SECRET	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12306	9	\N	\N
13591	SECRET	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12314	11	\N	\N
13592	SECRET	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12321	13	\N	\N
13311	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12303	\N	\N	\N
13312	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12304	\N	\N	\N
13314	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12305	\N	\N	\N
13316	MEMBRE	2008-10-01 00:00:00	2009-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	12306	0	\N	\N
13317	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12307	\N	\N	\N
13318	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12308	\N	\N	\N
13319	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12309	\N	\N	\N
13320	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12310	\N	\N	\N
13321	MEMBRE	2008-10-01 00:00:00	2009-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	12311	0	\N	\N
13322	MEMBRE	2008-10-01 00:00:00	2009-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	12312	0	\N	\N
13323	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12313	\N	\N	\N
13324	MEMBRE	2008-10-01 00:00:00	2009-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	12314	0	\N	\N
13325	MEMBRE	2008-10-01 00:00:00	2009-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	12315	0	\N	\N
13326	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12316	\N	\N	\N
13327	MEMBRE	2008-10-01 00:00:00	2009-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	12317	0	\N	\N
13328	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12318	\N	\N	\N
13329	MEMBRE	2008-10-01 00:00:00	2010-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	12319	\N	\N	\N
13330	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12320	\N	\N	\N
13331	MEMBRE	2008-10-01 00:00:00	2009-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	12321	0	\N	\N
13332	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12322	\N	\N	\N
13333	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12323	\N	\N	\N
13334	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12324	\N	\N	\N
13335	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12325	\N	\N	\N
13336	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12326	\N	\N	\N
13337	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12327	\N	\N	\N
13338	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12328	\N	\N	\N
13339	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12329	\N	\N	\N
13340	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12330	\N	\N	\N
13341	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12331	\N	\N	\N
13342	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12332	\N	\N	\N
13430	MEMBRE	2009-01-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12368	\N	\N	\N
13432	MEMBRE	2008-01-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12370	\N	\N	\N
13433	MEMBRE	2008-01-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12371	\N	\N	\N
13434	MEMBRE	2008-01-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12372	\N	\N	\N
13490	VICPDT	2008-12-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12082	6	\N	\N
13390	VICPDT	2009-01-13 00:00:00	2011-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	11983	8	\N	\N
13391	SECRET	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11985	9	\N	\N
13392	SECRET	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11849	10	\N	\N
13393	SECRET	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2522	11	\N	\N
13394	SECRET	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11859	13	\N	\N
13395	SECRET	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11984	14	\N	\N
13396	SECRET	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11863	15	\N	\N
13397	SECRET	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10312	16	\N	\N
13398	VICPDT	2008-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12359	2	\N	\N
13399	VICPDT	2008-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12360	4	\N	\N
13400	VICPDT	2008-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12361	5	\N	\N
13401	SECRET	2008-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9999	6	\N	\N
13402	SECRET	2008-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12362	7	\N	\N
13403	SECRET	2008-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10004	8	\N	\N
13409	VICPDT	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12365	7	\N	\N
13410	VICPDT	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10066	8	\N	\N
13406	MEMBRE	2008-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6197	0	\N	\N
13407	MEMBRE	2008-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10008	0	\N	\N
13408	VICPDT	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12364	6	\N	\N
13411	SECRET	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12366	10	\N	\N
13412	SECRET	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3448	12	\N	\N
13413	SECRET	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3454	13	\N	\N
13415	SECRET	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12367	14	\N	\N
13416	MEMBRE	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3466	0	\N	\N
13417	MEMBRE	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3479	0	\N	\N
13419	MEMBRE	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3477	0	\N	\N
13420	MEMBRE	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3485	0	\N	\N
13421	VICPDT	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9109	2	\N	\N
13422	VICPDT	2009-01-13 00:00:00	2011-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	12356	10	\N	2015-11-12 15:26:22
13423	VICPDT	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12357	13	\N	\N
13424	SECRET	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11891	14	\N	\N
13425	SECRET	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11403	15	\N	\N
13426	SECRET	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9118	16	\N	\N
13427	MEMBRE	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9954	0	\N	\N
12825	MEMBRE	2008-10-01 00:00:00	2006-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	11924	\N	\N	\N
12826	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11925	\N	\N	\N
12827	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11926	\N	\N	\N
12828	MEMBRE	2008-10-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	11927	0	\N	\N
12829	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11928	\N	\N	\N
12830	MEMBRE	2008-10-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	11929	0	\N	\N
12831	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11930	\N	\N	\N
12832	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11931	\N	\N	\N
12833	MEMBRE	2008-10-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	11932	0	\N	\N
12834	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11933	\N	\N	\N
12835	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11934	\N	\N	\N
12836	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11935	\N	\N	\N
12837	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11936	\N	\N	\N
12838	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11937	\N	\N	\N
12839	MEMBRE	2008-10-01 00:00:00	2010-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	11938	\N	\N	\N
12840	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11939	\N	\N	\N
12841	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11940	\N	\N	\N
12842	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11941	\N	\N	\N
12843	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11942	\N	\N	\N
12844	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11943	\N	\N	\N
12845	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11944	\N	\N	\N
12846	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11945	\N	\N	\N
12847	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11946	\N	\N	\N
12848	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11947	\N	\N	\N
12849	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11948	\N	\N	\N
12850	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11949	\N	\N	\N
12851	MEMBRE	2008-10-01 00:00:00	2008-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	11950	0	\N	\N
12852	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11951	\N	\N	\N
12853	MEMBRE	2008-10-01 00:00:00	2009-09-09 00:00:00	ANCIEN	\N	\N	\N	\N	11952	\N	\N	\N
12854	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11953	\N	\N	\N
12855	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11954	\N	\N	\N
12856	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11955	\N	\N	\N
12857	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11956	\N	\N	\N
12858	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11957	\N	\N	\N
12859	MEMBRE	2008-10-01 00:00:00	2008-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	11958	\N	\N	\N
12860	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11959	\N	\N	\N
12861	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11960	\N	\N	\N
12862	MEMBRE	2008-10-01 00:00:00	2008-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	11961	0	\N	\N
12863	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11962	\N	\N	\N
12864	MEMBRE	2008-10-01 00:00:00	2008-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	11963	0	\N	\N
12865	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11964	\N	\N	\N
12866	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11965	\N	\N	\N
12867	MEMBRE	2008-10-01 00:00:00	2008-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	11966	0	\N	\N
12868	MEMBRE	2008-10-01 00:00:00	2008-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	11967	0	\N	\N
12869	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11968	\N	\N	\N
12870	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11969	\N	\N	\N
12871	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11970	\N	\N	\N
12872	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11971	\N	\N	\N
12875	MEMBRE	2008-10-01 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	11972	0	\N	\N
12876	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11973	\N	\N	\N
12878	MEMBRE	2008-10-01 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	11974	0	\N	\N
12879	MEMBRE	2008-10-01 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	11975	0	\N	\N
12880	MEMBRE	2008-10-01 00:00:00	2010-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	11976	\N	\N	\N
12886	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11977	\N	\N	\N
12890	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11980	\N	\N	\N
12897	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11982	\N	\N	\N
12898	MEMBRE	2008-10-01 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	11983	0	\N	\N
12899	MEMBRE	2008-10-01 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	11984	0	\N	\N
12900	MEMBRE	2008-10-01 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	11985	0	\N	\N
12901	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11987	\N	\N	\N
12903	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11988	\N	\N	\N
12954	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12005	\N	\N	\N
12957	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12007	\N	\N	\N
12958	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12008	\N	\N	\N
12961	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12009	\N	\N	\N
12963	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12010	\N	\N	\N
12965	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12012	\N	\N	\N
12967	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12013	\N	\N	\N
12968	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12014	\N	\N	\N
12970	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12015	\N	\N	\N
12974	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12016	\N	\N	\N
12979	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12018	\N	\N	\N
12981	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12019	\N	\N	\N
12984	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12020	\N	\N	\N
12985	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12021	\N	\N	\N
12987	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12022	\N	\N	\N
12989	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12023	\N	\N	\N
13047	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12059	\N	\N	\N
13048	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12060	\N	\N	\N
13049	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12061	\N	\N	\N
13050	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12062	\N	\N	\N
13051	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12063	\N	\N	\N
13052	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12064	\N	\N	\N
13054	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12066	\N	\N	\N
13055	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12067	\N	\N	\N
13056	MEMBRE	2008-10-01 00:00:00	2010-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	12068	\N	\N	2015-11-12 15:26:22
13057	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12069	\N	\N	\N
13058	MEMBRE	2008-10-01 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	12070	\N	\N	\N
13059	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12071	\N	\N	\N
13060	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12072	\N	\N	\N
13061	MEMBRE	2008-10-01 00:00:00	2009-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	12073	\N	\N	\N
13062	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12074	\N	\N	\N
13063	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12075	\N	\N	\N
13064	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12076	\N	\N	\N
13065	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12077	\N	\N	\N
13066	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12078	\N	\N	\N
13067	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12079	\N	\N	\N
13068	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12080	\N	\N	\N
13069	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12081	\N	\N	\N
13070	MEMBRE	2008-10-01 00:00:00	2008-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	12082	\N	\N	\N
13071	MEMBRE	2008-10-01 00:00:00	2008-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	12083	\N	\N	\N
13072	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12084	\N	\N	\N
13073	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12085	\N	\N	\N
13074	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12086	\N	\N	\N
13075	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12087	\N	\N	\N
13076	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12088	\N	\N	\N
13772	MEMBRE	2008-10-01 00:00:00	2009-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	12568	\N	\N	\N
13773	MEMBRE	2008-10-01 00:00:00	2009-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	12569	\N	\N	\N
13774	SECRET	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12098	13	\N	\N
13775	SECRET	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11913	8	\N	\N
13795	VICPDT	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9986	6	\N	\N
13796	VICPDT	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3593	7	\N	\N
13797	SECRET	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12188	8	\N	\N
13798	TRESOR	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9569	9	\N	\N
13811	PDT	2009-02-03 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	3653	1	\N	\N
13812	VICPDT	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3631	11	\N	\N
13813	VICPDT	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9713	3	\N	\N
13814	VICPDT	2009-02-03 00:00:00	2010-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	3647	4	\N	\N
13815	VICPDT	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9718	4	\N	\N
13816	VICPDT	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9721	8	\N	\N
13817	VICPDT	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5980	9	\N	\N
13818	VICPDT	2009-02-03 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5139	8	\N	\N
13819	VICPDT	2009-02-03 00:00:00	2009-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	3670	9	\N	\N
13820	VICPDT	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5149	10	\N	\N
13821	SECRET	2009-02-03 00:00:00	2010-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	10202	11	\N	\N
13822	SECRET	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9712	14	\N	\N
13823	SECRET	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12593	13	\N	\N
13824	SECRET	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12594	15	\N	\N
15674	MEMBRE	2009-10-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13917	\N	\N	\N
13826	SECRET	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5144	18	\N	\N
13827	SECRET	2009-02-03 00:00:00	2010-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	12595	16	\N	\N
13828	SECRET	2009-02-03 00:00:00	2010-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	5146	18	\N	\N
13829	SECRET	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12596	17	\N	\N
13830	TRESOR	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12597	20	\N	\N
13832	MEMBRE	2009-02-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11257	\N	\N	\N
13833	MEMBRE	2009-02-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11261	\N	\N	\N
13834	SECRET	2009-02-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11267	7	\N	\N
13835	VICPDT	2009-02-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11262	4	\N	\N
13836	PDT	2009-02-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12598	1	\N	\N
13838	PDTHON	2009-02-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11252	2	\N	\N
13839	VICPDT	2009-02-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12599	3	\N	\N
14167	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12840	\N	\N	\N
14228	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12901	\N	\N	\N
14230	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12903	\N	\N	\N
14231	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12904	\N	\N	\N
14232	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12905	\N	\N	\N
14240	MEMBRE	2008-10-01 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	12907	\N	\N	\N
14241	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12908	\N	\N	\N
14242	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12909	\N	\N	\N
14252	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12910	\N	\N	\N
14253	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12911	\N	\N	\N
14254	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12912	\N	\N	\N
14255	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12913	\N	\N	\N
14257	MEMBRE	2009-02-19 00:00:00	2009-03-09 00:00:00	ANCIEN	\N	\N	\N	\N	3523	0	\N	\N
14299	PDT	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6121	1	\N	\N
14300	VICPDT	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9152	2	\N	\N
14301	VICPDT	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12957	3	\N	\N
14302	VICPDT	2009-02-17 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	12958	4	\N	\N
14303	VICPDT	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9166	5	\N	\N
14304	VICPDT	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9167	6	\N	\N
14305	VICPDT	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12959	7	\N	\N
14306	SECRET	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12960	8	\N	\N
14307	SECRET	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9173	10	\N	\N
14308	SECRET	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12961	11	\N	\N
14309	MEMBRE	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3048	\N	\N	\N
14310	MEMBRE	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1480	\N	\N	\N
14311	MEMBRE	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6122	\N	\N	\N
14312	MEMBRE	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6128	\N	\N	\N
14313	MEMBRE	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3042	\N	\N	\N
14315	MEMBRE	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6135	\N	\N	\N
14316	MEMBRE	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9168	\N	\N	\N
14318	MEMBRE	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6126	\N	\N	\N
14319	MEMBRE	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2027	\N	\N	\N
14320	MEMBRE	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9169	\N	\N	\N
14321	MEMBRE	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6136	\N	\N	\N
14322	MEMBRE	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6132	\N	\N	\N
14323	MEMBRE	2008-10-01 00:00:00	2009-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	12963	\N	\N	\N
14324	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12964	\N	\N	\N
13840	VICPDT	2009-02-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12600	5	\N	\N
13841	VICPDT	2009-02-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12601	6	\N	\N
13843	SECRET	2009-02-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12602	8	\N	\N
13890	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12650	\N	\N	\N
13891	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12651	\N	\N	\N
13892	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12652	\N	\N	\N
13893	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12653	\N	\N	\N
13894	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12654	\N	\N	\N
13896	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12656	\N	\N	\N
13903	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12662	\N	\N	\N
13907	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12666	\N	\N	\N
13930	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12690	\N	\N	\N
13936	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12694	\N	\N	\N
13933	MEMBRE	2004-10-01 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	8785	\N	\N	\N
7087	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	7230	\N	\N	\N
13934	MEMBRE	2008-10-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	12692	0	\N	\N
13935	MEMBRE	2008-10-01 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	12693	\N	\N	\N
13937	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12695	\N	\N	\N
14368	VICPDT	2009-02-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12994	3	\N	\N
14604	VICPDT	2009-01-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7478	\N	\N	\N
14372	SECRET	2009-02-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12997	7	\N	\N
14375	MEMBRE	2009-02-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2952	0	\N	\N
14586	VICPDT	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7224	\N	\N	\N
14603	VICPDT	2009-01-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9529	\N	\N	\N
14605	SECRET	2009-01-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13151	\N	\N	\N
7419	MEMBRE	2001-10-01 00:00:00	2009-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	7504	\N	\N	\N
14606	SECRET	2009-01-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7504	\N	\N	\N
14607	SECRET	2009-01-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13158	\N	\N	\N
14608	MEMBRE	2009-02-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11035	\N	\N	\N
14609	MEMBRE	2009-02-23 00:00:00	2009-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	11047	\N	\N	\N
14610	MEMBRE	2009-02-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11095	\N	\N	\N
14611	MEMBRE	2009-02-23 00:00:00	2009-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	11053	\N	\N	\N
13702	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12525	\N	\N	\N
13703	MEMBRE	2008-10-01 00:00:00	2009-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	12526	0	\N	\N
13704	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12527	\N	\N	\N
13705	MEMBRE	2008-10-01 00:00:00	2009-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	12528	0	\N	\N
13706	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12529	\N	\N	\N
13707	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12530	\N	\N	\N
13708	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12531	\N	\N	\N
13709	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12532	\N	\N	\N
13710	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12533	\N	\N	\N
14200	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12873	\N	\N	\N
13712	MEMBRE	2008-10-01 00:00:00	2010-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	12535	\N	\N	\N
13713	MEMBRE	2008-10-01 00:00:00	2009-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	12536	0	\N	\N
13714	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12537	\N	\N	\N
13715	MEMBRE	2008-10-01 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	12538	\N	\N	\N
13716	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12539	\N	\N	\N
13717	MEMBRE	2008-10-01 00:00:00	2010-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	12540	\N	\N	\N
13718	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12541	\N	\N	\N
13719	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12542	\N	\N	\N
13720	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12543	\N	\N	\N
14580	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13155	\N	\N	\N
13722	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12545	\N	\N	\N
14581	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13156	\N	\N	\N
14530	MEMBREBUR	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12544	\N	\N	\N
14579	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13154	\N	\N	\N
13726	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12549	\N	\N	\N
14582	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13157	\N	\N	\N
14583	MEMBRE	2008-10-01 00:00:00	2009-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	13158	\N	\N	\N
14584	MEMBRE	2008-10-01 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	\N	13159	\N	\N	\N
13801	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12589	\N	\N	\N
13802	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12590	\N	\N	\N
13803	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12591	\N	\N	\N
13804	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12592	\N	\N	\N
14199	MEMBRE	2008-10-01 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	12872	0	\N	\N
14201	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12874	\N	\N	\N
14202	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12875	\N	\N	\N
14203	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12876	\N	\N	\N
14204	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12877	\N	\N	\N
14205	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12878	\N	\N	\N
14206	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12879	\N	\N	\N
14207	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12880	\N	\N	\N
14208	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12881	\N	\N	\N
14209	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12882	\N	\N	\N
14210	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12883	\N	\N	\N
14211	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12884	\N	\N	\N
13599	TRESORADJ	2009-01-20 00:00:00	2011-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	12441	11	\N	\N
13600	MEMBRE	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6039	0	\N	\N
13601	MEMBRE	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5573	0	\N	\N
13602	MEMBRE	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9700	0	\N	\N
13603	MEMBRE	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9702	0	\N	\N
13604	MEMBRE	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4309	0	\N	\N
13605	MEMBRE	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9707	0	\N	\N
13606	PDTHON	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12442	1	\N	\N
13607	VICPDTPRE	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10807	3	\N	\N
13608	VICPDT	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12443	4	\N	\N
13609	VICPDT	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12444	7	\N	\N
13610	TRESOR	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1427	12	\N	\N
13611	TRESORADJ	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9246	13	\N	\N
13612	SECRET	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1396	15	\N	\N
13613	SECRET	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12445	16	\N	\N
13614	SECRET	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1981	19	\N	\N
13615	SECRET	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2852	22	\N	\N
15685	MEMBRE	2010-01-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13926	\N	\N	\N
13617	MEMBRE	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	190	0	\N	\N
13618	MEMBRE	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9257	0	\N	\N
13619	MEMBRE	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5370	0	\N	\N
14212	MEMBRE	2008-10-01 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	12885	\N	\N	\N
14213	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12886	\N	\N	\N
14214	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12887	\N	\N	\N
14215	MEMBRE	2008-10-01 00:00:00	2010-01-07 00:00:00	ANCIEN	\N	\N	\N	\N	12888	\N	\N	\N
14216	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12889	\N	\N	\N
14217	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12890	\N	\N	\N
14218	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12891	\N	\N	\N
14219	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12892	\N	\N	\N
14220	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12893	\N	\N	\N
14221	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12894	\N	\N	\N
15687	MEMBRE	2009-06-25 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13928	\N	\N	\N
14346	SECRET	2009-02-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12899	\N	\N	\N
14349	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12980	\N	\N	\N
14359	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12987	\N	\N	\N
14360	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12988	\N	\N	\N
14374	MEMBRE	2009-02-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8737	\N	\N	\N
14362	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12990	\N	\N	\N
14363	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12991	\N	\N	\N
14364	SECRET	2009-02-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7270	\N	\N	\N
14376	SECRET	2009-02-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12963	\N	\N	\N
14377	SECRET	2009-02-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9315	\N	\N	\N
14379	SECRET	2009-02-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12985	\N	\N	\N
14442	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13045	\N	\N	\N
14443	MEMBRE	2008-10-01 00:00:00	2009-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	13046	\N	\N	\N
14444	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13047	\N	\N	\N
14446	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13049	\N	\N	\N
14447	MEMBRE	2008-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	13050	\N	\N	\N
14454	VICPDT	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8275	\N	\N	\N
14455	SECRET	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9540	\N	\N	\N
14456	SECRET	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9541	\N	\N	\N
14460	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13057	\N	\N	\N
14482	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13079	\N	\N	\N
14483	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13080	\N	\N	\N
14488	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13085	\N	\N	\N
14489	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13086	\N	\N	\N
14513	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13106	\N	\N	\N
14491	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13088	\N	\N	\N
14492	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13089	\N	\N	\N
14493	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13090	\N	\N	\N
14494	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13091	\N	\N	\N
14510	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13104	\N	\N	\N
14511	VICPDT	2009-02-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7946	\N	\N	\N
14514	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13107	\N	\N	\N
14515	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13108	\N	\N	\N
14516	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13109	\N	\N	\N
14517	SECRET	2009-02-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13083	\N	\N	\N
14518	SECRET	2009-02-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11068	\N	\N	\N
14519	SECRET	2009-02-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9480	\N	\N	\N
14523	VICPDT	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12547	\N	\N	\N
14524	VICPDT	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12548	\N	\N	\N
14525	VICPDT	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12550	\N	\N	\N
14526	VICPDT	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12551	\N	\N	\N
14527	VICPDT	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12552	\N	\N	\N
14528	MEMBRE	2009-02-23 00:00:00	2010-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	11330	\N	\N	\N
14529	SECRET	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12546	\N	\N	\N
14575	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13150	\N	\N	\N
14015	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12728	\N	\N	\N
14016	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12729	\N	\N	\N
14017	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12730	\N	\N	\N
14018	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12731	\N	\N	\N
14019	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12732	\N	\N	\N
14020	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12733	\N	\N	\N
14021	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12734	\N	\N	\N
14022	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12735	\N	\N	\N
14023	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12736	\N	\N	\N
14024	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12737	\N	\N	\N
14025	MEMBRE	2008-10-01 00:00:00	2009-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	12738	\N	\N	\N
14026	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12739	\N	\N	\N
14027	MEMBRE	2008-10-01 00:00:00	2009-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	12740	\N	\N	\N
7457	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	7528	\N	\N	\N
8825	MEMBRE	2004-10-01 00:00:00	2009-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	8661	\N	\N	\N
14028	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12741	\N	\N	\N
14029	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12742	\N	\N	\N
14030	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12743	\N	\N	\N
14031	MEMBRE	2008-10-01 00:00:00	2009-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	12744	\N	\N	\N
14032	MEMBRE	2008-10-01 00:00:00	2009-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	12745	\N	\N	\N
14033	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12746	\N	\N	\N
14034	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12747	\N	\N	\N
14035	MEMBRE	2008-10-01 00:00:00	2009-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	12748	\N	\N	\N
14036	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12749	\N	\N	\N
14037	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12750	\N	\N	\N
14056	MEMBRE	2009-02-10 00:00:00	2011-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	2226	0	\N	\N
14057	VICPDT	2009-02-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10805	2	\N	\N
14058	VICPDT	2009-02-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12489	4	\N	\N
14059	VICPDT	2009-02-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12485	5	\N	\N
14060	SECRET	2009-02-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12494	6	\N	\N
14061	SECRET	2009-02-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12496	7	\N	\N
14064	VICPDT	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8634	3	\N	\N
14065	VICPDT	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12771	4	\N	\N
14066	SECRET	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3887	6	\N	\N
14067	MEMBRE	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3870	0	\N	\N
14068	MEMBRE	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8639	0	\N	\N
14069	MEMBRE	2008-12-09 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	\N	5039	0	\N	\N
14070	MEMBRE	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8633	0	\N	\N
14071	MEMBRE	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6141	0	\N	\N
14072	MEMBRE	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2819	0	\N	\N
14073	MEMBRE	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1491	0	\N	\N
14074	MEMBRE	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6153	0	\N	\N
14075	MEMBRE	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1460	0	\N	\N
14076	MEMBRE	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10997	0	\N	\N
14077	PDTDEL	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Guyana	\N	12772	2	\N	\N
14078	PDTDEL	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Suriname	\N	12773	3	\N	\N
14080	VICPDT	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12774	6	\N	\N
14081	VICPDT	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12775	9	\N	\N
14082	SECRET	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12776	11	\N	\N
14083	MEMBRE	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1424	0	\N	\N
14505	VICPDT	2009-02-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13087	\N	\N	\N
14506	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13101	\N	\N	\N
14507	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13102	\N	\N	\N
14508	VICPDT	2009-02-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7937	\N	\N	\N
14509	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13103	\N	\N	\N
14512	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13105	\N	\N	\N
14522	SECRET	2009-02-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13060	\N	\N	\N
14532	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13110	\N	\N	\N
14533	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13111	\N	\N	\N
14534	MEMBRE	2008-10-01 00:00:00	2009-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	13112	\N	\N	\N
14535	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13113	\N	\N	\N
14536	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13114	\N	\N	\N
14552	PDT	2009-02-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13112	\N	\N	\N
14553	VICPDT	2009-02-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7560	\N	\N	\N
14555	SECRET	2009-02-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13117	\N	\N	\N
14556	SECRET	2009-02-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13126	\N	\N	\N
14557	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13130	\N	\N	\N
14558	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13131	\N	\N	\N
14559	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13132	\N	\N	\N
14560	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13134	\N	\N	\N
14561	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13135	\N	\N	\N
13844	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12603	\N	\N	\N
13845	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12604	\N	\N	\N
13846	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12605	\N	\N	\N
13847	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12606	\N	\N	\N
13848	MEMBRE	2008-10-01 00:00:00	2010-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	12607	\N	\N	\N
13849	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12608	\N	\N	\N
13851	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12610	\N	\N	\N
13852	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12611	\N	\N	\N
13853	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12612	\N	\N	\N
13854	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12613	\N	\N	\N
13856	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12615	\N	\N	\N
7103	SECRET	2001-10-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7238	\N	\N	\N
13858	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12617	\N	\N	\N
13859	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12618	\N	\N	\N
13860	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12619	\N	\N	\N
13871	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12631	\N	\N	\N
13872	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12632	\N	\N	\N
13873	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12633	\N	\N	\N
13874	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12634	\N	\N	\N
13875	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12635	\N	\N	\N
13876	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12636	\N	\N	\N
13877	MEMBRE	2008-10-01 00:00:00	2010-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	12637	\N	\N	2015-11-12 15:26:22
13878	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12638	\N	\N	\N
13879	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12639	\N	\N	\N
13880	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12640	\N	\N	\N
13881	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12641	\N	\N	\N
13882	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12642	\N	\N	\N
13883	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12643	\N	\N	\N
13884	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12644	\N	\N	\N
13885	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12645	\N	\N	\N
13886	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12646	\N	\N	\N
13887	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12647	\N	\N	\N
13888	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12648	\N	\N	\N
13889	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1265	\N	\N	\N
13895	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12655	\N	\N	\N
13897	MEMBRE	1999-01-01 00:00:00	2009-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	12657	0	\N	\N
13898	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12658	\N	\N	\N
13899	MEMBRE	1999-01-01 00:00:00	2009-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	12659	0	\N	\N
13900	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12660	\N	\N	\N
13901	MEMBRE	1999-01-01 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	12661	\N	\N	\N
13902	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12663	\N	\N	\N
13904	MEMBRE	1999-01-01 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	12664	\N	\N	\N
13905	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12665	\N	\N	\N
13906	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12667	\N	\N	\N
13908	MEMBRE	1999-01-01 00:00:00	2010-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	12668	\N	\N	\N
13909	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12669	\N	\N	\N
13910	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12670	\N	\N	\N
13911	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12671	\N	\N	\N
13912	MEMBRE	1999-01-01 00:00:00	2009-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	12672	0	\N	\N
13913	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12673	\N	\N	\N
13914	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12674	\N	\N	\N
13915	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12675	\N	\N	\N
13916	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12676	\N	\N	\N
13917	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12677	\N	\N	\N
13918	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12678	\N	\N	\N
13919	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12679	\N	\N	\N
13920	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12680	\N	\N	\N
13921	MEMBRE	1999-01-01 00:00:00	2011-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	12681	\N	\N	\N
13922	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12682	\N	\N	\N
13923	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12683	\N	\N	\N
13924	MEMBRE	1999-01-01 00:00:00	2009-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	12684	0	\N	\N
13925	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12685	\N	\N	\N
13926	MEMBRE	1999-01-01 00:00:00	2009-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	12686	0	\N	\N
13927	MEMBRE	2009-01-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12687	\N	\N	\N
13928	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12688	\N	\N	\N
13929	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12689	\N	\N	\N
14084	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12777	\N	\N	\N
14085	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12778	\N	\N	\N
14086	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12779	\N	\N	\N
14087	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12780	\N	\N	\N
14088	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12781	\N	\N	\N
14089	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12782	\N	\N	\N
14090	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12783	\N	\N	\N
14091	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12784	\N	\N	\N
14092	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12785	\N	\N	\N
14093	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12786	\N	\N	\N
14094	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12787	\N	\N	\N
14095	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12788	\N	\N	\N
14096	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12789	\N	\N	\N
14097	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12790	\N	\N	\N
14098	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12791	\N	\N	\N
14099	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12792	\N	\N	\N
14100	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12793	\N	\N	\N
14101	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12794	\N	\N	\N
14102	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12795	\N	\N	\N
14103	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12796	\N	\N	\N
14104	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12797	\N	\N	\N
14105	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12798	\N	\N	\N
14106	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12799	\N	\N	\N
14107	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12800	\N	\N	\N
14108	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12801	\N	\N	\N
14109	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12802	\N	\N	\N
14110	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12803	\N	\N	\N
14127	PDTDEL	2009-02-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Malawi	\N	12292	4	\N	\N
14128	PDTDEL	2009-02-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Namibie	\N	12807	5	\N	\N
14129	PDTDEL	2009-02-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Zambie	\N	5438	6	\N	\N
14130	VICPDT	2009-02-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12275	9	\N	\N
14131	SECRET	2009-02-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12281	10	\N	\N
14132	SECRET	2009-02-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12276	11	\N	\N
14133	SECRET	2009-02-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10334	12	\N	\N
14134	MEMBRE	2009-02-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5451	0	\N	\N
14168	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12841	\N	\N	\N
14169	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12842	\N	\N	\N
14754	MEMBRE	2001-10-01 00:00:00	2005-09-20 00:00:00	ANCIEN	\N	\N	\N	\N	10782	\N	\N	\N
14734	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10416	\N	\N	\N
14739	VICPDT	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10418	\N	\N	\N
14741	VICPDT	2005-05-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	10414	\N	\N	\N
14785	VICPDT	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2100	3	\N	\N
14786	VICPDT	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12262	4	\N	\N
14787	VICPDT	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5929	6	\N	\N
14788	SECRET	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12267	8	\N	\N
14789	TRESOR	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12269	9	\N	\N
14790	MEMBREBUR	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3258	10	\N	\N
14791	MEMBREBUR	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12263	11	\N	\N
14792	PDTDEL	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Burkina Faso	\N	9359	3	\N	\N
14793	PDTDEL	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Cap-Vert	\N	12511	4	\N	\N
14862	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13309	\N	\N	\N
14863	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13310	\N	\N	\N
14864	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13311	\N	\N	\N
14912	MEMBRE	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13343	\N	\N	\N
14913	MEMBRE	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13344	\N	\N	\N
3042	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3083	\N	\N	\N
15022	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13431	\N	\N	\N
15031	MEMBRE	2009-01-29 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2539	\N	\N	\N
15032	VICPDT	2009-01-29 00:00:00	2010-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	11596	8	\N	2015-11-12 15:26:22
15033	SECRET	2009-01-29 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13282	\N	\N	\N
15034	SECRET	2009-01-29 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13283	\N	\N	\N
15035	SECRET	2009-01-29 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8522	\N	\N	\N
15036	SECRET	2009-01-29 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13287	\N	\N	\N
15037	SECRET	2009-01-29 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13290	\N	\N	\N
15038	SECRET	2009-01-29 00:00:00	2009-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	5311	\N	\N	\N
15217	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13595	\N	\N	\N
15218	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13596	\N	\N	\N
15256	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13611	\N	\N	\N
15257	MEMBRE	2008-10-01 00:00:00	2009-09-09 00:00:00	ANCIEN	\N	\N	\N	\N	13612	\N	\N	\N
15258	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13613	\N	\N	\N
15264	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13619	\N	\N	\N
15265	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13620	\N	\N	\N
15266	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13621	\N	\N	\N
15480	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13783	\N	\N	\N
15622	MEMBRE	2009-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13874	\N	\N	\N
15677	PDTHON	2009-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	893	2	\N	\N
15678	PDT	2009-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9890	1	\N	\N
3052	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3093	\N	\N	\N
3072	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3114	5	\N	\N
3091	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3134	\N	\N	\N
3108	TRESOR	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3151	7	\N	\N
3125	MEMBRE	1999-01-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	3168	0	\N	\N
2921	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2957	\N	\N	\N
2931	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2967	\N	\N	\N
2958	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2994	\N	\N	\N
2968	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3004	\N	\N	\N
2993	PDT	1999-01-01 00:00:00	2009-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	3033	1	\N	\N
3353	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3416	\N	\N	\N
3368	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3431	\N	\N	\N
3384	MEMBRE	1999-01-01 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	3448	0	\N	\N
3414	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3478	\N	\N	\N
3426	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	3492	\N	\N	\N
3445	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3512	9	\N	\N
3463	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3530	\N	\N	\N
3493	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3563	\N	\N	\N
14727	MEMBRE	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8242	\N	\N	\N
14857	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13304	\N	\N	\N
14878	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13323	\N	\N	\N
14957	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13376	\N	\N	\N
14960	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13379	\N	\N	\N
14961	MEMBRE	2008-10-01 00:00:00	2009-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	13380	\N	\N	\N
14962	MEMBRE	2008-10-01 00:00:00	2009-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	13381	\N	\N	\N
14970	SECRET	2009-03-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13380	\N	\N	\N
11213	MEMBRE	2004-10-01 00:00:00	2009-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	10614	\N	\N	\N
14971	SECRET	2009-03-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10614	\N	\N	\N
14972	SECRET	2009-03-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13385	\N	\N	\N
11221	MEMBRE	2004-10-01 00:00:00	2009-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	10622	\N	\N	\N
14974	VICPDT	2009-03-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10622	\N	\N	\N
14975	SECRET	2009-03-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13387	\N	\N	\N
14989	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13399	\N	\N	\N
14990	MEMBRE	2008-10-01 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	13400	\N	\N	\N
14992	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13402	\N	\N	\N
14993	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13403	\N	\N	\N
15005	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13415	\N	\N	\N
15006	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13416	\N	\N	\N
15007	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13417	\N	\N	\N
15008	MEMBRE	2008-10-01 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	\N	13418	\N	\N	\N
15009	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13419	\N	\N	\N
15010	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13420	\N	\N	\N
15011	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13421	\N	\N	\N
15012	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13422	\N	\N	\N
15013	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13423	\N	\N	\N
15014	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13424	\N	\N	\N
15015	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13425	\N	\N	\N
15016	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13426	\N	\N	\N
15021	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13430	\N	\N	\N
2089	PDT	1999-01-01 00:00:00	2009-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	2089	1	\N	\N
1396	MEMBRE	1998-10-01 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	1396	0	\N	\N
295	MEMBRE	1998-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	295	\N	\N	\N
15027	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13436	\N	\N	\N
15028	MEMBRE	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13437	\N	\N	\N
15030	MEMBRE	2008-10-01 00:00:00	2010-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	13439	\N	\N	\N
15106	MEMBRE	2008-10-01 00:00:00	2009-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	13507	\N	\N	\N
15186	VICPDT	2009-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13576	\N	\N	\N
15199	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13591	\N	\N	\N
15213	MEMBRE	2009-04-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6579	\N	\N	\N
15214	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13592	\N	\N	\N
15216	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13594	\N	\N	\N
15249	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13604	\N	\N	\N
15250	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13605	\N	\N	\N
15251	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13606	\N	\N	\N
15252	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13607	\N	\N	\N
15253	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13608	\N	\N	\N
15267	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13622	\N	\N	\N
15317	VICPDT	2009-03-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8233	\N	\N	\N
15318	VICPDT	2009-03-17 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	8209	\N	\N	\N
15412	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13723	\N	\N	\N
15413	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13724	\N	\N	\N
15414	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13725	\N	\N	\N
15415	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13726	\N	\N	\N
15419	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13730	\N	\N	\N
15420	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13731	\N	\N	\N
15421	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13732	\N	\N	\N
15422	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13733	\N	\N	\N
15423	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13734	\N	\N	\N
15424	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13735	\N	\N	\N
15425	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13736	\N	\N	\N
15439	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13749	\N	\N	\N
15461	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13766	\N	\N	\N
15500	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13794	\N	\N	\N
15501	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13795	\N	\N	\N
15502	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13796	\N	\N	\N
15503	MEMBRE	2008-10-26 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	13797	\N	\N	\N
15539	SECRET	2009-07-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13375	\N	\N	\N
7576	MEMBRE	2001-10-01 00:00:00	2009-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	7637	\N	\N	\N
7196	MEMBRE	2001-10-01 00:00:00	2009-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	7313	\N	\N	\N
15583	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13847	\N	\N	\N
14750	MEMBRE	2008-10-01 00:00:00	2009-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	13248	\N	\N	\N
14751	SECRET	2009-02-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13248	\N	\N	\N
14753	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13250	\N	\N	\N
14950	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13369	\N	\N	\N
14973	PDT	2009-03-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13386	\N	\N	\N
15277	VICPDT	2009-04-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13635	4	\N	\N
14809	MEMBRE	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4595	0	\N	\N
14810	MEMBRE	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4583	0	\N	\N
14811	MEMBRE	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4601	0	\N	\N
14812	PDTDEL	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Sierra Leone	\N	11594	15	\N	\N
14894	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13330	\N	\N	\N
14982	MEMBRE	2008-10-01 00:00:00	2009-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	13393	\N	\N	\N
14984	PDT	2009-03-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6585	\N	\N	\N
14987	MEMBRE	2008-10-01 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	13397	\N	\N	\N
14999	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13409	\N	\N	\N
15018	VICPDT	2009-03-25 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13249	\N	\N	\N
15026	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13435	\N	\N	\N
15182	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13578	\N	\N	\N
15185	MEMBRE	2009-04-01 00:00:00	2009-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	13581	\N	\N	\N
15210	SECRET	2009-04-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13393	\N	\N	\N
15281	MEMBRE	2009-04-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13638	\N	\N	\N
15282	MEMBRE	2009-04-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13639	\N	\N	\N
11571	MEMBRE	2006-02-02 00:00:00	2009-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	10909	\N	\N	\N
15289	SECRET	2009-05-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10909	\N	\N	\N
11593	SECRET	2006-02-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10878	\N	\N	\N
15299	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13645	\N	\N	\N
15416	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13727	\N	\N	\N
15417	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13728	\N	\N	\N
15418	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13729	\N	\N	\N
15426	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13737	\N	\N	\N
15453	MEMBRE	2008-10-01 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	13758	\N	\N	\N
15455	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13760	\N	\N	\N
15468	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13770	\N	\N	\N
15469	MEMBRE	2008-11-26 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	13771	\N	\N	\N
15470	MEMBRE	2008-11-26 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	13772	\N	\N	\N
15471	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13773	\N	\N	\N
15472	MEMBRE	2008-11-26 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	13774	\N	\N	\N
15473	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13775	\N	\N	\N
15474	MEMBRE	2008-11-26 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	13776	\N	\N	\N
15475	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13777	\N	\N	\N
15476	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13779	\N	\N	\N
15534	VICPDT	2009-07-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13758	\N	\N	\N
15535	VICPDT	2009-07-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13371	\N	\N	\N
11595	MEMBRE	2006-02-01 00:00:00	2009-09-09 00:00:00	ANCIEN	\N	\N	\N	\N	10929	\N	\N	\N
12246	MEMBRE	2006-09-01 00:00:00	2009-09-09 00:00:00	ANCIEN	\N	\N	\N	\N	11521	\N	\N	\N
12294	MEMBRE	2006-09-01 00:00:00	2009-09-09 00:00:00	ANCIEN	\N	\N	\N	\N	11569	\N	\N	\N
15618	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13873	\N	\N	\N
15708	SECRET	2009-03-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13944	\N	\N	\N
15723	MEMBRE	2010-02-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13956	\N	\N	\N
3024	MEMBRE	1999-01-01 00:00:00	2003-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	3065	\N	\N	\N
3032	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3073	\N	\N	\N
14775	MEMBRE	2008-10-01 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	13264	\N	\N	\N
14776	MEMBRE	2008-10-01 00:00:00	2009-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	13265	\N	\N	\N
14777	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13266	\N	\N	\N
14778	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13267	\N	\N	\N
14779	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13269	\N	\N	\N
14780	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13270	\N	\N	\N
14781	MEMBRE	2008-10-01 00:00:00	2009-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	13271	\N	\N	\N
14782	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13272	\N	\N	\N
14783	MEMBRE	2008-10-01 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	13273	\N	\N	\N
15157	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13558	\N	\N	\N
15158	MEMBRE	2008-11-26 00:00:00	2009-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	13559	0	\N	\N
15159	MEMBRE	2008-11-26 00:00:00	2009-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	13560	0	\N	\N
15160	MEMBRE	2008-11-26 00:00:00	2009-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	13561	0	\N	\N
15161	MEMBRE	2008-11-26 00:00:00	2009-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	13562	0	\N	\N
15162	MEMBRE	2008-11-26 00:00:00	2009-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	13563	0	\N	\N
15163	MEMBRE	2008-11-26 00:00:00	2009-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	13564	0	\N	\N
15164	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13565	\N	\N	\N
15167	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13568	\N	\N	\N
15168	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13569	\N	\N	\N
15169	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13570	\N	\N	\N
15170	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13571	\N	\N	\N
15175	SECRET	2009-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13523	\N	\N	\N
15176	MEMBRE	2009-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7673	\N	\N	\N
15180	MEMBRE	2009-04-01 00:00:00	2009-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	13576	\N	\N	\N
15181	MEMBRE	2009-04-01 00:00:00	2009-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	13577	\N	\N	\N
15187	VICPDT	2009-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13577	\N	\N	\N
15188	VICPDT	2009-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13581	\N	\N	\N
15198	TRESOR	2009-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13579	\N	\N	\N
15211	SECRET	2009-04-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13315	\N	\N	\N
15212	SECRET	2009-04-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13433	\N	\N	\N
15238	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13597	\N	\N	\N
15254	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13609	\N	\N	\N
15255	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13610	\N	\N	\N
15283	PDT	2009-05-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10912	\N	\N	\N
15286	VICPDT	2009-05-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10950	\N	\N	\N
15287	VICPDT	2009-05-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10888	\N	\N	\N
15288	PDTHON	2009-05-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10958	\N	\N	\N
14946	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13366	\N	\N	\N
14986	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13396	\N	\N	\N
15023	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13432	\N	\N	\N
15024	MEMBRE	2008-10-01 00:00:00	2009-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	13433	\N	\N	\N
15025	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13434	\N	\N	\N
15284	VICPDT	2009-05-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11099	\N	\N	\N
15285	VICPDT	2009-05-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13507	\N	\N	\N
15292	SECRET	2009-05-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13517	\N	\N	\N
15309	VICPDTDRT	2008-12-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Pays andins	\N	8826	2	\N	\N
15310	VICPDTDRT	2008-12-02 00:00:00	2011-10-05 00:00:00	ANCIEN	\N	\N	Pays du Cône Sud	\N	11958	5	\N	\N
15385	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13696	\N	\N	\N
15456	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13761	\N	\N	\N
15457	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13762	\N	\N	\N
15458	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13763	\N	\N	\N
15459	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13764	\N	\N	\N
15460	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13765	\N	\N	\N
15486	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13789	\N	\N	\N
14925	MEMBRE	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13356	\N	\N	\N
15410	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13721	\N	\N	\N
14991	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13401	\N	\N	\N
15184	MEMBRE	2009-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13580	\N	\N	\N
15189	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13582	\N	\N	\N
15190	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13583	\N	\N	\N
15191	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13584	\N	\N	\N
15192	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13585	\N	\N	\N
15193	MEMBRE	2008-11-26 00:00:00	2009-03-30 00:00:00	ANCIEN	\N	\N	\N	\N	13586	0	\N	\N
15194	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13587	\N	\N	\N
15195	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13588	\N	\N	\N
15196	MEMBRE	2008-11-26 00:00:00	2009-03-30 00:00:00	ANCIEN	\N	\N	\N	\N	13589	0	\N	\N
15197	MEMBRE	2008-11-26 00:00:00	2009-03-30 00:00:00	ANCIEN	\N	\N	\N	\N	13590	0	\N	\N
15215	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13593	\N	\N	\N
15268	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13624	\N	\N	\N
15403	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13714	\N	\N	\N
15404	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13715	\N	\N	\N
15405	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13716	\N	\N	\N
15406	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13717	\N	\N	\N
15407	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13718	\N	\N	\N
15408	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13719	\N	\N	\N
15409	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13720	\N	\N	\N
15411	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13722	\N	\N	\N
15435	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13745	\N	\N	\N
15436	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13746	\N	\N	\N
15437	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13747	\N	\N	\N
15438	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13748	\N	\N	\N
15428	MEMBRE	2008-11-26 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	\N	13738	\N	\N	\N
15489	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13792	\N	\N	\N
8915	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8740	\N	\N	\N
15551	PDT	2009-07-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13333	\N	\N	\N
15552	VICPDT	2009-07-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13332	\N	\N	\N
15588	MEMBRE	2009-09-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13852	\N	\N	\N
15554	VICPDT	2009-07-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13339	\N	\N	\N
15498	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13793	\N	\N	\N
15499	SECRET	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12692	11	\N	\N
15511	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13805	\N	\N	\N
15512	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13807	\N	\N	\N
15513	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13808	\N	\N	\N
15514	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13809	\N	\N	\N
15515	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13810	\N	\N	\N
15516	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13811	\N	\N	\N
15517	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13812	\N	\N	\N
15518	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13813	\N	\N	\N
15519	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13814	\N	\N	\N
15520	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13815	\N	\N	\N
10918	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10392	\N	\N	\N
15524	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13806	\N	\N	\N
6723	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6574	\N	\N	\N
11054	VICPDT	2005-03-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10431	\N	\N	\N
15300	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13646	\N	\N	\N
15301	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13647	\N	\N	\N
15302	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13648	\N	\N	\N
15305	VICPDT	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13305	3	\N	\N
15306	SECRET	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13264	\N	\N	\N
15308	VICPDTDRT	2008-12-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Québec	\N	12198	7	\N	\N
15485	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13788	\N	\N	\N
15541	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13818	\N	\N	\N
10378	VICPDT	2004-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9945	\N	\N	\N
10996	MEMBRE	2005-03-15 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	10434	\N	\N	\N
15555	VICPDT	2009-07-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13345	\N	\N	\N
15556	VICPDT	2009-07-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8027	\N	\N	\N
15557	VICPDT	2009-07-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13357	\N	\N	\N
15558	VICPDT	2009-07-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13359	\N	\N	\N
15559	SECRET	2009-07-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13335	\N	\N	\N
15560	SECRET	2009-07-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13338	\N	\N	\N
15561	SECRET	2009-07-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13342	\N	\N	\N
15562	SECRET	2009-07-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13350	\N	\N	\N
15563	SECRET	2009-07-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13351	\N	\N	\N
15564	SECRET	2009-07-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13361	\N	\N	\N
15565	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13829	\N	\N	\N
15566	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13830	\N	\N	\N
15567	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13831	\N	\N	\N
15568	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13832	\N	\N	\N
15569	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13833	\N	\N	\N
15570	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13834	\N	\N	\N
15571	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13835	\N	\N	\N
15572	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13836	\N	\N	\N
15573	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13837	\N	\N	\N
15574	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13838	\N	\N	\N
15575	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13839	\N	\N	\N
15576	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13840	\N	\N	\N
15577	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13841	\N	\N	\N
15578	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13842	\N	\N	\N
15623	MEMBRE	2009-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13875	\N	\N	\N
15624	MEMBRE	2009-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13876	\N	\N	\N
14813	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13274	\N	\N	\N
14994	MEMBRE	2008-10-01 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	13404	\N	\N	\N
15166	MEMBRE	2008-10-01 00:00:00	2009-03-31 00:00:00	ANCIEN	\N	\N	\N	\N	13567	\N	\N	\N
15203	VICPDT	2009-04-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6566	\N	\N	\N
15204	VICPDT	2009-04-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13316	\N	\N	\N
15205	VICPDT	2009-04-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13317	\N	\N	\N
15206	VICPDT	2009-04-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9037	\N	\N	\N
10913	MEMBRE	2004-10-01 00:00:00	2009-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	10387	\N	\N	\N
15207	VICPDT	2009-04-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10387	\N	\N	\N
15208	VICPDT	2009-04-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13318	\N	\N	\N
15209	VICPDT	2009-04-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13319	\N	\N	\N
15219	VICPDT	2009-03-31 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10284	4	\N	\N
15220	VICPDT	2009-03-31 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	\N	13589	5	\N	\N
15221	VICPDT	2009-03-31 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13590	6	\N	\N
15222	SECRET	2009-03-31 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13586	7	\N	\N
15223	VICPDT	2009-02-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13449	8	\N	\N
15224	VICPDT	2009-02-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13454	11	\N	\N
15225	VICPDT	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13527	7	\N	\N
15226	VICPDT	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13559	8	\N	\N
15228	SECRET	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13534	10	\N	\N
15229	SECRET	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13541	11	\N	\N
15230	SECRET	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13550	12	\N	\N
15231	SECRET	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13560	13	\N	\N
15232	SECRET	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13561	14	\N	\N
15233	SECRET	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13562	15	\N	\N
15234	SECRET	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13563	16	\N	\N
15235	SECRET	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13564	17	\N	\N
15236	TRESOR	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13552	18	\N	\N
15237	TRESORADJ	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13557	19	\N	\N
15311	MEMBRE	2008-10-01 00:00:00	2010-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	13652	\N	\N	\N
15312	PDTHON	2009-03-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8253	\N	\N	\N
15343	MEMBRE	2008-10-01 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	\N	13658	\N	\N	\N
15381	MEMBRE	2009-05-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5990	\N	\N	\N
15382	VICPDT	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12536	24	\N	\N
15383	VICPDT	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12528	25	\N	\N
15316	VICPDT	2009-03-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8251	\N	\N	\N
8568	MEMBRE	2001-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8449	\N	\N	\N
8569	MEMBRE	2001-01-01 00:00:00	2001-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	8450	\N	\N	\N
8570	PDT	2001-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8438	\N	\N	\N
8571	VICPDT	2001-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8319	\N	\N	\N
8572	VICPDT	2001-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8447	\N	\N	\N
8574	SECRET	2001-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8440	\N	\N	\N
8575	SECRET	2001-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8427	\N	\N	\N
8576	SECRET	2001-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8426	\N	\N	\N
8573	VICPDT	2001-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8450	\N	\N	\N
11659	MEMBRE	2004-10-01 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	10989	\N	\N	\N
8549	MEMBRE	2001-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8430	\N	\N	\N
8557	MEMBRE	2001-01-01 00:00:00	2001-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	8438	\N	\N	\N
8564	MEMBRE	2001-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8445	\N	\N	\N
8540	MEMBRE	2001-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8421	\N	\N	\N
7666	MEMBRE	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	7691	\N	\N	\N
7673	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7698	\N	\N	\N
7698	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7718	\N	\N	\N
7706	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7726	\N	\N	\N
14698	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13233	\N	\N	\N
14708	MEMBRE	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7230	\N	\N	\N
14709	PDT	2009-03-03 00:00:00	2010-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	11326	\N	\N	\N
13621	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12447	\N	\N	\N
14371	TRESOR	2009-02-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8741	\N	\N	\N
14448	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13051	\N	\N	\N
14449	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13052	\N	\N	\N
14450	MEMBRE	2008-10-01 00:00:00	2009-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	13053	\N	\N	\N
14451	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13054	\N	\N	\N
14452	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13055	\N	\N	\N
14453	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13056	\N	\N	\N
14457	SECRET	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13046	\N	\N	\N
14458	SECRET	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13053	\N	\N	\N
14459	MEMBRE	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8278	\N	\N	\N
14699	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13234	\N	\N	\N
14700	MEMBRE	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13235	\N	\N	\N
14702	PDTDEL	2009-02-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Djibouti	\N	10247	2	\N	\N
14703	PDTDEL	2009-02-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Erythrée	\N	6426	3	\N	\N
14704	PDTDEL	2009-02-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Ethiopie	\N	13236	4	\N	\N
14705	SECRET	2009-02-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13237	7	\N	\N
14706	MEMBRE	2009-02-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2871	0	\N	\N
14710	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13239	\N	\N	\N
14711	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13240	\N	\N	\N
14712	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13241	\N	\N	\N
14713	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13242	\N	\N	\N
3919	SECRET	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3961	11	\N	\N
3938	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3981	\N	\N	\N
9210	SECRET	2004-11-03 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8216	\N	\N	\N
14718	MEMBRE	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8216	\N	\N	\N
14719	MEMBRE	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8217	\N	\N	\N
8358	SECRET	2003-10-10 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8226	\N	\N	\N
14720	MEMBRE	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8226	\N	\N	\N
9225	SECRET	2004-11-03 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8229	\N	\N	\N
14721	MEMBRE	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8229	\N	\N	\N
8347	VICPDT	2003-10-10 00:00:00	2009-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	8230	\N	\N	\N
13750	PDT	2009-01-27 00:00:00	2009-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	12559	1	\N	\N
13751	VICPDT	2009-01-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5818	2	\N	\N
13752	VICPDT	2009-01-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2090	3	\N	\N
13753	VICPDT	2009-01-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11713	4	\N	\N
13754	VICPDT	2009-01-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12560	5	\N	\N
13755	VICPDT	2009-01-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12561	6	\N	\N
13756	VICPDT	2009-01-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12562	7	\N	\N
13757	VICPDT	2009-01-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12563	9	\N	\N
13758	VICPDT	2009-01-27 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	12564	10	\N	\N
13759	VICPDT	2009-01-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5825	11	\N	\N
13760	VICPDT	2009-01-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9353	12	\N	\N
13761	SECRET	2009-01-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9342	13	\N	\N
13762	MEMBRE	2009-01-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5817	0	\N	\N
13763	MEMBRE	2009-01-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2453	0	\N	\N
13764	MEMBRE	2009-01-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9358	0	\N	\N
13765	MEMBRE	2009-01-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5828	0	\N	\N
13766	PDT	2009-01-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12565	1	\N	\N
13767	VICPDT	2009-01-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10786	3	\N	\N
13768	VICPDT	2009-01-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12566	4	\N	\N
13769	VICPDT	2009-01-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12567	5	\N	\N
13770	SECRET	2009-01-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10802	6	\N	\N
13771	MEMBRE	2009-01-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6553	0	\N	\N
14041	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12753	\N	\N	\N
14042	MEMBRE	2008-10-01 00:00:00	2009-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	12754	\N	\N	\N
14043	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12755	\N	\N	\N
14044	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12756	\N	\N	\N
14045	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12757	\N	\N	\N
14046	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12758	\N	\N	\N
14047	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12759	\N	\N	\N
14048	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12760	\N	\N	\N
14621	MEMBRE	2009-02-17 00:00:00	2009-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	13172	\N	\N	\N
14622	MEMBRE	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13173	\N	\N	\N
14623	MEMBRE	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13174	\N	\N	\N
14624	MEMBRE	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13175	\N	\N	\N
14625	MEMBRE	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13176	\N	\N	\N
14626	MEMBRE	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13177	\N	\N	\N
14051	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12763	\N	\N	\N
14052	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12764	\N	\N	\N
14053	MEMBRE	2008-10-01 00:00:00	2009-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	12765	0	\N	\N
14054	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12766	\N	\N	\N
14473	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13070	\N	\N	\N
14497	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13094	\N	\N	\N
14548	MEMBRE	2008-10-01 00:00:00	2009-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	13126	\N	\N	\N
14549	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13127	\N	\N	\N
14550	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13128	\N	\N	\N
14551	MEMBRE	2008-10-01 00:00:00	2009-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	13129	\N	\N	\N
14587	VICPDT	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8789	\N	\N	\N
14588	VICPDT	2009-02-03 00:00:00	2010-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	7232	\N	\N	\N
14589	SECRET	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12609	\N	\N	\N
14590	SECRET	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12614	\N	\N	\N
14591	SECRET	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12616	\N	\N	\N
14627	MEMBRE	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13178	\N	\N	\N
14628	MEMBRE	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13179	\N	\N	\N
14629	MEMBRE	2009-02-17 00:00:00	2009-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	13180	\N	\N	\N
14630	MEMBRE	2009-02-17 00:00:00	2009-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	13181	\N	\N	\N
14631	MEMBRE	2009-02-17 00:00:00	2009-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	13182	\N	\N	\N
14632	MEMBRE	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13183	\N	\N	\N
14633	MEMBRE	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13184	\N	\N	\N
14634	MEMBRE	2009-02-17 00:00:00	2009-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	13185	\N	\N	\N
14635	MEMBRE	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13186	\N	\N	\N
14638	VICPDT	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13181	\N	\N	\N
14639	VICPDT	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13172	\N	\N	\N
14640	VICPDT	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13180	\N	\N	\N
14641	SECRET	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13185	\N	\N	\N
14642	SECRET	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13182	\N	\N	\N
14643	SECRET	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13188	\N	\N	\N
14644	MEMBRE	2009-02-17 00:00:00	2009-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	13189	\N	\N	\N
14645	MEMBRE	2009-02-17 00:00:00	2009-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	13190	\N	\N	\N
14646	PDT	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13189	\N	\N	\N
14647	SECRET	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13190	\N	\N	\N
14649	VICPDT	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8661	\N	\N	\N
14650	VICPDT	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12744	\N	\N	\N
14651	VICPDT	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12745	\N	\N	\N
14652	VICPDT	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8667	\N	\N	\N
14537	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13115	\N	\N	\N
14599	MEMBRE	2008-10-01 00:00:00	2009-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	13167	\N	\N	\N
14600	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13168	\N	\N	\N
14601	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13169	\N	\N	\N
14602	MEMBRE	2008-10-01 00:00:00	2009-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	13170	\N	\N	\N
14615	PDTDEL	2009-01-21 00:00:00	2010-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	11613	\N	\N	\N
14653	SECRET	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12738	\N	\N	\N
14658	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13193	\N	\N	\N
14656	SECRET	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12740	\N	\N	\N
14661	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13196	\N	\N	\N
14660	MEMBRE	2008-10-01 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	13195	\N	\N	\N
14662	MEMBRE	2008-10-01 00:00:00	2009-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	13197	\N	\N	\N
14663	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13199	\N	\N	\N
14664	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13198	\N	\N	\N
14665	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13200	\N	\N	\N
14666	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13202	\N	\N	\N
14667	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13201	\N	\N	\N
14668	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13204	\N	\N	\N
14669	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13203	\N	\N	\N
14670	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13205	\N	\N	\N
14671	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13206	\N	\N	\N
14672	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13207	\N	\N	\N
14673	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13208	\N	\N	\N
14674	MEMBRE	2008-10-01 00:00:00	2010-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	13209	\N	\N	\N
14675	MEMBRE	2008-10-01 00:00:00	2009-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	13210	\N	\N	\N
7702	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7722	\N	\N	\N
14678	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13213	\N	\N	\N
14679	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13214	\N	\N	\N
14680	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13215	\N	\N	\N
14681	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13216	\N	\N	\N
14684	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13219	\N	\N	\N
8547	MEMBRE	2001-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8428	\N	\N	\N
8548	MEMBRE	2001-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8429	\N	\N	\N
8550	MEMBRE	2001-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8431	\N	\N	\N
8551	MEMBRE	2001-01-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	8432	\N	\N	\N
8552	MEMBRE	2001-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8433	\N	\N	\N
8553	MEMBRE	2001-01-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	8434	\N	\N	\N
14170	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12843	\N	\N	\N
14171	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12844	\N	\N	\N
14172	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12845	\N	\N	\N
14173	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12846	\N	\N	\N
14174	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12847	\N	\N	\N
14175	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12848	\N	\N	\N
14176	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12849	\N	\N	\N
14177	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12850	\N	\N	\N
14178	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12851	\N	\N	\N
14179	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12852	\N	\N	\N
14180	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12853	\N	\N	\N
14181	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12854	\N	\N	\N
14182	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12855	\N	\N	\N
14183	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12856	\N	\N	\N
14184	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12857	\N	\N	\N
14185	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12858	\N	\N	\N
14981	MEMBRE	2009-03-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7250	\N	\N	\N
15276	PDT	2009-04-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13634	1	\N	\N
15278	VICPDT	2009-04-28 00:00:00	2010-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	13636	5	\N	2015-11-12 15:26:22
15279	SECRET	2009-04-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10236	6	\N	\N
15280	TRESOR	2009-04-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13637	7	\N	\N
15293	MEMBRE	2008-10-01 00:00:00	2009-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	13640	\N	\N	\N
15294	SECRET	2009-05-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13640	\N	\N	\N
15314	VICPDT	2009-03-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13025	\N	\N	\N
15319	VICPDTDEL	2009-03-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10800	\N	\N	\N
15320	VICPDTDEL	2009-03-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9027	\N	\N	\N
15321	VICPDTDEL	2009-03-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8230	\N	\N	\N
15322	VICPDTDEL	2009-03-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8208	\N	\N	\N
15323	VICPDTDEL	2009-03-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8206	\N	\N	\N
15325	VICPDTDEL	2009-03-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8199	\N	\N	\N
15326	SECRET	2009-03-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9018	\N	\N	\N
15327	SECRET	2009-03-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8200	\N	\N	\N
15329	SECRET	2009-03-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13016	\N	\N	\N
15330	SECRET	2009-03-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13027	\N	\N	\N
15331	SECRET	2009-03-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13036	\N	\N	\N
15580	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13844	\N	\N	\N
15615	MEMBRE	2009-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13870	\N	\N	\N
15595	VICPDT	2009-10-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12925	\N	\N	\N
15596	VICPDT	2009-10-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12864	\N	\N	\N
15616	MEMBRE	2009-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13871	\N	\N	\N
15617	MEMBRE	2009-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13872	\N	\N	\N
15628	MEMBRE	2009-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13880	\N	\N	\N
15650	MEMBRE	2009-10-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13902	\N	\N	\N
15653	PDT	2009-10-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11703	1	\N	\N
15654	VICPDT	2009-10-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6471	2	\N	\N
15655	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13903	\N	\N	\N
15656	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13904	\N	\N	\N
15657	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13905	\N	\N	\N
15658	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13906	\N	\N	\N
15386	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13697	\N	\N	\N
15387	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13698	\N	\N	\N
15388	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13699	\N	\N	\N
15497	MEMBRE	2009-06-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9437	\N	\N	\N
15477	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13780	\N	\N	\N
15660	MEMBRE	2008-10-01 00:00:00	2009-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	13908	\N	\N	\N
15659	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13907	\N	\N	\N
15661	MEMBRE	2009-10-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13909	\N	\N	\N
15662	MEMBRE	2009-10-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13910	\N	\N	\N
15664	PDTDEL	2009-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Estonie	\N	12723	2	\N	\N
15671	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13915	\N	\N	\N
15672	MEMBRE	2009-11-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10459	\N	\N	\N
15675	MEMBRE	2009-10-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13918	\N	\N	\N
15686	MEMBRE	2009-06-25 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13927	\N	\N	\N
15682	MEMBRE	2009-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13923	\N	\N	\N
12133	MEMBRE	2007-06-01 00:00:00	2010-01-07 00:00:00	ANCIEN	\N	\N	\N	\N	11417	\N	\N	\N
15688	MEMBRE	2009-04-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13929	\N	\N	\N
15689	MEMBRE	2010-01-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13930	\N	\N	\N
15690	MEMBRE	2010-01-26 00:00:00	2010-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	13931	0	\N	\N
15731	MEMBRE	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13958	\N	\N	\N
15709	MEMBRE	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13945	\N	\N	\N
15710	MEMBRE	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13946	\N	\N	\N
15732	MEMBRE	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13959	\N	\N	\N
15733	MEMBRE	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13960	\N	\N	\N
2842	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	2874	\N	\N	\N
2855	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2888	\N	\N	\N
2866	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2899	\N	\N	\N
2888	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2922	\N	\N	\N
2899	VICPDT	1999-01-01 00:00:00	2004-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	2933	5	\N	\N
2707	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2728	\N	\N	\N
2730	SECRETADJ	1999-01-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	2753	11	\N	\N
14815	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13276	\N	\N	\N
14816	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13277	\N	\N	\N
14817	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13278	\N	\N	\N
14818	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13279	\N	\N	\N
8558	MEMBRE	2001-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8439	\N	\N	\N
8559	MEMBRE	2001-01-01 00:00:00	2001-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	8440	\N	\N	\N
8560	MEMBRE	2001-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8441	\N	\N	\N
14336	PDT	2009-02-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12974	1	\N	\N
14337	PDTHON	2009-02-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10077	2	\N	\N
14328	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12967	\N	\N	\N
14329	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12968	\N	\N	\N
14330	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12969	\N	\N	\N
8926	SECRET	2004-11-02 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7260	\N	\N	\N
14331	VICPDT	2009-02-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7260	\N	\N	\N
14332	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12970	\N	\N	\N
14339	VICPDT	2009-02-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12976	3	\N	\N
14340	VICPDT	2009-02-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12977	5	\N	\N
14341	VICPDT	2009-02-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11090	6	\N	\N
14342	SECRET	2009-02-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12978	7	\N	\N
14343	SECRET	2009-02-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3924	9	\N	\N
14345	SECRET	2009-02-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12979	10	\N	\N
14347	MEMBRE	2009-02-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3907	0	\N	\N
14350	MEMBRE	2009-02-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6283	0	\N	\N
14369	SECRET	2009-02-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12995	5	\N	\N
8300	MEMBRE	2001-10-01 00:00:00	2003-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	8230	\N	\N	\N
8321	MEMBRE	2001-10-01 00:00:00	2003-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	8248	\N	\N	\N
8353	VICPDT	2003-10-10 00:00:00	2009-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	8251	\N	\N	\N
8377	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8277	\N	\N	\N
7796	MEMBRE	2001-10-01 00:00:00	2001-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	7801	\N	\N	\N
7830	MEMBRE	2001-10-01 00:00:00	2001-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	7835	\N	\N	\N
7845	MEMBRE	2001-10-01 00:00:00	2001-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	7845	\N	\N	\N
7872	MEMBRE	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	7865	\N	\N	\N
7912	MEMBRE	2001-10-01 00:00:00	2001-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	7905	\N	\N	\N
8025	MEMBRE	2003-06-25 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7977	\N	\N	\N
8805	VICPDT	2004-10-15 00:00:00	2008-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	8645	10	\N	\N
8814	MEMBRE	2004-10-01 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	8652	\N	\N	\N
8833	MEMBRE	2004-10-01 00:00:00	2006-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	8669	\N	\N	\N
8866	SECRET	2004-11-03 00:00:00	2008-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	8701	14	\N	\N
8916	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8741	\N	\N	\N
8944	MEMBRE	2004-10-01 00:00:00	2004-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	8762	\N	\N	\N
9005	MEMBRE	2004-10-18 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	8806	0	\N	\N
9024	MEMBRE	2004-10-18 00:00:00	2008-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	8826	\N	\N	\N
9063	MEMBRE	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	8868	\N	\N	\N
9136	MEMBRE	2004-10-15 00:00:00	2009-01-14 00:00:00	ANCIEN	\N	\N	\N	\N	8942	\N	\N	\N
8517	MEMBRE	2003-06-30 00:00:00	2004-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	8395	\N	\N	\N
8617	MEMBRE	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8490	\N	\N	\N
8626	MEMBRE	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8499	\N	\N	\N
8636	MEMBRE	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8509	\N	\N	\N
8653	MEMBRE	2003-11-28 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	8518	\N	\N	\N
8665	MEMBRE	2004-02-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	8531	\N	\N	\N
8687	MEMBRE	2004-07-06 00:00:00	2004-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	8553	\N	\N	\N
8738	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8587	\N	\N	\N
8755	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8604	\N	\N	\N
9542	PDTDEL	2004-11-10 00:00:00	2009-01-20 00:00:00	ANCIEN	\N	\N	Kirghizstan	\N	1903	6	\N	\N
9585	MEMBRE	2004-10-01 00:00:00	2009-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	9359	\N	\N	\N
9605	MEMBRE	2004-10-01 00:00:00	2009-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	9379	0	\N	\N
9641	VICPDT	2004-12-01 00:00:00	2009-01-14 00:00:00	ANCIEN	\N	\N	\N	\N	5481	\N	\N	\N
9680	MEMBRE	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	9440	\N	\N	\N
9738	TRESOR	2004-11-24 00:00:00	2009-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	3210	10	\N	\N
9747	SECRET	2004-11-18 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	8400	7	\N	\N
9763	MEMBRE	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	9487	\N	\N	\N
9224	SECRET	2004-11-03 00:00:00	2009-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	8208	\N	\N	\N
9242	MEMBRE	2004-10-01 00:00:00	2009-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	9037	\N	\N	\N
9298	VICPDT	2004-11-16 00:00:00	2009-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	5667	7	\N	\N
9308	SECRET	2004-11-16 00:00:00	2009-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	5648	26	\N	\N
9343	MEMBRE	2004-10-01 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	9109	0	\N	\N
9366	MEMBRE	2004-10-01 00:00:00	2007-06-05 00:00:00	ANCIEN	\N	\N	\N	\N	9137	0	\N	\N
9394	MEMBRE	2004-10-01 00:00:00	2009-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	9167	0	\N	\N
9426	MEMBRE	2004-10-01 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	9199	0	\N	\N
10147	MEMBRE	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	9774	\N	\N	\N
10162	MEMBRE	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	9790	\N	\N	\N
10173	MEMBRE	2004-10-01 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	9801	\N	\N	\N
10210	MEMBRE	2004-11-09 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	2070	\N	\N	\N
10239	MEMBREBUR	2004-12-09 00:00:00	2006-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	4485	7	\N	\N
10279	MEMBRE	2004-12-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	9898	\N	\N	\N
10301	VICPDT	2004-12-01 00:00:00	2008-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	4247	6	\N	\N
10329	MEMBRE	2004-10-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	9923	\N	\N	\N
10383	MEMBRE	2004-10-01 00:00:00	2007-10-23 00:00:00	ANCIEN	\N	\N	\N	\N	9954	\N	\N	\N
9160	VICPDT	2004-10-15 00:00:00	2009-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	8966	5	\N	\N
9800	SECRET	2004-10-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	9525	16	\N	\N
9819	MEMBRE	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	9543	\N	\N	\N
9849	VICPDT	2004-11-24 00:00:00	2009-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	5828	\N	\N	\N
9868	MEMBRE	2004-10-01 00:00:00	2009-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	9569	\N	\N	\N
9920	MEMBREBUR	2004-10-01 00:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	9617	24	\N	\N
9947	VICPDT	2004-10-01 00:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	9645	11	\N	\N
9988	VICPDT	2004-12-14 00:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	4796	8	\N	\N
9997	MEMBREBUR	2004-12-14 00:00:00	2008-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	4816	31	\N	\N
10017	TRESOR	2004-11-30 00:00:00	2009-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	4601	28	\N	\N
10047	MEMBRE	2004-12-08 00:00:00	2009-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	5081	\N	\N	\N
10064	SECRET	2004-11-03 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	2556	\N	\N	\N
10077	MEMBRE	2004-10-01 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	9695	\N	\N	\N
10718	TRESOR	2004-10-26 00:00:00	2009-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	7675	\N	\N	\N
10728	MEMBRE	2004-10-01 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	10216	\N	\N	\N
10767	VICPDT	2005-02-09 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	6489	4	\N	\N
10794	MEMBRE	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	10268	\N	\N	\N
10806	MEMBRE	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	10280	\N	\N	\N
10821	MEMBRE	2004-10-01 00:00:00	2005-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	10298	\N	\N	\N
10860	SECRET	2004-10-01 00:00:00	2009-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	10329	12	\N	\N
10924	VICPDT	2004-11-23 00:00:00	2009-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	2422	\N	\N	\N
10993	MEMBRE	2005-03-15 00:00:00	2005-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	10431	\N	\N	\N
11013	SECRET	2005-03-18 00:00:00	2005-03-22 00:00:00	ANCIEN	\N	\N	\N	\N	10431	\N	\N	\N
11045	SECRET	2005-03-18 00:00:00	2009-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	10459	\N	\N	\N
10490	SECRET	2004-10-01 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	10066	17	\N	\N
10543	SECRET	2004-10-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	10126	12	\N	\N
3828	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3532	\N	\N	\N
3435	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3501	6	\N	\N
3486	SECRET	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3555	7	\N	\N
3669	MEMBRE	1999-01-01 00:00:00	2002-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3742	\N	\N	\N
3764	MEMBRE	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3839	\N	\N	\N
3811	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3888	\N	\N	\N
3922	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3965	\N	\N	\N
3953	MEMBRE	1999-12-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4002	\N	\N	\N
3979	VICPDT	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4030	2	\N	\N
3997	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4049	\N	\N	\N
4019	SECRET	1999-01-01 00:00:00	2004-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	3963	12	\N	\N
4035	MEMBRE	2000-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4087	\N	\N	\N
2838	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2870	7	\N	\N
4075	PDTDEL	1999-01-01 00:00:00	2009-02-11 00:00:00	ANCIEN	\N	\N	Angola	\N	210	2	\N	\N
4088	MEMBRE	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4134	\N	\N	\N
4099	MEMBRE	2000-11-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4146	\N	\N	\N
4117	VICPDT	2000-11-01 00:00:00	2001-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	4167	3	\N	\N
4131	MEMBRE	2000-11-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4181	\N	\N	\N
3157	MEMBRE	1999-01-01 00:00:00	2004-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	3200	\N	\N	\N
3201	SECRET	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3255	6	\N	\N
3282	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3343	\N	\N	\N
3346	TRESOR	1999-01-01 00:00:00	2009-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	3409	9	\N	\N
4481	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4590	\N	\N	\N
6207	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6142	\N	\N	\N
6256	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6192	\N	\N	\N
6374	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6274	\N	\N	\N
7211	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7324	\N	\N	\N
8720	VICPDT	2004-11-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7325	\N	\N	\N
7256	SECRET	2001-10-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7326	\N	\N	\N
7260	MEMBRE	2002-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7363	\N	\N	\N
7275	MEMBRE	2002-01-01 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	7378	\N	\N	\N
7285	MEMBRE	2002-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7388	\N	\N	\N
7307	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7404	\N	\N	\N
7444	VICPDT	2001-10-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7422	\N	\N	\N
7441	VICPDT	2001-10-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7430	\N	\N	\N
12050	PDT	2007-04-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7447	\N	\N	\N
7377	SECRET	2001-10-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7448	\N	\N	\N
8906	SECRET	2004-10-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7479	\N	\N	\N
7404	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7489	\N	\N	\N
7428	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7513	\N	\N	\N
7488	SECRET	2001-10-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7519	\N	\N	\N
8816	SECRET	2004-11-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7527	\N	\N	\N
6736	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6587	\N	\N	\N
8900	VICPDT	2004-10-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6603	\N	\N	\N
7123	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7253	\N	\N	\N
7139	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7269	\N	\N	\N
7186	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7303	\N	\N	\N
7200	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7317	\N	\N	\N
9885	VICPDT	2004-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7765	\N	\N	\N
7778	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7783	\N	\N	\N
8011	VICPDT	2001-12-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7794	\N	\N	\N
7808	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7813	\N	\N	\N
7822	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7827	\N	\N	\N
7894	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7887	\N	\N	\N
7924	PDT	2001-12-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7902	\N	\N	\N
7931	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7916	\N	\N	\N
7938	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7923	\N	\N	\N
7960	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7942	\N	\N	\N
7584	VICPDT	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7563	\N	\N	\N
7514	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7575	\N	\N	\N
7526	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7587	\N	\N	\N
7539	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7600	\N	\N	\N
7556	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7617	\N	\N	\N
8411	SECRET	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8141	\N	\N	\N
8219	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8150	\N	\N	\N
8239	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8170	\N	\N	\N
8348	VICPDT	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8175	\N	\N	\N
8250	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8181	\N	\N	\N
8282	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8212	\N	\N	\N
8297	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8227	\N	\N	\N
8335	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8261	\N	\N	\N
9227	SECRET	2004-11-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8263	\N	\N	\N
8381	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8281	\N	\N	\N
12336	MEMBRE	2007-11-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11598	\N	\N	\N
8458	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8336	\N	\N	\N
12380	MEMBRE	2008-02-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11626	\N	\N	\N
7492	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7553	\N	\N	\N
8042	MEMBRE	2003-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7992	\N	\N	\N
8074	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8016	\N	\N	\N
8313	VICPDT	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8090	\N	\N	\N
8187	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8118	\N	\N	\N
8750	MEMBRE	2004-10-01 00:00:00	2010-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	8599	\N	\N	\N
8772	MEMBRE	2004-10-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8612	\N	\N	\N
8785	MEMBRE	2004-10-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8625	\N	\N	\N
8807	MEMBRE	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8647	\N	\N	\N
8839	MEMBRE	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8674	\N	\N	\N
8878	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8712	\N	\N	\N
12465	MEMBRE	2008-07-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11697	\N	\N	\N
8892	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8726	\N	\N	\N
8931	SECRET	2004-11-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8747	\N	\N	\N
8942	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8760	\N	\N	\N
8959	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8777	\N	\N	\N
9002	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8803	\N	\N	\N
8652	MEMBRE	2003-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8517	\N	\N	\N
8663	MEMBRE	2004-01-29 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8528	\N	\N	\N
8761	MEMBREBUR	2004-11-12 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8538	\N	\N	\N
9181	MEMBRE	2003-06-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8989	\N	\N	\N
9652	SECRET	2004-11-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8995	12	\N	\N
9212	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9019	\N	\N	\N
9231	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9032	\N	\N	\N
9255	VICPDT	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9047	6	\N	\N
9266	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9058	\N	\N	\N
9283	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9075	\N	\N	\N
9339	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9103	\N	\N	\N
12347	VICPDT	2007-10-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9119	11	\N	\N
9362	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9132	\N	\N	\N
9363	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9133	\N	\N	\N
9389	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9161	\N	\N	\N
9405	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9178	\N	\N	\N
9429	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9202	\N	\N	\N
9441	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9214	\N	\N	\N
8470	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8348	\N	\N	\N
12580	SECRET	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8810	10	\N	\N
9013	MEMBRE	2004-10-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8814	\N	\N	\N
9031	MEMBRE	2004-10-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8833	\N	\N	\N
9059	MEMBRE	2003-06-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8864	\N	\N	\N
9088	MEMBRE	2003-06-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8895	\N	\N	\N
9098	MEMBRE	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8905	\N	\N	\N
9117	MEMBRE	2003-06-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8924	\N	\N	\N
9128	VICPDT	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8935	8	\N	\N
9153	MEMBRE	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8959	\N	\N	\N
9173	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8981	\N	\N	\N
9683	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9443	\N	\N	\N
9693	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9453	\N	\N	\N
9703	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9463	\N	\N	\N
9715	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9477	\N	\N	\N
9778	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9502	\N	\N	\N
9810	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9534	\N	\N	\N
9917	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9612	\N	\N	\N
9929	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9627	\N	\N	\N
15765	MEMBRE	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13990	\N	\N	\N
15766	MEMBRE	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13991	\N	\N	\N
15767	MEMBRE	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13992	\N	\N	\N
15768	MEMBRE	2010-03-30 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	13993	\N	\N	\N
15769	MEMBRE	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13994	\N	\N	\N
15770	MEMBRE	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13995	\N	\N	\N
15771	MEMBRE	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13996	\N	\N	\N
15772	MEMBRE	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13997	\N	\N	\N
15773	MEMBRE	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13998	\N	\N	\N
15774	MEMBRE	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13999	\N	\N	\N
15775	MEMBRE	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14000	\N	\N	\N
15804	MEMBRE	2010-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14024	\N	\N	\N
9573	PDTDEL	2004-10-01 00:00:00	2010-10-18 00:00:00	ANCIEN	\N	\N	Mali	\N	9347	11	\N	\N
11501	MEMBRE	2005-12-01 00:00:00	2010-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	10848	\N	\N	\N
9545	MEMBRE	2004-10-01 00:00:00	2010-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	9314	\N	\N	\N
9604	MEMBRE	2004-10-01 00:00:00	2010-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	9378	\N	\N	\N
9864	MEMBRE	2004-10-01 00:00:00	2010-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	9563	\N	\N	\N
11502	MEMBRE	2005-12-01 00:00:00	2010-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	10849	\N	\N	\N
11542	MEMBRE	2004-10-01 00:00:00	2010-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	10879	\N	\N	\N
7984	MEMBRE	2001-10-01 00:00:00	2004-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	7963	\N	\N	\N
15811	MEMBRE	2010-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14031	\N	\N	\N
15812	MEMBRE	2010-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14032	\N	\N	\N
15858	MEMBRE	2010-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14072	\N	\N	\N
15859	MEMBRE	2011-03-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14073	\N	\N	\N
15779	MEMBRE	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14005	\N	\N	\N
15753	SECRET	2010-06-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13979	\N	\N	\N
15786	MEMBRE	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14006	\N	\N	\N
15800	MEMBRE	2010-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14020	\N	\N	\N
15801	MEMBRE	2010-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14021	\N	\N	\N
15830	MEMBRE	2010-12-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14051	\N	\N	\N
15746	MEMBRE	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13973	\N	\N	\N
15747	MEMBRE	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13974	\N	\N	\N
15749	MEMBRE	2010-05-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13976	\N	\N	\N
9942	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9640	\N	\N	\N
9951	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9649	\N	\N	\N
9469	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9243	\N	\N	\N
9480	SECRET	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9254	15	\N	\N
9487	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9261	\N	\N	\N
9498	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9272	\N	\N	\N
9513	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9292	\N	\N	\N
9526	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9305	\N	\N	\N
9556	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9327	\N	\N	\N
9569	VICPDT	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9343	21	\N	\N
9589	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9363	\N	\N	\N
9615	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9389	\N	\N	\N
9627	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9401	\N	\N	\N
10316	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9909	\N	\N	\N
10377	VICPDT	2004-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9944	\N	\N	\N
10382	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9953	\N	\N	\N
10400	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9971	\N	\N	\N
10416	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9987	\N	\N	\N
10428	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10001	\N	\N	\N
10451	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10024	\N	\N	\N
10466	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10040	\N	\N	\N
10472	VICPDT	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10046	7	\N	\N
10489	VICPDT	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10065	9	\N	\N
10507	VICPDT	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10085	4	\N	\N
12514	MEMBRE	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10123	0	\N	\N
9452	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9226	\N	\N	\N
9464	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9238	\N	\N	\N
9977	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9675	\N	\N	\N
10081	VICPDT	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9701	5	\N	\N
10094	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9715	\N	\N	\N
10107	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9729	\N	\N	\N
10121	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9744	\N	\N	\N
10134	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9757	\N	\N	\N
10176	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9804	\N	\N	\N
10197	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9826	\N	\N	\N
10212	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9841	\N	\N	\N
10230	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9860	\N	\N	\N
10252	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9872	\N	\N	\N
10257	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9877	\N	\N	\N
10267	SECRET	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9889	10	\N	\N
10867	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10337	\N	\N	\N
10890	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10361	\N	\N	\N
10901	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10374	\N	\N	\N
10915	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10389	\N	\N	\N
10973	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10411	\N	\N	\N
11011	VICPDT	2005-03-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10428	\N	\N	\N
11020	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10450	\N	\N	\N
11048	SECRET	2005-03-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10460	\N	\N	\N
11051	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10472	\N	\N	\N
11071	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10491	\N	\N	\N
11081	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10501	\N	\N	\N
11084	MEMBRE	2005-03-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10504	\N	\N	\N
11100	MEMBRE	2004-10-01 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	10520	\N	\N	\N
11116	VICPDT	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10537	7	\N	\N
11145	MEMBRE	2005-04-11 00:00:00	2010-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	10566	\N	\N	\N
10631	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10158	\N	\N	\N
10675	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10178	\N	\N	\N
12497	SECRET	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10184	7	\N	\N
6357	VICPDT	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2728	5	\N	\N
2615	VICPDT	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2628	2	\N	\N
2623	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2636	\N	\N	\N
5892	VICPDT	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2647	6	\N	\N
5750	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2662	\N	\N	\N
10339	MEMBRE	2004-10-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2609	\N	\N	\N
10061	VICPDT	2004-11-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2555	3	\N	\N
5218	PDTDEL	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Turkménistan	\N	2479	7	\N	\N
10015	SECRET	2004-11-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2480	26	\N	\N
5382	SECRET	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2513	8	\N	\N
10762	PDT	2004-12-07 00:00:00	2011-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	2731	1	\N	\N
2718	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2741	\N	\N	\N
2742	PDT	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2766	1	\N	\N
2673	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2686	\N	\N	\N
6707	MEMBRE	2003-05-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2703	\N	\N	\N
9828	SECRET	2004-12-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2082	5	\N	\N
6044	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2095	\N	\N	\N
5937	VICPDT	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1992	4	\N	\N
10832	MEMBREBUR	2004-12-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1934	7	\N	\N
10551	VICPDT	2004-11-09 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	1863	3	\N	\N
2704	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1901	\N	\N	\N
5329	SECRET	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2425	23	\N	\N
9847	VICPDT	2004-11-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2233	8	\N	\N
10681	SECRET	2004-11-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2107	7	\N	\N
10616	SECRET	2004-12-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1493	13	\N	\N
4883	VICPDT	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1278	5	\N	\N
5932	SECRET	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1262	30	\N	\N
9537	PDTHON	2004-11-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1247	2	\N	\N
10302	SECRET	2004-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1258	7	\N	\N
6056	VICPDT	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1097	5	\N	\N
9307	SECRET	2004-11-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1058	24	\N	\N
9999	MEMBRE	2004-12-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	888	\N	\N	\N
10960	VICPDTDRT	2005-02-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Afrique centrale	\N	210	8	\N	\N
3837	VICPDT	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3007	3	\N	\N
2972	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3009	\N	\N	\N
3017	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3057	\N	\N	\N
3033	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3074	\N	\N	\N
3065	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3107	\N	\N	\N
3119	VICPDT	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3162	2	\N	\N
9737	VICPDT	2004-11-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3200	5	\N	\N
4722	PDT	2001-10-01 01:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3201	1	\N	\N
2804	VICPDT	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2832	8	\N	\N
6440	PDT	2002-07-31 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2856	1	\N	\N
2834	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2865	\N	\N	\N
6584	MEMBRE	2002-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2873	\N	\N	\N
6288	MEMBRE	2002-01-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2920	\N	\N	\N
10618	SECRET	2004-12-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2933	9	\N	\N
11175	MEMBRE	2004-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2988	\N	\N	\N
3310	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3371	\N	\N	\N
3338	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3401	\N	\N	\N
3382	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3446	\N	\N	\N
10652	SECRET	2004-12-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3469	11	\N	\N
3466	VICPDT	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3534	2	\N	\N
10299	VICPDT	2004-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3540	4	\N	\N
3483	PDT	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3552	1	\N	\N
3195	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3248	\N	\N	\N
3244	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3303	\N	\N	\N
3699	SECRET	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3775	10	\N	\N
6560	SECRET	2001-11-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3525	10	\N	\N
3557	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3628	\N	\N	\N
3585	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3657	\N	\N	\N
15745	MEMBRE	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13972	\N	\N	\N
15748	MEMBRE	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13975	\N	\N	\N
15756	MEMBRE	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13981	\N	\N	\N
15757	MEMBRE	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13982	\N	\N	\N
15758	MEMBRE	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13983	\N	\N	\N
15759	MEMBRE	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13984	\N	\N	\N
15760	MEMBRE	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13985	\N	\N	\N
15761	MEMBRE	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13986	\N	\N	\N
15762	MEMBRE	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13987	\N	\N	\N
15763	MEMBRE	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13988	\N	\N	\N
15764	MEMBRE	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13989	\N	\N	\N
5425	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5471	\N	\N	\N
5440	MEMBRE	2001-10-01 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	5486	0	\N	\N
5456	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5504	\N	\N	\N
5467	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5515	\N	\N	\N
5482	MEMBRE	2001-10-01 00:00:00	2004-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	5531	\N	\N	\N
5514	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5564	\N	\N	\N
5532	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5583	\N	\N	\N
5540	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5592	\N	\N	\N
5555	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5607	\N	\N	\N
5569	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5621	\N	\N	\N
5581	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5633	\N	\N	\N
5595	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5647	\N	\N	\N
5608	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5660	\N	\N	\N
5622	MEMBRE	2001-10-01 00:00:00	2004-11-15 00:00:00	ANCIEN	\N	\N	\N	\N	5674	\N	\N	\N
5632	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5685	\N	\N	\N
5643	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5696	\N	\N	\N
5655	VICPDT	2001-10-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	5709	3	\N	\N
5676	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5730	3	\N	\N
5464	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5512	\N	\N	\N
5576	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5628	\N	\N	\N
5666	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5720	\N	\N	\N
5698	VICPDT	2001-10-01 00:00:00	2004-11-09 00:00:00	ANCIEN	\N	\N	\N	\N	5758	2	\N	\N
5707	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5767	\N	\N	\N
5717	MEMBRE	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5778	\N	\N	\N
6371	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6271	\N	\N	\N
6384	TRESOR	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6286	13	\N	\N
6414	MEMBRE	2000-12-12 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4500	\N	\N	\N
6428	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6341	\N	\N	\N
6444	MEMBREBUR	2002-07-31 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	6352	12	\N	\N
6450	MEMBREBUR	2002-07-09 00:00:00	2004-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	581	8	\N	\N
6466	MEMBRE	2001-10-24 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6362	\N	\N	\N
6475	SECRET	2001-10-24 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6371	21	\N	\N
6486	MEMBRE	2002-10-01 00:00:00	2004-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	6383	\N	\N	\N
6513	MEMBRE	2002-11-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	6396	\N	\N	\N
6546	MEMBRE	2002-11-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6430	\N	\N	\N
6557	PDT	2001-11-27 00:00:00	2005-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	4423	1	\N	\N
15344	MEMBRE	2008-11-26 00:00:00	2009-06-08 00:00:00	ANCIEN	\N	\N	\N	\N	13659	\N	\N	\N
15345	MEMBRE	2008-11-26 00:00:00	2009-06-08 00:00:00	ANCIEN	\N	\N	\N	\N	13660	\N	\N	\N
15346	MEMBRE	2008-11-26 00:00:00	2009-06-08 00:00:00	ANCIEN	\N	\N	\N	\N	13661	\N	\N	\N
15347	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13662	\N	\N	\N
15348	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13663	\N	\N	\N
15349	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13664	\N	\N	\N
15350	MEMBRE	2008-11-26 00:00:00	2009-06-08 00:00:00	ANCIEN	\N	\N	\N	\N	13665	\N	\N	\N
15351	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13666	\N	\N	\N
15352	MEMBRE	2008-11-26 00:00:00	2009-06-08 00:00:00	ANCIEN	\N	\N	\N	\N	13667	\N	\N	\N
15353	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13668	\N	\N	\N
15354	MEMBRE	2008-11-26 00:00:00	2009-06-08 00:00:00	ANCIEN	\N	\N	\N	\N	13669	\N	\N	\N
15355	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13670	\N	\N	\N
15356	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13671	\N	\N	\N
15357	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13672	\N	\N	\N
15358	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13673	\N	\N	\N
15359	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13674	\N	\N	\N
15360	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13675	\N	\N	\N
15384	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13695	\N	\N	\N
15393	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13704	\N	\N	\N
15394	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13705	\N	\N	\N
15395	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13706	\N	\N	\N
15399	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13710	\N	\N	\N
15397	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13708	\N	\N	\N
15398	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13709	\N	\N	\N
15400	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13711	\N	\N	\N
15401	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13712	\N	\N	\N
15402	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13713	\N	\N	\N
15429	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13739	\N	\N	\N
15440	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13750	\N	\N	\N
15536	VICPDT	2009-07-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13427	\N	\N	\N
15537	VICPDT	2009-07-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13373	\N	\N	\N
15538	VICPDT	2009-07-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13400	\N	\N	\N
15547	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13826	\N	\N	\N
15548	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13827	\N	\N	\N
15549	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13828	\N	\N	\N
11014	SECRET	2005-03-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10436	\N	\N	\N
14737	MEMBRE	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10416	\N	\N	\N
14736	SECRET	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10416	\N	\N	\N
14875	MEMBRE	2008-10-01 00:00:00	2009-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	13320	\N	\N	\N
14748	VICPDT	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13246	\N	\N	\N
14749	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13247	\N	\N	\N
14859	MEMBRE	2008-10-01 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	13306	\N	\N	\N
14917	MEMBRE	2009-03-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	13348	\N	\N	\N
3505	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3575	\N	\N	\N
14923	MEMBRE	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13354	\N	\N	\N
14924	MEMBRE	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13355	\N	\N	\N
15044	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13445	\N	\N	\N
15045	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13446	\N	\N	\N
15046	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13447	\N	\N	\N
15047	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13448	\N	\N	\N
15048	MEMBRE	2008-11-26 00:00:00	2009-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	13449	0	\N	\N
15049	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13450	\N	\N	\N
15050	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13451	\N	\N	\N
15051	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13452	\N	\N	\N
15052	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13453	\N	\N	\N
15053	MEMBRE	2008-11-26 00:00:00	2009-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	13454	0	\N	\N
15054	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13455	\N	\N	\N
15055	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13456	\N	\N	\N
15056	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13457	\N	\N	\N
15057	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13458	\N	\N	\N
15109	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13510	\N	\N	\N
15122	MEMBRE	2008-10-01 00:00:00	2009-03-31 00:00:00	ANCIEN	\N	\N	\N	\N	13523	\N	\N	\N
15165	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13566	\N	\N	\N
15171	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13572	\N	\N	\N
15172	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13573	\N	\N	\N
15173	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13574	\N	\N	\N
15174	SECRET	2009-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13567	\N	\N	\N
15177	MEMBRE	2009-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7675	\N	\N	\N
15178	PDT	2009-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7660	\N	\N	\N
15179	MEMBRE	2009-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13575	\N	\N	\N
15303	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13649	\N	\N	\N
15304	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13650	\N	\N	\N
15307	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13651	\N	\N	\N
15362	PDTDEL	2009-05-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Libéria	\N	4603	10	\N	\N
15441	PDT	2009-06-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13669	\N	\N	\N
15442	VICPDT	2009-06-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13659	\N	\N	\N
15443	SECRET	2009-06-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13667	\N	\N	\N
15444	VICPDT	2009-06-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13660	\N	\N	\N
15445	VICPDT	2009-06-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13665	\N	\N	\N
15446	VICPDT	2009-06-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13661	\N	\N	\N
15483	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13786	\N	\N	\N
15484	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13787	\N	\N	\N
15490	PDT	2009-06-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10818	1	\N	\N
14814	MEMBRE	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13275	\N	\N	\N
14840	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13300	\N	\N	\N
14858	MEMBRE	2008-10-01 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	13305	\N	\N	\N
7443	VICPDT	2001-10-03 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	7436	\N	\N	\N
14865	MEMBRE	2009-03-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7436	\N	\N	\N
14877	MEMBRE	2008-10-01 00:00:00	2009-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	13322	\N	\N	\N
14892	VICPDT	2009-01-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12754	7	\N	\N
14893	VICPDT	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13252	11	\N	\N
14910	MEMBRE	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13341	\N	\N	\N
15605	MEMBRE	2009-09-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13862	\N	\N	\N
14915	MEMBRE	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13346	\N	\N	\N
14916	MEMBRE	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13347	\N	\N	\N
14945	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13365	\N	\N	\N
15504	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13798	\N	\N	\N
15239	SECRET	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12872	26	\N	\N
15269	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13625	\N	\N	\N
15430	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13740	\N	\N	\N
15431	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13741	\N	\N	\N
15432	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13742	\N	\N	\N
15434	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13744	\N	\N	\N
15491	PDTDEL	2009-06-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Bangladesh	\N	13776	2	\N	\N
15492	PDTDEL	2009-06-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Brunei	\N	13775	4	\N	\N
15493	PDTDEL	2009-06-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Singapour	\N	13774	7	\N	\N
15494	VICPDT	2009-06-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13771	9	\N	\N
15495	VICPDT	2009-06-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4259	10	\N	\N
15505	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13799	\N	\N	\N
15506	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13800	\N	\N	\N
15507	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13801	\N	\N	\N
15509	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13803	\N	\N	\N
15510	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13804	\N	\N	\N
15526	PDT	2009-07-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13404	\N	\N	\N
15527	VICPDT	2009-07-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13602	\N	\N	\N
15533	PDT	2009-07-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13397	\N	\N	\N
15604	MEMBRE	2009-09-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13861	\N	\N	\N
15544	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13820	\N	\N	\N
15545	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13821	\N	\N	\N
15291	VICPDT	2009-05-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13520	\N	\N	\N
15295	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13641	\N	\N	\N
15296	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13642	\N	\N	\N
15297	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13643	\N	\N	\N
15298	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13644	\N	\N	\N
15313	MEMBRE	2008-10-01 00:00:00	2010-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	13653	\N	\N	\N
15315	VICPDT	2009-03-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8264	\N	\N	\N
15324	VICPDTDEL	2009-03-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13368	\N	\N	\N
15328	SECRET	2009-03-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13035	\N	\N	\N
15333	VICPDT	2008-12-09 00:00:00	2011-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	13655	10	\N	\N
15334	VICPDT	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13656	11	\N	\N
15335	VICPDT	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13657	12	\N	\N
15336	VICPDT	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6366	13	\N	\N
15337	VICPDT	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12804	3	\N	\N
15338	VICPDT	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10165	4	\N	\N
15339	VICPDT	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10166	5	\N	\N
15340	SECRET	2009-01-13 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	10164	8	\N	\N
15341	SECRET	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10167	10	\N	\N
15342	SECRET	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10186	11	\N	\N
15528	VICPDT	2009-07-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13797	\N	\N	\N
15529	VICPDT	2009-07-10 00:00:00	2010-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	13601	\N	\N	\N
15530	VICPDT	2009-07-10 00:00:00	2010-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	13600	\N	\N	\N
15599	MEMBRE	2009-09-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13856	\N	\N	\N
15600	MEMBRE	2009-09-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13857	0	\N	\N
15649	MEMBRE	2009-10-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13901	\N	\N	\N
15607	MEMBRE	2007-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13864	\N	\N	\N
10286	PDT	2005-01-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7842	\N	\N	\N
15701	MEMBRE	2010-02-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13939	\N	\N	\N
15722	MEMBRE	2010-01-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13955	\N	\N	\N
2765	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2790	16	\N	\N
2790	MEMBREBUR	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2816	11	\N	\N
2607	VICPDT	1999-01-01 00:00:00	2004-10-19 00:00:00	ANCIEN	\N	\N	\N	\N	2609	7	\N	\N
14841	PDTDEL	2009-02-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Venezuela	\N	12949	2	\N	\N
14842	PDTDEL	2009-02-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Colombie	\N	12930	3	\N	\N
14843	PDTDEL	2009-02-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Bolivie	\N	12927	4	\N	\N
14844	PDTDEL	2009-02-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Pérou	\N	12919	5	\N	\N
14845	PDTDEL	2009-02-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Equateur	\N	12937	6	\N	\N
14846	VICPDT	2009-02-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12939	7	\N	\N
14847	VICPDT	2009-02-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12917	9	\N	\N
14848	VICPDT	2009-02-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12915	10	\N	\N
14849	SECRET	2009-02-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12946	12	\N	\N
14850	SECRET	2009-02-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12922	13	\N	\N
14851	SECRET	2009-02-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12936	14	\N	\N
14852	SECRET	2009-02-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13271	15	\N	\N
14853	SECRET	2009-02-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12926	16	\N	\N
14870	MEMBRE	2008-10-01 00:00:00	2009-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	13315	\N	\N	\N
14874	MEMBRE	2008-10-01 00:00:00	2009-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	13319	\N	\N	\N
14876	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13321	\N	\N	\N
14903	MEMBRE	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13334	\N	\N	\N
14905	MEMBRE	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13336	\N	\N	\N
14921	MEMBRE	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13352	\N	\N	\N
14922	MEMBRE	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13353	\N	\N	\N
14927	MEMBRE	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13358	\N	\N	\N
14929	MEMBRE	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13360	\N	\N	\N
14932	PDT	2009-03-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11053	\N	\N	\N
14933	VICPDT	2009-03-18 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	\N	13210	\N	\N	\N
14941	SECRET	2009-03-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13167	\N	\N	\N
14942	SECRET	2009-03-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11058	\N	\N	\N
14944	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13364	\N	\N	\N
14979	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13391	\N	\N	\N
14998	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13408	\N	\N	\N
15003	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13413	\N	\N	\N
15004	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13414	\N	\N	\N
15020	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13429	\N	\N	\N
15240	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13598	\N	\N	\N
15245	MEMBRE	2008-10-01 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	13600	\N	\N	\N
15246	MEMBRE	2008-10-01 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	13601	\N	\N	\N
15247	MEMBRE	2008-10-01 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	13602	\N	\N	\N
15259	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13614	\N	\N	\N
14774	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13263	\N	\N	\N
14955	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13374	\N	\N	\N
15260	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13615	\N	\N	\N
15261	MEMBRE	2008-11-26 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	13616	\N	\N	\N
15262	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13617	\N	\N	\N
15263	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13618	\N	\N	\N
15332	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13654	\N	\N	\N
15363	VICPDT	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13676	6	\N	\N
15373	PDT	2009-05-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13687	1	\N	\N
15374	VICPDT	2009-05-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13688	2	\N	\N
15375	VICPDT	2009-05-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13689	3	\N	\N
15376	VICPDT	2009-05-20 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	\N	13690	4	\N	\N
15377	SECRET	2009-05-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13691	5	\N	\N
15378	SECRET	2009-05-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13692	6	\N	\N
15379	SECRET	2009-05-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13693	7	\N	\N
15380	SECRET	2009-05-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13694	8	\N	\N
15447	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13752	\N	\N	\N
15448	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13753	\N	\N	\N
15449	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13754	\N	\N	\N
15450	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13755	\N	\N	\N
15451	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13756	\N	\N	\N
15452	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13757	\N	\N	\N
15454	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13759	\N	\N	\N
15601	MEMBRE	2009-09-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13858	\N	\N	\N
15645	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13897	\N	\N	\N
15525	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13816	\N	\N	\N
15581	MEMBRE	2009-07-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12720	\N	\N	\N
15739	MEMBRE	2009-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13966	\N	\N	\N
2620	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2633	\N	\N	\N
2632	MEMBRE	1999-01-01 00:00:00	1999-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	2645	\N	\N	\N
2656	MEMBRE	1999-01-01 00:00:00	2001-10-30 00:00:00	ANCIEN	\N	\N	\N	\N	2669	\N	\N	\N
2676	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2689	\N	\N	\N
2584	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2584	\N	\N	\N
14757	MEMBRE	2008-10-01 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	13253	\N	\N	\N
14758	MEMBRE	2008-10-01 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	13254	\N	\N	\N
14759	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13255	\N	\N	\N
14760	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13256	\N	\N	\N
14761	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13257	\N	\N	\N
14763	MEMBRE	2008-10-01 00:00:00	2011-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	13259	\N	\N	\N
14794	PDTDEL	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Côte d'Ivoire	\N	2516	5	\N	\N
14795	PDTDEL	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Guinée Bissau	\N	12514	9	\N	\N
14796	PDTDEL	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Mauritanie	\N	12510	12	\N	\N
14797	PDTDEL	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Niger	\N	12526	13	\N	\N
14798	PDTDEL	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Nigeria	\N	4602	14	\N	\N
14799	PDTDEL	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Sénégal	\N	9338	16	\N	\N
14800	PDTDEL	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Togo	\N	12521	17	\N	\N
14801	VICPDT	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	184	18	\N	\N
14802	VICPDT	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	880	19	\N	\N
14803	VICPDT	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12513	20	\N	\N
14804	VICPDT	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12765	21	\N	\N
14805	VICPDT	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9365	23	\N	\N
14806	SECRET	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11702	27	\N	\N
14807	TRESOR	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1248	28	\N	\N
14808	MEMBRE	2009-03-03 00:00:00	2009-05-17 00:00:00	ANCIEN	\N	\N	\N	\N	4603	0	\N	\N
4490	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4599	\N	\N	\N
4498	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4608	\N	\N	\N
4513	MEMBRE	2001-10-01 00:00:00	2009-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	4625	\N	\N	\N
4523	MEMBRE	2001-10-01 00:00:00	2004-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	4635	\N	\N	\N
4547	MEMBRE	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4660	\N	\N	\N
4566	TRESOR	2001-10-01 00:00:00	2004-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	4679	6	\N	\N
4575	SECRET	2001-10-24 00:00:00	2004-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	3540	7	\N	\N
4033	MEMBRE	2000-03-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4085	\N	\N	\N
4165	MEMBRE	2000-11-10 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4216	\N	\N	\N
4246	VICPDT	1998-10-01 00:00:00	2004-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	4297	7	\N	\N
4383	MEMBRE	2001-05-15 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4492	\N	\N	\N
4564	MEMBRE	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4677	\N	\N	\N
4594	MEMBRE	2001-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4700	\N	\N	\N
4609	MEMBRE	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4716	\N	\N	\N
4614	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4722	\N	\N	\N
4631	MEMBRE	2001-10-01 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	4740	\N	\N	\N
4642	MEMBRE	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4751	\N	\N	\N
4664	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4777	4	\N	\N
4679	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4792	\N	\N	\N
4691	MEMBREBUR	2001-10-01 00:00:00	2004-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	4804	25	\N	\N
4712	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4831	\N	\N	\N
4706	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4825	\N	\N	\N
4737	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4850	10	\N	\N
4147	MEMBRE	2000-11-01 00:00:00	2004-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	4198	\N	\N	\N
4166	MEMBRE	2000-11-10 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4217	\N	\N	\N
4181	MEMBRE	2000-11-10 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4232	\N	\N	\N
4204	MEMBRE	2000-12-20 00:00:00	2005-03-07 00:00:00	ANCIEN	\N	\N	\N	\N	4254	\N	\N	\N
4211	PDTDEL	2000-12-15 00:00:00	2004-11-09 00:00:00	ANCIEN	\N	\N	Ouzbékistan	\N	4261	3	\N	\N
4225	VICPDT	1998-10-01 00:00:00	2004-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	4276	5	\N	\N
4238	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4289	\N	\N	\N
4249	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4300	\N	\N	\N
4311	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4411	\N	\N	\N
4318	MEMBRE	2001-05-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4419	\N	\N	\N
4331	VICPDT	2001-05-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4435	3	\N	\N
4340	MEMBRE	2001-05-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4444	\N	\N	\N
4357	MEMBRE	2000-11-28 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4464	\N	\N	\N
4373	MEMBRE	2000-06-28 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4480	\N	\N	\N
4394	MEMBRE	2000-12-18 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4502	\N	\N	\N
4417	VICPDT	2001-01-03 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	4526	2	\N	\N
4434	MEMBRE	2000-12-11 00:00:00	2001-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	4543	\N	\N	\N
4456	MEMBRE	2001-02-12 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4565	\N	\N	\N
5074	MEMBRE	2001-10-01 00:00:00	2004-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	5182	\N	\N	\N
5110	MEMBRE	2001-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	5219	\N	\N	\N
5118	SECRET	2001-10-01 00:00:00	2008-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	5227	\N	\N	\N
5146	SECRET	2001-10-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	5255	\N	\N	\N
4937	MEMBREBUR	2001-10-01 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	5039	9	\N	\N
5206	MEMBREBUR	2001-10-01 00:00:00	2003-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	5172	14	\N	\N
5227	VICPDT	2001-10-01 00:00:00	2004-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	1895	4	\N	\N
5237	SECRET	2001-10-01 00:00:00	2004-11-09 00:00:00	ANCIEN	\N	\N	\N	\N	2512	16	\N	\N
5251	MEMBRE	2001-10-01 00:00:00	2009-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	5311	\N	\N	\N
5263	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5324	\N	\N	\N
5286	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5347	\N	\N	\N
5301	MEMBRE	2001-10-01 00:00:00	2004-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	5362	\N	\N	\N
5323	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5384	\N	\N	\N
5345	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5400	\N	\N	\N
5364	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5419	\N	\N	\N
5387	VICPDT	2001-10-01 00:00:00	2009-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	3631	6	\N	\N
5405	SECRET	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5453	20	\N	\N
5417	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5465	\N	\N	\N
4784	MEMBRE	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	4899	\N	\N	\N
4800	VICPDT	2001-10-01 00:00:00	2009-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	4916	11	\N	\N
4827	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4943	\N	\N	\N
4835	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4951	\N	\N	\N
4847	SECRET	2001-10-01 00:00:00	2009-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	4963	10	\N	\N
14819	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13280	\N	\N	\N
14820	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13281	\N	\N	\N
14821	MEMBRE	2008-10-01 00:00:00	2009-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	13282	\N	\N	\N
14822	MEMBRE	2008-10-01 00:00:00	2009-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	13283	\N	\N	\N
14823	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13284	\N	\N	\N
14824	MEMBRE	2008-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	13285	\N	\N	\N
14825	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13286	\N	\N	\N
14826	MEMBRE	2008-10-01 00:00:00	2009-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	13287	\N	\N	\N
14827	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13288	\N	\N	\N
14828	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13289	\N	\N	\N
14829	MEMBRE	2008-10-01 00:00:00	2009-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	13290	\N	\N	\N
14830	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13291	\N	\N	\N
14831	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13292	\N	\N	\N
14832	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13293	\N	\N	\N
14833	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13294	\N	\N	\N
14834	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13295	\N	\N	\N
14835	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13296	\N	\N	\N
14836	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13297	\N	\N	\N
14837	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13298	\N	\N	\N
14838	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13299	\N	\N	\N
14895	PDT	2009-03-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13265	1	\N	\N
14896	VICPDT	2009-03-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5081	3	\N	\N
14897	VICPDT	2009-03-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5095	6	\N	\N
14898	VICPDT	2009-03-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12342	4	\N	\N
2746	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2770	\N	\N	\N
14948	VICPDT	2009-03-10 00:00:00	2011-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	11333	5	\N	2015-11-12 15:26:22
14985	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13395	\N	\N	\N
14988	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13398	\N	\N	\N
15040	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13441	\N	\N	\N
15041	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13442	\N	\N	\N
15042	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13443	\N	\N	\N
15043	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13444	\N	\N	\N
15586	MEMBRE	2009-09-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13850	\N	\N	\N
15587	MEMBRE	2009-09-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13851	\N	\N	\N
15589	MEMBRE	2009-09-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13853	\N	\N	\N
15590	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13854	\N	\N	\N
15597	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8039	\N	\N	\N
15592	PDT	2005-03-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13855	\N	\N	\N
15625	MEMBRE	2009-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13877	\N	\N	\N
15683	MEMBRE	2009-06-25 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13924	\N	\N	\N
15681	MEMBRE	2009-06-25 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13922	\N	\N	\N
15684	MEMBRE	2010-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13925	\N	\N	\N
15691	TRESOR	2010-02-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12338	17	\N	\N
15698	MEMBRE	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13938	\N	\N	\N
15699	SECRET	2009-03-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7845	\N	\N	\N
15700	VICPDT	2009-03-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7848	\N	\N	\N
15704	MEMBRE	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13942	\N	\N	\N
15705	MEMBRE	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13943	\N	\N	\N
15719	MEMBRE	2010-01-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13952	\N	\N	\N
15714	VICPDT	2009-03-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7851	\N	\N	\N
15717	MEMBRE	2010-02-12 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13950	\N	\N	\N
15718	MEMBRE	2010-01-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13951	\N	\N	\N
15720	SECRET	2010-01-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13953	16	\N	\N
15721	MEMBRE	2010-01-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13954	\N	\N	\N
5101	MEMBRE	2001-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	5210	\N	\N	\N
6174	MEMBRE	1999-01-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	6109	\N	\N	\N
7184	MEMBRE	2001-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	7301	\N	\N	\N
8196	MEMBRE	2001-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	8127	\N	\N	\N
8476	MEMBRE	2001-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	8354	\N	\N	\N
7887	MEMBRE	2001-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	7880	\N	\N	\N
14729	PDT	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8239	\N	\N	\N
14740	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	10414	\N	\N	\N
14752	MEMBRE	2008-10-01 00:00:00	2009-03-24 00:00:00	ANCIEN	\N	\N	\N	\N	13249	\N	\N	\N
14743	VICPDT	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10414	\N	\N	\N
14744	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	10415	\N	\N	\N
14951	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13370	\N	\N	\N
14956	MEMBRE	2008-10-01 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	13375	\N	\N	\N
14997	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13407	\N	\N	\N
15000	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13410	\N	\N	\N
15001	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13411	\N	\N	\N
15002	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13412	\N	\N	\N
15029	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13438	\N	\N	\N
15273	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13631	\N	\N	\N
15274	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13632	\N	\N	\N
15275	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13633	\N	\N	\N
15619	VICPDT	2009-10-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3033	2	\N	\N
15620	VICPDT	2009-10-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3037	3	\N	\N
15621	SECRET	2009-10-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3038	4	\N	\N
15637	MEMBRE	2009-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13889	0	\N	\N
15640	MEMBRE	2009-10-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13892	\N	\N	\N
15641	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13893	\N	\N	\N
15642	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13894	\N	\N	\N
15643	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13895	\N	\N	\N
15644	MEMBRE	2008-10-01 00:00:00	2009-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	13896	\N	\N	\N
15680	MEMBRE	2009-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13921	\N	\N	\N
15712	SECRET	2009-03-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13947	\N	\N	\N
7804	MEMBRE	2001-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	7809	\N	\N	\N
8797	MEMBRE	2004-11-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	8637	\N	\N	\N
10345	MEMBRE	2004-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	9929	\N	\N	\N
9149	MEMBRE	2004-10-15 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	8955	\N	\N	\N
10602	MEMBRE	2004-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	10146	\N	\N	\N
15725	PDT	2010-03-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3647	1	\N	\N
15390	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13701	\N	\N	\N
15391	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13702	\N	\N	\N
15392	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13703	\N	\N	\N
15540	VICPDT	2009-07-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13377	\N	\N	\N
15734	MEMBRE	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13961	\N	\N	\N
15735	MEMBRE	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13962	\N	\N	\N
15736	MEMBRE	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13963	\N	\N	\N
15737	MEMBRE	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13964	\N	\N	\N
15738	MEMBRE	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13965	\N	\N	\N
15743	MEMBRE	2009-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13970	\N	\N	\N
3540	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3610	\N	\N	\N
3560	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3631	\N	\N	\N
3581	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3653	\N	\N	\N
3616	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3688	\N	\N	\N
3645	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3717	\N	\N	\N
3658	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3731	\N	\N	\N
3685	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3761	\N	\N	\N
3701	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3777	\N	\N	\N
3711	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3787	\N	\N	\N
3726	PDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3802	1	\N	\N
3740	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3816	\N	\N	\N
3754	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3830	\N	\N	\N
3141	MEMBRE	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3184	\N	\N	\N
3155	SECRET	1999-01-01 00:00:00	2005-03-07 00:00:00	ANCIEN	\N	\N	\N	\N	3198	14	\N	\N
3173	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3217	\N	\N	\N
14860	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13307	\N	\N	\N
14861	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13308	\N	\N	\N
14871	MEMBRE	2008-10-01 00:00:00	2009-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	13316	\N	\N	\N
14872	MEMBRE	2008-10-01 00:00:00	2009-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	13317	\N	\N	\N
14873	MEMBRE	2008-10-01 00:00:00	2009-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	13318	\N	\N	\N
14900	MEMBRE	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13331	\N	\N	\N
15582	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13845	\N	\N	\N
14906	MEMBRE	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13337	\N	\N	\N
15602	MEMBRE	2009-09-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13859	\N	\N	\N
15603	MEMBRE	2009-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13860	\N	\N	\N
14909	MEMBRE	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13340	\N	\N	\N
14918	MEMBRE	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13349	\N	\N	\N
15611	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9448	\N	\N	\N
14934	MEMBRE	2008-10-01 00:00:00	2009-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	13363	\N	\N	\N
14935	VICPDT	2009-03-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13363	\N	\N	\N
14959	MEMBRE	2008-10-01 00:00:00	2010-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	13378	\N	\N	\N
14963	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13382	\N	\N	\N
14964	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13383	\N	\N	\N
14965	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13384	\N	\N	\N
14966	MEMBRE	2008-10-01 00:00:00	2009-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	13385	\N	\N	\N
14967	MEMBRE	2008-10-01 00:00:00	2009-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	13386	\N	\N	\N
14968	MEMBRE	2008-10-01 00:00:00	2009-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	13387	\N	\N	\N
11197	MEMBRE	2004-10-01 00:00:00	2009-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	10598	\N	\N	\N
14969	VICPDT	2009-03-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10598	\N	\N	\N
14976	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13388	\N	\N	\N
14977	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13389	\N	\N	\N
14978	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13390	\N	\N	\N
14995	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13405	\N	\N	\N
14996	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13406	\N	\N	\N
15090	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13493	\N	\N	\N
15200	MEMBRE	2009-04-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6598	\N	\N	\N
15201	VICPDT	2009-04-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13322	\N	\N	\N
15202	VICPDT	2009-04-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13320	\N	\N	\N
15244	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13599	\N	\N	\N
15550	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8008	\N	\N	\N
15487	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13790	\N	\N	\N
15488	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13791	\N	\N	\N
15612	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13867	\N	\N	\N
14755	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13251	\N	\N	\N
14756	MEMBRE	2008-10-01 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	13252	\N	\N	\N
14764	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13260	\N	\N	\N
14765	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13261	\N	\N	\N
11477	MEMBRE	2005-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10824	\N	\N	\N
11478	MEMBRE	2005-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10825	\N	\N	\N
14766	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13262	\N	\N	\N
15427	PDTDEL	2009-06-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Koweït	\N	12573	7	\N	\N
15613	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13868	\N	\N	\N
15614	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13869	\N	\N	\N
15629	MEMBRE	2009-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13881	\N	\N	\N
15630	MEMBRE	2009-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13882	\N	\N	\N
15631	MEMBRE	2009-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13883	\N	\N	\N
15632	MEMBRE	2009-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13884	\N	\N	\N
15633	MEMBRE	2009-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13885	\N	\N	\N
15634	MEMBRE	2009-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13886	\N	\N	\N
15635	MEMBRE	2009-04-22 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	13887	\N	\N	\N
15636	MEMBRE	2009-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13888	\N	\N	\N
15638	MEMBRE	2009-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13890	\N	\N	\N
15639	MEMBRE	2009-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13891	\N	\N	\N
15646	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13898	\N	\N	\N
15647	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13899	\N	\N	\N
15648	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13900	\N	\N	\N
15663	MEMBRE	2009-10-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13911	\N	\N	\N
15665	MEMBRE	2009-10-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13912	\N	\N	\N
15666	MEMBRE	2009-10-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13913	\N	\N	\N
15667	MEMBRE	2009-10-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13914	\N	\N	\N
15676	MEMBRE	2009-10-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13919	\N	\N	\N
15692	MEMBRE	2010-01-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13932	\N	\N	\N
10288	MEMBREBUR	2005-01-11 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	9903	\N	\N	\N
15702	MEMBRE	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13940	\N	\N	\N
15703	MEMBRE	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13941	\N	\N	\N
15713	MEMBRE	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13948	\N	\N	\N
15716	VICPDT	2009-03-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13949	\N	\N	\N
14879	PDTDEL	2009-03-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Arabie saoudite	\N	12576	4	\N	\N
14855	MEMBRE	2008-10-01 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	13302	\N	\N	\N
14856	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13303	\N	\N	\N
14880	PDTDEL	2009-03-10 00:00:00	2010-09-26 00:00:00	ANCIEN	\N	\N	Sultanat d'Oman	\N	11333	5	\N	2015-11-12 15:26:22
14881	VICPDT	2009-03-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10816	9	\N	\N
14882	VICPDT	2009-03-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3523	11	\N	\N
14883	MEMBRE	2009-03-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9142	0	\N	\N
14884	MEMBRE	2009-03-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5314	0	\N	\N
14885	VICPDTDEL	2008-12-16 00:00:00	2009-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	9890	2	\N	\N
14888	PDTDEL	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Chili	\N	13326	4	\N	\N
14889	PDTDEL	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Uruguay	\N	13327	5	\N	\N
14890	PDTDEL	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Paraguay	\N	13328	6	\N	\N
14931	MEMBRE	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13362	\N	\N	\N
14936	VICPDT	2009-03-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11615	\N	\N	\N
14937	VICPDT	2009-03-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11047	\N	\N	\N
14938	VICPDT	2009-03-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11059	\N	\N	\N
14939	SECRET	2009-03-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11045	\N	\N	\N
14943	SECRET	2009-03-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13170	\N	\N	\N
14958	MEMBRE	2008-10-01 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	13377	\N	\N	\N
15183	MEMBRE	2009-04-01 00:00:00	2009-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	13579	\N	\N	\N
15241	MEMBRE	2009-04-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11149	\N	\N	\N
15242	SECRET	2009-03-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9494	7	\N	\N
15243	SECRET	2009-03-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12344	8	\N	\N
15270	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13628	\N	\N	\N
15271	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13629	\N	\N	\N
15272	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13630	\N	\N	\N
15479	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13782	\N	\N	\N
15481	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13784	\N	\N	\N
15482	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13785	\N	\N	\N
15626	MEMBRE	2009-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13878	\N	\N	\N
15627	MEMBRE	2009-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13879	\N	\N	\N
11047	SECRET	2005-03-18 00:00:00	2009-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	10468	\N	\N	\N
15668	VICPDT	2009-11-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10468	\N	\N	\N
15669	VICPDT	2009-11-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13896	\N	\N	\N
15670	SECRET	2009-11-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13908	\N	\N	\N
15726	VICPDT	2010-03-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10202	6	\N	\N
15467	SECRET	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13769	\N	\N	\N
15673	MEMBRE	2009-10-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13916	\N	\N	\N
15724	MEMBRE	2010-01-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13957	\N	\N	\N
15727	VICPDT	2010-03-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5142	5	\N	\N
15728	VICPDT	2010-03-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5146	7	\N	\N
15729	VICPDT	2010-03-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3677	12	\N	\N
15730	SECRET	2010-03-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13931	19	\N	\N
3193	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3246	4	\N	\N
15741	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13968	\N	\N	\N
15742	MEMBRE	2010-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13969	\N	\N	\N
3213	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3267	\N	\N	\N
3226	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3281	\N	\N	\N
3258	MEMBREBUR	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3317	9	\N	\N
3279	MEMBRE	1999-01-01 00:00:00	1999-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3340	\N	\N	\N
3292	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3353	\N	\N	\N
3307	VICPDT	1999-01-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	3368	\N	\N	\N
3320	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3381	\N	\N	\N
3331	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3393	4	\N	\N
2770	VICPDT	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2795	17	\N	\N
2634	MEMBRE	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2647	\N	\N	\N
2681	MEMBRE	1999-01-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	2694	\N	\N	\N
3778	MEMBRE	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3853	\N	\N	\N
3793	TRESOR	1999-01-01 00:00:00	2004-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	3870	8	\N	\N
3810	MEMBRE	1999-01-01 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	3887	0	\N	\N
14767	PDTDEL	2009-03-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Danemark	\N	12339	2	\N	\N
14768	PDTDEL	2009-03-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Islande	\N	12358	3	\N	\N
14769	PDTDEL	2009-03-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Suède	\N	9577	5	\N	\N
14770	VICPDT	2009-03-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10835	2	\N	\N
14771	VICPDT	2009-03-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10922	3	\N	\N
14772	SECRET	2009-03-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10854	4	\N	\N
14869	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13314	\N	\N	\N
14867	VICPDT	2009-03-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8519	\N	\N	\N
14868	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13313	\N	\N	\N
14983	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13394	\N	\N	\N
15017	MEMBRE	2008-10-01 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	13427	\N	\N	\N
15019	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13428	\N	\N	\N
15058	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13459	\N	\N	\N
15059	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13460	\N	\N	\N
15060	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13461	\N	\N	\N
15061	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13462	\N	\N	\N
15062	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13463	\N	\N	\N
15063	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13464	\N	\N	\N
15064	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13465	\N	\N	\N
15065	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13466	\N	\N	\N
15066	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13467	\N	\N	\N
15067	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13468	\N	\N	\N
15068	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13469	\N	\N	\N
15069	MEMBRE	2008-11-26 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	\N	13470	\N	\N	\N
15070	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13472	\N	\N	\N
15071	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13473	\N	\N	\N
15072	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13474	\N	\N	\N
15073	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13475	\N	\N	\N
15074	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13476	\N	\N	\N
15075	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13477	\N	\N	\N
15076	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13478	\N	\N	\N
15077	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13479	\N	\N	\N
15078	VICPDT	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13480	7	\N	\N
15079	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13481	\N	\N	\N
15080	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13482	\N	\N	\N
15081	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13483	\N	\N	\N
15082	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13484	\N	\N	\N
15083	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13485	\N	\N	\N
15084	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13487	\N	\N	\N
15085	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13488	\N	\N	\N
15086	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13489	\N	\N	\N
15087	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13490	\N	\N	\N
15088	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13491	\N	\N	\N
15089	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13492	\N	\N	\N
15091	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13494	\N	\N	\N
15092	MEMBRE	2008-10-01 00:00:00	2009-03-31 00:00:00	ANCIEN	\N	\N	\N	\N	13495	\N	\N	\N
15093	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13496	\N	\N	\N
15094	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13497	\N	\N	\N
15095	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13498	\N	\N	\N
15096	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13499	\N	\N	\N
15097	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13500	\N	\N	\N
15098	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13501	\N	\N	\N
15099	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13502	\N	\N	\N
15100	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13503	\N	\N	\N
15101	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13504	\N	\N	\N
15102	MEMBRE	2008-10-01 00:00:00	2009-03-31 00:00:00	ANCIEN	\N	\N	\N	\N	13505	\N	\N	\N
15103	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13506	\N	\N	\N
15105	SECRET	2009-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13495	\N	\N	\N
15107	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13508	\N	\N	\N
15108	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13509	\N	\N	\N
15115	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13516	\N	\N	\N
15116	MEMBRE	2008-10-01 00:00:00	2009-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	13517	\N	\N	\N
15117	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13518	\N	\N	\N
15119	MEMBRE	2008-10-01 00:00:00	2009-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	13520	\N	\N	\N
15120	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13521	\N	\N	\N
15124	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13525	\N	\N	\N
15125	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13526	\N	\N	\N
15126	MEMBRE	2008-11-26 00:00:00	2009-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	13527	0	\N	\N
15127	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13528	\N	\N	\N
15128	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13529	\N	\N	\N
15129	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13530	\N	\N	\N
15130	MEMBRE	2008-11-26 00:00:00	2009-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	13531	0	\N	\N
15131	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13532	\N	\N	\N
15132	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13533	\N	\N	\N
14886	PDTHON	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13324	2	\N	\N
14887	PDTDEL	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Argentine	\N	13325	3	\N	\N
14891	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13329	\N	\N	\N
15104	VICPDT	2009-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13505	\N	\N	\N
15110	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13511	\N	\N	\N
15111	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13512	\N	\N	\N
15112	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13513	\N	\N	\N
15113	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13514	\N	\N	\N
15114	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13515	\N	\N	\N
15118	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13519	\N	\N	\N
15121	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13522	\N	\N	\N
15123	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13524	\N	\N	\N
15133	MEMBRE	2008-11-26 00:00:00	2009-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	13534	0	\N	\N
15134	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13535	\N	\N	\N
15135	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13536	\N	\N	\N
15136	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13537	\N	\N	\N
15137	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13538	\N	\N	\N
15138	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13539	\N	\N	\N
15139	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13540	\N	\N	\N
15140	MEMBRE	2008-11-26 00:00:00	2009-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	13541	0	\N	\N
15141	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13542	\N	\N	\N
15142	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13543	\N	\N	\N
15143	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13544	\N	\N	\N
15144	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13545	\N	\N	\N
15145	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13546	\N	\N	\N
15146	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13547	\N	\N	\N
15147	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13548	\N	\N	\N
15148	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13549	\N	\N	\N
15149	MEMBRE	2008-11-26 00:00:00	2009-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	13550	0	\N	\N
15150	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13551	\N	\N	\N
15151	MEMBRE	2008-11-26 00:00:00	2009-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	13552	0	\N	\N
15152	MEMBRE	2008-11-26 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	13553	\N	\N	\N
15153	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13554	\N	\N	\N
15154	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13555	\N	\N	\N
15155	MEMBRE	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13556	\N	\N	\N
15156	MEMBRE	2008-11-26 00:00:00	2009-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	13557	0	\N	\N
8286	MEMBRE	2001-10-01 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	8216	\N	\N	\N
15840	MEMBRE	2010-11-01 00:00:00	2011-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	14061	0	\N	\N
15844	PDT	2011-02-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11983	1	\N	\N
15845	PDT	2011-02-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14061	1	\N	\N
15848	PDTHON	2011-02-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2226	\N	\N	\N
15849	PDTHON	2011-02-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	2731	\N	\N	\N
15857	MEMBRE	2010-01-15 00:00:00	2011-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14070	\N	\N	\N
15777	MEMBRE	2010-03-30 00:00:00	2010-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	14004	\N	\N	\N
15797	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14017	\N	\N	\N
15842	MEMBRE	2010-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14064	\N	\N	\N
15851	MEMBRE	2010-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14067	\N	\N	\N
15782	VICPDT	2010-07-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12607	\N	\N	\N
15796	MEMBRE	2010-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14016	\N	\N	\N
15808	MEMBRE	2010-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14028	\N	\N	\N
15822	MEMBRE	2010-11-01 00:00:00	2011-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14042	\N	\N	\N
15823	MEMBRE	2010-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14043	\N	\N	\N
15824	MEMBRE	2010-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14044	\N	\N	\N
15825	MEMBRE	2010-11-01 00:00:00	2011-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14046	\N	\N	\N
15826	MEMBRE	2010-11-01 00:00:00	2011-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14047	\N	\N	\N
15751	MEMBRE	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13978	\N	\N	\N
15802	MEMBRE	2010-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14022	\N	\N	\N
15803	MEMBRE	2010-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14023	\N	\N	\N
15806	MEMBRE	2010-10-01 00:00:00	2011-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14026	\N	\N	\N
15820	MEMBRE	2010-11-01 00:00:00	2011-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14040	\N	\N	\N
15827	MEMBRE	2010-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14048	\N	\N	\N
15832	MEMBRE	2011-01-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14053	\N	\N	\N
8400	MEMBRE	2001-10-01 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	8297	\N	\N	\N
11545	MEMBRE	2006-01-31 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10882	\N	\N	\N
11608	MEMBRE	2006-01-31 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10942	\N	\N	\N
11621	MEMBRE	2006-02-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10955	\N	\N	\N
15290	PDTHON	2009-05-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10981	\N	\N	\N
11632	MEMBRE	2006-03-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10962	\N	\N	\N
15828	MEMBRE	2010-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14049	\N	\N	\N
15755	MEMBRE	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13980	\N	\N	\N
15805	MEMBRE	2010-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14025	\N	\N	\N
15813	MEMBRE	2010-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14033	\N	\N	\N
15814	MEMBRE	2010-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14034	\N	\N	\N
15815	MEMBRE	2010-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14035	\N	\N	\N
15841	MEMBRE	2010-11-01 00:00:00	2011-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14063	\N	\N	\N
15843	MEMBRE	2010-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14065	\N	\N	\N
15852	MEMBRE	2010-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14068	\N	\N	\N
15780	MEMBRE	2010-07-07 00:00:00	2010-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	10475	\N	\N	\N
15781	PDT	2010-07-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7232	\N	\N	\N
15783	PDT	2010-07-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11613	\N	\N	\N
15784	PDTDEL	2010-07-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11326	\N	\N	\N
15785	SECRET	2010-07-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12540	\N	\N	\N
15854	MEMBRE	2011-02-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10182	\N	\N	\N
15855	PDTDEL	2011-02-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Gambie	\N	14012	6	\N	\N
11622	MEMBRE	2006-02-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10956	\N	\N	\N
11636	MEMBRE	2006-03-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10966	\N	\N	\N
11643	MEMBRE	2006-03-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10973	\N	\N	\N
10541	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10124	\N	\N	\N
10574	SECRET	2005-01-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10130	\N	\N	\N
10589	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10142	\N	\N	\N
11178	MEMBRE	2005-04-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10583	\N	\N	\N
11194	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10595	\N	\N	\N
11218	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10619	\N	\N	\N
11242	MEMBRE	2005-04-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10630	\N	\N	\N
11282	SECRET	2005-05-31 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10632	\N	\N	\N
11283	MEMBRE	2005-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10649	\N	\N	\N
11352	VICPDT	2005-06-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10667	\N	\N	\N
11307	MEMBRE	2005-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10673	\N	\N	\N
11320	MEMBRE	2005-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10686	\N	\N	\N
11330	MEMBRE	2005-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10696	\N	\N	\N
11362	MEMBRE	2004-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10716	\N	\N	\N
11386	MEMBRE	2004-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10738	\N	\N	\N
11401	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10753	\N	\N	\N
11408	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10760	\N	\N	\N
11858	MEMBRE	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11162	\N	\N	\N
11876	MEMBRE	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11180	\N	\N	\N
11917	MEMBRE	2006-12-29 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11220	\N	\N	\N
12214	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11489	\N	\N	\N
11856	MEMBRE	2006-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11160	\N	\N	\N
12236	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11511	\N	\N	\N
12274	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11549	\N	\N	\N
12297	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11572	\N	\N	\N
12227	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11502	\N	\N	\N
11690	MEMBRE	2006-04-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11019	\N	\N	\N
11699	MEMBRE	2006-06-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11028	\N	\N	\N
11710	MEMBRE	2006-06-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11039	\N	\N	\N
11806	MEMBRE	2006-11-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11122	\N	\N	\N
12284	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11559	\N	\N	\N
12309	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11584	\N	\N	\N
12316	MEMBRE	2007-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11590	\N	\N	\N
11967	MEMBRE	2007-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11269	\N	\N	\N
11801	MEMBRE	2006-10-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11117	\N	\N	\N
12263	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11538	\N	\N	\N
12271	MEMBRE	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11546	\N	\N	\N
11803	MEMBRE	2006-11-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11119	\N	\N	\N
11837	MEMBRE	2006-11-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11153	\N	\N	\N
12095	MEMBRE	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11379	\N	\N	\N
11653	MEMBRE	2006-03-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10983	\N	\N	\N
11679	MEMBRE	2006-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11008	\N	\N	\N
12120	MEMBRE	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11404	\N	\N	\N
12142	MEMBRE	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11426	\N	\N	\N
12151	MEMBRE	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11435	\N	\N	\N
12404	MEMBRE	2008-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11641	\N	\N	\N
12438	MEMBRE	2008-04-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11673	\N	\N	\N
12446	MEMBRE	2008-04-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11681	\N	\N	\N
12455	MEMBRE	2008-04-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11690	\N	\N	\N
12701	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11842	\N	\N	\N
12501	SECRET	2008-12-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11718	10	\N	\N
12545	SECRET	2008-12-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11737	7	\N	\N
12582	SECRET	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11752	12	\N	\N
12044	MEMBRE	2007-02-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11340	\N	\N	\N
12977	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12017	\N	\N	\N
14445	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13048	\N	\N	\N
14585	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13160	\N	\N	\N
14676	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13211	\N	\N	\N
14655	SECRET	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12748	\N	\N	\N
9792	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9517	\N	\N	\N
9191	MEMBRE	2003-06-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8999	\N	\N	\N
9032	MEMBRE	2004-10-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8834	\N	\N	\N
9915	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9610	\N	\N	\N
9937	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9635	\N	\N	\N
5362	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5417	\N	\N	\N
14373	MEMBRE	2009-02-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9096	0	\N	\N
10164	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9792	\N	\N	\N
10100	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	9721	\N	\N	\N
11355	SECRET	2005-06-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10659	\N	\N	\N
11343	MEMBRE	2005-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10708	\N	\N	\N
11125	SECRET	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10546	11	\N	\N
12510	SECRET	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10119	13	\N	\N
15227	SECRET	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13531	9	\N	\N
15787	MEMBRE	2010-07-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14007	\N	\N	\N
15829	MEMBRE	2011-01-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14050	\N	\N	\N
15837	MEMBRE	2010-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14058	\N	\N	\N
15860	MEMBRE	2010-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14074	\N	\N	\N
15839	MEMBRE	2010-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14060	\N	\N	\N
15809	MEMBRE	2010-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14029	\N	\N	\N
15810	MEMBRE	2010-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14030	\N	\N	\N
15865	MEMBRE	2011-04-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14080	\N	\N	\N
15866	MEMBRE	2011-04-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14081	\N	\N	\N
15867	MEMBRE	2011-04-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14082	\N	\N	\N
15868	MEMBRE	2011-05-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14083	\N	\N	\N
15870	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14090	\N	\N	\N
15871	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14091	\N	\N	\N
15872	MEMBRE	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14092	\N	\N	\N
15873	MEMBRE	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14093	\N	\N	\N
15874	MEMBRE	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14094	\N	\N	\N
15875	MEMBRE	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14095	\N	\N	\N
15876	MEMBRE	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14096	\N	\N	\N
15877	MEMBRE	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14097	\N	\N	\N
15878	MEMBRE	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14098	\N	\N	\N
15879	MEMBRE	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14099	\N	\N	\N
15880	MEMBRE	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14100	\N	\N	\N
15881	MEMBRE	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14101	\N	\N	\N
15882	MEMBRE	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14102	\N	\N	\N
15883	MEMBRE	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14103	\N	\N	\N
15884	MEMBRE	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14104	\N	\N	\N
15885	MEMBRE	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14105	\N	\N	\N
15886	MEMBRE	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14106	\N	\N	\N
15887	MEMBRE	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14107	\N	\N	\N
15889	MEMBRE	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14111	\N	\N	\N
15890	MEMBRE	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14112	\N	\N	\N
15914	MEMBRE	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14136	\N	\N	\N
15938	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8537	\N	\N	\N
15940	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7838	\N	\N	\N
18134	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16338	\N	\N	\N
18139	MEMBRE	2011-10-01 00:00:00	2012-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	16343	\N	\N	\N
18140	MEMBRE	2011-10-01 00:00:00	2014-04-24 00:00:00	ANCIEN	\N	\N	\N	\N	16344	\N	\N	\N
18141	MEMBRE	2011-10-01 00:00:00	2012-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	16345	\N	\N	\N
18142	MEMBRE	2011-10-01 00:00:00	2012-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	16346	\N	\N	\N
18143	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16347	\N	\N	2014-09-28 17:40:23
18375	PDT	2012-01-11 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16506	\N	\N	\N
18378	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16581	\N	\N	2014-09-28 18:19:47
18714	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16917	\N	\N	\N
18729	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16932	\N	\N	\N
18516	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16719	\N	\N	\N
18750	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16953	\N	\N	\N
18724	MEMBRE	2011-10-01 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	16927	\N	\N	\N
18519	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16722	\N	\N	\N
18730	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16933	\N	\N	\N
18731	MEMBRE	2011-10-01 00:00:00	2012-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	16934	\N	\N	\N
18733	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16936	\N	\N	\N
18741	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16944	\N	\N	\N
18742	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16945	\N	\N	2014-09-28 17:27:35
18534	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16737	\N	\N	2014-09-28 13:32:35
18535	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16738	\N	\N	2014-09-28 16:50:17
18536	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16739	\N	\N	2014-09-28 17:55:37
18537	MEMBRE	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	16740	\N	\N	2014-09-29 13:43:10
18545	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16748	\N	\N	\N
18546	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16749	\N	\N	\N
15861	MEMBRE	2010-03-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14075	\N	\N	\N
18751	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16954	\N	\N	\N
18548	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16751	\N	\N	\N
18549	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16752	\N	\N	\N
18754	MEMBRE	2011-10-01 00:00:00	2014-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	16957	\N	\N	2014-12-18 16:15:04
18551	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16754	\N	\N	\N
18552	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16755	\N	\N	\N
18553	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16756	\N	\N	\N
18755	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16958	\N	\N	\N
18563	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16766	\N	\N	\N
18564	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16767	\N	\N	\N
18565	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16768	\N	\N	\N
18566	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16769	\N	\N	2014-09-28 12:56:42
18591	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16794	\N	\N	2014-09-28 16:40:50
18592	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16795	\N	\N	\N
18593	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16796	\N	\N	\N
18594	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16797	\N	\N	2014-09-28 16:59:41
18596	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16799	\N	\N	2014-09-28 13:19:48
18609	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16812	\N	\N	2014-09-28 17:27:35
18601	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16804	\N	\N	\N
18602	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16805	\N	\N	2014-09-28 13:19:48
18611	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16814	\N	\N	\N
18604	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16807	\N	\N	\N
18606	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16809	\N	\N	2014-09-28 16:59:41
18607	MEMBRE	2011-10-01 00:00:00	2012-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	16810	\N	\N	\N
18608	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16811	\N	\N	\N
18610	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16813	\N	\N	\N
18613	MEMBRE	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	16816	\N	\N	\N
18614	MEMBRE	2011-10-01 00:00:00	2012-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	16817	\N	\N	\N
18617	MEMBRE	2011-10-01 00:00:00	2012-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	16820	\N	\N	\N
18618	MEMBRE	2011-10-01 00:00:00	2012-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	16821	\N	\N	\N
18619	MEMBRE	2011-10-01 00:00:00	2012-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	16822	\N	\N	\N
18620	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16823	\N	\N	\N
18626	MEMBRE	2011-10-01 00:00:00	2012-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	16829	\N	\N	\N
18627	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16830	\N	\N	\N
18628	MEMBRE	2011-10-01 00:00:00	2012-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	16831	\N	\N	\N
15913	MEMBRE	2011-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14135	\N	\N	\N
18144	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16348	\N	\N	2014-09-28 17:34:16
18756	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16959	\N	\N	2014-09-28 16:42:05
18757	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16960	\N	\N	2014-09-28 17:00:59
18758	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16961	\N	\N	\N
18760	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16963	\N	\N	\N
18761	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16964	\N	\N	2014-09-28 17:35:38
18762	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16965	\N	\N	2014-09-28 13:21:47
18763	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16966	\N	\N	\N
18764	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16967	\N	\N	2014-09-28 19:03:23
18765	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16968	\N	\N	\N
18766	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16969	\N	\N	\N
18767	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16970	\N	\N	2014-09-28 17:27:35
18770	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16973	\N	\N	\N
18777	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16980	\N	\N	2014-09-28 12:44:31
18809	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17012	\N	\N	\N
21826	MEMBRE	2012-02-22 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19843	\N	\N	\N
21827	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19844	\N	\N	\N
18814	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17017	\N	\N	\N
21828	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19845	\N	\N	\N
18816	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17019	\N	\N	2014-09-28 13:16:32
18817	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17020	\N	\N	\N
18818	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17021	\N	\N	\N
21829	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19846	\N	\N	\N
18820	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17023	\N	\N	\N
18821	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17024	\N	\N	\N
21830	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19847	\N	\N	2014-09-28 13:39:21
21832	SECRET	2012-02-29 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19848	\N	\N	\N
18884	MEMBRE	2011-10-01 00:00:00	2012-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	17087	\N	\N	\N
18954	VICPDT	2012-01-26 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16708	\N	\N	2014-09-28 19:03:04
18972	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17157	\N	\N	\N
21833	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19849	\N	\N	\N
18974	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17159	\N	\N	\N
18975	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17160	\N	\N	2014-09-28 17:55:39
18976	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17161	\N	\N	\N
18977	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17162	\N	\N	\N
18982	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17167	\N	\N	2014-09-28 17:55:39
15918	MEMBRE	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14140	\N	\N	\N
15925	MEMBRE	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5849	\N	\N	\N
15926	MEMBRE	2004-10-01 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	5835	\N	\N	\N
15927	MEMBRE	2004-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3001	\N	\N	\N
15928	MEMBRE	2008-10-01 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	12302	\N	\N	\N
15929	MEMBRE	2001-10-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	3897	\N	\N	\N
15930	MEMBRE	2004-10-15 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	8963	\N	\N	\N
15931	MEMBRE	2009-02-11 00:00:00	2009-02-28 00:00:00	ANCIEN	\N	\N	\N	\N	10248	\N	\N	\N
15932	MEMBRE	2001-10-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	1833	\N	\N	\N
15933	MEMBRE	2002-01-16 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5145	\N	\N	\N
15934	MEMBRE	2003-06-18 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3900	\N	\N	\N
15935	MEMBREBUR	2003-06-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3066	\N	\N	\N
15936	MEMBRE	2001-10-01 00:00:00	2002-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1922	\N	\N	\N
15939	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7973	\N	\N	\N
15941	SECRET	2011-11-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13843	\N	\N	\N
14381	MEMBREBUR	2009-02-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12712	\N	\N	\N
14440	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13043	\N	\N	\N
18990	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17175	\N	\N	\N
18991	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17176	\N	\N	\N
18992	MEMBRE	2011-12-14 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17177	\N	\N	\N
18995	MEMBRE	2011-10-01 00:00:00	2012-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	17180	\N	\N	\N
18997	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17182	\N	\N	\N
18998	MEMBRE	2011-10-01 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	17183	\N	\N	\N
19000	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17185	\N	\N	2014-09-28 17:22:11
19005	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17190	\N	\N	\N
19021	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17206	\N	\N	2014-09-28 13:39:21
19027	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17212	\N	\N	\N
19046	MEMBRE	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17231	\N	\N	2014-09-28 16:40:50
19047	MEMBRE	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17232	\N	\N	\N
19051	MEMBRE	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17236	\N	\N	2014-09-28 13:19:48
19052	MEMBRE	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17237	\N	\N	2014-09-28 17:35:38
19053	MEMBRE	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17238	\N	\N	2014-09-28 12:56:42
19054	MEMBRE	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17239	\N	\N	2014-09-28 16:42:05
18850	MEMBRE	2011-10-01 00:00:00	2012-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	17053	\N	\N	\N
18852	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17055	\N	\N	\N
15937	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8019	\N	\N	\N
18860	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17063	\N	\N	\N
18952	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17146	\N	\N	\N
19057	MEMBRE	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17242	\N	\N	\N
19058	MEMBRE	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17243	\N	\N	\N
19059	MEMBRE	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17244	\N	\N	\N
19060	MEMBRE	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17245	\N	\N	\N
19061	MEMBRE	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17246	\N	\N	\N
19082	MEMBRE	2011-10-01 00:00:00	2014-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	17267	\N	\N	2014-11-04 11:22:47
19083	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17268	\N	\N	2014-09-28 12:56:42
19084	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17269	\N	\N	\N
19085	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17270	\N	\N	\N
19816	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18465	\N	\N	2014-09-28 13:19:48
19817	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18466	8	\N	\N
19818	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18022	16	\N	2014-09-28 17:38:26
19819	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18023	\N	\N	\N
19820	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18024	10	\N	\N
19821	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18025	\N	\N	\N
19822	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18026	\N	\N	\N
18182	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16386	\N	\N	2014-09-29 09:05:47
18198	MEMBRE	2011-10-01 00:00:00	2012-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	16402	\N	\N	\N
18225	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16429	\N	\N	\N
18242	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16446	\N	\N	\N
18244	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16448	\N	\N	\N
18245	MEMBRE	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	16449	\N	\N	\N
18246	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16450	\N	\N	\N
18247	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16451	\N	\N	\N
18248	MEMBRE	2011-10-01 00:00:00	2014-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	16452	\N	\N	\N
18312	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16516	\N	\N	\N
18313	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16517	\N	\N	\N
18433	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16636	\N	\N	\N
18437	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16640	\N	\N	2014-09-28 17:15:42
18438	MEMBRE	2011-10-01 00:00:00	2014-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	16641	\N	\N	2014-12-18 16:15:04
18439	MEMBRE	2011-10-01 00:00:00	2013-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16642	\N	\N	\N
18440	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16643	\N	\N	\N
18511	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16714	\N	\N	\N
18530	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16733	\N	\N	\N
18538	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16741	\N	\N	\N
18539	MEMBRE	2011-10-01 00:00:00	2012-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	16742	\N	\N	\N
18540	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16743	\N	\N	\N
18555	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16758	\N	\N	\N
18590	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16793	\N	\N	\N
18597	MEMBRE	2011-10-01 00:00:00	2012-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	16800	\N	\N	\N
18598	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16801	\N	\N	\N
18599	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16802	\N	\N	2014-09-28 16:59:41
19823	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18027	\N	\N	\N
19824	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18028	\N	\N	\N
19825	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18029	12	\N	2014-09-28 17:31:42
19826	MEMBRE	2011-10-01 00:00:00	2013-02-28 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18030	\N	\N	\N
19827	SECRET	2011-10-01 00:00:00	2014-10-03 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18031	15	\N	2014-11-27 10:15:39
19828	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18032	8	\N	\N
19829	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18193	\N	\N	\N
19830	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18194	4	\N	\N
19831	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18195	\N	\N	\N
19832	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18196	\N	\N	2014-09-28 17:27:35
19833	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18197	12	\N	\N
19834	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18198	\N	\N	\N
19835	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18199	\N	\N	\N
19836	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18200	\N	\N	\N
19837	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18201	6	\N	\N
19838	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18202	\N	\N	\N
19839	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18280	\N	\N	2014-09-28 13:40:33
19840	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18281	4	\N	\N
19841	MEMBRE	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18282	\N	\N	2014-09-29 13:41:53
19842	MEMBRE	2011-10-01 00:00:00	2014-10-03 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18283	\N	\N	\N
19843	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18284	\N	\N	\N
19844	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18285	13	\N	2014-09-28 17:22:11
19845	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18286	\N	\N	\N
19846	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18287	\N	\N	\N
20072	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17921	4	\N	2014-09-28 17:03:42
20073	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17922	\N	\N	2014-09-28 13:21:47
10583	VICPDT	2004-12-07 00:00:00	2009-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	6283	8	\N	\N
20074	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18088	\N	\N	2014-09-28 17:05:42
20075	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18089	16	\N	\N
20076	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18090	\N	\N	\N
20077	MEMBRE	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18091	\N	\N	2014-09-29 13:41:53
20078	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18092	\N	\N	\N
20079	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18093	7	\N	\N
20080	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18094	\N	\N	2014-09-28 17:22:11
20081	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18095	\N	\N	\N
20082	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18096	\N	\N	\N
20083	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18097	\N	\N	2014-09-28 16:40:50
19905	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18045	\N	\N	\N
19906	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18046	\N	\N	2014-09-28 19:03:23
19907	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18047	\N	\N	\N
19908	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18048	3	\N	2014-09-28 17:31:42
19909	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18049	2	\N	\N
19910	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18050	\N	\N	\N
19911	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18051	5	\N	\N
19912	PDTHON	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18052	2	\N	\N
19913	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18053	\N	\N	2014-09-28 13:21:47
19914	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18054	1	\N	\N
19915	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18213	\N	\N	\N
19916	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18214	\N	\N	\N
20084	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18098	\N	\N	2014-09-28 16:59:41
20085	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18251	\N	\N	\N
20086	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18252	\N	\N	\N
20087	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18253	11	\N	\N
20088	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18254	\N	\N	2014-09-28 16:42:05
20089	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18255	13	\N	\N
20090	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18256	\N	\N	\N
20091	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18257	\N	\N	\N
20092	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18258	10	\N	\N
20093	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18259	18	\N	\N
20094	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18260	\N	\N	\N
20095	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour l'Estonie	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18346	2	\N	\N
19917	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18215	20	\N	2014-09-28 12:09:44
19918	MEMBRE	2011-10-01 00:00:00	2014-10-03 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18216	\N	\N	\N
19919	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18217	5	\N	2014-09-28 12:32:23
19920	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18218	13	\N	\N
19921	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18219	\N	\N	\N
19922	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18220	\N	\N	\N
19923	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18221	3	\N	\N
19924	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18222	\N	\N	\N
19925	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18223	\N	\N	2014-09-28 17:31:42
19926	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18302	7	\N	\N
19927	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18303	\N	\N	\N
19928	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18304	16	\N	\N
18780	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16983	\N	\N	\N
18781	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16984	\N	\N	\N
18874	MEMBRE	2011-10-01 00:00:00	2012-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	17077	\N	\N	\N
19002	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17187	\N	\N	\N
19018	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17203	\N	\N	\N
19069	MEMBRE	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17254	\N	\N	2014-09-28 13:39:21
20096	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18347	2	\N	\N
20097	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18348	\N	\N	\N
20098	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18349	4	\N	\N
20099	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18350	\N	\N	\N
20100	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18351	\N	\N	\N
20101	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18352	\N	\N	\N
20102	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18353	12	\N	2014-09-28 13:21:47
20103	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18354	\N	\N	2014-09-28 18:03:38
20104	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18355	5	\N	\N
20105	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18356	\N	\N	\N
19087	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17272	\N	\N	\N
19088	MEMBRE	2011-12-14 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17273	\N	\N	2014-09-28 17:07:41
19092	MEMBRE	2011-10-01 00:00:00	2012-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	17277	\N	\N	\N
19929	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18305	14	\N	\N
19930	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18306	\N	\N	\N
19931	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18307	\N	\N	\N
19932	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18308	\N	\N	\N
19933	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18309	4	\N	\N
19934	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18310	\N	\N	\N
19935	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18311	4	\N	\N
19936	PDT	2011-10-01 00:00:00	2014-05-11 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18312	1	\N	\N
19937	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17879	\N	\N	2014-09-28 17:27:35
19938	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17880	\N	\N	\N
19939	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17881	\N	\N	2014-09-28 17:38:26
20106	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17923	\N	\N	\N
20107	MEMBRE	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17924	\N	\N	\N
20108	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17925	\N	\N	\N
20109	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17926	\N	\N	2014-09-28 18:03:38
20110	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17927	\N	\N	2014-09-28 17:35:38
20111	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17928	\N	\N	2014-09-28 13:39:21
20112	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17929	\N	\N	\N
20113	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17930	\N	\N	2014-09-28 13:19:48
20114	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17931	\N	\N	\N
20115	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17932	\N	\N	\N
20116	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17933	\N	\N	2014-09-28 17:27:35
20117	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18099	18	\N	2014-09-28 17:07:41
19940	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17882	\N	\N	2014-09-28 18:00:58
19941	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17883	6	\N	\N
19942	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17884	\N	\N	\N
19943	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17885	\N	\N	\N
19944	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17886	1	\N	\N
19945	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17887	3	\N	\N
19946	MEMBRE	2011-10-01 00:00:00	2014-10-03 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17888	\N	\N	2014-11-27 10:15:39
19947	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17889	\N	\N	\N
19948	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18055	\N	\N	2014-09-28 17:40:23
19949	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18056	\N	\N	\N
19950	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18057	\N	\N	\N
19951	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18058	\N	\N	\N
20118	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18100	\N	\N	\N
20119	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18101	\N	\N	\N
20120	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18102	19	\N	\N
20121	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18103	\N	\N	\N
20122	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18104	\N	\N	\N
6582	SECRET	2002-12-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6437	6	\N	\N
6598	MEMBRE	2002-12-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6464	\N	\N	\N
6610	MEMBRE	2002-04-07 00:00:00	2005-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	6476	\N	\N	\N
6620	MEMBRE	2002-07-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6486	\N	\N	\N
6631	MEMBRE	2003-01-29 00:00:00	2004-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	5178	\N	\N	\N
6640	MEMBRE	2003-04-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6498	\N	\N	\N
6654	MEMBRE	2003-04-01 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	6512	0	\N	\N
6665	MEMBRE	2003-04-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6523	\N	\N	\N
6683	MEMBRE	2003-04-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	6541	\N	\N	\N
6101	SECRET	2001-10-27 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	6030	10	\N	\N
6150	MEMBRE	2000-11-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6080	\N	\N	\N
6177	MEMBREBUR	2002-01-23 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6112	20	\N	\N
6187	SECRET	2002-01-09 00:00:00	2004-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	6122	11	\N	\N
6197	VICPDT	2002-01-09 00:00:00	2004-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	6132	6	\N	\N
6240	MEMBRE	1999-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6175	\N	\N	\N
6286	MEMBREBUR	2002-01-23 00:00:00	2004-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	2923	17	\N	\N
6305	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6213	\N	\N	\N
6314	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6223	\N	\N	\N
6326	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6237	\N	\N	\N
6340	VICPDT	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6251	3	\N	\N
6352	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	3294	\N	\N	\N
7351	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7448	\N	\N	\N
7367	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7464	\N	\N	\N
7393	MEMBRE	2001-10-01 00:00:00	2004-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	7478	\N	\N	\N
7403	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7488	\N	\N	\N
7449	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7520	\N	\N	\N
7462	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7533	\N	\N	\N
7477	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7548	\N	\N	\N
7505	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7566	\N	\N	\N
7559	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7620	\N	\N	\N
7592	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7644	\N	\N	\N
7604	SECRET	2001-10-02 00:00:00	2005-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7646	\N	\N	\N
7627	MEMBRE	2001-10-01 00:00:00	2004-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	7665	\N	\N	\N
6066	MEMBRE	1999-01-01 00:00:00	2002-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	5995	\N	\N	\N
6084	MEMBRE	2001-10-18 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6013	\N	\N	\N
6700	MEMBRE	2003-03-21 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6557	\N	\N	\N
6713	MEMBRE	2001-10-01 00:00:00	2003-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	6564	\N	\N	\N
6724	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	6575	\N	\N	\N
6765	MEMBRE	2003-06-25 00:00:00	2004-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	6605	\N	\N	\N
7208	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7321	\N	\N	\N
7214	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7327	\N	\N	\N
7223	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7336	\N	\N	\N
7234	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7347	\N	\N	\N
7250	VICPDT	2001-10-02 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	7345	\N	\N	\N
7281	MEMBRE	2002-01-01 00:00:00	2002-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	7384	\N	\N	\N
7320	MEMBRE	2001-10-01 00:00:00	2001-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	7417	\N	\N	\N
7328	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	7425	\N	\N	\N
7344	MEMBRE	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	7441	\N	\N	\N
10556	MEMBRE	2004-10-01 00:00:00	2005-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	10130	\N	\N	\N
10638	MEMBRE	2004-10-01 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	10165	\N	\N	\N
10660	VICPDT	2004-12-16 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	5328	\N	\N	\N
10689	VICPDT	2004-11-03 00:00:00	2009-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	4945	6	\N	\N
10700	MEMBREBUR	2004-12-15 00:00:00	2009-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	2027	15	\N	\N
11464	MEMBRE	2005-06-01 00:00:00	2008-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	10811	0	\N	\N
11483	MEMBRE	2005-12-16 00:00:00	2008-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	10830	\N	\N	\N
11497	MEMBRE	2005-12-01 00:00:00	2007-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	10844	\N	\N	\N
11512	MEMBRE	2005-12-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	10858	\N	\N	\N
11574	MEMBRE	2006-01-31 00:00:00	2006-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	10912	\N	\N	\N
10435	SECRET	2004-10-01 00:00:00	2008-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	10008	8	\N	\N
11106	MEMBRE	2004-10-01 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	10526	0	\N	\N
11154	SECRET	2005-03-08 00:00:00	2009-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	4254	7	\N	\N
11332	MEMBRE	2005-06-01 00:00:00	2007-11-05 00:00:00	ANCIEN	\N	\N	\N	\N	10698	\N	\N	\N
11365	VICPDT	2004-12-08 00:00:00	2009-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	5944	8	\N	\N
11374	MEMBRE	2004-11-01 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	10726	\N	\N	\N
11890	MEMBRE	2006-11-28 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	11194	0	\N	\N
12177	MEMBRE	2007-07-01 00:00:00	2009-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	11459	\N	\N	\N
12202	MEMBRE	2007-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11477	\N	\N	\N
12416	MEMBRE	2004-11-04 00:00:00	2008-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	11652	0	\N	\N
3636	PDT	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3708	1	\N	\N
3637	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3709	\N	\N	\N
3682	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3757	\N	\N	\N
5239	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3762	\N	\N	\N
11947	MEMBRE	1998-09-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1526	\N	\N	\N
11232	SECRET	2004-12-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1492	14	\N	\N
3912	VICPDT	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3954	4	\N	\N
3943	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3989	\N	\N	\N
3954	MEMBRE	1999-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4003	\N	\N	\N
4020	MEMBRE	1999-01-01 00:00:00	2011-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	4072	\N	\N	\N
4111	MEMBRE	2000-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4159	\N	\N	\N
4142	MEMBRE	2000-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4192	\N	\N	\N
3766	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3841	\N	\N	\N
5191	PDT	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3872	1	\N	\N
3925	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	3968	\N	\N	\N
4391	MEMBRE	2000-12-12 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	4499	\N	\N	\N
4393	MEMBRE	2000-12-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4501	\N	\N	\N
4414	MEMBRE	2000-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4523	\N	\N	\N
12513	MEMBRE	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4526	0	\N	\N
10546	VICPDT	2004-11-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4564	6	\N	\N
4468	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4577	\N	\N	\N
4495	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4604	\N	\N	\N
4537	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4650	\N	\N	\N
4582	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4683	\N	\N	\N
10754	PDT	2004-12-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4227	1	\N	\N
4226	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4277	\N	\N	\N
4316	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4417	\N	\N	\N
11364	MEMBRE	2005-06-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4423	\N	\N	\N
12540	VICPDT	2008-12-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4432	2	\N	\N
4790	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4906	\N	\N	\N
4814	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4930	\N	\N	\N
4859	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4975	\N	\N	\N
4941	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5043	\N	\N	\N
4955	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5047	\N	\N	\N
5002	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5106	\N	\N	\N
5023	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5130	\N	\N	\N
10242	VICPDT	2004-11-25 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5139	2	\N	\N
4612	SECRET	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4719	11	\N	\N
12489	SECRET	2008-12-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4730	9	\N	\N
4655	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4765	\N	\N	\N
10039	VICPDT	2004-11-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4835	7	\N	\N
12368	MEMBRE	2008-02-01 00:00:00	2009-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	11615	\N	\N	\N
11824	MEMBRE	2006-11-15 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	11140	\N	\N	\N
12117	MEMBRE	2007-06-01 00:00:00	2007-10-23 00:00:00	ANCIEN	\N	\N	\N	\N	11401	\N	\N	\N
4751	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	4866	\N	\N	\N
10708	VICPDT	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10200	5	\N	\N
10752	VICPDT	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10244	3	\N	\N
10795	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10269	\N	\N	\N
10835	MEMBRE	2005-02-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10302	\N	\N	\N
10844	MEMBRE	2005-02-21 00:00:00	2010-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	10311	\N	\N	\N
10861	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10331	\N	\N	\N
11426	MEMBRE	2005-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10777	\N	\N	\N
11449	MEMBRE	2005-11-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10796	\N	\N	\N
12363	VICPDT	2008-01-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10830	\N	\N	\N
11530	SECRET	2006-01-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10837	5	\N	\N
11533	SECRET	2006-01-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10845	6	\N	\N
11515	MEMBRE	2005-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10861	\N	\N	\N
11554	MEMBRE	2005-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10891	\N	\N	\N
11567	MEMBRE	2006-02-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10905	\N	\N	\N
11583	MEMBRE	2006-01-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10921	\N	\N	\N
11601	MEMBRE	2006-02-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10935	\N	\N	\N
11609	MEMBRE	2006-02-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10943	\N	\N	\N
5302	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5363	\N	\N	\N
5424	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5470	\N	\N	\N
9638	VICPDT	2004-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5472	2	\N	\N
5469	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5517	\N	\N	\N
5472	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5521	\N	\N	\N
5525	SECRET	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5575	9	\N	\N
9323	SECRET	2004-11-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5615	9	\N	\N
5085	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5193	\N	\N	\N
5121	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5230	\N	\N	\N
10349	VICPDT	2004-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5238	7	\N	\N
5793	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5838	\N	\N	\N
5818	MEMBRE	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5863	\N	\N	\N
10654	TRESOR	2004-12-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5885	16	\N	\N
5977	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5933	\N	\N	\N
6009	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5967	\N	\N	\N
11151	SECRET	2004-11-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5972	9	\N	\N
6096	MEMBRE	2001-10-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6025	\N	\N	\N
5578	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5630	\N	\N	\N
5611	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5663	\N	\N	\N
5628	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5681	\N	\N	\N
5688	MEMBRE	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5742	\N	\N	\N
6458	MEMBRE	2001-10-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6354	\N	\N	\N
6503	MEMBRE	2002-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6386	\N	\N	\N
6525	MEMBRE	2002-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6408	\N	\N	\N
6642	MEMBRE	2003-04-01 00:00:00	2010-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	6500	\N	\N	\N
6667	MEMBRE	2003-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6525	\N	\N	\N
6205	MEMBRE	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	6140	\N	\N	\N
15888	MEMBRE	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14110	\N	\N	\N
15915	MEMBRE	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14137	\N	\N	\N
18132	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16336	\N	\N	\N
19847	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18288	\N	\N	\N
19848	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18289	1	\N	\N
19849	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18290	\N	\N	\N
19850	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18478	1	\N	\N
19851	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18479	\N	\N	2014-09-28 17:22:11
19852	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18480	\N	\N	\N
19853	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18481	2	\N	\N
19854	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18482	\N	\N	2014-09-28 19:03:04
19855	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18483	\N	\N	2014-09-28 18:00:58
19856	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18484	\N	\N	\N
15862	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14077	\N	\N	\N
15863	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14078	\N	\N	\N
15864	MEMBRE	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14079	\N	\N	\N
15916	MEMBRE	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14138	\N	\N	\N
15917	MEMBRE	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14139	\N	\N	\N
18645	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16848	\N	\N	\N
18646	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16849	\N	\N	2014-09-28 17:07:41
18647	MEMBRE	2011-10-01 00:00:00	2013-02-28 00:00:00	ANCIEN	\N	\N	\N	\N	16850	\N	\N	\N
18654	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16857	\N	\N	2014-09-28 13:40:33
18655	MEMBRE	2011-10-01 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	16858	\N	\N	\N
18656	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16859	\N	\N	\N
18657	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16860	\N	\N	\N
18876	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17079	\N	\N	2014-09-28 12:39:09
18659	MEMBRE	2011-10-01 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	16862	\N	\N	\N
18740	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16943	\N	\N	\N
19006	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17191	\N	\N	\N
18877	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17080	\N	\N	2014-09-28 17:27:35
19028	MEMBRE	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17213	\N	\N	\N
19029	MEMBRE	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17214	\N	\N	2014-09-28 13:39:21
19034	MEMBRE	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17219	\N	\N	\N
19035	MEMBRE	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17220	\N	\N	\N
19064	MEMBRE	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17249	\N	\N	2014-09-28 17:07:07
19065	MEMBRE	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17250	\N	\N	\N
19066	MEMBRE	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17251	\N	\N	\N
19067	MEMBRE	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17252	\N	\N	\N
19068	MEMBRE	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17253	\N	\N	2014-09-28 13:09:05
19857	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18485	2	\N	\N
19858	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18486	3	\N	2014-09-28 12:09:44
19859	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18487	\N	\N	\N
4856	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	4972	\N	\N	\N
4921	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	1979	10	\N	\N
4954	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5046	\N	\N	\N
4965	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5064	\N	\N	\N
4979	MEMBRE	2004-10-01 00:00:00	2004-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	5080	\N	\N	\N
4992	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5094	\N	\N	\N
5011	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5116	\N	\N	\N
5032	MEMBRE	2001-10-01 00:00:00	2004-11-24 00:00:00	ANCIEN	\N	\N	\N	\N	5139	\N	\N	\N
5046	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5153	\N	\N	\N
5729	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5790	\N	\N	\N
5741	MEMBRE	2001-10-01 00:00:00	2004-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	5802	\N	\N	\N
5755	VICPDT	2001-10-01 00:00:00	2004-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	4265	2	\N	\N
5761	MEMBRE	1999-01-01 00:00:00	2008-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	5804	0	\N	\N
5784	MEMBRE	1998-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5827	\N	\N	\N
5794	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5839	\N	\N	\N
5807	MEMBRE	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5852	\N	\N	\N
5815	MEMBRE	1998-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5860	\N	\N	\N
5827	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5873	\N	\N	\N
5839	MEMBRE	2001-10-01 00:00:00	2004-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	5885	\N	\N	\N
5850	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5896	\N	\N	\N
5863	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5909	\N	\N	\N
5875	MEMBRE	2001-05-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5921	\N	\N	\N
5886	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	1104	\N	\N	\N
5909	SECRET	2001-10-01 00:00:00	2004-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	3484	17	\N	\N
5927	SECRET	2001-10-01 00:00:00	2004-11-15 00:00:00	ANCIEN	\N	\N	\N	\N	2816	13	\N	\N
5957	TRESOR	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5849	11	\N	\N
5966	SECRET	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5856	9	\N	\N
5983	MEMBRE	2001-10-01 00:00:00	2004-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	5939	\N	\N	\N
5997	MEMBRE	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	5955	\N	\N	\N
6018	MEMBRE	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	5976	\N	\N	\N
6042	SECRET	2001-10-01 00:00:00	2004-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	2720	11	\N	\N
4746	VICPDT	2001-10-01 00:00:00	2008-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	4859	7	\N	\N
4766	MEMBRE	2001-10-01 00:00:00	2008-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	4881	\N	\N	\N
15750	MEMBRE	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13977	\N	\N	\N
15778	PDT	2010-06-29 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14004	1	\N	\N
15793	MEMBRE	2010-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14013	\N	\N	\N
15799	MEMBRE	2010-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14019	\N	\N	\N
15816	MEMBRE	2010-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14036	\N	\N	\N
15831	MEMBRE	2011-01-12 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14052	\N	\N	\N
15833	MEMBRE	2010-11-01 00:00:00	2011-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14054	\N	\N	\N
15834	MEMBRE	2010-11-01 00:00:00	2011-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14055	\N	\N	\N
15835	MEMBRE	2010-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14056	\N	\N	\N
15754	MEMBRE	2010-06-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13166	\N	\N	\N
15776	MEMBRE	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14003	\N	\N	\N
15788	MEMBRE	2010-07-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14008	\N	\N	\N
15790	MEMBRE	2010-07-01 00:00:00	2011-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14010	\N	\N	2015-11-12 15:26:22
15791	MEMBRE	2010-07-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14011	\N	\N	\N
15792	MEMBRE	2010-07-01 00:00:00	2011-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	14012	0	\N	\N
15794	MEMBRE	2010-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14014	\N	\N	\N
15821	MEMBRE	2010-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14041	\N	\N	\N
15817	MEMBRE	2010-11-01 00:00:00	2011-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14037	\N	\N	\N
15818	MEMBRE	2010-11-01 00:00:00	2011-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14038	\N	\N	\N
15819	MEMBRE	2010-11-01 00:00:00	2011-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14039	\N	\N	\N
20065	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17914	\N	\N	2014-09-28 16:40:50
20066	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17915	9	\N	2014-09-28 16:42:05
20067	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17916	\N	\N	2014-09-28 17:07:41
20068	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17917	\N	\N	\N
20069	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17918	7	\N	\N
20070	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17919	\N	\N	\N
20071	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17920	\N	\N	\N
18964	MEMBRE	2011-12-14 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17149	\N	\N	\N
18966	MEMBRE	2011-12-14 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17151	\N	\N	\N
19894	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18468	\N	\N	2014-09-28 17:27:35
19895	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18469	\N	\N	\N
19896	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18470	\N	\N	\N
19897	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18471	\N	\N	\N
19898	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18472	\N	\N	\N
19899	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18473	9	\N	\N
19900	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18474	\N	\N	2014-09-28 17:12:41
19901	MEMBRE	2011-10-01 00:00:00	2014-10-03 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18475	\N	\N	\N
19902	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18476	7	\N	\N
19903	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18477	6	\N	\N
19904	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18044	1	\N	\N
8991	MEMBRE	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	8792	\N	\N	\N
20712	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18880	10	\N	\N
20713	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour Oman	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18881	6	\N	\N
20714	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18882	4	\N	\N
20715	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18883	10	\N	2014-09-28 17:27:35
20716	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18533	\N	\N	\N
20717	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18534	\N	\N	\N
20718	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18535	8	\N	\N
20719	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18536	10	\N	\N
20720	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18537	\N	\N	\N
20721	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18538	8	\N	\N
20722	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18539	\N	\N	2014-09-28 13:21:47
20723	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18540	\N	\N	2014-09-28 13:21:47
18380	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16583	\N	\N	\N
18381	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16584	\N	\N	\N
18958	VICPDT	2012-01-26 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16577	\N	\N	\N
18959	SECRET	2012-01-26 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16499	\N	\N	2014-09-28 16:40:50
18960	SECRET	2012-01-26 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17086	\N	\N	\N
18962	SECRET	2012-01-26 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16500	\N	\N	\N
20295	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18414	6	\N	2014-09-28 12:32:23
20296	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18415	\N	\N	\N
20297	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18416	5	\N	\N
20298	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18417	\N	\N	\N
20299	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18418	\N	\N	2014-09-28 19:03:23
20300	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18419	8	\N	\N
20301	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18420	7	\N	2014-09-28 13:40:33
20302	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18421	10	\N	\N
20303	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18422	11	\N	\N
20304	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19036	8	\N	2014-09-28 12:56:42
20408	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18630	\N	\N	2014-09-28 18:19:47
20409	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18631	\N	\N	2014-09-28 16:42:05
20410	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18796	\N	\N	2014-09-28 17:03:42
20411	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18797	\N	\N	2014-09-28 17:22:11
20412	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18798	\N	\N	\N
20413	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18799	\N	\N	\N
20414	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18800	\N	\N	2014-09-28 17:27:29
20415	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18801	5	\N	\N
20416	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18802	\N	\N	\N
20417	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18803	\N	\N	\N
20418	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18804	\N	\N	\N
20419	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18805	\N	\N	\N
20553	MEMBRE	2011-10-01 00:00:00	2014-10-03 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19000	\N	\N	\N
20554	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19001	\N	\N	\N
20555	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19002	\N	\N	2014-09-28 17:07:07
20556	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19003	10	\N	2014-09-28 17:22:11
20557	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19004	\N	\N	\N
20558	SECRET	2011-10-01 00:00:00	2014-10-03 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19005	4	\N	2014-11-27 10:15:39
20559	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19006	\N	\N	\N
20560	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19007	7	\N	2014-09-28 13:40:33
20561	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19008	6	\N	\N
20562	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour le Mozambique	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18489	5	\N	2014-09-28 17:00:59
20563	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18490	\N	\N	2014-09-28 19:03:23
20564	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18491	\N	\N	\N
20724	MEMBRE	2011-10-01 00:00:00	2013-06-27 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18541	\N	\N	\N
20725	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18542	\N	\N	2014-09-28 16:50:17
20726	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18543	4	\N	\N
20727	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18709	15	\N	2014-09-28 17:09:16
20728	VICPDT	2011-10-01 00:00:00	2014-10-05 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18710	4	\N	2014-09-28 13:39:21
20729	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18711	\N	\N	\N
20730	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18712	\N	\N	\N
20731	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18713	\N	\N	\N
20732	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18714	\N	\N	\N
20733	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18715	11	\N	2014-09-28 18:03:38
20734	VICPDTDRT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18716	3	\N	\N
20735	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18717	\N	\N	2014-09-28 13:16:32
20305	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19037	\N	\N	2014-09-28 17:09:16
20306	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19038	10	\N	2014-09-28 13:39:21
20307	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19039	\N	\N	\N
20308	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19040	25	\N	\N
20309	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19041	8	\N	\N
20310	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19042	\N	\N	\N
20311	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19043	\N	\N	2014-09-28 17:15:42
20312	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	Pour Tuvalu	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19044	8	\N	\N
20313	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19045	5	\N	\N
20314	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19046	\N	\N	\N
20315	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18599	6	\N	\N
20316	MEMBRE	2011-10-01 00:00:00	2014-05-11 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18600	\N	\N	\N
18868	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17071	\N	\N	2014-09-28 18:03:38
18869	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17072	\N	\N	2014-09-28 16:42:05
18872	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17075	\N	\N	\N
18875	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17078	\N	\N	\N
18878	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17081	\N	\N	\N
18880	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17083	\N	\N	\N
20420	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18806	\N	\N	2014-09-28 12:32:23
20421	MEMBRE	2011-10-01 00:00:00	2015-02-22 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18968	\N	\N	\N
20422	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18969	17	\N	\N
20423	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18970	\N	\N	2014-09-28 13:19:48
20424	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18971	4	\N	\N
22256	MEMBRE	2013-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20204	\N	2013-10-15 09:53:51	\N
20425	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18972	\N	\N	\N
20426	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour le Vanuatu	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18973	2	\N	\N
20427	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour les Iles Fidji	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18974	3	\N	\N
20428	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18975	18	\N	2014-09-28 17:27:35
20565	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18492	\N	\N	\N
20566	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18493	\N	\N	\N
20567	MEMBRE	2011-10-01 00:00:00	2013-02-06 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18494	\N	\N	\N
20568	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18495	\N	\N	\N
20569	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18496	\N	\N	\N
20570	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour les Comores	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18497	2	\N	\N
20571	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour le Kenya	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18498	3	\N	\N
20572	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18499	\N	\N	\N
20573	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18665	6	\N	2014-09-28 17:27:35
20574	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18666	\N	\N	\N
20575	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18667	10	\N	\N
20576	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18668	\N	\N	\N
20736	VICPDT	2011-10-01 00:00:00	2014-04-24 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18718	6	\N	\N
20737	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18719	12	\N	\N
20738	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18884	\N	\N	2014-09-28 16:50:17
20739	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18885	\N	\N	\N
20740	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18886	\N	\N	\N
20741	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18887	1	\N	\N
20742	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18888	\N	\N	\N
20743	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18889	\N	\N	\N
20744	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18890	3	\N	\N
20745	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18891	\N	\N	\N
20746	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18892	\N	\N	\N
20747	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour le Mexique	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18893	2	\N	\N
20317	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18601	\N	\N	\N
20318	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18602	\N	\N	2014-09-28 12:09:44
20319	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18603	8	\N	\N
20320	MEMBRE	2011-10-01 00:00:00	2014-10-03 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18604	\N	\N	\N
20321	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18605	\N	\N	2014-09-28 19:03:23
20322	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18606	\N	\N	\N
20323	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18607	\N	\N	\N
20324	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18608	\N	\N	2014-09-28 17:31:42
20325	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18609	\N	\N	\N
20326	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18774	5	\N	\N
20327	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18775	10	\N	\N
20328	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18776	\N	\N	\N
20429	MEMBRE	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18976	\N	\N	2014-09-29 13:43:10
21858	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19864	\N	\N	\N
20430	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18977	23	\N	\N
20431	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19069	\N	\N	2014-09-28 19:07:43
20432	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19070	\N	\N	2014-09-28 17:31:42
20433	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19071	10	\N	\N
20434	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19072	\N	\N	\N
20435	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19073	\N	\N	\N
20436	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19074	3	\N	\N
20437	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19075	8	\N	\N
20438	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19076	\N	\N	\N
20123	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18105	\N	\N	\N
20124	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18106	\N	\N	\N
20125	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18107	9	\N	\N
20126	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18108	\N	\N	2014-09-28 13:21:47
20127	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18109	\N	\N	\N
20128	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour la Lettonie	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18357	3	\N	\N
20129	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18358	\N	\N	2014-09-28 17:09:16
18803	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17006	\N	\N	\N
18804	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17007	\N	\N	2014-09-28 17:52:18
19952	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18059	\N	\N	2014-09-28 16:50:17
19953	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18060	\N	\N	\N
19954	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18061	6	\N	2014-09-28 18:19:47
19955	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18062	\N	\N	2014-09-28 17:09:16
19956	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18063	\N	\N	2014-09-28 13:39:21
19957	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18064	\N	\N	\N
19958	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18065	\N	\N	\N
19959	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18224	15	\N	2014-09-28 16:42:05
19960	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18225	\N	\N	\N
19961	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18226	\N	\N	\N
19962	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18227	9	\N	\N
18136	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16340	\N	\N	\N
18160	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16364	\N	\N	\N
18161	MEMBRE	2011-10-01 00:00:00	2012-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	16365	\N	\N	\N
18894	MEMBRE	2011-10-01 00:00:00	2013-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	17097	\N	\N	\N
18897	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17100	\N	\N	2014-09-28 16:50:17
18936	PDT	2012-01-26 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	13599	\N	\N	\N
18937	VICPDT	2012-01-26 00:00:00	2013-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	13581	\N	\N	\N
18938	VICPDT	2012-01-26 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13577	\N	\N	\N
18947	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17141	\N	\N	2014-09-28 17:38:26
18948	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17142	\N	\N	2014-09-28 12:39:09
18949	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17143	\N	\N	\N
18950	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17144	\N	\N	\N
19001	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17186	\N	\N	2014-09-29 09:05:47
19014	MEMBRE	2011-10-01 00:00:00	2012-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	17199	\N	\N	\N
19015	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17200	\N	\N	\N
19026	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17211	\N	\N	2014-09-28 13:39:21
19038	MEMBRE	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17223	\N	\N	\N
19039	MEMBRE	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17224	\N	\N	\N
19040	MEMBRE	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17225	\N	\N	\N
19041	MEMBRE	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17226	\N	\N	2014-09-28 14:31:42
19042	MEMBRE	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17227	\N	\N	\N
19043	MEMBRE	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17228	\N	\N	\N
19044	MEMBRE	2012-01-25 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	17229	\N	\N	\N
19045	MEMBRE	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17230	\N	\N	\N
19071	MEMBRE	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17256	\N	\N	\N
19089	MEMBRE	2011-10-01 00:00:00	2012-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	17274	\N	\N	\N
20130	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18359	\N	\N	\N
20131	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18360	\N	\N	2014-09-28 17:09:16
20132	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18361	\N	\N	2014-09-28 16:50:17
18723	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16926	\N	\N	\N
19963	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18228	22	\N	\N
19964	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour la Malaisie	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18229	3	\N	2014-09-28 13:21:47
19965	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18230	15	\N	2014-09-28 16:50:17
19966	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18231	\N	\N	2014-09-28 13:39:21
19967	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18313	\N	\N	\N
19968	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18314	5	\N	\N
19969	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18315	\N	\N	\N
19970	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18316	6	\N	\N
19971	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18317	12	\N	2014-09-28 18:03:38
19972	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18318	6	\N	2014-09-28 13:16:32
19973	VICPDT	2011-10-01 00:00:00	2014-10-05 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18319	8	\N	2014-09-28 13:39:21
20133	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18362	7	\N	2014-09-28 13:16:32
20134	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18363	12	\N	2014-09-28 13:39:21
20135	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18364	6	\N	\N
20136	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18365	\N	\N	\N
20137	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18366	1	\N	\N
20138	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18367	5	\N	\N
20139	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17934	\N	\N	2014-09-28 17:27:35
20140	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17935	\N	\N	\N
20141	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17936	\N	\N	\N
20142	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17937	\N	\N	\N
20143	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17938	\N	\N	\N
20144	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17939	\N	\N	\N
19974	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18320	10	\N	\N
19975	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18321	\N	\N	\N
19976	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18322	\N	\N	\N
19977	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18323	\N	\N	2014-09-28 17:27:35
19978	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17890	2	\N	\N
19979	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17891	\N	\N	\N
19980	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17892	4	\N	\N
19981	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17893	5	\N	\N
19982	VICPDT	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17894	5	\N	\N
19983	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17895	8	\N	\N
19984	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17896	\N	\N	2014-09-28 17:09:16
19985	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17897	\N	\N	\N
18790	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16993	\N	\N	2014-09-28 13:09:05
19013	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17198	\N	\N	2014-09-28 16:40:50
20145	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17940	\N	\N	\N
20146	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17941	\N	\N	\N
20147	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17942	\N	\N	\N
20148	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17943	\N	\N	\N
20149	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17944	\N	\N	\N
20150	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18110	1	\N	2014-09-28 16:40:50
20151	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18111	\N	\N	\N
20152	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18112	\N	\N	\N
20153	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18113	\N	\N	\N
20154	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18114	3	\N	2014-09-28 17:27:35
20155	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18115	4	\N	\N
18159	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16363	\N	\N	\N
18227	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16431	\N	\N	\N
18318	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16522	\N	\N	2014-09-28 17:27:35
18379	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16582	\N	\N	\N
18615	MEMBRE	2011-10-01 00:00:00	2014-04-24 00:00:00	ANCIEN	\N	\N	\N	\N	16818	\N	\N	\N
18621	MEMBRE	2011-10-01 00:00:00	2012-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	16824	\N	\N	\N
18622	MEMBRE	2011-10-01 00:00:00	2012-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	16825	\N	\N	\N
18623	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16826	\N	\N	\N
18624	MEMBRE	2011-10-01 00:00:00	2012-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	16827	\N	\N	\N
18625	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16828	\N	\N	\N
18789	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16992	\N	\N	\N
18793	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16996	\N	\N	\N
18796	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16999	\N	\N	\N
18798	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17001	\N	\N	\N
18799	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17002	\N	\N	\N
18807	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17010	\N	\N	\N
18808	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17011	\N	\N	2014-09-28 19:03:04
19986	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17898	\N	\N	2014-09-28 17:27:35
19987	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17899	3	\N	\N
19988	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17900	6	\N	\N
19989	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18066	\N	\N	\N
19990	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18067	\N	\N	2014-09-28 17:27:35
19991	MEMBRE	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18068	\N	\N	2014-09-29 13:43:10
20156	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18116	\N	\N	\N
20157	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18117	\N	\N	\N
20158	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18118	\N	\N	\N
20159	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18119	\N	\N	\N
20160	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18120	7	\N	2014-09-28 17:07:07
20161	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18368	\N	\N	\N
20162	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18369	9	\N	\N
20163	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18370	\N	\N	\N
20164	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18371	\N	\N	2014-09-28 17:27:35
20165	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18372	3	\N	2014-09-28 17:27:35
20166	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18373	8	\N	2014-09-28 17:27:35
20167	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18374	\N	\N	\N
19992	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18069	\N	\N	\N
19993	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18070	\N	\N	\N
19994	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18071	\N	\N	\N
19995	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18072	\N	\N	\N
19996	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18073	11	\N	\N
19997	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18074	17	\N	\N
19998	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18075	20	\N	\N
19999	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18076	8	\N	\N
20000	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18232	\N	\N	\N
20001	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18233	1	\N	\N
20002	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour les Philippines	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18234	4	\N	\N
20003	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18235	\N	\N	\N
20168	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18375	\N	\N	\N
20169	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18376	\N	\N	2014-09-28 19:03:04
20170	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18377	\N	\N	\N
20171	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18378	7	\N	\N
20172	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17945	1	\N	\N
20173	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17946	\N	\N	\N
20174	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17947	\N	\N	\N
20175	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17948	\N	\N	\N
20176	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17949	\N	\N	\N
20177	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17950	\N	\N	2014-09-28 17:03:42
20178	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17951	\N	\N	\N
20179	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17952	\N	\N	\N
18713	MEMBRE	2011-10-01 00:00:00	2012-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	16916	\N	\N	\N
20004	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18236	\N	\N	2014-09-28 17:27:35
20005	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18237	9	\N	\N
20006	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18238	10	\N	\N
20007	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18239	\N	\N	2014-09-28 16:50:17
20008	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour Singapour	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18240	5	\N	\N
20009	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18241	\N	\N	\N
20010	PDTDEL	2011-10-01 00:00:00	2012-09-30 00:00:00	ANCIEN	\N	\N	pour la Malaisie	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18242	2	\N	\N
20011	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18324	\N	\N	2014-09-28 17:27:35
20012	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18325	\N	\N	2014-09-28 17:38:26
20013	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18326	3	\N	2014-09-28 18:00:58
20014	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18327	11	\N	2014-09-28 16:50:17
18233	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16437	\N	\N	\N
18905	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17108	\N	\N	\N
18447	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16650	\N	\N	\N
18906	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17109	\N	\N	2014-09-28 16:42:05
18449	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16652	\N	\N	\N
20180	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17953	\N	\N	\N
18459	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16662	\N	\N	\N
18461	MEMBRE	2011-10-01 00:00:00	2012-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	16664	\N	\N	\N
18462	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16665	\N	\N	\N
20181	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17954	3	\N	2014-09-28 12:09:44
20182	MEMBRE	2011-10-01 00:00:00	2014-10-03 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17955	\N	\N	\N
20183	MEMBRE	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18121	\N	\N	\N
20184	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18122	\N	\N	\N
20185	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18123	2	\N	2014-09-28 17:31:42
22233	MEMBRE	2013-04-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20181	\N	2013-05-31 10:48:25	\N
20186	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18124	6	\N	\N
20187	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18125	5	\N	\N
20188	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18126	2	\N	2014-09-28 17:55:39
20015	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18328	5	\N	\N
20016	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18329	\N	\N	2014-09-28 19:03:04
20017	PDTHON	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18330	2	\N	2014-09-28 18:00:58
20018	VICPDT	2011-10-01 00:00:00	2013-07-08 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18331	9	\N	2013-07-10 09:59:46
20019	VICPDTPRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18332	2	\N	\N
20020	PDT	2011-10-01 00:00:00	2013-07-08 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18333	1	\N	2013-07-10 09:58:25
20021	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18334	3	\N	2014-09-28 12:09:44
20022	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17901	\N	\N	\N
20023	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17902	\N	\N	\N
20024	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17903	\N	\N	\N
20025	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17904	\N	\N	2014-09-28 13:19:48
20026	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17905	1	\N	\N
20189	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18127	\N	\N	\N
20190	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18128	\N	\N	2014-09-28 17:31:42
20191	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18129	13	\N	\N
20192	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18130	10	\N	\N
20193	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18131	\N	\N	\N
20194	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18379	\N	\N	\N
20195	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18380	\N	\N	\N
20196	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18381	4	\N	\N
20197	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18382	8	\N	\N
20198	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18383	\N	\N	\N
20199	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18384	\N	\N	\N
20200	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18385	13	\N	\N
20027	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17906	\N	\N	\N
20028	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17907	\N	\N	\N
20029	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17908	\N	\N	2014-09-28 17:22:11
20030	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17909	4	\N	\N
20031	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17910	1	\N	\N
20032	PDTHON	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17911	2	\N	\N
20033	MEMBRE	2011-10-01 00:00:00	2012-07-18 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18077	\N	\N	\N
20034	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18078	10	\N	\N
20035	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18079	5	\N	\N
20036	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18080	12	\N	\N
20037	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18081	15	\N	\N
20038	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18082	13	\N	2014-09-28 17:22:11
19860	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18488	5	\N	2014-09-28 17:22:11
19861	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18033	\N	\N	\N
19862	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18034	\N	\N	\N
19863	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18035	\N	\N	\N
19864	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18036	9	\N	\N
19865	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18037	\N	\N	2014-09-28 13:21:47
19866	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18038	\N	\N	\N
19867	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18039	1	\N	\N
19868	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18040	\N	\N	2014-09-28 17:27:35
19869	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18041	4	\N	\N
19870	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18042	6	\N	\N
19871	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18043	\N	\N	\N
18899	MEMBRE	2011-10-01 00:00:00	2012-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	17102	\N	\N	\N
21812	MEMBRE	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19838	\N	\N	2014-09-28 17:27:29
18840	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17043	\N	\N	2014-09-28 18:03:38
18901	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17104	\N	\N	2014-09-28 18:58:25
18902	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17105	\N	\N	\N
18904	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17107	\N	\N	2014-09-28 17:03:42
18951	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17145	\N	\N	\N
18996	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17181	\N	\N	\N
20039	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18083	\N	\N	\N
20040	MEMBRE	2011-10-01 00:00:00	2013-12-31 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18084	\N	\N	\N
20041	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18085	\N	\N	\N
20042	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18086	4	\N	\N
20043	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18087	14	\N	\N
20044	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18243	12	\N	\N
20045	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18244	\N	\N	\N
20046	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour la Thaïlande	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18245	6	\N	\N
20047	MEMBRE	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18246	\N	\N	2014-09-29 13:41:53
19093	MEMBRE	2011-10-01 00:00:00	2012-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	17278	\N	\N	\N
19094	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17279	\N	\N	\N
19095	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17280	\N	\N	\N
19096	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17281	\N	\N	2014-09-28 14:31:42
19098	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17283	\N	\N	\N
19872	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18203	14	\N	\N
19873	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18204	7	\N	2014-09-28 16:50:17
19874	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18205	17	\N	2014-09-28 12:21:28
19875	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18206	2	\N	2014-09-28 17:38:26
19876	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18207	19	\N	\N
19877	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18208	1	\N	2014-09-28 18:00:58
19878	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18209	23	\N	\N
19879	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18210	\N	\N	\N
19880	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18211	\N	\N	\N
19881	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18212	\N	\N	\N
20048	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18247	\N	\N	2014-09-28 17:12:41
20049	MEMBRE	2011-10-01 00:00:00	2014-10-03 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18248	\N	\N	\N
20050	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour le Bangladesh	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18249	8	\N	2014-09-28 17:38:26
20051	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour la Birmanie	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18250	7	\N	\N
20052	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18335	\N	\N	\N
18881	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17084	\N	\N	\N
20053	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18336	\N	\N	\N
20054	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18337	1	\N	\N
20055	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18338	5	\N	\N
20056	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18339	\N	\N	\N
20057	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18340	\N	\N	\N
20058	MEMBRE	2011-10-01 00:00:00	2014-05-11 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18341	\N	\N	\N
20059	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18342	\N	\N	\N
19882	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18291	6	\N	2014-09-28 17:27:35
19883	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18292	3	\N	\N
19884	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18293	\N	\N	\N
19885	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18294	4	\N	2014-09-28 18:00:58
19886	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18295	\N	\N	\N
19887	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18296	8	\N	2014-09-28 17:22:11
19888	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18297	\N	\N	2014-09-28 17:34:16
19889	PDTHON	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18298	2	\N	\N
19890	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18299	5	\N	\N
19891	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18300	9	\N	\N
19892	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18301	\N	\N	\N
19893	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18467	\N	\N	2014-09-28 17:27:35
20060	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18343	2	\N	\N
20061	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18344	\N	\N	\N
20062	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18345	\N	\N	\N
20063	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17912	\N	\N	\N
20064	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17913	\N	\N	\N
22241	MEMBRE	2013-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20187	\N	2013-07-17 17:48:36	2014-09-28 17:22:11
22242	PDT	2013-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20188	1	2013-07-17 17:50:55	2014-09-28 17:22:11
22236	MEMBRE	2013-06-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20184	\N	2013-06-12 15:22:40	\N
22240	MEMBRE	2013-07-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20186	\N	\N	2013-08-12 17:04:33
22237	MEMBRE	2013-06-01 00:00:00	2014-05-11 00:00:00	ANCIEN	\N	\N	\N	\N	20185	\N	2013-06-14 09:50:50	\N
22244	MEMBRE	2013-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20191	\N	2013-08-12 16:45:51	2014-09-28 17:58:05
22245	MEMBRE	2013-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20192	\N	2013-08-12 16:57:19	2013-08-12 16:57:36
22246	MEMBRE	2013-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20193	\N	2013-08-12 16:59:24	\N
22248	MEMBRE	2013-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20195	\N	2013-08-12 17:01:58	2014-09-28 17:14:21
22249	MEMBRE	2013-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20196	\N	2013-08-12 17:02:47	2014-09-28 17:14:21
22253	MEMBRE	2013-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20200	\N	2013-08-12 17:17:07	\N
22251	MEMBRE	2013-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20198	\N	2013-08-12 17:07:14	\N
22252	MEMBRE	2013-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20199	\N	2013-08-12 17:08:02	\N
22255	MEMBRE	2013-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20203	\N	2013-09-18 14:55:40	2014-09-28 17:14:21
22238	VICPDT	2013-07-09 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	18333	9	2013-07-10 09:58:25	2013-07-10 10:00:31
22239	PDT	2013-07-09 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	18331	1	2013-07-10 09:59:46	\N
21443	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19194	1	\N	\N
21444	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19195	12	\N	\N
20896	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18768	7	\N	2014-09-28 16:50:17
20897	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18769	\N	\N	\N
20898	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18770	\N	\N	2014-09-28 18:00:58
20899	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18771	\N	\N	2014-09-28 17:52:18
20900	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18772	\N	\N	2014-09-28 17:27:35
20901	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18773	15	\N	\N
20902	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18939	5	\N	\N
20903	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18940	\N	\N	\N
20904	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18941	\N	\N	\N
20905	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18942	9	\N	\N
20906	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18943	\N	\N	2014-09-28 12:56:42
20907	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18944	\N	\N	\N
21076	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19613	8	\N	2014-09-28 17:27:35
21077	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19614	3	\N	2014-09-28 17:27:35
21078	MEMBRE	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19615	\N	\N	2014-09-29 13:43:10
21079	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19616	\N	\N	\N
21080	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19617	14	\N	\N
21081	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19618	\N	\N	\N
21082	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19267	13	\N	\N
21083	VICPDT	2011-10-01 00:00:00	2014-10-03 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19268	9	\N	\N
21084	MEMBRE	2011-10-01 00:00:00	2012-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19269	\N	\N	\N
21085	VICPDTPRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19270	6	\N	\N
21086	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19271	\N	\N	\N
21087	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19272	12	\N	\N
21254	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19131	\N	\N	\N
21255	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19132	8	\N	2014-09-28 13:40:33
21256	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19133	\N	\N	2014-09-28 16:50:17
21257	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19134	\N	\N	2014-09-28 12:21:28
21258	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19311	10	\N	\N
21259	SECRET	2011-10-01 00:00:00	2014-10-03 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19312	13	\N	2014-11-27 10:15:39
21260	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19313	8	\N	\N
21544	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19703	\N	\N	\N
21262	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour l'Uruguay	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19315	5	\N	2014-09-28 18:58:25
21263	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19316	\N	\N	\N
21264	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19317	14	\N	\N
21265	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19318	\N	\N	\N
21539	VICPDT	2012-02-07 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17278	\N	\N	\N
21545	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19704	\N	\N	2014-09-28 18:19:47
21445	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19196	\N	\N	\N
21446	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19197	9	\N	\N
21447	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19198	\N	\N	2014-09-28 16:42:05
21448	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19199	7	\N	\N
21449	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19200	11	\N	\N
21450	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19366	15	\N	2014-09-28 16:40:50
21451	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19367	2	\N	\N
21452	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19368	8	\N	\N
21453	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19369	\N	\N	2014-09-28 17:27:35
21454	MEMBRE	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19370	\N	\N	2014-09-29 13:43:10
21455	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour le Nigéria	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19371	16	\N	\N
21229	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19480	\N	\N	2014-09-28 16:59:41
21400	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour la Mauritanie	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19525	12	\N	\N
21401	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19526	\N	\N	\N
21402	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19527	\N	\N	\N
21403	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19528	3	\N	\N
21404	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19529	7	\N	2014-09-28 16:59:41
21405	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19530	6	\N	2014-09-28 17:40:23
21406	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour la Zambie	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19168	3	\N	2014-09-28 17:27:35
21407	MEMBRE	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19169	\N	\N	2014-09-29 13:43:10
21408	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19170	8	\N	\N
21409	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19171	\N	\N	2014-09-28 17:27:35
21410	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19172	6	\N	\N
21411	PDTHON	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19173	2	\N	2014-09-28 18:00:58
20872	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18931	\N	\N	2014-09-28 16:59:41
20873	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18932	\N	\N	\N
20874	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18933	\N	\N	2014-09-28 16:40:50
20875	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18934	11	\N	\N
20876	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18935	\N	\N	\N
20877	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18936	\N	\N	\N
20878	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18937	\N	\N	\N
20879	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18938	\N	\N	\N
20880	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18588	\N	\N	\N
20881	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18589	\N	\N	\N
20882	MEMBRE	2011-10-01 00:00:00	2014-10-03 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18590	\N	\N	\N
20883	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18591	\N	\N	2014-09-28 19:03:23
21052	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19259	10	\N	2014-09-28 16:50:17
21053	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour le Paraguay	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19260	4	\N	2014-09-28 17:38:26
21054	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19261	15	\N	\N
21055	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19262	\N	\N	\N
21056	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour l'Argentine	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19263	2	\N	2014-09-28 19:03:04
21057	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19264	\N	\N	\N
21058	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19265	\N	\N	\N
21059	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19266	\N	\N	2014-09-28 12:09:44
21060	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19432	5	\N	\N
21061	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19433	\N	\N	2014-09-28 16:50:17
21062	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19434	4	\N	\N
21063	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19435	8	\N	\N
21230	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19481	\N	\N	2014-09-28 17:31:42
21231	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19482	\N	\N	2014-09-28 17:07:41
21232	MEMBRE	2011-10-01 00:00:00	2012-06-16 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19483	\N	\N	\N
21233	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19484	\N	\N	\N
21234	MEMBRE	2011-10-01 00:00:00	2014-05-11 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19485	\N	\N	\N
21235	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19486	11	\N	2014-09-28 17:31:42
21236	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19652	8	\N	\N
21237	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour la Bosnie-Herzégovine	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19653	2	\N	\N
21238	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19654	11	\N	\N
21239	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19655	7	\N	\N
21240	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19656	2	\N	2014-09-28 12:56:42
21241	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19657	6	\N	\N
18494	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16697	\N	\N	\N
18390	MEMBRE	2011-10-01 00:00:00	2012-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	16593	\N	\N	\N
18171	MEMBRE	2011-10-01 00:00:00	2012-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	16375	\N	\N	\N
18241	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16445	\N	\N	\N
18174	MEMBRE	2011-10-01 00:00:00	2012-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	16378	\N	\N	\N
18175	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16379	\N	\N	\N
18391	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16594	\N	\N	2014-09-28 18:58:25
18582	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16785	\N	\N	\N
18612	MEMBRE	2011-10-01 00:00:00	2012-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	16815	\N	\N	\N
18830	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17033	\N	\N	\N
18832	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17035	\N	\N	2014-09-28 13:19:48
19352	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17335	\N	\N	\N
18835	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17038	\N	\N	\N
18836	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17039	\N	\N	\N
18837	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17040	\N	\N	\N
18838	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17041	\N	\N	\N
18953	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17147	\N	\N	\N
19353	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17336	\N	\N	2014-09-28 13:40:33
19354	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17337	14	\N	\N
19355	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17338	12	\N	2014-09-28 12:09:44
19356	MEMBRE	2011-10-01 00:00:00	2014-10-03 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17339	\N	\N	\N
19534	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17393	\N	\N	\N
19535	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17394	1	\N	\N
19536	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17395	13	\N	\N
19537	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17396	14	\N	\N
19538	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17397	\N	\N	2014-09-28 13:21:47
19539	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17398	12	\N	2014-09-28 17:07:41
19540	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17587	15	\N	\N
19541	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17588	\N	\N	2014-09-28 12:09:44
19542	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17589	20	\N	\N
19543	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17590	16	\N	\N
19544	MEMBRE	2011-10-01 00:00:00	2014-10-03 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17591	\N	\N	\N
19545	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17592	5	\N	2014-09-28 12:32:23
19702	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18431	\N	\N	\N
19703	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18432	13	\N	\N
19704	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18433	\N	\N	2014-09-28 16:50:17
19705	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17989	\N	\N	\N
19706	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17990	\N	\N	2014-09-28 17:27:35
19707	VICPDT	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17991	5	\N	2014-09-29 13:43:10
19708	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17992	3	\N	\N
19709	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17993	6	\N	\N
19710	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17994	\N	\N	\N
19711	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17995	\N	\N	2014-09-28 19:03:04
19712	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17996	\N	\N	\N
19713	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17997	5	\N	\N
19176	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17826	15	\N	\N
19177	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17827	\N	\N	\N
19178	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17828	7	\N	\N
19179	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17829	10	\N	\N
19180	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17830	\N	\N	\N
19181	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17831	\N	\N	\N
19182	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17832	\N	\N	\N
19183	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17833	\N	\N	\N
19184	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17834	12	\N	\N
19185	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17447	8	\N	\N
19186	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17448	\N	\N	\N
19187	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17449	\N	\N	\N
19357	MEMBRE	2011-10-01 00:00:00	2013-02-06 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17340	\N	\N	\N
19358	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour le Guyana	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17341	3	\N	2014-09-29 09:05:47
19359	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour le Suriname	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17342	4	\N	\N
21456	MEMBRE	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19372	\N	\N	\N
18794	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16997	\N	\N	2014-09-28 14:31:42
18795	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16998	\N	\N	2014-09-28 13:39:21
18805	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17008	\N	\N	\N
20908	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18945	\N	\N	\N
20909	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18946	\N	\N	\N
20910	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18947	1	\N	\N
20911	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18948	26	\N	2014-09-28 17:22:11
20912	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18949	\N	\N	\N
20913	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19032	15	\N	2014-09-28 17:27:35
20914	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19033	\N	\N	\N
20915	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19034	\N	\N	2014-09-28 12:44:31
20916	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19035	\N	\N	\N
20917	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19223	\N	\N	\N
20918	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19224	\N	\N	\N
21088	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19273	\N	\N	\N
21089	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19274	\N	\N	2014-09-28 12:09:44
21090	MEMBRE	2011-10-01 00:00:00	2014-10-03 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19275	\N	\N	\N
21091	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19276	13	\N	\N
21092	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19277	\N	\N	\N
21093	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19443	\N	\N	\N
21094	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour la Guinée-Bissau	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19444	3	\N	\N
21095	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19445	\N	\N	\N
21096	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19446	\N	\N	\N
21097	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19447	\N	\N	\N
21098	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19448	\N	\N	\N
21099	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19449	\N	\N	\N
21266	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19319	\N	\N	\N
21267	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19320	\N	\N	\N
21268	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19321	\N	\N	\N
21269	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19487	\N	\N	\N
21270	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19488	\N	\N	\N
21271	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19489	\N	\N	2014-09-28 19:03:23
21272	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19490	18	\N	\N
21273	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19491	\N	\N	\N
21274	PDTDEL	2011-10-01 00:00:00	2012-06-16 00:00:00	ANCIEN	\N	\N	pour le Libéria	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19492	13	\N	\N
21275	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour le Sénégal	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19493	8	\N	\N
21276	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19494	\N	\N	\N
21277	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19495	\N	\N	2014-09-28 12:44:31
21457	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19373	\N	\N	2014-09-28 18:03:38
21458	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19374	28	\N	2014-09-28 16:40:50
21459	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour le Cap Vert	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19375	2	\N	\N
21460	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19376	\N	\N	2014-09-28 16:50:17
21461	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19542	\N	\N	\N
21462	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19543	\N	\N	\N
21463	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19544	\N	\N	\N
21464	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19545	11	\N	\N
21465	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19546	7	\N	\N
21466	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19547	\N	\N	\N
21467	MEMBRE	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19548	\N	\N	2014-09-29 13:41:53
21468	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19549	2	\N	\N
18769	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16972	\N	\N	2014-09-28 16:59:41
18771	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16974	\N	\N	\N
18749	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16952	\N	\N	\N
18845	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17048	\N	\N	\N
18863	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17066	\N	\N	\N
18871	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17074	\N	\N	\N
21412	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19174	2	\N	2014-09-28 17:27:35
21413	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19175	4	\N	\N
21414	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19176	\N	\N	\N
21415	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19177	5	\N	2014-09-28 17:07:07
21416	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour le Zimbabwe	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19178	2	\N	\N
21417	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19355	\N	\N	2014-09-28 17:03:42
21418	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19356	\N	\N	2014-09-28 13:21:47
21419	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19357	\N	\N	\N
21420	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19358	11	\N	2014-09-28 13:21:47
18715	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16918	\N	\N	\N
18716	MEMBRE	2011-10-01 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	16919	\N	\N	\N
18734	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16937	\N	\N	\N
18735	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16938	\N	\N	\N
18736	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16939	\N	\N	2014-09-28 17:05:42
18737	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16940	\N	\N	\N
18738	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16941	\N	\N	2014-09-28 17:55:39
18739	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16942	\N	\N	2014-09-28 17:09:16
18825	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17028	\N	\N	\N
18870	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17073	\N	\N	2014-09-28 17:35:38
19748	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18175	5	\N	\N
19749	VICPDT	2011-10-01 00:00:00	2014-10-03 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18176	6	\N	\N
19750	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18177	\N	\N	2014-09-28 19:03:23
19751	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18178	\N	\N	\N
19752	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18179	\N	\N	\N
19753	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18180	\N	\N	2014-09-28 17:31:42
19754	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18181	\N	\N	\N
19755	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18182	\N	\N	\N
19212	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17844	\N	\N	2014-09-28 17:27:35
19213	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17845	\N	\N	\N
19214	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17454	\N	\N	\N
19215	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17455	1	\N	\N
19216	MEMBRE	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17456	\N	\N	2014-09-29 13:41:53
19217	MEMBRE	2011-10-01 00:00:00	2012-06-16 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17457	\N	\N	\N
19218	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour le Luxembourg	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17458	2	\N	2014-09-28 17:07:41
19219	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17459	\N	\N	\N
19220	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17460	\N	\N	\N
19221	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17461	3	\N	\N
19222	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17462	\N	\N	2014-09-28 16:59:41
19223	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17664	\N	\N	2014-09-28 18:00:58
19393	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17345	\N	\N	\N
19394	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17346	\N	\N	\N
19395	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17347	\N	\N	2014-09-28 16:42:05
19396	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17348	\N	\N	\N
19397	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17349	\N	\N	\N
19398	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17350	\N	\N	\N
19399	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17351	10	\N	\N
19400	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17352	5	\N	\N
19401	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17353	\N	\N	\N
19402	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17354	\N	\N	\N
19403	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17504	\N	\N	\N
19404	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17505	\N	\N	\N
19573	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17598	\N	\N	\N
19574	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17599	\N	\N	\N
19575	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17600	\N	\N	\N
22235	MEMBRE	2013-06-12 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20183	\N	\N	\N
20439	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19077	\N	\N	2014-09-28 17:00:59
20440	VICPDT	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19078	6	\N	\N
19030	MEMBRE	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17215	\N	\N	2014-09-28 17:52:18
19032	MEMBRE	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17217	\N	\N	2014-09-28 19:03:04
19031	MEMBRE	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17216	\N	\N	2014-09-28 17:27:35
19033	MEMBRE	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17218	\N	\N	\N
20577	PDT	2011-10-01 00:00:00	2014-10-03 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18669	1	\N	2015-11-12 15:26:22
20578	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18670	\N	\N	2014-09-28 13:39:21
20579	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18671	\N	\N	\N
20580	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18672	\N	\N	\N
20581	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18673	\N	\N	\N
20582	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18674	14	\N	\N
20583	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18675	\N	\N	2014-09-28 16:50:17
20584	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18840	11	\N	2014-09-28 16:59:41
20585	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour l'Arabie saoudite	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18841	2	\N	\N
20586	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18842	\N	\N	\N
20748	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18894	13	\N	\N
20749	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18544	\N	\N	\N
20750	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18545	\N	\N	\N
20751	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18546	\N	\N	\N
20752	MEMBRE	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18547	\N	\N	\N
20753	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18548	\N	\N	2014-09-28 13:16:32
20754	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18549	\N	\N	2014-09-28 12:56:42
20755	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18550	6	\N	2014-09-28 13:39:21
20756	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18551	11	\N	\N
20757	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18552	\N	\N	\N
20758	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18553	\N	\N	\N
20759	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18554	7	\N	2014-09-28 18:19:47
20329	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18777	8	\N	2014-09-28 17:07:41
20330	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18778	\N	\N	\N
20331	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18779	\N	\N	\N
20332	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18780	\N	\N	\N
20333	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18781	\N	\N	\N
20334	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18782	\N	\N	\N
20335	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18783	3	\N	2014-09-28 17:38:26
20336	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18784	\N	\N	\N
20337	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18950	21	\N	\N
20338	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18951	1	\N	2014-09-28 13:21:47
20339	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18952	5	\N	2014-09-28 17:27:35
20340	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18953	\N	\N	\N
20441	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19079	10	\N	\N
20442	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18632	\N	\N	2014-09-28 17:31:42
18882	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17085	\N	\N	\N
20443	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18633	\N	\N	\N
20444	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18634	7	\N	\N
20445	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18635	1	\N	2014-09-28 12:52:11
20446	VICPDT	2011-10-01 00:00:00	2012-09-19 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18636	6	\N	\N
20447	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18637	2	\N	\N
20448	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18638	\N	\N	\N
20449	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18639	\N	\N	\N
20450	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18640	11	\N	\N
20451	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18641	3	\N	\N
20452	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18642	\N	\N	2014-09-28 13:39:21
20919	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19225	1	\N	\N
20920	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19226	\N	\N	2014-09-28 17:03:42
20921	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19227	\N	\N	\N
20922	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19228	7	\N	\N
20923	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19229	\N	\N	\N
20924	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19230	\N	\N	\N
20925	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19231	9	\N	\N
20926	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19232	\N	\N	\N
20927	PDTDEL	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	pour le Congo Brazzaville	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19233	10	\N	\N
20928	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19388	\N	\N	\N
20929	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19389	\N	\N	\N
20930	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19390	12	\N	\N
18806	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17009	\N	\N	\N
21100	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19450	\N	\N	2014-09-28 12:09:44
21101	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19451	4	\N	\N
21102	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19452	\N	\N	\N
21103	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19453	\N	\N	\N
21104	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19619	\N	\N	\N
21105	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19620	5	\N	\N
21106	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19621	\N	\N	\N
21107	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19622	1	\N	2014-09-28 17:27:35
21108	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19623	\N	\N	\N
21109	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19624	\N	\N	\N
21110	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19625	\N	\N	2014-09-28 17:35:38
21278	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19496	1	\N	\N
21279	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19497	10	\N	\N
21280	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19663	\N	\N	\N
21281	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19664	\N	\N	\N
21282	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19665	\N	\N	\N
21283	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19666	\N	\N	2014-09-28 16:50:17
21284	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19667	\N	\N	2014-09-28 18:00:58
21285	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour le Monténégro	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19668	5	\N	\N
21286	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19669	9	\N	2014-09-28 17:03:42
21287	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19670	\N	\N	2014-09-28 17:22:11
21288	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19671	4	\N	\N
21289	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19672	\N	\N	\N
21469	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19550	6	\N	2014-09-28 13:40:33
21470	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19551	\N	\N	\N
21471	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19552	\N	\N	\N
21472	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19201	1	\N	\N
21473	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19202	4	\N	\N
21474	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19203	1	\N	\N
21475	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19204	15	\N	\N
21476	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19205	\N	\N	\N
21477	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19206	\N	\N	\N
21478	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19207	\N	\N	\N
21479	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19208	\N	\N	\N
21480	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19209	\N	\N	2014-09-28 18:03:38
20931	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19391	\N	\N	\N
20932	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19392	1	\N	2014-09-28 17:27:35
19576	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17601	\N	\N	\N
19577	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17602	\N	\N	\N
19578	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17603	\N	\N	2014-09-28 12:44:31
19579	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17604	\N	\N	\N
19580	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17605	9	\N	\N
19581	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17606	29	\N	\N
19582	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17607	\N	\N	\N
19583	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17608	\N	\N	\N
19584	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17769	10	\N	\N
19756	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18261	16	\N	\N
19757	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour le Brunei	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18262	2	\N	\N
19758	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18263	12	\N	2014-09-28 17:07:41
19759	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18264	\N	\N	\N
19760	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18265	2	\N	\N
19761	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18266	11	\N	\N
19762	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18267	1	\N	2014-09-28 17:40:23
19763	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18268	3	\N	2014-09-28 17:40:23
19764	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18445	6	\N	\N
19765	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18446	\N	\N	\N
19766	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18447	\N	\N	\N
19767	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18448	\N	\N	\N
18791	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16994	\N	\N	\N
18800	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17003	\N	\N	\N
18801	MEMBRE	2011-10-01 00:00:00	2014-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	17004	\N	\N	\N
18873	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17076	\N	\N	\N
18879	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17082	\N	\N	\N
19224	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17665	\N	\N	\N
19225	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17666	\N	\N	\N
19226	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17667	\N	\N	\N
19227	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17668	1	\N	\N
19228	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17669	3	\N	\N
19229	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17670	\N	\N	\N
19230	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17671	\N	\N	\N
19231	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17672	7	\N	\N
19232	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17673	\N	\N	\N
19405	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17506	\N	\N	2014-09-28 17:27:35
19406	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17507	\N	\N	2014-09-28 17:27:35
19407	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17508	\N	\N	\N
19408	MEMBRE	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17509	\N	\N	2014-09-29 13:43:10
19409	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17510	2	\N	\N
19410	MEMBRE	2011-10-01 00:00:00	2013-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17511	\N	\N	\N
19411	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17512	\N	\N	\N
19412	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17513	7	\N	\N
19413	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17543	9	\N	\N
19414	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17544	\N	\N	\N
19415	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17545	\N	\N	\N
19416	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17546	\N	\N	\N
19585	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17770	\N	\N	2014-09-28 16:59:41
19586	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17771	6	\N	\N
19587	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17772	4	\N	\N
19588	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17773	9	\N	\N
19589	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17774	\N	\N	\N
19360	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17343	9	\N	\N
19361	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17495	\N	\N	\N
19362	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17496	6	\N	\N
19363	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17497	\N	\N	\N
19364	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17498	\N	\N	2014-09-28 13:21:47
19365	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17499	10	\N	\N
19366	PDT	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17500	1	\N	\N
19367	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17501	\N	\N	2014-09-28 18:19:47
19368	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17502	\N	\N	2014-09-28 17:09:16
18325	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16529	\N	\N	2014-09-28 16:50:17
18327	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16531	\N	\N	2014-09-28 17:27:29
18331	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16535	\N	\N	\N
18332	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16536	\N	\N	\N
18385	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16588	\N	\N	\N
18434	MEMBRE	2011-10-01 00:00:00	2012-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	16637	\N	\N	\N
18435	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16638	\N	\N	\N
18436	MEMBRE	2011-10-01 00:00:00	2012-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	16639	\N	\N	\N
18463	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16666	\N	\N	2014-09-28 18:58:25
18464	MEMBRE	2011-10-01 00:00:00	2012-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	16667	\N	\N	\N
18722	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16925	\N	\N	2014-09-28 17:38:26
18466	MEMBRE	2011-10-01 00:00:00	2012-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	16669	\N	\N	\N
18467	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16670	\N	\N	\N
18468	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16671	\N	\N	2014-09-28 14:31:42
18727	MEMBRE	2011-10-01 00:00:00	2012-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	16930	\N	\N	\N
18471	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16674	\N	\N	\N
18747	MEMBRE	2011-10-01 00:00:00	2012-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	16950	\N	\N	\N
18474	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16677	\N	\N	\N
18748	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16951	\N	\N	2014-09-28 17:55:39
18476	MEMBRE	2011-10-01 00:00:00	2012-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	16679	\N	\N	\N
18486	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16689	\N	\N	\N
18487	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16690	\N	\N	\N
18768	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16971	\N	\N	2014-09-28 18:19:47
18772	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16975	\N	\N	\N
18773	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16976	\N	\N	2014-09-28 16:50:17
18774	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16977	\N	\N	\N
19546	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17593	\N	\N	\N
19547	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17594	\N	\N	2014-09-28 17:27:29
19548	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17595	\N	\N	2014-09-29 09:08:33
19714	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17998	\N	\N	\N
19715	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17999	7	\N	2014-09-28 13:09:05
19716	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18165	\N	\N	\N
19717	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18166	\N	\N	\N
19718	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18167	1	\N	\N
19719	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18168	\N	\N	\N
19720	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18169	10	\N	\N
19721	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18170	9	\N	2014-09-28 18:00:58
19722	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18171	\N	\N	2014-09-28 17:03:42
19723	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18172	8	\N	\N
19724	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18434	\N	\N	2014-09-28 17:03:42
19725	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18435	5	\N	2014-09-28 13:21:47
19188	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17450	3	\N	\N
19189	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17451	4	\N	\N
19190	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17452	\N	\N	\N
19191	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17453	5	\N	\N
19192	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17653	\N	\N	\N
19193	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17654	\N	\N	2014-09-28 19:03:23
19194	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17655	8	\N	2014-09-28 17:52:18
19195	MEMBRE	2011-10-01 00:00:00	2013-02-28 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17656	\N	\N	\N
19196	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17657	4	\N	\N
19197	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17658	\N	\N	\N
19198	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17659	\N	\N	2014-09-28 13:21:47
19199	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17660	\N	\N	\N
19369	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17503	\N	\N	2014-09-28 13:39:21
19370	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17532	\N	\N	\N
19371	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17533	\N	\N	\N
19372	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17534	5	\N	\N
19373	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17535	\N	\N	2014-09-28 16:59:41
20587	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18843	\N	\N	\N
20588	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18844	\N	\N	\N
21875	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	9981	\N	\N	2013-03-26 11:24:47
20589	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18845	\N	\N	\N
20590	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18846	\N	\N	\N
20591	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18847	\N	\N	\N
20592	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18848	11	\N	\N
20593	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour les Emirats Arabes Unis	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18849	4	\N	2014-09-28 18:19:47
20594	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18850	\N	\N	\N
20595	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19010	\N	\N	2014-09-28 17:00:59
20596	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19011	12	\N	\N
20597	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19012	9	\N	\N
20598	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19013	22	\N	2014-09-28 13:09:05
19007	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17192	\N	\N	2014-09-28 13:39:21
19008	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17193	\N	\N	2014-09-28 17:55:39
20760	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour l'Amérique centrale	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18720	3	\N	\N
20761	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18721	1	\N	\N
20762	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18722	\N	\N	\N
20763	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18723	2	\N	\N
20764	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18724	5	\N	2014-09-28 17:07:41
20765	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18725	\N	\N	2014-09-28 17:09:16
20766	VICPDTDRT	2011-10-01 00:00:00	2014-10-05 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18726	2	\N	2014-09-28 13:39:21
20767	VICPDT	2011-10-01 00:00:00	2014-04-24 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18727	8	\N	\N
20768	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18728	\N	\N	\N
20769	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18729	\N	\N	\N
20770	VICPDTDRT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18730	4	\N	\N
20341	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18954	13	\N	\N
20342	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18955	\N	\N	\N
20343	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18956	17	\N	\N
20344	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18957	12	\N	\N
20345	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19047	\N	\N	\N
20346	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19048	1	\N	\N
20347	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19049	\N	\N	\N
20348	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19050	9	\N	2014-09-28 17:27:35
20349	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19051	\N	\N	2014-09-28 17:27:35
20350	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19052	7	\N	\N
20351	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19053	11	\N	\N
20352	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19054	16	\N	\N
20453	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18807	\N	\N	\N
20454	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18808	\N	\N	\N
20455	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18809	\N	\N	\N
20456	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18810	4	\N	2014-09-28 16:42:05
20457	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18811	\N	\N	\N
20458	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18812	17	\N	2014-09-28 17:52:18
21524	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19695	\N	\N	\N
20459	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18813	\N	\N	\N
20460	MEMBRE	2011-10-01 00:00:00	2014-10-03 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18814	\N	\N	2014-11-27 10:15:39
20461	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18815	11	\N	\N
20462	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18816	\N	\N	\N
20463	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18817	1	\N	\N
20464	MEMBRE	2011-10-01 00:00:00	2014-10-03 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18978	\N	\N	2015-11-12 15:26:22
20599	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19014	3	\N	\N
20600	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19015	6	\N	\N
20933	MEMBRE	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19393	\N	\N	2014-09-29 13:43:10
20934	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19394	\N	\N	\N
20935	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19395	\N	\N	\N
20936	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19396	\N	\N	2014-09-28 17:27:35
20937	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19397	\N	\N	\N
20938	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19398	31	\N	\N
20939	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19564	\N	\N	\N
20940	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19565	\N	\N	\N
20941	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19566	\N	\N	\N
20942	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19567	\N	\N	2014-09-28 18:00:58
21111	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19626	\N	\N	2014-09-28 16:40:50
21112	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19627	\N	\N	\N
21113	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19628	\N	\N	\N
21114	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19629	9	\N	2014-09-28 13:19:48
21115	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19102	9	\N	\N
21116	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19103	\N	\N	2014-09-28 18:19:47
21117	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19104	\N	\N	\N
21118	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19105	\N	\N	\N
21119	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19106	14	\N	\N
21120	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19107	\N	\N	2014-09-28 18:00:58
21121	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19108	4	\N	2014-09-28 17:27:35
21290	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19673	\N	\N	2014-09-28 13:40:33
21291	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19146	10	\N	\N
21292	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19147	4	\N	2014-09-28 17:27:35
21293	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19148	11	\N	\N
21294	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19149	2	\N	\N
21295	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19150	\N	\N	\N
21296	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19151	7	\N	2014-09-28 18:00:58
21297	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour la Géorgie	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19152	3	\N	\N
21298	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19153	\N	\N	2014-09-28 17:03:42
21299	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19154	10	\N	\N
21300	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19155	\N	\N	2014-09-28 17:27:35
21527	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19696	\N	\N	2014-09-28 14:31:42
21301	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19156	3	\N	2014-09-28 18:00:58
21481	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19210	\N	\N	\N
21482	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19211	3	\N	\N
21483	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19377	\N	\N	\N
21484	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19378	\N	\N	\N
21485	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19379	1	\N	\N
21486	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19380	\N	\N	\N
21487	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19381	19	\N	2014-09-28 18:19:47
21488	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour le Ghana	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19382	7	\N	2014-09-28 13:16:32
21489	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19383	\N	\N	2014-09-28 12:56:42
21490	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19384	\N	\N	2014-09-28 17:09:16
21491	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19385	\N	\N	\N
21492	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19386	\N	\N	\N
20943	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19568	8	\N	\N
20944	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19569	\N	\N	\N
20945	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19570	\N	\N	\N
20946	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19571	\N	\N	\N
20947	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19572	6	\N	\N
19590	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17775	1	\N	\N
19591	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17776	\N	\N	\N
19592	PDTHON	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17777	2	\N	\N
19593	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17778	\N	\N	\N
19594	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17779	1	\N	2014-09-28 16:59:41
19595	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17410	4	\N	\N
19596	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17411	6	\N	\N
19768	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18449	\N	\N	\N
19769	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18450	\N	\N	\N
19770	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18451	\N	\N	\N
19771	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18452	4	\N	2014-09-28 13:39:21
19772	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18453	\N	\N	\N
19773	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18454	9	\N	\N
19774	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18455	4	\N	\N
19775	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18011	13	\N	2014-09-28 13:39:21
19776	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18012	\N	\N	\N
19777	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18013	\N	\N	2014-09-28 17:27:35
19778	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18014	5	\N	\N
19779	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18015	\N	\N	\N
19233	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17674	4	\N	\N
19234	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17846	5	\N	\N
19235	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17847	3	\N	\N
19236	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17848	\N	\N	\N
21951	SECRET	2012-02-08 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19734	\N	\N	\N
19237	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17849	\N	\N	\N
19238	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17850	11	\N	2014-09-28 12:21:28
19239	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17851	8	\N	2014-09-28 18:00:58
19240	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17852	\N	\N	2014-09-28 17:52:18
19241	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17853	\N	\N	\N
19242	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17854	\N	\N	2014-09-28 17:22:11
19243	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17855	\N	\N	\N
19244	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17856	\N	\N	2014-09-28 17:03:42
18797	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17000	\N	\N	\N
19417	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17547	\N	\N	2014-09-28 16:40:50
19418	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17548	1	\N	2014-09-28 16:50:17
19419	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17549	4	\N	\N
19420	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17550	\N	\N	2014-09-28 13:16:32
19421	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17551	\N	\N	2014-09-28 12:56:42
19422	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17552	12	\N	2014-09-28 13:39:21
19423	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17553	19	\N	\N
19424	VICPDTDRT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17719	9	\N	\N
19425	VICPDTDRT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17720	7	\N	2014-09-28 18:19:47
19426	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17721	\N	\N	2014-09-28 12:56:42
19427	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17722	\N	\N	2014-09-28 17:27:35
19597	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17412	1	\N	\N
19598	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17413	\N	\N	\N
19599	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17414	15	\N	\N
19600	MEMBRE	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17415	\N	\N	2014-09-29 13:41:53
19601	MEMBRE	2011-10-01 00:00:00	2014-10-03 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17416	\N	\N	\N
19602	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17417	\N	\N	2014-09-28 17:00:59
19603	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17418	\N	\N	\N
19374	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17536	4	\N	\N
19375	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17537	8	\N	\N
19376	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17538	11	\N	\N
19377	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17539	\N	\N	\N
19378	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17540	\N	\N	\N
19379	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17541	6	\N	\N
19380	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17542	\N	\N	\N
19549	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17596	\N	\N	2014-09-29 09:05:47
19550	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17597	\N	\N	\N
19551	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17758	2	\N	\N
19552	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17759	\N	\N	\N
19553	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17760	\N	\N	\N
19554	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17761	\N	\N	\N
19555	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17762	\N	\N	\N
19556	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17763	\N	\N	2014-09-28 17:27:35
19557	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17764	8	\N	\N
19558	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17765	11	\N	\N
19559	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17766	12	\N	2014-09-28 19:07:43
19560	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17767	13	\N	\N
18718	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16921	\N	\N	\N
18719	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16922	\N	\N	\N
18728	MEMBRE	2011-10-01 00:00:00	2012-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	16931	\N	\N	\N
18744	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16947	\N	\N	\N
18827	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17030	\N	\N	\N
19726	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18436	11	\N	\N
19727	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18437	11	\N	\N
19728	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18438	1	\N	\N
19729	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18439	\N	\N	\N
19730	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18440	\N	\N	\N
19731	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18441	15	\N	2014-09-28 16:50:17
19732	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18442	3	\N	2014-09-28 17:03:42
19733	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18443	\N	\N	\N
19734	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18444	\N	\N	\N
19735	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18000	4	\N	\N
19200	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17661	\N	\N	2014-09-28 18:19:47
19201	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17662	5	\N	2014-09-28 13:39:21
19202	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17663	6	\N	\N
19203	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17835	\N	\N	\N
19204	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17836	\N	\N	\N
19205	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17837	\N	\N	2014-09-28 13:21:47
19206	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17838	4	\N	\N
19207	MEMBRE	2011-10-01 00:00:00	2013-06-27 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17839	\N	\N	\N
19208	MEMBRE	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17840	\N	\N	\N
19209	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17841	\N	\N	2014-09-28 13:16:32
19210	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17842	\N	\N	\N
19211	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17843	3	\N	\N
19381	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17708	8	\N	\N
19382	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour la Colombie	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17709	3	\N	2014-06-23 14:39:50
19383	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17710	18	\N	\N
19384	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17711	\N	\N	\N
19385	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17712	15	\N	\N
19386	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17713	25	\N	\N
19387	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17714	\N	\N	\N
20601	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19016	\N	\N	\N
20602	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19017	1	\N	\N
20603	MEMBRE	2011-10-01 00:00:00	2013-06-27 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19018	\N	\N	\N
20604	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19019	\N	\N	\N
20605	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19020	\N	\N	\N
20606	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18500	\N	\N	\N
20607	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18501	\N	\N	\N
20608	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18502	\N	\N	\N
20609	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18503	4	\N	\N
20610	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18504	\N	\N	\N
20771	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18895	\N	\N	2014-09-28 17:03:42
20772	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18896	\N	\N	\N
20773	VICPDT	2011-10-01 00:00:00	2014-10-03 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18897	9	\N	2015-11-12 15:26:22
20774	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18898	\N	\N	\N
20775	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18899	\N	\N	\N
20776	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18900	\N	\N	2014-09-28 12:09:44
20777	MEMBRE	2011-10-01 00:00:00	2014-10-03 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18901	\N	\N	\N
20778	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18902	\N	\N	\N
20779	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18903	1	\N	\N
20780	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18904	14	\N	\N
20781	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18905	8	\N	2014-09-28 13:40:33
20782	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18555	\N	\N	2014-09-28 13:16:32
18802	MEMBRE	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	17005	\N	\N	\N
20353	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19055	4	\N	\N
20354	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19056	5	\N	\N
20355	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19057	\N	\N	\N
20356	MEMBRE	2011-10-01 00:00:00	2013-02-28 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18610	\N	\N	\N
20357	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18611	\N	\N	\N
20358	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18612	12	\N	\N
20359	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18613	2	\N	2014-09-28 16:42:05
20360	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18614	5	\N	\N
20361	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18615	\N	\N	\N
20362	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18616	7	\N	\N
20363	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18617	12	\N	\N
20465	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18979	\N	\N	\N
20466	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18980	\N	\N	\N
20467	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18981	6	\N	\N
20468	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18982	2	\N	\N
20469	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18983	3	\N	2014-09-28 13:40:33
20470	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18984	5	\N	2014-09-28 17:27:35
20471	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18985	\N	\N	2014-09-28 17:07:41
20472	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18986	14	\N	2014-09-28 16:50:17
20473	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18987	13	\N	\N
20474	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18988	\N	\N	2014-09-28 16:59:41
20475	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19080	9	\N	\N
20476	MEMBRE	2011-10-01 00:00:00	2013-02-06 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19081	\N	\N	\N
20611	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18505	\N	\N	\N
20612	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18506	\N	\N	\N
20613	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18507	\N	\N	\N
20614	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18508	1	\N	\N
20948	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19573	10	\N	\N
20949	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19574	\N	\N	\N
20950	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19212	\N	\N	2014-09-28 18:19:47
20951	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19213	\N	\N	2014-09-28 12:56:42
20952	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19214	16	\N	2014-09-28 13:39:21
20953	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19215	\N	\N	\N
20954	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19216	5	\N	2014-09-28 17:27:35
21122	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19109	\N	\N	\N
21123	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19110	1	\N	\N
21124	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19111	5	\N	2014-09-28 13:39:21
21125	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19112	1	\N	\N
21126	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19278	12	\N	\N
21127	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19279	\N	\N	2014-09-28 17:05:42
21128	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19280	\N	\N	\N
21129	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19281	15	\N	\N
21130	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19282	\N	\N	2014-09-28 17:55:39
21131	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19283	1	\N	2014-09-28 16:42:05
21132	MEMBRE	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19284	\N	\N	2014-09-29 13:41:53
21133	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19285	\N	\N	\N
18491	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16694	\N	\N	2014-09-28 12:44:31
18493	MEMBRE	2011-10-01 00:00:00	2012-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	16696	\N	\N	\N
21302	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19322	\N	\N	\N
21303	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19323	\N	\N	\N
21304	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19324	9	\N	\N
21305	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19325	\N	\N	2014-09-28 18:19:47
21306	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19326	1	\N	2014-09-28 12:56:42
21307	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19327	\N	\N	2014-09-28 16:50:17
21308	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19328	\N	\N	\N
21309	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19329	14	\N	\N
21310	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19330	\N	\N	\N
21311	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour le Kirghizistan	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19331	3	\N	2014-09-28 13:39:21
21312	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19332	\N	\N	\N
20783	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18556	\N	\N	2014-09-28 12:56:42
20784	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18557	\N	\N	2014-09-28 13:39:21
20785	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18558	\N	\N	\N
20786	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18559	\N	\N	\N
20787	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18560	14	\N	\N
20788	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18561	7	\N	2014-09-28 17:27:35
20789	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18562	\N	\N	\N
20790	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18563	2	\N	\N
20791	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18564	10	\N	\N
20792	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18565	\N	\N	\N
20793	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18731	\N	\N	\N
20794	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18732	\N	\N	2014-09-28 17:07:41
20955	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19217	14	\N	\N
20956	PDTHON	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19218	2	\N	\N
20957	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19219	8	\N	\N
20958	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19220	1	\N	2014-09-28 13:39:21
20959	MEMBRE	2011-10-01 00:00:00	2014-04-24 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19221	\N	\N	\N
20960	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19222	\N	\N	\N
20961	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19399	7	\N	\N
19604	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17419	9	\N	2014-09-28 13:39:21
19605	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17420	7	\N	\N
19606	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17609	23	\N	\N
19607	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17610	\N	\N	2014-09-28 16:40:50
19608	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17611	\N	\N	2014-09-28 17:55:39
19780	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18016	14	\N	\N
19781	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18017	3	\N	\N
19782	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18018	11	\N	2014-09-28 18:00:58
19783	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18019	6	\N	\N
19784	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18020	\N	\N	\N
19785	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18021	1	\N	\N
19786	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18183	5	\N	2014-09-28 17:31:42
19787	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18184	\N	\N	\N
19788	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18185	\N	\N	\N
19789	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18186	\N	\N	\N
19790	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18187	8	\N	2014-09-28 13:21:47
19791	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18188	\N	\N	2014-09-28 12:52:11
19245	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17463	\N	\N	\N
19246	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17464	\N	\N	\N
19247	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17465	\N	\N	\N
19248	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17466	7	\N	\N
19249	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17467	\N	\N	\N
19250	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17468	\N	\N	\N
19251	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17469	\N	\N	2014-09-28 17:27:35
19252	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17470	\N	\N	\N
19253	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17471	\N	\N	\N
19254	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17472	1	\N	\N
19255	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17675	\N	\N	2014-09-28 13:21:47
19256	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17676	\N	\N	2014-09-28 18:03:38
19428	MEMBRE	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17723	\N	\N	2014-09-29 13:43:10
19429	VICPDTDRT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17724	10	\N	\N
19430	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17725	13	\N	\N
19431	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour l'Ethiopie	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17726	2	\N	\N
19432	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17727	14	\N	\N
19433	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17728	11	\N	\N
19434	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour le Soudan du Nord	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17729	4	\N	\N
19435	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17355	\N	\N	\N
19436	MEMBRE	2011-10-01 00:00:00	2014-05-11 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17356	\N	\N	\N
19437	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17357	\N	\N	\N
19438	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17358	\N	\N	\N
19439	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17359	\N	\N	\N
19609	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17612	7	\N	2014-09-28 16:42:05
19610	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17613	\N	\N	\N
19611	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17614	18	\N	\N
19612	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17615	\N	\N	2014-09-28 17:31:42
19613	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17616	25	\N	\N
19614	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17617	\N	\N	\N
19615	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17618	\N	\N	\N
19616	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17619	\N	\N	\N
19388	VICPDTDRT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17715	8	\N	\N
19389	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17716	\N	\N	\N
19390	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour l'Erythrée	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17717	3	\N	\N
19391	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17718	\N	\N	2014-09-28 18:03:38
19392	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17344	\N	\N	\N
19561	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17768	\N	\N	\N
19562	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17399	2	\N	\N
19563	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17400	\N	\N	2014-09-28 16:50:17
19564	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17401	\N	\N	\N
19565	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17402	\N	\N	\N
19566	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17403	\N	\N	\N
19567	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17404	13	\N	\N
19568	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17405	\N	\N	2014-09-28 17:27:35
19569	MEMBRE	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17406	\N	\N	2014-09-29 13:43:10
19570	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17407	11	\N	\N
19571	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17408	8	\N	\N
19572	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17409	\N	\N	\N
19736	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18001	\N	\N	2014-09-28 16:42:05
19737	MEMBRE	2011-10-01 00:00:00	2013-02-28 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18002	\N	\N	\N
19738	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18003	2	\N	\N
19739	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18004	\N	\N	2014-09-28 17:40:23
19740	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18005	\N	\N	\N
19741	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18006	4	\N	\N
19742	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18007	7	\N	2014-09-28 16:50:17
19743	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18008	\N	\N	\N
19744	PDTHON	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18009	2	\N	2014-09-28 13:16:32
19745	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18010	\N	\N	2014-09-28 17:09:16
19746	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18173	4	\N	2014-09-28 13:40:33
19747	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18174	3	\N	\N
22112	MEMBRE	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20082	\N	\N	\N
21809	VICPDT	2012-02-21 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17111	\N	\N	\N
21810	SECRET	2012-02-21 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17106	\N	\N	2014-09-28 16:59:41
21811	SECRET	2012-02-21 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17163	\N	\N	\N
21724	MEMBRE	2012-02-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19807	\N	\N	2014-09-28 17:52:18
21725	MEMBRE	2012-02-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19808	\N	\N	2014-09-28 12:44:31
21726	MEMBRE	2012-02-22 00:00:00	2012-09-02 00:00:00	ANCIEN	\N	\N	\N	\N	19809	\N	\N	\N
21727	MEMBRE	2012-02-22 00:00:00	2014-04-24 00:00:00	ANCIEN	\N	\N	\N	\N	19810	\N	\N	\N
21732	MEMBRE	2012-02-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19815	\N	\N	2014-09-28 16:50:17
21733	MEMBRE	2012-02-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19816	\N	\N	2014-09-28 14:31:42
21734	MEMBRE	2012-02-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19817	\N	\N	2014-09-28 18:03:38
21735	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19818	\N	\N	2014-09-28 17:09:16
22184	MEMBRE	2013-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20132	\N	\N	\N
21705	MEMBRE	2011-10-01 00:00:00	2012-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	19791	\N	\N	\N
21706	SECRET	2012-02-21 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19791	\N	\N	2014-09-28 17:03:42
22004	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19991	\N	\N	2014-09-28 13:32:35
21728	MEMBRE	2012-02-22 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19811	\N	\N	\N
21729	MEMBRE	2012-02-22 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19812	\N	\N	\N
21730	MEMBRE	2012-02-22 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19813	\N	\N	\N
21731	MEMBRE	2012-02-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19814	\N	\N	2014-09-28 13:39:21
22185	MEMBRE	2013-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20133	\N	\N	2014-09-28 17:03:42
21946	PDT	2012-02-08 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	19730	\N	\N	2014-09-29 13:41:53
21947	VICPDT	2012-02-08 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19728	\N	\N	\N
21948	PDTDEL	2011-10-01 00:00:00	2011-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19737	\N	\N	\N
21949	VICPDT	2012-02-08 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19731	\N	\N	\N
21950	VICPDT	2012-02-08 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19737	\N	\N	\N
22046	MEMBRE	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20031	\N	\N	\N
22160	MEMBRE	2013-01-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20108	\N	\N	\N
22186	MEMBRE	2013-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20134	\N	\N	\N
22014	MEMBRE	2012-10-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20000	\N	\N	\N
22015	MEMBRE	2012-10-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20001	\N	\N	\N
22016	MEMBRE	2012-10-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20002	\N	\N	\N
22017	MEMBRE	2012-10-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20003	\N	\N	2014-09-28 19:03:23
22034	MEMBRE	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20019	\N	\N	\N
22035	MEMBRE	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20020	\N	\N	\N
22036	MEMBRE	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20021	\N	\N	\N
22037	MEMBRE	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20022	\N	\N	\N
22038	MEMBRE	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20023	\N	\N	\N
22039	MEMBRE	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20024	\N	\N	\N
22040	MEMBRE	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20025	\N	\N	\N
22041	MEMBRE	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20026	\N	\N	\N
22042	MEMBRE	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20027	\N	\N	\N
22043	MEMBRE	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20028	\N	\N	\N
22044	MEMBRE	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20029	\N	\N	\N
22045	MEMBRE	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20030	\N	\N	\N
22188	MEMBRE	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20136	\N	2013-03-08 17:50:40	\N
21882	MEMBRE	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19885	\N	\N	\N
21586	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19723	\N	\N	2014-09-28 17:35:38
21911	MEMBRE	2012-06-28 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	19914	\N	\N	\N
21913	MEMBRE	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19916	\N	\N	\N
22148	VICPDT	2012-02-21 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19776	\N	\N	\N
22157	SECRET	2012-02-21 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16435	\N	\N	\N
22158	SECRET	2012-02-21 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16440	\N	\N	\N
21880	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19883	\N	\N	\N
21980	MEMBRE	2012-08-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19967	\N	\N	\N
21981	MEMBRE	2012-08-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19968	\N	\N	2014-10-14 16:12:12
21982	MEMBRE	2012-08-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19969	\N	\N	2014-10-14 16:36:00
21983	MEMBRE	2012-08-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19970	\N	\N	2014-10-14 16:35:17
22187	MEMBRE	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20135	\N	2013-03-07 16:15:41	\N
20615	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18509	\N	\N	\N
20616	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18510	\N	\N	\N
20617	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18676	\N	\N	\N
20633	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18856	\N	\N	\N
20618	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18677	\N	\N	2014-09-28 18:00:58
20619	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18678	13	\N	\N
20620	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18679	6	\N	\N
20621	MEMBRE	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18680	\N	\N	2014-09-29 13:41:53
20622	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18681	\N	\N	\N
20201	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18386	\N	\N	\N
20202	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18387	1	\N	\N
20203	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18388	2	\N	\N
20204	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18389	\N	\N	2014-09-28 18:00:58
20205	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17956	\N	\N	2014-09-28 17:07:07
20206	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17957	10	\N	2014-09-28 17:22:11
20207	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17958	\N	\N	\N
20208	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17959	\N	\N	2014-09-28 12:32:23
20209	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17960	\N	\N	2014-09-28 19:03:23
20210	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17961	\N	\N	2014-09-28 13:40:33
20211	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17962	11	\N	\N
20212	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17963	\N	\N	2014-09-28 16:59:41
20364	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour le Danemark	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18618	2	\N	\N
20365	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour l'Islande	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18619	3	\N	\N
20366	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18620	\N	\N	\N
20367	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18785	\N	\N	\N
20368	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18786	12	\N	\N
20369	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18787	\N	\N	2014-09-29 09:05:47
20370	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18788	\N	\N	\N
20371	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18789	\N	\N	2014-09-28 17:00:59
20372	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18790	\N	\N	\N
20373	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18791	\N	\N	\N
20374	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18792	9	\N	\N
20375	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18793	\N	\N	\N
20477	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19082	\N	\N	2014-09-28 16:42:05
20478	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19083	5	\N	\N
20479	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19084	\N	\N	\N
20480	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19085	\N	\N	\N
20481	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19086	6	\N	\N
20482	SECRET	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19087	23	\N	\N
20483	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19088	8	\N	\N
20484	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19089	7	\N	\N
20485	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19090	4	\N	2014-09-28 13:16:32
20486	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18643	\N	\N	\N
20487	SECRET	2011-10-01 00:00:00	2014-04-24 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18644	17	\N	\N
20488	PDTHON	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18645	2	\N	2014-09-29 13:43:10
20623	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18682	8	\N	\N
20624	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18683	\N	\N	\N
20625	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18684	8	\N	\N
20626	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18685	\N	\N	2014-09-28 17:27:35
20962	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19400	\N	\N	\N
20963	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19401	8	\N	2014-09-28 17:27:35
20964	PDTHON	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19402	2	\N	2014-09-29 13:43:10
20965	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19403	\N	\N	\N
20966	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19404	\N	\N	\N
21134	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19286	\N	\N	2014-09-28 12:09:44
21135	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19287	\N	\N	\N
21136	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19288	\N	\N	\N
21137	MEMBRE	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19454	\N	\N	2014-09-29 13:41:53
21138	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19455	\N	\N	\N
21139	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19456	\N	\N	\N
21140	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19457	18	\N	\N
21141	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19458	27	\N	\N
21142	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19459	\N	\N	2014-09-28 12:32:23
21143	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19460	\N	\N	\N
21144	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19461	17	\N	\N
21145	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19462	\N	\N	\N
21313	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19498	\N	\N	\N
21314	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19499	13	\N	\N
21315	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19500	\N	\N	\N
21316	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19501	\N	\N	\N
21317	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19502	\N	\N	\N
21318	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19503	\N	\N	\N
21319	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour le Tchad	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19504	9	\N	\N
21320	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour la Centrafrique	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19505	19	\N	\N
21321	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19506	\N	\N	2014-09-28 19:03:23
21322	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19507	32	\N	\N
21323	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19508	25	\N	\N
21324	PDTDEL	2011-10-01 00:00:00	2012-09-30 00:00:00	ANCIEN	\N	\N	pour le Kosovo	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19674	3	\N	\N
18981	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17166	\N	\N	\N
20795	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18733	3	\N	\N
20796	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18734	1	\N	\N
20797	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18735	\N	\N	2014-09-28 16:40:50
20798	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18736	9	\N	2014-09-28 13:39:21
20799	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18737	\N	\N	2014-09-28 17:27:35
20800	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18738	\N	\N	\N
20801	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18739	\N	\N	\N
21856	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19862	\N	\N	2014-09-28 17:00:59
20802	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18740	2	\N	\N
20803	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18906	4	\N	\N
20804	MEMBRE	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18907	\N	\N	2014-09-29 13:41:53
20805	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18908	3	\N	\N
20967	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19405	14	\N	\N
20968	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19406	\N	\N	\N
20969	MEMBRE	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19407	\N	\N	2014-09-29 13:43:10
20970	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour le Burkina Faso	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19408	15	\N	2014-09-28 17:27:35
20971	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19409	\N	\N	2014-09-28 17:27:35
20972	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19575	\N	\N	\N
20973	VICPDT	2011-10-01 00:00:00	2014-10-03 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19576	6	\N	\N
20974	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19577	\N	\N	2014-09-28 17:22:11
20975	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19578	4	\N	2014-09-28 12:32:23
19617	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17780	\N	\N	\N
19618	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17781	6	\N	\N
19619	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17782	\N	\N	2014-09-28 16:50:17
19620	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17783	\N	\N	\N
19792	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18189	\N	\N	\N
19793	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18190	11	\N	\N
19794	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18191	\N	\N	2014-09-28 13:16:32
19795	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18192	21	\N	2014-09-28 13:39:21
19796	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18269	14	\N	\N
19797	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18270	\N	\N	\N
19798	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18271	10	\N	\N
19799	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18272	6	\N	\N
19800	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18273	7	\N	\N
19801	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18274	\N	\N	\N
19802	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18275	9	\N	\N
19803	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18276	8	\N	\N
19257	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17677	16	\N	2014-09-28 16:40:50
19258	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17678	\N	\N	\N
19259	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17679	1	\N	\N
19260	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17680	19	\N	2014-09-28 17:09:16
19261	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17681	24	\N	2014-09-28 13:39:21
19262	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17682	\N	\N	\N
19263	PDTDEL	2011-10-01 00:00:00	2014-04-24 00:00:00	ANCIEN	\N	\N	pour la Colombie	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17683	3	\N	\N
19264	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17684	\N	\N	2014-09-28 17:27:35
19265	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17685	\N	\N	2014-09-28 17:27:35
19266	VICPDT	2011-10-01 00:00:00	2013-12-31 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17857	2	\N	\N
19267	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17858	\N	\N	\N
21855	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19861	\N	\N	\N
19268	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17859	\N	\N	\N
19440	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17360	\N	\N	\N
19441	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17361	6	\N	\N
19442	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17362	13	\N	\N
19443	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17363	\N	\N	\N
19444	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17364	\N	\N	\N
19445	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17365	\N	\N	\N
19446	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17554	\N	\N	\N
19447	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17555	\N	\N	\N
19448	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17556	24	\N	\N
19449	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17557	\N	\N	2014-09-28 13:19:48
19450	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17558	11	\N	\N
19451	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17559	\N	\N	\N
19621	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17784	\N	\N	\N
19622	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17785	\N	\N	\N
19623	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17786	9	\N	2014-09-28 17:27:35
19624	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17787	\N	\N	2014-09-28 17:27:35
19625	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17788	\N	\N	\N
19626	MEMBRE	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17789	\N	\N	2014-09-29 13:43:10
19627	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17790	\N	\N	\N
19628	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17421	\N	\N	\N
19629	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17422	\N	\N	\N
19630	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17423	\N	\N	\N
21864	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19871	\N	\N	\N
21679	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19775	\N	\N	\N
22067	MEMBRE	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20052	\N	\N	\N
22070	MEMBRE	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20055	\N	\N	\N
22071	MEMBRE	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20056	\N	\N	\N
21493	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19387	\N	\N	\N
21494	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19553	1	\N	\N
21495	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19554	3	\N	\N
21496	MEMBRE	2011-10-01 00:00:00	2013-02-06 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19555	\N	\N	\N
21497	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19556	9	\N	\N
21498	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19557	3	\N	\N
21499	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19558	\N	\N	2014-09-28 17:03:42
21500	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19559	\N	\N	\N
21501	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19560	7	\N	\N
21502	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19561	\N	\N	\N
21503	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19562	\N	\N	\N
21504	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19563	\N	\N	\N
21681	VICPDT	2012-02-20 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16354	\N	\N	\N
21682	VICPDT	2012-02-20 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16345	\N	\N	2014-09-28 18:00:58
21683	VICPDT	2012-02-20 00:00:00	2013-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	16605	\N	\N	\N
21684	PDTDEL	2012-02-20 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16352	\N	\N	\N
21687	VICPDT	2012-02-20 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16909	\N	\N	2014-09-28 16:40:50
21688	VICPDT	2012-02-20 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16712	\N	\N	2014-09-29 09:08:33
21689	SECRET	2012-02-20 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16339	\N	\N	2014-09-28 17:03:42
21690	SECRET	2012-02-20 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16346	\N	\N	\N
21713	MEMBRE	2011-10-01 00:00:00	2012-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	19796	\N	\N	\N
21530	MEMBRE	2011-10-01 00:00:00	2012-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	19699	\N	\N	\N
21531	MEMBRE	2011-10-01 00:00:00	2012-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	19700	\N	\N	\N
21532	PDT	2012-02-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17277	\N	\N	2014-09-28 16:42:05
21533	VICPDT	2012-02-07 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19694	\N	\N	\N
21534	VICPDT	2012-02-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19699	\N	\N	2014-09-28 18:03:38
21535	VICPDT	2012-02-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19700	\N	\N	2014-09-28 18:58:25
21536	VICPDT	2012-02-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17274	\N	\N	2014-09-28 17:00:59
21538	VICPDT	2012-02-07 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17205	\N	\N	\N
21540	SECRET	2012-02-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17188	\N	\N	2014-09-28 17:55:39
21861	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16533	\N	\N	\N
21863	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19870	\N	\N	2014-09-28 17:27:29
21939	MEMBRE	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19939	\N	\N	\N
21940	MEMBRE	2012-06-28 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	19940	\N	\N	\N
21941	MEMBRE	2012-06-28 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	19941	\N	\N	\N
21942	MEMBRE	2012-06-28 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	19942	\N	\N	\N
21943	MEMBRE	2012-06-28 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	19943	\N	\N	\N
22009	MEMBRE	2012-10-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19995	\N	\N	\N
22010	MEMBRE	2012-10-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19996	\N	\N	\N
22011	MEMBRE	2012-10-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19997	\N	\N	\N
22012	MEMBRE	2012-10-10 00:00:00	2012-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	19998	\N	\N	\N
22013	MEMBRE	2012-10-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19999	\N	\N	2014-09-29 09:08:33
21945	MEMBRE	2012-07-13 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19945	\N	\N	\N
22001	MEMBRE	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19988	\N	\N	2014-10-14 16:36:53
22063	MEMBRE	2012-10-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20048	\N	\N	\N
22182	MEMBRE	2013-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20130	\N	\N	\N
22183	MEMBRE	2013-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20131	\N	\N	\N
21848	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19854	\N	\N	\N
21849	MEMBRE	2012-02-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19855	\N	\N	2014-09-28 14:31:42
21693	MEMBRE	2012-01-25 00:00:00	2012-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	19779	\N	\N	\N
21694	MEMBRE	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19780	\N	\N	\N
22050	MEMBRE	2012-10-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20035	\N	\N	\N
22149	VICPDT	2012-02-21 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16419	\N	\N	2014-09-28 12:56:42
22150	VICPDT	2012-02-21 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16924	\N	\N	\N
22151	VICPDT	2012-02-21 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16428	\N	\N	\N
22152	VICPDT	2012-02-21 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16443	\N	\N	\N
21714	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19797	\N	\N	\N
21715	MEMBRE	2011-10-01 00:00:00	2014-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19798	\N	\N	\N
21716	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19799	5	\N	\N
21740	VICPDT	2012-02-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16460	\N	\N	2014-09-28 17:12:41
21739	VICPDT	2012-02-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16990	\N	\N	2014-09-28 17:09:16
21741	VICPDT	2012-02-22 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16488	\N	\N	\N
21743	SECRET	2012-02-22 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16463	\N	\N	\N
21744	SECRET	2012-02-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16457	\N	\N	2014-09-28 17:40:23
21751	VICPDT	2012-02-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16810	\N	\N	2014-09-28 16:40:50
21752	VICPDT	2012-02-22 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16914	\N	\N	\N
21870	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19875	\N	\N	\N
21871	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19876	\N	\N	\N
21965	MEMBRE	2012-01-25 00:00:00	2012-09-02 00:00:00	ANCIEN	\N	\N	\N	\N	19957	\N	\N	\N
21966	PDT	2012-09-04 00:00:00	2012-09-05 00:00:00	ANCIEN	\N	\N	\N	\N	19957	\N	\N	\N
21967	PDT	2012-09-06 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19957	\N	\N	2014-09-28 16:50:17
21968	PDT	2012-09-06 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19809	\N	\N	2014-09-28 13:19:48
21853	MEMBRE	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	19859	\N	\N	2014-09-29 13:41:53
21932	MEMBRE	2012-07-13 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19935	\N	\N	2014-09-28 17:52:18
21972	PDTDEL	2012-08-01 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	pour le Koweit	\N	19959	5	\N	\N
21973	MEMBRE	2012-08-01 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	19960	\N	\N	\N
21974	MEMBRE	2012-08-01 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	19961	\N	\N	\N
21975	MEMBRE	2012-08-01 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	19962	\N	\N	\N
21976	MEMBRE	2012-08-01 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	19963	\N	\N	\N
21977	MEMBRE	2012-08-01 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	19964	\N	\N	\N
21978	MEMBRE	2012-08-01 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	19965	\N	\N	\N
21562	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19706	\N	\N	\N
21506	PDT	2012-01-18 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17032	\N	\N	\N
21509	VICPDT	2012-02-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17099	\N	\N	\N
21542	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19701	2	\N	\N
21563	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19708	\N	\N	\N
21576	VICPDT	2012-02-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16633	\N	\N	2014-09-28 17:31:42
21582	VICPDT	2012-02-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16637	\N	\N	\N
21584	VICPDT	2012-02-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19721	\N	\N	\N
21873	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19878	\N	\N	\N
21953	MEMBRE	2011-12-14 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19946	\N	\N	2014-09-28 17:27:35
22051	MEMBRE	2012-10-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20036	\N	\N	\N
22077	VICPDT	2012-11-27 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19952	\N	\N	\N
22079	VICPDT	2012-11-27 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19951	\N	\N	\N
22154	SECRET	2012-02-21 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16423	\N	\N	2014-09-28 17:03:42
22155	SECRET	2012-12-21 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16432	\N	\N	\N
22156	SECRET	2012-02-21 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	16433	\N	\N	2014-09-29 13:43:10
22229	MEMBRE	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20177	\N	2013-05-07 14:03:10	\N
22230	MEMBRE	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20178	\N	2013-05-07 14:05:12	\N
21587	PDT	2012-01-17 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17150	\N	\N	\N
21588	VICPDT	2012-02-07 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17135	\N	\N	\N
21851	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19857	\N	\N	\N
21956	MEMBRE	2011-12-14 00:00:00	2012-12-26 00:00:00	ANCIEN	\N	\N	\N	\N	19949	\N	\N	\N
22002	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19989	\N	\N	\N
21610	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17314	\N	\N	2014-09-28 16:40:50
21612	VICPDT	2012-02-14 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16357	\N	\N	2014-09-28 17:40:23
21613	VICPDT	2012-02-14 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16912	\N	\N	2014-09-28 17:27:29
20627	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour la Suède	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18686	4	\N	\N
20628	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18851	\N	\N	2014-09-28 13:16:32
20629	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18852	\N	\N	\N
20630	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour Bahreïn	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18853	3	\N	\N
20631	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18854	\N	\N	\N
20632	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18855	9	\N	\N
20213	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17964	9	\N	2014-09-28 17:31:42
20214	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17965	\N	\N	\N
20215	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17966	\N	\N	\N
20216	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18132	\N	\N	\N
20217	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18133	\N	\N	2014-09-28 17:27:35
20218	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18134	11	\N	\N
20219	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18135	\N	\N	\N
20220	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18136	\N	\N	\N
20221	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18137	\N	\N	\N
20222	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18138	8	\N	\N
20223	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18139	1	\N	\N
20224	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18140	12	\N	\N
20376	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18794	9	\N	\N
20377	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18795	5	\N	\N
20378	MEMBRE	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18958	\N	\N	2014-09-29 13:41:53
20379	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18959	24	\N	\N
20380	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18960	11	\N	\N
20381	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18961	19	\N	2014-09-28 12:56:42
20382	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18962	\N	\N	\N
20383	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18963	\N	\N	\N
20384	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18964	\N	\N	\N
20385	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18965	1	\N	\N
20386	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18966	\N	\N	2014-09-28 13:39:21
20387	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18967	\N	\N	\N
20489	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18646	\N	\N	2014-09-28 17:03:42
20490	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18647	\N	\N	\N
20491	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18648	13	\N	2014-09-28 16:40:50
20492	VICPDTPRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18649	2	\N	\N
20493	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18650	\N	\N	\N
20494	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18651	\N	\N	\N
20495	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18652	\N	\N	\N
20496	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18653	\N	\N	\N
20497	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18818	\N	\N	2014-09-28 17:27:29
22066	MEMBRE	2012-10-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20051	\N	\N	\N
20498	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18819	8	\N	\N
20499	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18820	\N	\N	\N
20500	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18821	\N	\N	\N
20634	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18857	11	\N	\N
20635	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18858	\N	\N	\N
20636	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18859	\N	\N	\N
20637	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18860	\N	\N	2014-09-28 13:19:48
20638	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18861	\N	\N	2014-09-28 17:27:35
20639	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19021	6	\N	2014-09-28 16:40:50
20640	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19022	\N	\N	\N
20641	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19023	\N	\N	\N
20976	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19579	10	\N	2014-09-28 17:27:29
20977	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19580	\N	\N	\N
20978	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19581	5	\N	\N
21146	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour Sao-Tomé-et-Principe	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19463	8	\N	\N
21147	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19464	21	\N	\N
21148	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19630	3	\N	\N
21149	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19631	\N	\N	\N
21150	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19632	\N	\N	\N
21151	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19633	\N	\N	2014-09-28 17:27:35
21152	MEMBRE	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19634	\N	\N	2014-09-29 13:43:10
21153	MEMBRE	2011-10-01 00:00:00	2014-10-03 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19635	\N	\N	2015-11-12 15:26:22
21154	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19636	2	\N	\N
21155	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19637	\N	\N	2014-09-28 13:39:21
21156	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19638	\N	\N	\N
21157	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19639	4	\N	\N
21325	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19675	12	\N	\N
21326	SECRET	2011-10-01 00:00:00	2014-10-03 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19676	5	\N	\N
21327	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour le Kosovo	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19677	3	\N	2014-02-03 10:56:11
21328	VICPDT	2011-10-01 00:00:00	2014-10-03 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19678	10	\N	\N
21329	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19679	3	\N	\N
21330	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19680	\N	\N	\N
21331	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19681	\N	\N	\N
21332	PDTDEL	2011-10-01 00:00:00	2014-05-02 00:00:00	ANCIEN	\N	\N	pour la Macédoine	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19682	4	\N	\N
21333	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19683	\N	\N	\N
21334	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19684	\N	\N	\N
21335	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour la Namibie	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19157	7	\N	2014-09-28 18:03:38
21336	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19158	\N	\N	\N
20806	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18909	\N	\N	\N
20807	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18910	\N	\N	2014-09-28 12:09:44
20808	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18911	\N	\N	\N
20809	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18912	\N	\N	\N
20810	SECRET	2011-10-01 00:00:00	2014-10-03 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18913	10	\N	\N
20811	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18914	\N	\N	\N
20812	MEMBRE	2011-10-01 00:00:00	2013-02-06 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18915	\N	\N	\N
20813	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18916	1	\N	2014-04-16 17:18:58
20814	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18566	\N	\N	\N
20815	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18567	12	\N	\N
20816	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18568	\N	\N	\N
20817	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18569	\N	\N	2014-09-28 17:27:35
19003	MEMBRE	2011-10-01 00:00:00	2012-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	17188	\N	\N	\N
19004	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17189	\N	\N	\N
19009	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17194	\N	\N	\N
19010	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17195	\N	\N	\N
19011	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17196	\N	\N	2014-09-28 12:56:42
19012	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17197	\N	\N	\N
19016	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17201	\N	\N	2014-09-28 17:55:37
19017	MEMBRE	2011-12-14 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17202	\N	\N	\N
19019	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17204	\N	\N	2015-01-08 17:14:29
19020	MEMBRE	2011-10-01 00:00:00	2012-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	17205	\N	\N	\N
19025	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17210	\N	\N	2014-09-28 13:39:21
19048	MEMBRE	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17233	\N	\N	2014-09-28 13:21:47
19049	MEMBRE	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17234	\N	\N	2014-09-28 17:07:41
19050	MEMBRE	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17235	\N	\N	\N
19056	MEMBRE	2012-01-25 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	17241	\N	\N	2014-09-29 13:43:10
19062	MEMBRE	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17247	\N	\N	2014-09-28 17:22:11
19063	MEMBRE	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17248	\N	\N	\N
19070	MEMBRE	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17255	\N	\N	\N
19072	MEMBRE	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17257	\N	\N	\N
19073	MEMBRE	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17258	\N	\N	2014-09-28 13:32:35
19074	MEMBRE	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17259	\N	\N	\N
19075	MEMBRE	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17260	\N	\N	\N
19076	MEMBRE	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17261	\N	\N	\N
19077	MEMBRE	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17262	\N	\N	\N
19078	MEMBRE	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17263	\N	\N	2014-09-28 14:31:42
19079	MEMBRE	2012-01-25 00:00:00	2014-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	17264	\N	\N	2014-12-18 16:15:04
20979	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19582	8	\N	\N
20980	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19583	9	\N	2014-09-28 12:09:44
19631	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17424	14	\N	\N
19632	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17425	10	\N	\N
19804	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18277	5	\N	2014-09-28 12:21:28
19805	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18278	\N	\N	\N
19806	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18279	\N	\N	2014-09-28 18:00:58
19807	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18456	\N	\N	\N
19808	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18457	\N	\N	2014-09-28 16:50:17
19809	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18458	\N	\N	\N
19810	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18459	\N	\N	\N
19811	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18460	\N	\N	\N
19812	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18461	\N	\N	2014-09-28 18:19:47
19813	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18462	1	\N	2014-09-28 13:16:32
19814	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18463	\N	\N	2014-09-28 12:56:42
19815	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18464	\N	\N	\N
19269	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17860	\N	\N	\N
19270	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17861	\N	\N	\N
19271	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17862	\N	\N	\N
19272	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17863	6	\N	2014-09-28 17:07:07
19273	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17864	\N	\N	2014-09-28 17:34:16
19274	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17865	\N	\N	\N
19275	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17866	\N	\N	\N
19276	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17867	\N	\N	2014-09-28 12:44:31
19277	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17473	3	\N	\N
19278	PDTHON	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17474	2	\N	\N
19279	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17475	\N	\N	2014-09-28 18:00:58
19280	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17476	\N	\N	\N
19452	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17560	\N	\N	\N
19453	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17561	\N	\N	2014-09-28 17:27:35
19454	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17562	\N	\N	2014-09-28 17:27:35
19455	MEMBRE	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17563	\N	\N	2014-09-29 13:43:10
19456	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17564	27	\N	\N
19457	MEMBRE	2011-10-01 00:00:00	2012-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17730	\N	\N	\N
19458	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17731	1	\N	\N
19459	MEMBRE	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17732	\N	\N	2014-09-29 13:41:53
19460	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17733	12	\N	\N
19461	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17734	15	\N	\N
19462	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour Djibouti	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17735	6	\N	2014-09-28 17:55:39
19463	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour le Soudan du Sud	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17736	5	\N	\N
19633	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17426	5	\N	\N
19634	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17427	\N	\N	\N
19635	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17428	\N	\N	\N
19636	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17429	\N	\N	2014-09-28 13:21:47
19637	MEMBRE	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17430	\N	\N	\N
19638	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17431	\N	\N	\N
19639	MEMBRE	2011-10-01 00:00:00	2014-05-11 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17620	\N	\N	\N
19640	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17621	\N	\N	\N
19641	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17622	\N	\N	\N
19642	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17623	\N	\N	\N
19643	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17624	\N	\N	\N
19644	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17625	\N	\N	\N
21614	VICPDT	2012-02-14 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16365	\N	\N	\N
21615	VICPDT	2012-02-14 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16372	\N	\N	\N
21616	VICPDT	2012-02-14 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16380	\N	\N	\N
21617	SECRET	2012-02-14 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16361	\N	\N	2014-09-28 12:44:31
21618	SECRET	2012-02-14 00:00:00	2014-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	17168	\N	\N	2014-11-04 11:22:47
21619	SECRET	2012-02-14 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16986	\N	\N	\N
21620	SECRET	2012-02-14 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16376	\N	\N	\N
21631	SECRET	2012-02-08 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16411	\N	\N	\N
21632	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19744	\N	\N	\N
21633	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19745	\N	\N	\N
21634	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19746	\N	\N	\N
21635	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour le Togo	\N	19747	11	\N	\N
21636	VICPDT	2011-10-01 00:00:00	2014-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	19748	4	\N	2014-09-28 13:39:21
21850	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19856	\N	\N	\N
22065	MEMBRE	2012-10-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20050	\N	\N	\N
21664	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour l'Azerbaïdjan	\N	19283	2	\N	2014-09-28 16:42:05
22076	PDT	2012-11-27 00:00:00	2013-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	19993	\N	\N	\N
22153	VICPDT	2012-02-21 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16447	\N	\N	\N
21522	SECRET	2011-05-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19693	9	\N	2014-09-28 19:07:43
21623	VICPDT	2012-02-08 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16402	\N	\N	2014-09-28 13:16:32
21624	VICPDT	2012-02-08 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16403	\N	\N	\N
21625	VICPDT	2012-02-08 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16664	\N	\N	\N
21626	SECRET	2012-02-08 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16384	\N	\N	2014-09-28 13:39:21
21627	SECRET	2012-02-08 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17102	\N	\N	\N
21628	SECRET	2012-02-08 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16391	\N	\N	2014-09-28 12:44:31
21629	SECRET	2012-02-08 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16394	\N	\N	\N
21630	SECRET	2012-02-08 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16404	\N	\N	\N
21652	VICPDT	2012-02-15 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16824	\N	\N	\N
21653	VICPDT	2012-02-15 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16916	\N	\N	\N
21654	VICPDT	2012-02-15 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16931	\N	\N	\N
21655	VICPDT	2012-02-15 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16821	\N	\N	\N
22224	MEMBRE	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20172	\N	2013-04-04 10:07:04	2014-09-28 17:58:05
22225	MEMBRE	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20173	\N	2013-04-04 10:14:32	2014-09-28 17:58:05
22226	MEMBRE	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20174	\N	2013-04-04 10:39:10	2014-09-28 17:58:05
21817	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19842	\N	\N	\N
22003	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19990	\N	\N	2014-09-28 13:32:35
21647	MEMBRE	2011-10-01 00:00:00	2012-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	19758	\N	\N	\N
21648	PDTHON	2012-02-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19758	\N	\N	2014-09-28 12:52:11
21649	MEMBRE	2011-10-01 00:00:00	2012-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	19759	\N	\N	\N
21650	VICPDT	2012-02-15 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19759	\N	\N	\N
21651	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19760	\N	\N	\N
21663	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19762	\N	\N	\N
21665	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19763	6	\N	\N
21667	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19765	\N	\N	\N
21671	MEMBRE	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19767	\N	\N	2014-09-28 17:27:35
21691	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19777	7	\N	\N
21692	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19778	26	\N	\N
21857	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19863	\N	\N	\N
21872	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19877	\N	\N	\N
21883	MEMBRE	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19886	\N	\N	\N
21884	MEMBRE	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19887	\N	\N	\N
21885	MEMBRE	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19888	\N	\N	\N
21957	MEMBRE	2011-12-14 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19950	\N	\N	\N
21958	MEMBRE	2011-12-14 00:00:00	2012-12-26 00:00:00	ANCIEN	\N	\N	\N	\N	19951	\N	\N	\N
21959	MEMBRE	2011-12-14 00:00:00	2012-12-26 00:00:00	ANCIEN	\N	\N	\N	\N	19952	\N	\N	\N
22115	MEMBRE	2011-10-01 00:00:00	2013-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	20084	\N	\N	\N
21961	MEMBRE	2011-12-14 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19954	\N	\N	\N
21962	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19955	\N	\N	\N
21994	MEMBRE	2012-08-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19981	\N	\N	2014-10-14 16:27:39
22116	MEMBRE	2011-10-01 00:00:00	2013-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	20085	\N	\N	\N
22117	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20086	\N	\N	\N
21656	VICPDT	2012-02-15 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16820	\N	\N	\N
21971	PDT	2012-09-06 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19958	\N	\N	\N
21969	PDT	2012-09-06 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19913	\N	\N	\N
21970	MEMBRE	2012-07-13 00:00:00	2012-09-02 00:00:00	ANCIEN	\N	\N	\N	\N	19958	\N	\N	\N
22026	MEMBRE	2012-10-10 00:00:00	2014-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	20012	\N	\N	\N
22028	MEMBRE	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20014	\N	\N	\N
22128	MEMBRE	2011-10-01 00:00:00	2013-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	20097	\N	\N	\N
22129	MEMBRE	2011-10-01 00:00:00	2013-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	20098	\N	\N	\N
22130	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20099	\N	\N	\N
22139	PDT	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20093	\N	\N	\N
22140	VICPDT	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20085	\N	\N	\N
22145	SECRET	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20096	\N	\N	\N
22147	SECRET	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20098	\N	\N	\N
22176	MEMBRE	2013-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20124	\N	\N	\N
21660	SECRET	2012-02-15 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16825	\N	\N	\N
21657	VICPDT	2012-02-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16827	\N	\N	2014-09-28 17:27:35
21659	SECRET	2012-02-15 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16829	\N	\N	\N
21661	SECRET	2012-02-15 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16815	\N	\N	\N
21785	VICPDT	2012-02-23 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16606	\N	\N	\N
21786	VICPDT	2012-02-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16613	\N	\N	2014-09-28 16:42:05
21787	VICPDT	2012-02-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16598	\N	\N	2014-09-28 17:55:37
21788	VICPDT	2012-02-23 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16950	\N	\N	\N
21789	VICPDT	2012-02-23 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16586	\N	\N	\N
21790	VICPDT	2012-02-23 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16585	\N	\N	\N
21791	VICPDT	2012-02-23 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16798	\N	\N	\N
21792	VICPDT	2012-02-23 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16617	\N	\N	\N
21793	VICPDT	2012-02-23 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16800	\N	\N	\N
21794	VICPDT	2012-02-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16593	\N	\N	2014-09-28 13:09:05
21795	VICPDT	2012-02-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16599	\N	\N	2014-09-28 12:39:09
21952	SECRET	2012-02-08 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19727	\N	\N	\N
21954	MEMBRE	2011-12-14 00:00:00	2012-12-26 00:00:00	ANCIEN	\N	\N	\N	\N	19947	\N	\N	\N
22133	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20102	\N	\N	\N
22132	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20101	\N	\N	\N
22134	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20103	\N	\N	\N
22135	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20104	\N	\N	\N
22136	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20105	\N	\N	\N
22137	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20106	\N	\N	\N
22138	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20107	\N	\N	\N
22146	SECRET	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20097	\N	\N	\N
22223	MEMBRE	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20171	\N	2013-04-02 11:00:16	2014-09-28 17:40:23
21543	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19702	\N	\N	\N
21546	MEMBRE	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19705	\N	\N	\N
21564	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19709	\N	\N	\N
21565	MEMBRE	2011-12-14 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19710	\N	\N	\N
21567	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19712	\N	\N	\N
21758	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	18686	7	\N	\N
21759	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	18618	10	\N	\N
21760	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	18619	11	\N	\N
21761	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	18596	15	\N	2014-09-28 16:40:50
21818	VICPDT	2012-02-28 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17013	\N	\N	\N
21821	VICPDT	2012-02-28 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17015	\N	\N	\N
21822	VICPDT	2012-02-28 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17022	\N	\N	\N
21823	SECRET	2012-02-28 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17026	\N	\N	\N
21825	SECRET	2012-02-28 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17014	\N	\N	\N
21846	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19852	\N	\N	\N
21847	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19853	\N	\N	\N
21935	PDT	2012-07-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19092	1	\N	2014-09-28 17:27:35
21936	PDT	2012-07-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17519	1	\N	\N
21937	PDTDEL	2012-07-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour le Congo-Brazzaville	\N	19914	10	\N	\N
22025	MEMBRE	2012-10-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20011	\N	\N	2014-09-28 14:31:42
22027	MEMBRE	2012-10-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20013	\N	\N	\N
22029	MEMBRE	2012-10-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20015	\N	\N	2014-09-28 13:09:05
22055	MEMBRE	2012-10-10 00:00:00	2012-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	20040	\N	\N	\N
22072	MEMBRE	2012-02-14 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20057	\N	\N	\N
22073	MEMBRE	2012-02-14 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20058	\N	\N	\N
22085	MEMBRE	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20064	\N	\N	\N
22086	MEMBRE	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20065	\N	\N	\N
22087	MEMBRE	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20066	\N	\N	2014-09-28 17:40:23
22088	MEMBRE	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20067	\N	\N	\N
22089	MEMBRE	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20068	\N	\N	\N
22090	MEMBRE	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20069	\N	\N	2014-09-28 17:52:18
22100	PDT	2012-12-13 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19984	\N	\N	\N
22143	SECRET	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20084	\N	\N	\N
21609	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19742	\N	\N	\N
21658	VICPDT	2012-02-15 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16817	\N	\N	\N
21669	VICPDT	2012-02-16 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16627	\N	\N	2014-09-28 13:39:21
21762	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19827	\N	\N	\N
21764	MEMBRE	2012-01-25 00:00:00	2014-04-24 00:00:00	ANCIEN	\N	\N	\N	\N	19829	\N	\N	\N
21806	VICPDT	2012-02-21 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17164	\N	\N	\N
21807	VICPDT	2012-02-21 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17103	\N	\N	\N
21808	VICPDT	2012-02-21 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17110	\N	\N	\N
22006	MEMBRE	2011-12-14 00:00:00	2012-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	19993	\N	\N	\N
22018	MEMBRE	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20004	\N	\N	2014-10-14 16:37:26
20642	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19024	\N	\N	\N
20643	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19025	3	\N	2014-09-28 16:50:17
20644	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19026	2	\N	\N
20645	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19027	19	\N	2014-09-28 12:56:42
18983	MEMBRE	2011-10-01 00:00:00	2012-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	17168	\N	\N	\N
18988	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17173	\N	\N	\N
20225	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18141	\N	\N	2014-09-28 18:00:58
20226	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18142	\N	\N	\N
20227	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18390	10	\N	\N
20228	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18391	\N	\N	\N
20229	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18392	6	\N	\N
20230	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18393	\N	\N	2014-09-28 17:22:11
20231	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour la Lituanie	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18394	4	\N	\N
20232	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18395	\N	\N	\N
20233	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18396	\N	\N	\N
20234	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18397	6	\N	\N
20235	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18398	11	\N	\N
20388	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19058	\N	\N	\N
20389	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19059	\N	\N	2014-09-28 12:21:28
20390	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19060	\N	\N	\N
20391	MEMBRE	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19061	\N	\N	\N
20392	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19062	2	\N	\N
20393	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19063	\N	\N	2014-09-28 13:39:21
20394	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19064	\N	\N	\N
20395	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19065	7	\N	\N
20396	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19066	\N	\N	\N
20397	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19067	3	\N	\N
20398	SECRET	2011-10-01 00:00:00	2014-10-03 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19068	10	\N	\N
20399	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18621	\N	\N	\N
20501	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18822	13	\N	\N
20502	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18823	16	\N	\N
20503	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18824	\N	\N	\N
20504	MEMBRE	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18825	\N	\N	\N
20505	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18826	6	\N	\N
20506	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18827	\N	\N	\N
20507	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18828	\N	\N	\N
20508	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18989	2	\N	2014-09-28 16:42:05
20509	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18990	7	\N	\N
20510	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18991	8	\N	2014-09-28 16:50:17
20511	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18992	20	\N	\N
20512	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18993	6	\N	\N
20646	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19028	\N	\N	\N
20647	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour la Papouasie-Nouvelle Guinée	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19029	4	\N	\N
20648	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19030	\N	\N	\N
20649	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19031	18	\N	\N
20650	MEMBRE	2011-10-01 00:00:00	2014-05-11 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18511	\N	\N	\N
20651	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18512	7	\N	\N
20652	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18513	\N	\N	\N
20654	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18515	\N	\N	2014-09-28 12:32:23
20655	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18516	\N	\N	2014-09-28 12:39:09
20656	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18517	\N	\N	\N
20981	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19584	\N	\N	\N
21158	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19640	4	\N	\N
21159	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19113	9	\N	\N
21160	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19114	8	\N	\N
21161	MEMBRE	2011-10-01 00:00:00	2014-10-03 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19115	\N	\N	\N
21162	PDT	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19116	1	\N	\N
21163	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19117	\N	\N	\N
21164	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19118	11	\N	\N
21165	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19119	\N	\N	2014-09-28 17:52:18
21166	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19120	6	\N	2014-09-28 17:03:42
22104	MEMBRE	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20074	\N	\N	\N
21167	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19121	\N	\N	2014-09-28 17:07:07
21168	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19122	4	\N	2014-09-28 19:03:23
21169	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19123	\N	\N	\N
21337	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19159	1	\N	2014-09-28 18:19:47
21338	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour le Malawi	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19160	4	\N	\N
21339	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19161	\N	\N	2014-09-28 12:56:42
21340	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19162	\N	\N	2014-09-28 12:56:42
21341	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19163	\N	\N	2014-09-28 17:09:16
21342	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19164	\N	\N	\N
21343	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19165	\N	\N	\N
21344	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19166	\N	\N	\N
21345	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19167	\N	\N	\N
21346	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19333	\N	\N	\N
21347	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19334	\N	\N	\N
21348	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19335	\N	\N	\N
20818	MEMBRE	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18570	\N	\N	2014-09-29 13:43:10
20819	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18571	\N	\N	\N
20820	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18572	\N	\N	\N
20821	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18573	\N	\N	\N
20822	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18574	5	\N	\N
20823	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18575	\N	\N	2014-09-28 13:21:47
20824	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18576	\N	\N	\N
20825	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18741	\N	\N	\N
20826	MEMBRE	2011-10-01 00:00:00	2012-09-19 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18742	\N	\N	\N
20827	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18743	4	\N	\N
20828	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18744	4	\N	\N
20829	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18745	\N	\N	2014-09-28 17:27:35
20982	MEMBRE	2011-10-01 00:00:00	2014-10-03 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19585	\N	\N	\N
20983	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour la Guinée équatoriale	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19234	5	\N	2014-09-28 18:03:38
20984	VICPDTDRT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19235	11	\N	\N
20985	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19236	\N	\N	\N
20986	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19237	\N	\N	2014-09-28 17:27:35
20987	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19238	\N	\N	\N
20988	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19239	8	\N	\N
20989	MEMBRE	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19240	\N	\N	2014-09-29 13:43:10
20990	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19241	\N	\N	\N
20991	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19242	11	\N	\N
20992	VICPDTDRT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19243	12	\N	2014-09-28 18:19:47
20993	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour la République démocratique du Congo	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19244	7	\N	2014-09-28 12:56:42
19091	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17276	\N	\N	2014-09-28 16:50:17
19099	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17284	\N	\N	\N
19100	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17285	\N	\N	\N
19101	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17286	\N	\N	\N
19102	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17287	\N	\N	\N
19103	MEMBRE	2011-10-01 00:00:00	2014-10-03 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17288	\N	\N	2014-11-27 10:15:39
19104	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17289	9	\N	2014-09-28 17:03:42
19105	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17290	\N	\N	2014-09-28 13:21:47
19106	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17291	\N	\N	2014-09-28 13:21:47
19107	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17292	\N	\N	\N
19108	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17293	\N	\N	\N
19109	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17294	1	\N	2014-09-28 13:19:48
19281	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17477	4	\N	\N
19282	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17478	\N	\N	\N
19283	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17479	\N	\N	\N
19284	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17480	\N	\N	\N
19285	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17481	\N	\N	\N
19286	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17482	\N	\N	\N
19287	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17483	5	\N	\N
19288	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17514	\N	\N	\N
19289	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17515	\N	\N	\N
19290	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17516	\N	\N	\N
19291	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17517	\N	\N	2014-09-28 17:03:42
19292	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17518	\N	\N	\N
19464	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17737	16	\N	\N
19465	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17738	\N	\N	\N
19466	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17739	11	\N	\N
19467	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17740	26	\N	\N
19468	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17366	13	\N	\N
19469	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17367	8	\N	\N
19470	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17368	10	\N	\N
19471	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17369	\N	\N	\N
19472	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17370	\N	\N	\N
19473	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17371	\N	\N	\N
19474	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17372	11	\N	\N
19475	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17373	\N	\N	\N
19645	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17626	10	\N	\N
19646	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17627	\N	\N	\N
19647	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17628	13	\N	\N
19648	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17629	\N	\N	\N
19649	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17630	22	\N	\N
19650	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17791	\N	\N	2014-09-28 16:59:41
19651	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17792	\N	\N	\N
19652	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17793	14	\N	\N
19653	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17794	\N	\N	\N
19654	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17795	\N	\N	\N
19655	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17796	\N	\N	\N
19656	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17797	\N	\N	\N
19110	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17295	7	\N	\N
19111	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17296	2	\N	2014-09-28 17:27:35
22019	MEMBRE	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20005	\N	\N	\N
22020	MEMBRE	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20006	\N	\N	2014-09-28 18:03:38
22021	MEMBRE	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20007	\N	\N	\N
22022	MEMBRE	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20008	\N	\N	\N
22023	MEMBRE	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20009	\N	\N	\N
22024	MEMBRE	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20010	\N	\N	\N
22118	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20087	\N	\N	\N
22119	MEMBRE	2011-10-01 00:00:00	2013-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	20088	\N	\N	\N
22120	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20089	\N	\N	\N
22121	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20090	\N	\N	\N
22122	MEMBRE	2011-10-01 00:00:00	2013-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	20091	\N	\N	\N
22123	MEMBRE	2011-10-01 00:00:00	2013-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	20092	\N	\N	\N
22124	MEMBRE	2011-10-01 00:00:00	2013-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	20093	\N	\N	\N
21507	VICPDT	2012-02-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17172	\N	\N	\N
21508	VICPDT	2012-02-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17093	\N	\N	\N
21510	VICPDT	2012-02-01 00:00:00	2014-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	17042	\N	\N	2014-12-18 16:15:04
21511	VICPDT	2012-02-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17178	\N	\N	\N
21512	VICPDT	2012-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17130	\N	\N	2014-09-28 16:40:50
21513	VICPDT	2012-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17036	\N	\N	2014-09-28 17:35:38
21514	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19691	\N	\N	\N
21515	VICPDT	2012-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19690	\N	\N	2014-09-28 17:09:16
21516	SECRET	2012-02-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17158	\N	\N	\N
21517	SECRET	2012-02-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17184	\N	\N	\N
21518	SECRET	2012-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17034	\N	\N	2014-09-28 16:40:50
21519	SECRET	2012-02-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17153	\N	\N	\N
21520	SECRET	2012-02-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17031	\N	\N	\N
21526	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour le Gabon	\N	19225	4	\N	\N
21552	PDT	2012-02-08 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16742	\N	\N	2014-09-28 13:09:05
21592	VICPDT	2012-02-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19725	\N	\N	2014-09-28 17:09:16
21816	PDT	2012-01-12 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17096	\N	\N	\N
21819	VICPDT	2012-02-28 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17025	\N	\N	\N
21834	MEMBRE	2011-10-01 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	19850	\N	\N	\N
21835	VICPDT	2012-02-21 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17183	\N	\N	\N
21836	VICPDT	2012-02-21 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19850	\N	\N	\N
21862	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19869	\N	\N	\N
21865	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19872	\N	\N	\N
21866	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19873	\N	\N	\N
22082	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20061	\N	\N	\N
21765	VICPDT	2012-02-23 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17053	\N	\N	\N
21766	VICPDT	2012-02-23 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16667	\N	\N	\N
21767	VICPDT	2012-02-23 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17052	\N	\N	\N
21768	VICPDT	2012-02-23 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16656	\N	\N	\N
21769	VICPDT	2012-02-23 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19743	\N	\N	\N
21770	VICPDT	2012-02-23 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16696	\N	\N	\N
21771	VICPDT	2012-02-23 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17062	\N	\N	\N
21775	SECRET	2012-02-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17049	\N	\N	2014-09-28 17:03:42
21776	SECRET	2012-02-23 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16948	\N	\N	\N
21777	SECRET	2012-02-23 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16669	\N	\N	\N
21779	SECRET	2012-02-23 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16688	\N	\N	\N
21783	SECRET	2012-02-23 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16680	\N	\N	\N
21915	MEMBRE	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19918	\N	\N	2014-09-28 16:50:17
21845	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19851	\N	\N	2014-09-28 17:27:35
21916	MEMBRE	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19919	\N	\N	\N
21917	MEMBRE	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19920	\N	\N	\N
21918	SECRET	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19921	8	\N	\N
21919	MEMBRE	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19922	\N	\N	\N
21920	SECRET	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19923	9	\N	\N
21921	MEMBRE	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19924	\N	\N	\N
21922	MEMBRE	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19925	\N	\N	2014-09-28 13:39:21
21923	MEMBRE	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19926	\N	\N	2014-09-28 13:21:47
21924	VICPDT	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19927	7	\N	\N
21925	MEMBRE	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19928	\N	\N	2014-09-28 16:50:17
21926	MEMBRE	2012-06-28 00:00:00	2012-11-07 00:00:00	ANCIEN	\N	\N	\N	\N	19929	\N	\N	\N
21927	MEMBRE	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19930	\N	\N	\N
21928	MEMBRE	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19931	\N	\N	\N
21929	MEMBRE	2012-06-28 00:00:00	2014-05-11 00:00:00	ANCIEN	\N	\N	\N	\N	19932	\N	\N	\N
22101	MEMBRE	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20071	\N	\N	\N
22030	MEMBRE	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20016	\N	\N	\N
22031	MEMBRE	2012-10-10 00:00:00	2012-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	20017	\N	\N	\N
22033	MEMBRE	2012-11-15 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19956	\N	\N	\N
22102	MEMBRE	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20072	\N	\N	\N
22103	MEMBRE	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20073	\N	\N	\N
21553	PDT	2012-02-08 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16843	\N	\N	\N
21554	PDT	2012-02-08 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16934	\N	\N	2014-09-28 17:27:35
21555	PDT	2012-02-08 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16349	\N	\N	\N
21556	PDT	2012-02-08 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	16378	\N	\N	\N
21557	PDT	2012-02-08 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16626	\N	\N	\N
21561	PDT	2012-02-08 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16442	\N	\N	\N
21570	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour le Botswana	\N	19715	3	\N	\N
21571	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19716	\N	\N	\N
21572	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour le Kazakhstan	\N	19717	2	\N	\N
21573	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19718	\N	\N	\N
21574	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19719	2	\N	\N
21575	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19720	\N	\N	\N
21642	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19755	\N	\N	\N
21668	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19766	\N	\N	\N
21886	MEMBRE	2012-06-28 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	19889	\N	\N	\N
22144	SECRET	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20088	\N	\N	\N
21906	MEMBRE	2012-07-13 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19909	\N	\N	2014-09-28 17:40:23
21907	MEMBRE	2012-07-13 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19910	\N	\N	\N
21908	MEMBRE	2012-07-13 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19911	\N	\N	2014-09-28 13:09:05
21909	MEMBRE	2012-07-13 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19912	\N	\N	2014-09-28 17:31:42
21914	MEMBRE	2012-07-13 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19917	\N	\N	2014-09-28 17:52:18
21944	MEMBRE	2011-12-14 00:00:00	2012-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	19944	\N	\N	\N
21998	MEMBRE	2011-10-01 00:00:00	2014-05-01 00:00:00	ANCIEN	\N	\N	\N	\N	19985	\N	\N	\N
22052	MEMBRE	2012-10-10 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	20037	\N	\N	\N
22056	MEMBRE	2012-10-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20041	\N	\N	\N
22057	MEMBRE	2012-10-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20042	\N	\N	\N
22058	MEMBRE	2012-10-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20043	\N	\N	2014-09-28 17:07:41
22059	MEMBRE	2012-10-10 00:00:00	2012-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	20044	\N	\N	\N
22060	MEMBRE	2012-10-10 00:00:00	2012-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	20045	\N	\N	\N
22061	MEMBRE	2012-10-10 00:00:00	2013-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	20046	\N	\N	\N
22062	MEMBRE	2012-10-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20047	\N	\N	\N
21523	MEMBRE	2011-10-01 00:00:00	2012-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	19694	\N	\N	\N
21529	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19698	\N	\N	\N
21593	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19726	\N	\N	2014-09-28 17:27:35
21594	MEMBRE	2011-10-01 00:00:00	2012-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	19727	\N	\N	\N
21595	MEMBRE	2011-10-01 00:00:00	2012-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	19728	\N	\N	\N
21596	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19729	\N	\N	\N
21597	MEMBRE	2011-10-01 00:00:00	2012-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	19730	\N	\N	\N
21598	MEMBRE	2011-10-01 00:00:00	2012-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	19731	\N	\N	\N
21599	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19732	\N	\N	\N
21600	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19733	\N	\N	\N
21601	MEMBRE	2011-10-01 00:00:00	2012-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	19734	\N	\N	\N
21602	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19735	\N	\N	\N
21603	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19736	\N	\N	\N
21604	MEMBRE	2011-10-01 00:00:00	2012-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	19737	\N	\N	\N
21605	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19738	\N	\N	\N
21606	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19739	\N	\N	2014-09-28 13:39:21
21607	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19740	\N	\N	\N
21608	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19741	\N	\N	\N
21672	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19768	\N	\N	\N
21673	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19769	\N	\N	\N
21674	VICPDTDRT	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	19770	3	\N	\N
21676	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19772	\N	\N	\N
21677	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19773	\N	\N	\N
21678	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19774	20	\N	\N
21869	SECRET	2012-04-23 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19874	\N	\N	\N
21897	MEMBRE	2012-07-13 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19900	\N	\N	\N
21898	MEMBRE	2012-07-13 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19901	\N	\N	\N
21899	MEMBRE	2012-07-13 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19902	\N	\N	2014-09-28 12:44:31
21900	MEMBRE	2012-07-13 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19903	\N	\N	\N
21901	MEMBRE	2012-07-13 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19904	\N	\N	\N
21902	MEMBRE	2012-07-13 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19905	\N	\N	\N
21903	MEMBRE	2012-07-13 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19906	\N	\N	\N
21904	MEMBRE	2012-07-13 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19907	\N	\N	2014-09-28 19:03:23
21905	MEMBRE	2012-07-13 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19908	\N	\N	\N
21548	PDT	2012-02-08 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16822	\N	\N	2014-09-28 17:40:23
21549	PDT	2012-02-08 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16831	\N	\N	2014-09-28 14:31:42
21666	MEMBRE	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19764	\N	\N	2014-09-28 16:50:17
21931	MEMBRE	2012-07-13 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19934	\N	\N	2014-09-28 17:38:26
21984	MEMBRE	2012-08-01 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	19971	\N	\N	\N
21985	MEMBRE	2012-08-01 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	19972	\N	\N	\N
20657	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18518	\N	\N	\N
20236	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18399	\N	\N	\N
20237	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18400	11	\N	\N
20238	MEMBRE	2011-10-01 00:00:00	2014-05-11 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17967	\N	\N	\N
20239	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17968	\N	\N	\N
20240	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17969	\N	\N	2014-09-28 17:31:42
20241	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17970	10	\N	\N
20242	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17971	2	\N	\N
20243	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17972	7	\N	2014-09-28 17:52:18
20244	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17973	\N	\N	\N
20245	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17974	\N	\N	\N
20246	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17975	\N	\N	\N
20247	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17976	\N	\N	\N
18150	MEMBRE	2011-10-01 00:00:00	2012-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	16354	\N	\N	\N
18151	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16355	\N	\N	\N
18152	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16356	\N	\N	2014-09-28 13:39:21
18153	MEMBRE	2011-10-01 00:00:00	2012-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	16357	\N	\N	\N
18154	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16358	\N	\N	\N
18155	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16359	\N	\N	\N
18156	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16360	\N	\N	2014-09-28 12:21:28
18157	MEMBRE	2011-10-01 00:00:00	2012-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	16361	\N	\N	\N
18158	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16362	\N	\N	\N
18162	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16366	\N	\N	\N
18172	MEMBRE	2011-10-01 00:00:00	2012-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	16376	\N	\N	\N
18180	MEMBRE	2011-10-01 00:00:00	2012-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	16384	\N	\N	\N
18181	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16385	\N	\N	\N
18184	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16388	\N	\N	\N
18185	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16389	\N	\N	2014-09-28 17:27:29
18195	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16399	\N	\N	\N
18196	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16400	\N	\N	\N
18197	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16401	\N	\N	\N
18199	MEMBRE	2011-10-01 00:00:00	2012-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	16403	\N	\N	\N
18201	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16405	\N	\N	\N
18202	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16406	\N	\N	\N
18204	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16408	\N	\N	\N
18206	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16410	\N	\N	2014-09-28 13:09:05
18207	MEMBRE	2011-10-01 00:00:00	2012-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	16411	\N	\N	\N
18208	MEMBRE	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	16412	\N	\N	\N
18209	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16413	\N	\N	\N
18210	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16414	\N	\N	\N
18211	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16415	\N	\N	\N
18212	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16416	\N	\N	\N
18213	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16417	\N	\N	2014-08-06 16:34:54
18217	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16421	\N	\N	\N
18218	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16422	\N	\N	\N
18219	MEMBRE	2011-10-01 00:00:00	2013-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	16423	\N	\N	\N
18220	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16424	\N	\N	\N
18221	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16425	\N	\N	2014-09-28 14:31:42
18222	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16426	\N	\N	\N
18223	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16427	\N	\N	\N
18224	MEMBRE	2011-10-01 00:00:00	2013-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	16428	\N	\N	\N
18229	MEMBRE	2011-10-01 00:00:00	2013-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	16433	\N	\N	\N
20513	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18994	15	\N	\N
20514	VICPDT	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18995	7	\N	2014-09-29 13:41:53
20515	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18996	5	\N	\N
20516	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18997	3	\N	2014-09-28 18:00:58
20517	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18998	\N	\N	\N
20518	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18999	21	\N	\N
20519	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19091	\N	\N	2014-09-28 13:39:21
20520	MEMBRE	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19092	\N	\N	\N
20521	MEMBRE	2011-10-01 00:00:00	2014-05-11 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19093	\N	\N	\N
20522	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19094	27	\N	\N
20523	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19095	5	\N	\N
20524	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19096	\N	\N	2014-09-28 17:27:35
18629	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16832	\N	\N	\N
18630	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16833	\N	\N	\N
18631	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16834	\N	\N	\N
18632	MEMBRE	2011-10-01 00:00:00	2012-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	16835	\N	\N	\N
20658	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18519	10	\N	\N
18634	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16837	\N	\N	2014-09-28 12:56:42
20659	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18520	\N	\N	\N
18636	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16839	\N	\N	\N
18638	MEMBRE	2011-10-01 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	16841	\N	\N	\N
18639	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16842	\N	\N	\N
18640	MEMBRE	2011-10-01 00:00:00	2012-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	16843	\N	\N	\N
18662	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16865	\N	\N	\N
20660	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour la Tanzanie	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18521	6	\N	\N
20661	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18687	\N	\N	\N
20662	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18688	\N	\N	\N
20663	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18689	\N	\N	\N
20664	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18690	14	\N	\N
20665	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18691	\N	\N	\N
21170	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour l'Ouzbékistan	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19289	4	\N	2014-09-28 12:44:31
19086	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17271	\N	\N	\N
21171	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19290	\N	\N	2014-09-28 19:03:23
21172	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour le Tadjikistan	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19291	5	\N	\N
21173	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19292	5	\N	2014-09-28 13:40:33
21174	MEMBRE	2011-10-01 00:00:00	2013-02-06 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19293	\N	\N	\N
21175	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19294	\N	\N	\N
21176	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19295	\N	\N	\N
21177	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19296	\N	\N	2014-09-28 18:58:25
21178	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19297	\N	\N	\N
21179	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour le Turkménistan	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19298	6	\N	2014-09-28 13:39:21
21180	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19299	11	\N	\N
21349	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19336	7	\N	2014-09-28 18:03:38
21350	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19337	3	\N	2014-09-28 16:50:17
21351	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19338	4	\N	2014-09-28 13:16:32
21352	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19339	\N	\N	\N
21353	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19340	\N	\N	\N
21354	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19341	\N	\N	\N
21355	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19342	23	\N	\N
21356	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour le Mali	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19343	9	\N	\N
21357	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19509	\N	\N	2014-09-28 16:40:50
21358	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19510	\N	\N	\N
21359	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19511	9	\N	\N
21360	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19512	19	\N	\N
18679	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16882	\N	\N	\N
20830	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18746	\N	\N	\N
18681	MEMBRE	2011-10-01 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	16884	\N	\N	\N
20835	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18751	6	\N	\N
18683	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16886	\N	\N	2014-09-28 17:31:42
18684	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16887	\N	\N	\N
18685	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16888	\N	\N	2014-09-28 14:31:42
18686	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16889	\N	\N	\N
18687	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16890	\N	\N	\N
18688	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16891	\N	\N	\N
18689	MEMBRE	2011-10-01 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	16892	\N	\N	\N
20836	VICPDT	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18917	2	\N	2014-09-29 13:41:53
18691	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16894	\N	\N	\N
18692	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16895	\N	\N	\N
18693	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16896	\N	\N	\N
18694	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16897	\N	\N	\N
18695	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16898	\N	\N	\N
18696	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16899	\N	\N	\N
20831	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18747	1	\N	2014-09-28 16:50:17
20832	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18748	14	\N	\N
20833	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18749	\N	\N	2014-09-28 18:00:58
20834	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18750	\N	\N	2014-09-28 13:19:48
20994	PDTDEL	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	pour la Côte d'Ivoire	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19410	5	\N	2014-09-29 13:43:10
20995	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19411	\N	\N	\N
20996	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19412	\N	\N	\N
20997	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19413	30	\N	\N
20998	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19414	\N	\N	\N
20999	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19415	6	\N	\N
21000	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19416	9	\N	\N
21001	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19417	\N	\N	\N
21002	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19418	6	\N	\N
21003	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19419	\N	\N	\N
21004	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19420	\N	\N	\N
21005	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19586	\N	\N	\N
21181	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour la Guinée Conakry	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19465	6	\N	\N
21182	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19466	\N	\N	2014-09-29 09:08:33
19112	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17297	\N	\N	\N
19113	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17298	\N	\N	\N
19114	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17299	5	\N	\N
19115	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17300	4	\N	\N
19116	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17301	\N	\N	\N
19117	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17302	\N	\N	2014-09-28 17:03:42
19118	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17303	\N	\N	\N
19119	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17304	3	\N	2014-09-28 12:32:23
19120	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17305	\N	\N	\N
19121	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17306	\N	\N	\N
18984	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17169	\N	\N	\N
18985	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17170	\N	\N	2014-09-28 17:55:39
19293	MEMBRE	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17519	\N	\N	\N
19294	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17520	\N	\N	\N
19295	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17686	\N	\N	\N
19296	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17687	\N	\N	\N
19297	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17688	9	\N	\N
19298	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17689	\N	\N	\N
19299	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17690	\N	\N	\N
19300	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17691	23	\N	\N
19301	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17692	12	\N	\N
19302	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17693	22	\N	2014-09-28 16:50:17
19303	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17694	7	\N	\N
19476	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17374	\N	\N	2014-09-28 18:03:38
19477	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17375	\N	\N	\N
19478	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17376	10	\N	\N
19479	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17565	\N	\N	\N
19480	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17566	\N	\N	2014-09-28 17:15:42
19481	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17567	\N	\N	\N
19482	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17568	\N	\N	\N
19483	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17569	\N	\N	\N
19484	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17570	\N	\N	\N
19485	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17571	28	\N	2014-09-28 16:50:17
19486	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17572	6	\N	\N
19487	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17573	\N	\N	\N
19657	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17798	5	\N	\N
19658	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17799	8	\N	\N
19659	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17800	\N	\N	\N
19660	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17801	\N	\N	\N
19661	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17432	\N	\N	\N
19662	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17433	\N	\N	2014-09-28 12:56:42
19663	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17434	3	\N	\N
19664	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17435	\N	\N	2014-09-28 17:27:35
19665	PDTHON	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17436	2	\N	\N
19666	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17437	\N	\N	\N
19667	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17438	5	\N	\N
19668	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17439	6	\N	\N
19122	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17307	6	\N	2014-09-28 13:40:33
19123	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17308	12	\N	\N
19124	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17309	\N	\N	\N
19125	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17310	\N	\N	2014-09-28 13:21:47
21986	MEMBRE	2012-08-01 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	19973	\N	\N	\N
21987	MEMBRE	2012-08-01 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	19974	\N	\N	\N
21988	MEMBRE	2012-08-01 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	19975	\N	\N	\N
21989	MEMBRE	2012-08-01 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	19976	\N	\N	\N
21990	MEMBRE	2012-08-01 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	19977	\N	\N	\N
21991	MEMBRE	2012-08-01 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	19978	\N	\N	\N
21992	MEMBRE	2012-08-01 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	19979	\N	\N	\N
22049	MEMBRE	2012-10-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20034	\N	\N	\N
22106	MEMBRE	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20076	\N	\N	\N
22107	MEMBRE	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20077	\N	\N	\N
22113	SECRET	2012-12-19 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16375	\N	\N	\N
22227	MEMBRE	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20175	\N	2013-04-10 10:18:04	\N
21938	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19938	\N	\N	\N
21993	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19980	\N	\N	\N
22075	MEMBRE	2012-10-10 00:00:00	2012-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	20060	\N	\N	\N
22131	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20100	\N	\N	\N
22141	VICPDT	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20091	\N	\N	\N
22142	VICPDT	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20092	\N	\N	\N
21550	PDT	2012-02-08 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16550	\N	\N	\N
21551	PDT	2012-02-08 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16556	\N	\N	\N
21643	MEMBRE	2011-10-01 00:00:00	2012-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	19756	\N	\N	\N
21881	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19884	\N	\N	\N
21887	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19890	\N	\N	\N
21995	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19982	\N	\N	\N
21999	MEMBRE	2012-08-01 00:00:00	2014-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19986	\N	\N	2015-11-12 15:26:22
22000	MEMBRE	2012-08-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19987	\N	\N	2014-10-14 16:38:42
22091	PDT	2012-12-12 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20040	\N	\N	\N
22097	SECRET	2012-12-12 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19998	\N	\N	\N
22181	MEMBRE	2013-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20129	\N	\N	\N
22163	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20111	\N	\N	\N
22192	MEMBRE	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20140	\N	2013-03-26 11:35:29	\N
22193	MEMBRE	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20141	\N	2013-03-26 11:37:10	\N
22194	MEMBRE	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20142	\N	2013-03-26 11:39:18	\N
22195	MEMBRE	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20143	\N	2013-03-26 11:41:53	\N
22196	MEMBRE	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20144	\N	2013-03-26 11:44:17	2014-09-28 17:58:05
22197	MEMBRE	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20145	\N	2013-03-26 11:50:48	\N
22198	MEMBRE	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20146	\N	2013-03-26 11:52:20	\N
22199	MEMBRE	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20147	\N	2013-03-26 11:53:52	\N
22200	MEMBRE	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20148	\N	2013-03-26 11:55:14	2014-09-28 17:03:42
22201	MEMBRE	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20149	\N	2013-03-26 11:55:29	2014-09-28 18:00:58
22202	MEMBRE	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20150	\N	2013-03-26 11:55:44	2014-09-28 17:31:42
22203	MEMBRE	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20151	\N	2013-03-26 11:55:54	2014-09-28 12:52:11
22204	MEMBRE	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20152	\N	2013-03-26 11:56:57	2014-09-28 17:31:42
22205	MEMBRE	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20153	\N	2013-03-26 11:57:13	\N
22206	MEMBRE	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20154	\N	2013-03-26 11:57:47	\N
22207	MEMBRE	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20155	\N	2013-03-26 11:58:34	2014-09-28 16:59:41
22208	MEMBRE	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20156	\N	2013-03-26 11:58:41	\N
22209	MEMBRE	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20157	\N	2013-03-26 11:59:25	\N
21699	MEMBRE	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19785	\N	\N	\N
21703	MEMBRE	2011-10-01 00:00:00	2012-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	19789	\N	\N	\N
21708	VICPDT	2012-02-21 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19792	\N	\N	\N
21709	MEMBRE	2011-10-01 00:00:00	2012-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	19793	\N	\N	\N
21798	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19831	\N	\N	\N
21799	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19832	\N	\N	\N
21800	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19833	\N	\N	\N
21801	VICPDTPRE	2011-10-01 00:00:00	2014-05-11 00:00:00	ANCIEN	\N	\N	\N	\N	19834	2	\N	\N
21802	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19835	\N	\N	\N
21803	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19836	6	\N	\N
21804	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19837	\N	\N	\N
21831	MEMBRE	2011-10-01 00:00:00	2012-02-29 00:00:00	ANCIEN	\N	\N	\N	\N	19848	\N	\N	\N
21837	VICPDT	2012-02-21 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16847	\N	\N	\N
21840	VICPDT	2012-02-21 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16884	\N	\N	2014-09-28 12:39:09
21841	VICPDT	2012-02-21 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16892	\N	\N	\N
21842	SECRET	2012-02-21 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16841	\N	\N	2014-09-28 17:27:29
21843	SECRET	2012-02-21 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16927	\N	\N	\N
21854	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19860	\N	\N	\N
21859	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19865	\N	\N	\N
21860	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19866	\N	\N	\N
21930	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19933	\N	\N	\N
21933	MEMBRE	2012-07-13 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19936	\N	\N	2014-09-28 17:27:35
21979	MEMBRE	2011-10-01 00:00:00	2014-05-02 00:00:00	ANCIEN	\N	\N	\N	\N	19966	\N	\N	2014-08-06 16:33:35
21996	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19983	\N	\N	\N
21997	MEMBRE	2011-10-01 00:00:00	2012-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	19984	\N	\N	\N
22047	MEMBRE	2012-10-10 00:00:00	2012-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	20032	\N	\N	\N
22048	MEMBRE	2012-10-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20033	\N	\N	2014-09-28 12:44:31
22053	MEMBRE	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20038	\N	\N	\N
22054	MEMBRE	2012-10-01 00:00:00	2013-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	20039	\N	\N	\N
22083	MEMBRE	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20062	\N	\N	\N
22125	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20094	\N	\N	\N
22126	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20095	\N	\N	\N
21558	PDT	2012-02-08 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17077	\N	\N	\N
21559	PDT	2012-02-08 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16407	\N	\N	\N
21560	PDT	2012-02-08 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17050	\N	\N	\N
21577	VICPDT	2012-02-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16629	\N	\N	2014-09-28 17:40:23
21578	VICPDT	2012-02-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16835	\N	\N	2014-09-28 16:40:50
21738	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19821	\N	\N	2014-09-28 17:38:26
21805	PDT	2012-01-16 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17118	\N	\N	\N
21877	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19880	\N	\N	2014-09-28 12:44:31
21878	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19881	\N	\N	2014-09-28 12:44:31
22105	MEMBRE	2012-01-25 00:00:00	2014-05-11 00:00:00	ANCIEN	\N	\N	\N	\N	20075	\N	\N	\N
22127	MEMBRE	2011-10-01 00:00:00	2013-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	20096	\N	\N	\N
22217	MEMBRE	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20165	\N	2013-03-27 16:04:43	2014-09-28 16:40:50
22218	MEMBRE	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20166	\N	2013-03-29 12:17:23	2014-09-28 17:58:05
22219	MEMBRE	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20167	\N	2013-03-29 12:19:08	2014-09-28 17:58:05
22220	MEMBRE	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20168	\N	2013-03-29 12:19:54	2014-09-28 17:58:05
22221	MEMBRE	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20169	\N	2013-03-29 12:21:14	2014-09-28 17:58:05
22222	MEMBRE	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20170	\N	2013-03-29 12:21:47	2014-09-28 17:58:05
21566	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19711	\N	\N	\N
21685	VICPDT	2012-02-20 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16343	\N	\N	\N
21686	VICPDT	2012-02-20 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16335	\N	\N	2014-09-28 12:09:44
21696	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19782	\N	\N	\N
21698	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19784	\N	\N	\N
21704	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19790	\N	\N	2014-09-28 16:59:41
21838	VICPDT	2012-02-21 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16862	\N	\N	\N
18292	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16496	\N	\N	\N
21839	VICPDT	2012-02-21 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16919	\N	\N	2014-09-28 17:27:35
21890	MEMBRE	2012-06-28 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	19893	\N	\N	\N
21891	MEMBRE	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19894	\N	\N	\N
21892	MEMBRE	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19895	\N	\N	\N
21893	MEMBRE	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19896	\N	\N	\N
21894	MEMBRE	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19897	\N	\N	\N
21895	MEMBRE	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19898	\N	\N	\N
21910	MEMBRE	2012-07-13 00:00:00	2012-09-02 00:00:00	ANCIEN	\N	\N	\N	\N	19913	\N	\N	\N
22068	MEMBRE	2012-10-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20053	\N	\N	2014-09-28 17:00:59
22069	MEMBRE	2012-10-10 00:00:00	2012-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	20054	\N	\N	\N
22164	MEMBRE	2012-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20112	\N	\N	\N
22165	MEMBRE	2012-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20113	\N	\N	\N
22166	MEMBRE	2012-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20114	\N	\N	2014-09-28 12:56:42
22167	MEMBRE	2012-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20115	\N	\N	\N
22168	MEMBRE	2013-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20116	\N	\N	\N
22169	MEMBRE	2013-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20117	\N	\N	\N
22170	MEMBRE	2013-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20118	\N	\N	2014-09-28 17:38:26
22171	MEMBRE	2013-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20119	\N	\N	\N
22172	MEMBRE	2013-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20120	\N	\N	\N
22173	MEMBRE	2013-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20121	\N	\N	\N
22174	MEMBRE	2013-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20122	\N	\N	\N
22175	MEMBRE	2013-02-01 00:00:00	2014-05-11 00:00:00	ANCIEN	\N	\N	\N	\N	20123	\N	\N	\N
21637	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19749	\N	\N	\N
21638	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19750	\N	\N	\N
21639	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19751	\N	\N	\N
21640	MEMBRE	2011-10-01 00:00:00	2014-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19752	\N	\N	2015-11-12 15:26:22
21641	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19754	\N	\N	\N
21702	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19788	\N	\N	\N
21879	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19882	\N	\N	\N
21889	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19892	\N	\N	2014-09-28 17:27:35
20248	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17977	6	\N	\N
20249	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18143	3	\N	\N
20250	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18144	\N	\N	\N
20251	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18145	7	\N	\N
20252	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18146	4	\N	\N
20253	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18147	\N	\N	\N
20254	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18148	\N	\N	\N
20255	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18149	9	\N	2014-09-28 12:32:23
20256	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18150	6	\N	\N
20257	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18151	\N	\N	\N
20258	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18152	\N	\N	\N
20259	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18153	\N	\N	\N
18230	MEMBRE	2011-10-01 00:00:00	2013-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16434	\N	\N	\N
18231	MEMBRE	2011-10-01 00:00:00	2013-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	16435	\N	\N	\N
18232	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16436	\N	\N	\N
18235	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16439	\N	\N	\N
18236	MEMBRE	2011-10-01 00:00:00	2013-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	16440	\N	\N	\N
18238	MEMBRE	2011-10-01 00:00:00	2012-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	16442	\N	\N	\N
18254	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16458	\N	\N	2014-09-28 19:03:04
18255	MEMBRE	2011-10-01 00:00:00	2012-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	16459	\N	\N	\N
18256	MEMBRE	2011-10-01 00:00:00	2012-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	16460	\N	\N	\N
18257	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16461	\N	\N	2014-09-28 18:58:25
18258	MEMBRE	2011-10-01 00:00:00	2012-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	16462	\N	\N	\N
18259	MEMBRE	2011-10-01 00:00:00	2012-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	16463	\N	\N	\N
18260	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16464	\N	\N	\N
18261	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16465	\N	\N	\N
18262	MEMBRE	2011-10-01 00:00:00	2014-04-24 00:00:00	ANCIEN	\N	\N	\N	\N	16466	\N	\N	\N
18263	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16467	\N	\N	\N
18275	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16479	\N	\N	\N
18276	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16480	\N	\N	\N
18277	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16481	\N	\N	\N
18278	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16482	\N	\N	\N
18279	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16483	\N	\N	\N
18280	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16484	\N	\N	\N
18281	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16485	\N	\N	\N
18285	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16489	\N	\N	\N
18283	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16487	\N	\N	\N
18284	MEMBRE	2011-10-01 00:00:00	2012-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	16488	\N	\N	\N
18286	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16490	\N	\N	\N
18287	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16491	\N	\N	\N
18288	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16492	\N	\N	\N
18289	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16493	\N	\N	\N
18290	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16494	\N	\N	\N
18293	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16497	\N	\N	2014-09-28 13:16:32
18294	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16498	\N	\N	\N
18299	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16503	\N	\N	\N
18301	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16505	\N	\N	\N
18303	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16507	\N	\N	\N
18304	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16508	\N	\N	\N
18145	MEMBRE	2011-10-01 00:00:00	2012-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	16349	\N	\N	\N
18146	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16350	\N	\N	\N
18148	MEMBRE	2011-10-01 00:00:00	2012-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	16352	\N	\N	\N
18149	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16353	\N	\N	\N
18251	MEMBRE	2011-10-01 00:00:00	2012-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	16455	\N	\N	\N
18252	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16456	\N	\N	\N
18253	MEMBRE	2011-10-01 00:00:00	2012-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	16457	\N	\N	\N
18308	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16512	\N	\N	\N
18328	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16532	\N	\N	2014-09-28 17:40:23
18330	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16534	\N	\N	2014-09-28 17:34:16
18452	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16655	\N	\N	\N
18453	MEMBRE	2011-10-01 00:00:00	2012-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	16656	\N	\N	\N
18454	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16657	\N	\N	\N
18460	MEMBRE	2011-10-01 00:00:00	2012-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	16663	\N	\N	\N
18616	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16819	\N	\N	\N
18473	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16676	\N	\N	\N
18477	MEMBRE	2011-10-01 00:00:00	2012-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	16680	\N	\N	\N
18479	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16682	\N	\N	\N
18480	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16683	\N	\N	2014-09-28 14:31:42
18886	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17089	\N	\N	\N
18508	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16711	\N	\N	\N
18512	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16715	\N	\N	\N
18524	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16727	\N	\N	2014-09-28 17:03:42
18525	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16728	\N	\N	2014-09-28 14:31:42
18887	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17090	\N	\N	\N
18527	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16730	\N	\N	\N
18888	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17091	\N	\N	\N
18889	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17092	\N	\N	\N
21813	MEMBRE	2012-02-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19839	\N	\N	2014-09-28 16:50:17
18895	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17098	\N	\N	\N
18909	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17112	\N	\N	\N
18911	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17114	\N	\N	\N
21521	MEMBRE	2011-05-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19692	\N	\N	2014-09-28 19:03:23
20666	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18692	9	\N	\N
20667	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18693	4	\N	2014-09-28 12:09:44
20668	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18694	\N	\N	\N
20669	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18695	\N	\N	2014-09-28 17:22:11
20670	VICPDT	2011-10-01 00:00:00	2014-10-03 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18696	8	\N	\N
20671	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18697	15	\N	2014-09-28 17:27:29
20672	MEMBRE	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18862	\N	\N	2014-09-29 13:43:10
20673	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18863	\N	\N	2014-09-28 18:03:38
20674	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18864	\N	\N	2014-09-28 13:39:21
20675	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18865	\N	\N	\N
20676	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18866	8	\N	2014-09-28 17:27:35
20677	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18867	\N	\N	\N
20260	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18401	\N	\N	\N
20261	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18402	9	\N	\N
21183	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19467	\N	\N	\N
21184	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19468	16	\N	2014-09-28 19:03:23
21185	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19469	18	\N	\N
21186	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19470	\N	\N	\N
21187	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour le Cameroun	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19471	3	\N	\N
21188	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19472	\N	\N	2014-09-28 17:22:11
21189	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19473	22	\N	\N
21712	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19795	\N	\N	\N
21190	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour le Niger	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19474	10	\N	2014-09-28 17:34:16
21191	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour la Gambie	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19475	17	\N	2014-09-28 19:07:43
21192	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19641	\N	\N	\N
18234	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16438	\N	\N	2014-09-28 17:40:23
18239	MEMBRE	2011-10-01 00:00:00	2013-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	16443	\N	\N	\N
18240	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16444	\N	\N	\N
18243	MEMBRE	2011-10-01 00:00:00	2013-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	16447	\N	\N	\N
18264	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16468	\N	\N	\N
18265	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16469	\N	\N	2014-09-28 17:35:38
18266	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16470	\N	\N	2014-09-28 19:03:23
18267	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16471	\N	\N	2014-09-28 16:42:05
18268	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16472	\N	\N	\N
18269	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16473	\N	\N	\N
18270	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16474	\N	\N	\N
18271	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16475	\N	\N	2014-09-28 17:40:23
18272	MEMBRE	2011-10-01 00:00:00	2012-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	16476	\N	\N	\N
18273	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16477	\N	\N	\N
18274	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16478	\N	\N	\N
19022	MEMBRE	2011-12-14 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17207	\N	\N	2014-09-28 13:39:21
19024	MEMBRE	2011-12-14 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17209	\N	\N	\N
18297	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16501	\N	\N	\N
18298	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16502	\N	\N	2014-09-28 14:31:42
18326	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16530	\N	\N	\N
18482	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16685	\N	\N	\N
19036	MEMBRE	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17221	\N	\N	2014-09-28 12:44:31
18485	MEMBRE	2011-10-01 00:00:00	2012-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	16688	\N	\N	\N
18824	MEMBRE	2011-10-01 00:00:00	2013-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17027	\N	\N	\N
19037	MEMBRE	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17222	\N	\N	2014-09-28 17:03:42
21361	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour le Burundi	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19513	2	\N	\N
21362	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19514	\N	\N	2014-09-28 16:42:05
21363	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19515	\N	\N	2014-09-28 16:59:41
20837	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18918	\N	\N	\N
20838	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18919	\N	\N	\N
20839	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18920	5	\N	\N
20840	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18921	\N	\N	\N
20841	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18922	\N	\N	\N
20842	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18923	\N	\N	2014-09-28 16:42:05
20843	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18924	6	\N	2014-09-28 13:40:33
20844	PDTDEL	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	pour le Koweït	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18925	5	\N	\N
20845	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18926	\N	\N	\N
20846	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18927	7	\N	2014-09-29 09:08:33
20847	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18577	\N	\N	2014-09-28 17:40:23
20848	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18578	\N	\N	\N
21006	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19587	\N	\N	2014-09-28 12:32:23
21007	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19588	9	\N	2014-09-28 13:40:33
21008	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19589	\N	\N	\N
21009	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19590	3	\N	2014-09-28 17:55:39
21010	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19591	5	\N	2014-09-28 13:39:21
21011	MEMBRE	2011-10-01 00:00:00	2012-06-16 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19592	\N	\N	\N
21012	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19593	12	\N	\N
21013	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19594	\N	\N	\N
21014	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19595	\N	\N	\N
21015	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19596	\N	\N	\N
21016	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19245	\N	\N	2014-09-28 12:56:42
21017	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19246	\N	\N	2014-09-28 13:39:21
18650	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16853	\N	\N	\N
18651	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16854	\N	\N	2014-09-28 17:31:42
18652	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16855	\N	\N	\N
18653	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16856	\N	\N	\N
21193	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19642	\N	\N	\N
21194	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19643	\N	\N	2014-09-28 17:27:35
19126	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17311	\N	\N	2014-09-28 13:21:47
19127	PDTHON	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17312	2	\N	2014-09-28 16:59:41
19128	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17313	\N	\N	\N
21611	MEMBRE	2011-10-01 00:00:00	2012-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	19743	\N	\N	\N
19130	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17315	8	\N	2014-09-28 16:50:17
19131	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17316	\N	\N	\N
19132	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17317	\N	\N	\N
19133	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17318	\N	\N	2014-09-28 17:09:16
21621	VICPDT	2012-02-09 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16393	\N	\N	\N
21622	VICPDT	2012-02-08 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16946	\N	\N	\N
19304	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17695	\N	\N	2014-09-28 17:03:42
19305	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17696	20	\N	\N
19306	MEMBRE	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17868	\N	\N	\N
19307	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17869	\N	\N	2014-09-28 19:03:23
19308	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17870	9	\N	\N
19309	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17871	7	\N	\N
19310	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17872	\N	\N	\N
19311	MEMBRE	2011-10-01 00:00:00	2014-05-11 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17873	\N	\N	\N
19312	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17874	\N	\N	\N
19313	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17875	\N	\N	\N
19314	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17876	10	\N	\N
19315	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17877	\N	\N	\N
18732	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16935	\N	\N	\N
18743	MEMBRE	2011-10-01 00:00:00	2012-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	16946	\N	\N	\N
18969	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17154	\N	\N	\N
18970	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17155	\N	\N	2014-09-28 17:55:39
18971	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17156	\N	\N	\N
19488	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17574	21	\N	2014-09-28 18:00:58
19489	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17575	\N	\N	\N
19490	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17741	10	\N	\N
19491	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour la Bolivie	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17742	4	\N	\N
19492	VICPDT	2011-10-01 00:00:00	2014-10-05 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17743	3	\N	2014-09-28 13:39:21
19493	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17744	\N	\N	\N
19494	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17745	\N	\N	\N
19495	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17746	\N	\N	\N
19496	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17377	\N	\N	2014-09-28 13:39:21
19497	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17378	4	\N	\N
18642	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16845	\N	\N	2014-09-28 14:31:42
18648	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16851	\N	\N	\N
18649	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16852	\N	\N	\N
18660	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16863	\N	\N	\N
19669	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17440	4	\N	\N
19670	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17441	8	\N	\N
19671	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17442	1	\N	\N
18665	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16868	\N	\N	\N
18666	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16869	\N	\N	\N
19672	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17631	\N	\N	2014-09-28 13:21:47
19673	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17632	\N	\N	2014-09-28 13:21:47
18670	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16873	\N	\N	\N
18671	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16874	\N	\N	2014-09-28 13:19:48
18672	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16875	\N	\N	\N
19674	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17633	3	\N	\N
18674	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16877	\N	\N	\N
19675	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17634	\N	\N	\N
18676	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16879	\N	\N	\N
18678	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16881	\N	\N	\N
18710	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16913	\N	\N	\N
18711	MEMBRE	2011-10-01 00:00:00	2012-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	16914	\N	\N	\N
19134	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17319	\N	\N	2014-09-28 13:39:21
19135	MEMBRE	2011-10-01 00:00:00	2014-04-24 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17320	\N	\N	\N
19136	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17321	\N	\N	\N
19137	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17322	\N	\N	\N
19138	MEMBRE	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17323	\N	\N	2014-09-29 13:43:10
19139	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17324	\N	\N	\N
22007	MEMBRE	2011-10-01 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	19994	\N	\N	\N
22108	MEMBRE	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20078	\N	\N	2014-09-28 17:38:26
22109	MEMBRE	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20079	\N	\N	\N
22110	MEMBRE	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20080	\N	\N	\N
22111	MEMBRE	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20081	\N	\N	\N
22210	MEMBRE	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20158	\N	2013-03-26 11:59:44	\N
22211	MEMBRE	2013-03-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	20159	\N	2013-03-26 12:00:17	2014-09-29 13:43:10
22212	MEMBRE	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20160	\N	2013-03-26 12:00:43	\N
22213	MEMBRE	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20161	\N	2013-03-26 12:01:05	\N
22214	MEMBRE	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20162	\N	2013-03-26 12:01:32	2014-09-28 17:09:16
22215	MEMBRE	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20163	\N	2013-03-26 12:01:51	\N
22216	MEMBRE	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20164	\N	2013-03-26 12:13:09	\N
21569	MEMBRE	2011-12-14 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19714	\N	\N	\N
21888	MEMBRE	2011-10-01 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	19891	\N	\N	\N
21896	MEMBRE	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19899	\N	\N	2014-09-28 17:27:35
22098	SECRET	2012-12-12 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20054	\N	\N	\N
22159	SECRET	2013-01-14 00:00:00	2013-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	20084	\N	\N	\N
22177	MEMBRE	2013-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20125	\N	\N	\N
22178	MEMBRE	2013-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20126	\N	\N	\N
22179	MEMBRE	2013-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20127	\N	\N	\N
22190	MEMBRE	2013-02-13 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20138	\N	\N	2014-09-28 17:58:05
22232	MEMBRE	2012-10-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20180	\N	\N	\N
21670	VICPDT	2012-02-16 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17180	\N	\N	\N
21763	MEMBRE	2011-10-01 00:00:00	2014-05-11 00:00:00	ANCIEN	\N	\N	\N	\N	19828	\N	\N	\N
21774	VICPDT	2012-02-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16679	\N	\N	2014-09-28 17:31:42
22099	MEMBRE	2012-10-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20070	\N	\N	\N
22032	MEMBRE	2012-10-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20018	\N	\N	2014-09-28 14:31:42
21568	MEMBRE	2011-10-01 00:00:00	2012-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	19713	\N	\N	\N
21583	MEMBRE	2011-10-01 00:00:00	2012-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	19721	\N	\N	\N
21852	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19858	4	\N	\N
22005	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19992	\N	\N	\N
22092	VICPDT	2012-12-12 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20017	\N	\N	\N
22093	VICPDT	2012-12-12 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20032	\N	\N	\N
22094	VICPDT	2012-12-12 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20045	\N	\N	\N
22095	SECRET	2012-12-12 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20044	\N	\N	\N
22096	SECRET	2012-12-12 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20060	\N	\N	2014-09-28 17:38:26
21585	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19722	\N	\N	\N
21773	VICPDT	2012-02-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19713	\N	\N	2014-09-28 17:38:26
21778	SECRET	2012-02-23 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17087	\N	\N	\N
21780	SECRET	2012-02-23 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17067	\N	\N	\N
21781	SECRET	2012-02-23 00:00:00	2014-05-02 00:00:00	ANCIEN	\N	\N	\N	\N	17068	\N	\N	\N
21782	SECRET	2012-02-23 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16663	\N	\N	\N
22074	MEMBRE	2012-10-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20059	\N	\N	\N
22189	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20137	\N	\N	2014-09-28 17:58:05
21675	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19771	\N	\N	2014-09-28 17:40:23
21707	MEMBRE	2011-10-01 00:00:00	2012-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	19792	\N	\N	\N
21711	MEMBRE	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19794	\N	\N	\N
21736	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19819	\N	\N	2014-09-28 17:38:26
21772	VICPDT	2012-02-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16654	\N	\N	2014-09-28 17:07:07
22080	VICPDT	2012-11-27 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19949	\N	\N	2014-09-28 16:42:05
22081	VICPDT	2012-11-27 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19944	\N	\N	\N
22231	MEMBRE	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20179	\N	2013-05-15 10:44:33	\N
21717	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19800	\N	\N	2014-09-28 12:44:31
22078	VICPDT	2012-11-27 00:00:00	2013-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	19947	\N	\N	\N
21695	MEMBRE	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19781	\N	\N	\N
21700	MEMBRE	2011-10-01 00:00:00	2012-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	19786	\N	\N	\N
21701	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19787	\N	\N	2014-09-28 17:27:35
21723	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19806	\N	\N	\N
21753	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19822	3	\N	\N
21754	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19823	\N	\N	\N
21755	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19824	\N	\N	2014-09-28 12:39:09
21756	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19825	\N	\N	\N
21757	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19826	\N	\N	2014-09-28 17:07:41
21876	MEMBRE	2012-02-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	19879	\N	\N	\N
21680	MEMBRE	2011-10-01 00:00:00	2013-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	19776	\N	\N	\N
21710	SECRET	2012-02-21 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19793	\N	\N	2014-09-28 17:38:26
21718	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19801	\N	\N	\N
21719	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19802	\N	\N	\N
21720	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19803	\N	\N	2014-09-28 19:03:23
21721	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19804	\N	\N	\N
21722	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19805	\N	\N	\N
21745	SECRET	2012-02-22 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16455	\N	\N	\N
21747	VICPDT	2012-02-22 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16930	\N	\N	\N
21748	VICPDT	2012-02-22 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19789	\N	\N	\N
21749	VICPDT	2012-02-22 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16476	\N	\N	\N
21750	VICPDT	2012-02-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19796	\N	\N	2014-09-28 17:38:26
22234	MEMBRE	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20182	\N	2013-06-11 17:52:04	\N
22254	MEMBRE	2013-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20201	\N	2013-08-14 09:24:01	2014-09-28 16:50:17
20262	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18403	10	\N	2014-09-28 12:09:44
20263	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18404	\N	\N	\N
20264	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18405	\N	\N	\N
20265	MEMBRE	2011-10-01 00:00:00	2014-10-03 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18406	\N	\N	\N
20266	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18407	\N	\N	\N
20267	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18408	\N	\N	2014-09-28 12:32:23
20268	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18409	\N	\N	\N
20269	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18410	\N	\N	2014-09-28 12:32:23
20270	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18411	\N	\N	\N
20271	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17978	\N	\N	\N
18305	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16509	\N	\N	2014-09-28 17:00:59
18314	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16518	\N	\N	2014-09-28 16:50:17
18315	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16519	\N	\N	\N
18316	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16520	\N	\N	2014-09-28 17:40:23
18317	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16521	\N	\N	\N
18319	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16523	\N	\N	\N
18320	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16524	\N	\N	\N
18322	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16526	\N	\N	\N
18323	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16527	\N	\N	2014-09-28 13:39:21
18333	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16537	\N	\N	2014-09-28 13:39:21
18334	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16538	\N	\N	2014-09-28 16:59:41
18335	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16539	\N	\N	\N
18336	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16540	\N	\N	\N
18337	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16541	\N	\N	2014-09-28 13:09:05
18339	MEMBRE	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	16543	\N	\N	2014-09-29 13:43:10
18340	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16544	\N	\N	\N
18343	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16547	\N	\N	\N
18344	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16548	\N	\N	\N
18345	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16549	\N	\N	\N
18346	MEMBRE	2011-10-01 00:00:00	2012-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	16550	\N	\N	\N
18347	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16551	\N	\N	2014-09-28 17:31:42
18348	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16552	\N	\N	\N
18350	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16554	\N	\N	\N
18351	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16555	\N	\N	\N
18352	MEMBRE	2011-10-01 00:00:00	2012-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	16556	\N	\N	\N
18353	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16557	\N	\N	\N
18354	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16558	\N	\N	\N
18355	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16559	\N	\N	\N
18357	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16561	\N	\N	\N
18358	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16562	\N	\N	\N
18359	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16563	\N	\N	2014-09-28 18:03:38
18360	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16564	\N	\N	\N
18361	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16565	\N	\N	\N
18362	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16566	\N	\N	\N
18363	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16567	\N	\N	2014-09-28 12:44:31
18912	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17115	\N	\N	\N
18939	MEMBRE	2011-12-14 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17133	\N	\N	\N
18914	MEMBRE	2011-10-01 00:00:00	2012-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	17117	\N	\N	\N
21820	VICPDT	2012-02-28 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17095	\N	\N	\N
18940	MEMBRE	2011-12-14 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17134	\N	\N	\N
18917	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17120	\N	\N	2014-09-28 17:38:26
18918	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17121	\N	\N	\N
18919	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17122	\N	\N	\N
18922	MEMBRE	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	17125	\N	\N	2014-09-29 13:43:10
18942	MEMBRE	2011-12-14 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17136	\N	\N	\N
18943	MEMBRE	2011-12-14 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17137	\N	\N	\N
18944	MEMBRE	2011-12-14 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17138	\N	\N	2014-09-28 13:19:48
18945	MEMBRE	2011-12-14 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17139	\N	\N	\N
18931	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17127	\N	\N	\N
18946	MEMBRE	2011-12-14 00:00:00	2014-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	17140	\N	\N	\N
18933	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17113	\N	\N	\N
18957	VICPDT	2012-01-26 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16495	\N	\N	\N
18935	SECRET	2011-10-01 00:00:00	2014-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	17129	\N	\N	\N
21814	MEMBRE	2012-02-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19840	\N	\N	2014-09-28 17:27:35
21815	MEMBRE	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19841	\N	\N	\N
18980	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17165	\N	\N	\N
20525	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19097	3	\N	\N
20526	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19098	\N	\N	\N
20527	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19099	20	\N	\N
20528	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19100	6	\N	\N
18989	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17174	\N	\N	\N
20678	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18868	\N	\N	2014-09-28 17:09:16
20679	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18869	10	\N	\N
20680	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18870	5	\N	\N
20681	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18871	\N	\N	\N
20682	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18872	\N	\N	\N
20683	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour l'Ile Maurice	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18522	4	\N	\N
20684	VICPDT	2011-10-01 00:00:00	2014-10-03 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18523	3	\N	\N
20685	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18524	\N	\N	2014-09-28 19:03:23
20686	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18525	3	\N	2014-09-28 13:40:33
20687	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18526	\N	\N	\N
20688	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18527	\N	\N	\N
20272	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17979	\N	\N	\N
20273	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17980	\N	\N	\N
20274	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17981	8	\N	\N
20275	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17982	\N	\N	\N
21195	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19644	\N	\N	2014-09-28 17:27:35
21196	MEMBRE	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19645	\N	\N	2014-09-29 13:43:10
21197	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19646	5	\N	\N
21198	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19647	7	\N	\N
21199	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19648	\N	\N	2014-09-28 17:31:42
21200	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19649	\N	\N	\N
21201	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19650	8	\N	2014-09-28 17:55:39
21202	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour la Serbie	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19651	6	\N	2014-09-28 17:31:42
21364	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19516	\N	\N	\N
21365	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19517	\N	\N	\N
21366	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19518	\N	\N	\N
21367	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19519	\N	\N	\N
21368	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19685	\N	\N	\N
21369	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19686	1	\N	2014-09-28 13:40:33
21370	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19687	\N	\N	\N
21371	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19688	\N	\N	2014-09-28 16:59:41
21372	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19689	1	\N	\N
21373	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19179	13	\N	\N
21374	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19180	7	\N	\N
21375	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19181	\N	\N	\N
18167	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16371	\N	\N	2014-09-28 17:40:23
18215	MEMBRE	2011-10-01 00:00:00	2013-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	16419	\N	\N	\N
18216	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16420	\N	\N	2014-09-28 16:50:17
18228	MEMBRE	2011-10-01 00:00:00	2013-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	16432	\N	\N	\N
18309	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16513	\N	\N	\N
18310	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16514	\N	\N	\N
18341	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16545	\N	\N	\N
18386	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16589	\N	\N	2014-09-28 17:03:42
18374	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16578	\N	\N	2014-09-28 17:40:23
18376	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16579	\N	\N	\N
18387	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16590	\N	\N	2014-09-28 13:21:47
18388	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16591	\N	\N	2014-09-28 17:22:11
18396	MEMBRE	2011-10-01 00:00:00	2012-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	16599	\N	\N	\N
18397	MEMBRE	2011-10-01 00:00:00	2013-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	16600	\N	\N	\N
18398	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16601	\N	\N	\N
18399	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16602	\N	\N	\N
18961	SECRET	2012-01-26 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16928	\N	\N	\N
18401	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16604	\N	\N	\N
18402	MEMBRE	2011-10-01 00:00:00	2012-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	16605	\N	\N	\N
18403	MEMBRE	2011-10-01 00:00:00	2012-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	16606	\N	\N	\N
18404	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16607	\N	\N	\N
18405	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16608	\N	\N	\N
18422	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16625	\N	\N	\N
18423	MEMBRE	2011-10-01 00:00:00	2012-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	16626	\N	\N	\N
18424	MEMBRE	2011-10-01 00:00:00	2012-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	16627	\N	\N	\N
18425	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16628	\N	\N	\N
18426	MEMBRE	2011-10-01 00:00:00	2012-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	16629	\N	\N	\N
18504	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16707	\N	\N	2014-09-28 13:19:48
18955	VICPDT	2012-01-26 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16454	\N	\N	\N
18572	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16775	\N	\N	\N
18956	VICPDT	2012-01-26 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16504	\N	\N	\N
18994	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17179	\N	\N	\N
19055	MEMBRE	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17240	\N	\N	2014-09-28 19:03:23
19080	MEMBRE	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17265	\N	\N	2014-09-28 18:03:38
19081	MEMBRE	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17266	\N	\N	\N
19090	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17275	\N	\N	\N
21018	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19247	\N	\N	\N
21019	MEMBRE	2011-10-01 00:00:00	2014-02-28 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19248	\N	\N	2013-04-09 11:49:35
21020	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19249	\N	\N	2014-09-28 16:50:17
21021	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19250	\N	\N	\N
21022	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19251	\N	\N	2014-09-28 18:00:58
21023	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19252	\N	\N	2014-09-28 18:00:58
21024	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19253	16	\N	\N
21025	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19254	\N	\N	\N
21026	VICPDT	2011-10-01 00:00:00	2014-10-03 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19255	8	\N	2015-11-12 15:26:22
21027	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19421	\N	\N	\N
21028	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19422	\N	\N	\N
21029	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19423	\N	\N	2014-09-28 19:03:04
18560	MEMBRE	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	16763	\N	\N	\N
21203	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19135	\N	\N	2014-09-28 17:52:18
21204	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19136	7	\N	\N
21205	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19137	\N	\N	\N
21206	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19138	4	\N	2014-09-28 17:22:11
21207	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19139	\N	\N	\N
21208	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19140	\N	\N	2014-09-28 17:34:16
19140	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17325	1	\N	\N
19141	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17326	\N	\N	\N
19142	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17327	\N	\N	\N
19143	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17328	\N	\N	2014-09-28 16:50:17
19144	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17329	11	\N	2014-09-28 17:38:26
19145	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17330	7	\N	\N
19316	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17878	\N	\N	2014-09-28 17:09:16
19317	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17484	\N	\N	\N
19318	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17485	\N	\N	\N
19319	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17486	5	\N	\N
19320	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17487	7	\N	\N
19321	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17488	\N	\N	2014-09-28 17:27:35
19322	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17489	\N	\N	\N
19323	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17490	3	\N	2014-09-28 18:00:58
19324	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17491	6	\N	\N
19325	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17492	1	\N	\N
19326	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17493	2	\N	\N
19327	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17494	4	\N	\N
19498	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17379	7	\N	\N
19499	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17380	\N	\N	\N
19500	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17381	\N	\N	\N
19501	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17382	9	\N	2014-09-28 16:50:17
19502	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17383	12	\N	\N
19503	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17384	\N	\N	2014-09-28 18:00:58
19504	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17385	8	\N	\N
19505	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17386	\N	\N	\N
19506	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17387	6	\N	\N
19507	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17576	\N	\N	\N
19508	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17577	\N	\N	\N
19509	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17578	\N	\N	\N
18498	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16701	\N	\N	\N
18752	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16955	\N	\N	2014-09-28 17:22:11
18500	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16703	\N	\N	\N
18753	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16956	\N	\N	\N
18502	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16705	\N	\N	2014-09-28 16:59:41
18503	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16706	\N	\N	2014-09-28 16:59:41
18506	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16709	\N	\N	2014-09-28 12:44:31
18507	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16710	\N	\N	\N
18509	MEMBRE	2011-10-01 00:00:00	2012-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	16712	\N	\N	\N
18759	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16962	\N	\N	\N
18561	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16764	\N	\N	2014-09-28 17:52:18
18775	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16978	\N	\N	2014-09-28 17:31:42
18776	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16979	\N	\N	\N
18778	MEMBRE	2011-10-01 00:00:00	2014-04-24 00:00:00	ANCIEN	\N	\N	\N	\N	16981	\N	\N	\N
18569	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16772	\N	\N	2014-09-28 19:03:04
18570	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16773	\N	\N	\N
18574	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16777	\N	\N	2014-09-28 17:07:07
18783	MEMBRE	2011-10-01 00:00:00	2012-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	16986	\N	\N	\N
18784	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16987	\N	\N	\N
18577	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16780	\N	\N	2014-09-28 17:07:41
18578	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16781	\N	\N	2014-09-28 17:07:41
18579	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16782	\N	\N	\N
18785	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16988	\N	\N	\N
18786	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16989	\N	\N	\N
18787	MEMBRE	2011-10-01 00:00:00	2012-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	16990	\N	\N	\N
18813	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17016	\N	\N	2014-09-28 16:59:41
18587	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16790	\N	\N	2014-09-28 16:40:50
19676	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17635	14	\N	\N
19677	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17636	\N	\N	2014-09-28 13:21:47
18595	MEMBRE	2011-10-01 00:00:00	2012-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	16798	\N	\N	\N
19146	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17331	\N	\N	2014-09-28 17:03:42
19147	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17332	\N	\N	\N
19148	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17813	\N	\N	\N
19149	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17814	\N	\N	\N
19150	MEMBRE	2011-10-01 00:00:00	2014-10-03 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17815	\N	\N	\N
19151	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17816	\N	\N	\N
19153	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17818	\N	\N	\N
19154	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17819	\N	\N	\N
20276	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17983	\N	\N	\N
20277	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17984	\N	\N	\N
20278	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17985	\N	\N	\N
20279	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17986	\N	\N	\N
20280	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17987	\N	\N	\N
20281	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17988	\N	\N	\N
20282	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18154	14	\N	2014-09-28 17:52:18
20283	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18155	\N	\N	\N
18366	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16570	\N	\N	\N
18367	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16571	\N	\N	\N
18368	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16572	\N	\N	\N
18369	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16573	\N	\N	\N
18370	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16574	\N	\N	\N
18382	MEMBRE	2011-10-01 00:00:00	2012-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	16585	\N	\N	\N
18372	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16576	\N	\N	2014-09-28 19:03:23
18383	MEMBRE	2011-10-01 00:00:00	2012-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	16586	\N	\N	\N
18384	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16587	\N	\N	\N
18392	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16595	\N	\N	2014-09-28 17:00:59
18393	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16596	\N	\N	2014-09-28 16:50:17
18394	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16597	\N	\N	\N
18395	MEMBRE	2011-10-01 00:00:00	2012-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	16598	\N	\N	\N
18406	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16609	\N	\N	\N
18407	MEMBRE	2011-10-01 00:00:00	2013-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	16610	\N	\N	\N
18408	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16611	\N	\N	\N
18409	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16612	\N	\N	\N
18410	MEMBRE	2011-10-01 00:00:00	2012-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	16613	\N	\N	\N
18411	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16614	\N	\N	\N
18412	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16615	\N	\N	\N
18413	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16616	\N	\N	2015-01-08 17:14:29
18414	MEMBRE	2011-10-01 00:00:00	2012-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	16617	\N	\N	\N
18415	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16618	\N	\N	2014-09-28 18:03:38
18416	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16619	\N	\N	2014-09-28 12:44:31
18417	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16620	\N	\N	\N
18418	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16621	\N	\N	2014-09-28 19:03:23
18419	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16622	\N	\N	\N
18420	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16623	\N	\N	2014-09-28 16:59:41
18365	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16569	\N	\N	\N
18421	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16624	\N	\N	\N
18427	MEMBRE	2011-10-01 00:00:00	2012-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	16630	\N	\N	\N
18428	MEMBRE	2011-10-01 00:00:00	2012-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	16631	\N	\N	\N
18429	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16632	\N	\N	\N
18430	MEMBRE	2011-10-01 00:00:00	2012-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	16633	\N	\N	\N
18431	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16634	\N	\N	2014-09-29 09:05:47
18432	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16635	\N	\N	\N
20529	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19101	22	\N	\N
20530	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18654	\N	\N	\N
20531	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18655	9	\N	\N
20532	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18656	\N	\N	2014-09-28 13:16:32
20533	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18657	\N	\N	2014-09-28 17:09:16
20534	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18658	\N	\N	2014-09-28 17:27:35
20535	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18659	\N	\N	\N
20536	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18660	\N	\N	\N
20537	MEMBRE	2011-10-01 00:00:00	2013-06-27 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18661	\N	\N	\N
20538	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18662	1	\N	\N
20539	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18663	3	\N	\N
20540	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18664	\N	\N	2014-09-28 13:16:32
18706	MEMBRE	2011-10-01 00:00:00	2012-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	16909	\N	\N	\N
18707	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16910	\N	\N	\N
20689	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18528	\N	\N	\N
20690	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18529	\N	\N	\N
20691	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18530	\N	\N	\N
20692	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18531	\N	\N	2014-09-28 16:40:50
20693	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18532	\N	\N	\N
20694	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18698	\N	\N	2014-09-28 17:03:42
20695	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18699	\N	\N	\N
20696	VICPDT	2011-10-01 00:00:00	2014-10-03 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18700	4	\N	2015-11-12 15:26:22
20697	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18701	\N	\N	\N
20698	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18702	\N	\N	\N
20699	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18703	10	\N	\N
18377	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16580	\N	\N	\N
20289	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18161	11	\N	2014-09-28 16:40:50
18456	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16659	\N	\N	2014-09-28 16:50:17
20290	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18162	2	\N	2014-09-28 17:55:39
20284	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18156	\N	\N	\N
20285	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18157	\N	\N	\N
20286	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18158	\N	\N	\N
20287	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18159	\N	\N	\N
21209	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19141	3	\N	2014-09-28 17:03:42
21210	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19142	\N	\N	\N
21211	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19143	\N	\N	\N
21212	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19144	\N	\N	\N
21213	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19145	6	\N	\N
21214	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19300	17	\N	\N
21376	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19182	5	\N	\N
21377	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19183	\N	\N	2014-09-28 13:40:33
21378	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19184	\N	\N	\N
21379	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19185	\N	\N	\N
21380	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19186	\N	\N	2014-09-28 16:50:17
21381	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19187	\N	\N	\N
21382	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19188	5	\N	2014-09-28 18:00:58
21383	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19189	6	\N	2014-09-28 17:03:42
21384	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19344	\N	\N	\N
21385	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19345	\N	\N	\N
21386	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19346	3	\N	2014-09-28 17:03:42
21387	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19347	\N	\N	2014-09-28 13:21:47
18698	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16901	\N	\N	\N
18700	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16903	\N	\N	2014-09-28 18:03:38
20849	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18579	16	\N	\N
20850	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18580	\N	\N	\N
20851	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18581	\N	\N	\N
20852	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18582	\N	\N	\N
20853	MEMBRE	2011-10-01 00:00:00	2012-06-16 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18583	\N	\N	\N
20854	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18584	9	\N	\N
20855	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18585	5	\N	2014-09-28 17:55:39
20856	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18586	3	\N	\N
20857	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18587	6	\N	2014-09-28 12:09:44
20858	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18752	7	\N	\N
20859	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18753	\N	\N	\N
18324	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16528	\N	\N	\N
18891	MEMBRE	2011-10-01 00:00:00	2013-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	17094	\N	\N	\N
18963	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17148	\N	\N	\N
21030	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19424	15	\N	\N
21031	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19425	\N	\N	\N
21032	VICPDTDRT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19426	13	\N	\N
21033	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour l'Ouganda	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19427	6	\N	\N
21034	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19428	14	\N	\N
21035	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour le Libéria	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19429	13	\N	\N
21036	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19430	\N	\N	\N
21037	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19431	\N	\N	\N
21038	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19597	2	\N	2014-09-28 17:27:35
21039	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19598	\N	\N	\N
21215	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19301	\N	\N	2014-09-28 19:03:23
21216	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour le Chili	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19302	3	\N	\N
21217	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19303	\N	\N	\N
21218	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19304	10	\N	\N
21219	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19305	4	\N	\N
21220	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19306	12	\N	\N
29604	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25865	\N	\N	\N
21221	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19307	1	\N	\N
21222	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19308	\N	\N	\N
21223	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19309	\N	\N	\N
19155	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17820	\N	\N	\N
19156	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17821	\N	\N	\N
19157	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17822	\N	\N	\N
19328	MEMBRE	2011-10-01 00:00:00	2013-12-31 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17521	\N	\N	\N
19329	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17522	\N	\N	2014-09-28 17:05:42
19330	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17523	\N	\N	\N
19331	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17524	\N	\N	\N
19332	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17525	\N	\N	\N
19333	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17526	3	\N	\N
19334	MEMBRE	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17527	\N	\N	2014-09-29 13:41:53
19335	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17528	\N	\N	2014-09-28 17:12:41
19336	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17529	\N	\N	\N
19337	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17530	\N	\N	\N
19338	MEMBRE	2011-10-01 00:00:00	2014-10-03 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17531	\N	\N	\N
19339	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour l'Equateur	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17697	6	\N	\N
19510	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17579	\N	\N	\N
19511	VICPDT	2011-10-01 00:00:00	2014-10-03 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17580	8	\N	2015-11-12 15:26:22
19512	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17581	\N	\N	\N
19513	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17582	\N	\N	\N
19514	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17583	\N	\N	2014-09-28 17:34:16
19515	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17584	\N	\N	\N
19516	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17585	\N	\N	\N
19517	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17586	17	\N	\N
19518	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17747	\N	\N	2014-09-28 13:19:48
19519	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17748	\N	\N	2014-09-28 17:27:35
19520	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17749	\N	\N	\N
19521	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17750	5	\N	\N
19678	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17637	26	\N	2014-09-28 13:21:47
19679	PDTHON	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17638	3	\N	2014-09-28 12:52:11
19680	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17639	\N	\N	\N
19681	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17640	\N	\N	\N
19682	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17641	\N	\N	\N
19683	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17802	\N	\N	\N
19684	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17803	\N	\N	\N
19685	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17804	\N	\N	2014-09-28 17:22:11
19686	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17805	13	\N	\N
19687	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17806	\N	\N	\N
19688	MEMBRE	2011-10-01 00:00:00	2013-12-31 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17807	\N	\N	\N
22488	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20432	\N	2014-10-16 09:44:43	\N
19689	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17808	\N	\N	\N
18147	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16351	\N	\N	2014-09-28 17:34:16
18188	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16392	\N	\N	\N
18165	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16369	\N	\N	\N
18166	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16370	\N	\N	\N
18176	MEMBRE	2011-10-01 00:00:00	2012-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	16380	\N	\N	\N
18186	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16390	\N	\N	\N
18187	MEMBRE	2011-10-01 00:00:00	2012-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	16391	\N	\N	\N
18189	MEMBRE	2011-10-01 00:00:00	2012-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	16393	\N	\N	\N
18190	MEMBRE	2011-10-01 00:00:00	2012-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	16394	\N	\N	\N
18191	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16395	\N	\N	2014-09-28 13:21:47
18192	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16396	\N	\N	\N
18193	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16397	\N	\N	\N
18194	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16398	\N	\N	2014-09-28 19:03:23
18200	MEMBRE	2011-10-01 00:00:00	2012-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	16404	\N	\N	\N
18203	MEMBRE	2011-10-01 00:00:00	2012-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	16407	\N	\N	\N
18205	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16409	\N	\N	\N
19158	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17823	\N	\N	\N
19159	MEMBRE	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17443	\N	\N	2014-09-29 13:41:53
19160	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17444	\N	\N	\N
19161	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17445	7	\N	2014-09-28 17:31:42
19162	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17446	6	\N	\N
20288	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18160	\N	\N	\N
20291	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18163	7	\N	\N
20292	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18164	\N	\N	2014-09-28 17:40:23
20293	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18412	\N	\N	2014-09-28 17:00:59
20294	VICPDT	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18413	9	\N	\N
18441	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16644	\N	\N	\N
18442	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16645	\N	\N	\N
18443	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16646	\N	\N	\N
18704	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16907	\N	\N	\N
18451	MEMBRE	2011-10-01 00:00:00	2012-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	16654	\N	\N	\N
18701	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16904	\N	\N	2014-09-28 17:27:35
18703	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16906	\N	\N	2014-09-28 18:19:47
18705	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16908	\N	\N	\N
18708	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16911	\N	\N	2014-09-28 17:27:35
18709	MEMBRE	2011-10-01 00:00:00	2012-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	16912	\N	\N	\N
20400	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18622	1	\N	\N
20401	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18623	\N	\N	\N
20402	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18624	\N	\N	\N
20403	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18625	9	\N	\N
20404	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18626	\N	\N	\N
20405	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18627	\N	\N	\N
20406	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18628	7	\N	2014-09-28 18:03:38
20407	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18629	\N	\N	2014-09-28 16:50:17
20541	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18829	1	\N	\N
20542	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18830	6	\N	\N
20543	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18831	7	\N	\N
20544	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18832	\N	\N	2014-09-28 13:21:47
20545	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18833	\N	\N	2014-09-28 19:03:23
20546	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18834	7	\N	\N
20547	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18835	\N	\N	2014-09-28 13:40:33
20548	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18836	\N	\N	\N
20549	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour le Qatar	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18837	7	\N	2014-09-28 17:03:42
20550	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18838	\N	\N	2014-09-28 13:21:47
20551	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18839	\N	\N	\N
20552	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour la Micronésie	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19009	16	\N	2014-09-29 09:08:33
20700	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18704	2	\N	\N
20701	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18705	\N	\N	2014-09-28 13:21:47
20702	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18706	\N	\N	\N
20703	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18707	9	\N	\N
20704	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18708	\N	\N	2014-09-28 13:16:32
20705	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18873	7	\N	2014-09-28 17:27:35
20706	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18874	\N	\N	2014-09-28 16:59:41
20707	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18875	6	\N	2014-09-28 13:39:21
20708	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18876	\N	\N	\N
20709	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18877	7	\N	\N
20710	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18878	8	\N	2014-09-28 17:27:35
20711	MEMBRE	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18879	\N	\N	2014-09-29 13:43:10
21421	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19359	\N	\N	2014-09-28 17:07:41
21422	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19360	13	\N	\N
21423	PDTHON	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19361	2	\N	2014-09-28 12:52:11
21424	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19362	\N	\N	\N
21425	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19363	\N	\N	2014-09-28 17:40:23
21426	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19364	\N	\N	2014-09-28 17:31:42
21427	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19365	\N	\N	2014-09-28 18:03:38
21428	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19531	13	\N	2014-09-28 16:40:50
21429	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19532	\N	\N	\N
21224	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19310	7	\N	2014-09-28 13:39:21
21225	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19476	29	\N	\N
21226	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19477	\N	\N	2014-09-28 13:09:05
21388	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19348	\N	\N	2014-09-28 13:16:32
21389	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19349	11	\N	2014-09-28 13:39:21
21390	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19350	\N	\N	\N
21391	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19351	\N	\N	\N
21392	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19352	\N	\N	\N
21393	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19353	\N	\N	\N
21394	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19354	\N	\N	\N
21395	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19520	4	\N	2014-09-28 13:21:47
21396	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19521	\N	\N	\N
21397	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19522	\N	\N	\N
21398	MEMBRE	2011-10-01 00:00:00	2013-02-28 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19523	\N	\N	\N
21399	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19524	\N	\N	\N
20860	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18754	\N	\N	2014-09-28 17:27:35
20861	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18755	\N	\N	2014-09-28 17:27:35
20862	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18756	7	\N	2014-09-28 13:39:21
20863	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18757	3	\N	\N
20864	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18758	\N	\N	\N
20865	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18759	\N	\N	\N
20866	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18760	6	\N	\N
20867	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18761	\N	\N	\N
20868	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18762	\N	\N	\N
20869	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18928	\N	\N	2014-09-28 12:44:31
20870	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18929	\N	\N	2014-09-28 17:31:42
20871	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18930	\N	\N	\N
21040	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19599	2	\N	\N
21041	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19600	4	\N	\N
21042	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19601	5	\N	2014-09-28 16:42:05
21043	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19602	1	\N	\N
21044	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19603	\N	\N	\N
21045	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19604	\N	\N	\N
21046	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19605	\N	\N	\N
21047	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19606	1	\N	\N
21048	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19607	\N	\N	\N
21049	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19256	\N	\N	\N
21050	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19257	\N	\N	\N
21051	MEMBRE	2011-10-01 00:00:00	2014-10-03 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19258	\N	\N	2015-11-12 15:26:22
18721	MEMBRE	2011-10-01 00:00:00	2013-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	16924	\N	\N	\N
18726	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16929	\N	\N	\N
18745	MEMBRE	2011-10-01 00:00:00	2012-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	16948	\N	\N	\N
18779	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16982	\N	\N	\N
18826	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17029	\N	\N	2014-09-28 16:50:17
18841	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17044	\N	\N	2014-09-28 17:27:35
18842	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17045	\N	\N	2014-09-28 19:03:04
18843	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17046	\N	\N	2014-09-28 16:50:17
18844	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17047	\N	\N	\N
18846	MEMBRE	2011-10-01 00:00:00	2012-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	17049	\N	\N	\N
18847	MEMBRE	2011-10-01 00:00:00	2012-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	17050	\N	\N	\N
18848	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17051	\N	\N	2014-09-28 16:59:41
18849	MEMBRE	2011-10-01 00:00:00	2012-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	17052	\N	\N	\N
18851	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17054	\N	\N	\N
18853	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17056	\N	\N	\N
18854	MEMBRE	2011-10-01 00:00:00	2014-04-24 00:00:00	ANCIEN	\N	\N	\N	\N	17057	\N	\N	\N
21227	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19478	12	\N	\N
18856	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17059	\N	\N	\N
18857	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17060	\N	\N	\N
18858	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17061	\N	\N	\N
18859	MEMBRE	2011-10-01 00:00:00	2012-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	17062	\N	\N	\N
18861	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17064	\N	\N	\N
18862	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17065	\N	\N	\N
18864	MEMBRE	2011-10-01 00:00:00	2012-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	17067	\N	\N	\N
18865	MEMBRE	2011-10-01 00:00:00	2012-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	17068	\N	\N	\N
18866	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17069	\N	\N	\N
18867	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17070	\N	\N	2014-09-28 17:03:42
21228	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19479	10	\N	\N
19163	MEMBRE	2011-10-01 00:00:00	2013-06-27 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17642	\N	\N	\N
19340	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17698	14	\N	\N
19341	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour le Pérou	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17699	5	\N	2014-09-28 17:05:42
22489	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20433	\N	2014-10-16 09:44:43	\N
19342	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17700	21	\N	\N
19343	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17701	\N	\N	\N
19344	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17702	\N	\N	2014-09-28 12:09:44
19345	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17703	\N	\N	\N
19346	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17704	17	\N	\N
19347	MEMBRE	2011-10-01 00:00:00	2013-02-06 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17705	\N	\N	\N
19348	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour le Venezuela	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17706	2	\N	2014-09-28 19:03:23
19349	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17707	\N	\N	2014-09-28 16:42:05
19350	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17333	\N	\N	\N
19351	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17334	\N	\N	\N
19522	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17751	7	\N	2014-09-28 17:15:42
19523	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17752	\N	\N	\N
19524	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17753	\N	\N	\N
19525	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17754	\N	\N	\N
19526	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17755	\N	\N	\N
19527	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17756	\N	\N	2014-09-28 16:50:17
19528	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17757	\N	\N	2014-09-28 17:52:18
19529	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17388	\N	\N	2014-09-28 17:27:29
19530	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour le Laos	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17389	2	\N	2014-09-28 12:44:31
19531	PDTHON	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17390	3	\N	\N
19532	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17391	5	\N	2014-09-28 16:42:05
19533	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17392	11	\N	\N
19690	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17809	\N	\N	\N
19691	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17810	10	\N	\N
19692	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17811	11	\N	2014-09-28 12:09:44
19693	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17812	\N	\N	\N
19694	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18423	\N	\N	2014-09-28 16:59:41
19695	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18424	\N	\N	\N
19696	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18425	3	\N	\N
19697	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18426	\N	\N	2014-09-28 16:42:05
19698	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18427	4	\N	\N
19699	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18428	\N	\N	\N
19700	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18429	\N	\N	\N
19701	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18430	1	\N	\N
19164	PDTHON	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17643	2	\N	\N
19165	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17644	2	\N	\N
19166	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17645	\N	\N	2014-09-28 17:27:35
19167	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17646	5	\N	\N
19168	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17647	\N	\N	\N
19169	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17648	\N	\N	\N
19170	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17649	\N	\N	\N
19171	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17650	7	\N	2014-09-28 17:22:11
19172	PDT	2011-10-01 00:00:00	2013-12-31 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17651	1	\N	\N
19173	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17652	6	\N	\N
19174	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17824	\N	\N	2014-09-28 16:59:41
19175	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	17825	4	\N	\N
18168	MEMBRE	2011-10-01 00:00:00	2012-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	16372	\N	\N	\N
18389	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16592	\N	\N	2014-09-28 12:56:42
21430	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19533	10	\N	2014-09-28 16:50:17
21431	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19534	\N	\N	\N
21432	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19535	16	\N	\N
20884	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18592	1	\N	\N
20885	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18593	\N	\N	\N
20886	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18594	\N	\N	\N
20887	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18595	\N	\N	2014-09-28 12:44:31
20888	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour la Norvège	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18596	5	\N	2014-09-28 16:40:50
20889	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18597	\N	\N	\N
20890	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18598	18	\N	\N
20891	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18763	\N	\N	\N
20892	MEMBRE	2011-10-01 00:00:00	2013-12-31 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18764	\N	\N	\N
20893	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18765	\N	\N	\N
20894	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18766	\N	\N	\N
20895	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	18767	\N	\N	2014-09-28 17:27:35
21064	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19436	5	\N	2014-09-28 17:22:11
21065	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19437	\N	\N	\N
21066	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour la Sierra Leone	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19438	4	\N	2014-09-28 17:07:41
21067	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour le Bénin	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19439	14	\N	2014-09-28 16:50:17
21068	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19440	20	\N	2014-09-28 17:03:42
21069	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19441	7	\N	\N
21070	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19442	\N	\N	\N
21071	MEMBRE	2011-10-01 00:00:00	2014-05-11 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19608	\N	\N	\N
21072	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19609	1	\N	\N
21073	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19610	\N	\N	\N
21074	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19611	\N	\N	\N
21075	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19612	\N	\N	\N
21242	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19658	\N	\N	\N
21243	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19659	\N	\N	2014-09-28 17:27:35
21244	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19660	\N	\N	\N
21245	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19661	\N	\N	\N
21246	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19662	\N	\N	2014-09-28 17:27:35
21247	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19124	2	\N	2014-09-28 17:27:35
21248	PDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19125	1	\N	2014-09-28 17:22:11
22490	MEMBRE	2014-10-14 00:00:00	2015-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	20434	\N	2014-10-16 09:44:43	2015-01-23 12:08:07
21249	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19126	3	\N	\N
21250	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19127	2	\N	\N
21251	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19128	\N	\N	\N
21252	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19129	\N	\N	\N
21253	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19130	2	\N	\N
21433	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19536	17	\N	\N
21434	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19537	\N	\N	\N
21435	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19538	\N	\N	\N
21436	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19539	24	\N	\N
21437	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19540	\N	\N	\N
21438	SECRET	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19541	10	\N	\N
21439	PDTDEL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour l'Angola	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19190	6	\N	\N
21440	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19191	\N	\N	2014-09-28 17:22:11
21441	VICPDT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19192	9	\N	\N
21442	MEMBRE	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	Fonction Membre créée par script à partir de la table des adhésions ADHGRPSEN le 07/02/2012	19193	\N	\N	\N
22259	MEMBRE	2013-11-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20207	\N	2013-11-14 09:47:06	2013-11-14 09:47:18
22260	MEMBRE	2013-11-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20208	\N	2013-11-14 09:49:29	2013-11-14 09:49:36
22447	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20391	\N	2014-10-16 09:40:38	\N
22291	MEMBRE	2014-01-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20236	\N	2014-04-01 15:44:26	\N
22292	MEMBRE	2014-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20237	\N	2014-04-01 15:55:26	\N
22448	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20392	\N	2014-10-16 09:41:01	\N
22449	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20393	\N	2014-10-16 09:41:01	\N
22450	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20394	\N	2014-10-16 09:41:01	\N
22451	MEMBRE	2014-10-14 00:00:00	2015-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	20395	\N	2014-10-16 09:41:01	2015-01-13 15:41:40
22452	MEMBRE	2014-10-14 00:00:00	2015-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	20396	10	2014-10-16 09:41:01	2015-02-02 13:15:24
22453	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20397	\N	2014-10-16 09:41:01	\N
22454	MEMBRE	2014-10-15 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	20398	\N	2014-10-16 09:41:29	2015-02-03 16:18:13
22455	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20399	\N	2014-10-16 09:41:29	\N
22456	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20400	\N	2014-10-16 09:41:29	\N
22457	MEMBRE	2014-10-15 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	20401	\N	2014-10-16 09:41:29	2015-01-06 17:44:30
22458	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20402	\N	2014-10-16 09:41:29	\N
22459	MEMBRE	2014-10-15 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	20403	\N	2014-10-16 09:41:29	2015-02-13 17:03:17
22460	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20404	\N	2014-10-16 09:41:29	\N
22461	MEMBRE	2014-10-15 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	20405	\N	2014-10-16 09:41:29	2015-02-19 16:23:04
22462	MEMBRE	2014-10-15 00:00:00	2015-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	20406	\N	2014-10-16 09:42:58	2015-01-28 09:40:38
22463	MEMBRE	2014-10-15 00:00:00	2015-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	20407	\N	2014-10-16 09:42:58	2015-01-27 16:27:11
22464	MEMBRE	2014-10-15 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	20408	\N	2014-10-16 09:42:58	2015-06-12 16:01:25
22466	MEMBRE	2014-10-15 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	20410	\N	2014-10-16 09:42:58	2015-06-12 16:01:25
22467	MEMBRE	2014-10-15 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	20411	\N	2014-10-16 09:42:58	2015-06-12 16:01:25
22468	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20412	\N	2014-10-16 09:43:15	\N
22469	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20413	\N	2014-10-16 09:43:15	\N
22470	MEMBRE	2014-10-14 00:00:00	2015-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	20414	\N	2014-10-16 09:44:43	2015-04-09 15:21:09
22471	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20415	\N	2014-10-16 09:44:43	\N
22472	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20416	\N	2014-10-16 09:44:43	\N
22473	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20417	\N	2014-10-16 09:44:43	\N
22474	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20418	\N	2014-10-16 09:44:43	\N
22475	MEMBRE	2014-10-14 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	20419	\N	2014-10-16 09:44:43	2015-02-20 10:46:27
22476	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20420	\N	2014-10-16 09:44:43	\N
22477	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20421	\N	2014-10-16 09:44:43	\N
22478	MEMBRE	2014-10-14 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	20422	\N	2014-10-16 09:44:43	2015-02-20 10:42:58
22479	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20423	\N	2014-10-16 09:44:43	\N
22480	MEMBRE	2014-10-14 00:00:00	2015-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	20424	\N	2014-10-16 09:44:43	2015-02-16 17:41:56
22481	MEMBRE	2014-10-14 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	20425	\N	2014-10-16 09:44:43	2015-02-03 16:22:27
22482	MEMBRE	2014-10-14 00:00:00	2015-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	20426	\N	2014-10-16 09:44:43	2015-01-29 10:53:03
22483	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20427	\N	2014-10-16 09:44:43	\N
22484	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20428	\N	2014-10-16 09:44:43	\N
22485	MEMBRE	2014-10-14 00:00:00	2015-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	20429	\N	2014-10-16 09:44:43	2015-01-23 11:54:01
22486	MEMBRE	2014-10-14 00:00:00	2015-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	20430	\N	2014-10-16 09:44:43	2015-02-17 16:14:07
22487	MEMBRE	2014-10-14 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	20431	\N	2014-10-16 09:44:43	2015-02-19 15:43:01
22491	MEMBRE	2014-10-14 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	20435	\N	2014-10-16 09:44:43	2015-02-03 10:24:00
22492	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20436	\N	2014-10-16 09:44:43	\N
22493	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20437	\N	2014-10-16 09:45:40	\N
22494	MEMBRE	2014-10-14 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	20438	\N	2014-10-16 09:45:40	2015-01-06 15:28:38
22495	MEMBRE	2014-10-14 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	20439	\N	2014-10-16 09:45:40	2015-02-13 17:04:23
22496	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20440	\N	2014-10-16 09:45:40	\N
22497	MEMBRE	2014-10-14 00:00:00	2015-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	20441	\N	2014-10-16 09:45:56	2015-01-14 14:20:47
22498	MEMBRE	2014-10-14 00:00:00	2015-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	20442	\N	2014-10-16 09:47:37	2015-02-17 16:13:38
22499	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20443	\N	2014-10-16 09:47:37	\N
22500	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20444	\N	2014-10-16 09:47:37	\N
22501	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20445	\N	2014-10-16 09:47:37	\N
22502	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20446	\N	2014-10-16 09:48:18	\N
22503	MEMBRE	2014-10-14 00:00:00	2014-11-14 00:00:00	ANCIEN	\N	\N	\N	\N	20447	\N	2014-10-16 09:48:18	2015-11-12 15:26:22
22504	MEMBRE	2014-10-14 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	20448	\N	2014-10-16 09:48:18	2015-11-12 15:26:22
22505	MEMBRE	2014-10-14 00:00:00	2015-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	20449	\N	2014-10-16 09:48:18	2015-11-12 15:26:22
22506	MEMBRE	2014-10-14 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	20450	\N	2014-10-16 09:48:18	2015-11-12 15:26:22
22507	MEMBRE	2014-10-14 00:00:00	2015-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	20451	\N	2014-10-16 09:48:18	2015-11-12 15:26:22
22508	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20452	\N	2014-10-16 09:48:52	\N
22509	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20453	\N	2014-10-16 09:48:52	\N
22510	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20454	\N	2014-10-16 09:48:52	\N
22511	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20455	\N	2014-10-16 09:48:52	\N
22512	MEMBRE	2014-10-14 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	20456	\N	2014-10-16 09:49:33	2015-01-06 15:15:32
22513	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20457	\N	2014-10-16 09:49:33	\N
22514	MEMBRE	2014-10-14 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	20458	\N	2014-10-16 09:49:33	2015-02-02 13:27:14
22515	MEMBRE	2014-10-14 00:00:00	2015-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	20459	\N	2014-10-16 09:49:33	2015-03-11 10:58:16
22516	MEMBRE	2014-10-14 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	20460	\N	2014-10-16 09:49:33	2015-02-11 18:02:05
22517	MEMBRE	2014-10-14 00:00:00	2015-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	20461	\N	2014-10-16 09:49:33	2015-02-17 09:38:58
22518	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20462	\N	2014-10-16 09:49:33	\N
22519	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20463	\N	2014-10-16 09:49:33	\N
22520	MEMBRE	2014-10-14 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	20464	\N	2014-10-16 09:49:34	2015-01-06 15:29:00
22521	MEMBRE	2014-10-14 00:00:00	2015-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	20465	\N	2014-10-16 09:49:34	2015-02-12 12:43:28
22522	MEMBRE	2014-10-14 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	20466	\N	2014-10-16 09:49:34	2015-02-11 17:26:19
22523	MEMBRE	2014-10-14 00:00:00	2015-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	20467	\N	2014-10-16 09:49:34	2015-01-30 15:58:22
22524	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20468	\N	2014-10-16 09:49:34	\N
22525	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20469	\N	2014-10-16 09:49:34	\N
22526	MEMBRE	2014-10-14 00:00:00	2015-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	20470	\N	2014-10-16 09:53:42	2015-02-04 14:27:06
22527	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20471	\N	2014-10-16 09:53:42	\N
22528	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20472	\N	2014-10-16 09:53:42	\N
22529	MEMBRE	2014-10-14 00:00:00	2015-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	20473	\N	2014-10-16 09:53:42	2015-01-13 15:55:05
22530	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20474	\N	2014-10-16 09:53:42	\N
22531	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20475	\N	2014-10-16 09:53:42	\N
22532	MEMBRE	2014-10-14 00:00:00	2015-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	20476	\N	2014-10-16 09:53:42	2015-02-04 17:39:48
22533	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20477	\N	2014-10-16 09:53:43	\N
22534	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20478	\N	2014-10-16 09:53:43	\N
22535	MEMBRE	2014-10-14 00:00:00	2015-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	20479	\N	2014-10-16 09:53:43	2015-02-17 09:38:36
22536	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20480	\N	2014-10-16 09:53:43	\N
22537	MEMBRE	2014-10-14 00:00:00	2015-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	20481	8	2014-10-16 09:53:43	2015-02-23 15:23:34
22538	MEMBRE	2014-10-15 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	20482	\N	2014-10-16 09:54:12	2015-01-06 15:34:16
22539	MEMBRE	2014-10-15 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	20483	\N	2014-10-16 09:54:12	2015-02-19 16:16:28
22540	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20484	\N	2014-10-16 09:54:12	\N
22560	MEMBRE	2014-10-14 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	20504	\N	2014-10-17 14:40:39	2015-01-06 17:16:42
22561	MEMBRE	2014-10-14 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	20505	\N	2014-10-17 14:40:39	2015-02-11 16:39:16
22562	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20506	\N	2014-10-17 14:40:39	\N
22563	MEMBRE	2014-10-14 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	20507	\N	2014-10-17 14:40:39	2015-02-13 15:12:27
22564	MEMBRE	2014-10-14 00:00:00	2015-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	20508	\N	2014-10-17 14:40:39	2015-03-06 09:53:10
22565	MEMBRE	2014-10-14 00:00:00	2015-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	20509	\N	2014-10-17 14:40:39	2015-02-09 11:03:51
22566	MEMBRE	2014-10-14 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	20510	\N	2014-10-17 14:40:39	2015-02-05 18:57:44
22655	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20599	\N	2014-10-21 17:36:52	\N
22656	MEMBRE	2014-10-21 00:00:00	2015-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	20600	\N	2014-10-21 17:36:52	2015-01-29 10:57:28
22657	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20601	\N	2014-10-21 17:36:52	\N
22658	MEMBRE	2014-10-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20602	\N	2014-10-21 17:38:20	\N
22659	MEMBRE	2014-10-16 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	20603	\N	2014-10-21 17:38:20	2015-02-20 12:12:06
22660	MEMBRE	2014-10-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20604	\N	2014-10-21 17:38:20	\N
22661	MEMBRE	2014-10-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20605	\N	2014-10-21 17:38:20	\N
22662	MEMBRE	2014-10-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20606	\N	2014-10-21 17:38:20	\N
22663	MEMBRE	2014-10-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20607	\N	2014-10-21 17:38:20	\N
22664	MEMBRE	2014-10-21 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	20608	\N	2014-10-21 17:38:43	2015-02-20 10:52:06
22665	MEMBRE	2014-10-21 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	20609	\N	2014-10-21 17:38:43	2015-01-06 17:16:16
23443	MEMBRE	2014-10-28 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	21354	\N	2014-10-28 17:20:49	2017-06-19 12:20:59
23444	MEMBRE	2014-10-28 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	21355	\N	2014-10-28 17:20:49	2017-06-19 12:20:59
23445	MEMBRE	2014-10-28 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	21356	\N	2014-10-28 17:20:49	2017-06-19 12:20:59
23446	MEMBRE	2014-10-28 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	21357	\N	2014-10-28 17:20:49	2017-06-19 12:20:59
23447	MEMBRE	2014-10-28 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	21358	\N	2014-10-28 17:20:49	2017-06-19 12:20:59
23448	MEMBRE	2014-10-28 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21359	\N	2014-10-28 17:20:49	2015-01-06 17:50:57
23449	MEMBRE	2014-10-28 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	21360	\N	2014-10-28 17:20:49	2017-06-19 12:20:59
23450	MEMBRE	2014-10-28 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	21361	\N	2014-10-28 17:20:49	2017-06-19 12:20:59
23451	MEMBRE	2014-10-28 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	21362	\N	2014-10-28 17:20:49	2017-06-19 12:20:59
23452	MEMBRE	2014-10-28 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	21363	\N	2014-10-28 17:20:49	2015-02-20 10:43:24
23453	MEMBRE	2014-10-28 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21364	\N	2014-10-28 17:20:49	2015-01-06 15:48:01
23454	MEMBRE	2014-10-28 00:00:00	2015-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	21365	\N	2014-10-28 17:21:36	2015-02-04 14:27:00
23455	MEMBRE	2014-10-28 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21366	\N	2014-10-28 17:21:36	2015-01-06 17:44:53
23456	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21367	\N	2014-10-28 17:21:36	\N
23457	MEMBRE	2014-10-28 00:00:00	2015-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	21368	\N	2014-10-28 17:21:36	2015-02-12 12:45:16
23458	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21369	\N	2014-10-28 17:21:36	\N
23805	MEMBRE	2014-10-30 00:00:00	2015-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	21716	\N	2014-10-30 15:08:31	2015-01-28 09:41:31
23861	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21772	\N	2014-10-30 16:52:49	\N
23862	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21773	\N	2014-10-30 16:52:49	\N
23863	MEMBRE	2014-10-30 00:00:00	2015-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	21774	\N	2014-10-30 16:53:21	2015-01-23 11:54:34
23864	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21775	\N	2014-10-30 16:53:21	\N
23865	MEMBRE	2014-10-30 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21776	\N	2014-10-30 16:53:21	2015-01-06 16:08:34
23866	MEMBRE	2014-10-30 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	21777	\N	2014-10-30 16:53:21	2015-02-19 16:15:45
24217	MEMBRE	2014-11-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22128	\N	2014-11-06 10:55:14	\N
24218	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22129	\N	2014-11-06 10:55:25	\N
24219	MEMBRE	2014-11-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22130	\N	2014-11-06 10:55:40	\N
24220	MEMBRE	2014-11-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22131	\N	2014-11-06 10:55:40	\N
24253	MEMBRE	2014-11-06 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	22164	\N	2014-11-07 14:31:19	2015-02-11 11:01:02
24254	MEMBRE	2014-11-06 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	22165	\N	2014-11-07 14:31:19	2015-02-13 14:19:00
24255	MEMBRE	2014-11-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22166	\N	2014-11-07 14:31:19	\N
24354	MEMBRE	2014-11-19 00:00:00	2015-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	22261	\N	2014-11-20 15:16:25	2015-01-30 15:14:01
24355	MEMBRE	2014-11-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22262	\N	2014-11-20 15:16:38	\N
24356	MEMBRE	2014-11-20 00:00:00	2015-03-19 00:00:00	ANCIEN	\N	\N	\N	\N	22263	\N	2014-11-20 15:16:38	2015-03-20 11:38:03
24361	MEMBRE	2014-11-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22268	\N	2014-11-24 09:33:06	\N
24385	MEMBRE	2014-11-27 00:00:00	2015-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	22292	\N	2014-12-01 09:37:06	2015-02-12 17:35:33
24412	MEMBRE	2014-12-05 00:00:00	2015-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	22319	\N	2014-12-09 17:47:51	2015-01-14 09:55:55
24425	MEMBRE	2014-12-11 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	22332	\N	2014-12-11 16:12:59	2015-06-12 15:59:18
24430	MEMBRE	2014-12-15 00:00:00	2017-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	22337	\N	2014-12-15 15:28:35	2017-07-20 11:45:07
24431	MEMBRE	2014-12-15 00:00:00	2017-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	22338	\N	2014-12-15 15:28:35	2017-07-20 14:38:10
24469	PDTDEL	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour l'Ethiopie	\N	20873	2	2015-01-06 11:04:07	2015-01-22 10:47:50
24597	PDT	2015-01-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20395	1	2015-01-13 15:41:40	2015-01-13 15:41:43
24598	PDT	2015-01-13 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	22369	1	2015-01-13 15:43:47	2017-04-27 16:00:50
24599	PDT	2015-01-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22363	1	2015-01-13 15:44:22	2015-01-13 15:44:28
24600	PDTDEL	2015-01-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour les Emirats arabes unis	\N	22023	6	2015-01-13 15:51:26	2015-03-19 09:58:34
24601	PDTDEL	2015-01-13 00:00:00	2015-01-15 00:00:00	ANCIEN	\N	\N	pour le Bénin	\N	20473	\N	2015-01-13 15:55:05	2015-01-16 17:53:26
24602	PDTDEL	2015-01-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour l'Azerbaïdjan	\N	21917	3	2015-01-13 15:57:07	2015-02-19 18:04:55
24603	PDTDEL	2015-01-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour la Macédoine	\N	22360	3	2015-01-13 15:59:26	2015-02-20 12:09:13
24633	PDT	2015-01-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22387	1	2015-01-14 17:19:16	2015-01-14 17:21:09
24634	MEMBRE	2015-01-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22388	\N	2015-01-14 17:32:03	\N
24643	MEMBRE	2015-01-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22395	\N	2015-01-16 09:38:26	\N
24644	MEMBRE	2015-01-14 00:00:00	2015-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	22396	\N	2015-01-16 09:38:37	2015-03-19 10:03:41
24645	MEMBRE	2015-01-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22397	\N	2015-01-16 09:38:47	\N
24646	MEMBRE	2015-01-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22398	\N	2015-01-16 09:38:57	\N
24725	PDTDEL	2015-01-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour l'Angola	\N	22432	2	2015-01-23 11:48:53	2015-01-30 15:16:43
24726	PDTDEL	2015-01-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour la Namibie	\N	22407	5	2015-01-23 11:49:18	2015-01-30 15:25:49
24727	PDTDEL	2015-01-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour le Bénin	\N	20473	8	2015-01-23 11:53:19	2015-02-11 12:12:26
24728	PDTDEL	2015-01-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour la Guinée (Conakry))	\N	20429	10	2015-01-23 11:54:01	2015-02-11 12:12:34
24729	PDTDEL	2015-01-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour la Mauritanie	\N	21774	7	2015-01-23 11:54:34	2015-02-11 12:12:23
24730	PDTDEL	2015-01-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour le Niger	\N	22429	9	2015-01-23 11:54:45	2015-02-11 12:12:31
24731	PDTDEL	2015-01-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour la Sierra Leone	\N	22429	\N	2015-01-23 11:55:26	2015-02-11 12:11:29
24732	MEMBRE	2015-01-23 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	21847	\N	2015-01-23 11:59:21	2015-02-11 12:11:08
24733	PDTDEL	2015-01-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour l'Ouzbékistan	\N	20902	4	2015-01-23 12:04:53	2015-02-16 17:40:28
24734	PDTDEL	2015-01-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour le Turkménistan	\N	22340	6	2015-01-23 12:05:20	2015-02-16 17:40:34
24735	PDTDEL	2015-01-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour le Bangladesh	\N	22328	2	2015-01-23 12:06:06	2015-02-11 17:14:07
24736	PDTDEL	2015-01-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour la Serbie	\N	20434	5	2015-01-23 12:08:06	2015-02-20 12:09:22
24737	PDTDEL	2015-01-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour le Laos	\N	20563	2	2015-01-23 12:09:55	2015-02-09 11:41:25
24740	MEMBRE	2015-01-20 00:00:00	2015-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	22447	\N	2015-01-23 17:18:43	2015-01-23 17:22:09
24741	PDTDEL	2015-01-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour la Guinée équatoriale	\N	22447	8	2015-01-23 17:22:08	2015-02-03 10:16:47
24742	MEMBRE	2015-01-21 00:00:00	2015-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	22448	\N	2015-01-23 17:55:23	2015-01-23 17:59:55
24743	MEMBRE	2015-01-22 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	22449	\N	2015-01-23 17:56:17	2015-02-11 16:59:00
24744	PDTDEL	2015-01-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour l'Estonie	\N	22448	2	2015-01-23 17:59:54	2015-01-23 18:00:18
24749	MEMBRE	2015-01-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22454	\N	2015-01-27 09:24:34	\N
24750	MEMBRE	2015-01-26 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22455	\N	2015-01-27 09:40:22	\N
24751	MEMBRE	2015-01-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22456	\N	2015-01-27 09:40:34	2017-10-17 18:00:15
24752	MEMBRE	2015-01-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22457	\N	2015-01-27 09:40:58	\N
24753	MEMBRE	2015-01-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22458	\N	2015-01-27 10:09:45	\N
24754	MEMBRE	2015-01-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22459	\N	2015-01-27 10:09:45	\N
24755	MEMBRE	2015-01-26 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22460	\N	2015-01-27 10:12:38	\N
24808	MEMBRE	2015-01-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22474	\N	2015-01-28 14:56:15	\N
24809	MEMBRE	2015-01-27 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22475	\N	2015-01-28 14:56:29	\N
22276	MEMBRE	2013-11-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	20222	\N	2014-01-09 15:25:39	2014-09-29 13:43:10
22282	MEMBRE	2014-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20228	\N	\N	2014-09-28 17:03:42
22294	MEMBRE	2014-03-01 00:00:00	2014-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20241	\N	2014-05-13 10:01:24	2014-11-27 10:15:39
22295	MEMBRE	2014-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20242	\N	2014-05-13 10:02:30	\N
22791	MEMBRE	2014-10-21 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	20735	\N	2014-10-22 15:19:34	2015-02-20 10:46:44
22792	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20736	\N	2014-10-22 15:19:34	\N
22793	MEMBRE	2014-10-21 00:00:00	2015-04-09 00:00:00	ANCIEN	\N	\N	\N	\N	20737	\N	2014-10-22 15:19:34	2015-04-10 15:10:38
22794	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20738	\N	2014-10-22 15:19:34	\N
22795	MEMBRE	2014-10-21 00:00:00	2015-08-30 00:00:00	ANCIEN	\N	\N	\N	\N	20739	\N	2014-10-22 15:19:34	2015-08-31 09:34:34
22796	MEMBRE	2014-10-21 00:00:00	2015-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	20740	\N	2014-10-22 15:19:34	2015-02-18 13:27:40
22797	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20741	\N	2014-10-22 15:19:34	\N
22798	MEMBRE	2014-10-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20742	\N	2014-10-22 15:41:43	\N
22799	MEMBRE	2014-10-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20743	\N	2014-10-22 15:41:43	\N
22800	MEMBRE	2014-10-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20744	\N	2014-10-22 15:41:43	\N
22801	MEMBRE	2014-10-22 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	20745	\N	2014-10-22 15:42:36	2015-02-03 16:28:01
22802	MEMBRE	2014-10-22 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	20746	\N	2014-10-22 15:42:36	2015-02-05 12:16:52
22803	MEMBRE	2014-10-22 00:00:00	2015-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	20747	\N	2014-10-22 15:42:36	2015-01-30 15:17:22
22804	MEMBRE	2014-10-22 00:00:00	2015-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	20748	\N	2014-10-22 15:42:36	2015-02-12 12:43:10
22805	MEMBRE	2014-10-22 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	20749	\N	2014-10-22 15:42:36	2015-02-20 12:00:01
22806	MEMBRE	2014-10-22 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	20750	\N	2014-10-22 15:42:36	2015-02-05 18:59:18
22807	MEMBRE	2014-10-22 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	20751	\N	2014-10-22 15:42:36	2015-02-13 14:24:09
23703	MEMBRE	2014-10-29 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21614	\N	2014-10-30 11:48:40	2015-01-06 17:49:42
23704	MEMBRE	2014-10-29 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	21615	\N	2014-10-30 11:48:40	2015-02-13 10:34:39
23705	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21616	\N	2014-10-30 11:48:40	\N
23706	MEMBRE	2014-10-29 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	21617	\N	2014-10-30 11:48:40	2015-02-11 11:01:24
23707	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21618	\N	2014-10-30 11:48:40	\N
23708	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21619	\N	2014-10-30 11:48:40	\N
23709	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21620	\N	2014-10-30 11:48:40	\N
23710	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21621	\N	2014-10-30 11:48:40	\N
23711	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21622	\N	2014-10-30 11:48:40	\N
23712	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21623	\N	2014-10-30 11:48:40	\N
23713	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21624	\N	2014-10-30 11:48:40	\N
23714	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21625	\N	2014-10-30 11:48:40	\N
23715	MEMBRE	2014-10-29 00:00:00	2017-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	21626	\N	2014-10-30 11:48:40	2017-07-20 14:38:49
23716	MEMBRE	2014-10-29 00:00:00	2015-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	21627	\N	2014-10-30 11:48:40	2015-01-27 17:08:50
23717	MEMBRE	2014-10-29 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	21628	\N	2014-10-30 11:48:40	2015-02-05 12:17:38
23718	MEMBRE	2014-10-29 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	21629	\N	2014-10-30 11:48:40	2015-02-11 18:02:13
23719	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21630	\N	2014-10-30 11:48:40	\N
23720	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21631	\N	2014-10-30 11:48:40	\N
23721	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21632	\N	2014-10-30 11:48:40	\N
23722	MEMBRE	2014-10-29 00:00:00	2015-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	21633	\N	2014-10-30 11:48:40	2015-02-09 15:46:03
23723	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21634	\N	2014-10-30 11:48:40	\N
23724	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21635	\N	2014-10-30 11:48:40	\N
23725	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21636	\N	2014-10-30 11:48:40	\N
23726	MEMBRE	2014-10-29 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	21637	\N	2014-10-30 11:48:40	2015-02-11 17:26:02
23727	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21638	\N	2014-10-30 11:48:41	\N
23728	MEMBRE	2014-10-30 00:00:00	2015-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	21639	\N	2014-10-30 11:49:08	2015-02-09 15:47:40
23729	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21640	\N	2014-10-30 11:55:54	\N
24000	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21911	\N	2014-10-31 12:00:49	\N
24001	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21912	\N	2014-10-31 12:00:49	\N
24066	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21977	\N	2014-10-31 16:32:11	\N
24067	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21978	\N	2014-10-31 16:32:11	\N
24068	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21979	\N	2014-10-31 16:32:11	\N
24069	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21980	\N	2014-10-31 16:32:11	\N
24070	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21981	\N	2014-10-31 16:32:11	\N
24071	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21982	\N	2014-10-31 16:32:11	\N
24072	MEMBRE	2014-10-30 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	21983	\N	2014-10-31 16:32:11	2015-02-20 12:16:58
24073	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21984	\N	2014-10-31 16:32:11	\N
24074	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21985	\N	2014-10-31 16:32:11	\N
24075	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21986	\N	2014-10-31 16:32:11	\N
24413	MEMBRE	2014-12-09 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22320	\N	2014-12-09 18:47:15	\N
24414	MEMBRE	2014-12-09 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	22321	\N	2014-12-09 18:47:15	2015-02-13 10:34:31
24415	MEMBRE	2014-12-09 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22322	\N	2014-12-09 18:47:15	\N
24416	MEMBRE	2014-12-09 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22323	\N	2014-12-09 18:47:15	\N
24417	MEMBRE	2014-11-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22324	\N	2014-12-10 09:12:10	\N
24462	MEMBRE	2014-12-19 00:00:00	2015-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	22369	\N	2014-12-19 12:48:33	2017-04-27 16:00:50
24587	PDTDEL	2015-01-07 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour le Koweït	\N	21806	2	2015-01-07 15:24:09	2015-03-19 09:58:20
24607	PDT	2015-01-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22319	1	2015-01-14 09:55:55	2015-01-14 09:56:04
24608	PDT	2015-01-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22382	1	2015-01-14 10:01:20	2015-01-14 10:01:34
24609	PDTDEL	2015-01-14 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	pour le Tadjikistan	\N	21160	5	2015-01-14 10:01:58	2015-02-16 17:40:31
24610	PDTDEL	2015-01-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour l'Ile Maurice	\N	21708	4	2015-01-14 10:05:50	2015-03-10 10:00:30
24611	PDTDEL	2015-01-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour l'Islande	\N	21717	4	2015-01-14 10:07:27	2015-02-20 12:12:01
24612	MEMBRE	2015-01-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21172	\N	2015-01-14 10:07:46	\N
24613	PDTDEL	2015-01-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	pour la Norvège	\N	21441	3	2015-01-14 10:08:33	2017-10-17 18:00:01
24614	PDTDEL	2015-01-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour le Luxembourg	\N	20777	2	2015-01-14 10:10:28	2015-01-14 10:10:36
24615	PDTDEL	2015-01-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour le Sao-Tomé-et-Principe	\N	21480	7	2015-01-14 10:11:41	2015-02-03 10:15:29
24616	PDTDEL	2015-01-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour le Sultanat d'Oman	\N	22373	7	2015-01-14 10:12:58	2015-03-19 09:58:39
24617	MEMBRE	2015-01-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20822	\N	2015-01-14 10:13:22	\N
24640	MEMBRE	2015-01-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22393	\N	2015-01-15 11:45:16	\N
24839	VICPDT	2015-01-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22086	2	2015-01-30 09:39:12	2015-01-30 09:39:20
24840	VICPDT	2015-01-30 00:00:00	2017-07-28 00:00:00	ANCIEN	\N	\N	\N	\N	20340	3	2015-01-30 09:39:25	2017-08-03 11:38:41
24841	VICPDT	2015-01-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21334	4	2015-01-30 09:39:39	2015-01-30 09:39:46
24842	VICPDT	2015-01-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20837	5	2015-01-30 09:39:52	2015-01-30 09:40:04
24844	VICPDT	2015-01-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21442	6	2015-01-30 09:40:12	2015-01-30 09:40:36
24845	VICPDT	2015-01-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20540	7	2015-01-30 09:40:26	2015-01-30 09:40:39
24896	VICPDT	2015-02-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22446	\N	2015-02-03 10:23:04	2015-02-03 10:25:47
24897	VICPDT	2015-02-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21125	\N	2015-02-03 10:23:36	2015-02-03 10:25:50
24898	VICPDT	2015-02-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20435	\N	2015-02-03 10:24:00	2015-02-03 10:26:07
24899	PDTHON	2015-02-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21186	\N	2015-02-03 10:25:31	\N
24900	MEMBRE	2015-01-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22501	\N	2015-02-03 10:31:00	\N
24901	MEMBRE	2015-02-02 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22502	\N	2015-02-03 10:31:08	\N
24902	MEMBRE	2015-01-26 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22503	\N	2015-02-03 10:31:25	\N
24903	MEMBRE	2015-01-29 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	22504	\N	2015-02-03 10:31:35	\N
24904	MEMBRE	2015-01-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22505	\N	2015-02-03 10:48:53	\N
24905	VICPDT	2015-02-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22336	2	2015-02-03 13:56:40	2015-02-03 13:56:55
24906	VICPDT	2015-02-03 00:00:00	2015-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	22410	3	2015-02-03 13:56:48	2015-06-18 10:57:46
23364	MEMBRE	2014-10-28 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	21275	\N	2014-10-28 15:29:38	2015-02-11 17:12:28
23365	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21276	\N	2014-10-28 15:29:38	\N
23366	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21277	\N	2014-10-28 15:29:38	\N
23367	MEMBRE	2014-10-28 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21278	\N	2014-10-28 15:29:38	2015-01-06 17:51:46
23368	MEMBRE	2014-10-28 00:00:00	2015-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	21279	\N	2014-10-28 15:29:38	2015-02-12 12:44:59
23369	MEMBRE	2014-10-28 00:00:00	2015-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	21280	\N	2014-10-28 15:29:38	2015-02-16 17:42:09
23370	MEMBRE	2014-10-28 00:00:00	2015-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	21281	\N	2014-10-28 15:29:38	2015-03-19 10:02:59
23371	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21282	\N	2014-10-28 15:30:34	\N
23372	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21283	\N	2014-10-28 15:30:53	\N
23373	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21284	\N	2014-10-28 15:30:53	\N
23385	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21296	\N	2014-10-28 16:02:23	\N
23386	MEMBRE	2014-10-28 00:00:00	2015-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	21297	\N	2014-10-28 16:02:23	2015-02-09 15:41:18
23387	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21298	\N	2014-10-28 16:02:23	\N
23388	MEMBRE	2014-10-28 00:00:00	2017-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	21299	\N	2014-10-28 16:02:23	2017-07-20 14:38:34
23389	MEMBRE	2014-10-28 00:00:00	2015-08-30 00:00:00	ANCIEN	\N	\N	\N	\N	21300	\N	2014-10-28 16:02:23	2015-08-31 09:33:38
23390	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21301	\N	2014-10-28 16:02:23	\N
24352	MEMBRE	2014-11-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22259	\N	2014-11-20 11:29:24	\N
24427	MEMBRE	2014-12-11 00:00:00	2017-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	22334	\N	2014-12-12 16:19:53	2017-07-20 14:38:36
24631	MEMBRE	2014-10-15 00:00:00	2015-01-06 00:00:00	ANCIEN	\N	\N	\N	\N	20377	\N	2015-01-14 16:22:04	2015-01-14 16:32:39
29603	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25864	\N	\N	\N
24630	PDTDEL	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour le Gabon	\N	20377	11	2015-01-14 16:14:58	2015-02-03 10:17:02
21662	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19761	\N	\N	\N
21824	SECRET	2012-02-28 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17018	\N	\N	\N
21644	SECRET	2012-02-15 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19756	\N	\N	\N
21844	SECRET	2012-02-21 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16858	\N	\N	\N
18307	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16511	\N	\N	\N
21590	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19724	\N	\N	\N
24907	VICPDT	2015-02-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21736	4	2015-02-03 13:57:00	2015-02-03 13:57:10
24908	VICPDT	2015-02-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22372	5	2015-02-03 13:59:19	2015-02-03 13:59:30
24909	SECRET	2015-02-03 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	21828	6	2015-02-03 13:59:33	2016-12-12 16:10:15
24910	SECRET	2015-02-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22252	7	2015-02-03 13:59:41	2015-02-03 13:59:46
24911	SECRET	2015-02-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22305	8	2015-02-03 13:59:49	2015-02-03 14:00:01
24912	SECRET	2015-02-03 00:00:00	2017-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	22329	9	2015-02-03 14:00:03	2017-10-09 09:55:18
24914	PDTHON	2015-02-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20398	2	2015-02-03 16:18:13	2015-02-03 16:18:53
24915	VICPDT	2015-02-03 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	21406	3	2015-02-03 16:18:57	2017-05-16 15:18:14
24916	VICPDT	2015-02-03 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	21821	4	2015-02-03 16:19:40	2016-12-12 16:10:15
24917	VICPDT	2015-02-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20337	5	2015-02-03 16:20:02	2015-02-03 16:21:46
24918	VICPDT	2015-02-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22306	6	2015-02-03 16:21:50	2015-02-03 16:22:01
24919	VICPDT	2015-02-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22153	7	2015-02-03 16:22:06	2015-02-03 16:22:19
24920	VICPDT	2015-02-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20425	8	2015-02-03 16:22:27	2015-02-03 16:22:42
24921	VICPDT	2015-02-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21600	\N	2015-02-03 16:22:48	\N
24944	SECRET	2015-02-04 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22277	8	2015-02-04 10:49:12	2015-02-04 10:49:17
24947	MEMBRE	2015-02-04 00:00:00	2015-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	22511	\N	2015-02-04 13:41:45	2015-02-17 16:13:50
24959	MEMBRE	2015-01-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22516	\N	2015-02-04 15:18:33	\N
24960	MEMBRE	2015-02-02 00:00:00	2017-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	22517	\N	2015-02-04 16:20:18	2017-07-24 09:56:26
24961	MEMBRE	2015-01-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22518	\N	2015-02-04 16:20:32	\N
24962	VICPDT	2015-02-04 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20476	2	2015-02-04 17:39:48	2015-02-04 17:40:19
24963	VICPDT	2015-02-04 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	21415	3	2015-02-04 17:39:54	2017-05-16 15:18:14
24964	VICPDT	2015-02-04 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	21884	4	2015-02-04 17:40:00	2016-03-11 18:02:51
24965	VICPDT	2015-02-04 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21222	5	2015-02-04 17:40:05	2015-02-04 17:40:28
24966	VICPDT	2015-02-04 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21749	6	2015-02-04 17:40:11	2015-02-04 17:40:30
24974	MEMBRE	2015-02-04 00:00:00	2017-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	22519	\N	2015-02-05 09:35:37	2017-10-09 09:54:08
24975	MEMBRE	2015-02-04 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22520	\N	2015-02-05 09:35:47	\N
24976	MEMBRE	2015-02-04 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22521	\N	2015-02-05 09:36:25	\N
24977	MEMBRE	2015-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22522	\N	2015-02-05 10:00:03	\N
24978	MEMBRE	2014-12-08 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22523	\N	2015-02-05 10:02:37	\N
25083	VICPDT	2015-02-09 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20856	2	2015-02-09 15:38:40	2015-02-09 15:38:52
25084	VICPDT	2015-02-09 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20829	3	2015-02-09 15:40:39	2015-02-09 15:40:46
25085	VICPDT	2015-02-09 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20583	4	2015-02-09 15:40:50	2015-02-09 15:40:57
25086	VICPDT	2015-02-09 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22345	5	2015-02-09 15:41:03	2015-02-09 15:42:01
25087	VICPDT	2015-02-09 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20492	6	2015-02-09 15:41:11	2015-02-09 15:42:04
25088	VICPDT	2015-02-09 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21297	7	2015-02-09 15:41:18	2015-02-09 15:42:08
25089	VICPDT	2015-02-09 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20763	8	2015-02-09 15:41:40	2015-02-09 15:42:12
25090	VICPDT	2015-02-09 00:00:00	2017-09-21 00:00:00	ANCIEN	\N	\N	\N	\N	22168	9	2015-02-09 15:42:17	2017-09-22 10:42:23
25091	VICPDT	2015-02-09 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21115	10	2015-02-09 15:42:23	2015-02-09 15:44:48
25092	VICPDT	2015-02-09 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	21840	11	2015-02-09 15:42:28	2016-12-12 16:10:15
25093	VICPDT	2015-02-09 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21530	12	2015-02-09 15:42:38	2015-02-09 15:44:57
25094	VICPDT	2015-02-09 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22325	13	2015-02-09 15:42:47	2015-02-09 15:44:59
25095	VICPDT	2015-02-09 00:00:00	2017-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	21657	14	2015-02-09 15:42:57	2017-09-24 11:09:53
25096	VICPDT	2015-02-09 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20323	15	2015-02-09 15:43:05	2015-02-09 15:45:10
25097	VICPDT	2015-02-09 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21062	16	2015-02-09 15:43:17	2015-02-09 15:45:13
25098	VICPDT	2015-02-09 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21445	17	2015-02-09 15:43:35	2015-02-09 15:45:21
25099	VICPDT	2015-02-09 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	21871	18	2015-02-09 15:45:30	2016-03-11 18:02:51
25100	VICPDT	2015-02-09 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21888	19	2015-02-09 15:45:44	2015-02-09 15:46:21
25101	VICPDT	2015-02-09 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21752	20	2015-02-09 15:45:52	2015-02-09 15:46:25
25102	VICPDT	2015-02-09 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21633	21	2015-02-09 15:46:03	2015-02-09 15:46:33
25103	SECRET	2015-02-09 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20354	22	2015-02-09 15:46:37	2015-02-09 15:46:45
25104	SECRET	2015-02-09 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20352	23	2015-02-09 15:46:55	2015-02-09 15:47:58
25105	SECRET	2015-02-09 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21040	24	2015-02-09 15:47:00	2015-02-09 15:48:01
25106	SECRET	2015-02-09 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21305	25	2015-02-09 15:47:13	2015-02-09 15:48:04
25107	SECRET	2015-02-09 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21963	26	2015-02-09 15:47:22	2015-02-09 15:48:12
25108	PDTHON	2015-02-09 00:00:00	2017-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	21639	27	2015-02-09 15:47:40	2017-09-24 11:09:53
25115	VICPDT	2015-02-11 00:00:00	2015-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	21815	2	2015-02-11 11:00:53	2015-02-16 17:38:04
25116	VICPDT	2015-02-11 00:00:00	2015-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	22164	3	2015-02-11 11:01:02	2015-02-16 17:37:59
25117	VICPDT	2015-02-11 00:00:00	2015-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	20657	4	2015-02-11 11:01:09	2015-02-16 17:38:08
25118	VICPDT	2015-02-11 00:00:00	2015-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	21254	5	2015-02-11 11:01:13	2015-02-16 17:38:12
25119	PDT	2015-02-11 00:00:00	2015-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	20532	1	2015-02-11 11:01:19	2015-02-16 17:37:55
25120	SECRET	2015-02-11 00:00:00	2015-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	21617	6	2015-02-11 11:01:24	2015-02-16 17:38:18
25133	VICPDT	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22013	2	2015-02-11 16:39:07	2015-02-11 16:39:53
25134	VICPDT	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20505	3	2015-02-11 16:39:16	2015-02-11 16:39:56
22280	MEMBRE	2014-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20226	\N	\N	\N
22281	MEMBRE	2014-01-27 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20227	\N	\N	\N
22284	PDT	2014-01-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20230	1	2014-02-03 10:53:12	2014-02-03 10:59:26
22555	MEMBRE	2014-10-15 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20499	\N	2014-10-16 15:37:04	2017-04-27 16:00:50
22289	MEMBRE	2014-02-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20234	\N	\N	2014-03-06 17:36:23
22326	PDTDEL	2014-06-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour la Macédoine	\N	20270	4	2014-07-03 10:42:22	2014-09-28 16:54:10
22556	MEMBRE	2014-10-15 00:00:00	2015-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	20500	\N	2014-10-16 15:37:04	2017-04-27 16:00:50
22557	MEMBRE	2014-10-15 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20501	\N	2014-10-16 15:37:04	2017-04-27 16:00:50
22558	MEMBRE	2014-10-15 00:00:00	2016-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	20502	\N	2014-10-16 15:37:04	2017-04-27 16:00:50
22559	MEMBRE	2014-10-15 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20503	\N	2014-10-16 15:37:04	2017-04-27 16:00:50
22629	MEMBRE	2014-10-20 00:00:00	2015-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	20573	\N	2014-10-20 15:06:27	2015-01-28 10:26:33
22630	MEMBRE	2014-10-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20574	\N	2014-10-20 15:06:27	\N
22631	MEMBRE	2014-10-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20575	\N	2014-10-20 15:06:27	\N
22632	MEMBRE	2014-10-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20576	\N	2014-10-20 15:06:27	\N
22872	MEMBRE	2014-10-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20816	\N	2014-10-23 10:21:39	\N
22873	MEMBRE	2014-10-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20817	\N	2014-10-23 10:21:39	\N
22874	MEMBRE	2014-10-22 00:00:00	2015-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	20818	\N	2014-10-23 10:25:42	2015-01-30 15:54:31
22875	MEMBRE	2014-10-22 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	20819	\N	2014-10-23 10:25:42	2015-02-19 18:04:11
22876	MEMBRE	2014-10-22 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	20820	\N	2014-10-23 10:25:42	2015-02-02 13:25:39
22877	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20821	\N	2014-10-23 10:25:42	\N
22878	MEMBRE	2014-10-22 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	20822	\N	2014-10-23 10:25:42	2015-01-06 15:38:27
22879	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20823	\N	2014-10-23 10:25:42	\N
22880	MEMBRE	2014-10-22 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	20824	\N	2014-10-23 10:25:42	2015-02-11 12:10:20
22881	MEMBRE	2014-10-22 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	20825	\N	2014-10-23 10:25:42	2015-02-03 16:28:23
22882	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20826	\N	2014-10-23 10:25:42	\N
22883	MEMBRE	2014-10-22 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	20827	\N	2014-10-23 10:25:42	2015-02-03 10:20:07
22884	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20828	\N	2014-10-23 10:25:42	\N
22885	MEMBRE	2014-10-22 00:00:00	2015-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	20829	\N	2014-10-23 10:25:42	2015-02-09 15:40:39
22886	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20830	\N	2014-10-23 10:25:42	\N
22887	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20831	\N	2014-10-23 10:25:42	\N
22888	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20832	\N	2014-10-23 10:25:42	\N
22889	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20833	\N	2014-10-23 10:25:42	\N
22890	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20834	\N	2014-10-23 10:25:42	\N
22891	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20835	\N	2014-10-23 10:25:42	\N
22892	MEMBRE	2014-10-22 00:00:00	2015-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	20836	\N	2014-10-23 10:25:42	2015-03-06 09:53:15
22893	MEMBRE	2014-10-22 00:00:00	2015-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	20837	\N	2014-10-23 11:03:01	2015-01-30 09:39:52
22894	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20838	\N	2014-10-23 11:10:08	\N
22895	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20839	\N	2014-10-23 11:10:08	\N
22896	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20840	\N	2014-10-23 11:10:08	\N
22897	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20841	\N	2014-10-23 11:10:09	\N
22898	MEMBRE	2014-10-21 00:00:00	2015-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	20842	\N	2014-10-23 11:18:56	2015-03-19 10:02:20
22899	MEMBRE	2014-10-21 00:00:00	2015-08-30 00:00:00	ANCIEN	\N	\N	\N	\N	20843	\N	2014-10-23 11:18:56	2015-08-31 16:57:07
22900	MEMBRE	2014-10-21 00:00:00	2015-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	20844	\N	2014-10-23 11:18:56	2015-01-29 10:54:45
22901	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20845	\N	2014-10-23 11:18:56	\N
22902	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20846	\N	2014-10-23 11:18:56	\N
22903	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20847	\N	2014-10-23 11:20:16	\N
22904	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20848	\N	2014-10-23 11:20:16	\N
22905	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20849	\N	2014-10-23 11:20:16	\N
22906	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20850	\N	2014-10-23 11:20:16	\N
22907	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20851	\N	2014-10-23 11:20:16	\N
22908	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20852	\N	2014-10-23 11:20:16	\N
22909	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20853	\N	2014-10-23 11:20:16	\N
22910	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20854	\N	2014-10-23 11:20:16	\N
22911	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20855	\N	2014-10-23 11:20:16	\N
22912	MEMBRE	2014-10-22 00:00:00	2015-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	20856	\N	2014-10-23 11:20:16	2015-02-09 15:38:40
22913	MEMBRE	2014-10-22 00:00:00	2017-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	20857	\N	2014-10-23 11:21:12	2017-07-04 15:08:09
22914	MEMBRE	2014-10-22 00:00:00	2016-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	20858	\N	2014-10-23 11:21:12	2016-03-30 11:54:37
22915	MEMBRE	2014-10-22 00:00:00	2016-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	20859	\N	2014-10-23 11:21:12	2016-12-07 16:43:15
22916	MEMBRE	2014-10-22 00:00:00	2017-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	20860	\N	2014-10-23 11:21:12	2017-07-04 15:08:09
22917	MEMBRE	2014-10-22 00:00:00	2017-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	20861	\N	2014-10-23 11:21:12	2017-07-04 15:08:09
22918	MEMBRE	2014-10-22 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	20862	\N	2014-10-23 11:21:12	2015-02-13 15:13:02
22919	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20863	\N	2014-10-23 11:22:53	\N
22920	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20864	\N	2014-10-23 11:22:53	\N
22921	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20865	\N	2014-10-23 11:22:53	\N
22922	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20866	\N	2014-10-23 11:22:53	\N
22923	MEMBRE	2014-10-22 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	20867	\N	2014-10-23 11:22:53	2015-02-11 18:01:17
22924	MEMBRE	2014-10-22 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	20868	\N	2014-10-23 11:23:44	2015-02-13 10:35:26
22925	MEMBRE	2014-10-22 00:00:00	2015-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	20869	7	2014-10-23 11:23:44	2015-02-23 15:23:17
22926	MEMBRE	2014-10-22 00:00:00	2015-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	20870	\N	2014-10-23 11:23:44	2015-02-17 09:40:10
22927	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20871	\N	2014-10-23 11:23:44	\N
22928	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20872	\N	2014-10-23 11:23:45	\N
22929	MEMBRE	2014-10-22 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	20873	\N	2014-10-23 11:23:46	2015-02-02 13:24:38
22930	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20874	\N	2014-10-23 11:23:46	\N
22931	MEMBRE	2014-10-21 00:00:00	2015-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	20875	\N	2014-10-23 11:24:12	2015-02-23 11:39:55
22932	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20876	\N	2014-10-23 11:24:12	\N
22933	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20877	\N	2014-10-23 11:24:12	\N
22934	MEMBRE	2014-10-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20878	\N	2014-10-23 11:25:47	\N
22935	MEMBRE	2014-10-20 00:00:00	2015-03-09 00:00:00	ANCIEN	\N	\N	\N	\N	20879	\N	2014-10-23 11:25:47	2015-03-10 10:01:48
22936	MEMBRE	2014-10-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20880	\N	2014-10-23 11:25:47	\N
22937	MEMBRE	2014-10-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20881	\N	2014-10-23 11:25:47	\N
22938	MEMBRE	2014-10-20 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	20882	\N	2014-10-23 11:25:47	2015-02-05 18:51:55
22939	MEMBRE	2014-10-20 00:00:00	2015-04-09 00:00:00	ANCIEN	\N	\N	\N	\N	20883	\N	2014-10-23 11:25:47	2015-04-10 15:10:11
22940	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20884	\N	2014-10-23 11:31:42	\N
22941	MEMBRE	2014-10-22 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	20885	\N	2014-10-23 11:31:42	2015-02-05 18:58:38
22942	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20886	\N	2014-10-23 11:31:42	\N
22943	MEMBRE	2014-10-22 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	20887	\N	2014-10-23 11:31:42	2015-02-02 13:24:47
22944	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20888	\N	2014-10-23 11:31:42	\N
22945	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20889	\N	2014-10-23 11:31:42	\N
22946	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20890	\N	2014-10-23 11:31:42	\N
22947	MEMBRE	2014-10-22 00:00:00	2015-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	20891	\N	2014-10-23 11:31:42	2015-04-09 15:21:23
22948	MEMBRE	2014-10-22 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	20892	\N	2014-10-23 11:31:42	2015-01-06 16:33:46
22949	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20893	\N	2014-10-23 11:31:42	\N
22950	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20894	\N	2014-10-23 11:31:42	\N
22951	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20895	\N	2014-10-23 11:31:42	\N
22952	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20896	\N	2014-10-23 11:31:42	\N
22953	MEMBRE	2014-10-22 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	20897	\N	2014-10-23 11:31:42	2015-02-05 18:51:27
22954	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20898	\N	2014-10-23 11:38:53	\N
22955	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20899	\N	2014-10-23 11:38:53	\N
22956	MEMBRE	2014-10-22 00:00:00	2015-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	20900	\N	2014-10-23 11:38:53	2015-02-12 17:36:31
22957	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20901	\N	2014-10-23 11:38:53	\N
22958	MEMBRE	2014-10-22 00:00:00	2015-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	20902	\N	2014-10-23 11:38:53	2015-01-23 12:04:54
22959	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20903	\N	2014-10-23 11:40:00	\N
22960	MEMBRE	2014-10-15 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	20904	\N	2014-10-23 11:40:01	2015-02-11 17:18:22
22961	MEMBRE	2014-10-22 00:00:00	2015-03-08 00:00:00	ANCIEN	\N	\N	\N	\N	20905	\N	2014-10-23 11:53:35	2015-11-12 15:26:22
22962	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20906	\N	2014-10-23 11:54:21	\N
22567	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20511	\N	2014-10-17 14:42:06	\N
22568	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20512	\N	2014-10-17 14:42:06	\N
22569	MEMBRE	2014-10-15 00:00:00	2015-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	20513	\N	2014-10-17 14:42:06	2015-02-12 17:35:54
22570	MEMBRE	2014-10-15 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	20514	\N	2014-10-17 14:42:07	2015-01-06 15:39:27
22571	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20515	\N	2014-10-17 14:42:07	\N
22572	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20516	\N	2014-10-17 14:42:07	\N
22573	MEMBRE	2014-10-15 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	20517	\N	2014-10-17 14:42:07	2015-02-20 10:42:50
22574	MEMBRE	2014-10-15 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	20518	\N	2014-10-17 14:42:07	2015-02-05 19:03:18
22575	MEMBRE	2014-10-15 00:00:00	2015-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	20519	\N	2014-10-17 14:42:07	2015-02-12 12:43:01
22576	MEMBRE	2014-10-15 00:00:00	2015-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	20520	\N	2014-10-17 14:42:07	2015-03-19 09:57:33
22577	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20521	\N	2014-10-17 14:42:07	\N
22578	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20522	\N	2014-10-17 14:43:11	\N
22579	MEMBRE	2014-10-15 00:00:00	2015-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	20523	\N	2014-10-17 14:43:11	2015-01-29 10:53:19
22580	MEMBRE	2014-10-15 00:00:00	2015-01-21 00:00:00	ANCIEN	\N	\N	\N	\N	20524	\N	2014-10-17 14:43:11	2015-01-22 10:49:54
22581	MEMBRE	2014-10-15 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	20525	\N	2014-10-17 14:43:11	2015-01-06 15:22:37
22582	MEMBRE	2014-10-15 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	20526	\N	2014-10-17 14:43:11	2015-01-06 17:34:27
22583	MEMBRE	2014-10-15 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	20527	\N	2014-10-17 14:43:11	2015-02-20 10:42:11
22584	MEMBRE	2014-10-15 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	20528	\N	2014-10-17 14:43:11	2015-02-05 19:03:25
22585	MEMBRE	2014-10-15 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	20529	\N	2014-10-17 14:43:11	2015-02-20 10:46:37
22586	MEMBRE	2014-10-15 00:00:00	2015-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	20530	\N	2014-10-17 14:43:11	2015-02-12 12:43:15
22587	MEMBRE	2014-10-15 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	20531	\N	2014-10-17 14:43:11	2015-02-03 10:20:44
22588	MEMBRE	2014-10-16 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	20532	\N	2014-10-17 14:43:54	2015-02-11 11:01:19
22589	MEMBRE	2014-10-16 00:00:00	2015-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	20533	\N	2014-10-17 14:43:54	2015-01-27 17:08:31
22963	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20907	\N	2014-10-23 11:54:21	\N
22964	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20908	\N	2014-10-23 11:54:21	\N
22965	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20909	\N	2014-10-23 11:54:21	\N
22966	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20910	\N	2014-10-23 11:54:21	\N
22967	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20911	\N	2014-10-23 11:54:21	\N
22968	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20912	\N	2014-10-23 11:54:21	\N
22969	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20913	\N	2014-10-23 11:54:21	\N
22970	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20914	\N	2014-10-23 11:54:21	\N
22971	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20915	\N	2014-10-23 11:54:21	\N
22972	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20916	\N	2014-10-23 11:56:12	\N
22973	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20917	\N	2014-10-23 11:56:12	\N
22974	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20918	\N	2014-10-23 11:56:12	\N
22975	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20919	\N	2014-10-23 11:56:12	\N
22976	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20920	\N	2014-10-23 11:56:12	\N
22977	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20921	\N	2014-10-23 11:56:12	\N
22978	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20922	\N	2014-10-23 11:56:12	\N
22979	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20923	\N	2014-10-23 11:56:12	\N
22980	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20924	\N	2014-10-23 11:56:12	\N
22981	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20925	\N	2014-10-23 11:56:12	\N
22982	MEMBRE	2014-10-22 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	20926	\N	2014-10-23 11:56:12	2015-02-13 11:37:39
22983	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20927	\N	2014-10-23 11:56:12	\N
22984	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20928	\N	2014-10-23 11:56:12	\N
22985	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20929	\N	2014-10-23 11:56:12	\N
22986	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20930	\N	2014-10-23 11:56:12	\N
22987	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20931	\N	2014-10-23 11:56:12	\N
22988	MEMBRE	2014-10-22 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	20932	\N	2014-10-23 11:56:12	2015-01-06 17:17:08
22989	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20933	\N	2014-10-23 11:56:12	\N
22990	MEMBRE	2014-10-15 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	20934	\N	2014-10-23 11:56:44	2015-02-13 11:34:16
22991	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20935	\N	2014-10-23 11:56:44	\N
22992	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20936	\N	2014-10-23 11:58:18	\N
22993	MEMBRE	2014-10-22 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	20937	\N	2014-10-23 11:58:18	2015-01-06 16:26:13
22994	MEMBRE	2014-10-22 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	20938	\N	2014-10-23 11:58:18	2015-02-19 15:42:43
22995	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20939	\N	2014-10-23 11:58:18	\N
22996	MEMBRE	2014-10-22 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	20940	\N	2014-10-23 11:58:18	2015-02-05 18:54:46
22997	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20941	\N	2014-10-23 11:58:18	\N
22998	MEMBRE	2014-10-22 00:00:00	2015-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	20942	\N	2014-10-23 11:58:18	2015-01-29 10:53:50
22999	MEMBRE	2014-10-22 00:00:00	2015-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	20943	\N	2014-10-23 11:58:18	2015-02-06 14:46:14
23000	MEMBRE	2014-10-22 00:00:00	2015-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	20944	\N	2014-10-23 11:58:18	2015-02-12 15:35:46
23001	MEMBRE	2014-10-22 00:00:00	2016-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	20945	\N	2014-10-23 11:58:18	2016-12-07 16:41:20
23002	MEMBRE	2014-10-22 00:00:00	2015-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	20946	\N	2014-10-23 11:58:18	2015-01-29 10:52:47
23003	MEMBRE	2014-10-22 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	20947	\N	2014-10-23 11:58:18	2015-02-13 15:14:34
23004	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20948	\N	2014-10-23 12:07:32	\N
23005	MEMBRE	2014-10-21 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	20949	\N	2014-10-23 12:07:32	2015-02-03 16:28:15
23006	MEMBRE	2014-10-21 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	20950	\N	2014-10-23 12:07:32	2015-01-06 16:04:07
23007	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20951	\N	2014-10-23 12:07:32	\N
23008	MEMBRE	2014-10-21 00:00:00	2016-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	20952	\N	2014-10-23 12:07:32	2016-12-07 16:42:38
23009	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20953	\N	2014-10-23 12:13:26	\N
23010	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20954	\N	2014-10-23 12:13:26	\N
23011	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20955	\N	2014-10-23 12:14:53	\N
23012	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20956	\N	2014-10-23 12:14:53	\N
23013	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20957	\N	2014-10-23 12:14:53	\N
23014	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20958	\N	2014-10-23 12:14:53	\N
23015	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20959	\N	2014-10-23 12:14:53	\N
23016	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20960	\N	2014-10-23 12:14:53	\N
23017	MEMBRE	2014-10-15 00:00:00	2015-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	20961	\N	2014-10-23 12:14:53	2015-01-19 14:16:42
23018	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20962	\N	2014-10-23 12:14:53	\N
23019	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20963	\N	2014-10-23 12:14:53	\N
23020	MEMBRE	2014-10-15 00:00:00	2017-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	20964	\N	2014-10-23 12:14:53	2017-07-20 14:38:49
23021	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20965	\N	2014-10-23 12:14:53	\N
23022	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20966	\N	2014-10-23 12:14:53	\N
23023	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20967	\N	2014-10-23 12:14:53	\N
23024	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20968	\N	2014-10-23 12:14:53	\N
23025	MEMBRE	2014-10-15 00:00:00	2015-03-19 00:00:00	ANCIEN	\N	\N	\N	\N	20969	\N	2014-10-23 12:14:53	2015-03-20 18:13:24
23026	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20970	\N	2014-10-23 12:17:24	\N
23027	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20971	\N	2014-10-23 12:17:24	\N
23028	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20972	\N	2014-10-23 12:17:24	\N
23029	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20973	\N	2014-10-23 12:17:24	\N
23030	MEMBRE	2014-10-21 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	20974	\N	2014-10-23 12:18:22	2015-01-06 15:54:58
23031	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20975	\N	2014-10-23 12:18:22	\N
23032	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20976	\N	2014-10-23 12:18:22	\N
23033	MEMBRE	2014-10-21 00:00:00	2015-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	20977	\N	2014-10-23 12:18:22	2015-02-16 17:42:47
23034	MEMBRE	2014-10-21 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	20978	\N	2014-10-23 12:18:22	2015-01-06 17:12:08
23035	MEMBRE	2014-10-21 00:00:00	2015-03-19 00:00:00	ANCIEN	\N	\N	\N	\N	20979	\N	2014-10-23 12:18:22	2015-03-20 09:53:19
23036	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20980	\N	2014-10-23 12:18:22	\N
23037	MEMBRE	2014-10-21 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	20981	\N	2014-10-23 12:20:34	2015-02-13 10:35:33
23038	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20982	\N	2014-10-23 12:20:34	\N
23039	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20983	\N	2014-10-23 12:20:34	\N
23040	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20984	\N	2014-10-23 12:22:05	\N
23041	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20985	\N	2014-10-23 12:22:05	\N
23042	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20986	\N	2014-10-23 12:22:05	\N
23043	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20987	\N	2014-10-23 12:22:05	\N
23044	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20988	\N	2014-10-23 12:22:05	\N
22262	MEMBRE	2013-11-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20210	\N	2013-11-19 11:01:32	\N
22441	MEMBRE	2014-10-14 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	20385	\N	2014-10-15 16:46:40	2015-02-05 19:02:55
22442	MEMBRE	2014-10-14 00:00:00	2015-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	20386	\N	2014-10-15 16:46:40	2015-04-07 16:50:27
22443	MEMBRE	2014-10-14 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	20387	\N	2014-10-15 16:46:40	2015-01-06 16:28:03
22444	MEMBRE	2014-10-14 00:00:00	2015-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	20388	\N	2014-10-15 16:46:40	2015-04-07 16:50:27
22445	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20389	\N	2014-10-15 16:47:00	\N
22446	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20390	\N	2014-10-15 16:47:00	\N
22666	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20610	\N	2014-10-22 10:15:43	\N
22667	MEMBRE	2014-10-22 00:00:00	2015-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	20611	\N	2014-10-22 10:36:50	2015-02-04 10:19:05
22668	MEMBRE	2014-10-22 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	20612	\N	2014-10-22 10:36:50	2015-02-03 16:27:31
22669	MEMBRE	2014-10-22 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	20613	\N	2014-10-22 10:36:50	2015-02-19 16:23:46
22670	MEMBRE	2014-10-22 00:00:00	2015-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	20614	\N	2014-10-22 10:36:50	2015-01-29 10:52:11
22671	MEMBRE	2014-10-22 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	20615	\N	2014-10-22 10:36:50	2015-01-06 16:06:37
22672	MEMBRE	2014-10-22 00:00:00	2015-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	20616	\N	2014-10-22 10:36:50	2015-01-19 14:15:06
22673	MEMBRE	2014-10-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20617	\N	2014-10-22 10:41:16	\N
22674	MEMBRE	2014-10-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20618	\N	2014-10-22 10:41:16	\N
22675	MEMBRE	2014-10-17 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	20619	\N	2014-10-22 10:41:16	2015-02-20 12:00:14
22676	MEMBRE	2014-10-17 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	20620	\N	2014-10-22 10:41:16	2015-01-06 15:33:34
22677	MEMBRE	2014-10-17 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	20621	\N	2014-10-22 10:41:16	2015-02-20 10:42:33
22678	MEMBRE	2014-10-17 00:00:00	2015-08-30 00:00:00	ANCIEN	\N	\N	\N	\N	20622	7	2014-10-22 10:41:16	2015-08-31 09:34:50
22679	MEMBRE	2014-10-21 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	20623	\N	2014-10-22 10:46:39	2015-02-11 18:01:35
22680	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20624	\N	2014-10-22 10:46:39	\N
22681	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20625	\N	2014-10-22 10:46:39	\N
22682	MEMBRE	2014-10-21 00:00:00	2015-01-21 00:00:00	ANCIEN	\N	\N	\N	\N	20626	\N	2014-10-22 10:46:39	2015-01-22 10:51:39
22683	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20627	\N	2014-10-22 10:46:39	\N
22684	MEMBRE	2014-10-21 00:00:00	2015-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	20628	\N	2014-10-22 10:46:39	2015-01-14 10:31:45
22685	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20629	\N	2014-10-22 10:46:39	\N
22686	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20630	\N	2014-10-22 10:46:39	\N
22687	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20631	\N	2014-10-22 10:46:39	\N
22688	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20632	\N	2014-10-22 10:46:39	\N
22689	MEMBRE	2014-10-21 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	20633	\N	2014-10-22 10:46:39	2015-02-19 16:29:46
22690	MEMBRE	2014-10-21 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	20634	\N	2014-10-22 10:46:39	2015-02-11 16:40:18
22691	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20635	\N	2014-10-22 10:46:39	\N
22692	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20636	\N	2014-10-22 10:46:39	\N
22693	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20637	\N	2014-10-22 10:46:39	\N
22694	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20638	\N	2014-10-22 10:46:39	\N
22695	MEMBRE	2014-10-21 00:00:00	2017-07-20 00:00:00	ANCIEN	\N	\N	\N	\N	20639	\N	2014-10-22 10:46:39	2017-07-20 18:35:52
22696	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20640	\N	2014-10-22 10:46:39	\N
22697	MEMBRE	2014-10-15 00:00:00	2015-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	20641	\N	2014-10-22 10:47:14	2015-02-04 14:26:44
22698	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20642	\N	2014-10-22 10:47:32	\N
22699	MEMBRE	2014-10-21 00:00:00	2015-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	20643	\N	2014-10-22 10:47:32	2015-02-12 17:36:13
22700	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20644	\N	2014-10-22 10:47:32	\N
22701	MEMBRE	2014-10-17 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	20645	\N	2014-10-22 10:48:27	2015-02-20 12:12:35
22702	MEMBRE	2014-10-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20646	\N	2014-10-22 10:48:27	\N
22703	MEMBRE	2014-10-17 00:00:00	2015-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	20647	\N	2014-10-22 10:48:27	2015-02-12 17:36:45
22704	MEMBRE	2014-10-17 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	20648	\N	2014-10-22 10:48:27	2015-03-03 14:02:40
22705	MEMBRE	2014-10-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20649	\N	2014-10-22 10:48:27	\N
22706	MEMBRE	2014-10-14 00:00:00	2016-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20650	\N	2014-10-22 10:49:21	2017-01-03 11:09:24
22707	MEMBRE	2014-10-14 00:00:00	2016-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20651	\N	2014-10-22 10:49:21	2017-01-03 11:09:24
22708	MEMBRE	2014-10-14 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	20652	\N	2014-10-22 10:49:21	2015-02-11 16:59:14
22709	MEMBRE	2014-10-14 00:00:00	2016-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20653	\N	2014-10-22 10:49:21	2017-01-03 11:09:24
22710	MEMBRE	2014-10-14 00:00:00	2016-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20654	\N	2014-10-22 10:49:21	2017-01-03 11:09:24
22711	MEMBRE	2014-10-14 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	20655	\N	2014-10-22 10:49:21	2015-01-06 16:23:11
22713	MEMBRE	2014-10-14 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	20657	\N	2014-10-22 10:49:21	2015-02-11 11:01:09
22714	MEMBRE	2014-10-14 00:00:00	2015-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	20658	\N	2014-10-22 10:49:21	2015-01-29 12:01:40
22716	MEMBRE	2014-10-14 00:00:00	2016-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20660	\N	2014-10-22 10:49:21	2017-01-03 11:09:24
22717	MEMBRE	2014-10-14 00:00:00	2016-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	20661	\N	2014-10-22 10:49:21	2016-12-07 16:41:46
22718	MEMBRE	2014-10-16 00:00:00	2015-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	20662	\N	2014-10-22 11:07:44	2015-02-04 18:16:23
22719	MEMBRE	2014-10-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20663	\N	2014-10-22 11:07:44	\N
22720	MEMBRE	2014-10-16 00:00:00	2015-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	20664	\N	2014-10-22 11:07:44	2015-03-04 17:15:43
22721	MEMBRE	2014-10-16 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	20665	\N	2014-10-22 11:07:44	2015-02-05 12:05:10
22722	MEMBRE	2014-10-16 00:00:00	2015-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	20666	\N	2014-10-22 11:07:44	2015-01-28 10:26:02
22723	MEMBRE	2014-10-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20667	\N	2014-10-22 11:07:44	\N
22724	MEMBRE	2014-10-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20668	\N	2014-10-22 11:07:44	\N
22725	MEMBRE	2014-10-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20669	\N	2014-10-22 11:07:44	\N
22726	MEMBRE	2014-10-15 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	20670	\N	2014-10-22 11:08:04	2015-01-06 16:24:03
22727	MEMBRE	2014-10-15 00:00:00	2015-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	20671	\N	2014-10-22 11:08:04	2015-02-12 17:35:39
22728	MEMBRE	2014-10-15 00:00:00	2015-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	20672	\N	2014-10-22 11:08:04	2015-02-09 11:04:00
22729	MEMBRE	2014-10-16 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	20673	\N	2014-10-22 11:08:29	2017-04-27 16:00:50
22730	MEMBRE	2014-10-16 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20674	\N	2014-10-22 11:08:29	2017-04-27 16:00:50
22733	MEMBRE	2014-10-20 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	20677	\N	2014-10-22 11:15:25	2015-01-06 16:23:35
22734	MEMBRE	2014-10-20 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	20678	\N	2014-10-22 11:15:25	2015-06-12 15:59:49
22735	MEMBRE	2014-10-20 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	20679	\N	2014-10-22 11:15:25	2015-02-20 10:43:10
22736	MEMBRE	2014-10-20 00:00:00	2015-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	20680	\N	2014-10-22 11:15:25	2015-02-17 16:20:16
22737	MEMBRE	2014-10-20 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	20681	\N	2014-10-22 11:15:25	2015-06-12 15:59:49
22738	MEMBRE	2014-10-20 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	20682	\N	2014-10-22 11:15:25	2015-06-12 15:59:49
22739	MEMBRE	2014-10-20 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	20683	\N	2014-10-22 11:15:25	2015-02-11 16:58:30
22740	MEMBRE	2014-10-20 00:00:00	2015-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	20684	\N	2014-10-22 11:15:25	2015-02-10 11:22:22
22741	MEMBRE	2014-10-20 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	20685	\N	2014-10-22 11:15:25	2015-06-12 15:59:49
22742	MEMBRE	2014-10-20 00:00:00	2015-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	20686	\N	2014-10-22 11:15:25	2015-01-29 12:01:34
22743	MEMBRE	2014-10-20 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	20687	\N	2014-10-22 11:15:25	2015-06-12 15:59:49
22744	MEMBRE	2014-10-20 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	20688	\N	2014-10-22 11:15:25	2015-06-12 15:59:49
22745	MEMBRE	2014-10-20 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	20689	\N	2014-10-22 11:15:25	2015-06-12 15:59:49
22746	MEMBRE	2014-10-20 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	20690	\N	2014-10-22 11:15:25	2015-02-05 19:00:16
22747	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20691	\N	2014-10-22 11:28:24	\N
22748	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20692	\N	2014-10-22 11:28:24	\N
22749	MEMBRE	2014-10-22 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	20693	\N	2014-10-22 11:28:24	2015-01-06 17:49:12
22750	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20694	\N	2014-10-22 11:28:24	\N
22752	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20696	\N	2014-10-22 11:46:04	\N
22753	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20697	\N	2014-10-22 11:46:04	\N
22754	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20698	\N	2014-10-22 11:46:04	\N
22755	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20699	\N	2014-10-22 11:46:04	\N
22756	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20700	\N	2014-10-22 11:46:04	\N
22757	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20701	\N	2014-10-22 11:46:04	\N
22758	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20702	\N	2014-10-22 11:46:04	\N
22759	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20703	\N	2014-10-22 11:46:04	\N
22760	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20704	\N	2014-10-22 11:46:04	\N
22761	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20705	\N	2014-10-22 11:46:04	\N
23045	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20989	\N	2014-10-23 12:22:05	\N
23046	MEMBRE	2014-10-21 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	20990	\N	2014-10-23 12:22:38	2015-01-06 17:14:46
23047	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20991	\N	2014-10-23 12:22:38	\N
23087	MEMBRE	2014-10-22 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21031	\N	2014-10-24 09:24:38	2015-01-06 16:01:57
23088	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21032	\N	2014-10-24 09:24:38	\N
23089	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21033	\N	2014-10-24 09:24:38	\N
23090	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21034	\N	2014-10-24 09:24:38	\N
23091	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21035	\N	2014-10-24 09:24:38	\N
23092	MEMBRE	2014-10-23 00:00:00	2015-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	21036	\N	2014-10-24 09:25:02	2015-03-11 12:57:26
23093	MEMBRE	2014-10-23 00:00:00	2015-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	21037	\N	2014-10-24 09:25:02	2015-01-28 10:27:13
23094	MEMBRE	2014-10-23 00:00:00	2015-03-19 00:00:00	ANCIEN	\N	\N	\N	\N	21038	\N	2014-10-24 09:25:02	2015-03-20 18:13:34
23095	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21039	\N	2014-10-24 09:34:35	\N
23096	MEMBRE	2014-10-22 00:00:00	2015-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	21040	\N	2014-10-24 09:34:35	2015-02-09 15:47:00
23097	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21041	\N	2014-10-24 09:34:35	\N
23098	MEMBRE	2014-10-22 00:00:00	2017-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	21042	\N	2014-10-24 09:34:35	2017-07-20 14:38:36
23099	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21043	\N	2014-10-24 09:34:35	\N
23100	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21044	\N	2014-10-24 09:34:35	\N
23101	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21045	\N	2014-10-24 09:34:59	\N
23102	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21046	\N	2014-10-24 09:34:59	\N
23103	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21047	\N	2014-10-24 09:35:49	\N
23104	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21048	\N	2014-10-24 09:35:49	\N
23105	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21049	\N	2014-10-24 09:35:49	\N
23106	MEMBRE	2014-10-22 00:00:00	2015-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	21050	\N	2014-10-24 09:35:49	2015-02-04 10:18:40
23107	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21051	\N	2014-10-24 09:35:49	\N
23108	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21052	\N	2014-10-24 09:35:49	\N
23109	MEMBRE	2014-10-21 00:00:00	2015-03-19 00:00:00	ANCIEN	\N	\N	\N	\N	21053	\N	2014-10-24 09:36:09	2015-03-20 11:38:42
23110	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21054	\N	2014-10-24 09:36:09	\N
23111	MEMBRE	2014-10-22 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21055	\N	2014-10-24 09:38:25	2015-01-06 17:34:37
23112	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21056	\N	2014-10-24 09:38:25	\N
23113	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21057	\N	2014-10-24 09:38:25	\N
23114	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21058	\N	2014-10-24 09:38:25	\N
23115	MEMBRE	2014-10-20 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21059	\N	2014-10-24 09:39:14	2015-01-06 16:00:18
23116	MEMBRE	2014-10-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21060	\N	2014-10-24 09:39:14	\N
23117	MEMBRE	2014-10-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21061	\N	2014-10-24 09:39:14	\N
23118	MEMBRE	2014-10-20 00:00:00	2015-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	21062	\N	2014-10-24 09:39:14	2015-02-09 15:43:17
23196	MEMBRE	2014-10-24 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21140	\N	2014-10-24 12:44:33	\N
23197	MEMBRE	2014-10-24 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21141	\N	2014-10-24 12:44:33	\N
23198	MEMBRE	2014-10-24 00:00:00	2015-08-30 00:00:00	ANCIEN	\N	\N	\N	\N	21142	\N	2014-10-24 12:44:33	2015-08-31 09:59:18
23199	MEMBRE	2014-10-21 00:00:00	2015-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	21143	\N	2014-10-24 12:53:46	2015-02-12 12:45:34
23200	MEMBRE	2014-10-21 00:00:00	2015-09-02 00:00:00	ANCIEN	\N	\N	\N	\N	21144	\N	2014-10-24 12:53:46	2015-08-31 09:33:49
23201	MEMBRE	2014-10-21 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21145	\N	2014-10-24 12:53:46	\N
23202	MEMBRE	2014-10-21 00:00:00	2015-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	21146	\N	2014-10-24 12:53:46	2015-02-13 15:14:12
23203	MEMBRE	2014-10-21 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21147	\N	2014-10-24 12:53:46	\N
23204	MEMBRE	2014-10-21 00:00:00	2015-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	21148	\N	2014-10-24 12:53:46	2015-02-05 12:05:32
23205	MEMBRE	2014-10-21 00:00:00	2015-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	21149	\N	2014-10-24 12:53:46	2015-02-05 19:03:01
23206	MEMBRE	2014-10-21 00:00:00	2015-03-08 00:00:00	ANCIEN	\N	\N	\N	\N	21150	\N	2014-10-24 12:53:46	2015-03-06 09:53:30
23207	MEMBRE	2014-10-21 00:00:00	2015-05-29 00:00:00	ANCIEN	\N	\N	\N	\N	21151	\N	2014-10-24 12:53:46	2015-05-27 16:38:47
23208	MEMBRE	2014-10-21 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21152	\N	2014-10-24 12:53:46	\N
23209	MEMBRE	2014-10-21 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21153	\N	2014-10-24 12:53:46	\N
23210	MEMBRE	2014-10-21 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21154	\N	2014-10-24 12:53:46	\N
23211	MEMBRE	2014-10-21 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21155	\N	2014-10-24 12:53:46	\N
23212	MEMBRE	2014-10-21 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21156	\N	2014-10-24 12:53:46	\N
23213	MEMBRE	2014-10-21 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	21157	\N	2014-10-24 12:53:46	2015-02-10 11:23:21
23214	MEMBRE	2014-10-21 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21158	\N	2014-10-24 12:53:46	\N
23215	MEMBRE	2014-10-21 00:00:00	2015-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	21159	\N	2014-10-24 12:53:46	2015-02-11 17:12:16
23216	MEMBRE	2014-10-21 00:00:00	2015-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	21160	\N	2014-10-24 12:53:46	2015-01-14 10:01:58
23217	MEMBRE	2014-10-21 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21161	\N	2014-10-24 12:53:46	\N
23218	MEMBRE	2014-10-21 00:00:00	2015-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	21162	\N	2014-10-24 12:53:46	2015-02-09 11:03:14
23219	MEMBRE	2014-10-21 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21163	\N	2014-10-24 12:53:46	\N
23220	MEMBRE	2014-10-21 00:00:00	2015-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	21164	\N	2014-10-24 12:53:46	2015-02-11 17:25:32
23221	MEMBRE	2014-10-21 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	21165	\N	2014-10-24 12:53:46	2015-02-17 16:13:26
23222	MEMBRE	2014-10-21 00:00:00	2015-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	21166	\N	2014-10-24 12:53:46	2015-02-12 15:35:32
23223	MEMBRE	2014-10-21 00:00:00	2015-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	21167	\N	2014-10-24 12:53:46	2015-02-19 18:04:21
23224	MEMBRE	2014-10-21 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21168	\N	2014-10-24 12:53:46	\N
23225	MEMBRE	2014-10-21 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21169	\N	2014-10-24 12:53:46	\N
23226	MEMBRE	2014-10-14 00:00:00	2015-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	21170	\N	2014-10-24 12:54:38	2015-03-02 11:07:18
23227	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21171	\N	2014-10-24 12:54:38	\N
23228	MEMBRE	2014-10-14 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21172	\N	2014-10-24 12:54:38	2015-01-06 16:19:17
23229	MEMBRE	2014-10-14 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21173	\N	2014-10-24 12:54:38	2015-01-06 16:22:22
23230	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21174	\N	2014-10-24 12:54:38	\N
23231	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21175	\N	2014-10-24 12:54:38	\N
23232	MEMBRE	2014-10-14 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	21176	\N	2014-10-24 12:54:38	2015-02-11 12:11:16
23233	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21123	\N	2014-10-24 13:00:20	\N
23236	MEMBRE	2014-10-22 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21107	\N	2014-10-24 13:00:20	2015-01-06 16:37:25
23237	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21111	\N	2014-10-24 13:00:20	\N
23239	MEMBRE	2014-10-22 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	21108	\N	2014-10-24 13:00:20	2015-02-05 12:17:08
23241	MEMBRE	2014-10-22 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	21116	\N	2014-10-24 13:00:20	2015-02-05 19:02:43
23243	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21128	\N	2014-10-24 13:00:20	\N
23244	MEMBRE	2014-10-22 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	21110	\N	2014-10-24 13:00:20	2015-02-20 10:50:48
23247	MEMBRE	2014-10-22 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	21139	\N	2014-10-24 13:00:20	2015-02-20 10:42:03
23248	MEMBRE	2014-10-22 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	21132	\N	2014-10-24 13:00:20	2015-02-11 17:12:10
23249	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21126	\N	2014-10-24 13:00:20	\N
23250	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21133	\N	2014-10-24 13:00:20	\N
23252	MEMBRE	2014-10-22 00:00:00	2015-01-21 00:00:00	ANCIEN	\N	\N	\N	\N	21134	\N	2014-10-24 13:00:20	2015-01-22 10:49:16
23255	MEMBRE	2014-10-22 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	21114	\N	2014-10-24 13:00:20	2015-02-13 09:50:24
23257	MEMBRE	2014-10-22 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	21120	\N	2014-10-24 13:00:20	2015-02-19 18:04:17
23260	MEMBRE	2014-10-22 00:00:00	2015-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	21113	\N	2014-10-24 13:00:20	2015-02-06 16:57:07
23261	MEMBRE	2014-10-22 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	21119	\N	2014-10-24 13:00:20	2015-02-11 12:11:04
23295	MEMBRE	2014-10-24 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21206	\N	2014-10-27 09:21:50	\N
23296	MEMBRE	2014-10-24 00:00:00	2015-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	21207	\N	2014-10-27 09:24:36	2015-01-29 10:53:55
23297	MEMBRE	2014-10-24 00:00:00	2015-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	21208	\N	2014-10-27 09:24:36	2015-02-17 09:41:13
22265	MEMBRE	2013-11-29 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20211	\N	\N	2013-11-29 16:16:31
22266	MEMBRE	2013-11-29 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20212	\N	\N	2013-11-29 16:16:45
22323	MEMBRE	2014-06-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20267	\N	2014-07-01 10:10:47	\N
22324	MEMBRE	2014-06-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20268	\N	2014-07-01 10:11:49	2014-07-01 10:11:56
22325	MEMBRE	2014-06-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20269	\N	2014-07-01 10:12:34	\N
22328	MEMBRE	2014-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20272	\N	2014-07-18 16:44:24	\N
22337	MEMBRE	2014-09-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20281	\N	2014-09-03 17:12:23	\N
22338	MEMBRE	2014-09-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20282	\N	2014-09-03 17:12:55	\N
22339	MEMBRE	2014-09-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20283	\N	2014-09-03 17:13:32	\N
22340	MEMBRE	2014-09-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20284	\N	2014-09-03 17:14:14	\N
22341	MEMBRE	2014-09-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20285	\N	2014-09-03 17:15:47	\N
22342	MEMBRE	2014-09-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20286	\N	2014-09-03 17:16:20	\N
22633	MEMBRE	2014-10-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20577	\N	2014-10-20 17:44:43	\N
22634	MEMBRE	2014-10-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20578	\N	2014-10-20 17:44:43	\N
22635	MEMBRE	2014-10-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20579	\N	2014-10-20 17:44:43	\N
22636	MEMBRE	2014-10-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20580	\N	2014-10-20 17:44:43	\N
22637	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20581	\N	2014-10-20 17:45:03	\N
22638	MEMBRE	2014-10-15 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	20582	\N	2014-10-20 17:45:03	2015-02-13 10:34:14
22639	MEMBRE	2014-10-15 00:00:00	2015-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	20583	\N	2014-10-20 17:45:03	2015-02-09 15:40:50
22640	MEMBRE	2014-10-15 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	20584	\N	2014-10-20 17:45:03	2015-01-06 16:31:50
22641	MEMBRE	2014-10-17 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	20585	\N	2014-10-20 17:45:19	2015-02-11 17:12:04
22808	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20752	\N	2014-10-22 15:49:52	\N
22809	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20753	\N	2014-10-22 15:49:52	\N
22810	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20754	\N	2014-10-22 15:49:52	\N
22811	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20755	\N	2014-10-22 15:49:52	\N
23298	MEMBRE	2014-10-24 00:00:00	2015-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	21209	\N	2014-10-27 09:24:36	2015-01-27 17:08:18
23299	MEMBRE	2014-10-24 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21210	\N	2014-10-27 09:24:36	\N
23300	MEMBRE	2014-10-24 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21211	\N	2014-10-27 09:24:36	\N
23301	MEMBRE	2014-10-24 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21212	\N	2014-10-27 09:24:37	\N
23302	MEMBRE	2014-10-24 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21213	\N	2014-10-27 09:24:37	2015-01-06 17:46:36
23303	MEMBRE	2014-10-24 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21214	\N	2014-10-27 09:24:37	\N
23304	MEMBRE	2014-10-24 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21215	\N	2014-10-27 09:24:37	\N
23305	MEMBRE	2014-10-24 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	21216	\N	2014-10-27 09:24:37	2015-02-11 18:02:10
23306	MEMBRE	2014-10-24 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21217	\N	2014-10-27 09:24:37	\N
23307	MEMBRE	2014-10-24 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21218	\N	2014-10-27 09:24:37	\N
23308	MEMBRE	2014-10-24 00:00:00	2014-10-26 00:00:00	ANCIEN	\N	\N	\N	\N	21219	\N	2014-10-27 09:24:37	2014-10-27 15:59:49
23309	MEMBRE	2014-10-24 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21220	\N	2014-10-27 09:24:37	\N
23310	MEMBRE	2014-10-24 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21221	\N	2014-10-27 09:24:37	\N
23311	MEMBRE	2014-10-24 00:00:00	2015-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	21222	\N	2014-10-27 09:24:37	2015-02-04 17:40:05
23312	MEMBRE	2014-10-24 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21223	\N	2014-10-27 09:24:37	\N
23313	MEMBRE	2014-10-22 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	21224	\N	2014-10-27 09:25:23	2015-02-11 17:12:24
23314	MEMBRE	2014-10-22 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21225	\N	2014-10-27 09:25:23	2015-01-06 17:35:37
23315	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21226	\N	2014-10-27 09:25:23	\N
23316	MEMBRE	2014-10-27 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21227	\N	2014-10-27 16:00:30	2015-01-06 15:29:31
23374	MEMBRE	2014-10-28 00:00:00	2014-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	21285	\N	2014-10-28 15:41:39	2014-12-18 16:15:04
23375	MEMBRE	2014-10-28 00:00:00	2014-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	21286	\N	2014-10-28 15:41:39	2014-12-18 16:15:04
23376	MEMBRE	2014-10-28 00:00:00	2014-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	21287	\N	2014-10-28 15:41:39	2014-12-18 16:15:04
23377	MEMBRE	2014-10-28 00:00:00	2014-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	21288	\N	2014-10-28 15:41:39	2014-12-18 16:15:04
23378	MEMBRE	2014-10-28 00:00:00	2014-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	21289	\N	2014-10-28 15:41:39	2014-12-18 16:15:04
23379	MEMBRE	2014-10-28 00:00:00	2014-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	21290	\N	2014-10-28 15:41:39	2014-12-18 16:15:04
23380	MEMBRE	2014-10-28 00:00:00	2014-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	21291	\N	2014-10-28 15:41:39	2014-12-18 16:15:04
23381	MEMBRE	2014-10-28 00:00:00	2014-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	21292	\N	2014-10-28 15:41:39	2014-12-18 16:15:04
23382	MEMBRE	2014-10-28 00:00:00	2014-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	21293	\N	2014-10-28 15:41:39	2014-12-18 16:15:04
23383	MEMBRE	2014-10-28 00:00:00	2014-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	21294	\N	2014-10-28 15:41:39	2014-12-18 16:15:04
23384	MEMBRE	2014-10-28 00:00:00	2014-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	21295	\N	2014-10-28 15:41:39	2014-12-18 16:15:04
23462	MEMBRE	2014-10-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21373	\N	2014-10-28 18:51:00	\N
23463	MEMBRE	2014-10-23 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	21374	\N	2014-10-28 18:51:00	2015-02-05 18:57:57
23464	MEMBRE	2014-10-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21375	\N	2014-10-28 18:51:00	\N
23465	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21376	\N	2014-10-28 18:51:21	\N
23466	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21377	\N	2014-10-28 18:51:21	\N
23467	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21378	\N	2014-10-28 18:51:21	\N
23468	MEMBRE	2014-10-28 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21379	\N	2014-10-28 18:51:21	2015-01-06 17:44:02
23469	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21380	\N	2014-10-28 18:51:21	\N
23470	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21381	\N	2014-10-28 18:52:03	\N
23471	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21382	\N	2014-10-28 18:52:03	\N
23975	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21886	\N	2014-10-31 10:05:40	\N
23976	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21887	\N	2014-10-31 10:05:40	\N
23977	MEMBRE	2014-10-29 00:00:00	2015-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	21888	\N	2014-10-31 10:05:40	2015-02-09 15:45:44
23978	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21889	\N	2014-10-31 10:06:00	\N
23979	MEMBRE	2014-10-29 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21890	\N	2014-10-31 10:06:00	2015-01-06 17:54:18
23980	MEMBRE	2014-10-29 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	21891	\N	2014-10-31 10:06:00	2015-02-20 10:46:20
23981	MEMBRE	2014-10-29 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	21892	\N	2014-10-31 10:06:00	2015-02-11 17:12:37
23982	MEMBRE	2014-10-30 00:00:00	2015-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	21893	\N	2014-10-31 10:06:28	2015-02-17 16:20:07
23983	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21894	\N	2014-10-31 10:06:28	\N
23984	MEMBRE	2014-10-30 00:00:00	2015-03-19 00:00:00	ANCIEN	\N	\N	\N	\N	21895	\N	2014-10-31 10:06:59	2015-03-20 09:52:32
23985	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21896	\N	2014-10-31 10:06:59	\N
23986	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21897	\N	2014-10-31 10:06:59	\N
23987	MEMBRE	2014-10-30 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	21898	\N	2014-10-31 10:06:59	2015-02-13 17:04:27
23988	MEMBRE	2014-10-30 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	21899	\N	2014-10-31 10:06:59	2015-02-11 16:39:21
23989	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21900	\N	2014-10-31 10:06:59	\N
23990	MEMBRE	2014-10-30 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	21901	\N	2014-10-31 10:07:00	2015-02-05 19:02:19
23991	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21902	\N	2014-10-31 10:07:00	\N
23992	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21903	\N	2014-10-31 10:07:00	\N
23993	MEMBRE	2014-10-30 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21904	\N	2014-10-31 10:07:00	2015-01-06 17:14:11
23994	MEMBRE	2014-10-30 00:00:00	2015-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	21905	\N	2014-10-31 10:07:00	2015-01-28 10:26:13
23995	MEMBRE	2014-10-30 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	21906	\N	2014-10-31 10:10:54	2015-02-19 16:15:11
23997	MEMBRE	2014-10-30 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	21908	\N	2014-10-31 10:10:54	2015-02-05 19:00:53
23998	MEMBRE	2014-10-30 00:00:00	2017-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	21909	\N	2014-10-31 10:10:54	2017-10-05 09:38:16
23999	MEMBRE	2014-10-30 00:00:00	2017-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	21910	\N	2014-10-31 10:10:54	2017-10-05 09:37:55
24096	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22007	\N	2014-11-03 10:14:00	\N
24097	MEMBRE	2014-10-31 00:00:00	2015-06-08 00:00:00	ANCIEN	\N	\N	\N	\N	22008	\N	2014-11-03 10:14:00	2015-06-08 09:40:59
24126	MEMBRE	2014-10-30 00:00:00	2015-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	22037	\N	2014-11-03 15:08:04	2015-02-17 16:20:12
24127	MEMBRE	2014-10-30 00:00:00	2016-01-11 00:00:00	ANCIEN	\N	\N	\N	\N	22038	\N	2014-11-03 15:08:32	2016-01-11 17:34:09
24128	MEMBRE	2014-10-30 00:00:00	2016-01-11 00:00:00	ANCIEN	\N	\N	\N	\N	22039	\N	2014-11-03 15:08:32	2016-01-11 17:34:09
24129	MEMBRE	2014-10-30 00:00:00	2016-01-11 00:00:00	ANCIEN	\N	\N	\N	\N	22040	\N	2014-11-03 15:08:32	2016-01-11 17:34:09
24130	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22041	\N	2014-11-03 15:12:01	\N
24131	MEMBRE	2014-10-31 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	22042	\N	2014-11-03 15:12:01	2015-02-19 17:22:32
24132	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22043	\N	2014-11-03 15:12:01	\N
24133	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22044	\N	2014-11-03 15:12:01	\N
24134	MEMBRE	2014-10-31 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	22045	\N	2014-11-03 15:12:01	2015-01-06 15:50:44
24135	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22046	\N	2014-11-03 15:12:01	\N
24136	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22047	\N	2014-11-03 15:12:01	\N
24137	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22048	\N	2014-11-03 15:12:01	\N
23516	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21427	\N	2014-10-29 10:16:09	\N
23517	MEMBRE	2014-10-28 00:00:00	2015-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	21428	\N	2014-10-29 10:16:09	2015-01-28 09:42:37
23518	MEMBRE	2014-10-28 00:00:00	2015-03-09 00:00:00	ANCIEN	\N	\N	\N	\N	21429	\N	2014-10-29 10:16:09	2015-03-10 10:01:17
23519	MEMBRE	2014-10-28 00:00:00	2015-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	21430	\N	2014-10-29 10:16:09	2015-02-06 14:48:12
23520	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21431	\N	2014-10-29 10:16:09	\N
23521	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21432	\N	2014-10-29 10:17:04	\N
23522	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21433	\N	2014-10-29 10:17:04	\N
23523	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21434	\N	2014-10-29 10:17:04	\N
23524	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21435	\N	2014-10-29 10:17:04	\N
23525	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21436	\N	2014-10-29 10:17:04	\N
23526	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21437	\N	2014-10-29 10:17:04	\N
23527	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21438	\N	2014-10-29 10:17:04	\N
23528	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21439	\N	2014-10-29 10:17:04	\N
23529	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21440	\N	2014-10-29 10:17:04	\N
23531	MEMBRE	2014-10-28 00:00:00	2015-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	21442	\N	2014-10-29 10:17:32	2015-01-30 09:40:12
23532	MEMBRE	2014-10-28 00:00:00	2015-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	21443	\N	2014-10-29 10:17:32	2015-01-19 14:15:50
23533	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21444	\N	2014-10-29 10:17:32	\N
23534	MEMBRE	2014-10-28 00:00:00	2015-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	21445	\N	2014-10-29 10:17:32	2015-02-09 15:43:35
23535	MEMBRE	2014-10-28 00:00:00	2015-03-09 00:00:00	ANCIEN	\N	\N	\N	\N	21446	\N	2014-10-29 10:17:32	2015-03-10 17:27:31
23536	MEMBRE	2014-10-28 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	21447	\N	2014-10-29 10:17:32	2015-02-13 11:34:35
23622	MEMBRE	2014-10-23 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21533	\N	2014-10-29 18:10:51	2015-01-06 15:52:58
23623	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21534	\N	2014-10-29 18:11:26	\N
23624	MEMBRE	2014-10-28 00:00:00	2015-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	21535	\N	2014-10-29 18:11:26	2015-03-02 11:06:55
23625	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21536	\N	2014-10-29 18:11:26	\N
23626	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21537	\N	2014-10-29 18:11:26	\N
23627	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21538	\N	2014-10-29 18:11:26	\N
23628	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21539	\N	2014-10-29 18:11:26	\N
24138	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22049	\N	2014-11-03 15:12:01	\N
24139	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22050	\N	2014-11-03 15:12:01	\N
24140	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22051	\N	2014-11-03 15:12:01	\N
24141	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22052	\N	2014-11-03 15:12:01	\N
24142	MEMBRE	2014-10-31 00:00:00	2015-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	22053	\N	2014-11-03 15:12:01	2015-02-06 16:56:29
24143	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22054	\N	2014-11-03 15:12:01	\N
24144	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22055	\N	2014-11-03 15:12:01	\N
24145	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22056	\N	2014-11-03 15:12:01	\N
24146	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22057	\N	2014-11-03 15:12:01	\N
24147	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22058	\N	2014-11-03 15:12:01	\N
24148	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22059	\N	2014-11-03 15:12:01	\N
24150	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22061	\N	2014-11-03 15:12:02	\N
24151	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22062	\N	2014-11-03 15:12:02	\N
24153	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22064	\N	2014-11-03 15:12:02	\N
24154	MEMBRE	2014-10-31 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	22065	\N	2014-11-03 15:12:02	2015-02-13 10:35:16
24155	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22066	\N	2014-11-03 15:12:02	\N
24156	MEMBRE	2014-10-31 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	22067	\N	2014-11-03 15:12:02	2015-01-06 15:29:52
24157	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22068	\N	2014-11-03 15:12:02	\N
24158	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22069	\N	2014-11-03 15:12:02	\N
24159	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22070	\N	2014-11-03 15:12:02	\N
24160	MEMBRE	2014-10-28 00:00:00	2015-04-09 00:00:00	ANCIEN	\N	\N	\N	\N	22071	\N	2014-11-03 15:12:43	2015-04-10 15:10:48
24161	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22072	\N	2014-11-03 15:12:43	\N
24162	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22073	\N	2014-11-03 15:12:43	\N
24164	MEMBRE	2014-11-04 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22075	\N	2014-11-04 10:20:05	\N
24224	MEMBRE	2014-11-06 00:00:00	2015-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	22135	\N	2014-11-07 09:49:50	2015-03-16 18:44:03
24225	MEMBRE	2014-11-06 00:00:00	2017-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	22136	\N	2014-11-07 09:49:50	2017-07-20 11:43:02
24260	MEMBRE	2014-11-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22171	\N	2014-11-12 17:23:03	\N
24261	MEMBRE	2014-11-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22172	\N	2014-11-12 17:23:03	\N
24262	MEMBRE	2014-11-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22173	\N	2014-11-12 17:23:03	\N
24263	MEMBRE	2014-11-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22174	\N	2014-11-12 17:23:03	\N
24264	MEMBRE	2014-11-12 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	22175	\N	2014-11-12 17:23:03	2015-02-11 12:10:29
24265	MEMBRE	2014-11-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22176	\N	2014-11-12 17:23:03	\N
24266	MEMBRE	2014-11-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22177	\N	2014-11-12 17:25:10	\N
24267	MEMBRE	2014-11-07 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22178	\N	2014-11-12 17:25:26	\N
24268	MEMBRE	2014-11-07 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	22179	\N	2014-11-12 17:25:27	2015-02-05 19:03:14
24269	MEMBRE	2014-11-07 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22180	\N	2014-11-12 17:25:27	\N
24270	MEMBRE	2014-11-07 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22181	\N	2014-11-12 17:25:27	\N
24271	MEMBRE	2014-11-07 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22182	\N	2014-11-12 17:25:27	\N
24272	MEMBRE	2014-11-07 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22183	\N	2014-11-12 17:25:27	\N
24317	MEMBRE	2014-11-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22224	\N	2014-11-14 14:49:37	\N
24326	MEMBRE	2014-11-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22233	\N	2014-11-18 14:12:56	\N
24349	MEMBRE	2014-11-19 00:00:00	2015-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	22256	\N	2014-11-20 09:45:04	2015-01-30 15:55:44
24350	MEMBRE	2014-11-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22257	\N	2014-11-20 09:45:04	\N
24386	MEMBRE	2014-11-27 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22293	\N	2014-12-01 16:38:15	\N
24387	MEMBRE	2014-11-27 00:00:00	2015-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	22294	\N	2014-12-01 16:38:15	2015-02-18 13:27:57
24428	MEMBRE	2014-12-11 00:00:00	2017-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	22335	\N	2014-12-15 10:00:48	2017-07-20 14:38:10
24429	MEMBRE	2014-12-11 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	22336	\N	2014-12-15 10:00:48	2015-02-03 13:56:40
24435	MEMBRE	2014-12-15 00:00:00	2017-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	22342	\N	2014-12-16 10:50:29	2017-07-20 14:38:36
24436	MEMBRE	2014-12-15 00:00:00	2017-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	22343	\N	2014-12-16 18:17:37	2017-07-20 14:38:34
24437	MEMBRE	2014-12-15 00:00:00	2017-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	22344	\N	2014-12-16 18:17:48	2017-07-20 14:38:34
24438	MEMBRE	2014-12-16 00:00:00	2015-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	22345	\N	2014-12-16 18:18:13	2015-02-09 15:41:03
24439	MEMBRE	2014-12-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22346	\N	2014-12-16 18:18:14	\N
24440	MEMBRE	2014-12-16 00:00:00	2015-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	22347	\N	2014-12-16 18:18:14	2015-02-17 09:39:22
24441	MEMBRE	2014-12-16 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	22348	\N	2014-12-16 18:18:14	2015-02-05 18:55:43
24442	MEMBRE	2014-12-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22349	\N	2014-12-16 18:18:14	\N
24443	MEMBRE	2014-12-16 00:00:00	2015-03-19 00:00:00	ANCIEN	\N	\N	\N	\N	22350	\N	2014-12-16 18:18:14	2015-03-20 09:52:38
24444	MEMBRE	2014-12-16 00:00:00	2015-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	22351	\N	2014-12-16 18:18:14	2015-01-28 10:26:31
24445	MEMBRE	2014-12-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22352	\N	2014-12-16 18:18:14	\N
24446	MEMBRE	2014-12-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22353	\N	2014-12-16 18:18:14	\N
24447	MEMBRE	2014-12-11 00:00:00	2017-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	22354	\N	2014-12-16 18:18:36	2017-07-20 14:38:49
24448	MEMBRE	2014-12-12 00:00:00	2017-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	22355	\N	2014-12-16 18:18:47	2017-07-20 14:38:10
24449	MEMBRE	2014-12-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22356	\N	2014-12-17 09:45:59	\N
24450	MEMBRE	2014-12-15 00:00:00	2015-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	22357	\N	2014-12-17 12:14:01	2015-03-04 10:25:47
24457	MEMBRE	2014-12-18 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22364	\N	2014-12-18 16:35:35	\N
24463	MEMBRE	2014-12-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22370	\N	2014-12-19 15:47:28	\N
24464	MEMBRE	2014-11-20 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	22371	\N	2014-12-19 15:53:45	2015-02-11 18:01:55
24465	MEMBRE	2014-12-17 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	22372	\N	2014-12-19 18:00:30	2015-02-03 13:59:19
24466	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20383	1	2015-01-06 10:58:00	2015-01-06 17:41:04
24467	PDTDEL	2015-01-06 00:00:00	2015-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	20820	\N	2015-01-06 10:58:34	2015-01-14 14:55:56
24468	PDTDEL	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour l'Erythrée	\N	20887	3	2015-01-06 11:03:13	2015-01-23 12:55:40
24470	PDTDEL	2015-01-06 00:00:00	2015-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	20873	\N	2015-01-06 11:04:39	2015-01-14 14:56:08
24471	PDTDEL	2015-01-06 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	pour le Soudan	\N	22074	\N	2015-01-06 11:05:52	2015-01-08 17:14:29
24472	PDTDEL	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour le Soudan du Sud	\N	20458	5	2015-01-06 11:06:23	2015-01-22 10:48:32
24473	PDTDEL	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour Djibouti	\N	20820	6	2015-01-06 11:16:30	2015-01-22 10:49:01
24474	PDT	2015-01-06 00:00:00	2015-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	20747	\N	2015-01-06 14:28:44	2015-01-13 15:45:23
24475	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20747	1	2015-01-06 15:09:07	2015-01-13 15:45:53
22263	PDT	2013-10-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19947	\N	\N	\N
22269	MEMBRE	2015-03-01 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	20216	\N	\N	\N
22270	MEMBRE	2012-01-25 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	20217	\N	\N	\N
22287	MEMBRE	2014-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20232	\N	\N	2014-09-28 13:16:32
22288	MEMBRE	2014-02-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20233	\N	\N	2014-03-06 17:36:28
22293	MEMBRE	2014-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20240	\N	2014-04-10 16:03:00	\N
22862	MEMBRE	2014-10-22 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	20806	\N	2014-10-22 18:10:34	2015-02-13 14:19:43
22863	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20807	\N	2014-10-22 18:10:34	\N
22864	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20808	\N	2014-10-22 18:10:34	\N
22865	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20809	\N	2014-10-22 18:10:34	\N
22866	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20810	\N	2014-10-22 18:10:34	\N
22867	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20811	\N	2014-10-22 18:11:09	\N
22868	MEMBRE	2014-10-22 00:00:00	2015-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	20812	\N	2014-10-22 18:11:09	2015-02-06 14:47:07
22869	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20813	\N	2014-10-22 18:11:09	\N
22870	MEMBRE	2014-10-22 00:00:00	2015-04-09 00:00:00	ANCIEN	\N	\N	\N	\N	20814	\N	2014-10-22 18:11:09	2015-04-10 15:10:32
22871	MEMBRE	2014-10-22 00:00:00	2015-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	20815	\N	2014-10-22 18:11:10	2015-03-02 11:08:05
23355	MEMBRE	2014-10-24 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21266	\N	2014-10-28 11:52:33	\N
23356	MEMBRE	2014-10-24 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	21267	\N	2014-10-28 11:52:33	2015-02-03 10:20:20
23357	MEMBRE	2014-10-24 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21268	\N	2014-10-28 11:52:34	\N
23358	MEMBRE	2014-10-24 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21269	\N	2014-10-28 11:52:35	\N
23359	MEMBRE	2014-10-28 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21270	\N	2014-10-28 11:52:50	2015-01-06 16:10:53
23494	MEMBRE	2014-10-28 00:00:00	2015-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	21405	\N	2014-10-29 10:13:10	2015-02-23 11:39:31
23495	MEMBRE	2014-10-28 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	21406	\N	2014-10-29 10:13:10	2015-02-03 16:18:57
23496	MEMBRE	2014-10-28 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	21407	\N	2014-10-29 10:13:10	2017-05-16 15:18:14
23497	MEMBRE	2014-10-28 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	21408	\N	2014-10-29 10:13:10	2017-05-16 15:18:14
23498	MEMBRE	2014-10-28 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	21409	\N	2014-10-29 10:13:10	2017-05-16 15:18:14
23499	MEMBRE	2014-10-28 00:00:00	2015-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	21410	\N	2014-10-29 10:13:10	2015-01-28 09:41:50
23500	MEMBRE	2014-10-28 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	21411	\N	2014-10-29 10:13:10	2015-02-20 12:08:42
23501	MEMBRE	2014-10-28 00:00:00	2015-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	21412	\N	2014-10-29 10:13:10	2015-03-11 11:00:33
23502	MEMBRE	2014-10-28 00:00:00	2015-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	21413	\N	2014-10-29 10:13:10	2015-03-02 11:07:11
23503	MEMBRE	2014-10-28 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	21414	\N	2014-10-29 10:13:10	2017-05-16 15:18:14
23504	MEMBRE	2014-10-28 00:00:00	2015-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	21415	\N	2014-10-29 10:13:10	2015-02-04 17:39:54
23505	MEMBRE	2014-10-28 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	21416	\N	2014-10-29 10:13:10	2015-02-05 18:55:59
23506	MEMBRE	2014-10-28 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	21417	\N	2014-10-29 10:13:10	2015-02-05 12:04:43
23507	MEMBRE	2014-10-28 00:00:00	2016-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	21418	\N	2014-10-29 10:13:10	2016-12-07 16:40:32
23508	MEMBRE	2014-10-28 00:00:00	2015-03-09 00:00:00	ANCIEN	\N	\N	\N	\N	21419	\N	2014-10-29 10:13:10	2015-03-10 10:00:55
23509	MEMBRE	2014-10-28 00:00:00	2015-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	21420	\N	2014-10-29 10:13:10	2015-01-19 14:16:13
23510	MEMBRE	2014-10-28 00:00:00	2015-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	21421	\N	2014-10-29 10:13:10	2015-03-04 10:25:42
23511	MEMBRE	2014-10-28 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21422	\N	2014-10-29 10:13:10	2015-01-06 15:36:30
23512	MEMBRE	2014-10-28 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	21423	\N	2014-10-29 10:13:10	2015-02-19 18:03:37
23513	MEMBRE	2014-10-28 00:00:00	2015-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	21424	\N	2014-10-29 10:13:10	2015-01-29 10:52:42
23514	MEMBRE	2014-10-28 00:00:00	2015-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	21425	\N	2014-10-29 10:13:10	2015-04-09 15:21:27
23515	MEMBRE	2014-10-28 00:00:00	2015-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	21426	\N	2014-10-29 10:13:10	2015-01-29 12:01:25
23530	MEMBRE	2014-10-23 00:00:00	2015-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	21441	\N	2014-10-29 10:17:18	2015-01-14 10:08:33
23537	MEMBRE	2014-10-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21448	\N	2014-10-29 10:18:57	\N
23538	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21449	\N	2014-10-29 10:19:19	\N
23539	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21450	\N	2014-10-29 10:19:19	\N
23540	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21451	\N	2014-10-29 10:23:36	\N
23541	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21452	\N	2014-10-29 10:27:05	\N
23542	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21453	\N	2014-10-29 10:27:05	\N
23543	MEMBRE	2014-10-28 00:00:00	2015-01-14 00:00:00	ANCIEN	\N	\N	\N	\N	21454	\N	2014-10-29 10:27:05	2015-01-15 09:19:09
24259	MEMBRE	2014-11-10 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22170	\N	2014-11-12 11:14:26	\N
24305	MEMBRE	2014-11-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22216	\N	2014-11-13 16:17:58	\N
24306	MEMBRE	2014-11-10 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	22217	\N	2014-11-13 16:18:09	2015-02-13 11:37:53
24307	MEMBRE	2014-11-10 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	22218	\N	2014-11-13 16:18:09	2015-02-13 17:03:57
24308	MEMBRE	2014-11-05 00:00:00	2017-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	22219	\N	2014-11-13 16:18:23	2017-07-20 11:45:21
24309	MEMBRE	2014-11-07 00:00:00	2017-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	22220	\N	2014-11-13 16:18:38	2017-07-20 11:43:02
24333	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22240	\N	2014-11-19 12:10:19	\N
24334	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22241	\N	2014-11-19 12:10:19	\N
24335	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22242	\N	2014-11-19 12:10:19	\N
24336	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22243	\N	2014-11-19 12:10:19	\N
24337	MEMBRE	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22244	\N	2014-11-19 12:10:19	2016-12-07 16:38:33
24338	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22245	\N	2014-11-19 12:10:19	\N
24339	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22246	\N	2014-11-19 12:10:19	\N
24340	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22247	\N	2014-11-19 12:10:19	\N
24341	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22248	\N	2014-11-19 12:10:19	\N
24342	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22249	\N	2014-11-19 12:10:19	\N
24343	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22250	\N	2014-11-19 12:10:19	\N
24392	MEMBRE	2014-12-02 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	22299	\N	2014-12-03 10:54:22	2015-01-06 17:48:38
24393	MEMBRE	2014-12-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22300	\N	2014-12-03 10:54:34	\N
24394	MEMBRE	2014-11-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22301	\N	2014-12-03 11:49:24	\N
24395	MEMBRE	2014-11-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22302	\N	2014-12-03 11:49:25	\N
24396	MEMBRE	2014-11-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22303	\N	2014-12-03 11:49:25	\N
24397	MEMBRE	2014-11-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22304	\N	2014-12-03 11:49:25	\N
24398	MEMBRE	2014-12-03 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	22305	\N	2014-12-03 14:21:37	2015-02-03 13:59:49
24399	MEMBRE	2014-12-03 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	22306	\N	2014-12-03 14:21:37	2015-02-03 16:21:50
24402	MEMBRE	2014-12-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22309	\N	2014-12-04 09:27:18	\N
24403	MEMBRE	2014-11-27 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22310	\N	2014-12-04 09:27:30	\N
24553	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21107	1	2015-01-06 16:37:25	2015-01-06 16:37:47
24618	PDT	2015-01-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20628	1	2015-01-14 10:31:45	2015-01-14 10:31:48
24637	MEMBRE	2014-12-18 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22390	\N	2015-01-15 09:39:23	\N
24638	MEMBRE	2015-01-13 00:00:00	2015-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	22391	\N	2015-01-15 09:39:42	2015-03-19 10:03:28
24639	MEMBRE	2015-01-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22392	\N	2015-01-15 09:39:42	\N
24641	PDT	2015-01-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22389	1	2015-01-15 15:10:48	2015-01-15 15:10:53
24650	MEMBRE	2015-01-16 00:00:00	2015-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	20473	\N	2015-01-16 17:53:26	2015-01-23 11:53:20
24651	MEMBRE	2015-01-16 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	22401	\N	2015-01-19 09:22:11	2015-02-05 18:58:15
24664	MEMBRE	2015-01-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22403	\N	2015-01-19 15:00:18	\N
24689	MEMBRE	2015-01-21 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	22422	\N	2015-01-22 09:17:53	2015-02-13 11:33:52
24690	MEMBRE	2015-01-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22423	\N	2015-01-22 09:18:15	\N
24691	MEMBRE	2015-01-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22424	\N	2015-01-22 09:18:27	\N
24692	MEMBRE	2015-01-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22425	\N	2015-01-22 09:18:45	\N
24693	MEMBRE	2015-01-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22426	\N	2015-01-22 09:18:56	\N
24694	MEMBRE	2015-01-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22427	\N	2015-01-22 09:19:43	\N
24695	MEMBRE	2015-01-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22428	\N	2015-01-22 09:19:55	\N
24696	VICPDT	2015-01-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21134	7	2015-01-22 10:49:16	2015-01-22 10:49:30
24697	VICPDT	2015-01-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20798	8	2015-01-22 10:49:38	2015-01-22 10:49:47
24698	VICPDT	2015-01-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20524	9	2015-01-22 10:49:54	2015-01-22 10:50:06
24699	VICPDT	2015-01-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20534	10	2015-01-22 10:50:11	2015-01-22 10:50:23
24700	VICPDT	2015-01-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21012	11	2015-01-22 10:50:30	2015-01-22 10:50:48
24701	VICPDT	2015-01-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21799	12	2015-01-22 10:50:55	2015-01-22 10:51:09
24702	SECRET	2015-01-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22193	13	2015-01-22 10:51:16	2015-01-22 10:51:36
24703	SECRET	2015-01-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20626	14	2015-01-22 10:51:39	2015-01-22 10:51:51
24408	MEMBRE	2014-12-05 00:00:00	2015-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	22315	\N	2014-12-05 18:37:59	2015-01-14 14:27:51
24409	MEMBRE	2014-12-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22316	\N	2014-12-05 18:37:59	\N
24596	PDTDEL	2015-01-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour le Burkina Faso	\N	22381	6	2015-01-13 14:49:45	2015-02-11 12:12:18
24604	MEMBRE	2015-01-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21309	\N	2015-01-13 17:26:42	\N
24605	PDT	2015-01-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21778	1	2015-01-13 17:26:51	2015-01-13 17:27:04
24606	PDTDEL	2015-01-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour le Paraguay	\N	21310	4	2015-01-13 17:29:25	2015-02-06 16:45:10
24648	MEMBRE	2015-01-14 00:00:00	2015-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	22400	\N	2015-01-16 16:31:55	2015-01-16 16:44:29
24681	MEMBRE	2015-01-15 00:00:00	2015-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	22415	\N	2015-01-21 10:08:50	2015-01-21 10:09:22
24682	PDT	2015-01-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22415	1	2015-01-21 10:09:22	2015-02-04 17:40:16
24745	MEMBRE	2015-01-26 00:00:00	2015-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	22450	\N	2015-01-26 12:04:28	2015-01-29 10:52:34
24705	MEMBRE	2015-01-07 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22430	\N	2015-01-22 12:37:14	\N
24723	MEMBRE	2015-01-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22443	\N	2015-01-23 09:34:56	\N
24738	MEMBRE	2015-01-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22445	\N	2015-01-23 16:05:51	\N
24876	MEMBRE	2015-01-30 00:00:00	2015-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	22497	\N	2015-02-02 09:32:12	2015-02-02 10:48:20
24724	MEMBRE	2015-01-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22444	\N	2015-01-23 11:13:34	\N
24739	MEMBRE	2015-01-21 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	22446	3	2015-01-23 16:06:09	2015-02-03 10:23:04
24778	MEMBRE	2015-01-27 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22468	\N	2015-01-28 09:13:50	\N
24779	MEMBRE	2015-01-26 00:00:00	2015-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	22469	\N	2015-01-28 09:14:09	2015-03-16 18:44:13
24780	VICPDT	2015-01-28 00:00:00	2017-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	20595	\N	2015-01-28 09:38:41	2017-07-20 18:17:21
24781	VICPDT	2015-01-28 00:00:00	2015-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	20339	3	2015-01-28 09:39:28	2015-05-26 11:57:59
24782	VICPDT	2015-01-28 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	20406	3	2015-01-28 09:40:38	2015-06-12 16:01:25
24783	VICPDT	2015-01-28 00:00:00	2017-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	21599	2	2015-01-28 09:41:06	2017-07-20 14:38:10
24784	VICPDT	2015-01-28 00:00:00	2017-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	21716	4	2015-01-28 09:41:31	2017-07-20 14:38:10
24785	SECRET	2015-01-28 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	21410	6	2015-01-28 09:41:50	2017-05-16 15:18:14
24786	SECRET	2015-01-28 00:00:00	2017-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	21948	5	2015-01-28 09:42:07	2017-07-20 14:38:10
24787	SECRET	2015-01-28 00:00:00	2017-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	21428	6	2015-01-28 09:42:37	2017-07-20 14:38:10
24788	MEMBRE	2015-01-22 00:00:00	2015-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	22470	\N	2015-01-28 10:05:29	2015-06-17 13:55:29
24789	VICPDT	2015-01-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21235	5	2015-01-28 10:24:06	2015-01-28 10:25:48
24792	VICPDT	2015-01-28 00:00:00	2015-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	22125	6	2015-01-28 10:25:58	2015-02-06 14:32:44
24798	VICPDT	2015-01-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20573	6	2015-01-28 10:26:33	2015-03-02 15:19:32
24800	VICPDT	2015-01-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21681	7	2015-01-28 10:26:47	2015-03-02 15:19:38
24801	SECRET	2015-01-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21037	8	2015-01-28 10:27:13	2015-03-02 15:19:42
24802	SECRET	2015-01-28 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	21844	9	2015-01-28 10:27:27	2016-12-12 16:10:15
24803	SECRET	2015-01-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20486	10	2015-01-28 10:27:40	2015-03-02 15:19:53
24804	SECRET	2015-01-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21022	11	2015-01-28 10:28:37	2015-03-02 15:20:21
24805	MEMBRE	2015-01-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22471	\N	2015-01-28 12:22:23	\N
24806	MEMBRE	2015-01-27 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22472	\N	2015-01-28 12:22:46	\N
24807	MEMBRE	2015-01-20 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	22473	\N	2015-01-28 12:23:00	\N
24818	VICPDT	2015-01-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22450	2	2015-01-29 10:52:34	2015-01-29 10:52:41
24820	VICPDT	2015-01-29 00:00:00	2016-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20946	3	2015-01-29 10:52:47	2016-10-05 16:30:19
24822	VICPDT	2015-01-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20426	4	2015-01-29 10:53:03	2015-01-29 10:53:14
24823	VICPDT	2015-01-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20523	5	2015-01-29 10:53:19	2015-01-29 10:53:28
24827	SECRET	2015-01-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21207	6	2015-01-29 10:53:55	2015-01-29 10:54:28
24831	VICPDT	2015-01-29 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	21426	2	2015-01-29 12:01:25	2017-05-16 15:18:14
24832	VICPDT	2015-01-29 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	20686	3	2015-01-29 12:01:34	2015-06-12 15:59:49
24833	VICPDT	2015-01-29 00:00:00	2016-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20658	4	2015-01-29 12:01:40	2017-01-03 11:09:24
21697	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19783	\N	\N	\N
22064	MEMBRE	2012-10-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20049	\N	\N	\N
22161	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20109	\N	\N	\N
21589	VICPDT	2012-02-07 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17208	\N	\N	\N
18226	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16430	\N	\N	\N
21746	SECRET	2012-02-22 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16459	\N	\N	\N
21742	SECRET	2012-02-22 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16462	\N	\N	\N
18311	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16515	\N	\N	\N
18321	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16525	\N	\N	\N
18338	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16542	\N	\N	\N
18349	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16553	\N	\N	\N
18356	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16560	\N	\N	\N
21580	VICPDT	2012-02-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16630	\N	\N	\N
21579	VICPDT	2012-02-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16631	\N	\N	\N
18364	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16568	\N	\N	\N
18885	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17088	\N	\N	\N
18237	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16441	\N	\N	\N
18510	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16713	\N	\N	\N
18558	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16761	\N	\N	\N
21581	VICPDT	2012-02-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16639	\N	\N	\N
18923	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17126	\N	\N	\N
18986	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17171	\N	\N	\N
18898	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17101	\N	\N	\N
21537	VICPDT	2012-02-07 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	17199	\N	\N	\N
24834	MEMBRE	2015-01-27 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22478	\N	2015-01-29 15:15:56	\N
24881	MEMBRE	2015-01-30 00:00:00	2015-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	22499	\N	2015-02-02 12:07:15	2015-03-16 18:44:32
24877	MEMBRE	2015-01-28 00:00:00	2015-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	22498	\N	2015-02-02 10:44:29	2015-02-02 11:27:39
24838	MEMBRE	2015-01-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20561	\N	2015-01-29 19:09:52	2015-02-03 16:49:11
24843	MEMBRE	2015-01-30 00:00:00	2016-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	22480	\N	2015-01-30 09:40:01	2016-12-01 10:36:51
24854	MEMBRE	2015-01-28 00:00:00	2015-04-09 00:00:00	ANCIEN	\N	\N	\N	\N	22489	\N	2015-01-30 11:06:02	2015-04-10 15:09:54
24855	MEMBRE	2015-01-28 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	22490	\N	2015-01-30 11:06:19	2017-06-19 16:04:13
24856	MEMBRE	2015-01-28 00:00:00	2015-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	22491	\N	2015-01-30 11:06:32	2015-02-17 16:13:05
24882	SECRET	2015-02-02 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20396	10	2015-02-02 13:15:24	2015-02-02 13:15:55
24885	MEMBRE	2015-01-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22500	\N	2015-02-02 15:28:14	\N
24888	VICPDT	2015-02-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21784	12	2015-02-03 10:19:36	2015-02-03 10:19:46
24889	VICPDT	2015-02-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21372	13	2015-02-03 10:19:51	2015-02-03 10:20:03
24890	VICPDT	2015-02-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20827	14	2015-02-03 10:20:07	2015-02-03 10:20:13
24891	VICPDT	2015-02-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21267	15	2015-02-03 10:20:20	2015-02-03 10:21:17
24892	VICPDTDRT	2015-02-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20381	16	2015-02-03 10:20:35	2015-02-03 10:22:06
24893	VICPDTDRT	2015-02-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20531	17	2015-02-03 10:20:44	2015-02-03 10:22:08
24894	VICPDTDRT	2015-02-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20536	18	2015-02-03 10:20:53	2015-02-03 10:22:13
24895	SECRET	2015-02-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22189	19	2015-02-03 10:22:20	2015-02-03 10:30:54
22272	MEMBRE	2013-11-01 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	20218	\N	2013-12-04 16:39:25	\N
22320	MEMBRE	2014-05-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20264	\N	2014-06-04 13:51:27	\N
22277	MEMBRE	2014-11-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20223	\N	2014-01-16 10:05:08	2014-01-16 10:05:32
22278	MEMBRE	2014-01-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20224	\N	2014-01-16 10:06:52	\N
22279	MEMBRE	2014-01-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20225	\N	2014-01-16 10:33:21	\N
22321	MEMBRE	2014-05-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20265	\N	2014-06-04 13:52:51	\N
22322	MEMBRE	2014-05-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20266	\N	2014-06-04 13:59:34	\N
22329	MEMBRE	2014-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20273	\N	2014-08-06 14:40:56	\N
22330	MEMBRE	2014-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20274	\N	2014-08-06 14:42:01	\N
22331	MEMBRE	2014-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20275	\N	2014-08-06 14:43:09	\N
22332	MEMBRE	2014-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20276	\N	2014-08-06 14:44:04	\N
22333	MEMBRE	2014-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20277	\N	2014-08-06 14:44:32	\N
22334	MEMBRE	2014-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20278	\N	2014-08-06 14:45:04	\N
22335	MEMBRE	2014-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20279	\N	2014-08-06 14:45:40	\N
22762	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20706	\N	2014-10-22 14:43:56	\N
22763	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20707	\N	2014-10-22 14:43:56	\N
22764	MEMBRE	2014-10-21 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	20708	\N	2014-10-22 14:43:56	2015-02-19 18:04:26
22765	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20709	\N	2014-10-22 14:43:56	\N
22766	MEMBRE	2014-10-21 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	20710	\N	2014-10-22 14:43:56	2015-02-05 18:56:06
22767	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20711	\N	2014-10-22 14:44:28	\N
22768	MEMBRE	2014-10-22 00:00:00	2016-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	20712	\N	2014-10-22 14:45:05	2016-12-07 16:43:22
22769	MEMBRE	2014-10-22 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	20713	\N	2014-10-22 14:45:05	2015-02-11 17:19:14
22770	MEMBRE	2014-10-22 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	20714	\N	2014-10-22 14:45:06	2015-02-13 15:13:22
22771	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20715	\N	2014-10-22 14:45:06	\N
22772	MEMBRE	2014-10-22 00:00:00	2015-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	20716	\N	2014-10-22 14:45:06	2015-03-02 11:07:00
22773	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20717	\N	2014-10-22 14:45:06	\N
22774	MEMBRE	2014-10-22 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	20718	\N	2014-10-22 14:45:06	2015-01-06 16:32:30
22775	MEMBRE	2014-10-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20719	\N	2014-10-22 14:45:52	\N
22776	MEMBRE	2014-10-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20720	\N	2014-10-22 14:45:52	\N
22777	MEMBRE	2014-10-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20721	\N	2014-10-22 14:45:52	\N
22778	MEMBRE	2014-10-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20722	\N	2014-10-22 14:45:52	\N
22779	MEMBRE	2014-10-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20723	\N	2014-10-22 14:45:52	\N
22780	MEMBRE	2014-10-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20724	\N	2014-10-22 14:45:52	\N
22781	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20725	\N	2014-10-22 14:46:22	\N
22782	MEMBRE	2014-10-21 00:00:00	2015-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	20726	\N	2014-10-22 14:46:22	2015-02-12 12:43:23
22783	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20727	\N	2014-10-22 14:46:22	\N
22784	MEMBRE	2014-10-21 00:00:00	2015-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	20728	\N	2014-10-22 14:46:22	2015-02-18 13:27:32
22785	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20729	\N	2014-10-22 14:46:22	\N
22786	MEMBRE	2014-10-21 00:00:00	2015-03-09 00:00:00	ANCIEN	\N	\N	\N	\N	20730	\N	2014-10-22 14:46:22	2015-03-10 10:01:22
22787	MEMBRE	2014-10-14 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	20731	\N	2014-10-22 14:47:16	2017-06-19 16:06:51
22788	MEMBRE	2014-10-14 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	20732	\N	2014-10-22 14:47:16	2017-06-19 16:06:51
22789	MEMBRE	2014-10-14 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	20733	\N	2014-10-22 14:47:16	2017-06-19 16:06:51
22790	MEMBRE	2014-10-14 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	20734	\N	2014-10-22 14:47:16	2017-06-19 16:06:51
23073	MEMBRE	2014-10-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21017	\N	2014-10-23 18:29:59	\N
23074	MEMBRE	2014-10-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21018	\N	2014-10-23 18:29:59	\N
23075	MEMBRE	2014-10-17 00:00:00	2015-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	21019	\N	2014-10-23 18:29:59	2015-03-02 11:07:05
23076	MEMBRE	2014-10-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21020	\N	2014-10-23 18:29:59	\N
23077	MEMBRE	2014-10-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21021	\N	2014-10-23 18:29:59	\N
23078	MEMBRE	2014-10-17 00:00:00	2015-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	21022	\N	2014-10-23 18:29:59	2015-01-28 10:28:37
23079	MEMBRE	2014-10-17 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	21023	\N	2014-10-23 18:29:59	2015-02-05 18:55:15
23080	MEMBRE	2014-10-17 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21024	\N	2014-10-23 18:29:59	2015-01-06 16:31:16
23081	MEMBRE	2014-10-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21025	\N	2014-10-23 18:29:59	\N
23082	MEMBRE	2014-10-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21026	\N	2014-10-23 18:29:59	\N
23083	MEMBRE	2014-10-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21027	\N	2014-10-23 18:30:00	\N
23084	MEMBRE	2014-10-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21028	\N	2014-10-23 18:30:00	\N
23085	MEMBRE	2014-10-17 00:00:00	2015-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	21029	\N	2014-10-23 18:30:00	2015-01-28 10:26:20
23086	MEMBRE	2014-10-17 00:00:00	2016-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	21030	\N	2014-10-23 18:30:00	2016-03-30 11:57:29
23328	MEMBRE	2014-10-24 00:00:00	2017-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	21239	\N	2014-10-28 09:27:23	2017-07-20 14:38:36
23329	MEMBRE	2014-10-24 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21240	\N	2014-10-28 09:27:24	\N
23330	MEMBRE	2014-10-24 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21241	\N	2014-10-28 09:27:24	\N
23331	MEMBRE	2014-10-24 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21242	\N	2014-10-28 09:27:24	\N
23332	MEMBRE	2014-10-24 00:00:00	2015-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	21243	\N	2014-10-28 09:27:24	2015-02-04 18:17:15
23333	MEMBRE	2014-10-24 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	21244	\N	2014-10-28 09:27:43	2015-02-13 14:24:00
23334	MEMBRE	2014-10-24 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21245	\N	2014-10-28 09:27:43	\N
23335	MEMBRE	2014-10-24 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21246	\N	2014-10-28 09:27:43	\N
23336	MEMBRE	2014-10-23 00:00:00	2016-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	21247	\N	2014-10-28 09:28:02	2016-12-07 15:00:10
23337	MEMBRE	2014-10-24 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21248	\N	2014-10-28 10:00:15	\N
24226	MEMBRE	2014-11-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22137	\N	2014-11-07 11:25:05	\N
24227	MEMBRE	2014-11-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22138	\N	2014-11-07 11:25:05	\N
24228	MEMBRE	2014-11-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22139	\N	2014-11-07 11:25:05	\N
24229	MEMBRE	2014-11-06 00:00:00	2015-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	22140	\N	2014-11-07 11:25:06	2015-02-12 17:36:51
24230	MEMBRE	2014-11-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22141	\N	2014-11-07 11:25:06	\N
24231	MEMBRE	2014-11-07 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22142	\N	2014-11-07 11:31:16	\N
24232	MEMBRE	2014-11-07 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22143	\N	2014-11-07 11:31:16	\N
24233	MEMBRE	2014-11-07 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22144	\N	2014-11-07 11:31:16	\N
24234	MEMBRE	2014-11-07 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	22145	\N	2014-11-07 11:31:16	2015-02-19 15:42:35
24235	MEMBRE	2014-11-07 00:00:00	2017-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	22146	\N	2014-11-07 11:31:16	2017-07-20 11:45:25
24236	MEMBRE	2014-11-07 00:00:00	2015-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	22147	\N	2014-11-07 11:31:17	2015-01-19 14:15:41
24237	MEMBRE	2014-11-07 00:00:00	2015-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	22148	\N	2014-11-07 11:31:17	2015-03-19 09:57:27
24238	MEMBRE	2014-11-07 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22149	\N	2014-11-07 11:31:17	\N
24239	MEMBRE	2014-11-07 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22150	\N	2014-11-07 11:31:17	\N
24240	MEMBRE	2014-11-07 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22151	\N	2014-11-07 11:31:17	\N
24241	MEMBRE	2014-11-07 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	22152	\N	2014-11-07 11:31:17	2015-02-05 12:06:10
24242	MEMBRE	2014-11-07 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	22153	\N	2014-11-07 11:31:17	2015-02-03 16:22:06
24243	MEMBRE	2014-11-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22154	\N	2014-11-07 11:31:42	\N
24244	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22155	\N	2014-11-07 11:32:07	\N
24245	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22156	\N	2014-11-07 11:32:07	\N
24246	MEMBRE	2014-10-29 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	22157	\N	2014-11-07 11:32:07	2015-01-06 16:03:32
24247	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22158	\N	2014-11-07 11:32:07	\N
24248	MEMBRE	2014-11-06 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	22159	\N	2014-11-07 11:32:29	2015-06-12 16:01:25
24249	MEMBRE	2014-11-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22160	\N	2014-11-07 11:32:45	\N
24250	MEMBRE	2014-11-06 00:00:00	2015-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	22161	\N	2014-11-07 11:32:45	2015-02-12 12:45:12
24251	MEMBRE	2014-11-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22162	\N	2014-11-07 11:32:45	\N
24252	MEMBRE	2014-11-05 00:00:00	2017-07-16 00:00:00	ANCIEN	\N	\N	\N	\N	22163	\N	2014-11-07 11:33:05	2017-07-17 11:34:59
24359	MEMBRE	2014-11-17 00:00:00	2016-01-11 00:00:00	ANCIEN	\N	\N	\N	\N	22266	\N	2014-11-21 11:51:31	2016-01-11 17:34:09
24360	MEMBRE	2014-11-19 00:00:00	2017-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	22267	\N	2014-11-21 11:51:44	2017-10-09 09:55:19
24366	MEMBRE	2014-11-19 00:00:00	2015-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	22273	\N	2014-11-26 09:42:01	2015-01-30 15:57:52
24367	MEMBRE	2014-11-25 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22274	\N	2014-11-26 09:42:12	\N
24368	MEMBRE	2014-11-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22275	\N	2014-11-26 09:42:26	\N
24400	MEMBRE	2014-12-02 00:00:00	2015-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	22307	\N	2014-12-03 15:41:24	2015-02-06 16:55:56
24401	MEMBRE	2014-12-02 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22308	\N	2014-12-03 15:41:42	\N
24410	MEMBRE	2014-12-08 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	22317	\N	2014-12-09 16:23:15	2015-02-19 18:04:00
24411	MEMBRE	2014-12-08 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	22318	\N	2014-12-09 16:23:15	2016-03-11 18:02:51
24589	MEMBRE	2015-01-09 00:00:00	2015-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	22375	\N	2015-01-09 16:54:54	2015-03-04 10:26:10
24590	PDTDEL	2015-01-12 00:00:00	2015-01-12 00:00:00	ANCIEN	\N	\N	pour la Papouasie-Nouvelle Guinée	\N	21278	\N	2015-01-12 14:49:17	2015-01-13 15:58:49
22614	MEMBRE	2014-10-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20558	\N	2014-10-20 14:22:34	\N
22615	MEMBRE	2014-10-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20559	\N	2014-10-20 14:22:34	\N
22616	MEMBRE	2014-10-16 00:00:00	2015-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	20560	\N	2014-10-20 14:22:34	2015-01-27 17:08:24
22617	MEMBRE	2014-10-16 00:00:00	2015-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	20561	\N	2014-10-20 14:22:34	2015-02-03 16:49:25
22618	MEMBRE	2014-10-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20562	\N	2014-10-20 14:22:34	\N
22619	MEMBRE	2014-10-16 00:00:00	2015-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	20563	\N	2014-10-20 14:22:34	2015-01-23 12:09:56
22620	MEMBRE	2014-10-16 00:00:00	2014-11-05 00:00:00	ANCIEN	\N	\N	\N	\N	20564	\N	2014-10-20 14:22:34	2014-11-07 11:31:42
22621	MEMBRE	2014-10-16 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	20565	\N	2014-10-20 14:22:34	2015-02-11 12:10:00
22622	MEMBRE	2014-10-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20566	\N	2014-10-20 14:23:02	\N
22623	MEMBRE	2014-10-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20567	\N	2014-10-20 14:23:02	\N
22624	MEMBRE	2014-10-16 00:00:00	2015-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	20568	\N	2014-10-20 14:23:02	2015-02-18 13:28:21
22625	MEMBRE	2014-10-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20569	\N	2014-10-20 14:23:02	\N
22626	MEMBRE	2014-10-16 00:00:00	2015-05-26 00:00:00	ANCIEN	\N	\N	\N	\N	20570	\N	2014-10-20 14:23:02	2015-05-27 16:33:22
22627	MEMBRE	2014-10-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20571	\N	2014-10-20 14:30:51	\N
22628	MEMBRE	2014-10-20 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	20572	\N	2014-10-20 14:30:51	2015-01-06 15:15:11
23459	MEMBRE	2014-10-28 00:00:00	2015-03-19 00:00:00	ANCIEN	\N	\N	\N	\N	21370	\N	2014-10-28 17:33:26	2015-03-20 09:53:35
23460	MEMBRE	2014-10-28 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	21371	\N	2014-10-28 17:33:26	2015-02-11 12:10:12
23461	MEMBRE	2014-10-28 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	21372	\N	2014-10-28 17:33:27	2015-02-03 10:19:51
23620	MEMBRE	2014-10-29 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	21531	\N	2014-10-29 16:23:35	2015-02-20 12:00:29
23621	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21532	\N	2014-10-29 16:39:06	\N
23781	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21692	\N	2014-10-30 14:45:13	\N
23782	MEMBRE	2014-10-29 00:00:00	2015-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	21693	\N	2014-10-30 14:45:13	2015-02-06 14:48:18
23783	MEMBRE	2014-10-29 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	21694	\N	2014-10-30 14:45:13	2015-02-05 18:55:28
23784	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21695	\N	2014-10-30 14:45:13	\N
23785	MEMBRE	2014-10-29 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	21696	\N	2014-10-30 14:45:13	2015-02-19 16:29:29
23786	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21697	\N	2014-10-30 14:45:14	\N
23787	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21698	\N	2014-10-30 14:57:29	\N
23788	MEMBRE	2014-10-30 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	21699	\N	2014-10-30 14:57:29	2015-02-19 17:22:10
23789	MEMBRE	2014-10-30 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	21700	\N	2014-10-30 14:57:30	2015-02-19 16:22:27
23790	MEMBRE	2014-10-30 00:00:00	2015-03-19 00:00:00	ANCIEN	\N	\N	\N	\N	21701	\N	2014-10-30 14:57:30	2015-03-20 09:52:50
23791	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21702	\N	2014-10-30 14:57:30	\N
23792	MEMBRE	2014-10-30 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	21703	\N	2014-10-30 14:57:30	2015-02-20 12:16:52
23793	MEMBRE	2014-10-30 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	21704	\N	2014-10-30 14:57:30	2015-02-05 18:58:34
23794	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21705	\N	2014-10-30 14:57:30	\N
23795	MEMBRE	2014-10-30 00:00:00	2015-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	21706	\N	2014-10-30 14:57:30	2015-03-19 10:02:37
23796	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21707	\N	2014-10-30 14:57:30	\N
23797	MEMBRE	2014-10-30 00:00:00	2015-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	21708	\N	2014-10-30 14:57:30	2015-01-14 10:05:50
23798	MEMBRE	2014-10-30 00:00:00	2015-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	21709	\N	2014-10-30 14:57:30	2015-02-17 09:39:58
23799	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21710	\N	2014-10-30 14:57:30	\N
23800	MEMBRE	2014-10-30 00:00:00	2015-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	21711	\N	2014-10-30 14:57:30	2015-02-12 12:42:51
23801	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21712	\N	2014-10-30 15:01:22	\N
23802	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21713	\N	2014-10-30 15:01:22	\N
23803	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21714	\N	2014-10-30 15:01:22	\N
23804	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21715	\N	2014-10-30 15:01:22	\N
23806	MEMBRE	2014-10-30 00:00:00	2015-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	21717	\N	2014-10-30 15:34:50	2015-01-14 10:07:27
23807	MEMBRE	2014-10-30 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	21718	\N	2014-10-30 15:34:50	2015-02-20 10:51:44
23808	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21719	\N	2014-10-30 15:35:26	\N
23809	MEMBRE	2014-10-21 00:00:00	2015-03-09 00:00:00	ANCIEN	\N	\N	\N	\N	21720	\N	2014-10-30 15:35:26	2015-03-10 10:00:45
23810	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21721	\N	2014-10-30 15:35:27	\N
23811	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21722	\N	2014-10-30 15:35:27	\N
23812	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21723	\N	2014-10-30 15:35:27	\N
23813	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21724	\N	2014-10-30 15:35:27	\N
23814	MEMBRE	2014-10-21 00:00:00	2015-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	21725	\N	2014-10-30 15:35:27	2015-02-12 15:35:20
23815	MEMBRE	2014-10-29 00:00:00	2017-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	21726	\N	2014-10-30 15:35:53	2017-07-24 09:58:00
23816	MEMBRE	2014-10-29 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	21727	\N	2014-10-30 15:35:53	2015-02-19 16:30:01
23817	MEMBRE	2014-10-29 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21728	\N	2014-10-30 15:35:54	2015-01-06 15:25:08
23818	MEMBRE	2014-10-29 00:00:00	2017-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	21729	\N	2014-10-30 15:35:54	2017-07-24 09:58:00
23820	MEMBRE	2014-10-29 00:00:00	2017-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	21731	\N	2014-10-30 15:35:54	2017-07-24 09:58:00
23821	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21732	\N	2014-10-30 15:36:54	\N
23822	MEMBRE	2014-10-28 00:00:00	2015-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	21733	\N	2014-10-30 15:36:54	2015-02-04 10:18:52
23823	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21734	\N	2014-10-30 15:36:54	\N
23824	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21735	\N	2014-10-30 15:36:54	\N
23825	MEMBRE	2014-10-28 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	21736	\N	2014-10-30 15:36:54	2015-02-03 13:57:00
23826	MEMBRE	2014-10-28 00:00:00	2016-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	21737	\N	2014-10-30 15:36:54	2016-12-07 16:42:05
23827	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21738	\N	2014-10-30 15:36:54	\N
23828	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21739	\N	2014-10-30 15:36:54	\N
23829	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21740	\N	2014-10-30 15:36:54	\N
23830	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21741	\N	2014-10-30 15:38:28	\N
23831	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21742	\N	2014-10-30 15:38:28	\N
23832	MEMBRE	2014-10-29 00:00:00	2015-03-19 00:00:00	ANCIEN	\N	\N	\N	\N	21743	\N	2014-10-30 15:38:28	2015-03-20 09:53:10
23833	MEMBRE	2014-10-30 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	21744	\N	2014-10-30 15:39:11	2015-10-13 14:18:31
23834	MEMBRE	2014-10-30 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	21745	\N	2014-10-30 15:39:11	2015-10-13 14:18:46
23835	MEMBRE	2014-10-30 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	21746	\N	2014-10-30 15:39:11	2015-10-13 14:18:56
23836	MEMBRE	2014-10-30 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	21747	\N	2014-10-30 15:39:11	2015-02-03 16:27:40
23838	MEMBRE	2014-10-29 00:00:00	2015-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	21749	\N	2014-10-30 15:40:13	2015-02-04 17:40:11
23839	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21750	\N	2014-10-30 15:40:13	\N
23840	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21751	\N	2014-10-30 15:40:13	\N
23841	MEMBRE	2014-10-29 00:00:00	2015-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	21752	\N	2014-10-30 15:40:13	2015-02-09 15:45:52
23842	MEMBRE	2014-10-29 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21753	\N	2014-10-30 15:40:13	2015-01-06 15:53:33
23843	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21754	\N	2014-10-30 15:40:13	\N
23844	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21755	\N	2014-10-30 15:40:13	\N
23845	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21756	\N	2014-10-30 15:40:13	\N
23846	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21757	\N	2014-10-30 15:40:13	\N
23847	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21758	\N	2014-10-30 15:40:32	\N
23848	MEMBRE	2014-10-29 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	21759	\N	2014-10-30 15:40:52	2015-02-19 16:16:03
23849	MEMBRE	2014-10-29 00:00:00	2015-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	21760	\N	2014-10-30 15:40:52	2015-04-10 14:43:33
23850	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21761	\N	2014-10-30 15:40:52	\N
23851	MEMBRE	2014-10-29 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	21762	\N	2014-10-30 15:40:52	2015-02-20 10:46:15
23852	MEMBRE	2014-10-24 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21763	\N	2014-10-30 15:41:17	2015-01-06 16:19:38
23853	MEMBRE	2014-10-24 00:00:00	2015-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	21764	\N	2014-10-30 15:41:17	2015-02-12 12:43:33
23854	MEMBRE	2014-10-24 00:00:00	2015-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	21765	\N	2014-10-30 15:41:17	2015-03-19 10:04:35
23855	MEMBRE	2014-10-24 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21766	\N	2014-10-30 15:41:17	2015-01-06 16:22:50
23857	MEMBRE	2014-10-29 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21768	\N	2014-10-30 15:41:48	2015-01-06 16:30:12
23858	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21769	\N	2014-10-30 15:41:48	\N
23859	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21770	\N	2014-10-30 15:41:48	\N
23860	MEMBRE	2014-10-29 00:00:00	2015-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	21771	\N	2014-10-30 15:41:48	2015-02-12 15:35:41
23867	MEMBRE	2014-10-28 00:00:00	2015-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	21778	\N	2014-10-30 17:49:00	2015-01-13 17:26:51
23868	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21779	\N	2014-10-30 17:49:00	\N
23869	MEMBRE	2014-10-28 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21780	\N	2014-10-30 17:49:00	2015-01-06 17:16:59
23870	MEMBRE	2014-10-28 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	21781	\N	2014-10-30 17:49:00	2015-02-05 18:51:36
23871	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21782	\N	2014-10-30 17:49:00	\N
25135	VICPDT	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21899	4	2015-02-11 16:39:21	2015-02-11 16:39:59
25136	VICPDT	2015-02-11 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	21842	5	2015-02-11 16:39:28	2016-12-12 16:10:15
25137	VICPDT	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22453	6	2015-02-11 16:39:32	2015-02-11 16:40:04
25138	VICPDT	2015-02-11 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	21875	6	2015-02-11 16:39:42	2016-03-11 18:02:51
25139	SECRET	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20634	7	2015-02-11 16:40:18	2015-02-11 16:40:45
25140	SECRET	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22463	\N	2015-02-11 16:40:33	\N
25608	MEMBRE	2015-02-03 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	22827	\N	2015-02-17 10:22:10	2016-12-12 16:10:15
25609	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22828	\N	\N	2017-09-24 13:25:54
25642	MEMBRE	2014-10-01 00:00:00	2014-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22847	\N	\N	\N
25643	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22848	\N	\N	\N
26010	MEMBRE	2014-10-01 00:00:00	2014-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	23069	\N	\N	\N
26309	MEMBRE	2015-04-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23187	\N	2015-04-07 14:01:11	\N
26428	VICPDT	2015-03-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22650	\N	\N	2017-09-24 13:44:49
26512	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23287	\N	\N	\N
26516	MEMBRE	2015-02-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	23291	\N	\N	\N
26518	MEMBRE	2015-06-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23293	\N	2015-06-16 17:37:42	\N
26655	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23394	\N	\N	\N
26664	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23402	\N	\N	\N
26666	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23404	\N	\N	\N
26672	VICPDT	2015-10-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	22613	\N	\N	\N
26711	MEMBRE	2015-11-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23435	\N	2015-12-14 16:22:25	2017-09-24 17:42:26
26712	MEMBRE	2015-12-03 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	23436	\N	2015-12-14 16:23:06	2016-12-12 16:10:15
26713	MEMBRE	2015-12-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23437	\N	2015-12-14 16:23:27	\N
26722	MEMBRE	2016-01-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23443	\N	2016-01-28 16:39:12	\N
26723	MEMBRE	2016-01-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23444	\N	2016-01-28 17:06:18	2017-09-24 19:25:10
26975	MEMBRE	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23675	\N	\N	2017-09-24 17:42:26
26953	MEMBRE	2016-06-15 00:00:00	2016-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	23653	\N	\N	\N
26971	MEMBRE	2016-06-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	23671	\N	\N	\N
26979	MEMBRE	2016-06-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	23679	\N	\N	\N
26981	MEMBRE	2016-06-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	23681	\N	\N	\N
26985	MEMBRE	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23685	\N	\N	2017-09-24 17:42:26
26988	MEMBRE	2016-06-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	23688	\N	\N	\N
26989	MEMBRE	2016-06-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	23689	\N	\N	\N
26992	MEMBRE	2016-06-15 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	23692	\N	\N	2017-06-19 12:20:59
26993	MEMBRE	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23693	\N	\N	2017-09-24 13:14:55
26999	MEMBRE	2016-06-15 00:00:00	2016-09-28 00:00:00	ANCIEN	\N	\N	\N	\N	23699	\N	\N	\N
27003	MEMBRE	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23703	\N	\N	2017-09-24 17:35:15
27054	VICPDT	2016-09-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	23695	\N	\N	\N
27060	MEMBRE	2016-06-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	23752	\N	\N	\N
27168	MEMBRE	2017-02-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23835	\N	\N	2017-09-24 19:25:10
28449	MEMBRE	2017-10-31 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	25016	\N	2017-11-02 10:07:04	2018-01-23 18:43:26
28450	MEMBRE	2017-10-31 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	25017	\N	2017-11-02 10:07:04	2017-12-20 12:23:00
28451	MEMBRE	2017-10-31 00:00:00	2018-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	25018	\N	2017-11-02 10:07:04	2018-01-26 16:18:20
28452	MEMBRE	2017-11-02 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	25019	\N	2017-11-02 10:20:31	2018-01-18 11:35:54
28453	MEMBRE	2017-11-02 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	25020	\N	2017-11-02 10:20:31	2018-01-25 17:37:57
28454	MEMBRE	2017-11-02 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	25021	\N	2017-11-02 10:20:31	\N
28455	MEMBRE	2017-11-02 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	25022	\N	2017-11-02 10:20:31	\N
28456	MEMBRE	2017-11-02 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	25023	\N	2017-11-02 10:20:31	\N
28457	MEMBRE	2017-11-02 00:00:00	2017-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	25024	\N	2017-11-02 10:20:31	2017-12-14 18:23:43
28458	MEMBRE	2017-11-02 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	25025	\N	2017-11-02 10:20:31	2018-01-23 18:50:01
28684	MEMBRE	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25251	\N	2017-11-14 16:06:37	\N
28685	MEMBRE	2017-11-08 00:00:00	2017-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	25252	\N	2017-11-14 16:06:37	2017-11-30 16:06:10
28686	MEMBRE	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25253	\N	2017-11-14 16:06:54	\N
28687	MEMBRE	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25254	\N	2017-11-14 16:06:54	\N
28898	MEMBRE	2017-11-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25465	\N	2017-11-27 11:24:00	\N
28899	MEMBRE	2017-11-16 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	25466	\N	2017-11-27 11:26:52	2018-01-24 10:41:58
28941	MEMBRE	2017-11-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25474	\N	2017-11-29 09:42:14	\N
28942	MEMBRE	2017-11-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25475	\N	2017-11-29 09:42:14	\N
28943	MEMBRE	2017-11-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25476	\N	2017-11-29 09:42:44	\N
28944	MEMBRE	2017-11-22 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25477	\N	2017-11-29 09:43:03	\N
28945	MEMBRE	2017-11-28 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25478	\N	2017-11-29 09:43:19	\N
28946	MEMBRE	2017-11-21 00:00:00	2017-12-11 00:00:00	ANCIEN	\N	\N	\N	\N	25479	\N	2017-11-29 09:43:36	2017-12-12 17:34:46
28947	MEMBRE	2017-11-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25480	\N	2017-11-29 09:43:59	\N
28948	MEMBRE	2017-11-23 00:00:00	2018-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	25481	\N	2017-11-29 10:53:53	2018-01-30 14:46:58
28949	MEMBRE	2017-11-23 00:00:00	2017-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	25482	\N	2017-11-29 10:53:53	2017-11-30 17:33:10
28950	MEMBRE	2017-11-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25483	\N	2017-11-29 10:53:53	\N
29079	MEMBRE	2017-12-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25547	\N	2017-12-06 09:45:40	\N
29468	MEMBRE	2017-12-14 00:00:00	2018-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	25794	\N	2018-01-12 10:13:30	2018-01-17 10:37:37
29469	MEMBRE	2017-12-20 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	25795	\N	2018-01-12 10:14:05	2018-01-24 15:53:21
29470	MEMBRE	2018-01-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25796	\N	2018-01-12 10:14:28	\N
29471	MEMBRE	2017-12-21 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	25797	\N	2018-01-12 10:14:50	2018-01-25 15:20:24
29472	MEMBRE	2017-12-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25798	\N	2018-01-12 10:14:50	\N
29473	MEMBRE	2018-01-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25799	\N	2018-01-12 10:15:43	\N
29475	MEMBRE	2017-12-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25801	\N	\N	\N
29479	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25805	\N	\N	\N
29480	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25806	\N	\N	\N
29486	MEMBRE	2018-01-15 00:00:00	2018-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	25812	\N	2018-01-15 12:50:52	\N
29675	MEMBRE	2017-10-01 00:00:00	2018-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	25929	\N	\N	\N
29501	MEMBRE	2018-01-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25827	\N	2018-01-16 17:14:49	\N
29578	SECRET	2018-01-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24608	\N	2018-01-16 19:09:01	\N
29579	SECRET	2018-01-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24862	\N	2018-01-16 19:09:09	\N
29580	SECRET	2018-01-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25452	\N	2018-01-16 19:09:16	\N
29581	SECRET	2018-01-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24169	\N	2018-01-16 19:09:26	\N
29582	SECRET	2018-01-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24937	\N	2018-01-16 19:09:32	\N
29583	VICPDT	2018-01-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24797	\N	2018-01-16 19:10:41	\N
29584	VICPDT	2018-01-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24878	\N	2018-01-16 19:10:51	\N
29585	VICPDT	2018-01-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24291	\N	2018-01-16 19:10:54	\N
29586	VICPDT	2018-01-16 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	24497	\N	2018-01-16 19:11:01	\N
29587	VICPDT	2018-01-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24969	\N	2018-01-16 19:11:11	\N
29588	VICPDT	2018-01-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23902	\N	2018-01-16 19:11:20	\N
29589	VICPDT	2018-01-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25243	\N	2018-01-16 19:11:24	\N
29590	SECRET	2018-01-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25177	\N	2018-01-16 19:11:31	\N
29591	SECRET	2018-01-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25175	\N	2018-01-16 19:11:48	\N
29601	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25862	\N	\N	\N
29602	MEMBRE	2017-10-01 00:00:00	2020-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	25863	\N	\N	\N
29624	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25885	\N	\N	\N
29630	MEMBRE	2017-10-01 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	25891	\N	\N	\N
29631	MEMBRE	2017-10-01 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	25892	\N	\N	\N
29632	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25893	\N	\N	\N
29633	MEMBRE	2017-10-01 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	25894	\N	\N	\N
29634	MEMBRE	2017-10-01 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	25895	\N	\N	\N
29635	MEMBRE	2017-10-01 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	25896	\N	\N	\N
29637	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25898	\N	\N	\N
29672	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25926	\N	\N	\N
29673	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25927	\N	\N	\N
29677	MEMBRE	2017-10-01 00:00:00	2018-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	25931	\N	\N	\N
29678	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25932	\N	\N	\N
29692	MEMBRE	2017-11-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25946	\N	2018-01-17 17:15:39	\N
29693	MEMBRE	2017-11-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25947	\N	2018-01-17 17:15:39	\N
29694	MEMBRE	2017-11-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25948	\N	2018-01-17 17:15:39	\N
29695	MEMBRE	2017-11-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25949	\N	2018-01-17 17:15:39	\N
29696	MEMBRE	2018-01-17 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	25950	\N	2018-01-17 17:27:02	2018-01-23 17:21:50
22385	MEMBRE	2014-10-14 00:00:00	2014-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	20329	\N	2014-10-14 12:24:49	2014-10-22 16:49:18
24458	MEMBRE	2014-12-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22365	\N	2014-12-18 17:46:35	\N
24459	MEMBRE	2014-12-17 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	22366	\N	2014-12-18 17:46:44	2016-12-12 16:10:15
24588	MEMBRE	2015-01-07 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	22374	\N	2015-01-09 09:15:06	2015-02-11 16:58:03
26201	MEMBRE	2014-10-01 00:00:00	2015-05-01 00:00:00	ANCIEN	\N	\N	\N	\N	23151	\N	\N	\N
26202	MEMBRE	2014-10-01 00:00:00	2015-05-01 00:00:00	ANCIEN	\N	\N	\N	\N	23152	\N	\N	\N
26203	MEMBRE	2014-09-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23153	\N	2015-03-11 13:55:25	\N
26204	MEMBRE	2014-09-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23154	\N	2015-03-11 13:56:38	\N
26205	MEMBRE	2014-09-01 00:00:00	2015-04-06 00:00:00	ANCIEN	\N	\N	\N	\N	23155	\N	2015-03-11 13:58:13	\N
26206	MEMBRE	2014-09-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23156	\N	2015-03-11 13:58:24	\N
26211	MEMBRE	2015-02-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23161	\N	2015-03-13 16:37:41	\N
26221	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23164	\N	\N	\N
26350	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23212	\N	\N	\N
26348	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23210	\N	\N	\N
26349	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23211	\N	\N	\N
26418	MEMBRE	2015-05-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23256	\N	2015-05-12 16:50:00	\N
26665	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23403	\N	\N	\N
26720	MEMBRE	2016-01-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23441	\N	2016-01-28 11:52:02	\N
26945	PDT	2016-06-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	23645	\N	\N	\N
26972	MEMBRE	2016-06-15 00:00:00	2016-09-28 00:00:00	ANCIEN	\N	\N	\N	\N	23672	\N	\N	\N
26973	MEMBRE	2016-06-15 00:00:00	2016-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	23673	\N	\N	\N
26984	MEMBRE	2016-06-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	23684	\N	\N	\N
26986	MEMBRE	2016-06-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	23686	\N	\N	\N
26987	MEMBRE	2016-06-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	23687	\N	\N	\N
26998	MEMBRE	2016-06-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23698	\N	\N	2017-10-01 09:22:38
27005	MEMBRE	2016-06-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	23705	\N	\N	\N
27178	MEMBRE	2016-12-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	23845	\N	\N	\N
27179	MEMBRE	2017-01-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23846	\N	\N	2017-09-24 19:25:10
27180	MEMBRE	2017-01-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	23847	\N	\N	\N
27181	MEMBRE	2016-12-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	23848	\N	\N	\N
28746	MEMBRE	2017-11-16 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	25313	\N	2017-11-17 14:39:35	2018-01-18 11:36:12
28747	MEMBRE	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25314	\N	2017-11-17 14:47:05	\N
29481	MEMBRE	2017-10-01 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	25807	\N	\N	\N
29619	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25880	\N	\N	\N
29552	MEMBRE	2018-01-10 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	25853	\N	2018-01-16 18:17:36	2018-01-18 11:22:16
29606	MEMBRE	2017-10-01 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	25867	\N	\N	\N
29621	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25882	\N	\N	\N
29622	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25883	\N	\N	\N
29623	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25884	\N	\N	\N
29625	MEMBRE	2017-10-01 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	25886	\N	\N	\N
29626	MEMBRE	2017-10-01 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	25887	\N	\N	\N
29815	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25983	\N	\N	\N
30071	MEMBRE	2018-01-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26066	\N	2018-01-25 14:48:01	\N
30075	MEMBRE	2018-01-22 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26070	\N	2018-01-25 14:48:23	\N
30076	MEMBRE	2018-01-22 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26071	\N	2018-01-25 14:48:23	\N
30077	MEMBRE	2018-01-22 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26072	\N	2018-01-25 14:48:23	\N
30080	MEMBRE	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26075	\N	2018-01-25 14:48:40	\N
30090	VICPDT	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25338	\N	2018-01-25 15:19:23	\N
30091	VICPDT	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24556	\N	2018-01-25 15:19:40	\N
30092	VICPDT	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25694	\N	2018-01-25 15:19:51	\N
30093	VICPDT	2018-01-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25630	\N	2018-01-25 15:20:04	\N
30094	VICPDT	2018-01-25 00:00:00	2018-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	24313	\N	2018-01-25 15:20:16	2018-04-13 17:54:29
30095	VICPDT	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25797	\N	2018-01-25 15:20:24	\N
30096	VICPDT	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25592	\N	2018-01-25 15:20:36	\N
30097	VICPDT	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25663	\N	2018-01-25 15:20:49	\N
30098	VICPDT	2018-01-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24923	\N	2018-01-25 15:21:05	\N
30099	SECRET	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25682	\N	2018-01-25 15:21:24	\N
30100	SECRET	2018-01-25 00:00:00	2019-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	25652	\N	2018-01-25 15:21:34	\N
30101	VICPDT	2018-01-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25791	\N	2018-01-25 15:53:46	\N
30102	VICPDT	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25703	\N	2018-01-25 15:53:55	\N
30103	VICPDT	2018-01-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25605	\N	2018-01-25 15:54:07	2018-01-25 15:54:44
30104	VICPDT	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24133	\N	2018-01-25 15:54:56	\N
30105	VICPDT	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25549	\N	2018-01-25 15:55:08	\N
30106	VICPDT	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23912	\N	2018-01-25 15:55:22	\N
30107	VICPDT	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24827	\N	2018-01-25 16:02:30	\N
30108	VICPDT	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25284	\N	2018-01-25 16:04:34	\N
30109	VICPDT	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24217	\N	2018-01-25 16:04:47	\N
30110	SECRET	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25310	\N	2018-01-25 16:05:02	2018-01-25 16:05:12
30111	SECRET	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24850	\N	2018-01-25 16:05:24	\N
30112	SECRET	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25202	\N	2018-01-25 16:05:30	\N
30470	MEMBRE	2018-02-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26251	\N	2018-02-06 15:02:49	\N
30471	MEMBRE	2018-02-02 00:00:00	2019-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	26252	\N	2018-02-06 15:03:07	\N
30472	MEMBRE	2017-10-01 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	26253	\N	\N	\N
30473	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26254	\N	\N	\N
30474	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26255	\N	\N	\N
30475	MEMBRE	2017-10-01 00:00:00	2018-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	26256	\N	\N	\N
30476	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26257	\N	\N	\N
30477	MEMBRE	2017-10-01 00:00:00	2020-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	26258	\N	\N	\N
30478	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26259	\N	\N	\N
30479	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26260	\N	\N	\N
30480	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26261	\N	\N	\N
30481	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26262	\N	\N	\N
30482	PDTHON	2018-02-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25376	\N	2018-02-06 16:27:31	\N
30483	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26263	\N	\N	\N
30484	VICPDT	2018-02-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24823	\N	2018-02-06 16:27:40	\N
30485	VICPDT	2018-02-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23942	\N	2018-02-06 16:27:46	\N
30486	VICPDT	2018-02-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24185	\N	2018-02-06 16:27:53	\N
30487	SECRET	2018-02-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24917	\N	2018-02-06 16:27:58	\N
30488	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26264	\N	\N	\N
30489	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26265	\N	\N	\N
30490	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26266	\N	\N	\N
30491	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26267	\N	\N	\N
30492	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26268	\N	\N	\N
30493	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26269	\N	\N	\N
30494	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26270	\N	\N	\N
30495	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26271	\N	\N	\N
30496	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26272	\N	\N	\N
30497	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26273	\N	\N	\N
30498	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26274	\N	\N	\N
30499	MEMBRE	2017-10-01 00:00:00	2018-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	26275	\N	\N	\N
30500	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26276	\N	\N	\N
30501	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26277	\N	\N	\N
30502	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26278	\N	\N	\N
30503	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26279	\N	\N	\N
30504	MEMBRE	2017-10-01 00:00:00	2018-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	26280	\N	\N	\N
30505	MEMBRE	2017-10-01 00:00:00	2020-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	26281	\N	\N	\N
30506	MEMBRE	2017-10-01 00:00:00	2020-06-24 00:00:00	ANCIEN	\N	\N	\N	\N	26282	\N	\N	\N
30507	MEMBRE	2017-10-01 00:00:00	2018-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	26283	\N	\N	\N
30508	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26284	\N	\N	\N
30509	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26285	\N	\N	\N
30510	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26286	\N	\N	\N
30511	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26287	\N	\N	\N
30512	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26288	\N	\N	\N
30513	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26289	\N	\N	\N
30514	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26290	\N	\N	\N
30515	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26291	\N	\N	\N
30516	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26292	\N	\N	\N
30517	MEMBRE	2017-10-01 00:00:00	2018-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	26293	\N	\N	\N
30518	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26294	\N	\N	\N
30519	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26295	\N	\N	\N
30520	MEMBRE	2017-10-01 00:00:00	2018-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	26296	\N	\N	2018-04-13 17:54:29
30521	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26297	\N	\N	\N
30522	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26298	\N	\N	\N
30523	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26299	\N	\N	\N
30524	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26300	\N	\N	\N
30525	MEMBRE	2017-10-01 00:00:00	2018-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	26301	\N	\N	\N
30526	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26302	\N	\N	\N
30527	MEMBRE	2017-10-01 00:00:00	2018-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	26303	\N	\N	\N
30528	MEMBRE	2017-10-01 00:00:00	2018-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	26304	\N	\N	\N
30529	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26305	\N	\N	\N
30530	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26306	\N	\N	\N
30531	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26307	\N	\N	\N
30532	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26308	\N	\N	\N
30533	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26309	\N	\N	\N
30534	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26310	\N	\N	\N
24544	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20342	1	2015-01-06 16:29:54	2015-01-06 16:29:58
24545	PDTDEL	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour les Comores	\N	21768	2	2015-01-06 16:30:12	2015-03-10 10:00:24
24546	PDTDEL	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour le Kenya	\N	21103	5	2015-01-06 16:30:49	2015-03-10 10:00:32
24547	PDTDEL	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour la Tanzanie	\N	21024	3	2015-01-06 16:31:16	2015-03-10 10:00:28
24548	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20584	1	2015-01-06 16:31:50	2015-01-06 16:31:55
24549	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20718	1	2015-01-06 16:32:30	2015-01-06 16:32:37
24550	PDTDEL	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour le Mexique	\N	21389	2	2015-01-06 16:32:46	2015-02-09 11:02:40
24551	PDTDEL	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour l'Amérique centrale	\N	22197	3	2015-01-06 16:32:56	2015-02-09 11:02:44
24552	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20892	1	2015-01-06 16:33:46	2015-01-06 16:33:49
24554	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20978	1	2015-01-06 17:12:08	2015-01-06 17:12:12
24555	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21904	1	2015-01-06 17:14:11	2015-01-06 17:14:15
24556	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20990	1	2015-01-06 17:14:46	2015-01-06 17:15:00
24557	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20609	1	2015-01-06 17:16:16	2015-01-06 17:16:22
24558	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20504	1	2015-01-06 17:16:42	2015-01-06 17:16:45
24559	PDTDEL	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour la Bolivie	\N	21780	2	2015-01-06 17:16:59	2015-01-14 14:28:29
24560	PDTDEL	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour la Colombie	\N	20932	3	2015-01-06 17:17:08	2015-01-14 14:28:33
24561	PDTDEL	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour l'Equateur	\N	22016	4	2015-01-06 17:17:14	2015-01-14 14:28:41
24562	PDTDEL	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour la Lettonie	\N	20526	3	2015-01-06 17:34:27	2015-01-23 18:00:25
24563	PDTDEL	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour la Lituanie	\N	21055	4	2015-01-06 17:34:37	2015-01-23 18:00:57
24564	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21225	1	2015-01-06 17:35:37	2015-01-06 17:35:44
24565	PDTDEL	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour l'Argentine	\N	21682	2	2015-01-06 17:37:59	2015-02-06 16:44:55
24566	PDTDEL	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour le Chili	\N	22134	3	2015-01-06 17:38:10	2015-02-06 16:45:05
24567	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20359	1	2015-01-06 17:43:12	2015-01-06 17:43:15
24568	PDT	2015-01-06 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	21508	1	2015-01-06 17:43:34	2017-09-25 09:57:52
24569	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21379	1	2015-01-06 17:44:02	2015-01-06 17:44:05
24570	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20401	1	2015-01-06 17:44:30	2015-01-06 17:44:33
24571	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21366	1	2015-01-06 17:44:53	2015-01-06 17:44:58
24572	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21213	1	2015-01-06 17:46:36	2015-01-06 17:46:41
24573	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20372	1	2015-01-06 17:48:01	2015-01-06 17:48:16
24574	PDT	2015-01-06 00:00:00	2017-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	22299	1	2015-01-06 17:48:38	2017-07-04 15:08:09
24575	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20693	1	2015-01-06 17:49:12	2015-01-06 17:49:23
24576	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21614	1	2015-01-06 17:49:41	2015-01-06 17:49:47
24578	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22110	1	2015-01-06 17:50:03	2015-01-06 17:50:07
24579	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21519	1	2015-01-06 17:50:30	2015-01-06 17:50:35
24580	PDT	2015-01-06 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	21359	1	2015-01-06 17:50:57	2017-06-19 12:20:59
24581	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21098	1	2015-01-06 17:51:23	2015-01-06 17:51:26
24582	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21278	1	2015-01-06 17:51:46	2015-01-06 17:51:53
24583	PDTDEL	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour les Fidji	\N	21966	2	2015-01-06 17:52:09	2015-01-28 10:23:06
24584	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21890	1	2015-01-06 17:54:18	2015-01-06 17:54:29
24585	PDT	2015-01-06 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	21823	1	2015-01-06 17:54:48	2016-12-12 16:10:15
24586	MEMBRE	2015-01-05 00:00:00	2015-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	22373	\N	2015-01-07 09:46:51	2015-01-14 10:12:58
24624	PDTDEL	2015-01-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour la Malaisie	\N	22296	5	2015-01-14 14:23:49	2015-02-11 17:14:12
24620	MEMBRE	2015-01-14 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	22384	\N	2015-01-14 13:10:58	2015-02-19 17:17:22
24621	PDT	2015-01-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21236	1	2015-01-14 14:09:03	2015-01-14 14:09:11
24622	PDTDEL	2015-01-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour le Guyana	\N	20441	2	2015-01-14 14:20:47	2015-01-14 14:21:13
24623	PDT	2015-01-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22383	1	2015-01-14 14:22:32	2015-01-14 14:22:41
24625	PDTDEL	2015-01-14 00:00:00	2016-12-06 00:00:00	ANCIEN	\N	\N	pour le Venezuela	\N	22315	6	2015-01-14 14:27:51	2016-12-07 15:57:06
24626	PDT	2015-01-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21547	1	2015-01-14 14:31:05	2015-01-14 14:31:12
18249	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	16453	\N	\N	\N
25109	VICPDT	2015-02-10 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	20684	7	2015-02-10 11:22:22	2015-06-12 15:59:49
25110	VICPDT	2015-02-10 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21157	11	2015-02-10 11:23:20	2015-02-10 11:23:25
25113	MEMBRE	2015-01-29 00:00:00	2015-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	22531	\N	2015-02-10 18:20:05	2015-02-12 15:35:25
25114	MEMBRE	2015-02-11 00:00:00	2017-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	22532	\N	2015-02-11 09:44:08	2017-07-24 09:56:26
25121	VICPDT	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21816	15	2015-02-11 12:09:50	2015-02-11 12:13:10
25122	VICPDT	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20565	16	2015-02-11 12:10:00	2015-02-11 12:13:21
25123	VICPDT	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21371	17	2015-02-11 12:10:12	2015-02-11 12:13:28
25124	VICPDT	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20824	18	2015-02-11 12:10:20	2015-02-11 12:13:32
25125	VICPDT	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22175	19	2015-02-11 12:10:29	2015-02-11 12:13:43
25126	VICPDT	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22194	20	2015-02-11 12:10:43	2015-02-11 12:13:54
25127	SECRET	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21929	21	2015-02-11 12:10:59	2015-02-11 12:14:05
25128	SECRET	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21119	22	2015-02-11 12:11:04	2015-02-11 12:14:09
25129	SECRET	2015-02-11 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	21847	23	2015-02-11 12:11:08	2016-12-12 16:10:15
25130	SECRET	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21176	24	2015-02-11 12:11:16	2015-02-11 12:14:14
25644	VICPDT	2015-02-18 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21135	2	2015-02-18 13:27:22	2015-02-18 13:28:36
25645	VICPDT	2015-02-18 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20728	3	2015-02-18 13:27:32	2015-02-18 13:28:40
25646	VICPDT	2015-02-18 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20740	4	2015-02-18 13:27:40	2015-02-18 13:28:44
25647	VICPDT	2015-02-18 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20306	5	2015-02-18 13:27:50	2015-02-18 13:28:47
25648	VICPDT	2015-02-18 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22294	6	2015-02-18 13:27:57	2015-02-18 13:28:51
25649	VICPDT	2015-02-18 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21808	7	2015-02-18 13:28:05	2015-02-18 13:28:53
25650	SECRET	2015-02-18 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21106	8	2015-02-18 13:28:13	2015-02-18 13:29:00
25651	SECRET	2015-02-18 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20568	9	2015-02-18 13:28:21	2015-02-18 13:29:04
25652	SECRET	2015-02-18 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21388	10	2015-02-18 13:28:26	2015-02-18 13:29:05
25653	VICPDT	2015-02-18 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22218	2	2015-02-18 13:31:00	2015-02-18 13:31:59
25654	VICPDT	2015-02-18 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22254	3	2015-02-18 13:31:03	2015-02-18 13:32:01
25655	VICPDT	2015-02-18 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21086	4	2015-02-18 13:31:08	2015-02-18 13:32:03
25656	VICPDT	2015-02-18 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20403	5	2015-02-18 13:31:16	2015-02-18 13:32:06
25657	VICPDT	2015-02-18 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21661	6	2015-02-18 13:31:22	2015-02-18 13:32:09
25658	SECRET	2015-02-18 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21196	7	2015-02-18 13:31:29	2015-02-18 13:32:12
25659	SECRET	2015-02-18 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21898	8	2015-02-18 13:31:33	2015-02-18 13:32:23
25660	SECRET	2015-02-18 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20303	9	2015-02-18 13:31:40	2015-02-18 13:32:26
25661	SECRET	2015-02-18 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20439	10	2015-02-18 13:31:44	2015-02-18 13:32:28
25662	SECRET	2015-02-18 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22030	11	2015-02-18 13:31:48	2015-02-18 13:32:32
25663	SECRET	2015-02-18 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21952	12	2015-02-18 13:31:52	2015-02-18 13:32:35
24163	MEMBRE	2014-11-03 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	22074	\N	2014-11-03 16:15:20	2015-01-08 17:14:29
24274	MEMBRE	2014-11-12 00:00:00	2017-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	22185	\N	2014-11-13 09:28:05	2017-07-20 11:45:11
24275	MEMBRE	2014-11-12 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	22186	\N	2014-11-13 09:31:01	2015-02-13 11:38:09
24276	MEMBRE	2014-11-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22187	\N	2014-11-13 09:31:01	\N
24277	MEMBRE	2014-11-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22188	\N	2014-11-13 09:31:01	\N
24278	MEMBRE	2014-11-12 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	22189	\N	2014-11-13 09:31:01	2015-02-03 10:22:20
24279	MEMBRE	2014-11-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22190	\N	2014-11-13 09:31:01	\N
24280	MEMBRE	2014-11-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22191	\N	2014-11-13 09:31:01	\N
24281	MEMBRE	2014-11-12 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	22192	\N	2014-11-13 09:31:01	2015-02-05 18:59:04
24282	MEMBRE	2014-11-12 00:00:00	2015-01-21 00:00:00	ANCIEN	\N	\N	\N	\N	22193	\N	2014-11-13 09:31:01	2015-01-22 10:51:16
24283	MEMBRE	2014-11-12 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	22194	\N	2014-11-13 09:31:01	2015-02-11 12:10:43
24284	MEMBRE	2014-11-12 00:00:00	2015-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	22195	\N	2014-11-13 09:31:01	2015-02-12 16:24:34
24285	MEMBRE	2014-11-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22196	\N	2014-11-13 14:23:20	\N
24286	MEMBRE	2014-11-03 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	22197	\N	2014-11-13 15:41:13	2015-01-06 16:32:56
24287	MEMBRE	2014-11-03 00:00:00	2014-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	22198	\N	2014-11-13 15:41:13	2014-11-13 15:44:58
24288	MEMBRE	2014-11-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22199	\N	2014-11-13 15:41:13	\N
24289	MEMBRE	2014-11-03 00:00:00	2014-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	22200	\N	2014-11-13 15:41:13	2014-11-13 15:44:58
24290	MEMBRE	2014-11-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22201	\N	2014-11-13 15:41:13	\N
24291	MEMBRE	2014-11-03 00:00:00	2014-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	22202	\N	2014-11-13 15:41:13	2014-11-13 15:44:58
24292	MEMBRE	2014-11-03 00:00:00	2015-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	22203	\N	2014-11-13 15:41:13	2015-02-06 16:56:39
24293	MEMBRE	2014-11-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22204	\N	2014-11-13 15:41:13	\N
24294	MEMBRE	2014-11-03 00:00:00	2014-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	22205	\N	2014-11-13 15:41:13	2014-11-13 15:44:58
24295	MEMBRE	2014-11-03 00:00:00	2014-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	22206	\N	2014-11-13 15:41:13	2014-11-13 15:44:58
24296	MEMBRE	2014-11-03 00:00:00	2014-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	22207	\N	2014-11-13 15:41:13	2014-11-13 15:44:58
24297	MEMBRE	2014-11-03 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	22208	\N	2014-11-13 15:41:13	2015-01-06 15:49:11
24298	MEMBRE	2014-11-03 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	22209	\N	2014-11-13 15:41:13	2015-02-13 15:15:09
24299	MEMBRE	2014-11-03 00:00:00	2014-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	22210	\N	2014-11-13 15:41:13	2014-11-13 15:44:58
24300	MEMBRE	2014-11-03 00:00:00	2015-03-19 00:00:00	ANCIEN	\N	\N	\N	\N	22211	\N	2014-11-13 15:41:13	2015-03-20 09:53:15
24301	MEMBRE	2014-11-03 00:00:00	2014-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	22212	\N	2014-11-13 15:41:13	2014-11-13 15:44:58
24302	MEMBRE	2014-11-03 00:00:00	2014-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	22213	\N	2014-11-13 15:41:13	2014-11-13 15:44:58
24303	MEMBRE	2014-11-03 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	22214	\N	2014-11-13 15:41:13	2015-02-05 19:03:30
24304	MEMBRE	2014-11-03 00:00:00	2014-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	22215	\N	2014-11-13 15:41:13	2014-11-13 15:44:58
24767	VICPDT	2015-01-27 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20312	2	2015-01-27 17:07:26	2015-01-27 17:07:50
24768	VICPDT	2015-01-27 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21481	3	2015-01-27 17:08:04	2015-01-27 17:09:04
24769	VICPDT	2015-01-27 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21209	4	2015-01-27 17:08:18	2015-01-27 17:09:07
24770	VICPDT	2015-01-27 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20560	5	2015-01-27 17:08:24	2015-01-27 17:09:10
24771	VICPDT	2015-01-27 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20533	6	2015-01-27 17:08:31	2015-01-27 17:09:12
24772	SECRET	2015-01-27 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21649	7	2015-01-27 17:08:38	2015-01-27 17:09:16
24773	SECRET	2015-01-27 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21562	8	2015-01-27 17:08:43	2015-01-27 17:09:18
24774	SECRET	2015-01-27 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21627	10	2015-01-27 17:08:50	2015-02-02 14:59:08
25222	VICPDT	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21114	2	2015-02-13 09:50:24	2015-02-13 09:50:51
25223	SECRET	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21933	4	2015-02-13 09:50:31	2015-02-13 09:50:53
25224	SECRET	2015-02-13 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	21852	5	2015-02-13 09:50:36	2016-03-11 18:02:51
25374	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22644	\N	\N	\N
25375	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22645	\N	\N	\N
25376	MEMBRE	2014-10-01 00:00:00	2015-03-24 00:00:00	ANCIEN	\N	\N	\N	\N	22646	\N	\N	\N
25377	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22647	\N	\N	2017-09-24 13:44:49
25383	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22653	\N	\N	\N
25394	MEMBRE	2015-01-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	22664	\N	\N	\N
25613	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22832	\N	\N	\N
25630	MEMBRE	2014-10-01 00:00:00	2015-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	22835	\N	\N	\N
25632	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22837	\N	\N	\N
25633	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22838	\N	\N	\N
25634	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22839	\N	\N	\N
25635	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22840	\N	\N	2017-09-24 17:42:26
25636	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22841	\N	\N	\N
26020	PDT	2015-03-04 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22803	\N	\N	2017-10-01 10:01:39
26021	VICPDT	2015-03-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	22809	\N	\N	\N
26023	VICPDT	2015-03-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	22784	\N	\N	\N
26024	VICPDT	2015-03-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	22930	\N	\N	\N
26026	VICPDT	2015-03-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	22931	\N	\N	\N
26027	VICPDT	2015-03-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	22937	\N	\N	\N
26028	VICPDT	2015-03-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23069	\N	\N	2017-09-24 17:14:27
26030	VICPDT	2015-03-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	22786	\N	\N	\N
26031	SECRET	2015-03-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22934	\N	\N	2017-09-24 13:25:54
26032	SECRET	2015-03-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	22791	\N	\N	\N
26261	VICPDT	2015-03-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21895	3	2015-03-20 09:52:32	2015-03-20 09:53:47
26262	VICPDT	2015-03-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22350	4	2015-03-20 09:52:38	2015-03-20 09:53:51
26263	VICPDT	2015-03-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20765	5	2015-03-20 09:52:43	2017-09-24 18:17:56
26264	VICPDT	2015-03-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21701	6	2015-03-20 09:52:50	2017-10-01 10:39:23
26265	VICPDT	2015-03-20 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	21833	7	2015-03-20 09:52:56	2016-12-12 16:10:15
26266	VICPDT	2015-03-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21671	8	2015-03-20 09:53:01	2015-03-20 09:54:05
26267	VICPDT	2015-03-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21743	9	2015-03-20 09:53:10	2017-09-24 19:25:10
26268	VICPDT	2015-03-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22211	10	2015-03-20 09:53:15	2017-09-24 13:47:46
26269	VICPDT	2015-03-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20979	11	2015-03-20 09:53:19	2015-03-20 09:54:17
26270	VICPDT	2015-03-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21679	12	2015-03-20 09:53:26	2015-03-20 09:54:21
26271	SECRET	2015-03-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21370	13	2015-03-20 09:53:35	2017-09-24 17:18:03
26272	SECRET	2015-03-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21540	14	2015-03-20 09:53:39	2017-10-01 10:34:22
26351	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23213	\N	\N	\N
26393	VICPDT	2015-03-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23222	\N	\N	\N
26415	MEMBRE	2015-05-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23253	\N	2015-05-06 17:18:42	\N
26422	VICPDT	2015-05-06 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	22871	\N	\N	2017-05-16 15:18:14
26495	MEMBRE	2014-10-01 00:00:00	2015-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	23282	\N	\N	\N
26497	VICPDT	2015-05-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	23241	\N	\N	\N
26502	SECRET	2015-06-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	23199	\N	\N	\N
26503	SECRET	2015-05-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	22888	\N	\N	\N
26505	VICPDT	2015-05-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	22895	\N	\N	\N
26506	SECRET	2015-05-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	22744	\N	\N	\N
26507	SECRET	2015-05-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	22892	\N	\N	\N
26525	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23300	\N	\N	\N
26550	MEMBRE	2014-10-01 00:00:00	2015-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	23325	\N	\N	\N
26619	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23377	\N	\N	\N
26901	PDT	2016-04-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	22759	\N	\N	\N
27070	MEMBRE	2016-10-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23762	\N	2016-10-28 15:40:44	2017-09-24 13:25:54
27084	MEMBRE	2016-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23776	\N	\N	2017-09-24 17:35:15
27087	MEMBRE	2016-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23779	\N	\N	\N
27088	MEMBRE	2016-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23780	\N	\N	\N
27119	MEMBRE	2016-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23811	\N	\N	\N
27169	MEMBRE	2017-02-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23836	\N	\N	2017-09-24 19:25:10
28137	MEMBRE	2017-10-26 00:00:00	2018-12-30 00:00:00	ANCIEN	\N	\N	\N	\N	24704	\N	2017-10-26 15:43:48	\N
28138	MEMBRE	2017-10-26 00:00:00	2018-12-30 00:00:00	ANCIEN	\N	\N	\N	\N	24705	\N	2017-10-26 15:43:48	\N
28139	MEMBRE	2017-10-26 00:00:00	2017-11-13 00:00:00	ANCIEN	\N	\N	\N	\N	24706	\N	2017-10-26 15:43:48	2017-11-15 09:32:13
28140	MEMBRE	2017-10-19 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	24707	\N	2017-10-26 15:44:21	2018-01-25 17:35:37
28141	MEMBRE	2017-10-19 00:00:00	2017-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	24708	\N	2017-10-26 15:44:21	2017-11-28 17:01:21
26055	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23082	\N	\N	\N
26056	MEMBRE	2014-10-01 00:00:00	2015-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	23083	\N	\N	\N
26427	PDT	2015-03-25 00:00:00	2015-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	23095	\N	\N	\N
26499	SECRET	2015-05-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22746	\N	\N	2017-09-24 18:16:52
26504	VICPDT	2015-05-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	22890	\N	\N	\N
26906	MEMBRE	2016-05-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23613	\N	2016-05-04 14:35:24	\N
27860	MEMBRE	2017-10-19 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	24427	\N	2017-10-19 16:48:34	2018-01-23 17:21:18
28183	MEMBRE	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24750	\N	2017-10-27 09:56:07	\N
28184	MEMBRE	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24751	\N	2017-10-27 09:56:07	\N
28185	MEMBRE	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24752	\N	2017-10-27 09:56:07	\N
28186	MEMBRE	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24753	\N	2017-10-27 09:57:22	\N
28187	MEMBRE	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24754	\N	2017-10-27 09:57:22	\N
28188	MEMBRE	2017-10-26 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24755	\N	2017-10-27 09:57:22	2018-01-24 18:06:54
28189	MEMBRE	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24756	\N	2017-10-27 09:57:22	\N
28190	MEMBRE	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24757	\N	2017-10-27 09:57:22	\N
28191	MEMBRE	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24758	\N	2017-10-27 09:57:49	\N
28192	MEMBRE	2017-10-25 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	24759	\N	2017-10-27 09:57:49	2018-01-23 17:23:39
28193	MEMBRE	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24760	\N	2017-10-27 09:58:29	\N
28194	MEMBRE	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24761	\N	2017-10-27 09:58:29	\N
28195	MEMBRE	2017-10-26 00:00:00	2017-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	24762	\N	2017-10-27 09:58:29	2017-12-05 10:05:17
28196	MEMBRE	2017-10-26 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	24763	\N	2017-10-27 09:58:29	2018-01-25 17:36:55
28197	MEMBRE	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24764	\N	2017-10-27 09:58:29	\N
28198	MEMBRE	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24765	\N	2017-10-27 09:58:29	\N
28199	MEMBRE	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24766	\N	2017-10-27 09:58:45	\N
28200	MEMBRE	2017-10-26 00:00:00	2017-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	24767	\N	2017-10-27 09:59:15	2017-12-19 18:17:31
28201	MEMBRE	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24768	\N	2017-10-27 09:59:15	\N
28202	MEMBRE	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24769	\N	2017-10-27 09:59:15	\N
28203	MEMBRE	2017-10-26 00:00:00	2018-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	24770	\N	2017-10-27 10:00:17	2018-01-30 16:00:46
28204	MEMBRE	2017-10-26 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	24771	\N	2017-10-27 10:00:17	2018-01-23 17:26:30
28205	MEMBRE	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24772	\N	2017-10-27 10:00:17	\N
28206	MEMBRE	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24773	\N	2017-10-27 10:00:17	\N
28207	MEMBRE	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24774	\N	2017-10-27 10:00:17	\N
28208	MEMBRE	2017-10-26 00:00:00	2020-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	24775	\N	2017-10-27 10:00:36	\N
28209	MEMBRE	2017-10-26 00:00:00	2017-12-11 00:00:00	ANCIEN	\N	\N	\N	\N	24776	\N	2017-10-27 10:01:06	2017-12-12 17:36:03
28210	MEMBRE	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24777	\N	2017-10-27 10:01:06	\N
28211	MEMBRE	2017-10-26 00:00:00	2018-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	24778	\N	2017-10-27 10:01:06	2018-01-16 19:06:37
28212	MEMBRE	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24779	\N	2017-10-27 10:01:06	\N
28213	MEMBRE	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24780	\N	2017-10-27 10:01:38	\N
28910	PDT	2017-11-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24569	\N	2017-11-28 16:25:51	\N
28911	PDT	2017-11-28 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25212	\N	2017-11-28 16:28:06	\N
28912	PDT	2017-11-28 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24064	\N	2017-11-28 16:28:40	\N
28913	PDT	2017-11-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24488	\N	2017-11-28 16:29:08	\N
28914	PDT	2017-11-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25388	\N	2017-11-28 16:30:48	\N
28915	PDT	2017-11-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25058	\N	2017-11-28 16:31:27	\N
28916	PDT	2017-11-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24018	\N	2017-11-28 16:32:03	\N
28917	PDT	2017-11-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25357	\N	2017-11-28 16:35:11	\N
28918	PDT	2017-11-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24856	\N	2017-11-28 16:35:59	\N
28919	PDT	2017-11-28 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25282	\N	2017-11-28 16:53:14	\N
28920	PDT	2017-11-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24087	\N	2017-11-28 16:54:37	\N
28921	PDT	2017-11-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24280	\N	2017-11-28 16:55:40	\N
28922	PDT	2017-11-28 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25147	\N	2017-11-28 16:57:32	\N
28923	PDT	2017-11-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25316	\N	2017-11-28 16:58:00	\N
28924	PDT	2017-11-28 00:00:00	2018-08-06 00:00:00	ANCIEN	\N	\N	\N	\N	24070	\N	2017-11-28 16:58:24	\N
28925	PDT	2017-11-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24290	\N	2017-11-28 16:58:44	\N
28926	PDT	2017-11-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24014	\N	2017-11-28 16:59:10	\N
28927	PDT	2017-11-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24335	\N	2017-11-28 16:59:37	\N
28928	PDT	2017-11-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24061	\N	2017-11-28 17:00:00	\N
28929	PDT	2017-11-28 00:00:00	2017-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	24080	\N	2017-11-28 17:00:58	2017-11-30 15:59:02
28930	PDT	2017-11-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24708	\N	2017-11-28 17:01:21	\N
28931	PDT	2017-11-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24667	\N	2017-11-28 17:02:31	\N
28932	PDT	2017-11-28 00:00:00	2020-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	24144	\N	2017-11-28 17:02:56	\N
28933	PDT	2017-11-28 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	24023	\N	2017-11-28 17:03:15	\N
28934	PDT	2017-11-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25159	\N	2017-11-28 17:03:35	\N
28935	PDT	2017-11-28 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24715	\N	2017-11-28 17:04:21	\N
28936	PDT	2017-11-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24256	\N	2017-11-28 17:04:45	\N
28937	PDT	2017-11-28 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24723	\N	2017-11-28 17:05:06	\N
28938	PDT	2017-11-28 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24344	\N	2017-11-28 17:05:31	\N
28939	PDT	2017-11-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25094	\N	2017-11-28 17:06:01	\N
28940	PDT	2017-11-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24093	\N	2017-11-28 17:06:26	\N
29748	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25964	\N	\N	\N
29785	PDTDEL	2018-01-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Malaisie	\N	25904	\N	2018-01-19 10:00:08	2018-01-19 10:03:12
29808	MEMBRE	2018-01-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25979	\N	2018-01-22 14:54:01	\N
29809	SECRET	2018-01-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25968	\N	2018-01-22 15:32:06	2018-01-22 15:32:18
29810	VICPDT	2018-01-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25962	\N	2018-01-22 15:32:28	\N
29915	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25997	\N	\N	\N
29935	VICPDT	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26015	\N	\N	\N
29936	MEMBRE	2017-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26016	\N	\N	\N
29938	MEMBRE	2017-10-01 00:00:00	2018-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	26017	\N	\N	2018-04-13 17:54:30
29939	MEMBRE	2017-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26018	\N	\N	\N
29940	PDT	2018-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	26018	\N	\N	\N
29941	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26019	\N	\N	\N
29944	MEMBRE	2017-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26021	\N	\N	\N
29945	VICPDT	2018-01-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26021	\N	\N	\N
29946	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26022	\N	\N	\N
29948	MEMBRE	2017-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26024	\N	\N	\N
29949	VICPDT	2018-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	26024	\N	\N	\N
29951	VICPDT	2018-01-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26025	\N	\N	\N
29952	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26026	\N	\N	\N
29953	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26027	\N	\N	\N
29955	MEMBRE	2017-12-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26029	\N	\N	\N
29973	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26035	\N	\N	\N
30048	VICPDT	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24089	\N	2018-01-25 11:14:06	\N
30049	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26045	\N	\N	\N
30050	VICPDT	2018-01-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	26023	\N	\N	\N
30051	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26046	\N	\N	\N
30052	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26047	\N	\N	\N
30053	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26048	\N	\N	\N
30054	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26049	\N	\N	\N
30056	MEMBRE	2017-10-01 00:00:00	2018-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	26051	\N	\N	\N
30057	MEMBRE	2017-10-01 00:00:00	2018-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	26052	\N	\N	\N
30058	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26053	\N	\N	\N
30060	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26055	\N	\N	\N
30061	MEMBRE	2017-10-01 00:00:00	2018-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	26056	\N	\N	\N
30062	MEMBRE	2017-10-01 00:00:00	2018-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	26057	\N	\N	\N
30063	MEMBRE	2017-10-01 00:00:00	2018-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	26058	\N	\N	\N
30064	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26059	\N	\N	\N
30065	MEMBRE	2017-10-01 00:00:00	2018-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	26060	\N	\N	\N
30066	MEMBRE	2017-10-01 00:00:00	2018-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	26061	\N	\N	\N
30069	MEMBRE	2017-10-01 00:00:00	2018-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	26064	\N	\N	\N
30070	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26065	\N	\N	\N
30072	MEMBRE	2017-10-01 00:00:00	2019-06-24 00:00:00	ANCIEN	\N	\N	\N	\N	26067	\N	\N	\N
30073	MEMBRE	2017-10-01 00:00:00	2018-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	26068	\N	\N	\N
30074	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26069	\N	\N	\N
30078	MEMBRE	2017-10-01 00:00:00	2018-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	26073	\N	\N	\N
30079	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26074	\N	\N	\N
30081	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26076	\N	\N	\N
30082	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26077	\N	\N	\N
30083	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26078	\N	\N	\N
30084	MEMBRE	2017-10-01 00:00:00	2018-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	26079	\N	\N	\N
30085	MEMBRE	2017-10-01 00:00:00	2018-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	26080	\N	\N	\N
30086	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26081	\N	\N	\N
30087	MEMBRE	2017-10-01 00:00:00	2018-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	26082	\N	\N	\N
30088	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26083	\N	\N	\N
22275	MEMBRE	2013-12-17 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20221	\N	\N	\N
23338	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21249	\N	2014-10-28 10:40:02	\N
23339	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21250	\N	2014-10-28 10:40:02	\N
23340	MEMBRE	2014-10-22 00:00:00	2017-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	21251	\N	2014-10-28 10:40:02	2017-07-20 14:38:36
23341	MEMBRE	2014-10-22 00:00:00	2017-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	21252	\N	2014-10-28 10:40:02	2017-07-20 11:43:02
23342	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21253	\N	2014-10-28 10:40:02	\N
23343	MEMBRE	2014-10-22 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	21254	\N	2014-10-28 10:40:02	2015-02-11 11:01:13
23344	MEMBRE	2014-10-22 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	21255	\N	2014-10-28 10:40:02	2015-02-20 12:08:57
23345	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21256	\N	2014-10-28 10:40:02	\N
23346	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21257	\N	2014-10-28 10:40:02	\N
23347	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21258	\N	2014-10-28 10:40:02	\N
23348	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21259	\N	2014-10-28 10:40:02	\N
23349	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21260	\N	2014-10-28 10:40:02	\N
23350	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21261	\N	2014-10-28 10:40:02	\N
23351	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21262	\N	2014-10-28 10:40:02	\N
23352	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21263	\N	2014-10-28 10:57:02	\N
23353	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21264	\N	2014-10-28 10:57:02	\N
23354	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21265	\N	2014-10-28 10:57:02	\N
24221	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22132	\N	2014-11-06 15:52:46	\N
24222	MEMBRE	2014-10-15 00:00:00	2015-03-19 00:00:00	ANCIEN	\N	\N	\N	\N	22133	\N	2014-11-06 15:52:46	2015-03-20 11:38:15
24223	MEMBRE	2014-10-15 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	22134	\N	2014-11-06 15:52:46	2015-01-06 17:38:10
24328	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22235	\N	2014-11-19 09:34:35	\N
24329	MEMBRE	2014-10-28 00:00:00	2016-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	22236	\N	2014-11-19 09:34:35	2016-02-02 18:00:43
24330	MEMBRE	2014-10-28 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	22237	\N	2014-11-19 09:34:35	2015-02-13 10:34:50
24331	MEMBRE	2014-10-28 00:00:00	2015-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	22238	\N	2014-11-19 09:34:35	2015-02-23 11:40:00
25054	SECRET	2015-02-06 00:00:00	2016-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	21521	34	2015-02-06 15:54:36	2016-11-14 11:07:47
25055	MEMBRE	2015-01-30 00:00:00	2015-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	22527	\N	2015-02-06 15:59:38	2015-02-06 16:48:21
25058	PDTDEL	2015-02-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour le Libéria	\N	22527	13	2015-02-06 16:48:21	2015-02-11 12:13:01
25057	PDTDEL	2015-02-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour l'Uruguay	\N	22528	5	2015-02-06 16:41:07	2015-02-06 16:45:12
25059	VICPDT	2015-02-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22307	\N	2015-02-06 16:55:56	2015-02-06 16:56:04
25060	VICPDT	2015-02-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22312	\N	2015-02-06 16:56:15	\N
25061	VICPDT	2015-02-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22053	\N	2015-02-06 16:56:29	\N
25062	VICPDT	2015-02-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22203	\N	2015-02-06 16:56:39	\N
25063	VICPDT	2015-02-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20545	\N	2015-02-06 16:56:43	\N
25064	SECRET	2015-02-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22229	\N	2015-02-06 16:56:51	\N
25065	SECRET	2015-02-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21928	\N	2015-02-06 16:56:58	\N
25066	SECRET	2015-02-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21113	\N	2015-02-06 16:57:07	\N
25067	SECRET	2015-02-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21396	\N	2015-02-06 16:57:17	\N
25068	SECRET	2015-02-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21491	\N	2015-02-06 16:57:29	\N
25069	SECRET	2015-02-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21962	\N	2015-02-06 16:58:27	\N
25070	SECRET	2015-02-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21683	\N	2015-02-06 16:58:34	\N
25148	VICPDT	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21790	2	2015-02-11 17:11:57	2015-02-11 17:12:46
25149	VICPDT	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20585	3	2015-02-11 17:12:04	2015-02-11 17:12:48
25150	VICPDT	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21132	4	2015-02-11 17:12:10	2015-02-11 17:12:51
25151	VICPDT	2015-02-11 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21159	5	2015-02-11 17:12:16	2015-02-11 17:12:54
25152	VICPDT	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21224	6	2015-02-11 17:12:24	2015-02-11 17:12:56
25153	VICPDT	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21275	7	2015-02-11 17:12:28	2015-02-11 17:12:59
25154	SECRET	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21892	8	2015-02-11 17:12:37	2015-02-11 17:13:01
25155	VICPDT	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20488	9	2015-02-11 17:18:17	2015-02-11 17:19:25
25156	VICPDT	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20904	10	2015-02-11 17:18:22	2015-02-11 17:19:28
25157	VICPDT	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21104	11	2015-02-11 17:18:35	2015-02-11 17:19:32
25158	VICPDT	2015-02-11 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	21885	12	2015-02-11 17:18:45	2016-03-11 18:02:51
25159	VICPDT	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21676	13	2015-02-11 17:18:50	2015-02-11 17:19:38
25160	SECRET	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20713	14	2015-02-11 17:19:14	2015-02-11 17:19:39
25161	VICPDT	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20500	2	2015-02-11 17:25:11	2015-02-11 17:26:29
25162	VICPDT	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21456	3	2015-02-11 17:25:24	2015-02-11 17:26:33
25163	VICPDT	2015-02-11 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21164	4	2015-02-11 17:25:32	2015-02-11 17:26:35
25164	VICPDT	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22090	5	2015-02-11 17:25:45	2015-02-11 17:26:38
25165	SECRET	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21637	6	2015-02-11 17:26:02	2015-02-11 17:26:44
25166	SECRET	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20466	7	2015-02-11 17:26:19	2015-02-11 17:26:46
25612	MEMBRE	2014-10-01 00:00:00	2015-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	22831	\N	\N	\N
25631	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22836	\N	\N	\N
25639	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22844	\N	\N	2017-09-24 13:14:55
25640	MEMBRE	2014-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22845	\N	\N	2017-10-01 10:34:22
25641	MEMBRE	2014-10-01 00:00:00	2015-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	22846	\N	\N	\N
25671	MEMBRE	2014-10-01 00:00:00	2014-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22856	\N	\N	\N
26022	VICPDT	2015-03-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	22792	\N	\N	\N
26029	VICPDT	2015-03-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	22939	\N	\N	\N
26310	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23188	\N	\N	\N
26413	MEMBRE	2015-05-05 00:00:00	2015-05-06 00:00:00	ANCIEN	\N	\N	\N	\N	22406	\N	2015-05-05 16:57:56	2015-05-11 17:08:32
26414	MEMBRE	2015-02-13 00:00:00	2015-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	23252	\N	2015-05-06 10:09:49	2015-07-08 16:47:08
26895	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23603	\N	\N	\N
27193	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23859	\N	\N	\N
26929	MEMBRE	2016-06-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	23635	\N	\N	\N
27652	MEMBRE	2017-10-11 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24219	\N	2017-10-17 15:10:43	\N
26931	MEMBRE	2016-06-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	23637	\N	\N	\N
26932	MEMBRE	2016-06-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	23638	\N	\N	\N
26936	MEMBRE	2016-06-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	23642	\N	\N	\N
26937	MEMBRE	2016-06-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	23643	\N	\N	\N
26938	MEMBRE	2016-06-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23644	\N	\N	2017-09-24 12:57:09
27068	MEMBRE	2016-07-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23760	\N	2016-10-26 12:08:16	2017-09-24 17:28:55
27643	MEMBRE	2017-10-12 00:00:00	2018-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	24210	\N	2017-10-17 15:10:18	2018-01-19 10:24:40
27644	MEMBRE	2017-10-12 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	24211	\N	2017-10-17 15:10:19	2018-01-18 11:23:12
27645	MEMBRE	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24212	\N	2017-10-17 15:10:19	\N
27646	MEMBRE	2017-10-12 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	24213	\N	2017-10-17 15:10:19	2018-01-18 18:10:53
27647	MEMBRE	2017-10-12 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	24214	\N	2017-10-17 15:10:19	2018-02-07 16:35:20
27648	MEMBRE	2017-10-12 00:00:00	2018-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	24215	\N	2017-10-17 15:10:19	2018-01-30 12:29:15
27649	MEMBRE	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24216	\N	2017-10-17 15:10:19	\N
27650	MEMBRE	2017-10-12 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	24217	\N	2017-10-17 15:10:19	2018-01-25 16:04:47
27651	MEMBRE	2017-10-11 00:00:00	2017-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	24218	\N	2017-10-17 15:10:43	2017-12-01 14:52:26
27653	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24220	\N	2017-10-17 15:11:11	\N
27654	MEMBRE	2017-10-10 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	24221	\N	2017-10-17 15:11:11	2018-01-18 17:49:37
27655	MEMBRE	2017-10-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24222	\N	2017-10-17 15:12:13	\N
28459	MEMBRE	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25026	\N	2017-11-02 11:15:51	\N
28460	MEMBRE	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25027	\N	2017-11-02 11:15:51	\N
28461	MEMBRE	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25028	\N	2017-11-02 11:15:51	\N
28462	MEMBRE	2017-10-31 00:00:00	2018-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	25029	\N	2017-11-02 11:15:51	2018-02-14 12:55:34
28463	MEMBRE	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25030	\N	2017-11-02 11:15:51	\N
29257	PDT	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25656	\N	2017-12-19 15:35:12	2017-12-19 15:36:08
25665	MEMBRE	2015-02-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22850	\N	2015-02-18 16:03:24	\N
25666	MEMBRE	2015-02-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22851	\N	2015-02-18 16:03:34	\N
25667	MEMBRE	2015-02-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22852	\N	2015-02-18 16:03:44	\N
25679	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22863	\N	\N	\N
25674	SECRET	2015-02-19 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	22855	7	2015-02-19 09:09:18	2016-12-12 16:10:15
25726	PDT	2015-02-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22567	\N	\N	\N
25730	VICPDT	2015-02-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22573	\N	\N	\N
25731	VICPDT	2015-02-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22856	\N	\N	\N
25732	VICPDT	2015-02-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22550	\N	\N	\N
25733	VICPDT	2015-02-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22579	\N	\N	\N
25734	VICPDT	2015-02-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22847	\N	\N	\N
25735	VICPDT	2015-02-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22555	\N	\N	\N
25736	VICPDT	2015-02-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22562	\N	\N	\N
25737	VICPDT	2015-02-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22593	\N	\N	\N
25738	SECRET	2015-02-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22582	\N	\N	\N
25740	SECRET	2015-02-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22586	\N	\N	\N
25760	VICPDT	2015-02-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21798	2	2015-02-19 15:42:14	2015-02-19 15:42:19
25761	VICPDT	2015-02-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20318	3	2015-02-19 15:42:25	2015-02-19 15:42:31
25762	VICPDT	2015-02-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22145	4	2015-02-19 15:42:35	2015-02-19 15:43:09
25763	VICPDT	2015-02-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20938	5	2015-02-19 15:42:43	2015-02-19 15:43:11
25764	VICPDT	2015-02-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20543	6	2015-02-19 15:42:52	2015-02-19 15:43:15
25765	SECRET	2015-02-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21383	7	2015-02-19 15:42:56	2015-02-19 15:43:16
25766	SECRET	2015-02-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20431	8	2015-02-19 15:43:01	2015-02-19 15:43:17
26035	SECRET	2015-03-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22795	\N	\N	2017-09-24 17:06:55
26036	SECRET	2015-03-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	22810	\N	\N	\N
26038	SECRET	2015-03-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	22966	\N	\N	\N
26039	SECRET	2015-03-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	22796	\N	\N	\N
26040	SECRET	2015-03-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	22813	\N	\N	\N
26045	SECRET	2015-03-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	22802	\N	\N	\N
26046	MEMBRE	2014-09-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23073	\N	2015-03-04 15:55:55	2017-10-01 10:25:16
26050	MEMBRE	2014-09-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23077	\N	2015-03-04 16:34:55	\N
26064	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23086	\N	\N	\N
26065	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23087	\N	\N	\N
26066	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23088	\N	\N	\N
26144	MEMBRE	2014-10-01 00:00:00	2016-01-11 00:00:00	ANCIEN	\N	\N	\N	\N	23119	\N	\N	2016-01-11 17:34:09
26075	PDT	2015-03-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	22982	\N	\N	\N
26145	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23120	\N	\N	\N
26146	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23121	\N	\N	\N
26147	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23122	\N	\N	\N
26148	MEMBRE	2014-10-01 00:00:00	2015-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	23123	\N	\N	\N
26149	MEMBRE	2014-10-01 00:00:00	2015-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	23124	\N	\N	\N
26292	MEMBRE	2015-03-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23178	\N	2015-04-01 09:46:08	2017-09-24 19:16:18
26308	VICPDT	2015-04-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	23057	\N	\N	\N
26315	MEMBRE	2015-04-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23193	\N	2015-04-09 09:47:01	2017-09-24 13:29:42
26322	MEMBRE	2015-03-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23194	\N	2015-04-10 14:38:27	2017-09-24 16:24:51
26323	MEMBRE	2015-03-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23195	\N	2015-04-10 14:38:27	2017-09-24 16:24:51
26324	VICPDT	2015-04-10 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	22489	3	2015-04-10 15:09:54	2017-06-19 16:04:13
26325	VICPDT	2015-04-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21802	4	2015-04-10 15:09:58	2017-09-24 17:47:28
26326	VICPDT	2015-04-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21335	5	2015-04-10 15:10:05	2015-04-10 15:13:29
26327	VICPDT	2015-04-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20883	6	2015-04-10 15:10:11	2017-09-24 18:16:52
26328	VICPDT	2015-04-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20309	7	2015-04-10 15:10:19	2017-09-24 18:59:59
26329	VICPDT	2015-04-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21926	8	2015-04-10 15:10:26	2015-04-10 15:13:39
26330	VICPDT	2015-04-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20814	9	2015-04-10 15:10:32	2015-04-10 15:13:43
26331	VICPDT	2015-04-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20737	10	2015-04-10 15:10:38	2015-04-10 15:13:46
26332	SECRET	2015-04-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21642	11	2015-04-10 15:10:44	2017-09-24 13:44:49
26333	SECRET	2015-04-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22071	12	2015-04-10 15:10:48	2015-04-10 15:13:54
26342	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23204	\N	\N	2017-09-24 17:47:27
26347	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23209	\N	\N	\N
26382	MEMBRE	2015-03-02 00:00:00	2015-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	23228	\N	\N	\N
26383	MEMBRE	2015-03-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	23229	\N	\N	\N
26384	MEMBRE	2015-03-02 00:00:00	2015-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	23230	\N	\N	2015-10-12 09:39:31
26385	MEMBRE	2015-03-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	23231	\N	\N	\N
26386	MEMBRE	2015-03-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	23232	\N	\N	\N
26389	MEMBRE	2015-03-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	23235	\N	\N	\N
26391	MEMBRE	2015-03-02 00:00:00	2015-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	23237	\N	\N	\N
26392	MEMBRE	2015-03-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	23238	\N	\N	\N
26397	VICPDT	2015-03-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23236	\N	\N	\N
26429	VICPDT	2015-03-25 00:00:00	2015-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	22635	\N	\N	\N
26467	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23272	\N	\N	2017-09-24 17:06:55
26494	MEMBRE	2015-05-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23281	\N	2015-06-02 15:00:05	\N
26658	MEMBRE	2015-01-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23397	\N	2015-10-07 09:32:02	\N
26669	VICPDT	2015-10-21 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	23245	\N	\N	2016-12-12 16:10:15
26670	VICPDT	2015-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23131	\N	\N	2017-10-01 10:20:50
26671	VICPDT	2015-10-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	23265	\N	\N	\N
26691	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23423	\N	\N	\N
26721	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23442	\N	\N	\N
26726	MEMBRE	2016-02-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23446	\N	2016-02-03 12:14:45	\N
26728	MEMBRE	2015-12-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23448	\N	2016-02-03 16:25:31	2017-09-24 17:47:27
26913	MEMBRE	2016-05-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23619	\N	2016-05-26 10:38:28	\N
27188	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23854	\N	\N	\N
26933	MEMBRE	2016-06-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	23639	\N	\N	\N
26934	MEMBRE	2016-06-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	23640	\N	\N	\N
26935	MEMBRE	2016-06-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	23641	\N	\N	\N
27018	MEMBRE	2016-06-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	23716	\N	\N	\N
26940	VICPDT	2016-06-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	23629	\N	\N	\N
26941	VICPDT	2016-06-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	23630	\N	\N	\N
26942	VICPDT	2016-06-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23632	\N	\N	2017-09-24 18:17:56
27189	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23855	\N	\N	\N
27237	MEMBRE	2017-07-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22063	\N	2017-07-20 14:38:36	2017-07-20 14:42:26
24152	MEMBRE	2014-10-31 00:00:00	2017-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	22063	\N	2014-11-03 15:12:02	2017-07-20 14:38:36
27238	MEMBRE	2017-07-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21526	\N	2017-07-20 14:38:36	2017-07-20 14:42:29
27239	MEMBRE	2017-07-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21042	\N	2017-07-20 14:38:36	2017-07-20 14:42:32
27240	MEMBRE	2017-07-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21239	\N	2017-07-20 14:38:36	2017-07-20 14:42:35
27241	MEMBRE	2017-07-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20315	\N	2017-07-20 14:38:36	2017-09-24 18:59:59
27242	MEMBRE	2017-07-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22334	\N	2017-07-20 14:38:36	2017-09-25 10:58:49
27243	MEMBRE	2017-07-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21251	\N	2017-07-20 14:38:36	2017-07-20 14:42:51
27244	MEMBRE	2017-07-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22342	\N	2017-07-20 14:38:36	2017-07-20 14:43:16
27245	MEMBRE	2017-07-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22545	\N	2017-07-20 14:38:36	2017-07-20 14:43:26
27246	MEMBRE	2017-07-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20964	\N	2017-07-20 14:38:49	2017-07-20 14:41:14
27247	MEMBRE	2017-07-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21572	\N	2017-07-20 14:38:49	2017-07-20 14:41:18
27248	MEMBRE	2017-07-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21010	\N	2017-07-20 14:38:49	2017-07-20 14:41:21
27249	MEMBRE	2017-07-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22354	\N	2017-07-20 14:38:49	2017-07-20 14:41:25
27250	MEMBRE	2017-07-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21626	\N	2017-07-20 14:38:49	2017-07-20 14:41:28
23740	MEMBRE	2014-10-30 00:00:00	2017-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	21651	\N	2014-10-30 12:06:37	2017-09-24 11:09:53
27265	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23872	\N	2017-10-10 09:45:39	\N
27267	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23873	\N	2017-10-10 09:45:39	\N
24205	MEMBRE	2014-11-04 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22116	\N	2014-11-05 17:07:55	\N
24206	MEMBRE	2014-10-23 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	22117	\N	2014-11-05 17:20:06	2015-06-12 15:59:18
24207	MEMBRE	2014-10-23 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	22118	\N	2014-11-05 17:20:06	2015-02-05 18:57:51
24208	MEMBRE	2014-10-23 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	22119	\N	2014-11-05 17:20:06	2015-02-19 17:23:40
24209	MEMBRE	2014-10-22 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	22120	\N	2014-11-05 17:20:20	2015-02-05 19:02:26
24210	MEMBRE	2014-10-22 00:00:00	2015-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	22121	\N	2014-11-05 17:20:20	2015-02-06 14:27:55
24211	MEMBRE	2014-10-22 00:00:00	2015-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	22122	\N	2014-11-05 17:20:20	2015-02-06 14:27:55
24212	MEMBRE	2014-10-22 00:00:00	2015-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	22123	\N	2014-11-05 17:20:20	2015-02-06 14:27:55
24213	MEMBRE	2014-10-22 00:00:00	2015-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	22124	\N	2014-11-05 17:20:46	2015-02-06 14:32:44
24214	MEMBRE	2014-10-22 00:00:00	2015-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	22125	\N	2014-11-05 17:20:46	2015-01-28 10:25:58
24215	MEMBRE	2014-10-22 00:00:00	2015-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	22126	\N	2014-11-05 17:20:46	2015-02-06 14:32:44
24216	MEMBRE	2014-10-22 00:00:00	2015-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	22127	\N	2014-11-05 17:20:46	2015-02-06 14:32:44
24835	MEMBRE	2015-01-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22479	\N	2015-01-29 16:02:56	\N
26025	VICPDT	2015-03-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22787	\N	\N	2017-09-24 13:44:49
26034	SECRET	2015-03-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	22790	\N	\N	\N
26037	SECRET	2015-03-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23071	\N	\N	2017-09-24 13:25:54
26660	MEMBRE	2015-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23398	\N	2015-10-07 15:28:43	\N
26729	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23449	\N	\N	\N
26943	VICPDT	2016-06-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	23636	\N	\N	\N
28142	MEMBRE	2017-10-19 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	24709	\N	2017-10-26 15:44:21	2017-12-20 12:21:56
28143	MEMBRE	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24710	\N	2017-10-26 15:44:21	\N
28144	MEMBRE	2017-10-10 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24711	\N	2017-10-26 15:44:57	2018-01-24 18:07:51
28145	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24712	\N	2017-10-26 15:44:57	\N
28146	MEMBRE	2017-10-25 00:00:00	2018-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	24713	\N	2017-10-26 15:45:24	2018-01-26 16:18:59
28147	MEMBRE	2017-10-25 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24714	\N	2017-10-26 15:45:24	\N
28148	MEMBRE	2017-10-25 00:00:00	2017-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	24715	\N	2017-10-26 15:45:24	2017-11-28 17:04:21
28149	MEMBRE	2017-10-25 00:00:00	2017-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	24716	\N	2017-10-26 15:45:24	2017-11-30 16:25:06
28150	MEMBRE	2017-10-25 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24717	\N	2017-10-26 15:45:24	\N
28151	MEMBRE	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24718	\N	2017-10-26 15:46:11	\N
28152	MEMBRE	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24719	\N	2017-10-26 15:46:11	\N
28153	MEMBRE	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24720	\N	2017-10-26 15:46:12	\N
28154	MEMBRE	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24721	\N	2017-10-26 15:46:12	\N
28155	MEMBRE	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24722	\N	2017-10-26 15:46:12	\N
28156	MEMBRE	2017-10-25 00:00:00	2017-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	24723	\N	2017-10-26 15:46:12	2017-11-28 17:05:06
28157	MEMBRE	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24724	\N	2017-10-26 15:46:12	\N
28158	MEMBRE	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24725	\N	2017-10-26 15:46:12	\N
28159	MEMBRE	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24726	\N	2017-10-26 15:46:12	\N
28160	MEMBRE	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24727	\N	2017-10-26 15:46:12	\N
28161	MEMBRE	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24728	\N	2017-10-26 15:46:12	\N
28162	MEMBRE	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24729	\N	2017-10-26 15:46:12	\N
28163	MEMBRE	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24730	\N	2017-10-26 15:46:12	\N
28164	MEMBRE	2017-10-25 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	24731	\N	2017-10-26 15:46:12	2017-12-20 12:22:28
28165	MEMBRE	2017-10-25 00:00:00	2018-03-04 00:00:00	ANCIEN	\N	\N	\N	\N	24732	\N	2017-10-26 15:46:12	2018-03-05 17:04:07
28166	MEMBRE	2017-10-25 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	24733	\N	2017-10-26 15:46:12	2018-01-18 16:36:58
28167	MEMBRE	2017-10-25 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	24734	\N	2017-10-26 15:46:12	2018-02-07 15:32:02
28168	MEMBRE	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24735	\N	2017-10-26 15:46:12	\N
28169	MEMBRE	2017-10-25 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	24736	\N	2017-10-26 15:46:12	2018-01-23 18:43:12
28240	MEMBRE	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24807	\N	2017-10-30 09:46:48	\N
28241	MEMBRE	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24808	\N	2017-10-30 09:47:16	\N
28242	MEMBRE	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24809	\N	2017-10-30 09:47:16	\N
28243	MEMBRE	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24810	\N	2017-10-30 09:47:16	\N
28244	MEMBRE	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24811	\N	2017-10-30 09:47:16	\N
28245	MEMBRE	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24812	\N	2017-10-30 09:47:16	\N
28246	MEMBRE	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24813	\N	2017-10-30 09:47:41	\N
28247	MEMBRE	2017-10-25 00:00:00	2017-12-05 00:00:00	ANCIEN	\N	\N	\N	\N	24814	\N	2017-10-30 09:47:41	2017-12-06 15:11:34
28248	MEMBRE	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24815	\N	2017-10-30 09:47:41	\N
28249	MEMBRE	2017-10-26 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	24816	\N	2017-10-30 09:48:29	2018-02-07 17:31:07
28250	MEMBRE	2017-10-26 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	24817	\N	2017-10-30 09:48:29	2018-01-23 18:42:41
28251	MEMBRE	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24818	\N	2017-10-30 09:48:29	\N
28252	MEMBRE	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24819	\N	2017-10-30 09:48:29	\N
28253	MEMBRE	2017-10-26 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	24820	\N	2017-10-30 09:48:29	2018-01-23 18:49:36
28254	MEMBRE	2017-10-26 00:00:00	2018-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	24821	\N	2017-10-30 09:48:29	2018-02-12 09:30:43
28255	MEMBRE	2017-10-26 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	24822	\N	2017-10-30 09:48:29	2018-01-25 10:58:43
28256	MEMBRE	2017-10-26 00:00:00	2018-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	24823	\N	2017-10-30 09:48:29	2018-02-06 16:27:40
28257	MEMBRE	2017-10-26 00:00:00	2018-03-04 00:00:00	ANCIEN	\N	\N	\N	\N	24824	\N	2017-10-30 09:48:29	2018-03-05 17:58:05
28258	MEMBRE	2017-10-26 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	24825	\N	2017-10-30 09:48:29	2018-01-18 17:52:13
28259	MEMBRE	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24826	\N	2017-10-30 09:48:29	\N
28260	MEMBRE	2017-10-25 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	24827	\N	2017-10-30 09:48:52	2018-01-25 16:02:30
28261	MEMBRE	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24828	\N	2017-10-30 09:48:52	\N
28262	MEMBRE	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24829	\N	2017-10-30 09:50:08	\N
28263	MEMBRE	2017-10-25 00:00:00	2018-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	24830	\N	2017-10-30 09:50:08	2018-01-29 17:06:18
28264	MEMBRE	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24831	\N	2017-10-30 09:50:24	\N
28265	MEMBRE	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24832	\N	2017-10-30 09:50:24	\N
28266	MEMBRE	2017-10-27 00:00:00	2018-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	24833	\N	2017-10-30 09:53:35	2018-02-01 18:31:49
28267	MEMBRE	2017-10-27 00:00:00	2018-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	24834	\N	2017-10-30 09:53:35	2018-02-01 17:49:29
28268	MEMBRE	2017-10-27 00:00:00	2017-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	24835	\N	2017-10-30 09:53:35	2017-12-07 14:58:40
28269	MEMBRE	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24836	\N	2017-10-30 09:53:52	\N
28270	MEMBRE	2017-10-26 00:00:00	2018-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	24837	\N	2017-10-30 09:53:52	2018-01-30 16:01:04
28297	MEMBRE	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24864	\N	2017-10-31 09:57:27	\N
28288	MEMBRE	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24855	\N	2017-10-31 09:56:31	\N
28289	MEMBRE	2017-10-26 00:00:00	2017-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	24856	\N	2017-10-31 09:56:31	2017-11-28 16:35:59
28290	MEMBRE	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24857	\N	2017-10-31 09:56:32	\N
28291	MEMBRE	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24858	\N	2017-10-31 09:56:32	\N
28292	MEMBRE	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24859	\N	2017-10-31 09:56:32	\N
28293	MEMBRE	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24860	\N	2017-10-31 09:56:32	\N
28294	MEMBRE	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24861	\N	2017-10-31 09:56:32	\N
28295	MEMBRE	2017-10-26 00:00:00	2018-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	24862	\N	2017-10-31 09:56:32	2018-01-16 19:09:09
28296	MEMBRE	2017-10-24 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	24863	\N	2017-10-31 09:57:27	2018-01-18 18:09:41
28298	MEMBRE	2017-10-24 00:00:00	2018-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	24865	\N	2017-10-31 09:57:27	2018-02-02 17:41:55
28299	MEMBRE	2017-10-24 00:00:00	2018-03-04 00:00:00	ANCIEN	\N	\N	\N	\N	24866	\N	2017-10-31 09:57:27	2018-03-05 17:19:13
28300	MEMBRE	2017-10-24 00:00:00	2017-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	24867	\N	2017-10-31 09:57:27	2017-12-05 16:40:56
28301	MEMBRE	2017-10-24 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	24868	\N	2017-10-31 09:57:27	2018-02-07 16:33:42
28302	MEMBRE	2017-10-24 00:00:00	2018-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	24869	\N	2017-10-31 09:57:27	2018-01-16 18:58:12
28303	MEMBRE	2017-10-24 00:00:00	2018-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	24870	\N	2017-10-31 09:57:27	2018-02-01 18:31:04
28304	MEMBRE	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24871	\N	2017-10-31 09:57:27	\N
28305	MEMBRE	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24872	\N	2017-10-31 09:57:27	\N
28306	MEMBRE	2017-10-24 00:00:00	2018-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	24873	\N	2017-10-31 09:57:27	2018-02-12 09:31:17
28307	MEMBRE	2017-10-24 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24874	\N	2017-10-31 09:57:27	2018-01-24 17:19:16
28308	MEMBRE	2017-10-24 00:00:00	2018-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	24875	\N	2017-10-31 09:57:27	2018-02-14 18:33:26
28309	MEMBRE	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24876	\N	2017-10-31 09:57:27	\N
28310	MEMBRE	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24877	\N	2017-10-31 09:57:27	\N
28311	MEMBRE	2017-10-24 00:00:00	2018-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	24878	\N	2017-10-31 09:57:27	2018-01-16 19:10:51
28312	MEMBRE	2017-10-24 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24879	\N	2017-10-31 09:57:27	2018-01-24 18:09:07
26033	SECRET	2015-03-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	22972	\N	\N	\N
26095	VICPDT	2015-03-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	23002	\N	\N	\N
26100	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23098	\N	\N	2017-09-24 17:14:26
26900	MEMBRE	2016-04-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23608	\N	2016-04-08 15:03:46	\N
27633	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24200	\N	2017-10-17 12:19:06	\N
27634	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24201	\N	2017-10-17 12:19:06	\N
27635	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24202	\N	2017-10-17 12:19:06	\N
27636	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24203	\N	2017-10-17 12:19:06	\N
27637	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24204	\N	2017-10-17 12:19:06	\N
27638	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24205	\N	2017-10-17 12:19:06	\N
27639	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24206	\N	2017-10-17 12:19:06	\N
27640	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24207	\N	2017-10-17 12:19:06	\N
27641	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24208	\N	2017-10-17 12:19:06	\N
27642	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24209	\N	2017-10-17 12:19:06	\N
28693	MEMBRE	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25260	\N	2017-11-15 10:12:25	\N
28694	MEMBRE	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25261	\N	2017-11-15 10:12:25	\N
28695	MEMBRE	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25262	\N	2017-11-15 10:12:25	\N
28696	MEMBRE	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25263	\N	2017-11-15 10:12:25	\N
28856	MEMBRE	2017-11-21 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	25423	\N	2017-11-23 17:46:12	2018-01-18 16:40:29
29352	MEMBRE	2017-12-20 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	25694	\N	2017-12-21 09:52:40	2018-01-25 15:19:51
29353	MEMBRE	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25695	\N	2017-12-21 09:53:08	\N
29356	MEMBRE	2017-12-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25698	\N	2017-12-21 12:27:23	\N
29519	MEMBRE	2017-12-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	25836	\N	\N	\N
30089	MEMBRE	2017-10-01 00:00:00	2018-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	26084	\N	\N	\N
30130	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26085	\N	\N	\N
30131	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26086	\N	\N	\N
30132	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26087	\N	\N	\N
30133	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26088	\N	\N	\N
30134	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26089	\N	\N	\N
30135	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26090	\N	\N	\N
30136	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26091	\N	\N	\N
30140	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26095	\N	\N	\N
30142	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26097	\N	\N	\N
30143	MEMBRE	2017-10-01 00:00:00	2020-06-24 00:00:00	ANCIEN	\N	\N	\N	\N	26098	\N	\N	\N
30144	MEMBRE	2017-10-01 00:00:00	2018-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	26099	\N	\N	\N
30145	MEMBRE	2017-10-01 00:00:00	2018-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	26100	\N	\N	\N
30146	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26101	\N	\N	\N
30147	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26102	\N	\N	\N
30149	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26104	\N	\N	\N
30150	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26105	\N	\N	\N
30151	MEMBRE	2017-10-01 00:00:00	2018-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	26106	\N	\N	\N
30152	MEMBRE	2017-10-01 00:00:00	2018-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	26107	\N	\N	\N
30153	MEMBRE	2017-10-01 00:00:00	2018-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	26108	\N	\N	\N
30154	MEMBRE	2017-10-01 00:00:00	2018-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	26109	\N	\N	\N
30155	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26110	\N	\N	\N
30156	MEMBRE	2017-10-01 00:00:00	2018-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	26111	\N	\N	\N
30157	MEMBRE	2017-10-01 00:00:00	2018-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	26112	\N	\N	\N
30158	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26113	\N	\N	\N
30159	MEMBRE	2017-10-01 00:00:00	2018-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	26114	\N	\N	\N
30160	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26115	\N	\N	\N
30161	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26116	\N	\N	\N
30162	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26117	\N	\N	\N
30163	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26118	\N	\N	\N
30164	MEMBRE	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26119	\N	2018-01-26 09:28:38	\N
30165	MEMBRE	2018-01-24 00:00:00	2018-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	26120	\N	2018-01-26 09:29:43	2018-01-26 17:47:17
30166	MEMBRE	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26121	\N	2018-01-26 09:30:06	\N
30167	MEMBRE	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26122	\N	2018-01-26 09:30:24	\N
30168	MEMBRE	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26123	\N	2018-01-26 09:30:24	\N
30169	MEMBRE	2018-01-17 00:00:00	2020-06-24 00:00:00	ANCIEN	\N	\N	\N	\N	26124	\N	2018-01-26 09:30:42	\N
30170	VICPDT	2018-01-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24168	\N	2018-01-26 09:58:25	\N
30171	VICPDT	2018-01-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24749	\N	2018-01-26 10:01:22	\N
30172	SECRET	2018-01-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25459	\N	2018-01-26 10:01:43	2018-01-26 10:04:57
30173	SECRET	2018-01-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23931	\N	2018-01-26 10:02:13	2018-01-26 10:05:39
30174	VICPDT	2018-01-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24453	\N	2018-01-26 10:02:32	\N
30175	SECRET	2018-01-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24631	\N	2018-01-26 10:07:50	\N
30176	VICPDT	2018-01-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24652	\N	2018-01-26 10:08:11	\N
30177	VICPDT	2018-01-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25328	\N	2018-01-26 10:08:32	\N
30178	VICPDT	2018-01-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24178	\N	2018-01-26 10:08:48	\N
30179	SECRET	2018-01-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24364	\N	2018-01-26 10:09:13	\N
30180	SECRET	2018-01-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25564	\N	2018-01-26 10:09:34	\N
30181	VICPDT	2018-01-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24008	\N	2018-01-26 10:15:32	\N
30182	VICPDT	2018-01-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25225	\N	2018-01-26 10:15:42	\N
30183	VICPDT	2018-01-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25518	\N	2018-01-26 10:15:50	\N
30184	VICPDT	2018-01-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25548	\N	2018-01-26 10:16:12	\N
30185	SECRET	2018-01-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24105	\N	2018-01-26 10:16:26	\N
30186	SECRET	2018-01-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24385	\N	2018-01-26 10:16:39	\N
30187	SECRET	2018-01-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24962	\N	2018-01-26 10:16:46	\N
30188	SECRET	2018-01-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25312	\N	2018-01-26 10:17:08	\N
30189	SECRET	2018-01-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25012	\N	2018-01-26 10:17:14	\N
30190	SECRET	2018-01-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24748	\N	2018-01-26 10:17:20	\N
30191	VICPDT	2018-01-26 00:00:00	2020-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	24627	\N	2018-01-26 10:34:34	\N
30192	VICPDT	2018-01-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24328	\N	2018-01-26 10:34:42	\N
30193	VICPDT	2018-01-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25330	\N	2018-01-26 10:34:50	\N
30194	VICPDT	2018-01-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24638	\N	2018-01-26 10:34:56	\N
30195	VICPDT	2018-01-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24300	\N	2018-01-26 10:35:03	\N
30196	VICPDT	2018-01-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24583	\N	2018-01-26 10:35:13	\N
30197	VICPDT	2018-01-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24941	\N	2018-01-26 10:35:21	\N
30198	SECRET	2018-01-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25259	\N	2018-01-26 10:35:37	\N
30199	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26125	\N	\N	\N
30200	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26126	\N	\N	\N
30201	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26127	\N	\N	\N
30202	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26128	\N	\N	\N
30204	MEMBRE	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26130	\N	2018-01-26 14:49:03	\N
30205	VICPDT	2018-01-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25429	\N	2018-01-26 16:15:25	\N
30206	VICPDT	2018-01-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25354	\N	2018-01-26 16:15:47	\N
30207	VICPDT	2018-01-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23997	\N	2018-01-26 16:16:41	\N
30208	VICPDT	2018-01-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25504	\N	2018-01-26 16:17:18	\N
30209	VICPDT	2018-01-26 00:00:00	2020-09-10 00:00:00	ANCIEN	\N	\N	\N	\N	24685	\N	2018-01-26 16:17:28	\N
30210	VICPDT	2018-01-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25195	\N	2018-01-26 16:17:58	\N
30211	VICPDT	2018-01-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25567	\N	2018-01-26 16:18:11	\N
30212	VICPDT	2018-01-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25018	\N	2018-01-26 16:18:19	\N
30213	SECRET	2018-01-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24964	\N	2018-01-26 16:18:34	\N
30214	SECRET	2018-01-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23880	\N	2018-01-26 16:18:52	\N
30215	SECRET	2018-01-26 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24713	\N	2018-01-26 16:18:59	\N
30216	PDT	2018-01-26 00:00:00	2018-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	25401	\N	2018-01-26 16:28:05	2018-02-01 18:30:26
30217	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26131	\N	\N	\N
30218	MEMBRE	2017-10-01 00:00:00	2018-05-07 00:00:00	ANCIEN	\N	\N	\N	\N	26132	\N	\N	\N
30221	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26135	\N	\N	\N
30222	MEMBRE	2017-10-01 00:00:00	2020-06-24 00:00:00	ANCIEN	\N	\N	\N	\N	26136	\N	\N	\N
30223	MEMBRE	2017-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26137	\N	\N	\N
30224	MEMBRE	2017-10-01 00:00:00	2018-05-07 00:00:00	ANCIEN	\N	\N	\N	\N	26138	\N	\N	\N
30225	MEMBRE	2017-10-01 00:00:00	2018-05-07 00:00:00	ANCIEN	\N	\N	\N	\N	26139	\N	\N	\N
30226	MEMBRE	2017-10-01 00:00:00	2018-05-07 00:00:00	ANCIEN	\N	\N	\N	\N	26140	\N	\N	\N
30227	MEMBRE	2017-10-01 00:00:00	2018-05-07 00:00:00	ANCIEN	\N	\N	\N	\N	26141	\N	\N	\N
30228	MEMBRE	2017-10-01 00:00:00	2018-05-07 00:00:00	ANCIEN	\N	\N	\N	\N	26142	\N	\N	\N
30229	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26143	\N	\N	\N
30230	MEMBRE	2017-10-01 00:00:00	2018-05-07 00:00:00	ANCIEN	\N	\N	\N	\N	26144	\N	\N	\N
30231	PDTDEL	2018-01-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Estonie	\N	26120	\N	2018-01-26 17:47:17	2018-01-26 17:47:28
30232	VICPDT	2018-01-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25358	\N	2018-01-29 10:20:36	\N
23395	MEMBRE	2014-10-28 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	21306	\N	2014-10-28 16:56:46	2015-02-05 18:58:04
23396	MEMBRE	2014-10-28 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21307	\N	2014-10-28 16:56:46	2015-01-06 15:54:24
23397	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21308	\N	2014-10-28 16:56:46	\N
23398	MEMBRE	2014-10-28 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21309	\N	2014-10-28 16:56:46	2015-01-06 15:32:29
23399	MEMBRE	2014-10-28 00:00:00	2015-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	21310	\N	2014-10-28 16:56:46	2015-01-13 17:29:25
23400	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21311	\N	2014-10-28 16:56:46	\N
23401	MEMBRE	2014-10-28 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	21312	\N	2014-10-28 16:56:46	2015-02-13 15:12:41
23402	MEMBRE	2014-10-28 00:00:00	2016-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	21313	\N	2014-10-28 16:56:47	2016-12-07 16:39:03
23403	MEMBRE	2014-10-28 00:00:00	2015-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	21314	\N	2014-10-28 16:56:47	2015-02-06 14:46:03
23404	MEMBRE	2014-10-28 00:00:00	2015-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	21315	\N	2014-10-28 16:56:47	2015-03-11 12:57:20
23405	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21316	\N	2014-10-28 16:56:47	\N
23406	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21317	\N	2014-10-28 16:56:47	\N
23407	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21318	\N	2014-10-28 17:00:33	\N
23408	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21319	\N	2014-10-28 17:00:33	\N
23409	MEMBRE	2014-10-28 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	21320	\N	2014-10-28 17:00:33	2015-02-05 19:00:28
23410	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21321	\N	2014-10-28 17:00:33	\N
23411	MEMBRE	2014-10-28 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	21322	\N	2014-10-28 17:00:33	2015-02-20 10:42:23
23412	MEMBRE	2014-10-28 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	21323	\N	2014-10-28 17:00:33	2015-02-03 16:29:33
23413	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21324	\N	2014-10-28 17:08:58	\N
23414	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21325	\N	2014-10-28 17:08:58	\N
23415	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21326	\N	2014-10-28 17:08:58	\N
23416	MEMBRE	2014-10-27 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21327	\N	2014-10-28 17:09:30	\N
23417	MEMBRE	2014-10-27 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21328	\N	2014-10-28 17:09:30	\N
23418	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21329	\N	2014-10-28 17:10:30	\N
23419	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21330	\N	2014-10-28 17:10:30	\N
23420	MEMBRE	2014-10-22 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	21331	\N	2014-10-28 17:10:30	2015-02-05 18:58:27
23421	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21332	\N	2014-10-28 17:10:30	\N
23422	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21333	\N	2014-10-28 17:10:30	\N
23423	MEMBRE	2014-10-22 00:00:00	2015-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	21334	\N	2014-10-28 17:10:30	2015-01-30 09:39:39
23424	MEMBRE	2014-10-22 00:00:00	2015-04-09 00:00:00	ANCIEN	\N	\N	\N	\N	21335	\N	2014-10-28 17:10:30	2015-04-10 15:10:05
23425	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21336	\N	2014-10-28 17:10:30	\N
23426	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21337	\N	2014-10-28 17:10:59	\N
23427	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21338	\N	2014-10-28 17:10:59	\N
23428	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21339	\N	2014-10-28 17:10:59	\N
23429	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21340	\N	2014-10-28 17:10:59	\N
23430	MEMBRE	2014-10-24 00:00:00	2015-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	21341	\N	2014-10-28 17:11:25	2015-01-28 10:25:46
23431	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21342	\N	2014-10-28 17:11:44	\N
23432	MEMBRE	2014-10-22 00:00:00	2015-03-19 00:00:00	ANCIEN	\N	\N	\N	\N	21343	\N	2014-10-28 17:11:44	2015-03-20 18:13:30
23433	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21344	\N	2014-10-28 17:11:44	\N
23434	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21345	\N	2014-10-28 17:12:10	\N
23435	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21346	\N	2014-10-28 17:12:10	\N
23436	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21347	\N	2014-10-28 17:12:10	\N
23437	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21348	\N	2014-10-28 17:12:10	\N
23438	MEMBRE	2014-10-28 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	21349	\N	2014-10-28 17:12:10	2015-02-20 10:43:42
23439	MEMBRE	2014-10-28 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21350	\N	2014-10-28 17:13:21	2015-01-06 16:26:43
23440	MEMBRE	2014-10-28 00:00:00	2015-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	21351	\N	2014-10-28 17:13:21	2015-03-04 17:15:55
23441	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21352	\N	2014-10-28 17:13:21	\N
23442	MEMBRE	2014-10-28 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	21353	\N	2014-10-28 17:13:21	2015-02-05 12:18:06
24332	MEMBRE	2014-11-19 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	22239	\N	2014-11-19 11:38:20	2016-12-12 16:10:15
24372	MEMBRE	2014-11-18 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22279	\N	2014-11-27 10:15:39	\N
24373	MEMBRE	2014-11-18 00:00:00	2015-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	22280	\N	2014-11-27 10:15:39	2015-04-09 15:21:33
24374	MEMBRE	2014-11-18 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22281	\N	2014-11-27 10:15:39	\N
24375	MEMBRE	2014-11-18 00:00:00	2015-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	22282	\N	2014-11-27 10:15:39	2015-01-19 14:16:22
24376	MEMBRE	2014-11-18 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	22283	\N	2014-11-27 10:15:39	2015-02-20 10:46:49
24377	MEMBRE	2014-11-18 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22284	\N	2014-11-27 10:15:39	\N
24378	MEMBRE	2014-11-25 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22285	\N	2014-11-27 10:16:06	\N
24379	MEMBRE	2014-11-25 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22286	\N	2014-11-27 10:16:06	\N
24380	MEMBRE	2014-11-25 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22287	\N	2014-11-27 10:16:06	\N
24381	MEMBRE	2014-11-25 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	22288	\N	2014-11-27 10:16:06	2015-01-06 16:07:22
25673	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22858	\N	\N	\N
26047	MEMBRE	2015-03-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23074	\N	2015-03-04 16:17:27	2017-09-24 13:42:36
26048	MEMBRE	2015-02-26 00:00:00	2016-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	23075	\N	2015-03-04 16:17:38	2017-01-03 11:09:24
26049	MEMBRE	2015-03-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23076	\N	2015-03-04 16:17:46	\N
26174	MEMBRE	2014-10-01 00:00:00	2017-06-01 00:00:00	ANCIEN	\N	\N	\N	\N	23142	\N	\N	2017-06-02 10:02:57
26659	VICPDT	2015-10-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21173	5	2015-10-07 15:22:44	2015-10-07 15:23:37
26716	PDT	2016-01-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	22821	\N	\N	\N
26727	MEMBRE	2016-02-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23447	\N	2016-02-03 12:40:46	\N
26884	MEMBRE	2016-03-24 00:00:00	2016-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	23598	\N	2016-03-25 10:40:00	2016-03-30 12:01:44
27073	MEMBRE	2014-10-01 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	23765	\N	\N	2017-06-19 16:04:13
27077	MEMBRE	2016-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23769	\N	\N	\N
27078	MEMBRE	2016-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23770	\N	\N	\N
27079	MEMBRE	2016-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23771	\N	\N	\N
27080	MEMBRE	2016-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23772	\N	\N	\N
27177	MEMBRE	2017-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23844	\N	\N	2017-09-24 19:25:10
27190	MEMBRE	2017-04-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23856	\N	2017-04-27 16:00:57	\N
27197	PDT	2017-07-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20595	1	2017-07-17 11:32:43	2017-07-20 14:39:40
27198	MEMBRE	2017-07-17 00:00:00	2017-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	20591	\N	2017-07-17 11:34:11	2017-07-20 11:43:02
27199	PDT	2017-07-17 00:00:00	2017-07-20 00:00:00	ANCIEN	\N	\N	\N	\N	22163	1	2017-07-17 11:34:59	2017-07-20 13:51:06
27200	MEMBRE	2017-07-17 00:00:00	2017-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	20339	\N	2017-07-17 11:46:37	2017-07-20 14:38:34
27985	MEMBRE	2017-10-24 00:00:00	2018-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	24552	\N	2017-10-25 09:51:38	2018-02-01 18:33:21
27986	MEMBRE	2017-10-24 00:00:00	2018-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	24553	\N	2017-10-25 09:51:38	2018-02-05 10:00:15
27987	MEMBRE	2017-10-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24554	\N	2017-10-25 09:51:39	\N
27988	MEMBRE	2017-10-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24555	\N	2017-10-25 09:51:39	\N
27989	MEMBRE	2017-10-20 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	24556	\N	2017-10-25 09:53:02	2018-01-25 15:19:40
27990	MEMBRE	2017-10-20 00:00:00	2018-03-04 00:00:00	ANCIEN	\N	\N	\N	\N	24557	\N	2017-10-25 09:53:02	2018-03-05 17:17:22
27991	MEMBRE	2017-10-20 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	24558	\N	2017-10-25 09:53:02	2018-01-25 17:39:33
27992	MEMBRE	2017-10-20 00:00:00	2017-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	24559	\N	2017-10-25 09:53:02	2017-11-24 16:57:56
27993	MEMBRE	2017-10-20 00:00:00	2018-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	24560	\N	2017-10-25 09:53:02	2018-01-30 14:46:41
27994	MEMBRE	2017-10-20 00:00:00	2018-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	24561	\N	2017-10-25 09:53:02	2018-02-14 18:32:02
27995	MEMBRE	2017-10-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24562	\N	2017-10-25 09:53:02	\N
27996	MEMBRE	2017-10-20 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	24563	\N	2017-10-25 09:53:02	2018-01-18 16:40:47
27997	MEMBRE	2017-10-20 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24564	\N	2017-10-25 09:53:02	2018-01-24 15:53:10
27998	MEMBRE	2017-10-20 00:00:00	2017-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	24565	\N	2017-10-25 09:53:02	2017-11-24 16:57:56
27999	MEMBRE	2017-10-20 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	24566	\N	2017-10-25 09:53:02	2018-02-07 15:30:37
28000	MEMBRE	2017-10-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24567	\N	2017-10-25 09:53:02	\N
28001	MEMBRE	2017-10-20 00:00:00	2018-03-04 00:00:00	ANCIEN	\N	\N	\N	\N	24568	\N	2017-10-25 09:53:02	2018-03-05 18:15:24
28002	MEMBRE	2017-10-20 00:00:00	2017-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	24569	\N	2017-10-25 09:53:02	2017-11-28 16:25:51
28003	MEMBRE	2017-10-20 00:00:00	2018-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	24570	\N	2017-10-25 09:53:02	2018-01-29 17:06:42
26051	MEMBRE	2014-10-01 00:00:00	2015-04-15 00:00:00	ANCIEN	\N	\N	\N	\N	23078	\N	\N	\N
26052	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23079	\N	\N	\N
26063	MEMBRE	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23085	\N	2015-03-04 17:59:48	\N
26520	MEMBRE	2015-06-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23295	\N	2015-06-29 16:52:38	2017-09-24 17:19:42
26599	VICPDT	2015-07-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	22624	\N	\N	\N
26600	SECRET	2015-07-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	23115	\N	\N	\N
27489	MEMBRE	2017-10-11 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24056	\N	2017-10-12 14:55:16	\N
27270	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23874	\N	2017-10-10 09:45:39	\N
27490	MEMBRE	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24057	\N	2017-10-12 14:55:16	\N
27272	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23875	\N	2017-10-10 09:45:39	\N
27491	MEMBRE	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24058	\N	2017-10-12 14:55:16	\N
27492	MEMBRE	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24059	\N	2017-10-12 14:55:16	\N
27493	MEMBRE	2017-10-10 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	24060	\N	2017-10-12 14:56:19	2018-02-07 16:35:41
27494	MEMBRE	2017-10-10 00:00:00	2017-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	24061	\N	2017-10-12 14:56:19	2017-11-28 17:00:01
27527	MEMBRE	2017-10-12 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	24094	\N	2017-10-16 11:06:43	2018-02-07 15:32:19
27528	MEMBRE	2017-10-12 00:00:00	2017-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	24095	\N	2017-10-16 11:06:43	2017-12-19 18:07:34
27529	MEMBRE	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24096	\N	2017-10-16 11:06:43	\N
27530	MEMBRE	2017-10-12 00:00:00	2017-12-05 00:00:00	ANCIEN	\N	\N	\N	\N	24097	\N	2017-10-16 11:06:43	2017-12-06 15:13:39
27531	MEMBRE	2017-10-10 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	24098	\N	2017-10-16 11:32:34	2018-01-18 16:40:37
27532	MEMBRE	2017-10-10 00:00:00	2018-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	24099	\N	2017-10-16 11:32:34	2018-02-08 17:36:00
27533	MEMBRE	2017-10-16 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	24100	\N	2017-10-16 11:35:47	\N
27534	MEMBRE	2017-10-16 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	24101	\N	2017-10-16 11:38:09	\N
27535	MEMBRE	2017-10-13 00:00:00	2018-05-18 00:00:00	ANCIEN	\N	\N	\N	\N	24102	\N	2017-10-16 11:45:43	2018-06-11 17:35:24
27549	MEMBRE	2017-10-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24116	\N	2017-10-17 11:07:57	\N
27711	MEMBRE	2017-10-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24278	\N	2017-10-18 12:15:02	\N
27879	MEMBRE	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24446	\N	2017-10-20 16:37:31	\N
27289	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23876	\N	2017-10-10 09:45:39	\N
27880	MEMBRE	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24447	\N	2017-10-20 16:37:31	\N
27291	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23877	\N	2017-10-10 09:45:39	\N
27881	MEMBRE	2017-10-19 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24448	\N	2017-10-20 16:37:31	2018-01-24 11:14:09
27882	MEMBRE	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24449	\N	2017-10-20 16:37:31	\N
27883	MEMBRE	2017-10-19 00:00:00	2018-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	24450	\N	2017-10-20 16:37:31	2018-01-30 16:03:16
27884	MEMBRE	2017-10-19 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	24451	\N	2017-10-20 16:37:31	2018-01-18 18:10:36
27296	MEMBRE	2017-10-09 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	23878	\N	2017-10-10 09:45:39	2018-01-18 16:41:26
27885	MEMBRE	2017-10-19 00:00:00	2017-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	24452	\N	2017-10-20 16:37:31	2017-12-05 10:01:12
27886	MEMBRE	2017-10-19 00:00:00	2018-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	24453	\N	2017-10-20 16:37:31	2018-01-26 10:02:32
27887	MEMBRE	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24454	\N	2017-10-20 16:38:35	\N
27888	MEMBRE	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24455	\N	2017-10-20 16:38:35	\N
27889	MEMBRE	2017-10-19 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	24456	\N	2017-10-20 16:38:35	2018-01-23 17:26:48
27890	MEMBRE	2017-10-19 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24457	\N	2017-10-20 16:38:35	2018-01-24 17:19:31
27891	MEMBRE	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24458	\N	2017-10-20 16:38:35	\N
27892	MEMBRE	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24459	\N	2017-10-20 16:38:35	\N
27893	MEMBRE	2017-10-18 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	24460	\N	2017-10-20 16:39:07	2018-01-23 18:49:03
27894	MEMBRE	2017-10-18 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	24461	\N	2017-10-20 16:39:07	2018-01-18 17:50:34
27895	MEMBRE	2017-10-18 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	24462	\N	2017-10-20 16:39:07	2018-01-18 16:37:25
27896	MEMBRE	2017-10-18 00:00:00	2018-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	24463	\N	2017-10-20 16:39:07	2018-02-14 18:32:29
27897	MEMBRE	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24464	\N	2017-10-20 16:39:23	\N
27898	MEMBRE	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24465	\N	2017-10-20 16:39:23	\N
27317	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23885	\N	2017-10-10 11:06:29	2017-10-10 12:39:42
27318	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23886	\N	2017-10-10 11:06:29	2017-10-10 12:39:42
27319	MEMBRE	2017-10-10 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	23887	\N	2017-10-10 11:06:29	2017-12-20 12:22:18
27320	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23888	\N	2017-10-10 11:06:29	2017-10-10 12:39:42
27364	MEMBRE	2017-10-10 00:00:00	2018-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	23931	\N	2017-10-10 18:10:30	2018-01-26 10:02:13
27899	MEMBRE	2017-10-12 00:00:00	2019-06-24 00:00:00	ANCIEN	\N	\N	\N	\N	24466	\N	2017-10-20 17:23:17	\N
27900	MEMBRE	2017-10-12 00:00:00	2019-06-24 00:00:00	ANCIEN	\N	\N	\N	\N	24467	\N	2017-10-20 17:23:17	\N
27901	MEMBRE	2017-10-12 00:00:00	2017-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	24468	\N	2017-10-20 17:23:17	2017-11-30 16:46:11
27902	MEMBRE	2017-10-12 00:00:00	2019-06-24 00:00:00	ANCIEN	\N	\N	\N	\N	24469	\N	2017-10-20 17:23:17	\N
27903	MEMBRE	2017-10-12 00:00:00	2019-06-24 00:00:00	ANCIEN	\N	\N	\N	\N	24470	\N	2017-10-20 17:23:17	\N
27904	MEMBRE	2017-10-12 00:00:00	2019-06-24 00:00:00	ANCIEN	\N	\N	\N	\N	24471	\N	2017-10-20 17:23:17	\N
27905	MEMBRE	2017-10-12 00:00:00	2019-06-24 00:00:00	ANCIEN	\N	\N	\N	\N	24472	\N	2017-10-20 17:23:17	\N
27906	MEMBRE	2017-10-19 00:00:00	2020-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	24473	\N	2017-10-20 17:23:42	\N
27907	MEMBRE	2017-10-23 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	24474	\N	2017-10-23 10:01:44	\N
27982	MEMBRE	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24549	\N	2017-10-24 17:45:36	\N
27983	MEMBRE	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24550	\N	2017-10-24 17:45:36	\N
27984	MEMBRE	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24551	\N	2017-10-24 17:45:36	\N
28043	MEMBRE	2017-10-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24610	\N	2017-10-25 17:06:35	\N
28044	MEMBRE	2017-10-24 00:00:00	2018-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	24611	\N	2017-10-25 17:06:35	2018-01-16 18:56:35
28045	MEMBRE	2017-10-24 00:00:00	2018-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	24612	\N	2017-10-25 17:06:35	2018-02-22 10:21:36
28046	MEMBRE	2017-10-24 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	24613	\N	2017-10-25 17:06:35	2018-01-25 10:59:34
28047	MEMBRE	2017-10-24 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24614	\N	2017-10-25 17:07:02	2018-01-24 15:31:15
28048	MEMBRE	2017-10-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24615	\N	2017-10-25 17:07:21	\N
28049	MEMBRE	2017-10-13 00:00:00	2018-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	24616	\N	2017-10-25 17:07:21	2018-01-17 11:29:38
28050	MEMBRE	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24617	\N	2017-10-25 17:07:38	\N
28051	MEMBRE	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24618	\N	2017-10-25 17:07:38	\N
28052	MEMBRE	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24619	\N	2017-10-25 17:07:38	\N
28053	MEMBRE	2017-10-20 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	24620	\N	2017-10-25 17:08:22	2018-01-18 18:22:56
28054	MEMBRE	2017-10-20 00:00:00	2018-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	24621	\N	2017-10-25 17:08:22	2018-02-01 18:31:27
28055	MEMBRE	2017-10-20 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	24622	\N	2017-10-25 17:08:22	2018-01-18 18:09:46
28056	MEMBRE	2017-10-25 00:00:00	2017-12-11 00:00:00	ANCIEN	\N	\N	\N	\N	24623	\N	2017-10-25 17:09:04	2017-12-12 17:29:00
28057	MEMBRE	2017-10-20 00:00:00	2020-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	24624	\N	2017-10-25 17:14:42	\N
28058	MEMBRE	2017-10-20 00:00:00	2018-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	24625	\N	2017-10-25 17:14:42	2018-02-21 15:38:59
28059	MEMBRE	2017-10-20 00:00:00	2020-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	24626	\N	2017-10-25 17:14:42	\N
28060	MEMBRE	2017-10-20 00:00:00	2018-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	24627	\N	2017-10-25 17:14:42	2018-01-26 10:34:34
28061	MEMBRE	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24628	\N	2017-10-25 17:15:09	\N
28062	MEMBRE	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24629	\N	2017-10-25 17:15:30	\N
28063	MEMBRE	2017-10-25 00:00:00	2017-12-11 00:00:00	ANCIEN	\N	\N	\N	\N	24630	\N	2017-10-25 17:15:47	2017-12-12 17:33:59
28064	MEMBRE	2017-10-25 00:00:00	2018-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	24631	\N	2017-10-25 17:15:47	2018-01-26 10:07:50
28065	MEMBRE	2017-10-24 00:00:00	2018-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	24632	\N	2017-10-25 17:16:38	2018-01-29 17:05:48
28066	MEMBRE	2017-10-24 00:00:00	2018-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	24633	\N	2017-10-25 17:16:38	2018-01-16 18:57:36
28067	MEMBRE	2017-10-24 00:00:00	2017-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	24634	\N	2017-10-25 17:17:07	2017-12-19 18:17:41
28068	MEMBRE	2017-10-24 00:00:00	2017-11-09 00:00:00	ANCIEN	\N	\N	\N	\N	24635	\N	2017-10-25 17:17:07	2017-11-10 11:39:17
28069	MEMBRE	2017-10-24 00:00:00	2017-11-09 00:00:00	ANCIEN	\N	\N	\N	\N	24636	\N	2017-10-25 17:17:07	2017-11-10 11:39:17
28070	MEMBRE	2017-10-25 00:00:00	2017-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	24637	\N	2017-10-25 17:20:52	2017-12-14 15:49:59
28071	MEMBRE	2017-10-25 00:00:00	2018-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	24638	\N	2017-10-25 17:20:52	2018-01-26 10:34:56
28072	MEMBRE	2017-10-25 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	24639	\N	2017-10-25 17:20:52	2018-01-25 17:37:24
28073	MEMBRE	2017-10-25 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	24640	\N	2017-10-25 17:20:52	2018-02-07 15:31:34
28074	MEMBRE	2017-10-25 00:00:00	2017-12-05 00:00:00	ANCIEN	\N	\N	\N	\N	24641	\N	2017-10-25 17:20:52	2017-12-06 15:12:17
28075	MEMBRE	2017-10-25 00:00:00	2018-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	24642	\N	2017-10-25 17:20:52	2018-02-01 18:32:08
28125	MEMBRE	2017-10-24 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24692	\N	2017-10-26 15:26:01	2018-01-24 10:52:02
28126	MEMBRE	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24693	\N	2017-10-26 15:26:59	\N
28127	MEMBRE	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24694	\N	2017-10-26 15:27:25	\N
28128	MEMBRE	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24695	\N	2017-10-26 15:27:25	\N
28129	MEMBRE	2017-10-24 00:00:00	2018-12-30 00:00:00	ANCIEN	\N	\N	\N	\N	24696	\N	2017-10-26 15:27:51	\N
28214	MEMBRE	2017-10-06 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	24781	\N	2017-10-27 11:28:12	2018-02-07 16:35:50
28215	MEMBRE	2017-10-06 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24782	\N	2017-10-27 11:28:12	2018-01-24 17:09:30
24649	PDT	2015-01-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22400	1	2015-01-16 16:44:29	2015-01-16 16:44:36
25627	MEMBRE	2015-02-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22833	\N	2015-02-17 17:36:11	\N
25664	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22849	\N	\N	2017-09-24 17:48:21
25668	MEMBRE	2014-10-01 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	22853	\N	\N	2017-05-16 15:18:14
25669	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22854	\N	\N	\N
25672	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22857	\N	\N	\N
26054	MEMBRE	2015-03-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23081	\N	2015-03-04 17:13:49	\N
26057	VICPDT	2015-03-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20664	2	2015-03-04 17:15:42	2017-09-24 17:42:26
26058	VICPDT	2015-03-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20314	3	2015-03-04 17:15:48	2017-09-24 18:59:59
26059	VICPDT	2015-03-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21351	4	2015-03-04 17:15:55	2017-09-24 13:29:42
26060	SECRET	2015-03-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21801	5	2015-03-04 17:16:03	2017-09-24 17:47:28
26061	SECRET	2015-03-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22412	6	2015-03-04 17:16:08	2015-03-04 17:16:28
26297	VICPDT	2015-04-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23042	\N	\N	2017-09-24 17:09:24
26298	MEMBRE	2014-09-01 00:00:00	2015-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	23181	\N	2015-04-01 16:21:09	\N
26661	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23399	\N	\N	\N
26908	MEMBRE	2016-05-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20545	\N	2016-05-10 17:47:19	2017-09-24 17:35:15
26914	MEMBRE	2016-05-26 00:00:00	2017-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	23620	\N	\N	2017-07-24 09:56:26
27062	MEMBRE	2016-09-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23754	\N	2016-09-28 16:59:50	\N
27156	SECRET	2014-10-01 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	23257	\N	\N	2017-06-19 16:06:01
27321	MEMBRE	2017-10-10 00:00:00	2018-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	23889	\N	2017-10-10 17:20:55	2018-02-12 10:01:00
27322	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23890	\N	2017-10-10 17:22:57	\N
27323	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23891	\N	2017-10-10 17:23:20	\N
27324	MEMBRE	2017-10-09 00:00:00	2018-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	23892	\N	2017-10-10 17:23:39	2018-02-14 18:32:18
27325	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23893	\N	2017-10-10 17:24:00	\N
27326	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23894	\N	2017-10-10 17:24:23	\N
27327	MEMBRE	2017-10-09 00:00:00	2017-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	23895	\N	2017-10-10 17:24:46	2017-12-19 17:55:14
27328	MEMBRE	2017-10-09 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	23896	\N	2017-10-10 17:25:20	2018-01-18 16:37:03
27329	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23897	\N	2017-10-10 17:25:38	2017-10-10 17:25:58
27330	MEMBRE	2017-10-10 00:00:00	2017-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	23898	\N	2017-10-10 17:26:20	2017-10-18 15:49:23
27331	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23899	\N	2017-10-10 17:27:01	\N
27332	MEMBRE	2017-10-10 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	23900	\N	2017-10-10 17:27:25	2018-01-24 15:54:52
27333	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23901	\N	2017-10-10 17:27:42	\N
27334	MEMBRE	2017-10-09 00:00:00	2018-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	23902	\N	2017-10-10 17:28:11	2018-01-16 19:11:20
27335	MEMBRE	2017-10-09 00:00:00	2017-12-11 00:00:00	ANCIEN	\N	\N	\N	\N	23903	\N	2017-10-10 17:29:21	2017-12-12 17:33:06
27336	MEMBRE	2017-10-09 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	23904	\N	2017-10-10 17:29:49	2018-01-23 18:49:16
27337	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23905	\N	2017-10-10 17:30:18	\N
27338	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23906	\N	2017-10-10 17:30:41	\N
27339	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23907	\N	2017-10-10 17:30:52	\N
27340	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23908	\N	2017-10-10 17:31:00	\N
27341	MEMBRE	2017-10-09 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	23909	\N	2017-10-10 17:31:07	2018-01-18 17:52:19
27342	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23910	\N	2017-10-10 17:31:15	\N
27343	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23911	\N	2017-10-10 17:31:23	\N
27344	MEMBRE	2017-10-09 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	23912	\N	2017-10-10 17:31:33	2018-01-25 15:55:22
27345	MEMBRE	2017-10-09 00:00:00	2017-12-11 00:00:00	ANCIEN	\N	\N	\N	\N	23913	\N	2017-10-10 17:31:44	2017-12-12 17:24:00
27346	MEMBRE	2017-10-09 00:00:00	2018-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	23914	\N	2017-10-10 17:31:54	2018-01-19 10:24:32
27347	MEMBRE	2017-10-09 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	23915	\N	2017-10-10 17:32:02	2017-12-20 16:57:33
27348	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23916	\N	2017-10-10 17:32:13	\N
27349	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23917	\N	2017-10-10 17:32:24	\N
27350	MEMBRE	2017-10-09 00:00:00	2018-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	23918	\N	2017-10-10 17:32:31	2018-02-08 16:43:19
27351	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23919	\N	2017-10-10 17:32:42	\N
27352	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23920	\N	2017-10-10 17:32:51	\N
27353	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23921	\N	2017-10-10 17:33:01	\N
27360	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23925	\N	2017-10-10 17:39:16	\N
28313	MEMBRE	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24880	\N	2017-10-31 09:57:27	\N
27356	MEMBRE	2017-10-10 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	23924	\N	2017-10-10 17:33:42	2017-12-20 16:56:57
27357	MEMBRE	2017-10-10 00:00:00	2018-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	23925	\N	2017-10-10 17:33:49	2018-01-30 16:01:29
27358	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23926	\N	2017-10-10 17:33:58	\N
27359	MEMBRE	2017-10-10 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	23927	\N	2017-10-10 17:34:07	2018-02-07 15:31:03
27361	MEMBRE	2017-10-10 00:00:00	2017-12-26 00:00:00	ANCIEN	\N	\N	\N	\N	23928	\N	2017-10-10 17:39:28	2017-12-27 11:11:26
27363	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23930	\N	2017-10-10 17:40:57	\N
28314	MEMBRE	2017-10-26 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	24881	\N	2017-10-31 09:57:45	2018-01-25 17:38:18
28464	MEMBRE	2017-11-02 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25031	\N	2017-11-02 17:48:50	\N
28465	MEMBRE	2017-11-02 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25032	\N	2017-11-02 17:48:50	\N
28498	MEMBRE	2017-10-25 00:00:00	2023-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	25065	\N	2017-11-03 14:04:15	\N
28499	MEMBRE	2017-10-25 00:00:00	2020-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	25066	\N	2017-11-03 14:08:12	\N
28500	MEMBRE	2017-10-20 00:00:00	2020-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	25067	\N	2017-11-03 14:09:30	\N
28552	MEMBRE	2017-11-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25119	\N	2017-11-08 09:24:21	\N
28553	MEMBRE	2017-11-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25120	\N	2017-11-08 09:24:21	\N
28554	MEMBRE	2017-11-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25121	\N	2017-11-08 09:24:21	\N
28555	MEMBRE	2017-11-07 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	25122	\N	2017-11-08 09:24:21	2017-12-20 12:21:48
28556	MEMBRE	2017-11-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25123	\N	2017-11-08 09:43:13	\N
28557	MEMBRE	2017-11-07 00:00:00	2018-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	25124	\N	2017-11-08 09:43:13	2018-01-30 16:03:11
28558	MEMBRE	2017-11-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25125	\N	2017-11-08 09:43:13	\N
28559	MEMBRE	2017-10-29 00:00:00	2017-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	25126	\N	2017-11-08 11:36:52	2017-12-05 09:59:44
28896	MEMBRE	2017-11-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25463	\N	2017-11-27 09:41:08	\N
28897	MEMBRE	2017-11-17 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	25464	\N	2017-11-27 09:41:08	2018-02-07 15:30:01
28965	MEMBRE	2017-11-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25498	\N	2017-11-30 09:48:11	\N
28966	MEMBRE	2017-11-29 00:00:00	2018-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	25499	\N	2017-11-30 09:48:46	2018-01-16 18:57:57
28967	MEMBRE	2017-11-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25500	\N	2017-11-30 09:50:48	\N
28968	MEMBRE	2017-11-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25501	\N	2017-11-30 09:51:02	\N
28969	MEMBRE	2017-11-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25502	\N	2017-11-30 09:51:49	\N
28970	MEMBRE	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25503	\N	2017-11-30 09:52:56	\N
28971	MEMBRE	2017-11-30 00:00:00	2018-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	25504	\N	2017-11-30 09:52:56	2018-01-26 16:17:18
28972	MEMBRE	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25505	\N	2017-11-30 09:53:57	\N
28973	MEMBRE	2017-11-28 00:00:00	2017-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	25506	\N	2017-11-30 09:54:13	2017-11-30 17:31:48
28974	MEMBRE	2017-11-28 00:00:00	2017-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	25507	\N	2017-11-30 09:54:13	2017-11-30 16:42:13
29080	MEMBRE	2017-11-30 00:00:00	2018-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	25548	\N	2017-12-06 11:35:18	2018-01-26 10:16:13
29081	MEMBRE	2017-12-05 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	25549	\N	2017-12-06 11:35:50	2018-01-25 15:55:08
29082	MEMBRE	2017-11-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25550	\N	2017-12-06 11:40:03	\N
29083	MEMBRE	2017-11-29 00:00:00	2017-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	25551	\N	2017-12-06 11:40:03	2017-12-06 11:43:46
29084	MEMBRE	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25552	\N	2017-12-06 11:40:52	\N
29085	MEMBRE	2017-12-05 00:00:00	2018-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	25553	\N	2017-12-06 11:52:22	2018-02-08 14:36:50
29183	MEMBRE	2017-12-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25612	\N	2017-12-12 17:43:32	\N
29184	MEMBRE	2017-12-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25613	\N	2017-12-12 18:25:37	\N
29600	MEMBRE	2017-10-01 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	25861	\N	\N	\N
29605	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25866	\N	\N	\N
29607	MEMBRE	2017-10-01 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	25868	\N	\N	\N
29609	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25870	\N	\N	\N
29610	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25871	\N	\N	\N
29611	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25872	\N	\N	\N
29612	MEMBRE	2017-10-01 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	25873	\N	\N	\N
29613	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25874	\N	\N	\N
29614	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25875	\N	\N	\N
29615	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25876	\N	\N	\N
29616	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25877	\N	\N	\N
29617	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25878	\N	\N	\N
26078	VICPDT	2015-03-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22957	\N	\N	2017-09-24 17:35:15
26083	VICPDT	2015-03-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	23031	\N	\N	\N
26085	VICPDT	2015-03-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	23035	\N	\N	\N
26717	PDT	2016-01-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	22993	\N	\N	\N
27170	MEMBRE	2017-02-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23837	\N	2017-02-08 10:56:07	2017-09-24 19:25:10
27171	MEMBRE	2017-02-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23838	\N	2017-02-08 10:56:07	2017-09-24 19:25:10
27172	MEMBRE	2017-02-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23839	\N	2017-02-08 10:56:08	2017-09-24 19:25:10
27173	MEMBRE	2017-02-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23840	\N	2017-02-08 10:56:08	2017-09-24 19:25:10
27174	MEMBRE	2017-02-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23841	\N	2017-02-08 10:56:08	2017-09-24 19:25:10
27175	MEMBRE	2017-02-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23842	\N	2017-02-08 10:56:08	2017-09-24 19:25:10
27176	MEMBRE	2017-02-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23843	\N	2017-02-08 10:56:08	2017-09-24 19:25:10
28679	MEMBRE	2017-11-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25246	\N	2017-11-14 11:26:11	\N
28680	MEMBRE	2017-10-25 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	25247	\N	2017-11-14 11:26:41	2018-01-25 17:40:20
28681	MEMBRE	2017-10-25 00:00:00	2018-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	25248	\N	2017-11-14 11:26:41	2018-01-29 17:07:08
28682	MEMBRE	2017-10-25 00:00:00	2017-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	25249	\N	2017-11-14 11:26:41	2017-12-15 10:46:18
28810	MEMBRE	2017-11-20 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	25377	\N	2017-11-22 09:53:43	2017-12-20 16:58:03
28811	MEMBRE	2017-11-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25378	\N	2017-11-22 09:57:39	\N
28812	MEMBRE	2017-11-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25379	\N	2017-11-22 09:57:56	\N
28813	MEMBRE	2017-11-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25380	\N	2017-11-22 09:57:56	\N
28814	MEMBRE	2017-11-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25381	\N	2017-11-22 16:03:43	\N
28815	MEMBRE	2017-11-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25382	\N	2017-11-22 16:04:27	\N
28816	MEMBRE	2017-11-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25383	\N	2017-11-22 16:04:27	\N
28817	MEMBRE	2017-11-21 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	25384	\N	2017-11-22 16:05:05	2018-01-23 17:48:57
28818	MEMBRE	2017-11-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25385	\N	2017-11-22 16:05:23	\N
28819	MEMBRE	2017-11-21 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25386	\N	2017-11-22 16:05:43	\N
28820	MEMBRE	2017-11-22 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25387	\N	2017-11-22 16:06:12	\N
28821	MEMBRE	2017-11-20 00:00:00	2017-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	25388	\N	2017-11-22 16:06:45	2017-11-28 16:30:48
28822	MEMBRE	2017-11-22 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25389	\N	2017-11-22 16:08:22	\N
28823	MEMBRE	2017-11-22 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25390	\N	2017-11-22 16:08:22	\N
28824	MEMBRE	2017-11-22 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25391	\N	2017-11-22 16:08:22	\N
28825	MEMBRE	2017-11-21 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25392	\N	2017-11-22 16:09:08	\N
28826	MEMBRE	2017-11-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25393	\N	2017-11-22 17:15:39	\N
28827	MEMBRE	2017-11-22 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	25394	\N	2017-11-22 17:37:19	2017-12-20 17:59:43
28828	MEMBRE	2017-11-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25395	\N	2017-11-22 17:37:35	\N
28829	MEMBRE	2017-11-21 00:00:00	2018-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	25396	\N	2017-11-22 17:37:50	2018-01-30 14:46:51
29820	VICPDT	2018-01-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	25719	\N	\N	\N
29824	VICPDT	2018-01-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25715	\N	\N	\N
29988	MEMBRE	2018-01-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26036	\N	2018-01-24 16:35:32	\N
29989	MEMBRE	2018-01-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26037	\N	2018-01-24 16:35:32	\N
29990	PDTHON	2018-01-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24782	\N	2018-01-24 17:09:30	\N
29991	VICPDT	2018-01-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24547	\N	2018-01-24 17:09:53	\N
29992	VICPDT	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25139	\N	2018-01-24 17:10:04	\N
29993	VICPDT	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25116	\N	2018-01-24 17:10:18	\N
29994	SECRET	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24977	\N	2018-01-24 17:10:30	\N
29995	SECRET	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24578	\N	2018-01-24 17:10:37	\N
29996	SECRET	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24025	\N	2018-01-24 17:10:44	\N
29997	SECRET	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23884	\N	2018-01-24 17:10:50	\N
29998	SECRET	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25198	\N	2018-01-24 17:10:59	\N
29999	VICPDT	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24332	\N	2018-01-24 17:19:07	\N
30000	VICPDT	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24874	\N	2018-01-24 17:19:16	\N
30001	SECRET	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24457	\N	2018-01-24 17:19:31	\N
30002	VICPDT	2018-01-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24660	\N	2018-01-24 17:29:57	\N
30003	VICPDT	2018-01-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24319	\N	2018-01-24 17:30:07	\N
30004	VICPDT	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25403	\N	2018-01-24 17:30:20	\N
30005	VICPDT	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24365	\N	2018-01-24 17:30:27	\N
30006	VICPDT	2018-01-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24063	\N	2018-01-24 17:30:34	\N
30007	SECRET	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24743	\N	2018-01-24 17:30:39	\N
30008	MEMBRE	2018-01-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26038	\N	2018-01-24 17:38:18	\N
30009	VICPDT	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25093	\N	2018-01-24 18:06:24	\N
30010	VICPDT	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24443	\N	2018-01-24 18:06:38	\N
30011	VICPDT	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24491	\N	2018-01-24 18:06:47	\N
30012	SECRET	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24755	\N	2018-01-24 18:06:54	\N
30013	VICPDT	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25070	\N	2018-01-24 18:07:06	\N
30014	SECRET	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24711	\N	2018-01-24 18:07:51	\N
30015	VICPDT	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24934	\N	2018-01-24 18:08:16	\N
30016	SECRET	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24224	\N	2018-01-24 18:08:28	\N
30017	VICPDT	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24370	\N	2018-01-24 18:08:46	\N
30018	SECRET	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24942	\N	2018-01-24 18:08:53	\N
30019	SECRET	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24879	\N	2018-01-24 18:09:07	\N
30020	SECRET	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24176	\N	2018-01-24 18:09:22	\N
30021	VICPDT	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25680	\N	2018-01-24 18:29:29	\N
30022	VICPDT	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24745	\N	2018-01-24 18:29:47	\N
30023	VICPDT	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24435	\N	2018-01-24 18:30:00	\N
30024	VICPDT	2018-01-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23949	\N	2018-01-24 18:30:11	\N
30025	VICPDT	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25194	\N	2018-01-24 18:30:22	\N
30026	VICPDT	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24417	\N	2018-01-24 18:30:40	\N
30027	VICPDT	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24940	\N	2018-01-24 18:31:17	\N
30028	VICPDT	2018-01-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25043	\N	2018-01-24 18:31:26	\N
30029	VICPDT	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25035	\N	2018-01-24 18:31:37	\N
30030	SECRET	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25143	\N	2018-01-24 18:31:47	\N
30031	SECRET	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23992	\N	2018-01-24 18:32:43	\N
30148	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26103	\N	\N	\N
30233	VICPDT	2018-01-29 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	24505	\N	2018-01-29 10:20:48	\N
30234	VICPDT	2018-01-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25005	\N	2018-01-29 10:21:15	\N
30235	VICPDT	2018-01-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25174	\N	2018-01-29 10:21:25	\N
30236	MEMBRE	2017-10-01 00:00:00	2018-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	26145	\N	\N	\N
30238	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26147	\N	\N	\N
30239	MEMBRE	2017-10-01 00:00:00	2020-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	26148	\N	\N	\N
30240	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26149	\N	\N	\N
30241	MEMBRE	2018-01-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26150	\N	2018-01-29 15:17:33	\N
30242	VICPDT	2018-01-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24318	\N	2018-01-29 16:17:05	\N
30243	VICPDT	2018-01-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24676	\N	2018-01-29 16:17:11	\N
30244	VICPDT	2018-01-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24180	\N	2018-01-29 16:17:21	\N
30245	VICPDT	2018-01-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24744	\N	2018-01-29 16:17:26	\N
30246	SECRET	2018-01-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25351	\N	2018-01-29 16:17:38	\N
30247	SECRET	2018-01-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25269	\N	2018-01-29 16:17:43	\N
30248	SECRET	2018-01-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25205	\N	2018-01-29 16:17:54	2018-01-29 16:18:30
30249	SECRET	2018-01-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24632	\N	2018-01-29 17:05:48	\N
30250	VICPDT	2018-01-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24830	\N	2018-01-29 17:06:18	\N
30251	VICPDT	2018-01-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24055	\N	2018-01-29 17:06:32	\N
30252	VICPDT	2018-01-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24570	\N	2018-01-29 17:06:42	\N
30253	VICPDT	2018-01-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24929	\N	2018-01-29 17:06:57	\N
30254	VICPDT	2018-01-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24199	\N	2018-01-29 17:07:02	\N
30255	VICPDT	2018-01-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25248	\N	2018-01-29 17:07:08	\N
23048	MEMBRE	2014-10-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20992	\N	2014-10-23 15:50:24	\N
23049	MEMBRE	2014-10-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20993	\N	2014-10-23 15:50:24	\N
23050	MEMBRE	2014-10-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20994	\N	2014-10-23 15:50:24	\N
23051	MEMBRE	2014-10-17 00:00:00	2015-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	20995	\N	2014-10-23 15:50:24	2015-03-11 10:58:21
23052	MEMBRE	2014-10-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20996	\N	2014-10-23 15:50:24	\N
23053	MEMBRE	2014-10-22 00:00:00	2015-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	20997	\N	2014-10-23 16:06:18	2015-03-06 09:53:23
23054	MEMBRE	2014-10-22 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	20998	\N	2014-10-23 16:06:18	2015-02-05 18:55:34
23055	MEMBRE	2014-10-22 00:00:00	2015-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	20999	\N	2014-10-23 16:06:19	2015-02-06 14:47:22
23056	MEMBRE	2014-10-22 00:00:00	2015-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	21000	\N	2014-10-23 16:06:19	2015-03-02 11:07:38
23057	MEMBRE	2014-10-22 00:00:00	2015-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	21001	\N	2014-10-23 16:06:19	2015-01-30 15:55:22
23058	MEMBRE	2014-10-22 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21002	\N	2014-10-23 16:06:19	2015-01-06 15:51:36
23059	MEMBRE	2014-10-22 00:00:00	2015-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	21003	\N	2014-10-23 16:06:19	2015-02-09 11:03:34
23060	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21004	\N	2014-10-23 16:06:19	\N
23061	MEMBRE	2014-10-22 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	21005	\N	2014-10-23 16:06:19	2015-02-13 11:35:04
23062	MEMBRE	2014-10-22 00:00:00	2016-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	21006	\N	2014-10-23 16:06:19	2016-12-07 16:39:48
23063	MEMBRE	2014-10-22 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	21007	\N	2014-10-23 16:06:19	2015-02-02 13:09:18
23064	MEMBRE	2014-10-22 00:00:00	2015-03-09 00:00:00	ANCIEN	\N	\N	\N	\N	21008	\N	2014-10-23 16:06:19	2015-03-10 10:01:38
23065	MEMBRE	2014-10-22 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	21009	\N	2014-10-23 16:06:19	2015-02-20 10:43:06
23066	MEMBRE	2014-10-22 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21010	\N	2014-10-23 16:06:19	2015-01-06 16:21:58
23067	MEMBRE	2014-10-22 00:00:00	2015-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	21011	\N	2014-10-23 16:06:19	2015-01-19 14:17:01
23068	MEMBRE	2014-10-22 00:00:00	2015-01-21 00:00:00	ANCIEN	\N	\N	\N	\N	21012	\N	2014-10-23 16:06:19	2015-01-22 10:50:30
23069	MEMBRE	2014-10-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21013	\N	2014-10-23 16:14:52	\N
23070	MEMBRE	2014-10-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21014	\N	2014-10-23 16:14:52	\N
23071	MEMBRE	2014-10-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21015	\N	2014-10-23 16:14:52	\N
23072	MEMBRE	2014-10-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21016	\N	2014-10-23 16:14:52	\N
23629	MEMBRE	2014-10-22 00:00:00	2015-03-19 00:00:00	ANCIEN	\N	\N	\N	\N	21540	\N	2014-10-29 18:51:15	2015-03-20 09:53:39
23630	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21541	\N	2014-10-29 18:51:15	\N
23631	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21542	\N	2014-10-29 18:51:15	\N
23632	MEMBRE	2014-10-22 00:00:00	2016-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	21543	\N	2014-10-29 18:51:15	2016-02-09 14:23:28
23633	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21544	\N	2014-10-29 18:51:37	\N
23634	MEMBRE	2014-10-29 00:00:00	2016-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	21545	\N	2014-10-29 18:51:37	2016-12-07 16:41:32
23635	MEMBRE	2014-10-29 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	21546	\N	2014-10-29 18:51:37	2015-02-05 18:56:11
23636	MEMBRE	2014-10-29 00:00:00	2015-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	21547	\N	2014-10-29 18:51:37	2015-01-14 14:31:05
23637	MEMBRE	2014-10-29 00:00:00	2015-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	21548	\N	2014-10-29 18:51:37	2015-03-11 11:00:26
23638	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21549	\N	2014-10-29 18:51:37	\N
24023	MEMBRE	2014-10-27 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21934	\N	2014-10-31 15:50:21	\N
24024	MEMBRE	2014-10-27 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21935	\N	2014-10-31 15:50:21	\N
24025	MEMBRE	2014-10-27 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21936	\N	2014-10-31 15:50:21	\N
24026	MEMBRE	2014-10-30 00:00:00	2015-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	21937	\N	2014-10-31 15:50:51	2015-03-11 11:04:30
24027	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21938	\N	2014-10-31 15:50:51	\N
24028	MEMBRE	2014-10-30 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	21939	\N	2014-10-31 15:52:08	2015-02-19 17:23:02
24029	MEMBRE	2014-10-30 00:00:00	2015-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	21940	\N	2014-10-31 15:52:08	2015-01-28 10:26:42
24030	MEMBRE	2014-10-30 00:00:00	2015-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	21941	\N	2014-10-31 15:52:08	2015-02-12 17:36:05
24031	MEMBRE	2014-10-30 00:00:00	2015-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	21942	\N	2014-10-31 15:52:08	2015-03-02 15:18:23
24032	MEMBRE	2014-10-30 00:00:00	2015-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	21943	\N	2014-10-31 15:52:08	2015-01-19 14:16:51
24033	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21944	\N	2014-10-31 15:52:08	\N
24034	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21945	\N	2014-10-31 15:52:08	\N
24035	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21946	\N	2014-10-31 15:52:08	\N
24036	MEMBRE	2014-10-30 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21947	\N	2014-10-31 15:52:08	2015-01-06 16:09:00
24037	MEMBRE	2014-10-30 00:00:00	2015-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	21948	\N	2014-10-31 15:52:08	2015-01-28 09:42:07
24038	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21949	\N	2014-10-31 15:52:08	\N
24039	MEMBRE	2014-10-30 00:00:00	2015-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	21950	\N	2014-10-31 15:52:08	2015-02-06 14:46:44
24040	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21951	\N	2014-10-31 15:52:09	\N
24041	MEMBRE	2014-10-30 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	21952	\N	2014-10-31 15:52:09	2015-02-13 17:04:04
24042	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21953	\N	2014-10-31 15:52:09	\N
24043	MEMBRE	2014-10-30 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	21954	\N	2014-10-31 15:52:09	2015-02-13 10:34:24
24044	MEMBRE	2014-10-30 00:00:00	2015-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	21955	\N	2014-10-31 15:52:09	2015-02-12 12:45:41
24045	MEMBRE	2014-10-30 00:00:00	2015-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	21956	\N	2014-10-31 15:52:09	2015-02-04 18:16:53
24046	MEMBRE	2014-10-30 00:00:00	2015-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	21957	\N	2014-10-31 15:52:09	2015-03-02 11:07:31
24047	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21958	\N	2014-10-31 15:52:09	\N
24048	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21959	\N	2014-10-31 15:52:09	\N
24049	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21960	\N	2014-10-31 15:52:09	\N
24050	MEMBRE	2014-10-30 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	21961	\N	2014-10-31 15:52:09	2015-02-02 13:09:03
24051	MEMBRE	2014-10-30 00:00:00	2015-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	21962	\N	2014-10-31 15:52:09	2015-02-06 16:58:27
24052	MEMBRE	2014-10-30 00:00:00	2015-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	21963	\N	2014-10-31 15:52:09	2015-02-09 15:47:22
24053	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21964	\N	2014-10-31 15:52:57	\N
24054	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21965	\N	2014-10-31 15:52:57	\N
24055	MEMBRE	2014-10-30 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21966	\N	2014-10-31 15:52:57	2015-01-06 17:52:09
24056	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21967	\N	2014-10-31 15:52:57	\N
24057	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21968	\N	2014-10-31 15:52:57	\N
24058	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21969	\N	2014-10-31 15:52:57	\N
24059	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21970	\N	2014-10-31 15:52:57	\N
24060	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21971	\N	2014-10-31 15:52:57	\N
24061	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21972	\N	2014-10-31 15:52:57	\N
24062	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21973	\N	2014-10-31 15:52:57	\N
24063	MEMBRE	2014-10-30 00:00:00	2015-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	21974	\N	2014-10-31 15:52:57	2015-02-04 18:17:09
24064	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21975	\N	2014-10-31 15:55:26	\N
24065	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21976	\N	2014-10-31 15:55:53	\N
24382	MEMBRE	2014-11-27 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	22289	\N	2014-11-28 10:00:01	2015-02-19 18:04:07
24383	MEMBRE	2014-11-25 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22290	\N	2014-11-28 10:00:13	\N
24384	MEMBRE	2014-11-27 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22291	\N	2014-11-28 12:45:16	\N
24404	MEMBRE	2014-10-27 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22311	\N	2014-12-04 10:15:26	\N
24405	MEMBRE	2014-10-27 00:00:00	2015-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	22312	\N	2014-12-04 10:15:26	2015-02-06 16:56:15
24756	MEMBRE	2015-01-26 00:00:00	2015-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	22461	\N	2015-01-27 14:59:59	2015-01-29 19:00:28
24922	VICPDT	2015-02-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20612	2	2015-02-03 16:27:31	2015-02-03 16:28:52
24923	VICPDT	2015-02-03 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	21747	3	2015-02-03 16:27:40	2015-10-13 14:18:39
24924	VICPDT	2015-02-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20373	5	2015-02-03 16:27:52	2015-02-03 16:29:02
24925	VICPDT	2015-02-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20745	4	2015-02-03 16:28:01	2015-02-03 16:28:59
24926	VICPDT	2015-02-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20949	6	2015-02-03 16:28:15	2015-02-03 16:29:06
24927	VICPDT	2015-02-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20825	7	2015-02-03 16:28:23	2015-02-03 16:29:08
24928	VICPDT	2015-02-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21392	8	2015-02-03 16:28:34	2015-02-03 16:29:13
24929	VICPDT	2015-02-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21595	9	2015-02-03 16:28:41	2015-02-03 16:29:18
24930	SECRET	2015-02-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22109	10	2015-02-03 16:29:29	2015-02-03 16:30:23
24931	SECRET	2015-02-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21323	11	2015-02-03 16:29:33	2015-02-03 16:30:26
24932	SECRET	2015-02-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22077	12	2015-02-03 16:29:44	2015-02-03 16:30:33
24933	SECRET	2015-02-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21482	13	2015-02-03 16:30:00	2015-02-03 16:30:38
24948	PDTHON	2015-02-04 00:00:00	2017-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	20641	2	2015-02-04 14:26:44	2017-07-24 09:56:26
26076	VICPDT	2015-03-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22905	\N	\N	2017-09-24 18:20:10
26378	MEMBRE	2015-03-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	23224	\N	\N	\N
26387	MEMBRE	2015-03-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	23233	\N	\N	\N
26390	MEMBRE	2015-03-02 00:00:00	2015-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	23236	\N	\N	\N
26682	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23415	\N	\N	\N
26702	MEMBRE	2015-11-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23430	\N	2015-11-26 16:55:52	\N
26892	VICPDTPRE	2016-03-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22147	\N	2016-03-31 15:50:35	2017-09-24 17:47:27
26893	MEMBRE	2016-03-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20357	\N	2016-03-31 15:51:47	\N
24273	MEMBRE	2014-11-12 00:00:00	2016-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	22184	\N	2014-11-12 17:38:29	2016-12-01 10:36:51
27452	MEMBRE	2017-10-11 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	24019	\N	2017-10-12 09:52:52	\N
27453	MEMBRE	2017-10-11 00:00:00	2017-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	24020	\N	2017-10-12 09:52:52	2017-11-30 16:40:44
27454	MEMBRE	2017-10-11 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	24021	\N	2017-10-12 09:52:52	\N
27455	MEMBRE	2017-10-11 00:00:00	2018-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	24022	\N	2017-10-12 09:52:52	2018-02-21 15:39:28
27456	MEMBRE	2017-10-11 00:00:00	2017-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	24023	\N	2017-10-12 09:52:52	2017-11-28 17:03:15
28216	MEMBRE	2017-10-27 00:00:00	2018-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	24783	\N	2017-10-27 14:41:06	2018-01-30 12:29:40
28217	MEMBRE	2017-10-27 00:00:00	2018-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	24784	\N	2017-10-27 14:41:06	2018-02-01 18:32:16
28218	MEMBRE	2017-10-27 00:00:00	2017-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	24785	\N	2017-10-27 14:41:06	2017-12-14 15:50:08
28219	MEMBRE	2017-10-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24786	\N	2017-10-27 14:41:06	\N
28220	MEMBRE	2017-10-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24787	\N	2017-10-27 14:41:07	\N
28221	MEMBRE	2017-10-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24788	\N	2017-10-27 14:41:07	\N
28222	MEMBRE	2017-10-27 00:00:00	2017-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	24789	\N	2017-10-27 14:41:07	2017-12-14 18:31:33
28223	MEMBRE	2017-10-27 00:00:00	2017-12-05 00:00:00	ANCIEN	\N	\N	\N	\N	24790	\N	2017-10-27 14:41:07	2017-12-06 15:14:25
28224	MEMBRE	2017-10-27 00:00:00	2018-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	24791	\N	2017-10-27 14:41:07	2018-02-12 10:01:09
28225	MEMBRE	2017-10-27 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	24792	\N	2017-10-27 14:41:07	2018-01-18 18:10:43
28274	MEMBRE	2017-10-27 00:00:00	2017-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	24841	\N	2017-10-30 11:49:02	2017-12-19 17:55:37
28275	MEMBRE	2017-10-27 00:00:00	2018-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	24842	\N	2017-10-30 11:49:02	2018-01-16 19:06:52
28276	MEMBRE	2017-10-27 00:00:00	2018-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	24843	\N	2017-10-30 11:49:02	2018-01-17 11:30:02
28277	MEMBRE	2017-10-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24844	\N	2017-10-30 11:49:02	\N
28278	MEMBRE	2017-10-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24845	\N	2017-10-30 11:49:02	\N
28279	MEMBRE	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24846	\N	2017-10-30 11:50:35	\N
28473	MEMBRE	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25040	\N	2017-11-03 11:05:49	\N
28474	MEMBRE	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25041	\N	2017-11-03 11:06:06	\N
28475	MEMBRE	2017-10-31 00:00:00	2017-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	25042	\N	2017-11-03 11:06:06	2017-11-08 09:28:00
28501	MEMBRE	2017-11-02 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25068	\N	2017-11-06 10:25:52	\N
28502	MEMBRE	2017-11-02 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25069	\N	2017-11-06 10:25:52	\N
28503	MEMBRE	2017-11-02 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	25070	\N	2017-11-06 10:25:52	2018-01-24 18:07:06
28504	MEMBRE	2017-11-02 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25071	\N	2017-11-06 10:25:52	\N
28505	MEMBRE	2017-11-02 00:00:00	2017-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	25072	\N	2017-11-06 10:25:52	2017-12-05 10:04:26
28506	MEMBRE	2017-11-02 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25073	\N	2017-11-06 10:25:52	\N
28507	MEMBRE	2017-11-02 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25074	\N	2017-11-06 10:25:52	\N
28508	MEMBRE	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25075	\N	2017-11-06 10:26:22	\N
28509	MEMBRE	2017-10-24 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	25076	\N	2017-11-06 10:26:22	\N
28510	MEMBRE	2017-10-20 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25077	\N	2017-11-06 10:27:33	\N
28511	MEMBRE	2017-10-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25078	\N	2017-11-06 10:27:33	\N
28512	MEMBRE	2017-10-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25079	\N	2017-11-06 10:27:33	\N
28513	MEMBRE	2017-10-20 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	25080	\N	2017-11-06 10:27:33	\N
28514	MEMBRE	2017-11-06 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	25081	\N	2017-11-06 10:28:02	2017-12-20 12:22:50
28541	MEMBRE	2017-11-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25108	\N	2017-11-07 14:19:38	\N
28542	MEMBRE	2017-10-30 00:00:00	2017-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	25109	\N	2017-11-07 14:39:30	2017-12-01 14:58:59
28543	MEMBRE	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25110	\N	2017-11-07 14:39:30	\N
28544	MEMBRE	2017-10-30 00:00:00	2018-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	25111	\N	2017-11-07 14:39:30	2018-01-30 16:00:12
28545	MEMBRE	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25112	\N	2017-11-07 14:39:30	\N
28546	MEMBRE	2017-10-30 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	25113	\N	2017-11-07 14:39:30	2018-01-18 18:10:18
28547	MEMBRE	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25114	\N	2017-11-07 14:39:30	\N
28548	MEMBRE	2017-11-02 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25115	\N	2017-11-07 15:13:17	\N
28549	MEMBRE	2017-11-02 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	25116	\N	2017-11-07 15:13:17	2018-01-24 17:10:18
28583	MEMBRE	2017-11-08 00:00:00	2018-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	25150	\N	2017-11-08 16:07:38	2018-02-21 15:39:19
28584	MEMBRE	2017-11-08 00:00:00	2017-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	25151	\N	2017-11-08 16:07:38	2017-12-14 18:23:03
28585	MEMBRE	2017-11-08 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	25152	\N	2017-11-08 16:07:38	2018-01-25 17:36:37
28586	MEMBRE	2017-11-08 00:00:00	2020-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	25153	\N	2017-11-08 16:07:38	\N
28587	MEMBRE	2017-11-08 00:00:00	2020-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	25154	\N	2017-11-08 16:07:38	\N
28588	MEMBRE	2017-11-08 00:00:00	2020-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	25155	\N	2017-11-08 16:07:38	\N
28599	MEMBRE	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25166	\N	2017-11-09 14:53:20	\N
28600	MEMBRE	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25167	\N	2017-11-09 14:53:20	\N
28601	MEMBRE	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25168	\N	2017-11-09 14:53:20	\N
28602	MEMBRE	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25169	\N	2017-11-09 14:53:20	\N
28603	MEMBRE	2017-11-08 00:00:00	2017-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	25170	\N	2017-11-09 14:53:20	2017-12-01 14:51:28
28604	MEMBRE	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25171	\N	2017-11-09 14:53:20	\N
28703	MEMBRE	2017-11-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25270	\N	2017-11-16 10:23:14	\N
28704	MEMBRE	2017-11-15 00:00:00	2018-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	25271	\N	2017-11-16 10:23:57	2018-03-07 17:12:05
28705	MEMBRE	2017-11-15 00:00:00	2017-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	25272	\N	2017-11-16 10:23:57	2017-12-19 17:54:01
28706	MEMBRE	2017-11-15 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	25273	\N	2017-11-16 10:23:57	2018-01-31 10:03:08
28707	MEMBRE	2017-11-15 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	25274	\N	2017-11-16 10:23:57	2018-01-23 17:22:52
28708	MEMBRE	2017-11-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25275	\N	2017-11-16 10:24:14	\N
28709	MEMBRE	2017-11-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25276	\N	2017-11-16 10:24:31	\N
28710	MEMBRE	2017-11-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25277	\N	2017-11-16 10:24:42	\N
28711	MEMBRE	2017-10-18 00:00:00	2018-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	25278	\N	2017-11-16 10:25:00	2018-01-30 12:30:23
28712	MEMBRE	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25279	\N	2017-11-16 14:07:36	\N
28719	MEMBRE	2017-11-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25286	\N	2017-11-16 17:09:16	\N
28720	MEMBRE	2017-11-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25287	\N	2017-11-16 17:09:16	\N
28721	MEMBRE	2017-11-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25288	\N	2017-11-17 09:53:33	\N
28722	MEMBRE	2017-11-16 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	25289	\N	2017-11-17 09:55:19	2018-01-23 17:23:56
28723	MEMBRE	2017-11-16 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	25290	\N	2017-11-17 09:55:19	2017-12-20 12:22:44
28724	MEMBRE	2017-11-16 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	25291	\N	2017-11-17 09:55:20	2018-01-23 18:49:26
28725	MEMBRE	2017-11-15 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25292	\N	2017-11-17 09:55:56	\N
28726	MEMBRE	2017-11-15 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25293	\N	2017-11-17 09:55:56	\N
28727	MEMBRE	2017-11-15 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	25294	\N	2017-11-17 09:55:56	2018-01-18 16:41:53
28728	MEMBRE	2017-11-15 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	25295	\N	2017-11-17 09:56:25	2018-02-07 15:32:07
28729	MEMBRE	2017-11-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25296	\N	2017-11-17 09:56:25	\N
28730	MEMBRE	2017-11-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25297	\N	2017-11-17 09:56:25	\N
28731	MEMBRE	2017-11-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25298	\N	2017-11-17 09:56:25	\N
28732	MEMBRE	2017-11-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25299	\N	2017-11-17 09:56:25	\N
28733	MEMBRE	2017-11-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25300	\N	2017-11-17 09:56:41	\N
28734	MEMBRE	2017-11-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25301	\N	2017-11-17 09:57:01	\N
28735	MEMBRE	2017-11-14 00:00:00	2018-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	25302	\N	2017-11-17 09:57:01	2018-02-12 16:56:56
28736	MEMBRE	2017-11-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25303	\N	2017-11-17 09:57:01	\N
28737	MEMBRE	2017-11-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25304	\N	2017-11-17 09:57:01	\N
28738	MEMBRE	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25305	\N	2017-11-17 09:57:22	\N
28739	MEMBRE	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25306	\N	2017-11-17 09:57:22	\N
28740	MEMBRE	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25307	\N	2017-11-17 09:57:22	\N
28741	MEMBRE	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25308	\N	2017-11-17 09:57:42	\N
28742	MEMBRE	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25309	\N	2017-11-17 09:57:42	\N
28743	MEMBRE	2017-11-16 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	25310	\N	2017-11-17 09:57:42	2018-01-25 16:05:02
28744	MEMBRE	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25311	\N	2017-11-17 09:57:42	\N
28745	MEMBRE	2017-11-16 00:00:00	2018-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	25312	\N	2017-11-17 09:57:42	2018-01-26 10:17:08
24672	MEMBRE	2015-01-16 00:00:00	2015-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	22407	\N	2015-01-20 16:30:39	2015-01-23 11:49:19
24673	MEMBRE	2015-01-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22408	\N	2015-01-20 17:02:10	\N
26151	VICPDT	2015-03-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22541	2	2015-03-10 17:25:26	2017-09-24 17:47:28
26152	VICPDT	2015-03-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22507	3	2015-03-10 17:25:32	2017-09-24 19:31:54
26153	VICPDT	2015-03-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23118	4	2015-03-10 17:27:14	2015-03-10 17:28:00
26154	VICPDT	2015-03-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22534	5	2015-03-10 17:27:20	2015-03-10 17:28:03
26155	VICPDT	2015-03-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22379	6	2015-03-10 17:27:27	2015-03-10 17:28:06
26156	VICPDT	2015-03-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21446	7	2015-03-10 17:27:31	2015-03-10 17:28:08
26157	VICPDT	2015-03-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20367	8	2015-03-10 17:27:36	2015-03-10 17:28:10
26176	VICPDT	2015-03-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21793	6	2015-03-11 10:57:38	2017-09-24 17:47:28
26177	VICPDT	2015-03-11 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	22476	7	2015-03-11 10:57:46	2017-06-19 16:04:13
26178	MEMBRE	2015-03-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22908	\N	2015-03-11 10:57:52	2015-03-11 10:59:40
26179	MEMBRE	2015-03-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22965	\N	2015-03-11 10:58:01	2015-03-11 10:59:45
26180	SECRET	2015-03-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22980	9	2015-03-11 10:58:11	2015-03-11 11:05:22
26181	MEMBRE	2015-03-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20459	\N	2015-03-11 10:58:16	2017-09-24 19:14:37
26182	SECRET	2015-03-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20995	10	2015-03-11 10:58:21	2017-09-24 17:48:21
26183	VICPDT	2015-03-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20300	2	2015-03-11 11:00:10	2017-09-24 18:59:59
26184	VICPDT	2015-03-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22112	3	2015-03-11 11:00:16	2015-03-11 11:04:48
26185	VICPDT	2015-03-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21548	4	2015-03-11 11:00:26	2017-09-24 18:20:10
26186	VICPDT	2015-03-11 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	21412	5	2015-03-11 11:00:33	2017-05-16 15:18:14
26187	SECRET	2015-03-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22538	8	2015-03-11 11:01:06	2015-03-11 11:05:17
26188	SECRET	2015-03-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21937	11	2015-03-11 11:04:30	2015-03-11 11:05:39
26678	VICPDT	2015-10-22 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	23090	\N	\N	2017-05-16 15:18:14
27010	MEMBRE	2016-06-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	23708	\N	\N	\N
28589	MEMBRE	2017-11-07 00:00:00	2018-03-07 00:00:00	ANCIEN	\N	\N	\N	\N	25156	\N	2017-11-08 17:10:53	2018-03-08 17:17:46
28590	MEMBRE	2017-11-07 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	25157	\N	2017-11-08 17:11:21	2018-01-18 17:49:29
28591	MEMBRE	2017-11-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25158	\N	2017-11-08 17:11:21	\N
28592	MEMBRE	2017-11-07 00:00:00	2017-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	25159	\N	2017-11-08 17:11:21	2017-11-28 17:03:35
28593	MEMBRE	2017-11-07 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	25160	\N	2017-11-08 17:11:21	2018-01-18 16:35:44
28594	MEMBRE	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25161	\N	2017-11-08 17:11:42	\N
28595	MEMBRE	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25162	\N	2017-11-08 17:11:42	\N
28596	MEMBRE	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25163	\N	2017-11-08 17:11:42	\N
28597	MEMBRE	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25164	\N	2017-11-08 17:11:57	\N
28598	MEMBRE	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25165	\N	2017-11-08 17:11:57	\N
29190	PDTDEL	2017-12-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Tchad	\N	25619	\N	2017-12-13 10:36:12	2017-12-13 15:48:22
29217	MEMBRE	2017-12-13 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	25630	\N	2017-12-14 17:09:15	2018-01-25 15:20:04
29218	MEMBRE	2017-12-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25631	\N	2017-12-14 17:09:31	\N
29477	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25803	\N	\N	\N
29618	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25879	\N	\N	\N
29704	SECRET	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24890	\N	2018-01-18 11:22:11	\N
29705	SECRET	2018-01-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25853	\N	2018-01-18 11:22:16	\N
29706	SECRET	2018-01-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25046	\N	2018-01-18 11:22:21	\N
29707	SECRET	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25204	\N	2018-01-18 11:22:31	\N
29708	SECRET	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24037	\N	2018-01-18 11:22:36	\N
29709	VICPDT	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24674	\N	2018-01-18 11:22:45	\N
29710	VICPDT	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25749	\N	2018-01-18 11:22:53	\N
29711	VICPDT	2018-01-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25857	\N	2018-01-18 11:23:02	\N
29712	VICPDT	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24211	\N	2018-01-18 11:23:12	\N
29713	VICPDT	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25096	\N	2018-01-18 11:23:17	\N
29714	VICPDT	2018-01-18 00:00:00	2020-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	25704	\N	2018-01-18 11:35:14	\N
29715	VICPDT	2018-01-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25620	\N	2018-01-18 11:35:25	\N
29716	VICPDT	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25375	\N	2018-01-18 11:35:38	\N
29717	VICPDT	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23989	\N	2018-01-18 11:35:50	\N
29718	VICPDT	2018-01-18 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	25019	\N	2018-01-18 11:35:54	\N
29719	SECRET	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24574	\N	2018-01-18 11:36:06	\N
29720	SECRET	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25313	\N	2018-01-18 11:36:12	\N
29828	SECRET	2018-01-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25720	\N	\N	\N
29829	SECRET	2018-01-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25710	\N	\N	\N
29971	SECRET	2018-01-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24298	\N	2018-01-24 15:04:54	\N
29878	MEMBRE	2018-01-23 00:00:00	2023-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	25988	\N	2018-01-24 09:39:30	\N
29933	VICPDT	2018-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	26004	\N	\N	\N
29934	MEMBRE	2017-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26015	\N	\N	\N
29947	MEMBRE	2017-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26023	\N	\N	\N
29950	MEMBRE	2017-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26025	\N	\N	\N
29956	MEMBRE	2017-10-01 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	26030	\N	\N	\N
29957	MEMBRE	2018-01-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26031	\N	2018-01-24 14:43:45	\N
29958	MEMBRE	2018-01-22 00:00:00	2018-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	26032	\N	2018-01-24 14:44:08	2018-02-14 12:54:24
29959	MEMBRE	2018-01-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26033	\N	2018-01-24 14:44:08	\N
29960	MEMBRE	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26034	\N	2018-01-24 14:48:01	\N
29961	VICPDT	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25098	\N	2018-01-24 14:55:23	\N
29962	VICPDT	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24486	\N	2018-01-24 14:55:28	\N
29963	VICPDT	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24886	\N	2018-01-24 15:03:32	\N
29964	VICPDT	2018-01-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24548	\N	2018-01-24 15:03:41	\N
29965	VICPDT	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24049	\N	2018-01-24 15:03:49	\N
29966	VICPDT	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25634	\N	2018-01-24 15:03:58	\N
29967	VICPDT	2018-01-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25961	\N	2018-01-24 15:04:11	\N
29968	VICPDT	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25422	\N	2018-01-24 15:04:27	\N
29969	VICPDT	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25987	\N	2018-01-24 15:04:34	\N
29970	SECRET	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25629	\N	2018-01-24 15:04:45	\N
29972	SECRET	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25425	\N	2018-01-24 15:04:59	\N
29974	PDTHON	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24286	\N	2018-01-24 15:30:18	\N
29975	VICPDT	2018-01-24 00:00:00	2020-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	24614	\N	2018-01-24 15:31:15	\N
29976	VICPDT	2018-01-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25685	\N	2018-01-24 15:31:31	\N
29977	VICPDT	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24994	\N	2018-01-24 15:31:43	\N
29978	VICPDT	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25672	\N	2018-01-24 15:31:56	\N
29979	VICPDT	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24564	\N	2018-01-24 15:53:10	\N
29980	VICPDT	2018-01-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25795	\N	2018-01-24 15:53:21	\N
29981	VICPDT	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24166	\N	2018-01-24 15:53:27	\N
29982	VICPDT	2018-01-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24305	\N	2018-01-24 15:53:34	\N
29983	SECRET	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24039	\N	2018-01-24 15:53:52	\N
29984	SECRET	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25903	\N	2018-01-24 15:53:58	\N
29985	SECRET	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23900	\N	2018-01-24 15:54:52	\N
29986	SECRET	2018-01-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25461	\N	2018-01-24 15:54:59	\N
29987	SECRET	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25819	\N	2018-01-24 15:55:09	\N
30039	VICPDT	2018-01-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24796	\N	2018-01-25 10:58:04	\N
30040	VICPDT	2018-01-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25355	\N	2018-01-25 10:58:15	\N
30041	VICPDT	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24822	\N	2018-01-25 10:58:43	\N
30042	VICPDT	2018-01-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25000	\N	2018-01-25 10:58:50	\N
30043	VICPDT	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25544	\N	2018-01-25 10:58:57	\N
30044	SECRET	2018-01-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24613	\N	2018-01-25 10:59:34	\N
30045	SECRET	2018-01-25 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	24508	\N	2018-01-25 10:59:48	\N
30046	VICPDT	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25595	\N	2018-01-25 11:00:48	\N
30047	VICPDT	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24692	\N	2018-01-25 11:14:01	\N
25206	VICPDT	2015-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22292	2	2015-02-12 17:35:33	2015-02-12 17:36:58
25207	VICPDT	2015-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20671	3	2015-02-12 17:35:39	2015-02-12 17:37:01
25208	VICPDT	2015-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21556	4	2015-02-12 17:35:47	2015-02-12 17:37:06
25209	VICPDT	2015-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20513	5	2015-02-12 17:35:54	2015-02-12 17:37:10
25210	VICPDT	2015-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22034	6	2015-02-12 17:35:59	2015-02-12 17:37:13
25211	VICPDT	2015-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21941	7	2015-02-12 17:36:05	2015-02-12 17:37:16
25212	VICPDT	2015-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20643	8	2015-02-12 17:36:13	2015-02-12 17:37:19
25213	SECRET	2015-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22226	9	2015-02-12 17:36:24	2015-02-12 17:37:21
25214	SECRET	2015-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20900	10	2015-02-12 17:36:31	2015-02-12 17:37:23
25215	SECRET	2015-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22326	11	2015-02-12 17:36:39	2015-02-12 17:37:30
25216	SECRET	2015-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20647	12	2015-02-12 17:36:45	2015-02-12 17:37:33
25217	SECRET	2015-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22140	13	2015-02-12 17:36:51	2015-02-12 17:37:35
25342	VICPDT	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20507	2	2015-02-13 15:12:27	2015-02-13 15:12:33
25343	VICPDT	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21312	3	2015-02-13 15:12:41	2015-02-13 15:12:52
25344	VICPDT	2015-02-13 00:00:00	2017-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	20862	4	2015-02-13 15:13:02	2017-07-04 15:08:09
25345	VICPDT	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20714	5	2015-02-13 15:13:22	2015-02-13 15:13:33
25346	VICPDT	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20760	6	2015-02-13 15:13:51	2015-02-13 15:14:06
25347	VICPDT	2015-02-13 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21146	7	2015-02-13 15:14:12	2015-02-13 15:14:27
25348	VICPDT	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20947	8	2015-02-13 15:14:34	2015-02-13 15:14:45
25349	VICPDT	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21455	9	2015-02-13 15:14:52	2015-02-13 15:15:00
25350	VICPDT	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22209	10	2015-02-13 15:15:09	2015-02-13 15:15:22
25351	VICPDT	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21685	11	2015-02-13 15:15:33	2015-02-13 15:15:52
25352	SECRET	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20293	12	2015-02-13 15:16:04	2015-02-13 15:16:15
25353	SECRET	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21390	\N	2015-02-13 15:16:25	\N
25387	MEMBRE	2014-10-01 00:00:00	2015-03-24 00:00:00	ANCIEN	\N	\N	\N	\N	22657	\N	\N	\N
25395	MEMBRE	2015-01-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	22665	\N	\N	\N
25397	MEMBRE	2015-01-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	22667	\N	\N	\N
25398	MEMBRE	2015-01-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	22668	\N	\N	\N
25400	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22670	\N	\N	\N
26524	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23299	\N	\N	\N
26529	MEMBRE	2014-10-01 00:00:00	2015-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	23304	\N	\N	\N
26531	MEMBRE	2014-10-01 00:00:00	2015-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	23306	\N	\N	\N
26533	MEMBRE	2014-10-01 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	23308	\N	\N	2016-12-12 16:10:15
26539	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23314	\N	\N	\N
26546	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23321	\N	\N	\N
26556	MEMBRE	2014-10-01 00:00:00	2015-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	23331	\N	\N	\N
26601	PDT	2015-07-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23298	\N	\N	2017-09-24 13:44:49
26602	PDTDEL	2015-07-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23306	\N	\N	2017-09-24 18:59:59
26603	PDTDEL	2015-07-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	23331	\N	\N	\N
26604	VICPDT	2015-07-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	23304	\N	\N	\N
26608	VICPDT	2015-07-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23325	\N	\N	2017-09-24 18:20:10
27011	MEMBRE	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23709	\N	\N	2017-09-24 17:14:26
27014	MEMBRE	2016-06-23 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	23712	\N	2016-06-23 12:49:23	2017-09-25 09:57:52
29191	MEMBRE	2017-12-11 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	25620	\N	2017-12-13 11:38:45	2018-01-18 11:35:25
29292	MEMBRE	2017-12-19 00:00:00	2018-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	25668	\N	2017-12-20 10:01:25	2018-01-19 10:25:16
29293	MEMBRE	2017-12-19 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25669	\N	2017-12-20 10:01:25	\N
29294	MEMBRE	2017-12-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25670	\N	2017-12-20 10:02:31	\N
29295	MEMBRE	2017-12-19 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25671	\N	2017-12-20 10:02:50	\N
29296	MEMBRE	2017-12-19 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	25672	\N	2017-12-20 10:03:05	2018-01-24 15:31:56
29297	MEMBRE	2017-12-15 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	25673	\N	2017-12-20 10:06:04	2017-12-20 10:25:25
29298	MEMBRE	2017-12-15 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	25674	\N	2017-12-20 10:09:28	2017-12-20 10:26:30
29299	MEMBRE	2017-12-18 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	25675	\N	2017-12-20 10:09:42	2017-12-20 10:39:08
29300	MEMBRE	2017-12-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25676	\N	2017-12-20 10:10:02	\N
29301	SECRET	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25677	\N	2017-12-20 10:11:50	2017-12-20 16:57:44
29302	PDTDEL	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Djibouti	\N	25673	\N	2017-12-20 10:25:24	2017-12-20 10:25:34
29303	PDTDEL	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Sultanat d'Oman	\N	25674	\N	2017-12-20 10:26:29	2017-12-20 10:26:43
29304	PDTDEL	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Tadjikistan	\N	25675	\N	2017-12-20 10:39:08	2017-12-20 10:39:21
29316	VICPDT	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25206	\N	2017-12-20 14:34:23	\N
29317	VICPDT	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25560	\N	2017-12-20 14:34:33	\N
29318	VICPDT	2017-12-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25183	\N	2017-12-20 14:34:41	\N
29319	SECRET	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25471	\N	2017-12-20 14:34:55	\N
29320	SECRET	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25451	\N	2017-12-20 14:35:04	\N
29445	MEMBRE	2017-12-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25777	\N	2017-12-28 15:29:35	\N
29680	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25934	\N	\N	\N
29681	MEMBRE	2017-10-01 00:00:00	2018-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	25935	\N	\N	\N
29819	MEMBRE	2018-01-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25985	\N	2018-01-23 14:57:42	\N
30257	MEMBRE	2018-01-29 00:00:00	2018-03-04 00:00:00	ANCIEN	\N	\N	\N	\N	26152	\N	2018-01-30 09:25:24	2018-03-05 17:04:50
30258	MEMBRE	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26153	\N	2018-01-30 09:26:33	\N
30259	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26154	\N	\N	\N
30262	VICPDT	2018-01-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25992	\N	2018-01-30 12:28:52	\N
30263	VICPDT	2018-01-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24068	\N	2018-01-30 12:29:01	\N
30264	VICPDT	2018-01-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24215	\N	2018-01-30 12:29:15	\N
30265	VICPDT	2018-01-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25326	\N	2018-01-30 12:29:31	\N
30266	VICPDT	2018-01-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24783	\N	2018-01-30 12:29:40	\N
30267	VICPDT	2018-01-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24954	\N	2018-01-30 12:29:52	\N
30268	VICPDT	2018-01-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25232	\N	2018-01-30 12:30:00	\N
30269	VICPDT	2018-01-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24136	\N	2018-01-30 12:30:11	\N
30270	VICPDT	2018-01-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25278	\N	2018-01-30 12:30:23	\N
30271	VICPDT	2018-01-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24926	\N	2018-01-30 12:30:32	\N
30272	SECRET	2018-01-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24347	\N	2018-01-30 12:30:37	\N
30273	SECRET	2018-01-30 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	24494	\N	2018-01-30 12:30:51	\N
30274	SECRET	2018-01-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24670	\N	2018-01-30 12:30:56	\N
30275	MEMBRE	2018-01-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26157	\N	2018-01-30 14:45:41	\N
30276	VICPDT	2018-01-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25348	\N	2018-01-30 14:46:29	\N
30277	VICPDT	2018-01-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23868	\N	2018-01-30 14:46:36	\N
30278	VICPDT	2018-01-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24560	\N	2018-01-30 14:46:41	\N
30279	VICPDT	2018-01-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25396	\N	2018-01-30 14:46:51	\N
30280	SECRET	2018-01-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25481	\N	2018-01-30 14:46:58	\N
30281	SECRET	2018-01-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25856	\N	2018-01-30 14:47:02	\N
30282	SECRET	2018-01-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25450	\N	2018-01-30 14:47:11	\N
30283	SECRET	2018-01-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25508	\N	2018-01-30 14:47:20	\N
30287	PDTDEL	2018-01-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Pérou	\N	25817	\N	2018-01-30 16:00:31	2018-01-30 16:10:31
30285	VICPDTDEL	2018-01-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Venezuela	\N	25036	\N	2018-01-30 16:00:00	2018-01-30 17:06:59
30286	SECRET	2018-01-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25111	\N	2018-01-30 16:00:12	\N
30288	PDTDEL	2018-01-30 00:00:00	2018-04-02 00:00:00	ANCIEN	\N	\N	Pérou	\N	24770	\N	2018-01-30 16:00:46	2018-04-03 12:21:41
30289	SECRET	2018-01-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24545	\N	2018-01-30 16:00:53	\N
30290	SECRET	2018-01-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24837	\N	2018-01-30 16:01:04	\N
30291	VICPDTDEL	2018-01-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Bolivie	\N	23925	\N	2018-01-30 16:01:29	2018-01-30 17:07:23
30292	SECRET	2018-01-30 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	24519	\N	2018-01-30 16:01:38	\N
30293	PDT	2018-01-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	25867	\N	\N	\N
30294	VICPDTDEL	2018-01-30 00:00:00	2018-02-04 00:00:00	ANCIEN	\N	\N	Equateur	\N	25008	\N	2018-01-30 16:02:27	2018-02-05 17:21:59
30295	SECRET	2018-01-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24539	\N	2018-01-30 16:02:36	\N
22285	MEMBRE	2014-01-26 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19993	\N	\N	\N
24675	MEMBRE	2015-01-20 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	22410	\N	2015-01-21 09:28:27	2015-02-03 13:56:48
24676	MEMBRE	2015-01-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22411	\N	2015-01-21 09:28:41	\N
24677	MEMBRE	2015-01-20 00:00:00	2015-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	22412	\N	2015-01-21 09:28:58	2015-03-04 17:16:08
24775	MEMBRE	2015-01-27 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22465	\N	2015-01-27 17:35:28	\N
24679	MEMBRE	2015-01-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22414	\N	2015-01-21 09:29:31	\N
24680	PDT	2015-01-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22413	1	2015-01-21 09:30:09	2015-01-21 09:30:19
24776	MEMBRE	2015-01-27 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22466	\N	2015-01-27 17:35:28	\N
24777	MEMBRE	2015-01-27 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22467	\N	2015-01-27 17:35:28	\N
24935	MEMBRE	2015-01-30 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	22508	\N	2015-02-03 18:40:32	2015-02-03 18:40:54
24936	PDTDEL	2015-02-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour le Pérou	\N	22508	5	2015-02-03 18:40:54	2015-02-03 18:41:44
24937	MEMBRE	2015-01-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22509	\N	2015-02-04 09:41:32	\N
24949	VICPDT	2015-02-04 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21365	3	2015-02-04 14:27:00	2015-02-04 14:27:39
24950	VICPDT	2015-02-04 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20470	4	2015-02-04 14:27:06	2015-02-04 14:27:41
24951	VICPDT	2015-02-04 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22085	5	2015-02-04 14:27:26	2015-02-04 14:27:44
24952	VICPDT	2015-02-04 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20769	6	2015-02-04 14:27:33	2015-02-04 14:27:48
24954	SECRET	2015-02-04 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21202	7	2015-02-04 14:27:52	2015-02-04 14:28:03
24955	SECRET	2015-02-04 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21457	8	2015-02-04 14:27:57	2015-02-04 14:28:05
25614	VICPDT	2015-02-17 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	22491	2	2015-02-17 16:13:05	2017-06-19 16:04:13
25615	VICPDT	2015-02-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21393	3	2015-02-17 16:13:09	2015-02-17 16:14:16
25616	VICPDT	2015-02-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21397	4	2015-02-17 16:13:16	2015-02-17 16:14:19
25617	VICPDT	2015-02-17 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21165	5	2015-02-17 16:13:26	2015-02-17 16:14:21
25618	VICPDT	2015-02-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21687	6	2015-02-17 16:13:31	2015-02-17 16:14:25
25619	VICPDT	2015-02-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20442	7	2015-02-17 16:13:38	2015-02-17 16:14:28
25620	VICPDT	2015-02-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22511	8	2015-02-17 16:13:50	2015-02-17 16:14:30
25621	SECRET	2015-02-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22482	9	2015-02-17 16:14:00	2015-02-17 16:14:34
25622	SECRET	2015-02-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20430	10	2015-02-17 16:14:07	2015-02-17 16:14:37
25623	VICPDT	2015-02-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21668	2	2015-02-17 16:20:01	2015-02-17 16:20:21
25624	VICPDT	2015-02-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21893	3	2015-02-17 16:20:07	2015-02-17 16:20:24
25625	VICPDT	2015-02-17 00:00:00	2017-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	22037	4	2015-02-17 16:20:12	2017-07-24 09:58:00
25626	VICPDT	2015-02-17 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	20680	5	2015-02-17 16:20:16	2015-06-12 15:59:49
25628	MEMBRE	2015-02-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22834	\N	2015-02-18 09:08:55	\N
25629	VICPDT	2015-02-18 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21192	7	2015-02-18 09:59:07	2015-02-18 09:59:25
26207	MEMBRE	2015-03-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23157	\N	2015-03-11 15:21:53	\N
26208	MEMBRE	2015-03-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23158	\N	2015-03-11 16:12:33	\N
26373	MEMBRE	2015-03-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	23219	\N	\N	\N
26523	MEMBRE	2014-10-01 00:00:00	2015-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	23298	\N	\N	\N
26380	MEMBRE	2015-03-02 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	23226	\N	\N	2017-09-25 09:57:52
26607	VICPDT	2015-07-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23309	\N	\N	2017-09-24 17:42:26
26609	VICPDT	2015-07-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	23310	\N	\N	\N
26610	VICPDT	2015-07-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	23323	\N	\N	\N
26611	VICPDT	2015-07-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23315	\N	\N	2017-09-24 18:59:59
26910	MEMBRE	2016-05-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23616	\N	2016-05-19 15:11:39	\N
23996	MEMBRE	2014-10-30 00:00:00	2017-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	21907	\N	2014-10-31 10:10:54	2017-10-05 09:37:46
27536	MEMBRE	2017-10-16 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	24103	\N	2017-10-16 14:22:33	\N
27976	MEMBRE	2017-10-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24543	\N	2017-10-24 15:05:56	\N
27977	MEMBRE	2017-10-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24544	\N	2017-10-24 15:05:56	\N
28004	MEMBRE	2017-10-20 00:00:00	2017-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	24571	\N	2017-10-25 09:53:02	2017-11-24 16:57:56
28005	MEMBRE	2017-10-20 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	24572	\N	2017-10-25 09:53:02	2018-01-23 17:48:04
28006	MEMBRE	2017-10-20 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	24573	\N	2017-10-25 09:53:02	2018-02-07 12:14:36
28007	MEMBRE	2017-10-20 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	24574	\N	2017-10-25 09:53:02	2018-01-18 11:36:06
28008	MEMBRE	2017-10-20 00:00:00	2018-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	24575	\N	2017-10-25 09:53:03	2018-01-16 18:56:57
28009	MEMBRE	2017-10-20 00:00:00	2018-03-04 00:00:00	ANCIEN	\N	\N	\N	\N	24576	\N	2017-10-25 09:53:03	2018-03-05 17:58:42
28010	MEMBRE	2017-10-20 00:00:00	2017-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	24577	\N	2017-10-25 09:53:03	2017-12-14 15:43:24
28011	MEMBRE	2017-10-20 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24578	\N	2017-10-25 09:53:03	2018-01-24 17:10:37
28012	MEMBRE	2017-10-20 00:00:00	2017-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	24579	\N	2017-10-25 09:53:03	2017-11-24 16:57:56
28013	MEMBRE	2017-10-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24580	\N	2017-10-25 09:53:36	\N
28014	MEMBRE	2017-10-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24581	\N	2017-10-25 09:53:37	\N
28015	MEMBRE	2017-10-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24582	\N	2017-10-25 09:53:37	\N
28016	MEMBRE	2017-10-13 00:00:00	2018-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	24583	\N	2017-10-25 09:53:37	2018-01-26 10:35:13
28017	MEMBRE	2017-10-13 00:00:00	2018-03-04 00:00:00	ANCIEN	\N	\N	\N	\N	24584	\N	2017-10-25 09:53:37	2018-03-05 18:15:32
28018	MEMBRE	2017-10-24 00:00:00	2017-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	24585	\N	2017-10-25 09:54:56	2017-12-01 14:55:26
28019	MEMBRE	2017-10-23 00:00:00	2018-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	24586	\N	2017-10-25 09:55:22	2018-01-17 11:29:46
28020	MEMBRE	2017-10-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24587	\N	2017-10-25 09:55:41	\N
28021	MEMBRE	2017-10-24 00:00:00	2018-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	24588	\N	2017-10-25 09:55:41	2018-01-16 18:59:35
28022	MEMBRE	2017-10-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24589	\N	2017-10-25 09:55:41	\N
28023	MEMBRE	2017-10-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24590	\N	2017-10-25 09:58:57	\N
28024	MEMBRE	2017-10-23 00:00:00	2018-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	24591	\N	2017-10-25 09:58:57	2018-02-14 18:31:51
28025	MEMBRE	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24592	\N	2017-10-25 10:19:19	\N
28026	MEMBRE	2017-10-25 00:00:00	2018-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	24593	\N	2017-10-25 10:19:19	2018-02-01 14:36:17
28076	MEMBRE	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24643	\N	2017-10-26 09:38:17	\N
28077	MEMBRE	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24644	\N	2017-10-26 09:38:17	\N
28078	MEMBRE	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24645	\N	2017-10-26 09:38:17	\N
28079	MEMBRE	2017-10-26 00:00:00	2017-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	24646	\N	2017-10-26 09:38:17	2017-12-14 18:27:04
28080	MEMBRE	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24647	\N	2017-10-26 09:38:17	\N
28081	MEMBRE	2017-10-26 00:00:00	2018-03-04 00:00:00	ANCIEN	\N	\N	\N	\N	24648	\N	2017-10-26 09:38:17	2018-03-05 18:14:23
28082	MEMBRE	2017-10-26 00:00:00	2019-03-08 00:00:00	ANCIEN	\N	\N	\N	\N	24649	\N	2017-10-26 09:38:17	\N
28083	MEMBRE	2017-10-26 00:00:00	2017-12-05 00:00:00	ANCIEN	\N	\N	\N	\N	24650	\N	2017-10-26 09:38:17	2017-12-06 15:08:46
28084	MEMBRE	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24651	\N	2017-10-26 09:38:17	\N
28085	MEMBRE	2017-10-26 00:00:00	2018-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	24652	\N	2017-10-26 09:38:17	2018-01-26 10:08:11
28086	MEMBRE	2017-10-26 00:00:00	2019-03-08 00:00:00	ANCIEN	\N	\N	\N	\N	24653	\N	2017-10-26 09:38:17	\N
28087	MEMBRE	2017-10-26 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	24654	\N	2017-10-26 09:38:17	2018-02-07 12:14:46
28088	MEMBRE	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24655	\N	2017-10-26 09:38:17	\N
28089	MEMBRE	2017-10-26 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	24656	\N	2017-10-26 09:38:17	2018-02-07 15:29:54
28090	MEMBRE	2017-10-26 00:00:00	2018-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	24657	\N	2017-10-26 09:38:17	2018-02-15 10:20:39
28091	MEMBRE	2017-10-26 00:00:00	2019-03-08 00:00:00	ANCIEN	\N	\N	\N	\N	24658	\N	2017-10-26 09:38:17	\N
28092	MEMBRE	2017-10-26 00:00:00	2018-03-04 00:00:00	ANCIEN	\N	\N	\N	\N	24659	\N	2017-10-26 09:38:17	2018-03-05 17:18:35
28093	MEMBRE	2017-10-26 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24660	\N	2017-10-26 09:38:17	2018-01-24 17:29:57
28094	MEMBRE	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24661	\N	2017-10-26 09:38:17	\N
28095	MEMBRE	2017-10-26 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	24662	\N	2017-10-26 09:38:17	2018-01-18 16:35:52
28096	MEMBRE	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24663	\N	2017-10-26 09:38:17	\N
28097	MEMBRE	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24664	\N	2017-10-26 09:48:04	\N
28098	MEMBRE	2017-10-24 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	24665	\N	2017-10-26 09:48:04	2018-01-18 18:23:15
28099	MEMBRE	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24666	\N	2017-10-26 09:48:05	\N
28100	MEMBRE	2017-10-24 00:00:00	2017-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	24667	\N	2017-10-26 09:48:05	2017-11-28 17:02:31
28101	MEMBRE	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24668	\N	2017-10-26 09:48:05	\N
28102	MEMBRE	2017-10-24 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	24669	\N	2017-10-26 09:48:40	2018-01-23 18:43:34
28103	MEMBRE	2017-10-24 00:00:00	2018-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	24670	\N	2017-10-26 09:48:40	2018-01-30 12:30:56
25686	VICPDTDRT	2015-02-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22866	\N	2015-02-19 11:14:18	\N
25695	MEMBRE	2014-10-01 00:00:00	2015-04-15 00:00:00	ANCIEN	\N	\N	\N	\N	22878	\N	\N	\N
25696	MEMBRE	2014-10-01 00:00:00	2015-04-15 00:00:00	ANCIEN	\N	\N	\N	\N	22879	\N	\N	\N
25697	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22880	\N	\N	\N
25698	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22881	\N	\N	\N
25699	MEMBRE	2014-10-01 00:00:00	2015-04-15 00:00:00	ANCIEN	\N	\N	\N	\N	22882	\N	\N	\N
25700	MEMBRE	2014-10-01 00:00:00	2015-04-15 00:00:00	ANCIEN	\N	\N	\N	\N	22883	\N	\N	\N
25704	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22887	\N	\N	\N
25705	MEMBRE	2014-10-01 00:00:00	2015-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	22888	\N	\N	\N
25706	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22889	\N	\N	\N
25707	MEMBRE	2014-10-01 00:00:00	2015-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	22890	\N	\N	\N
25708	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22891	\N	\N	2017-09-24 17:42:26
25709	MEMBRE	2014-10-01 00:00:00	2015-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	22892	\N	\N	\N
25710	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22893	\N	\N	\N
25711	MEMBRE	2014-10-01 00:00:00	2015-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	22894	\N	\N	\N
25712	MEMBRE	2014-10-01 00:00:00	2015-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	22895	\N	\N	\N
25713	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22896	\N	\N	\N
25714	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22897	\N	\N	2017-09-24 13:44:49
25715	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22898	\N	\N	\N
25716	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22899	\N	\N	\N
25718	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22901	\N	\N	2017-09-24 16:45:26
25719	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22902	\N	\N	\N
25720	MEMBRE	2014-10-01 00:00:00	2015-03-04 00:00:00	ANCIEN	\N	\N	\N	\N	22903	\N	\N	\N
25721	MEMBRE	2014-10-01 00:00:00	2017-07-28 00:00:00	ANCIEN	\N	\N	\N	\N	22904	\N	\N	2017-08-03 11:38:41
25722	MEMBRE	2014-10-01 00:00:00	2015-03-04 00:00:00	ANCIEN	\N	\N	\N	\N	22905	\N	\N	\N
25723	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22906	\N	\N	\N
25724	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22907	\N	\N	\N
26372	MEMBRE	2015-03-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	23218	\N	\N	\N
26375	MEMBRE	2015-03-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	23221	\N	\N	\N
26668	MEMBRE	2015-10-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	23406	\N	\N	\N
26879	MEMBRE	2016-02-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23595	\N	2016-02-16 18:08:35	2017-09-24 17:47:27
27908	MEMBRE	2017-10-23 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	24475	\N	2017-10-23 15:23:09	\N
27909	MEMBRE	2017-10-20 00:00:00	2020-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	24476	\N	2017-10-23 15:52:46	\N
28315	MEMBRE	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24882	\N	2017-10-31 15:23:03	\N
28316	MEMBRE	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24883	\N	2017-10-31 15:23:03	\N
28317	MEMBRE	2017-10-31 00:00:00	2017-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	24884	\N	2017-10-31 15:23:03	2017-12-14 15:51:00
28318	MEMBRE	2017-10-31 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	24885	\N	2017-10-31 15:23:03	2018-01-23 18:43:00
28319	MEMBRE	2017-10-31 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24886	\N	2017-10-31 15:23:03	2018-01-24 15:03:32
28320	MEMBRE	2017-10-31 00:00:00	2018-03-04 00:00:00	ANCIEN	\N	\N	\N	\N	24887	\N	2017-10-31 15:23:03	2018-03-05 17:18:00
28321	MEMBRE	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24888	\N	2017-10-31 15:23:03	\N
28322	MEMBRE	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24889	\N	2017-10-31 15:23:03	\N
28323	MEMBRE	2017-10-31 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	24890	\N	2017-10-31 15:23:03	2018-01-18 11:22:11
28324	MEMBRE	2017-10-25 00:00:00	2018-09-09 00:00:00	ANCIEN	\N	\N	\N	\N	24891	\N	2017-10-31 15:58:18	\N
28325	MEMBRE	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24892	\N	2017-10-31 15:58:18	\N
28326	MEMBRE	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24893	\N	2017-10-31 15:58:18	\N
28327	MEMBRE	2017-10-25 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	24894	\N	2017-10-31 15:58:18	2018-01-18 18:22:50
28798	MEMBRE	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25365	\N	2017-11-20 10:07:42	\N
28799	MEMBRE	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25366	\N	2017-11-20 14:33:59	\N
28800	MEMBRE	2017-11-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25367	\N	2017-11-20 15:24:02	\N
28801	MEMBRE	2017-11-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25368	\N	2017-11-20 15:24:02	\N
28802	MEMBRE	2017-11-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25369	\N	2017-11-20 15:44:30	\N
28803	MEMBRE	2017-11-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25370	\N	2017-11-20 15:44:30	\N
28804	MEMBRE	2017-11-20 00:00:00	2017-12-11 00:00:00	ANCIEN	\N	\N	\N	\N	25371	\N	2017-11-20 15:44:30	2017-12-12 17:14:51
28805	MEMBRE	2017-11-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25372	\N	2017-11-20 15:44:30	\N
28806	MEMBRE	2017-11-20 00:00:00	2018-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	25373	\N	2017-11-20 15:44:30	2018-02-01 18:33:29
28807	MEMBRE	2017-11-20 00:00:00	2018-05-23 00:00:00	ANCIEN	\N	\N	\N	\N	25374	\N	2017-11-20 15:44:30	2018-05-24 10:46:52
28888	MEMBRE	2017-11-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25455	\N	2017-11-24 16:57:32	\N
28889	MEMBRE	2017-11-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25456	\N	2017-11-24 16:59:33	\N
28890	MEMBRE	2017-11-24 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	25457	\N	2017-11-24 16:59:33	2018-01-18 17:50:06
28891	MEMBRE	2017-11-24 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	25458	\N	2017-11-24 16:59:33	2018-01-23 16:57:06
28892	MEMBRE	2017-11-24 00:00:00	2018-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	25459	\N	2017-11-24 16:59:33	2018-01-26 10:01:43
28893	MEMBRE	2017-11-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25460	\N	2017-11-24 16:59:48	\N
28905	MEMBRE	2017-11-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25469	\N	2017-11-28 11:16:36	\N
28952	MEMBRE	2017-11-29 00:00:00	2018-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	25485	\N	2017-11-29 12:36:02	2018-01-09 11:35:03
28990	PDTDEL	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Bahreïn	\N	25252	\N	2017-11-30 16:06:10	2017-11-30 16:06:24
28991	PDTDEL	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Birmanie	\N	25136	\N	2017-11-30 16:07:08	2017-11-30 16:07:19
28992	PDTDEL	2017-11-30 00:00:00	2020-07-13 00:00:00	ANCIEN	\N	\N	Bosnie-Herzégovine	\N	25397	\N	2017-11-30 16:07:51	2017-11-30 16:08:08
28993	PDTDEL	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Botswana	\N	24126	\N	2017-11-30 16:09:18	2017-11-30 16:09:34
28994	PDTDEL	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Burkina Faso	\N	23932	\N	2017-11-30 16:14:17	2017-11-30 16:14:29
28995	PDTDEL	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Cameroun	\N	24914	\N	2017-11-30 16:17:20	2017-11-30 16:17:34
28996	PDTDEL	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Gabon	\N	24569	\N	2017-11-30 16:18:17	2017-11-30 16:18:39
28997	PDTDEL	2017-11-30 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	Nigéria	\N	24716	\N	2017-11-30 16:25:06	2017-11-30 16:25:16
28998	PDTDEL	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Sénégal	\N	25132	\N	2017-11-30 16:25:35	2017-11-30 16:25:51
28999	PDTDEL	2017-11-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	Équateur	\N	25215	\N	2017-11-30 16:30:48	2017-11-30 16:31:08
29000	PDTDEL	2017-11-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	Fidji	\N	24523	\N	2017-11-30 16:32:12	2017-11-30 16:32:19
29001	PDTDEL	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Vanuatu	\N	25449	\N	2017-11-30 16:32:45	2017-11-30 16:33:10
29002	PDTDEL	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Namibie	\N	24126	\N	2017-11-30 16:34:52	2017-11-30 16:35:13
29003	PDTDEL	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Zimbabwe	\N	24335	\N	2017-11-30 16:35:45	2017-11-30 16:36:07
29004	PDTDEL	2017-11-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	Kazakhstan	\N	24800	\N	2017-11-30 16:37:13	2017-11-30 16:37:40
29005	PDTDEL	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Kosovo	\N	25388	\N	2017-11-30 16:39:15	2017-11-30 16:39:33
29006	PDTDEL	2017-11-30 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	Monténégro	\N	24020	\N	2017-11-30 16:40:44	2017-11-30 16:40:52
29007	PDTDEL	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Lettonie	\N	24901	\N	2017-11-30 16:41:31	2017-11-30 16:41:38
29008	PDTDEL	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Lituanie	\N	25507	\N	2017-11-30 16:42:13	2017-11-30 16:44:56
29009	PDTDEL	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Mexique	\N	24280	\N	2017-11-30 16:45:17	2017-11-30 16:45:33
29010	PDTDEL	2017-11-30 00:00:00	2019-06-24 00:00:00	ANCIEN	\N	\N	République démocratique du Congo	\N	24468	\N	2017-11-30 16:46:11	2017-11-30 16:46:25
29011	PDTDEL	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Singapour	\N	24488	\N	2017-11-30 16:47:53	2017-11-30 16:48:10
29012	PDTDEL	2017-11-30 00:00:00	2018-12-30 00:00:00	ANCIEN	\N	\N	Thaïlande	\N	25258	\N	2017-11-30 16:48:21	2017-11-30 16:48:31
29013	PDT	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25506	\N	2017-11-30 17:31:48	2017-11-30 17:32:02
29014	PDT	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25482	\N	2017-11-30 17:33:10	\N
29015	PDT	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25514	\N	2017-11-30 17:34:37	\N
29016	MEMBRE	2017-11-29 00:00:00	2018-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	25516	\N	2017-11-30 17:36:18	2018-01-16 19:00:33
29017	MEMBRE	2017-11-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25517	\N	2017-11-30 17:36:35	\N
29018	MEMBRE	2017-11-07 00:00:00	2018-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	25518	\N	2017-11-30 17:36:35	2018-01-26 10:15:50
29019	MEMBRE	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25519	\N	2017-12-01 09:34:34	\N
29020	MEMBRE	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25520	\N	2017-12-01 09:34:34	\N
29021	MEMBRE	2017-11-30 00:00:00	2018-12-30 00:00:00	ANCIEN	\N	\N	\N	\N	25521	\N	2017-12-01 09:34:59	\N
29022	MEMBRE	2017-11-29 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	25522	\N	2017-12-01 09:48:51	2018-02-07 15:29:30
29023	MEMBRE	2017-11-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25523	\N	2017-12-01 09:48:51	\N
29024	MEMBRE	2017-11-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25524	\N	2017-12-01 10:07:33	\N
29025	MEMBRE	2017-11-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25525	\N	2017-12-01 10:07:33	\N
29026	PDTDEL	2017-12-01 00:00:00	2019-03-12 00:00:00	ANCIEN	\N	\N	Cote d'Ivoire	\N	23932	\N	2017-12-01 10:40:18	2017-12-01 17:44:34
29027	PDT	2017-12-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24139	\N	2017-12-01 14:51:02	\N
29028	PDT	2017-12-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25170	\N	2017-12-01 14:51:28	\N
23119	MEMBRE	2014-10-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21063	\N	2014-10-24 09:49:19	\N
23120	MEMBRE	2014-10-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21064	\N	2014-10-24 09:49:19	\N
23121	MEMBRE	2014-10-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21065	\N	2014-10-24 09:49:19	\N
23122	MEMBRE	2014-10-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21066	\N	2014-10-24 09:49:19	\N
23123	MEMBRE	2014-10-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21067	\N	2014-10-24 09:49:19	\N
23124	MEMBRE	2014-10-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21068	\N	2014-10-24 09:49:19	\N
23125	MEMBRE	2014-10-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21069	\N	2014-10-24 09:49:19	\N
23126	MEMBRE	2014-10-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21070	\N	2014-10-24 09:49:19	\N
23127	MEMBRE	2014-10-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21071	\N	2014-10-24 09:49:19	\N
23128	MEMBRE	2014-10-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21072	\N	2014-10-24 09:49:19	\N
23129	MEMBRE	2014-10-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21073	\N	2014-10-24 09:49:19	\N
23130	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21074	\N	2014-10-24 09:50:07	\N
23131	MEMBRE	2014-10-22 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	21075	\N	2014-10-24 09:50:07	2015-02-05 18:58:49
23132	MEMBRE	2014-10-22 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	21076	\N	2014-10-24 09:50:07	2015-02-20 12:12:24
23133	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21077	\N	2014-10-24 09:50:07	\N
23134	MEMBRE	2014-10-22 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	21078	\N	2014-10-24 09:50:07	2015-02-05 18:52:07
23135	MEMBRE	2014-10-23 00:00:00	2015-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	21079	\N	2014-10-24 09:50:45	2015-01-19 14:15:29
23136	MEMBRE	2014-10-23 00:00:00	2015-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	21080	\N	2014-10-24 09:50:45	2015-03-19 10:03:17
23137	MEMBRE	2014-10-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21081	\N	2014-10-24 09:50:45	\N
23138	MEMBRE	2014-10-23 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21082	\N	2014-10-24 09:50:45	2015-01-06 16:27:05
23139	MEMBRE	2014-10-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21083	\N	2014-10-24 09:50:45	\N
23140	MEMBRE	2014-10-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21084	\N	2014-10-24 09:50:45	\N
23141	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21085	\N	2014-10-24 09:51:24	\N
23142	MEMBRE	2014-10-21 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	21086	\N	2014-10-24 09:51:24	2015-02-13 17:03:25
23143	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21087	\N	2014-10-24 09:51:24	\N
23144	MEMBRE	2014-10-21 00:00:00	2015-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	21088	\N	2014-10-24 09:51:24	2015-03-19 10:02:27
23145	MEMBRE	2014-10-21 00:00:00	2015-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	21089	\N	2014-10-24 09:51:24	2015-02-17 09:41:40
23146	MEMBRE	2014-10-21 00:00:00	2015-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	21090	\N	2014-10-24 09:51:24	2015-02-09 11:03:55
23910	MEMBRE	2014-10-29 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	21821	\N	2014-10-31 09:26:52	2015-02-03 16:19:40
23911	MEMBRE	2014-10-29 00:00:00	2015-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	21822	\N	2014-10-31 09:26:52	2015-01-27 16:28:39
23912	MEMBRE	2014-10-29 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21823	\N	2014-10-31 09:26:52	2015-01-06 17:54:48
23913	MEMBRE	2014-10-29 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	21824	\N	2014-10-31 09:26:53	2016-12-12 16:10:15
23914	MEMBRE	2014-10-29 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	21825	\N	2014-10-31 09:26:53	2015-02-19 18:03:45
23915	MEMBRE	2014-10-29 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	21826	\N	2014-10-31 09:26:53	2016-12-12 16:10:15
23916	MEMBRE	2014-10-29 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	21827	\N	2014-10-31 09:26:53	2016-12-12 16:10:15
23917	MEMBRE	2014-10-29 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	21828	\N	2014-10-31 09:26:53	2015-02-03 13:59:33
23918	MEMBRE	2014-10-29 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	21829	\N	2014-10-31 09:26:53	2015-02-13 14:19:17
23920	MEMBRE	2014-10-29 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	21831	\N	2014-10-31 09:26:53	2015-02-13 11:34:06
23922	MEMBRE	2014-10-29 00:00:00	2015-03-19 00:00:00	ANCIEN	\N	\N	\N	\N	21833	\N	2014-10-31 09:26:53	2015-03-20 09:52:56
23923	MEMBRE	2014-10-29 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	21834	\N	2014-10-31 09:26:53	2016-12-12 16:10:15
29402	MEMBRE	2017-12-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25744	\N	\N	\N
23924	MEMBRE	2014-10-29 00:00:00	2015-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	21835	\N	2014-10-31 09:26:53	2015-03-06 09:53:34
23925	MEMBRE	2014-10-29 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	21836	\N	2014-10-31 09:26:53	2016-12-12 16:10:15
23926	MEMBRE	2014-10-29 00:00:00	2015-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	21837	\N	2014-10-31 09:26:53	2015-01-28 10:26:26
23927	MEMBRE	2014-10-29 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	21838	\N	2014-10-31 09:26:53	2016-12-12 16:10:15
23928	MEMBRE	2014-10-29 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	21839	\N	2014-10-31 09:26:53	2016-12-12 16:10:15
23929	MEMBRE	2014-10-29 00:00:00	2015-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	21840	\N	2014-10-31 09:26:53	2015-02-09 15:42:28
23930	MEMBRE	2014-10-29 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	21841	\N	2014-10-31 09:26:53	2016-12-12 16:10:15
23931	MEMBRE	2014-10-29 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	21842	\N	2014-10-31 09:26:53	2015-02-11 16:39:28
23932	MEMBRE	2014-10-29 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21843	\N	2014-10-31 09:26:53	2015-01-06 15:54:41
23933	MEMBRE	2014-10-29 00:00:00	2015-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	21844	\N	2014-10-31 09:26:53	2015-01-28 10:27:27
23934	MEMBRE	2014-10-29 00:00:00	2015-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	21845	\N	2014-10-31 09:26:53	2015-02-16 17:42:35
23935	MEMBRE	2014-10-29 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	21846	\N	2014-10-31 09:26:54	2015-02-05 19:02:50
23936	MEMBRE	2014-10-29 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21847	\N	2014-10-31 09:26:54	2015-01-06 15:25:32
23937	MEMBRE	2014-10-30 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	21848	\N	2014-10-31 09:28:53	2015-02-20 10:51:52
23938	MEMBRE	2014-10-30 00:00:00	2015-03-19 00:00:00	ANCIEN	\N	\N	\N	\N	21849	\N	2014-10-31 09:28:53	2015-03-20 11:38:36
23939	MEMBRE	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	21850	\N	2014-10-31 09:28:53	2016-03-11 18:02:51
23940	MEMBRE	2014-10-30 00:00:00	2015-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	21851	\N	2014-10-31 09:28:53	2015-01-19 14:16:02
23941	MEMBRE	2014-10-30 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	21852	\N	2014-10-31 09:28:53	2015-02-13 09:50:36
23942	MEMBRE	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	21853	\N	2014-10-31 09:28:53	2016-03-11 18:02:51
23943	MEMBRE	2014-10-30 00:00:00	2015-08-30 00:00:00	ANCIEN	\N	\N	\N	\N	21854	\N	2014-10-31 09:28:53	2015-08-31 09:34:17
23945	MEMBRE	2014-10-30 00:00:00	2015-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	21856	\N	2014-10-31 09:28:53	2015-03-04 10:26:00
23946	MEMBRE	2014-10-30 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	21857	\N	2014-10-31 09:28:53	2015-02-13 14:19:49
23947	MEMBRE	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	21858	\N	2014-10-31 09:28:53	2016-03-11 18:02:51
23948	MEMBRE	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	21859	\N	2014-10-31 09:28:53	2016-03-11 18:02:51
23950	MEMBRE	2014-10-30 00:00:00	2015-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	21861	\N	2014-10-31 09:28:53	2015-03-19 09:57:38
23951	MEMBRE	2014-10-30 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	21862	\N	2014-10-31 09:28:53	2015-02-13 10:34:56
23952	MEMBRE	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	21863	\N	2014-10-31 09:28:53	2016-03-11 18:02:51
23953	MEMBRE	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	21864	\N	2014-10-31 09:28:53	2016-03-11 18:02:51
23954	MEMBRE	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	21865	\N	2014-10-31 09:28:53	2016-03-11 18:02:51
23956	MEMBRE	2014-10-30 00:00:00	2015-03-09 00:00:00	ANCIEN	\N	\N	\N	\N	21867	\N	2014-10-31 09:28:53	2015-03-10 10:01:33
23958	MEMBRE	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	21869	\N	2014-10-31 09:28:53	2016-03-11 18:02:51
23959	MEMBRE	2014-10-30 00:00:00	2015-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	21870	\N	2014-10-31 09:28:53	2015-02-02 14:59:17
23960	MEMBRE	2014-10-30 00:00:00	2015-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	21871	\N	2014-10-31 09:28:54	2015-02-09 15:45:30
23961	MEMBRE	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	21872	\N	2014-10-31 09:28:54	2016-03-11 18:02:51
23962	MEMBRE	2014-10-30 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21873	\N	2014-10-31 09:28:54	2015-01-06 16:18:04
23963	MEMBRE	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	21874	\N	2014-10-31 09:28:54	2016-03-11 18:02:51
23964	MEMBRE	2014-10-30 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	21875	\N	2014-10-31 09:28:54	2015-02-11 16:39:42
23965	MEMBRE	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	21876	\N	2014-10-31 09:28:54	2016-03-11 18:02:51
23966	MEMBRE	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	21877	\N	2014-10-31 09:28:54	2016-03-11 18:02:51
23967	MEMBRE	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	21878	\N	2014-10-31 09:28:54	2016-03-11 18:02:51
23968	MEMBRE	2014-10-30 00:00:00	2015-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	21879	\N	2014-10-31 09:28:54	2015-02-16 17:42:03
23969	MEMBRE	2014-10-30 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	21880	\N	2014-10-31 09:28:54	2015-02-05 19:00:40
23970	MEMBRE	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	21881	\N	2014-10-31 09:28:54	2016-03-11 18:02:51
23971	MEMBRE	2014-10-30 00:00:00	2015-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	21882	\N	2014-10-31 09:28:54	2015-03-11 12:57:44
23973	MEMBRE	2014-10-30 00:00:00	2015-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	21884	\N	2014-10-31 09:28:54	2015-02-04 17:40:00
23974	MEMBRE	2014-10-30 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	21885	\N	2014-10-31 09:28:54	2015-02-11 17:18:45
24082	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21993	\N	2014-11-03 09:17:33	\N
24083	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21994	\N	2014-11-03 09:17:33	\N
24084	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21995	\N	2014-11-03 09:17:33	\N
24085	MEMBRE	2014-10-31 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	21996	\N	2014-11-03 09:33:45	2015-02-20 10:41:47
24086	MEMBRE	2014-10-31 00:00:00	2017-06-01 00:00:00	ANCIEN	\N	\N	\N	\N	21997	\N	2014-11-03 09:33:45	2017-06-02 10:02:57
24087	MEMBRE	2014-10-31 00:00:00	2017-06-01 00:00:00	ANCIEN	\N	\N	\N	\N	21998	\N	2014-11-03 09:33:45	2017-06-02 10:02:57
24089	MEMBRE	2014-10-31 00:00:00	2017-06-01 00:00:00	ANCIEN	\N	\N	\N	\N	22000	\N	2014-11-03 09:33:45	2017-06-02 10:02:57
24090	MEMBRE	2014-10-31 00:00:00	2017-06-01 00:00:00	ANCIEN	\N	\N	\N	\N	22001	\N	2014-11-03 09:33:45	2017-06-02 10:02:57
24091	MEMBRE	2014-10-31 00:00:00	2017-06-01 00:00:00	ANCIEN	\N	\N	\N	\N	22002	\N	2014-11-03 09:33:45	2017-06-02 10:02:57
24093	MEMBRE	2014-10-31 00:00:00	2017-06-01 00:00:00	ANCIEN	\N	\N	\N	\N	22004	\N	2014-11-03 09:33:46	2017-06-02 10:02:57
26209	MEMBRE	2015-03-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23159	\N	2015-03-12 09:58:42	\N
26388	MEMBRE	2015-03-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	23234	\N	\N	\N
27020	MEMBRE	2016-06-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23718	\N	2016-06-29 17:11:49	\N
29812	MEMBRE	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25980	\N	2018-01-22 16:47:22	\N
27196	MEMBRE	2017-07-06 00:00:00	2017-08-01 00:00:00	ANCIEN	\N	\N	\N	\N	23862	\N	2017-07-06 17:50:34	2017-08-02 09:51:07
27537	MEMBRE	2017-10-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24104	\N	2017-10-17 11:05:25	\N
27538	MEMBRE	2017-10-16 00:00:00	2018-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	24105	\N	2017-10-17 11:05:25	2018-01-26 10:16:26
27539	MEMBRE	2017-10-16 00:00:00	2018-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	24106	\N	2017-10-17 11:05:25	2018-02-02 17:41:17
27540	MEMBRE	2017-10-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24107	\N	2017-10-17 11:05:25	\N
27541	MEMBRE	2017-10-16 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	24108	\N	2017-10-17 11:05:25	2017-12-20 18:00:12
27542	MEMBRE	2017-10-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24109	\N	2017-10-17 11:05:25	\N
27543	MEMBRE	2017-10-16 00:00:00	2018-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	24110	\N	2017-10-17 11:05:25	2018-02-01 17:48:29
27544	MEMBRE	2017-10-10 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	24111	\N	2017-10-17 11:05:49	2018-02-07 17:30:34
27545	MEMBRE	2017-10-10 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	24112	\N	2017-10-17 11:05:49	2018-02-07 16:34:25
27546	MEMBRE	2017-10-10 00:00:00	2018-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	24113	\N	2017-10-17 11:05:49	2018-02-14 18:31:38
27547	MEMBRE	2017-10-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24114	\N	2017-10-17 11:06:12	\N
27548	MEMBRE	2017-10-10 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	24115	\N	2017-10-17 11:06:12	2017-12-20 12:21:28
27550	MEMBRE	2017-10-11 00:00:00	2017-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	24117	\N	2017-10-17 11:08:45	2017-12-05 10:09:16
27551	MEMBRE	2017-10-11 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24118	\N	2017-10-17 11:08:45	\N
27552	MEMBRE	2017-10-11 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24119	\N	2017-10-17 11:08:45	\N
27553	MEMBRE	2017-10-11 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24120	\N	2017-10-17 11:08:45	\N
27554	MEMBRE	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24121	\N	2017-10-17 11:09:19	\N
27555	MEMBRE	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24122	\N	2017-10-17 11:09:19	\N
27556	MEMBRE	2017-10-12 00:00:00	2017-12-05 00:00:00	ANCIEN	\N	\N	\N	\N	24123	\N	2017-10-17 11:10:05	2017-12-06 15:19:10
27557	MEMBRE	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24124	\N	2017-10-17 11:16:57	\N
27558	MEMBRE	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24125	\N	2017-10-17 11:17:24	\N
27559	MEMBRE	2017-10-12 00:00:00	2017-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	24126	\N	2017-10-17 11:17:24	2017-11-30 16:09:18
27560	MEMBRE	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24127	\N	2017-10-17 11:17:24	\N
27561	MEMBRE	2017-10-10 00:00:00	2018-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	24128	\N	2017-10-17 11:17:55	2018-02-12 10:01:19
27562	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24129	\N	2017-10-17 11:17:55	\N
27563	MEMBRE	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24130	\N	2017-10-17 11:18:42	\N
27564	MEMBRE	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24131	\N	2017-10-17 11:18:42	\N
27565	MEMBRE	2017-10-11 00:00:00	2018-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	24132	\N	2017-10-17 11:18:42	2018-01-17 11:30:21
27566	MEMBRE	2017-10-11 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	24133	\N	2017-10-17 11:18:42	2018-01-25 15:54:56
27567	MEMBRE	2017-10-11 00:00:00	2018-03-07 00:00:00	ANCIEN	\N	\N	\N	\N	24134	\N	2017-10-17 11:18:42	2018-03-08 17:17:39
27568	MEMBRE	2017-10-11 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	24135	\N	2017-10-17 11:18:42	2018-02-07 16:33:35
27569	MEMBRE	2017-10-11 00:00:00	2018-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	24136	\N	2017-10-17 11:18:42	2018-01-30 12:30:11
27570	MEMBRE	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24137	\N	2017-10-17 11:18:42	\N
27571	MEMBRE	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24138	\N	2017-10-17 11:18:42	\N
27572	MEMBRE	2017-10-11 00:00:00	2017-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	24139	\N	2017-10-17 11:18:42	2017-12-01 14:51:02
27573	MEMBRE	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24140	\N	2017-10-17 11:18:42	\N
27574	MEMBRE	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24141	\N	2017-10-17 11:18:42	\N
27575	MEMBRE	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24142	\N	2017-10-17 11:18:42	\N
27576	MEMBRE	2017-10-11 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24143	\N	2017-10-17 11:18:42	2018-01-24 10:52:25
27577	MEMBRE	2017-10-10 00:00:00	2017-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	24144	\N	2017-10-17 11:19:04	2017-11-28 17:02:56
27578	MEMBRE	2017-10-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24145	\N	2017-10-17 11:19:37	\N
27579	MEMBRE	2017-10-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24146	\N	2017-10-17 11:19:37	\N
27580	MEMBRE	2017-10-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24147	\N	2017-10-17 11:19:37	\N
27581	MEMBRE	2017-10-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24148	\N	2017-10-17 11:19:37	\N
27582	MEMBRE	2017-10-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24149	\N	2017-10-17 11:19:37	\N
27583	MEMBRE	2017-10-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24150	\N	2017-10-17 11:19:37	\N
27584	MEMBRE	2017-10-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24151	\N	2017-10-17 11:19:37	\N
27585	MEMBRE	2017-10-11 00:00:00	2020-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	24152	\N	2017-10-17 11:20:35	\N
27586	MEMBRE	2017-10-11 00:00:00	2020-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	24153	\N	2017-10-17 11:20:35	\N
27587	MEMBRE	2017-10-11 00:00:00	2020-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	24154	\N	2017-10-17 11:20:35	\N
27588	MEMBRE	2017-10-11 00:00:00	2020-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	24155	\N	2017-10-17 11:20:35	\N
27589	MEMBRE	2017-10-11 00:00:00	2017-12-05 00:00:00	ANCIEN	\N	\N	\N	\N	24156	\N	2017-10-17 11:20:35	2017-12-06 15:15:02
27590	MEMBRE	2017-10-11 00:00:00	2020-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	24157	\N	2017-10-17 11:20:35	\N
27591	MEMBRE	2017-10-11 00:00:00	2020-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	24158	\N	2017-10-17 11:20:35	\N
27592	MEMBRE	2017-10-11 00:00:00	2020-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	24159	\N	2017-10-17 11:20:35	\N
27593	MEMBRE	2017-10-11 00:00:00	2020-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	24160	\N	2017-10-17 11:20:35	\N
27594	MEMBRE	2017-10-11 00:00:00	2020-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	24161	\N	2017-10-17 11:20:35	\N
27595	MEMBRE	2017-10-11 00:00:00	2020-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	24162	\N	2017-10-17 11:20:36	\N
27596	MEMBRE	2017-10-11 00:00:00	2020-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	24163	\N	2017-10-17 11:20:36	\N
27597	MEMBRE	2017-10-11 00:00:00	2020-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	24164	\N	2017-10-17 11:20:36	\N
27598	MEMBRE	2017-10-11 00:00:00	2020-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	24165	\N	2017-10-17 11:20:36	\N
27599	MEMBRE	2017-10-11 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24166	\N	2017-10-17 11:21:03	2018-01-24 15:53:28
27600	MEMBRE	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24167	\N	2017-10-17 11:21:03	\N
27601	MEMBRE	2017-10-11 00:00:00	2018-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	24168	\N	2017-10-17 11:21:03	2018-01-26 09:58:25
27602	MEMBRE	2017-10-11 00:00:00	2018-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	24169	\N	2017-10-17 11:28:37	2018-01-16 19:09:26
27603	MEMBRE	2017-10-11 00:00:00	2018-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	24170	\N	2017-10-17 11:28:37	2018-02-12 15:24:50
27604	MEMBRE	2017-10-11 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	24171	\N	2017-10-17 11:28:37	2018-01-18 16:41:16
27605	MEMBRE	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24172	\N	2017-10-17 11:28:37	\N
27606	MEMBRE	2017-10-11 00:00:00	2018-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	24173	\N	2017-10-17 11:28:37	2018-01-16 18:57:50
27607	MEMBRE	2017-10-11 00:00:00	2017-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	24174	\N	2017-10-17 11:28:37	2017-12-05 10:04:56
27608	MEMBRE	2017-10-12 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	24175	\N	2017-10-17 11:30:25	2018-02-07 15:31:44
27609	MEMBRE	2017-10-12 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24176	\N	2017-10-17 11:30:25	2018-01-24 18:09:22
27610	MEMBRE	2017-10-12 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	24177	\N	2017-10-17 11:30:25	2018-01-31 16:17:41
27611	MEMBRE	2017-10-12 00:00:00	2018-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	24178	\N	2017-10-17 11:30:25	2018-01-26 10:08:48
27612	MEMBRE	2017-10-12 00:00:00	2018-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	24179	\N	2017-10-17 11:30:25	2018-02-05 10:00:23
27613	MEMBRE	2017-10-12 00:00:00	2018-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	24180	\N	2017-10-17 11:30:25	2018-01-29 16:17:21
27614	MEMBRE	2017-10-12 00:00:00	2018-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	24181	\N	2017-10-17 11:30:25	2018-02-12 09:31:29
27615	MEMBRE	2017-10-12 00:00:00	2017-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	24182	\N	2017-10-17 11:30:25	2017-11-27 16:36:56
27616	MEMBRE	2017-10-12 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24183	\N	2017-10-17 11:30:25	2018-01-24 11:14:31
27617	MEMBRE	2017-10-12 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24184	\N	2017-10-17 11:30:25	2018-01-24 10:52:58
27618	MEMBRE	2017-10-12 00:00:00	2018-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	24185	\N	2017-10-17 11:30:25	2018-02-06 16:27:53
27619	MEMBRE	2017-10-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24186	\N	2017-10-17 11:30:51	\N
27620	MEMBRE	2017-10-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24187	\N	2017-10-17 11:30:51	\N
27621	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24188	\N	2017-10-17 11:31:36	\N
27622	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24189	\N	2017-10-17 11:31:36	\N
27623	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24190	\N	2017-10-17 11:31:36	\N
27624	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24191	\N	2017-10-17 11:31:36	\N
27625	MEMBRE	2017-10-10 00:00:00	2017-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	24192	\N	2017-10-17 11:32:04	2017-12-05 10:07:25
27626	MEMBRE	2017-10-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24193	\N	2017-10-17 11:32:04	\N
27627	MEMBRE	2017-10-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24194	\N	2017-10-17 11:32:04	\N
27628	MEMBRE	2017-10-11 00:00:00	2017-12-05 00:00:00	ANCIEN	\N	\N	\N	\N	24195	\N	2017-10-17 11:32:32	2017-12-06 15:14:00
27629	MEMBRE	2017-10-06 00:00:00	2018-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	24196	\N	2017-10-17 11:34:29	2018-02-01 18:32:33
27630	MEMBRE	2017-10-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24197	\N	2017-10-17 11:34:29	\N
27631	MEMBRE	2017-10-06 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24198	\N	2017-10-17 11:34:29	2018-01-24 11:15:28
27632	MEMBRE	2017-10-06 00:00:00	2018-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	24199	\N	2017-10-17 11:34:29	2018-01-29 17:07:02
29813	MEMBRE	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25981	\N	2018-01-22 16:49:04	\N
22386	MEMBRE	2014-10-14 00:00:00	2015-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	20330	\N	2014-10-14 18:31:30	2015-02-09 11:03:03
22387	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20331	\N	2014-10-14 18:31:30	\N
22388	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20332	\N	2014-10-14 18:31:30	\N
22389	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20333	\N	2014-10-14 18:31:31	\N
22812	MEMBRE	2014-10-17 00:00:00	2017-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	20756	\N	2014-10-22 16:34:14	2017-07-20 14:38:34
22813	MEMBRE	2014-10-17 00:00:00	2015-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	20757	\N	2014-10-22 16:34:14	2015-02-17 09:39:34
22814	MEMBRE	2014-10-17 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	20758	\N	2014-10-22 16:34:14	2015-01-06 15:20:49
22815	MEMBRE	2014-10-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20759	\N	2014-10-22 16:34:14	\N
22816	MEMBRE	2014-10-17 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	20760	\N	2014-10-22 16:34:14	2015-02-13 15:13:51
22817	MEMBRE	2014-10-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20761	\N	2014-10-22 16:34:14	\N
22818	MEMBRE	2014-10-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20762	\N	2014-10-22 16:34:14	\N
22819	MEMBRE	2014-10-17 00:00:00	2015-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	20763	\N	2014-10-22 16:34:14	2015-02-09 15:41:40
22820	MEMBRE	2014-10-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20764	\N	2014-10-22 16:34:14	\N
22821	MEMBRE	2014-10-17 00:00:00	2015-03-19 00:00:00	ANCIEN	\N	\N	\N	\N	20765	\N	2014-10-22 16:34:14	2015-03-20 09:52:43
22822	MEMBRE	2014-10-17 00:00:00	2015-08-30 00:00:00	ANCIEN	\N	\N	\N	\N	20766	\N	2014-10-22 16:34:14	2015-08-31 09:59:31
22823	MEMBRE	2014-10-17 00:00:00	2015-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	20767	\N	2014-10-22 16:34:14	2015-03-19 10:03:35
22824	MEMBRE	2014-10-21 00:00:00	2015-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	20768	\N	2014-10-22 16:36:52	2015-01-29 10:53:35
22825	MEMBRE	2014-10-21 00:00:00	2015-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	20769	\N	2014-10-22 16:36:52	2015-02-04 14:27:33
22827	MEMBRE	2014-10-22 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	20771	\N	2014-10-22 16:40:05	2015-02-19 17:24:12
22828	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20772	\N	2014-10-22 16:40:05	\N
22829	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20773	\N	2014-10-22 16:40:06	\N
22830	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20774	\N	2014-10-22 16:40:06	\N
22831	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20775	\N	2014-10-22 16:40:06	\N
22832	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20776	\N	2014-10-22 16:40:06	\N
22833	MEMBRE	2014-10-22 00:00:00	2015-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	20777	\N	2014-10-22 16:40:06	2015-01-14 10:10:28
22834	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20778	\N	2014-10-22 16:40:06	\N
22835	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20779	\N	2014-10-22 16:40:06	\N
22836	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20780	\N	2014-10-22 16:40:06	\N
22837	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20781	\N	2014-10-22 16:40:06	\N
24683	MEMBRE	2015-01-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22416	\N	2015-01-21 12:00:49	\N
24684	MEMBRE	2015-01-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22417	\N	2015-01-21 12:01:06	\N
24685	MEMBRE	2015-01-20 00:00:00	2015-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	22418	\N	2015-01-21 12:01:06	2015-02-02 10:47:42
24686	MEMBRE	2015-01-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22419	\N	2015-01-21 12:01:25	\N
24953	MEMBRE	2015-02-04 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22512	\N	2015-02-04 14:27:33	\N
24957	MEMBRE	2015-02-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22514	\N	2015-02-04 15:15:36	\N
24958	MEMBRE	2015-02-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22515	\N	2015-02-04 15:15:57	\N
25688	MEMBRE	2014-10-01 00:00:00	2015-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	22871	\N	\N	\N
25727	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22909	\N	\N	\N
25728	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22910	\N	\N	\N
25741	SECRET	2015-02-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22590	\N	\N	\N
25742	SECRET	2015-02-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22552	\N	\N	\N
26735	PDT	2015-06-04 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	23454	\N	2016-02-11 18:02:43	2016-02-12 11:47:35
27163	MEMBRE	2017-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23832	\N	\N	\N
27365	MEMBRE	2017-10-10 00:00:00	2017-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	23932	\N	2017-10-11 10:22:19	2017-11-30 16:14:17
27366	MEMBRE	2017-10-10 00:00:00	2018-03-07 00:00:00	ANCIEN	\N	\N	\N	\N	23933	\N	2017-10-11 10:22:19	2018-03-08 17:17:53
27367	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23934	\N	2017-10-11 10:22:19	\N
27368	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23935	\N	2017-10-11 10:24:08	\N
27369	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23936	\N	2017-10-11 10:24:08	\N
27370	MEMBRE	2017-10-10 00:00:00	2017-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	23937	\N	2017-10-11 10:24:08	2017-12-19 18:06:30
27371	MEMBRE	2017-10-10 00:00:00	2018-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	23938	\N	2017-10-11 10:25:00	2018-02-12 10:03:10
27372	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23939	\N	2017-10-11 10:25:00	\N
27373	MEMBRE	2017-10-10 00:00:00	2018-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	23940	\N	2017-10-11 10:25:00	2018-02-12 09:30:28
27374	MEMBRE	2017-10-10 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	23941	\N	2017-10-11 10:25:00	2018-01-24 10:52:51
27375	MEMBRE	2017-10-09 00:00:00	2018-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	23942	\N	2017-10-11 10:27:03	2018-02-06 16:27:46
27376	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23943	\N	2017-10-11 10:27:03	\N
27377	MEMBRE	2017-10-09 00:00:00	2018-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	23944	\N	2017-10-11 10:27:04	2018-02-08 14:37:24
27378	MEMBRE	2017-10-09 00:00:00	2018-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	23945	\N	2017-10-11 10:27:04	2018-02-08 17:36:10
27379	MEMBRE	2017-10-09 00:00:00	2017-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	23946	\N	2017-10-11 10:27:04	2017-12-14 18:21:44
27380	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23947	\N	2017-10-11 10:27:04	\N
27381	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23948	\N	2017-10-11 10:27:04	\N
27382	MEMBRE	2017-10-09 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	23949	\N	2017-10-11 10:27:57	2018-01-24 18:30:11
27383	MEMBRE	2017-10-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23950	\N	2017-10-11 10:27:57	\N
27384	MEMBRE	2017-10-09 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	23951	\N	2017-10-11 10:27:57	2018-01-24 10:52:44
28104	MEMBRE	2017-10-24 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	24671	\N	2017-10-26 09:48:40	2018-01-25 17:36:45
28105	MEMBRE	2017-10-24 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	24672	\N	2017-10-26 09:48:40	2018-01-31 16:17:30
28106	MEMBRE	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24673	\N	2017-10-26 09:49:28	\N
28107	MEMBRE	2017-10-24 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	24674	\N	2017-10-26 09:49:28	2018-01-18 11:22:45
28108	MEMBRE	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24675	\N	2017-10-26 10:01:17	\N
28109	MEMBRE	2017-10-24 00:00:00	2018-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	24676	\N	2017-10-26 10:01:17	2018-01-29 16:17:12
28110	MEMBRE	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24677	\N	2017-10-26 10:01:17	\N
28111	MEMBRE	2017-10-24 00:00:00	2018-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	24678	\N	2017-10-26 10:01:17	2018-01-16 19:08:16
28112	MEMBRE	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24679	\N	2017-10-26 10:01:17	\N
28113	MEMBRE	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24680	\N	2017-10-26 10:01:17	\N
28114	MEMBRE	2017-10-24 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	24681	\N	2017-10-26 10:01:17	2018-02-07 15:32:46
28115	MEMBRE	2017-10-24 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	24682	\N	2017-10-26 10:02:03	\N
28116	MEMBRE	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24683	\N	2017-10-26 10:02:03	\N
28117	MEMBRE	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24684	\N	2017-10-26 10:02:03	\N
28118	MEMBRE	2017-10-24 00:00:00	2018-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	24685	\N	2017-10-26 10:02:03	2018-01-26 16:17:28
28119	MEMBRE	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24686	\N	2017-10-26 10:02:03	\N
28120	MEMBRE	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24687	\N	2017-10-26 10:02:03	\N
28121	MEMBRE	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24688	\N	2017-10-26 10:02:03	\N
28122	MEMBRE	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24689	\N	2017-10-26 10:02:03	\N
28123	MEMBRE	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24690	\N	2017-10-26 10:43:49	\N
28124	MEMBRE	2017-10-26 00:00:00	2018-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	24691	\N	2017-10-26 11:01:31	2018-02-01 18:32:25
28688	MEMBRE	2017-11-14 00:00:00	2018-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	25255	\N	2017-11-15 09:29:38	2018-02-08 15:51:53
28689	MEMBRE	2017-11-10 00:00:00	2017-12-26 00:00:00	ANCIEN	\N	\N	\N	\N	25256	\N	2017-11-15 09:31:38	2017-12-27 11:11:01
28690	MEMBRE	2017-11-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25257	\N	2017-11-15 09:31:53	\N
28691	MEMBRE	2017-11-13 00:00:00	2017-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	25258	\N	2017-11-15 09:32:13	2017-11-30 16:48:21
28692	MEMBRE	2017-11-14 00:00:00	2018-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	25259	\N	2017-11-15 09:32:34	2018-01-26 10:35:37
28975	PDT	2017-11-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25006	\N	2017-11-30 11:14:55	\N
28976	PDT	2017-11-30 00:00:00	2018-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	25101	\N	2017-11-30 11:15:25	\N
28977	PDT	2017-11-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25051	\N	2017-11-30 11:15:49	\N
28978	PDT	2017-11-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24740	\N	2017-11-30 11:16:17	\N
28979	PDT	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25454	\N	2017-11-30 11:16:39	\N
29384	MEMBRE	2017-12-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	25726	\N	\N	\N
29385	MEMBRE	2017-12-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	25727	\N	\N	\N
29387	MEMBRE	2017-12-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25729	\N	\N	\N
29388	MEMBRE	2017-12-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	25730	\N	\N	\N
29389	MEMBRE	2017-12-07 00:00:00	2018-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	25731	\N	\N	\N
29390	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25732	\N	\N	\N
29391	MEMBRE	2017-10-01 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	25733	\N	\N	\N
29392	MEMBRE	2017-10-01 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	25734	\N	\N	\N
29393	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25735	\N	\N	\N
29394	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25736	\N	\N	\N
29395	MEMBRE	2017-12-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	25737	\N	\N	\N
29396	MEMBRE	2017-12-07 00:00:00	2018-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	25738	\N	\N	\N
29397	MEMBRE	2017-12-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	25739	\N	\N	\N
29398	MEMBRE	2017-12-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	25740	\N	\N	\N
29399	MEMBRE	2017-12-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25741	\N	\N	\N
29400	MEMBRE	2017-12-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	25742	\N	\N	\N
25264	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22546	\N	\N	\N
25279	MEMBRE	2014-10-01 00:00:00	2014-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22561	\N	\N	\N
25290	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22572	\N	\N	\N
25311	MEMBRE	2014-10-01 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	22593	\N	\N	\N
25325	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22607	\N	\N	\N
25326	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22608	\N	\N	\N
25327	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22609	\N	\N	\N
25328	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22610	\N	\N	\N
25329	MEMBRE	2014-10-01 00:00:00	2014-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22611	\N	\N	\N
25330	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22612	\N	\N	2017-09-24 17:29:37
25331	MEMBRE	2014-10-01 00:00:00	2015-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	22613	\N	\N	\N
25333	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22615	\N	\N	2017-09-24 16:45:26
25334	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22616	\N	\N	\N
25336	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22618	\N	\N	\N
25338	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22620	\N	\N	\N
25339	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22621	\N	\N	\N
25340	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22622	\N	\N	2017-09-24 17:15:15
25341	MEMBRE	2014-10-01 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	22623	\N	\N	2015-06-12 15:59:18
25725	MEMBRE	2015-02-19 00:00:00	2015-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	22908	\N	2015-02-19 14:12:32	2015-03-11 10:57:52
27978	MEMBRE	2017-10-23 00:00:00	2018-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	24545	\N	2017-10-24 17:07:20	2018-01-30 16:00:54
27979	MEMBRE	2017-10-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24546	\N	2017-10-24 17:07:20	\N
27980	MEMBRE	2017-10-23 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24547	\N	2017-10-24 17:07:20	2018-01-24 17:09:53
27981	MEMBRE	2017-10-23 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24548	\N	2017-10-24 17:07:20	2018-01-24 15:03:41
28550	MEMBRE	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25117	\N	2017-11-07 17:21:01	\N
28551	MEMBRE	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25118	\N	2017-11-07 17:21:01	\N
28960	MEMBRE	2017-11-29 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	25493	\N	2017-11-29 17:52:46	\N
28961	MEMBRE	2017-11-28 00:00:00	2018-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	25494	\N	2017-11-29 17:53:01	2018-02-01 18:31:17
28962	MEMBRE	2017-11-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25495	\N	2017-11-29 17:53:01	\N
28963	MEMBRE	2017-11-29 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	25496	\N	2017-11-29 17:53:57	2018-01-31 10:03:12
28964	MEMBRE	2017-11-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25497	\N	2017-11-29 17:54:19	\N
29029	PDT	2017-12-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25228	\N	2017-12-01 14:51:54	\N
29030	PDT	2017-12-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24218	\N	2017-12-01 14:52:26	\N
29031	PDTDEL	2017-12-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	Guyana	\N	24585	\N	2017-12-01 14:55:26	2017-12-01 14:56:14
29032	PDTDEL	2017-12-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	Malawi	\N	25217	\N	2017-12-01 14:56:54	2017-12-01 14:57:03
29033	PDTDEL	2017-12-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	Paraguay	\N	25226	\N	2017-12-01 14:57:40	2017-12-01 14:57:49
29034	PDTDEL	2017-12-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Surinam	\N	25109	\N	2017-12-01 14:58:59	2017-12-01 14:59:08
29037	MEMBRE	2017-11-30 00:00:00	2017-12-26 00:00:00	ANCIEN	\N	\N	\N	\N	25528	\N	2017-12-04 09:34:28	2017-12-27 11:00:05
29044	PDT	2017-12-04 00:00:00	2018-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	24078	\N	2017-12-04 18:47:59	\N
29070	PDT	2017-12-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23981	\N	2017-12-05 16:09:22	\N
29071	PDTDEL	2017-12-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Argentine	\N	25107	\N	2017-12-05 16:35:32	2017-12-05 16:38:50
29072	PDTDEL	2017-12-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Arabie saoudite	\N	24027	\N	2017-12-05 16:37:14	2017-12-05 16:38:23
29073	PDTDEL	2017-12-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Mali	\N	24371	\N	2017-12-05 16:39:13	2017-12-05 16:40:33
29074	PDTDEL	2017-12-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Tanzanie	\N	24867	\N	2017-12-05 16:40:56	2017-12-05 16:41:36
29075	MEMBRE	2017-11-30 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	25543	\N	2017-12-05 17:31:41	2018-02-07 17:31:01
29076	MEMBRE	2017-12-01 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	25544	\N	2017-12-05 17:31:56	2018-01-25 10:58:58
29077	MEMBRE	2017-12-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25545	\N	2017-12-05 17:39:31	\N
29078	MEMBRE	2017-12-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25546	\N	2017-12-05 17:39:31	\N
29086	MEMBRE	2017-12-05 00:00:00	2018-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	25554	\N	2017-12-06 14:41:24	2018-02-08 14:37:17
29087	PDT	2017-12-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24650	\N	2017-12-06 15:08:46	\N
29088	PDT	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24001	\N	2017-12-06 15:09:11	\N
29089	PDT	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24394	\N	2017-12-06 15:09:38	\N
29102	MEMBRE	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25555	\N	2017-12-07 09:33:29	\N
29103	MEMBRE	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25556	\N	2017-12-07 09:34:45	\N
29104	MEMBRE	2017-12-06 00:00:00	2018-12-30 00:00:00	ANCIEN	\N	\N	\N	\N	25557	\N	2017-12-07 09:35:05	\N
29105	MEMBRE	2017-11-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25558	\N	2017-12-07 09:35:22	\N
29106	MEMBRE	2017-12-06 00:00:00	2017-12-21 00:00:00	ANCIEN	\N	\N	\N	\N	25559	\N	2017-12-07 09:35:47	2017-12-22 12:21:20
29107	MEMBRE	2017-12-06 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	25560	\N	2017-12-07 09:35:47	2017-12-20 14:34:33
29108	MEMBRE	2017-12-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25561	\N	2017-12-07 10:19:15	\N
29109	PDT	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24847	\N	2017-12-07 14:56:37	\N
29110	PDT	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24424	\N	2017-12-07 14:57:08	\N
29111	PDTDEL	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Bolivie	\N	24835	\N	2017-12-07 14:58:40	2017-12-07 14:58:54
29112	PDTDEL	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Comores	\N	25086	\N	2017-12-07 15:00:00	2017-12-07 15:00:11
29113	PDTDEL	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Danemark	\N	24976	\N	2017-12-07 15:00:43	2017-12-07 15:00:56
29114	PDTDEL	2017-12-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	Uruguay	\N	25149	\N	2017-12-07 15:02:05	2017-12-07 15:02:32
29115	MEMBRE	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25562	\N	2017-12-07 16:10:25	\N
29116	MEMBRE	2017-12-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25563	\N	2017-12-07 16:10:50	\N
29117	MEMBRE	2017-11-30 00:00:00	2018-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	25564	\N	2017-12-07 16:11:14	2018-01-26 10:09:34
29118	MEMBRE	2017-12-06 00:00:00	2018-03-04 00:00:00	ANCIEN	\N	\N	\N	\N	25565	\N	2017-12-07 16:11:45	2018-03-05 17:19:18
29119	MEMBRE	2017-12-06 00:00:00	2017-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	25566	\N	2017-12-07 16:11:45	2017-12-14 18:21:53
29120	MEMBRE	2017-12-06 00:00:00	2018-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	25567	\N	2017-12-07 16:11:45	2018-01-26 16:18:11
29121	MEMBRE	2017-12-06 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	25568	\N	2017-12-07 16:11:45	2018-01-18 16:41:38
29122	MEMBRE	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25569	\N	2017-12-07 16:11:45	\N
29123	MEMBRE	2017-12-04 00:00:00	2018-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	25570	\N	2017-12-07 16:12:21	2018-02-14 18:34:12
29124	MEMBRE	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25571	\N	2017-12-07 16:17:41	\N
29125	MEMBRE	2017-12-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25572	\N	2017-12-07 16:18:19	\N
29126	MEMBRE	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25573	\N	2017-12-07 18:14:06	\N
29127	MEMBRE	2017-11-30 00:00:00	2018-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	25574	\N	2017-12-07 18:14:06	2018-02-12 09:30:35
29128	MEMBRE	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25575	\N	2017-12-07 18:14:06	\N
29129	MEMBRE	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25576	\N	2017-12-07 18:14:06	\N
29130	MEMBRE	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25577	\N	2017-12-07 18:14:06	\N
29131	MEMBRE	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25578	\N	2017-12-07 18:14:06	\N
29132	MEMBRE	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25579	\N	2017-12-07 18:14:06	\N
29133	MEMBRE	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25580	\N	2017-12-07 18:14:06	\N
29134	MEMBRE	2017-11-30 00:00:00	2017-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	25581	\N	2017-12-07 18:14:06	2017-12-13 17:53:52
29135	MEMBRE	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25582	\N	2017-12-07 18:14:06	\N
29136	MEMBRE	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25583	\N	2017-12-07 18:14:06	\N
29137	MEMBRE	2017-12-06 00:00:00	2020-02-27 00:00:00	ANCIEN	\N	\N	\N	\N	25584	\N	2017-12-07 18:22:18	\N
29138	MEMBRE	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25585	\N	2017-12-07 18:22:18	\N
29139	MEMBRE	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25586	\N	2017-12-07 18:22:18	\N
29140	MEMBRE	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25587	\N	2017-12-07 18:22:18	\N
29141	MEMBRE	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25588	\N	2017-12-07 18:22:18	\N
29142	MEMBRE	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25589	\N	2017-12-07 18:22:18	\N
29143	MEMBRE	2017-12-06 00:00:00	2018-03-04 00:00:00	ANCIEN	\N	\N	\N	\N	25590	\N	2017-12-07 18:22:18	2018-03-05 17:17:41
29144	MEMBRE	2017-12-06 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	25591	\N	2017-12-07 18:22:18	2018-02-07 12:15:24
29145	MEMBRE	2017-12-06 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	25592	\N	2017-12-07 18:22:18	2018-01-25 15:20:36
29146	MEMBRE	2017-12-06 00:00:00	2018-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	25593	\N	2017-12-07 18:22:18	2018-02-01 18:33:10
29147	MEMBRE	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25594	\N	2017-12-08 09:45:02	\N
29148	MEMBRE	2017-12-07 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	25595	\N	2017-12-08 09:45:02	2018-01-25 11:00:48
29149	MEMBRE	2017-12-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25596	\N	2017-12-08 09:45:37	\N
29150	MEMBRE	2017-12-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25597	\N	2017-12-08 09:45:37	\N
29185	MEMBRE	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25614	\N	2017-12-13 09:45:54	\N
29186	MEMBRE	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25615	\N	2017-12-13 09:46:12	\N
29187	MEMBRE	2017-12-04 00:00:00	2018-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	25616	\N	2017-12-13 09:46:57	2018-02-08 17:36:21
29188	MEMBRE	2017-12-12 00:00:00	2018-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	25617	\N	2017-12-13 09:47:31	2018-02-12 16:56:48
29189	MEMBRE	2017-12-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25618	\N	2017-12-13 09:47:51	\N
22826	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20770	\N	2014-10-22 16:39:52	\N
22838	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20782	\N	2014-10-22 16:46:22	\N
22839	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20783	\N	2014-10-22 16:46:22	\N
22840	MEMBRE	2014-10-22 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	20784	\N	2014-10-22 16:46:22	2015-02-20 12:00:46
22841	MEMBRE	2014-10-22 00:00:00	2015-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	20785	\N	2014-10-22 16:46:22	2015-02-09 11:04:08
22842	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20786	\N	2014-10-22 16:46:22	\N
22843	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20787	\N	2014-10-22 16:46:22	\N
22844	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20788	\N	2014-10-22 16:46:22	\N
22845	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20789	\N	2014-10-22 16:46:22	\N
22846	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20790	\N	2014-10-22 16:46:22	\N
22847	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20791	\N	2014-10-22 16:46:22	\N
22848	MEMBRE	2014-10-22 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	20792	\N	2014-10-22 16:53:26	2015-02-20 10:41:55
22849	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20793	\N	2014-10-22 16:53:26	\N
22850	MEMBRE	2014-10-22 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	20794	\N	2014-10-22 16:53:26	2015-01-06 15:38:47
22851	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20795	\N	2014-10-22 16:53:26	\N
22852	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20796	\N	2014-10-22 16:54:43	\N
22853	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20797	\N	2014-10-22 16:54:43	\N
22854	MEMBRE	2014-10-21 00:00:00	2015-01-21 00:00:00	ANCIEN	\N	\N	\N	\N	20798	\N	2014-10-22 16:54:43	2015-01-22 10:49:38
22855	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20799	\N	2014-10-22 16:54:43	\N
22856	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20800	\N	2014-10-22 16:54:43	\N
22857	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20801	\N	2014-10-22 16:54:43	\N
22858	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20802	\N	2014-10-22 16:54:43	\N
22859	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20803	\N	2014-10-22 16:58:15	\N
22860	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20804	\N	2014-10-22 16:58:15	\N
22861	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20805	\N	2014-10-22 16:58:15	\N
23661	MEMBRE	2014-10-28 00:00:00	2017-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	21572	\N	2014-10-30 10:50:18	2017-07-20 14:38:49
23662	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21573	\N	2014-10-30 10:50:18	\N
23663	MEMBRE	2014-10-28 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	21574	\N	2014-10-30 10:50:18	2015-02-19 17:23:09
23664	MEMBRE	2014-10-28 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	21575	\N	2014-10-30 10:50:19	2015-02-11 18:01:46
23665	MEMBRE	2014-10-28 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	21576	\N	2014-10-30 10:50:19	2015-02-05 18:54:56
23666	MEMBRE	2014-10-28 00:00:00	2015-03-19 00:00:00	ANCIEN	\N	\N	\N	\N	21577	\N	2014-10-30 10:52:15	2015-03-20 09:20:30
23667	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21578	\N	2014-10-30 10:52:15	\N
23668	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21579	\N	2014-10-30 10:52:15	\N
23669	MEMBRE	2014-10-29 00:00:00	2015-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	21580	10	2014-10-30 10:52:37	2015-02-23 15:24:03
23670	MEMBRE	2014-10-29 00:00:00	2015-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	21581	\N	2014-10-30 10:52:37	2015-02-09 11:03:10
23671	MEMBRE	2014-10-29 00:00:00	2017-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	21582	\N	2014-10-30 10:52:37	2017-07-20 14:38:36
23672	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21583	\N	2014-10-30 10:52:37	\N
23673	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21584	\N	2014-10-30 10:52:37	\N
23674	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21585	\N	2014-10-30 10:53:11	\N
23675	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21586	\N	2014-10-30 10:53:11	\N
23676	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21587	\N	2014-10-30 10:53:11	\N
23677	MEMBRE	2014-10-29 00:00:00	2015-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	21588	\N	2014-10-30 10:54:41	2015-02-09 11:02:49
23678	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21589	\N	2014-10-30 10:54:41	\N
23679	MEMBRE	2014-10-29 00:00:00	2015-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	21590	\N	2014-10-30 10:54:41	2015-02-04 18:16:41
23680	MEMBRE	2014-10-29 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21591	\N	2014-10-30 10:54:41	2015-01-06 15:24:42
23681	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21592	\N	2014-10-30 10:55:21	\N
23682	MEMBRE	2014-10-29 00:00:00	2016-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	21593	\N	2014-10-30 10:55:59	2016-11-18 12:37:50
23683	MEMBRE	2014-10-28 00:00:00	2017-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	21594	\N	2014-10-30 10:56:57	2017-07-20 14:38:34
23684	MEMBRE	2014-10-28 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	21595	\N	2014-10-30 10:56:57	2015-02-03 16:28:41
23685	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21596	\N	2014-10-30 10:56:57	\N
23686	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21597	\N	2014-10-30 10:56:57	\N
23687	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21598	\N	2014-10-30 10:56:57	\N
23688	MEMBRE	2014-10-29 00:00:00	2015-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	21599	\N	2014-10-30 10:57:45	2015-01-28 09:41:06
23689	MEMBRE	2014-10-29 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	21600	\N	2014-10-30 10:57:45	2015-02-03 16:22:48
23690	MEMBRE	2014-10-29 00:00:00	2015-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	21601	\N	2014-10-30 10:57:45	2015-02-04 18:16:31
23691	MEMBRE	2014-10-29 00:00:00	2016-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	21602	\N	2014-10-30 10:57:45	2016-12-07 16:42:17
23692	MEMBRE	2014-10-29 00:00:00	2015-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	21603	\N	2014-10-30 10:57:45	2015-03-02 11:07:25
23693	MEMBRE	2014-10-29 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21604	\N	2014-10-30 10:57:45	2015-01-06 15:51:05
23694	MEMBRE	2014-10-29 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	21605	\N	2014-10-30 10:57:45	2015-02-05 18:59:25
23695	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21606	\N	2014-10-30 10:57:45	\N
23696	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21607	\N	2014-10-30 10:57:45	\N
23697	MEMBRE	2014-10-29 00:00:00	2015-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	21608	\N	2014-10-30 10:57:45	2015-02-06 14:46:33
23698	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21609	\N	2014-10-30 10:57:45	\N
23699	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21610	\N	2014-10-30 10:57:45	\N
23700	MEMBRE	2014-10-29 00:00:00	2015-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	21611	\N	2014-10-30 10:57:45	2015-03-19 10:02:50
23701	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21612	\N	2014-10-30 11:19:10	\N
23702	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21613	\N	2014-10-30 11:19:26	\N
23730	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21641	\N	2014-10-30 11:56:56	\N
23731	MEMBRE	2014-10-22 00:00:00	2015-04-09 00:00:00	ANCIEN	\N	\N	\N	\N	21642	\N	2014-10-30 11:57:16	2015-04-10 15:10:44
23732	MEMBRE	2014-10-22 00:00:00	2015-08-30 00:00:00	ANCIEN	\N	\N	\N	\N	21643	\N	2014-10-30 11:57:40	2015-08-31 09:33:27
23733	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21644	\N	2014-10-30 11:58:00	\N
23734	MEMBRE	2014-10-22 00:00:00	2016-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	21645	\N	2014-10-30 11:58:16	2016-12-07 16:41:07
23735	MEMBRE	2014-10-22 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	21646	\N	2014-10-30 11:58:30	2015-02-20 10:46:10
23736	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21647	\N	2014-10-30 11:58:44	\N
23738	MEMBRE	2014-10-30 00:00:00	2015-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	21649	\N	2014-10-30 12:06:01	2015-01-27 17:08:38
23739	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21650	\N	2014-10-30 12:06:01	\N
23741	MEMBRE	2014-10-30 00:00:00	2017-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	21652	\N	2014-10-30 12:06:37	2017-09-24 11:09:53
23742	MEMBRE	2014-10-30 00:00:00	2017-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	21653	\N	2014-10-30 12:06:38	2017-09-24 11:09:53
23743	MEMBRE	2014-10-30 00:00:00	2017-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	21654	\N	2014-10-30 12:06:38	2017-09-24 11:09:53
23744	MEMBRE	2014-10-30 00:00:00	2017-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	21655	\N	2014-10-30 12:06:38	2017-09-24 11:09:53
23745	MEMBRE	2014-10-30 00:00:00	2017-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	21656	\N	2014-10-30 12:06:38	2017-09-24 11:09:53
23746	MEMBRE	2014-10-30 00:00:00	2015-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	21657	\N	2014-10-30 12:06:38	2015-02-09 15:42:57
23747	MEMBRE	2014-10-30 00:00:00	2017-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	21658	\N	2014-10-30 12:06:38	2017-09-24 11:09:53
23748	MEMBRE	2014-10-30 00:00:00	2017-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	21659	\N	2014-10-30 12:06:38	2017-09-24 11:09:53
23749	MEMBRE	2014-10-30 00:00:00	2017-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	21660	\N	2014-10-30 12:06:38	2017-09-24 11:09:53
23775	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21686	\N	2014-10-30 14:17:28	\N
23776	MEMBRE	2014-10-30 00:00:00	2015-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	21687	\N	2014-10-30 14:17:28	2015-02-17 16:13:31
23777	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21688	\N	2014-10-30 14:17:28	\N
23778	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21689	\N	2014-10-30 14:17:28	\N
23779	MEMBRE	2014-10-30 00:00:00	2015-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	21690	\N	2014-10-30 14:17:28	2015-01-29 10:53:19
23780	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21691	\N	2014-10-30 14:17:28	\N
24094	MEMBRE	2014-10-31 00:00:00	2017-06-01 00:00:00	ANCIEN	\N	\N	\N	\N	22005	\N	2014-11-03 09:33:46	2017-06-02 10:02:57
24095	MEMBRE	2014-10-31 00:00:00	2017-06-01 00:00:00	ANCIEN	\N	\N	\N	\N	22006	\N	2014-11-03 09:33:46	2017-06-02 10:02:57
24186	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22097	\N	2014-11-04 17:18:07	\N
24187	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22098	\N	2014-11-05 09:37:10	\N
24188	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22099	\N	2014-11-05 09:37:28	\N
24189	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22100	\N	2014-11-05 09:37:29	\N
24190	MEMBRE	2014-10-30 00:00:00	2014-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	22101	\N	2014-11-05 09:37:29	2014-12-23 09:10:35
24191	MEMBRE	2014-10-30 00:00:00	2014-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	22102	\N	2014-11-05 09:37:29	2014-12-23 09:10:35
24192	MEMBRE	2014-10-30 00:00:00	2014-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	22103	\N	2014-11-05 09:37:29	2014-12-18 14:47:10
24193	MEMBRE	2014-11-04 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22104	\N	2014-11-05 09:37:47	\N
24194	MEMBRE	2014-11-04 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	22105	\N	2014-11-05 09:37:48	2015-02-13 11:34:29
25266	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22548	\N	\N	\N
25332	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22614	\N	\N	\N
25702	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22885	\N	\N	\N
25717	MEMBRE	2014-10-01 00:00:00	2015-03-04 00:00:00	ANCIEN	\N	\N	\N	\N	22900	\N	\N	\N
25729	VICPDT	2015-02-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22574	\N	\N	\N
25739	SECRET	2015-02-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22561	\N	\N	\N
25784	PDTHON	2015-02-19 00:00:00	2017-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	21906	2	2015-02-19 16:15:11	2017-10-05 09:38:11
25785	VICPDT	2015-02-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21777	3	2015-02-19 16:15:45	2015-02-19 16:15:51
25786	VICPDT	2015-02-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21759	4	2015-02-19 16:16:03	2015-02-19 16:16:18
25787	VICPDT	2015-02-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20483	5	2015-02-19 16:16:28	2015-02-19 16:16:33
25788	VICPDT	2015-02-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20497	6	2015-02-19 16:16:53	2015-02-19 16:20:49
25789	VICPDT	2015-02-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21700	9	2015-02-19 16:22:27	2015-02-19 16:22:39
25790	VICPDT	2015-02-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20405	11	2015-02-19 16:23:04	2015-02-19 16:23:13
25791	VICPDT	2015-02-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21663	12	2015-02-19 16:23:32	2015-02-19 16:23:38
25792	VICPDT	2015-02-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20613	13	2015-02-19 16:23:46	2015-02-19 16:23:50
25793	VICPDT	2015-02-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20319	15	2015-02-19 16:29:04	2015-02-19 16:29:07
25794	VICPDT	2015-02-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21696	16	2015-02-19 16:29:29	2015-02-23 15:26:56
25795	SECRET	2015-02-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20633	17	2015-02-19 16:29:46	2015-02-19 16:29:53
25796	SECRET	2015-02-19 00:00:00	2017-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	21727	18	2015-02-19 16:30:01	2017-07-24 09:58:00
25797	SECRET	2015-02-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21233	19	2015-02-19 16:30:14	2015-02-23 15:27:03
25798	MEMBRE	2015-02-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22945	\N	2015-02-19 16:34:53	\N
26620	PDT	2015-07-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	23340	\N	\N	\N
26622	VICPDT	2015-07-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	23368	\N	\N	\N
26623	VICPDT	2015-07-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	23371	\N	\N	\N
26624	SECRET	2015-07-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	23352	\N	\N	\N
26625	SECRET	2015-07-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	23351	\N	\N	\N
26626	VICPDT	2015-07-15 00:00:00	2015-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	23360	\N	\N	\N
26628	SECRET	2015-07-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	23360	\N	\N	\N
27131	MEMBRE	2016-12-07 00:00:00	2017-04-27 00:00:00	ANCIEN	\N	\N	pour le Vénézuela	\N	20502	\N	2016-12-07 15:56:55	2017-04-27 16:00:50
27132	PDTDEL	2016-12-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	pour le Vénézuela	\N	22315	\N	2016-12-07 15:57:06	2016-12-07 15:58:34
27133	SECRET	2016-12-07 00:00:00	2017-01-04 00:00:00	ANCIEN	\N	\N	\N	\N	20542	\N	2016-12-07 15:59:06	2017-01-04 12:17:10
27164	MEMBRE	2017-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23833	\N	\N	\N
29250	MEMBRE	2017-12-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25650	\N	2017-12-18 18:15:25	\N
29258	MEMBRE	2017-12-19 00:00:00	2018-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	25657	\N	2017-12-19 17:19:03	2018-02-12 10:01:37
29259	MEMBRE	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25658	\N	2017-12-19 17:19:03	\N
29260	MEMBRE	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25659	\N	2017-12-19 17:19:03	\N
29261	MEMBRE	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25660	\N	2017-12-19 17:19:03	\N
29262	MEMBRE	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25661	\N	2017-12-19 17:19:03	\N
29263	MEMBRE	2017-12-19 00:00:00	2018-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	25662	\N	2017-12-19 17:19:03	2018-02-12 09:31:03
29264	MEMBRE	2017-12-19 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	25663	\N	2017-12-19 17:19:03	2018-01-25 15:20:49
29265	MEMBRE	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25664	\N	2017-12-19 17:19:03	\N
29266	MEMBRE	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25665	\N	2017-12-19 17:19:03	\N
29267	MEMBRE	2017-12-19 00:00:00	2018-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	25666	\N	2017-12-19 17:19:03	2018-03-12 09:48:57
29268	PDT	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25667	\N	2017-12-19 17:19:03	2017-12-19 17:19:28
29657	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25911	\N	\N	\N
29659	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25913	\N	\N	\N
29663	MEMBRE	2017-10-01 00:00:00	2018-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	25917	\N	\N	\N
29665	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25919	\N	\N	\N
29667	MEMBRE	2017-10-01 00:00:00	2018-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	25921	\N	\N	\N
29671	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25925	\N	\N	\N
29682	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25936	\N	\N	\N
29683	MEMBRE	2017-10-01 00:00:00	2018-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	25937	\N	\N	\N
29684	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25938	\N	\N	\N
29685	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25939	\N	\N	\N
29686	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25940	\N	\N	\N
29687	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25941	\N	\N	\N
29688	MEMBRE	2017-10-01 00:00:00	2018-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	25942	\N	\N	\N
29690	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25944	\N	\N	\N
29691	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25945	\N	\N	\N
29802	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25974	\N	\N	\N
30296	SECRET	2018-01-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25342	\N	2018-01-30 16:02:48	\N
30297	VICPDT	2018-01-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25861	\N	\N	\N
29839	VICPDT	2018-01-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25458	\N	2018-01-23 16:57:06	\N
29840	VICPDT	2018-01-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24045	\N	2018-01-23 16:58:03	\N
29841	VICPDT	2018-01-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25601	\N	2018-01-23 16:58:20	\N
29842	SECRET	2018-01-23 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	24516	\N	2018-01-23 16:58:42	\N
30298	VICPDTDEL	2018-01-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Colombie	\N	25124	\N	2018-01-30 16:03:11	2018-01-30 17:03:44
30299	SECRET	2018-01-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24450	\N	2018-01-30 16:03:16	\N
29845	VICPDT	2018-01-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25274	\N	2018-01-23 17:22:52	\N
29846	VICPDT	2018-01-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24991	\N	2018-01-23 17:23:29	\N
29847	VICPDT	2018-01-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24759	\N	2018-01-23 17:23:39	\N
29848	VICPDT	2018-01-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25289	\N	2018-01-23 17:23:55	\N
29849	VICPDT	2018-01-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24965	\N	2018-01-23 17:24:08	\N
29850	SECRET	2018-01-23 00:00:00	2019-03-12 00:00:00	ANCIEN	\N	\N	\N	\N	24771	\N	2018-01-23 17:26:30	\N
29851	SECRET	2018-01-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24456	\N	2018-01-23 17:26:48	\N
29852	SECRET	2018-01-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24231	\N	2018-01-23 17:27:04	\N
29853	SECRET	2018-01-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24938	\N	2018-01-23 17:27:18	\N
29854	SECRET	2018-01-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25241	\N	2018-01-23 17:27:30	\N
29855	VICPDTPRE	2018-01-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24572	\N	2018-01-23 17:48:04	\N
29856	VICPDTDEU	2018-01-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24999	\N	2018-01-23 17:48:12	\N
29857	VICPDT	2018-01-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25775	\N	2018-01-23 17:48:20	\N
29858	VICPDT	2018-01-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25982	\N	2018-01-23 17:48:32	\N
29859	SECRET	2018-01-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25967	\N	2018-01-23 17:48:42	\N
29860	SECRET	2018-01-23 00:00:00	2019-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	25788	\N	2018-01-23 17:48:51	\N
29861	SECRET	2018-01-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25384	\N	2018-01-23 17:48:57	\N
29862	VICPDTPRE	2018-01-23 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	23879	\N	2018-01-23 18:42:31	2018-02-07 15:20:03
29863	VICPDTDEU	2018-01-23 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	24817	\N	2018-01-23 18:42:41	2018-02-07 15:20:09
29864	VICPDT	2018-01-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24885	\N	2018-01-23 18:43:00	\N
29865	VICPDT	2018-01-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24736	\N	2018-01-23 18:43:12	\N
29866	SECRET	2018-01-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25016	\N	2018-01-23 18:43:26	\N
29867	SECRET	2018-01-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24669	\N	2018-01-23 18:43:34	\N
29868	SECRET	2018-01-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23994	\N	2018-01-23 18:43:41	\N
29869	VICPDTPRE	2018-01-23 00:00:00	2018-12-05 00:00:00	ANCIEN	\N	\N	\N	\N	24801	\N	2018-01-23 18:48:53	\N
29403	MEMBRE	2017-12-07 00:00:00	2018-04-02 00:00:00	ANCIEN	\N	\N	\N	\N	25745	\N	\N	\N
29870	VICPDTDEU	2018-01-23 00:00:00	2018-12-05 00:00:00	ANCIEN	\N	\N	\N	\N	24460	\N	2018-01-23 18:49:03	\N
29871	VICPDT	2018-01-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23904	\N	2018-01-23 18:49:16	\N
29872	SECRET	2018-01-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25291	\N	2018-01-23 18:49:26	\N
29873	SECRET	2018-01-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24820	\N	2018-01-23 18:49:36	\N
29874	SECRET	2018-01-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25242	\N	2018-01-23 18:49:42	\N
29875	SECRET	2018-01-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25176	\N	2018-01-23 18:49:53	\N
29876	SECRET	2018-01-23 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	25025	\N	2018-01-23 18:50:01	\N
30300	SECRET	2018-01-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25208	\N	2018-01-30 16:03:22	\N
30301	VICPDT	2018-01-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	25969	\N	\N	\N
30303	VICPDT	2018-01-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	25887	\N	\N	\N
30304	VICPDT	2018-01-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	25888	\N	\N	\N
30305	VICPDT	2018-01-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	25892	\N	\N	\N
30306	VICPDT	2018-01-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25895	\N	\N	\N
30307	MEMBRE	2017-10-01 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	26158	\N	\N	\N
30308	VICPDT	2018-01-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	26158	\N	\N	\N
30309	SECRET	2018-01-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	25868	\N	\N	\N
30310	SECRET	2018-01-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25886	\N	\N	\N
30311	SECRET	2018-01-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25891	\N	\N	\N
30312	SECRET	2018-01-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	25896	\N	\N	\N
30313	MEMBRE	2018-01-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26159	\N	2018-01-30 17:32:56	\N
23147	MEMBRE	2014-10-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21091	\N	2014-10-24 10:10:26	\N
23148	MEMBRE	2014-10-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21092	\N	2014-10-24 10:10:26	\N
23149	MEMBRE	2014-10-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21093	\N	2014-10-24 10:10:26	\N
23150	MEMBRE	2014-10-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21094	\N	2014-10-24 10:10:26	\N
23151	MEMBRE	2014-10-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21095	\N	2014-10-24 10:12:30	\N
23152	MEMBRE	2014-10-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21096	\N	2014-10-24 10:12:30	\N
23153	MEMBRE	2014-10-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21097	\N	2014-10-24 10:12:30	\N
23154	MEMBRE	2014-10-23 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21098	\N	2014-10-24 10:12:30	2015-01-06 17:51:23
23155	MEMBRE	2014-10-23 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	21099	\N	2014-10-24 10:12:30	2015-02-13 11:34:53
23156	MEMBRE	2014-10-23 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	21100	\N	2014-10-24 10:12:30	2015-02-05 19:00:03
23157	MEMBRE	2014-10-23 00:00:00	2015-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	21101	\N	2014-10-24 10:12:30	2015-02-17 09:39:45
23158	MEMBRE	2014-10-23 00:00:00	2015-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	21102	\N	2014-10-24 10:12:30	2015-03-02 11:07:55
23159	MEMBRE	2014-10-23 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21103	\N	2014-10-24 10:12:30	2015-01-06 16:30:49
23160	MEMBRE	2014-10-23 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	21104	1	2014-10-24 10:12:30	2015-02-11 17:18:35
23161	MEMBRE	2014-10-23 00:00:00	2015-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	21105	\N	2014-10-24 10:12:30	2015-03-19 09:58:10
23162	MEMBRE	2014-10-23 00:00:00	2015-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	21106	\N	2014-10-24 10:12:31	2015-02-18 13:28:13
23642	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21553	\N	2014-10-30 09:30:15	\N
23643	MEMBRE	2014-10-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21554	\N	2014-10-30 09:30:41	\N
23644	MEMBRE	2014-10-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21555	\N	2014-10-30 09:30:41	\N
23645	MEMBRE	2014-10-29 00:00:00	2015-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	21556	\N	2014-10-30 09:35:00	2015-02-12 17:35:47
23646	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21557	\N	2014-10-30 09:35:00	\N
23647	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21558	\N	2014-10-30 09:35:13	\N
23648	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21559	\N	2014-10-30 09:35:13	\N
23649	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21560	\N	2014-10-30 09:35:36	\N
23650	MEMBRE	2014-10-29 00:00:00	2017-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	21561	\N	2014-10-30 09:35:36	2017-07-20 14:38:34
23651	MEMBRE	2014-10-29 00:00:00	2015-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	21562	\N	2014-10-30 09:35:36	2015-01-27 17:08:43
23652	MEMBRE	2014-10-29 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21563	\N	2014-10-30 09:35:36	2015-01-06 16:01:38
23653	MEMBRE	2014-10-29 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	21564	\N	2014-10-30 09:35:36	2015-02-05 18:55:50
23654	MEMBRE	2014-10-29 00:00:00	2015-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	21565	\N	2014-10-30 09:35:54	2015-05-06 17:28:40
23655	MEMBRE	2014-10-29 00:00:00	2015-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	21566	\N	2014-10-30 09:35:54	2015-05-06 17:28:40
23656	MEMBRE	2014-10-29 00:00:00	2015-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	21567	\N	2014-10-30 09:35:54	2015-05-06 17:28:40
23657	MEMBRE	2014-10-29 00:00:00	2015-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	21568	\N	2014-10-30 09:35:54	2015-05-06 17:28:40
23658	MEMBRE	2014-10-29 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	21569	\N	2014-10-30 09:35:54	2015-02-13 14:19:23
23659	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21570	\N	2014-10-30 09:35:54	\N
23660	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21571	\N	2014-10-30 09:36:10	\N
24357	MEMBRE	2014-11-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22264	\N	2014-11-20 16:30:29	\N
24358	MEMBRE	2014-11-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22265	\N	2014-11-20 16:30:29	\N
24865	PDTDEL	2015-01-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour le Zimbabwe	\N	22461	7	2015-01-30 15:51:15	2015-01-30 15:51:46
24956	MEMBRE	2015-01-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22513	\N	2015-02-04 14:51:21	\N
25071	VICPDT	2015-02-09 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21588	4	2015-02-09 11:02:49	2015-02-09 11:04:29
25072	VICPDT	2015-02-09 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20330	5	2015-02-09 11:03:03	2015-02-09 11:04:31
25073	VICPDT	2015-02-09 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21581	6	2015-02-09 11:03:10	2015-02-09 11:04:34
25074	VICPDT	2015-02-09 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21162	7	2015-02-09 11:03:14	2015-02-09 11:04:37
25075	VICPDT	2015-02-09 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21677	8	2015-02-09 11:03:22	2015-02-09 11:04:40
25076	VICPDT	2015-02-09 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20548	9	2015-02-09 11:03:28	2015-02-09 11:04:43
25077	VICPDT	2015-02-09 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21003	10	2015-02-09 11:03:34	2015-02-09 11:04:45
25078	SECRET	2015-02-09 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20509	11	2015-02-09 11:03:50	2015-02-09 11:04:52
25079	SECRET	2015-02-09 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21090	12	2015-02-09 11:03:55	2015-02-09 11:04:55
25080	SECRET	2015-02-09 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20672	13	2015-02-09 11:04:00	2015-02-09 11:04:59
25081	SECRET	2015-02-09 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20785	14	2015-02-09 11:04:08	2015-02-09 11:05:02
25082	SECRET	2015-02-09 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21467	15	2015-02-09 11:04:13	2015-02-09 11:05:07
25111	MEMBRE	2015-02-03 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	22529	\N	2015-02-10 12:18:49	2015-06-12 16:01:25
25415	MEMBRE	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22674	\N	2015-02-16 10:02:28	\N
25416	MEMBRE	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22675	\N	2015-02-16 10:02:28	\N
25743	MEMBRE	2015-02-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22911	\N	2015-02-19 15:20:50	\N
25767	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22928	\N	\N	\N
25768	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22929	\N	\N	2017-09-24 13:25:54
25769	MEMBRE	2014-10-01 00:00:00	2014-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	22930	\N	\N	\N
25770	MEMBRE	2014-10-01 00:00:00	2014-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	22931	\N	\N	\N
25772	MEMBRE	2014-10-01 00:00:00	2016-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	22933	\N	\N	2016-12-01 10:36:51
25773	MEMBRE	2014-10-01 00:00:00	2014-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	22934	\N	\N	\N
25775	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22936	\N	\N	\N
25777	MEMBRE	2014-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22938	\N	\N	2017-10-01 10:34:22
25778	MEMBRE	2014-10-01 00:00:00	2014-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	22939	\N	\N	\N
25779	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22940	\N	\N	2017-09-24 17:48:21
25780	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22941	\N	\N	\N
25781	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22942	\N	\N	\N
25782	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22943	\N	\N	\N
25783	MEMBRE	2014-10-01 00:00:00	2014-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	22944	\N	\N	\N
25819	MEMBRE	2015-02-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22947	\N	2015-02-20 10:18:28	\N
25820	MEMBRE	2015-02-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22948	\N	2015-02-20 10:18:45	\N
25821	MEMBRE	2015-02-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22949	\N	2015-02-20 10:18:52	\N
25822	VICPDT	2015-02-20 00:00:00	2017-06-01 00:00:00	ANCIEN	\N	\N	\N	\N	21996	2	2015-02-20 10:41:47	2017-06-02 10:02:57
25823	VICPDT	2015-02-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20792	3	2015-02-20 10:41:55	2015-02-20 10:44:20
25824	VICPDT	2015-02-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21139	4	2015-02-20 10:42:03	2015-02-20 10:44:23
25825	VICPDT	2015-02-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20527	5	2015-02-20 10:42:11	2015-02-20 10:44:28
25826	VICPDT	2015-02-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21322	6	2015-02-20 10:42:23	2015-02-20 10:44:35
25827	VICPDT	2015-02-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20621	7	2015-02-20 10:42:33	2015-02-20 10:44:46
25828	VICPDT	2015-02-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20517	8	2015-02-20 10:42:50	2015-02-20 10:44:51
25829	VICPDT	2015-02-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20422	9	2015-02-20 10:42:58	2015-02-20 10:44:54
25830	VICPDT	2015-02-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21009	10	2015-02-20 10:43:06	2015-02-20 10:45:01
25831	VICPDT	2015-02-20 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	20679	11	2015-02-20 10:43:10	2015-06-12 15:59:49
25832	VICPDT	2015-02-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21180	12	2015-02-20 10:43:15	2015-02-20 10:45:13
25833	VICPDT	2015-02-20 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	21363	13	2015-02-20 10:43:24	2017-06-19 12:20:59
25834	VICPDT	2015-02-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21349	14	2015-02-20 10:43:42	2015-02-20 10:45:33
25835	VICPDT	2015-02-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21819	15	2015-02-20 10:43:52	2015-02-20 10:45:36
25836	VICPDT	2015-02-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20350	16	2015-02-20 10:44:01	2015-02-20 10:45:40
25837	MEMBRE	2015-02-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21646	\N	2015-02-20 10:46:10	2015-02-20 10:49:24
25838	VICPDT	2015-02-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21762	2	2015-02-20 10:46:15	2015-02-20 10:52:20
25839	SECRET	2015-02-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21891	8	2015-02-20 10:46:20	2015-02-20 10:52:48
25840	VICPDT	2015-02-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20419	4	2015-02-20 10:46:27	2015-02-20 10:52:27
25841	VICPDT	2015-02-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20529	5	2015-02-20 10:46:37	2015-02-20 10:52:33
25842	VICPDT	2015-02-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20735	7	2015-02-20 10:46:44	2015-02-20 10:52:41
25843	SECRET	2015-02-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22283	12	2015-02-20 10:46:49	2015-02-20 10:53:32
25844	VICPDT	2015-02-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21110	3	2015-02-20 10:50:48	2015-02-20 10:52:24
25845	SECRET	2015-02-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21718	9	2015-02-20 10:51:44	2015-02-20 10:52:58
25846	SECRET	2015-02-20 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	21848	10	2015-02-20 10:51:52	2016-03-11 18:02:51
25847	SECRET	2015-02-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20608	11	2015-02-20 10:52:06	2015-02-20 10:53:04
25401	MEMBRE	2014-10-01 00:00:00	2017-07-28 00:00:00	ANCIEN	\N	\N	\N	\N	22671	\N	\N	2017-08-03 11:38:41
25402	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22672	\N	\N	\N
26621	VICPDT	2015-07-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	23344	\N	\N	\N
27072	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23764	\N	\N	\N
27075	MEMBRE	2016-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23767	\N	\N	\N
27092	MEMBRE	2016-10-01 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	23784	\N	\N	2017-09-25 09:57:52
27093	MEMBRE	2016-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23785	\N	\N	\N
27101	MEMBRE	2016-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23793	\N	\N	\N
27104	MEMBRE	2016-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23796	\N	\N	\N
27105	MEMBRE	2016-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23797	\N	\N	\N
27109	MEMBRE	2016-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23801	\N	\N	\N
27111	MEMBRE	2016-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23803	\N	\N	\N
29200	MEMBRE	2017-11-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25627	\N	2017-12-14 14:41:07	\N
29201	MEMBRE	2017-12-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25628	\N	2017-12-14 14:41:30	\N
29202	MEMBRE	2017-12-13 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	25629	\N	2017-12-14 15:15:05	2018-01-24 15:04:45
29203	VICPDT	2017-12-14 00:00:00	2018-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	24338	\N	2017-12-14 15:43:04	\N
29204	VICPDT	2017-12-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24577	\N	2017-12-14 15:43:24	\N
29205	VICPDT	2017-12-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24853	\N	2017-12-14 15:43:38	\N
29206	VICPDT	2017-12-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23987	\N	2017-12-14 15:46:17	\N
29207	SECRET	2017-12-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24261	\N	2017-12-14 15:46:29	2017-12-14 15:48:37
29208	SECRET	2017-12-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25053	\N	2017-12-14 15:46:43	2017-12-14 15:48:50
29209	VICPDT	2017-12-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25146	\N	2017-12-14 15:49:07	\N
29210	VICPDT	2017-12-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24532	\N	2017-12-14 15:49:19	\N
29211	SECRET	2017-12-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23882	\N	2017-12-14 15:49:35	\N
29212	VICPDT	2017-12-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24637	\N	2017-12-14 15:49:59	\N
29213	VICPDT	2017-12-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24785	\N	2017-12-14 15:50:08	\N
29214	VICPDT	2017-12-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24369	\N	2017-12-14 15:50:21	\N
29215	VICPDT	2017-12-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25011	\N	2017-12-14 15:50:38	\N
29216	VICPDT	2017-12-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24884	\N	2017-12-14 15:51:00	\N
29231	MEMBRE	2017-12-04 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	25632	\N	2017-12-15 09:26:17	2018-01-31 18:42:48
29232	MEMBRE	2017-12-13 00:00:00	2018-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	25633	\N	2017-12-15 09:26:41	2018-02-08 14:37:10
29233	MEMBRE	2017-12-13 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	25634	\N	2017-12-15 09:26:41	2018-01-24 15:03:58
29234	MEMBRE	2017-12-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25635	\N	2017-12-15 09:26:41	\N
29246	PDTDEL	2017-12-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Centrafrique	\N	25647	\N	2017-12-15 17:17:12	2017-12-15 17:27:32
29247	MEMBRE	2017-12-07 00:00:00	2017-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	25648	\N	2017-12-18 09:54:21	2017-12-18 10:02:33
29248	PDT	2017-12-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25648	\N	2017-12-18 10:02:33	\N
29256	MEMBRE	2017-12-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25655	\N	2017-12-19 15:21:08	\N
29269	VICPDT	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24090	\N	2017-12-19 17:53:39	\N
29270	VICPDT	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25272	\N	2017-12-19 17:54:01	\N
29271	VICPDT	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25414	\N	2017-12-19 17:54:13	\N
29272	VICPDT	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25417	\N	2017-12-19 17:54:33	\N
29273	VICPDT	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23895	\N	2017-12-19 17:55:14	\N
29274	VICPDT	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25409	\N	2017-12-19 17:55:25	\N
29275	VICPDT	2017-12-19 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24841	\N	2017-12-19 17:55:37	\N
29276	VICPDT	2017-12-19 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25048	\N	2017-12-19 18:03:52	\N
29277	VICPDT	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24348	\N	2017-12-19 18:04:14	\N
29278	VICPDT	2017-12-19 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25444	\N	2017-12-19 18:04:51	\N
29279	VICPDT	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24247	\N	2017-12-19 18:05:08	\N
29280	VICPDT	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24404	\N	2017-12-19 18:05:19	\N
29281	VICPDT	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24354	\N	2017-12-19 18:05:37	\N
29282	SECRET	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23937	\N	2017-12-19 18:06:30	\N
29283	SECRET	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24095	\N	2017-12-19 18:07:34	\N
29284	SECRET	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24990	\N	2017-12-19 18:08:58	\N
29285	VICPDT	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24767	\N	2017-12-19 18:17:31	\N
29286	VICPDT	2017-12-19 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24634	\N	2017-12-19 18:17:41	\N
29287	VICPDT	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24960	\N	2017-12-19 18:17:51	\N
29288	VICPDT	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24932	\N	2017-12-19 18:18:01	\N
29289	SECRET	2017-12-19 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24522	\N	2017-12-19 18:18:13	\N
29290	SECRET	2017-12-19 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24302	\N	2017-12-19 18:18:20	\N
29291	SECRET	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25408	\N	2017-12-19 18:18:27	\N
29321	VICPDT	2017-12-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23869	\N	2017-12-20 16:56:16	\N
29322	VICPDT	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24963	\N	2017-12-20 16:56:28	\N
29323	VICPDT	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25325	\N	2017-12-20 16:56:36	\N
29324	VICPDT	2017-12-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25009	\N	2017-12-20 16:56:46	\N
29325	VICPDT	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23924	\N	2017-12-20 16:56:57	\N
29326	VICPDT	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23915	\N	2017-12-20 16:57:33	\N
29327	SECRET	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24069	\N	2017-12-20 16:57:54	\N
29328	SECRET	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25377	\N	2017-12-20 16:58:02	\N
29329	MEMBRE	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25679	\N	2017-12-20 17:36:00	\N
29330	MEMBRE	2017-12-19 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	25680	\N	2017-12-20 17:36:18	2018-01-24 18:29:29
29331	MEMBRE	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25681	\N	2017-12-20 17:36:31	\N
29332	MEMBRE	2017-12-19 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	25682	\N	2017-12-20 17:36:45	2018-01-25 15:21:24
29333	MEMBRE	2017-12-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25683	\N	2017-12-20 17:37:00	\N
29334	MEMBRE	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25684	\N	2017-12-20 17:37:14	\N
29335	MEMBRE	2017-12-19 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	25685	\N	2017-12-20 17:37:28	2018-01-24 15:31:31
29336	MEMBRE	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25686	\N	2017-12-20 17:37:54	\N
29337	MEMBRE	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25687	\N	2017-12-20 17:37:54	\N
29338	MEMBRE	2017-10-25 00:00:00	2018-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	25688	\N	2017-12-20 17:37:54	2018-01-17 11:29:55
29339	PDTDEL	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Qatar	\N	25529	\N	2017-12-20 17:41:04	2017-12-20 17:41:12
29340	MEMBRE	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25689	\N	2017-12-20 17:42:06	\N
29341	MEMBRE	2017-12-18 00:00:00	2018-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	25690	\N	2017-12-20 17:42:34	2018-02-08 16:43:02
29346	VICPDT	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24995	\N	2017-12-20 17:59:56	\N
29343	MEMBRE	2017-12-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25692	\N	2017-12-20 17:43:07	\N
29344	VICPDT	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25691	\N	2017-12-20 17:48:02	\N
29345	VICPDT	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25394	\N	2017-12-20 17:59:42	\N
29347	VICPDT	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24108	\N	2017-12-20 18:00:11	\N
29348	VICPDT	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23995	\N	2017-12-20 18:00:23	\N
29349	SECRET	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25412	\N	2017-12-20 18:00:42	\N
29350	MEMBRE	2017-11-28 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	25693	\N	2017-12-20 19:02:00	2017-12-20 19:06:25
29351	PDTDEL	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Emirats Arabes Unis	\N	25693	\N	2017-12-20 19:06:25	2017-12-20 19:07:03
29354	MEMBRE	2017-12-20 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	25696	\N	2017-12-21 11:10:41	2018-01-18 17:51:23
29372	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25714	\N	\N	\N
29364	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25706	\N	\N	\N
29365	MEMBRE	2017-10-01 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	25707	\N	\N	\N
29374	MEMBRE	2017-10-01 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	25716	\N	\N	\N
29381	MEMBRE	2017-10-01 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	25723	\N	\N	\N
29386	MEMBRE	2017-12-07 00:00:00	2018-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	25728	\N	\N	\N
29401	MEMBRE	2017-12-07 00:00:00	2018-04-02 00:00:00	ANCIEN	\N	\N	\N	\N	25743	\N	\N	\N
29404	MEMBRE	2017-12-07 00:00:00	2018-04-02 00:00:00	ANCIEN	\N	\N	\N	\N	25746	\N	\N	\N
29406	MEMBRE	2017-12-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	25748	\N	\N	\N
29407	MEMBRE	2017-12-20 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	25749	\N	2017-12-22 09:46:41	2018-01-18 11:22:53
29408	MEMBRE	2017-12-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25750	\N	2017-12-22 09:48:56	\N
29409	MEMBRE	2017-12-21 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	25751	\N	2017-12-22 09:49:28	2018-01-24 11:13:02
29410	MEMBRE	2017-12-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25752	\N	2017-12-22 09:49:28	\N
29411	MEMBRE	2017-12-21 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	25753	\N	2017-12-22 09:50:04	2018-02-07 12:15:41
29412	MEMBRE	2017-12-19 00:00:00	2017-12-21 00:00:00	ANCIEN	\N	\N	\N	\N	25754	\N	2017-12-22 09:59:14	2017-12-22 10:00:02
29413	PDTDEL	2017-12-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Ouganda	\N	25754	\N	2017-12-22 10:00:02	2017-12-22 10:00:29
29414	MEMBRE	2017-12-22 00:00:00	2017-12-26 00:00:00	ANCIEN	\N	\N	\N	\N	25559	\N	2017-12-22 12:21:20	2017-12-27 11:10:48
22261	MEMBRE	2013-11-19 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20209	\N	\N	2013-11-19 11:00:08
22296	MEMBRE	2014-05-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20243	\N	2014-05-16 09:19:20	\N
22297	MEMBRE	2014-05-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20244	\N	2014-05-16 09:50:23	2014-09-28 19:29:39
22298	MEMBRE	2014-05-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20245	\N	2014-05-16 09:51:01	\N
22299	MEMBRE	2014-05-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20246	\N	2014-05-16 09:51:35	2014-09-28 19:29:39
22300	MEMBRE	2014-05-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20247	\N	2014-05-16 10:12:04	2014-10-14 16:18:19
22301	MEMBRE	2014-05-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20248	\N	2014-05-16 10:13:02	2014-05-16 10:20:28
22302	MEMBRE	2014-05-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20249	\N	2014-05-16 10:13:32	2014-05-16 10:38:42
22303	MEMBRE	2014-05-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20250	\N	2014-05-16 10:14:07	2014-05-16 10:39:19
22304	MEMBRE	2014-05-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20251	\N	2014-05-16 10:14:58	\N
22305	MEMBRE	2014-05-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20252	\N	2014-05-16 10:16:05	2014-05-16 10:16:19
22306	MEMBRE	2014-05-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20253	\N	2014-05-16 10:17:19	\N
22307	MEMBRE	2014-05-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20254	\N	2014-05-16 10:17:57	\N
22308	MEMBRE	2014-05-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20255	\N	2014-05-16 10:19:03	\N
22309	MEMBRE	2014-05-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20256	\N	2014-05-16 11:03:57	\N
22310	MEMBRE	2014-05-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20257	\N	2014-05-16 11:07:39	\N
22311	PDTDEL	2014-05-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	pour le Koweït	\N	20258	4	2014-05-16 11:10:40	2014-09-28 19:03:23
22312	MEMBRE	2014-05-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20259	\N	2014-05-16 11:13:49	2014-09-28 19:03:23
22313	MEMBRE	2014-05-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20260	\N	2014-05-16 11:14:25	2014-09-28 19:03:23
24195	MEMBRE	2014-11-04 00:00:00	2015-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	22106	\N	2014-11-05 09:39:19	2015-01-28 17:42:36
24196	MEMBRE	2014-10-22 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	22107	\N	2014-11-05 09:39:39	2015-02-13 10:35:38
24197	MEMBRE	2014-10-22 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	22108	\N	2014-11-05 09:39:39	2015-02-20 12:00:06
24198	MEMBRE	2014-10-22 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	22109	\N	2014-11-05 09:39:39	2015-02-03 16:29:29
24199	MEMBRE	2014-10-22 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	22110	\N	2014-11-05 09:39:39	2015-01-06 17:50:03
24200	MEMBRE	2014-10-22 00:00:00	2015-03-19 00:00:00	ANCIEN	\N	\N	\N	\N	22111	\N	2014-11-05 09:39:39	2015-03-20 11:38:27
24201	MEMBRE	2014-10-22 00:00:00	2015-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	22112	\N	2014-11-05 09:39:39	2015-03-11 11:00:16
24202	MEMBRE	2014-10-22 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	22113	\N	2014-11-05 09:39:39	2015-02-19 17:23:29
24256	MEMBRE	2014-10-31 00:00:00	2017-09-21 00:00:00	ANCIEN	\N	\N	\N	\N	22167	\N	2014-11-10 09:22:57	2017-09-22 10:42:23
24257	MEMBRE	2014-10-31 00:00:00	2015-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	22168	\N	2014-11-10 09:22:57	2015-02-09 15:42:17
24258	MEMBRE	2014-11-06 00:00:00	2017-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	22169	\N	2014-11-10 09:23:34	2017-07-20 11:45:15
24318	MEMBRE	2014-11-13 00:00:00	2015-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	22225	\N	2014-11-17 09:40:39	2015-02-04 18:17:03
24319	MEMBRE	2014-11-13 00:00:00	2015-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	22226	\N	2014-11-17 09:40:39	2015-02-12 17:36:24
24320	MEMBRE	2014-11-13 00:00:00	2015-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	22227	\N	2014-11-17 09:40:39	2015-03-19 10:03:12
24321	MEMBRE	2014-11-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22228	\N	2014-11-17 09:40:39	\N
24322	MEMBRE	2014-11-13 00:00:00	2015-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	22229	\N	2014-11-17 09:40:39	2015-02-06 16:56:51
24323	MEMBRE	2014-11-06 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	22230	\N	2014-11-17 09:40:59	2017-06-19 16:06:51
24324	MEMBRE	2014-11-06 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	22231	\N	2014-11-17 09:40:59	2017-06-19 16:06:51
24327	MEMBRE	2014-11-18 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22234	\N	2014-11-18 14:12:59	\N
24344	MEMBRE	2014-11-18 00:00:00	2015-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	22251	\N	2014-11-19 17:25:50	2015-03-19 10:03:51
24345	MEMBRE	2014-11-14 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	22252	\N	2014-11-19 17:26:04	2015-02-03 13:59:41
24346	MEMBRE	2014-11-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22253	\N	2014-11-19 17:26:15	\N
24347	MEMBRE	2014-11-07 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	22254	\N	2014-11-19 17:27:22	2015-02-13 17:03:34
24857	MEMBRE	2015-01-27 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22492	\N	2015-01-30 11:11:01	2015-02-03 09:52:45
24687	MEMBRE	2015-01-20 00:00:00	2015-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	22420	\N	2015-01-21 15:11:00	2015-03-16 18:44:24
24688	MEMBRE	2015-01-21 00:00:00	2015-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	22421	\N	2015-01-21 16:47:22	2015-06-17 13:55:29
25287	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22569	\N	\N	2017-09-24 18:20:10
24861	VICPDT	2015-01-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22261	9	2015-01-30 15:14:01	2015-01-30 15:14:09
24862	PDTDEL	2015-01-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour le Botswana	\N	22461	3	2015-01-30 15:18:10	2015-01-30 15:25:28
24863	MEMBRE	2015-01-26 00:00:00	2015-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	22495	\N	2015-01-30 15:42:55	2015-01-30 15:44:18
24864	PDTDEL	2015-01-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour la Zambie	\N	22495	6	2015-01-30 15:44:18	2015-01-30 15:44:40
25309	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22591	\N	\N	\N
25310	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22592	\N	\N	\N
25312	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22594	\N	\N	2017-09-24 17:15:15
25313	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22595	\N	\N	\N
25314	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22596	\N	\N	\N
25315	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22597	\N	\N	\N
25316	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22598	\N	\N	\N
25317	MEMBRE	2014-10-01 00:00:00	2015-05-28 00:00:00	ANCIEN	\N	\N	\N	\N	22599	\N	\N	\N
25318	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22600	\N	\N	\N
25319	MEMBRE	2014-10-01 00:00:00	2015-05-28 00:00:00	ANCIEN	\N	\N	\N	\N	22601	\N	\N	\N
25320	MEMBRE	2014-10-01 00:00:00	2015-05-28 00:00:00	ANCIEN	\N	\N	\N	\N	22602	\N	\N	\N
25321	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22603	\N	\N	\N
25322	MEMBRE	2014-10-01 00:00:00	2015-05-28 00:00:00	ANCIEN	\N	\N	\N	\N	22604	\N	\N	\N
25323	MEMBRE	2014-10-01 00:00:00	2015-05-28 00:00:00	ANCIEN	\N	\N	\N	\N	22605	\N	\N	\N
25701	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22884	\N	\N	\N
25703	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22886	\N	\N	\N
25744	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22912	\N	\N	\N
25745	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22913	\N	\N	\N
25746	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22914	\N	\N	\N
25747	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22915	\N	\N	2017-09-24 13:14:55
25748	MEMBRE	2014-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22916	\N	\N	2017-10-01 10:34:22
25749	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22917	\N	\N	\N
25750	MEMBRE	2014-10-01 00:00:00	2016-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	22918	\N	\N	2016-12-01 10:36:51
25751	MEMBRE	2014-10-01 00:00:00	2015-05-01 00:00:00	ANCIEN	\N	\N	\N	\N	22919	\N	\N	\N
25752	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22920	\N	\N	\N
25753	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22921	\N	\N	\N
25754	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22922	\N	\N	\N
25755	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22923	\N	\N	\N
25757	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22925	\N	\N	\N
25758	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22926	\N	\N	\N
25759	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22927	\N	\N	2017-09-24 17:42:26
25934	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22993	\N	\N	\N
26009	VICPDTDRT	2015-03-03 00:00:00	2015-05-06 00:00:00	ANCIEN	\N	\N	\N	\N	23068	\N	2015-03-03 17:44:06	2015-05-11 17:08:32
26106	VICPDT	2015-03-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21785	2	2015-03-06 09:52:53	2017-09-24 17:47:28
26107	VICPDT	2015-03-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22026	3	2015-03-06 09:53:01	2015-03-06 09:53:49
26108	VICPDT	2015-03-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20508	4	2015-03-06 09:53:10	2015-03-06 09:53:52
26109	VICPDT	2015-03-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20836	5	2015-03-06 09:53:15	2015-03-06 09:53:55
26110	VICPDT	2015-03-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20997	6	2015-03-06 09:53:23	2015-03-06 09:54:00
26111	SECRET	2015-03-06 00:00:00	2017-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	21150	7	2015-03-06 09:53:30	2015-03-06 09:54:02
26112	SECRET	2015-03-06 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	21835	8	2015-03-06 09:53:34	2016-12-12 16:10:15
26120	PDT	2015-03-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20532	1	2015-03-09 14:10:53	2015-03-09 14:11:29
26121	VICPDT	2015-03-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21815	2	2015-03-09 14:11:08	2017-09-24 17:47:28
26122	VICPDT	2015-03-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22164	3	2015-03-09 14:11:12	2015-03-09 14:11:45
26123	VICPDT	2015-03-09 00:00:00	2016-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20657	4	2015-03-09 14:11:16	2017-01-03 11:09:24
26124	VICPDT	2015-03-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21254	5	2015-03-09 14:11:20	2015-03-09 14:11:52
26125	SECRET	2015-03-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21617	6	2015-03-09 14:11:25	2015-03-09 14:11:54
26126	MEMBRE	2015-03-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23111	\N	2015-03-09 15:01:43	\N
26210	MEMBRE	2015-03-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23160	\N	2015-03-13 10:31:57	\N
26212	VICPDT	2015-03-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20553	2	2015-03-16 18:43:52	2015-03-16 18:44:55
26213	VICPDT	2015-03-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22135	3	2015-03-16 18:44:03	2017-09-24 13:14:55
26214	VICPDT	2015-03-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22469	4	2015-03-16 18:44:13	2015-03-16 18:45:02
26215	VICPDT	2015-03-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22420	5	2015-03-16 18:44:24	2017-09-24 17:04:02
26216	VICPDT	2015-03-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22499	6	2015-03-16 18:44:32	2017-09-24 17:47:28
26217	VICPDT	2015-03-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22368	7	2015-03-16 18:44:38	2015-03-16 18:45:11
26218	VICPDT	2015-03-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21178	8	2015-03-16 18:44:44	2017-09-24 17:47:27
25771	MEMBRE	2014-10-01 00:00:00	2014-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	22932	\N	\N	\N
25776	MEMBRE	2014-10-01 00:00:00	2014-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	22937	\N	\N	\N
25849	VICPDT	2015-02-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21485	3	2015-02-20 11:59:55	2015-02-20 12:00:59
25850	VICPDT	2015-02-20 00:00:00	2017-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20749	4	2015-02-20 12:00:01	2017-10-09 09:55:18
25851	VICPDT	2015-02-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22108	5	2015-02-20 12:00:06	2015-02-20 12:01:05
25852	VICPDT	2015-02-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20619	6	2015-02-20 12:00:14	2015-02-20 12:01:09
25853	SECRET	2015-02-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21531	7	2015-02-20 12:00:29	2015-02-20 12:02:11
25854	PDTHON	2015-02-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20784	2	2015-02-20 12:00:46	2015-02-20 12:00:56
25855	VICPDT	2015-02-20 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	21411	7	2015-02-20 12:08:42	2017-05-16 15:18:14
25856	VICPDT	2015-02-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21179	8	2015-02-20 12:08:50	2015-02-20 12:09:34
25857	SECRET	2015-02-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21255	9	2015-02-20 12:08:57	2015-02-20 12:09:49
25858	VICPDT	2015-02-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20603	6	2015-02-20 12:12:06	2015-02-20 12:13:06
25859	VICPDT	2015-02-20 00:00:00	2016-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	21667	7	2015-02-20 12:12:19	2016-03-16 11:35:59
25860	VICPDT	2015-02-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21076	8	2015-02-20 12:12:24	2015-02-20 12:13:11
25861	VICPDT	2015-02-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21204	9	2015-02-20 12:12:31	2015-02-20 12:13:15
25862	VICPDT	2015-02-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20645	10	2015-02-20 12:12:35	2015-02-20 12:13:19
25863	SECRET	2015-02-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21200	11	2015-02-20 12:12:41	2015-02-20 12:13:24
25864	VICPDT	2015-02-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21800	2	2015-02-20 12:16:44	2015-02-20 12:17:15
25865	VICPDT	2015-02-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21703	3	2015-02-20 12:16:52	2015-02-20 12:17:19
25866	VICPDT	2015-02-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21983	4	2015-02-20 12:16:58	2015-02-20 12:17:20
25867	MEMBRE	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22951	\N	2015-02-20 12:19:02	\N
25918	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22977	\N	\N	2017-09-24 18:16:52
26226	MEMBRE	2014-10-01 00:00:00	2015-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	23169	\N	\N	\N
26227	VICPDT	2015-03-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	23123	\N	\N	\N
29420	MEMBRE	2017-10-01 00:00:00	2018-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	25760	\N	\N	\N
26470	MEMBRE	2015-05-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23275	\N	2015-05-26 10:23:07	\N
26471	MEMBRE	2015-05-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23276	\N	2015-05-26 10:26:10	\N
26478	VICPDT	2015-05-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20570	2	2015-05-27 16:33:22	2015-05-27 16:38:38
26479	VICPDT	2015-05-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20308	3	2015-05-27 16:33:30	2017-09-24 18:59:59
26480	SECRET	2015-05-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21794	4	2015-05-27 16:38:40	2017-09-24 17:47:28
26481	SECRET	2015-05-27 00:00:00	2017-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	21151	5	2015-05-27 16:38:47	2015-05-27 16:39:25
26493	MEMBRE	2015-05-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23280	\N	2015-05-29 10:08:00	2017-09-24 17:42:26
26508	MEMBRE	2015-06-03 00:00:00	2017-06-04 00:00:00	ANCIEN	\N	\N	\N	\N	23283	\N	2015-06-04 08:56:00	2017-06-07 09:38:00
27015	MEMBRE	2016-06-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	23713	\N	\N	\N
27063	MEMBRE	2016-09-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23755	\N	2016-10-03 15:58:59	\N
27067	MEMBRE	2016-10-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23759	\N	2016-10-18 09:32:30	2017-09-24 13:57:40
27130	MEMBRE	2016-07-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23821	\N	2016-12-01 12:41:37	\N
27165	MEMBRE	2017-01-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19069	\N	2017-01-25 15:45:09	\N
27656	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24223	\N	2017-10-18 10:22:37	\N
27657	MEMBRE	2017-10-17 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24224	\N	2017-10-18 10:22:37	2018-01-24 18:08:29
27658	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24225	\N	2017-10-18 10:22:37	\N
27659	MEMBRE	2017-10-17 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24226	\N	2017-10-18 10:22:37	2018-01-24 11:13:29
27660	MEMBRE	2017-10-17 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24227	\N	2017-10-18 10:22:37	2018-01-24 10:40:39
27661	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24228	\N	2017-10-18 10:22:37	\N
27662	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24229	\N	2017-10-18 10:22:37	\N
27663	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24230	\N	2017-10-18 10:22:37	\N
27664	MEMBRE	2017-10-17 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	24231	\N	2017-10-18 10:22:38	2018-01-23 17:27:04
27665	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24232	\N	2017-10-18 10:22:38	\N
27666	MEMBRE	2017-10-17 00:00:00	2018-03-04 00:00:00	ANCIEN	\N	\N	\N	\N	24233	\N	2017-10-18 10:22:38	2018-03-05 17:19:09
27667	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24234	\N	2017-10-18 10:22:38	\N
27668	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24235	\N	2017-10-18 10:22:38	\N
27669	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24236	\N	2017-10-18 10:22:38	\N
27670	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24237	\N	2017-10-18 10:22:38	\N
27671	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24238	\N	2017-10-18 10:22:38	\N
27672	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24239	\N	2017-10-18 10:22:38	\N
27673	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24240	\N	2017-10-18 10:22:38	\N
27674	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24241	\N	2017-10-18 10:22:38	\N
27675	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24242	\N	2017-10-18 10:22:38	\N
27676	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24243	\N	2017-10-18 10:22:38	\N
27677	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24244	\N	2017-10-18 10:22:38	\N
27678	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24245	\N	2017-10-18 10:22:38	\N
27679	MEMBRE	2017-10-11 00:00:00	2018-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	24246	\N	2017-10-18 10:27:57	2018-03-06 12:09:18
27680	MEMBRE	2017-10-11 00:00:00	2017-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	24247	\N	2017-10-18 10:27:57	2017-12-19 18:05:08
27681	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24248	\N	2017-10-18 10:29:38	\N
27682	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24249	\N	2017-10-18 10:29:38	\N
27683	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24250	\N	2017-10-18 10:29:38	\N
27684	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24251	\N	2017-10-18 10:29:38	\N
27685	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24252	\N	2017-10-18 10:29:38	\N
27686	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24253	\N	2017-10-18 10:29:38	\N
27687	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24254	\N	2017-10-18 10:29:38	\N
27688	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24255	\N	2017-10-18 10:29:38	\N
27689	MEMBRE	2017-10-17 00:00:00	2017-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	24256	\N	2017-10-18 10:29:38	2017-11-28 17:04:45
27690	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24257	\N	2017-10-18 10:29:38	\N
27691	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24258	\N	2017-10-18 10:29:38	\N
27692	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24259	\N	2017-10-18 10:29:38	\N
27693	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24260	\N	2017-10-18 10:29:38	\N
27694	MEMBRE	2017-10-17 00:00:00	2017-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	24261	\N	2017-10-18 10:29:38	2017-12-14 15:46:29
27695	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24262	\N	2017-10-18 10:29:38	\N
27696	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24263	\N	2017-10-18 10:29:38	\N
27697	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24264	\N	2017-10-18 10:29:38	\N
27698	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24265	\N	2017-10-18 10:29:38	\N
27699	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24266	\N	2017-10-18 10:29:38	\N
27700	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24267	\N	2017-10-18 10:29:38	\N
27701	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24268	\N	2017-10-18 10:29:38	\N
27702	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24269	\N	2017-10-18 10:29:38	\N
27703	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24270	\N	2017-10-18 10:29:38	\N
27704	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24271	\N	2017-10-18 10:29:38	\N
27705	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24272	\N	2017-10-18 10:29:38	\N
27706	MEMBRE	2017-10-11 00:00:00	2017-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	24273	\N	2017-10-18 10:30:01	2017-12-05 10:09:39
27707	MEMBRE	2017-10-11 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	24274	\N	2017-10-18 10:30:23	2018-02-07 16:34:38
27708	MEMBRE	2017-10-11 00:00:00	2018-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	24275	\N	2017-10-18 10:30:23	2018-01-16 19:08:41
27790	MEMBRE	2017-10-18 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	24357	\N	2017-10-19 10:27:17	2018-01-18 16:36:21
27791	MEMBRE	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24358	\N	2017-10-19 10:27:17	\N
27792	MEMBRE	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24359	\N	2017-10-19 10:27:17	\N
27793	MEMBRE	2017-10-18 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24360	\N	2017-10-19 10:27:17	2018-01-24 10:43:18
27794	MEMBRE	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24361	\N	2017-10-19 10:27:17	\N
27795	MEMBRE	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24362	\N	2017-10-19 10:27:17	\N
27796	MEMBRE	2017-10-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24363	\N	2017-10-19 10:28:01	\N
27797	MEMBRE	2017-10-18 00:00:00	2018-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	24364	\N	2017-10-19 10:28:01	2018-01-26 10:09:13
27798	MEMBRE	2017-10-18 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24365	\N	2017-10-19 10:28:01	2018-01-24 17:30:27
23472	MEMBRE	2014-10-28 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	21383	\N	2014-10-29 09:12:30	2015-02-19 15:42:56
23473	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21384	\N	2014-10-29 09:12:30	\N
23474	MEMBRE	2014-10-28 00:00:00	2015-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	21385	\N	2014-10-29 09:12:30	2015-01-30 15:58:06
23475	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21386	\N	2014-10-29 09:12:30	\N
23476	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21387	\N	2014-10-29 09:12:30	\N
23477	MEMBRE	2014-10-28 00:00:00	2015-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	21388	\N	2014-10-29 09:12:31	2015-02-18 13:28:26
23478	MEMBRE	2014-10-28 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21389	\N	2014-10-29 09:12:31	2015-01-06 16:32:46
23479	MEMBRE	2014-10-24 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	21390	\N	2014-10-29 09:14:57	2015-02-13 15:16:25
23480	MEMBRE	2014-10-24 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21391	\N	2014-10-29 09:14:57	\N
23481	MEMBRE	2014-10-24 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	21392	\N	2014-10-29 09:14:57	2015-02-03 16:28:34
23482	MEMBRE	2014-10-24 00:00:00	2015-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	21393	\N	2014-10-29 09:14:57	2015-02-17 16:13:09
23483	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21394	\N	2014-10-29 09:20:49	\N
23484	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21395	\N	2014-10-29 09:20:49	\N
23485	MEMBRE	2014-10-22 00:00:00	2015-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	21396	\N	2014-10-29 09:20:49	2015-02-06 16:57:17
23486	MEMBRE	2014-10-22 00:00:00	2015-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	21397	\N	2014-10-29 09:20:49	2015-02-17 16:13:16
23487	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21398	\N	2014-10-29 09:20:49	\N
23488	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21399	\N	2014-10-29 09:20:49	\N
23489	MEMBRE	2014-10-22 00:00:00	2015-03-09 00:00:00	ANCIEN	\N	\N	\N	\N	21400	\N	2014-10-29 09:20:49	2015-03-10 10:01:54
23490	MEMBRE	2014-10-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21401	\N	2014-10-29 09:22:54	\N
23491	MEMBRE	2014-10-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21402	\N	2014-10-29 09:22:54	\N
23492	MEMBRE	2014-10-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21403	\N	2014-10-29 09:22:54	\N
23493	MEMBRE	2014-10-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21404	\N	2014-10-29 09:22:54	\N
23544	MEMBRE	2014-10-27 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	21455	\N	2014-10-29 10:58:36	2015-02-13 15:14:52
23545	MEMBRE	2014-10-27 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	21456	\N	2014-10-29 10:58:36	2015-02-11 17:25:24
23546	MEMBRE	2014-10-27 00:00:00	2015-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	21457	\N	2014-10-29 10:58:37	2015-02-04 14:27:57
23547	MEMBRE	2014-10-28 00:00:00	2015-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	21458	\N	2014-10-29 11:02:44	2015-03-02 11:07:50
23548	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21459	\N	2014-10-29 11:02:44	\N
23549	MEMBRE	2014-10-28 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	21460	\N	2014-10-29 11:02:44	2015-02-05 19:02:35
23558	MEMBRE	2014-10-28 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	21469	\N	2014-10-29 12:27:00	2017-06-19 16:06:01
23559	MEMBRE	2014-10-28 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	21470	\N	2014-10-29 12:27:00	2017-06-19 16:06:01
23560	MEMBRE	2014-10-28 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	21471	\N	2014-10-29 12:27:00	2017-06-19 16:06:01
23561	MEMBRE	2014-10-28 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	21472	\N	2014-10-29 12:27:00	2017-06-19 16:06:01
23562	MEMBRE	2014-10-28 00:00:00	2017-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	21473	\N	2014-10-29 12:27:22	2017-10-09 09:54:08
23563	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21474	\N	2014-10-29 12:27:22	\N
23564	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21475	\N	2014-10-29 12:27:36	\N
23565	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21476	\N	2014-10-29 12:27:36	\N
23566	MEMBRE	2014-10-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21477	\N	2014-10-29 12:28:26	\N
23567	MEMBRE	2014-10-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21478	\N	2014-10-29 12:28:26	\N
23568	MEMBRE	2014-10-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21479	\N	2014-10-29 12:28:26	\N
23569	MEMBRE	2014-10-23 00:00:00	2015-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	21480	\N	2014-10-29 12:28:27	2015-01-14 10:11:41
23570	MEMBRE	2014-10-23 00:00:00	2015-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	21481	\N	2014-10-29 12:28:27	2015-01-27 17:08:04
23571	MEMBRE	2014-10-23 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	21482	\N	2014-10-29 12:28:27	2015-02-03 16:30:00
23572	MEMBRE	2014-10-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21483	\N	2014-10-29 12:28:27	\N
23573	MEMBRE	2014-10-23 00:00:00	2015-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	21484	\N	2014-10-29 12:28:27	2015-03-11 12:57:31
23574	MEMBRE	2014-10-22 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	21485	\N	2014-10-29 12:28:43	2015-02-20 11:59:55
23575	MEMBRE	2014-10-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21486	\N	2014-10-29 12:29:30	\N
24432	MEMBRE	2014-12-12 00:00:00	2016-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	22339	\N	2014-12-16 09:52:30	2016-12-07 16:42:59
24433	MEMBRE	2014-12-12 00:00:00	2015-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	22340	\N	2014-12-16 09:52:30	2015-01-23 12:05:21
24434	MEMBRE	2014-12-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22341	\N	2014-12-16 09:52:30	\N
24810	MEMBRE	2015-01-28 00:00:00	2015-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	22476	\N	2015-01-28 17:27:17	2015-03-11 10:57:46
24811	VICPDT	2015-01-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22106	2	2015-01-28 17:42:36	2015-01-28 17:42:43
24812	VICPDT	2015-01-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22260	3	2015-01-28 17:45:51	2015-01-28 17:46:02
24813	VICPDT	2015-01-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21669	4	2015-01-28 17:46:36	2015-01-28 17:47:35
24814	SECRET	2015-01-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21127	5	2015-01-28 17:47:53	2015-01-28 17:48:26
24980	VICPDT	2015-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21817	2	2015-02-05 12:04:31	2015-02-05 12:04:39
24981	VICPDT	2015-02-05 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	21417	3	2015-02-05 12:04:43	2017-05-16 15:18:14
24982	VICPDT	2015-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20665	4	2015-02-05 12:05:10	2015-02-05 12:05:24
24983	VICPDT	2015-02-05 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21148	5	2015-02-05 12:05:32	2015-02-05 12:05:45
24984	VICPDT	2015-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20307	6	2015-02-05 12:05:51	2015-02-05 12:06:26
24985	VICPDT	2015-02-05 00:00:00	2015-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	22152	7	2015-02-05 12:06:10	2015-05-26 11:57:04
24986	VICPDT	2015-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20746	7	2015-02-05 12:16:51	2015-05-26 11:57:15
24987	SECRET	2015-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21108	8	2015-02-05 12:17:08	2015-05-26 11:57:18
29422	MEMBRE	2017-10-01 00:00:00	2018-08-06 00:00:00	ANCIEN	\N	\N	\N	\N	25762	\N	\N	\N
24988	SECRET	2015-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22014	9	2015-02-05 12:17:22	2015-05-26 11:57:21
24989	SECRET	2015-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21628	10	2015-02-05 12:17:38	2015-05-26 11:57:25
24990	SECRET	2015-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21353	11	2015-02-05 12:18:06	2015-05-26 11:57:31
25043	VICPDT	2015-02-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21805	4	2015-02-06 14:45:56	2015-02-06 14:47:32
25044	VICPDT	2015-02-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21314	5	2015-02-06 14:46:03	2015-02-06 14:47:35
25045	VICPDT	2015-02-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20943	6	2015-02-06 14:46:14	2015-02-06 14:47:39
25046	VICPDT	2015-02-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21489	7	2015-02-06 14:46:24	2015-02-06 14:47:41
25047	VICPDT	2015-02-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21608	8	2015-02-06 14:46:33	2015-02-06 14:47:45
25048	VICPDT	2015-02-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21950	9	2015-02-06 14:46:44	2015-02-06 14:47:49
25049	VICPDT	2015-02-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20812	10	2015-02-06 14:47:07	2015-02-06 14:47:56
25050	VICPDT	2015-02-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20544	11	2015-02-06 14:47:16	2015-02-06 14:48:00
25051	VICPDT	2015-02-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20999	12	2015-02-06 14:47:22	2015-02-06 14:48:07
25052	SECRET	2015-02-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21430	11	2015-02-06 14:48:12	2015-02-06 14:48:25
25053	SECRET	2015-02-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21693	12	2015-02-06 14:48:18	2015-02-06 14:48:29
25167	MEMBRE	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22536	\N	2015-02-11 17:45:35	\N
25168	VICPDT	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21796	2	2015-02-11 18:01:12	2015-02-11 18:02:38
25169	VICPDT	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20867	3	2015-02-11 18:01:17	2015-02-11 18:02:41
25170	VICPDT	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20328	4	2015-02-11 18:01:27	2015-02-11 18:02:44
25171	VICPDT	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20623	5	2015-02-11 18:01:35	2015-02-11 18:02:50
25172	VICPDT	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21575	6	2015-02-11 18:01:46	2015-02-11 18:02:52
25173	SECRET	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22371	8	2015-02-11 18:01:55	2015-02-18 09:59:31
25174	SECRET	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20349	9	2015-02-11 18:02:00	2015-02-18 09:59:35
25175	SECRET	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20460	10	2015-02-11 18:02:05	2015-02-18 09:59:39
25176	SECRET	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21216	11	2015-02-11 18:02:10	2015-02-18 09:59:44
25177	SECRET	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21629	12	2015-02-11 18:02:13	2015-02-18 09:59:54
25178	MEMBRE	2015-02-09 00:00:00	2017-07-28 00:00:00	ANCIEN	\N	\N	\N	\N	22537	\N	2015-02-12 09:05:56	2017-08-03 11:38:41
25179	MEMBRE	2015-02-11 00:00:00	2015-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	22538	\N	2015-02-12 09:06:15	2015-03-11 11:01:06
25180	MEMBRE	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22539	\N	2015-02-12 09:06:15	\N
25181	MEMBRE	2015-02-10 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22540	\N	2015-02-12 09:06:28	\N
25182	MEMBRE	2015-02-11 00:00:00	2015-03-09 00:00:00	ANCIEN	\N	\N	\N	\N	22541	\N	2015-02-12 09:51:50	2015-03-10 17:25:26
25236	VICPDT	2015-02-13 00:00:00	2017-08-06 00:00:00	ANCIEN	\N	\N	\N	\N	20336	3	2015-02-13 11:33:34	2017-08-07 16:31:39
25337	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22619	\N	\N	\N
25568	MEMBRE	2015-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22816	\N	2015-02-16 17:00:40	\N
25774	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22935	\N	\N	\N
25871	MEMBRE	2015-02-19 00:00:00	2015-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	22955	\N	2015-02-23 09:42:25	2015-02-23 15:25:41
25894	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22967	\N	\N	\N
26134	VICPDT	2015-03-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21720	7	2015-03-10 10:00:45	2015-03-10 10:02:03
26135	VICPDT	2015-03-10 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	21419	8	2015-03-10 10:00:55	2017-05-16 15:18:14
26136	VICPDT	2015-03-10 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	21510	9	2015-03-10 10:01:03	2017-09-25 09:57:52
26137	VICPDT	2015-03-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21429	10	2015-03-10 10:01:17	2017-09-24 17:14:27
26138	VICPDT	2015-03-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20730	11	2015-03-10 10:01:22	2015-03-10 10:02:17
26139	VICPDT	2015-03-10 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	21867	12	2015-03-10 10:01:33	2016-03-11 18:02:51
26140	VICPDT	2015-03-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21008	13	2015-03-10 10:01:38	2015-03-10 10:02:24
26141	SECRET	2015-03-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20879	14	2015-03-10 10:01:48	2017-09-24 18:16:52
26142	SECRET	2015-03-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21400	15	2015-03-10 10:01:54	2015-03-10 10:02:27
26189	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23144	\N	\N	\N
26190	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23145	\N	\N	\N
26444	MEMBRE	2015-05-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23260	\N	2015-05-18 10:18:30	\N
26445	MEMBRE	2015-05-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23261	\N	2015-05-18 11:52:01	2017-09-24 17:06:55
26605	VICPDT	2015-07-07 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	23326	\N	\N	2016-03-11 18:02:51
26606	VICPDT	2015-07-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	23311	\N	\N	\N
26636	VICPDT	2015-08-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21643	2	2015-08-31 09:33:27	2017-09-24 13:44:49
26637	VICPDT	2015-08-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21300	3	2015-08-31 09:33:38	2017-09-24 17:19:42
26638	VICPDT	2015-08-31 00:00:00	2017-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	21144	4	2015-08-31 09:33:49	2015-08-31 09:34:11
26639	VICPDT	2015-08-31 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	21854	5	2015-08-31 09:34:17	2016-03-11 18:02:51
26640	VICPDT	2015-08-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20739	6	2015-08-31 09:34:34	2015-08-31 09:34:41
26641	VICPDT	2015-08-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20622	7	2015-08-31 09:34:50	2015-08-31 09:59:15
26701	MEMBRE	2015-11-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23429	\N	2015-11-20 15:55:20	\N
26724	MEMBRE	2016-02-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23445	\N	2016-02-01 17:36:58	\N
26904	MEMBRE	2016-05-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23611	\N	2016-05-04 09:41:36	\N
27082	MEMBRE	2016-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23774	\N	\N	2017-09-24 13:14:55
27083	MEMBRE	2016-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23775	\N	\N	\N
27118	MEMBRE	2016-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23810	\N	\N	\N
27388	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23955	\N	2017-10-11 15:51:06	\N
27389	MEMBRE	2017-10-10 00:00:00	2017-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	23956	\N	2017-10-11 15:51:06	2017-12-05 10:08:32
27390	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23957	\N	2017-10-11 15:51:06	\N
27391	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23958	\N	2017-10-11 15:51:06	\N
27392	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23959	\N	2017-10-11 15:52:51	\N
27393	MEMBRE	2017-10-10 00:00:00	2017-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	23960	\N	2017-10-11 15:52:51	2017-12-05 10:10:00
27394	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23961	\N	2017-10-11 15:52:51	\N
27395	MEMBRE	2017-10-10 00:00:00	2019-08-27 00:00:00	ANCIEN	\N	\N	\N	\N	23962	\N	2017-10-11 15:53:47	\N
27396	MEMBRE	2017-10-10 00:00:00	2017-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	23963	\N	2017-10-11 15:53:47	2017-12-14 18:21:26
27397	MEMBRE	2017-10-10 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	23964	\N	2017-10-11 15:53:47	2018-01-18 16:36:44
27398	MEMBRE	2017-10-10 00:00:00	2019-08-27 00:00:00	ANCIEN	\N	\N	\N	\N	23965	\N	2017-10-11 15:53:47	\N
27399	MEMBRE	2017-10-08 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	23966	\N	2017-10-11 15:54:40	2018-01-24 11:13:41
27400	MEMBRE	2017-10-08 00:00:00	2018-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	23967	\N	2017-10-11 15:54:40	2018-01-16 19:08:09
27401	MEMBRE	2017-10-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23968	\N	2017-10-11 15:54:40	\N
27402	MEMBRE	2017-10-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23969	\N	2017-10-11 15:54:40	\N
27403	MEMBRE	2017-10-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23970	\N	2017-10-11 15:54:40	\N
27404	MEMBRE	2017-10-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23971	\N	2017-10-11 15:54:40	\N
27405	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23972	\N	2017-10-11 15:55:36	\N
27406	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23973	\N	2017-10-11 15:55:37	\N
27407	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23974	\N	2017-10-11 15:55:37	\N
27408	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23975	\N	2017-10-11 16:12:53	\N
27409	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23976	\N	2017-10-11 16:12:53	\N
27410	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23977	\N	2017-10-11 16:17:47	\N
27411	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23978	\N	2017-10-11 16:17:47	\N
27412	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23979	\N	2017-10-11 16:17:47	\N
27413	MEMBRE	2017-10-10 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	23980	\N	2017-10-11 16:19:42	2018-01-18 16:41:49
27414	MEMBRE	2017-10-10 00:00:00	2017-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	23981	\N	2017-10-11 16:19:42	2017-12-05 16:09:22
27415	MEMBRE	2017-10-10 00:00:00	2017-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	23982	\N	2017-10-11 16:19:42	2017-12-14 18:20:44
27416	MEMBRE	2017-10-10 00:00:00	2018-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	23983	\N	2017-10-11 16:19:42	2018-02-01 18:30:38
27417	MEMBRE	2017-10-10 00:00:00	2018-03-04 00:00:00	ANCIEN	\N	\N	\N	\N	23984	\N	2017-10-11 16:19:42	2018-03-05 18:16:14
27418	MEMBRE	2017-10-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23985	\N	2017-10-11 16:19:42	\N
27419	MEMBRE	2017-10-10 00:00:00	2018-03-04 00:00:00	ANCIEN	\N	\N	\N	\N	23986	\N	2017-10-11 16:21:36	2018-03-05 17:58:20
27420	MEMBRE	2017-10-10 00:00:00	2017-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	23987	\N	2017-10-11 16:21:36	2017-12-14 15:46:17
27421	MEMBRE	2017-10-10 00:00:00	2017-12-26 00:00:00	ANCIEN	\N	\N	\N	\N	23988	\N	2017-10-11 16:21:36	2017-12-27 11:10:32
27422	MEMBRE	2017-10-10 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	23989	\N	2017-10-11 16:21:36	2018-01-18 11:35:50
27423	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23990	\N	2017-10-11 16:23:07	\N
27424	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23991	\N	2017-10-11 16:23:07	\N
27425	MEMBRE	2017-10-10 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	23992	\N	2017-10-11 16:23:07	2018-01-24 18:32:44
27426	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23993	\N	2017-10-11 16:23:07	\N
27427	MEMBRE	2017-10-10 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	23994	\N	2017-10-11 16:23:07	2018-01-23 18:43:41
27428	MEMBRE	2017-10-10 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	23995	\N	2017-10-11 16:23:07	2017-12-20 18:00:23
27429	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23996	\N	2017-10-11 16:23:07	\N
27430	MEMBRE	2017-10-10 00:00:00	2018-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	23997	\N	2017-10-11 16:23:07	2018-01-26 16:16:41
27431	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23998	\N	2017-10-11 16:23:07	\N
27432	MEMBRE	2017-10-10 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	23999	\N	2017-10-11 16:23:07	2018-02-07 16:33:55
27433	MEMBRE	2017-10-10 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	24000	\N	2017-10-11 16:23:07	2018-01-18 18:23:11
27434	MEMBRE	2017-10-10 00:00:00	2017-12-05 00:00:00	ANCIEN	\N	\N	\N	\N	24001	\N	2017-10-11 16:23:07	2017-12-06 15:09:11
27435	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24002	\N	2017-10-11 16:23:07	\N
27436	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24003	\N	2017-10-11 16:23:07	\N
27437	MEMBRE	2017-10-10 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	24004	\N	2017-10-11 16:23:07	2018-02-07 15:32:41
27438	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24005	\N	2017-10-11 16:23:07	\N
27439	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24006	\N	2017-10-11 16:23:07	\N
27440	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24007	\N	2017-10-11 16:23:07	\N
27441	MEMBRE	2017-10-09 00:00:00	2018-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	24008	\N	2017-10-11 16:24:56	2018-01-26 10:15:32
27442	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24009	\N	2017-10-11 16:24:56	\N
27443	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24010	\N	2017-10-11 16:24:56	\N
27444	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24011	\N	2017-10-11 16:24:56	\N
27445	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24012	\N	2017-10-11 16:24:56	\N
27446	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24013	\N	2017-10-11 16:24:56	\N
28749	MEMBRE	2017-11-17 00:00:00	2017-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	25316	\N	2017-11-17 16:52:16	2017-11-28 16:58:00
27873	MEMBRE	2017-10-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24440	\N	2017-10-20 10:10:41	\N
28748	MEMBRE	2017-11-17 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	25315	\N	2017-11-17 16:52:16	2018-01-18 18:10:48
29415	MEMBRE	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25755	\N	2017-12-22 13:49:14	\N
29418	MEMBRE	2017-12-07 00:00:00	2020-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	25758	\N	\N	\N
29421	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25761	\N	\N	\N
29426	MEMBRE	2017-12-07 00:00:00	2020-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	25766	\N	\N	\N
29427	MEMBRE	2017-12-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25767	\N	2017-12-26 10:23:01	\N
29428	MEMBRE	2017-12-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25768	\N	2017-12-26 10:23:57	\N
29429	MEMBRE	2017-12-22 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25769	\N	2017-12-26 10:24:55	\N
29430	MEMBRE	2017-12-22 00:00:00	2020-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	25770	\N	2017-12-26 10:25:09	\N
22336	MEMBRE	2014-09-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20280	\N	2014-09-03 09:32:32	\N
24406	MEMBRE	2014-12-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22313	\N	2014-12-04 15:08:24	\N
24866	VICPDT	2015-01-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20818	9	2015-01-30 15:54:31	2015-01-30 15:54:41
24867	VICPDT	2015-01-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21138	10	2015-01-30 15:55:04	2015-01-30 15:55:11
24868	VICPDT	2015-01-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21001	11	2015-01-30 15:55:22	2015-01-30 15:55:30
24869	VICPDT	2015-01-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22256	12	2015-01-30 15:55:44	2015-01-30 15:55:51
24870	VICPDT	2015-01-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20537	13	2015-01-30 15:56:05	2015-01-30 15:56:34
24871	SECRET	2015-01-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21810	15	2015-01-30 15:57:39	2015-01-30 15:57:44
24872	SECRET	2015-01-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22273	16	2015-01-30 15:57:52	2015-01-30 15:57:56
24873	SECRET	2015-01-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21385	17	2015-01-30 15:58:06	2015-01-30 15:58:12
24874	SECRET	2015-01-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20467	18	2015-01-30 15:58:22	2015-01-30 15:58:52
24875	MEMBRE	2015-01-20 00:00:00	2016-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	22496	\N	2015-01-30 17:04:45	2016-12-07 15:00:10
24967	VICPDT	2015-02-04 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20662	2	2015-02-04 18:16:23	2015-02-04 18:17:25
24968	VICPDT	2015-02-04 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21601	3	2015-02-04 18:16:31	2015-02-04 18:17:28
24969	VICPDT	2015-02-04 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21590	4	2015-02-04 18:16:41	2015-02-04 18:17:31
24970	VICPDT	2015-02-04 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21956	5	2015-02-04 18:16:53	2015-02-04 18:17:34
24971	SECRET	2015-02-04 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22225	6	2015-02-04 18:17:03	2015-02-04 18:17:38
24972	SECRET	2015-02-04 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21974	7	2015-02-04 18:17:09	2015-02-04 18:17:43
24973	SECRET	2015-02-04 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21243	8	2015-02-04 18:17:15	2015-02-04 18:17:54
25417	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22676	\N	\N	\N
25637	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22842	\N	\N	\N
25638	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22843	\N	\N	\N
25799	PDTHON	2015-02-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21699	2	2015-02-19 17:22:10	2015-02-19 17:22:19
25800	VICPDT	2015-02-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21803	3	2015-02-19 17:22:23	2015-02-19 17:24:22
25801	VICPDT	2015-02-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22042	4	2015-02-19 17:22:32	2015-02-19 17:24:25
25802	VICPDT	2015-02-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20375	5	2015-02-19 17:22:43	2015-02-19 17:24:28
25803	VICPDT	2015-02-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21939	6	2015-02-19 17:23:02	2015-02-19 17:24:32
25804	VICPDT	2015-02-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21574	7	2015-02-19 17:23:09	2015-02-19 17:24:36
25805	VICPDT	2015-02-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20343	8	2015-02-19 17:23:17	2015-02-19 17:24:42
25806	SECRET	2015-02-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22113	9	2015-02-19 17:23:29	2015-02-19 17:24:46
25807	SECRET	2015-02-19 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	22119	10	2015-02-19 17:23:40	2015-06-12 15:59:18
25808	SECRET	2015-02-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20771	11	2015-02-19 17:24:12	2015-02-24 11:28:39
25809	VICPDT	2015-02-19 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	21423	4	2015-02-19 18:03:37	2017-05-16 15:18:14
25810	VICPDT	2015-02-19 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	21825	5	2015-02-19 18:03:45	2016-12-12 16:10:15
25811	VICPDT	2015-02-19 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20451	6	2015-02-19 18:03:51	2015-11-12 15:26:22
25812	VICPDT	2015-02-19 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	22317	7	2015-02-19 18:04:00	2016-03-11 18:02:51
25813	SECRET	2015-02-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22289	8	2015-02-19 18:04:07	2015-02-19 18:04:57
25814	SECRET	2015-02-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20819	9	2015-02-19 18:04:11	2015-02-19 18:05:00
25815	SECRET	2015-02-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21120	10	2015-02-19 18:04:17	2015-02-19 18:05:03
25816	SECRET	2015-02-19 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21167	11	2015-02-19 18:04:21	2015-02-19 18:05:08
25817	SECRET	2015-02-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20708	12	2015-02-19 18:04:26	2015-02-19 18:05:13
25818	MEMBRE	2015-02-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22946	\N	2015-02-19 18:06:00	\N
25896	MEMBRE	2015-02-04 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22969	\N	2015-02-26 09:16:47	\N
26219	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23162	\N	\N	\N
26232	VICPDT	2015-03-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23124	\N	\N	2017-09-24 17:29:37
26233	PDT	2015-03-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	22835	\N	\N	\N
26237	VICPDT	2015-03-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20324	8	2015-03-19 09:55:16	2017-09-24 18:59:59
26238	VICPDT	2015-03-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22148	9	2015-03-19 09:57:27	2017-09-24 17:47:27
26239	VICPDT	2015-03-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20520	10	2015-03-19 09:57:33	2017-09-24 19:25:10
26240	VICPDT	2015-03-19 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	21861	11	2015-03-19 09:57:38	2016-03-11 18:02:51
26241	VICPDT	2015-03-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22451	12	2015-03-19 09:57:44	2015-03-19 09:58:58
26242	SECRET	2015-03-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21137	13	2015-03-19 09:58:05	2015-03-19 09:59:06
26243	SECRET	2015-03-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21105	14	2015-03-19 09:58:10	2015-03-19 09:59:13
26244	VICPDT	2015-03-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20842	2	2015-03-19 10:02:20	2017-09-24 18:16:52
26245	VICPDT	2015-03-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21088	3	2015-03-19 10:02:27	2015-03-19 10:04:05
26246	VICPDT	2015-03-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21706	4	2015-03-19 10:02:37	2017-10-01 10:39:23
26247	VICPDT	2015-03-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21611	5	2015-03-19 10:02:50	2017-09-24 13:57:40
26248	VICPDT	2015-03-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21281	7	2015-03-19 10:02:59	2015-03-19 10:04:47
26249	VICPDT	2015-03-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20546	8	2015-03-19 10:03:05	2017-09-24 17:35:15
26250	SECRET	2015-03-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22227	9	2015-03-19 10:03:12	2017-09-24 18:07:57
26251	SECRET	2015-03-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21080	10	2015-03-19 10:03:17	2015-03-19 10:06:11
26252	SECRET	2015-03-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22439	11	2015-03-19 10:03:20	2015-03-19 10:06:27
26253	SECRET	2015-03-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22391	12	2015-03-19 10:03:28	2015-03-19 10:06:30
26254	SECRET	2015-03-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20767	13	2015-03-19 10:03:35	2017-09-24 18:17:56
26255	SECRET	2015-03-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22396	14	2015-03-19 10:03:41	2015-03-19 10:06:36
26256	SECRET	2015-03-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22376	15	2015-03-19 10:03:44	2015-11-12 15:26:22
26257	SECRET	2015-03-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22251	16	2015-03-19 10:03:51	2017-09-24 16:24:51
26258	VICPDT	2015-03-19 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	21765	6	2015-03-19 10:04:35	2017-09-25 09:56:00
26416	MEMBRE	2015-03-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23254	\N	2015-05-11 10:10:05	\N
26417	MEMBRE	2015-05-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23255	\N	2015-05-12 10:11:55	\N
26477	MEMBRE	2015-05-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	23278	\N	\N	\N
26483	PDT	2015-05-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23135	\N	\N	2017-09-24 17:29:37
26484	PDT	2015-05-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	23136	\N	\N	\N
26485	VICPDT	2015-05-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22829	\N	\N	2017-09-24 13:25:54
26486	VICPDT	2015-05-28 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	23243	\N	\N	2016-12-12 16:10:15
26487	VICPDT	2015-05-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23132	\N	\N	2017-09-24 17:48:21
26488	VICPDT	2015-05-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	22604	\N	\N	\N
26489	SECRET	2015-05-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	22605	\N	\N	\N
26517	MEMBRE	2015-06-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23292	\N	2015-06-12 14:19:41	\N
26598	MEMBRE	2015-07-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23373	\N	2015-07-07 09:13:16	\N
26612	MEMBRE	2015-07-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23374	\N	2015-07-08 09:31:07	\N
26613	MEMBRE	2015-07-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23375	\N	2015-07-08 09:36:39	\N
26614	PDTDEL	2015-07-08 00:00:00	2017-06-01 00:00:00	ANCIEN	\N	\N	pour le Kazakhstan	\N	23252	2	2015-07-08 16:47:08	2017-06-02 10:02:57
26615	PDT	2015-07-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23294	1	2015-07-09 15:07:31	2015-07-09 15:07:42
26616	MEMBRE	2015-07-09 00:00:00	2015-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	21173	\N	2015-07-09 15:11:15	2015-10-07 15:22:44
26617	PDT	2015-07-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21484	1	2015-07-09 15:11:20	2015-07-09 15:11:34
26627	SECRET	2015-07-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	23370	\N	\N	\N
26898	MEMBRE	2016-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23606	\N	2016-04-07 09:18:03	2017-10-01 10:34:22
26899	MEMBRE	2016-04-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23607	\N	2016-04-08 09:24:37	2017-09-24 13:57:40
26915	MEMBRE	2016-05-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23621	\N	2016-05-26 14:47:45	\N
27023	MEMBRE	2016-06-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23721	\N	2016-07-11 15:56:57	\N
27024	MEMBRE	2016-05-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23722	\N	2016-07-11 15:58:03	\N
27053	MEMBRE	2016-09-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23751	\N	2016-09-20 15:54:25	\N
27081	MEMBRE	2016-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23773	\N	\N	\N
27100	MEMBRE	2016-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23792	\N	\N	\N
25183	VICPDT	2015-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21989	2	2015-02-12 12:42:44	2015-02-12 12:45:55
25184	VICPDT	2015-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21711	3	2015-02-12 12:42:51	2015-02-12 12:45:58
25185	VICPDT	2015-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20519	4	2015-02-12 12:43:01	2015-02-12 12:46:01
25186	VICPDT	2015-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20748	5	2015-02-12 12:43:10	2015-02-12 12:46:04
25187	VICPDT	2015-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20530	6	2015-02-12 12:43:15	2015-02-12 12:46:07
25188	VICPDT	2015-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20726	7	2015-02-12 12:43:23	2015-02-12 12:46:14
25189	VICPDT	2015-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20465	8	2015-02-12 12:43:28	2015-02-12 12:46:20
25190	VICPDT	2015-02-12 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	21764	9	2015-02-12 12:43:33	2017-09-25 09:56:00
25191	VICPDT	2015-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21279	10	2015-02-12 12:44:59	2015-02-12 12:46:26
25192	SECRET	2015-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21791	11	2015-02-12 12:45:07	2015-02-12 12:46:38
25193	SECRET	2015-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22161	12	2015-02-12 12:45:12	2015-02-12 12:46:41
25194	SECRET	2015-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21368	13	2015-02-12 12:45:16	2015-02-12 12:46:44
25195	SECRET	2015-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20493	14	2015-02-12 12:45:23	2015-02-12 12:46:48
25196	SECRET	2015-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21303	15	2015-02-12 12:45:28	2015-02-12 12:46:51
25197	SECRET	2015-02-12 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21143	16	2015-02-12 12:45:34	2015-02-12 12:46:54
25198	SECRET	2015-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21955	17	2015-02-12 12:45:41	2015-02-12 12:46:56
25199	SECRET	2015-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22399	18	2015-02-12 12:45:47	2015-02-12 12:46:59
25200	VICPDT	2015-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21725	2	2015-02-12 15:35:20	2015-02-12 15:36:14
25201	VICPDT	2015-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22531	3	2015-02-12 15:35:25	2015-02-12 15:36:17
25202	VICPDT	2015-02-12 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21166	4	2015-02-12 15:35:32	2015-02-12 15:36:19
25203	VICPDT	2015-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21771	5	2015-02-12 15:35:41	2015-02-12 15:36:23
25204	VICPDT	2015-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20944	6	2015-02-12 15:35:46	2015-02-12 15:37:02
25205	SECRET	2015-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22195	10	2015-02-12 16:24:34	2015-02-12 16:25:33
25378	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22648	\N	\N	\N
25379	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22649	\N	\N	\N
25380	MEMBRE	2014-10-01 00:00:00	2015-03-24 00:00:00	ANCIEN	\N	\N	\N	\N	22650	\N	\N	\N
25381	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22651	\N	\N	2017-09-24 19:31:54
26450	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23266	\N	\N	\N
26452	PDT	2015-05-20 00:00:00	2015-05-22 00:00:00	ANCIEN	\N	\N	\N	\N	23101	\N	\N	\N
26521	MEMBRE	2015-06-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23296	\N	2015-06-30 16:28:32	\N
26642	SECRET	2015-08-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21142	8	2015-08-31 09:59:18	2015-08-31 10:00:05
26643	SECRET	2015-08-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20766	9	2015-08-31 09:59:31	2017-09-24 18:17:56
26644	SECRET	2015-08-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20299	10	2015-08-31 09:59:38	2017-09-24 18:59:59
27026	MEMBRE	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23724	\N	\N	2017-09-24 17:06:55
27121	MEMBRE	2016-11-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23813	\N	2016-11-09 11:54:24	\N
27799	MEMBRE	2017-10-18 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	24366	\N	2017-10-19 10:28:01	2018-01-18 18:23:32
27800	MEMBRE	2017-10-18 00:00:00	2018-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	24367	\N	2017-10-19 10:28:01	2018-02-14 18:34:19
27801	MEMBRE	2017-10-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24368	\N	2017-10-19 10:28:01	\N
27802	MEMBRE	2017-10-18 00:00:00	2017-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	24369	\N	2017-10-19 10:28:02	2017-12-14 15:50:21
27803	MEMBRE	2017-10-18 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24370	\N	2017-10-19 10:28:02	2018-01-24 18:08:46
27804	MEMBRE	2017-10-18 00:00:00	2017-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	24371	\N	2017-10-19 10:30:36	2017-12-05 16:39:13
27805	MEMBRE	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24372	\N	2017-10-19 10:31:19	\N
27806	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24373	\N	2017-10-19 10:32:14	\N
27807	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24374	\N	2017-10-19 10:32:14	\N
27808	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24375	\N	2017-10-19 10:32:14	\N
27809	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24376	\N	2017-10-19 10:32:14	\N
27810	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24377	\N	2017-10-19 10:32:14	\N
27811	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24378	\N	2017-10-19 10:32:14	\N
27812	MEMBRE	2017-10-10 00:00:00	2018-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	24379	\N	2017-10-19 10:32:14	2018-03-07 17:12:24
27813	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24380	\N	2017-10-19 10:32:14	\N
27814	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24381	\N	2017-10-19 10:32:14	\N
27815	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24382	\N	2017-10-19 10:32:14	\N
27816	MEMBRE	2017-10-10 00:00:00	2018-03-04 00:00:00	ANCIEN	\N	\N	\N	\N	24383	\N	2017-10-19 10:32:14	2018-03-05 17:19:03
27817	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24384	\N	2017-10-19 10:32:14	\N
27818	MEMBRE	2017-10-10 00:00:00	2018-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	24385	\N	2017-10-19 10:32:14	2018-01-26 10:16:39
27819	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24386	\N	2017-10-19 10:32:14	\N
27820	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24387	\N	2017-10-19 10:32:14	\N
27821	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24388	\N	2017-10-19 10:32:14	\N
27822	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24389	\N	2017-10-19 10:32:14	\N
27823	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24390	\N	2017-10-19 10:32:14	\N
27824	MEMBRE	2017-10-17 00:00:00	2017-12-05 00:00:00	ANCIEN	\N	\N	\N	\N	24391	\N	2017-10-19 11:27:20	2017-12-06 15:17:27
27825	MEMBRE	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24392	\N	2017-10-19 11:50:33	\N
27910	MEMBRE	2017-10-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24477	\N	2017-10-24 09:57:23	\N
27911	MEMBRE	2017-10-18 00:00:00	2018-03-04 00:00:00	ANCIEN	\N	\N	\N	\N	24478	\N	2017-10-24 09:57:23	2018-03-05 17:18:09
27912	MEMBRE	2017-10-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24479	\N	2017-10-24 09:57:23	\N
27913	MEMBRE	2017-10-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24480	\N	2017-10-24 09:57:23	\N
27914	MEMBRE	2017-10-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24481	\N	2017-10-24 09:57:23	\N
27915	MEMBRE	2017-10-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24482	\N	2017-10-24 09:58:20	\N
27916	MEMBRE	2017-10-20 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	24483	\N	2017-10-24 09:58:20	2018-02-07 15:30:21
27917	MEMBRE	2017-10-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24484	\N	2017-10-24 09:58:20	\N
27918	MEMBRE	2017-10-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24485	\N	2017-10-24 09:58:20	\N
27919	MEMBRE	2017-10-20 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	24486	\N	2017-10-24 09:58:20	2018-01-23 16:56:50
27920	MEMBRE	2017-10-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24487	\N	2017-10-24 09:58:20	\N
27921	MEMBRE	2017-10-20 00:00:00	2017-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	24488	\N	2017-10-24 09:58:20	2017-11-28 16:29:08
27922	MEMBRE	2017-10-20 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	24489	\N	2017-10-24 09:58:20	2018-02-07 12:15:13
27923	MEMBRE	2017-10-20 00:00:00	2018-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	24490	\N	2017-10-24 09:58:20	2018-02-01 18:32:50
27924	MEMBRE	2017-10-20 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24491	\N	2017-10-24 09:58:20	2018-01-24 18:06:47
27925	MEMBRE	2017-10-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24492	\N	2017-10-24 09:58:20	\N
27926	MEMBRE	2017-10-19 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	24493	\N	2017-10-24 09:59:38	\N
27927	MEMBRE	2017-10-19 00:00:00	2018-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	24494	\N	2017-10-24 09:59:38	2018-01-30 12:30:51
27928	MEMBRE	2017-10-19 00:00:00	2018-02-23 00:00:00	ANCIEN	\N	\N	\N	\N	24495	\N	2017-10-24 09:59:38	2018-02-21 15:39:12
27929	MEMBRE	2017-10-19 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	24496	\N	2017-10-24 09:59:38	\N
27930	MEMBRE	2017-10-19 00:00:00	2018-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	24497	\N	2017-10-24 09:59:38	2018-01-16 19:11:01
27931	MEMBRE	2017-10-19 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	24498	\N	2017-10-24 09:59:38	\N
27932	MEMBRE	2017-10-19 00:00:00	2018-01-21 00:00:00	ANCIEN	\N	\N	\N	\N	24499	\N	2017-10-24 09:59:38	2018-01-19 10:24:17
27933	MEMBRE	2017-10-19 00:00:00	2018-03-07 00:00:00	ANCIEN	\N	\N	\N	\N	24500	\N	2017-10-24 09:59:38	2018-03-05 17:57:58
27934	MEMBRE	2017-10-19 00:00:00	2018-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	24501	\N	2017-10-24 09:59:38	2018-01-16 19:06:45
27935	MEMBRE	2017-10-19 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	24502	\N	2017-10-24 09:59:38	\N
27936	MEMBRE	2017-10-19 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	24503	\N	2017-10-24 09:59:38	\N
27937	MEMBRE	2017-10-19 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	24504	\N	2017-10-24 09:59:39	\N
27938	MEMBRE	2017-10-19 00:00:00	2018-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	24505	\N	2017-10-24 09:59:39	2018-01-29 10:20:49
27939	MEMBRE	2017-10-19 00:00:00	2018-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	24506	\N	2017-10-24 09:59:39	2018-02-15 10:21:45
27940	MEMBRE	2017-10-19 00:00:00	2018-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	24507	\N	2017-10-24 09:59:39	2018-02-07 17:30:55
27941	MEMBRE	2017-10-19 00:00:00	2018-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	24508	\N	2017-10-24 09:59:39	2018-01-25 10:59:48
27942	MEMBRE	2017-10-19 00:00:00	2018-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	24509	\N	2017-10-24 09:59:39	2018-01-18 16:40:54
27943	MEMBRE	2017-10-19 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	24510	\N	2017-10-24 09:59:39	\N
27944	MEMBRE	2017-10-19 00:00:00	2018-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	24511	\N	2017-10-24 09:59:39	2018-01-18 18:23:01
27945	MEMBRE	2017-10-19 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	24512	\N	2017-10-24 09:59:39	\N
27946	MEMBRE	2017-10-19 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	24513	\N	2017-10-24 09:59:39	\N
22422	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20366	\N	2014-10-15 13:26:29	\N
22423	MEMBRE	2014-10-15 00:00:00	2015-03-09 00:00:00	ANCIEN	\N	\N	\N	\N	20367	\N	2014-10-15 13:26:29	2015-03-10 17:27:36
22424	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20368	\N	2014-10-15 13:26:29	\N
22425	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20369	\N	2014-10-15 13:26:29	\N
22426	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20370	\N	2014-10-15 13:26:29	\N
22427	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20371	\N	2014-10-15 13:26:29	\N
22428	MEMBRE	2014-10-15 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	20372	\N	2014-10-15 13:26:29	2015-01-06 17:48:01
22429	MEMBRE	2014-10-15 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	20373	\N	2014-10-15 13:26:29	2015-02-03 16:27:52
22430	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20374	\N	2014-10-15 13:26:29	\N
22431	MEMBRE	2014-10-15 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	20375	\N	2014-10-15 13:26:29	2015-02-19 17:22:43
22432	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20376	\N	2014-10-15 13:26:29	\N
22654	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20598	\N	2014-10-21 17:21:57	2014-10-21 17:22:10
23391	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21302	\N	2014-10-28 16:07:21	\N
24348	MEMBRE	2014-11-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22255	\N	2014-11-20 09:45:02	\N
24353	MEMBRE	2014-11-19 00:00:00	2015-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	22260	\N	2014-11-20 14:47:49	2015-01-28 17:45:51
24407	MEMBRE	2014-12-04 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22314	\N	2014-12-04 15:49:08	\N
24709	MEMBRE	2015-01-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22434	\N	2015-01-22 14:58:23	\N
24859	SECRET	2015-01-30 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	22494	14	2015-01-30 12:40:35	2017-06-19 16:04:13
24860	MEMBRE	2015-01-30 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	21420	\N	2015-01-30 14:45:40	2017-05-16 15:18:14
24945	MEMBRE	2015-01-22 00:00:00	2015-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	22510	\N	2015-02-04 11:40:06	2015-02-04 11:47:05
24946	PDTDEL	2015-02-04 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour le Mozambique	\N	22510	6	2015-02-04 11:47:05	2015-03-10 10:00:39
24979	MEMBRE	2015-02-02 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22524	\N	2015-02-05 11:58:23	\N
24992	VICPDT	2015-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21797	2	2015-02-05 18:51:13	2015-02-05 18:51:21
24993	VICPDT	2015-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20897	3	2015-02-05 18:51:27	2015-02-05 18:52:31
24994	VICPDT	2015-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21781	4	2015-02-05 18:51:36	2015-02-05 18:52:35
24995	VICPDT	2015-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20292	5	2015-02-05 18:51:45	2015-02-05 18:52:39
24996	VICPDT	2015-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20882	6	2015-02-05 18:51:55	2015-02-05 18:52:50
24997	SECRET	2015-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21078	8	2015-02-05 18:52:07	2015-02-05 18:52:52
24998	SECRET	2015-02-05 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	20345	9	2015-02-05 18:52:17	2017-06-19 16:06:01
24999	VICPDT	2015-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20554	6	2015-02-05 18:54:25	2015-02-06 16:45:23
25000	VICPDT	2015-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20940	7	2015-02-05 18:54:46	2015-02-06 16:45:57
25001	VICPDT	2015-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21576	8	2015-02-05 18:54:56	2015-02-06 16:46:06
25002	VICPDT	2015-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21023	9	2015-02-05 18:55:15	2015-02-06 16:46:10
25003	VICPDT	2015-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21694	10	2015-02-05 18:55:28	2015-02-06 16:46:23
25004	VICPDT	2015-02-05 00:00:00	2015-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	20998	12	2015-02-05 18:55:34	2015-05-26 11:54:43
25005	SECRET	2015-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22348	12	2015-02-05 18:55:43	2015-05-26 11:55:54
25006	SECRET	2015-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21564	13	2015-02-05 18:55:50	2015-05-26 11:56:00
25007	SECRET	2015-02-05 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	21416	14	2015-02-05 18:55:59	2017-05-16 15:18:14
25008	SECRET	2015-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20710	15	2015-02-05 18:56:06	2015-05-26 11:56:09
25009	SECRET	2015-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21546	16	2015-02-05 18:56:11	2015-05-26 11:56:17
25010	VICPDT	2015-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20510	2	2015-02-05 18:57:44	2015-02-05 19:03:55
25011	VICPDT	2015-02-05 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	22118	3	2015-02-05 18:57:51	2015-06-12 15:59:18
25012	VICPDT	2015-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21374	4	2015-02-05 18:57:57	2015-02-05 19:04:01
25013	VICPDT	2015-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21306	5	2015-02-05 18:58:04	2015-02-05 19:04:03
25014	VICPDT	2015-02-05 00:00:00	2017-07-28 00:00:00	ANCIEN	\N	\N	\N	\N	22401	6	2015-02-05 18:58:15	2017-08-03 11:38:41
25015	VICPDT	2015-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21331	7	2015-02-05 18:58:27	2015-02-05 19:04:08
25016	VICPDT	2015-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21704	8	2015-02-05 18:58:34	2015-02-05 19:04:11
25017	VICPDT	2015-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20885	9	2015-02-05 18:58:38	2015-02-05 19:04:18
25018	VICPDT	2015-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21075	10	2015-02-05 18:58:49	2015-02-05 19:04:24
25019	VICPDT	2015-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22192	11	2015-02-05 18:59:04	2015-02-05 19:04:29
25020	VICPDT	2015-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20322	12	2015-02-05 18:59:10	2015-02-05 19:04:36
25021	VICPDT	2015-02-05 00:00:00	2017-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20750	13	2015-02-05 18:59:18	2017-10-09 09:55:19
25022	VICPDT	2015-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21605	14	2015-02-05 18:59:25	2015-02-05 19:04:42
25023	VICPDT	2015-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21100	15	2015-02-05 19:00:03	2015-02-05 19:04:48
25024	VICPDT	2015-02-05 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	20690	16	2015-02-05 19:00:16	2015-06-12 15:59:49
25025	VICPDT	2015-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21320	17	2015-02-05 19:00:28	2015-02-05 19:05:00
25026	VICPDT	2015-02-05 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	21880	18	2015-02-05 19:00:40	2016-03-11 18:02:51
25027	VICPDT	2015-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21181	19	2015-02-05 19:00:46	2015-02-05 19:05:05
25028	VICPDT	2015-02-05 00:00:00	2017-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	21908	20	2015-02-05 19:00:53	2017-10-05 09:38:03
25029	VICPDT	2015-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20549	21	2015-02-05 19:01:03	2015-02-05 19:05:11
25030	SECRET	2015-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21901	22	2015-02-05 19:02:19	2015-02-05 19:05:41
25031	SECRET	2015-02-05 00:00:00	2015-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	22120	23	2015-02-05 19:02:26	2015-02-06 14:27:55
25032	SECRET	2015-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21460	241	2015-02-05 19:02:35	2015-02-05 19:05:46
25033	SECRET	2015-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21116	25	2015-02-05 19:02:43	2015-02-05 19:05:48
25034	SECRET	2015-02-05 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	21846	26	2015-02-05 19:02:50	2016-12-12 16:10:15
25035	SECRET	2015-02-05 00:00:00	2015-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	20385	27	2015-02-05 19:02:55	2015-04-07 16:50:27
25036	SECRET	2015-02-05 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21149	28	2015-02-05 19:03:01	2015-02-05 19:06:02
25037	SECRET	2015-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22179	29	2015-02-05 19:03:14	2015-02-05 19:06:04
25038	SECRET	2015-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20518	30	2015-02-05 19:03:18	2015-02-05 19:06:07
25039	SECRET	2015-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20528	31	2015-02-05 19:03:25	2015-02-05 19:06:20
25040	SECRET	2015-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22214	32	2015-02-05 19:03:30	2015-02-05 19:06:27
25041	SECRET	2015-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21500	33	2015-02-05 19:03:45	2015-02-05 19:06:34
25042	MEMBRE	2015-02-03 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	22526	\N	2015-02-06 09:23:15	2017-09-25 09:57:52
25237	VICPDT	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20291	7	2015-02-13 11:33:42	2016-03-16 18:03:14
25238	VICPDT	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22422	4	2015-02-13 11:33:52	2015-02-13 11:35:25
25239	VICPDT	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21112	5	2015-02-13 11:34:00	2015-02-13 11:35:30
25240	VICPDT	2015-02-13 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	21831	6	2015-02-13 11:34:06	2016-12-12 16:10:15
25241	VICPDT	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20934	8	2015-02-13 11:34:16	2016-03-16 18:03:26
25242	VICPDT	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20362	9	2015-02-13 11:34:23	2016-03-16 18:03:58
25243	VICPDT	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22105	10	2015-02-13 11:34:29	2016-03-16 18:03:31
25244	VICPDT	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21447	11	2015-02-13 11:34:35	2016-03-16 18:04:15
25245	VICPDT	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21099	12	2015-02-13 11:34:53	2016-03-16 18:04:23
25246	VICPDT	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21005	13	2015-02-13 11:35:04	2016-03-16 18:04:40
25247	SECRET	2015-02-13 00:00:00	2016-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	22088	13	2015-02-13 11:37:27	2016-03-16 16:02:09
25248	SECRET	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20926	17	2015-02-13 11:37:39	2016-03-16 18:05:16
25249	SECRET	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22033	18	2015-02-13 11:37:45	2016-03-16 18:05:31
25250	SECRET	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22217	14	2015-02-13 11:37:53	2016-03-16 18:04:46
25251	SECRET	2015-02-13 00:00:00	2017-07-28 00:00:00	ANCIEN	\N	\N	\N	\N	20338	15	2015-02-13 11:37:59	2017-08-03 11:38:41
25359	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22629	\N	\N	\N
25360	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22630	\N	\N	2017-09-25 10:58:49
25362	MEMBRE	2014-10-01 00:00:00	2017-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	22632	\N	\N	2017-07-04 15:08:09
25366	MEMBRE	2014-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22636	\N	\N	2017-10-01 09:41:22
25367	MEMBRE	2014-10-01 00:00:00	2015-03-24 00:00:00	ANCIEN	\N	\N	\N	\N	22637	\N	\N	\N
25370	MEMBRE	2014-10-01 00:00:00	2015-03-24 00:00:00	ANCIEN	\N	\N	\N	\N	22640	\N	\N	\N
25403	MEMBRE	2015-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22673	\N	2015-02-13 16:36:18	\N
25404	VICPDT	2015-02-13 00:00:00	2015-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	20403	52	2015-02-13 17:03:17	2015-02-16 16:00:07
25405	VICPDT	2015-02-13 00:00:00	2015-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	21086	4	2015-02-13 17:03:25	2015-02-16 16:00:03
25406	VICPDT	2015-02-13 00:00:00	2015-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	22254	3	2015-02-13 17:03:34	2015-02-16 15:59:58
25407	VICPDT	2015-02-13 00:00:00	2015-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	21661	6	2015-02-13 17:03:45	2015-02-16 16:00:32
25408	VICPDT	2015-02-13 00:00:00	2015-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	22218	2	2015-02-13 17:03:57	2015-02-16 15:59:50
25409	SECRET	2015-02-13 00:00:00	2015-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	21952	12	2015-02-13 17:04:04	2015-02-16 16:00:28
25410	SECRET	2015-02-13 00:00:00	2015-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	22030	11	2015-02-13 17:04:11	2015-02-16 16:00:22
25411	SECRET	2015-02-13 00:00:00	2015-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	20303	9	2015-02-13 17:04:15	2015-02-16 16:00:15
25412	SECRET	2015-02-13 00:00:00	2015-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	21196	7	2015-02-13 17:04:19	2015-02-16 16:00:10
25413	SECRET	2015-02-13 00:00:00	2015-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	20439	10	2015-02-13 17:04:23	2015-02-16 16:00:25
25414	SECRET	2015-02-13 00:00:00	2015-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	21898	8	2015-02-13 17:04:27	2015-02-16 16:00:19
26882	PDT	2016-03-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21667	1	2016-03-16 11:35:59	2016-03-16 11:36:07
26883	VICPDT	2016-03-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22088	2	2016-03-16 16:02:09	2016-03-16 18:02:53
27709	MEMBRE	2017-10-17 00:00:00	2020-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	24276	\N	2017-10-18 11:38:12	\N
27710	MEMBRE	2017-10-17 00:00:00	2020-10-19 00:00:00	ANCIEN	\N	\N	\N	\N	24277	\N	2017-10-18 11:49:10	\N
28659	MEMBRE	2017-11-09 00:00:00	2017-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	25226	\N	2017-11-10 11:39:17	2017-12-01 14:57:40
28660	MEMBRE	2017-11-09 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	25227	\N	2017-11-10 11:39:17	2018-01-24 10:40:53
28661	MEMBRE	2017-11-08 00:00:00	2017-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	25228	\N	2017-11-10 12:13:11	2017-12-01 14:51:54
29038	MEMBRE	2017-11-29 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	25529	\N	2017-12-04 15:40:15	2017-12-20 17:41:04
29039	MEMBRE	2017-12-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25530	\N	2017-12-04 15:40:37	\N
29165	PDTDEL	2017-12-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Amérique centrale	\N	25371	\N	2017-12-12 17:14:51	2017-12-12 17:15:12
29166	MEMBRE	2017-12-12 00:00:00	2018-03-04 00:00:00	ANCIEN	\N	\N	\N	\N	24697	\N	2017-12-12 17:17:22	2018-03-05 18:15:52
29167	MEMBRE	2017-12-12 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24305	\N	2017-12-12 17:21:19	2018-01-24 15:53:34
29168	PDTDEL	2017-12-12 00:00:00	2020-06-24 00:00:00	ANCIEN	\N	\N	Guinée-Bissau	\N	25085	\N	2017-12-12 17:22:27	2017-12-12 17:22:51
29169	PDTDEL	2017-12-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Guinée (Conakry)	\N	23913	\N	2017-12-12 17:24:00	2017-12-12 17:24:25
29170	PDTDEL	2017-12-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Mauritanie	\N	25484	\N	2017-12-12 17:24:49	2017-12-12 17:25:01
29171	PDTDEL	2017-12-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Sierra Leone	\N	25267	\N	2017-12-12 17:25:26	2017-12-12 17:25:46
29172	PDTDEL	2017-12-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Togo	\N	24327	\N	2017-12-12 17:26:00	2017-12-12 17:26:33
29173	PDTDEL	2017-12-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Bénin	\N	24944	\N	2017-12-12 17:27:04	2017-12-12 17:27:19
29174	PDTDEL	2017-12-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	Chili	\N	24316	\N	2017-12-12 17:28:15	2017-12-12 17:28:22
29175	PDTDEL	2017-12-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Bangladesh	\N	24623	\N	2017-12-12 17:29:00	2017-12-12 17:29:12
29176	PDTDEL	2017-12-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	Philippines	\N	24537	\N	2017-12-12 17:29:45	2017-12-12 17:30:04
29177	PDTDEL	2017-12-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Laos	\N	25453	\N	2017-12-12 17:31:31	2017-12-12 17:31:38
29178	PDTDEL	2017-12-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Serbie	\N	23903	\N	2017-12-12 17:33:06	2017-12-12 17:33:14
29179	PDTDEL	2017-12-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Suède	\N	24630	\N	2017-12-12 17:33:59	2017-12-12 17:34:10
29180	PDTDEL	2017-12-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Vénézuela	\N	25479	\N	2017-12-12 17:34:46	2017-12-12 17:34:54
29181	PDTDEL	2017-12-12 00:00:00	2018-02-01 00:00:00	ANCIEN	\N	\N	Zambie	\N	25515	\N	2017-12-12 17:35:20	2018-02-02 10:02:51
29182	PDTDEL	2017-12-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	Mozambique	\N	24776	\N	2017-12-12 17:36:03	2017-12-12 17:36:12
29417	MEMBRE	2017-12-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25757	\N	\N	\N
29431	MEMBRE	2017-12-21 00:00:00	2018-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	25771	\N	2017-12-26 10:25:26	2018-01-16 18:59:49
29432	VICPDT	2017-12-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25528	\N	2017-12-27 11:00:05	\N
29433	VICPDT	2017-12-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24946	\N	2017-12-27 11:10:03	\N
29434	VICPDT	2017-12-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24035	\N	2017-12-27 11:10:12	\N
29435	VICPDT	2017-12-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25406	\N	2017-12-27 11:10:24	\N
29436	VICPDT	2017-12-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23988	\N	2017-12-27 11:10:32	\N
29437	SECRET	2017-12-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25559	\N	2017-12-27 11:10:48	2017-12-27 11:12:54
29438	SECRET	2017-12-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25256	\N	2017-12-27 11:11:01	2017-12-27 11:12:46
29439	SECRET	2017-12-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23928	\N	2017-12-27 11:11:26	2017-12-27 11:13:03
29440	MEMBRE	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25772	\N	2017-12-27 11:24:20	\N
29441	MEMBRE	2017-12-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25773	\N	2017-12-27 14:40:20	\N
29442	MEMBRE	2017-12-21 00:00:00	2018-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	25774	\N	2017-12-27 17:06:47	2018-01-19 10:25:05
29443	MEMBRE	2017-12-21 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	25775	\N	2017-12-27 17:06:47	2018-01-23 17:48:20
29444	MEMBRE	2017-12-21 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	25776	\N	2017-12-27 17:06:47	2018-02-07 17:31:47
29447	MEMBRE	2018-01-03 00:00:00	2018-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	25779	\N	2018-01-05 10:00:24	2018-02-08 16:44:21
29462	MEMBRE	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25789	\N	2018-01-10 11:21:23	\N
29463	MEMBRE	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25790	\N	2018-01-10 11:21:23	\N
29464	MEMBRE	2017-12-06 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	25791	\N	2018-01-10 13:44:33	2018-01-25 15:53:46
29465	MEMBRE	2017-12-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25792	\N	2018-01-10 14:02:11	\N
29474	MEMBRE	2018-01-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25800	\N	2018-01-12 14:04:36	\N
29503	VICPDT	2017-12-19 00:00:00	2020-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	25828	\N	\N	\N
29592	MEMBRE	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25854	\N	2018-01-17 09:22:17	\N
29505	MEMBRE	2017-12-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	25829	\N	\N	\N
29593	MEMBRE	2017-12-20 00:00:00	2019-10-16 00:00:00	ANCIEN	\N	\N	\N	\N	25855	\N	2018-01-17 09:22:18	\N
29507	MEMBRE	2017-12-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	25830	\N	\N	\N
29508	MEMBRE	2017-12-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	25831	\N	\N	\N
29594	MEMBRE	2017-12-20 00:00:00	2018-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	25856	\N	2018-01-17 09:22:18	2018-01-30 14:47:02
29510	MEMBRE	2017-12-19 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25832	\N	\N	\N
29595	MEMBRE	2018-01-15 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	25857	\N	2018-01-17 09:22:42	2018-01-18 11:23:02
29596	MEMBRE	2018-01-12 00:00:00	2018-09-10 00:00:00	ANCIEN	\N	\N	\N	\N	25858	\N	2018-01-17 09:23:03	\N
29513	VICPDT	2017-12-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	25833	\N	\N	\N
29514	MEMBRE	2017-12-19 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25834	\N	\N	\N
29599	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25860	\N	\N	\N
29516	MEMBRE	2017-12-19 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25835	\N	\N	\N
29620	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25881	\N	\N	\N
29641	VICPDT	2018-01-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24616	\N	2018-01-17 11:29:38	\N
29520	MEMBRE	2017-12-19 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25837	\N	\N	\N
29642	VICPDT	2018-01-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24586	\N	2018-01-17 11:29:46	\N
29643	VICPDT	2018-01-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25688	\N	2018-01-17 11:29:55	\N
29523	PDT	2017-12-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	25838	\N	\N	\N
29644	VICPDT	2018-01-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24843	\N	2018-01-17 11:30:02	\N
29525	VICPDT	2017-12-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	25839	\N	\N	\N
29526	MEMBRE	2017-12-19 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25840	\N	\N	\N
29645	VICPDT	2018-01-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24132	\N	2018-01-17 11:30:21	\N
29528	MEMBRE	2017-12-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	25841	\N	\N	\N
29646	SECRET	2018-01-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24323	\N	2018-01-17 11:30:32	\N
29647	PDTDEL	2018-01-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Brunéi	\N	25820	\N	2018-01-17 12:24:00	2018-01-17 12:24:23
29531	VICPDT	2017-12-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	25842	\N	\N	\N
29533	VICPDT	2017-12-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	25843	\N	\N	\N
29535	VICPDT	2017-12-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	25844	\N	\N	\N
29537	VICPDT	2017-12-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	25845	\N	\N	\N
29538	MEMBRE	2017-12-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	25846	\N	\N	\N
29540	MEMBRE	2017-12-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	25847	\N	\N	\N
29543	MEMBRE	2017-12-19 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25848	\N	\N	\N
29544	MEMBRE	2017-12-19 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25849	\N	\N	\N
29551	MEMBRE	2017-12-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	25852	\N	\N	\N
25399	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22669	\N	\N	\N
25848	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22950	\N	\N	\N
26662	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23400	\N	\N	\N
26703	MEMBRE	2015-11-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23431	\N	2015-11-26 18:05:51	2017-09-24 19:14:37
26731	MEMBRE	2016-02-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23450	\N	2016-02-11 09:50:25	2017-09-24 18:16:52
26885	MEMBRE	2016-03-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23599	\N	2016-03-29 15:45:33	2017-09-24 17:47:27
26886	VICPDT	2016-03-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21809	\N	2016-03-30 11:51:00	2017-09-24 17:47:28
26887	VICPDT	2016-03-30 00:00:00	2017-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	20858	\N	2016-03-30 11:54:37	2017-07-04 15:08:09
26888	VICPDT	2016-03-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21030	\N	2016-03-30 11:57:29	\N
26889	VICPDT	2016-03-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23598	\N	2016-03-30 12:01:44	2017-09-24 17:47:28
26890	MEMBRE	2016-03-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23600	\N	2016-03-30 15:40:09	\N
26894	MEMBRE	2016-03-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23602	\N	2016-04-01 09:31:55	\N
26902	MEMBRE	2016-04-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23609	\N	2016-04-13 16:04:33	2017-09-24 17:29:37
27102	MEMBRE	2016-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23794	\N	\N	\N
27106	MEMBRE	2016-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23798	\N	\N	\N
27107	MEMBRE	2016-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23799	\N	\N	\N
27108	MEMBRE	2016-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23800	\N	\N	\N
27110	MEMBRE	2016-10-01 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	23802	\N	\N	2017-06-19 12:20:59
27120	MEMBRE	2016-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23812	\N	\N	2017-09-24 17:29:37
27122	MEMBRE	2016-11-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23814	\N	2016-11-17 09:45:28	2017-09-24 17:29:37
27252	MEMBRE	2017-07-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23863	\N	2017-07-20 18:35:52	\N
27255	MEMBRE	2017-09-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23864	\N	2017-09-15 10:22:15	\N
22751	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20695	\N	2014-10-22 11:46:04	\N
24149	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22060	\N	2014-11-03 15:12:02	\N
23856	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21767	\N	2014-10-30 15:41:48	\N
23737	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21648	\N	2014-10-30 11:59:08	\N
27301	MEMBRE	2017-10-07 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	23879	\N	2017-10-10 09:48:39	2018-01-23 18:42:31
27302	MEMBRE	2017-10-07 00:00:00	2018-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	23880	\N	2017-10-10 09:48:39	2018-01-26 16:18:53
27303	MEMBRE	2017-10-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23881	\N	2017-10-10 09:48:39	\N
27304	MEMBRE	2017-10-07 00:00:00	2017-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	23882	\N	2017-10-10 09:48:39	2017-12-14 15:49:35
27305	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23883	\N	2017-10-10 09:49:00	\N
27306	MEMBRE	2017-10-09 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	23884	\N	2017-10-10 09:49:00	2018-01-24 17:10:50
27385	MEMBRE	2017-10-11 00:00:00	2018-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	23952	\N	2017-10-11 15:13:17	2018-02-08 17:35:54
27386	MEMBRE	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23953	\N	2017-10-11 15:13:17	\N
27387	MEMBRE	2017-10-11 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	23954	\N	2017-10-11 15:13:17	2018-02-07 15:32:24
27450	MEMBRE	2017-10-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24017	\N	2017-10-12 09:47:44	\N
27451	MEMBRE	2017-10-03 00:00:00	2017-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	24018	\N	2017-10-12 09:48:17	2017-11-28 16:32:04
27826	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24393	\N	2017-10-19 15:01:57	\N
27827	MEMBRE	2017-10-17 00:00:00	2017-12-05 00:00:00	ANCIEN	\N	\N	\N	\N	24394	\N	2017-10-19 15:01:57	2017-12-06 15:09:38
27828	MEMBRE	2017-10-17 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	24395	\N	2017-10-19 15:01:57	2018-02-07 16:34:12
27829	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24396	\N	2017-10-19 15:01:57	\N
27830	MEMBRE	2017-10-17 00:00:00	2018-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	24397	\N	2017-10-19 15:01:57	2018-02-12 15:25:11
27831	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24398	\N	2017-10-19 15:01:57	\N
27832	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24399	\N	2017-10-19 15:01:57	\N
27833	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24400	\N	2017-10-19 15:01:57	\N
27834	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24401	\N	2017-10-19 15:01:58	\N
27835	MEMBRE	2017-10-17 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	24402	\N	2017-10-19 15:01:58	2018-02-07 15:32:52
27836	MEMBRE	2017-10-17 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24403	\N	2017-10-19 15:01:58	2018-01-24 11:14:52
27837	MEMBRE	2017-10-17 00:00:00	2017-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	24404	\N	2017-10-19 15:01:58	2017-12-19 18:05:19
27838	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24405	\N	2017-10-19 15:01:58	\N
27839	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24406	\N	2017-10-19 15:01:58	\N
27840	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24407	\N	2017-10-19 15:01:58	\N
27841	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24408	\N	2017-10-19 15:01:58	\N
27842	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24409	\N	2017-10-19 15:01:58	\N
27843	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24410	\N	2017-10-19 15:01:58	\N
27844	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24411	\N	2017-10-19 15:01:58	\N
27845	MEMBRE	2017-10-17 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	24412	\N	2017-10-19 15:01:58	2018-01-25 17:37:15
27846	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24413	\N	2017-10-19 15:01:58	\N
27847	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24414	\N	2017-10-19 15:01:58	\N
27848	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24415	\N	2017-10-19 15:01:59	\N
27849	MEMBRE	2017-10-17 00:00:00	2018-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	24416	\N	2017-10-19 15:01:59	2018-02-01 17:48:20
27850	MEMBRE	2017-10-17 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24417	\N	2017-10-19 15:01:59	2018-01-24 18:30:40
27851	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24418	\N	2017-10-19 15:01:59	\N
27852	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24419	\N	2017-10-19 15:01:59	\N
27853	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24420	\N	2017-10-19 15:01:59	\N
27854	MEMBRE	2017-10-17 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	24421	\N	2017-10-19 15:01:59	2018-01-18 18:10:11
27855	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24422	\N	2017-10-19 15:01:59	\N
27856	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24423	\N	2017-10-19 15:01:59	\N
27857	MEMBRE	2017-10-17 00:00:00	2017-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	24424	\N	2017-10-19 15:04:56	2017-12-07 14:57:08
27858	MEMBRE	2017-10-17 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	24425	\N	2017-10-19 15:04:56	2018-01-18 17:49:51
27859	MEMBRE	2017-10-17 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24426	\N	2017-10-19 15:04:56	2018-01-24 10:41:50
28037	MEMBRE	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24604	\N	2017-10-25 14:47:45	\N
28038	MEMBRE	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24605	\N	2017-10-25 14:47:45	\N
28039	MEMBRE	2017-10-25 00:00:00	2018-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	24606	\N	2017-10-25 14:47:45	2018-01-19 10:24:23
28040	MEMBRE	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24607	\N	2017-10-25 14:47:45	\N
28041	MEMBRE	2017-10-25 00:00:00	2018-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	24608	\N	2017-10-25 14:47:45	2018-01-16 19:09:01
28042	MEMBRE	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24609	\N	2017-10-25 14:47:45	\N
28666	MEMBRE	2017-11-06 00:00:00	2018-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	25233	\N	2017-11-13 09:31:35	2018-03-06 12:10:33
28667	MEMBRE	2017-11-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25234	\N	2017-11-13 09:31:35	\N
28668	MEMBRE	2017-11-06 00:00:00	2018-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	25235	\N	2017-11-13 09:31:35	2018-02-15 10:22:11
28669	MEMBRE	2017-11-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25236	\N	2017-11-13 09:32:26	\N
28670	MEMBRE	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25237	\N	2017-11-13 09:36:48	\N
28671	MEMBRE	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25238	\N	2017-11-13 09:36:48	\N
28672	MEMBRE	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25239	\N	2017-11-13 09:36:48	\N
28808	MEMBRE	2017-11-15 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	25375	\N	2017-11-21 18:43:14	2018-01-18 11:35:38
28842	MEMBRE	2017-11-22 00:00:00	2017-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	25409	\N	2017-11-23 14:27:38	2017-12-19 17:55:25
28843	MEMBRE	2017-11-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25410	\N	2017-11-23 14:27:38	\N
28844	MEMBRE	2017-11-22 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	25411	\N	2017-11-23 14:27:38	2018-02-07 15:31:49
28845	MEMBRE	2017-11-21 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	25412	\N	2017-11-23 15:05:03	2017-12-20 18:00:43
28846	MEMBRE	2017-11-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25413	\N	2017-11-23 15:05:18	\N
28847	MEMBRE	2017-11-22 00:00:00	2017-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	25414	\N	2017-11-23 15:05:38	2017-12-19 17:54:13
28848	MEMBRE	2017-11-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25415	\N	2017-11-23 15:05:55	\N
28849	MEMBRE	2017-11-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25416	\N	2017-11-23 15:06:11	\N
28850	MEMBRE	2017-11-21 00:00:00	2017-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	25417	\N	2017-11-23 15:06:29	2017-12-19 17:54:33
28851	MEMBRE	2017-11-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25418	\N	2017-11-23 15:06:45	\N
28852	MEMBRE	2017-11-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25419	\N	2017-11-23 15:07:02	\N
28853	MEMBRE	2017-11-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25420	\N	2017-11-23 15:07:18	\N
28854	MEMBRE	2017-11-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25421	\N	2017-11-23 15:07:18	\N
28855	MEMBRE	2017-11-22 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	25422	\N	2017-11-23 15:07:18	2018-01-24 15:04:28
29045	MEMBRE	2017-12-04 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	25535	\N	2017-12-05 09:35:04	2017-12-20 12:23:08
29046	PDT	2017-12-05 00:00:00	2020-08-03 00:00:00	ANCIEN	\N	\N	\N	\N	25126	\N	2017-12-05 09:59:44	\N
29047	PDT	2017-12-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25432	\N	2017-12-05 10:00:33	\N
29048	PDT	2017-12-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24452	\N	2017-12-05 10:01:12	\N
25364	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22634	\N	\N	\N
25373	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22643	\N	\N	\N
25389	MEMBRE	2015-01-28 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	22659	\N	\N	2017-06-19 12:20:59
25391	MEMBRE	2015-01-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	22661	\N	\N	\N
25393	MEMBRE	2015-01-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	22663	\N	\N	\N
25396	MEMBRE	2015-01-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	22666	\N	\N	\N
25870	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22954	\N	\N	\N
25884	VICPDT	2015-02-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21197	3	2015-02-23 15:21:24	2015-02-23 15:21:37
25885	VICPDT	2015-02-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20869	7	2015-02-23 15:23:17	2015-02-23 15:26:14
25886	VICPDT	2015-02-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20481	8	2015-02-23 15:23:34	2015-02-23 15:26:20
25887	VICPDT	2015-02-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21580	10	2015-02-23 15:24:03	2015-02-23 15:26:27
25888	VICPDT	2015-02-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22955	14	2015-02-23 15:25:41	2015-02-23 15:26:44
26228	VICPDT	2015-03-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22831	\N	\N	2017-09-24 17:19:42
26229	VICPDT	2015-03-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22846	\N	\N	2017-09-24 17:15:15
26230	VICPDT	2015-03-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	22701	\N	\N	\N
26231	VICPDT	2015-03-18 00:00:00	2015-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	22702	\N	\N	\N
26234	PDT	2015-03-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23169	\N	\N	2017-09-24 13:47:46
26235	MEMBRE	2015-03-18 00:00:00	2015-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	22702	\N	\N	\N
26236	VICPDT	2015-03-18 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	22706	\N	\N	2017-06-19 12:20:59
26496	PDT	2015-05-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	23282	\N	\N	\N
26498	VICPDT	2015-05-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	22894	\N	\N	\N
26500	SECRET	2015-05-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	23083	\N	\N	\N
26501	VICPDT	2015-05-26 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	23273	\N	\N	2017-06-19 16:06:01
26679	MEMBRE	2015-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23412	\N	2015-10-23 11:29:03	2017-09-24 17:19:42
26680	MEMBRE	2015-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23413	\N	2015-10-29 14:32:51	\N
26685	MEMBRE	2015-11-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23417	\N	2015-11-05 16:00:27	\N
26686	MEMBRE	2015-11-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23418	\N	2015-11-05 16:01:00	\N
26718	MEMBRE	2016-01-22 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	23439	\N	2016-01-22 11:45:00	2016-03-11 18:02:51
26730	VICPDT	2016-02-09 00:00:00	2017-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	21543	\N	2016-02-09 14:23:28	2017-07-20 11:44:30
27019	MEMBRE	2016-06-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23717	\N	2016-06-29 10:11:46	\N
27264	MEMBRE	2017-10-06 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	23871	\N	2017-10-09 10:42:53	2018-01-24 11:15:16
27947	MEMBRE	2017-10-19 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	24514	\N	2017-10-24 09:59:39	\N
27948	MEMBRE	2017-10-19 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	24515	\N	2017-10-24 09:59:39	\N
27949	MEMBRE	2017-10-19 00:00:00	2018-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	24516	\N	2017-10-24 09:59:39	2018-01-23 16:58:42
27950	MEMBRE	2017-10-19 00:00:00	2018-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	24517	\N	2017-10-24 09:59:39	2018-01-18 17:51:06
27951	MEMBRE	2017-10-19 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	24518	\N	2017-10-24 09:59:39	\N
27952	MEMBRE	2017-10-19 00:00:00	2018-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	24519	\N	2017-10-24 09:59:39	2018-01-30 16:01:38
27953	MEMBRE	2017-10-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24520	\N	2017-10-24 10:00:25	\N
27954	MEMBRE	2017-10-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24521	\N	2017-10-24 10:00:25	\N
27955	MEMBRE	2017-10-20 00:00:00	2017-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	24522	\N	2017-10-24 10:00:25	2017-12-19 18:18:13
27956	MEMBRE	2017-10-20 00:00:00	2017-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	24523	\N	2017-10-24 10:00:25	2017-11-30 16:32:12
27957	MEMBRE	2017-10-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24524	\N	2017-10-24 10:00:25	\N
27958	MEMBRE	2017-10-20 00:00:00	2017-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	24525	\N	2017-10-24 10:00:25	2017-12-13 15:45:01
27959	MEMBRE	2017-10-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24526	\N	2017-10-24 10:00:25	\N
27960	MEMBRE	2017-10-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24527	\N	2017-10-24 10:00:25	\N
27961	MEMBRE	2017-10-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24528	\N	2017-10-24 10:00:25	\N
27962	MEMBRE	2017-10-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24529	\N	2017-10-24 10:00:25	\N
27963	MEMBRE	2017-10-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24530	\N	2017-10-24 10:00:25	\N
27964	MEMBRE	2017-10-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24531	\N	2017-10-24 10:00:25	\N
27965	MEMBRE	2017-10-16 00:00:00	2017-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	24532	\N	2017-10-24 10:01:19	2017-12-14 15:49:19
27966	MEMBRE	2017-10-16 00:00:00	2018-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	24533	\N	2017-10-24 10:01:19	2018-02-12 15:25:20
27967	MEMBRE	2017-10-16 00:00:00	2018-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	24534	\N	2017-10-24 10:01:19	2018-02-15 10:21:57
27968	MEMBRE	2017-10-16 00:00:00	2018-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	24535	\N	2017-10-24 10:01:19	2018-02-01 17:48:47
27969	MEMBRE	2017-10-16 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	24536	\N	2017-10-24 10:01:19	2018-01-18 17:52:25
27970	MEMBRE	2017-10-16 00:00:00	2017-12-11 00:00:00	ANCIEN	\N	\N	\N	\N	24537	\N	2017-10-24 10:01:19	2017-12-12 17:29:45
27971	MEMBRE	2017-10-16 00:00:00	2017-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	24538	\N	2017-10-24 10:01:19	2017-12-05 10:10:23
27972	MEMBRE	2017-10-16 00:00:00	2018-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	24539	\N	2017-10-24 10:01:19	2018-01-30 16:02:36
27973	MEMBRE	2017-10-16 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	24540	\N	2017-10-24 10:01:19	2018-01-25 17:39:44
27974	MEMBRE	2017-10-24 00:00:00	2018-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	24541	\N	2017-10-24 10:51:14	\N
27975	MEMBRE	2017-10-24 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	24542	\N	2017-10-24 10:53:43	\N
28466	MEMBRE	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25033	\N	2017-11-03 10:58:55	\N
28467	MEMBRE	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25034	\N	2017-11-03 10:58:56	\N
25354	MEMBRE	2014-10-01 00:00:00	2014-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22624	\N	\N	\N
28468	MEMBRE	2017-10-16 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	25035	\N	2017-11-03 10:59:42	2018-01-24 18:31:37
28469	MEMBRE	2017-10-16 00:00:00	2018-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	25036	\N	2017-11-03 10:59:42	2018-01-30 16:00:00
28470	MEMBRE	2017-10-16 00:00:00	2018-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	25037	\N	2017-11-03 10:59:42	2018-02-12 16:11:58
28471	MEMBRE	2017-10-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25038	\N	2017-11-03 10:59:42	\N
28472	MEMBRE	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25039	\N	2017-11-03 11:05:14	\N
28476	MEMBRE	2017-10-27 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	25043	\N	2017-11-03 11:10:37	2018-01-24 18:31:26
28477	MEMBRE	2017-10-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25044	\N	2017-11-03 11:10:37	\N
28478	MEMBRE	2017-10-27 00:00:00	2018-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	25045	\N	2017-11-03 11:10:37	2018-02-21 15:39:06
28479	MEMBRE	2017-10-27 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	25046	\N	2017-11-03 11:10:37	2018-01-18 11:22:21
28480	MEMBRE	2017-10-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25047	\N	2017-11-03 11:10:37	\N
28481	MEMBRE	2017-10-27 00:00:00	2017-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	25048	\N	2017-11-03 11:10:37	2017-12-19 18:03:52
28482	MEMBRE	2017-10-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25049	\N	2017-11-03 11:10:37	\N
28483	MEMBRE	2017-10-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25050	\N	2017-11-03 11:10:37	\N
28484	MEMBRE	2017-10-27 00:00:00	2017-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	25051	\N	2017-11-03 11:10:37	2017-11-30 11:15:49
28485	MEMBRE	2017-10-31 00:00:00	2018-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	25052	\N	2017-11-03 11:10:57	2018-01-16 18:56:46
28486	MEMBRE	2017-10-18 00:00:00	2017-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	25053	\N	2017-11-03 11:11:13	2017-12-14 15:46:43
28487	MEMBRE	2017-10-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25054	\N	2017-11-03 11:11:13	\N
28488	MEMBRE	2017-10-18 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	25055	\N	2017-11-03 11:11:13	\N
28489	MEMBRE	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25056	\N	2017-11-03 11:11:43	\N
28490	MEMBRE	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25057	\N	2017-11-03 11:11:43	\N
28491	MEMBRE	2017-10-31 00:00:00	2017-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	25058	\N	2017-11-03 11:11:43	2017-11-28 16:31:27
28492	MEMBRE	2017-10-31 00:00:00	2018-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	25059	\N	2017-11-03 11:11:43	2018-02-01 18:31:09
28493	MEMBRE	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25060	\N	2017-11-03 11:11:43	\N
28494	MEMBRE	2017-10-24 00:00:00	2018-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	25061	\N	2017-11-03 11:12:03	2018-01-16 18:57:14
28495	MEMBRE	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25062	\N	2017-11-03 11:12:03	\N
28496	MEMBRE	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25063	\N	2017-11-03 11:12:03	\N
28497	MEMBRE	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25064	\N	2017-11-03 11:12:03	\N
28809	MEMBRE	2017-11-21 00:00:00	2018-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	25376	\N	2017-11-22 09:44:26	2018-02-06 16:27:31
28904	MEMBRE	2017-11-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25468	\N	2017-11-28 09:43:29	\N
28906	MEMBRE	2017-11-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25470	\N	2017-11-28 15:03:47	\N
28907	MEMBRE	2017-11-27 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	25471	\N	2017-11-28 15:04:01	2017-12-20 14:34:55
28908	MEMBRE	2017-11-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25472	\N	2017-11-28 15:04:20	\N
28909	MEMBRE	2017-11-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25473	\N	2017-11-28 15:04:20	\N
28980	MEMBRE	2017-11-29 00:00:00	2018-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	25508	\N	2017-11-30 14:57:42	2018-01-30 14:47:20
28981	MEMBRE	2017-11-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25509	\N	2017-11-30 14:59:02	\N
28982	PDTDEL	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Soudan	\N	25510	\N	2017-11-30 14:59:48	2017-11-30 16:49:04
28983	MEMBRE	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25511	\N	2017-11-30 14:59:48	\N
28984	MEMBRE	2017-11-28 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	25512	\N	2017-11-30 15:00:09	2018-02-07 12:15:53
28985	MEMBRE	2017-11-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25513	\N	2017-11-30 15:00:29	\N
28986	MEMBRE	2017-11-27 00:00:00	2017-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	25514	\N	2017-11-30 15:00:42	2017-11-30 17:34:37
28987	MEMBRE	2017-11-30 00:00:00	2017-12-11 00:00:00	ANCIEN	\N	\N	\N	\N	25515	\N	2017-11-30 15:39:24	2017-12-12 17:35:20
28988	PDT	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24080	\N	2017-11-30 15:59:01	2017-11-30 16:00:07
28989	PDTDEL	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Azerbaïdjan	\N	24080	\N	2017-11-30 16:03:23	2017-11-30 16:05:17
24314	MEMBRE	2014-10-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21016	\N	2014-11-14 11:09:14	\N
24310	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22221	\N	2014-11-14 10:37:18	\N
24311	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22222	\N	2014-11-14 10:37:18	\N
24312	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22223	\N	2014-11-14 10:37:18	\N
24313	MEMBRE	2014-10-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21014	\N	2014-11-14 11:09:14	\N
24315	MEMBRE	2014-10-23 00:00:00	2015-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	21015	\N	2014-11-14 11:09:14	2015-02-23 11:39:46
24316	MEMBRE	2014-10-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21013	\N	2014-11-14 11:09:14	\N
24362	MEMBRE	2014-11-20 00:00:00	2015-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	22269	\N	2014-11-24 16:16:35	2015-03-04 10:25:54
24363	MEMBRE	2014-11-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22270	\N	2014-11-24 16:16:52	\N
24364	MEMBRE	2014-11-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22271	\N	2014-11-24 16:18:09	\N
24365	MEMBRE	2014-11-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22272	\N	2014-11-25 14:16:19	\N
24369	MEMBRE	2014-11-25 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22276	\N	2014-11-26 15:16:38	\N
24370	MEMBRE	2014-11-25 00:00:00	2015-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	22277	\N	2014-11-26 15:16:47	2015-02-04 10:49:12
24371	MEMBRE	2014-11-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22278	\N	2014-11-26 15:17:07	\N
24592	MEMBRE	2015-01-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22377	\N	2015-01-13 12:13:34	\N
24593	MEMBRE	2015-01-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22378	\N	2015-01-13 12:13:34	\N
24594	MEMBRE	2015-01-12 00:00:00	2015-03-09 00:00:00	ANCIEN	\N	\N	\N	\N	22379	\N	2015-01-13 12:13:34	2015-03-10 17:27:27
24595	MEMBRE	2015-01-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22380	\N	2015-01-13 12:13:34	\N
24627	PDT	2015-01-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20384	1	2015-01-14 14:53:17	2015-01-14 14:53:30
24628	MEMBRE	2014-12-04 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22385	\N	2015-01-14 16:09:02	\N
24636	PDTDEL	2015-01-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour le Soudan 	\N	21454	4	2015-01-15 09:19:09	2015-02-02 14:43:57
24991	MEMBRE	2015-02-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22525	\N	2015-02-05 16:34:34	\N
25131	MEMBRE	2015-02-10 00:00:00	2015-03-19 00:00:00	ANCIEN	\N	\N	\N	\N	22533	\N	2015-02-11 15:37:50	2015-03-20 11:38:59
25132	MEMBRE	2015-02-09 00:00:00	2015-03-09 00:00:00	ANCIEN	\N	\N	\N	\N	22534	\N	2015-02-11 15:38:10	2015-03-10 17:27:20
25252	SECRET	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22186	16	2015-02-13 11:38:09	2016-03-16 18:05:01
25324	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22606	\N	\N	\N
25335	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22617	\N	\N	2017-09-24 19:31:54
25355	MEMBRE	2014-10-01 00:00:00	2015-06-03 00:00:00	ANCIEN	\N	\N	\N	\N	22625	\N	\N	\N
25356	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22626	\N	\N	\N
25357	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22627	\N	\N	\N
25358	MEMBRE	2014-10-01 00:00:00	2015-06-03 00:00:00	ANCIEN	\N	\N	\N	\N	22628	\N	\N	\N
25361	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22631	\N	\N	\N
25363	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22633	\N	\N	\N
25365	MEMBRE	2014-10-01 00:00:00	2015-03-24 00:00:00	ANCIEN	\N	\N	\N	\N	22635	\N	\N	\N
25368	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22638	\N	\N	\N
25369	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22639	\N	\N	\N
25371	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22641	\N	\N	\N
25372	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22642	\N	\N	2017-09-24 17:29:37
25382	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22652	\N	\N	2017-09-24 17:14:26
25384	MEMBRE	2014-10-01 00:00:00	2015-03-24 00:00:00	ANCIEN	\N	\N	\N	\N	22654	\N	\N	\N
25385	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22655	\N	\N	\N
25386	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22656	\N	\N	\N
25392	MEMBRE	2015-01-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	22662	\N	\N	\N
25756	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22924	\N	\N	\N
25874	MEMBRE	2014-10-01 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	22958	\N	\N	2016-12-12 16:10:15
25875	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22959	\N	\N	\N
25876	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22960	\N	\N	2017-09-24 17:47:27
25883	MEMBRE	2014-10-01 00:00:00	2015-03-04 00:00:00	ANCIEN	\N	\N	\N	\N	22961	\N	\N	\N
25893	MEMBRE	2014-10-01 00:00:00	2014-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	22966	\N	\N	\N
25897	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22970	\N	\N	\N
25900	MEMBRE	2015-02-26 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22973	\N	2015-02-26 10:42:34	\N
25901	MEMBRE	2015-02-26 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22974	\N	2015-02-26 10:43:04	\N
25902	MEMBRE	2015-03-02 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	21364	\N	2015-03-02 10:50:52	2017-06-19 12:20:59
25903	VICPDT	2015-03-02 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21535	2	2015-03-02 11:06:54	2015-03-02 11:08:16
25904	VICPDT	2015-03-02 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20716	3	2015-03-02 11:07:00	2015-03-02 11:08:19
25905	VICPDT	2015-03-02 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21019	4	2015-03-02 11:07:05	2015-03-02 11:08:21
25906	VICPDT	2015-03-02 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	21413	5	2015-03-02 11:07:11	2017-05-16 15:18:14
25907	VICPDT	2015-03-02 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21170	6	2015-03-02 11:07:18	2015-03-02 11:08:28
25908	VICPDT	2015-03-02 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21603	7	2015-03-02 11:07:25	2015-03-02 11:08:32
25909	VICPDT	2015-03-02 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21957	8	2015-03-02 11:07:31	2015-03-02 11:08:34
25910	VICPDT	2015-03-02 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21000	9	2015-03-02 11:07:38	2015-03-02 11:08:38
25911	SECRET	2015-03-02 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21458	10	2015-03-02 11:07:50	2015-03-02 11:08:41
25912	SECRET	2015-03-02 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21102	11	2015-03-02 11:07:55	2015-03-02 11:08:47
25913	SECRET	2015-03-02 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20815	12	2015-03-02 11:08:05	2015-03-02 11:08:49
25914	MEMBRE	2015-02-16 00:00:00	2015-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	22975	\N	2015-03-02 14:58:56	2015-03-02 15:01:13
25915	VICPDTDRT	2015-03-02 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22975	\N	2015-03-02 15:01:13	\N
25916	SECRET	2015-03-02 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21942	12	2015-03-02 15:18:23	2015-03-02 15:20:16
25922	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22981	\N	\N	\N
26003	MEMBRE	2015-02-25 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23063	\N	2015-03-03 15:34:29	\N
26086	VICPDT	2015-03-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	23024	\N	\N	\N
26089	VICPDT	2015-03-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	23033	\N	\N	\N
26090	SECRET	2015-03-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	23027	\N	\N	\N
26273	VICPDT	2015-03-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22263	2	2015-03-20 11:38:03	2017-09-24 18:20:10
26274	VICPDT	2015-03-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22297	3	2015-03-20 11:38:09	2017-09-24 18:16:52
26275	VICPDT	2015-03-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22133	4	2015-03-20 11:38:15	2015-03-20 11:39:14
26276	VICPDT	2015-03-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22111	5	2015-03-20 11:38:27	2015-03-20 11:39:17
26277	VICPDT	2015-03-20 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	21849	6	2015-03-20 11:38:36	2016-03-11 18:02:51
26278	VICPDT	2015-03-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21053	7	2015-03-20 11:38:42	2017-09-24 17:42:26
26279	SECRET	2015-03-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22533	8	2015-03-20 11:38:59	2015-03-20 11:39:27
26399	MEMBRE	2015-04-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23239	\N	2015-04-17 09:47:40	\N
26400	MEMBRE	2015-04-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23240	\N	2015-04-17 09:52:41	\N
26401	PDT	2015-04-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	22731	\N	\N	\N
26402	MEMBRE	2014-10-01 00:00:00	2015-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	23241	\N	\N	\N
26412	MEMBRE	2015-05-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23251	\N	2015-05-05 09:21:44	\N
26454	MEMBRE	2014-10-01 00:00:00	2014-10-30 00:00:00	ANCIEN	\N	\N	\N	\N	23268	\N	\N	\N
26455	MEMBRE	2015-04-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23269	\N	\N	\N
26456	MEMBRE	2015-04-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23270	\N	\N	\N
26458	PDT	2015-05-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23268	\N	\N	2017-09-24 16:45:26
26522	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23297	\N	\N	\N
26526	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23301	\N	\N	\N
26527	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23302	\N	\N	2017-09-24 13:25:54
26528	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23303	\N	\N	\N
26530	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23305	\N	\N	2017-09-24 18:17:56
26532	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23307	\N	\N	2017-09-24 19:31:54
26534	MEMBRE	2014-10-01 00:00:00	2015-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	23309	\N	\N	\N
26535	MEMBRE	2014-10-01 00:00:00	2015-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	23310	\N	\N	\N
26536	MEMBRE	2014-10-01 00:00:00	2015-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	23311	\N	\N	\N
26537	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23312	\N	\N	2017-09-24 17:14:26
26538	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23313	\N	\N	\N
26540	MEMBRE	2014-10-01 00:00:00	2015-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	23315	\N	\N	\N
26541	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23316	\N	\N	\N
26542	MEMBRE	2014-10-01 00:00:00	2017-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	23317	\N	\N	2017-07-24 09:58:00
26543	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23318	\N	\N	2017-09-24 17:48:21
26544	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23319	\N	\N	\N
26545	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23320	\N	\N	\N
26547	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23322	\N	\N	\N
26548	MEMBRE	2014-10-01 00:00:00	2015-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	23323	\N	\N	\N
26549	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23324	\N	\N	\N
26551	MEMBRE	2014-10-01 00:00:00	2015-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	23326	\N	\N	\N
26552	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23327	\N	\N	\N
26553	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23328	\N	\N	2017-09-24 17:35:15
26554	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23329	\N	\N	\N
26555	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23330	\N	\N	2017-09-24 17:04:02
26597	MEMBRE	2015-07-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23372	\N	2015-07-03 09:23:16	\N
26645	VICPDT	2015-08-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20843	\N	2015-08-31 16:57:07	2017-09-24 18:16:52
25418	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22677	\N	\N	\N
25419	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22678	\N	\N	\N
25423	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22682	\N	\N	2017-09-24 16:45:26
25424	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22683	\N	\N	\N
25425	MEMBRE	2014-10-01 00:00:00	2015-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	22684	\N	\N	\N
25426	MEMBRE	2014-10-01 00:00:00	2015-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	22685	\N	\N	\N
25427	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22686	\N	\N	\N
25428	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22687	\N	\N	2017-09-24 17:14:26
25429	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22688	\N	\N	\N
25430	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22689	\N	\N	\N
25431	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22690	\N	\N	\N
25432	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22691	\N	\N	\N
25433	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22692	\N	\N	\N
25434	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22693	\N	\N	2017-09-24 17:15:15
25435	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22694	\N	\N	\N
25436	MEMBRE	2014-10-01 00:00:00	2015-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	22695	\N	\N	\N
25438	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22697	\N	\N	\N
25439	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22698	\N	\N	\N
25441	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22700	\N	\N	\N
25442	MEMBRE	2014-10-01 00:00:00	2015-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	22701	\N	\N	\N
25443	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22702	\N	\N	\N
25444	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22703	\N	\N	\N
25445	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22704	\N	\N	\N
25446	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22705	\N	\N	\N
25447	MEMBRE	2014-10-01 00:00:00	2015-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	22706	\N	\N	\N
25448	MEMBRE	2014-10-01 00:00:00	2015-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	22707	\N	\N	\N
25449	MEMBRE	2014-10-01 00:00:00	2015-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	22708	\N	\N	\N
25450	MEMBRE	2014-10-01 00:00:00	2016-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	22709	\N	\N	2016-11-18 12:37:50
25451	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22710	\N	\N	2017-09-24 17:29:37
25452	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22711	\N	\N	2017-09-24 13:57:40
25453	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22712	\N	\N	\N
25454	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22713	\N	\N	2017-09-24 18:05:41
25455	MEMBRE	2014-10-01 00:00:00	2015-04-15 00:00:00	ANCIEN	\N	\N	\N	\N	22714	\N	\N	\N
25457	MEMBRE	2014-10-01 00:00:00	2015-04-15 00:00:00	ANCIEN	\N	\N	\N	\N	22716	\N	\N	\N
25458	MEMBRE	2014-10-01 00:00:00	2015-04-15 00:00:00	ANCIEN	\N	\N	\N	\N	22717	\N	\N	\N
25459	MEMBRE	2014-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22718	\N	\N	2017-10-01 09:22:38
25460	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22719	\N	\N	\N
25461	MEMBRE	2014-10-01 00:00:00	2015-04-15 00:00:00	ANCIEN	\N	\N	\N	\N	22720	\N	\N	\N
25464	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22723	\N	\N	\N
25465	MEMBRE	2014-10-01 00:00:00	2015-04-15 00:00:00	ANCIEN	\N	\N	\N	\N	22724	\N	\N	\N
25466	MEMBRE	2014-10-01 00:00:00	2015-04-15 00:00:00	ANCIEN	\N	\N	\N	\N	22725	\N	\N	\N
25467	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22726	\N	\N	\N
25468	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22727	\N	\N	\N
25478	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22737	\N	\N	2017-09-24 18:05:41
25479	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22738	\N	\N	2017-09-24 17:09:24
25480	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22739	\N	\N	\N
25489	MEMBRE	2015-01-28 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	22748	\N	\N	2017-09-25 09:56:00
25868	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22952	\N	\N	\N
26316	VICPDT	2015-04-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20305	2	2015-04-09 15:20:59	2017-09-24 18:59:59
26317	VICPDT	2015-04-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20414	3	2015-04-09 15:21:09	2015-07-09 15:10:29
26318	SECRET	2015-04-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21792	4	2015-04-09 15:21:16	2017-09-24 17:47:28
26319	SECRET	2015-04-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20891	5	2015-04-09 15:21:23	2017-09-24 12:39:59
26320	SECRET	2015-04-09 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	21425	6	2015-04-09 15:21:27	2017-05-16 15:18:14
26321	SECRET	2015-04-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22280	7	2015-04-09 15:21:33	2015-07-09 15:10:39
22731	MEMBRE	2014-10-20 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	20675	\N	2014-10-22 11:15:25	2015-06-12 15:59:49
22732	MEMBRE	2014-10-20 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	20676	\N	2014-10-22 11:15:25	2015-06-12 15:59:49
22465	MEMBRE	2014-10-15 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	20409	\N	2014-10-16 09:42:58	2015-06-12 16:01:25
26652	MEMBRE	2015-09-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23391	\N	2015-09-17 15:25:27	\N
26896	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23604	\N	\N	\N
27257	MEMBRE	2017-10-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23865	\N	2017-10-09 09:54:07	\N
27258	MEMBRE	2017-10-06 00:00:00	2018-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	23866	\N	2017-10-09 09:54:07	2018-02-08 16:43:09
27259	MEMBRE	2017-10-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23867	\N	2017-10-09 09:54:08	\N
27260	MEMBRE	2017-10-06 00:00:00	2018-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	23868	\N	2017-10-09 09:54:08	2018-01-30 14:46:36
27261	MEMBRE	2017-10-06 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	23869	\N	2017-10-09 09:54:08	2017-12-20 16:56:16
29090	PDT	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25321	\N	2017-12-06 15:11:06	\N
27263	MEMBRE	2017-10-05 00:00:00	2018-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	23870	\N	2017-10-09 09:55:18	2018-01-19 10:25:08
27519	MEMBRE	2017-10-12 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	24086	\N	2017-10-13 11:05:09	2018-02-07 15:30:08
27520	MEMBRE	2017-10-12 00:00:00	2017-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	24087	\N	2017-10-13 11:05:09	2017-11-28 16:54:37
27521	MEMBRE	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24088	\N	2017-10-13 11:05:09	\N
27878	MEMBRE	2017-10-20 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	24445	\N	2017-10-20 15:31:21	\N
29091	PDT	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24814	\N	2017-12-06 15:11:34	\N
29092	PDT	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24641	\N	2017-12-06 15:12:17	\N
29093	PDT	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24036	\N	2017-12-06 15:12:45	\N
29094	PDT	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25340	\N	2017-12-06 15:13:08	\N
29095	PDT	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24097	\N	2017-12-06 15:13:39	\N
29096	PDT	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24195	\N	2017-12-06 15:13:59	\N
29097	PDT	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24790	\N	2017-12-06 15:14:25	\N
29098	PDTDEL	2017-12-06 00:00:00	2020-07-31 00:00:00	ANCIEN	\N	\N	Colombie	\N	24156	\N	2017-12-06 15:15:02	2017-12-06 15:15:24
29099	PDTDEL	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Islande	\N	25361	\N	2017-12-06 15:15:44	2017-12-06 15:16:00
29100	PDTDEL	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Papouasie-Nouvelle Guinée	\N	24391	\N	2017-12-06 15:17:27	2017-12-06 15:17:46
29101	PDTDEL	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Norvège	\N	24123	\N	2017-12-06 15:19:10	2017-12-06 15:19:16
29419	MEMBRE	2017-10-01 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	25759	\N	\N	\N
29648	MEMBRE	2017-12-15 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25902	\N	2018-01-17 12:32:00	\N
29649	MEMBRE	2018-01-16 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	25903	\N	2018-01-17 14:33:57	2018-01-24 15:53:58
29650	MEMBRE	2018-01-09 00:00:00	2018-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	25904	\N	2018-01-17 14:34:15	2018-01-19 10:00:08
29651	MEMBRE	2018-01-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25905	\N	2018-01-17 14:34:28	\N
29652	MEMBRE	2018-01-15 00:00:00	2018-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	25906	\N	2018-01-17 14:34:41	2018-02-12 16:56:39
29653	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25907	\N	\N	\N
29654	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25908	\N	\N	\N
29655	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25909	\N	\N	\N
29656	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25910	\N	\N	\N
29658	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25912	\N	\N	\N
29660	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25914	\N	\N	\N
29661	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25915	\N	\N	\N
29662	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25916	\N	\N	\N
29664	MEMBRE	2017-10-01 00:00:00	2018-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	25918	\N	\N	\N
29666	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25920	\N	\N	\N
29668	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25922	\N	\N	\N
29669	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25923	\N	\N	\N
29670	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25924	\N	\N	\N
29689	MEMBRE	2017-10-01 00:00:00	2018-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	25943	\N	\N	\N
29698	MEMBRE	2018-01-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25952	\N	2018-01-18 09:35:48	\N
29699	MEMBRE	2018-01-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25953	\N	2018-01-18 09:36:07	\N
29700	MEMBRE	2018-01-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25954	\N	2018-01-18 09:36:07	\N
29701	MEMBRE	2018-01-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25955	\N	2018-01-18 09:38:12	\N
29702	MEMBRE	2018-01-17 00:00:00	2018-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	25956	\N	2018-01-18 09:39:37	2018-02-12 15:25:05
29703	MEMBRE	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25957	\N	2018-01-18 09:47:35	\N
29721	MEMBRE	2018-01-17 00:00:00	2018-01-21 00:00:00	ANCIEN	\N	\N	\N	\N	25958	\N	2018-01-18 15:15:57	2018-01-22 11:59:03
29722	MEMBRE	2018-01-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25959	\N	2018-01-18 15:16:09	\N
29723	MEMBRE	2018-01-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25960	\N	2018-01-18 15:16:20	\N
29724	MEMBRE	2018-01-17 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	25961	\N	2018-01-18 15:16:51	2018-01-24 15:04:11
29725	MEMBRE	2018-01-16 00:00:00	2018-01-21 00:00:00	ANCIEN	\N	\N	\N	\N	25962	\N	2018-01-18 15:17:05	2018-01-22 15:32:28
29726	VICPDT	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25160	\N	2018-01-18 16:35:44	\N
29727	VICPDT	2018-01-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24662	\N	2018-01-18 16:35:52	\N
29728	VICPDT	2018-01-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25624	\N	2018-01-18 16:36:06	\N
29729	SECRET	2018-01-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24357	\N	2018-01-18 16:36:21	\N
24165	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22076	\N	2014-11-04 14:30:53	\N
24166	MEMBRE	2014-10-21 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	22077	\N	2014-11-04 14:30:53	2015-02-03 16:29:44
24167	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22078	\N	2014-11-04 14:31:17	\N
24168	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22079	\N	2014-11-04 14:31:18	\N
24169	MEMBRE	2014-11-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22080	\N	2014-11-04 14:31:50	\N
24170	MEMBRE	2014-11-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22081	\N	2014-11-04 14:31:50	\N
24171	MEMBRE	2014-11-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22082	\N	2014-11-04 14:31:50	\N
24172	MEMBRE	2014-11-04 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22083	\N	2014-11-04 14:32:10	\N
24173	MEMBRE	2014-11-04 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22084	\N	2014-11-04 14:32:10	\N
24174	MEMBRE	2014-11-04 00:00:00	2015-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	22085	\N	2014-11-04 14:32:10	2015-02-04 14:27:26
24175	MEMBRE	2014-10-30 00:00:00	2015-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	22086	\N	2014-11-04 14:32:35	2015-01-30 09:39:12
24176	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22087	\N	2014-11-04 14:32:35	\N
24177	MEMBRE	2014-10-30 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	22088	\N	2014-11-04 14:32:35	2015-02-13 11:37:27
24178	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22089	\N	2014-11-04 14:32:35	\N
24179	MEMBRE	2014-10-30 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	22090	\N	2014-11-04 14:32:35	2015-02-11 17:25:45
24180	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22091	\N	2014-11-04 14:32:35	\N
24181	MEMBRE	2014-11-04 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22092	\N	2014-11-04 14:32:54	\N
24182	MEMBRE	2014-11-04 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22093	\N	2014-11-04 14:32:54	\N
24183	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22094	\N	2014-11-04 14:33:22	\N
24184	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22095	\N	2014-11-04 14:33:22	\N
24185	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22096	\N	2014-11-04 14:33:22	\N
25420	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22679	\N	\N	\N
25421	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22680	\N	\N	\N
25422	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22681	\N	\N	2017-09-24 17:04:02
26411	MEMBRE	2015-04-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23250	\N	2015-04-30 14:08:03	2017-09-24 17:15:15
25456	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22715	\N	\N	\N
25462	MEMBRE	2014-10-01 00:00:00	2015-04-15 00:00:00	ANCIEN	\N	\N	\N	\N	22721	\N	\N	\N
25463	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22722	\N	\N	2017-09-24 16:43:43
25469	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22728	\N	\N	\N
25470	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22729	\N	\N	\N
25471	MEMBRE	2014-10-01 00:00:00	2015-04-15 00:00:00	ANCIEN	\N	\N	\N	\N	22730	\N	\N	\N
25472	MEMBRE	2014-10-01 00:00:00	2015-04-14 00:00:00	ANCIEN	\N	\N	\N	\N	22731	\N	\N	\N
25474	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22733	\N	\N	2017-09-24 17:29:37
25475	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22734	\N	\N	2017-09-24 13:57:40
25476	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22735	\N	\N	\N
25477	MEMBRE	2014-10-01 00:00:00	2015-04-15 00:00:00	ANCIEN	\N	\N	\N	\N	22736	\N	\N	\N
25481	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22740	\N	\N	\N
25482	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22741	\N	\N	\N
25483	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22742	\N	\N	\N
26287	MEMBRE	2014-09-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23173	\N	2015-03-30 16:22:18	\N
26288	MEMBRE	2014-09-01 00:00:00	2015-03-31 00:00:00	ANCIEN	\N	\N	\N	\N	23174	\N	2015-03-30 16:22:45	\N
26289	MEMBRE	2014-09-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23175	\N	2015-03-30 16:25:13	\N
26692	VICPDT	2015-11-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20449	3	2015-11-12 14:27:52	2015-11-12 15:26:22
26880	MEMBRE	2016-02-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23596	\N	2016-02-18 14:06:20	2017-09-24 17:29:37
26881	MEMBRE	2016-03-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23597	\N	2016-03-04 14:59:32	\N
27861	MEMBRE	2017-10-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24428	\N	2017-10-20 09:47:29	\N
27862	MEMBRE	2017-10-12 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	24429	\N	2017-10-20 09:47:29	2018-02-07 15:30:45
27863	MEMBRE	2017-10-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24430	\N	2017-10-20 09:47:29	\N
27864	MEMBRE	2017-10-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24431	\N	2017-10-20 09:47:29	\N
27865	MEMBRE	2017-10-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24432	\N	2017-10-20 09:47:29	\N
27866	MEMBRE	2017-10-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24433	\N	2017-10-20 09:48:17	\N
27867	MEMBRE	2017-10-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24434	\N	2017-10-20 09:48:17	\N
27868	MEMBRE	2017-10-18 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24435	\N	2017-10-20 09:48:17	2018-01-24 18:30:00
27869	MEMBRE	2017-10-18 00:00:00	2018-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	24436	\N	2017-10-20 09:48:17	2018-01-16 19:07:57
27870	MEMBRE	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24437	\N	2017-10-20 09:49:41	\N
27871	MEMBRE	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24438	\N	2017-10-20 09:49:41	\N
27872	MEMBRE	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24439	\N	2017-10-20 09:49:41	\N
27874	MEMBRE	2017-10-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24441	\N	2017-10-20 10:16:47	\N
27875	MEMBRE	2017-10-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24442	\N	2017-10-20 10:16:47	\N
27876	MEMBRE	2017-10-13 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24443	\N	2017-10-20 10:16:47	2018-01-24 18:06:38
27877	MEMBRE	2017-10-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24444	\N	2017-10-20 10:16:47	\N
28673	MEMBRE	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25240	\N	2017-11-13 17:52:22	\N
28674	MEMBRE	2017-11-08 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	25241	\N	2017-11-13 17:52:22	2018-01-23 17:27:30
28675	MEMBRE	2017-11-08 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	25242	\N	2017-11-13 17:52:22	2018-01-23 18:49:42
28676	MEMBRE	2017-11-08 00:00:00	2018-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	25243	\N	2017-11-13 17:52:22	2018-01-16 19:11:24
28677	MEMBRE	2017-11-09 00:00:00	2018-01-04 00:00:00	ANCIEN	\N	\N	\N	\N	25244	\N	2017-11-13 17:52:54	2018-01-05 11:29:47
28678	MEMBRE	2017-11-09 00:00:00	2023-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	25245	\N	2017-11-13 17:53:14	\N
29049	PDT	2017-12-05 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	25401	\N	2017-12-05 10:01:47	2018-01-25 18:56:26
29050	PDT	2017-12-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25072	\N	2017-12-05 10:04:26	\N
29051	PDT	2017-12-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24174	\N	2017-12-05 10:04:56	\N
29052	PDT	2017-12-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24762	\N	2017-12-05 10:05:17	\N
29053	PDT	2017-12-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24043	\N	2017-12-05 10:06:12	\N
29054	PDT	2017-12-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24311	\N	2017-12-05 10:06:37	\N
29055	PDT	2017-12-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24192	\N	2017-12-05 10:07:25	\N
29056	PDT	2017-12-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24301	\N	2017-12-05 10:07:43	\N
29057	PDT	2017-12-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23956	\N	2017-12-05 10:08:32	\N
29058	PDT	2017-12-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24951	\N	2017-12-05 10:08:56	\N
29059	PDT	2017-12-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24117	\N	2017-12-05 10:09:16	\N
29060	PDT	2017-12-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24273	\N	2017-12-05 10:09:38	\N
29061	PDT	2017-12-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23960	\N	2017-12-05 10:10:00	\N
29062	PDT	2017-12-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24538	\N	2017-12-05 10:10:23	\N
29151	MEMBRE	2017-12-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25598	\N	2017-12-08 11:44:56	\N
29416	VICPDT	2017-12-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25756	\N	2017-12-22 16:50:13	2017-12-22 16:50:38
29446	MEMBRE	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25778	\N	2018-01-02 17:37:45	\N
29459	MEMBRE	2018-01-04 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25786	\N	2018-01-10 09:52:32	\N
29460	MEMBRE	2018-01-04 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25787	\N	2018-01-10 09:52:32	\N
29461	MEMBRE	2018-01-08 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	25788	\N	2018-01-10 09:52:52	2018-01-23 17:48:51
29487	MEMBRE	2017-12-07 00:00:00	2018-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	25813	\N	\N	\N
29493	MEMBRE	2018-01-10 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	25819	\N	2018-01-16 11:01:54	2018-01-24 15:55:09
29496	MEMBRE	2017-12-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	25822	\N	\N	\N
29553	VICPDT	2018-01-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24611	\N	2018-01-16 18:56:35	\N
29554	VICPDT	2018-01-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25052	\N	2018-01-16 18:56:46	\N
29555	VICPDT	2018-01-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24575	\N	2018-01-16 18:56:57	\N
29556	VICPDT	2018-01-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24968	\N	2018-01-16 18:57:07	\N
29546	MEMBRE	2017-12-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	25850	\N	\N	\N
29557	VICPDT	2018-01-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25061	\N	2018-01-16 18:57:14	\N
29548	MEMBRE	2017-12-19 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25851	\N	\N	\N
29558	VICPDT	2018-01-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24303	\N	2018-01-16 18:57:26	\N
29559	VICPDT	2018-01-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24633	\N	2018-01-16 18:57:36	\N
29560	SECRET	2018-01-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24173	\N	2018-01-16 18:57:50	\N
29561	SECRET	2018-01-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25499	\N	2018-01-16 18:57:57	\N
29562	SECRET	2018-01-16 00:00:00	2020-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	24981	\N	2018-01-16 18:58:04	\N
29563	SECRET	2018-01-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24869	\N	2018-01-16 18:58:12	\N
29564	VICPDT	2018-01-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24588	\N	2018-01-16 18:59:35	\N
29565	VICPDT	2018-01-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25771	\N	2018-01-16 18:59:49	\N
29566	SECRET	2018-01-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25516	\N	2018-01-16 19:00:33	\N
29567	VICPDT	2018-01-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24778	\N	2018-01-16 19:06:37	\N
29568	VICPDT	2018-01-16 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	24501	\N	2018-01-16 19:06:45	\N
29569	SECRET	2018-01-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24842	\N	2018-01-16 19:06:52	\N
29570	SECRET	2018-01-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25201	\N	2018-01-16 19:06:57	\N
26117	MEMBRE	2014-10-01 00:00:00	2015-03-24 00:00:00	ANCIEN	\N	\N	\N	\N	23108	\N	\N	\N
26160	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23128	\N	\N	\N
26161	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23129	\N	\N	\N
26162	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23130	\N	\N	\N
26163	MEMBRE	2014-10-01 00:00:00	2015-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	23131	\N	\N	\N
26165	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23133	\N	\N	\N
26166	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23134	\N	\N	\N
26167	MEMBRE	2014-10-01 00:00:00	2015-05-28 00:00:00	ANCIEN	\N	\N	\N	\N	23135	\N	\N	\N
26168	MEMBRE	2014-10-01 00:00:00	2015-05-28 00:00:00	ANCIEN	\N	\N	\N	\N	23136	\N	\N	\N
26169	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23137	\N	\N	\N
26170	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23138	\N	\N	\N
26172	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23140	\N	\N	\N
26173	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23141	\N	\N	\N
26175	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23143	\N	\N	\N
26191	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23146	\N	\N	\N
26192	MEMBRE	2014-10-01 00:00:00	2015-04-15 00:00:00	ANCIEN	\N	\N	\N	\N	23147	\N	\N	\N
26193	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23148	\N	\N	\N
26194	MEMBRE	2014-10-01 00:00:00	2016-01-11 00:00:00	ANCIEN	\N	\N	\N	\N	23149	\N	\N	2016-01-11 17:34:09
26195	MEMBRE	2015-01-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	23150	\N	\N	\N
26618	MEMBRE	2015-06-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23376	\N	2015-07-16 10:33:45	\N
26684	MEMBRE	2015-11-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23414	\N	2015-11-02 16:15:52	2017-09-24 18:16:52
27457	MEMBRE	2017-10-11 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	24024	\N	2017-10-12 10:12:57	2018-01-18 17:51:59
27458	MEMBRE	2017-10-11 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24025	\N	2017-10-12 10:12:57	2018-01-24 17:10:44
27459	MEMBRE	2017-10-11 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	24026	\N	2017-10-12 10:12:57	2018-01-25 17:40:02
27460	MEMBRE	2017-10-11 00:00:00	2017-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	24027	\N	2017-10-12 10:12:57	2017-12-05 16:37:14
27461	MEMBRE	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24028	\N	2017-10-12 10:12:57	\N
27462	MEMBRE	2017-10-11 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	24029	\N	2017-10-12 10:12:57	2018-02-07 15:30:50
27463	MEMBRE	2017-10-11 00:00:00	2017-10-16 00:00:00	ANCIEN	\N	\N	\N	\N	24030	\N	2017-10-12 10:13:24	2017-10-18 16:05:47
27464	MEMBRE	2017-10-11 00:00:00	2018-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	24031	\N	2017-10-12 10:13:24	2018-01-16 19:08:47
27465	MEMBRE	2017-10-11 00:00:00	2018-03-04 00:00:00	ANCIEN	\N	\N	\N	\N	24032	\N	2017-10-12 10:14:00	2018-03-05 17:57:52
27466	MEMBRE	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24033	\N	2017-10-12 10:14:00	\N
27467	MEMBRE	2017-10-11 00:00:00	2018-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	24034	\N	2017-10-12 10:14:00	2018-01-30 09:25:46
27468	MEMBRE	2017-10-11 00:00:00	2017-12-26 00:00:00	ANCIEN	\N	\N	\N	\N	24035	\N	2017-10-12 10:14:00	2017-12-27 11:10:12
27469	MEMBRE	2017-10-11 00:00:00	2017-12-05 00:00:00	ANCIEN	\N	\N	\N	\N	24036	\N	2017-10-12 10:14:00	2017-12-06 15:12:46
27470	MEMBRE	2017-10-11 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	24037	\N	2017-10-12 10:14:00	2018-01-18 11:22:36
27471	MEMBRE	2017-10-10 00:00:00	2018-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	24038	\N	2017-10-12 10:14:28	2018-02-12 09:30:12
27472	MEMBRE	2017-10-10 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24039	\N	2017-10-12 10:14:28	2018-01-24 15:53:52
27473	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24040	\N	2017-10-12 10:14:28	\N
27474	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24041	\N	2017-10-12 10:14:28	\N
27475	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24042	\N	2017-10-12 10:14:28	\N
27476	MEMBRE	2017-10-11 00:00:00	2017-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	24043	\N	2017-10-12 10:15:28	2017-12-05 10:06:12
27477	MEMBRE	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24044	\N	2017-10-12 10:15:28	\N
27478	MEMBRE	2017-10-11 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	24045	\N	2017-10-12 10:15:28	2018-01-23 16:58:03
27479	MEMBRE	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24046	\N	2017-10-12 10:15:28	\N
27480	MEMBRE	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24047	\N	2017-10-12 10:15:28	\N
28237	MEMBRE	2017-10-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24804	\N	2017-10-30 09:13:28	\N
28238	MEMBRE	2017-10-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24805	\N	2017-10-30 09:13:28	\N
28239	MEMBRE	2017-10-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24806	\N	2017-10-30 09:13:28	\N
28857	MEMBRE	2017-11-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25424	\N	2017-11-24 09:41:29	\N
28858	MEMBRE	2017-11-22 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	25425	\N	2017-11-24 09:47:21	2018-01-24 15:04:59
28859	MEMBRE	2017-11-22 00:00:00	2017-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	25426	\N	2017-11-24 09:47:21	2017-11-27 16:39:24
28860	MEMBRE	2017-11-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25427	\N	2017-11-24 09:47:21	\N
28861	MEMBRE	2017-11-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25428	\N	2017-11-24 09:47:56	\N
28862	MEMBRE	2017-11-23 00:00:00	2018-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	25429	\N	2017-11-24 09:47:56	2018-01-26 16:15:25
28863	MEMBRE	2017-11-23 00:00:00	2018-03-04 00:00:00	ANCIEN	\N	\N	\N	\N	25430	\N	2017-11-24 09:47:56	2018-03-05 17:18:20
28864	MEMBRE	2017-11-24 00:00:00	2018-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	25431	\N	2017-11-24 09:49:37	2018-02-01 18:32:56
28865	MEMBRE	2017-11-24 00:00:00	2017-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	25432	\N	2017-11-24 09:49:37	2017-12-05 10:00:33
28866	MEMBRE	2017-11-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25433	\N	2017-11-24 09:50:34	\N
28867	MEMBRE	2017-11-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25434	\N	2017-11-24 09:50:34	\N
28868	MEMBRE	2017-11-17 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	25435	\N	2017-11-24 09:50:34	2018-01-24 10:43:23
28869	MEMBRE	2017-11-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25436	\N	2017-11-24 09:50:34	\N
28870	MEMBRE	2017-11-17 00:00:00	2017-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	25437	\N	2017-11-24 09:50:34	2017-12-14 18:23:23
28871	MEMBRE	2017-11-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25438	\N	2017-11-24 09:51:19	\N
28872	MEMBRE	2017-11-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25439	\N	2017-11-24 09:51:19	\N
28873	MEMBRE	2017-11-23 00:00:00	2018-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	25440	\N	2017-11-24 09:51:19	2018-02-15 10:19:30
28874	MEMBRE	2017-11-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25441	\N	2017-11-24 09:51:19	\N
28875	MEMBRE	2017-11-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25442	\N	2017-11-24 09:51:19	\N
28876	MEMBRE	2017-11-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25443	\N	2017-11-24 09:51:19	\N
28877	MEMBRE	2017-11-23 00:00:00	2017-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	25444	\N	2017-11-24 09:51:19	2017-12-19 18:04:51
30339	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26183	\N	\N	\N
28878	MEMBRE	2017-11-22 00:00:00	2018-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	25445	\N	2017-11-24 09:51:39	2018-02-08 17:36:17
28879	MEMBRE	2017-11-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25446	\N	2017-11-24 09:51:56	\N
28880	MEMBRE	2017-11-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25447	\N	2017-11-24 09:52:41	\N
28881	MEMBRE	2017-11-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25448	\N	2017-11-24 09:52:59	\N
28882	MEMBRE	2017-11-22 00:00:00	2017-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	25449	\N	2017-11-24 09:53:14	2017-11-30 16:32:45
28883	MEMBRE	2017-11-17 00:00:00	2018-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	25450	\N	2017-11-24 09:53:27	2018-01-30 14:47:11
28884	MEMBRE	2017-11-21 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	25451	\N	2017-11-24 10:20:38	2017-12-20 14:35:04
28885	MEMBRE	2017-11-21 00:00:00	2018-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	25452	\N	2017-11-24 10:20:52	2018-01-16 19:09:16
28886	MEMBRE	2017-11-23 00:00:00	2017-12-11 00:00:00	ANCIEN	\N	\N	\N	\N	25453	\N	2017-11-24 10:21:07	2017-12-12 17:31:31
28887	MEMBRE	2017-11-21 00:00:00	2017-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	25454	\N	2017-11-24 10:21:23	2017-11-30 11:16:39
29035	MEMBRE	2017-11-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25526	\N	2017-12-01 15:49:40	\N
29036	MEMBRE	2017-11-23 00:00:00	2018-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	25527	\N	2017-12-01 16:29:16	2018-02-12 16:56:32
29040	MEMBRE	2017-12-04 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25531	\N	2017-12-04 16:34:55	\N
29041	MEMBRE	2017-12-04 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25532	\N	2017-12-04 16:34:55	\N
29042	MEMBRE	2017-12-04 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	25533	\N	2017-12-04 16:34:55	2018-02-07 12:15:30
29063	MEMBRE	2017-11-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25536	\N	2017-12-05 14:42:00	\N
29064	MEMBRE	2017-11-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25537	\N	2017-12-05 14:42:17	\N
29065	MEMBRE	2017-12-04 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25538	\N	2017-12-05 14:42:40	\N
29066	MEMBRE	2017-12-04 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	25539	\N	2017-12-05 14:42:40	2018-02-07 15:29:43
29067	MEMBRE	2017-12-04 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	25540	\N	2017-12-05 14:42:40	2018-01-31 18:42:58
29068	MEMBRE	2017-12-04 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	25541	\N	2017-12-05 14:42:40	2018-01-18 17:50:58
29069	MEMBRE	2017-12-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	25542	\N	2017-12-05 14:42:58	\N
29152	MEMBRE	2017-12-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25599	\N	2017-12-08 16:41:52	\N
29153	MEMBRE	2017-11-29 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	25600	\N	2017-12-08 16:47:38	\N
29219	VICPDT	2017-12-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23982	\N	2017-12-14 18:20:44	\N
29220	VICPDT	2017-12-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25007	\N	2017-12-14 18:21:12	\N
29221	VICPDT	2017-12-14 00:00:00	2019-08-27 00:00:00	ANCIEN	\N	\N	\N	\N	23963	\N	2017-12-14 18:21:26	\N
29222	VICPDT	2017-12-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23946	\N	2017-12-14 18:21:44	\N
29223	VICPDT	2017-12-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25566	\N	2017-12-14 18:21:53	\N
29224	SECRET	2017-12-14 00:00:00	2020-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	25151	\N	2017-12-14 18:23:03	\N
29225	SECRET	2017-12-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25437	\N	2017-12-14 18:23:23	\N
29226	SECRET	2017-12-14 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	25024	\N	2017-12-14 18:23:43	\N
29227	PDTDEL	2017-12-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	Congo-Brazzaville	\N	24646	\N	2017-12-14 18:27:04	2017-12-14 18:37:50
29228	PDTDEL	2017-12-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Kenya	\N	24789	\N	2017-12-14 18:31:33	2017-12-14 18:31:45
29229	PDTDEL	2017-12-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Turkménistan	\N	24036	\N	2017-12-14 18:34:28	2017-12-14 18:34:55
29230	PDTDEL	2017-12-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Sao-Tomé-et-Principe	\N	25324	\N	2017-12-14 18:37:23	2017-12-14 18:38:14
22274	MEMBRE	2013-11-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20220	\N	2013-12-13 15:10:32	2014-10-14 16:20:48
23266	MEMBRE	2014-10-24 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21177	\N	2014-10-24 14:17:12	\N
23267	MEMBRE	2014-10-22 00:00:00	2015-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	21178	\N	2014-10-24 14:19:00	2015-03-16 18:44:44
23268	MEMBRE	2014-10-22 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	21179	\N	2014-10-24 14:19:00	2015-02-20 12:08:50
23269	MEMBRE	2014-10-22 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	21180	\N	2014-10-24 14:19:00	2015-02-20 10:43:15
23270	MEMBRE	2014-10-22 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	21181	\N	2014-10-24 14:19:00	2015-02-05 19:00:46
23271	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21182	\N	2014-10-24 14:19:00	\N
23272	MEMBRE	2014-10-22 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21183	\N	2014-10-24 14:19:00	2015-01-06 15:48:21
23273	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21184	\N	2014-10-24 14:19:00	\N
23274	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21185	\N	2014-10-24 14:19:00	\N
23275	MEMBRE	2014-10-22 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	21186	\N	2014-10-24 14:19:00	2015-02-03 10:25:31
23276	MEMBRE	2014-10-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21187	\N	2014-10-24 14:19:40	\N
23277	MEMBRE	2014-10-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21188	\N	2014-10-24 14:19:40	\N
23278	MEMBRE	2014-10-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21189	\N	2014-10-24 14:19:40	\N
23279	MEMBRE	2014-10-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21190	\N	2014-10-24 14:19:40	\N
23280	MEMBRE	2014-10-20 00:00:00	2015-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	21191	\N	2014-10-24 14:19:40	2015-01-20 11:25:31
23281	MEMBRE	2014-10-20 00:00:00	2015-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	21192	\N	2014-10-24 14:19:40	2015-02-18 09:59:08
23282	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21193	\N	2014-10-24 14:21:32	\N
23283	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21194	\N	2014-10-24 14:22:06	\N
23284	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21195	\N	2014-10-24 14:22:06	\N
23285	MEMBRE	2014-10-21 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	21196	\N	2014-10-24 14:22:06	2015-02-13 17:04:19
23286	MEMBRE	2014-10-21 00:00:00	2015-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	21197	\N	2014-10-24 14:22:06	2015-02-23 15:21:24
23287	MEMBRE	2014-10-21 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21198	\N	2014-10-24 14:22:06	2015-01-06 15:33:09
23288	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21199	\N	2014-10-24 14:22:38	\N
23576	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21487	\N	2014-10-29 13:22:07	\N
23577	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21488	\N	2014-10-29 13:22:07	\N
23578	MEMBRE	2014-10-29 00:00:00	2015-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	21489	\N	2014-10-29 13:22:07	2015-02-06 14:46:24
23579	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21490	\N	2014-10-29 13:22:07	\N
23580	MEMBRE	2014-10-29 00:00:00	2015-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	21491	\N	2014-10-29 13:22:07	2015-02-06 16:57:29
23587	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21498	\N	2014-10-29 14:28:24	\N
23588	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21499	\N	2014-10-29 14:28:24	\N
23589	MEMBRE	2014-10-29 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	21500	\N	2014-10-29 14:28:24	2015-02-05 19:03:45
23590	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21501	\N	2014-10-29 14:28:24	\N
23591	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21502	\N	2014-10-29 14:28:24	\N
24203	MEMBRE	2014-11-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22114	\N	2014-11-05 10:22:57	\N
24655	VICPDT	2015-01-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21079	4	2015-01-19 14:15:29	2015-01-20 11:31:37
24653	VICPDT	2015-01-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20616	2	2015-01-19 14:15:06	2015-01-19 14:17:57
24654	VICPDT	2015-01-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20313	3	2015-01-19 14:15:20	2015-01-19 14:18:01
24656	VICPDT	2015-01-19 00:00:00	2016-03-30 00:00:00	ANCIEN	\N	\N	\N	\N	22147	5	2015-01-19 14:15:41	2016-03-31 15:50:35
24657	VICPDT	2015-01-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21443	6	2015-01-19 14:15:50	2015-01-20 11:31:43
24658	VICPDT	2015-01-19 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	21851	7	2015-01-19 14:16:02	2016-03-11 18:02:51
24659	VICPDT	2015-01-19 00:00:00	2015-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	21420	\N	2015-01-19 14:16:13	2015-01-30 14:45:40
24660	VICPDT	2015-01-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22282	9	2015-01-19 14:16:22	2015-01-19 14:18:28
24661	SECRET	2015-01-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20961	10	2015-01-19 14:16:42	2015-01-19 14:18:49
24662	SECRET	2015-01-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21943	12	2015-01-19 14:16:51	2015-01-20 11:32:54
24663	SECRET	2015-01-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21011	13	2015-01-19 14:17:01	2015-01-20 11:33:30
24846	MEMBRE	2015-01-08 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22481	\N	2015-01-30 09:46:54	\N
24847	MEMBRE	2015-01-28 00:00:00	2015-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	22482	\N	2015-01-30 09:47:09	2015-02-17 16:14:00
24848	MEMBRE	2015-01-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22483	\N	2015-01-30 09:47:32	\N
24849	MEMBRE	2015-01-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22484	\N	2015-01-30 09:47:32	\N
24850	MEMBRE	2015-01-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22485	\N	2015-01-30 09:47:49	\N
24851	MEMBRE	2015-01-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22486	\N	2015-01-30 09:47:49	\N
24852	MEMBRE	2015-01-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22487	\N	2015-01-30 09:47:49	\N
24853	MEMBRE	2015-01-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22488	\N	2015-01-30 09:48:02	\N
24878	PDTDEL	2015-02-02 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour le Ghana	\N	22418	11	2015-02-02 10:47:42	2015-02-11 12:12:44
24879	PDTDEL	2015-02-02 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour le Togo	\N	22497	12	2015-02-02 10:48:20	2015-02-11 12:12:58
24880	PDTDEL	2015-02-02 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour la République démocratique du Congo	\N	22498	6	2015-02-02 11:27:39	2015-02-03 10:15:20
25440	MEMBRE	2014-10-01 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	22699	\N	\N	2017-06-19 12:20:59
25485	MEMBRE	2014-10-01 00:00:00	2015-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	22744	\N	\N	\N
26062	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23084	\N	\N	\N
26286	MEMBRE	2015-03-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23172	\N	2015-03-25 10:11:28	\N
26457	PDT	2015-05-17 00:00:00	2015-05-18 00:00:00	ANCIEN	\N	\N	\N	\N	22773	\N	\N	\N
26459	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23271	\N	\N	2017-09-25 10:58:49
26629	MEMBRE	2015-07-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23378	\N	2015-07-22 15:49:27	\N
26646	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23385	\N	\N	\N
26647	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23386	\N	\N	\N
26651	MEMBRE	2015-09-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23390	\N	2015-09-16 17:35:51	\N
26657	MEMBRE	2015-09-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23396	\N	2015-10-05 16:53:17	\N
23837	MEMBRE	2014-10-30 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	21748	\N	2014-10-30 15:39:11	2015-10-13 14:18:52
26694	MEMBRE	2015-11-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23424	\N	2015-11-13 15:12:22	\N
26695	VICPDT	2015-11-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23103	5	2015-11-18 09:39:25	2015-11-18 09:41:58
26704	MEMBRE	2015-11-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23432	\N	2015-12-01 10:00:38	\N
26714	MEMBRE	2015-12-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23438	\N	2015-12-17 09:33:54	\N
26715	VICPDT	2015-09-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	23416	\N	\N	\N
26719	MEMBRE	2016-01-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23440	\N	2016-01-25 10:28:34	\N
26736	MEMBRE	2016-02-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23455	\N	2016-02-12 12:17:23	2017-09-24 17:47:28
26737	MEMBRE	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	23456	\N	2016-02-12 12:17:51	2017-04-27 16:00:50
26738	MEMBRE	2016-02-12 00:00:00	2018-01-04 00:00:00	ANCIEN	\N	\N	\N	\N	23457	\N	2016-02-12 12:18:00	2018-01-05 11:29:32
26739	MEMBRE	2016-02-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23458	\N	2016-02-12 12:18:54	2017-09-24 13:44:49
26740	VICPDT	2016-02-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23459	\N	2016-02-12 12:19:02	2017-09-24 13:44:49
26741	MEMBRE	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	23460	\N	2016-02-12 12:19:07	\N
26742	MEMBRE	2016-02-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23461	\N	2016-02-12 12:19:10	2017-09-24 17:09:24
26743	MEMBRE	2016-02-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23462	\N	2016-02-12 12:19:16	\N
26744	MEMBRE	2016-02-12 00:00:00	2016-11-24 00:00:00	ANCIEN	\N	\N	\N	\N	23462	\N	2016-02-12 12:19:18	2016-11-24 16:25:14
26745	MEMBRE	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	23463	\N	2016-02-12 12:19:25	\N
26746	MEMBRE	2016-02-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23464	\N	2016-02-12 12:19:28	2017-09-24 17:18:03
26747	MEMBRE	2016-02-12 00:00:00	2020-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	23465	\N	2016-02-12 12:19:37	\N
26748	MEMBRE	2016-02-12 00:00:00	2020-10-19 00:00:00	ANCIEN	\N	\N	\N	\N	23466	\N	2016-02-12 12:19:44	\N
26749	MEMBRE	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	23467	\N	2016-02-12 12:19:59	\N
26750	MEMBRE	2016-02-12 00:00:00	2020-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	23468	\N	2016-02-12 12:20:31	\N
26751	MEMBRE	2016-02-12 00:00:00	2018-01-04 00:00:00	ANCIEN	\N	\N	\N	\N	23469	\N	2016-02-12 12:21:05	2018-01-05 11:29:19
26752	MEMBRE	2016-02-12 00:00:00	2017-06-01 00:00:00	ANCIEN	\N	\N	\N	\N	23470	\N	2016-02-12 12:21:08	2017-06-02 10:02:57
26753	MEMBRE	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	23471	\N	2016-02-12 12:21:14	\N
26754	MEMBRE	2016-02-12 00:00:00	2020-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	23472	\N	2016-02-12 12:21:18	\N
26755	MEMBRE	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	23473	\N	2016-02-12 12:21:26	\N
26756	MEMBRE	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	23474	\N	2016-02-12 12:21:30	\N
26757	MEMBRE	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	23475	\N	2016-02-12 12:22:32	\N
26758	MEMBRE	2016-02-12 00:00:00	2023-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	23476	\N	2016-02-12 12:22:36	\N
26759	MEMBRE	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	23477	\N	2016-02-12 12:22:51	\N
26760	MEMBRE	2016-02-12 00:00:00	2020-10-19 00:00:00	ANCIEN	\N	\N	\N	\N	23478	\N	2016-02-12 12:22:57	\N
25484	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22743	\N	\N	\N
25487	MEMBRE	2014-10-01 00:00:00	2015-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	22746	\N	\N	\N
25491	MEMBRE	2014-10-01 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	22750	\N	\N	2017-09-25 09:56:00
25494	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22753	\N	\N	\N
30340	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26184	\N	\N	\N
25495	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22754	\N	\N	2017-09-24 13:44:49
25496	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22755	\N	\N	\N
25497	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22756	\N	\N	\N
25498	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22757	\N	\N	\N
25499	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22758	\N	\N	2017-09-24 13:25:54
25557	MEMBRE	2015-02-16 00:00:00	2015-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	22218	\N	2015-02-16 15:59:50	2015-02-18 13:31:00
25558	MEMBRE	2015-02-16 00:00:00	2015-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	22254	\N	2015-02-16 15:59:58	2015-02-18 13:31:04
25559	MEMBRE	2015-02-16 00:00:00	2015-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	21086	\N	2015-02-16 16:00:03	2015-02-18 13:31:08
25560	MEMBRE	2015-02-16 00:00:00	2015-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	20403	\N	2015-02-16 16:00:07	2015-02-18 13:31:16
25561	MEMBRE	2015-02-16 00:00:00	2015-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	21196	\N	2015-02-16 16:00:10	2015-02-18 13:31:29
25562	MEMBRE	2015-02-16 00:00:00	2015-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	20303	\N	2015-02-16 16:00:15	2015-02-18 13:31:40
25563	MEMBRE	2015-02-16 00:00:00	2015-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	21898	\N	2015-02-16 16:00:19	2015-02-18 13:31:33
25564	MEMBRE	2015-02-16 00:00:00	2015-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	22030	\N	2015-02-16 16:00:22	2015-02-18 13:31:48
25565	MEMBRE	2015-02-16 00:00:00	2015-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	20439	\N	2015-02-16 16:00:25	2015-02-18 13:31:44
25566	MEMBRE	2015-02-16 00:00:00	2015-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	21952	\N	2015-02-16 16:00:28	2015-02-18 13:31:52
25567	MEMBRE	2015-02-16 00:00:00	2015-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	21661	\N	2015-02-16 16:00:32	2015-02-18 13:31:22
25869	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22953	\N	\N	2017-09-25 10:56:48
25872	MEMBRE	2014-10-01 00:00:00	2015-03-04 00:00:00	ANCIEN	\N	\N	\N	\N	22956	\N	\N	\N
25873	MEMBRE	2014-10-01 00:00:00	2015-03-04 00:00:00	ANCIEN	\N	\N	\N	\N	22957	\N	\N	\N
25925	MEMBRE	2015-02-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22984	\N	2015-03-03 10:25:00	\N
25935	MEMBRE	2014-09-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22994	\N	2015-03-03 13:28:18	\N
25936	MEMBRE	2014-09-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22995	\N	2015-03-03 13:28:35	\N
25937	MEMBRE	2014-09-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22996	\N	2015-03-03 13:28:49	\N
25938	MEMBRE	2014-09-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22997	\N	2015-03-03 13:29:01	\N
25939	MEMBRE	2014-09-01 00:00:00	2015-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	22998	\N	2015-03-03 13:29:12	\N
25940	MEMBRE	2014-09-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22999	\N	2015-03-03 13:29:30	\N
25941	MEMBRE	2014-09-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23000	\N	2015-03-03 13:29:39	\N
25942	MEMBRE	2014-09-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23001	\N	2015-03-03 13:29:54	\N
25943	MEMBRE	2014-09-01 00:00:00	2015-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	23002	\N	2015-03-03 13:30:10	\N
25944	MEMBRE	2014-09-01 00:00:00	2015-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	23003	\N	2015-03-03 13:30:20	\N
25945	MEMBRE	2014-09-01 00:00:00	2017-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	23004	\N	2015-03-03 13:30:33	2017-09-24 11:09:53
25946	MEMBRE	2014-09-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23005	\N	2015-03-03 13:30:48	\N
25947	MEMBRE	2014-09-01 00:00:00	2015-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	23006	\N	2015-03-03 13:31:02	\N
25948	MEMBRE	2014-09-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23007	\N	2015-03-03 13:31:11	\N
25949	MEMBRE	2014-09-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23008	\N	2015-03-03 13:31:23	\N
25950	MEMBRE	2014-09-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23009	\N	2015-03-03 13:31:34	\N
25951	MEMBRE	2014-09-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23010	\N	2015-03-03 13:31:49	\N
25952	MEMBRE	2014-09-01 00:00:00	2015-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	23011	\N	2015-03-03 13:32:01	\N
25953	MEMBRE	2014-09-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23012	\N	2015-03-03 13:32:12	\N
25954	MEMBRE	2014-09-01 00:00:00	2015-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	23013	\N	2015-03-03 13:32:26	\N
25955	MEMBRE	2014-09-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23014	\N	2015-03-03 13:32:33	\N
25956	MEMBRE	2014-09-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23015	\N	2015-03-03 13:36:46	\N
25957	MEMBRE	2014-09-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23017	\N	2015-03-03 13:38:52	\N
25958	MEMBRE	2014-09-01 00:00:00	2017-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	23018	\N	2015-03-03 13:39:08	2017-07-04 15:08:09
25959	MEMBRE	2014-09-01 00:00:00	2015-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	23019	\N	2015-03-03 13:39:20	\N
25960	MEMBRE	2014-09-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23020	\N	2015-03-03 13:39:33	\N
25961	MEMBRE	2014-09-01 00:00:00	2015-08-31 00:00:00	ANCIEN	\N	\N	\N	\N	23021	\N	2015-03-03 13:39:41	\N
25962	MEMBRE	2014-09-01 00:00:00	2015-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	23022	\N	2015-03-03 13:39:55	\N
25963	MEMBRE	2014-09-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23023	\N	2015-03-03 13:41:37	\N
25964	MEMBRE	2014-09-01 00:00:00	2015-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	23024	\N	2015-03-03 13:41:49	\N
25965	MEMBRE	2014-09-01 00:00:00	2015-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	23025	\N	2015-03-03 13:42:02	\N
25966	MEMBRE	2014-09-01 00:00:00	2015-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	23026	\N	2015-03-03 13:42:22	\N
25967	MEMBRE	2014-09-01 00:00:00	2015-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	23027	\N	2015-03-03 13:42:35	\N
25968	MEMBRE	2014-09-01 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	23028	\N	2015-03-03 13:42:49	2017-05-16 15:18:14
25969	MEMBRE	2014-09-01 00:00:00	2015-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	23029	\N	2015-03-03 13:42:58	\N
25970	MEMBRE	2014-09-01 00:00:00	2015-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	23030	\N	2015-03-03 13:43:35	\N
25971	MEMBRE	2014-09-01 00:00:00	2015-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	23031	\N	2015-03-03 13:43:46	\N
25972	MEMBRE	2014-09-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23032	\N	2015-03-03 13:43:56	\N
25973	MEMBRE	2014-09-01 00:00:00	2015-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	23033	\N	2015-03-03 13:44:08	\N
25974	MEMBRE	2014-09-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23034	\N	2015-03-03 13:44:20	\N
25975	MEMBRE	2014-09-01 00:00:00	2015-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	23035	\N	2015-03-03 13:44:33	\N
25976	MEMBRE	2014-09-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23036	\N	2015-03-03 13:44:46	\N
25977	MEMBRE	2014-09-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23037	\N	2015-03-03 13:44:56	\N
25978	MEMBRE	2014-09-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23038	\N	2015-03-03 13:45:10	\N
25979	MEMBRE	2014-09-01 00:00:00	2015-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	23039	\N	2015-03-03 13:45:23	\N
25980	MEMBRE	2014-09-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23040	\N	2015-03-03 13:57:06	\N
25981	MEMBRE	2014-09-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23041	\N	2015-03-03 13:57:25	\N
25982	MEMBRE	2014-09-01 00:00:00	2015-03-31 00:00:00	ANCIEN	\N	\N	\N	\N	23042	\N	2015-03-03 13:57:38	\N
25983	MEMBRE	2014-09-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23043	\N	2015-03-03 13:57:50	\N
25984	MEMBRE	2014-09-01 00:00:00	2015-03-31 00:00:00	ANCIEN	\N	\N	\N	\N	23044	\N	2015-03-03 13:58:08	\N
25986	MEMBRE	2014-09-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23045	\N	2015-03-03 13:58:21	\N
25987	MEMBRE	2014-09-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23047	\N	2015-03-03 13:58:33	\N
25988	MEMBRE	2014-09-01 00:00:00	2015-03-31 00:00:00	ANCIEN	\N	\N	\N	\N	23048	\N	2015-03-03 13:58:43	\N
25989	MEMBRE	2014-09-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23049	\N	2015-03-03 13:59:49	\N
25990	MEMBRE	2014-09-01 00:00:00	2017-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	23050	\N	2015-03-03 14:00:04	2017-07-04 15:08:09
25991	MEMBRE	2014-09-01 00:00:00	2015-04-06 00:00:00	ANCIEN	\N	\N	\N	\N	23051	\N	2015-03-03 14:00:18	\N
25992	MEMBRE	2014-09-01 00:00:00	2015-04-06 00:00:00	ANCIEN	\N	\N	\N	\N	23052	\N	2015-03-03 14:00:31	\N
25993	MEMBRE	2014-09-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23053	\N	2015-03-03 14:00:41	2017-10-01 10:34:22
25994	MEMBRE	2014-09-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23054	\N	2015-03-03 14:00:59	2017-09-24 17:06:55
25995	MEMBRE	2014-09-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23055	\N	2015-03-03 14:01:15	\N
25996	MEMBRE	2014-09-01 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	23056	\N	2015-03-03 14:01:37	2016-12-12 16:10:15
25997	MEMBRE	2014-09-01 00:00:00	2015-04-06 00:00:00	ANCIEN	\N	\N	\N	\N	23057	\N	2015-03-03 14:01:46	\N
25998	MEMBRE	2014-09-01 00:00:00	2015-04-06 00:00:00	ANCIEN	\N	\N	\N	\N	23058	\N	2015-03-03 14:01:55	\N
25999	MEMBRE	2014-09-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23059	\N	2015-03-03 14:02:09	\N
26053	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23080	\N	\N	2017-09-24 17:47:27
26077	VICPDT	2015-03-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	22961	\N	\N	\N
26079	VICPDT	2015-03-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	22903	\N	\N	\N
26080	VICPDT	2015-03-05 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	22956	\N	\N	2015-06-12 16:01:58
26081	VICPDT	2015-03-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	22900	\N	\N	\N
26082	MEMBRE	2015-03-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23096	\N	2015-03-05 11:47:23	\N
26118	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23109	\N	\N	\N
26448	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23264	\N	\N	2017-09-24 17:06:55
26681	MEMBRE	2015-10-29 00:00:00	2015-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	23414	\N	2015-10-29 17:24:09	2015-11-02 16:16:22
26907	MEMBRE	2016-05-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23614	\N	2016-05-04 16:09:23	\N
27159	MEMBRE	2017-01-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23828	\N	2017-01-18 17:45:25	\N
23819	MEMBRE	2014-10-29 00:00:00	2017-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	21730	\N	2014-10-30 15:35:54	2017-07-24 09:58:00
27254	PDT	2017-08-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23862	\N	2017-08-02 09:51:06	\N
27512	MEMBRE	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24079	\N	2017-10-12 18:26:55	\N
22264	VICPDT	2013-10-10 00:00:00	2014-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	19993	\N	\N	\N
22590	MEMBRE	2014-10-17 00:00:00	2015-01-21 00:00:00	ANCIEN	\N	\N	\N	\N	20534	\N	2014-10-20 09:50:28	2015-01-22 10:50:11
22591	MEMBRE	2014-10-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20535	\N	2014-10-20 09:50:28	\N
22592	MEMBRE	2014-10-17 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	20536	\N	2014-10-20 09:50:28	2015-02-03 10:20:53
22593	MEMBRE	2014-10-17 00:00:00	2015-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	20537	\N	2014-10-20 09:50:28	2015-01-30 15:56:05
22594	MEMBRE	2014-10-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20538	\N	2014-10-20 09:51:29	\N
22595	MEMBRE	2014-10-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20539	\N	2014-10-20 09:51:29	\N
22596	MEMBRE	2014-10-16 00:00:00	2015-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	20540	\N	2014-10-20 09:51:29	2015-01-30 09:40:26
22597	MEMBRE	2014-10-16 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	20541	\N	2014-10-20 09:51:29	2015-01-06 15:52:27
22598	MEMBRE	2014-10-16 00:00:00	2016-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	20542	\N	2014-10-20 09:51:29	2016-12-07 16:40:05
22599	MEMBRE	2014-10-16 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	20543	\N	2014-10-20 09:51:29	2015-02-19 15:42:52
22600	MEMBRE	2014-10-16 00:00:00	2015-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	20544	\N	2014-10-20 09:51:29	2015-02-06 14:47:16
22601	MEMBRE	2014-10-16 00:00:00	2015-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	20545	\N	2014-10-20 09:51:30	2015-02-06 16:56:43
22602	MEMBRE	2014-10-16 00:00:00	2015-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	20546	\N	2014-10-20 09:51:30	2015-03-19 10:03:05
22603	MEMBRE	2014-10-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20547	\N	2014-10-20 09:51:30	\N
22604	MEMBRE	2014-10-16 00:00:00	2015-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	20548	\N	2014-10-20 09:51:30	2015-02-09 11:03:28
22605	MEMBRE	2014-10-16 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	20549	\N	2014-10-20 09:51:30	2015-02-05 19:01:03
22606	MEMBRE	2014-10-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20550	\N	2014-10-20 09:51:30	\N
22607	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20551	\N	2014-10-20 09:52:08	\N
22608	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20552	\N	2014-10-20 09:52:08	\N
22609	MEMBRE	2014-10-15 00:00:00	2015-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	20553	\N	2014-10-20 09:52:08	2015-03-16 18:43:52
22610	MEMBRE	2014-10-15 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	20554	\N	2014-10-20 09:52:08	2015-02-05 18:54:25
22611	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20555	\N	2014-10-20 09:52:24	\N
22612	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20556	\N	2014-10-20 09:52:24	\N
22613	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20557	\N	2014-10-20 09:52:24	\N
23550	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21461	\N	2014-10-29 12:04:40	\N
23551	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21462	\N	2014-10-29 12:04:40	\N
23552	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21463	\N	2014-10-29 12:04:40	\N
23553	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21464	\N	2014-10-29 12:04:40	\N
23554	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21465	\N	2014-10-29 12:04:40	\N
23555	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21466	\N	2014-10-29 12:04:40	\N
23556	MEMBRE	2014-10-28 00:00:00	2015-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	21467	\N	2014-10-29 12:04:40	2015-02-09 11:04:13
23557	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21468	\N	2014-10-29 12:04:40	\N
23750	MEMBRE	2014-10-21 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	21661	\N	2014-10-30 12:34:05	2015-02-13 17:03:45
23751	MEMBRE	2014-10-21 00:00:00	2015-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	21662	\N	2014-10-30 12:34:05	2015-02-23 11:39:36
23752	MEMBRE	2014-10-21 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	21663	\N	2014-10-30 12:34:05	2015-02-19 16:23:32
23753	MEMBRE	2014-10-21 00:00:00	2015-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	21664	\N	2014-10-30 12:34:05	2015-02-17 09:40:04
23754	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21665	\N	2014-10-30 12:34:05	\N
23755	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21666	\N	2014-10-30 12:34:05	\N
23756	MEMBRE	2014-10-21 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	21667	\N	2014-10-30 12:34:05	2015-02-20 12:12:19
23757	MEMBRE	2014-10-21 00:00:00	2015-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	21668	\N	2014-10-30 12:34:05	2015-02-17 16:20:01
23758	MEMBRE	2014-10-21 00:00:00	2015-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	21669	\N	2014-10-30 12:34:05	2015-01-28 17:46:36
23759	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21670	\N	2014-10-30 12:34:05	\N
23760	MEMBRE	2014-10-21 00:00:00	2015-03-19 00:00:00	ANCIEN	\N	\N	\N	\N	21671	\N	2014-10-30 12:34:05	2015-03-20 09:53:01
23761	MEMBRE	2014-10-30 00:00:00	2016-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	21672	\N	2014-10-30 12:34:56	2016-12-07 16:42:27
23762	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21673	\N	2014-10-30 12:34:56	\N
23763	MEMBRE	2014-10-30 00:00:00	2015-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	21674	\N	2014-10-30 12:34:56	2015-02-04 10:19:26
23764	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21675	\N	2014-10-30 12:34:56	\N
23765	MEMBRE	2014-10-30 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	21676	\N	2014-10-30 12:34:56	2015-02-11 17:18:50
23766	MEMBRE	2014-10-30 00:00:00	2015-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	21677	\N	2014-10-30 12:34:57	2015-02-09 11:03:23
23767	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21678	\N	2014-10-30 12:34:57	\N
23768	MEMBRE	2014-10-30 00:00:00	2015-03-19 00:00:00	ANCIEN	\N	\N	\N	\N	21679	\N	2014-10-30 12:34:57	2015-03-20 09:53:26
23769	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21680	\N	2014-10-30 12:34:57	\N
23770	MEMBRE	2014-10-30 00:00:00	2015-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	21681	\N	2014-10-30 12:34:57	2015-01-28 10:26:47
23771	MEMBRE	2014-10-30 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21682	\N	2014-10-30 12:34:57	2015-01-06 17:37:59
23772	MEMBRE	2014-10-30 00:00:00	2015-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	21683	\N	2014-10-30 12:34:57	2015-02-06 16:58:34
23773	MEMBRE	2014-10-30 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	21684	\N	2014-10-30 12:34:57	2015-02-13 14:19:55
23774	MEMBRE	2014-10-30 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	21685	\N	2014-10-30 12:34:57	2015-02-13 15:15:33
24422	MEMBRE	2014-12-09 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	22329	\N	2014-12-10 14:31:39	2015-02-03 14:00:03
24423	MEMBRE	2014-12-09 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22330	\N	2014-12-11 09:28:27	\N
24424	MEMBRE	2014-12-09 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22331	\N	2014-12-11 09:28:39	\N
24816	VICPDT	2015-01-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20614	2	2015-01-29 10:52:11	2015-01-29 10:52:15
24817	VICPDT	2015-01-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20590	3	2015-01-29 10:52:28	2015-01-29 10:52:31
24819	VICPDT	2015-01-29 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	21424	4	2015-01-29 10:52:42	2017-05-16 15:18:14
24821	VICPDT	2015-01-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20316	5	2015-01-29 10:53:01	2015-01-29 10:53:07
24824	VICPDT	2015-01-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21690	6	2015-01-29 10:53:19	2015-01-29 10:53:25
24825	VICPDT	2015-01-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20768	7	2015-01-29 10:53:35	2015-01-29 10:53:41
24826	SECRET	2015-01-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20942	8	2015-01-29 10:53:50	2015-02-02 13:14:34
24828	SECRET	2015-01-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21232	9	2015-01-29 10:54:02	2015-01-29 10:54:07
24829	SECRET	2015-01-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20844	11	2015-01-29 10:54:45	2015-01-29 10:57:16
24830	SECRET	2015-01-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20600	12	2015-01-29 10:57:28	2015-01-29 10:57:43
25895	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22968	\N	\N	\N
25923	MEMBRE	2014-10-01 00:00:00	2014-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	22982	\N	\N	\N
25924	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22983	\N	\N	\N
25926	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22985	\N	\N	2017-09-24 17:14:26
25931	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22990	\N	\N	\N
26301	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23184	\N	\N	\N
26302	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23185	\N	\N	\N
26453	PDT	2015-05-20 00:00:00	2015-05-22 00:00:00	ANCIEN	\N	\N	\N	\N	23101	\N	\N	\N
26557	MEMBRE	2015-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23332	\N	\N	\N
26558	MEMBRE	2015-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23333	\N	\N	\N
26559	MEMBRE	2015-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23334	\N	\N	\N
26561	MEMBRE	2015-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23336	\N	\N	\N
26562	MEMBRE	2015-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23337	\N	\N	\N
26563	MEMBRE	2015-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23338	\N	\N	\N
26564	MEMBRE	2015-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23339	\N	\N	\N
26565	MEMBRE	2015-01-01 00:00:00	2015-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	23340	\N	\N	\N
26566	MEMBRE	2015-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23341	\N	\N	\N
26568	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23343	\N	\N	\N
26569	MEMBRE	2015-01-01 00:00:00	2015-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	23344	\N	\N	\N
26570	MEMBRE	2015-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23345	\N	\N	\N
26571	MEMBRE	2015-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23346	\N	\N	\N
26630	MEMBRE	2015-07-22 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	23379	\N	2015-07-23 15:20:40	2017-06-19 12:20:59
27021	MEMBRE	2014-10-01 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	23719	\N	\N	2017-06-19 16:06:51
26574	MEMBRE	2015-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23349	\N	\N	\N
26575	MEMBRE	2015-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23350	\N	\N	\N
27050	MEMBRE	2016-09-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23748	\N	2016-09-08 10:20:36	\N
27052	MEMBRE	2016-09-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23750	\N	2016-09-19 10:25:40	2017-09-24 16:43:43
27066	MEMBRE	2016-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23758	\N	\N	\N
27152	MEMBRE	2016-12-20 00:00:00	2017-07-28 00:00:00	ANCIEN	\N	\N	\N	\N	23822	\N	2016-12-21 10:09:54	2017-08-03 11:38:41
27153	MEMBRE	2016-12-20 00:00:00	2017-07-28 00:00:00	ANCIEN	\N	\N	\N	\N	23823	\N	2016-12-21 10:09:54	2017-08-03 11:38:41
27154	MEMBRE	2016-12-20 00:00:00	2017-07-28 00:00:00	ANCIEN	\N	\N	\N	\N	23824	\N	2016-12-21 10:09:54	2017-08-03 11:38:41
25488	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22747	\N	\N	2017-09-24 13:57:40
25877	VICPDT	2015-02-23 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	21405	2	2015-02-23 11:39:31	2017-05-16 15:18:14
25878	VICPDT	2015-02-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21662	3	2015-02-23 11:39:36	2015-02-23 11:40:11
25879	VICPDT	2015-02-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22232	4	2015-02-23 11:39:42	2015-02-23 11:40:13
25880	VICPDT	2015-02-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21015	5	2015-02-23 11:39:46	2015-02-23 11:40:16
25881	SECRET	2015-02-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20875	6	2015-02-23 11:39:55	2015-02-23 11:40:18
25882	SECRET	2015-02-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22238	7	2015-02-23 11:40:00	2015-02-23 11:40:23
26113	MEMBRE	2014-09-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23104	\N	2015-03-06 14:17:16	\N
26114	MEMBRE	2014-09-01 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	23105	\N	2015-03-06 14:20:01	2017-06-19 16:06:51
26115	MEMBRE	2014-09-01 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	23106	\N	2015-03-06 14:22:26	2017-06-19 16:06:51
26116	MEMBRE	2014-09-01 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	23107	\N	2015-03-06 14:23:53	2017-06-19 16:06:51
26376	MEMBRE	2015-03-02 00:00:00	2015-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	23222	\N	\N	\N
26377	MEMBRE	2015-03-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	23223	\N	\N	\N
26379	MEMBRE	2015-03-02 00:00:00	2015-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	23225	\N	\N	\N
26381	MEMBRE	2015-03-02 00:00:00	2015-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	23227	\N	\N	\N
26449	MEMBRE	2014-10-01 00:00:00	2015-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	23265	\N	\N	\N
26451	MEMBRE	2014-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23267	\N	\N	2017-10-01 10:01:39
30341	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26185	\N	\N	\N
26509	MEMBRE	2015-05-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23284	\N	2015-06-04 09:36:25	2017-09-24 19:14:37
26634	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23383	\N	\N	\N
26909	MEMBRE	2016-05-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23615	\N	2016-05-18 09:41:45	2017-10-01 10:39:23
27127	MEMBRE	2016-11-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23818	\N	2016-12-01 09:58:05	2017-09-24 18:16:52
22712	MEMBRE	2014-10-14 00:00:00	2016-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20656	\N	2014-10-22 10:49:21	2017-01-03 11:09:24
22715	MEMBRE	2014-10-14 00:00:00	2016-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20659	\N	2014-10-22 10:49:21	2017-01-03 11:09:24
28683	MEMBRE	2017-11-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25250	\N	2017-11-14 14:45:07	\N
29305	MEMBRE	2017-12-19 00:00:00	2018-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	25678	\N	2017-12-20 12:15:34	2018-02-05 09:59:58
29306	VICPDT	2017-12-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24115	\N	2017-12-20 12:21:28	\N
29307	VICPDT	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25122	\N	2017-12-20 12:21:48	\N
29308	VICPDT	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24709	\N	2017-12-20 12:21:56	\N
29309	VICPDT	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25323	\N	2017-12-20 12:22:08	\N
29310	VICPDT	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23887	\N	2017-12-20 12:22:18	\N
29311	VICPDT	2017-12-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24731	\N	2017-12-20 12:22:28	\N
29312	SECRET	2017-12-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25290	\N	2017-12-20 12:22:44	\N
29313	SECRET	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25081	\N	2017-12-20 12:22:50	\N
29314	SECRET	2017-12-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25017	\N	2017-12-20 12:23:00	\N
29315	SECRET	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25535	\N	2017-12-20 12:23:08	\N
29357	MEMBRE	2017-12-20 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	25699	\N	2017-12-21 15:14:50	2018-01-18 18:09:35
29358	MEMBRE	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25700	\N	2017-12-21 15:15:00	\N
29359	MEMBRE	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25701	\N	2017-12-21 15:15:32	\N
29360	MEMBRE	2017-12-20 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	25702	\N	2017-12-21 15:15:33	2018-02-07 17:30:49
29361	MEMBRE	2017-12-20 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	25703	\N	2017-12-21 15:15:33	2018-01-25 15:53:55
29362	MEMBRE	2017-12-20 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	25704	\N	2017-12-21 15:15:48	2018-01-18 11:35:14
29363	MEMBRE	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25705	\N	2017-12-21 15:16:07	\N
29423	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25763	\N	\N	\N
29424	MEMBRE	2017-12-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25764	\N	\N	\N
29425	MEMBRE	2017-12-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	25765	\N	\N	\N
29455	MEMBRE	2017-12-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25782	\N	2018-01-05 11:32:27	\N
29488	MEMBRE	2018-01-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25814	\N	2018-01-15 16:07:11	\N
29489	MEMBRE	2017-12-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25815	\N	2018-01-15 16:21:36	\N
29490	MEMBRE	2018-01-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25816	\N	2018-01-15 16:43:38	\N
29499	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25825	\N	\N	\N
29786	VICPDT	2018-01-19 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	24499	\N	2018-01-19 10:24:17	\N
29787	VICPDT	2018-01-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24606	\N	2018-01-19 10:24:23	\N
29788	VICPDT	2018-01-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23914	\N	2018-01-19 10:24:32	\N
29789	VICPDT	2018-01-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24210	\N	2018-01-19 10:24:40	\N
29790	SECRET	2018-01-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24281	\N	2018-01-19 10:24:52	\N
29791	SECRET	2018-01-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25774	\N	2018-01-19 10:25:04	\N
29792	SECRET	2018-01-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23870	\N	2018-01-19 10:25:08	\N
29793	SECRET	2018-01-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25106	\N	2018-01-19 10:25:11	\N
29794	SECRET	2018-01-19 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25668	\N	2018-01-19 10:25:16	\N
29798	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25970	\N	\N	\N
29832	PDT	2018-01-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	25728	\N	\N	\N
29833	VICPDT	2018-01-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	25813	\N	\N	\N
29834	VICPDT	2018-01-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	25731	\N	\N	\N
29835	VICPDT	2018-01-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	25802	\N	\N	\N
29921	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26003	\N	\N	\N
29922	MEMBRE	2017-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26004	\N	\N	\N
29937	VICPDT	2018-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	26016	\N	\N	\N
29942	MEMBRE	2017-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26020	\N	\N	\N
29954	MEMBRE	2017-12-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26028	\N	\N	\N
30055	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26050	\N	\N	\N
30219	MEMBRE	2017-10-01 00:00:00	2018-05-07 00:00:00	ANCIEN	\N	\N	\N	\N	26133	\N	\N	\N
30220	MEMBRE	2017-10-01 00:00:00	2018-05-07 00:00:00	ANCIEN	\N	\N	\N	\N	26134	\N	\N	\N
30261	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26156	\N	\N	\N
30302	VICPDT	2018-01-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	25873	\N	\N	\N
30315	MEMBRE	2018-01-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26161	\N	2018-01-30 19:43:06	\N
30316	MEMBRE	2018-01-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26162	\N	2018-01-31 09:50:23	\N
30317	VICPDT	2018-01-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25273	\N	2018-01-31 10:03:08	\N
30318	VICPDT	2018-01-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25496	\N	2018-01-31 10:03:12	\N
30319	MEMBRE	2017-10-01 00:00:00	2018-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	26163	\N	\N	\N
30320	MEMBRE	2017-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26164	\N	\N	\N
30321	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26165	\N	\N	\N
30322	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26166	\N	\N	\N
30323	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26167	\N	\N	\N
30324	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26168	\N	\N	\N
30325	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26169	\N	\N	\N
30326	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26170	\N	\N	\N
30327	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26171	\N	\N	\N
30328	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26172	\N	\N	\N
30329	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26173	\N	\N	\N
30330	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26174	\N	\N	\N
30331	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26175	\N	\N	\N
30332	MEMBRE	2017-10-01 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	26176	\N	\N	\N
30333	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26177	\N	\N	\N
30334	MEMBRE	2018-01-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26178	\N	2018-01-31 12:21:35	\N
30335	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26179	\N	\N	\N
30336	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26180	\N	\N	\N
30337	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26181	\N	\N	\N
30338	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26182	\N	\N	\N
30342	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26186	\N	\N	\N
30343	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26187	\N	\N	\N
30344	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26188	\N	\N	\N
30345	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26189	\N	\N	\N
30346	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26190	\N	\N	\N
30347	MEMBRE	2017-10-01 00:00:00	2018-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	26191	\N	\N	2018-04-13 17:54:29
30348	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26192	\N	\N	\N
30349	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26193	\N	\N	\N
30350	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26194	\N	\N	\N
30351	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26195	\N	\N	\N
30352	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26196	\N	\N	\N
30353	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26197	\N	\N	\N
30354	MEMBRE	2017-10-01 00:00:00	2018-05-07 00:00:00	ANCIEN	\N	\N	\N	\N	26198	\N	\N	\N
30355	SECRET	2018-01-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25349	\N	2018-01-31 16:17:26	\N
30356	VICPDT	2018-01-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24672	\N	2018-01-31 16:17:30	\N
30357	VICPDT	2018-01-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24177	\N	2018-01-31 16:17:41	\N
30358	MEMBRE	2018-01-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26199	\N	2018-01-31 16:53:03	\N
30359	MEMBRE	2018-01-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26200	\N	2018-01-31 17:00:47	\N
30360	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26201	\N	\N	\N
30361	MEMBRE	2018-01-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26202	\N	2018-01-31 18:18:43	\N
30362	MEMBRE	2018-01-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26203	\N	2018-01-31 18:18:43	\N
30363	MEMBRE	2018-01-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26204	\N	2018-01-31 18:18:43	\N
22652	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20596	\N	2014-10-21 12:51:34	\N
22258	MEMBRE	2013-11-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20206	\N	\N	2013-11-14 09:45:17
22343	MEMBRE	2014-09-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20287	\N	2014-09-09 09:53:44	\N
22653	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20597	\N	2014-10-21 12:51:34	\N
23360	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21271	\N	2014-10-28 15:02:31	\N
23361	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21272	\N	2014-10-28 15:02:31	\N
23362	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21273	\N	2014-10-28 15:02:31	\N
23363	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21274	\N	2014-10-28 15:02:31	\N
23639	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21550	\N	2014-10-30 09:17:31	\N
23640	MEMBRE	2014-10-29 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	21551	\N	2014-10-30 09:17:45	2015-02-13 14:23:52
23641	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21552	\N	2014-10-30 09:17:45	\N
24388	MEMBRE	2014-11-27 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22295	\N	2014-12-02 09:20:56	\N
24389	MEMBRE	2014-11-27 00:00:00	2015-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	22296	\N	2014-12-02 09:20:56	2015-01-14 14:23:49
24883	PDTDEL	2015-02-02 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour le Kirghizistan	\N	22452	3	2015-02-02 14:25:21	2015-02-16 17:40:25
24884	SECRET	2015-02-02 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	21870	9	2015-02-02 14:59:17	2016-03-11 18:02:51
25490	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22749	\N	\N	\N
25493	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22752	\N	\N	\N
25500	MEMBRE	2014-10-01 00:00:00	2016-04-05 00:00:00	ANCIEN	\N	\N	\N	\N	22759	\N	\N	\N
25501	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22760	\N	\N	\N
25502	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22761	\N	\N	\N
25503	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22762	\N	\N	\N
25504	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22763	\N	\N	2017-09-24 18:16:52
25505	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22764	\N	\N	2017-09-24 13:57:40
25506	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22765	\N	\N	\N
25507	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22766	\N	\N	\N
25508	MEMBRE	2014-10-01 00:00:00	2015-05-01 00:00:00	ANCIEN	\N	\N	\N	\N	22767	\N	\N	\N
25509	MEMBRE	2014-10-01 00:00:00	2015-05-01 00:00:00	ANCIEN	\N	\N	\N	\N	22768	\N	\N	\N
25510	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22769	\N	\N	\N
25511	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22770	\N	\N	\N
25512	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22771	\N	\N	2017-09-24 13:44:49
25513	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22772	\N	\N	\N
25514	MEMBRE	2014-10-01 00:00:00	2015-05-18 00:00:00	ANCIEN	\N	\N	\N	\N	22773	\N	\N	\N
25515	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22774	\N	\N	\N
25594	MEMBRE	2015-01-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22826	\N	\N	2017-09-24 13:25:54
26119	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23110	\N	\N	\N
26311	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23189	\N	\N	\N
26408	MEMBRE	2015-04-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23247	\N	2015-04-27 11:38:23	\N
26409	MEMBRE	2015-04-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23248	\N	2015-04-27 11:38:23	\N
26515	MEMBRE	2014-10-01 00:00:00	2017-06-04 00:00:00	ANCIEN	\N	\N	\N	\N	23290	\N	\N	2017-06-07 09:38:00
26560	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23335	\N	\N	\N
26567	MEMBRE	2015-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23342	\N	\N	\N
26577	MEMBRE	2015-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23352	\N	\N	\N
26578	MEMBRE	2015-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23353	\N	\N	\N
26579	MEMBRE	2015-01-01 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	23354	\N	\N	2016-12-12 16:10:15
26580	MEMBRE	2015-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23355	\N	\N	\N
26581	MEMBRE	2015-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23356	\N	\N	\N
26582	MEMBRE	2015-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23357	\N	\N	\N
26584	MEMBRE	2015-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23359	\N	\N	\N
26585	MEMBRE	2015-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23360	\N	\N	\N
26586	MEMBRE	2015-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23361	\N	\N	\N
26588	MEMBRE	2015-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23363	\N	\N	\N
26589	MEMBRE	2015-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23364	\N	\N	\N
26591	MEMBRE	2015-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23366	\N	\N	\N
26592	MEMBRE	2015-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23367	\N	\N	\N
26593	MEMBRE	2015-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23368	\N	\N	\N
26594	MEMBRE	2015-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23369	\N	\N	\N
26595	MEMBRE	2015-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23370	\N	\N	\N
26631	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23380	\N	\N	\N
26683	MEMBRE	2014-10-01 00:00:00	2015-09-06 00:00:00	ANCIEN	\N	\N	\N	\N	23416	\N	\N	\N
26696	MEMBRE	2015-11-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23425	\N	2015-11-18 11:06:26	\N
26697	MEMBRE	2015-11-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23426	\N	2015-11-18 11:06:52	\N
26698	MEMBRE	2015-11-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23427	\N	2015-11-18 18:11:57	2017-09-24 17:47:28
26699	MEMBRE	2015-11-10 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23428	\N	2015-11-18 18:12:20	2017-10-01 09:22:38
26761	MEMBRE	2016-02-12 00:00:00	2017-10-30 00:00:00	ANCIEN	\N	\N	\N	\N	23479	\N	2016-02-12 12:23:23	2017-10-31 17:30:33
26762	MEMBRE	2016-02-12 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	23480	\N	2016-02-12 12:23:31	\N
26763	MEMBRE	2016-02-12 00:00:00	2020-10-19 00:00:00	ANCIEN	\N	\N	\N	\N	23481	\N	2016-02-12 12:23:38	\N
26764	MEMBRE	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	23482	\N	2016-02-12 12:23:41	\N
26765	MEMBRE	2016-02-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23483	\N	2016-02-12 12:24:29	2017-09-24 19:25:10
26766	MEMBRE	2016-02-12 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23484	\N	2016-02-12 12:24:32	\N
26767	MEMBRE	2016-02-12 00:00:00	2023-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	23485	\N	2016-02-12 12:24:58	\N
26768	MEMBRE	2016-02-12 00:00:00	2020-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	23486	\N	2016-02-12 12:25:01	\N
26769	MEMBRE	2016-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23487	\N	2016-02-12 12:25:04	2017-10-01 09:41:22
26770	MEMBRE	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	23488	\N	2016-02-12 12:25:11	\N
26771	MEMBRE	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	23489	\N	2016-02-12 12:25:14	\N
26772	VICPDT	2016-02-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23490	\N	2016-02-12 12:25:18	2017-09-24 17:19:42
26773	MEMBRE	2016-02-12 00:00:00	2017-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	23491	\N	2016-02-12 12:25:24	2017-10-17 11:10:05
26774	MEMBRE	2016-02-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23492	\N	2016-02-12 12:25:27	2017-09-24 17:28:55
26775	MEMBRE	2016-02-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23493	\N	2016-02-12 12:25:30	2017-09-24 18:17:56
26776	MEMBRE	2016-02-12 00:00:00	2020-10-19 00:00:00	ANCIEN	\N	\N	\N	\N	23494	\N	2016-02-12 12:25:36	\N
26777	MEMBRE	2016-02-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23495	\N	2016-02-12 12:25:44	2017-09-24 18:59:59
26778	MEMBRE	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	23496	\N	2016-02-12 12:25:52	\N
26779	MEMBRE	2016-02-12 00:00:00	2023-04-11 00:00:00	ANCIEN	\N	\N	\N	\N	23497	\N	2016-02-12 12:25:58	\N
26780	MEMBRE	2016-02-12 00:00:00	2023-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	23498	\N	2016-02-12 12:26:06	\N
26781	MEMBRE	2016-02-12 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	23499	\N	2016-02-12 12:26:09	2017-09-25 09:57:52
26782	MEMBRE	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	23500	\N	2016-02-12 12:26:14	\N
26783	MEMBRE	2016-02-12 00:00:00	2023-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	23501	\N	2016-02-12 12:26:17	\N
26785	MEMBRE	2016-02-12 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	23503	\N	2016-02-12 12:28:40	\N
26786	MEMBRE	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	23504	\N	2016-02-12 12:28:57	\N
26787	MEMBRE	2016-02-12 00:00:00	2020-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	23505	\N	2016-02-12 12:29:04	\N
26788	MEMBRE	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	23506	\N	2016-02-12 12:29:28	\N
26789	VICPDT	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	23507	\N	2016-02-12 12:31:00	2016-02-12 13:02:04
26790	MEMBRE	2016-02-12 00:00:00	2020-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	23508	\N	2016-02-12 12:31:10	\N
26791	MEMBRE	2016-02-12 00:00:00	2016-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	23509	\N	2016-02-12 12:31:23	2016-12-01 10:36:51
26792	MEMBRE	2016-02-12 00:00:00	2017-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	23510	\N	2016-02-12 12:31:30	2017-09-24 11:09:53
26793	MEMBRE	2016-02-12 00:00:00	2020-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	23511	\N	2016-02-12 12:31:36	\N
26794	MEMBRE	2016-02-12 00:00:00	2023-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	23512	\N	2016-02-12 12:31:41	\N
26795	MEMBRE	2016-02-12 00:00:00	2020-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	23513	\N	2016-02-12 12:31:47	\N
26796	MEMBRE	2016-02-12 00:00:00	2020-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	23514	\N	2016-02-12 12:31:54	\N
26797	MEMBRE	2016-02-12 00:00:00	2020-10-16 00:00:00	ANCIEN	\N	\N	\N	\N	23515	\N	2016-02-12 12:32:01	\N
26798	MEMBRE	2016-02-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23516	\N	2016-02-12 12:32:09	2017-09-24 19:25:10
26799	MEMBRE	2016-02-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23517	\N	2016-02-12 12:32:14	2017-09-24 18:59:59
26800	VICPDT	2016-02-12 00:00:00	2020-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	23518	\N	2016-02-12 12:32:21	2016-02-12 12:45:19
26801	MEMBRE	2016-02-12 00:00:00	2019-06-24 00:00:00	ANCIEN	\N	\N	\N	\N	23519	\N	2016-02-12 12:32:30	\N
26802	MEMBRE	2016-02-12 00:00:00	2020-10-19 00:00:00	ANCIEN	\N	\N	\N	\N	23520	\N	2016-02-12 12:32:35	\N
26803	VICPDT	2016-02-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23521	\N	2016-02-12 12:32:42	2017-09-24 17:47:27
26804	MEMBRE	2016-02-12 00:00:00	2020-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	23522	\N	2016-02-12 12:32:48	\N
26805	MEMBRE	2016-02-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23523	\N	2016-02-12 12:32:58	2017-09-24 16:45:26
26806	MEMBRE	2016-02-12 00:00:00	2020-10-19 00:00:00	ANCIEN	\N	\N	\N	\N	23524	\N	2016-02-12 12:33:05	\N
26807	MEMBRE	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	23525	\N	2016-02-12 12:33:12	\N
26808	MEMBRE	2016-02-12 00:00:00	2023-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	23526	\N	2016-02-12 12:33:20	\N
26809	MEMBRE	2016-02-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23527	\N	2016-02-12 12:33:27	2017-09-24 18:17:56
26810	MEMBRE	2016-02-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23528	\N	2016-02-12 12:33:37	2017-09-24 18:16:52
26812	MEMBRE	2016-02-12 00:00:00	2020-10-19 00:00:00	ANCIEN	\N	\N	\N	\N	23530	\N	2016-02-12 12:34:20	\N
26813	MEMBRE	2016-02-12 00:00:00	2017-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	23531	\N	2016-02-12 12:34:26	2017-07-24 09:58:00
26814	MEMBRE	2016-02-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23532	\N	2016-02-12 12:34:32	2017-09-24 17:48:21
26815	MEMBRE	2016-02-12 00:00:00	2023-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	23533	\N	2016-02-12 12:34:38	\N
26816	MEMBRE	2016-02-12 00:00:00	2020-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	23534	\N	2016-02-12 12:34:44	\N
26817	MEMBRE	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	23535	\N	2016-02-12 12:34:55	\N
25473	MEMBRE	2014-10-01 00:00:00	2015-04-15 00:00:00	ANCIEN	\N	\N	\N	\N	22732	\N	\N	\N
25516	MEMBRE	2014-10-01 00:00:00	2017-07-28 00:00:00	ANCIEN	\N	\N	\N	\N	22775	\N	\N	2017-08-03 11:38:41
25517	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22776	\N	\N	\N
25518	MEMBRE	2014-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22777	\N	\N	2017-10-01 09:41:22
25519	MEMBRE	2014-10-01 00:00:00	2017-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	22778	\N	\N	2017-07-24 09:58:00
25521	MEMBRE	2014-10-01 00:00:00	2015-05-01 00:00:00	ANCIEN	\N	\N	\N	\N	22780	\N	\N	\N
25522	MEMBRE	2014-10-01 00:00:00	2014-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	22781	\N	\N	\N
25523	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22782	\N	\N	\N
25524	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22783	\N	\N	\N
25525	MEMBRE	2014-10-01 00:00:00	2014-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	22784	\N	\N	\N
25526	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22785	\N	\N	2017-09-24 17:04:02
25527	MEMBRE	2014-10-01 00:00:00	2014-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	22786	\N	\N	\N
25529	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22788	\N	\N	\N
25530	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22789	\N	\N	\N
25531	MEMBRE	2014-10-01 00:00:00	2014-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	22790	\N	\N	\N
25532	MEMBRE	2014-10-01 00:00:00	2014-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	22791	\N	\N	\N
25533	MEMBRE	2014-10-01 00:00:00	2014-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	22792	\N	\N	\N
25534	MEMBRE	2014-10-01 00:00:00	2017-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	22793	\N	\N	2017-09-24 11:09:53
25536	MEMBRE	2014-10-01 00:00:00	2014-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	22795	\N	\N	\N
25537	MEMBRE	2014-10-01 00:00:00	2014-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	22796	\N	\N	\N
25538	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22797	\N	\N	\N
25539	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22798	\N	\N	\N
25540	MEMBRE	2014-10-01 00:00:00	2014-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	22799	\N	\N	\N
25541	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22800	\N	\N	\N
25542	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22801	\N	\N	\N
25543	MEMBRE	2014-10-01 00:00:00	2014-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	22802	\N	\N	\N
25544	MEMBRE	2014-10-01 00:00:00	2014-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	22803	\N	\N	\N
25545	MEMBRE	2014-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22804	\N	\N	2017-10-01 09:41:22
25546	MEMBRE	2014-10-01 00:00:00	2017-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	22805	\N	\N	2017-07-24 09:58:00
25547	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22806	\N	\N	\N
25548	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22807	\N	\N	\N
25549	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22808	\N	\N	\N
25550	MEMBRE	2014-10-01 00:00:00	2014-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	22809	\N	\N	\N
25551	MEMBRE	2014-10-01 00:00:00	2014-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	22810	\N	\N	\N
25552	MEMBRE	2014-10-01 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	22811	\N	\N	2015-06-12 16:01:25
25556	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22815	\N	\N	\N
25927	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22986	\N	\N	\N
25933	MEMBRE	2014-10-01 00:00:00	2016-01-11 00:00:00	ANCIEN	\N	\N	\N	\N	22992	\N	\N	2016-01-11 17:34:09
26067	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23089	\N	\N	\N
26068	MEMBRE	2014-10-01 00:00:00	2015-03-24 00:00:00	ANCIEN	\N	\N	\N	\N	23090	\N	\N	\N
26069	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23091	\N	\N	\N
26070	MEMBRE	2014-10-01 00:00:00	2015-03-24 00:00:00	ANCIEN	\N	\N	\N	\N	23092	\N	\N	\N
26071	MEMBRE	2014-10-01 00:00:00	2015-03-24 00:00:00	ANCIEN	\N	\N	\N	\N	23093	\N	\N	\N
26072	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23094	\N	\N	\N
26073	MEMBRE	2014-10-01 00:00:00	2015-03-24 00:00:00	ANCIEN	\N	\N	\N	\N	23095	\N	\N	\N
26127	MEMBRE	2015-03-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23112	\N	2015-03-09 15:28:08	\N
26441	MEMBRE	2014-10-01 00:00:00	2014-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23257	\N	\N	\N
26472	PDT	2015-05-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20998	1	2015-05-26 11:54:43	2015-05-26 11:55:49
26473	PDT	2015-05-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22152	1	2015-05-26 11:57:04	2017-09-24 17:47:27
26474	MEMBRE	2015-05-26 00:00:00	2017-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	21010	\N	2015-05-26 11:57:55	2017-07-20 14:38:49
26475	PDT	2015-05-26 00:00:00	2017-07-16 00:00:00	ANCIEN	\N	\N	\N	\N	20339	1	2015-05-26 11:57:59	2017-07-17 11:46:37
26476	MEMBRE	2015-05-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23277	\N	2015-05-26 15:13:43	\N
26490	SECRET	2015-05-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	22602	\N	\N	\N
27513	MEMBRE	2017-10-12 00:00:00	2017-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	24080	\N	2017-10-12 18:26:55	2017-11-28 17:00:58
27514	MEMBRE	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24081	\N	2017-10-12 18:26:55	\N
28900	MEMBRE	2017-11-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25467	\N	2017-11-27 15:36:29	\N
28901	PDT	2017-11-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24182	\N	2017-11-27 16:36:56	\N
28902	PDT	2017-11-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24967	\N	2017-11-27 16:37:53	\N
28903	PDTDEL	2017-11-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Koweït	\N	25426	\N	2017-11-27 16:39:24	2017-11-27 16:40:09
29154	MEMBRE	2017-12-04 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	25601	\N	2017-12-11 09:41:30	2018-01-23 16:58:20
29155	MEMBRE	2017-12-04 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25602	\N	2017-12-11 09:41:30	\N
29156	MEMBRE	2017-12-04 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25603	\N	2017-12-11 09:41:30	\N
29157	MEMBRE	2017-12-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25604	\N	2017-12-11 09:42:00	\N
29158	MEMBRE	2017-12-08 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	25605	\N	2017-12-11 09:42:00	2018-01-25 15:54:08
29159	MEMBRE	2017-12-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25606	\N	2017-12-11 09:42:00	\N
29160	MEMBRE	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25607	\N	2017-12-11 09:42:19	\N
29161	MEMBRE	2017-11-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25608	\N	2017-12-11 09:48:57	\N
29235	MEMBRE	2017-12-12 00:00:00	2018-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	25636	\N	2017-12-15 14:53:59	2018-02-12 16:56:26
29448	MEMBRE	2018-01-05 00:00:00	2023-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	25780	\N	2018-01-05 11:27:37	\N
29237	PDTDEL	2017-12-15 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	Niger	\N	25638	\N	2017-12-15 15:38:08	2017-12-15 15:42:31
29238	MEMBRE	2017-12-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25639	\N	2017-12-15 16:07:16	\N
29239	MEMBRE	2017-12-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25640	\N	2017-12-15 16:07:16	\N
29240	MEMBRE	2017-12-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25641	\N	2017-12-15 16:07:16	\N
29241	MEMBRE	2017-12-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25642	\N	2017-12-15 16:07:35	\N
29242	MEMBRE	2017-12-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25643	\N	2017-12-15 16:08:16	\N
29243	MEMBRE	2017-12-06 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	25644	\N	2017-12-15 16:08:37	2018-01-24 10:52:33
29249	PDT	2017-12-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25649	\N	2017-12-18 11:50:54	2017-12-18 11:51:19
29449	VICPDT	2018-01-05 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	23548	\N	2018-01-05 11:28:46	\N
29450	VICPDT	2018-01-05 00:00:00	2020-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	23469	\N	2018-01-05 11:29:19	\N
29451	VICPDT	2018-01-05 00:00:00	2020-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	23457	\N	2018-01-05 11:29:31	\N
29452	VICPDT	2018-01-05 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	25244	\N	2018-01-05 11:29:47	\N
29453	MEMBRE	2017-12-12 00:00:00	2018-01-04 00:00:00	ANCIEN	\N	\N	\N	\N	25781	\N	2018-01-05 11:31:16	2018-01-05 11:31:42
29454	VICPDT	2018-01-05 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	25781	\N	2018-01-05 11:31:42	\N
29458	MEMBRE	2018-01-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25785	\N	2018-01-09 11:35:03	\N
29483	MEMBRE	2018-01-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25809	\N	2018-01-15 11:23:13	\N
29484	MEMBRE	2018-01-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25810	\N	2018-01-15 11:23:13	\N
29485	MEMBRE	2018-01-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25811	\N	2018-01-15 11:23:13	\N
29491	MEMBRE	2017-11-22 00:00:00	2018-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	25817	\N	2018-01-16 10:07:39	2018-01-30 16:00:31
29492	MEMBRE	2017-11-22 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	25818	\N	2018-01-16 10:07:39	2018-01-18 16:37:17
29497	MEMBRE	2017-12-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	25823	\N	\N	\N
29697	MEMBRE	2018-01-17 00:00:00	2018-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	25951	\N	2018-01-17 18:53:19	2018-02-14 12:55:10
29730	VICPDT	2018-01-18 00:00:00	2019-08-27 00:00:00	ANCIEN	\N	\N	\N	\N	23964	\N	2018-01-18 16:36:44	\N
29731	SECRET	2018-01-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24733	\N	2018-01-18 16:36:58	\N
29732	SECRET	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23896	\N	2018-01-18 16:37:03	\N
29733	VICPDT	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25818	\N	2018-01-18 16:37:17	\N
29734	VICPDT	2018-01-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24462	\N	2018-01-18 16:37:25	\N
29735	VICPDT	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25423	\N	2018-01-18 16:40:29	\N
29736	VICPDT	2018-01-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24098	\N	2018-01-18 16:40:37	\N
29737	VICPDT	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24563	\N	2018-01-18 16:40:47	\N
29738	VICPDT	2018-01-18 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	24509	\N	2018-01-18 16:40:53	\N
29739	VICPDT	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24930	\N	2018-01-18 16:41:01	\N
29740	VICPDT	2018-01-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25211	\N	2018-01-18 16:41:10	\N
29741	VICPDT	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24171	\N	2018-01-18 16:41:16	\N
29742	SECRET	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23878	\N	2018-01-18 16:41:26	\N
29743	SECRET	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25331	\N	2018-01-18 16:41:30	\N
29744	SECRET	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25568	\N	2018-01-18 16:41:38	\N
29745	SECRET	2018-01-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23980	\N	2018-01-18 16:41:49	\N
29746	SECRET	2018-01-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25294	\N	2018-01-18 16:41:53	\N
29747	MEMBRE	2018-01-18 00:00:00	2020-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	25963	\N	2018-01-18 16:48:45	\N
29750	VICPDT	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25157	\N	2018-01-18 17:49:29	\N
29751	VICPDT	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24221	\N	2018-01-18 17:49:37	\N
29752	VICPDT	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24425	\N	2018-01-18 17:49:51	\N
29753	VICPDT	2018-01-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24802	\N	2018-01-18 17:50:02	\N
29754	VICPDT	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25457	\N	2018-01-18 17:50:06	\N
29755	VICPDT	2018-01-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24461	\N	2018-01-18 17:50:34	\N
29756	VICPDT	2018-01-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24066	\N	2018-01-18 17:50:43	\N
22319	PDT	2014-05-21 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20263	\N	\N	2014-09-28 19:29:39
22327	MEMBRE	2014-06-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20271	\N	2014-07-04 15:04:01	\N
22318	MEMBRE	2014-05-21 00:00:00	2014-05-21 00:00:00	ANCIEN	\N	\N	\N	\N	20263	\N	\N	\N
24002	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21913	\N	2014-10-31 12:46:20	\N
24003	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21914	\N	2014-10-31 12:46:20	\N
24004	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21915	\N	2014-10-31 12:46:20	\N
24652	MEMBRE	2015-01-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22402	\N	2015-01-19 11:29:08	\N
24711	MEMBRE	2015-01-20 00:00:00	2015-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	22432	\N	2015-01-22 16:16:13	2015-01-30 15:15:03
24746	MEMBRE	2015-01-26 00:00:00	2015-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	22451	\N	2015-01-26 14:38:42	2015-03-19 09:57:44
24757	MEMBRE	2015-01-26 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22462	\N	2015-01-27 16:18:48	\N
24758	MEMBRE	2015-01-26 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	22463	\N	2015-01-27 16:18:48	2015-02-11 16:40:33
24759	VICPDT	2015-01-27 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	20407	2	2015-01-27 16:27:11	2015-06-12 16:01:25
24760	VICPDT	2015-01-27 00:00:00	2017-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	21007	3	2015-01-27 16:27:27	2017-07-20 11:43:24
24761	MEMBRE	2015-01-27 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	21822	\N	2015-01-27 16:28:07	2015-02-02 13:08:48
24762	VICPDT	2015-01-27 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	21822	4	2015-01-27 16:28:39	2016-12-12 16:10:15
24766	MEMBRE	2015-01-27 00:00:00	2015-04-21 00:00:00	ANCIEN	\N	\N	\N	\N	22464	\N	2015-01-27 16:49:39	2015-04-21 17:14:30
24764	SECRET	2015-01-27 00:00:00	2017-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	21961	5	2015-01-27 16:30:57	2017-07-20 11:43:35
24765	SECRET	2015-01-27 00:00:00	2017-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	20326	6	2015-01-27 16:32:25	2017-07-20 11:43:29
24790	VICPDT	2015-01-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21341	2	2015-01-28 10:25:46	2015-01-28 10:27:10
24791	VICPDT	2015-01-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21130	3	2015-01-28 10:25:55	2015-01-28 10:27:19
24793	VICPDT	2015-01-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20666	4	2015-01-28 10:26:02	2015-01-28 10:27:23
24794	VICPDT	2015-01-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21905	5	2015-01-28 10:26:13	2015-01-28 10:27:30
24795	VICPDT	2015-01-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21029	6	2015-01-28 10:26:20	2015-01-28 10:27:34
24796	SECRET	2015-01-28 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	21837	8	2015-01-28 10:26:26	2016-12-12 16:10:15
24797	SECRET	2015-01-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22351	7	2015-01-28 10:26:31	2015-01-30 16:26:29
24799	SECRET	2015-01-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21940	9	2015-01-28 10:26:42	2015-01-28 10:27:45
24934	MEMBRE	2015-02-03 00:00:00	2015-03-09 00:00:00	ANCIEN	\N	\N	\N	\N	22507	\N	2015-02-03 18:04:24	2015-03-10 17:25:32
25141	MEMBRE	2015-02-10 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22535	\N	2015-02-11 16:41:16	\N
25492	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22751	\N	\N	\N
25520	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22779	\N	\N	\N
25572	MEMBRE	2015-02-16 00:00:00	2015-03-08 00:00:00	ANCIEN	\N	\N	\N	\N	20532	\N	2015-02-16 17:37:55	2015-03-09 14:10:54
25573	MEMBRE	2015-02-16 00:00:00	2015-03-08 00:00:00	ANCIEN	\N	\N	\N	\N	22164	\N	2015-02-16 17:37:59	2015-03-09 14:11:12
25574	MEMBRE	2015-02-16 00:00:00	2015-03-08 00:00:00	ANCIEN	\N	\N	\N	\N	21815	\N	2015-02-16 17:38:04	2015-03-09 14:11:08
25575	MEMBRE	2015-02-16 00:00:00	2015-03-08 00:00:00	ANCIEN	\N	\N	\N	\N	20657	\N	2015-02-16 17:38:08	2015-03-09 14:11:16
25576	MEMBRE	2015-02-16 00:00:00	2015-03-08 00:00:00	ANCIEN	\N	\N	\N	\N	21254	\N	2015-02-16 17:38:12	2015-03-09 14:11:20
25577	MEMBRE	2015-02-16 00:00:00	2015-03-08 00:00:00	ANCIEN	\N	\N	\N	\N	21617	\N	2015-02-16 17:38:18	2015-03-09 14:11:25
25581	VICPDT	2015-02-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21931	7	2015-02-16 17:41:35	2015-02-16 17:42:58
25582	VICPDT	2015-02-16 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20448	8	2015-02-16 17:41:49	2015-11-12 15:26:22
25583	VICPDT	2015-02-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20424	9	2015-02-16 17:41:55	2015-02-16 17:43:03
25584	VICPDT	2015-02-16 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	21879	10	2015-02-16 17:42:03	2016-03-11 18:02:51
25585	VICPDT	2015-02-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21280	11	2015-02-16 17:42:09	2015-02-16 17:43:12
25586	VICPDT	2015-02-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21919	12	2015-02-16 17:42:17	2015-02-16 17:43:17
25587	SECRET	2015-02-16 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20673	13	2015-02-16 17:42:30	2017-04-27 16:00:50
25588	SECRET	2015-02-16 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	21845	14	2015-02-16 17:42:35	2016-12-12 16:10:15
25589	SECRET	2015-02-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21925	15	2015-02-16 17:42:42	2015-02-16 17:43:27
25590	SECRET	2015-02-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20977	16	2015-02-16 17:42:47	2015-02-16 17:43:30
25591	MEMBRE	2015-02-04 00:00:00	2017-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	22823	\N	2015-02-16 17:50:20	2017-07-20 14:38:34
25592	MEMBRE	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22824	\N	2015-02-16 17:50:31	\N
25593	MEMBRE	2015-01-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22825	\N	2015-02-16 17:50:40	\N
25610	MEMBRE	2014-10-01 00:00:00	2015-05-28 00:00:00	ANCIEN	\N	\N	\N	\N	22829	\N	\N	\N
25611	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22830	\N	\N	2017-09-24 13:25:54
26224	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23167	\N	\N	\N
26225	MEMBRE	2015-03-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23168	\N	2015-03-18 11:29:36	\N
26343	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23205	\N	\N	2017-09-24 18:20:10
26354	VICPDT	2015-04-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	22882	\N	\N	\N
26355	VICPDT	2015-04-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	22725	\N	\N	\N
26357	SECRET	2015-04-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	22716	\N	\N	\N
26358	SECRET	2015-04-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	22717	\N	\N	\N
26359	VICPDT	2015-04-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	22724	\N	\N	\N
26360	VICPDT	2015-04-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22732	\N	\N	2017-09-24 18:16:52
26361	VICPDT	2015-04-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	23147	\N	\N	\N
26370	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23216	\N	\N	\N
26419	PDT	2015-05-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22684	\N	\N	2017-09-24 13:44:49
26420	VICPDT	2015-05-06 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	22695	\N	\N	2015-06-12 15:59:18
26423	VICPDT	2015-05-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23181	\N	\N	2017-09-24 16:45:26
26424	VICPDT	2015-05-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	22707	\N	\N	\N
26426	VICPDT	2015-05-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	22708	\N	\N	\N
26442	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23258	\N	\N	2017-09-24 17:06:55
26468	MEMBRE	2014-10-01 00:00:00	2015-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	23273	\N	\N	\N
26576	MEMBRE	2015-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23351	\N	\N	\N
26583	MEMBRE	2015-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23358	\N	\N	\N
26590	MEMBRE	2015-01-01 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	23365	\N	\N	2017-06-19 12:20:59
27182	MEMBRE	2017-02-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23849	\N	2017-02-23 13:00:54	\N
28328	MEMBRE	2017-10-31 00:00:00	2018-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	24895	\N	2017-10-31 17:06:36	2018-03-06 12:08:47
28329	MEMBRE	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24896	\N	2017-10-31 17:06:36	\N
28330	MEMBRE	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24897	\N	2017-10-31 17:18:21	\N
28331	MEMBRE	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24898	\N	2017-10-31 17:18:21	\N
28332	MEMBRE	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24899	\N	2017-10-31 17:18:21	\N
28333	MEMBRE	2017-10-30 00:00:00	2018-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	24900	\N	2017-10-31 17:18:21	2018-01-16 19:08:57
28334	MEMBRE	2017-10-30 00:00:00	2017-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	24901	\N	2017-10-31 17:18:21	2017-11-30 16:41:31
28335	MEMBRE	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24902	\N	2017-10-31 17:18:21	\N
28336	MEMBRE	2017-10-30 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	24903	\N	2017-10-31 17:18:21	2018-02-07 17:30:42
28337	MEMBRE	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24904	\N	2017-10-31 17:18:21	\N
28338	MEMBRE	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24905	\N	2017-10-31 17:18:21	\N
28339	MEMBRE	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24906	\N	2017-10-31 17:18:21	\N
28340	MEMBRE	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24907	\N	2017-10-31 17:18:21	\N
28341	MEMBRE	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24908	\N	2017-10-31 17:18:21	\N
28342	MEMBRE	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24909	\N	2017-10-31 17:18:21	\N
28343	MEMBRE	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24910	\N	2017-10-31 17:18:21	\N
28344	MEMBRE	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24911	\N	2017-10-31 17:18:21	\N
28345	MEMBRE	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24912	\N	2017-10-31 17:18:21	\N
28346	MEMBRE	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24913	\N	2017-10-31 17:18:21	\N
28347	MEMBRE	2017-10-30 00:00:00	2017-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	24914	\N	2017-10-31 17:18:21	2017-11-30 16:17:20
28348	MEMBRE	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24915	\N	2017-10-31 17:18:21	\N
28349	MEMBRE	2017-10-30 00:00:00	2018-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	24916	\N	2017-10-31 17:18:21	2018-02-08 16:43:41
28350	MEMBRE	2017-10-30 00:00:00	2018-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	24917	\N	2017-10-31 17:18:21	2018-02-06 16:27:58
28351	MEMBRE	2017-10-30 00:00:00	2018-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	24918	\N	2017-10-31 17:18:21	2018-02-01 18:30:58
28352	MEMBRE	2017-10-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24919	\N	2017-10-31 17:24:27	\N
28353	MEMBRE	2017-10-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24920	\N	2017-10-31 17:24:27	\N
28354	MEMBRE	2017-10-27 00:00:00	2018-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	24921	\N	2017-10-31 17:24:27	2018-02-12 09:31:39
25486	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22745	\N	\N	\N
25528	MEMBRE	2014-10-01 00:00:00	2014-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	22787	\N	\N	\N
25535	MEMBRE	2014-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22794	\N	\N	2017-10-01 09:22:38
25555	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22814	\N	\N	\N
26446	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23262	\N	\N	2017-09-24 17:06:55
26460	VICPDT	2015-05-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	23152	\N	\N	\N
26462	VICPDT	2015-05-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	22780	\N	\N	\N
26463	VICPDT	2015-05-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	23151	\N	\N	\N
26464	VICPDT	2015-05-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23201	\N	\N	2017-09-24 18:49:56
26465	SECRET	2015-05-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	22768	\N	\N	\N
26466	SECRET	2015-05-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	22919	\N	\N	\N
26596	MEMBRE	2015-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23371	\N	\N	\N
26905	MEMBRE	2016-05-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23612	\N	2016-05-04 11:23:52	\N
27051	MEMBRE	2016-09-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23749	\N	2016-09-12 15:37:03	\N
27071	MEMBRE	2016-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23763	\N	2016-10-31 14:15:41	\N
27191	MEMBRE	2017-04-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23857	\N	2017-05-16 14:42:50	\N
27192	MEMBRE	2017-04-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23858	\N	2017-05-16 14:42:50	\N
24088	MEMBRE	2014-10-31 00:00:00	2017-06-01 00:00:00	ANCIEN	\N	\N	\N	\N	21999	\N	2014-11-03 09:33:45	2017-06-02 10:02:57
24092	MEMBRE	2014-10-31 00:00:00	2017-06-01 00:00:00	ANCIEN	\N	\N	\N	\N	22003	\N	2014-11-03 09:33:46	2017-06-02 10:02:57
27253	MEMBRE	2017-07-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	18870	\N	2017-07-21 09:12:41	\N
28697	MEMBRE	2017-11-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25264	\N	2017-11-15 17:10:25	\N
28698	MEMBRE	2017-10-31 00:00:00	2018-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	25265	\N	2017-11-15 17:10:50	2018-02-08 17:33:22
28699	MEMBRE	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25266	\N	2017-11-15 17:10:50	\N
28700	MEMBRE	2017-10-31 00:00:00	2017-12-11 00:00:00	ANCIEN	\N	\N	\N	\N	25267	\N	2017-11-15 17:10:50	2017-12-12 17:25:26
28701	MEMBRE	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25268	\N	2017-11-15 17:10:50	\N
28702	MEMBRE	2017-11-14 00:00:00	2018-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	25269	\N	2017-11-15 17:11:09	2018-01-29 16:17:43
28750	MEMBRE	2017-11-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25317	\N	2017-11-17 17:22:09	\N
28751	MEMBRE	2017-11-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25318	\N	2017-11-17 17:22:09	\N
28752	MEMBRE	2017-11-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25319	\N	2017-11-17 17:22:09	\N
28753	MEMBRE	2017-11-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25320	\N	2017-11-17 17:22:09	\N
28754	MEMBRE	2017-11-15 00:00:00	2017-12-05 00:00:00	ANCIEN	\N	\N	\N	\N	25321	\N	2017-11-17 17:22:44	2017-12-06 15:11:07
28755	MEMBRE	2017-11-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25322	\N	2017-11-17 17:22:44	\N
28756	MEMBRE	2017-11-15 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	25323	\N	2017-11-17 17:22:44	2017-12-20 12:22:08
28757	MEMBRE	2017-11-15 00:00:00	2017-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	25324	\N	2017-11-17 17:22:44	2017-12-14 18:37:23
28758	MEMBRE	2017-11-15 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	25325	\N	2017-11-17 17:22:44	2017-12-20 16:56:36
28759	MEMBRE	2017-11-15 00:00:00	2018-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	25326	\N	2017-11-17 17:22:44	2018-01-30 12:29:31
28760	MEMBRE	2017-11-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25327	\N	2017-11-17 17:22:44	\N
28761	MEMBRE	2017-11-15 00:00:00	2018-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	25328	\N	2017-11-17 17:22:44	2018-01-26 10:08:32
28762	MEMBRE	2017-11-15 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25329	\N	2017-11-17 17:24:36	\N
28763	MEMBRE	2017-11-15 00:00:00	2018-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	25330	\N	2017-11-17 17:24:51	2018-01-26 10:34:50
28764	MEMBRE	2017-11-14 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	25331	\N	2017-11-17 17:25:38	2018-01-18 16:41:30
28765	MEMBRE	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25332	\N	2017-11-17 17:25:55	\N
28766	MEMBRE	2017-11-16 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	25333	\N	2017-11-17 17:26:10	2018-02-07 16:34:55
28767	MEMBRE	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25334	\N	2017-11-17 17:26:28	\N
28768	MEMBRE	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25335	\N	2017-11-17 17:26:28	\N
28769	MEMBRE	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25336	\N	2017-11-17 17:27:13	\N
28770	MEMBRE	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25337	\N	2017-11-17 17:27:13	\N
28771	MEMBRE	2017-11-16 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	25338	\N	2017-11-17 17:27:13	2018-01-25 15:19:23
28772	MEMBRE	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25339	\N	2017-11-17 17:27:13	\N
28773	MEMBRE	2017-11-16 00:00:00	2017-12-05 00:00:00	ANCIEN	\N	\N	\N	\N	25340	\N	2017-11-17 17:27:13	2017-12-06 15:13:08
28774	MEMBRE	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25341	\N	2017-11-17 17:27:13	\N
28775	MEMBRE	2017-11-16 00:00:00	2018-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	25342	\N	2017-11-17 17:27:13	2018-01-30 16:02:48
28776	MEMBRE	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25343	\N	2017-11-17 17:27:13	\N
28777	MEMBRE	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25344	\N	2017-11-17 17:27:13	\N
28778	MEMBRE	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25345	\N	2017-11-17 17:27:13	\N
28779	MEMBRE	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25346	\N	2017-11-17 17:27:13	\N
28780	MEMBRE	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25347	\N	2017-11-17 17:27:13	\N
28781	MEMBRE	2017-11-16 00:00:00	2018-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	25348	\N	2017-11-17 17:27:13	2018-01-30 14:46:29
28782	MEMBRE	2017-11-16 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	25349	\N	2017-11-17 17:27:13	2018-01-31 16:17:26
28783	MEMBRE	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25350	\N	2017-11-17 17:27:13	\N
28784	MEMBRE	2017-11-16 00:00:00	2018-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	25351	\N	2017-11-17 17:27:13	2018-01-29 16:17:38
28785	MEMBRE	2017-11-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25352	\N	2017-11-17 17:27:39	\N
28786	MEMBRE	2017-11-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25353	\N	2017-11-17 17:27:39	\N
28787	MEMBRE	2017-11-17 00:00:00	2018-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	25354	\N	2017-11-17 17:27:39	2018-01-26 16:15:47
28788	MEMBRE	2017-11-17 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	25355	\N	2017-11-17 17:27:39	2018-01-25 10:58:15
28789	MEMBRE	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25356	\N	2017-11-17 17:28:02	\N
28790	MEMBRE	2017-11-16 00:00:00	2017-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	25357	\N	2017-11-17 17:28:02	2017-11-28 16:35:11
28791	MEMBRE	2017-11-17 00:00:00	2018-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	25358	\N	2017-11-17 17:28:31	2018-01-29 10:20:37
28792	MEMBRE	2017-11-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25359	\N	2017-11-17 17:28:31	\N
28793	MEMBRE	2017-11-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25360	\N	2017-11-17 17:29:10	\N
28794	MEMBRE	2017-11-15 00:00:00	2017-12-05 00:00:00	ANCIEN	\N	\N	\N	\N	25361	\N	2017-11-17 17:29:10	2017-12-06 15:15:45
28795	MEMBRE	2017-11-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25362	\N	2017-11-17 17:29:10	\N
28796	MEMBRE	2017-11-15 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25363	\N	2017-11-17 17:29:20	\N
28797	MEMBRE	2017-11-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25364	\N	2017-11-17 17:29:35	\N
28830	MEMBRE	2017-11-22 00:00:00	2017-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	25397	\N	2017-11-22 18:23:30	2017-11-30 16:07:51
28831	MEMBRE	2017-11-22 00:00:00	2020-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	25398	\N	2017-11-22 18:23:30	\N
28832	MEMBRE	2017-10-23 00:00:00	2018-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	25399	\N	2017-11-22 18:37:31	\N
28833	MEMBRE	2017-10-23 00:00:00	2018-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	25400	\N	2017-11-22 18:37:31	\N
28834	MEMBRE	2017-10-23 00:00:00	2017-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	25401	\N	2017-11-22 18:37:31	2017-12-05 10:01:47
29457	MEMBRE	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25784	\N	2018-01-08 16:26:57	\N
29598	PDTDEL	2018-01-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Macédoine du Nord	\N	25794	\N	2018-01-17 10:37:37	2018-01-17 10:37:47
30059	MEMBRE	2017-10-01 00:00:00	2018-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	26054	\N	\N	\N
30067	MEMBRE	2017-10-01 00:00:00	2018-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	26062	\N	\N	\N
30068	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26063	\N	\N	\N
30137	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26092	\N	\N	\N
30138	MEMBRE	2017-10-01 00:00:00	2018-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	26093	\N	\N	\N
30139	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26094	\N	\N	\N
30141	MEMBRE	2017-10-01 00:00:00	2018-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	26096	\N	\N	\N
30364	VICPDT	2018-01-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25632	\N	2018-01-31 18:42:47	\N
30365	VICPDT	2018-01-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25540	\N	2018-01-31 18:42:58	\N
30366	VICPDT	2018-01-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24288	\N	2018-01-31 18:43:14	\N
30367	VICPDT	2018-01-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26160	\N	2018-01-31 18:43:28	\N
30368	SECRET	2018-01-31 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24795	\N	2018-01-31 18:43:33	\N
30369	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26205	\N	\N	\N
30370	PDT	2018-01-31 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25807	\N	\N	\N
30371	VICPDT	2018-01-31 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25733	\N	\N	\N
30372	VICPDT	2018-01-31 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25734	\N	\N	\N
30373	VICPDT	2018-01-31 00:00:00	\N	ACTIF	\N	\N	\N	\N	26030	\N	\N	\N
30374	MEMBRE	2017-12-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26206	\N	\N	\N
30375	MEMBRE	2018-01-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26207	\N	2018-02-01 09:34:40	\N
30376	MEMBRE	2018-01-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26208	\N	2018-02-01 09:34:52	\N
30377	MEMBRE	2018-01-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26209	\N	2018-02-01 09:35:11	\N
30378	MEMBRE	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26210	\N	2018-02-01 09:35:26	\N
30379	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26211	\N	\N	\N
30380	VICPDT	2018-02-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24593	\N	2018-02-01 14:36:17	\N
22268	MEMBRE	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20215	\N	\N	\N
24632	MEMBRE	2015-01-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22386	\N	2015-01-14 16:27:09	\N
24747	MEMBRE	2015-01-26 00:00:00	2015-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	22452	\N	2015-01-26 15:00:16	2015-02-02 14:25:21
23165	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21109	\N	2014-10-24 10:57:46	\N
24748	MEMBRE	2015-01-26 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	22453	\N	2015-01-26 15:00:16	2015-02-11 16:39:32
25553	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22812	\N	\N	\N
23168	MEMBRE	2014-10-22 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	21112	\N	2014-10-24 10:57:46	2015-02-13 11:34:00
26087	VICPDT	2015-03-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	23026	\N	\N	\N
26091	SECRET	2015-03-04 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	23029	\N	\N	2017-09-25 09:57:52
23171	MEMBRE	2014-10-22 00:00:00	2015-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	21115	\N	2014-10-24 10:57:46	2015-02-09 15:42:23
26093	PDT	2015-03-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	23039	\N	\N	\N
23173	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21117	\N	2014-10-24 10:57:46	\N
23174	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21118	\N	2014-10-24 10:57:46	\N
26133	MEMBRE	2015-02-11 00:00:00	2015-03-09 00:00:00	ANCIEN	\N	\N	\N	\N	23118	\N	2015-03-10 09:31:37	2015-03-10 17:27:14
26150	MEMBRE	2015-01-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23125	\N	2015-03-10 15:12:21	\N
23177	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21121	\N	2014-10-24 10:57:46	\N
23178	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21122	\N	2014-10-24 10:57:47	\N
26312	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23190	\N	\N	\N
23180	MEMBRE	2014-10-22 00:00:00	2015-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	21124	\N	2014-10-24 10:57:47	2015-02-04 10:19:21
23181	MEMBRE	2014-10-22 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	21125	\N	2014-10-24 10:57:47	2015-02-03 10:23:36
26313	MEMBRE	2014-10-01 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	23191	\N	\N	2017-05-16 15:18:14
23183	MEMBRE	2014-10-22 00:00:00	2015-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	21127	\N	2014-10-24 10:57:47	2015-01-28 17:47:53
26725	VICPDT	2016-02-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22236	\N	2016-02-02 18:00:43	\N
23185	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21129	\N	2014-10-24 10:57:47	\N
23186	MEMBRE	2014-10-22 00:00:00	2015-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	21130	\N	2014-10-24 10:57:47	2015-01-28 10:25:55
23187	MEMBRE	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21131	\N	2014-10-24 10:57:47	\N
26819	MEMBRE	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	23536	\N	2016-02-12 12:35:07	\N
26820	MEMBRE	2016-02-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23537	\N	2016-02-12 12:35:13	2017-09-24 19:14:37
26821	MEMBRE	2016-02-12 00:00:00	2023-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	23538	\N	2016-02-12 12:35:20	\N
23191	MEMBRE	2014-10-22 00:00:00	2015-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	21135	\N	2014-10-24 10:57:47	2015-02-18 13:27:22
23192	MEMBRE	2014-10-22 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21136	\N	2014-10-24 10:57:47	2015-01-06 15:14:37
23193	MEMBRE	2014-10-22 00:00:00	2015-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	21137	\N	2014-10-24 10:57:47	2015-03-19 09:58:05
23194	MEMBRE	2014-10-22 00:00:00	2015-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	21138	\N	2014-10-24 10:57:47	2015-01-30 15:55:04
26822	MEMBRE	2016-02-12 00:00:00	2020-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	23539	\N	2016-02-12 12:35:27	\N
23289	MEMBRE	2014-10-24 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	21200	\N	2014-10-24 17:35:46	2015-02-20 12:12:41
23290	MEMBRE	2014-10-24 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21201	\N	2014-10-24 17:35:46	\N
23291	MEMBRE	2014-10-24 00:00:00	2015-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	21202	\N	2014-10-24 17:36:08	2015-02-04 14:27:52
23292	MEMBRE	2014-10-24 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21203	\N	2014-10-24 17:36:08	\N
23293	MEMBRE	2014-10-24 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	21204	\N	2014-10-24 17:36:08	2015-02-20 12:12:31
23294	MEMBRE	2014-10-24 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21205	\N	2014-10-24 17:36:08	\N
26823	MEMBRE	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	23540	\N	2016-02-12 12:35:33	\N
26824	MEMBRE	2016-02-12 00:00:00	2020-11-25 00:00:00	ANCIEN	\N	\N	\N	\N	23541	\N	2016-02-12 12:35:41	\N
26825	MEMBRE	2016-02-12 00:00:00	2023-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	23542	\N	2016-02-12 12:35:49	\N
26826	MEMBRE	2016-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23543	\N	2016-02-12 12:35:58	2017-10-01 10:42:05
26827	MEMBRE	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	23544	\N	2016-02-12 12:36:05	\N
26828	MEMBRE	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	23545	\N	2016-02-12 12:36:10	\N
26829	MEMBRE	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	23546	\N	2016-02-12 12:36:17	\N
26830	MEMBRE	2016-02-12 00:00:00	2020-10-19 00:00:00	ANCIEN	\N	\N	\N	\N	23547	\N	2016-02-12 12:36:24	\N
26831	MEMBRE	2016-02-12 00:00:00	2018-01-04 00:00:00	ANCIEN	\N	\N	\N	\N	23548	\N	2016-02-12 12:36:29	2018-01-05 11:28:46
26832	MEMBRE	2016-02-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23549	\N	2016-02-12 12:36:34	\N
26833	MEMBRE	2016-02-12 00:00:00	2017-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	23550	\N	2016-02-12 12:36:40	2017-10-11 15:55:37
26834	MEMBRE	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	23551	\N	2016-02-12 12:37:01	\N
26835	MEMBRE	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	23552	\N	2016-02-12 12:37:09	\N
26836	MEMBRE	2016-02-12 00:00:00	2020-10-19 00:00:00	ANCIEN	\N	\N	\N	\N	23553	\N	2016-02-12 12:37:43	\N
26837	MEMBRE	2016-02-12 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	23554	\N	2016-02-12 12:37:55	\N
26838	VICPDT	2016-02-12 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	23555	\N	2016-02-12 12:38:03	2016-03-11 18:02:51
26839	MEMBRE	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	23556	\N	2016-02-12 12:38:16	\N
26840	MEMBRE	2016-02-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23557	\N	2016-02-12 12:38:21	2017-09-24 17:15:15
26841	MEMBRE	2016-02-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23558	\N	2016-02-12 12:38:27	2017-09-24 17:47:27
26842	MEMBRE	2016-02-12 00:00:00	2017-10-31 00:00:00	ANCIEN	\N	\N	\N	\N	23559	\N	2016-02-12 12:38:38	2017-11-06 15:38:29
26843	MEMBRE	2016-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23560	\N	2016-02-12 12:38:44	2017-10-01 10:25:16
26844	MEMBRE	2016-02-12 00:00:00	2020-10-19 00:00:00	ANCIEN	\N	\N	\N	\N	23561	\N	2016-02-12 12:38:49	\N
26845	MEMBRE	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	23562	\N	2016-02-12 12:38:54	\N
26846	MEMBRE	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	23563	\N	2016-02-12 12:39:00	\N
26847	MEMBRE	2016-02-12 00:00:00	2023-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	23564	\N	2016-02-12 12:39:05	\N
26848	MEMBRE	2016-02-12 00:00:00	2020-10-19 00:00:00	ANCIEN	\N	\N	\N	\N	23454	\N	2016-02-12 12:39:10	\N
26849	MEMBRE	2016-02-12 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23565	\N	2016-02-12 12:39:15	\N
26850	MEMBRE	2016-02-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23566	\N	2016-02-12 12:39:21	2017-09-24 12:57:09
26851	MEMBRE	2016-02-12 00:00:00	2023-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	23567	\N	2016-02-12 12:39:30	\N
26852	MEMBRE	2016-02-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23568	\N	2016-02-12 12:39:37	2017-09-24 17:35:15
26853	MEMBRE	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	23569	\N	2016-02-12 12:39:43	\N
26854	MEMBRE	2016-02-12 00:00:00	2023-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	23570	\N	2016-02-12 12:39:50	\N
26855	MEMBRE	2016-02-12 00:00:00	2020-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	23571	\N	2016-02-12 12:39:56	\N
26856	MEMBRE	2016-02-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23572	\N	2016-02-12 12:40:02	2017-09-24 17:04:02
26857	MEMBRE	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	23573	\N	2016-02-12 12:40:10	\N
26858	MEMBRE	2016-02-12 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	23574	\N	2016-02-12 12:40:18	\N
26859	MEMBRE	2016-02-12 00:00:00	2020-10-19 00:00:00	ANCIEN	\N	\N	\N	\N	23575	\N	2016-02-12 12:40:24	\N
26860	MEMBRE	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	23576	\N	2016-02-12 12:40:29	\N
26861	MEMBRE	2016-02-12 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23577	\N	2016-02-12 12:40:36	\N
26862	VICPDT	2016-02-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23578	\N	2016-02-12 12:40:42	2017-09-24 13:29:42
26863	MEMBRE	2016-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23579	\N	2016-02-12 12:41:21	2017-10-01 10:18:28
26864	MEMBRE	2016-02-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23580	\N	2016-02-12 12:41:32	2017-09-24 18:59:59
26865	MEMBRE	2016-02-12 00:00:00	2017-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	23581	\N	2016-02-12 12:41:52	2017-12-08 09:45:37
26866	MEMBRE	2016-02-12 00:00:00	2020-10-19 00:00:00	ANCIEN	\N	\N	\N	\N	23582	\N	2016-02-12 12:42:02	\N
26867	MEMBRE	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	23583	\N	2016-02-12 12:42:13	\N
26868	MEMBRE	2016-02-12 00:00:00	2020-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	23584	\N	2016-02-12 12:42:52	\N
26869	MEMBRE	2016-02-12 00:00:00	2017-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	23585	\N	2016-02-12 12:43:01	2017-07-24 09:56:26
26870	MEMBRE	2016-02-12 00:00:00	2016-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	23586	\N	2016-02-12 12:57:08	2017-01-03 11:09:24
26871	MEMBRE	2016-02-12 00:00:00	2023-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	23587	\N	2016-02-12 12:57:19	\N
26872	MEMBRE	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	23588	\N	2016-02-12 12:57:29	\N
26873	MEMBRE	2016-02-12 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	23589	\N	2016-02-12 12:57:36	\N
26874	MEMBRE	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	23590	\N	2016-02-12 12:57:52	\N
26875	MEMBRE	2016-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23591	\N	2016-02-12 12:57:59	2017-10-01 10:32:58
26876	MEMBRE	2016-02-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	23592	\N	\N	\N
26903	MEMBRE	2016-04-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	23610	\N	\N	\N
26911	MEMBRE	2016-05-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23617	\N	2016-05-20 10:07:45	\N
26912	MEMBRE	2016-05-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23618	\N	2016-05-26 09:58:01	\N
26916	MEMBRE	2016-05-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23622	\N	2016-05-30 09:58:48	\N
26955	MEMBRE	2016-06-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	23655	\N	\N	\N
26956	MEMBRE	2016-06-15 00:00:00	2016-09-28 00:00:00	ANCIEN	\N	\N	\N	\N	23656	\N	\N	\N
26957	MEMBRE	2016-06-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	23657	\N	\N	\N
26958	MEMBRE	2016-06-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	23658	\N	\N	\N
26960	MEMBRE	2016-06-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	23660	\N	\N	\N
26961	MEMBRE	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23661	\N	\N	2017-09-24 13:14:55
26962	MEMBRE	2016-06-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	23662	\N	\N	\N
26964	MEMBRE	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23664	\N	\N	2017-09-24 17:35:15
26965	MEMBRE	2016-06-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	23665	\N	\N	\N
26966	MEMBRE	2016-06-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23666	\N	\N	2017-10-01 10:34:22
25218	MEMBRE	2015-02-12 00:00:00	2015-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	22542	\N	2015-02-13 09:02:22	2015-03-11 12:57:40
25219	MEMBRE	2015-02-11 00:00:00	2017-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	22543	\N	2015-02-13 09:02:32	2017-07-04 15:08:09
25220	MEMBRE	2015-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22544	\N	2015-02-13 09:28:20	\N
25221	MEMBRE	2014-12-19 00:00:00	2017-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	22545	\N	2015-02-13 09:28:27	2017-07-20 14:38:36
25261	SECRET	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21551	\N	2015-02-13 14:23:52	\N
25262	SECRET	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21244	11	2015-02-13 14:24:00	2015-02-13 14:24:05
25263	SECRET	2015-02-13 00:00:00	2017-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20751	12	2015-02-13 14:24:09	2017-10-09 09:55:19
25570	MEMBRE	2014-10-01 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	22818	\N	\N	2017-09-25 09:56:00
25571	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22819	\N	\N	\N
25578	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22820	\N	\N	\N
25579	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22821	\N	\N	\N
25580	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22822	\N	\N	\N
25930	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22989	\N	\N	\N
26128	MEMBRE	2014-10-01 00:00:00	2015-06-03 00:00:00	ANCIEN	\N	\N	\N	\N	23113	\N	\N	\N
26129	MEMBRE	2014-10-01 00:00:00	2015-06-03 00:00:00	ANCIEN	\N	\N	\N	\N	23114	\N	\N	\N
26130	MEMBRE	2014-10-01 00:00:00	2014-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23115	\N	\N	\N
26143	SECRET	2015-03-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	23006	\N	\N	\N
26356	VICPDT	2015-04-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	22720	\N	\N	\N
26362	SECRET	2015-04-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	23078	\N	\N	\N
26363	SECRET	2015-04-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22714	\N	\N	2017-09-24 17:09:24
26364	VICPDT	2015-04-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	22877	\N	\N	\N
26365	SECRET	2015-04-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22721	\N	\N	2017-09-24 13:25:54
26366	VICPDT	2015-04-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22736	\N	\N	2017-09-24 17:18:03
26367	VICPDT	2015-04-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	22883	\N	\N	\N
26368	SECRET	2015-04-16 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	22879	\N	\N	2017-05-16 15:18:14
26369	VICPDT	2015-04-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	22730	\N	\N	\N
26403	MEMBRE	2014-10-01 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	23242	\N	\N	2016-12-12 16:10:15
26404	MEMBRE	2014-10-01 00:00:00	2015-05-28 00:00:00	ANCIEN	\N	\N	\N	\N	23243	\N	\N	\N
26405	MEMBRE	2014-10-01 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	23244	\N	\N	2016-12-12 16:10:15
26406	MEMBRE	2014-10-01 00:00:00	2015-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	23245	\N	\N	\N
26514	MEMBRE	2014-10-01 00:00:00	2017-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	23289	\N	\N	2017-07-24 09:56:26
26587	MEMBRE	2015-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23362	\N	\N	\N
26632	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23381	\N	\N	\N
26656	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23395	\N	\N	\N
26690	MEMBRE	2015-11-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23422	\N	2015-11-10 10:11:42	\N
26897	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23605	\N	\N	\N
27194	MEMBRE	2017-06-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	23860	\N	\N	\N
27515	MEMBRE	2017-10-11 00:00:00	2020-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	24082	\N	2017-10-13 10:05:22	\N
27516	MEMBRE	2017-10-11 00:00:00	2020-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	24083	\N	2017-10-13 10:05:22	\N
27517	MEMBRE	2017-10-11 00:00:00	2020-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	24084	\N	2017-10-13 10:05:22	\N
27518	MEMBRE	2017-10-11 00:00:00	2020-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	24085	\N	2017-10-13 10:05:22	\N
28515	MEMBRE	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25082	\N	2017-11-06 14:42:06	\N
28516	MEMBRE	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25083	\N	2017-11-06 14:42:06	\N
28517	MEMBRE	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25084	\N	2017-11-06 14:42:06	\N
28518	MEMBRE	2017-10-26 00:00:00	2017-12-11 00:00:00	ANCIEN	\N	\N	\N	\N	25085	\N	2017-11-06 15:28:50	2017-12-12 17:22:27
28519	MEMBRE	2017-10-31 00:00:00	2017-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	25086	\N	2017-11-06 15:37:00	2017-12-07 15:00:00
28520	MEMBRE	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25087	\N	2017-11-06 15:37:00	\N
28521	MEMBRE	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25088	\N	2017-11-06 15:37:00	\N
28522	MEMBRE	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25089	\N	2017-11-06 15:37:00	\N
28523	MEMBRE	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25090	\N	2017-11-06 15:37:00	\N
28524	MEMBRE	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25091	\N	2017-11-06 15:37:00	\N
28525	MEMBRE	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25092	\N	2017-11-06 15:38:28	\N
28526	MEMBRE	2017-10-31 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	25093	\N	2017-11-06 15:38:28	2018-01-24 18:06:24
28527	MEMBRE	2017-10-31 00:00:00	2017-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	25094	\N	2017-11-06 15:38:28	2017-11-28 17:06:01
28528	MEMBRE	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25095	\N	2017-11-06 15:38:28	\N
28529	MEMBRE	2017-10-31 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	25096	\N	2017-11-06 15:38:28	2018-01-18 11:23:17
28530	MEMBRE	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25097	\N	2017-11-06 15:38:28	\N
28531	MEMBRE	2017-10-31 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	25098	\N	2017-11-06 15:38:28	2018-01-23 16:55:26
28532	MEMBRE	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25099	\N	2017-11-06 15:38:28	\N
28560	MEMBRE	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25127	\N	2017-11-08 14:10:19	\N
28561	MEMBRE	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25128	\N	2017-11-08 14:10:19	\N
28562	MEMBRE	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25129	\N	2017-11-08 14:10:19	\N
28563	MEMBRE	2017-11-08 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	25130	\N	2017-11-08 14:13:24	2018-01-24 11:13:54
28564	MEMBRE	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25131	\N	2017-11-08 14:13:24	\N
28565	MEMBRE	2017-11-08 00:00:00	2017-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	25132	\N	2017-11-08 14:13:24	2017-11-30 16:25:35
28566	MEMBRE	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25133	\N	2017-11-08 14:13:24	\N
28567	MEMBRE	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25134	\N	2017-11-08 14:13:24	\N
28568	MEMBRE	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25135	\N	2017-11-08 14:13:24	\N
28569	MEMBRE	2017-11-08 00:00:00	2017-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	25136	\N	2017-11-08 14:13:24	2017-11-30 16:07:08
28570	MEMBRE	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25137	\N	2017-11-08 14:13:24	\N
28571	MEMBRE	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25138	\N	2017-11-08 14:15:38	\N
28572	MEMBRE	2017-11-08 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	25139	\N	2017-11-08 14:15:38	2018-01-24 17:10:04
28573	MEMBRE	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25140	\N	2017-11-08 14:15:38	\N
28574	MEMBRE	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25141	\N	2017-11-08 14:15:38	\N
28575	MEMBRE	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25142	\N	2017-11-08 14:15:38	\N
28576	MEMBRE	2017-11-08 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	25143	\N	2017-11-08 14:15:38	2018-01-24 18:31:47
28577	MEMBRE	2017-11-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25144	\N	2017-11-08 14:26:54	\N
28578	MEMBRE	2017-11-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25145	\N	2017-11-08 14:26:54	\N
28579	MEMBRE	2017-11-07 00:00:00	2017-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	25146	\N	2017-11-08 14:26:54	2017-12-14 15:49:07
28580	MEMBRE	2017-11-06 00:00:00	2017-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	25147	\N	2017-11-08 14:27:10	2017-11-28 16:57:33
28581	MEMBRE	2017-11-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25148	\N	2017-11-08 14:27:10	\N
28582	MEMBRE	2017-11-07 00:00:00	2017-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	25149	\N	2017-11-08 14:27:32	2017-12-07 15:02:05
28662	MEMBRE	2017-11-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25229	\N	2017-11-10 17:09:30	\N
28663	MEMBRE	2017-11-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25230	\N	2017-11-10 17:09:30	\N
28664	MEMBRE	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25231	\N	2017-11-10 17:09:49	\N
28665	MEMBRE	2017-11-08 00:00:00	2018-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	25232	\N	2017-11-10 17:09:49	2018-01-30 12:30:00
29193	MEMBRE	2017-12-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25621	\N	2017-12-13 17:09:53	\N
29194	PDTDEL	2017-12-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Angola	\N	25581	\N	2017-12-13 17:53:52	2017-12-13 17:54:00
29253	MEMBRE	2017-11-29 00:00:00	2020-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	25653	\N	2017-12-19 14:36:14	\N
29254	MEMBRE	2017-12-15 00:00:00	2017-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	25654	\N	2017-12-19 14:36:33	2017-12-19 14:37:52
29255	PDTDEL	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Ile Maurice	\N	25654	\N	2017-12-19 14:37:52	2017-12-19 14:38:26
29608	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25869	\N	\N	\N
29757	VICPDT	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25541	\N	2018-01-18 17:50:58	\N
29758	VICPDT	2018-01-18 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	24517	\N	2018-01-18 17:51:06	\N
29759	VICPDT	2018-01-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25222	\N	2018-01-18 17:51:12	\N
29760	VICPDT	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25696	\N	2018-01-18 17:51:23	\N
29761	VICPDT	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24024	\N	2018-01-18 17:51:58	\N
29762	VICPDT	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24825	\N	2018-01-18 17:52:13	\N
29763	VICPDT	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23909	\N	2018-01-18 17:52:19	\N
29764	VICPDT	2018-01-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24536	\N	2018-01-18 17:52:25	\N
29765	VICPDT	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25699	\N	2018-01-18 18:09:35	\N
29766	VICPDT	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24863	\N	2018-01-18 18:09:41	\N
29767	VICPDT	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24622	\N	2018-01-18 18:09:46	\N
29768	VICPDT	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24957	\N	2018-01-18 18:09:57	\N
29769	VICPDT	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24421	\N	2018-01-18 18:10:11	\N
29770	VICPDT	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25113	\N	2018-01-18 18:10:18	\N
29771	SECRET	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24451	\N	2018-01-18 18:10:36	\N
29772	SECRET	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24792	\N	2018-01-18 18:10:43	\N
29773	SECRET	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25315	\N	2018-01-18 18:10:48	\N
22267	MEMBRE	2013-11-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20213	\N	2013-11-29 16:17:59	\N
24390	MEMBRE	2014-12-02 00:00:00	2015-03-19 00:00:00	ANCIEN	\N	\N	\N	\N	22297	\N	2014-12-03 09:49:54	2015-03-20 11:38:09
24391	MEMBRE	2014-12-02 00:00:00	2015-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	22298	\N	2014-12-03 09:50:04	2015-02-04 10:19:33
24418	MEMBRE	2014-11-27 00:00:00	2015-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	22325	\N	2014-12-10 10:39:42	2015-02-09 15:42:47
24419	MEMBRE	2014-12-10 00:00:00	2015-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	22326	\N	2014-12-10 11:38:39	2015-02-12 17:36:39
24420	MEMBRE	2014-12-10 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22327	\N	2014-12-10 11:38:39	\N
24421	MEMBRE	2014-12-10 00:00:00	2015-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	22328	\N	2014-12-10 12:19:21	2015-01-23 12:06:06
24426	MEMBRE	2014-12-11 00:00:00	2017-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	22333	\N	2014-12-12 10:20:34	2017-07-20 14:38:30
24456	MEMBRE	2014-12-17 00:00:00	2015-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	22363	\N	2014-12-18 16:03:43	2015-01-13 15:44:22
24460	MEMBRE	2014-12-18 00:00:00	2017-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	22367	\N	2014-12-19 09:39:03	2017-07-20 14:38:10
24461	MEMBRE	2014-12-17 00:00:00	2015-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	22368	\N	2014-12-19 09:39:27	2015-03-16 18:44:38
25142	VICPDT	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22374	2	2015-02-11 16:58:03	2015-02-11 16:58:17
24667	VICPDT	2015-01-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21191	8	2015-01-20 11:25:31	2015-01-20 11:32:30
24714	PDTDEL	2015-01-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour le Vanuatu	\N	22435	4	2015-01-22 16:32:48	2015-01-22 16:33:47
24669	SECRET	2015-01-20 00:00:00	2016-03-30 00:00:00	ANCIEN	\N	\N	\N	\N	20357	11	2015-01-20 11:33:54	2016-03-31 15:51:47
24671	PDT	2015-01-20 00:00:00	2015-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	22406	1	2015-01-20 12:39:23	2015-05-05 16:57:56
24713	PDTDEL	2015-01-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour la Papouasie-Nouvelle Guinée	\N	22436	3	2015-01-22 16:31:08	2015-01-22 16:32:23
24938	VICPDT	2015-02-04 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21050	5	2015-02-04 10:18:40	2015-02-04 16:36:58
24939	VICPDT	2015-02-04 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21733	6	2015-02-04 10:18:52	2015-02-04 16:37:00
24940	VICPDT	2015-02-04 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20611	7	2015-02-04 10:19:05	2015-02-04 16:37:03
24941	SECRET	2015-02-04 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21124	8	2015-02-04 10:19:21	2015-02-04 16:37:07
24942	SECRET	2015-02-04 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21674	9	2015-02-04 10:19:26	2015-02-04 16:37:09
24943	SECRET	2015-02-04 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22298	10	2015-02-04 10:19:33	2015-02-04 16:37:11
25143	VICPDT	2015-02-11 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	20683	3	2015-02-11 16:58:30	2015-06-12 15:59:49
25144	SECRET	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21814	4	2015-02-11 16:58:45	2015-02-11 16:58:53
25145	SECRET	2015-02-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22449	5	2015-02-11 16:59:00	2015-02-11 16:59:10
25146	SECRET	2015-02-11 00:00:00	2016-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20652	6	2015-02-11 16:59:14	2017-01-03 11:09:24
25147	SECRET	2015-02-11 00:00:00	2015-11-11 00:00:00	ANCIEN	\N	\N	\N	\N	20449	\N	2015-02-11 17:00:06	2015-11-12 15:26:22
25554	MEMBRE	2014-10-01 00:00:00	2014-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	22813	\N	\N	\N
25919	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22978	\N	\N	2017-09-25 10:56:48
25920	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22979	\N	\N	2017-09-24 17:04:02
26012	MEMBRE	2014-10-01 00:00:00	2014-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	23071	\N	\N	\N
26700	PDT	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22611	\N	\N	\N
26732	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23451	\N	\N	\N
26733	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23452	\N	\N	\N
26734	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23453	\N	\N	\N
27123	MEMBRE	2016-11-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23815	\N	2016-11-18 09:41:45	2017-09-24 17:29:37
27157	MEMBRE	2017-01-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23826	\N	2017-01-16 18:17:51	\N
27158	MEMBRE	2017-01-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23827	\N	2017-01-16 18:17:51	\N
27481	MEMBRE	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24048	\N	2017-10-12 12:21:31	\N
27482	MEMBRE	2017-10-11 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24049	\N	2017-10-12 12:21:31	2018-01-24 15:03:49
27483	MEMBRE	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24050	\N	2017-10-12 12:21:31	\N
27484	MEMBRE	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24051	\N	2017-10-12 12:21:31	\N
27485	MEMBRE	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24052	\N	2017-10-12 12:21:31	\N
27486	MEMBRE	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24053	\N	2017-10-12 12:21:31	\N
27487	MEMBRE	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24054	\N	2017-10-12 12:21:31	\N
27488	MEMBRE	2017-10-11 00:00:00	2018-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	24055	\N	2017-10-12 12:21:31	2018-01-29 17:06:32
27495	MEMBRE	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24062	\N	2017-10-12 15:01:55	\N
27496	MEMBRE	2017-10-10 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24063	\N	2017-10-12 15:20:28	2018-01-24 17:30:34
27497	MEMBRE	2017-10-10 00:00:00	2017-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	24064	\N	2017-10-12 15:20:28	2017-11-28 16:28:40
27498	MEMBRE	2017-10-10 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	24065	\N	2017-10-12 15:20:28	2018-01-18 18:23:39
27499	MEMBRE	2017-10-10 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	24066	\N	2017-10-12 15:20:28	2018-01-18 17:50:43
27500	MEMBRE	2017-10-11 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	24067	\N	2017-10-12 15:27:28	2018-02-07 15:30:15
27501	MEMBRE	2017-10-11 00:00:00	2018-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	24068	\N	2017-10-12 15:27:28	2018-01-30 12:29:01
27502	MEMBRE	2017-10-11 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	24069	\N	2017-10-12 15:27:28	2017-12-20 16:57:54
27503	MEMBRE	2017-10-12 00:00:00	2017-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	24070	\N	2017-10-12 15:45:44	2017-11-28 16:58:24
27504	MEMBRE	2017-10-12 00:00:00	2018-08-06 00:00:00	ANCIEN	\N	\N	\N	\N	24071	\N	2017-10-12 15:45:44	\N
27505	MEMBRE	2017-10-12 00:00:00	2018-08-06 00:00:00	ANCIEN	\N	\N	\N	\N	24072	\N	2017-10-12 15:45:44	\N
27506	MEMBRE	2017-10-11 00:00:00	2018-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	24073	\N	2017-10-12 15:50:22	\N
27507	MEMBRE	2017-10-11 00:00:00	2018-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	24074	\N	2017-10-12 15:50:22	\N
27508	MEMBRE	2017-10-11 00:00:00	2018-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	24075	\N	2017-10-12 15:50:22	\N
27509	MEMBRE	2017-10-11 00:00:00	2018-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	24076	\N	2017-10-12 15:50:22	\N
27510	MEMBRE	2017-10-11 00:00:00	2018-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	24077	\N	2017-10-12 15:50:22	\N
27511	MEMBRE	2017-10-11 00:00:00	2017-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	24078	\N	2017-10-12 15:50:22	2017-12-04 18:47:59
28355	MEMBRE	2017-10-30 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	24922	\N	2017-10-31 17:25:12	2018-02-07 16:33:26
28356	MEMBRE	2017-10-30 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	24923	\N	2017-10-31 17:25:12	2018-01-25 15:21:05
28357	MEMBRE	2017-10-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24924	\N	2017-10-31 17:25:12	\N
28358	MEMBRE	2017-10-30 00:00:00	2018-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	24925	\N	2017-10-31 17:25:12	2018-02-12 10:01:51
28359	MEMBRE	2017-10-30 00:00:00	2018-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	24926	\N	2017-10-31 17:25:12	2018-01-30 12:30:32
28360	MEMBRE	2017-10-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24927	\N	2017-10-31 17:25:12	\N
28361	MEMBRE	2017-10-30 00:00:00	2018-03-04 00:00:00	ANCIEN	\N	\N	\N	\N	24928	\N	2017-10-31 17:25:12	2018-03-05 17:57:44
28362	MEMBRE	2017-10-27 00:00:00	2018-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	24929	\N	2017-10-31 17:29:24	2018-01-29 17:06:57
28363	MEMBRE	2017-10-27 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	24930	\N	2017-10-31 17:29:24	2018-01-18 16:41:01
28364	MEMBRE	2017-10-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24931	\N	2017-10-31 17:29:24	\N
28365	MEMBRE	2017-10-27 00:00:00	2017-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	24932	\N	2017-10-31 17:29:24	2017-12-19 18:18:01
28366	MEMBRE	2017-10-27 00:00:00	2018-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	24933	\N	2017-10-31 17:29:24	2018-02-12 10:03:24
28367	MEMBRE	2017-10-27 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24934	\N	2017-10-31 17:29:24	2018-01-24 18:08:16
28368	MEMBRE	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24935	\N	2017-10-31 17:29:59	\N
28369	MEMBRE	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24936	\N	2017-10-31 17:29:59	\N
28370	MEMBRE	2017-10-30 00:00:00	2018-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	24937	\N	2017-10-31 17:29:59	2018-01-16 19:09:32
28371	MEMBRE	2017-10-30 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	24938	\N	2017-10-31 17:29:59	2018-01-23 17:27:18
28372	MEMBRE	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24939	\N	2017-10-31 17:29:59	\N
28373	MEMBRE	2017-10-30 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24940	\N	2017-10-31 17:29:59	2018-01-24 18:31:17
28374	MEMBRE	2017-10-30 00:00:00	2018-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	24941	\N	2017-10-31 17:29:59	2018-01-26 10:35:21
28375	MEMBRE	2017-10-30 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24942	\N	2017-10-31 17:29:59	2018-01-24 18:08:53
28376	MEMBRE	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24943	\N	2017-10-31 17:30:32	\N
28377	MEMBRE	2017-10-30 00:00:00	2017-12-11 00:00:00	ANCIEN	\N	\N	\N	\N	24944	\N	2017-10-31 17:30:32	2017-12-12 17:27:04
28378	MEMBRE	2017-10-30 00:00:00	2017-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	24945	\N	2017-10-31 17:30:32	2017-11-30 14:58:30
28379	MEMBRE	2017-10-30 00:00:00	2017-12-26 00:00:00	ANCIEN	\N	\N	\N	\N	24946	\N	2017-10-31 17:30:32	2017-12-27 11:10:03
28380	MEMBRE	2017-10-30 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24947	\N	2017-10-31 17:30:32	2018-01-24 10:42:32
28381	MEMBRE	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24948	\N	2017-10-31 17:30:32	\N
28382	MEMBRE	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24949	\N	2017-10-31 17:30:32	\N
28383	MEMBRE	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24950	\N	2017-10-31 17:30:32	\N
28384	MEMBRE	2017-10-30 00:00:00	2017-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	24951	\N	2017-10-31 17:30:32	2017-12-05 10:08:56
28385	MEMBRE	2017-10-30 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	24952	\N	2017-10-31 17:30:32	2018-02-07 12:14:53
28386	MEMBRE	2017-10-30 00:00:00	2017-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	24953	\N	2017-10-31 17:30:32	2017-11-30 14:58:30
28387	MEMBRE	2017-10-30 00:00:00	2018-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	24954	\N	2017-10-31 17:30:32	2018-01-30 12:29:52
28388	MEMBRE	2017-10-30 00:00:00	2017-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	24955	\N	2017-10-31 17:30:32	2017-11-30 14:58:30
28389	MEMBRE	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24956	\N	2017-10-31 17:35:15	\N
25595	VICPDT	2015-02-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20498	3	2015-02-17 09:36:06	2015-02-17 09:38:48
25596	PDTHON	2015-02-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20479	2	2015-02-17 09:38:36	2015-02-17 09:38:45
25597	VICPDT	2015-02-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20461	4	2015-02-17 09:38:58	2015-02-17 09:40:24
25598	VICPDT	2015-02-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20378	5	2015-02-17 09:39:11	2015-02-17 09:40:27
25599	VICPDT	2015-02-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22347	6	2015-02-17 09:39:22	2015-02-17 09:40:30
25600	VICPDT	2015-02-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20757	7	2015-02-17 09:39:34	2015-02-17 09:40:46
25601	VICPDT	2015-02-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21101	8	2015-02-17 09:39:45	2015-02-17 09:40:52
25602	VICPDT	2015-02-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21709	9	2015-02-17 09:39:58	2015-02-17 09:41:00
25603	VICPDT	2015-02-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21664	10	2015-02-17 09:40:04	2015-02-17 09:41:03
25604	VICPDT	2015-02-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20870	11	2015-02-17 09:40:10	2015-02-17 09:41:07
25605	SECRET	2015-02-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21208	12	2015-02-17 09:41:13	2015-02-17 09:42:09
25606	SECRET	2015-02-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20325	13	2015-02-17 09:41:28	2015-02-17 09:42:12
25607	SECRET	2015-02-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21089	14	2015-02-17 09:41:40	2015-02-17 09:42:16
25898	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22971	\N	\N	\N
25899	MEMBRE	2014-10-01 00:00:00	2014-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	22972	\N	\N	\N
25917	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22976	\N	\N	2017-09-24 16:24:51
25921	MEMBRE	2015-02-05 00:00:00	2015-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	22980	\N	2015-03-02 17:08:20	2015-03-11 10:58:11
26223	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23166	\N	\N	\N
26447	MEMBRE	2015-05-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23263	\N	2015-05-19 09:37:59	2017-09-24 18:16:52
26667	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23405	\N	\N	\N
27025	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23723	\N	\N	\N
27160	MEMBRE	2017-01-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23829	\N	2017-01-24 14:52:06	\N
27183	MEMBRE	2017-02-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23850	\N	2017-02-27 15:46:47	\N
27184	MEMBRE	2017-01-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23834	\N	2017-02-27 15:51:21	\N
27201	MEMBRE	2017-07-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22220	\N	2017-07-20 11:43:02	\N
27202	MEMBRE	2017-07-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20591	\N	2017-07-20 11:43:02	\N
27203	MEMBRE	2017-07-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21252	\N	2017-07-20 11:43:02	\N
27204	MEMBRE	2017-07-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22136	\N	2017-07-20 11:43:02	2017-09-24 13:14:55
27205	VICPDT	2017-07-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21007	\N	2017-07-20 11:43:24	\N
27206	SECRET	2017-07-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20326	\N	2017-07-20 11:43:29	2017-09-24 18:59:59
27207	SECRET	2017-07-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21961	\N	2017-07-20 11:43:35	2017-07-20 11:44:57
27208	VICPDT	2017-07-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21543	\N	2017-07-20 11:44:30	2017-10-01 10:34:22
27209	MEMBRE	2017-07-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22337	\N	2017-07-20 11:45:07	2017-09-24 18:20:10
27210	MEMBRE	2017-07-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22185	\N	2017-07-20 11:45:11	\N
27211	MEMBRE	2017-07-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22169	\N	2017-07-20 11:45:15	\N
27212	MEMBRE	2017-07-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22219	\N	2017-07-20 11:45:21	2017-09-24 13:42:36
27213	MEMBRE	2017-07-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22146	\N	2017-07-20 11:45:25	2017-09-24 17:47:27
27713	MEMBRE	2017-10-18 00:00:00	2017-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	24280	\N	2017-10-18 15:57:17	2017-11-28 16:55:40
27714	MEMBRE	2017-10-16 00:00:00	2018-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	24281	\N	2017-10-18 16:05:47	2018-01-19 10:24:52
27715	MEMBRE	2017-10-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24282	\N	2017-10-18 16:23:39	\N
27716	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24283	\N	2017-10-18 16:24:18	\N
27717	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24284	\N	2017-10-18 16:24:18	\N
27718	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24285	\N	2017-10-18 16:24:18	\N
27719	MEMBRE	2017-10-17 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24286	\N	2017-10-18 16:24:18	2018-01-24 15:30:18
27720	MEMBRE	2017-10-17 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	24287	\N	2017-10-18 16:24:18	2018-02-07 15:30:32
27721	MEMBRE	2017-10-17 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	24288	\N	2017-10-18 16:24:18	2018-01-31 18:43:14
27722	MEMBRE	2017-10-17 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	24289	\N	2017-10-18 16:24:18	2018-02-07 16:35:32
27723	MEMBRE	2017-10-17 00:00:00	2017-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	24290	\N	2017-10-18 16:24:18	2017-11-28 16:58:44
27724	MEMBRE	2017-10-17 00:00:00	2018-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	24291	\N	2017-10-18 16:24:18	2018-01-16 19:10:54
27725	MEMBRE	2017-10-17 00:00:00	2018-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	24292	\N	2017-10-18 16:24:57	2018-02-01 18:33:01
27726	MEMBRE	2017-10-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24293	\N	2017-10-18 16:25:54	\N
27727	MEMBRE	2017-10-13 00:00:00	2018-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	24294	\N	2017-10-18 16:25:54	2018-02-12 15:25:30
27728	MEMBRE	2017-10-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24295	\N	2017-10-18 16:25:54	\N
27729	MEMBRE	2017-10-13 00:00:00	2018-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	24296	\N	2017-10-18 16:25:54	2018-02-12 16:56:20
27730	MEMBRE	2017-10-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24297	\N	2017-10-18 16:25:54	\N
27731	MEMBRE	2017-10-13 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24298	\N	2017-10-18 16:25:54	2018-01-24 15:04:54
27732	MEMBRE	2017-10-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24299	\N	2017-10-18 16:25:54	\N
27733	MEMBRE	2017-10-13 00:00:00	2018-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	24300	\N	2017-10-18 16:25:54	2018-01-26 10:35:03
27734	MEMBRE	2017-10-13 00:00:00	2017-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	24301	\N	2017-10-18 16:25:54	2017-12-05 10:07:43
27735	MEMBRE	2017-10-13 00:00:00	2017-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	24302	\N	2017-10-18 16:25:54	2017-12-19 18:18:20
27736	MEMBRE	2017-10-13 00:00:00	2018-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	24303	\N	2017-10-18 16:25:54	2018-01-16 18:57:26
27737	MEMBRE	2017-10-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24304	\N	2017-10-18 16:25:54	\N
27738	MEMBRE	2017-10-13 00:00:00	2017-12-11 00:00:00	ANCIEN	\N	\N	\N	\N	24305	\N	2017-10-18 16:25:54	2017-12-12 17:21:19
27739	MEMBRE	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24306	\N	2017-10-18 16:26:20	\N
27740	MEMBRE	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24307	\N	2017-10-18 16:26:20	\N
27741	MEMBRE	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24308	\N	2017-10-18 16:26:20	\N
27742	MEMBRE	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24309	\N	2017-10-18 16:26:20	\N
27743	MEMBRE	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24310	\N	2017-10-18 16:26:20	\N
27744	MEMBRE	2017-10-12 00:00:00	2017-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	24311	\N	2017-10-18 16:26:20	2017-12-05 10:06:37
27745	MEMBRE	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24312	\N	2017-10-18 16:27:27	\N
27746	MEMBRE	2017-10-12 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	24313	\N	2017-10-18 16:27:54	2018-01-25 15:20:16
27747	MEMBRE	2017-10-12 00:00:00	2018-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	24314	\N	2017-10-18 16:27:54	2018-02-15 10:19:41
27748	MEMBRE	2017-10-10 00:00:00	2018-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	24315	\N	2017-10-18 16:28:53	2018-02-14 12:54:05
27749	MEMBRE	2017-10-10 00:00:00	2017-12-11 00:00:00	ANCIEN	\N	\N	\N	\N	24316	\N	2017-10-18 16:28:53	2017-12-12 17:28:15
27750	MEMBRE	2017-10-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24317	\N	2017-10-18 16:28:53	\N
27751	MEMBRE	2017-10-10 00:00:00	2018-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	24318	\N	2017-10-18 16:28:53	2018-01-29 16:17:05
27752	MEMBRE	2017-10-17 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24319	\N	2017-10-18 16:29:09	2018-01-24 17:30:07
27753	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24320	\N	2017-10-18 16:30:02	\N
27754	MEMBRE	2017-10-17 00:00:00	2018-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	24321	\N	2017-10-18 16:30:02	2018-03-06 12:10:25
27755	MEMBRE	2017-10-17 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	24322	\N	2017-10-18 16:30:02	2018-02-07 15:32:37
27756	MEMBRE	2017-10-17 00:00:00	2018-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	24323	\N	2017-10-18 16:30:02	2018-01-17 11:30:32
27757	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24324	\N	2017-10-18 16:30:02	\N
27758	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24325	\N	2017-10-18 16:30:25	\N
27759	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24326	\N	2017-10-18 16:30:25	\N
27760	MEMBRE	2017-10-17 00:00:00	2017-12-11 00:00:00	ANCIEN	\N	\N	\N	\N	24327	\N	2017-10-18 16:30:44	2017-12-12 17:26:00
27761	MEMBRE	2017-10-18 00:00:00	2018-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	24328	\N	2017-10-18 16:39:31	2018-01-26 10:34:42
27762	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24329	\N	2017-10-18 17:43:40	\N
27763	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24330	\N	2017-10-18 17:43:40	\N
27764	MEMBRE	2017-10-17 00:00:00	2017-10-19 00:00:00	ANCIEN	\N	\N	\N	\N	24331	\N	2017-10-18 17:43:40	2017-10-19 16:44:45
27765	MEMBRE	2017-10-17 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24332	\N	2017-10-18 17:43:40	2018-01-24 17:19:07
27766	MEMBRE	2017-10-17 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	24333	\N	2017-10-18 17:43:40	\N
27767	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24334	\N	2017-10-18 17:43:40	\N
27768	MEMBRE	2017-10-17 00:00:00	2017-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	24335	\N	2017-10-18 17:43:40	2017-11-28 16:59:37
27769	MEMBRE	2017-10-18 00:00:00	2018-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	24336	\N	2017-10-18 17:44:23	\N
27770	MEMBRE	2017-10-18 00:00:00	2018-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	24337	\N	2017-10-18 17:44:23	\N
27771	MEMBRE	2017-10-18 00:00:00	2017-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	24338	\N	2017-10-18 17:44:23	2017-12-14 15:43:04
27772	MEMBRE	2017-10-18 00:00:00	2018-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	24339	\N	2017-10-18 17:44:23	\N
27773	MEMBRE	2017-10-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24340	\N	2017-10-18 17:45:06	\N
27774	MEMBRE	2017-10-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24341	\N	2017-10-18 17:45:06	\N
27775	MEMBRE	2017-10-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24342	\N	2017-10-18 17:45:06	\N
27776	MEMBRE	2017-10-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24343	\N	2017-10-18 17:45:06	\N
22390	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20334	\N	2014-10-15 09:39:30	\N
22391	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20335	\N	2014-10-15 09:39:31	\N
22392	MEMBRE	2014-10-14 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	20336	\N	2014-10-15 09:39:55	2015-02-13 11:33:34
22393	MEMBRE	2014-10-14 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	20337	\N	2014-10-15 09:40:13	2015-02-03 16:20:02
22394	MEMBRE	2014-10-14 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	20338	\N	2014-10-15 09:40:28	2015-02-13 11:37:59
22395	MEMBRE	2014-10-14 00:00:00	2015-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	20339	\N	2014-10-15 09:40:28	2015-01-28 09:39:28
22396	MEMBRE	2014-10-14 00:00:00	2015-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	20340	\N	2014-10-15 09:40:28	2015-01-30 09:39:25
22397	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20341	\N	2014-10-15 09:40:46	\N
22398	MEMBRE	2014-10-14 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	20342	\N	2014-10-15 09:40:46	2015-01-06 16:29:54
22399	MEMBRE	2014-10-14 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	20343	\N	2014-10-15 09:40:46	2015-02-19 17:23:17
22400	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20344	\N	2014-10-15 09:40:46	\N
22401	MEMBRE	2014-10-14 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	20345	\N	2014-10-15 09:40:58	2015-02-05 18:52:17
22402	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20346	\N	2014-10-15 09:41:11	\N
22403	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20347	\N	2014-10-15 09:41:11	\N
22404	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20348	\N	2014-10-15 09:41:11	\N
22405	MEMBRE	2014-10-14 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	20349	\N	2014-10-15 09:41:11	2015-02-11 18:02:00
22406	MEMBRE	2014-10-14 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	20350	\N	2014-10-15 09:52:15	2015-02-20 10:44:01
22407	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20351	\N	2014-10-15 09:52:15	\N
22408	MEMBRE	2014-10-14 00:00:00	2015-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	20352	\N	2014-10-15 09:52:15	2015-02-09 15:46:55
22409	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20353	\N	2014-10-15 10:19:41	\N
22410	MEMBRE	2014-10-14 00:00:00	2015-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	20354	\N	2014-10-15 10:21:30	2015-02-09 15:46:37
22411	MEMBRE	2014-10-14 00:00:00	2015-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	20355	\N	2014-10-15 10:21:30	2015-03-04 10:25:37
22412	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20356	\N	2014-10-15 10:21:30	\N
23581	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21492	\N	2014-10-29 13:30:48	\N
23582	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21493	\N	2014-10-29 13:30:48	\N
23583	MEMBRE	2014-10-29 00:00:00	2015-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	21494	\N	2014-10-29 13:30:48	2015-07-08 09:36:39
23584	MEMBRE	2014-10-29 00:00:00	2015-06-24 00:00:00	ANCIEN	\N	\N	\N	\N	21495	\N	2014-10-29 13:30:48	2015-06-24 12:06:17
23585	MEMBRE	2014-10-29 00:00:00	2016-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	21496	\N	2014-10-29 13:30:48	2016-02-03 11:35:08
23586	MEMBRE	2014-10-29 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	21497	\N	2014-10-29 13:30:48	2015-02-09 11:12:01
24005	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21916	\N	2014-10-31 14:45:14	\N
24006	MEMBRE	2014-10-28 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21917	\N	2014-10-31 14:45:14	2015-01-06 16:06:24
24007	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21918	\N	2014-10-31 14:45:14	\N
24008	MEMBRE	2014-10-28 00:00:00	2015-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	21919	\N	2014-10-31 14:45:14	2015-02-16 17:42:17
24009	MEMBRE	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21920	\N	2014-10-31 14:45:14	\N
24010	MEMBRE	2014-10-28 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21921	\N	2014-10-31 14:45:14	2015-01-06 15:37:40
24011	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21922	\N	2014-10-31 15:08:08	\N
24012	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21923	\N	2014-10-31 15:08:08	\N
24013	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21924	\N	2014-10-31 15:08:08	\N
24014	MEMBRE	2014-10-31 00:00:00	2015-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	21925	\N	2014-10-31 15:08:08	2015-02-16 17:42:42
24015	MEMBRE	2014-10-31 00:00:00	2015-04-09 00:00:00	ANCIEN	\N	\N	\N	\N	21926	\N	2014-10-31 15:08:08	2015-04-10 15:10:26
24016	MEMBRE	2014-10-31 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21927	\N	2014-10-31 15:19:13	2015-01-06 16:18:57
24017	MEMBRE	2014-10-31 00:00:00	2015-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	21928	\N	2014-10-31 15:19:13	2015-02-06 16:56:58
24018	MEMBRE	2014-10-31 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	21929	\N	2014-10-31 15:19:13	2015-02-11 12:10:59
24019	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21930	\N	2014-10-31 15:19:13	\N
24020	MEMBRE	2014-10-31 00:00:00	2015-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	21931	\N	2014-10-31 15:19:13	2015-02-16 17:41:35
24021	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21932	\N	2014-10-31 15:19:13	\N
24022	MEMBRE	2014-10-31 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	21933	\N	2014-10-31 15:19:13	2015-02-13 09:50:31
24325	MEMBRE	2014-11-07 00:00:00	2015-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	22232	\N	2014-11-18 10:20:50	2015-02-23 11:39:42
24715	MEMBRE	2015-01-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22409	\N	2015-01-22 16:33:13	2015-01-22 17:04:47
24716	PDT	2015-01-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22409	1	2015-01-22 16:33:23	2015-02-20 12:17:12
24717	PDTDEL	2015-01-22 00:00:00	2015-01-30 00:00:00	ANCIEN	\N	\N	pour le Pérou	\N	22437	5	2015-01-22 16:35:48	2015-01-30 15:27:04
26300	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23183	\N	\N	\N
26491	SECRET	2015-05-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22601	\N	\N	2017-09-24 18:16:52
26492	SECRET	2015-05-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	22599	\N	\N	\N
26633	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23382	\N	\N	\N
26707	PDT	2015-06-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	23114	\N	\N	\N
26708	VICPDT	2015-06-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22625	\N	\N	2017-09-24 13:25:54
26709	VICPDT	2015-06-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	22628	\N	\N	\N
26710	SECRET	2015-06-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	23113	\N	\N	\N
26946	MEMBRE	2016-06-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23646	\N	2016-06-09 16:37:12	2017-09-24 17:47:28
26947	MEMBRE	2016-05-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23647	\N	2016-06-10 17:40:03	\N
26967	MEMBRE	2016-06-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	23667	\N	\N	\N
26968	MEMBRE	2016-06-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	23668	\N	\N	\N
27016	MEMBRE	2016-06-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	23714	\N	\N	\N
27017	MEMBRE	2016-06-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	23715	\N	\N	\N
27027	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23725	\N	\N	\N
27028	MEMBRE	2014-10-01 00:00:00	2017-07-28 00:00:00	ANCIEN	\N	\N	\N	\N	23726	\N	\N	2017-08-03 11:38:41
27029	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23727	\N	\N	\N
27031	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23729	\N	\N	\N
27032	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23730	\N	\N	\N
27033	MEMBRE	2014-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23731	\N	\N	2017-10-01 09:41:22
27034	MEMBRE	2014-10-01 00:00:00	2016-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	23732	\N	\N	2016-12-01 10:36:52
27035	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23733	\N	\N	\N
27036	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23734	\N	\N	2017-09-24 17:47:27
27037	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23735	\N	\N	2017-09-25 10:58:49
27039	MEMBRE	2014-10-01 00:00:00	2017-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	23737	\N	\N	2017-07-24 09:58:00
27040	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23738	\N	\N	\N
27041	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23739	\N	\N	2017-09-24 18:49:56
27042	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23740	\N	\N	\N
27043	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23741	\N	\N	2017-09-24 13:14:55
27044	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23742	\N	\N	\N
27045	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23743	\N	\N	\N
27046	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23744	\N	\N	\N
27047	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23745	\N	\N	2017-09-24 17:06:55
27048	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23746	\N	\N	\N
27049	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23747	\N	\N	\N
27069	MEMBRE	2016-10-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23761	\N	2016-10-27 15:50:42	\N
27085	MEMBRE	2016-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23777	\N	\N	\N
27096	MEMBRE	2016-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23788	\N	\N	\N
27103	MEMBRE	2016-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23795	\N	\N	\N
27124	MEMBRE	2016-11-21 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	23816	\N	2016-11-21 16:06:13	\N
27125	MEMBRE	2016-11-21 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	23817	\N	2016-11-21 16:06:34	\N
27134	VICPDT	2016-12-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22244	\N	2016-12-07 16:35:49	2016-12-07 16:37:12
27137	VICPDT	2016-12-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21006	\N	2016-12-07 16:39:48	\N
27136	SECRET	2016-12-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21313	\N	2016-12-07 16:39:03	2017-09-24 17:18:03
27138	SECRET	2016-12-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20542	\N	2016-12-07 16:40:05	2017-09-24 17:35:15
27139	SECRET	2016-12-07 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	21418	\N	2016-12-07 16:40:32	2017-05-16 15:18:14
27140	SECRET	2016-12-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20295	\N	2016-12-07 16:40:45	2017-09-24 18:59:59
27141	VICPDT	2016-12-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21645	\N	2016-12-07 16:41:07	2017-09-24 13:44:49
27142	SECRET	2016-12-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20945	\N	2016-12-07 16:41:20	\N
27143	SECRET	2016-12-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21545	\N	2016-12-07 16:41:32	2017-09-24 18:20:10
27144	SECRET	2016-12-07 00:00:00	2016-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20661	\N	2016-12-07 16:41:46	2017-01-03 11:09:24
27145	VICPDT	2016-12-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21737	\N	2016-12-07 16:42:05	2017-09-24 17:47:28
27146	SECRET	2016-12-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21602	\N	2016-12-07 16:42:17	2017-09-24 13:57:40
27147	SECRET	2016-12-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21672	\N	2016-12-07 16:42:27	\N
27148	VICPDT	2016-12-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20952	\N	2016-12-07 16:42:38	\N
27149	SECRET	2016-12-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22339	\N	2016-12-07 16:42:59	\N
27150	SECRET	2016-12-07 00:00:00	2017-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	20859	\N	2016-12-07 16:43:15	2017-07-04 15:08:09
27151	SECRET	2016-12-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20712	\N	2016-12-07 16:43:22	\N
25675	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22859	\N	\N	\N
25676	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22860	\N	\N	\N
25677	MEMBRE	2014-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22861	\N	\N	2017-10-01 10:34:22
25678	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22862	\N	\N	2017-09-24 17:42:26
25680	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22864	\N	\N	\N
25681	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22865	\N	\N	\N
25689	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22872	\N	\N	\N
25683	MEMBRE	2015-02-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22867	\N	2015-02-19 10:02:17	\N
25684	MEMBRE	2015-02-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22868	\N	2015-02-19 10:02:17	\N
25685	MEMBRE	2015-02-18 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22869	\N	2015-02-19 10:02:28	\N
25687	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22870	\N	\N	\N
25690	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22873	\N	\N	2017-09-24 17:42:26
25691	MEMBRE	2014-10-01 00:00:00	2015-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	22874	\N	\N	\N
25692	MEMBRE	2014-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22875	\N	\N	2017-10-01 10:20:50
25693	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22876	\N	\N	\N
25694	MEMBRE	2014-10-01 00:00:00	2015-04-15 00:00:00	ANCIEN	\N	\N	\N	\N	22877	\N	\N	\N
25928	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22987	\N	\N	\N
26001	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23061	\N	\N	\N
26002	MEMBRE	2014-10-01 00:00:00	2016-01-11 00:00:00	ANCIEN	\N	\N	\N	\N	23062	\N	\N	2016-01-11 17:34:09
26004	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23064	\N	\N	2017-09-24 17:14:27
26006	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23066	\N	\N	2017-09-25 10:58:49
26007	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23067	\N	\N	2017-09-24 17:14:27
26008	MEMBRE	2015-02-19 00:00:00	2015-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	23068	\N	2015-03-03 17:42:47	2015-03-03 17:44:06
26092	SECRET	2015-03-04 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	23030	\N	\N	2016-12-12 16:10:15
26131	MEMBRE	2015-01-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	23116	\N	\N	\N
26407	MEMBRE	2014-10-01 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	23246	\N	\N	2016-12-12 16:10:15
26513	MEMBRE	2014-10-01 00:00:00	2017-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	23288	\N	\N	2017-07-24 09:56:26
26663	MEMBRE	2015-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23401	\N	\N	\N
26689	MEMBRE	2015-11-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23421	\N	2015-11-06 16:52:53	2017-09-24 18:07:57
26891	MEMBRE	2016-03-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23601	\N	2016-03-31 09:41:21	\N
28713	MEMBRE	2017-11-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25280	\N	2017-11-16 15:05:42	\N
28714	MEMBRE	2017-11-14 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	25281	\N	2017-11-16 15:06:01	2018-02-07 15:31:09
27009	MEMBRE	2016-06-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23707	\N	2016-06-16 16:22:19	\N
28715	MEMBRE	2017-11-14 00:00:00	2017-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	25282	\N	2017-11-16 15:06:01	2017-11-28 16:53:14
28716	MEMBRE	2017-11-14 00:00:00	2017-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	25283	\N	2017-11-16 15:06:01	2017-12-06 11:35:18
28717	MEMBRE	2017-11-15 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	25284	\N	2017-11-16 15:06:21	2018-01-25 16:04:34
28718	MEMBRE	2017-11-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25285	\N	2017-11-16 15:06:22	\N
28835	MEMBRE	2017-11-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25402	\N	2017-11-23 09:41:31	\N
28836	MEMBRE	2017-11-22 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	25403	\N	2017-11-23 09:41:31	2018-01-24 17:30:20
28837	MEMBRE	2017-11-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25404	\N	2017-11-23 09:41:31	\N
28838	MEMBRE	2017-11-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25405	\N	2017-11-23 09:46:23	\N
28839	MEMBRE	2017-11-21 00:00:00	2017-12-26 00:00:00	ANCIEN	\N	\N	\N	\N	25406	\N	2017-11-23 09:46:23	2017-12-27 11:10:24
28840	MEMBRE	2017-11-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25407	\N	2017-11-23 09:46:41	\N
28841	MEMBRE	2017-11-21 00:00:00	2017-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	25408	\N	2017-11-23 09:48:56	2017-12-19 18:18:27
29244	PDTDEL	2017-12-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Ouzbékistan	\N	25645	\N	2017-12-15 17:03:52	2017-12-15 17:08:03
29383	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25725	\N	\N	\N
29467	PDTDEL	2018-01-11 00:00:00	2020-06-27 00:00:00	ANCIEN	\N	\N	Géorgie	\N	25625	\N	2018-01-11 18:28:24	2018-01-11 18:28:44
29774	SECRET	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24213	\N	2018-01-18 18:10:53	\N
29775	SECRET	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24894	\N	2018-01-18 18:22:50	\N
29776	VICPDT	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24620	\N	2018-01-18 18:22:56	\N
29777	VICPDT	2018-01-18 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	24511	\N	2018-01-18 18:23:01	\N
29778	SECRET	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24000	\N	2018-01-18 18:23:11	\N
29779	VICPDT	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24665	\N	2018-01-18 18:23:15	\N
29780	VICPDT	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24356	\N	2018-01-18 18:23:21	\N
29781	VICPDT	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25102	\N	2018-01-18 18:23:27	\N
29782	VICPDT	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24366	\N	2018-01-18 18:23:32	\N
29783	VICPDT	2018-01-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24065	\N	2018-01-18 18:23:39	\N
29795	MEMBRE	2018-01-16 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	25967	\N	2018-01-19 13:34:43	2018-01-23 17:48:42
29796	MEMBRE	2018-01-16 00:00:00	2018-01-21 00:00:00	ANCIEN	\N	\N	\N	\N	25968	\N	2018-01-19 13:34:43	2018-01-22 15:32:06
29797	MEMBRE	2017-10-01 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	25969	\N	\N	\N
29799	MEMBRE	2017-10-01 00:00:00	2018-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	25971	\N	\N	\N
29800	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25972	\N	\N	\N
29801	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25973	\N	\N	\N
29803	MEMBRE	2017-10-01 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	25975	\N	\N	\N
29804	MEMBRE	2018-01-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25976	\N	2018-01-22 11:40:31	\N
29805	MEMBRE	2018-01-18 00:00:00	2018-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	25977	\N	2018-01-22 11:42:15	2018-02-08 16:42:57
29806	MEMBRE	2018-01-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25978	\N	2018-01-22 11:53:25	\N
29807	PDTDEL	2018-01-22 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	Ethiopie	\N	25958	\N	2018-01-22 11:59:03	2018-01-22 11:59:16
29811	PDT	2018-01-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25793	\N	2018-01-22 16:08:44	\N
29879	VICPDT	2018-01-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24345	\N	2018-01-24 10:39:46	2018-01-24 18:16:41
29817	PDTDEL	2018-01-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Burundi	\N	25984	\N	2018-01-23 12:25:45	2018-01-23 12:26:43
29818	PDT	2018-01-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	25724	\N	\N	\N
29821	VICPDT	2018-01-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	25723	\N	\N	\N
29822	VICPDT	2018-01-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	25718	\N	\N	\N
29823	VICPDT	2018-01-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	25759	\N	\N	\N
29825	VICPDT	2018-01-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25716	\N	\N	\N
29826	SECRET	2018-01-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	25707	\N	\N	\N
29827	SECRET	2018-01-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	25975	\N	\N	\N
29830	SECRET	2018-01-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	25712	\N	\N	\N
29831	SECRET	2018-01-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25709	\N	\N	\N
29836	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25986	\N	\N	\N
29880	VICPDT	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24227	\N	2018-01-24 10:40:39	\N
29881	VICPDT	2018-01-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25227	\N	2018-01-24 10:40:53	\N
29882	VICPDT	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24426	\N	2018-01-24 10:41:50	\N
29883	VICPDT	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25466	\N	2018-01-24 10:41:58	\N
29884	VICPDT	2018-01-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25219	\N	2018-01-24 10:42:12	\N
29885	VICPDT	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24947	\N	2018-01-24 10:42:32	2018-01-24 18:16:48
29886	SECRET	2018-01-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24360	\N	2018-01-24 10:43:18	\N
29887	SECRET	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25435	\N	2018-01-24 10:43:23	\N
29890	VICPDT	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24143	\N	2018-01-24 10:52:25	\N
29891	VICPDT	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25644	\N	2018-01-24 10:52:33	\N
29892	VICPDT	2018-01-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23951	\N	2018-01-24 10:52:44	\N
29893	SECRET	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23941	\N	2018-01-24 10:52:51	\N
29894	SECRET	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24184	\N	2018-01-24 10:52:58	\N
29895	SECRET	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25751	\N	2018-01-24 11:13:02	\N
29896	SECRET	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24226	\N	2018-01-24 11:13:29	\N
29897	SECRET	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23966	\N	2018-01-24 11:13:41	\N
29898	VICPDT	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25130	\N	2018-01-24 11:13:54	\N
29899	VICPDT	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24448	\N	2018-01-24 11:14:09	\N
29900	VICPDT	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24183	\N	2018-01-24 11:14:30	\N
29901	VICPDT	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24403	\N	2018-01-24 11:14:52	\N
29902	SECRET	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24746	\N	2018-01-24 11:15:02	\N
29903	VICPDT	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23871	\N	2018-01-24 11:15:16	\N
29904	VICPDT	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24198	\N	2018-01-24 11:15:28	\N
29905	VICPDT	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24427	\N	2018-01-24 11:38:58	\N
29906	VICPDT	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25950	\N	2018-01-24 11:39:04	\N
29907	MEMBRE	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25989	\N	2018-01-24 11:40:14	\N
29908	MEMBRE	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25990	\N	2018-01-24 11:44:04	\N
29910	MEMBRE	2018-01-24 00:00:00	2018-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	25992	\N	2018-01-24 11:46:37	2018-01-30 12:28:52
29911	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25993	\N	\N	\N
29912	MEMBRE	2017-10-01 00:00:00	2020-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	25994	\N	\N	\N
24081	MEMBRE	2014-10-31 00:00:00	2014-12-27 00:00:00	ANCIEN	\N	\N	\N	\N	21992	\N	2014-10-31 18:02:46	2014-12-29 15:40:09
24098	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22009	\N	2014-11-03 13:43:34	\N
24076	MEMBRE	2014-10-31 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21987	\N	2014-10-31 17:53:27	2015-01-06 15:36:49
24077	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21988	\N	2014-10-31 17:53:27	\N
24078	MEMBRE	2014-10-31 00:00:00	2015-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	21989	\N	2014-10-31 17:53:27	2015-02-12 12:42:44
24079	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21990	\N	2014-10-31 17:53:27	\N
24080	MEMBRE	2014-10-31 00:00:00	2014-12-27 00:00:00	ANCIEN	\N	\N	\N	\N	21991	\N	2014-10-31 18:02:46	2014-12-29 15:40:09
24099	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22010	\N	2014-11-03 13:43:35	\N
24100	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22011	\N	2014-11-03 13:43:35	\N
24101	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22012	\N	2014-11-03 13:43:35	\N
24102	MEMBRE	2014-10-31 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	22013	\N	2014-11-03 14:38:21	2015-02-11 16:39:07
24103	MEMBRE	2014-10-31 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	22014	\N	2014-11-03 14:38:21	2015-02-05 12:17:22
24104	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22015	\N	2014-11-03 14:38:21	\N
24105	MEMBRE	2014-10-31 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	22016	\N	2014-11-03 14:38:21	2015-01-06 17:17:14
24106	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22017	\N	2014-11-03 14:38:21	\N
24107	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22018	\N	2014-11-03 14:38:21	\N
24108	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22019	\N	2014-11-03 14:38:21	\N
24109	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22020	\N	2014-11-03 14:38:21	\N
24110	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22021	\N	2014-11-03 14:38:21	\N
24111	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22022	\N	2014-11-03 14:38:21	\N
24112	MEMBRE	2014-10-31 00:00:00	2015-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	22023	\N	2014-11-03 14:38:21	2015-01-13 15:51:26
24113	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22024	\N	2014-11-03 14:38:21	\N
24114	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22025	\N	2014-11-03 14:38:21	\N
24115	MEMBRE	2014-10-31 00:00:00	2015-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	22026	\N	2014-11-03 14:38:21	2015-03-06 09:53:01
24116	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22027	\N	2014-11-03 14:38:21	\N
24117	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22028	\N	2014-11-03 14:38:21	\N
24118	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22029	\N	2014-11-03 14:38:21	\N
24119	MEMBRE	2014-10-31 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	22030	\N	2014-11-03 14:38:21	2015-02-13 17:04:11
24120	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22031	\N	2014-11-03 14:38:22	\N
24121	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22032	\N	2014-11-03 14:38:22	\N
24122	MEMBRE	2014-10-31 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	22033	\N	2014-11-03 14:38:22	2015-02-13 11:37:45
24123	MEMBRE	2014-10-31 00:00:00	2015-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	22034	\N	2014-11-03 14:38:22	2015-02-12 17:35:59
24124	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22035	\N	2014-11-03 14:38:22	\N
24125	MEMBRE	2014-10-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22036	\N	2014-11-03 14:38:22	\N
24591	MEMBRE	2015-01-12 00:00:00	2015-03-21 00:00:00	ANCIEN	\N	\N	\N	\N	22376	\N	2015-01-13 09:23:58	2015-11-12 15:26:22
24665	MEMBRE	2015-01-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22404	\N	2015-01-19 17:41:50	\N
25112	MEMBRE	2015-02-04 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22530	\N	2015-02-10 15:53:33	\N
25929	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22988	\N	\N	\N
25932	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22991	\N	\N	2017-09-25 10:54:33
26084	VICPDT	2015-03-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	17036	\N	\N	\N
26088	VICPDT	2015-03-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	23025	\N	\N	\N
26094	PDT	2015-03-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	23003	\N	\N	\N
26096	VICPDT	2015-03-04 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22998	\N	\N	2017-10-01 10:34:22
26097	VICPDT	2015-03-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	23013	\N	\N	\N
26098	SECRET	2015-03-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	23011	\N	\N	\N
26099	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23097	\N	\N	\N
26101	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23099	\N	\N	2017-09-24 16:45:26
26102	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23100	\N	\N	\N
26103	MEMBRE	2014-10-01 00:00:00	2014-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	23101	\N	\N	\N
26519	MEMBRE	2015-06-25 00:00:00	2015-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	23294	\N	2015-06-26 10:19:06	2015-07-09 15:07:31
26635	MEMBRE	2015-08-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23384	\N	2015-08-10 16:09:13	\N
27128	MEMBRE	2016-11-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23819	\N	2016-12-01 12:19:58	\N
27129	MEMBRE	2016-11-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23820	\N	2016-12-01 12:19:58	\N
28390	MEMBRE	2017-10-30 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	24957	\N	2017-10-31 17:35:15	2018-01-18 18:09:57
28391	MEMBRE	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24958	\N	2017-10-31 17:35:15	\N
28392	MEMBRE	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24959	\N	2017-10-31 17:35:15	\N
28393	MEMBRE	2017-10-30 00:00:00	2017-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	24960	\N	2017-10-31 17:35:15	2017-12-19 18:17:51
28394	MEMBRE	2017-10-30 00:00:00	2018-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	24961	\N	2017-10-31 17:35:15	2018-02-21 15:39:34
28395	MEMBRE	2017-10-31 00:00:00	2018-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	24962	\N	2017-10-31 18:02:18	2018-01-26 10:16:46
28396	MEMBRE	2017-10-31 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	24963	\N	2017-10-31 18:02:18	2017-12-20 16:56:28
28397	MEMBRE	2017-10-31 00:00:00	2018-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	24964	\N	2017-10-31 18:02:18	2018-01-26 16:18:34
28398	MEMBRE	2017-10-31 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	24965	\N	2017-10-31 18:02:18	2018-01-23 17:24:08
28399	MEMBRE	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24966	\N	2017-10-31 18:02:18	\N
28400	MEMBRE	2017-10-31 00:00:00	2017-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	24967	\N	2017-10-31 18:02:18	2017-11-27 16:37:53
28401	MEMBRE	2017-10-31 00:00:00	2018-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	24968	\N	2017-10-31 18:02:18	2018-01-16 18:57:07
28402	MEMBRE	2017-10-31 00:00:00	2018-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	24969	\N	2017-10-31 18:02:18	2018-01-16 19:11:11
28403	MEMBRE	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24970	\N	2017-10-31 18:02:18	\N
28404	MEMBRE	2017-10-31 00:00:00	2018-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	24971	\N	2017-10-31 18:02:53	2018-02-01 18:31:41
28405	MEMBRE	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24972	\N	2017-10-31 18:02:53	\N
28533	MEMBRE	2017-10-10 00:00:00	2018-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	25100	\N	2017-11-06 16:40:54	\N
28534	MEMBRE	2017-10-10 00:00:00	2017-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	25101	\N	2017-11-06 16:40:54	2017-11-30 11:15:25
28535	MEMBRE	2017-10-31 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	25102	\N	2017-11-06 17:04:34	2018-01-18 18:23:27
28536	MEMBRE	2017-10-31 00:00:00	2018-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	25103	\N	2017-11-06 17:04:34	2018-02-01 17:48:39
28537	MEMBRE	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25104	\N	2017-11-06 17:04:34	\N
28538	MEMBRE	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25105	\N	2017-11-06 17:04:34	\N
28539	MEMBRE	2017-10-31 00:00:00	2018-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	25106	\N	2017-11-06 17:04:34	2018-01-19 10:25:11
28540	MEMBRE	2017-10-31 00:00:00	2017-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	25107	\N	2017-11-06 17:04:34	2017-12-05 16:35:32
32830	MEMBRE	2020-10-20 00:00:00	2020-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	28263	\N	\N	\N
28894	MEMBRE	2017-11-24 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	25461	\N	2017-11-24 18:15:26	2018-01-24 15:54:59
28895	MEMBRE	2017-11-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25462	\N	2017-11-24 18:15:26	\N
29162	MEMBRE	2017-12-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25609	\N	2017-12-12 11:07:40	\N
29163	MEMBRE	2017-12-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25610	\N	2017-12-12 11:07:57	\N
29164	MEMBRE	2017-12-07 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	25611	\N	2017-12-12 11:08:27	2018-01-22 11:42:55
29366	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25708	\N	\N	\N
29367	MEMBRE	2017-10-01 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	25709	\N	\N	\N
29368	MEMBRE	2017-10-01 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	25710	\N	\N	\N
29369	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25711	\N	\N	\N
29370	MEMBRE	2017-10-01 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	25712	\N	\N	\N
29371	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25713	\N	\N	\N
29373	MEMBRE	2017-10-01 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	25715	\N	\N	\N
29375	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25717	\N	\N	\N
29376	MEMBRE	2017-10-01 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	25718	\N	\N	\N
29377	MEMBRE	2017-10-01 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	25719	\N	\N	\N
29378	MEMBRE	2017-10-01 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	25720	\N	\N	\N
29379	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25721	\N	\N	\N
29380	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25722	\N	\N	\N
29382	MEMBRE	2017-10-01 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	25724	\N	\N	\N
29405	MEMBRE	2017-12-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	25747	\N	\N	\N
29456	MEMBRE	2018-01-05 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	25783	\N	2018-01-05 11:41:19	\N
29482	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25808	\N	\N	\N
29495	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25821	\N	\N	\N
29498	MEMBRE	2018-01-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25824	\N	2018-01-16 14:49:59	\N
29500	MEMBRE	2018-01-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25826	\N	2018-01-16 14:58:17	\N
29571	VICPDT	2018-01-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24436	\N	2018-01-16 19:07:57	\N
29572	VICPDT	2018-01-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23967	\N	2018-01-16 19:08:09	\N
29573	VICPDT	2018-01-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24678	\N	2018-01-16 19:08:16	\N
29574	VICPDT	2018-01-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25196	\N	2018-01-16 19:08:26	\N
29575	VICPDT	2018-01-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24275	\N	2018-01-16 19:08:41	\N
29576	VICPDT	2018-01-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24031	\N	2018-01-16 19:08:47	\N
29577	SECRET	2018-01-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24900	\N	2018-01-16 19:08:57	\N
25985	MEMBRE	2015-03-02 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23046	\N	2015-03-03 13:58:22	\N
26222	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23165	\N	\N	2017-09-24 17:47:27
26290	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23176	\N	\N	\N
26291	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23177	\N	\N	\N
26299	MEMBRE	2015-04-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23182	\N	2015-04-02 17:39:51	\N
26303	MEMBRE	2015-04-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23186	\N	2015-04-03 10:02:30	\N
26314	MEMBRE	2015-04-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23192	\N	2015-04-08 17:57:06	\N
26469	MEMBRE	2015-05-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23274	\N	2015-05-22 15:24:39	\N
26705	MEMBRE	2015-12-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23433	\N	2015-12-03 13:46:25	\N
26706	MEMBRE	2015-12-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23434	\N	2015-12-03 15:11:15	\N
27030	MEMBRE	2014-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23728	\N	\N	2017-10-01 10:34:22
27074	MEMBRE	2016-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23766	\N	\N	\N
27076	MEMBRE	2016-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23768	\N	\N	\N
27086	MEMBRE	2016-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23778	\N	\N	\N
27089	MEMBRE	2016-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23781	\N	\N	\N
27090	MEMBRE	2016-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23782	\N	\N	\N
27091	MEMBRE	2016-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23783	\N	\N	2017-09-24 17:06:55
27094	MEMBRE	2016-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23786	\N	\N	2017-09-24 17:42:26
27095	MEMBRE	2016-10-01 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	23787	\N	\N	2017-06-19 16:06:51
27097	MEMBRE	2016-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23789	\N	\N	\N
27098	MEMBRE	2016-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23790	\N	\N	\N
27099	MEMBRE	2016-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23791	\N	\N	\N
27112	MEMBRE	2016-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23804	\N	\N	\N
27113	MEMBRE	2016-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23805	\N	\N	2017-10-01 09:22:38
27114	MEMBRE	2016-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23806	\N	\N	2017-09-24 17:09:24
27115	MEMBRE	2016-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23807	\N	\N	\N
27116	MEMBRE	2016-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23808	\N	\N	2017-09-24 17:35:15
27117	MEMBRE	2016-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23809	\N	\N	\N
27185	MEMBRE	2017-03-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23851	\N	2017-04-03 09:57:07	\N
27777	MEMBRE	2017-10-13 00:00:00	2017-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	24344	\N	2017-10-18 17:45:27	2017-11-28 17:05:31
27778	MEMBRE	2017-10-13 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24345	\N	2017-10-18 17:45:27	2018-01-24 10:39:46
27779	MEMBRE	2017-10-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24346	\N	2017-10-18 17:45:27	\N
27780	MEMBRE	2017-10-10 00:00:00	2018-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	24347	\N	2017-10-18 17:45:48	2018-01-30 12:30:37
27781	MEMBRE	2017-10-10 00:00:00	2017-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	24348	\N	2017-10-18 17:45:48	2017-12-19 18:04:14
27782	MEMBRE	2017-10-10 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	24349	\N	2017-10-18 17:45:48	2018-01-25 17:36:06
27783	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24350	\N	2017-10-18 17:45:48	\N
27784	MEMBRE	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24351	\N	2017-10-18 17:45:48	\N
27785	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24352	\N	2017-10-18 17:46:48	\N
27786	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24353	\N	2017-10-18 17:46:48	\N
27787	MEMBRE	2017-10-17 00:00:00	2017-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	24354	\N	2017-10-18 17:46:48	2017-12-19 18:05:37
27788	MEMBRE	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24355	\N	2017-10-18 17:46:48	\N
27789	MEMBRE	2017-10-17 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	24356	\N	2017-10-18 17:46:48	2018-01-18 18:23:21
28027	MEMBRE	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24594	\N	2017-10-25 12:28:03	\N
28028	MEMBRE	2017-10-25 00:00:00	2017-10-26 00:00:00	ANCIEN	\N	\N	\N	\N	24595	\N	2017-10-25 12:28:03	2017-10-31 18:09:28
28029	MEMBRE	2017-10-25 00:00:00	2017-10-26 00:00:00	ANCIEN	\N	\N	\N	\N	24596	\N	2017-10-25 12:28:03	2017-10-31 18:09:28
28030	MEMBRE	2017-10-25 00:00:00	2017-10-26 00:00:00	ANCIEN	\N	\N	\N	\N	24597	\N	2017-10-25 12:28:03	2017-10-31 18:09:28
28031	MEMBRE	2017-10-25 00:00:00	2017-10-26 00:00:00	ANCIEN	\N	\N	\N	\N	24598	\N	2017-10-25 12:28:04	2017-10-31 18:09:28
28032	MEMBRE	2017-10-25 00:00:00	2017-10-26 00:00:00	ANCIEN	\N	\N	\N	\N	24599	\N	2017-10-25 12:28:04	2017-10-31 18:09:28
28033	MEMBRE	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24600	\N	2017-10-25 12:28:04	\N
28034	MEMBRE	2017-10-25 00:00:00	2017-10-26 00:00:00	ANCIEN	\N	\N	\N	\N	24601	\N	2017-10-25 12:28:04	2017-10-31 18:09:28
28035	MEMBRE	2017-10-25 00:00:00	2017-10-26 00:00:00	ANCIEN	\N	\N	\N	\N	24602	\N	2017-10-25 12:28:04	2017-10-31 18:09:28
28036	MEMBRE	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24603	\N	2017-10-25 12:28:04	\N
28226	MEMBRE	2017-10-27 00:00:00	2018-03-04 00:00:00	ANCIEN	\N	\N	\N	\N	24793	\N	2017-10-27 16:19:38	2018-03-05 18:15:44
28227	MEMBRE	2017-10-27 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	24794	\N	2017-10-27 16:19:38	2018-02-07 15:32:29
28228	MEMBRE	2017-10-27 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	24795	\N	2017-10-27 16:19:38	2018-01-31 18:43:33
28229	MEMBRE	2017-10-27 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	24796	\N	2017-10-27 16:19:38	2018-01-25 10:58:04
28230	MEMBRE	2017-10-27 00:00:00	2018-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	24797	\N	2017-10-27 16:19:38	2018-01-16 19:10:41
28231	MEMBRE	2017-10-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24798	\N	2017-10-27 16:19:38	\N
28232	MEMBRE	2017-10-27 00:00:00	2018-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	24799	\N	2017-10-27 16:19:38	2018-02-15 10:19:18
28233	MEMBRE	2017-10-27 00:00:00	2017-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	24800	\N	2017-10-27 16:19:38	2017-11-30 16:37:13
28234	MEMBRE	2017-10-27 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	24801	\N	2017-10-27 16:19:38	2018-01-23 18:48:53
28235	MEMBRE	2017-10-27 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	24802	\N	2017-10-27 16:19:38	2018-01-18 17:50:02
28236	MEMBRE	2017-10-27 00:00:00	2018-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	24803	\N	2017-10-27 16:19:38	2018-02-14 18:33:09
28951	MEMBRE	2017-11-29 00:00:00	2017-12-11 00:00:00	ANCIEN	\N	\N	\N	\N	25484	\N	2017-11-29 11:56:06	2017-12-12 17:24:49
28953	MEMBRE	2017-11-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25486	\N	2017-11-29 14:41:35	\N
28954	MEMBRE	2017-11-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25487	\N	2017-11-29 14:42:15	\N
28955	MEMBRE	2017-11-27 00:00:00	2017-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	25488	\N	2017-11-29 14:42:42	2017-12-06 18:06:40
28956	MEMBRE	2017-11-29 00:00:00	2018-03-04 00:00:00	ANCIEN	\N	\N	\N	\N	25489	\N	2017-11-29 14:42:56	2018-03-05 18:14:52
28957	MEMBRE	2017-11-24 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	25490	\N	2017-11-29 14:43:15	\N
28958	MEMBRE	2017-11-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25491	\N	2017-11-29 14:43:31	\N
28959	MEMBRE	2017-11-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25492	\N	2017-11-29 14:43:31	\N
29192	PDTDEL	2017-12-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	Guinée équatoriale	\N	24525	\N	2017-12-13 15:45:01	2017-12-13 15:45:28
29195	MEMBRE	2017-12-12 00:00:00	2018-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	25622	\N	2017-12-14 11:33:16	2018-03-06 12:07:57
29196	MEMBRE	2017-12-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25623	\N	2017-12-14 11:33:46	\N
29197	MEMBRE	2017-12-12 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	25624	\N	2017-12-14 11:34:05	2018-01-18 16:36:06
29198	MEMBRE	2017-12-13 00:00:00	2018-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	25625	\N	2017-12-14 11:34:48	2018-01-11 18:28:24
29199	MEMBRE	2017-12-12 00:00:00	2020-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	25626	\N	2017-12-14 11:35:08	\N
29627	MEMBRE	2017-10-01 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	25888	\N	\N	\N
29628	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25889	\N	\N	\N
29629	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25890	\N	\N	\N
29636	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25897	\N	\N	\N
29638	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25899	\N	\N	\N
29639	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25900	\N	\N	\N
29640	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25901	\N	\N	\N
29749	MEMBRE	2018-01-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25965	\N	2018-01-18 17:48:27	\N
29943	VICPDT	2018-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	26020	\N	\N	\N
30032	VICPDTDEL	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Rwanda	\N	25991	\N	2018-01-25 09:44:18	2018-01-26 17:21:32
30033	MEMBRE	2017-12-12 00:00:00	2020-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	26039	\N	2018-01-25 09:51:52	\N
30034	MEMBRE	2017-12-12 00:00:00	2020-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	26040	\N	2018-01-25 09:51:52	\N
30035	MEMBRE	2018-01-18 00:00:00	2018-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	26041	\N	2018-01-25 09:52:10	2018-02-12 15:24:58
30036	MEMBRE	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26042	\N	2018-01-25 09:52:23	\N
30037	MEMBRE	2018-01-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26043	\N	2018-01-25 09:52:34	\N
30038	MEMBRE	2018-01-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26044	\N	2018-01-25 09:52:45	\N
30237	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26146	\N	\N	\N
30256	MEMBRE	2017-10-01 00:00:00	2018-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	26151	\N	\N	\N
30381	MEMBRE	2018-01-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26212	\N	2018-02-01 14:47:05	\N
30382	MEMBRE	2018-01-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26213	\N	2018-02-01 14:47:49	\N
30383	MEMBRE	2018-01-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26214	\N	2018-02-01 14:47:49	\N
30384	PDT	2018-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25943	\N	\N	\N
30385	VICPDT	2018-02-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25931	\N	\N	\N
30386	VICPDT	2018-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26145	\N	\N	\N
30387	VICPDT	2018-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25942	\N	\N	\N
30388	VICPDT	2018-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25971	\N	\N	\N
30389	VICPDT	2018-02-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26163	\N	\N	\N
30390	VICPDT	2018-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25921	\N	\N	\N
30391	VICPDT	2018-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25917	\N	\N	\N
30392	VICPDT	2018-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25918	\N	\N	\N
30393	VICPDT	2018-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26151	\N	\N	\N
30394	SECRET	2018-02-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25929	\N	\N	\N
30395	SECRET	2018-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25937	\N	\N	\N
30396	SECRET	2018-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25935	\N	\N	\N
22344	MEMBRE	2014-10-10 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20288	\N	2014-10-13 15:05:40	\N
22345	MEMBRE	2014-10-10 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20289	\N	2014-10-13 15:05:40	\N
22346	MEMBRE	2014-10-10 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20290	\N	2014-10-13 15:05:40	\N
22347	MEMBRE	2014-10-10 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	20291	\N	2014-10-13 15:05:40	2015-02-13 11:33:42
22348	MEMBRE	2014-10-10 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	20292	\N	2014-10-13 15:05:40	2015-02-05 18:51:45
22349	MEMBRE	2014-10-10 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	20293	\N	2014-10-13 15:05:40	2015-02-13 15:16:04
22350	MEMBRE	2014-10-10 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20294	\N	2014-10-13 15:05:40	\N
22351	MEMBRE	2014-10-10 00:00:00	2016-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	20295	\N	2014-10-13 15:05:40	2016-12-07 16:40:45
22352	MEMBRE	2014-10-10 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	20296	\N	2014-10-13 15:05:40	2015-02-13 10:35:07
22353	MEMBRE	2014-10-10 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20297	\N	2014-10-13 15:05:40	\N
22354	MEMBRE	2014-10-10 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20298	\N	2014-10-13 15:05:40	\N
32831	MEMBRE	2020-10-20 00:00:00	2021-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	28264	\N	\N	\N
22355	MEMBRE	2014-10-10 00:00:00	2015-08-30 00:00:00	ANCIEN	\N	\N	\N	\N	20299	\N	2014-10-13 15:05:40	2015-08-31 09:59:38
22356	MEMBRE	2014-10-10 00:00:00	2015-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	20300	\N	2014-10-13 15:05:40	2015-03-11 11:00:10
22357	MEMBRE	2014-10-10 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20301	\N	2014-10-13 15:05:40	\N
22358	MEMBRE	2014-10-10 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20302	\N	2014-10-13 15:05:40	\N
22359	MEMBRE	2014-10-10 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	20303	\N	2014-10-13 15:05:40	2015-02-13 17:04:15
22360	MEMBRE	2014-10-10 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20304	\N	2014-10-13 15:05:40	\N
22361	MEMBRE	2014-10-10 00:00:00	2015-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	20305	\N	2014-10-13 15:05:40	2015-04-09 15:20:59
22362	MEMBRE	2014-10-10 00:00:00	2015-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	20306	\N	2014-10-13 15:05:40	2015-02-18 13:27:50
22363	MEMBRE	2014-10-10 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	20307	\N	2014-10-13 15:05:40	2015-02-05 12:05:51
22364	MEMBRE	2014-10-10 00:00:00	2015-05-26 00:00:00	ANCIEN	\N	\N	\N	\N	20308	\N	2014-10-13 15:05:40	2015-05-27 16:33:30
22365	MEMBRE	2014-10-10 00:00:00	2015-04-09 00:00:00	ANCIEN	\N	\N	\N	\N	20309	\N	2014-10-13 15:05:40	2015-04-10 15:10:19
22366	MEMBRE	2014-10-10 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	20310	\N	2014-10-13 15:05:40	2015-01-06 16:27:29
22367	MEMBRE	2014-10-10 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	20311	\N	2014-10-13 15:05:41	2015-01-06 15:20:23
22368	MEMBRE	2014-10-10 00:00:00	2015-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	20312	\N	2014-10-13 15:05:41	2015-01-27 17:07:26
22369	MEMBRE	2014-10-10 00:00:00	2015-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	20313	\N	2014-10-13 15:05:41	2015-01-19 14:15:20
22370	MEMBRE	2014-10-10 00:00:00	2015-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	20314	\N	2014-10-13 15:05:41	2015-03-04 17:15:48
22371	MEMBRE	2014-10-10 00:00:00	2017-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	20315	\N	2014-10-13 15:05:41	2017-07-20 14:38:36
22372	MEMBRE	2014-10-10 00:00:00	2015-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	20316	\N	2014-10-13 15:05:41	2015-01-29 10:53:01
22373	MEMBRE	2014-10-10 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20317	\N	2014-10-13 15:05:41	\N
22374	MEMBRE	2014-10-10 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	20318	\N	2014-10-13 15:05:41	2015-02-19 15:42:25
22375	MEMBRE	2014-10-10 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	20319	\N	2014-10-13 15:05:41	2015-02-19 16:29:04
22376	MEMBRE	2014-10-10 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20320	\N	2014-10-13 15:05:41	\N
22377	MEMBRE	2014-10-10 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	20321	\N	2014-10-13 15:05:41	2015-02-13 14:19:34
22378	MEMBRE	2014-10-10 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	20322	\N	2014-10-13 15:05:41	2015-02-05 18:59:10
22379	MEMBRE	2014-10-10 00:00:00	2015-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	20323	\N	2014-10-13 15:05:41	2015-02-09 15:43:05
22380	MEMBRE	2014-10-10 00:00:00	2015-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	20324	\N	2014-10-13 15:05:41	2015-03-19 09:55:16
22381	MEMBRE	2014-10-10 00:00:00	2015-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	20325	\N	2014-10-13 15:05:41	2015-02-17 09:41:28
22382	MEMBRE	2014-10-10 00:00:00	2015-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	20326	\N	2014-10-13 15:05:41	2015-01-27 16:32:25
22383	MEMBRE	2014-10-10 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20327	\N	2014-10-13 15:05:41	\N
22384	MEMBRE	2014-10-10 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	20328	\N	2014-10-13 15:05:41	2015-02-11 18:01:27
24647	MEMBRE	2015-01-16 00:00:00	2015-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	22399	\N	2015-01-16 11:19:49	2015-02-12 12:45:47
25569	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22817	\N	\N	\N
26000	MEMBRE	2015-02-26 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23060	\N	2015-03-03 15:22:48	\N
26013	VICPDT	2015-03-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20355	2	2015-03-04 10:25:37	2015-03-04 10:26:30
26014	VICPDT	2015-03-04 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	21421	3	2015-03-04 10:25:42	2017-05-16 15:18:14
26015	VICPDT	2015-03-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22357	4	2015-03-04 10:25:47	2017-09-24 16:45:26
26016	VICPDT	2015-03-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22269	5	2015-03-04 10:25:54	2015-03-04 10:26:59
26017	VICPDT	2015-03-04 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	21856	6	2015-03-04 10:26:00	2016-03-11 18:02:51
26018	SECRET	2015-03-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22375	7	2015-03-04 10:26:10	2017-09-24 18:59:59
26132	MEMBRE	2015-01-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23117	\N	\N	2017-09-24 17:19:42
26158	MEMBRE	2015-03-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23126	\N	2015-03-11 09:14:33	\N
26159	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23127	\N	\N	\N
26164	MEMBRE	2014-10-01 00:00:00	2015-05-28 00:00:00	ANCIEN	\N	\N	\N	\N	23132	\N	\N	\N
26171	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23139	\N	\N	\N
26293	MEMBRE	2015-03-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23179	\N	2015-04-01 13:34:06	\N
26334	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23196	\N	\N	\N
26335	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23197	\N	\N	\N
26371	MEMBRE	2015-04-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23217	\N	2015-04-16 15:17:17	\N
26461	VICPDT	2015-05-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	22767	\N	\N	\N
26877	MEMBRE	2016-02-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23593	\N	2016-02-16 15:58:33	\N
26878	MEMBRE	2016-02-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23594	\N	2016-02-16 17:34:17	\N
23972	MEMBRE	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	21883	\N	2014-10-31 09:28:54	2016-03-11 18:02:51
23955	MEMBRE	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	21866	\N	2014-10-31 09:28:53	2016-03-11 18:02:51
23949	MEMBRE	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	21860	\N	2014-10-31 09:28:53	2016-03-11 18:02:51
23957	MEMBRE	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	21868	\N	2014-10-31 09:28:53	2016-03-11 18:02:51
23944	MEMBRE	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	21855	\N	2014-10-31 09:28:53	2016-03-11 18:02:51
27022	MEMBRE	2016-06-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23720	\N	\N	2017-09-24 13:42:36
27038	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23736	\N	\N	\N
23919	MEMBRE	2014-10-29 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	21830	\N	2014-10-31 09:26:53	2016-12-12 16:10:15
23921	MEMBRE	2014-10-29 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	21832	\N	2014-10-31 09:26:53	2016-12-12 16:10:15
27155	MEMBRE	2016-12-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23825	\N	2017-01-02 12:13:37	\N
27162	MEMBRE	2017-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23831	\N	\N	\N
27186	MEMBRE	2017-04-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23852	\N	2017-04-07 09:08:21	\N
27187	MEMBRE	2017-04-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23853	\N	2017-04-07 10:12:21	\N
27195	MEMBRE	2017-07-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	23861	\N	\N	\N
27217	VICPDT	2017-07-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21716	3	2017-07-20 14:38:10	2017-07-20 14:44:22
27218	VICPDT	2017-07-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21599	2	2017-07-20 14:38:10	2017-09-24 13:57:40
27220	SECRET	2017-07-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21428	5	2017-07-20 14:38:10	2017-09-24 17:14:27
27221	SECRET	2017-07-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21948	4	2017-07-20 14:38:10	2017-07-20 14:44:26
27222	MEMBRE	2017-07-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22338	\N	2017-07-20 14:38:10	2017-09-24 18:20:10
27223	MEMBRE	2017-07-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22355	\N	2017-07-20 14:38:10	2017-07-20 14:39:57
27224	MEMBRE	2017-07-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22367	\N	2017-07-20 14:38:10	2017-07-20 14:40:03
27225	MEMBRE	2017-07-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22335	\N	2017-07-20 14:38:10	\N
27226	MEMBRE	2017-07-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22333	\N	2017-07-20 14:38:30	2017-07-20 14:40:08
27227	MEMBRE	2017-07-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22343	\N	2017-07-20 14:38:34	2017-07-20 14:40:12
27228	MEMBRE	2017-07-20 00:00:00	2017-07-28 00:00:00	ANCIEN	\N	\N	\N	\N	20339	\N	2017-07-20 14:38:34	2017-08-03 11:38:41
27229	MEMBRE	2017-07-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21561	\N	2017-07-20 14:38:34	2017-07-20 14:40:21
27230	MEMBRE	2017-07-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21594	\N	2017-07-20 14:38:34	2017-09-24 17:35:15
27231	MEMBRE	2017-07-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22358	\N	2017-07-20 14:38:34	2017-09-24 18:16:52
27232	MEMBRE	2017-07-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22823	\N	2017-07-20 14:38:34	2017-09-24 17:47:28
27233	MEMBRE	2017-07-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21299	\N	2017-07-20 14:38:34	2017-09-24 17:19:42
27234	MEMBRE	2017-07-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20756	\N	2017-07-20 14:38:34	2017-09-24 18:17:56
27235	MEMBRE	2017-07-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22344	\N	2017-07-20 14:38:34	2017-07-20 14:42:19
27236	MEMBRE	2017-07-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21582	\N	2017-07-20 14:38:36	2017-09-24 17:55:12
25889	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22962	\N	\N	\N
25892	MEMBRE	2015-02-23 00:00:00	2015-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	22965	\N	2015-02-23 16:23:01	2015-03-11 10:58:01
26011	MEMBRE	2015-02-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23070	\N	2015-03-04 09:43:51	\N
26336	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23198	\N	\N	\N
26482	MEMBRE	2014-10-01 00:00:00	2014-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23279	\N	\N	\N
26510	MEMBRE	2015-06-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23285	\N	2015-06-04 09:56:20	2017-09-24 17:06:55
26511	MEMBRE	2015-06-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23286	\N	2015-06-04 09:56:20	2017-09-24 17:06:55
26918	MEMBRE	2016-06-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	23624	\N	\N	\N
26952	MEMBRE	2016-06-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	23652	\N	\N	\N
26954	MEMBRE	2016-06-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	23654	\N	\N	\N
26959	MEMBRE	2016-06-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	23659	\N	\N	\N
26963	MEMBRE	2016-06-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	23663	\N	\N	\N
26969	MEMBRE	2016-06-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	23669	\N	\N	\N
26970	MEMBRE	2016-06-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	23670	\N	\N	\N
26974	MEMBRE	2016-06-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	23674	\N	\N	\N
26976	MEMBRE	2016-06-15 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	23676	\N	\N	2017-06-19 16:06:51
26977	MEMBRE	2016-06-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	23677	\N	\N	\N
26978	MEMBRE	2016-06-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	23678	\N	\N	\N
26980	MEMBRE	2016-06-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	23680	\N	\N	\N
26982	MEMBRE	2016-06-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	23682	\N	\N	\N
26983	MEMBRE	2016-06-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	23683	\N	\N	\N
26990	MEMBRE	2016-06-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	23690	\N	\N	\N
26991	MEMBRE	2016-06-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	23691	\N	\N	\N
26994	MEMBRE	2016-06-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	23694	\N	\N	\N
26995	MEMBRE	2016-06-15 00:00:00	2016-09-28 00:00:00	ANCIEN	\N	\N	\N	\N	23695	\N	\N	\N
26996	MEMBRE	2016-06-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	23696	\N	\N	\N
26997	MEMBRE	2016-06-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	23697	\N	\N	\N
27000	MEMBRE	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23700	\N	\N	2017-09-24 17:09:24
27001	MEMBRE	2016-06-15 00:00:00	2016-09-28 00:00:00	ANCIEN	\N	\N	\N	\N	23701	\N	\N	\N
27002	MEMBRE	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23702	\N	\N	2017-09-24 17:06:55
27004	MEMBRE	2016-06-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	23704	\N	\N	\N
27006	MEMBRE	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23706	\N	\N	2017-09-24 17:29:37
27007	PDT	2016-06-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	23653	\N	\N	\N
27008	PDT	2016-06-15 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	23673	\N	\N	2017-09-25 09:57:52
27013	MEMBRE	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23711	\N	2016-06-21 16:34:25	\N
27447	MEMBRE	2017-10-09 00:00:00	2017-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	24014	\N	2017-10-11 16:30:13	2017-11-28 16:59:10
27448	MEMBRE	2017-10-09 00:00:00	2018-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	24015	\N	2017-10-11 16:31:09	2018-02-01 17:49:23
27449	MEMBRE	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24016	\N	2017-10-11 16:31:09	\N
28605	MEMBRE	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25172	\N	2017-11-10 10:34:33	\N
28606	MEMBRE	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25173	\N	2017-11-10 10:34:33	\N
28607	MEMBRE	2017-11-08 00:00:00	2018-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	25174	\N	2017-11-10 10:34:33	2018-01-29 10:21:25
28608	MEMBRE	2017-11-08 00:00:00	2018-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	25175	\N	2017-11-10 10:34:33	2018-01-16 19:11:48
28609	MEMBRE	2017-11-08 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	25176	\N	2017-11-10 10:34:33	2018-01-23 18:49:53
28610	MEMBRE	2017-10-25 00:00:00	2018-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	25177	\N	2017-11-10 10:36:16	2018-01-16 19:11:31
28611	MEMBRE	2017-10-25 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	25178	\N	2017-11-10 10:36:16	2018-01-25 17:40:11
28612	MEMBRE	2017-11-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25179	\N	2017-11-10 10:43:59	\N
28613	MEMBRE	2017-11-09 00:00:00	2018-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	25180	\N	2017-11-10 10:43:59	2018-02-01 17:47:53
28614	MEMBRE	2017-11-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25181	\N	2017-11-10 10:43:59	\N
28615	MEMBRE	2017-11-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25182	\N	2017-11-10 10:43:59	\N
28616	MEMBRE	2017-11-09 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	25183	\N	2017-11-10 10:43:59	2017-12-20 14:34:41
28617	MEMBRE	2017-11-09 00:00:00	2018-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	25184	\N	2017-11-10 10:43:59	2018-02-08 14:37:29
28618	MEMBRE	2017-11-09 00:00:00	2018-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	25185	\N	2017-11-10 10:43:59	2018-02-05 10:00:09
28619	MEMBRE	2017-11-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25186	\N	2017-11-10 10:44:00	\N
28620	MEMBRE	2017-11-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25187	\N	2017-11-10 10:44:00	\N
28621	MEMBRE	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25188	\N	2017-11-10 10:44:21	\N
28622	MEMBRE	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25189	\N	2017-11-10 10:44:21	\N
28623	MEMBRE	2017-11-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25190	\N	2017-11-10 10:45:47	\N
28624	MEMBRE	2017-11-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25191	\N	2017-11-10 10:46:03	\N
28625	MEMBRE	2017-11-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25192	\N	2017-11-10 10:46:03	\N
28626	MEMBRE	2017-11-07 00:00:00	2018-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	25193	\N	2017-11-10 10:46:36	2018-02-01 17:47:59
28627	MEMBRE	2017-11-07 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	25194	\N	2017-11-10 10:46:36	2018-01-24 18:30:22
28628	MEMBRE	2017-11-07 00:00:00	2018-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	25195	\N	2017-11-10 10:46:36	2018-01-26 16:17:58
28629	MEMBRE	2017-11-07 00:00:00	2018-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	25196	\N	2017-11-10 10:46:36	2018-01-16 19:08:26
28630	MEMBRE	2017-11-07 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	25197	\N	2017-11-10 10:46:36	2018-02-07 16:35:05
28631	MEMBRE	2017-11-07 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	25198	\N	2017-11-10 10:46:36	2018-01-24 17:11:00
28632	MEMBRE	2017-11-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25199	\N	2017-11-10 10:46:36	\N
28633	MEMBRE	2017-11-07 00:00:00	2018-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	25200	\N	2017-11-10 10:46:36	2018-03-06 12:10:47
28634	MEMBRE	2017-11-08 00:00:00	2018-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	25201	\N	2017-11-10 10:47:34	2018-01-16 19:06:58
28635	MEMBRE	2017-11-08 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	25202	\N	2017-11-10 10:47:34	2018-01-25 16:05:30
28636	MEMBRE	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25203	\N	2017-11-10 10:47:34	\N
28637	MEMBRE	2017-11-08 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	25204	\N	2017-11-10 10:47:35	2018-01-18 11:22:31
28638	MEMBRE	2017-11-08 00:00:00	2018-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	25205	\N	2017-11-10 10:47:35	2018-01-29 16:17:54
28639	MEMBRE	2017-11-08 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	25206	\N	2017-11-10 10:47:35	2017-12-20 14:34:23
28640	MEMBRE	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25207	\N	2017-11-10 10:47:35	\N
28641	MEMBRE	2017-11-08 00:00:00	2018-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	25208	\N	2017-11-10 10:47:35	2018-01-30 16:03:22
28642	MEMBRE	2017-11-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25209	\N	2017-11-10 10:48:17	\N
28643	MEMBRE	2017-11-06 00:00:00	2018-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	25210	\N	2017-11-10 10:48:17	2018-03-06 12:09:12
28644	MEMBRE	2017-11-08 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	25211	\N	2017-11-10 10:49:26	2018-01-18 16:41:10
28645	MEMBRE	2017-11-08 00:00:00	2017-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	25212	\N	2017-11-10 10:49:26	2017-11-28 16:28:06
28646	MEMBRE	2017-11-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25213	\N	2017-11-10 10:49:26	\N
28647	MEMBRE	2017-11-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25214	\N	2017-11-10 10:49:26	\N
28648	MEMBRE	2017-11-08 00:00:00	2017-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	25215	\N	2017-11-10 10:49:26	2017-11-30 16:30:48
28649	MEMBRE	2017-11-08 00:00:00	2018-03-04 00:00:00	ANCIEN	\N	\N	\N	\N	25216	\N	2017-11-10 10:49:26	2018-03-05 17:58:12
28650	MEMBRE	2017-11-08 00:00:00	2017-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	25217	\N	2017-11-10 10:49:44	2017-12-01 14:56:54
28651	MEMBRE	2017-11-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25218	\N	2017-11-10 10:50:29	\N
28652	MEMBRE	2017-11-08 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	25219	\N	2017-11-10 10:50:29	2018-01-24 10:42:12
28653	MEMBRE	2017-11-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25220	\N	2017-11-10 10:50:29	\N
28654	MEMBRE	2017-11-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25221	\N	2017-11-10 10:50:29	\N
28655	MEMBRE	2017-11-08 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	25222	\N	2017-11-10 10:50:29	2018-01-18 17:51:12
28656	MEMBRE	2017-11-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25223	\N	2017-11-10 10:53:06	\N
28657	MEMBRE	2017-11-10 00:00:00	2018-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	25224	\N	2017-11-10 10:53:06	2018-03-06 12:09:06
28658	MEMBRE	2017-11-10 00:00:00	2018-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	25225	\N	2017-11-10 10:53:06	2018-01-26 10:15:42
29251	MEMBRE	2017-12-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25651	\N	2017-12-19 10:23:01	\N
29252	MEMBRE	2017-12-14 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	25652	\N	2017-12-19 10:23:32	2018-01-25 15:21:34
29476	MEMBRE	2017-12-07 00:00:00	2018-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	25802	\N	\N	\N
29597	MEMBRE	2017-01-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	25859	\N	\N	\N
29784	MEMBRE	2018-01-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25966	\N	2018-01-19 09:42:58	\N
29913	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25995	\N	\N	\N
29914	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25996	\N	\N	\N
29916	MEMBRE	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25998	\N	2018-01-24 12:06:58	\N
29917	MEMBRE	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25999	\N	2018-01-24 12:09:31	\N
29918	MEMBRE	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26000	\N	2018-01-24 12:10:50	\N
29919	MEMBRE	2018-01-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26001	\N	2018-01-24 12:12:05	\N
29920	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26002	\N	\N	\N
29923	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26005	\N	\N	\N
29924	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26006	\N	\N	\N
29925	MEMBRE	2018-01-24 00:00:00	2019-06-24 00:00:00	ANCIEN	\N	\N	\N	\N	26007	\N	2018-01-24 12:13:47	\N
29926	MEMBRE	2017-10-01 00:00:00	2020-06-24 00:00:00	ANCIEN	\N	\N	\N	\N	26008	\N	\N	\N
29927	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26009	\N	\N	\N
29928	MEMBRE	2017-10-01 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	26010	\N	\N	\N
29929	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26011	\N	\N	\N
29930	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26012	\N	\N	\N
29931	MEMBRE	2017-10-01 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	26013	\N	\N	\N
29932	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26014	\N	\N	\N
22541	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20485	\N	2014-10-16 15:09:20	\N
22542	MEMBRE	2014-10-14 00:00:00	2015-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	20486	\N	2014-10-16 15:09:20	2015-01-28 10:27:40
22543	MEMBRE	2014-10-14 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	20487	\N	2014-10-16 15:09:41	2015-02-13 14:19:11
22544	MEMBRE	2014-10-14 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	20488	\N	2014-10-16 15:09:41	2015-02-11 17:18:17
22545	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20489	\N	2014-10-16 15:10:11	\N
22546	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20490	\N	2014-10-16 15:10:11	\N
22547	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20491	\N	2014-10-16 15:10:11	\N
22548	MEMBRE	2014-10-14 00:00:00	2015-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	20492	\N	2014-10-16 15:10:11	2015-02-09 15:41:11
22549	MEMBRE	2014-10-14 00:00:00	2015-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	20493	\N	2014-10-16 15:10:11	2015-02-12 12:45:23
22550	MEMBRE	2014-10-14 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	20494	\N	2014-10-16 15:10:11	2015-01-06 15:52:11
22551	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20495	\N	2014-10-16 15:10:11	\N
22552	MEMBRE	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20496	\N	2014-10-16 15:10:11	\N
22553	MEMBRE	2014-10-15 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	20497	\N	2014-10-16 15:10:23	2015-02-19 16:16:53
22554	MEMBRE	2014-10-15 00:00:00	2015-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	20498	\N	2014-10-16 15:10:23	2015-02-17 09:36:06
24718	MEMBRE	2015-01-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22438	\N	2015-01-23 09:15:31	\N
24719	MEMBRE	2015-01-22 00:00:00	2015-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	22439	\N	2015-01-23 09:15:31	2015-03-19 10:03:20
24720	MEMBRE	2015-01-22 00:00:00	2016-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	22440	\N	2015-01-23 09:17:02	2017-01-03 11:09:24
24721	MEMBRE	2015-01-22 00:00:00	2016-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	22441	\N	2015-01-23 09:17:02	2017-01-03 11:09:24
24722	MEMBRE	2015-01-15 00:00:00	2015-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	22442	\N	2015-01-23 09:23:29	2015-06-15 10:19:51
24815	MEMBRE	2015-01-27 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22477	\N	2015-01-29 10:36:18	\N
26284	PDT	2015-03-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	23019	\N	\N	\N
26285	VICPDT	2015-03-18 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23022	\N	\N	\N
26304	PDT	2015-04-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	23058	\N	\N	\N
26305	VICPDT	2015-04-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	23051	\N	\N	\N
26306	VICPDT	2015-04-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23052	\N	\N	2017-09-24 17:09:24
26307	VICPDT	2015-04-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	23155	\N	\N	\N
26337	MEMBRE	2014-10-01 00:00:00	2015-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	23199	\N	\N	\N
26338	MEMBRE	2015-01-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23200	\N	\N	2017-09-24 18:49:56
26339	MEMBRE	2014-10-01 00:00:00	2015-05-01 00:00:00	ANCIEN	\N	\N	\N	\N	23201	\N	\N	\N
26340	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23202	\N	\N	2017-09-24 18:49:56
26341	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23203	\N	\N	2017-09-24 18:07:57
26353	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23215	\N	\N	\N
26648	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23387	\N	\N	\N
26649	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23388	\N	\N	\N
26688	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23420	\N	\N	\N
26919	MEMBRE	2016-06-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	23625	\N	\N	\N
26920	MEMBRE	2016-06-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	23626	\N	\N	\N
26921	MEMBRE	2016-06-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23627	\N	\N	2017-09-24 17:15:15
27065	MEMBRE	2016-10-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23757	\N	\N	\N
26925	MEMBRE	2016-06-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23631	\N	\N	2017-09-24 17:42:26
28130	MEMBRE	2017-10-25 00:00:00	2017-12-11 00:00:00	ANCIEN	\N	\N	\N	\N	24697	\N	2017-10-26 15:38:56	2017-12-12 17:17:22
26927	MEMBRE	2016-06-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	23633	\N	\N	\N
26928	MEMBRE	2016-06-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	23634	\N	\N	\N
27064	MEMBRE	2017-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23756	\N	\N	\N
27167	MEMBRE	2017-01-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23834	\N	2017-01-30 15:36:28	\N
28131	MEMBRE	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24698	\N	2017-10-26 15:38:56	\N
28133	MEMBRE	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24700	\N	2017-10-26 15:38:56	\N
28134	MEMBRE	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24701	\N	2017-10-26 15:38:56	\N
28135	MEMBRE	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24702	\N	2017-10-26 15:38:56	\N
28136	MEMBRE	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24703	\N	2017-10-26 15:38:56	\N
28170	MEMBRE	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24737	\N	2017-10-26 16:06:15	\N
28171	MEMBRE	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24738	\N	2017-10-26 16:06:15	\N
28172	MEMBRE	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24739	\N	2017-10-26 16:06:15	\N
28173	MEMBRE	2017-10-25 00:00:00	2017-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	24740	\N	2017-10-26 16:06:15	2017-11-30 11:16:17
28174	MEMBRE	2017-10-13 00:00:00	2018-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	24741	\N	2017-10-26 16:30:56	2018-02-08 16:43:26
28175	MEMBRE	2017-10-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24742	\N	2017-10-26 16:30:56	\N
28176	MEMBRE	2017-10-24 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24743	\N	2017-10-26 17:24:39	2018-01-24 17:30:39
28177	MEMBRE	2017-10-24 00:00:00	2018-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	24744	\N	2017-10-26 17:24:39	2018-01-29 16:17:26
28178	MEMBRE	2017-10-24 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24745	\N	2017-10-26 17:24:40	2018-01-24 18:29:47
28179	MEMBRE	2017-10-24 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24746	\N	2017-10-26 17:24:40	2018-01-24 11:15:02
28180	MEMBRE	2017-10-24 00:00:00	2018-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	24747	\N	2017-10-26 17:24:40	2018-03-06 12:08:29
28181	MEMBRE	2017-10-24 00:00:00	2018-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	24748	\N	2017-10-26 17:24:40	2018-01-26 10:17:20
28182	MEMBRE	2017-10-24 00:00:00	2018-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	24749	\N	2017-10-26 17:24:40	2018-01-26 10:01:22
28406	MEMBRE	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24973	\N	2017-11-02 09:53:37	\N
28407	MEMBRE	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24974	\N	2017-11-02 09:53:37	\N
28408	MEMBRE	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24975	\N	2017-11-02 09:53:37	\N
28409	MEMBRE	2017-10-31 00:00:00	2017-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	24976	\N	2017-11-02 09:54:03	2017-12-07 15:00:43
28410	MEMBRE	2017-10-31 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24977	\N	2017-11-02 09:54:03	2018-01-24 17:10:30
28411	MEMBRE	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24978	\N	2017-11-02 09:54:03	\N
28412	MEMBRE	2017-10-31 00:00:00	2018-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	24979	\N	2017-11-02 09:54:03	2018-02-01 17:48:08
28413	MEMBRE	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24980	\N	2017-11-02 09:54:03	\N
28414	MEMBRE	2017-10-31 00:00:00	2018-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	24981	\N	2017-11-02 09:54:42	2018-01-16 18:58:04
28415	MEMBRE	2017-11-02 00:00:00	2020-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	24982	\N	2017-11-02 09:56:23	\N
28416	MEMBRE	2017-11-02 00:00:00	2020-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	24983	\N	2017-11-02 09:56:23	\N
28417	MEMBRE	2017-11-02 00:00:00	2020-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	24984	\N	2017-11-02 09:56:23	\N
28418	MEMBRE	2017-11-02 00:00:00	2020-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	24985	\N	2017-11-02 09:56:23	\N
28419	MEMBRE	2017-11-02 00:00:00	2020-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	24986	\N	2017-11-02 09:56:23	\N
28420	MEMBRE	2017-11-02 00:00:00	2020-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	24987	\N	2017-11-02 09:56:23	\N
28421	MEMBRE	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24988	\N	2017-11-02 09:56:55	\N
28422	MEMBRE	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24989	\N	2017-11-02 09:56:55	\N
28423	MEMBRE	2017-10-31 00:00:00	2017-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	24990	\N	2017-11-02 09:56:55	2017-12-19 18:08:58
28424	MEMBRE	2017-10-31 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	24991	\N	2017-11-02 09:56:55	2018-01-23 17:23:29
28425	MEMBRE	2017-11-02 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24992	\N	2017-11-02 09:57:29	\N
28426	MEMBRE	2017-11-02 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24993	\N	2017-11-02 09:57:29	\N
28427	MEMBRE	2017-10-26 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24994	\N	2017-11-02 10:00:50	2018-01-24 15:31:44
28428	MEMBRE	2017-10-26 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	24995	\N	2017-11-02 10:00:50	2017-12-20 17:59:56
28429	MEMBRE	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24996	\N	2017-11-02 10:00:50	\N
28430	MEMBRE	2017-10-26 00:00:00	2018-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	24997	\N	2017-11-02 10:00:50	2018-03-07 17:12:31
28431	MEMBRE	2017-10-26 00:00:00	2018-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	24998	\N	2017-11-02 10:00:50	2018-03-06 12:08:58
28432	MEMBRE	2017-10-26 00:00:00	2018-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	24999	\N	2017-11-02 10:00:50	2018-01-23 17:48:12
28433	MEMBRE	2017-10-31 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	25000	\N	2017-11-02 10:02:34	2018-01-25 10:58:50
28434	MEMBRE	2017-10-31 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25001	\N	2017-11-02 10:02:34	\N
28435	MEMBRE	2017-10-31 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25002	\N	2017-11-02 10:02:34	\N
28436	MEMBRE	2017-10-31 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25003	\N	2017-11-02 10:02:34	\N
28437	MEMBRE	2017-10-31 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25004	\N	2017-11-02 10:02:34	\N
28438	MEMBRE	2017-10-31 00:00:00	2018-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	25005	\N	2017-11-02 10:02:34	2018-01-29 10:21:15
28439	MEMBRE	2017-10-31 00:00:00	2017-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	25006	\N	2017-11-02 10:02:34	2017-11-30 11:14:55
28440	MEMBRE	2017-10-31 00:00:00	2017-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	25007	\N	2017-11-02 10:02:34	2017-12-14 18:21:12
28441	MEMBRE	2017-10-31 00:00:00	2018-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	25008	\N	2017-11-02 10:02:34	2018-01-30 16:02:27
28442	MEMBRE	2017-10-31 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	25009	\N	2017-11-02 10:02:34	2017-12-20 16:56:46
28443	MEMBRE	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25010	\N	2017-11-02 10:03:00	\N
28444	MEMBRE	2017-10-31 00:00:00	2017-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	25011	\N	2017-11-02 10:03:00	2017-12-14 15:50:38
28445	MEMBRE	2017-10-31 00:00:00	2018-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	25012	\N	2017-11-02 10:03:00	2018-01-26 10:17:14
28446	MEMBRE	2017-10-27 00:00:00	2018-04-03 00:00:00	ANCIEN	\N	\N	\N	\N	25013	\N	2017-11-02 10:04:10	2018-04-03 14:56:24
28447	MEMBRE	2017-10-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25014	\N	2017-11-02 10:04:10	\N
28448	MEMBRE	2017-10-31 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25015	\N	2017-11-02 10:07:04	\N
25890	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22963	\N	\N	2017-09-24 16:24:51
25891	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22964	\N	\N	\N
26019	MEMBRE	2014-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23072	\N	\N	2017-10-01 10:25:16
26196	VICPDT	2015-03-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21315	2	2015-03-11 12:57:20	2017-09-24 17:18:03
26197	VICPDT	2015-03-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21036	3	2015-03-11 12:57:26	2015-03-11 12:57:57
26198	VICPDT	2015-03-11 00:00:00	2015-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	21484	4	2015-03-11 12:57:31	2015-07-09 15:11:20
26199	VICPDT	2015-03-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22542	4	2015-03-11 12:57:40	2015-07-09 15:11:38
26200	SECRET	2015-03-11 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	21882	6	2015-03-11 12:57:44	2016-03-11 18:02:51
26352	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23214	\N	\N	\N
26394	VICPDT	2015-03-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23225	\N	\N	\N
26395	PDT	2015-03-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23227	\N	\N	\N
26396	VICPDT	2015-03-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23228	\N	\N	\N
26398	VICPDT	2015-03-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23237	\N	\N	\N
26410	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23249	\N	\N	\N
26673	MEMBRE	2015-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23407	\N	2015-10-21 11:00:08	\N
26674	MEMBRE	2015-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23408	\N	2015-10-21 11:00:08	\N
26675	MEMBRE	2015-10-15 00:00:00	2016-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	23409	\N	2015-10-21 11:00:08	2016-03-22 14:44:18
26676	MEMBRE	2015-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23410	\N	2015-10-21 11:00:52	2017-09-24 18:16:52
26677	MEMBRE	2015-10-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23411	\N	2015-10-21 11:02:19	\N
26917	MEMBRE	2016-05-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23623	\N	2016-05-31 14:42:51	\N
29043	MEMBRE	2017-11-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25534	\N	2017-12-04 17:18:25	\N
29466	MEMBRE	2017-12-21 00:00:00	2018-01-21 00:00:00	ANCIEN	\N	\N	\N	\N	25793	\N	2018-01-10 17:08:20	2018-01-22 16:08:44
29674	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25928	\N	\N	\N
29676	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25930	\N	\N	\N
29679	MEMBRE	2017-10-01 00:00:00	2018-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	25933	\N	\N	\N
30113	VICPDT	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24707	\N	2018-01-25 17:35:37	\N
30114	VICPDT	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24349	\N	2018-01-25 17:36:06	\N
30115	VICPDT	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24854	\N	2018-01-25 17:36:21	\N
30116	VICPDT	2018-01-25 00:00:00	2020-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	25152	\N	2018-01-25 17:36:37	\N
30117	VICPDT	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24671	\N	2018-01-25 17:36:45	\N
30118	VICPDT	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24763	\N	2018-01-25 17:36:55	\N
30119	VICPDT	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24412	\N	2018-01-25 17:37:15	\N
30120	VICPDT	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24639	\N	2018-01-25 17:37:24	\N
30121	VICPDT	2018-01-25 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	25020	\N	2018-01-25 17:37:57	\N
30122	SECRET	2018-01-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24881	\N	2018-01-25 17:38:18	\N
30123	SECRET	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24558	\N	2018-01-25 17:39:33	\N
30124	SECRET	2018-01-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24540	\N	2018-01-25 17:39:44	\N
30125	SECRET	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24026	\N	2018-01-25 17:40:02	\N
30126	SECRET	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25178	\N	2018-01-25 17:40:11	\N
30127	SECRET	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25247	\N	2018-01-25 17:40:20	\N
30397	SECRET	2018-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	25933	\N	\N	\N
30399	MEMBRE	2018-02-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26216	\N	2018-02-01 17:14:58	\N
30398	MEMBRE	2018-01-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26215	\N	2018-02-01 16:30:15	\N
30400	MEMBRE	2018-02-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26217	\N	2018-02-01 17:17:15	\N
30401	VICPDT	2018-02-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25180	\N	2018-02-01 17:47:53	\N
30402	VICPDT	2018-02-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25193	\N	2018-02-01 17:47:59	\N
30403	VICPDT	2018-02-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24979	\N	2018-02-01 17:48:08	\N
30404	VICPDT	2018-02-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24416	\N	2018-02-01 17:48:20	\N
30405	VICPDT	2018-02-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24110	\N	2018-02-01 17:48:29	\N
30406	VICPDT	2018-02-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25103	\N	2018-02-01 17:48:39	\N
30407	SECRET	2018-02-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24535	\N	2018-02-01 17:48:47	2018-02-01 17:49:10
30408	SECRET	2018-02-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24015	\N	2018-02-01 17:49:23	\N
30409	SECRET	2018-02-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24834	\N	2018-02-01 17:49:29	\N
30410	MEMBRE	2018-02-01 00:00:00	2018-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	25401	\N	2018-02-01 18:30:26	\N
30411	VICPDT	2018-02-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23983	\N	2018-02-01 18:30:38	\N
30412	VICPDT	2018-02-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24918	\N	2018-02-01 18:30:58	\N
30413	VICPDT	2018-02-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24870	\N	2018-02-01 18:31:04	\N
30414	VICPDT	2018-02-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25059	\N	2018-02-01 18:31:09	\N
30415	VICPDT	2018-02-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25494	\N	2018-02-01 18:31:17	\N
30416	VICPDT	2018-02-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24621	\N	2018-02-01 18:31:27	\N
30417	VICPDT	2018-02-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24971	\N	2018-02-01 18:31:41	\N
30418	VICPDT	2018-02-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24833	\N	2018-02-01 18:31:49	\N
30419	VICPDT	2018-02-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24642	\N	2018-02-01 18:32:08	\N
30420	VICPDT	2018-02-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24784	\N	2018-02-01 18:32:16	\N
30421	VICPDT	2018-02-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24691	\N	2018-02-01 18:32:25	\N
30422	VICPDT	2018-02-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24196	\N	2018-02-01 18:32:33	\N
30423	SECRET	2018-02-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24490	\N	2018-02-01 18:32:50	\N
30424	SECRET	2018-02-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25431	\N	2018-02-01 18:32:56	\N
30425	SECRET	2018-02-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24292	\N	2018-02-01 18:33:01	\N
30426	SECRET	2018-02-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25593	\N	2018-02-01 18:33:10	\N
30427	SECRET	2018-02-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24552	\N	2018-02-01 18:33:21	\N
30428	PDT	2018-02-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25373	\N	2018-02-01 18:33:29	\N
30429	MEMBRE	2018-01-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26218	\N	2018-02-02 09:19:22	\N
30430	MEMBRE	2018-01-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26219	\N	2018-02-02 09:19:40	\N
30431	MEMBRE	2018-01-31 00:00:00	2018-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	26220	\N	2018-02-02 09:20:02	2018-02-14 12:55:21
30432	MEMBRE	2018-01-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26221	\N	2018-02-02 09:20:22	\N
30433	MEMBRE	2018-02-02 00:00:00	2018-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	25515	\N	2018-02-02 10:02:51	2018-02-13 12:33:09
30434	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26222	\N	\N	\N
30435	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26223	\N	\N	\N
30436	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26224	\N	\N	\N
30437	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26225	\N	\N	\N
30438	MEMBRE	2018-01-18 00:00:00	2018-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	26226	\N	2018-02-02 15:51:11	2018-02-13 12:32:05
30439	MEMBRE	2018-02-02 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26227	\N	2018-02-02 15:51:52	\N
30440	MEMBRE	2018-01-31 00:00:00	2018-03-04 00:00:00	ANCIEN	\N	\N	\N	\N	26228	\N	2018-02-02 15:52:11	2018-03-05 18:16:05
30441	MEMBRE	2018-02-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26229	\N	2018-02-02 15:52:56	\N
30442	MEMBRE	2018-02-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26230	\N	2018-02-02 15:52:56	\N
30443	MEMBRE	2017-10-01 00:00:00	2018-05-07 00:00:00	ANCIEN	\N	\N	\N	\N	26231	\N	\N	\N
30444	MEMBRE	2017-10-01 00:00:00	2018-05-07 00:00:00	ANCIEN	\N	\N	\N	\N	26232	\N	\N	\N
30445	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26233	\N	\N	\N
30446	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26234	\N	\N	\N
30447	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26235	\N	\N	\N
30448	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26236	\N	\N	\N
30449	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26237	\N	\N	\N
30450	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26238	\N	\N	\N
30451	VICPDT	2018-02-02 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24106	\N	2018-02-02 17:41:17	\N
30452	VICPDT	2018-02-02 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24865	\N	2018-02-02 17:41:55	\N
30453	MEMBRE	2018-01-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26239	\N	2018-02-02 17:51:55	\N
30454	VICPDT	2018-02-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25678	\N	2018-02-05 09:59:58	\N
30455	VICPDT	2018-02-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25185	\N	2018-02-05 10:00:09	\N
30456	VICPDT	2018-02-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24553	\N	2018-02-05 10:00:15	\N
30457	SECRET	2018-02-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24179	\N	2018-02-05 10:00:23	\N
30458	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26240	\N	\N	\N
30459	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26241	\N	\N	\N
30460	MEMBRE	2017-10-01 00:00:00	2018-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	26242	\N	\N	\N
30461	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26243	\N	\N	\N
30462	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26244	\N	\N	\N
30463	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26245	\N	\N	\N
30464	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26246	\N	\N	\N
30465	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26247	\N	\N	\N
30466	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26248	\N	\N	\N
30467	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26249	\N	\N	\N
30468	MEMBRE	2018-02-05 00:00:00	2018-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	26250	\N	2018-02-05 16:41:17	2018-03-16 14:48:15
30469	VICPDTDEL	2018-02-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	Equateur	\N	25008	\N	2018-02-05 17:21:59	2018-02-05 17:23:20
22413	MEMBRE	2014-10-15 00:00:00	2015-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	20357	\N	2014-10-15 11:55:09	2015-01-20 11:33:54
22414	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20358	\N	2014-10-15 11:56:13	\N
22415	MEMBRE	2014-10-15 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	20359	\N	2014-10-15 11:56:13	2015-01-06 17:43:12
22416	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20360	\N	2014-10-15 11:56:13	\N
22417	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20361	\N	2014-10-15 11:56:13	\N
22418	MEMBRE	2014-10-15 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	20362	\N	2014-10-15 11:56:13	2015-02-13 11:34:23
22419	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20363	\N	2014-10-15 11:56:32	\N
22420	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20364	\N	2014-10-15 11:56:32	\N
22421	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20365	\N	2014-10-15 11:56:32	\N
22434	MEMBRE	2014-10-15 00:00:00	2015-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	20378	\N	2014-10-15 16:19:01	2015-02-17 09:39:11
24476	PDT	2015-01-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20377	1	2015-01-06 15:11:27	2015-01-14 16:14:27
22436	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20380	\N	2014-10-15 16:19:01	\N
22437	MEMBRE	2014-10-15 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	20381	\N	2014-10-15 16:19:01	2015-02-03 10:20:35
22438	MEMBRE	2014-10-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20382	\N	2014-10-15 16:19:01	\N
22439	MEMBRE	2014-10-15 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	20383	\N	2014-10-15 16:19:01	2015-02-02 13:24:21
22440	MEMBRE	2014-10-14 00:00:00	2015-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	20384	\N	2014-10-15 16:19:22	2015-01-14 14:53:17
23592	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21503	\N	2014-10-29 15:29:20	\N
24351	MEMBRE	2014-11-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22258	\N	2014-11-20 10:27:25	\N
24478	PDTDEL	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour le Cameroun	\N	21136	4	2015-01-06 15:14:37	2015-02-03 10:15:07
24479	PDTDEL	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour la Centrafrique	\N	20572	2	2015-01-06 15:15:11	2015-02-03 10:14:40
24480	PDTDEL	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour le Congo Brazzaville	\N	20456	9	2015-01-06 15:15:32	2015-02-03 10:16:58
24481	PDTDEL	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour l'Ouganda	\N	20311	5	2015-01-06 15:20:23	2015-02-03 10:15:11
24482	PDTDEL	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour le Tchad	\N	20758	3	2015-01-06 15:20:49	2015-02-03 10:14:51
24483	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20525	1	2015-01-06 15:22:37	2015-01-06 15:23:10
24484	PDTDEL	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour le Cap Vert	\N	21591	2	2015-01-06 15:24:42	2015-02-11 12:12:01
24485	PDTDEL	2015-01-06 00:00:00	2017-07-22 00:00:00	ANCIEN	\N	\N	pour la Côte d'Ivoire	\N	21728	4	2015-01-06 15:25:08	2017-07-24 09:58:00
24486	PDTDEL	2015-01-06 00:00:00	2015-01-22 00:00:00	ANCIEN	\N	\N	pour la Guinée (Conakry)	\N	21847	\N	2015-01-06 15:25:32	2015-01-23 11:59:21
24487	PDTDEL	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour le Mali	\N	20438	\N	2015-01-06 15:28:38	2015-02-11 12:11:34
24488	PDTDEL	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour la Guinée-Bissau	\N	20464	14	2015-01-06 15:29:00	2015-02-11 12:13:06
24489	PDTDEL	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour le Nigéria	\N	21227	5	2015-01-06 15:29:31	2015-02-11 12:12:15
24490	PDTDEL	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour le Sénégal	\N	22067	3	2015-01-06 15:29:52	2015-02-11 12:12:04
24491	PDT	2015-01-06 00:00:00	2015-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	21309	1	2015-01-06 15:32:29	2015-01-13 17:26:42
24492	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21198	1	2015-01-06 15:33:09	2015-01-06 15:33:11
24493	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20620	1	2015-01-06 15:33:34	2015-01-06 15:33:56
24494	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20482	1	2015-01-06 15:34:16	2015-01-06 15:34:21
24495	PDT	2015-01-06 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20450	1	2015-01-06 15:34:41	2015-11-12 15:26:22
24496	PDTDEL	2015-01-06 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	pour l'Arabie saoudite	\N	21422	5	2015-01-06 15:36:30	2017-05-16 15:18:14
24497	PDTDEL	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour le Bahreïn	\N	21987	3	2015-01-06 15:36:49	2015-03-19 09:58:24
24498	PDTDEL	2015-01-06 00:00:00	2015-01-12 00:00:00	ANCIEN	\N	\N	pour les Emirats arabes unis	\N	21921	\N	2015-01-06 15:37:40	2015-01-13 15:51:36
24499	PDTDEL	2015-01-06 00:00:00	2015-01-13 00:00:00	ANCIEN	\N	\N	pour le Sultanat d'Oman	\N	20822	\N	2015-01-06 15:38:27	2015-01-14 10:13:22
24500	PDTDEL	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour le Qatar	\N	20794	4	2015-01-06 15:38:47	2015-03-19 09:58:27
24501	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20514	1	2015-01-06 15:39:27	2015-01-06 15:39:32
24502	PDTDEL	2015-01-06 00:00:00	2015-03-01 00:00:00	ANCIEN	\N	\N	pour le Kazakhstan	\N	21364	\N	2015-01-06 15:48:01	2015-03-02 10:50:52
24503	PDTDEL	2015-01-06 00:00:00	2015-01-13 00:00:00	ANCIEN	\N	\N	pour le Tadjikistan	\N	21183	\N	2015-01-06 15:48:21	2015-01-14 10:00:40
24504	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22208	1	2015-01-06 15:49:11	2015-01-06 15:49:27
24505	PDTDEL	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour la Birmanie	\N	22045	4	2015-01-06 15:50:43	2015-02-11 17:14:10
24506	PDTDEL	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour le Brunei	\N	21604	6	2015-01-06 15:51:05	2015-02-11 17:17:54
24507	PDTDEL	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour les Philippines	\N	21002	8	2015-01-06 15:51:36	2015-02-11 17:18:12
24508	PDTDEL	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour Singapour	\N	20494	3	2015-01-06 15:52:11	2015-02-11 17:14:09
24509	PDTDEL	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour la Thaïlande	\N	20541	7	2015-01-06 15:52:27	2015-02-11 17:17:56
24510	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21533	1	2015-01-06 15:52:58	2015-01-06 15:53:05
24511	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21753	1	2015-01-06 15:53:33	2015-01-06 15:53:44
24512	PDTDEL	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour la Bosnie-Herzégovine	\N	21307	2	2015-01-06 15:54:24	2015-01-14 14:22:45
24513	PDTDEL	2015-01-06 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	pour le Kosovo	\N	21843	4	2015-01-06 15:54:41	2016-12-12 16:10:15
24514	PDTDEL	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour le Monténégro	\N	20974	6	2015-01-06 15:54:58	2015-02-20 12:09:27
24515	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21059	1	2015-01-06 16:00:18	2015-01-06 16:00:31
24516	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21563	1	2015-01-06 16:01:38	2015-01-06 16:01:46
24517	PDTDEL	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour le Suriname	\N	21031	3	2015-01-06 16:01:57	2015-01-14 14:21:15
24518	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22157	1	2015-01-06 16:03:31	2015-01-06 16:03:34
24519	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20950	1	2015-01-06 16:04:06	2015-01-06 16:04:12
24520	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21917	1	2015-01-06 16:06:24	2015-01-06 16:06:32
24521	PDTDEL	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour la Géorgie	\N	20615	2	2015-01-06 16:06:37	2015-02-19 18:04:51
24522	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22288	1	2015-01-06 16:07:22	2015-01-06 16:07:33
24523	PDT	2015-01-06 00:00:00	2017-07-16 00:00:00	ANCIEN	\N	\N	\N	\N	20591	1	2015-01-06 16:07:48	2017-07-17 11:34:11
24524	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22359	1	2015-01-06 16:08:13	2015-01-06 16:08:21
24525	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21776	1	2015-01-06 16:08:34	2015-01-06 16:08:37
24526	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21947	1	2015-01-06 16:09:00	2015-01-06 16:09:07
24527	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21304	1	2015-01-06 16:10:04	2015-01-06 16:10:19
24528	PDT	2015-01-06 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	21270	1	2015-01-06 16:10:53	2015-01-08 17:14:29
24529	PDT	2015-01-06 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	21873	1	2015-01-06 16:18:04	2016-03-11 18:02:51
24530	PDTDEL	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour le Danemark	\N	21927	2	2015-01-06 16:18:57	2015-01-14 10:08:48
24531	PDTDEL	2015-01-06 00:00:00	2015-01-13 00:00:00	ANCIEN	\N	\N	pour l'Islande	\N	21172	\N	2015-01-06 16:19:17	2015-01-14 10:07:46
24532	PDTDEL	2015-01-06 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	pour la Suède	\N	21763	5	2015-01-06 16:19:38	2017-09-25 09:56:00
24533	PDT	2015-01-06 00:00:00	2015-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	21010	1	2015-01-06 16:21:58	2015-05-26 11:57:55
24534	PDT	2015-01-06 00:00:00	2015-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	21173	1	2015-01-06 16:22:22	2015-07-09 15:11:15
24535	PDT	2015-01-06 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	21766	1	2015-01-06 16:22:50	2017-09-25 09:56:00
24536	PDT	2015-01-06 00:00:00	2016-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	20655	1	2015-01-06 16:23:11	2017-01-03 11:09:24
24537	PDT	2015-01-06 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	20677	1	2015-01-06 16:23:35	2015-06-12 15:59:49
24538	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20670	1	2015-01-06 16:24:03	2015-01-06 16:24:07
24539	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20937	1	2015-01-06 16:26:13	2015-01-06 16:26:16
24540	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21350	1	2015-01-06 16:26:43	2015-01-06 16:26:49
24541	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21082	1	2015-01-06 16:27:05	2015-01-06 16:27:13
24542	PDT	2015-01-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20310	1	2015-01-06 16:27:29	2015-01-06 16:27:39
24543	PDT	2015-01-06 00:00:00	2015-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	20387	1	2015-01-06 16:28:03	2015-04-07 16:50:27
25225	VICPDT	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20582	2	2015-02-13 10:34:14	2015-02-13 10:35:50
25226	VICPDT	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21954	3	2015-02-13 10:34:24	2015-02-13 10:35:56
25227	VICPDT	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22321	4	2015-02-13 10:34:31	2015-02-13 10:35:59
25228	VICPDT	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21615	5	2015-02-13 10:34:39	2015-02-13 10:36:03
25229	VICPDT	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22237	6	2015-02-13 10:34:50	2015-02-13 10:36:06
25230	VICPDT	2015-02-13 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	21862	7	2015-02-13 10:34:56	2016-03-11 18:02:51
25231	VICPDT	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20296	8	2015-02-13 10:35:07	2015-02-13 10:36:13
25232	VICPDT	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22065	9	2015-02-13 10:35:16	2015-02-13 10:36:17
25233	SECRET	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20868	10	2015-02-13 10:35:26	2015-02-13 10:36:21
25234	SECRET	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20981	11	2015-02-13 10:35:33	2015-02-13 10:36:32
25235	SECRET	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22107	12	2015-02-13 10:35:38	2015-02-13 10:36:37
25253	VICPDT	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22165	2	2015-02-13 14:19:00	2015-02-13 14:23:26
25254	VICPDT	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20487	3	2015-02-13 14:19:11	2015-02-13 14:23:29
25255	VICPDT	2015-02-13 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	21829	4	2015-02-13 14:19:17	2016-12-12 16:10:15
25256	VICPDT	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21569	5	2015-02-13 14:19:23	2015-02-13 14:23:35
25257	VICPDT	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20321	6	2015-02-13 14:19:34	2015-02-13 14:23:38
25258	VICPDT	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20806	7	2015-02-13 14:19:43	2015-02-13 14:23:41
25259	VICPDT	2015-02-13 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	21857	8	2015-02-13 14:19:49	2016-03-11 18:02:51
25260	VICPDT	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21684	9	2015-02-13 14:19:55	2015-02-13 14:23:48
25265	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22547	\N	\N	\N
25267	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22549	\N	\N	2017-09-24 13:25:54
25268	MEMBRE	2014-10-01 00:00:00	2014-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22550	\N	\N	\N
25269	MEMBRE	2014-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22551	\N	\N	2017-10-01 09:41:22
25270	MEMBRE	2014-10-01 00:00:00	2014-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22552	\N	\N	\N
25271	MEMBRE	2014-10-01 00:00:00	2017-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	22553	\N	\N	2017-07-24 09:58:00
25272	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22554	\N	\N	\N
25273	MEMBRE	2014-10-01 00:00:00	2014-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22555	\N	\N	\N
25274	MEMBRE	2014-10-01 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	22556	\N	\N	2015-06-12 16:01:25
25275	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22557	\N	\N	\N
25276	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22558	\N	\N	\N
25277	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22559	\N	\N	\N
25278	MEMBRE	2014-10-01 00:00:00	2016-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	22560	\N	\N	2016-11-18 12:37:50
25280	MEMBRE	2014-10-01 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	22562	\N	\N	\N
25281	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22563	\N	\N	2017-09-24 18:16:52
25282	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22564	\N	\N	\N
25283	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22565	\N	\N	2017-09-24 17:29:37
25284	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22566	\N	\N	\N
25285	MEMBRE	2014-10-01 00:00:00	2014-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22567	\N	\N	\N
25286	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22568	\N	\N	\N
25288	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22570	\N	\N	\N
25289	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22571	\N	\N	\N
25291	MEMBRE	2014-10-01 00:00:00	2014-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22573	\N	\N	\N
25292	MEMBRE	2014-10-01 00:00:00	2014-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22574	\N	\N	\N
25293	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22575	\N	\N	2017-09-24 17:04:02
25294	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22576	\N	\N	\N
25295	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22577	\N	\N	\N
25296	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22578	\N	\N	2017-09-24 16:45:26
25297	MEMBRE	2014-10-01 00:00:00	2014-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22579	\N	\N	\N
25298	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22580	\N	\N	\N
25299	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22581	\N	\N	\N
25300	MEMBRE	2014-10-01 00:00:00	2014-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22582	\N	\N	\N
25301	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22583	\N	\N	\N
25302	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22584	\N	\N	2017-09-24 19:31:54
25303	MEMBRE	2014-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22585	\N	\N	2017-10-01 09:22:38
25304	MEMBRE	2014-10-01 00:00:00	2014-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22586	\N	\N	\N
25305	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22587	\N	\N	\N
25306	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22588	\N	\N	\N
25307	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	22589	\N	\N	\N
25308	MEMBRE	2014-10-01 00:00:00	2014-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22590	\N	\N	\N
25388	MEMBRE	2015-01-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22658	\N	\N	2017-09-24 13:25:54
25390	MEMBRE	2015-01-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	22660	\N	\N	\N
26005	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23065	\N	\N	\N
26041	SECRET	2015-03-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	22799	\N	\N	\N
26042	SECRET	2015-03-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	22944	\N	\N	\N
26043	SECRET	2015-03-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	22932	\N	\N	\N
26044	SECRET	2015-03-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	22781	\N	\N	\N
26104	MEMBRE	2015-03-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23102	\N	2015-03-05 16:03:39	2015-11-12 15:26:22
26105	MEMBRE	2015-03-05 00:00:00	2015-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	23103	\N	2015-03-05 16:03:39	2015-11-18 09:39:25
26259	MEMBRE	2015-03-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23170	\N	2015-03-19 12:21:37	\N
26260	SECRET	2015-03-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21577	14	2015-03-20 09:20:30	2015-03-20 09:20:55
26280	VICPDT	2015-03-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20969	\N	2015-03-20 18:13:24	\N
26281	VICPDT	2015-03-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21343	\N	2015-03-20 18:13:30	\N
26282	SECRET	2015-03-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	21038	\N	2015-03-20 18:13:34	\N
26283	MEMBRE	2015-03-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23171	\N	2015-03-24 13:48:12	2015-11-12 15:26:22
26294	PDT	2015-04-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23048	\N	\N	2017-09-24 13:14:55
26295	VICPDT	2015-04-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23044	\N	\N	\N
26296	VICPDT	2015-04-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23174	\N	\N	2017-09-24 17:15:15
26421	VICPDT	2015-05-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22685	\N	\N	2017-09-24 19:31:54
26425	VICPDT	2015-05-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	22874	\N	\N	\N
26430	PDT	2015-03-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23095	\N	\N	2017-09-24 17:48:21
26431	VICPDT	2015-03-25 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22635	\N	\N	2017-10-01 10:01:39
26432	PDT	2015-03-25 00:00:00	2015-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	23090	\N	\N	\N
26433	VICPDT	2015-03-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	22640	\N	\N	\N
26434	VICPDT	2015-03-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23092	\N	\N	2017-09-24 13:14:55
26435	VICPDT	2015-03-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	22637	\N	\N	\N
26436	SECRET	2015-03-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	22654	\N	\N	\N
26437	SECRET	2015-03-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	23108	\N	\N	\N
26438	SECRET	2015-03-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	23093	\N	\N	\N
26439	SECRET	2015-03-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	22646	\N	\N	2017-09-24 17:04:02
26440	SECRET	2015-03-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	22657	\N	\N	\N
26443	MEMBRE	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23259	\N	\N	2017-09-24 17:06:55
26653	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23392	\N	\N	\N
26654	MEMBRE	2014-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	23393	\N	\N	\N
26687	MEMBRE	2015-11-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	23419	\N	\N	\N
27012	MEMBRE	2016-06-15 00:00:00	2016-09-28 00:00:00	ANCIEN	\N	\N	\N	\N	23710	\N	\N	\N
27055	VICPDT	2016-09-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	23710	\N	\N	\N
27056	VICPDT	2016-09-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	23656	\N	\N	\N
27057	VICPDT	2016-09-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	23672	\N	\N	\N
27058	VICPDT	2016-09-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	23699	\N	\N	\N
27059	VICPDT	2016-09-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	23701	\N	\N	\N
27061	MEMBRE	2016-09-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23753	\N	2016-09-28 16:44:33	\N
27522	MEMBRE	2017-10-11 00:00:00	2018-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	24089	\N	2017-10-13 16:28:53	2018-01-24 10:52:11
27523	MEMBRE	2017-10-11 00:00:00	2017-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	24090	\N	2017-10-13 16:28:53	2017-12-19 17:53:39
27524	MEMBRE	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24091	\N	2017-10-13 16:28:53	\N
27525	MEMBRE	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24092	\N	2017-10-13 16:28:53	\N
27526	MEMBRE	2017-10-11 00:00:00	2017-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	24093	\N	2017-10-13 16:28:53	2017-11-28 17:06:26
28280	MEMBRE	2017-10-27 00:00:00	2017-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	24847	\N	2017-10-31 09:54:24	2017-12-07 14:56:37
28281	MEMBRE	2017-10-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24848	\N	2017-10-31 09:54:24	\N
28282	MEMBRE	2017-10-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24849	\N	2017-10-31 09:54:24	\N
28283	MEMBRE	2017-10-27 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	24850	\N	2017-10-31 09:54:24	2018-01-25 16:05:24
28284	MEMBRE	2017-10-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24851	\N	2017-10-31 09:54:24	\N
28285	MEMBRE	2017-10-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24852	\N	2017-10-31 09:54:24	\N
28286	MEMBRE	2017-10-30 00:00:00	2017-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	24853	\N	2017-10-31 09:54:47	2017-12-14 15:43:38
28287	MEMBRE	2017-10-31 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	24854	\N	2017-10-31 09:56:04	2018-01-25 17:36:21
22642	MEMBRE	2014-10-17 00:00:00	2015-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	20586	\N	2014-10-21 09:23:47	2015-03-03 10:16:55
22643	MEMBRE	2014-10-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20587	\N	2014-10-21 09:24:03	\N
22644	MEMBRE	2014-10-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20588	\N	2014-10-21 09:24:03	\N
22645	MEMBRE	2014-10-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20589	\N	2014-10-21 09:24:03	\N
22646	MEMBRE	2014-10-16 00:00:00	2015-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	20590	\N	2014-10-21 09:24:27	2015-01-29 10:52:28
22647	MEMBRE	2014-10-16 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	20591	\N	2014-10-21 09:24:27	2015-01-06 16:07:48
22648	MEMBRE	2014-10-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20592	\N	2014-10-21 09:24:27	\N
22649	MEMBRE	2014-10-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20593	\N	2014-10-21 09:24:27	\N
22650	MEMBRE	2014-10-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20594	\N	2014-10-21 09:24:27	\N
22651	MEMBRE	2014-10-16 00:00:00	2015-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	20595	\N	2014-10-21 09:24:27	2015-01-28 09:38:47
23317	MEMBRE	2014-10-27 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	21228	\N	2014-10-27 16:55:09	2015-01-08 17:14:29
23318	MEMBRE	2014-10-27 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	21229	\N	2014-10-27 16:55:09	2015-01-08 17:14:29
23319	MEMBRE	2014-10-27 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	21230	\N	2014-10-27 16:55:09	2015-01-08 17:14:29
23320	MEMBRE	2014-10-27 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	21231	\N	2014-10-27 16:55:09	2015-01-08 17:14:29
23321	MEMBRE	2014-10-21 00:00:00	2015-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	21232	\N	2014-10-27 16:55:40	2015-01-29 10:54:02
23322	MEMBRE	2014-10-21 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	21233	\N	2014-10-27 16:55:40	2015-02-19 16:30:14
23323	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21234	\N	2014-10-27 16:55:40	\N
23324	MEMBRE	2014-10-21 00:00:00	2015-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	21235	\N	2014-10-27 16:57:25	2015-01-28 10:24:06
23325	MEMBRE	2014-10-21 00:00:00	2015-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	21236	\N	2014-10-27 16:57:25	2015-01-14 14:09:03
23326	MEMBRE	2014-10-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21237	\N	2014-10-27 16:57:25	\N
23327	MEMBRE	2014-10-24 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21238	\N	2014-10-27 16:58:11	\N
23392	MEMBRE	2014-10-17 00:00:00	2015-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	21303	\N	2014-10-28 16:51:57	2015-02-12 12:45:28
23393	MEMBRE	2014-10-17 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21304	\N	2014-10-28 16:51:57	2015-01-06 16:10:04
23394	MEMBRE	2014-10-17 00:00:00	2015-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	21305	\N	2014-10-28 16:51:57	2015-02-09 15:47:14
23593	MEMBRE	2014-10-28 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	21504	\N	2014-10-29 15:53:57	2017-09-25 09:57:52
23594	MEMBRE	2014-10-28 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	21505	\N	2014-10-29 15:53:57	2017-09-25 09:57:52
23595	MEMBRE	2014-10-28 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	21506	\N	2014-10-29 15:53:57	2017-09-25 09:57:52
23596	MEMBRE	2014-10-28 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	21507	\N	2014-10-29 15:53:58	2017-09-25 09:57:52
23597	MEMBRE	2014-10-28 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21508	\N	2014-10-29 15:53:58	2015-01-06 17:43:34
23598	MEMBRE	2014-10-28 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	21509	\N	2014-10-29 15:53:58	2017-09-25 09:57:52
23599	MEMBRE	2014-10-28 00:00:00	2015-03-09 00:00:00	ANCIEN	\N	\N	\N	\N	21510	\N	2014-10-29 15:53:58	2015-03-10 10:01:03
23600	MEMBRE	2014-10-28 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	21511	\N	2014-10-29 15:53:58	2017-09-25 09:57:52
23601	MEMBRE	2014-10-28 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	21512	\N	2014-10-29 15:53:58	2017-09-25 09:57:52
23602	MEMBRE	2014-10-27 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21513	\N	2014-10-29 15:55:41	\N
23603	MEMBRE	2014-10-27 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21514	\N	2014-10-29 15:55:41	\N
23604	MEMBRE	2014-10-27 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21515	\N	2014-10-29 15:55:41	\N
23605	MEMBRE	2014-10-27 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21516	\N	2014-10-29 15:55:41	\N
23606	MEMBRE	2014-10-27 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21517	\N	2014-10-29 15:55:41	\N
23607	MEMBRE	2014-10-27 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21518	\N	2014-10-29 15:55:41	\N
23608	MEMBRE	2014-10-27 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	21519	\N	2014-10-29 15:55:41	2015-01-06 17:50:30
23609	MEMBRE	2014-10-27 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21520	\N	2014-10-29 15:55:41	\N
23610	MEMBRE	2014-10-24 00:00:00	2015-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	21521	\N	2014-10-29 15:56:10	2015-02-06 15:54:36
23611	MEMBRE	2014-10-24 00:00:00	2016-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	21522	\N	2014-10-29 15:56:10	2016-11-14 11:07:47
23612	MEMBRE	2014-10-24 00:00:00	2016-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	21523	\N	2014-10-29 15:56:10	2016-11-14 11:07:47
23613	MEMBRE	2014-10-24 00:00:00	2016-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	21524	\N	2014-10-29 15:56:10	2016-11-14 11:07:47
23614	MEMBRE	2014-10-24 00:00:00	2016-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	21525	\N	2014-10-29 15:56:10	2016-11-14 11:07:47
23615	MEMBRE	2014-10-29 00:00:00	2017-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	21526	\N	2014-10-29 16:19:47	2017-07-20 14:38:36
23616	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21527	\N	2014-10-29 16:19:47	\N
23617	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21528	\N	2014-10-29 16:19:47	\N
23618	MEMBRE	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21529	\N	2014-10-29 16:19:47	\N
23619	MEMBRE	2014-10-29 00:00:00	2015-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	21530	\N	2014-10-29 16:19:47	2015-02-09 15:42:38
23872	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21783	\N	2014-10-30 18:34:28	\N
23873	MEMBRE	2014-10-30 00:00:00	2015-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	21784	\N	2014-10-30 18:34:28	2015-02-03 10:19:36
23874	MEMBRE	2014-10-30 00:00:00	2015-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	21785	\N	2014-10-30 18:34:28	2015-03-06 09:52:53
23875	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21786	\N	2014-10-30 18:34:28	\N
23876	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21787	\N	2014-10-30 18:34:28	\N
23877	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21788	\N	2014-10-30 18:34:28	\N
23878	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21789	\N	2014-10-30 18:34:28	\N
23879	MEMBRE	2014-10-30 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	21790	\N	2014-10-30 18:34:29	2015-02-11 17:11:57
23880	MEMBRE	2014-10-30 00:00:00	2015-02-11 00:00:00	ANCIEN	\N	\N	\N	\N	21791	\N	2014-10-30 18:34:29	2015-02-12 12:45:07
23881	MEMBRE	2014-10-30 00:00:00	2015-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	21792	\N	2014-10-30 18:34:29	2015-04-09 15:21:16
23882	MEMBRE	2014-10-30 00:00:00	2015-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	21793	\N	2014-10-30 18:34:29	2015-03-11 10:57:38
23883	MEMBRE	2014-10-30 00:00:00	2015-05-26 00:00:00	ANCIEN	\N	\N	\N	\N	21794	\N	2014-10-30 18:34:29	2015-05-27 16:38:40
23884	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21795	\N	2014-10-30 18:34:29	\N
23885	MEMBRE	2014-10-30 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	21796	\N	2014-10-30 18:34:29	2015-02-11 18:01:12
23886	MEMBRE	2014-10-30 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	21797	\N	2014-10-30 18:34:29	2015-02-05 18:51:13
23887	MEMBRE	2014-10-30 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	21798	\N	2014-10-30 18:34:29	2015-02-19 15:42:14
23888	MEMBRE	2014-10-30 00:00:00	2015-01-21 00:00:00	ANCIEN	\N	\N	\N	\N	21799	\N	2014-10-30 18:34:29	2015-01-22 10:50:55
23889	MEMBRE	2014-10-30 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	21800	\N	2014-10-30 18:34:29	2015-02-20 12:16:44
23890	MEMBRE	2014-10-30 00:00:00	2015-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	21801	\N	2014-10-30 18:34:29	2015-03-04 17:16:03
23891	MEMBRE	2014-10-30 00:00:00	2015-04-09 00:00:00	ANCIEN	\N	\N	\N	\N	21802	\N	2014-10-30 18:34:29	2015-04-10 15:09:58
23892	MEMBRE	2014-10-30 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	21803	\N	2014-10-30 18:34:29	2015-02-19 17:22:23
23893	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21804	\N	2014-10-30 18:34:29	\N
23894	MEMBRE	2014-10-30 00:00:00	2015-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	21805	\N	2014-10-30 18:34:29	2015-02-06 14:45:56
23895	MEMBRE	2014-10-30 00:00:00	2015-01-06 00:00:00	ANCIEN	\N	\N	\N	\N	21806	\N	2014-10-30 18:34:29	2015-01-07 15:24:09
23896	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21807	\N	2014-10-30 18:34:29	\N
23897	MEMBRE	2014-10-30 00:00:00	2015-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	21808	\N	2014-10-30 18:34:29	2015-02-18 13:28:05
23898	MEMBRE	2014-10-30 00:00:00	2016-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	21809	\N	2014-10-30 18:34:29	2016-03-30 11:51:00
23899	MEMBRE	2014-10-30 00:00:00	2015-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	21810	\N	2014-10-30 18:34:29	2015-01-30 15:57:39
23900	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21811	\N	2014-10-30 18:34:29	\N
23901	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21812	\N	2014-10-30 18:34:29	\N
23902	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21813	\N	2014-10-30 18:34:29	\N
23903	MEMBRE	2014-10-30 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	21814	\N	2014-10-30 18:34:29	2015-02-11 16:58:45
23904	MEMBRE	2014-10-30 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	21815	\N	2014-10-30 18:34:29	2015-02-11 11:00:53
23905	MEMBRE	2014-10-30 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	21816	\N	2014-10-30 18:34:29	2015-02-11 12:09:50
23906	MEMBRE	2014-10-30 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	21817	\N	2014-10-30 18:34:30	2015-02-05 12:04:31
23907	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21818	\N	2014-10-30 18:34:30	\N
23908	MEMBRE	2014-10-30 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	21819	\N	2014-10-30 18:34:30	2015-02-20 10:43:52
23909	MEMBRE	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	21820	\N	2014-10-30 18:34:30	\N
24204	MEMBRE	2014-10-24 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22115	\N	2014-11-05 15:05:42	\N
24451	MEMBRE	2014-12-11 00:00:00	2017-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	22358	\N	2014-12-18 09:26:55	2017-07-20 14:38:34
24452	MEMBRE	2014-12-17 00:00:00	2015-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	22359	\N	2014-12-18 10:00:08	2015-01-06 16:08:13
24453	MEMBRE	2014-12-17 00:00:00	2015-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	22360	\N	2014-12-18 13:13:13	2015-01-13 15:59:26
24454	MEMBRE	2014-12-18 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22361	\N	2014-12-18 14:35:25	\N
24455	MEMBRE	2014-12-18 00:00:00	2014-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	22362	\N	2014-12-18 14:47:16	2014-12-23 09:10:35
24913	PDTDEL	2015-02-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	pour le Burundi	\N	22506	10	2015-02-03 15:26:59	2015-02-03 16:49:16
32832	MEMBRE	2020-10-20 00:00:00	2021-01-03 00:00:00	ANCIEN	\N	\N	\N	\N	28265	\N	\N	\N
24642	MEMBRE	2015-01-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	22394	\N	2015-01-15 16:37:36	\N
30787	MEMBRE	2017-10-01 00:00:00	2018-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	26460	\N	\N	\N
30790	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26463	\N	\N	\N
30794	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26467	\N	\N	\N
30962	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26556	\N	\N	\N
31082	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26620	\N	\N	\N
31244	MEMBRE	2018-02-07 00:00:00	2020-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	26737	\N	2018-04-03 16:01:17	\N
31270	MEMBRE	2018-05-02 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26755	\N	2018-05-03 18:24:45	\N
31449	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26910	\N	\N	\N
31450	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26911	\N	\N	\N
31526	MEMBRE	2019-02-14 00:00:00	2019-03-12 00:00:00	ANCIEN	\N	\N	\N	\N	26978	\N	\N	\N
31527	MEMBRE	2019-02-14 00:00:00	2019-06-24 00:00:00	ANCIEN	\N	\N	\N	\N	26979	\N	\N	\N
31656	MEMBRE	2020-02-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	27088	\N	\N	\N
31613	MEMBRE	2019-10-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	27048	\N	\N	\N
31677	MEMBRE	2019-11-21 00:00:00	2021-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	27106	\N	\N	\N
31730	MEMBRE	2020-10-07 00:00:00	2021-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	27159	\N	\N	\N
31731	MEMBRE	2020-10-07 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	27160	\N	\N	\N
31905	MEMBRE	2020-10-09 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	27334	\N	\N	\N
31906	MEMBRE	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27335	\N	\N	\N
31907	MEMBRE	2020-10-09 00:00:00	2020-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	27336	\N	\N	\N
31908	MEMBRE	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27337	\N	\N	\N
31909	MEMBRE	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27338	\N	\N	\N
31910	MEMBRE	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27339	\N	\N	\N
31911	MEMBRE	2020-10-08 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	27340	\N	\N	\N
31912	MEMBRE	2020-10-08 00:00:00	2021-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	27341	\N	\N	\N
31913	MEMBRE	2020-10-08 00:00:00	2021-01-03 00:00:00	ANCIEN	\N	\N	\N	\N	27342	\N	\N	\N
31914	MEMBRE	2020-10-08 00:00:00	2021-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	27343	\N	\N	\N
31915	MEMBRE	2020-10-08 00:00:00	2020-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	27344	\N	\N	\N
31916	MEMBRE	2020-10-08 00:00:00	2021-01-14 00:00:00	ANCIEN	\N	\N	\N	\N	27345	\N	\N	\N
31917	MEMBRE	2020-10-09 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	27346	\N	\N	\N
31918	MEMBRE	2020-10-09 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	27347	\N	\N	\N
31919	MEMBRE	2020-10-09 00:00:00	2020-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	27348	\N	\N	\N
31920	MEMBRE	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27349	\N	\N	\N
31921	MEMBRE	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27350	\N	\N	\N
31922	MEMBRE	2020-10-09 00:00:00	2021-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	27351	\N	\N	\N
32209	MEMBRE	2020-10-14 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	27638	\N	\N	\N
32210	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27639	\N	\N	\N
32211	MEMBRE	2020-10-14 00:00:00	2021-06-23 00:00:00	ANCIEN	\N	\N	\N	\N	27640	\N	\N	\N
32212	MEMBRE	2020-10-14 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	27641	\N	\N	\N
32213	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27642	\N	\N	\N
32214	MEMBRE	2020-10-14 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	27643	\N	\N	\N
32215	MEMBRE	2020-10-14 00:00:00	2021-01-14 00:00:00	ANCIEN	\N	\N	\N	\N	27644	\N	\N	\N
32216	MEMBRE	2020-10-14 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	27645	\N	\N	\N
32217	MEMBRE	2020-10-14 00:00:00	2021-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	27646	\N	\N	\N
32218	MEMBRE	2020-10-14 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	27647	\N	\N	\N
32219	MEMBRE	2020-10-14 00:00:00	2020-12-23 00:00:00	ANCIEN	\N	\N	\N	\N	27648	\N	\N	\N
32220	MEMBRE	2020-10-14 00:00:00	2021-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	27649	\N	\N	\N
32221	MEMBRE	2020-10-14 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	27650	\N	\N	\N
32222	MEMBRE	2020-10-14 00:00:00	2021-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	27651	\N	\N	\N
32223	MEMBRE	2020-10-14 00:00:00	2020-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	27652	\N	\N	\N
32224	MEMBRE	2020-10-14 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	27653	\N	\N	\N
32225	MEMBRE	2020-10-14 00:00:00	2020-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	27654	\N	\N	\N
32794	MEMBRE	2020-10-21 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	28227	\N	\N	\N
32795	MEMBRE	2020-10-21 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	28228	\N	\N	\N
32796	MEMBRE	2020-10-21 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	28229	\N	\N	\N
32797	MEMBRE	2020-10-21 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	28230	\N	\N	\N
32798	MEMBRE	2020-10-21 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	28231	\N	\N	\N
32799	MEMBRE	2020-10-21 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	28232	\N	\N	\N
32800	MEMBRE	2020-10-21 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	28233	\N	\N	\N
32801	MEMBRE	2020-10-21 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	28234	\N	\N	\N
32802	MEMBRE	2020-10-21 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	28235	\N	\N	\N
32803	MEMBRE	2020-10-21 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	28236	\N	\N	\N
32804	MEMBRE	2020-10-21 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	28237	\N	\N	\N
32805	MEMBRE	2020-10-21 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	28238	\N	\N	\N
32806	MEMBRE	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28239	\N	\N	\N
32807	MEMBRE	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28240	\N	\N	\N
32808	MEMBRE	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28241	\N	\N	\N
32809	MEMBRE	2020-10-20 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	28242	\N	\N	\N
32810	MEMBRE	2020-10-20 00:00:00	2021-01-03 00:00:00	ANCIEN	\N	\N	\N	\N	28243	\N	\N	\N
32811	MEMBRE	2020-10-20 00:00:00	2021-01-21 00:00:00	ANCIEN	\N	\N	\N	\N	28244	\N	\N	\N
32812	MEMBRE	2020-10-20 00:00:00	2021-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	28245	\N	\N	\N
32813	MEMBRE	2020-10-20 00:00:00	2021-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	28246	\N	\N	\N
32814	MEMBRE	2020-10-20 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	28247	\N	\N	\N
32815	MEMBRE	2020-10-20 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	28248	\N	\N	\N
32816	MEMBRE	2020-10-20 00:00:00	2020-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	28249	\N	\N	\N
32817	MEMBRE	2020-10-20 00:00:00	2020-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	28250	\N	\N	\N
32818	MEMBRE	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28251	\N	\N	\N
32819	MEMBRE	2020-10-20 00:00:00	2020-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	28252	\N	\N	\N
32820	MEMBRE	2020-10-20 00:00:00	2020-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	28253	\N	\N	\N
32821	MEMBRE	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28254	\N	\N	\N
32822	MEMBRE	2020-10-20 00:00:00	2020-12-23 00:00:00	ANCIEN	\N	\N	\N	\N	28255	\N	\N	\N
32823	MEMBRE	2020-10-20 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	28256	\N	\N	\N
32824	MEMBRE	2020-10-20 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	28257	\N	\N	\N
32825	MEMBRE	2020-10-20 00:00:00	2021-06-23 00:00:00	ANCIEN	\N	\N	\N	\N	28258	\N	\N	\N
32826	MEMBRE	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28259	\N	\N	\N
32827	MEMBRE	2020-10-20 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	28260	\N	\N	\N
32828	MEMBRE	2020-10-20 00:00:00	2020-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	28261	\N	\N	\N
32829	MEMBRE	2020-10-20 00:00:00	2022-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	28262	\N	\N	\N
32833	MEMBRE	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28266	\N	\N	\N
34248	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29263	\N	\N	\N
34601	MEMBRE	2020-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29462	\N	\N	\N
34602	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29463	\N	\N	\N
34603	MEMBRE	2020-12-15 00:00:00	2021-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	29464	\N	\N	\N
34604	MEMBRE	2020-12-15 00:00:00	2021-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	29465	\N	\N	\N
34637	MEMBRE	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29495	\N	\N	\N
34684	MEMBRE	2020-12-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	29524	\N	\N	\N
35106	MEMBRE	2020-10-01 00:00:00	2021-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	29830	\N	\N	\N
35593	MEMBRE	2021-02-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	30094	\N	\N	\N
35644	MEMBRE	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30129	\N	\N	\N
35749	MEMBRE	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30149	\N	\N	\N
35844	PDT	2021-02-15 00:00:00	2021-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	29937	\N	\N	\N
35904	SECRET	2021-03-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	29548	\N	\N	\N
35931	VICPDT	2021-03-17 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29859	\N	\N	\N
35940	VICPDT	2021-03-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	30243	\N	\N	\N
35995	MEMBRE	2021-03-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	30292	\N	\N	\N
35996	MEMBRE	2021-03-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	30293	\N	\N	\N
35997	MEMBRE	2021-03-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	30294	\N	\N	\N
35998	MEMBRE	2021-03-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	30295	\N	\N	\N
35999	MEMBRE	2021-03-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30296	\N	\N	\N
36000	MEMBRE	2021-03-25 00:00:00	2021-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	30297	\N	\N	\N
36058	MEMBRE	2021-06-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	30339	\N	\N	\N
36257	MEMBRE	2022-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30501	\N	\N	\N
36403	MEMBRE	2022-05-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30621	\N	\N	\N
36458	MEMBRE	2022-09-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30675	\N	\N	\N
36474	MEMBRE	2022-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30691	\N	\N	\N
37132	MEMBRE	2023-10-10 00:00:00	2024-02-27 00:00:00	ACTIF	\N	\N	\N	\N	31324	\N	\N	\N
37133	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31325	\N	\N	\N
37134	MEMBRE	2023-10-10 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	31326	\N	\N	\N
37135	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31327	\N	\N	\N
37136	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31328	\N	\N	\N
37137	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31329	\N	\N	\N
37400	MEMBRE	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31592	\N	\N	\N
37401	MEMBRE	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31593	\N	\N	\N
37402	MEMBRE	2023-10-12 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	31594	\N	\N	\N
37404	MEMBRE	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31596	\N	\N	\N
37405	MEMBRE	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31597	\N	\N	\N
37414	MEMBRE	2023-10-12 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	31606	\N	\N	\N
37415	MEMBRE	2023-10-12 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	31607	\N	\N	\N
37416	MEMBRE	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31608	\N	\N	\N
37417	MEMBRE	2023-10-12 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	31609	\N	\N	\N
37418	MEMBRE	2023-10-12 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	31610	\N	\N	\N
37419	MEMBRE	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31611	\N	\N	\N
38006	MEMBRE	2023-10-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32201	\N	\N	\N
38184	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32379	\N	\N	\N
38185	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32380	\N	\N	\N
38186	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32381	\N	\N	\N
38187	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32382	\N	\N	\N
38188	MEMBRE	2023-10-25 00:00:00	2024-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	32383	\N	\N	\N
38189	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32384	\N	\N	\N
38190	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32385	\N	\N	\N
38191	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32386	\N	\N	\N
38192	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32387	\N	\N	\N
38193	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32388	\N	\N	\N
38194	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32389	\N	\N	\N
38195	MEMBRE	2023-10-25 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	32390	\N	\N	\N
38225	MEMBRE	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32420	\N	\N	\N
38226	MEMBRE	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32421	\N	\N	\N
38236	MEMBRE	2023-10-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32431	\N	\N	\N
38412	MEMBRE	2023-11-01 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	32607	\N	\N	\N
38413	MEMBRE	2023-11-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32608	\N	\N	\N
38414	MEMBRE	2023-11-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32609	\N	\N	\N
38415	MEMBRE	2023-11-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32610	\N	\N	\N
38487	MEMBRE	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32682	\N	\N	\N
38488	MEMBRE	2023-11-03 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	32683	\N	\N	\N
38489	MEMBRE	2023-11-03 00:00:00	2024-01-04 00:00:00	ANCIEN	\N	\N	\N	\N	32684	\N	\N	\N
38490	MEMBRE	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32685	\N	\N	\N
38491	MEMBRE	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32686	\N	\N	\N
38492	MEMBRE	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32687	\N	\N	\N
38493	MEMBRE	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32688	\N	\N	\N
38494	MEMBRE	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32689	\N	\N	\N
38495	MEMBRE	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32690	\N	\N	\N
38496	MEMBRE	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32691	\N	\N	\N
38497	MEMBRE	2023-11-03 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	32692	\N	\N	\N
38498	MEMBRE	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32693	\N	\N	\N
38499	MEMBRE	2023-11-03 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	32694	\N	\N	\N
38500	MEMBRE	2023-11-03 00:00:00	2024-01-30 00:00:00	ACTIF	\N	\N	\N	\N	32695	\N	\N	\N
38501	MEMBRE	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32696	\N	\N	\N
38502	MEMBRE	2023-11-03 00:00:00	2024-02-13 00:00:00	ACTIF	\N	\N	\N	\N	32697	\N	\N	\N
38503	MEMBRE	2023-11-03 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	32698	\N	\N	\N
38504	MEMBRE	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32699	\N	\N	\N
38505	MEMBRE	2023-11-03 00:00:00	2024-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	32700	\N	\N	\N
38506	MEMBRE	2023-11-03 00:00:00	2023-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	32701	\N	\N	\N
38507	MEMBRE	2023-11-03 00:00:00	2024-02-13 00:00:00	ACTIF	\N	\N	\N	\N	32702	\N	\N	\N
38508	MEMBRE	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32703	\N	\N	\N
38509	MEMBRE	2023-11-03 00:00:00	2024-02-29 00:00:00	ACTIF	\N	\N	\N	\N	32704	\N	\N	\N
38530	MEMBRE	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32725	\N	\N	\N
38531	MEMBRE	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32726	\N	\N	\N
38532	MEMBRE	2023-11-03 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	32727	\N	\N	\N
38635	MEMBRE	2023-11-09 00:00:00	2024-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	32830	\N	\N	\N
38640	MEMBRE	2023-11-09 00:00:00	2024-02-08 00:00:00	ACTIF	\N	\N	\N	\N	32835	\N	\N	\N
38641	MEMBRE	2023-11-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32836	\N	\N	\N
38642	MEMBRE	2023-11-09 00:00:00	2024-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	32837	\N	\N	\N
38643	MEMBRE	2023-11-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32838	\N	\N	\N
38644	MEMBRE	2023-11-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32839	\N	\N	\N
38645	MEMBRE	2023-11-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32840	\N	\N	\N
38646	MEMBRE	2023-11-09 00:00:00	2024-01-25 00:00:00	ACTIF	\N	\N	\N	\N	32841	\N	\N	\N
38647	MEMBRE	2023-11-09 00:00:00	2024-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	32842	\N	\N	\N
38648	MEMBRE	2023-11-09 00:00:00	2024-02-25 00:00:00	ACTIF	\N	\N	\N	\N	32843	\N	\N	\N
38649	MEMBRE	2023-11-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32844	\N	\N	\N
38650	MEMBRE	2023-11-09 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	32845	\N	\N	\N
38651	MEMBRE	2023-11-09 00:00:00	2024-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	32846	\N	\N	\N
38652	MEMBRE	2023-11-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32847	\N	\N	\N
38653	MEMBRE	2023-11-09 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	32848	\N	\N	\N
38654	MEMBRE	2023-11-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32849	\N	\N	\N
38655	MEMBRE	2023-11-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32850	\N	\N	\N
38710	MEMBRE	2023-11-14 00:00:00	2023-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	32905	\N	\N	\N
38711	MEMBRE	2023-11-15 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	32906	\N	\N	\N
38839	MEMBRE	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33034	\N	\N	\N
38872	MEMBRE	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33067	\N	\N	\N
38877	MEMBRE	2023-11-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33072	\N	\N	\N
38889	PDT	2023-11-20 00:00:00	2024-03-20 00:00:00	ANCIEN	\N	\N	\N	\N	32024	\N	\N	\N
38890	PDT	2023-11-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32038	\N	\N	\N
38891	PDT	2023-11-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31488	\N	\N	\N
38892	PDT	2023-11-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31145	\N	\N	\N
38908	MEMBRE	2023-11-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33095	\N	\N	\N
38909	MEMBRE	2023-11-21 00:00:00	2024-02-05 00:00:00	ACTIF	\N	\N	\N	\N	33096	\N	\N	\N
38936	PDTDEL	2023-11-22 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour le koweit	\N	32442	\N	\N	\N
38933	PDT	2023-11-22 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30980	\N	\N	\N
38934	PDT	2023-11-22 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33055	\N	\N	\N
38935	PDTDEL	2023-11-22 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour la Birmanie	\N	33102	\N	\N	\N
39132	MEMBRE	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33177	\N	\N	\N
39151	PDTDEL	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour le Soudan du Sud	\N	33196	\N	\N	\N
39152	MEMBRE	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33197	\N	\N	\N
39191	MEMBRE	2023-12-04 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33236	\N	\N	\N
39192	MEMBRE	2023-12-04 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33237	\N	\N	\N
39193	MEMBRE	2023-12-04 00:00:00	2024-01-30 00:00:00	ACTIF	\N	\N	\N	\N	33238	\N	\N	\N
39203	MEMBRE	2023-12-05 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	33249	\N	\N	\N
39268	MEMBRE	2023-12-07 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	33312	\N	\N	\N
39290	MEMBRE	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33318	\N	\N	\N
39383	MEMBRE	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33353	\N	\N	\N
39401	VICPDT	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33051	\N	\N	\N
39402	VICPDT	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31021	\N	\N	\N
39403	VICPDT	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31258	\N	\N	\N
39404	VICPDT	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31081	\N	\N	\N
39405	VICPDT	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32698	\N	\N	\N
39406	VICPDT	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31653	\N	\N	\N
39407	VICPDT	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33078	\N	\N	\N
39408	SECRET	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32799	\N	\N	\N
39409	SECRET	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31126	\N	\N	\N
39410	SECRET	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30992	\N	\N	\N
39411	SECRET	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32536	\N	\N	\N
39412	VICPDT	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31799	\N	\N	\N
39413	VICPDT	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32286	\N	\N	\N
39414	VICPDT	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33291	\N	\N	\N
39415	VICPDT	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32629	\N	\N	\N
39416	VICPDT	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31807	\N	\N	\N
39417	VICPDT	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32894	\N	\N	\N
39418	VICPDT	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32023	\N	\N	\N
39419	SECRET	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32044	\N	\N	\N
39455	MEMBRE	2023-12-14 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	33381	\N	\N	\N
39476	PDTDEL	2023-12-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour le Brunéi	\N	33105	\N	\N	\N
39634	MEMBRE	2023-12-21 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	33402	\N	\N	\N
39654	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33409	\N	\N	\N
39655	MEMBRE	2023-12-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	29809	\N	\N	\N
39656	MEMBRE	2023-10-01 00:00:00	2024-01-29 00:00:00	ACTIF	\N	\N	\N	\N	33410	\N	\N	\N
39657	MEMBRE	2023-12-22 00:00:00	2024-01-29 00:00:00	ACTIF	\N	\N	\N	\N	30008	\N	\N	\N
39663	MEMBRE	2023-12-22 00:00:00	2024-01-30 00:00:00	ACTIF	\N	\N	\N	\N	29859	\N	\N	\N
39664	MEMBRE	2023-12-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	29966	\N	\N	\N
39671	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33419	\N	\N	\N
39674	MEMBRE	2023-10-01 00:00:00	2024-04-08 00:00:00	ACTIF	\N	\N	\N	\N	33421	\N	\N	\N
39681	MEMBRE	2023-12-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	30280	\N	\N	\N
39684	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33425	\N	\N	\N
39689	MEMBRE	2023-10-01 00:00:00	2024-02-05 00:00:00	ACTIF	\N	\N	\N	\N	33429	\N	\N	\N
39690	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33430	\N	\N	\N
39691	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33431	\N	\N	\N
39692	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33432	\N	\N	\N
39693	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33433	\N	\N	\N
39697	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33436	\N	\N	\N
39773	MEMBRE	2023-10-01 00:00:00	2024-01-22 00:00:00	ACTIF	\N	\N	\N	\N	33459	\N	\N	\N
39784	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33463	\N	\N	\N
39786	MEMBRE	2024-01-09 00:00:00	2024-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	33465	\N	\N	\N
39845	MEMBRE	2024-01-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33513	\N	\N	\N
39846	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33514	\N	\N	\N
39851	MEMBRE	2024-01-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33519	\N	\N	\N
39855	MEMBRE	2024-01-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33523	\N	\N	\N
39863	VICPDT	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31766	\N	\N	\N
39864	VICPDT	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31429	\N	\N	\N
39865	VICPDT	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32181	\N	\N	\N
39866	VICPDT	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30979	\N	\N	\N
39867	SECRET	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33230	\N	\N	\N
39868	SECRET	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31442	\N	\N	\N
39869	VICPDT	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31019	\N	\N	\N
39870	VICPDT	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31089	\N	\N	\N
39871	VICPDT	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31825	\N	\N	\N
39872	VICPDT	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31409	\N	\N	\N
39873	VICPDT	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31255	\N	\N	\N
39874	VICPDT	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31070	\N	\N	\N
30615	MEMBRE	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26335	\N	2018-02-08 09:50:33	\N
30616	MEMBRE	2018-02-01 00:00:00	2018-06-19 00:00:00	ANCIEN	\N	\N	\N	\N	26336	\N	2018-02-08 09:50:54	\N
30617	MEMBRE	2018-02-07 00:00:00	2018-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	26337	\N	2018-02-08 09:51:52	2018-02-14 12:54:55
30677	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26378	\N	\N	\N
30678	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26379	\N	\N	\N
30687	MEMBRE	2017-10-01 00:00:00	2018-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	26388	\N	\N	\N
30690	MEMBRE	2017-10-01 00:00:00	2018-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	26391	\N	\N	\N
30691	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26392	\N	\N	\N
30696	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26397	\N	\N	\N
30697	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26398	\N	\N	\N
30698	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26399	\N	\N	\N
30704	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26405	\N	\N	\N
30705	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26406	\N	\N	\N
30706	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26407	\N	\N	\N
30963	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26557	\N	\N	\N
31029	MEMBRE	2018-02-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26610	\N	2018-02-27 09:03:39	\N
31098	VICPDT	2018-03-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24134	\N	2018-03-08 17:17:39	\N
31099	VICPDT	2018-03-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25156	\N	2018-03-08 17:17:46	\N
31100	VICPDT	2018-03-08 00:00:00	2019-03-12 00:00:00	ANCIEN	\N	\N	\N	\N	23933	\N	2018-03-08 17:17:53	\N
31320	MEMBRE	2018-06-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26788	\N	\N	\N
31129	MEMBRE	2018-03-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26653	\N	\N	\N
31132	MEMBRE	2018-03-07 00:00:00	2018-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	26656	\N	\N	\N
31135	MEMBRE	2018-03-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26659	\N	\N	\N
31136	MEMBRE	2018-03-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26660	\N	\N	\N
31137	MEMBRE	2018-03-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26661	\N	\N	\N
31143	MEMBRE	2018-03-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26667	\N	\N	\N
31144	MEMBRE	2018-03-07 00:00:00	2018-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	26668	\N	\N	\N
31145	MEMBRE	2018-03-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26669	\N	\N	\N
31147	MEMBRE	2018-03-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26671	\N	\N	\N
31148	MEMBRE	2018-03-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26672	\N	\N	\N
31149	MEMBRE	2018-03-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26673	\N	\N	\N
31151	MEMBRE	2018-03-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26675	\N	\N	\N
31152	MEMBRE	2018-03-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26676	\N	\N	\N
31153	MEMBRE	2018-03-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26677	\N	\N	\N
31154	MEMBRE	2018-03-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26678	\N	\N	\N
31155	MEMBRE	2018-03-07 00:00:00	2018-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	26679	\N	\N	2018-04-13 17:54:29
31156	MEMBRE	2018-03-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26680	\N	\N	\N
31165	MEMBRE	2018-03-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26689	\N	\N	\N
31167	MEMBRE	2018-03-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26691	\N	\N	\N
31196	PDT	2018-03-15 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26514	\N	\N	\N
31434	MEMBRE	2018-11-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26895	\N	\N	\N
31435	MEMBRE	2018-11-07 00:00:00	2019-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	26896	\N	\N	\N
31494	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26950	\N	\N	\N
31589	MEMBRE	2019-07-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	27031	\N	\N	\N
31592	MEMBRE	2019-09-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	27034	\N	\N	\N
33148	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28581	\N	\N	\N
33149	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28582	\N	\N	\N
33150	MEMBRE	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28583	\N	\N	\N
33151	MEMBRE	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28584	\N	\N	\N
33152	MEMBRE	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28585	\N	\N	\N
33153	MEMBRE	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28586	\N	\N	\N
33154	MEMBRE	2020-10-22 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	28587	\N	\N	\N
33155	MEMBRE	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28588	\N	\N	\N
33156	MEMBRE	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28589	\N	\N	\N
33157	MEMBRE	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28590	\N	\N	\N
33158	MEMBRE	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28591	\N	\N	\N
33159	MEMBRE	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28592	\N	\N	\N
33160	MEMBRE	2020-10-29 00:00:00	2020-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	28593	\N	\N	\N
33161	MEMBRE	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28594	\N	\N	\N
33162	MEMBRE	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28595	\N	\N	\N
33163	MEMBRE	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28596	\N	\N	\N
33164	MEMBRE	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28597	\N	\N	\N
33165	MEMBRE	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28598	\N	\N	\N
33166	MEMBRE	2020-10-29 00:00:00	2021-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	28599	\N	\N	\N
33167	MEMBRE	2020-10-29 00:00:00	2020-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	28600	\N	\N	\N
33168	MEMBRE	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28601	\N	\N	\N
33169	MEMBRE	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28602	\N	\N	\N
33170	MEMBRE	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28603	\N	\N	\N
33171	MEMBRE	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28604	\N	\N	\N
33172	MEMBRE	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28605	\N	\N	\N
33173	MEMBRE	2020-10-29 00:00:00	2021-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	28606	\N	\N	\N
33174	MEMBRE	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28607	\N	\N	\N
33175	MEMBRE	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28608	\N	\N	\N
33176	MEMBRE	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28609	\N	\N	\N
33177	MEMBRE	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28610	\N	\N	\N
33178	MEMBRE	2020-10-29 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	28611	\N	\N	\N
33179	MEMBRE	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28612	\N	\N	\N
33180	MEMBRE	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28613	\N	\N	\N
33181	MEMBRE	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28614	\N	\N	\N
33182	MEMBRE	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28615	\N	\N	\N
33183	MEMBRE	2020-10-29 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	28616	\N	\N	\N
33184	MEMBRE	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28617	\N	\N	\N
33185	MEMBRE	2020-10-29 00:00:00	2021-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	28618	\N	\N	\N
33186	MEMBRE	2020-10-28 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	28619	\N	\N	\N
33187	MEMBRE	2020-10-28 00:00:00	2021-01-03 00:00:00	ANCIEN	\N	\N	\N	\N	28620	\N	\N	\N
33188	MEMBRE	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28621	\N	\N	\N
33189	MEMBRE	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28622	\N	\N	\N
33190	MEMBRE	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28623	\N	\N	\N
33191	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28624	\N	\N	\N
33192	MEMBRE	2020-10-30 00:00:00	2021-01-21 00:00:00	ANCIEN	\N	\N	\N	\N	28625	\N	\N	\N
33193	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28626	\N	\N	\N
33194	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28627	\N	\N	\N
33195	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28628	\N	\N	\N
33196	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28629	\N	\N	\N
33197	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28630	\N	\N	\N
33198	MEMBRE	2020-10-30 00:00:00	2021-01-03 00:00:00	ANCIEN	\N	\N	\N	\N	28631	\N	\N	\N
33199	MEMBRE	2020-10-30 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	28632	\N	\N	\N
33200	MEMBRE	2020-10-30 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	28633	\N	\N	\N
33201	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28634	\N	\N	\N
33202	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28635	\N	\N	\N
33203	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28636	\N	\N	\N
33204	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28637	\N	\N	\N
33205	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28638	\N	\N	\N
33206	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28639	\N	\N	\N
33207	MEMBRE	2020-10-30 00:00:00	2021-01-14 00:00:00	ANCIEN	\N	\N	\N	\N	28640	\N	\N	\N
33208	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28641	\N	\N	\N
33209	MEMBRE	2020-10-30 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	28642	\N	\N	\N
33210	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28643	\N	\N	\N
33211	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28644	\N	\N	\N
33212	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28645	\N	\N	\N
33213	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28646	\N	\N	\N
33214	MEMBRE	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28647	\N	\N	\N
33215	MEMBRE	2020-10-29 00:00:00	2020-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	28648	\N	\N	\N
33216	MEMBRE	2020-10-29 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	28649	\N	\N	\N
33217	MEMBRE	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28650	\N	\N	\N
33218	MEMBRE	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28651	\N	\N	\N
33219	MEMBRE	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28652	\N	\N	\N
33617	MEMBRE	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28988	\N	\N	\N
33619	MEMBRE	2020-11-18 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	28990	\N	\N	\N
33620	PDT	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27266	\N	\N	\N
33621	PDT	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27421	\N	\N	\N
33622	PDT	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27296	\N	\N	\N
33623	PDT	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28795	\N	\N	\N
33624	PDT	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27946	\N	\N	\N
33625	PDT	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27136	\N	\N	\N
33626	PDT	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27322	\N	\N	\N
33627	PDT	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27787	\N	\N	\N
33628	PDT	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27286	\N	\N	\N
33629	PDT	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27131	\N	\N	\N
33630	PDT	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27463	\N	\N	\N
33631	PDT	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27413	\N	\N	\N
33632	PDT	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28095	\N	\N	\N
33633	PDT	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28417	\N	\N	\N
33634	PDT	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27878	\N	\N	\N
33635	PDT	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27678	\N	\N	\N
33636	PDT	2020-11-19 00:00:00	2021-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	27151	\N	\N	\N
33637	PDT	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27327	\N	\N	\N
33638	PDT	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28017	\N	\N	\N
38092	MEMBRE	2023-10-24 00:00:00	2024-01-29 00:00:00	ACTIF	\N	\N	\N	\N	32287	\N	\N	\N
38376	MEMBRE	2023-10-31 00:00:00	2023-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	32571	\N	\N	\N
38377	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32572	\N	\N	\N
38410	MEMBRE	2023-11-01 00:00:00	2024-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	32605	\N	\N	\N
38467	MEMBRE	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32662	\N	\N	\N
38468	MEMBRE	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32663	\N	\N	\N
38469	MEMBRE	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32664	\N	\N	\N
38470	MEMBRE	2023-11-02 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	32665	\N	\N	\N
38471	MEMBRE	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32666	\N	\N	\N
38472	MEMBRE	2023-11-02 00:00:00	2024-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	32667	\N	\N	\N
38522	MEMBRE	2023-11-03 00:00:00	2023-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	32717	\N	\N	\N
38523	MEMBRE	2023-11-03 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	32718	\N	\N	\N
38524	MEMBRE	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32719	\N	\N	\N
38525	MEMBRE	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32720	\N	\N	\N
38526	MEMBRE	2022-02-28 00:00:00	2023-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	32721	\N	\N	\N
38527	MEMBRE	2022-11-15 00:00:00	2023-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	32722	\N	\N	\N
38528	MEMBRE	2021-11-23 00:00:00	2023-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	32723	\N	\N	\N
38529	MEMBRE	2021-02-17 00:00:00	2023-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	32724	\N	\N	\N
38539	MEMBRE	2023-11-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32734	\N	\N	\N
38555	MEMBRE	2023-11-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32750	\N	\N	\N
38556	MEMBRE	2023-11-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32751	\N	\N	\N
38557	MEMBRE	2023-11-06 00:00:00	2023-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	32752	\N	\N	\N
38558	MEMBRE	2023-11-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32753	\N	\N	\N
38559	MEMBRE	2023-11-06 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	32754	\N	\N	\N
38560	MEMBRE	2023-11-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32755	\N	\N	\N
38610	MEMBRE	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32805	\N	\N	\N
38611	MEMBRE	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32806	\N	\N	\N
38612	MEMBRE	2023-11-08 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	32807	\N	\N	\N
38613	MEMBRE	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32808	\N	\N	\N
38621	MEMBRE	2023-11-08 00:00:00	2024-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	32816	\N	\N	\N
38657	MEMBRE	2023-11-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32852	\N	\N	\N
38679	MEMBRE	2023-11-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32874	\N	\N	\N
38680	MEMBRE	2023-11-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32875	\N	\N	\N
38681	MEMBRE	2023-11-14 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	32876	\N	\N	\N
38682	MEMBRE	2023-11-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32877	\N	\N	\N
38683	MEMBRE	2023-11-14 00:00:00	2023-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	32878	\N	\N	\N
38684	MEMBRE	2023-11-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32879	\N	\N	\N
38685	MEMBRE	2023-11-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32880	\N	\N	\N
38686	MEMBRE	2023-11-14 00:00:00	2024-04-02 00:00:00	ACTIF	\N	\N	\N	\N	32881	\N	\N	\N
38687	MEMBRE	2023-11-14 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	32882	\N	\N	\N
38688	MEMBRE	2023-11-14 00:00:00	2024-02-08 00:00:00	ACTIF	\N	\N	\N	\N	32883	\N	\N	\N
38689	MEMBRE	2023-11-14 00:00:00	2024-01-28 00:00:00	ACTIF	\N	\N	\N	\N	32884	\N	\N	\N
38690	MEMBRE	2023-11-14 00:00:00	2024-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	32885	\N	\N	\N
38691	MEMBRE	2023-11-14 00:00:00	2024-01-30 00:00:00	ACTIF	\N	\N	\N	\N	32886	\N	\N	\N
38692	MEMBRE	2023-11-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32887	\N	\N	\N
38693	MEMBRE	2023-11-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32888	\N	\N	\N
38694	MEMBRE	2023-11-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32889	\N	\N	\N
38695	MEMBRE	2023-11-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32890	\N	\N	\N
38696	MEMBRE	2023-11-14 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	32891	\N	\N	\N
38697	MEMBRE	2023-11-14 00:00:00	2024-02-04 00:00:00	ACTIF	\N	\N	\N	\N	32892	\N	\N	\N
38698	MEMBRE	2023-11-14 00:00:00	2023-12-11 00:00:00	ANCIEN	\N	\N	\N	\N	32893	\N	\N	\N
38699	MEMBRE	2023-11-14 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	32894	\N	\N	\N
38700	MEMBRE	2023-11-14 00:00:00	2023-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	32895	\N	\N	\N
38714	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32909	\N	\N	\N
38715	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32910	\N	\N	\N
38716	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32911	\N	\N	\N
38717	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32912	\N	\N	\N
38719	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32914	\N	\N	\N
38754	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32949	\N	\N	\N
38755	MEMBRE	2023-11-15 00:00:00	2023-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	32950	\N	\N	\N
38840	MEMBRE	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33035	\N	\N	\N
38841	MEMBRE	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33036	\N	\N	\N
38873	MEMBRE	2023-11-16 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	33068	\N	\N	\N
38874	MEMBRE	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33069	\N	\N	\N
38875	MEMBRE	2023-11-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33070	\N	\N	\N
38886	MEMBRE	2023-11-18 00:00:00	2024-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	33081	\N	\N	\N
38887	MEMBRE	2023-11-18 00:00:00	2024-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	33082	\N	\N	\N
38901	MEMBRE	2023-11-20 00:00:00	2023-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	33088	\N	\N	\N
38991	PDT	2023-11-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33157	\N	\N	\N
39164	MEMBRE	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33209	\N	\N	\N
39115	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour le Centrafrique	\N	33168	\N	\N	\N
39168	MEMBRE	2023-11-30 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33213	\N	\N	\N
39169	MEMBRE	2023-11-30 00:00:00	2024-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	33214	\N	\N	\N
39170	MEMBRE	2023-11-30 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33215	\N	\N	\N
39172	MEMBRE	2023-11-30 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33217	\N	\N	\N
39179	MEMBRE	2023-12-01 00:00:00	2023-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	33224	\N	\N	\N
39197	MEMBRE	2023-12-04 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33242	\N	\N	\N
39198	MEMBRE	2023-12-04 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33244	\N	\N	\N
39199	MEMBRE	2023-12-04 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33245	\N	\N	\N
39243	MEMBRE	2023-12-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33287	\N	\N	\N
39244	MEMBRE	2023-12-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33288	\N	\N	\N
39251	MEMBRE	2023-12-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33295	\N	\N	\N
39252	MEMBRE	2023-12-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33296	\N	\N	\N
39267	MEMBRE	2023-12-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33311	\N	\N	\N
39346	MEMBRE	2023-12-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33329	\N	\N	\N
39347	MEMBRE	2023-12-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33330	\N	\N	\N
39348	PDTDEL	2023-12-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour le Tadjikistan	\N	33331	\N	\N	\N
39372	PDTHON	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32354	\N	\N	\N
39373	VICPDT	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32358	\N	\N	\N
39374	VICPDT	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32956	\N	\N	\N
39375	VICPDT	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32893	\N	\N	\N
39376	VICPDT	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32555	\N	\N	\N
39377	VICPDT	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32283	\N	\N	\N
39378	VICPDT	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31584	\N	\N	\N
39379	VICPDT	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31833	\N	\N	\N
39380	VICPDT	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31443	\N	\N	\N
39381	VICPDT	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31783	\N	\N	\N
39382	VICPDT	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31820	\N	\N	\N
39399	MEMBRE	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33369	\N	\N	\N
39635	MEMBRE	2023-12-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33403	\N	\N	\N
39647	MEMBRE	2023-12-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	29787	\N	\N	\N
39659	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33412	\N	\N	\N
39666	MEMBRE	2023-12-22 00:00:00	2024-01-30 00:00:00	ACTIF	\N	\N	\N	\N	30012	\N	\N	\N
39709	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33448	\N	\N	\N
39710	MEMBRE	2023-10-01 00:00:00	2024-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	33449	\N	\N	\N
39711	MEMBRE	2023-10-01 00:00:00	2024-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	33450	\N	\N	\N
39712	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33451	\N	\N	\N
39713	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33452	\N	\N	\N
39714	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33453	\N	\N	\N
39718	VICPDT	2024-01-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33180	\N	\N	\N
39719	VICPDT	2024-01-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33214	\N	\N	\N
39720	VICPDT	2024-01-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33142	\N	\N	\N
39721	VICPDT	2024-01-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32833	\N	\N	\N
39722	SECRET	2024-01-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32842	\N	\N	\N
39723	SECRET	2024-01-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32974	\N	\N	\N
39724	VICPDT	2024-01-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32626	\N	\N	\N
39725	VICPDT	2024-01-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33152	\N	\N	\N
39726	VICPDT	2024-01-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31087	\N	\N	\N
39727	VICPDT	2024-01-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32846	\N	\N	\N
39728	SECRET	2024-01-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32091	\N	\N	\N
39729	SECRET	2024-01-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32468	\N	\N	\N
39730	VICPDT	2024-01-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33006	\N	\N	\N
39731	VICPDT	2024-01-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30931	\N	\N	\N
39732	VICPDT	2024-01-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32444	\N	\N	\N
39736	VICPDT	2024-01-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32605	\N	\N	\N
39734	MEMBRE	2024-01-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32717	\N	\N	\N
39735	VICPDT	2024-01-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30986	\N	\N	\N
39737	VICPDT	2024-01-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31522	\N	\N	\N
39738	VICPDT	2024-01-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31023	\N	\N	\N
39739	VICPDT	2024-01-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31601	\N	\N	\N
39740	VICPDT	2024-01-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31369	\N	\N	\N
39741	VICPDT	2024-01-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30899	\N	\N	\N
39742	VICPDT	2024-01-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31072	\N	\N	\N
39743	VICPDT	2024-01-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31642	\N	\N	\N
39744	SECRET	2024-01-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31448	\N	\N	\N
39745	SECRET	2024-01-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33350	\N	\N	\N
39746	PDTHON	2024-01-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31942	\N	\N	\N
39747	PDTHON	2024-01-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30923	\N	\N	\N
39748	VICPDT	2024-01-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31198	\N	\N	\N
39749	VICPDT	2024-01-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31012	\N	\N	\N
39750	VICPDT	2024-01-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32366	\N	\N	\N
39751	VICPDT	2024-01-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32830	\N	\N	\N
30641	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26342	\N	\N	\N
30900	MEMBRE	2018-02-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26536	\N	2018-02-15 09:45:38	\N
30902	MEMBRE	2018-02-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26538	\N	2018-02-15 10:14:53	\N
30903	MEMBRE	2018-02-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26539	\N	2018-02-15 10:15:10	\N
30904	MEMBRE	2018-02-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26540	\N	2018-02-15 10:15:54	\N
30905	VICPDT	2018-02-15 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24799	\N	2018-02-15 10:19:17	\N
30906	VICPDT	2018-02-15 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25440	\N	2018-02-15 10:19:30	\N
30907	VICPDT	2018-02-15 00:00:00	2018-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	24314	\N	2018-02-15 10:19:40	2018-04-13 17:54:29
30908	VICPDT	2018-02-15 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24657	\N	2018-02-15 10:20:39	\N
30909	VICPDT	2018-02-15 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	24506	\N	2018-02-15 10:21:45	\N
30910	VICPDT	2018-02-15 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24534	\N	2018-02-15 10:21:57	\N
30911	SECRET	2018-02-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25235	\N	2018-02-15 10:22:11	\N
31012	VICPDT	2018-02-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	26429	\N	\N	\N
31014	VICPDT	2018-02-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	26551	\N	\N	\N
31254	VICPDT	2018-04-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	25746	\N	\N	\N
31337	PDTDEL	2018-09-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Kirghizistan	\N	25858	\N	\N	\N
31515	MEMBRE	2019-02-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	26967	\N	\N	\N
31522	MEMBRE	2019-02-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	26974	\N	\N	\N
31523	MEMBRE	2019-02-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	26975	\N	\N	\N
31532	MEMBRE	2019-02-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	26984	\N	\N	\N
31557	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	27004	\N	\N	\N
31655	MEMBRE	2020-01-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27087	\N	\N	\N
31901	MEMBRE	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27330	\N	\N	\N
31902	MEMBRE	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27331	\N	\N	\N
31903	MEMBRE	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27332	\N	\N	\N
31904	MEMBRE	2020-10-09 00:00:00	2021-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	27333	\N	\N	\N
31923	MEMBRE	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27352	\N	\N	\N
31924	MEMBRE	2020-10-09 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	27353	\N	\N	\N
31925	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27354	\N	\N	\N
31926	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27355	\N	\N	\N
31927	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27356	\N	\N	\N
31928	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27357	\N	\N	\N
31929	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27358	\N	\N	\N
31930	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27359	\N	\N	\N
31931	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27360	\N	\N	\N
31932	MEMBRE	2020-10-07 00:00:00	2021-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	27361	\N	\N	\N
31933	MEMBRE	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27362	\N	\N	\N
31934	MEMBRE	2020-10-09 00:00:00	2020-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	27363	\N	\N	\N
31935	MEMBRE	2020-10-09 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	27364	\N	\N	\N
31936	MEMBRE	2020-10-09 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	27365	\N	\N	\N
31937	MEMBRE	2020-10-09 00:00:00	2021-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	27366	\N	\N	\N
31938	MEMBRE	2020-10-09 00:00:00	2021-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	27367	\N	\N	\N
31939	MEMBRE	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27368	\N	\N	\N
31940	MEMBRE	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27369	\N	\N	\N
31941	MEMBRE	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27370	\N	\N	\N
31942	MEMBRE	2020-10-09 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	27371	\N	\N	\N
31943	MEMBRE	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27372	\N	\N	\N
32059	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27488	\N	\N	\N
32060	MEMBRE	2020-10-07 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	27489	\N	\N	\N
32061	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27490	\N	\N	\N
32062	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27491	\N	\N	\N
32063	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27492	\N	\N	\N
32064	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27493	\N	\N	\N
32065	MEMBRE	2020-10-12 00:00:00	2021-09-20 00:00:00	ANCIEN	\N	\N	\N	\N	27494	\N	\N	\N
32066	MEMBRE	2020-10-12 00:00:00	2020-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	27495	\N	\N	\N
32067	MEMBRE	2020-10-13 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	27496	\N	\N	\N
32068	MEMBRE	2020-10-13 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	27497	\N	\N	\N
32069	MEMBRE	2020-10-13 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	27498	\N	\N	\N
32070	MEMBRE	2020-10-13 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	27499	\N	\N	\N
32071	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27500	\N	\N	\N
32072	MEMBRE	2020-10-13 00:00:00	2020-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	27501	\N	\N	\N
32073	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27502	\N	\N	\N
32074	MEMBRE	2020-10-13 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	27503	\N	\N	\N
32075	MEMBRE	2020-10-13 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	27504	\N	\N	\N
32076	MEMBRE	2020-10-12 00:00:00	2022-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	27505	\N	\N	\N
32077	MEMBRE	2020-10-12 00:00:00	2020-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	27506	\N	\N	\N
32078	MEMBRE	2020-10-12 00:00:00	2020-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	27507	\N	\N	\N
32079	MEMBRE	2020-10-12 00:00:00	2021-01-14 00:00:00	ANCIEN	\N	\N	\N	\N	27508	\N	\N	\N
32080	MEMBRE	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27509	\N	\N	\N
32081	MEMBRE	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27510	\N	\N	\N
32082	MEMBRE	2020-10-12 00:00:00	2020-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	27511	\N	\N	\N
32083	MEMBRE	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27512	\N	\N	\N
32084	MEMBRE	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27513	\N	\N	\N
32452	MEMBRE	2020-10-16 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	27881	\N	\N	\N
32453	MEMBRE	2020-10-16 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	27882	\N	\N	\N
32454	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27883	\N	\N	\N
32455	MEMBRE	2020-10-16 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	27884	\N	\N	\N
32456	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27885	\N	\N	\N
32457	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27886	\N	\N	\N
32458	MEMBRE	2020-10-16 00:00:00	2020-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	27887	\N	\N	\N
32459	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27888	\N	\N	\N
32460	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27889	\N	\N	\N
32461	MEMBRE	2020-10-13 00:00:00	2021-06-23 00:00:00	ANCIEN	\N	\N	\N	\N	27890	\N	\N	\N
32462	MEMBRE	2020-10-13 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	27891	\N	\N	\N
32463	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27892	\N	\N	\N
32464	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27893	\N	\N	\N
32465	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27894	\N	\N	\N
32466	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27895	\N	\N	\N
32467	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27896	\N	\N	\N
32468	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27897	\N	\N	\N
32469	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27898	\N	\N	\N
32470	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27899	\N	\N	\N
32471	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27900	\N	\N	\N
34755	MEMBRE	2020-12-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	29575	\N	\N	\N
34859	MEMBRE	2020-12-18 00:00:00	2021-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	29642	\N	\N	\N
34860	MEMBRE	2021-01-04 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29643	\N	\N	\N
35011	MEMBRE	2021-01-07 00:00:00	2021-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	29759	\N	\N	\N
35041	MEMBRE	2021-01-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	29770	\N	\N	\N
35068	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29792	\N	\N	\N
35069	MEMBRE	2020-10-01 00:00:00	2021-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	29793	\N	\N	\N
35070	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29794	\N	\N	\N
35071	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29795	\N	\N	\N
35072	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29796	\N	\N	\N
35073	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29797	\N	\N	\N
35074	MEMBRE	2020-10-01 00:00:00	2021-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	29798	\N	\N	\N
35305	MEMBRE	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29975	\N	\N	\N
35406	MEMBRE	2021-01-26 00:00:00	2022-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	30038	\N	\N	\N
35597	VICPDT	2021-02-03 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	30053	\N	\N	\N
35656	MEMBRE	2021-02-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	30141	\N	\N	\N
35684	MEMBRE	2020-10-01 00:00:00	2024-01-29 00:00:00	ACTIF	\N	\N	\N	\N	30147	\N	\N	\N
35842	PDT	2021-02-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29937	\N	\N	\N
35871	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30205	\N	\N	\N
36066	MEMBRE	2021-06-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30347	\N	\N	\N
36524	MEMBRE	2023-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30741	\N	\N	\N
36535	MEMBRE	2023-01-01 00:00:00	2023-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	30752	\N	\N	\N
36553	MEMBRE	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30770	\N	\N	\N
36559	MEMBRE	2023-01-01 00:00:00	2023-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	30776	\N	\N	\N
36573	MEMBRE	2023-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30790	\N	\N	\N
36596	MEMBRE	2023-01-31 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30802	\N	\N	\N
36599	MEMBRE	2023-02-09 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30805	\N	\N	\N
36634	MEMBRE	2023-05-04 00:00:00	2023-05-09 00:00:00	ANCIEN	\N	\N	\N	\N	30832	\N	\N	\N
37171	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31363	\N	\N	\N
37172	MEMBRE	2023-10-10 00:00:00	2024-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	31364	\N	\N	\N
37173	MEMBRE	2023-10-10 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	31365	\N	\N	\N
37174	MEMBRE	2023-10-10 00:00:00	2024-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	31366	\N	\N	\N
37175	MEMBRE	2023-10-10 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	31367	\N	\N	\N
37176	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31368	\N	\N	\N
37177	MEMBRE	2023-10-10 00:00:00	2024-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	31369	\N	\N	\N
37579	MEMBRE	2023-10-16 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	31771	\N	\N	\N
37580	MEMBRE	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31772	\N	\N	\N
37581	MEMBRE	2023-10-16 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	31773	\N	\N	\N
37582	MEMBRE	2023-10-16 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	31774	\N	\N	\N
37583	MEMBRE	2023-10-16 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	31775	\N	\N	\N
37584	MEMBRE	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31776	\N	\N	\N
38902	MEMBRE	2023-11-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33089	\N	\N	\N
38932	MEMBRE	2023-11-22 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33109	\N	\N	\N
39875	VICPDT	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32447	\N	\N	\N
39876	VICPDT	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31744	\N	\N	\N
39877	SECRET	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31134	\N	\N	\N
39878	SECRET	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32598	\N	\N	\N
39879	SECRET	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32971	\N	\N	\N
39880	VICPDT	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31987	\N	\N	\N
39881	VICPDT	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32635	\N	\N	\N
39882	VICPDT	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31162	\N	\N	\N
39883	VICPDT	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31022	\N	\N	\N
39884	VICPDT	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31016	\N	\N	\N
39885	VICPDT	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31307	\N	\N	\N
39886	VICPDT	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31105	\N	\N	\N
39887	VICPDT	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30961	\N	\N	\N
39888	VICPDT	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32548	\N	\N	\N
39889	VICPDT	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32653	\N	\N	\N
39890	VICPDT	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31742	\N	\N	\N
39891	VICPDT	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31502	\N	\N	\N
39892	SECRET	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31296	\N	\N	\N
39893	SECRET	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30914	\N	\N	\N
39894	SECRET	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31532	\N	\N	\N
39895	SECRET	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33508	\N	\N	\N
39896	VICPDT	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31218	\N	\N	\N
39897	VICPDT	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32558	\N	\N	\N
39898	VICPDT	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31247	\N	\N	\N
39899	MEMBRE	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31169	\N	\N	\N
39900	VICPDT	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31397	\N	\N	\N
39901	SECRET	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31411	\N	\N	\N
39903	MEMBRE	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33532	\N	\N	\N
39919	MEMBRE	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33534	\N	\N	\N
39920	MEMBRE	2023-12-14 00:00:00	2024-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	33535	\N	\N	\N
39921	VICPDT	2024-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	33535	\N	\N	\N
39930	MEMBRE	2023-12-14 00:00:00	2024-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	33540	\N	\N	\N
39944	MEMBRE	2023-12-14 00:00:00	2024-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	33547	\N	\N	\N
39945	VICPDT	2024-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	33547	\N	\N	\N
39946	MEMBRE	2023-12-14 00:00:00	2024-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	33548	\N	\N	\N
39947	VICPDT	2024-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	33548	\N	\N	\N
39952	MEMBRE	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33551	\N	\N	\N
39953	MEMBRE	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33552	\N	\N	\N
40103	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33678	\N	\N	\N
40314	MEMBRE	2024-01-02 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	30726	\N	\N	\N
40318	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	30745	\N	\N	\N
40319	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	30765	\N	\N	\N
40320	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33830	\N	\N	\N
40321	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	30772	\N	\N	\N
40322	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33831	\N	\N	\N
40372	MEMBRE	2024-01-01 00:00:00	2024-01-22 00:00:00	ACTIF	\N	\N	\N	\N	29885	\N	\N	\N
40375	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33848	\N	\N	\N
40380	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33853	\N	\N	\N
40561	MEMBRE	2023-10-01 00:00:00	2024-02-06 00:00:00	ACTIF	\N	\N	\N	\N	34034	\N	\N	\N
40562	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34035	\N	\N	\N
40563	MEMBRE	2023-10-01 00:00:00	2024-02-27 00:00:00	ACTIF	\N	\N	\N	\N	34036	\N	\N	\N
40677	MEMBRE	2023-12-14 00:00:00	2024-02-06 00:00:00	ACTIF	\N	\N	\N	\N	34136	\N	\N	\N
40679	MEMBRE	2023-12-14 00:00:00	2024-02-06 00:00:00	ACTIF	\N	\N	\N	\N	34138	\N	\N	\N
40684	MEMBRE	2023-12-14 00:00:00	2024-02-06 00:00:00	ACTIF	\N	\N	\N	\N	34143	\N	\N	\N
40685	MEMBRE	2023-12-14 00:00:00	2024-02-06 00:00:00	ACTIF	\N	\N	\N	\N	34144	\N	\N	\N
40686	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34145	\N	\N	\N
40688	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34147	\N	\N	\N
40689	MEMBRE	2023-12-14 00:00:00	2024-02-06 00:00:00	ACTIF	\N	\N	\N	\N	34148	\N	\N	\N
40690	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34149	\N	\N	\N
40691	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34150	\N	\N	\N
40692	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34151	\N	\N	\N
40694	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34153	\N	\N	\N
40695	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34154	\N	\N	\N
40727	MEMBRE	2024-01-02 00:00:00	2024-02-06 00:00:00	ACTIF	\N	\N	\N	\N	34185	\N	\N	\N
40839	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31594	\N	\N	\N
40840	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30920	\N	\N	\N
40841	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31613	\N	\N	\N
40842	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31650	\N	\N	\N
40843	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32997	\N	\N	\N
40844	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31693	\N	\N	\N
40845	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31036	\N	\N	\N
40846	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32601	\N	\N	\N
40847	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32402	\N	\N	\N
40848	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32740	\N	\N	\N
40849	SECRET	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31731	\N	\N	\N
40852	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31840	\N	\N	\N
40853	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31606	\N	\N	\N
40854	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31478	\N	\N	\N
40855	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32284	\N	\N	\N
40856	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34190	\N	\N	\N
40857	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33191	\N	\N	\N
40858	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31866	\N	\N	\N
40859	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32016	\N	\N	\N
40860	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31471	\N	\N	\N
40861	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33183	\N	\N	\N
40862	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31652	\N	\N	\N
40863	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31754	\N	\N	\N
40864	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31500	\N	\N	\N
40865	SECRET	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31794	\N	\N	\N
40866	SECRET	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31365	\N	\N	\N
40867	SECRET	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31679	\N	\N	\N
40870	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33516	\N	\N	\N
40871	PDTHON	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31664	\N	\N	\N
40872	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32037	\N	\N	\N
40873	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32694	\N	\N	\N
40874	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31194	\N	\N	\N
40875	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31609	\N	\N	\N
40876	SECRET	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32546	\N	\N	\N
40877	SECRET	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32863	\N	\N	\N
40878	SECRET	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32500	\N	\N	\N
40977	MEMBRE	2023-12-14 00:00:00	\N	\N	\N	\N	\N	\N	34268	\N	\N	\N
41034	VICPDT	2024-01-31 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	29859	\N	\N	\N
41035	VICPDT	2024-01-31 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	33676	\N	\N	\N
41036	VICPDT	2024-01-31 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	29857	\N	\N	\N
41054	MEMBRE	2024-01-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34279	\N	\N	\N
41064	MEMBRE	2023-12-14 00:00:00	\N	\N	\N	\N	\N	\N	34287	\N	\N	\N
41067	VICPDT	2024-02-05 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31954	\N	\N	\N
41068	VICPDT	2024-02-05 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31458	\N	\N	\N
41069	VICPDT	2024-02-05 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31855	\N	\N	\N
41070	VICPDT	2024-02-05 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31088	\N	\N	\N
41071	VICPDT	2024-02-05 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32561	\N	\N	\N
41072	SECRET	2024-02-05 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31267	\N	\N	\N
41073	SECRET	2024-02-05 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32892	\N	\N	\N
41074	SECRET	2024-02-05 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31481	\N	\N	\N
41075	SECRET	2024-02-05 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	30981	\N	\N	\N
41081	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34295	\N	\N	\N
41114	VICPDT	2024-02-06 00:00:00	\N	\N	\N	\N	\N	\N	33984	\N	\N	\N
41116	SECRET	2024-02-06 00:00:00	\N	\N	\N	\N	\N	\N	34297	\N	\N	\N
41120	VICPDT	2024-02-07 00:00:00	\N	\N	\N	\N	\N	\N	34057	\N	\N	\N
41121	VICPDT	2024-02-07 00:00:00	\N	\N	\N	\N	\N	\N	34051	\N	\N	\N
41123	VICPDT	2024-02-06 00:00:00	\N	\N	\N	\N	\N	\N	34065	\N	\N	\N
41144	VICPDT	2024-02-08 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	34234	\N	\N	\N
41145	VICPDT	2024-02-08 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32063	\N	\N	\N
41146	VICPDT	2024-02-08 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	33282	\N	\N	\N
41147	VICPDT	2024-02-08 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	30911	\N	\N	\N
41148	VICPDT	2024-02-08 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31749	\N	\N	\N
41149	VICPDT	2024-02-08 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32790	\N	\N	\N
41150	VICPDT	2024-02-08 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32976	\N	\N	\N
41151	VICPDT	2024-02-08 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31315	\N	\N	\N
41152	SECRET	2024-02-08 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31256	\N	\N	\N
41153	SECRET	2024-02-08 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31338	\N	\N	\N
41163	MEMBRE	2024-01-02 00:00:00	\N	\N	\N	\N	\N	\N	34312	\N	\N	\N
41188	MEMBRE	2023-12-14 00:00:00	2024-02-06 00:00:00	\N	\N	\N	\N	\N	34323	\N	\N	\N
41190	MEMBRE	2023-12-14 00:00:00	2024-02-06 00:00:00	\N	\N	\N	\N	\N	34324	\N	\N	\N
41208	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34334	\N	\N	\N
41215	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34340	\N	\N	\N
41238	VICPDT	2024-02-14 00:00:00	\N	\N	\N	\N	\N	\N	33939	\N	\N	\N
41279	SECRET	2024-02-26 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32843	\N	\N	\N
41283	MEMBRE	2023-12-14 00:00:00	\N	\N	\N	\N	\N	\N	34355	\N	\N	\N
41284	MEMBRE	2023-12-14 00:00:00	\N	\N	\N	\N	\N	\N	34356	\N	\N	\N
41286	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34358	\N	\N	\N
41288	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34360	\N	\N	\N
41339	MEMBRE	2023-10-01 00:00:00	2024-02-27 00:00:00	\N	\N	\N	\N	\N	34363	\N	\N	\N
30972	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26566	\N	\N	\N
30985	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26579	\N	\N	\N
30996	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26590	\N	\N	\N
31015	VICPDT	2018-02-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	26440	\N	\N	\N
31234	MEMBRE	2018-03-15 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26728	\N	2018-03-28 17:07:52	\N
31325	MEMBRE	2018-07-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25515	\N	\N	\N
31326	PDTDEL	2018-07-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Zambie	\N	26447	\N	\N	\N
31338	MEMBRE	2018-06-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26800	\N	\N	\N
31339	MEMBRE	2018-06-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26801	\N	\N	\N
31340	MEMBRE	2018-06-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26802	\N	\N	\N
32995	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28428	\N	\N	\N
32996	MEMBRE	2020-10-27 00:00:00	2020-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	28429	\N	\N	\N
32997	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28430	\N	\N	\N
32998	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28431	\N	\N	\N
32999	MEMBRE	2020-10-27 00:00:00	2020-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	28432	\N	\N	\N
33000	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28433	\N	\N	\N
33001	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28434	\N	\N	\N
33002	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28435	\N	\N	\N
33003	MEMBRE	2020-10-27 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	28436	\N	\N	\N
33004	MEMBRE	2020-10-27 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	28437	\N	\N	\N
33005	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28438	\N	\N	\N
33006	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28439	\N	\N	\N
33007	MEMBRE	2020-10-27 00:00:00	2021-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	28440	\N	\N	\N
33008	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28441	\N	\N	\N
33009	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28442	\N	\N	\N
33010	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28443	\N	\N	\N
33011	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28444	\N	\N	\N
33012	MEMBRE	2020-10-27 00:00:00	2020-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	28445	\N	\N	\N
33013	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28446	\N	\N	\N
33014	MEMBRE	2020-10-27 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	28447	\N	\N	\N
33015	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28448	\N	\N	\N
33016	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28449	\N	\N	\N
33017	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28450	\N	\N	\N
33018	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28451	\N	\N	\N
33019	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28452	\N	\N	\N
33020	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28453	\N	\N	\N
33021	MEMBRE	2020-10-27 00:00:00	2020-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	28454	\N	\N	\N
33346	MEMBRE	2020-10-16 00:00:00	2021-01-11 00:00:00	ANCIEN	\N	\N	\N	\N	28779	\N	\N	\N
33347	MEMBRE	2020-10-16 00:00:00	2021-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	28780	\N	\N	\N
33348	MEMBRE	2020-10-16 00:00:00	2021-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	28781	\N	\N	\N
33349	MEMBRE	2020-10-16 00:00:00	2021-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	28782	\N	\N	\N
33350	MEMBRE	2020-10-16 00:00:00	2021-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	28783	\N	\N	\N
33351	MEMBRE	2020-10-16 00:00:00	2021-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	28784	\N	\N	\N
33352	MEMBRE	2020-10-29 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	28785	\N	\N	\N
33353	MEMBRE	2020-10-29 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	28786	\N	\N	\N
33639	PDT	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27671	\N	\N	\N
33640	PDT	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27706	\N	\N	\N
33641	MEMBRE	2020-11-19 00:00:00	2021-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	28327	\N	\N	\N
33642	PDT	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27576	\N	\N	\N
33648	PDT	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28933	\N	\N	\N
33649	PDT	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27881	\N	\N	\N
33650	PDT	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27975	\N	\N	\N
33651	PDTDEL	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour la Birmanie	\N	28746	\N	\N	\N
33652	PDTDEL	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour la Bosnie-Herzégovine	\N	28705	\N	\N	\N
33653	PDTDEL	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour le Botswana	\N	27461	\N	\N	\N
33654	PDTDEL	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour Brunei	\N	27622	\N	\N	\N
33655	PDTDEL	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour le Burkina Faso	\N	27562	\N	\N	\N
33656	PDTDEL	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour le Burundi	\N	27272	\N	\N	\N
33657	PDTDEL	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour le Cameroun	\N	28642	\N	\N	\N
33658	PDTDEL	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour le Cap-Vert	\N	28405	\N	\N	\N
33659	PDTDEL	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour la Côte d'Ivoire	\N	27475	\N	\N	\N
33827	MEMBRE	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29092	\N	\N	\N
33828	MEMBRE	2020-11-24 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	29093	\N	\N	\N
33829	MEMBRE	2020-11-23 00:00:00	2020-11-24 00:00:00	ANCIEN	\N	\N	\N	\N	29094	\N	\N	\N
33830	PDTDEL	2020-11-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour l'Amérique centrale	\N	29094	\N	\N	\N
33831	MEMBRE	2020-11-23 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	29095	\N	\N	\N
33832	MEMBRE	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29096	\N	\N	\N
33833	MEMBRE	2020-11-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29097	\N	\N	\N
33840	MEMBRE	2020-11-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29099	\N	\N	\N
33841	MEMBRE	2020-11-23 00:00:00	2020-11-24 00:00:00	ANCIEN	\N	\N	\N	\N	29100	\N	\N	\N
33842	MEMBRE	2020-11-23 00:00:00	2020-11-24 00:00:00	ANCIEN	\N	\N	\N	\N	29101	\N	\N	\N
33843	PDTDEL	2020-11-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour la Namibie	\N	29100	\N	\N	\N
33844	PDTDEL	2020-11-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour la Guinée équatoriale	\N	29101	\N	\N	\N
34595	SECRET	2020-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29308	\N	\N	\N
34619	MEMBRE	2020-12-16 00:00:00	2021-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	29478	\N	\N	\N
34623	MEMBRE	2020-12-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29482	\N	\N	\N
34690	MEMBRE	2020-12-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	29530	\N	\N	\N
34714	MEMBRE	2020-12-21 00:00:00	2021-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	29554	\N	\N	\N
34760	MEMBRE	2020-12-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	29580	\N	\N	\N
34781	MEMBRE	2020-12-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	29588	\N	\N	\N
34915	MEMBRE	2021-01-11 00:00:00	2021-01-11 00:00:00	ANCIEN	\N	\N	\N	\N	29680	\N	\N	\N
34961	MEMBRE	2021-01-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	29717	\N	\N	\N
34962	MEMBRE	2021-01-13 00:00:00	2021-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	29718	\N	\N	\N
35042	MEMBRE	2021-01-15 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	29771	\N	\N	\N
35046	VICPDT	2021-01-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28082	\N	\N	\N
35047	VICPDT	2021-01-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27556	\N	\N	\N
35048	VICPDT	2021-01-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27689	\N	\N	\N
35049	VICPDT	2021-01-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27927	\N	\N	\N
35050	VICPDT	2021-01-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28277	\N	\N	\N
35309	MEMBRE	2021-01-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29979	\N	\N	\N
35370	VICPDT	2021-01-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	29642	\N	\N	\N
35371	VICPDT	2021-01-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29473	\N	\N	\N
35372	VICPDT	2021-01-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29476	\N	\N	\N
35374	VICPDT	2021-01-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29622	\N	\N	\N
35375	VICPDT	2021-01-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	29617	\N	\N	\N
35376	VICPDT	2021-01-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29992	\N	\N	\N
35377	MEMBRE	2021-01-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	30014	\N	\N	\N
35463	VICPDT	2021-01-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	29550	\N	\N	\N
35464	VICPDT	2021-01-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	29412	\N	\N	\N
35465	VICPDT	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29594	\N	\N	\N
35466	VICPDT	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29424	\N	\N	\N
35467	VICPDT	2021-01-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	29417	\N	\N	\N
35520	VICPDT	2021-01-13 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29551	\N	\N	\N
35610	MEMBRE	2021-02-03 00:00:00	2021-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	30095	\N	\N	\N
35611	MEMBRE	2021-02-03 00:00:00	2021-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	30096	\N	\N	\N
35612	MEMBRE	2021-02-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	30097	\N	\N	\N
35613	MEMBRE	2021-02-03 00:00:00	2021-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	30098	\N	\N	\N
35614	MEMBRE	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30099	\N	\N	\N
35663	VICPDT	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30101	\N	\N	\N
35756	MEMBRE	2020-10-01 00:00:00	2021-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	30151	\N	\N	\N
36064	MEMBRE	2021-06-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30345	\N	\N	\N
36237	MEMBRE	2021-11-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30482	\N	\N	\N
36306	MEMBRE	2022-03-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30534	\N	\N	\N
36338	MEMBRE	2022-03-31 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30565	\N	\N	\N
36370	PDT	2022-04-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30550	\N	\N	\N
36398	MEMBRE	2022-04-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30616	\N	\N	\N
36444	MEMBRE	2022-09-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30661	\N	\N	\N
36457	MEMBRE	2020-12-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30674	\N	\N	\N
36476	MEMBRE	2022-10-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	30693	\N	\N	\N
36499	MEMBRE	2022-11-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30716	\N	\N	\N
36517	MEMBRE	2023-01-01 00:00:00	2023-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	30734	\N	\N	\N
36541	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30758	\N	\N	\N
36719	MEMBRE	2023-10-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30909	\N	\N	\N
36653	PDT	2023-05-10 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	30832	\N	\N	\N
36720	MEMBRE	2023-10-06 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	30910	\N	\N	\N
36721	MEMBRE	2023-10-06 00:00:00	2024-02-07 00:00:00	ACTIF	\N	\N	\N	\N	30911	\N	\N	\N
36722	MEMBRE	2023-10-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30912	\N	\N	\N
36723	MEMBRE	2023-10-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30913	\N	\N	\N
36724	MEMBRE	2023-10-06 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	30914	\N	\N	\N
36725	MEMBRE	2023-10-06 00:00:00	2024-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	30915	\N	\N	\N
36726	MEMBRE	2023-10-06 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	30916	\N	\N	\N
36727	MEMBRE	2023-10-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30917	\N	\N	\N
36728	MEMBRE	2023-10-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30918	\N	\N	\N
38615	MEMBRE	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32810	\N	\N	\N
38616	MEMBRE	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32811	\N	\N	\N
38703	MEMBRE	2023-11-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32898	\N	\N	\N
38726	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32921	\N	\N	\N
38833	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33028	\N	\N	\N
38836	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33031	\N	\N	\N
38837	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33032	\N	\N	\N
38838	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33033	\N	\N	\N
38898	MEMBRE	2023-11-20 00:00:00	2024-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	33085	\N	\N	\N
39127	MEMBRE	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33173	\N	\N	\N
39128	MEMBRE	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33174	\N	\N	\N
39202	MEMBRE	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33248	\N	\N	\N
39207	MEMBRE	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33253	\N	\N	\N
39248	MEMBRE	2023-12-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33292	\N	\N	\N
39255	MEMBRE	2023-12-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33299	\N	\N	\N
39333	MEMBRE	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33322	\N	\N	\N
39420	PDT	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33352	\N	\N	\N
39421	VICPDT	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31209	\N	\N	\N
39422	VICPDT	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32633	\N	\N	\N
39423	VICPDT	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31575	\N	\N	\N
39424	VICPDT	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33059	\N	\N	\N
39425	VICPDT	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31082	\N	\N	\N
39426	VICPDT	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33294	\N	\N	\N
39427	VICPDT	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32901	\N	\N	\N
39428	SECRET	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31790	\N	\N	\N
39429	SECRET	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31244	\N	\N	\N
39430	SECRET	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31085	\N	\N	\N
39431	VICPDT	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31793	\N	\N	\N
39432	VICPDT	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32230	\N	\N	\N
39433	VICPDT	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33057	\N	\N	\N
39434	VICPDT	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33338	\N	\N	\N
39435	VICPDT	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31741	\N	\N	\N
39436	VICPDT	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32651	\N	\N	\N
39437	VICPDT	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32001	\N	\N	\N
39438	VICPDT	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31415	\N	\N	\N
39439	VICPDT	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32190	\N	\N	\N
39440	VICPDT	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31385	\N	\N	\N
39441	VICPDT	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32411	\N	\N	\N
39442	VICPDT	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33306	\N	\N	\N
39443	SECRET	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32304	\N	\N	\N
39444	SECRET	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32919	\N	\N	\N
39445	MEMBRE	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33371	\N	\N	\N
39752	VICPDT	2024-01-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32700	\N	\N	\N
39753	VICPDT	2024-01-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32521	\N	\N	\N
39754	VICPDT	2024-01-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31759	\N	\N	\N
39755	VICPDT	2024-01-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33015	\N	\N	\N
39756	VICPDT	2024-01-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31672	\N	\N	\N
39757	VICPDT	2024-01-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32600	\N	\N	\N
39758	SECRET	2024-01-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31366	\N	\N	\N
39759	SECRET	2024-01-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32258	\N	\N	\N
39760	SECRET	2024-01-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32029	\N	\N	\N
39776	VICPDT	2024-01-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31804	\N	\N	\N
39777	VICPDT	2024-01-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32758	\N	\N	\N
39778	VICPDT	2024-01-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32684	\N	\N	\N
39779	VICPDT	2024-01-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31086	\N	\N	\N
39780	VICPDT	2024-01-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31094	\N	\N	\N
39781	SECRET	2024-01-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31583	\N	\N	\N
39799	MEMBRE	2024-01-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33469	\N	\N	\N
39800	MEMBRE	2024-01-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33470	\N	\N	\N
39802	PDTDEL	2024-01-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour le Libéria	\N	33472	\N	\N	\N
39803	MEMBRE	2024-01-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33473	\N	\N	\N
39807	MEMBRE	2024-01-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33476	\N	\N	\N
39805	PDTDEL	2024-01-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour le Ghana	\N	33474	\N	\N	\N
39822	MEMBRE	2024-01-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33490	\N	\N	\N
39815	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33483	\N	\N	\N
39816	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33484	\N	\N	\N
39828	MEMBRE	2024-01-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33496	\N	\N	\N
39830	MEMBRE	2024-01-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33498	\N	\N	\N
39842	MEMBRE	2024-01-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33510	\N	\N	\N
39844	MEMBRE	2024-01-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33512	\N	\N	\N
39849	MEMBRE	2024-01-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33517	\N	\N	\N
39856	MEMBRE	2024-01-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33524	\N	\N	\N
39857	MEMBRE	2024-01-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33525	\N	\N	\N
39860	MEMBRE	2024-01-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33528	\N	\N	\N
39861	MEMBRE	2024-01-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33529	\N	\N	\N
39862	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33530	\N	\N	\N
39924	MEMBRE	2023-12-14 00:00:00	2024-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	33537	\N	\N	\N
39925	VICPDT	2024-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	33537	\N	\N	\N
39926	MEMBRE	2023-12-14 00:00:00	2024-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	33538	\N	\N	\N
39929	VICPDT	2024-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	33539	\N	\N	\N
39960	MEMBRE	2024-01-02 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	33559	\N	\N	\N
39968	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33567	\N	\N	\N
39970	MEMBRE	2024-01-02 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	33569	\N	\N	\N
39971	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33570	\N	\N	\N
39972	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33571	\N	\N	\N
40007	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33586	\N	\N	\N
40018	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33595	\N	\N	\N
40023	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33600	\N	\N	\N
40029	MEMBRE	2024-01-02 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	33606	\N	\N	\N
40121	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33694	\N	\N	\N
40133	MEMBRE	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33701	\N	\N	\N
40138	MEMBRE	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33706	\N	\N	\N
40139	VICPDT	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31455	\N	\N	\N
40140	VICPDT	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30971	\N	\N	\N
40141	VICPDT	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33156	\N	\N	\N
40142	VICPDT	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31677	\N	\N	\N
40143	VICPDT	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31603	\N	\N	\N
40144	VICPDT	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33500	\N	\N	\N
40145	VICPDT	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31093	\N	\N	\N
40146	SECRET	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31040	\N	\N	\N
40147	SECRET	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32105	\N	\N	\N
40148	VICPDT	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32325	\N	\N	\N
40149	VICPDT	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32308	\N	\N	\N
40150	VICPDT	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31364	\N	\N	\N
40151	VICPDT	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31845	\N	\N	\N
40152	VICPDT	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31862	\N	\N	\N
40153	VICPDT	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33194	\N	\N	\N
40154	VICPDT	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31647	\N	\N	\N
40155	VICPDT	2024-01-19 00:00:00	2024-01-28 00:00:00	ACTIF	\N	\N	\N	\N	31686	\N	\N	\N
40156	SECRET	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33050	\N	\N	\N
40157	SECRET	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31582	\N	\N	\N
40158	SECRET	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31515	\N	\N	\N
40159	SECRET	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32748	\N	\N	\N
40160	SECRET	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31553	\N	\N	\N
40161	SECRET	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32490	\N	\N	\N
40162	SECRET	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31069	\N	\N	\N
40163	VICPDT	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31337	\N	\N	\N
40164	VICPDT	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30915	\N	\N	\N
40165	VICPDT	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33465	\N	\N	\N
40166	VICPDT	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32965	\N	\N	\N
40167	VICPDT	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32590	\N	\N	\N
40168	SECRET	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32383	\N	\N	\N
40169	SECRET	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32963	\N	\N	\N
40170	VICPDT	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31956	\N	\N	\N
40171	VICPDT	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32943	\N	\N	\N
40172	VICPDT	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33356	\N	\N	\N
40173	VICPDT	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30906	\N	\N	\N
40174	VICPDT	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32210	\N	\N	\N
40175	VICPDT	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32596	\N	\N	\N
40176	SECRET	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31107	\N	\N	\N
40177	SECRET	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33275	\N	\N	\N
40281	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33810	\N	\N	\N
40284	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33813	\N	\N	\N
40299	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33828	\N	\N	\N
40311	MEMBRE	2024-01-02 00:00:00	2024-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	30729	\N	\N	\N
40312	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	30747	\N	\N	\N
40313	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	30736	\N	\N	\N
40315	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	30742	\N	\N	\N
40316	MEMBRE	2024-01-02 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	30735	\N	\N	\N
40317	MEMBRE	2024-01-02 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	30734	\N	\N	\N
40338	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	30727	\N	\N	\N
40350	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33844	\N	\N	\N
40381	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33854	\N	\N	\N
40382	MEMBRE	2023-10-01 00:00:00	2024-02-14 00:00:00	ACTIF	\N	\N	\N	\N	33855	\N	\N	\N
40383	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33856	\N	\N	\N
40385	MEMBRE	2023-12-14 00:00:00	2024-02-14 00:00:00	ACTIF	\N	\N	\N	\N	33858	\N	\N	\N
40387	MEMBRE	2023-12-14 00:00:00	2024-02-14 00:00:00	ACTIF	\N	\N	\N	\N	33860	\N	\N	\N
40388	MEMBRE	2023-12-14 00:00:00	2024-02-14 00:00:00	ACTIF	\N	\N	\N	\N	33861	\N	\N	\N
40394	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33867	\N	\N	\N
40395	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33868	\N	\N	\N
40396	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33869	\N	\N	\N
30560	VICPDT	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23879	\N	2018-02-07 15:20:03	\N
30561	VICPDT	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24817	\N	2018-02-07 15:20:09	\N
30582	VICPDT	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25295	\N	2018-02-07 15:32:07	\N
30563	MEMBRE	2018-02-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26329	\N	2018-02-07 15:28:32	\N
30564	VICPDT	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25522	\N	2018-02-07 15:29:30	\N
30565	VICPDT	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25539	\N	2018-02-07 15:29:43	\N
30566	VICPDT	2018-02-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24656	\N	2018-02-07 15:29:54	\N
30567	VICPDT	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25464	\N	2018-02-07 15:30:01	\N
30568	VICPDT	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24086	\N	2018-02-07 15:30:08	\N
30569	VICPDT	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24067	\N	2018-02-07 15:30:15	\N
30570	VICPDT	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24483	\N	2018-02-07 15:30:21	\N
30571	VICPDT	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24287	\N	2018-02-07 15:30:32	\N
30572	VICPDT	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24566	\N	2018-02-07 15:30:37	\N
30573	VICPDT	2018-02-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24429	\N	2018-02-07 15:30:45	\N
30574	VICPDT	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24029	\N	2018-02-07 15:30:50	\N
30575	VICPDT	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23927	\N	2018-02-07 15:31:02	\N
30576	VICPDT	2018-02-07 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25281	\N	2018-02-07 15:31:09	\N
30577	VICPDT	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24640	\N	2018-02-07 15:31:34	\N
30578	VICPDT	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24175	\N	2018-02-07 15:31:44	\N
30579	VICPDT	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25411	\N	2018-02-07 15:31:49	\N
30580	VICPDT	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26328	\N	2018-02-07 15:31:58	\N
30581	VICPDT	2018-02-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24734	\N	2018-02-07 15:32:02	\N
30583	SECRET	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24094	\N	2018-02-07 15:32:19	\N
30584	SECRET	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23954	\N	2018-02-07 15:32:24	\N
30585	SECRET	2018-02-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24794	\N	2018-02-07 15:32:29	\N
30586	SECRET	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24322	\N	2018-02-07 15:32:37	\N
30587	SECRET	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24004	\N	2018-02-07 15:32:41	\N
30588	SECRET	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24681	\N	2018-02-07 15:32:46	\N
30589	SECRET	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24402	\N	2018-02-07 15:32:52	\N
30712	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26413	\N	\N	\N
30714	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26415	\N	\N	\N
31271	PDT	2018-05-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26198	\N	\N	\N
31502	MEMBRE	2019-01-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26958	\N	\N	\N
31503	MEMBRE	2019-01-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26959	\N	\N	\N
31564	MEMBRE	2019-04-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	27011	\N	\N	\N
31625	MEMBRE	2019-11-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	27058	\N	\N	\N
33510	MEMBRE	2020-11-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28932	\N	\N	\N
33511	MEMBRE	2020-11-12 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	28933	\N	\N	\N
33774	MEMBRE	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29046	\N	\N	\N
33775	MEMBRE	2020-11-23 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	29047	\N	\N	\N
33776	MEMBRE	2020-11-23 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	29048	\N	\N	\N
33777	MEMBRE	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29049	\N	\N	\N
33778	PDTDEL	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour les Comores	\N	29050	\N	\N	\N
33779	MEMBRE	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29051	\N	\N	\N
33845	MEMBRE	2020-11-23 00:00:00	2020-11-24 00:00:00	ANCIEN	\N	\N	\N	\N	29102	\N	\N	\N
33846	PDTDEL	2020-11-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour le Ghana	\N	29102	\N	\N	\N
33847	PDTDEL	2020-11-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour l'Azerbaïdjan	\N	28795	\N	\N	\N
33848	PDTDEL	2020-11-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour le Gabon	\N	27437	\N	\N	\N
33849	MEMBRE	2020-11-23 00:00:00	2020-11-24 00:00:00	ANCIEN	\N	\N	\N	\N	29103	\N	\N	\N
33850	PDTDEL	2020-11-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour le Congo Brazzaville	\N	29103	\N	\N	\N
34388	MEMBRE	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29291	\N	\N	\N
34389	MEMBRE	2020-12-17 00:00:00	2022-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	29292	\N	\N	\N
34390	VICPDT	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28078	\N	\N	\N
34391	VICPDT	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27432	\N	\N	\N
34392	VICPDT	2020-12-17 00:00:00	2023-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	28930	\N	\N	\N
34393	VICPDT	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28649	\N	\N	\N
34394	VICPDT	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27776	\N	\N	\N
34395	VICPDT	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29185	\N	\N	\N
34396	SECRET	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28587	\N	\N	\N
34397	VICPDT	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28122	\N	\N	\N
34398	VICPDT	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27719	\N	\N	\N
34399	SECRET	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28690	\N	\N	\N
34400	SECRET	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28287	\N	\N	\N
34401	VICPDT	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28083	\N	\N	\N
34402	VICPDT	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27726	\N	\N	\N
34403	VICPDT	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27207	\N	\N	\N
34404	VICPDT	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27773	\N	\N	\N
34405	SECRET	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28034	\N	\N	\N
34406	SECRET	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28367	\N	\N	\N
34407	SECRET	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27156	\N	\N	\N
34408	SECRET	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28128	\N	\N	\N
34409	SECRET	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28114	\N	\N	\N
34410	SECRET	2020-12-17 00:00:00	2021-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	27745	\N	\N	\N
34411	VICPDT	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28740	\N	\N	\N
34412	VICPDT	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29166	\N	\N	\N
34413	VICPDT	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27769	\N	\N	\N
34414	SECRET	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28270	\N	\N	\N
34417	PDTHON	2020-12-17 00:00:00	2021-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	27302	\N	\N	\N
34418	VICPDT	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28076	\N	\N	\N
34419	VICPDT	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28260	\N	\N	\N
34420	VICPDT	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27559	\N	\N	\N
34421	SECRET	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27536	\N	\N	\N
34546	MEMBRE	2020-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29410	\N	\N	\N
34547	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29411	\N	\N	\N
34583	MEMBRE	2020-12-15 00:00:00	2021-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	29447	\N	\N	\N
34584	MEMBRE	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29448	\N	\N	\N
34627	MEMBRE	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29486	\N	\N	\N
34628	MEMBRE	2020-12-16 00:00:00	2021-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	29487	\N	\N	\N
34709	MEMBRE	2020-12-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	29549	\N	\N	\N
35081	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29805	\N	\N	\N
35393	MEMBRE	2021-01-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	30030	\N	\N	\N
35395	MEMBRE	2021-01-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	30032	\N	\N	\N
35396	MEMBRE	2021-01-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	30033	\N	\N	\N
35397	MEMBRE	2021-01-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	30034	\N	\N	\N
35398	MEMBRE	2021-01-26 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	30035	\N	\N	\N
35849	VICPDT	2021-02-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29892	\N	\N	\N
35878	MEMBRE	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30212	\N	\N	\N
35879	MEMBRE	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30213	\N	\N	\N
35880	MEMBRE	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30214	\N	\N	\N
35881	MEMBRE	2021-02-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30215	\N	\N	\N
35978	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30275	\N	\N	\N
36060	MEMBRE	2021-06-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	30341	\N	\N	\N
36077	MEMBRE	2021-06-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	30358	\N	\N	\N
36165	MEMBRE	2021-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30427	\N	\N	\N
36482	MEMBRE	2023-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30699	\N	\N	\N
36483	MEMBRE	2022-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30700	\N	\N	\N
36556	MEMBRE	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30773	\N	\N	\N
36643	MEMBRE	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30841	\N	\N	\N
37548	MEMBRE	2023-10-15 00:00:00	2024-01-29 00:00:00	ACTIF	\N	\N	\N	\N	31740	\N	\N	\N
37549	MEMBRE	2023-10-15 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	31741	\N	\N	\N
37550	MEMBRE	2023-10-15 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	31742	\N	\N	\N
37551	MEMBRE	2023-10-15 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	31743	\N	\N	\N
37552	MEMBRE	2023-10-15 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	31744	\N	\N	\N
37553	MEMBRE	2023-10-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31745	\N	\N	\N
37554	MEMBRE	2023-10-15 00:00:00	2024-01-25 00:00:00	ACTIF	\N	\N	\N	\N	31746	\N	\N	\N
37555	MEMBRE	2023-10-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31747	\N	\N	\N
37556	MEMBRE	2023-10-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31748	\N	\N	\N
37557	MEMBRE	2023-10-15 00:00:00	2024-02-07 00:00:00	ACTIF	\N	\N	\N	\N	31749	\N	\N	\N
37558	MEMBRE	2023-10-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31750	\N	\N	\N
37585	MEMBRE	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31777	\N	\N	\N
37834	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32026	\N	\N	\N
37835	MEMBRE	2023-10-18 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	32027	\N	\N	\N
37837	MEMBRE	2023-10-18 00:00:00	2024-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	32029	\N	\N	\N
37838	MEMBRE	2023-10-18 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	32030	\N	\N	\N
37839	MEMBRE	2023-10-18 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	32031	\N	\N	\N
37840	MEMBRE	2023-10-18 00:00:00	2024-01-30 00:00:00	ACTIF	\N	\N	\N	\N	32032	\N	\N	\N
39118	PDT	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31507	\N	\N	\N
39119	PDT	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32906	\N	\N	\N
39120	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour la Bolivie	\N	32793	\N	\N	\N
39121	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour les Comores	\N	32213	\N	\N	\N
39122	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour le Danemark	\N	32876	\N	\N	\N
39123	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour le Kazakhstan	\N	32848	\N	\N	\N
39124	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour le Paraguay	\N	33068	\N	\N	\N
39180	MEMBRE	2023-12-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33225	\N	\N	\N
39181	MEMBRE	2023-12-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33226	\N	\N	\N
39182	MEMBRE	2023-12-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33227	\N	\N	\N
39183	MEMBRE	2023-12-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33228	\N	\N	\N
39184	MEMBRE	2023-12-01 00:00:00	2024-03-05 00:00:00	ACTIF	\N	\N	\N	\N	33229	\N	\N	\N
39345	MEMBRE	2023-12-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33328	\N	\N	\N
39703	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33442	\N	\N	\N
40101	MEMBRE	2023-10-01 00:00:00	2024-01-30 00:00:00	ACTIF	\N	\N	\N	\N	33676	\N	\N	\N
40603	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34076	\N	\N	\N
40604	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34077	\N	\N	\N
40605	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34078	\N	\N	\N
40671	VICPDT	2024-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	33744	\N	\N	\N
40773	VICPDT	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32816	\N	\N	\N
40774	VICPDT	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31260	\N	\N	\N
40775	VICPDT	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33250	\N	\N	\N
40776	VICPDT	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31809	\N	\N	\N
40777	SECRET	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33085	\N	\N	\N
41018	MEMBRE	2024-01-30 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34272	\N	\N	\N
41019	MEMBRE	2024-01-30 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34273	\N	\N	\N
41020	MEMBRE	2024-01-30 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34274	\N	\N	\N
41155	PDTHON	2024-02-09 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31805	\N	\N	\N
41156	VICPDT	2024-02-09 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31163	\N	\N	\N
41157	VICPDT	2024-02-09 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32206	\N	\N	\N
41158	VICPDT	2024-02-09 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32792	\N	\N	\N
41159	VICPDT	2024-02-09 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31033	\N	\N	\N
41160	VICPDT	2024-02-09 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32763	\N	\N	\N
41161	VICPDT	2024-02-09 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	33360	\N	\N	\N
41390	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34392	\N	\N	\N
41410	MEMBRE	2023-12-14 00:00:00	\N	\N	\N	\N	\N	\N	34408	\N	\N	\N
41435	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34426	\N	\N	\N
41511	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34490	\N	\N	\N
41437	VICPDT	2024-02-14 00:00:00	\N	\N	\N	\N	\N	\N	34427	\N	\N	\N
41438	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34428	\N	\N	\N
41439	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34429	\N	\N	\N
41443	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34433	\N	\N	\N
41444	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34434	\N	\N	\N
41445	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34435	\N	\N	\N
41517	VICPDT	2024-03-25 00:00:00	\N	\N	\N	\N	\N	\N	34463	\N	\N	\N
41447	VICPDT	2024-02-14 00:00:00	\N	\N	\N	\N	\N	\N	34436	\N	\N	\N
41516	VICPDT	2024-03-25 00:00:00	\N	\N	\N	\N	\N	\N	34460	\N	\N	\N
41452	MEMBRE	2024-03-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34440	\N	\N	\N
41482	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34470	\N	\N	\N
41492	MEMBRE	2024-03-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34480	\N	\N	\N
41493	MEMBRE	2024-03-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34481	\N	\N	\N
41502	VICPDT	2024-03-20 00:00:00	2026-10-31 00:00:00	\N	\N	\N	\N	\N	34101	\N	\N	\N
41503	PDT	2024-03-20 00:00:00	2026-10-31 00:00:00	\N	\N	\N	\N	\N	34113	\N	\N	\N
41506	VICPDT	2024-03-20 00:00:00	2026-10-31 00:00:00	\N	\N	\N	\N	\N	34112	\N	\N	\N
41524	VICPDT	2024-03-25 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	34247	\N	\N	\N
41525	VICPDT	2024-03-25 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32237	\N	\N	\N
41526	VICPDT	2024-03-25 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32260	\N	\N	\N
41527	VICPDT	2024-03-25 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	34280	\N	\N	\N
41528	VICPDT	2024-03-25 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	34233	\N	\N	\N
41529	SECRET	2024-03-25 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32594	\N	\N	\N
41530	SECRET	2024-03-25 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32866	\N	\N	\N
41536	VICPDT	2024-03-19 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	34385	\N	\N	\N
41540	SECRET	2024-03-19 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	34384	\N	\N	\N
41543	MEMBRE	2024-04-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34495	\N	\N	\N
41556	MEMBRE	2024-04-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34497	\N	\N	\N
41557	MEMBRE	2024-04-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34498	\N	\N	\N
41566	MEMBRE	2024-04-15 00:00:00	\N	\N	\N	\N	\N	\N	34501	\N	\N	\N
30852	VICPDT	2018-02-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26079	\N	\N	\N
30856	SECRET	2018-02-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26068	\N	\N	\N
30857	SECRET	2018-02-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	26080	\N	\N	\N
30858	SECRET	2018-02-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26084	\N	\N	\N
30954	VICPDT	2018-02-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26355	\N	\N	\N
31178	MEMBRE	2018-03-08 00:00:00	2019-06-24 00:00:00	ANCIEN	\N	\N	\N	\N	26702	\N	2018-03-15 09:48:30	\N
31179	MEMBRE	2018-03-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26703	\N	2018-03-15 09:48:30	\N
31298	MEMBRE	2018-05-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26767	\N	2018-05-30 10:11:19	\N
31352	MEMBRE	2018-09-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26814	\N	\N	\N
31353	MEMBRE	2018-09-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26815	\N	\N	\N
31354	MEMBRE	2018-09-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26816	\N	\N	\N
31355	MEMBRE	2018-09-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26817	\N	\N	\N
31356	MEMBRE	2018-09-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26818	\N	\N	\N
31357	MEMBRE	2018-09-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26819	\N	\N	\N
31358	MEMBRE	2018-09-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26820	\N	\N	\N
31359	MEMBRE	2018-09-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26821	\N	\N	\N
31568	MEMBRE	2019-04-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	27015	\N	\N	\N
31569	MEMBRE	2019-04-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	27016	\N	\N	\N
32242	MEMBRE	2020-10-07 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	27671	\N	\N	\N
32243	MEMBRE	2020-10-07 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	27672	\N	\N	\N
32244	MEMBRE	2020-10-08 00:00:00	2020-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	27673	\N	\N	\N
32245	MEMBRE	2020-10-08 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	27674	\N	\N	\N
32246	MEMBRE	2020-10-08 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	27675	\N	\N	\N
32247	MEMBRE	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27676	\N	\N	\N
32248	MEMBRE	2020-10-08 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	27677	\N	\N	\N
32249	MEMBRE	2020-10-08 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	27678	\N	\N	\N
32250	MEMBRE	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27679	\N	\N	\N
32251	MEMBRE	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27680	\N	\N	\N
32252	MEMBRE	2020-10-08 00:00:00	2021-01-03 00:00:00	ANCIEN	\N	\N	\N	\N	27681	\N	\N	\N
32253	MEMBRE	2020-10-08 00:00:00	2020-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	27682	\N	\N	\N
32254	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27683	\N	\N	\N
32255	MEMBRE	2020-10-13 00:00:00	2020-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	27684	\N	\N	\N
32256	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27685	\N	\N	\N
32257	MEMBRE	2020-10-13 00:00:00	2021-01-03 00:00:00	ANCIEN	\N	\N	\N	\N	27686	\N	\N	\N
32258	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27687	\N	\N	\N
32259	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27688	\N	\N	\N
32260	MEMBRE	2020-10-07 00:00:00	2021-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	27689	\N	\N	\N
32261	MEMBRE	2020-10-07 00:00:00	2020-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	27690	\N	\N	\N
32262	MEMBRE	2020-10-08 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	27691	\N	\N	\N
32263	MEMBRE	2020-10-08 00:00:00	2021-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	27692	\N	\N	\N
32264	MEMBRE	2020-10-08 00:00:00	2020-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	27693	\N	\N	\N
32265	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27694	\N	\N	\N
32266	MEMBRE	2020-10-13 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	27695	\N	\N	\N
32267	MEMBRE	2020-10-13 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	27696	\N	\N	\N
32268	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27697	\N	\N	\N
32269	MEMBRE	2020-10-13 00:00:00	2020-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	27698	\N	\N	\N
32270	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27699	\N	\N	\N
32271	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27700	\N	\N	\N
32272	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27701	\N	\N	\N
32273	MEMBRE	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27702	\N	\N	\N
32274	MEMBRE	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27703	\N	\N	\N
32275	MEMBRE	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27704	\N	\N	\N
32276	MEMBRE	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27705	\N	\N	\N
32277	MEMBRE	2020-10-08 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	27706	\N	\N	\N
32397	MEMBRE	2020-10-14 00:00:00	2021-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	27826	\N	\N	\N
32398	MEMBRE	2020-10-14 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	27827	\N	\N	\N
32399	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27828	\N	\N	\N
32400	MEMBRE	2020-10-14 00:00:00	2021-01-03 00:00:00	ANCIEN	\N	\N	\N	\N	27829	\N	\N	\N
32401	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27830	\N	\N	\N
32402	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27831	\N	\N	\N
32403	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27832	\N	\N	\N
32404	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27833	\N	\N	\N
32405	MEMBRE	2020-10-14 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	27834	\N	\N	\N
33812	MEMBRE	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29083	\N	\N	\N
33813	PDT	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29084	\N	\N	\N
33814	MEMBRE	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29085	\N	\N	\N
33815	MEMBRE	2020-11-24 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	29086	\N	\N	\N
33965	MEMBRE	2020-12-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29178	\N	\N	\N
34798	VICPDTDEL	2021-01-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour le Rwanda	\N	27471	\N	\N	\N
35335	MEMBRE	2021-01-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29998	\N	\N	\N
35337	MEMBRE	2021-01-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30000	\N	\N	\N
35562	MEMBRE	2021-01-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	30082	\N	\N	\N
35626	MEMBRE	2021-02-03 00:00:00	2021-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	30111	\N	\N	\N
35564	MEMBRE	2021-01-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	30084	\N	\N	\N
35565	MEMBRE	2021-01-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	30085	\N	\N	\N
35629	MEMBRE	2021-02-03 00:00:00	2021-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	30114	\N	\N	\N
35630	MEMBRE	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30115	\N	\N	\N
35763	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30157	\N	\N	\N
35764	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30158	\N	\N	\N
35765	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30159	\N	\N	\N
35766	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30160	\N	\N	\N
35767	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30161	\N	\N	\N
35863	SECRET	2021-02-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29895	\N	\N	\N
35769	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30163	\N	\N	\N
35770	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30164	\N	\N	\N
35771	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30165	\N	\N	\N
35772	MEMBRE	2020-10-01 00:00:00	2021-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	30166	\N	\N	\N
35773	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30167	\N	\N	\N
35774	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30168	\N	\N	\N
35775	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30169	\N	\N	\N
35776	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30170	\N	\N	\N
35777	MEMBRE	2020-10-01 00:00:00	2021-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	30171	\N	\N	\N
35903	VICPDT	2021-03-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30058	\N	\N	\N
36298	VICPDT	2022-03-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27125	\N	\N	\N
36299	VICPDT	2022-03-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30517	\N	\N	\N
36300	SECRET	2022-03-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28843	\N	\N	\N
36301	SECRET	2022-03-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27760	\N	\N	\N
36302	SECRET	2022-03-03 00:00:00	2022-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	27867	\N	\N	\N
36303	SECRET	2022-03-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28427	\N	\N	\N
36335	MEMBRE	2022-03-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30562	\N	\N	\N
36413	SECRET	2022-05-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30627	\N	\N	\N
36414	MEMBRE	2022-05-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30631	\N	\N	\N
36468	MEMBRE	2022-09-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30685	\N	\N	\N
36612	MEMBRE	2023-03-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30811	\N	\N	\N
36729	MEMBRE	2023-10-06 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	30919	\N	\N	\N
36730	MEMBRE	2023-10-06 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	30920	\N	\N	\N
36731	MEMBRE	2023-10-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30921	\N	\N	\N
36732	MEMBRE	2023-10-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30922	\N	\N	\N
37376	MEMBRE	2023-10-12 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	31568	\N	\N	\N
37377	MEMBRE	2023-10-12 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	31569	\N	\N	\N
37406	MEMBRE	2023-10-12 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	31598	\N	\N	\N
37407	MEMBRE	2023-10-12 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	31599	\N	\N	\N
37408	MEMBRE	2023-10-12 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	31600	\N	\N	\N
37409	MEMBRE	2023-10-12 00:00:00	2024-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	31601	\N	\N	\N
37410	MEMBRE	2023-10-12 00:00:00	2024-01-29 00:00:00	ACTIF	\N	\N	\N	\N	31602	\N	\N	\N
37411	MEMBRE	2023-10-12 00:00:00	2024-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	31603	\N	\N	\N
37412	MEMBRE	2023-10-12 00:00:00	2023-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	31604	\N	\N	\N
37413	MEMBRE	2023-10-12 00:00:00	2024-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	31605	\N	\N	\N
37756	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31948	\N	\N	\N
37757	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31949	\N	\N	\N
37758	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31950	\N	\N	\N
37759	MEMBRE	2023-10-17 00:00:00	2024-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	31951	\N	\N	\N
37760	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31952	\N	\N	\N
37761	MEMBRE	2023-10-17 00:00:00	2023-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	31953	\N	\N	\N
37762	MEMBRE	2023-10-17 00:00:00	2024-02-04 00:00:00	ACTIF	\N	\N	\N	\N	31954	\N	\N	\N
37763	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31955	\N	\N	\N
37764	MEMBRE	2023-10-17 00:00:00	2024-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	31956	\N	\N	\N
37765	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31957	\N	\N	\N
37766	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31958	\N	\N	\N
37767	MEMBRE	2023-10-17 00:00:00	2024-02-26 00:00:00	ACTIF	\N	\N	\N	\N	31959	\N	\N	\N
37768	MEMBRE	2023-10-17 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	31960	\N	\N	\N
37769	MEMBRE	2023-10-17 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	31961	\N	\N	\N
37770	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31962	\N	\N	\N
37771	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31963	\N	\N	\N
37772	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31964	\N	\N	\N
38708	MEMBRE	2023-11-14 00:00:00	2023-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	32903	\N	\N	\N
38942	MEMBRE	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33115	\N	\N	\N
38943	MEMBRE	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33116	\N	\N	\N
38944	MEMBRE	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33117	\N	\N	\N
38945	MEMBRE	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33118	\N	\N	\N
38946	MEMBRE	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33119	\N	\N	\N
38947	MEMBRE	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33120	\N	\N	\N
38948	MEMBRE	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33121	\N	\N	\N
38949	MEMBRE	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33122	\N	\N	\N
38950	MEMBRE	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33123	\N	\N	\N
38951	MEMBRE	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33124	\N	\N	\N
38952	MEMBRE	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33125	\N	\N	\N
38953	MEMBRE	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33126	\N	\N	\N
38954	MEMBRE	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33127	\N	\N	\N
38955	MEMBRE	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33128	\N	\N	\N
38956	MEMBRE	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33129	\N	\N	\N
38957	MEMBRE	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33130	\N	\N	\N
38958	MEMBRE	2023-11-23 00:00:00	2024-01-25 00:00:00	ACTIF	\N	\N	\N	\N	33131	\N	\N	\N
38959	MEMBRE	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33132	\N	\N	\N
38960	MEMBRE	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33133	\N	\N	\N
38961	MEMBRE	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33134	\N	\N	\N
38962	MEMBRE	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33135	\N	\N	\N
38963	MEMBRE	2023-11-23 00:00:00	2024-02-26 00:00:00	ACTIF	\N	\N	\N	\N	33136	\N	\N	\N
38964	MEMBRE	2023-11-23 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	33137	\N	\N	\N
38965	MEMBRE	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33138	\N	\N	\N
38966	MEMBRE	2023-11-23 00:00:00	2023-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	33139	\N	\N	\N
38967	MEMBRE	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33140	\N	\N	\N
38968	MEMBRE	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33141	\N	\N	\N
38969	MEMBRE	2023-11-23 00:00:00	2024-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	33142	\N	\N	\N
38970	MEMBRE	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33143	\N	\N	\N
38971	MEMBRE	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33144	\N	\N	\N
38972	MEMBRE	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33145	\N	\N	\N
38973	MEMBRE	2023-11-23 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	33146	\N	\N	\N
38974	MEMBRE	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33147	\N	\N	\N
38975	MEMBRE	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33148	\N	\N	\N
38976	MEMBRE	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33149	\N	\N	\N
38977	MEMBRE	2023-11-23 00:00:00	2023-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	33150	\N	\N	\N
38978	MEMBRE	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33151	\N	\N	\N
38979	MEMBRE	2023-11-23 00:00:00	2024-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	33152	\N	\N	\N
38980	MEMBRE	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33153	\N	\N	\N
38981	MEMBRE	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33154	\N	\N	\N
38993	MEMBRE	2023-11-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33159	\N	\N	\N
39214	MEMBRE	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33258	\N	\N	\N
39398	MEMBRE	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33368	\N	\N	\N
39665	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33415	\N	\N	\N
40032	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33609	\N	\N	\N
40033	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33610	\N	\N	\N
40037	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33614	\N	\N	\N
40081	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33658	\N	\N	\N
40082	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33659	\N	\N	\N
40084	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33661	\N	\N	\N
40085	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33662	\N	\N	\N
40089	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33666	\N	\N	\N
40090	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33667	\N	\N	\N
40094	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33671	\N	\N	\N
40095	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33672	\N	\N	\N
40096	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33673	\N	\N	\N
40127	MEMBRE	2024-01-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	30776	\N	\N	\N
40227	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33756	\N	\N	\N
40228	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33757	\N	\N	\N
40229	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33758	\N	\N	\N
40230	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33759	\N	\N	\N
40233	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33762	\N	\N	\N
40236	MEMBRE	2023-10-01 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	33765	\N	\N	\N
40237	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33766	\N	\N	\N
40238	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33767	\N	\N	\N
40239	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33768	\N	\N	\N
40241	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33770	\N	\N	\N
40242	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33771	\N	\N	\N
40243	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33772	\N	\N	\N
40244	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33773	\N	\N	\N
40245	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33774	\N	\N	\N
40246	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33775	\N	\N	\N
40248	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33777	\N	\N	\N
40250	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33779	\N	\N	\N
40251	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33780	\N	\N	\N
40252	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33781	\N	\N	\N
40253	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33782	\N	\N	\N
40254	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33783	\N	\N	\N
40257	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33786	\N	\N	\N
40258	MEMBRE	2023-10-01 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	33787	\N	\N	\N
40259	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33788	\N	\N	\N
40270	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33799	\N	\N	\N
40273	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33802	\N	\N	\N
40279	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33808	\N	\N	\N
40384	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33857	\N	\N	\N
40407	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33880	\N	\N	\N
40519	MEMBRE	2023-10-01 00:00:00	2024-02-27 00:00:00	ACTIF	\N	\N	\N	\N	33992	\N	\N	\N
40520	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33993	\N	\N	\N
40522	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33995	\N	\N	\N
40523	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33996	\N	\N	\N
40524	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33997	\N	\N	\N
40525	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33998	\N	\N	\N
40526	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33999	\N	\N	\N
40527	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34000	\N	\N	\N
40528	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34001	\N	\N	\N
40548	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34021	\N	\N	\N
40559	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34032	\N	\N	\N
40566	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34039	\N	\N	\N
40569	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34042	\N	\N	\N
40581	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34054	\N	\N	\N
40582	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34055	\N	\N	\N
40583	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34056	\N	\N	\N
40587	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34060	\N	\N	\N
40591	MEMBRE	2023-12-14 00:00:00	2024-02-05 00:00:00	ACTIF	\N	\N	\N	\N	34064	\N	\N	\N
40593	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34066	\N	\N	\N
40594	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34067	\N	\N	\N
40596	MEMBRE	2023-12-14 00:00:00	2024-02-05 00:00:00	ACTIF	\N	\N	\N	\N	34069	\N	\N	\N
40636	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34109	\N	\N	\N
40637	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34110	\N	\N	\N
40638	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34111	\N	\N	\N
40640	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34113	\N	\N	\N
40641	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34114	\N	\N	\N
40642	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34115	\N	\N	\N
40643	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34116	\N	\N	\N
40644	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34117	\N	\N	\N
40646	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34119	\N	\N	\N
40652	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34125	\N	\N	\N
40666	VICPDT	2024-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	33822	\N	\N	\N
40670	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34133	\N	\N	\N
40676	VICPDT	2024-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	33732	\N	\N	\N
40693	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34152	\N	\N	\N
40711	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34170	\N	\N	\N
40733	MEMBRE	2023-10-01 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	34189	\N	\N	\N
40750	SECRET	2024-01-23 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	\N	29887	\N	\N	\N
40752	SECRET	2024-01-23 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	\N	29894	\N	\N	\N
40791	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31367	\N	\N	\N
40792	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31476	\N	\N	\N
40793	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30919	\N	\N	\N
40794	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32202	\N	\N	\N
40795	MEMBRE	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31510	\N	\N	\N
40796	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31243	\N	\N	\N
40797	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32534	\N	\N	\N
40798	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32459	\N	\N	\N
40799	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31860	\N	\N	\N
40800	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32456	\N	\N	\N
40801	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32363	\N	\N	\N
40802	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31449	\N	\N	\N
40803	SECRET	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33137	\N	\N	\N
40804	SECRET	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32065	\N	\N	\N
40805	SECRET	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32373	\N	\N	\N
40818	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34225	\N	\N	\N
40819	VICPDT	2024-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	34189	\N	\N	\N
40820	VICPDT	2024-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	34220	\N	\N	\N
40821	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34226	\N	\N	\N
40830	MEMBRE	2024-01-24 00:00:00	2024-03-24 00:00:00	ACTIF	\N	\N	\N	\N	34233	\N	\N	\N
40880	VICPDT	2024-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	33807	\N	\N	\N
40882	MEMBRE	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34246	\N	\N	\N
40906	MEMBRE	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34249	\N	\N	\N
30552	PDTHON	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24573	\N	2018-02-07 12:14:36	\N
30553	VICPDT	2018-02-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24654	\N	2018-02-07 12:14:46	\N
30554	VICPDT	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24952	\N	2018-02-07 12:14:53	\N
30555	VICPDT	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24489	\N	2018-02-07 12:15:13	\N
30556	VICPDT	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25591	\N	2018-02-07 12:15:24	\N
30557	VICPDT	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25533	\N	2018-02-07 12:15:30	\N
30558	SECRET	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25753	\N	2018-02-07 12:15:40	\N
30559	SECRET	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25512	\N	2018-02-07 12:15:53	\N
31118	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26642	\N	\N	\N
31170	MEMBRE	2017-12-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26694	\N	\N	\N
31202	VICPDT	2018-03-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	26504	\N	\N	\N
31228	MEMBRE	2017-12-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26722	\N	\N	\N
31324	MEMBRE	2018-06-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26792	\N	\N	\N
31419	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26880	\N	\N	\N
31441	MEMBRE	2018-01-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26902	\N	\N	\N
31443	MEMBRE	2018-11-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26904	\N	\N	\N
31558	MEMBRE	2019-04-02 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	27005	\N	\N	\N
31629	MEMBRE	2019-12-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27061	\N	\N	\N
31631	MEMBRE	2019-12-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27063	\N	\N	\N
33286	MEMBRE	2020-11-03 00:00:00	2023-09-12 00:00:00	ANCIEN	\N	\N	\N	\N	28719	\N	\N	\N
33287	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28720	\N	\N	\N
33288	MEMBRE	2020-11-03 00:00:00	2021-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	28721	\N	\N	\N
33523	MEMBRE	2020-11-13 00:00:00	2020-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	28945	\N	\N	\N
34533	MEMBRE	2020-12-15 00:00:00	2021-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	29397	\N	\N	\N
34605	MEMBRE	2020-12-16 00:00:00	2021-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	29466	\N	\N	\N
35189	MEMBRE	2020-10-01 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	29913	\N	\N	\N
35190	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29914	\N	\N	\N
35192	MEMBRE	2020-10-01 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	29916	\N	\N	\N
35193	MEMBRE	2020-10-01 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	29917	\N	\N	\N
35194	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29918	\N	\N	\N
35195	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29919	\N	\N	\N
35196	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29920	\N	\N	\N
35197	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29921	\N	\N	\N
35198	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29922	\N	\N	\N
35199	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29923	\N	\N	\N
35200	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29924	\N	\N	\N
35201	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29925	\N	\N	\N
35202	MEMBRE	2020-10-01 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	29926	\N	\N	\N
35204	MEMBRE	2020-10-01 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	29928	\N	\N	\N
35205	MEMBRE	2020-10-01 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	29929	\N	\N	\N
35206	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29930	\N	\N	\N
35207	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29931	\N	\N	\N
35373	VICPDT	2021-01-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	29270	\N	\N	\N
35380	MEMBRE	2021-01-22 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	30017	\N	\N	\N
35400	PDTHON	2021-01-26 00:00:00	2021-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	28903	\N	\N	\N
35401	VICPDT	2021-01-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28383	\N	\N	\N
35402	VICPDT	2021-01-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27561	\N	\N	\N
35404	VICPDT	2021-01-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28734	\N	\N	\N
35405	VICPDT	2021-01-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27366	\N	\N	\N
35407	VICPDT	2021-01-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27341	\N	\N	\N
35408	VICPDT	2021-01-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28117	\N	\N	\N
35410	SECRET	2021-01-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28283	\N	\N	\N
35411	SECRET	2021-01-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27424	\N	\N	\N
35412	SECRET	2021-01-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28954	\N	\N	\N
35424	VICPDT	2021-01-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29691	\N	\N	\N
35425	PDT	2021-01-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29377	\N	\N	\N
35426	VICPDT	2021-01-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	29674	\N	\N	\N
35427	VICPDT	2021-01-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	29389	\N	\N	\N
35428	VICPDT	2021-01-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29751	\N	\N	\N
35429	VICPDT	2021-01-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29390	\N	\N	\N
35434	MEMBRE	2021-01-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	30051	\N	\N	\N
35480	VICPDT	2021-01-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	29927	\N	\N	\N
35481	VICPDT	2021-01-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29911	\N	\N	\N
35482	VICPDT	2021-01-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	29913	\N	\N	\N
36039	VICPDT	2021-04-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30297	\N	\N	\N
36041	VICPDT	2021-04-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	30298	\N	\N	\N
36477	MEMBRE	2021-12-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30694	\N	\N	\N
36591	MEMBRE	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30797	\N	\N	\N
36618	MEMBRE	2023-03-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30817	\N	\N	\N
36624	MEMBRE	2023-04-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30823	\N	\N	\N
37251	MEMBRE	2023-10-11 00:00:00	2023-12-11 00:00:00	ANCIEN	\N	\N	\N	\N	31443	\N	\N	\N
37252	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31444	\N	\N	\N
37253	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31445	\N	\N	\N
37254	MEMBRE	2023-10-11 00:00:00	2024-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	31446	\N	\N	\N
37262	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31454	\N	\N	\N
37263	MEMBRE	2023-10-11 00:00:00	2024-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	31455	\N	\N	\N
37264	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31456	\N	\N	\N
37265	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31457	\N	\N	\N
37266	MEMBRE	2023-10-11 00:00:00	2024-02-04 00:00:00	ACTIF	\N	\N	\N	\N	31458	\N	\N	\N
37267	MEMBRE	2023-10-11 00:00:00	2024-04-02 00:00:00	ACTIF	\N	\N	\N	\N	31459	\N	\N	\N
37268	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31460	\N	\N	\N
37269	MEMBRE	2023-10-11 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	31461	\N	\N	\N
37270	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31462	\N	\N	\N
37271	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31463	\N	\N	\N
37272	MEMBRE	2023-10-11 00:00:00	2024-01-29 00:00:00	ACTIF	\N	\N	\N	\N	31464	\N	\N	\N
37298	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31490	\N	\N	\N
37299	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31491	\N	\N	\N
37300	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31492	\N	\N	\N
37621	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31813	\N	\N	\N
37809	MEMBRE	2023-10-18 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	32001	\N	\N	\N
37810	MEMBRE	2023-10-18 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	32002	\N	\N	\N
37811	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32003	\N	\N	\N
37812	MEMBRE	2023-10-18 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	32004	\N	\N	\N
37813	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32005	\N	\N	\N
37814	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32006	\N	\N	\N
37815	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32007	\N	\N	\N
37816	MEMBRE	2023-10-18 00:00:00	2024-02-26 00:00:00	ACTIF	\N	\N	\N	\N	32008	\N	\N	\N
37817	MEMBRE	2023-10-18 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	32009	\N	\N	\N
37818	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32010	\N	\N	\N
37819	MEMBRE	2023-10-18 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	32011	\N	\N	\N
37820	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32012	\N	\N	\N
37821	MEMBRE	2023-10-18 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	32013	\N	\N	\N
37822	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32014	\N	\N	\N
37823	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32015	\N	\N	\N
37824	MEMBRE	2023-10-18 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	32016	\N	\N	\N
37825	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32017	\N	\N	\N
37841	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32033	\N	\N	\N
37842	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32034	\N	\N	\N
37843	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32035	\N	\N	\N
37844	MEMBRE	2023-10-18 00:00:00	2024-04-02 00:00:00	ACTIF	\N	\N	\N	\N	32036	\N	\N	\N
37854	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32046	\N	\N	\N
37855	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32047	\N	\N	\N
37856	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32048	\N	\N	\N
37955	MEMBRE	2023-10-19 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	32150	\N	\N	\N
38007	MEMBRE	2023-10-23 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	32202	\N	\N	\N
38008	MEMBRE	2023-10-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32203	\N	\N	\N
38009	MEMBRE	2023-10-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32204	\N	\N	\N
38010	MEMBRE	2023-10-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32205	\N	\N	\N
38011	MEMBRE	2023-10-23 00:00:00	2024-02-08 00:00:00	ACTIF	\N	\N	\N	\N	32206	\N	\N	\N
38012	MEMBRE	2023-10-23 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	32207	\N	\N	\N
38220	MEMBRE	2023-10-26 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	32415	\N	\N	\N
38221	MEMBRE	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32416	\N	\N	\N
38222	MEMBRE	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32417	\N	\N	\N
38223	MEMBRE	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32418	\N	\N	\N
38224	MEMBRE	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32419	\N	\N	\N
38230	MEMBRE	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32425	\N	\N	\N
38231	MEMBRE	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32426	\N	\N	\N
38232	MEMBRE	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32427	\N	\N	\N
38233	MEMBRE	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32428	\N	\N	\N
38234	MEMBRE	2023-10-26 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	32429	\N	\N	\N
38235	MEMBRE	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32430	\N	\N	\N
38984	PDT	2023-11-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31697	\N	\N	\N
38985	PDT	2023-11-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32584	\N	\N	\N
38986	PDTDEL	2023-11-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour la Guinée-Bissau	\N	32728	\N	\N	\N
38987	PDTDEL	2023-11-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour la Guinée (Conakry)	\N	32970	\N	\N	\N
38028	MEMBRE	2023-10-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32223	\N	\N	\N
38152	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32347	\N	\N	\N
38510	MEMBRE	2023-11-03 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	32705	\N	\N	\N
38511	MEMBRE	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32706	\N	\N	\N
38512	MEMBRE	2023-11-03 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	32707	\N	\N	\N
39257	MEMBRE	2023-12-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33301	\N	\N	\N
39397	MEMBRE	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33367	\N	\N	\N
39494	MEMBRE	2023-12-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33388	\N	\N	\N
39495	MEMBRE	2023-12-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33389	\N	\N	\N
40039	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33616	\N	\N	\N
40040	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33617	\N	\N	\N
40041	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33618	\N	\N	\N
40105	MEMBRE	2023-10-01 00:00:00	2024-04-08 00:00:00	ACTIF	\N	\N	\N	\N	33680	\N	\N	\N
40043	MEMBRE	2024-01-02 00:00:00	2024-02-06 00:00:00	ACTIF	\N	\N	\N	\N	33620	\N	\N	\N
40045	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33622	\N	\N	\N
40046	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33623	\N	\N	\N
40972	SECRET	2024-01-26 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31351	\N	\N	\N
40048	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33625	\N	\N	\N
40049	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33626	\N	\N	\N
40056	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33633	\N	\N	\N
40057	MEMBRE	2024-01-02 00:00:00	2024-02-06 00:00:00	ACTIF	\N	\N	\N	\N	33634	\N	\N	\N
40060	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33637	\N	\N	\N
40061	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33638	\N	\N	\N
40093	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33670	\N	\N	\N
40097	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33674	\N	\N	\N
40107	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33682	\N	\N	\N
40128	MEMBRE	2024-01-02 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	30744	\N	\N	\N
40187	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33716	\N	\N	\N
40202	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33731	\N	\N	\N
40204	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33733	\N	\N	\N
40205	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33734	\N	\N	\N
40206	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33735	\N	\N	\N
40207	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33736	\N	\N	\N
40208	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33737	\N	\N	\N
40209	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33738	\N	\N	\N
40210	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33739	\N	\N	\N
40211	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33740	\N	\N	\N
40212	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33741	\N	\N	\N
40214	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33743	\N	\N	\N
40216	MEMBRE	2023-10-01 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	33745	\N	\N	\N
40217	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33746	\N	\N	\N
40218	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33747	\N	\N	\N
40219	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33748	\N	\N	\N
40220	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33749	\N	\N	\N
40222	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33751	\N	\N	\N
40223	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33752	\N	\N	\N
40224	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33753	\N	\N	\N
40291	MEMBRE	2023-10-01 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	33820	\N	\N	\N
40292	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33821	\N	\N	\N
40325	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33833	\N	\N	\N
40477	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33950	\N	\N	\N
40478	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33951	\N	\N	\N
40479	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33952	\N	\N	\N
40484	MEMBRE	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	\N	33957	\N	\N	\N
40973	SECRET	2024-01-26 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32097	\N	\N	\N
41165	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34314	\N	\N	\N
30657	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26358	\N	\N	\N
31348	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26810	\N	\N	\N
32523	MEMBRE	2020-10-19 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	27952	\N	\N	\N
32524	MEMBRE	2020-10-19 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	27953	\N	\N	\N
32525	MEMBRE	2020-10-16 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	27954	\N	\N	\N
32526	MEMBRE	2020-10-19 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	27955	\N	\N	\N
32527	MEMBRE	2020-10-19 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	27956	\N	\N	\N
32528	MEMBRE	2020-10-19 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	27957	\N	\N	\N
33280	MEMBRE	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28713	\N	\N	\N
33281	MEMBRE	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28714	\N	\N	\N
33282	MEMBRE	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28715	\N	\N	\N
33283	MEMBRE	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28716	\N	\N	\N
33284	MEMBRE	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28717	\N	\N	\N
33285	MEMBRE	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28718	\N	\N	\N
33289	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28722	\N	\N	\N
33290	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28723	\N	\N	\N
33291	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28724	\N	\N	\N
33292	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28725	\N	\N	\N
33293	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28726	\N	\N	\N
33294	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28727	\N	\N	\N
33861	MEMBRE	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29112	\N	\N	\N
33862	MEMBRE	2020-11-25 00:00:00	2020-12-23 00:00:00	ANCIEN	\N	\N	\N	\N	29113	\N	\N	\N
33863	MEMBRE	2020-11-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29114	\N	\N	\N
33864	MEMBRE	2020-11-24 00:00:00	2023-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	29115	\N	\N	\N
33865	MEMBRE	2020-11-24 00:00:00	2020-12-23 00:00:00	ANCIEN	\N	\N	\N	\N	29116	\N	\N	\N
33866	MEMBRE	2020-11-25 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	29117	\N	\N	\N
33867	MEMBRE	2020-11-19 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	29118	\N	\N	\N
33868	MEMBRE	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29119	\N	\N	\N
33869	MEMBRE	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29120	\N	\N	\N
33870	MEMBRE	2020-11-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29121	\N	\N	\N
33885	MEMBRE	2020-11-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29134	\N	\N	\N
33966	MEMBRE	2020-12-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29179	\N	\N	\N
33967	VICPDT	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27121	\N	\N	\N
33968	VICPDT	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27802	\N	\N	\N
33969	VICPDT	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28306	\N	\N	\N
33970	VICPDT	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27849	\N	\N	\N
33971	VICPDT	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27698	\N	\N	\N
33972	VICPDT	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27506	\N	\N	\N
33973	VICPDT	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27472	\N	\N	\N
33974	VICPDT	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27682	\N	\N	\N
33975	VICPDT	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28278	\N	\N	\N
33976	SECRET	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27484	\N	\N	\N
33977	SECRET	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28249	\N	\N	\N
33978	VICPDT	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28363	\N	\N	\N
33979	VICPDT	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27774	\N	\N	\N
33980	VICPDT	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28315	\N	\N	\N
33981	SECRET	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28053	\N	\N	\N
33982	SECRET	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27725	\N	\N	\N
33983	SECRET	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28261	\N	\N	\N
33984	SECRET	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27938	\N	\N	\N
33985	SECRET	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28297	\N	\N	\N
33986	MEMBRE	2020-12-04 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	29180	\N	\N	\N
34112	VICPDT	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27968	\N	\N	\N
34113	VICPDT	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27653	\N	\N	\N
34114	VICPDT	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29086	\N	\N	\N
34115	VICPDT	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27579	\N	\N	\N
34116	VICPDT	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27120	\N	\N	\N
34117	VICPDT	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29130	\N	\N	\N
34118	VICPDT	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27647	\N	\N	\N
34119	VICPDT	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29181	\N	\N	\N
34120	SECRET	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27423	\N	\N	\N
34121	SECRET	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29007	\N	\N	\N
34432	MEMBRE	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29304	\N	\N	\N
34439	MEMBRE	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29311	\N	\N	\N
34440	MEMBRE	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29312	\N	\N	\N
34446	VICPDT	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27596	\N	\N	\N
34447	VICPDT	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28159	\N	\N	\N
34448	VICPDT	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27740	\N	\N	\N
34449	VICPDT	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28867	\N	\N	\N
34450	SECRET	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27979	\N	\N	\N
34451	SECRET	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28354	\N	\N	\N
34452	SECRET	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27503	\N	\N	\N
34453	VICPDT	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27757	\N	\N	\N
34534	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29398	\N	\N	\N
34551	MEMBRE	2020-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29415	\N	\N	\N
34552	MEMBRE	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29416	\N	\N	\N
34553	MEMBRE	2020-12-15 00:00:00	2021-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	29417	\N	\N	\N
34567	MEMBRE	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29431	\N	\N	\N
34568	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29432	\N	\N	\N
34569	MEMBRE	2020-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29433	\N	\N	\N
34570	MEMBRE	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29434	\N	\N	\N
34636	MEMBRE	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29494	\N	\N	\N
35259	VICPDT	2021-01-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27786	\N	\N	\N
35260	VICPDT	2021-01-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27159	\N	\N	\N
35261	VICPDT	2021-01-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27440	\N	\N	\N
35262	VICPDT	2021-01-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27232	\N	\N	\N
35263	VICPDT	2021-01-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27537	\N	\N	\N
35264	VICPDT	2021-01-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28509	\N	\N	\N
35265	VICPDT	2021-01-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27601	\N	\N	\N
35266	VICPDT	2021-01-21 00:00:00	2023-07-26 00:00:00	ANCIEN	\N	\N	\N	\N	29554	\N	\N	\N
35267	VICPDT	2021-01-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27398	\N	\N	\N
35268	VICPDT	2021-01-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28536	\N	\N	\N
35269	SECRET	2021-01-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28899	\N	\N	\N
35270	SECRET	2021-01-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28211	\N	\N	\N
35271	SECRET	2021-01-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28606	\N	\N	\N
35272	VICPDT	2021-01-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27410	\N	\N	\N
35273	VICPDT	2021-01-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27636	\N	\N	\N
35274	VICPDT	2021-01-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27851	\N	\N	\N
35275	VICPDT	2021-01-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27826	\N	\N	\N
35276	VICPDT	2021-01-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28974	\N	\N	\N
35277	VICPDT	2021-01-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28289	\N	\N	\N
35278	SECRET	2021-01-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27333	\N	\N	\N
35279	SECRET	2021-01-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28402	\N	\N	\N
35327	MEMBRE	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29990	\N	\N	\N
35336	MEMBRE	2021-01-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29999	\N	\N	\N
35348	MEMBRE	2020-10-01 00:00:00	2021-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	30011	\N	\N	\N
35350	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30013	\N	\N	\N
35351	PDT	2021-01-26 00:00:00	2021-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	29614	\N	\N	\N
35352	PDT	2021-01-26 00:00:00	2021-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	29614	\N	\N	\N
35353	VICPDT	2021-01-26 00:00:00	2021-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	29656	\N	\N	\N
35365	VICPDT	2021-01-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29619	\N	\N	\N
35366	PDT	2021-01-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	29614	\N	\N	\N
35367	VICPDT	2021-01-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	29656	\N	\N	\N
35379	MEMBRE	2021-01-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30016	\N	\N	\N
35381	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30018	\N	\N	\N
35394	MEMBRE	2021-01-26 00:00:00	2022-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	30031	\N	\N	\N
35399	MEMBRE	2021-01-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30036	\N	\N	\N
35433	MEMBRE	2021-01-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30050	\N	\N	\N
35615	MEMBRE	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30100	\N	\N	\N
35681	VICPDT	2021-02-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29818	\N	\N	\N
35761	MEMBRE	2020-10-01 00:00:00	2021-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	30156	\N	\N	\N
35778	MEMBRE	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	30172	\N	\N	\N
35781	MEMBRE	2020-10-01 00:00:00	2021-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	30175	\N	\N	\N
35782	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30176	\N	\N	\N
35783	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30177	\N	\N	\N
35784	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30178	\N	\N	\N
35785	MEMBRE	2020-10-01 00:00:00	2021-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	30179	\N	\N	\N
35786	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30180	\N	\N	\N
35789	MEMBRE	2020-10-01 00:00:00	2021-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	30183	\N	\N	\N
35792	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30186	\N	\N	\N
35793	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30187	\N	\N	\N
35794	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30188	\N	\N	\N
35911	MEMBRE	2021-03-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	30223	\N	\N	\N
35947	MEMBRE	2020-10-01 00:00:00	2021-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	30250	\N	\N	\N
35948	PDT	2021-03-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30250	\N	\N	\N
36017	PDT	2021-03-30 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29868	\N	\N	\N
36018	VICPDT	2021-03-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29867	\N	\N	\N
36032	MEMBRE	2021-03-31 00:00:00	\N	ACTIF	\N	\N	\N	\N	30319	\N	\N	\N
36068	MEMBRE	2021-06-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30349	\N	\N	\N
36073	MEMBRE	2021-06-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30354	\N	\N	\N
36262	MEMBRE	2022-01-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30506	\N	\N	\N
38081	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32276	\N	\N	\N
38196	MEMBRE	2023-10-25 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	32391	\N	\N	\N
38197	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32392	\N	\N	\N
38198	MEMBRE	2023-10-25 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	32393	\N	\N	\N
38199	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32394	\N	\N	\N
38200	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32395	\N	\N	\N
38253	MEMBRE	2023-10-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32448	\N	\N	\N
38383	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32578	\N	\N	\N
38384	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32579	\N	\N	\N
38477	MEMBRE	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32672	\N	\N	\N
38478	MEMBRE	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32673	\N	\N	\N
39394	MEMBRE	2023-12-13 00:00:00	2024-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	33364	\N	\N	\N
39395	MEMBRE	2023-12-13 00:00:00	2024-02-29 00:00:00	ACTIF	\N	\N	\N	\N	33365	\N	\N	\N
39396	MEMBRE	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33366	\N	\N	\N
40213	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33742	\N	\N	\N
40215	MEMBRE	2023-10-01 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	33744	\N	\N	\N
40249	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33778	\N	\N	\N
40256	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33785	\N	\N	\N
40323	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33832	\N	\N	\N
40324	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	30775	\N	\N	\N
40332	MEMBRE	2024-01-02 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	30756	\N	\N	\N
40334	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	30770	\N	\N	\N
40834	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34237	\N	\N	\N
40941	MEMBRE	2023-12-14 00:00:00	\N	\N	\N	\N	\N	\N	34263	\N	\N	\N
40985	VICPDT	2024-01-29 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32279	\N	\N	\N
40987	VICPDT	2024-01-30 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31464	\N	\N	\N
40988	VICPDT	2024-01-30 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32287	\N	\N	\N
40989	VICPDT	2024-01-30 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31661	\N	\N	\N
40990	VICPDT	2024-01-30 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31988	\N	\N	\N
40991	VICPDT	2024-01-30 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32092	\N	\N	\N
40992	VICPDT	2024-01-30 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31602	\N	\N	\N
40993	VICPDT	2024-01-30 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32109	\N	\N	\N
40994	VICPDT	2024-01-30 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31436	\N	\N	\N
40995	VICPDT	2024-01-30 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31696	\N	\N	\N
40996	VICPDT	2024-01-30 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	33499	\N	\N	\N
40997	VICPDT	2024-01-30 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31092	\N	\N	\N
40998	SECRET	2024-01-30 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31011	\N	\N	\N
40999	SECRET	2024-01-30 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32018	\N	\N	\N
41000	SECRET	2024-01-30 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31740	\N	\N	\N
41001	SECRET	2024-01-30 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32068	\N	\N	\N
41002	PDTDEL	2024-01-30 00:00:00	2026-10-01 00:00:00	\N	\N	\N	pour le Pérou	\N	34053	\N	\N	\N
41003	PDT	2024-01-30 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	29786	\N	\N	\N
41017	MEMBRE	2024-01-30 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34271	\N	\N	\N
41031	PDT	2024-01-31 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	30012	\N	\N	\N
41032	VICPDT	2024-01-31 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	33520	\N	\N	\N
41033	VICPDT	2024-01-31 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	29858	\N	\N	\N
41055	MEMBRE	2024-01-31 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	34269	\N	\N	\N
41102	MEMBRE	2024-02-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34304	\N	\N	\N
41124	VICPDT	2024-02-06 00:00:00	\N	\N	\N	\N	\N	\N	34064	\N	\N	\N
41130	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34306	\N	\N	\N
41196	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34329	\N	\N	\N
41209	MEMBRE	2024-02-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34335	\N	\N	\N
41235	VICPDT	2024-02-14 00:00:00	\N	\N	\N	\N	\N	\N	34230	\N	\N	\N
41237	VICPDT	2024-02-14 00:00:00	\N	\N	\N	\N	\N	\N	33909	\N	\N	\N
41252	VICPDT	2024-02-14 00:00:00	\N	\N	\N	\N	\N	\N	33855	\N	\N	\N
41260	VICPDT	2024-02-14 00:00:00	\N	\N	\N	\N	\N	\N	33901	\N	\N	\N
41268	SECRET	2024-02-14 00:00:00	\N	\N	\N	\N	\N	\N	33941	\N	\N	\N
41350	VICPDT	2024-02-28 00:00:00	\N	\N	\N	\N	\N	\N	34046	\N	\N	\N
41355	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34367	\N	\N	\N
41356	MEMBRE	2023-12-14 00:00:00	\N	\N	\N	\N	\N	\N	34368	\N	\N	\N
41382	MEMBRE	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	34384	\N	\N	\N
41386	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34388	\N	\N	\N
41392	MEMBRE	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	34394	\N	\N	\N
41394	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34396	\N	\N	\N
41395	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34397	\N	\N	\N
41396	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34398	\N	\N	\N
41408	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34406	\N	\N	\N
41409	MEMBRE	2023-12-14 00:00:00	\N	\N	\N	\N	\N	\N	34407	\N	\N	\N
41453	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34441	\N	\N	\N
41483	MEMBRE	2024-03-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34471	\N	\N	\N
41496	MEMBRE	2024-03-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34484	\N	\N	\N
41532	PDT	2024-03-19 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	34381	\N	\N	\N
41535	VICPDT	2024-03-19 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	34372	\N	\N	\N
41541	PDTDEL	2024-03-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour l'Erythrée	\N	34494	\N	\N	\N
41542	VICPDTDEL	2024-03-29 00:00:00	2026-10-01 00:00:00	\N	\N	\N	pour le Rwanda	\N	32654	\N	\N	\N
41559	MEMBRE	2023-10-01 00:00:00	2024-04-08 00:00:00	\N	\N	\N	\N	\N	34500	\N	\N	\N
30626	VICPDT	2018-02-08 00:00:00	2019-03-08 00:00:00	ANCIEN	\N	\N	\N	\N	25977	\N	2018-02-08 16:42:57	\N
30627	VICPDT	2018-02-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25690	\N	2018-02-08 16:43:02	\N
30628	VICPDT	2018-02-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23866	\N	2018-02-08 16:43:09	\N
30629	VICPDT	2018-02-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23918	\N	2018-02-08 16:43:19	\N
30630	VICPDT	2018-02-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24741	\N	2018-02-08 16:43:26	\N
30631	SECRET	2018-02-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24916	\N	2018-02-08 16:43:41	\N
30632	SECRET	2018-02-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25779	\N	2018-02-08 16:44:21	\N
30701	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26402	\N	\N	\N
30859	MEMBREBUR	2018-02-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	26052	\N	\N	\N
30860	MEMBREBUR	2018-02-14 00:00:00	2018-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	26057	\N	\N	\N
30861	MEMBRE	2018-02-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	26057	\N	\N	\N
30862	MEMBREBUR	2018-02-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	26058	\N	\N	\N
30947	MEMBRE	2018-01-18 00:00:00	2018-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	26546	\N	2018-02-16 15:15:33	2018-02-21 15:39:40
30948	MEMBRE	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26547	\N	2018-02-16 15:15:33	\N
30949	MEMBRE	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26548	\N	2018-02-16 15:15:33	\N
30950	MEMBRE	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26549	\N	2018-02-16 15:15:33	\N
30951	MEMBRE	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26550	\N	2018-02-16 15:15:33	\N
31390	MEMBRE	2018-10-04 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26852	\N	\N	\N
31418	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26879	\N	\N	\N
31541	MEMBRE	2018-01-31 00:00:00	\N	ACTIF	\N	\N	\N	\N	26993	\N	\N	\N
31559	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	27006	\N	\N	\N
31587	MEMBRE	2019-07-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	27029	\N	\N	\N
31586	PDTDEL	2019-07-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	République démocratique du Congo	\N	24263	\N	\N	\N
31588	MEMBRE	2019-07-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	27030	\N	\N	\N
31595	MEMBRE	2019-09-25 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26114	\N	\N	\N
31651	MEMBRE	2020-01-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27083	\N	\N	\N
33032	MEMBRE	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28465	\N	\N	\N
33033	MEMBRE	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28466	\N	\N	\N
33034	MEMBRE	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28467	\N	\N	\N
33035	MEMBRE	2020-10-20 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	28468	\N	\N	\N
33036	MEMBRE	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28469	\N	\N	\N
33037	MEMBRE	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28470	\N	\N	\N
33038	MEMBRE	2020-10-20 00:00:00	2021-01-11 00:00:00	ANCIEN	\N	\N	\N	\N	28471	\N	\N	\N
33519	MEMBRE	2020-11-04 00:00:00	2021-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	28941	\N	\N	\N
33520	MEMBRE	2020-11-04 00:00:00	2020-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	28942	\N	\N	\N
33521	MEMBRE	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28943	\N	\N	\N
33522	MEMBRE	2020-11-04 00:00:00	2021-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	28944	\N	\N	\N
34426	MEMBRE	2020-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29298	\N	\N	\N
34428	MEMBRE	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29300	\N	\N	\N
34429	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29301	\N	\N	\N
34651	MEMBRE	2020-12-18 00:00:00	2021-07-20 00:00:00	ANCIEN	\N	\N	\N	\N	29509	\N	\N	\N
34654	MEMBRE	2020-12-18 00:00:00	2020-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	29318	\N	\N	\N
34840	MEMBRE	2021-01-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29623	\N	\N	\N
34891	MEMBRE	2021-01-08 00:00:00	2021-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	29656	\N	\N	\N
35037	VICPDT	2021-01-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28196	\N	\N	\N
35038	VICPDT	2021-01-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29730	\N	\N	\N
35342	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30005	\N	\N	\N
35496	VICPDT	2021-01-27 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	30047	\N	\N	\N
35592	MEMBRE	2021-02-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30093	\N	\N	\N
36197	VICPDT	2021-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	30359	\N	\N	\N
36198	VICPDT	2021-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	30344	\N	\N	\N
36199	VICPDT	2021-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	30365	\N	\N	\N
36212	MEMBRE	2021-11-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30458	\N	\N	\N
36245	VICPDT	2021-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28844	\N	\N	\N
36320	MEMBRE	2022-03-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27867	\N	\N	\N
36584	VICPDT	2023-01-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30753	\N	\N	\N
37910	MEMBRE	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32102	\N	\N	\N
37911	MEMBRE	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32103	\N	\N	\N
37912	MEMBRE	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32104	\N	\N	\N
37913	MEMBRE	2023-10-19 00:00:00	2024-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	32105	\N	\N	\N
37914	MEMBRE	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32106	\N	\N	\N
37915	MEMBRE	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32107	\N	\N	\N
37916	MEMBRE	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32108	\N	\N	\N
37917	MEMBRE	2023-10-19 00:00:00	2024-01-29 00:00:00	ACTIF	\N	\N	\N	\N	32109	\N	\N	\N
37918	MEMBRE	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32110	\N	\N	\N
37919	MEMBRE	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32111	\N	\N	\N
37920	MEMBRE	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32112	\N	\N	\N
37921	MEMBRE	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32113	\N	\N	\N
37922	MEMBRE	2023-10-19 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	32114	\N	\N	\N
37923	MEMBRE	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32115	\N	\N	\N
37924	MEMBRE	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32116	\N	\N	\N
37925	MEMBRE	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32117	\N	\N	\N
37954	MEMBRE	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32149	\N	\N	\N
38263	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32458	\N	\N	\N
38264	MEMBRE	2023-10-31 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	32459	\N	\N	\N
38265	MEMBRE	2023-10-31 00:00:00	2023-10-31 00:00:00	ANCIEN	\N	\N	\N	\N	32460	\N	\N	\N
38266	MEMBRE	2023-10-31 00:00:00	2023-10-31 00:00:00	ANCIEN	\N	\N	\N	\N	32461	\N	\N	\N
38267	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32462	\N	\N	\N
38268	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32463	\N	\N	\N
38269	MEMBRE	2023-10-31 00:00:00	2023-10-31 00:00:00	ANCIEN	\N	\N	\N	\N	32464	\N	\N	\N
38842	MEMBRE	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33037	\N	\N	\N
38844	MEMBRE	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33039	\N	\N	\N
38866	MEMBRE	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33061	\N	\N	\N
38867	MEMBRE	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33062	\N	\N	\N
38988	PDTDEL	2023-11-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour Sao Tomé-et-Principe	\N	32745	\N	\N	\N
38989	PDTDEL	2023-11-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour la Tanzanie	\N	32552	\N	\N	\N
38990	PDTDEL	2023-11-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	Pour la Zambie	\N	32613	\N	\N	\N
38992	MEMBRE	2023-11-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33158	\N	\N	\N
39157	MEMBRE	2023-11-29 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	33202	\N	\N	\N
39158	MEMBRE	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33203	\N	\N	\N
39160	MEMBRE	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33205	\N	\N	\N
39307	MEMBRE	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33320	\N	\N	\N
39271	MEMBRE	2023-12-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33315	\N	\N	\N
39354	MEMBRE	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33337	\N	\N	\N
39478	VICPDT	2023-12-18 00:00:00	2024-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	32717	\N	\N	\N
39479	VICPDT	2023-12-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33192	\N	\N	\N
39480	VICPDT	2023-12-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31967	\N	\N	\N
39481	VICPDT	2023-12-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31041	\N	\N	\N
39482	VICPDT	2023-12-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32326	\N	\N	\N
39483	VICPDT	2023-12-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32224	\N	\N	\N
39484	VICPDT	2023-12-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31467	\N	\N	\N
39485	VICPDT	2023-12-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32895	\N	\N	\N
39486	VICPDT	2023-12-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32571	\N	\N	\N
39487	VICPDT	2023-12-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31626	\N	\N	\N
39488	VICPDT	2023-12-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32040	\N	\N	\N
39489	SECRET	2023-12-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31168	\N	\N	\N
39490	SECRET	2023-12-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32628	\N	\N	\N
39491	SECRET	2023-12-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31226	\N	\N	\N
39631	VICPDT	2023-12-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32218	\N	\N	\N
39632	SECRET	2023-12-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31953	\N	\N	\N
39651	MEMBRE	2023-10-01 00:00:00	2024-01-29 00:00:00	ACTIF	\N	\N	\N	\N	33406	\N	\N	\N
39827	MEMBRE	2024-01-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33495	\N	\N	\N
39829	MEMBRE	2024-01-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33497	\N	\N	\N
39847	MEMBRE	2024-01-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33515	\N	\N	\N
40008	MEMBRE	2024-01-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33587	\N	\N	\N
40009	MEMBRE	2024-01-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33588	\N	\N	\N
40013	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33590	\N	\N	\N
40014	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33591	\N	\N	\N
40131	MEMBRE	2024-01-02 00:00:00	2024-02-06 00:00:00	ACTIF	\N	\N	\N	\N	33699	\N	\N	\N
40132	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33700	\N	\N	\N
40306	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	30788	\N	\N	\N
40308	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	30780	\N	\N	\N
40704	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34163	\N	\N	\N
40836	MEMBRE	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34239	\N	\N	\N
40850	MEMBRE	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34242	\N	\N	\N
40904	MEMBRE	2024-01-24 00:00:00	2024-03-24 00:00:00	ACTIF	\N	\N	\N	\N	34247	\N	\N	\N
41009	VICPDT	2024-01-30 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	29949	\N	\N	\N
41010	VICPDT	2024-01-30 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	30008	\N	\N	\N
41090	VICPDT	2024-02-06 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	33685	\N	\N	\N
41091	VICPDT	2024-02-06 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	29847	\N	\N	\N
41092	VICPDT	2024-02-06 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	33427	\N	\N	\N
41093	VICPDT	2024-02-06 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	33429	\N	\N	\N
41250	PDT	2024-02-14 00:00:00	\N	\N	\N	\N	\N	\N	33876	\N	\N	\N
39208	MEMBRE	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33254	\N	\N	\N
39209	MEMBRE	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33255	\N	\N	\N
39266	MEMBRE	2023-12-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33310	\N	\N	\N
39343	MEMBRE	2023-12-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33326	\N	\N	\N
39344	MEMBRE	2023-12-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33327	\N	\N	\N
39352	MEMBRE	2023-12-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33335	\N	\N	\N
39353	MEMBRE	2023-12-11 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	33336	\N	\N	\N
39475	MEMBRE	2023-12-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33385	\N	\N	\N
39819	MEMBRE	2024-01-12 00:00:00	2024-02-08 00:00:00	ACTIF	\N	\N	\N	\N	33487	\N	\N	\N
39931	VICPDT	2024-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	33540	\N	\N	\N
40038	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33615	\N	\N	\N
40065	MEMBRE	2024-01-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33642	\N	\N	\N
40196	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33725	\N	\N	\N
40199	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33728	\N	\N	\N
40344	MEMBRE	2024-01-22 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33840	\N	\N	\N
40730	VICPDT	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33081	\N	\N	\N
40913	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	34250	\N	\N	\N
41218	MEMBRE	2024-02-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34343	\N	\N	\N
41285	MEMBRE	2023-12-14 00:00:00	\N	\N	\N	\N	\N	\N	34357	\N	\N	\N
41508	PDT	2024-03-21 00:00:00	\N	\N	\N	\N	\N	\N	34462	\N	\N	\N
30913	MEMBRE	2017-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26164	\N	\N	\N
31122	MEMBRE	2018-03-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26646	\N	\N	\N
31327	PDTDEL	2018-07-16 00:00:00	2020-11-03 00:00:00	ANCIEN	\N	\N	en charge des Kurdes	\N	26789	\N	\N	\N
31485	MEMBRE	2019-01-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26941	\N	\N	\N
31486	MEMBRE	2019-01-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26942	\N	\N	\N
31487	MEMBRE	2019-01-15 00:00:00	2019-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	26943	\N	\N	\N
31488	MEMBRE	2019-01-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26944	\N	\N	\N
31489	MEMBRE	2019-01-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26945	\N	\N	\N
31490	MEMBRE	2019-01-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26946	\N	\N	\N
31491	MEMBRE	2019-01-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26947	\N	\N	\N
31492	MEMBRE	2019-01-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26948	\N	\N	\N
31737	MEMBRE	2020-10-07 00:00:00	2021-01-03 00:00:00	ANCIEN	\N	\N	\N	\N	27166	\N	\N	\N
31738	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27167	\N	\N	\N
31739	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27168	\N	\N	\N
31740	MEMBRE	2020-10-07 00:00:00	2021-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	27169	\N	\N	\N
31741	MEMBRE	2020-10-07 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	27170	\N	\N	\N
31742	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27171	\N	\N	\N
31743	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27172	\N	\N	\N
31744	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27173	\N	\N	\N
31745	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27174	\N	\N	\N
31746	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27175	\N	\N	\N
31747	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27176	\N	\N	\N
31748	MEMBRE	2020-10-07 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	27177	\N	\N	\N
31749	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27178	\N	\N	\N
31750	MEMBRE	2020-10-07 00:00:00	2020-12-23 00:00:00	ANCIEN	\N	\N	\N	\N	27179	\N	\N	\N
31751	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27180	\N	\N	\N
31752	MEMBRE	2020-10-08 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	27181	\N	\N	\N
31753	MEMBRE	2020-10-08 00:00:00	2020-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	27182	\N	\N	\N
31754	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27183	\N	\N	\N
31755	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27184	\N	\N	\N
31756	MEMBRE	2020-10-07 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	27185	\N	\N	\N
31757	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27186	\N	\N	\N
31758	MEMBRE	2020-10-07 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	27187	\N	\N	\N
31759	MEMBRE	2020-10-07 00:00:00	2021-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	27188	\N	\N	\N
31760	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27189	\N	\N	\N
31761	MEMBRE	2020-10-07 00:00:00	2020-12-23 00:00:00	ANCIEN	\N	\N	\N	\N	27190	\N	\N	\N
31762	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27191	\N	\N	\N
31763	MEMBRE	2020-10-07 00:00:00	2020-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	27192	\N	\N	\N
31764	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27193	\N	\N	\N
31765	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27194	\N	\N	\N
31766	MEMBRE	2020-10-07 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	27195	\N	\N	\N
31767	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27196	\N	\N	\N
31768	MEMBRE	2020-10-07 00:00:00	2021-04-18 00:00:00	ANCIEN	\N	\N	\N	\N	27197	\N	\N	\N
31769	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27198	\N	\N	\N
31770	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27199	\N	\N	\N
31771	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27200	\N	\N	\N
31772	MEMBRE	2020-10-07 00:00:00	2021-01-21 00:00:00	ANCIEN	\N	\N	\N	\N	27201	\N	\N	\N
31773	MEMBRE	2020-10-07 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	27202	\N	\N	\N
31774	MEMBRE	2020-10-07 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	27203	\N	\N	\N
31775	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27204	\N	\N	\N
31776	MEMBRE	2020-10-07 00:00:00	2021-06-23 00:00:00	ANCIEN	\N	\N	\N	\N	27205	\N	\N	\N
31777	MEMBRE	2020-10-07 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	27206	\N	\N	\N
31778	MEMBRE	2020-10-07 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	27207	\N	\N	\N
31779	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27208	\N	\N	\N
31780	MEMBRE	2020-10-07 00:00:00	2021-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	27209	\N	\N	\N
31781	MEMBRE	2020-10-06 00:00:00	2021-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	27210	\N	\N	\N
31782	MEMBRE	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27211	\N	\N	\N
31783	MEMBRE	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27212	\N	\N	\N
31784	MEMBRE	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27213	\N	\N	\N
31785	MEMBRE	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27214	\N	\N	\N
31786	MEMBRE	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27215	\N	\N	\N
31787	MEMBRE	2020-10-08 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	27216	\N	\N	\N
31788	MEMBRE	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27217	\N	\N	\N
31789	MEMBRE	2020-10-08 00:00:00	2021-06-23 00:00:00	ANCIEN	\N	\N	\N	\N	27218	\N	\N	\N
31790	MEMBRE	2020-10-08 00:00:00	2020-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	27219	\N	\N	\N
31791	MEMBRE	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27220	\N	\N	\N
31792	MEMBRE	2020-10-08 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	27221	\N	\N	\N
31793	MEMBRE	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27222	\N	\N	\N
31794	MEMBRE	2020-10-08 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	27223	\N	\N	\N
31795	MEMBRE	2020-10-08 00:00:00	2020-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	27224	\N	\N	\N
31796	MEMBRE	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27225	\N	\N	\N
32031	MEMBRE	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27460	\N	\N	\N
32032	MEMBRE	2020-10-12 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	27461	\N	\N	\N
32033	MEMBRE	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27462	\N	\N	\N
32034	MEMBRE	2020-10-12 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	27463	\N	\N	\N
32035	MEMBRE	2020-10-12 00:00:00	2020-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	27464	\N	\N	\N
32036	MEMBRE	2020-10-12 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	27465	\N	\N	\N
32037	MEMBRE	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27466	\N	\N	\N
32038	MEMBRE	2020-10-12 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	27467	\N	\N	\N
32039	MEMBRE	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27468	\N	\N	\N
32040	MEMBRE	2020-10-12 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	27469	\N	\N	\N
32041	MEMBRE	2020-10-12 00:00:00	2021-01-03 00:00:00	ANCIEN	\N	\N	\N	\N	27470	\N	\N	\N
32042	MEMBRE	2020-10-12 00:00:00	2021-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	27471	\N	\N	\N
32043	MEMBRE	2020-10-12 00:00:00	2020-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	27472	\N	\N	\N
32044	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27473	\N	\N	\N
32045	MEMBRE	2020-10-13 00:00:00	2021-01-03 00:00:00	ANCIEN	\N	\N	\N	\N	27474	\N	\N	\N
32046	MEMBRE	2020-10-13 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	27475	\N	\N	\N
32047	MEMBRE	2020-10-13 00:00:00	2020-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	27476	\N	\N	\N
32048	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27477	\N	\N	\N
32723	MEMBRE	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28152	\N	\N	\N
32724	MEMBRE	2020-10-21 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	28153	\N	\N	\N
32725	MEMBRE	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28154	\N	\N	\N
32726	MEMBRE	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28155	\N	\N	\N
32727	MEMBRE	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28156	\N	\N	\N
32728	MEMBRE	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28157	\N	\N	\N
32729	MEMBRE	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28158	\N	\N	\N
32730	MEMBRE	2020-10-21 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	28159	\N	\N	\N
32731	MEMBRE	2020-10-21 00:00:00	2021-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	28160	\N	\N	\N
32732	MEMBRE	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28161	\N	\N	\N
32733	MEMBRE	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28162	\N	\N	\N
32734	MEMBRE	2020-10-20 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	28163	\N	\N	\N
32735	MEMBRE	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28164	\N	\N	\N
32736	MEMBRE	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28165	\N	\N	\N
32737	MEMBRE	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28166	\N	\N	\N
32738	MEMBRE	2020-10-18 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	28167	\N	\N	\N
32739	MEMBRE	2020-10-18 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	28168	\N	\N	\N
32746	MEMBRE	2020-10-20 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	28176	\N	\N	\N
32747	MEMBRE	2020-10-20 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	28177	\N	\N	\N
32754	MEMBRE	2020-10-22 00:00:00	2020-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	28187	\N	\N	\N
32959	MEMBRE	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28392	\N	\N	\N
33891	MEMBRE	2020-11-25 00:00:00	2020-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	29140	\N	\N	\N
33917	MEMBRE	2020-12-01 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	29165	\N	\N	\N
34517	MEMBRE	2020-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29381	\N	\N	\N
34518	MEMBRE	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29382	\N	\N	\N
34520	MEMBRE	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29384	\N	\N	\N
34624	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29483	\N	\N	\N
35211	MEMBRE	2020-10-01 00:00:00	2021-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	29935	\N	\N	\N
35217	MEMBRE	2021-01-20 00:00:00	2021-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	29941	\N	\N	\N
35544	MEMBRE	2020-10-01 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	30079	\N	\N	\N
35340	MEMBRE	2021-01-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30003	\N	\N	\N
35435	MEMBRE	2021-01-20 00:00:00	2021-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	30052	\N	\N	\N
35548	VICPDT	2021-01-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	30079	\N	\N	\N
35825	MEMBRE	2021-02-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30201	\N	\N	\N
35847	VICPDT	2021-02-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29885	\N	\N	\N
35906	MEMBRE	2021-03-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	30221	\N	\N	\N
35936	MEMBRE	2021-03-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30240	\N	\N	\N
35973	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30271	\N	\N	\N
35974	MEMBRE	2020-10-01 00:00:00	2021-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	30272	\N	\N	\N
36046	MEMBRE	2021-04-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30327	\N	\N	\N
36102	MEMBRE	2021-07-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	30375	\N	\N	\N
36103	MEMBRE	2021-07-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	30376	\N	\N	\N
36263	MEMBRE	2021-11-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30507	\N	\N	\N
36388	MEMBRE	2022-04-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30607	\N	\N	\N
36389	MEMBRE	2022-04-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30608	\N	\N	\N
36422	MEMBRE	2022-06-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30639	\N	\N	\N
36449	MEMBRE	2022-03-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30666	\N	\N	\N
36523	MEMBRE	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30740	\N	\N	\N
38519	MEMBRE	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32714	\N	\N	\N
38520	MEMBRE	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32715	\N	\N	\N
38674	MEMBRE	2023-11-13 00:00:00	2023-11-13 00:00:00	ANCIEN	\N	\N	\N	\N	32869	\N	\N	\N
38675	MEMBRE	2023-11-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32870	\N	\N	\N
38676	MEMBRE	2023-11-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32871	\N	\N	\N
38702	MEMBRE	2023-11-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32897	\N	\N	\N
38870	MEMBRE	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33065	\N	\N	\N
39153	MEMBRE	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33198	\N	\N	\N
39154	MEMBRE	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33199	\N	\N	\N
39155	MEMBRE	2023-11-29 00:00:00	2024-02-19 00:00:00	ACTIF	\N	\N	\N	\N	33200	\N	\N	\N
39156	MEMBRE	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33201	\N	\N	\N
39161	MEMBRE	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33206	\N	\N	\N
39852	MEMBRE	2023-10-01 00:00:00	2024-01-30 00:00:00	ACTIF	\N	\N	\N	\N	33520	\N	\N	\N
40025	MEMBRE	2024-01-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33602	\N	\N	\N
40058	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33635	\N	\N	\N
40558	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34031	\N	\N	\N
40564	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34037	\N	\N	\N
40740	VICPDT	2024-01-23 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	\N	29892	\N	\N	\N
40756	MEMBRE	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34192	\N	\N	\N
40757	MEMBRE	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34193	\N	\N	\N
40778	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34209	\N	\N	\N
40786	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34217	\N	\N	\N
40832	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	34235	\N	\N	\N
41164	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34313	\N	\N	\N
41189	VICPDT	2024-02-07 00:00:00	\N	\N	\N	\N	\N	\N	34323	\N	\N	\N
41191	VICPDT	2024-02-07 00:00:00	\N	\N	\N	\N	\N	\N	34324	\N	\N	\N
41193	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34326	\N	\N	\N
41194	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34327	\N	\N	\N
41195	MEMBRE	2023-12-14 00:00:00	\N	\N	\N	\N	\N	\N	34328	\N	\N	\N
41236	VICPDT	2024-02-14 00:00:00	\N	\N	\N	\N	\N	\N	33940	\N	\N	\N
41266	SECRET	2024-02-14 00:00:00	\N	\N	\N	\N	\N	\N	33887	\N	\N	\N
41269	MEMBRE	2023-10-01 00:00:00	2024-02-06 00:00:00	\N	\N	\N	\N	\N	34348	\N	\N	\N
30612	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26333	\N	\N	\N
30614	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26334	\N	\N	\N
30660	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26361	\N	\N	\N
30663	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26364	\N	\N	\N
30664	MEMBRE	2017-10-01 00:00:00	2018-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	26365	\N	\N	\N
30666	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26367	\N	\N	\N
30668	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26369	\N	\N	\N
30669	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26370	\N	\N	\N
30670	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26371	\N	\N	\N
30671	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26372	\N	\N	\N
30672	MEMBRE	2017-10-01 00:00:00	2018-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	26373	\N	\N	\N
30820	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26491	\N	\N	\N
31183	VICPDT	2018-03-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	26624	\N	\N	\N
31238	MEMBRE	2018-03-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26732	\N	2018-03-30 15:01:24	\N
31261	MEMBRE	2018-04-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26746	\N	2018-04-11 15:05:52	\N
31306	MEMBRE	2018-05-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26775	\N	2018-06-06 16:33:04	\N
31408	MEMBRE	2018-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26869	\N	\N	\N
31409	MEMBRE	2018-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26870	\N	\N	\N
31410	MEMBRE	2018-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26871	\N	\N	\N
31411	MEMBRE	2018-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26872	\N	\N	\N
31626	VICPDT	2019-02-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	26906	\N	\N	\N
31632	MEMBRE	2019-12-02 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27064	\N	\N	\N
31633	MEMBRE	2019-11-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27065	\N	\N	\N
32392	MEMBRE	2020-10-15 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	27821	\N	\N	\N
32393	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27822	\N	\N	\N
34615	MEMBRE	2020-12-15 00:00:00	2021-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	29476	\N	\N	\N
34679	MEMBRE	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29519	\N	\N	\N
34778	MEMBRE	2020-12-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29585	\N	\N	\N
34916	MEMBRE	2021-01-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	29681	\N	\N	\N
35084	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29808	\N	\N	\N
35085	MEMBRE	2020-10-01 00:00:00	2021-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	29809	\N	\N	\N
35086	MEMBRE	2020-10-01 00:00:00	2021-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	29810	\N	\N	\N
35218	MEMBRE	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29942	\N	\N	\N
35762	VICPDT	2021-02-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	30156	\N	\N	\N
35787	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30181	\N	\N	\N
35801	PDT	2021-02-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	30166	\N	\N	\N
35802	VICPDT	2021-02-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30175	\N	\N	\N
35958	VICPDT	2021-03-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30259	\N	\N	\N
35959	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30260	\N	\N	\N
36171	MEMBRE	2021-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27684	\N	\N	\N
36172	PDT	2021-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28675	\N	\N	\N
36173	VICPDT	2021-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27625	\N	\N	\N
36174	PDTDEL	2021-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	Singapour	\N	27319	\N	\N	\N
36175	PDT	2021-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28721	\N	\N	\N
36176	MEMBRE	2021-10-15 00:00:00	2023-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	28676	\N	\N	\N
36177	PDT	2021-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28153	\N	\N	\N
36178	VICPDT	2021-10-15 00:00:00	2023-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	29198	\N	\N	\N
36547	MEMBRE	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30764	\N	\N	\N
36549	MEMBRE	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30766	\N	\N	\N
36881	MEMBRE	2023-10-09 00:00:00	2024-04-02 00:00:00	ACTIF	\N	\N	\N	\N	31071	\N	\N	\N
36882	MEMBRE	2023-10-09 00:00:00	2024-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	31072	\N	\N	\N
36883	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31073	\N	\N	\N
36884	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31074	\N	\N	\N
36904	MEMBRE	2023-10-09 00:00:00	2024-01-04 00:00:00	ANCIEN	\N	\N	\N	\N	31094	\N	\N	\N
36905	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31095	\N	\N	\N
36906	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31096	\N	\N	\N
36907	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31097	\N	\N	\N
36908	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31098	\N	\N	\N
36909	MEMBRE	2023-10-09 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	31099	\N	\N	\N
37455	MEMBRE	2023-10-12 00:00:00	2024-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	31647	\N	\N	\N
37746	MEMBRE	2023-10-17 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	31938	\N	\N	\N
37747	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31939	\N	\N	\N
37748	MEMBRE	2023-10-17 00:00:00	2023-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	31940	\N	\N	\N
37749	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31941	\N	\N	\N
37750	MEMBRE	2023-10-17 00:00:00	2024-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	31942	\N	\N	\N
37751	MEMBRE	2023-10-17 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	31943	\N	\N	\N
37752	MEMBRE	2023-10-17 00:00:00	2023-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	31944	\N	\N	\N
37753	MEMBRE	2023-10-17 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	31945	\N	\N	\N
37754	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31946	\N	\N	\N
37755	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31947	\N	\N	\N
37790	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31982	\N	\N	\N
37791	MEMBRE	2023-10-17 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	31983	\N	\N	\N
37792	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31984	\N	\N	\N
39171	PDTDEL	2023-11-30 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour les îles Fidji	\N	33216	\N	\N	\N
39764	PDT	2024-01-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33234	\N	\N	\N
39765	VICPDT	2024-01-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32786	\N	\N	\N
39766	VICPDT	2024-01-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32505	\N	\N	\N
39767	VICPDT	2024-01-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33010	\N	\N	\N
39768	VICPDT	2024-01-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31620	\N	\N	\N
39769	VICPDT	2024-01-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31552	\N	\N	\N
39770	VICPDT	2024-01-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32647	\N	\N	\N
39771	VICPDT	2024-01-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31998	\N	\N	\N
39772	VICPDT	2024-01-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31755	\N	\N	\N
39775	MEMBRE	2024-01-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30997	\N	\N	\N
39951	PDT	2024-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	33550	\N	\N	\N
39983	MEMBRE	2024-01-17 00:00:00	2024-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	30151	\N	\N	\N
39984	MEMBRE	2024-01-17 00:00:00	2024-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	29892	\N	\N	\N
39985	MEMBRE	2024-01-17 00:00:00	2024-01-22 00:00:00	ACTIF	\N	\N	\N	\N	29960	\N	\N	\N
39986	MEMBRE	2024-01-17 00:00:00	2024-01-22 00:00:00	ACTIF	\N	\N	\N	\N	29896	\N	\N	\N
39987	MEMBRE	2024-01-17 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	\N	29900	\N	\N	\N
39990	MEMBRE	2024-01-17 00:00:00	2024-01-22 00:00:00	ACTIF	\N	\N	\N	\N	29937	\N	\N	\N
39991	MEMBRE	2024-01-17 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	\N	30576	\N	\N	\N
39994	MEMBRE	2024-01-17 00:00:00	2024-01-29 00:00:00	ACTIF	\N	\N	\N	\N	29818	\N	\N	\N
40488	MEMBRE	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	\N	33961	\N	\N	\N
40628	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34101	\N	\N	\N
41014	VICPDT	2024-01-30 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	30090	\N	\N	\N
41015	VICPDT	2024-01-30 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	33410	\N	\N	\N
41251	VICPDT	2024-02-14 00:00:00	\N	\N	\N	\N	\N	\N	33852	\N	\N	\N
41253	VICPDT	2024-02-14 00:00:00	\N	\N	\N	\N	\N	\N	33858	\N	\N	\N
41254	VICPDT	2024-02-14 00:00:00	\N	\N	\N	\N	\N	\N	33860	\N	\N	\N
41256	VICPDT	2024-02-14 00:00:00	\N	\N	\N	\N	\N	\N	33871	\N	\N	\N
41257	VICPDT	2024-02-14 00:00:00	\N	\N	\N	\N	\N	\N	33884	\N	\N	\N
41258	VICPDT	2024-02-14 00:00:00	\N	\N	\N	\N	\N	\N	33893	\N	\N	\N
41259	VICPDT	2024-02-14 00:00:00	\N	\N	\N	\N	\N	\N	33904	\N	\N	\N
41278	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34351	\N	\N	\N
41368	MEMBRE	2023-12-14 00:00:00	\N	\N	\N	\N	\N	\N	34370	\N	\N	\N
41372	MEMBRE	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	34374	\N	\N	\N
41375	MEMBRE	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	34377	\N	\N	\N
41376	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34378	\N	\N	\N
41380	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34382	\N	\N	\N
41381	MEMBRE	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	34383	\N	\N	\N
41428	VICPDT	2024-02-14 00:00:00	\N	\N	\N	\N	\N	\N	34421	\N	\N	\N
38294	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32489	\N	\N	\N
38295	MEMBRE	2023-10-31 00:00:00	2024-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	32490	\N	\N	\N
38516	MEMBRE	2023-11-03 00:00:00	2023-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	32711	\N	\N	\N
38517	MEMBRE	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32712	\N	\N	\N
38518	MEMBRE	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32713	\N	\N	\N
38918	MEMBRE	2023-11-21 00:00:00	2023-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	33105	\N	\N	\N
39858	MEMBRE	2024-01-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33526	\N	\N	\N
40406	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33879	\N	\N	\N
40411	MEMBRE	2023-12-14 00:00:00	2024-02-14 00:00:00	ACTIF	\N	\N	\N	\N	33884	\N	\N	\N
40412	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33885	\N	\N	\N
40413	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33886	\N	\N	\N
40415	MEMBRE	2023-10-01 00:00:00	2024-02-12 00:00:00	ACTIF	\N	\N	\N	\N	33888	\N	\N	\N
40416	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33889	\N	\N	\N
40418	MEMBRE	2023-10-01 00:00:00	2024-02-12 00:00:00	ACTIF	\N	\N	\N	\N	33891	\N	\N	\N
40419	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33892	\N	\N	\N
40420	MEMBRE	2023-12-14 00:00:00	2024-02-14 00:00:00	ACTIF	\N	\N	\N	\N	33893	\N	\N	\N
40421	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33894	\N	\N	\N
40426	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33899	\N	\N	\N
40427	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33900	\N	\N	\N
40701	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34160	\N	\N	\N
40712	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34171	\N	\N	\N
40713	MEMBRE	2023-12-14 00:00:00	2024-02-06 00:00:00	ACTIF	\N	\N	\N	\N	34172	\N	\N	\N
40715	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34174	\N	\N	\N
40716	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34175	\N	\N	\N
40718	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34177	\N	\N	\N
40729	MEMBRE	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34187	\N	\N	\N
40809	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31796	\N	\N	\N
40810	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32231	\N	\N	\N
40811	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32707	\N	\N	\N
40812	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30935	\N	\N	\N
40813	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32941	\N	\N	\N
40814	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33002	\N	\N	\N
40815	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32011	\N	\N	\N
40816	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31112	\N	\N	\N
40817	SECRET	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31924	\N	\N	\N
40824	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32741	\N	\N	\N
40831	MEMBRE	2024-01-24 00:00:00	2024-02-07 00:00:00	ACTIF	\N	\N	\N	\N	34234	\N	\N	\N
41185	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34320	\N	\N	\N
41212	PDT	2024-02-07 00:00:00	\N	\N	\N	\N	\N	\N	34159	\N	\N	\N
41270	VICPDT	2024-02-07 00:00:00	\N	\N	\N	\N	\N	\N	34348	\N	\N	\N
41292	VICPDT	2024-02-27 00:00:00	\N	\N	\N	\N	\N	\N	34336	\N	\N	\N
41293	VICPDT	2024-02-27 00:00:00	\N	\N	\N	\N	\N	\N	33917	\N	\N	\N
30956	VICPDT	2018-02-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	26373	\N	\N	\N
30981	MEMBRE	2017-10-01 00:00:00	2018-03-07 00:00:00	ANCIEN	\N	\N	\N	\N	26575	\N	\N	\N
30982	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26576	\N	\N	\N
30986	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26580	\N	\N	\N
30988	MEMBRE	2017-10-01 00:00:00	2018-03-07 00:00:00	ANCIEN	\N	\N	\N	\N	26582	\N	\N	\N
30992	MEMBRE	2017-10-01 00:00:00	2018-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	26586	\N	\N	\N
30993	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26587	\N	\N	\N
31235	MEMBRE	2017-12-07 00:00:00	2018-08-06 00:00:00	ANCIEN	\N	\N	\N	\N	26729	\N	\N	\N
31452	MEMBRE	2018-11-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26913	\N	\N	\N
31453	MEMBRE	2018-11-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26914	\N	\N	\N
31498	MEMBRE	2017-10-01 00:00:00	2020-08-06 00:00:00	ANCIEN	\N	\N	\N	\N	26954	\N	\N	\N
31596	PDT	2019-09-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	26109	\N	\N	\N
31607	MEMBRE	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27042	\N	\N	\N
33743	MEMBRE	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29040	\N	\N	\N
33744	MEMBRE	2020-11-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29041	\N	\N	\N
33745	PDTDEL	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour la Serbie	\N	28600	\N	\N	\N
33746	PDTDEL	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour le Luxembourg	\N	27573	\N	\N	\N
33747	PDTDEL	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour le Suriname	\N	27511	\N	\N	\N
33748	PDTDEL	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour la Guyana	\N	27607	\N	\N	\N
33749	PDTDEL	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour le Laos	\N	27608	\N	\N	\N
33750	PDTDEL	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour le Danemark	\N	28280	\N	\N	\N
33751	PDTDEL	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour l'Islande	\N	28986	\N	\N	\N
33752	PDTDEL	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour la Norvège	\N	27690	\N	\N	\N
33753	PDTDEL	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour la Suède	\N	28508	\N	\N	\N
33754	PDTDEL	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour l'île Maurice	\N	27111	\N	\N	\N
33755	PDTDEL	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour le Kénya	\N	27845	\N	\N	\N
33756	PDTDEL	2020-11-23 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	pour le Mozambique	\N	27182	\N	\N	\N
33757	PDTDEL	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour l'Équateur	\N	28360	\N	\N	\N
33758	PDTDEL	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour le Pérou	\N	27501	\N	\N	\N
33759	PDTDEL	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour la Bolivie	\N	28136	\N	\N	\N
33760	PDTDEL	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour Djibouti	\N	27507	\N	\N	\N
33761	PDTDEL	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour l'Erythrée	\N	29005	\N	\N	\N
33762	PDTDEL	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour le Soudan	\N	27420	\N	\N	\N
33763	PDTDEL	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour le Chili	\N	28574	\N	\N	\N
33764	PDTDEL	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour le Paraguay	\N	28124	\N	\N	\N
33765	PDTDEL	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour l'Uruguay	\N	27563	\N	\N	\N
33766	PDTDEL	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour le Koweït	\N	27749	\N	\N	\N
33767	PDTDEL	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour le Sultanat d'Oman	\N	28336	\N	\N	\N
33768	PDTDEL	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour la Papouasie-Nouvelle Guinée	\N	27554	\N	\N	\N
33769	PDTDEL	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour Vanuatu	\N	28870	\N	\N	\N
33770	MEMBRE	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29042	\N	\N	\N
33772	MEMBRE	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29044	\N	\N	\N
33773	PDTDEL	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour le Nigeria	\N	29045	\N	\N	\N
34004	MEMBRE	2020-12-08 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	29181	\N	\N	\N
34005	MEMBRE	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29182	\N	\N	\N
34007	MEMBRE	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29184	\N	\N	\N
34049	PDTDEL	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour l'Angola	\N	29199	\N	\N	\N
34050	VICPDT	2020-12-09 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	28238	\N	\N	\N
34051	VICPDT	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27402	\N	\N	\N
34052	VICPDT	2020-12-09 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29165	\N	\N	\N
34053	VICPDT	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29012	\N	\N	\N
34054	VICPDT	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28996	\N	\N	\N
34055	VICPDT	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29004	\N	\N	\N
34056	SECRET	2020-12-09 00:00:00	2022-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	29180	\N	\N	\N
34057	SECRET	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29091	\N	\N	\N
34639	MEMBRE	2020-12-15 00:00:00	2021-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	29497	\N	\N	\N
34640	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29498	\N	\N	\N
34680	MEMBRE	2020-12-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	29520	\N	\N	\N
34777	MEMBRE	2020-12-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29584	\N	\N	\N
34902	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29667	\N	\N	\N
34932	VICPDT	2021-01-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28264	\N	\N	\N
34938	MEMBRE	2021-01-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29702	\N	\N	\N
34939	MEMBRE	2021-01-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29703	\N	\N	\N
34949	VICPDT	2021-01-13 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	27449	\N	\N	\N
34950	VICPDT	2021-01-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27409	\N	\N	\N
34951	VICPDT	2021-01-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27664	\N	\N	\N
34952	VICPDT	2021-01-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27434	\N	\N	\N
34953	SECRET	2021-01-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27231	\N	\N	\N
34954	SECRET	2021-01-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28024	\N	\N	\N
34955	SECRET	2021-01-13 00:00:00	2023-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	27527	\N	\N	\N
34956	SECRET	2021-01-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29678	\N	\N	\N
34958	MEMBRE	2021-01-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29714	\N	\N	\N
34972	MEMBRE	2021-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29728	\N	\N	\N
35035	MEMBRE	2021-01-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	29767	\N	\N	\N
35039	MEMBRE	2021-01-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	29768	\N	\N	\N
35067	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29791	\N	\N	\N
35153	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29877	\N	\N	\N
35421	MEMBRE	2021-01-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30045	\N	\N	\N
35423	VICPDT	2021-01-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	29262	\N	\N	\N
35431	MEMBRE	2021-01-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30048	\N	\N	\N
35461	VICPDT	2021-01-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	29677	\N	\N	\N
35501	VICPDT	2021-01-11 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29680	\N	\N	\N
35508	VICPDT	2021-01-20 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	30052	\N	\N	\N
35561	MEMBRE	2021-01-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	30081	\N	\N	\N
35566	MEMBRE	2021-01-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	30086	\N	\N	\N
35631	MEMBRE	2021-02-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	30116	\N	\N	\N
35798	VICPDT	2021-02-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30173	\N	\N	\N
35799	VICPDT	2021-02-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30174	\N	\N	\N
35894	MEMBRE	2021-03-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30218	\N	\N	\N
35933	PDT	2021-03-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	29497	\N	\N	\N
35934	VICPDT	2021-03-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	30068	\N	\N	\N
35935	VICPDT	2021-03-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	29558	\N	\N	\N
36074	MEMBRE	2021-06-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	30355	\N	\N	\N
36075	MEMBRE	2021-06-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	30356	\N	\N	\N
36076	MEMBRE	2021-06-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	30357	\N	\N	\N
36082	MEMBRE	2021-06-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30363	\N	\N	\N
36083	MEMBRE	2021-06-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	30364	\N	\N	\N
36160	MEMBRE	2021-10-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30422	\N	\N	\N
36161	MEMBRE	2021-10-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30423	\N	\N	\N
36162	MEMBRE	2021-10-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30424	\N	\N	\N
36163	MEMBRE	2021-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30425	\N	\N	\N
36164	MEMBRE	2021-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30426	\N	\N	\N
36220	MEMBRE	2021-10-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	30465	\N	\N	\N
36221	MEMBRE	2021-10-23 00:00:00	2021-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	30466	\N	\N	\N
36223	MEMBRE	2021-11-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30468	\N	\N	\N
36248	MEMBRE	2021-12-09 00:00:00	2023-11-15 00:00:00	ANCIEN	\N	\N	\N	\N	30492	\N	\N	\N
36261	MEMBRE	2022-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30505	\N	\N	\N
36291	MEMBRE	2022-02-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30525	\N	\N	\N
36304	MEMBRE	2022-03-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30532	\N	\N	\N
36530	MEMBRE	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30747	\N	\N	\N
36537	MEMBRE	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30754	\N	\N	\N
36538	MEMBRE	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30755	\N	\N	\N
36539	MEMBRE	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30756	\N	\N	\N
36546	MEMBRE	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30763	\N	\N	\N
36561	MEMBRE	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30778	\N	\N	\N
36574	MEMBRE	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30791	\N	\N	\N
36647	MEMBRE	2023-10-01 00:00:00	2024-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	30845	\N	\N	\N
36650	MEMBRE	2023-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30848	\N	\N	\N
36651	MEMBRE	2023-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30849	\N	\N	\N
36655	MEMBRE	2023-07-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30852	\N	\N	\N
36733	MEMBRE	2023-10-06 00:00:00	2024-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	30923	\N	\N	\N
36949	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31139	\N	\N	\N
36950	MEMBRE	2023-10-10 00:00:00	2024-02-26 00:00:00	ACTIF	\N	\N	\N	\N	31140	\N	\N	\N
36951	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31141	\N	\N	\N
36952	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31142	\N	\N	\N
36953	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31143	\N	\N	\N
36954	MEMBRE	2023-10-10 00:00:00	2024-01-31 00:00:00	ACTIF	\N	\N	\N	\N	31144	\N	\N	\N
37546	MEMBRE	2023-10-13 00:00:00	2024-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	31738	\N	\N	\N
37625	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31817	\N	\N	\N
37626	MEMBRE	2023-10-17 00:00:00	2023-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	31818	\N	\N	\N
37627	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31819	\N	\N	\N
39229	MEMBRE	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33273	\N	\N	\N
39230	MEMBRE	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33274	\N	\N	\N
39838	MEMBRE	2024-01-15 00:00:00	2024-02-13 00:00:00	ACTIF	\N	\N	\N	\N	33506	\N	\N	\N
39961	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33560	\N	\N	\N
40024	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33601	\N	\N	\N
41041	MEMBRE	2024-01-02 00:00:00	\N	\N	\N	\N	\N	\N	34275	\N	\N	\N
41056	MEMBRE	2024-01-31 00:00:00	2024-03-24 00:00:00	ACTIF	\N	\N	\N	\N	34280	\N	\N	\N
41455	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34443	\N	\N	\N
41456	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34444	\N	\N	\N
41459	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34447	\N	\N	\N
41460	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34448	\N	\N	\N
41477	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34465	\N	\N	\N
30673	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26374	\N	\N	\N
30674	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26375	\N	\N	\N
30809	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26480	\N	\N	\N
30974	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26568	\N	\N	\N
31187	VICPDT	2018-03-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	26460	\N	\N	\N
31268	MEMBRE	2018-04-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26753	\N	2018-04-20 10:20:58	\N
31604	MEMBRE	2019-09-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	27039	\N	\N	\N
31623	MEMBRE	2019-11-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	27056	\N	\N	\N
32049	MEMBRE	2020-10-09 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	27478	\N	\N	\N
32050	MEMBRE	2020-10-09 00:00:00	2020-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	27479	\N	\N	\N
32051	MEMBRE	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27480	\N	\N	\N
32052	MEMBRE	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27481	\N	\N	\N
32053	MEMBRE	2020-10-09 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	27482	\N	\N	\N
32054	MEMBRE	2020-10-09 00:00:00	2022-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	27483	\N	\N	\N
32055	MEMBRE	2020-10-09 00:00:00	2020-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	27484	\N	\N	\N
32056	MEMBRE	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27485	\N	\N	\N
32057	MEMBRE	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27486	\N	\N	\N
32058	MEMBRE	2020-10-09 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	27487	\N	\N	\N
34506	MEMBRE	2020-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29370	\N	\N	\N
34526	MEMBRE	2020-12-17 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	29390	\N	\N	\N
34557	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29421	\N	\N	\N
34655	VICPDT	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29318	\N	\N	\N
34705	MEMBRE	2020-12-17 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	29545	\N	\N	\N
34901	MEMBRE	2021-01-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	29666	\N	\N	\N
35346	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30009	\N	\N	\N
35447	MEMBRE	2021-01-27 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	30059	\N	\N	\N
35980	MEMBRE	2021-03-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30277	\N	\N	\N
36043	MEMBRE	2021-04-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	30326	\N	\N	\N
36047	MEMBRE	2021-04-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30328	\N	\N	\N
36105	MEMBRE	2021-07-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	30378	\N	\N	\N
36106	MEMBRE	2021-07-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	30379	\N	\N	\N
36107	MEMBRE	2021-07-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	30380	\N	\N	\N
36125	MEMBRE	2021-09-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30387	\N	\N	\N
36126	MEMBRE	2021-09-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30388	\N	\N	\N
36127	MEMBRE	2021-09-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30389	\N	\N	\N
36128	MEMBRE	2021-09-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30390	\N	\N	\N
36179	MEMBRE	2021-10-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	30431	\N	\N	\N
36214	MEMBRE	2021-10-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	30460	\N	\N	\N
36326	MEMBRE	2022-03-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30553	\N	\N	\N
36334	MEMBRE	2022-03-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30561	\N	\N	\N
36380	VICPDT	2022-04-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30587	\N	\N	\N
36381	VICPDT	2022-04-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30569	\N	\N	\N
36382	VICPDT	2022-04-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30586	\N	\N	\N
36383	VICPDT	2022-04-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30524	\N	\N	\N
36384	VICPDT	2022-04-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30570	\N	\N	\N
36385	VICPDT	2022-04-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30591	\N	\N	\N
36386	SECRET	2022-04-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30600	\N	\N	\N
36438	MEMBRE	2022-07-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30655	\N	\N	\N
36439	MEMBRE	2022-07-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30656	\N	\N	\N
36551	MEMBRE	2023-01-01 00:00:00	2023-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30768	\N	\N	\N
36638	MEMBRE	2023-05-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30836	\N	\N	\N
37826	MEMBRE	2023-10-18 00:00:00	2024-01-29 00:00:00	ACTIF	\N	\N	\N	\N	32018	\N	\N	\N
37832	MEMBRE	2023-10-18 00:00:00	2023-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	32024	\N	\N	\N
37833	MEMBRE	2023-10-18 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	32025	\N	\N	\N
38845	MEMBRE	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33040	\N	\N	\N
38849	MEMBRE	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33044	\N	\N	\N
38850	MEMBRE	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33045	\N	\N	\N
39477	MEMBRE	2023-12-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33386	\N	\N	\N
39493	PDTDEL	2023-12-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour la Bosnie-Herzégovine	\N	33387	\N	\N	\N
39600	MEMBRE	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33396	\N	\N	\N
39601	MEMBRE	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33397	\N	\N	\N
39602	MEMBRE	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33398	\N	\N	\N
39683	MEMBRE	2023-12-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	30011	\N	\N	\N
39785	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33464	\N	\N	\N
40267	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33796	\N	\N	\N
40397	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33870	\N	\N	\N
40398	MEMBRE	2023-12-14 00:00:00	2024-02-14 00:00:00	ACTIF	\N	\N	\N	\N	33871	\N	\N	\N
40399	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33872	\N	\N	\N
40400	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33873	\N	\N	\N
40401	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33874	\N	\N	\N
41210	MEMBRE	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	34336	\N	\N	\N
38533	MEMBRE	2023-11-03 00:00:00	2023-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	32728	\N	\N	\N
38534	MEMBRE	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32729	\N	\N	\N
38535	MEMBRE	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32730	\N	\N	\N
38536	MEMBRE	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32731	\N	\N	\N
38537	MEMBRE	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32732	\N	\N	\N
38538	MEMBRE	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32733	\N	\N	\N
38664	MEMBRE	2023-11-10 00:00:00	2024-01-25 00:00:00	ACTIF	\N	\N	\N	\N	32859	\N	\N	\N
39189	MEMBRE	2023-12-01 00:00:00	2024-01-04 00:00:00	ANCIEN	\N	\N	\N	\N	33234	\N	\N	\N
39698	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33437	\N	\N	\N
40026	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33603	\N	\N	\N
40077	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33654	\N	\N	\N
40080	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33657	\N	\N	\N
40092	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33669	\N	\N	\N
40438	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33911	\N	\N	\N
40440	MEMBRE	2023-10-01 00:00:00	2024-02-13 00:00:00	ACTIF	\N	\N	\N	\N	33913	\N	\N	\N
40607	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34080	\N	\N	\N
40610	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34083	\N	\N	\N
40616	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34089	\N	\N	\N
40623	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34096	\N	\N	\N
40630	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34103	\N	\N	\N
40631	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34104	\N	\N	\N
40632	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34105	\N	\N	\N
40639	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34112	\N	\N	\N
40645	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34118	\N	\N	\N
40772	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34208	\N	\N	\N
41087	MEMBRE	2023-10-01 00:00:00	2024-02-27 00:00:00	\N	\N	\N	\N	\N	34296	\N	\N	\N
41089	MEMBRE	2024-02-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34298	\N	\N	\N
41169	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34318	\N	\N	\N
41418	VICPDT	2024-02-14 00:00:00	\N	\N	\N	\N	\N	\N	34415	\N	\N	\N
41478	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34466	\N	\N	\N
41495	MEMBRE	2024-03-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34483	\N	\N	\N
41510	VICPDT	2024-02-14 00:00:00	\N	\N	\N	\N	\N	\N	34420	\N	\N	\N
41515	VICPDT	2024-03-25 00:00:00	\N	\N	\N	\N	\N	\N	34445	\N	\N	\N
41520	VICPDT	2024-03-25 00:00:00	\N	\N	\N	\N	\N	\N	34464	\N	\N	\N
41531	MEMBRE	2024-03-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34493	\N	\N	\N
31205	VICPDT	2018-03-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26597	\N	2018-03-16 14:48:09	\N
31206	VICPDT	2018-03-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26250	\N	2018-03-16 14:48:15	\N
31207	VICPDT	2018-03-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26612	\N	2018-03-16 14:48:25	\N
31208	VICPDT	2018-03-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26704	\N	2018-03-16 14:48:33	\N
31209	VICPDT	2018-03-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26645	\N	2018-03-16 14:48:41	\N
31210	SECRET	2018-03-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26545	\N	2018-03-16 14:49:12	\N
31211	SECRET	2018-03-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26517	\N	2018-03-16 14:49:33	\N
31397	MEMBRE	2018-10-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26858	\N	\N	\N
31398	MEMBRE	2018-10-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26859	\N	\N	\N
31399	MEMBRE	2018-10-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26860	\N	\N	\N
31400	MEMBRE	2018-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26861	\N	\N	\N
31401	MEMBRE	2018-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26862	\N	\N	\N
31459	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26920	\N	\N	\N
31627	MEMBRE	2019-12-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	27059	\N	\N	\N
32519	MEMBRE	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27948	\N	\N	\N
32520	MEMBRE	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27949	\N	\N	\N
32521	MEMBRE	2020-10-19 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	27950	\N	\N	\N
32522	MEMBRE	2020-10-14 00:00:00	2021-01-03 00:00:00	ANCIEN	\N	\N	\N	\N	27951	\N	\N	\N
32767	MEMBRE	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28200	\N	\N	\N
32768	MEMBRE	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28201	\N	\N	\N
32769	MEMBRE	2020-10-12 00:00:00	2020-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	28202	\N	\N	\N
32770	MEMBRE	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28203	\N	\N	\N
32771	MEMBRE	2020-10-12 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	28204	\N	\N	\N
33524	MEMBRE	2020-11-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28946	\N	\N	\N
33871	MEMBRE	2020-11-26 00:00:00	2021-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	29122	\N	\N	\N
33912	MEMBRE	2020-11-19 00:00:00	2020-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	29161	\N	\N	\N
33913	PDT	2020-12-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29161	\N	\N	\N
34898	MEMBRE	2021-12-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	29663	\N	\N	\N
34923	MEMBRE	2021-01-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29688	\N	\N	\N
34924	MEMBRE	2021-01-05 00:00:00	2021-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	29689	\N	\N	\N
34925	MEMBRE	2021-01-05 00:00:00	2021-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	29690	\N	\N	\N
34957	MEMBRE	2020-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29713	\N	\N	\N
35001	MEMBRE	2021-01-12 00:00:00	2021-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	29749	\N	\N	\N
35002	MEMBRE	2021-01-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29750	\N	\N	\N
35003	MEMBRE	2021-01-12 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	29751	\N	\N	\N
35005	MEMBRE	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29753	\N	\N	\N
35006	MEMBRE	2021-01-12 00:00:00	2021-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	29754	\N	\N	\N
35284	PDT	2021-01-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29478	\N	\N	\N
35469	VICPDT	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29418	\N	\N	\N
35470	VICPDT	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29743	\N	\N	\N
35502	MEMBRE	2021-01-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	30067	\N	\N	\N
35987	MEMBRE	2021-03-25 00:00:00	2021-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	30284	\N	\N	\N
35988	MEMBRE	2021-03-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	30285	\N	\N	\N
35991	MEMBRE	2021-03-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	30288	\N	\N	\N
35992	MEMBRE	2021-03-25 00:00:00	2021-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	30289	\N	\N	\N
36219	MEMBRE	2021-11-15 00:00:00	2021-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	30464	\N	\N	\N
36268	VICPDT	2021-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	30466	\N	\N	\N
36269	SECRET	2021-12-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30127	\N	\N	\N
36792	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30982	\N	\N	\N
36793	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30983	\N	\N	\N
36794	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30984	\N	\N	\N
36795	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30985	\N	\N	\N
36796	MEMBRE	2023-10-09 00:00:00	2024-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	30986	\N	\N	\N
36797	MEMBRE	2023-10-09 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	30987	\N	\N	\N
36798	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30988	\N	\N	\N
36799	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30989	\N	\N	\N
37243	MEMBRE	2023-10-11 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	31435	\N	\N	\N
37244	MEMBRE	2023-10-11 00:00:00	2024-01-29 00:00:00	ACTIF	\N	\N	\N	\N	31436	\N	\N	\N
37245	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31437	\N	\N	\N
37246	MEMBRE	2023-10-11 00:00:00	2023-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	31438	\N	\N	\N
37259	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31451	\N	\N	\N
37365	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31557	\N	\N	\N
37366	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31558	\N	\N	\N
37456	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31648	\N	\N	\N
37457	MEMBRE	2023-10-13 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	31649	\N	\N	\N
37458	MEMBRE	2023-10-13 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	31650	\N	\N	\N
37459	MEMBRE	2023-10-13 00:00:00	2024-01-28 00:00:00	ACTIF	\N	\N	\N	\N	31651	\N	\N	\N
37460	MEMBRE	2023-10-13 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	31652	\N	\N	\N
37461	MEMBRE	2023-10-13 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	31653	\N	\N	\N
37462	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31654	\N	\N	\N
37463	MEMBRE	2023-10-13 00:00:00	2024-02-27 00:00:00	ACTIF	\N	\N	\N	\N	31655	\N	\N	\N
37464	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31656	\N	\N	\N
37628	MEMBRE	2023-10-17 00:00:00	2023-12-11 00:00:00	ANCIEN	\N	\N	\N	\N	31820	\N	\N	\N
37629	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31821	\N	\N	\N
37630	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31822	\N	\N	\N
37634	MEMBRE	2023-10-17 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	31826	\N	\N	\N
37635	MEMBRE	2023-10-17 00:00:00	2024-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	31827	\N	\N	\N
37636	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31828	\N	\N	\N
37637	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31829	\N	\N	\N
37638	MEMBRE	2023-10-17 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	31830	\N	\N	\N
37639	MEMBRE	2023-10-17 00:00:00	2023-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	31831	\N	\N	\N
37640	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31832	\N	\N	\N
37641	MEMBRE	2023-10-17 00:00:00	2023-12-11 00:00:00	ANCIEN	\N	\N	\N	\N	31833	\N	\N	\N
37653	MEMBRE	2023-10-17 00:00:00	2024-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	31845	\N	\N	\N
37654	MEMBRE	2023-10-17 00:00:00	2024-01-25 00:00:00	ACTIF	\N	\N	\N	\N	31846	\N	\N	\N
37655	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31847	\N	\N	\N
37688	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31880	\N	\N	\N
37689	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31881	\N	\N	\N
37690	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31882	\N	\N	\N
37691	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31883	\N	\N	\N
37692	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31884	\N	\N	\N
37693	MEMBRE	2023-10-17 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	31885	\N	\N	\N
37694	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31886	\N	\N	\N
37695	MEMBRE	2023-10-17 00:00:00	2024-01-28 00:00:00	ACTIF	\N	\N	\N	\N	31887	\N	\N	\N
37696	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31888	\N	\N	\N
37697	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31889	\N	\N	\N
37698	MEMBRE	2023-10-17 00:00:00	2024-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	31890	\N	\N	\N
37699	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31891	\N	\N	\N
37700	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31892	\N	\N	\N
37701	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31893	\N	\N	\N
37702	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31894	\N	\N	\N
37703	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31895	\N	\N	\N
37773	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31965	\N	\N	\N
37774	MEMBRE	2023-10-17 00:00:00	2024-04-02 00:00:00	ACTIF	\N	\N	\N	\N	31966	\N	\N	\N
37775	MEMBRE	2023-10-17 00:00:00	2023-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	31967	\N	\N	\N
37776	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31968	\N	\N	\N
37777	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31969	\N	\N	\N
37778	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31970	\N	\N	\N
37779	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31971	\N	\N	\N
37780	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31972	\N	\N	\N
37781	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31973	\N	\N	\N
37782	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31974	\N	\N	\N
37783	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31975	\N	\N	\N
37784	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31976	\N	\N	\N
37785	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31977	\N	\N	\N
37786	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31978	\N	\N	\N
37787	MEMBRE	2023-10-17 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	31979	\N	\N	\N
37788	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31980	\N	\N	\N
37789	MEMBRE	2023-10-17 00:00:00	2024-01-25 00:00:00	ACTIF	\N	\N	\N	\N	31981	\N	\N	\N
37801	MEMBRE	2023-10-18 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	31993	\N	\N	\N
37802	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31994	\N	\N	\N
37803	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31995	\N	\N	\N
37804	MEMBRE	2023-10-18 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	31996	\N	\N	\N
37805	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31997	\N	\N	\N
37806	MEMBRE	2023-10-18 00:00:00	2024-01-04 00:00:00	ANCIEN	\N	\N	\N	\N	31998	\N	\N	\N
37807	MEMBRE	2023-10-18 00:00:00	2024-01-25 00:00:00	ACTIF	\N	\N	\N	\N	31999	\N	\N	\N
37827	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32019	\N	\N	\N
37828	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32020	\N	\N	\N
37829	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32021	\N	\N	\N
37872	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32064	\N	\N	\N
37873	MEMBRE	2023-10-18 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	32065	\N	\N	\N
37874	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32066	\N	\N	\N
37875	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32067	\N	\N	\N
37876	MEMBRE	2023-10-18 00:00:00	2024-01-29 00:00:00	ACTIF	\N	\N	\N	\N	32068	\N	\N	\N
37877	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32069	\N	\N	\N
38656	MEMBRE	2023-11-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32851	\N	\N	\N
39213	MEMBRE	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33257	\N	\N	\N
39218	MEMBRE	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33262	\N	\N	\N
39497	MEMBRE	2023-12-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33391	\N	\N	\N
39498	MEMBRE	2023-12-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33392	\N	\N	\N
41416	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34414	\N	\N	\N
30833	MEMBRE	2017-10-01 00:00:00	2018-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	26504	\N	\N	\N
30834	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26505	\N	\N	\N
30835	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26506	\N	\N	\N
30959	MEMBRE	2018-02-19 00:00:00	2023-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	26553	\N	2018-02-19 12:46:11	\N
31074	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26618	\N	\N	\N
31080	VICPDT	2018-03-07 00:00:00	2020-06-24 00:00:00	ANCIEN	\N	\N	\N	\N	26395	\N	\N	\N
31197	VICPDT	2018-03-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	26493	\N	\N	\N
31199	VICPDT	2018-03-15 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26513	\N	\N	\N
31200	VICPDT	2018-03-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	26503	\N	\N	\N
31201	VICPDT	2018-03-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	26497	\N	\N	\N
31659	MEMBRE	2020-03-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	27091	\N	\N	\N
31670	MEMBRE	2020-08-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27101	\N	\N	\N
33022	MEMBRE	2020-10-27 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	28455	\N	\N	\N
33023	MEMBRE	2020-10-27 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	28456	\N	\N	\N
33024	MEMBRE	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28457	\N	\N	\N
33025	MEMBRE	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28458	\N	\N	\N
33026	MEMBRE	2020-10-09 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	28459	\N	\N	\N
33027	MEMBRE	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28460	\N	\N	\N
33028	MEMBRE	2020-10-09 00:00:00	2021-01-11 00:00:00	ANCIEN	\N	\N	\N	\N	28461	\N	\N	\N
33029	MEMBRE	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28462	\N	\N	\N
33030	MEMBRE	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28463	\N	\N	\N
33031	MEMBRE	2020-10-27 00:00:00	2021-10-13 00:00:00	ANCIEN	\N	\N	\N	\N	28464	\N	\N	\N
33126	MEMBRE	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28559	\N	\N	\N
33127	MEMBRE	2020-10-29 00:00:00	2020-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	28560	\N	\N	\N
33128	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28561	\N	\N	\N
33129	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28562	\N	\N	\N
33220	MEMBRE	2020-10-23 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	28653	\N	\N	\N
33221	MEMBRE	2020-10-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28654	\N	\N	\N
33222	MEMBRE	2020-10-23 00:00:00	2022-04-11 00:00:00	ANCIEN	\N	\N	\N	\N	28655	\N	\N	\N
33223	MEMBRE	2020-10-27 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	28656	\N	\N	\N
33224	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28657	\N	\N	\N
33225	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28658	\N	\N	\N
33226	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28659	\N	\N	\N
33227	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28660	\N	\N	\N
33228	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28661	\N	\N	\N
33229	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28662	\N	\N	\N
33230	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28663	\N	\N	\N
33231	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28664	\N	\N	\N
33232	MEMBRE	2020-10-30 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	28665	\N	\N	\N
33233	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28666	\N	\N	\N
33234	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28667	\N	\N	\N
33235	MEMBRE	2020-10-30 00:00:00	2021-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	28668	\N	\N	\N
33236	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28669	\N	\N	\N
33237	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28670	\N	\N	\N
34458	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29322	\N	\N	\N
34650	MEMBRE	2020-12-18 00:00:00	2021-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	29508	\N	\N	\N
34842	MEMBRE	2021-01-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29625	\N	\N	\N
35328	MEMBRE	2021-01-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	29991	\N	\N	\N
35575	VICPDT	2021-01-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	29402	\N	\N	\N
35576	VICPDT	2021-01-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29409	\N	\N	\N
35577	SECRET	2021-01-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	29401	\N	\N	\N
35580	SECRET	2021-01-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29408	\N	\N	\N
35647	MEMBRE	2021-02-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	30132	\N	\N	\N
35648	MEMBRE	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30133	\N	\N	\N
35662	VICPDT	2021-02-03 00:00:00	2021-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	30118	\N	\N	\N
35686	VICPDT	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27430	\N	\N	\N
35687	VICPDT	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27431	\N	\N	\N
35688	VICPDT	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27436	\N	\N	\N
35689	VICPDT	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28054	\N	\N	\N
35690	VICPDT	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28564	\N	\N	\N
35691	VICPDT	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30070	\N	\N	\N
35692	SECRET	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27821	\N	\N	\N
35693	SECRET	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28619	\N	\N	\N
35694	VICPDT	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28391	\N	\N	\N
35695	VICPDT	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28304	\N	\N	\N
35696	VICPDT	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27656	\N	\N	\N
35697	VICPDT	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28455	\N	\N	\N
35698	VICPDT	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27834	\N	\N	\N
35699	SECRET	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27415	\N	\N	\N
35700	SECRET	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27221	\N	\N	\N
35701	SECRET	2021-02-05 00:00:00	2023-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	27316	\N	\N	\N
35702	SECRET	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27695	\N	\N	\N
35703	VICPDT	2021-02-05 00:00:00	2021-09-19 00:00:00	ANCIEN	\N	\N	\N	\N	27250	\N	\N	\N
35704	VICPDT	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27117	\N	\N	\N
35705	SECRET	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28002	\N	\N	\N
35706	SECRET	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27716	\N	\N	\N
35707	VICPDT	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28543	\N	\N	\N
35708	VICPDT	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28204	\N	\N	\N
35709	SECRET	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27170	\N	\N	\N
35710	VICPDT	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28141	\N	\N	\N
35711	VICPDT	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28337	\N	\N	\N
35712	VICPDT	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27504	\N	\N	\N
35713	VICPDT	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28397	\N	\N	\N
35714	VICPDT	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28535	\N	\N	\N
35715	VICPDT	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28268	\N	\N	\N
35716	VICPDT	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29233	\N	\N	\N
35717	VICPDT	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27942	\N	\N	\N
35819	VICPDT	2021-02-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29107	\N	\N	\N
35820	VICPDT	2021-02-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28440	\N	\N	\N
35821	SECRET	2021-02-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29137	\N	\N	\N
35924	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30236	\N	\N	\N
36283	MEMBRE	2022-02-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30518	\N	\N	\N
36285	MEMBRE	2022-02-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	30520	\N	\N	\N
36510	MEMBRE	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30727	\N	\N	\N
36811	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31001	\N	\N	\N
36812	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31002	\N	\N	\N
36847	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31037	\N	\N	\N
36848	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31038	\N	\N	\N
36915	MEMBRE	2023-10-09 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	31105	\N	\N	\N
36916	MEMBRE	2023-10-09 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	31106	\N	\N	\N
36917	MEMBRE	2023-10-09 00:00:00	2024-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	31107	\N	\N	\N
36955	MEMBRE	2023-10-10 00:00:00	2023-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	31145	\N	\N	\N
37336	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31528	\N	\N	\N
37337	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31529	\N	\N	\N
37338	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31530	\N	\N	\N
37339	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31531	\N	\N	\N
37340	MEMBRE	2023-10-11 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	31532	\N	\N	\N
37399	MEMBRE	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31591	\N	\N	\N
37642	MEMBRE	2023-10-17 00:00:00	2024-02-27 00:00:00	ACTIF	\N	\N	\N	\N	31834	\N	\N	\N
37643	MEMBRE	2023-10-17 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	31835	\N	\N	\N
37644	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31836	\N	\N	\N
37645	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31837	\N	\N	\N
37646	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31838	\N	\N	\N
37647	MEMBRE	2023-10-17 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	31839	\N	\N	\N
37648	MEMBRE	2023-10-17 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	31840	\N	\N	\N
37649	MEMBRE	2023-10-17 00:00:00	2023-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	31841	\N	\N	\N
37650	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31842	\N	\N	\N
37651	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31843	\N	\N	\N
37652	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31844	\N	\N	\N
37665	MEMBRE	2023-10-17 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	31857	\N	\N	\N
37666	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31858	\N	\N	\N
37667	MEMBRE	2023-10-17 00:00:00	2024-01-30 00:00:00	ACTIF	\N	\N	\N	\N	31859	\N	\N	\N
37668	MEMBRE	2023-10-17 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	31860	\N	\N	\N
37669	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31861	\N	\N	\N
37670	MEMBRE	2023-10-17 00:00:00	2024-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	31862	\N	\N	\N
37671	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31863	\N	\N	\N
37672	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31864	\N	\N	\N
37673	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31865	\N	\N	\N
38568	MEMBRE	2023-11-07 00:00:00	2024-02-08 00:00:00	ACTIF	\N	\N	\N	\N	32763	\N	\N	\N
38569	MEMBRE	2023-11-07 00:00:00	2029-11-27 00:00:00	ACTIF	\N	\N	\N	\N	32764	\N	\N	\N
38570	MEMBRE	2023-11-07 00:00:00	2029-11-27 00:00:00	ACTIF	\N	\N	\N	\N	32765	\N	\N	\N
38571	MEMBRE	2023-11-07 00:00:00	2029-11-27 00:00:00	ACTIF	\N	\N	\N	\N	32766	\N	\N	\N
38632	MEMBRE	2023-11-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32827	\N	\N	\N
38903	MEMBRE	2023-11-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33090	\N	\N	\N
38904	MEMBRE	2023-11-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33091	\N	\N	\N
38905	MEMBRE	2023-11-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33092	\N	\N	\N
38101	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32296	\N	\N	\N
38122	MEMBRE	2023-10-24 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	32317	\N	\N	\N
38123	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32318	\N	\N	\N
38124	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32319	\N	\N	\N
38125	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32320	\N	\N	\N
38126	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32321	\N	\N	\N
38127	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32322	\N	\N	\N
38128	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32323	\N	\N	\N
38129	MEMBRE	2023-10-24 00:00:00	2024-01-25 00:00:00	ACTIF	\N	\N	\N	\N	32324	\N	\N	\N
38130	MEMBRE	2023-10-24 00:00:00	2024-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	32325	\N	\N	\N
38131	MEMBRE	2023-10-24 00:00:00	2023-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	32326	\N	\N	\N
38132	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32327	\N	\N	\N
38133	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32328	\N	\N	\N
38134	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32329	\N	\N	\N
38135	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32330	\N	\N	\N
38659	MEMBRE	2023-11-10 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	32854	\N	\N	\N
38660	MEMBRE	2023-11-10 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	32855	\N	\N	\N
39499	MEMBRE	2023-12-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33393	\N	\N	\N
40430	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33903	\N	\N	\N
40066	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33643	\N	\N	\N
40442	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33915	\N	\N	\N
40443	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33916	\N	\N	\N
40601	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34074	\N	\N	\N
40714	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34173	\N	\N	\N
40717	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34176	\N	\N	\N
41079	MEMBRE	2024-02-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34293	\N	\N	\N
41080	MEMBRE	2024-02-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34294	\N	\N	\N
41095	VICPDT	2024-02-06 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	30845	\N	\N	\N
30536	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26312	\N	\N	\N
31101	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26626	\N	\N	\N
31119	PDT	2018-01-30 00:00:00	2018-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	26643	\N	2018-03-12 15:59:19	2018-06-13 10:20:50
31160	MEMBRE	2018-03-07 00:00:00	2018-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	26684	\N	\N	\N
31304	MEMBRE	2018-05-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26773	\N	2018-06-05 15:48:32	\N
31308	MEMBRE	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26777	\N	2018-06-08 16:10:41	\N
31438	MEMBRE	2018-11-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	26899	\N	\N	\N
31439	MEMBRE	2018-11-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	26900	\N	\N	\N
31483	MEMBRE	2019-01-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26939	\N	\N	\N
31497	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26953	\N	\N	\N
31500	MEMBRE	2017-10-01 00:00:00	2020-08-06 00:00:00	ANCIEN	\N	\N	\N	\N	26956	\N	\N	\N
31637	MEMBRE	2020-01-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27069	\N	\N	\N
31831	MEMBRE	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27260	\N	\N	\N
31832	MEMBRE	2020-10-09 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	27261	\N	\N	\N
31833	MEMBRE	2020-10-07 00:00:00	2021-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	27262	\N	\N	\N
31834	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27263	\N	\N	\N
31835	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27264	\N	\N	\N
31836	MEMBRE	2020-10-07 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	27265	\N	\N	\N
31837	MEMBRE	2020-10-07 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	27266	\N	\N	\N
31838	MEMBRE	2020-10-07 00:00:00	2021-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	27267	\N	\N	\N
31839	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27268	\N	\N	\N
31840	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27269	\N	\N	\N
31841	MEMBRE	2020-10-07 00:00:00	2020-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	27270	\N	\N	\N
31842	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27271	\N	\N	\N
31843	MEMBRE	2020-10-07 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	27272	\N	\N	\N
31844	MEMBRE	2020-10-07 00:00:00	2021-01-14 00:00:00	ANCIEN	\N	\N	\N	\N	27273	\N	\N	\N
31845	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27274	\N	\N	\N
31846	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27275	\N	\N	\N
31847	MEMBRE	2020-10-07 00:00:00	2020-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	27276	\N	\N	\N
31848	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27277	\N	\N	\N
31849	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27278	\N	\N	\N
31850	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27279	\N	\N	\N
31851	MEMBRE	2020-10-07 00:00:00	2020-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	27280	\N	\N	\N
31852	MEMBRE	2020-10-07 00:00:00	2020-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	27281	\N	\N	\N
31853	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27282	\N	\N	\N
31854	MEMBRE	2020-10-07 00:00:00	2021-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	27283	\N	\N	\N
31855	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27284	\N	\N	\N
31856	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27285	\N	\N	\N
31857	MEMBRE	2020-10-07 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	27286	\N	\N	\N
31858	MEMBRE	2020-10-07 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	27287	\N	\N	\N
31859	MEMBRE	2020-10-07 00:00:00	2021-01-03 00:00:00	ANCIEN	\N	\N	\N	\N	27288	\N	\N	\N
31860	MEMBRE	2020-10-07 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	27289	\N	\N	\N
31861	MEMBRE	2020-10-07 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	27290	\N	\N	\N
31862	MEMBRE	2020-10-07 00:00:00	2020-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	27291	\N	\N	\N
31863	MEMBRE	2020-10-07 00:00:00	2020-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	27292	\N	\N	\N
31864	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27293	\N	\N	\N
31865	MEMBRE	2020-10-07 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	27294	\N	\N	\N
31866	MEMBRE	2020-10-07 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	27295	\N	\N	\N
31867	MEMBRE	2020-10-07 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	27296	\N	\N	\N
31868	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27297	\N	\N	\N
31869	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27298	\N	\N	\N
31870	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27299	\N	\N	\N
31871	MEMBRE	2020-10-07 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	27300	\N	\N	\N
31872	MEMBRE	2020-10-07 00:00:00	2020-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	27301	\N	\N	\N
31873	MEMBRE	2020-10-07 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	27302	\N	\N	\N
31874	MEMBRE	2020-10-07 00:00:00	2021-01-03 00:00:00	ANCIEN	\N	\N	\N	\N	27303	\N	\N	\N
31875	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27304	\N	\N	\N
31876	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27305	\N	\N	\N
31877	MEMBRE	2020-10-07 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	27306	\N	\N	\N
31878	MEMBRE	2020-10-07 00:00:00	2020-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	27307	\N	\N	\N
31879	MEMBRE	2020-10-07 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	27308	\N	\N	\N
31880	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27309	\N	\N	\N
31881	MEMBRE	2020-10-07 00:00:00	2020-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	27310	\N	\N	\N
31882	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27311	\N	\N	\N
31883	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27312	\N	\N	\N
31884	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27313	\N	\N	\N
31885	MEMBRE	2020-10-07 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	27314	\N	\N	\N
31886	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27315	\N	\N	\N
31887	MEMBRE	2020-10-07 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	27316	\N	\N	\N
31888	MEMBRE	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27317	\N	\N	\N
31889	MEMBRE	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27318	\N	\N	\N
31890	MEMBRE	2020-10-06 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	27319	\N	\N	\N
31891	MEMBRE	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27320	\N	\N	\N
31892	MEMBRE	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27321	\N	\N	\N
31893	MEMBRE	2020-10-06 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	27322	\N	\N	\N
31894	MEMBRE	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27323	\N	\N	\N
31895	MEMBRE	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27324	\N	\N	\N
31896	MEMBRE	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27325	\N	\N	\N
31897	MEMBRE	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27326	\N	\N	\N
31898	MEMBRE	2020-10-07 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	27327	\N	\N	\N
33238	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28671	\N	\N	\N
33239	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28672	\N	\N	\N
33240	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28673	\N	\N	\N
33241	MEMBRE	2020-10-30 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	28674	\N	\N	\N
33242	MEMBRE	2020-10-30 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	28675	\N	\N	\N
33243	MEMBRE	2020-10-30 00:00:00	2020-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	28676	\N	\N	\N
33244	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28677	\N	\N	\N
33245	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28678	\N	\N	\N
33246	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28679	\N	\N	\N
33247	MEMBRE	2020-10-30 00:00:00	2020-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	28680	\N	\N	\N
33248	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28681	\N	\N	\N
33249	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28682	\N	\N	\N
33250	MEMBRE	2020-10-27 00:00:00	2021-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	28683	\N	\N	\N
33279	MEMBRE	2020-11-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28712	\N	\N	\N
33499	MEMBRE	2020-11-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28921	\N	\N	\N
33670	MEMBRE	2020-11-18 00:00:00	2020-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	29003	\N	\N	\N
33671	MEMBRE	2020-11-18 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	29004	\N	\N	\N
33673	MEMBRE	2020-11-19 00:00:00	2020-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	29005	\N	\N	\N
33674	MEMBRE	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29006	\N	\N	\N
33675	MEMBRE	2020-11-19 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	29007	\N	\N	\N
33676	MEMBRE	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29008	\N	\N	\N
33677	MEMBRE	2020-11-19 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	29009	\N	\N	\N
33678	MEMBRE	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29010	\N	\N	\N
33679	MEMBRE	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29011	\N	\N	\N
34749	MEMBRE	2020-12-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	29569	\N	\N	\N
34910	MEMBRE	2020-12-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	29675	\N	\N	\N
34912	MEMBRE	2020-12-18 00:00:00	2021-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	29677	\N	\N	\N
34917	MEMBRE	2021-01-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	29682	\N	\N	\N
34918	MEMBRE	2021-01-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	29683	\N	\N	\N
34942	MEMBRE	2021-01-13 00:00:00	2021-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	29706	\N	\N	\N
34943	MEMBRE	2021-01-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29707	\N	\N	\N
35021	VICPDT	2021-01-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28419	\N	\N	\N
35022	VICPDT	2021-01-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27273	\N	\N	\N
35023	VICPDT	2021-01-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27508	\N	\N	\N
35024	VICPDT	2021-01-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27438	\N	\N	\N
35025	VICPDT	2021-01-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27158	\N	\N	\N
35026	VICPDT	2021-01-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27345	\N	\N	\N
35027	VICPDT	2021-01-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27841	\N	\N	\N
35028	VICPDT	2021-01-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27663	\N	\N	\N
35029	VICPDT	2021-01-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28479	\N	\N	\N
35030	SECRET	2021-01-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27795	\N	\N	\N
35031	SECRET	2021-01-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28055	\N	\N	\N
35032	SECRET	2021-01-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28323	\N	\N	\N
35080	MEMBRE	2020-10-01 00:00:00	2021-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	29804	\N	\N	\N
35116	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29840	\N	\N	\N
35209	MEMBRE	2021-01-19 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	29933	\N	\N	\N
35210	MEMBRE	2021-01-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29934	\N	\N	\N
35357	VICPDT	2021-01-26 00:00:00	2021-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	29473	\N	\N	\N
35360	VICPDT	2021-01-26 00:00:00	2021-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	29619	\N	\N	\N
35361	VICPDT	2021-01-26 00:00:00	2021-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	29622	\N	\N	\N
35362	VICPDT	2021-01-26 00:00:00	2021-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	29617	\N	\N	\N
35363	VICPDT	2021-01-26 00:00:00	2021-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	29992	\N	\N	\N
35364	VICPDT	2021-01-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30004	\N	\N	\N
35369	VICPDT	2021-01-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	29726	\N	\N	\N
35478	VICPDT	2021-01-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	29916	\N	\N	\N
35585	VICPDT	2021-01-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	29545	\N	\N	\N
35589	MEMBRE	2020-10-01 00:00:00	2021-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	30090	\N	\N	\N
38102	MEMBRE	2023-10-24 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	32297	\N	\N	\N
38103	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32298	\N	\N	\N
38104	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32299	\N	\N	\N
38105	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32300	\N	\N	\N
38106	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32301	\N	\N	\N
38107	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32302	\N	\N	\N
38586	MEMBRE	2023-11-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32781	\N	\N	\N
38834	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33029	\N	\N	\N
38835	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33030	\N	\N	\N
39217	MEMBRE	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33261	\N	\N	\N
39226	MEMBRE	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33270	\N	\N	\N
39680	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33424	\N	\N	\N
39904	VICPDT	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31331	\N	\N	\N
39905	VICPDT	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31961	\N	\N	\N
39906	VICPDT	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32039	\N	\N	\N
39907	VICPDT	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32939	\N	\N	\N
39908	VICPDT	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32027	\N	\N	\N
39909	VICPDT	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32533	\N	\N	\N
39910	VICPDT	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33075	\N	\N	\N
39911	VICPDT	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32413	\N	\N	\N
39912	VICPDT	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31285	\N	\N	\N
39913	VICPDT	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31119	\N	\N	\N
39914	VICPDT	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31109	\N	\N	\N
39915	VICPDT	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32457	\N	\N	\N
39916	SECRET	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31003	\N	\N	\N
39917	SECRET	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30925	\N	\N	\N
39988	MEMBRE	2024-01-17 00:00:00	2024-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	29901	\N	\N	\N
40376	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33849	\N	\N	\N
40389	MEMBRE	2023-12-14 00:00:00	2024-02-14 00:00:00	ACTIF	\N	\N	\N	\N	33862	\N	\N	\N
40390	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33863	\N	\N	\N
40565	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34038	\N	\N	\N
40572	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34045	\N	\N	\N
40611	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34084	\N	\N	\N
40614	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34087	\N	\N	\N
40629	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34102	\N	\N	\N
40722	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34181	\N	\N	\N
40869	MEMBRE	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34244	\N	\N	\N
40975	MEMBRE	2024-01-02 00:00:00	\N	\N	\N	\N	\N	\N	30768	\N	\N	\N
41008	VICPDT	2024-01-30 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	33485	\N	\N	\N
41229	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34344	\N	\N	\N
41352	MEMBRE	2024-02-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34365	\N	\N	\N
30642	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26343	\N	\N	\N
30643	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26344	\N	\N	\N
30644	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26345	\N	\N	\N
30645	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26346	\N	\N	\N
30864	VICPDT	2018-02-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24315	\N	2018-02-14 12:54:05	2018-02-14 12:54:11
30865	VICPDT	2018-02-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26032	\N	2018-02-14 12:54:24	\N
30866	VICPDT	2018-02-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26337	\N	2018-02-14 12:54:55	\N
30867	SECRET	2018-02-14 00:00:00	2020-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	25951	\N	2018-02-14 12:55:10	\N
30868	SECRET	2018-02-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26220	\N	2018-02-14 12:55:21	\N
30869	SECRET	2018-02-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25029	\N	2018-02-14 12:55:34	\N
31117	MEMBRE	2018-03-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26641	\N	2018-03-12 14:56:35	\N
31262	MEMBRE	2018-04-11 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26747	\N	2018-04-13 10:43:03	\N
31496	MEMBRE	2017-10-01 00:00:00	2020-08-06 00:00:00	ANCIEN	\N	\N	\N	\N	26952	\N	\N	\N
31508	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26962	\N	\N	\N
31537	MEMBRE	2019-01-22 00:00:00	2020-08-06 00:00:00	ANCIEN	\N	\N	\N	\N	26989	\N	\N	\N
31678	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27107	\N	\N	\N
31679	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27108	\N	\N	\N
31680	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27109	\N	\N	\N
31681	MEMBRE	2020-10-07 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	27110	\N	\N	\N
31682	MEMBRE	2020-10-07 00:00:00	2020-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	27111	\N	\N	\N
31683	MEMBRE	2020-10-07 00:00:00	2020-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	27112	\N	\N	\N
31684	MEMBRE	2020-10-07 00:00:00	2021-01-03 00:00:00	ANCIEN	\N	\N	\N	\N	27113	\N	\N	\N
31685	MEMBRE	2020-10-07 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	27114	\N	\N	\N
31686	MEMBRE	2020-10-07 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	27115	\N	\N	\N
31687	MEMBRE	2020-10-07 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	27116	\N	\N	\N
31688	MEMBRE	2020-10-07 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	27117	\N	\N	\N
31689	MEMBRE	2020-10-07 00:00:00	2020-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	27118	\N	\N	\N
31690	MEMBRE	2020-10-07 00:00:00	2021-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	27119	\N	\N	\N
31691	MEMBRE	2020-10-07 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	27120	\N	\N	\N
31692	MEMBRE	2020-10-07 00:00:00	2020-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	27121	\N	\N	\N
31693	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27122	\N	\N	\N
31694	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27123	\N	\N	\N
31695	MEMBRE	2020-10-07 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	27124	\N	\N	\N
31696	MEMBRE	2020-10-07 00:00:00	2020-12-23 00:00:00	ANCIEN	\N	\N	\N	\N	27125	\N	\N	\N
31697	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27126	\N	\N	\N
31698	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27127	\N	\N	\N
31699	MEMBRE	2020-10-07 00:00:00	2021-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	27128	\N	\N	\N
31700	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27129	\N	\N	\N
31701	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27130	\N	\N	\N
31702	MEMBRE	2020-10-07 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	27131	\N	\N	\N
31703	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27132	\N	\N	\N
31704	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27133	\N	\N	\N
31705	MEMBRE	2020-10-07 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	27134	\N	\N	\N
31706	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27135	\N	\N	\N
31707	MEMBRE	2020-10-07 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	27136	\N	\N	\N
31708	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27137	\N	\N	\N
31709	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27138	\N	\N	\N
33354	MEMBRE	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28787	\N	\N	\N
33355	MEMBRE	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28788	\N	\N	\N
33356	MEMBRE	2020-11-04 00:00:00	2020-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	28789	\N	\N	\N
33724	MEMBRE	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28686	\N	\N	\N
33725	PDTDEL	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour le Bénin	\N	27673	\N	\N	\N
33726	PDTDEL	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour la Guinée (Conakry)	\N	27540	\N	\N	\N
33727	PDTDEL	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour la Mauritanie	\N	27464	\N	\N	\N
33728	PDTDEL	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour le Niger	\N	29033	\N	\N	\N
33729	PDTDEL	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour la Sierra Leone	\N	28217	\N	\N	\N
33730	PDTDEL	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour le Togo	\N	28648	\N	\N	\N
33731	PDTDEL	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour Sao Tomé-et-Principe	\N	28694	\N	\N	\N
33732	MEMBRE	2020-11-23 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	29036	\N	\N	\N
33733	MEMBRE	2020-11-23 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	29037	\N	\N	\N
33734	MEMBRE	2020-11-23 00:00:00	2020-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	29038	\N	\N	\N
33735	MEMBRE	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29039	\N	\N	\N
33736	PDTDEL	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour le Kazakhstan	\N	28560	\N	\N	\N
33737	PDTDEL	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour le Kirghizistan	\N	29032	\N	\N	\N
33738	PDTDEL	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour l'Ouzbékistan	\N	28429	\N	\N	\N
33739	PDTDEL	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	Tadjikistan	\N	27310	\N	\N	\N
33740	PDTDEL	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour le Turkménistan	\N	28864	\N	\N	\N
33741	PDTDEL	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour la Malaisie	\N	27148	\N	\N	\N
33742	PDTDEL	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour la Thaïlande	\N	27162	\N	\N	\N
34415	MEMBRE	2023-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29293	\N	\N	\N
34800	MEMBRE	2020-10-01 00:00:00	2021-07-20 00:00:00	ANCIEN	\N	\N	\N	\N	29589	\N	\N	\N
34824	MEMBRE	2021-01-04 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	29607	\N	\N	\N
34830	MEMBRE	2021-01-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	29613	\N	\N	\N
34831	MEMBRE	2021-01-06 00:00:00	2021-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	29614	\N	\N	\N
34869	MEMBRE	2021-01-11 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	29652	\N	\N	\N
34913	MEMBRE	2021-01-11 00:00:00	2021-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	29678	\N	\N	\N
34926	MEMBRE	2021-01-13 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	29691	\N	\N	\N
34933	MEMBRE	2021-01-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	29697	\N	\N	\N
34934	MEMBRE	2021-01-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	29698	\N	\N	\N
34948	MEMBRE	2021-01-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29712	\N	\N	\N
34964	MEMBRE	2021-01-13 00:00:00	2021-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	29720	\N	\N	\N
34965	MEMBRE	2021-01-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29721	\N	\N	\N
34966	MEMBRE	2021-01-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29722	\N	\N	\N
34976	MEMBRE	2021-01-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29732	\N	\N	\N
35091	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29815	\N	\N	\N
35092	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29816	\N	\N	\N
35652	MEMBRE	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30137	\N	\N	\N
35653	MEMBRE	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30138	\N	\N	\N
35843	VICPDT	2021-02-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29880	\N	\N	\N
36029	MEMBRE	2021-03-31 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30316	\N	\N	\N
36067	MEMBRE	2021-06-09 00:00:00	2021-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	30348	\N	\N	\N
36288	MEMBRE	2022-02-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30523	\N	\N	\N
36355	MEMBRE	2022-04-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30582	\N	\N	\N
36417	MEMBRE	2022-06-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30634	\N	\N	\N
36431	MEMBRE	2022-07-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30648	\N	\N	\N
36452	MEMBRE	2022-09-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30669	\N	\N	\N
36453	MEMBRE	2022-09-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30670	\N	\N	\N
36469	MEMBRE	2022-09-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30686	\N	\N	\N
36470	MEMBRE	2022-09-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30687	\N	\N	\N
36481	MEMBRE	2022-10-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30698	\N	\N	\N
36484	MEMBRE	2022-11-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30701	\N	\N	\N
36485	MEMBRE	2022-11-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30702	\N	\N	\N
36519	MEMBRE	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30736	\N	\N	\N
36674	MEMBRE	2023-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30864	\N	\N	\N
36676	MEMBRE	2023-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30866	\N	\N	\N
36677	MEMBRE	2023-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30867	\N	\N	\N
36678	MEMBRE	2023-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30868	\N	\N	\N
36683	MEMBRE	2023-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30873	\N	\N	\N
36684	MEMBRE	2023-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30874	\N	\N	\N
36788	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30978	\N	\N	\N
36789	MEMBRE	2023-10-09 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	30979	\N	\N	\N
36790	MEMBRE	2023-10-09 00:00:00	2023-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	30980	\N	\N	\N
36791	MEMBRE	2023-10-09 00:00:00	2024-02-04 00:00:00	ACTIF	\N	\N	\N	\N	30981	\N	\N	\N
36808	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30998	\N	\N	\N
36809	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30999	\N	\N	\N
36810	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31000	\N	\N	\N
37138	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31330	\N	\N	\N
37139	MEMBRE	2023-10-10 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	31331	\N	\N	\N
37140	MEMBRE	2023-10-10 00:00:00	2024-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	31332	\N	\N	\N
37141	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31333	\N	\N	\N
37142	MEMBRE	2023-10-10 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	31334	\N	\N	\N
37143	MEMBRE	2023-10-10 00:00:00	2024-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	31335	\N	\N	\N
37144	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31336	\N	\N	\N
37145	MEMBRE	2023-10-10 00:00:00	2024-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	31337	\N	\N	\N
37382	MEMBRE	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31574	\N	\N	\N
37383	MEMBRE	2023-10-12 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	31575	\N	\N	\N
37384	MEMBRE	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31576	\N	\N	\N
38906	MEMBRE	2023-11-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33093	\N	\N	\N
38907	MEMBRE	2023-11-21 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	33094	\N	\N	\N
38057	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32252	\N	\N	\N
38058	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32253	\N	\N	\N
38059	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32254	\N	\N	\N
38060	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32255	\N	\N	\N
38061	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32256	\N	\N	\N
38062	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32257	\N	\N	\N
38063	MEMBRE	2023-10-24 00:00:00	2024-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	32258	\N	\N	\N
38064	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32259	\N	\N	\N
38065	MEMBRE	2023-10-24 00:00:00	2024-03-24 00:00:00	ACTIF	\N	\N	\N	\N	32260	\N	\N	\N
38066	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32261	\N	\N	\N
38067	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32262	\N	\N	\N
38068	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32263	\N	\N	\N
38069	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32264	\N	\N	\N
38070	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32265	\N	\N	\N
38071	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32266	\N	\N	\N
38072	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32267	\N	\N	\N
38073	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32268	\N	\N	\N
38074	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32269	\N	\N	\N
38075	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32270	\N	\N	\N
38076	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32271	\N	\N	\N
38077	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32272	\N	\N	\N
38078	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32273	\N	\N	\N
38079	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32274	\N	\N	\N
38080	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32275	\N	\N	\N
38770	MEMBRE	2023-11-15 00:00:00	2024-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	32965	\N	\N	\N
38771	MEMBRE	2023-11-15 00:00:00	2024-02-26 00:00:00	ACTIF	\N	\N	\N	\N	32966	\N	\N	\N
38772	MEMBRE	2023-11-15 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	32967	\N	\N	\N
38773	MEMBRE	2023-11-15 00:00:00	2024-01-30 00:00:00	ACTIF	\N	\N	\N	\N	32968	\N	\N	\N
38774	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32969	\N	\N	\N
38775	MEMBRE	2023-11-15 00:00:00	2023-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	32970	\N	\N	\N
38776	MEMBRE	2023-11-15 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	32971	\N	\N	\N
38777	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32972	\N	\N	\N
38778	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32973	\N	\N	\N
38779	MEMBRE	2023-11-15 00:00:00	2024-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	32974	\N	\N	\N
38780	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32975	\N	\N	\N
38781	MEMBRE	2023-11-15 00:00:00	2024-02-07 00:00:00	ACTIF	\N	\N	\N	\N	32976	\N	\N	\N
38782	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32977	\N	\N	\N
38783	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32978	\N	\N	\N
38784	MEMBRE	2023-11-15 00:00:00	2024-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	32979	\N	\N	\N
38785	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32980	\N	\N	\N
38786	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32981	\N	\N	\N
38787	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32982	\N	\N	\N
38788	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32983	\N	\N	\N
38789	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32984	\N	\N	\N
38790	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32985	\N	\N	\N
38791	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32986	\N	\N	\N
38792	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32987	\N	\N	\N
38793	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32988	\N	\N	\N
38794	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32989	\N	\N	\N
38795	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32990	\N	\N	\N
38796	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32991	\N	\N	\N
38797	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32992	\N	\N	\N
38798	MEMBRE	2023-11-15 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	32993	\N	\N	\N
38799	MEMBRE	2023-11-15 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	32994	\N	\N	\N
38800	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32995	\N	\N	\N
38801	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32996	\N	\N	\N
38802	MEMBRE	2023-11-15 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	32997	\N	\N	\N
38803	MEMBRE	2023-11-15 00:00:00	2024-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	32998	\N	\N	\N
38804	MEMBRE	2023-11-15 00:00:00	2024-04-02 00:00:00	ACTIF	\N	\N	\N	\N	32999	\N	\N	\N
38805	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33000	\N	\N	\N
38806	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33001	\N	\N	\N
38807	MEMBRE	2023-11-15 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	33002	\N	\N	\N
38808	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33003	\N	\N	\N
38809	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33004	\N	\N	\N
38810	MEMBRE	2023-11-15 00:00:00	2024-02-27 00:00:00	ACTIF	\N	\N	\N	\N	33005	\N	\N	\N
38811	MEMBRE	2023-11-15 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	33006	\N	\N	\N
38812	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33007	\N	\N	\N
38813	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33008	\N	\N	\N
38814	MEMBRE	2023-11-15 00:00:00	2024-02-08 00:00:00	ACTIF	\N	\N	\N	\N	33009	\N	\N	\N
38815	MEMBRE	2023-11-15 00:00:00	2024-01-04 00:00:00	ANCIEN	\N	\N	\N	\N	33010	\N	\N	\N
38816	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33011	\N	\N	\N
38817	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33012	\N	\N	\N
38818	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33013	\N	\N	\N
38819	MEMBRE	2023-11-15 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	33014	\N	\N	\N
38820	MEMBRE	2023-11-15 00:00:00	2024-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	33015	\N	\N	\N
38821	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33016	\N	\N	\N
38822	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33017	\N	\N	\N
38823	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33018	\N	\N	\N
38824	MEMBRE	2023-11-15 00:00:00	2024-03-05 00:00:00	ACTIF	\N	\N	\N	\N	33019	\N	\N	\N
38825	MEMBRE	2023-11-15 00:00:00	2024-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	33020	\N	\N	\N
38826	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33021	\N	\N	\N
38827	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33022	\N	\N	\N
38828	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33023	\N	\N	\N
38829	MEMBRE	2023-11-15 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	33024	\N	\N	\N
38830	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33025	\N	\N	\N
38831	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33026	\N	\N	\N
38832	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33027	\N	\N	\N
40391	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33864	\N	\N	\N
40531	MEMBRE	2023-10-01 00:00:00	2024-02-27 00:00:00	ACTIF	\N	\N	\N	\N	34004	\N	\N	\N
40533	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34006	\N	\N	\N
40539	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34012	\N	\N	\N
40540	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34013	\N	\N	\N
40543	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34016	\N	\N	\N
40556	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34029	\N	\N	\N
40933	MEMBRE	2024-01-25 00:00:00	2024-01-30 00:00:00	ACTIF	\N	\N	\N	\N	34255	\N	\N	\N
40934	MEMBRE	2024-01-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34256	\N	\N	\N
40935	MEMBRE	2024-01-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34257	\N	\N	\N
40936	MEMBRE	2024-01-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34258	\N	\N	\N
40937	MEMBRE	2024-01-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34259	\N	\N	\N
40939	MEMBRE	2024-01-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34261	\N	\N	\N
41126	VICPDT	2024-02-06 00:00:00	\N	\N	\N	\N	\N	\N	33846	\N	\N	\N
41170	MEMBRE	2023-10-01 00:00:00	2024-02-12 00:00:00	\N	\N	\N	\N	\N	34319	\N	\N	\N
30618	VICPDT	2018-02-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25553	\N	2018-02-08 14:36:50	\N
30619	VICPDT	2018-02-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25633	\N	2018-02-08 14:37:10	\N
30620	VICPDT	2018-02-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25554	\N	2018-02-08 14:37:17	\N
30621	VICPDT	2018-02-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23944	\N	2018-02-08 14:37:24	\N
30622	VICPDT	2018-02-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25184	\N	2018-02-08 14:37:29	\N
30623	MEMBRE	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26338	\N	2018-02-08 14:48:57	\N
30646	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26347	\N	\N	\N
30648	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26349	\N	\N	\N
30655	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26356	\N	\N	\N
31146	MEMBRE	2018-03-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26670	\N	\N	\N
31150	MEMBRE	2018-03-07 00:00:00	2018-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	26674	\N	\N	\N
31157	MEMBRE	2018-03-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26681	\N	\N	\N
31158	MEMBRE	2018-03-07 00:00:00	2018-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	26682	\N	\N	\N
31203	MEMBRE	2018-03-09 00:00:00	2018-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	26704	\N	2018-03-15 18:59:35	2018-03-16 14:48:33
31296	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26765	\N	\N	\N
31517	MEMBRE	2017-02-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	26969	\N	\N	\N
31528	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26980	\N	\N	\N
31529	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26981	\N	\N	\N
31671	MEMBRE	2020-08-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27102	\N	\N	\N
32226	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27655	\N	\N	\N
32227	MEMBRE	2020-10-14 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	27656	\N	\N	\N
32228	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27657	\N	\N	\N
32229	MEMBRE	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27658	\N	\N	\N
32230	MEMBRE	2020-10-08 00:00:00	2021-01-03 00:00:00	ANCIEN	\N	\N	\N	\N	27659	\N	\N	\N
32231	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27660	\N	\N	\N
32232	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27661	\N	\N	\N
32233	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27662	\N	\N	\N
32234	MEMBRE	2020-10-14 00:00:00	2021-01-14 00:00:00	ANCIEN	\N	\N	\N	\N	27663	\N	\N	\N
32235	MEMBRE	2020-10-14 00:00:00	2021-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	27664	\N	\N	\N
32236	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27665	\N	\N	\N
32237	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27666	\N	\N	\N
32238	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27667	\N	\N	\N
32239	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27668	\N	\N	\N
32240	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27669	\N	\N	\N
32241	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27670	\N	\N	\N
32278	MEMBRE	2020-10-14 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	27707	\N	\N	\N
32279	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27708	\N	\N	\N
32280	MEMBRE	2020-10-14 00:00:00	2023-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	27709	\N	\N	\N
32281	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27710	\N	\N	\N
32282	MEMBRE	2020-10-14 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	27711	\N	\N	\N
34638	MEMBRE	2020-12-16 00:00:00	2021-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	29496	\N	\N	\N
34706	MEMBRE	2020-12-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	29546	\N	\N	\N
34707	MEMBRE	2020-12-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	29547	\N	\N	\N
34708	MEMBRE	2020-12-18 00:00:00	2021-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	29548	\N	\N	\N
34849	MEMBRE	2021-01-06 00:00:00	2021-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	29632	\N	\N	\N
35043	MEMBRE	2021-01-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	29772	\N	\N	\N
35044	MEMBRE	2021-01-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	29773	\N	\N	\N
35045	MEMBRE	2021-01-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	29774	\N	\N	\N
35242	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29950	\N	\N	\N
35243	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29951	\N	\N	\N
35244	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29952	\N	\N	\N
35299	MEMBRE	2021-01-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	29969	\N	\N	\N
35345	MEMBRE	2020-10-01 00:00:00	2021-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	30008	\N	\N	\N
35383	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30020	\N	\N	\N
35414	MEMBRE	2021-01-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	30041	\N	\N	\N
35415	MEMBRE	2021-01-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	30042	\N	\N	\N
35416	MEMBRE	2021-01-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	30043	\N	\N	\N
35607	VICPDT	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29739	\N	\N	\N
35650	MEMBRE	2021-02-03 00:00:00	2021-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	30135	\N	\N	\N
35828	SECRET	2021-02-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30096	\N	\N	\N
35846	VICPDT	2021-02-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29884	\N	\N	\N
35944	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30247	\N	\N	\N
36022	VICPDT	2021-03-30 00:00:00	2022-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	29936	\N	\N	\N
36023	VICPDT	2021-03-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30282	\N	\N	\N
36079	MEMBRE	2021-06-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	30360	\N	\N	\N
36080	MEMBRE	2021-06-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	30361	\N	\N	\N
36095	MEMBRE	2021-06-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	30369	\N	\N	\N
36118	VICPDT	2021-07-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	29509	\N	\N	\N
36181	MEMBRE	2021-10-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	30433	\N	\N	\N
36183	MEMBRE	2021-10-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	30435	\N	\N	\N
36206	PDT	2021-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30118	\N	\N	\N
36258	MEMBRE	2022-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30502	\N	\N	\N
36327	MEMBRE	2022-03-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30554	\N	\N	\N
36376	MEMBRE	2022-04-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30602	\N	\N	\N
36616	MEMBRE	2023-03-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30815	\N	\N	\N
36688	MEMBRE	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30878	\N	\N	\N
36689	MEMBRE	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30879	\N	\N	\N
36690	MEMBRE	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30880	\N	\N	\N
36691	MEMBRE	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30881	\N	\N	\N
36692	MEMBRE	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30882	\N	\N	\N
36693	MEMBRE	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30883	\N	\N	\N
36694	MEMBRE	2023-10-05 00:00:00	2023-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	30884	\N	\N	\N
36695	MEMBRE	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30885	\N	\N	\N
36696	MEMBRE	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30886	\N	\N	\N
36697	MEMBRE	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30887	\N	\N	\N
36698	MEMBRE	2023-10-05 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	30888	\N	\N	\N
36699	MEMBRE	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30889	\N	\N	\N
36700	MEMBRE	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30890	\N	\N	\N
36701	MEMBRE	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30891	\N	\N	\N
36702	MEMBRE	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30892	\N	\N	\N
36703	MEMBRE	2023-10-05 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	30893	\N	\N	\N
36704	MEMBRE	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30894	\N	\N	\N
36705	MEMBRE	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30895	\N	\N	\N
36706	MEMBRE	2023-10-05 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	30896	\N	\N	\N
36707	MEMBRE	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30897	\N	\N	\N
36708	MEMBRE	2023-10-05 00:00:00	2024-02-08 00:00:00	ACTIF	\N	\N	\N	\N	30898	\N	\N	\N
36709	MEMBRE	2023-10-05 00:00:00	2024-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	30899	\N	\N	\N
36710	MEMBRE	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30900	\N	\N	\N
36711	MEMBRE	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30901	\N	\N	\N
36712	MEMBRE	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30902	\N	\N	\N
36713	MEMBRE	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30903	\N	\N	\N
36714	MEMBRE	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30904	\N	\N	\N
36715	MEMBRE	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30905	\N	\N	\N
36716	MEMBRE	2023-10-05 00:00:00	2024-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	30906	\N	\N	\N
36717	MEMBRE	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30907	\N	\N	\N
36718	MEMBRE	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30908	\N	\N	\N
36782	MEMBRE	2023-10-09 00:00:00	2024-02-29 00:00:00	ACTIF	\N	\N	\N	\N	30972	\N	\N	\N
36783	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30973	\N	\N	\N
36784	MEMBRE	2023-10-09 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	30974	\N	\N	\N
36785	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30975	\N	\N	\N
36786	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30976	\N	\N	\N
36787	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30977	\N	\N	\N
36813	MEMBRE	2023-10-09 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	31003	\N	\N	\N
36814	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31004	\N	\N	\N
36815	MEMBRE	2023-10-09 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	31005	\N	\N	\N
36816	MEMBRE	2023-10-09 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	31006	\N	\N	\N
36817	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31007	\N	\N	\N
36818	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31008	\N	\N	\N
36819	MEMBRE	2023-10-09 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	31009	\N	\N	\N
36820	MEMBRE	2023-10-09 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	31010	\N	\N	\N
36821	MEMBRE	2023-10-09 00:00:00	2024-01-29 00:00:00	ACTIF	\N	\N	\N	\N	31011	\N	\N	\N
36822	MEMBRE	2023-10-09 00:00:00	2024-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	31012	\N	\N	\N
36823	MEMBRE	2023-10-09 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	31013	\N	\N	\N
36824	MEMBRE	2023-10-09 00:00:00	2024-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	31014	\N	\N	\N
36825	MEMBRE	2023-10-09 00:00:00	2023-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	31015	\N	\N	\N
36826	MEMBRE	2023-10-09 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	31016	\N	\N	\N
36827	MEMBRE	2023-10-09 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	31017	\N	\N	\N
36828	MEMBRE	2023-10-09 00:00:00	2024-02-19 00:00:00	ACTIF	\N	\N	\N	\N	31018	\N	\N	\N
36829	MEMBRE	2023-10-09 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	31019	\N	\N	\N
36830	MEMBRE	2023-10-09 00:00:00	2024-01-25 00:00:00	ACTIF	\N	\N	\N	\N	31020	\N	\N	\N
36831	MEMBRE	2023-10-09 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	31021	\N	\N	\N
36876	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31066	\N	\N	\N
37089	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31279	\N	\N	\N
37090	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31280	\N	\N	\N
37091	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31281	\N	\N	\N
37092	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31282	\N	\N	\N
37093	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31283	\N	\N	\N
39204	MEMBRE	2023-12-05 00:00:00	2024-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	33250	\N	\N	\N
39670	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33418	\N	\N	\N
40021	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33598	\N	\N	\N
40402	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33875	\N	\N	\N
40943	VICPDT	2024-01-26 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32324	\N	\N	\N
40944	VICPDT	2024-01-26 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31803	\N	\N	\N
40945	VICPDT	2024-01-26 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32634	\N	\N	\N
40946	VICPDT	2024-01-26 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31616	\N	\N	\N
40947	PDTHON	2024-01-26 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31020	\N	\N	\N
40948	VICPDT	2024-01-26 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31846	\N	\N	\N
40949	VICPDT	2024-01-26 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32670	\N	\N	\N
40950	SECRET	2024-01-26 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31030	\N	\N	\N
40951	SECRET	2024-01-26 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	33204	\N	\N	\N
40953	PDTHON	2024-01-26 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31010	\N	\N	\N
40954	VICPDT	2024-01-26 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32627	\N	\N	\N
40955	VICPDT	2024-01-26 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31712	\N	\N	\N
40956	VICPDT	2024-01-26 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31619	\N	\N	\N
40957	VICPDT	2024-01-26 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31981	\N	\N	\N
40958	VICPDT	2024-01-26 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31999	\N	\N	\N
40959	VICPDT	2024-01-26 00:00:00	2024-03-28 00:00:00	\N	\N	\N	\N	\N	32654	\N	\N	\N
40960	VICPDT	2024-01-26 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32859	\N	\N	\N
40961	VICPDT	2024-01-26 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32089	\N	\N	\N
40962	VICPDT	2024-01-26 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32438	\N	\N	\N
40963	PDTHON	2024-01-26 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31559	\N	\N	\N
40964	VICPDT	2024-01-26 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31234	\N	\N	\N
40965	VICPDT	2024-01-26 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31746	\N	\N	\N
40966	VICPDT	2024-01-26 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32475	\N	\N	\N
40967	VICPDT	2024-01-26 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31080	\N	\N	\N
40968	VICPDT	2024-01-26 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	33131	\N	\N	\N
40969	SECRET	2024-01-26 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32586	\N	\N	\N
40970	SECRET	2024-01-26 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31657	\N	\N	\N
40971	SECRET	2024-01-26 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32841	\N	\N	\N
41162	MEMBRE	2024-01-02 00:00:00	\N	\N	\N	\N	\N	\N	34311	\N	\N	\N
41186	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34321	\N	\N	\N
41341	VICPDT	2024-02-28 00:00:00	\N	\N	\N	\N	\N	\N	34182	\N	\N	\N
30537	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26313	\N	\N	\N
30539	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26315	\N	\N	\N
30543	MEMBRE	2017-10-01 00:00:00	2018-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	26319	\N	\N	\N
30647	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26348	\N	\N	\N
30662	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26363	\N	\N	\N
30667	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26368	\N	\N	\N
30926	VICPDT	2018-02-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	26096	\N	\N	\N
30930	VICPDT	2018-02-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	26108	\N	\N	\N
31278	VICPDT	2018-05-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26139	\N	\N	\N
31279	VICPDT	2018-05-07 00:00:00	2018-05-07 00:00:00	ANCIEN	\N	\N	\N	\N	26140	\N	\N	\N
31297	MEMBRE	2018-05-22 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26766	\N	2018-05-29 09:39:04	\N
31349	MEMBRE	2018-09-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26811	\N	\N	\N
31363	MEMBRE	2018-09-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26825	\N	\N	\N
31365	MEMBRE	2018-09-24 00:00:00	2020-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	26827	\N	\N	\N
31403	MEMBRE	2018-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26864	\N	\N	\N
31471	VICPDT	2018-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26841	\N	\N	\N
31615	MEMBRE	2019-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27050	\N	\N	\N
32283	MEMBRE	2020-10-14 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	27712	\N	\N	\N
32284	MEMBRE	2020-10-14 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	27713	\N	\N	\N
32285	MEMBRE	2020-10-14 00:00:00	2020-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	27714	\N	\N	\N
32286	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27715	\N	\N	\N
33449	MEMBRE	2020-11-09 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	28871	\N	\N	\N
33450	MEMBRE	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28872	\N	\N	\N
33451	MEMBRE	2020-11-09 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	28873	\N	\N	\N
33452	MEMBRE	2020-11-09 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	28874	\N	\N	\N
33453	MEMBRE	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28875	\N	\N	\N
33454	MEMBRE	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28876	\N	\N	\N
33455	MEMBRE	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28877	\N	\N	\N
33456	MEMBRE	2020-11-09 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	28878	\N	\N	\N
33457	MEMBRE	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28879	\N	\N	\N
33458	MEMBRE	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28880	\N	\N	\N
33878	PDTDEL	2020-11-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour Bahreïn	\N	29127	\N	\N	\N
33879	PDTDEL	2020-11-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour le Vénézuéla	\N	29124	\N	\N	\N
33901	MEMBRE	2020-12-01 00:00:00	2021-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	29151	\N	\N	\N
33926	VICPDT	2020-12-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27714	\N	\N	\N
33927	SECRET	2020-12-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27836	\N	\N	\N
33928	VICPDT	2020-12-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27588	\N	\N	\N
33929	VICPDT	2020-12-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28089	\N	\N	\N
33930	VICPDT	2020-12-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27723	\N	\N	\N
33931	SECRET	2020-12-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27727	\N	\N	\N
33932	VICPDT	2020-12-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28252	\N	\N	\N
33933	VICPDT	2020-12-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27307	\N	\N	\N
33934	VICPDT	2020-12-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27937	\N	\N	\N
33935	VICPDT	2020-12-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28350	\N	\N	\N
33936	VICPDT	2020-12-02 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29140	\N	\N	\N
33937	VICPDT	2020-12-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28138	\N	\N	\N
33938	VICPDT	2020-12-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27557	\N	\N	\N
33939	SECRET	2020-12-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28541	\N	\N	\N
33940	VICPDT	2020-12-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27495	\N	\N	\N
33941	VICPDT	2020-12-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27730	\N	\N	\N
33942	SECRET	2020-12-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28432	\N	\N	\N
33943	VICPDT	2020-12-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28149	\N	\N	\N
33944	SECRET	2020-12-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28593	\N	\N	\N
34310	VICPDT	2020-12-16 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	27446	\N	\N	\N
34311	VICPDT	2020-12-16 00:00:00	2023-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	27235	\N	\N	\N
34312	VICPDT	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27609	\N	\N	\N
34313	VICPDT	2020-12-16 00:00:00	2022-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	29176	\N	\N	\N
34314	SECRET	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28066	\N	\N	\N
34315	SECRET	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27932	\N	\N	\N
34316	VICPDT	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27589	\N	\N	\N
34317	VICPDT	2020-12-16 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	28706	\N	\N	\N
34318	VICPDT	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27924	\N	\N	\N
34319	VICPDT	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27202	\N	\N	\N
34320	VICPDT	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28987	\N	\N	\N
34321	SECRET	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29064	\N	\N	\N
34322	SECRET	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28167	\N	\N	\N
34323	MEMBRE	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29283	\N	\N	\N
34324	VICPDT	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28049	\N	\N	\N
34325	VICPDT	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27914	\N	\N	\N
34326	VICPDT	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28990	\N	\N	\N
34327	VICPDT	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27216	\N	\N	\N
34328	VICPDT	2020-12-16 00:00:00	2021-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	28153	\N	\N	\N
34329	SECRET	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27346	\N	\N	\N
34330	SECRET	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27643	\N	\N	\N
34331	SECRET	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28210	\N	\N	\N
34332	VICPDT	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29015	\N	\N	\N
34333	VICPDT	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29118	\N	\N	\N
34334	VICPDT	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28365	\N	\N	\N
34335	VICPDT	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28893	\N	\N	\N
34336	VICPDT	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27641	\N	\N	\N
34337	VICPDT	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27528	\N	\N	\N
34338	SECRET	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29162	\N	\N	\N
34339	SECRET	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27496	\N	\N	\N
34340	SECRET	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29131	\N	\N	\N
34341	VICPDT	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27478	\N	\N	\N
34342	VICPDT	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27610	\N	\N	\N
34343	VICPDT	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28328	\N	\N	\N
34344	VICPDT	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27498	\N	\N	\N
34345	VICPDT	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28248	\N	\N	\N
34346	SECRET	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28523	\N	\N	\N
34454	MEMBRE	2020-12-16 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	29318	\N	\N	\N
34455	MEMBRE	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29319	\N	\N	\N
34606	MEMBRE	2020-12-15 00:00:00	2021-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	29467	\N	\N	\N
34629	MEMBRE	2020-12-15 00:00:00	2021-07-20 00:00:00	ANCIEN	\N	\N	\N	\N	29488	\N	\N	\N
34630	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29489	\N	\N	\N
34631	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29490	\N	\N	\N
34673	MEMBRE	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29513	\N	\N	\N
34674	MEMBRE	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29514	\N	\N	\N
34675	MEMBRE	2020-12-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29515	\N	\N	\N
34676	MEMBRE	2020-12-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29516	\N	\N	\N
34710	MEMBRE	2020-12-23 00:00:00	2021-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	29550	\N	\N	\N
34711	MEMBRE	2020-12-23 00:00:00	2021-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	29551	\N	\N	\N
34751	MEMBRE	2020-12-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	29571	\N	\N	\N
34752	MEMBRE	2020-12-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	29572	\N	\N	\N
34839	MEMBRE	2021-01-07 00:00:00	2021-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	29622	\N	\N	\N
34850	MEMBRE	2021-01-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	29633	\N	\N	\N
35521	VICPDT	2021-01-13 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29586	\N	\N	\N
35594	VICPDT	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29327	\N	\N	\N
35598	VICPDT	2021-02-03 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	30054	\N	\N	\N
35599	PDT	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29749	\N	\N	\N
35600	VICPDT	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29335	\N	\N	\N
35601	PDT	2021-02-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	29765	\N	\N	\N
35602	VICPDT	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29346	\N	\N	\N
35603	VICPDT	2021-02-03 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29604	\N	\N	\N
35604	VICPDT	2021-02-03 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29645	\N	\N	\N
35667	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30143	\N	\N	\N
35864	VICPDT	2021-02-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28160	\N	\N	\N
35865	VICPDT	2021-02-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28668	\N	\N	\N
35866	SECRET	2021-02-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27646	\N	\N	\N
35867	VICPDT	2021-02-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28571	\N	\N	\N
35868	VICPDT	2021-02-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27909	\N	\N	\N
35869	VICPDT	2021-02-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27374	\N	\N	\N
35870	SECRET	2021-02-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28869	\N	\N	\N
36168	MEMBRE	2021-10-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30428	\N	\N	\N
36344	MEMBRE	2022-04-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30571	\N	\N	\N
36345	MEMBRE	2022-04-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30572	\N	\N	\N
36895	MEMBRE	2023-10-09 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	31085	\N	\N	\N
36896	MEMBRE	2023-10-09 00:00:00	2024-01-04 00:00:00	ANCIEN	\N	\N	\N	\N	31086	\N	\N	\N
36897	MEMBRE	2023-10-09 00:00:00	2024-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	31087	\N	\N	\N
36898	MEMBRE	2023-10-09 00:00:00	2024-02-04 00:00:00	ACTIF	\N	\N	\N	\N	31088	\N	\N	\N
36899	MEMBRE	2023-10-09 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	31089	\N	\N	\N
36900	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31090	\N	\N	\N
37053	MEMBRE	2023-10-10 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	31243	\N	\N	\N
37210	MEMBRE	2023-10-10 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	31402	\N	\N	\N
37211	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31403	\N	\N	\N
38897	MEMBRE	2023-11-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33084	\N	\N	\N
39473	MEMBRE	2023-12-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33383	\N	\N	\N
40036	MEMBRE	2024-01-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33613	\N	\N	\N
40261	MEMBRE	2023-10-01 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	33790	\N	\N	\N
40262	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33791	\N	\N	\N
40263	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33792	\N	\N	\N
40264	MEMBRE	2023-10-01 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	33793	\N	\N	\N
40441	MEMBRE	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	\N	33914	\N	\N	\N
40480	MEMBRE	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33953	\N	\N	\N
40529	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34002	\N	\N	\N
40530	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34003	\N	\N	\N
40737	VICPDT	2024-01-23 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	\N	33459	\N	\N	\N
40739	VICPDT	2024-01-23 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	\N	29891	\N	\N	\N
40741	VICPDT	2024-01-23 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	\N	29960	\N	\N	\N
40742	VICPDT	2024-01-23 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	\N	29896	\N	\N	\N
40743	VICPDT	2024-01-23 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	\N	33585	\N	\N	\N
40744	VICPDT	2024-01-23 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	\N	29901	\N	\N	\N
40747	SECRET	2024-01-23 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	\N	29878	\N	\N	\N
40748	SECRET	2024-01-23 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	\N	33450	\N	\N	\N
40762	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34198	\N	\N	\N
40925	VICPDT	2024-01-24 00:00:00	\N	\N	\N	\N	\N	\N	34186	\N	\N	\N
41137	VICPDT	2024-02-07 00:00:00	\N	\N	\N	\N	\N	\N	34158	\N	\N	\N
41216	MEMBRE	2024-02-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34341	\N	\N	\N
30542	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26318	\N	\N	\N
30840	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26511	\N	\N	\N
31005	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26592	\N	\N	\N
31006	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26593	\N	\N	\N
31032	MEMBRE	2018-02-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26613	\N	2018-03-02 11:02:30	\N
31033	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26614	\N	\N	\N
31258	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26743	\N	\N	\N
31323	MEMBRE	2018-07-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	26791	\N	\N	\N
31328	MEMBRE	2018-07-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26793	\N	\N	\N
31329	MEMBRE	2018-07-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26794	\N	\N	\N
31499	MEMBRE	2017-10-01 00:00:00	2020-08-06 00:00:00	ANCIEN	\N	\N	\N	\N	26955	\N	\N	\N
31501	MEMBRE	2017-10-01 00:00:00	2020-08-06 00:00:00	ANCIEN	\N	\N	\N	\N	26957	\N	\N	\N
31673	PDT	2020-09-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24685	\N	\N	\N
31899	MEMBRE	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27328	\N	\N	\N
31900	MEMBRE	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27329	\N	\N	\N
33295	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28728	\N	\N	\N
33296	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28729	\N	\N	\N
33297	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28730	\N	\N	\N
33298	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28731	\N	\N	\N
33299	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28732	\N	\N	\N
33300	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28733	\N	\N	\N
33301	MEMBRE	2020-11-03 00:00:00	2021-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	28734	\N	\N	\N
33302	MEMBRE	2020-11-03 00:00:00	2021-01-11 00:00:00	ANCIEN	\N	\N	\N	\N	28735	\N	\N	\N
33303	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28736	\N	\N	\N
33304	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28737	\N	\N	\N
33305	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28738	\N	\N	\N
33306	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28739	\N	\N	\N
33307	MEMBRE	2020-11-03 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	28740	\N	\N	\N
33308	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28741	\N	\N	\N
33309	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28742	\N	\N	\N
33310	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28743	\N	\N	\N
33311	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28744	\N	\N	\N
33312	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28745	\N	\N	\N
33313	MEMBRE	2020-11-03 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	28746	\N	\N	\N
33314	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28747	\N	\N	\N
33315	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28748	\N	\N	\N
33316	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28749	\N	\N	\N
33317	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28750	\N	\N	\N
33318	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28751	\N	\N	\N
33319	MEMBRE	2020-11-03 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	28752	\N	\N	\N
33320	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28753	\N	\N	\N
33321	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28754	\N	\N	\N
33322	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28755	\N	\N	\N
33323	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28756	\N	\N	\N
33324	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28757	\N	\N	\N
33325	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28758	\N	\N	\N
33326	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28759	\N	\N	\N
33327	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28760	\N	\N	\N
33328	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28761	\N	\N	\N
33329	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28762	\N	\N	\N
33330	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28763	\N	\N	\N
33331	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28764	\N	\N	\N
33332	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28765	\N	\N	\N
33333	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28766	\N	\N	\N
33334	MEMBRE	2020-11-03 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	28767	\N	\N	\N
33335	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28768	\N	\N	\N
33336	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28769	\N	\N	\N
33337	MEMBRE	2020-11-03 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	28770	\N	\N	\N
33338	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28771	\N	\N	\N
33339	MEMBRE	2020-11-03 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	28772	\N	\N	\N
33340	MEMBRE	2020-11-03 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	28773	\N	\N	\N
33341	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28774	\N	\N	\N
33342	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28775	\N	\N	\N
33343	MEMBRE	2020-11-03 00:00:00	2021-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	28776	\N	\N	\N
33344	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28777	\N	\N	\N
33345	MEMBRE	2020-11-03 00:00:00	2020-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	28778	\N	\N	\N
33480	MEMBRE	2020-11-10 00:00:00	2020-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	28902	\N	\N	\N
34022	VICPDT	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28459	\N	\N	\N
33836	MEMBRE	2020-11-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29098	\N	\N	\N
33964	MEMBRE	2020-12-03 00:00:00	2020-12-23 00:00:00	ANCIEN	\N	\N	\N	\N	29177	\N	\N	\N
34023	VICPDT	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27972	\N	\N	\N
34024	VICPDT	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27195	\N	\N	\N
34025	VICPDT	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28544	\N	\N	\N
34026	VICPDT	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28860	\N	\N	\N
34027	VICPDT	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27744	\N	\N	\N
34028	VICPDT	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28538	\N	\N	\N
34029	SECRET	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27489	\N	\N	\N
34030	SECRET	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27154	\N	\N	\N
34031	SECRET	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28693	\N	\N	\N
34032	SECRET	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28341	\N	\N	\N
34433	MEMBRE	2020-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29305	\N	\N	\N
34034	MEMBRE	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29192	\N	\N	\N
34435	MEMBRE	2020-12-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	29307	\N	\N	\N
34456	MEMBRE	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29320	\N	\N	\N
34457	MEMBRE	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29321	\N	\N	\N
34460	MEMBRE	2020-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29324	\N	\N	\N
34461	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29325	\N	\N	\N
34462	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29326	\N	\N	\N
34515	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29379	\N	\N	\N
34626	MEMBRE	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29485	\N	\N	\N
34656	VICPDT	2020-12-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28526	\N	\N	\N
34657	VICPDT	2020-12-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27270	\N	\N	\N
34658	VICPDT	2020-12-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28695	\N	\N	\N
34659	VICPDT	2020-12-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28342	\N	\N	\N
34660	VICPDT	2020-12-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28197	\N	\N	\N
34661	VICPDT	2020-12-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28478	\N	\N	\N
34662	SECRET	2020-12-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28191	\N	\N	\N
34663	MEMBRE	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29512	\N	\N	\N
34906	MEMBRE	2020-12-18 00:00:00	2021-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	29671	\N	\N	\N
34911	MEMBRE	2021-01-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29676	\N	\N	\N
35007	MEMBRE	2021-01-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	29755	\N	\N	\N
35093	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29817	\N	\N	\N
35107	MEMBRE	2020-10-01 00:00:00	2021-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	29831	\N	\N	\N
35111	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29835	\N	\N	\N
35112	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29836	\N	\N	\N
35155	MEMBRE	2020-10-01 00:00:00	2021-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	29879	\N	\N	\N
35156	MEMBRE	2020-10-01 00:00:00	2021-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	29880	\N	\N	\N
35159	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29883	\N	\N	\N
35160	MEMBRE	2020-10-01 00:00:00	2021-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	29884	\N	\N	\N
35161	MEMBRE	2020-10-01 00:00:00	2021-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	29885	\N	\N	\N
35162	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29886	\N	\N	\N
35163	MEMBRE	2020-10-01 00:00:00	2021-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	29887	\N	\N	\N
35164	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29888	\N	\N	\N
35166	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29890	\N	\N	\N
35167	MEMBRE	2020-10-01 00:00:00	2024-01-22 00:00:00	ACTIF	\N	\N	\N	\N	29891	\N	\N	\N
35168	MEMBRE	2020-10-01 00:00:00	2021-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	29892	\N	\N	\N
35169	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29893	\N	\N	\N
35170	MEMBRE	2020-10-01 00:00:00	2021-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	29894	\N	\N	\N
35172	MEMBRE	2020-10-01 00:00:00	2021-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	29896	\N	\N	\N
35191	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29915	\N	\N	\N
35203	MEMBRE	2020-10-01 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	29927	\N	\N	\N
35208	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29932	\N	\N	\N
35503	MEMBRE	2021-01-19 00:00:00	2021-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	30068	\N	\N	\N
35841	VICPDT	2021-02-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	29848	\N	\N	\N
35923	MEMBRE	2021-03-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30235	\N	\N	\N
35985	MEMBRE	2020-10-01 00:00:00	2021-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	30282	\N	\N	\N
36093	MEMBRE	2021-06-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	30367	\N	\N	\N
36104	MEMBRE	2021-07-20 00:00:00	2021-07-20 00:00:00	ANCIEN	\N	\N	\N	\N	30377	\N	\N	\N
36191	MEMBRE	2021-10-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	30443	\N	\N	\N
36225	MEMBRE	2021-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30470	\N	\N	\N
36226	MEMBRE	2021-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30471	\N	\N	\N
36307	MEMBRE	2022-03-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30535	\N	\N	\N
36349	MEMBRE	2022-04-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30576	\N	\N	\N
36401	MEMBRE	2022-05-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	30619	\N	\N	\N
36418	MEMBRE	2022-05-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30635	\N	\N	\N
36587	MEMBRE	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30793	\N	\N	\N
36777	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30967	\N	\N	\N
36778	MEMBRE	2023-10-09 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	30968	\N	\N	\N
38382	MEMBRE	2023-10-31 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	32577	\N	\N	\N
39976	MEMBRE	2024-01-17 00:00:00	2024-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	33575	\N	\N	\N
39997	MEMBRE	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33582	\N	\N	\N
40445	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33918	\N	\N	\N
40447	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33920	\N	\N	\N
40448	MEMBRE	2023-10-01 00:00:00	2024-02-13 00:00:00	ACTIF	\N	\N	\N	\N	33921	\N	\N	\N
40450	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33923	\N	\N	\N
40634	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34107	\N	\N	\N
40635	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34108	\N	\N	\N
40723	MEMBRE	2023-10-01 00:00:00	2024-02-27 00:00:00	ACTIF	\N	\N	\N	\N	34182	\N	\N	\N
40735	PDT	2024-01-23 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	\N	29937	\N	\N	\N
40749	SECRET	2024-01-23 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	\N	30204	\N	\N	\N
40761	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34197	\N	\N	\N
41213	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34338	\N	\N	\N
41214	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34339	\N	\N	\N
30548	MEMBRE	2018-01-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26324	\N	2018-02-07 11:00:01	\N
30549	MEMBRE	2018-02-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26325	\N	2018-02-07 11:00:12	\N
30550	MEMBRE	2018-02-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26326	\N	2018-02-07 11:03:33	\N
30551	MEMBRE	2018-02-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26327	\N	2018-02-07 11:04:49	\N
30821	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26492	\N	\N	\N
30901	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26537	\N	\N	\N
31061	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26615	\N	\N	\N
31241	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26734	\N	\N	\N
31294	MEMBRE	2018-05-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26763	\N	2018-05-22 15:34:30	\N
31341	MEMBRE	2018-09-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26803	\N	\N	\N
31342	MEMBRE	2018-09-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26804	\N	\N	\N
31531	MEMBRE	2019-02-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	26983	\N	\N	\N
31639	MEMBRE	2020-01-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27071	\N	\N	\N
31640	MEMBRE	2020-01-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27072	\N	\N	\N
31641	MEMBRE	2020-01-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27073	\N	\N	\N
31642	MEMBRE	2020-01-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27074	\N	\N	\N
32325	MEMBRE	2020-10-13 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	27754	\N	\N	\N
32761	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28194	\N	\N	\N
32762	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28195	\N	\N	\N
32763	MEMBRE	2020-10-18 00:00:00	2021-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	28196	\N	\N	\N
32764	MEMBRE	2020-10-18 00:00:00	2020-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	28197	\N	\N	\N
32765	MEMBRE	2020-10-18 00:00:00	2020-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	28198	\N	\N	\N
32766	MEMBRE	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28199	\N	\N	\N
32772	MEMBRE	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28205	\N	\N	\N
32773	MEMBRE	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28206	\N	\N	\N
32774	MEMBRE	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28207	\N	\N	\N
32775	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28208	\N	\N	\N
32776	MEMBRE	2020-10-16 00:00:00	2021-01-11 00:00:00	ANCIEN	\N	\N	\N	\N	28209	\N	\N	\N
32777	MEMBRE	2020-10-16 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	28210	\N	\N	\N
32778	MEMBRE	2020-10-20 00:00:00	2021-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	28211	\N	\N	\N
32779	MEMBRE	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28212	\N	\N	\N
32780	MEMBRE	2020-10-20 00:00:00	2021-01-21 00:00:00	ANCIEN	\N	\N	\N	\N	28213	\N	\N	\N
32781	MEMBRE	2020-10-21 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	28214	\N	\N	\N
32782	MEMBRE	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28215	\N	\N	\N
32783	MEMBRE	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28216	\N	\N	\N
32784	MEMBRE	2020-10-18 00:00:00	2020-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	28217	\N	\N	\N
32785	MEMBRE	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28218	\N	\N	\N
32786	MEMBRE	2020-10-18 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	28219	\N	\N	\N
32787	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28220	\N	\N	\N
32788	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28221	\N	\N	\N
32789	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28222	\N	\N	\N
32790	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28223	\N	\N	\N
32791	MEMBRE	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28224	\N	\N	\N
32792	MEMBRE	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28225	\N	\N	\N
32793	MEMBRE	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28226	\N	\N	\N
33853	MEMBRE	2020-11-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29105	\N	\N	\N
33852	PDTDEL	2020-11-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour le Soudan du Sud	\N	29104	\N	\N	\N
33854	MEMBRE	2020-11-23 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29106	\N	\N	\N
33855	MEMBRE	2020-11-25 00:00:00	2021-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	29107	\N	\N	\N
33987	VICPDT	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27219	\N	\N	\N
33988	VICPDT	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28948	\N	\N	\N
33989	SECRET	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28945	\N	\N	\N
33990	VICPDT	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27693	\N	\N	\N
33991	VICPDT	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28343	\N	\N	\N
33992	VICPDT	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27960	\N	\N	\N
33993	VICPDT	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27804	\N	\N	\N
33994	VICPDT	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27854	\N	\N	\N
33995	VICPDT	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28305	\N	\N	\N
33996	VICPDT	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28850	\N	\N	\N
33997	VICPDT	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28187	\N	\N	\N
33998	VICPDT	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28680	\N	\N	\N
33999	SECRET	2020-12-08 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	27450	\N	\N	\N
34000	SECRET	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27401	\N	\N	\N
34001	SECRET	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27281	\N	\N	\N
34002	SECRET	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28883	\N	\N	\N
34003	SECRET	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28250	\N	\N	\N
34006	MEMBRE	2020-12-03 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	29183	\N	\N	\N
34288	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29269	\N	\N	\N
34290	MEMBRE	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29271	\N	\N	\N
34474	MEMBRE	2020-12-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	29338	\N	\N	\N
34475	MEMBRE	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29339	\N	\N	\N
34476	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29340	\N	\N	\N
34477	MEMBRE	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29341	\N	\N	\N
34503	MEMBRE	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29367	\N	\N	\N
34563	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29427	\N	\N	\N
34564	MEMBRE	2020-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29428	\N	\N	\N
34565	MEMBRE	2020-12-16 00:00:00	2021-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	29429	\N	\N	\N
34930	MEMBRE	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29695	\N	\N	\N
34968	MEMBRE	2021-01-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	29724	\N	\N	\N
35221	MEMBRE	2021-01-14 00:00:00	2021-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	29945	\N	\N	\N
35222	MEMBRE	2021-01-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	29946	\N	\N	\N
35252	PDT	2021-01-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	29646	\N	\N	\N
35253	VICPDT	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29496	\N	\N	\N
35254	VICPDT	2021-01-20 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29361	\N	\N	\N
35256	VICPDT	2021-01-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	29362	\N	\N	\N
35304	MEMBRE	2021-01-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	29974	\N	\N	\N
35441	MEMBRE	2021-01-25 00:00:00	2021-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	30058	\N	\N	\N
35535	MEMBRE	2021-01-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	30073	\N	\N	\N
35582	VICPDT	2021-01-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29647	\N	\N	\N
35654	MEMBRE	2021-02-03 00:00:00	2021-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	30139	\N	\N	\N
35803	MEMBRE	2021-02-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30189	\N	\N	\N
35824	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30200	\N	\N	\N
35916	MEMBRE	2021-03-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	30228	\N	\N	\N
35917	MEMBRE	2021-03-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	30229	\N	\N	\N
35945	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30248	\N	\N	\N
36081	MEMBRE	2021-06-22 00:00:00	2021-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	30362	\N	\N	\N
36131	MEMBRE	2021-09-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	30393	\N	\N	\N
36255	MEMBRE	2021-12-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30499	\N	\N	\N
36273	MEMBRE	2022-01-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30512	\N	\N	\N
36274	VICPDT	2022-01-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28262	\N	\N	\N
36275	VICPDT	2022-01-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27505	\N	\N	\N
36276	VICPDT	2022-01-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27483	\N	\N	\N
36277	VICPDT	2022-01-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28418	\N	\N	\N
36339	MEMBRE	2022-03-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30566	\N	\N	\N
36374	MEMBRE	2022-04-01 00:00:00	2022-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	30600	\N	\N	\N
36430	MEMBRE	2022-06-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30647	\N	\N	\N
36500	MEMBRE	2022-12-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30717	\N	\N	\N
36593	MEMBRE	2023-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30799	\N	\N	\N
36735	MEMBRE	2023-10-08 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	30925	\N	\N	\N
36736	MEMBRE	2023-10-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30926	\N	\N	\N
36737	MEMBRE	2023-10-08 00:00:00	2023-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	30927	\N	\N	\N
36837	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31027	\N	\N	\N
36849	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31039	\N	\N	\N
36850	MEMBRE	2023-10-09 00:00:00	2024-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	31040	\N	\N	\N
36851	MEMBRE	2023-10-09 00:00:00	2023-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	31041	\N	\N	\N
36852	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31042	\N	\N	\N
36853	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31043	\N	\N	\N
36854	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31044	\N	\N	\N
36855	MEMBRE	2023-10-09 00:00:00	2024-01-30 00:00:00	ACTIF	\N	\N	\N	\N	31045	\N	\N	\N
36856	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31046	\N	\N	\N
36857	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31047	\N	\N	\N
36858	MEMBRE	2023-10-09 00:00:00	2024-02-08 00:00:00	ACTIF	\N	\N	\N	\N	31048	\N	\N	\N
36859	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31049	\N	\N	\N
36860	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31050	\N	\N	\N
36861	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31051	\N	\N	\N
36862	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31052	\N	\N	\N
36863	MEMBRE	2023-10-09 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	31053	\N	\N	\N
36864	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31054	\N	\N	\N
36865	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31055	\N	\N	\N
36866	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31056	\N	\N	\N
36867	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31057	\N	\N	\N
36868	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31058	\N	\N	\N
36869	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31059	\N	\N	\N
36870	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31060	\N	\N	\N
36871	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31061	\N	\N	\N
36872	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31062	\N	\N	\N
38167	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32362	\N	\N	\N
40446	MEMBRE	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	\N	33919	\N	\N	\N
40449	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33922	\N	\N	\N
40452	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33925	\N	\N	\N
40453	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33926	\N	\N	\N
40807	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	34223	\N	\N	\N
40883	PDT	2024-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	30728	\N	\N	\N
40890	VICPDT	2024-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	30734	\N	\N	\N
40891	PDT	2024-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	33569	\N	\N	\N
40895	VICPDT	2024-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	33561	\N	\N	\N
40900	VICPDT	2024-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	30756	\N	\N	\N
41082	VICPDT	2024-02-06 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31341	\N	\N	\N
41083	VICPDT	2024-02-06 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31382	\N	\N	\N
41084	VICPDT	2024-02-06 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	33317	\N	\N	\N
41085	VICPDT	2024-02-06 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32815	\N	\N	\N
41086	SECRET	2024-02-06 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	33096	\N	\N	\N
41107	VICPDT	2024-02-07 00:00:00	\N	\N	\N	\N	\N	\N	33632	\N	\N	\N
41230	MEMBRE	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	34345	\N	\N	\N
41348	VICPDT	2024-02-28 00:00:00	\N	\N	\N	\N	\N	\N	34025	\N	\N	\N
41367	MEMBRE	2023-12-14 00:00:00	\N	\N	\N	\N	\N	\N	34369	\N	\N	\N
41501	VICPDT	2024-03-20 00:00:00	2026-10-31 00:00:00	\N	\N	\N	\N	\N	34108	\N	\N	\N
30546	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26322	\N	\N	\N
30822	MEMBRE	2017-10-01 00:00:00	2018-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	26493	\N	\N	\N
30919	VICPDT	2018-02-15 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26520	\N	\N	\N
31248	MEMBRE	2018-03-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26738	\N	2018-04-05 10:10:00	\N
31249	MEMBRE	2018-04-03 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26739	\N	2018-04-05 10:10:14	\N
31259	MEMBRE	2018-04-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26744	\N	2018-04-11 09:28:53	\N
31291	MEMBRE	2018-05-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	26760	\N	\N	\N
31368	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26830	\N	\N	\N
31375	MEMBRE	2018-10-03 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26837	\N	\N	\N
31581	MEMBRE	2019-06-21 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	27025	\N	\N	\N
33952	MEMBRE	2020-12-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29172	\N	\N	\N
34560	MEMBRE	2020-12-17 00:00:00	2021-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	29424	\N	\N	\N
34713	MEMBRE	2020-12-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29553	\N	\N	\N
34820	MEMBRE	2021-01-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	29603	\N	\N	\N
34821	MEMBRE	2021-01-05 00:00:00	2021-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	29604	\N	\N	\N
35078	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29802	\N	\N	\N
35079	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29803	\N	\N	\N
35087	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29811	\N	\N	\N
35098	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29822	\N	\N	\N
35101	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29825	\N	\N	\N
35102	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29826	\N	\N	\N
35103	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29827	\N	\N	\N
35104	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29828	\N	\N	\N
35105	MEMBRE	2020-10-01 00:00:00	2021-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	29829	\N	\N	\N
35219	MEMBRE	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29943	\N	\N	\N
35422	MEMBRE	2020-10-01 00:00:00	2021-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	30046	\N	\N	\N
35460	VICPDT	2021-01-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	29567	\N	\N	\N
35462	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30061	\N	\N	\N
35505	MEMBRE	2021-01-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	30069	\N	\N	\N
35664	VICPDT	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30139	\N	\N	\N
36051	MEMBRE	2021-05-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30332	\N	\N	\N
36309	MEMBRE	2022-03-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30537	\N	\N	\N
36310	MEMBRE	2022-03-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30538	\N	\N	\N
36311	MEMBRE	2022-03-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30539	\N	\N	\N
36312	MEMBRE	2022-03-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30540	\N	\N	\N
36313	MEMBRE	2022-03-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30541	\N	\N	\N
36314	MEMBRE	2022-03-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30542	\N	\N	\N
36315	MEMBRE	2022-03-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30543	\N	\N	\N
36316	MEMBRE	2022-03-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30544	\N	\N	\N
36317	MEMBRE	2022-03-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30545	\N	\N	\N
36318	MEMBRE	2022-03-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30546	\N	\N	\N
36319	MEMBRE	2022-03-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30547	\N	\N	\N
36540	MEMBRE	2023-01-01 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	\N	30757	\N	\N	\N
36575	VICPDT	2023-01-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30752	\N	\N	\N
36578	VICPDT	2023-01-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30735	\N	\N	\N
36580	VICPDT	2023-01-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30744	\N	\N	\N
36582	VICPDT	2023-01-25 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	30784	\N	\N	\N
36779	MEMBRE	2023-10-09 00:00:00	2023-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	30969	\N	\N	\N
36780	MEMBRE	2023-10-09 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	30970	\N	\N	\N
36781	MEMBRE	2023-10-09 00:00:00	2024-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	30971	\N	\N	\N
37094	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31284	\N	\N	\N
37095	MEMBRE	2023-10-10 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	31285	\N	\N	\N
37116	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31306	\N	\N	\N
37149	MEMBRE	2023-10-10 00:00:00	2024-02-05 00:00:00	ACTIF	\N	\N	\N	\N	31341	\N	\N	\N
37150	MEMBRE	2023-10-10 00:00:00	2024-02-13 00:00:00	ACTIF	\N	\N	\N	\N	31342	\N	\N	\N
37151	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31343	\N	\N	\N
37152	MEMBRE	2023-10-10 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	31344	\N	\N	\N
37153	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31345	\N	\N	\N
37154	MEMBRE	2023-10-10 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	31346	\N	\N	\N
37155	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31347	\N	\N	\N
37156	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31348	\N	\N	\N
37157	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31349	\N	\N	\N
37158	MEMBRE	2023-10-10 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	31350	\N	\N	\N
37162	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31354	\N	\N	\N
37163	MEMBRE	2023-10-10 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	31355	\N	\N	\N
37164	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31356	\N	\N	\N
37165	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31357	\N	\N	\N
37234	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31426	\N	\N	\N
37235	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31427	\N	\N	\N
37236	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31428	\N	\N	\N
37249	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31441	\N	\N	\N
37250	MEMBRE	2023-10-11 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	31442	\N	\N	\N
37260	MEMBRE	2023-10-11 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	31452	\N	\N	\N
37261	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31453	\N	\N	\N
37476	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31668	\N	\N	\N
37477	MEMBRE	2023-10-13 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	31669	\N	\N	\N
37478	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31670	\N	\N	\N
37479	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31671	\N	\N	\N
37480	MEMBRE	2023-10-13 00:00:00	2024-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	31672	\N	\N	\N
37481	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31673	\N	\N	\N
37482	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31674	\N	\N	\N
37483	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31675	\N	\N	\N
37484	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31676	\N	\N	\N
37485	MEMBRE	2023-10-13 00:00:00	2024-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	31677	\N	\N	\N
37486	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31678	\N	\N	\N
37487	MEMBRE	2023-10-13 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	31679	\N	\N	\N
37488	MEMBRE	2023-10-13 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	31680	\N	\N	\N
37744	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31936	\N	\N	\N
37878	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32070	\N	\N	\N
37879	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32071	\N	\N	\N
37896	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32088	\N	\N	\N
37897	MEMBRE	2023-10-18 00:00:00	2024-01-25 00:00:00	ACTIF	\N	\N	\N	\N	32089	\N	\N	\N
37898	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32090	\N	\N	\N
37899	MEMBRE	2023-10-18 00:00:00	2024-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	32091	\N	\N	\N
37900	MEMBRE	2023-10-18 00:00:00	2024-01-29 00:00:00	ACTIF	\N	\N	\N	\N	32092	\N	\N	\N
37901	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32093	\N	\N	\N
37902	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32094	\N	\N	\N
37903	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32095	\N	\N	\N
37904	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32096	\N	\N	\N
37905	MEMBRE	2023-10-18 00:00:00	2024-01-25 00:00:00	ACTIF	\N	\N	\N	\N	32097	\N	\N	\N
37906	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32098	\N	\N	\N
37907	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32099	\N	\N	\N
37908	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32100	\N	\N	\N
37909	MEMBRE	2023-10-18 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	32101	\N	\N	\N
37972	MEMBRE	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32167	\N	\N	\N
37973	MEMBRE	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32168	\N	\N	\N
37974	MEMBRE	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32169	\N	\N	\N
37980	MEMBRE	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32175	\N	\N	\N
37981	MEMBRE	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32176	\N	\N	\N
37984	MEMBRE	2023-10-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32179	\N	\N	\N
37985	MEMBRE	2023-10-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32180	\N	\N	\N
37986	MEMBRE	2023-10-20 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	32181	\N	\N	\N
38005	MEMBRE	2023-10-22 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32200	\N	\N	\N
38145	MEMBRE	2023-10-25 00:00:00	2024-01-28 00:00:00	ACTIF	\N	\N	\N	\N	32340	\N	\N	\N
38146	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32341	\N	\N	\N
38147	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32342	\N	\N	\N
38148	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32343	\N	\N	\N
38149	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32344	\N	\N	\N
38153	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32348	\N	\N	\N
38168	MEMBRE	2023-10-25 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	32363	\N	\N	\N
38201	MEMBRE	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32396	\N	\N	\N
38202	MEMBRE	2023-10-26 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	32397	\N	\N	\N
38203	MEMBRE	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32398	\N	\N	\N
38204	MEMBRE	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32399	\N	\N	\N
38205	MEMBRE	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32400	\N	\N	\N
38206	MEMBRE	2023-10-26 00:00:00	2023-10-31 00:00:00	ANCIEN	\N	\N	\N	\N	32401	\N	\N	\N
38207	MEMBRE	2023-10-26 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	32402	\N	\N	\N
38208	MEMBRE	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32403	\N	\N	\N
38209	MEMBRE	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32404	\N	\N	\N
38210	MEMBRE	2023-10-26 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	32405	\N	\N	\N
38211	MEMBRE	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32406	\N	\N	\N
38212	MEMBRE	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32407	\N	\N	\N
38229	MEMBRE	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32424	\N	\N	\N
38273	MEMBRE	2023-10-31 00:00:00	2024-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	32468	\N	\N	\N
38274	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32469	\N	\N	\N
38275	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32470	\N	\N	\N
38276	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32471	\N	\N	\N
38386	MEMBRE	2023-10-31 00:00:00	2024-02-27 00:00:00	ACTIF	\N	\N	\N	\N	32581	\N	\N	\N
39699	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33438	\N	\N	\N
39700	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33439	\N	\N	\N
39701	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33440	\N	\N	\N
39702	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33441	\N	\N	\N
39974	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33573	\N	\N	\N
40404	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33877	\N	\N	\N
40405	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33878	\N	\N	\N
30804	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26475	\N	\N	\N
30805	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26476	\N	\N	\N
30845	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26516	\N	\N	\N
31089	SECRET	2018-03-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	26583	\N	\N	\N
31091	VICPDT	2018-03-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	26571	\N	\N	\N
31369	MEMBRE	2018-10-03 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26831	\N	\N	\N
31370	MEMBRE	2018-10-03 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26832	\N	\N	\N
31371	MEMBRE	2018-10-03 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26833	\N	\N	\N
31372	MEMBRE	2018-10-03 00:00:00	2020-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	26834	\N	\N	\N
31373	MEMBRE	2018-10-03 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26835	\N	\N	\N
31432	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26893	\N	\N	\N
31468	MEMBRE	2018-01-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26929	\N	\N	\N
31473	MEMBRE	2018-12-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26931	\N	\N	\N
31574	MEMBRE	2019-05-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	27021	\N	\N	\N
31575	MEMBRE	2019-05-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	27022	\N	\N	\N
31590	MEMBRE	2019-09-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	27032	\N	\N	\N
31591	MEMBRE	2019-09-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	27033	\N	\N	\N
32016	MEMBRE	2020-10-07 00:00:00	2020-12-23 00:00:00	ANCIEN	\N	\N	\N	\N	27445	\N	\N	\N
32017	MEMBRE	2020-10-07 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	27446	\N	\N	\N
32018	MEMBRE	2020-10-07 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	27447	\N	\N	\N
32019	MEMBRE	2020-10-07 00:00:00	2020-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	27448	\N	\N	\N
32020	MEMBRE	2020-10-07 00:00:00	2021-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	27449	\N	\N	\N
32021	MEMBRE	2020-10-07 00:00:00	2020-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	27450	\N	\N	\N
32022	MEMBRE	2020-10-07 00:00:00	2020-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	27451	\N	\N	\N
32023	MEMBRE	2020-10-07 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	27452	\N	\N	\N
33856	MEMBRE	2020-11-25 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	29108	\N	\N	\N
34193	MEMBRE	2020-12-10 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	29242	\N	\N	\N
34194	MEMBRE	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29243	\N	\N	\N
34195	MEMBRE	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29244	\N	\N	\N
34196	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27397	\N	\N	\N
34197	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29009	\N	\N	\N
34198	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27261	\N	\N	\N
34199	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27713	\N	\N	\N
34200	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27674	\N	\N	\N
34201	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28074	\N	\N	\N
34202	SECRET	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28133	\N	\N	\N
34203	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28767	\N	\N	\N
34204	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28842	\N	\N	\N
34205	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27586	\N	\N	\N
34206	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28853	\N	\N	\N
34207	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27950	\N	\N	\N
34208	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28534	\N	\N	\N
34209	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27638	\N	\N	\N
34210	SECRET	2020-12-15 00:00:00	2022-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	27626	\N	\N	\N
34211	SECRET	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28065	\N	\N	\N
34219	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27884	\N	\N	\N
34220	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27754	\N	\N	\N
34221	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28537	\N	\N	\N
34222	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27340	\N	\N	\N
34223	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27347	\N	\N	\N
34224	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28147	\N	\N	\N
34225	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28321	\N	\N	\N
34226	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28325	\N	\N	\N
34227	VICPDT	2020-12-15 00:00:00	2022-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	29034	\N	\N	\N
34228	SECRET	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28665	\N	\N	\N
34229	SECRET	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27441	\N	\N	\N
34230	MEMBRE	2020-12-15 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	29245	\N	\N	\N
34250	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27314	\N	\N	\N
34251	VICPDT	2020-12-15 00:00:00	2021-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	27874	\N	\N	\N
34252	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27634	\N	\N	\N
34253	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28819	\N	\N	\N
34254	VICPDT	2020-12-15 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	27452	\N	\N	\N
34255	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27308	\N	\N	\N
34256	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27427	\N	\N	\N
34257	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28674	\N	\N	\N
34258	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27482	\N	\N	\N
34259	VICPDT	2020-12-15 00:00:00	2023-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	27378	\N	\N	\N
34260	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28822	\N	\N	\N
34261	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28299	\N	\N	\N
34262	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28146	\N	\N	\N
34263	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27499	\N	\N	\N
34264	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27721	\N	\N	\N
34265	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27185	\N	\N	\N
34266	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27515	\N	\N	\N
34267	SECRET	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27570	\N	\N	\N
34268	SECRET	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27223	\N	\N	\N
34269	SECRET	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27765	\N	\N	\N
34270	SECRET	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27672	\N	\N	\N
34271	SECRET	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28351	\N	\N	\N
34272	SECRET	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28485	\N	\N	\N
34273	SECRET	2020-12-15 00:00:00	2021-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	28873	\N	\N	\N
34274	MEMBRE	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29265	\N	\N	\N
34835	MEMBRE	2021-01-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	29618	\N	\N	\N
34837	MEMBRE	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29620	\N	\N	\N
35113	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29837	\N	\N	\N
35119	MEMBRE	2020-10-01 00:00:00	2021-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	29843	\N	\N	\N
35459	PDT	2021-01-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	29419	\N	\N	\N
35472	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30062	\N	\N	\N
35474	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30064	\N	\N	\N
35475	VICPDT	2021-01-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	29413	\N	\N	\N
35476	VICPDT	2021-01-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	29423	\N	\N	\N
35513	VICPDT	2021-01-13 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29718	\N	\N	\N
35779	MEMBRE	2020-10-01 00:00:00	2021-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	30173	\N	\N	\N
35780	MEMBRE	2020-10-01 00:00:00	2021-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	30174	\N	\N	\N
35851	VICPDT	2021-02-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29896	\N	\N	\N
35852	VICPDT	2021-02-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29901	\N	\N	\N
35853	VICPDT	2021-02-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	30203	\N	\N	\N
35854	SECRET	2021-02-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	30046	\N	\N	\N
35892	MEMBRE	2021-02-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30216	\N	\N	\N
35895	MEMBRE	2021-03-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30219	\N	\N	\N
36014	MEMBRE	2021-03-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30311	\N	\N	\N
36329	MEMBRE	2022-03-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30556	\N	\N	\N
36330	MEMBRE	2022-03-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30557	\N	\N	\N
36331	MEMBRE	2022-03-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30558	\N	\N	\N
36368	MEMBRE	2022-04-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30595	\N	\N	\N
36369	MEMBRE	2022-04-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30596	\N	\N	\N
36442	MEMBRE	2022-09-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30659	\N	\N	\N
36503	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30720	\N	\N	\N
36509	MEMBRE	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30726	\N	\N	\N
36522	MEMBRE	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30739	\N	\N	\N
36560	MEMBRE	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30777	\N	\N	\N
36586	MEMBRE	2023-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30792	\N	\N	\N
36753	MEMBRE	2023-10-09 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	30943	\N	\N	\N
37186	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31378	\N	\N	\N
37187	MEMBRE	2023-10-10 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	31379	\N	\N	\N
37188	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31380	\N	\N	\N
37189	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31381	\N	\N	\N
37190	MEMBRE	2023-10-10 00:00:00	2024-02-05 00:00:00	ACTIF	\N	\N	\N	\N	31382	\N	\N	\N
37191	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31383	\N	\N	\N
37192	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31384	\N	\N	\N
37193	MEMBRE	2023-10-10 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	31385	\N	\N	\N
37194	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31386	\N	\N	\N
37195	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31387	\N	\N	\N
37196	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31388	\N	\N	\N
37197	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31389	\N	\N	\N
37198	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31390	\N	\N	\N
37199	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31391	\N	\N	\N
37200	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31392	\N	\N	\N
37201	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31393	\N	\N	\N
37202	MEMBRE	2023-10-10 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	31394	\N	\N	\N
37203	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31395	\N	\N	\N
37204	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31396	\N	\N	\N
37205	MEMBRE	2023-10-10 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	31397	\N	\N	\N
37206	MEMBRE	2023-10-10 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	31398	\N	\N	\N
37207	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31399	\N	\N	\N
37212	MEMBRE	2023-10-10 00:00:00	2023-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	31404	\N	\N	\N
37213	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31405	\N	\N	\N
37214	MEMBRE	2023-10-10 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	31406	\N	\N	\N
38136	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32331	\N	\N	\N
38137	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32332	\N	\N	\N
38138	MEMBRE	2023-10-25 00:00:00	2024-02-08 00:00:00	ACTIF	\N	\N	\N	\N	32333	\N	\N	\N
38139	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32334	\N	\N	\N
38140	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32335	\N	\N	\N
38304	MEMBRE	2023-10-31 00:00:00	2024-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	32499	\N	\N	\N
38345	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32540	\N	\N	\N
38346	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32541	\N	\N	\N
38347	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32542	\N	\N	\N
38348	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32543	\N	\N	\N
38349	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32544	\N	\N	\N
38350	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32545	\N	\N	\N
38351	MEMBRE	2023-10-31 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	32546	\N	\N	\N
38352	MEMBRE	2023-10-31 00:00:00	2023-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	32547	\N	\N	\N
38353	MEMBRE	2023-10-31 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	32548	\N	\N	\N
38354	MEMBRE	2023-10-31 00:00:00	2023-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	32549	\N	\N	\N
38355	MEMBRE	2023-10-31 00:00:00	2024-01-30 00:00:00	ACTIF	\N	\N	\N	\N	32550	\N	\N	\N
38356	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32551	\N	\N	\N
38357	MEMBRE	2023-10-31 00:00:00	2023-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	32552	\N	\N	\N
38358	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32553	\N	\N	\N
38359	MEMBRE	2023-10-31 00:00:00	2024-02-08 00:00:00	ACTIF	\N	\N	\N	\N	32554	\N	\N	\N
38360	MEMBRE	2023-10-31 00:00:00	2023-12-11 00:00:00	ANCIEN	\N	\N	\N	\N	32555	\N	\N	\N
38361	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32556	\N	\N	\N
38362	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32557	\N	\N	\N
38363	MEMBRE	2023-10-31 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	32558	\N	\N	\N
38364	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32559	\N	\N	\N
38365	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32560	\N	\N	\N
38366	MEMBRE	2023-10-31 00:00:00	2024-02-04 00:00:00	ACTIF	\N	\N	\N	\N	32561	\N	\N	\N
38367	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32562	\N	\N	\N
38368	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32563	\N	\N	\N
38369	MEMBRE	2023-10-31 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	32564	\N	\N	\N
38370	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32565	\N	\N	\N
38371	MEMBRE	2023-10-31 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	32566	\N	\N	\N
38561	MEMBRE	2023-11-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32756	\N	\N	\N
38563	MEMBRE	2023-11-07 00:00:00	2024-01-04 00:00:00	ANCIEN	\N	\N	\N	\N	32758	\N	\N	\N
38564	MEMBRE	2023-11-07 00:00:00	2024-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	32759	\N	\N	\N
39661	MEMBRE	2023-12-22 00:00:00	2024-01-29 00:00:00	ACTIF	\N	\N	\N	\N	29786	\N	\N	\N
40028	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33605	\N	\N	\N
40063	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33640	\N	\N	\N
40064	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33641	\N	\N	\N
40454	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33927	\N	\N	\N
40483	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33956	\N	\N	\N
40489	MEMBRE	2023-10-01 00:00:00	2026-06-30 00:00:00	ACTIF	\N	\N	\N	\N	33962	\N	\N	\N
40490	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33963	\N	\N	\N
40650	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34123	\N	\N	\N
40738	VICPDT	2024-01-23 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	\N	29885	\N	\N	\N
40751	SECRET	2024-01-23 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	\N	30151	\N	\N	\N
41412	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34410	\N	\N	\N
41504	VICPDT	2024-03-20 00:00:00	2026-10-31 00:00:00	\N	\N	\N	\N	\N	34104	\N	\N	\N
41505	VICPDT	2024-03-20 00:00:00	2026-10-31 00:00:00	\N	\N	\N	\N	\N	34106	\N	\N	\N
30679	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26380	\N	\N	\N
30823	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26494	\N	\N	\N
30944	VICPDT	2018-02-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	26283	\N	\N	\N
30945	VICPDT	2018-02-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	26293	\N	\N	\N
30946	VICPDT	2018-02-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	26303	\N	\N	\N
30957	MEMBRE	2017-10-01 00:00:00	2018-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	26551	\N	\N	\N
30961	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26555	\N	\N	\N
31083	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26621	\N	\N	\N
31333	MEMBRE	2018-09-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	26798	\N	\N	\N
31360	MEMBRE	2018-09-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26822	\N	\N	\N
31361	MEMBRE	2018-09-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26823	\N	\N	\N
31366	MEMBRE	2018-10-03 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26828	\N	\N	\N
31367	MEMBRE	2018-10-03 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26829	\N	\N	\N
32967	MEMBRE	2020-10-22 00:00:00	2021-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	28400	\N	\N	\N
33073	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28506	\N	\N	\N
33074	MEMBRE	2020-10-27 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	28507	\N	\N	\N
33075	MEMBRE	2020-10-27 00:00:00	2020-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	28508	\N	\N	\N
33076	MEMBRE	2020-10-27 00:00:00	2021-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	28509	\N	\N	\N
33077	MEMBRE	2020-10-27 00:00:00	2023-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	28510	\N	\N	\N
33078	MEMBRE	2020-10-27 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	28511	\N	\N	\N
33079	MEMBRE	2020-10-21 00:00:00	2021-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	28512	\N	\N	\N
33080	MEMBRE	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28513	\N	\N	\N
33081	MEMBRE	2020-10-21 00:00:00	2020-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	28514	\N	\N	\N
33082	MEMBRE	2020-10-21 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	28515	\N	\N	\N
33083	MEMBRE	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28516	\N	\N	\N
33084	MEMBRE	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28517	\N	\N	\N
33085	MEMBRE	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28518	\N	\N	\N
33086	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28519	\N	\N	\N
33087	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28520	\N	\N	\N
33088	MEMBRE	2020-10-27 00:00:00	2023-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	28521	\N	\N	\N
33089	MEMBRE	2020-10-27 00:00:00	2023-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	28522	\N	\N	\N
33090	MEMBRE	2020-10-27 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	28523	\N	\N	\N
33091	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28524	\N	\N	\N
33092	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28525	\N	\N	\N
33093	MEMBRE	2020-10-27 00:00:00	2020-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	28526	\N	\N	\N
33094	MEMBRE	2020-10-27 00:00:00	2021-01-03 00:00:00	ANCIEN	\N	\N	\N	\N	28527	\N	\N	\N
33095	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28528	\N	\N	\N
33096	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28529	\N	\N	\N
33097	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28530	\N	\N	\N
33098	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28531	\N	\N	\N
33099	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28532	\N	\N	\N
33100	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28533	\N	\N	\N
33101	MEMBRE	2020-10-27 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	28534	\N	\N	\N
33102	MEMBRE	2020-10-27 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	28535	\N	\N	\N
33103	MEMBRE	2020-10-27 00:00:00	2021-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	28536	\N	\N	\N
33104	MEMBRE	2020-10-27 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	28537	\N	\N	\N
33105	MEMBRE	2020-10-27 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	28538	\N	\N	\N
33106	MEMBRE	2020-10-27 00:00:00	2021-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	28539	\N	\N	\N
33107	MEMBRE	2020-10-22 00:00:00	2021-01-11 00:00:00	ANCIEN	\N	\N	\N	\N	28540	\N	\N	\N
33108	MEMBRE	2020-10-22 00:00:00	2020-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	28541	\N	\N	\N
33109	MEMBRE	2020-10-22 00:00:00	2021-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	28542	\N	\N	\N
33110	MEMBRE	2020-10-28 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	28543	\N	\N	\N
33111	MEMBRE	2020-10-28 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	28544	\N	\N	\N
33112	MEMBRE	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28545	\N	\N	\N
33113	MEMBRE	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28546	\N	\N	\N
33131	MEMBRE	2020-10-16 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	28564	\N	\N	\N
33132	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28565	\N	\N	\N
33133	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28566	\N	\N	\N
33134	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28567	\N	\N	\N
33135	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28568	\N	\N	\N
33136	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28569	\N	\N	\N
33137	MEMBRE	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28570	\N	\N	\N
33138	MEMBRE	2020-10-29 00:00:00	2021-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	28571	\N	\N	\N
33139	MEMBRE	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28572	\N	\N	\N
33140	MEMBRE	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28573	\N	\N	\N
33141	MEMBRE	2020-10-29 00:00:00	2020-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	28574	\N	\N	\N
33142	MEMBRE	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28575	\N	\N	\N
33143	MEMBRE	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28576	\N	\N	\N
33144	MEMBRE	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28577	\N	\N	\N
33145	MEMBRE	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28578	\N	\N	\N
33146	MEMBRE	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28579	\N	\N	\N
33147	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28580	\N	\N	\N
34102	VICPDT	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27677	\N	\N	\N
34103	VICPDT	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28838	\N	\N	\N
34104	VICPDT	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27426	\N	\N	\N
34105	VICPDT	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28285	\N	\N	\N
34106	VICPDT	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28333	\N	\N	\N
34107	VICPDT	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28871	\N	\N	\N
34285	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29266	\N	\N	\N
34291	MEMBRE	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29272	\N	\N	\N
34292	MEMBRE	2020-12-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29273	\N	\N	\N
34293	MEMBRE	2020-12-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29274	\N	\N	\N
34294	MEMBRE	2020-12-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29275	\N	\N	\N
34696	MEMBRE	2020-12-17 00:00:00	2021-07-20 00:00:00	ANCIEN	\N	\N	\N	\N	29536	\N	\N	\N
34697	MEMBRE	2020-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29537	\N	\N	\N
34699	MEMBRE	2020-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29539	\N	\N	\N
34700	MEMBRE	2020-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29540	\N	\N	\N
34701	MEMBRE	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29541	\N	\N	\N
34702	MEMBRE	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29542	\N	\N	\N
34703	MEMBRE	2020-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29543	\N	\N	\N
34816	MEMBRE	2021-01-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29599	\N	\N	\N
35129	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29853	\N	\N	\N
35143	MEMBRE	2020-10-01 00:00:00	2021-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	29867	\N	\N	\N
35158	MEMBRE	2020-10-01 00:00:00	2021-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	29882	\N	\N	\N
35165	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29889	\N	\N	\N
35171	MEMBRE	2020-10-01 00:00:00	2021-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	29895	\N	\N	\N
35173	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29897	\N	\N	\N
35213	MEMBRE	2020-10-01 00:00:00	2021-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	29937	\N	\N	\N
35321	MEMBRE	2021-01-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29984	\N	\N	\N
35473	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30063	\N	\N	\N
35514	SECRET	2021-01-12 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29754	\N	\N	\N
35522	VICPDT	2021-01-13 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29451	\N	\N	\N
35525	VICPDT	2021-01-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29437	\N	\N	\N
35855	SECRET	2021-02-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29878	\N	\N	\N
35857	SECRET	2021-02-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	30204	\N	\N	\N
35858	SECRET	2021-02-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29938	\N	\N	\N
35859	SECRET	2021-02-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29935	\N	\N	\N
35860	SECRET	2021-02-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29887	\N	\N	\N
35862	SECRET	2021-02-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29894	\N	\N	\N
35876	MEMBRE	2021-02-16 00:00:00	2021-07-20 00:00:00	ANCIEN	\N	\N	\N	\N	30210	\N	\N	\N
36056	MEMBRE	2021-06-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	30337	\N	\N	\N
36432	MEMBRE	2022-07-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	30649	\N	\N	\N
36443	MEMBRE	2022-09-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30660	\N	\N	\N
36611	MEMBRE	2023-03-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30810	\N	\N	\N
36666	MEMBRE	2023-08-31 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30859	\N	\N	\N
36667	MEMBRE	2023-08-31 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30860	\N	\N	\N
37808	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32000	\N	\N	\N
37830	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32022	\N	\N	\N
37831	MEMBRE	2023-10-18 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	32023	\N	\N	\N
37946	MEMBRE	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32141	\N	\N	\N
37983	MEMBRE	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32178	\N	\N	\N
38277	MEMBRE	2023-10-31 00:00:00	2024-01-30 00:00:00	ACTIF	\N	\N	\N	\N	32472	\N	\N	\N
38282	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32477	\N	\N	\N
38283	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32478	\N	\N	\N
38284	MEMBRE	2023-10-31 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	32479	\N	\N	\N
38285	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32480	\N	\N	\N
38286	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32481	\N	\N	\N
38287	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32482	\N	\N	\N
38288	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32483	\N	\N	\N
38289	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32484	\N	\N	\N
38290	MEMBRE	2023-10-31 00:00:00	2024-02-27 00:00:00	ACTIF	\N	\N	\N	\N	32485	\N	\N	\N
38291	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32486	\N	\N	\N
38292	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32487	\N	\N	\N
38293	MEMBRE	2023-10-31 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	32488	\N	\N	\N
38318	MEMBRE	2023-10-31 00:00:00	2024-02-27 00:00:00	ACTIF	\N	\N	\N	\N	32513	\N	\N	\N
38373	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32568	\N	\N	\N
38374	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32569	\N	\N	\N
40494	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33967	\N	\N	\N
40499	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33972	\N	\N	\N
40500	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33973	\N	\N	\N
40508	MEMBRE	2023-12-14 00:00:00	2024-02-05 00:00:00	ACTIF	\N	\N	\N	\N	33981	\N	\N	\N
40509	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33982	\N	\N	\N
30547	MEMBRE	2018-02-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26323	\N	2018-02-06 18:56:27	\N
30709	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26410	\N	\N	\N
30737	MEMBRE	2018-02-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26423	\N	2018-02-12 14:59:04	\N
30738	MEMBRE	2018-02-02 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26424	\N	2018-02-12 14:59:21	\N
30739	PDTHON	2018-02-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24170	\N	2018-02-12 15:24:50	\N
30740	VICPDT	2018-02-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26041	\N	2018-02-12 15:24:58	\N
30741	VICPDT	2018-02-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25956	\N	2018-02-12 15:25:04	\N
30742	VICPDT	2018-02-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24397	\N	2018-02-12 15:25:11	\N
30743	VICPDT	2018-02-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24533	\N	2018-02-12 15:25:20	\N
30744	SECRET	2018-02-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24294	\N	2018-02-12 15:25:29	\N
31175	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26699	\N	\N	\N
31565	MEMBRE	2019-04-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	27012	\N	\N	\N
31566	MEMBRE	2019-04-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27013	\N	\N	\N
31567	MEMBRE	2019-04-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27014	\N	\N	\N
31572	MEMBRE	2019-05-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27019	\N	\N	\N
31573	MEMBRE	2019-05-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27020	\N	\N	\N
31619	PDTDEL	2019-11-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	Gambie	\N	26252	\N	\N	\N
31653	MEMBRE	2020-02-04 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27085	\N	\N	\N
31654	MEMBRE	2020-02-04 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27086	\N	\N	\N
32158	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27587	\N	\N	\N
32159	MEMBRE	2020-10-13 00:00:00	2020-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	27588	\N	\N	\N
32160	MEMBRE	2020-10-13 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	27589	\N	\N	\N
32161	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27590	\N	\N	\N
32162	MEMBRE	2020-10-13 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	27591	\N	\N	\N
32163	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27592	\N	\N	\N
32164	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27593	\N	\N	\N
32165	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27594	\N	\N	\N
32166	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27595	\N	\N	\N
32167	MEMBRE	2020-10-13 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	27596	\N	\N	\N
32168	MEMBRE	2020-10-13 00:00:00	2020-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	27597	\N	\N	\N
32169	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27598	\N	\N	\N
32170	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27599	\N	\N	\N
32171	MEMBRE	2020-10-07 00:00:00	2021-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	27600	\N	\N	\N
32172	MEMBRE	2020-10-07 00:00:00	2021-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	27601	\N	\N	\N
32173	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27602	\N	\N	\N
32174	MEMBRE	2020-10-07 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	27603	\N	\N	\N
32175	MEMBRE	2020-10-13 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	27604	\N	\N	\N
32176	MEMBRE	2020-10-13 00:00:00	2020-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	27605	\N	\N	\N
32177	MEMBRE	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27606	\N	\N	\N
32178	MEMBRE	2020-10-12 00:00:00	2020-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	27607	\N	\N	\N
32179	MEMBRE	2020-10-13 00:00:00	2020-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	27608	\N	\N	\N
32180	MEMBRE	2020-10-13 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	27609	\N	\N	\N
32181	MEMBRE	2020-10-13 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	27610	\N	\N	\N
32182	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27611	\N	\N	\N
32183	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27612	\N	\N	\N
32184	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27613	\N	\N	\N
32185	MEMBRE	2020-10-14 00:00:00	2020-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	27614	\N	\N	\N
32186	MEMBRE	2020-10-14 00:00:00	2022-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	27615	\N	\N	\N
32187	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27616	\N	\N	\N
32188	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27617	\N	\N	\N
32189	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27618	\N	\N	\N
32190	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27619	\N	\N	\N
32191	MEMBRE	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27620	\N	\N	\N
32192	MEMBRE	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27621	\N	\N	\N
32193	MEMBRE	2020-10-13 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	27622	\N	\N	\N
32194	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27623	\N	\N	\N
32195	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27624	\N	\N	\N
32196	MEMBRE	2020-10-13 00:00:00	2021-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	27625	\N	\N	\N
32197	MEMBRE	2020-10-13 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	27626	\N	\N	\N
32198	MEMBRE	2020-10-13 00:00:00	2022-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	27627	\N	\N	\N
32199	MEMBRE	2020-10-13 00:00:00	2021-01-11 00:00:00	ANCIEN	\N	\N	\N	\N	27628	\N	\N	\N
32200	MEMBRE	2020-10-13 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	27629	\N	\N	\N
32201	MEMBRE	2020-10-13 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	27630	\N	\N	\N
33446	MEMBRE	2020-11-05 00:00:00	2020-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	28868	\N	\N	\N
33447	MEMBRE	2020-10-23 00:00:00	2021-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	28869	\N	\N	\N
33782	MEMBRE	2020-11-05 00:00:00	2020-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	29054	\N	\N	\N
33783	PDTDEL	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour les Philippines	\N	29054	\N	\N	\N
33784	MEMBRE	2020-11-18 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	29055	\N	\N	\N
33785	MEMBRE	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29056	\N	\N	\N
33786	MEMBRE	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29057	\N	\N	\N
33787	MEMBRE	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29058	\N	\N	\N
33788	MEMBRE	2020-11-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29059	\N	\N	\N
33789	MEMBRE	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29060	\N	\N	\N
34286	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29267	\N	\N	\N
34287	MEMBRE	2020-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29268	\N	\N	\N
34554	MEMBRE	2020-12-17 00:00:00	2021-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	29418	\N	\N	\N
34558	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29422	\N	\N	\N
34610	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29471	\N	\N	\N
34611	MEMBRE	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29472	\N	\N	\N
34643	MEMBRE	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29501	\N	\N	\N
34664	PDTHON	2020-12-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27425	\N	\N	\N
34665	VICPDT	2020-12-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28482	\N	\N	\N
34666	VICPDT	2020-12-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27597	\N	\N	\N
34667	VICPDT	2020-12-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29135	\N	\N	\N
34668	VICPDT	2020-12-21 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	27451	\N	\N	\N
34669	VICPDT	2020-12-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27654	\N	\N	\N
34670	VICPDT	2020-12-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29018	\N	\N	\N
34671	SECRET	2020-12-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27291	\N	\N	\N
34672	SECRET	2020-12-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28376	\N	\N	\N
34682	MEMBRE	2020-12-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29522	\N	\N	\N
34685	MEMBRE	2020-12-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29525	\N	\N	\N
34941	MEMBRE	2021-01-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29705	\N	\N	\N
35109	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29833	\N	\N	\N
35146	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29870	\N	\N	\N
35148	MEMBRE	2020-10-01 00:00:00	2021-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	29872	\N	\N	\N
35149	MEMBRE	2020-10-01 00:00:00	2021-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	29873	\N	\N	\N
35150	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29874	\N	\N	\N
35151	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29875	\N	\N	\N
35152	MEMBRE	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29876	\N	\N	\N
35257	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29959	\N	\N	\N
35280	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29961	\N	\N	\N
35281	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29962	\N	\N	\N
35536	MEMBRE	2021-01-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30074	\N	\N	\N
35537	MEMBRE	2021-01-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30075	\N	\N	\N
35538	MEMBRE	2021-01-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30076	\N	\N	\N
35539	MEMBRE	2021-01-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30077	\N	\N	\N
35540	MEMBRE	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30078	\N	\N	\N
35541	VICPDT	2021-01-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27901	\N	\N	\N
35542	VICPDT	2021-01-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27240	\N	\N	\N
35543	VICPDT	2021-01-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27816	\N	\N	\N
35545	VICPDT	2021-01-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27188	\N	\N	\N
35546	VICPDT	2021-01-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27840	\N	\N	\N
35547	VICPDT	2021-01-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28310	\N	\N	\N
35549	VICPDT	2021-01-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27343	\N	\N	\N
35550	SECRET	2021-01-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28071	\N	\N	\N
35551	PDTHON	2021-01-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28327	\N	\N	\N
35552	VICPDT	2021-01-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28246	\N	\N	\N
35553	VICPDT	2021-01-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27933	\N	\N	\N
35554	VICPDT	2021-01-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29581	\N	\N	\N
35555	VICPDT	2021-01-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27524	\N	\N	\N
35556	VICPDT	2021-01-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29175	\N	\N	\N
35557	VICPDT	2021-01-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27737	\N	\N	\N
35558	MEMBRE	2021-01-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30080	\N	\N	\N
35608	VICPDT	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29344	\N	\N	\N
35617	MEMBRE	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30102	\N	\N	\N
35618	MEMBRE	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30103	\N	\N	\N
35619	MEMBRE	2021-02-03 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	30104	\N	\N	\N
35829	SECRET	2021-02-13 00:00:00	2021-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	30107	\N	\N	\N
35830	SECRET	2021-02-13 00:00:00	2022-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	30111	\N	\N	\N
35832	SECRET	2021-02-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	30136	\N	\N	\N
35833	SECRET	2021-02-13 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	30121	\N	\N	\N
35834	SECRET	2021-02-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30128	\N	\N	\N
35835	SECRET	2021-02-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30134	\N	\N	\N
35845	VICPDT	2021-02-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29882	\N	\N	\N
35937	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30241	\N	\N	\N
36007	MEMBRE	2021-03-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	30304	\N	\N	\N
36008	MEMBRE	2021-03-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30305	\N	\N	\N
38278	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32473	\N	\N	\N
38279	MEMBRE	2023-10-31 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	32474	\N	\N	\N
38280	MEMBRE	2023-10-31 00:00:00	2024-01-25 00:00:00	ACTIF	\N	\N	\N	\N	32475	\N	\N	\N
38281	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32476	\N	\N	\N
38300	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32495	\N	\N	\N
38899	MEMBRE	2023-11-20 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	33086	\N	\N	\N
38900	MEMBRE	2023-11-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33087	\N	\N	\N
39210	MEMBRE	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33256	\N	\N	\N
39219	MEMBRE	2023-12-05 00:00:00	2024-01-30 00:00:00	ACTIF	\N	\N	\N	\N	33263	\N	\N	\N
39220	MEMBRE	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33264	\N	\N	\N
39221	MEMBRE	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33265	\N	\N	\N
39222	MEMBRE	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33266	\N	\N	\N
39223	MEMBRE	2023-12-05 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	33267	\N	\N	\N
40719	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34178	\N	\N	\N
40720	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34179	\N	\N	\N
40721	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34180	\N	\N	\N
30611	MEMBRE	2017-10-01 00:00:00	2018-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	26332	\N	\N	\N
30825	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26496	\N	\N	\N
30828	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26499	\N	\N	\N
30928	VICPDT	2018-02-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	26100	\N	\N	\N
30931	VICPDT	2018-02-15 00:00:00	2019-09-25 00:00:00	ANCIEN	\N	\N	\N	\N	26109	\N	\N	\N
30991	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26585	\N	\N	\N
31025	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26606	\N	\N	\N
31295	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26764	\N	\N	\N
31442	MEMBRE	2018-11-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	26903	\N	\N	\N
31505	PDTDEL	2019-01-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Thaïlande	\N	25652	\N	\N	\N
31645	MEMBRE	2020-01-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27077	\N	\N	\N
31710	MEMBRE	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27139	\N	\N	\N
31711	MEMBRE	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27140	\N	\N	\N
31712	MEMBRE	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27141	\N	\N	\N
31713	MEMBRE	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27142	\N	\N	\N
31714	MEMBRE	2020-10-07 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	27143	\N	\N	\N
31715	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27144	\N	\N	\N
31716	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27145	\N	\N	\N
31717	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27146	\N	\N	\N
31718	MEMBRE	2020-10-07 00:00:00	2020-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	27147	\N	\N	\N
31719	MEMBRE	2020-10-07 00:00:00	2020-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	27148	\N	\N	\N
31720	MEMBRE	2020-10-07 00:00:00	2020-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	27149	\N	\N	\N
31721	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27150	\N	\N	\N
31722	MEMBRE	2020-10-07 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	27151	\N	\N	\N
31723	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27152	\N	\N	\N
31724	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27153	\N	\N	\N
31725	MEMBRE	2020-10-07 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	27154	\N	\N	\N
31726	MEMBRE	2020-10-07 00:00:00	2021-01-03 00:00:00	ANCIEN	\N	\N	\N	\N	27155	\N	\N	\N
31727	MEMBRE	2020-10-07 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	27156	\N	\N	\N
33381	MEMBRE	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28803	\N	\N	\N
33382	MEMBRE	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28804	\N	\N	\N
33383	MEMBRE	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28805	\N	\N	\N
33384	MEMBRE	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28806	\N	\N	\N
33385	MEMBRE	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28807	\N	\N	\N
33386	MEMBRE	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28808	\N	\N	\N
33387	MEMBRE	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28809	\N	\N	\N
33388	MEMBRE	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28810	\N	\N	\N
33389	MEMBRE	2020-11-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28811	\N	\N	\N
33390	MEMBRE	2020-11-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28812	\N	\N	\N
33391	MEMBRE	2020-11-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28813	\N	\N	\N
33392	MEMBRE	2020-11-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28814	\N	\N	\N
33393	MEMBRE	2020-11-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28815	\N	\N	\N
33394	MEMBRE	2020-11-05 00:00:00	2020-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	28816	\N	\N	\N
33395	MEMBRE	2020-11-05 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	28817	\N	\N	\N
33396	MEMBRE	2020-11-05 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	28818	\N	\N	\N
33397	MEMBRE	2020-11-05 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	28819	\N	\N	\N
33398	MEMBRE	2020-11-05 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	28820	\N	\N	\N
33399	MEMBRE	2020-11-05 00:00:00	2020-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	28821	\N	\N	\N
33400	MEMBRE	2020-11-03 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	28822	\N	\N	\N
33401	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28823	\N	\N	\N
33402	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28824	\N	\N	\N
33403	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28825	\N	\N	\N
33660	MEMBRE	2020-11-19 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	28996	\N	\N	\N
33661	MEMBRE	2020-11-19 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	28997	\N	\N	\N
33669	PDT	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29002	\N	\N	\N
33663	MEMBRE	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28999	\N	\N	\N
33664	MEMBRE	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29000	\N	\N	\N
33665	MEMBRE	2020-11-19 00:00:00	2021-01-21 00:00:00	ANCIEN	\N	\N	\N	\N	29001	\N	\N	\N
33680	MEMBRE	2020-11-18 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	29012	\N	\N	\N
33667	PDT	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28998	\N	\N	\N
33668	PDT	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28989	\N	\N	\N
33672	PDT	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28456	\N	\N	\N
33681	PDT	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28820	\N	\N	\N
33685	MEMBRE	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29016	\N	\N	\N
33687	PDTDEL	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour les Emirats arabes unis	\N	28772	\N	\N	\N
33688	PDTDEL	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour la Colombie	\N	27762	\N	\N	\N
33689	PDTDEL	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour la Gambie	\N	28970	\N	\N	\N
33690	PDTDEL	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour la Géorgie	\N	28377	\N	\N	\N
33691	PDTDEL	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour le Kosovo	\N	27124	\N	\N	\N
33692	PDTDEL	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour la Lettonie	\N	28632	\N	\N	\N
33693	PDTDEL	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour la Lituanie	\N	27115	\N	\N	\N
33694	PDTDEL	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour la Macédoine	\N	27458	\N	\N	\N
33695	PDTDEL	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour le Monténégro	\N	27782	\N	\N	\N
33696	PDTDEL	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour le Malawi	\N	28928	\N	\N	\N
33697	PDTDEL	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour le Sénégal	\N	28773	\N	\N	\N
33698	PDTDEL	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour le Zimbabwe	\N	28616	\N	\N	\N
33699	PDTDEL	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour le Tchad	\N	27391	\N	\N	\N
33834	PDT	2020-11-25 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	27448	\N	\N	\N
33701	PDTDEL	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour la République démocratique du Congo	\N	27976	\N	\N	\N
33702	PDTDEL	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour l'Ouganda	\N	27134	\N	\N	\N
33954	VICPDT	2020-12-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27224	\N	\N	\N
33955	VICPDT	2020-12-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28909	\N	\N	\N
33956	MEMBRE	2020-12-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28396	\N	\N	\N
33957	VICPDT	2020-12-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28396	\N	\N	\N
33958	SECRET	2020-12-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27793	\N	\N	\N
33959	SECRET	2020-12-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29157	\N	\N	\N
33960	SECRET	2020-12-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27363	\N	\N	\N
34512	MEMBRE	2020-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29376	\N	\N	\N
35214	MEMBRE	2020-10-01 00:00:00	2021-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	29938	\N	\N	\N
35368	VICPDT	2021-01-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29510	\N	\N	\N
35960	MEMBRE	2020-10-01 00:00:00	2021-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	30261	\N	\N	\N
36015	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30312	\N	\N	\N
36016	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30313	\N	\N	\N
36110	MEMBRE	2021-07-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30383	\N	\N	\N
36297	MEMBRE	2022-03-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30531	\N	\N	\N
36437	MEMBRE	2022-07-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30654	\N	\N	\N
36589	MEMBRE	2023-01-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30795	\N	\N	\N
36590	MEMBRE	2023-01-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30796	\N	\N	\N
36592	MEMBRE	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30798	\N	\N	\N
36656	MEMBRE	2023-07-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30853	\N	\N	\N
36774	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30964	\N	\N	\N
36775	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30965	\N	\N	\N
36776	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30966	\N	\N	\N
36938	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31128	\N	\N	\N
36939	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31129	\N	\N	\N
36976	MEMBRE	2023-10-10 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	31166	\N	\N	\N
36977	MEMBRE	2023-10-10 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	31167	\N	\N	\N
37057	MEMBRE	2023-10-10 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	31247	\N	\N	\N
37058	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31248	\N	\N	\N
37059	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31249	\N	\N	\N
37060	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31250	\N	\N	\N
37061	MEMBRE	2023-10-10 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	31251	\N	\N	\N
37062	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31252	\N	\N	\N
37372	MEMBRE	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31564	\N	\N	\N
37373	MEMBRE	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31565	\N	\N	\N
37374	MEMBRE	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31566	\N	\N	\N
37375	MEMBRE	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31567	\N	\N	\N
37436	MEMBRE	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31628	\N	\N	\N
37437	MEMBRE	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31629	\N	\N	\N
37438	MEMBRE	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31630	\N	\N	\N
37439	MEMBRE	2023-10-12 00:00:00	2024-02-19 00:00:00	ACTIF	\N	\N	\N	\N	31631	\N	\N	\N
37440	MEMBRE	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31632	\N	\N	\N
37441	MEMBRE	2023-10-12 00:00:00	2024-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	31633	\N	\N	\N
37442	MEMBRE	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31634	\N	\N	\N
37443	MEMBRE	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31635	\N	\N	\N
37444	MEMBRE	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31636	\N	\N	\N
37445	MEMBRE	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31637	\N	\N	\N
37446	MEMBRE	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31638	\N	\N	\N
37447	MEMBRE	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31639	\N	\N	\N
37448	MEMBRE	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31640	\N	\N	\N
37449	MEMBRE	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31641	\N	\N	\N
37450	MEMBRE	2023-10-12 00:00:00	2024-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	31642	\N	\N	\N
38473	MEMBRE	2023-11-02 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	32668	\N	\N	\N
38474	MEMBRE	2023-11-02 00:00:00	2024-02-27 00:00:00	ACTIF	\N	\N	\N	\N	32669	\N	\N	\N
38475	MEMBRE	2023-11-02 00:00:00	2024-01-25 00:00:00	ACTIF	\N	\N	\N	\N	32670	\N	\N	\N
38476	MEMBRE	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32671	\N	\N	\N
38727	MEMBRE	2023-11-15 00:00:00	2029-11-27 00:00:00	ACTIF	\N	\N	\N	\N	32922	\N	\N	\N
39129	PDTDEL	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour le Tchad	\N	33175	\N	\N	\N
39131	PDTDEL	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour la Sierra Leone	\N	33176	\N	\N	\N
39783	MEMBRE	2024-01-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33462	\N	\N	\N
40510	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33983	\N	\N	\N
40512	MEMBRE	2023-10-01 00:00:00	2024-02-27 00:00:00	ACTIF	\N	\N	\N	\N	33985	\N	\N	\N
30713	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26414	\N	\N	\N
30736	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26422	\N	\N	\N
30918	VICPDT	2018-02-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	26527	\N	\N	\N
30927	VICPDT	2018-02-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	26099	\N	\N	\N
30929	VICPDT	2018-02-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	26106	\N	\N	\N
30958	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26552	\N	\N	\N
31019	MEMBRE	2017-10-01 00:00:00	2018-05-07 00:00:00	ANCIEN	\N	\N	\N	\N	26600	\N	\N	\N
31440	MEMBRE	2018-11-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	26901	\N	\N	\N
31446	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26907	\N	\N	\N
31448	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26909	\N	\N	\N
31577	MEMBRE	2019-06-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	27024	\N	\N	\N
32905	MEMBRE	2020-10-14 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	28338	\N	\N	\N
32887	MEMBRE	2020-10-23 00:00:00	2020-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	28320	\N	\N	\N
32888	MEMBRE	2020-10-23 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	28321	\N	\N	\N
32889	MEMBRE	2020-10-23 00:00:00	2021-01-03 00:00:00	ANCIEN	\N	\N	\N	\N	28322	\N	\N	\N
32890	MEMBRE	2020-10-13 00:00:00	2021-01-14 00:00:00	ANCIEN	\N	\N	\N	\N	28323	\N	\N	\N
32891	MEMBRE	2020-10-13 00:00:00	2020-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	28324	\N	\N	\N
32892	MEMBRE	2020-10-13 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	28325	\N	\N	\N
32906	MEMBRE	2020-10-14 00:00:00	2021-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	28339	\N	\N	\N
32907	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28340	\N	\N	\N
32908	MEMBRE	2020-10-14 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	28341	\N	\N	\N
32909	MEMBRE	2020-10-14 00:00:00	2020-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	28342	\N	\N	\N
32910	MEMBRE	2020-10-14 00:00:00	2020-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	28343	\N	\N	\N
32911	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28344	\N	\N	\N
32912	MEMBRE	2020-10-14 00:00:00	2020-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	28345	\N	\N	\N
32913	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28346	\N	\N	\N
32914	MEMBRE	2020-10-14 00:00:00	2021-01-03 00:00:00	ANCIEN	\N	\N	\N	\N	28347	\N	\N	\N
32915	MEMBRE	2020-10-14 00:00:00	2021-01-11 00:00:00	ANCIEN	\N	\N	\N	\N	28348	\N	\N	\N
32916	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28349	\N	\N	\N
32917	MEMBRE	2020-10-14 00:00:00	2020-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	28350	\N	\N	\N
32918	MEMBRE	2020-10-14 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	28351	\N	\N	\N
32919	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28352	\N	\N	\N
32920	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28353	\N	\N	\N
32921	MEMBRE	2020-10-14 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	28354	\N	\N	\N
32922	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28355	\N	\N	\N
32923	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28356	\N	\N	\N
32924	MEMBRE	2020-10-14 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	28357	\N	\N	\N
32925	MEMBRE	2020-10-15 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	28358	\N	\N	\N
32926	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28359	\N	\N	\N
32927	MEMBRE	2020-10-15 00:00:00	2020-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	28360	\N	\N	\N
32928	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28361	\N	\N	\N
32929	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28362	\N	\N	\N
32930	MEMBRE	2020-10-15 00:00:00	2020-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	28363	\N	\N	\N
32931	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28364	\N	\N	\N
32932	MEMBRE	2020-10-15 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	28365	\N	\N	\N
32933	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28366	\N	\N	\N
32934	MEMBRE	2020-10-15 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	28367	\N	\N	\N
32935	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28368	\N	\N	\N
32936	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28369	\N	\N	\N
32937	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28370	\N	\N	\N
32938	MEMBRE	2020-10-07 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	28371	\N	\N	\N
32939	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28372	\N	\N	\N
32940	MEMBRE	2020-10-07 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	28373	\N	\N	\N
32941	MEMBRE	2020-10-07 00:00:00	2021-01-11 00:00:00	ANCIEN	\N	\N	\N	\N	28374	\N	\N	\N
32942	MEMBRE	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28375	\N	\N	\N
32943	MEMBRE	2020-10-26 00:00:00	2020-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	28376	\N	\N	\N
32944	MEMBRE	2020-10-26 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	28377	\N	\N	\N
32945	MEMBRE	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28378	\N	\N	\N
32946	MEMBRE	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28379	\N	\N	\N
32947	MEMBRE	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28380	\N	\N	\N
32948	MEMBRE	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28381	\N	\N	\N
32949	MEMBRE	2020-10-12 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	28382	\N	\N	\N
32950	MEMBRE	2020-10-12 00:00:00	2021-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	28383	\N	\N	\N
32951	MEMBRE	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28384	\N	\N	\N
32952	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28385	\N	\N	\N
32953	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28386	\N	\N	\N
32954	MEMBRE	2020-10-13 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	28387	\N	\N	\N
32955	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28388	\N	\N	\N
32956	MEMBRE	2020-10-26 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	28389	\N	\N	\N
32957	MEMBRE	2020-10-13 00:00:00	2021-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	28390	\N	\N	\N
32958	MEMBRE	2020-10-13 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	28391	\N	\N	\N
33914	MEMBRE	2020-11-24 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	29162	\N	\N	\N
33915	MEMBRE	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29163	\N	\N	\N
34579	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29443	\N	\N	\N
34625	MEMBRE	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29484	\N	\N	\N
34804	MEMBRE	2021-01-04 00:00:00	2021-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	29593	\N	\N	\N
34805	MEMBRE	2021-01-04 00:00:00	2021-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	29594	\N	\N	\N
34865	MEMBRE	2021-01-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29648	\N	\N	\N
34967	MEMBRE	2021-01-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	29723	\N	\N	\N
35417	SECRET	2021-01-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28282	\N	\N	\N
35418	SECRET	2021-01-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27169	\N	\N	\N
35419	PDTDEL	2021-01-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour l'Estonie	\N	28103	\N	\N	\N
35651	MEMBRE	2021-02-03 00:00:00	2021-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	30136	\N	\N	\N
35655	MEMBRE	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30140	\N	\N	\N
35837	MEMBRE	2020-10-01 00:00:00	2021-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	30204	\N	\N	\N
35918	MEMBRE	2021-03-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	30230	\N	\N	\N
35919	MEMBRE	2021-03-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	30231	\N	\N	\N
35942	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30245	\N	\N	\N
35982	MEMBRE	2021-03-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	30279	\N	\N	\N
35983	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30280	\N	\N	\N
35984	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30281	\N	\N	\N
36009	MEMBRE	2021-03-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	30306	\N	\N	\N
36010	MEMBRE	2021-03-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30307	\N	\N	\N
36011	MEMBRE	2021-03-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30308	\N	\N	\N
36035	MEMBRE	2021-04-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30322	\N	\N	\N
36048	MEMBRE	2021-05-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30329	\N	\N	\N
36061	MEMBRE	2021-06-09 00:00:00	2021-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	30342	\N	\N	\N
36062	MEMBRE	2021-06-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30343	\N	\N	\N
36096	MEMBRE	2021-06-28 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	30370	\N	\N	\N
36143	MEMBRE	2021-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30405	\N	\N	\N
36144	MEMBRE	2021-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30406	\N	\N	\N
36145	MEMBRE	2021-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30407	\N	\N	\N
36158	MEMBRE	2021-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30420	\N	\N	\N
36159	MEMBRE	2021-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30421	\N	\N	\N
36169	MEMBRE	2021-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30429	\N	\N	\N
36170	MEMBRE	2021-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30430	\N	\N	\N
36188	MEMBRE	2021-10-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	30440	\N	\N	\N
36259	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30503	\N	\N	\N
36260	MEMBRE	2022-01-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	30504	\N	\N	\N
36270	MEMBRE	2022-01-21 00:00:00	2022-01-21 00:00:00	ANCIEN	\N	\N	\N	\N	30509	\N	\N	\N
36625	MEMBRE	2023-05-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30824	\N	\N	\N
36410	MEMBRE	2022-05-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30628	\N	\N	\N
36411	MEMBRE	2022-05-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30629	\N	\N	\N
36412	MEMBRE	2022-05-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30630	\N	\N	\N
36454	MEMBRE	2021-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30671	\N	\N	\N
36516	MEMBRE	2023-01-01 00:00:00	2023-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	30733	\N	\N	\N
36901	MEMBRE	2023-10-09 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	31091	\N	\N	\N
36902	MEMBRE	2023-10-09 00:00:00	2024-01-29 00:00:00	ACTIF	\N	\N	\N	\N	31092	\N	\N	\N
36903	MEMBRE	2023-10-09 00:00:00	2024-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	31093	\N	\N	\N
36910	MEMBRE	2023-10-09 00:00:00	2023-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	31100	\N	\N	\N
36911	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31101	\N	\N	\N
36912	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31102	\N	\N	\N
36913	MEMBRE	2023-10-09 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	31103	\N	\N	\N
36914	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31104	\N	\N	\N
37054	MEMBRE	2023-10-10 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	31244	\N	\N	\N
37055	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31245	\N	\N	\N
37215	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31407	\N	\N	\N
37216	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31408	\N	\N	\N
37217	MEMBRE	2023-10-10 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	31409	\N	\N	\N
37224	MEMBRE	2023-10-10 00:00:00	2024-02-26 00:00:00	ACTIF	\N	\N	\N	\N	31416	\N	\N	\N
37225	MEMBRE	2023-10-10 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	31417	\N	\N	\N
37226	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31418	\N	\N	\N
37237	MEMBRE	2023-10-10 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	31429	\N	\N	\N
37238	MEMBRE	2023-10-10 00:00:00	2024-02-27 00:00:00	ACTIF	\N	\N	\N	\N	31430	\N	\N	\N
37239	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31431	\N	\N	\N
37240	MEMBRE	2023-10-10 00:00:00	2024-02-13 00:00:00	ACTIF	\N	\N	\N	\N	31432	\N	\N	\N
37241	MEMBRE	2023-10-10 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	31433	\N	\N	\N
38521	MEMBRE	2023-07-10 00:00:00	2023-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	32716	\N	\N	\N
38634	MEMBRE	2023-11-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32829	\N	\N	\N
40067	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33644	\N	\N	\N
40068	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33645	\N	\N	\N
40457	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33930	\N	\N	\N
40606	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34079	\N	\N	\N
40608	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34081	\N	\N	\N
40609	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34082	\N	\N	\N
40613	MEMBRE	2023-10-01 00:00:00	2024-02-12 00:00:00	ACTIF	\N	\N	\N	\N	34086	\N	\N	\N
40615	MEMBRE	2023-10-01 00:00:00	2024-02-12 00:00:00	ACTIF	\N	\N	\N	\N	34088	\N	\N	\N
40617	MEMBRE	2023-10-01 00:00:00	2024-02-12 00:00:00	ACTIF	\N	\N	\N	\N	34090	\N	\N	\N
40619	MEMBRE	2023-10-01 00:00:00	2024-02-12 00:00:00	ACTIF	\N	\N	\N	\N	34092	\N	\N	\N
40620	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34093	\N	\N	\N
40621	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34094	\N	\N	\N
40622	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34095	\N	\N	\N
40624	MEMBRE	2023-10-01 00:00:00	2024-02-12 00:00:00	ACTIF	\N	\N	\N	\N	34097	\N	\N	\N
40625	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34098	\N	\N	\N
40626	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34099	\N	\N	\N
40627	MEMBRE	2023-10-01 00:00:00	2024-02-12 00:00:00	ACTIF	\N	\N	\N	\N	34100	\N	\N	\N
41480	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34468	\N	\N	\N
41507	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34489	\N	\N	\N
30680	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26381	\N	\N	\N
30682	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26383	\N	\N	\N
30683	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26384	\N	\N	\N
30883	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26519	\N	\N	\N
31009	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26596	\N	\N	\N
31011	VICPDT	2018-02-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	26427	\N	\N	\N
31013	VICPDT	2018-02-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	26428	\N	\N	\N
31239	VICPDTDEL	2018-04-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	Pérou	\N	24770	\N	2018-04-03 12:21:41	2018-04-03 12:24:25
31266	MEMBRE	2018-04-04 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26751	\N	2018-04-16 10:31:55	\N
31289	MEMBRE	2018-04-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26758	\N	2018-05-17 16:23:35	\N
31290	MEMBRE	2018-05-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26759	\N	2018-05-17 16:24:00	\N
31554	MEMBRE	2019-03-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27001	\N	\N	\N
31614	MEMBRE	2019-10-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	27049	\N	\N	\N
31646	MEMBRE	2019-10-03 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27078	\N	\N	\N
31647	MEMBRE	2019-10-03 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27079	\N	\N	\N
31648	MEMBRE	2019-10-03 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27080	\N	\N	\N
31649	MEMBRE	2019-10-03 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27081	\N	\N	\N
31650	MEMBRE	2019-10-03 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27082	\N	\N	\N
32287	MEMBRE	2020-10-13 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	27716	\N	\N	\N
32288	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27717	\N	\N	\N
33066	MEMBRE	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28499	\N	\N	\N
33067	MEMBRE	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28500	\N	\N	\N
33068	MEMBRE	2020-10-26 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	28501	\N	\N	\N
33069	MEMBRE	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28502	\N	\N	\N
33070	MEMBRE	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28503	\N	\N	\N
33071	MEMBRE	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28504	\N	\N	\N
33072	MEMBRE	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28505	\N	\N	\N
33712	MEMBRE	2020-11-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29026	\N	\N	\N
33713	MEMBRE	2020-11-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28437	\N	\N	\N
33714	PDTDEL	2020-11-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour le Centrafrique	\N	28324	\N	\N	\N
33882	MEMBRE	2020-11-24 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	29131	\N	\N	\N
33883	MEMBRE	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29132	\N	\N	\N
33884	MEMBRE	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29133	\N	\N	\N
33886	MEMBRE	2020-11-25 00:00:00	2020-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	29135	\N	\N	\N
33887	MEMBRE	2020-11-26 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	29136	\N	\N	\N
33888	MEMBRE	2020-11-25 00:00:00	2021-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	29137	\N	\N	\N
33889	MEMBRE	2020-11-25 00:00:00	2022-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	29138	\N	\N	\N
34504	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29368	\N	\N	\N
34505	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29369	\N	\N	\N
34508	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29372	\N	\N	\N
34510	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29374	\N	\N	\N
34511	MEMBRE	2020-12-16 00:00:00	2022-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	29375	\N	\N	\N
34536	MEMBRE	2020-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29400	\N	\N	\N
34537	MEMBRE	2020-12-16 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	29401	\N	\N	\N
34538	MEMBRE	2020-12-15 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	29402	\N	\N	\N
34539	MEMBRE	2020-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29403	\N	\N	\N
34540	MEMBRE	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29404	\N	\N	\N
34566	MEMBRE	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29430	\N	\N	\N
34596	MEMBRE	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29457	\N	\N	\N
34597	MEMBRE	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29458	\N	\N	\N
34598	MEMBRE	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29459	\N	\N	\N
34599	MEMBRE	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29460	\N	\N	\N
34600	MEMBRE	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29461	\N	\N	\N
34763	VICPDT	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27474	\N	\N	\N
34764	VICPDT	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28631	\N	\N	\N
34765	VICPDT	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28243	\N	\N	\N
34766	VICPDT	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27686	\N	\N	\N
34767	VICPDT	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27155	\N	\N	\N
34768	VICPDT	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27947	\N	\N	\N
34769	VICPDT	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28423	\N	\N	\N
34770	VICPDT	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27659	\N	\N	\N
34771	VICPDT	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28144	\N	\N	\N
34772	VICPDT	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27951	\N	\N	\N
34773	VICPDT	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27829	\N	\N	\N
34774	MEMBRE	2021-01-04 00:00:00	2021-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	29581	\N	\N	\N
34775	MEMBRE	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29582	\N	\N	\N
34852	MEMBRE	2021-01-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29635	\N	\N	\N
34853	MEMBRE	2021-01-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	29636	\N	\N	\N
34854	MEMBRE	2021-01-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29637	\N	\N	\N
35075	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29799	\N	\N	\N
35507	VICPDT	2020-12-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29492	\N	\N	\N
35913	MEMBRE	2021-03-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30225	\N	\N	\N
35927	MEMBRE	2021-03-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30238	\N	\N	\N
35928	MEMBRE	2021-03-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30239	\N	\N	\N
35951	MEMBRE	2020-10-01 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	30253	\N	\N	\N
35952	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30254	\N	\N	\N
35953	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30255	\N	\N	\N
35954	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30256	\N	\N	\N
35955	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30257	\N	\N	\N
35956	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30258	\N	\N	\N
36109	MEMBRE	2021-07-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30382	\N	\N	\N
36121	MEMBRE	2021-08-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30384	\N	\N	\N
36185	MEMBRE	2021-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30437	\N	\N	\N
36195	MEMBRE	2021-10-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30447	\N	\N	\N
36222	MEMBRE	2021-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30467	\N	\N	\N
36292	MEMBRE	2022-02-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30526	\N	\N	\N
36455	MEMBRE	2021-11-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30672	\N	\N	\N
36456	MEMBRE	2022-03-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30673	\N	\N	\N
36511	MEMBRE	2023-01-01 00:00:00	2023-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	30728	\N	\N	\N
36512	MEMBRE	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30729	\N	\N	\N
36513	MEMBRE	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30730	\N	\N	\N
36514	MEMBRE	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30731	\N	\N	\N
36515	MEMBRE	2023-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30732	\N	\N	\N
36518	MEMBRE	2023-01-01 00:00:00	2023-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	30735	\N	\N	\N
36563	MEMBRE	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30780	\N	\N	\N
36564	MEMBRE	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30781	\N	\N	\N
36635	MEMBRE	2023-05-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30833	\N	\N	\N
37420	MEMBRE	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31612	\N	\N	\N
37421	MEMBRE	2023-10-12 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	31613	\N	\N	\N
37422	MEMBRE	2023-10-12 00:00:00	2024-04-02 00:00:00	ACTIF	\N	\N	\N	\N	31614	\N	\N	\N
37423	MEMBRE	2023-10-12 00:00:00	2024-02-27 00:00:00	ACTIF	\N	\N	\N	\N	31615	\N	\N	\N
37424	MEMBRE	2023-10-12 00:00:00	2024-01-25 00:00:00	ACTIF	\N	\N	\N	\N	31616	\N	\N	\N
37425	MEMBRE	2023-10-12 00:00:00	2024-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	31617	\N	\N	\N
37426	MEMBRE	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31618	\N	\N	\N
37427	MEMBRE	2023-10-12 00:00:00	2024-01-25 00:00:00	ACTIF	\N	\N	\N	\N	31619	\N	\N	\N
37428	MEMBRE	2023-10-12 00:00:00	2024-01-04 00:00:00	ANCIEN	\N	\N	\N	\N	31620	\N	\N	\N
37429	MEMBRE	2023-10-12 00:00:00	2024-02-26 00:00:00	ACTIF	\N	\N	\N	\N	31621	\N	\N	\N
37430	MEMBRE	2023-10-12 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	31622	\N	\N	\N
37431	MEMBRE	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31623	\N	\N	\N
37432	MEMBRE	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31624	\N	\N	\N
37433	MEMBRE	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31625	\N	\N	\N
37434	MEMBRE	2023-10-12 00:00:00	2023-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	31626	\N	\N	\N
37435	MEMBRE	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31627	\N	\N	\N
37451	MEMBRE	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31643	\N	\N	\N
37452	MEMBRE	2023-10-12 00:00:00	2024-02-13 00:00:00	ACTIF	\N	\N	\N	\N	31644	\N	\N	\N
37453	MEMBRE	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31645	\N	\N	\N
37454	MEMBRE	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31646	\N	\N	\N
37559	MEMBRE	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31751	\N	\N	\N
37560	MEMBRE	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31752	\N	\N	\N
37561	MEMBRE	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31753	\N	\N	\N
37562	MEMBRE	2023-10-16 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	31754	\N	\N	\N
37563	MEMBRE	2023-10-16 00:00:00	2024-01-04 00:00:00	ANCIEN	\N	\N	\N	\N	31755	\N	\N	\N
37836	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32028	\N	\N	\N
37982	MEMBRE	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32177	\N	\N	\N
37992	MEMBRE	2023-10-20 00:00:00	2024-01-28 00:00:00	ACTIF	\N	\N	\N	\N	32187	\N	\N	\N
37993	MEMBRE	2023-10-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32188	\N	\N	\N
37994	MEMBRE	2023-10-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32189	\N	\N	\N
37995	MEMBRE	2023-10-20 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	32190	\N	\N	\N
37996	MEMBRE	2023-10-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32191	\N	\N	\N
37997	MEMBRE	2023-10-20 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	32192	\N	\N	\N
37998	MEMBRE	2023-10-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32193	\N	\N	\N
37999	MEMBRE	2023-10-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32194	\N	\N	\N
38000	MEMBRE	2023-10-20 00:00:00	2023-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	32195	\N	\N	\N
38001	MEMBRE	2023-10-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32196	\N	\N	\N
38002	MEMBRE	2023-10-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32197	\N	\N	\N
38003	MEMBRE	2023-10-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32198	\N	\N	\N
38375	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32570	\N	\N	\N
38307	MEMBRE	2023-10-31 00:00:00	2024-02-26 00:00:00	ACTIF	\N	\N	\N	\N	32502	\N	\N	\N
38308	MEMBRE	2023-10-31 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	32503	\N	\N	\N
38309	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32504	\N	\N	\N
38310	MEMBRE	2023-10-31 00:00:00	2024-01-04 00:00:00	ANCIEN	\N	\N	\N	\N	32505	\N	\N	\N
38311	MEMBRE	2023-10-31 00:00:00	2023-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	32506	\N	\N	\N
38312	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32507	\N	\N	\N
38325	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32520	\N	\N	\N
38326	MEMBRE	2023-10-31 00:00:00	2024-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	32521	\N	\N	\N
38327	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32522	\N	\N	\N
38608	MEMBRE	2023-11-08 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	32803	\N	\N	\N
39265	MEMBRE	2023-12-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33309	\N	\N	\N
39272	PDT	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33313	\N	\N	\N
39273	VICPDT	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31698	\N	\N	\N
39274	VICPDT	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33249	\N	\N	\N
39275	VICPDT	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33052	\N	\N	\N
39276	VICPDT	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32114	\N	\N	\N
39277	VICPDT	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31270	\N	\N	\N
39278	VICPDT	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30893	\N	\N	\N
39279	VICPDT	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32587	\N	\N	\N
39280	VICPDT	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32855	\N	\N	\N
39281	SECRET	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30987	\N	\N	\N
39282	SECRET	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31239	\N	\N	\N
39283	SECRET	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31352	\N	\N	\N
39284	SECRET	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32809	\N	\N	\N
39285	SECRET	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32577	\N	\N	\N
39286	SECRET	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32831	\N	\N	\N
39287	PDTDEL	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour l'île Maurice	\N	33314	\N	\N	\N
39288	MEMBRE	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33316	\N	\N	\N
39292	VICPDT	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31213	\N	\N	\N
39293	VICPDT	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32882	\N	\N	\N
39294	VICPDT	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31167	\N	\N	\N
39295	SECRET	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32994	\N	\N	\N
39296	VICPDT	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32891	\N	\N	\N
39297	VICPDTDEL	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	aux relations de voisinage avec les collectivités d'outre-mer	\N	31786	\N	\N	\N
39298	VICPDT	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31106	\N	\N	\N
39299	VICPDT	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33212	\N	\N	\N
39300	VICPDT	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33208	\N	\N	\N
39301	VICPDT	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31394	\N	\N	\N
39302	SECRET	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32727	\N	\N	\N
39303	SECRET	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31006	\N	\N	\N
39304	SECRET	2023-12-08 00:00:00	2024-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	33006	\N	\N	\N
39305	SECRET	2023-12-08 00:00:00	2024-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	30931	\N	\N	\N
39306	SECRET	2023-12-08 00:00:00	2024-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	32444	\N	\N	\N
39474	MEMBRE	2023-12-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33384	\N	\N	\N
41354	MEMBRE	2024-01-02 00:00:00	\N	\N	\N	\N	\N	\N	30797	\N	\N	\N
41488	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34476	\N	\N	\N
30717	MEMBRE	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26418	\N	2018-02-09 12:02:47	\N
30753	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26426	\N	\N	\N
30755	MEMBRE	2017-10-01 00:00:00	2018-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	26428	\N	\N	\N
30756	MEMBRE	2017-10-01 00:00:00	2018-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	26429	\N	\N	\N
30757	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26430	\N	\N	\N
30884	MEMBRE	2017-10-01 00:00:00	2018-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	26520	\N	\N	\N
30886	MEMBRE	2017-10-01 00:00:00	2018-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	26522	\N	\N	\N
31096	MEMBRE	2017-10-01 00:00:00	2018-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	26624	\N	\N	\N
31161	MEMBRE	2018-03-07 00:00:00	2018-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	26685	\N	\N	\N
31162	MEMBRE	2018-03-07 00:00:00	2018-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	26686	\N	\N	\N
31163	MEMBRE	2018-03-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26687	\N	\N	\N
31164	MEMBRE	2018-03-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26688	\N	\N	\N
31166	MEMBRE	2018-03-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26690	\N	\N	\N
31194	VICPDT	2018-03-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	26686	\N	\N	\N
31246	VICPDT	2018-02-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	26112	\N	\N	\N
31247	VICPDT	2018-02-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	26093	\N	\N	\N
31255	MEMBRE	2018-01-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	26741	\N	\N	\N
31504	PDT	2019-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26943	\N	\N	\N
32394	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27823	\N	\N	\N
32395	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27824	\N	\N	\N
32396	MEMBRE	2020-10-15 00:00:00	2021-01-03 00:00:00	ANCIEN	\N	\N	\N	\N	27825	\N	\N	\N
34868	MEMBRE	2020-12-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	29651	\N	\N	\N
34900	MEMBRE	2021-01-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	29665	\N	\N	\N
34908	MEMBRE	2020-12-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	29673	\N	\N	\N
35331	MEMBRE	2021-01-25 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	29994	\N	\N	\N
35378	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30015	\N	\N	\N
35583	VICPDT	2021-01-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30035	\N	\N	\N
35669	PDT	2021-02-04 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29786	\N	\N	\N
35670	VICPDT	2021-02-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29776	\N	\N	\N
35939	MEMBRE	2020-10-01 00:00:00	2021-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	30243	\N	\N	\N
36044	VICPDT	2021-04-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27197	\N	\N	\N
36045	PDTHON	2021-04-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27151	\N	\N	\N
36113	VICPDT	2021-07-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	29589	\N	\N	\N
36136	MEMBRE	2021-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30398	\N	\N	\N
36137	MEMBRE	2021-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30399	\N	\N	\N
36139	MEMBRE	2021-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30401	\N	\N	\N
36142	MEMBRE	2021-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30404	\N	\N	\N
36284	MEMBRE	2022-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30519	\N	\N	\N
36289	VICPDT	2022-02-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29292	\N	\N	\N
36391	MEMBRE	2022-03-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30610	\N	\N	\N
36407	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30625	\N	\N	\N
36570	MEMBRE	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30787	\N	\N	\N
36670	PDTDEL	2023-09-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour la Tanzanie	\N	28253	\N	\N	\N
36685	MEMBRE	2023-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30875	\N	\N	\N
36675	MEMBRE	2023-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30865	\N	\N	\N
36679	MEMBRE	2023-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30869	\N	\N	\N
36680	MEMBRE	2023-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30870	\N	\N	\N
36681	MEMBRE	2023-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30871	\N	\N	\N
36682	MEMBRE	2023-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30872	\N	\N	\N
36686	MEMBRE	2023-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30876	\N	\N	\N
37273	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31465	\N	\N	\N
37274	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31466	\N	\N	\N
37275	MEMBRE	2023-10-11 00:00:00	2023-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	31467	\N	\N	\N
37276	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31468	\N	\N	\N
37277	MEMBRE	2023-10-11 00:00:00	2024-02-26 00:00:00	ACTIF	\N	\N	\N	\N	31469	\N	\N	\N
37278	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31470	\N	\N	\N
37279	MEMBRE	2023-10-11 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	31471	\N	\N	\N
37280	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31472	\N	\N	\N
37281	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31473	\N	\N	\N
37282	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31474	\N	\N	\N
37283	MEMBRE	2023-10-11 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	31475	\N	\N	\N
37305	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31497	\N	\N	\N
37306	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31498	\N	\N	\N
37307	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31499	\N	\N	\N
37308	MEMBRE	2023-10-11 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	31500	\N	\N	\N
37309	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31501	\N	\N	\N
37310	MEMBRE	2023-10-11 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	31502	\N	\N	\N
37311	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31503	\N	\N	\N
37312	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31504	\N	\N	\N
37393	MEMBRE	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31585	\N	\N	\N
37394	MEMBRE	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31586	\N	\N	\N
37395	MEMBRE	2023-10-12 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	31587	\N	\N	\N
37396	MEMBRE	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31588	\N	\N	\N
37397	MEMBRE	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31589	\N	\N	\N
37398	MEMBRE	2023-10-12 00:00:00	2024-02-26 00:00:00	ACTIF	\N	\N	\N	\N	31590	\N	\N	\N
37465	MEMBRE	2023-10-13 00:00:00	2024-01-25 00:00:00	ACTIF	\N	\N	\N	\N	31657	\N	\N	\N
37466	MEMBRE	2023-10-13 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	31658	\N	\N	\N
37467	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31659	\N	\N	\N
37468	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31660	\N	\N	\N
37469	MEMBRE	2023-10-13 00:00:00	2024-01-29 00:00:00	ACTIF	\N	\N	\N	\N	31661	\N	\N	\N
37470	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31662	\N	\N	\N
37489	MEMBRE	2023-10-13 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	31681	\N	\N	\N
37490	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31682	\N	\N	\N
37491	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31683	\N	\N	\N
37492	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31684	\N	\N	\N
37493	MEMBRE	2023-10-13 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	31685	\N	\N	\N
37494	MEMBRE	2023-10-13 00:00:00	2024-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	31686	\N	\N	\N
37495	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31687	\N	\N	\N
37496	MEMBRE	2023-10-13 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	31688	\N	\N	\N
37497	MEMBRE	2023-10-13 00:00:00	2024-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	31689	\N	\N	\N
37498	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31690	\N	\N	\N
37499	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31691	\N	\N	\N
37500	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31692	\N	\N	\N
37501	MEMBRE	2023-10-13 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	31693	\N	\N	\N
37502	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31694	\N	\N	\N
37503	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31695	\N	\N	\N
37508	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31700	\N	\N	\N
37509	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31701	\N	\N	\N
37510	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31702	\N	\N	\N
37511	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31703	\N	\N	\N
37512	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31704	\N	\N	\N
37513	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31705	\N	\N	\N
37514	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31706	\N	\N	\N
37515	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31707	\N	\N	\N
37516	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31708	\N	\N	\N
37517	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31709	\N	\N	\N
37518	MEMBRE	2023-10-13 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	31710	\N	\N	\N
37519	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31711	\N	\N	\N
37520	MEMBRE	2023-10-13 00:00:00	2024-01-25 00:00:00	ACTIF	\N	\N	\N	\N	31712	\N	\N	\N
37521	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31713	\N	\N	\N
37522	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31714	\N	\N	\N
37523	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31715	\N	\N	\N
37524	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31716	\N	\N	\N
37525	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31717	\N	\N	\N
37526	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31718	\N	\N	\N
37527	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31719	\N	\N	\N
37528	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31720	\N	\N	\N
37529	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31721	\N	\N	\N
37530	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31722	\N	\N	\N
37531	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31723	\N	\N	\N
37532	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31724	\N	\N	\N
37533	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31725	\N	\N	\N
37534	MEMBRE	2023-10-13 00:00:00	2024-02-29 00:00:00	ACTIF	\N	\N	\N	\N	31726	\N	\N	\N
37535	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31727	\N	\N	\N
37536	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31728	\N	\N	\N
37537	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31729	\N	\N	\N
37594	MEMBRE	2023-10-16 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	31786	\N	\N	\N
37595	MEMBRE	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31787	\N	\N	\N
37596	MEMBRE	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31788	\N	\N	\N
37597	MEMBRE	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31789	\N	\N	\N
37598	MEMBRE	2023-10-16 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	31790	\N	\N	\N
37599	MEMBRE	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31791	\N	\N	\N
37600	MEMBRE	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31792	\N	\N	\N
37601	MEMBRE	2023-10-16 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	31793	\N	\N	\N
37602	MEMBRE	2023-10-16 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	31794	\N	\N	\N
37603	MEMBRE	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31795	\N	\N	\N
37604	MEMBRE	2023-10-16 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	31796	\N	\N	\N
37605	MEMBRE	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31797	\N	\N	\N
38319	MEMBRE	2023-10-31 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	32514	\N	\N	\N
38320	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32515	\N	\N	\N
38321	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32516	\N	\N	\N
38322	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32517	\N	\N	\N
38323	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32518	\N	\N	\N
38324	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32519	\N	\N	\N
38572	MEMBRE	2023-11-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32767	\N	\N	\N
38573	MEMBRE	2023-11-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32768	\N	\N	\N
38574	MEMBRE	2023-11-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32769	\N	\N	\N
38575	MEMBRE	2023-11-07 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	32770	\N	\N	\N
38576	MEMBRE	2023-11-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32771	\N	\N	\N
38577	MEMBRE	2023-11-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32772	\N	\N	\N
38578	MEMBRE	2023-11-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32773	\N	\N	\N
38579	MEMBRE	2023-11-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32774	\N	\N	\N
38580	MEMBRE	2023-11-07 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	32775	\N	\N	\N
38581	MEMBRE	2023-11-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32776	\N	\N	\N
38582	MEMBRE	2023-11-07 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	32777	\N	\N	\N
38583	MEMBRE	2023-11-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32778	\N	\N	\N
38584	MEMBRE	2023-11-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32779	\N	\N	\N
38585	MEMBRE	2023-11-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32780	\N	\N	\N
39456	VICPDT	2023-12-14 00:00:00	2024-01-04 00:00:00	ANCIEN	\N	\N	\N	\N	30997	\N	\N	\N
39457	VICPDT	2023-12-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31831	\N	\N	\N
39458	VICPDT	2023-12-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31015	\N	\N	\N
39459	VICPDT	2023-12-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30956	\N	\N	\N
39460	VICPDT	2023-12-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32752	\N	\N	\N
39461	VICPDT	2023-12-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32494	\N	\N	\N
39462	VICPDT	2023-12-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31604	\N	\N	\N
39463	VICPDT	2023-12-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31940	\N	\N	\N
39464	VICPDT	2023-12-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31765	\N	\N	\N
39465	VICPDT	2023-12-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32878	\N	\N	\N
39466	VICPDT	2023-12-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31117	\N	\N	\N
39467	VICPDT	2023-12-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32618	\N	\N	\N
39468	SECRET	2023-12-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31918	\N	\N	\N
39469	SECRET	2023-12-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32440	\N	\N	\N
39470	SECRET	2023-12-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33139	\N	\N	\N
39471	SECRET	2023-12-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32549	\N	\N	\N
39787	MEMBRE	2024-01-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33466	\N	\N	\N
39853	MEMBRE	2024-01-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33521	\N	\N	\N
39854	MEMBRE	2024-01-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33522	\N	\N	\N
41371	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34373	\N	\N	\N
41373	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34375	\N	\N	\N
41374	MEMBRE	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	34376	\N	\N	\N
30850	VICPDT	2018-02-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	26064	\N	\N	\N
30853	VICPDT	2018-02-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	26082	\N	\N	\N
30888	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26524	\N	\N	\N
30890	MEMBRE	2017-10-01 00:00:00	2018-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	26526	\N	\N	\N
30891	MEMBRE	2017-10-01 00:00:00	2018-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	26527	\N	\N	\N
30896	MEMBRE	2017-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26532	\N	\N	\N
31226	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26720	\N	\N	\N
31301	MEMBRE	2018-05-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26770	\N	2018-06-01 15:48:42	\N
31302	MEMBRE	2018-05-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26771	\N	2018-06-01 15:49:28	\N
31405	MEMBRE	2018-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26866	\N	\N	\N
31406	MEMBRE	2018-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26867	\N	\N	\N
31484	MEMBRE	2019-01-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	26940	\N	\N	\N
31506	MEMBRE	2019-01-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26960	\N	\N	\N
31507	MEMBRE	2019-02-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	26961	\N	\N	\N
31525	MEMBRE	2019-02-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	26977	\N	\N	\N
32976	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28409	\N	\N	\N
32977	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28410	\N	\N	\N
32978	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28411	\N	\N	\N
32979	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28412	\N	\N	\N
32980	MEMBRE	2020-10-27 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	28413	\N	\N	\N
32981	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28414	\N	\N	\N
32982	MEMBRE	2020-10-27 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	28415	\N	\N	\N
32983	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28416	\N	\N	\N
32984	MEMBRE	2020-10-27 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	28417	\N	\N	\N
32985	MEMBRE	2020-10-27 00:00:00	2022-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	28418	\N	\N	\N
32986	MEMBRE	2020-10-27 00:00:00	2021-01-14 00:00:00	ANCIEN	\N	\N	\N	\N	28419	\N	\N	\N
32987	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28420	\N	\N	\N
32988	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28421	\N	\N	\N
32989	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28422	\N	\N	\N
32990	MEMBRE	2020-10-27 00:00:00	2021-01-03 00:00:00	ANCIEN	\N	\N	\N	\N	28423	\N	\N	\N
32991	MEMBRE	2020-10-27 00:00:00	2020-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	28424	\N	\N	\N
32992	MEMBRE	2020-10-27 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	28425	\N	\N	\N
32993	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28426	\N	\N	\N
32994	MEMBRE	2020-10-27 00:00:00	2022-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	28427	\N	\N	\N
33448	MEMBRE	2020-10-30 00:00:00	2020-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	28870	\N	\N	\N
33481	MEMBRE	2020-10-22 00:00:00	2021-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	28903	\N	\N	\N
33482	MEMBRE	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28904	\N	\N	\N
33483	MEMBRE	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28905	\N	\N	\N
33484	MEMBRE	2020-11-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28906	\N	\N	\N
33643	MEMBRE	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28991	\N	\N	\N
33644	MEMBRE	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28992	\N	\N	\N
33645	MEMBRE	2020-11-17 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	28993	\N	\N	\N
33646	MEMBRE	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28994	\N	\N	\N
33647	MEMBRE	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28995	\N	\N	\N
34728	VICPDT	2020-12-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28272	\N	\N	\N
35004	MEMBRE	2020-12-15 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	29752	\N	\N	\N
34730	VICPDT	2020-12-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28308	\N	\N	\N
34731	SECRET	2020-12-24 00:00:00	2021-01-03 00:00:00	ANCIEN	\N	\N	\N	\N	29177	\N	\N	\N
34732	VICPDT	2020-12-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27190	\N	\N	\N
34733	VICPDT	2020-12-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28312	\N	\N	\N
34734	VICPDT	2020-12-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29116	\N	\N	\N
34735	SECRET	2020-12-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27179	\N	\N	\N
34736	SECRET	2020-12-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29113	\N	\N	\N
34737	VICPDT	2020-12-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27733	\N	\N	\N
34738	VICPDT	2020-12-24 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	27445	\N	\N	\N
34739	VICPDT	2020-12-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27929	\N	\N	\N
34740	VICPDT	2020-12-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28553	\N	\N	\N
34741	VICPDT	2020-12-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27779	\N	\N	\N
34742	VICPDT	2020-12-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27412	\N	\N	\N
34743	SECRET	2020-12-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28072	\N	\N	\N
34744	SECRET	2020-12-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28255	\N	\N	\N
34745	SECRET	2020-12-24 00:00:00	2022-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	27125	\N	\N	\N
34746	SECRET	2020-12-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27648	\N	\N	\N
34747	SECRET	2020-12-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28475	\N	\N	\N
34870	MEMBRE	2021-01-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29653	\N	\N	\N
34914	MEMBRE	2021-01-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29679	\N	\N	\N
35020	MEMBRE	2021-01-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	29764	\N	\N	\N
35094	MEMBRE	2020-10-01 00:00:00	2021-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	29818	\N	\N	\N
35154	MEMBRE	2020-10-01 00:00:00	2021-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	29878	\N	\N	\N
35247	MEMBRE	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29955	\N	\N	\N
35286	VICPDT	2021-01-19 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29249	\N	\N	\N
35287	VICPDT	2021-01-19 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29251	\N	\N	\N
35314	PDTHON	2021-01-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28213	\N	\N	\N
35315	VICPDT	2021-01-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29001	\N	\N	\N
35316	VICPDT	2021-01-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28625	\N	\N	\N
35317	VICPDT	2021-01-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27201	\N	\N	\N
35318	SECRET	2021-01-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28244	\N	\N	\N
35319	SECRET	2021-01-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27906	\N	\N	\N
35320	VICPDT	2021-01-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29017	\N	\N	\N
35488	VICPDT	2021-01-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	30065	\N	\N	\N
35587	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30088	\N	\N	\N
35634	MEMBRE	2021-02-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	30119	\N	\N	\N
35635	MEMBRE	2021-02-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	30120	\N	\N	\N
35665	VICPDT	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30131	\N	\N	\N
35676	VICPDT	2021-02-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29804	\N	\N	\N
35678	VICPDT	2021-02-04 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	30008	\N	\N	\N
35679	VICPDT	2021-02-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	29810	\N	\N	\N
35680	VICPDT	2021-02-04 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29788	\N	\N	\N
35826	MEMBRE	2021-02-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	30202	\N	\N	\N
35921	MEMBRE	2021-03-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	30233	\N	\N	\N
35922	MEMBRE	2021-03-05 00:00:00	2021-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	30234	\N	\N	\N
35993	MEMBRE	2021-03-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30290	\N	\N	\N
35994	MEMBRE	2021-03-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30291	\N	\N	\N
36053	MEMBRE	2021-05-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30334	\N	\N	\N
36135	MEMBRE	2021-10-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30397	\N	\N	\N
36243	MEMBRE	2021-11-23 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	30488	\N	\N	\N
36244	MEMBRE	2021-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30489	\N	\N	\N
36246	MEMBRE	2021-12-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30490	\N	\N	\N
36247	MEMBRE	2021-12-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30491	\N	\N	\N
36256	MEMBRE	2021-12-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30500	\N	\N	\N
36378	MEMBRE	2022-04-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30604	\N	\N	\N
36399	MEMBRE	2022-04-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30617	\N	\N	\N
36657	VICPDT	2023-07-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27378	\N	\N	\N
36658	VICPDT	2023-07-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28109	\N	\N	\N
36659	VICPDT	2023-07-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29198	\N	\N	\N
36763	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30953	\N	\N	\N
36764	MEMBRE	2023-10-09 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	30954	\N	\N	\N
36765	MEMBRE	2023-10-09 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	30955	\N	\N	\N
36766	MEMBRE	2023-10-09 00:00:00	2023-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	30956	\N	\N	\N
36767	MEMBRE	2023-10-09 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	30957	\N	\N	\N
36768	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30958	\N	\N	\N
36769	MEMBRE	2023-10-09 00:00:00	2024-03-05 00:00:00	ACTIF	\N	\N	\N	\N	30959	\N	\N	\N
37182	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31374	\N	\N	\N
37183	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31375	\N	\N	\N
37184	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31376	\N	\N	\N
37185	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31377	\N	\N	\N
37218	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31410	\N	\N	\N
37219	MEMBRE	2023-10-10 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	31411	\N	\N	\N
37220	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31412	\N	\N	\N
37221	MEMBRE	2023-10-10 00:00:00	2023-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	31413	\N	\N	\N
37222	MEMBRE	2023-10-10 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	31414	\N	\N	\N
37223	MEMBRE	2023-10-10 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	31415	\N	\N	\N
37361	MEMBRE	2023-10-11 00:00:00	2024-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	31553	\N	\N	\N
37362	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31554	\N	\N	\N
37363	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31555	\N	\N	\N
37364	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31556	\N	\N	\N
38082	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32277	\N	\N	\N
38083	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32278	\N	\N	\N
38084	MEMBRE	2023-10-24 00:00:00	2024-01-28 00:00:00	ACTIF	\N	\N	\N	\N	32279	\N	\N	\N
38085	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32280	\N	\N	\N
38086	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32281	\N	\N	\N
38087	MEMBRE	2023-10-24 00:00:00	2023-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	32282	\N	\N	\N
38088	MEMBRE	2023-10-24 00:00:00	2023-12-11 00:00:00	ANCIEN	\N	\N	\N	\N	32283	\N	\N	\N
38089	MEMBRE	2023-10-24 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	32284	\N	\N	\N
38090	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32285	\N	\N	\N
38091	MEMBRE	2023-10-24 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	32286	\N	\N	\N
39116	MEMBRE	2023-11-28 00:00:00	2024-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	33169	\N	\N	\N
39117	MEMBRE	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33170	\N	\N	\N
39167	MEMBRE	2023-11-30 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	33212	\N	\N	\N
39696	MEMBRE	2023-12-22 00:00:00	2024-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	30204	\N	\N	\N
40069	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33646	\N	\N	\N
40326	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33834	\N	\N	\N
40328	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	30731	\N	\N	\N
40329	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33835	\N	\N	\N
41398	MEMBRE	2024-01-02 00:00:00	\N	\N	\N	\N	\N	\N	34400	\N	\N	\N
30718	MEMBRE	2018-02-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26419	\N	2018-02-09 15:23:59	\N
30719	MEMBRE	2018-02-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26420	\N	2018-02-09 15:24:24	\N
30781	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26454	\N	\N	\N
30782	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26455	\N	\N	\N
30793	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26466	\N	\N	\N
30797	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26470	\N	\N	\N
30854	VICPDT	2018-02-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26242	\N	\N	\N
30855	SECRET	2018-02-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	26060	\N	\N	\N
30932	VICPDT	2018-02-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	26111	\N	\N	\N
30933	PDT	2018-02-15 00:00:00	2019-09-25 00:00:00	ANCIEN	\N	\N	\N	\N	26114	\N	\N	\N
31078	VICPDT	2018-03-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26391	\N	\N	\N
31236	MEMBRE	2018-03-26 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	26730	\N	2018-03-29 15:18:13	\N
31335	VICPDT	2018-09-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24891	\N	\N	\N
31336	MEMBRE	2018-09-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26799	\N	\N	\N
31381	MEMBRE	2018-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26843	\N	\N	\N
31481	MEMBRE	2017-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26938	\N	\N	\N
31542	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26994	\N	\N	\N
32590	MEMBRE	2020-10-20 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	28019	\N	\N	\N
32968	MEMBRE	2020-10-26 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	28401	\N	\N	\N
32969	MEMBRE	2020-10-26 00:00:00	2021-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	28402	\N	\N	\N
32970	MEMBRE	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28403	\N	\N	\N
32971	MEMBRE	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28404	\N	\N	\N
32972	MEMBRE	2020-10-16 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	28405	\N	\N	\N
32973	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28406	\N	\N	\N
32974	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28407	\N	\N	\N
32975	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28408	\N	\N	\N
33715	MEMBRE	2020-11-13 00:00:00	2023-09-28 00:00:00	ANCIEN	\N	\N	\N	\N	29027	\N	\N	\N
33716	MEMBRE	2020-11-13 00:00:00	2023-09-28 00:00:00	ANCIEN	\N	\N	\N	\N	29028	\N	\N	\N
33717	MEMBRE	2020-11-23 00:00:00	2023-09-28 00:00:00	ANCIEN	\N	\N	\N	\N	29029	\N	\N	\N
33718	MEMBRE	2020-11-23 00:00:00	2023-09-28 00:00:00	ANCIEN	\N	\N	\N	\N	29030	\N	\N	\N
33719	MEMBRE	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29031	\N	\N	\N
34416	PDT	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29293	\N	\N	\N
34653	MEMBRE	2020-12-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29511	\N	\N	\N
34716	MEMBRE	2020-12-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	29556	\N	\N	\N
34895	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29660	\N	\N	\N
34896	MEMBRE	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29661	\N	\N	\N
34897	MEMBRE	2021-12-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	29662	\N	\N	\N
34899	MEMBRE	2021-01-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	29664	\N	\N	\N
34986	MEMBRE	2021-01-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29734	\N	\N	\N
34987	MEMBRE	2021-01-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29735	\N	\N	\N
34988	MEMBRE	2021-01-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29736	\N	\N	\N
34990	MEMBRE	2021-01-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29738	\N	\N	\N
34997	MEMBRE	2021-01-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29745	\N	\N	\N
34998	MEMBRE	2021-01-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	29746	\N	\N	\N
35000	MEMBRE	2021-01-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29748	\N	\N	\N
35009	MEMBRE	2021-01-07 00:00:00	2022-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	29757	\N	\N	\N
35010	MEMBRE	2021-01-14 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29758	\N	\N	\N
35530	SECRET	2021-01-13 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29447	\N	\N	\N
35758	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30153	\N	\N	\N
35861	SECRET	2021-02-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	30151	\N	\N	\N
35877	MEMBRE	2021-02-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	30211	\N	\N	\N
35893	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30217	\N	\N	\N
36092	MEMBRE	2021-06-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30366	\N	\N	\N
36133	MEMBRE	2021-09-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30395	\N	\N	\N
36254	MEMBRE	2021-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30498	\N	\N	\N
36427	MEMBRE	2022-06-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30644	\N	\N	\N
37100	MEMBRE	2023-10-10 00:00:00	2024-02-29 00:00:00	ACTIF	\N	\N	\N	\N	31290	\N	\N	\N
37606	MEMBRE	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31798	\N	\N	\N
37607	MEMBRE	2023-10-16 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	31799	\N	\N	\N
37608	MEMBRE	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31800	\N	\N	\N
37609	MEMBRE	2023-10-16 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	31801	\N	\N	\N
37610	MEMBRE	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31802	\N	\N	\N
37611	MEMBRE	2023-10-16 00:00:00	2024-01-25 00:00:00	ACTIF	\N	\N	\N	\N	31803	\N	\N	\N
37612	MEMBRE	2023-10-16 00:00:00	2024-01-04 00:00:00	ANCIEN	\N	\N	\N	\N	31804	\N	\N	\N
37613	MEMBRE	2023-10-16 00:00:00	2024-02-08 00:00:00	ACTIF	\N	\N	\N	\N	31805	\N	\N	\N
37614	MEMBRE	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31806	\N	\N	\N
37674	MEMBRE	2023-10-17 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	31866	\N	\N	\N
37685	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31877	\N	\N	\N
37686	MEMBRE	2023-10-17 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	31878	\N	\N	\N
37687	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31879	\N	\N	\N
37864	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32056	\N	\N	\N
37865	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32057	\N	\N	\N
37866	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32058	\N	\N	\N
37867	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32059	\N	\N	\N
37868	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32060	\N	\N	\N
37869	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32061	\N	\N	\N
37870	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32062	\N	\N	\N
37871	MEMBRE	2023-10-18 00:00:00	2024-02-07 00:00:00	ACTIF	\N	\N	\N	\N	32063	\N	\N	\N
37880	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32072	\N	\N	\N
37881	MEMBRE	2023-10-18 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	32073	\N	\N	\N
37882	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32074	\N	\N	\N
37883	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32075	\N	\N	\N
37884	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32076	\N	\N	\N
37885	MEMBRE	2023-10-18 00:00:00	2024-02-27 00:00:00	ACTIF	\N	\N	\N	\N	32077	\N	\N	\N
37886	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32078	\N	\N	\N
37887	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32079	\N	\N	\N
37888	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32080	\N	\N	\N
37889	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32081	\N	\N	\N
37890	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32082	\N	\N	\N
37891	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32083	\N	\N	\N
37892	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32084	\N	\N	\N
37893	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32085	\N	\N	\N
37894	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32086	\N	\N	\N
37895	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32087	\N	\N	\N
37947	MEMBRE	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32142	\N	\N	\N
37948	MEMBRE	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32143	\N	\N	\N
37949	MEMBRE	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32144	\N	\N	\N
37950	MEMBRE	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32145	\N	\N	\N
37951	MEMBRE	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32146	\N	\N	\N
37952	MEMBRE	2023-10-19 00:00:00	2024-02-29 00:00:00	ACTIF	\N	\N	\N	\N	32147	\N	\N	\N
37953	MEMBRE	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32148	\N	\N	\N
37989	MEMBRE	2023-10-20 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	32184	\N	\N	\N
37990	MEMBRE	2023-10-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32185	\N	\N	\N
38024	MEMBRE	2023-10-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32219	\N	\N	\N
38025	MEMBRE	2023-10-23 00:00:00	2024-02-27 00:00:00	ACTIF	\N	\N	\N	\N	32220	\N	\N	\N
38029	MEMBRE	2023-10-23 00:00:00	2023-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	32224	\N	\N	\N
38030	MEMBRE	2023-10-23 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	32225	\N	\N	\N
38031	MEMBRE	2023-10-23 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	32226	\N	\N	\N
38034	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32229	\N	\N	\N
38035	MEMBRE	2023-10-24 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	32230	\N	\N	\N
38036	MEMBRE	2023-10-24 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	32231	\N	\N	\N
38037	MEMBRE	2023-10-24 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	32232	\N	\N	\N
38038	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32233	\N	\N	\N
38039	MEMBRE	2023-10-24 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	32234	\N	\N	\N
38040	MEMBRE	2023-10-24 00:00:00	2024-04-02 00:00:00	ACTIF	\N	\N	\N	\N	32235	\N	\N	\N
38041	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32236	\N	\N	\N
38042	MEMBRE	2023-10-24 00:00:00	2024-03-24 00:00:00	ACTIF	\N	\N	\N	\N	32237	\N	\N	\N
38043	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32238	\N	\N	\N
38118	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32313	\N	\N	\N
38119	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32314	\N	\N	\N
38120	MEMBRE	2023-10-24 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	32315	\N	\N	\N
38121	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32316	\N	\N	\N
38169	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32364	\N	\N	\N
38170	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32365	\N	\N	\N
38171	MEMBRE	2023-10-25 00:00:00	2024-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	32366	\N	\N	\N
38172	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32367	\N	\N	\N
38173	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32368	\N	\N	\N
38174	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32369	\N	\N	\N
38175	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32370	\N	\N	\N
38176	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32371	\N	\N	\N
38177	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32372	\N	\N	\N
38178	MEMBRE	2023-10-25 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	32373	\N	\N	\N
38179	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32374	\N	\N	\N
38180	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32375	\N	\N	\N
38181	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32376	\N	\N	\N
38182	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32377	\N	\N	\N
38183	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32378	\N	\N	\N
39106	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour le Bangladesh	\N	33165	\N	\N	\N
39113	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour le Soudan	\N	33166	\N	\N	\N
39902	MEMBRE	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33531	\N	\N	\N
40178	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33707	\N	\N	\N
40179	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33708	\N	\N	\N
40304	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	30798	\N	\N	\N
40918	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	30764	\N	\N	\N
41247	VICPDT	2024-02-13 00:00:00	\N	\N	\N	\N	\N	\N	33891	\N	\N	\N
41351	MEMBRE	2024-01-02 00:00:00	\N	\N	\N	\N	\N	\N	34364	\N	\N	\N
41484	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34472	\N	\N	\N
41485	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34473	\N	\N	\N
41486	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34474	\N	\N	\N
40779	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34210	\N	\N	\N
40780	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34211	\N	\N	\N
40787	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34218	\N	\N	\N
40788	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34219	\N	\N	\N
40806	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	34222	\N	\N	\N
40833	MEMBRE	2023-10-01 00:00:00	2024-02-27 00:00:00	ACTIF	\N	\N	\N	\N	34236	\N	\N	\N
40838	MEMBRE	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34241	\N	\N	\N
40851	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34243	\N	\N	\N
40881	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34245	\N	\N	\N
40887	VICPDT	2024-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	30729	\N	\N	\N
40888	VICPDT	2024-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	30726	\N	\N	\N
40898	VICPDT	2024-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	33566	\N	\N	\N
40905	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	34248	\N	\N	\N
40924	MEMBRE	2024-01-02 00:00:00	2024-02-06 00:00:00	ACTIF	\N	\N	\N	\N	34253	\N	\N	\N
40926	VICPDT	2024-01-25 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31446	\N	\N	\N
40927	MEMBRE	2024-01-25 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31014	\N	\N	\N
40928	VICPDT	2024-01-25 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	33076	\N	\N	\N
40929	VICPDT	2024-01-25 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	33082	\N	\N	\N
40930	MEMBRE	2024-01-25 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31224	\N	\N	\N
40931	MEMBRE	2024-01-25 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	29801	\N	\N	\N
40932	MEMBRE	2024-01-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34254	\N	\N	\N
40938	MEMBRE	2024-01-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34260	\N	\N	\N
40942	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34264	\N	\N	\N
40952	MEMBRE	2023-10-01 00:00:00	2024-04-08 00:00:00	\N	\N	\N	\N	\N	34265	\N	\N	\N
40974	MEMBRE	2024-01-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34266	\N	\N	\N
41004	VICPDT	2024-01-30 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	29789	\N	\N	\N
41005	VICPDT	2024-01-30 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	33405	\N	\N	\N
41006	VICPDT	2024-01-30 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	29788	\N	\N	\N
41007	VICPDT	2024-01-30 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	29785	\N	\N	\N
41011	VICPDT	2024-01-30 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	30147	\N	\N	\N
41016	MEMBRE	2024-01-30 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34270	\N	\N	\N
41059	MEMBRE	2023-12-14 00:00:00	\N	\N	\N	\N	\N	\N	34282	\N	\N	\N
41061	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34284	\N	\N	\N
41063	MEMBRE	2023-12-14 00:00:00	\N	\N	\N	\N	\N	\N	34286	\N	\N	\N
41076	MEMBRE	2024-02-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34290	\N	\N	\N
41077	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34291	\N	\N	\N
41103	PDT	2024-02-07 00:00:00	\N	\N	\N	\N	\N	\N	33621	\N	\N	\N
41098	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34300	\N	\N	\N
41101	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34303	\N	\N	\N
41104	VICPDT	2024-02-07 00:00:00	\N	\N	\N	\N	\N	\N	33699	\N	\N	\N
41105	VICPDT	2024-02-07 00:00:00	\N	\N	\N	\N	\N	\N	33634	\N	\N	\N
41106	VICPDT	2024-02-07 00:00:00	\N	\N	\N	\N	\N	\N	34183	\N	\N	\N
41108	VICPDT	2024-02-07 00:00:00	\N	\N	\N	\N	\N	\N	33620	\N	\N	\N
41109	VICPDT	2024-02-07 00:00:00	\N	\N	\N	\N	\N	\N	34253	\N	\N	\N
41110	VICPDT	2024-02-07 00:00:00	\N	\N	\N	\N	\N	\N	33636	\N	\N	\N
41111	VICPDT	2024-02-07 00:00:00	\N	\N	\N	\N	\N	\N	34185	\N	\N	\N
41112	VICPDT	2024-02-07 00:00:00	\N	\N	\N	\N	\N	\N	33703	\N	\N	\N
41119	VICPDT	2024-02-07 00:00:00	\N	\N	\N	\N	\N	\N	34047	\N	\N	\N
41233	VICPDT	2024-02-14 00:00:00	\N	\N	\N	\N	\N	\N	33936	\N	\N	\N
41135	VICPDT	2024-02-07 00:00:00	\N	\N	\N	\N	\N	\N	34144	\N	\N	\N
41138	VICPDT	2024-02-07 00:00:00	\N	\N	\N	\N	\N	\N	34172	\N	\N	\N
41154	MEMBRE	2024-02-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34310	\N	\N	\N
41166	MEMBRE	2023-12-14 00:00:00	\N	\N	\N	\N	\N	\N	34315	\N	\N	\N
41167	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34316	\N	\N	\N
41168	MEMBRE	2023-12-14 00:00:00	\N	\N	\N	\N	\N	\N	34317	\N	\N	\N
41187	MEMBRE	2024-02-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34322	\N	\N	\N
41197	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34330	\N	\N	\N
41199	VICPDT	2024-02-13 00:00:00	\N	\N	\N	\N	\N	\N	34331	\N	\N	\N
41200	VICPDT	2024-02-13 00:00:00	\N	\N	\N	\N	\N	\N	34018	\N	\N	\N
41203	PDT	2024-02-13 00:00:00	\N	\N	\N	\N	\N	\N	34030	\N	\N	\N
41217	MEMBRE	2024-02-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34342	\N	\N	\N
41232	PDT	2024-02-14 00:00:00	\N	\N	\N	\N	\N	\N	33943	\N	\N	\N
41234	VICPDT	2024-02-14 00:00:00	\N	\N	\N	\N	\N	\N	33913	\N	\N	\N
41240	MEMBRE	2024-02-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34347	\N	\N	\N
41242	VICPDT	2024-02-13 00:00:00	\N	\N	\N	\N	\N	\N	33888	\N	\N	\N
41243	VICPDT	2024-02-13 00:00:00	\N	\N	\N	\N	\N	\N	34086	\N	\N	\N
41244	VICPDT	2024-02-13 00:00:00	\N	\N	\N	\N	\N	\N	34088	\N	\N	\N
41245	VICPDT	2024-02-13 00:00:00	\N	\N	\N	\N	\N	\N	34090	\N	\N	\N
41246	VICPDT	2024-02-13 00:00:00	\N	\N	\N	\N	\N	\N	34092	\N	\N	\N
41248	VICPDT	2024-02-13 00:00:00	\N	\N	\N	\N	\N	\N	34097	\N	\N	\N
41249	VICPDT	2024-02-13 00:00:00	\N	\N	\N	\N	\N	\N	34100	\N	\N	\N
41255	VICPDT	2024-02-14 00:00:00	\N	\N	\N	\N	\N	\N	33861	\N	\N	\N
41261	VICPDT	2024-02-14 00:00:00	\N	\N	\N	\N	\N	\N	33865	\N	\N	\N
41262	VICPDT	2024-02-14 00:00:00	\N	\N	\N	\N	\N	\N	33935	\N	\N	\N
41263	VICPDT	2024-02-14 00:00:00	\N	\N	\N	\N	\N	\N	33938	\N	\N	\N
41264	SECRET	2024-02-14 00:00:00	\N	\N	\N	\N	\N	\N	33862	\N	\N	\N
41265	SECRET	2024-02-14 00:00:00	\N	\N	\N	\N	\N	\N	33882	\N	\N	\N
41267	SECRET	2024-02-14 00:00:00	\N	\N	\N	\N	\N	\N	33898	\N	\N	\N
41271	VICPDT	2024-02-20 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31631	\N	\N	\N
41272	PDTHON	2024-02-20 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	33200	\N	\N	\N
41273	VICPDT	2024-02-20 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31018	\N	\N	\N
41274	VICPDT	2024-02-20 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32783	\N	\N	\N
41275	SECRET	2024-02-20 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31171	\N	\N	\N
41276	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34349	\N	\N	\N
41277	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34350	\N	\N	\N
41280	MEMBRE	2023-12-14 00:00:00	\N	\N	\N	\N	\N	\N	34352	\N	\N	\N
41282	MEMBRE	2023-12-14 00:00:00	\N	\N	\N	\N	\N	\N	34354	\N	\N	\N
41289	MEMBRE	2023-12-14 00:00:00	\N	\N	\N	\N	\N	\N	34361	\N	\N	\N
41291	VICPDT	2024-02-27 00:00:00	\N	\N	\N	\N	\N	\N	33919	\N	\N	\N
41295	VICPDT	2024-02-27 00:00:00	\N	\N	\N	\N	\N	\N	33914	\N	\N	\N
41296	VICPDT	2024-02-27 00:00:00	\N	\N	\N	\N	\N	\N	34345	\N	\N	\N
41297	VICPDT	2024-02-27 00:00:00	\N	\N	\N	\N	\N	\N	33961	\N	\N	\N
41318	VICPDT	2024-02-28 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31834	\N	\N	\N
41319	VICPDT	2024-02-28 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31125	\N	\N	\N
41320	VICPDT	2024-02-28 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31615	\N	\N	\N
41321	VICPDT	2024-02-28 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31079	\N	\N	\N
41322	VICPDT	2024-02-28 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32581	\N	\N	\N
41323	VICPDT	2024-02-28 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31655	\N	\N	\N
41324	VICPDT	2024-02-28 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32513	\N	\N	\N
41325	VICPDT	2024-02-28 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31324	\N	\N	\N
41326	VICPDT	2024-02-28 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32220	\N	\N	\N
41327	VICPDT	2024-02-28 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31430	\N	\N	\N
41328	VICPDT	2024-02-28 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32350	\N	\N	\N
41329	VICPDT	2024-02-28 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32742	\N	\N	\N
41330	VICPDT	2024-02-28 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32907	\N	\N	\N
41331	SECRET	2024-02-28 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32823	\N	\N	\N
41332	SECRET	2024-02-28 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32485	\N	\N	\N
41333	SECRET	2024-02-28 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32077	\N	\N	\N
41334	SECRET	2024-02-28 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	33005	\N	\N	\N
41335	SECRET	2024-02-28 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32669	\N	\N	\N
41336	PDT	2024-02-28 00:00:00	\N	\N	\N	\N	\N	\N	34023	\N	\N	\N
41343	VICPDT	2024-02-28 00:00:00	\N	\N	\N	\N	\N	\N	34004	\N	\N	\N
41357	VICPDT	2024-03-01 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31726	\N	\N	\N
41358	VICPDT	2024-03-01 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31290	\N	\N	\N
41359	VICPDT	2024-03-01 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32704	\N	\N	\N
41360	VICPDT	2024-03-01 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31108	\N	\N	\N
41361	VICPDT	2024-03-01 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31203	\N	\N	\N
41362	VICPDT	2024-03-01 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	33365	\N	\N	\N
41363	VICPDT	2024-03-01 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32147	\N	\N	\N
41364	SECRET	2024-03-01 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	30972	\N	\N	\N
41365	SECRET	2024-03-01 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	30993	\N	\N	\N
41366	PDT	2024-03-05 00:00:00	\N	\N	\N	\N	\N	\N	30250	\N	\N	\N
41370	MEMBRE	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	34372	\N	\N	\N
41383	MEMBRE	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	34385	\N	\N	\N
41384	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34386	\N	\N	\N
41397	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34399	\N	\N	\N
41399	MEMBRE	2024-03-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34401	\N	\N	\N
41400	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34402	\N	\N	\N
41401	VICPDT	2024-03-06 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	33019	\N	\N	\N
41402	VICPDT	2024-03-06 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	30959	\N	\N	\N
41403	VICPDT	2024-03-06 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	33229	\N	\N	\N
41404	SECRET	2024-03-06 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31292	\N	\N	\N
41406	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34404	\N	\N	\N
41407	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34405	\N	\N	\N
41413	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34411	\N	\N	\N
41414	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34412	\N	\N	\N
41514	VICPDT	2024-03-25 00:00:00	\N	\N	\N	\N	\N	\N	34466	\N	\N	\N
41512	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34491	\N	\N	\N
41430	VICPDT	2024-02-14 00:00:00	\N	\N	\N	\N	\N	\N	34422	\N	\N	\N
41537	VICPDT	2024-03-19 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	34394	\N	\N	\N
41433	VICPDT	2024-02-14 00:00:00	\N	\N	\N	\N	\N	\N	34424	\N	\N	\N
41434	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34425	\N	\N	\N
41454	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34442	\N	\N	\N
41457	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34445	\N	\N	\N
41458	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34446	\N	\N	\N
41476	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34464	\N	\N	\N
41479	MEMBRE	2024-03-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34467	\N	\N	\N
41487	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34475	\N	\N	\N
41489	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34477	\N	\N	\N
41490	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34478	\N	\N	\N
41518	VICPDT	2024-03-25 00:00:00	\N	\N	\N	\N	\N	\N	34459	\N	\N	\N
41519	VICPDT	2024-03-25 00:00:00	\N	\N	\N	\N	\N	\N	34452	\N	\N	\N
41538	VICPDT	2024-03-19 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	34376	\N	\N	\N
41539	SECRET	2024-03-19 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	34377	\N	\N	\N
41548	VICPDT	2024-04-03 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32881	\N	\N	\N
41545	PDT	2024-04-03 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	34496	\N	\N	\N
41546	VICPDT	2024-04-03 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31071	\N	\N	\N
41547	VICPDT	2024-04-03 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31966	\N	\N	\N
41549	VICPDT	2024-04-03 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32036	\N	\N	\N
41550	VICPDT	2024-04-03 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31614	\N	\N	\N
41551	VICPDT	2024-04-03 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	33104	\N	\N	\N
41552	SECRET	2024-04-03 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32235	\N	\N	\N
30702	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26403	\N	\N	\N
30703	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26404	\N	\N	\N
30710	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26411	\N	\N	\N
30711	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26412	\N	\N	\N
30754	MEMBRE	2017-10-01 00:00:00	2018-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	26427	\N	\N	\N
30915	VICPDT	2018-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26542	\N	\N	\N
30955	VICPDT	2018-02-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	26359	\N	\N	\N
31062	PDTDEL	2018-03-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Luxembourg	\N	25622	\N	2018-03-06 12:07:57	2018-03-06 12:08:19
31063	VICPDT	2018-03-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24747	\N	2018-03-06 12:08:29	\N
31064	VICPDT	2018-03-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24895	\N	2018-03-06 12:08:47	\N
31065	VICPDT	2018-03-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24998	\N	2018-03-06 12:08:58	\N
31066	VICPDT	2018-03-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25224	\N	2018-03-06 12:09:06	\N
31067	VICPDT	2018-03-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25210	\N	2018-03-06 12:09:12	\N
31068	VICPDT	2018-03-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24246	\N	2018-03-06 12:09:18	\N
31069	SECRET	2018-03-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24321	\N	2018-03-06 12:10:25	\N
31070	SECRET	2018-03-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25233	\N	2018-03-06 12:10:33	\N
31071	SECRET	2018-03-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25200	\N	2018-03-06 12:10:47	\N
31102	MEMBRE	2018-03-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26627	\N	2018-03-12 09:45:42	\N
31103	MEMBRE	2018-03-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26628	\N	2018-03-12 09:45:42	\N
31104	MEMBRE	2018-03-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26629	\N	2018-03-12 09:45:42	\N
31105	MEMBRE	2018-03-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26630	\N	2018-03-12 09:45:42	\N
31106	MEMBRE	2018-03-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26631	\N	2018-03-12 09:45:42	\N
31107	MEMBRE	2018-03-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26632	\N	2018-03-12 09:45:42	\N
31108	MEMBRE	2018-03-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26633	\N	2018-03-12 09:45:42	\N
31109	MEMBRE	2018-03-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26634	\N	2018-03-12 09:45:42	\N
31110	MEMBRE	2018-03-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26635	\N	2018-03-12 09:45:42	\N
31111	MEMBRE	2018-03-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26636	\N	2018-03-12 09:45:42	\N
31112	MEMBRE	2018-03-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26637	\N	2018-03-12 09:45:42	\N
31113	MEMBRE	2018-03-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26638	\N	2018-03-12 09:45:42	\N
31114	MEMBRE	2018-03-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26639	\N	2018-03-12 09:45:42	\N
31115	MEMBRE	2018-03-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26640	\N	2018-03-12 09:45:42	\N
31116	SECRET	2018-03-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25666	\N	2018-03-12 09:48:57	\N
31213	MEMBRE	2017-12-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26707	\N	\N	\N
31215	MEMBRE	2017-12-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26709	\N	\N	\N
31222	MEMBRE	2017-12-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26716	\N	\N	\N
31456	MEMBRE	2018-11-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26917	\N	\N	\N
33890	MEMBRE	2020-11-30 00:00:00	2021-04-22 00:00:00	ANCIEN	\N	\N	\N	\N	29139	\N	\N	\N
33948	MEMBRE	2020-12-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29169	\N	\N	\N
33949	MEMBRE	2020-11-24 00:00:00	2020-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	29170	\N	\N	\N
33950	PDT	2020-12-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29170	\N	\N	\N
34148	MEMBRE	2020-12-08 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	29230	\N	\N	\N
34555	MEMBRE	2020-12-15 00:00:00	2021-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	29419	\N	\N	\N
34621	MEMBRE	2020-12-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	29480	\N	\N	\N
34757	MEMBRE	2020-12-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	29577	\N	\N	\N
34758	MEMBRE	2020-12-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	29578	\N	\N	\N
34759	MEMBRE	2020-12-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	29579	\N	\N	\N
34822	MEMBRE	2021-01-06 00:00:00	2021-01-06 00:00:00	ANCIEN	\N	\N	\N	\N	29605	\N	\N	\N
34973	MEMBRE	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29729	\N	\N	\N
34993	MEMBRE	2021-01-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29741	\N	\N	\N
34996	MEMBRE	2021-01-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	29744	\N	\N	\N
35246	MEMBRE	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29954	\N	\N	\N
35468	VICPDT	2021-01-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	29684	\N	\N	\N
35526	VICPDT	2021-01-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29487	\N	\N	\N
35632	MEMBRE	2021-02-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	30117	\N	\N	\N
35633	MEMBRE	2021-02-03 00:00:00	2021-10-26 00:00:00	ANCIEN	\N	\N	\N	\N	30118	\N	\N	\N
35639	MEMBRE	2021-02-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	30124	\N	\N	\N
35640	MEMBRE	2021-02-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	30125	\N	\N	\N
35962	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30262	\N	\N	\N
35963	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30263	\N	\N	\N
36099	MEMBRE	2021-07-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30372	\N	\N	\N
36100	MEMBRE	2021-07-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30373	\N	\N	\N
36216	MEMBRE	2021-11-03 00:00:00	2023-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	30461	\N	\N	\N
36217	MEMBRE	2021-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30462	\N	\N	\N
36218	MEMBRE	2021-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30463	\N	\N	\N
36471	MEMBRE	2022-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30688	\N	\N	\N
36490	MEMBRE	2022-11-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30707	\N	\N	\N
36491	MEMBRE	2022-11-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30708	\N	\N	\N
36492	MEMBRE	2022-11-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30709	\N	\N	\N
36493	MEMBRE	2022-11-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30710	\N	\N	\N
36494	MEMBRE	2022-11-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30711	\N	\N	\N
36495	MEMBRE	2022-11-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30712	\N	\N	\N
36496	MEMBRE	2022-11-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30713	\N	\N	\N
36497	MEMBRE	2022-11-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30714	\N	\N	\N
36594	MEMBRE	2023-01-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	30800	\N	\N	\N
36597	MEMBRE	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30803	\N	\N	\N
36639	MEMBRE	2023-05-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30837	\N	\N	\N
36918	MEMBRE	2023-10-09 00:00:00	2024-02-29 00:00:00	ACTIF	\N	\N	\N	\N	31108	\N	\N	\N
36919	MEMBRE	2023-10-09 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	31109	\N	\N	\N
36920	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31110	\N	\N	\N
36921	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31111	\N	\N	\N
36922	MEMBRE	2023-10-09 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	31112	\N	\N	\N
36923	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31113	\N	\N	\N
36924	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31114	\N	\N	\N
36925	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31115	\N	\N	\N
36926	MEMBRE	2023-10-09 00:00:00	2024-01-30 00:00:00	ACTIF	\N	\N	\N	\N	31116	\N	\N	\N
36927	MEMBRE	2023-10-09 00:00:00	2023-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	31117	\N	\N	\N
36928	MEMBRE	2023-10-09 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	31118	\N	\N	\N
37227	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31419	\N	\N	\N
37228	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31420	\N	\N	\N
37229	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31421	\N	\N	\N
37230	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31422	\N	\N	\N
37231	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31423	\N	\N	\N
37567	MEMBRE	2023-10-16 00:00:00	2024-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	31759	\N	\N	\N
37568	MEMBRE	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31760	\N	\N	\N
37569	MEMBRE	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31761	\N	\N	\N
37570	MEMBRE	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31762	\N	\N	\N
37571	MEMBRE	2023-10-16 00:00:00	2024-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	31763	\N	\N	\N
37572	MEMBRE	2023-10-16 00:00:00	2024-01-30 00:00:00	ACTIF	\N	\N	\N	\N	31764	\N	\N	\N
37573	MEMBRE	2023-10-16 00:00:00	2023-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	31765	\N	\N	\N
37574	MEMBRE	2023-10-16 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	31766	\N	\N	\N
37575	MEMBRE	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31767	\N	\N	\N
37576	MEMBRE	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31768	\N	\N	\N
37577	MEMBRE	2023-10-16 00:00:00	2024-02-13 00:00:00	ACTIF	\N	\N	\N	\N	31769	\N	\N	\N
37578	MEMBRE	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31770	\N	\N	\N
37965	MEMBRE	2023-10-19 00:00:00	2023-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	32160	\N	\N	\N
37966	MEMBRE	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32161	\N	\N	\N
38677	MEMBRE	2023-11-13 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	32872	\N	\N	\N
38879	MEMBRE	2023-11-17 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	33074	\N	\N	\N
38880	MEMBRE	2023-11-17 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	33075	\N	\N	\N
38881	MEMBRE	2023-11-17 00:00:00	2024-01-24 00:00:00	ACTIF	\N	\N	\N	\N	33076	\N	\N	\N
38882	MEMBRE	2023-11-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33077	\N	\N	\N
38883	MEMBRE	2023-11-17 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	33078	\N	\N	\N
38884	MEMBRE	2023-11-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33079	\N	\N	\N
38885	MEMBRE	2023-11-17 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	33080	\N	\N	\N
39350	PDTDEL	2023-12-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour la Namibie	\N	33333	\N	\N	\N
39351	PDTDEL	2023-12-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour la République démocratique du Congo	\N	33334	\N	\N	\N
39648	MEMBRE	2023-10-01 00:00:00	2024-01-29 00:00:00	ACTIF	\N	\N	\N	\N	29788	\N	\N	\N
39650	MEMBRE	2023-10-01 00:00:00	2024-01-29 00:00:00	ACTIF	\N	\N	\N	\N	33405	\N	\N	\N
39652	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33407	\N	\N	\N
39817	MEMBRE	2023-10-01 00:00:00	2024-01-29 00:00:00	ACTIF	\N	\N	\N	\N	33485	\N	\N	\N
39843	MEMBRE	2024-01-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33511	\N	\N	\N
39949	VICPDT	2024-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	33549	\N	\N	\N
40290	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33819	\N	\N	\N
40333	MEMBRE	2024-01-02 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	30733	\N	\N	\N
41125	VICPDT	2024-02-06 00:00:00	\N	\N	\N	\N	\N	\N	34292	\N	\N	\N
41499	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34487	\N	\N	\N
41500	MEMBRE	2023-12-14 00:00:00	\N	\N	\N	\N	\N	\N	34488	\N	\N	\N
32680	MEMBRE	2020-10-14 00:00:00	2023-07-18 00:00:00	ANCIEN	\N	\N	\N	\N	28109	\N	\N	\N
32681	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28110	\N	\N	\N
32682	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28111	\N	\N	\N
32683	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28112	\N	\N	\N
32684	MEMBRE	2020-10-14 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	28113	\N	\N	\N
32685	MEMBRE	2020-10-14 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	28114	\N	\N	\N
32686	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28115	\N	\N	\N
32687	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28116	\N	\N	\N
32688	MEMBRE	2020-10-13 00:00:00	2021-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	28117	\N	\N	\N
32689	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28118	\N	\N	\N
32690	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28119	\N	\N	\N
32691	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28120	\N	\N	\N
32692	MEMBRE	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28121	\N	\N	\N
32693	MEMBRE	2020-10-15 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	28122	\N	\N	\N
32694	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28123	\N	\N	\N
32695	MEMBRE	2020-10-15 00:00:00	2020-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	28124	\N	\N	\N
32696	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28125	\N	\N	\N
32697	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28126	\N	\N	\N
32698	MEMBRE	2020-10-15 00:00:00	2021-06-23 00:00:00	ANCIEN	\N	\N	\N	\N	28127	\N	\N	\N
32699	MEMBRE	2020-10-15 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	28128	\N	\N	\N
32700	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28129	\N	\N	\N
32701	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28130	\N	\N	\N
32702	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28131	\N	\N	\N
32703	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28132	\N	\N	\N
32704	MEMBRE	2020-10-15 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	28133	\N	\N	\N
32705	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28134	\N	\N	\N
32706	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28135	\N	\N	\N
32707	MEMBRE	2020-10-21 00:00:00	2020-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	28136	\N	\N	\N
32708	MEMBRE	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28137	\N	\N	\N
33251	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28684	\N	\N	\N
33252	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28685	\N	\N	\N
33711	MEMBRE	2020-11-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29025	\N	\N	\N
34154	MEMBRE	2020-12-09 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	29233	\N	\N	\N
34155	MEMBRE	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29234	\N	\N	\N
34156	MEMBRE	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29235	\N	\N	\N
34166	MEMBRE	2020-12-09 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	29239	\N	\N	\N
34492	MEMBRE	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29356	\N	\N	\N
34609	MEMBRE	2020-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29470	\N	\N	\N
34686	MEMBRE	2020-12-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	29526	\N	\N	\N
34687	MEMBRE	2020-12-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	29527	\N	\N	\N
34688	MEMBRE	2020-12-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	29528	\N	\N	\N
34689	MEMBRE	2020-12-21 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	29529	\N	\N	\N
34712	MEMBRE	2020-12-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29552	\N	\N	\N
34779	MEMBRE	2020-12-21 00:00:00	2021-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	29586	\N	\N	\N
34927	MEMBRE	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29692	\N	\N	\N
34985	MEMBRE	2021-01-13 00:00:00	2021-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	29733	\N	\N	\N
35343	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30006	\N	\N	\N
35344	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30007	\N	\N	\N
35356	VICPDT	2021-01-26 00:00:00	2021-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	29642	\N	\N	\N
35358	VICPDT	2021-01-26 00:00:00	2021-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	29476	\N	\N	\N
35359	VICPDT	2021-01-26 00:00:00	2021-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	29270	\N	\N	\N
35838	PDT	2021-02-10 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29851	\N	\N	\N
35839	VICPDT	2021-02-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30060	\N	\N	\N
35840	VICPDT	2021-02-10 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29847	\N	\N	\N
35856	SECRET	2021-02-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29879	\N	\N	\N
36013	MEMBRE	2021-03-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30310	\N	\N	\N
36019	VICPDT	2021-03-30 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29869	\N	\N	\N
36129	MEMBRE	2021-08-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30391	\N	\N	\N
36130	MEMBRE	2021-09-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30392	\N	\N	\N
36213	MEMBRE	2021-10-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	30459	\N	\N	\N
36308	MEMBRE	2022-03-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30536	\N	\N	\N
36328	MEMBRE	2022-03-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30555	\N	\N	\N
36336	MEMBRE	2022-03-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30563	\N	\N	\N
36337	MEMBRE	2022-03-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30564	\N	\N	\N
36406	MEMBRE	2022-03-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30624	\N	\N	\N
36419	MEMBRE	2022-06-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30636	\N	\N	\N
36420	MEMBRE	2022-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30637	\N	\N	\N
36421	MEMBRE	2022-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30638	\N	\N	\N
36525	MEMBRE	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30742	\N	\N	\N
36526	MEMBRE	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30743	\N	\N	\N
36568	MEMBRE	2022-02-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30785	\N	\N	\N
36654	MEMBRE	2023-06-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30851	\N	\N	\N
38451	MEMBRE	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32646	\N	\N	\N
38452	MEMBRE	2023-11-02 00:00:00	2024-01-04 00:00:00	ANCIEN	\N	\N	\N	\N	32647	\N	\N	\N
38453	MEMBRE	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32648	\N	\N	\N
38454	MEMBRE	2023-11-02 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	32649	\N	\N	\N
38455	MEMBRE	2023-11-02 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	32650	\N	\N	\N
38456	MEMBRE	2023-11-02 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	32651	\N	\N	\N
38457	MEMBRE	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32652	\N	\N	\N
38458	MEMBRE	2023-11-02 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	32653	\N	\N	\N
38459	MEMBRE	2023-11-02 00:00:00	2024-01-25 00:00:00	ACTIF	\N	\N	\N	\N	32654	\N	\N	\N
38460	MEMBRE	2023-11-02 00:00:00	2023-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	32655	\N	\N	\N
38461	MEMBRE	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32656	\N	\N	\N
38462	MEMBRE	2023-11-02 00:00:00	2024-02-08 00:00:00	ACTIF	\N	\N	\N	\N	32657	\N	\N	\N
38463	MEMBRE	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32658	\N	\N	\N
38464	MEMBRE	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32659	\N	\N	\N
38465	MEMBRE	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32660	\N	\N	\N
38466	MEMBRE	2023-11-02 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	32661	\N	\N	\N
38756	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32951	\N	\N	\N
38757	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32952	\N	\N	\N
38758	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32953	\N	\N	\N
38759	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32954	\N	\N	\N
38760	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32955	\N	\N	\N
38761	MEMBRE	2023-11-15 00:00:00	2023-12-11 00:00:00	ANCIEN	\N	\N	\N	\N	32956	\N	\N	\N
38762	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32957	\N	\N	\N
38763	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32958	\N	\N	\N
38764	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32959	\N	\N	\N
38765	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32960	\N	\N	\N
38766	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32961	\N	\N	\N
38767	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32962	\N	\N	\N
39356	MEMBRE	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33339	\N	\N	\N
39357	MEMBRE	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33340	\N	\N	\N
39358	MEMBRE	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33341	\N	\N	\N
39359	MEMBRE	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33342	\N	\N	\N
39360	MEMBRE	2023-12-12 00:00:00	2024-02-08 00:00:00	ACTIF	\N	\N	\N	\N	33343	\N	\N	\N
39365	MEMBRE	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33348	\N	\N	\N
39508	SECRET	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32862	\N	\N	\N
39509	SECRET	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31099	\N	\N	\N
39510	SECRET	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31253	\N	\N	\N
39511	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31477	\N	\N	\N
39512	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32290	\N	\N	\N
39513	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33219	\N	\N	\N
39514	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32004	\N	\N	\N
39515	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33114	\N	\N	\N
39516	SECRET	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31236	\N	\N	\N
39517	SECRET	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33024	\N	\N	\N
39518	SECRET	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32860	\N	\N	\N
39519	SECRET	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31251	\N	\N	\N
39520	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31339	\N	\N	\N
39521	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31849	\N	\N	\N
39522	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32041	\N	\N	\N
39523	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32942	\N	\N	\N
39524	VICPDT	2023-12-20 00:00:00	2023-12-21 00:00:00	ANCIEN	\N	\N	\N	\N	31406	\N	\N	\N
39525	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32770	\N	\N	\N
39526	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32692	\N	\N	\N
39527	SECRET	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33381	\N	\N	\N
39528	SECRET	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32529	\N	\N	\N
39529	SECRET	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31406	\N	\N	\N
39530	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30955	\N	\N	\N
39531	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31875	\N	\N	\N
39532	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32650	\N	\N	\N
39533	SECRET	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31005	\N	\N	\N
39534	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31835	\N	\N	\N
39535	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32705	\N	\N	\N
39536	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32872	\N	\N	\N
39537	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31362	\N	\N	\N
39538	SECRET	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32825	\N	\N	\N
39539	SECRET	2023-12-20 00:00:00	2024-01-03 00:00:00	ANCIEN	\N	\N	\N	\N	32479	\N	\N	\N
39540	SECRET	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32566	\N	\N	\N
39541	SECRET	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33218	\N	\N	\N
30590	VICPDT	2018-02-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24922	\N	2018-02-07 16:33:26	\N
30591	VICPDT	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24135	\N	2018-02-07 16:33:35	\N
30592	VICPDT	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24868	\N	2018-02-07 16:33:42	\N
30593	VICPDT	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23999	\N	2018-02-07 16:33:55	\N
30594	SECRET	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24395	\N	2018-02-07 16:34:12	\N
30595	VICPDT	2018-02-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24112	\N	2018-02-07 16:34:25	\N
30596	VICPDT	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24274	\N	2018-02-07 16:34:38	\N
30597	VICPDT	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25333	\N	2018-02-07 16:34:55	\N
30598	VICPDT	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25197	\N	2018-02-07 16:35:05	\N
30599	VICPDT	2018-02-07 00:00:00	2018-09-06 00:00:00	ANCIEN	\N	\N	\N	\N	24214	\N	2018-02-07 16:35:20	\N
30600	VICPDT	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24289	\N	2018-02-07 16:35:32	\N
30601	VICPDT	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24060	\N	2018-02-07 16:35:40	\N
30602	VICPDT	2018-02-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24781	\N	2018-02-07 16:35:50	\N
30603	MEMBRE	2018-02-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26330	\N	2018-02-07 16:54:38	\N
30604	MEMBRE	2018-02-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26331	\N	2018-02-07 17:02:56	\N
30605	VICPDT	2018-02-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24111	\N	2018-02-07 17:30:33	\N
30606	VICPDT	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24903	\N	2018-02-07 17:30:42	\N
30607	VICPDT	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25702	\N	2018-02-07 17:30:49	\N
30608	VICPDT	2018-02-07 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	24507	\N	2018-02-07 17:30:55	\N
30609	MEMBRE	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25543	\N	2018-02-07 17:31:00	2018-02-07 17:31:43
30610	SECRET	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24816	\N	2018-02-07 17:31:07	\N
30613	SECRET	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25776	\N	2018-02-07 17:31:47	\N
30768	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26441	\N	\N	\N
30770	MEMBRE	2017-10-01 00:00:00	2018-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	26443	\N	\N	\N
30801	MEMBRE	2018-02-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26472	\N	2018-02-13 14:38:01	\N
30914	MEMBRE	2017-10-01 00:00:00	2017-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	26542	\N	\N	\N
31245	VICPDT	2018-02-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	26107	\N	\N	\N
31315	MEMBRE	2018-06-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26783	\N	\N	\N
31423	MEMBRE	2018-10-31 00:00:00	2019-03-08 00:00:00	ANCIEN	\N	\N	\N	\N	26884	\N	\N	\N
31425	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26886	\N	\N	\N
31426	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26887	\N	\N	\N
31427	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26888	\N	\N	\N
31428	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26889	\N	\N	\N
31429	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26890	\N	\N	\N
31430	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26891	\N	\N	\N
31431	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26892	\N	\N	\N
31469	VICPDT	2018-12-06 00:00:00	2020-02-25 00:00:00	ANCIEN	\N	\N	\N	\N	24801	\N	\N	\N
31470	VICPDT	2018-12-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24460	\N	\N	\N
31509	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26963	\N	\N	\N
31510	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26964	\N	\N	\N
31666	MEMBRE	2020-06-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27097	\N	\N	\N
31667	MEMBRE	2020-07-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27098	\N	\N	\N
32085	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27514	\N	\N	\N
32086	MEMBRE	2020-10-13 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	27515	\N	\N	\N
32087	MEMBRE	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27516	\N	\N	\N
32088	MEMBRE	2020-10-10 00:00:00	2021-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	27517	\N	\N	\N
32089	MEMBRE	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27518	\N	\N	\N
32090	MEMBRE	2020-10-10 00:00:00	2020-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	27519	\N	\N	\N
32091	MEMBRE	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27520	\N	\N	\N
32092	MEMBRE	2020-10-10 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	27521	\N	\N	\N
32093	MEMBRE	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27522	\N	\N	\N
32094	MEMBRE	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27523	\N	\N	\N
32095	MEMBRE	2020-10-10 00:00:00	2021-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	27524	\N	\N	\N
32096	MEMBRE	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27525	\N	\N	\N
32097	MEMBRE	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27526	\N	\N	\N
32098	MEMBRE	2020-10-10 00:00:00	2021-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	27527	\N	\N	\N
32099	MEMBRE	2020-10-10 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	27528	\N	\N	\N
32100	MEMBRE	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27529	\N	\N	\N
32101	MEMBRE	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27530	\N	\N	\N
32102	MEMBRE	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27531	\N	\N	\N
32103	MEMBRE	2020-10-10 00:00:00	2021-01-03 00:00:00	ANCIEN	\N	\N	\N	\N	27532	\N	\N	\N
32104	MEMBRE	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27533	\N	\N	\N
32105	MEMBRE	2020-10-10 00:00:00	2020-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	27534	\N	\N	\N
32106	MEMBRE	2020-10-10 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	27535	\N	\N	\N
32107	MEMBRE	2020-10-10 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	27536	\N	\N	\N
32108	MEMBRE	2020-10-10 00:00:00	2021-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	27537	\N	\N	\N
32109	MEMBRE	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27538	\N	\N	\N
32110	MEMBRE	2020-10-10 00:00:00	2020-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	27539	\N	\N	\N
32111	MEMBRE	2020-10-10 00:00:00	2020-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	27540	\N	\N	\N
32112	MEMBRE	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27541	\N	\N	\N
32113	MEMBRE	2020-10-10 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	27542	\N	\N	\N
32114	MEMBRE	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27543	\N	\N	\N
32115	MEMBRE	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27544	\N	\N	\N
32116	MEMBRE	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27545	\N	\N	\N
32117	MEMBRE	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27546	\N	\N	\N
32118	MEMBRE	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27547	\N	\N	\N
32119	MEMBRE	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27548	\N	\N	\N
32120	MEMBRE	2020-10-10 00:00:00	2020-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	27549	\N	\N	\N
32121	MEMBRE	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27550	\N	\N	\N
32122	MEMBRE	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27551	\N	\N	\N
32123	MEMBRE	2020-10-10 00:00:00	2021-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	27552	\N	\N	\N
32124	MEMBRE	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27553	\N	\N	\N
32125	MEMBRE	2020-10-13 00:00:00	2020-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	27554	\N	\N	\N
32126	MEMBRE	2020-10-13 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	27555	\N	\N	\N
32127	MEMBRE	2020-10-13 00:00:00	2021-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	27556	\N	\N	\N
32128	MEMBRE	2020-10-13 00:00:00	2020-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	27557	\N	\N	\N
32129	MEMBRE	2020-10-13 00:00:00	2020-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	27558	\N	\N	\N
32130	MEMBRE	2020-10-13 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	27559	\N	\N	\N
32131	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27560	\N	\N	\N
32132	MEMBRE	2020-10-12 00:00:00	2021-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	27561	\N	\N	\N
32133	MEMBRE	2020-10-12 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	27562	\N	\N	\N
32134	MEMBRE	2020-10-12 00:00:00	2020-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	27563	\N	\N	\N
32135	MEMBRE	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27564	\N	\N	\N
32136	MEMBRE	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27565	\N	\N	\N
32137	MEMBRE	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27566	\N	\N	\N
32138	MEMBRE	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27567	\N	\N	\N
32139	MEMBRE	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27568	\N	\N	\N
32140	MEMBRE	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27569	\N	\N	\N
32141	MEMBRE	2020-10-12 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	27570	\N	\N	\N
32142	MEMBRE	2020-10-13 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	27571	\N	\N	\N
32143	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27572	\N	\N	\N
32144	MEMBRE	2020-10-13 00:00:00	2020-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	27573	\N	\N	\N
32145	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27574	\N	\N	\N
32146	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27575	\N	\N	\N
32147	MEMBRE	2020-10-13 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	27576	\N	\N	\N
32148	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27577	\N	\N	\N
32149	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27578	\N	\N	\N
32150	MEMBRE	2020-10-13 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	27579	\N	\N	\N
32151	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27580	\N	\N	\N
32152	MEMBRE	2020-10-13 00:00:00	2020-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	27581	\N	\N	\N
32153	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27582	\N	\N	\N
32154	MEMBRE	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27583	\N	\N	\N
32155	MEMBRE	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27584	\N	\N	\N
32156	MEMBRE	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27585	\N	\N	\N
32157	MEMBRE	2020-10-12 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	27586	\N	\N	\N
32834	MEMBRE	2020-10-22 00:00:00	2021-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	28267	\N	\N	\N
32835	MEMBRE	2020-10-22 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	28268	\N	\N	\N
32836	MEMBRE	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28269	\N	\N	\N
32837	MEMBRE	2020-10-22 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	28270	\N	\N	\N
32838	MEMBRE	2020-10-22 00:00:00	2021-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	28271	\N	\N	\N
32839	MEMBRE	2020-10-22 00:00:00	2020-12-23 00:00:00	ANCIEN	\N	\N	\N	\N	28272	\N	\N	\N
32840	MEMBRE	2020-10-22 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	28273	\N	\N	\N
32841	MEMBRE	2020-10-22 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	28274	\N	\N	\N
32842	MEMBRE	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28275	\N	\N	\N
32843	MEMBRE	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28276	\N	\N	\N
32844	MEMBRE	2020-10-22 00:00:00	2021-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	28277	\N	\N	\N
32845	MEMBRE	2020-10-22 00:00:00	2020-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	28278	\N	\N	\N
32846	MEMBRE	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28279	\N	\N	\N
32847	MEMBRE	2020-10-22 00:00:00	2020-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	28280	\N	\N	\N
32848	MEMBRE	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28281	\N	\N	\N
41553	SECRET	2024-04-03 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31459	\N	\N	\N
30952	PDT	2018-02-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26340	\N	\N	\N
30953	VICPDT	2018-02-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	26365	\N	\N	\N
30975	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26569	\N	\N	\N
30976	MEMBRE	2017-10-01 00:00:00	2018-03-07 00:00:00	ANCIEN	\N	\N	\N	\N	26570	\N	\N	\N
30977	MEMBRE	2017-10-01 00:00:00	2018-03-07 00:00:00	ANCIEN	\N	\N	\N	\N	26571	\N	\N	\N
30978	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26572	\N	\N	\N
30979	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26573	\N	\N	\N
30980	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26574	\N	\N	\N
30984	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26578	\N	\N	\N
30987	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26581	\N	\N	\N
30990	MEMBRE	2018-02-15 00:00:00	2020-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	26584	\N	2018-02-20 09:49:13	\N
31177	MEMBRE	2017-12-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26701	\N	\N	\N
31251	PDT	2018-04-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	25745	\N	\N	\N
31263	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26748	\N	\N	\N
31264	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26749	\N	\N	\N
31288	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26757	\N	\N	\N
31392	MEMBRE	2018-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26853	\N	\N	\N
31393	MEMBRE	2018-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26854	\N	\N	\N
31395	MEMBRE	2018-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26856	\N	\N	\N
31396	MEMBRE	2018-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26857	\N	\N	\N
33122	MEMBRE	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28555	\N	\N	\N
33123	MEMBRE	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28556	\N	\N	\N
33124	MEMBRE	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28557	\N	\N	\N
33566	MEMBRE	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28983	\N	\N	\N
33567	PDT	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28778	\N	\N	\N
33568	PDT	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28703	\N	\N	\N
33569	PDT	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28949	\N	\N	\N
33570	PDTDEL	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour la Guinée-Bissau	\N	28698	\N	\N	\N
33571	PDTDEL	2020-11-18 00:00:00	2020-11-22 00:00:00	ANCIEN	\N	\N	pour Sao-Tomé-et-Principe	\N	28686	\N	\N	\N
33572	VICPDTDEL	2020-11-18 00:00:00	2023-09-27 00:00:00	ANCIEN	\N	\N	pour la Tanzanie	\N	28253	\N	\N	\N
33573	PDT	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28902	\N	\N	\N
33574	MEMBRE	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28984	\N	\N	\N
33575	MEMBRE	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28985	\N	\N	\N
33576	MEMBRE	2020-11-18 00:00:00	2020-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	28986	\N	\N	\N
33577	MEMBRE	2020-11-18 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	28987	\N	\N	\N
33578	PDT	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28926	\N	\N	\N
33579	PDTDEL	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour l'Argentine	\N	28865	\N	\N	\N
33580	PDT	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27652	\N	\N	\N
33581	PDT	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28868	\N	\N	\N
33582	PDT	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27344	\N	\N	\N
33583	PDTDEL	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour les îles Fidji	\N	28942	\N	\N	\N
33584	PDT	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28088	\N	\N	\N
33585	PDT	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27605	\N	\N	\N
33586	PDT	2020-11-18 00:00:00	2021-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	27684	\N	\N	\N
33587	PDT	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27292	\N	\N	\N
33588	PDT	2020-11-18 00:00:00	2021-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	28676	\N	\N	\N
33589	PDT	2020-11-18 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	27257	\N	\N	\N
33590	PDT	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27348	\N	\N	\N
33591	PDT	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27631	\N	\N	\N
33592	PDT	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27479	\N	\N	\N
33593	PDT	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27739	\N	\N	\N
33594	PDT	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27799	\N	\N	\N
33595	PDT	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28319	\N	\N	\N
33596	PDT	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27301	\N	\N	\N
33597	PDT	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28798	\N	\N	\N
33598	PDT	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28445	\N	\N	\N
33599	PDT	2020-11-18 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	27844	\N	\N	\N
33600	PDT	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28202	\N	\N	\N
33601	PDT	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27770	\N	\N	\N
33602	PDT	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28454	\N	\N	\N
33603	PDT	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27558	\N	\N	\N
33604	PDT	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27276	\N	\N	\N
33605	PDT	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28345	\N	\N	\N
33606	PDT	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28855	\N	\N	\N
33607	MEMBRE	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28309	\N	\N	\N
33608	PDT	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28307	\N	\N	\N
33609	PDT	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28143	\N	\N	\N
33610	PDT	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28789	\N	\N	\N
33611	PDT	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28816	\N	\N	\N
33612	PDT	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28045	\N	\N	\N
33613	PDT	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27918	\N	\N	\N
33614	PDT	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27965	\N	\N	\N
33615	PDT	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28514	\N	\N	\N
33616	PDT	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27399	\N	\N	\N
33816	MEMBRE	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29087	\N	\N	\N
33817	MEMBRE	2020-11-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29088	\N	\N	\N
33818	PDT	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28931	\N	\N	\N
33819	PDT	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27147	\N	\N	\N
33820	PDT	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27519	\N	\N	\N
33821	MEMBRE	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29089	\N	\N	\N
33822	PDT	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28320	\N	\N	\N
33823	PDT	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28894	\N	\N	\N
33826	MEMBRE	2020-11-18 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	29091	\N	\N	\N
33825	PDTDEL	2020-11-24 00:00:00	2021-01-19 00:00:00	ANCIEN	\N	\N	pour le Qatar	\N	29090	\N	\N	\N
34633	MEMBRE	2020-12-18 00:00:00	2020-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	29492	\N	\N	\N
34644	MEMBRE	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29502	\N	\N	\N
34704	MEMBRE	2020-12-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	29544	\N	\N	\N
34723	MEMBRE	2020-12-23 00:00:00	2021-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	29563	\N	\N	\N
34724	MEMBRE	2020-12-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	29564	\N	\N	\N
35036	VICPDT	2021-01-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27302	\N	\N	\N
35082	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29806	\N	\N	\N
35120	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29844	\N	\N	\N
35123	MEMBRE	2020-10-01 00:00:00	2021-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	29847	\N	\N	\N
35124	MEMBRE	2020-10-01 00:00:00	2021-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	29848	\N	\N	\N
35125	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29849	\N	\N	\N
35255	VICPDT	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29650	\N	\N	\N
35332	MEMBRE	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29995	\N	\N	\N
35338	MEMBRE	2021-01-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30001	\N	\N	\N
35458	MEMBRE	2020-10-01 00:00:00	2021-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	30060	\N	\N	\N
35485	VICPDT	2021-01-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	30047	\N	\N	\N
35527	VICPDT	2021-01-13 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29759	\N	\N	\N
35590	MEMBRE	2021-02-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30091	\N	\N	\N
35591	MEMBRE	2021-02-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	30092	\N	\N	\N
35649	MEMBRE	2021-02-03 00:00:00	2021-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	30134	\N	\N	\N
35685	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30148	\N	\N	\N
35872	MEMBRE	2021-02-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	30206	\N	\N	\N
36182	MEMBRE	2021-10-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	30434	\N	\N	\N
36253	MEMBRE	2021-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	30497	\N	\N	\N
36371	MEMBRE	2022-04-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30597	\N	\N	\N
36372	MEMBRE	2022-04-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30598	\N	\N	\N
36373	MEMBRE	2022-04-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30599	\N	\N	\N
36375	MEMBRE	2022-04-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30601	\N	\N	\N
36377	MEMBRE	2022-04-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30603	\N	\N	\N
36423	MEMBRE	2022-06-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	30640	\N	\N	\N
36557	MEMBRE	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30774	\N	\N	\N
36738	MEMBRE	2023-10-09 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	30928	\N	\N	\N
36739	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30929	\N	\N	\N
36740	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30930	\N	\N	\N
36741	MEMBRE	2023-10-09 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	30931	\N	\N	\N
36934	MEMBRE	2023-10-10 00:00:00	2024-01-30 00:00:00	ACTIF	\N	\N	\N	\N	31124	\N	\N	\N
36935	MEMBRE	2023-10-10 00:00:00	2024-02-27 00:00:00	ACTIF	\N	\N	\N	\N	31125	\N	\N	\N
36936	MEMBRE	2023-10-10 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	31126	\N	\N	\N
36937	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31127	\N	\N	\N
36940	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31130	\N	\N	\N
36941	MEMBRE	2023-10-10 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	31131	\N	\N	\N
36942	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31132	\N	\N	\N
36943	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31133	\N	\N	\N
36944	MEMBRE	2023-10-10 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	31134	\N	\N	\N
36945	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31135	\N	\N	\N
36946	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31136	\N	\N	\N
36947	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31137	\N	\N	\N
36948	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31138	\N	\N	\N
36994	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31184	\N	\N	\N
36995	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31185	\N	\N	\N
36996	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31186	\N	\N	\N
36997	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31187	\N	\N	\N
36998	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31188	\N	\N	\N
36999	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31189	\N	\N	\N
39542	SECRET	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32415	\N	\N	\N
39543	SECRET	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32479	\N	\N	\N
39544	SECRET	2023-12-20 00:00:00	2024-01-03 00:00:00	ANCIEN	\N	\N	\N	\N	32825	\N	\N	\N
39545	SECRET	2023-12-20 00:00:00	2024-01-03 00:00:00	ANCIEN	\N	\N	\N	\N	32566	\N	\N	\N
39546	SECRET	2023-12-20 00:00:00	2024-01-03 00:00:00	ANCIEN	\N	\N	\N	\N	32415	\N	\N	\N
39547	SECRET	2023-12-20 00:00:00	2024-01-03 00:00:00	ANCIEN	\N	\N	\N	\N	33218	\N	\N	\N
39548	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31435	\N	\N	\N
39549	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33303	\N	\N	\N
39550	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30910	\N	\N	\N
39551	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32915	\N	\N	\N
39552	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32297	\N	\N	\N
39553	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32612	\N	\N	\N
39554	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32928	\N	\N	\N
39555	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32867	\N	\N	\N
39556	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31350	\N	\N	\N
39557	SECRET	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32488	\N	\N	\N
39558	SECRET	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30974	\N	\N	\N
39559	SECRET	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33080	\N	\N	\N
39560	SECRET	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32619	\N	\N	\N
39561	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30924	\N	\N	\N
39562	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32150	\N	\N	\N
39563	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31512	\N	\N	\N
39564	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32013	\N	\N	\N
39565	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33336	\N	\N	\N
39566	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30943	\N	\N	\N
39567	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33349	\N	\N	\N
39568	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33146	\N	\N	\N
39569	SECRET	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33202	\N	\N	\N
39570	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31417	\N	\N	\N
39571	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31757	\N	\N	\N
39572	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33323	\N	\N	\N
39573	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33222	\N	\N	\N
39574	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31433	\N	\N	\N
39575	SECRET	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33394	\N	\N	\N
39576	SECRET	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33312	\N	\N	\N
39577	SECRET	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33304	\N	\N	\N
39578	SECRET	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33267	\N	\N	\N
39579	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31607	\N	\N	\N
39580	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32031	\N	\N	\N
39581	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31009	\N	\N	\N
39582	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31885	\N	\N	\N
39583	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31560	\N	\N	\N
39584	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30950	\N	\N	\N
39585	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31346	\N	\N	\N
39586	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31326	\N	\N	\N
39587	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31871	\N	\N	\N
39588	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33235	\N	\N	\N
39589	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31599	\N	\N	\N
39590	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31118	\N	\N	\N
39591	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33048	\N	\N	\N
39592	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31379	\N	\N	\N
39593	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32902	\N	\N	\N
39594	VICPDT	2023-12-20 00:00:00	2024-03-20 00:00:00	ANCIEN	\N	\N	\N	\N	32025	\N	\N	\N
39595	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32967	\N	\N	\N
39596	SECRET	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30995	\N	\N	\N
39597	SECRET	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33232	\N	\N	\N
39598	SECRET	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32405	\N	\N	\N
39599	SECRET	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32009	\N	\N	\N
39604	MEMBRE	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33400	\N	\N	\N
39633	PDT	2023-12-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33401	\N	\N	\N
39649	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33404	\N	\N	\N
39653	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33408	\N	\N	\N
39667	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33416	\N	\N	\N
39668	MEMBRE	2023-12-22 00:00:00	2024-01-30 00:00:00	ACTIF	\N	\N	\N	\N	29858	\N	\N	\N
39694	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33434	\N	\N	\N
39695	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33435	\N	\N	\N
39705	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33444	\N	\N	\N
39707	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33446	\N	\N	\N
39708	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33447	\N	\N	\N
39716	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33455	\N	\N	\N
39761	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33457	\N	\N	\N
39782	MEMBRE	2024-01-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33461	\N	\N	\N
39798	MEMBRE	2024-01-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33468	\N	\N	\N
39801	MEMBRE	2024-01-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33471	\N	\N	\N
39836	MEMBRE	2024-01-15 00:00:00	2024-02-13 00:00:00	ACTIF	\N	\N	\N	\N	33504	\N	\N	\N
39808	MEMBRE	2024-01-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33477	\N	\N	\N
39809	MEMBRE	2024-01-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33478	\N	\N	\N
39810	PDT	2024-01-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33475	\N	\N	\N
39818	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33486	\N	\N	\N
39821	MEMBRE	2024-01-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33489	\N	\N	\N
39839	MEMBRE	2024-01-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33507	\N	\N	\N
39848	MEMBRE	2024-01-16 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	33516	\N	\N	\N
39850	MEMBRE	2024-01-16 00:00:00	2024-02-13 00:00:00	ACTIF	\N	\N	\N	\N	33518	\N	\N	\N
39922	MEMBRE	2023-12-14 00:00:00	2024-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	33536	\N	\N	\N
39927	VICPDT	2024-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	33538	\N	\N	\N
39932	MEMBRE	2023-12-14 00:00:00	2024-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	33541	\N	\N	\N
39933	VICPDT	2024-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	33541	\N	\N	\N
39934	MEMBRE	2023-12-14 00:00:00	2024-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	33542	\N	\N	\N
39935	VICPDT	2024-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	33542	\N	\N	\N
39936	MEMBRE	2023-12-14 00:00:00	2024-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	33543	\N	\N	\N
39940	MEMBRE	2023-12-14 00:00:00	2024-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	33545	\N	\N	\N
39942	MEMBRE	2023-12-14 00:00:00	2024-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	33546	\N	\N	\N
39943	VICPDT	2024-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	33546	\N	\N	\N
39948	MEMBRE	2024-01-14 00:00:00	2024-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	33549	\N	\N	\N
39962	MEMBRE	2024-01-02 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	33561	\N	\N	\N
39963	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33562	\N	\N	\N
39964	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33563	\N	\N	\N
39965	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33564	\N	\N	\N
39966	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33565	\N	\N	\N
39967	MEMBRE	2024-01-02 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	33566	\N	\N	\N
39969	MEMBRE	2024-01-02 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	33568	\N	\N	\N
39975	MEMBRE	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33574	\N	\N	\N
39977	MEMBRE	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33576	\N	\N	\N
39979	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33578	\N	\N	\N
39980	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33579	\N	\N	\N
39981	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33580	\N	\N	\N
40027	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33604	\N	\N	\N
39989	MEMBRE	2024-01-17 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	\N	30811	\N	\N	\N
39992	MEMBRE	2024-01-17 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	\N	29800	\N	\N	\N
40000	MEMBRE	2024-01-17 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	\N	29881	\N	\N	\N
40002	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33583	\N	\N	\N
40003	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33584	\N	\N	\N
40022	MEMBRE	2024-01-02 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	33599	\N	\N	\N
40051	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33628	\N	\N	\N
40052	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33629	\N	\N	\N
40053	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33630	\N	\N	\N
40054	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33631	\N	\N	\N
40062	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33639	\N	\N	\N
40079	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33656	\N	\N	\N
40098	MEMBRE	2024-01-18 00:00:00	2024-01-29 00:00:00	ACTIF	\N	\N	\N	\N	30090	\N	\N	\N
40099	MEMBRE	2024-01-18 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	\N	30150	\N	\N	\N
40108	MEMBRE	2024-01-18 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	\N	29876	\N	\N	\N
40109	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33683	\N	\N	\N
40114	MEMBRE	2024-01-18 00:00:00	2024-02-05 00:00:00	ACTIF	\N	\N	\N	\N	29847	\N	\N	\N
40115	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33688	\N	\N	\N
40116	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33689	\N	\N	\N
40120	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33693	\N	\N	\N
40135	MEMBRE	2024-01-02 00:00:00	2024-02-06 00:00:00	ACTIF	\N	\N	\N	\N	33703	\N	\N	\N
40137	MEMBRE	2024-01-19 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	33705	\N	\N	\N
40184	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33713	\N	\N	\N
40195	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33724	\N	\N	\N
40197	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33726	\N	\N	\N
40231	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33760	\N	\N	\N
40232	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33761	\N	\N	\N
40247	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33776	\N	\N	\N
40265	MEMBRE	2023-10-01 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	33794	\N	\N	\N
40271	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33800	\N	\N	\N
40272	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33801	\N	\N	\N
40274	MEMBRE	2023-10-01 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	33803	\N	\N	\N
40275	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33804	\N	\N	\N
40276	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33805	\N	\N	\N
40277	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33806	\N	\N	\N
40278	MEMBRE	2023-10-01 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	33807	\N	\N	\N
40280	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33809	\N	\N	\N
40282	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33811	\N	\N	\N
40283	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33812	\N	\N	\N
40285	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33814	\N	\N	\N
40286	MEMBRE	2023-10-01 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	33815	\N	\N	\N
40287	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33816	\N	\N	\N
40293	MEMBRE	2023-10-01 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	33822	\N	\N	\N
40294	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33823	\N	\N	\N
40296	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33825	\N	\N	\N
40298	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33827	\N	\N	\N
40300	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33829	\N	\N	\N
40303	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	30762	\N	\N	\N
40305	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	30789	\N	\N	\N
40307	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	30738	\N	\N	\N
40310	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	30841	\N	\N	\N
40331	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	30743	\N	\N	\N
31018	MEMBRE	2018-02-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26599	\N	2018-02-23 09:54:46	\N
31287	MEMBRE	2018-01-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	26756	\N	\N	\N
31293	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26762	\N	\N	\N
31307	MEMBRE	2018-02-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26776	\N	2018-06-07 09:47:37	\N
31539	MEMBRE	2018-01-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	26991	\N	\N	\N
31608	MEMBRE	2017-12-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	27043	\N	\N	\N
31657	MEMBRE	2020-02-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27089	\N	\N	\N
34422	MEMBRE	2020-12-18 00:00:00	2020-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	29294	\N	\N	\N
32849	MEMBRE	2020-10-14 00:00:00	2021-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	28282	\N	\N	\N
32850	MEMBRE	2020-10-14 00:00:00	2021-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	28283	\N	\N	\N
32851	MEMBRE	2020-10-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28284	\N	\N	\N
32852	MEMBRE	2020-10-21 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	28285	\N	\N	\N
32853	MEMBRE	2020-10-16 00:00:00	2020-11-25 00:00:00	ANCIEN	\N	\N	\N	\N	28286	\N	\N	\N
32854	MEMBRE	2020-10-16 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	28287	\N	\N	\N
32855	MEMBRE	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28288	\N	\N	\N
32856	MEMBRE	2020-10-21 00:00:00	2021-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	28289	\N	\N	\N
32857	MEMBRE	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28290	\N	\N	\N
32858	MEMBRE	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28291	\N	\N	\N
32859	MEMBRE	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28292	\N	\N	\N
32860	MEMBRE	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28293	\N	\N	\N
32861	MEMBRE	2020-10-21 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	28294	\N	\N	\N
32862	MEMBRE	2020-10-21 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	28295	\N	\N	\N
32863	MEMBRE	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28296	\N	\N	\N
32864	MEMBRE	2020-10-21 00:00:00	2020-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	28297	\N	\N	\N
32865	MEMBRE	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28298	\N	\N	\N
32866	MEMBRE	2020-10-22 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	28299	\N	\N	\N
32867	MEMBRE	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28300	\N	\N	\N
32868	MEMBRE	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28301	\N	\N	\N
32869	MEMBRE	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28302	\N	\N	\N
32870	MEMBRE	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28303	\N	\N	\N
32871	MEMBRE	2020-10-12 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	28304	\N	\N	\N
32872	MEMBRE	2020-10-20 00:00:00	2020-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	28305	\N	\N	\N
32873	MEMBRE	2020-10-20 00:00:00	2020-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	28306	\N	\N	\N
32874	MEMBRE	2020-10-20 00:00:00	2020-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	28307	\N	\N	\N
32875	MEMBRE	2020-10-20 00:00:00	2020-12-23 00:00:00	ANCIEN	\N	\N	\N	\N	28308	\N	\N	\N
32876	MEMBRE	2020-10-20 00:00:00	2020-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	28309	\N	\N	\N
32877	MEMBRE	2020-10-20 00:00:00	2021-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	28310	\N	\N	\N
32878	MEMBRE	2020-10-20 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	28311	\N	\N	\N
32879	MEMBRE	2020-10-20 00:00:00	2020-12-23 00:00:00	ANCIEN	\N	\N	\N	\N	28312	\N	\N	\N
32880	MEMBRE	2020-10-20 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	28313	\N	\N	\N
32881	MEMBRE	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28314	\N	\N	\N
32882	MEMBRE	2020-10-23 00:00:00	2020-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	28315	\N	\N	\N
32883	MEMBRE	2020-10-23 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	28316	\N	\N	\N
32884	MEMBRE	2020-10-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28317	\N	\N	\N
32885	MEMBRE	2020-10-23 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	28318	\N	\N	\N
32886	MEMBRE	2020-10-23 00:00:00	2020-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	28319	\N	\N	\N
33945	MEMBRE	2020-12-02 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	29166	\N	\N	\N
33946	MEMBRE	2020-12-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29167	\N	\N	\N
34423	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29295	\N	\N	\N
34521	MEMBRE	2020-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29385	\N	\N	\N
34522	MEMBRE	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29386	\N	\N	\N
34607	MEMBRE	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29468	\N	\N	\N
34608	MEMBRE	2020-12-15 00:00:00	2021-07-20 00:00:00	ANCIEN	\N	\N	\N	\N	29469	\N	\N	\N
34616	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29477	\N	\N	\N
34617	VICPDT	2020-12-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29003	\N	\N	\N
34618	SECRET	2020-12-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28925	\N	\N	\N
34721	MEMBRE	2020-12-23 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	29561	\N	\N	\N
34722	MEMBRE	2020-12-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	29562	\N	\N	\N
34782	VICPDT	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28527	\N	\N	\N
34783	VICPDT	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27825	\N	\N	\N
34784	VICPDT	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28265	\N	\N	\N
34785	VICPDT	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28975	\N	\N	\N
34786	VICPDT	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27303	\N	\N	\N
34787	VICPDT	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27233	\N	\N	\N
34788	VICPDT	2021-01-04 00:00:00	2021-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	27342	\N	\N	\N
34789	VICPDT	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27470	\N	\N	\N
34790	VICPDT	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27113	\N	\N	\N
34791	VICPDT	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28322	\N	\N	\N
34792	SECRET	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27166	\N	\N	\N
34793	SECRET	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28347	\N	\N	\N
34794	SECRET	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27532	\N	\N	\N
34795	SECRET	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27288	\N	\N	\N
34796	SECRET	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28854	\N	\N	\N
34797	SECRET	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28620	\N	\N	\N
34823	MEMBRE	2021-01-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	29606	\N	\N	\N
34826	MEMBRE	2021-01-04 00:00:00	2022-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	29609	\N	\N	\N
34841	MEMBRE	2021-01-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29624	\N	\N	\N
34857	MEMBRE	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29640	\N	\N	\N
35017	MEMBRE	2021-01-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	29761	\N	\N	\N
35018	MEMBRE	2021-01-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	29762	\N	\N	\N
35212	MEMBRE	2020-10-01 00:00:00	2021-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	29936	\N	\N	\N
35215	MEMBRE	2021-01-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	29939	\N	\N	\N
35300	MEMBRE	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29970	\N	\N	\N
35301	MEMBRE	2021-01-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29971	\N	\N	\N
35302	MEMBRE	2021-01-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29972	\N	\N	\N
35322	MEMBRE	2021-01-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	29985	\N	\N	\N
35341	MEMBRE	2020-01-26 00:00:00	2021-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	30004	\N	\N	\N
35533	VICPDT	2021-01-13 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29733	\N	\N	\N
35666	MEMBRE	2020-12-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	30142	\N	\N	\N
36033	MEMBRE	2021-03-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	30320	\N	\N	\N
36036	MEMBRE	2021-04-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30323	\N	\N	\N
36037	MEMBRE	2021-04-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30324	\N	\N	\N
36038	PDT	2021-04-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30284	\N	\N	\N
36052	MEMBRE	2021-05-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30333	\N	\N	\N
36094	MEMBRE	2021-06-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	30368	\N	\N	\N
36098	PDT	2021-07-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	30362	\N	\N	\N
36123	MEMBRE	2021-09-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30386	\N	\N	\N
36239	MEMBRE	2021-12-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30484	\N	\N	\N
36282	MEMBRE	2022-02-01 00:00:00	2022-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	30517	\N	\N	\N
36321	MEMBRE	2022-03-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	30548	\N	\N	\N
36346	MEMBRE	2022-04-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30573	\N	\N	\N
36348	MEMBRE	2022-04-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30575	\N	\N	\N
36350	MEMBRE	2022-03-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30577	\N	\N	\N
36351	MEMBRE	2022-04-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30578	\N	\N	\N
36379	MEMBRE	2022-04-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30605	\N	\N	\N
36408	MEMBRE	2022-05-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30626	\N	\N	\N
36504	MEMBRE	2023-01-10 00:00:00	2023-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	30721	\N	\N	\N
36505	MEMBRE	2023-01-10 00:00:00	2023-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	30722	\N	\N	\N
36506	MEMBRE	2023-01-10 00:00:00	2023-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	30723	\N	\N	\N
36507	MEMBRE	2023-01-10 00:00:00	2023-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	30724	\N	\N	\N
36508	MEMBRE	2023-01-10 00:00:00	2023-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	30725	\N	\N	\N
36544	MEMBRE	2023-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30761	\N	\N	\N
36545	MEMBRE	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30762	\N	\N	\N
36567	MEMBRE	2023-01-01 00:00:00	2023-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	30784	\N	\N	\N
36609	MEMBRE	2023-03-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30808	\N	\N	\N
36610	MEMBRE	2023-03-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30809	\N	\N	\N
37967	MEMBRE	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32162	\N	\N	\N
38109	MEMBRE	2023-10-24 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	32304	\N	\N	\N
38110	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32305	\N	\N	\N
38111	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32306	\N	\N	\N
38112	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32307	\N	\N	\N
38113	MEMBRE	2023-10-24 00:00:00	2024-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	32308	\N	\N	\N
38114	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32309	\N	\N	\N
38115	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32310	\N	\N	\N
38116	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32311	\N	\N	\N
38117	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32312	\N	\N	\N
38143	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32338	\N	\N	\N
38144	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32339	\N	\N	\N
38213	MEMBRE	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32408	\N	\N	\N
38214	MEMBRE	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32409	\N	\N	\N
38215	MEMBRE	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32410	\N	\N	\N
38216	MEMBRE	2023-10-26 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	32411	\N	\N	\N
38217	MEMBRE	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32412	\N	\N	\N
38218	MEMBRE	2023-10-26 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	32413	\N	\N	\N
38219	MEMBRE	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32414	\N	\N	\N
38513	MEMBRE	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32708	\N	\N	\N
38514	MEMBRE	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32709	\N	\N	\N
30656	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26357	\N	\N	\N
30937	PDT	2018-02-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	26275	\N	\N	\N
31260	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26745	\N	\N	\N
31272	PDT	2018-05-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26133	\N	\N	\N
31310	MEMBRE	2018-01-31 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26779	\N	2018-06-12 15:16:17	\N
31311	MEMBRE	2018-01-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26780	\N	2018-06-12 15:16:29	\N
31321	MEMBRE	2018-06-27 00:00:00	2018-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	26789	\N	\N	\N
31387	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26849	\N	\N	\N
31634	MEMBRE	2020-01-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27066	\N	\N	\N
33365	MEMBRE	2020-11-04 00:00:00	2020-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	28798	\N	\N	\N
33366	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28799	\N	\N	\N
33367	MEMBRE	2020-11-03 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	28800	\N	\N	\N
33368	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28801	\N	\N	\N
33369	MEMBRE	2020-11-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28802	\N	\N	\N
33962	MEMBRE	2020-12-02 00:00:00	2021-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	29175	\N	\N	\N
33963	MEMBRE	2020-12-02 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	29176	\N	\N	\N
34430	MEMBRE	2020-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29302	\N	\N	\N
34431	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29303	\N	\N	\N
34529	MEMBRE	2020-12-15 00:00:00	2021-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	29393	\N	\N	\N
34531	MEMBRE	2020-12-15 00:00:00	2021-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	29395	\N	\N	\N
34532	MEMBRE	2020-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29396	\N	\N	\N
34561	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29425	\N	\N	\N
34562	MEMBRE	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29426	\N	\N	\N
34977	VICPDT	2021-01-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28020	\N	\N	\N
34978	VICPDT	2021-01-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27428	\N	\N	\N
34979	VICPDT	2021-01-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29145	\N	\N	\N
34980	VICPDT	2021-01-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28834	\N	\N	\N
34981	VICPDT	2021-01-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28618	\N	\N	\N
34982	SECRET	2021-01-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27267	\N	\N	\N
34983	SECRET	2021-01-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28267	\N	\N	\N
34984	SECRET	2021-01-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28245	\N	\N	\N
35058	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29782	\N	\N	\N
35088	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29812	\N	\N	\N
35089	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29813	\N	\N	\N
35090	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29814	\N	\N	\N
35095	MEMBRE	2020-10-01 00:00:00	2021-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	29819	\N	\N	\N
35097	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29821	\N	\N	\N
35126	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29850	\N	\N	\N
35127	MEMBRE	2020-10-01 00:00:00	2021-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	29851	\N	\N	\N
35128	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29852	\N	\N	\N
35134	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29858	\N	\N	\N
35135	MEMBRE	2020-10-01 00:00:00	2021-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	29859	\N	\N	\N
35534	MEMBRE	2021-01-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30072	\N	\N	\N
35671	VICPDT	2021-02-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29819	\N	\N	\N
35672	VICPDT	2021-02-04 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	30090	\N	\N	\N
35673	VICPDT	2021-02-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29793	\N	\N	\N
35674	VICPDT	2021-02-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29798	\N	\N	\N
35750	VICPDT	2021-02-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27242	\N	\N	\N
35751	VICPDT	2021-02-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27209	\N	\N	\N
35752	VICPDT	2021-02-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27119	\N	\N	\N
35753	VICPDT	2021-02-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28944	\N	\N	\N
35754	SECRET	2021-02-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28599	\N	\N	\N
35759	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30154	\N	\N	\N
35760	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30155	\N	\N	\N
35981	MEMBRE	2021-03-24 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	30278	\N	\N	\N
36055	MEMBRE	2021-05-31 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30336	\N	\N	\N
36227	MEMBRE	2021-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30472	\N	\N	\N
36293	MEMBRE	2022-02-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30527	\N	\N	\N
36294	MEMBRE	2022-02-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30528	\N	\N	\N
36325	MEMBRE	2022-03-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30552	\N	\N	\N
36404	MEMBRE	2021-01-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30622	\N	\N	\N
36405	MEMBRE	2022-05-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30623	\N	\N	\N
36447	MEMBRE	2022-09-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30664	\N	\N	\N
36448	MEMBRE	2022-09-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30665	\N	\N	\N
37000	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31190	\N	\N	\N
37001	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31191	\N	\N	\N
37002	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31192	\N	\N	\N
37003	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31193	\N	\N	\N
37004	MEMBRE	2023-10-10 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	31194	\N	\N	\N
37005	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31195	\N	\N	\N
37006	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31196	\N	\N	\N
37007	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31197	\N	\N	\N
37008	MEMBRE	2023-10-10 00:00:00	2024-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	31198	\N	\N	\N
37009	MEMBRE	2023-10-10 00:00:00	2024-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	31199	\N	\N	\N
37010	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31200	\N	\N	\N
37011	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31201	\N	\N	\N
37012	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31202	\N	\N	\N
37013	MEMBRE	2023-10-10 00:00:00	2024-02-29 00:00:00	ACTIF	\N	\N	\N	\N	31203	\N	\N	\N
37014	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31204	\N	\N	\N
37015	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31205	\N	\N	\N
37016	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31206	\N	\N	\N
37017	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31207	\N	\N	\N
37018	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31208	\N	\N	\N
37019	MEMBRE	2023-10-10 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	31209	\N	\N	\N
37020	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31210	\N	\N	\N
37021	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31211	\N	\N	\N
37022	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31212	\N	\N	\N
37023	MEMBRE	2023-10-10 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	31213	\N	\N	\N
37024	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31214	\N	\N	\N
37025	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31215	\N	\N	\N
37026	MEMBRE	2023-10-10 00:00:00	2024-01-28 00:00:00	ACTIF	\N	\N	\N	\N	31216	\N	\N	\N
37027	MEMBRE	2023-10-10 00:00:00	2024-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	31217	\N	\N	\N
37028	MEMBRE	2023-10-10 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	31218	\N	\N	\N
37029	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31219	\N	\N	\N
37030	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31220	\N	\N	\N
37031	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31221	\N	\N	\N
37032	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31222	\N	\N	\N
37033	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31223	\N	\N	\N
37034	MEMBRE	2023-10-10 00:00:00	2024-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	31224	\N	\N	\N
37035	MEMBRE	2023-10-10 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	31225	\N	\N	\N
37036	MEMBRE	2023-10-10 00:00:00	2023-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	31226	\N	\N	\N
37037	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31227	\N	\N	\N
37038	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31228	\N	\N	\N
37039	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31229	\N	\N	\N
37040	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31230	\N	\N	\N
37041	MEMBRE	2023-10-10 00:00:00	2024-02-26 00:00:00	ACTIF	\N	\N	\N	\N	31231	\N	\N	\N
37042	MEMBRE	2023-10-10 00:00:00	2024-02-26 00:00:00	ACTIF	\N	\N	\N	\N	31232	\N	\N	\N
37043	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31233	\N	\N	\N
37044	MEMBRE	2023-10-10 00:00:00	2024-01-25 00:00:00	ACTIF	\N	\N	\N	\N	31234	\N	\N	\N
37045	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31235	\N	\N	\N
37046	MEMBRE	2023-10-10 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	31236	\N	\N	\N
37047	MEMBRE	2023-10-10 00:00:00	2024-02-08 00:00:00	ACTIF	\N	\N	\N	\N	31237	\N	\N	\N
37048	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31238	\N	\N	\N
37049	MEMBRE	2023-10-10 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	31239	\N	\N	\N
37050	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31240	\N	\N	\N
37051	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31241	\N	\N	\N
37052	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31242	\N	\N	\N
37987	MEMBRE	2023-10-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32182	\N	\N	\N
38004	MEMBRE	2023-10-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32199	\N	\N	\N
38026	MEMBRE	2023-10-23 00:00:00	2024-02-13 00:00:00	ACTIF	\N	\N	\N	\N	32221	\N	\N	\N
38027	MEMBRE	2023-10-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32222	\N	\N	\N
38032	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32227	\N	\N	\N
38033	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32228	\N	\N	\N
38055	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32250	\N	\N	\N
38056	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32251	\N	\N	\N
38154	MEMBRE	2023-10-25 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	32349	\N	\N	\N
38238	MEMBRE	2023-10-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32433	\N	\N	\N
38239	MEMBRE	2023-10-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32434	\N	\N	\N
38240	MEMBRE	2023-10-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32435	\N	\N	\N
38241	MEMBRE	2023-10-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32436	\N	\N	\N
38242	MEMBRE	2023-10-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32437	\N	\N	\N
38243	MEMBRE	2023-10-27 00:00:00	2024-01-25 00:00:00	ACTIF	\N	\N	\N	\N	32438	\N	\N	\N
38244	MEMBRE	2023-10-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32439	\N	\N	\N
38245	MEMBRE	2023-10-27 00:00:00	2023-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	32440	\N	\N	\N
38246	MEMBRE	2023-10-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32441	\N	\N	\N
38254	MEMBRE	2023-10-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32449	\N	\N	\N
38255	MEMBRE	2023-10-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32450	\N	\N	\N
40335	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	30730	\N	\N	\N
40341	MEMBRE	2024-01-22 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33837	\N	\N	\N
40345	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	30774	\N	\N	\N
40346	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33841	\N	\N	\N
40373	MEMBRE	2023-12-14 00:00:00	2024-02-05 00:00:00	ACTIF	\N	\N	\N	\N	33846	\N	\N	\N
40374	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33847	\N	\N	\N
40392	MEMBRE	2023-12-14 00:00:00	2024-02-14 00:00:00	ACTIF	\N	\N	\N	\N	33865	\N	\N	\N
40393	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33866	\N	\N	\N
40403	MEMBRE	2023-12-14 00:00:00	2024-02-14 00:00:00	ACTIF	\N	\N	\N	\N	33876	\N	\N	\N
40422	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33895	\N	\N	\N
40423	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33896	\N	\N	\N
40424	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33897	\N	\N	\N
40428	MEMBRE	2023-12-14 00:00:00	2024-02-14 00:00:00	ACTIF	\N	\N	\N	\N	33901	\N	\N	\N
40437	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33910	\N	\N	\N
40439	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33912	\N	\N	\N
40451	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33924	\N	\N	\N
40460	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33933	\N	\N	\N
40462	MEMBRE	2023-12-14 00:00:00	2024-02-14 00:00:00	ACTIF	\N	\N	\N	\N	33935	\N	\N	\N
40464	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33937	\N	\N	\N
40465	MEMBRE	2023-12-14 00:00:00	2024-02-14 00:00:00	ACTIF	\N	\N	\N	\N	33938	\N	\N	\N
40470	MEMBRE	2023-10-01 00:00:00	2024-02-13 00:00:00	ACTIF	\N	\N	\N	\N	33943	\N	\N	\N
40471	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33944	\N	\N	\N
40475	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33948	\N	\N	\N
40481	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33954	\N	\N	\N
40482	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33955	\N	\N	\N
40485	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33958	\N	\N	\N
40486	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33959	\N	\N	\N
40491	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33964	\N	\N	\N
40492	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33965	\N	\N	\N
40493	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33966	\N	\N	\N
40496	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33969	\N	\N	\N
40497	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33970	\N	\N	\N
40511	MEMBRE	2023-12-14 00:00:00	2024-02-05 00:00:00	ACTIF	\N	\N	\N	\N	33984	\N	\N	\N
40517	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33990	\N	\N	\N
40521	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33994	\N	\N	\N
40534	MEMBRE	2023-10-01 00:00:00	2024-02-27 00:00:00	ACTIF	\N	\N	\N	\N	34007	\N	\N	\N
40536	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34009	\N	\N	\N
40537	MEMBRE	2023-10-01 00:00:00	2024-02-27 00:00:00	ACTIF	\N	\N	\N	\N	34010	\N	\N	\N
40538	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34011	\N	\N	\N
40541	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34014	\N	\N	\N
40542	MEMBRE	2023-10-01 00:00:00	2024-02-27 00:00:00	ACTIF	\N	\N	\N	\N	34015	\N	\N	\N
40544	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34017	\N	\N	\N
40545	MEMBRE	2023-10-01 00:00:00	2024-02-12 00:00:00	ACTIF	\N	\N	\N	\N	34018	\N	\N	\N
40546	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34019	\N	\N	\N
40547	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34020	\N	\N	\N
40549	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34022	\N	\N	\N
40550	MEMBRE	2023-10-01 00:00:00	2024-02-27 00:00:00	ACTIF	\N	\N	\N	\N	34023	\N	\N	\N
40551	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34024	\N	\N	\N
40552	MEMBRE	2023-10-01 00:00:00	2024-02-27 00:00:00	ACTIF	\N	\N	\N	\N	34025	\N	\N	\N
40553	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34026	\N	\N	\N
40554	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34027	\N	\N	\N
40555	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34028	\N	\N	\N
40557	MEMBRE	2023-10-01 00:00:00	2024-02-12 00:00:00	ACTIF	\N	\N	\N	\N	34030	\N	\N	\N
40567	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34040	\N	\N	\N
40568	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34041	\N	\N	\N
40570	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34043	\N	\N	\N
40571	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34044	\N	\N	\N
40573	MEMBRE	2023-10-01 00:00:00	2024-02-27 00:00:00	ACTIF	\N	\N	\N	\N	34046	\N	\N	\N
40574	MEMBRE	2023-10-01 00:00:00	2024-02-06 00:00:00	ACTIF	\N	\N	\N	\N	34047	\N	\N	\N
40575	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34048	\N	\N	\N
40576	MEMBRE	2023-10-01 00:00:00	2024-02-06 00:00:00	ACTIF	\N	\N	\N	\N	34049	\N	\N	\N
40577	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34050	\N	\N	\N
40578	MEMBRE	2023-10-01 00:00:00	2024-02-06 00:00:00	ACTIF	\N	\N	\N	\N	34051	\N	\N	\N
40579	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34052	\N	\N	\N
40580	MEMBRE	2024-01-23 00:00:00	2024-01-29 00:00:00	ACTIF	\N	\N	\N	\N	34053	\N	\N	\N
40584	MEMBRE	2023-10-01 00:00:00	2024-02-06 00:00:00	ACTIF	\N	\N	\N	\N	34057	\N	\N	\N
40585	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34058	\N	\N	\N
40586	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34059	\N	\N	\N
40588	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34061	\N	\N	\N
40589	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34062	\N	\N	\N
40590	MEMBRE	2023-12-14 00:00:00	2024-02-05 00:00:00	ACTIF	\N	\N	\N	\N	34063	\N	\N	\N
40592	MEMBRE	2023-12-14 00:00:00	2024-02-05 00:00:00	ACTIF	\N	\N	\N	\N	34065	\N	\N	\N
40597	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34070	\N	\N	\N
40598	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34071	\N	\N	\N
40599	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34072	\N	\N	\N
40600	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34073	\N	\N	\N
40602	MEMBRE	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34075	\N	\N	\N
40651	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34124	\N	\N	\N
40660	VICPDT	2024-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	33745	\N	\N	\N
40661	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34130	\N	\N	\N
40662	VICPDT	2024-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	33803	\N	\N	\N
40663	MEMBRE	2023-12-14 00:00:00	2024-02-06 00:00:00	ACTIF	\N	\N	\N	\N	34131	\N	\N	\N
40664	VICPDT	2024-01-24 00:00:00	2024-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	33794	\N	\N	\N
40665	VICPDT	2024-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	33793	\N	\N	\N
40667	VICPDT	2024-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	33790	\N	\N	\N
40668	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34132	\N	\N	\N
40669	VICPDT	2024-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	33820	\N	\N	\N
40672	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34134	\N	\N	\N
40673	VICPDT	2024-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	33787	\N	\N	\N
40681	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34140	\N	\N	\N
40675	VICPDT	2024-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	33815	\N	\N	\N
40678	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34137	\N	\N	\N
40680	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34139	\N	\N	\N
40682	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34141	\N	\N	\N
40683	MEMBRE	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34142	\N	\N	\N
40687	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34146	\N	\N	\N
40696	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34155	\N	\N	\N
40697	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34156	\N	\N	\N
40698	MEMBRE	2023-12-14 00:00:00	2024-02-06 00:00:00	ACTIF	\N	\N	\N	\N	34157	\N	\N	\N
40699	MEMBRE	2023-12-14 00:00:00	2024-02-06 00:00:00	ACTIF	\N	\N	\N	\N	34158	\N	\N	\N
40700	MEMBRE	2023-12-14 00:00:00	2024-02-06 00:00:00	ACTIF	\N	\N	\N	\N	34159	\N	\N	\N
40702	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34161	\N	\N	\N
40703	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34162	\N	\N	\N
40705	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34164	\N	\N	\N
40706	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34165	\N	\N	\N
40708	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34167	\N	\N	\N
40709	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34168	\N	\N	\N
40710	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34169	\N	\N	\N
40726	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	34184	\N	\N	\N
40728	MEMBRE	2024-01-02 00:00:00	2024-01-23 00:00:00	ACTIF	\N	\N	\N	\N	34186	\N	\N	\N
40732	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	30803	\N	\N	\N
40736	VICPDT	2024-01-23 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	\N	30203	\N	\N	\N
40758	MEMBRE	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34194	\N	\N	\N
40759	MEMBRE	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34195	\N	\N	\N
40763	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34199	\N	\N	\N
40764	MEMBRE	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34200	\N	\N	\N
40765	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34201	\N	\N	\N
40768	MEMBRE	2023-12-14 00:00:00	2024-02-12 00:00:00	ACTIF	\N	\N	\N	\N	34204	\N	\N	\N
40769	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34205	\N	\N	\N
40770	MEMBRE	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34206	\N	\N	\N
40771	MEMBRE	2024-01-23 00:00:00	2024-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	34207	\N	\N	\N
40781	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34212	\N	\N	\N
40782	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34213	\N	\N	\N
40783	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34214	\N	\N	\N
40784	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34215	\N	\N	\N
40785	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34216	\N	\N	\N
40789	MEMBRE	2023-10-01 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	34220	\N	\N	\N
40790	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34221	\N	\N	\N
40808	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	34224	\N	\N	\N
40822	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34227	\N	\N	\N
40823	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34228	\N	\N	\N
40825	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34229	\N	\N	\N
40826	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	30746	\N	\N	\N
40827	MEMBRE	2023-10-01 00:00:00	2024-02-13 00:00:00	ACTIF	\N	\N	\N	\N	34230	\N	\N	\N
40828	MEMBRE	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34231	\N	\N	\N
40829	MEMBRE	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34232	\N	\N	\N
40835	MEMBRE	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34238	\N	\N	\N
40837	MEMBRE	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34240	\N	\N	\N
40868	VICPDT	2024-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	33665	\N	\N	\N
40879	MEMBRE	2024-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	33794	\N	\N	\N
40884	PDTHON	2024-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	30733	\N	\N	\N
40885	VICPDT	2024-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	30752	\N	\N	\N
40886	VICPDT	2024-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	30787	\N	\N	\N
40889	VICPDT	2024-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	30735	\N	\N	\N
40892	VICPDT	2024-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	33606	\N	\N	\N
40893	VICPDT	2024-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	33568	\N	\N	\N
40894	VICPDT	2024-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	33554	\N	\N	\N
40896	VICPDT	2024-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	33559	\N	\N	\N
40897	VICPDT	2024-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	30744	\N	\N	\N
40901	VICPDT	2024-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	33558	\N	\N	\N
40902	VICPDT	2024-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	33599	\N	\N	\N
40903	VICPDT	2024-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	30753	\N	\N	\N
40907	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33402	\N	\N	\N
40908	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33268	\N	\N	\N
40909	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31265	\N	\N	\N
40910	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32164	\N	\N	\N
40911	VICPDT	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33705	\N	\N	\N
40912	SECRET	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32807	\N	\N	\N
40914	MEMBRE	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34251	\N	\N	\N
30887	MEMBRE	2017-10-01 00:00:00	2018-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	26523	\N	\N	\N
30889	MEMBRE	2017-10-01 00:00:00	2018-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	26525	\N	\N	\N
30892	MEMBRE	2017-10-01 00:00:00	2018-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	26528	\N	\N	\N
30893	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26529	\N	\N	\N
30966	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26560	\N	\N	\N
30968	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26562	\N	\N	\N
30969	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26563	\N	\N	\N
31330	MEMBRE	2018-07-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26795	\N	\N	\N
31385	MEMBRE	2018-10-03 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26847	\N	\N	\N
31386	MEMBRE	2018-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26848	\N	\N	\N
31402	MEMBRE	2018-10-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26863	\N	\N	\N
31458	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26919	\N	\N	\N
31544	PDT	2019-03-11 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26996	\N	\N	\N
32202	MEMBRE	2020-10-13 00:00:00	2020-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	27631	\N	\N	\N
32203	MEMBRE	2020-10-13 00:00:00	2021-01-11 00:00:00	ANCIEN	\N	\N	\N	\N	27632	\N	\N	\N
32204	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27633	\N	\N	\N
32205	MEMBRE	2020-10-13 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	27634	\N	\N	\N
32206	MEMBRE	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27635	\N	\N	\N
32207	MEMBRE	2020-10-06 00:00:00	2021-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	27636	\N	\N	\N
32208	MEMBRE	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27637	\N	\N	\N
32709	MEMBRE	2020-10-21 00:00:00	2020-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	28138	\N	\N	\N
32710	MEMBRE	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28139	\N	\N	\N
32711	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28140	\N	\N	\N
32712	MEMBRE	2020-10-16 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	28141	\N	\N	\N
32713	MEMBRE	2020-10-16 00:00:00	2021-01-14 00:00:00	ANCIEN	\N	\N	\N	\N	28142	\N	\N	\N
32714	MEMBRE	2020-10-16 00:00:00	2020-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	28143	\N	\N	\N
32715	MEMBRE	2020-10-16 00:00:00	2021-01-03 00:00:00	ANCIEN	\N	\N	\N	\N	28144	\N	\N	\N
32716	MEMBRE	2020-10-16 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	28145	\N	\N	\N
32717	MEMBRE	2020-10-16 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	28146	\N	\N	\N
32718	MEMBRE	2020-10-16 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	28147	\N	\N	\N
32719	MEMBRE	2020-10-21 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	28148	\N	\N	\N
32720	MEMBRE	2020-10-21 00:00:00	2020-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	28149	\N	\N	\N
32721	MEMBRE	2020-10-21 00:00:00	2021-01-11 00:00:00	ANCIEN	\N	\N	\N	\N	28150	\N	\N	\N
32722	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28151	\N	\N	\N
33464	MEMBRE	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28886	\N	\N	\N
33465	MEMBRE	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28887	\N	\N	\N
33466	MEMBRE	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28888	\N	\N	\N
33467	MEMBRE	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28889	\N	\N	\N
33468	MEMBRE	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28890	\N	\N	\N
33469	MEMBRE	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28891	\N	\N	\N
33470	MEMBRE	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28892	\N	\N	\N
33471	MEMBRE	2020-11-09 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	28893	\N	\N	\N
33472	MEMBRE	2020-11-09 00:00:00	2020-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	28894	\N	\N	\N
33473	MEMBRE	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28895	\N	\N	\N
33474	MEMBRE	2020-11-09 00:00:00	2021-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	28896	\N	\N	\N
33475	MEMBRE	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28897	\N	\N	\N
33476	MEMBRE	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28898	\N	\N	\N
33477	MEMBRE	2020-11-09 00:00:00	2021-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	28899	\N	\N	\N
33478	MEMBRE	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28900	\N	\N	\N
33479	MEMBRE	2020-11-09 00:00:00	2021-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	28901	\N	\N	\N
34018	MEMBRE	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29187	\N	\N	\N
34289	MEMBRE	2020-12-16 00:00:00	2021-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	29270	\N	\N	\N
34501	MEMBRE	2020-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29365	\N	\N	\N
34502	MEMBRE	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29366	\N	\N	\N
34509	MEMBRE	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29373	\N	\N	\N
34513	MEMBRE	2020-12-15 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	29377	\N	\N	\N
34541	MEMBRE	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29405	\N	\N	\N
34585	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29449	\N	\N	\N
34586	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29450	\N	\N	\N
34587	MEMBRE	2020-12-15 00:00:00	2021-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	29451	\N	\N	\N
34588	MEMBRE	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29452	\N	\N	\N
34589	MEMBRE	2020-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29453	\N	\N	\N
34590	MEMBRE	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29454	\N	\N	\N
34591	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29455	\N	\N	\N
34592	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29456	\N	\N	\N
34635	MEMBRE	2020-12-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29493	\N	\N	\N
34642	MEMBRE	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29500	\N	\N	\N
34761	MEMBRE	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29177	\N	\N	\N
34762	VICPDT	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27681	\N	\N	\N
35457	VICPDT	2021-01-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	29843	\N	\N	\N
35646	MEMBRE	2021-02-03 00:00:00	2021-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	30131	\N	\N	\N
35804	MEMBRE	2021-02-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30190	\N	\N	\N
36001	MEMBRE	2021-03-25 00:00:00	2021-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	30298	\N	\N	\N
36002	MEMBRE	2021-03-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30299	\N	\N	\N
36003	MEMBRE	2021-03-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	30300	\N	\N	\N
36004	MEMBRE	2021-03-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	30301	\N	\N	\N
36005	MEMBRE	2021-03-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30302	\N	\N	\N
36006	MEMBRE	2021-03-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30303	\N	\N	\N
36057	MEMBRE	2021-06-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30338	\N	\N	\N
36400	MEMBRE	2022-04-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30618	\N	\N	\N
36486	MEMBRE	2022-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30703	\N	\N	\N
36521	MEMBRE	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30738	\N	\N	\N
36550	MEMBRE	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30767	\N	\N	\N
37208	MEMBRE	2023-10-10 00:00:00	2023-11-13 00:00:00	ANCIEN	\N	\N	\N	\N	31400	\N	\N	\N
37209	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31401	\N	\N	\N
38301	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32496	\N	\N	\N
38302	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32497	\N	\N	\N
38303	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32498	\N	\N	\N
38416	MEMBRE	2023-11-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32611	\N	\N	\N
38417	MEMBRE	2023-11-01 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	32612	\N	\N	\N
38418	MEMBRE	2023-11-01 00:00:00	2023-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	32613	\N	\N	\N
38419	MEMBRE	2023-11-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32614	\N	\N	\N
38420	MEMBRE	2023-11-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32615	\N	\N	\N
38515	MEMBRE	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32710	\N	\N	\N
38614	MEMBRE	2023-11-08 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	32809	\N	\N	\N
38622	MEMBRE	2023-11-08 00:00:00	2023-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	32817	\N	\N	\N
38701	MEMBRE	2023-11-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32896	\N	\N	\N
38712	MEMBRE	2023-11-15 00:00:00	2024-02-27 00:00:00	ACTIF	\N	\N	\N	\N	32907	\N	\N	\N
38713	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32908	\N	\N	\N
38893	PDTDEL	2023-11-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour l'Arabie Saoudite	\N	31579	\N	\N	\N
38894	PDTDEL	2023-11-20 00:00:00	2023-12-13 00:00:00	ANCIEN	\N	\N	pour l'Argentine	\N	32817	\N	\N	\N
38895	PDTDEL	2023-11-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour l'Ethiopie	\N	32905	\N	\N	\N
38896	PDTDEL	2023-11-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour le Mali	\N	32506	\N	\N	\N
38938	PDT	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33111	\N	\N	\N
38982	MEMBRE	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33155	\N	\N	\N
39159	MEMBRE	2023-11-29 00:00:00	2024-01-25 00:00:00	ACTIF	\N	\N	\N	\N	33204	\N	\N	\N
39185	MEMBRE	2023-12-01 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	33230	\N	\N	\N
39186	MEMBRE	2023-12-01 00:00:00	2024-01-30 00:00:00	ACTIF	\N	\N	\N	\N	33231	\N	\N	\N
39187	MEMBRE	2023-12-01 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	33232	\N	\N	\N
39188	MEMBRE	2023-12-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33233	\N	\N	\N
39249	MEMBRE	2023-12-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33293	\N	\N	\N
39250	MEMBRE	2023-12-06 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	33294	\N	\N	\N
39327	MEMBRE	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33321	\N	\N	\N
39449	MEMBRE	2023-12-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33375	\N	\N	\N
39496	MEMBRE	2023-12-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33390	\N	\N	\N
39603	MEMBRE	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33399	\N	\N	\N
39672	MEMBRE	2023-12-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	30191	\N	\N	\N
39678	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33422	\N	\N	\N
39704	MEMBRE	2023-10-01 00:00:00	2024-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	33443	\N	\N	\N
39706	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33445	\N	\N	\N
39833	MEMBRE	2024-01-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33501	\N	\N	\N
39834	MEMBRE	2024-01-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33502	\N	\N	\N
39837	MEMBRE	2024-01-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33505	\N	\N	\N
39840	MEMBRE	2024-01-15 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	33508	\N	\N	\N
39841	MEMBRE	2024-01-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33509	\N	\N	\N
39937	VICPDT	2024-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	33543	\N	\N	\N
39938	MEMBRE	2023-12-14 00:00:00	2024-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	33544	\N	\N	\N
39941	VICPDT	2024-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	33545	\N	\N	\N
40005	MEMBRE	2024-01-17 00:00:00	2024-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	30046	\N	\N	\N
40006	MEMBRE	2024-01-17 00:00:00	2024-01-22 00:00:00	ACTIF	\N	\N	\N	\N	30217	\N	\N	\N
40015	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33592	\N	\N	\N
40073	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33650	\N	\N	\N
40078	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33655	\N	\N	\N
40083	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33660	\N	\N	\N
40091	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33668	\N	\N	\N
40136	MEMBRE	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33704	\N	\N	\N
40266	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33795	\N	\N	\N
40268	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33797	\N	\N	\N
40414	MEMBRE	2023-12-14 00:00:00	2024-02-14 00:00:00	ACTIF	\N	\N	\N	\N	33887	\N	\N	\N
40417	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33890	\N	\N	\N
41560	PDT	2024-04-09 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	30196	\N	\N	\N
30633	VICPDT	2018-02-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25265	\N	2018-02-08 17:33:22	\N
30634	VICPDT	2018-02-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23952	\N	2018-02-08 17:35:54	\N
30635	VICPDT	2018-02-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24099	\N	2018-02-08 17:36:00	\N
30636	VICPDT	2018-02-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23945	\N	2018-02-08 17:36:10	\N
30637	SECRET	2018-02-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25445	\N	2018-02-08 17:36:17	\N
30638	SECRET	2018-02-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25616	\N	2018-02-08 17:36:21	\N
30812	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26483	\N	\N	\N
30813	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26484	\N	\N	\N
30814	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26485	\N	\N	\N
30816	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26487	\N	\N	\N
30934	MEMBRE	2018-02-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26543	\N	2018-02-15 16:34:02	\N
30967	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26561	\N	\N	\N
31180	PDT	2018-03-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	26586	\N	\N	\N
31181	VICPDT	2018-03-15 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26468	\N	\N	\N
31182	VICPDT	2018-03-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	26457	\N	\N	\N
31184	VICPDT	2018-03-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	26462	\N	\N	\N
31185	VICPDT	2018-03-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	26458	\N	\N	\N
31454	MEMBRE	2018-11-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26915	\N	\N	\N
31455	PDT	2018-11-19 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	26916	\N	\N	\N
31560	MEMBRE	2019-04-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	27007	\N	\N	\N
33130	MEMBRE	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28563	\N	\N	\N
33419	MEMBRE	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28841	\N	\N	\N
33420	MEMBRE	2020-10-21 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	28842	\N	\N	\N
33421	MEMBRE	2020-10-21 00:00:00	2022-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	28843	\N	\N	\N
33422	MEMBRE	2020-10-21 00:00:00	2021-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	28844	\N	\N	\N
33423	MEMBRE	2020-11-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28845	\N	\N	\N
33424	MEMBRE	2020-11-03 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	28846	\N	\N	\N
33425	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28847	\N	\N	\N
33426	MEMBRE	2020-10-30 00:00:00	2021-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	28848	\N	\N	\N
33427	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28849	\N	\N	\N
33428	MEMBRE	2020-10-30 00:00:00	2020-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	28850	\N	\N	\N
33429	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28851	\N	\N	\N
33430	MEMBRE	2020-10-30 00:00:00	2021-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	28852	\N	\N	\N
33431	MEMBRE	2020-10-30 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	28853	\N	\N	\N
33432	MEMBRE	2020-10-30 00:00:00	2021-01-03 00:00:00	ANCIEN	\N	\N	\N	\N	28854	\N	\N	\N
33433	MEMBRE	2020-10-30 00:00:00	2020-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	28855	\N	\N	\N
33434	MEMBRE	2020-10-30 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	28856	\N	\N	\N
33435	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28857	\N	\N	\N
33436	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28858	\N	\N	\N
33437	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28859	\N	\N	\N
33438	MEMBRE	2020-10-30 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	28860	\N	\N	\N
33439	MEMBRE	2020-10-30 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	28861	\N	\N	\N
33440	MEMBRE	2020-10-30 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	28862	\N	\N	\N
33441	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28863	\N	\N	\N
33528	PDT	2020-11-17 00:00:00	2020-11-24 00:00:00	ANCIEN	\N	\N	\N	\N	27448	\N	\N	\N
33529	PDT	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28003	\N	\N	\N
33530	PDT	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27437	\N	\N	\N
33531	PDT	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27118	\N	\N	\N
33532	PDTDEL	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour le Bangladesh	\N	28424	\N	\N	\N
33872	MEMBRE	2020-11-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29123	\N	\N	\N
34212	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27397	\N	\N	\N
34213	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29009	\N	\N	\N
34214	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27261	\N	\N	\N
34215	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27713	\N	\N	\N
34216	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27674	\N	\N	\N
34217	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28074	\N	\N	\N
34218	SECRET	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28133	\N	\N	\N
34427	MEMBRE	2020-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29299	\N	\N	\N
34519	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29383	\N	\N	\N
34523	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29387	\N	\N	\N
34524	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29388	\N	\N	\N
34525	MEMBRE	2020-12-15 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	29389	\N	\N	\N
34527	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29391	\N	\N	\N
34528	MEMBRE	2020-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29392	\N	\N	\N
34542	MEMBRE	2020-12-16 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	29406	\N	\N	\N
34544	MEMBRE	2020-12-15 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	29408	\N	\N	\N
34545	MEMBRE	2020-12-15 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	29409	\N	\N	\N
34571	MEMBRE	2020-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29435	\N	\N	\N
34573	MEMBRE	2020-12-15 00:00:00	2021-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	29437	\N	\N	\N
34641	MEMBRE	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29499	\N	\N	\N
34803	MEMBRE	2021-01-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29592	\N	\N	\N
34817	MEMBRE	2021-01-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29600	\N	\N	\N
34867	MEMBRE	2021-01-05 00:00:00	2021-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	29650	\N	\N	\N
34999	MEMBRE	2021-01-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29747	\N	\N	\N
35578	VICPDT	2021-01-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	29602	\N	\N	\N
35579	VICPDT	2021-01-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29981	\N	\N	\N
35925	MEMBRE	2021-03-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	30237	\N	\N	\N
36020	VICPDT	2021-03-30 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29873	\N	\N	\N
36024	SECRET	2021-03-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29864	\N	\N	\N
36025	SECRET	2021-03-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30197	\N	\N	\N
36026	SECRET	2021-03-30 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29872	\N	\N	\N
36194	MEMBRE	2021-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	30446	\N	\N	\N
36265	VICPDT	2021-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	30464	\N	\N	\N
36266	SECRET	2021-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	30452	\N	\N	\N
36542	MEMBRE	2023-01-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30759	\N	\N	\N
36554	MEMBRE	2023-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30771	\N	\N	\N
36601	MEMBRE	2023-02-15 00:00:00	2023-07-18 00:00:00	ANCIEN	\N	\N	\N	\N	27378	\N	\N	\N
36602	VICPDT	2023-02-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27527	\N	\N	\N
36603	SECRET	2023-02-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27709	\N	\N	\N
36604	MEMBRE	2023-02-15 00:00:00	2023-07-18 00:00:00	ANCIEN	\N	\N	\N	\N	29198	\N	\N	\N
36605	PDTHON	2023-02-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28676	\N	\N	\N
36606	VICPDT	2023-02-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30461	\N	\N	\N
36607	VICPDT	2023-02-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30457	\N	\N	\N
38256	MEMBRE	2023-10-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32451	\N	\N	\N
38257	MEMBRE	2023-10-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32452	\N	\N	\N
38329	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32524	\N	\N	\N
38372	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32567	\N	\N	\N
38385	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32580	\N	\N	\N
38411	MEMBRE	2023-11-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32606	\N	\N	\N
38547	MEMBRE	2023-11-06 00:00:00	2024-02-27 00:00:00	ACTIF	\N	\N	\N	\N	32742	\N	\N	\N
38565	MEMBRE	2023-11-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32760	\N	\N	\N
38587	MEMBRE	2023-11-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32782	\N	\N	\N
38718	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32913	\N	\N	\N
38721	MEMBRE	2023-11-15 00:00:00	2024-01-30 00:00:00	ACTIF	\N	\N	\N	\N	32916	\N	\N	\N
39044	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	Pour l'Islande	\N	31480	\N	\N	\N
39045	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	Pour  le Kirghizstan	\N	31774	\N	\N	\N
39046	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	Pour le Luxembourg	\N	32803	\N	\N	\N
39047	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour le Niger	\N	32397	\N	\N	\N
39048	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	Pour la Norvège	\N	31340	\N	\N	\N
39049	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour le Sultanat d'Oman	\N	31945	\N	\N	\N
39050	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour la Gambie	\N	31527	\N	\N	\N
39051	PDT	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32649	\N	\N	\N
39052	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour la Papouasie-Nouvelle Guinée	\N	32593	\N	\N	\N
39053	PDT	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31153	\N	\N	\N
39055	PDT	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31175	\N	\N	\N
39056	PDT	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31068	\N	\N	\N
39057	PDT	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32315	\N	\N	\N
39058	PDT	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31771	\N	\N	\N
39059	PDT	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32718	\N	\N	\N
39060	PDT	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32510	\N	\N	\N
39061	PDT	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31103	\N	\N	\N
39062	PDT	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32514	\N	\N	\N
39063	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour l'Angola	\N	32474	\N	\N	\N
39064	PDT	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31979	\N	\N	\N
39065	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour Bahreïn	\N	31034	\N	\N	\N
39066	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	Pour le Bostwana	\N	30968	\N	\N	\N
39067	PDTDEL	2023-11-28 00:00:00	2023-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	31334	\N	\N	\N
39068	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour le Cameroun	\N	31930	\N	\N	\N
39070	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour le Cap-Vert	\N	31773	\N	\N	\N
39071	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour la Colombie	\N	32390	\N	\N	\N
39072	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour les Emirats arabes unis	\N	30896	\N	\N	\N
39073	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour le Gabon	\N	31010	\N	\N	\N
39074	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour la Géorgie	\N	32668	\N	\N	\N
40915	VICPDT	2024-01-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31605	\N	\N	\N
40916	SECRET	2024-01-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34207	\N	\N	\N
40917	SECRET	2024-01-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32837	\N	\N	\N
40919	PDTHON	2024-01-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33169	\N	\N	\N
40920	VICPDT	2024-01-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32466	\N	\N	\N
40921	VICPDT	2024-01-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31199	\N	\N	\N
40922	VICPDT	2024-01-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32819	\N	\N	\N
40923	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34252	\N	\N	\N
40940	MEMBRE	2023-12-14 00:00:00	\N	\N	\N	\N	\N	\N	34262	\N	\N	\N
40976	MEMBRE	2024-01-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34267	\N	\N	\N
40978	VICPDT	2024-01-29 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32340	\N	\N	\N
40979	MEMBRE	2024-01-29 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31686	\N	\N	\N
40980	VICPDT	2024-01-29 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31216	\N	\N	\N
40981	VICPDT	2024-01-29 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32884	\N	\N	\N
40982	VICPDT	2024-01-29 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31887	\N	\N	\N
40983	VICPDT	2024-01-29 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31651	\N	\N	\N
40984	SECRET	2024-01-29 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32187	\N	\N	\N
40986	PDTDEL	2024-01-29 00:00:00	2024-01-30 00:00:00	ACTIF	\N	\N	pour l'Erythrée	\N	34269	\N	\N	\N
41012	VICPDT	2024-01-30 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	33406	\N	\N	\N
41013	VICPDT	2024-01-30 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	29818	\N	\N	\N
41021	VICPDT	2024-01-31 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	34255	\N	\N	\N
41022	VICPDT	2024-01-31 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	33238	\N	\N	\N
41023	VICPDT	2024-01-31 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31869	\N	\N	\N
41024	VICPDT	2024-01-31 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31859	\N	\N	\N
41025	VICPDT	2024-01-31 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31764	\N	\N	\N
41026	VICPDT	2024-01-31 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32492	\N	\N	\N
41027	VICPDT	2024-01-31 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32445	\N	\N	\N
41028	VICPDT	2024-01-31 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	33263	\N	\N	\N
41029	SECRET	2024-01-31 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32916	\N	\N	\N
41030	SECRET	2024-01-31 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31154	\N	\N	\N
41037	VICPDT	2024-01-31 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32472	\N	\N	\N
41038	VICPDT	2024-01-31 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32032	\N	\N	\N
41039	VICPDT	2024-01-31 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31045	\N	\N	\N
41040	SECRET	2024-01-31 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32968	\N	\N	\N
41042	VICPDT	2024-01-31 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	33231	\N	\N	\N
41043	VICPDT	2024-01-31 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31124	\N	\N	\N
41044	VICPDT	2024-01-31 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	33047	\N	\N	\N
41045	VICPDT	2024-01-31 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32886	\N	\N	\N
41046	VICPDT	2024-01-31 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32550	\N	\N	\N
41047	VICPDT	2024-01-31 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32695	\N	\N	\N
41048	VICPDT	2024-01-31 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	30952	\N	\N	\N
41049	VICPDT	2024-01-31 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31116	\N	\N	\N
41050	SECRET	2024-01-31 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31496	\N	\N	\N
41051	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34276	\N	\N	\N
41052	MEMBRE	2024-01-02 00:00:00	\N	\N	\N	\N	\N	\N	34277	\N	\N	\N
41053	MEMBRE	2024-01-02 00:00:00	\N	\N	\N	\N	\N	\N	34278	\N	\N	\N
41057	VICPDT	2024-02-01 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31144	\N	\N	\N
41058	MEMBRE	2023-12-14 00:00:00	\N	\N	\N	\N	\N	\N	34281	\N	\N	\N
41060	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34283	\N	\N	\N
41062	MEMBRE	2023-12-14 00:00:00	\N	\N	\N	\N	\N	\N	34285	\N	\N	\N
41065	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34288	\N	\N	\N
41066	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34289	\N	\N	\N
41078	MEMBRE	2023-12-14 00:00:00	2024-02-05 00:00:00	\N	\N	\N	\N	\N	34292	\N	\N	\N
41088	MEMBRE	2023-12-14 00:00:00	2024-02-05 00:00:00	\N	\N	\N	\N	\N	34297	\N	\N	\N
41094	VICPDT	2024-02-06 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	33426	\N	\N	\N
41096	PDT	2024-02-06 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	30832	\N	\N	\N
41099	MEMBRE	2024-02-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34301	\N	\N	\N
41100	MEMBRE	2024-02-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34302	\N	\N	\N
41113	VICPDT	2024-02-06 00:00:00	\N	\N	\N	\N	\N	\N	33978	\N	\N	\N
41115	VICPDT	2024-02-06 00:00:00	\N	\N	\N	\N	\N	\N	34069	\N	\N	\N
41117	SECRET	2024-02-06 00:00:00	\N	\N	\N	\N	\N	\N	33981	\N	\N	\N
41118	PDT	2024-02-07 00:00:00	\N	\N	\N	\N	\N	\N	34034	\N	\N	\N
41122	VICPDT	2024-02-07 00:00:00	\N	\N	\N	\N	\N	\N	34049	\N	\N	\N
41127	VICPDT	2024-02-06 00:00:00	\N	\N	\N	\N	\N	\N	34063	\N	\N	\N
41173	VICPDT	2024-02-09 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31048	\N	\N	\N
41171	VICPDT	2024-02-09 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31261	\N	\N	\N
41132	MEMBRE	2023-12-14 00:00:00	\N	\N	\N	\N	\N	\N	34308	\N	\N	\N
41133	MEMBRE	2023-12-14 00:00:00	\N	\N	\N	\N	\N	\N	34309	\N	\N	\N
41134	VICPDT	2024-02-07 00:00:00	\N	\N	\N	\N	\N	\N	34157	\N	\N	\N
41136	VICPDT	2024-02-07 00:00:00	\N	\N	\N	\N	\N	\N	34148	\N	\N	\N
41139	VICPDT	2024-02-07 00:00:00	\N	\N	\N	\N	\N	\N	34143	\N	\N	\N
41140	VICPDT	2024-02-07 00:00:00	\N	\N	\N	\N	\N	\N	34131	\N	\N	\N
41141	VICPDT	2024-02-07 00:00:00	\N	\N	\N	\N	\N	\N	34138	\N	\N	\N
41142	VICPDT	2024-02-07 00:00:00	\N	\N	\N	\N	\N	\N	34136	\N	\N	\N
41143	VICPDT	2024-02-07 00:00:00	\N	\N	\N	\N	\N	\N	34121	\N	\N	\N
41172	VICPDT	2024-02-09 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	33343	\N	\N	\N
41174	VICPDT	2024-02-09 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	33009	\N	\N	\N
41175	VICPDT	2024-02-09 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32835	\N	\N	\N
41176	SECRET	2024-02-09 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	30898	\N	\N	\N
41177	VICPDT	2024-02-09 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31161	\N	\N	\N
41178	VICPDT	2024-02-09 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31237	\N	\N	\N
41179	VICPDT	2024-02-09 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32333	\N	\N	\N
41180	VICPDT	2024-02-09 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32554	\N	\N	\N
41181	VICPDT	2024-02-09 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32883	\N	\N	\N
41182	VICPDT	2024-02-09 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32657	\N	\N	\N
41183	SECRET	2024-02-09 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	33058	\N	\N	\N
41184	SECRET	2024-02-09 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	33487	\N	\N	\N
41192	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34325	\N	\N	\N
41198	MEMBRE	2023-10-01 00:00:00	2024-02-12 00:00:00	\N	\N	\N	\N	\N	34331	\N	\N	\N
41201	VICPDT	2024-02-13 00:00:00	\N	\N	\N	\N	\N	\N	34319	\N	\N	\N
41202	VICPDT	2024-02-13 00:00:00	\N	\N	\N	\N	\N	\N	34204	\N	\N	\N
41204	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34332	\N	\N	\N
41207	VICPDT	2024-02-13 00:00:00	\N	\N	\N	\N	\N	\N	34333	\N	\N	\N
41206	MEMBRE	2023-12-14 00:00:00	2024-02-05 00:00:00	\N	\N	\N	\N	\N	34333	\N	\N	\N
41211	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34337	\N	\N	\N
41219	VICPDT	2024-02-14 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	33518	\N	\N	\N
41220	VICPDT	2024-02-14 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32221	\N	\N	\N
41221	VICPDT	2024-02-14 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31342	\N	\N	\N
41222	VICPDT	2024-02-14 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32697	\N	\N	\N
41223	VICPDT	2024-02-14 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	33506	\N	\N	\N
41224	VICPDT	2024-02-14 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	33504	\N	\N	\N
41225	VICPDT	2024-02-14 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31644	\N	\N	\N
41226	VICPDT	2024-02-14 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32702	\N	\N	\N
41227	VICPDT	2024-02-14 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31769	\N	\N	\N
41228	VICPDT	2024-02-14 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31432	\N	\N	\N
41231	MEMBRE	2024-01-02 00:00:00	\N	\N	\N	\N	\N	\N	34346	\N	\N	\N
41239	VICPDT	2024-02-14 00:00:00	\N	\N	\N	\N	\N	\N	33921	\N	\N	\N
41241	PDT	2024-02-13 00:00:00	\N	\N	\N	\N	\N	\N	34085	\N	\N	\N
41281	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34353	\N	\N	\N
41290	PDT	2024-02-27 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	33960	\N	\N	\N
41294	VICPDT	2024-02-27 00:00:00	\N	\N	\N	\N	\N	\N	33957	\N	\N	\N
41298	VICPDT	2024-02-27 00:00:00	\N	\N	\N	\N	\N	\N	33962	\N	\N	\N
41299	VICPDT	2024-02-27 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31549	\N	\N	\N
41300	VICPDT	2024-02-27 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31590	\N	\N	\N
41301	VICPDT	2024-02-27 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31231	\N	\N	\N
41302	VICPDT	2024-02-27 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32641	\N	\N	\N
41303	SECRET	2024-02-27 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31272	\N	\N	\N
41304	VICPDT	2024-02-27 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	33136	\N	\N	\N
41305	VICPDT	2024-02-27 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32787	\N	\N	\N
41306	VICPDT	2024-02-27 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31959	\N	\N	\N
41307	VICPDT	2024-02-27 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31232	\N	\N	\N
41308	VICPDT	2024-02-27 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31156	\N	\N	\N
41309	VICPDT	2024-02-27 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31416	\N	\N	\N
41310	VICPDT	2024-02-27 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31621	\N	\N	\N
41311	VICPDT	2024-02-27 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32008	\N	\N	\N
41312	VICPDT	2024-02-27 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31469	\N	\N	\N
41313	VICPDT	2024-02-27 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32502	\N	\N	\N
41314	VICPDT	2024-02-27 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32966	\N	\N	\N
41315	SECRET	2024-02-27 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	33211	\N	\N	\N
41316	SECRET	2024-02-27 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	31140	\N	\N	\N
41337	VICPDT	2024-02-28 00:00:00	\N	\N	\N	\N	\N	\N	33985	\N	\N	\N
41338	VICPDT	2024-02-28 00:00:00	\N	\N	\N	\N	\N	\N	33992	\N	\N	\N
41340	VICPDT	2024-02-28 00:00:00	\N	\N	\N	\N	\N	\N	34363	\N	\N	\N
41342	VICPDT	2024-02-28 00:00:00	\N	\N	\N	\N	\N	\N	34236	\N	\N	\N
41344	VICPDT	2024-02-28 00:00:00	\N	\N	\N	\N	\N	\N	34007	\N	\N	\N
41345	VICPDT	2024-02-28 00:00:00	\N	\N	\N	\N	\N	\N	34296	\N	\N	\N
41346	VICPDT	2024-02-28 00:00:00	\N	\N	\N	\N	\N	\N	34010	\N	\N	\N
41347	VICPDT	2024-02-28 00:00:00	\N	\N	\N	\N	\N	\N	34015	\N	\N	\N
41349	VICPDT	2024-02-28 00:00:00	\N	\N	\N	\N	\N	\N	34036	\N	\N	\N
41369	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34371	\N	\N	\N
41377	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34379	\N	\N	\N
41378	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34380	\N	\N	\N
41379	MEMBRE	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	34381	\N	\N	\N
41385	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34387	\N	\N	\N
41387	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34389	\N	\N	\N
41388	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34390	\N	\N	\N
41389	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34391	\N	\N	\N
41391	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34393	\N	\N	\N
41393	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34395	\N	\N	\N
41405	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34403	\N	\N	\N
41411	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34409	\N	\N	\N
41415	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34413	\N	\N	\N
41419	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34416	\N	\N	\N
41420	PDT	2024-02-14 00:00:00	\N	\N	\N	\N	\N	\N	34416	\N	\N	\N
41421	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34417	\N	\N	\N
41422	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34418	\N	\N	\N
41424	VICPDT	2024-02-14 00:00:00	\N	\N	\N	\N	\N	\N	34419	\N	\N	\N
41431	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34423	\N	\N	\N
31094	VICPDT	2018-03-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	26582	\N	\N	\N
31169	MEMBRE	2017-12-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26693	\N	\N	\N
31186	VICPDT	2018-03-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	26461	\N	\N	\N
31204	MEMBRE	2018-03-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26705	\N	2018-03-16 09:28:10	\N
31347	MEMBRE	2018-09-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	26809	\N	\N	\N
31593	MEMBRE	2019-09-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	27035	\N	\N	\N
31594	MEMBRE	2019-09-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	27036	\N	\N	\N
31606	MEMBRE	2019-10-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27041	\N	\N	\N
31616	MEMBRE	2019-11-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27051	\N	\N	\N
31617	MEMBRE	2019-11-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27052	\N	\N	\N
33703	MEMBRE	2020-11-19 00:00:00	2020-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	29018	\N	\N	\N
33704	MEMBRE	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29019	\N	\N	\N
33705	MEMBRE	2020-11-19 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	29020	\N	\N	\N
33706	MEMBRE	2020-11-19 00:00:00	2021-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	29021	\N	\N	\N
33902	MEMBRE	2020-12-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29152	\N	\N	\N
33903	MEMBRE	2020-11-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29153	\N	\N	\N
33904	MEMBRE	2020-11-23 00:00:00	2020-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	29154	\N	\N	\N
33905	PDTDEL	2020-12-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour le Libéria	\N	29154	\N	\N	\N
33906	MEMBRE	2020-12-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29155	\N	\N	\N
33908	MEMBRE	2020-12-01 00:00:00	2020-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	29157	\N	\N	\N
33916	MEMBRE	2020-12-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29164	\N	\N	\N
33953	MEMBRE	2020-12-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29173	\N	\N	\N
34354	VICPDT	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27732	\N	\N	\N
34355	VICPDT	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28316	\N	\N	\N
34356	VICPDT	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27408	\N	\N	\N
34357	VICPDT	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27371	\N	\N	\N
34358	VICPDT	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28401	\N	\N	\N
34359	SECRET	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27916	\N	\N	\N
34360	SECRET	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28688	\N	\N	\N
34361	SECRET	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27794	\N	\N	\N
34362	SECRET	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28387	\N	\N	\N
34363	SECRET	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28752	\N	\N	\N
34364	VICPDT	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29242	\N	\N	\N
34365	VICPDT	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29241	\N	\N	\N
34366	VICPDT	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29239	\N	\N	\N
34367	VICPDT	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29111	\N	\N	\N
34368	VICPDT	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27290	\N	\N	\N
34369	VICPDT	2020-12-17 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	27843	\N	\N	\N
34370	VICPDT	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27645	\N	\N	\N
34371	VICPDT	2020-12-17 00:00:00	2022-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	27630	\N	\N	\N
34372	VICPDT	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27497	\N	\N	\N
34373	SECRET	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29036	\N	\N	\N
34374	SECRET	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29245	\N	\N	\N
34375	SECRET	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28338	\N	\N	\N
34376	SECRET	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28507	\N	\N	\N
34377	SECRET	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27731	\N	\N	\N
34378	VICPDT	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27400	\N	\N	\N
34379	VICPDT	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28415	\N	\N	\N
34380	VICPDT	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27922	\N	\N	\N
34381	VICPDT	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27707	\N	\N	\N
34382	SECRET	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28846	\N	\N	\N
34383	SECRET	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28611	\N	\N	\N
34384	VICPDT	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27306	\N	\N	\N
34385	VICPDT	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28382	\N	\N	\N
34386	VICPDT	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27334	\N	\N	\N
34387	VICPDT	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27911	\N	\N	\N
34441	MEMBRE	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29313	\N	\N	\N
34442	MEMBRE	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29314	\N	\N	\N
34443	MEMBRE	2020-12-15 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	29315	\N	\N	\N
34444	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29316	\N	\N	\N
34493	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29357	\N	\N	\N
34494	MEMBRE	2020-12-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	29358	\N	\N	\N
34495	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29359	\N	\N	\N
34496	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29360	\N	\N	\N
34497	MEMBRE	2020-12-16 00:00:00	2021-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	29361	\N	\N	\N
34498	MEMBRE	2020-12-15 00:00:00	2021-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	29362	\N	\N	\N
34499	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29363	\N	\N	\N
34500	MEMBRE	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29364	\N	\N	\N
34530	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29394	\N	\N	\N
34556	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29420	\N	\N	\N
34559	MEMBRE	2020-12-16 00:00:00	2021-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	29423	\N	\N	\N
34725	MEMBRE	2020-12-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	29565	\N	\N	\N
34802	MEMBRE	2021-01-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	29591	\N	\N	\N
34807	MEMBRE	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29596	\N	\N	\N
34833	MEMBRE	2021-01-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	29616	\N	\N	\N
34834	MEMBRE	2021-01-07 00:00:00	2021-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	29617	\N	\N	\N
34836	MEMBRE	2021-01-07 00:00:00	2021-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	29619	\N	\N	\N
34946	MEMBRE	2021-01-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	29710	\N	\N	\N
34947	MEMBRE	2021-01-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	29711	\N	\N	\N
35114	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29838	\N	\N	\N
35248	MEMBRE	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29956	\N	\N	\N
35311	MEMBRE	2021-01-21 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	29981	\N	\N	\N
35324	MEMBRE	2021-01-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	29987	\N	\N	\N
35486	VICPDT	2021-01-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	29926	\N	\N	\N
35511	VICPDT	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29752	\N	\N	\N
35559	PDT	2021-01-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29286	\N	\N	\N
35560	MEMBRE	2021-01-29 00:00:00	2021-04-18 00:00:00	ANCIEN	\N	\N	\N	\N	27151	\N	\N	\N
35677	VICPDT	2021-02-04 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29809	\N	\N	\N
35682	MEMBRE	2021-02-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	30145	\N	\N	\N
35755	MEMBRE	2020-10-01 00:00:00	2021-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	30150	\N	\N	\N
35920	MEMBRE	2021-03-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30232	\N	\N	\N
36049	MEMBRE	2021-05-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30330	\N	\N	\N
36050	MEMBRE	2021-05-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30331	\N	\N	\N
36054	MEMBRE	2021-04-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30335	\N	\N	\N
36069	MEMBRE	2021-06-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	30350	\N	\N	\N
36149	MEMBRE	2021-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30411	\N	\N	\N
36150	MEMBRE	2021-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30412	\N	\N	\N
36151	MEMBRE	2021-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30413	\N	\N	\N
36152	MEMBRE	2021-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30414	\N	\N	\N
36153	MEMBRE	2021-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30415	\N	\N	\N
36154	MEMBRE	2021-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30416	\N	\N	\N
36155	MEMBRE	2021-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30417	\N	\N	\N
36156	MEMBRE	2021-10-10 00:00:00	2021-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	30418	\N	\N	\N
36157	MEMBRE	2021-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30419	\N	\N	\N
36207	MEMBRE	2021-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30453	\N	\N	\N
36208	MEMBRE	2021-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30454	\N	\N	\N
36209	MEMBRE	2021-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30455	\N	\N	\N
36210	MEMBRE	2021-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30456	\N	\N	\N
36236	MEMBRE	2021-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30481	\N	\N	\N
36295	MEMBRE	2022-02-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30529	\N	\N	\N
36296	MEMBRE	2022-03-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30530	\N	\N	\N
36425	MEMBRE	2022-06-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30642	\N	\N	\N
36426	MEMBRE	2022-06-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30643	\N	\N	\N
36440	MEMBRE	2022-08-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30657	\N	\N	\N
36441	MEMBRE	2022-08-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30658	\N	\N	\N
36558	MEMBRE	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30775	\N	\N	\N
36562	MEMBRE	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30779	\N	\N	\N
36608	MEMBRE	2023-02-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30807	\N	\N	\N
36661	MEMBRE	2023-07-31 00:00:00	2023-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	30854	\N	\N	\N
36662	MEMBRE	2023-07-31 00:00:00	2023-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	30855	\N	\N	\N
36663	MEMBRE	2023-07-31 00:00:00	2023-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	30856	\N	\N	\N
36664	MEMBRE	2023-07-31 00:00:00	2023-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	30857	\N	\N	\N
36665	MEMBRE	2023-07-31 00:00:00	2023-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	30858	\N	\N	\N
36734	MEMBRE	2023-10-08 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	30924	\N	\N	\N
38044	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32239	\N	\N	\N
38045	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32240	\N	\N	\N
38046	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32241	\N	\N	\N
38047	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32242	\N	\N	\N
38048	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32243	\N	\N	\N
38049	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32244	\N	\N	\N
38050	MEMBRE	2023-10-24 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	32245	\N	\N	\N
38051	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32246	\N	\N	\N
38052	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32247	\N	\N	\N
38053	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32248	\N	\N	\N
38054	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32249	\N	\N	\N
38150	MEMBRE	2023-10-25 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	32345	\N	\N	\N
38151	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32346	\N	\N	\N
30715	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26416	\N	\N	\N
31223	MEMBRE	2017-12-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26717	\N	\N	\N
31334	PDT	2018-09-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24214	\N	\N	\N
31377	MEMBRE	2018-10-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26839	\N	\N	\N
31462	MEMBRE	2018-11-27 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	26923	\N	\N	\N
31463	MEMBRE	2018-11-27 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	26924	\N	\N	\N
31464	MEMBRE	2018-11-27 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	26925	\N	\N	\N
31465	MEMBRE	2018-11-27 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	26926	\N	\N	\N
31466	MEMBRE	2018-11-27 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	26927	\N	\N	\N
31513	MEMBRE	2019-02-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	26965	\N	\N	\N
31624	MEMBRE	2019-11-29 00:00:00	2020-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	27057	\N	\N	\N
31818	MEMBRE	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27247	\N	\N	\N
31819	MEMBRE	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27248	\N	\N	\N
31820	MEMBRE	2020-10-08 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	27249	\N	\N	\N
31821	MEMBRE	2020-10-08 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	27250	\N	\N	\N
31822	MEMBRE	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27251	\N	\N	\N
31823	MEMBRE	2020-10-07 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	27252	\N	\N	\N
31824	MEMBRE	2020-10-07 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	27253	\N	\N	\N
31825	MEMBRE	2020-10-07 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	27254	\N	\N	\N
31826	MEMBRE	2020-10-07 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	27255	\N	\N	\N
31827	MEMBRE	2020-10-07 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	27256	\N	\N	\N
31828	MEMBRE	2020-10-07 00:00:00	2020-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	27257	\N	\N	\N
31829	MEMBRE	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27258	\N	\N	\N
31830	MEMBRE	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27259	\N	\N	\N
33125	MEMBRE	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28558	\N	\N	\N
33512	MEMBRE	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28934	\N	\N	\N
33513	MEMBRE	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28935	\N	\N	\N
33514	MEMBRE	2020-10-29 00:00:00	2021-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	28936	\N	\N	\N
33515	MEMBRE	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28937	\N	\N	\N
33516	MEMBRE	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28938	\N	\N	\N
33517	MEMBRE	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28939	\N	\N	\N
33518	MEMBRE	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28940	\N	\N	\N
33771	MEMBRE	2020-11-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29043	\N	\N	\N
33909	MEMBRE	2020-12-01 00:00:00	2021-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	29158	\N	\N	\N
33910	MEMBRE	2020-12-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29159	\N	\N	\N
34692	MEMBRE	2020-12-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	29532	\N	\N	\N
34693	MEMBRE	2020-12-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	29533	\N	\N	\N
34845	MEMBRE	2021-01-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29628	\N	\N	\N
34848	MEMBRE	2021-01-06 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	29631	\N	\N	\N
35052	MEMBRE	2020-10-01 00:00:00	2021-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	29776	\N	\N	\N
35147	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29871	\N	\N	\N
35288	VICPDT	2021-01-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29246	\N	\N	\N
35289	VICPDT	2021-01-19 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29465	\N	\N	\N
35306	MEMBRE	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29976	\N	\N	\N
35307	MEMBRE	2021-01-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29977	\N	\N	\N
35308	MEMBRE	2021-01-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	29978	\N	\N	\N
35477	PDT	2021-01-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29917	\N	\N	\N
35479	VICPDT	2021-01-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	29929	\N	\N	\N
35484	VICPDT	2021-01-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29912	\N	\N	\N
35622	MEMBRE	2021-02-03 00:00:00	2021-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	30107	\N	\N	\N
35827	SECRET	2021-02-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30095	\N	\N	\N
35848	VICPDT	2021-02-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	30150	\N	\N	\N
36071	MEMBRE	2021-06-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	30352	\N	\N	\N
36072	MEMBRE	2021-06-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	30353	\N	\N	\N
36101	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30374	\N	\N	\N
36224	MEMBRE	2021-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30469	\N	\N	\N
36249	MEMBRE	2021-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30493	\N	\N	\N
36250	MEMBRE	2021-12-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30494	\N	\N	\N
36251	MEMBRE	2021-12-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30495	\N	\N	\N
36475	MEMBRE	2021-03-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30692	\N	\N	\N
36532	MEMBRE	2023-01-01 00:00:00	2023-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	30749	\N	\N	\N
36533	MEMBRE	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30750	\N	\N	\N
36644	MEMBRE	2023-06-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30842	\N	\N	\N
37096	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31286	\N	\N	\N
37097	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31287	\N	\N	\N
37098	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31288	\N	\N	\N
37099	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31289	\N	\N	\N
37146	MEMBRE	2023-10-10 00:00:00	2024-02-07 00:00:00	ACTIF	\N	\N	\N	\N	31338	\N	\N	\N
37147	MEMBRE	2023-10-10 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	31339	\N	\N	\N
37148	MEMBRE	2023-10-10 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	31340	\N	\N	\N
37159	MEMBRE	2023-10-10 00:00:00	2024-01-25 00:00:00	ACTIF	\N	\N	\N	\N	31351	\N	\N	\N
37160	MEMBRE	2023-10-10 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	31352	\N	\N	\N
37161	MEMBRE	2023-10-10 00:00:00	2023-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	31353	\N	\N	\N
37178	MEMBRE	2023-10-10 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	31370	\N	\N	\N
37179	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31371	\N	\N	\N
37180	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31372	\N	\N	\N
37656	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31848	\N	\N	\N
37657	MEMBRE	2023-10-17 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	31849	\N	\N	\N
37658	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31850	\N	\N	\N
37659	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31851	\N	\N	\N
37660	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31852	\N	\N	\N
37661	MEMBRE	2023-10-17 00:00:00	2023-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	31853	\N	\N	\N
37662	MEMBRE	2023-10-17 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	31854	\N	\N	\N
37663	MEMBRE	2023-10-17 00:00:00	2024-02-04 00:00:00	ACTIF	\N	\N	\N	\N	31855	\N	\N	\N
37664	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31856	\N	\N	\N
38093	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32288	\N	\N	\N
38156	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32351	\N	\N	\N
38157	MEMBRE	2023-10-25 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	32352	\N	\N	\N
38158	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32353	\N	\N	\N
38159	MEMBRE	2023-10-25 00:00:00	2023-12-11 00:00:00	ANCIEN	\N	\N	\N	\N	32354	\N	\N	\N
38160	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32355	\N	\N	\N
38161	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32356	\N	\N	\N
38162	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32357	\N	\N	\N
38562	MEMBRE	2023-11-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32757	\N	\N	\N
38662	MEMBRE	2023-11-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32857	\N	\N	\N
38663	MEMBRE	2023-11-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32858	\N	\N	\N
38937	MEMBRE	2023-11-22 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33110	\N	\N	\N
39075	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour la Guinée équatoriale	\N	32349	\N	\N	\N
39076	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	Pour la Lettonie	\N	31402	\N	\N	\N
39077	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	Pour la Lituanie	\N	32665	\N	\N	\N
39078	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour la Macédoine du Nord	\N	31370	\N	\N	\N
39079	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	Pour le Malawi	\N	31131	\N	\N	\N
39080	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	Pour le Zimbabwe	\N	31158	\N	\N	\N
39081	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour le Burkina Faso	\N	31175	\N	\N	\N
39082	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour la Thaïlande	\N	31334	\N	\N	\N
39083	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour le Sénégal	\N	31801	\N	\N	\N
39084	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour l'Ouganda	\N	32155	\N	\N	\N
39085	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour le Qatar	\N	31867	\N	\N	\N
39086	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour Singapour	\N	30888	\N	\N	\N
39087	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour l'Uruguay	\N	31493	\N	\N	\N
39088	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour le Vanuatu	\N	32429	\N	\N	\N
39089	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour le Mexique	\N	30945	\N	\N	\N
39090	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour le Caucase	\N	31979	\N	\N	\N
39091	PDT	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32234	\N	\N	\N
39092	PDT	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32207	\N	\N	\N
39093	PDT	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32345	\N	\N	\N
39094	PDT	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32754	\N	\N	\N
39095	PDT	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31414	\N	\N	\N
39096	PDT	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31122	\N	\N	\N
39097	PDT	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32317	\N	\N	\N
39098	PDT	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32683	\N	\N	\N
39099	PDT	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32172	\N	\N	\N
39100	PDT	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31053	\N	\N	\N
39101	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour l'Amérique centrale	\N	33161	\N	\N	\N
39102	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour la Malaisie	\N	32352	\N	\N	\N
39103	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour les Philippines	\N	32391	\N	\N	\N
39104	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour le Bénin	\N	32101	\N	\N	\N
39105	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour le Togo	\N	31452	\N	\N	\N
39107	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour le Chili	\N	31425	\N	\N	\N
39108	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour l'Estonie	\N	31730	\N	\N	\N
39109	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour le Laos	\N	31808	\N	\N	\N
39110	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour le Monténégro	\N	33160	\N	\N	\N
39111	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour la Serbie	\N	31398	\N	\N	\N
39112	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour la Suède	\N	31857	\N	\N	\N
41440	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34430	\N	\N	\N
41441	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34431	\N	\N	\N
41442	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34432	\N	\N	\N
41449	VICPDT	2024-02-14 00:00:00	\N	\N	\N	\N	\N	\N	34437	\N	\N	\N
41450	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34438	\N	\N	\N
41451	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34439	\N	\N	\N
41461	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34449	\N	\N	\N
41462	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34450	\N	\N	\N
41463	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34451	\N	\N	\N
41464	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34452	\N	\N	\N
41465	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34453	\N	\N	\N
41466	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34454	\N	\N	\N
41467	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34455	\N	\N	\N
41468	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34456	\N	\N	\N
41469	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34457	\N	\N	\N
41470	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34458	\N	\N	\N
41471	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34459	\N	\N	\N
41472	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34460	\N	\N	\N
41473	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34461	\N	\N	\N
41474	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34462	\N	\N	\N
41475	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34463	\N	\N	\N
41481	MEMBRE	2023-12-14 00:00:00	\N	\N	\N	\N	\N	\N	34469	\N	\N	\N
41491	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34479	\N	\N	\N
41497	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34485	\N	\N	\N
41498	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34486	\N	\N	\N
41509	MEMBRE	2024-03-22 00:00:00	\N	\N	\N	\N	\N	\N	30172	\N	\N	\N
41522	MEMBRE	2023-10-01 00:00:00	\N	\N	\N	\N	\N	\N	34492	\N	\N	\N
41523	VICPDT	2024-03-25 00:00:00	\N	\N	\N	\N	\N	\N	34449	\N	\N	\N
41533	VICPDT	2024-03-19 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	34374	\N	\N	\N
41534	VICPDT	2024-03-19 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	34383	\N	\N	\N
41554	SECRET	2024-04-03 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32818	\N	\N	\N
41555	SECRET	2024-04-03 00:00:00	2026-10-01 00:00:00	\N	\N	\N	\N	\N	32999	\N	\N	\N
41561	VICPDT	2024-04-09 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	33421	\N	\N	\N
41562	VICPDT	2024-04-11 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	34265	\N	\N	\N
41563	VICPDT	2024-04-11 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	33680	\N	\N	\N
41564	VICPDT	2024-04-11 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	34500	\N	\N	\N
40104	MEMBRE	2023-10-01 00:00:00	2024-04-08 00:00:00	ACTIF	\N	\N	\N	\N	33679	\N	\N	\N
41565	VICPDT	2024-04-11 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	\N	33679	\N	\N	\N
30625	MEMBRE	2017-10-01 00:00:00	2018-05-07 00:00:00	ANCIEN	\N	\N	\N	\N	26339	\N	\N	\N
30659	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26360	\N	\N	\N
30661	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26362	\N	\N	\N
30675	MEMBRE	2018-02-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26376	\N	2018-02-09 09:45:51	\N
30676	MEMBRE	2018-02-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26377	\N	2018-02-09 09:45:51	\N
30807	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26478	\N	\N	\N
31168	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26692	\N	\N	\N
31232	MEMBRE	2017-12-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26726	\N	\N	\N
31286	VICPDT	2018-05-15 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26443	\N	\N	\N
31303	MEMBRE	2018-05-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26772	\N	2018-06-05 10:15:17	\N
31482	PDT	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26938	\N	\N	\N
31514	MEMBRE	2019-02-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26966	\N	\N	\N
31545	MEMBRE	2019-03-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26997	\N	\N	\N
31546	PDT	2019-03-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23933	\N	\N	\N
31547	MEMBRE	2019-03-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23932	\N	\N	\N
31548	PDTDEL	2019-03-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	Côte d'Ivoire	\N	24771	\N	\N	\N
31549	VICPDT	2019-03-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25999	\N	\N	\N
31550	PDTDEL	2019-03-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Monténégro	\N	26978	\N	\N	\N
31582	MEMBRE	2019-06-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27026	\N	\N	\N
31732	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27161	\N	\N	\N
31733	MEMBRE	2020-10-07 00:00:00	2020-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	27162	\N	\N	\N
31734	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27163	\N	\N	\N
31735	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27164	\N	\N	\N
31736	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27165	\N	\N	\N
31944	MEMBRE	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27373	\N	\N	\N
31945	MEMBRE	2020-10-09 00:00:00	2021-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	27374	\N	\N	\N
31946	MEMBRE	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27375	\N	\N	\N
31947	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27376	\N	\N	\N
31948	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27377	\N	\N	\N
31949	MEMBRE	2020-10-07 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	27378	\N	\N	\N
33790	MEMBRE	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29061	\N	\N	\N
33791	MEMBRE	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29062	\N	\N	\N
33792	MEMBRE	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29063	\N	\N	\N
33793	MEMBRE	2020-11-24 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	29064	\N	\N	\N
33794	PDTDEL	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour le Mali	\N	29065	\N	\N	\N
33795	PDTDEL	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour l'Arabie saoudite	\N	29066	\N	\N	\N
33796	MEMBRE	2020-11-24 00:00:00	2020-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	29067	\N	\N	\N
33797	MEMBRE	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29068	\N	\N	\N
33798	MEMBRE	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29069	\N	\N	\N
33799	MEMBRE	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29070	\N	\N	\N
33800	MEMBRE	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29071	\N	\N	\N
33801	MEMBRE	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29072	\N	\N	\N
33802	MEMBRE	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29073	\N	\N	\N
33803	MEMBRE	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29074	\N	\N	\N
33804	PDT	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29075	\N	\N	\N
33805	MEMBRE	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29076	\N	\N	\N
33806	MEMBRE	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29077	\N	\N	\N
33807	MEMBRE	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29078	\N	\N	\N
33808	MEMBRE	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29079	\N	\N	\N
33809	MEMBRE	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29080	\N	\N	\N
33810	PDTDEL	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour l'Ethiopie	\N	29081	\N	\N	\N
33811	MEMBRE	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29082	\N	\N	\N
34157	MEMBRE	2020-12-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29236	\N	\N	\N
34158	VICPDT	2020-12-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27192	\N	\N	\N
34159	VICPDT	2020-12-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27549	\N	\N	\N
34160	VICPDT	2020-12-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27280	\N	\N	\N
34161	SECRET	2020-12-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27476	\N	\N	\N
34162	SECRET	2020-12-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29038	\N	\N	\N
34163	SECRET	2020-12-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28263	\N	\N	\N
34543	MEMBRE	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29407	\N	\N	\N
34678	MEMBRE	2020-12-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	29518	\N	\N	\N
34801	MEMBRE	2021-01-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	29590	\N	\N	\N
34904	MEMBRE	2021-01-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	29669	\N	\N	\N
34919	MEMBRE	2021-01-12 00:00:00	2021-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	29684	\N	\N	\N
35176	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29900	\N	\N	\N
35177	MEMBRE	2020-10-01 00:00:00	2021-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	29901	\N	\N	\N
35178	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29902	\N	\N	\N
35179	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29903	\N	\N	\N
35403	MEMBRE	2021-01-26 00:00:00	2022-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	30037	\N	\N	\N
35413	MEMBRE	2021-01-26 00:00:00	2022-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	30040	\N	\N	\N
35605	VICPDT	2021-02-03 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29350	\N	\N	\N
35905	MEMBRE	2021-03-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	30220	\N	\N	\N
35907	SECRET	2021-03-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28884	\N	\N	\N
35908	SECRET	2021-03-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27936	\N	\N	\N
35909	SECRET	2021-03-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27796	\N	\N	\N
36200	VICPDT	2021-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30342	\N	\N	\N
36205	MEMBRE	2021-10-27 00:00:00	2021-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	30452	\N	\N	\N
36234	MEMBRE	2021-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30479	\N	\N	\N
36235	MEMBRE	2021-11-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30480	\N	\N	\N
36264	MEMBRE	2022-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30508	\N	\N	\N
36267	VICPDT	2021-12-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30107	\N	\N	\N
36271	MEMBRE	2022-01-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30510	\N	\N	\N
36290	MEMBRE	2022-02-21 00:00:00	2022-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	30524	\N	\N	\N
36324	MEMBRE	2022-03-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30551	\N	\N	\N
36390	MEMBRE	2022-04-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30609	\N	\N	\N
36572	MEMBRE	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30789	\N	\N	\N
36648	MEMBRE	2023-10-01 00:00:00	2026-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	30846	\N	\N	\N
36649	MEMBRE	2023-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30847	\N	\N	\N
36673	MEMBRE	2023-10-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30863	\N	\N	\N
37068	MEMBRE	2023-10-10 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	31258	\N	\N	\N
37069	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31259	\N	\N	\N
37070	MEMBRE	2023-10-10 00:00:00	2024-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	31260	\N	\N	\N
37071	MEMBRE	2023-10-10 00:00:00	2024-02-08 00:00:00	ACTIF	\N	\N	\N	\N	31261	\N	\N	\N
37072	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31262	\N	\N	\N
37073	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31263	\N	\N	\N
37074	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31264	\N	\N	\N
37075	MEMBRE	2023-10-10 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	31265	\N	\N	\N
37076	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31266	\N	\N	\N
37077	MEMBRE	2023-10-10 00:00:00	2024-02-04 00:00:00	ACTIF	\N	\N	\N	\N	31267	\N	\N	\N
37078	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31268	\N	\N	\N
37079	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31269	\N	\N	\N
37080	MEMBRE	2023-10-10 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	31270	\N	\N	\N
37081	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31271	\N	\N	\N
37082	MEMBRE	2023-10-10 00:00:00	2024-02-26 00:00:00	ACTIF	\N	\N	\N	\N	31272	\N	\N	\N
37083	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31273	\N	\N	\N
37084	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31274	\N	\N	\N
37085	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31275	\N	\N	\N
37086	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31276	\N	\N	\N
37087	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31277	\N	\N	\N
37088	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31278	\N	\N	\N
37117	MEMBRE	2023-10-10 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	31307	\N	\N	\N
37118	MEMBRE	2023-10-10 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	31308	\N	\N	\N
37119	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31309	\N	\N	\N
37166	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31358	\N	\N	\N
37167	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31359	\N	\N	\N
37168	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31360	\N	\N	\N
37169	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31361	\N	\N	\N
37170	MEMBRE	2023-10-10 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	31362	\N	\N	\N
37975	MEMBRE	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32170	\N	\N	\N
37976	MEMBRE	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32171	\N	\N	\N
37977	MEMBRE	2023-10-19 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	32172	\N	\N	\N
37978	MEMBRE	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32173	\N	\N	\N
37979	MEMBRE	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32174	\N	\N	\N
38155	MEMBRE	2023-10-25 00:00:00	2024-02-27 00:00:00	ACTIF	\N	\N	\N	\N	32350	\N	\N	\N
38227	MEMBRE	2023-10-26 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	32422	\N	\N	\N
38270	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32465	\N	\N	\N
38271	MEMBRE	2023-10-31 00:00:00	2024-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	32466	\N	\N	\N
38272	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32467	\N	\N	\N
38296	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32491	\N	\N	\N
38297	MEMBRE	2023-10-31 00:00:00	2024-01-30 00:00:00	ACTIF	\N	\N	\N	\N	32492	\N	\N	\N
38298	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32493	\N	\N	\N
38299	MEMBRE	2023-10-31 00:00:00	2023-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	32494	\N	\N	\N
38606	MEMBRE	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32801	\N	\N	\N
38609	MEMBRE	2023-11-08 00:00:00	2023-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	32804	\N	\N	\N
38624	MEMBRE	2023-11-08 00:00:00	2024-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	32819	\N	\N	\N
31008	MEMBRE	2018-02-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26595	\N	2018-02-22 10:20:51	\N
31256	MEMBRE	2018-04-06 00:00:00	2018-04-09 00:00:00	ANCIEN	\N	\N	\N	\N	26742	\N	2018-04-10 09:46:11	2018-04-10 09:47:07
31257	PDTDEL	2018-04-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Ghana	\N	26742	\N	2018-04-10 09:47:07	2018-04-10 09:48:25
31299	MEMBRE	2018-05-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26768	\N	2018-05-31 09:21:58	\N
31300	MEMBRE	2018-05-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26769	\N	2018-05-31 09:39:47	\N
31312	MEMBRE	2018-06-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26781	\N	2018-06-13 09:53:04	\N
31313	MEMBRE	2018-05-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26782	\N	2018-06-13 09:53:19	\N
31314	MEMBRE	2018-03-12 00:00:00	2018-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	26643	\N	2018-06-13 10:20:49	\N
31343	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26805	\N	\N	\N
31421	MEMBRE	2017-10-01 00:00:00	2020-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	26882	\N	\N	\N
31474	MEMBRE	2018-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26932	\N	\N	\N
31475	MEMBRE	2018-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26933	\N	\N	\N
31476	MEMBRE	2018-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26934	\N	\N	\N
31584	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	27028	\N	\N	\N
31635	MEMBRE	2020-01-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27067	\N	\N	\N
31950	MEMBRE	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27379	\N	\N	\N
31951	MEMBRE	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27380	\N	\N	\N
31952	MEMBRE	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27381	\N	\N	\N
31953	MEMBRE	2020-10-12 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	27382	\N	\N	\N
31954	MEMBRE	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27383	\N	\N	\N
31955	MEMBRE	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27384	\N	\N	\N
31956	MEMBRE	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27385	\N	\N	\N
31957	MEMBRE	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27386	\N	\N	\N
31958	MEMBRE	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27387	\N	\N	\N
31959	MEMBRE	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27388	\N	\N	\N
31960	MEMBRE	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27389	\N	\N	\N
31961	MEMBRE	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27390	\N	\N	\N
31962	MEMBRE	2020-10-12 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	27391	\N	\N	\N
31963	MEMBRE	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27392	\N	\N	\N
31964	MEMBRE	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27393	\N	\N	\N
31965	MEMBRE	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27394	\N	\N	\N
31966	MEMBRE	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27395	\N	\N	\N
31967	MEMBRE	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27396	\N	\N	\N
31968	MEMBRE	2020-10-12 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	27397	\N	\N	\N
31969	MEMBRE	2020-10-12 00:00:00	2021-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	27398	\N	\N	\N
31970	MEMBRE	2020-10-12 00:00:00	2020-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	27399	\N	\N	\N
31971	MEMBRE	2020-10-12 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	27400	\N	\N	\N
31972	MEMBRE	2020-10-12 00:00:00	2020-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	27401	\N	\N	\N
31973	MEMBRE	2020-10-12 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	27402	\N	\N	\N
31974	MEMBRE	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27403	\N	\N	\N
31975	MEMBRE	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27404	\N	\N	\N
31976	MEMBRE	2020-10-12 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	27405	\N	\N	\N
31977	MEMBRE	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27406	\N	\N	\N
31978	MEMBRE	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27407	\N	\N	\N
31979	MEMBRE	2020-10-12 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	27408	\N	\N	\N
31980	MEMBRE	2020-10-12 00:00:00	2021-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	27409	\N	\N	\N
31981	MEMBRE	2020-10-12 00:00:00	2021-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	27410	\N	\N	\N
31982	MEMBRE	2020-10-12 00:00:00	2021-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	27411	\N	\N	\N
31983	MEMBRE	2020-10-12 00:00:00	2020-12-23 00:00:00	ANCIEN	\N	\N	\N	\N	27412	\N	\N	\N
31984	MEMBRE	2020-10-12 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	27413	\N	\N	\N
31985	MEMBRE	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27414	\N	\N	\N
31986	MEMBRE	2020-10-09 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	27415	\N	\N	\N
31987	MEMBRE	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27416	\N	\N	\N
31988	MEMBRE	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27417	\N	\N	\N
31989	MEMBRE	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27418	\N	\N	\N
31990	MEMBRE	2020-10-09 00:00:00	2020-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	27419	\N	\N	\N
31991	MEMBRE	2020-10-09 00:00:00	2020-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	27420	\N	\N	\N
31992	MEMBRE	2020-10-09 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	27421	\N	\N	\N
31993	MEMBRE	2020-10-08 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	27422	\N	\N	\N
31994	MEMBRE	2020-10-08 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	27423	\N	\N	\N
31995	MEMBRE	2020-10-08 00:00:00	2021-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	27424	\N	\N	\N
31996	MEMBRE	2020-10-08 00:00:00	2020-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	27425	\N	\N	\N
31997	MEMBRE	2020-10-08 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	27426	\N	\N	\N
31998	MEMBRE	2020-10-08 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	27427	\N	\N	\N
31999	MEMBRE	2020-10-08 00:00:00	2021-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	27428	\N	\N	\N
32000	MEMBRE	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27429	\N	\N	\N
32001	MEMBRE	2020-10-08 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	27430	\N	\N	\N
32002	MEMBRE	2020-10-08 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	27431	\N	\N	\N
32003	MEMBRE	2020-10-08 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	27432	\N	\N	\N
32004	MEMBRE	2020-10-08 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	27433	\N	\N	\N
32005	MEMBRE	2020-10-08 00:00:00	2021-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	27434	\N	\N	\N
32006	MEMBRE	2020-10-08 00:00:00	2021-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	27435	\N	\N	\N
32007	MEMBRE	2020-10-08 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	27436	\N	\N	\N
32008	MEMBRE	2020-10-08 00:00:00	2020-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	27437	\N	\N	\N
32009	MEMBRE	2020-10-08 00:00:00	2021-01-14 00:00:00	ANCIEN	\N	\N	\N	\N	27438	\N	\N	\N
32010	MEMBRE	2020-10-08 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	27439	\N	\N	\N
32011	MEMBRE	2020-10-08 00:00:00	2021-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	27440	\N	\N	\N
32012	MEMBRE	2020-10-08 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	27441	\N	\N	\N
32013	MEMBRE	2020-10-08 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	27442	\N	\N	\N
32014	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27443	\N	\N	\N
32015	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27444	\N	\N	\N
32960	MEMBRE	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28393	\N	\N	\N
32961	MEMBRE	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28394	\N	\N	\N
32962	MEMBRE	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28395	\N	\N	\N
32963	MEMBRE	2020-10-26 00:00:00	2020-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	28396	\N	\N	\N
32964	MEMBRE	2020-10-26 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	28397	\N	\N	\N
32965	MEMBRE	2020-10-26 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	28398	\N	\N	\N
32966	MEMBRE	2020-10-26 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	28399	\N	\N	\N
33357	MEMBRE	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28790	\N	\N	\N
33358	MEMBRE	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28791	\N	\N	\N
33359	MEMBRE	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28792	\N	\N	\N
33360	MEMBRE	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28793	\N	\N	\N
33361	MEMBRE	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28794	\N	\N	\N
33362	MEMBRE	2020-11-04 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	28795	\N	\N	\N
33363	MEMBRE	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28796	\N	\N	\N
33364	MEMBRE	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28797	\N	\N	\N
33370	VICPDT	2020-11-04 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	26789	\N	\N	\N
33371	MEMBRE	2020-11-04 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	23518	\N	\N	\N
33372	SECRET	2020-11-04 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	25963	\N	\N	\N
33373	SECRET	2020-11-04 00:00:00	2021-10-13 00:00:00	ANCIEN	\N	\N	\N	\N	27887	\N	\N	\N
33374	VICPDT	2020-11-04 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23486	\N	\N	\N
33375	VICPDT	2020-11-04 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	24276	\N	\N	\N
33376	PDTDEL	2020-11-04 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	pour les Kurdes	\N	25066	\N	\N	\N
33377	SECRET	2020-11-04 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	23514	\N	\N	\N
33378	VICPDT	2020-11-04 00:00:00	2023-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	23534	\N	\N	\N
33379	VICPDT	2020-11-04 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	23539	\N	\N	\N
33380	SECRET	2020-11-04 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	23508	\N	\N	\N
33918	VICPDT	2020-12-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27336	\N	\N	\N
33919	VICPDT	2020-12-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28821	\N	\N	\N
33920	VICPDT	2020-12-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29067	\N	\N	\N
33921	VICPDT	2020-12-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27539	\N	\N	\N
33922	VICPDT	2020-12-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27419	\N	\N	\N
33923	SECRET	2020-12-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27149	\N	\N	\N
33924	SECRET	2020-12-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28198	\N	\N	\N
33925	SECRET	2020-12-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27112	\N	\N	\N
34038	MEMBRE	2020-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29196	\N	\N	\N
34167	MEMBRE	2020-12-11 00:00:00	2021-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	29240	\N	\N	\N
34168	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28044	\N	\N	\N
34169	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28997	\N	\N	\N
34170	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28691	\N	\N	\N
34171	VICPDT	2020-12-15 00:00:00	2023-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	27239	\N	\N	\N
34172	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27294	\N	\N	\N
34173	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27521	\N	\N	\N
34174	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29055	\N	\N	\N
34175	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29020	\N	\N	\N
34176	SECRET	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29141	\N	\N	\N
34177	SECRET	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29160	\N	\N	\N
34178	SECRET	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27935	\N	\N	\N
34179	SECRET	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28219	\N	\N	\N
34180	SECRET	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28700	\N	\N	\N
34181	SECRET	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27287	\N	\N	\N
34183	VICPDT	2020-12-15 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	29183	\N	\N	\N
34184	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27433	\N	\N	\N
34185	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28800	\N	\N	\N
30941	VICPDT	2018-02-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26256	\N	\N	\N
30942	VICPDT	2018-02-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	26280	\N	\N	\N
30943	VICPDT	2018-02-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26304	\N	\N	\N
30970	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26564	\N	\N	\N
30971	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26565	\N	\N	\N
31090	PDT	2018-03-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	26570	\N	\N	\N
31174	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26698	\N	\N	\N
31220	MEMBRE	2017-12-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26714	\N	\N	\N
31351	MEMBRE	2018-09-24 00:00:00	2023-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	26813	\N	\N	\N
31404	MEMBRE	2018-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26865	\N	\N	\N
32028	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27457	\N	\N	\N
32029	MEMBRE	2020-10-07 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	27458	\N	\N	\N
32030	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27459	\N	\N	\N
32510	MEMBRE	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27939	\N	\N	\N
32511	MEMBRE	2020-10-19 00:00:00	2023-09-28 00:00:00	ANCIEN	\N	\N	\N	\N	27940	\N	\N	\N
32512	MEMBRE	2020-10-19 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	27941	\N	\N	\N
32513	MEMBRE	2020-10-19 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	27942	\N	\N	\N
32514	MEMBRE	2020-10-19 00:00:00	2021-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	27943	\N	\N	\N
32515	MEMBRE	2020-10-19 00:00:00	2023-09-28 00:00:00	ANCIEN	\N	\N	\N	\N	27944	\N	\N	\N
32516	MEMBRE	2020-10-19 00:00:00	2023-09-28 00:00:00	ANCIEN	\N	\N	\N	\N	27945	\N	\N	\N
32517	MEMBRE	2020-10-19 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	27946	\N	\N	\N
32518	MEMBRE	2020-10-19 00:00:00	2021-01-03 00:00:00	ANCIEN	\N	\N	\N	\N	27947	\N	\N	\N
33459	MEMBRE	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28881	\N	\N	\N
33460	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28882	\N	\N	\N
33461	MEMBRE	2020-10-14 00:00:00	2020-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	28883	\N	\N	\N
33462	MEMBRE	2020-10-14 00:00:00	2021-03-04 00:00:00	ANCIEN	\N	\N	\N	\N	28884	\N	\N	\N
33463	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28885	\N	\N	\N
33533	MEMBRE	2020-11-16 00:00:00	2023-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	28950	\N	\N	\N
33534	MEMBRE	2020-11-13 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	28951	\N	\N	\N
33535	MEMBRE	2020-11-13 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	28952	\N	\N	\N
33536	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28953	\N	\N	\N
33537	MEMBRE	2020-10-27 00:00:00	2021-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	28954	\N	\N	\N
33538	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28955	\N	\N	\N
33539	MEMBRE	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28956	\N	\N	\N
33540	MEMBRE	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28957	\N	\N	\N
33720	MEMBRE	2020-11-16 00:00:00	2020-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	29032	\N	\N	\N
33721	MEMBRE	2020-11-20 00:00:00	2020-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	29033	\N	\N	\N
33722	MEMBRE	2020-11-18 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	29034	\N	\N	\N
33723	MEMBRE	2020-11-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29035	\N	\N	\N
33907	MEMBRE	2020-11-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29156	\N	\N	\N
33961	MEMBRE	2020-12-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29174	\N	\N	\N
34019	MEMBRE	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29188	\N	\N	\N
34020	MEMBRE	2020-12-07 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29189	\N	\N	\N
34021	MEMBRE	2020-11-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29190	\N	\N	\N
34182	MEMBRE	2020-12-15 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	29241	\N	\N	\N
34275	VICPDT	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27882	\N	\N	\N
34276	VICPDT	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27469	\N	\N	\N
34277	VICPDT	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27542	\N	\N	\N
34278	VICPDT	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28332	\N	\N	\N
34279	VICPDT	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28861	\N	\N	\N
34280	SECRET	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28242	\N	\N	\N
34281	SECRET	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29093	\N	\N	\N
34282	SECRET	2020-12-16 00:00:00	2023-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	27230	\N	\N	\N
34283	SECRET	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28373	\N	\N	\N
34284	SECRET	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29117	\N	\N	\N
34487	MEMBRE	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29351	\N	\N	\N
34593	VICPDT	2020-12-18 00:00:00	2020-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	29318	\N	\N	\N
34871	MEMBRE	2021-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29654	\N	\N	\N
34873	VICPDT	2021-01-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28209	\N	\N	\N
34874	VICPDT	2021-01-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27632	\N	\N	\N
34875	VICPDT	2021-01-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27970	\N	\N	\N
34876	VICPDT	2021-01-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28079	\N	\N	\N
34877	VICPDT	2021-01-12 00:00:00	2022-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	27628	\N	\N	\N
34878	VICPDT	2021-01-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28150	\N	\N	\N
34879	VICPDT	2021-01-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28471	\N	\N	\N
34880	VICPDT	2021-01-12 00:00:00	2021-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	28779	\N	\N	\N
34881	VICPDT	2021-01-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28374	\N	\N	\N
34882	VICPDT	2021-01-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28540	\N	\N	\N
34883	VICPDT	2021-01-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28480	\N	\N	\N
34884	VICPDT	2021-01-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27722	\N	\N	\N
34885	VICPDT	2021-01-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29568	\N	\N	\N
34886	SECRET	2021-01-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28735	\N	\N	\N
34887	SECRET	2021-01-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28461	\N	\N	\N
34888	SECRET	2021-01-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28348	\N	\N	\N
34889	SECRET	2021-01-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27771	\N	\N	\N
34890	SECRET	2021-01-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28487	\N	\N	\N
34975	MEMBRE	2021-01-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29731	\N	\N	\N
35295	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29965	\N	\N	\N
35296	MEMBRE	2020-10-01 00:00:00	2021-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	29966	\N	\N	\N
35333	MEMBRE	2021-01-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	29996	\N	\N	\N
35442	VICPDT	2021-01-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27351	\N	\N	\N
35443	VICPDT	2021-01-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28339	\N	\N	\N
35444	VICPDT	2021-01-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29285	\N	\N	\N
35445	VICPDT	2021-01-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28901	\N	\N	\N
35446	SECRET	2021-01-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27128	\N	\N	\N
35487	MEMBRE	2021-01-25 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	30065	\N	\N	\N
35518	VICPDT	2021-01-13 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29429	\N	\N	\N
35519	VICPDT	2021-01-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29593	\N	\N	\N
35524	VICPDT	2021-01-14 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29756	\N	\N	\N
35595	VICPDT	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29632	\N	\N	\N
35596	VICPDT	2021-02-03 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29671	\N	\N	\N
35788	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30182	\N	\N	\N
35790	MEMBRE	2020-10-01 00:00:00	2021-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	30184	\N	\N	\N
35791	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30185	\N	\N	\N
35873	MEMBRE	2021-02-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	30207	\N	\N	\N
36415	MEMBRE	2022-05-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30632	\N	\N	\N
36478	MEMBRE	2022-10-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	30695	\N	\N	\N
36978	MEMBRE	2023-10-10 00:00:00	2023-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	31168	\N	\N	\N
36979	MEMBRE	2023-10-10 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	31169	\N	\N	\N
36980	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31170	\N	\N	\N
36981	MEMBRE	2023-10-10 00:00:00	2024-02-19 00:00:00	ACTIF	\N	\N	\N	\N	31171	\N	\N	\N
36982	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31172	\N	\N	\N
36983	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31173	\N	\N	\N
36984	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31174	\N	\N	\N
36985	MEMBRE	2023-10-10 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	31175	\N	\N	\N
36986	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31176	\N	\N	\N
36987	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31177	\N	\N	\N
36988	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31178	\N	\N	\N
36989	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31179	\N	\N	\N
36990	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31180	\N	\N	\N
36991	MEMBRE	2023-10-10 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	31181	\N	\N	\N
36992	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31182	\N	\N	\N
36993	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31183	\N	\N	\N
37056	MEMBRE	2023-10-10 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	31246	\N	\N	\N
38163	MEMBRE	2023-10-25 00:00:00	2023-12-11 00:00:00	ANCIEN	\N	\N	\N	\N	32358	\N	\N	\N
38164	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32359	\N	\N	\N
38165	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32360	\N	\N	\N
38166	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32361	\N	\N	\N
38625	MEMBRE	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32820	\N	\N	\N
38626	MEMBRE	2023-11-08 00:00:00	2024-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	32821	\N	\N	\N
38627	MEMBRE	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32822	\N	\N	\N
38628	MEMBRE	2023-11-08 00:00:00	2024-02-27 00:00:00	ACTIF	\N	\N	\N	\N	32823	\N	\N	\N
38629	MEMBRE	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32824	\N	\N	\N
38630	MEMBRE	2023-11-08 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	32825	\N	\N	\N
38631	MEMBRE	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32826	\N	\N	\N
38633	MEMBRE	2023-11-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32828	\N	\N	\N
38637	MEMBRE	2023-11-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32832	\N	\N	\N
38638	MEMBRE	2023-11-09 00:00:00	2024-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	32833	\N	\N	\N
38639	MEMBRE	2023-11-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32834	\N	\N	\N
38658	MEMBRE	2023-11-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32853	\N	\N	\N
38751	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32946	\N	\N	\N
38753	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32948	\N	\N	\N
39162	MEMBRE	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33207	\N	\N	\N
39256	MEMBRE	2023-12-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33300	\N	\N	\N
39289	MEMBRE	2023-12-08 00:00:00	2024-02-05 00:00:00	ACTIF	\N	\N	\N	\N	33317	\N	\N	\N
39448	MEMBRE	2023-12-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33374	\N	\N	\N
39673	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33420	\N	\N	\N
30535	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26311	\N	\N	\N
30848	VICPDT	2018-02-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	26054	\N	\N	\N
30849	VICPDT	2018-02-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	26056	\N	\N	\N
30851	VICPDT	2018-02-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	26073	\N	\N	\N
31140	MEMBRE	2018-03-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26664	\N	\N	\N
31141	MEMBRE	2018-03-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26665	\N	\N	\N
31142	MEMBRE	2018-03-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26666	\N	\N	\N
31534	MEMBRE	2019-02-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	26986	\N	\N	\N
31535	MEMBRE	2019-02-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	26987	\N	\N	\N
31563	MEMBRE	2019-04-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27010	\N	\N	\N
31612	MEMBRE	2019-10-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	27047	\N	\N	\N
31728	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27157	\N	\N	\N
31729	MEMBRE	2020-10-07 00:00:00	2021-01-14 00:00:00	ANCIEN	\N	\N	\N	\N	27158	\N	\N	\N
32289	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27718	\N	\N	\N
32290	MEMBRE	2020-10-09 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	27719	\N	\N	\N
32291	MEMBRE	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27720	\N	\N	\N
32292	MEMBRE	2020-10-09 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	27721	\N	\N	\N
32293	MEMBRE	2020-10-09 00:00:00	2021-01-11 00:00:00	ANCIEN	\N	\N	\N	\N	27722	\N	\N	\N
32294	MEMBRE	2020-10-09 00:00:00	2020-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	27723	\N	\N	\N
32295	MEMBRE	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27724	\N	\N	\N
32296	MEMBRE	2020-10-14 00:00:00	2020-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	27725	\N	\N	\N
32297	MEMBRE	2020-10-14 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	27726	\N	\N	\N
32298	MEMBRE	2020-10-14 00:00:00	2020-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	27727	\N	\N	\N
32299	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27728	\N	\N	\N
32300	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27729	\N	\N	\N
32301	MEMBRE	2020-10-13 00:00:00	2020-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	27730	\N	\N	\N
32302	MEMBRE	2020-10-13 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	27731	\N	\N	\N
32303	MEMBRE	2020-10-13 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	27732	\N	\N	\N
32304	MEMBRE	2020-10-13 00:00:00	2020-12-23 00:00:00	ANCIEN	\N	\N	\N	\N	27733	\N	\N	\N
32305	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27734	\N	\N	\N
32306	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27735	\N	\N	\N
32307	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27736	\N	\N	\N
32308	MEMBRE	2020-10-13 00:00:00	2021-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	27737	\N	\N	\N
32309	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27738	\N	\N	\N
34039	MEMBRE	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29197	\N	\N	\N
34040	MEMBRE	2020-11-23 00:00:00	2021-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	29198	\N	\N	\N
34041	MEMBRE	2020-11-23 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	29199	\N	\N	\N
34042	MEMBRE	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29200	\N	\N	\N
34043	MEMBRE	2020-12-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29201	\N	\N	\N
34044	MEMBRE	2020-12-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29202	\N	\N	\N
34045	MEMBRE	2020-12-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29203	\N	\N	\N
34046	MEMBRE	2020-12-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29204	\N	\N	\N
34047	MEMBRE	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29205	\N	\N	\N
34048	MEMBRE	2020-12-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29206	\N	\N	\N
34186	VICPDT	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28051	\N	\N	\N
34187	SECRET	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28398	\N	\N	\N
34188	SECRET	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28274	\N	\N	\N
34189	SECRET	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29126	\N	\N	\N
34190	SECRET	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27487	\N	\N	\N
34191	SECRET	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29230	\N	\N	\N
34192	SECRET	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27891	\N	\N	\N
34231	MEMBRE	2020-12-15 00:00:00	2021-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	29246	\N	\N	\N
34232	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29247	\N	\N	\N
34424	MEMBRE	2020-12-16 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	29296	\N	\N	\N
34425	MEMBRE	2020-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29297	\N	\N	\N
34479	MEMBRE	2020-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29343	\N	\N	\N
34480	MEMBRE	2020-12-17 00:00:00	2021-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	29344	\N	\N	\N
34481	MEMBRE	2020-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29345	\N	\N	\N
34482	MEMBRE	2020-12-15 00:00:00	2021-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	29346	\N	\N	\N
34483	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29347	\N	\N	\N
34718	MEMBRE	2020-12-23 00:00:00	2021-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	29558	\N	\N	\N
34719	MEMBRE	2020-12-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	29559	\N	\N	\N
34720	MEMBRE	2020-12-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	29560	\N	\N	\N
34727	MEMBRE	2020-12-23 00:00:00	2021-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	29567	\N	\N	\N
34776	MEMBRE	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29583	\N	\N	\N
34780	MEMBRE	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29587	\N	\N	\N
34806	MEMBRE	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29595	\N	\N	\N
34838	MEMBRE	2021-01-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	29621	\N	\N	\N
34893	MEMBRE	2021-01-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29658	\N	\N	\N
35083	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29807	\N	\N	\N
35220	MEMBRE	2021-01-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	29944	\N	\N	\N
35223	VICPDT	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27961	\N	\N	\N
35224	VICPDT	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28271	\N	\N	\N
35225	VICPDT	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27361	\N	\N	\N
35226	VICPDT	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28683	\N	\N	\N
35227	VICPDT	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28542	\N	\N	\N
35228	VICPDT	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28848	\N	\N	\N
35229	VICPDT	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29021	\N	\N	\N
35230	SECRET	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28192	\N	\N	\N
35231	SECRET	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27943	\N	\N	\N
35234	VICPDT	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27788	\N	\N	\N
35235	VICPDT	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28512	\N	\N	\N
35236	VICPDT	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27106	\N	\N	\N
35237	VICPDT	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28896	\N	\N	\N
35238	SECRET	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28776	\N	\N	\N
35239	VICPDT	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27210	\N	\N	\N
35240	VICPDT	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27552	\N	\N	\N
35245	MEMBRE	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29953	\N	\N	\N
35249	MEMBRE	2021-01-20 00:00:00	2021-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	29090	\N	\N	\N
35250	MEMBRE	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29957	\N	\N	\N
35251	MEMBRE	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29958	\N	\N	\N
35282	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29963	\N	\N	\N
35283	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29964	\N	\N	\N
35382	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30019	\N	\N	\N
35483	VICPDT	2021-01-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29928	\N	\N	\N
35509	VICPDT	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29655	\N	\N	\N
35567	PDT	2021-01-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	29670	\N	\N	\N
35569	VICPDT	2021-01-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	29529	\N	\N	\N
35570	VICPDT	2021-01-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29652	\N	\N	\N
35571	VICPDT	2021-01-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	29715	\N	\N	\N
35572	SECRET	2021-01-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29631	\N	\N	\N
35573	SECRET	2021-01-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	29406	\N	\N	\N
35574	SECRET	2021-01-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	29573	\N	\N	\N
35636	MEMBRE	2021-02-03 00:00:00	2021-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	30121	\N	\N	\N
35637	MEMBRE	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30122	\N	\N	\N
35638	MEMBRE	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30123	\N	\N	\N
35641	MEMBRE	2021-02-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	30126	\N	\N	\N
35642	MEMBRE	2021-02-03 00:00:00	2021-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	30127	\N	\N	\N
35643	MEMBRE	2021-02-03 00:00:00	2021-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	30128	\N	\N	\N
35661	VICPDT	2021-02-03 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	30135	\N	\N	\N
35836	MEMBRE	2020-10-01 00:00:00	2021-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	30203	\N	\N	\N
35900	VICPDT	2021-03-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	29393	\N	\N	\N
35902	VICPDT	2021-03-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	29397	\N	\N	\N
35926	PDTDEL	2021-03-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour le Qatar	\N	29090	\N	\N	\N
36021	VICPDT	2021-03-30 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	30011	\N	\N	\N
36027	MEMBRE	2021-03-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30314	\N	\N	\N
36028	MEMBRE	2021-03-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30315	\N	\N	\N
36085	VICPDT	2021-06-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27890	\N	\N	\N
36086	VICPDT	2021-06-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28127	\N	\N	\N
36087	VICPDT	2021-06-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27205	\N	\N	\N
36088	VICPDT	2021-06-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28552	\N	\N	\N
36089	VICPDT	2021-06-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27218	\N	\N	\N
36090	SECRET	2021-06-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28258	\N	\N	\N
36091	SECRET	2021-06-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27640	\N	\N	\N
36124	PDT	2021-09-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27250	\N	\N	\N
36231	MEMBRE	2021-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30476	\N	\N	\N
36232	MEMBRE	2021-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30477	\N	\N	\N
36233	MEMBRE	2021-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30478	\N	\N	\N
36396	MEMBRE	2022-04-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30615	\N	\N	\N
36489	MEMBRE	2022-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30706	\N	\N	\N
36569	MEMBRE	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30786	\N	\N	\N
36576	VICPDT	2023-01-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30749	\N	\N	\N
36577	VICPDT	2023-01-25 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	30776	\N	\N	\N
36579	VICPDT	2023-01-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30734	\N	\N	\N
36598	MEMBRE	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30804	\N	\N	\N
36622	MEMBRE	2023-04-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30821	\N	\N	\N
36640	MEMBRE	2023-04-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30838	\N	\N	\N
36641	MEMBRE	2023-04-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30839	\N	\N	\N
36668	MEMBRE	2023-09-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30861	\N	\N	\N
36742	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30932	\N	\N	\N
30799	SECRET	2018-02-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26226	\N	2018-02-13 12:32:05	\N
30800	PDTDEL	2018-02-13 00:00:00	2018-07-15 00:00:00	ANCIEN	\N	\N	Zambie	\N	25515	\N	2018-02-13 12:33:09	2018-02-13 12:33:50
30841	MEMBRE	2017-10-01 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26512	\N	\N	\N
30897	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26533	\N	\N	\N
30916	PDT	2018-02-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	26526	\N	\N	\N
31125	MEMBRE	2018-03-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26649	\N	\N	\N
31127	MEMBRE	2018-03-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26651	\N	\N	\N
31130	MEMBRE	2018-03-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26654	\N	\N	\N
31133	MEMBRE	2018-03-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26657	\N	\N	\N
31134	MEMBRE	2018-03-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26658	\N	\N	\N
31138	MEMBRE	2018-03-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26662	\N	\N	\N
31273	VICPDT	2018-05-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26132	\N	\N	\N
31275	VICPDT	2018-05-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26134	\N	\N	\N
31276	VICPDT	2018-05-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26231	\N	\N	\N
31277	VICPDT	2018-05-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26138	\N	\N	\N
31280	VICPDT	2018-05-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26600	\N	\N	\N
31281	VICPDT	2018-05-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26144	\N	\N	\N
31282	SECRET	2018-05-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26339	\N	\N	\N
31283	SECRET	2018-05-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26140	\N	\N	\N
31284	VICPDT	2018-05-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26141	\N	\N	\N
31285	SECRET	2018-05-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26142	\N	\N	\N
31292	MEMBRE	2018-05-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26761	\N	2018-05-18 09:51:28	\N
31379	MEMBRE	2017-10-01 00:00:00	2018-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	26841	\N	\N	\N
31495	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26951	\N	\N	\N
31536	MEMBRE	2019-02-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26988	\N	\N	\N
31553	MEMBRE	2019-03-20 00:00:00	2020-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	27000	\N	\N	\N
31556	MEMBRE	2019-04-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27003	\N	\N	\N
31672	MEMBRE	2020-09-03 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27103	\N	\N	\N
32362	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27791	\N	\N	\N
32363	MEMBRE	2020-10-15 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	27792	\N	\N	\N
32364	MEMBRE	2020-10-15 00:00:00	2020-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	27793	\N	\N	\N
32365	MEMBRE	2020-10-07 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	27794	\N	\N	\N
32755	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28188	\N	\N	\N
32756	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28189	\N	\N	\N
32757	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28190	\N	\N	\N
32758	MEMBRE	2020-10-14 00:00:00	2020-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	28191	\N	\N	\N
32759	MEMBRE	2020-10-14 00:00:00	2021-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	28192	\N	\N	\N
32760	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28193	\N	\N	\N
33114	MEMBRE	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28547	\N	\N	\N
33115	MEMBRE	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28548	\N	\N	\N
33116	MEMBRE	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28549	\N	\N	\N
33117	MEMBRE	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28550	\N	\N	\N
33118	MEMBRE	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28551	\N	\N	\N
33119	MEMBRE	2020-10-28 00:00:00	2021-06-23 00:00:00	ANCIEN	\N	\N	\N	\N	28552	\N	\N	\N
33120	MEMBRE	2020-10-28 00:00:00	2020-12-23 00:00:00	ANCIEN	\N	\N	\N	\N	28553	\N	\N	\N
33121	MEMBRE	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28554	\N	\N	\N
33892	MEMBRE	2020-11-27 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	29141	\N	\N	\N
33893	MEMBRE	2020-11-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29142	\N	\N	\N
33894	MEMBRE	2020-12-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29143	\N	\N	\N
33895	MEMBRE	2020-12-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29144	\N	\N	\N
33896	MEMBRE	2020-12-01 00:00:00	2021-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	29145	\N	\N	\N
33897	MEMBRE	2020-12-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29146	\N	\N	\N
34066	MEMBRE	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29215	\N	\N	\N
33951	MEMBRE	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29171	\N	\N	\N
34065	MEMBRE	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29214	\N	\N	\N
34067	MEMBRE	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29216	\N	\N	\N
34127	VICPDT	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27591	\N	\N	\N
34128	VICPDT	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27442	\N	\N	\N
34129	VICPDT	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27751	\N	\N	\N
34130	SECRET	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27364	\N	\N	\N
34131	SECRET	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27827	\N	\N	\N
34132	SECRET	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28701	\N	\N	\N
34133	VICPDT	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27555	\N	\N	\N
34134	VICPDT	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27604	\N	\N	\N
34135	VICPDT	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28273	\N	\N	\N
34136	VICPDT	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27535	\N	\N	\N
34137	VICPDT	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28874	\N	\N	\N
34138	VICPDT	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29191	\N	\N	\N
34139	SECRET	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28047	\N	\N	\N
34150	SECRET	2020-12-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28035	\N	\N	\N
34151	SECRET	2020-12-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27534	\N	\N	\N
34152	MEMBRE	2020-11-23 00:00:00	2020-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	29232	\N	\N	\N
34153	PDTDEL	2020-12-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour la Zambie	\N	29232	\N	\N	\N
34945	MEMBRE	2021-01-13 00:00:00	2021-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	29709	\N	\N	\N
35012	MEMBRE	2021-01-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	29760	\N	\N	\N
35110	MEMBRE	2020-10-01 00:00:00	2021-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	29834	\N	\N	\N
35144	MEMBRE	2020-10-01 00:00:00	2021-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	29868	\N	\N	\N
35232	MEMBRE	2021-01-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	29947	\N	\N	\N
35310	MEMBRE	2021-01-20 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29980	\N	\N	\N
35349	MEMBRE	2020-10-01 00:00:00	2021-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	30012	\N	\N	\N
35354	PDT	2021-01-26 00:00:00	2021-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	30004	\N	\N	\N
35432	MEMBRE	2021-01-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	30049	\N	\N	\N
35805	MEMBRE	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	30191	\N	\N	\N
35806	MEMBRE	2020-10-01 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	30192	\N	\N	\N
35807	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30193	\N	\N	\N
35822	MEMBRE	2021-02-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	30199	\N	\N	\N
36084	MEMBRE	2021-06-21 00:00:00	2021-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	30365	\N	\N	\N
36108	MEMBRE	2021-07-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	30381	\N	\N	\N
36322	MEMBRE	2022-03-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30549	\N	\N	\N
36402	MEMBRE	2020-05-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	30620	\N	\N	\N
36595	MEMBRE	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30801	\N	\N	\N
36960	MEMBRE	2023-10-10 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	31150	\N	\N	\N
36961	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31151	\N	\N	\N
36962	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31152	\N	\N	\N
36963	MEMBRE	2023-10-10 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	31153	\N	\N	\N
36964	MEMBRE	2023-10-10 00:00:00	2024-01-30 00:00:00	ACTIF	\N	\N	\N	\N	31154	\N	\N	\N
36965	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31155	\N	\N	\N
36966	MEMBRE	2023-10-10 00:00:00	2024-02-26 00:00:00	ACTIF	\N	\N	\N	\N	31156	\N	\N	\N
36967	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31157	\N	\N	\N
36968	MEMBRE	2023-10-10 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	31158	\N	\N	\N
36969	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31159	\N	\N	\N
36970	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31160	\N	\N	\N
36971	MEMBRE	2023-10-10 00:00:00	2024-02-08 00:00:00	ACTIF	\N	\N	\N	\N	31161	\N	\N	\N
36972	MEMBRE	2023-10-10 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	31162	\N	\N	\N
36973	MEMBRE	2023-10-10 00:00:00	2024-02-08 00:00:00	ACTIF	\N	\N	\N	\N	31163	\N	\N	\N
36974	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31164	\N	\N	\N
36975	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31165	\N	\N	\N
37284	MEMBRE	2023-10-11 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	31476	\N	\N	\N
37285	MEMBRE	2023-10-11 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	31477	\N	\N	\N
37286	MEMBRE	2023-10-11 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	31478	\N	\N	\N
37287	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31479	\N	\N	\N
38728	MEMBRE	2023-11-15 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	32923	\N	\N	\N
39175	MEMBRE	2023-11-30 00:00:00	2023-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	33220	\N	\N	\N
39176	MEMBRE	2023-11-30 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33221	\N	\N	\N
39195	MEMBRE	2023-12-04 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33240	\N	\N	\N
39196	MEMBRE	2023-12-04 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33241	\N	\N	\N
39224	MEMBRE	2023-12-05 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	33268	\N	\N	\N
39225	MEMBRE	2023-12-05 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	33269	\N	\N	\N
39245	MEMBRE	2023-12-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33289	\N	\N	\N
39501	MEMBRE	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33395	\N	\N	\N
39630	MEMBRE	2023-12-20 00:00:00	2024-01-29 00:00:00	ACTIF	\N	\N	\N	\N	29789	\N	\N	\N
39675	MEMBRE	2023-12-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	29868	\N	\N	\N
39676	MEMBRE	2023-12-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	29869	\N	\N	\N
39679	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33423	\N	\N	\N
39682	MEMBRE	2023-12-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	29872	\N	\N	\N
39715	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33454	\N	\N	\N
39797	MEMBRE	2024-01-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33467	\N	\N	\N
39923	VICPDT	2024-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	33536	\N	\N	\N
39939	VICPDT	2024-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	33544	\N	\N	\N
39954	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33553	\N	\N	\N
39955	MEMBRE	2024-01-02 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	33554	\N	\N	\N
39956	MEMBRE	2024-01-02 00:00:00	2027-03-01 00:00:00	ANCIEN	\N	\N	\N	\N	33555	\N	\N	\N
39957	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33556	\N	\N	\N
39958	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33557	\N	\N	\N
39959	MEMBRE	2024-01-02 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	33558	\N	\N	\N
39978	MEMBRE	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33577	\N	\N	\N
39993	MEMBRE	2024-01-17 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	\N	29812	\N	\N	\N
39995	MEMBRE	2024-01-17 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	\N	30837	\N	\N	\N
39996	MEMBRE	2024-01-17 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	\N	30833	\N	\N	\N
39998	MEMBRE	2024-01-17 00:00:00	2024-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	29878	\N	\N	\N
40011	SECRET	2024-01-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32998	\N	\N	\N
30649	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26350	\N	\N	\N
30650	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26351	\N	\N	\N
30658	MEMBRE	2017-10-01 00:00:00	2018-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	26359	\N	\N	\N
30665	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26366	\N	\N	\N
30720	VICPDT	2018-02-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24038	\N	2018-02-12 09:30:12	\N
30721	VICPDT	2018-02-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23940	\N	2018-02-12 09:30:28	\N
30722	VICPDT	2018-02-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25574	\N	2018-02-12 09:30:35	\N
30723	VICPDT	2018-02-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24821	\N	2018-02-12 09:30:43	\N
30724	PDTHON	2018-02-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25662	\N	2018-02-12 09:31:03	\N
30725	SECRET	2018-02-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24873	\N	2018-02-12 09:31:17	\N
30726	SECRET	2018-02-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24181	\N	2018-02-12 09:31:29	\N
30727	SECRET	2018-02-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24921	\N	2018-02-12 09:31:39	\N
30728	VICPDT	2018-02-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23889	\N	2018-02-12 10:00:59	\N
30729	VICPDT	2018-02-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24791	\N	2018-02-12 10:01:09	\N
30730	VICPDT	2018-02-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24128	\N	2018-02-12 10:01:19	\N
30731	VICPDT	2018-02-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25657	\N	2018-02-12 10:01:37	\N
30732	VICPDT	2018-02-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24925	\N	2018-02-12 10:01:51	\N
30733	SECRET	2018-02-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23938	\N	2018-02-12 10:03:10	\N
30734	SECRET	2018-02-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24933	\N	2018-02-12 10:03:24	\N
30802	MEMBRE	2017-10-01 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	26473	\N	\N	\N
31030	MEMBRE	2018-02-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	26611	\N	\N	\N
31131	MEMBRE	2018-03-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26655	\N	\N	\N
31139	MEMBRE	2018-03-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26663	\N	\N	\N
31159	MEMBRE	2018-03-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26683	\N	\N	\N
31219	MEMBRE	2017-12-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26713	\N	\N	\N
31233	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26727	\N	\N	\N
31605	MEMBRE	2019-10-02 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27040	\N	\N	\N
31610	MEMBRE	2019-10-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	27045	\N	\N	\N
31652	MEMBRE	2020-01-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	27084	\N	\N	\N
31661	MEMBRE	2020-03-02 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27092	\N	\N	\N
31663	MEMBRE	2020-04-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	27094	\N	\N	\N
33857	MEMBRE	2020-11-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29109	\N	\N	\N
33858	MEMBRE	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29110	\N	\N	\N
33859	MEMBRE	2020-11-23 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	29111	\N	\N	\N
33860	PDTDEL	2020-11-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	pour le Mexique	\N	27479	\N	\N	\N
34681	MEMBRE	2020-12-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29521	\N	\N	\N
34715	MEMBRE	2020-12-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	29555	\N	\N	\N
34717	MEMBRE	2020-12-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	29557	\N	\N	\N
34750	MEMBRE	2020-12-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	29570	\N	\N	\N
34753	MEMBRE	2020-12-28 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	29573	\N	\N	\N
34754	MEMBRE	2020-12-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	29574	\N	\N	\N
34903	MEMBRE	2021-01-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	29668	\N	\N	\N
34928	MEMBRE	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29693	\N	\N	\N
34929	MEMBRE	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29694	\N	\N	\N
34960	MEMBRE	2021-01-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	29716	\N	\N	\N
34963	MEMBRE	2021-01-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	29719	\N	\N	\N
34971	MEMBRE	2021-01-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	29727	\N	\N	\N
35118	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29842	\N	\N	\N
35290	VICPDT	2021-01-19 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29466	\N	\N	\N
35291	VICPDT	2021-01-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29467	\N	\N	\N
35292	VICPDT	2021-01-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29250	\N	\N	\N
35293	VICPDT	2021-01-19 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29508	\N	\N	\N
35294	VICPDT	2021-01-19 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29464	\N	\N	\N
35430	MEMBRE	2021-01-26 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	30047	\N	\N	\N
35515	SECRET	2021-01-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29605	\N	\N	\N
35941	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30244	\N	\N	\N
36042	MEMBRE	2021-04-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30325	\N	\N	\N
36180	MEMBRE	2021-10-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	30432	\N	\N	\N
36184	MEMBRE	2021-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30436	\N	\N	\N
36196	VICPDT	2021-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	30348	\N	\N	\N
36238	MEMBRE	2021-12-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30483	\N	\N	\N
36286	MEMBRE	2022-02-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30521	\N	\N	\N
36305	MEMBRE	2022-03-07 00:00:00	2023-09-28 00:00:00	ANCIEN	\N	\N	\N	\N	30533	\N	\N	\N
36356	MEMBRE	2022-03-31 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30583	\N	\N	\N
36357	MEMBRE	2022-04-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30584	\N	\N	\N
36358	MEMBRE	2022-04-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30585	\N	\N	\N
36360	MEMBRE	2022-04-05 00:00:00	2022-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	30587	\N	\N	\N
36361	MEMBRE	2022-04-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30588	\N	\N	\N
36362	MEMBRE	2022-04-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30589	\N	\N	\N
36363	MEMBRE	2022-04-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30590	\N	\N	\N
36623	MEMBRE	2023-04-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30822	\N	\N	\N
36743	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30933	\N	\N	\N
36744	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30934	\N	\N	\N
36745	MEMBRE	2023-10-09 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	30935	\N	\N	\N
36746	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30936	\N	\N	\N
36747	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30937	\N	\N	\N
36748	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30938	\N	\N	\N
36749	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30939	\N	\N	\N
36750	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30940	\N	\N	\N
36751	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30941	\N	\N	\N
36752	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30942	\N	\N	\N
36770	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30960	\N	\N	\N
36771	MEMBRE	2023-10-09 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	30961	\N	\N	\N
36772	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30962	\N	\N	\N
36773	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30963	\N	\N	\N
37247	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31439	\N	\N	\N
37248	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31440	\N	\N	\N
37385	MEMBRE	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31577	\N	\N	\N
37386	MEMBRE	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31578	\N	\N	\N
37387	MEMBRE	2023-10-12 00:00:00	2023-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	31579	\N	\N	\N
37388	MEMBRE	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31580	\N	\N	\N
37389	MEMBRE	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31581	\N	\N	\N
37390	MEMBRE	2023-10-12 00:00:00	2024-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	31582	\N	\N	\N
37391	MEMBRE	2023-10-12 00:00:00	2024-01-04 00:00:00	ANCIEN	\N	\N	\N	\N	31583	\N	\N	\N
37392	MEMBRE	2023-10-12 00:00:00	2023-12-11 00:00:00	ANCIEN	\N	\N	\N	\N	31584	\N	\N	\N
37615	MEMBRE	2023-10-17 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	31807	\N	\N	\N
37622	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31814	\N	\N	\N
37623	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31815	\N	\N	\N
37624	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31816	\N	\N	\N
37631	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31823	\N	\N	\N
37632	MEMBRE	2023-10-17 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	31824	\N	\N	\N
37633	MEMBRE	2023-10-17 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	31825	\N	\N	\N
37845	MEMBRE	2023-10-18 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	32037	\N	\N	\N
37846	MEMBRE	2023-10-18 00:00:00	2023-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	32038	\N	\N	\N
37847	MEMBRE	2023-10-18 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	32039	\N	\N	\N
37848	MEMBRE	2023-10-18 00:00:00	2023-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	32040	\N	\N	\N
37849	MEMBRE	2023-10-18 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	32041	\N	\N	\N
37857	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32049	\N	\N	\N
37858	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32050	\N	\N	\N
37859	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32051	\N	\N	\N
37860	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32052	\N	\N	\N
37861	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32053	\N	\N	\N
37862	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32054	\N	\N	\N
37863	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32055	\N	\N	\N
38018	MEMBRE	2023-10-23 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	32213	\N	\N	\N
38141	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32336	\N	\N	\N
38262	MEMBRE	2023-10-30 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	32457	\N	\N	\N
38331	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32526	\N	\N	\N
38332	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32527	\N	\N	\N
38333	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32528	\N	\N	\N
38334	MEMBRE	2023-10-31 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	32529	\N	\N	\N
38335	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32530	\N	\N	\N
38336	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32531	\N	\N	\N
38337	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32532	\N	\N	\N
38338	MEMBRE	2023-10-31 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	32533	\N	\N	\N
38339	MEMBRE	2023-10-31 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	32534	\N	\N	\N
38340	MEMBRE	2023-10-31 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	32535	\N	\N	\N
38341	MEMBRE	2023-10-31 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	32536	\N	\N	\N
38342	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32537	\N	\N	\N
38343	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32538	\N	\N	\N
38344	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32539	\N	\N	\N
38392	MEMBRE	2023-11-01 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	32587	\N	\N	\N
38393	MEMBRE	2023-11-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32588	\N	\N	\N
38394	MEMBRE	2023-11-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32589	\N	\N	\N
30538	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26314	\N	\N	\N
30541	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26317	\N	\N	\N
30544	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26320	\N	\N	\N
30803	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26474	\N	\N	\N
30806	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26477	\N	\N	\N
30917	VICPDT	2018-02-15 00:00:00	2020-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	26528	\N	\N	\N
30920	VICPDT	2018-02-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	26523	\N	\N	\N
30921	VICPDT	2018-02-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	26522	\N	\N	\N
30923	SECRET	2018-02-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	26530	\N	\N	\N
30924	SECRET	2018-02-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	26518	\N	\N	\N
30960	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26554	\N	\N	\N
31084	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26622	\N	\N	\N
31188	PDT	2018-03-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	26656	\N	\N	\N
31190	VICPDT	2018-03-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	26685	\N	\N	\N
31191	VICPDT	2018-03-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	26668	\N	\N	\N
31192	VICPDT	2018-03-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	26648	\N	\N	\N
31193	VICPDT	2018-03-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	26684	\N	\N	\N
31540	MEMBRE	2017-12-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	26992	\N	\N	\N
31551	MEMBRE	2018-12-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26998	\N	\N	\N
31552	MEMBRE	2018-12-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26999	\N	\N	\N
31658	MEMBRE	2020-02-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27090	\N	\N	\N
31669	MEMBRE	2020-07-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27100	\N	\N	\N
33039	MEMBRE	2020-10-22 00:00:00	2020-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	28472	\N	\N	\N
33040	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28473	\N	\N	\N
33041	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28474	\N	\N	\N
33042	MEMBRE	2020-10-27 00:00:00	2020-12-23 00:00:00	ANCIEN	\N	\N	\N	\N	28475	\N	\N	\N
33043	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28476	\N	\N	\N
33044	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28477	\N	\N	\N
33045	MEMBRE	2020-10-27 00:00:00	2020-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	28478	\N	\N	\N
33046	MEMBRE	2020-10-27 00:00:00	2021-01-14 00:00:00	ANCIEN	\N	\N	\N	\N	28479	\N	\N	\N
33047	MEMBRE	2020-10-27 00:00:00	2021-01-11 00:00:00	ANCIEN	\N	\N	\N	\N	28480	\N	\N	\N
34058	MEMBRE	2020-12-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29207	\N	\N	\N
34059	MEMBRE	2020-12-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29208	\N	\N	\N
34060	MEMBRE	2020-12-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29209	\N	\N	\N
34622	MEMBRE	2020-12-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29481	\N	\N	\N
34808	MEMBRE	2020-12-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29597	\N	\N	\N
35040	MEMBRE	2021-01-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	29769	\N	\N	\N
35241	MEMBRE	2020-10-01 00:00:00	2024-01-29 00:00:00	ACTIF	\N	\N	\N	\N	29949	\N	\N	\N
35303	MEMBRE	2021-01-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29973	\N	\N	\N
35329	MEMBRE	2021-01-21 00:00:00	2021-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	29992	\N	\N	\N
35330	MEMBRE	2021-01-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29993	\N	\N	\N
35409	MEMBRE	2021-01-26 00:00:00	2022-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	30039	\N	\N	\N
35420	MEMBRE	2021-01-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	30044	\N	\N	\N
35517	PDT	2021-01-13 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29446	\N	\N	\N
35568	VICPDT	2021-01-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	29561	\N	\N	\N
35588	MEMBRE	2021-02-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30089	\N	\N	\N
35683	MEMBRE	2021-02-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30146	\N	\N	\N
35718	VICPDT	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28817	\N	\N	\N
35719	VICPDT	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29771	\N	\N	\N
35720	VICPDT	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28334	\N	\N	\N
35721	VICPDT	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27675	\N	\N	\N
35722	VICPDT	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28656	\N	\N	\N
35723	VICPDT	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27913	\N	\N	\N
35724	VICPDT	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27712	\N	\N	\N
35725	SECRET	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27971	\N	\N	\N
35726	SECRET	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28856	\N	\N	\N
35727	SECRET	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27792	\N	\N	\N
35728	SECRET	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28709	\N	\N	\N
35729	SECRET	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27650	\N	\N	\N
35730	SECRET	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28257	\N	\N	\N
35731	VICPDT	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27571	\N	\N	\N
35732	VICPDT	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30017	\N	\N	\N
35733	VICPDT	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27206	\N	\N	\N
35734	VICPDT	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29933	\N	\N	\N
35735	SECRET	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27711	\N	\N	\N
35736	VICPDT	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29047	\N	\N	\N
35737	VICPDT	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28113	\N	\N	\N
35738	VICPDT	2021-02-05 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	27253	\N	\N	\N
35739	VICPDT	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28413	\N	\N	\N
35740	VICPDT	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28962	\N	\N	\N
35741	VICPDT	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28214	\N	\N	\N
35742	VICPDT	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29994	\N	\N	\N
35743	SECRET	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28019	\N	\N	\N
35744	SECRET	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28090	\N	\N	\N
35745	SECRET	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28358	\N	\N	\N
35746	SECRET	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27177	\N	\N	\N
35747	SECRET	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28294	\N	\N	\N
35748	SECRET	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28436	\N	\N	\N
35823	VICPDTDEL	2021-02-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	aux relations de voisinage avec les collectivités d'outre-mer	\N	28903	\N	\N	\N
36192	MEMBRE	2021-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30444	\N	\N	\N
36193	MEMBRE	2021-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30445	\N	\N	\N
36281	MEMBRE	2022-01-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30516	\N	\N	\N
36332	MEMBRE	2022-03-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30559	\N	\N	\N
36333	MEMBRE	2022-03-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30560	\N	\N	\N
36347	MEMBRE	2022-04-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30574	\N	\N	\N
36929	MEMBRE	2023-10-09 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	31119	\N	\N	\N
36660	MEMBRE	2023-07-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29554	\N	\N	\N
36930	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31120	\N	\N	\N
36931	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31121	\N	\N	\N
36932	MEMBRE	2023-10-09 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	31122	\N	\N	\N
36933	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31123	\N	\N	\N
37101	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31291	\N	\N	\N
37102	MEMBRE	2023-10-10 00:00:00	2024-03-05 00:00:00	ACTIF	\N	\N	\N	\N	31292	\N	\N	\N
37103	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31293	\N	\N	\N
37104	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31294	\N	\N	\N
37105	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31295	\N	\N	\N
37106	MEMBRE	2023-10-10 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	31296	\N	\N	\N
37107	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31297	\N	\N	\N
37108	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31298	\N	\N	\N
37109	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31299	\N	\N	\N
37110	MEMBRE	2023-10-10 00:00:00	2024-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	31300	\N	\N	\N
37111	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31301	\N	\N	\N
37112	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31302	\N	\N	\N
37113	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31303	\N	\N	\N
37114	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31304	\N	\N	\N
37115	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31305	\N	\N	\N
37968	MEMBRE	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32163	\N	\N	\N
37969	MEMBRE	2023-10-19 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	32164	\N	\N	\N
37970	MEMBRE	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32165	\N	\N	\N
37971	MEMBRE	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32166	\N	\N	\N
38729	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32924	\N	\N	\N
38730	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32925	\N	\N	\N
38731	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32926	\N	\N	\N
38732	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32927	\N	\N	\N
38733	MEMBRE	2023-11-15 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	32928	\N	\N	\N
38734	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32929	\N	\N	\N
38735	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32930	\N	\N	\N
38736	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32931	\N	\N	\N
38737	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32932	\N	\N	\N
38738	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32933	\N	\N	\N
38739	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32934	\N	\N	\N
38740	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32935	\N	\N	\N
38741	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32936	\N	\N	\N
38742	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32937	\N	\N	\N
38743	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32938	\N	\N	\N
38752	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32947	\N	\N	\N
38910	MEMBRE	2023-11-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33097	\N	\N	\N
38911	MEMBRE	2023-11-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33098	\N	\N	\N
38996	MEMBRE	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33162	\N	\N	\N
40012	VICPDT	2024-01-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31300	\N	\N	\N
40019	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33596	\N	\N	\N
40030	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33607	\N	\N	\N
40031	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33608	\N	\N	\N
40070	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33647	\N	\N	\N
40071	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33648	\N	\N	\N
40072	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33649	\N	\N	\N
40074	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33651	\N	\N	\N
40075	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33652	\N	\N	\N
40076	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33653	\N	\N	\N
30540	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26316	\N	\N	\N
30652	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26353	\N	\N	\N
30938	VICPDT	2018-02-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	26319	\N	\N	\N
30939	VICPDT	2018-02-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	26301	\N	\N	\N
30994	MEMBRE	2018-02-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26588	\N	2018-02-20 17:00:06	\N
31092	SECRET	2018-03-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	26575	\N	\N	\N
31093	SECRET	2018-03-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	26558	\N	\N	\N
31189	VICPDT	2018-03-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	26682	\N	\N	\N
31231	MEMBRE	2018-03-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26725	\N	2018-03-22 16:49:00	\N
31265	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26750	\N	\N	\N
31316	MEMBRE	2018-06-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26784	\N	\N	\N
31317	MEMBRE	2018-06-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26785	\N	\N	\N
31318	MEMBRE	2018-06-19 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26786	\N	\N	\N
31346	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26808	\N	\N	\N
31420	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26881	\N	\N	\N
31518	MEMBRE	2019-02-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	26970	\N	\N	\N
31521	MEMBRE	2019-02-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	26973	\N	\N	\N
32366	MEMBRE	2020-10-14 00:00:00	2021-01-14 00:00:00	ANCIEN	\N	\N	\N	\N	27795	\N	\N	\N
32367	MEMBRE	2020-10-14 00:00:00	2021-03-04 00:00:00	ANCIEN	\N	\N	\N	\N	27796	\N	\N	\N
32368	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27797	\N	\N	\N
33273	MEMBRE	2020-11-02 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	28706	\N	\N	\N
33274	MEMBRE	2020-11-02 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	28707	\N	\N	\N
33275	MEMBRE	2020-11-02 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	28708	\N	\N	\N
33276	MEMBRE	2020-11-02 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	28709	\N	\N	\N
33277	MEMBRE	2020-11-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28710	\N	\N	\N
33278	MEMBRE	2020-11-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28711	\N	\N	\N
33487	MEMBRE	2020-11-12 00:00:00	2020-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	28909	\N	\N	\N
33488	MEMBRE	2020-11-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28910	\N	\N	\N
33489	MEMBRE	2020-11-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28911	\N	\N	\N
33490	MEMBRE	2020-11-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28912	\N	\N	\N
33491	MEMBRE	2020-11-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28913	\N	\N	\N
33492	MEMBRE	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28914	\N	\N	\N
33493	MEMBRE	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28915	\N	\N	\N
33494	MEMBRE	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28916	\N	\N	\N
33495	MEMBRE	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28917	\N	\N	\N
33496	MEMBRE	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28918	\N	\N	\N
33497	MEMBRE	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28919	\N	\N	\N
33498	MEMBRE	2020-11-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28920	\N	\N	\N
33564	MEMBRE	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28981	\N	\N	\N
33565	MEMBRE	2020-11-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28982	\N	\N	\N
33873	MEMBRE	2020-11-23 00:00:00	2020-11-25 00:00:00	ANCIEN	\N	\N	\N	\N	29124	\N	\N	\N
33874	MEMBRE	2020-11-25 00:00:00	2023-09-12 00:00:00	ANCIEN	\N	\N	\N	\N	29125	\N	\N	\N
33875	MEMBRE	2020-11-25 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	29126	\N	\N	\N
33876	MEMBRE	2020-11-24 00:00:00	2020-11-25 00:00:00	ANCIEN	\N	\N	\N	\N	29127	\N	\N	\N
33877	MEMBRE	2020-11-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29128	\N	\N	\N
34140	MEMBRE	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29222	\N	\N	\N
34141	MEMBRE	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29223	\N	\N	\N
34142	MEMBRE	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29224	\N	\N	\N
34143	MEMBRE	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29225	\N	\N	\N
34144	MEMBRE	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29226	\N	\N	\N
34145	MEMBRE	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29227	\N	\N	\N
34146	MEMBRE	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29228	\N	\N	\N
34147	MEMBRE	2020-12-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29229	\N	\N	\N
34149	MEMBRE	2020-12-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29231	\N	\N	\N
34246	MEMBRE	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29261	\N	\N	\N
34434	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29306	\N	\N	\N
34437	MEMBRE	2020-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29309	\N	\N	\N
34485	MEMBRE	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29349	\N	\N	\N
34488	MEMBRE	2020-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29352	\N	\N	\N
34489	MEMBRE	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29353	\N	\N	\N
34572	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29436	\N	\N	\N
34574	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29438	\N	\N	\N
34632	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29491	\N	\N	\N
34858	MEMBRE	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29641	\N	\N	\N
34862	MEMBRE	2021-01-04 00:00:00	2021-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	29645	\N	\N	\N
34863	MEMBRE	2021-01-04 00:00:00	2021-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	29646	\N	\N	\N
34922	MEMBRE	2021-01-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	29687	\N	\N	\N
35504	VICPDT	2021-01-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29706	\N	\N	\N
35528	SECRET	2021-01-13 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29563	\N	\N	\N
35529	SECRET	2021-01-13 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29445	\N	\N	\N
35658	VICPDT	2021-02-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	30098	\N	\N	\N
36030	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30317	\N	\N	\N
36078	MEMBRE	2021-06-22 00:00:00	2021-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	30359	\N	\N	\N
36132	MEMBRE	2021-09-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	30394	\N	\N	\N
36252	MEMBRE	2022-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30496	\N	\N	\N
36433	MEMBRE	2022-07-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30650	\N	\N	\N
37292	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31484	\N	\N	\N
37293	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31485	\N	\N	\N
37294	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31486	\N	\N	\N
37295	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31487	\N	\N	\N
37328	MEMBRE	2023-10-11 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	31520	\N	\N	\N
37329	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31521	\N	\N	\N
37330	MEMBRE	2023-10-11 00:00:00	2024-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	31522	\N	\N	\N
37331	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31523	\N	\N	\N
37332	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31524	\N	\N	\N
38228	MEMBRE	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32423	\N	\N	\N
38395	MEMBRE	2023-11-01 00:00:00	2024-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	32590	\N	\N	\N
38396	MEMBRE	2023-11-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32591	\N	\N	\N
38397	MEMBRE	2023-11-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32592	\N	\N	\N
38398	MEMBRE	2023-11-01 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	32593	\N	\N	\N
38399	MEMBRE	2023-11-01 00:00:00	2024-03-24 00:00:00	ACTIF	\N	\N	\N	\N	32594	\N	\N	\N
38400	MEMBRE	2023-11-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32595	\N	\N	\N
38401	MEMBRE	2023-11-01 00:00:00	2024-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	32596	\N	\N	\N
38402	MEMBRE	2023-11-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32597	\N	\N	\N
38403	MEMBRE	2023-11-01 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	32598	\N	\N	\N
38404	MEMBRE	2023-11-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32599	\N	\N	\N
38405	MEMBRE	2023-11-01 00:00:00	2024-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	32600	\N	\N	\N
38406	MEMBRE	2023-11-01 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	32601	\N	\N	\N
38407	MEMBRE	2023-11-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32602	\N	\N	\N
38408	MEMBRE	2023-11-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32603	\N	\N	\N
38409	MEMBRE	2023-11-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32604	\N	\N	\N
38566	MEMBRE	2023-11-07 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	32761	\N	\N	\N
38567	MEMBRE	2023-11-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32762	\N	\N	\N
38607	MEMBRE	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32802	\N	\N	\N
38661	MEMBRE	2023-11-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32856	\N	\N	\N
38678	MEMBRE	2023-11-13 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	32873	\N	\N	\N
38704	MEMBRE	2023-11-14 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	32899	\N	\N	\N
38705	MEMBRE	2023-11-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32900	\N	\N	\N
38706	MEMBRE	2023-11-14 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	32901	\N	\N	\N
38707	MEMBRE	2023-11-14 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	32902	\N	\N	\N
38720	MEMBRE	2023-11-15 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	32915	\N	\N	\N
38888	MEMBRE	2023-11-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33083	\N	\N	\N
38922	PDT	2023-11-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32950	\N	\N	\N
39125	MEMBRE	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33171	\N	\N	\N
39130	PDTDEL	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour le Nigéria	\N	30957	\N	\N	\N
39133	MEMBRE	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33178	\N	\N	\N
39134	MEMBRE	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33179	\N	\N	\N
39135	MEMBRE	2023-11-29 00:00:00	2024-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	33180	\N	\N	\N
39136	MEMBRE	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33181	\N	\N	\N
39137	MEMBRE	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33182	\N	\N	\N
39138	MEMBRE	2023-11-29 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	33183	\N	\N	\N
39139	MEMBRE	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33184	\N	\N	\N
39140	MEMBRE	2023-11-29 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	33185	\N	\N	\N
39141	MEMBRE	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33186	\N	\N	\N
39142	MEMBRE	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33187	\N	\N	\N
39143	MEMBRE	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33188	\N	\N	\N
39144	PDT	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33189	\N	\N	\N
39145	MEMBRE	2023-11-29 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	33190	\N	\N	\N
39146	MEMBRE	2023-11-29 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	33191	\N	\N	\N
39147	MEMBRE	2023-11-29 00:00:00	2023-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	33192	\N	\N	\N
39148	MEMBRE	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33193	\N	\N	\N
39149	MEMBRE	2023-11-29 00:00:00	2024-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	33194	\N	\N	\N
39150	MEMBRE	2023-11-29 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	33195	\N	\N	\N
39163	MEMBRE	2023-11-29 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	33208	\N	\N	\N
39165	MEMBRE	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33210	\N	\N	\N
39166	MEMBRE	2023-11-29 00:00:00	2024-02-26 00:00:00	ACTIF	\N	\N	\N	\N	33211	\N	\N	\N
39177	MEMBRE	2023-12-01 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	33222	\N	\N	\N
39178	MEMBRE	2023-12-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33223	\N	\N	\N
30545	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26321	\N	\N	\N
31195	SECRET	2018-03-15 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26674	\N	\N	\N
31227	MEMBRE	2017-12-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26721	\N	\N	\N
31229	MEMBRE	2017-12-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26723	\N	\N	\N
31380	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26842	\N	\N	\N
31664	MEMBRE	2020-04-02 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27095	\N	\N	\N
34064	MEMBRE	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29213	\N	\N	\N
34061	MEMBRE	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29210	\N	\N	\N
34062	MEMBRE	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29211	\N	\N	\N
34063	MEMBRE	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29212	\N	\N	\N
34108	VICPDT	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27581	\N	\N	\N
34109	VICPDT	2020-12-10 00:00:00	2021-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	27319	\N	\N	\N
34110	SECRET	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28818	\N	\N	\N
34111	SECRET	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28104	\N	\N	\N
34122	VICPDT	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27928	\N	\N	\N
34123	VICPDT	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29136	\N	\N	\N
34124	VICPDT	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28993	\N	\N	\N
34125	SECRET	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27422	\N	\N	\N
34126	SECRET	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28770	\N	\N	\N
34436	MEMBRE	2020-12-15 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	29308	\N	\N	\N
34445	MEMBRE	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29317	\N	\N	\N
34463	MEMBRE	2020-12-15 00:00:00	2021-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	29327	\N	\N	\N
34464	MEMBRE	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29328	\N	\N	\N
34465	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29329	\N	\N	\N
34466	MEMBRE	2020-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29330	\N	\N	\N
34467	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29331	\N	\N	\N
34468	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29332	\N	\N	\N
34469	MEMBRE	2020-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29333	\N	\N	\N
34470	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29334	\N	\N	\N
34471	MEMBRE	2020-10-01 00:00:00	2021-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	29335	\N	\N	\N
34472	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29336	\N	\N	\N
34473	MEMBRE	2020-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29337	\N	\N	\N
34486	MEMBRE	2020-12-16 00:00:00	2021-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	29350	\N	\N	\N
34490	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29354	\N	\N	\N
34491	MEMBRE	2020-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29355	\N	\N	\N
34507	MEMBRE	2020-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29371	\N	\N	\N
34832	MEMBRE	2021-01-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	29615	\N	\N	\N
34864	MEMBRE	2021-01-05 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	29647	\N	\N	\N
34894	MEMBRE	2021-01-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	29659	\N	\N	\N
35033	MEMBRE	2020-12-18 00:00:00	2021-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	29765	\N	\N	\N
35174	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29898	\N	\N	\N
35506	VICPDT	2021-01-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29720	\N	\N	\N
35510	VICPDT	2021-01-13 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29709	\N	\N	\N
35757	MEMBRE	2021-02-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30152	\N	\N	\N
35949	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30251	\N	\N	\N
36138	MEMBRE	2021-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30400	\N	\N	\N
36140	MEMBRE	2021-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30402	\N	\N	\N
36189	MEMBRE	2021-10-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	30441	\N	\N	\N
36201	MEMBRE	2021-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30448	\N	\N	\N
36202	MEMBRE	2021-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30449	\N	\N	\N
36203	MEMBRE	2021-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30450	\N	\N	\N
36204	MEMBRE	2021-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30451	\N	\N	\N
36228	MEMBRE	2021-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30473	\N	\N	\N
36229	MEMBRE	2021-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30474	\N	\N	\N
36230	MEMBRE	2021-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30475	\N	\N	\N
36387	MEMBRE	2022-04-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30606	\N	\N	\N
36435	MEMBRE	2022-07-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	30652	\N	\N	\N
36502	MEMBRE	2022-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30719	\N	\N	\N
36571	MEMBRE	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30788	\N	\N	\N
36585	PDT	2023-01-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30733	\N	\N	\N
37255	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31447	\N	\N	\N
37256	MEMBRE	2023-10-11 00:00:00	2024-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	31448	\N	\N	\N
37257	MEMBRE	2023-10-11 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	31449	\N	\N	\N
37258	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31450	\N	\N	\N
37288	MEMBRE	2023-10-11 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	31480	\N	\N	\N
37289	MEMBRE	2023-10-11 00:00:00	2024-02-04 00:00:00	ACTIF	\N	\N	\N	\N	31481	\N	\N	\N
37290	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31482	\N	\N	\N
37333	MEMBRE	2023-10-11 00:00:00	2024-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	31525	\N	\N	\N
37334	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31526	\N	\N	\N
37335	MEMBRE	2023-10-11 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	31527	\N	\N	\N
37341	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31533	\N	\N	\N
37342	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31534	\N	\N	\N
37343	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31535	\N	\N	\N
37344	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31536	\N	\N	\N
37345	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31537	\N	\N	\N
37346	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31538	\N	\N	\N
37347	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31539	\N	\N	\N
37348	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31540	\N	\N	\N
37349	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31541	\N	\N	\N
37350	MEMBRE	2023-10-11 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	31542	\N	\N	\N
37351	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31543	\N	\N	\N
37352	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31544	\N	\N	\N
37353	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31545	\N	\N	\N
37354	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31546	\N	\N	\N
37355	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31547	\N	\N	\N
37356	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31548	\N	\N	\N
37357	MEMBRE	2023-10-11 00:00:00	2024-02-26 00:00:00	ACTIF	\N	\N	\N	\N	31549	\N	\N	\N
37358	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31550	\N	\N	\N
37359	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31551	\N	\N	\N
37360	MEMBRE	2023-10-11 00:00:00	2024-01-04 00:00:00	ANCIEN	\N	\N	\N	\N	31552	\N	\N	\N
37367	MEMBRE	2023-10-11 00:00:00	2024-01-25 00:00:00	ACTIF	\N	\N	\N	\N	31559	\N	\N	\N
37368	MEMBRE	2023-10-11 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	31560	\N	\N	\N
37369	MEMBRE	2023-10-11 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	31561	\N	\N	\N
37370	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31562	\N	\N	\N
37371	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31563	\N	\N	\N
38094	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32289	\N	\N	\N
38095	MEMBRE	2023-10-24 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	32290	\N	\N	\N
38096	MEMBRE	2023-10-24 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	32291	\N	\N	\N
38097	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32292	\N	\N	\N
38983	MEMBRE	2023-11-24 00:00:00	2024-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	33156	\N	\N	\N
39370	PDTDEL	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour le Turkménistan	\N	33113	\N	\N	\N
39371	MEMBRE	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33049	\N	\N	\N
39400	MEMBRE	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33370	\N	\N	\N
39677	MEMBRE	2023-12-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	29870	\N	\N	\N
39823	MEMBRE	2024-01-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33491	\N	\N	\N
39824	MEMBRE	2024-01-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33492	\N	\N	\N
39825	MEMBRE	2024-01-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33493	\N	\N	\N
39826	MEMBRE	2024-01-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33494	\N	\N	\N
40100	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33675	\N	\N	\N
40110	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33684	\N	\N	\N
40111	MEMBRE	2023-10-01 00:00:00	2024-02-05 00:00:00	ACTIF	\N	\N	\N	\N	33685	\N	\N	\N
40112	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33686	\N	\N	\N
40117	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33690	\N	\N	\N
40118	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33691	\N	\N	\N
40119	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33692	\N	\N	\N
40123	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33696	\N	\N	\N
40180	MEMBRE	2024-01-22 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33709	\N	\N	\N
40342	MEMBRE	2024-01-22 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33838	\N	\N	\N
40343	MEMBRE	2024-01-22 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33839	\N	\N	\N
40347	MEMBRE	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33842	\N	\N	\N
40348	PDTDEL	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour l'Argentine	\N	33575	\N	\N	\N
40351	VICPDT	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31951	\N	\N	\N
40352	VICPDT	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32759	\N	\N	\N
40353	VICPDT	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31494	\N	\N	\N
40354	VICPDT	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31738	\N	\N	\N
40355	VICPDT	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32885	\N	\N	\N
40356	VICPDT	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31028	\N	\N	\N
40357	VICPDT	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31689	\N	\N	\N
40358	SECRET	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32979	\N	\N	\N
40359	SECRET	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31827	\N	\N	\N
40360	SECRET	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31217	\N	\N	\N
40361	SECRET	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31617	\N	\N	\N
40362	VICPDT	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31332	\N	\N	\N
40363	VICPDT	2024-01-23 00:00:00	2024-01-24 00:00:00	ACTIF	\N	\N	\N	\N	31224	\N	\N	\N
40364	VICPDT	2024-01-23 00:00:00	2024-01-24 00:00:00	ACTIF	\N	\N	\N	\N	31014	\N	\N	\N
40365	VICPDT	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31633	\N	\N	\N
40366	VICPDT	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33364	\N	\N	\N
40367	SECRET	2024-01-23 00:00:00	2024-01-24 00:00:00	ACTIF	\N	\N	\N	\N	33082	\N	\N	\N
40368	SECRET	2024-01-23 00:00:00	2024-01-24 00:00:00	ACTIF	\N	\N	\N	\N	31446	\N	\N	\N
40369	SECRET	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33020	\N	\N	\N
40370	SECRET	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33063	\N	\N	\N
30654	MEMBRE	2017-10-01 00:00:00	2018-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	26355	\N	\N	\N
30707	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26408	\N	\N	\N
30708	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26409	\N	\N	\N
30745	SECRET	2018-02-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25037	\N	2018-02-12 16:11:58	\N
30746	MEMBRE	2018-01-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26425	\N	2018-02-12 16:29:10	\N
30747	VICPDT	2018-02-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24296	\N	2018-02-12 16:56:19	\N
30748	VICPDT	2018-02-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25636	\N	2018-02-12 16:56:26	\N
30749	VICPDT	2018-02-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25527	\N	2018-02-12 16:56:32	\N
30750	VICPDT	2018-02-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25906	\N	2018-02-12 16:56:39	\N
30751	SECRET	2018-02-12 00:00:00	2020-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	25617	\N	2018-02-12 16:56:48	\N
30752	SECRET	2018-02-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25302	\N	2018-02-12 16:56:56	\N
30771	MEMBRE	2018-02-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26444	\N	2018-02-12 18:22:48	\N
30772	MEMBRE	2018-02-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26445	\N	2018-02-12 18:22:48	\N
30773	MEMBRE	2018-01-24 00:00:00	2018-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	26446	\N	2018-02-12 18:25:09	\N
30774	MEMBRE	2018-02-06 00:00:00	2018-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	26447	\N	2018-02-12 18:26:10	\N
30871	VICPDT	2018-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	26010	\N	\N	\N
30872	VICPDT	2018-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	26013	\N	\N	\N
30912	MEMBRE	2017-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26541	\N	\N	\N
30973	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26567	\N	\N	\N
31016	MEMBRE	2018-02-07 00:00:00	2018-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	26597	\N	2018-02-22 15:28:51	2018-03-16 14:48:09
31017	MEMBRE	2018-02-21 00:00:00	2019-06-24 00:00:00	ANCIEN	\N	\N	\N	\N	26598	\N	2018-02-22 15:29:07	\N
31097	MEMBRE	2018-03-08 00:00:00	2020-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	26625	\N	2018-03-08 12:30:39	\N
31123	MEMBRE	2018-03-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26647	\N	\N	\N
31124	MEMBRE	2018-03-07 00:00:00	2018-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	26648	\N	\N	\N
31126	MEMBRE	2018-03-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26650	\N	\N	\N
31267	MEMBRE	2018-03-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26752	\N	2018-04-19 10:08:05	\N
31444	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26905	\N	\N	\N
31445	MEMBRE	2017-10-01 00:00:00	2019-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	26906	\N	\N	\N
31447	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26908	\N	\N	\N
31451	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26912	\N	\N	\N
31478	VICPDT	2018-01-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	25894	\N	\N	\N
31543	MEMBRE	2019-03-06 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	26995	\N	\N	\N
31620	MEMBRE	2019-11-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27054	\N	\N	\N
31621	MEMBRE	2019-11-15 00:00:00	2019-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	27055	\N	\N	\N
31622	PDTDEL	2019-11-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Cap Vert	\N	27055	\N	\N	\N
31644	MEMBRE	2020-01-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	27076	\N	\N	\N
32529	MEMBRE	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27958	\N	\N	\N
32530	MEMBRE	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27959	\N	\N	\N
32531	MEMBRE	2020-10-19 00:00:00	2020-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	27960	\N	\N	\N
32532	MEMBRE	2020-10-19 00:00:00	2021-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	27961	\N	\N	\N
32533	MEMBRE	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27962	\N	\N	\N
32534	MEMBRE	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27963	\N	\N	\N
32535	MEMBRE	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27964	\N	\N	\N
32536	MEMBRE	2020-10-19 00:00:00	2020-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	27965	\N	\N	\N
32537	MEMBRE	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27966	\N	\N	\N
32538	MEMBRE	2020-10-19 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	27967	\N	\N	\N
32539	MEMBRE	2020-10-19 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	27968	\N	\N	\N
32540	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27969	\N	\N	\N
32541	MEMBRE	2020-10-15 00:00:00	2021-01-11 00:00:00	ANCIEN	\N	\N	\N	\N	27970	\N	\N	\N
32542	MEMBRE	2020-10-15 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	27971	\N	\N	\N
32543	MEMBRE	2020-10-15 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	27972	\N	\N	\N
32544	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27973	\N	\N	\N
32545	MEMBRE	2020-10-15 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	27974	\N	\N	\N
32546	MEMBRE	2020-10-15 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	27975	\N	\N	\N
32547	MEMBRE	2020-10-18 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	27976	\N	\N	\N
32548	MEMBRE	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27977	\N	\N	\N
32549	MEMBRE	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27978	\N	\N	\N
32550	MEMBRE	2020-10-18 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	27979	\N	\N	\N
32551	MEMBRE	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27980	\N	\N	\N
32552	MEMBRE	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27981	\N	\N	\N
32553	MEMBRE	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27982	\N	\N	\N
32554	MEMBRE	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27983	\N	\N	\N
32555	MEMBRE	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27984	\N	\N	\N
32556	MEMBRE	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27985	\N	\N	\N
32557	MEMBRE	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27986	\N	\N	\N
32558	MEMBRE	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27987	\N	\N	\N
32559	MEMBRE	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27988	\N	\N	\N
32560	MEMBRE	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27989	\N	\N	\N
32561	MEMBRE	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27990	\N	\N	\N
32562	MEMBRE	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27991	\N	\N	\N
32563	MEMBRE	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27992	\N	\N	\N
32564	MEMBRE	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27993	\N	\N	\N
32565	MEMBRE	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27994	\N	\N	\N
32566	MEMBRE	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27995	\N	\N	\N
32567	MEMBRE	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27996	\N	\N	\N
32568	MEMBRE	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27997	\N	\N	\N
32569	MEMBRE	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27998	\N	\N	\N
32570	MEMBRE	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27999	\N	\N	\N
32571	MEMBRE	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28000	\N	\N	\N
32572	MEMBRE	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28001	\N	\N	\N
32573	MEMBRE	2020-10-18 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	28002	\N	\N	\N
32574	MEMBRE	2020-10-18 00:00:00	2020-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	28003	\N	\N	\N
32575	MEMBRE	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28004	\N	\N	\N
32576	MEMBRE	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28005	\N	\N	\N
32577	MEMBRE	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28006	\N	\N	\N
32578	MEMBRE	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28007	\N	\N	\N
32579	MEMBRE	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28008	\N	\N	\N
32580	MEMBRE	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28009	\N	\N	\N
32581	MEMBRE	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28010	\N	\N	\N
32582	MEMBRE	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28011	\N	\N	\N
32583	MEMBRE	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28012	\N	\N	\N
32584	MEMBRE	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28013	\N	\N	\N
32585	MEMBRE	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28014	\N	\N	\N
32586	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28015	\N	\N	\N
32587	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28016	\N	\N	\N
32588	MEMBRE	2020-10-16 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	28017	\N	\N	\N
32589	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28018	\N	\N	\N
33048	MEMBRE	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28481	\N	\N	\N
33049	MEMBRE	2020-10-26 00:00:00	2020-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	28482	\N	\N	\N
33050	MEMBRE	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28483	\N	\N	\N
33051	MEMBRE	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28484	\N	\N	\N
33052	MEMBRE	2020-10-13 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	28485	\N	\N	\N
33053	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28486	\N	\N	\N
33054	MEMBRE	2020-10-13 00:00:00	2021-01-11 00:00:00	ANCIEN	\N	\N	\N	\N	28487	\N	\N	\N
33055	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28488	\N	\N	\N
33056	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28489	\N	\N	\N
33057	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28490	\N	\N	\N
33058	MEMBRE	2020-10-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28491	\N	\N	\N
33059	MEMBRE	2020-10-23 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	28492	\N	\N	\N
33060	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28493	\N	\N	\N
33061	MEMBRE	2020-10-27 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	28494	\N	\N	\N
33062	MEMBRE	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28495	\N	\N	\N
33063	MEMBRE	2020-10-27 00:00:00	2023-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	28496	\N	\N	\N
33686	MEMBRE	2020-11-19 00:00:00	2021-01-21 00:00:00	ANCIEN	\N	\N	\N	\N	29017	\N	\N	\N
34484	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29348	\N	\N	\N
34612	MEMBRE	2020-12-16 00:00:00	2021-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	29473	\N	\N	\N
34613	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29474	\N	\N	\N
34614	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29475	\N	\N	\N
34645	MEMBRE	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29503	\N	\N	\N
34646	MEMBRE	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29504	\N	\N	\N
34647	MEMBRE	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29505	\N	\N	\N
34648	MEMBRE	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29506	\N	\N	\N
34818	MEMBRE	2021-01-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	29601	\N	\N	\N
34827	MEMBRE	2021-01-04 00:00:00	2022-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	29610	\N	\N	\N
34921	MEMBRE	2021-01-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	29686	\N	\N	\N
34969	MEMBRE	2021-01-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29725	\N	\N	\N
34970	MEMBRE	2021-01-12 00:00:00	2021-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	29726	\N	\N	\N
34991	MEMBRE	2021-01-12 00:00:00	2021-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	29739	\N	\N	\N
35145	MEMBRE	2020-10-01 00:00:00	2021-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	29869	\N	\N	\N
35233	MEMBRE	2021-01-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	29948	\N	\N	\N
35453	PDT	2021-01-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29830	\N	\N	\N
35454	VICPDT	2021-01-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29829	\N	\N	\N
35455	VICPDT	2021-01-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29831	\N	\N	\N
35456	VICPDT	2021-01-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29834	\N	\N	\N
30651	MEMBRE	2017-10-01 00:00:00	2020-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	26352	\N	\N	\N
30653	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26354	\N	\N	\N
31007	MEMBRE	2017-10-01 00:00:00	2018-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	26594	\N	\N	\N
31198	VICPDT	2018-03-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	26591	\N	\N	\N
31332	MEMBRE	2018-09-04 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26797	\N	\N	\N
31407	MEMBRE	2018-10-03 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26868	\N	\N	\N
32326	MEMBRE	2020-10-09 00:00:00	2021-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	27755	\N	\N	\N
32327	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27756	\N	\N	\N
32328	MEMBRE	2020-10-15 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	27757	\N	\N	\N
32356	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27785	\N	\N	\N
32357	MEMBRE	2020-10-14 00:00:00	2021-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	27786	\N	\N	\N
32358	MEMBRE	2020-10-14 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	27787	\N	\N	\N
32359	MEMBRE	2020-10-14 00:00:00	2021-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	27788	\N	\N	\N
32360	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27789	\N	\N	\N
32361	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27790	\N	\N	\N
33253	MEMBRE	2020-10-30 00:00:00	2020-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	28686	\N	\N	\N
33254	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28687	\N	\N	\N
33255	MEMBRE	2020-10-30 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	28688	\N	\N	\N
33256	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28689	\N	\N	\N
33257	MEMBRE	2020-10-30 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	28690	\N	\N	\N
33258	MEMBRE	2020-10-30 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	28691	\N	\N	\N
33259	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28692	\N	\N	\N
33260	MEMBRE	2020-10-30 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	28693	\N	\N	\N
33261	MEMBRE	2020-10-30 00:00:00	2020-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	28694	\N	\N	\N
33262	MEMBRE	2020-10-30 00:00:00	2020-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	28695	\N	\N	\N
33263	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28696	\N	\N	\N
33264	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28697	\N	\N	\N
33265	MEMBRE	2020-10-30 00:00:00	2020-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	28698	\N	\N	\N
33266	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28699	\N	\N	\N
33267	MEMBRE	2020-10-30 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	28700	\N	\N	\N
33268	MEMBRE	2020-10-31 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	28701	\N	\N	\N
33269	MEMBRE	2020-10-31 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28702	\N	\N	\N
33270	MEMBRE	2020-10-31 00:00:00	2020-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	28703	\N	\N	\N
33271	MEMBRE	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28704	\N	\N	\N
33272	MEMBRE	2020-10-30 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	28705	\N	\N	\N
34035	MEMBRE	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29193	\N	\N	\N
34036	MEMBRE	2020-12-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29194	\N	\N	\N
34037	MEMBRE	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29195	\N	\N	\N
34575	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29439	\N	\N	\N
34576	MEMBRE	2020-12-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	29440	\N	\N	\N
34577	MEMBRE	2020-12-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	29441	\N	\N	\N
34578	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29442	\N	\N	\N
34695	MEMBRE	2020-12-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	29535	\N	\N	\N
34920	MEMBRE	2021-01-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	29685	\N	\N	\N
34931	MEMBRE	2020-12-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	29696	\N	\N	\N
34940	MEMBRE	2021-01-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29704	\N	\N	\N
35034	MEMBRE	2021-01-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29766	\N	\N	\N
35099	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29823	\N	\N	\N
35675	VICPDT	2021-02-04 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29789	\N	\N	\N
35896	PDTHON	2021-03-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28048	\N	\N	\N
35897	VICPDT	2021-03-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27435	\N	\N	\N
35898	VICPDT	2021-03-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27692	\N	\N	\N
35899	VICPDT	2021-03-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29158	\N	\N	\N
35901	VICPDT	2021-03-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29395	\N	\N	\N
36424	MEMBRE	2022-06-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30641	\N	\N	\N
36429	MEMBRE	2020-04-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	30646	\N	\N	\N
36842	MEMBRE	2023-10-09 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	31032	\N	\N	\N
36843	MEMBRE	2023-10-09 00:00:00	2024-02-08 00:00:00	ACTIF	\N	\N	\N	\N	31033	\N	\N	\N
36844	MEMBRE	2023-10-09 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	31034	\N	\N	\N
36845	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31035	\N	\N	\N
36846	MEMBRE	2023-10-09 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	31036	\N	\N	\N
36873	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31063	\N	\N	\N
36874	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31064	\N	\N	\N
36875	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31065	\N	\N	\N
37704	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31896	\N	\N	\N
37705	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31897	\N	\N	\N
37706	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31898	\N	\N	\N
37707	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31899	\N	\N	\N
37708	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31900	\N	\N	\N
37709	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31901	\N	\N	\N
37710	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31902	\N	\N	\N
37711	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31903	\N	\N	\N
37712	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31904	\N	\N	\N
37713	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31905	\N	\N	\N
37714	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31906	\N	\N	\N
37715	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31907	\N	\N	\N
37716	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31908	\N	\N	\N
37717	MEMBRE	2023-10-17 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	31909	\N	\N	\N
37718	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31910	\N	\N	\N
37719	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31911	\N	\N	\N
37720	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31912	\N	\N	\N
37721	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31913	\N	\N	\N
37722	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31914	\N	\N	\N
37723	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31915	\N	\N	\N
37724	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31916	\N	\N	\N
37725	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31917	\N	\N	\N
37726	MEMBRE	2023-10-17 00:00:00	2023-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	31918	\N	\N	\N
37727	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31919	\N	\N	\N
37728	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31920	\N	\N	\N
37729	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31921	\N	\N	\N
37730	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31922	\N	\N	\N
37731	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31923	\N	\N	\N
37732	MEMBRE	2023-10-17 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	31924	\N	\N	\N
37733	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31925	\N	\N	\N
37734	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31926	\N	\N	\N
37735	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31927	\N	\N	\N
37736	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31928	\N	\N	\N
37737	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31929	\N	\N	\N
37738	MEMBRE	2023-10-17 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	31930	\N	\N	\N
37739	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31931	\N	\N	\N
37740	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31932	\N	\N	\N
37741	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31933	\N	\N	\N
37742	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31934	\N	\N	\N
37743	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31935	\N	\N	\N
38098	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32293	\N	\N	\N
38099	MEMBRE	2023-10-24 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	32294	\N	\N	\N
38100	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32295	\N	\N	\N
38108	MEMBRE	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32303	\N	\N	\N
38247	MEMBRE	2023-10-28 00:00:00	2023-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	32442	\N	\N	\N
38248	MEMBRE	2023-10-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32443	\N	\N	\N
38249	MEMBRE	2023-10-28 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	32444	\N	\N	\N
38250	MEMBRE	2023-10-28 00:00:00	2024-01-30 00:00:00	ACTIF	\N	\N	\N	\N	32445	\N	\N	\N
38251	MEMBRE	2023-10-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32446	\N	\N	\N
38252	MEMBRE	2023-10-28 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	32447	\N	\N	\N
38923	PDT	2023-11-22 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33088	\N	\N	\N
38924	PDT	2023-11-22 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31077	\N	\N	\N
38925	PDT	2023-11-22 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31438	\N	\N	\N
38926	PDT	2023-11-22 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31853	\N	\N	\N
38927	PDTDEL	2023-11-22 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour la Guyana	\N	31316	\N	\N	\N
38928	PDTDEL	2023-11-22 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour le Suriname	\N	31818	\N	\N	\N
38929	PDTDEL	2023-11-22 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour la Mauritanie	\N	32922	\N	\N	\N
38930	PDTDEL	2023-11-22 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour le Vénézuela	\N	32903	\N	\N	\N
38931	PDTDEL	2023-11-22 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour le Mozambique	\N	32160	\N	\N	\N
39201	MEMBRE	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33247	\N	\N	\N
39342	MEMBRE	2023-12-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33325	\N	\N	\N
39762	VICPDT	2024-01-04 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31824	\N	\N	\N
39763	MEMBRE	2024-01-04 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33458	\N	\N	\N
39999	MEMBRE	2024-01-17 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	\N	29880	\N	\N	\N
40001	MEMBRE	2024-01-17 00:00:00	2024-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	29887	\N	\N	\N
40004	MEMBRE	2023-10-01 00:00:00	2024-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	33585	\N	\N	\N
40371	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33845	\N	\N	\N
40017	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33594	\N	\N	\N
40377	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33850	\N	\N	\N
40378	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33851	\N	\N	\N
40379	MEMBRE	2023-12-14 00:00:00	2024-02-14 00:00:00	ACTIF	\N	\N	\N	\N	33852	\N	\N	\N
40425	MEMBRE	2023-12-14 00:00:00	2024-02-14 00:00:00	ACTIF	\N	\N	\N	\N	33898	\N	\N	\N
40429	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33902	\N	\N	\N
40431	MEMBRE	2023-12-14 00:00:00	2024-02-14 00:00:00	ACTIF	\N	\N	\N	\N	33904	\N	\N	\N
40432	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33905	\N	\N	\N
30758	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26431	\N	\N	\N
30759	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26432	\N	\N	\N
30760	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26433	\N	\N	\N
30761	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26434	\N	\N	\N
30762	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26435	\N	\N	\N
30763	MEMBRE	2017-10-01 00:00:00	2020-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	26436	\N	\N	\N
30764	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26437	\N	\N	\N
30765	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26438	\N	\N	\N
30766	MEMBRE	2017-10-01 00:00:00	2018-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	26439	\N	\N	\N
30767	MEMBRE	2017-10-01 00:00:00	2018-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	26440	\N	\N	\N
30769	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26442	\N	\N	\N
30863	MEMBREBUR	2018-02-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	26062	\N	\N	\N
30894	MEMBRE	2017-10-01 00:00:00	2018-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	26530	\N	\N	\N
30895	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26531	\N	\N	\N
30898	MEMBRE	2017-10-01 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	26534	\N	\N	\N
30899	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26535	\N	\N	\N
31026	MEMBRE	2018-02-21 00:00:00	2018-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	26607	\N	2018-02-23 17:44:41	\N
31027	MEMBRE	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26608	\N	2018-02-23 18:06:56	\N
31031	MEMBRE	2018-02-23 00:00:00	2018-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	26612	\N	2018-03-01 09:17:53	2018-03-16 14:48:25
31171	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26695	\N	\N	\N
31172	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26696	\N	\N	\N
31173	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26697	\N	\N	\N
31221	MEMBRE	2017-12-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26715	\N	\N	\N
31225	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26719	\N	\N	\N
31274	VICPDT	2018-05-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26232	\N	\N	\N
31331	MEMBRE	2018-07-19 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	26796	\N	\N	\N
31350	MEMBRE	2018-09-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26812	\N	\N	\N
31391	PDT	2018-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26643	\N	\N	\N
31533	MEMBRE	2019-02-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	26985	\N	\N	\N
31570	MEMBRE	2019-05-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	27017	\N	\N	\N
31628	MEMBRE	2019-12-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27060	\N	\N	\N
32024	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27453	\N	\N	\N
32025	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27454	\N	\N	\N
32026	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27455	\N	\N	\N
32027	MEMBRE	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27456	\N	\N	\N
33404	MEMBRE	2020-11-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28826	\N	\N	\N
33405	MEMBRE	2020-11-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28827	\N	\N	\N
33406	MEMBRE	2020-11-04 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	28828	\N	\N	\N
33407	MEMBRE	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28829	\N	\N	\N
33408	MEMBRE	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28830	\N	\N	\N
33409	MEMBRE	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28831	\N	\N	\N
33410	MEMBRE	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28832	\N	\N	\N
33411	MEMBRE	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28833	\N	\N	\N
33412	MEMBRE	2020-11-04 00:00:00	2021-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	28834	\N	\N	\N
33413	MEMBRE	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28835	\N	\N	\N
33414	MEMBRE	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28836	\N	\N	\N
33415	MEMBRE	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28837	\N	\N	\N
33416	MEMBRE	2020-10-26 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	28838	\N	\N	\N
33417	MEMBRE	2020-11-04 00:00:00	2023-09-28 00:00:00	ANCIEN	\N	\N	\N	\N	28839	\N	\N	\N
33418	MEMBRE	2020-11-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28840	\N	\N	\N
33911	MEMBRE	2020-12-01 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	29160	\N	\N	\N
34008	MEMBRE	2020-12-08 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	29185	\N	\N	\N
34009	MEMBRE	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29186	\N	\N	\N
34010	VICPDT	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28515	\N	\N	\N
34011	VICPDT	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28256	\N	\N	\N
34012	VICPDT	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27295	\N	\N	\N
34013	VICPDT	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28313	\N	\N	\N
34014	VICPDT	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28878	\N	\N	\N
34015	VICPDT	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28468	\N	\N	\N
34016	VICPDT	2020-12-09 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29108	\N	\N	\N
34017	SECRET	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27382	\N	\N	\N
34691	MEMBRE	2020-12-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29531	\N	\N	\N
34815	MEMBRE	2021-01-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29598	\N	\N	\N
34861	MEMBRE	2021-01-04 00:00:00	2021-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	29644	\N	\N	\N
34866	MEMBRE	2021-01-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29649	\N	\N	\N
35061	MEMBRE	2020-10-01 00:00:00	2024-01-29 00:00:00	ACTIF	\N	\N	\N	\N	29785	\N	\N	\N
35076	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29800	\N	\N	\N
35077	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29801	\N	\N	\N
35108	MEMBRE	2020-10-01 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29832	\N	\N	\N
35121	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29845	\N	\N	\N
35122	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29846	\N	\N	\N
35130	MEMBRE	2020-10-01 00:00:00	2021-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	29854	\N	\N	\N
35131	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29855	\N	\N	\N
35133	MEMBRE	2020-10-01 00:00:00	2024-01-30 00:00:00	ACTIF	\N	\N	\N	\N	29857	\N	\N	\N
35136	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29860	\N	\N	\N
35137	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29861	\N	\N	\N
35138	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29862	\N	\N	\N
35139	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29863	\N	\N	\N
35140	MEMBRE	2020-10-01 00:00:00	2021-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	29864	\N	\N	\N
35141	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29865	\N	\N	\N
35142	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29866	\N	\N	\N
35180	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29904	\N	\N	\N
35181	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29905	\N	\N	\N
35182	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29906	\N	\N	\N
35183	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29907	\N	\N	\N
35184	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29908	\N	\N	\N
35185	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29909	\N	\N	\N
35186	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29910	\N	\N	\N
35187	MEMBRE	2020-10-01 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	29911	\N	\N	\N
35188	MEMBRE	2020-10-01 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	29912	\N	\N	\N
35285	VICPDT	2021-01-19 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29252	\N	\N	\N
35334	MEMBRE	2021-01-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29997	\N	\N	\N
35436	MEMBRE	2021-01-26 00:00:00	2021-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	30053	\N	\N	\N
35437	MEMBRE	2021-01-26 00:00:00	2021-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	30054	\N	\N	\N
35438	MEMBRE	2021-01-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30055	\N	\N	\N
35439	MEMBRE	2021-01-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30056	\N	\N	\N
35440	MEMBRE	2021-01-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30057	\N	\N	\N
35471	VICPDT	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29689	\N	\N	\N
35523	VICPDT	2021-01-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29690	\N	\N	\N
35657	VICPDT	2021-02-03 00:00:00	2021-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	30098	\N	\N	\N
35874	MEMBRE	2021-02-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	30208	\N	\N	\N
35914	MEMBRE	2021-03-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30226	\N	\N	\N
35986	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30283	\N	\N	\N
35989	MEMBRE	2021-03-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30286	\N	\N	\N
35990	MEMBRE	2021-03-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30287	\N	\N	\N
36122	MEMBRE	2021-09-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30385	\N	\N	\N
36278	MEMBRE	2021-12-31 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30513	\N	\N	\N
36279	MEMBRE	2021-12-31 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30514	\N	\N	\N
36280	MEMBRE	2021-12-31 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30515	\N	\N	\N
36428	MEMBRE	2022-06-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	30645	\N	\N	\N
36527	MEMBRE	2023-01-01 00:00:00	2023-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	30744	\N	\N	\N
36528	MEMBRE	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30745	\N	\N	\N
36529	MEMBRE	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30746	\N	\N	\N
36548	MEMBRE	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30765	\N	\N	\N
36588	MEMBRE	2023-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30794	\N	\N	\N
36652	MEMBRE	2023-06-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30850	\N	\N	\N
36645	MEMBRE	2023-06-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30843	\N	\N	\N
36646	MEMBRE	2023-06-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30844	\N	\N	\N
36669	MEMBRE	2023-09-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30862	\N	\N	\N
36800	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30990	\N	\N	\N
36801	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30991	\N	\N	\N
36838	MEMBRE	2023-10-09 00:00:00	2024-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	31028	\N	\N	\N
36839	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31029	\N	\N	\N
36840	MEMBRE	2023-10-09 00:00:00	2024-01-25 00:00:00	ACTIF	\N	\N	\N	\N	31030	\N	\N	\N
36841	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31031	\N	\N	\N
36885	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31075	\N	\N	\N
36886	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31076	\N	\N	\N
36887	MEMBRE	2023-10-09 00:00:00	2023-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	31077	\N	\N	\N
36888	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31078	\N	\N	\N
36889	MEMBRE	2023-10-09 00:00:00	2024-02-27 00:00:00	ACTIF	\N	\N	\N	\N	31079	\N	\N	\N
36890	MEMBRE	2023-10-09 00:00:00	2024-01-25 00:00:00	ACTIF	\N	\N	\N	\N	31080	\N	\N	\N
36891	MEMBRE	2023-10-09 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	31081	\N	\N	\N
36892	MEMBRE	2023-10-09 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	31082	\N	\N	\N
36893	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31083	\N	\N	\N
36894	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31084	\N	\N	\N
37063	MEMBRE	2023-10-10 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	31253	\N	\N	\N
37064	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31254	\N	\N	\N
37065	MEMBRE	2023-10-10 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	31255	\N	\N	\N
37066	MEMBRE	2023-10-10 00:00:00	2024-02-07 00:00:00	ACTIF	\N	\N	\N	\N	31256	\N	\N	\N
30624	PDT	2018-02-08 00:00:00	2020-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	25255	\N	2018-02-08 15:51:53	\N
30639	MEMBRE	2017-10-01 00:00:00	2018-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	26340	\N	\N	\N
30640	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26341	\N	\N	\N
30824	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26495	\N	\N	\N
30826	MEMBRE	2017-10-01 00:00:00	2018-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	26497	\N	\N	\N
30827	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26498	\N	\N	\N
30829	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26500	\N	\N	\N
30830	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26501	\N	\N	\N
30831	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26502	\N	\N	\N
30832	MEMBRE	2017-10-01 00:00:00	2018-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	26503	\N	\N	\N
30922	SECRET	2018-02-15 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26521	\N	\N	\N
30925	SECRET	2018-02-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	26525	\N	\N	\N
30997	VICPDT	2018-02-21 00:00:00	2020-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	24625	\N	2018-02-21 15:38:59	\N
30998	VICPDT	2018-02-21 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25045	\N	2018-02-21 15:39:05	\N
30999	VICPDT	2018-02-21 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	24495	\N	2018-02-21 15:39:12	\N
31000	VICPDT	2018-02-21 00:00:00	2020-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	25150	\N	2018-02-21 15:39:19	\N
31001	VICPDT	2018-02-21 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	24022	\N	2018-02-21 15:39:27	\N
31002	SECRET	2018-02-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24961	\N	2018-02-21 15:39:34	\N
31003	SECRET	2018-02-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26546	\N	2018-02-21 15:39:40	\N
31085	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26623	\N	\N	\N
31242	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26735	\N	\N	\N
31243	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26736	\N	\N	\N
31309	MEMBRE	2018-06-11 00:00:00	2022-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	26778	\N	2018-06-11 17:36:54	\N
31374	MEMBRE	2017-12-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26836	\N	\N	\N
31433	MEMBRE	2018-11-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26894	\N	\N	\N
31479	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26936	\N	\N	\N
31516	MEMBRE	2019-02-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	26968	\N	\N	\N
31578	VICPDT	2019-06-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26598	\N	\N	\N
31579	VICPDT	2019-06-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26702	\N	\N	\N
31580	VICPDT	2019-06-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26979	\N	\N	\N
31643	MEMBRE	2020-01-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27075	\N	\N	\N
32369	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27798	\N	\N	\N
32370	MEMBRE	2020-10-15 00:00:00	2020-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	27799	\N	\N	\N
32371	MEMBRE	2020-10-15 00:00:00	2021-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	27800	\N	\N	\N
32372	MEMBRE	2020-10-15 00:00:00	2021-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	27801	\N	\N	\N
32373	MEMBRE	2020-10-15 00:00:00	2020-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	27802	\N	\N	\N
32374	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27803	\N	\N	\N
32375	MEMBRE	2020-10-15 00:00:00	2020-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	27804	\N	\N	\N
32376	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27805	\N	\N	\N
32377	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27806	\N	\N	\N
32378	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27807	\N	\N	\N
32379	MEMBRE	2020-10-15 00:00:00	2023-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	27808	\N	\N	\N
32380	MEMBRE	2020-10-15 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	27809	\N	\N	\N
32381	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27810	\N	\N	\N
32382	MEMBRE	2020-10-15 00:00:00	2021-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	27811	\N	\N	\N
32383	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27812	\N	\N	\N
32384	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27813	\N	\N	\N
32385	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27814	\N	\N	\N
32386	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27815	\N	\N	\N
32387	MEMBRE	2020-10-15 00:00:00	2021-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	27816	\N	\N	\N
32388	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27817	\N	\N	\N
32389	MEMBRE	2020-10-15 00:00:00	2021-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	27818	\N	\N	\N
32390	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27819	\N	\N	\N
32391	MEMBRE	2020-10-15 00:00:00	2021-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	27820	\N	\N	\N
33485	MEMBRE	2020-11-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28907	\N	\N	\N
33486	MEMBRE	2020-11-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28908	\N	\N	\N
33500	MEMBRE	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28922	\N	\N	\N
33501	MEMBRE	2020-10-26 00:00:00	2021-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	28923	\N	\N	\N
33502	MEMBRE	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28924	\N	\N	\N
33503	MEMBRE	2020-11-12 00:00:00	2020-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	28925	\N	\N	\N
33504	MEMBRE	2020-11-12 00:00:00	2020-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	28926	\N	\N	\N
33505	MEMBRE	2020-11-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28927	\N	\N	\N
33506	MEMBRE	2020-11-12 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	28928	\N	\N	\N
33507	MEMBRE	2020-11-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28929	\N	\N	\N
33508	MEMBRE	2020-11-10 00:00:00	2020-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	28930	\N	\N	\N
33509	MEMBRE	2020-11-10 00:00:00	2020-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	28931	\N	\N	\N
33780	MEMBRE	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29052	\N	\N	\N
33781	MEMBRE	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29053	\N	\N	\N
34164	MEMBRE	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29237	\N	\N	\N
34165	MEMBRE	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29238	\N	\N	\N
34295	MEMBRE	2020-12-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29276	\N	\N	\N
34296	MEMBRE	2020-12-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29277	\N	\N	\N
34297	MEMBRE	2020-12-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29278	\N	\N	\N
34298	MEMBRE	2020-12-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29279	\N	\N	\N
34299	MEMBRE	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29280	\N	\N	\N
34300	MEMBRE	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29281	\N	\N	\N
34301	VICPDT	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27300	\N	\N	\N
34302	VICPDT	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27465	\N	\N	\N
34303	VICPDT	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28357	\N	\N	\N
34304	VICPDT	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28399	\N	\N	\N
34305	VICPDT	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29048	\N	\N	\N
34306	VICPDT	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27203	\N	\N	\N
34307	VICPDT	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27143	\N	\N	\N
34308	SECRET	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29095	\N	\N	\N
34309	MEMBRE	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29282	\N	\N	\N
34459	MEMBRE	2020-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29323	\N	\N	\N
34594	SECRET	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29315	\N	\N	\N
35448	VICPDT	2021-01-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27800	\N	\N	\N
35449	VICPDT	2021-01-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27517	\N	\N	\N
35450	SECRET	2021-01-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28923	\N	\N	\N
35451	SECRET	2021-01-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27852	\N	\N	\N
35452	SECRET	2021-01-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28941	\N	\N	\N
35659	PDT	2021-02-03 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	30108	\N	\N	\N
35660	VICPDT	2021-02-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	30114	\N	\N	\N
35915	MEMBRE	2021-03-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30227	\N	\N	\N
36063	MEMBRE	2021-06-10 00:00:00	2021-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	30344	\N	\N	\N
36141	MEMBRE	2021-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	30403	\N	\N	\N
36215	PDT	2021-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30418	\N	\N	\N
36395	MEMBRE	2022-03-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30614	\N	\N	\N
36467	MEMBRE	2022-09-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30684	\N	\N	\N
36565	MEMBRE	2023-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30782	\N	\N	\N
36687	MEMBRE	2023-10-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30877	\N	\N	\N
37475	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31667	\N	\N	\N
38550	MEMBRE	2023-11-06 00:00:00	2023-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	32745	\N	\N	\N
38551	MEMBRE	2023-11-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32746	\N	\N	\N
38552	MEMBRE	2023-11-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32747	\N	\N	\N
38553	MEMBRE	2023-11-06 00:00:00	2024-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	32748	\N	\N	\N
38554	MEMBRE	2023-11-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32749	\N	\N	\N
39205	MEMBRE	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33251	\N	\N	\N
39227	MEMBRE	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33271	\N	\N	\N
39264	MEMBRE	2023-12-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33308	\N	\N	\N
39605	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32030	\N	\N	\N
39606	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33190	\N	\N	\N
39607	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31876	\N	\N	\N
39608	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32631	\N	\N	\N
39609	VICPDT	2023-12-20 00:00:00	2024-01-03 00:00:00	ANCIEN	\N	\N	\N	\N	31824	\N	\N	\N
39610	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31688	\N	\N	\N
39611	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33074	\N	\N	\N
39612	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33086	\N	\N	\N
39613	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32564	\N	\N	\N
39614	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31743	\N	\N	\N
39615	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32209	\N	\N	\N
39616	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30928	\N	\N	\N
39617	SECRET	2023-12-20 00:00:00	2023-12-21 00:00:00	ANCIEN	\N	\N	\N	\N	31824	\N	\N	\N
39618	SECRET	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32775	\N	\N	\N
39619	SECRET	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32661	\N	\N	\N
39620	SECRET	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31355	\N	\N	\N
39621	SECRET	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31943	\N	\N	\N
39622	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32607	\N	\N	\N
39623	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31854	\N	\N	\N
39624	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31017	\N	\N	\N
39625	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33185	\N	\N	\N
39626	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31344	\N	\N	\N
39627	SECRET	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32861	\N	\N	\N
39628	SECRET	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32923	\N	\N	\N
39629	SECRET	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32777	\N	\N	\N
39788	VICPDT	2024-01-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32821	\N	\N	\N
30681	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26382	\N	\N	\N
30940	VICPDT	2018-02-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	26332	\N	\N	\N
31319	MEMBRE	2018-01-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26787	\N	\N	\N
31362	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26824	\N	\N	\N
31378	MEMBRE	2018-10-03 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26840	\N	\N	\N
31412	MEMBRE	2018-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26873	\N	\N	\N
31413	MEMBRE	2018-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26874	\N	\N	\N
31414	MEMBRE	2018-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26875	\N	\N	\N
31415	MEMBRE	2018-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26876	\N	\N	\N
31416	MEMBRE	2018-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26877	\N	\N	\N
31417	MEMBRE	2018-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26878	\N	\N	\N
31437	MEMBRE	2018-11-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26898	\N	\N	\N
31457	MEMBRE	2018-11-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26918	\N	\N	\N
31472	MEMBRE	2018-12-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26930	\N	\N	\N
31520	MEMBRE	2019-02-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	26972	\N	\N	\N
31524	MEMBRE	2019-02-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	26976	\N	\N	\N
31576	MEMBRE	2019-06-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27023	\N	\N	\N
31611	MEMBRE	2019-10-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	27046	\N	\N	\N
34677	MEMBRE	2020-12-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29517	\N	\N	\N
34819	MEMBRE	2021-01-05 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	29602	\N	\N	\N
34872	MEMBRE	2020-12-16 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	29655	\N	\N	\N
34937	MEMBRE	2021-01-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	29701	\N	\N	\N
35132	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29856	\N	\N	\N
35157	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29881	\N	\N	\N
35910	MEMBRE	2021-03-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	30222	\N	\N	\N
35258	MEMBRE	2020-10-01 00:00:00	2021-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	29960	\N	\N	\N
35929	PDT	2021-03-17 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	30012	\N	\N	\N
35930	VICPDT	2021-03-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29854	\N	\N	\N
35932	VICPDT	2021-03-17 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29966	\N	\N	\N
35964	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30264	\N	\N	\N
35965	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30265	\N	\N	\N
35966	MEMBRE	2020-10-01 00:00:00	2021-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	30266	\N	\N	\N
35968	MEMBRE	2020-10-01 00:00:00	2021-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	30267	\N	\N	\N
35969	SECRET	2021-03-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30267	\N	\N	\N
35970	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30268	\N	\N	\N
35971	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30269	\N	\N	\N
35972	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30270	\N	\N	\N
35975	VICPDT	2021-03-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30272	\N	\N	\N
35977	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30274	\N	\N	\N
36012	MEMBRE	2021-03-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30309	\N	\N	\N
36070	MEMBRE	2021-06-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	30351	\N	\N	\N
36190	MEMBRE	2021-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30442	\N	\N	\N
36242	MEMBRE	2021-12-07 00:00:00	2023-09-28 00:00:00	ANCIEN	\N	\N	\N	\N	30487	\N	\N	\N
36359	MEMBRE	2022-04-05 00:00:00	2022-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	30586	\N	\N	\N
36392	MEMBRE	2022-04-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30611	\N	\N	\N
36393	MEMBRE	2022-04-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30612	\N	\N	\N
36434	MEMBRE	2022-07-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30651	\N	\N	\N
36445	MEMBRE	2022-06-08 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30662	\N	\N	\N
36446	MEMBRE	2022-06-01 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	30663	\N	\N	\N
36566	MEMBRE	2023-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30783	\N	\N	\N
37067	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31257	\N	\N	\N
37131	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31323	\N	\N	\N
37181	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31373	\N	\N	\N
37232	MEMBRE	2023-10-10 00:00:00	2024-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	31424	\N	\N	\N
37233	MEMBRE	2023-10-10 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	31425	\N	\N	\N
37471	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31663	\N	\N	\N
37472	MEMBRE	2023-10-13 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	31664	\N	\N	\N
37473	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31665	\N	\N	\N
37474	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31666	\N	\N	\N
37504	MEMBRE	2023-10-13 00:00:00	2024-01-29 00:00:00	ACTIF	\N	\N	\N	\N	31696	\N	\N	\N
37505	MEMBRE	2023-10-13 00:00:00	2023-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	31697	\N	\N	\N
37506	MEMBRE	2023-10-13 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	31698	\N	\N	\N
37586	MEMBRE	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31778	\N	\N	\N
37587	MEMBRE	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31779	\N	\N	\N
37588	MEMBRE	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31780	\N	\N	\N
37589	MEMBRE	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31781	\N	\N	\N
37590	MEMBRE	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31782	\N	\N	\N
37591	MEMBRE	2023-10-16 00:00:00	2023-12-11 00:00:00	ANCIEN	\N	\N	\N	\N	31783	\N	\N	\N
37592	MEMBRE	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31784	\N	\N	\N
37593	MEMBRE	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31785	\N	\N	\N
37988	MEMBRE	2023-10-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32183	\N	\N	\N
37991	MEMBRE	2023-10-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32186	\N	\N	\N
38013	MEMBRE	2023-10-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32208	\N	\N	\N
38014	MEMBRE	2023-10-23 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	32209	\N	\N	\N
38015	MEMBRE	2023-10-23 00:00:00	2024-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	32210	\N	\N	\N
38016	MEMBRE	2023-10-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32211	\N	\N	\N
38017	MEMBRE	2023-10-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32212	\N	\N	\N
38019	MEMBRE	2023-10-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32214	\N	\N	\N
38020	MEMBRE	2023-10-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32215	\N	\N	\N
38021	MEMBRE	2023-10-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32216	\N	\N	\N
38022	MEMBRE	2023-10-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32217	\N	\N	\N
38023	MEMBRE	2023-10-23 00:00:00	2023-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	32218	\N	\N	\N
38142	MEMBRE	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32337	\N	\N	\N
38306	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32501	\N	\N	\N
38387	MEMBRE	2023-10-31 00:00:00	2023-11-15 00:00:00	ANCIEN	\N	\N	\N	\N	32582	\N	\N	\N
38388	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32583	\N	\N	\N
38389	MEMBRE	2023-10-31 00:00:00	2023-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	32584	\N	\N	\N
38390	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32585	\N	\N	\N
38391	MEMBRE	2023-10-31 00:00:00	2024-01-25 00:00:00	ACTIF	\N	\N	\N	\N	32586	\N	\N	\N
38479	MEMBRE	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32674	\N	\N	\N
38480	MEMBRE	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32675	\N	\N	\N
38481	MEMBRE	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32676	\N	\N	\N
38482	MEMBRE	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32677	\N	\N	\N
38483	MEMBRE	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32678	\N	\N	\N
38484	MEMBRE	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32679	\N	\N	\N
38485	MEMBRE	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32680	\N	\N	\N
38486	MEMBRE	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32681	\N	\N	\N
38722	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32917	\N	\N	\N
38749	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32944	\N	\N	\N
38750	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32945	\N	\N	\N
38768	MEMBRE	2023-11-15 00:00:00	2024-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	32963	\N	\N	\N
38769	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32964	\N	\N	\N
38998	PDT	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31091	\N	\N	\N
38999	PDT	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32854	\N	\N	\N
39000	PDT	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31909	\N	\N	\N
39001	PDT	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31680	\N	\N	\N
39002	PDT	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32873	\N	\N	\N
39003	PDT	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31938	\N	\N	\N
39004	PDT	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31839	\N	\N	\N
39005	PDT	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31166	\N	\N	\N
39006	PDT	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31561	\N	\N	\N
39007	PDT	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32002	\N	\N	\N
39008	PDT	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33094	\N	\N	\N
39009	PDT	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31710	\N	\N	\N
39010	PDT	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32632	\N	\N	\N
39012	PDT	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31830	\N	\N	\N
39013	PDT	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31685	\N	\N	\N
39014	PDT	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31983	\N	\N	\N
39015	PDT	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31572	\N	\N	\N
39016	PDT	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31649	\N	\N	\N
39017	PDT	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31996	\N	\N	\N
39018	PDT	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31246	\N	\N	\N
39019	PDT	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32184	\N	\N	\N
39020	PDT	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31568	\N	\N	\N
39021	PDT	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31600	\N	\N	\N
39022	PDT	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32159	\N	\N	\N
39023	PDT	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31658	\N	\N	\N
39024	PDT	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31610	\N	\N	\N
39025	PDT	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30945	\N	\N	\N
39026	PDT	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31669	\N	\N	\N
39027	PDT	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31542	\N	\N	\N
39028	PDT	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31225	\N	\N	\N
39029	PDT	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31461	\N	\N	\N
39030	PDT	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31874	\N	\N	\N
39031	PDT	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31032	\N	\N	\N
39032	PDT	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32899	\N	\N	\N
39033	PDT	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31878	\N	\N	\N
39034	PDT	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31775	\N	\N	\N
39035	PDT	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31937	\N	\N	\N
39036	PDT	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30970	\N	\N	\N
39038	PDT	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32226	\N	\N	\N
30775	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26448	\N	\N	\N
30776	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26449	\N	\N	\N
30778	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26451	\N	\N	\N
30779	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26452	\N	\N	\N
31021	MEMBRE	2018-02-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26602	\N	2018-02-23 15:18:42	\N
31388	MEMBRE	2018-10-10 00:00:00	2020-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	26850	\N	\N	\N
31389	MEMBRE	2018-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26851	\N	\N	\N
31603	MEMBRE	2018-06-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27038	\N	\N	\N
33541	MEMBRE	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28958	\N	\N	\N
33542	MEMBRE	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28959	\N	\N	\N
33543	MEMBRE	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28960	\N	\N	\N
33544	MEMBRE	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28961	\N	\N	\N
33545	MEMBRE	2020-11-17 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	28962	\N	\N	\N
33546	MEMBRE	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28963	\N	\N	\N
33547	MEMBRE	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28964	\N	\N	\N
33548	MEMBRE	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28965	\N	\N	\N
33549	MEMBRE	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28966	\N	\N	\N
33550	MEMBRE	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28967	\N	\N	\N
33551	MEMBRE	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28968	\N	\N	\N
33552	MEMBRE	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28969	\N	\N	\N
33553	MEMBRE	2020-11-17 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	28970	\N	\N	\N
33554	MEMBRE	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28971	\N	\N	\N
33555	MEMBRE	2020-11-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28972	\N	\N	\N
33556	MEMBRE	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28973	\N	\N	\N
33557	MEMBRE	2020-10-27 00:00:00	2021-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	28974	\N	\N	\N
33558	MEMBRE	2020-10-27 00:00:00	2021-01-03 00:00:00	ANCIEN	\N	\N	\N	\N	28975	\N	\N	\N
33559	MEMBRE	2020-11-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28976	\N	\N	\N
34068	MEMBRE	2020-12-10 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	29217	\N	\N	\N
33838	MEMBRE	2020-11-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28472	\N	\N	\N
33839	PDTDEL	2020-11-25 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	pour Singapour	\N	27448	\N	\N	\N
34069	MEMBRE	2020-12-10 00:00:00	2021-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	29218	\N	\N	\N
34070	MEMBRE	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29219	\N	\N	\N
34071	MEMBRE	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29220	\N	\N	\N
34072	VICPDT	2020-12-10 00:00:00	2022-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	27629	\N	\N	\N
34073	VICPDT	2020-12-10 00:00:00	2021-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	28675	\N	\N	\N
34074	VICPDT	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27603	\N	\N	\N
34075	VICPDT	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27691	\N	\N	\N
34076	VICPDT	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29037	\N	\N	\N
34077	VICPDT	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28371	\N	\N	\N
34078	VICPDT	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27405	\N	\N	\N
34079	VICPDT	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27353	\N	\N	\N
34080	VICPDT	2020-12-10 00:00:00	2021-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	27746	\N	\N	\N
34081	SECRET	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28025	\N	\N	\N
34082	SECRET	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28148	\N	\N	\N
34083	VICPDT	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27160	\N	\N	\N
34084	VICPDT	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27941	\N	\N	\N
34085	VICPDT	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27974	\N	\N	\N
34086	VICPDT	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27967	\N	\N	\N
34087	VICPDT	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27365	\N	\N	\N
34088	VICPDT	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27249	\N	\N	\N
34089	VICPDT	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28145	\N	\N	\N
34090	VICPDT	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28862	\N	\N	\N
34091	VICPDT	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28447	\N	\N	\N
34092	SECRET	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28633	\N	\N	\N
34093	SECRET	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27439	\N	\N	\N
34094	SECRET	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28311	\N	\N	\N
34095	SECRET	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27696	\N	\N	\N
34096	SECRET	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27110	\N	\N	\N
34097	SECRET	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27289	\N	\N	\N
34098	SECRET	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28511	\N	\N	\N
34099	SECRET	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27187	\N	\N	\N
34100	SECRET	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27768	\N	\N	\N
34101	MEMBRE	2020-11-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29221	\N	\N	\N
34247	MEMBRE	2020-12-15 00:00:00	2021-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	29262	\N	\N	\N
34249	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29264	\N	\N	\N
34347	MEMBRE	2020-12-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29284	\N	\N	\N
34348	MEMBRE	2020-12-11 00:00:00	2021-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	29285	\N	\N	\N
34349	MEMBRE	2020-12-11 00:00:00	2021-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	29286	\N	\N	\N
34350	MEMBRE	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29287	\N	\N	\N
34351	MEMBRE	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29288	\N	\N	\N
34352	MEMBRE	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29289	\N	\N	\N
34353	MEMBRE	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29290	\N	\N	\N
34438	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29310	\N	\N	\N
34478	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29342	\N	\N	\N
34535	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29399	\N	\N	\N
34548	MEMBRE	2020-12-15 00:00:00	2021-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	29412	\N	\N	\N
34549	MEMBRE	2020-12-16 00:00:00	2021-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	29413	\N	\N	\N
34550	MEMBRE	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29414	\N	\N	\N
34652	MEMBRE	2020-12-18 00:00:00	2021-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	29510	\N	\N	\N
34944	MEMBRE	2021-01-13 00:00:00	2021-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	29708	\N	\N	\N
35312	MEMBRE	2021-01-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29982	\N	\N	\N
35313	MEMBRE	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29983	\N	\N	\N
35609	VICPDT	2021-02-03 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29945	\N	\N	\N
35800	VICPDT	2021-02-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30179	\N	\N	\N
35813	VICPDT	2021-02-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28390	\N	\N	\N
35814	VICPDT	2021-02-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27367	\N	\N	\N
35815	VICPDT	2021-02-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28936	\N	\N	\N
35816	VICPDT	2021-02-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27755	\N	\N	\N
35817	VICPDT	2021-02-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27651	\N	\N	\N
35818	SECRET	2021-02-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30194	\N	\N	\N
35950	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30252	\N	\N	\N
35979	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30276	\N	\N	\N
36166	VICPDT	2021-10-14 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	27887	\N	\N	\N
36167	SECRET	2021-10-14 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	28464	\N	\N	\N
36272	MEMBRE	2022-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30511	\N	\N	\N
36364	MEMBRE	2022-04-05 00:00:00	2022-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	30591	\N	\N	\N
36365	MEMBRE	2022-04-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30592	\N	\N	\N
36366	MEMBRE	2022-04-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30593	\N	\N	\N
36367	MEMBRE	2022-03-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30594	\N	\N	\N
36459	MEMBRE	2022-09-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30676	\N	\N	\N
36498	MEMBRE	2022-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30715	\N	\N	\N
36805	MEMBRE	2023-10-09 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	30995	\N	\N	\N
36806	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30996	\N	\N	\N
36807	MEMBRE	2023-10-09 00:00:00	2023-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	30997	\N	\N	\N
37291	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31483	\N	\N	\N
37564	MEMBRE	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31756	\N	\N	\N
37565	MEMBRE	2023-10-16 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	31757	\N	\N	\N
37566	MEMBRE	2023-10-16 00:00:00	2024-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	31758	\N	\N	\N
37850	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32042	\N	\N	\N
37851	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32043	\N	\N	\N
37852	MEMBRE	2023-10-18 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	32044	\N	\N	\N
37853	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32045	\N	\N	\N
37956	MEMBRE	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32151	\N	\N	\N
37957	MEMBRE	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32152	\N	\N	\N
37958	MEMBRE	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32153	\N	\N	\N
37959	MEMBRE	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32154	\N	\N	\N
37960	MEMBRE	2023-10-19 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	32155	\N	\N	\N
37961	MEMBRE	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32156	\N	\N	\N
37962	MEMBRE	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32157	\N	\N	\N
37963	MEMBRE	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32158	\N	\N	\N
37964	MEMBRE	2023-10-19 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	32159	\N	\N	\N
38258	MEMBRE	2023-10-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32453	\N	\N	\N
38259	MEMBRE	2023-10-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32454	\N	\N	\N
38260	MEMBRE	2023-10-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32455	\N	\N	\N
38588	MEMBRE	2023-11-08 00:00:00	2024-02-19 00:00:00	ACTIF	\N	\N	\N	\N	32783	\N	\N	\N
38589	MEMBRE	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32784	\N	\N	\N
38590	MEMBRE	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32785	\N	\N	\N
38591	MEMBRE	2023-11-08 00:00:00	2024-01-04 00:00:00	ANCIEN	\N	\N	\N	\N	32786	\N	\N	\N
38592	MEMBRE	2023-11-08 00:00:00	2024-02-26 00:00:00	ACTIF	\N	\N	\N	\N	32787	\N	\N	\N
38593	MEMBRE	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32788	\N	\N	\N
38594	MEMBRE	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32789	\N	\N	\N
38595	MEMBRE	2023-11-08 00:00:00	2024-02-07 00:00:00	ACTIF	\N	\N	\N	\N	32790	\N	\N	\N
38596	MEMBRE	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32791	\N	\N	\N
38597	MEMBRE	2023-11-08 00:00:00	2024-02-08 00:00:00	ACTIF	\N	\N	\N	\N	32792	\N	\N	\N
38598	MEMBRE	2023-11-08 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	32793	\N	\N	\N
30935	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26544	\N	\N	\N
30995	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26589	\N	\N	\N
31010	PDT	2018-02-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	26439	\N	\N	\N
31028	MEMBRE	2018-02-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26609	\N	2018-02-26 17:52:25	\N
31086	VICPDT	2018-03-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25271	\N	2018-03-07 17:12:05	\N
31087	VICPDT	2018-03-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24379	\N	2018-03-07 17:12:24	\N
31088	SECRET	2018-03-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24997	\N	2018-03-07 17:12:31	\N
31422	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26883	\N	\N	\N
31436	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26897	\N	\N	\N
31600	MEMBRE	2019-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25282	\N	\N	\N
31601	PDTDEL	2019-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	Nigéria	\N	24056	\N	\N	\N
31602	PDT	2019-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25281	\N	\N	\N
31665	MEMBRE	2020-05-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27096	\N	\N	\N
33525	MEMBRE	2020-11-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28947	\N	\N	\N
33526	MEMBRE	2020-11-12 00:00:00	2020-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	28948	\N	\N	\N
34634	VICPDTDEL	2020-12-18 00:00:00	2020-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	29492	\N	\N	\N
34694	MEMBRE	2020-12-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	29534	\N	\N	\N
34756	MEMBRE	2020-12-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	29576	\N	\N	\N
34905	MEMBRE	2020-12-18 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	29670	\N	\N	\N
34907	MEMBRE	2020-12-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	29672	\N	\N	\N
34909	MEMBRE	2020-12-18 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	29674	\N	\N	\N
34994	MEMBRE	2021-01-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29742	\N	\N	\N
34995	MEMBRE	2021-01-12 00:00:00	2021-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	29743	\N	\N	\N
35051	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29775	\N	\N	\N
35053	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29777	\N	\N	\N
35054	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29778	\N	\N	\N
35055	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29779	\N	\N	\N
35056	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29780	\N	\N	\N
35057	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29781	\N	\N	\N
35059	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29783	\N	\N	\N
35060	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29784	\N	\N	\N
35100	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29824	\N	\N	\N
35384	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30021	\N	\N	\N
35875	MEMBRE	2021-02-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	30209	\N	\N	\N
35386	MEMBRE	2021-01-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	30023	\N	\N	\N
35387	MEMBRE	2021-01-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	30024	\N	\N	\N
35388	MEMBRE	2021-01-26 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	30025	\N	\N	\N
35389	MEMBRE	2021-01-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	30026	\N	\N	\N
35390	MEMBRE	2021-01-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	30027	\N	\N	\N
35391	MEMBRE	2021-01-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	30028	\N	\N	\N
35392	MEMBRE	2021-01-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	30029	\N	\N	\N
35500	MEMBRE	2021-01-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30066	\N	\N	\N
35512	MEMBRE	2021-01-26 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	30070	\N	\N	\N
35586	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30087	\N	\N	\N
35882	VICPDT	2021-02-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27923	\N	\N	\N
35883	VICPDT	2021-02-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27243	\N	\N	\N
35884	VICPDT	2021-02-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27818	\N	\N	\N
35885	VICPDT	2021-02-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27283	\N	\N	\N
35886	VICPDT	2021-02-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27411	\N	\N	\N
35887	SECRET	2021-02-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27763	\N	\N	\N
35888	VICPDT	2021-02-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27600	\N	\N	\N
35889	VICPDT	2021-02-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29240	\N	\N	\N
35890	VICPDT	2021-02-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27811	\N	\N	\N
35891	VICPDT	2021-02-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27649	\N	\N	\N
35943	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30246	\N	\N	\N
36034	MEMBRE	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30321	\N	\N	\N
36111	PDT	2021-07-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	29258	\N	\N	\N
36112	VICPDT	2021-07-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29488	\N	\N	\N
36116	VICPDT	2021-07-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	30210	\N	\N	\N
36117	VICPDT	2021-07-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	29536	\N	\N	\N
36119	VICPDT	2021-07-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29255	\N	\N	\N
36120	VICPDT	2021-07-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	30377	\N	\N	\N
36134	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30396	\N	\N	\N
36186	MEMBRE	2021-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30438	\N	\N	\N
36187	MEMBRE	2021-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30439	\N	\N	\N
36323	MEMBRE	2022-03-15 00:00:00	2022-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	30550	\N	\N	\N
36352	MEMBRE	2022-04-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30579	\N	\N	\N
36353	MEMBRE	2022-04-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30580	\N	\N	\N
36354	MEMBRE	2022-04-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30581	\N	\N	\N
36460	MEMBRE	2020-11-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30677	\N	\N	\N
36461	MEMBRE	2020-11-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30678	\N	\N	\N
36462	MEMBRE	2020-11-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30679	\N	\N	\N
36463	MEMBRE	2020-11-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30680	\N	\N	\N
36464	MEMBRE	2022-09-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30681	\N	\N	\N
36465	MEMBRE	2022-09-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30682	\N	\N	\N
36466	MEMBRE	2022-09-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30683	\N	\N	\N
36501	MEMBRE	2022-12-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30718	\N	\N	\N
36642	MEMBRE	2023-05-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30840	\N	\N	\N
36672	SECRET	2023-09-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27316	\N	\N	\N
36956	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31146	\N	\N	\N
36957	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31147	\N	\N	\N
36958	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31148	\N	\N	\N
36959	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31149	\N	\N	\N
37296	MEMBRE	2023-10-11 00:00:00	2023-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	31488	\N	\N	\N
37297	MEMBRE	2023-10-11 00:00:00	2024-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	31489	\N	\N	\N
38421	MEMBRE	2023-11-02 00:00:00	2024-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	32616	\N	\N	\N
38422	MEMBRE	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32617	\N	\N	\N
38423	MEMBRE	2023-11-02 00:00:00	2023-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	32618	\N	\N	\N
38442	MEMBRE	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32637	\N	\N	\N
38443	MEMBRE	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32638	\N	\N	\N
38444	MEMBRE	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32639	\N	\N	\N
38445	MEMBRE	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32640	\N	\N	\N
38446	MEMBRE	2023-11-02 00:00:00	2024-02-26 00:00:00	ACTIF	\N	\N	\N	\N	32641	\N	\N	\N
38447	MEMBRE	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32642	\N	\N	\N
38448	MEMBRE	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32643	\N	\N	\N
38449	MEMBRE	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32644	\N	\N	\N
38450	MEMBRE	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32645	\N	\N	\N
39039	PDT	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32422	\N	\N	\N
39040	PDT	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32245	\N	\N	\N
39041	PDTDEL	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour le Congo Brazzaville	\N	30916	\N	\N	\N
39042	PDTDEL	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour Djibouti	\N	31308	\N	\N	\N
39043	PDTDEL	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour l'Equateur	\N	32073	\N	\N	\N
39200	MEMBRE	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33246	\N	\N	\N
39216	MEMBRE	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33260	\N	\N	\N
39228	MEMBRE	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33272	\N	\N	\N
39231	MEMBRE	2023-12-05 00:00:00	2024-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	33275	\N	\N	\N
39232	MEMBRE	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33276	\N	\N	\N
39233	MEMBRE	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33277	\N	\N	\N
39234	MEMBRE	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33278	\N	\N	\N
39235	MEMBRE	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33279	\N	\N	\N
39236	MEMBRE	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33280	\N	\N	\N
39237	MEMBRE	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33281	\N	\N	\N
39238	MEMBRE	2023-12-05 00:00:00	2024-02-07 00:00:00	ACTIF	\N	\N	\N	\N	33282	\N	\N	\N
39239	MEMBRE	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33283	\N	\N	\N
39240	MEMBRE	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33284	\N	\N	\N
39241	MEMBRE	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33285	\N	\N	\N
39242	MEMBRE	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33286	\N	\N	\N
39246	MEMBRE	2023-12-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33290	\N	\N	\N
39253	MEMBRE	2023-12-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33297	\N	\N	\N
39259	MEMBRE	2023-12-06 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	33303	\N	\N	\N
39260	MEMBRE	2023-12-06 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	33304	\N	\N	\N
39261	MEMBRE	2023-12-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33305	\N	\N	\N
39263	MEMBRE	2023-12-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33307	\N	\N	\N
39291	PDTDEL	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour le Burundi	\N	33319	\N	\N	\N
39340	MEMBRE	2023-12-09 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	33323	\N	\N	\N
39349	MEMBRE	2023-12-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33332	\N	\N	\N
39361	MEMBRE	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33344	\N	\N	\N
39362	MEMBRE	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33345	\N	\N	\N
39363	MEMBRE	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33346	\N	\N	\N
39364	MEMBRE	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33347	\N	\N	\N
39366	MEMBRE	2023-12-12 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	33349	\N	\N	\N
39367	MEMBRE	2023-12-12 00:00:00	2024-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	33350	\N	\N	\N
39368	MEMBRE	2023-12-12 00:00:00	2023-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	33351	\N	\N	\N
39384	MEMBRE	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33354	\N	\N	\N
39385	MEMBRE	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33355	\N	\N	\N
39386	MEMBRE	2023-12-12 00:00:00	2024-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	33356	\N	\N	\N
30692	MEMBRE	2017-10-01 00:00:00	2018-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	26393	\N	\N	\N
30798	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26471	\N	\N	\N
30808	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26479	\N	\N	\N
30810	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26481	\N	\N	\N
30811	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26482	\N	\N	\N
30815	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26486	\N	\N	\N
30817	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26488	\N	\N	\N
30818	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26489	\N	\N	\N
30819	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26490	\N	\N	\N
30836	MEMBRE	2017-10-01 00:00:00	2019-08-27 00:00:00	ANCIEN	\N	\N	\N	\N	26507	\N	\N	\N
30838	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26509	\N	\N	\N
30839	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26510	\N	\N	\N
30846	PDT	2018-02-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	26061	\N	\N	\N
30847	VICPDT	2018-02-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26051	\N	\N	\N
30873	VICPDT	2018-02-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24113	\N	2018-02-14 18:31:38	\N
30874	VICPDT	2018-02-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24591	\N	2018-02-14 18:31:51	\N
30875	VICPDT	2018-02-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24561	\N	2018-02-14 18:32:02	\N
30876	VICPDT	2018-02-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23892	\N	2018-02-14 18:32:18	\N
30877	VICPDT	2018-02-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24463	\N	2018-02-14 18:32:29	2018-02-14 18:32:59
30878	SECRET	2018-02-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24803	\N	2018-02-14 18:33:09	\N
30879	SECRET	2018-02-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24875	\N	2018-02-14 18:33:26	2018-02-14 18:33:47
30880	SECRET	2018-02-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25570	\N	2018-02-14 18:34:12	\N
30881	SECRET	2018-02-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24367	\N	2018-02-14 18:34:19	\N
31121	MEMBRE	2018-03-13 00:00:00	2018-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	26645	\N	2018-03-13 17:10:39	2018-03-16 14:48:41
31230	MEMBRE	2017-12-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26724	\N	\N	\N
31461	MEMBRE	2018-11-22 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26922	\N	\N	\N
31467	MEMBRE	2018-11-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	26928	\N	\N	\N
31618	MEMBRE	2019-11-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27053	\N	\N	\N
31630	MEMBRE	2019-12-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	27062	\N	\N	\N
33682	MEMBRE	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29013	\N	\N	\N
33683	MEMBRE	2020-11-18 00:00:00	2023-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	29014	\N	\N	\N
33684	MEMBRE	2020-11-18 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	29015	\N	\N	\N
33947	MEMBRE	2020-12-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29168	\N	\N	\N
34514	MEMBRE	2020-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29378	\N	\N	\N
34843	MEMBRE	2021-01-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	29626	\N	\N	\N
34844	MEMBRE	2021-01-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29627	\N	\N	\N
34846	MEMBRE	2021-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29629	\N	\N	\N
34847	MEMBRE	2021-12-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	29630	\N	\N	\N
34851	MEMBRE	2021-01-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	29634	\N	\N	\N
35013	VICPDT	2021-01-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28640	\N	\N	\N
35014	VICPDT	2021-01-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28142	\N	\N	\N
35015	VICPDT	2021-01-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27644	\N	\N	\N
35016	SECRET	2021-01-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29612	\N	\N	\N
35115	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29839	\N	\N	\N
35117	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29841	\N	\N	\N
35809	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30195	\N	\N	\N
35810	MEMBRE	2020-10-01 00:00:00	2024-04-08 00:00:00	ACTIF	\N	\N	\N	\N	30196	\N	\N	\N
35811	MEMBRE	2020-10-01 00:00:00	2021-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	30197	\N	\N	\N
35812	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30198	\N	\N	\N
35831	SECRET	2021-02-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30113	\N	\N	\N
35961	SECRET	2021-03-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	30261	\N	\N	\N
36031	MEMBRE	2021-04-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30318	\N	\N	\N
36097	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30371	\N	\N	\N
36114	VICPDT	2021-07-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	29639	\N	\N	\N
36520	MEMBRE	2023-01-01 00:00:00	2023-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	30737	\N	\N	\N
36536	MEMBRE	2023-01-01 00:00:00	2023-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	30753	\N	\N	\N
36543	MEMBRE	2023-01-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30760	\N	\N	\N
36555	MEMBRE	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30772	\N	\N	\N
36581	VICPDT	2023-01-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30737	\N	\N	\N
36600	MEMBRE	2023-02-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30806	\N	\N	\N
36619	MEMBRE	2023-04-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30818	\N	\N	\N
36620	MEMBRE	2023-03-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30819	\N	\N	\N
36626	MEMBRE	2023-05-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30825	\N	\N	\N
36754	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30944	\N	\N	\N
36755	MEMBRE	2023-10-09 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	30945	\N	\N	\N
36756	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30946	\N	\N	\N
36757	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30947	\N	\N	\N
36758	MEMBRE	2023-10-09 00:00:00	2023-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	30948	\N	\N	\N
36759	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30949	\N	\N	\N
36760	MEMBRE	2023-10-09 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	30950	\N	\N	\N
36761	MEMBRE	2023-10-09 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	30951	\N	\N	\N
36762	MEMBRE	2023-10-09 00:00:00	2024-01-30 00:00:00	ACTIF	\N	\N	\N	\N	30952	\N	\N	\N
36877	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31067	\N	\N	\N
36878	MEMBRE	2023-10-09 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	31068	\N	\N	\N
36879	MEMBRE	2023-10-09 00:00:00	2024-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	31069	\N	\N	\N
36880	MEMBRE	2023-10-09 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	31070	\N	\N	\N
37242	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31434	\N	\N	\N
37301	MEMBRE	2023-10-11 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	31493	\N	\N	\N
37302	MEMBRE	2023-10-11 00:00:00	2024-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	31494	\N	\N	\N
37303	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31495	\N	\N	\N
37304	MEMBRE	2023-10-11 00:00:00	2024-01-30 00:00:00	ACTIF	\N	\N	\N	\N	31496	\N	\N	\N
37313	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31505	\N	\N	\N
37314	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31506	\N	\N	\N
37315	MEMBRE	2023-10-11 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	31507	\N	\N	\N
37316	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31508	\N	\N	\N
37317	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31509	\N	\N	\N
37318	MEMBRE	2023-10-11 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	31510	\N	\N	\N
37319	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31511	\N	\N	\N
37320	MEMBRE	2023-10-11 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	31512	\N	\N	\N
37321	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31513	\N	\N	\N
37322	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31514	\N	\N	\N
37323	MEMBRE	2023-10-11 00:00:00	2024-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	31515	\N	\N	\N
37324	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31516	\N	\N	\N
37325	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31517	\N	\N	\N
37326	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31518	\N	\N	\N
37327	MEMBRE	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31519	\N	\N	\N
37538	MEMBRE	2023-10-13 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	31730	\N	\N	\N
37539	MEMBRE	2023-10-13 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	31731	\N	\N	\N
37540	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31732	\N	\N	\N
37541	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31733	\N	\N	\N
37542	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31734	\N	\N	\N
37543	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31735	\N	\N	\N
37544	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31736	\N	\N	\N
37545	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31737	\N	\N	\N
37547	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31739	\N	\N	\N
37616	MEMBRE	2023-10-17 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	31808	\N	\N	\N
37617	MEMBRE	2023-10-17 00:00:00	2024-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	31809	\N	\N	\N
37618	MEMBRE	2023-10-17 00:00:00	2023-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	31810	\N	\N	\N
37619	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31811	\N	\N	\N
37620	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31812	\N	\N	\N
38261	MEMBRE	2023-10-30 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	32456	\N	\N	\N
38305	MEMBRE	2023-10-31 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	32500	\N	\N	\N
38599	MEMBRE	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32794	\N	\N	\N
38600	MEMBRE	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32795	\N	\N	\N
38601	MEMBRE	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32796	\N	\N	\N
38602	MEMBRE	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32797	\N	\N	\N
38603	MEMBRE	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32798	\N	\N	\N
38604	MEMBRE	2023-11-08 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	32799	\N	\N	\N
38605	MEMBRE	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32800	\N	\N	\N
38636	MEMBRE	2023-11-09 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	32831	\N	\N	\N
38665	MEMBRE	2023-11-12 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	32860	\N	\N	\N
38666	MEMBRE	2023-11-12 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	32861	\N	\N	\N
38667	MEMBRE	2023-11-12 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	32862	\N	\N	\N
38668	MEMBRE	2023-11-12 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	32863	\N	\N	\N
38669	MEMBRE	2023-11-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32864	\N	\N	\N
38670	MEMBRE	2023-11-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32865	\N	\N	\N
38671	MEMBRE	2023-11-12 00:00:00	2024-03-24 00:00:00	ACTIF	\N	\N	\N	\N	32866	\N	\N	\N
38672	MEMBRE	2023-11-12 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	32867	\N	\N	\N
38673	MEMBRE	2023-11-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32868	\N	\N	\N
38878	MEMBRE	2023-11-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33073	\N	\N	\N
39126	MEMBRE	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33172	\N	\N	\N
39190	MEMBRE	2023-12-04 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	33235	\N	\N	\N
39194	MEMBRE	2023-12-04 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33239	\N	\N	\N
39393	MEMBRE	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33363	\N	\N	\N
39636	VICPDT	2023-12-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30969	\N	\N	\N
30699	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26400	\N	\N	\N
30700	MEMBRE	2017-10-01 00:00:00	2018-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	26401	\N	\N	2018-04-13 17:54:29
31004	MEMBRE	2017-10-01 00:00:00	2018-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	26591	\N	\N	\N
31020	MEMBRE	2018-02-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26601	\N	2018-02-23 14:28:51	\N
31237	MEMBRE	2017-12-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26731	\N	\N	\N
31305	MEMBRE	2018-05-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26774	\N	2018-06-06 12:36:46	\N
31477	MEMBRE	2018-12-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26935	\N	\N	\N
31511	VICPDTDRT	2019-02-11 00:00:00	2019-03-12 00:00:00	ANCIEN	\N	\N	\N	\N	25999	\N	\N	\N
32406	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27835	\N	\N	\N
32407	MEMBRE	2020-10-14 00:00:00	2020-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	27836	\N	\N	\N
32408	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27837	\N	\N	\N
32409	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27838	\N	\N	\N
32410	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27839	\N	\N	\N
32411	MEMBRE	2020-10-14 00:00:00	2021-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	27840	\N	\N	\N
32412	MEMBRE	2020-10-14 00:00:00	2021-01-14 00:00:00	ANCIEN	\N	\N	\N	\N	27841	\N	\N	\N
32413	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27842	\N	\N	\N
32414	MEMBRE	2020-10-14 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	27843	\N	\N	\N
32415	MEMBRE	2020-10-14 00:00:00	2020-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	27844	\N	\N	\N
32416	MEMBRE	2020-10-14 00:00:00	2020-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	27845	\N	\N	\N
32417	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27846	\N	\N	\N
32418	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27847	\N	\N	\N
32419	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27848	\N	\N	\N
32420	MEMBRE	2020-10-14 00:00:00	2020-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	27849	\N	\N	\N
32421	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27850	\N	\N	\N
32422	MEMBRE	2020-10-14 00:00:00	2021-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	27851	\N	\N	\N
32423	MEMBRE	2020-10-14 00:00:00	2021-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	27852	\N	\N	\N
32424	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27853	\N	\N	\N
32425	MEMBRE	2020-10-14 00:00:00	2020-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	27854	\N	\N	\N
32426	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27855	\N	\N	\N
32427	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27856	\N	\N	\N
32428	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27857	\N	\N	\N
32429	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27858	\N	\N	\N
32430	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27859	\N	\N	\N
32431	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27860	\N	\N	\N
32432	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27861	\N	\N	\N
32433	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27862	\N	\N	\N
32434	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27863	\N	\N	\N
32435	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27864	\N	\N	\N
32436	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27865	\N	\N	\N
32437	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27866	\N	\N	\N
32438	MEMBRE	2020-10-14 00:00:00	2022-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	27867	\N	\N	\N
32439	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27868	\N	\N	\N
32440	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27869	\N	\N	\N
32441	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27870	\N	\N	\N
32442	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27871	\N	\N	\N
32443	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27872	\N	\N	\N
32444	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27873	\N	\N	\N
32445	MEMBRE	2020-10-08 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	27874	\N	\N	\N
32446	MEMBRE	2020-10-08 00:00:00	2021-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	27875	\N	\N	\N
32447	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27876	\N	\N	\N
32448	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27877	\N	\N	\N
32449	MEMBRE	2020-10-14 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	27878	\N	\N	\N
32450	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27879	\N	\N	\N
32451	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27880	\N	\N	\N
32472	MEMBRE	2020-10-19 00:00:00	2021-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	27901	\N	\N	\N
32473	MEMBRE	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27902	\N	\N	\N
32474	MEMBRE	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27903	\N	\N	\N
32475	MEMBRE	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27904	\N	\N	\N
32476	MEMBRE	2020-10-19 00:00:00	2023-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	27905	\N	\N	\N
32477	MEMBRE	2020-10-19 00:00:00	2021-01-21 00:00:00	ANCIEN	\N	\N	\N	\N	27906	\N	\N	\N
32478	MEMBRE	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27907	\N	\N	\N
32479	MEMBRE	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27908	\N	\N	\N
32480	MEMBRE	2020-10-19 00:00:00	2021-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	27909	\N	\N	\N
32481	MEMBRE	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27910	\N	\N	\N
32482	MEMBRE	2020-10-19 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	27911	\N	\N	\N
32483	MEMBRE	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27912	\N	\N	\N
32484	MEMBRE	2020-10-19 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	27913	\N	\N	\N
32485	MEMBRE	2020-10-19 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	27914	\N	\N	\N
32486	MEMBRE	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27915	\N	\N	\N
32487	MEMBRE	2020-10-19 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	27916	\N	\N	\N
32488	MEMBRE	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27917	\N	\N	\N
32489	MEMBRE	2020-10-19 00:00:00	2020-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	27918	\N	\N	\N
32490	MEMBRE	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27919	\N	\N	\N
32491	MEMBRE	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27920	\N	\N	\N
32492	MEMBRE	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27921	\N	\N	\N
32493	MEMBRE	2020-10-19 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	27922	\N	\N	\N
32494	MEMBRE	2020-10-19 00:00:00	2021-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	27923	\N	\N	\N
32495	MEMBRE	2020-10-19 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	27924	\N	\N	\N
32496	MEMBRE	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27925	\N	\N	\N
32497	MEMBRE	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27926	\N	\N	\N
32498	MEMBRE	2020-10-19 00:00:00	2021-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	27927	\N	\N	\N
32499	MEMBRE	2020-10-19 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	27928	\N	\N	\N
32500	MEMBRE	2020-10-19 00:00:00	2020-12-23 00:00:00	ANCIEN	\N	\N	\N	\N	27929	\N	\N	\N
32501	MEMBRE	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27930	\N	\N	\N
32502	MEMBRE	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27931	\N	\N	\N
32503	MEMBRE	2020-10-19 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	27932	\N	\N	\N
32504	MEMBRE	2020-10-19 00:00:00	2021-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	27933	\N	\N	\N
32505	MEMBRE	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27934	\N	\N	\N
32506	MEMBRE	2020-10-19 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	27935	\N	\N	\N
32507	MEMBRE	2020-10-19 00:00:00	2021-03-04 00:00:00	ANCIEN	\N	\N	\N	\N	27936	\N	\N	\N
32508	MEMBRE	2020-10-19 00:00:00	2020-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	27937	\N	\N	\N
32509	MEMBRE	2020-10-19 00:00:00	2020-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	27938	\N	\N	\N
33064	MEMBRE	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28497	\N	\N	\N
33065	MEMBRE	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28498	\N	\N	\N
33527	MEMBRE	2020-11-13 00:00:00	2020-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	28949	\N	\N	\N
33560	MEMBRE	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28977	\N	\N	\N
33561	MEMBRE	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28978	\N	\N	\N
33562	MEMBRE	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28979	\N	\N	\N
33563	MEMBRE	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28980	\N	\N	\N
34233	MEMBRE	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29248	\N	\N	\N
34234	MEMBRE	2020-12-15 00:00:00	2021-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	29249	\N	\N	\N
34235	MEMBRE	2020-12-15 00:00:00	2021-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	29250	\N	\N	\N
34236	MEMBRE	2020-12-15 00:00:00	2021-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	29251	\N	\N	\N
34238	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29253	\N	\N	\N
34239	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29254	\N	\N	\N
34240	MEMBRE	2020-10-01 00:00:00	2021-07-20 00:00:00	ANCIEN	\N	\N	\N	\N	29255	\N	\N	\N
34241	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29256	\N	\N	\N
34242	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29257	\N	\N	\N
34243	MEMBRE	2020-12-15 00:00:00	2021-07-20 00:00:00	ANCIEN	\N	\N	\N	\N	29258	\N	\N	\N
34244	MEMBRE	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29259	\N	\N	\N
34516	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29380	\N	\N	\N
34855	MEMBRE	2021-01-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	29638	\N	\N	\N
34856	MEMBRE	2021-01-07 00:00:00	2021-07-20 00:00:00	ANCIEN	\N	\N	\N	\N	29639	\N	\N	\N
34935	MEMBRE	2021-01-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	29699	\N	\N	\N
34936	MEMBRE	2021-01-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	29700	\N	\N	\N
34959	MEMBRE	2021-01-13 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	29715	\N	\N	\N
34989	MEMBRE	2021-01-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29737	\N	\N	\N
35019	MEMBRE	2021-01-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	29763	\N	\N	\N
35216	MEMBRE	2021-01-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	29940	\N	\N	\N
35355	VICPDT	2021-01-26 00:00:00	2021-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	29726	\N	\N	\N
35489	VICPDT	2021-01-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27265	\N	\N	\N
35490	VICPDT	2021-01-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28247	\N	\N	\N
35491	VICPDT	2021-01-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28425	\N	\N	\N
35492	VICPDT	2021-01-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28295	\N	\N	\N
35493	VICPDT	2021-01-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28163	\N	\N	\N
35494	VICPDT	2021-01-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28329	\N	\N	\N
35495	SECRET	2021-01-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28318	\N	\N	\N
35497	VICPDT	2021-01-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28389	\N	\N	\N
35498	SECRET	2021-01-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27467	\N	\N	\N
35499	VICPDT	2021-01-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27116	\N	\N	\N
35581	VICPDT	2021-01-27 00:00:00	2022-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	29607	\N	\N	\N
35795	VICPDT	2021-02-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	30184	\N	\N	\N
35850	VICPDT	2021-02-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29960	\N	\N	\N
35912	MEMBRE	2021-03-10 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30224	\N	\N	\N
35967	VICPDT	2021-03-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	30266	\N	\N	\N
35946	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	30249	\N	\N	\N
35957	MEMBRE	2020-10-01 00:00:00	2021-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	30259	\N	\N	\N
36065	MEMBRE	2021-06-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30346	\N	\N	\N
30870	MEMBRE	2018-02-07 00:00:00	2018-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	26517	\N	2018-02-14 15:16:52	2018-03-16 14:49:33
30882	MEMBRE	2017-10-01 00:00:00	2018-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	26518	\N	\N	\N
30885	MEMBRE	2017-10-01 00:00:00	2018-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	26521	\N	\N	\N
31075	PDT	2018-03-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26388	\N	\N	\N
31076	VICPDT	2018-03-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26396	\N	\N	\N
31077	VICPDT	2018-03-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26594	\N	\N	\N
31079	VICPDT	2018-03-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26393	\N	\N	\N
31081	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26619	\N	\N	\N
31176	MEMBRE	2017-12-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26700	\N	\N	\N
31382	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26844	\N	\N	\N
31583	MEMBRE	2019-07-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	27027	\N	\N	\N
31662	MEMBRE	2019-11-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	27093	\N	\N	\N
31598	PDT	2019-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25077	\N	\N	\N
31609	MEMBRE	2019-10-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	27044	\N	\N	\N
34237	MEMBRE	2020-12-15 00:00:00	2021-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	29252	\N	\N	\N
34245	MEMBRE	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	29260	\N	\N	\N
34580	MEMBRE	2020-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29444	\N	\N	\N
34581	MEMBRE	2020-12-16 00:00:00	2021-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	29445	\N	\N	\N
34582	MEMBRE	2020-12-16 00:00:00	2021-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	29446	\N	\N	\N
34698	MEMBRE	2020-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	29538	\N	\N	\N
35062	MEMBRE	2020-10-01 00:00:00	2021-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	29786	\N	\N	\N
35063	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29787	\N	\N	\N
35064	MEMBRE	2020-10-01 00:00:00	2021-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	29788	\N	\N	\N
35065	MEMBRE	2020-10-01 00:00:00	2021-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	29789	\N	\N	\N
35066	MEMBRE	2020-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	29790	\N	\N	\N
35623	MEMBRE	2021-02-03 00:00:00	2021-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	30108	\N	\N	\N
35624	MEMBRE	2021-02-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	30109	\N	\N	\N
35625	MEMBRE	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30110	\N	\N	\N
35627	MEMBRE	2021-02-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	30112	\N	\N	\N
35628	MEMBRE	2021-02-03 00:00:00	2021-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	30113	\N	\N	\N
35645	MEMBRE	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30130	\N	\N	\N
35796	VICPDT	2021-02-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30183	\N	\N	\N
35797	VICPDT	2021-02-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	30171	\N	\N	\N
36287	MEMBRE	2022-02-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30522	\N	\N	\N
36394	MEMBRE	2022-04-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30613	\N	\N	\N
36472	MEMBRE	2022-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30689	\N	\N	\N
36473	MEMBRE	2022-09-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30690	\N	\N	\N
36479	MEMBRE	2022-10-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30696	\N	\N	\N
36480	MEMBRE	2022-10-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30697	\N	\N	\N
36487	MEMBRE	2022-11-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30704	\N	\N	\N
36552	MEMBRE	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30769	\N	\N	\N
36583	VICPDT	2023-01-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30728	\N	\N	\N
38548	MEMBRE	2023-11-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32743	\N	\N	\N
38549	MEMBRE	2023-11-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32744	\N	\N	\N
38723	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32918	\N	\N	\N
38724	MEMBRE	2023-11-15 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	32919	\N	\N	\N
38725	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32920	\N	\N	\N
38744	MEMBRE	2023-11-15 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	32939	\N	\N	\N
38745	MEMBRE	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32940	\N	\N	\N
38746	MEMBRE	2023-11-15 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	32941	\N	\N	\N
38747	MEMBRE	2023-11-15 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	32942	\N	\N	\N
38748	MEMBRE	2023-11-15 00:00:00	2024-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	32943	\N	\N	\N
38876	MEMBRE	2023-11-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33071	\N	\N	\N
39254	MEMBRE	2023-12-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33298	\N	\N	\N
39637	VICPDT	2023-12-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30948	\N	\N	\N
39638	VICPDT	2023-12-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31404	\N	\N	\N
39639	VICPDT	2023-12-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31944	\N	\N	\N
39640	VICPDT	2023-12-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31810	\N	\N	\N
39641	VICPDT	2023-12-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33150	\N	\N	\N
39642	VICPDT	2023-12-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33351	\N	\N	\N
39643	VICPDT	2023-12-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32701	\N	\N	\N
39644	VICPDT	2023-12-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32655	\N	\N	\N
39645	VICPDT	2023-12-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32547	\N	\N	\N
39646	SECRET	2023-12-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30884	\N	\N	\N
39658	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33411	\N	\N	\N
39660	MEMBRE	2023-12-22 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33413	\N	\N	\N
39662	MEMBRE	2023-12-22 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33414	\N	\N	\N
39669	MEMBRE	2023-12-22 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33417	\N	\N	\N
39685	MEMBRE	2023-12-22 00:00:00	2024-02-05 00:00:00	ACTIF	\N	\N	\N	\N	30832	\N	\N	\N
39686	MEMBRE	2023-10-01 00:00:00	2024-02-05 00:00:00	ACTIF	\N	\N	\N	\N	33426	\N	\N	\N
39687	MEMBRE	2023-10-01 00:00:00	2024-02-05 00:00:00	ACTIF	\N	\N	\N	\N	33427	\N	\N	\N
39688	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33428	\N	\N	\N
39774	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33460	\N	\N	\N
39789	VICPDT	2024-01-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31335	\N	\N	\N
39790	VICPDT	2024-01-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31525	\N	\N	\N
39791	VICPDT	2024-01-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31890	\N	\N	\N
39792	VICPDT	2024-01-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31489	\N	\N	\N
39793	VICPDT	2024-01-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31758	\N	\N	\N
39794	VICPDT	2024-01-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32499	\N	\N	\N
39795	SECRET	2024-01-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32616	\N	\N	\N
39796	SECRET	2024-01-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32667	\N	\N	\N
39820	MEMBRE	2024-01-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33488	\N	\N	\N
39831	MEMBRE	2024-01-15 00:00:00	2024-01-29 00:00:00	ACTIF	\N	\N	\N	\N	33499	\N	\N	\N
39832	MEMBRE	2024-01-15 00:00:00	2024-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	33500	\N	\N	\N
39835	MEMBRE	2024-01-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33503	\N	\N	\N
39918	MEMBRE	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33533	\N	\N	\N
40010	MEMBRE	2024-01-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33589	\N	\N	\N
40020	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33597	\N	\N	\N
40034	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33611	\N	\N	\N
40035	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33612	\N	\N	\N
40086	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33663	\N	\N	\N
40087	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33664	\N	\N	\N
40088	MEMBRE	2023-12-14 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	33665	\N	\N	\N
40106	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33681	\N	\N	\N
40113	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33687	\N	\N	\N
40124	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33697	\N	\N	\N
40125	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33698	\N	\N	\N
40181	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33710	\N	\N	\N
40134	MEMBRE	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33702	\N	\N	\N
40182	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33711	\N	\N	\N
40183	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33712	\N	\N	\N
40185	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33714	\N	\N	\N
40186	MEMBRE	2023-10-01 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	33715	\N	\N	\N
40188	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33717	\N	\N	\N
40189	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33718	\N	\N	\N
40190	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33719	\N	\N	\N
40191	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33720	\N	\N	\N
40192	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33721	\N	\N	\N
40193	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33722	\N	\N	\N
40194	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33723	\N	\N	\N
40198	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33727	\N	\N	\N
40200	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33729	\N	\N	\N
40203	MEMBRE	2023-10-01 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	33732	\N	\N	\N
40295	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33824	\N	\N	\N
40297	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33826	\N	\N	\N
40301	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	30750	\N	\N	\N
40302	MEMBRE	2024-01-02 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	30752	\N	\N	\N
40309	MEMBRE	2024-01-02 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	30787	\N	\N	\N
40327	MEMBRE	2024-01-22 00:00:00	2024-01-22 00:00:00	ACTIF	\N	\N	\N	\N	30203	\N	\N	\N
40330	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	30755	\N	\N	\N
40336	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	30754	\N	\N	\N
40337	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	30739	\N	\N	\N
40340	MEMBRE	2024-01-22 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33836	\N	\N	\N
40433	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33906	\N	\N	\N
40434	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33907	\N	\N	\N
40435	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33908	\N	\N	\N
40436	MEMBRE	2023-10-01 00:00:00	2024-02-13 00:00:00	ACTIF	\N	\N	\N	\N	33909	\N	\N	\N
40444	MEMBRE	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	\N	33917	\N	\N	\N
40455	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33928	\N	\N	\N
40456	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33929	\N	\N	\N
40458	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33931	\N	\N	\N
40459	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33932	\N	\N	\N
40461	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33934	\N	\N	\N
40463	MEMBRE	2023-10-01 00:00:00	2024-02-13 00:00:00	ACTIF	\N	\N	\N	\N	33936	\N	\N	\N
40466	MEMBRE	2023-10-01 00:00:00	2024-02-13 00:00:00	ACTIF	\N	\N	\N	\N	33939	\N	\N	\N
40467	MEMBRE	2023-10-01 00:00:00	2024-02-13 00:00:00	ACTIF	\N	\N	\N	\N	33940	\N	\N	\N
40468	MEMBRE	2023-12-14 00:00:00	2024-02-14 00:00:00	ACTIF	\N	\N	\N	\N	33941	\N	\N	\N
40469	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33942	\N	\N	\N
40472	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33945	\N	\N	\N
40473	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33946	\N	\N	\N
40474	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33947	\N	\N	\N
40476	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33949	\N	\N	\N
40487	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33960	\N	\N	\N
40495	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33968	\N	\N	\N
40498	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33971	\N	\N	\N
40501	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33974	\N	\N	\N
40502	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33975	\N	\N	\N
40503	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33976	\N	\N	\N
40504	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33977	\N	\N	\N
40505	MEMBRE	2023-12-14 00:00:00	2024-02-05 00:00:00	ACTIF	\N	\N	\N	\N	33978	\N	\N	\N
40506	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33979	\N	\N	\N
40507	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33980	\N	\N	\N
40513	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33986	\N	\N	\N
40514	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33987	\N	\N	\N
40515	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33988	\N	\N	\N
40516	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33989	\N	\N	\N
30684	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26385	\N	\N	\N
30685	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26386	\N	\N	\N
30686	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26387	\N	\N	\N
30688	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26389	\N	\N	\N
30693	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26394	\N	\N	\N
30694	MEMBRE	2017-10-01 00:00:00	2018-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	26395	\N	\N	\N
30695	MEMBRE	2017-10-01 00:00:00	2018-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	26396	\N	\N	\N
30716	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26417	\N	\N	\N
30795	MEMBRE	2017-10-01 00:00:00	2018-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	26468	\N	\N	\N
30837	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26508	\N	\N	\N
30842	MEMBRE	2017-10-01 00:00:00	2018-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	26513	\N	\N	\N
30964	MEMBRE	2017-10-01 00:00:00	2018-03-07 00:00:00	ANCIEN	\N	\N	\N	\N	26558	\N	\N	\N
30965	MEMBRE	2017-10-01 00:00:00	2018-03-07 00:00:00	ANCIEN	\N	\N	\N	\N	26559	\N	\N	\N
30983	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26577	\N	\N	\N
31120	MEMBRE	2017-12-07 00:00:00	2018-04-02 00:00:00	ANCIEN	\N	\N	\N	\N	26644	\N	\N	\N
31252	VICPDT	2018-04-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	26644	\N	\N	\N
31253	VICPDT	2018-04-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25743	\N	\N	\N
31269	MEMBRE	2017-04-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	26754	\N	\N	\N
31376	MEMBRE	2018-10-04 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26838	\N	\N	\N
31383	MEMBRE	2018-10-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26845	\N	\N	\N
31384	MEMBRE	2018-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26846	\N	\N	\N
31538	MEMBRE	2018-10-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	26990	\N	\N	\N
31561	MEMBRE	2019-04-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27008	\N	\N	\N
31562	MEMBRE	2018-01-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	27009	\N	\N	\N
31571	MEMBRE	2019-05-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	27018	\N	\N	\N
31636	MEMBRE	2020-01-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27068	\N	\N	\N
31797	MEMBRE	2020-10-08 00:00:00	2023-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	27226	\N	\N	\N
31798	MEMBRE	2020-10-08 00:00:00	2023-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	27227	\N	\N	\N
31799	MEMBRE	2020-10-08 00:00:00	2023-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	27228	\N	\N	\N
31800	MEMBRE	2020-10-08 00:00:00	2023-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	27229	\N	\N	\N
31801	MEMBRE	2020-10-08 00:00:00	2020-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	27230	\N	\N	\N
31802	MEMBRE	2020-10-08 00:00:00	2021-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	27231	\N	\N	\N
31803	MEMBRE	2020-10-08 00:00:00	2021-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	27232	\N	\N	\N
31804	MEMBRE	2020-10-08 00:00:00	2021-01-03 00:00:00	ANCIEN	\N	\N	\N	\N	27233	\N	\N	\N
31805	MEMBRE	2020-10-08 00:00:00	2023-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	27234	\N	\N	\N
31806	MEMBRE	2020-10-08 00:00:00	2020-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	27235	\N	\N	\N
31807	MEMBRE	2020-10-08 00:00:00	2023-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	27236	\N	\N	\N
31808	MEMBRE	2020-10-08 00:00:00	2023-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	27237	\N	\N	\N
31809	MEMBRE	2020-10-08 00:00:00	2023-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	27238	\N	\N	\N
31810	MEMBRE	2020-10-08 00:00:00	2020-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	27239	\N	\N	\N
31811	MEMBRE	2020-10-08 00:00:00	2021-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	27240	\N	\N	\N
31812	MEMBRE	2020-10-08 00:00:00	2023-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	27241	\N	\N	\N
31813	MEMBRE	2020-10-08 00:00:00	2021-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	27242	\N	\N	\N
31814	MEMBRE	2020-10-08 00:00:00	2021-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	27243	\N	\N	\N
31815	MEMBRE	2020-10-08 00:00:00	2023-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	27244	\N	\N	\N
31816	MEMBRE	2020-10-08 00:00:00	2023-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	27245	\N	\N	\N
31817	MEMBRE	2020-10-08 00:00:00	2023-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	27246	\N	\N	\N
33442	MEMBRE	2020-11-04 00:00:00	2020-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	28864	\N	\N	\N
33443	MEMBRE	2020-11-03 00:00:00	2020-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	28865	\N	\N	\N
33444	MEMBRE	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28866	\N	\N	\N
33445	MEMBRE	2020-11-03 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	28867	\N	\N	\N
33707	MEMBRE	2020-11-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29022	\N	\N	\N
34620	MEMBRE	2020-12-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	29479	\N	\N	\N
33709	PDT	2020-11-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29023	\N	\N	\N
33710	MEMBRE	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29024	\N	\N	\N
34649	MEMBRE	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29507	\N	\N	\N
34683	MEMBRE	2020-12-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	29523	\N	\N	\N
34726	MEMBRE	2020-12-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	29566	\N	\N	\N
34748	MEMBRE	2020-12-09 00:00:00	2021-01-11 00:00:00	ANCIEN	\N	\N	\N	\N	29568	\N	\N	\N
34809	VICPDT	2021-01-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28852	\N	\N	\N
34810	VICPDT	2021-01-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27801	\N	\N	\N
34811	VICPDT	2021-01-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28539	\N	\N	\N
34812	VICPDT	2021-01-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27753	\N	\N	\N
34813	SECRET	2021-01-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27262	\N	\N	\N
34814	SECRET	2021-01-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27820	\N	\N	\N
34828	MEMBRE	2021-01-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29611	\N	\N	\N
34829	MEMBRE	2021-01-06 00:00:00	2021-01-14 00:00:00	ANCIEN	\N	\N	\N	\N	29612	\N	\N	\N
34974	MEMBRE	2021-01-14 00:00:00	2021-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	29730	\N	\N	\N
35096	MEMBRE	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29820	\N	\N	\N
36040	VICPDT	2021-04-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30289	\N	\N	\N
36115	VICPDT	2021-07-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	29469	\N	\N	\N
36147	MEMBRE	2021-10-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30409	\N	\N	\N
36148	MEMBRE	2021-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30410	\N	\N	\N
36211	MEMBRE	2021-10-28 00:00:00	2023-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	30457	\N	\N	\N
36436	MEMBRE	2022-07-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	30653	\N	\N	\N
36488	MEMBRE	2022-11-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30705	\N	\N	\N
36802	MEMBRE	2023-10-09 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	30992	\N	\N	\N
36803	MEMBRE	2023-10-09 00:00:00	2024-02-29 00:00:00	ACTIF	\N	\N	\N	\N	30993	\N	\N	\N
36804	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30994	\N	\N	\N
37124	MEMBRE	2023-10-10 00:00:00	2024-02-07 00:00:00	ACTIF	\N	\N	\N	\N	31315	\N	\N	\N
37125	MEMBRE	2023-10-10 00:00:00	2023-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	31316	\N	\N	\N
37126	MEMBRE	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31317	\N	\N	\N
37507	MEMBRE	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31699	\N	\N	\N
37793	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31985	\N	\N	\N
37794	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31986	\N	\N	\N
38237	MEMBRE	2023-10-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32432	\N	\N	\N
38313	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32508	\N	\N	\N
38314	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32509	\N	\N	\N
38315	MEMBRE	2023-10-31 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	32510	\N	\N	\N
38316	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32511	\N	\N	\N
38317	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32512	\N	\N	\N
38328	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32523	\N	\N	\N
38330	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32525	\N	\N	\N
38424	MEMBRE	2023-11-02 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	32619	\N	\N	\N
38425	MEMBRE	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32620	\N	\N	\N
38426	MEMBRE	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32621	\N	\N	\N
38427	MEMBRE	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32622	\N	\N	\N
38428	MEMBRE	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32623	\N	\N	\N
38429	MEMBRE	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32624	\N	\N	\N
38617	MEMBRE	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32812	\N	\N	\N
38618	MEMBRE	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32813	\N	\N	\N
38619	MEMBRE	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32814	\N	\N	\N
38620	MEMBRE	2023-11-08 00:00:00	2024-02-05 00:00:00	ACTIF	\N	\N	\N	\N	32815	\N	\N	\N
38623	MEMBRE	2023-11-08 00:00:00	2024-04-02 00:00:00	ACTIF	\N	\N	\N	\N	32818	\N	\N	\N
38843	MEMBRE	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33038	\N	\N	\N
38847	MEMBRE	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33042	\N	\N	\N
38848	MEMBRE	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33043	\N	\N	\N
38917	MEMBRE	2023-11-21 00:00:00	2024-04-02 00:00:00	ACTIF	\N	\N	\N	\N	33104	\N	\N	\N
39037	MEMBRE	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33163	\N	\N	\N
39069	PDTDEL	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour l'Ouzbékistan	\N	33164	\N	\N	\N
39173	MEMBRE	2023-11-30 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	33218	\N	\N	\N
39174	MEMBRE	2023-11-30 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	33219	\N	\N	\N
39206	MEMBRE	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33252	\N	\N	\N
39211	PDTDEL	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour la Côte d'Ivoire	\N	31353	\N	\N	\N
39212	PDTDEL	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	pour le Kosovo	\N	33220	\N	\N	\N
39258	MEMBRE	2023-12-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33302	\N	\N	\N
39262	MEMBRE	2023-12-06 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	33306	\N	\N	\N
39341	MEMBRE	2023-12-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33324	\N	\N	\N
39387	MEMBRE	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33357	\N	\N	\N
39388	MEMBRE	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33358	\N	\N	\N
39389	MEMBRE	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33359	\N	\N	\N
39390	MEMBRE	2023-12-12 00:00:00	2024-02-08 00:00:00	ACTIF	\N	\N	\N	\N	33360	\N	\N	\N
39391	MEMBRE	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33361	\N	\N	\N
39392	MEMBRE	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33362	\N	\N	\N
39446	MEMBRE	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33372	\N	\N	\N
39447	MEMBRE	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33373	\N	\N	\N
39451	MEMBRE	2023-12-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33377	\N	\N	\N
39452	MEMBRE	2023-12-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33378	\N	\N	\N
39453	MEMBRE	2023-12-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33379	\N	\N	\N
39454	MEMBRE	2023-12-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33380	\N	\N	\N
39472	MEMBRE	2023-12-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33382	\N	\N	\N
39504	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32393	\N	\N	\N
39502	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31181	\N	\N	\N
39503	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33269	\N	\N	\N
39505	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32535	\N	\N	\N
39506	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32575	\N	\N	\N
39507	VICPDT	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32192	\N	\N	\N
30843	MEMBRE	2017-10-01 00:00:00	2018-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	26514	\N	\N	\N
30936	MEMBRE	2018-02-14 00:00:00	2018-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	26545	\N	2018-02-16 09:29:16	2018-03-16 14:49:12
31034	VICPDT	2018-03-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24732	\N	2018-03-05 17:04:07	\N
31035	SECRET	2018-03-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26152	\N	2018-03-05 17:04:50	\N
31036	VICPDT	2018-03-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24557	\N	2018-03-05 17:17:22	\N
31037	VICPDT	2018-03-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25590	\N	2018-03-05 17:17:41	\N
31038	VICPDT	2018-03-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24887	\N	2018-03-05 17:18:00	\N
31039	VICPDT	2018-03-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24478	\N	2018-03-05 17:18:09	\N
31040	VICPDT	2018-03-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25430	\N	2018-03-05 17:18:20	\N
31041	VICPDT	2018-03-05 00:00:00	2019-03-08 00:00:00	ANCIEN	\N	\N	\N	\N	24659	\N	2018-03-05 17:18:35	\N
31042	SECRET	2018-03-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24383	\N	2018-03-05 17:19:03	\N
31043	SECRET	2018-03-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24233	\N	2018-03-05 17:19:09	\N
31044	SECRET	2018-03-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24866	\N	2018-03-05 17:19:13	\N
31045	SECRET	2018-03-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	25565	\N	2018-03-05 17:19:18	\N
31046	VICPDT	2018-03-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24928	\N	2018-03-05 17:57:44	\N
31047	VICPDT	2018-03-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24032	\N	2018-03-05 17:57:52	\N
31048	VICPDT	2018-03-05 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	24500	\N	2018-03-05 17:57:58	\N
31049	VICPDT	2018-03-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24824	\N	2018-03-05 17:58:05	\N
31050	VICPDT	2018-03-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	25216	\N	2018-03-05 17:58:12	\N
31051	VICPDT	2018-03-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	23986	\N	2018-03-05 17:58:20	\N
31052	SECRET	2018-03-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24576	\N	2018-03-05 17:58:42	\N
31053	PDTHON	2018-03-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24648	\N	2018-03-05 18:14:23	\N
31054	VICPDT	2018-03-05 00:00:00	2019-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	25489	\N	2018-03-05 18:14:52	\N
31055	VICPDT	2018-03-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24568	\N	2018-03-05 18:15:24	\N
31056	VICPDT	2018-03-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	24584	\N	2018-03-05 18:15:32	\N
31057	SECRET	2018-03-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24793	\N	2018-03-05 18:15:44	\N
31058	VICPDT	2018-03-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	24697	\N	2018-03-05 18:15:52	\N
31059	SECRET	2018-03-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26228	\N	2018-03-05 18:16:05	\N
31060	SECRET	2018-03-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	23984	\N	2018-03-05 18:16:14	\N
31424	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26885	\N	\N	\N
31480	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26937	\N	\N	\N
31530	MEMBRE	2019-02-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	26982	\N	\N	\N
31668	MEMBRE	2020-07-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27099	\N	\N	\N
34825	MEMBRE	2021-01-04 00:00:00	2022-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	29608	\N	\N	\N
34992	MEMBRE	2021-01-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29740	\N	\N	\N
35008	MEMBRE	2021-01-14 00:00:00	2021-01-14 00:00:00	ANCIEN	\N	\N	\N	\N	29756	\N	\N	\N
35323	MEMBRE	2021-01-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	29986	\N	\N	\N
35325	MEMBRE	2021-01-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	29988	\N	\N	\N
35326	MEMBRE	2021-01-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	29989	\N	\N	\N
35531	SECRET	2021-01-13 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29644	\N	\N	\N
35584	VICPDT	2021-01-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30059	\N	\N	\N
36059	MEMBRE	2021-06-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	30340	\N	\N	\N
36240	MEMBRE	2021-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30485	\N	\N	\N
36241	MEMBRE	2021-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30486	\N	\N	\N
36340	MEMBRE	2022-03-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30567	\N	\N	\N
36341	MEMBRE	2022-03-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30568	\N	\N	\N
36342	MEMBRE	2022-04-01 00:00:00	2022-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	30569	\N	\N	\N
36343	MEMBRE	2022-03-30 00:00:00	2022-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	30570	\N	\N	\N
36613	MEMBRE	2023-03-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30812	\N	\N	\N
36614	MEMBRE	2023-03-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30813	\N	\N	\N
36615	MEMBRE	2023-03-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30814	\N	\N	\N
37378	MEMBRE	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31570	\N	\N	\N
37379	MEMBRE	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31571	\N	\N	\N
37380	MEMBRE	2023-10-12 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	31572	\N	\N	\N
37381	MEMBRE	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31573	\N	\N	\N
37675	MEMBRE	2023-10-17 00:00:00	2023-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	31867	\N	\N	\N
37676	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31868	\N	\N	\N
37677	MEMBRE	2023-10-17 00:00:00	2024-01-30 00:00:00	ACTIF	\N	\N	\N	\N	31869	\N	\N	\N
37678	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31870	\N	\N	\N
37679	MEMBRE	2023-10-17 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	31871	\N	\N	\N
37680	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31872	\N	\N	\N
37681	MEMBRE	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31873	\N	\N	\N
37682	MEMBRE	2023-10-17 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	31874	\N	\N	\N
37683	MEMBRE	2023-10-17 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	31875	\N	\N	\N
37684	MEMBRE	2023-10-17 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	31876	\N	\N	\N
37745	MEMBRE	2023-10-17 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	31937	\N	\N	\N
37795	MEMBRE	2023-10-18 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	31987	\N	\N	\N
37796	MEMBRE	2023-10-18 00:00:00	2024-01-29 00:00:00	ACTIF	\N	\N	\N	\N	31988	\N	\N	\N
37797	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31989	\N	\N	\N
37798	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31990	\N	\N	\N
37799	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31991	\N	\N	\N
37800	MEMBRE	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31992	\N	\N	\N
38378	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32573	\N	\N	\N
38379	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32574	\N	\N	\N
38380	MEMBRE	2023-10-31 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	32575	\N	\N	\N
38381	MEMBRE	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32576	\N	\N	\N
38430	MEMBRE	2023-11-02 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	32625	\N	\N	\N
38431	MEMBRE	2023-11-02 00:00:00	2024-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	32626	\N	\N	\N
38432	MEMBRE	2023-11-02 00:00:00	2024-01-25 00:00:00	ACTIF	\N	\N	\N	\N	32627	\N	\N	\N
38433	MEMBRE	2023-11-02 00:00:00	2023-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	32628	\N	\N	\N
38434	MEMBRE	2023-11-02 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	32629	\N	\N	\N
38435	MEMBRE	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32630	\N	\N	\N
38436	MEMBRE	2023-11-02 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	32631	\N	\N	\N
38437	MEMBRE	2023-11-02 00:00:00	2023-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	32632	\N	\N	\N
38438	MEMBRE	2023-11-02 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	32633	\N	\N	\N
38439	MEMBRE	2023-11-02 00:00:00	2024-01-25 00:00:00	ACTIF	\N	\N	\N	\N	32634	\N	\N	\N
38440	MEMBRE	2023-11-02 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	32635	\N	\N	\N
38441	MEMBRE	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32636	\N	\N	\N
38540	MEMBRE	2023-11-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32735	\N	\N	\N
38541	MEMBRE	2023-11-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32736	\N	\N	\N
38542	MEMBRE	2023-11-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32737	\N	\N	\N
38543	MEMBRE	2023-11-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32738	\N	\N	\N
38544	MEMBRE	2023-11-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32739	\N	\N	\N
38545	MEMBRE	2023-11-06 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	32740	\N	\N	\N
38546	MEMBRE	2023-11-06 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	32741	\N	\N	\N
38709	MEMBRE	2023-11-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32904	\N	\N	\N
38846	MEMBRE	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33041	\N	\N	\N
38851	MEMBRE	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33046	\N	\N	\N
38852	MEMBRE	2023-11-16 00:00:00	2024-01-30 00:00:00	ACTIF	\N	\N	\N	\N	33047	\N	\N	\N
38853	MEMBRE	2023-11-16 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	33048	\N	\N	\N
38854	MEMBRE	2023-11-16 00:00:00	2023-12-11 00:00:00	ANCIEN	\N	\N	\N	\N	33049	\N	\N	\N
38855	MEMBRE	2023-11-16 00:00:00	2024-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	33050	\N	\N	\N
38856	MEMBRE	2023-11-16 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	33051	\N	\N	\N
38857	MEMBRE	2023-11-16 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	33052	\N	\N	\N
38858	MEMBRE	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33053	\N	\N	\N
38859	MEMBRE	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33054	\N	\N	\N
38860	MEMBRE	2023-11-16 00:00:00	2023-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	33055	\N	\N	\N
38861	MEMBRE	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33056	\N	\N	\N
38862	MEMBRE	2023-11-16 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	33057	\N	\N	\N
38863	MEMBRE	2023-11-16 00:00:00	2024-02-08 00:00:00	ACTIF	\N	\N	\N	\N	33058	\N	\N	\N
38864	MEMBRE	2023-11-16 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	33059	\N	\N	\N
38865	MEMBRE	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33060	\N	\N	\N
38868	MEMBRE	2023-11-16 00:00:00	2024-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	33063	\N	\N	\N
38869	MEMBRE	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33064	\N	\N	\N
38871	MEMBRE	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33066	\N	\N	\N
40201	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33730	\N	\N	\N
40221	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33750	\N	\N	\N
40225	MEMBRE	2023-10-01 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	33754	\N	\N	\N
40226	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33755	\N	\N	\N
40234	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33763	\N	\N	\N
40235	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33764	\N	\N	\N
40240	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33769	\N	\N	\N
40255	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33784	\N	\N	\N
40260	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33789	\N	\N	\N
40269	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33798	\N	\N	\N
40288	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33817	\N	\N	\N
40339	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	30767	\N	\N	\N
40408	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33881	\N	\N	\N
40409	MEMBRE	2023-12-14 00:00:00	2024-02-14 00:00:00	ACTIF	\N	\N	\N	\N	33882	\N	\N	\N
40410	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	33883	\N	\N	\N
40518	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33991	\N	\N	\N
40532	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34005	\N	\N	\N
41558	MEMBRE	2024-04-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34499	\N	\N	\N
30689	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26390	\N	\N	\N
30735	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26421	\N	\N	\N
30777	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26450	\N	\N	\N
30989	MEMBRE	2017-10-01 00:00:00	2018-03-07 00:00:00	ANCIEN	\N	\N	\N	\N	26583	\N	\N	\N
31022	MEMBRE	2018-02-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26603	\N	2018-02-23 16:08:41	\N
31023	MEMBRE	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26604	\N	2018-02-23 16:13:00	\N
31024	MEMBRE	2018-02-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26605	\N	2018-02-23 16:38:23	\N
31072	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26616	\N	\N	\N
31073	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26617	\N	\N	\N
31095	SECRET	2018-03-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	26559	\N	\N	\N
31212	MEMBRE	2017-12-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26706	\N	\N	\N
31214	MEMBRE	2017-12-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26708	\N	\N	\N
31216	MEMBRE	2017-12-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26710	\N	\N	\N
31217	MEMBRE	2017-12-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26711	\N	\N	\N
31218	MEMBRE	2017-12-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	26712	\N	\N	\N
31224	MEMBRE	2018-03-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26718	\N	2018-03-21 12:29:35	\N
31250	MEMBRE	2018-03-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26740	\N	2018-04-05 14:52:13	\N
31322	MEMBRE	2018-07-04 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26790	\N	\N	\N
31344	MEMBRE	2018-02-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26806	\N	\N	\N
31345	MEMBRE	2018-02-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	26807	\N	\N	\N
32329	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27758	\N	\N	\N
32330	MEMBRE	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27759	\N	\N	\N
32331	MEMBRE	2020-10-13 00:00:00	2022-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	27760	\N	\N	\N
32332	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27761	\N	\N	\N
32333	MEMBRE	2020-10-13 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	27762	\N	\N	\N
32334	MEMBRE	2020-10-13 00:00:00	2021-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	27763	\N	\N	\N
32335	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27764	\N	\N	\N
32336	MEMBRE	2020-10-14 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	27765	\N	\N	\N
32337	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27766	\N	\N	\N
32338	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27767	\N	\N	\N
32339	MEMBRE	2020-10-14 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	27768	\N	\N	\N
32340	MEMBRE	2020-10-13 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	27769	\N	\N	\N
32341	MEMBRE	2020-10-13 00:00:00	2020-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	27770	\N	\N	\N
32342	MEMBRE	2020-10-13 00:00:00	2021-01-11 00:00:00	ANCIEN	\N	\N	\N	\N	27771	\N	\N	\N
32343	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27772	\N	\N	\N
32344	MEMBRE	2020-10-13 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	27773	\N	\N	\N
32345	MEMBRE	2020-10-13 00:00:00	2020-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	27774	\N	\N	\N
32346	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27775	\N	\N	\N
32347	MEMBRE	2020-10-13 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	27776	\N	\N	\N
32348	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27777	\N	\N	\N
32349	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27778	\N	\N	\N
32350	MEMBRE	2020-10-14 00:00:00	2020-12-23 00:00:00	ANCIEN	\N	\N	\N	\N	27779	\N	\N	\N
32351	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27780	\N	\N	\N
32352	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27781	\N	\N	\N
32353	MEMBRE	2020-10-14 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	27782	\N	\N	\N
32354	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27783	\N	\N	\N
32355	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27784	\N	\N	\N
32591	MEMBRE	2020-10-16 00:00:00	2021-01-13 00:00:00	ANCIEN	\N	\N	\N	\N	28020	\N	\N	\N
32592	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28021	\N	\N	\N
32593	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28022	\N	\N	\N
32594	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28023	\N	\N	\N
32595	MEMBRE	2020-10-16 00:00:00	2021-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	28024	\N	\N	\N
32596	MEMBRE	2020-10-16 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	28025	\N	\N	\N
32597	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28026	\N	\N	\N
32598	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28027	\N	\N	\N
32599	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28028	\N	\N	\N
32600	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28029	\N	\N	\N
32601	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28030	\N	\N	\N
32602	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28031	\N	\N	\N
32603	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28032	\N	\N	\N
32604	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28033	\N	\N	\N
32605	MEMBRE	2020-10-16 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	28034	\N	\N	\N
32606	MEMBRE	2020-10-16 00:00:00	2020-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	28035	\N	\N	\N
32607	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28036	\N	\N	\N
32608	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28037	\N	\N	\N
32609	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28038	\N	\N	\N
32610	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28039	\N	\N	\N
32611	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28040	\N	\N	\N
32612	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28041	\N	\N	\N
32613	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28042	\N	\N	\N
32614	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28043	\N	\N	\N
32615	MEMBRE	2020-10-16 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	28044	\N	\N	\N
32616	MEMBRE	2020-10-16 00:00:00	2020-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	28045	\N	\N	\N
32617	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28046	\N	\N	\N
32618	MEMBRE	2020-10-16 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	28047	\N	\N	\N
32619	MEMBRE	2020-10-16 00:00:00	2021-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	28048	\N	\N	\N
32620	MEMBRE	2020-10-16 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	28049	\N	\N	\N
32621	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28050	\N	\N	\N
32622	MEMBRE	2020-10-16 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	28051	\N	\N	\N
32623	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28052	\N	\N	\N
32624	MEMBRE	2020-10-16 00:00:00	2020-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	28053	\N	\N	\N
32625	MEMBRE	2020-10-16 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	28054	\N	\N	\N
32626	MEMBRE	2020-10-16 00:00:00	2021-01-14 00:00:00	ANCIEN	\N	\N	\N	\N	28055	\N	\N	\N
32627	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28056	\N	\N	\N
32628	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28057	\N	\N	\N
32629	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28058	\N	\N	\N
32630	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28059	\N	\N	\N
32631	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28060	\N	\N	\N
32632	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28061	\N	\N	\N
32633	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28062	\N	\N	\N
32634	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28063	\N	\N	\N
32635	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28064	\N	\N	\N
32636	MEMBRE	2020-10-16 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	28065	\N	\N	\N
32637	MEMBRE	2020-10-16 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	28066	\N	\N	\N
32638	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28067	\N	\N	\N
32639	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28068	\N	\N	\N
32640	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28069	\N	\N	\N
32641	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28070	\N	\N	\N
32642	MEMBRE	2020-10-16 00:00:00	2021-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	28071	\N	\N	\N
32643	MEMBRE	2020-10-16 00:00:00	2020-12-23 00:00:00	ANCIEN	\N	\N	\N	\N	28072	\N	\N	\N
32644	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28073	\N	\N	\N
32645	MEMBRE	2020-10-16 00:00:00	2020-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	28074	\N	\N	\N
32646	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28075	\N	\N	\N
32647	MEMBRE	2020-10-16 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	28076	\N	\N	\N
32648	MEMBRE	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28077	\N	\N	\N
32649	MEMBRE	2020-10-15 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	28078	\N	\N	\N
32650	MEMBRE	2020-10-15 00:00:00	2021-01-11 00:00:00	ANCIEN	\N	\N	\N	\N	28079	\N	\N	\N
32651	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28080	\N	\N	\N
32652	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28081	\N	\N	\N
32653	MEMBRE	2020-10-15 00:00:00	2021-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	28082	\N	\N	\N
32654	MEMBRE	2020-10-15 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	28083	\N	\N	\N
32655	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28084	\N	\N	\N
32656	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28085	\N	\N	\N
32657	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28086	\N	\N	\N
32658	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28087	\N	\N	\N
32659	MEMBRE	2020-10-15 00:00:00	2020-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	28088	\N	\N	\N
32660	MEMBRE	2020-10-15 00:00:00	2020-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	28089	\N	\N	\N
32661	MEMBRE	2020-10-15 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	28090	\N	\N	\N
32662	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28091	\N	\N	\N
32663	MEMBRE	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28092	\N	\N	\N
32664	MEMBRE	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28093	\N	\N	\N
32665	MEMBRE	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28094	\N	\N	\N
32666	MEMBRE	2020-10-19 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	28095	\N	\N	\N
32667	MEMBRE	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28096	\N	\N	\N
32668	MEMBRE	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28097	\N	\N	\N
32669	MEMBRE	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28098	\N	\N	\N
32670	MEMBRE	2020-10-20 00:00:00	2022-04-26 00:00:00	ANCIEN	\N	\N	\N	\N	28099	\N	\N	\N
32671	MEMBRE	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28100	\N	\N	\N
32672	MEMBRE	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28101	\N	\N	\N
32673	MEMBRE	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28102	\N	\N	\N
32674	MEMBRE	2020-10-20 00:00:00	2021-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	28103	\N	\N	\N
32675	MEMBRE	2020-10-20 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	28104	\N	\N	\N
32676	MEMBRE	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28105	\N	\N	\N
32677	MEMBRE	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28106	\N	\N	\N
32678	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28107	\N	\N	\N
32679	MEMBRE	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28108	\N	\N	\N
30780	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26453	\N	\N	\N
30783	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26456	\N	\N	\N
30784	MEMBRE	2017-10-01 00:00:00	2018-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	26457	\N	\N	\N
30785	MEMBRE	2017-10-01 00:00:00	2018-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	26458	\N	\N	\N
30786	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26459	\N	\N	\N
30788	MEMBRE	2017-10-01 00:00:00	2018-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	26461	\N	\N	\N
30789	MEMBRE	2017-10-01 00:00:00	2018-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	26462	\N	\N	\N
30791	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26464	\N	\N	\N
30792	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26465	\N	\N	\N
30796	MEMBRE	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	26469	\N	\N	\N
30844	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26515	\N	\N	\N
31240	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26733	\N	\N	\N
31460	MEMBRE	2017-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	26921	\N	\N	\N
31519	MEMBRE	2019-02-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	26971	\N	\N	\N
31555	MEMBRE	2019-03-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27002	\N	\N	\N
31638	MEMBRE	2020-01-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27070	\N	\N	\N
32310	MEMBRE	2020-10-13 00:00:00	2020-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	27739	\N	\N	\N
32311	MEMBRE	2020-10-13 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	27740	\N	\N	\N
32312	MEMBRE	2020-10-13 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	27741	\N	\N	\N
32313	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27742	\N	\N	\N
32314	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27743	\N	\N	\N
32315	MEMBRE	2020-10-13 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	27744	\N	\N	\N
32316	MEMBRE	2020-10-13 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	27745	\N	\N	\N
32317	MEMBRE	2020-10-13 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	27746	\N	\N	\N
32318	MEMBRE	2020-10-13 00:00:00	2022-09-12 00:00:00	ANCIEN	\N	\N	\N	\N	27747	\N	\N	\N
32319	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27748	\N	\N	\N
32320	MEMBRE	2020-10-13 00:00:00	2020-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	27749	\N	\N	\N
32321	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27750	\N	\N	\N
32322	MEMBRE	2020-10-13 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	27751	\N	\N	\N
32323	MEMBRE	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	27752	\N	\N	\N
32324	MEMBRE	2020-10-13 00:00:00	2021-01-05 00:00:00	ANCIEN	\N	\N	\N	\N	27753	\N	\N	\N
32893	MEMBRE	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28326	\N	\N	\N
32894	MEMBRE	2020-10-22 00:00:00	2020-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	28327	\N	\N	\N
32895	MEMBRE	2020-10-22 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	28328	\N	\N	\N
32896	MEMBRE	2020-10-22 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	28329	\N	\N	\N
32897	MEMBRE	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28330	\N	\N	\N
32898	MEMBRE	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28331	\N	\N	\N
32899	MEMBRE	2020-10-22 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	28332	\N	\N	\N
32900	MEMBRE	2020-10-22 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	28333	\N	\N	\N
32901	MEMBRE	2020-10-22 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	28334	\N	\N	\N
32902	MEMBRE	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28335	\N	\N	\N
32903	MEMBRE	2020-10-22 00:00:00	2020-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	28336	\N	\N	\N
32904	MEMBRE	2020-10-22 00:00:00	2021-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	28337	\N	\N	\N
33880	MEMBRE	2020-11-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29129	\N	\N	\N
33881	MEMBRE	2020-11-26 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	29130	\N	\N	\N
34892	MEMBRE	2021-01-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	29657	\N	\N	\N
35297	MEMBRE	2021-01-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29967	\N	\N	\N
35298	MEMBRE	2021-01-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	29968	\N	\N	\N
35516	MEMBRE	2021-01-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	30071	\N	\N	\N
35532	SECRET	2021-01-13 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	29708	\N	\N	\N
35606	VICPDT	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	29941	\N	\N	\N
35616	MEMBRE	2021-02-03 00:00:00	2021-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	30101	\N	\N	\N
35620	MEMBRE	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30105	\N	\N	\N
35621	MEMBRE	2021-02-03 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	30106	\N	\N	\N
35668	MEMBRE	2021-01-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30144	\N	\N	\N
36146	MEMBRE	2021-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30408	\N	\N	\N
36397	VICPDT	2022-04-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	28099	\N	\N	\N
36450	MEMBRE	2022-01-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30667	\N	\N	\N
36451	MEMBRE	2022-03-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	30668	\N	\N	\N
36832	MEMBRE	2023-10-09 00:00:00	2024-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	31022	\N	\N	\N
36833	MEMBRE	2023-10-09 00:00:00	2024-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	31023	\N	\N	\N
36834	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31024	\N	\N	\N
36835	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31025	\N	\N	\N
36836	MEMBRE	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31026	\N	\N	\N
38912	MEMBRE	2023-11-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33099	\N	\N	\N
38913	MEMBRE	2023-11-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33100	\N	\N	\N
38914	MEMBRE	2023-11-21 00:00:00	2023-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	33101	\N	\N	\N
38916	MEMBRE	2023-11-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33103	\N	\N	\N
38919	MEMBRE	2023-11-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33106	\N	\N	\N
38920	MEMBRE	2023-11-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33107	\N	\N	\N
38921	MEMBRE	2023-11-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33108	\N	\N	\N
38939	MEMBRE	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33112	\N	\N	\N
38940	MEMBRE	2023-11-23 00:00:00	2023-12-11 00:00:00	ANCIEN	\N	\N	\N	\N	33113	\N	\N	\N
38941	MEMBRE	2023-11-23 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	33114	\N	\N	\N
39114	MEMBRE	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33167	\N	\N	\N
39215	MEMBRE	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33259	\N	\N	\N
39247	MEMBRE	2023-12-06 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	33291	\N	\N	\N
39308	VICPDT	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32845	\N	\N	\N
39309	VICPDT	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31587	\N	\N	\N
39310	VICPDT	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31960	\N	\N	\N
39311	VICPDT	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32625	\N	\N	\N
39312	VICPDT	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31826	\N	\N	\N
39313	VICPDT	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33195	\N	\N	\N
39314	VICPDT	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32291	\N	\N	\N
39315	VICPDT	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31013	\N	\N	\N
39316	VICPDT	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31622	\N	\N	\N
39317	VICPDT	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31569	\N	\N	\N
39318	VICPDT	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32503	\N	\N	\N
39319	VICPDT	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31598	\N	\N	\N
39320	VICPDT	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32993	\N	\N	\N
39321	VICPDT	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31681	\N	\N	\N
39322	SECRET	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32232	\N	\N	\N
39323	SECRET	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31520	\N	\N	\N
39324	SECRET	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32294	\N	\N	\N
39325	SECRET	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31993	\N	\N	\N
39326	SECRET	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32225	\N	\N	\N
39328	VICPDT	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30951	\N	\N	\N
39329	VICPDT	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30954	\N	\N	\N
39330	VICPDT	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33014	\N	\N	\N
39331	VICPDT	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31475	\N	\N	\N
39332	SECRET	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	31150	\N	\N	\N
39334	VICPDT	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	25244	\N	\N	\N
39335	VICPDT	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	25080	\N	\N	\N
39336	SECRET	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	32761	\N	\N	\N
39337	SECRET	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	28492	\N	\N	\N
39338	SECRET	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	23503	\N	\N	\N
39339	VICPDT	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	30663	\N	\N	\N
39450	MEMBRE	2023-12-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33376	\N	\N	\N
39717	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33456	\N	\N	\N
39859	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33527	\N	\N	\N
39928	MEMBRE	2023-12-14 00:00:00	2024-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	33539	\N	\N	\N
39950	MEMBRE	2023-12-14 00:00:00	2024-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	33550	\N	\N	\N
39973	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33572	\N	\N	\N
40044	MEMBRE	2024-01-02 00:00:00	2024-02-06 00:00:00	ACTIF	\N	\N	\N	\N	33621	\N	\N	\N
40050	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	33627	\N	\N	\N
40055	MEMBRE	2024-01-02 00:00:00	2024-02-06 00:00:00	ACTIF	\N	\N	\N	\N	33632	\N	\N	\N
40059	MEMBRE	2024-01-02 00:00:00	2024-02-06 00:00:00	ACTIF	\N	\N	\N	\N	33636	\N	\N	\N
40122	MEMBRE	2024-01-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	33695	\N	\N	\N
40129	MEMBRE	2024-01-02 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	30728	\N	\N	\N
40130	MEMBRE	2024-01-02 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	30753	\N	\N	\N
40289	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	33818	\N	\N	\N
40535	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34008	\N	\N	\N
40560	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34033	\N	\N	\N
40595	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34068	\N	\N	\N
40612	MEMBRE	2023-10-01 00:00:00	2024-02-12 00:00:00	ACTIF	\N	\N	\N	\N	34085	\N	\N	\N
40633	MEMBRE	2023-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	34106	\N	\N	\N
40647	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34120	\N	\N	\N
40648	MEMBRE	2023-12-14 00:00:00	2024-02-06 00:00:00	ACTIF	\N	\N	\N	\N	34121	\N	\N	\N
40649	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34122	\N	\N	\N
40653	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34126	\N	\N	\N
40654	PDT	2024-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	33754	\N	\N	\N
40655	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34127	\N	\N	\N
40656	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34128	\N	\N	\N
40657	VICPDT	2024-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	33765	\N	\N	\N
40658	VICPDT	2024-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	33715	\N	\N	\N
40659	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34129	\N	\N	\N
40707	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34166	\N	\N	\N
40724	MEMBRE	2024-01-10 00:00:00	2024-01-22 00:00:00	ACTIF	\N	\N	\N	\N	29894	\N	\N	\N
40725	MEMBRE	2024-01-02 00:00:00	2024-02-06 00:00:00	ACTIF	\N	\N	\N	\N	34183	\N	\N	\N
40731	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	34188	\N	\N	\N
40745	VICPDT	2024-01-23 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	\N	30217	\N	\N	\N
40746	SECRET	2024-01-23 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	\N	30046	\N	\N	\N
40753	SECRET	2024-01-23 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	\N	33449	\N	\N	\N
40754	SECRET	2024-01-23 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	\N	33443	\N	\N	\N
40755	MEMBRE	2024-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	34191	\N	\N	\N
40760	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34196	\N	\N	\N
40766	MEMBRE	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	34202	\N	\N	\N
40767	MEMBRE	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	\N	34203	\N	\N	\N
\.


--
-- Data for Name: fonmemorg; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY fonmemorg (fonmemorgid, memorgid, fonorgcod, fonmemorgdatdeb, fonmemorganndeb, fonmemorgdatfin, fonmemorgannfin, temvalcod, evelic, evelib, evelil, eveobs, fonmemorgrngele, syscredat, sysmajdat) FROM stdin;
170	179	MEMBREORG	1999-04-01 00:00:00	1999	2004-03-31 00:00:00	2004	ANCIEN	\N	\N	\N	\N	\N	\N	\N
66	69	MEMBREORG	2002-02-01 00:00:00	\N	2017-10-05 00:00:00	2002	ANCIEN	\N	Membre de la délégation au Comité des régions de l'UE	Membre de la délégation au Comité des régions de l'Union européenne	Membre de la délégation au Comité des régions de l'Union européenne	\N	\N	2017-10-05 09:30:52
168	175	MEMBREORG	\N	1998	\N	2004	ANCIEN	\N	\N	\N	\N	\N	\N	\N
68	71	MEMBREORG	2002-02-01 00:00:00	\N	2022-10-17 00:00:00	\N	ANCIEN	\N	Membre de la délégation au Comité des régions de l'Union eur	Membre de la délégation au Comité des régions de l'Union européenne	Membre de la délégation au Comité des régions de l'Union européenne	\N	\N	\N
69	72	MEMBREORG	2002-02-01 00:00:00	\N	2022-10-17 00:00:00	\N	ANCIEN	\N	Membre de la délégation au Comité des régions de l'Union eur	Membre de la délégation au Comité des régions de l'Union européenne	Membre de la délégation au Comité des régions de l'Union européenne	\N	\N	\N
70	74	MEMBREORG	\N	2001	2014-09-30 00:00:00	2003	ANCIEN	\N	\N	\N	\N	\N	\N	2014-09-28 17:31:42
71	75	MEMBREORG	\N	1993	2016-11-30 00:00:00	1995	ANCIEN	\N	\N	\N	\N	\N	\N	2016-12-01 10:36:52
125	131	VICPDTORG	\N	\N	\N	\N	ACTIF	\N	\N	\N	\N	\N	\N	\N
1	1	PDTORG	\N	1986	2024-02-09 00:00:00	1995	ANCIEN	\N	\N	\N	\N	\N	\N	\N
3	2	MEMBREORG	\N	1989	2017-06-17 00:00:00	1994	ANCIEN	\N	\N	\N	\N	\N	\N	2017-06-19 12:20:22
177	184	MEMBREORG	\N	2005	2021-09-30 00:00:00	2006	ANCIEN	\N	\N	\N	\N	\N	\N	\N
179	186	MEMBREORG	\N	1974	2014-09-30 00:00:00	1994	ANCIEN	\N	\N	\N	\N	\N	\N	2014-09-28 17:09:16
176	183	MEMBREORG	\N	2000	\N	2013	ANCIEN	\N	\N	\N	\N	\N	\N	2013-09-06 14:40:10
178	185	MEMBREORG	\N	1991	2018-05-24 00:00:00	1999	ANCIEN	\N	\N	\N	\N	\N	\N	2018-05-30 17:03:14
180	188	MEDIATEURREP	\N	2004	2022-03-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	\N	\N	\N
181	189	MEDIATEURREP	1992-03-01 00:00:00	1992	1998-02-28 00:00:00	1998	ANCIEN	\N	\N	\N	\N	\N	\N	\N
169	178	MEMBREORG	\N	\N	\N	2008	ANCIEN	\N	\N	\N	\N	\N	\N	\N
\.


--
-- Data for Name: fonorg; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY fonorg (fonorgcod, fonorglib, fonorglic, fonorgnumtri, fonorglil, fonorglibfem, fonorglicfem, fonorglilfem, fonorglibplu, fonorglicplu, fonorglilplu, syscredat, sysmajdat, fonorglicfemplu, fonorglibfemplu, fonorglilfemplu) FROM stdin;
SECGENORG	Secrétaire général	Secrétaire général	8	Secrétaire général	Secrétaire générale	Secrétaire générale	Secrétaire générale	Secrétaires généraux	Secrétaires généraux	Secrétaires généraux	\N	\N	Secrétaires générales	Secrétaires générales	Secrétaires générales
PDTORG	Président	Président	1	Président	Présidente	Présidente	Présidente	Présidents	Présidents	Présidents	\N	\N	Présidentes	Présidentes	Présidentes
VICPDTORG	Vice-Président	Vice-Président	7	Vice-Président	Vice-Présidente	Vice-Présidente	Vice-Présidente	Vice-Présidents	Vice-Présidents	Vice-Présidents	\N	\N	Vice-Présidentes	Vice-Présidentes	Vice-Présidentes
MEMBREORG	Membre	Membre	20	Membre	Membre	Membre	Membre	Membres	Membres	Membres	\N	\N	Membres	Membres	Membres
PDTDELORG	Président délégué	Président délégué	3	Président délégué	Présidente déléguée	Présidente déléguée	Présidente déléguée	Présidents délégués	Présidents délégués	Présidents délégués	\N	\N	Présidentes déléguées	Présidentes déléguées	Présidentes déléguées
TRESORADJORG	Trésorier adjoint	Trésorier adjoint	12	Trésorier adjoint	Trésorière adjointe	Trésorière adjointe	Trésorière adjointe	Trésoriers adjoints	Trésoriers adjoints	Trésoriers adjoints	\N	\N	Trésorière adjointes	Trésorière adjointes	Trésorière adjointes
TRESORORG	Trésorier	Trésorier	11	Trésorier	Trésorière	Trésorière	Trésorière	Trésoriers	Trésoriers	Trésoriers	\N	\N	Trésorières	Trésorières	Trésorières
SECRETADJORG	Secrétaire adjoint	Secrétaire adjoint	10	Secrétaire adjoint	Secrétaire adjointe	Secrétaire adjointe	Secrétaire adjointe	Secrétaires adjoints	Secrétaires adjoints	Secrétaires adjoints	\N	\N	Secrétaires adjointes	Secrétaires adjointes	Secrétaires adjointes
SECRETORG	Secrétaire	Secrétaire	9	Secrétaire	Secrétaire	Secrétaire	Secrétaire	Secrétaires	Secrétaires	Secrétaires	\N	\N	Secrétaires	Secrétaires	Secrétaires
MEMBREBURORG	Membre du bureau	Membre bureau	13	Membre du bureau	Membre du bureau	Membre bureau	Membre du bureau	Membres du bureau	Membres bureau	Membres du bureau	\N	\N	Membres bureau	Membres du bureau	Membres du bureau
VICPDTPREORG	Premier Vice-Président	Premier Vice-Président	4	Premier Vice-Président	Première Vice-Présidente	Première Vice-Présidente	Première Vice-Présidente	Premiers Vice-Présidents	Premiers Vice-Présidents	Premier Vice-Président	\N	\N	Premières Vice-Présidentes	Premières Vice-Présidentes	Premières Vice-Présidentes
VICPDTDELORG	Vice-Président délégué	Vice-Président délégué	6	Vice-Président délégué	Vice-Présidente déléguée	Vice-Présidente déléguée	Vice-Présidente déléguée	Vice-Présidents délégués	Vice-Présidents délégués	Vice-Présidents délégués	\N	\N	Vice-Présidentes déléguées	Vice-Présidentes déléguées	Vice-Présidentes déléguées
PDTEXECUTORG	Président exécutif	Président exécutif	2	Président exécutif	Présidente exécutive	Présidente exécutive	Présidente exécutive	Présidents exécutifs	Présidents exécutifs	Présidents exécutifs	\N	\N	Présidentes exécutives	Présidentes exécutives	Présidentes exécutives
PDTDRTORG	Président de droit	Président de droit	1	Président de droit	Présidente de droit	Présidente de droit	Présidente de droit	Présidents de droit	Présidents de droit	Présidents de droit	\N	\N	Présidentes de droit	Présidentes de droit	Présidentes de droit
MEDIATEURREP	Médiateur de la République	Médiateur de la République	5	Médiateur de la République	Médiatrice de la République	Médiatrice de la République	Médiatrice de la République	Médiateurs de la République	Médiateurs de la République	Médiateurs de la République	\N	\N	Médiatrices de la Républiques	Médiatrices de la Républiques	Médiatrices de la Républiques
\.


--
-- Data for Name: grppol; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY grppol (grppolcod, grppolpre, grppoldatcre, grppoldatfin, grppolliccou, grppollibcou, grppollilcou, temvalcod, evelic, evelib, evelil, typorgcod, grppolart, grppolurlsim, grppolurlcmp, grppolcodamelicou, syscredat, sysmajdat) FROM stdin;
CRC	OUI	2011-10-01 00:00:00	\N	CRCE-K	Groupe CRCE - Kanaky	Groupe Communiste Républicain Citoyen et Écologiste - Kanaky	ACTIF	\N	\N	\N	GRPPOL	du	\N	https://senateurscrce.fr	CRCE	\N	2018-06-13 00:00:00
NI	NON	1899-12-31 00:50:39	\N	NI	Réunion administrative des non-inscrits	Réunion administrative des Sénateurs ne figurant sur la liste d'aucun groupe	ACTIF	\N	\N	\N	GRPPOLNI	de la	\N	https://rasnag-senat.fr/	NI	\N	2017-10-03 17:46:58
RDSE	OUI	1899-12-31 00:00:00	\N	RDSE	Groupe du RDSE	Groupe du Rassemblement Démocratique et Social Européen	ACTIF	\N	\N	\N	GRPPOL	du	\N	http://www.rdse-senat.fr	RDSE	\N	2018-06-13 00:00:00
RI	OUI	1900-01-01 00:00:00	2002-12-10 00:00:00	RI	Groupe des RI	Groupe des Républicains et Indépendants	ANCIEN	\N	\N	\N	GRPPOL	du	\N	http://www.senat.fr/grp/ri/index.html	RI	\N	2014-02-14 17:27:30
RPR	OUI	1900-01-01 00:00:00	2002-12-10 00:00:00	RPR	Groupe du RPR	Groupe du Rassemblement pour la République	ANCIEN	\N	\N	\N	GRPPOL	du	\N	http://www.rpr-senat.org	RPR	\N	2014-02-14 17:27:30
SOC	OUI	2015-06-11 00:00:00	\N	SER	Groupe Socialiste, Écologiste et Républicain	Groupe Socialiste, Écologiste et Républicain	ACTIF	\N	\N	\N	GRPPOL	du	\N	http://www.senateurs-socialistes.fr/	SOC	\N	2018-06-13 16:17:31
UC	OUI	2008-10-02 00:00:00	\N	UC	Groupe Union Centriste	Groupe Union Centriste	ACTIF	\N	\N	\N	GRPPOL	du 	\N	http://unioncentriste-senat.fr/	UC	\N	2018-06-13 16:17:31
AUCUN	NON	1899-12-31 00:50:39	\N	Aucun	Sénateurs n'appartenant à aucun groupe	Nouveaux Sénateurs	ACTIF	\N	\N	\N	GRPPOL	de la	\N	\N	AUCUN	\N	2014-01-02 15:39:01
UMP	OUI	2002-12-11 00:00:00	\N	Les Républicains	Groupe Les Républicains	Groupe Les Républicains	ACTIF	\N	\N	\N	GRPPOL	du	\N	http://www.lesrepublicains-senat.fr/	REPUBLICAINS	\N	2017-10-09 16:22:46
C	OUI	1900-01-01 00:00:00	1995-10-01 00:00:00	C	Communistes	Groupe Communiste	ANCIEN	\N	\N	\N	GRPPOL	du	\N	\N	C	\N	2014-10-02 09:56:55
CNIP	OUI	1900-01-01 00:00:00	1980-10-01 00:00:00	C.N.I.P.	Centre National des Indépendants et Paysans	Groupe du Centre National des Indépendants et Paysans	ANCIEN	\N	\N	\N	GRPPOL	du	\N	\N	C.N.I.P.	\N	2014-10-02 09:56:55
CRARS	OUI	1900-01-01 00:00:00	1980-10-01 00:00:00	CRARS	Centre Républicain d'Action Rurale et Sociale	Groupe du Centre Républicain d'Action Rurale et Sociale	ANCIEN	\N	\N	\N	GRPPOL	du	\N	\N	CRARS	\N	2014-10-02 09:56:55
FCD	OUI	1900-01-01 00:00:00	1968-10-01 00:00:00	FCD	Formation Centre Démocratique (rattaché R.P.)	Groupe de la Formation Centre Démocratique (rattaché R.P.)	ANCIEN	\N	\N	\N	GRPPOL	du	\N	\N	FCD	\N	2014-10-02 09:56:55
GD	OUI	1900-01-01 00:00:00	1989-10-01 00:00:00	G.D.	Gauche Démocratique	Groupe de la Gauche Démocratique	ANCIEN	\N	\N	\N	GRPPOL	du	\N	\N	G.D.	\N	2014-10-02 09:56:55
GDSRG	OUI	1900-01-01 00:00:00	1986-10-01 00:00:00	G.D.S.R.G.	Formation des Sénateurs Radicaux de Gauche	Formation des Sénateurs Radicaux de Gauche rattachée administrativement au groupe de la Gauche Démocratique	ANCIEN	\N	\N	\N	GRPPOL	de la	\N	\N	G.D.S.R.G.	\N	2014-10-02 09:56:55
MRP	OUI	1900-01-01 00:00:00	1959-04-29 00:00:00	MRP	Mouvement Républicain Populaire	Groupe du Mouvement Républicain Populaire	ANCIEN	\N	\N	\N	GRPPOL	du	\N	\N	MRP	\N	2014-10-02 09:56:55
RDE	OUI	1899-12-31 00:50:39	1995-10-02 00:00:00	R.D.E.	Rassemblement Démocratique et Européen	Groupe du Rassemblement Démocratique et Européen	ANCIEN	\N	\N	\N	GRPPOL	du	\N	\N	R.D.E.	\N	2014-10-02 09:56:55
RIAS	OUI	1900-01-01 00:00:00	1980-10-01 00:00:00	R.I.A.S.	Républicains Indépendants d'Action Sociale (Devenu C.N.I.P.)	Groupe des Républicains Indépendants d'Action Sociale	ANCIEN	\N	\N	\N	GRPPOL	du	\N	\N	R.I.A.S.	\N	2014-10-02 09:56:55
RP	OUI	1900-01-01 00:00:00	1968-10-01 00:00:00	RP	Républicains Populaires	Groupe des Républicains Populaires	ANCIEN	\N	\N	\N	GRPPOL	du	\N	\N	RP	\N	2014-10-02 09:56:55
RPCD	OUI	1900-01-01 00:00:00	1974-10-01 00:00:00	RPCD	Républicains Populaires et du Centre Démocratique	Groupe des Républicains Populaires et du Centre Démocratique	ANCIEN	\N	\N	\N	GRPPOL	du	\N	\N	RPCD	\N	2014-10-02 09:56:55
UCDP	OUI	1900-01-01 00:00:00	1986-10-01 00:00:00	U.C.D.P.	Union Centriste des Démocrates de Progrès	Groupe de l'Union Centriste des Démocrates de Progrès	ANCIEN	\N	\N	\N	GRPPOL	du	\N	\N	U.C.D.P.	\N	2014-10-02 09:56:55
UDR	OUI	1900-01-01 00:00:00	1977-10-01 00:00:00	U.D.R.	Union des Démocrates pour la République	Groupe de l'Union des Démocrates pour la République	ANCIEN	\N	\N	\N	GRPPOL	du	\N	\N	U.D.R.	\N	2014-10-02 09:56:55
UNR	OUI	1900-01-01 00:00:00	1968-10-01 00:00:00	U.N.R.	Union pour la Nouvelle République	Groupe de l'Union pour la Nouvelle République	ANCIEN	\N	\N	\N	GRPPOL	du	\N	\N	U.N.R.	\N	2014-10-02 09:56:55
UREI	OUI	1900-01-01 00:00:00	2004-10-01 00:00:00	U.R.E.I.	Union des Républicains et des Indépendants	Groupe de l'Union des Républicains et des Indépendants	ANCIEN	\N	\N	\N	GRPPOL	du	\N	\N	U.R.E.I.	\N	2014-10-02 09:56:55
ECO	OUI	2012-01-11 00:00:00	2017-06-29 00:00:00	Écologiste	Groupe écologiste	Groupe écologiste	ANCIEN	\N	\N	\N	GRPPOL	du 	\N	http://ecologistes-senat.fr/	ECOLO	\N	2017-06-30 09:52:10
LREM	NON	2017-06-28 00:00:00	\N	RDPI	Groupe Rassemblement des démocrates, progressistes et indépendants	Groupe Rassemblement des démocrates, progressistes et indépendants	ACTIF	\N	\N	\N	GRPPOL	du	\N	\N	LaREM	2017-06-29 09:48:06	2018-06-13 16:17:40
RTLI	NON	2020-10-05 00:00:00	\N	Les Indépendants	Groupe Les Indépendants - République et Territoires	Groupe Les Indépendants - République et Territoires	ACTIF	\N	\N	\N	GRPPOL	du	\N	\N	RTLI	2017-10-03 00:00:00	2017-10-26 00:00:00
GEST	OUI	2020-10-05 00:00:00	\N	GEST	Groupe Écologiste - Solidarité et Territoires	Groupe Écologiste - Solidarité et Territoires	ACTIF	\N	\N	\N	GRPPOL	du	\N	\N	GEST	\N	\N
\.


--
-- Data for Name: grpsenami; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY grpsenami (typorgcod, orgcod, orgnumtri, orgdatcre, orgdatfin, grpsenalf, scnorgcod, temvalcod, evelic, evelib, evelil, orgart, grpsenweb, typgrpsencod, orgurlsim, orgurlcmp, comorgcod, orgtemannu, plaindcod, syscredat, sysmajdat, type_com_neant) FROM stdin;
GRPSEN	622	1	1985-12-18 00:00:00	\N	AIPLF	622	ACTIF	Madagascar	France-Madagascar et pays de l'Océan indien	FRANCE-MADAGASCAR ET PAYS DE L'OCÉAN INDIEN (Comores, Kenya, Madagascar, Maldives, Ile Maurice, Mozambique, Seychelles, Tanzanie)	du	OUI	AMITIE	\N	\N	NEANT	OUI	3	\N	2014-01-08 15:25:36	\N
GRPSEN	623	623	1984-11-20 00:00:00	\N	NON	623	ACTIF	Taïwan	Groupe d'échanges et d'études Sénat-Taïwan	Groupe d'échanges et d'études SÉNAT-TAÏWAN	du	OUI	AMITIE	\N	\N	NEANT	OUI	3	\N	2017-03-13 15:09:59	\N
GRPSEN	624	1	1987-04-15 00:00:00	\N	NON	624	ACTIF	Turquie	France-Turquie	FRANCE-TURQUIE	du	OUI	AMITIE	\N	\N	NEANT	OUI	2	\N	2017-03-13 15:10:29	\N
GRPSEN	625	1	1989-01-01 00:00:00	\N	NON	625	ACTIF	Europe du Nord	France-Europe du Nord	FRANCE-EUROPE DU NORD  (Danemark, Islande, Norvège, Suède)	du	OUI	AMITIE	\N	\N	NEANT	OUI	2	\N	2018-03-14 12:17:54	\N
GRPSEN	626	1	1989-06-15 00:00:00	\N	AIPLF	626	ACTIF	Vietnam	France-Vietnam	FRANCE-VIETNAM	du	OUI	AMITIE	\N	\N	NEANT	OUI	3	\N	2017-07-31 11:08:03	\N
GRPSEN	627	1	1992-01-01 00:00:00	\N	NON	627	ACTIF	Yémen	France-Yémen	FRANCE-YÉMEN	du	OUI	AMITIE	\N	\N	NEANT	OUI	3	\N	2014-01-02 15:38:56	\N
GRPSEN	632	632	1995-11-08 00:00:00	\N	NON	632	ACTIF	Palestine	France-Palestine	FRANCE-PALESTINE	du	OUI	AMITIE	\N	\N	NEANT	OUI	2	\N	2013-07-26 09:36:06	\N
GRPSEN	640	1	1995-11-08 00:00:00	\N	NON	640	ACTIF	Finlande	France-Finlande	FRANCE-FINLANDE	du	OUI	AMITIE	\N	\N	NEANT	OUI	2	\N	2014-01-02 15:38:56	\N
GRPSEN	641	1	1996-01-24 00:00:00	\N	AIPLF	641	ACTIF	Arménie	France-Arménie	FRANCE-ARMENIE	du	OUI	AMITIE	\N	\N	NEANT	OUI	2	\N	2014-02-28 16:40:36	\N
GRPSEN	642	642	1951-11-21 00:00:00	\N	AIPLF	642	ACTIF	Caraïbes	France-Caraïbes	FRANCE-CARAÏBES (Anguilla, Antigua-et-Barbuda, Bahamas, Barbade, Cuba, Dominique, Haïti, Jamaïque, République dominicaine, Saint-Kitts-et-Nevis, Sainte-Lucie, Trinité-et-Tobago)	du	OUI	AMITIE	\N	\N	NEANT	OUI	3	\N	2017-01-30 16:12:36	\N
GRPSEN	643	643	1951-01-01 00:00:00	\N	NON	643	ACTIF	Mexique-Pays d'Am. Centrale	France-Mexique-Pays d'Amérique centrale	FRANCE-MEXIQUE et PAYS D'AMÉRIQUE CENTRALE  (Mexique, Belize, Costa Rica, El Salvador, Guatemala, Honduras, Nicaragua, Panama)	du	OUI	AMITIE	\N	\N	NEANT	OUI	3	\N	2014-01-08 15:54:18	\N
GRPSEN	659	659	1997-01-21 00:00:00	\N	NON	659	ACTIF	Jordanie	France-Jordanie	FRANCE-JORDANIE	du	OUI	AMITIE	\N	\N	NEANT	OUI	2	\N	\N	\N
GRPSEN	661	0	1997-01-21 00:00:00	\N	NON	661	ACTIF	Pays du Golfe	France-Pays du Golfe	FRANCE-PAYS DU GOLFE (Arabie saoudite, Bahreïn, Emirats Arabes Unis, Koweït, Oman, Qatar)	du	OUI	AMITIE	\N	\N	NEANT	OUI	3	\N	2015-06-24 18:36:13	\N
GRPSEN	663	\N	1992-01-01 00:00:00	\N	NON	663	ACTIF	Nouvelle-Zélande	France-Nouvelle-Zélande	FRANCE-NOUVELLE-ZÉLANDE	du	OUI	AMITIE	\N	\N	NEANT	OUI	3	\N	2013-07-26 09:30:23	\N
GRPSEN	851	1	1993-03-09 00:00:00	\N	AIPLF	851	ACTIF	Moldavie	France-Moldavie	FRANCE-MOLDAVIE	du	OUI	AMITIE	\N	\N	NEANT	OUI	2	\N	2017-07-31 09:58:34	\N
GRPSENSCN	6251	1	1900-01-01 00:00:00	2014-09-30 00:00:00	NON	625	ANCIEN	Suède	Suède	SUEDE	du	NON	AMITIE	\N	\N	NEANT	OUI	0	\N	2014-10-30 16:58:39	\N
GRPSENSCN	6252	2	1900-01-01 00:00:00	2014-09-30 00:00:00	NON	625	ANCIEN	Norvège	Norvège	NORVEGE	du	NON	AMITIE	\N	\N	NEANT	OUI	0	\N	2014-10-30 16:58:39	\N
GRPSENSCN	6253	3	1900-01-01 00:00:00	2014-09-30 00:00:00	NON	625	ANCIEN	Danemark	Danemark	DANEMARK	du	NON	AMITIE	\N	\N	NEANT	OUI	0	\N	2014-10-30 16:58:39	\N
GRPSENSCN	6254	4	1900-01-01 00:00:00	2014-09-30 00:00:00	NON	625	ANCIEN	Islande	Islande	ISLANDE	du	NON	AMITIE	\N	\N	NEANT	OUI	0	\N	2014-10-30 16:58:39	\N
GRPSEN	651	651	1996-06-19 00:00:00	\N	AIPLF	\N	ACTIF	Vanuatu	France-Vanuatu-Iles du Pacifique	FRANCE-VANUATU-ILES DU PACIFIQUE (Iles Cook, Iles Fidji, Kiribati, Mariannes du Nord, Iles Marshall, Micronésie, Nauru, Iles Niué, Palaos, Papouasie-Nouvelle Guinée, Pitcairn, Iles Salomon, Samoa occidentales, Tokelau, Tonga, Tuvalu)	\N	OUI	AMITIE	\N	\N	NEANT	OUI	3	\N	2014-01-08 15:31:05	\N
GRPSEN	628	628	1998-04-22 00:00:00	\N	NON	628	ACTIF	Iran	France-Iran	FRANCE-IRAN	\N	OUI	AMITIE	\N	\N	NEANT	OUI	2	\N	2017-03-13 15:04:40	\N
GRPSEN	657	657	1997-01-21 00:00:00	\N	NON	657	ACTIF	Libye	France-Libye	FRANCE-LIBYE	\N	OUI	AMITIE	\N	\N	NEANT	OUI	2	\N	2014-01-08 15:16:00	\N
GRPSEN	629	629	1998-12-15 00:00:00	\N	NON	629	ACTIF	Saint-Siège	France-Saint-Siège	FRANCE-SAINT-SIÈGE	\N	OUI	AMITIE	\N	\N	NEANT	OUI	1	\N	2013-07-26 09:46:18	\N
GRPSENSCN	6431	6431	1996-01-01 00:00:00	2014-09-30 00:00:00	NON	643	ANCIEN	Mexique	France-Mexique	FRANCE-MEXIQUE	\N	NON	AMITIE	\N	\N	NEANT	OUI	0	\N	2014-10-30 16:58:39	\N
GRPSENSCN	6432	6432	1996-01-01 00:00:00	2014-09-30 00:00:00	NON	643	ANCIEN	Amérique Centrale	France-Amérique Centrale	FRANCE-AMERIQUE CENTRALE (Guatemala, Salvador, Belize, Honduras, Nicaragua, Costa Rica, Panama)	\N	NON	AMITIE	\N	\N	NEANT	OUI	3	\N	2014-10-30 16:58:39	\N
GRPSEN	633	633	2000-03-21 00:00:00	\N	NON	633	ACTIF	Népal	France-Népal	FRANCE-NÉPAL	du	OUI	AMITIE	\N	\N	NEANT	OUI	3	\N	2015-10-20 14:46:06	\N
GRPSEN	634	634	2000-03-21 00:00:00	\N	NON	634	ACTIF	Tibet	Groupe d'information internationale sur le TIBET	Groupe d'information internationale sur le TIBET	du	OUI	AMITIE	http://www.senat.fr/international/groupes_interparlementaires/groupe_tibet.html	\N	NEANT	OUI	3	\N	2015-10-20 14:47:06	\N
GRPSEN	647	647	1998-07-08 00:00:00	\N	AIPLF	647	ACTIF	Croatie	France-Croatie	FRANCE-CROATIE	du	OUI	AMITIE	\N	\N	NEANT	OUI	1	\N	2013-07-25 16:47:24	\N
GRPSEN	648	648	2000-05-25 00:00:00	\N	NON	648	ACTIF	Afghanistan	France-Afghanistan	FRANCE-AFGHANISTAN	du	OUI	AMITIE	\N	\N	NEANT	OUI	3	\N	2014-02-28 15:10:43	\N
GRPSEN	646	646	1996-06-19 00:00:00	\N	NON	646	ACTIF	Afrique australe	France-Afrique australe	FRANCE-AFRIQUE AUSTRALE (Angola, Botswana, Malawi, Namibie, Zambie, Zimbabwe)	du	OUI	AMITIE	\N	\N	NEANT	OUI	3	\N	2014-09-25 10:11:03	\N
GRPSEN	662	662	2002-10-01 00:00:00	2007-02-14 00:00:00	AIPLF	662	ANCIEN	Bosnie Herzégovine	France - Bosnie Herzégovine	FRANCE - BOSNIE HERZEGOVINE	du	OUI	AMITIE	\N	\N	NEANT	OUI	2	\N	2014-01-02 15:38:56	\N
ETUDES	901	1	1986-01-01 00:00:00	2011-09-30 00:00:00	NON	901	ANCIEN	Innovation et entreprise	Groupe d'études Innovation et entreprises	Groupe d'études Innovation et entreprise	du	OUI	ETUDES	\N	\N	AFCL	OUI	0	\N	\N	\N
ETUDES	902	1	1989-01-01 00:00:00	2011-09-30 00:00:00	NON	902	ANCIEN	Métiers d'art	Groupe d'études sur les métiers d'art	Groupe d'études sur les métiers d'art	du	OUI	ETUDES	\N	\N	AFCL	OUI	0	\N	\N	\N
ETUDES	922	1	1999-01-01 00:00:00	\N	NON	922	ACTIF	Economie circulaire	Groupe d'études Economie circulaire	Groupe d'études Economie circulaire	du	OUI	ETUDES	\N	\N	CDD	OUI	0	\N	\N	\N
ETUDES	903	1	1991-01-01 00:00:00	2002-06-30 00:00:00	NON	903	ANCIEN	Villes d'art et d'histoire	Groupe d'études consacré aux villes d'art et d'histoire et à tous les secteurs sauvegardés	Groupe d'études consacré aux villes d'art et d'histoire et à tous les secteurs sauvegardés	du	OUI	ETUDES	\N	\N	AFCL	OUI	0	\N	\N	\N
ETUDES	904	1	1992-01-01 00:00:00	2015-01-28 00:00:00	NON	904	ANCIEN	Patrimoines	Groupe d'études sur les patrimoines	Groupe d'études sur les patrimoines	du	OUI	ETUDES	\N	\N	AFCL	OUI	0	\N	\N	\N
ETUDES	905	1	1979-01-01 00:00:00	2008-12-31 00:00:00	NON	905	ANCIEN	Droits de l'Homme	Groupe d'études des droits de l'Homme	Groupe d'études des droits de l'Homme	du	OUI	ETUDES	\N	\N	AFCL	OUI	0	\N	\N	\N
ETUDES	906	1	1972-01-01 00:00:00	\N	NON	906	ACTIF	Energie	Groupe d'études Énergie	Groupe d'études Énergie	du	OUI	ETUDES	\N	\N	CAE	OUI	0	\N	\N	\N
ETUDES	907	1	1975-01-01 00:00:00	\N	NON	907	ACTIF	Chasse et pêche	Groupe d'études Chasse et pêche	Groupe d'études Chasse et pêche	du	OUI	ETUDES	\N	\N	CAE	OUI	0	\N	\N	\N
ETUDES	908	1	1976-01-01 00:00:00	\N	NON	908	ACTIF	Mer et littoral	Groupe d'études Mer et littoral	Groupe d'études Mer et littoral	du	OUI	ETUDES	\N	\N	CDD	OUI	0	\N	\N	\N
ETUDES	909	1	1978-01-01 00:00:00	\N	NON	909	ACTIF	Vigne et vin	Groupe d'études Vigne et vin	Groupe d'études de la vigne et du vin	du	OUI	ETUDES	\N	\N	CAE	OUI	0	\N	2013-04-23 15:28:51	\N
ETUDES	910	1	1979-01-01 00:00:00	2017-10-01 00:00:00	NON	910	ANCIEN	Tourisme et loisirs	Groupe d'études Tourisme et loisirs	Groupe d'études Tourisme et loisirs	du	OUI	ETUDES	\N	\N	CAE	OUI	0	\N	\N	\N
ETUDES	911	1	1980-01-01 00:00:00	2024-01-30 00:00:00	NON	911	ACTIF	Élevage	Groupe d'études Élevage	Groupe d'études Élevage	du	OUI	ETUDES	\N	\N	CAE	OUI	0	\N	2014-04-03 16:18:45	\N
ETUDESSCN	912	1	1980-01-01 00:00:00	\N	NON	919	ACTIF	Cheval	Section Cheval	Section Cheval	de la	OUI	ETUDES	\N	\N	CAE	OUI	0	\N	\N	\N
ETUDES	913	1	1980-01-01 00:00:00	2017-10-01 00:00:00	NON	913	ANCIEN	Communications électroniques et Poste	Groupe d'études Communications électroniques et Poste	Groupe d'études Communications électroniques et Poste	du	OUI	ETUDES	\N	\N	CAE	OUI	0	\N	\N	\N
ETUDES	914	1	1975-01-01 00:00:00	2002-06-30 00:00:00	NON	914	ANCIEN	Petites et moyennes entreprises	Groupe d'études consacré aux petites et moyennes entreprises	Groupe d'études consacré aux petites et moyennes entreprises	du	OUI	ETUDES	\N	\N	ECON	OUI	0	\N	\N	\N
ETUDES	915	1	1988-01-01 00:00:00	2011-09-30 00:00:00	NON	915	ANCIEN	Voies navigables	Groupe d'études sur les voies navigables	Groupe d'études sur les voies navigables	du	OUI	ETUDES	\N	\N	ECON	OUI	0	\N	\N	\N
ETUDES	916	1	1992-01-01 00:00:00	2002-06-30 00:00:00	NON	916	ANCIEN	Aménagement de la Loire et de ses affluents	Groupe d'études aménagement de la Loire	Groupe d'études ayant pour objet l'examen et le suivi des projets d'aménagement de la Loire et de ses affluents	du	OUI	ETUDES	\N	\N	ECON	OUI	0	\N	\N	\N
ETUDES	917	1	1996-01-01 00:00:00	2008-09-30 00:00:00	NON	917	ANCIEN	Eau	Groupe d'études sur l'eau	Groupe d'études sur l'eau	du	OUI	ETUDES	\N	\N	ECON	OUI	0	\N	\N	\N
ETUDES	918	1	1998-01-01 00:00:00	\N	NON	918	ACTIF	Développement économique de la montagne	Groupe d'études Développement économique de la montagne	Groupe d'études Développement économique de la montagne	du	OUI	ETUDES	\N	\N	CDD	OUI	0	\N	\N	\N
ETUDES	919	1	1984-01-01 00:00:00	\N	NON	919	ACTIF	Agriculture et alimentation	Groupe d'études Agriculture, élevage et alimentation	Groupe d'études Agriculture, élevage et alimentation	du	OUI	ETUDES	\N	\N	CAE	OUI	0	\N	\N	\N
ETUDESSCN	920	1	1984-01-01 00:00:00	2008-09-30 00:00:00	NON	919	ANCIEN	Chocolat	Section chocolat	Section chocolat	de la	OUI	ETUDES	\N	\N	ECON	OUI	0	\N	\N	\N
ETUDESSCN	921	1	1984-01-01 00:00:00	2011-09-30 00:00:00	NON	907	ANCIEN	Oléiculture	Section oléiculture	Section oléiculture	de la	OUI	ETUDES	\N	\N	ECON	OUI	0	\N	\N	\N
GRPSEN	528	1	1994-05-17 00:00:00	2007-02-14 00:00:00	AIPLF	528	ANCIEN	Macédoine	France-République de Macédoine	FRANCE-RÉPUBLIQUE DE MACÉDOINE	du	OUI	AMITIE	\N	\N	NEANT	OUI	0	\N	2014-11-19 10:57:50	\N
GRPSEN	529	1	1994-06-14 00:00:00	\N	NON	529	ACTIF	Slovénie	France-Slovénie	FRANCE-SLOVÉNIE	du	OUI	AMITIE	\N	\N	NEANT	OUI	1	\N	2014-01-02 15:38:56	\N
GRPSEN	530	1	1992-11-03 00:00:00	\N	NON	530	ACTIF	Ukraine	France-Ukraine	FRANCE-UKRAINE	du	OUI	AMITIE	\N	\N	NEANT	OUI	2	\N	2017-01-30 16:14:30	\N
GRPSEN	532	1	1993-06-08 00:00:00	\N	NON	532	ACTIF	Slovaquie	France-République slovaque	FRANCE-RÉPUBLIQUE SLOVAQUE	du	OUI	AMITIE	\N	\N	NEANT	OUI	1	\N	2016-01-18 15:37:16	\N
GRPSEN	534	1	1993-01-01 00:00:00	\N	AIPLF	534	ACTIF	Caucase	France-Caucase	FRANCE-CAUCASE  (Azerbaïdjan, Géorgie)	du	OUI	AMITIE	\N	\N	NEANT	OUI	2	\N	2014-01-08 15:01:01	\N
GRPSEN	535	1	1993-03-09 00:00:00	2009-06-04 00:00:00	NON	535	ANCIEN	Koweït	France-Koweït	FRANCE-KOWEÏT	du	OUI	AMITIE	\N	\N	NEANT	OUI	0	\N	2014-01-02 15:38:57	\N
GRPSEN	556	1	1992-01-01 00:00:00	\N	NON	556	ACTIF	Asie Centrale	France-Asie Centrale	FRANCE-ASIE CENTRALE (Kazakhstan, Kirghizstan, Ouzbékistan, Tadjikistan, Turkménistan)	du	OUI	AMITIE	\N	\N	NEANT	OUI	3	\N	2014-02-28 16:41:15	\N
GRPSEN	571	1	1992-04-29 00:00:00	\N	AIPLF	571	ACTIF	Albanie	France-Albanie	FRANCE-ALBANIE	du	OUI	AMITIE	\N	\N	NEANT	OUI	1	\N	2014-02-28 16:38:28	\N
ETUDESSCN	974	1	2006-06-26 00:00:00	2008-09-30 00:00:00	NON	906	ANCIEN	Energies renouvelables	Section énergies renouvelables	Section énergies renouvelables	de la	OUI	ETUDES	\N	\N	ECON	OUI	0	\N	\N	\N
GRPSEN	978	520	2008-12-17 00:00:00	\N	NON	978	ACTIF	Pays du Cône Sud	France-Pays du Cône Sud	FRANCE-PAYS DU CÔNE SUD (Argentine, Chili, Paraguay, Uruguay)	du	OUI	AMITIE	\N	\N	NEANT	OUI	3	\N	2014-09-24 15:49:25	\N
GRPSEN	572	1	1980-01-01 00:00:00	\N	AIPLF	572	ACTIF	Afrique centrale	France-Afrique centrale	FRANCE-AFRIQUE CENTRALE (Burundi, Cameroun, Centrafrique, Congo, République démocratique du Congo, Gabon, Guinée équatoriale, Ouganda, Rwanda, Sao Tomé-et-Principe, Tchad)	du	OUI	AMITIE	\N	\N	NEANT	OUI	3	\N	2017-03-07 17:38:08	\N
GRPSEN	573	1	1978-01-01 00:00:00	\N	AIPLF	573	ACTIF	Afrique de l'Ouest	France-Afrique de l'Ouest	FRANCE-AFRIQUE DE L'OUEST (Bénin, Burkina Faso, Cap-Vert, Côte d'Ivoire, Gambie, Ghana, Guinée, Guinée-Bissau, Liberia, Mali, Mauritanie, Niger, Nigeria,  Sénégal, Sierra Leone, Togo)	du	OUI	AMITIE	\N	\N	NEANT	OUI	2	\N	2018-03-23 12:34:13	\N
GRPSEN	574	1	1953-03-10 00:00:00	\N	NON	574	ACTIF	Afrique du Sud	France-Afrique du Sud	FRANCE-AFRIQUE DU SUD (Lesotho, Eswatini)	du	OUI	AMITIE	\N	\N	NEANT	OUI	3	\N	2014-02-28 16:38:09	\N
ETUDESSCN	992	1	2012-01-25 00:00:00	2015-01-28 00:00:00	NON	919	ANCIEN	Trufficulture	Trufficulture	Trufficulture	de la	OUI	ETUDES	\N	\N	CAE	OUI	0	\N	\N	\N
GRPSEN	595	1	1960-12-13 00:00:00	\N	NON	595	ACTIF	Israël	France-Israël	FRANCE-ISRAEL	du	OUI	AMITIE	\N	\N	NEANT	OUI	2	\N	2016-05-30 09:28:58	\N
GRPSEN	596	1	1960-12-30 00:00:00	\N	NON	596	ACTIF	Japon	France-Japon	FRANCE-JAPON	du	OUI	AMITIE	\N	\N	NEANT	OUI	3	\N	2014-01-02 15:38:57	\N
GRPSEN	597	1	1965-04-22 00:00:00	\N	AIPLF	597	ACTIF	Liban	France-Liban	FRANCE-LIBAN	du	OUI	AMITIE	\N	\N	NEANT	OUI	2	\N	2014-01-02 15:38:57	\N
ETUDESSCN	980	1	2009-02-17 00:00:00	2011-09-30 00:00:00	NON	911	ANCIEN	Tauromachie	Section Tauromachie	Section Tauromachie	de la	OUI	ETUDES	\N	\N	ECON	OUI	0	\N	\N	\N
GRPSEN	673	673	2007-01-01 00:00:00	\N	AIPLF	673	ACTIF	Monaco	France-Monaco	FRANCE-MONACO	du	OUI	AMITIE	\N	\N	NEANT	OUI	1	\N	2014-01-02 15:38:57	\N
GRPLIAISON	CHRETORIENT	\N	2015-06-04 00:00:00	\N	\N	\N	ACTIF	Chrétiens d'Orient	Chrétiens d'Orient	Chrétiens d'Orient, minorités au Moyen-Orient et Kurdes	\N	OUI	LIAISON	/commission/groupe_solidarite_chretiens_et_minorites_moyen_orient.html	\N	NEANT	OUI	0	2016-02-11 18:00:21	2016-02-12 11:04:01	\N
ETUDES	927	1	1980-01-01 00:00:00	2008-12-31 00:00:00	NON	927	ANCIEN	Exclusion	Groupe d'études sur la lutte contre l'exclusion	Groupe d'études sur la lutte contre l'exclusion	du	OUI	ETUDES	\N	\N	SOCI	OUI	0	\N	\N	\N
ETUDES	929	1	1987-01-01 00:00:00	2008-12-31 00:00:00	NON	929	ANCIEN	Drogue et toxicomanie	Groupe d'études sur la lutte contre la drogue et la toxicomanie	Groupe d'études sur la lutte contre la drogue et la toxicomanie	du	OUI	ETUDES	\N	\N	SOCI	OUI	0	\N	\N	\N
ETUDES	932	1	2001-01-01 00:00:00	2008-12-31 00:00:00	NON	932	ANCIEN	Enfance et adolescence	Groupe d'études sur les problématiques de l'enfance	Groupe d'études sur les problématiques de l'enfance et de l'adolescence	du	OUI	ETUDES	\N	\N	SOCI	OUI	0	\N	\N	\N
ETUDES	923	1	2001-01-01 00:00:00	2002-06-30 00:00:00	NON	923	ANCIEN	Horticulture	Groupe d'études sur l'horticulture	Groupe d'études sur l'horticulture	du	OUI	ETUDES	\N	\N	ECON	OUI	0	\N	\N	\N
ETUDES	924	1	2002-01-01 00:00:00	2008-09-30 00:00:00	NON	924	ANCIEN	Industrie du bâtiment et des travaux publics	Groupe d'études sur l'industrie du BTP	Groupe d'études sur l'industrie du bâtiment et des travaux publics	du	OUI	ETUDES	\N	\N	ECON	OUI	0	\N	\N	\N
ETUDES	925	1	1986-01-01 00:00:00	2002-06-30 00:00:00	NON	925	ANCIEN	Industrie textile et de l'habillement	Groupe d'études sur l'industrie textile et de l'habillement	Groupe d'études sur les problèmes relatifs à l'industrie textile et de l'habillement	du	OUI	ETUDES	\N	\N	ECON	OUI	0	\N	\N	\N
ETUDES	926	1	1976-01-01 00:00:00	2003-06-30 00:00:00	NON	926	ANCIEN	Veuvage	Groupe d'études des problèmes du veuvage	Groupe d'études des problèmes du veuvage	du	OUI	ETUDES	\N	\N	SOCI	OUI	0	\N	\N	\N
ETUDES	928	1	2021-05-20 00:00:00	\N	NON	928	ACTIF	Monde combattant et mémoire	Groupe d'études Monde combattant et mémoire	Groupe d'études Monde combattant et mémoire	du	OUI	ETUDES	\N	\N	SOCI	OUI	0	\N	\N	\N
ETUDES	930	1	1997-01-01 00:00:00	2003-06-30 00:00:00	NON	930	ANCIEN	Démographie et population mondiale	Groupe d'études «Démographie et population mondiale»	Groupe d'études «Démographie et population mondiale»	du	OUI	ETUDES	\N	\N	SOCI	OUI	0	\N	\N	\N
ETUDES	931	1	1992-01-01 00:00:00	2011-09-30 00:00:00	NON	931	ANCIEN	Thermalisme et le climatisme	Groupe d'études sur le thermalisme et le climatisme	Groupe d'études sur le thermalisme et le climatisme	du	OUI	ETUDES	\N	\N	SOCI	OUI	0	\N	\N	\N
ETUDES	933	1	1968-01-01 00:00:00	\N	NON	933	ACTIF	Aviation civile	Groupe d'études Aviation civile	Groupe d'études Aviation civile	du	OUI	ETUDES	\N	\N	FINC	OUI	0	\N	\N	\N
ETUDES	934	1	1983-01-01 00:00:00	\N	NON	934	ACTIF	Pratiques sportives et grands événements sportifs	Groupe d'études Pratiques sportives et grands événements sportifs	Groupe d'études Pratiques sportives et grands événements sportifs	du	OUI	ETUDES	\N	\N	AFCL	OUI	0	\N	\N	\N
ETUDES	935	1	1994-01-01 00:00:00	2002-06-30 00:00:00	NON	935	ANCIEN	Politique spatiale française et européenne	Groupe d'études politique spatiale française et européenne	Groupe d'études relatif à la politique spatiale française et européenne	du	OUI	ETUDES	\N	\N	FINC	OUI	0	\N	\N	\N
ETUDES	936	1	1998-01-01 00:00:00	2002-06-30 00:00:00	NON	936	ANCIEN	ONG (Organisations non gouvernementales)	Groupe d'études sur les ONG	Groupe d'études sur les ONG (Organisations non gouvernementales)	du	OUI	ETUDES	\N	\N	FINC	OUI	0	\N	\N	\N
ETUDES	937	1	1999-01-01 00:00:00	2010-01-28 00:00:00	NON	937	ANCIEN	Prospective	Groupe d'études de prospective	Groupe d'études de prospective	du	OUI	ETUDES	\N	\N	FINC	OUI	0	\N	\N	\N
ETUDES	938	1	1985-01-01 00:00:00	\N	NON	938	ACTIF	TAAF	Groupe d'études Arctique, Antarctique et Terres australes	Groupe d'études Arctique, Antarctique et Terres australes	du	OUI	ETUDES	\N	\N	LOIS	OUI	0	\N	\N	\N
ETUDES	939	1	1989-01-01 00:00:00	2003-06-30 00:00:00	NON	939	ANCIEN	Sénateurs conseillers régionaux	Groupe d'études sur les sénateurs conseillers régionaux	Groupe d'études sur les sénateurs conseillers régionaux	du	OUI	ETUDES	\N	\N	LOIS	OUI	0	\N	\N	\N
ETUDES	940	1	1999-01-01 00:00:00	2011-09-30 00:00:00	NON	940	ANCIEN	Sécurité et défense civiles	Groupe d'études sur la sécurité et la défense civiles	Groupe d'études sur la sécurité et la défense civiles	du	OUI	ETUDES	\N	\N	LOIS	OUI	0	\N	\N	\N
ETUDES	941	1	2000-01-01 00:00:00	2006-12-31 00:00:00	NON	941	ANCIEN	Evaluation des politiques publiques	Comité évaluation des politiques publiques	Comité d'évaluation des politiques publiques	du	OUI	ETUDES	\N	\N	FINC	OUI	0	\N	\N	\N
ETUDES	942	1	1993-01-01 00:00:00	2003-06-30 00:00:00	NON	942	ANCIEN	Défense des services publics	Intergroupe défense des services publics	Intergroupe défense des services publics	de l'	OUI	ETUDES	\N	\N	NEANT	OUI	0	\N	\N	\N
ETUDES	947	1	1993-01-01 00:00:00	2011-09-30 00:00:00	NON	947	ANCIEN	Musiques et chanson française	Groupe d'études musiques et chanson française	Groupe d'études musiques et chanson française	du	OUI	ETUDES	\N	\N	AFCL	OUI	0	\N	\N	\N
ETUDES	948	1	1996-01-01 00:00:00	\N	NON	948	ACTIF	Forêt et filière bois	Groupe d'études Forêt et filière bois	Groupe d'études Forêt et filière bois	du	OUI	ETUDES	\N	\N	CAE	OUI	0	\N	\N	\N
GRPSEN	670	670	2003-06-30 00:00:00	2007-02-14 00:00:00	NON	670	ANCIEN	Serbie	France- Serbie	FRANCE-SERBIE	du	OUI	AMITIE	\N	\N	NEANT	OUI	0	\N	2014-11-19 10:56:58	\N
ETUDESSCN	951	1	2003-10-01 00:00:00	2008-12-31 00:00:00	NON	902	ANCIEN	tourisme et métiers d'art	section Tourisme et métiers d'art	Groupe d'études sur les métiers d'art - Section Tourisme et métiers d'art	de la	OUI	ETUDES	\N	\N	AFCL	OUI	0	\N	\N	\N
ETUDES	954	560	2004-12-14 00:00:00	2011-09-30 00:00:00	NON	954	ANCIEN	Fruits et légumes	Groupe d'études fruits et légumes	Groupe d'études fruits et légumes	du	OUI	ETUDES	\N	\N	ECON	OUI	0	\N	\N	\N
GRPSEN	644	644	1996-11-26 00:00:00	\N	AIPLF	644	ACTIF	Syrie	France-Syrie	FRANCE-SYRIE	du	OUI	AMITIE	\N	\N	NEANT	OUI	2	\N	2017-07-31 09:57:14	\N
ETUDES	957	563	2005-03-15 00:00:00	\N	NON	957	ACTIF	Industrie	Groupe d'études Industrie	Groupe d'études Industrie	du	OUI	ETUDES	\N	\N	CAE	OUI	0	\N	\N	\N
GRPSEN	963	1	2005-11-01 00:00:00	\N	AIPLF	963	ACTIF	Andorre	France-Andorre	FRANCE-ANDORRE	du	OUI	AMITIE	\N	\N	NEANT	OUI	1	\N	2014-03-04 16:58:44	\N
ETUDESSCN	964	1	2006-01-31 00:00:00	2011-09-30 00:00:00	NON	907	ANCIEN	Trufficulture	Section trufficulture	Section trufficulture	de la	OUI	ETUDES	\N	\N	ECON	OUI	0	\N	\N	\N
ETUDES	965	1	2006-06-23 00:00:00	2017-10-01 00:00:00	NON	965	ANCIEN	Société numérique, nouveaux usages, nouveaux médias	Groupe d'études Société numérique, nouveaux usages, nouveaux médias	Groupe d'études Société numérique, nouveaux usages, nouveaux médias	du	OUI	ETUDES	\N	\N	AFCL	OUI	0	\N	\N	\N
ETUDES	968	523	2006-09-01 00:00:00	2011-09-30 00:00:00	NON	968	ANCIEN	Artisanat et services	Groupe d'étude Artisanat et services	Groupe d'étude Artisanat et services	du	OUI	AMITIE	\N	\N	ECON	OUI	0	\N	2015-02-04 15:26:12	\N
GRPSEN	674	674	2006-02-01 00:00:00	\N	AIPLF	674	ACTIF	Balkans Occidentaux	France-Balkans Occidentaux	FRANCE-BALKANS OCCIDENTAUX	du	OUI	AMITIE	\N	\N	NEANT	OUI	2	\N	2014-02-28 16:48:01	\N
ETUDES	966	1	2006-07-08 00:00:00	\N	NON	966	ACTIF	Arts de la scène, arts de la rue et festivals en régions	Groupe d'études Arts de la scène, arts de la rue et festivals en régions 	Groupe d'études Arts de la scène, arts de la rue et festivals en régions	du	OUI	ETUDES	\N	\N	AFCL	OUI	0	\N	\N	\N
GRPSEN	653	653	2009-05-20 00:00:00	\N	NON	653	ACTIF	Indonésie et Timor-Est	France-Indonésie et Timor-Est	FRANCE-INDONÉSIE ET TIMOR-EST	du	OUI	AMITIE	\N	\N	NEANT	OUI	3	\N	2014-01-08 15:29:52	\N
ETUDESSCN	993	1	2012-02-22 00:00:00	2015-01-28 00:00:00	NON	919	ANCIEN	Oléiculture	Section oléiculture	Section Oléiculture	de la	OUI	ETUDES	\N	\N	CAE	OUI	0	\N	\N	\N
ETUDES	991	1	2011-12-14 00:00:00	2017-10-01 00:00:00	NON	991	ANCIEN	Éducation populaire et culture	Groupe d'études Éducation populaire et culture	Groupe d'études Éducation populaire et culture	du	OUI	ETUDES	\N	\N	AFCL	OUI	0	\N	\N	\N
ETUDES	998	1	2012-10-10 00:00:00	\N	NON	998	ACTIF	Économie Sociale et Solidaire	Groupe d'études Économie sociale et solidaire	Groupe d'études Économie sociale et solidaire	du	OUI	ETUDES	\N	\N	CAE	OUI	0	\N	2013-05-28 17:22:58	\N
ETUDES	990	1	2011-12-14 00:00:00	2017-10-01 00:00:00	NON	990	ANCIEN	Photographie et autres arts visuels	Groupe d'études Photographie et autres arts visuels	Groupe d'études sur la photographie et les autres arts visuels	du	OUI	ETUDES	\N	\N	AFCL	OUI	0	\N	2014-02-13 10:39:24	\N
ETUDESSCN	997	1	2012-07-13 00:00:00	2015-01-28 00:00:00	NON	919	ANCIEN	Fruits et légumes	Section Fruits et Légumes	Section Fruits et Légumes	de la	OUI	ETUDES	\N	\N	CAE	OUI	0	\N	\N	\N
GRPSEN	575	1	1963-01-01 00:00:00	\N	AIPLF	575	ACTIF	Algérie	France-Algérie	FRANCE-ALGERIE	du	OUI	AMITIE	\N	\N	NEANT	OUI	2	\N	2014-02-28 16:38:44	\N
GRPSEN	576	\N	1951-01-01 00:00:00	\N	NON	576	ACTIF	Brésil	France-Brésil	FRANCE-BRESIL (Guyana, Suriname)	du	OUI	AMITIE	\N	\N	NEANT	OUI	3	\N	2014-02-28 16:48:40	\N
GRPSEN	577	1	1991-01-01 00:00:00	\N	AIPLF	577	ACTIF	Cambodge et Laos	France-Cambodge et Laos	FRANCE-CAMBODGE ET LAOS	du	OUI	AMITIE	\N	\N	NEANT	OUI	3	\N	2014-02-28 16:49:50	\N
GRPSEN	578	1	1980-01-01 00:00:00	\N	NON	578	ACTIF	Australie	France-Australie	FRANCE-AUSTRALIE	du	OUI	AMITIE	\N	\N	NEANT	OUI	3	\N	2014-02-28 16:41:54	\N
GRPSEN	579	1	1957-01-01 00:00:00	\N	NON	579	ACTIF	Autriche	France-Autriche	FRANCE-AUTRICHE	du	OUI	AMITIE	\N	\N	NEANT	OUI	1	\N	2014-02-28 16:42:23	\N
GRPSEN	580	1	1997-01-01 00:00:00	\N	AIPLF	580	ACTIF	Belgique et Luxembourg	France-Belgique et Luxembourg	FRANCE-BELGIQUE et LUXEMBOURG	du	OUI	AMITIE	\N	\N	NEANT	OUI	1	\N	2016-05-30 09:27:12	\N
GRPSEN	581	1	1947-07-08 00:00:00	\N	NON	581	ACTIF	Royaume-Uni	France-Royaume-Uni	FRANCE-ROYAUME-UNI	du	OUI	AMITIE	\N	\N	NEANT	OUI	1	\N	2013-07-26 09:44:18	\N
GRPSEN	582	1	1960-01-01 00:00:00	\N	AIPLF	582	ACTIF	Bulgarie	France-Bulgarie	FRANCE-BULGARIE	du	OUI	AMITIE	\N	\N	NEANT	OUI	2	\N	2014-02-28 16:49:33	\N
GRPSEN	583	1	1951-01-01 00:00:00	\N	AIPLF	583	ACTIF	Canada	France-Canada	FRANCE-CANADA	du	OUI	AMITIE	\N	\N	NEANT	OUI	3	\N	2014-02-28 16:50:01	\N
GRPSEN	584	1	1971-12-09 00:00:00	\N	NON	584	ACTIF	Chine	France-République populaire de Chine	FRANCE-REPUBLIQUE POPULAIRE DE CHINE	du	OUI	AMITIE	\N	\N	NEANT	OUI	3	\N	2017-07-31 09:58:04	\N
GRPSEN	585	1	1978-01-01 00:00:00	\N	NON	585	ACTIF	Chypre	France-Chypre	FRANCE-CHYPRE	du	OUI	AMITIE	\N	\N	NEANT	OUI	2	\N	2014-01-02 15:38:58	\N
GRPSEN	586	1	1974-12-10 00:00:00	\N	NON	586	ACTIF	Corée du Nord	Groupe d'études et de contact France-République populaire démocratique de Corée	Groupe d'études et de contact FRANCE-RÉPUBLIQUE POPULAIRE DÉMOCRATIQUE DE CORÉE	du	OUI	AMITIE	\N	\N	NEANT	OUI	3	\N	2017-07-31 09:56:47	\N
GRPSEN	587	1	1981-07-22 00:00:00	1998-09-30 00:00:00	NON	587	ANCIEN	Caraïbes	France-Caraïbes	FRANCE-CARAÏBES (Anguilla, Antigua et Barbuda, Bahamas, Barbade, Cuba, Dominique, Haïti, Jamaïque, Saint-Domingue, Sainte-Lucie, Trinité et Tobago)	du	NON	AMITIE	\N	\N	NEANT	OUI	3	\N	2014-01-13 18:16:36	\N
GRPSEN	979	0	2008-12-17 00:00:00	\N	NON	979	ACTIF	Pays Andins	France-Pays Andins	FRANCE-PAYS ANDINS (Bolivie, Colombie, Equateur, Pérou, Venezuela )	du	OUI	AMITIE	\N	\N	NEANT	OUI	3	\N	2014-09-24 15:49:25	\N
GRPSEN	588	588	1996-01-01 00:00:00	\N	AIPLF	588	ACTIF	Pays de la Corne de l'Afrique	France-Pays de la Corne de l'Afrique	FRANCE-PAYS DE LA CORNE DE L'AFRIQUE (Djibouti, Erythrée, Ethiopie, Somalie, Soudan)	du	OUI	AMITIE	\N	\N	NEANT	OUI	3	\N	2016-01-18 15:33:33	\N
GRPSEN	589	1	1950-01-01 00:00:00	\N	NON	589	ACTIF	Espagne	France-Espagne	FRANCE-ESPAGNE	du	OUI	AMITIE	\N	\N	NEANT	OUI	1	\N	2014-01-02 15:38:59	\N
GRPSEN	590	1	1947-05-30 00:00:00	\N	NON	590	ACTIF	Etats-Unis	France-Etats-Unis	FRANCE-ETATS-UNIS	du	OUI	AMITIE	\N	\N	NEANT	OUI	3	\N	2014-01-02 15:38:59	\N
GRPSEN	591	1	1961-05-10 00:00:00	\N	NON	591	ACTIF	Grèce	France-Grèce	FRANCE-GRECE	du	OUI	AMITIE	\N	\N	NEANT	OUI	2	\N	2017-07-31 11:07:04	\N
GRPSEN	592	1	1975-12-02 00:00:00	\N	AIPLF	592	ACTIF	Hongrie	France-Hongrie	FRANCE-HONGRIE	du	OUI	AMITIE	\N	\N	NEANT	OUI	1	\N	2014-01-02 15:38:59	\N
GRPSEN	593	1	1977-12-22 00:00:00	1996-06-01 00:00:00	NON	593	ANCIEN	Ile Maurice	France-Ile Maurice	FRANCE-ILE MAURICE	du	NON	AMITIE	\N	\N	NEANT	OUI	0	\N	2014-01-02 15:38:59	\N
GRPSEN	594	1	1988-06-16 00:00:00	\N	NON	594	ACTIF	Irlande	France-Irlande	FRANCE-IRLANDE	du	OUI	AMITIE	\N	\N	NEANT	OUI	1	\N	2016-05-30 09:33:01	\N
GRPSEN	598	1	1963-05-31 00:00:00	\N	AIPLF	598	ACTIF	Maroc	France-Maroc	FRANCE-MAROC	du	OUI	AMITIE	/international/groupes_interparlementaires/groupe_maroc.html	\N	NEANT	OUI	2	\N	2014-01-02 15:38:59	\N
GRPSEN	599	1	1949-01-01 00:00:00	\N	NON	599	ACTIF	Pays-Bas	France-Pays-Bas	FRANCE-PAYS-BAS	du	OUI	AMITIE	\N	\N	NEANT	OUI	1	\N	2014-01-02 15:38:59	\N
GRPSEN	600	1	1956-01-01 00:00:00	\N	AIPLF	600	ACTIF	Pologne	France-Pologne	FRANCE-POLOGNE	du	OUI	AMITIE	\N	\N	NEANT	OUI	1	\N	2017-03-13 15:09:10	\N
GRPSEN	601	1	1978-10-03 00:00:00	\N	NON	601	ACTIF	Portugal	France-Portugal	FRANCE-PORTUGAL	du	OUI	AMITIE	\N	\N	NEANT	OUI	1	\N	2014-01-02 15:38:59	\N
GRPSEN	602	1	1973-06-21 00:00:00	\N	AIPLF	602	ACTIF	Québec	France-Québec	FRANCE-QUÉBEC	du	OUI	AMITIE	\N	\N	NEANT	OUI	3	\N	2014-01-02 15:38:59	\N
GRPSEN	603	1	1993-06-08 00:00:00	\N	NON	603	ACTIF	Malte	France-Malte	FRANCE-MALTE	du	OUI	AMITIE	\N	\N	NEANT	OUI	2	\N	2014-01-02 15:39:00	\N
GRPSEN	604	1	1961-01-01 00:00:00	\N	NON	604	ACTIF	Allemagne	France-Allemagne	FRANCE-ALLEMAGNE	du	OUI	AMITIE	\N	\N	NEANT	OUI	1	\N	2014-02-28 16:39:06	\N
GRPSEN	605	1	1961-01-01 00:00:00	\N	AIPLF	605	ACTIF	Roumanie	France-Roumanie	FRANCE-ROUMANIE	du	OUI	AMITIE	\N	\N	NEANT	OUI	1	\N	2014-01-02 15:39:00	\N
GRPSEN	606	1	1977-11-08 00:00:00	2014-09-30 00:00:00	NON	606	ANCIEN	Afrique de l'Ouest	France-Afrique de l'Ouest	France-Afrique de l'Ouest	du	NON	AMITIE	\N	\N	NEANT	OUI	0	\N	2014-10-30 11:53:27	\N
GRPSEN	607	1	1978-04-05 00:00:00	2003-06-17 00:00:00	NON	607	ANCIEN	Soudan	France-Soudan	FRANCE-SOUDAN	du	NON	AMITIE	\N	\N	NEANT	OUI	0	\N	2014-09-24 15:49:25	\N
GRPSEN	608	1	1955-06-26 00:00:00	\N	NON	608	ACTIF	Russie	France-Russie	FRANCE-RUSSIE	du	OUI	AMITIE	\N	\N	NEANT	OUI	3	\N	2016-05-30 09:29:40	\N
GRPSEN	550	1	2014-10-07 00:00:00	\N	\N	550	ACTIF	Sri Lanka	France-Sri Lanka	FRANCE-SRI LANKA	\N	OUI	AMITIE	\N	\N	NEANT	OUI	3	2014-10-07 10:45:32	2014-10-07 11:12:01	\N
ETUDES	1003	1	2015-01-28 00:00:00	2017-10-01 00:00:00	NON	1003	ANCIEN	Fruits et légumes	Groupe d'études Fruits et légumes	Groupe d'études Fruits et légumes	du	OUI	ETUDES	\N	\N	CAE	OUI	0	\N	2015-03-20 09:42:25	\N
GRPSEN	609	1	1979-12-19 00:00:00	\N	NON	609	ACTIF	Asie du Sud-Est	France-Asie du Sud-Est	FRANCE-ASIE DU SUD-EST (Bangladesh, Birmanie, Brunei, Malaisie, Philippines, Singapour, Thaïlande)	du	OUI	AMITIE	\N	\N	NEANT	OUI	3	\N	2014-03-04 16:48:55	\N
GRPSEN	610	1	1978-11-29 00:00:00	\N	AIPLF	610	ACTIF	Suisse	France-Suisse	FRANCE-SUISSE	du	OUI	AMITIE	\N	\N	NEANT	OUI	1	\N	2014-01-02 15:39:00	\N
GRPSEN	611	1	1957-06-21 00:00:00	\N	AIPLF	611	ACTIF	Tchéquie	France-République Tchèque	FRANCE-RÉPUBLIQUE TCHÈQUE	du	OUI	AMITIE	\N	\N	NEANT	OUI	1	\N	2014-01-02 15:39:00	\N
GRPSEN	612	1	1982-06-03 00:00:00	\N	NON	612	ACTIF	Mongolie	France-Mongolie	FRANCE-MONGOLIE	du	OUI	AMITIE	\N	\N	NEANT	OUI	3	\N	2014-01-02 15:39:00	\N
GRPSEN	613	1	1976-12-04 00:00:00	\N	NON	613	ACTIF	Corée du Sud	France-Corée du Sud	FRANCE-COREE DU SUD	du	OUI	AMITIE	\N	\N	NEANT	OUI	3	\N	2018-02-01 18:00:15	\N
GRPSEN	614	1	1990-07-04 00:00:00	1998-06-02 00:00:00	NON	614	ANCIEN	Luxembourg	France-Grand Duché du Luxembourg	FRANCE-GRAND DUCHÉ DU LUXEMBOURG	du	NON	AMITIE	\N	\N	NEANT	OUI	0	\N	2014-01-02 15:39:00	\N
GRPSEN	615	1	1983-01-01 00:00:00	\N	NON	615	ACTIF	Irak	France-Irak	FRANCE-IRAK	du	OUI	AMITIE	\N	\N	NEANT	OUI	3	\N	2017-06-13 11:42:28	\N
GRPSEN	616	1	1991-11-13 00:00:00	\N	AIPLF	616	ACTIF	Pays Baltes	France-Pays Baltes	FRANCE-PAYS BALTES (Estonie, Lettonie, Lituanie)	du	OUI	AMITIE	\N	\N	NEANT	OUI	2	\N	2015-10-20 14:46:33	\N
GRPSEN	617	1	1956-01-01 00:00:00	\N	AIPLF	617	ACTIF	Egypte	France-Egypte	FRANCE-EGYPTE	du	OUI	AMITIE	\N	\N	NEANT	OUI	2	\N	2014-01-02 15:39:00	\N
GRPSEN	618	1	1985-05-29 00:00:00	\N	NON	618	ACTIF	Inde	France-Inde	FRANCE-INDE	du	OUI	AMITIE	\N	\N	NEANT	OUI	3	\N	2014-01-02 15:39:00	\N
GRPSEN	619	1	1984-12-20 00:00:00	\N	NON	619	ACTIF	Pakistan	France-Pakistan	FRANCE-PAKISTAN	du	OUI	AMITIE	\N	\N	NEANT	OUI	3	\N	2017-06-13 11:43:45	\N
GRPSEN	620	1	1997-01-01 00:00:00	\N	AIPLF	620	ACTIF	Tunisie	France-Tunisie	FRANCE-TUNISIE	du	OUI	AMITIE	\N	\N	NEANT	OUI	2	\N	2014-01-02 15:39:00	\N
GRPSEN	621	1	1950-06-26 00:00:00	\N	NON	621	ACTIF	Italie	France-Italie	FRANCE-ITALIE	du	OUI	AMITIE	\N	\N	NEANT	OUI	1	\N	2014-01-02 15:39:00	\N
ETUDES	1008	1	2018-01-25 00:00:00	\N	NON	1008	ACTIF	Numérique	Groupe Numérique	Groupe Numérique	du	OUI	ETUDES	\N	\N	NEANT	OUI	0	\N	\N	TOUTCOM
ETUDESSCN	1005	1	2016-06-15 00:00:00	\N	NON	919	ACTIF	Section Cultures traditionnelles et spécialisées	Section Cultures traditionnelles et spécialisées	Section Cultures traditionnelles et spécialisées	de la	OUI	ETUDES	\N	\N	CAE	OUI	0	\N	\N	\N
GRPSEN	852	\N	2018-01-30 00:00:00	\N	\N	852	ACTIF	Biélorussie	France-Biélorussie	FRANCE-BIÉLORUSSIE	\N	OUI	AMITIE	\N	\N	NEANT	OUI	1	2018-01-30 10:14:37	2018-01-30 10:18:08	\N
ETUDES	1010	1	2021-02-03 00:00:00	\N	NON	1010	ACTIF	Statut, rôle et place des Français établis hors de France	Groupe d'études Statut, rôle et place des Français établis hors de France	Groupe d'études Statut, rôle et place des Français établis hors de France	du	OUI	ETUDES	\N	\N	LOIS	OUI	0	\N	\N	\N
ETUDES	1004	1	2016-06-07 00:00:00	\N	NON	1004	ACTIF	Cancer	Groupe d'études Cancer	Groupe d'études sur le cancer	du	OUI	ETUDES	\N	\N	SOCI	OUI	0	\N	\N	\N
ETUDES	1014	1	2022-12-15 00:00:00	\N	NON	1014	ACTIF	Handicap	Groupe d'études Handicap	Groupe d'études sur le handicap	du	OUI	ETUDES	\N	\N	SOCI	OUI	0	\N	\N	\N
ETUDES	1006	1	2020-12-10 00:00:00	\N	NON	1006	ACTIF	Francophonie	Groupe d'études Francophonie	Groupe d'études Francophonie	du	OUI	ETUDES	\N	\N	AFCL	OUI	0	\N	\N	\N
ETUDES	1007	1	2017-12-07 00:00:00	\N	NON	1007	ACTIF	Métiers d'art	Groupe d'études Métiers d'art	Groupe d'études Métiers d'art	du	OUI	ETUDES	\N	\N	AFCL	OUI	0	\N	\N	\N
ETUDESSCN	1011	1	2021-03-25 00:00:00	\N	NON	919	ACTIF	Animal et société	Section Animal et société	Section Animal et société	de la	OUI	ETUDES	\N	\N	CAE	OUI	0	\N	\N	\N
ETUDESSCN	1012	1	2021-06-09 00:00:00	\N	NON	919	ACTIF	Section Pêche et produits de la mer	Section Pêche et produits de la mer	Section Pêche et produits de la mer	de la	OUI	ETUDES	\N	\N	CAE	OUI	0	\N	\N	\N
GRPSEN	1013	1013	2021-12-15 00:00:00	\N	\N	1013	ACTIF	Haut-Karabagh	Groupe d'information internationale sur le Haut-Karabagh	Groupe d'information internationale sur le Haut-Karabagh	du	OUI	AMITIE	http://www.senat.fr/groupe-interparlementaire-amitie/ami_1013.html	\N	NEANT	OUI	1	\N	\N	\N
\.


--
-- Data for Name: libcom; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY libcom (orgcod, libcomdatdeb, libcomdatfin, temvalcod, evelic, evelib, evelil, libcomart, libcomlilmin, libcomlibameli, syscredat, sysmajdat, libcomid) FROM stdin;
NEANT	1900-01-01 00:00:00	\N	ACTIF	Aucune	                     	Aucune  (Président du Sénat)	d'	Aucune  (Président du Sénat)	Aucune (Président du Sénat)	\N	\N	35
SOCI	1900-01-01 00:00:00	\N	ACTIF	SOCI	Affaires sociales	COMMISSION DES AFFAIRES SOCIALES	de la 	commission des affaires sociales	commission des affaires sociales	\N	\N	36
CORSE	2001-06-19 00:00:00	2001-11-19 00:00:00	ANCIEN	Corse	Commission spéciale sur  la Corse	COMMISSION SPECIALE SUR LE PROJET DE LOI RELATIF A LA CORSE	de la 	commission spéciale sur le projet de loi relatif à la Corse	Commission spéciale sur  la Corse	\N	\N	37
COMSPEAPU	1900-01-01 00:00:00	2009-06-21 00:00:00	ANCIEN	Commission d'apuration comptes	Commission spéciale chargée d'apurer les comptes	COMMISSION SPÉCIALE CHARGÉE DE VÉRIFIER ET D'APURER LES COMPTES	de la	commission spéciale chargée de vérifier et d'apurer les comptes	Commission spéciale chargée de vérifier et d'apurer les comptes	\N	\N	38
20040123N2	2004-01-23 00:00:00	\N	\N	\N	Evolutions de la criminalité	\N	du	projet de loi portant adaptation de la justice aux évolutions de la criminalité	\N	\N	\N	39
20040211N3	2004-02-11 00:00:00	\N	\N	\N	Formation professionnelle et dialogue social	\N	du	projet de loi relatif à la formation professionnelle tout au long de la vie et au dialogue social	\N	\N	\N	40
20040413N4	2004-04-13 00:00:00	\N	\N	\N	Economie numérique	\N	du	projet de loi pour la confiance dans l'économie numérique	\N	\N	\N	41
20040415N5	2004-04-15 00:00:00	\N	\N	\N	Divorce	\N	du	projet de loi relatif au divorce	\N	\N	\N	42
20040512N6	2004-05-12 00:00:00	\N	\N	\N	Communications électroniques et services de communication au	\N	du	projet de loi relatif aux communications électroniques et aux services de communication audiovisuelle	\N	\N	\N	43
20040526N7	2004-05-26 00:00:00	\N	\N	\N	solidarité pour l'autonomie des personnes âgées et des personnes handicapées	\N	du	projet de loi relatif à la solidarité pour l'autonomie des personnes âgées et des personnes handicapées	\N	\N	\N	44
20061115N50	2006-11-23 00:00:00	2006-11-28 00:00:00	\N	\N	participation et actionnariat salarié	\N	du	projet de loi pour le développement de la participation et de l'actionnariat salarié	\N	\N	\N	45
2007CMP2	2007-01-25 00:00:00	2007-01-31 00:00:00	\N	\N	adaptation au droit communautaire dans le domaine du médicament	\N	du	projet de loi portant diverses dispositions d'adaptation au droit communautaire dans le domaine du médicament	\N	\N	\N	46
OUTREMER	2009-03-05 00:00:00	2009-07-07 00:00:00	ACTIF	MCI OUTRE MER	Mission commune d'information "Outre-mer"	MISSION COMMUNE D'INFORMATION SUR LA SITUATION DES DEPARTEMENTS D'OUTRE-MER	de la	Mission commune d'information sur la situation des départements d'outre-mer	Mission commune d'information "Outre-mer"	\N	\N	47
DROGUE	2002-12-12 00:00:00	2003-05-27 00:00:00	ANCIEN	Drogues illicites	politique nationale de lutte contre les drogues illicites	COMMISSION D'ENQUÊTE SUR LA POLITIQUE NATIONALE DE LUTTE CONTRE LES DROGUES ILLICITES	de la	commission d'enquête sur la politique nationale de lutte contre les drogues illicites	\N	\N	\N	48
HANDICAPES	2002-12-12 00:00:00	2003-06-04 00:00:00	ANCIEN	Personnes handicapées	maltraitance envers les personnes handicapées	COMMISSION D'ENQUÊTE SUR LA MALTRAITANCE ENVERS LES PERSONNES HANDICAPÉES ACCUEILLIES EN INSTITUTION ET LES MOYENS DE LA PRÉVENIR	de la	commission d'enquête sur la maltraitance envers les personnes handicapées accueillies en institution et les moyens de la prévenir	\N	\N	\N	49
20030128N1	2003-01-28 00:00:00	\N	\N	\N	Sécurité intérieure	\N	du	projet de loi pour la sécurité intérieure	\N	\N	\N	50
20030515N2	2003-05-15 00:00:00	\N	\N	\N	Urbanisme, habitat et construction	\N	du	projet de loi portant diverses dispositions relatives à l'urbanisme, à l'habitat et à la construction	\N	\N	\N	51
2008CMP18	2008-12-09 00:00:00	2008-12-15 00:00:00	\N	\N	PJL de finances pour 2009	\N	du 	projet de loi de finances pour 2009	\N	\N	\N	52
INITIATIVE	2003-02-12 00:00:00	2003-07-21 00:00:00	ANCIEN	INITIATIVE ÉCONOMIQUE	COMMISSION SPÉCIALE "INITIATIVE ÉCONOMIQUE"	COMMISSION SPÉCIALE CHARGÉE D'EXAMINER LE PROJET DE LOI POUR L'INITIATIVE ÉCONOMIQUE	de la	commission spéciale chargée d'examiner le projet de loi pour l'initiative économique	Commission spéciale	\N	\N	53
20030612N3	2003-06-12 00:00:00	\N	\N	\N	outre-mer	\N	du	projet de loi de programme pour l'outre-mer	\N	\N	\N	54
20030618N4	2003-06-18 00:00:00	\N	\N	\N	initiative économique	\N	du	projet de loi pour l'initiative économique	\N	\N	\N	55
20030715N6	2003-07-15 00:00:00	\N	\N	\N	prévention des risques technologiques et naturels	\N	du	projet de loi relatif à la prévention des risques technologiques et naturels et à la réparation des dommages	\N	\N	\N	56
20030626N5	2003-06-26 00:00:00	\N	\N	\N	archéologie préventive	\N	du	projet de loi modifiant la loi n° 2001-44 du 17 janvier 2001 relative à l'archéologie préventive	\N	\N	\N	57
20030718N7	2003-07-18 00:00:00	\N	\N	\N	Réforme des retraites	\N	du	projet de loi portant réforme des retraites	\N	\N	\N	58
20030723N8	2003-07-23 00:00:00	\N	\N	\N	programmation pour la ville	\N	du	projet de loi d'orientation et de programmation pour la ville et la rénovation urbaine	\N	\N	\N	59
MCI	2003-10-08 00:00:00	2004-02-03 00:00:00	ANCIEN	Canicule	Mission commune d'information "Canicule"	MISSION COMMUNE D'INFORMATION " LA FRANCE ET LES FRANÇAIS FACE À LA CANICULE : LES LEÇONS D'UNE CRISE "	de la	mission commune d'information "La France et les Français face à la canicule : les leçons d'une crise"	\N	\N	\N	60
20031016N9	2003-10-16 00:00:00	\N	\N	\N	maîtrise de l'immigration	\N	du	projet de loi relatif à la maîtrise de l'immigration et au séjour des étrangers en France	\N	\N	\N	61
20031119N10	2003-11-19 00:00:00	\N	\N	\N	financement sécurité sociale pour 2004	\N	du	projet de loi de financement de la sécurité sociale pour 2004	\N	\N	\N	62
20031209N11	2003-12-09 00:00:00	\N	\N	\N	Projet de loi de finances pour 2004	\N	du	projet de loi de finances pour 2004	\N	\N	\N	63
20031217N12	2003-12-16 00:00:00	\N	\N	\N	Projet de loi de finances rectificative pour 2003	\N	du	projet de loi de finances rectificative pour 2003	\N	\N	\N	64
20040115N1	2004-01-15 00:00:00	\N	\N	\N	Polynésie française	\N	du	projet de loi organique portant statut d'autonomie de la Polynésie française et du projet de loi complétant le statut d'autonomie de la Polynésie française	\N	\N	\N	65
20040609N8	2004-06-09 00:00:00	\N	\N	\N	Bioéthique	\N	du	projet de loi relatif à la bioéthique	\N	\N	\N	66
20040708N9	2004-07-08 00:00:00	\N	\N	\N	EDF-GDF	\N	du	projet de loi relatif au service public de l'électricité et du gaz et aux entreprises électriques et gazières	\N	\N	\N	67
20040709N10	2004-07-09 00:00:00	\N	\N	\N	politique de santé publique	\N	du	projet de loi relatif à la politique de santé publique	\N	\N	\N	68
20040715N11	2004-07-15 00:00:00	\N	\N	\N	soutien à la consommation et à l'investissement	\N	du	projet de loi pour le soutien à la consommation et à l'investissement	\N	\N	\N	69
20040727N12	2004-07-27 00:00:00	\N	\N	\N	assurance maladie	\N	du	projet de loi relatif à l'assurance maladie	\N	\N	\N	70
20040727N13	2004-07-27 00:00:00	\N	\N	\N	modernisation de la sécurité civile	\N	du	projet de loi de modernisation de la sécurité civile	\N	\N	\N	71
20040727N14	2004-07-27 00:00:00	\N	\N	\N	libertés et responsabilités locales	\N	du	projet de loi relatif aux libertés et responsabilités locales	\N	\N	\N	72
20041118N15	2004-11-18 00:00:00	\N	\N	\N	sécurité sociale	\N	du	projet de loi de financement de la sécurité sociale pour 2005	\N	\N	\N	73
20040712N16	2004-12-07 00:00:00	\N	\N	\N	programmation pour la cohésion sociale	\N	du	projet de loi de programmation pour la cohésion sociale	\N	\N	\N	74
20041214N17	2004-12-14 00:00:00	\N	\N	\N	loi de finances pour 2005	\N	du	projet de loi de finances pour 2005	\N	\N	\N	75
20041221N18	2004-12-20 00:00:00	\N	\N	\N	loi de finances rectificative pour 2004	\N	du	projet de loi de finances rectificative pour 2004	\N	\N	\N	76
20041022N19	2004-10-20 00:00:00	\N	\N	\N	Simplification du droit	\N	du	projet de loi de simplification du droit	\N	\N	\N	77
AMIANTE	2005-02-02 00:00:00	2005-10-20 00:00:00	ANCIEN	MCI AMIANTE	Mission commune d'information "Amiante"	MISSION COMMUNE D'INFORMATION SUR LE BILAN ET LES CONSÉQUENCES DE LA CONTAMINATION PAR L'AMIANTE	de la	Mission commune d'information sur le bilan et les conséquences de la contamination par l'amiante	Mission commune d'information "Amiante"	\N	\N	78
20050119N20	2005-01-19 00:00:00	\N	\N	\N	égalité des droits et des chances, la participation et la citoyenneté des personnes handicapées	\N	du	projet de loi pour l'égalité des droits et des chances, la participation et la citoyenneté des personnes handicapées	\N	\N	\N	79
20050127N21	2005-01-27 00:00:00	\N	\N	\N	développement des territoires ruraux	\N	du	projet de loi relatif au développement des territoires ruraux	\N	\N	\N	80
20050319N22	2005-03-19 00:00:00	\N	\N	\N	Avenir de l'école	\N	du	projet de loi d'orientation pour l'avenir de l'école	\N	\N	\N	81
20050503N23	2005-05-03 00:00:00	\N	\N	\N	Régulation des activités postales	\N	du	projet de loi relatif à la régulation des activités postales	\N	\N	\N	82
20050504N24	2005-05-04 00:00:00	\N	\N	\N	Assistants maternels et assistants familiaux	\N	du	projet de loi relatif aux assistants maternels et aux assistants familiaux	\N	\N	\N	83
20050511N25	2005-05-11 00:00:00	\N	\N	\N	énergie	\N	du	projet de loi d'orientation sur l'énergie	\N	\N	\N	84
20050630N27	2005-06-30 00:00:00	\N	\N	\N	sauvegarde des entreprises	\N	du	projet de loi de sauvegarde des entreprises	\N	\N	\N	85
20050707N29	2005-07-07 00:00:00	\N	\N	\N	mesures d'urgence pour l'emploi	\N	du	projet de loi habilitant le Gouvernement à prendre, par ordonnances, des mesures d'urgence pour l'emploi	\N	\N	\N	86
20050707N30	2005-07-07 00:00:00	\N	\N	\N	petites et moyennes entreprises	\N	du	projet de loi en faveur des petites et moyennes entreprises	\N	\N	\N	87
20050629N26	2005-06-29 00:00:00	\N	\N	\N	cohésion sociale	\N	du	projet de loi relatif au développement des services à la personne et portant diverses mesures en faveur de la cohésion sociale	\N	\N	\N	88
RECHERCHE	2005-11-23 00:00:00	2006-03-17 00:00:00	ANCIEN	Recherche	Commission spéciale sur la recherche	COMMISSION SPÉCIALE SUR LE PROJET DE LOI RELATIF À LA RECHERCHE	de la 	Commission spéciale sur le projet de loi relatif à la recherche	Commission spéciale sur la recherche	\N	\N	89
IMMIGRATION	2005-11-03 00:00:00	2006-05-02 00:00:00	ANCIEN	Immigration	Commission d'enquête sur l'immigration clandestine	COMMISSION D'ENQUÊTE SUR L'IMMIGRATION CLANDESTINE	de la	Commission d'enquête sur l'immigration clandestine	Commission d'enquête sur l'immigration clandestine	\N	\N	90
20051104N31	2005-11-04 00:00:00	\N	\N	\N	récidive des infractions pénales	\N	de la	proposition de loi relative au traitement de la récidive des infractions pénales	\N	\N	\N	91
20051118N32	2005-11-18 00:00:00	\N	\N	\N	financement de la sécurité sociale pour 2006	\N	du	projet de loi de financement de la sécurité sociale pour 2006	\N	\N	\N	92
20050705N28	2005-07-05 00:00:00	\N	\N	\N	modernisation de l'économie	\N	du	projet de loi pour la confiance et la modernisation de l'économie	\N	\N	\N	93
20051130N33	2005-11-30 00:00:00	\N	\N	\N	loi d'orientation agricole	\N	du	projet de loi d'orientation agricole	\N	\N	\N	94
20051215N34	2005-12-15 00:00:00	\N	\N	\N	sécurité et développement des transports	\N	du	projet de loi relatif à la sécurité et au développement des transports	\N	\N	\N	95
20051213N35	2005-12-13 00:00:00	\N	\N	\N	loi de finances pour 2006	\N	du	projet de loi de finances pour 2006	\N	\N	\N	96
20051215N36	2005-12-15 00:00:00	\N	\N	\N	lutte contre le terrorisme	\N	du	projet de loi relatif à la lutte contre le terrorisme et portant dispositions diverses relatives à la sécurité et aux contrôles frontaliers	\N	\N	\N	97
20051220N37	2005-12-20 00:00:00	\N	\N	\N	loi de finances rectificative pour 2005	\N	du	projet de loi de finances rectificative pour 2005	\N	\N	\N	98
BANLIEUES	2005-12-22 00:00:00	2006-11-06 00:00:00	ANCIEN	MCI BANLIEUES	Mission commune d'information "Banlieues"	MISSION COMMUNE D'INFORMATION SUR LE BILAN ET LES PERSPECTIVES D'AVENIR DES POLITIQUES CONDUITES ENVERS LES QUARTIERS EN DIFFICULTÉ DEPUIS UNE QUINZAINE D'ANNÉES	de la	Mission commune d'information sur le bilan et les perspectives d'avenir des politiques conduites envers les quartiers en difficulté depuis une quinzaine d'années	Mission commune d'information "Banlieues"	\N	\N	99
20060119N38	2006-01-19 00:00:00	\N	\N	\N	égalité salariale entre les hommes et les femmes	\N	du	projet de loi relatif à l'égalité salariale entre les femmes et les hommes	\N	\N	\N	100
20060119N39	2006-01-26 00:00:00	\N	\N	\N	retour à l'emploi et sur les droits et les devoirs des bénéf	\N	du	projet de loi pour le retour à l'emploi et sur les droits et les devoirs des bénéficiaires de minima sociaux	\N	\N	\N	101
20060119N40	2006-02-08 00:00:00	\N	\N	\N	parcs nationaux et parcs naturels marins	\N	du	projet de loi relatif aux parcs nationaux et aux parcs naturels marins	\N	\N	\N	102
20060119N41	2006-01-23 00:00:00	\N	\N	\N	dispositions relatives au tourisme	\N	du	projet de loi portant diverses dispositions relatives au tourisme	\N	\N	\N	103
20060119N42	2006-02-28 00:00:00	\N	\N	\N	violences au sein du couple ou commises contre les mineurs	\N	de la	proposition de loi renforçant la prévention et la répression des violences au sein du couple ou commises contre les mineurs	\N	\N	\N	104
20060119N43	2006-03-05 00:00:00	\N	\N	\N	égalité des chances	\N	du	projet de loi pour l'égalité des chances	\N	\N	\N	105
20060307N44	2006-03-07 00:00:00	2006-03-14 00:00:00	\N	\N	programme pour la recherche	\N	du	projet de loi de programme pour la recherche	\N	\N	\N	106
DOPAGE	2013-02-26 00:00:00	2013-07-19 00:00:00	ACTIF	Commission d'enquête sur le dopage	Commission d'enquête sur l'efficacité de la lutte contre le dopage	COMMISSION D'ENQUÊTE SUR L'EFFICACITÉ DE LA LUTTE CONTRE LE DOPAGE	de la	Commission d'enquête sur l'efficacité de la lutte contre le dopage	Commission d'enquête sur l'efficacité de la lutte contre le dopage	\N	\N	107
GRIPPEA	2010-02-17 00:00:00	2010-08-05 00:00:00	ACTIF	GRIPPE A	Commission d'enquête sur le rôle des firmes pharmaceutiques dans la gestion par le Gouvernement de la grippe A (H1N1)v	COMMISSION D'ENQUÊTE SUR LE RÔLE DES FIRMES PHARMACEUTIQUES DANS LA GESTION PAR LE GOUVERNEMENT DE LA GRIPPE A (H1N1)v	de la 	Commission d'enquête sur le rôle des firmes pharmaceutiques dans la gestion par le Gouvernement de la grippe A (H1N1)v	Commission d'enquête sur le rôle des firmes pharmaceutiques dans la gestion par le Gouvernement de la grippe A (H1N1)v	\N	\N	108
GRANDPARIS	2009-12-09 00:00:00	2011-04-08 00:00:00	ACTIF	GRAND PARIS	Commission spéciale sur le Grand Paris	COMMISSION SPÉCIALE SUR LE GRAND PARIS	de la 	Commission spéciale sur le Grand Paris	Commission spéciale sur le Grand Paris	\N	\N	109
DECHETS	2009-10-14 00:00:00	2010-06-28 00:00:00	ACTIF	MCI Dechets	MCI sur le traitement des déchets	MISSION COMMUNE D'INFORMATION SUR LE TRAITEMENT DES DECHETS	de la	Mission commune d'information sur le traitement des déchets	Misson commune d'information sur le traitement des déchets	\N	2015-01-14 10:42:25	110
ECON	2009-06-25 00:00:00	2012-02-20 00:00:00	ACTIF	ECON	Économie	COMMISSION DE L'ÉCONOMIE, DU DÉVELOPPEMENT DURABLE ET DE L'AMÉNAGEMENT DU TERRITOIRE	de la 	commission de l'économie, du développement durable et de l'aménagement du territoire	commission de l'économie	\N	\N	112
FINC	2009-06-25 00:00:00	\N	ACTIF	FINC	Finances	COMMISSION DES FINANCES	de la	commission des finances	commission des finances	\N	\N	113
TOXICOMANIE	2010-10-20 00:00:00	2011-09-30 00:00:00	ACTIF	TOXICOMANIE	Mission commune d'information sur les toxicomanies	MISSION COMMUNE D'INFORMATION SUR LES TOXICOMANIES	de la 	Mission commune d'information sur les toxicomanies	Mission commune d'information sur les toxicomanies	\N	\N	114
MEDIATOR	2011-01-11 00:00:00	2011-01-24 00:00:00	ANCIEN	MEDIATOR	Mission commune d'information sur le Médiator	MISSION COMMUNE D'INFORMATION SUR LES DYSFONCTIONNEMENTS ÉVENTUELS DE NOTRE SYSTÈME DE CONTRÔLE ET D'ÉVALUATION DES MÉDICAMENTS, RÉVÉLÉS À L'OCCASION DU RETRAIT DE LA VENTE EN NOVEMBRE 2009 D'UNE MOLÉCULE PRESCRITE DANS LE CADRE DU DIABÈTE COMMERCIALISÉE SOUS LE NOM DE " MEDIATOR ", ET SUR LES MOYENS D'Y REMÉDIER EN TANT QUE DE BESOIN	de la	Mission commune d'information sur les dysfonctionnements éventuels de notre système de contrôle et d'évaluation des médicaments, révélés à l'occasion du retrait de la vente en novembre 2009 d'une molécule prescrite dans le cadre du diabète commercialisée sous le nom de « Mediator », et sur les moyens d'y remédier en tant que de besoin	Mission commune d'information sur le Médiator	\N	\N	115
SURENDETTEME	2009-04-29 00:00:00	2009-06-30 00:00:00	ACTIF	Crédit à la consommation	Commission spéciale sur le crédit à la consommation	COMMISSION SPECIALE SUR LE CREDIT A LA CONSOMMATION	de la	Commission spéciale sur le crédit à la consommation	Commission spéciale sur le crédit à la consommation	\N	\N	116
SERVICE	2007-07-05 00:00:00	2007-08-02 00:00:00	ANCIEN	Service minimum	Commission spéciale sur le service minimum	COMMISSION SPECIALE SUR LE PROJET DE LOI RELATIF AU SERVICE MINIMUM	de la	Commission spéciale sur le projet de loi relatif au service minimum	Commission spéciale	\N	\N	117
2007CMP15	2007-12-11 00:00:00	2007-12-13 00:00:00	\N	\N	Projet de loi de finances pour 2008	\N	du	projet de loi de finances pour 2008	\N	\N	\N	118
2008CMP3	2008-01-31 00:00:00	2008-02-04 00:00:00	\N	\N	Projet de loi relatif à la rétention de sûreté	\N	du	Projet de loi relatif à la rétention de sûreté et à la déclaration d'irresponsabilité pénale pour cause de trouble mental	\N	\N	\N	119
2007CMP14	2007-11-16 00:00:00	2007-11-20 00:00:00	\N	\N	Projet de loi de financement de la sécurité sociale pour 2008	\N	du	projet de loi de financement de la sécurité sociale pour 2008	\N	\N	\N	120
2008CMP1	2008-01-24 00:00:00	2008-01-29 00:00:00	\N	\N	pouvoir d'achat	\N	du	projet de loi pour le pouvoir d'achat	\N	\N	\N	121
2008CMP4	2008-04-16 00:00:00	2008-05-13 00:00:00	\N	\N	Lutte contre les discriminations	\N	du	projet de loi portant diverses dispositions d'adaptation au droit communautaire dans le domaine de la lutte contre les discriminations	\N	\N	\N	122
2008CMP7	2008-06-03 00:00:00	2008-06-10 00:00:00	\N	\N	Lutte contre le trafic de produits dopants	\N	du	projet de loi relatif à la lutte contre le trafic de produits dopants	\N	\N	\N	123
2008CMP6	2008-05-21 00:00:00	2008-06-03 00:00:00	\N	\N	Modernisation du marché du travail	\N	du	projet de loi relatif à la modernisation du marché du travail	\N	\N	\N	124
2008CMP17	2008-11-13 00:00:00	2009-01-27 00:00:00	\N	\N	Finances publiques pour les années 2009 à 2012	\N	du	projet de loi de programmation des finances publiques pour les années 2009 à 2012	\N	\N	\N	125
2009CMP2	2009-01-26 00:00:00	\N	\N	\N	PJL de finances rectificative pour 2009	\N	du 	projet de loi de finances rectificative pour 2009	\N	\N	\N	126
20061214N53	2006-12-14 00:00:00	2006-12-19 00:00:00	\N	\N	projet de loi sur l'eau et les milieux aquatiques	\N	du	projet de loi sur l'eau et les milieux aquatiques	\N	\N	\N	127
20061219N54	2006-12-19 00:00:00	2006-12-20 00:00:00	\N	\N	projet de loi de finances rectificative pour 2006	\N	du	projet de loi de finances rectificative pour 2006	\N	\N	\N	128
2008CMP11	2008-07-17 00:00:00	2008-07-22 00:00:00	\N	\N	droit d'accueil pour les élèves des écoles maternelles	\N	du	projet de loi instituant un droit d'accueil pour les élèves des écoles maternelles et élémentaires publiques pendant le temps scolaire obligatoire	\N	\N	\N	129
2008CMP12	2008-07-18 00:00:00	2008-07-23 00:00:00	\N	\N	droits et devoirs des demandeurs d'emploi	\N	du	projet de loi relatif aux droits et devoirs des demandeurs d'emploi	\N	\N	\N	130
2008CMP13	2008-07-18 00:00:00	2008-07-23 00:00:00	\N	\N	rénovation de la démocratie sociale et temps de travail	\N	du	projet de loi portant rénovation de la démocratie sociale et réforme du temps de travail	\N	\N	\N	131
JEUNES	2009-03-11 00:00:00	2009-10-08 00:00:00	ACTIF	Politique en faveur des jeunes	Mission commune d'information sur la politique en faveur des jeunes	MISSION COMMUNE D'INFORMATION SUR LA POLITIQUE EN FAVEUR DES JEUNES	de la	Mission commune d'information sur la politique en faveur des jeunes	Mission commune d'information sur la politique en faveur des jeunes	\N	\N	132
2007CMP3	2007-02-01 00:00:00	2007-02-13 00:00:00	\N	\N	modernisation de la diffusion audiovisuelle et à la télévisi	\N	du	projet de loi relatif à la modernisation de la diffusion audiovisuelle et à la télévision du futur	\N	\N	\N	133
2007CMP4	2007-02-07 00:00:00	2007-02-16 00:00:00	\N	\N	recrutement, formation et responsabilité des magistrats	\N	du	projet de loi organique relatif au recrutement, à la formation et à la responsabilité des magistrats	\N	\N	\N	134
2007CMP6	2007-02-15 00:00:00	2007-02-20 00:00:00	\N	\N	réforme de la protection juridique des majeurs	\N	du	projet de loi portant réforme de la protection juridique des majeurs	\N	\N	\N	135
2007CMP8	2007-02-20 00:00:00	2007-02-22 00:00:00	\N	\N	diverses mesures en faveur de la cohésion sociale	\N	du	projet de loi instituant le droit au logement opposable et portant diverses mesures en faveur de la cohésion sociale	\N	\N	\N	136
2007CMP17	2007-12-18 00:00:00	2007-12-19 00:00:00	\N	\N	projet de loi de finances rectificative pour 2007	\N	du	projet de loi de finances rectificative pour 2007	\N	\N	\N	137
2008CMP5	2008-05-14 00:00:00	2008-05-14 00:00:00	\N	\N	Organismes génétiquement modifiés	\N	du	projet de loi relatif aux organismes génétiquement modifiés	\N	\N	\N	138
2009CMP5	2009-04-02 00:00:00	\N	\N	\N	PJL de finances rectificative pour 2009	\N	du	deuxième projet de loi de finances rectificative pour 2009	\N	\N	\N	139
AFEU	2008-10-08 00:00:00	\N	ACTIF	AFEU	Affaires européennes	COMMISSION DES AFFAIRES EUROPÉENNES	de la 	commission des affaires européennes	commission des affaires européennes	\N	\N	140
CIVI	2024-03-22 00:00:00	2024-03-27 00:00:00	ACTIF	CIVI	PPL Droit responsabilité civile	CIVI	de la	proposition de loi visant à adapter le droit  de la responsabilité civile aux enjeux actuels	CIVI	\N	\N	4022
COLLECTIVITE	2008-10-15 00:00:00	2009-06-30 00:00:00	ANCIEN	Mission collectivités	Mission temporaire collectivités territoriales	MISSION TEMPORAIRE SUR L'ORGANISATION ET L'EVOLUTION DES COLLECTIVITÉS TERRITORIALES	de la	Mission temporaire sur l'organisation et l'évolution des collectivités territoriales	Mission temporaire collectivités territoriales	\N	\N	141
2008CMP16	2008-11-20 00:00:00	2008-11-25 00:00:00	\N	\N	financement de la sécurité sociale pour 2009	\N	du	projet de loi de financement de la sécurité sociale pour 2009	\N	\N	\N	142
2009CMP3	2009-02-27 00:00:00	2009-02-27 00:00:00	\N	\N	projet de loi pour l'accélération des programmes de construc	\N	du	projet de loi pour l'accélération des programmes de construction et d'investissement publics et privés	\N	\N	\N	143
2009CMP4	2009-02-11 00:00:00	2009-02-17 00:00:00	\N	\N	mobilisation pour le logement et lutte contre l'exclusion	\N	du	projet de loi de mobilisation pour le logement et lutte contre l'exclusion	\N	\N	\N	144
2009CMP7	2009-04-28 00:00:00	2009-05-05 00:00:00	\N	\N	développement économique des outre-mer	\N	du	projet de loi pour le développement économique des outre-mer	\N	\N	\N	145
DEPENDANCE	2007-12-05 00:00:00	2011-01-25 00:00:00	ACTIF	MCI DEPENDANCE	Mission commune d'information "Dépendance"	MISSION COMMUNE D'INFORMATION SUR LA PRISE EN CHARGE DE LA DEPENDANCE ET LA CREATION DU CINQUIEME RISQUE	de la	Mission commune d'information sur la prise en charge de la dépendance et la création du cinquième risque	Mission commune d'information "Dépendance"	\N	\N	146
2009CMP6	2009-04-02 00:00:00	2009-04-07 00:00:00	\N	\N	diffusion et  protection de la création sur internet	\N	du	projet de loi favorisant la diffusion et la protection de la création sur internet	\N	\N	\N	147
COMSPEAPU	2009-06-22 00:00:00	\N	ACTIF	Commission spéciale chargée du contrôle des comptes	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne 	COMMISSION SPÉCIALE CHARGÉE DU CONTRÔLE DES COMPTES ET DE L'ÉVALUATION INTERNE	de la	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne 	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne 	\N	\N	148
FORMATIONPRO	2009-07-07 00:00:00	2009-10-14 00:00:00	ACTIF	Formation professionnelle	Commission spéciale sur l'orientation et la formation professionnelle tout au long de la vie	COMMISSION SPÉCIALE SUR L'ORIENTATION ET LA FORMATION PROFESSIONNELLE TOUT AU LONG DE LA VIE	de la 	Commission spéciale sur l'orientation et la formation professionnelle tout au long de la vie	Commission spéciale sur l'orientation et la formation professionnelle tout au long de la vie	\N	\N	149
XYNTHIA	2010-03-30 00:00:00	2010-07-09 00:00:00	ACTIF	Tempête Xynthia	Mission commune d'information sur les conséquences de la tempête Xynthia	MISSION COMMUNE D'INFORMATION SUR LES CONSÉQUENCES DE LA TEMPÊTE XYNTHIA	de la	Mission commune d'information sur les conséquences de la tempête Xynthia	Mission commune d'information sur les conséquences de la tempête Xynthia	\N	\N	150
DESINDUSTRI	2010-04-28 00:00:00	2011-04-05 00:00:00	ACTIF	DESINDUSTRIALISATION DES TERRITOIRES	Mission commune d'information sur la désindustrialisation des territoires	MISSION COMMUNE D'INFORMATION SUR LA DÉSINDUSTRIALISATION DES TERRITOIRES	de la	Mission commune d'information sur la désindustrialisation des territoires	Mission commune d'information sur la désindustrialisation des territoires	\N	\N	151
MEDIATOR	2011-01-25 00:00:00	2011-09-30 00:00:00	ACTIF	MEDIATOR	Mission commune d'information sur le Médiator	MEDIATOR : EVALUATION ET CONTROLE DES MEDICAMENTS	de la	Mediator : évaluation et contrôle des médicaments	Mission commune d'information sur le Médiator	\N	\N	152
POLEEMPLOI	2011-02-02 00:00:00	2011-09-30 00:00:00	ACTIF	POLE EMPLOI	Mission commune d'information relative à Pôle Emploi	MISSION COMMUNE D'INFORMATION RELATIVE A POLE EMPLOI	de la 	Mission commune d'information relative à Pôle Emploi	Mission commune d'information relative à Pôle Emploi	\N	\N	153
RGPP	2011-01-11 00:00:00	2011-06-27 00:00:00	ACTIF	RGPP	Mission commune d'information sur la RGPP	MISSION COMMUNE D'INFORMATION SUR LES CONSÉQUENCES DE LA RÉVISION GÉNÉRALE DES POLITIQUES PUBLIQUES POUR LES COLLECTIVITÉS TERRITORIALES ET LES SERVICES PUBLICS LOCAUX	de la	Mission commune d'information sur les conséquences de la révision générale des politiques publiques pour les collectivités territoriales et les services publics locaux	Mission commune d'information sur la RGPP	\N	\N	154
SYSTEMESCO  	2010-11-17 00:00:00	2011-06-27 00:00:00	ACTIF	SYSTEME SCOLAIRE	Mission commune d'information sur l'organisation territoriale du système scolaire	MISSION COMMUNE D'INFORMATION SUR L'ORGANISATION TERRITORIALE DU SYSTÈME SCOLAIRE ET SUR L'ÉVALUATION DES EXPÉRIMENTATIONS LOCALES EN MATIÈRE D'ÉDUCATION	de la	Mission commune d'information sur l'organisation territoriale du système scolaire et sur l'évaluation des expérimentations locales en matière d'éducation	Mission commune d'information sur l'organisation territoriale du système scolaire	\N	\N	155
TAXEPRO	2011-06-28 00:00:00	2012-10-01 00:00:00	ACTIF	Taxe professionnelle	Suppression de la taxe professionnelle et son remplacement par la contribution économique territoriale	MISSION COMMUNE D'INFORMATION SUR LES CONSÉQUENCES POUR LES COLLECTIVITÉS TERRITORIALES, L'ETAT ET LES ENTREPRISES DE LA SUPPRESSION DE LA TAXE PROFESSIONNELLE ET DE SON REMPLACEMENT PAR LA CONTRIBUTION ÉCONOMIQUE TERRITORIALE	de la	Mission commune d'information sur les conséquences pour les collectivités territoriales, l'Etat et les entreprises de la suppression de la taxe professionnelle et de son remplacement par la contribution économique territoriale	Suppression de la taxe professionnelle et son remplacement par la contribution économique territoriale	\N	\N	156
COMAPLEG	2011-11-30 00:00:00	2014-09-30 00:00:00	ACTIF	Application des lois	Commission sénatoriale pour le contrôle de l'application des lois	COMMISSION SENATORIALE POUR LE CONTROLE DE L'APPLICATION DES LOIS	de la 	Commission sénatoriale pour le contrôle de l'application des lois	Commission sénatoriale pour le contrôle de l'application des lois	\N	2014-11-19 17:50:38	157
EVASION	2012-02-01 00:00:00	2012-07-17 00:00:00	ACTIF	Evasion des capitaux et des actifs	Commission d'enquête sur l'évasion des capitaux et des actifs hors de France et ses incidences fiscales	COMMISSION D'ENQUÊTE SUR L'ÉVASION DES CAPITAUX ET DES ACTIFS HORS DE FRANCE ET SES INCIDENCES FISCALES	de la 	Commission d'enquête sur l'évasion des capitaux et des actifs hors de France et ses incidences fiscales	Commission d'enquête sur l'évasion des capitaux et des actifs hors de France et ses incidences fiscales	\N	2015-01-14 10:42:59	158
COUTELEC	2012-02-15 00:00:00	2012-10-01 00:00:00	ACTIF	Commission d'enquête sur le coût réel de l'électricité	Commission d'enquête sur le coût réel de l'électricité	COMMISSION D'ENQUÊTE SUR LE COÛT RÉEL DE L'ÉLECTRICITÉ AFIN D'EN DÉTERMINER L'IMPUTATION AUX DIFFÉRENTS AGENTS ÉCONOMIQUES	de la	Commission d'enquête sur le coût réel de l'électricité afin d'en déterminer l'imputation aux différents agents économiques	Commission d'enquête sur le coût réel de l'électricité	\N	\N	159
2009CMP1	2009-01-21 00:00:00	2009-01-28 00:00:00	\N	\N	Communication audiovisuelle et service public de la télévisi	\N	du	projet de loi relatif à la communication audiovisuelle et au nouveau service public de la télévision	\N	\N	\N	29
PESTICIDES	2012-02-15 00:00:00	2013-01-08 00:00:00	ACTIF	Mission commune d'information portant sur les pesticides	Mission commune d'information portant sur les pesticides	MISSION COMMUNE D'INFORMATION PORTANT SUR LES PESTICIDES ET LEUR IMPACT SUR L'ENVIRONNEMENT ET LA SANTÉ	de la	Mission commune d'information portant sur les pesticides et leur impact sur l'environnement et la santé	Mission commune d'information portant sur les pesticides et leur impact sur l'environnement et la santé	\N	2015-01-14 10:44:54	160
AGENCES	2012-02-15 00:00:00	2012-10-01 00:00:00	ACTIF	MCI Agences de notation	MCI sur le fonctionnement, la méthodologie et la crédibilité des agences de notation	MISSION COMMUNE D'INFORMATION SUR LE FONCTIONNEMENT, LA MÉTHODOLOGIE ET LA CRÉDIBILITÉ DES AGENCES DE NOTATION	de la	Mission commune d'information sur le fonctionnement, la méthodologie et la crédibilité des agences de notation	Mission commune d'information sur le fonctionnement, la méthodologie et la crédibilité des agences de notation	\N	\N	161
20060405N45	2006-04-05 00:00:00	2006-04-11 00:00:00	\N	\N	protection des locataires en cas de vente d'un immeuble	\N	de la	proposition de loi relative au droit de préemption et à la protection des locataires en cas de vente d'un immeuble	\N	\N	\N	1
DECISION ECO	2006-06-15 00:00:00	2007-06-27 00:00:00	ACTIF	MCI "décision économique"	Mission commune d'information "décision économique"	MISSION COMMUNE D'INFORMATION "CENTRE DE DÉCISION ÉCONOMIQUE ET ATTRACTIVITÉ DU TERRITOIRE NATIONAL"	de la 	Mission commune d'information "Centre de décision économique et attractivité du territoire national"	Mission commune d'information "décision économique"	\N	2015-01-14 10:39:44	2
20060608N46	2006-06-08 00:00:00	2006-06-21 00:00:00	\N	\N	engagement national pour le logement	\N	du	projet de loi portant engagement national pour le logement	\N	\N	\N	3
20060616N47	2006-06-16 00:00:00	2006-06-21 00:00:00	\N	\N	projet de loi relatif à l'immigration et à l'intégration	\N	du	projet de loi relatif à l'immigration et à l'intégration	\N	\N	\N	4
20060615N48	2006-06-15 00:00:00	2006-06-22 00:00:00	\N	\N	projet de loi relatif au droit d'auteur	\N	du	projet de loi relatif au droit d'auteur et aux droits voisins dans la société de l'information	\N	\N	\N	5
FORMATION	2007-01-10 00:00:00	2007-07-11 00:00:00	ACTIF	MCI FORMATION	Mission commune d'information "Formation professionnelle"	MISSION COMMUNE D'INFORMATION SUR LE FONCTIONNEMENT DES DISPOSITIFS DE FORMATION PROFESSIONNELLE	de la 	Mission commune d'information sur le fonctionnement des dispositifs de formation professionnelle	Mission commune d'information "Formation professionnelle"	\N	2015-01-14 10:41:18	6
ELECTRICITE	2007-01-10 00:00:00	2007-07-04 00:00:00	ACTIF	MCI ELECTRICITE	Mission commune d'information "Electricité"	MISSION COMMUNE D'INFORMATION SUR LA SÉCURITÉ D'APPROVISIONNEMENT ÉLECTRIQUE DE LA FRANCE ET LES MOYENS DE LA PRÉSERVER	de la 	Mission commune d'information sur la sécurité d'approvisionnement électrique de la France et les moyens de la préserver	Mission commune d'information "Electricité"	\N	2015-01-14 10:40:42	7
2007CMP1	2007-01-25 00:00:00	2007-01-30 00:00:00	\N	\N	dispositions statutaires relatives à l'outre-mer	\N	du	projet de loi organique portant dispositions statutaires et institutionnelles relatives à l'outre-mer et du projet de loi portant dispositions statutaires et institutionnelles relatives à l'outre-mer	\N	\N	\N	8
2007CMP5	2007-02-12 00:00:00	2007-02-16 00:00:00	\N	\N	équilibre de la procédure pénale	\N	du	projet de loi tendant à renforcer l'équilibre de la procédure pénale	\N	\N	\N	9
2007CMP7	2007-02-14 00:00:00	2007-02-20 00:00:00	\N	\N	prévention de la délinquance	\N	du	projet de loi relatif à la prévention de la délinquance	\N	\N	\N	10
2007CMP10	2007-07-26 00:00:00	2007-07-31 00:00:00	\N	\N	libertés et responsabilités des universités	\N	du	projet de loi relatif aux libertés et responsabilités des universités	\N	\N	\N	11
2007CMP11	2007-07-27 00:00:00	2007-07-31 00:00:00	\N	\N	travail, emploi et pouvoir d'achat	\N	du	projet de loi en faveur du travail, de l'emploi et du pouvoir d'achat	\N	\N	\N	12
20061030N49	2006-10-30 00:00:00	2006-11-06 00:00:00	\N	\N	secteur de l'énergie	\N	du	projet de loi relatif au secteur de l'énergie	\N	\N	\N	13
20061117N51	2006-11-17 00:00:00	2006-11-21 00:00:00	\N	\N	financement de la sécurité sociale pour 2007	\N	du	projet de loi de financement de la sécurité sociale pour 2007	\N	\N	\N	14
20061214N52	2006-12-12 00:00:00	2006-12-14 00:00:00	\N	\N	projet de loi de finances pour 2007	\N	du	projet de loi de finances pour 2007	\N	\N	\N	15
2007CMP13	2007-10-11 00:00:00	2007-10-16 00:00:00	\N	\N	projet de loi relatif à la maîtrise de l'immigration, à l'intégration et à l'asile	\N	du	projet de loi relatif à la maîtrise de l'immigration, à l'intégration et à l'asile	\N	\N	\N	16
2007CMP16	2007-12-14 00:00:00	2007-12-18 00:00:00	\N	\N	développement de la concurrence au service des consommateurs	\N	du	projet de loi pour le développement de la concurrence au service des consommateurs	\N	\N	\N	17
PAUVRETE	2008-01-10 00:00:00	2008-07-07 00:00:00	ACTIF	MCI PAUVRETE	Mission commune d'information "Pauvreté"	MISSION COMMUNE D'INFORMATION SUR LES POLITIQUES DE LUTTE CONTRE LA PAUVRETÉ ET L'EXCLUSION	de la 	Mission commune d'information sur les politiques de lutte contre la pauvreté et l'exclusion	Mission commune d'information "Pauvreté"	\N	\N	18
2008CMP2	2008-01-24 00:00:00	2008-01-30 00:00:00	\N	\N	réforme de l'organisation du service public de l'emploi	\N	du	projet de loi relatif à la réforme de l'organisation du service public de l'emploi	\N	\N	\N	19
2008CMP8	2008-07-02 00:00:00	2008-07-08 00:00:00	\N	\N	responsabilité environnementale	\N	du	projet de loi relatif à la responsabilité environnementale et à diverses dispositions d'adaptation au droit communautaire dans le domaine de l'environnement	\N	\N	\N	20
2008CMP9	2008-07-10 00:00:00	2008-07-17 00:00:00	\N	\N	modernisation de l'économie	\N	du	projet de loi de modernisation de l'économie	\N	\N	\N	21
2007CMP9	2007-07-19 00:00:00	2007-07-24 00:00:00	\N	\N	lutte contre la récidive des majeurs et des mineurs	\N	du	projet de loi renforçant la lutte contre la récidive des majeurs et des mineurs	\N	\N	\N	22
2007CMP12	2007-07-31 00:00:00	2007-08-02 00:00:00	\N	\N	continuité du service public dans les transports terrestres 	\N	du	projet de loi sur le dialogue social et  la continuité du service public dans les transports terrestres réguliers de voyageurs	\N	\N	\N	23
ECONOMIE	2008-06-18 00:00:00	2008-07-23 00:00:00	ANCIEN	Modernisation de l'économie	Commission spéciale sur la modernisation de l'économie	COMMISSION SPÉCIALE SUR LE PROJET DE LOI DE MODERNISATION DE L'ÉCONOMIE	de la	Commission spéciale sur le projet de loi de modernisation de l'économie	Commission spéciale modernisation de l'économie	\N	\N	24
2008CMP10	2008-07-09 00:00:00	2008-07-22 00:00:00	\N	\N	règlement des comptes et rapport de gestion pour 2007	\N	du	projet de loi de règlement des comptes et rapport de gestion pour 2007	\N	\N	\N	25
2008CMP14	2008-10-29 00:00:00	2008-11-04 00:00:00	\N	\N	Revenu de solidarité active et politiques d'insertion	\N	du	projet de loi généralisant le revenu de solidarité active et réformant les politiques d'insertion	\N	\N	\N	26
2008CMP15	2008-10-29 00:00:00	2008-11-04 00:00:00	\N	\N	Revenus du travail	\N	du	projet de loi en faveur des revenus du travail	\N	\N	\N	27
2008CMP19	2008-12-19 00:00:00	2008-12-20 00:00:00	\N	\N	PJL de finances rectificative pour 2008	\N	du	projet de loi de finances rectificative pour 2008	\N	\N	\N	28
AFCL	1899-12-31 00:00:00	2023-10-04 00:00:00	ANCIEN	AFCL	Affaires culturelles	COMMISSION DES AFFAIRES CULTURELLES	de la 	commission des affaires culturelles	Commission des Affaires culturelles	\N	2023-10-04 00:00:00	30
ECON	1900-01-01 00:00:00	2009-06-25 00:00:00	ANCIEN	ECON	Affaires économiques	COMMISSION DES AFFAIRES ECONOMIQUES	de la 	commission des affaires économiques	Commission des Affaires économiques	\N	\N	31
ETRD	1900-01-01 00:00:00	\N	ACTIF	ETRD	Affaires étrangères	COMMISSION DES AFFAIRES ÉTRANGÈRES, DE LA DÉFENSE ET DES FORCES ARMÉES	de la 	commission des affaires étrangères, de la défense et des forces armées	commission des affaires étrangères	\N	\N	32
FINC	1900-01-01 00:00:00	2009-06-25 00:00:00	ACTIF	FINC	Finances	COMMISSION DES FINANCES, DU CONTROLE BUDGETAIRE ET DES COMPTES ECONOMIQUES DE LA NATION	de la 	commission des finances, du contrôle budgétaire et des comptes économiques de la Nation	Commission des Finances	\N	\N	33
LOIS	1900-01-01 00:00:00	\N	ACTIF	LOIS	Lois	COMMISSION DES LOIS CONSTITUTIONNELLES, DE LÉGISLATION, DU SUFFRAGE UNIVERSEL, DU RÈGLEMENT ET D'ADMINISTRATION GÉNÉRALE	de la 	commission des lois constitutionnelles, de législation, du suffrage universel, du Règlement et d'administration générale	commission des lois	\N	\N	34
SPORTS	2013-10-02 00:00:00	2014-05-01 00:00:00	ACTIF	MCI Sport professionnel et collectivités territoriales	Mission commune d'information sur le sport professionnel et les collectivités territoriales	MISSION COMMUNE D'INFORMATION SUR LE SPORT PROFESSIONNEL ET LES COLLECTIVITÉS TERRITORIALES	de la 	Mission commune d'information sur le sport professionnel et les collectivités territoriales	Mission commune d'information sur le sport professionnel et les collectivités territoriales	2013-10-02 16:28:09	2014-11-18 15:42:19	281
IMPLANTS	2012-02-15 00:00:00	2012-10-01 00:00:00	ACTIF	MCI Dispositifs médicaux implantables	Mission commune d'information portant sur les dispositifs médicaux implantables et les interventions à visée esthétique	MISSION COMMUNE D'INFORMATION PORTANT SUR LES DISPOSITIFS MÉDICAUX IMPLANTABLES ET LES INTERVENTIONS À VISÉE ESTHÉTIQUE	de la 	Mission commune d'information portant sur les dispositifs médicaux implantables et les interventions à visée esthétique	Mission commune d'information portant sur les dispositifs médicaux implantables et les interventions à visée esthétique	\N	\N	162
CAE	2012-02-21 00:00:00	\N	ACTIF	CAE	Affaires économiques	COMMISSION DES AFFAIRES ÉCONOMIQUES	de la 	commission des affaires économiques	commission des affaires économiques	\N	2014-01-31 14:47:01	163
CDD	2012-02-21 00:00:00	2015-06-16 00:00:00	ANCIEN	CDD	Développement durable	COMMISSION DU DÉVELOPPEMENT DURABLE, DES INFRASTRUCTURES, DE L'EQUIPEMENT ET DE L'AMÉNAGEMENT DU TERRITOIRE	de la 	commission du développement durable, des infrastructures, de l'équipement et de l'aménagement du territoire	commission du développement durable	\N	2015-06-17 11:15:58	164
INONDATIONS	2012-02-15 00:00:00	2012-10-01 00:00:00	ACTIF	MCI Inondations dans le sud est	MCI Inondations dans le sud-est de la France	MISSION COMMUNE D'INFORMATION SUR LES INONDATIONS QUI SE SONT PRODUITES DANS LE VAR, ET PLUS LARGEMENT, DANS LE SUD-EST DE LA FRANCE AU MOIS DE NOVEMBRE 2011	de la	Mission commune d'information sur les inondations qui se sont produites dans le Var, et plus largement, dans le sud-est de la France au mois de novembre 2011	Mission commune d'information sur les inondations qui se sont produites dans le Var, et plus largement, dans le sud-est 	\N	\N	165
SECTES	2012-10-02 00:00:00	2013-06-11 00:00:00	ACTIF	Commission d'enquête sur les sectes	Commission d'enquête sur l'influence des mouvements à caractère sectaire dans le domaine de la santé	COMMISSION D'ENQUÊTE SUR L'INFLUENCE DES MOUVEMENTS À CARACTÈRE SECTAIRE DANS LE DOMAINE DE LA SANTÉ 	de la	Commission d'enquête sur l'influence des mouvements à caractère sectaire dans le domaine de la santé	Commission d'enquête sur l'influence des mouvements à caractère sectaire dans le domaine de la santé	\N	\N	166
ACTION	2013-03-13 00:00:00	2013-10-30 00:00:00	ACTIF	Mission commune d'information recherche pour développement	Mission commune d'information sur l'action extérieure de la France en matière de recherche pour le développement	MISSION COMMUNE D'INFORMATION SUR L'ACTION EXTÉRIEURE DE LA FRANCE EN MATIÈRE DE RECHERCHE POUR LE DÉVELOPPEMENT	de la 	Mission commune d'information sur l'action extérieure de la France en matière de recherche pour le développement	Mission commune d'information sur l'action extérieure de la France en matière de recherche pour le développement	2013-03-13 11:46:57	2014-11-18 15:43:11	181
VIANDE	2013-03-13 00:00:00	2013-07-19 00:00:00	ACTIF	Mission commune d'information sur la filière viande	Mission commune d'information sur la filière viande en France et en Europe : élevage, abattage et distribution	MISSION COMMUNE D'INFORMATION SUR LA FILIÈRE VIANDE EN FRANCE ET EN EUROPE : ÉLEVAGE, ABATTAGE ET DISTRIBUTION	de la	Mission commune d'information sur la filière viande en France et en Europe : élevage, abattage et distribution	Mission commune d'information sur la filière viande en France et en Europe : élevage, abattage et distribution	2013-03-13 11:47:39	\N	182
DECE	2013-04-23 00:00:00	2013-10-09 00:00:00	ACTIF	MCI Organisation décentralisée 	Mission commune d'information sur l'avenir de l'organisation décentralisée de la République	MISSION COMMUNE D'INFORMATION SUR L'AVENIR DE L'ORGANISATION DÉCENTRALISÉE DE LA RÉPUBLIQUE	de la	Mission commune d'information sur l'avenir de l'organisation décentralisée de la République	Mission commune d'information sur l'avenir de l'organisation décentralisée de la République	2013-04-23 18:22:31	2014-04-14 14:34:45	241
BANQ	2013-04-23 00:00:00	2013-10-17 00:00:00	ACTIF	CE sur le rôle des banques et acteurs financiers	Commission d'enquête sur le rôle des banques et acteurs financiers dans l'évasion des ressources financières	COMMISSION D'ENQUÊTE SUR LE RÔLE DES BANQUES ET ACTEURS FINANCIERS DANS L'ÉVASION DES RESSOURCES FINANCIÈRES EN SES CONSÉQUENCES FISCALES ET SUR LES ÉQUILIBRES ÉCONOMIQUES AINSI QUE SUR L'EFFICACITÉ DU DISPOSITIF LÉGISLATIF, JURIDIQUE ET ADMINISTRATIF DESTINÉ À LA COMBATTRE	de la	Commission d'enquête sur le rôle des banques et acteurs financiers dans l'évasion des ressources financières en ses conséquences fiscales et sur les équilibres économiques ainsi que sur l'efficacité du dispositif législatif, juridique et administratif destiné à la combattre	Commission d'enquête sur le rôle des banques et acteurs financiers dans l'évasion des ressources financières	2013-04-23 18:31:58	2014-04-14 14:28:48	242
RYTHMES	2013-10-15 00:00:00	2014-09-30 00:00:00	ACTIF	MCI sur la réforme des rythmes scolaires	Mission commune d'information sur la réforme des rythmes scolaires	MISSION COMMUNE D'INFORMATION SUR LA REFORME DES RYTHMES SCOLAIRES	de la	Mission commune d'information sur la réforme des rythmes scolaires	Mission commune d'information sur la réforme des rythmes scolaires	2013-10-15 18:10:58	2014-11-18 15:41:37	301
JUSTICE	2016-06-15 00:00:00	2016-06-22 00:00:00	ACTIF	JUSTICE	Modernisation de la justice du XXI siècle	JUSTICE	de la	Modernisation de la justice du XXI siècle	JUSTICE	2016-06-15 15:03:36	2016-06-24 20:12:48	981
BLEUE	2016-04-01 00:00:00	2016-04-03 00:00:00	ACTIF	BLEUE	BLEUE	BLEUE	de la	\N	BLEUE	2016-04-01 10:41:53	2016-04-04 15:17:15	781
MAGISTRATURE	2016-06-15 00:00:00	2016-06-22 00:00:00	ACTIF	MAGISTRATURE	Obligation déontologie, recrutement des magistrats	MAGISTRATURE	de la	Obligation déontologie, recrutement des magistrats	MAGISTRATURE	2016-06-15 15:20:50	2016-06-24 20:12:27	982
ELECTORALE	2016-06-30 00:00:00	2016-07-12 00:00:00	ACTIF	ELECTORALE	Modalités d'inscription sur les listes électorales	ELECTORALE	de la	Modalités d'inscription sur les listes électorales	ELECTORALE	2016-06-30 15:34:13	2016-10-07 09:19:22	1041
TRANSPARENCE	2016-07-13 00:00:00	2016-09-14 00:00:00	ACTIF	TRANSPARENCE	Transparence et modernisation de la vie économique	TRANSPARENCE	de la	\N	TRANSPARENCE	2016-07-13 16:22:02	2016-10-07 09:18:55	1101
PLFSS2017	2016-11-16 00:00:00	2016-11-24 00:00:00	ACTIF	PLFSS2017	projet de loi de financement de la sécurité sociale pour 2017	PLFSS2017	de la	projet de loi de financement de la sécurité sociale pour 2017	PLFSS2017	2016-11-17 10:37:19	2016-11-24 11:54:25	1201
SCHENGEN	2016-11-22 00:00:00	2017-06-12 00:00:00	ACTIF	CE Avenir espace Schengen	CE Frontières européennes, contrôle des flux des personnes et des marchandises en Europe et avenir de l'espace Schengen	COMMISSION D'ENQUÊTE SUR LES FRONTIÈRES EUROPÉENNES, LE CONTRÔLE DES FLUX DES PERSONNES ET DES MARCHANDISES EN EUROPE ET L'AVENIR DE L'ESPACE SCHENGEN	de la	commission d'enquête sur les frontières européennes, le contrôle des flux des personnes et des marchandises en Europe et l'avenir de l'espace Schengen	CE Frontières européennes, contrôle des flux des personnes et des marchandises en Europe et avenir de l'espace Schengen	2016-11-21 17:12:31	2017-06-12 11:06:52	1221
IVG	2017-01-18 00:00:00	2017-01-25 00:00:00	ACTIF	IVG	proposition de loi realtive à l'extension du délit d'entrave à l'interruption volontaire de grossesse	IVG	de la	proposition de loi relative à l'extension du délit d'entrave à l'interruption volontaire de grossesse	IVG	2017-01-23 14:30:28	2018-02-28 15:14:34	1381
ENVIRONNEMEN	2017-11-08 00:00:00	2017-12-21 00:00:00	ACTIF	ENVIRONNEMEN	projet de loi ratifiant les ordonnances relatives à l'évaluation environnementale	ENVIRONNEMEN	du	projet de loi ratifiant les ordonnances relatives à la modification des règles applicables à l'évaluation environnementale des projets, plans et programmes et portant réforme des procédures destinées à assurer l'information et la participation du public à l'élaboration de certaines décisions susceptibles d'avoir une incidence sur l'environnement	ENVIRONNEMEN	2017-11-08 14:27:53	2017-12-21 10:15:39	1562
PARIS	2017-12-01 00:00:00	2017-12-07 00:00:00	ANCIEN	PARIS	projet de loi ratifiant l'ordonnance portant création de l'établissement public Paris La Défense	PARIS	du	projet de loi ratifiant l'ordonnance portant création de l'établissement public Paris La Défense	PARIS	2017-12-01 16:39:53	2018-02-28 15:07:37	1623
FORCES	2018-01-17 00:00:00	2018-06-30 00:00:00	ACTIF	CE Etat des forces de sécurité intérieure	CE Etat des forces de sécurité intérieure	COMMISSION D'ENQUÊTE SUR L'ÉTAT DES FORCES DE SÉCURITÉ INTÉRIEURE	de la	commission d'enquête sur l'état des forces de sécurité intérieure	Commission d'enquête Etat des forces de sécurité intérieure	2018-01-16 14:39:56	2018-01-16 14:50:31	1701
ETAT	2018-01-17 00:00:00	2018-01-30 00:00:00	ACTIF	GT Etat au service d'une société de confiance	GT Etat au service d'une société de confiance	GROUPE DE TRAVAIL PRÉFIGURANT LA COMMISSION SPÉCIALE SUR LE PROJET DE LOI POUR UN ÉTAT AU SERVICE D'UNE SOCIÉTÉ DE CONFIANCE	du	groupe de travail préfigurant la commission spéciale sur le projet de loi pour un état au service d'une société de confiance	Groupe de travail pour un Etat au service d'une société de confiance	2018-01-16 14:51:43	2018-02-02 09:30:09	1702
MINEURSENF	2018-03-14 00:00:00	2018-09-30 00:00:00	ACTIF	MI sur la réinsertion des mineurs enfermés	Mission d'information sur la réinsertion des mineurs enfermés	Mission d'information sur la réinsertion des mineurs enfermés	de la	Mission d'information sur la réinsertion des mineurs enfermés	MI sur la réinsertion des mineurs enfermés	2018-03-13 16:24:21	2018-04-30 10:22:23	1822
EFFICACITE	2018-03-14 00:00:00	2018-03-14 00:00:00	ACTIF	EFFICACITE	projet de loi pour un Etat au service d'une société de confiance	EFFICACITE	du	projet de loi pour un Etat au service d'une société de confiance	EFFICACITE	2018-03-21 14:02:52	2018-05-22 16:40:21	1841
EAU	2018-04-18 00:00:00	2018-05-18 00:00:00	ACTIF	EAU	proposition de loi relative à la mise en oeuvre du transfert des compétences eau et assainissement	EAU	de la	proposition de loi relative à la mise en oeuvre du transfert des compétences eau et assainissement aux communautés de communes et aux communautés d'agglomération	EAU	2018-05-22 16:40:45	2018-06-07 17:11:04	1921
SECRET	2018-05-22 00:00:00	2018-05-25 00:00:00	ACTIF	SECRET	proposition de loi relative à la protection du secret des affaires	SECRET	de la	proposition de loi relative à la protection du secret des affaires	SECRET	2018-05-22 16:45:23	2018-06-07 17:10:53	1922
PENURIE	2018-06-27 00:00:00	2018-09-30 00:00:00	ACTIF	Mission d'information sur la pénurie de médicaments	Mission d'information sur la pénurie de médicaments et de vaccins	MISSION D'INFORMATION SUR LA PÉNURIE DE MÉDICAMENTS ET DE VACCINS	de la	Mission d'information sur la pénurie de médicaments et de vaccins	Mission d'information sur la pénurie de médicaments	\N	\N	1981
RETRAIT	2018-10-10 00:00:00	2019-01-19 00:00:00	ACTIF	CS préparation du retrait du Royaume-Uni de l'UE	CS habilitant le Gouvernement à prendre les mesures de préparation du retrait du Royaume-Uni de l'Union européenne	COMMISSION SPECIALE SUR LE PROJET DE LOI HABILITANT LE GOUVERNEMENT À PRENDRE PAR ORDONNANCE LES MESURES DE PRÉPARATION DU RETRAIT DU ROYAUME-UNI DE L'UNION EUROPÉENNE	de la	commission spéciale sur le projet de loi habilitant le Gouvernement à prendre par ordonnance les mesures de préparation du retrait du Royaume-Uni de l'Union européenne	CS préparation du retrait du Royaume-Uni de l'UE	\N	\N	2141
SURTRANSPO	2018-10-10 00:00:00	2018-11-12 00:00:00	ACTIF	CS suppression surtranspositions directives droit français	CS portant suppression des surtranspositions des directives en droit français	COMMISSION SPECIALE PORTANT SUPPRESSION DES SURTRANSPOSITIONS DES DIRECTIVES EN DROIT FRANÇAIS	de la	commission spéciale sur le projet de loi portant suppression des surtranspositions des directives en droit français	CS suppression surtranspositions directives droit français	\N	\N	2143
ENTREPRISES	2018-10-10 00:00:00	2019-05-22 00:00:00	ACTIF	CS croissance et transformation des entreprises  	CS croissance et la transformation des entreprises	COMMISSION SPECIALE SUR LE PROJET DE LOI RELATIF A LA CROISSANCE ET LA TRANSFORMATION DES ENTREPRISES	de la	commission spéciale sur le projet de loi relatif à la croissance et la transformation des entreprises	CS croissance et transformation des entreprises  	\N	\N	2144
PLFR2018	2018-11-19 00:00:00	2018-11-21 00:00:00	ACTIF	PLFR2018	projet de loi de finances rectificative pour 2018	PLFR2018	du	projet de loi de finances rectificative pour 2018	PLFR2018	\N	\N	2181
COTISATIONS	2014-02-25 00:00:00	2014-09-30 00:00:00	ACTIF	MCI impact emploi des exonérations	MCI sur la réalité de l'impact sur l'emploi des exonérations de cotisations sociales accordées aux entreprises	MISSION COMMUNE D'INFORMATION RELATIVE À LA RÉALITÉ DE L'IMPACT SUR L'EMPLOI DES EXONÉRATIONS DE COTISATIONS SOCIALES ACCORDÉES AUX ENTREPRISES	de la	Mission commune d'information relative à la réalité de l'impact sur l'emploi des exonérations de cotisations sociales accordées aux entreprises	MCI relative à la réalité de l'impact sur l'emploi des exonérations de cotisations sociales accordées aux entreprises	2014-02-25 16:11:53	2014-11-18 15:40:17	381
CROISSANCE	2015-01-15 00:00:00	2015-12-08 00:00:00	ANCIEN	CS croissance et activité	Commission spéciale sur le projet de loi pour la croissance, l'activité et l'égalité des chances économiques	COMMISSION SPÉCIALE SUR LE PROJET DE LOI POUR LA CROISSANCE, L'ACTIVITE ET L'EGALITE DES CHANCES ECONOMIQUES	de la	Commission spéciale sur le projet de loi pour la croissance, l'activité et l'égalité des chances économiques	Commission spéciale sur le projet de loi pour la croissance, l'activité et l'égalité des chances économiques	2015-01-09 11:38:57	2015-12-09 18:22:21	502
POLLUTION	2015-02-18 00:00:00	2015-07-15 00:00:00	ACTIF	CE Coût économique et financier de la pollution de l'air	Commission d'enquête sur le coût économique et financier de la pollution de l'air	COMMISSION D'ENQUÊTE SUR LE COÛT ÉCONOMIQUE ET FINANCIER DE LA POLLUTION DE L'AIR	de la	Commission d'enquête sur le coût économique et financier de la pollution de l'air	Commission d'enquête sur le coût économique et financier de la pollution de l'air	2015-02-19 14:57:11	2016-04-28 11:37:05	541
CDD	2015-06-17 00:00:00	\N	ACTIF	CDD	Développement durable	COMMISSION DE L'AMÉNAGEMENT DU TERRITOIRE ET DU DÉVELOPPEMENT DURABLE	de la 	commission de l'aménagement du territoire et du développement durable	commission de l'aménagement du territoire et du développement durable	2015-06-17 10:53:25	2015-09-11 10:49:49	581
ISLAM	2015-12-14 00:00:00	2016-07-10 00:00:00	ACTIF	MI organisation, place et financement de l'islam en France	Mission d'information sur l'organisation, la place et le financement de l'islam en France et de ses lieux de culte	MISSION D'INFORMATION SUR L'ORGANISATION, LA PLACE ET LE FINANCEMENT DE L'ISLAM EN FRANCE ET DE SES LIEUX DE CULTE	de la	mission d'information sur l'organisation, la place et le financement de l'islam en France et de ses lieux de culte	Mission d'information sur l'organisation, la place et le financement de l'Islam en France et de ses lieux de culte	2015-12-21 15:10:13	2017-03-21 11:21:07	681
ZEROCHOMAGE	2016-01-27 00:00:00	2016-02-03 00:00:00	ACTIF	ZEROCHOMAGE	Expérimentation territoriale visant à résorber chômage de longue durée	ZEROCHOMAGE	de la	Expérimentation territoriale visant à résorber chômage de longue durée	ZEROCHOMAGE	2016-02-23 14:38:12	2016-02-23 14:45:41	726
FINDEVIE	2015-12-17 00:00:00	2016-01-20 00:00:00	ACTIF	FINDEVIE	Nouveaux droits personnes malades en fin de vie	FINDEVIE	de la	Nouveaux droits personnes malades en fin de vie	FINDEVIE	2016-02-23 14:46:21	2016-02-23 14:50:30	728
PROTECTION	2015-12-17 00:00:00	2016-01-13 00:00:00	ACTIF	PROTECTION	Protection de l'enfant	PROTECTION	de la	Protection de l'enfant	PROTECTION	2016-02-23 14:50:53	2016-02-23 14:58:25	729
MINEURS	2016-03-02 00:00:00	2016-03-10 00:00:00	ACTIF	MINEURS	MINEURS test 5	MINEURS	de la	test	MINEURS	2016-03-11 10:48:31	2016-03-11 11:43:34	765
DEONTOLOGIE	2016-03-02 00:00:00	2016-03-10 00:00:00	ANCIEN	DEONTOLOGIE	déontologie fonctionnaires	DEONTOLOGIE	de la	déontologie fonctionnaires	DEONTOLOGIE	2016-03-11 14:18:24	2016-03-11 14:57:41	769
DEONTOLOGIE	2016-03-11 00:00:00	2016-03-29 00:00:00	ACTIF	DEONTOLOGIE	déontologie et droits et obligations des fonctionnaires	DEONTOLOGIE	de la	déontologie et droits et obligations des fonctionnaires	DEONTOLOGIE	2016-03-11 14:57:41	2016-04-05 14:32:45	776
BLEUE	2016-04-04 00:00:00	2016-04-06 00:00:00	ACTIF	BLEUE	économie bleue	BLEUE	de l'	économie bleue	BLEUE	2016-04-04 15:17:15	2016-04-07 16:23:00	801
TURQUIE	2016-04-27 00:00:00	2016-10-14 00:00:00	ACTIF	MI Accord UE/Turquie	Mission d'information sur l'accord de mars 2016 entre l'Union européenne et la Turquie relatif à la crise des réfugiés	Mission d'information sur la position de la France à l'égard de l'accord de mars 2016 entre l'Union européenne et la Turquie relatif à la crise des réfugiés et sur les conditions de mise en oeuvre de cet accord	de la	mission d'information sur la position de la France à l'égard de l'accord de mars 2016 entre l'Union européenne et la Turquie relatif à la crise des réfugiés et sur les conditions de mise en oeuvre de cet accord	mission d'information sur l'accord UE/Turquie relatif à la crise des réfugiés	2016-04-27 15:03:19	2017-06-12 11:08:26	842
CHOMAGE	2016-04-27 00:00:00	2016-10-04 00:00:00	ACTIF	commission d'enquête sur les chiffres du chômage	CE sur les chiffres du chômage	COMMISSION ENQUETE SUR LES CHIFFRES DU CHÔMAGE EN FRANCE ET DANS LES PAYS DE L'UNION EUROPÉENNE AINSI QUE SUR L'IMPACT DES RÉFORMES MISES EN PLACE PAR CES PAYS POUR FAIRE BAISSER LE CHÔMAGE	de la	commission d'enquête sur les chiffres du chômage en France et dans les pays de l'Union européenne ainsi que sur l'impact des réformes mises en place par ces pays pour faire baisser le chômage	commission d'enquête sur les chiffres du chômage en France et dans les pays de l'Union européenne	2016-04-27 14:47:50	2017-06-12 11:08:12	841
REGLEMENT	2016-07-08 00:00:00	2016-07-12 00:00:00	ACTIF	REGLEMENT	Règlement du budget et approbation des comptes de l'année 2015	REGLEMENT	de la	Règlement du budget et approbation des comptes de l'année 2015	REGLEMENT	2016-07-08 11:17:53	2016-10-07 09:19:09	1081
CDGEXPRESS	2016-11-23 00:00:00	2016-12-01 00:00:00	ACTIF	CDGEXPRESS	liaison ferroviaire entre Paris et l'aéroport Paris-Charles de Gaulle	CDGEXPRESS	de la	liaison ferroviaire entre Paris et l'aéroport Paris-Charles de Gaulle	CDGEXPRESS	2016-11-24 11:54:36	2016-12-01 15:39:21	1241
VTC	2016-11-23 00:00:00	2016-12-01 00:00:00	ACTIF	VTC	régulation, responsabilisation et simplification dans le secteur du transport public particulier de personnes	VTC	de la	régulation, responsabilisation et simplification dans le secteur du transport public particulier de personnes	VTC	2016-11-24 11:58:00	2016-12-01 15:39:15	1242
ACCAPAREMENT	2017-02-08 00:00:00	2017-02-09 00:00:00	ACTIF	ACCAPAREMENT	proposition de loi relative à la lutte contre l'accaparement des terres agricoles et développement du biocontrôle	ACCAPAREMENT	de la	proposition de loi relative à la lutte contre l'accaparement des terres agricoles et développement du biocontrôle	ACCAPAREMENT	2017-02-09 10:39:30	2018-02-28 15:10:14	1441
PRESCRIPTION	2017-01-25 00:00:00	2017-02-14 00:00:00	ACTIF	PRESCRIPTION	proposition de loi portant réforme de la prescription en matière pénale	PRESCRIPTION	de la	proposition de loi portant réforme de la prescription en matière pénale	PRESCRIPTION	2017-02-14 16:17:31	2018-02-28 15:10:21	1461
COLLCORSE	2017-01-25 00:00:00	2017-02-14 00:00:00	ANCIEN	COLLCORSE	projet de loi ratifiant les ordonnances relatives à la collectivité de Corse	COLLCORSE	du	projet de loi ratifiant les ordonnances relatives à la collectivité de Corse	COLLCORSE	2017-02-14 17:56:10	2018-02-28 15:11:20	1481
SECURITEPUBL	2017-01-25 00:00:00	2017-02-14 00:00:00	ANCIEN	SECURITEPUBL	projet de loi relatif à la sécurité publique	SECURITEPUBL	du	projet de loi relatif à la sécurité publique	SECURITEPUBL	2017-02-14 18:00:01	2018-02-28 15:12:05	1501
EDUCATION	2015-01-22 00:00:00	2015-10-12 00:00:00	ACTIF	CE Service public de l'éducation	CE Service public de l'éducation	COMMISSION D'ENQUÊTE SUR LE FONCTIONNEMENT DU SERVICE PUBLIC DE L'ÉDUCATION, SUR LA PERTE DE REPÈRES RÉPUBLICAINS QUE RÉVÈLE LA VIE DANS LES ÉTABLISSEMENTS SCOLAIRES ET SUR LES DIFFICULTÉS RENCONTRÉES PAR LES ENSEIGNANTS DANS L'EXERCICE DE LEUR PROFESSION	de la	Commission d'enquête sur le fonctionnement du service public de l'éducation, sur la perte de repères républicains que révèle la vie dans les établissements scolaires et sur les difficultés rencontrées par les enseignants dans l'exercice de leur profession	Commission d'enquête sur le fonctionnement du service public de l'éducation	2015-01-27 16:36:06	2016-04-28 11:35:48	521
CRIME	2016-04-27 00:00:00	2016-05-12 00:00:00	ACTIF	CRIME	crime organisé	CRIME	de la	Projet de loi renforçant la lutte contre le crime organisé, le terrorisme et leur financement et améliorant l'efficacité et les garanties de la procédure pénale	CRIME	2016-05-06 10:14:16	2017-02-24 14:39:47	861
ELECTION	2016-03-02 00:00:00	2016-03-15 00:00:00	ACTIF	ELECTION	modernisation des règles applicables à l'élection présidentielle	ELECTION	de la	modernisation des règles applicables à l'élection présidentielle	ELECTION	2016-03-11 10:05:03	2016-04-01 10:41:01	761
BIODIVERSITE	2016-05-17 00:00:00	2016-05-25 00:00:00	ACTIF	BIODIVERSITE	Reconquête de la biodiversité 	BIODIVERSITE	de la	Commission mixte paritaire sur le PJL "reconquête de la biodiversité"	BIODIVERSITE	2016-05-18 08:49:42	2016-06-08 17:34:23	921
ARCHITECTURE	2016-06-08 00:00:00	2016-06-15 00:00:00	ACTIF	ARCHITECTURE	Liberté de la création, architecture et patrimoine	ARCHITECTURE	de la	Liberté de la création, architecture et patrimoine	ARCHITECTURE	2016-06-08 17:34:52	2016-06-24 20:13:48	961
MEDIAS	2016-06-08 00:00:00	2016-06-14 00:00:00	ACTIF	MEDIAS	Liberté, indépendance et pluralisme des médias	MEDIAS	de la	Proposition de loi visant à renforcer la liberté, indépendance et pluralisme des médias	MEDIAS	2016-06-08 17:39:27	2017-02-24 14:33:58	962
TRAVAIL	2016-06-23 00:00:00	2016-06-28 00:00:00	ACTIF	TRAVAIL	Instituer de nouvelles libertés et de nouvelles protections pour les entreprises et les actif-ve-s	TRAVAIL	de la	Instituer de nouvelles libertés et de nouvelles protections pour les entreprises et les actif-ve-s	TRAVAIL	2016-06-24 20:14:05	2016-06-30 15:31:51	1021
ENERGIE	2017-01-26 00:00:00	2017-02-07 00:00:00	ANCIEN	ENERGIE	projet de loi ratifiant les ordonnances relatives à l'autoconsommation d'électricité et énergies renouvelables	ENERGIE	du	projet de loi ratifiant les ordonnances relatives à l'autoconsommation d'électricité et énergies renouvelables	ENERGIE	2017-01-31 14:14:19	2018-02-28 15:13:45	1401
OUTRE_MER	2017-01-31 00:00:00	2017-02-07 00:00:00	ANCIEN	OUTRE_MER	Egalité réelle outre-mer et autres dispositions en matière sociale et économique	OUTRE_MER	du	projet de loi de programmation relatif à l'égalité réelle outre-mer et autres dispositions en matière sociale et économique	OUTRE_MER	2017-01-31 14:38:24	2018-02-28 15:13:01	1421
DIALOGUE	2017-07-26 00:00:00	2017-08-01 00:00:00	ACTIF	DIALOGUE	projet de loi d'habilitation à prendre par ordonnances les mesures pour le renforcement du dialogue social	DIALOGUE	du	projet de loi d'habilitation à prendre par ordonnances les mesures pour le renforcement du dialogue social	DIALOGUE	2017-07-27 11:16:08	2017-08-03 12:18:38	1521
CONFIANCE	2017-07-26 00:00:00	2017-08-02 00:00:00	ACTIF	CONFIANCE	projet de loi et projet de loi organique rétablissant la confiance dans l'action publique	CONFIANCE	du	projet de loi et projet de loi organique rétablissant la confiance dans l'action publique	CONFIANCE	2017-07-27 11:27:41	2017-08-03 12:18:47	1522
CONTRATS	2018-02-22 00:00:00	2018-03-14 00:00:00	ACTIF	CONTRATS	projet de loi portant réforme du droit des contrats, du régime général et de la preuve des obligations	CONTRATS	du	projet de loi portant réforme du droit des contrats, du régime général et de la preuve des obligations	CONTRATS	2018-02-22 10:58:00	2018-03-21 14:02:21	1801
MARCHE	2018-04-18 00:00:00	2018-04-19 00:00:00	ACTIF	MARCHE	projet de loi ratifiant l'ordonnance concernant les services de paiement dans le marché intérieur	MARCHE	du	projet de loi ratifiant l'ordonnance portant transposition de la directive concernant les services de paiement dans le marché intérieur	MARCHE	2018-04-18 11:40:23	2018-05-22 16:39:12	1901
EUROPEEN	2018-04-17 00:00:00	2018-04-20 00:00:00	ACTIF	EUROPEEN	projet de loi relatif à l'élection des représentants au Parlement européen	EUROPEEN	du	projet de loi relatif à l'élection des représentants au Parlement européen	EUROPEEN	2018-04-18 11:48:35	2018-05-22 16:39:37	1902
INFRACTIONS	2018-10-31 00:00:00	2019-05-31 00:00:00	ACTIF	MCI répression infractions sexuelles sur mineurs	MCI répression infractions sexuelles sur mineurs	MISSION COMMUNE D'INFORMATION SUR LES POLITIQUES PUBLIQUES DE PRÉVENTION, DE DÉTECTION, D'ORGANISATION DES SIGNALEMENTS ET DE RÉPRESSION DES INFRACTIONS SEXUELLES SUSCEPTIBLES D'ÊTRE COMMISES PAR DES PERSONNES EN CONTACT AVEC DES MINEURS DANS LE CADRE DE L'EXERCICE DE LEUR MÉTIER OU DE LEURS FONCTIONS	de la	Mission commune d'information sur les politiques publiques de prévention, de détection, d'organisation des signalements et de répression des infractions sexuelles susceptibles d'être commises par des personnes en contact avec des mineurs dans le cadre de l'exercice de leur métier ou de leurs fonctions	MCI répression infractions sexuelles sur mineurs	\N	\N	2161
TRANSPORTS	2019-03-06 00:00:00	2019-09-27 00:00:00	ACTIF	MI Gratuité des transports collectifs	MI Gratuité des transports collectifs	MISSION D'INFORMATION « GRATUITÉ DES TRANSPORTS COLLECTIFS : FAUSSE BONNE IDÉE OU RÉVOLUTION ÉCOLOGIQUE ET SOCIALE DES MOBILITÉS ? »	de la	mission d'information  « Gratuité des transports collectifs : fausse bonne idée ou révolution écologique et sociale des mobilités ? »	MI Gratuité des transports collectifs	\N	\N	2321
SIDERURGIE	2019-01-30 00:00:00	2019-07-12 00:00:00	ACTIF	MI sur les enjeux de la filière sidérurgique	MI sur les enjeux de la filière sidérurgique	MISSION D'INFORMATION SUR LES ENJEUX DE LA FILIÈRE SIDÉRURGIQUE DANS LA FRANCE DU XXIÈ SIÈCLE : OPPORTUNITÉ DE CROISSANCE ET DE DÉVELOPPEMENT	de la	Mission d'information sur les enjeux de la filière sidérurgique dans la France du XXIè siècle : opportunité de croissance et de développement	MI sur les enjeux de la filière sidérurgique	\N	\N	2281
ANCT	2019-03-20 00:00:00	2019-04-04 00:00:00	ACTIF	ANCT	proposition de loi portant creation d'une Agence nationale de la cohésion des territoires	ANCT	de la	proposition de loi portant creation d'une Agence nationale de la cohésion des territoires	ANCT	\N	\N	2341
ANCTORG	2019-03-20 00:00:00	2019-04-04 00:00:00	ACTIF	ANCTORG	proposition de loi organique relative à la nomination du directeur général de l'ANCT	ANCTORG	de la 	proposition de loi organique relative à la nomination du directeur général de l'ANCT	ANCTORG	\N	\N	2342
SOUVERAINETE	2019-04-10 00:00:00	2019-10-04 00:00:00	ACTIF	Commission d'enquête sur la souveraineté numérique	Commission d'enquête sur la souveraineté numérique	COMMISSION D'ENQUÊTE SUR LA SOUVERAINETÉ NUMÉRIQUE	de la	Commission d'enquête sur la souveraineté numérique	Commission d'enquête sur la souveraineté numérique	\N	\N	2361
GAFA	2019-06-05 00:00:00	2019-06-27 00:00:00	ACTIF	GAFA	projet de loi portant création d'une taxe sur les services numériques	GAFA	du	projet de loi portant création d'une taxe sur les services numériques et modification de la trajectoire de baisse de l'impôt sur les sociétés	GAFA	\N	\N	2501
PROSTITUTION	2014-01-22 00:00:00	2016-04-13 00:00:00	ACTIF	CS sur la lutte contre le système prostitutionnel	Commission spéciale sur la lutte contre le système prostitutionnel	COMMISSION SPÉCIALE SUR LA LUTTE CONTRE LE SYSTÈME PROSTITUTIONNEL	de la	commission spéciale sur la lutte contre le système prostitutionnel	Commission spéciale sur la lutte contre le système prostitutionnel	2014-01-23 10:28:26	2017-03-21 11:13:21	361
CREDITIMPOT	2014-12-10 00:00:00	2015-06-09 00:00:00	ACTIF	CE réalité du détournement du crédit impôt recherche	CE réalité du détournement du crédit impôt recherche	COMMISSION D'ENQUÊTE SUR LA RÉALITÉ DU DÉTOURNEMENT DU CRÉDIT D'IMPÔT RECHERCHE DE SON OBJET ET DE SES INCIDENCES SUR LA SITUATION DE L'EMPLOI ET DE LA RECHERCHE DANS NOTRE PAYS	de la	Commission d'enquête sur la réalité du détournement du crédit d'impôt recherche de son objet et de ses incidences sur la situation de l'emploi et de la recherche dans notre pays	Commission d'enquête sur la réalité du détournement du crédit d'impôt recherche	2014-12-16 17:29:06	2016-04-28 11:34:40	481
REVENU	2016-05-18 00:00:00	2016-10-14 00:00:00	ACTIF	MI Revenu de base en France	Mission d'information sur un revenu de base en France	MISSION D'INFORMATION SUR L'INTÉRÊT ET LES FORMES POSSIBLES DE MISE EN PLACE D'UN REVENU DE BASE EN FRANCE	de la	Mission d'information sur l'intérêt et les formes possibles de mise en place d'un revenu de base en France	Mission d'information sur un revenu de base en France	2016-05-17 16:41:21	2017-06-12 11:07:55	901
REPUBLIQUE	2016-06-01 00:00:00	2016-06-29 00:00:00	ACTIF	REPUBLIQUE	République numérique	REPUBLIQUE	de la	République numérique	REPUBLIQUE	2016-06-02 11:03:43	2016-06-30 15:32:20	941
ATTEINTES	2016-11-22 00:00:00	2017-06-12 00:00:00	ACTIF	CE Compensation des atteintes à la biodiversité 	Commission d'enquête sur les atteintes à la biodiversité sur grands projets d'infrastructures	COMMISSION D'ENQUÊTE SUR LA RÉALITÉ DES MESURES DE COMPENSATION DES ATTEINTES À LA BIODIVERSITÉ ENGAGÉES SUR DES GRANDS PROJETS D'INFRASTRUCTURES, INTÉGRANT LES MESURES D'ANTICIPATION, LES ÉTUDES PRÉALABLES, LES CONDITIONS DE RÉALISATION ET LEUR SUIVI	de la	commission d'enquête sur la réalité des mesures de compensation des atteintes à la biodiversité engagées sur des grands projets d'infrastructures, intégrant les mesures d'anticipation, les études préalables, les conditions de réalisation et leur suivi	CE Atteintes à la biodiversité sur grands projets d'infrastructures	2016-11-21 17:25:15	2017-06-12 11:06:58	1222
DEMOCRATIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ACTIF	MI Démocratie	Mission d'information Démocratie représentative, participative, paritaire	MISSION D'INFORMATION SUR LA DÉMOCRATIE REPRÉSENTATIVE, DÉMOCRATIE PARTICIPATIVE, DÉMOCRATIE PARITAIRE : COMMENT DÉCIDER AVEC EFFICACITÉ ET LÉGITIMITÉ EN FRANCE EN 2017	de la	mission d'information sur la démocratie représentative, la démocratie participative, la démocratie paritaire : comment décider avec efficacité et légitimité en France en 2017	MI Démocratie représentative, participative, paritaire	2016-11-21 17:36:38	2017-06-12 11:07:07	1223
PSYCHIATRIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ACTIF	MI sur la situation de la psychiatrie des mineurs en France	Mission d'information sur la situation de la psychiatrie des mineurs en France	MISSION D'INFORMATION SUR LA SITUATION DE LA PSYCHIATRIE DES MINEURS EN FRANCE	de la	mission d'information sur la situation de la psychiatrie des mineurs en France	Mission d'information sur la situation de la psychiatrie des mineurs en France	2016-11-21 17:41:24	2017-06-12 11:07:11	1224
TERRORISME	2017-10-05 00:00:00	2017-10-10 00:00:00	ANCIEN	TERRORISME	projet de loi renforçant la sécurité intérieure et la lutte contre le terrorisme	TERRORISME	du	projet de loi renforçant la sécurité intérieure et la lutte contre le terrorisme	TERRORISME	2017-10-09 17:28:33	2018-02-28 15:08:01	1541
PLF2018	2017-12-07 00:00:00	2017-12-13 00:00:00	ANCIEN	PLF2018	projet de loi de finances pour 2018	PLF2018	du	projet de loi de finances pour 2018	PLF2018	2017-12-08 15:33:56	2018-02-28 15:07:11	1641
PLFP2018	2017-12-07 00:00:00	2017-12-14 00:00:00	ANCIEN	PLFP2018	projet de loi de programmation des finances publiques pour les années 2018 à 2022	PLFP2018	du	projet de loi de programmation des finances publiques pour les années 2018 à 2022	PLFP2018	2017-12-08 15:37:29	2018-02-28 15:06:17	1642
SOCIETE	2018-01-31 00:00:00	2018-08-10 00:00:00	ACTIF	CS Etat au service d'une société de confiance	CS Etat au service d'une société de confiance	COMMISSION SPECIALE SUR LE PROJET DE LOI POUR UN ETAT AU SERVICE D'UNE SOCIETE DE CONFIANCE	de la	commission spéciale sur le projet de loi pour un Etat au service d'une société de confiance	CS Etat au service d'une société de confiance	2018-02-02 09:30:28	2018-02-02 09:35:35	1741
EGALIM	2018-07-03 00:00:00	2018-07-11 00:00:00	ACTIF	EGALIM	projet de loi pour une alimentation saine, durable et accessible à tous	EGALIM	du	projet de loi pour l'équilibre des relations commerciales dans le secteur agricole et alimentaire et une alimentation saine, durable et accessible à tous	EGALIM	\N	\N	2021
VIOLENCES	2018-07-10 00:00:00	2018-07-24 00:00:00	ACTIF	VIOLENCES	projet de loi renforçant la lutte contre les violences sexuelles et sexistes	VIOLENCES	du	projet de loi renforçant la lutte contre les violences sexuelles et sexistes	VIOLENCES	\N	\N	2041
INFORMATION	2018-09-25 00:00:00	2018-09-27 00:00:00	ACTIF	INFORMATION	proposition de loi organique relative à la lutte contre la manipulation de l'information	INFORMATION	de la	proposition de loi organique relative à la lutte contre la manipulation de l'information	INFORMATION	\N	\N	2124
FRAUDE	2018-10-02 00:00:00	2018-10-05 00:00:00	ACTIF	FRAUDE	projet de loi relatif à la lutte contre la fraude	FRAUDE	du	projet de loi relatif à la lutte contre la fraude	FRAUDE	\N	\N	2125
SOCIAL	2018-01-24 00:00:00	2018-02-01 00:00:00	ACTIF	SOCIAL	projet de loi ratifiant ordonnances renforcement dialogue social	SOCIAL	du	projet de loi ratifiant ordonnances renforcement dialogue social	SOCIAL	2018-01-24 17:40:48	2018-02-06 12:25:06	1721
CLIMATIQUE	2019-01-16 00:00:00	2019-07-12 00:00:00	ACTIF	mission d'information sur la gestion des risques climatiques	mission d'information sur la gestion des risques climatiques	MISSION D'INFORMATION PORTANT SUR LA GESTION DES RISQUES CLIMATIQUES ET L'EVOLUTION DE NOS REGIMES D'INDEMNISATION	de la	Mission d'information portant sur la gestion des risques climatiques et l'évolution de nos régimes d'indemnisation	MI sur l'indemnisation des risques climatiques	\N	\N	2261
CROISSENTRE	2019-02-12 00:00:00	2019-02-21 00:00:00	ACTIF	CROISSENTRE	projet de loi relatif à la croissance et la transformation des entreprises	CROISSENTRE	du	projet de loi relatif à la croissance et la transformation des entreprises	CROISSENTRE	\N	\N	2303
POLYNESIE2	2019-04-30 00:00:00	2019-05-08 00:00:00	ACTIF	POLYNESIE2	projet de loi organique portant modification du statut d'autonomie de la Polynésie française	POLYNESIE2	du	projet de loi organique portant modification du statut d'autonomie de la Polynésie française	POLYNESIE2	\N	\N	2401
POLYNESIE3	2019-04-30 00:00:00	2019-05-08 00:00:00	ACTIF	POLYNESIE3	projet de loi portant diverses dispositions institutionnelles en Polynésie française	POLYNESIE3	du	projet de loi portant diverses dispositions institutionnelles en Polynésie française	POLYNESIE3	\N	\N	2402
SANTE	2019-05-02 00:00:00	2019-05-16 00:00:00	ACTIF	SANTE	proposition de loi relative au droit de résiliation sans frais de contrats de complémentaire santé	SANTE	de la 	proposition de loi relative au droit de résiliation sans frais de contrats de complémentaire santé	SANTE	\N	\N	2421
DOCUMENTSADM	2013-12-10 00:00:00	2014-09-30 00:00:00	ACTIF	MCI sur l'accès aux documents administratifs	MCI sur l'accès aux documents administratifs et aux données publiques	MISSION COMMUNE D'INFORMATION SUR L'ACCÈS AUX DOCUMENTS ADMINISTRATIFS ET AUX DONNÉES PUBLIQUES	de la	Mission commune d'information sur l'accès aux documents administratifs et aux données publiques	Mission commune d'information sur l'accès aux documents administratifs et aux données publiques	2013-12-10 17:52:20	2014-11-18 15:40:00	342
CITOYENNETE	2016-06-22 00:00:00	2016-07-07 00:00:00	ACTIF	GT Egalité et citoyenneté	Groupe de travail préfigurant commission spéciale Egalité et citoyenneté	GT PREFIGURANT COMMISSION SPECIALE EGALITE ET CITOYENNETE	de la	groupe de travail préfigurant commission spéciale "égalité et citoyenneté"	Groupe de travail préfigurant commission spéciale Egalité et citoyenneté	2016-06-22 16:05:02	2017-03-21 11:14:04	1001
DJIHAD	2014-10-14 00:00:00	2015-05-12 00:00:00	ACTIF	CE sur la lutte contre les réseaux djihadistes	CE organisation et moyens de la lutte contre les réseaux djihadistes en France et en Europe	COMMISSION D'ENQUÊTE SUR L'ORGANISATION ET LES MOYENS DE LA LUTTE CONTRE LES RÉSEAUX DJIHADISTES EN FRANCE ET EN EUROPE	de la	commission d'enquête sur l'organisation et les moyens de la lutte contre les réseaux djihadistes en France et en Europe	Commission d'enquête sur organisation et moyens de la lutte contre les réseaux djihadistes en France et en Europe	2014-10-14 18:04:53	2017-03-21 11:16:53	461
TELEPHONE	2016-06-22 00:00:00	2016-09-30 00:00:00	ACTIF	MI téléphones mobiles	Mission d'information sur l'inventaire et devenir des matériaux et composants des téléphones mobiles	MISSION D'INFORMATION SUR L'INVENTAIRE ET LE DEVENIR DES MATERIAUX ET COMPOSANTS DES TELEPHONES MOBILES	de la	Mission d'information sur l'inventaire et le devenir des matériaux et composants des téléphones mobiles	Mission d'information sur l'inventaire et devenir des matériaux et composants des téléphones mobiles	2016-06-22 16:38:58	2016-10-07 09:16:23	1002
VIGILANCE	2016-10-19 00:00:00	2016-11-02 00:00:00	ACTIF	VIGILANCE	Devoir de vigilance des sociétés mères et des entreprises donneuses d'ordre	VIGILANCE	de la	Devoir de vigilance des sociétés mères et des entreprises donneuses d'ordre	VIGILANCE	2016-10-20 17:03:10	2016-11-03 17:03:58	1181
PLFR2016	2016-12-16 00:00:00	2016-12-19 00:00:00	ACTIF	PLFR2016	Projet de loi de finances rectificative pour 2016	PLFR2016	de la	Projet de loi de finances rectificative pour 2016	PLFR2016	2016-12-16 17:10:53	2016-12-21 14:17:50	1321
CONSOMMATION	2017-01-12 00:00:00	2017-01-18 00:00:00	ANCIEN	CONSOMMATION	PJL Ratification de deux ordonnances relatives à la consommation	CONSOMMATION	du	projet de loi ratifiant les ordonnances n° 2016-301 du 14 mars 2016 relative à la partie législative du code de la consommation et n° 2016-351 du 25 mars 2016  sur les contrats de crédit aux consommateurs relatifs aux biens immobiliers à usage d'habitation et simplifiant le dispositif de mise en oeuvre des obligations en matière de conformité et de sécurité des produits et services	CONSOMMATION	2017-01-13 10:56:43	2018-02-28 15:16:27	1341
ANSM	2017-01-12 00:00:00	2017-01-18 00:00:00	ANCIEN	ANSM	PJL Simplification procédures mises en oeuvre par l'Agence nationale de sécurité du médicament et des produits de santé	ANSM	du	projet de loi de simplification procédures mises en oeuvre par l'Agence nationale de sécurité du médicament et des produits de santé	ANSM	2017-01-13 11:04:35	2018-02-28 15:17:35	1361
ANSP	2017-01-12 00:00:00	2017-01-18 00:00:00	ANCIEN	ANSP	projet de loi portant création Agence nationale de santé publique	ANSP	du	projet de loi portant création de l'Agence nationale de santé publique	ANSP	2017-01-13 11:14:23	2018-02-28 15:18:28	1362
CHUTE	2018-02-07 00:00:00	2018-07-07 00:00:00	ACTIF	CE Moyens de l'Etat après chute Etat islamique	CE Moyens de l'Etat après chute Etat islamique	COMMISSION D'ENQUÊTE SUR L'ORGANISATION ET LES MOYENS DES SERVICES DE L'ETAT POUR FAIRE FACE À L'ÉVOLUTION DE LA MENACE TERRORISTE APRÈS LA CHUTE DE L'ETAT ISLAMIQUE	de la	Commission d'enquête sur l'organisation et les moyens des services de l'Etat pour faire face à l'évolution de la menace terroriste après la chute de l'Etat islamique	CE Moyens de l'Etat après chute Etat islamique	2018-02-06 16:26:47	2018-02-16 12:03:28	1762
PLFSS2018	2017-11-20 00:00:00	2017-11-23 00:00:00	ACTIF	PLFSS2018	projet de loi de financement de la sécurité sociale pour 2018	PLFSS2018	du	projet de loi de financement de la sécurité sociale pour 2018	PLFSS2018	2017-11-20 10:41:29	2017-12-07 10:05:36	1601
POLYNESIE	2018-06-28 00:00:00	2018-07-05 00:00:00	ACTIF	POLYNESIE	projet de loi sur les sanctions en matière de concurrence en Polynésie française	POLYNESIE	du	projet de loi ratifiant l'ordonnance n° 2017-157 du 9 février 2017 étendant et adaptation à la Polynésie française certaines dispositions du livre IV du code de commerce relatives aux contrôles et aux sanctions en matière de concurrence	POLYNESIE	\N	\N	2001
ASILE	2018-06-28 00:00:00	2018-07-05 00:00:00	ACTIF	ASILE	projet de loi Asile et immigration	ASILE	du	projet de loi pour une immigration maîtrisée, un droit d'asile effectif et une intégration réussie	ASILE	\N	\N	2002
MANIPULATION	2018-09-25 00:00:00	2018-09-27 00:00:00	ACTIF	MANIPULATION	proposition de loi relative à la lutte contre la manipulation de l'information	MANIPULATION	de la 	proposition de loi relative à la lutte contre la manipulation de l'information	MANIPULATION	\N	\N	2121
AERIEN	2019-04-30 00:00:00	2019-10-04 00:00:00	ACTIF	MI Transports aériens et aménagement des territoires	MI Transports aériens et aménagement des territoires	MISSION D'INFORMATION "TRANSPORTS AÉRIENS ET AMÉNAGEMENT DES TERRITOIRES"	de la	Mission d'information "Transports aériens et aménagement des territoires"	MI Transports aériens et aménagement des territoires	\N	\N	2381
FONDS	2019-05-22 00:00:00	2019-10-04 00:00:00	ACTIF	MI sous-utilisation fonds européens en France	MI sous-utilisation fonds européens en France	MISSION D'INFORMATION SUR LA SOUS-UTILISATION CHRONIQUE DES FONDS EUROPÉENS EN FRANCE	de la 	Mission d'information sur la sous-utilisation chronique des fonds européens en France	MI sous-utilisation fonds européens en France	\N	\N	2441
NOTREDAME	2019-05-28 00:00:00	2019-06-05 00:00:00	ACTIF	NOTREDAME	projet de loi pour la conservation et la restauration de Notre-Dame de Paris	NOTREDAME	du	projet de loi pour la conservation et la restauration de la cathédrale Notre-Dame de Paris et instituant une souscription nationale à cet effet	NOTREDAME	\N	\N	2461
ECOLE	2019-06-05 00:00:00	2019-06-14 00:00:00	ACTIF	ECOLE	projet de loi pour une école de la confiance	ECOLE	du	projet de loi pour une école de la confiance	ECOLE	\N	\N	2481
SYSTEME	2019-06-05 00:00:00	2019-06-20 00:00:00	ACTIF	SYSTEME	projet de loi relatif à l'organisation et à la transformation du système de santé	SYSTEME	du	projet de loi relatif à l'organisation et à la transformation du système de santé	SYSTEME	\N	\N	2482
OFBC	2019-05-22 00:00:00	2019-06-26 00:00:00	ACTIF	OFBC	projet de loi portant création de l'OFBC	OFBC	du	projet de loi portant création de l'Office français de la biodiversité et de la chasse	OFBC	\N	\N	2502
ARTICLE13	2019-05-22 00:00:00	2019-06-26 00:00:00	ACTIF	ARTICLE13	projet de loi portant organique relative à l'application de l'article 13 de la Constitution	ARTICLE13	du	projet de loi organique relative à l'application du cinquième alinéa de l'article 13 de la Constitution	ARTICLE13	\N	\N	2503
AUTORITES	2015-04-08 00:00:00	2016-02-28 00:00:00	ANCIEN	CE Autorités administratives indépendantes	Commission d'enquête sur les autorités administratives indépendantes	COMMISSION D'ENQUÊTE SUR LE BILAN ET LE CONTRÔLE DE LA CRÉATION, DE L'ORGANISATION, DE L'ACTIVITÉ ET DE LA GESTION DES AUTORITÉS ADMINISTRATIVES INDÉPENDANTES	de la	commission d'enquête sur le bilan et le contrôle de la création, de l'organisation, de l'activité et de la gestion des autorités administratives indépendantes	Commission d'enquête sur les autorités administratives indépendantes	2015-04-09 17:30:06	2017-03-21 11:16:19	561
COMMANDE	2015-04-08 00:00:00	2015-10-14 00:00:00	ACTIF	MCI Commande publique	Mission commune d'information sur la commande publique	MISSION COMMUNE D'INFORMATION SUR LA COMMANDE PUBLIQUE	de la	Mission commune d'information sur la commande publique	Mission commune d'information sur la commande publique	2015-04-09 17:34:36	2016-05-03 09:48:35	562
SECURITE	2016-02-04 00:00:00	2016-02-11 00:00:00	ACTIF	SECURITE	sécurité dans transports de voyageurs	SECURITE	de la	Sécurité dans transports de voyageurs	SECURITE	2016-02-23 13:29:43	2016-02-23 13:49:56	721
CCI	2016-02-04 00:00:00	2016-02-11 00:00:00	ACTIF	CCI	Chambres de commerce et d'industrie et chambres des métiers et de l'artisanat	CCI	de la	Chambres de commerce et d'industrie et chambres des métiers et de l'artisanat	CCI	2016-02-23 13:50:36	2016-02-23 13:57:34	723
MINEURS	2016-03-11 00:00:00	2016-03-22 00:00:00	ACTIF	MINEURS	protection des mineurs	MINEURS	de la	protection des mineurs	MINEURS	2016-03-11 11:43:29	2016-04-01 10:40:24	768
ABUS	2016-05-12 00:00:00	2016-05-17 00:00:00	ACTIF	ABUS	Abus de marché	ABUS	de la	Commission mixte paritaire réformant le système de répression des abus de marché	ABUS	2016-05-12 13:49:18	2016-05-18 08:49:08	881
URGENCE	2016-07-20 00:00:00	2016-07-20 00:00:00	ACTIF	URGENCE	Prorogation de l'état d'urgence	URGENCE	de la	\N	URGENCE	2016-07-20 19:30:07	2016-10-07 09:17:16	1121
BREXIT	2016-07-13 00:00:00	2017-06-12 00:00:00	ACTIF	GS Retrait du Royaume-Uni et la refondation de l'UE	GS Retrait du Royaume-Uni et la refondation de l'UE	GROUPE DE SUIVI SUR LE RETRAIT DU ROYAUME-UNI ET REFONDATION DE L'UNION EUROPEENNE	du	groupe de suivi sur le retrait du Royaume-Uni et la refondation de l'Union européenne	GS Retrait du Royaume-Uni et la refondation de l'UE	2016-10-07 09:04:29	2017-06-12 11:07:15	1141
PLEC	2016-10-18 00:00:00	2016-10-25 00:00:00	ACTIF	PLEC	Egalité et citoyenneté	PLEC	de la	Egalité et citoyenneté	PLEC	2016-10-19 10:52:39	2016-11-03 17:04:14	1161
STATUT	2016-12-15 00:00:00	2016-12-21 00:00:00	ACTIF	STATUT	Statut de Paris et aménagement métropolitain	STATUT	de la	Statut de Paris et aménagement métropolitain	STATUT	2016-12-16 10:37:09	2016-12-21 14:17:28	1281
MONTAGNE	2016-12-13 00:00:00	2016-12-19 00:00:00	ACTIF	MONTAGNE	Modernisation, développement et protection des territoires de montagne	MONTAGNE	de la	Modernisation, développement et protection des territoires de montagne	MONTAGNE	2016-12-16 10:40:45	2016-12-21 14:18:00	1301
PLFR2017	2017-11-09 00:00:00	2017-11-10 00:00:00	ACTIF	PLFR2017	projet de loi de finances rectificative pour 2017	PLFR2017	du	projet de loi de finances rectificative pour 2017	PLFR2017	2017-11-09 18:37:27	2017-11-20 10:47:06	1563
HYDROCARBURE	2017-11-15 00:00:00	2017-11-22 00:00:00	ACTIF	HYDROCARBURE	projet de loi mettant fin à la recherche ainsi qu'à l'exploitation des hydrocarbures	HYDROCARBURE	du	projet de loi mettant fin à la recherche ainsi qu'à l'exploitation des hydrocarbures et portant diverses dispositions relatives à l'énergie et à l'environnement	HYDROCARBURE	2017-11-16 10:14:33	2017-12-07 10:05:16	1581
ALSTOM	2017-11-22 00:00:00	2018-06-06 00:00:00	ACTIF	MI Alstom et stratégie industrielle du pays	Mission d'information sur Alstom et la stratégie industrielle du pays	MISSION D'INFORMATION SUR ALSTOM ET LA STRATEGIE INDUSTRIELLE DU PAYS	de la	mission d'information sur Alstom et la strategie industrielle du pays	MI Alstom et stratégie industrielle du pays	2017-11-21 15:41:03	2017-11-21 15:45:13	1602
ORDRE	2017-12-01 00:00:00	2017-12-06 00:00:00	ACTIF	ORDRE	projet de loi ratifiant ordonnance relative au fonctionnement des ordres des professions de santé	ORDRE	du	projet de loi ratifiant l'ordonnance relative à l'adaptation des dispositions législatives relatives au fonctionnement des ordres des professions de santé	ORDRE	2017-12-01 11:39:52	2017-12-07 10:05:56	1622
PLFR2017_2	2017-12-18 00:00:00	2017-12-19 00:00:00	ANCIEN	PLFR2017_2	projet de loi de finances rectificative pour 2017_2	projet de loi de finances rectificative pour 2017	du	projet de loi de finances rectificative pour 2017	PLFR2017_2	2017-12-18 09:19:27	2018-02-28 15:03:57	1661
GEMAPI	2017-12-19 00:00:00	2017-12-21 00:00:00	ACTIF	GEMAPI	PPL exercice des compétences des collectivités territoriales dans le domaine de la gestion des milieux aquatiques	GEMAPI	de la	proposition de loi relative à l'exercice des compétences des collectivités territoriales dans le domaine de la gestion des milieux aquatiques et de la prévention des inondations	GEMAPI	2017-12-20 10:07:04	2017-12-21 10:18:39	1681
DDADUE	2018-01-31 00:00:00	2018-02-06 00:00:00	ANCIEN	DDADUE	Projet de loi portant diverses dispositions d'adaptation au droit de l'UE dans le domaine de la sécurité	DDADUE	du	projet de loi portant diverses dispositions d'adaptation au droit de l'Union européenne dans le domaine de la sécurité	DDADUE	2018-02-06 12:16:14	2018-02-28 15:05:34	1761
HERBE	2018-04-11 00:00:00	2018-09-30 00:00:00	ACTIF	MI sur le développement de l'herboristerie	Mission d'information sur le développement de l'herboristerie	MISSION D'INFORMATION SUR LE DÉVELOPPEMENT DE L'HERBORISTERIE ET DES PLANTES MÉDICINALES, DES FILIÈRES ET MÉTIERS D'AVENIR	de la	Mission d'information sur le développement de l'herboristerie et des plantes médicinales, des filières et métiers d'avenir	MI sur le développement de l'herboristerie	2018-04-10 15:58:09	2018-04-30 10:22:04	1881
HAUTE	2018-04-11 00:00:00	2018-10-07 00:00:00	ACTIF	CE sur les mutations de la Haute fonction publique	CE sur les mutations de la Haute fonction publique et leurs conséquences	COMMISSION D'ENQUÊTE SUR LES MUTATIONS DE LA HAUTE FONCTION PUBLIQUE ET LEURS CONSÉQUENCES SUR LE FONCTIONNEMENT DES INSTITUTIONS DE LA RÉPUBLIQUE	de la	Commission d'enquête sur les mutations de la Haute fonction publique et leurs conséquences sur le fonctionnement des institutions de la République	CE sur les mutations de la Haute fonction publique	2018-04-10 16:08:57	2018-04-30 10:21:09	1882
PACTE	2018-06-07 00:00:00	2018-06-12 00:00:00	ACTIF	PACTE	projet de loi pour un nouveau pacte ferroviaire	PACTE	du	projet de loi pour un nouveau pacte ferroviaire	PACTE	2018-06-07 17:06:31	2018-06-07 17:09:51	1941
PORTABLE	2018-07-16 00:00:00	2018-07-19 00:00:00	ACTIF	PORTABLE	proposition de loi relative à l'encadrement de l'usage du téléphone portable dans les écoles et les collèges	PORTABLE	de la	proposition de loi relative à l'encadrement de l'usage du téléphone portable dans les écoles et les collèges	PORTABLE	\N	\N	2061
ELAN	2018-07-19 00:00:00	2018-09-12 00:00:00	ACTIF	ELAN	projet de loi portant évolution du logement, de l'aménagement et du numérique	ELAN	du	projet de loi portant évolution du logement, de l'aménagement et du numérique	ELAN	\N	\N	2081
REFORME	2018-11-26 00:00:00	2018-12-14 00:00:00	ACTIF	REFORME	projet de loi de programmation 2018-2022 et de réforme pour la justice	REFORME	du	projet de loi de programmation 2018-2022 et de réforme pour la justice	REFORME	\N	\N	2201
GOUVERNANCE	2013-11-19 00:00:00	2014-09-30 00:00:00	ACTIF	MCI sur la gouvernance de l'internet	Mission commune d'information sur la gouvernance de l'internet	MISSION COMMUNE D'INFORMATION SUR LE NOUVEAU RÔLE ET LA NOUVELLE STRATÉGIE POUR L'UNION EUROPÉENNE DANS LA GOUVERNANCE DE L'INTERNET	de la 	Mission commune d'information sur le nouveau rôle et la nouvelle stratégie pour l'Union européenne dans la gouvernance de l'internet	Mission commune d'information sur le nouveau rôle et la nouvelle stratégie pour l'UE dans la gouvernance de l'internet	2013-11-19 18:41:46	2014-11-18 15:40:46	321
ECOMOUV	2013-12-10 00:00:00	2014-09-30 00:00:00	ACTIF	CE sur la mise en oeuvre de l'écotaxe poids lourds	Commission d'enquête sur la mise en oeuvre de l'écotaxe poids lourds	COMMISSION D'ENQUÊTE SUR LES MODALITÉS DU MONTAGE JURIDIQUE ET FINANCIER ET L'ENVIRONNEMENT DU CONTRAT RETENU IN FINE POUR LA MISE EN OEUVRE DE L'ÉCOTAXE POIDS LOURDS	de la	Commission d'enquête sur les modalités du montage juridique et financier et l'environnement du contrat retenu in fine pour la mise en oeuvre de l'écotaxe poids lourds	Commission d'enquête sur la mise en oeuvre de l'écotaxe poids lourds	2013-12-10 17:41:56	2014-11-18 15:40:30	341
REGIONS	2014-06-18 00:00:00	2015-01-17 00:00:00	ACTIF	CS Délimitation des régions	Commission spéciale Délimitation des régions, élections régionales et départementales et calendrier électoral	COMMISSION SPÉCIALE CHARGÉE D'EXAMINER LE PROJET DE LOI RELATIF À LA DÉLIMITATION DES RÉGIONS, AUX ÉLECTIONS RÉGIONALES ET DÉPARTEMENTALES ET MODIFIANT LE CALENDRIER ÉLECTORAL	de la	Commission spéciale chargée d'examiner le projet de loi relatif à la délimitation des régions, aux élections régionales et départementales et modifiant le calendrier électoral	Commission spéciale Délimitation des régions, élections régionales et départementales et calendrier électoral	2014-06-18 21:50:55	2015-04-09 17:09:52	421
AUTORITES	2015-07-09 00:00:00	2015-11-04 00:00:00	ACTIF	CE Autorités administratives indépendantes	Commission d'enquête sur les autorités administratives indépendantes	COMMISSION D'ENQUÊTE SUR LE BILAN ET LE CONTRÔLE DE LA CRÉATION, DE L'ORGANISATION, DE L'ACTIVITÉ ET DE LA GESTION DES AUTORITÉS ADMINISTRATIVES INDÉPENDANTES	de la	Commission d'enquête sur le bilan et le contrôle de la création, de l'organisation, de l'activité et de la gestion des autorités administratives indépendantes	Commission d'enquête sur les autorités administratives indépendantes	2015-07-09 11:36:18	2016-04-28 11:37:32	601
CROISSANCE	2015-12-09 00:00:00	2015-06-23 00:00:00	ACTIF	CS croissance et activité	Commission spéciale sur le projet de loi pour la croissance, l'activité et l'égalité des chances économiques	COMMISSION SPÉCIALE SUR LE PROJET DE LOI POUR LA CROISSANCE, L'ACTIVITE ET L'EGALITE DES CHANCES ECONOMIQUES	de la	Commission spéciale sur le projet de loi pour la croissance, l'activité et l'égalité des chances économiques	Commission spéciale sur le projet de loi pour la croissance, l'activité et l'égalité des chances économiques	2015-12-09 18:22:21	2016-04-28 11:35:21	641
AUTORITES	2016-02-29 00:00:00	2015-10-28 00:00:00	ACTIF	CE Autorités administratives indépendantes	Commission d'enquête sur les autorités administratives indépendantes	COMMISSION D'ENQUÊTE SUR LE BILAN ET LE CONTRÔLE DE LA CRÉATION, DE L'ORGANISATION, DE L'ACTIVITÉ ET DE LA GESTION DES AUTORITÉS ADMINISTRATIVES INDÉPENDANTES	de la	Commission d'enquête sur le bilan et le contrôle de la création, de l'organisation, de l'activité et de la gestion des autorités administratives indépendantes	Commission d'enquête sur les autorités administratives indépendantes	2016-02-29 14:54:40	2016-02-29 14:55:23	741
EGALITE	2016-07-07 00:00:00	2017-06-12 00:00:00	ACTIF	CS Egalité et citoyenneté	Commission spéciale chargée d'examiner le projet de loi « Egalité et citoyenneté »	COMMISSION SPÉCIALE CHARGÉE D¿EXAMINER LE PROJET DE LOI « ÉGALITÉ ET CITOYENNETÉ »	de la	commission spéciale chargée d'examiner le projet de loi « Égalité et citoyenneté »	Commission spéciale chargée d'examiner le projet de loi « Egalité et citoyenneté »	2016-07-07 17:19:19	2017-06-12 11:07:18	1061
PLF2017	2016-11-29 00:00:00	2016-12-14 00:00:00	ACTIF	PLF2017	projet de loi de finances pour 2017	PLF2017	de la	projet de loi de finances pour 2017	PLF2017	2016-11-30 12:07:49	2016-12-15 10:00:00	1261
PHYSICIEN	2017-12-01 00:00:00	2017-12-06 00:00:00	ACTIF	PHYSICIEN	projet de loi ratifiant l'ordonnance relative à la profession de physicien médical	PHYSICIEN	du	projet de loi ratifiant l'ordonnance relative à la profession de physicien médical et l'ordonnance relative à la reconnaissance des qualifications professionnelles dans le domaine de la santé	PHYSICIEN	2017-12-01 11:29:30	2017-12-07 10:05:49	1621
ORIENTATION	2018-02-07 00:00:00	2018-02-14 00:00:00	ACTIF	ORIENTATION	Projet de loi relatif à l'orientation et à la réussite des étudiants	ORIENTATION	du	Projet de loi relatif à l'orientation et à la réussite des étudiants	ORIENTATION	2018-02-14 10:46:02	2018-02-16 09:34:55	1781
JO2024	2018-02-07 00:00:00	2018-02-21 00:00:00	ACTIF	JO2024	projet de loi relatif à l'organisation des jeux olympiques et paralympiques de 2024	JO2024	du	projet de loi relatif à l'organisation des jeux olympiques et paralympiques de 2024	JO2024	2018-02-14 10:51:40	2018-02-22 10:57:50	1782
BREXIT2	2017-11-08 00:00:00	2020-01-30 00:00:00	ACTIF	GS retrait du Royaume-Uni et refondation de l'UE	Groupe de suivi sur le retrait du Royaume-Uni et la refondation de l'Union européenne	GROUPE DE SUIVI SUR LE RETRAIT DU ROYAUME-UNI ET LA REFONDATION DE L'UNION EUROPÉENNE 2	du	Groupe de suivi sur le retrait du Royaume-Uni et la refondation de l'Union européenne 2	BREXIT2	2018-03-12 15:54:12	2018-03-12 16:04:06	1821
DONNEES	2018-03-29 00:00:00	2018-04-08 00:00:00	ACTIF	DONNEES	projet de loi relatif à la protection des données personnelles	DONNEES	du	projet de loi relatif à la protection des données personnelles	DONNEES	2018-03-29 17:20:25	2018-05-22 16:40:01	1861
AVENIR	2018-07-12 00:00:00	2018-07-17 00:00:00	ACTIF	AVENIR	projet de loi pour la liberté de choisir son avenir professionnel	AVENIR	du	projet de loi pour la liberté de choisir son avenir professionnel	AVENIR	\N	\N	2022
OEP	2018-06-19 00:00:00	2018-07-04 00:00:00	ACTIF	OEP	proposition de loi visant à garantir la présence des parlementaires dans certains OEP	OEP	de la	proposition de loi visant à garantir la présence des parlementaires dans certains organismes extérieurs au Parlement et à simplifier les modalités de leur nomination	OEP	\N	\N	1962
PLFSS2019	2018-11-15 00:00:00	2018-11-21 00:00:00	ACTIF	PLFSS2019	projet de loi de financement de la sécurité sociale pour 2019	PLFSS2019	du	projet de loi de financement de la sécurité sociale pour 2019	PLFSS2019	\N	\N	2182
JURIDICTIONS	2018-11-26 00:00:00	2018-12-14 00:00:00	ACTIF	JURIDICTIONS	projet de loi organique relatif au renforcement de l'organisation des juridictions	JURIDICTIONS	du	projet de loi organique relatif au renforcement de l'organisation des juridictions	JURIDICTIONS	\N	\N	2202
PLF2019	2018-12-07 00:00:00	2018-12-12 00:00:00	ACTIF	PLF2019	projet de loi de finances pour 2019	PLF2019	du	projet de loi de finances pour 2019	PLF2019	\N	\N	2221
BIENCULT	2020-11-19 00:00:00	2020-11-20 00:00:00	ACTIF	BIENCULT	PJL Restitution biens culturels Bénin Sénégal	BIENCULT	du	projet de loi relatif au retour de biens culturels à la République du Bénin et à la République du Sénégal	BIENCULT	\N	\N	3201
PLFSS21	2020-11-12 00:00:00	2020-11-20 00:00:00	ACTIF	PLFSS21	PLFSS pour 2021	PLFSS21	du	projet de loi de financement de la sécurité sociale pour 2021	PLFSS21	\N	\N	3202
PLFR420	2020-11-17 00:00:00	2020-12-18 00:00:00	ACTIF	PLFR420	PLFR4 pour 2020	PLFR420	du	projet de loi de finances rectificative pour 2020 (4)	PLFR420	\N	\N	3203
PLF2021	2020-12-09 00:00:00	2020-12-10 00:00:00	ACTIF	PLF2021	PLF pour 2021	PLF2021	du	projet de loi de finances pour 2021	PLF2021	\N	\N	3204
PJLOELEC	2020-12-10 00:00:00	2020-12-11 00:00:00	ACTIF	PJLOELEC	projet de loi organique relatif aux délais d'organisation des élections législatives et sénatoriales	PJLOELEC	du	projet de loi organique relatif aux délais d'organisation des élections législatives et sénatoriales	PJLOELEC	\N	\N	3205
PJLELEC	2020-12-10 00:00:00	2020-12-11 00:00:00	ACTIF	PJLELEC	PJL Délais d'organisation des élections municipales partielles et des élections des membres des commissions syndicales	PJLELEC	du	projet de loi relatif aux délais d'organisation des élections municipales partielles et des élections des membres des commissions syndicales	PJLELEC	\N	\N	3206
PARQUETEURO	2020-12-15 00:00:00	2020-12-16 00:00:00	ACTIF	PARQUETEURO	PJL Parquet européen, justice environnementale et justice pénale spécialisée	PARQUETEURO	du	projet de loi relatif au Parquet européen, à la justice environnementale et à la justice pénale spécialisée	PARQUETEURO	\N	\N	3207
URGSAN	2021-01-28 00:00:00	2021-01-29 00:00:00	ACTIF	URGSAN	projet de loi prorogeant l'état d'urgence sanitaire	URGSAN	du	projet de loi prorogeant l'état d'urgence sanitaire	URGSAN	\N	\N	3208
JUSTMINEURS	2021-02-04 00:00:00	2021-02-05 00:00:00	ACTIF	JUSTMINEURS	PJL Code de la justice pénale des mineurs	JUSTMINEURS	du	projet de loi ratifiant l'ordonnance n° 2019-950 du 11 septembre 2019 portant partie législative du code de la justice pénale des mineurs	JUSTMINEURS	\N	\N	3209
BIOETHIQ	2021-02-17 00:00:00	2021-02-19 00:00:00	ACTIF	BIOETHIQ	projet de loi relatif à la bioéthique	BIOETHIQ	du	projet de loi relatif à la bioéthique	BIOETHIQ	\N	\N	3210
REPORT	2021-02-11 00:00:00	2021-02-15 00:00:00	ACTIF	REPORT	PJL Report des conseils départementaux, régionaux et assemblées de Corse, Guyane et Martinique	REPORT	du	PJL portant report du renouvellement général des conseils départementaux, des conseils régionaux et des assemblées de Corse, de Guyane et de Martinique	REPORT	\N	\N	3211
ELECTPDR	2021-03-02 00:00:00	2021-03-05 00:00:00	ACTIF	ELECTPDR	PJLO Élection du Président de la République	ELECTPDR	du	PJLO portant diverses mesures relatives à l¿élection du Président de la République	ELECTPDR	\N	\N	3221
COURTAGE	2021-03-10 00:00:00	2021-03-15 00:00:00	ACTIF	COURTAGE	PPL Réforme du courtage de l'assurance et du courtage en opérations de banque et en services de paiement	COURTAGE	de la	proposition de loi relative à la réforme du courtage de l'assurance et du courtage en opérations de banque et en services de paiement	COURTAGE	\N	\N	3222
SYSANTE	2021-03-02 00:00:00	2021-03-05 00:00:00	ACTIF	SYSANTE	PPL Améliorer le système de santé par la confiance et la simplification	SYSANTE	de la	proposition de loi visant à améliorer le système de santé par la confiance et la simplification	SYSANTE	\N	\N	3223
JUSTIPEN	2021-03-04 00:00:00	2021-03-09 00:00:00	ACTIF	JUSTIPEN	PPL améliorant l'efficacité de la justice de proximité et de la réponse pénale	JUSTIPEN	de la	proposition de loi améliorant l'efficacité de la justice de proximité et de la réponse pénale	JUSTIPEN	\N	\N	3224
EAUPOTAB	2021-03-23 00:00:00	2021-03-25 00:00:00	ACTIF	EAUPOTAB	PPL Services publics d'eau potable et d'assainissement en Guadeloupe	EAUPOTAB	de la	proposition de loi rénovant la gouvernance des services publics d'eau potable et d'assainissement en Guadeloupe	EAUPOTAB	\N	\N	3225
DETENTIO	2021-03-23 00:00:00	2021-03-25 00:00:00	ACTIF	DETENTIO	PPL tendant à garantir le droit au respect de la dignité en détention	DETENTIO	de la	proposition de loi tendant à garantir le droit au respect de la dignité en détention	DETENTIO	\N	\N	3226
HARCEL	2021-05-12 00:00:00	2021-09-22 00:00:00	ACTIF	MI Harcèlement scolaire	MI Harcèlement scolaire	MISSION D'INFORMATION SUR LE HARCÈLEMENT SCOLAIRE ET LE CYBERHARCÈLEMENT	\N	Mission d'information sur le harcèlement scolaire et le cyberharcèlement	HARCEL	\N	\N	3241
RATP	2023-12-06 00:00:00	2023-12-07 00:00:00	ACTIF	RATP	PPL RATP	RATP	de la	proposition de loi relative à l'ouverture à la concurrence du réseau de bus francilien de la RATP	RATP	\N	\N	3844
MEDIC	2023-01-19 00:00:00	\N	ACTIF	CE Pénurie de médicaments	CE Pénurie de médicaments	COMMISSION D'ENQUÊTE SUR LA PÉNURIE DE MÉDICAMENTS ET LES CHOIX DE L'INDUSTRIE PHARMACEUTIQUE FRANÇAISE	de la	Commission d'enquête sur la pénurie de médicaments et les choix de l'industrie pharmaceutique française	CE Pénurie de médicaments	\N	\N	3381
RENOV	2023-01-17 00:00:00	\N	ACTIF	CE Rénovation énergétique	CE Rénovation énergétique	COMMISSION D'ENQUÊTE SUR L'EFFICACITÉ DES POLITIQUES PUBLIQUES EN MATIÈRE DE RÉNOVATION ÉNERGÉTIQUE	\N	Commission d'enquête sur l'efficacité des politiques publiques en matière de rénovation énergétique	CE Rénovation énergétique	\N	\N	3383
AVENCOMM	2023-01-24 00:00:00	\N	ACTIF	MI Commune et maire	MI Commune et maire	MISSION D'INFORMATION SUR L'AVENIR DE LA COMMUNE ET DU MAIRE EN FRANCE	de la	Mission d'information sur l'avenir de la commune et du maire en France	MI Commune et maire	\N	\N	3401
PENMEDIC	2023-01-24 00:00:00	\N	ACTIF	PENMEDIC	PENMEDIC	PENMEDIC	\N	\N	PENMEDIC	\N	\N	3402
PAPIER	2023-03-30 00:00:00	2023-03-31 00:00:00	ACTIF	PAPIER	PPL portant fusion des filières à responsabilité élargie des producteurs d¿emballages ménagers et de papier 	PAPIER	de la	proposition de loi portant fusion des filières à responsabilité élargie des producteurs d¿emballages ménagers et des producteurs de papier	PAPIER	\N	\N	3521
NUCLEAIRE	2023-05-04 00:00:00	2023-05-05 00:00:00	ACTIF	NUCLEAIRE	PJL Nucléaire	NUCLEAIRE	du	PJL construction nouvelles installations nucléaires à proximité sites nucléaires existants et fonctionnement installations existantes	NUCLEAIRE	\N	\N	3541
PJLO	2023-10-05 00:00:00	2023-10-06 00:00:00	ACTIF	PJLO	PJLO Justice	PJLO	de la	PJLO relatif à l'ouverture, la modernisation et la responsabilité du corps judiciaire	PJLO	\N	\N	3661
SEPA	2021-05-12 00:00:00	2021-05-13 00:00:00	ACTIF	SEPA	PJL confortant les principes de la République et de lutte contre le séparatisme	SEPA	du	projet de loi confortant les principes de la République et de lutte contre le séparatisme	SEPA	\N	\N	3701
CRIS	2021-05-20 00:00:00	2021-05-21 00:00:00	ACTIF	CRIS	PJL Gestion de la sortie de crise sanitaire	CRIS	du	projet de loi relatif à la gestion de la sortie de crise sanitaire	CRIS	\N	\N	3702
CLIM	2021-07-12 00:00:00	2021-07-13 00:00:00	ACTIF	CLIM	PJL Lutte contre le dérèglement climatique et renforcement de la résilience face à ses effets	CLIM	du	projet de loi portant lutte contre le dérèglement climatique et renforcement de la résilience face à ses effets	CLIM	\N	\N	3703
FR21	2021-07-05 00:00:00	2021-07-05 00:00:00	ACTIF	FR21	PLFR 2021	FR21	du	projet de loi de finances rectificative pour 2021	FR21	\N	\N	3704
OA13	2021-07-01 00:00:00	2021-07-02 00:00:00	ACTIF	OA13	PJLO article 13 de la Constitution	OA13	du	projet de loi organique modifiant la loi organique n° 2010-837 du 23 juillet 2010 relative à l¿application du cinquième alinéa de l¿article 13 de la Constitution	OA13	\N	\N	3705
OECU	2021-07-01 00:00:00	2021-07-02 00:00:00	ACTIF	OECU	PJL Régulation et protection oeuvres culturelles	OECU	du	projet de loi relatif à la régulation et à la protection de l¿accès aux ¿uvres culturelles à l¿ère numérique	OECU	\N	\N	3706
CLIMAT	2019-07-17 00:00:00	2019-07-26 00:00:00	ACTIF	CLIMAT	projet de loi relatif à l'énergie et au climat	CLIMAT	du	projet de loi relatif à l'énergie et au climat	CLIMAT	\N	\N	2561
AGENCESPORT	2019-07-17 00:00:00	2019-07-24 00:00:00	ACTIF	AGENCESPORT	PJL Création agence nationale du sport et JO 2024	AGENCESPORT	du	projet de loi relatif à la création de l'Agence nationale du sport et diverses dispositions relatives à l'organisation des jeux Olympiques et Paralympiques 2024	AGENCESPORT	\N	\N	2562
BIOETHIQUE	2019-10-16 00:00:00	2021-08-02 00:00:00	ACTIF	Commission spéciale sur la bioéthique	Commission spéciale sur la bioéthique	COMMISSION SPECIALE SUR LE PROJET DE LOI RELATIF A LA BIOETHIQUE	de la	Commission spéciale sur le projet de loi relatif à la bioéthique	Commission spéciale sur la bioéthique	\N	\N	2601
LUBRIZOL	2019-10-16 00:00:00	2020-06-02 00:00:00	ACTIF	Commission d'enquête sur l'incendie de l'usine Lubrizol	Commission d'enquête sur l'incendie de l'usine Lubrizol	COMMISSION D'ENQUÊTE CHARGÉE D'ÉVALUER LA GESTION DES CONSÉQUENCES DE L'INCENDIE DE L'USINE LUBRIZOL	de la	Commission d'enquête chargée d'évaluer la gestion des conséquences de l'incendie de l'usine Lubrizol	Commission d'enquête sur l'incendie de l'usine Lubrizol	\N	\N	2602
FAMILLE	2019-11-21 00:00:00	2019-11-28 00:00:00	ACTIF	FAMILLE	proposition de loi visant à agir contre les violences au sein de la famille	FAMILLE	de la	proposition de loi visant à agir contre les violences au sein de la famille	FAMILLE	\N	\N	2681
HAINE	2019-12-18 00:00:00	2020-01-09 00:00:00	ACTIF	HAINE	proposition de loi visant à lutter contre les contenus haineux sur internet	HAINE	de la	proposition de loi visant à lutter contre les contenus haineux sur internet	HAINE	\N	\N	2741
DEPARTEMENT	2020-02-19 00:00:00	2020-09-15 00:00:00	ACTIF	MI Compétences des départements	MI Compétences des départements	MISSION D'INFORMATION « QUEL RÔLE, QUELLE PLACE, QUELLES COMPÉTENCES DES DÉPARTEMENTS DANS LES RÉGIONS FUSIONNÉES AUJOURD'HUI ET DEMAIN ? »	de la	Mission d'information « Quel rôle, quelle place, quelles compétences des départements dans les régions fusionnées aujourd'hui et demain ? »	MI Compétences des départements	\N	\N	2841
ILLECTRONISM	2020-03-04 00:00:00	2020-09-17 00:00:00	ACTIF	MI Illectronisme et inclusion numérique	MI Illectronisme et inclusion numérique	MISSION D'INFORMATION SUR LA LUTTE CONTRE L'ILLECTRONISME ET INCLUSION NUMÉRIQUE	de la	Mission d'information sur la lutte contre l'illectronisme et inclusion numérique	MI Illectronisme et inclusion numérique	\N	\N	2863
PHYT	2020-10-29 00:00:00	2020-11-02 00:00:00	ACTIF	PHYT	PJL produits phytopharmaceutiques en cas de danger sanitaire pour les betteraves sucrières	PHYT	du	projet de loi relatif aux conditions de mise sur le marché de certains produits phytopharmaceutiques en cas de danger sanitaire pour les betteraves sucrières	PHYT	\N	\N	3123
CESE	2020-10-30 00:00:00	2020-11-02 00:00:00	ACTIF	CESE	projet de loi organique relatif au conseil économique, social et environnemental	CESE	du	projet de loi organique relatif au conseil économique, social et environnemental	CESE	\N	\N	3122
PAUP	2021-01-13 00:00:00	2021-09-15 00:00:00	ACTIF	MI Lutte contre la précarisation et la paupérisation	MI Lutte contre la précarisation et la paupérisation	MISSION D'INFORMATION SUR L'ÉVOLUTION ET LA LUTTE CONTRE LA PRÉCARISATION ET LA PAUPÉRISATION D'UNE PARTIE DES FRANÇAIS	de la	mission d'information sur l'évolution et la lutte contre la précarisation et la paupérisation d'une partie des français	MI Lutte contre la précarisation et la paupérisation	\N	\N	3142
PLFFG23	2023-11-21 00:00:00	2023-11-22 00:00:00	ACTIF	PLFFG23	PLFFG23	PLFFG23	du	projet de loi de finances de fin de gestion pour 2023	PLFFG23	\N	\N	3845
SECR	2023-12-13 00:00:00	2023-12-13 00:00:00	ACTIF	SECR	PPL Secrétaire de mairie	SECR	de la	proposition de loi visant à revaloriser le métier de secrétaire de mairie	SECR	\N	\N	3846
ENSAGRIC	2021-02-03 00:00:00	2021-09-30 00:00:00	ACTIF	MI Enseignement agricole	MI Enseignement agricole	MISSION D'INFORMATION SUR L'ENSEIGNEMENT AGRICOLE, OUTIL INDISPENSABLE AU COEUR DES ENJEUX DE NOS FILIÈRES AGRICOLES ET ALIMENTAIRES	de la	mission d'information sur l'enseignement agricole, outil indispensable au coeur des enjeux de nos filières agricoles et alimentaires	MI Enseignement agricole	\N	\N	3162
UBER	2021-06-17 00:00:00	2021-09-29 00:00:00	ACTIF	MI Uberisation	MI Uberisation	MISSION D'INFORMATION SUR LE THÈME : "UBERISATION DE LA SOCIÉTÉ : QUEL IMPACT DES PLATEFORMES NUMÉRIQUES SUR LES MÉTIERS ET L'EMPLOI ?"	\N	Mission d'information sur le thème : "Uberisation de la société : quel impact des plateformes numériques sur les métiers et l'emploi ?"	UBER	\N	\N	3261
JUST	2023-10-05 00:00:00	2023-10-06 00:00:00	ACTIF	JUST	PJL Justice	JUST	de la	Projet de loi d¿orientation et de programmation du ministère de la justice 2023-2027	JUST	\N	\N	3662
INDUS	2023-10-09 00:00:00	2023-10-10 00:00:00	ACTIF	INDUS	PJL Industrie verte	INDUS	de la	Projet de loi relatif à l'industrie verte	INDUS	\N	\N	3663
TOTA	2023-12-14 00:00:00	\N	ACTIF	CE Obligations de TotalEnergies	CE Obligations de TotalEnergies	COMMISSION D'ENQUÊTE SUR « LES MOYENS MOBILISÉS ET MOBILISABLES PAR L'ÉTAT POUR ASSURER LA PRISE EN COMPTE ET LE RESPECT PAR LE GROUPE TOTALENERGIES DES OBLIGATIONS CLIMATIQUES ET DES ORIENTATIONS DE LA POLITIQUE ÉTRANGÈRE DE LA FRANCE »	\N	Commission d'enquête sur « les moyens mobilisés et mobilisables par l'État pour assurer la prise en compte et le respect par le groupe TotalEnergies des obligations climatiques et des orientations de la politique étrangère de la France »	CE Obligations de TotalEnergies	\N	\N	3821
COMP	2024-02-15 00:00:00	\N	ACTIF	MI Complémentaires santé	MI Complémentaires santé	MISSION D'INFORMATION SUR « LES COMPLÉMENTAIRES SANTÉ, MUTUELLES : L'IMPACT SUR LE POUVOIR D'ACHAT DES FRANÇAIS »	de la	mission d'information sur le thème : « Complémentaires santé, mutuelles : l'impact sur le pouvoir d'achat des Français »	MI Complémentaires santé	\N	\N	3921
AUTOROUT	2020-01-29 00:00:00	2020-09-16 00:00:00	ACTIF	CE sur l'évolution des concessions autoroutières	CE sur l'évolution des concessions autoroutières	COMMISSION D'ENQUÊTE SUR LE CONTRÔLE, LA RÉGULATION ET L'ÉVOLUTION DES CONCESSIONS AUTOROUTIÈRES	\N	Commission d'enquête sur le contrôle, la régulation et l'évolution des concessions autoroutières	CE sur l'évolution des concessions autoroutières	\N	\N	2761
COVID19	2020-03-19 00:00:00	2020-03-23 00:00:00	ACTIF	COVID19	projet de loi d'urgence pour faire face à l'épidémie de Covid-19	COVID19	du	projet de loi d'urgence pour faire face à l'épidémie de Covid-19	COVID19	\N	\N	2901
PLFR2	2020-04-21 00:00:00	2020-04-24 00:00:00	ACTIF	PLFR2	deuxième projet de loi de finances rectificative pour 2020	PLFR2	du	deuxième projet de loi de finances rectificative pour 2020	PLFR2	\N	\N	2902
SANITAIRE	2020-05-04 00:00:00	2020-05-10 00:00:00	ACTIF	SANITAIRE	projet de loi prorogeant l'état d'urgence sanitaire et complétant ses dispositions	SANITAIRE	du	projet de loi prorogeant l'état d'urgence sanitaire et complétant ses dispositions	SANITAIRE	\N	\N	2903
DETTESOCIALE	2020-07-01 00:00:00	2020-07-09 00:00:00	ACTIF	DETTESOCIALE	projet de loi relatif à la dette sociale et à l'autonomie	DETTESOCIALE	du	projet de loi relatif à la dette sociale et à l'autonomie	DETTESOCIALE	\N	\N	3001
AUTONOMIE	2020-07-01 00:00:00	2020-07-09 00:00:00	ACTIF	AUTONOMIE	projet de loi organique relatif à la dette sociale et à l'autonomie	AUTONOMIE	du	projet de loi organique relatif à la dette sociale et à l'autonomie	AUTONOMIE	\N	\N	3002
EGALCHAN	2021-02-03 00:00:00	2021-09-23 00:00:00	ACTIF	MI Égalité des chances	MI Égalité des chances	MISSION D'INFORMATION SUR LA POLITIQUE EN FAVEUR DE L'ÉGALITÉ DES CHANCES ET DE L'ÉMANCIPATION DE LA JEUNESSE	de la	mission d'information sur la politique en faveur de l'égalité des chances et de l'émancipation de la jeunesse	MI Égalité des chances	\N	\N	3161
HOPITAL	2021-12-01 00:00:00	2022-03-29 00:00:00	ACTIF	CE Hôpital	CE Hôpital	COMMISSION D'ENQUÊTE SUR LA SITUATION DE L'HÔPITAL  ET LE SYSTÈME DE SANTÉ EN FRANCE	de la	commission d'enquête sur la situation de l'hôpital  et le système de santé en France	CE Hôpital	\N	\N	3341
JUDI	2021-12-01 00:00:00	2022-03-29 00:00:00	ACTIF	MI Judiciarisation	MI Judiciarisation	MISSION D'INFORMATION SUR LE THÈME : « LA JUDICIARISATION DE LA VIE PUBLIQUE : UNE CHANCE POUR L'ÉTAT DE DROIT ? UNE MISE EN QUESTION DE LA DÉMOCRATIE REPRÉSENTATIVE ? QUELLES CONSÉQUENCES SUR LA MANIÈRE DE PRODUIRE DES NORMES ET LEUR HIÉRARCHIE ? »	de la	mission d'information sur le thème : « La judiciarisation de la vie publique : une chance pour l'État de droit ? Une mise en question de la démocratie représentative ? Quelles conséquences sur la manière de produire des normes et leur hiérarchie ? »	MI Judiciarisation	\N	\N	3342
BREXIT3	2020-01-31 00:00:00	\N	ACTIF	GS Nouvelle relation euro-britannique	Groupe de suivi de la nouvelle relation euro-britannique	GROUPE DE SUIVI DE LA NOUVELLE RELATION EURO-BRITANNIQUE	du	Groupe de suivi de la nouvelle relation euro-britannique	BREXIT3	\N	\N	3481
RETRAITES	2023-03-15 00:00:00	2023-03-16 00:00:00	ACTIF	RETRAITES	Projet de loi de financement rectificative  de la sécurité sociale pour 2023	RETRAITES	du	projet de loi de financement rectificative  de la sécurité sociale pour 2023	RETRAITES	\N	\N	3501
RELCOM	2023-03-15 00:00:00	2023-03-16 00:00:00	ACTIF	RELCOM	Proposition de loi tendant à renforcer l'équilibre dans les relations commerciales entre fournisseurs et distributeurs	RELCOM	de la	Proposition de loi tendant à renforcer l'équilibre dans les relations commerciales entre fournisseurs et distributeurs	RELCOM	\N	\N	3502
AFCL	2023-10-04 00:00:00	2024-01-18 00:00:00	ANCIEN	AFCL	Culture	COMMISSION DE LA CULTURE, DE L'ÉDUCATION ET DE LA COMMUNICATION	AFC	commission de la culture, de l'éducation et de la communication	commission de la culture	2023-10-04 00:00:00	2024-01-19 00:00:00	3641
EMPLO	2023-10-20 00:00:00	2023-10-21 00:00:00	ACTIF	EMPLO	PJL Plein emploi	EMPLO	de la	projet de loi pour le plein emploi	EMPLO	\N	\N	3681
INEG	2021-06-24 00:00:00	2021-06-25 00:00:00	ACTIF	INEG	PJL de programmation développement solidaire et lutte contre les inégalités mondiales	INEG	du	projet de loi de programmation relatif au développement solidaire et à la lutte contre les inégalités mondiales	INEG	\N	\N	3707
PLFSS	2023-11-17 00:00:00	2023-11-18 00:00:00	ACTIF	PLFSS	PLFSS	PLFSS	du	projet de loi de financement de la sécurité sociale pour 2024	PLFSS	\N	\N	3801
HABI	2024-03-14 00:00:00	2024-03-15 00:00:00	ACTIF	HABI	PJL Rénovation habitat	HABI	du	projet de loi relatif à l'accélération et à la simplification de la rénovation de l'habitat dégradé et des grandes opérations 	HABI	\N	\N	3981
IMMI	2023-12-18 00:00:00	2023-12-19 00:00:00	ACTIF	IMMI	PJL Immigration	IMMI	du	projet de loi pour contrôler l'immigration, améliorer l'intégration	IMMI	\N	\N	3842
PLF2024	2023-12-12 00:00:00	2023-12-12 00:00:00	ACTIF	PLF2024	PLF 2024	PLF2024	du	projet de loi de finances pour 2024	PLF2024	\N	\N	3843
RESTHUM	2023-12-06 00:00:00	2023-12-07 00:00:00	ACTIF	RESTHUM	PPL Restitution des restes humains	RESTHUM	de la	proposition de loi relative à la restitution des restes humains appartenant aux collections publiques	RESTHUM	\N	\N	3847
SOINS	2023-12-07 00:00:00	2023-12-08 00:00:00	ACTIF	SOINS	PPL Accès aux soins	SOINS	de la	proposition de loi relative visant à améliorer l'accès aux soins par l¿engagement territorial des professionnels	SOINS	\N	\N	3848
VAPO	2024-03-20 00:00:00	2024-03-21 00:00:00	ACTIF	VAPO	PPL Vapotage	VAPO	de la 	proposition de loi visant à interdire les dispositifs électroniques de vapotage à usage unique	VAPO	\N	\N	4001
NUME	2024-03-20 00:00:00	2024-03-27 00:00:00	ACTIF	NUME	PJL Espace numérique	NUME	du	projet de loi visant à sécuriser  et réguler l'espace numérique 	NUME	\N	\N	4002
COMPTES2018	2019-07-11 00:00:00	2019-07-17 00:00:00	ACTIF	COMPTES2018	projet de loi de règlement du budget et d'approbation des comptes pour l'année 2018	COMPTES2018	du 	projet de loi de règlement du budget et d'approbation des comptes pour l'année 2018	COMPTES2018	\N	\N	2541
MUSIQUE	2019-07-24 00:00:00	2019-09-14 00:00:00	ACTIF	MUSIQUE	proposition de loi relative à la création d'un Centre national de la musique	MUSIQUE	de la 	proposition de loi relative à la création d'un Centre national de la musique	MUSIQUE	\N	\N	2581
PRESSE	2019-07-24 00:00:00	2019-09-25 00:00:00	ACTIF	PRESSE	projet de loi relatif à la modernisation de la distribution de la presse	PRESSE	du	projet de loi relatif à la modernisation de la distribution de la presse	PRESSE	\N	\N	2582
PLFR2019	2019-11-15 00:00:00	2019-11-20 00:00:00	ACTIF	PLFR2019	projet de loi de finances rectificative pour 2019	PLFR2019	du	projet de loi de finances rectificative pour 2019	PLFR2019	\N	\N	2661
PLF2020	2019-12-06 00:00:00	2019-12-12 00:00:00	ACTIF	PLF2020	projet de loi de finances pour 2020	PLF2020	du	projet de loi de finances pour 2020	PLF2020	\N	\N	2721
PJLO13	2020-01-28 00:00:00	2020-02-05 00:00:00	ACTIF	PJLO13	PJLO modifiant la loi organique relative à l'application du cinquième alinéa de l'article 13 de la Constitution	PJLO13	du	PJLO modifiant la loi organique relative à l'application du cinquième alinéa de l'article 13 de la Constitution	PJLO13	\N	\N	2781
HADOPI	2020-01-28 00:00:00	2020-02-05 00:00:00	ACTIF	HADOPI	PJL modifiant article 13 de la Constitution et prorogeant mandat membres HADOPI	HADOPI	du	PJL modifiant article 13 de la Constitution et prorogeant mandat membres HADOPI	HADOPI	\N	\N	2782
SOLS	2020-02-05 00:00:00	2020-09-08 00:00:00	ACTIF	CE Pollution des sols	CE Pollution des sols	COMMISSION D'ENQUÊTE SUR LES PROBLÈMES SANITAIRES ET ÉCOLOGIQUES LIÉS AUX POLLUTIONS DES SOLS QUI ONT ACCUEILLI DES ACTIVITÉS INDUSTRIELLES OU MINIÈRES ET SUR LES POLITIQUES PUBLIQUES ET INDUSTRIELLES DE RÉHABILITATION DE CES SOLS	de la	Commission d'enquête sur les problèmes sanitaires et écologiques liés aux pollutions des sols qui ont accueilli des activités industrielles ou minières et sur les politiques publiques et industrielles de réhabilitation de ces sols	CE Pollution des sols	\N	\N	2801
FEDERATION	2020-03-04 00:00:00	2020-09-08 00:00:00	ACTIF	MI Fonctionnement fédérations sportives	MI Fonctionnement fédérations sportives	MISSION D'INFORMATION SUR LE FONCTIONNEMENT ET L'ORGANISATION DES FÉDÉRATIONS SPORTIVES	de la 	Mission d'information sur le fonctionnement et l'organisation des fédérations sportives	MI Fonctionnement fédérations sportives	\N	\N	2861
CRISE	2020-05-27 00:00:00	2020-06-03 00:00:00	ACTIF	CRISE	projet de loi relatif à diverses dispositions liées à la crise sanitaire	CRISE	du	projet de loi relatif à diverses dispositions liées à la crise sanitaire	CRISE	\N	\N	2904
SORTIE	2020-06-22 00:00:00	2020-06-26 00:00:00	ACTIF	SORTIE	projet de loi organisant la sortie de l'état d'urgence sanitaire	SORTIE	du	projet de loi organisant la sortie de l'état d'urgence sanitaire	SORTIE	\N	\N	2941
APPROBATION	2020-07-08 00:00:00	2020-07-10 00:00:00	ACTIF	APPROBATION	projet de loi de règlement du budget et d'approbation des comptes de l'année 2019	APPROBATION	du	projet de loi de règlement du budget et d'approbation des comptes de l'année 2019	APPROBATION	\N	\N	3021
PANDEMIE	2020-07-01 00:00:00	2020-12-08 00:00:00	ACTIF	CE Évaluation des politiques publiques face aux pandémies	CE Évaluation des politiques publiques face aux pandémies	COMMISSION D'ENQUÊTE POUR L'ÉVALUATION DES POLITIQUES PUBLIQUES FACE AUX GRANDES PANDÉMIES À LA LUMIÈRE DE LA CRISE SANITAIRE DE LA COVID-19 ET DE SA GESTION	de la	commission d'enquête pour l'évaluation des politiques publiques face aux grandes pandémies à la lumière de la crise sanitaire de la covid-19 et de sa gestion	CE Évaluation des politiques publiques face aux pandémies	\N	\N	2964
CMPASAP	2020-10-20 00:00:00	2020-10-22 00:00:00	ACTIF	CMPASAP	projet de loi d'accélération et de simplification de l'action publique	CMPASAP	du	projet de loi d'accélération et de simplification de l'action publique	CMPASAP	\N	\N	3061
CONF	2021-01-13 00:00:00	2021-11-18 00:00:00	ACTIF	MCI Effets des mesures en matière de confinement	MCI Effets des mesures en matière de confinement	MISSION COMMUNE D'INFORMATION CHARGÉE D'ÉVALUER LES EFFETS DES MESURES PRISES OU ENVISAGÉES EN MATIÈRE DE CONFINEMENT OU DE RESTRICTIONS D'ACTIVITÉS	de la	mission commune d'information chargée d'évaluer les effets des mesures prises ou envisagées en matière de confinement ou de restrictions d'activités	MCI Effets des mesures en matière de confinement	\N	\N	3141
METHANIS	2021-02-17 00:00:00	2021-09-29 00:00:00	ACTIF	MI Méthanisation	MI Méthanisation	MISSION D'INFORMATION INTITULÉE : « LA MÉTHANISATION DANS LE MIX ÉNERGÉTIQUE : ENJEUX ET IMPACTS »	de la	Mission d'information intitulée : « La méthanisation dans le mix énergétique : enjeux et impacts »	MI Méthanisation	\N	\N	3182
VIETUDIA	2021-02-17 00:00:00	2021-07-06 00:00:00	ACTIF	MI Conditions de la vie étudiante	MI Conditions de la vie étudiante	MISSION D'INFORMATION RELATIVE AUX CONDITIONS DE LA VIE ÉTUDIANTE EN FRANCE	de la	Mission d'information relative aux conditions de la vie étudiante en France	MI Conditions de la vie étudiante	\N	\N	3183
INFLUENCES	2021-06-24 00:00:00	2021-09-29 00:00:00	ACTIF	MI Influences étatiques	MI Influences étatiques	MISSION D'INFORMATION SUR LE THÈME : « LES INFLUENCES ÉTATIQUES EXTRA-EUROPÉENNES DANS LE MONDE UNIVERSITAIRE ET ACADÉMIQUE FRANÇAIS ET LEURS INCIDENCES »	de la	mission d'information sur le thème : « les influences étatiques extra-européennes dans le monde universitaire et académique français et leurs incidences »	MI Influences étatiques	\N	\N	3282
FONDSMER	2021-12-09 00:00:00	2022-06-21 00:00:00	ACTIF	MI Fonds marins	MI Fonds marins	MISSION D'INFORMATION SUR « L'EXPLORATION, LA PROTECTION ET L'EXPLOITATION DES FONDS MARINS : QUELLE STRATÉGIE POUR LA FRANCE ? »	de la	Mission d'information sur « L'exploration, la protection et l'exploitation des fonds marins : quelle stratégie pour la France ? »	MI Fonds marins	\N	\N	3361
INFL	2023-05-25 00:00:00	2023-05-26 00:00:00	ACTIF	INFL	PPL Influenceurs	INFL	de la	PPL visant à encadrer l¿influence commerciale et à lutter contre les dérives des influenceurs sur les réseaux sociaux	INFL	\N	\N	3611
RECHINNO	2021-12-09 00:00:00	2022-06-08 00:00:00	ACTIF	MI Excellence de la recherche/innovation	MI Excellence de la recherche/innovation	MISSION D'INFORMATION SUR LE THÈME « EXCELLENCE DE LA RECHERCHE/INNOVATION, PÉNURIE DE CHAMPIONS INDUSTRIELS : CHERCHEZ L'ERREUR FRANÇAISE »	de la	mission d'information sur le thème « Excellence de la recherche/innovation, pénurie de champions industriels : cherchez l'erreur française »	MI Excellence de la recherche/innovation	\N	\N	3362
GEAU	2023-02-01 00:00:00	\N	ACTIF	MI Gestion de l'eau	MI Gestion de l'eau	MISSION D'INFORMATION SUR LE THÈME : « GESTION DURABLE DE L'EAU : L'URGENCE D'AGIR POUR NOS USAGES, NOS TERRITOIRES ET NOTRE ENVIRONNEMENT »	de la	mission d'information sur le thème : « gestion durable de l'eau : l'urgence d'agir pour nos usages, nos territoires et notre environnement »	MI Gestion de l'eau	\N	\N	3421
BATI	2023-02-01 00:00:00	\N	ACTIF	MI Bâti scolaire	MI Bâti scolaire	MISSION D'INFORMATION SUR LE THÈME : « LE BÂTI SCOLAIRE À L'ÉPREUVE DE LA TRANSITION ÉCOLOGIQUE »	de la	mission d'information sur le thème : « le bâti scolaire à l'épreuve de la transition écologique »	MI Bâti scolaire	\N	\N	3423
FONCTION	2019-06-20 00:00:00	2019-07-04 00:00:00	ACTIF	FONCTION	projet de loi de transformation de la fonction publique	FONCTION	du	projet de loi de transformation de la fonction publique	FONCTION	\N	\N	2504
RADIO	2019-06-26 00:00:00	2019-07-04 00:00:00	ACTIF	RADIO	proposition de loi visant à préserver les intérêts dans le cadre de l'exploitation des réseaux radioélectriques mobiles	RADIO	de la	proposition de loi visant à préserver les intérêts de la défense et de la sécurité nationale de la France dans le cadre de l'exploitation des réseaux radioélectriques mobiles	RADIO	\N	\N	2506
MARITIME	2019-06-25 00:00:00	2019-10-22 00:00:00	ACTIF	MCI relative au sauvetage en mer	MCI relative au sauvetage en mer	MISSION COMMUNE D'INFORMATION RELATIVE AU SAUVETAGE EN MER	de la	Mission commune d'information relative au sauvetage en mer	MCI relative au sauvetage en mer	\N	\N	2507
PROXIMITE	2019-11-28 00:00:00	2019-12-12 00:00:00	ACTIF	PROXIMITE	projet de loi relatif à l'engagement dans la vie locale et à la proximité de l'action publique	PROXIMITE	du	projet de loi relatif à l'engagement dans la vie locale et à la proximité de l'action publique	PROXIMITE	\N	\N	2701
ELECTIONS	2020-06-10 00:00:00	2020-06-16 00:00:00	ACTIF	ELECTIONS	projet de loi report du 2nd tour des élections municipales	ELECTIONS	du	projet de loi report du 2nd tour des élections municipales	ELECTIONS	\N	\N	2921
PLFR3	2020-07-17 00:00:00	2020-07-23 00:00:00	ACTIF	PLFR3	troisième projet de loi de finances rectificative pour 2020	PLFR3	du	troisième projet de loi de finances rectificative pour 2020	PLFR3	\N	\N	3041
SURETE	2020-07-21 00:00:00	2020-07-23 00:00:00	ACTIF	SURETE	PPL instaurant des mesures de sûreté à l'encontre des auteurs d'infractions terroristes	SURETE	de la	PPL instaurant des mesures de sûreté à l'encontre des auteurs d'infractions terroristes	SURETE	\N	\N	3042
EMPL	2020-10-28 00:00:00	2020-10-29 00:00:00	ACTIF	EMPL	 PPL Inclusion dans l'emploi - Territoires zéro chômeur de longue durée	EMPL	de la	proposition de loi relative au renforcement de l'inclusion dans l'emploi par l'activité économique et à l'expérimentation « territoires zéro chômeur de longue durée »	EMPL	\N	\N	3101
SEGL	2021-03-29 00:00:00	2021-04-02 00:00:00	ACTIF	SEGL	PPL Sécurité globale	SEGL	de la	proposition de loi pour un nouveau pacte de sécurité respectueux des libertés	SEGL	\N	\N	3281
CZAN	2023-02-01 00:00:00	\N	ACTIF	CS Zéro artificialisation nette	CS Zéro artificialisation nette	COMMISSION SPÉCIALE SUR LA PROPOSITION DE LOI VISANT À FACILITER LA MISE EN OEUVRE DES OBJECTIFS DE « ZÉRO ARTIFICIALISATION NETTE » AU COEUR DES TERRITOIRES	de la	commission spéciale sur la proposition de loi visant à faciliter la mise en oeuvre des objectifs de « zéro artificialisation nette » au coeur des territoires	CS Zéro artificialisation nette	\N	\N	3422
CINC	2023-02-01 00:00:00	\N	ACTIF	CS Risque incendie	CS Risque incendie	COMMISSION SPÉCIALE SUR LA PROPOSITION DE LOI VISANT À RENFORCER LA PRÉVENTION ET LA LUTTE CONTRE L'INTENSIFICATION ET L'EXTENSION DU RISQUE INCENDIE	de la	commission spéciale sur la proposition de loi visant à renforcer la prévention et la lutte contre l'intensification et l'extension du risque incendie	CS Risque incendie	\N	\N	3424
LOCA	2023-02-15 00:00:00	\N	ACTIF	MI Finances locales	MI Finances locales	MISSION D'INFORMATION SUR " L'IMPACT DES DÉCISIONS RÉGLEMENTAIRES ET BUDGÉTAIRES DE L'ÉTAT SUR L'ÉQUILIBRE FINANCIER DES COLLECTIVITÉS LOCALES "	de la	mission d'information sur "l'impact des décisions réglementaires et budgétaires de l'Etat sur l'équilibre financier des collectivités locales"	MI Finances locales	\N	\N	3441
TIKTO	2023-03-01 00:00:00	\N	ACTIF	CE Tiktok	CE Tiktok	COMMISSION D'ENQUÊTE SUR L'UTILISATION DU RÉSEAU SOCIAL TIKTOK, SON EXPLOITATION DES DONNÉES, SA STRATÉGIE D'INFLUENCE	\N	commission d'enquête sur l'utilisation du réseau social tiktok, son exploitation des données, sa stratégie d'influence	CE Tiktok	\N	\N	3461
ESNU	2023-06-01 00:00:00	\N	ACTIF	CS numérique	CS numérique	COMMISSION SPÉCIALE SUR LE PROJET DE LOI VISANT À SÉCURISER ET RÉGULER L'ESPACE NUMÉRIQUE	de la	commission spéciale sur le projet de loi visant à sécuriser et réguler l'espace numérique	CS numérique	\N	\N	3561
PLPM	2023-07-10 00:00:00	2023-07-10 00:00:00	ACTIF	PLPM	LPM 2024-2030	PLPM	de la	PJL relatif à la programmation militaire pour les années 2024 à 2030 et portant diverses dispositions intéressant la défense	PLPM	\N	\N	3601
PZAN	2023-07-06 00:00:00	2023-07-07 00:00:00	ACTIF	PZAN	PPL ZAN	PZAN	de la 	PPL visant à renforcer l'accompagnement des élus locaux dans la mise en ¿uvre de la lutte contre l'artificialisation des sols	PZAN	\N	\N	3602
PCMF	2023-06-28 00:00:00	2023-06-29 00:00:00	ACTIF	PCMF	PJL CMF DDOM	PCMF	du	PJL ratifiant les ordonnances relatives à la partie législative du livre VII du code monétaire et financier et portant diverses dispositions relatives à l¿outre-mer	PCMF	\N	\N	3603
DOUA	2023-06-28 00:00:00	2023-06-29 00:00:00	ACTIF	DOUA	PJL Douane	DOUA	du	PJL visant à donner à la douane les moyens de faire face aux nouvelles menaces	DOUA	\N	\N	3604
PAFP	2023-06-28 00:00:00	2023-06-29 00:00:00	ACTIF	PAFP	PPL Parité fonction publique	PAFP	de la	PPL visant à renforcer l'accès des femmes aux responsabilités dans la fonction publique	PAFP	\N	\N	3605
EHAI	2023-06-20 00:00:00	2023-06-21 00:00:00	ACTIF	EHAI	PPL Majorité numérique	EHAI	de la	PPL visant à instaurer une majorité numérique et à lutter contre la haine en ligne	EHAI	\N	\N	3606
INCE	2023-06-19 00:00:00	2023-06-20 00:00:00	ACTIF	INCE	PPL Risque incendie	INCE	de la	PPL visant à renforcer la prévention et la lutte contre l'intensification et l'extension du risque incendie	INCE	\N	\N	3607
ENFA	2023-06-01 00:00:00	2023-06-02 00:00:00	ACTIF	ENFA	PPL Droit à l'image des enfants	ENFA	de la	visant à garantir le respect du droit à l¿image des enfants	ENFA	\N	\N	3610
INTE	2023-05-04 00:00:00	2023-05-05 00:00:00	ACTIF	INTE	PPL Interruption spontanée de grossesse	INTE	de la	PPL visant à favoriser l¿accompagnement des couples confrontés à une interruption spontanée de grossesse	INTE	\N	\N	3612
JOPA	2023-04-04 00:00:00	2023-04-05 00:00:00	ACTIF	JOPA	PJL Jeux Olympiques et Paralympiques 2024	JOPA	du	PJL relatif aux jeux Olympiques et Paralympiques de 2024 et portant diverses autres dispositions	JOPA	\N	\N	3613
SOIN	2023-04-06 00:00:00	2023-04-07 00:00:00	ACTIF	SOIN	PPL Accès aux soins	SOIN	de la	PPL portant amélioration de l'accès aux soins par la confiance aux professionnels de santé	SOIN	\N	\N	3614
SPOL	2023-07-04 00:00:00	2023-07-06 00:00:00	ACTIF	SPOL	PJL Restitution de biens culturels	SPOL	du	PJL relatif à la restitution des biens culturels ayant fait l¿objet de spoliations dans le contexte des persécutions antisémites perpétrées entre 1933 et 1945	SPOL	\N	\N	3615
ACCI	2023-07-06 00:00:00	2023-07-06 00:00:00	ACTIF	ACCI	PPL Protection des familles	ACCI	de la	PPL visant à renforcer la protection des familles d'enfants atteints d'une maladie ou d'un handicap ou victimes d'un accident d'une particulière gravité	ACCI	\N	\N	3616
RENO	2023-03-09 00:00:00	2023-03-10 00:00:00	ACTIF	RENO	PPL Rénovation énergétique	RENO	de la	PPL visant à ouvrir le tiers financement à l¿État, à ses établissements publics et aux collectivités territoriales pour favoriser les travaux de rénovation énergétique	RENO	\N	\N	3617
DADU	2023-02-09 00:00:00	2023-02-10 00:00:00	ACTIF	DADU	PJL DDADUE	DADU	du	PJL ortant diverses dispositions d'adaptation au droit de l'Union européenne dans les domaines de l¿économie, de la santé, du travail, des transports et de l¿agriculture	DADU	\N	\N	3618
MOBILITES	2019-07-03 00:00:00	2019-07-11 00:00:00	ACTIF	MOBILITES	projet de loi d'orientation des mobilités	MOBILITES	du	projet de loi d'orientation des mobilités	MOBILITES	\N	\N	2521
ALSACE	2019-07-03 00:00:00	2019-07-12 00:00:00	ACTIF	ALSACE	projet de loi relatif aux compétences de la Collectivité européenne d'Alsace	ALSACE	du	projet de loi relatif aux compétences de la Collectivité européenne d'Alsace	ALSACE	\N	\N	2522
RADICALI	2019-11-14 00:00:00	2020-07-07 00:00:00	ACTIF	CE combattre la radicalisation islamiste	CE combattre la radicalisation islamiste	COMMISSION D'ENQUÊTE SUR LE DÉVELOPPEMENT DE LA RADICALISATION ISLAMISTE ET LES MOYENS DE LE COMBATTRE	de la	Commission d'enquête sur le développement de la radicalisation islamiste et les moyens de le combattre	CE combattre la radicalisation	\N	\N	2622
PLFSS2020	2019-11-14 00:00:00	2019-11-20 00:00:00	ACTIF	PLFSS2020	projet de loi de financement de la sécurité sociale pour 2020	PLFSS2020	du	projet de loi de financement de la sécurité sociale pour 2020	PLFSS2020	\N	\N	2641
ASAP	2020-02-06 00:00:00	2020-12-08 00:00:00	ACTIF	CS ASAP	CS ASAP	COMMISSION SPÉCIALE CHARGÉE D'EXAMINER LE PROJET DE LOI D'ACCÉLÉRATION ET DE SIMPLIFICATION DE L'ACTION PUBLIQUE	de la 	Commission spéciale chargée d'examiner le projet de loi d'accélération et de simplification de l'action publique	CS ASAP	\N	\N	2821
GUYANE	2020-05-13 00:00:00	2020-09-15 00:00:00	ACTIF	MI Trafic de stupéfiants en provenance de Guyane	MI Trafic de stupéfiants en provenance de Guyane	MISSION D'INFORMATION SUR LE TRAFIC DE STUPÉFIANTS EN PROVENANCE DE GUYANE	de la	Mission d'information sur le trafic de stupéfiants en provenance de Guyane	MI Trafic de stupéfiants en provenance de Guyane	\N	\N	2881
DEMARCHAGE	2020-06-24 00:00:00	2020-07-02 00:00:00	ACTIF	DEMARCHAGE	proposition de loi visant à encadrer le démarchage téléphonique et à lutter contre les appels frauduleux	DEMARCHAGE	de la	proposition de loi visant à encadrer le démarchage téléphonique et à lutter contre les appels frauduleux	DEMARCHAGE	\N	\N	2961
CHEQUEVAC	2020-06-24 00:00:00	2020-07-03 00:00:00	ACTIF	CHEQUEVAC	projet de loi permettant le don de congés payés sous forme de chèques-vacances aux membres du secteur médico-social 	CHEQUEVAC	du	projet de loi permettant le don de congés payés sous forme de chèques-vacances aux membres du secteur médico-social en reconnaissance de leur action durant l'épidémie de Covid-19	CHEQUEVAC	\N	\N	2962
CONJUGALE	2020-06-24 00:00:00	2020-06-26 00:00:00	ACTIF	CONJUGALE	proposition de loi visant à protéger les victimes de violences conjugales	CONJUGALE	de la 	proposition de loi visant à protéger les victimes de violences conjugales	CONJUGALE	\N	\N	2981
RECHERCH	2020-11-09 00:00:00	2020-11-11 00:00:00	ACTIF	RECHERCH	projet de loi de programmation de la recherche de 2021 à 2030	RECHERCH	du	projet de loi de programmation de la recherche pour les années 2021 à 2030 et portant diverses dispositions relatives à la recherche et à l'enseignement supérieur	RECHERCH	\N	\N	3181
BIOCARBU	2023-01-17 00:00:00	\N	ACTIF	MI Biocarburants	MI Biocarburants	MISSION D'INFORMATION SUR LE THÈME : « LE DÉVELOPPEMENT D'UNE FILIÈRE DE BIOCARBURANTS, CARBURANTS SYNTHÉTIQUES DURABLES ET HYDROGÈNE VERT »	de la	Mission d'information sur le thème : « Le développement d'une filière de biocarburants, carburants synthétiques durables et hydrogène vert »	MI Biocarburants	\N	\N	3382
LOCATIF	2023-06-05 00:00:00	2023-06-06 00:00:00	ACTIF	LOCATIF	PPL Indices locatifs	LOCATIF	de la 	PPL maintenant provisoirement un dispositif de plafonnement de revalorisation de la variation annuelle des indices locatifs	LOCATIF	\N	\N	3581
PENR	2023-01-24 00:00:00	2023-01-25 00:00:00	ACTIF	PENR	PJL Energies renouvelables	PENR	du	PJL relatif à l¿accélération de la production d¿énergies renouvelables	PENR	\N	\N	3619
FIPU	2022-12-15 00:00:00	2022-12-16 00:00:00	ACTIF	FIPU	PJL Finances publiques 2023-2027	FIPU	du	PJL de programmation des finances publiques pour les années 2023 à 2027	FIPU	\N	\N	3620
PLF23	2022-12-06 00:00:00	2022-12-07 00:00:00	ACTIF	PLF23	PLF 2023	PLF23	du	PJL de finances pour 2023	PLF23	\N	\N	3621
OPMI	2022-12-01 00:00:00	2022-12-02 00:00:00	ACTIF	OPMI	PJLOPMI	OPMI	du	PJL d¿orientation et de programmation du ministère de l¿intérieur	OPMI	\N	\N	3622
PLFR22	2022-11-22 00:00:00	2022-11-23 00:00:00	ACTIF	PLFR22	PLFR 2022	PLFR22	du	PJL de finances rectificative pour 2022	PLFR22	\N	\N	3623
EMPLOI	2022-11-09 00:00:00	2022-11-10 00:00:00	ACTIF	EMPLOI	PJL Plein emploi	EMPLOI	du	PJL portant mesures d¿urgence relatives au fonctionnement du marché du travail en vue du plein emploi	EMPLOI	\N	\N	3624
PLFSS2023	2022-11-15 00:00:00	2022-11-16 00:00:00	ACTIF	PLFSS2023	PLFSS 2023	PLFSS2023	du	PJL de financement de la sécurité sociale pour 2023	PLFSS2023	\N	\N	3625
DDADUE23	2023-10-30 00:00:00	\N	ACTIF	CS DDADUE	CS sur le projet de loi portant diverses dispositions d'adaptation au droit de l'Union européenne	COMMISSION SPÉCIALE SUR LE PROJET DE LOI PORTANT DIVERSES DISPOSITIONS D'ADAPTATION AU DROIT DE L'UNION EUROPÉENNE	de la	commission spéciale sur le projet de loi portant diverses dispositions d'adaptation au droit de l'Union européenne	CS DDADUE	\N	\N	3721
CONSO	2023-10-31 00:00:00	2023-11-01 00:00:00	ACTIF	CONSO	PJL grande consommation	CONSO	du	projet de loi portant mesures d'urgence pour lutter contre l¿inflation concernant les produits de grande consommation	CONSO	\N	\N	3722
NARCO	2023-11-08 00:00:00	\N	ACTIF	CE Narcotrafic	CE Narcotrafic	COMMISSION D'ENQUÊTE SUR L'IMPACT DU NARCOTRAFIC EN FRANCE ET LES MESURES À PRENDRE POUR Y REMÉDIER	\N	commission d'enquête sur l'impact du narcotrafic en France et les mesures à prendre pour y remédier	CE Narcotrafic	\N	\N	3761
PARTAGE	2023-11-15 00:00:00	2023-11-16 00:00:00	ACTIF	PARTAGE	PJL Partage de la valeur	PARTAGE	du	projet de loi portant transposition de l'accord national interprofessionnel relatif au partage de la valeur au sein de l'entreprise	PARTAGE	\N	\N	3781
ELEC	2024-01-17 00:00:00	\N	ACTIF	CE Electricité	CE Electricité	COMMISSION D'ENQUÊTE PORTANT SUR LA PRODUCTION, LA CONSOMMATION ET LE PRIX DE L'ÉLECTRICITÉ AUX HORIZONS 2035 ET 2050	\N	commission d'enquête portant sur la production, la consommation et le prix de l'électricité aux horizons 2035 et 2050	ELEC	\N	\N	3861
COPRO	2024-02-01 00:00:00	\N	ACTIF	CE Paupérisation des copropriétés	CE Paupérisation des copropriétés	COMMISSION D'ENQUÊTE SUR LA PAUPÉRISATION DES COPROPRIÉTÉS IMMOBILIÈRES	de la	commission d'enquête sur la paupérisation des copropriétés immobilières	CE Paupérisation des copropriétés	\N	\N	3901
INFLU	2024-02-01 00:00:00	\N	ACTIF	CE Influences étrangères	CE Influences étrangères	COMMISSION D'ENQUÊTE SUR LES POLITIQUES PUBLIQUES FACE AUX OPÉRATIONS D'INFLUENCES ÉTRANGÈRES VISANT NOTRE VIE DÉMOCRATIQUE, NOTRE ÉCONOMIE ET LES INTÉRÊTS DE LA FRANCE SUR LE TERRITOIRE NATIONAL ET À L'ÉTRANGER AFIN DE DOTER NOTRE LÉGISLATION ET NOS PRATIQUES DE MOYENS D'ENTRAVES EFFICIENTS POUR CONTRECARRER LES ACTIONS HOSTILES À NOTRE SOUVERAINETÉ	de la 	commission d'enquête sur les politiques publiques face aux opérations d'influences étrangères visant notre vie démocratique, notre économie et les intérêts de la France sur le territoire national et à l'étranger afin de doter notre législation et nos pratiques de moyens d'entraves efficients pour contrecarrer les actions hostiles à notre souveraineté	CE Influences étrangères	\N	\N	3902
GASPILLE	2019-12-18 00:00:00	2020-01-09 00:00:00	ACTIF	GASPILLE	projet de loi relatif à la lutte contre le gaspillage et à l'économie circulaire	GASPILLE	du	projet de loi relatif à la lutte contre le gaspillage et à l'économie circulaire	GASPILLE	\N	\N	2742
DDADUEF	2020-10-22 00:00:00	2020-10-23 00:00:00	ACTIF	DDADUEF	PJL portant diverses dispositions d'adaptation au droit de l'UE en matière économique et financière	DDADUEF	du	projet de loi portant diverses dispositions d'adaptation au droit de l'Union européenne en matière économique et financière	DDADUEF	\N	\N	3081
CSI	2020-10-22 00:00:00	2020-10-23 00:00:00	ACTIF	CSI	PJL Code de la sécurité intérieure	CSI	du	projet de loi relatif à la prorogation des chapitres VI à X du titre II du livre II et de l'article L. 851-3 du code de la sécurité intérieure	CSI	\N	\N	3082
PPLEGALIM	2021-10-04 00:00:00	2021-10-05 00:00:00	ACTIF	PPLEGALIM	Proposition de loi visant à protéger la rémunération des agriculteurs	PPLEGALIM	de la	Proposition de loi visant à protéger la rémunération des agriculteurs	PPLEGALIM	\N	\N	3301
PPLPOMPIERS	2021-10-07 00:00:00	2021-10-08 00:00:00	ACTIF	PPLPOMPIERS	Proposition de loi sapeurs pompiers	PPLPOMPIERS	de la	Proposition de loi visant à consolider notre modèle de sécurité civile et valoriser le volontariat des sapeurs pompiers et les sapeurs pompiers professionnels 	PPLPOMPIERS	\N	\N	3302
CULTURE	2021-11-18 00:00:00	2022-06-07 00:00:00	ACTIF	MI Culture citoyenne	MI Culture citoyenne	MISSION D'INFORMATION SUR LE THÈME : " COMMENT REDYNAMISER LA CULTURE CITOYENNE ?"	de la	mission d'information sur le thème : " comment redynamiser la culture citoyenne ?"	MI Culture citoyenne	\N	\N	3321
SECUECO	2021-11-18 00:00:00	2022-03-30 00:00:00	ACTIF	MI Sécurité sociale écologique	MI Sécurité sociale écologique	MISSION D'INFORMATION SUR LE THÈME " PROTÉGER ET ACCOMPAGNER LES INDIVIDUS EN CONSTRUISANT LA SÉCURITÉ SOCIALE ÉCOLOGIQUE DU XXIÈME SIÈCLE "	de la	mission d'information sur le thème " Protéger et accompagner les individus en construisant la sécurité sociale écologique du XXIème siècle "	MI Sécurité sociale écologique	\N	\N	3322
CABINETS	2021-11-18 00:00:00	2022-03-16 00:00:00	ACTIF	CE Cabinets de conseil	CE Cabinets de conseil	COMMISSION D'ENQUÊTE SUR L'INFLUENCE CROISSANTE DES CABINETS DE CONSEIL PRIVÉS SUR LES POLITIQUES PUBLIQUES	de la	commission d'enquête sur l'influence croissante des cabinets de conseil privés sur les politiques publiques	CE Cabinets de conseil	\N	\N	3323
MEDIA	2021-11-18 00:00:00	2022-03-29 00:00:00	ACTIF	CE Concentration dans les médias	CE Concentration dans les médias	COMMISSION D'ENQUÊTE " AFIN DE METTRE EN LUMIÈRE LES PROCESSUS AYANT PERMIS OU POUVANT ABOUTIR À UNE CONCENTRATION DANS LES MÉDIAS EN FRANCE, ET D'ÉVALUER L'IMPACT DE CETTE CONCENTRATION SUR LA DÉMOCRATIE"	de la	commission d'enquête " afin de mettre en lumière les processus ayant permis ou pouvant aboutir à une concentration dans les médias en France, et d'évaluer l'impact de cette concentration sur la démocratie "	CE Concentration dans les médias	\N	\N	3325
SER	2023-11-07 00:00:00	2023-11-08 00:00:00	ACTIF	SER	PPL SER	SER	de la	proposition de loi relative aux services express régionaux métropolitains	SER	\N	\N	3741
AFCL	2024-01-18 00:00:00	\N	ACTIF	AFCL	Culture	COMMISSION DE LA CULTURE, DE L'ÉDUCATION, DE LA COMMUNICATION ET DU SPORT	AFC	commission de la culture, de l'éducation, de la communication et du sport	commission de la culture	2024-01-19 00:00:00	\N	3883
PERI	2024-02-28 00:00:00	\N	ACTIF	MI Périnatalité	MI Périnatalité	MISSION D'INFORMATION SUR LE THÈME : « L'AVENIR DE LA SANTÉ PÉRINATALE ET SON ORGANISATION TERRITORIALE »	de la	mission d'information sur le thème : « L'avenir de la santé périnatale et son organisation territoriale »	MI Périnatalité	\N	\N	3941
ARCH	2024-02-28 00:00:00	\N	ACTIF	MI Architectes Bâtiments de France	MI Architectes Bâtiments de France	MISSION D'INFORMATION SUR « ARCHITECTES DES BÂTIMENTS DE FRANCE : PÉRIMÈTRE ET COMPÉTENCES »	de la	mission d'information sur « Architectes des Bâtiments de France : périmètre et compétences »	MI Architectes Bâtiments de France	\N	\N	3942
IFAM	2024-02-15 00:00:00	2024-02-16 00:00:00	ACTIF	IFAM	PPL Violences intrafamiliales	IFAM	de la	proposition de loi visant à mieux protéger et accompagner les enfants victimes et covictimes de violences intrafamiliales	IFAM	\N	\N	3943
SECT	2024-02-27 00:00:00	2024-02-28 00:00:00	ACTIF	SECT	PPL Protection des élus	SECT	de la	proposition de loi renforçant la sécurité et la protection des maires et des élus locaux	SECT	\N	\N	3944
DERI	2024-03-07 00:00:00	2024-03-08 00:00:00	ACTIF	DERI	PJL Dérives sectaires	DERI	du	projet de loi visant à lutter contre les dérives sectaires	DERI	\N	\N	3961
AGE	2024-03-12 00:00:00	2024-03-13 00:00:00	ACTIF	AGE	PPL Grand âge 	AGE	de la	proposition de loi portant diverses mesures relatives au grand âge et à l'autonomie	AGE	\N	\N	3962
ASSO	2024-03-22 00:00:00	2024-03-28 00:00:00	ACTIF	ASSO	PPL Engagement bénévole	ASSO	de la	proposition de loi visant à soutenir l'engagement bénévole et simplifier la vie associative	ASSO	\N	\N	4021
NUCL	2024-03-07 00:00:00	2024-04-04 00:00:00	ACTIF	NUCL	PJL Sûreté nucléaire	NUCL	du	Projet de loi relatif à l¿organisation de la gouvernance de la sûreté nucléaire et de la radioprotection pour répondre au défi de la relance de la filière nucléaire	NUCL	\N	\N	4041
ARTI	2024-03-07 00:00:00	2024-04-04 00:00:00	ACTIF	ARTI	PJLO Article 13	ARTI	du	Projet de loi organique modifiant la loi organique n° 2010-837 du 23 juillet 2010 relative à l'application du cinquième alinéa de l'article 13 de la Constitution	ARTI	\N	\N	4042
DDAD	2023-12-19 00:00:00	2024-04-05 00:00:00	ACTIF	DDAD	PJL DDADUE	DDAD	du	projet de loi portant diverses dispositions d'adaptation au droit de l'Union européenne en matière d'économie, de finances, de transition écologique, de droit pénal, de droit social et en matière agricole 	DDAD	\N	\N	4043
TEST	2024-04-03 00:00:00	2024-04-10 00:00:00	ACTIF	TEST	PPL Discriminations tests individuels	TEST	de la	proposition de loi visant à lutter  contre les discriminations par la pratique de tests individuels et statistiques	TEST	\N	\N	4061
CRIM	2024-04-10 00:00:00	\N	ACTIF	CRIM	PPL Confiscation avoirs criminels	CRIM	de la	proposition de loi améliorant l'efficacité des dispositifs de saisie et de confiscation des avoirs criminels	CRIM	\N	\N	4081
\.


--
-- Data for Name: libdelega; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY libdelega (orgcod, libdelegadatdeb, libdelegadatfin, temvalcod, evelic, evelib, evelil, eveobs, libdelegaart, syscredat, sysmajdat, libdelegaid) FROM stdin;
COMITEDEONTO	2009-12-16 00:00:00	\N	ACTIF	Comité de déontologie	Comité de déontologie parlementaire du Sénat	Comité de déontologie parlementaire du Sénat	\N	du 	\N	\N	1
SFAPF	1900-01-01 00:00:00	\N	ACTIF	Section française de l'APF	Section française de l'Assemblée parlementaire de la francophonie	Section française de l'Assemblée parlementaire de la francophonie (A.P.F.)	Section française de l'Assemblée Parlementaire de la Francophonie	de la	\N	\N	2
UIP	1900-01-01 00:00:00	\N	ACTIF	Union Interparlementaire	Groupe français de l'Union Interparlementaire (U.I.P.)	Groupe français de l'Union Interparlementaire (U.I.P.)	\N	du	\N	\N	3
OTAN	1900-01-01 00:00:00	\N	ACTIF	délégation parlementaire Otan	Délégation française à l'Assemblée parlementaire de l'OTAN	Délégation française à l'Assemblée parlementaire de l'OTAN	\N	de la	\N	\N	4
205	1900-01-01 00:00:00	2009-06-25 00:00:00	ACTIF	Planification	Délégation pour la planification	Délégation pour la planification	\N	de la 	\N	\N	5
RENSEIGNEMEN	2007-10-10 00:00:00	\N	ACTIF	Renseignement	Délégation parlementaire au renseignement 	Délégation parlementaire au renseignement 	\N	de la	\N	\N	6
MECSS	2006-01-25 00:00:00	\N	ACTIF	MECSS	Mission d'évaluation et de contrôle de la sécurité sociale	Mission d'évaluation et de contrôle de la sécurité sociale	\N	de la 	\N	\N	7
202	1900-01-01 00:00:00	2008-10-07 00:00:00	ANCIEN	Union Européenne              	Délégation pour l'Union européenne	Délégation pour l'Union européenne	\N	de la 	\N	\N	8
203	1900-01-01 00:00:00	2009-06-25 00:00:00	ACTIF	Problèmes démographiques	Délégation parlementaire pour les problèmes démographiques	Délégation parlementaire pour les problèmes démographiques	\N	de la 	\N	\N	9
206	1900-01-01 00:00:00	\N	ACTIF	OPECST	Office parlementaire d'évaluation des choix scientifiques et technologiques	Office parlementaire d'évaluation des choix scientifiques et technologiques	\N	de l'	\N	\N	10
207	1900-01-01 00:00:00	2000-12-31 00:00:00	ANCIEN	Politiques publiques	Office parlementaire d'évaluation des politiques publiques	Office parlementaire d'évaluation des politiques publiques	\N	de l'	\N	\N	11
208	1900-01-01 00:00:00	2009-06-25 00:00:00	ACTIF	Législation	Office parlementaire d'évaluation de la législation	Office parlementaire d'évaluation de la législation	\N	de l'	\N	\N	12
CSCE	1900-01-01 00:00:00	\N	ACTIF	Org. sécurite coop. Europe	Délégation française à l'Assemblée parlementaire de l'Organisation pour la Sécurité et la Coopération en Europe (O.S.C.E	Délégation française à l'Assemblée parlementaire de l'Organisation pour la Sécurité et la Coopération en Europe (O.S.C.E.)	\N	de la 	\N	\N	13
210	1999-06-25 00:00:00	2009-06-25 00:00:00	ACTIF	Territoire	Délégation à l'aménagement et au développement durable du territoire	Délégation à l'aménagement et au développement durable du territoire	\N	de la 	\N	\N	14
211	1999-07-12 00:00:00	\N	ACTIF	Droits des femmes	Délégation aux droits des femmes et à l'égalité des chances entre les hommes et les femmes	Délégation aux droits des femmes et à l'égalité des chances entre les hommes et les femmes	\N	de la 	\N	\N	15
SANTE	2002-12-20 00:00:00	2009-06-25 00:00:00	ACTIF	Politiques de santé	Office parlementaire d'évaluation des politiques de santé	Office parlementaire d'évaluation des politiques de santé	\N	de l'	\N	\N	16
ODD	1900-01-01 00:00:00	2009-06-25 00:00:00	ACTIF	Observatoire décentralisation	Observatoire de la Décentralisation	Observatoire de la Décentralisation	\N	de l'	\N	\N	17
CONEUR	1900-01-01 00:00:00	2014-01-01 00:00:00	ACTIF	Conseil de l'Europe	Assemblée parlementaire du Conseil de l'Europe	Assemblée parlementaire du Conseil de l'Europe	\N	de l'	\N	2015-10-09 10:20:17	18
UEO	1900-01-01 00:00:00	\N	ACTIF	Union de l'Europe occidentale	Assemblée de l'Union de l'Europe occidentale	Assemblée de l'Union de l'Europe occidentale	\N	de l'	\N	\N	19
DELCONEUR	1900-01-01 00:00:00	2011-06-30 00:00:00	ACTIF	Déléga. fra. Ass. parl. Conseil de l'Europe	Délégation française aux Assemblées parlementaires du Conseil de l'Europe et de l'Union de l'Europe occidentale	Délégation française aux Assemblées parlementaires du Conseil de l'Europe et de l'Union de l'Europe occidentale	\N	de la 	\N	\N	20
PROS	2009-04-07 00:00:00	\N	ACTIF	Délégation sénatoriale à la prospective	Délégation sénatoriale à la prospective	Délégation sénatoriale à la prospective	\N	de la 	\N	\N	21
COLTER	2009-04-07 00:00:00	\N	ACTIF	Collectivités territoriales	Délégation sénatoriale aux collectivités territoriales et à la décentralisation	Délégation sénatoriale aux collectivités territoriales et à la décentralisation	\N	de la 	\N	2017-06-02 11:50:35	22
DELCONEUR	2011-07-01 00:00:00	\N	ACTIF	Déléga. fra. Ass. parl. Conseil de l'Europe	Délégation française à l'Assemblée parlementaire du Conseil de l'Europe	Délégation française à l'Assemblée parlementaire du Conseil de l'Europe	\N	de la 	\N	\N	23
DSOM	2011-11-30 00:00:00	\N	ACTIF	Outre-mer	Délégation sénatoriale aux outre-mer	Délégation sénatoriale aux outre-mer	\N	de la 	\N	2017-06-01 14:48:12	24
APM	2005-01-01 00:00:00	\N	ACTIF	Ass. parl. de la Méditerranée	Assemblée parlementaire de la Méditerranée	Assemblée parlementaire de la Méditerranée	\N	de l'	2015-08-25 14:05:26	\N	102
ACMN	2002-11-28 00:00:00	2020-10-27 00:00:00	ANCIEN	Ass. consult. de la Mer Noire	Assemblée consultative de la Mer Noire	Assemblée consultative de la Mer Noire	\N	de l'	2015-08-25 14:05:29	\N	103
APUPM	2010-01-01 00:00:00	\N	ACTIF	Ass. parl. de l'Union pour la Méditerranée	Assemblée parlementaire de l'Union pour la Méditerranée	Assemblée parlementaire de l'Union pour la Méditerranée	\N	de l'	2015-08-25 14:05:33	\N	104
ENTREPRISES	2014-11-26 00:00:00	\N	ACTIF	Délégation sénatoriale aux entreprises	Délégation sénatoriale aux entreprises	Délégation sénatoriale aux entreprises	\N	de la	2014-11-26 13:16:03	2014-11-26 13:19:46	61
COSAC	1989-01-01 00:00:00	\N	ACTIF	COSAC	Conférence des organes spécialisés dans les affaires communautaires	Conférence des organes spécialisés dans les affaires communautaires	\N	de la 	2015-09-22 18:27:06	2015-09-22 18:28:17	123
COSAC	2015-09-22 00:00:00	\N	ACTIF	COSAC	Conférence des organes spécialisés dans les affaires communautaires	Conférence des organes spécialisés dans les affaires communautaires	\N	de la 	2015-09-22 18:28:02	\N	125
CVFS	2002-01-01 00:00:00	\N	ACTIF	Commission de vérification des fonds spéciaux	Commission de vérification des fonds spéciaux	Commission de vérification des fonds spéciaux	\N	de la 	\N	\N	141
ACMN	2020-10-28 00:00:00	\N	ACTIF	Ass. parlem. de la Mer noire	Assemblée parlementaire de la coopération économique de la Mer noire	Assemblée parlementaire de la coopération économique de la Mer noire	\N	de l'	\N	\N	161
\.


--
-- Data for Name: libgrppol; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY libgrppol (grppolcod, libgrppoldatdeb, libgrppoldatfin, temvalcod, evelic, evelib, evelil, eveobs, libgrppolart, libgrppolcodameli, syscredat, sysmajdat, libgrppolid) FROM stdin;
UC	2008-10-02 00:00:00	2011-09-30 00:00:00	\N	UC	Groupe UC	Groupe Union centriste	\N	du	UC	\N	\N	1
CRC	1899-12-31 00:50:39	2008-11-27 00:00:00	\N	Communiste républicain citoyen et écologiste	Groupe CRCE	Groupe communiste républicain citoyen et écologiste	\N	du	CRCE	\N	2017-10-03 16:48:10	2
NI	1899-12-31 00:50:39	\N	\N	NI	Réunion administrative des non-inscrits	Réunion administrative des Sénateurs ne figurant sur la liste d'aucun groupe	\N	de la	NI	\N	2017-06-29 10:05:29	3
RDSE	1899-12-31 00:00:00	\N	ACTIF	RDSE	Groupe du RDSE	Groupe du Rassemblement Démocratique et Social Européen	\N	du	RDSE	2023-10-11 16:00:23	2023-10-11 00:00:00	4
RI	1900-01-01 00:00:00	2002-12-10 00:00:00	\N	RI	Groupe des RI	Groupe des Républicains et Indépendants	\N	du	RI	\N	\N	5
RPR	1900-01-01 00:00:00	2002-12-10 00:00:00	\N	RPR	Groupe du RPR	Groupe du Rassemblement pour la République	\N	du	RPR	\N	\N	6
SOC	2020-10-05 00:00:00	\N	ACTIF	SER	Groupe Socialiste, Écologiste et Républicain	Groupe Socialiste, Écologiste et Républicain	\N	du	SOC	\N	\N	261
UC	1899-12-31 00:50:39	2005-01-13 00:00:00	\N	UC	Groupe Union Centriste	Groupe Union Centriste	\N	du	UC	\N	2017-07-05 10:13:38	8
AUCUN	1899-12-31 00:50:39	\N	\N	Aucun	Sénateurs n'appartenant à aucun groupe	Nouveaux Sénateurs	\N	de la	AUCUN	\N	\N	9
UMP	2002-12-11 00:00:00	2015-06-01 00:00:00	ANCIEN	UMP	Groupe UMP	Groupe Union pour un Mouvement Populaire	\N	du	UMP	\N	2017-11-03 11:49:17	10
C	1900-01-01 00:00:00	1995-10-01 00:00:00	\N	C	Communistes	Groupe Communiste	\N	du	C	\N	\N	11
CNIP	1900-01-01 00:00:00	1980-10-01 00:00:00	\N	C.N.I.P.	Centre National des Indépendants et Paysans	Groupe du Centre National des Indépendants et Paysans	\N	du	C.N.I.P.	\N	\N	12
CRARS	1900-01-01 00:00:00	1980-10-01 00:00:00	\N	CRARS	Centre Républicain d'Action Rurale et Sociale	Groupe du Centre Républicain d'Action Rurale et Sociale	\N	du	CRARS	\N	\N	13
FCD	1900-01-01 00:00:00	1968-10-01 00:00:00	\N	FCD	Formation Centre Démocratique (rattaché R.P.)	Groupe de la Formation Centre Démocratique (rattaché R.P.)	\N	du	FCD	\N	\N	14
GD	1900-01-01 00:00:00	1989-10-01 00:00:00	\N	G.D.	Gauche Démocratique	Groupe de la Gauche Démocratique	\N	du	G.D.	\N	\N	15
GDSRG	1900-01-01 00:00:00	1986-10-01 00:00:00	\N	G.D.S.R.G.	Formation des Sénateurs Radicaux de Gauche	Formation des Sénateurs Radicaux de Gauche rattachée administrativement au groupe de la Gauche Démocratique	\N	de la	G.D.S.R.G.	\N	\N	16
MRP	1900-01-01 00:00:00	1959-04-29 00:00:00	\N	MRP	Mouvement Républicain Populaire	Groupe du Mouvement Républicain Populaire	\N	du	MRP	\N	\N	17
RDE	1899-12-31 00:50:39	1995-10-02 00:00:00	\N	R.D.E.	Rassemblement Démocratique et Européen	Groupe du Rassemblement Démocratique et Européen	\N	du	R.D.E.	\N	\N	18
RIAS	1900-01-01 00:00:00	1980-10-01 00:00:00	\N	R.I.A.S.	Républicains Indépendants d'Action Sociale (Devenu C.N.I.P.)	Groupe des Républicains Indépendants d'Action Sociale	\N	du	R.I.A.S.	\N	\N	19
RP	1900-01-01 00:00:00	1968-10-01 00:00:00	\N	RP	Républicains Populaires	Groupe des Républicains Populaires	\N	du	RP	\N	\N	20
RPCD	1900-01-01 00:00:00	1974-10-01 00:00:00	\N	RPCD	Républicains Populaires et du Centre Démocratique	Groupe des Républicains Populaires et du Centre Démocratique	\N	du	RPCD	\N	\N	21
UCDP	1900-01-01 00:00:00	1986-10-01 00:00:00	\N	U.C.D.P.	Union Centriste des Démocrates de Progrès	Groupe de l'Union Centriste des Démocrates de Progrès	\N	du	U.C.D.P.	\N	\N	22
UDR	1900-01-01 00:00:00	1977-10-01 00:00:00	\N	U.D.R.	Union des Démocrates pour la République	Groupe de l'Union des Démocrates pour la République	\N	du	U.D.R.	\N	\N	23
UNR	1900-01-01 00:00:00	1968-10-01 00:00:00	\N	U.N.R.	Union pour la Nouvelle République	Groupe de l'Union pour la Nouvelle République	\N	du	U.N.R.	\N	\N	24
UREI	1900-01-01 00:00:00	2004-10-01 00:00:00	\N	U.R.E.I.	Union des Républicains et des Indépendants	Groupe de l'Union des Républicains et des Indépendants	\N	du	U.R.E.I.	\N	\N	25
UC	2005-01-14 00:00:00	2008-10-01 00:00:00	ANCIEN	UC	Groupe Union centriste	Groupe Union Centriste	\N	du	UC	\N	2017-07-04 10:59:59	26
CRC	2008-11-28 00:00:00	2011-09-30 00:00:00	\N	CRC-SPG	Groupe CRC-SPG	Groupe Communiste, Républicain, Citoyen et des Sénateurs du Parti de Gauche	\N	du	CRC-SPG	\N	\N	27
SOC	2011-10-01 00:00:00	2012-01-10 00:00:00	ANCIEN	SOC-EELVr	Groupe Socialiste, Apparentés et Groupe Europe Écologie	Groupe Socialiste, Apparentés et Groupe Europe Écologie Les Verts rattaché	\N	du	SOC-EELVr	\N	\N	28
UC	2011-10-01 00:00:00	2012-10-22 00:00:00	\N	UCR	Groupe UCR	Groupe de l'Union Centriste et Républicaine	\N	du	UCR	\N	\N	29
ECO	2012-01-11 00:00:00	2015-07-08 00:00:00	ANCIEN	ECOLO	Groupe écologiste	Groupe écologiste	\N	du 	ECOLO	\N	2015-07-09 15:25:01	30
CRC	2011-10-01 00:00:00	2015-07-08 00:00:00	ANCIEN	CRCE	Groupe CRCE	Groupe communiste républicain citoyen et écologiste	\N	du	CRCE	\N	2017-10-04 09:43:43	31
UC	2012-10-23 00:00:00	2017-07-03 00:00:00	ANCIEN	UDI-UC	Groupe UDI - UC	Groupe Union des Démocrates et Indépendants - UC	\N	du 	UDI-UC	\N	2017-07-04 10:56:52	32
RTLI	2020-10-05 00:00:00	2021-04-26 00:00:00	ANCIEN	INDEP	Groupe Les Indépendants - République et Territoires	Groupe Les Indépendants - République et Territoires	\N	du	RTLI	\N	\N	262
SOC	2015-06-11 00:00:00	2015-07-08 00:00:00	ANCIEN	SOC	Groupe socialiste et républicain	Groupe socialiste et républicain	\N	du	SOC	2015-06-11 09:52:33	2017-11-03 11:42:34	121
LREM	2020-10-05 00:00:00	\N	ACTIF	RDPI	Groupe Rassemblement des démocrates, progressistes et indépendants	Groupe Rassemblement des démocrates, progressistes et indépendants	\N	du	LaREM	\N	\N	263
GEST	2020-10-05 00:00:00	\N	ACTIF	GEST	Groupe Écologiste - Solidarité et Territoires	Groupe Écologiste - Solidarité et Territoires	\N	du	GEST	2023-10-11 16:04:02	2023-10-11 00:00:00	264
RTLI	2021-04-27 00:00:00	\N	ACTIF	Les Indépendants	Groupe Les Indépendants - République et Territoires	Groupe Les Indépendants - République et Territoires	\N	du	RTLI	\N	\N	301
CRC	2023-10-03 00:00:00	\N	ACTIF	CRCE-K	Groupe CRCE - Kanaky	Groupe Communiste Républicain Citoyen et Écologiste - Kanaky	\N	du	CRCE	2023-10-11 16:01:25	2023-10-11 00:00:00	321
SOC	1900-01-01 00:50:39	2011-09-30 00:00:00	ANCIEN	SOC	Groupe socialiste	Groupe socialiste	\N	du	SOC	2014-09-04 16:04:06	2015-07-09 16:27:01	41
SOC	2015-07-09 00:00:00	2020-10-04 00:00:00	ANCIEN	SOCR	Groupe socialiste et républicain	Groupe socialiste et républicain	\N	du	SOC	2015-07-09 15:24:16	2017-10-04 09:46:28	161
ECO	2015-07-09 00:00:00	2017-06-29 00:00:00	ACTIF	Écologiste	Groupe écologiste	Groupe écologiste	\N	du 	ECOLO	2015-07-09 15:25:01	2017-06-30 09:52:10	162
CRC	2015-07-09 00:00:00	2017-10-02 00:00:00	ANCIEN	Communiste républicain et citoyen	Groupe CRC	Groupe communiste républicain et citoyen	\N	du	CRC	2015-07-09 15:25:19	2017-10-03 16:47:12	163
CRC	2017-10-03 00:00:00	2023-10-02 00:00:00	ANCIEN	CRCE	Groupe CRCE	Groupe communiste républicain citoyen et écologiste	\N	du	CRCE	2017-10-03 00:00:00	2023-10-03 00:00:00	221
RTLI	2017-10-03 00:00:00	2017-10-24 00:00:00	ANCIEN	Les Indépendants	Groupe Les Indépendants - République et Territoires	Groupe Les Indépendants - République et Territoires	\N	du	RTLI	2017-10-03 16:49:27	2017-10-26 17:42:09	222
UC	2017-07-04 00:00:00	\N	ACTIF	UC	Groupe Union Centriste	Groupe Union Centriste	\N	du 	UC	2017-07-04 10:56:52	2017-07-05 10:14:13	201
SOC	2012-01-11 00:00:00	2015-06-10 00:00:00	ANCIEN	SOCR	Groupe socialiste et apparentés	Groupe socialiste et apparentés	\N	du	SOC	2015-07-01 18:41:56	2017-11-03 11:39:11	141
UMP	2015-06-02 00:00:00	\N	ACTIF	Les Républicains	Groupe Les Républicains	Groupe Les Républicains	\N	du	REPUBLICAINS	2015-06-02 13:50:47	2017-11-03 11:49:30	81
LREM	2017-06-28 00:00:00	2020-10-04 00:00:00	ANCIEN	LaREM	La République En Marche	La République En Marche	\N	de	LaREM	2017-06-29 09:48:06	2017-10-04 09:45:00	181
RTLI	2017-10-25 00:00:00	2020-10-04 00:00:00	ANCIEN	Les Indépendants	Groupe Les Indépendants - République et Territoires	Groupe Les Indépendants - République et Territoires	\N	du	RTLI	2023-10-11 16:10:03	2023-10-11 00:00:00	241
\.


--
-- Data for Name: libgrpsen; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY libgrpsen (orgcod, libgrpsendatautbur, libgrpsendatfin, libgrpsenlib, libgrpsenlic, libgrpsenlil, syscredat, sysmajdat, libgrpsenid, libgrpsenart) FROM stdin;
576	1951-01-01 00:00:00	1996-06-18 00:00:00	GR AMITIE FRANCE-AMERIQUE-LATINE                            	AMERIQUE-LATINE	GR AMITIE FRANCE-AMERIQUE-LATINE	\N	\N	57	du
577	1991-01-01 00:00:00	\N	France-Cambodge et Laos	Cambodge et Laos	FRANCE-CAMBODGE ET LAOS	\N	\N	58	du
578	1980-01-01 00:00:00	\N	France-Australie	Australie	FRANCE-AUSTRALIE	\N	\N	59	du
579	1957-01-01 00:00:00	\N	France-Autriche	Autriche	FRANCE-AUTRICHE	\N	\N	60	du
580	1997-01-01 00:00:00	\N	France-Belgique et Luxembourg	Belgique et Luxembourg	FRANCE-BELGIQUE et LUXEMBOURG	\N	\N	61	du
581	1947-07-08 00:00:00	\N	France-Royaume-Uni	Royaume-Uni	FRANCE-ROYAUME-UNI	\N	\N	62	du
582	1960-01-01 00:00:00	\N	France-Bulgarie	Bulgarie	FRANCE-BULGARIE	\N	\N	63	du
583	1951-01-01 00:00:00	\N	France-Canada	Canada	FRANCE-CANADA	\N	\N	64	du
584	1971-12-09 00:00:00	\N	France-République populaire de Chine	Chine	FRANCE-REPUBLIQUE POPULAIRE DE CHINE	\N	\N	65	du
585	1978-01-01 00:00:00	\N	France-Chypre	Chypre	FRANCE-CHYPRE	\N	\N	66	du
586	1974-12-10 00:00:00	\N	Groupe d'études et de contact France-République populaire démocratique de Corée	Corée du Nord	Groupe d'études et de contact FRANCE-RÉPUBLIQUE POPULAIRE DÉMOCRATIQUE DE CORÉE	\N	\N	67	du
587	1981-07-22 00:00:00	1996-06-18 00:00:00	France-Cuba	Cuba	FRANCE-CUBA	\N	\N	68	du
588	1996-01-01 00:00:00	2007-10-31 00:00:00	France-Djibouti et Corne de l'Afrique	Djibouti	FRANCE-DJIBOUTI ET CORNE DE L'AFRIQUE (Djibouti, Ethiopie, Erythrée, Somalie)	\N	\N	69	du
589	1950-01-01 00:00:00	\N	France-Espagne	Espagne	FRANCE-ESPAGNE	\N	\N	70	du
590	1947-05-30 00:00:00	\N	France-Etats-Unis	Etats-Unis	FRANCE-ETATS-UNIS	\N	\N	71	du
591	1961-05-10 00:00:00	\N	France-Grèce	Grèce	FRANCE-GRECE	\N	\N	72	du
592	1975-12-02 00:00:00	\N	France-Hongrie	Hongrie	FRANCE-HONGRIE	\N	\N	73	du
593	1977-12-22 00:00:00	1996-06-01 00:00:00	France-Ile Maurice	Ile Maurice	FRANCE-ILE MAURICE	\N	\N	74	du
594	1988-06-16 00:00:00	\N	France-Irlande	Irlande	FRANCE-IRLANDE	\N	\N	75	du
595	1960-12-13 00:00:00	\N	France-Israël	Israël	FRANCE-ISRAEL	\N	\N	76	du
596	1960-12-30 00:00:00	\N	France-Japon	Japon	FRANCE-JAPON	\N	\N	77	du
597	1965-04-22 00:00:00	\N	France-Liban	Liban	FRANCE-LIBAN	\N	\N	78	du
598	1963-05-31 00:00:00	\N	France-Maroc	Maroc	FRANCE-MAROC	\N	\N	79	du
599	1949-01-01 00:00:00	\N	France-Pays-Bas	Pays-Bas	FRANCE-PAYS-BAS	\N	\N	80	du
600	1956-01-01 00:00:00	\N	France-Pologne	Pologne	FRANCE-POLOGNE	\N	\N	81	du
601	1978-10-03 00:00:00	\N	France-Portugal	Portugal	FRANCE-PORTUGAL	\N	\N	82	du
602	1973-06-21 00:00:00	\N	France-Québec	Québec	FRANCE-QUÉBEC	\N	\N	83	du
603	1993-06-08 00:00:00	\N	France-Malte	Malte	FRANCE-MALTE	\N	\N	84	du
604	1961-01-01 00:00:00	\N	France-Allemagne	Allemagne	FRANCE-ALLEMAGNE	\N	\N	85	du
605	1961-01-01 00:00:00	\N	France-Roumanie	Roumanie	FRANCE-ROUMANIE	\N	\N	86	du
606	1977-11-08 00:00:00	1999-01-01 00:00:00	France-Sénégal	Sénégal	FRANCE-SENEGAL	\N	\N	87	du
607	1978-04-05 00:00:00	2003-06-17 00:00:00	France-Soudan	Soudan	FRANCE-SOUDAN	\N	\N	88	du
608	1955-06-26 00:00:00	\N	France-Russie	Russie	FRANCE-RUSSIE	\N	\N	89	du
609	1979-12-19 00:00:00	\N	France-Asie du Sud-Est	Asie du Sud-Est	FRANCE-ASIE DU SUD-EST (Bangladesh, Birmanie, Brunei, Malaisie, Philippines, Singapour, Thaïlande)	\N	\N	90	du
610	1978-11-29 00:00:00	\N	France-Suisse	Suisse	FRANCE-SUISSE	\N	\N	91	du
611	1957-06-21 00:00:00	\N	France-République Tchèque	Tchéquie	FRANCE-RÉPUBLIQUE TCHÈQUE	\N	\N	92	du
612	1982-06-03 00:00:00	\N	France-Mongolie	Mongolie	FRANCE-MONGOLIE	\N	\N	93	du
613	1976-12-04 00:00:00	\N	France-Corée du Sud	Corée du Sud	FRANCE-COREE DU SUD	\N	\N	94	du
614	1990-07-04 00:00:00	1998-06-02 00:00:00	France-Grand Duché du Luxembourg	Luxembourg	FRANCE-GRAND DUCHÉ DU LUXEMBOURG	\N	\N	95	du
615	1983-01-01 00:00:00	\N	France-Irak	Irak	FRANCE-IRAK	\N	\N	96	du
616	1991-11-13 00:00:00	\N	France-Pays Baltes	Pays Baltes	FRANCE-PAYS BALTES (Estonie, Lettonie, Lituanie)	\N	\N	97	du
617	1956-01-01 00:00:00	\N	France-Egypte	Egypte	FRANCE-EGYPTE	\N	\N	98	du
618	1985-05-29 00:00:00	\N	France-Inde	Inde	FRANCE-INDE	\N	\N	99	du
619	1984-12-20 00:00:00	\N	France-Pakistan	Pakistan	FRANCE-PAKISTAN	\N	\N	100	du
620	1997-01-01 00:00:00	\N	France-Tunisie	Tunisie	FRANCE-TUNISIE	\N	\N	101	du
621	1950-06-26 00:00:00	\N	France-Italie	Italie	FRANCE-ITALIE	\N	\N	102	du
588	2007-11-01 00:00:00	\N	France-Pays de la Corne de l'Afrique	Pays de la Corne de l'Afrique	FRANCE-PAYS DE LA CORNE DE L'AFRIQUE (Djibouti, Erythrée, Ethiopie, Somalie, Soudan)	\N	\N	103	du
661	2007-11-01 00:00:00	2015-04-29 00:00:00	France-Arabie saoudite-Pays du Golfe	Arabie saoudite-Pays du Golfe	FRANCE-ARABIE SAOUDITE-PAYS DU GOLFE (Arabie saoudite, Bahreïn, Emirats Arabes Unis, Koweït, Oman, Qatar)	\N	2015-04-30 14:52:28	104	du
576	2008-12-17 00:00:00	\N	France-Brésil	Brésil	FRANCE-BRESIL (Guyana, Suriname)	\N	\N	105	du
653	2009-05-20 00:00:00	\N	France-Indonésie et Timor-Est	Indonésie et Timor-Est	FRANCE-INDONÉSIE ET TIMOR-EST	\N	\N	106	du
632	2013-02-27 00:00:00	\N	France-Palestine	Palestine	FRANCE-PALESTINE	\N	\N	107	du
622	1985-12-18 00:00:00	\N	France-Madagascar et pays de l'Océan indien	Madagascar	FRANCE-MADAGASCAR ET PAYS DE L'OCÉAN INDIEN (Comores, Kenya, Madagascar, Maldives, Ile Maurice, Mozambique, Seychelles, Tanzanie)	\N	\N	1	du
623	1984-11-20 00:00:00	\N	Groupe d'échanges et d'études Sénat-Taïwan	Taïwan	Groupe d'échanges et d'études SÉNAT-TAÏWAN	\N	\N	2	du
624	1987-04-15 00:00:00	\N	France-Turquie	Turquie	FRANCE-TURQUIE	\N	\N	3	du
625	1989-01-01 00:00:00	\N	France-Europe du Nord	Europe du Nord	FRANCE-EUROPE DU NORD  (Danemark, Islande, Norvège, Suède)	\N	\N	4	du
626	1989-06-15 00:00:00	\N	France-Vietnam	Vietnam	FRANCE-VIETNAM	\N	\N	5	du
627	1992-01-01 00:00:00	\N	France-Yémen	Yémen	FRANCE-YÉMEN	\N	\N	6	du
632	1995-11-08 00:00:00	2013-02-26 00:00:00	Groupe d'Information France-Palestine	Territoires palestiniens	Groupe d'information et de contacts sur les relations FRANCO-PALESTINIENNES	\N	\N	7	du
550	2014-10-07 00:00:00	\N	France-Sri Lanka	Sri Lanka	FRANCE-SRI LANKA	2014-10-07 10:45:32	2014-10-07 10:47:00	121	\N
571	1992-04-29 00:00:00	\N	France-Albanie	Albanie	FRANCE-ALBANIE	\N	\N	52	du
661	2015-04-17 00:00:00	2015-04-19 00:00:00	France-Pays du Golfe	Pays du Golfe	FRANCE-ARABIE SAOUDITE-PAYS DU GOLFE (Arabie saoudite, Bahreïn, Emirats Arabes Unis, Koweït, Oman, Qatar)	2015-04-17 18:36:22	2015-04-20 10:18:54	141	du
661	2015-04-20 00:00:00	\N	France-Pays du Golfe	Pays du Golfe	FRANCE-PAYS DU GOLFE (Arabie saoudite, Bahreïn, Emirats Arabes Unis, Koweït, Oman, Qatar)	2015-04-20 10:18:54	\N	161	du
661	2015-04-30 00:00:00	\N	France-Pays du Golfe	Pays du Golfe	FRANCE-PAYS DU GOLFE (Arabie saoudite, Bahreïn, Emirats Arabes Unis, Koweït, Oman, Qatar)	2015-04-30 14:52:28	\N	181	du
628	2015-10-20 00:00:00	\N	France-Iran	Iran	FRANCE-IRAN	2015-10-20 14:45:00	\N	201	\N
CHRETORIENT	2015-06-04 00:00:00	\N	Chrétiens d'Orient	Chrétiens d'Orient	Chrétiens d'Orient, minorités au Moyen-Orient et Kurdes	2016-02-11 18:00:21	2016-02-11 18:01:58	221	\N
852	2018-01-30 00:00:00	\N	France-Biélorussie	Biélorussie	FRANCE-BIÉLORUSSIE	2018-01-30 10:14:38	2018-01-30 10:15:53	241	\N
574	1953-03-10 00:00:00	2018-12-31 00:00:00	France-Afrique du Sud	Afrique du Sud	FRANCE-AFRIQUE DU SUD (Lesotho, Swaziland)	\N	\N	261	du
1013	2021-12-15 00:00:00	\N	Groupe d'information internationale sur le Haut-Karabagh	Haut-Karabagh	Groupe d'information internationale sur le Haut-Karabagh	\N	\N	284	du
640	1995-11-08 00:00:00	\N	France-Finlande	Finlande	FRANCE-FINLANDE	\N	\N	8	du
641	1996-01-24 00:00:00	\N	France-Arménie	Arménie	FRANCE-ARMENIE	\N	\N	9	du
642	1996-06-19 00:00:00	\N	France-Caraïbes	Caraïbes	FRANCE-CARAÏBES (Anguilla, Antigua-et-Barbuda, Bahamas, Barbade, Cuba, Dominique, Haïti, Jamaïque, République dominicaine, Saint-Kitts-et-Nevis, Sainte-Lucie, Trinité-et-Tobago)	\N	\N	10	du
643	1996-06-19 00:00:00	\N	France-Mexique-Pays d'Amérique centrale	Mexique-Pays d'Am. Centrale	FRANCE-MEXIQUE et PAYS D'AMÉRIQUE CENTRALE  (Mexique, Belize, Costa Rica, El Salvador, Guatemala, Honduras, Nicaragua, Panama)	\N	\N	11	du
644	1996-11-26 00:00:00	\N	France-Syrie	Syrie	FRANCE-SYRIE	\N	\N	12	du
646	1996-06-19 00:00:00	\N	France-Afrique australe	Afrique australe	FRANCE-AFRIQUE AUSTRALE (Angola, Botswana, Malawi, Namibie, Zambie, Zimbabwe)	\N	\N	13	du
659	1997-01-21 00:00:00	\N	France-Jordanie	Jordanie	FRANCE-JORDANIE	\N	\N	14	du
661	1997-01-21 00:00:00	2007-10-31 00:00:00	France-Pays du Golfe	Pays du Golfe	FRANCE-PAYS DU GOLFE (Arabie saoudite, Bahreïn, Emirats Arabes Unis, Koweït, Qatar)	\N	\N	15	du
663	1992-01-01 00:00:00	\N	France-Nouvelle-Zélande	Nouvelle-Zélande	FRANCE-NOUVELLE-ZÉLANDE	\N	\N	16	du
851	1993-03-09 00:00:00	\N	France-Moldavie	Moldavie	FRANCE-MOLDAVIE	\N	\N	17	du
6251	1900-01-01 00:00:00	2014-09-30 00:00:00	Suède	Suède	SUEDE	\N	2014-11-03 15:12:47	18	du
6252	1900-01-01 00:00:00	2014-09-30 00:00:00	Norvège	Norvège	NORVEGE	\N	2014-11-03 15:12:47	19	du
6253	1900-01-01 00:00:00	2014-09-30 00:00:00	Danemark	Danemark	DANEMARK	\N	2014-11-03 15:12:47	20	du
6254	1900-01-01 00:00:00	2014-09-30 00:00:00	Islande	Islande	ISLANDE	\N	2014-11-03 15:12:47	21	du
651	1996-06-19 00:00:00	2023-10-01 00:00:00	France-Vanuatu-Iles du Pacifique	Vanuatu	FRANCE-VANUATU-ILES DU PACIFIQUE (Iles Cook, Iles Fidji, Kiribati, Mariannes du Nord, Iles Marshall, Micronésie, Nauru, Iles Niué, Palaos, Papouasie-Nouvelle Guinée, Pitcairn, Iles Salomon, Samoa occidentales, Tokelau, Tonga, Tuvalu)	\N	\N	22	\N
628	1998-04-22 00:00:00	\N	France-Iran	Iran	FRANCE-IRAN	\N	\N	23	\N
657	1997-01-21 00:00:00	\N	France-Libye	Libye	FRANCE-LIBYE	\N	\N	24	\N
629	1998-12-15 00:00:00	\N	France-Saint-Siège	Saint-Siège	FRANCE-SAINT-SIÈGE	\N	\N	25	\N
6431	1996-01-01 00:00:00	2014-09-30 00:00:00	France-Mexique	Mexique	FRANCE-MEXIQUE	\N	2014-11-03 15:12:47	26	\N
6432	1996-01-01 00:00:00	2014-09-30 00:00:00	France-Amérique Centrale	Amérique Centrale	FRANCE-AMERIQUE CENTRALE (Guatemala, Salvador, Belize, Honduras, Nicaragua, Costa Rica, Panama)	\N	2014-11-03 15:12:47	27	\N
576	1996-06-19 00:00:00	2008-12-16 00:00:00	France-Amérique du Sud	Amérique du Sud	FRANCE-AMERIQUE DU SUD (Argentine, Bolivie, Brésil, Chili, Colombie, Equateur, Guyana, Paraguay, Pérou, Surinam, Uruguay, Venezuela)	\N	\N	28	du
633	2000-03-21 00:00:00	\N	France-Népal	Népal	FRANCE-NÉPAL	\N	\N	29	du
643	1951-01-01 00:00:00	1996-06-18 00:00:00	France-Amérique latine	Amérique latine	France-Amérique latine	\N	\N	30	du
642	1951-11-21 00:00:00	1996-06-18 00:00:00	Amérique latine	Amérique latine	Amérique latine	\N	\N	31	du
634	2000-03-21 00:00:00	\N	Groupe d'information internationale sur le TIBET	Tibet	Groupe d'information internationale sur le TIBET	\N	\N	32	du
587	1996-06-19 00:00:00	1998-09-30 00:00:00	France-Caraïbes	Caraïbes	FRANCE-CARAÏBES (Anguilla, Antigua et Barbuda, Bahamas, Barbade, Cuba, Dominique, Haïti, Jamaïque, Saint-Domingue, Sainte-Lucie, Trinité et Tobago)	\N	\N	33	du
606	1999-01-02 00:00:00	2014-09-30 00:00:00	France-Afrique de l'Ouest	Afrique de l'Ouest	France-Afrique de l'Ouest	\N	2014-11-03 15:12:47	34	du
647	1998-07-08 00:00:00	\N	France-Croatie	Croatie	FRANCE-CROATIE	\N	\N	35	du
648	2000-05-25 00:00:00	\N	France-Afghanistan	Afghanistan	FRANCE-AFGHANISTAN	\N	\N	36	du
662	2002-10-01 00:00:00	2007-02-14 00:00:00	France - Bosnie Herzégovine	Bosnie Herzégovine	FRANCE - BOSNIE HERZEGOVINE	\N	\N	37	du
670	2003-06-30 00:00:00	2007-02-14 00:00:00	France- Serbie	Serbie	FRANCE-SERBIE	\N	2014-11-03 15:12:47	38	du
963	2005-11-01 00:00:00	\N	France-Andorre	Andorre	FRANCE-ANDORRE	\N	\N	39	du
673	2007-01-01 00:00:00	\N	France-Monaco	Monaco	FRANCE-MONACO	\N	\N	40	du
978	2008-12-17 00:00:00	\N	France-Pays du Cône Sud	Pays du Cône Sud	FRANCE-PAYS DU CÔNE SUD (Argentine, Chili, Paraguay, Uruguay)	\N	\N	41	du
979	2008-12-17 00:00:00	\N	France-Pays Andins	Pays Andins	FRANCE-PAYS ANDINS (Bolivie, Colombie, Equateur, Pérou, Venezuela )	\N	\N	42	du
674	2006-02-01 00:00:00	\N	France-Balkans Occidentaux	Balkans Occidentaux	FRANCE-BALKANS OCCIDENTAUX	\N	\N	44	du
528	1994-05-17 00:00:00	2007-02-14 00:00:00	France-République de Macédoine	Macédoine	FRANCE-RÉPUBLIQUE DE MACÉDOINE	\N	2014-11-03 15:12:47	45	du
529	1994-06-14 00:00:00	\N	France-Slovénie	Slovénie	FRANCE-SLOVÉNIE	\N	\N	46	du
530	1992-11-03 00:00:00	\N	France-Ukraine	Ukraine	FRANCE-UKRAINE	\N	\N	47	du
532	1993-06-08 00:00:00	\N	France-République slovaque	Slovaquie	FRANCE-RÉPUBLIQUE SLOVAQUE	\N	\N	48	du
534	1993-01-01 00:00:00	\N	France-Caucase	Caucase	FRANCE-CAUCASE  (Azerbaïdjan, Géorgie)	\N	\N	49	du
535	1993-03-09 00:00:00	2009-06-04 00:00:00	France-Koweït	Koweït	FRANCE-KOWEÏT	\N	\N	50	du
556	1992-01-01 00:00:00	\N	France-Asie Centrale	Asie Centrale	FRANCE-ASIE CENTRALE (Kazakhstan, Kirghizstan, Ouzbékistan, Tadjikistan, Turkménistan)	\N	\N	51	du
572	1980-01-01 00:00:00	\N	France-Afrique centrale	Afrique centrale	FRANCE-AFRIQUE CENTRALE (Burundi, Cameroun, Centrafrique, Congo, République démocratique du Congo, Gabon, Guinée équatoriale, Ouganda, Rwanda, Sao Tomé-et-Principe, Tchad)	\N	\N	53	du
573	1978-01-01 00:00:00	\N	France-Afrique de l'Ouest	Afrique de l'Ouest	FRANCE-AFRIQUE DE L'OUEST (Bénin, Burkina Faso, Cap-Vert, Côte d'Ivoire, Gambie, Ghana, Guinée, Guinée-Bissau, Liberia, Mali, Mauritanie, Niger, Nigeria,  Sénégal, Sierra Leone, Togo)	\N	\N	54	du
574	2019-01-01 00:00:00	\N	France-Afrique du Sud	Afrique du Sud	FRANCE-AFRIQUE DU SUD (Lesotho, Eswatini)	\N	\N	55	du
575	1963-01-01 00:00:00	\N	France-Algérie	Algérie	FRANCE-ALGERIE	\N	\N	56	du
\.


--
-- Data for Name: liborg; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY liborg (orgcod, liborgdatdeb, liborgdatfin, temvalcod, evelic, evelib, evelil, eveobs, liborgart, syscredat, sysmajdat, liborgid) FROM stdin;
CONCST	1899-12-31 00:50:39	2022-03-23 00:00:00	ACTIF	Conseil constitutionnel	Conseil constitutionnel	Conseil constitutionnel	\N	du	\N	\N	1
CES	1925-01-01 00:00:00	2008-07-22 00:00:00	ACTIF	Conseil Économique et Social	Conseil Économique et Social	Conseil Économique et Social	\N	du	\N	\N	2
DCRUE	1900-01-01 00:00:00	2022-10-17 00:00:00	ACTIF	Délégation au Comité des régions de l'UE	Délégation au Comité des régions de l'Union européenne	Délégation au Comité des régions de l'Union européenne	Délégation au Comité des régions de l'Union européenne	de la	\N	\N	3
BASMED	1900-01-01 00:00:00	\N	ACTIF	bassin méditerranéen	commission du bassin méditerranéen	commission du Bassin méditerranéen	\N	de la 	\N	\N	4
COMREGUE	1899-12-31 00:50:39	2022-10-17 00:00:00	ACTIF	Comité des régions de l'UE	Comité des régions de l'Union européenne	Comité des régions de l'Union européenne	\N	du 	\N	\N	5
CES	2008-07-23 00:00:00	2022-03-23 00:00:00	\N	Conseil économique, social et environnemental	Conseil économique, social et environnemental	Conseil économique, social et environnemental	\N	du 	\N	\N	6
MEDIATEUR	1900-01-01 00:00:00	2022-03-23 00:00:00	\N	institution du Médiateur de la République	institution du Médiateur de la République	institution du Médiateur de la République	\N	\N	\N	\N	7
APM	2014-01-30 00:00:00	2014-01-30 00:00:00	ACTIF	APM	APM	Assemblée parlementaire de la Méditerranée	\N	de la	2014-01-30 11:14:11	2014-01-30 11:14:32	21
\.


--
-- Data for Name: mel; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY mel (melid, poiconid, melema, melnumtri, syscredat, sysmajdat) FROM stdin;
28	830	a.billon-senat@orange.fr	1	2014-10-27 10:52:25	2015-09-16 18:17:28
42	871	maire@strasbourg.eu	1	2015-07-13 15:16:22	2015-07-13 15:16:36
46	874	chcointat@gmail.com	1	2015-07-13 15:30:50	2015-07-13 15:31:19
61	925	assistante.fgatel@gmail.com	1	2016-11-10 11:55:17	2016-11-10 11:55:25
45	873	raymondcouderc@orange.fr	1	2015-07-13 15:29:24	2015-07-13 15:29:53
62	935	permanence.botrel@orange.fr	1	2017-03-02 15:15:53	2017-03-02 15:18:07
133	1425	daniel.chasseing@laposte.net	1	\N	\N
97	1084	n.delattre@senat.fr	1	2018-01-30 16:04:20	2018-01-30 16:04:40
113	679	j.bizet@senat.fr	1	\N	\N
131	1416	c.redon-sarrazy@senat.fr	1	\N	\N
139	1312	mbonnus83@gmail.com	1	\N	\N
151	1522	o.richard@senat.fr	1	2023-12-04 00:00:00	\N
155	1526	jl.ruelle@senat.fr	1	2023-12-05 00:00:00	\N
22	812	demontes.christiane@orange.fr	1	2014-10-13 10:52:11	2014-10-13 10:52:15
38	863	y.rome@senat.fr	1	2015-06-30 13:06:32	2015-06-30 13:06:45
48	879	pa.bordas@wanadoo.fr	1	2015-07-13 15:36:16	2015-07-13 15:36:43
49	880	bernadette-bourzai@orange.fr	1	2015-07-13 15:39:22	2015-07-13 15:40:03
50	881	helenemasson@wanadoo.fr	1	2015-07-13 15:40:42	2015-07-13 15:41:06
51	882	jp.amoudry@syane.fr	1	2015-07-13 15:43:03	2015-07-13 15:43:22
52	884	bourdin.joel@wanadoo.fr	1	2015-07-13 15:45:24	2015-07-13 15:45:42
141	1500	d.bouad@senat.fr	1	\N	\N
106	1223	mc.chauvin.39@gmail.com	1	2018-06-11 09:36:48	2018-06-11 09:37:14
74	1147	jp.corbisez@senat.fr	2	2017-12-20 09:51:02	2017-12-20 09:51:18
68	1114	f.gerbaud@senatrice-indre.fr	1	2017-11-16 11:49:38	2017-11-16 11:49:43
75	723	cedric.perrin@senat.fr	1	2017-12-20 10:09:50	2017-12-20 10:10:02
73	1147	senateurcorbisez@gmail.com	1	2017-12-20 09:50:17	2017-12-20 09:50:44
76	730	m.raison@senat.fr	1	2017-12-20 10:10:43	2017-12-20 10:10:52
163	1545	o.bitz@senat.fr	1	2024-02-19 00:00:00	\N
124	1399	p.ellul@clb.senat.fr	1	\N	\N
120	1315	c.redon-sarrazy@senat.fr	1	\N	\N
125	1391	p.ellul@clb.senat.fr	1	\N	\N
127	923	contact@gerard-longuet.fr	1	\N	\N
128	389	contact@gerard-longuet.fr	1	\N	\N
129	1377	ma.evrard@senat.fr	1	\N	\N
29	831	secretariat-senateur-todeschini@wanadoo.fr	1	2014-10-27 16:00:21	2014-10-27 16:00:35
36	861	yves.detraigne@orange.fr	1	2015-06-30 10:20:36	2015-06-30 10:20:47
39	373	d.raoul@senat.fr	1	2015-06-30 16:34:41	2015-06-30 16:35:13
56	913	jjlozach@jjlozach.fr	1	2015-12-21 17:55:36	2015-12-21 17:55:50
66	845	l.herve@senat.fr	1	2017-10-10 18:40:59	2017-10-10 18:41:19
96	1195	permanence.cazeau@gmail.com	1	2018-01-29 14:03:38	2018-01-29 14:04:15
153	1525	a.mellouli@senat.fr	1	2023-12-04 00:00:00	\N
109	1251	secretariat@sylvianenoel.fr	1	\N	\N
118	1369	 losomon@orange.fr	1	\N	\N
130	1415	s.vermeillet@gmail.com	1	\N	\N
23	824	r.mazuir@senat.fr	1	2014-10-23 14:42:51	2018-01-16 14:40:54
65	857	p.nom@senat.fr	2	2017-10-10 13:32:46	\N
25	826	louis.pinton@orange.fr	1	2014-10-23 17:14:50	2014-10-23 17:15:12
31	836	j.delpech@clb.senat.fr	1	2014-12-04 23:18:20	2014-12-04 23:18:47
34	844	permadufaut@orange.fr	1	2015-05-22 11:39:52	2015-05-22 11:40:01
35	857	alain.dufaut@orange.fr	1	2015-05-22 11:44:46	2015-05-22 11:45:03
121	1373	bureau.d.salmon@senat.fr	1	\N	\N
53	886	elisabeth.lamure@wanadoo.fr	1	2015-07-17 16:09:09	2015-07-17 16:09:32
102	1213	 e.perrot.permanence@orange.fr	1	2018-04-04 14:13:34	2018-04-04 14:13:46
94	1183	bernard.delcros@senateurcantal.fr	1	2018-01-08 19:06:17	2018-01-08 19:06:40
135	1451	permanence.olivierhenno@gmail.com	1	\N	\N
138	1463	senateurjbblanc@gmail.com	1	\N	\N
147	1518	jl.brault@senat.fr	1	\N	\N
156	1527	l.vogel@senat.fr	1	2023-12-05 00:00:00	\N
160	1542	laurianejosende@gmail.com	1	\N	\N
20	13	jm.bockel@senat.fr	1	2013-12-10 10:15:02	\N
21	14	l.lenner@clb.senat.fr	1	2013-12-10 10:15:02	\N
26	827	jeanpaul.emorine@wanadoo.fr	1	2014-10-24 16:39:49	2014-10-24 16:40:22
27	828	a.fisseau@clb.senat.fr	1	2014-10-24 16:44:23	2014-10-24 16:44:31
30	833	m.roby@clb.senat.fr	1	2014-11-03 11:40:03	2014-11-03 11:40:07
33	856	senateurclaudekern@gmail.com	1	2015-05-19 14:14:32	2015-05-19 14:14:49
37	862	senatricedeshautesalpes@gmail.com	1	2015-06-30 11:47:04	2015-06-30 11:47:22
67	376	y.detraigne@senat.fr	1	2017-10-25 11:13:28	2017-10-25 11:13:37
78	1155	e.levine@clb.senat.fr	1	2017-12-20 16:55:02	2017-12-20 16:55:18
79	500	r.vall@senat.fr	1	2017-12-20 16:59:31	2017-12-20 16:59:38
80	1157	gl.devinaz@senat.fr	1	2017-12-21 10:15:32	2017-12-21 10:15:53
86	1173	simon.sutour@orange.fr	1	2017-12-21 16:08:47	2017-12-21 16:09:03
99	1214	senateurcabanel@gmail.com	1	2018-03-14 16:43:05	2018-03-14 16:43:12
90	1179	jean.bizet@wanadoo.fr 	1	2017-12-22 11:20:54	2017-12-22 11:24:12
98	1185	nadia.sollogoub@gmail.com	1	2018-03-09 10:40:51	2018-03-09 10:41:16
103	1058	c.vigorie@clb.senat.fr	1	2018-04-09 12:25:41	2018-04-09 12:26:22
105	1112	benoit.hure@orange.fr	1	2018-06-05 10:26:28	2018-06-05 10:26:43
112	1171	j.costes@senat.fr	1	\N	\N
119	1370	 contact@philippe-folliot.fr	1	\N	\N
148	1510	s.nadille@senat.fr	1	2023-11-27 00:00:00	\N
152	1524	mc.carrere-gee@senat.fr	1	2023-12-04 00:00:00	\N
157	1528	j.hochart@senat.fr	1	\N	\N
161	1543	pa.roiron@senat.fr	1	2024-02-07 00:00:00	\N
\.


--
-- Data for Name: memcom; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY memcom (memcomid, orgcod, memcomdatdeb, memcomdatfin, temvalcod, evelic, evelib, evelil, eveobs, senmat, memcomtitsup, syscredat, sysmajdat) FROM stdin;
240	ECON	\N	2000-10-24 00:00:00	ANCIEN	\N	\N	\N	\N	95066P	\N	\N	\N
241	FINC	1998-10-06 00:00:00	2013-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	95003X	\N	\N	\N
242	LOIS	1989-10-04 00:00:00	1998-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	88006J	\N	\N	\N
243	LOIS	1998-10-06 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	\N	\N	2014-09-28 18:00:58
244	ETRD	\N	1999-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	95054K	\N	\N	\N
245	LOIS	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77033C	\N	\N	\N
246	ECON	1987-04-15 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	83003J	\N	\N	\N
247	LOIS	1995-10-05 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	\N	\N	2015-10-13 14:16:49
249	LOIS	\N	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	95024D	\N	\N	\N
250	LOIS	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95046K	\N	\N	\N
251	ETRD	\N	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	77017C	\N	\N	\N
252	AFCL	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95060H	\N	\N	\N
253	ETRD	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	86014A	\N	\N	\N
254	ECON	2001-10-03 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	95009E	\N	\N	\N
255	ETRD	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95028H	\N	\N	2014-09-28 12:56:41
256	ECON	\N	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	95023C	\N	\N	\N
257	ECON	\N	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	95025E	\N	\N	\N
258	AFCL	2001-10-03 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95047L	\N	\N	2014-09-28 17:09:16
259	SOCI	\N	1998-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	95048M	\N	\N	\N
260	ECON	2001-10-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95052H	\N	\N	\N
261	ETRD	2001-10-03 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86010V	\N	\N	2014-09-28 19:03:04
262	FINC	\N	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	88008L	\N	\N	2017-10-04 19:49:41
263	AFCL	\N	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	77044F	\N	\N	\N
265	AFCL	\N	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	95057N	\N	\N	\N
266	AFCL	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	97004H	\N	\N	\N
267	FINC	1998-03-05 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86018E	\N	\N	\N
268	ECON	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	97005J	\N	\N	\N
269	FINC	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	97009N	\N	\N	\N
270	FINC	1995-10-05 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	79004F	\N	\N	\N
271	SOCI	\N	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	95051G	\N	\N	\N
272	FINC	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95042F	\N	\N	\N
273	ETRD	\N	2002-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	95031C	\N	\N	\N
274	LOIS	1986-10-06 00:00:00	2001-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	86035F	\N	\N	\N
275	FINC	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86049M	\N	\N	2014-09-28 18:03:38
276	FINC	2001-10-03 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	95037J	\N	\N	2014-10-08 17:06:19
277	AFCL	1992-10-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	87003B	\N	\N	2017-10-04 19:42:38
278	FINC	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86041D	\N	\N	\N
279	SOCI	\N	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	95021A	\N	\N	\N
280	ECON	1995-10-05 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	87002A	\N	\N	\N
281	ECON	1997-10-07 00:00:00	2002-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	95059Q	\N	\N	\N
282	ETRD	\N	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	90004C	\N	\N	\N
283	LOIS	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95055L	\N	\N	\N
284	FINC	1986-10-06 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77058M	\N	\N	\N
285	ECON	\N	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	95012Y	\N	\N	\N
286	SOCI	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95033E	\N	\N	\N
287	SOCI	\N	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	86044G	\N	\N	\N
288	ETRD	\N	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	95004Y	\N	\N	\N
289	ECON	1986-10-02 00:00:00	2008-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	86034E	\N	\N	\N
290	SOCI	2001-10-03 00:00:00	2011-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	95035G	\N	\N	\N
291	ECON	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86011W	\N	\N	\N
292	ECON	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95013A	\N	\N	\N
293	ETRD	\N	1998-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	95050F	\N	\N	\N
294	SOCI	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95043G	\N	\N	\N
295	LOIS	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89035T	\N	\N	\N
296	ECON	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86021Y	\N	\N	\N
297	FINC	\N	2000-05-23 00:00:00	ANCIEN	\N	\N	\N	\N	95044H	\N	\N	\N
298	AFCL	\N	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98002K	\N	\N	\N
299	ECON	\N	2000-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	95002W	\N	\N	\N
300	SOCI	1996-04-15 00:00:00	2000-03-07 00:00:00	ANCIEN	\N	\N	\N	\N	96003C	\N	\N	\N
301	SOCI	\N	1999-01-21 00:00:00	ANCIEN	\N	\N	\N	\N	92033R	\N	\N	\N
302	LOIS	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77001T	\N	\N	\N
303	SOCI	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98004M	\N	\N	\N
304	ETRD	\N	1998-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	77028F	\N	\N	\N
305	AFCL	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95061J	\N	\N	\N
306	ETRD	1992-10-07 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	69001W	\N	\N	\N
307	ETRD	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98001J	\N	\N	\N
308	ETRD	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89021M	\N	\N	\N
309	ETRD	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89023P	\N	\N	\N
310	LOIS	1974-10-04 00:00:00	1999-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	74019R	\N	\N	\N
311	SOCI	1985-04-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77002U	\N	\N	\N
312	ETRD	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92008Q	\N	\N	\N
313	AFCL	1992-10-07 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92034S	\N	\N	\N
314	ETRD	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	90002A	\N	\N	\N
315	ETRD	\N	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	74032N	\N	\N	\N
316	ETRD	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86050E	\N	\N	\N
317	ETRD	1992-10-08 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86042E	\N	\N	\N
318	NEANT	\N	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	68036E	\N	\N	\N
319	NEANT	\N	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98005N	\N	\N	\N
320	NEANT	\N	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98007Q	\N	\N	\N
321	NEANT	\N	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98006P	\N	\N	\N
322	NEANT	\N	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98008R	\N	\N	\N
323	NEANT	\N	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98009S	\N	\N	\N
324	NEANT	\N	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98010K	\N	\N	\N
325	NEANT	\N	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98011L	\N	\N	\N
326	NEANT	\N	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98012M	\N	\N	\N
327	NEANT	\N	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98013N	\N	\N	\N
328	NEANT	\N	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98014P	\N	\N	\N
329	NEANT	1998-10-01 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98015Q	\N	\N	\N
330	NEANT	1998-10-01 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	89029V	\N	\N	\N
331	NEANT	1998-10-01 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98016R	\N	\N	\N
332	NEANT	1998-10-01 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98017S	\N	\N	\N
335	NEANT	1998-10-01 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98019U	\N	\N	\N
334	NEANT	1998-10-01 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98018T	\N	\N	\N
336	NEANT	1998-10-01 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98020M	\N	\N	\N
337	NEANT	1998-10-01 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98021N	\N	\N	\N
340	NEANT	1998-10-01 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98023Q	\N	\N	\N
339	NEANT	1998-10-01 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98022P	\N	\N	\N
341	NEANT	1998-10-01 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98024R	\N	\N	\N
342	NEANT	1998-10-01 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98025S	\N	\N	\N
343	NEANT	\N	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98026T	\N	\N	\N
344	NEANT	1998-10-01 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98027U	\N	\N	\N
345	NEANT	1998-10-01 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98028V	\N	\N	\N
346	NEANT	1998-10-01 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98029W	\N	\N	\N
347	NEANT	1998-10-01 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98030P	\N	\N	\N
348	NEANT	1998-10-01 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	80024B	\N	\N	\N
349	NEANT	1998-10-01 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98031Q	\N	\N	\N
350	NEANT	1998-10-01 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98032R	\N	\N	\N
351	NEANT	1998-10-01 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98033S	\N	\N	\N
352	NEANT	1998-10-01 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98034T	\N	\N	\N
353	NEANT	1998-10-01 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98035U	\N	\N	\N
354	NEANT	\N	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98036V	\N	\N	\N
355	NEANT	1998-10-01 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	66002K	\N	\N	\N
356	NEANT	1998-10-01 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98037W	\N	\N	\N
357	NEANT	1998-10-01 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98038X	\N	\N	\N
358	NEANT	1998-10-01 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98039Y	\N	\N	\N
359	NEANT	1998-10-01 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98040R	\N	\N	\N
360	NEANT	1998-10-01 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98041S	\N	\N	\N
361	NEANT	1998-10-01 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98042T	\N	\N	\N
362	NEANT	1998-10-01 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98043U	\N	\N	\N
363	NEANT	1998-10-01 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98044V	\N	\N	\N
364	NEANT	1998-10-01 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98045W	\N	\N	\N
365	NEANT	1998-10-01 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98046X	\N	\N	\N
366	NEANT	1998-10-01 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98047Y	\N	\N	\N
367	NEANT	1998-10-01 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98048A	\N	\N	\N
368	NEANT	1998-10-01 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98049B	\N	\N	\N
369	NEANT	1998-10-01 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98050T	\N	\N	\N
370	NEANT	1998-10-01 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98051U	\N	\N	\N
371	NEANT	\N	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98052V	\N	\N	\N
372	NEANT	1998-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	77058M	\N	\N	\N
373	NEANT	1998-10-03 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98053W	\N	\N	\N
374	AFCL	1998-10-06 00:00:00	2000-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	95018F	\N	\N	\N
375	AFCL	1998-10-06 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	80017C	\N	\N	\N
376	AFCL	1998-10-06 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98022P	\N	\N	\N
377	AFCL	1998-10-06 00:00:00	2000-05-02 00:00:00	ANCIEN	\N	\N	\N	\N	98051U	\N	\N	\N
378	AFCL	1998-10-06 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98015Q	\N	\N	\N
379	ECON	1998-10-06 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98049B	\N	\N	\N
380	ECON	1998-10-06 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98009S	\N	\N	\N
381	ECON	1998-10-06 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98034T	\N	\N	\N
383	ECON	1998-10-06 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	98010K	\N	\N	\N
384	ECON	1998-10-06 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	98037W	\N	\N	\N
385	ECON	1998-10-06 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	98012M	\N	\N	\N
386	ETRD	1998-10-06 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	98011L	\N	\N	\N
387	ETRD	1998-10-06 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	80039J	\N	\N	\N
388	SOCI	1998-10-06 00:00:00	2004-12-23 00:00:00	ANCIEN	\N	\N	\N	\N	98020M	\N	\N	\N
389	SOCI	1998-10-06 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	98029W	\N	\N	2014-10-08 16:59:48
390	SOCI	1998-10-06 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	98030P	\N	\N	\N
391	SOCI	1998-10-06 00:00:00	1998-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	98035U	\N	\N	\N
392	FINC	1998-10-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	90004C	\N	\N	\N
393	LOIS	1998-10-06 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	98006P	\N	\N	\N
394	LOIS	1998-10-06 00:00:00	2002-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	97007L	\N	\N	\N
395	LOIS	1998-10-06 00:00:00	1998-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	83039W	\N	\N	\N
396	LOIS	1998-10-06 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	98046X	\N	\N	\N
397	AFCL	1998-10-06 00:00:00	2001-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	83008P	\N	\N	\N
398	AFCL	1998-10-06 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95023C	\N	\N	\N
399	ETRD	1998-10-06 00:00:00	2001-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	98032R	\N	\N	\N
400	SOCI	1998-10-06 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98002K	\N	\N	\N
401	FINC	1998-10-06 00:00:00	2002-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	66002K	\N	\N	\N
402	FINC	1998-10-06 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	89042S	\N	\N	\N
403	LOIS	1998-10-06 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83020K	\N	\N	\N
404	LOIS	1998-10-06 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	95004Y	\N	\N	\N
405	LOIS	1998-10-06 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98041S	\N	\N	2014-09-28 16:42:05
406	LOIS	1998-10-06 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	98028V	\N	\N	\N
407	AFCL	1998-10-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98042T	\N	\N	\N
408	ECON	1998-10-06 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	98050T	\N	\N	\N
409	ETRD	1998-10-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98021N	\N	\N	2017-10-01 09:22:38
410	ECON	1998-10-06 00:00:00	2002-07-30 00:00:00	ANCIEN	\N	\N	\N	\N	98019U	\N	\N	\N
411	ETRD	1998-10-06 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	89029V	\N	\N	\N
412	ETRD	1998-10-06 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98018T	\N	\N	2017-10-04 19:57:21
413	ETRD	1998-10-06 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98033S	\N	\N	\N
414	LOIS	1998-10-06 00:00:00	2006-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	98052V	\N	\N	\N
415	LOIS	1998-10-06 00:00:00	2003-11-13 00:00:00	ANCIEN	\N	\N	\N	\N	98040R	\N	\N	\N
416	LOIS	1998-10-06 00:00:00	1999-01-21 00:00:00	ANCIEN	\N	\N	\N	\N	98039Y	\N	\N	\N
417	ECON	1998-10-06 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98003L	\N	\N	\N
418	ETRD	1998-10-06 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80035E	\N	\N	\N
419	SOCI	1998-10-06 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83026R	\N	\N	\N
420	FINC	1998-10-06 00:00:00	2001-09-20 00:00:00	ANCIEN	\N	\N	\N	\N	94002S	\N	\N	\N
421	LOIS	1998-10-06 00:00:00	2004-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	98016R	\N	\N	\N
422	FINC	1998-10-06 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	98053W	\N	\N	2017-10-04 18:48:04
423	ECON	1998-10-06 00:00:00	2000-03-07 00:00:00	ANCIEN	\N	\N	\N	\N	98038X	\N	\N	\N
425	ETRD	1998-10-06 00:00:00	2003-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	86031B	\N	\N	\N
426	FINC	1998-10-06 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95012Y	\N	\N	\N
427	FINC	1998-10-06 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	95041E	\N	\N	2017-10-04 19:51:24
428	SOCI	1998-10-06 00:00:00	2000-05-23 00:00:00	ANCIEN	\N	\N	\N	\N	95024D	\N	\N	\N
429	SOCI	1998-10-06 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98045W	\N	\N	\N
430	SOCI	1998-10-06 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98017S	\N	\N	\N
431	SOCI	1998-10-06 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98026T	\N	\N	\N
432	AFCL	1998-10-06 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98048A	\N	\N	\N
433	AFCL	1998-10-06 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	98031Q	\N	\N	\N
434	AFCL	1998-10-06 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98005N	\N	\N	\N
435	AFCL	1998-10-06 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	98025S	\N	\N	\N
436	AFCL	1998-10-06 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98013N	\N	\N	\N
437	AFCL	1998-10-06 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83052T	\N	\N	\N
438	ECON	1998-10-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98036V	\N	\N	\N
439	ECON	1998-10-06 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	98023Q	\N	\N	\N
440	ECON	1998-10-06 00:00:00	2000-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	95027G	\N	\N	\N
441	ECON	1998-10-06 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86006A	\N	\N	\N
442	ECON	1998-10-06 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	\N	98043U	\N	\N	\N
443	ECON	1998-10-06 00:00:00	1999-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	98007Q	\N	\N	\N
444	ECON	1998-10-06 00:00:00	2005-03-19 00:00:00	ANCIEN	\N	\N	\N	\N	98008R	\N	\N	\N
445	ECON	1998-10-06 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	96008H	\N	\N	\N
459	LOIS	1998-10-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98035U	\N	\N	2017-10-04 19:51:00
447	AFCL	1998-10-06 00:00:00	2002-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	83011J	\N	\N	\N
448	AFCL	1998-10-06 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	74013K	\N	\N	\N
449	AFCL	1998-10-06 00:00:00	1998-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	68036E	\N	\N	\N
450	ETRD	1998-10-06 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98014P	\N	\N	\N
451	ETRD	1998-10-06 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92036U	\N	\N	\N
452	ETRD	1998-10-06 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95057N	\N	\N	\N
453	LOIS	1998-10-06 00:00:00	2001-06-14 00:00:00	ANCIEN	\N	\N	\N	\N	98024R	\N	\N	\N
454	LOIS	1998-10-06 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	98047Y	\N	\N	\N
455	LOIS	1998-10-06 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	98027U	\N	\N	\N
456	ECON	1998-10-06 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92032Q	\N	\N	\N
457	SOCI	1998-10-06 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	98044V	\N	\N	\N
460	LOIS	1998-10-14 00:00:00	1999-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	95050F	\N	\N	\N
461	ETRD	1998-10-14 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	83043S	\N	\N	\N
462	SOCI	1998-10-14 00:00:00	2000-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	83039W	\N	\N	\N
1	ECON	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89016Q	\N	\N	\N
2	ECON	1992-10-08 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	89027T	\N	\N	\N
3	AFCL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	88005H	\N	\N	\N
4	LOIS	1978-05-09 00:00:00	1989-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	78003A	\N	\N	\N
5	ECON	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	71006X	\N	\N	\N
6	FINC	1974-10-04 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	71009B	\N	\N	\N
7	ECON	2001-10-03 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	89018S	\N	\N	\N
8	ECON	1980-10-07 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80043E	\N	\N	\N
9	SOCI	\N	2007-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	89006N	\N	\N	\N
10	ECON	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	88012G	\N	\N	\N
11	AFCL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89046W	\N	\N	\N
12	LOIS	1989-10-06 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	84004P	\N	\N	\N
13	AFCL	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	85003S	\N	\N	\N
14	FINC	\N	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	80045G	\N	\N	\N
15	ECON	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80021X	\N	\N	\N
16	ECON	\N	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	96005E	\N	\N	\N
17	FINC	1977-10-06 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	71003U	\N	\N	\N
18	LOIS	1980-10-07 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80004W	\N	\N	\N
19	FINC	\N	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89017R	\N	\N	2017-10-04 19:48:46
20	FINC	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	94003T	\N	\N	2014-09-28 13:16:32
21	LOIS	\N	2006-08-11 00:00:00	ANCIEN	\N	\N	\N	\N	74050Q	\N	\N	\N
22	ECON	\N	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	80013X	\N	\N	2017-10-04 20:11:36
23	SOCI	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89041R	\N	\N	\N
24	ECON	\N	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	80035E	\N	\N	\N
25	LOIS	\N	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	80017C	\N	\N	\N
27	FINC	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89024Q	\N	\N	\N
28	ETRD	1989-10-02 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	89042S	\N	\N	\N
29	LOIS	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89044U	\N	\N	\N
30	ECON	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89039X	\N	\N	\N
31	AFCL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89036U	\N	\N	\N
32	SOCI	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95068R	\N	\N	\N
33	LOIS	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	71018C	\N	\N	\N
34	LOIS	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	70001N	\N	\N	\N
36	FINC	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89010J	\N	\N	\N
37	ECON	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89038W	\N	\N	\N
38	ETRD	1980-10-07 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80002U	\N	\N	\N
39	AFCL	\N	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	96008H	\N	\N	\N
40	FINC	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89013M	\N	\N	2014-09-28 17:05:42
41	ECON	2001-10-03 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	89014N	\N	\N	\N
42	LOIS	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89012L	\N	\N	\N
661	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01011G	\N	\N	\N
662	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01012H	\N	\N	\N
663	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01013J	\N	\N	\N
664	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01014K	\N	\N	\N
665	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01015L	\N	\N	\N
666	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	\N	\N	\N
667	ECON	2001-10-03 00:00:00	2007-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	01017N	\N	\N	\N
668	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01018P	\N	\N	\N
669	LOIS	2001-10-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01019Q	\N	\N	2017-09-24 17:35:15
670	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01020H	\N	\N	\N
672	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01022K	\N	\N	\N
673	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01023L	\N	\N	\N
674	ECON	2001-10-03 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	01024M	\N	\N	\N
675	AFCL	2001-10-03 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01025N	\N	\N	2017-10-04 19:13:12
676	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01026P	\N	\N	\N
677	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01027Q	\N	\N	\N
678	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	\N	\N	\N
679	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01029S	\N	\N	\N
680	SOCI	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01030K	\N	\N	\N
681	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	\N	\N	\N
682	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01032M	\N	\N	\N
683	SOCI	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01033N	\N	\N	\N
684	AFCL	2001-10-03 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	01034P	\N	\N	\N
685	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01035Q	\N	\N	\N
686	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01036R	\N	\N	\N
687	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01037S	\N	\N	\N
688	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01038T	\N	\N	\N
689	AFCL	2001-10-03 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	\N	01039U	\N	\N	\N
690	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01040M	\N	\N	\N
691	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01041N	\N	\N	\N
692	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01042P	\N	\N	\N
693	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01043Q	\N	\N	\N
695	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01044R	\N	\N	\N
696	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01045S	\N	\N	\N
697	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	\N	\N	\N
698	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	\N	\N	\N
699	LOIS	2001-10-03 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	01048V	\N	\N	\N
700	ECON	2001-10-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01049W	\N	\N	\N
701	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01050P	\N	\N	\N
702	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01051Q	\N	\N	\N
703	ECON	2001-10-03 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	01052R	\N	\N	\N
704	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01053S	\N	\N	\N
705	AFCL	2001-10-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01054T	\N	\N	\N
706	ECON	2001-10-03 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	01055U	\N	\N	\N
707	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01056V	\N	\N	\N
708	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01057W	\N	\N	\N
709	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01058X	\N	\N	\N
710	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	\N	\N	\N
711	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01060R	\N	\N	\N
712	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	83042R	\N	\N	\N
713	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01061S	\N	\N	\N
714	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01062T	\N	\N	\N
716	AFCL	2001-10-03 00:00:00	2002-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	83033Q	\N	\N	\N
718	ECON	2001-10-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01050P	\N	\N	\N
719	ETRD	2001-10-03 00:00:00	2002-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	89042S	\N	\N	\N
720	SOCI	2001-10-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	\N	\N	2017-09-24 13:44:49
721	SOCI	2001-10-03 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	77019E	\N	\N	\N
722	FINC	2001-10-03 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	98032R	\N	\N	2014-10-08 16:41:16
723	AFCL	2001-10-03 00:00:00	2017-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	01044R	\N	\N	2017-07-04 15:08:09
724	AFCL	2001-10-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01012H	\N	\N	\N
725	AFCL	2001-10-03 00:00:00	2006-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	01032M	\N	\N	\N
115	SOCI	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89004L	\N	\N	\N
116	AFCL	\N	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	83039W	\N	\N	\N
117	AFCL	\N	2000-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	92015P	\N	\N	\N
120	SOCI	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83046V	\N	\N	\N
121	AFCL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92041R	\N	\N	\N
122	AFCL	2001-10-03 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	97011G	\N	\N	2014-10-08 17:36:57
123	ECON	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83044T	\N	\N	\N
124	AFCL	1980-10-07 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	78006D	\N	\N	\N
125	LOIS	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83025Q	\N	\N	\N
127	SOCI	1992-10-07 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92019T	\N	\N	\N
128	AFCL	\N	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	92032Q	\N	\N	\N
129	SOCI	\N	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	83012K	\N	\N	\N
130	SOCI	1974-10-04 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	74015M	\N	\N	\N
131	LOIS	1986-04-10 00:00:00	1998-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	83043S	\N	\N	\N
132	ECON	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	74028S	\N	\N	\N
133	FINC	1998-10-06 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	92039X	\N	\N	2014-10-08 16:53:50
134	ETRD	\N	2008-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	88004G	\N	\N	\N
135	ECON	\N	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	83033Q	\N	\N	\N
136	ECON	\N	2001-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	81001X	\N	\N	\N
137	ECON	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	94004U	\N	\N	\N
138	LOIS	1983-10-06 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83038V	\N	\N	\N
139	ECON	1983-10-07 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83035S	\N	\N	\N
140	AFCL	1992-10-07 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92026S	\N	\N	\N
141	ECON	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92025R	\N	\N	\N
142	ECON	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	82002D	\N	\N	\N
143	ECON	2001-10-03 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	96004D	\N	\N	\N
144	SOCI	1983-10-06 00:00:00	2001-06-14 00:00:00	ANCIEN	\N	\N	\N	\N	83040P	\N	\N	\N
145	AFCL	\N	2000-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	92010J	\N	\N	\N
146	AFCL	1983-10-06 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83056X	\N	\N	\N
147	FINC	1986-10-06 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	81007E	\N	\N	\N
148	ECON	1996-10-04 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	74011H	\N	\N	\N
150	FINC	\N	2001-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	74008N	\N	\N	\N
151	AFCL	1992-10-07 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92009R	\N	\N	\N
152	SOCI	1983-10-07 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83036T	\N	\N	\N
153	FINC	\N	2007-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	92007P	\N	\N	\N
156	ECON	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	74022L	\N	\N	\N
157	LOIS	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83016P	\N	\N	\N
158	ECON	\N	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	83050R	\N	\N	\N
159	SOCI	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	81011A	\N	\N	\N
160	ECON	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	74042Q	\N	\N	\N
161	ETRD	\N	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	\N	83037U	\N	\N	\N
162	LOIS	\N	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	74013K	\N	\N	\N
829	AFCL	2002-01-15 00:00:00	2002-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01065W	\N	\N	\N
830	NEANT	2002-01-20 00:00:00	2002-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	02001J	\N	\N	\N
831	LOIS	2002-01-29 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	02001J	\N	\N	\N
832	ECON	\N	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	95036H	\N	\N	\N
833	ECON	2002-06-27 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	02002K	\N	\N	\N
834	SOCI	2002-06-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	02003L	\N	\N	\N
835	NEANT	2002-06-08 00:00:00	2002-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	02004M	\N	\N	\N
836	NEANT	2002-06-08 00:00:00	2002-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	02005N	\N	\N	\N
841	FINC	2002-06-27 00:00:00	2014-07-01 00:00:00	ANCIEN	\N	\N	\N	\N	83011J	\N	\N	2014-07-01 09:25:11
842	ETRD	2002-06-27 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	99003Q	\N	\N	\N
843	FINC	2002-06-27 00:00:00	2009-07-28 00:00:00	ANCIEN	\N	\N	\N	\N	99004R	\N	\N	2017-10-24 16:15:15
844	LOIS	2002-06-27 00:00:00	2015-04-21 00:00:00	ANCIEN	\N	\N	\N	\N	01042P	\N	\N	2015-04-21 17:14:30
845	AFCL	2002-06-27 00:00:00	2004-06-01 00:00:00	ANCIEN	\N	\N	\N	\N	02004M	\N	\N	\N
846	ECON	2002-06-27 00:00:00	2003-11-05 00:00:00	ANCIEN	\N	\N	\N	\N	01060R	\N	\N	\N
848	AFCL	2002-07-03 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	02005N	\N	\N	\N
854	NEANT	2002-07-18 00:00:00	2002-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	02006P	\N	\N	\N
857	ETRD	2002-07-30 00:00:00	2003-05-14 00:00:00	ANCIEN	\N	\N	\N	\N	98019U	\N	\N	\N
859	SOCI	2002-10-03 00:00:00	2002-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	02007Q	\N	\N	\N
861	AFCL	2002-10-01 00:00:00	2004-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	66002K	\N	\N	\N
862	FINC	2002-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	78003A	\N	\N	\N
863	LOIS	2002-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01065W	\N	\N	2014-09-28 12:09:44
864	ETRD	2002-10-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	59312E	\N	\N	\N
867	ECON	2002-10-08 00:00:00	2003-05-14 00:00:00	ANCIEN	\N	\N	\N	\N	77047J	\N	\N	\N
868	SOCI	2002-10-08 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	02006P	\N	\N	\N
870	AFCL	2002-10-15 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	89042S	\N	\N	\N
873	ETRD	2002-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83033Q	\N	\N	\N
874	NEANT	2002-12-11 00:00:00	2002-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	59569E	\N	\N	\N
875	ETRD	2002-12-19 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	59569E	\N	\N	\N
876	COMSPEAPU	2002-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86041D	\N	\N	\N
878	COMSPEAPU	2002-10-01 00:00:00	2010-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	86049M	\N	\N	\N
881	COMSPEAPU	2002-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	94003T	\N	\N	2014-09-28 13:16:32
882	COMSPEAPU	2002-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98047Y	\N	\N	\N
883	COMSPEAPU	2002-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	01024M	\N	\N	\N
884	COMSPEAPU	2002-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	95003X	\N	\N	\N
885	COMSPEAPU	2002-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	80039J	\N	\N	\N
887	DROGUE	2002-12-12 00:00:00	2003-05-27 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	\N	\N	\N
888	DROGUE	2002-12-12 00:00:00	2003-05-27 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	\N	\N	\N
889	DROGUE	2002-12-12 00:00:00	2003-05-27 00:00:00	ANCIEN	\N	\N	\N	\N	98006P	\N	\N	\N
890	DROGUE	2002-12-12 00:00:00	2003-05-27 00:00:00	ANCIEN	\N	\N	\N	\N	01001E	\N	\N	\N
891	DROGUE	2002-12-12 00:00:00	2003-05-27 00:00:00	ANCIEN	\N	\N	\N	\N	01064V	\N	\N	\N
892	DROGUE	2002-12-12 00:00:00	2003-05-27 00:00:00	ANCIEN	\N	\N	\N	\N	01052R	\N	\N	\N
893	DROGUE	2002-12-12 00:00:00	2003-05-27 00:00:00	ANCIEN	\N	\N	\N	\N	95017E	\N	\N	\N
894	DROGUE	2002-12-12 00:00:00	2003-05-27 00:00:00	ANCIEN	\N	\N	\N	\N	92018S	\N	\N	\N
927	HANDICAPES	2002-12-12 00:00:00	2003-06-04 00:00:00	ANCIEN	\N	\N	\N	\N	01005J	\N	\N	\N
896	DROGUE	2002-12-12 00:00:00	2003-05-27 00:00:00	ANCIEN	\N	\N	\N	\N	95024D	\N	\N	\N
897	DROGUE	2002-12-12 00:00:00	2003-05-27 00:00:00	ANCIEN	\N	\N	\N	\N	98024R	\N	\N	\N
898	DROGUE	2002-12-12 00:00:00	2003-05-27 00:00:00	ANCIEN	\N	\N	\N	\N	78003A	\N	\N	\N
899	DROGUE	2002-12-12 00:00:00	2003-05-27 00:00:00	ANCIEN	\N	\N	\N	\N	78006D	\N	\N	\N
900	DROGUE	2002-12-12 00:00:00	2003-05-27 00:00:00	ANCIEN	\N	\N	\N	\N	97004H	\N	\N	\N
901	DROGUE	2002-12-12 00:00:00	2003-05-27 00:00:00	ANCIEN	\N	\N	\N	\N	88013H	\N	\N	\N
902	DROGUE	2003-01-15 00:00:00	2003-05-27 00:00:00	ANCIEN	\N	\N	\N	\N	01043Q	\N	\N	2018-01-31 09:48:22
903	DROGUE	2002-12-12 00:00:00	2003-05-27 00:00:00	ANCIEN	\N	\N	\N	\N	77043E	\N	\N	\N
904	DROGUE	2002-12-12 00:00:00	2003-05-27 00:00:00	ANCIEN	\N	\N	\N	\N	95046K	\N	\N	\N
905	DROGUE	2002-12-12 00:00:00	2003-05-27 00:00:00	ANCIEN	\N	\N	\N	\N	00002B	\N	\N	\N
906	DROGUE	2002-12-12 00:00:00	2003-05-27 00:00:00	ANCIEN	\N	\N	\N	\N	95051G	\N	\N	\N
907	DROGUE	2002-12-12 00:00:00	2003-05-27 00:00:00	ANCIEN	\N	\N	\N	\N	01054T	\N	\N	\N
908	DROGUE	2002-12-12 00:00:00	2003-05-27 00:00:00	ANCIEN	\N	\N	\N	\N	95056M	\N	\N	\N
928	HANDICAPES	2002-12-12 00:00:00	2003-06-04 00:00:00	ANCIEN	\N	\N	\N	\N	92011K	\N	\N	\N
929	HANDICAPES	2002-12-12 00:00:00	2003-06-04 00:00:00	ANCIEN	\N	\N	\N	\N	95014B	\N	\N	\N
930	HANDICAPES	2002-12-12 00:00:00	2003-06-04 00:00:00	ANCIEN	\N	\N	\N	\N	92018S	\N	\N	\N
931	HANDICAPES	2002-12-12 00:00:00	2003-06-04 00:00:00	ANCIEN	\N	\N	\N	\N	98030P	\N	\N	\N
932	HANDICAPES	2002-12-12 00:00:00	2003-06-04 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	\N	\N	\N
933	HANDICAPES	2002-12-12 00:00:00	2003-06-04 00:00:00	ANCIEN	\N	\N	\N	\N	95033E	\N	\N	\N
934	HANDICAPES	2002-12-12 00:00:00	2003-06-04 00:00:00	ANCIEN	\N	\N	\N	\N	95035G	\N	\N	\N
935	HANDICAPES	2002-12-12 00:00:00	2003-06-04 00:00:00	ANCIEN	\N	\N	\N	\N	01030K	\N	\N	\N
936	HANDICAPES	2002-12-12 00:00:00	2003-06-04 00:00:00	ANCIEN	\N	\N	\N	\N	01018P	\N	\N	\N
937	HANDICAPES	2002-12-12 00:00:00	2003-06-04 00:00:00	ANCIEN	\N	\N	\N	\N	95043G	\N	\N	\N
938	HANDICAPES	2002-12-12 00:00:00	2003-06-04 00:00:00	ANCIEN	\N	\N	\N	\N	95045J	\N	\N	\N
939	HANDICAPES	2002-12-12 00:00:00	2003-06-04 00:00:00	ANCIEN	\N	\N	\N	\N	02004M	\N	\N	\N
940	HANDICAPES	2002-12-12 00:00:00	2003-06-04 00:00:00	ANCIEN	\N	\N	\N	\N	80031A	\N	\N	\N
941	HANDICAPES	2002-12-12 00:00:00	2003-06-04 00:00:00	ANCIEN	\N	\N	\N	\N	01009N	\N	\N	\N
942	HANDICAPES	2002-12-12 00:00:00	2003-06-04 00:00:00	ANCIEN	\N	\N	\N	\N	98015Q	\N	\N	\N
943	HANDICAPES	2002-12-12 00:00:00	2003-06-04 00:00:00	ANCIEN	\N	\N	\N	\N	96007G	\N	\N	\N
944	HANDICAPES	2002-12-12 00:00:00	2003-06-04 00:00:00	ANCIEN	\N	\N	\N	\N	01029S	\N	\N	\N
945	HANDICAPES	2002-12-12 00:00:00	2003-06-04 00:00:00	ANCIEN	\N	\N	\N	\N	01023L	\N	\N	\N
946	HANDICAPES	2002-12-12 00:00:00	2003-06-04 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	\N	\N	\N
947	HANDICAPES	2002-12-12 00:00:00	2003-06-04 00:00:00	ANCIEN	\N	\N	\N	\N	80048K	\N	\N	\N
969	INITIATIVE	2003-02-12 00:00:00	2003-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	77013X	\N	\N	\N
970	INITIATIVE	2003-02-12 00:00:00	2003-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	98023Q	\N	\N	\N
971	INITIATIVE	2003-02-12 00:00:00	2003-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	98024R	\N	\N	\N
972	INITIATIVE	2003-02-12 00:00:00	2003-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	99003Q	\N	\N	\N
973	INITIATIVE	2003-02-12 00:00:00	2003-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	89027T	\N	\N	\N
974	INITIATIVE	2003-02-12 00:00:00	2003-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	95036H	\N	\N	\N
975	INITIATIVE	2003-02-12 00:00:00	2003-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	01057W	\N	\N	\N
976	INITIATIVE	2003-02-12 00:00:00	2003-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	\N	\N	\N
977	INITIATIVE	2003-02-12 00:00:00	2003-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	86034E	\N	\N	\N
978	INITIATIVE	2003-02-12 00:00:00	2003-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	01061S	\N	\N	\N
980	INITIATIVE	2003-02-12 00:00:00	2003-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	\N	\N	\N
981	INITIATIVE	2003-02-12 00:00:00	2003-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	91002E	\N	\N	\N
982	INITIATIVE	2003-02-12 00:00:00	2003-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	86041D	\N	\N	\N
983	INITIATIVE	2003-02-12 00:00:00	2003-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	86044G	\N	\N	\N
984	INITIATIVE	2003-02-12 00:00:00	2003-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	01019Q	\N	\N	\N
985	INITIATIVE	2003-02-12 00:00:00	2003-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	80041C	\N	\N	\N
986	INITIATIVE	2003-02-12 00:00:00	2003-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	86047K	\N	\N	\N
1001	NEANT	2003-02-09 00:00:00	2003-02-26 00:00:00	ANCIEN	\N	\N	\N	\N	03001N	\N	\N	\N
1002	INITIATIVE	2003-02-12 00:00:00	2003-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	85003S	\N	\N	\N
1003	INITIATIVE	2003-02-12 00:00:00	2003-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	89042S	\N	\N	\N
1005	INITIATIVE	2003-02-12 00:00:00	2003-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	97005J	\N	\N	\N
1006	INITIATIVE	2003-02-12 00:00:00	2003-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	00002B	\N	\N	\N
1007	INITIATIVE	2003-02-12 00:00:00	2003-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	95003X	\N	\N	\N
1008	INITIATIVE	2003-02-12 00:00:00	2003-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	97009N	\N	\N	\N
1009	INITIATIVE	2003-02-12 00:00:00	2003-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	98012M	\N	\N	\N
1011	INITIATIVE	2003-02-12 00:00:00	2003-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	96006F	\N	\N	\N
1012	INITIATIVE	2003-02-12 00:00:00	2003-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	89040Q	\N	\N	\N
1013	INITIATIVE	2003-02-12 00:00:00	2003-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	01011G	\N	\N	\N
1014	INITIATIVE	2003-02-12 00:00:00	2003-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	98015Q	\N	\N	\N
1021	SOCI	2003-02-27 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	03001N	\N	\N	\N
1016	INITIATIVE	2003-02-12 00:00:00	2003-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	89017R	\N	\N	\N
1017	INITIATIVE	2003-02-12 00:00:00	2003-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	98049B	\N	\N	\N
1018	INITIATIVE	2003-02-12 00:00:00	2003-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	01017N	\N	\N	\N
1019	INITIATIVE	2003-02-12 00:00:00	2003-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	\N	\N	\N
1020	INITIATIVE	2003-02-12 00:00:00	2003-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	95014B	\N	\N	\N
1023	ECON	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000083	\N	\N	\N
1024	SOCI	1967-10-11 00:00:00	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	57426F	\N	\N	\N
1025	ECON	1959-05-06 00:00:00	1971-02-25 00:00:00	ANCIEN	\N	\N	\N	\N	000165	\N	\N	\N
1026	ETRD	1961-10-05 00:00:00	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000176	\N	\N	\N
1027	ETRD	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58041V	\N	\N	\N
1028	ECON	\N	1973-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	000160	\N	\N	\N
1029	AFCL	1959-05-06 00:00:00	1981-01-03 00:00:00	ANCIEN	\N	\N	\N	\N	000198	\N	\N	\N
1030	SOCI	\N	1969-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	000081	\N	\N	\N
1031	SOCI	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000028	\N	\N	\N
1032	ETRD	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000328	\N	\N	\N
1033	LOIS	1959-05-06 00:00:00	1965-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	000316	\N	\N	\N
1034	SOCI	1959-05-06 00:00:00	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000013	\N	\N	\N
1035	SOCI	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000234	\N	\N	\N
1036	ECON	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	57701F	\N	\N	\N
1037	SOCI	1959-07-02 00:00:00	1959-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	000021	\N	\N	\N
1038	SOCI	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000064	\N	\N	\N
1039	AFCL	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000665	\N	\N	\N
1040	ETRD	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000047	\N	\N	\N
1041	SOCI	\N	1967-04-03 00:00:00	ANCIEN	\N	\N	\N	\N	58302X	\N	\N	\N
1042	ETRD	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	56326X	\N	\N	\N
1043	ECON	\N	1973-09-26 00:00:00	ANCIEN	\N	\N	\N	\N	000285	\N	\N	\N
1044	SOCI	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000340	\N	\N	\N
1045	AFCL	\N	1961-09-19 00:00:00	ANCIEN	\N	\N	\N	\N	000113	\N	\N	\N
1046	ETRD	1959-05-06 00:00:00	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000036	\N	\N	\N
1047	LOIS	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	57741P	\N	\N	\N
1048	AFCL	1959-05-06 00:00:00	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000016	\N	\N	\N
1049	NEANT	\N	1971-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	000490	\N	\N	\N
1050	AFCL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000115	\N	\N	\N
1051	SOCI	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000282	\N	\N	\N
1052	FINC	\N	1973-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	58109Y	\N	\N	\N
1053	SOCI	\N	1980-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	58515K	\N	\N	\N
1054	AFCL	\N	1975-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	000002	\N	\N	\N
1055	LOIS	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000032	\N	\N	\N
1056	AFCL	\N	1967-04-03 00:00:00	ANCIEN	\N	\N	\N	\N	000400	\N	\N	\N
1057	ETRD	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000116	\N	\N	\N
1058	AFCL	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000091	\N	\N	\N
1059	AFCL	1963-10-03 00:00:00	1973-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	000425	\N	\N	\N
1060	AFCL	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	57316A	\N	\N	\N
1061	LOIS	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000346	\N	\N	\N
1062	AFCL	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000448	\N	\N	\N
1063	AFCL	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000260	\N	\N	\N
1064	ETRD	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	57773X	\N	\N	\N
1065	FINC	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000087	\N	\N	\N
1066	FINC	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	57716N	\N	\N	\N
1067	FINC	\N	1974-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	000037	\N	\N	\N
1068	FINC	\N	1962-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	000012	\N	\N	\N
1069	ECON	\N	1969-08-22 00:00:00	ANCIEN	\N	\N	\N	\N	000146	\N	\N	\N
1070	AFCL	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000051	\N	\N	\N
1071	SOCI	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	58614M	\N	\N	\N
43	LOIS	1971-10-06 00:00:00	1974-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	71017B	\N	\N	\N
44	ETRD	1996-02-14 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	89045V	\N	\N	\N
45	SOCI	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80031A	\N	\N	\N
46	SOCI	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80007A	\N	\N	\N
47	LOIS	\N	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	94002S	\N	\N	\N
48	ECON	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	97002F	\N	\N	\N
49	SOCI	\N	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98003L	\N	\N	\N
50	ETRD	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80025C	\N	\N	\N
51	ECON	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89037V	\N	\N	\N
52	FINC	1986-10-06 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80036F	\N	\N	\N
53	LOIS	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	97010F	\N	\N	\N
54	AFCL	\N	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	89040Q	\N	\N	\N
55	ECON	1981-10-08 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	81010Y	\N	\N	\N
56	FINC	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	73006G	\N	\N	\N
57	AFCL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	97001E	\N	\N	\N
58	SOCI	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80028F	\N	\N	\N
59	ECON	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	88009M	\N	\N	\N
60	ECON	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	88002E	\N	\N	\N
61	SOCI	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80041C	\N	\N	\N
62	ECON	\N	2005-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	89015P	\N	\N	\N
63	ECON	\N	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	96006F	\N	\N	\N
64	FINC	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86037H	\N	\N	\N
65	ETRD	\N	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	95027G	\N	\N	\N
66	ETRD	\N	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	95053J	\N	\N	\N
68	ECON	\N	2000-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	88003F	\N	\N	\N
69	FINC	2001-10-03 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89022N	\N	\N	2014-09-28 18:19:47
70	FINC	1989-10-05 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	81014D	\N	\N	\N
71	ECON	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83004K	\N	\N	\N
72	SOCI	\N	2001-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	89009R	\N	\N	\N
73	ECON	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89031P	\N	\N	\N
74	LOIS	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80003V	\N	\N	\N
75	ETRD	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	71024A	\N	\N	\N
77	ECON	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89034S	\N	\N	\N
78	SOCI	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92046W	\N	\N	\N
79	ETRD	1986-10-07 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80040B	\N	\N	\N
80	ECON	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80033C	\N	\N	\N
81	LOIS	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	96001A	\N	\N	\N
82	SOCI	1980-10-02 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	80039J	\N	\N	\N
83	FINC	\N	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	89019T	\N	\N	\N
84	AFCL	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89008Q	\N	\N	\N
85	ECON	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89028U	\N	\N	\N
86	SOCI	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	93006S	\N	\N	\N
87	ECON	1996-02-14 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	90003B	\N	\N	\N
88	ETRD	2001-10-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80027E	\N	\N	\N
89	ECON	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89025R	\N	\N	\N
91	LOIS	1997-06-24 00:00:00	2000-03-28 00:00:00	ANCIEN	\N	\N	\N	\N	97003G	\N	\N	\N
92	LOIS	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	93005R	\N	\N	\N
93	FINC	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95007C	\N	\N	\N
94	LOIS	\N	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	95006B	\N	\N	\N
95	SOCI	\N	1998-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	77019E	\N	\N	\N
96	ETRD	1995-10-04 00:00:00	1999-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	77053G	\N	\N	\N
97	LOIS	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95016D	\N	\N	\N
98	ECON	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80015A	\N	\N	\N
99	SOCI	\N	2007-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	89043T	\N	\N	\N
100	AFCL	\N	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	80048K	\N	\N	\N
101	SOCI	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80026D	\N	\N	\N
102	ECON	1980-10-07 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80014Y	\N	\N	\N
103	ETRD	1980-10-07 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80011V	\N	\N	\N
104	AFCL	1989-10-04 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89026S	\N	\N	\N
105	ECON	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89030N	\N	\N	\N
106	ETRD	\N	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	89020L	\N	\N	\N
107	AFCL	1983-10-06 00:00:00	1992-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	83026R	\N	\N	\N
108	SOCI	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92030N	\N	\N	\N
109	AFCL	1992-10-07 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	92012L	\N	\N	\N
110	FINC	1995-10-05 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	83020K	\N	\N	\N
111	ECON	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83018R	\N	\N	\N
112	SOCI	1985-10-02 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83028T	\N	\N	\N
113	ETRD	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83031N	\N	\N	\N
163	SOCI	\N	2014-09-01 00:00:00	ANCIEN	\N	\N	\N	\N	96007G	\N	\N	2014-09-01 10:21:13
164	AFCL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	97008M	\N	\N	\N
165	LOIS	\N	2000-05-23 00:00:00	ANCIEN	\N	\N	\N	\N	92016Q	\N	\N	\N
166	AFCL	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86053H	\N	\N	\N
167	ECON	1997-06-24 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	97006K	\N	\N	\N
168	AFCL	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	65017N	\N	\N	\N
169	SOCI	1997-09-17 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	97007L	\N	\N	\N
170	AFCL	2001-10-03 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	92031P	\N	\N	2014-10-08 17:38:04
171	SOCI	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92023P	\N	\N	\N
172	AFCL	\N	1999-10-16 00:00:00	ANCIEN	\N	\N	\N	\N	83013L	\N	\N	\N
173	AFCL	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	85002R	\N	\N	\N
174	LOIS	2001-10-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92044U	\N	\N	\N
175	ETRD	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92037V	\N	\N	\N
176	ECON	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92042S	\N	\N	\N
177	LOIS	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83010H	\N	\N	\N
178	SOCI	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	\N	\N	\N
179	FINC	1996-02-07 00:00:00	1998-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	\N	\N	\N
180	ECON	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83054V	\N	\N	\N
181	ETRD	\N	2007-02-25 00:00:00	ANCIEN	\N	\N	\N	\N	92024Q	\N	\N	\N
182	FINC	1992-10-07 00:00:00	1998-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	92029V	\N	\N	\N
183	SOCI	\N	2000-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	95011X	\N	\N	\N
184	ETRD	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95056M	\N	\N	\N
185	ETRD	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86025D	\N	\N	\N
186	SOCI	\N	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	95026F	\N	\N	\N
187	ETRD	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86028G	\N	\N	\N
188	LOIS	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	93003P	\N	\N	\N
189	ETRD	1995-10-04 00:00:00	2001-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	95022B	\N	\N	\N
190	ETRD	1980-10-07 00:00:00	2002-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77009C	\N	\N	\N
191	AFCL	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95058P	\N	\N	\N
192	ETRD	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77046H	\N	\N	\N
193	SOCI	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77013X	\N	\N	\N
194	ECON	\N	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	95018F	\N	\N	\N
195	FINC	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92043T	\N	\N	\N
196	LOIS	\N	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	92017R	\N	\N	\N
197	ECON	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86004X	\N	\N	\N
198	ETRD	\N	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	84003N	\N	\N	\N
199	ECON	1995-10-04 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92021M	\N	\N	\N
201	SOCI	1992-10-07 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92027T	\N	\N	\N
202	ECON	\N	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	83017Q	\N	\N	\N
203	FINC	\N	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	81015E	\N	\N	\N
204	FINC	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83021L	\N	\N	\N
205	ECON	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92006N	\N	\N	\N
206	ETRD	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92013M	\N	\N	\N
207	ETRD	2001-10-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92020L	\N	\N	2017-09-24 12:39:59
208	ETRD	1989-10-05 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	83008P	\N	\N	\N
209	SOCI	\N	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	92036U	\N	\N	\N
210	SOCI	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92011K	\N	\N	\N
211	ECON	2001-10-03 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	95036H	\N	\N	\N
212	AFCL	1992-10-08 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	92005M	\N	\N	\N
213	LOIS	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77029G	\N	\N	\N
215	AFCL	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95029J	\N	\N	\N
217	SOCI	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95045J	\N	\N	\N
218	SOCI	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95017E	\N	\N	\N
219	FINC	1992-10-08 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86047K	\N	\N	\N
220	FINC	1986-10-06 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	86031B	\N	\N	\N
221	ETRD	\N	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	77047J	\N	\N	\N
222	AFCL	1995-10-04 00:00:00	1999-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	77066M	\N	\N	\N
223	FINC	\N	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	95049N	\N	\N	\N
224	SOCI	1997-07-03 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	\N	\N	2014-09-28 17:07:41
225	ECON	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95040D	\N	\N	\N
226	AFCL	\N	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	95041E	\N	\N	\N
227	ECON	2001-10-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95030B	\N	\N	\N
228	SOCI	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86043F	\N	\N	\N
229	LOIS	2001-01-24 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	95020Y	\N	\N	2015-06-12 16:01:25
230	FINC	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77012W	\N	\N	\N
231	FINC	1995-10-02 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77043E	\N	\N	2014-09-28 16:59:41
232	ECON	\N	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	95019G	\N	\N	\N
233	ECON	\N	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	95008D	\N	\N	\N
234	ECON	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77060F	\N	\N	\N
235	AFCL	2001-10-03 00:00:00	2018-08-06 00:00:00	ANCIEN	\N	\N	\N	\N	95015C	\N	\N	2017-10-04 19:41:55
236	ECON	2001-10-03 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	95038K	\N	\N	\N
237	LOIS	\N	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	95005A	\N	\N	\N
239	ECON	2001-10-03 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	95062K	\N	\N	\N
1631	LOIS	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58626R	\N	\N	\N
1632	ECON	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58924Y	\N	\N	\N
1217	FINC	\N	1981-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	59715V	\N	\N	\N
1219	LOIS	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000236	\N	\N	\N
1220	ECON	\N	1962-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	000498	\N	\N	\N
1221	SOCI	1960-10-06 00:00:00	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	57749X	\N	\N	\N
1222	ECON	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000227	\N	\N	\N
1224	ECON	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000136	\N	\N	\N
1225	LOIS	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000332	\N	\N	\N
1226	FINC	1959-05-06 00:00:00	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000080	\N	\N	\N
1227	SOCI	1968-10-04 00:00:00	1974-05-22 00:00:00	ANCIEN	\N	\N	\N	\N	000314	\N	\N	\N
1229	SOCI	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000179	\N	\N	\N
1230	SOCI	1959-05-06 00:00:00	1970-08-19 00:00:00	ANCIEN	\N	\N	\N	\N	000233	\N	\N	\N
1126	AFCL	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000105	\N	\N	\N
1131	AFCL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000255	\N	\N	\N
1136	ECON	\N	1971-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	000215	\N	\N	\N
1141	SOCI	\N	1962-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	56905M	\N	\N	\N
1146	LOIS	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000296	\N	\N	\N
1151	ECON	\N	1978-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	000306	\N	\N	\N
1213	ECON	\N	1969-03-20 00:00:00	ANCIEN	\N	\N	\N	\N	000017	\N	\N	\N
1218	ETRD	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	56406W	\N	\N	\N
1223	FINC	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	57456M	\N	\N	\N
1228	ECON	\N	1982-03-20 00:00:00	ANCIEN	\N	\N	\N	\N	000269	\N	\N	\N
1233	FINC	\N	1979-06-05 00:00:00	ANCIEN	\N	\N	\N	\N	000129	\N	\N	\N
1238	AFCL	\N	1962-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000065	\N	\N	\N
1243	LOIS	1959-05-06 00:00:00	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000069	\N	\N	\N
1305	NEANT	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000168	\N	\N	\N
1310	SOCI	1968-10-08 00:00:00	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000334	\N	\N	\N
1315	SOCI	\N	1978-10-13 00:00:00	ANCIEN	\N	\N	\N	\N	000006	\N	\N	\N
1320	FINC	\N	1983-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	000417	\N	\N	\N
1325	NEANT	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000311	\N	\N	\N
1330	ETRD	\N	1980-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	000354	\N	\N	\N
1335	ETRD	1975-10-09 00:00:00	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000246	\N	\N	\N
1397	AFCL	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000764	\N	\N	\N
1402	SOCI	1959-05-06 00:00:00	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000697	\N	\N	\N
1407	ECON	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000700	\N	\N	\N
1412	LOIS	\N	1964-08-07 00:00:00	ANCIEN	\N	\N	\N	\N	000737	\N	\N	\N
1417	SOCI	1959-05-06 00:00:00	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000706	\N	\N	\N
1422	ETRD	\N	1962-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	000708	\N	\N	\N
1427	AFCL	\N	1972-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	000771	\N	\N	\N
1492	FINC	1990-06-28 00:00:00	1998-02-25 00:00:00	ANCIEN	\N	\N	\N	\N	79005G	\N	\N	\N
1496	ETRD	1983-10-07 00:00:00	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000663	\N	\N	\N
1501	ETRD	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59213C	\N	\N	\N
1506	SOCI	1965-10-06 00:00:00	1970-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	000184	\N	\N	\N
1511	SOCI	\N	1996-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	92014N	\N	\N	\N
1516	ECON	1960-10-06 00:00:00	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58946F	\N	\N	\N
1521	ETRD	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59526S	\N	\N	\N
1585	AFCL	\N	1995-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	000533	\N	\N	\N
1590	ETRD	1980-10-07 00:00:00	1996-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	80020W	\N	\N	\N
1594	ETRD	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58656X	\N	\N	\N
1599	ETRD	1986-10-06 00:00:00	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59575C	\N	\N	\N
1604	LOIS	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59537V	\N	\N	\N
1609	AFCL	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59233G	\N	\N	\N
1614	FINC	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000185	\N	\N	\N
1678	ECON	1977-10-06 00:00:00	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58636T	\N	\N	\N
1683	ETRD	1971-10-05 00:00:00	1985-05-13 00:00:00	ANCIEN	\N	\N	\N	\N	000393	\N	\N	\N
1688	ETRD	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58628T	\N	\N	\N
1693	AFCL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000307	\N	\N	\N
1698	ETRD	1992-10-07 00:00:00	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000211	\N	\N	\N
1703	ETRD	1971-10-06 00:00:00	1974-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	59242H	\N	\N	\N
1708	SOCI	1972-05-09 00:00:00	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58918B	\N	\N	\N
1771	SOCI	\N	1986-07-16 00:00:00	ANCIEN	\N	\N	\N	\N	58613L	\N	\N	\N
1775	ECON	\N	1988-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	000621	\N	\N	\N
1780	SOCI	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59241G	\N	\N	\N
1785	ECON	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000190	\N	\N	\N
1803	ECON	2003-05-14 00:00:00	2007-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	98019U	\N	\N	\N
1804	ETRD	2003-05-14 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77047J	\N	\N	\N
726	AFCL	2001-10-03 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01062T	\N	\N	2017-10-04 19:14:51
727	ECON	2001-10-03 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98006P	\N	\N	\N
728	ECON	2001-10-03 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	01022K	\N	\N	\N
729	ECON	2001-10-03 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01004H	\N	\N	\N
730	ECON	2001-10-03 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	01014K	\N	\N	\N
731	ECON	2001-10-03 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89040Q	\N	\N	\N
732	ETRD	2001-10-03 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89019T	\N	\N	\N
734	ETRD	2001-10-03 00:00:00	2012-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01051Q	\N	\N	\N
733	AFCL	2001-10-03 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95026F	\N	\N	\N
736	ETRD	2001-10-03 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	83042R	\N	\N	\N
737	ETRD	2001-10-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01020H	\N	\N	\N
739	ETRD	2001-10-03 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	98010K	\N	\N	\N
738	AFCL	2001-10-03 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98028V	\N	\N	2014-09-28 17:22:11
740	AFCL	2001-10-03 00:00:00	2022-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	92040Q	\N	\N	2017-10-04 19:45:46
741	SOCI	2001-10-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01011G	\N	\N	2017-09-24 16:43:42
742	SOCI	2001-10-03 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	83039W	\N	\N	\N
743	SOCI	2001-10-03 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	80039J	\N	\N	\N
744	SOCI	2001-10-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01036R	\N	\N	\N
745	SOCI	2001-10-03 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	01023L	\N	\N	\N
747	FINC	2001-10-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98011L	\N	\N	\N
748	ECON	2001-10-03 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	\N	\N	\N
749	FINC	2001-10-03 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	98046X	\N	\N	2017-09-25 09:56:00
750	LOIS	2001-10-03 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	\N	\N	\N
751	LOIS	2001-10-03 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77017C	\N	\N	\N
752	LOIS	2001-10-03 00:00:00	2008-09-07 00:00:00	ANCIEN	\N	\N	\N	\N	80017C	\N	\N	\N
753	LOIS	2001-10-03 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	01037S	\N	\N	\N
754	LOIS	2001-10-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01053S	\N	\N	\N
755	LOIS	2001-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	\N	\N	2017-10-04 00:00:00
756	SOCI	2001-10-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01045S	\N	\N	\N
757	ECON	2001-10-03 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	95021A	\N	\N	\N
758	ETRD	2001-10-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01005J	\N	\N	\N
763	ECON	2001-10-03 00:00:00	2004-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	01013J	\N	\N	\N
1350	ECON	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000056	\N	\N	\N
1351	AFCL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000388	\N	\N	\N
1352	ETRD	1968-10-04 00:00:00	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000309	\N	\N	\N
1353	SOCI	1959-05-06 00:00:00	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000110	\N	\N	\N
1354	ETRD	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000072	\N	\N	\N
1355	AFCL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000133	\N	\N	\N
1356	AFCL	\N	1976-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	000325	\N	\N	\N
1357	LOIS	1959-05-06 00:00:00	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000088	\N	\N	\N
1358	LOIS	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000119	\N	\N	\N
1359	AFCL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000178	\N	\N	\N
1360	AFCL	\N	1979-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	000007	\N	\N	\N
1361	FINC	1959-05-06 00:00:00	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000044	\N	\N	\N
1362	ETRD	\N	1961-07-18 00:00:00	ANCIEN	\N	\N	\N	\N	000300	\N	\N	\N
1363	FINC	\N	1970-06-13 00:00:00	ANCIEN	\N	\N	\N	\N	000015	\N	\N	\N
1364	LOIS	1960-10-06 00:00:00	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000703	\N	\N	\N
1365	FINC	1959-05-06 00:00:00	1967-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	000724	\N	\N	\N
1366	ECON	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000689	\N	\N	\N
1367	ETRD	1959-05-06 00:00:00	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000757	\N	\N	\N
1368	LOIS	\N	1966-12-22 00:00:00	ANCIEN	\N	\N	\N	\N	000733	\N	\N	\N
1369	ECON	1959-05-06 00:00:00	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000731	\N	\N	\N
1370	ETRD	\N	1959-08-28 00:00:00	ANCIEN	\N	\N	\N	\N	000759	\N	\N	\N
1371	ECON	1959-05-06 00:00:00	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000701	\N	\N	\N
1372	ETRD	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000711	\N	\N	\N
1373	AFCL	\N	1970-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	000682	\N	\N	\N
1374	AFCL	\N	1961-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	000761	\N	\N	\N
1375	LOIS	1959-05-06 00:00:00	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000696	\N	\N	\N
1376	ECON	\N	1965-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	000718	\N	\N	\N
1377	ECON	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000690	\N	\N	\N
1378	ETRD	\N	1962-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	000756	\N	\N	\N
1379	FINC	1962-10-05 00:00:00	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000760	\N	\N	\N
1380	AFCL	\N	1979-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	000735	\N	\N	\N
1381	SOCI	\N	1966-05-26 00:00:00	ANCIEN	\N	\N	\N	\N	000755	\N	\N	\N
1384	FINC	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000715	\N	\N	\N
1385	ETRD	1959-05-06 00:00:00	1966-03-09 00:00:00	ANCIEN	\N	\N	\N	\N	000726	\N	\N	\N
1386	AFCL	1959-05-06 00:00:00	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000763	\N	\N	\N
1387	FINC	1959-05-06 00:00:00	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000702	\N	\N	\N
1388	AFCL	\N	1976-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	000769	\N	\N	\N
1389	SOCI	1961-10-03 00:00:00	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000683	\N	\N	\N
1390	SOCI	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000709	\N	\N	\N
1391	ECON	\N	1969-01-11 00:00:00	ANCIEN	\N	\N	\N	\N	000744	\N	\N	\N
1393	FINC	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000728	\N	\N	\N
1394	FINC	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000713	\N	\N	\N
1395	ETRD	\N	1975-04-25 00:00:00	ANCIEN	\N	\N	\N	\N	000681	\N	\N	\N
1396	ECON	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000687	\N	\N	\N
1398	ECON	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000699	\N	\N	\N
1399	LOIS	1973-06-14 00:00:00	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000720	\N	\N	\N
1400	LOIS	1965-10-05 00:00:00	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000719	\N	\N	\N
1401	SOCI	\N	1968-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	000678	\N	\N	\N
1404	AFCL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000766	\N	\N	\N
1405	ECON	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000675	\N	\N	\N
1406	ETRD	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000753	\N	\N	\N
1408	ETRD	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000765	\N	\N	\N
1409	SOCI	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000721	\N	\N	\N
1410	AFCL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000732	\N	\N	\N
1411	ECON	\N	1970-10-24 00:00:00	ANCIEN	\N	\N	\N	\N	000680	\N	\N	\N
1413	FINC	\N	1976-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	000727	\N	\N	\N
1414	AFCL	1977-10-06 00:00:00	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000686	\N	\N	\N
1415	SOCI	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000670	\N	\N	\N
1416	ECON	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000758	\N	\N	\N
1418	SOCI	1959-05-06 00:00:00	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000679	\N	\N	\N
1419	ECON	\N	1971-10-28 00:00:00	ANCIEN	\N	\N	\N	\N	000693	\N	\N	\N
1420	ETRD	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000707	\N	\N	\N
1421	SOCI	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000710	\N	\N	\N
1423	SOCI	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000762	\N	\N	\N
1424	AFCL	\N	1961-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	000742	\N	\N	\N
1425	FINC	\N	1968-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	000746	\N	\N	\N
1426	NEANT	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000738	\N	\N	\N
1428	AFCL	\N	1963-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	000767	\N	\N	\N
1429	SOCI	1960-10-06 00:00:00	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000751	\N	\N	\N
1430	AFCL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000671	\N	\N	\N
1431	FINC	\N	1974-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	000677	\N	\N	\N
1432	ETRD	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000691	\N	\N	\N
1433	ETRD	1959-05-06 00:00:00	1968-10-29 00:00:00	ANCIEN	\N	\N	\N	\N	000736	\N	\N	\N
1434	ETRD	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000712	\N	\N	\N
1435	ETRD	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000688	\N	\N	\N
1436	AFCL	\N	1965-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	000725	\N	\N	\N
1437	ECON	1959-05-06 00:00:00	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000748	\N	\N	\N
1438	FINC	1959-05-06 00:00:00	1972-10-19 00:00:00	ANCIEN	\N	\N	\N	\N	000734	\N	\N	\N
1439	ECON	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000714	\N	\N	\N
1440	AFCL	1962-10-05 00:00:00	1968-09-19 00:00:00	ANCIEN	\N	\N	\N	\N	000694	\N	\N	\N
1441	ETRD	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000739	\N	\N	\N
1442	AFCL	\N	1979-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	000747	\N	\N	\N
1443	ECON	\N	1961-08-22 00:00:00	ANCIEN	\N	\N	\N	\N	000730	\N	\N	\N
1444	SOCI	1959-05-06 00:00:00	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000698	\N	\N	\N
1445	FINC	1959-05-06 00:00:00	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000672	\N	\N	\N
1446	LOIS	1959-05-06 00:00:00	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000772	\N	\N	\N
1447	ECON	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000741	\N	\N	\N
1448	FINC	1971-10-06 00:00:00	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000752	\N	\N	\N
1449	LOIS	1959-05-06 00:00:00	1965-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	000743	\N	\N	\N
1450	ECON	1959-05-06 00:00:00	1971-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	000750	\N	\N	\N
1451	ETRD	1959-05-06 00:00:00	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000704	\N	\N	\N
1453	AFCL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000754	\N	\N	\N
1454	SOCI	1959-05-06 00:00:00	1966-04-24 00:00:00	ANCIEN	\N	\N	\N	\N	000768	\N	\N	\N
1455	ECON	\N	1973-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	000749	\N	\N	\N
1456	FINC	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000673	\N	\N	\N
1457	ECON	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000745	\N	\N	\N
1458	SOCI	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000716	\N	\N	\N
1459	AFCL	\N	1968-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	000692	\N	\N	\N
1460	ECON	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000717	\N	\N	\N
1461	AFCL	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000674	\N	\N	\N
1462	AFCL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000684	\N	\N	\N
1463	SOCI	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000770	\N	\N	\N
1464	AFCL	\N	1962-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000676	\N	\N	\N
1465	NEANT	\N	1966-06-02 00:00:00	ANCIEN	\N	\N	\N	\N	000668	\N	\N	\N
1466	ECON	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000669	\N	\N	\N
1467	FINC	\N	1959-04-29 00:00:00	ANCIEN	\N	\N	\N	\N	000740	\N	\N	\N
1469	ECON	\N	1997-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	95010W	\N	\N	\N
1470	AFCL	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	58328J	\N	\N	\N
1471	AFCL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59567C	\N	\N	\N
1472	SOCI	1986-10-07 00:00:00	1993-08-27 00:00:00	ANCIEN	\N	\N	\N	\N	000634	\N	\N	\N
1473	AFCL	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59218H	\N	\N	\N
1474	FINC	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58920U	\N	\N	\N
1999	20031016N9	2003-10-16 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	95020Y	TITULAIRE	\N	2015-06-12 16:01:25
2000	20031016N9	2003-10-16 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	TITULAIRE	\N	2014-09-28 18:00:58
2001	20031016N9	2003-10-16 00:00:00	2015-04-21 00:00:00	ANCIEN	\N	\N	\N	\N	01042P	TITULAIRE	\N	2015-04-21 17:14:30
2002	20031016N9	2003-10-16 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	92022N	TITULAIRE	\N	\N
2003	20031016N9	2003-10-16 00:00:00	2008-09-07 00:00:00	ANCIEN	\N	\N	\N	\N	80017C	TITULAIRE	\N	\N
2004	20031016N9	2003-10-16 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98016R	TITULAIRE	\N	\N
2005	20031016N9	2003-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	SUPPLEANT	\N	2017-09-24 18:20:10
2006	20031016N9	2003-10-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01001E	SUPPLEANT	\N	\N
2007	20031016N9	2003-10-16 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	01063U	SUPPLEANT	\N	2014-09-29 13:41:53
2008	20031016N9	2003-10-16 00:00:00	2015-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	SUPPLEANT	\N	2015-10-12 09:39:30
2009	20031016N9	2003-10-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95046K	SUPPLEANT	\N	\N
2010	20031016N9	2003-10-16 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89035T	SUPPLEANT	\N	\N
2013	ECON	2003-11-05 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98039Y	\N	\N	\N
2014	LOIS	2003-11-05 00:00:00	2004-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	01060R	\N	\N	2017-10-24 16:16:13
2017	NEANT	2003-11-05 00:00:00	2003-11-13 00:00:00	ANCIEN	\N	\N	\N	\N	03003Q	\N	\N	\N
2018	FINC	1959-05-12 00:00:00	1972-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	000235	\N	\N	\N
2020	ECON	1971-10-06 00:00:00	1983-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	59549A	\N	\N	\N
2021	ETRD	1959-05-12 00:00:00	1962-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	000144	\N	\N	\N
2022	SOCI	1962-10-05 00:00:00	1965-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	000144	\N	\N	\N
2023	ETRD	1965-10-05 00:00:00	1974-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	000144	\N	\N	\N
2024	ETRD	1968-10-08 00:00:00	1976-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	59560U	\N	\N	\N
2025	ETRD	1974-10-04 00:00:00	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000355	\N	\N	\N
2026	ETRD	1972-11-16 00:00:00	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000052	\N	\N	\N
2027	ETRD	2003-11-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98040R	\N	\N	\N
2028	LOIS	2003-11-14 00:00:00	2007-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	01057W	\N	\N	\N
2029	ECON	2003-11-14 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	03003Q	\N	\N	\N
2030	ETRD	1974-10-04 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	71017B	\N	\N	\N
2031	AFCL	1959-05-12 00:00:00	1962-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	000008	\N	\N	\N
2032	FINC	1959-05-12 00:00:00	1960-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	57749X	\N	\N	\N
2033	ECON	1962-10-05 00:00:00	1968-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	58036Y	\N	\N	\N
2034	LOIS	1969-05-16 00:00:00	1971-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	000752	\N	\N	\N
2035	ECON	1959-05-12 00:00:00	1968-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	000201	\N	\N	\N
2036	LOIS	1972-09-15 00:00:00	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000098	\N	\N	\N
2037	LOIS	1959-05-12 00:00:00	1962-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	000272	\N	\N	\N
1731	AFCL	1977-10-06 00:00:00	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	58336J	\N	\N	\N
2039	AFCL	1977-10-06 00:00:00	1986-04-20 00:00:00	ANCIEN	\N	\N	\N	\N	77053G	\N	\N	\N
2044	ECON	1977-10-06 00:00:00	1978-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	58630M	\N	\N	\N
2041	ECON	1970-10-07 00:00:00	1974-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	000184	\N	\N	\N
2042	LOIS	1974-10-04 00:00:00	1977-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	000184	\N	\N	\N
2043	AFCL	1977-10-06 00:00:00	1980-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	000184	\N	\N	\N
2045	SOCI	1971-10-06 00:00:00	1986-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	59307H	\N	\N	\N
2046	ETRD	1968-10-08 00:00:00	1969-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	000536	\N	\N	\N
2047	SOCI	1969-10-08 00:00:00	1973-04-02 00:00:00	ANCIEN	\N	\N	\N	\N	000536	\N	\N	\N
2048	LOIS	1959-10-06 00:00:00	1962-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	000158	\N	\N	\N
2049	ETRD	1964-10-03 00:00:00	1965-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	000158	\N	\N	\N
1292	FINC	1962-10-06 00:00:00	1963-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	000158	\N	\N	\N
1617	FINC	1974-10-04 00:00:00	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	58348N	\N	\N	\N
2051	LOIS	1977-10-06 00:00:00	1977-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	000308	\N	\N	\N
2052	LOIS	1975-05-21 00:00:00	1977-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	58633Q	\N	\N	\N
2053	ETRD	1977-10-03 00:00:00	1993-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	000442	\N	\N	\N
2054	ECON	1973-05-17 00:00:00	1974-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	000405	\N	\N	\N
2055	SOCI	1974-10-04 00:00:00	1982-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	000405	\N	\N	\N
1564	ECON	1978-10-01 00:00:00	1984-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	58420D	\N	\N	\N
2056	SOCI	1980-10-07 00:00:00	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000184	\N	\N	\N
2057	AFCL	1980-10-07 00:00:00	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000337	\N	\N	\N
1520	AFCL	1968-10-08 00:00:00	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59525R	\N	\N	\N
1645	SOCI	1977-10-06 00:00:00	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59546W	\N	\N	\N
2058	ECON	1979-04-02 00:00:00	1979-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	79002D	\N	\N	\N
2062	ETRD	1959-05-12 00:00:00	1960-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	000720	\N	\N	\N
2063	AFCL	1960-10-04 00:00:00	1973-06-14 00:00:00	ANCIEN	\N	\N	\N	\N	000720	\N	\N	\N
2064	LOIS	1969-10-08 00:00:00	1983-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	000326	\N	\N	\N
2065	SOCI	1974-10-14 00:00:00	1977-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	58419L	\N	\N	\N
1537	ECON	1968-10-08 00:00:00	1971-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	58805S	\N	\N	\N
2066	ETRD	1971-10-06 00:00:00	1974-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	58805S	\N	\N	\N
2067	ECON	1974-10-04 00:00:00	1988-05-13 00:00:00	ANCIEN	\N	\N	\N	\N	58805S	\N	\N	\N
2069	LOIS	1981-07-29 00:00:00	1982-04-02 00:00:00	ANCIEN	\N	\N	\N	\N	58631N	\N	\N	\N
2070	SOCI	1982-04-02 00:00:00	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58631N	\N	\N	\N
2071	ECON	1971-10-06 00:00:00	1974-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	71009B	\N	\N	\N
2072	ECON	1959-05-12 00:00:00	1965-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	55510R	\N	\N	\N
2073	LOIS	1965-10-06 00:00:00	1968-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	55510R	\N	\N	\N
2074	AFCL	1960-10-06 00:00:00	1973-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	000095	\N	\N	\N
2075	LOIS	1973-10-11 00:00:00	1986-06-23 00:00:00	ANCIEN	\N	\N	\N	\N	000095	\N	\N	\N
2077	ETRD	1974-10-04 00:00:00	1975-12-05 00:00:00	ANCIEN	\N	\N	\N	\N	59582B	\N	\N	\N
1759	AFCL	1975-12-05 00:00:00	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59582B	\N	\N	\N
2078	LOIS	1965-10-06 00:00:00	1967-04-03 00:00:00	ANCIEN	\N	\N	\N	\N	57714L	\N	\N	\N
2079	AFCL	1983-10-06 00:00:00	1986-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	57714L	\N	\N	\N
2080	20031119N10	2003-11-19 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	95004Y	TITULAIRE	\N	\N
2081	20031119N10	2003-11-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	TITULAIRE	\N	\N
2082	20031119N10	2003-11-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92030N	TITULAIRE	\N	\N
2083	20031119N10	2003-11-19 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95045J	TITULAIRE	\N	\N
2084	20031119N10	2003-11-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	78006D	TITULAIRE	\N	\N
2085	20031119N10	2003-11-19 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95017E	TITULAIRE	\N	\N
2086	20031119N10	2003-11-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	TITULAIRE	\N	2014-09-28 17:07:41
2087	20031119N10	2003-11-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	SUPPLEANT	\N	2017-09-24 13:44:49
2088	20031119N10	2003-11-19 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98029W	SUPPLEANT	\N	\N
2089	20031119N10	2003-11-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92018S	SUPPLEANT	\N	2017-09-24 18:16:52
2090	20031119N10	2003-11-19 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98024R	SUPPLEANT	\N	\N
2091	20031119N10	2003-11-19 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98045W	SUPPLEANT	\N	\N
2092	20031119N10	2003-11-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01033N	SUPPLEANT	\N	\N
2093	20031119N10	2003-11-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01018P	SUPPLEANT	\N	\N
2094	FINC	1974-10-04 00:00:00	1977-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	74044S	\N	\N	\N
2095	ECON	1977-10-06 00:00:00	1983-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	74044S	\N	\N	\N
2096	FINC	1983-10-05 00:00:00	1986-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	74044S	\N	\N	\N
2097	AFCL	1986-10-06 00:00:00	1995-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	74044S	\N	\N	\N
2098	ETRD	1959-05-12 00:00:00	1966-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	000197	\N	\N	\N
2099	LOIS	1980-10-07 00:00:00	1986-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	000197	\N	\N	\N
1530	ETRD	1986-10-06 00:00:00	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59221C	\N	\N	\N
2104	NEANT	1966-10-05 00:00:00	1974-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	000355	\N	\N	\N
2105	ETRD	1983-10-06 00:00:00	1992-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	83020K	\N	\N	\N
2106	ECON	1981-10-16 00:00:00	1983-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	81014D	\N	\N	\N
2107	SOCI	1983-10-07 00:00:00	1989-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	81014D	\N	\N	\N
2108	AFCL	1983-10-06 00:00:00	1985-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	83028T	\N	\N	\N
1476	FINC	1959-05-12 00:00:00	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58619S	\N	\N	\N
2109	AFCL	1971-10-06 00:00:00	1972-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	58923X	\N	\N	\N
2111	AFCL	1986-10-06 00:00:00	1992-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	59566B	\N	\N	\N
2112	ECON	1979-10-02 00:00:00	1980-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	79005G	\N	\N	\N
2113	AFCL	1980-10-07 00:00:00	1981-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	79005G	\N	\N	\N
2114	ECON	1981-07-08 00:00:00	1990-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	79005G	\N	\N	\N
2115	ECON	1983-10-07 00:00:00	1989-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	83008P	\N	\N	\N
2116	AFCL	1980-10-07 00:00:00	1986-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	000634	\N	\N	\N
119	SOCI	1986-10-09 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	86005Y	\N	\N	\N
2117	ECON	1971-10-06 00:00:00	1981-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	000514	\N	\N	\N
2118	FINC	1986-10-06 00:00:00	1992-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	59527T	\N	\N	\N
2119	AFCL	1962-10-05 00:00:00	1972-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	62001R	\N	\N	\N
2120	SOCI	1965-10-06 00:00:00	1979-10-23 00:00:00	ANCIEN	\N	\N	\N	\N	000524	\N	\N	\N
2121	NEANT	1968-10-02 00:00:00	1992-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000211	\N	\N	\N
2122	LOIS	1992-10-07 00:00:00	1995-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	83020K	\N	\N	\N
2123	ECON	1986-10-06 00:00:00	1990-10-30 00:00:00	ANCIEN	\N	\N	\N	\N	59583C	\N	\N	\N
2125	AFCL	1977-10-06 00:00:00	1978-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	77066M	\N	\N	\N
2126	LOIS	1978-10-18 00:00:00	1983-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	77066M	\N	\N	\N
2127	AFCL	1983-10-06 00:00:00	1986-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	77066M	\N	\N	\N
2128	SOCI	1986-10-06 00:00:00	1995-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	77066M	\N	\N	\N
1534	AFCL	1992-10-07 00:00:00	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59527T	\N	\N	\N
2129	ECON	1982-01-21 00:00:00	1986-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	000456	\N	\N	\N
1628	LOIS	1986-10-06 00:00:00	1994-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	000456	\N	\N	\N
2130	ECON	1977-10-06 00:00:00	1983-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	59568D	\N	\N	\N
2131	AFCL	1983-10-06 00:00:00	1990-01-14 00:00:00	ANCIEN	\N	\N	\N	\N	000326	\N	\N	\N
2132	ECON	1992-10-08 00:00:00	1995-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	83026R	\N	\N	\N
2133	AFCL	1995-10-04 00:00:00	1998-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	83026R	\N	\N	\N
2134	SOCI	1986-10-06 00:00:00	1988-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	86039K	\N	\N	\N
2135	AFCL	1988-06-29 00:00:00	1989-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	86039K	\N	\N	\N
2136	ECON	1980-10-07 00:00:00	1986-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	80036F	\N	\N	\N
2137	ECON	1988-11-15 00:00:00	1989-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	88006J	\N	\N	\N
155	LOIS	1983-10-06 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	83052T	\N	\N	\N
2138	ECON	1983-10-05 00:00:00	1986-04-09 00:00:00	ANCIEN	\N	\N	\N	\N	83043S	\N	\N	\N
2139	NEANT	1995-10-02 00:00:00	1995-10-31 00:00:00	ANCIEN	\N	\N	\N	\N	95059Q	\N	\N	\N
2140	SOCI	1992-10-07 00:00:00	1995-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	92021M	\N	\N	\N
2141	AFCL	1983-10-06 00:00:00	1986-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	83023N	\N	\N	\N
126	ETRD	1986-10-06 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83023N	\N	\N	\N
2142	AFCL	1977-10-06 00:00:00	1980-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	77009C	\N	\N	\N
2143	ETRD	1981-10-08 00:00:00	1986-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	81007E	\N	\N	\N
2145	20031209N11	2003-12-09 00:00:00	2014-07-01 00:00:00	ANCIEN	\N	\N	\N	\N	83011J	TITULAIRE	\N	2014-07-01 09:25:11
2146	20031209N11	2003-12-09 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
2147	20031209N11	2003-12-09 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77043E	TITULAIRE	\N	2014-09-28 16:59:41
2148	20031209N11	2003-12-09 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86041D	TITULAIRE	\N	\N
2149	20031209N11	2003-12-09 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	98032R	TITULAIRE	\N	2015-06-12 15:59:49
2150	20031209N11	2003-12-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92039X	TITULAIRE	\N	2017-09-24 13:47:46
2151	20031209N11	2003-12-09 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	79004F	TITULAIRE	\N	\N
2152	20031209N11	2003-12-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89017R	SUPPLEANT	\N	\N
2153	20031209N11	2003-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95007C	SUPPLEANT	\N	\N
2154	20031209N11	2003-12-09 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	94003T	SUPPLEANT	\N	2014-09-28 13:16:32
2155	20031209N11	2003-12-09 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	78003A	SUPPLEANT	\N	\N
2156	20031209N11	2003-12-09 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95042F	SUPPLEANT	\N	\N
2157	20031209N11	2003-12-09 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	98046X	SUPPLEANT	\N	2017-09-25 09:56:00
2158	20031209N11	2003-12-09 00:00:00	2013-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	95003X	SUPPLEANT	\N	\N
2159	20031217N12	2003-12-16 00:00:00	2014-07-01 00:00:00	ANCIEN	\N	\N	\N	\N	83011J	TITULAIRE	\N	2014-07-01 09:25:11
2160	20031217N12	2003-12-16 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
2161	20031217N12	2003-12-16 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77043E	TITULAIRE	\N	2014-09-28 16:59:41
2162	20031217N12	2003-12-16 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86041D	TITULAIRE	\N	\N
2164	20031217N12	2003-12-16 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	81015E	TITULAIRE	\N	\N
2165	20031217N12	2003-12-16 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	79004F	TITULAIRE	\N	\N
2166	20031217N12	2003-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95007C	SUPPLEANT	\N	\N
2167	20031217N12	2003-12-16 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89022N	SUPPLEANT	\N	2014-09-28 18:19:47
2168	20031217N12	2003-12-16 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	94003T	SUPPLEANT	\N	2014-09-28 13:16:32
2169	20031217N12	2003-12-16 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	78003A	SUPPLEANT	\N	\N
2170	20031217N12	2003-12-16 00:00:00	2013-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	95003X	SUPPLEANT	\N	\N
2171	20031217N12	2003-12-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92039X	SUPPLEANT	\N	2017-09-24 13:47:46
2172	20031217N12	2003-12-16 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	91002E	SUPPLEANT	\N	\N
2173	ETRD	2004-03-02 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	03004R	\N	\N	\N
2174	20040115N1	2004-01-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98041S	TITULAIRE	\N	2014-09-28 16:42:05
2175	20040115N1	2004-01-15 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	88013H	TITULAIRE	\N	\N
2176	20040115N1	2004-01-15 00:00:00	2014-09-16 00:00:00	ANCIEN	\N	\N	\N	\N	98052V	TITULAIRE	\N	2014-09-16 14:55:28
2177	20040115N1	2004-01-15 00:00:00	2015-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-12 09:39:30
1073	SOCI	\N	1962-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	000292	\N	\N	\N
1074	LOIS	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000295	\N	\N	\N
1075	FINC	\N	1959-07-14 00:00:00	ANCIEN	\N	\N	\N	\N	000140	\N	\N	\N
1076	SOCI	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000039	\N	\N	\N
1077	ECON	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000020	\N	\N	\N
1078	LOIS	\N	1977-09-25 00:00:00	ANCIEN	\N	\N	\N	\N	000365	\N	\N	\N
1079	FINC	1968-10-08 00:00:00	1976-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	000574	\N	\N	\N
1080	SOCI	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000053	\N	\N	\N
1081	ETRD	1964-10-07 00:00:00	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000035	\N	\N	\N
1082	AFCL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000049	\N	\N	\N
1083	LOIS	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	57432D	\N	\N	\N
1084	ECON	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000010	\N	\N	\N
1085	SOCI	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000150	\N	\N	\N
1086	NEANT	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	58366Q	\N	\N	\N
1087	ETRD	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000076	\N	\N	\N
1088	ETRD	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000003	\N	\N	\N
1089	SOCI	1968-10-08 00:00:00	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000350	\N	\N	\N
1090	SOCI	\N	1974-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	58202U	\N	\N	\N
1091	AFCL	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000257	\N	\N	\N
1092	ETRD	\N	1974-08-26 00:00:00	ANCIEN	\N	\N	\N	\N	000111	\N	\N	\N
1093	LOIS	1959-05-06 00:00:00	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000061	\N	\N	\N
1094	ECON	\N	1967-03-08 00:00:00	ANCIEN	\N	\N	\N	\N	000038	\N	\N	\N
1095	AFCL	\N	1965-08-19 00:00:00	ANCIEN	\N	\N	\N	\N	000191	\N	\N	\N
1096	ECON	1970-10-07 00:00:00	1979-06-11 00:00:00	ANCIEN	\N	\N	\N	\N	000439	\N	\N	\N
1097	ECON	\N	1972-09-14 00:00:00	ANCIEN	\N	\N	\N	\N	000222	\N	\N	\N
1098	SOCI	\N	1962-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	58113U	\N	\N	\N
1099	ETRD	1959-05-06 00:00:00	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	57434F	\N	\N	\N
1100	AFCL	\N	1981-04-23 00:00:00	ANCIEN	\N	\N	\N	\N	000195	\N	\N	\N
1101	ECON	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	56819Q	\N	\N	\N
1102	SOCI	\N	1967-08-03 00:00:00	ANCIEN	\N	\N	\N	\N	000060	\N	\N	\N
1103	ETRD	1972-10-17 00:00:00	1978-08-29 00:00:00	ANCIEN	\N	\N	\N	\N	000235	\N	\N	\N
1104	AFCL	\N	1976-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	000494	\N	\N	\N
1105	AFCL	\N	1962-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	57710G	\N	\N	\N
1106	ECON	1959-05-06 00:00:00	1968-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	000073	\N	\N	\N
1107	ECON	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000192	\N	\N	\N
1108	SOCI	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000121	\N	\N	\N
1109	FINC	\N	1974-09-20 00:00:00	ANCIEN	\N	\N	\N	\N	000205	\N	\N	\N
1110	AFCL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000359	\N	\N	\N
1111	ECON	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000173	\N	\N	\N
1112	LOIS	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000416	\N	\N	\N
1113	AFCL	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58019X	\N	\N	\N
1114	ECON	\N	1978-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	57826T	\N	\N	\N
1115	ECON	\N	1979-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	000031	\N	\N	\N
1116	ETRD	\N	1974-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	000194	\N	\N	\N
1117	ETRD	\N	1962-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	000250	\N	\N	\N
1118	LOIS	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000245	\N	\N	\N
1119	ECON	\N	1974-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	000066	\N	\N	\N
1120	LOIS	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000199	\N	\N	\N
1122	AFCL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000180	\N	\N	\N
1123	ECON	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000084	\N	\N	\N
1124	ETRD	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58043X	\N	\N	\N
1125	FINC	1959-05-05 00:00:00	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000220	\N	\N	\N
1127	FINC	1968-10-04 00:00:00	1973-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	000011	\N	\N	\N
1128	AFCL	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000009	\N	\N	\N
1129	ETRD	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000511	\N	\N	\N
1130	AFCL	\N	1983-03-28 00:00:00	ANCIEN	\N	\N	\N	\N	000041	\N	\N	\N
1132	SOCI	\N	1981-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	59509R	\N	\N	\N
1133	SOCI	\N	1967-05-11 00:00:00	ANCIEN	\N	\N	\N	\N	000134	\N	\N	\N
1134	AFCL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000082	\N	\N	\N
1135	AFCL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	57721K	\N	\N	\N
1137	AFCL	\N	1962-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000057	\N	\N	\N
1138	LOIS	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000380	\N	\N	\N
1139	LOIS	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	57613G	\N	\N	\N
1140	AFCL	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000075	\N	\N	\N
1142	ECON	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000135	\N	\N	\N
1143	FINC	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000043	\N	\N	\N
1144	AFCL	1962-10-04 00:00:00	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000046	\N	\N	\N
1145	AFCL	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58021R	\N	\N	\N
1147	LOIS	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000139	\N	\N	\N
1148	SOCI	\N	1980-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	000455	\N	\N	\N
1149	AFCL	\N	1962-10-31 00:00:00	ANCIEN	\N	\N	\N	\N	56601X	\N	\N	\N
1150	LOIS	\N	1972-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	000131	\N	\N	\N
1152	FINC	1973-04-02 00:00:00	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000536	\N	\N	\N
1153	SOCI	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000137	\N	\N	\N
1154	SOCI	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000071	\N	\N	\N
1156	AFCL	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000210	\N	\N	\N
1157	ETRD	\N	1978-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	58673Y	\N	\N	\N
1158	SOCI	1959-05-06 00:00:00	1978-05-08 00:00:00	ANCIEN	\N	\N	\N	\N	000097	\N	\N	\N
1159	ETRD	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	57445J	\N	\N	\N
1160	AFCL	\N	1982-10-22 00:00:00	ANCIEN	\N	\N	\N	\N	000226	\N	\N	\N
1161	SOCI	1974-10-04 00:00:00	1977-03-04 00:00:00	ANCIEN	\N	\N	\N	\N	000067	\N	\N	\N
1162	SOCI	\N	1977-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	000224	\N	\N	\N
1163	ECON	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	56531B	\N	\N	\N
1165	ETRD	\N	1967-04-03 00:00:00	ANCIEN	\N	\N	\N	\N	000216	\N	\N	\N
1166	SOCI	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000459	\N	\N	\N
1167	ETRD	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000092	\N	\N	\N
1168	AFCL	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000162	\N	\N	\N
1169	ECON	\N	1971-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	000271	\N	\N	\N
1170	SOCI	\N	1978-08-27 00:00:00	ANCIEN	\N	\N	\N	\N	000602	\N	\N	\N
1171	ECON	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000218	\N	\N	\N
1172	LOIS	1965-10-05 00:00:00	1981-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	000186	\N	\N	\N
1173	LOIS	1971-10-05 00:00:00	1978-06-09 00:00:00	ANCIEN	\N	\N	\N	\N	000406	\N	\N	\N
1174	FINC	\N	1981-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	000243	\N	\N	\N
1175	LOIS	\N	1965-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	000040	\N	\N	\N
1176	ECON	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000273	\N	\N	\N
1177	FINC	1977-12-15 00:00:00	1983-04-18 00:00:00	ANCIEN	\N	\N	\N	\N	000308	\N	\N	\N
1178	ETRD	\N	1975-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	000403	\N	\N	\N
1179	ECON	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000171	\N	\N	\N
1180	LOIS	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58039C	\N	\N	\N
1181	LOIS	1959-05-12 00:00:00	1983-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	58303Y	\N	\N	\N
1182	ECON	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000225	\N	\N	\N
1183	AFCL	1959-05-06 00:00:00	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	57208W	\N	\N	\N
1184	ETRD	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000348	\N	\N	\N
1185	SOCI	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	56405V	\N	\N	\N
1186	ECON	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000149	\N	\N	\N
1187	ETRD	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000213	\N	\N	\N
1188	LOIS	\N	1962-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	000124	\N	\N	\N
1189	LOIS	1959-05-06 00:00:00	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000068	\N	\N	\N
1190	SOCI	\N	1980-07-28 00:00:00	ANCIEN	\N	\N	\N	\N	000458	\N	\N	\N
463	AFCL	1998-10-20 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	77019E	\N	\N	\N
464	NEANT	\N	1998-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	98054X	\N	\N	\N
465	AFCL	1998-11-03 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77028F	\N	\N	\N
466	ETRD	1998-11-03 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	68036E	\N	\N	\N
467	SOCI	1998-11-16 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98054X	\N	\N	\N
633	CORSE	2001-06-19 00:00:00	2001-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	78006D	\N	\N	\N
468	FINC	1998-10-07 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	\N	\N	2014-10-08 17:34:16
469	FINC	1998-10-07 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	92029V	\N	\N	\N
470	SOCI	1999-01-21 00:00:00	1999-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	98039Y	\N	\N	\N
471	LOIS	1999-01-21 00:00:00	1999-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	92033R	\N	\N	\N
473	SOCI	1999-02-17 00:00:00	1999-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	92033R	\N	\N	\N
474	LOIS	1999-02-17 00:00:00	2003-11-05 00:00:00	ANCIEN	\N	\N	\N	\N	98039Y	\N	\N	\N
475	ETRD	1999-10-05 00:00:00	2000-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	95050F	\N	\N	\N
476	LOIS	1999-10-05 00:00:00	2000-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	92033R	\N	\N	\N
477	ECON	1999-10-12 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	74019R	\N	\N	\N
478	LOIS	1999-10-12 00:00:00	2000-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	98007Q	\N	\N	\N
479	AFCL	1999-11-09 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	99001N	\N	\N	\N
480	AFCL	1999-11-04 00:00:00	2009-11-24 00:00:00	ANCIEN	\N	\N	\N	\N	99002P	\N	\N	\N
481	ECON	\N	1997-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	\N	\N	\N
482	SOCI	1999-11-17 00:00:00	2000-03-28 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	\N	\N	\N
483	ECON	2000-01-20 00:00:00	2002-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	99003Q	\N	\N	\N
484	AFCL	2000-01-20 00:00:00	2001-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	99004R	\N	\N	\N
485	ETRD	2000-01-20 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92010J	\N	\N	\N
486	ETRD	2000-01-20 00:00:00	2001-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	95027G	\N	\N	\N
487	NEANT	\N	2000-02-23 00:00:00	ANCIEN	\N	\N	\N	\N	00001A	\N	\N	\N
488	SOCI	2000-02-23 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	00001A	\N	\N	\N
489	ECON	2000-03-07 00:00:00	2000-04-25 00:00:00	ANCIEN	\N	\N	\N	\N	96003C	\N	\N	\N
490	SOCI	2000-03-07 00:00:00	2000-04-25 00:00:00	ANCIEN	\N	\N	\N	\N	98038X	\N	\N	\N
492	NEANT	2000-03-19 00:00:00	2000-03-28 00:00:00	ANCIEN	\N	\N	\N	\N	93007T	\N	\N	\N
493	ECON	2000-03-28 00:00:00	2007-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	\N	\N	\N
494	SOCI	2000-03-28 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	93007T	\N	\N	\N
495	NEANT	2000-03-29 00:00:00	2000-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	00002B	\N	\N	\N
496	LOIS	2000-04-04 00:00:00	2012-09-19 00:00:00	ANCIEN	\N	\N	\N	\N	95011X	\N	\N	\N
497	SOCI	2000-04-04 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	00002B	\N	\N	\N
498	ECON	2000-04-25 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	98038X	\N	\N	\N
499	SOCI	2000-04-25 00:00:00	2004-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	96003C	\N	\N	\N
500	NEANT	2000-04-28 00:00:00	2000-05-02 00:00:00	ANCIEN	\N	\N	\N	\N	00003C	\N	\N	\N
501	NEANT	\N	2000-05-23 00:00:00	ANCIEN	\N	\N	\N	\N	00004D	\N	\N	\N
502	AFCL	2000-05-02 00:00:00	2000-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	00003C	\N	\N	\N
503	ETRD	2000-05-02 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98051U	\N	\N	\N
504	AFCL	2000-05-04 00:00:00	2000-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	83047W	\N	\N	\N
505	ECON	2000-05-04 00:00:00	2000-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	92015P	\N	\N	\N
506	ETRD	2000-05-16 00:00:00	2005-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	92033R	\N	\N	\N
507	LOIS	2000-05-16 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95002W	\N	\N	\N
508	ECON	2000-05-23 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	95024D	\N	\N	\N
509	SOCI	2000-05-23 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	00004D	\N	\N	\N
510	FINC	2000-05-23 00:00:00	2000-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	92016Q	\N	\N	\N
511	LOIS	2000-05-23 00:00:00	2000-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	95044H	\N	\N	\N
513	AFCL	2000-06-28 00:00:00	2000-10-24 00:00:00	ANCIEN	\N	\N	\N	\N	83039W	\N	\N	\N
514	SOCI	2000-06-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	00003C	\N	\N	2017-09-24 18:05:40
515	LOIS	2000-10-02 00:00:00	2000-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	95050F	\N	\N	\N
516	ETRD	2000-10-02 00:00:00	2000-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	98007Q	\N	\N	\N
517	AFCL	2000-10-03 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	92015P	\N	\N	\N
520	FINC	2000-10-10 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	95044H	\N	\N	\N
519	ECON	2000-10-03 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	83047W	\N	\N	\N
521	LOIS	2000-10-10 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92016Q	\N	\N	\N
522	ETRD	2000-10-12 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95050F	\N	\N	\N
523	LOIS	2000-10-12 00:00:00	2001-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	98007Q	\N	\N	\N
524	ECON	2000-10-25 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	83039W	\N	\N	\N
525	AFCL	2000-10-25 00:00:00	2004-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	95066P	\N	\N	\N
526	NEANT	2001-01-17 00:00:00	2001-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	01001E	\N	\N	\N
527	ETRD	2001-01-23 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86035F	\N	\N	\N
528	LOIS	2001-01-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01001E	\N	\N	\N
529	NEANT	2001-02-08 00:00:00	2001-03-26 00:00:00	ANCIEN	\N	\N	\N	\N	01002F	\N	\N	\N
530	NEANT	2001-03-03 00:00:00	2001-03-26 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	\N	\N	\N
601	AFCL	2001-03-27 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01002F	\N	\N	\N
602	AFCL	2001-03-27 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	\N	\N	\N
604	NEANT	2001-03-28 00:00:00	2001-04-02 00:00:00	ANCIEN	\N	\N	\N	\N	01004H	\N	\N	\N
605	ETRD	2001-04-03 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01004H	\N	\N	\N
606	ECON	2001-04-05 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	98032R	\N	\N	\N
607	ETRD	2001-04-05 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	81001X	\N	\N	\N
608	LOIS	2001-06-14 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83040P	\N	\N	\N
609	SOCI	2001-06-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98024R	\N	\N	2017-10-04 20:00:03
610	LOIS	2001-06-21 00:00:00	2002-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	99004R	\N	\N	\N
611	AFCL	2001-06-21 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98007Q	\N	\N	\N
614	CORSE	2001-06-19 00:00:00	2001-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	84004P	\N	\N	\N
615	CORSE	2001-06-19 00:00:00	2001-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	98006P	\N	\N	\N
616	CORSE	2001-06-19 00:00:00	2001-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	86011W	\N	\N	\N
617	CORSE	2001-06-19 00:00:00	2001-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	01001E	\N	\N	\N
618	CORSE	2001-06-19 00:00:00	2001-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	98014P	\N	\N	\N
619	CORSE	2001-06-19 00:00:00	2001-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	98016R	\N	\N	\N
620	CORSE	2001-06-19 00:00:00	2001-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	81015E	\N	\N	\N
621	CORSE	2001-06-19 00:00:00	2001-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	88008L	\N	\N	\N
622	CORSE	2001-06-19 00:00:00	2001-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	95020Y	\N	\N	\N
655	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01005J	\N	\N	\N
624	CORSE	2001-06-19 00:00:00	2001-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	77017C	\N	\N	\N
625	CORSE	2001-06-19 00:00:00	2001-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	97007L	\N	\N	\N
626	CORSE	2001-06-19 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	99001N	\N	\N	\N
627	CORSE	2001-06-19 00:00:00	2001-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	98042T	\N	\N	\N
628	CORSE	2001-06-19 00:00:00	2001-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	98047Y	\N	\N	\N
629	CORSE	2001-06-19 00:00:00	2001-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	98041S	\N	\N	\N
630	CORSE	2001-06-19 00:00:00	2001-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	\N	\N	\N
631	CORSE	2001-06-19 00:00:00	2001-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	98017S	\N	\N	\N
632	CORSE	2001-06-19 00:00:00	2001-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	78003A	\N	\N	\N
634	CORSE	2001-06-19 00:00:00	2001-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	77029G	\N	\N	\N
635	CORSE	2001-06-19 00:00:00	2001-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	\N	\N	\N
637	CORSE	2001-06-19 00:00:00	2001-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	88013H	\N	\N	\N
638	CORSE	2001-06-19 00:00:00	2001-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	77033C	\N	\N	\N
639	CORSE	2001-06-19 00:00:00	2001-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	92031P	\N	\N	\N
640	CORSE	2001-06-19 00:00:00	2001-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	98051U	\N	\N	\N
641	CORSE	2001-06-19 00:00:00	2001-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	77044F	\N	\N	\N
642	CORSE	2001-06-19 00:00:00	2001-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	\N	\N	\N
643	CORSE	2001-06-19 00:00:00	2001-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	95049N	\N	\N	\N
644	CORSE	2001-06-19 00:00:00	2001-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	98008R	\N	\N	\N
645	CORSE	2001-06-19 00:00:00	2001-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	98015Q	\N	\N	\N
646	CORSE	2001-06-19 00:00:00	2001-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	92005M	\N	\N	\N
647	CORSE	2001-06-19 00:00:00	2001-09-20 00:00:00	ANCIEN	\N	\N	\N	\N	94002S	\N	\N	\N
648	CORSE	2001-06-19 00:00:00	2001-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	80039J	\N	\N	\N
656	ECON	2001-10-03 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	01006K	\N	\N	\N
650	CORSE	2001-06-19 00:00:00	2001-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	98012M	\N	\N	\N
651	CORSE	2001-06-19 00:00:00	2001-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	93003P	\N	\N	\N
652	CORSE	2001-06-19 00:00:00	2001-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	89042S	\N	\N	\N
657	ETRD	2001-10-03 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	01007L	\N	\N	\N
658	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01008M	\N	\N	\N
659	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01009N	\N	\N	\N
660	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01010F	\N	\N	\N
1633	ETRD	1959-05-05 00:00:00	1973-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	000442	\N	\N	\N
1634	ETRD	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58941A	\N	\N	\N
1635	ECON	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000248	\N	\N	\N
1636	LOIS	1977-10-06 00:00:00	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59543T	\N	\N	\N
1637	FINC	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000280	\N	\N	\N
1638	FINC	1968-10-08 00:00:00	1989-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	000201	\N	\N	\N
1639	ECON	1974-10-04 00:00:00	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000531	\N	\N	\N
1640	ETRD	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000206	\N	\N	\N
1641	ECON	1974-10-04 00:00:00	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000144	\N	\N	\N
1642	SOCI	1959-05-12 00:00:00	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000320	\N	\N	\N
1643	ECON	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59545V	\N	\N	\N
1644	ECON	\N	1997-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	89033R	\N	\N	\N
1646	ETRD	\N	1990-08-11 00:00:00	ANCIEN	\N	\N	\N	\N	000351	\N	\N	\N
1647	SOCI	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59547X	\N	\N	\N
1648	SOCI	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59548Y	\N	\N	\N
1649	ETRD	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000004	\N	\N	\N
1650	AFCL	1983-10-07 00:00:00	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59549A	\N	\N	\N
1651	AFCL	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000059	\N	\N	\N
1652	ECON	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58947G	\N	\N	\N
1653	AFCL	1977-10-06 00:00:00	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58633Q	\N	\N	\N
1654	SOCI	\N	1993-11-07 00:00:00	ANCIEN	\N	\N	\N	\N	000561	\N	\N	\N
1655	AFCL	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59235J	\N	\N	\N
1657	ECON	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58621L	\N	\N	\N
1658	AFCL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58939G	\N	\N	\N
1659	AFCL	\N	1997-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	88011F	\N	\N	\N
1660	ETRD	1980-10-07 00:00:00	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000502	\N	\N	\N
1661	ETRD	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59550S	\N	\N	\N
1662	ETRD	1959-05-06 00:00:00	1966-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	000355	\N	\N	\N
1663	ETRD	1977-10-06 00:00:00	1980-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	000337	\N	\N	\N
1664	ETRD	\N	1988-06-24 00:00:00	ANCIEN	\N	\N	\N	\N	59717X	\N	\N	\N
1665	SOCI	1992-10-07 00:00:00	1996-09-10 00:00:00	ANCIEN	\N	\N	\N	\N	92038W	\N	\N	\N
1666	ECON	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58635S	\N	\N	\N
1667	AFCL	1968-10-08 00:00:00	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59551T	\N	\N	\N
1668	SOCI	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59552U	\N	\N	\N
1669	FINC	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58914W	\N	\N	\N
1670	ETRD	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59236K	\N	\N	\N
1671	ECON	\N	1995-07-01 00:00:00	ANCIEN	\N	\N	\N	\N	000597	\N	\N	\N
1672	AFCL	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000100	\N	\N	\N
1673	ETRD	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000027	\N	\N	\N
1674	FINC	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000586	\N	\N	\N
1675	SOCI	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59237L	\N	\N	\N
1676	ECON	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000528	\N	\N	\N
1677	ETRD	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000126	\N	\N	\N
1679	ECON	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59240F	\N	\N	\N
1680	LOIS	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58645U	\N	\N	\N
1681	LOIS	\N	1994-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	000419	\N	\N	\N
1682	AFCL	\N	1989-05-18 00:00:00	ANCIEN	\N	\N	\N	\N	000488	\N	\N	\N
1684	SOCI	\N	1998-04-05 00:00:00	ANCIEN	\N	\N	\N	\N	71031Y	\N	\N	\N
1685	FINC	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000521	\N	\N	\N
1686	LOIS	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59553V	\N	\N	\N
1687	ECON	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59579G	\N	\N	\N
1689	FINC	1977-10-06 00:00:00	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59580Y	\N	\N	\N
1690	ECON	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	58335H	\N	\N	\N
1691	LOIS	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000138	\N	\N	\N
1692	AFCL	\N	1995-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	59554W	\N	\N	\N
1694	LOIS	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	58341F	\N	\N	\N
1695	FINC	1981-07-08 00:00:00	1990-06-14 00:00:00	ANCIEN	\N	\N	\N	\N	000514	\N	\N	\N
1696	SOCI	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59619W	\N	\N	\N
1697	ETRD	\N	1998-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	96002B	\N	\N	\N
1699	AFCL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58916Y	\N	\N	\N
1700	ETRD	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59556Y	\N	\N	\N
1701	ETRD	\N	1992-03-20 00:00:00	ANCIEN	\N	\N	\N	\N	000476	\N	\N	\N
1702	SOCI	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58917A	\N	\N	\N
1704	ECON	1974-10-06 00:00:00	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000470	\N	\N	\N
1705	LOIS	\N	1997-09-11 00:00:00	ANCIEN	\N	\N	\N	\N	88010E	\N	\N	\N
1706	ECON	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000202	\N	\N	\N
1707	SOCI	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59244K	\N	\N	\N
1709	LOIS	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59245L	\N	\N	\N
1710	FINC	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58926B	\N	\N	\N
1711	FINC	1959-05-12 00:00:00	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000104	\N	\N	\N
1713	FINC	1995-10-04 00:00:00	1997-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	\N	\N	\N
1714	ECON	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58938F	\N	\N	\N
1715	ETRD	\N	1997-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	77003V	\N	\N	\N
1716	ETRD	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58919C	\N	\N	\N
1717	SOCI	1971-10-06 00:00:00	1984-12-25 00:00:00	ANCIEN	\N	\N	\N	\N	000125	\N	\N	\N
1718	ETRD	\N	1997-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	95064M	\N	\N	\N
1719	SOCI	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59557A	\N	\N	\N
1720	ECON	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59558B	\N	\N	\N
1721	ETRD	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58638V	\N	\N	\N
1722	ECON	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58929E	\N	\N	\N
1723	ECON	\N	1985-05-26 00:00:00	ANCIEN	\N	\N	\N	\N	000443	\N	\N	\N
1724	AFCL	\N	1997-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	95065N	\N	\N	\N
1725	SOCI	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000214	\N	\N	\N
1726	LOIS	1977-10-06 00:00:00	1992-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	000505	\N	\N	\N
1727	AFCL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58928D	\N	\N	\N
1728	SOCI	\N	1983-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	000453	\N	\N	\N
1729	LOIS	1977-10-06 00:00:00	1989-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	000564	\N	\N	\N
1730	ETRD	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	57752S	\N	\N	\N
1732	AFCL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59559C	\N	\N	\N
1733	AFCL	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000278	\N	\N	\N
1734	AFCL	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58662V	\N	\N	\N
1735	FINC	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	58352J	\N	\N	\N
1736	FINC	1995-10-04 00:00:00	1998-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	74044S	\N	\N	\N
1737	FINC	1986-10-06 00:00:00	1988-06-24 00:00:00	ANCIEN	\N	\N	\N	\N	59307H	\N	\N	\N
1738	LOIS	\N	1995-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	59581A	\N	\N	\N
1739	AFCL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58933A	\N	\N	\N
1740	AFCL	1977-10-06 00:00:00	1992-02-23 00:00:00	ANCIEN	\N	\N	\N	\N	000440	\N	\N	\N
1741	AFCL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000369	\N	\N	\N
1742	ETRD	\N	1993-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	000373	\N	\N	\N
1312	FINC	\N	1971-08-01 00:00:00	ANCIEN	\N	\N	\N	\N	000120	\N	\N	\N
1313	FINC	1966-10-05 00:00:00	1975-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	000302	\N	\N	\N
1314	SOCI	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58508L	\N	\N	\N
1316	SOCI	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000118	\N	\N	\N
1317	AFCL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	56829S	\N	\N	\N
1318	ETRD	\N	1969-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	000251	\N	\N	\N
1319	LOIS	\N	1981-09-09 00:00:00	ANCIEN	\N	\N	\N	\N	000268	\N	\N	\N
1321	ECON	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000301	\N	\N	\N
1322	FINC	1968-10-08 00:00:00	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58036Y	\N	\N	\N
1323	SOCI	1971-10-06 00:00:00	1973-05-17 00:00:00	ANCIEN	\N	\N	\N	\N	000405	\N	\N	\N
1324	FINC	\N	1968-10-24 00:00:00	ANCIEN	\N	\N	\N	\N	000094	\N	\N	\N
1326	ECON	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000074	\N	\N	\N
1327	ETRD	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000078	\N	\N	\N
1328	LOIS	1959-05-06 00:00:00	1974-10-19 00:00:00	ANCIEN	\N	\N	\N	\N	000154	\N	\N	\N
1329	AFCL	1959-05-05 00:00:00	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58048D	\N	\N	\N
1331	SOCI	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000259	\N	\N	\N
1332	SOCI	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000055	\N	\N	\N
1333	ECON	\N	1975-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	000283	\N	\N	\N
1334	AFCL	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000117	\N	\N	\N
1336	ETRD	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000148	\N	\N	\N
1337	NEANT	\N	1981-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	59308J	\N	\N	\N
1338	SOCI	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000239	\N	\N	\N
1339	SOCI	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000029	\N	\N	\N
1340	ETRD	\N	1979-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	000169	\N	\N	\N
1341	FINC	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000099	\N	\N	\N
1342	SOCI	\N	1960-10-23 00:00:00	ANCIEN	\N	\N	\N	\N	000054	\N	\N	\N
1343	ECON	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000391	\N	\N	\N
1344	AFCL	\N	1976-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	000018	\N	\N	\N
1345	AFCL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000058	\N	\N	\N
1346	AFCL	\N	1982-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	000089	\N	\N	\N
1347	LOIS	\N	1979-05-28 00:00:00	ANCIEN	\N	\N	\N	\N	000360	\N	\N	\N
1348	LOIS	\N	1973-09-09 00:00:00	ANCIEN	\N	\N	\N	\N	000322	\N	\N	\N
1349	SOCI	\N	1975-12-29 00:00:00	ANCIEN	\N	\N	\N	\N	000106	\N	\N	\N
1743	AFCL	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000279	\N	\N	\N
1744	ECON	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000452	\N	\N	\N
1745	SOCI	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59247N	\N	\N	\N
1746	ETRD	\N	1983-08-20 00:00:00	ANCIEN	\N	\N	\N	\N	000330	\N	\N	\N
1747	ECON	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000287	\N	\N	\N
1748	LOIS	1959-05-12 00:00:00	1960-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	000095	\N	\N	\N
1750	ECON	\N	1984-03-20 00:00:00	ANCIEN	\N	\N	\N	\N	000592	\N	\N	\N
1751	SOCI	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58950B	\N	\N	\N
1752	AFCL	1959-05-06 00:00:00	1984-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	000312	\N	\N	\N
1753	LOIS	\N	1996-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	83001G	\N	\N	\N
1754	ECON	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59249Q	\N	\N	\N
1755	ETRD	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59561V	\N	\N	\N
1756	ETRD	\N	1988-05-10 00:00:00	ANCIEN	\N	\N	\N	\N	58808V	\N	\N	\N
1757	AFCL	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59250H	\N	\N	\N
1758	FINC	1977-10-06 00:00:00	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	55510R	\N	\N	\N
1760	SOCI	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000377	\N	\N	\N
1761	LOIS	1974-10-04 00:00:00	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59251J	\N	\N	\N
1762	SOCI	1967-10-11 00:00:00	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59252K	\N	\N	\N
1763	FINC	1986-10-06 00:00:00	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59562W	\N	\N	\N
1764	ETRD	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59563X	\N	\N	\N
1765	FINC	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59253L	\N	\N	\N
1766	ECON	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58647W	\N	\N	\N
1767	ECON	1959-05-06 00:00:00	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	58355M	\N	\N	\N
1768	ECON	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58655W	\N	\N	\N
1769	AFCL	\N	1998-07-14 00:00:00	ANCIEN	\N	\N	\N	\N	74041P	\N	\N	\N
1770	ETRD	\N	1986-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	000353	\N	\N	\N
1772	ETRD	1974-01-01 00:00:00	1983-05-10 00:00:00	ANCIEN	\N	\N	\N	\N	000376	\N	\N	\N
1773	ETRD	\N	1996-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	83022M	\N	\N	\N
1774	LOIS	\N	1987-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	000572	\N	\N	\N
1776	FINC	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58925A	\N	\N	\N
1777	LOIS	\N	1987-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	000611	\N	\N	\N
1778	SOCI	\N	1988-07-29 00:00:00	ANCIEN	\N	\N	\N	\N	000323	\N	\N	\N
1779	LOIS	\N	1995-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	59578F	\N	\N	\N
1781	ECON	\N	1996-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	89005M	\N	\N	\N
1782	LOIS	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59248P	\N	\N	\N
1783	AFCL	\N	1985-09-01 00:00:00	ANCIEN	\N	\N	\N	\N	000595	\N	\N	\N
1784	ECON	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58644T	\N	\N	\N
1786	FINC	1959-05-06 00:00:00	1993-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	000705	\N	\N	\N
1787	LOIS	\N	1992-04-06 00:00:00	ANCIEN	\N	\N	\N	\N	000667	\N	\N	\N
1788	20030128N1	2003-01-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01001E	TITULAIRE	\N	\N
1789	20030128N1	2003-01-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98016R	TITULAIRE	\N	\N
1790	20030128N1	2003-01-28 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	95020Y	TITULAIRE	\N	2015-06-12 16:01:25
1791	20030128N1	2003-01-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98041S	TITULAIRE	\N	2014-09-28 16:42:05
1792	20030128N1	2003-01-28 00:00:00	2015-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-12 09:39:30
1793	20030128N1	2003-01-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95046K	TITULAIRE	\N	\N
1794	20030128N1	2003-01-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	TITULAIRE	\N	2017-09-24 13:29:42
1795	20030128N1	2003-01-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	SUPPLEANT	\N	2017-09-24 18:20:10
1796	20030128N1	2003-01-28 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	92022N	SUPPLEANT	\N	\N
1798	20030128N1	2003-01-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89035T	SUPPLEANT	\N	\N
1799	20030128N1	2003-01-28 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	93005R	SUPPLEANT	\N	\N
1800	20030128N1	2003-01-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	SUPPLEANT	\N	\N
1801	20030128N1	2003-01-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92044U	SUPPLEANT	\N	2017-09-24 18:16:52
1121	AFCL	1959-05-06 00:00:00	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000188	\N	\N	\N
1231	ETRD	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000001	\N	\N	\N
1232	AFCL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000050	\N	\N	\N
1234	SOCI	1971-10-06 00:00:00	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000102	\N	\N	\N
1235	ETRD	\N	1959-05-28 00:00:00	ANCIEN	\N	\N	\N	\N	000025	\N	\N	\N
1236	LOIS	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000356	\N	\N	\N
1237	ECON	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	58003P	\N	\N	\N
1239	NEANT	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000070	\N	\N	\N
1240	ECON	1959-05-06 00:00:00	1981-08-29 00:00:00	ANCIEN	\N	\N	\N	\N	000103	\N	\N	\N
1241	ETRD	\N	1962-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	000379	\N	\N	\N
1242	AFCL	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000034	\N	\N	\N
1244	FINC	1959-05-06 00:00:00	1977-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	000033	\N	\N	\N
1245	ECON	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000022	\N	\N	\N
1246	FINC	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000132	\N	\N	\N
1247	ETRD	1959-05-06 00:00:00	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	57135W	\N	\N	\N
1248	LOIS	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000209	\N	\N	\N
1249	AFCL	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000290	\N	\N	\N
1250	SOCI	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58026W	\N	\N	\N
1251	LOIS	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000284	\N	\N	\N
1252	ETRD	\N	1971-08-10 00:00:00	ANCIEN	\N	\N	\N	\N	000145	\N	\N	\N
1253	SOCI	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000242	\N	\N	\N
1254	SOCI	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000024	\N	\N	\N
1255	LOIS	1959-05-06 00:00:00	1975-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	000187	\N	\N	\N
1256	ECON	\N	1967-04-03 00:00:00	ANCIEN	\N	\N	\N	\N	000079	\N	\N	\N
1257	LOIS	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000352	\N	\N	\N
1258	SOCI	\N	1972-05-08 00:00:00	ANCIEN	\N	\N	\N	\N	000166	\N	\N	\N
1259	ETRD	\N	1963-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	000428	\N	\N	\N
1260	AFCL	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000096	\N	\N	\N
1261	AFCL	\N	1977-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	000019	\N	\N	\N
1262	ECON	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000437	\N	\N	\N
1263	SOCI	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000026	\N	\N	\N
1264	FINC	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000254	\N	\N	\N
1265	AFCL	\N	1981-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	000412	\N	\N	\N
1266	ECON	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	57761T	\N	\N	\N
1267	AFCL	\N	1979-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	000109	\N	\N	\N
1268	ECON	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000182	\N	\N	\N
1269	ECON	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000112	\N	\N	\N
1270	ECON	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000090	\N	\N	\N
1271	FINC	\N	1973-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	000048	\N	\N	\N
1272	ECON	1962-10-05 00:00:00	1971-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	000008	\N	\N	\N
1273	ETRD	1959-05-06 00:00:00	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000208	\N	\N	\N
1274	ECON	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000161	\N	\N	\N
1275	SOCI	\N	1978-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	000643	\N	\N	\N
1276	AFCL	\N	1977-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	000434	\N	\N	\N
1277	AFCL	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000023	\N	\N	\N
1278	SOCI	1966-10-05 00:00:00	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000030	\N	\N	\N
1279	ECON	1975-10-09 00:00:00	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000143	\N	\N	\N
1280	ECON	1959-10-08 00:00:00	1972-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	000052	\N	\N	\N
1281	LOIS	1968-10-08 00:00:00	1973-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	000543	\N	\N	\N
1282	ETRD	\N	1981-05-26 00:00:00	ANCIEN	\N	\N	\N	\N	57321W	\N	\N	\N
1283	SOCI	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000108	\N	\N	\N
1284	ECON	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	56522A	\N	\N	\N
1285	SOCI	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000141	\N	\N	\N
1286	NEANT	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000156	\N	\N	\N
1287	ECON	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000275	\N	\N	\N
1288	ECON	\N	1978-03-12 00:00:00	ANCIEN	\N	\N	\N	\N	000639	\N	\N	\N
1289	AFCL	\N	1977-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	000085	\N	\N	\N
1290	LOIS	\N	1959-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	000212	\N	\N	\N
1291	SOCI	\N	1976-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	000077	\N	\N	\N
1293	FINC	1959-05-06 00:00:00	1967-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	57310T	\N	\N	\N
1294	ECON	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000142	\N	\N	\N
1295	LOIS	\N	1962-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	000281	\N	\N	\N
1296	ECON	\N	1959-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	56305S	\N	\N	\N
1297	AFCL	\N	1969-09-12 00:00:00	ANCIEN	\N	\N	\N	\N	000537	\N	\N	\N
1298	AFCL	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000174	\N	\N	\N
1299	ETRD	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000128	\N	\N	\N
1300	LOIS	1971-10-05 00:00:00	1974-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	000172	\N	\N	\N
1301	AFCL	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	57146A	\N	\N	\N
1302	LOIS	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000305	\N	\N	\N
1303	SOCI	1973-11-17 00:00:00	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	57738U	\N	\N	\N
1304	LOIS	\N	1960-05-09 00:00:00	ANCIEN	\N	\N	\N	\N	000147	\N	\N	\N
1306	AFCL	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000101	\N	\N	\N
1307	SOCI	\N	1980-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	000364	\N	\N	\N
1308	SOCI	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000123	\N	\N	\N
1309	LOIS	\N	1974-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	000298	\N	\N	\N
1311	ECON	\N	1966-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	000499	\N	\N	\N
761	LOIS	2001-10-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01038T	\N	\N	\N
762	SOCI	\N	2004-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	92018S	\N	\N	\N
764	ECON	2001-10-03 00:00:00	2007-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	01035Q	\N	\N	\N
765	ECON	2001-10-03 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	01015L	\N	\N	\N
766	AFCL	2001-10-03 00:00:00	2007-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	\N	\N	\N
767	AFCL	2001-10-03 00:00:00	2004-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	83012K	\N	\N	\N
768	ETRD	2001-10-03 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	80045G	\N	\N	\N
769	ETRD	2001-10-03 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	00001A	\N	\N	\N
770	ETRD	2001-10-03 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	\N	77044F	\N	\N	\N
772	ETRD	2001-10-03 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	92017R	\N	\N	\N
773	ETRD	2001-10-03 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83003J	\N	\N	\N
775	SOCI	2001-10-03 00:00:00	2002-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	77047J	\N	\N	\N
776	FINC	2001-10-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01027Q	\N	\N	2017-09-24 17:28:55
777	FINC	2001-10-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	78006D	\N	\N	\N
778	LOIS	2001-10-03 00:00:00	2001-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	74032N	\N	\N	\N
779	LOIS	2001-10-03 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	83050R	\N	\N	\N
780	LOIS	2001-10-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89029V	\N	\N	\N
781	SOCI	2001-10-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01018P	\N	\N	\N
782	SOCI	2001-10-03 00:00:00	2002-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	01042P	\N	\N	\N
783	SOCI	2001-10-03 00:00:00	2002-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	01060R	\N	\N	\N
784	SOCI	2001-10-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01029S	\N	\N	\N
787	AFCL	2001-10-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95024D	\N	\N	\N
788	AFCL	2001-10-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01041N	\N	\N	2017-09-24 18:59:59
789	AFCL	2001-10-03 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	01040M	\N	\N	\N
790	AFCL	2001-10-03 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	98044V	\N	\N	\N
791	ECON	2001-10-03 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	01008M	\N	\N	\N
792	ECON	2001-10-03 00:00:00	2003-11-13 00:00:00	ANCIEN	\N	\N	\N	\N	01057W	\N	\N	\N
793	ECON	2001-10-03 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	01061S	\N	\N	\N
794	ECON	2001-10-03 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	93007T	\N	\N	\N
795	ECON	2001-10-03 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	01058X	\N	\N	\N
796	ECON	2001-10-03 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	01056V	\N	\N	\N
797	ETRD	2001-10-03 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	87002A	\N	\N	\N
798	FINC	2001-10-03 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98047Y	\N	\N	\N
800	LOIS	2001-10-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01010F	\N	\N	\N
801	ECON	2001-10-03 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	68036E	\N	\N	\N
802	LOIS	2001-10-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	\N	\N	2017-09-24 13:29:42
803	SOCI	2001-10-03 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	01043Q	\N	\N	\N
804	SOCI	2001-10-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01009N	\N	\N	\N
805	SOCI	2001-10-03 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	01026P	\N	\N	\N
807	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01048V	\N	\N	\N
808	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01019Q	\N	\N	\N
809	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01052R	\N	\N	\N
810	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01006K	\N	\N	\N
811	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	89018S	\N	\N	\N
812	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01049W	\N	\N	\N
813	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01024M	\N	\N	\N
814	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01025N	\N	\N	\N
815	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01017N	\N	\N	\N
816	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01055U	\N	\N	\N
817	NEANT	2001-10-01 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01007L	\N	\N	2017-10-04 18:55:25
818	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	95036H	\N	\N	\N
819	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01021J	\N	\N	\N
820	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01054T	\N	\N	\N
821	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01039U	\N	\N	\N
822	NEANT	2001-10-01 00:00:00	2001-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01034P	\N	\N	\N
826	SOCI	2001-11-06 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	01064V	\N	\N	\N
824	LOIS	2001-10-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01063U	\N	\N	2014-09-29 15:47:31
825	NEANT	2001-10-15 00:00:00	2001-11-05 00:00:00	ANCIEN	\N	\N	\N	\N	01064V	\N	\N	\N
828	NEANT	2001-10-01 00:00:00	2002-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	01065W	\N	\N	\N
1475	SOCI	1980-10-07 00:00:00	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58921V	\N	\N	\N
1477	ETRD	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58654V	\N	\N	\N
1478	ETRD	1969-06-26 00:00:00	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58620K	\N	\N	\N
1479	SOCI	1985-10-22 00:00:00	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000374	\N	\N	\N
1480	AFCL	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59217G	\N	\N	\N
1481	AFCL	\N	1987-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	000541	\N	\N	\N
1482	LOIS	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000321	\N	\N	\N
1483	SOCI	\N	1988-06-24 00:00:00	ANCIEN	\N	\N	\N	\N	59309K	\N	\N	\N
1484	SOCI	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000553	\N	\N	\N
1485	LOIS	1992-10-07 00:00:00	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59566B	\N	\N	\N
1486	ETRD	1990-10-30 00:00:00	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59583C	\N	\N	\N
1487	SOCI	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58911T	\N	\N	\N
1488	ETRD	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59522N	\N	\N	\N
1489	SOCI	1979-10-07 00:00:00	1997-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	79002D	\N	\N	\N
1490	ECON	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000339	\N	\N	\N
1491	ECON	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59564Y	\N	\N	\N
1493	SOCI	\N	1990-04-11 00:00:00	ANCIEN	\N	\N	\N	\N	000529	\N	\N	\N
1494	ECON	1967-03-09 00:00:00	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000277	\N	\N	\N
1495	SOCI	\N	1992-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	59721T	\N	\N	\N
1497	ECON	\N	1986-09-09 00:00:00	ANCIEN	\N	\N	\N	\N	000460	\N	\N	\N
1498	LOIS	\N	1986-04-02 00:00:00	ANCIEN	\N	\N	\N	\N	58819Y	\N	\N	\N
1499	ETRD	1977-10-06 00:00:00	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59533R	\N	\N	\N
1500	AFCL	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	58343H	\N	\N	\N
1502	ECON	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59214D	\N	\N	\N
1503	AFCL	1986-10-06 00:00:00	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59215E	\N	\N	\N
1504	AFCL	\N	1995-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	000465	\N	\N	\N
1505	AFCL	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59520L	\N	\N	\N
1507	ETRD	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59219J	\N	\N	\N
1508	FINC	\N	1990-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	000545	\N	\N	\N
1509	ECON	1989-10-04 00:00:00	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59220B	\N	\N	\N
1510	LOIS	1983-10-06 00:00:00	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59568D	\N	\N	\N
1512	SOCI	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58951C	\N	\N	\N
1513	ECON	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000399	\N	\N	\N
1514	AFCL	\N	1989-09-17 00:00:00	ANCIEN	\N	\N	\N	\N	000474	\N	\N	\N
1515	SOCI	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59523P	\N	\N	\N
1517	FINC	\N	1995-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	59524Q	\N	\N	\N
1518	FINC	1980-10-07 00:00:00	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	58411C	\N	\N	\N
1519	ECON	\N	1987-02-27 00:00:00	ANCIEN	\N	\N	\N	\N	000538	\N	\N	\N
1522	AFCL	1968-10-08 00:00:00	1969-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	000326	\N	\N	\N
1523	SOCI	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58936D	\N	\N	\N
1524	ECON	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59570W	\N	\N	\N
1525	SOCI	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000327	\N	\N	\N
1526	ECON	\N	1994-09-09 00:00:00	ANCIEN	\N	\N	\N	\N	000510	\N	\N	\N
1527	ECON	\N	1995-11-09 00:00:00	ANCIEN	\N	\N	\N	\N	59601L	\N	\N	\N
1528	LOIS	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58657Y	\N	\N	\N
1529	LOIS	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59571X	\N	\N	\N
1531	AFCL	1962-10-05 00:00:00	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000272	\N	\N	\N
1532	FINC	1974-10-04 00:00:00	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	58349P	\N	\N	2017-01-10 11:19:10
1533	LOIS	1977-10-06 00:00:00	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	58419L	\N	\N	\N
1535	ECON	1974-10-04 00:00:00	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59222D	\N	\N	\N
1536	LOIS	1972-12-13 00:00:00	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58923X	\N	\N	\N
1538	LOIS	1980-10-07 00:00:00	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000501	\N	\N	\N
1539	ECON	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59223E	\N	\N	\N
1540	ECON	1968-10-08 00:00:00	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59528U	\N	\N	\N
1541	ETRD	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000196	\N	\N	\N
1542	LOIS	\N	1996-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	89011K	\N	\N	\N
1543	ECON	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59224F	\N	\N	\N
1544	FINC	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59529V	\N	\N	\N
1545	ETRD	\N	1998-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	71011U	\N	\N	\N
1546	ETRD	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59530N	\N	\N	\N
1547	SOCI	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58649Y	\N	\N	\N
1548	LOIS	1964-06-25 00:00:00	1995-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	000397	\N	\N	\N
1549	LOIS	1979-10-23 00:00:00	1992-01-06 00:00:00	ANCIEN	\N	\N	\N	\N	000524	\N	\N	\N
1550	LOIS	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000438	\N	\N	\N
1551	ETRD	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59226H	\N	\N	\N
1552	SOCI	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59572Y	\N	\N	\N
1553	ECON	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58670V	\N	\N	\N
1554	FINC	1959-05-06 00:00:00	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000331	\N	\N	\N
1555	ETRD	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	58367R	\N	\N	\N
1556	SOCI	\N	1997-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	86001U	\N	\N	\N
1557	ETRD	1971-10-06 00:00:00	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58943C	\N	\N	\N
1558	ETRD	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	58330C	\N	\N	\N
1559	ECON	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000203	\N	\N	\N
1560	ETRD	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59227J	\N	\N	\N
1561	FINC	1977-10-06 00:00:00	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000164	\N	\N	\N
1562	ECON	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59531P	\N	\N	\N
1563	SOCI	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59573A	\N	\N	\N
1565	FINC	1986-10-06 00:00:00	1988-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	57714L	\N	\N	\N
1566	AFCL	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000647	\N	\N	\N
1567	FINC	1968-10-08 00:00:00	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58643S	\N	\N	\N
1568	ECON	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000122	\N	\N	\N
1569	ECON	\N	1988-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	59305F	\N	\N	\N
1570	LOIS	1969-09-13 00:00:00	1977-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	58630M	\N	\N	\N
1571	AFCL	1971-10-06 00:00:00	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58942B	\N	\N	\N
1572	ECON	\N	1985-04-02 00:00:00	ANCIEN	\N	\N	\N	\N	58502E	\N	\N	\N
1573	ECON	\N	1986-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	000411	\N	\N	\N
1574	AFCL	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	58351H	\N	\N	\N
1575	AFCL	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58934B	\N	\N	\N
1576	AFCL	1986-10-06 00:00:00	1988-03-30 00:00:00	ANCIEN	\N	\N	\N	\N	000197	\N	\N	\N
1577	ETRD	\N	1988-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	58818X	\N	\N	\N
1578	ETRD	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000177	\N	\N	\N
1579	FINC	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000451	\N	\N	\N
1580	ETRD	\N	1995-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	000449	\N	\N	\N
1581	ECON	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59521M	\N	\N	\N
1582	FINC	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59574B	\N	\N	\N
1583	FINC	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58944D	\N	\N	\N
1584	SOCI	\N	1997-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	86027F	\N	\N	\N
1586	LOIS	\N	1992-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	59229L	\N	\N	\N
1587	FINC	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58668C	\N	\N	\N
1588	ETRD	1977-10-06 00:00:00	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59534S	\N	\N	\N
1589	SOCI	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58641Q	\N	\N	\N
1591	FINC	\N	1995-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	59535T	\N	\N	\N
1592	ETRD	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000319	\N	\N	\N
1593	LOIS	1959-05-12 00:00:00	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000114	\N	\N	\N
1595	LOIS	1972-12-14 00:00:00	1997-03-07 00:00:00	ANCIEN	\N	\N	\N	\N	62001R	\N	\N	\N
1596	ETRD	\N	1988-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	000599	\N	\N	\N
1597	FINC	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59536U	\N	\N	\N
1598	SOCI	1979-05-29 00:00:00	1981-07-29 00:00:00	ANCIEN	\N	\N	\N	\N	58631N	\N	\N	\N
1600	SOCI	\N	1992-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	59230D	\N	\N	\N
1601	ECON	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59231E	\N	\N	\N
1602	LOIS	\N	1988-07-01 00:00:00	ANCIEN	\N	\N	\N	\N	58816V	\N	\N	\N
1605	ECON	1977-10-06 00:00:00	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59232F	\N	\N	\N
1606	AFCL	1973-10-23 00:00:00	1985-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	000551	\N	\N	\N
1607	ETRD	\N	1997-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	89032Q	\N	\N	\N
1608	ECON	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58949J	\N	\N	\N
1610	ECON	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58625Q	\N	\N	\N
1611	ETRD	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59538W	\N	\N	\N
1612	SOCI	\N	1995-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	58115W	\N	\N	\N
1613	ETRD	\N	1993-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	000310	\N	\N	\N
1615	ECON	\N	1983-07-28 00:00:00	ANCIEN	\N	\N	\N	\N	000207	\N	\N	\N
1616	ECON	\N	1986-04-02 00:00:00	ANCIEN	\N	\N	\N	\N	000630	\N	\N	\N
1618	ETRD	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59539X	\N	\N	\N
1619	SOCI	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58650R	\N	\N	\N
1620	ETRD	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59540Q	\N	\N	\N
1621	SOCI	\N	1991-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	000516	\N	\N	\N
1622	ETRD	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58945E	\N	\N	\N
1623	ECON	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58913V	\N	\N	\N
1624	AFCL	\N	1996-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	80022Y	\N	\N	\N
1625	SOCI	\N	1998-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	92028U	\N	\N	\N
1626	FINC	1977-10-06 00:00:00	1995-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	000107	\N	\N	\N
1627	ECON	1968-10-08 00:00:00	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59541R	\N	\N	\N
1629	ETRD	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59542S	\N	\N	\N
1630	SOCI	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58948H	\N	\N	\N
2648	20040727N14	2004-07-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01038T	TITULAIRE	\N	\N
2649	20040727N14	2004-07-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	SUPPLEANT	\N	2017-09-24 18:20:10
2650	20040727N14	2004-07-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01001E	SUPPLEANT	\N	\N
2651	20040727N14	2004-07-27 00:00:00	2015-04-21 00:00:00	ANCIEN	\N	\N	\N	\N	01042P	SUPPLEANT	\N	2015-04-21 17:14:30
2652	20040727N14	2004-07-27 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89035T	TITULAIRE	\N	\N
2653	20040727N14	2004-07-27 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	92005M	SUPPLEANT	\N	\N
2654	20040727N14	2004-07-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	SUPPLEANT	\N	\N
2655	20040727N13	2004-07-27 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98041S	TITULAIRE	\N	2014-09-28 16:42:05
2657	20040727N13	2004-07-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01001E	TITULAIRE	\N	\N
2658	20040727N13	2004-07-27 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95055L	TITULAIRE	\N	2014-09-28 13:21:47
2659	20040727N13	2004-07-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	TITULAIRE	\N	2017-09-24 13:29:42
2660	20040727N13	2004-07-27 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98016R	TITULAIRE	\N	\N
2662	20040727N13	2004-07-27 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	92022N	SUPPLEANT	\N	\N
2663	20040727N13	2004-07-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	01057W	SUPPLEANT	\N	\N
2664	20040727N13	2004-07-27 00:00:00	2015-04-21 00:00:00	ANCIEN	\N	\N	\N	\N	01042P	SUPPLEANT	\N	2015-04-21 17:14:30
2665	20040727N13	2004-07-27 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89035T	SUPPLEANT	\N	\N
2666	20040727N13	2004-07-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	SUPPLEANT	\N	\N
2667	SOCI	2004-10-19 00:00:00	2007-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	89020L	\N	\N	\N
2668	AFCL	2004-10-19 00:00:00	2004-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	95051G	\N	\N	\N
2669	20040727N14	2004-07-27 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	93005R	TITULAIRE	\N	\N
2670	20040727N14	2004-07-27 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77029G	TITULAIRE	\N	\N
2671	20040727N14	2004-07-27 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95014B	SUPPLEANT	\N	\N
2673	20040727N13	2004-07-27 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	93005R	TITULAIRE	\N	\N
2674	20040727N13	2004-07-27 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77029G	SUPPLEANT	\N	\N
2676	NEANT	2004-11-02 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	04098U	\N	\N	\N
2677	NEANT	2004-11-02 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	04099V	\N	\N	\N
2678	NEANT	2004-11-02 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	04100U	\N	\N	\N
2679	AFCL	2004-11-03 00:00:00	2005-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	04099V	\N	\N	\N
2680	AFCL	2004-11-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04100U	\N	\N	\N
2681	ECON	2004-11-03 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	04097T	\N	\N	\N
2682	SOCI	2004-11-03 00:00:00	2005-05-03 00:00:00	ANCIEN	\N	\N	\N	\N	04098U	\N	\N	\N
2683	20041118N15	2004-11-18 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	95004Y	TITULAIRE	\N	\N
2684	20041118N15	2004-11-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	TITULAIRE	\N	\N
2685	20041118N15	2004-11-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01018P	TITULAIRE	\N	\N
2686	20041118N15	2004-11-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92030N	TITULAIRE	\N	\N
2687	20041118N15	2004-11-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04037F	TITULAIRE	\N	\N
2688	20041118N15	2004-11-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98029W	TITULAIRE	\N	\N
2689	20041118N15	2004-11-18 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	TITULAIRE	\N	2014-09-28 17:07:41
2690	20041118N15	2004-11-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	SUPPLEANT	\N	2017-09-24 13:44:49
2691	20041118N15	2004-11-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92011K	SUPPLEANT	\N	\N
2692	20041118N15	2004-11-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04081K	SUPPLEANT	\N	2017-09-24 19:25:10
2693	20041118N15	2004-11-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98024R	SUPPLEANT	\N	\N
2694	20041118N15	2004-11-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01011G	SUPPLEANT	\N	2017-09-24 16:43:42
2695	20041118N15	2004-11-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	95035G	SUPPLEANT	\N	2017-09-24 18:17:56
2696	20041118N15	2004-11-18 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	00002B	SUPPLEANT	\N	\N
2697	20040712N16	2004-12-07 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	95004Y	TITULAIRE	\N	\N
2698	20040712N16	2004-12-07 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80041C	TITULAIRE	\N	\N
2699	20040712N16	2004-12-07 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	01043Q	TITULAIRE	\N	\N
2701	20040712N16	2004-12-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01011G	TITULAIRE	\N	2017-09-24 16:43:42
2702	20040712N16	2004-12-07 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	00002B	TITULAIRE	\N	\N
2703	20040712N16	2004-12-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	SUPPLEANT	\N	2017-09-24 13:44:49
2704	20040712N16	2004-12-07 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	95020Y	SUPPLEANT	\N	2015-06-12 16:01:25
2705	20040712N16	2004-12-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	SUPPLEANT	\N	2014-09-28 17:07:41
2706	20040712N16	2004-12-07 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	78003A	SUPPLEANT	\N	\N
2707	20040712N16	2004-12-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04075M	SUPPLEANT	\N	\N
2708	20040712N16	2004-12-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01018P	SUPPLEANT	\N	\N
2709	20040712N16	2004-12-07 00:00:00	2014-09-01 00:00:00	ANCIEN	\N	\N	\N	\N	96007G	SUPPLEANT	\N	2014-09-01 10:21:13
2710	20040712N16	2004-12-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95013A	TITULAIRE	\N	\N
2711	20041214N17	2004-12-14 00:00:00	2014-07-01 00:00:00	ANCIEN	\N	\N	\N	\N	83011J	TITULAIRE	\N	2014-07-01 09:25:11
2712	20041214N17	2004-12-14 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
2713	20041214N17	2004-12-14 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	94003T	TITULAIRE	\N	2014-09-28 13:16:32
2715	20041214N17	2004-12-14 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	98032R	TITULAIRE	\N	2015-06-12 15:59:49
2716	20041214N17	2004-12-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	97009N	TITULAIRE	\N	\N
2718	20041214N17	2004-12-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89017R	SUPPLEANT	\N	\N
2719	20041214N17	2004-12-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95007C	SUPPLEANT	\N	\N
2720	20041214N17	2004-12-14 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89022N	SUPPLEANT	\N	2014-09-28 18:19:47
2722	20041214N17	2004-12-14 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	81015E	SUPPLEANT	\N	\N
2723	20041214N17	2004-12-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	78003A	SUPPLEANT	\N	\N
2724	20041214N17	2004-12-14 00:00:00	2010-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	92029V	SUPPLEANT	\N	\N
2725	NEANT	2004-12-24 00:00:00	2005-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	04101V	\N	\N	\N
2726	20041221N18	2004-12-20 00:00:00	2014-07-01 00:00:00	ANCIEN	\N	\N	\N	\N	83011J	TITULAIRE	\N	2014-07-01 09:25:11
2727	20041221N18	2004-12-20 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
2728	20041221N18	2004-12-20 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	94003T	TITULAIRE	\N	2014-09-28 13:16:32
2729	20041221N18	2004-12-20 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77043E	TITULAIRE	\N	2014-09-28 16:59:41
2730	20041221N18	2004-12-20 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	98032R	TITULAIRE	\N	2015-06-12 15:59:49
2731	20041221N18	2004-12-20 00:00:00	2013-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	95003X	TITULAIRE	\N	\N
2732	20041221N18	2004-12-20 00:00:00	2018-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	98053W	TITULAIRE	\N	2018-05-31 10:52:17
2733	20041221N18	2004-12-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89017R	SUPPLEANT	\N	\N
2734	20041221N18	2004-12-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	97009N	SUPPLEANT	\N	\N
2736	20041221N18	2004-12-20 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89022N	SUPPLEANT	\N	2014-09-28 18:19:47
2737	20041221N18	2004-12-20 00:00:00	2012-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	SUPPLEANT	\N	\N
1833	20030612N3	2003-06-12 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86041D	SUPPLEANT	\N	\N
1834	20030612N3	2003-06-12 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01050P	SUPPLEANT	\N	\N
1835	20030618N4	2003-06-18 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	95036H	TITULAIRE	\N	\N
1837	20030618N4	2003-06-18 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95014B	TITULAIRE	\N	\N
1838	20030618N4	2003-06-18 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86047K	TITULAIRE	\N	\N
1839	20030618N4	2003-06-18 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
1840	20030618N4	2003-06-18 00:00:00	2013-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	95003X	TITULAIRE	\N	\N
1841	20030618N4	2003-06-18 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	97005J	TITULAIRE	\N	\N
1842	20030618N4	2003-06-18 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77013X	SUPPLEANT	\N	\N
1843	20030618N4	2003-06-18 00:00:00	2018-12-30 00:00:00	ANCIEN	\N	\N	\N	\N	98023Q	SUPPLEANT	\N	\N
1844	20030618N4	2003-06-18 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	99003Q	SUPPLEANT	\N	\N
1845	20030618N4	2003-06-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89027T	SUPPLEANT	\N	\N
1846	20030618N4	2003-06-18 00:00:00	2010-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	01017N	SUPPLEANT	\N	\N
1847	20030618N4	2003-06-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01011G	SUPPLEANT	\N	2017-09-24 16:43:43
1848	20030618N4	2003-06-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	SUPPLEANT	\N	2017-09-24 17:09:24
1850	20030626N5	2003-06-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92031P	TITULAIRE	\N	2017-09-24 18:16:52
1851	20030626N5	2003-06-26 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	92005M	TITULAIRE	\N	\N
1852	20030626N5	2003-06-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	01025N	TITULAIRE	\N	\N
1853	20030626N5	2003-06-26 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95023C	TITULAIRE	\N	\N
1854	20030626N5	2003-06-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	85002R	TITULAIRE	\N	\N
1855	20030626N5	2003-06-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	97004H	TITULAIRE	\N	\N
1856	20030626N5	2003-06-26 00:00:00	2017-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	01044R	SUPPLEANT	\N	2017-07-04 15:08:09
1857	20030626N5	2003-06-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	SUPPLEANT	\N	2017-09-24 17:35:15
1858	20030626N5	2003-06-26 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95029J	SUPPLEANT	\N	\N
1859	20030626N5	2003-06-26 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	98025S	SUPPLEANT	\N	\N
1860	20030626N5	2003-06-26 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95047L	SUPPLEANT	\N	2014-09-28 17:09:16
1861	20030626N5	2003-06-26 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	66002K	SUPPLEANT	\N	\N
1862	20030626N5	2003-06-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	01034P	SUPPLEANT	\N	\N
1864	AFCL	1959-05-06 00:00:00	1974-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	000067	\N	\N	\N
1887	ECON	1959-05-06 00:00:00	1977-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	000374	\N	\N	\N
1712	ETRD	1959-05-06 00:00:00	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000293	\N	\N	\N
1869	AFCL	1959-05-06 00:00:00	1966-03-09 00:00:00	ANCIEN	\N	\N	\N	\N	000685	\N	\N	\N
1888	ETRD	1959-05-06 00:00:00	1966-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	000030	\N	\N	\N
1889	SOCI	1959-05-06 00:00:00	1960-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	000703	\N	\N	\N
1892	SOCI	1959-05-06 00:00:00	1959-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	000062	\N	\N	\N
1894	SOCI	1959-05-06 00:00:00	1966-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	000011	\N	\N	\N
1895	FINC	1959-05-06 00:00:00	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59220B	\N	\N	\N
1896	FINC	1959-05-06 00:00:00	1962-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	000694	\N	\N	\N
1897	FINC	1959-05-06 00:00:00	1964-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	000035	\N	\N	\N
1899	SOCI	1959-05-06 00:00:00	1962-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	000760	\N	\N	\N
1900	AFCL	1959-05-06 00:00:00	1964-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	000723	\N	\N	\N
1901	FINC	1965-10-05 00:00:00	1968-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	000326	\N	\N	\N
1468	LOIS	1959-05-06 00:00:00	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000729	\N	\N	\N
1903	LOIS	1965-10-05 00:00:00	1977-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	58336J	\N	\N	\N
1904	SOCI	1965-10-06 00:00:00	1986-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	59215E	\N	\N	\N
1905	ECON	1966-10-05 00:00:00	1968-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	000011	\N	\N	\N
1906	SOCI	1965-10-06 00:00:00	1966-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	59242H	\N	\N	\N
1907	LOIS	1968-10-08 00:00:00	1971-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	59242H	\N	\N	\N
1910	AFCL	1967-10-11 00:00:00	1980-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	58411C	\N	\N	\N
1382	SOCI	1959-05-06 00:00:00	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000722	\N	\N	\N
1911	AFCL	1969-10-08 00:00:00	1992-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	69001W	\N	\N	\N
1912	ECON	1965-10-05 00:00:00	1986-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	59221C	\N	\N	\N
1913	ECON	1968-10-04 00:00:00	1975-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	000246	\N	\N	\N
1656	ETRD	1966-10-05 00:00:00	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	58342G	\N	\N	\N
1603	SOCI	1966-10-05 00:00:00	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000370	\N	\N	\N
1914	SOCI	1971-10-06 00:00:00	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000008	\N	\N	\N
1915	FINC	1971-10-05 00:00:00	1977-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	000686	\N	\N	\N
1916	20030715N6	2003-07-15 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	86034E	TITULAIRE	\N	\N
1917	20030715N6	2003-07-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	TITULAIRE	\N	\N
1918	20030715N6	2003-07-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95013A	TITULAIRE	\N	\N
1919	20030715N6	2003-07-15 00:00:00	2007-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	01035Q	TITULAIRE	\N	\N
1920	20030715N6	2003-07-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01018P	TITULAIRE	\N	\N
1921	20030715N6	2003-07-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	TITULAIRE	\N	2017-09-24 17:09:24
1922	20030715N6	2003-07-15 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	TITULAIRE	\N	\N
1924	20030715N6	2003-07-15 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80013X	SUPPLEANT	\N	\N
1925	20030715N6	2003-07-15 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	96005E	SUPPLEANT	\N	\N
1926	20030715N6	2003-07-15 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95040D	SUPPLEANT	\N	\N
1927	20030715N6	2003-07-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01061S	SUPPLEANT	\N	2017-09-24 17:48:21
1928	20030715N6	2003-07-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01014K	SUPPLEANT	\N	2017-09-24 17:19:42
1929	20030715N6	2003-07-15 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95062K	SUPPLEANT	\N	\N
1930	20030718N7	2003-07-18 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	95004Y	TITULAIRE	\N	\N
1931	20030718N7	2003-07-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92030N	TITULAIRE	\N	\N
1932	20030718N7	2003-07-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	78006D	TITULAIRE	\N	\N
1933	20030718N7	2003-07-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77019E	TITULAIRE	\N	\N
1934	20030718N7	2003-07-18 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	01043Q	TITULAIRE	\N	\N
1935	20030718N7	2003-07-18 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98030P	TITULAIRE	\N	2014-09-28 13:19:48
1936	20030718N7	2003-07-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92018S	TITULAIRE	\N	2017-09-24 18:16:52
1937	20030718N7	2003-07-18 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95014B	SUPPLEANT	\N	\N
1938	20030718N7	2003-07-18 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95017E	SUPPLEANT	\N	\N
1939	20030718N7	2003-07-18 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77013X	SUPPLEANT	\N	\N
1940	20030718N7	2003-07-18 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	SUPPLEANT	\N	2014-09-28 17:07:41
1941	20030718N7	2003-07-18 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95033E	SUPPLEANT	\N	\N
1942	20030718N7	2003-07-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	95035G	SUPPLEANT	\N	2017-09-24 18:17:56
1943	20030718N7	2003-07-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	SUPPLEANT	\N	\N
1944	20030723N8	2003-07-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95030B	TITULAIRE	\N	2014-09-28 18:58:21
1945	20030723N8	2003-07-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98036V	TITULAIRE	\N	2014-09-28 17:15:42
1946	20030723N8	2003-07-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01027Q	TITULAIRE	\N	2017-09-24 17:28:55
1947	20030723N8	2003-07-23 00:00:00	2015-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-12 09:39:30
1948	20030723N8	2003-07-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01055U	TITULAIRE	\N	\N
1949	20030723N8	2003-07-23 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01004H	TITULAIRE	\N	\N
1950	20030723N8	2003-07-23 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	97005J	TITULAIRE	\N	\N
1951	20030723N8	2003-07-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01006K	SUPPLEANT	\N	\N
1952	20030723N8	2003-07-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95013A	SUPPLEANT	\N	\N
1953	20030723N8	2003-07-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95019G	SUPPLEANT	\N	2014-09-28 16:59:41
1954	20030723N8	2003-07-23 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95040D	SUPPLEANT	\N	\N
1955	20030723N8	2003-07-23 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	95051G	SUPPLEANT	\N	\N
1956	20030723N8	2003-07-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	96006F	SUPPLEANT	\N	2014-09-28 16:50:17
1957	20030723N8	2003-07-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	SUPPLEANT	\N	2017-09-24 17:09:24
1958	NEANT	2003-08-29 00:00:00	2003-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	03002P	\N	\N	\N
1960	ECON	2003-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	03002P	\N	\N	\N
1962	MCI	2003-10-08 00:00:00	2004-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	\N	\N	\N
1963	MCI	2003-10-08 00:00:00	2004-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	97009N	\N	\N	\N
1964	MCI	2003-10-08 00:00:00	2004-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	89018S	\N	\N	\N
1965	MCI	2003-10-08 00:00:00	2004-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	02003L	\N	\N	\N
1966	MCI	2003-10-08 00:00:00	2004-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	98029W	\N	\N	\N
1967	MCI	2003-10-08 00:00:00	2004-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	95017E	\N	\N	\N
1968	MCI	2003-10-08 00:00:00	2004-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	92018S	\N	\N	\N
1969	MCI	2003-10-08 00:00:00	2004-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	98024R	\N	\N	\N
1970	MCI	2003-10-08 00:00:00	2004-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	01045S	\N	\N	\N
1971	MCI	2003-10-08 00:00:00	2004-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	01015L	\N	\N	\N
1972	MCI	2003-10-08 00:00:00	2004-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	98030P	\N	\N	\N
1973	MCI	2003-10-08 00:00:00	2004-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	95029J	\N	\N	\N
1974	MCI	2003-10-08 00:00:00	2004-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	96005E	\N	\N	\N
1975	MCI	2003-10-08 00:00:00	2004-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	\N	\N	\N
1976	MCI	2003-10-08 00:00:00	2004-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	01055U	\N	\N	\N
1977	MCI	2003-10-08 00:00:00	2004-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	98017S	\N	\N	\N
1978	MCI	2003-10-08 00:00:00	2004-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	78003A	\N	\N	\N
1979	MCI	2003-10-08 00:00:00	2004-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	95035G	\N	\N	\N
1980	MCI	2003-10-08 00:00:00	2004-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	78006D	\N	\N	\N
1981	MCI	2003-10-08 00:00:00	2004-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	98003L	\N	\N	\N
1982	MCI	2003-10-08 00:00:00	2004-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	01033N	\N	\N	\N
1983	MCI	2003-10-08 00:00:00	2004-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	98025S	\N	\N	\N
1984	MCI	2003-10-08 00:00:00	2004-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	01043Q	\N	\N	\N
1985	MCI	2003-10-08 00:00:00	2004-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	95051G	\N	\N	\N
1986	MCI	2003-10-08 00:00:00	2004-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	01054T	\N	\N	\N
1987	MCI	2003-10-08 00:00:00	2004-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	66002K	\N	\N	\N
1988	MCI	2003-10-08 00:00:00	2004-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	98040R	\N	\N	\N
1989	MCI	2003-10-08 00:00:00	2004-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	98015Q	\N	\N	\N
1990	MCI	2003-10-08 00:00:00	2004-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	95056M	\N	\N	\N
1991	MCI	2003-10-08 00:00:00	2004-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	95058P	\N	\N	\N
1992	MCI	2003-10-08 00:00:00	2004-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	96007G	\N	\N	\N
1993	MCI	2003-10-08 00:00:00	2004-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	93005R	\N	\N	\N
1994	MCI	2003-10-08 00:00:00	2004-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	01050P	\N	\N	\N
1995	MCI	2003-10-08 00:00:00	2004-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	98012M	\N	\N	\N
1996	MCI	2003-10-08 00:00:00	2004-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	86049M	\N	\N	\N
1998	20031016N9	2003-10-16 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98041S	TITULAIRE	\N	2014-09-28 16:42:05
2489	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	95051G	\N	\N	\N
2490	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04074L	\N	\N	\N
2491	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04075M	\N	\N	\N
2492	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04076N	\N	\N	\N
2493	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04077P	\N	\N	\N
2494	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04078Q	\N	\N	\N
2495	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	77053G	\N	\N	\N
2496	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04079R	\N	\N	\N
2497	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04080J	\N	\N	\N
2498	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04081K	\N	\N	\N
2499	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04082L	\N	\N	\N
2500	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04083M	\N	\N	\N
2501	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04084N	\N	\N	\N
2502	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	\N	\N	\N
2503	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	\N	\N	\N
2504	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04087R	\N	\N	\N
2505	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04088S	\N	\N	\N
2506	NEANT	2004-10-01 00:00:00	2004-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	04089T	\N	\N	\N
2507	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04090L	\N	\N	\N
2508	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04091M	\N	\N	\N
2509	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	\N	\N	\N
2510	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04093P	\N	\N	\N
2511	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04094Q	\N	\N	\N
214	FINC	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	91002E	\N	\N	\N
2514	LOIS	2004-10-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	\N	\N	\N
3215	20060119N41	2006-01-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92018S	SUPPLEANT	\N	2017-09-24 18:16:52
3216	20060119N41	2006-01-23 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	SUPPLEANT	\N	2017-05-16 15:18:13
3217	20060119N41	2006-01-23 00:00:00	2007-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04060E	SUPPLEANT	\N	\N
3218	20060119N41	2006-01-23 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	02005N	SUPPLEANT	\N	\N
3219	20060119N41	2006-01-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04088S	SUPPLEANT	\N	\N
3220	20060119N41	2006-01-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92042S	SUPPLEANT	\N	\N
3221	20060119N41	2006-01-23 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95062K	SUPPLEANT	\N	\N
3222	20060119N42	2006-02-28 00:00:00	2015-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-12 09:39:30
3223	20060119N42	2006-02-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98039Y	TITULAIRE	\N	\N
3225	20060119N42	2006-02-28 00:00:00	2007-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	04072J	TITULAIRE	\N	\N
3226	20060119N42	2006-02-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	TITULAIRE	\N	2017-09-24 13:29:42
3228	20060119N42	2006-02-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01038T	TITULAIRE	\N	\N
3229	20060119N42	2006-02-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01065W	SUPPLEANT	\N	2014-09-28 12:09:44
3230	20060119N42	2006-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	SUPPLEANT	\N	\N
3231	20060119N42	2006-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	01057W	SUPPLEANT	\N	\N
3232	20060119N42	2006-02-28 00:00:00	2015-04-21 00:00:00	ANCIEN	\N	\N	\N	\N	01042P	SUPPLEANT	\N	2015-04-21 17:14:30
3233	20060119N42	2006-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	SUPPLEANT	\N	\N
3234	20060119N42	2006-02-28 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	\N	\N
3235	20060119N42	2006-02-28 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	SUPPLEANT	\N	\N
3236	20060119N43	2006-03-05 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	95004Y	TITULAIRE	\N	\N
3237	20060119N43	2006-03-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	95035G	TITULAIRE	\N	2017-09-24 18:17:56
3238	20060119N43	2006-03-05 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98036V	TITULAIRE	\N	2014-09-28 17:15:42
3239	20060119N43	2006-03-05 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	TITULAIRE	\N	\N
3240	20060119N43	2006-03-05 00:00:00	2015-04-21 00:00:00	ANCIEN	\N	\N	\N	\N	01042P	TITULAIRE	\N	2015-04-21 17:14:30
3241	20060119N43	2006-03-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01011G	TITULAIRE	\N	2017-09-24 16:43:43
3242	20060119N43	2006-03-05 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	00002B	TITULAIRE	\N	\N
3243	20060119N43	2006-03-05 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98045W	SUPPLEANT	\N	\N
3244	20060119N43	2006-03-05 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	SUPPLEANT	\N	2014-09-28 17:07:41
3245	20060119N43	2006-03-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01033N	SUPPLEANT	\N	\N
3246	20060119N43	2006-03-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04076N	SUPPLEANT	\N	\N
3247	20060119N43	2006-03-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	04043D	SUPPLEANT	\N	\N
3248	20060119N43	2006-03-05 00:00:00	2010-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	92005M	SUPPLEANT	\N	\N
3249	20060119N43	2006-03-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	01034P	SUPPLEANT	\N	\N
3250	20060307N44	2006-03-07 00:00:00	2006-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	80046H	TITULAIRE	\N	\N
3251	20060307N44	2006-03-07 00:00:00	2006-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	71003U	TITULAIRE	\N	\N
3252	20060307N44	2006-03-07 00:00:00	2006-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	89037V	TITULAIRE	\N	\N
3253	20060307N44	2006-03-07 00:00:00	2006-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	98028V	TITULAIRE	\N	2014-09-28 17:22:11
3254	20060307N44	2006-03-07 00:00:00	2006-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	95036H	TITULAIRE	\N	2014-09-28 17:31:42
3256	20060307N44	2006-03-07 00:00:00	2006-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	TITULAIRE	\N	2017-09-24 17:09:24
3257	20060307N44	2006-03-07 00:00:00	2006-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	89017R	SUPPLEANT	\N	\N
3258	20060307N44	2006-03-07 00:00:00	2006-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	01044R	SUPPLEANT	\N	2017-07-04 15:08:09
3259	20060307N44	2006-03-07 00:00:00	2006-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	77019E	SUPPLEANT	\N	\N
3260	20060307N44	2006-03-07 00:00:00	2006-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	98047Y	SUPPLEANT	\N	\N
3261	20060307N44	2006-03-07 00:00:00	2006-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	85003S	SUPPLEANT	\N	\N
3262	20060307N44	2006-03-07 00:00:00	2006-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	01054T	SUPPLEANT	\N	\N
3263	20060307N44	2006-03-07 00:00:00	2006-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	85002R	SUPPLEANT	\N	\N
3264	20060405N45	2006-04-05 00:00:00	2006-04-11 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-12 09:39:30
3265	20060405N45	2006-04-05 00:00:00	2006-04-11 00:00:00	ANCIEN	\N	\N	\N	\N	01001E	TITULAIRE	\N	\N
3266	20060405N45	2006-04-05 00:00:00	2006-04-11 00:00:00	ANCIEN	\N	\N	\N	\N	04072J	TITULAIRE	\N	\N
3268	20060405N45	2006-04-05 00:00:00	2006-04-11 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
1805	20030515N2	2003-05-15 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	86034E	TITULAIRE	\N	\N
1806	20030515N2	2003-05-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95013A	TITULAIRE	\N	\N
1807	20030515N2	2003-05-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	01057W	TITULAIRE	\N	\N
1808	20030515N2	2003-05-15 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	98027U	TITULAIRE	\N	2015-06-12 16:01:58
1809	20030515N2	2003-05-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	96008H	TITULAIRE	\N	\N
1810	20030515N2	2003-05-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01014K	TITULAIRE	\N	2017-09-24 17:19:42
1811	20030515N2	2003-05-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01013J	TITULAIRE	\N	2017-09-24 17:06:55
1813	20030515N2	2003-05-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98006P	SUPPLEANT	\N	2014-09-28 12:54:15
1814	20030515N2	2003-05-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95038K	SUPPLEANT	\N	2014-09-28 17:40:23
1815	20030515N2	2003-05-15 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95040D	SUPPLEANT	\N	\N
1816	20030515N2	2003-05-15 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01004H	SUPPLEANT	\N	\N
1817	20030515N2	2003-05-15 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98050T	SUPPLEANT	\N	\N
1818	20030515N2	2003-05-15 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	SUPPLEANT	\N	\N
1836	20030618N4	2003-06-18 00:00:00	2015-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-12 09:39:30
1849	20030626N5	2003-06-26 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80046H	TITULAIRE	\N	\N
1822	20030612N3	2003-06-12 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77043E	TITULAIRE	\N	2014-09-28 16:59:41
1823	20030612N3	2003-06-12 00:00:00	2015-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-12 09:39:30
1824	20030612N3	2003-06-12 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	01043Q	TITULAIRE	\N	\N
1825	20030612N3	2003-06-12 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95061J	TITULAIRE	\N	\N
1826	20030612N3	2003-06-12 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95044H	TITULAIRE	\N	\N
1827	20030612N3	2003-06-12 00:00:00	2018-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	98053W	TITULAIRE	\N	2018-05-31 10:52:17
1828	20030612N3	2003-06-12 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98047Y	SUPPLEANT	\N	\N
1829	20030612N3	2003-06-12 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	94003T	SUPPLEANT	\N	2014-09-28 13:16:32
1830	20030612N3	2003-06-12 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	98046X	SUPPLEANT	\N	2017-09-25 09:56:00
1831	20030612N3	2003-06-12 00:00:00	2013-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	95003X	SUPPLEANT	\N	\N
1832	20030612N3	2003-06-12 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	98032R	SUPPLEANT	\N	2015-06-12 15:59:49
2290	20040512N6	2004-05-12 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95040D	SUPPLEANT	\N	\N
2291	20040512N6	2004-05-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01061S	SUPPLEANT	\N	2017-09-24 17:48:21
2292	20040512N6	2004-05-12 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	93007T	SUPPLEANT	\N	\N
2293	20040512N6	2004-05-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	SUPPLEANT	\N	2017-09-24 17:09:24
2294	20040512N6	2004-05-12 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89040Q	SUPPLEANT	\N	\N
2295	20040512N6	2004-05-12 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	03002P	SUPPLEANT	\N	\N
2296	20040526N7	2004-05-26 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	95004Y	TITULAIRE	\N	\N
2297	20040526N7	2004-05-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01018P	TITULAIRE	\N	\N
2299	20040526N7	2004-05-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92011K	TITULAIRE	\N	\N
2300	20040526N7	2004-05-26 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80031A	TITULAIRE	\N	\N
2301	20040526N7	2004-05-26 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98030P	TITULAIRE	\N	2014-09-28 13:19:48
2302	20040526N7	2004-05-26 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	TITULAIRE	\N	2014-09-28 17:07:41
2303	20040526N7	2004-05-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	SUPPLEANT	\N	2017-09-24 13:44:49
2304	20040526N7	2004-05-26 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95017E	SUPPLEANT	\N	\N
2305	20040526N7	2004-05-26 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95033E	SUPPLEANT	\N	\N
2306	20040526N7	2004-05-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92030N	SUPPLEANT	\N	\N
2307	20040526N7	2004-05-26 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	01043Q	SUPPLEANT	\N	\N
2308	20040526N7	2004-05-26 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	00002B	SUPPLEANT	\N	\N
2309	20040526N7	2004-05-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	SUPPLEANT	\N	\N
2311	20040609N8	2004-06-09 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98017S	TITULAIRE	\N	\N
2312	20040609N8	2004-06-09 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77013X	TITULAIRE	\N	\N
2313	20040609N8	2004-06-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98024R	TITULAIRE	\N	\N
2314	20040609N8	2004-06-09 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95045J	TITULAIRE	\N	\N
2315	20040609N8	2004-06-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98029W	TITULAIRE	\N	\N
2316	20040609N8	2004-06-09 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	TITULAIRE	\N	2014-09-28 17:07:41
2317	20040609N8	2004-06-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92011K	SUPPLEANT	\N	\N
2318	20040609N8	2004-06-09 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98030P	SUPPLEANT	\N	2014-09-28 13:19:48
2319	20040609N8	2004-06-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92030N	SUPPLEANT	\N	\N
2320	20040609N8	2004-06-09 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	00002B	SUPPLEANT	\N	\N
2321	20040609N8	2004-06-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01009N	SUPPLEANT	\N	\N
2323	20040609N8	2004-06-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	SUPPLEANT	\N	\N
2324	SOCI	2004-06-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83012K	\N	\N	\N
2329	AFCL	2004-06-28 00:00:00	2004-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	96003C	\N	\N	\N
2833	20050319N22	2005-03-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92031P	TITULAIRE	\N	2017-09-24 18:16:52
2834	20050319N22	2005-03-19 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89042S	TITULAIRE	\N	\N
2835	20050319N22	2005-03-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04052E	TITULAIRE	\N	\N
2836	20050319N22	2005-03-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	TITULAIRE	\N	2017-09-24 17:35:15
2837	20050319N22	2005-03-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01012H	SUPPLEANT	\N	\N
2838	20050319N22	2005-03-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95024D	SUPPLEANT	\N	\N
2839	20050319N22	2005-03-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95047L	SUPPLEANT	\N	2014-09-28 17:09:16
2840	20050319N22	2005-03-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01054T	SUPPLEANT	\N	\N
2842	20050319N22	2005-03-19 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	\N	01039U	SUPPLEANT	\N	\N
2843	20050319N22	2005-03-19 00:00:00	2014-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	01062T	SUPPLEANT	\N	2014-12-18 16:15:04
2844	20050503N23	2005-05-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95030B	TITULAIRE	\N	2014-09-28 18:58:21
2846	20050503N23	2005-05-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	01058X	TITULAIRE	\N	\N
2847	20050503N23	2005-05-03 00:00:00	2007-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04060E	TITULAIRE	\N	\N
2848	20050503N23	2005-05-03 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	98012M	TITULAIRE	\N	\N
2849	20050503N23	2005-05-03 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	04090L	TITULAIRE	\N	\N
2850	20050503N23	2005-05-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01050P	TITULAIRE	\N	\N
2851	20050503N23	2005-05-03 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01064V	SUPPLEANT	\N	2014-09-28 17:12:41
2852	20050503N23	2005-05-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04054G	SUPPLEANT	\N	2017-09-24 17:18:03
2853	20050503N23	2005-05-03 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80015A	SUPPLEANT	\N	\N
2854	20050503N23	2005-05-03 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	02005N	SUPPLEANT	\N	\N
2855	20050503N23	2005-05-03 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	96006F	SUPPLEANT	\N	2014-09-28 16:50:17
2856	20050503N23	2005-05-03 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95062K	SUPPLEANT	\N	\N
2857	20050503N23	2005-05-03 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	03002P	SUPPLEANT	\N	\N
2858	20050504N24	2005-05-04 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	95004Y	TITULAIRE	\N	\N
2859	20050504N24	2005-05-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01018P	TITULAIRE	\N	\N
2861	20050504N24	2005-05-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04075M	TITULAIRE	\N	\N
2862	20050504N24	2005-05-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	04043D	TITULAIRE	\N	\N
2863	20050504N24	2005-05-04 00:00:00	2014-09-01 00:00:00	ANCIEN	\N	\N	\N	\N	96007G	TITULAIRE	\N	2014-09-01 10:21:13
2864	20050504N24	2005-05-04 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	00002B	TITULAIRE	\N	\N
2865	20050504N24	2005-05-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	02003L	SUPPLEANT	\N	\N
2866	20050504N24	2005-05-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	00003C	SUPPLEANT	\N	2017-09-24 18:05:40
2867	20050504N24	2005-05-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04081K	SUPPLEANT	\N	2017-09-24 19:25:10
2868	20050504N24	2005-05-04 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	SUPPLEANT	\N	2014-09-28 17:07:41
2869	20050504N24	2005-05-04 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	01043Q	SUPPLEANT	\N	\N
2870	20050504N24	2005-05-04 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80031A	SUPPLEANT	\N	\N
2872	20050511N25	2005-05-11 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95030B	TITULAIRE	\N	2014-09-28 18:58:21
2372	20040708N9	2004-07-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95030B	TITULAIRE	\N	2014-09-28 18:58:21
2373	20040708N9	2004-07-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98050T	TITULAIRE	\N	\N
2374	20040708N9	2004-07-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92030N	TITULAIRE	\N	\N
2375	20040708N9	2004-07-08 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
2376	20040708N9	2004-07-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01049W	TITULAIRE	\N	\N
2377	20040708N9	2004-07-08 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	96006F	TITULAIRE	\N	2014-09-28 16:50:17
2378	20040708N9	2004-07-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01013J	TITULAIRE	\N	2017-09-24 17:06:55
2379	20040708N9	2004-07-08 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98006P	SUPPLEANT	\N	2014-09-28 12:54:15
2380	20040708N9	2004-07-08 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89027T	SUPPLEANT	\N	\N
2381	20040708N9	2004-07-08 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95040D	SUPPLEANT	\N	\N
2382	20040708N9	2004-07-08 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	93007T	SUPPLEANT	\N	\N
2383	20040708N9	2004-07-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	SUPPLEANT	\N	2017-09-24 17:09:24
2384	20040708N9	2004-07-08 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89037V	SUPPLEANT	\N	\N
2385	20040708N9	2004-07-08 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	03002P	SUPPLEANT	\N	\N
2387	20040709N10	2004-07-09 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98017S	TITULAIRE	\N	\N
2388	20040709N10	2004-07-09 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95045J	TITULAIRE	\N	\N
2389	20040709N10	2004-07-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92011K	TITULAIRE	\N	\N
2390	20040709N10	2004-07-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98024R	TITULAIRE	\N	\N
2391	20040709N10	2004-07-09 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95017E	TITULAIRE	\N	\N
2392	20040709N10	2004-07-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83012K	TITULAIRE	\N	\N
2393	20040709N10	2004-07-09 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77013X	SUPPLEANT	\N	\N
2394	20040709N10	2004-07-09 00:00:00	2010-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	01026P	SUPPLEANT	\N	\N
2395	20040709N10	2004-07-09 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	SUPPLEANT	\N	2014-09-28 17:07:41
2396	20040709N10	2004-07-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01011G	SUPPLEANT	\N	2017-09-24 16:43:43
2397	20040709N10	2004-07-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92030N	SUPPLEANT	\N	\N
2398	20040709N10	2004-07-09 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	01043Q	SUPPLEANT	\N	\N
2399	20040709N10	2004-07-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	SUPPLEANT	\N	\N
2400	20040715N11	2004-07-15 00:00:00	2014-07-01 00:00:00	ANCIEN	\N	\N	\N	\N	83011J	TITULAIRE	\N	2014-07-01 09:25:11
2401	20040715N11	2004-07-15 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
2402	20040715N11	2004-07-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77043E	TITULAIRE	\N	2014-09-28 16:59:41
2403	20040715N11	2004-07-15 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86041D	TITULAIRE	\N	\N
2404	20040715N11	2004-07-15 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	98032R	TITULAIRE	\N	2015-06-12 15:59:49
2406	20040715N11	2004-07-15 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	79004F	TITULAIRE	\N	\N
2407	20040715N11	2004-07-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95007C	SUPPLEANT	\N	\N
2408	20040715N11	2004-07-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89022N	SUPPLEANT	\N	2014-09-28 18:19:47
2409	20040715N11	2004-07-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	94003T	SUPPLEANT	\N	2014-09-28 13:16:32
2410	20040715N11	2004-07-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	78003A	SUPPLEANT	\N	\N
2411	20040715N11	2004-07-15 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95042F	SUPPLEANT	\N	\N
2412	20040715N11	2004-07-15 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	98046X	SUPPLEANT	\N	2017-09-25 09:56:00
2413	20040715N11	2004-07-15 00:00:00	2013-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	95003X	SUPPLEANT	\N	\N
2415	20040727N12	2004-07-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	TITULAIRE	\N	\N
2416	20040727N12	2004-07-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	78006D	TITULAIRE	\N	\N
2417	20040727N12	2004-07-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77019E	TITULAIRE	\N	\N
2418	20040727N12	2004-07-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92030N	TITULAIRE	\N	\N
2419	20040727N12	2004-07-27 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95017E	TITULAIRE	\N	\N
2420	20040727N12	2004-07-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83012K	TITULAIRE	\N	\N
2421	20040727N12	2004-07-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92011K	SUPPLEANT	\N	\N
2422	20040727N12	2004-07-27 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77013X	SUPPLEANT	\N	\N
2423	20040727N12	2004-07-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92018S	SUPPLEANT	\N	2017-09-24 18:16:52
2424	20040727N12	2004-07-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98024R	SUPPLEANT	\N	\N
2425	20040727N12	2004-07-27 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98030P	SUPPLEANT	\N	2014-09-28 13:19:48
2426	20040727N12	2004-07-27 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	01043Q	SUPPLEANT	\N	\N
2427	20040727N12	2004-07-27 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95045J	SUPPLEANT	\N	\N
248	ETRD	1995-10-05 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	78007E	\N	\N	\N
264	LOIS	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	88013H	\N	\N	\N
2429	NEANT	2004-10-01 00:00:00	2004-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	04033B	\N	\N	\N
2430	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	95059Q	\N	\N	\N
2431	NEANT	2004-09-26 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	92029V	\N	\N	\N
2432	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	02009S	\N	\N	\N
2433	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	\N	\N	\N
2438	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04036E	\N	\N	\N
2439	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04037F	\N	\N	\N
2441	LOIS	2004-10-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	\N	\N	2017-10-04 19:43:30
2442	NEANT	2004-10-01 00:00:00	2004-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	04039H	\N	\N	\N
2443	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04040A	\N	\N	\N
2446	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04041B	\N	\N	\N
2447	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04042C	\N	\N	\N
2449	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	95031C	\N	\N	\N
2452	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04043D	\N	\N	\N
2453	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	\N	\N	\N
2454	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04045F	\N	\N	\N
2457	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04046G	\N	\N	\N
2458	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	\N	\N	\N
2460	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04048J	\N	\N	\N
2461	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	\N	\N	\N
2462	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04050C	\N	\N	\N
2463	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04051D	\N	\N	\N
2464	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04052E	\N	\N	\N
2465	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	\N	\N	\N
2467	NEANT	2004-10-01 00:00:00	2004-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	04054G	\N	\N	\N
2468	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04055H	\N	\N	\N
2469	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04056J	\N	\N	\N
2471	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04058L	\N	\N	\N
2472	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04059M	\N	\N	\N
2473	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04060E	\N	\N	\N
2474	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04061F	\N	\N	\N
2475	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04062G	\N	\N	\N
2476	LOIS	2004-10-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04063H	\N	\N	\N
2478	NEANT	2004-10-01 00:00:00	2004-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	04064J	\N	\N	\N
2479	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04065K	\N	\N	\N
2480	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04066L	\N	\N	\N
238	SOCI	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95014B	\N	\N	\N
2481	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04067M	\N	\N	\N
2482	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04068N	\N	\N	\N
2483	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	86039K	\N	\N	\N
2484	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04069P	\N	\N	\N
2485	NEANT	2004-10-01 00:00:00	2004-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	04070G	\N	\N	\N
2486	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04071H	\N	\N	\N
2487	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04072J	\N	\N	\N
2488	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04073K	\N	\N	\N
3029	20051104N31	2005-11-04 00:00:00	2015-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-12 09:39:30
3030	20051104N31	2005-11-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	TITULAIRE	\N	2017-09-24 13:29:42
3031	20051104N31	2005-11-04 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	TITULAIRE	\N	2014-09-28 18:00:58
3032	20051104N31	2005-11-04 00:00:00	2015-04-21 00:00:00	ANCIEN	\N	\N	\N	\N	01042P	TITULAIRE	\N	2015-04-21 17:14:30
3034	20051104N31	2005-11-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95006B	TITULAIRE	\N	\N
3035	20051104N31	2005-11-04 00:00:00	2012-09-19 00:00:00	ANCIEN	\N	\N	\N	\N	95011X	TITULAIRE	\N	\N
3036	20051104N31	2005-11-04 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01065W	SUPPLEANT	\N	2014-09-28 12:09:44
3037	20051104N31	2005-11-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	SUPPLEANT	\N	\N
3038	20051104N31	2005-11-04 00:00:00	2008-09-07 00:00:00	ANCIEN	\N	\N	\N	\N	80017C	SUPPLEANT	\N	\N
3039	20051104N31	2005-11-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01053S	SUPPLEANT	\N	\N
3040	20051104N31	2005-11-04 00:00:00	2007-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	04072J	SUPPLEANT	\N	\N
3041	20051104N31	2005-11-04 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	\N	\N
636	CORSE	2001-06-19 00:00:00	2001-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	95041E	\N	\N	\N
968	INITIATIVE	2003-02-12 00:00:00	2003-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	01006K	\N	\N	\N
3044	FINC	1989-10-05 00:00:00	1995-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	78003A	\N	\N	\N
3045	LOIS	1995-10-05 00:00:00	2002-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	78003A	\N	\N	\N
3046	20051118N32	2005-11-18 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	95004Y	TITULAIRE	\N	\N
3047	20051118N32	2005-11-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	TITULAIRE	\N	\N
3048	20051118N32	2005-11-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01018P	TITULAIRE	\N	\N
3066	20051130N33	2005-11-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95030B	TITULAIRE	\N	2014-09-28 18:58:21
3050	20051118N32	2005-11-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92030N	TITULAIRE	\N	\N
3051	20051118N32	2005-11-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04037F	TITULAIRE	\N	\N
3052	20051118N32	2005-11-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98029W	TITULAIRE	\N	\N
3053	20051118N32	2005-11-18 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	TITULAIRE	\N	2014-09-28 17:07:41
3054	20051118N32	2005-11-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83012K	SUPPLEANT	\N	\N
3055	20051118N32	2005-11-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	SUPPLEANT	\N	2017-09-24 13:44:49
3056	20051118N32	2005-11-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92011K	SUPPLEANT	\N	\N
3057	20051118N32	2005-11-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98024R	SUPPLEANT	\N	\N
3058	20051118N32	2005-11-18 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98030P	SUPPLEANT	\N	2014-09-28 13:19:48
3060	20051118N32	2005-11-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01030K	SUPPLEANT	\N	\N
3061	SOCI	1986-10-02 00:00:00	1987-10-19 00:00:00	ANCIEN	\N	\N	\N	\N	86018E	\N	\N	\N
3062	LOIS	1987-10-20 00:00:00	1989-04-05 00:00:00	ANCIEN	\N	\N	\N	\N	86018E	\N	\N	\N
3065	RECHERCHE	2005-11-23 00:00:00	2006-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	\N	\N	\N
3067	20051130N33	2005-11-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	90003B	TITULAIRE	\N	2017-10-01 10:01:39
3068	20051130N33	2005-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89022N	TITULAIRE	\N	2014-09-28 18:19:47
3069	20051130N33	2005-11-30 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	02005N	TITULAIRE	\N	\N
3070	20051130N33	2005-11-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01050P	TITULAIRE	\N	\N
3071	20051130N33	2005-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95052H	TITULAIRE	\N	2014-09-28 13:39:20
3072	20051130N33	2005-11-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92042S	TITULAIRE	\N	\N
3074	20051130N33	2005-11-30 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	SUPPLEANT	\N	2017-05-16 15:18:13
3075	20051130N33	2005-11-30 00:00:00	2007-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04060E	SUPPLEANT	\N	\N
3076	20051130N33	2005-11-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04097T	SUPPLEANT	\N	\N
3077	20051130N33	2005-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98038X	SUPPLEANT	\N	2014-09-28 17:38:26
3078	20051130N33	2005-11-30 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95062K	SUPPLEANT	\N	\N
3079	20051130N33	2005-11-30 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	98012M	SUPPLEANT	\N	\N
3080	20051215N34	2005-12-15 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95030B	TITULAIRE	\N	2014-09-28 18:58:21
3081	20051215N34	2005-12-15 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95062K	TITULAIRE	\N	\N
3082	20051215N34	2005-12-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89030N	TITULAIRE	\N	\N
3083	20051215N34	2005-12-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	82002D	TITULAIRE	\N	\N
3084	20051215N34	2005-12-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95025E	TITULAIRE	\N	2014-09-28 17:09:16
3085	20051215N34	2005-12-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01014K	TITULAIRE	\N	2017-09-24 17:19:42
3086	20051215N34	2005-12-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	TITULAIRE	\N	2017-09-24 17:09:24
3087	20051215N34	2005-12-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04091M	SUPPLEANT	\N	2014-09-28 17:55:37
3088	20051215N34	2005-12-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04054G	SUPPLEANT	\N	2017-09-24 17:18:03
3089	20051215N34	2005-12-15 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	SUPPLEANT	\N	2017-05-16 15:18:13
3090	20051215N34	2005-12-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86006A	SUPPLEANT	\N	\N
3091	20051215N34	2005-12-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	88009M	SUPPLEANT	\N	\N
3092	20051215N34	2005-12-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	03001N	SUPPLEANT	\N	2014-09-28 13:40:33
3093	20051215N34	2005-12-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	03002P	SUPPLEANT	\N	\N
3094	20051213N35	2005-12-13 00:00:00	2014-07-01 00:00:00	ANCIEN	\N	\N	\N	\N	83011J	TITULAIRE	\N	2014-07-01 09:25:11
3095	20051213N35	2005-12-13 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
2178	20040115N1	2004-01-15 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	92022N	TITULAIRE	\N	\N
2179	20040115N1	2004-01-15 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98035U	TITULAIRE	\N	\N
2180	20040115N1	2004-01-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98016R	TITULAIRE	\N	\N
2182	20040115N1	2004-01-15 00:00:00	2008-09-07 00:00:00	ANCIEN	\N	\N	\N	\N	80017C	SUPPLEANT	\N	\N
2183	20040115N1	2004-01-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	SUPPLEANT	\N	2014-09-28 18:00:58
2184	20040115N1	2004-01-15 00:00:00	2015-04-21 00:00:00	ANCIEN	\N	\N	\N	\N	01042P	SUPPLEANT	\N	2015-04-21 17:14:30
2185	20040115N1	2004-01-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89035T	SUPPLEANT	\N	\N
2186	20040115N1	2004-01-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	SUPPLEANT	\N	\N
2187	20040115N1	2004-01-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	SUPPLEANT	\N	2017-09-24 13:29:42
2188	20040123N2	2004-01-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98041S	TITULAIRE	\N	2014-09-28 16:42:05
2189	20040123N2	2004-01-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	TITULAIRE	\N	2017-09-24 13:29:42
2190	20040123N2	2004-01-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	TITULAIRE	\N	2014-09-28 18:00:58
2191	20040123N2	2004-01-23 00:00:00	2015-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-12 09:39:30
2192	20040123N2	2004-01-23 00:00:00	2015-04-21 00:00:00	ANCIEN	\N	\N	\N	\N	01042P	TITULAIRE	\N	2015-04-21 17:14:30
2193	20040123N2	2004-01-23 00:00:00	2008-09-07 00:00:00	ANCIEN	\N	\N	\N	\N	80017C	TITULAIRE	\N	\N
2194	20040123N2	2004-01-23 00:00:00	2012-09-19 00:00:00	ANCIEN	\N	\N	\N	\N	95011X	TITULAIRE	\N	\N
2195	20040123N2	2004-01-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95006B	SUPPLEANT	\N	\N
2198	20040123N2	2004-01-23 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	92022N	SUPPLEANT	\N	\N
2199	20040123N2	2004-01-23 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	86030A	SUPPLEANT	\N	\N
2200	20040123N2	2004-01-23 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89035T	SUPPLEANT	\N	\N
2201	20040123N2	2004-01-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	SUPPLEANT	\N	\N
2202	20040211N3	2004-02-11 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	95004Y	TITULAIRE	\N	\N
2203	20040211N3	2004-02-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95014B	TITULAIRE	\N	\N
2204	20040211N3	2004-02-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77013X	TITULAIRE	\N	\N
2205	20040211N3	2004-02-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98045W	TITULAIRE	\N	\N
2206	20040211N3	2004-02-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	95035G	TITULAIRE	\N	2017-09-24 18:17:56
2207	20040211N3	2004-02-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95017E	TITULAIRE	\N	\N
2208	20040211N3	2004-02-11 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	00002B	TITULAIRE	\N	\N
2209	20040211N3	2004-02-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	SUPPLEANT	\N	2017-09-24 13:44:49
2210	20040211N3	2004-02-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92011K	SUPPLEANT	\N	\N
2211	20040211N3	2004-02-11 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	SUPPLEANT	\N	2014-09-28 17:07:41
2212	20040211N3	2004-02-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01033N	SUPPLEANT	\N	\N
2213	20040211N3	2004-02-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92030N	SUPPLEANT	\N	\N
2214	20040211N3	2004-02-11 00:00:00	2014-09-01 00:00:00	ANCIEN	\N	\N	\N	\N	96007G	SUPPLEANT	\N	2014-09-01 10:21:13
2215	20040211N3	2004-02-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	SUPPLEANT	\N	\N
2216	ECON	1988-11-23 00:00:00	1989-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	83011J	\N	\N	\N
149	ETRD	1992-10-08 00:00:00	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	83011J	\N	\N	\N
2217	SOCI	1986-10-06 00:00:00	1989-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	84004P	\N	\N	\N
2218	SOCI	1992-10-08 00:00:00	1995-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	79004F	\N	\N	\N
2219	AFCL	1986-10-06 00:00:00	1995-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	78007E	\N	\N	\N
2220	ETRD	1995-10-05 00:00:00	1998-03-04 00:00:00	ANCIEN	\N	\N	\N	\N	86018E	\N	\N	\N
2221	SOCI	1977-10-06 00:00:00	1980-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	77043E	\N	\N	\N
2222	LOIS	1980-10-07 00:00:00	1983-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	77043E	\N	\N	\N
2223	FINC	1992-10-08 00:00:00	1997-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	83042R	\N	\N	\N
2224	LOIS	1974-10-04 00:00:00	1978-04-06 00:00:00	ANCIEN	\N	\N	\N	\N	66002K	\N	\N	\N
2225	SOCI	1989-10-05 00:00:00	1992-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	86042E	\N	\N	\N
2226	ECON	1983-10-06 00:00:00	1986-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	80040B	\N	\N	\N
2227	ECON	1986-10-06 00:00:00	1992-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	86047K	\N	\N	\N
2228	ECON	1986-10-06 00:00:00	1987-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	80046H	\N	\N	\N
2229	FINC	1989-04-05 00:00:00	1995-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	86018E	\N	\N	\N
2230	NEANT	1965-10-02 00:00:00	1965-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	000184	\N	\N	\N
2234	NEANT	1997-09-21 00:00:00	1997-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	95059Q	\N	\N	\N
2235	FINC	1959-01-21 00:00:00	1959-05-06 00:00:00	ANCIEN	\N	\N	\N	\N	000374	\N	\N	\N
2233	NEANT	1971-10-02 00:00:00	1971-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	000405	\N	\N	\N
2238	ECON	1966-10-05 00:00:00	1968-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	59242H	\N	\N	\N
2239	ETRD	1974-10-29 00:00:00	1992-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	59242H	\N	\N	\N
2240	ETRD	1988-06-28 00:00:00	1988-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	77053G	\N	\N	\N
2241	AFCL	1988-10-12 00:00:00	1993-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	77053G	\N	\N	\N
2242	NEANT	2004-05-01 00:00:00	2004-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	04016A	\N	\N	\N
2243	NEANT	2004-05-01 00:00:00	2004-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	04017B	\N	\N	\N
2244	NEANT	2004-05-01 00:00:00	2004-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	04018C	\N	\N	2017-10-04 18:47:13
1383	LOIS	1964-10-07 00:00:00	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000723	\N	\N	\N
2245	SOCI	1993-06-20 00:00:00	1993-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	000501	\N	\N	\N
2246	LOIS	1993-10-01 00:00:00	1994-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	000501	\N	\N	\N
1155	ECON	1959-10-08 00:00:00	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000062	\N	\N	\N
1749	SOCI	1989-10-04 00:00:00	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59560U	\N	\N	\N
2249	AFCL	1977-10-06 00:00:00	1989-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	59560U	\N	\N	\N
2250	AFCL	2004-05-06 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04018C	\N	\N	2017-10-04 19:46:53
2251	ECON	2004-05-06 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04016A	\N	\N	\N
2252	SOCI	2004-05-06 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04017B	\N	\N	\N
2253	FINC	1965-10-06 00:00:00	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000158	\N	\N	\N
2254	20040413N4	2004-04-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95030B	TITULAIRE	\N	2014-09-28 18:58:21
2255	20040413N4	2004-04-13 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95038K	TITULAIRE	\N	2014-09-28 17:40:23
2256	20040413N4	2004-04-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	01058X	TITULAIRE	\N	\N
1191	ECON	\N	1981-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	000237	\N	\N	\N
1192	AFCL	\N	1975-07-29 00:00:00	ANCIEN	\N	\N	\N	\N	000231	\N	\N	\N
1193	FINC	1959-05-06 00:00:00	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000153	\N	\N	\N
1194	ETRD	1959-05-06 00:00:00	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	57449N	\N	\N	\N
1195	ETRD	\N	1967-04-18 00:00:00	ANCIEN	\N	\N	\N	\N	000086	\N	\N	\N
1196	AFCL	\N	1974-10-13 00:00:00	ANCIEN	\N	\N	\N	\N	000063	\N	\N	\N
1197	AFCL	1968-10-04 00:00:00	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	57728S	\N	\N	\N
1198	SOCI	1959-05-06 00:00:00	1967-04-03 00:00:00	ANCIEN	\N	\N	\N	\N	56812H	\N	\N	\N
1199	AFCL	1959-04-26 00:00:00	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000230	\N	\N	\N
1200	ETRD	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000303	\N	\N	\N
1201	AFCL	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000219	\N	\N	\N
1202	ETRD	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000204	\N	\N	\N
1203	ECON	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	57129Y	\N	\N	\N
1204	AFCL	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000042	\N	\N	\N
1205	LOIS	\N	1972-12-05 00:00:00	ANCIEN	\N	\N	\N	\N	000093	\N	\N	\N
1206	ETRD	\N	1983-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	000170	\N	\N	\N
1207	FINC	\N	1981-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	58652T	\N	\N	\N
1208	ECON	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000014	\N	\N	\N
1209	ECON	\N	1978-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	57830P	\N	\N	\N
1210	SOCI	1959-05-06 00:00:00	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	57130R	\N	\N	\N
1211	ETRD	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000005	\N	\N	\N
1212	SOCI	1963-10-03 00:00:00	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000200	\N	\N	\N
1214	ETRD	1977-10-06 00:00:00	1982-08-15 00:00:00	ANCIEN	\N	\N	\N	\N	000633	\N	\N	\N
1215	LOIS	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000223	\N	\N	\N
1216	AFCL	\N	1973-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	000518	\N	\N	\N
2515	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04063H	\N	\N	\N
2516	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	\N	\N	\N
2517	ECON	2004-10-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04066L	\N	\N	\N
2518	ECON	2004-10-06 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	04068N	\N	\N	\N
2519	ECON	2004-10-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04077P	\N	\N	\N
2520	ECON	2004-10-06 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	03001N	\N	\N	\N
2521	ECON	2004-10-06 00:00:00	2007-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	04090L	\N	\N	\N
2522	ECON	2004-10-06 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	04065K	\N	\N	\N
2523	ECON	2004-10-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95044H	\N	\N	\N
2524	ECON	2004-10-06 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	04067M	\N	\N	\N
2525	FINC	2004-10-06 00:00:00	2012-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	\N	\N	\N
2526	FINC	2004-10-06 00:00:00	2014-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	01037S	\N	\N	2014-07-22 12:08:43
2527	FINC	2004-10-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83042R	\N	\N	\N
2528	ETRD	2004-10-06 00:00:00	2007-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	66002K	\N	\N	\N
2529	ETRD	2004-10-06 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	92015P	\N	\N	2014-10-08 17:02:50
2530	ETRD	2004-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	98022P	\N	\N	2017-10-04 00:00:00
2531	AFCL	2004-10-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01060R	\N	\N	\N
2532	ECON	2004-10-06 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	04033B	\N	\N	\N
2533	ETRD	2004-10-06 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	83047W	\N	\N	\N
2534	ETRD	2004-10-06 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80039J	\N	\N	\N
2536	ETRD	2004-10-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04056J	\N	\N	\N
2535	ECON	2004-10-06 00:00:00	2010-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	04071H	\N	\N	\N
2537	ETRD	2004-10-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01023L	\N	\N	\N
2538	ETRD	2004-10-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04082L	\N	\N	\N
2539	LOIS	2004-10-06 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	\N	\N	2017-10-04 18:53:16
2540	FINC	2004-10-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01013J	\N	\N	2017-09-24 17:06:55
2541	FINC	2004-10-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04050C	\N	\N	\N
2543	ECON	2004-10-06 00:00:00	2007-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	92018S	\N	\N	\N
2544	ECON	2004-10-06 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	04054G	\N	\N	\N
2546	ETRD	2004-10-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04078Q	\N	\N	2017-09-24 17:15:15
2547	ETRD	2004-10-06 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98016R	\N	\N	\N
2548	AFCL	2004-10-06 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	04051D	\N	\N	\N
2550	AFCL	2004-10-06 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	04083M	\N	\N	\N
2549	SOCI	2004-10-06 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04087R	\N	\N	2014-09-28 13:39:21
2551	SOCI	2004-10-06 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04046G	\N	\N	2014-09-28 17:07:41
2554	SOCI	2004-10-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04094Q	\N	\N	\N
2555	SOCI	2004-10-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04076N	\N	\N	\N
2556	SOCI	2004-10-06 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	04079R	\N	\N	\N
2557	SOCI	2004-10-06 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	04084N	\N	\N	\N
2558	ECON	2004-10-06 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	04089T	\N	\N	\N
2559	SOCI	2004-10-06 00:00:00	2020-02-25 00:00:00	ANCIEN	\N	\N	\N	\N	04045F	\N	\N	2017-10-04 20:06:57
2560	AFCL	2004-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04059M	\N	\N	2017-10-04 00:00:00
2562	AFCL	2004-10-06 00:00:00	2005-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	98006P	\N	\N	\N
2563	AFCL	2004-10-06 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	04040A	\N	\N	\N
2564	AFCL	2004-10-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04052E	\N	\N	\N
2565	AFCL	2004-10-06 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98034T	\N	\N	\N
2566	AFCL	2004-10-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83039W	\N	\N	\N
2567	AFCL	2004-10-06 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	86039K	\N	\N	\N
2569	COMSPEAPU	2004-10-06 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	98046X	\N	\N	\N
2571	COMSPEAPU	2004-10-06 00:00:00	2013-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	98010K	\N	\N	2013-10-03 18:07:38
2572	ETRD	2004-10-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01055U	\N	\N	\N
671	ECON	2001-10-03 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	01021J	\N	\N	\N
2573	ETRD	2004-10-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01021J	\N	\N	\N
2574	ETRD	2004-10-06 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98044V	\N	\N	\N
2575	ETRD	2004-10-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04080J	\N	\N	2017-09-24 17:47:27
2576	SOCI	2004-10-06 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	95005A	\N	\N	\N
2577	SOCI	2004-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01034P	\N	\N	2017-10-04 00:00:00
2578	FINC	2004-10-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04037F	\N	\N	\N
2579	LOIS	2004-10-06 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	01024M	\N	\N	2017-10-04 19:44:58
2581	LOIS	2004-10-06 00:00:00	2017-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	01007L	\N	\N	2017-07-24 09:56:26
2580	ETRD	2004-10-06 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89018S	\N	\N	\N
2582	LOIS	2004-10-06 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	89042S	\N	\N	\N
2583	ETRD	2004-10-06 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	77019E	\N	\N	\N
2584	ETRD	2004-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04035D	\N	\N	2017-10-04 00:00:00
2585	COMSPEAPU	2004-10-06 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89022N	\N	\N	2014-09-28 18:19:47
2586	ETRD	2004-10-06 00:00:00	2005-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	98017S	\N	\N	\N
2587	COMSPEAPU	2004-10-06 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	78003A	\N	\N	\N
2589	ETRD	2004-10-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98005N	\N	\N	2017-10-04 19:54:47
2590	ECON	2004-10-06 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	04091M	\N	\N	\N
2591	ETRD	2004-10-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77053G	\N	\N	\N
2592	ECON	2004-10-06 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	01064V	\N	\N	\N
2593	ETRD	2004-10-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83050R	\N	\N	\N
2594	ETRD	2004-10-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01056V	\N	\N	2017-09-24 17:04:02
2596	ECON	2004-10-06 00:00:00	2007-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04060E	\N	\N	\N
2597	FINC	2004-10-06 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	\N	\N	2017-10-04 19:49:46
2598	ECON	2004-10-06 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	04048J	\N	\N	\N
2599	FINC	2004-10-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04055H	\N	\N	2017-09-24 18:05:41
2600	ECON	2004-10-06 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	\N	\N	\N
2601	ECON	2004-10-06 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	02005N	\N	\N	\N
2602	FINC	2004-10-06 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	04061F	\N	\N	\N
2603	FINC	2004-10-06 00:00:00	2010-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	92029V	\N	\N	\N
2604	FINC	2004-10-06 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	01048V	\N	\N	\N
2606	FINC	2004-10-06 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80045G	\N	\N	\N
2607	LOIS	2004-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	\N	\N	2017-10-04 00:00:00
2608	LOIS	2004-10-06 00:00:00	2008-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	04042C	\N	\N	\N
2609	LOIS	2004-10-06 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	95019G	\N	\N	\N
2610	LOIS	2004-10-06 00:00:00	2007-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	04072J	\N	\N	\N
216	FINC	\N	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	86030A	\N	\N	\N
2611	LOIS	2004-10-06 00:00:00	2005-03-09 00:00:00	ANCIEN	\N	\N	\N	\N	86030A	\N	\N	\N
2612	LOIS	2004-10-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04074L	\N	\N	2017-09-24 17:15:15
2613	LOIS	2004-10-06 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98039Y	\N	\N	\N
2614	SOCI	2004-10-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04081K	\N	\N	2017-09-24 19:25:10
2615	SOCI	2004-10-06 00:00:00	2009-07-20 00:00:00	ANCIEN	\N	\N	\N	\N	04058L	\N	\N	\N
2616	SOCI	2004-10-06 00:00:00	2004-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	02009S	\N	\N	\N
2617	SOCI	2004-10-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04075M	\N	\N	\N
2738	20041221N18	2004-12-20 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	78003A	SUPPLEANT	\N	\N
2739	20041221N18	2004-12-20 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86049M	SUPPLEANT	\N	2014-09-28 18:03:38
2740	20041022N19	2004-10-20 00:00:00	2015-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-12 09:39:30
2741	20041022N19	2004-10-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01019Q	TITULAIRE	\N	2017-09-24 17:35:15
2742	20041022N19	2004-10-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98024R	TITULAIRE	\N	\N
2744	20041022N19	2004-10-20 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
2745	20041022N19	2004-10-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
2746	20041022N19	2004-10-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01038T	TITULAIRE	\N	\N
2747	20041022N19	2004-10-20 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01065W	SUPPLEANT	\N	2014-09-28 12:09:44
2748	20041022N19	2004-10-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	\N	\N
2749	20041022N19	2004-10-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	SUPPLEANT	\N	\N
2750	20041022N19	2004-10-20 00:00:00	2008-09-07 00:00:00	ANCIEN	\N	\N	\N	\N	80017C	SUPPLEANT	\N	\N
2751	20041022N19	2004-10-20 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98041S	SUPPLEANT	\N	2014-09-28 16:42:05
2752	20041022N19	2004-10-20 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	SUPPLEANT	\N	2014-09-28 18:00:58
2753	20041022N19	2004-10-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01054T	SUPPLEANT	\N	\N
2754	SOCI	2005-01-19 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	04101V	\N	\N	\N
2757	AMIANTE	2005-02-02 00:00:00	2005-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	97009N	\N	\N	\N
2758	AMIANTE	2005-02-02 00:00:00	2005-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	\N	\N	\N
2759	AMIANTE	2005-02-02 00:00:00	2005-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	92011K	\N	\N	\N
2760	AMIANTE	2005-02-02 00:00:00	2005-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	01044R	\N	\N	\N
2761	AMIANTE	2005-02-02 00:00:00	2005-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	\N	\N	\N
2762	AMIANTE	2005-02-02 00:00:00	2005-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	92018S	\N	\N	\N
2763	AMIANTE	2005-02-02 00:00:00	2005-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	98024R	\N	\N	\N
2287	20040512N6	2004-05-12 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	98012M	TITULAIRE	\N	\N
2288	20040512N6	2004-05-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01013J	TITULAIRE	\N	2017-09-24 17:06:55
2289	20040512N6	2004-05-12 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89027T	SUPPLEANT	\N	\N
2618	SOCI	2004-10-06 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	04036E	\N	\N	2014-10-08 17:37:34
2619	SOCI	2004-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	\N	\N	2017-10-04 00:00:00
2620	SOCI	2004-10-06 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	95051G	\N	\N	\N
2621	SOCI	2004-10-06 00:00:00	2005-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	04088S	\N	\N	\N
2623	SOCI	2004-10-06 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	04069P	\N	\N	\N
2624	AFCL	2004-10-06 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	89020L	\N	\N	\N
2625	AFCL	2004-10-06 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04073K	\N	\N	2014-09-28 18:58:25
2626	AFCL	2004-10-06 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	04093P	\N	\N	\N
2627	AFCL	2004-10-06 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89027T	\N	\N	\N
2628	AFCL	2004-10-06 00:00:00	2005-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	95031C	\N	\N	\N
2629	AFCL	2004-10-06 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	04041B	\N	\N	\N
2470	NEANT	2004-10-01 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04057K	\N	\N	\N
2631	AFCL	2004-10-06 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04057K	\N	\N	2017-10-04 19:45:22
2632	AFCL	2004-10-06 00:00:00	2017-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	95059Q	\N	\N	2017-10-05 09:35:29
2633	AFCL	2004-10-06 00:00:00	2005-03-09 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	\N	\N	\N
2634	COMSPEAPU	2004-10-06 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	\N	\N	\N
2635	COMSPEAPU	2004-10-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98053W	\N	\N	\N
2636	COMSPEAPU	2004-10-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04037F	\N	\N	\N
2638	AFCL	2004-10-12 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89042S	\N	\N	\N
2639	ECON	2004-10-12 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	04083M	\N	\N	\N
2640	LOIS	2004-10-12 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	96008H	\N	\N	\N
2643	NEANT	2004-10-19 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	04097T	\N	\N	\N
2644	20040727N14	2004-07-27 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98041S	TITULAIRE	\N	2014-09-28 16:42:05
2645	20040727N14	2004-07-27 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	88009M	TITULAIRE	\N	\N
2646	20040727N14	2004-07-27 00:00:00	2009-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	95049N	TITULAIRE	\N	\N
2647	20040727N14	2004-07-27 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95055L	TITULAIRE	\N	2014-09-28 13:21:47
2264	20040413N4	2004-04-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01061S	SUPPLEANT	\N	2017-09-24 17:48:21
2265	20040413N4	2004-04-13 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89040Q	SUPPLEANT	\N	\N
2266	20040413N4	2004-04-13 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	03002P	SUPPLEANT	\N	\N
2267	20040413N4	2004-04-13 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	98012M	SUPPLEANT	\N	\N
2268	20040415N5	2004-04-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98041S	TITULAIRE	\N	2014-09-28 16:42:05
2269	20040415N5	2004-04-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	TITULAIRE	\N	2014-09-28 18:00:58
2270	20040415N5	2004-04-15 00:00:00	2015-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-12 09:39:30
2271	20040415N5	2004-04-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01001E	TITULAIRE	\N	\N
2272	20040415N5	2004-04-15 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	92022N	TITULAIRE	\N	\N
2274	20040415N5	2004-04-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01038T	TITULAIRE	\N	\N
2276	20040415N5	2004-04-15 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	01063U	SUPPLEANT	\N	2014-09-29 13:41:53
2277	20040415N5	2004-04-15 00:00:00	2008-09-07 00:00:00	ANCIEN	\N	\N	\N	\N	80017C	SUPPLEANT	\N	\N
3744	2007CMP12	2007-07-31 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	SUPPLEANT	\N	2017-09-24 13:44:49
3833	NEANT	2007-12-17 00:00:00	2008-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	07034Q	\N	\N	\N
3940	NEANT	1959-05-31 00:00:00	1959-07-01 00:00:00	ANCIEN	\N	\N	\N	\N	000021	\N	\N	\N
4087	2008CMP11	2008-07-17 00:00:00	2008-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	07033P	SUPPLEANT	\N	\N
4088	2008CMP11	2008-07-17 00:00:00	2008-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	07026Q	SUPPLEANT	\N	2017-09-24 19:25:10
4089	2008CMP11	2008-07-17 00:00:00	2008-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	92031P	SUPPLEANT	\N	2017-09-24 18:16:52
4090	2008CMP11	2008-07-17 00:00:00	2008-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	04057K	SUPPLEANT	\N	\N
4091	2008CMP11	2008-07-17 00:00:00	2008-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	01054T	SUPPLEANT	\N	\N
4105	2008CMP12	2008-07-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	95035G	SUPPLEANT	\N	2017-09-24 18:17:56
4119	2008CMP13	2008-07-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	01033N	SUPPLEANT	\N	\N
4120	2008CMP13	2008-07-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	92030N	SUPPLEANT	\N	\N
4121	2008CMP13	2008-07-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	89041R	SUPPLEANT	\N	\N
4129	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08015R	\N	\N	\N
3369	20061030N49	2006-10-30 00:00:00	2006-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	SUPPLEANT	\N	\N
3370	20061030N49	2006-10-30 00:00:00	2006-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	04090L	SUPPLEANT	\N	\N
3448	FORMATION	2007-01-10 00:00:00	2007-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	98011L	\N	\N	\N
3449	FORMATION	2007-01-10 00:00:00	2007-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	95015C	\N	\N	\N
3450	FORMATION	2007-01-10 00:00:00	2007-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	83021L	\N	\N	\N
3451	FORMATION	2007-01-10 00:00:00	2007-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	04055H	\N	\N	\N
3452	FORMATION	2007-01-10 00:00:00	2007-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	\N	\N	\N
3453	FORMATION	2007-01-10 00:00:00	2007-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	04081K	\N	\N	\N
3454	FORMATION	2007-01-10 00:00:00	2007-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	90004C	\N	\N	\N
3455	FORMATION	2007-01-10 00:00:00	2007-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	04046G	\N	\N	\N
3457	FORMATION	2007-01-10 00:00:00	2007-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	04051D	\N	\N	\N
3458	FORMATION	2007-01-10 00:00:00	2007-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	98042T	\N	\N	\N
3459	FORMATION	2007-01-10 00:00:00	2007-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	94003T	\N	\N	\N
3460	FORMATION	2007-01-10 00:00:00	2007-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	78003A	\N	\N	\N
3461	FORMATION	2007-01-10 00:00:00	2007-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	01011G	\N	\N	\N
3462	FORMATION	2007-01-10 00:00:00	2007-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	95035G	\N	\N	\N
3463	FORMATION	2007-01-10 00:00:00	2007-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	98028V	\N	\N	\N
3465	FORMATION	2007-01-10 00:00:00	2007-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	92031P	\N	\N	\N
3466	FORMATION	2007-01-10 00:00:00	2007-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	01043Q	\N	\N	\N
3467	FORMATION	2007-01-10 00:00:00	2007-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	86039K	\N	\N	\N
3468	FORMATION	2007-01-10 00:00:00	2007-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	04057K	\N	\N	\N
3469	FORMATION	2007-01-10 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	00002B	\N	\N	\N
3470	FORMATION	2007-01-10 00:00:00	2007-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	96007G	\N	\N	\N
3471	FORMATION	2007-01-10 00:00:00	2007-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	01029S	\N	\N	\N
3472	FORMATION	2007-01-10 00:00:00	2007-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	89041R	\N	\N	\N
3473	FORMATION	2007-01-10 00:00:00	2007-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	04069P	\N	\N	\N
3474	FORMATION	2007-01-10 00:00:00	2007-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	80041C	\N	\N	\N
3477	ELECTRICITE	2007-01-10 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	01013J	\N	\N	\N
3478	ELECTRICITE	2007-01-10 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	04091M	\N	\N	\N
3479	ELECTRICITE	2007-01-10 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	04054G	\N	\N	\N
3480	ELECTRICITE	2007-01-10 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	\N	\N	\N
3481	ELECTRICITE	2007-01-10 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	90003B	\N	\N	\N
3482	ELECTRICITE	2007-01-10 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	95025E	\N	\N	\N
3484	ELECTRICITE	2007-01-10 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	98030P	\N	\N	\N
3485	ELECTRICITE	2007-01-10 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	04071H	\N	\N	\N
3486	ELECTRICITE	2007-01-10 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	89007P	\N	\N	\N
3487	ELECTRICITE	2007-01-10 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	98045W	\N	\N	\N
3488	ELECTRICITE	2007-01-10 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	85003S	\N	\N	\N
3489	ELECTRICITE	2007-01-10 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	97004H	\N	\N	\N
3490	ELECTRICITE	2007-01-10 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	\N	\N	2018-02-02 10:20:31
3491	ELECTRICITE	2007-01-10 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	01048V	\N	\N	\N
3492	ELECTRICITE	2007-01-10 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	02005N	\N	\N	\N
3493	ELECTRICITE	2007-01-10 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	95052H	\N	\N	\N
3495	ELECTRICITE	2007-01-10 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	98021N	\N	\N	\N
3496	ELECTRICITE	2007-01-10 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	\N	\N	\N
3497	ELECTRICITE	2007-01-10 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	04090L	\N	\N	\N
3498	ELECTRICITE	2007-01-10 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	89037V	\N	\N	\N
3499	ELECTRICITE	2007-01-10 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	92043T	\N	\N	\N
3500	ELECTRICITE	2007-01-10 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	01058X	\N	\N	\N
3501	ELECTRICITE	2007-01-10 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	80046H	\N	\N	\N
3502	ELECTRICITE	2007-01-10 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	89042S	\N	\N	\N
3503	ELECTRICITE	2007-01-10 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	04082L	\N	\N	\N
3504	ECON	2007-01-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	07001F	\N	\N	\N
3311	20060608N46	2006-06-08 00:00:00	2006-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	04060E	TITULAIRE	\N	\N
3312	20060608N46	2006-06-08 00:00:00	2006-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	04090L	TITULAIRE	\N	\N
3313	20060608N46	2006-06-08 00:00:00	2006-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	04066L	TITULAIRE	\N	2017-09-24 17:47:28
3314	20060608N46	2006-06-08 00:00:00	2006-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	01006K	SUPPLEANT	\N	\N
3315	20060608N46	2006-06-08 00:00:00	2006-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	98036V	SUPPLEANT	\N	2014-09-28 17:15:42
3316	20060608N46	2006-06-08 00:00:00	2006-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	80015A	SUPPLEANT	\N	\N
3317	20060608N46	2006-06-08 00:00:00	2006-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	92018S	SUPPLEANT	\N	2017-09-24 18:16:52
3318	20060608N46	2006-06-08 00:00:00	2006-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	95038K	SUPPLEANT	\N	2014-09-28 17:40:23
3319	20060608N46	2006-06-08 00:00:00	2006-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	02005N	SUPPLEANT	\N	\N
3320	20060608N46	2006-06-08 00:00:00	2006-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	SUPPLEANT	\N	2017-09-24 17:09:24
3321	20060616N47	2006-06-16 00:00:00	2006-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-12 09:39:30
3322	20060616N47	2006-06-16 00:00:00	2006-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
3323	20060616N47	2006-06-16 00:00:00	2006-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	TITULAIRE	\N	2014-09-28 18:00:58
3324	20060616N47	2006-06-16 00:00:00	2006-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	95020Y	TITULAIRE	\N	2015-06-12 16:01:25
3325	20060616N47	2006-06-16 00:00:00	2006-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	TITULAIRE	\N	2017-09-24 13:29:42
3326	20060616N47	2006-06-16 00:00:00	2006-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	02001J	TITULAIRE	\N	\N
3327	20060616N47	2006-06-16 00:00:00	2006-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	TITULAIRE	\N	\N
3328	20060616N47	2006-06-16 00:00:00	2006-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	01024M	SUPPLEANT	\N	\N
3329	20060616N47	2006-06-16 00:00:00	2006-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	80017C	SUPPLEANT	\N	\N
3330	20060616N47	2006-06-16 00:00:00	2006-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	04072J	SUPPLEANT	\N	\N
3331	20060616N47	2006-06-16 00:00:00	2006-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	01042P	SUPPLEANT	\N	2015-04-21 17:14:30
3332	20060616N47	2006-06-16 00:00:00	2006-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	89035T	SUPPLEANT	\N	\N
3333	20060616N47	2006-06-16 00:00:00	2006-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	04074L	SUPPLEANT	\N	2017-09-24 17:15:15
3335	20060615N48	2006-06-15 00:00:00	2006-06-22 00:00:00	ANCIEN	\N	\N	\N	\N	80046H	TITULAIRE	\N	\N
3336	20060615N48	2006-06-15 00:00:00	2006-06-22 00:00:00	ANCIEN	\N	\N	\N	\N	01039U	TITULAIRE	\N	\N
3337	20060615N48	2006-06-15 00:00:00	2006-06-22 00:00:00	ANCIEN	\N	\N	\N	\N	87003B	TITULAIRE	\N	2014-09-28 17:35:38
3339	20060615N48	2006-06-15 00:00:00	2006-06-22 00:00:00	ANCIEN	\N	\N	\N	\N	04070G	TITULAIRE	\N	\N
3340	20060615N48	2006-06-15 00:00:00	2006-06-22 00:00:00	ANCIEN	\N	\N	\N	\N	04059M	TITULAIRE	\N	\N
3342	20060615N48	2006-06-15 00:00:00	2006-06-22 00:00:00	ANCIEN	\N	\N	\N	\N	01044R	SUPPLEANT	\N	2017-07-04 15:08:09
3343	20060615N48	2006-06-15 00:00:00	2006-06-22 00:00:00	ANCIEN	\N	\N	\N	\N	98048A	SUPPLEANT	\N	\N
3344	20060615N48	2006-06-15 00:00:00	2006-06-22 00:00:00	ANCIEN	\N	\N	\N	\N	95015C	SUPPLEANT	\N	\N
3345	20060615N48	2006-06-15 00:00:00	2006-06-22 00:00:00	ANCIEN	\N	\N	\N	\N	98028V	SUPPLEANT	\N	2014-09-28 17:22:11
3346	20060615N48	2006-06-15 00:00:00	2006-06-22 00:00:00	ANCIEN	\N	\N	\N	\N	01054T	SUPPLEANT	\N	\N
3347	20060615N48	2006-06-15 00:00:00	2006-06-22 00:00:00	ANCIEN	\N	\N	\N	\N	95060H	SUPPLEANT	\N	\N
3348	20060615N48	2006-06-15 00:00:00	2006-06-22 00:00:00	ANCIEN	\N	\N	\N	\N	92005M	SUPPLEANT	\N	\N
3349	SOCI	2006-06-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	06001B	\N	\N	\N
3350	AFCL	2006-06-30 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04101V	\N	\N	\N
3392	20061117N51	2006-11-17 00:00:00	2006-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	83012K	TITULAIRE	\N	\N
3393	20061117N51	2006-11-17 00:00:00	2006-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	SUPPLEANT	\N	2017-09-24 13:44:49
3394	20061117N51	2006-11-17 00:00:00	2006-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	92011K	SUPPLEANT	\N	\N
3395	20061117N51	2006-11-17 00:00:00	2006-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	04046G	SUPPLEANT	\N	2014-09-28 17:07:41
3505	LOIS	2007-01-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98052V	\N	\N	\N
3506	AFCL	2007-01-18 00:00:00	2008-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	92033R	\N	\N	\N
3509	NEANT	2007-01-26 00:00:00	2007-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	07003H	\N	\N	\N
3539	ETRD	2007-06-26 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	07004J	\N	\N	2017-10-04 19:17:05
3635	ECON	2007-06-26 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	66002K	\N	\N	\N
3636	SERVICE	2007-07-05 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	04091M	\N	\N	\N
3637	SERVICE	2007-07-05 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	04054G	\N	\N	\N
3638	SERVICE	2007-07-05 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	92011K	\N	\N	\N
3639	SERVICE	2007-07-05 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	\N	\N	\N
3640	SERVICE	2007-07-05 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	01049W	\N	\N	\N
3641	SERVICE	2007-07-05 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	04042C	\N	\N	\N
3642	SERVICE	2007-07-05 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	\N	\N	\N
3643	SERVICE	2007-07-05 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	04046G	\N	\N	\N
3644	SERVICE	2007-07-05 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	98030P	\N	\N	\N
3645	SERVICE	2007-07-05 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	04067M	\N	\N	\N
3646	SERVICE	2007-07-05 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	\N	\N	\N
3649	SERVICE	2007-07-05 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	04060E	\N	\N	\N
3650	SERVICE	2007-07-05 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	88009M	\N	\N	\N
3651	SERVICE	2007-07-05 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	95035G	\N	\N	\N
3652	SERVICE	2007-07-05 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	04089T	\N	\N	\N
3653	SERVICE	2007-07-05 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	95038K	\N	\N	\N
3654	SERVICE	2007-07-05 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	04075M	\N	\N	\N
3655	SERVICE	2007-07-05 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	03001N	\N	\N	\N
3656	SERVICE	2007-07-05 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	92029V	\N	\N	\N
3657	SERVICE	2007-07-05 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	01018P	\N	\N	\N
3658	SERVICE	2007-07-05 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	92030N	\N	\N	\N
3659	SERVICE	2007-07-05 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	01048V	\N	\N	\N
3660	SERVICE	2007-07-05 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	04074L	\N	\N	\N
3661	SERVICE	2007-07-05 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	04043D	\N	\N	\N
3687	AFCL	2007-07-25 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	07025P	\N	\N	\N
3664	SERVICE	2007-07-05 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	01014K	\N	\N	\N
3665	SERVICE	2007-07-05 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	04065K	\N	\N	\N
3666	SERVICE	2007-07-05 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	95062K	\N	\N	\N
3667	SERVICE	2007-07-05 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	01029S	\N	\N	\N
3668	SERVICE	2007-07-05 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	04033B	\N	\N	\N
3669	SERVICE	2007-07-05 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	98037W	\N	\N	\N
3670	SERVICE	2007-07-05 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	80041C	\N	\N	\N
3671	SERVICE	2007-07-05 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	96008H	\N	\N	\N
3673	AFCL	2007-07-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	07026Q	\N	\N	2017-09-24 19:25:10
3745	2007CMP12	2007-07-31 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	04091M	SUPPLEANT	\N	2014-09-28 17:55:37
3746	2007CMP12	2007-07-31 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	04042C	SUPPLEANT	\N	\N
3747	2007CMP12	2007-07-31 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	04060E	SUPPLEANT	\N	\N
3748	2007CMP12	2007-07-31 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	03001N	SUPPLEANT	\N	2014-09-28 13:40:33
3750	2007CMP12	2007-07-31 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	96007G	SUPPLEANT	\N	2014-09-01 10:21:13
3756	2007CMP13	2007-10-11 00:00:00	2007-10-16 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-12 09:39:30
3757	2007CMP13	2007-10-11 00:00:00	2007-10-16 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
3758	2007CMP13	2007-10-11 00:00:00	2007-10-16 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	TITULAIRE	\N	2014-09-28 18:00:58
3759	2007CMP13	2007-10-11 00:00:00	2007-10-16 00:00:00	ANCIEN	\N	\N	\N	\N	95020Y	TITULAIRE	\N	2015-06-12 16:01:25
3760	2007CMP13	2007-10-11 00:00:00	2007-10-16 00:00:00	ANCIEN	\N	\N	\N	\N	92022N	TITULAIRE	\N	\N
3761	2007CMP13	2007-10-11 00:00:00	2007-10-16 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	TITULAIRE	\N	\N
3762	2007CMP13	2007-10-11 00:00:00	2007-10-16 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	TITULAIRE	\N	\N
3763	2007CMP13	2007-10-11 00:00:00	2007-10-16 00:00:00	ANCIEN	\N	\N	\N	\N	01001E	SUPPLEANT	\N	\N
3764	2007CMP13	2007-10-11 00:00:00	2007-10-16 00:00:00	ANCIEN	\N	\N	\N	\N	04063H	SUPPLEANT	\N	\N
3766	2007CMP13	2007-10-11 00:00:00	2007-10-16 00:00:00	ANCIEN	\N	\N	\N	\N	89035T	SUPPLEANT	\N	\N
3767	2007CMP13	2007-10-11 00:00:00	2007-10-16 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	SUPPLEANT	\N	\N
3768	2007CMP13	2007-10-11 00:00:00	2007-10-16 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	\N	\N
3769	2007CMP13	2007-10-11 00:00:00	2007-10-16 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	SUPPLEANT	\N	2017-09-24 13:29:42
3777	2007CMP14	2007-11-16 00:00:00	2007-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	98029W	TITULAIRE	\N	\N
3778	2007CMP14	2007-11-16 00:00:00	2007-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	TITULAIRE	\N	2014-09-28 17:07:41
3782	2007CMP14	2007-11-16 00:00:00	2007-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	92011K	SUPPLEANT	\N	\N
3789	AFCL	2017-10-05 00:00:00	2021-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	07033P	\N	\N	2017-10-04 19:42:44
3790	SOCI	2007-12-03 00:00:00	2016-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	07032N	\N	\N	2016-11-18 12:37:49
3819	2007CMP15	2007-12-11 00:00:00	2007-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	83011J	TITULAIRE	\N	2014-07-01 09:25:11
3820	2007CMP15	2007-12-11 00:00:00	2007-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
3822	2007CMP15	2007-12-11 00:00:00	2007-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	77043E	TITULAIRE	\N	2014-09-28 16:59:41
3823	2007CMP15	2007-12-11 00:00:00	2007-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	98032R	TITULAIRE	\N	2015-06-12 15:59:49
3824	2007CMP15	2007-12-11 00:00:00	2007-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	95003X	TITULAIRE	\N	\N
3826	2007CMP15	2007-12-11 00:00:00	2007-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	89017R	SUPPLEANT	\N	\N
3827	2007CMP15	2007-12-11 00:00:00	2007-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	95007C	SUPPLEANT	\N	\N
3828	2007CMP15	2007-12-11 00:00:00	2007-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	81015E	SUPPLEANT	\N	\N
3829	2007CMP15	2007-12-11 00:00:00	2007-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	SUPPLEANT	\N	\N
3830	2007CMP15	2007-12-11 00:00:00	2007-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	98047Y	SUPPLEANT	\N	\N
3831	2007CMP15	2007-12-11 00:00:00	2007-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	78003A	SUPPLEANT	\N	\N
3832	2007CMP15	2007-12-11 00:00:00	2007-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	92043T	SUPPLEANT	\N	\N
3863	ETRD	2008-01-09 00:00:00	2009-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	92033R	\N	\N	\N
3864	PAUVRETE	2008-01-10 00:00:00	2008-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	92011K	\N	\N	\N
3355	NEANT	2006-09-25 00:00:00	2006-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	06006G	\N	\N	\N
3629	AFCL	2007-06-26 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04099V	\N	\N	2014-09-28 16:59:41
3630	AFCL	2007-06-26 00:00:00	2007-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	04072J	\N	\N	\N
3631	LOIS	2007-06-26 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	\N	\N	2017-10-04 18:57:28
3632	ETRD	2007-06-26 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	86030A	\N	\N	\N
3633	FINC	2007-06-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01057W	\N	\N	2017-10-04 00:00:00
3634	FINC	2007-06-26 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	98019U	\N	\N	2014-09-29 13:43:10
3689	ECON	2007-09-18 00:00:00	2007-09-19 00:00:00	ANCIEN	\N	\N	\N	\N	07029T	\N	\N	\N
3690	SOCI	2007-09-18 00:00:00	2007-09-19 00:00:00	ANCIEN	\N	\N	\N	\N	07030L	\N	\N	\N
3783	2007CMP14	2007-11-16 00:00:00	2007-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	04075M	SUPPLEANT	\N	\N
3784	2007CMP14	2007-11-16 00:00:00	2007-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	01030K	SUPPLEANT	\N	\N
3785	2007CMP14	2007-11-16 00:00:00	2007-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	92030N	SUPPLEANT	\N	\N
3865	PAUVRETE	2008-01-10 00:00:00	2008-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	04052E	\N	\N	\N
3866	PAUVRETE	2008-01-10 00:00:00	2008-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	02003L	\N	\N	\N
3867	PAUVRETE	2008-01-10 00:00:00	2008-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	\N	\N	\N
3868	PAUVRETE	2008-01-10 00:00:00	2008-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	04081K	\N	\N	\N
3869	PAUVRETE	2008-01-10 00:00:00	2008-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	95024D	\N	\N	\N
3870	PAUVRETE	2008-01-10 00:00:00	2008-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	07028S	\N	\N	\N
3871	PAUVRETE	2008-01-10 00:00:00	2008-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	04067M	\N	\N	\N
3872	PAUVRETE	2008-01-10 00:00:00	2008-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	04051D	\N	\N	\N
3873	PAUVRETE	2008-01-10 00:00:00	2008-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	98030P	\N	\N	\N
3874	PAUVRETE	2008-01-10 00:00:00	2008-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	\N	\N	\N
3876	PAUVRETE	2008-01-10 00:00:00	2008-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	95035G	\N	\N	\N
3877	PAUVRETE	2008-01-10 00:00:00	2008-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	01022K	\N	\N	\N
3878	PAUVRETE	2008-01-10 00:00:00	2008-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	98028V	\N	\N	\N
3879	PAUVRETE	2008-01-10 00:00:00	2008-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	04097T	\N	\N	\N
3880	PAUVRETE	2008-01-10 00:00:00	2008-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	06001B	\N	\N	\N
3881	PAUVRETE	2008-01-10 00:00:00	2008-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	97004H	\N	\N	\N
3882	PAUVRETE	2008-01-10 00:00:00	2008-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	04057K	\N	\N	\N
3835	2007CMP16	2007-12-14 00:00:00	2007-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	95030B	TITULAIRE	\N	2014-09-28 18:58:21
3836	2007CMP16	2007-12-14 00:00:00	2007-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	98023Q	TITULAIRE	\N	\N
3855	2007CMP17	2007-12-18 00:00:00	2007-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	04050C	TITULAIRE	\N	\N
3856	2007CMP17	2007-12-18 00:00:00	2007-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	89017R	SUPPLEANT	\N	\N
3883	PAUVRETE	2008-01-10 00:00:00	2008-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	07023M	\N	\N	\N
3884	PAUVRETE	2008-01-10 00:00:00	2008-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	04088S	\N	\N	\N
3885	PAUVRETE	2008-01-10 00:00:00	2008-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	96007G	\N	\N	\N
3886	PAUVRETE	2008-01-10 00:00:00	2008-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	95062K	\N	\N	\N
3887	PAUVRETE	2008-01-10 00:00:00	2008-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	01036R	\N	\N	\N
3888	PAUVRETE	2008-01-10 00:00:00	2008-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	89041R	\N	\N	\N
3889	PAUVRETE	2008-01-10 00:00:00	2008-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	04069P	\N	\N	\N
3890	PAUVRETE	2008-01-10 00:00:00	2008-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	89042S	\N	\N	\N
3896	2008CMP1	2008-01-24 00:00:00	2008-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	95004Y	TITULAIRE	\N	\N
3899	2008CMP1	2008-01-24 00:00:00	2008-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	95035G	TITULAIRE	\N	2017-09-24 18:17:56
3901	2008CMP1	2008-01-24 00:00:00	2008-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	04076N	TITULAIRE	\N	\N
3902	2008CMP1	2008-01-24 00:00:00	2008-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	TITULAIRE	\N	2017-09-24 17:35:15
3903	2008CMP1	2008-01-24 00:00:00	2008-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	83012K	SUPPLEANT	\N	\N
3904	2008CMP1	2008-01-24 00:00:00	2008-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	01045S	SUPPLEANT	\N	\N
3905	2008CMP1	2008-01-24 00:00:00	2008-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	98045W	SUPPLEANT	\N	\N
3906	2008CMP1	2008-01-24 00:00:00	2008-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	01009N	SUPPLEANT	\N	\N
3910	2008CMP2	2008-01-24 00:00:00	2008-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	95004Y	TITULAIRE	\N	\N
3911	2008CMP2	2008-01-24 00:00:00	2008-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	04043D	TITULAIRE	\N	\N
3912	2008CMP2	2008-01-24 00:00:00	2008-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	92011K	TITULAIRE	\N	\N
3913	2008CMP2	2008-01-24 00:00:00	2008-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	95035G	TITULAIRE	\N	2017-09-24 18:17:56
3914	2008CMP2	2008-01-24 00:00:00	2008-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	80041C	TITULAIRE	\N	\N
3916	2008CMP2	2008-01-24 00:00:00	2008-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	TITULAIRE	\N	2017-09-24 17:35:15
3917	2008CMP2	2008-01-24 00:00:00	2008-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	83012K	SUPPLEANT	\N	\N
3919	2008CMP2	2008-01-24 00:00:00	2008-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	02003L	SUPPLEANT	\N	\N
3920	2008CMP2	2008-01-24 00:00:00	2008-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	06001B	SUPPLEANT	\N	\N
3814	DEPENDANCE	2007-12-05 00:00:00	2011-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	01045S	\N	\N	\N
3815	DEPENDANCE	2007-12-05 00:00:00	2009-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	86044G	\N	\N	\N
3816	DEPENDANCE	2007-12-05 00:00:00	2011-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	01036R	\N	\N	\N
3817	DEPENDANCE	2007-12-05 00:00:00	2011-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	\N	\N	\N
3818	DEPENDANCE	2007-12-05 00:00:00	2011-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	86049M	\N	\N	\N
3857	2007CMP17	2007-12-18 00:00:00	2007-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	95007C	SUPPLEANT	\N	\N
3858	2007CMP17	2007-12-18 00:00:00	2007-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	81015E	SUPPLEANT	\N	\N
3859	2007CMP17	2007-12-18 00:00:00	2007-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	01037S	SUPPLEANT	\N	2016-12-12 16:10:15
3860	2007CMP17	2007-12-18 00:00:00	2007-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	78003A	SUPPLEANT	\N	\N
3861	2007CMP17	2007-12-18 00:00:00	2007-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	92029V	SUPPLEANT	\N	\N
3862	2007CMP17	2007-12-18 00:00:00	2007-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	86049M	SUPPLEANT	\N	2014-09-28 18:03:38
3943	AFCL	2008-03-25 00:00:00	2008-04-18 00:00:00	ANCIEN	\N	\N	\N	\N	95031C	\N	\N	\N
3944	ETRD	2008-03-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04042C	\N	\N	2017-10-04 00:00:00
3982	2008CMP6	2008-05-21 00:00:00	2008-06-03 00:00:00	ANCIEN	\N	\N	\N	\N	04076N	SUPPLEANT	\N	\N
4234	NEANT	2008-09-25 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08074D	\N	\N	\N
4235	ECON	2008-10-07 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	08054Y	\N	\N	\N
4236	SOCI	2008-10-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08026U	\N	\N	2014-09-28 17:52:18
4237	ECON	2008-10-07 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	08016S	\N	\N	\N
4238	ETRD	2008-10-07 00:00:00	2012-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	04054G	\N	\N	2013-12-04 10:36:17
4240	COMSPEAPU	2008-10-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98035U	\N	\N	\N
4241	COMSPEAPU	2008-10-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98030P	\N	\N	2014-09-28 13:19:48
4242	COMSPEAPU	2008-10-07 00:00:00	2015-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	92039X	\N	\N	2015-12-16 17:18:53
4243	COMSPEAPU	2008-10-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	78006D	\N	\N	\N
4244	AFCL	2008-10-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08055A	\N	\N	\N
4245	AFCL	2008-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08043V	\N	\N	2017-10-04 19:40:28
4246	AFCL	2008-10-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08050U	\N	\N	\N
4247	AFCL	2008-10-07 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	08024S	\N	\N	2017-10-04 19:12:49
4248	AFCL	2008-10-07 00:00:00	2013-07-14 00:00:00	ANCIEN	\N	\N	\N	\N	98030P	\N	\N	2013-07-15 18:30:07
4249	AFCL	2008-10-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08045X	\N	\N	\N
4250	AFCL	2008-10-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08063A	\N	\N	2014-09-28 17:07:07
4251	AFCL	2008-10-07 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08017T	\N	\N	2017-10-04 19:44:35
4252	AFCL	2008-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08012N	\N	\N	2017-10-04 00:00:00
4253	ECON	2008-10-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08040S	\N	\N	\N
4254	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08014Q	\N	\N	\N
3378	20061115N50	2006-11-23 00:00:00	2006-11-28 00:00:00	ANCIEN	\N	\N	\N	\N	00002B	TITULAIRE	\N	\N
3379	20061115N50	2006-11-23 00:00:00	2006-11-28 00:00:00	ANCIEN	\N	\N	\N	\N	92011K	SUPPLEANT	\N	\N
3380	20061115N50	2006-11-23 00:00:00	2006-11-28 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	SUPPLEANT	\N	2014-09-28 17:07:41
3381	20061115N50	2006-11-23 00:00:00	2006-11-28 00:00:00	ANCIEN	\N	\N	\N	\N	06001B	SUPPLEANT	\N	\N
3382	20061115N50	2006-11-23 00:00:00	2006-11-28 00:00:00	ANCIEN	\N	\N	\N	\N	01018P	SUPPLEANT	\N	\N
3384	20061115N50	2006-11-23 00:00:00	2006-11-28 00:00:00	ANCIEN	\N	\N	\N	\N	89041R	SUPPLEANT	\N	\N
3385	20061115N50	2006-11-23 00:00:00	2006-11-28 00:00:00	ANCIEN	\N	\N	\N	\N	01034P	SUPPLEANT	\N	\N
3446	20061219N54	2006-12-19 00:00:00	2006-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	95003X	SUPPLEANT	\N	\N
3447	20061219N54	2006-12-19 00:00:00	2006-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	86049M	SUPPLEANT	\N	2014-09-28 18:03:38
3521	2007CMP1	2007-01-25 00:00:00	2007-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	01057W	SUPPLEANT	\N	\N
3522	2007CMP1	2007-01-25 00:00:00	2007-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	89035T	SUPPLEANT	\N	\N
3523	2007CMP1	2007-01-25 00:00:00	2007-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	04074L	SUPPLEANT	\N	2017-09-24 17:15:15
3524	2007CMP1	2007-01-25 00:00:00	2007-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	98035U	SUPPLEANT	\N	\N
3526	2007CMP2	2007-01-25 00:00:00	2007-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	TITULAIRE	\N	2017-09-24 13:44:49
3527	2007CMP2	2007-01-25 00:00:00	2007-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	98024R	TITULAIRE	\N	\N
3528	2007CMP2	2007-01-25 00:00:00	2007-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	92030N	TITULAIRE	\N	\N
3529	2007CMP2	2007-01-25 00:00:00	2007-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	TITULAIRE	\N	\N
3530	2007CMP2	2007-01-25 00:00:00	2007-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	04084N	TITULAIRE	\N	2014-09-28 13:40:33
3531	2007CMP2	2007-01-25 00:00:00	2007-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	TITULAIRE	\N	2014-09-28 17:07:41
3532	2007CMP2	2007-01-25 00:00:00	2007-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	83012K	SUPPLEANT	\N	\N
3533	2007CMP2	2007-01-25 00:00:00	2007-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	01045S	SUPPLEANT	\N	\N
3534	2007CMP2	2007-01-25 00:00:00	2007-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	98017S	SUPPLEANT	\N	\N
3535	2007CMP2	2007-01-25 00:00:00	2007-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	01011G	SUPPLEANT	\N	2017-09-24 16:43:43
3536	2007CMP2	2007-01-25 00:00:00	2007-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	01033N	SUPPLEANT	\N	\N
3538	2007CMP2	2007-01-25 00:00:00	2007-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	01018P	SUPPLEANT	\N	\N
3552	2007CMP3	2007-02-01 00:00:00	2007-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	06004E	SUPPLEANT	\N	2014-09-28 17:03:42
3614	2007CMP8	2007-02-20 00:00:00	2007-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	98027U	TITULAIRE	\N	2015-06-12 16:01:58
3615	2007CMP8	2007-02-20 00:00:00	2007-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	01033N	TITULAIRE	\N	\N
3616	2007CMP8	2007-02-20 00:00:00	2007-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	04090L	TITULAIRE	\N	\N
3617	2007CMP8	2007-02-20 00:00:00	2007-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	00002B	TITULAIRE	\N	\N
3618	2007CMP8	2007-02-20 00:00:00	2007-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	04081K	SUPPLEANT	\N	2017-09-24 19:25:10
3619	2007CMP8	2007-02-20 00:00:00	2007-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	98045W	SUPPLEANT	\N	\N
3620	2007CMP8	2007-02-20 00:00:00	2007-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	SUPPLEANT	\N	2014-09-28 17:07:41
3621	2007CMP8	2007-02-20 00:00:00	2007-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	04036E	SUPPLEANT	\N	2017-09-24 18:59:59
3622	2007CMP8	2007-02-20 00:00:00	2007-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	04076N	SUPPLEANT	\N	\N
3623	2007CMP8	2007-02-20 00:00:00	2007-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	SUPPLEANT	\N	\N
3624	2007CMP8	2007-02-20 00:00:00	2007-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	04069P	SUPPLEANT	\N	2014-09-28 17:31:41
3694	SOCI	2007-09-19 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	07029T	\N	\N	2014-10-08 17:43:55
3751	ECON	2007-09-25 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	97005J	\N	\N	\N
3752	ETRD	2007-09-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92018S	\N	\N	2017-09-24 18:16:52
3966	2008CMP5	2008-05-14 00:00:00	2008-05-14 00:00:00	ANCIEN	\N	\N	\N	\N	95025E	TITULAIRE	\N	2014-09-28 17:09:16
3964	2008CMP5	2008-05-14 00:00:00	2008-05-14 00:00:00	ANCIEN	\N	\N	\N	\N	95013A	TITULAIRE	\N	\N
4125	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08011M	\N	\N	\N
4127	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08013P	\N	\N	\N
4128	ECON	2008-10-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08014Q	\N	\N	\N
4133	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08018U	\N	\N	\N
3096	20051213N35	2005-12-13 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	94003T	TITULAIRE	\N	2014-09-28 13:16:32
3097	20051213N35	2005-12-13 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77043E	TITULAIRE	\N	2014-09-28 16:59:41
3098	20051213N35	2005-12-13 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	98032R	TITULAIRE	\N	2015-06-12 15:59:49
3099	20051213N35	2005-12-13 00:00:00	2012-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	TITULAIRE	\N	\N
3100	20051213N35	2005-12-13 00:00:00	2018-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	98053W	TITULAIRE	\N	2018-05-31 10:52:17
3101	20051213N35	2005-12-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89017R	SUPPLEANT	\N	\N
3103	20051213N35	2005-12-13 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	01037S	SUPPLEANT	\N	2016-12-12 16:10:15
3104	20051213N35	2005-12-13 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98047Y	SUPPLEANT	\N	\N
3105	20051213N35	2005-12-13 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	78003A	SUPPLEANT	\N	\N
3106	20051213N35	2005-12-13 00:00:00	2010-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	92029V	SUPPLEANT	\N	\N
3107	20051213N35	2005-12-13 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	98046X	SUPPLEANT	\N	2017-09-25 09:56:00
3108	20051215N36	2005-12-15 00:00:00	2015-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-12 09:39:30
3109	20051215N36	2005-12-15 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	95020Y	TITULAIRE	\N	2015-06-12 16:01:25
3110	20051215N36	2005-12-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	TITULAIRE	\N	2014-09-28 18:00:58
3111	20051215N36	2005-12-15 00:00:00	2007-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	04072J	TITULAIRE	\N	\N
3112	20051215N36	2005-12-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	TITULAIRE	\N	2017-09-24 13:29:42
3113	20051215N36	2005-12-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95055L	TITULAIRE	\N	2014-09-28 13:21:47
3114	20051215N36	2005-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	04085P	TITULAIRE	\N	\N
3115	20051215N36	2005-12-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01065W	SUPPLEANT	\N	2014-09-28 12:09:44
3117	20051215N36	2005-12-15 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	\N	\N
3118	20051215N36	2005-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	SUPPLEANT	\N	\N
3119	20051215N36	2005-12-15 00:00:00	2015-04-21 00:00:00	ANCIEN	\N	\N	\N	\N	01042P	SUPPLEANT	\N	2015-04-21 17:14:30
3120	20051215N36	2005-12-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04074L	SUPPLEANT	\N	2017-09-24 17:15:15
3121	20051215N36	2005-12-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92044U	SUPPLEANT	\N	2017-09-24 18:16:52
3122	20051220N37	2005-12-20 00:00:00	2014-07-01 00:00:00	ANCIEN	\N	\N	\N	\N	83011J	TITULAIRE	\N	2014-07-01 09:25:11
3123	20051220N37	2005-12-20 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
3124	20051220N37	2005-12-20 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	94003T	TITULAIRE	\N	2014-09-28 13:16:32
3125	20051220N37	2005-12-20 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77043E	TITULAIRE	\N	2014-09-28 16:59:41
3126	20051220N37	2005-12-20 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	98032R	TITULAIRE	\N	2015-06-12 15:59:49
3127	20051220N37	2005-12-20 00:00:00	2013-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	95003X	TITULAIRE	\N	\N
3128	20051220N37	2005-12-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04050C	TITULAIRE	\N	\N
3129	20051220N37	2005-12-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89017R	SUPPLEANT	\N	\N
3131	20051220N37	2005-12-20 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89022N	SUPPLEANT	\N	2014-09-28 18:19:47
3132	20051220N37	2005-12-20 00:00:00	2012-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	SUPPLEANT	\N	\N
3133	20051220N37	2005-12-20 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	78003A	SUPPLEANT	\N	\N
3134	20051220N37	2005-12-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92043T	SUPPLEANT	\N	\N
3135	20051220N37	2005-12-20 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86049M	SUPPLEANT	\N	2014-09-28 18:03:38
3136	NEANT	1961-11-13 00:00:00	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	05015D	\N	\N	\N
3137	BANLIEUES	2005-12-22 00:00:00	2006-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	01006K	\N	\N	\N
3139	BANLIEUES	2005-12-22 00:00:00	2006-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	84004P	\N	\N	\N
3140	BANLIEUES	2005-12-22 00:00:00	2006-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	\N	\N	\N
3141	BANLIEUES	2005-12-22 00:00:00	2006-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	01013J	\N	\N	\N
3142	BANLIEUES	2005-12-22 00:00:00	2006-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	95013A	\N	\N	\N
3143	BANLIEUES	2005-12-22 00:00:00	2006-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	\N	\N	\N
3144	BANLIEUES	2005-12-22 00:00:00	2006-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	04042C	\N	\N	\N
3145	BANLIEUES	2005-12-22 00:00:00	2006-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	\N	\N	\N
3146	BANLIEUES	2005-12-22 00:00:00	2006-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	01012H	\N	\N	\N
3147	BANLIEUES	2005-12-22 00:00:00	2006-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	95024D	\N	\N	\N
3148	BANLIEUES	2005-12-22 00:00:00	2006-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	87003B	\N	\N	\N
3151	BANLIEUES	2005-12-22 00:00:00	2006-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	04048J	\N	\N	\N
3152	BANLIEUES	2005-12-22 00:00:00	2006-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	97004H	\N	\N	\N
3153	BANLIEUES	2005-12-22 00:00:00	2006-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	01043Q	\N	\N	\N
3154	BANLIEUES	2005-12-22 00:00:00	2006-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	04076N	\N	\N	\N
3155	BANLIEUES	2005-12-22 00:00:00	2006-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	04079R	\N	\N	\N
3156	BANLIEUES	2005-12-22 00:00:00	2006-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	95046K	\N	\N	\N
3157	BANLIEUES	2005-12-22 00:00:00	2006-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	04070G	\N	\N	\N
3158	BANLIEUES	2005-12-22 00:00:00	2006-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	00002B	\N	\N	\N
3159	BANLIEUES	2005-12-22 00:00:00	2006-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	04074L	\N	\N	\N
3160	BANLIEUES	2005-12-22 00:00:00	2006-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	04090L	\N	\N	\N
3161	BANLIEUES	2005-12-22 00:00:00	2006-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	92005M	\N	\N	\N
3162	BANLIEUES	2005-12-22 00:00:00	2006-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	80041C	\N	\N	\N
3163	BANLIEUES	2005-12-22 00:00:00	2006-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	92044U	\N	\N	\N
3164	BANLIEUES	2005-12-22 00:00:00	2006-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	89042S	\N	\N	\N
3165	BANLIEUES	2005-12-22 00:00:00	2006-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	04082L	\N	\N	\N
3166	20060119N38	2006-01-19 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	95004Y	TITULAIRE	\N	\N
3167	20060119N38	2006-01-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04069P	TITULAIRE	\N	2014-09-28 17:31:41
3168	20060119N38	2006-01-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	02003L	TITULAIRE	\N	\N
3169	20060119N38	2006-01-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	04043D	TITULAIRE	\N	\N
3172	20060119N38	2006-01-19 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	00002B	TITULAIRE	\N	\N
3173	20060119N38	2006-01-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	SUPPLEANT	\N	2017-09-24 13:44:49
3174	20060119N38	2006-01-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92011K	SUPPLEANT	\N	\N
3175	20060119N38	2006-01-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	SUPPLEANT	\N	2014-09-28 17:07:41
3176	20060119N38	2006-01-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01018P	SUPPLEANT	\N	\N
3177	20060119N38	2006-01-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92030N	SUPPLEANT	\N	\N
3178	20060119N38	2006-01-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01009N	SUPPLEANT	\N	\N
3179	20060119N38	2006-01-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	04045F	SUPPLEANT	\N	\N
3180	20060119N39	2006-01-26 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	95004Y	TITULAIRE	\N	\N
3181	20060119N39	2006-01-26 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89041R	TITULAIRE	\N	\N
3182	20060119N39	2006-01-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92011K	TITULAIRE	\N	\N
3184	20060119N39	2006-01-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	95035G	TITULAIRE	\N	2017-09-24 18:17:56
3185	20060119N39	2006-01-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04076N	TITULAIRE	\N	\N
3186	20060119N39	2006-01-26 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	00002B	TITULAIRE	\N	\N
3187	20060119N39	2006-01-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	02003L	SUPPLEANT	\N	\N
3188	20060119N39	2006-01-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98029W	SUPPLEANT	\N	\N
3189	20060119N39	2006-01-26 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	SUPPLEANT	\N	2014-09-28 17:07:41
3190	20060119N39	2006-01-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01018P	SUPPLEANT	\N	\N
3191	20060119N39	2006-01-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92030N	SUPPLEANT	\N	\N
3192	20060119N39	2006-01-26 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	01043Q	SUPPLEANT	\N	\N
3193	20060119N39	2006-01-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	04043D	SUPPLEANT	\N	\N
3194	20060119N40	2006-02-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95030B	TITULAIRE	\N	2014-09-28 18:58:21
3196	20060119N40	2006-02-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95013A	TITULAIRE	\N	\N
3197	20060119N40	2006-02-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	TITULAIRE	\N	\N
3198	20060119N40	2006-02-08 00:00:00	2007-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04060E	TITULAIRE	\N	\N
3199	20060119N40	2006-02-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92042S	TITULAIRE	\N	\N
3200	20060119N40	2006-02-08 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	04090L	TITULAIRE	\N	\N
3201	20060119N40	2006-02-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04067M	SUPPLEANT	\N	2017-09-24 17:47:27
3202	20060119N40	2006-02-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01015L	SUPPLEANT	\N	2017-09-24 17:19:42
3203	20060119N40	2006-02-08 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	SUPPLEANT	\N	2017-05-16 15:18:13
3204	20060119N40	2006-02-08 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95038K	SUPPLEANT	\N	2014-09-28 17:40:23
3205	20060119N40	2006-02-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	SUPPLEANT	\N	\N
3206	20060119N40	2006-02-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	82002D	SUPPLEANT	\N	\N
3207	20060119N40	2006-02-08 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95062K	SUPPLEANT	\N	\N
3208	20060119N41	2006-01-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95030B	TITULAIRE	\N	2014-09-28 18:58:21
3209	20060119N41	2006-01-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04077P	TITULAIRE	\N	2017-09-24 17:47:27
3210	20060119N41	2006-01-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95038K	TITULAIRE	\N	2014-09-28 17:40:23
3211	20060119N41	2006-01-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95009E	TITULAIRE	\N	2014-09-28 12:56:42
3212	20060119N41	2006-01-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01008M	TITULAIRE	\N	2017-09-24 13:44:49
3213	20060119N41	2006-01-23 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	04090L	TITULAIRE	\N	\N
2969	RECHERCHE	2005-11-23 00:00:00	2006-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	04073K	\N	\N	\N
2970	RECHERCHE	2005-11-23 00:00:00	2006-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	71003U	\N	\N	\N
2971	RECHERCHE	2005-11-23 00:00:00	2006-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	95007C	\N	\N	\N
2973	RECHERCHE	2005-11-23 00:00:00	2006-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	\N	\N	\N
2974	RECHERCHE	2005-11-24 00:00:00	2006-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	89017R	\N	\N	2018-03-12 16:10:45
2975	RECHERCHE	2005-10-27 00:00:00	2006-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	04054G	\N	\N	2016-11-21 17:17:23
2976	RECHERCHE	2005-11-23 00:00:00	2006-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	01044R	\N	\N	\N
2977	RECHERCHE	2005-11-23 00:00:00	2006-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	98023Q	\N	\N	\N
2978	RECHERCHE	2005-11-23 00:00:00	2006-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	98042T	\N	\N	\N
2979	RECHERCHE	2005-11-23 00:00:00	2006-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	04055H	\N	\N	\N
2980	RECHERCHE	2005-11-23 00:00:00	2006-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	\N	\N	\N
2982	RECHERCHE	2005-11-23 00:00:00	2006-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	78006D	\N	\N	\N
2983	RECHERCHE	2005-10-27 00:00:00	2006-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	04070G	\N	\N	2014-10-09 15:57:06
2985	RECHERCHE	2005-11-23 00:00:00	2006-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	98003L	\N	\N	\N
2986	RECHERCHE	2005-11-23 00:00:00	2006-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	98047Y	\N	\N	\N
2987	RECHERCHE	2005-11-23 00:00:00	2006-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	04041B	\N	\N	\N
2988	RECHERCHE	2005-11-23 00:00:00	2006-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	98028V	\N	\N	\N
2989	RECHERCHE	2005-11-23 00:00:00	2006-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	98017S	\N	\N	\N
2990	RECHERCHE	2005-11-23 00:00:00	2006-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	85003S	\N	\N	\N
2991	RECHERCHE	2005-11-23 00:00:00	2006-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	97004H	\N	\N	\N
2992	RECHERCHE	2005-10-27 00:00:00	2006-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	\N	\N	2018-01-25 13:08:03
2993	RECHERCHE	2005-11-23 00:00:00	2006-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	04084N	\N	\N	\N
2994	RECHERCHE	2005-11-23 00:00:00	2006-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	77019E	\N	\N	\N
2995	RECHERCHE	2005-11-23 00:00:00	2006-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	01054T	\N	\N	\N
2996	RECHERCHE	2005-11-23 00:00:00	2006-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	98015Q	\N	\N	\N
2997	RECHERCHE	2005-11-23 00:00:00	2006-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	04074L	\N	\N	\N
2998	RECHERCHE	2005-11-23 00:00:00	2006-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	\N	\N	\N
2999	RECHERCHE	2005-11-23 00:00:00	2006-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	85002R	\N	\N	\N
3000	RECHERCHE	2005-11-23 00:00:00	2006-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	89037V	\N	\N	\N
3001	RECHERCHE	2005-11-23 00:00:00	2006-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	89040Q	\N	\N	\N
3002	RECHERCHE	2005-11-23 00:00:00	2006-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	\N	\N	\N
3003	RECHERCHE	2005-11-23 00:00:00	2006-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	98012M	\N	\N	\N
3004	RECHERCHE	2005-10-27 00:00:00	2006-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	01062T	\N	\N	\N
3005	RECHERCHE	2005-11-23 00:00:00	2006-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	80046H	\N	\N	\N
3007	IMMIGRATION	2005-11-03 00:00:00	2006-05-02 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	\N	\N	\N
3009	IMMIGRATION	2005-11-03 00:00:00	2006-05-02 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	\N	\N	\N
3010	IMMIGRATION	2005-11-03 00:00:00	2006-05-02 00:00:00	ANCIEN	\N	\N	\N	\N	77002U	\N	\N	\N
3011	IMMIGRATION	2005-11-03 00:00:00	2006-05-02 00:00:00	ANCIEN	\N	\N	\N	\N	95020Y	\N	\N	\N
3012	IMMIGRATION	2005-11-03 00:00:00	2006-05-02 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	\N	\N	\N
3013	IMMIGRATION	2005-11-03 00:00:00	2006-05-02 00:00:00	ANCIEN	\N	\N	\N	\N	95024D	\N	\N	\N
3014	IMMIGRATION	2005-11-03 00:00:00	2006-05-02 00:00:00	ANCIEN	\N	\N	\N	\N	02001J	\N	\N	\N
3016	IMMIGRATION	2005-11-03 00:00:00	2006-05-02 00:00:00	ANCIEN	\N	\N	\N	\N	01053S	\N	\N	\N
3017	IMMIGRATION	2005-11-03 00:00:00	2006-05-02 00:00:00	ANCIEN	\N	\N	\N	\N	95035G	\N	\N	\N
3018	IMMIGRATION	2005-11-03 00:00:00	2006-05-02 00:00:00	ANCIEN	\N	\N	\N	\N	05001W	\N	\N	\N
3019	IMMIGRATION	2005-11-03 00:00:00	2006-05-02 00:00:00	ANCIEN	\N	\N	\N	\N	98028V	\N	\N	\N
3020	IMMIGRATION	2005-11-03 00:00:00	2006-05-02 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	\N	\N	\N
3022	IMMIGRATION	2005-11-03 00:00:00	2006-05-02 00:00:00	ANCIEN	\N	\N	\N	\N	95049N	\N	\N	\N
3024	IMMIGRATION	2005-11-03 00:00:00	2006-05-02 00:00:00	ANCIEN	\N	\N	\N	\N	89035T	\N	\N	\N
3025	IMMIGRATION	2005-11-03 00:00:00	2006-05-02 00:00:00	ANCIEN	\N	\N	\N	\N	95055L	\N	\N	\N
3026	IMMIGRATION	2005-11-03 00:00:00	2006-05-02 00:00:00	ANCIEN	\N	\N	\N	\N	04056J	\N	\N	\N
3027	IMMIGRATION	2005-11-03 00:00:00	2006-05-02 00:00:00	ANCIEN	\N	\N	\N	\N	01010F	\N	\N	\N
3356	ECON	2006-10-03 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	06006G	\N	\N	\N
3404	NEANT	2007-01-03 00:00:00	2007-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	07001F	\N	\N	\N
3405	NEANT	2007-01-02 00:00:00	2007-01-03 00:00:00	ANCIEN	\N	\N	\N	\N	07002G	\N	\N	\N
3546	2007CMP3	2007-02-01 00:00:00	2007-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	04040A	SUPPLEANT	\N	\N
3547	2007CMP3	2007-02-01 00:00:00	2007-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	95015C	SUPPLEANT	\N	\N
3548	2007CMP3	2007-02-01 00:00:00	2007-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	89007P	SUPPLEANT	\N	2014-09-28 16:42:05
3549	2007CMP3	2007-02-01 00:00:00	2007-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	98028V	SUPPLEANT	\N	2014-09-28 17:22:11
3550	2007CMP3	2007-02-01 00:00:00	2007-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	85003S	SUPPLEANT	\N	\N
3551	2007CMP3	2007-02-01 00:00:00	2007-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	95060H	SUPPLEANT	\N	\N
3553	2007CMP3	2007-02-01 00:00:00	2007-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	04057K	TITULAIRE	\N	\N
3579	2007CMP5	2007-02-12 00:00:00	2007-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	89035T	SUPPLEANT	\N	\N
3627	ECON	2007-07-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	07023M	\N	\N	\N
3698	2007CMP9	2007-07-19 00:00:00	2015-04-21 00:00:00	ANCIEN	\N	\N	\N	\N	01042P	TITULAIRE	\N	2015-04-21 17:14:30
3699	2007CMP9	2007-07-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04074L	TITULAIRE	\N	2017-09-24 17:15:15
3700	2007CMP9	2007-07-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95006B	TITULAIRE	\N	\N
3701	2007CMP9	2007-07-19 00:00:00	2012-09-19 00:00:00	ANCIEN	\N	\N	\N	\N	95011X	TITULAIRE	\N	\N
3702	2007CMP9	2007-07-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01065W	SUPPLEANT	\N	2014-09-28 12:09:44
3703	2007CMP9	2007-07-19 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	01063U	SUPPLEANT	\N	2014-09-29 13:41:53
3704	2007CMP9	2007-07-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	SUPPLEANT	\N	\N
3705	2007CMP9	2007-07-19 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98039Y	SUPPLEANT	\N	\N
3706	2007CMP9	2007-07-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	SUPPLEANT	\N	\N
3707	2007CMP9	2007-07-19 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	\N	\N
3708	2007CMP9	2007-07-19 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	SUPPLEANT	\N	\N
3709	2007CMP10	2007-07-26 00:00:00	2007-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	80046H	TITULAIRE	\N	\N
3710	2007CMP10	2007-07-26 00:00:00	2007-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	98042T	TITULAIRE	\N	2017-10-01 10:39:22
3711	2007CMP10	2007-07-26 00:00:00	2007-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	89017R	TITULAIRE	\N	\N
3712	2007CMP10	2007-07-26 00:00:00	2007-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	92031P	TITULAIRE	\N	2017-09-24 18:16:52
3713	2007CMP10	2007-07-26 00:00:00	2007-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	04057K	TITULAIRE	\N	\N
3428	20061214N53	2006-12-14 00:00:00	2006-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	89014N	SUPPLEANT	\N	2014-04-25 17:05:01
3430	20061214N53	2006-12-14 00:00:00	2006-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	82002D	SUPPLEANT	\N	\N
3431	20061214N53	2006-12-14 00:00:00	2006-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	02005N	SUPPLEANT	\N	\N
3432	20061214N53	2006-12-14 00:00:00	2006-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	96006F	SUPPLEANT	\N	2014-09-28 16:50:17
3439	20061219N54	2006-12-19 00:00:00	2006-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	TITULAIRE	\N	\N
3514	2007CMP1	2007-01-25 00:00:00	2007-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	01042P	TITULAIRE	\N	2015-04-21 17:14:30
3515	2007CMP1	2007-01-25 00:00:00	2007-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	96008H	TITULAIRE	\N	\N
3516	2007CMP1	2007-01-25 00:00:00	2007-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	02001J	TITULAIRE	\N	\N
3517	2007CMP1	2007-01-25 00:00:00	2007-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	TITULAIRE	\N	\N
3518	2007CMP1	2007-01-25 00:00:00	2007-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	84004P	SUPPLEANT	\N	\N
3519	2007CMP1	2007-01-25 00:00:00	2007-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	80017C	SUPPLEANT	\N	\N
3597	2007CMP7	2007-02-14 00:00:00	2007-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-12 09:39:30
3598	2007CMP7	2007-02-14 00:00:00	2007-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	01042P	TITULAIRE	\N	2015-04-21 17:14:30
3599	2007CMP7	2007-02-14 00:00:00	2007-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	95004Y	TITULAIRE	\N	\N
3600	2007CMP7	2007-02-14 00:00:00	2007-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	95020Y	TITULAIRE	\N	2015-06-12 16:01:25
3601	2007CMP7	2007-02-14 00:00:00	2007-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	04072J	TITULAIRE	\N	\N
3602	2007CMP7	2007-02-14 00:00:00	2007-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	95055L	TITULAIRE	\N	2014-09-28 13:21:47
3603	2007CMP7	2007-02-14 00:00:00	2007-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	TITULAIRE	\N	\N
3604	2007CMP7	2007-02-14 00:00:00	2007-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	01065W	SUPPLEANT	\N	2014-09-28 12:09:44
2962	AFCL	2005-10-04 00:00:00	2007-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	02009S	\N	\N	\N
3625	NEANT	2007-06-18 00:00:00	2007-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	04099V	\N	\N	\N
3737	2007CMP12	2007-07-31 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	95062K	TITULAIRE	\N	\N
3738	2007CMP12	2007-07-31 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	04043D	TITULAIRE	\N	\N
3739	2007CMP12	2007-07-31 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	92011K	TITULAIRE	\N	\N
3740	2007CMP12	2007-07-31 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	95035G	TITULAIRE	\N	2017-09-24 18:17:56
3741	2007CMP12	2007-07-31 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	01049W	TITULAIRE	\N	\N
3742	2007CMP12	2007-07-31 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	04046G	TITULAIRE	\N	2014-09-28 17:07:41
3714	2007CMP10	2007-07-26 00:00:00	2007-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	01062T	TITULAIRE	\N	2014-12-18 16:15:04
3715	2007CMP10	2007-07-26 00:00:00	2007-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	85002R	TITULAIRE	\N	\N
3921	2008CMP2	2008-01-24 00:00:00	2008-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	89041R	SUPPLEANT	\N	\N
3922	2008CMP2	2008-01-24 00:00:00	2008-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	04069P	SUPPLEANT	\N	2014-09-28 17:31:41
3923	2008CMP2	2008-01-24 00:00:00	2008-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	01034P	SUPPLEANT	\N	\N
3932	2008CMP3	2008-01-31 00:00:00	2008-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	04063H	SUPPLEANT	\N	\N
3933	2008CMP3	2008-01-31 00:00:00	2008-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	01063U	SUPPLEANT	\N	2014-09-29 13:41:53
3934	2008CMP3	2008-01-31 00:00:00	2008-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	\N	\N
3935	2008CMP3	2008-01-31 00:00:00	2008-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	95020Y	SUPPLEANT	\N	2015-06-12 16:01:25
3936	2008CMP3	2008-01-31 00:00:00	2008-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	98041S	SUPPLEANT	\N	2014-09-28 16:42:05
3948	2008CMP4	2008-04-16 00:00:00	2008-05-13 00:00:00	ANCIEN	\N	\N	\N	\N	95035G	TITULAIRE	\N	2017-09-24 18:17:56
3953	2008CMP4	2008-04-16 00:00:00	2008-05-13 00:00:00	ANCIEN	\N	\N	\N	\N	92011K	SUPPLEANT	\N	\N
3954	2008CMP4	2008-04-16 00:00:00	2008-05-13 00:00:00	ANCIEN	\N	\N	\N	\N	04081K	SUPPLEANT	\N	2017-09-24 19:25:10
3955	2008CMP4	2008-04-16 00:00:00	2008-05-13 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	SUPPLEANT	\N	2014-09-28 17:07:41
3956	2008CMP4	2008-04-16 00:00:00	2008-05-13 00:00:00	ANCIEN	\N	\N	\N	\N	01011G	SUPPLEANT	\N	2017-09-24 16:43:43
3957	2008CMP4	2008-04-16 00:00:00	2008-05-13 00:00:00	ANCIEN	\N	\N	\N	\N	01009N	SUPPLEANT	\N	\N
3958	2008CMP4	2008-04-16 00:00:00	2008-05-13 00:00:00	ANCIEN	\N	\N	\N	\N	89041R	SUPPLEANT	\N	\N
3962	2008CMP5	2008-05-14 00:00:00	2008-05-14 00:00:00	ANCIEN	\N	\N	\N	\N	95030B	TITULAIRE	\N	2014-09-28 18:58:21
3963	2008CMP5	2008-05-14 00:00:00	2008-05-14 00:00:00	ANCIEN	\N	\N	\N	\N	96004D	TITULAIRE	\N	\N
3970	2008CMP5	2008-05-14 00:00:00	2008-05-14 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	SUPPLEANT	\N	2017-05-16 15:18:13
3971	2008CMP5	2008-05-14 00:00:00	2008-05-14 00:00:00	ANCIEN	\N	\N	\N	\N	07027R	SUPPLEANT	\N	\N
3972	2008CMP6	2008-05-21 00:00:00	2008-06-03 00:00:00	ANCIEN	\N	\N	\N	\N	95004Y	TITULAIRE	\N	\N
3973	2008CMP6	2008-05-21 00:00:00	2008-06-03 00:00:00	ANCIEN	\N	\N	\N	\N	07003H	TITULAIRE	\N	2014-09-28 12:21:28
3974	2008CMP6	2008-05-21 00:00:00	2008-06-03 00:00:00	ANCIEN	\N	\N	\N	\N	98045W	TITULAIRE	\N	\N
4039	ECONOMIE	2008-06-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	95052H	\N	\N	\N
4043	2008CMP8	2008-07-02 00:00:00	2008-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	95025E	TITULAIRE	\N	2014-09-28 17:09:16
4044	2008CMP8	2008-07-02 00:00:00	2008-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	04088S	TITULAIRE	\N	\N
4045	2008CMP8	2008-07-02 00:00:00	2008-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	01022K	TITULAIRE	\N	2017-09-24 17:14:26
4047	2008CMP8	2008-07-02 00:00:00	2008-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	01015L	SUPPLEANT	\N	2017-09-24 17:19:42
4048	2008CMP8	2008-07-02 00:00:00	2008-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	SUPPLEANT	\N	2017-05-16 15:18:13
4052	2008CMP9	2008-07-10 00:00:00	2008-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	86034E	TITULAIRE	\N	\N
3351	NEANT	2006-07-09 00:00:00	2006-09-06 00:00:00	ANCIEN	\N	\N	\N	\N	06004E	\N	\N	\N
3401	AFCL	2006-12-15 00:00:00	2007-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	98052V	\N	\N	\N
3402	LOIS	2006-12-15 00:00:00	2007-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	92033R	\N	\N	\N
3683	SOCI	2007-07-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	\N	\N	2017-09-24 17:35:15
3685	ECON	2007-07-25 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	07027R	\N	\N	\N
3695	2007CMP9	2007-07-19 00:00:00	2015-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-12 09:39:30
3696	2007CMP9	2007-07-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	TITULAIRE	\N	2017-09-24 13:29:42
3697	2007CMP9	2007-07-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	TITULAIRE	\N	2014-09-28 18:00:58
3716	2007CMP10	2007-07-26 00:00:00	2007-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	04059M	SUPPLEANT	\N	\N
3717	2007CMP10	2007-07-26 00:00:00	2007-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	95015C	SUPPLEANT	\N	\N
3718	2007CMP10	2007-07-26 00:00:00	2007-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	85003S	SUPPLEANT	\N	\N
3719	2007CMP10	2007-07-26 00:00:00	2007-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	97004H	SUPPLEANT	\N	\N
3720	2007CMP10	2007-07-26 00:00:00	2007-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	04070G	SUPPLEANT	\N	\N
3722	2007CMP10	2007-07-26 00:00:00	2007-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	89037V	SUPPLEANT	\N	\N
3723	2007CMP11	2007-07-27 00:00:00	2007-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	83011J	TITULAIRE	\N	2014-07-01 09:25:11
3724	2007CMP11	2007-07-27 00:00:00	2007-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
3726	2007CMP11	2007-07-27 00:00:00	2007-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	94003T	TITULAIRE	\N	2014-09-28 13:16:32
3727	2007CMP11	2007-07-27 00:00:00	2007-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	78003A	TITULAIRE	\N	\N
3728	2007CMP11	2007-07-27 00:00:00	2007-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	81015E	TITULAIRE	\N	\N
3729	2007CMP11	2007-07-27 00:00:00	2007-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	98053W	TITULAIRE	\N	2018-05-31 10:52:17
3730	2007CMP11	2007-07-27 00:00:00	2007-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	95007C	SUPPLEANT	\N	\N
3731	2007CMP11	2007-07-27 00:00:00	2007-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	89022N	SUPPLEANT	\N	2014-09-28 18:19:47
3732	2007CMP11	2007-07-27 00:00:00	2007-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	98047Y	SUPPLEANT	\N	\N
3733	2007CMP11	2007-07-27 00:00:00	2007-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	95003X	SUPPLEANT	\N	\N
3734	2007CMP11	2007-07-27 00:00:00	2007-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	98032R	SUPPLEANT	\N	2015-06-12 15:59:49
3735	2007CMP11	2007-07-27 00:00:00	2007-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	73006G	SUPPLEANT	\N	\N
3736	2007CMP11	2007-07-27 00:00:00	2007-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	86049M	SUPPLEANT	\N	2014-09-28 18:03:38
4053	2008CMP9	2008-07-10 00:00:00	2008-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	01001E	TITULAIRE	\N	\N
4054	2008CMP9	2008-07-10 00:00:00	2008-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	TITULAIRE	\N	\N
3376	20061115N50	2006-11-23 00:00:00	2006-11-28 00:00:00	ANCIEN	\N	\N	\N	\N	04043D	TITULAIRE	\N	\N
3377	20061115N50	2006-11-23 00:00:00	2006-11-28 00:00:00	ANCIEN	\N	\N	\N	\N	01011G	TITULAIRE	\N	2017-09-24 16:43:43
4000	ECONOMIE	2008-06-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	01001E	\N	\N	\N
4001	ECONOMIE	2008-06-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	01049W	\N	\N	\N
4002	ECONOMIE	2008-06-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	98023Q	\N	\N	\N
4003	ECONOMIE	2008-06-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	04071H	\N	\N	\N
4004	ECONOMIE	2008-06-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	\N	\N	\N
4005	ECONOMIE	2008-06-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	02002K	\N	\N	\N
4006	ECONOMIE	2008-06-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	07024N	\N	\N	\N
4008	ECONOMIE	2008-06-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	\N	\N	2018-02-02 10:20:31
4009	ECONOMIE	2008-06-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	86034E	\N	\N	\N
4056	2008CMP9	2008-07-10 00:00:00	2008-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	01049W	TITULAIRE	\N	\N
4011	ECONOMIE	2008-06-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	\N	\N	\N
4012	ECONOMIE	2008-06-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	04090L	\N	\N	\N
4013	ECONOMIE	2008-06-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	04033B	\N	\N	\N
4014	ECONOMIE	2008-06-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	98039Y	\N	\N	\N
4015	ECONOMIE	2008-06-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	\N	\N	\N
4016	ECONOMIE	2008-06-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	97005J	\N	\N	\N
4017	ECONOMIE	2008-06-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	\N	\N	\N
4019	ECONOMIE	2008-06-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	\N	\N	\N
4020	ECONOMIE	2008-06-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	95003X	\N	\N	\N
4057	2008CMP9	2008-07-10 00:00:00	2008-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	TITULAIRE	\N	2017-09-24 17:09:24
4022	ECONOMIE	2008-06-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	04055H	\N	\N	\N
4023	ECONOMIE	2008-06-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	01027Q	\N	\N	\N
4024	ECONOMIE	2008-06-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	01048V	\N	\N	\N
4025	ECONOMIE	2008-06-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	\N	\N	\N
4101	2008CMP12	2008-07-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	92011K	SUPPLEANT	\N	\N
4102	2008CMP12	2008-07-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	04076N	SUPPLEANT	\N	\N
6972	DECHETS	2009-10-14 00:00:00	2010-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	02003L	\N	\N	\N
4104	2008CMP12	2008-07-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	SUPPLEANT	\N	2014-09-28 17:07:41
3353	AFCL	2006-09-07 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	06004E	\N	\N	\N
3354	LOIS	2006-09-07 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	06005F	\N	\N	\N
3359	20061030N49	2006-10-30 00:00:00	2006-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
3360	20061030N49	2006-10-30 00:00:00	2006-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	02005N	TITULAIRE	\N	\N
3361	20061030N49	2006-10-30 00:00:00	2006-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	95025E	TITULAIRE	\N	2014-09-28 17:09:16
3362	20061030N49	2006-10-30 00:00:00	2006-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	TITULAIRE	\N	2017-09-24 17:09:24
3364	20061030N49	2006-10-30 00:00:00	2006-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	04091M	SUPPLEANT	\N	2014-09-28 17:55:37
3365	20061030N49	2006-10-30 00:00:00	2006-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	96004D	SUPPLEANT	\N	\N
3367	20061030N49	2006-10-30 00:00:00	2006-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	80015A	SUPPLEANT	\N	\N
3396	20061117N51	2006-11-17 00:00:00	2006-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	98024R	SUPPLEANT	\N	\N
3397	20061117N51	2006-11-17 00:00:00	2006-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	SUPPLEANT	\N	2014-09-28 17:07:41
3398	20061117N51	2006-11-17 00:00:00	2006-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	04075M	SUPPLEANT	\N	\N
3399	20061117N51	2006-11-17 00:00:00	2006-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	01030K	SUPPLEANT	\N	\N
3420	20061214N53	2006-12-14 00:00:00	2006-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	95030B	TITULAIRE	\N	2014-09-28 18:58:21
3422	20061214N53	2006-12-14 00:00:00	2006-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	98027U	TITULAIRE	\N	2015-06-12 16:01:58
3423	20061214N53	2006-12-14 00:00:00	2006-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	04061F	TITULAIRE	\N	\N
3426	20061214N53	2006-12-14 00:00:00	2006-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	04090L	TITULAIRE	\N	\N
3427	20061214N53	2006-12-14 00:00:00	2006-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	01015L	SUPPLEANT	\N	2017-09-24 17:19:42
2278	20040415N5	2004-04-15 00:00:00	2015-04-21 00:00:00	ANCIEN	\N	\N	\N	\N	01042P	SUPPLEANT	\N	2015-04-21 17:14:30
2279	20040415N5	2004-04-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89035T	SUPPLEANT	\N	\N
2280	20040415N5	2004-04-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01019Q	SUPPLEANT	\N	2017-09-24 17:35:15
2281	20040415N5	2004-04-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	SUPPLEANT	\N	2017-09-24 13:29:42
90	AFCL	1989-10-02 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80046H	\N	\N	\N
2283	20040512N6	2004-05-12 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95038K	TITULAIRE	\N	2014-09-28 17:40:23
2284	20040512N6	2004-05-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	01058X	TITULAIRE	\N	\N
2285	20040512N6	2004-05-12 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98048A	TITULAIRE	\N	\N
2286	20040512N6	2004-05-12 00:00:00	2010-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	01017N	TITULAIRE	\N	\N
2765	AMIANTE	2005-02-02 00:00:00	2005-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	01045S	\N	\N	\N
2766	AMIANTE	2005-02-02 00:00:00	2005-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	89007P	\N	\N	\N
2768	AMIANTE	2005-02-02 00:00:00	2005-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	92022N	\N	\N	\N
2769	AMIANTE	2005-02-02 00:00:00	2005-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	02001J	\N	\N	\N
2770	AMIANTE	2005-02-02 00:00:00	2005-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	04017B	\N	\N	\N
2771	AMIANTE	2005-02-02 00:00:00	2005-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	98017S	\N	\N	\N
2772	AMIANTE	2005-02-02 00:00:00	2005-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	01011G	\N	\N	\N
2773	AMIANTE	2005-02-02 00:00:00	2005-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	95035G	\N	\N	\N
2774	AMIANTE	2005-02-02 00:00:00	2005-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	04060E	\N	\N	\N
2775	AMIANTE	2005-02-02 00:00:00	2005-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	01033N	\N	\N	\N
2777	AMIANTE	2005-02-02 00:00:00	2005-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	04079R	\N	\N	\N
2778	AMIANTE	2005-02-02 00:00:00	2005-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	00002B	\N	\N	\N
2779	AMIANTE	2005-02-02 00:00:00	2005-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	04043D	\N	\N	\N
2780	AMIANTE	2005-02-02 00:00:00	2005-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	98039Y	\N	\N	\N
2781	AMIANTE	2005-02-02 00:00:00	2005-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	01029S	\N	\N	\N
2782	AMIANTE	2005-02-02 00:00:00	2005-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	01036R	\N	\N	\N
2783	AMIANTE	2005-02-02 00:00:00	2005-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	01062T	\N	\N	\N
2784	AMIANTE	2005-02-02 00:00:00	2005-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	01034P	\N	\N	\N
2785	NEANT	2005-02-21 00:00:00	2005-02-28 00:00:00	ANCIEN	\N	\N	\N	\N	95036H	\N	\N	\N
2786	NEANT	2005-02-21 00:00:00	2005-02-28 00:00:00	ANCIEN	\N	\N	\N	\N	04061F	\N	\N	\N
2787	NEANT	2005-02-21 00:00:00	2005-02-28 00:00:00	ANCIEN	\N	\N	\N	\N	92005M	\N	\N	\N
2788	NEANT	2005-02-21 00:00:00	2005-02-28 00:00:00	ANCIEN	\N	\N	\N	\N	04065K	\N	\N	\N
2789	NEANT	2005-02-21 00:00:00	2005-02-28 00:00:00	ANCIEN	\N	\N	\N	\N	04069P	\N	\N	\N
2790	20050119N20	2005-01-19 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	95004Y	TITULAIRE	\N	\N
2792	20050119N20	2005-01-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04075M	TITULAIRE	\N	\N
2793	20050119N20	2005-01-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01030K	TITULAIRE	\N	\N
2794	20050119N20	2005-01-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	TITULAIRE	\N	\N
2795	20050119N20	2005-01-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01011G	TITULAIRE	\N	2017-09-24 16:43:43
2796	20050119N20	2005-01-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	TITULAIRE	\N	2014-09-28 17:07:41
2797	20050119N20	2005-01-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	SUPPLEANT	\N	2017-09-24 13:44:49
2798	20050119N20	2005-01-19 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98029W	SUPPLEANT	\N	\N
2799	20050119N20	2005-01-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04058L	SUPPLEANT	\N	\N
2800	20050119N20	2005-01-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01018P	SUPPLEANT	\N	\N
2801	20050119N20	2005-01-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92030N	SUPPLEANT	\N	\N
2802	20050119N20	2005-01-19 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	00002B	SUPPLEANT	\N	\N
2803	20050119N20	2005-01-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01029S	SUPPLEANT	\N	\N
2804	20050127N21	2005-01-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95030B	TITULAIRE	\N	2014-09-28 18:58:21
2805	20050127N21	2005-01-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98050T	TITULAIRE	\N	\N
2806	20050127N21	2005-01-27 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	90003B	TITULAIRE	\N	2017-10-01 10:01:39
2808	20050127N21	2005-01-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01050P	TITULAIRE	\N	\N
2809	20050127N21	2005-01-27 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	04090L	TITULAIRE	\N	\N
2810	20050127N21	2005-01-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92042S	TITULAIRE	\N	\N
2812	20050127N21	2005-01-27 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	SUPPLEANT	\N	2017-05-16 15:18:13
2813	20050127N21	2005-01-27 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98038X	SUPPLEANT	\N	2014-09-28 17:38:26
2814	20050127N21	2005-01-27 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	02005N	SUPPLEANT	\N	\N
2815	20050127N21	2005-01-27 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95052H	SUPPLEANT	\N	2014-09-28 13:39:20
2816	20050127N21	2005-01-27 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95062K	SUPPLEANT	\N	\N
2817	20050127N21	2005-01-27 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	03002P	SUPPLEANT	\N	\N
2818	NEANT	2005-02-24 00:00:00	2005-02-28 00:00:00	ANCIEN	\N	\N	\N	\N	05001W	\N	\N	\N
2819	ECON	2005-03-01 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	95036H	\N	\N	\N
2820	FINC	2005-03-01 00:00:00	2019-06-23 00:00:00	ANCIEN	\N	\N	\N	\N	04061F	\N	\N	2017-10-04 19:51:50
2822	ECON	2005-03-01 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	04065K	\N	\N	\N
2823	SOCI	2005-03-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	04069P	\N	\N	\N
2824	SOCI	2005-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	05001W	\N	\N	\N
2825	LOIS	2005-03-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	\N	\N	2017-10-04 19:51:17
2827	AFCL	2005-03-15 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	89015P	\N	\N	\N
2828	ECON	2005-03-15 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	98006P	\N	\N	\N
1004	INITIATIVE	2003-02-12 00:00:00	2003-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	98053W	\N	\N	\N
979	INITIATIVE	2003-02-12 00:00:00	2003-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	77043E	\N	\N	\N
1010	INITIATIVE	2003-02-12 00:00:00	2003-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	\N	\N	\N
2829	ECON	2005-05-04 00:00:00	2005-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	04098U	\N	\N	\N
2830	20050319N22	2005-03-19 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80046H	TITULAIRE	\N	\N
2831	20050319N22	2005-03-19 00:00:00	2018-08-06 00:00:00	ANCIEN	\N	\N	\N	\N	95015C	TITULAIRE	\N	\N
2832	20050319N22	2005-03-19 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	01048V	TITULAIRE	\N	\N
2873	20050511N25	2005-05-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89037V	TITULAIRE	\N	\N
2874	20050511N25	2005-05-11 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98050T	TITULAIRE	\N	\N
2875	20050511N25	2005-05-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	82002D	TITULAIRE	\N	\N
2876	20050511N25	2005-05-11 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95025E	TITULAIRE	\N	2014-09-28 17:09:16
2877	20050511N25	2005-05-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	TITULAIRE	\N	2017-09-24 17:09:24
2879	20050511N25	2005-05-11 00:00:00	2007-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	01035Q	SUPPLEANT	\N	\N
2880	20050511N25	2005-05-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80015A	SUPPLEANT	\N	\N
2881	20050511N25	2005-05-11 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95036H	SUPPLEANT	\N	2014-09-28 17:31:42
2882	20050511N25	2005-05-11 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	04090L	SUPPLEANT	\N	\N
2883	20050511N25	2005-05-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	01058X	SUPPLEANT	\N	\N
2884	20050511N25	2005-05-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	03002P	SUPPLEANT	\N	\N
2885	20050511N25	2005-05-11 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	SUPPLEANT	\N	\N
2886	NEANT	2005-06-19 00:00:00	2005-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	05011Y	\N	\N	\N
2887	SOCI	2005-06-29 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	05011Y	\N	\N	\N
2890	20050629N26	2005-06-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	95035G	TITULAIRE	\N	2017-09-24 18:17:56
2891	20050629N26	2005-06-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	04043D	TITULAIRE	\N	\N
2892	20050629N26	2005-06-29 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80041C	TITULAIRE	\N	\N
2893	20050629N26	2005-06-29 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01036R	TITULAIRE	\N	\N
2894	20050629N26	2005-06-29 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	00002B	TITULAIRE	\N	\N
2895	20050629N26	2005-06-29 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98045W	SUPPLEANT	\N	\N
2896	20050629N26	2005-06-29 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	SUPPLEANT	\N	2014-09-28 17:07:41
2897	20050629N26	2005-06-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01011G	SUPPLEANT	\N	2017-09-24 16:43:43
2898	20050629N26	2005-06-29 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01030K	SUPPLEANT	\N	\N
2899	20050629N26	2005-06-29 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	01043Q	SUPPLEANT	\N	\N
2900	20050629N26	2005-06-29 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80031A	SUPPLEANT	\N	\N
2901	20050629N26	2005-06-29 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01029S	SUPPLEANT	\N	\N
2902	20050630N27	2005-06-30 00:00:00	2015-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-12 09:39:30
2903	20050630N27	2005-06-30 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
2904	20050630N27	2005-06-30 00:00:00	2010-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	01017N	TITULAIRE	\N	\N
2905	20050630N27	2005-06-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	TITULAIRE	\N	2014-09-28 18:00:58
2906	20050630N27	2005-06-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
2907	20050630N27	2005-06-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95006B	TITULAIRE	\N	\N
2908	20050630N27	2005-06-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	04085P	TITULAIRE	\N	\N
2910	20050630N27	2005-06-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	SUPPLEANT	\N	\N
2911	20050630N27	2005-06-30 00:00:00	2007-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	04072J	SUPPLEANT	\N	\N
2912	20050630N27	2005-06-30 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89035T	SUPPLEANT	\N	\N
2913	20050630N27	2005-06-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01019Q	SUPPLEANT	\N	2017-09-24 17:35:15
2914	20050630N27	2005-06-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98035U	SUPPLEANT	\N	\N
2915	20050630N27	2005-06-30 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	SUPPLEANT	\N	\N
2916	20050705N28	2005-07-05 00:00:00	2014-07-01 00:00:00	ANCIEN	\N	\N	\N	\N	83011J	TITULAIRE	\N	2014-07-01 09:25:11
2917	20050705N28	2005-07-05 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
2919	20050705N28	2005-07-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
2920	20050705N28	2005-07-05 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	78003A	TITULAIRE	\N	\N
2921	20050705N28	2005-07-05 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	98046X	TITULAIRE	\N	2017-09-25 09:56:00
2922	20050705N28	2005-07-05 00:00:00	2018-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	98053W	TITULAIRE	\N	2018-05-31 10:52:17
2923	20050705N28	2005-07-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	97009N	SUPPLEANT	\N	\N
2924	20050705N28	2005-07-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95007C	SUPPLEANT	\N	\N
2925	20050705N28	2005-07-05 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89022N	SUPPLEANT	\N	2014-09-28 18:19:47
2926	20050705N28	2005-07-05 00:00:00	2012-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	SUPPLEANT	\N	\N
2927	20050705N28	2005-07-05 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	94003T	SUPPLEANT	\N	2014-09-28 13:16:32
2928	20050705N28	2005-07-05 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	98032R	SUPPLEANT	\N	2015-06-12 15:59:49
2929	20050705N28	2005-07-05 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86049M	SUPPLEANT	\N	2014-09-28 18:03:38
2930	20050707N29	2005-07-07 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	95004Y	TITULAIRE	\N	\N
2931	20050707N29	2005-07-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	95035G	TITULAIRE	\N	2017-09-24 18:17:56
2932	20050707N29	2005-07-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01033N	TITULAIRE	\N	\N
2933	20050707N29	2005-07-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01018P	TITULAIRE	\N	\N
2934	20050707N29	2005-07-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01029S	TITULAIRE	\N	\N
2935	20050707N29	2005-07-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01011G	TITULAIRE	\N	2017-09-24 16:43:43
2936	20050707N29	2005-07-07 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	00002B	TITULAIRE	\N	\N
2937	20050707N29	2005-07-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92011K	SUPPLEANT	\N	\N
2938	20050707N29	2005-07-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04081K	SUPPLEANT	\N	2017-09-24 19:25:10
2940	20050707N29	2005-07-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04075M	SUPPLEANT	\N	\N
2941	20050707N29	2005-07-07 00:00:00	2014-09-01 00:00:00	ANCIEN	\N	\N	\N	\N	96007G	SUPPLEANT	\N	2014-09-01 10:21:13
2942	20050707N29	2005-07-07 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89041R	SUPPLEANT	\N	\N
2943	20050707N29	2005-07-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	01034P	SUPPLEANT	\N	\N
2944	20050707N30	2005-07-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95030B	TITULAIRE	\N	2014-09-28 18:58:21
2945	20050707N30	2005-07-07 00:00:00	2018-12-30 00:00:00	ANCIEN	\N	\N	\N	\N	98023Q	TITULAIRE	\N	\N
2946	20050707N30	2005-07-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	04043D	TITULAIRE	\N	\N
2947	20050707N30	2005-07-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	04042C	TITULAIRE	\N	\N
2948	20050707N30	2005-07-07 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89025R	TITULAIRE	\N	\N
2950	20050707N30	2005-07-07 00:00:00	2014-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	01052R	TITULAIRE	\N	2014-11-04 11:22:47
2951	20050707N30	2005-07-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83021L	SUPPLEANT	\N	\N
2952	20050707N30	2005-07-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92018S	SUPPLEANT	\N	2017-09-24 18:16:52
2954	20050707N30	2005-07-07 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	SUPPLEANT	\N	2017-05-16 15:18:13
2955	20050707N30	2005-07-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	SUPPLEANT	\N	\N
2956	20050707N30	2005-07-07 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	02005N	SUPPLEANT	\N	\N
2957	20050707N30	2005-07-07 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	03002P	SUPPLEANT	\N	\N
2959	NEANT	2005-09-19 00:00:00	2005-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	05012A	\N	\N	\N
2960	NEANT	2005-09-19 00:00:00	2005-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	02009S	\N	\N	\N
2961	NEANT	2005-09-19 00:00:00	2005-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	95059Q	\N	\N	\N
2963	AFCL	2005-10-04 00:00:00	2006-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	92033R	\N	\N	\N
2964	ECON	2005-10-04 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	04088S	\N	\N	\N
2966	ETRD	2005-10-04 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	95059Q	\N	\N	2017-10-04 19:11:48
2967	ETRD	2005-10-04 00:00:00	2008-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	95031C	\N	\N	\N
2968	SOCI	2005-10-04 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98017S	\N	\N	\N
4058	2008CMP9	2008-07-10 00:00:00	2008-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	04090L	TITULAIRE	\N	\N
4059	2008CMP9	2008-07-10 00:00:00	2008-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	04081K	SUPPLEANT	\N	2017-09-24 19:25:10
4060	2008CMP9	2008-07-10 00:00:00	2008-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	04071H	SUPPLEANT	\N	\N
4061	2008CMP9	2008-07-10 00:00:00	2008-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	85003S	SUPPLEANT	\N	\N
4063	2008CMP9	2008-07-10 00:00:00	2008-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	04043D	SUPPLEANT	\N	\N
4064	2008CMP9	2008-07-10 00:00:00	2008-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	04033B	SUPPLEANT	\N	\N
4065	2008CMP9	2008-07-10 00:00:00	2008-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	97005J	SUPPLEANT	\N	\N
4066	2008CMP10	2008-07-09 00:00:00	2008-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	83011J	TITULAIRE	\N	2014-07-01 09:25:11
4067	2008CMP10	2008-07-09 00:00:00	2008-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
4068	2008CMP10	2008-07-09 00:00:00	2008-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	94003T	TITULAIRE	\N	2014-09-28 13:16:32
4069	2008CMP10	2008-07-09 00:00:00	2008-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	92029V	TITULAIRE	\N	\N
4070	2008CMP10	2008-07-09 00:00:00	2008-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	77043E	TITULAIRE	\N	2014-09-28 16:59:41
4071	2008CMP10	2008-07-09 00:00:00	2008-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	95003X	TITULAIRE	\N	\N
4072	2008CMP10	2008-07-09 00:00:00	2008-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	98053W	TITULAIRE	\N	2018-05-31 10:52:17
4073	2008CMP10	2008-07-09 00:00:00	2008-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	89017R	SUPPLEANT	\N	\N
4074	2008CMP10	2008-07-09 00:00:00	2008-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	97009N	SUPPLEANT	\N	\N
4076	2008CMP10	2008-07-09 00:00:00	2008-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	89022N	SUPPLEANT	\N	2014-09-28 18:19:47
4077	2008CMP10	2008-07-09 00:00:00	2008-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	SUPPLEANT	\N	\N
4078	2008CMP10	2008-07-09 00:00:00	2008-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	78003A	SUPPLEANT	\N	\N
4079	2008CMP10	2008-07-09 00:00:00	2008-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	86049M	SUPPLEANT	\N	2014-09-28 18:03:38
4255	ECON	2008-10-07 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	08057C	\N	\N	\N
4256	SOCI	2008-10-07 00:00:00	2010-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	08013P	\N	\N	\N
4257	ECON	2008-10-07 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	08038Y	\N	\N	\N
4258	ECON	2008-10-07 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	08066D	\N	\N	\N
4259	ECON	2008-10-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04079R	\N	\N	\N
4260	ECON	2008-10-07 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	08033T	\N	\N	\N
4262	ECON	2008-10-07 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	08021P	\N	\N	\N
4263	ECON	2008-10-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08073C	\N	\N	\N
4264	ECON	2008-10-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08061X	\N	\N	\N
4265	ECON	2008-10-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	06005F	\N	\N	\N
4266	ETRD	2008-10-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08072B	\N	\N	\N
4267	ETRD	2008-10-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95006B	\N	\N	\N
4269	ETRD	2008-10-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08059E	\N	\N	2014-09-28 17:27:29
4270	ETRD	2008-10-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89015P	\N	\N	2014-09-28 16:50:17
4271	ETRD	2008-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08058D	\N	\N	2017-10-04 19:51:20
4272	ETRD	2008-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08053X	\N	\N	2017-10-04 19:55:18
4273	ETRD	2008-10-07 00:00:00	2009-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	86039K	\N	\N	\N
4274	ETRD	2008-10-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	96006F	\N	\N	2014-09-28 16:50:17
4275	ETRD	2008-10-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01014K	\N	\N	2017-09-24 17:19:42
4276	ECON	2008-10-07 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	08068F	\N	\N	\N
4205	NEANT	2008-10-01 00:00:00	2018-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	\N	\N	\N
4161	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08029X	\N	\N	\N
4191	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08041T	\N	\N	\N
4211	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08056B	\N	\N	\N
4230	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08070Y	\N	\N	\N
4277	SOCI	2008-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	\N	\N	2017-10-04 19:59:43
3387	20061117N51	2006-11-17 00:00:00	2006-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	TITULAIRE	\N	\N
3388	20061117N51	2006-11-17 00:00:00	2006-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	92030N	TITULAIRE	\N	\N
3389	20061117N51	2006-11-17 00:00:00	2006-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	01018P	TITULAIRE	\N	\N
3390	20061117N51	2006-11-17 00:00:00	2006-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	04037F	TITULAIRE	\N	\N
3391	20061117N51	2006-11-17 00:00:00	2006-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	98029W	TITULAIRE	\N	\N
3771	NEANT	2007-11-22 00:00:00	2007-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	07032N	\N	\N	\N
3772	2007CMP14	2007-11-16 00:00:00	2007-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	95004Y	TITULAIRE	\N	\N
3773	2007CMP14	2007-11-16 00:00:00	2007-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	TITULAIRE	\N	\N
3774	2007CMP14	2007-11-16 00:00:00	2007-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	01018P	TITULAIRE	\N	\N
3775	2007CMP14	2007-11-16 00:00:00	2007-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	98024R	TITULAIRE	\N	\N
3776	2007CMP14	2007-11-16 00:00:00	2007-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	04037F	TITULAIRE	\N	\N
3779	2007CMP14	2007-11-16 00:00:00	2007-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	83012K	SUPPLEANT	\N	\N
3897	2008CMP1	2008-01-24 00:00:00	2008-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	04055H	TITULAIRE	\N	2017-09-24 18:05:41
3269	20060405N45	2006-04-05 00:00:00	2006-04-11 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	\N	\N
3270	20060405N45	2006-04-05 00:00:00	2006-04-11 00:00:00	ANCIEN	\N	\N	\N	\N	92022N	SUPPLEANT	\N	\N
3271	20060405N45	2006-04-05 00:00:00	2006-04-11 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	\N	\N
3272	20060405N45	2006-04-05 00:00:00	2006-04-11 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	TITULAIRE	\N	2017-09-24 13:29:42
3273	20060405N45	2006-04-05 00:00:00	2006-04-11 00:00:00	ANCIEN	\N	\N	\N	\N	95011X	TITULAIRE	\N	\N
3274	20060405N45	2006-04-05 00:00:00	2006-04-11 00:00:00	ANCIEN	\N	\N	\N	\N	04063H	SUPPLEANT	\N	\N
2257	20040413N4	2004-04-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92044U	TITULAIRE	\N	2017-09-24 18:16:52
2258	20040413N4	2004-04-13 00:00:00	2010-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	01017N	TITULAIRE	\N	\N
2259	20040413N4	2004-04-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	TITULAIRE	\N	2017-09-24 17:09:24
2260	20040413N4	2004-04-13 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	97005J	TITULAIRE	\N	\N
2261	20040413N4	2004-04-13 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98048A	SUPPLEANT	\N	\N
2262	20040413N4	2004-04-13 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95040D	SUPPLEANT	\N	\N
2263	20040413N4	2004-04-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	82002D	SUPPLEANT	\N	\N
6662	JEUNES	2009-03-11 00:00:00	2009-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	08050U	\N	\N	\N
6663	JEUNES	2009-03-11 00:00:00	2009-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	08068F	\N	\N	\N
6664	JEUNES	2009-03-11 00:00:00	2009-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	04056J	\N	\N	\N
6665	JEUNES	2009-03-11 00:00:00	2009-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	\N	\N	\N
6666	JEUNES	2009-03-11 00:00:00	2009-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	04046G	\N	\N	\N
6667	JEUNES	2009-03-11 00:00:00	2009-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	04067M	\N	\N	\N
6668	JEUNES	2009-03-11 00:00:00	2009-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	06001B	\N	\N	\N
6669	JEUNES	2009-03-11 00:00:00	2009-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	04076N	\N	\N	\N
6848	2009CMP10	2009-07-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	TITULAIRE	\N	\N
6853	2009CMP10	2009-07-07 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	01063U	SUPPLEANT	\N	2014-09-29 13:41:53
6490	2008CMP16	2008-11-20 00:00:00	2008-11-25 00:00:00	ANCIEN	\N	\N	\N	\N	92030N	TITULAIRE	\N	\N
6491	2008CMP16	2008-11-20 00:00:00	2008-11-25 00:00:00	ANCIEN	\N	\N	\N	\N	04037F	TITULAIRE	\N	\N
6492	2008CMP16	2008-11-20 00:00:00	2008-11-25 00:00:00	ANCIEN	\N	\N	\N	\N	98029W	TITULAIRE	\N	\N
6494	2008CMP16	2008-11-20 00:00:00	2008-11-25 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	TITULAIRE	\N	2014-09-28 17:07:41
6495	2008CMP16	2008-11-20 00:00:00	2008-11-25 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	SUPPLEANT	\N	2017-09-24 13:44:49
6507	2008CMP17	2008-11-13 00:00:00	2009-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	TITULAIRE	\N	\N
6855	2009CMP10	2009-07-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	SUPPLEANT	\N	\N
6856	2009CMP10	2009-07-07 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	08064B	SUPPLEANT	\N	\N
6857	2009CMP10	2009-07-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	SUPPLEANT	\N	2014-09-28 18:00:58
6858	2009CMP10	2009-07-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01019Q	SUPPLEANT	\N	2017-09-24 17:35:15
6859	2009CMP10	2009-07-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	SUPPLEANT	\N	\N
3995	2008CMP7	2008-06-03 00:00:00	2008-06-10 00:00:00	ANCIEN	\N	\N	\N	\N	95047L	SUPPLEANT	\N	2014-09-28 17:09:16
3996	2008CMP7	2008-06-03 00:00:00	2008-06-10 00:00:00	ANCIEN	\N	\N	\N	\N	98007Q	SUPPLEANT	\N	\N
3999	2008CMP7	2008-06-03 00:00:00	2008-06-10 00:00:00	ANCIEN	\N	\N	\N	\N	06004E	SUPPLEANT	\N	2014-09-28 17:03:42
4122	NEANT	2008-09-08 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08008S	\N	\N	\N
4268	AFCL	2008-10-07 00:00:00	2009-07-20 00:00:00	ANCIEN	\N	\N	\N	\N	98006P	\N	\N	\N
4278	SOCI	2008-10-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04067M	\N	\N	2017-09-24 17:47:27
4280	SOCI	2008-10-07 00:00:00	2013-07-14 00:00:00	ANCIEN	\N	\N	\N	\N	08035V	\N	\N	2013-07-15 18:34:02
4281	SOCI	2008-10-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08067E	\N	\N	2014-09-28 17:22:11
4282	SOCI	2008-10-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08037X	\N	\N	2014-09-28 17:34:16
4283	SOCI	2008-10-07 00:00:00	2014-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	08046Y	\N	\N	2014-02-14 10:10:22
4284	FINC	2008-10-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	\N	\N	2017-09-24 18:20:10
4285	FINC	2008-10-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08027V	\N	\N	2014-09-28 17:34:16
4286	FINC	2008-10-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	03001N	\N	\N	2014-09-28 13:40:33
4287	AFCL	2008-10-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	83047W	\N	\N	2017-09-24 17:42:26
4288	FINC	2008-10-07 00:00:00	2011-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	08070Y	\N	\N	\N
4289	FINC	2008-10-07 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	01062T	\N	\N	2014-10-08 17:04:21
4290	LOIS	2008-10-07 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08025T	\N	\N	2017-10-01 10:17:18
4291	LOIS	2008-10-07 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	08060W	\N	\N	2014-10-08 16:52:42
4292	LOIS	2008-10-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08032S	\N	\N	2014-09-28 17:34:16
4293	LOIS	2008-10-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04084N	\N	\N	2014-09-28 13:40:33
4294	LOIS	2008-10-07 00:00:00	2009-11-24 00:00:00	ANCIEN	\N	\N	\N	\N	08029X	\N	\N	\N
4295	LOIS	2008-10-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08071A	\N	\N	\N
4296	LOIS	2008-10-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08064B	\N	\N	\N
4297	LOIS	2008-10-07 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	\N	\N	2017-06-19 12:20:59
4298	ECON	2008-10-07 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	06004E	\N	\N	\N
3892	LOIS	2008-01-16 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	07034Q	\N	\N	2017-10-04 19:50:19
3895	AFCL	2008-01-16 00:00:00	2008-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	04042C	\N	\N	\N
3909	2008CMP1	2008-01-24 00:00:00	2008-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	89041R	SUPPLEANT	\N	\N
3945	AFCL	2008-04-29 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08007R	\N	\N	\N
3967	2008CMP5	2008-05-14 00:00:00	2008-05-14 00:00:00	ANCIEN	\N	\N	\N	\N	95052H	TITULAIRE	\N	2014-09-28 13:39:20
3968	2008CMP5	2008-05-14 00:00:00	2008-05-14 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	TITULAIRE	\N	2017-09-24 17:09:24
3975	2008CMP6	2008-05-21 00:00:00	2008-06-03 00:00:00	ANCIEN	\N	\N	\N	\N	95035G	TITULAIRE	\N	2017-09-24 18:17:56
3976	2008CMP6	2008-05-21 00:00:00	2008-06-03 00:00:00	ANCIEN	\N	\N	\N	\N	04043D	TITULAIRE	\N	\N
3978	2008CMP6	2008-05-21 00:00:00	2008-06-03 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	TITULAIRE	\N	2017-09-24 17:35:15
3979	2008CMP6	2008-05-21 00:00:00	2008-06-03 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	SUPPLEANT	\N	2014-09-28 17:07:41
3980	2008CMP6	2008-05-21 00:00:00	2008-06-03 00:00:00	ANCIEN	\N	\N	\N	\N	01033N	SUPPLEANT	\N	\N
3981	2008CMP6	2008-05-21 00:00:00	2008-06-03 00:00:00	ANCIEN	\N	\N	\N	\N	92030N	SUPPLEANT	\N	\N
3983	2008CMP6	2008-05-21 00:00:00	2008-06-03 00:00:00	ANCIEN	\N	\N	\N	\N	80031A	SUPPLEANT	\N	\N
3984	2008CMP6	2008-05-21 00:00:00	2008-06-03 00:00:00	ANCIEN	\N	\N	\N	\N	80041C	SUPPLEANT	\N	\N
3985	2008CMP6	2008-05-21 00:00:00	2008-06-03 00:00:00	ANCIEN	\N	\N	\N	\N	01034P	SUPPLEANT	\N	\N
4207	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	02053W	\N	\N	\N
4300	ECON	2008-10-07 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	08049C	\N	\N	\N
4301	AFCL	2008-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08031R	\N	\N	2017-10-04 19:44:05
4302	AFCL	2008-10-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98010K	\N	\N	2014-09-28 17:27:35
4303	ETRD	2008-10-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	02053W	\N	\N	2014-09-28 12:32:23
4304	ETRD	2008-10-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08074D	\N	\N	\N
4306	AFCL	2008-10-07 00:00:00	2009-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	95049N	\N	\N	\N
4307	ECON	2008-10-07 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	08009T	\N	\N	\N
4308	SOCI	2008-10-07 00:00:00	2009-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	01052R	\N	\N	\N
4309	ETRD	2008-10-07 00:00:00	2009-07-20 00:00:00	ANCIEN	\N	\N	\N	\N	01006K	\N	\N	\N
4310	ETRD	2008-10-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04091M	\N	\N	2014-09-28 17:55:37
4311	ETRD	2008-10-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95019G	\N	\N	2014-09-28 16:59:41
3693	ECON	2007-09-19 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	07030L	\N	\N	\N
4312	ETRD	2008-10-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	07030L	\N	\N	2014-09-28 17:03:41
4313	ETRD	2008-10-07 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	08065C	\N	\N	2017-09-25 09:57:52
4314	ETRD	2008-10-07 00:00:00	2009-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	07024N	\N	\N	\N
4315	ETRD	2008-10-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77058M	\N	\N	2014-09-28 12:52:10
3275	20060405N45	2006-04-05 00:00:00	2006-04-11 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	SUPPLEANT	\N	2014-09-28 18:00:58
3276	20060405N45	2006-04-05 00:00:00	2006-04-11 00:00:00	ANCIEN	\N	\N	\N	\N	01042P	SUPPLEANT	\N	2015-04-21 17:14:30
3277	20060405N45	2006-04-05 00:00:00	2006-04-11 00:00:00	ANCIEN	\N	\N	\N	\N	89035T	SUPPLEANT	\N	\N
3278	NEANT	2006-05-17 00:00:00	2006-06-05 00:00:00	ANCIEN	\N	\N	\N	\N	06001B	\N	\N	\N
3282	AFCL	2006-06-06 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	06001B	\N	\N	\N
3286	DECISION ECO	2006-06-13 00:00:00	2007-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	95007C	\N	\N	\N
3287	DECISION ECO	2006-06-13 00:00:00	2007-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	92011K	\N	\N	\N
3289	DECISION ECO	2006-06-15 00:00:00	2007-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	90003B	\N	\N	2016-05-03 09:54:34
3290	DECISION ECO	2006-06-13 00:00:00	2007-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	98023Q	\N	\N	\N
3291	DECISION ECO	2006-06-13 00:00:00	2007-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	04055H	\N	\N	\N
3292	DECISION ECO	2006-06-13 00:00:00	2007-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	04081K	\N	\N	\N
3293	DECISION ECO	2006-06-13 00:00:00	2007-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	92018S	\N	\N	\N
3294	DECISION ECO	2006-06-13 00:00:00	2007-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	89025R	\N	\N	\N
3295	DECISION ECO	2006-06-13 00:00:00	2007-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	01017N	\N	\N	\N
3297	DECISION ECO	2006-06-13 00:00:00	2007-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	04075M	\N	\N	\N
3298	DECISION ECO	2006-06-13 00:00:00	2007-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	92029V	\N	\N	\N
3299	DECISION ECO	2006-06-15 00:00:00	2007-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	\N	\N	2018-01-25 13:08:03
3300	DECISION ECO	2006-06-13 00:00:00	2007-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	98046X	\N	\N	\N
3301	DECISION ECO	2006-06-13 00:00:00	2007-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	\N	\N	\N
3302	DECISION ECO	2006-06-13 00:00:00	2007-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	04084N	\N	\N	\N
3303	DECISION ECO	2006-06-13 00:00:00	2007-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	98032R	\N	\N	\N
3304	DECISION ECO	2006-06-13 00:00:00	2007-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	00002B	\N	\N	\N
3306	DECISION ECO	2006-06-13 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	98012M	\N	\N	\N
3307	20060608N46	2006-06-08 00:00:00	2006-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	95030B	TITULAIRE	\N	2014-09-28 18:58:21
3308	20060608N46	2006-06-08 00:00:00	2006-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	95013A	TITULAIRE	\N	\N
3309	20060608N46	2006-06-08 00:00:00	2006-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	98027U	TITULAIRE	\N	2015-06-12 16:01:58
3310	20060608N46	2006-06-08 00:00:00	2006-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	01043Q	TITULAIRE	\N	\N
3406	20061214N52	2006-12-12 00:00:00	2006-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	83011J	TITULAIRE	\N	2014-07-01 09:25:11
3407	20061214N52	2006-12-12 00:00:00	2006-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
3408	20061214N52	2006-12-12 00:00:00	2006-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	94003T	TITULAIRE	\N	2014-09-28 13:16:32
3409	20061214N52	2006-12-12 00:00:00	2006-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	77043E	TITULAIRE	\N	2014-09-28 16:59:41
3410	20061214N52	2006-12-12 00:00:00	2006-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	98032R	TITULAIRE	\N	2015-06-12 15:59:49
3413	20061214N52	2006-12-12 00:00:00	2006-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	89017R	SUPPLEANT	\N	\N
3414	20061214N52	2006-12-12 00:00:00	2006-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	98011L	SUPPLEANT	\N	2014-09-28 17:27:35
3415	20061214N52	2006-12-12 00:00:00	2006-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	95007C	SUPPLEANT	\N	\N
3416	20061214N52	2006-12-12 00:00:00	2006-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	SUPPLEANT	\N	\N
3421	20061214N53	2006-12-14 00:00:00	2006-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	01058X	TITULAIRE	\N	\N
3424	20061214N53	2006-12-14 00:00:00	2006-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	01050P	TITULAIRE	\N	\N
3425	20061214N53	2006-12-14 00:00:00	2006-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	92042S	TITULAIRE	\N	\N
3429	20061214N53	2006-12-14 00:00:00	2006-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	SUPPLEANT	\N	2017-05-16 15:18:13
3433	20061214N53	2006-12-14 00:00:00	2006-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	03002P	SUPPLEANT	\N	\N
3434	20061219N54	2006-12-19 00:00:00	2006-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	83011J	TITULAIRE	\N	2014-07-01 09:25:11
3435	20061219N54	2006-12-19 00:00:00	2006-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
3436	20061219N54	2006-12-19 00:00:00	2006-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	94003T	TITULAIRE	\N	2014-09-28 13:16:32
3437	20061219N54	2006-12-19 00:00:00	2006-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	89022N	TITULAIRE	\N	2014-09-28 18:19:47
3674	ECON	2007-07-04 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	04090L	\N	\N	\N
3675	AFCL	2007-07-04 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	01043Q	\N	\N	\N
3676	SOCI	2007-07-04 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04051D	\N	\N	2014-09-28 17:07:41
3959	2008CMP4	2008-04-16 00:00:00	2008-05-13 00:00:00	ANCIEN	\N	\N	\N	\N	04069P	SUPPLEANT	\N	2014-09-28 17:31:41
3998	2008CMP7	2008-06-03 00:00:00	2008-06-10 00:00:00	ANCIEN	\N	\N	\N	\N	01062T	SUPPLEANT	\N	2014-12-18 16:15:04
4027	ECONOMIE	2008-06-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	04042C	\N	\N	\N
4028	ECONOMIE	2008-06-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	95015C	\N	\N	\N
4029	ECONOMIE	2008-06-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	04081K	\N	\N	\N
4030	ECONOMIE	2008-06-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	04046G	\N	\N	\N
4031	ECONOMIE	2008-06-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	89027T	\N	\N	\N
4032	ECONOMIE	2008-06-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	01011G	\N	\N	\N
4033	ECONOMIE	2008-06-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	95035G	\N	\N	\N
4034	ECONOMIE	2008-06-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	04037F	\N	\N	\N
4035	ECONOMIE	2008-06-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	85003S	\N	\N	\N
4036	ECONOMIE	2008-06-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	97004H	\N	\N	\N
4037	ECONOMIE	2008-06-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	01009N	\N	\N	\N
4038	ECONOMIE	2008-06-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	04043D	\N	\N	\N
4040	2008CMP8	2008-07-02 00:00:00	2008-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	95030B	TITULAIRE	\N	2014-09-28 18:58:21
4041	2008CMP8	2008-07-02 00:00:00	2008-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	95013A	TITULAIRE	\N	\N
4042	2008CMP8	2008-07-02 00:00:00	2008-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	96004D	TITULAIRE	\N	\N
4080	2008CMP11	2008-07-17 00:00:00	2008-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	80046H	TITULAIRE	\N	\N
4081	2008CMP11	2008-07-17 00:00:00	2008-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	92005M	TITULAIRE	\N	\N
4082	2008CMP11	2008-07-17 00:00:00	2008-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	95015C	TITULAIRE	\N	\N
4083	2008CMP11	2008-07-17 00:00:00	2008-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	89007P	TITULAIRE	\N	2014-09-28 16:42:05
4084	2008CMP11	2008-07-17 00:00:00	2008-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	01025N	TITULAIRE	\N	\N
4085	2008CMP11	2008-07-17 00:00:00	2008-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	04052E	TITULAIRE	\N	\N
4086	2008CMP11	2008-07-17 00:00:00	2008-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	97004H	TITULAIRE	\N	\N
4092	2008CMP11	2008-07-17 00:00:00	2008-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	01039U	SUPPLEANT	\N	\N
4093	2008CMP11	2008-07-17 00:00:00	2008-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	01062T	SUPPLEANT	\N	2014-12-18 16:15:04
4094	2008CMP12	2008-07-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	95004Y	TITULAIRE	\N	\N
4095	2008CMP12	2008-07-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	92030N	TITULAIRE	\N	\N
4096	2008CMP12	2008-07-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	02003L	TITULAIRE	\N	\N
4097	2008CMP12	2008-07-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	01033N	TITULAIRE	\N	\N
4098	2008CMP12	2008-07-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	80041C	TITULAIRE	\N	\N
4099	2008CMP12	2008-07-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	04046G	TITULAIRE	\N	2014-09-28 17:07:41
4100	2008CMP12	2008-07-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	TITULAIRE	\N	2017-09-24 17:35:15
4106	2008CMP12	2008-07-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	04043D	SUPPLEANT	\N	\N
4107	2008CMP12	2008-07-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	89041R	SUPPLEANT	\N	\N
4111	2008CMP13	2008-07-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	98045W	TITULAIRE	\N	\N
4112	2008CMP13	2008-07-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	04043D	TITULAIRE	\N	\N
3540	2007CMP3	2007-02-01 00:00:00	2007-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	80046H	TITULAIRE	\N	\N
3541	2007CMP3	2007-02-01 00:00:00	2007-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	98048A	TITULAIRE	\N	\N
3542	2007CMP3	2007-02-01 00:00:00	2007-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	04033B	TITULAIRE	\N	\N
3543	2007CMP3	2007-02-01 00:00:00	2007-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	97004H	TITULAIRE	\N	\N
3544	2007CMP3	2007-02-01 00:00:00	2007-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	01044R	TITULAIRE	\N	2017-07-04 15:08:09
3554	2007CMP3	2007-02-01 00:00:00	2007-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	04057K	TITULAIRE	\N	\N
3557	2007CMP4	2007-02-07 00:00:00	2007-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	TITULAIRE	\N	2014-09-28 18:00:58
3558	2007CMP4	2007-02-07 00:00:00	2007-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	01001E	TITULAIRE	\N	\N
3559	2007CMP4	2007-02-07 00:00:00	2007-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	01063U	TITULAIRE	\N	2014-09-29 13:41:53
3561	2007CMP4	2007-02-07 00:00:00	2007-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	95011X	TITULAIRE	\N	\N
3562	2007CMP4	2007-02-07 00:00:00	2007-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	04042C	SUPPLEANT	\N	\N
3563	2007CMP4	2007-02-07 00:00:00	2007-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	92022N	SUPPLEANT	\N	\N
3564	2007CMP4	2007-02-07 00:00:00	2007-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	01042P	SUPPLEANT	\N	2015-04-21 17:14:30
3565	2007CMP4	2007-02-07 00:00:00	2007-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	89035T	SUPPLEANT	\N	\N
3567	2007CMP4	2007-02-07 00:00:00	2007-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	04074L	SUPPLEANT	\N	2017-09-24 17:15:15
3569	2007CMP5	2007-02-12 00:00:00	2007-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-12 09:39:30
3572	2007CMP5	2007-02-12 00:00:00	2007-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	01001E	TITULAIRE	\N	\N
3573	2007CMP5	2007-02-12 00:00:00	2007-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	01063U	TITULAIRE	\N	2014-09-29 13:41:53
3574	2007CMP5	2007-02-12 00:00:00	2007-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	95006B	TITULAIRE	\N	\N
3575	2007CMP5	2007-02-12 00:00:00	2007-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	95011X	TITULAIRE	\N	\N
3576	2007CMP5	2007-02-12 00:00:00	2007-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	04042C	SUPPLEANT	\N	\N
3578	2007CMP5	2007-02-12 00:00:00	2007-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	01042P	SUPPLEANT	\N	2015-04-21 17:14:30
3580	2007CMP5	2007-02-12 00:00:00	2007-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	95055L	SUPPLEANT	\N	2014-09-28 13:21:47
3581	2007CMP5	2007-02-12 00:00:00	2007-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	04074L	SUPPLEANT	\N	2017-09-24 17:15:15
7193	2010CMP2	2010-02-18 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	95004Y	TITULAIRE	\N	\N
7194	2010CMP2	2010-02-18 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08025T	TITULAIRE	\N	2017-10-01 10:17:18
7195	2010CMP2	2010-02-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01053S	TITULAIRE	\N	\N
7196	2010CMP2	2010-02-18 00:00:00	2012-09-19 00:00:00	ANCIEN	\N	\N	\N	\N	95011X	TITULAIRE	\N	\N
7197	2010CMP2	2010-02-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01001E	SUPPLEANT	\N	\N
7198	2010CMP2	2010-02-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	SUPPLEANT	\N	\N
7199	2010CMP2	2010-02-18 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08032S	SUPPLEANT	\N	2014-09-28 17:34:16
7200	2010CMP2	2010-02-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	08010L	SUPPLEANT	\N	\N
6969	DECHETS	2009-10-14 00:00:00	2010-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	98036V	\N	\N	\N
6970	DECHETS	2009-10-14 00:00:00	2010-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	08072B	\N	\N	\N
6971	DECHETS	2009-10-14 00:00:00	2010-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	98011L	\N	\N	\N
6973	DECHETS	2009-10-14 00:00:00	2010-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	95013A	\N	\N	\N
6974	DECHETS	2009-10-14 00:00:00	2010-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	07028S	\N	\N	\N
6975	DECHETS	2009-10-14 00:00:00	2010-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	01015L	\N	\N	\N
6976	DECHETS	2009-10-14 00:00:00	2010-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	04089T	\N	\N	\N
6977	DECHETS	2009-10-14 00:00:00	2010-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	01057W	\N	\N	\N
6978	DECHETS	2009-10-14 00:00:00	2010-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	95038K	\N	\N	\N
6979	DECHETS	2009-10-14 00:00:00	2010-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	08074D	\N	\N	\N
6980	DECHETS	2009-10-14 00:00:00	2010-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	92039X	\N	\N	\N
6981	DECHETS	2009-10-14 00:00:00	2010-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	07027R	\N	\N	\N
6982	DECHETS	2009-10-14 00:00:00	2010-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	95052H	\N	\N	\N
6983	DECHETS	\N	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	\N	\N	2017-09-24 17:09:24
6984	DECHETS	2009-10-14 00:00:00	2010-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	04069P	\N	\N	\N
6985	DECHETS	2009-10-14 00:00:00	2010-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	01050P	\N	\N	\N
6986	DECHETS	2009-10-14 00:00:00	2010-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	\N	\N	\N
7001	2009CMP18	2009-11-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83050R	TITULAIRE	\N	\N
7002	2009CMP18	2009-11-06 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95019G	TITULAIRE	\N	2014-09-28 16:59:41
7201	2010CMP2	2010-02-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95046K	SUPPLEANT	\N	\N
7202	2010CMP2	2010-02-18 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	SUPPLEANT	\N	2017-06-19 12:20:59
7203	2010CMP2	2010-02-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92044U	SUPPLEANT	\N	2017-09-24 18:16:52
7205	SOCI	2010-04-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10003H	\N	\N	2014-09-28 17:38:26
7207	AFEU	2010-03-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98028V	\N	\N	2014-09-28 17:22:11
7208	ETRD	2010-03-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08047A	\N	\N	2017-10-04 00:00:00
7210	ECON	2010-03-23 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	08062Y	\N	\N	\N
7211	XYNTHIA	2010-03-30 00:00:00	2010-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	89013M	\N	\N	\N
7212	XYNTHIA	2010-03-30 00:00:00	2010-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	01027Q	\N	\N	\N
6423	COLLECTIVITE	2008-10-15 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	01013J	\N	\N	\N
6424	COLLECTIVITE	2008-10-15 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	89013M	\N	\N	\N
6425	COLLECTIVITE	2008-10-15 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	08055A	\N	\N	\N
6426	COLLECTIVITE	2008-10-15 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	95013A	\N	\N	\N
6427	COLLECTIVITE	2008-10-15 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	00003C	\N	\N	\N
6428	COLLECTIVITE	2008-10-15 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	98029W	\N	\N	\N
6429	COLLECTIVITE	2008-10-15 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	\N	\N	\N
6430	COLLECTIVITE	2008-10-15 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	95020Y	\N	\N	\N
6431	COLLECTIVITE	2008-10-15 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	\N	\N	\N
6432	COLLECTIVITE	2008-10-15 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	01024M	\N	\N	\N
6433	COLLECTIVITE	2008-10-15 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	01027Q	\N	\N	\N
6434	COLLECTIVITE	2008-10-15 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	92020L	\N	\N	\N
6435	COLLECTIVITE	2008-10-15 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	08064B	\N	\N	\N
6436	COLLECTIVITE	2008-10-15 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	08065C	\N	\N	\N
6437	COLLECTIVITE	2008-10-15 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	01007L	\N	\N	\N
3781	2007CMP14	2007-11-16 00:00:00	2007-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	SUPPLEANT	\N	2017-09-24 13:44:49
3786	2007CMP14	2007-11-16 00:00:00	2007-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	04076N	SUPPLEANT	\N	\N
3907	2008CMP1	2008-01-24 00:00:00	2008-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	01029S	SUPPLEANT	\N	\N
3908	2008CMP1	2008-01-24 00:00:00	2008-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	04045F	SUPPLEANT	\N	\N
3918	2008CMP2	2008-01-24 00:00:00	2008-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	07003H	SUPPLEANT	\N	2014-09-28 12:21:28
3924	2008CMP3	2008-01-31 00:00:00	2008-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-12 09:39:30
3926	2008CMP3	2008-01-31 00:00:00	2008-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	TITULAIRE	\N	2014-09-28 18:00:58
3927	2008CMP3	2008-01-31 00:00:00	2008-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	04074L	TITULAIRE	\N	2017-09-24 17:15:15
3928	2008CMP3	2008-01-31 00:00:00	2008-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	92022N	TITULAIRE	\N	\N
3929	2008CMP3	2008-01-31 00:00:00	2008-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	95006B	TITULAIRE	\N	\N
3930	2008CMP3	2008-01-31 00:00:00	2008-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	01038T	TITULAIRE	\N	\N
3931	2008CMP3	2008-01-31 00:00:00	2008-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	01065W	SUPPLEANT	\N	2014-09-28 12:09:44
3946	2008CMP4	2008-04-16 00:00:00	2008-05-13 00:00:00	ANCIEN	\N	\N	\N	\N	95004Y	TITULAIRE	\N	\N
3947	2008CMP4	2008-04-16 00:00:00	2008-05-13 00:00:00	ANCIEN	\N	\N	\N	\N	04051D	TITULAIRE	\N	2014-09-28 17:07:41
3949	2008CMP4	2008-04-16 00:00:00	2008-05-13 00:00:00	ANCIEN	\N	\N	\N	\N	04043D	TITULAIRE	\N	\N
3950	2008CMP4	2008-04-16 00:00:00	2008-05-13 00:00:00	ANCIEN	\N	\N	\N	\N	80041C	TITULAIRE	\N	\N
3951	2008CMP4	2008-04-16 00:00:00	2008-05-13 00:00:00	ANCIEN	\N	\N	\N	\N	04087R	SUPPLEANT	\N	2015-01-22 17:17:25
3952	2008CMP4	2008-04-16 00:00:00	2008-05-13 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	TITULAIRE	\N	2017-09-24 17:35:15
3986	2008CMP7	2008-06-03 00:00:00	2008-06-10 00:00:00	ANCIEN	\N	\N	\N	\N	80046H	TITULAIRE	\N	\N
3987	2008CMP7	2008-06-03 00:00:00	2008-06-10 00:00:00	ANCIEN	\N	\N	\N	\N	87003B	TITULAIRE	\N	2014-09-28 17:35:38
3988	2008CMP7	2008-06-03 00:00:00	2008-06-10 00:00:00	ANCIEN	\N	\N	\N	\N	89007P	TITULAIRE	\N	2014-09-28 16:42:05
3989	2008CMP7	2008-06-03 00:00:00	2008-06-10 00:00:00	ANCIEN	\N	\N	\N	\N	98028V	TITULAIRE	\N	2014-09-28 17:22:11
3990	2008CMP7	2008-06-03 00:00:00	2008-06-10 00:00:00	ANCIEN	\N	\N	\N	\N	01025N	TITULAIRE	\N	\N
3991	2008CMP7	2008-06-03 00:00:00	2008-06-10 00:00:00	ANCIEN	\N	\N	\N	\N	04052E	TITULAIRE	\N	\N
3992	2008CMP7	2008-06-03 00:00:00	2008-06-10 00:00:00	ANCIEN	\N	\N	\N	\N	04039H	TITULAIRE	\N	\N
3993	2008CMP7	2008-06-03 00:00:00	2008-06-10 00:00:00	ANCIEN	\N	\N	\N	\N	04099V	SUPPLEANT	\N	2014-09-28 16:59:41
3994	2008CMP7	2008-06-03 00:00:00	2008-06-10 00:00:00	ANCIEN	\N	\N	\N	\N	97004H	SUPPLEANT	\N	\N
6596	2009CMP4	2009-02-11 00:00:00	2009-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	95021A	SUPPLEANT	\N	2014-09-28 16:40:50
6597	2009CMP4	2009-02-11 00:00:00	2009-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	SUPPLEANT	\N	2017-05-16 15:18:13
6598	2009CMP4	2009-02-11 00:00:00	2009-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	95038K	SUPPLEANT	\N	2014-09-28 17:40:23
6599	2009CMP4	2009-02-11 00:00:00	2009-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	04083M	SUPPLEANT	\N	2014-09-28 16:40:50
6600	2009CMP4	2009-02-11 00:00:00	2009-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	04088S	SUPPLEANT	\N	\N
6601	2009CMP4	2009-02-11 00:00:00	2009-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	97005J	SUPPLEANT	\N	\N
6783	2009CMP8	2009-06-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08048B	SUPPLEANT	\N	\N
6785	2009CMP8	2009-06-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	SUPPLEANT	\N	\N
6786	FORMATIONPRO	2009-07-22 00:00:00	2009-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	\N	\N	\N
6787	FORMATIONPRO	2009-07-22 00:00:00	2009-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	08026U	\N	\N	\N
6788	FORMATIONPRO	2009-07-22 00:00:00	2009-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	04089T	\N	\N	\N
6789	FORMATIONPRO	2009-07-22 00:00:00	2009-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	01034P	\N	\N	\N
6790	FORMATIONPRO	2009-07-22 00:00:00	2009-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	\N	\N	\N
6791	FORMATIONPRO	2009-07-22 00:00:00	2009-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	04046G	\N	\N	\N
6792	FORMATIONPRO	2009-07-22 00:00:00	2009-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	96007G	\N	\N	\N
6793	FORMATIONPRO	2009-07-22 00:00:00	2009-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	04076N	\N	\N	\N
6794	FORMATIONPRO	2009-07-22 00:00:00	2009-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	04045F	\N	\N	\N
6795	FORMATIONPRO	2009-07-22 00:00:00	2009-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	04067M	\N	\N	\N
6796	FORMATIONPRO	2009-07-22 00:00:00	2009-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	01011G	\N	\N	\N
6797	FORMATIONPRO	2009-07-22 00:00:00	2009-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	08067E	\N	\N	\N
7253	AFCL	2010-04-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10005K	\N	\N	\N
6414	AFEU	2008-10-08 00:00:00	2015-04-21 00:00:00	ANCIEN	\N	\N	\N	\N	01042P	\N	\N	2015-04-21 17:14:30
6415	AFEU	2008-10-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04074L	\N	\N	\N
6416	AFEU	2008-10-08 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08050U	\N	\N	2014-09-28 12:44:31
6417	AFEU	2008-10-08 00:00:00	2009-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	\N	\N	\N
6418	AFEU	2008-10-08 00:00:00	2009-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	95055L	\N	\N	\N
6419	AFEU	2008-10-08 00:00:00	2017-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	\N	\N	2017-10-05 11:42:52
6420	AFEU	2008-10-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04054G	\N	\N	2017-09-24 17:18:03
6421	AFEU	2008-10-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	\N	\N	\N
6422	AFEU	2008-10-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95021A	\N	\N	\N
6474	2008CMP15	2008-10-29 00:00:00	2008-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	95004Y	TITULAIRE	\N	\N
6475	2008CMP15	2008-10-29 00:00:00	2008-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	04081K	TITULAIRE	\N	2017-09-24 19:25:10
6476	2008CMP15	2008-10-29 00:00:00	2008-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	04055H	TITULAIRE	\N	2017-09-24 18:05:41
6477	2008CMP15	2008-10-29 00:00:00	2008-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	04043D	TITULAIRE	\N	\N
6478	2008CMP15	2008-10-29 00:00:00	2008-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	06001B	TITULAIRE	\N	\N
6479	2008CMP15	2008-10-29 00:00:00	2008-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	04076N	TITULAIRE	\N	\N
6531	2008CMP19	2008-12-19 00:00:00	2008-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	83011J	TITULAIRE	\N	2014-07-01 09:25:11
6532	2008CMP19	2008-12-19 00:00:00	2008-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
6533	2008CMP19	2008-12-19 00:00:00	2008-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	94003T	TITULAIRE	\N	2014-09-28 13:16:32
6554	2009CMP1	2009-01-21 00:00:00	2009-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	98028V	SUPPLEANT	\N	2014-09-28 17:22:11
6670	JEUNES	2009-03-11 00:00:00	2009-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	08060W	\N	\N	\N
6671	JEUNES	2009-03-11 00:00:00	2009-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	08032S	\N	\N	\N
6672	JEUNES	2009-03-11 00:00:00	2009-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	95046K	\N	\N	\N
6673	JEUNES	2009-03-11 00:00:00	2009-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	98042T	\N	\N	\N
6674	JEUNES	2009-03-11 00:00:00	2009-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	01025N	\N	\N	\N
6675	JEUNES	2009-03-11 00:00:00	2009-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	04070G	\N	\N	\N
6676	JEUNES	2009-03-11 00:00:00	2009-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	04039H	\N	\N	\N
6677	JEUNES	2009-03-11 00:00:00	2009-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	\N	\N	\N
6678	JEUNES	2009-03-11 00:00:00	2009-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	08031R	\N	\N	\N
6679	JEUNES	2009-03-11 00:00:00	2009-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	\N	\N	\N
6680	JEUNES	2009-03-11 00:00:00	2009-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	01045S	\N	\N	\N
6688	2009CMP5	2009-04-02 00:00:00	2012-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	TITULAIRE	\N	\N
6689	2009CMP5	2009-04-02 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77043E	TITULAIRE	\N	2014-09-28 16:59:41
6690	2009CMP5	2009-04-02 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	98046X	TITULAIRE	\N	2017-09-25 09:56:00
6691	2009CMP5	2009-04-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04050C	TITULAIRE	\N	\N
6692	2009CMP5	2009-04-02 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89017R	SUPPLEANT	\N	\N
6770	LOIS	2009-06-17 00:00:00	2009-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	92033R	\N	\N	\N
6771	ETRD	2009-06-17 00:00:00	2009-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	08018U	\N	\N	\N
3008	IMMIGRATION	2005-11-03 00:00:00	2006-05-02 00:00:00	ANCIEN	\N	\N	\N	\N	04063H	\N	\N	\N
3015	IMMIGRATION	2005-11-03 00:00:00	2006-05-02 00:00:00	ANCIEN	\N	\N	\N	\N	01055U	\N	\N	\N
3023	IMMIGRATION	2005-11-03 00:00:00	2006-05-02 00:00:00	ANCIEN	\N	\N	\N	\N	01020H	\N	\N	\N
6798	FORMATIONPRO	2009-07-22 00:00:00	2009-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	04081K	\N	\N	\N
6799	FORMATIONPRO	2009-07-22 00:00:00	2009-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	08041T	\N	\N	\N
6800	FORMATIONPRO	2009-07-22 00:00:00	2009-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	95035G	\N	\N	\N
6801	FORMATIONPRO	2009-07-22 00:00:00	2009-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	08056B	\N	\N	\N
6802	FORMATIONPRO	2009-07-22 00:00:00	2009-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	04043D	\N	\N	\N
6803	FORMATIONPRO	2009-07-22 00:00:00	2009-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	08036W	\N	\N	\N
6804	FORMATIONPRO	2009-07-22 00:00:00	2009-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	01045S	\N	\N	\N
6805	FORMATIONPRO	2009-07-22 00:00:00	2009-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	07026Q	\N	\N	\N
6806	FORMATIONPRO	2009-07-22 00:00:00	2009-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	98042T	\N	\N	\N
6807	FORMATIONPRO	2009-07-22 00:00:00	2009-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	98010K	\N	\N	\N
6808	FORMATIONPRO	2009-07-22 00:00:00	2009-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	08043V	\N	\N	\N
6809	FORMATIONPRO	2009-07-22 00:00:00	2009-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	08050U	\N	\N	\N
6810	FORMATIONPRO	2009-07-22 00:00:00	2009-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	04052E	\N	\N	\N
6811	FORMATIONPRO	2009-07-22 00:00:00	2009-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	08045X	\N	\N	\N
6812	FORMATIONPRO	2009-07-22 00:00:00	2009-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	95015C	\N	\N	\N
6813	FORMATIONPRO	2009-07-22 00:00:00	2009-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	98028V	\N	\N	\N
6460	2008CMP14	2008-10-29 00:00:00	2008-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	95004Y	TITULAIRE	\N	\N
6461	2008CMP14	2008-10-29 00:00:00	2008-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	04058L	TITULAIRE	\N	\N
6462	2008CMP14	2008-10-29 00:00:00	2008-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	02003L	SUPPLEANT	\N	\N
6466	2008CMP14	2008-10-29 00:00:00	2008-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	TITULAIRE	\N	2014-09-28 17:07:41
6468	2008CMP14	2008-10-29 00:00:00	2008-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	01052R	SUPPLEANT	\N	2014-11-04 11:22:47
6469	2008CMP14	2008-10-29 00:00:00	2008-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	SUPPLEANT	\N	\N
6470	2008CMP14	2008-10-29 00:00:00	2008-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	SUPPLEANT	\N	2017-09-24 17:35:15
6471	2008CMP14	2008-10-29 00:00:00	2008-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	04081K	SUPPLEANT	\N	2017-09-24 19:25:10
6472	2008CMP14	2008-10-29 00:00:00	2008-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	04067M	SUPPLEANT	\N	2017-09-24 17:47:27
6473	2008CMP14	2008-10-29 00:00:00	2008-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	01027Q	TITULAIRE	\N	2017-09-24 17:28:55
6480	2008CMP15	2008-10-29 00:00:00	2008-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	TITULAIRE	\N	2017-09-24 17:35:15
6481	2008CMP15	2008-10-29 00:00:00	2008-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	SUPPLEANT	\N	2017-09-24 13:44:49
6482	2008CMP15	2008-10-29 00:00:00	2008-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	02003L	SUPPLEANT	\N	\N
6483	2008CMP15	2008-10-29 00:00:00	2008-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	04067M	SUPPLEANT	\N	2017-09-24 17:47:27
6518	2008CMP18	2008-12-09 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	94003T	TITULAIRE	\N	2014-09-28 13:16:32
6520	2008CMP18	2008-12-09 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	98032R	TITULAIRE	\N	2015-06-12 15:59:49
6521	2008CMP18	2008-12-09 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	TITULAIRE	\N	\N
6522	2008CMP18	2008-12-09 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	98053W	TITULAIRE	\N	2018-05-31 10:52:17
6523	2008CMP18	2008-12-09 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	89017R	SUPPLEANT	\N	\N
6530	2008CMP18	2008-12-09 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	01057W	SUPPLEANT	\N	\N
6775	2009CMP8	2009-06-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04075M	TITULAIRE	\N	\N
6776	2009CMP8	2009-06-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98029W	TITULAIRE	\N	\N
6777	2009CMP8	2009-06-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08037X	TITULAIRE	\N	2014-09-28 17:34:16
6778	2009CMP8	2009-06-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83012K	TITULAIRE	\N	\N
6779	2009CMP8	2009-06-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	SUPPLEANT	\N	2017-09-24 13:44:49
6780	2009CMP8	2009-06-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01005J	SUPPLEANT	\N	\N
6781	2009CMP8	2009-06-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	SUPPLEANT	\N	\N
6782	2009CMP8	2009-06-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	SUPPLEANT	\N	2014-09-28 17:07:41
3997	2008CMP7	2008-06-03 00:00:00	2008-06-10 00:00:00	ANCIEN	\N	\N	\N	\N	01039U	SUPPLEANT	\N	\N
6815	FORMATIONPRO	2009-07-22 00:00:00	2009-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	92031P	\N	\N	\N
6816	FORMATIONPRO	2009-07-22 00:00:00	2009-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	04057K	\N	\N	\N
6817	FORMATIONPRO	2009-07-22 00:00:00	2009-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	01055U	\N	\N	\N
6818	FORMATIONPRO	2009-07-22 00:00:00	2009-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	01056V	\N	\N	\N
6819	FORMATIONPRO	2009-07-22 00:00:00	2009-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	08061X	\N	\N	\N
6820	FORMATIONPRO	2009-07-22 00:00:00	2009-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	90003B	\N	\N	\N
6821	FORMATIONPRO	2009-07-22 00:00:00	2009-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	04055H	\N	\N	\N
6822	FORMATIONPRO	2009-07-22 00:00:00	2009-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	08022Q	\N	\N	\N
6823	FORMATIONPRO	2009-07-22 00:00:00	2009-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	01010F	\N	\N	\N
6867	AFCL	2009-09-21 00:00:00	2012-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	09010Q	\N	\N	\N
6865	ETRD	2009-07-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98006P	\N	\N	\N
6868	NEANT	2009-07-24 00:00:00	2009-09-14 00:00:00	ANCIEN	\N	\N	\N	\N	09011R	\N	\N	\N
6890	2009CMP12	2009-07-21 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	08064B	SUPPLEANT	\N	\N
6891	2009CMP12	2009-07-21 00:00:00	2017-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	01007L	SUPPLEANT	\N	2017-07-24 09:56:26
6892	2009CMP12	2009-07-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	08034U	SUPPLEANT	\N	\N
6893	2009CMP12	2009-07-21 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95055L	SUPPLEANT	\N	2014-09-28 13:21:47
6894	2009CMP12	2009-07-21 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	07034Q	SUPPLEANT	\N	\N
6895	2009CMP12	2009-07-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	SUPPLEANT	\N	\N
6918	2009CMP14	2009-09-29 00:00:00	2015-04-21 00:00:00	ANCIEN	\N	\N	\N	\N	01042P	TITULAIRE	\N	2015-04-21 17:14:30
6919	2009CMP14	2009-09-29 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	95004Y	TITULAIRE	\N	\N
6920	2009CMP14	2009-09-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04074L	TITULAIRE	\N	2017-09-24 17:15:15
6921	2009CMP14	2009-09-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08025T	TITULAIRE	\N	2017-10-01 10:17:18
6922	2009CMP14	2009-09-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
6923	2009CMP14	2009-09-29 00:00:00	2012-09-19 00:00:00	ANCIEN	\N	\N	\N	\N	95011X	TITULAIRE	\N	\N
6924	2009CMP14	2009-09-29 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04063H	SUPPLEANT	\N	\N
6925	2009CMP14	2009-09-29 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	92022N	SUPPLEANT	\N	\N
6926	2009CMP14	2009-09-29 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	SUPPLEANT	\N	2014-09-28 18:00:58
6927	2009CMP14	2009-09-29 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	SUPPLEANT	\N	2017-06-19 12:20:59
6928	2009CMP14	2009-09-29 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04084N	SUPPLEANT	\N	2014-09-28 13:40:33
6516	2008CMP18	2008-12-09 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	83011J	TITULAIRE	\N	2014-07-01 09:25:11
6517	2008CMP18	2008-12-09 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
6519	2008CMP18	2008-12-09 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	77043E	TITULAIRE	\N	2014-09-28 16:59:41
6524	2008CMP18	2008-12-09 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	97009N	SUPPLEANT	\N	\N
6525	2008CMP18	2008-12-09 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	77019E	SUPPLEANT	\N	\N
6899	ECON	2009-09-21 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	09012S	\N	\N	\N
6527	2008CMP18	2008-12-09 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	04037F	SUPPLEANT	\N	\N
6528	2008CMP18	2008-12-09 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	08011M	SUPPLEANT	\N	\N
6529	2008CMP18	2008-12-09 00:00:00	2008-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	92043T	SUPPLEANT	\N	\N
6874	2009CMP11	2009-07-08 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	04090L	TITULAIRE	\N	\N
6876	2009CMP11	2009-07-08 00:00:00	2020-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	96004D	SUPPLEANT	\N	\N
6929	2009CMP14	2009-09-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01019Q	SUPPLEANT	\N	2017-09-24 17:35:15
6930	2009CMP14	2009-09-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	\N	\N
6931	2009CMP15	2009-09-29 00:00:00	2015-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-12 09:39:30
6932	2009CMP15	2009-09-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	TITULAIRE	\N	\N
6933	2009CMP15	2009-09-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01019Q	TITULAIRE	\N	2017-09-24 17:35:15
6934	2009CMP15	2009-09-29 00:00:00	2017-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	01007L	TITULAIRE	\N	2017-07-24 09:56:26
6935	2009CMP15	2009-09-29 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95055L	TITULAIRE	\N	2014-09-28 13:21:47
6936	2009CMP15	2009-09-29 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95046K	TITULAIRE	\N	\N
6937	2009CMP15	2009-09-29 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01038T	TITULAIRE	\N	\N
6938	2009CMP15	2009-09-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	\N	\N
6939	2009CMP15	2009-09-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	SUPPLEANT	\N	\N
6940	2009CMP15	2009-09-29 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	08064B	SUPPLEANT	\N	\N
6945	2009CMP15	2009-09-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	\N	\N
6946	2009CMP16	2009-09-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	04043D	TITULAIRE	\N	\N
6947	2009CMP16	2009-09-29 00:00:00	2018-08-06 00:00:00	ANCIEN	\N	\N	\N	\N	95015C	TITULAIRE	\N	\N
6948	2009CMP16	2009-09-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	95035G	TITULAIRE	\N	2017-09-24 18:17:56
6949	2009CMP16	2009-09-29 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04046G	TITULAIRE	\N	2014-09-28 17:07:41
6950	2009CMP16	2009-09-29 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08067E	TITULAIRE	\N	2014-09-28 17:22:11
6951	2009CMP16	2009-09-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04089T	TITULAIRE	\N	\N
6602	OUTREMER	2009-03-05 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	\N	\N	\N
6603	OUTREMER	2009-03-05 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	08072B	\N	\N	\N
6604	OUTREMER	2009-03-05 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	04059M	\N	\N	\N
6605	OUTREMER	2009-03-05 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	\N	\N	\N
6606	OUTREMER	2009-03-05 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	95009E	\N	\N	\N
6607	OUTREMER	2009-03-05 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	90003B	\N	\N	\N
6608	OUTREMER	2009-03-05 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	01063U	\N	\N	\N
6609	OUTREMER	2009-03-05 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	04093P	\N	\N	\N
6610	OUTREMER	2009-03-05 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	01027Q	\N	\N	\N
6611	OUTREMER	2009-03-05 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	07033P	\N	\N	\N
6612	OUTREMER	2009-03-05 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	98052V	\N	\N	\N
6613	OUTREMER	2009-03-05 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	02001J	\N	\N	\N
6614	OUTREMER	2009-03-05 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	01017N	\N	\N	\N
6616	OUTREMER	2009-03-05 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	04064J	\N	\N	\N
6617	OUTREMER	2009-03-05 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	01057W	\N	\N	\N
6618	OUTREMER	2009-03-05 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	05001W	\N	\N	\N
6619	OUTREMER	2009-03-05 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	04094Q	\N	\N	\N
6620	OUTREMER	2009-03-05 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	95044H	\N	\N	\N
6621	OUTREMER	2009-03-05 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	77043E	\N	\N	\N
6622	OUTREMER	2009-03-05 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	04100U	\N	\N	\N
6623	OUTREMER	2009-03-05 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	\N	\N	\N
6625	OUTREMER	2009-03-05 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	95003X	\N	\N	\N
6626	OUTREMER	2009-03-05 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	08062Y	\N	\N	\N
6627	OUTREMER	2009-03-05 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	95050F	\N	\N	\N
6628	OUTREMER	2009-03-05 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	08011M	\N	\N	\N
6545	2009CMP1	2009-01-21 00:00:00	2009-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	04059M	TITULAIRE	\N	\N
6546	2009CMP1	2009-01-21 00:00:00	2009-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	07033P	TITULAIRE	\N	\N
6547	2009CMP1	2009-01-21 00:00:00	2009-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	97004H	TITULAIRE	\N	\N
6548	2009CMP1	2009-01-21 00:00:00	2009-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	92031P	TITULAIRE	\N	2017-09-24 18:16:52
6559	2009CMP2	2009-01-26 00:00:00	2014-07-01 00:00:00	ANCIEN	\N	\N	\N	\N	83011J	TITULAIRE	\N	2014-07-01 09:25:11
6560	2009CMP2	2009-01-26 00:00:00	2012-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	TITULAIRE	\N	\N
6561	2009CMP2	2009-01-26 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	94003T	TITULAIRE	\N	2014-09-28 13:16:32
6562	2009CMP2	2009-01-26 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77043E	TITULAIRE	\N	2014-09-28 16:59:41
6563	2009CMP2	2009-01-26 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
6564	2009CMP2	2009-01-26 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	98032R	TITULAIRE	\N	2015-06-12 15:59:49
6565	2009CMP2	2009-01-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04050C	TITULAIRE	\N	\N
6566	2009CMP2	2009-01-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	SUPPLEANT	\N	2017-09-24 18:20:10
6567	2009CMP2	2009-01-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	97009N	SUPPLEANT	\N	\N
6568	2009CMP2	2009-01-26 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	07003H	SUPPLEANT	\N	2014-09-28 12:21:28
6629	OUTREMER	2009-03-05 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	08073C	\N	\N	\N
6630	OUTREMER	2009-03-05 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	01009N	\N	\N	\N
6631	OUTREMER	2009-03-05 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	04043D	\N	\N	\N
6632	OUTREMER	2009-03-05 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	\N	\N	\N
6633	OUTREMER	2009-03-05 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	01019Q	\N	\N	\N
6634	OUTREMER	2009-03-05 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	98035U	\N	\N	\N
6635	OUTREMER	2009-03-05 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	97005J	\N	\N	\N
6636	OUTREMER	2009-03-05 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	08071A	\N	\N	\N
6637	OUTREMER	2009-03-05 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	01010F	\N	\N	\N
6638	OUTREMER	2009-03-05 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	95011X	\N	\N	\N
6639	OUTREMER	2009-03-05 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	88008L	\N	\N	\N
6640	OUTREMER	2009-03-05 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	98006P	\N	\N	\N
6641	OUTREMER	2009-03-05 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	95049N	\N	\N	\N
6642	OUTREMER	2009-03-05 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	86044G	\N	\N	\N
6643	OUTREMER	2009-03-05 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	89017R	\N	\N	\N
6699	2009CMP6	2009-04-02 00:00:00	2009-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	92031P	TITULAIRE	\N	2017-09-24 18:16:52
6700	2009CMP6	2009-04-02 00:00:00	2009-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	01039U	TITULAIRE	\N	\N
6701	2009CMP6	2009-04-02 00:00:00	2009-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	98030P	TITULAIRE	\N	2014-09-28 13:19:48
6713	SURENDETTEME	2009-04-29 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	97009N	\N	\N	\N
6714	SURENDETTEME	2009-04-29 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	08025T	\N	\N	\N
6715	SURENDETTEME	2009-04-29 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	01008M	\N	\N	\N
6716	SURENDETTEME	2009-04-29 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	\N	\N	\N
6717	SURENDETTEME	2009-04-29 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	01001E	\N	\N	\N
6718	SURENDETTEME	2009-04-29 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	01049W	\N	\N	\N
6719	SURENDETTEME	2009-04-29 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	89022N	\N	\N	\N
6720	SURENDETTEME	2009-04-29 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	02003L	\N	\N	\N
6721	SURENDETTEME	2009-04-29 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	\N	\N	\N
6722	SURENDETTEME	2009-04-29 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	08013P	\N	\N	\N
6723	SURENDETTEME	2009-04-29 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	95021A	\N	\N	\N
6724	SURENDETTEME	2009-04-29 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	04081K	\N	\N	\N
6725	SURENDETTEME	2009-04-29 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	04051D	\N	\N	\N
6726	SURENDETTEME	2009-04-29 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	04071H	\N	\N	\N
6727	SURENDETTEME	2009-04-29 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	95030B	\N	\N	\N
6728	SURENDETTEME	2009-04-29 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	08064B	\N	\N	\N
6729	SURENDETTEME	2009-04-29 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	08066D	\N	\N	\N
6730	SURENDETTEME	2009-04-29 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	04037F	\N	\N	\N
6731	SURENDETTEME	2009-04-29 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	08035V	\N	\N	\N
6732	SURENDETTEME	2009-04-29 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	95035G	\N	\N	\N
6733	SURENDETTEME	2009-04-29 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	01033N	\N	\N	\N
6734	SURENDETTEME	2009-04-29 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	08027V	\N	\N	\N
6754	2009CMP7	2009-04-28 00:00:00	2009-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	01027Q	TITULAIRE	\N	2017-09-24 17:28:55
6755	2009CMP7	2009-04-28 00:00:00	2009-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	98053W	TITULAIRE	\N	2018-05-31 10:52:17
6758	2009CMP7	2009-04-28 00:00:00	2009-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	95003X	TITULAIRE	\N	\N
6508	2008CMP17	2008-11-13 00:00:00	2009-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	98053W	TITULAIRE	\N	2018-05-31 10:52:17
6509	2008CMP17	2008-11-13 00:00:00	2009-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	89017R	SUPPLEANT	\N	\N
6510	2008CMP17	2008-11-13 00:00:00	2009-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	SUPPLEANT	\N	2017-09-24 18:20:10
6512	2008CMP17	2008-11-13 00:00:00	2009-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	95007C	SUPPLEANT	\N	\N
6513	2008CMP17	2008-11-13 00:00:00	2009-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	89022N	SUPPLEANT	\N	2014-09-28 18:19:47
6514	2008CMP17	2008-11-13 00:00:00	2009-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	08011M	SUPPLEANT	\N	\N
6515	2008CMP17	2008-11-13 00:00:00	2009-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	86049M	SUPPLEANT	\N	2014-09-28 18:03:38
6735	SURENDETTEME	2009-04-29 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	04048J	\N	\N	\N
6736	SURENDETTEME	2009-04-29 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	04097T	\N	\N	\N
6759	2009CMP7	2009-04-28 00:00:00	2009-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	01010F	TITULAIRE	\N	\N
6738	SURENDETTEME	2009-04-29 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	01018P	\N	\N	\N
6739	SURENDETTEME	2009-04-29 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	08034U	\N	\N	\N
6740	SURENDETTEME	2009-04-29 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	\N	\N	\N
6741	SURENDETTEME	2009-04-29 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	08026U	\N	\N	\N
6743	SURENDETTEME	2009-04-29 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	08061X	\N	\N	\N
6744	SURENDETTEME	2009-04-29 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	\N	\N	\N
6745	SURENDETTEME	2009-04-29 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	95062K	\N	\N	\N
6746	SURENDETTEME	2009-04-29 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	\N	\N	\N
6747	SURENDETTEME	2009-04-29 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	97005J	\N	\N	\N
6748	SURENDETTEME	2009-04-29 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	08046Y	\N	\N	\N
6749	SURENDETTEME	2009-04-29 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	\N	\N	\N
6750	SURENDETTEME	2009-04-29 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	04050C	\N	\N	\N
6751	SURENDETTEME	2009-04-29 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	\N	\N	\N
6766	2009CMP7	2009-04-28 00:00:00	2009-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	01009N	SUPPLEANT	\N	\N
6772	2009CMP8	2009-06-10 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	95004Y	TITULAIRE	\N	\N
6773	2009CMP8	2009-06-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	04092N	TITULAIRE	\N	\N
6774	2009CMP8	2009-06-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98024R	TITULAIRE	\N	\N
7251	NEANT	2010-04-17 00:00:00	2010-04-26 00:00:00	ANCIEN	\N	\N	\N	\N	10005K	\N	\N	\N
6484	2008CMP15	2008-10-29 00:00:00	2008-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	04051D	SUPPLEANT	\N	2014-09-28 17:07:41
3875	PAUVRETE	2008-01-10 00:00:00	2008-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	04064J	\N	\N	\N
3476	ELECTRICITE	2007-01-10 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	95005A	\N	\N	\N
3483	ELECTRICITE	2007-01-10 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	01027Q	\N	\N	\N
3494	ELECTRICITE	2007-01-10 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	04088S	\N	\N	\N
3456	FORMATION	2007-01-10 00:00:00	2007-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	01045S	\N	\N	\N
3464	FORMATION	2007-01-10 00:00:00	2007-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	97004H	\N	\N	\N
3475	FORMATION	2007-01-10 00:00:00	2007-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	06004E	\N	\N	\N
3288	DECISION ECO	2006-06-13 00:00:00	2007-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	\N	\N	\N
3296	DECISION ECO	2006-06-13 00:00:00	2007-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	95036H	\N	\N	\N
3305	DECISION ECO	2006-06-13 00:00:00	2007-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	98037W	\N	\N	\N
6832	2009CMP9	2009-07-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83050R	TITULAIRE	\N	\N
6833	2009CMP9	2009-07-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83031N	TITULAIRE	\N	\N
6834	2009CMP9	2009-07-01 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	95020Y	TITULAIRE	\N	2015-06-12 16:01:25
6835	2009CMP9	2009-07-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01021J	TITULAIRE	\N	\N
6836	2009CMP9	2009-07-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92015P	TITULAIRE	\N	2017-09-24 13:14:55
4135	NEANT	2008-10-01 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	08020N	\N	\N	2017-10-04 18:40:04
4136	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08021P	\N	\N	\N
4139	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08023R	\N	\N	\N
4154	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08027V	\N	\N	\N
4182	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08032S	\N	\N	\N
4184	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08034U	\N	\N	\N
4187	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08037X	\N	\N	\N
4197	NEANT	2008-10-01 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	08045X	\N	\N	2017-10-04 19:10:31
4199	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08047A	\N	\N	\N
4201	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08049C	\N	\N	\N
4209	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08054Y	\N	\N	\N
4217	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08057C	\N	\N	\N
4225	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08065C	\N	\N	\N
4227	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08067E	\N	\N	\N
3357	20061030N49	2006-10-30 00:00:00	2006-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	95030B	TITULAIRE	\N	2014-09-28 18:58:21
3358	20061030N49	2006-10-30 00:00:00	2006-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	98050T	TITULAIRE	\N	\N
3366	20061030N49	2006-10-30 00:00:00	2006-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	01035Q	SUPPLEANT	\N	\N
3368	20061030N49	2006-10-30 00:00:00	2006-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	04060E	SUPPLEANT	\N	\N
3373	20061115N50	2006-11-23 00:00:00	2006-11-28 00:00:00	ANCIEN	\N	\N	\N	\N	04081K	TITULAIRE	\N	2017-09-24 19:25:10
3374	20061115N50	2006-11-23 00:00:00	2006-11-28 00:00:00	ANCIEN	\N	\N	\N	\N	04055H	TITULAIRE	\N	2017-09-24 18:05:41
3375	20061115N50	2006-11-23 00:00:00	2006-11-28 00:00:00	ANCIEN	\N	\N	\N	\N	87003B	TITULAIRE	\N	2014-09-28 17:35:38
3510	SOCI	2007-02-07 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	07003H	\N	\N	\N
3692	NEANT	2007-09-19 00:00:00	2007-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	97005J	\N	\N	\N
3825	2007CMP15	2007-12-11 00:00:00	2007-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	98053W	TITULAIRE	\N	2018-05-31 10:52:17
3925	2008CMP3	2008-01-31 00:00:00	2008-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	01042P	TITULAIRE	\N	2015-04-21 17:14:30
4049	2008CMP8	2008-07-02 00:00:00	2008-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	07023M	SUPPLEANT	\N	\N
4050	2008CMP8	2008-07-02 00:00:00	2008-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	92042S	SUPPLEANT	\N	\N
4051	2008CMP8	2008-07-02 00:00:00	2008-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	04090L	TITULAIRE	\N	\N
3582	2007CMP5	2007-02-12 00:00:00	2007-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	SUPPLEANT	\N	\N
3583	2007CMP6	2007-02-15 00:00:00	2007-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-12 09:39:30
3584	2007CMP6	2007-02-15 00:00:00	2007-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	98039Y	TITULAIRE	\N	\N
3585	2007CMP6	2007-02-15 00:00:00	2007-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	04058L	TITULAIRE	\N	\N
3586	2007CMP6	2007-02-15 00:00:00	2007-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	01042P	TITULAIRE	\N	2015-04-21 17:14:30
3587	2007CMP6	2007-02-15 00:00:00	2007-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	01024M	TITULAIRE	\N	\N
3588	2007CMP6	2007-02-15 00:00:00	2007-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	01053S	TITULAIRE	\N	\N
3589	2007CMP6	2007-02-15 00:00:00	2007-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	01038T	TITULAIRE	\N	\N
3590	2007CMP6	2007-02-15 00:00:00	2007-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	01065W	SUPPLEANT	\N	2014-09-28 12:09:44
3591	2007CMP6	2007-02-15 00:00:00	2007-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	01001E	SUPPLEANT	\N	\N
3592	2007CMP6	2007-02-15 00:00:00	2007-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	01063U	SUPPLEANT	\N	2014-09-29 13:41:53
3593	2007CMP6	2007-02-15 00:00:00	2007-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	80017C	SUPPLEANT	\N	\N
3595	2007CMP6	2007-02-15 00:00:00	2007-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	01057W	SUPPLEANT	\N	\N
3596	2007CMP6	2007-02-15 00:00:00	2007-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	SUPPLEANT	\N	\N
3612	2007CMP8	2007-02-20 00:00:00	2007-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	89041R	TITULAIRE	\N	\N
3613	2007CMP8	2007-02-20 00:00:00	2007-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	95013A	TITULAIRE	\N	\N
3837	2007CMP16	2007-12-14 00:00:00	2007-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	02005N	TITULAIRE	\N	\N
3838	2007CMP16	2007-12-14 00:00:00	2007-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	95038K	TITULAIRE	\N	2014-09-28 17:40:23
3840	2007CMP16	2007-12-14 00:00:00	2007-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	98037W	TITULAIRE	\N	2014-09-28 14:31:42
3841	2007CMP16	2007-12-14 00:00:00	2007-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	TITULAIRE	\N	2017-09-24 17:09:24
3843	2007CMP16	2007-12-14 00:00:00	2007-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	SUPPLEANT	\N	2017-05-16 15:18:13
3844	2007CMP16	2007-12-14 00:00:00	2007-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	07023M	SUPPLEANT	\N	\N
3845	2007CMP16	2007-12-14 00:00:00	2007-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	04088S	SUPPLEANT	\N	\N
3846	2007CMP16	2007-12-14 00:00:00	2007-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	04033B	SUPPLEANT	\N	\N
3847	2007CMP16	2007-12-14 00:00:00	2007-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	97005J	SUPPLEANT	\N	\N
3848	2007CMP16	2007-12-14 00:00:00	2007-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	03002P	SUPPLEANT	\N	\N
3849	2007CMP17	2007-12-18 00:00:00	2007-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	83011J	TITULAIRE	\N	2014-07-01 09:25:11
3850	2007CMP17	2007-12-18 00:00:00	2007-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
3851	2007CMP17	2007-12-18 00:00:00	2007-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	94003T	TITULAIRE	\N	2014-09-28 13:16:32
3852	2007CMP17	2007-12-18 00:00:00	2007-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	89022N	TITULAIRE	\N	2014-09-28 18:19:47
3853	2007CMP17	2007-12-18 00:00:00	2007-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	77043E	TITULAIRE	\N	2014-09-28 16:59:41
3854	2007CMP17	2007-12-18 00:00:00	2007-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	TITULAIRE	\N	\N
3938	LOIS	1959-10-08 00:00:00	1961-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	000021	\N	\N	\N
3352	NEANT	2006-08-12 00:00:00	2006-09-06 00:00:00	ANCIEN	\N	\N	\N	\N	06005F	\N	\N	\N
3418	20061214N52	2006-12-12 00:00:00	2006-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	98047Y	SUPPLEANT	\N	\N
3419	20061214N52	2006-12-12 00:00:00	2006-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	92029V	SUPPLEANT	\N	\N
3438	20061219N54	2006-12-19 00:00:00	2006-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	98032R	TITULAIRE	\N	2015-06-12 15:59:49
3440	20061219N54	2006-12-19 00:00:00	2006-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	04050C	TITULAIRE	\N	\N
3441	20061219N54	2006-12-19 00:00:00	2006-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	89017R	SUPPLEANT	\N	\N
3442	20061219N54	2006-12-19 00:00:00	2006-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	81015E	SUPPLEANT	\N	\N
3443	20061219N54	2006-12-19 00:00:00	2006-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	78003A	SUPPLEANT	\N	\N
3444	20061219N54	2006-12-19 00:00:00	2006-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	04037F	SUPPLEANT	\N	\N
3555	2007CMP4	2007-02-07 00:00:00	2007-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-12 09:39:30
3556	2007CMP4	2007-02-07 00:00:00	2007-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	TITULAIRE	\N	2017-09-24 13:29:42
3560	2007CMP4	2007-02-07 00:00:00	2007-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	95006B	TITULAIRE	\N	\N
3605	2007CMP7	2007-02-14 00:00:00	2007-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	01001E	SUPPLEANT	\N	\N
3606	2007CMP7	2007-02-14 00:00:00	2007-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	01024M	SUPPLEANT	\N	\N
3608	2007CMP7	2007-02-14 00:00:00	2007-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	SUPPLEANT	\N	2014-09-28 18:00:58
3609	2007CMP7	2007-02-14 00:00:00	2007-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	04074L	SUPPLEANT	\N	2017-09-24 17:15:15
3610	2007CMP7	2007-02-14 00:00:00	2007-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	SUPPLEANT	\N	\N
3680	SERVICE	2007-07-05 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	\N	\N	\N
3681	SERVICE	2007-07-05 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	98044V	\N	\N	\N
3787	NEANT	2007-11-30 00:00:00	2007-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	07033P	\N	\N	2017-10-04 18:41:56
3939	NEANT	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08001K	\N	\N	\N
4113	2008CMP13	2008-07-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	06001B	TITULAIRE	\N	\N
4114	2008CMP13	2008-07-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	TITULAIRE	\N	2017-09-24 17:35:15
4115	2008CMP13	2008-07-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	95005A	SUPPLEANT	\N	2014-09-28 17:40:23
4116	2008CMP13	2008-07-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	02003L	SUPPLEANT	\N	\N
4117	2008CMP13	2008-07-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	04046G	SUPPLEANT	\N	2014-09-28 17:07:41
4118	2008CMP13	2008-07-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	SUPPLEANT	\N	2014-09-28 17:07:41
4124	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08010L	\N	\N	\N
4126	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08012N	\N	\N	\N
4131	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08016S	\N	\N	\N
4132	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08017T	\N	\N	\N
4134	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08019V	\N	\N	\N
4138	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08022Q	\N	\N	\N
4140	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08024S	\N	\N	\N
4144	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08026U	\N	\N	\N
4159	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08028W	\N	\N	\N
4180	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08031R	\N	\N	\N
4183	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08033T	\N	\N	\N
4185	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08035V	\N	\N	\N
4186	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08036W	\N	\N	\N
4188	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08038Y	\N	\N	\N
4189	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08039A	\N	\N	\N
4190	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08040S	\N	\N	\N
4196	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08044W	\N	\N	\N
4198	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08046Y	\N	\N	\N
4200	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08048B	\N	\N	\N
4204	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08050U	\N	\N	\N
4206	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	\N	\N	\N
4208	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08053X	\N	\N	\N
4210	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08055A	\N	\N	\N
2605	FINC	2004-10-06 00:00:00	2009-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	86044G	\N	\N	\N
6866	FINC	2009-07-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01006K	\N	\N	\N
382	ECON	1998-10-06 00:00:00	2009-09-09 00:00:00	ANCIEN	\N	\N	\N	\N	80024B	\N	\N	\N
6903	2009CMP13	2009-09-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92031P	TITULAIRE	\N	2017-09-24 18:16:52
6904	2009CMP13	2009-09-15 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	\N	01039U	TITULAIRE	\N	\N
6905	2009CMP13	2009-09-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	01025N	TITULAIRE	\N	\N
6906	2009CMP13	2009-09-15 00:00:00	2022-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	92040Q	TITULAIRE	\N	\N
6907	2009CMP13	2009-09-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	97004H	TITULAIRE	\N	\N
6908	2009CMP13	2009-09-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	04059M	TITULAIRE	\N	\N
6909	2009CMP13	2009-09-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	85002R	TITULAIRE	\N	\N
6910	2009CMP13	2009-09-15 00:00:00	2017-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	01044R	SUPPLEANT	\N	2017-07-04 15:08:09
6911	2009CMP13	2009-09-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04052E	SUPPLEANT	\N	\N
6912	2009CMP13	2009-09-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04073K	SUPPLEANT	\N	2014-09-28 18:58:25
6913	2009CMP13	2009-09-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	87003B	SUPPLEANT	\N	2014-09-28 17:35:38
6914	2009CMP13	2009-09-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01041N	SUPPLEANT	\N	2017-09-24 18:59:59
6915	2009CMP13	2009-09-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	04057K	SUPPLEANT	\N	\N
6916	2009CMP13	2009-09-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98010K	SUPPLEANT	\N	2014-09-28 17:27:35
6917	2009CMP14	2009-09-29 00:00:00	2015-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-12 09:39:30
6583	2009CMP3	2009-02-27 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95038K	SUPPLEANT	\N	2014-09-28 17:40:23
6584	2009CMP3	2009-02-27 00:00:00	2016-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	04048J	SUPPLEANT	\N	2016-12-01 10:36:51
6585	2009CMP3	2009-02-27 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95062K	SUPPLEANT	\N	\N
6586	2009CMP3	2009-02-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	97005J	SUPPLEANT	\N	\N
6784	2009CMP8	2009-06-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01011G	SUPPLEANT	\N	2017-09-24 16:43:43
6592	2009CMP4	2009-02-11 00:00:00	2009-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	04089T	TITULAIRE	\N	\N
6593	2009CMP4	2009-02-11 00:00:00	2009-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	TITULAIRE	\N	2017-09-24 17:09:24
6594	2009CMP4	2009-02-11 00:00:00	2009-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	04090L	TITULAIRE	\N	\N
6595	2009CMP4	2009-02-11 00:00:00	2009-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	98023Q	SUPPLEANT	\N	\N
4218	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08058D	\N	\N	\N
4220	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08060W	\N	\N	\N
4221	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08061X	\N	\N	\N
4222	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08062Y	\N	\N	\N
4224	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08064B	\N	\N	\N
4226	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08066D	\N	\N	\N
4228	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08068F	\N	\N	\N
4229	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08069G	\N	\N	\N
4231	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08071A	\N	\N	\N
4233	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08073C	\N	\N	\N
3371	NEANT	1965-03-03 00:00:00	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	58332E	\N	\N	\N
3507	ECON	2007-01-23 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	89043T	\N	\N	\N
3508	SOCI	2007-01-23 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	04090L	\N	\N	\N
3511	2007CMP1	2007-01-25 00:00:00	2007-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-12 09:39:30
3512	2007CMP1	2007-01-25 00:00:00	2007-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	01063U	TITULAIRE	\N	2014-09-29 13:41:53
3513	2007CMP1	2007-01-25 00:00:00	2007-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	TITULAIRE	\N	2014-09-28 18:00:58
3628	LOIS	2007-06-26 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	07024N	\N	\N	\N
3791	DEPENDANCE	2007-12-05 00:00:00	2011-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	95005A	\N	\N	\N
3792	DEPENDANCE	2007-12-05 00:00:00	2011-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	83012K	\N	\N	\N
3793	DEPENDANCE	2007-12-05 00:00:00	2011-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	92011K	\N	\N	\N
3794	DEPENDANCE	2007-12-05 00:00:00	2011-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	00003C	\N	\N	\N
3795	DEPENDANCE	2007-12-05 00:00:00	2011-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	83021L	\N	\N	\N
3796	DEPENDANCE	2007-12-05 00:00:00	2011-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	98029W	\N	\N	\N
3797	DEPENDANCE	2007-12-05 00:00:00	2011-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	90004C	\N	\N	\N
3798	DEPENDANCE	2007-12-05 00:00:00	2011-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	04051D	\N	\N	\N
3799	DEPENDANCE	2007-12-05 00:00:00	2011-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	01027Q	\N	\N	\N
3800	DEPENDANCE	2007-12-05 00:00:00	2011-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	04058L	\N	\N	\N
3801	DEPENDANCE	2007-12-05 00:00:00	2011-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	\N	\N	\N
3802	DEPENDANCE	2007-12-05 00:00:00	2011-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	01011G	\N	\N	\N
3803	DEPENDANCE	2007-12-05 00:00:00	2011-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	01057W	\N	\N	\N
3804	DEPENDANCE	2007-12-05 00:00:00	2011-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	95037J	\N	\N	\N
3805	DEPENDANCE	2007-12-05 00:00:00	2011-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	04075M	\N	\N	\N
3806	DEPENDANCE	2007-12-05 00:00:00	2011-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	01018P	\N	\N	\N
3807	DEPENDANCE	2007-12-05 00:00:00	2011-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	92030N	\N	\N	\N
3808	DEPENDANCE	2007-12-05 00:00:00	2011-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	\N	\N	\N
3809	DEPENDANCE	2007-12-05 00:00:00	2009-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	95049N	\N	\N	\N
3810	DEPENDANCE	2007-12-05 00:00:00	2011-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	\N	\N	\N
3811	DEPENDANCE	2007-12-05 00:00:00	2011-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	92039X	\N	\N	\N
3812	DEPENDANCE	2007-12-05 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	73006G	\N	\N	\N
3813	DEPENDANCE	2007-12-05 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80031A	\N	\N	\N
4317	FINC	2008-10-07 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	98027U	\N	\N	2015-06-12 16:01:58
4318	FINC	2008-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08011M	\N	\N	2017-10-04 00:00:00
4319	LOIS	2008-10-07 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	08007R	\N	\N	\N
4320	LOIS	2008-10-07 00:00:00	2010-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	08022Q	\N	\N	\N
4321	LOIS	2008-10-07 00:00:00	2013-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	08023R	\N	\N	2013-12-17 17:10:27
4322	LOIS	2008-10-07 00:00:00	2009-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	08018U	\N	\N	2017-10-04 19:45:53
4323	LOIS	2008-10-07 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	08010L	\N	\N	2014-10-08 17:44:19
4324	LOIS	2008-10-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08034U	\N	\N	\N
4325	SOCI	2008-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08048B	\N	\N	2017-10-04 20:02:43
4326	SOCI	2008-10-07 00:00:00	2020-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	08041T	\N	\N	2017-10-04 20:02:55
4327	SOCI	2008-10-07 00:00:00	2010-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	08056B	\N	\N	\N
4328	SOCI	2008-10-07 00:00:00	2010-03-22 00:00:00	ANCIEN	\N	\N	\N	\N	08062Y	\N	\N	\N
4329	SOCI	2008-10-07 00:00:00	2010-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	08036W	\N	\N	\N
4330	AFCL	2008-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08020N	\N	\N	2017-10-04 19:41:07
4331	AFCL	2008-10-07 00:00:00	2010-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	01026P	\N	\N	\N
4332	AFCL	2008-10-07 00:00:00	2010-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	08044W	\N	\N	\N
4333	AFCL	2008-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08039A	\N	\N	2017-10-04 19:44:31
4334	ECON	2008-10-07 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	08028W	\N	\N	\N
4335	ECON	2008-10-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04093P	\N	\N	\N
4336	ECON	2008-10-07 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	08069G	\N	\N	\N
4337	ECON	2008-10-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04041B	\N	\N	\N
4338	ECON	2008-10-07 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	08015R	\N	\N	\N
4339	ECON	2008-10-07 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	08019V	\N	\N	\N
4340	ECON	2008-10-07 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	08042U	\N	\N	\N
4341	ECON	2008-10-07 00:00:00	2010-03-22 00:00:00	ANCIEN	\N	\N	\N	\N	08047A	\N	\N	\N
4342	ECON	2008-10-07 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	04069P	\N	\N	\N
4343	FINC	2008-10-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	07003H	\N	\N	\N
6463	2008CMP14	2008-10-29 00:00:00	2008-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	01033N	TITULAIRE	\N	\N
6464	2008CMP14	2008-10-29 00:00:00	2008-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	06001B	TITULAIRE	\N	\N
6465	2008CMP14	2008-10-29 00:00:00	2008-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	04076N	TITULAIRE	\N	\N
6467	2008CMP14	2008-10-29 00:00:00	2008-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	SUPPLEANT	\N	2017-09-24 13:44:49
6579	2009CMP3	2009-02-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08014Q	TITULAIRE	\N	\N
6580	2009CMP3	2009-02-27 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95021A	SUPPLEANT	\N	2014-09-28 16:40:50
6581	2009CMP3	2009-02-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	04071H	SUPPLEANT	\N	\N
6582	2009CMP3	2009-02-27 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	SUPPLEANT	\N	2017-05-16 15:18:13
6644	JEUNES	2009-03-11 00:00:00	2009-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	95024D	\N	\N	\N
6645	JEUNES	2009-03-11 00:00:00	2009-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	07028S	\N	\N	\N
6646	JEUNES	2009-03-11 00:00:00	2009-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	01026P	\N	\N	\N
6647	JEUNES	2009-03-11 00:00:00	2009-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	08044W	\N	\N	\N
6648	JEUNES	2009-03-11 00:00:00	2009-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	92031P	\N	\N	\N
6649	JEUNES	2009-03-11 00:00:00	2009-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	95047L	\N	\N	\N
6650	JEUNES	2009-03-11 00:00:00	2009-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	01039U	\N	\N	\N
6651	JEUNES	2009-03-11 00:00:00	2009-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	04088S	\N	\N	\N
6652	JEUNES	2009-03-11 00:00:00	2009-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	08065C	\N	\N	\N
6653	JEUNES	2009-03-11 00:00:00	2009-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	04058L	\N	\N	\N
6654	JEUNES	2009-03-11 00:00:00	2009-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	04075M	\N	\N	\N
6655	JEUNES	2009-03-11 00:00:00	2009-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	\N	\N	\N
6656	JEUNES	2009-03-11 00:00:00	2009-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	01029S	\N	\N	\N
6657	JEUNES	2009-03-11 00:00:00	2009-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	\N	\N	\N
6658	JEUNES	2009-03-11 00:00:00	2009-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	08010L	\N	\N	\N
6659	JEUNES	2009-03-11 00:00:00	2009-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	\N	\N	\N
6849	2009CMP10	2009-07-07 00:00:00	2017-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	01007L	TITULAIRE	\N	2017-07-24 09:56:26
6661	JEUNES	2009-03-11 00:00:00	2009-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	08043V	\N	\N	\N
7390	2010CMP11	2010-09-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	TITULAIRE	\N	2017-09-24 17:35:15
7391	2010CMP11	2010-09-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	SUPPLEANT	\N	2017-09-24 13:44:49
3445	20061219N54	2006-12-19 00:00:00	2006-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	92029V	SUPPLEANT	\N	\N
7432	LOIS	2010-10-28 00:00:00	2020-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	08044W	\N	\N	2017-10-04 19:46:53
7685	2011CMP1	2011-01-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	08018U	SUPPLEANT	\N	\N
7686	2011CMP1	2011-01-19 00:00:00	2017-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	01007L	SUPPLEANT	\N	2017-07-24 09:56:26
7687	2011CMP1	2011-01-19 00:00:00	2015-04-21 00:00:00	ANCIEN	\N	\N	\N	\N	01042P	SUPPLEANT	\N	2015-04-21 17:14:30
7688	2011CMP1	2011-01-19 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	SUPPLEANT	\N	2017-06-19 12:20:59
7689	2011CMP1	2011-01-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95055L	SUPPLEANT	\N	2014-09-28 13:21:47
7690	2011CMP1	2011-01-19 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	\N	\N
7720	MEDIATOR	2011-02-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01044R	\N	\N	\N
7343	2010CMP8	2010-06-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01001E	SUPPLEANT	\N	\N
7435	2010CMP13	2010-10-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	TITULAIRE	\N	\N
7436	2010CMP13	2010-10-19 00:00:00	2020-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	08041T	TITULAIRE	\N	\N
7437	2010CMP13	2010-10-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04075M	TITULAIRE	\N	\N
7438	2010CMP13	2010-10-19 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98029W	TITULAIRE	\N	\N
7439	2010CMP13	2010-10-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08037X	TITULAIRE	\N	2014-09-28 17:34:16
7440	2010CMP13	2010-10-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	TITULAIRE	\N	2014-09-28 17:07:41
7441	2010CMP13	2010-10-19 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	SUPPLEANT	\N	\N
7442	2010CMP13	2010-10-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	SUPPLEANT	\N	2017-09-24 17:35:15
7443	2010CMP13	2010-10-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04046G	SUPPLEANT	\N	2014-09-28 17:07:41
7444	2010CMP13	2010-10-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01033N	SUPPLEANT	\N	\N
7448	2010CMP14	2010-10-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04051D	TITULAIRE	\N	2014-09-28 17:07:41
7449	2010CMP14	2010-10-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92030N	TITULAIRE	\N	\N
7450	2010CMP14	2010-10-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	TITULAIRE	\N	\N
7451	2010CMP14	2010-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04081K	TITULAIRE	\N	2017-09-24 19:25:10
7452	2010CMP14	2010-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01011G	TITULAIRE	\N	2017-09-24 16:43:43
7453	2010CMP14	2010-10-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	TITULAIRE	\N	2014-09-28 17:07:41
7454	2010CMP14	2010-10-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04046G	TITULAIRE	\N	2014-09-28 17:07:41
7455	2010CMP14	2010-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	SUPPLEANT	\N	2017-09-24 17:35:15
7456	2010CMP14	2010-10-22 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98024R	SUPPLEANT	\N	\N
7457	2010CMP14	2010-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	95035G	SUPPLEANT	\N	2017-09-24 18:17:56
7458	2010CMP14	2010-10-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04037F	SUPPLEANT	\N	\N
7459	2010CMP14	2010-10-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08037X	SUPPLEANT	\N	2014-09-28 17:34:16
7460	2010CMP14	2010-10-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	04092N	SUPPLEANT	\N	\N
7461	2010CMP14	2010-10-22 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	SUPPLEANT	\N	\N
7466	SYSTEMESCO  	2010-11-17 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	04091M	\N	\N	\N
7467	SYSTEMESCO  	2010-11-17 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	08055A	\N	\N	\N
7308	2010CMP6	2010-06-02 00:00:00	2015-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-12 09:39:30
7309	2010CMP6	2010-06-02 00:00:00	2015-04-21 00:00:00	ANCIEN	\N	\N	\N	\N	01042P	TITULAIRE	\N	2015-04-21 17:14:30
7310	2010CMP6	2010-06-02 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	TITULAIRE	\N	2014-09-28 18:00:58
7311	2010CMP6	2010-06-02 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04084N	TITULAIRE	\N	2014-09-28 13:40:33
7312	2010CMP6	2010-06-02 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08032S	TITULAIRE	\N	2014-09-28 17:34:16
7313	2010CMP6	2010-06-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	TITULAIRE	\N	\N
7314	2010CMP6	2010-06-02 00:00:00	2012-09-19 00:00:00	ANCIEN	\N	\N	\N	\N	95011X	TITULAIRE	\N	\N
7315	2010CMP6	2010-06-02 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	SUPPLEANT	\N	2017-06-19 12:20:59
7316	2010CMP6	2010-06-02 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95055L	SUPPLEANT	\N	2014-09-28 13:21:47
7317	2010CMP6	2010-06-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04074L	SUPPLEANT	\N	2017-09-24 17:15:15
7318	2010CMP6	2010-06-02 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	\N	\N
7319	2010CMP6	2010-06-02 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	SUPPLEANT	\N	\N
7320	2010CMP6	2010-06-02 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	SUPPLEANT	\N	\N
7321	2010CMP6	2010-06-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	SUPPLEANT	\N	2017-09-24 13:29:42
7392	2010CMP11	2010-09-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	SUPPLEANT	\N	2014-09-28 17:07:41
7393	2010CMP11	2010-09-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08067E	SUPPLEANT	\N	2014-09-28 17:22:11
7394	2010CMP11	2010-09-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04036E	SUPPLEANT	\N	2017-09-24 18:59:59
7395	2010CMP11	2010-09-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10003H	SUPPLEANT	\N	2014-09-28 17:38:26
7396	2010CMP11	2010-09-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	07029T	SUPPLEANT	\N	\N
7397	2010CMP11	2010-09-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01029S	SUPPLEANT	\N	\N
7468	SYSTEMESCO  	2010-11-17 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	08043V	\N	\N	\N
7469	SYSTEMESCO  	2010-11-17 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	04052E	\N	\N	\N
7470	SYSTEMESCO  	2010-11-17 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	04073K	\N	\N	\N
7471	SYSTEMESCO  	2010-11-17 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	08020N	\N	\N	\N
7472	SYSTEMESCO  	2010-11-17 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	95015C	\N	\N	\N
7473	SYSTEMESCO  	2010-11-17 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	08024S	\N	\N	\N
7474	SYSTEMESCO  	2010-11-17 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	95021A	\N	\N	\N
2743	20041022N19	2004-10-20 00:00:00	2010-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	01017N	TITULAIRE	\N	\N
3214	20060119N41	2006-01-23 00:00:00	2010-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	01017N	TITULAIRE	\N	\N
3684	FINC	2007-07-18 00:00:00	2010-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	01017N	\N	\N	\N
7408	2010CMP12	2010-10-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	\N	\N
7403	2010CMP12	2010-10-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	TITULAIRE	\N	\N
7404	2010CMP12	2010-10-06 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95055L	TITULAIRE	\N	2014-09-28 13:21:47
7405	2010CMP12	2010-10-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
7406	2010CMP12	2010-10-06 00:00:00	2012-09-19 00:00:00	ANCIEN	\N	\N	\N	\N	95011X	TITULAIRE	\N	\N
7407	2010CMP12	2010-10-06 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	99002P	SUPPLEANT	\N	2017-06-19 12:20:22
7409	2010CMP12	2010-10-06 00:00:00	2017-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	01007L	SUPPLEANT	\N	2017-07-24 09:56:26
7410	2010CMP12	2010-10-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	01057W	SUPPLEANT	\N	\N
7475	SYSTEMESCO  	2010-11-17 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	95024D	\N	\N	\N
7476	SYSTEMESCO  	2010-11-17 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	04089T	\N	\N	\N
7477	SYSTEMESCO  	2010-11-17 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	87003B	\N	\N	\N
7478	SYSTEMESCO  	2010-11-17 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	01025N	\N	\N	\N
7479	SYSTEMESCO  	2010-11-17 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	08045X	\N	\N	\N
7480	SYSTEMESCO  	2010-11-17 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	07026Q	\N	\N	\N
7481	SYSTEMESCO  	2010-11-17 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	98028V	\N	\N	\N
7482	SYSTEMESCO  	2010-11-17 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	08044W	\N	\N	\N
7483	SYSTEMESCO  	2010-11-17 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	10003H	\N	\N	\N
7484	SYSTEMESCO  	2010-11-17 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	04061F	\N	\N	\N
7485	SYSTEMESCO  	2010-11-17 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	08031R	\N	\N	\N
7486	SYSTEMESCO  	2010-11-17 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	97004H	\N	\N	\N
7487	SYSTEMESCO  	2010-11-17 00:00:00	2011-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	04076N	\N	\N	\N
7488	SYSTEMESCO  	2010-11-17 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	04057K	\N	\N	\N
7295	2010CMP5	2010-05-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77019E	TITULAIRE	\N	\N
7297	2010CMP5	2010-05-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04080J	TITULAIRE	\N	2017-09-24 17:47:27
7336	2010CMP8	2010-06-02 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	TITULAIRE	\N	\N
7337	2010CMP8	2010-06-02 00:00:00	2015-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-12 09:39:30
7338	2010CMP8	2010-06-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01045S	TITULAIRE	\N	\N
7339	2010CMP8	2010-06-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95046K	TITULAIRE	\N	\N
7340	2010CMP8	2010-06-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
7341	2010CMP8	2010-06-02 00:00:00	2017-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	01007L	TITULAIRE	\N	2017-07-24 09:56:26
7465	AFCL	2010-11-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10007M	\N	\N	\N
7489	SYSTEMESCO  	2010-11-17 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	04043D	\N	\N	\N
7490	SYSTEMESCO  	2010-11-17 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	04039H	\N	\N	\N
2841	20050319N22	2005-03-19 00:00:00	2010-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	92005M	SUPPLEANT	\N	\N
2821	AFCL	2005-03-01 00:00:00	2010-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	92005M	\N	\N	\N
7510	AFCL	2010-12-15 00:00:00	2011-03-28 00:00:00	ANCIEN	\N	\N	\N	\N	10015M	\N	\N	\N
7620	2010CMP20	2010-12-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95030B	TITULAIRE	\N	2014-09-28 18:58:21
7621	2010CMP20	2010-12-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	01058X	TITULAIRE	\N	\N
7622	2010CMP20	2010-12-17 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95038K	TITULAIRE	\N	2014-09-28 17:40:23
7623	2010CMP20	2010-12-17 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95025E	TITULAIRE	\N	2014-09-28 17:09:16
7624	2010CMP20	2010-12-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	TITULAIRE	\N	2017-09-24 17:09:24
7625	2010CMP20	2010-12-17 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04065K	TITULAIRE	\N	2014-09-28 17:31:42
7626	2010CMP20	2010-12-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01015L	TITULAIRE	\N	2017-09-24 17:19:42
7627	2010CMP20	2010-12-17 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95062K	SUPPLEANT	\N	\N
7628	2010CMP20	2010-12-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04088S	SUPPLEANT	\N	\N
7629	2010CMP20	2010-12-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	08015R	SUPPLEANT	\N	\N
7630	2010CMP20	2010-12-17 00:00:00	2018-12-30 00:00:00	ANCIEN	\N	\N	\N	\N	98023Q	SUPPLEANT	\N	\N
7632	2010CMP20	2010-12-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04077P	SUPPLEANT	\N	2017-09-24 17:47:27
7633	2010CMP20	2010-12-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80013X	SUPPLEANT	\N	\N
7463	NEANT	2010-11-03 00:00:00	2010-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	10007M	\N	\N	\N
7542	2010CMP18	2010-12-16 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
7543	2010CMP18	2010-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77019E	TITULAIRE	\N	\N
7544	2010CMP18	2010-12-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01027Q	TITULAIRE	\N	2017-09-24 17:28:55
7545	2010CMP18	2010-12-16 00:00:00	2012-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	TITULAIRE	\N	\N
7555	2010CMP19	2010-12-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95030B	TITULAIRE	\N	2014-09-28 18:58:21
7556	2010CMP19	2010-12-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	01058X	TITULAIRE	\N	\N
7557	2010CMP19	2010-12-17 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95038K	TITULAIRE	\N	2014-09-28 17:40:23
7558	2010CMP19	2010-12-17 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95025E	TITULAIRE	\N	2014-09-28 17:09:16
7559	2010CMP19	2010-12-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	TITULAIRE	\N	2017-09-24 17:09:24
7560	2010CMP19	2010-12-17 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04065K	TITULAIRE	\N	2014-09-28 17:31:42
7561	2010CMP19	2010-12-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01015L	TITULAIRE	\N	2017-09-24 17:19:42
7562	2010CMP19	2010-12-17 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95062K	SUPPLEANT	\N	\N
7563	2010CMP19	2010-12-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04088S	SUPPLEANT	\N	\N
7564	2010CMP19	2010-12-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	08015R	SUPPLEANT	\N	\N
7565	2010CMP19	2010-12-17 00:00:00	2018-12-30 00:00:00	ANCIEN	\N	\N	\N	\N	98023Q	SUPPLEANT	\N	\N
7566	2010CMP19	2010-12-17 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	06004E	SUPPLEANT	\N	2014-09-28 17:03:42
7567	2010CMP19	2010-12-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04077P	SUPPLEANT	\N	2017-09-24 17:47:27
7568	2010CMP19	2010-12-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80013X	SUPPLEANT	\N	\N
7706	2011CMP3	2011-02-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04051D	TITULAIRE	\N	2014-09-28 17:07:41
7704	2011CMP2	2011-01-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	04045F	SUPPLEANT	\N	\N
7707	2011CMP3	2011-02-10 00:00:00	2020-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	08041T	TITULAIRE	\N	\N
7708	2011CMP3	2011-02-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	04033B	TITULAIRE	\N	\N
7709	2011CMP3	2011-02-10 00:00:00	2013-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	95045J	TITULAIRE	\N	\N
7710	2011CMP3	2011-02-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	TITULAIRE	\N	\N
7711	2011CMP3	2011-02-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98037W	TITULAIRE	\N	2014-09-28 14:31:42
7712	2011CMP3	2011-02-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	TITULAIRE	\N	2014-09-28 17:07:41
7399	SOCI	2010-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	10006L	\N	\N	2017-10-04 00:00:00
7413	ECON	2010-10-15 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	08036W	\N	\N	\N
7415	FINC	2010-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04071H	\N	\N	2017-10-04 00:00:00
7417	TOXICOMANIE	2010-10-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01006K	\N	\N	\N
7418	TOXICOMANIE	2010-10-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	\N	\N	\N
7419	TOXICOMANIE	2010-10-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08060W	\N	\N	\N
7420	TOXICOMANIE	2010-10-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	02003L	\N	\N	\N
7421	TOXICOMANIE	2010-10-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04046G	\N	\N	\N
7422	TOXICOMANIE	2010-10-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08035V	\N	\N	\N
7423	TOXICOMANIE	2010-10-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08048B	\N	\N	\N
7424	TOXICOMANIE	2010-10-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04075M	\N	\N	\N
7425	TOXICOMANIE	2010-10-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04041B	\N	\N	\N
7426	TOXICOMANIE	2010-10-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08032S	\N	\N	\N
7427	TOXICOMANIE	2010-10-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08037X	\N	\N	\N
7428	TOXICOMANIE	2010-10-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	\N	\N	\N
7429	TOXICOMANIE	2010-10-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08026U	\N	\N	\N
7430	TOXICOMANIE	2010-10-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	07034Q	\N	\N	\N
7431	TOXICOMANIE	2010-10-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04080J	\N	\N	\N
7503	2010CMP15	2010-11-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04076N	SUPPLEANT	\N	\N
7504	2010CMP15	2010-11-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	04092N	SUPPLEANT	\N	\N
771	SOCI	2001-10-03 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	95004Y	\N	\N	\N
2310	20040609N8	2004-06-09 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	95004Y	TITULAIRE	\N	\N
2386	20040709N10	2004-07-09 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	95004Y	TITULAIRE	\N	\N
2414	20040727N12	2004-07-27 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	95004Y	TITULAIRE	\N	\N
3372	20061115N50	2006-11-23 00:00:00	2006-11-28 00:00:00	ANCIEN	\N	\N	\N	\N	95004Y	TITULAIRE	\N	\N
7433	FINC	2010-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08022Q	\N	\N	2017-10-01 09:41:22
7519	2010CMP16	2010-12-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	04071H	SUPPLEANT	\N	\N
7523	2010CMP16	2010-12-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	90004C	SUPPLEANT	\N	2014-09-28 13:21:47
7524	2010CMP16	2010-12-07 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	SUPPLEANT	\N	2017-05-16 15:18:13
7525	2010CMP17	2010-12-08 00:00:00	2014-07-01 00:00:00	ANCIEN	\N	\N	\N	\N	83011J	TITULAIRE	\N	2014-07-01 09:25:11
3611	2007CMP8	2007-02-20 00:00:00	2007-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	95004Y	TITULAIRE	\N	\N
7638	NEANT	2011-01-23 00:00:00	2011-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	11001K	\N	\N	\N
3520	2007CMP1	2007-01-25 00:00:00	2007-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	92022N	SUPPLEANT	\N	\N
3577	2007CMP5	2007-02-12 00:00:00	2007-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	92022N	SUPPLEANT	\N	\N
3594	2007CMP6	2007-02-15 00:00:00	2007-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	92022N	SUPPLEANT	\N	\N
7645	SYSTEMESCO  	2011-01-25 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	08050U	\N	\N	\N
7713	2011CMP3	2011-02-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83012K	SUPPLEANT	\N	\N
7714	2011CMP3	2011-02-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	02003L	SUPPLEANT	\N	\N
7715	2011CMP3	2011-02-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01033N	SUPPLEANT	\N	\N
7716	2011CMP3	2011-02-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	06001B	SUPPLEANT	\N	\N
7717	2011CMP3	2011-02-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10003H	SUPPLEANT	\N	2014-09-28 17:38:26
7718	2011CMP3	2011-02-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	07029T	SUPPLEANT	\N	\N
7719	2011CMP3	2011-02-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	04070G	SUPPLEANT	\N	\N
7749	AFCL	2011-03-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11003M	\N	\N	\N
7293	2010CMP4	2010-04-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	SUPPLEANT	\N	\N
7493	2010CMP15	2010-11-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98024R	TITULAIRE	\N	\N
7514	2010CMP16	2010-12-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01027Q	TITULAIRE	\N	2017-09-24 17:28:55
7517	2010CMP16	2010-12-07 00:00:00	2018-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	98053W	TITULAIRE	\N	2018-05-31 10:52:17
7518	2010CMP16	2010-12-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77019E	SUPPLEANT	\N	\N
7529	2010CMP17	2010-12-08 00:00:00	2012-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	TITULAIRE	\N	\N
7530	2010CMP17	2010-12-08 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	98046X	TITULAIRE	\N	2017-09-25 09:56:00
7751	LOIS	2011-03-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	10015M	\N	\N	2017-10-04 00:00:00
7237	2010CMP3	2010-03-31 00:00:00	2015-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-12 09:39:30
7238	2010CMP3	2010-03-31 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	TITULAIRE	\N	2014-09-28 18:00:58
7239	2010CMP3	2010-03-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04074L	TITULAIRE	\N	2017-09-24 17:15:15
7240	2010CMP3	2010-03-31 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	92022N	TITULAIRE	\N	\N
7241	2010CMP3	2010-03-31 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	02001J	TITULAIRE	\N	\N
7242	2010CMP3	2010-03-31 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95055L	TITULAIRE	\N	2014-09-28 13:21:47
7243	2010CMP3	2010-03-31 00:00:00	2012-09-19 00:00:00	ANCIEN	\N	\N	\N	\N	95011X	TITULAIRE	\N	\N
7245	2010CMP3	2010-03-31 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08022Q	SUPPLEANT	\N	2017-10-01 09:41:22
7246	2010CMP3	2010-03-31 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	SUPPLEANT	\N	\N
7247	2010CMP3	2010-03-31 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	SUPPLEANT	\N	2017-06-19 12:20:59
7248	2010CMP3	2010-03-31 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04084N	SUPPLEANT	\N	2014-09-28 13:40:33
7249	2010CMP3	2010-03-31 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	07034Q	SUPPLEANT	\N	\N
7250	2010CMP3	2010-03-31 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	\N	\N
2939	20050707N29	2005-07-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	SUPPLEANT	\N	2014-09-28 17:07:41
7520	2010CMP16	2010-12-07 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	SUPPLEANT	\N	\N
7637	ECON	2011-01-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04040A	\N	\N	\N
7639	SOCI	2011-01-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11001K	\N	\N	\N
7721	2011CMP4	2011-02-10 00:00:00	2015-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-12 09:39:30
7729	2011CMP4	2011-02-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	SUPPLEANT	\N	\N
6446	COLLECTIVITE	2008-10-15 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	95044H	\N	\N	\N
7356	2010CMP9	2010-07-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83050R	TITULAIRE	\N	\N
7357	2010CMP9	2010-07-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01021J	TITULAIRE	\N	\N
7358	2010CMP9	2010-07-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01041N	TITULAIRE	\N	2017-09-24 18:59:59
7359	2010CMP9	2010-07-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01056V	TITULAIRE	\N	2017-09-24 17:04:02
7360	2010CMP9	2010-07-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01012H	TITULAIRE	\N	\N
7370	2010CMP10	2010-07-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95030B	TITULAIRE	\N	2014-09-28 18:58:21
7371	2010CMP10	2010-07-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	90003B	TITULAIRE	\N	2017-10-01 10:01:39
7372	2010CMP10	2010-07-06 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95062K	TITULAIRE	\N	\N
7373	2010CMP10	2010-07-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01050P	TITULAIRE	\N	\N
7374	2010CMP10	2010-07-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01022K	TITULAIRE	\N	2017-09-24 17:14:26
7375	2010CMP10	2010-07-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08014Q	TITULAIRE	\N	\N
7376	2010CMP10	2010-07-06 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98038X	TITULAIRE	\N	2014-09-28 17:38:26
7377	2010CMP10	2010-07-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	05012A	SUPPLEANT	\N	\N
7378	2010CMP10	2010-07-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	07023M	SUPPLEANT	\N	\N
7379	2010CMP10	2010-07-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04088S	SUPPLEANT	\N	\N
7380	2010CMP10	2010-07-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01008M	SUPPLEANT	\N	2017-09-24 13:44:49
7381	2010CMP10	2010-07-06 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	07027R	SUPPLEANT	\N	\N
7382	2010CMP10	2010-07-06 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	08064B	SUPPLEANT	\N	\N
7491	2010CMP15	2010-11-18 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04051D	TITULAIRE	\N	2014-09-28 17:07:41
7492	2010CMP15	2010-11-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	TITULAIRE	\N	\N
7501	2010CMP15	2010-11-18 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10003H	SUPPLEANT	\N	2014-09-28 17:38:26
7502	2010CMP15	2010-11-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92030N	SUPPLEANT	\N	\N
7521	2010CMP16	2010-12-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	01057W	SUPPLEANT	\N	\N
7522	2010CMP16	2010-12-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	SUPPLEANT	\N	2017-09-24 18:20:10
7536	2010CMP17	2010-12-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	SUPPLEANT	\N	2017-09-24 18:20:10
7537	2010CMP17	2010-12-08 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	90004C	SUPPLEANT	\N	2014-09-28 13:21:47
7294	2010CMP5	2010-05-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95030B	TITULAIRE	\N	2014-09-28 18:58:21
7296	2010CMP5	2010-05-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01001E	TITULAIRE	\N	\N
7298	2010CMP5	2010-05-20 00:00:00	2012-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	TITULAIRE	\N	\N
7299	2010CMP5	2010-05-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04066L	TITULAIRE	\N	2017-09-24 17:47:28
7306	2010CMP5	2010-05-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	04059M	SUPPLEANT	\N	\N
7445	2010CMP13	2010-10-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04037F	SUPPLEANT	\N	\N
7446	2010CMP13	2010-10-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	07029T	SUPPLEANT	\N	\N
7447	2010CMP13	2010-10-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01029S	SUPPLEANT	\N	\N
7507	SOCI	2010-12-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01043Q	\N	\N	\N
7508	NEANT	2010-12-14 00:00:00	2011-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	04040A	\N	\N	\N
7509	LOIS	2010-12-14 00:00:00	2011-03-28 00:00:00	ANCIEN	\N	\N	\N	\N	95031C	\N	\N	\N
7511	2010CMP16	2010-12-07 00:00:00	2014-07-01 00:00:00	ANCIEN	\N	\N	\N	\N	83011J	TITULAIRE	\N	2014-07-01 09:25:11
7512	2010CMP16	2010-12-07 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
7513	2010CMP16	2010-12-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	08011M	TITULAIRE	\N	\N
7515	2010CMP16	2010-12-07 00:00:00	2012-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	TITULAIRE	\N	\N
7516	2010CMP16	2010-12-07 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	98046X	TITULAIRE	\N	2017-09-25 09:56:00
7526	2010CMP17	2010-12-08 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
7527	2010CMP17	2010-12-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	08011M	TITULAIRE	\N	\N
7528	2010CMP17	2010-12-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	01057W	TITULAIRE	\N	\N
7534	2010CMP17	2010-12-08 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	SUPPLEANT	\N	\N
7535	2010CMP17	2010-12-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01027Q	SUPPLEANT	\N	2017-09-24 17:28:55
7538	2010CMP17	2010-12-08 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	SUPPLEANT	\N	2017-05-16 15:18:13
7554	2010CMP18	2010-12-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	88008L	SUPPLEANT	\N	\N
7596	RGPP	2011-01-11 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	95009E	\N	\N	\N
7597	RGPP	2011-01-11 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	\N	\N	\N
7598	RGPP	2011-01-11 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	07030L	\N	\N	\N
7599	RGPP	2011-01-11 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	04046G	\N	\N	\N
7600	RGPP	2011-01-11 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	10006L	\N	\N	\N
7601	RGPP	2011-01-11 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	01027Q	\N	\N	\N
118	LOIS	1994-10-19 00:00:00	2011-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	92022N	\N	\N	\N
7603	RGPP	2011-01-11 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	08045X	\N	\N	\N
7604	RGPP	2011-01-11 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	01007L	\N	\N	\N
7605	RGPP	2011-01-11 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	78006D	\N	\N	\N
7606	RGPP	2011-01-11 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	08016S	\N	\N	\N
7607	RGPP	2011-01-11 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	08069G	\N	\N	\N
7608	RGPP	2011-01-11 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	08034U	\N	\N	\N
7609	RGPP	2011-01-11 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	01043Q	\N	\N	\N
7610	RGPP	2011-01-11 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	77043E	\N	\N	\N
7611	RGPP	2011-01-11 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	08053X	\N	\N	\N
7612	RGPP	2011-01-11 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	\N	\N	\N
7613	RGPP	2011-01-11 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	92039X	\N	\N	\N
7614	RGPP	2011-01-11 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	08073C	\N	\N	\N
7615	RGPP	2011-01-11 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	08061X	\N	\N	\N
7616	RGPP	2011-01-11 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	95062K	\N	\N	\N
7617	RGPP	2011-01-11 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	92044U	\N	\N	\N
7618	RGPP	2011-01-11 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	04050C	\N	\N	\N
7619	RGPP	2011-01-11 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	\N	\N	\N
7631	2010CMP20	2010-12-17 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	06004E	SUPPLEANT	\N	2014-09-28 17:03:42
7634	AFCL	2011-01-13 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	92022N	\N	\N	\N
4305	AFCL	2008-10-07 00:00:00	2011-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	95005A	\N	\N	\N
7635	LOIS	2011-01-13 00:00:00	2012-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	95005A	\N	\N	\N
7695	2011CMP2	2011-01-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01011G	TITULAIRE	\N	2017-09-24 16:43:43
7691	2011CMP2	2011-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04051D	TITULAIRE	\N	2014-09-28 17:07:41
7692	2011CMP2	2011-01-25 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04075M	TITULAIRE	\N	\N
7693	2011CMP2	2011-01-25 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92011K	TITULAIRE	\N	\N
7694	2011CMP2	2011-01-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	10006L	TITULAIRE	\N	\N
7696	2011CMP2	2011-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10003H	TITULAIRE	\N	2014-09-28 17:38:26
7697	2011CMP2	2011-01-25 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83012K	TITULAIRE	\N	\N
7301	2010CMP5	2010-05-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	59312E	SUPPLEANT	\N	\N
7464	NEANT	2010-01-08 00:00:00	2010-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	10001F	\N	\N	\N
7494	2010CMP15	2010-11-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01018P	TITULAIRE	\N	\N
7500	2010CMP15	2010-11-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04037F	SUPPLEANT	\N	\N
7680	2011CMP1	2011-01-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95005A	TITULAIRE	\N	2014-09-28 17:40:23
7681	2011CMP1	2011-01-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08025T	TITULAIRE	\N	2017-10-01 10:17:18
7682	2011CMP1	2011-01-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08032S	TITULAIRE	\N	2014-09-28 17:34:16
7683	2011CMP1	2011-01-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	04085P	TITULAIRE	\N	\N
7684	2011CMP1	2011-01-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04063H	SUPPLEANT	\N	\N
7698	2011CMP2	2011-01-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	SUPPLEANT	\N	2017-09-24 13:44:49
7699	2011CMP2	2011-01-25 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	02003L	SUPPLEANT	\N	\N
7700	2011CMP2	2011-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	SUPPLEANT	\N	2014-09-28 17:07:41
7701	2011CMP2	2011-01-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	07029T	SUPPLEANT	\N	\N
7702	2011CMP2	2011-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08037X	SUPPLEANT	\N	2014-09-28 17:34:16
6967	DEPENDANCE	2009-10-08 00:00:00	2011-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	04037F	\N	\N	\N
7703	2011CMP2	2011-01-25 00:00:00	2013-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	95045J	SUPPLEANT	\N	\N
7722	2011CMP4	2011-02-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	TITULAIRE	\N	2014-09-28 18:00:58
7723	2011CMP4	2011-02-10 00:00:00	2015-04-21 00:00:00	ANCIEN	\N	\N	\N	\N	01042P	TITULAIRE	\N	2015-04-21 17:14:30
7724	2011CMP4	2011-02-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95005A	TITULAIRE	\N	2014-09-28 17:40:23
7725	2011CMP4	2011-02-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
7726	2011CMP4	2011-02-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04084N	TITULAIRE	\N	2014-09-28 13:40:33
7727	2011CMP4	2011-02-10 00:00:00	2012-09-19 00:00:00	ANCIEN	\N	\N	\N	\N	95011X	TITULAIRE	\N	\N
7539	2010CMP18	2010-12-16 00:00:00	2014-07-01 00:00:00	ANCIEN	\N	\N	\N	\N	83011J	TITULAIRE	\N	2014-07-01 09:25:11
4062	2008CMP9	2008-07-10 00:00:00	2008-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	01048V	SUPPLEANT	\N	\N
7750	FINC	2011-03-29 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95031C	\N	\N	\N
7728	2011CMP4	2011-02-10 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08025T	SUPPLEANT	\N	2017-10-01 10:17:18
7285	2010CMP4	2010-04-08 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08032S	TITULAIRE	\N	2014-09-28 17:34:16
7286	2010CMP4	2010-04-08 00:00:00	2012-09-19 00:00:00	ANCIEN	\N	\N	\N	\N	95011X	TITULAIRE	\N	\N
7888	2011CMP14	2011-06-29 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	01063U	TITULAIRE	\N	2014-09-29 13:41:53
7952	2011CMP18	2011-07-05 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	SUPPLEANT	\N	2017-06-19 12:20:59
7955	2011CMP18	2011-07-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	SUPPLEANT	\N	\N
8198	COMSPEAPU	2011-10-01 00:00:00	2015-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	11069T	\N	\N	2015-12-16 17:18:59
8199	ECON	2011-10-01 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	08055A	\N	\N	\N
8200	ECON	2011-10-01 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	08050U	\N	\N	\N
8201	FINC	2011-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08014Q	\N	\N	2017-10-04 19:49:11
8202	FINC	2011-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	04066L	\N	\N	2014-10-08 17:05:14
8203	ECON	2011-10-01 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	08045X	\N	\N	\N
6837	2009CMP9	2009-07-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01014K	TITULAIRE	\N	2017-09-24 17:19:42
6838	2009CMP9	2009-07-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92018S	TITULAIRE	\N	2017-09-24 18:16:52
6839	2009CMP9	2009-07-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	86030A	SUPPLEANT	\N	\N
6840	2009CMP9	2009-07-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77053G	SUPPLEANT	\N	\N
6841	2009CMP9	2009-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95028H	SUPPLEANT	\N	2014-09-28 12:56:41
6842	2009CMP9	2009-07-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01056V	SUPPLEANT	\N	2017-09-24 17:04:02
6896	2009CMP12	2009-07-21 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	SUPPLEANT	\N	\N
7077	2009CMP20	2009-12-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77019E	SUPPLEANT	\N	\N
7085	GRANDPARIS	2009-12-21 00:00:00	2010-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	04077P	\N	\N	\N
7088	2009CMP21	2009-12-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95030B	TITULAIRE	\N	2014-09-28 18:58:21
7089	2009CMP21	2009-12-17 00:00:00	2018-12-30 00:00:00	ANCIEN	\N	\N	\N	\N	98023Q	TITULAIRE	\N	\N
7090	2009CMP21	2009-12-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	01058X	TITULAIRE	\N	\N
7091	2009CMP21	2009-12-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04089T	TITULAIRE	\N	\N
7092	2009CMP21	2009-12-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04079R	TITULAIRE	\N	2017-09-24 17:47:27
7122	2009CMP23	2009-12-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	07001F	TITULAIRE	\N	\N
7123	2009CMP23	2009-12-22 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95062K	SUPPLEANT	\N	\N
7127	2009CMP23	2009-12-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	04033B	SUPPLEANT	\N	\N
7125	2009CMP23	2009-12-22 00:00:00	2018-12-30 00:00:00	ANCIEN	\N	\N	\N	\N	98023Q	SUPPLEANT	\N	\N
7126	2009CMP23	2009-12-22 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04088S	SUPPLEANT	\N	\N
7131	2009CMP23	2009-12-22 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	SUPPLEANT	\N	2017-05-16 15:18:13
7129	2009CMP23	2009-12-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08033T	SUPPLEANT	\N	2014-09-28 17:27:35
7130	2009CMP23	2009-12-22 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80013X	SUPPLEANT	\N	\N
7148	GRIPPEA	2010-02-17 00:00:00	2010-08-05 00:00:00	ANCIEN	\N	\N	\N	\N	01040M	\N	\N	\N
7149	GRIPPEA	2010-02-17 00:00:00	2010-08-05 00:00:00	ANCIEN	\N	\N	\N	\N	04075M	\N	\N	\N
7150	GRIPPEA	2010-02-17 00:00:00	2010-08-05 00:00:00	ANCIEN	\N	\N	\N	\N	01022K	\N	\N	\N
7151	GRIPPEA	2010-02-17 00:00:00	2010-08-05 00:00:00	ANCIEN	\N	\N	\N	\N	08069G	\N	\N	\N
7152	GRIPPEA	2010-02-17 00:00:00	2010-08-05 00:00:00	ANCIEN	\N	\N	\N	\N	04037F	\N	\N	\N
7153	GRIPPEA	2010-02-17 00:00:00	2010-08-05 00:00:00	ANCIEN	\N	\N	\N	\N	04036E	\N	\N	\N
7154	GRIPPEA	2010-02-17 00:00:00	2010-08-05 00:00:00	ANCIEN	\N	\N	\N	\N	97004H	\N	\N	\N
7155	GRIPPEA	2010-02-17 00:00:00	2010-08-05 00:00:00	ANCIEN	\N	\N	\N	\N	07029T	\N	\N	\N
7156	GRIPPEA	2010-02-17 00:00:00	2010-08-05 00:00:00	ANCIEN	\N	\N	\N	\N	08037X	\N	\N	\N
7157	GRIPPEA	2010-02-17 00:00:00	2010-08-05 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	\N	\N	\N
7158	GRIPPEA	2010-02-17 00:00:00	2010-08-05 00:00:00	ANCIEN	\N	\N	\N	\N	04045F	\N	\N	\N
7159	GRIPPEA	2010-02-17 00:00:00	2010-08-05 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	\N	\N	\N
7257	DESINDUSTRI	2010-04-28 00:00:00	2011-04-05 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	\N	\N	2018-02-02 10:20:31
7258	DESINDUSTRI	2010-04-28 00:00:00	2011-04-05 00:00:00	ANCIEN	\N	\N	\N	\N	92031P	\N	\N	\N
6850	2009CMP10	2009-07-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95055L	TITULAIRE	\N	2014-09-28 13:21:47
6851	2009CMP10	2009-07-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95046K	TITULAIRE	\N	\N
6852	2009CMP10	2009-07-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01038T	TITULAIRE	\N	\N
6902	AFEU	2009-10-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01053S	\N	\N	\N
7179	2010CMP1	2010-02-16 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
7180	2010CMP1	2010-02-16 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89022N	TITULAIRE	\N	2014-09-28 18:19:47
7181	2010CMP1	2010-02-16 00:00:00	2018-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	98053W	TITULAIRE	\N	2018-05-31 10:52:17
7182	2010CMP1	2010-02-16 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08027V	TITULAIRE	\N	2014-09-28 17:34:16
7183	2010CMP1	2010-02-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	08011M	TITULAIRE	\N	\N
7184	2010CMP1	2010-02-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89017R	SUPPLEANT	\N	\N
7185	2010CMP1	2010-02-16 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	SUPPLEANT	\N	\N
7186	2010CMP1	2010-02-16 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	94003T	SUPPLEANT	\N	2014-09-28 13:16:32
7187	2010CMP1	2010-02-16 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	03001N	SUPPLEANT	\N	2014-09-28 13:40:33
7188	2010CMP1	2010-02-16 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77043E	SUPPLEANT	\N	2014-09-28 16:59:41
7189	2010CMP1	2010-02-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83042R	SUPPLEANT	\N	\N
7190	2010CMP2	2010-02-18 00:00:00	2015-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-12 09:39:30
3411	20061214N52	2006-12-12 00:00:00	2006-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	81015E	TITULAIRE	\N	\N
7191	2010CMP2	2010-02-18 00:00:00	2015-04-21 00:00:00	ANCIEN	\N	\N	\N	\N	01042P	TITULAIRE	\N	2015-04-21 17:14:30
7176	ECON	2010-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98009S	\N	\N	\N
7178	2010CMP1	2010-02-16 00:00:00	2014-07-01 00:00:00	ANCIEN	\N	\N	\N	\N	83011J	TITULAIRE	\N	2014-07-01 09:25:11
7192	2010CMP2	2010-02-18 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	07034Q	TITULAIRE	\N	\N
7254	DESINDUSTRI	2010-04-28 00:00:00	2011-04-05 00:00:00	ANCIEN	\N	\N	\N	\N	95009E	\N	\N	\N
7059	GRANDPARIS	2009-12-09 00:00:00	2010-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	\N	\N	\N
7060	GRANDPARIS	2009-12-09 00:00:00	2010-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	04066L	\N	\N	\N
7061	GRANDPARIS	2009-12-09 00:00:00	2010-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	00003C	\N	\N	\N
7062	GRANDPARIS	2009-12-09 00:00:00	2010-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	97004H	\N	\N	\N
7255	DESINDUSTRI	2010-04-28 00:00:00	2011-04-05 00:00:00	ANCIEN	\N	\N	\N	\N	08028W	\N	\N	2017-12-01 14:23:06
6511	2008CMP17	2008-11-13 00:00:00	2009-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	97009N	SUPPLEANT	\N	\N
6534	2008CMP19	2008-12-19 00:00:00	2008-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	77043E	TITULAIRE	\N	2014-09-28 16:59:41
6535	2008CMP19	2008-12-19 00:00:00	2008-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	98032R	TITULAIRE	\N	2015-06-12 15:59:49
6536	2008CMP19	2008-12-19 00:00:00	2008-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	TITULAIRE	\N	\N
6537	2008CMP19	2008-12-19 00:00:00	2008-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	04050C	TITULAIRE	\N	\N
6541	2008CMP19	2008-12-19 00:00:00	2008-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	89022N	SUPPLEANT	\N	2014-09-28 18:19:47
6687	2009CMP5	2009-04-02 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89022N	TITULAIRE	\N	2014-09-28 18:19:47
6685	2009CMP5	2009-04-02 00:00:00	2014-07-01 00:00:00	ANCIEN	\N	\N	\N	\N	83011J	TITULAIRE	\N	2014-07-01 09:25:11
6686	2009CMP5	2009-04-02 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
6693	2009CMP5	2009-04-02 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	88008L	SUPPLEANT	\N	\N
6694	2009CMP5	2009-04-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77019E	SUPPLEANT	\N	\N
6695	2009CMP5	2009-04-02 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	01048V	SUPPLEANT	\N	\N
6696	2009CMP5	2009-04-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	08011M	SUPPLEANT	\N	\N
6697	2009CMP5	2009-04-02 00:00:00	2014-05-02 00:00:00	ANCIEN	\N	\N	\N	\N	08070Y	SUPPLEANT	\N	2014-05-05 10:59:42
6698	2009CMP5	2009-04-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92043T	SUPPLEANT	\N	\N
6702	2009CMP6	2009-04-02 00:00:00	2009-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	08031R	TITULAIRE	\N	\N
6703	2009CMP6	2009-04-02 00:00:00	2009-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	97004H	TITULAIRE	\N	\N
6704	2009CMP6	2009-04-02 00:00:00	2009-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	04057K	TITULAIRE	\N	\N
6705	2009CMP6	2009-04-02 00:00:00	2009-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	04070G	TITULAIRE	\N	\N
6706	2009CMP6	2009-04-02 00:00:00	2009-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	04052E	SUPPLEANT	\N	\N
6707	2009CMP6	2009-04-02 00:00:00	2009-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	01012H	SUPPLEANT	\N	\N
2764	AMIANTE	2005-02-02 00:00:00	2005-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	04067M	\N	\N	\N
2767	AMIANTE	2005-02-02 00:00:00	2005-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	98042T	\N	\N	\N
2776	AMIANTE	2005-02-02 00:00:00	2005-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	04075M	\N	\N	\N
6875	2009CMP11	2009-07-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01015L	TITULAIRE	\N	2017-09-24 17:19:42
6897	ETRD	2009-07-29 00:00:00	2016-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	07024N	\N	\N	2017-01-03 11:09:24
6898	NEANT	2009-07-21 00:00:00	2010-01-07 00:00:00	ANCIEN	\N	\N	\N	\N	86039K	\N	\N	\N
7063	GRANDPARIS	2009-12-09 00:00:00	2010-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	04079R	\N	\N	\N
4316	FINC	2008-10-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77019E	\N	\N	\N
7005	2009CMP18	2009-11-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04080J	TITULAIRE	\N	2017-09-24 17:47:27
7006	2009CMP18	2009-11-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01023L	TITULAIRE	\N	\N
7064	GRANDPARIS	2009-12-09 00:00:00	2010-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	95046K	\N	\N	\N
7065	GRANDPARIS	2009-12-09 00:00:00	2010-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	04090L	\N	\N	\N
7066	GRANDPARIS	2009-12-09 00:00:00	2010-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	04056J	\N	\N	\N
7067	GRANDPARIS	2009-12-09 00:00:00	2010-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	98037W	\N	\N	\N
7068	GRANDPARIS	2009-12-09 00:00:00	2010-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	04082L	\N	\N	\N
7069	2009CMP20	2009-12-08 00:00:00	2014-07-01 00:00:00	ANCIEN	\N	\N	\N	\N	83011J	TITULAIRE	\N	2014-07-01 09:25:11
7070	2009CMP20	2009-12-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01013J	TITULAIRE	\N	2017-09-24 17:06:55
7078	2009CMP20	2009-12-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01027Q	SUPPLEANT	\N	2017-09-24 17:28:55
7079	2009CMP20	2009-12-08 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08027V	SUPPLEANT	\N	2014-09-28 17:34:16
7080	2009CMP20	2009-12-08 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	SUPPLEANT	\N	\N
7081	2009CMP20	2009-12-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	SUPPLEANT	\N	2017-09-24 18:20:10
7082	2009CMP20	2009-12-08 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	81015E	SUPPLEANT	\N	\N
7118	2009CMP23	2009-12-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	05012A	TITULAIRE	\N	\N
7119	2009CMP23	2009-12-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01049W	TITULAIRE	\N	\N
7120	2009CMP23	2009-12-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98037W	TITULAIRE	\N	2014-09-28 14:31:42
7121	2009CMP23	2009-12-22 00:00:00	2020-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	08068F	TITULAIRE	\N	\N
7136	AFCL	2010-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10001F	\N	\N	\N
7139	GRIPPEA	2010-02-17 00:00:00	2010-08-05 00:00:00	ANCIEN	\N	\N	\N	\N	83012K	\N	\N	\N
7140	GRIPPEA	2010-02-17 00:00:00	2010-08-05 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	\N	\N	\N
7141	GRIPPEA	2010-02-17 00:00:00	2010-08-05 00:00:00	ANCIEN	\N	\N	\N	\N	01044R	\N	\N	\N
7142	GRIPPEA	2010-02-17 00:00:00	2010-08-05 00:00:00	ANCIEN	\N	\N	\N	\N	95024D	\N	\N	\N
7143	GRIPPEA	2010-02-17 00:00:00	2010-08-05 00:00:00	ANCIEN	\N	\N	\N	\N	95025E	\N	\N	\N
7144	GRIPPEA	2010-02-17 00:00:00	2010-08-05 00:00:00	ANCIEN	\N	\N	\N	\N	98030P	\N	\N	\N
7145	GRIPPEA	2010-02-17 00:00:00	2010-08-05 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	\N	\N	\N
7146	GRIPPEA	2010-02-17 00:00:00	2010-08-05 00:00:00	ANCIEN	\N	\N	\N	\N	08048B	\N	\N	\N
7147	GRIPPEA	2010-02-17 00:00:00	2010-08-05 00:00:00	ANCIEN	\N	\N	\N	\N	01011G	\N	\N	\N
7256	DESINDUSTRI	2010-04-28 00:00:00	2011-04-05 00:00:00	ANCIEN	\N	\N	\N	\N	04097T	\N	\N	\N
4402	AFEU	2008-10-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95006B	\N	\N	\N
4403	AFEU	2008-10-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95007C	\N	\N	\N
4408	AFEU	2008-10-08 00:00:00	2020-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	96004D	\N	\N	2017-10-05 14:39:03
4409	AFEU	2008-10-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01005J	\N	\N	\N
4413	AFEU	2008-10-08 00:00:00	2014-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	98018T	\N	\N	2014-10-09 15:40:04
6489	2008CMP16	2008-11-20 00:00:00	2008-11-25 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	TITULAIRE	\N	\N
6496	2008CMP16	2008-11-20 00:00:00	2008-11-25 00:00:00	ANCIEN	\N	\N	\N	\N	08013P	SUPPLEANT	\N	\N
4423	AFEU	2008-10-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83033Q	\N	\N	\N
4424	AFEU	2008-10-08 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	94003T	\N	\N	2014-09-28 13:16:32
4427	AFEU	2008-10-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	97004H	\N	\N	\N
4430	AFEU	2008-10-08 00:00:00	2014-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	98032R	\N	\N	2014-10-09 15:40:51
4433	AFEU	2008-10-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98035U	\N	\N	2017-10-05 14:43:13
4592	AFEU	2008-10-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	02001J	\N	\N	\N
4585	AFEU	2008-10-08 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	90003B	\N	\N	2017-10-01 10:01:39
4723	AFEU	2008-10-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86010V	\N	\N	\N
4727	AFEU	2008-10-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01051Q	\N	\N	\N
4729	AFEU	2008-10-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04063H	\N	\N	\N
4735	AFEU	2008-10-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01063U	\N	\N	\N
4741	AFEU	2008-10-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04075M	\N	\N	\N
4742	AFEU	2008-10-08 00:00:00	2019-06-23 00:00:00	ANCIEN	\N	\N	\N	\N	04061F	\N	\N	2017-10-05 14:41:26
6497	2008CMP16	2008-11-20 00:00:00	2008-11-25 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	SUPPLEANT	\N	2017-09-24 17:35:15
7347	2010CMP8	2010-06-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	08034U	SUPPLEANT	\N	\N
7348	2010CMP8	2010-06-02 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95055L	SUPPLEANT	\N	2014-09-28 13:21:47
7349	2010CMP8	2010-06-02 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	SUPPLEANT	\N	\N
7569	MEDIATOR	2011-01-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83012K	\N	\N	\N
7570	MEDIATOR	2011-01-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92011K	\N	\N	\N
7571	MEDIATOR	2011-01-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	\N	\N	\N
7572	MEDIATOR	2011-01-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98029W	\N	\N	\N
7573	MEDIATOR	2011-01-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95021A	\N	\N	\N
7574	MEDIATOR	2011-01-11 00:00:00	2011-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	04067M	\N	\N	\N
7575	MEDIATOR	2011-01-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95028H	\N	\N	\N
7576	MEDIATOR	2011-01-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08066D	\N	\N	\N
7577	MEDIATOR	2011-01-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	07004J	\N	\N	\N
7578	MEDIATOR	2011-01-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01040M	\N	\N	\N
7579	MEDIATOR	2011-01-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04075M	\N	\N	\N
7580	MEDIATOR	2011-01-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04036E	\N	\N	\N
7581	MEDIATOR	2011-01-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10003H	\N	\N	\N
7582	MEDIATOR	2011-01-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08032S	\N	\N	\N
7583	MEDIATOR	2011-01-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92030N	\N	\N	\N
7584	MEDIATOR	2011-01-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08037X	\N	\N	\N
7585	MEDIATOR	2011-01-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95045J	\N	\N	\N
7586	MEDIATOR	2011-01-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04084N	\N	\N	\N
7587	MEDIATOR	2011-01-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	\N	\N	\N
7588	MEDIATOR	2011-01-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08033T	\N	\N	\N
7589	MEDIATOR	2011-01-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01029S	\N	\N	\N
7652	POLEEMPLOI	2011-02-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01006K	\N	\N	\N
7653	POLEEMPLOI	2011-02-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04087R	\N	\N	\N
7590	MEDIATOR	2011-01-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	97005J	\N	\N	\N
7592	MEDIATOR	2011-01-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	\N	\N	\N
4746	AFEU	2008-10-08 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	04057K	\N	\N	2017-10-05 14:42:10
4748	AFEU	2008-10-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01054T	\N	\N	\N
4750	AFEU	2008-10-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04080J	\N	\N	\N
4752	AFEU	2008-10-08 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04065K	\N	\N	2014-09-28 17:31:42
4754	AFEU	2008-10-08 00:00:00	2014-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	04056J	\N	\N	2014-10-09 15:41:14
6498	2008CMP16	2008-11-20 00:00:00	2008-11-25 00:00:00	ANCIEN	\N	\N	\N	\N	98024R	SUPPLEANT	\N	\N
6488	2008CMP16	2008-11-20 00:00:00	2008-11-25 00:00:00	ANCIEN	\N	\N	\N	\N	95004Y	TITULAIRE	\N	\N
6499	2008CMP16	2008-11-20 00:00:00	2008-11-25 00:00:00	ANCIEN	\N	\N	\N	\N	04046G	SUPPLEANT	\N	2014-09-28 17:07:41
6500	2008CMP16	2008-11-20 00:00:00	2008-11-25 00:00:00	ANCIEN	\N	\N	\N	\N	01045S	SUPPLEANT	\N	\N
6501	2008CMP16	2008-11-20 00:00:00	2008-11-25 00:00:00	ANCIEN	\N	\N	\N	\N	01018P	SUPPLEANT	\N	\N
6574	2009CMP3	2009-02-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	TITULAIRE	\N	\N
6575	2009CMP3	2009-02-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01001E	TITULAIRE	\N	\N
6576	2009CMP3	2009-02-27 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
6577	2009CMP3	2009-02-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04089T	TITULAIRE	\N	\N
6578	2009CMP3	2009-02-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	TITULAIRE	\N	2017-09-24 17:09:24
6588	2009CMP4	2009-02-11 00:00:00	2009-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	95030B	TITULAIRE	\N	2014-09-28 18:58:21
6589	2009CMP4	2009-02-11 00:00:00	2009-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	95013A	TITULAIRE	\N	\N
6283	AFEU	2008-10-08 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	07003H	\N	\N	2014-09-28 12:21:28
6409	AFEU	2008-10-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83050R	\N	\N	\N
6573	2009CMP3	2009-02-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95030B	TITULAIRE	\N	2014-09-28 18:58:21
6590	2009CMP4	2009-02-11 00:00:00	2009-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	TITULAIRE	\N	\N
6591	2009CMP4	2009-02-11 00:00:00	2009-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	02003L	TITULAIRE	\N	\N
6753	2009CMP7	2009-04-28 00:00:00	2009-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	83011J	TITULAIRE	\N	2014-07-01 09:25:11
6756	2009CMP7	2009-04-28 00:00:00	2009-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	01037S	TITULAIRE	\N	2016-12-12 16:10:15
6757	2009CMP7	2009-04-28 00:00:00	2009-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	01057W	TITULAIRE	\N	\N
6760	2009CMP7	2009-04-28 00:00:00	2009-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	SUPPLEANT	\N	2017-09-24 18:20:10
6761	2009CMP7	2009-04-28 00:00:00	2009-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	07003H	SUPPLEANT	\N	2014-09-28 12:21:28
6762	2009CMP7	2009-04-28 00:00:00	2009-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	89022N	SUPPLEANT	\N	2014-09-28 18:19:47
6763	2009CMP7	2009-04-28 00:00:00	2009-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	SUPPLEANT	\N	\N
6764	2009CMP7	2009-04-28 00:00:00	2009-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	77019E	SUPPLEANT	\N	\N
6965	DEPENDANCE	2008-10-08 00:00:00	2011-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	\N	\N	\N
6966	DEPENDANCE	2008-10-08 00:00:00	2011-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	\N	\N	\N
6968	DEPENDANCE	2009-10-08 00:00:00	2011-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	08011M	\N	\N	\N
7071	2009CMP20	2009-12-08 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
7072	2009CMP20	2009-12-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	08011M	TITULAIRE	\N	\N
7073	2009CMP20	2009-12-08 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	01048V	TITULAIRE	\N	\N
7074	2009CMP20	2009-12-08 00:00:00	2012-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	TITULAIRE	\N	\N
7075	2009CMP20	2009-12-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	01057W	SUPPLEANT	\N	\N
7076	2009CMP20	2009-12-08 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	98046X	TITULAIRE	\N	2017-09-25 09:56:00
6493	2008CMP16	2008-11-20 00:00:00	2008-11-25 00:00:00	ANCIEN	\N	\N	\N	\N	04076N	TITULAIRE	\N	\N
6538	2008CMP19	2008-12-19 00:00:00	2008-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	SUPPLEANT	\N	2017-09-24 18:20:10
6539	2008CMP19	2008-12-19 00:00:00	2008-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	97009N	SUPPLEANT	\N	\N
6540	2008CMP19	2008-12-19 00:00:00	2008-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	95007C	SUPPLEANT	\N	\N
6542	2008CMP19	2008-12-19 00:00:00	2008-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	81015E	SUPPLEANT	\N	\N
6543	2008CMP19	2008-12-19 00:00:00	2008-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	77019E	SUPPLEANT	\N	\N
6544	2008CMP19	2008-12-19 00:00:00	2008-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	01057W	SUPPLEANT	\N	\N
6549	2009CMP1	2009-01-21 00:00:00	2009-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	04070G	TITULAIRE	\N	\N
6550	2009CMP1	2009-01-21 00:00:00	2009-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	04033B	TITULAIRE	\N	\N
6551	2009CMP1	2009-01-21 00:00:00	2009-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	01039U	TITULAIRE	\N	\N
6552	2009CMP1	2009-01-21 00:00:00	2009-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	01044R	SUPPLEANT	\N	2017-07-04 15:08:09
6553	2009CMP1	2009-01-21 00:00:00	2009-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	04073K	SUPPLEANT	\N	2014-09-28 18:58:25
6555	2009CMP1	2009-01-21 00:00:00	2009-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	08044W	SUPPLEANT	\N	\N
6556	2009CMP1	2009-01-21 00:00:00	2009-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	01021J	SUPPLEANT	\N	\N
6557	2009CMP1	2009-01-21 00:00:00	2009-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	98010K	SUPPLEANT	\N	2014-09-28 17:27:35
6558	2009CMP1	2009-01-21 00:00:00	2009-01-28 00:00:00	ANCIEN	\N	\N	\N	\N	95060H	SUPPLEANT	\N	\N
6569	2009CMP2	2009-01-26 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89022N	SUPPLEANT	\N	2014-09-28 18:19:47
6570	2009CMP2	2009-01-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77019E	SUPPLEANT	\N	\N
6571	2009CMP2	2009-01-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	01057W	SUPPLEANT	\N	\N
6572	2009CMP2	2009-01-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04037F	SUPPLEANT	\N	\N
6843	2009CMP9	2009-07-01 00:00:00	2012-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01051Q	SUPPLEANT	\N	\N
6847	2009CMP10	2009-07-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04074L	TITULAIRE	\N	2017-09-24 17:15:15
6860	ETRD	2009-07-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04058L	\N	\N	\N
6883	2009CMP12	2009-07-21 00:00:00	2015-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-12 09:39:30
6884	2009CMP12	2009-07-21 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	01063U	TITULAIRE	\N	2014-09-29 13:41:53
6885	2009CMP12	2009-07-21 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	TITULAIRE	\N	2014-09-28 18:00:58
6886	2009CMP12	2009-07-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	TITULAIRE	\N	\N
6887	2009CMP12	2009-07-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	02001J	TITULAIRE	\N	\N
6888	2009CMP12	2009-07-21 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98035U	TITULAIRE	\N	\N
6889	2009CMP12	2009-07-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	04085P	TITULAIRE	\N	\N
7259	DESINDUSTRI	2010-04-28 00:00:00	2011-04-05 00:00:00	ANCIEN	\N	\N	\N	\N	08034U	\N	\N	\N
7260	DESINDUSTRI	2010-04-28 00:00:00	2011-04-05 00:00:00	ANCIEN	\N	\N	\N	\N	01061S	\N	\N	\N
7261	DESINDUSTRI	2010-04-28 00:00:00	2011-04-05 00:00:00	ANCIEN	\N	\N	\N	\N	92040Q	\N	\N	\N
7262	DESINDUSTRI	2010-04-28 00:00:00	2011-04-05 00:00:00	ANCIEN	\N	\N	\N	\N	05012A	\N	\N	\N
7263	DESINDUSTRI	2010-04-28 00:00:00	2011-04-05 00:00:00	ANCIEN	\N	\N	\N	\N	77058M	\N	\N	\N
7264	DESINDUSTRI	2010-04-28 00:00:00	2011-04-05 00:00:00	ANCIEN	\N	\N	\N	\N	04069P	\N	\N	\N
7265	DESINDUSTRI	2010-04-28 00:00:00	2011-04-05 00:00:00	ANCIEN	\N	\N	\N	\N	08068F	\N	\N	\N
7266	DESINDUSTRI	2010-04-28 00:00:00	2011-04-05 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	\N	\N	\N
7267	DESINDUSTRI	2010-04-28 00:00:00	2011-04-05 00:00:00	ANCIEN	\N	\N	\N	\N	08033T	\N	\N	\N
7268	DESINDUSTRI	2010-04-28 00:00:00	2011-04-05 00:00:00	ANCIEN	\N	\N	\N	\N	08038Y	\N	\N	\N
7269	DESINDUSTRI	2010-04-28 00:00:00	2011-04-05 00:00:00	ANCIEN	\N	\N	\N	\N	98037W	\N	\N	\N
7270	DESINDUSTRI	2010-04-28 00:00:00	2011-04-05 00:00:00	ANCIEN	\N	\N	\N	\N	08027V	\N	\N	\N
7271	DESINDUSTRI	2010-04-28 00:00:00	2011-04-05 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	\N	\N	\N
7272	DESINDUSTRI	2010-04-28 00:00:00	2011-04-05 00:00:00	ANCIEN	\N	\N	\N	\N	04046G	\N	\N	\N
7273	DESINDUSTRI	2010-04-28 00:00:00	2011-04-05 00:00:00	ANCIEN	\N	\N	\N	\N	92042S	\N	\N	\N
7274	DESINDUSTRI	2010-04-28 00:00:00	2011-04-05 00:00:00	ANCIEN	\N	\N	\N	\N	01049W	\N	\N	\N
7275	DESINDUSTRI	2010-04-28 00:00:00	2011-04-05 00:00:00	ANCIEN	\N	\N	\N	\N	07004J	\N	\N	\N
7276	DESINDUSTRI	2010-04-28 00:00:00	2011-04-05 00:00:00	ANCIEN	\N	\N	\N	\N	07001F	\N	\N	\N
7277	DESINDUSTRI	2010-04-28 00:00:00	2011-04-05 00:00:00	ANCIEN	\N	\N	\N	\N	08026U	\N	\N	\N
7278	DESINDUSTRI	2010-04-28 00:00:00	2011-04-05 00:00:00	ANCIEN	\N	\N	\N	\N	08049C	\N	\N	\N
7279	DESINDUSTRI	2010-04-28 00:00:00	2011-04-05 00:00:00	ANCIEN	\N	\N	\N	\N	01060R	\N	\N	\N
7302	2010CMP5	2010-05-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	04042C	SUPPLEANT	\N	\N
7322	2010CMP7	2010-05-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95030B	TITULAIRE	\N	2014-09-28 18:58:21
7323	2010CMP7	2010-05-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	01058X	TITULAIRE	\N	\N
7324	2010CMP7	2010-05-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95013A	TITULAIRE	\N	\N
7325	2010CMP7	2010-05-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04089T	TITULAIRE	\N	\N
7326	2010CMP7	2010-05-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92042S	TITULAIRE	\N	\N
7327	2010CMP7	2010-05-26 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	04090L	TITULAIRE	\N	\N
7342	2010CMP8	2010-06-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01038T	TITULAIRE	\N	\N
7402	2010CMP12	2010-10-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
7411	2010CMP12	2010-10-06 00:00:00	2015-04-21 00:00:00	ANCIEN	\N	\N	\N	\N	01042P	SUPPLEANT	\N	2015-04-21 17:14:30
7412	2010CMP12	2010-10-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92031P	SUPPLEANT	\N	2017-09-24 18:16:52
7414	2010CMP12	2010-10-06 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	SUPPLEANT	\N	2017-06-19 12:20:59
7495	2010CMP15	2010-11-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98029W	TITULAIRE	\N	\N
7531	2010CMP17	2010-12-08 00:00:00	2018-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	98053W	TITULAIRE	\N	2018-05-31 10:52:17
7532	2010CMP17	2010-12-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77019E	SUPPLEANT	\N	\N
7533	2010CMP17	2010-12-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	04071H	SUPPLEANT	\N	\N
7344	2010CMP8	2010-06-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	SUPPLEANT	\N	\N
7345	2010CMP8	2010-06-02 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	08064B	SUPPLEANT	\N	\N
7346	2010CMP8	2010-06-02 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98041S	SUPPLEANT	\N	2014-09-28 16:42:05
6845	2009CMP9	2009-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	02053W	SUPPLEANT	\N	2014-09-28 12:32:23
6846	2009CMP10	2009-07-07 00:00:00	2015-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-12 09:39:30
6869	2009CMP11	2009-07-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95030B	TITULAIRE	\N	2014-09-28 18:58:21
6870	2009CMP11	2009-07-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	01058X	TITULAIRE	\N	\N
6871	2009CMP11	2009-07-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95013A	TITULAIRE	\N	\N
6872	2009CMP11	2009-07-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01050P	TITULAIRE	\N	\N
6873	2009CMP11	2009-07-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	TITULAIRE	\N	2017-09-24 17:09:24
6877	2009CMP11	2009-07-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08038Y	SUPPLEANT	\N	\N
6878	2009CMP11	2009-07-08 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	SUPPLEANT	\N	2017-05-16 15:18:13
6879	2009CMP11	2009-07-08 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95038K	SUPPLEANT	\N	2014-09-28 17:40:23
6880	2009CMP11	2009-07-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04088S	SUPPLEANT	\N	\N
6881	2009CMP11	2009-07-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92042S	SUPPLEANT	\N	\N
6882	2009CMP11	2009-07-08 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04069P	SUPPLEANT	\N	2014-09-28 17:31:41
6900	SOCI	2009-09-15 00:00:00	2012-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	09011R	\N	\N	\N
7093	2009CMP21	2009-12-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	TITULAIRE	\N	2017-09-24 17:09:24
7094	2009CMP21	2009-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	07001F	TITULAIRE	\N	\N
4344	ETRD	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86034E	\N	\N	2014-10-01 19:54:29
200	ECON	\N	2000-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	83047W	\N	\N	\N
424	ETRD	1998-10-06 00:00:00	1999-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	95008D	\N	\N	\N
26	ECON	1978-10-02 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	78010Y	\N	\N	\N
35	AFCL	1998-10-06 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89007P	\N	\N	2014-09-28 16:42:05
67	ETRD	1989-10-04 00:00:00	2000-04-27 00:00:00	ANCIEN	\N	\N	\N	\N	86039K	\N	\N	\N
76	AFCL	\N	1998-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	86006A	\N	\N	\N
114	AFCL	\N	2001-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	74024N	\N	\N	\N
2545	AFCL	2004-10-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04039H	\N	\N	\N
2553	AFCL	2004-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04070G	\N	\N	2017-10-04 00:00:00
2561	ECON	2004-10-06 00:00:00	2009-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	04064J	\N	\N	\N
2588	ETRD	2004-10-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01040M	\N	\N	\N
2595	ECON	2004-10-06 00:00:00	2005-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	04017B	\N	\N	\N
2622	SOCI	2004-10-06 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	04043D	\N	\N	2017-10-04 18:51:31
2630	AFCL	2004-10-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04062G	\N	\N	\N
3138	BANLIEUES	2005-12-22 00:00:00	2006-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	98036V	\N	\N	\N
3150	BANLIEUES	2005-12-22 00:00:00	2006-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	04075M	\N	\N	\N
3171	20060119N38	2006-01-19 00:00:00	2014-09-01 00:00:00	ANCIEN	\N	\N	\N	\N	96007G	TITULAIRE	\N	2014-09-01 10:21:13
3183	20060119N39	2006-01-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04081K	TITULAIRE	\N	2017-09-24 19:25:10
2282	20040512N6	2004-05-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95030B	TITULAIRE	\N	2014-09-28 18:58:21
2826	AFCL	2005-03-10 00:00:00	2007-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	86030A	\N	\N	\N
2889	20050629N26	2005-06-29 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92030N	TITULAIRE	\N	\N
2965	ECON	2005-10-04 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	05012A	\N	\N	\N
2972	RECHERCHE	2005-11-23 00:00:00	2006-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	04052E	\N	\N	\N
2984	RECHERCHE	2005-11-23 00:00:00	2006-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	95036H	\N	\N	\N
3021	IMMIGRATION	2005-11-03 00:00:00	2006-05-02 00:00:00	ANCIEN	\N	\N	\N	\N	04062G	\N	\N	\N
4007	ECONOMIE	2008-06-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	04077P	\N	\N	\N
4018	ECONOMIE	2008-06-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	01013J	\N	\N	\N
4103	2008CMP12	2008-07-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	04051D	SUPPLEANT	\N	2014-09-28 17:07:41
3648	SERVICE	2007-07-05 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	01011G	\N	\N	\N
3662	SERVICE	2007-07-05 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	96007G	\N	\N	\N
3672	ECON	2007-07-05 00:00:00	2007-07-25 00:00:00	ANCIEN	\N	\N	\N	\N	07025P	\N	\N	\N
4123	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08009T	\N	\N	\N
4195	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08043V	\N	\N	\N
4223	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08063A	\N	\N	\N
4110	2008CMP13	2008-07-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	92011K	TITULAIRE	\N	\N
4141	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08025T	\N	\N	\N
4192	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08042U	\N	\N	\N
4219	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08059E	\N	\N	\N
4232	NEANT	2008-10-01 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08072B	\N	\N	\N
6502	2008CMP17	2008-11-13 00:00:00	2009-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	83011J	TITULAIRE	\N	2014-07-01 09:25:11
6503	2008CMP17	2008-11-13 00:00:00	2009-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
6504	2008CMP17	2008-11-13 00:00:00	2009-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	TITULAIRE	\N	\N
6505	2008CMP17	2008-11-13 00:00:00	2009-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	94003T	TITULAIRE	\N	2014-09-28 13:16:32
6506	2008CMP17	2008-11-13 00:00:00	2009-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	77019E	TITULAIRE	\N	\N
6954	2009CMP16	2009-09-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92031P	SUPPLEANT	\N	2017-09-24 18:16:52
6952	2009CMP16	2009-09-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	TITULAIRE	\N	2017-09-24 17:35:15
6953	2009CMP16	2009-09-29 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98028V	SUPPLEANT	\N	2014-09-28 17:22:11
6955	2009CMP16	2009-09-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	04057K	SUPPLEANT	\N	\N
6956	2009CMP16	2009-09-29 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98010K	SUPPLEANT	\N	2014-09-28 17:27:35
6957	2009CMP16	2009-09-29 00:00:00	2014-09-01 00:00:00	ANCIEN	\N	\N	\N	\N	96007G	SUPPLEANT	\N	2014-09-01 10:21:13
7007	2009CMP18	2009-11-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04082L	TITULAIRE	\N	\N
6959	2009CMP16	2009-09-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	04045F	SUPPLEANT	\N	\N
6960	2009CMP16	2009-09-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01056V	SUPPLEANT	\N	2017-09-24 17:04:02
7003	2009CMP18	2009-11-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92018S	TITULAIRE	\N	2017-09-24 18:16:52
7004	2009CMP18	2009-11-06 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95028H	TITULAIRE	\N	2014-09-28 12:56:41
7008	2009CMP18	2009-11-06 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04091M	SUPPLEANT	\N	2014-09-28 17:55:37
7009	2009CMP18	2009-11-06 00:00:00	2012-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01051Q	SUPPLEANT	\N	\N
7010	2009CMP18	2009-11-06 00:00:00	2016-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	07024N	SUPPLEANT	\N	2017-01-03 11:09:24
7011	2009CMP18	2009-11-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98005N	SUPPLEANT	\N	\N
7014	2009CMP18	2009-11-06 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08071A	SUPPLEANT	\N	2014-09-29 09:08:32
7015	2009CMP19	2009-11-16 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04051D	TITULAIRE	\N	2014-09-28 17:07:41
7016	2009CMP19	2009-11-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98029W	TITULAIRE	\N	\N
7017	2009CMP19	2009-11-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	TITULAIRE	\N	\N
7018	2009CMP19	2009-11-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98024R	TITULAIRE	\N	\N
7019	2009CMP19	2009-11-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92030N	TITULAIRE	\N	\N
7020	2009CMP19	2009-11-16 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04046G	TITULAIRE	\N	2014-09-28 17:07:41
7021	2009CMP19	2009-11-16 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	TITULAIRE	\N	2014-09-28 17:07:41
7022	2009CMP19	2009-11-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83012K	SUPPLEANT	\N	\N
7023	2009CMP19	2009-11-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	SUPPLEANT	\N	\N
7024	2009CMP19	2009-11-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01045S	SUPPLEANT	\N	\N
7025	2009CMP19	2009-11-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04037F	SUPPLEANT	\N	\N
7026	2009CMP19	2009-11-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01018P	SUPPLEANT	\N	\N
7027	2009CMP19	2009-11-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04076N	SUPPLEANT	\N	\N
7028	2009CMP19	2009-11-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	04092N	SUPPLEANT	\N	\N
7083	AFEU	2009-12-18 00:00:00	2013-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	98046X	\N	\N	\N
7095	2009CMP21	2009-12-17 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95062K	SUPPLEANT	\N	\N
7096	2009CMP21	2009-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95013A	SUPPLEANT	\N	\N
7097	2009CMP21	2009-12-17 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95038K	SUPPLEANT	\N	2014-09-28 17:40:23
7098	2009CMP21	2009-12-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04088S	SUPPLEANT	\N	\N
7099	2009CMP21	2009-12-17 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	04090L	SUPPLEANT	\N	\N
7100	2009CMP21	2009-12-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08014Q	SUPPLEANT	\N	\N
7101	2009CMP21	2009-12-17 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	02053W	SUPPLEANT	\N	2014-09-28 12:32:23
7102	2009CMP22	2009-12-17 00:00:00	2014-07-01 00:00:00	ANCIEN	\N	\N	\N	\N	83011J	TITULAIRE	\N	2014-07-01 09:25:11
7103	2009CMP22	2009-12-17 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
7104	2009CMP22	2009-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77019E	TITULAIRE	\N	\N
7105	2009CMP22	2009-12-17 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89022N	TITULAIRE	\N	2014-09-28 18:19:47
7106	2009CMP22	2009-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92043T	TITULAIRE	\N	\N
7107	2009CMP22	2009-12-17 00:00:00	2018-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	98053W	TITULAIRE	\N	2018-05-31 10:52:17
7108	2009CMP22	2009-12-17 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	SUPPLEANT	\N	\N
7109	2009CMP22	2009-12-17 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77043E	SUPPLEANT	\N	2014-09-28 16:59:41
7110	2009CMP22	2009-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83021L	SUPPLEANT	\N	\N
7111	2009CMP22	2009-12-17 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	94003T	SUPPLEANT	\N	2014-09-28 13:16:32
7112	2009CMP22	2009-12-17 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98036V	SUPPLEANT	\N	2014-09-28 17:15:42
7113	2009CMP22	2009-12-17 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	98046X	SUPPLEANT	\N	2017-09-25 09:56:00
7114	2009CMP22	2009-12-17 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	81015E	SUPPLEANT	\N	\N
7115	2009CMP22	2009-12-17 00:00:00	2012-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	TITULAIRE	\N	\N
7116	2009CMP23	2009-12-22 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95030B	TITULAIRE	\N	2014-09-28 18:58:21
7117	2009CMP23	2009-12-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95038K	TITULAIRE	\N	2014-09-28 17:40:23
6485	2008CMP15	2008-10-29 00:00:00	2008-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	SUPPLEANT	\N	2014-09-28 17:07:41
6486	2008CMP15	2008-10-29 00:00:00	2008-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	01033N	SUPPLEANT	\N	\N
6487	2008CMP15	2008-10-29 00:00:00	2008-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	08067E	SUPPLEANT	\N	2014-09-28 17:22:11
6825	ETRD	2009-07-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92033R	\N	\N	\N
6826	LOIS	2009-07-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08018U	\N	\N	\N
6829	ECON	2009-07-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01052R	\N	\N	\N
6831	SOCI	2009-07-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04064J	\N	\N	\N
6941	2009CMP15	2009-09-29 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	SUPPLEANT	\N	2014-09-28 18:00:58
6942	2009CMP15	2009-09-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	08034U	SUPPLEANT	\N	\N
6943	2009CMP15	2009-09-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	SUPPLEANT	\N	\N
6944	2009CMP15	2009-09-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	\N	\N
6987	2009CMP17	2009-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95030B	TITULAIRE	\N	2014-09-28 18:58:21
6988	2009CMP17	2009-10-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95036H	TITULAIRE	\N	2014-09-28 17:31:42
6989	2009CMP17	2009-10-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95038K	TITULAIRE	\N	2014-09-28 17:40:23
6990	2009CMP17	2009-10-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01049W	TITULAIRE	\N	\N
6991	2009CMP17	2009-10-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98037W	TITULAIRE	\N	2014-09-28 14:31:42
6992	2009CMP17	2009-10-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04066L	TITULAIRE	\N	2017-09-24 17:47:28
6993	2009CMP17	2009-10-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08054Y	TITULAIRE	\N	2014-09-28 12:39:09
6994	2009CMP17	2009-10-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95009E	SUPPLEANT	\N	2014-09-28 12:56:42
6995	2009CMP17	2009-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	04071H	SUPPLEANT	\N	\N
6996	2009CMP17	2009-10-07 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	SUPPLEANT	\N	2017-05-16 15:18:13
6997	2009CMP17	2009-10-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08033T	SUPPLEANT	\N	2014-09-28 17:27:35
6998	2009CMP17	2009-10-07 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08042U	SUPPLEANT	\N	2017-10-01 10:20:50
6999	2009CMP17	2009-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04088S	SUPPLEANT	\N	\N
7000	2009CMP17	2009-10-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04065K	SUPPLEANT	\N	2014-09-28 17:31:42
7033	GRANDPARIS	2009-12-09 00:00:00	2010-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	\N	\N	\N
7034	GRANDPARIS	2009-12-09 00:00:00	2010-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	07026Q	\N	\N	\N
7035	GRANDPARIS	2009-12-09 00:00:00	2010-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	04050C	\N	\N	\N
7036	GRANDPARIS	2009-12-09 00:00:00	2010-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	95007C	\N	\N	\N
7037	GRANDPARIS	2009-12-09 00:00:00	2010-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	98042T	\N	\N	\N
7012	2009CMP18	2009-11-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08074D	SUPPLEANT	\N	\N
7013	2009CMP18	2009-11-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01056V	SUPPLEANT	\N	2017-09-24 17:04:02
7031	LOIS	2009-11-25 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	99002P	\N	\N	2017-06-19 12:20:22
7032	AFCL	2009-11-25 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08029X	\N	\N	\N
7038	GRANDPARIS	2009-12-09 00:00:00	2010-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	04080J	\N	\N	\N
7039	GRANDPARIS	2009-12-09 00:00:00	2010-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	88008L	\N	\N	\N
7040	GRANDPARIS	2009-12-09 00:00:00	2010-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	08031R	\N	\N	\N
7041	GRANDPARIS	2009-12-09 00:00:00	2010-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	01001E	\N	\N	\N
7042	GRANDPARIS	2009-12-09 00:00:00	2010-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	95013A	\N	\N	\N
7043	GRANDPARIS	2009-12-09 00:00:00	2010-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	04042C	\N	\N	\N
7044	GRANDPARIS	2009-12-09 00:00:00	2010-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	\N	\N	\N
7045	GRANDPARIS	2009-12-09 00:00:00	2010-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	04081K	\N	\N	\N
7046	GRANDPARIS	2009-12-09 00:00:00	2010-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	95024D	\N	\N	\N
7047	GRANDPARIS	2009-12-09 00:00:00	2010-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	04071H	\N	\N	\N
7048	GRANDPARIS	2009-12-09 00:00:00	2010-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	07033P	\N	\N	\N
7049	GRANDPARIS	2009-12-09 00:00:00	2010-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	95030B	\N	\N	\N
7050	GRANDPARIS	2009-12-09 00:00:00	2010-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	77019E	\N	\N	\N
7051	GRANDPARIS	2009-12-09 00:00:00	2010-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	07024N	\N	\N	\N
7052	GRANDPARIS	2009-12-09 00:00:00	2010-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	04048J	\N	\N	\N
7053	GRANDPARIS	2009-12-09 00:00:00	2010-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	04074L	\N	\N	\N
7054	GRANDPARIS	2009-12-09 00:00:00	2010-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	04043D	\N	\N	\N
7055	GRANDPARIS	2009-12-09 00:00:00	2010-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	95062K	\N	\N	\N
7056	GRANDPARIS	2009-12-09 00:00:00	2010-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	59312E	\N	\N	\N
7057	GRANDPARIS	2009-12-09 00:00:00	2010-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	97009N	\N	\N	\N
7287	2010CMP4	2010-04-08 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08022Q	SUPPLEANT	\N	2017-10-01 09:41:22
7288	2010CMP4	2010-04-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	SUPPLEANT	\N	\N
7289	2010CMP4	2010-04-08 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	08064B	SUPPLEANT	\N	\N
7290	2010CMP4	2010-04-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	08010L	SUPPLEANT	\N	\N
7291	2010CMP4	2010-04-08 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95055L	SUPPLEANT	\N	2014-09-28 13:21:47
7292	2010CMP4	2010-04-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	SUPPLEANT	\N	\N
7416	NEANT	2010-10-12 00:00:00	2010-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	10006L	\N	\N	\N
7434	2010CMP13	2010-10-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04051D	TITULAIRE	\N	2014-09-28 17:07:41
7496	2010CMP15	2010-11-18 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	TITULAIRE	\N	2014-09-28 17:07:41
7497	2010CMP15	2010-11-18 00:00:00	2014-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	08046Y	TITULAIRE	\N	\N
7498	2010CMP15	2010-11-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83012K	SUPPLEANT	\N	\N
7499	2010CMP15	2010-11-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01045S	SUPPLEANT	\N	\N
7730	2011CMP4	2011-02-10 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	08064B	SUPPLEANT	\N	\N
7731	2011CMP4	2011-02-10 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	07034Q	SUPPLEANT	\N	\N
7732	2011CMP4	2011-02-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	\N	\N
7733	2011CMP4	2011-02-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	SUPPLEANT	\N	\N
7734	2011CMP4	2011-02-10 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	SUPPLEANT	\N	\N
7735	2011CMP5	2011-02-10 00:00:00	2015-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-12 09:39:30
7736	2011CMP5	2011-02-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	TITULAIRE	\N	2014-09-28 18:00:58
7737	2011CMP5	2011-02-10 00:00:00	2015-04-21 00:00:00	ANCIEN	\N	\N	\N	\N	01042P	TITULAIRE	\N	2015-04-21 17:14:30
7738	2011CMP5	2011-02-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95005A	TITULAIRE	\N	2014-09-28 17:40:23
7739	2011CMP5	2011-02-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
7740	2011CMP5	2011-02-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04084N	TITULAIRE	\N	2014-09-28 13:40:33
7741	2011CMP5	2011-02-10 00:00:00	2012-09-19 00:00:00	ANCIEN	\N	\N	\N	\N	95011X	TITULAIRE	\N	\N
7742	2011CMP5	2011-02-10 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08025T	SUPPLEANT	\N	2017-10-01 10:17:18
7743	2011CMP5	2011-02-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	SUPPLEANT	\N	\N
7744	2011CMP5	2011-02-10 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	08064B	SUPPLEANT	\N	\N
7745	2011CMP5	2011-02-10 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	07034Q	SUPPLEANT	\N	\N
7746	2011CMP5	2011-02-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	\N	\N
7747	2011CMP5	2011-02-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	SUPPLEANT	\N	\N
7748	2011CMP5	2011-02-10 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	SUPPLEANT	\N	\N
7303	2010CMP5	2010-05-20 00:00:00	2016-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	07024N	SUPPLEANT	\N	2017-01-03 11:09:24
7361	2010CMP9	2010-07-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92008Q	TITULAIRE	\N	\N
7362	2010CMP9	2010-07-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04078Q	TITULAIRE	\N	2017-09-24 17:15:15
7363	2010CMP9	2010-07-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	59312E	SUPPLEANT	\N	\N
7364	2010CMP9	2010-07-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	04042C	SUPPLEANT	\N	\N
7365	2010CMP9	2010-07-06 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98018T	SUPPLEANT	\N	\N
7366	2010CMP9	2010-07-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04080J	SUPPLEANT	\N	2017-09-24 17:47:27
7367	2010CMP9	2010-07-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04082L	SUPPLEANT	\N	\N
7368	2010CMP9	2010-07-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01023L	SUPPLEANT	\N	\N
7369	2010CMP9	2010-07-06 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	02053W	SUPPLEANT	\N	2014-09-28 12:32:23
7383	2010CMP10	2010-07-06 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08066D	SUPPLEANT	\N	2014-09-28 19:03:23
7400	2010CMP12	2010-10-06 00:00:00	2015-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-12 09:39:30
7401	2010CMP12	2010-10-06 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	95020Y	TITULAIRE	\N	2015-06-12 16:01:25
3686	AFCL	2007-07-27 00:00:00	2010-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	07028S	\N	\N	\N
7505	SOCI	2010-12-08 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	07028S	\N	\N	\N
7506	AFCL	2010-12-08 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	08056B	\N	\N	2014-10-08 16:40:46
717	ECON	2001-10-03 00:00:00	2010-03-31 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	\N	\N	\N
7236	FINC	2010-04-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	\N	\N	2014-10-08 17:09:47
7244	2010CMP3	2010-03-31 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	\N	\N
7546	2010CMP18	2010-12-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	TITULAIRE	\N	2017-09-24 18:20:10
7547	2010CMP18	2010-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04050C	TITULAIRE	\N	\N
7548	2010CMP18	2010-12-16 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	SUPPLEANT	\N	\N
7549	2010CMP18	2010-12-16 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89022N	SUPPLEANT	\N	2014-09-28 18:19:47
7550	2010CMP18	2010-12-16 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	94003T	SUPPLEANT	\N	2014-09-28 13:16:32
6438	COLLECTIVITE	2008-10-15 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	01057W	\N	\N	\N
6439	COLLECTIVITE	2008-10-15 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	08027V	\N	\N	\N
6440	COLLECTIVITE	2008-10-15 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	98027U	\N	\N	\N
6441	COLLECTIVITE	2008-10-15 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	03001N	\N	\N	\N
6442	COLLECTIVITE	2008-10-15 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	97004H	\N	\N	\N
6443	COLLECTIVITE	2008-10-15 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	92029V	\N	\N	\N
6444	COLLECTIVITE	2008-10-15 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	07029T	\N	\N	\N
6445	COLLECTIVITE	2008-10-15 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	01061S	\N	\N	\N
6447	COLLECTIVITE	2008-10-15 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	08009T	\N	\N	\N
6448	COLLECTIVITE	2008-10-15 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	\N	\N	\N
6449	COLLECTIVITE	2008-10-15 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	08061X	\N	\N	\N
6450	COLLECTIVITE	2008-10-15 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	95055L	\N	\N	\N
6451	COLLECTIVITE	2008-10-15 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	07032N	\N	\N	\N
6452	COLLECTIVITE	2008-10-15 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	96006F	\N	\N	\N
6453	COLLECTIVITE	2008-10-15 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	05012A	\N	\N	\N
6454	COLLECTIVITE	2008-10-15 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	04074L	\N	\N	\N
6455	COLLECTIVITE	2008-10-15 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	04033B	\N	\N	\N
6456	COLLECTIVITE	2008-10-15 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	92005M	\N	\N	\N
6457	COLLECTIVITE	2008-10-15 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	\N	\N	\N
6458	COLLECTIVITE	2008-10-15 00:00:00	2009-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	04039H	\N	\N	\N
6708	2009CMP6	2009-04-02 00:00:00	2009-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	08044W	SUPPLEANT	\N	\N
6709	2009CMP6	2009-04-02 00:00:00	2009-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	08039A	SUPPLEANT	\N	\N
6710	2009CMP6	2009-04-02 00:00:00	2009-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	04100U	SUPPLEANT	\N	\N
6711	2009CMP6	2009-04-02 00:00:00	2009-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	85002R	SUPPLEANT	\N	\N
6712	2009CMP6	2009-04-02 00:00:00	2009-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	04033B	SUPPLEANT	\N	\N
6844	2009CMP9	2009-07-01 00:00:00	2019-08-27 00:00:00	ANCIEN	\N	\N	\N	\N	80027E	SUPPLEANT	\N	\N
7654	POLEEMPLOI	2011-02-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08072B	\N	\N	\N
7655	POLEEMPLOI	2011-02-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08060W	\N	\N	\N
7656	POLEEMPLOI	2011-02-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	90003B	\N	\N	\N
7657	POLEEMPLOI	2011-02-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	07001F	\N	\N	\N
7658	POLEEMPLOI	2011-02-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04055H	\N	\N	\N
7659	POLEEMPLOI	2011-02-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	\N	\N	\N
7660	POLEEMPLOI	2011-02-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04046G	\N	\N	\N
7661	POLEEMPLOI	2011-02-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04067M	\N	\N	\N
7662	POLEEMPLOI	2011-02-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08041T	\N	\N	\N
7663	POLEEMPLOI	2011-02-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95035G	\N	\N	\N
7664	POLEEMPLOI	2011-02-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	06001B	\N	\N	\N
7665	POLEEMPLOI	2011-02-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08067E	\N	\N	\N
7666	POLEEMPLOI	2011-02-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10003H	\N	\N	\N
7667	POLEEMPLOI	2011-02-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01043Q	\N	\N	\N
7668	POLEEMPLOI	2011-02-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01060R	\N	\N	\N
7669	POLEEMPLOI	2011-02-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10007M	\N	\N	\N
7670	POLEEMPLOI	2011-02-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	07023M	\N	\N	\N
7671	POLEEMPLOI	2011-02-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98010K	\N	\N	\N
7672	POLEEMPLOI	2011-02-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10015M	\N	\N	\N
7673	POLEEMPLOI	2011-02-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95062K	\N	\N	\N
7674	POLEEMPLOI	2011-02-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01034P	\N	\N	\N
7675	POLEEMPLOI	2011-02-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	\N	\N	\N
7677	2011CMP1	2011-01-19 00:00:00	2015-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-12 09:39:30
7678	2011CMP1	2011-01-19 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	95020Y	TITULAIRE	\N	2015-06-12 16:01:25
7679	2011CMP1	2011-01-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	TITULAIRE	\N	2014-09-28 18:00:58
7384	2010CMP11	2010-09-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04051D	TITULAIRE	\N	2014-09-28 17:07:41
7385	2010CMP11	2010-09-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	95035G	TITULAIRE	\N	2017-09-24 18:17:56
7386	2010CMP11	2010-09-28 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98024R	TITULAIRE	\N	\N
7387	2010CMP11	2010-09-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	04043D	TITULAIRE	\N	\N
7388	2010CMP11	2010-09-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04076N	TITULAIRE	\N	\N
7389	2010CMP11	2010-09-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	04045F	TITULAIRE	\N	\N
3566	2007CMP4	2007-02-07 00:00:00	2007-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	95055L	SUPPLEANT	\N	2014-09-28 13:21:47
4108	2008CMP13	2008-07-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	95004Y	TITULAIRE	\N	\N
3525	2007CMP2	2007-01-25 00:00:00	2007-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	95004Y	TITULAIRE	\N	\N
3386	20061117N51	2006-11-17 00:00:00	2006-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	95004Y	TITULAIRE	\N	\N
2888	20050629N26	2005-06-29 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	95004Y	TITULAIRE	\N	\N
2656	20040727N13	2004-07-27 00:00:00	2015-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-12 09:39:30
3842	2007CMP16	2007-12-14 00:00:00	2007-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	95009E	SUPPLEANT	\N	2014-09-28 12:56:42
3821	2007CMP15	2007-12-11 00:00:00	2007-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	94003T	TITULAIRE	\N	2014-09-28 13:16:32
2807	20050127N21	2005-01-27 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89022N	TITULAIRE	\N	2014-09-28 18:19:47
3042	20051104N31	2005-11-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92044U	SUPPLEANT	\N	2017-09-24 18:16:52
3725	2007CMP11	2007-07-27 00:00:00	2007-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	TITULAIRE	\N	\N
2871	20050504N24	2005-05-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	SUPPLEANT	\N	\N
3073	20051130N33	2005-11-30 00:00:00	2020-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	96004D	SUPPLEANT	\N	\N
2298	20040526N7	2004-05-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	78006D	TITULAIRE	\N	\N
2405	20040715N11	2004-07-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92039X	TITULAIRE	\N	2017-09-24 13:47:46
2163	20031217N12	2003-12-16 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	98032R	TITULAIRE	\N	2015-06-12 15:59:49
2275	20040415N5	2004-04-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95006B	SUPPLEANT	\N	\N
3267	20060405N45	2006-04-05 00:00:00	2006-04-11 00:00:00	ANCIEN	\N	\N	\N	\N	95019G	TITULAIRE	\N	2014-09-28 16:59:41
1923	20030715N6	2003-07-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01006K	SUPPLEANT	\N	\N
1812	20030515N2	2003-05-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01006K	SUPPLEANT	\N	\N
4046	2008CMP8	2008-07-02 00:00:00	2008-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	01008M	SUPPLEANT	\N	2017-09-24 13:44:49
2949	20050707N30	2005-07-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	TITULAIRE	\N	2017-09-24 17:09:24
3749	2007CMP12	2007-07-31 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	01018P	SUPPLEANT	\N	\N
3383	20061115N50	2006-11-23 00:00:00	2006-11-28 00:00:00	ANCIEN	\N	\N	\N	\N	01029S	SUPPLEANT	\N	\N
3170	20060119N38	2006-01-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01029S	TITULAIRE	\N	\N
2322	20040609N8	2004-06-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01029S	SUPPLEANT	\N	\N
3571	2007CMP5	2007-02-12 00:00:00	2007-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	TITULAIRE	\N	2014-09-28 18:00:58
3224	20060119N42	2006-02-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	TITULAIRE	\N	2014-09-28 18:00:58
3568	2007CMP4	2007-02-07 00:00:00	2007-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	SUPPLEANT	\N	\N
6854	2009CMP10	2009-07-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	\N	\N
2909	20050630N27	2005-06-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	04042C	SUPPLEANT	\N	\N
3977	2008CMP6	2008-05-21 00:00:00	2008-06-03 00:00:00	ANCIEN	\N	\N	\N	\N	04046G	TITULAIRE	\N	2014-09-28 17:07:41
3915	2008CMP2	2008-01-24 00:00:00	2008-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	04046G	TITULAIRE	\N	2014-09-28 17:07:41
3033	20051104N31	2005-11-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
3839	2007CMP16	2007-12-14 00:00:00	2007-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	01052R	TITULAIRE	\N	2014-11-04 11:22:47
3195	20060119N40	2006-02-08 00:00:00	2014-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	01052R	TITULAIRE	\N	2014-11-04 11:22:47
3363	20061030N49	2006-10-30 00:00:00	2006-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	96006F	TITULAIRE	\N	2014-09-28 16:50:17
3412	20061214N52	2006-12-12 00:00:00	2006-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	01013J	TITULAIRE	\N	2017-09-24 17:06:55
1821	20030612N3	2003-06-12 00:00:00	2014-07-01 00:00:00	ANCIEN	\N	\N	\N	\N	83011J	TITULAIRE	\N	2014-07-01 09:25:11
4075	2008CMP10	2008-07-09 00:00:00	2008-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	95007C	SUPPLEANT	\N	\N
3130	20051220N37	2005-12-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95007C	SUPPLEANT	\N	\N
3102	20051213N35	2005-12-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95007C	SUPPLEANT	\N	\N
2735	20041221N18	2004-12-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95007C	SUPPLEANT	\N	\N
3765	2007CMP13	2007-10-11 00:00:00	2007-10-16 00:00:00	ANCIEN	\N	\N	\N	\N	01042P	SUPPLEANT	\N	2015-04-21 17:14:30
1797	20030128N1	2003-01-28 00:00:00	2015-04-21 00:00:00	ANCIEN	\N	\N	\N	\N	01042P	SUPPLEANT	\N	2015-04-21 17:14:30
4055	2008CMP9	2008-07-10 00:00:00	2008-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
3570	2007CMP5	2007-02-12 00:00:00	2007-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	TITULAIRE	\N	2017-09-24 13:29:42
3937	2008CMP3	2008-01-31 00:00:00	2008-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	SUPPLEANT	\N	2017-09-24 13:29:42
2011	20031016N9	2003-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	SUPPLEANT	\N	2017-09-24 13:29:42
3721	2007CMP10	2007-07-26 00:00:00	2007-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	01054T	SUPPLEANT	\N	\N
2196	20040123N2	2004-01-23 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	01063U	SUPPLEANT	\N	2014-09-29 13:41:53
2181	20040115N1	2004-01-15 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	01063U	SUPPLEANT	\N	2014-09-29 13:41:53
3607	2007CMP7	2007-02-14 00:00:00	2007-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	02001J	SUPPLEANT	\N	\N
3334	20060616N47	2006-06-16 00:00:00	2006-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	SUPPLEANT	\N	\N
3227	20060119N42	2006-02-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	TITULAIRE	\N	2017-09-24 18:20:10
2661	20040727N13	2004-07-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	SUPPLEANT	\N	2017-09-24 18:20:10
3743	2007CMP12	2007-07-31 00:00:00	2007-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	TITULAIRE	\N	2017-09-24 17:35:15
4109	2008CMP13	2008-07-18 00:00:00	2008-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	95035G	TITULAIRE	\N	2017-09-24 18:17:56
2700	20040712N16	2004-12-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	95035G	TITULAIRE	\N	2017-09-24 18:17:56
3969	2008CMP5	2008-05-14 00:00:00	2008-05-14 00:00:00	ANCIEN	\N	\N	\N	\N	04091M	SUPPLEANT	\N	2014-09-28 17:55:37
2878	20050511N25	2005-05-11 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04065K	TITULAIRE	\N	2014-09-28 17:31:42
2811	20050127N21	2005-01-27 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89007P	SUPPLEANT	\N	2014-09-28 16:42:05
3341	20060615N48	2006-06-15 00:00:00	2006-06-22 00:00:00	ANCIEN	\N	\N	\N	\N	97004H	TITULAIRE	\N	\N
3255	20060307N44	2006-03-07 00:00:00	2006-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	97004H	TITULAIRE	\N	\N
3900	2008CMP1	2008-01-24 00:00:00	2008-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	04043D	TITULAIRE	\N	\N
2721	20041214N17	2004-12-14 00:00:00	2012-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	SUPPLEANT	\N	\N
2953	20050707N30	2005-07-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04067M	SUPPLEANT	\N	2017-09-24 17:47:27
3545	2007CMP3	2007-02-01 00:00:00	2007-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	04070G	TITULAIRE	\N	\N
3537	2007CMP2	2007-01-25 00:00:00	2007-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	04075M	SUPPLEANT	\N	\N
3059	20051118N32	2005-11-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04075M	SUPPLEANT	\N	\N
2918	20050705N28	2005-07-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04081K	TITULAIRE	\N	2017-09-24 19:25:10
3417	20061214N52	2006-12-12 00:00:00	2006-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	SUPPLEANT	\N	\N
3965	2008CMP5	2008-05-14 00:00:00	2008-05-14 00:00:00	ANCIEN	\N	\N	\N	\N	04088S	TITULAIRE	\N	\N
3116	20051215N36	2005-12-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04063H	SUPPLEANT	\N	\N
7300	2010CMP5	2010-05-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	04085P	TITULAIRE	\N	\N
7304	2010CMP5	2010-05-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95013A	SUPPLEANT	\N	\N
7305	2010CMP5	2010-05-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	97004H	SUPPLEANT	\N	\N
7328	2010CMP7	2010-05-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01015L	TITULAIRE	\N	2017-09-24 17:19:42
7329	2010CMP7	2010-05-26 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08042U	SUPPLEANT	\N	2017-10-01 10:20:50
7330	2010CMP7	2010-05-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	08034U	SUPPLEANT	\N	\N
7331	2010CMP7	2010-05-26 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89007P	SUPPLEANT	\N	2014-09-28 16:42:05
7332	2010CMP7	2010-05-26 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04069P	SUPPLEANT	\N	2014-09-28 17:31:41
7333	2010CMP7	2010-05-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	SUPPLEANT	\N	2017-09-24 17:09:24
7334	2010CMP7	2010-05-26 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04065K	SUPPLEANT	\N	2014-09-28 17:31:42
7335	2010CMP7	2010-05-26 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08049C	SUPPLEANT	\N	2014-09-28 19:07:43
7791	2011CMP9	2011-06-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	04047H	SUPPLEANT	\N	\N
7792	2011CMP9	2011-06-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	SUPPLEANT	\N	2017-09-24 17:35:15
7793	2011CMP9	2011-06-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04067M	SUPPLEANT	\N	2017-09-24 17:47:27
7788	2011CMP9	2011-06-14 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	TITULAIRE	\N	2014-09-28 17:07:41
7789	2011CMP9	2011-06-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01011G	TITULAIRE	\N	2017-09-24 16:43:43
7790	2011CMP9	2011-06-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	SUPPLEANT	\N	2017-09-24 13:44:49
7794	2011CMP9	2011-06-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08048B	SUPPLEANT	\N	\N
7795	2011CMP9	2011-06-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01018P	SUPPLEANT	\N	\N
7800	2011CMP8	2011-06-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98050T	TITULAIRE	\N	\N
7798	2011CMP8	2011-06-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95030B	TITULAIRE	\N	2014-09-28 18:58:21
7799	2011CMP8	2011-06-14 00:00:00	2016-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	04048J	TITULAIRE	\N	2016-12-01 10:36:51
7801	2011CMP8	2011-06-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01049W	TITULAIRE	\N	\N
7802	2011CMP8	2011-06-14 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08066D	TITULAIRE	\N	2014-09-28 19:03:23
7803	2011CMP8	2011-06-14 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98037W	TITULAIRE	\N	2014-09-28 14:31:42
7804	2011CMP8	2011-06-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01015L	TITULAIRE	\N	2017-09-24 17:19:42
7813	2011CMP10	2011-06-21 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	TITULAIRE	\N	2014-09-28 18:00:58
7815	2011CMP10	2011-06-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	TITULAIRE	\N	\N
7816	2011CMP10	2011-06-21 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04084N	TITULAIRE	\N	2014-09-28 13:40:33
7817	2011CMP10	2011-06-21 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95055L	TITULAIRE	\N	2014-09-28 13:21:47
7818	2011CMP10	2011-06-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01038T	TITULAIRE	\N	\N
7819	2011CMP10	2011-06-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08025T	SUPPLEANT	\N	2017-10-01 10:17:18
7824	2011CMP10	2011-06-21 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	\N	\N
7825	2011CMP10	2011-06-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	SUPPLEANT	\N	2017-09-24 13:29:42
7845	2011CMP11	2011-04-06 00:00:00	2015-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-12 09:39:30
7846	2011CMP11	2011-04-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01019Q	TITULAIRE	\N	2017-09-24 17:35:15
7848	2011CMP11	2011-04-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	TITULAIRE	\N	2017-09-24 13:29:42
7849	2011CMP11	2011-04-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
7855	2011CMP11	2011-04-06 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08032S	SUPPLEANT	\N	2014-09-28 17:34:16
7856	2011CMP11	2011-04-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	08009T	SUPPLEANT	\N	\N
7857	2011CMP11	2011-04-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01020H	SUPPLEANT	\N	\N
7858	2011CMP11	2011-04-06 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	07034Q	SUPPLEANT	\N	\N
7862	2011CMP12	2011-06-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	TITULAIRE	\N	2017-09-24 13:29:42
7863	2011CMP12	2011-06-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08025T	TITULAIRE	\N	2017-10-01 10:17:18
7864	2011CMP12	2011-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04084N	TITULAIRE	\N	2014-09-28 13:40:33
7865	2011CMP12	2011-06-28 00:00:00	2012-09-19 00:00:00	ANCIEN	\N	\N	\N	\N	95011X	TITULAIRE	\N	\N
7866	2011CMP12	2011-06-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01001E	SUPPLEANT	\N	\N
7867	2011CMP12	2011-06-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04063H	SUPPLEANT	\N	\N
7868	2011CMP12	2011-06-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	04047H	SUPPLEANT	\N	\N
7887	2011CMP14	2011-06-29 00:00:00	2015-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-12 09:39:30
7896	2011CMP14	2011-06-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	08034U	SUPPLEANT	\N	\N
7897	2011CMP14	2011-06-29 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95055L	SUPPLEANT	\N	2014-09-28 13:21:47
7899	2011CMP14	2011-06-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	\N	\N
7906	2011CMP15	2011-06-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	TITULAIRE	\N	\N
7961	2011CMP19	2011-07-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98029W	TITULAIRE	\N	\N
7965	2011CMP19	2011-07-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	SUPPLEANT	\N	2017-09-24 17:35:15
7970	2011CMP19	2011-07-06 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10003H	SUPPLEANT	\N	2014-09-28 17:38:26
7984	2011CMP20	2011-07-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	04043D	SUPPLEANT	\N	\N
8181	ETRD	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98036V	\N	\N	2014-09-28 17:15:42
8182	ECON	2011-10-01 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	01043Q	\N	\N	\N
8183	ETRD	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	77002U	\N	\N	2017-09-24 18:59:59
8184	ETRD	2011-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04040A	\N	\N	2017-10-04 19:51:10
8185	ETRD	2011-10-01 00:00:00	2017-09-21 00:00:00	ANCIEN	\N	\N	\N	\N	95031C	\N	\N	2017-09-22 10:42:23
8186	SOCI	2011-10-01 00:00:00	2012-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	98042T	\N	\N	\N
8187	ETRD	2011-10-01 00:00:00	2011-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	89029V	\N	\N	\N
8188	SOCI	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08020N	\N	\N	2014-09-28 17:03:42
8189	SOCI	2011-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	04041B	\N	\N	2014-10-08 17:33:34
8190	FINC	2011-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	95030B	\N	\N	2014-10-08 17:36:48
8191	FINC	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08034U	\N	\N	2017-10-04 00:00:00
8195	COMSPEAPU	2011-10-01 00:00:00	2015-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	01027Q	\N	\N	2015-12-16 17:18:48
8196	COMSPEAPU	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77043E	\N	\N	2014-09-28 16:59:41
8590	IMPLANTS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08037X	\N	\N	\N
8591	IMPLANTS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08033T	\N	\N	\N
8592	IMPLANTS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11105E	\N	\N	\N
8593	IMPLANTS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	96007G	\N	\N	\N
8594	IMPLANTS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08046Y	\N	\N	\N
8595	IMPLANTS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11055M	\N	\N	\N
8596	IMPLANTS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	07004J	\N	\N	\N
8597	IMPLANTS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11093T	\N	\N	\N
8598	PESTICIDES	2012-02-15 00:00:00	2013-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	\N	\N	\N
8599	PESTICIDES	2012-02-15 00:00:00	2013-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	01008M	\N	\N	\N
8600	PESTICIDES	2012-02-15 00:00:00	2013-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	04073K	\N	\N	\N
8601	PESTICIDES	2012-02-15 00:00:00	2013-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	11103C	\N	\N	\N
8602	PESTICIDES	2012-02-15 00:00:00	2013-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	08069G	\N	\N	\N
8603	PESTICIDES	2012-02-15 00:00:00	2013-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	11049P	\N	\N	\N
8604	PESTICIDES	2012-02-15 00:00:00	2013-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	\N	\N	2018-02-02 10:20:31
8605	PESTICIDES	2012-02-15 00:00:00	2013-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	08015R	\N	\N	\N
8606	PESTICIDES	2012-02-15 00:00:00	2013-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	95047L	\N	\N	\N
8607	PESTICIDES	2012-02-15 00:00:00	2013-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	11090Q	\N	\N	\N
8608	PESTICIDES	2012-02-15 00:00:00	2013-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	04069P	\N	\N	\N
8609	PESTICIDES	2012-02-15 00:00:00	2013-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	04087R	\N	\N	\N
8610	PESTICIDES	2012-02-15 00:00:00	2013-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	08060W	\N	\N	\N
8611	PESTICIDES	2012-02-15 00:00:00	2013-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	08014Q	\N	\N	\N
8612	PESTICIDES	2012-02-15 00:00:00	2013-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	08050U	\N	\N	\N
8613	PESTICIDES	2012-02-15 00:00:00	2013-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	08066D	\N	\N	\N
8614	PESTICIDES	2012-02-15 00:00:00	2013-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	08067E	\N	\N	\N
8615	PESTICIDES	2012-02-15 00:00:00	2013-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	04094Q	\N	\N	\N
8616	PESTICIDES	2012-02-15 00:00:00	2013-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	11067R	\N	\N	\N
8617	PESTICIDES	2012-02-15 00:00:00	2013-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	92039X	\N	\N	\N
7758	2011CMP6	2011-03-31 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95060H	TITULAIRE	\N	\N
7759	2011CMP6	2011-03-31 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08039A	SUPPLEANT	\N	\N
7760	2011CMP6	2011-03-31 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04100U	SUPPLEANT	\N	\N
7761	2011CMP6	2011-03-31 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08020N	SUPPLEANT	\N	2014-09-28 17:03:42
7762	2011CMP6	2011-03-31 00:00:00	\N	ACTIF	\N	\N	\N	\N	01025N	SUPPLEANT	\N	\N
7820	2011CMP10	2011-06-21 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98041S	SUPPLEANT	\N	2014-09-28 16:42:05
7821	2011CMP10	2011-06-21 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	SUPPLEANT	\N	2017-06-19 12:20:59
7822	2011CMP10	2011-06-21 00:00:00	2022-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	92040Q	SUPPLEANT	\N	\N
7823	2011CMP10	2011-06-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	SUPPLEANT	\N	\N
7826	TAXEPRO	2011-06-28 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01013J	\N	\N	\N
7827	TAXEPRO	2011-06-28 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	89013M	\N	\N	\N
7828	TAXEPRO	2011-06-28 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08055A	\N	\N	\N
7829	TAXEPRO	2011-06-28 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08068F	\N	\N	\N
7830	TAXEPRO	2011-06-28 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	\N	\N	\N
7831	TAXEPRO	2011-06-28 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	02002K	\N	\N	\N
7832	TAXEPRO	2011-06-28 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01037S	\N	\N	\N
7833	TAXEPRO	2011-06-28 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	98027U	\N	\N	\N
7834	TAXEPRO	2011-06-28 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01057W	\N	\N	\N
7835	TAXEPRO	2011-06-28 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08027V	\N	\N	\N
7836	TAXEPRO	2011-06-28 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04097T	\N	\N	\N
7837	TAXEPRO	2011-06-28 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	\N	\N	2018-02-02 10:20:31
7838	TAXEPRO	2011-06-28 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	07025P	\N	\N	\N
7839	TAXEPRO	2011-06-28 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08012N	\N	\N	\N
7840	TAXEPRO	2011-06-28 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	\N	\N	\N
7841	TAXEPRO	2011-06-28 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01060R	\N	\N	\N
7842	TAXEPRO	2011-06-28 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	\N	\N	\N
7843	TAXEPRO	2011-06-28 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04070G	\N	\N	\N
7844	TAXEPRO	2011-06-28 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	05012A	\N	\N	\N
8001	FINC	2011-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	11069T	\N	\N	2014-10-08 18:14:13
7551	2010CMP18	2010-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	78006D	SUPPLEANT	\N	\N
7552	2010CMP18	2010-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92043T	SUPPLEANT	\N	\N
7553	2010CMP18	2010-12-16 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	03001N	SUPPLEANT	\N	2014-09-28 13:40:33
7280	2010CMP4	2010-04-08 00:00:00	2015-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-12 09:39:30
7281	2010CMP4	2010-04-08 00:00:00	2016-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	04048J	TITULAIRE	\N	2016-12-01 10:36:51
7282	2010CMP4	2010-04-08 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	07034Q	TITULAIRE	\N	\N
7283	2010CMP4	2010-04-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	TITULAIRE	\N	2017-09-24 13:29:42
7284	2010CMP4	2010-04-08 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	TITULAIRE	\N	\N
7705	AFEU	2011-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11001K	\N	\N	\N
7213	XYNTHIA	2010-03-30 00:00:00	2010-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	89014N	\N	\N	\N
7214	XYNTHIA	2010-03-30 00:00:00	2010-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	01055U	\N	\N	\N
7215	XYNTHIA	2010-03-30 00:00:00	2010-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	98027U	\N	\N	\N
7216	XYNTHIA	2010-03-30 00:00:00	2010-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	04061F	\N	\N	\N
7217	XYNTHIA	2010-03-30 00:00:00	2010-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	08015R	\N	\N	\N
7218	XYNTHIA	2010-03-30 00:00:00	2010-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	08034U	\N	\N	\N
7219	XYNTHIA	2010-03-30 00:00:00	2010-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	08011M	\N	\N	\N
7220	XYNTHIA	2010-03-30 00:00:00	2010-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	\N	\N	\N
7221	XYNTHIA	2010-03-30 00:00:00	2010-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	08060W	\N	\N	\N
7222	XYNTHIA	2010-03-30 00:00:00	2010-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	04082L	\N	\N	\N
7223	XYNTHIA	2010-03-30 00:00:00	2010-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	08025T	\N	\N	\N
7224	XYNTHIA	2010-03-30 00:00:00	2010-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	08058D	\N	\N	\N
7225	XYNTHIA	2010-03-30 00:00:00	2010-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	01012H	\N	\N	\N
7226	XYNTHIA	2010-03-30 00:00:00	2010-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	01053S	\N	\N	\N
7227	XYNTHIA	2010-03-30 00:00:00	2010-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	10003H	\N	\N	\N
7228	XYNTHIA	2010-03-30 00:00:00	2010-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	92042S	\N	\N	\N
7229	XYNTHIA	2010-03-30 00:00:00	2010-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	04083M	\N	\N	\N
7768	2011CMP7	2011-04-27 00:00:00	2015-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-12 09:39:30
7769	2011CMP7	2011-04-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
7770	2011CMP7	2011-04-27 00:00:00	2020-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	08044W	TITULAIRE	\N	\N
7774	2011CMP7	2011-04-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	04085P	TITULAIRE	\N	\N
7775	2011CMP7	2011-04-27 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08025T	SUPPLEANT	\N	2017-10-01 10:17:18
7777	2011CMP7	2011-04-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	SUPPLEANT	\N	\N
7779	2011CMP7	2011-04-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	08034U	SUPPLEANT	\N	\N
7780	2011CMP7	2011-04-27 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	07034Q	SUPPLEANT	\N	\N
7781	2011CMP7	2011-04-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	\N	\N
7805	2011CMP8	2011-06-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	90003B	SUPPLEANT	\N	2017-10-01 10:01:39
7811	2011CMP8	2011-06-14 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	06004E	SUPPLEANT	\N	2014-09-28 17:03:42
7812	2011CMP10	2011-06-21 00:00:00	2015-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-12 09:39:30
8257	2011CMP21	2011-10-20 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
8004	FINC	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11070L	\N	\N	2017-10-04 00:00:00
8005	FINC	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11068S	\N	\N	2017-09-24 18:05:41
8262	2011CMP21	2011-10-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	01057W	TITULAIRE	\N	\N
8007	ECON	2011-10-01 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	11096W	\N	\N	\N
8263	2011CMP21	2011-10-20 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	98032R	TITULAIRE	\N	2015-06-12 15:59:49
8264	2011CMP21	2011-10-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	SUPPLEANT	\N	2017-09-24 18:20:10
8273	TAXEPRO	2011-10-25 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11095V	\N	\N	\N
8274	TAXEPRO	2011-10-25 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11035H	\N	\N	\N
8012	AFCL	2011-10-01 00:00:00	2013-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	11049P	\N	\N	2013-12-17 17:04:43
8013	LOIS	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11035H	\N	\N	2017-09-24 18:16:52
8014	ECON	2011-10-01 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	11036J	\N	\N	\N
8015	AFCL	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11039M	\N	\N	2017-09-24 18:16:52
8275	TAXEPRO	2011-10-25 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	08064B	\N	\N	\N
8017	LOIS	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11037K	\N	\N	2017-09-24 18:16:52
8276	TAXEPRO	2011-10-25 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11034G	\N	\N	\N
8019	FINC	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11040E	\N	\N	2017-10-04 00:00:00
8023	LOIS	2011-10-01 00:00:00	2012-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	11029K	\N	\N	\N
8277	TAXEPRO	2011-10-25 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08034U	\N	\N	\N
8025	SOCI	2011-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	\N	\N	2014-10-08 17:43:48
8278	TAXEPRO	2011-10-25 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04045F	\N	\N	\N
8313	2011CMP24	2011-11-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	TITULAIRE	\N	2017-09-24 17:35:15
8028	ECON	2011-10-01 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	11095V	\N	\N	\N
8029	ECON	2011-10-01 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	11094U	\N	\N	\N
8030	ETRD	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11082Q	\N	\N	2017-09-24 19:16:18
8314	2011CMP24	2011-11-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	TITULAIRE	\N	\N
8032	AFCL	2011-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	11098Y	\N	\N	2014-10-08 17:11:49
8033	ECON	2011-10-01 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	11099A	\N	\N	\N
8034	ECON	2011-10-01 00:00:00	2011-12-22 00:00:00	ANCIEN	\N	\N	\N	\N	11081P	\N	\N	\N
8315	2011CMP24	2011-11-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04066L	TITULAIRE	\N	2017-09-24 17:47:28
8316	2011CMP24	2011-11-14 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10003H	TITULAIRE	\N	2014-09-28 17:38:26
8037	LOIS	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	\N	\N	2017-10-05 00:00:00
8317	2011CMP24	2011-11-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	09001P	TITULAIRE	\N	2017-09-24 17:47:27
8318	2011CMP24	2011-11-14 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04051D	TITULAIRE	\N	2014-09-28 17:07:41
8040	SOCI	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11097X	\N	\N	2017-10-04 00:00:00
8319	2011CMP24	2011-11-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	04092N	TITULAIRE	\N	\N
8320	2011CMP24	2011-11-14 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04046G	SUPPLEANT	\N	2014-09-28 17:07:41
8321	2011CMP24	2011-11-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98024R	SUPPLEANT	\N	\N
8322	2011CMP24	2011-11-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	10006L	SUPPLEANT	\N	\N
8323	2011CMP24	2011-11-14 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	08064B	SUPPLEANT	\N	\N
8324	2011CMP24	2011-11-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01011G	SUPPLEANT	\N	2017-09-24 16:43:43
8325	2011CMP24	2011-11-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	07029T	SUPPLEANT	\N	\N
8326	2011CMP24	2011-11-14 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08026U	SUPPLEANT	\N	2014-09-28 17:52:18
8367	2011CMP25	2011-12-08 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
8050	ETRD	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11106F	\N	\N	2017-09-24 19:14:37
8052	SOCI	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11093T	\N	\N	2017-09-24 12:57:09
8056	SOCI	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11103C	\N	\N	2017-10-04 00:00:00
8059	SOCI	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11112D	\N	\N	2017-09-24 16:45:26
8060	AFCL	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11011M	\N	\N	2017-09-24 10:41:28
7783	2011CMP9	2011-06-14 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04051D	TITULAIRE	\N	2014-09-28 17:07:41
7784	2011CMP9	2011-06-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	04092N	TITULAIRE	\N	\N
7785	2011CMP9	2011-06-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04075M	TITULAIRE	\N	\N
7786	2011CMP9	2011-06-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98029W	TITULAIRE	\N	\N
7787	2011CMP9	2011-06-14 00:00:00	2013-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	95045J	TITULAIRE	\N	\N
7797	2011CMP9	2011-06-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04076N	SUPPLEANT	\N	\N
7809	2011CMP8	2011-06-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	SUPPLEANT	\N	2017-09-24 17:09:24
7814	2011CMP10	2011-06-21 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	07034Q	TITULAIRE	\N	\N
7847	2011CMP11	2011-04-06 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	TITULAIRE	\N	2014-09-28 18:00:58
7852	2011CMP11	2011-04-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	08060W	SUPPLEANT	\N	\N
7853	2011CMP11	2011-04-06 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04073K	SUPPLEANT	\N	2014-09-28 18:58:25
7854	2011CMP11	2011-04-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01033N	SUPPLEANT	\N	\N
7996	AFCL	2011-10-01 00:00:00	2013-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	11090Q	\N	\N	\N
7997	AFCL	2011-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	11074Q	\N	\N	2014-10-08 16:55:52
8061	ECON	2011-10-01 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	11107G	\N	\N	\N
8062	FINC	2011-10-01 00:00:00	2015-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	11108H	\N	\N	2015-04-07 16:50:27
8175	ETRD	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	07003H	\N	\N	2014-09-28 12:21:28
8064	ECON	2011-10-01 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	11111C	\N	\N	\N
8065	FINC	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11110B	\N	\N	2017-10-04 00:00:00
8176	AFCL	2011-10-01 00:00:00	2014-09-16 00:00:00	ANCIEN	\N	\N	\N	\N	98052V	\N	\N	2014-09-16 14:55:28
8177	LOIS	2011-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	01060R	\N	\N	2017-10-24 16:16:39
8178	AFCL	2011-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	92044U	\N	\N	2014-10-08 16:42:08
8069	ECON	2011-10-01 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	11101A	\N	\N	\N
8070	ETRD	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04095R	\N	\N	2017-09-25 10:54:33
8071	ECON	2011-10-01 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	11114F	\N	\N	\N
8072	LOIS	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11113E	\N	\N	2017-09-25 10:54:33
8231	COMSPEAPU	2011-10-01 00:00:00	2012-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	98046X	\N	\N	\N
8258	2011CMP21	2011-10-20 00:00:00	2012-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	TITULAIRE	\N	\N
8076	AFCL	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11071M	\N	\N	2017-09-24 18:16:33
8077	LOIS	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11072N	\N	\N	2017-10-04 00:00:00
8259	2011CMP21	2011-10-20 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	98046X	TITULAIRE	\N	2017-09-25 09:56:00
8260	2011CMP21	2011-10-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	08061X	TITULAIRE	\N	\N
8261	2011CMP21	2011-10-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	11040E	TITULAIRE	\N	\N
8082	ECON	2011-10-01 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	11100Y	\N	\N	\N
8381	2011CMP25	2011-12-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11088W	SUPPLEANT	\N	2017-09-24 17:15:15
8084	ETRD	2011-10-01 00:00:00	2012-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11105E	\N	\N	\N
8086	ETRD	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	11027H	\N	\N	\N
8087	LOIS	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11026G	\N	\N	2017-10-04 00:00:00
8396	2011CMP26	2011-12-19 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
8437	2012CMP2	2012-12-21 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04084N	SUPPLEANT	\N	2014-09-28 13:40:33
8438	2012CMP2	2012-12-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	95063L	SUPPLEANT	\N	\N
8468	EVASION	2012-02-01 00:00:00	2012-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	11029K	\N	\N	2013-12-16 10:26:49
8469	EVASION	2012-02-01 00:00:00	2012-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	95009E	\N	\N	2013-12-16 10:26:49
8093	FINC	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11088W	\N	\N	2017-09-24 17:15:15
8094	LOIS	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	\N	\N	2017-10-04 00:00:00
8095	AFCL	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11089X	\N	\N	2017-09-24 17:15:15
8470	EVASION	2012-02-01 00:00:00	2012-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	11080N	\N	\N	2013-12-16 10:26:49
8097	SOCI	2011-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	11020A	\N	\N	2014-10-08 17:40:09
8098	AFCL	2011-10-01 00:00:00	2014-07-01 00:00:00	ANCIEN	\N	\N	\N	\N	11022C	\N	\N	2014-07-01 09:29:53
8471	EVASION	2012-02-01 00:00:00	2012-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	11088W	\N	\N	2013-12-16 10:26:49
8100	SOCI	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11025F	\N	\N	2017-09-24 16:24:51
8472	EVASION	2012-02-01 00:00:00	2012-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	04071H	\N	\N	2013-12-16 10:26:49
8473	EVASION	2012-02-01 00:00:00	2012-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	01041N	\N	\N	2013-12-16 10:26:49
8474	EVASION	2012-02-01 00:00:00	2012-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	94003T	\N	\N	2013-12-16 10:26:49
8104	SOCI	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11044J	\N	\N	2017-09-24 17:29:37
8105	ETRD	2011-10-01 00:00:00	2012-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	11046L	\N	\N	\N
8106	ECON	2011-10-01 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	11045K	\N	\N	\N
8475	EVASION	2012-02-01 00:00:00	2012-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	08041T	\N	\N	2013-12-16 10:26:49
8108	SOCI	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11061K	\N	\N	2017-09-24 17:42:25
8109	SOCI	2011-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	11059R	\N	\N	2014-10-08 16:53:34
8110	SOCI	2011-10-01 00:00:00	2012-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11062L	\N	\N	\N
8112	SOCI	2011-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	11060J	\N	\N	2014-10-08 17:39:47
8117	AFCL	2011-10-01 00:00:00	2012-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	11056N	\N	\N	\N
7876	2011CMP13	2011-06-27 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	98019U	TITULAIRE	\N	2014-09-29 13:43:10
7877	2011CMP13	2011-06-27 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	98046X	TITULAIRE	\N	2017-09-25 09:56:00
7878	2011CMP13	2011-06-27 00:00:00	2012-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	TITULAIRE	\N	\N
7879	2011CMP13	2011-06-27 00:00:00	2018-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	98053W	TITULAIRE	\N	2018-05-31 10:52:17
7880	2011CMP13	2011-06-27 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08022Q	SUPPLEANT	\N	2017-10-01 09:41:22
7881	2011CMP13	2011-06-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77019E	SUPPLEANT	\N	\N
7882	2011CMP13	2011-06-27 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77043E	SUPPLEANT	\N	2014-09-28 16:59:41
7883	2011CMP13	2011-06-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89017R	SUPPLEANT	\N	\N
7884	2011CMP13	2011-06-27 00:00:00	2013-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	95003X	SUPPLEANT	\N	\N
7885	2011CMP13	2011-06-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92043T	SUPPLEANT	\N	\N
7890	2011CMP14	2011-06-29 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	02001J	TITULAIRE	\N	\N
7891	2011CMP14	2011-06-29 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08071A	TITULAIRE	\N	2014-09-29 09:08:32
7892	2011CMP14	2011-06-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	TITULAIRE	\N	\N
7893	2011CMP14	2011-06-29 00:00:00	2012-09-19 00:00:00	ANCIEN	\N	\N	\N	\N	95011X	TITULAIRE	\N	\N
7894	2011CMP14	2011-06-29 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01001E	SUPPLEANT	\N	\N
7895	2011CMP14	2011-06-29 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	08064B	SUPPLEANT	\N	\N
7900	2011CMP14	2011-06-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	SUPPLEANT	\N	2017-09-24 13:29:42
7910	2011CMP15	2011-06-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	08034U	SUPPLEANT	\N	\N
7911	2011CMP15	2011-06-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95055L	SUPPLEANT	\N	2014-09-28 13:21:47
7912	2011CMP15	2011-06-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98035U	SUPPLEANT	\N	\N
7913	2011CMP15	2011-06-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	\N	\N
7929	2011CMP17	2011-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04051D	TITULAIRE	\N	2014-09-28 17:07:41
7930	2011CMP17	2011-07-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	04043D	TITULAIRE	\N	\N
7931	2011CMP17	2011-07-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01045S	TITULAIRE	\N	\N
7932	2011CMP17	2011-07-01 00:00:00	2018-08-06 00:00:00	ANCIEN	\N	\N	\N	\N	95015C	TITULAIRE	\N	\N
7937	2011CMP17	2011-07-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04081K	SUPPLEANT	\N	2017-09-24 19:25:10
7938	2011CMP17	2011-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04046G	SUPPLEANT	\N	2014-09-28 17:07:41
7957	2011CMP19	2011-07-06 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04051D	TITULAIRE	\N	2014-09-28 17:07:41
7958	2011CMP19	2011-07-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	TITULAIRE	\N	\N
7959	2011CMP19	2011-07-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	95035G	TITULAIRE	\N	2017-09-24 18:17:56
7960	2011CMP19	2011-07-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	04043D	TITULAIRE	\N	\N
7962	2011CMP19	2011-07-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	TITULAIRE	\N	\N
7963	2011CMP19	2011-07-06 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	TITULAIRE	\N	2014-09-28 17:07:41
7964	2011CMP19	2011-07-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	SUPPLEANT	\N	2017-09-24 13:44:49
7966	2011CMP19	2011-07-06 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04046G	SUPPLEANT	\N	2014-09-28 17:07:41
7967	2011CMP19	2011-07-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01033N	SUPPLEANT	\N	\N
7968	2011CMP19	2011-07-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01030K	SUPPLEANT	\N	\N
7969	2011CMP19	2011-07-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04036E	SUPPLEANT	\N	2017-09-24 18:59:59
7983	2011CMP20	2011-07-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04076N	SUPPLEANT	\N	\N
7985	ETRD	2011-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	11010L	\N	\N	2014-10-08 17:18:55
8172	SOCI	2011-10-01 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	09001P	\N	\N	2014-05-05 14:50:38
8192	SOCI	2011-10-01 00:00:00	2012-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	08064B	\N	\N	\N
8193	ECON	2011-10-01 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	05011Y	\N	\N	\N
8197	COMSPEAPU	2011-10-05 00:00:00	2015-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	01013J	\N	\N	2015-12-16 17:18:56
8122	ECON	2011-10-01 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	11066Q	\N	\N	\N
8123	SOCI	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11067R	\N	\N	2017-10-04 00:00:00
8124	ECON	2011-10-01 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	11065P	\N	\N	\N
8213	LOIS	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04056J	\N	\N	2017-09-24 18:17:56
8126	ETRD	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11064N	\N	\N	2017-10-04 00:00:00
8218	ETRD	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98011L	\N	\N	2014-09-28 17:27:35
8129	LOIS	2011-10-01 00:00:00	2012-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	11041F	\N	\N	\N
8219	ETRD	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	90004C	\N	\N	2014-09-28 13:21:47
8220	ETRD	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95052H	\N	\N	2014-09-28 13:39:20
8221	ETRD	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95055L	\N	\N	2014-09-28 13:21:47
8222	ETRD	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08029X	\N	\N	2014-09-28 17:52:18
8223	ETRD	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08071A	\N	\N	2014-09-29 09:08:32
8265	2011CMP21	2011-10-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	08073C	SUPPLEANT	\N	\N
7782	COMSPEAPU	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77019E	\N	\N	\N
7850	2011CMP11	2011-04-06 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	TITULAIRE	\N	\N
7851	2011CMP11	2011-04-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01038T	TITULAIRE	\N	\N
7898	2011CMP14	2011-06-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98035U	SUPPLEANT	\N	\N
7943	2011CMP18	2011-07-05 00:00:00	2015-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-12 09:39:30
7944	2011CMP18	2011-07-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	TITULAIRE	\N	\N
7951	2011CMP18	2011-07-05 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95019G	SUPPLEANT	\N	2014-09-28 16:59:41
7953	2011CMP18	2011-07-05 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04084N	SUPPLEANT	\N	2014-09-28 13:40:33
7954	2011CMP18	2011-07-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	10015M	SUPPLEANT	\N	\N
7956	2011CMP18	2011-07-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	SUPPLEANT	\N	2017-09-24 13:29:42
8266	2011CMP21	2011-10-20 00:00:00	2013-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	95003X	SUPPLEANT	\N	\N
8267	2011CMP21	2011-10-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	88008L	SUPPLEANT	\N	\N
8268	2011CMP21	2011-10-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11088W	SUPPLEANT	\N	2017-09-24 17:15:15
8269	2011CMP21	2011-10-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	04071H	SUPPLEANT	\N	\N
8270	2011CMP21	2011-10-20 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86049M	SUPPLEANT	\N	2014-09-28 18:03:38
8286	2011CMP22	2011-11-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	04085P	TITULAIRE	\N	\N
8146	ECON	2011-10-01 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	11077T	\N	\N	\N
8287	2011CMP22	2011-11-02 00:00:00	2015-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-12 09:39:30
8150	ETRD	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11076S	\N	\N	2017-09-24 17:47:28
8152	SOCI	2011-10-01 00:00:00	2012-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	11032E	\N	\N	\N
8153	SOCI	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11031D	\N	\N	2017-10-04 00:00:00
8154	LOIS	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11034G	\N	\N	2017-09-24 17:55:12
8158	ECON	2011-10-01 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	11051H	\N	\N	\N
8159	ECON	2011-10-01 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	11053K	\N	\N	\N
8289	2011CMP22	2011-11-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	TITULAIRE	\N	2017-09-24 13:29:42
8290	2011CMP22	2011-11-02 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95005A	SUPPLEANT	\N	2014-09-28 17:40:23
8291	2011CMP22	2011-11-02 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08025T	SUPPLEANT	\N	2017-10-01 10:17:18
8165	ECON	2011-10-01 00:00:00	2012-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	11084S	\N	\N	\N
8292	2011CMP22	2011-11-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11030C	SUPPLEANT	\N	2017-09-24 17:09:24
8167	AFCL	2011-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	11083R	\N	\N	2017-10-04 19:42:59
8168	SOCI	2011-10-01 00:00:00	2014-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	11085T	\N	\N	2014-07-16 17:22:41
8293	2011CMP22	2011-11-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	11033F	SUPPLEANT	\N	\N
8294	2011CMP22	2011-11-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11015D	SUPPLEANT	\N	2017-09-24 13:42:35
8295	2011CMP22	2011-11-02 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	SUPPLEANT	\N	2017-06-19 12:20:59
8296	2011CMP22	2011-11-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	10015M	SUPPLEANT	\N	\N
8412	2012CMP1	2011-12-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
8419	2012CMP1	2011-12-21 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	\N	\N
8476	EVASION	2012-02-01 00:00:00	2012-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	07034Q	\N	\N	2013-12-16 10:26:49
8477	EVASION	2012-02-01 00:00:00	2012-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	\N	\N	\N
8478	EVASION	2012-02-01 00:00:00	2012-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	11032E	\N	\N	2013-12-16 10:26:49
8479	EVASION	2012-02-01 00:00:00	2012-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	11042G	\N	\N	2013-12-16 10:26:49
8480	EVASION	2012-02-01 00:00:00	2012-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	11084S	\N	\N	2013-12-16 10:26:49
8481	EVASION	2012-02-01 00:00:00	2012-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	11077T	\N	\N	2013-12-16 10:26:49
8482	EVASION	2012-02-01 00:00:00	2012-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	11066Q	\N	\N	2013-12-16 10:26:49
8483	EVASION	2012-02-01 00:00:00	2012-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	\N	\N	2013-12-16 10:26:49
8484	EVASION	2012-02-01 00:00:00	2012-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	11040E	\N	\N	2013-12-16 10:26:49
8485	EVASION	2012-02-01 00:00:00	2012-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	01013J	\N	\N	2013-12-16 10:26:49
8486	EVASION	2012-02-01 00:00:00	2012-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	88008L	\N	\N	2013-12-16 10:26:49
8487	EVASION	2012-02-01 00:00:00	2012-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	07004J	\N	\N	2013-12-16 10:26:49
8488	EVASION	2012-02-01 00:00:00	2012-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	11064N	\N	\N	2013-12-16 10:26:49
8489	2012CMP5	2012-01-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92015P	TITULAIRE	\N	2017-09-24 13:14:55
8490	2012CMP5	2012-01-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11105E	TITULAIRE	\N	2017-09-24 18:20:10
8497	2012CMP5	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08059E	SUPPLEANT	\N	2014-09-28 17:27:29
8499	2012CMP5	2012-01-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	11080N	SUPPLEANT	\N	\N
7767	AFEU	2008-10-08 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	86030A	\N	\N	\N
7771	2011CMP7	2011-04-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	TITULAIRE	\N	2017-09-24 13:29:42
7772	2011CMP7	2011-04-27 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	TITULAIRE	\N	\N
7773	2011CMP7	2011-04-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
7776	2011CMP7	2011-04-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04063H	SUPPLEANT	\N	\N
7778	2011CMP7	2011-04-27 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	08064B	SUPPLEANT	\N	\N
7806	2011CMP8	2011-06-14 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95009E	SUPPLEANT	\N	2014-09-28 12:56:42
7807	2011CMP8	2011-06-14 00:00:00	2018-12-30 00:00:00	ANCIEN	\N	\N	\N	\N	98023Q	SUPPLEANT	\N	\N
7873	2011CMP13	2011-06-27 00:00:00	2014-07-01 00:00:00	ANCIEN	\N	\N	\N	\N	83011J	TITULAIRE	\N	2014-07-01 09:25:11
7874	2011CMP13	2011-06-27 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
7875	2011CMP13	2011-06-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	01057W	TITULAIRE	\N	\N
7886	2011CMP13	2011-06-27 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	SUPPLEANT	\N	2017-05-16 15:18:13
7889	2011CMP14	2011-06-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	TITULAIRE	\N	\N
7901	2011CMP15	2011-06-30 00:00:00	2015-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-12 09:39:30
7915	2011CMP16	2011-07-01 00:00:00	2015-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-12 09:39:30
7916	2011CMP16	2011-07-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	01063U	TITULAIRE	\N	2014-09-29 13:41:53
7917	2011CMP16	2011-07-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	TITULAIRE	\N	\N
7918	2011CMP16	2011-07-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	02001J	TITULAIRE	\N	\N
7919	2011CMP16	2011-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08071A	TITULAIRE	\N	2014-09-29 09:08:32
7920	2011CMP16	2011-07-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	TITULAIRE	\N	\N
7921	2011CMP16	2011-07-01 00:00:00	2012-09-19 00:00:00	ANCIEN	\N	\N	\N	\N	95011X	TITULAIRE	\N	\N
7922	2011CMP16	2011-07-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01001E	SUPPLEANT	\N	\N
7923	2011CMP16	2011-07-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	08064B	SUPPLEANT	\N	\N
7924	2011CMP16	2011-07-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	08034U	SUPPLEANT	\N	\N
7925	2011CMP16	2011-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95055L	SUPPLEANT	\N	2014-09-28 13:21:47
7927	2011CMP16	2011-07-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	\N	\N
7928	2011CMP16	2011-07-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	SUPPLEANT	\N	2017-09-24 13:29:42
7933	2011CMP17	2011-07-01 00:00:00	2014-09-01 00:00:00	ANCIEN	\N	\N	\N	\N	96007G	TITULAIRE	\N	2014-09-01 10:21:13
7934	2011CMP17	2011-07-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	04045F	TITULAIRE	\N	\N
7935	2011CMP17	2011-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	TITULAIRE	\N	2014-09-28 17:07:41
7936	2011CMP17	2011-07-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	SUPPLEANT	\N	2017-09-24 17:35:15
7939	2011CMP17	2011-07-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	10006L	SUPPLEANT	\N	\N
7940	2011CMP17	2011-07-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	01025N	SUPPLEANT	\N	\N
7971	2011CMP20	2011-07-08 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04051D	TITULAIRE	\N	2014-09-28 17:07:41
7972	2011CMP20	2011-07-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	04092N	TITULAIRE	\N	\N
7973	2011CMP20	2011-07-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77019E	TITULAIRE	\N	\N
7974	2011CMP20	2011-07-08 00:00:00	2013-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	95045J	TITULAIRE	\N	\N
7975	2011CMP20	2011-07-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	TITULAIRE	\N	\N
7976	2011CMP20	2011-07-08 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	TITULAIRE	\N	2014-09-28 17:07:41
7977	2011CMP20	2011-07-08 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08037X	TITULAIRE	\N	2014-09-28 17:34:16
8225	FINC	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	99004R	\N	\N	2017-10-24 00:00:00
8441	2012CMP3	2012-01-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11015D	TITULAIRE	\N	2017-09-24 13:42:35
8464	2012CMP4	2012-01-12 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98030P	SUPPLEANT	\N	2014-09-28 13:19:48
8229	COMSPEAPU	2011-10-01 00:00:00	2012-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	83011J	\N	\N	\N
8230	SOCI	2010-10-07 00:00:00	2013-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	95045J	\N	\N	\N
8299	2011CMP23	2011-11-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11055M	TITULAIRE	\N	2017-09-24 18:07:57
8440	2012CMP3	2012-01-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
8465	2012CMP4	2012-01-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	08009T	SUPPLEANT	\N	\N
8466	2012CMP4	2012-01-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	10015M	SUPPLEANT	\N	\N
8500	2012CMP5	2012-01-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	04042C	SUPPLEANT	\N	\N
8501	2012CMP5	2012-01-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	08047A	SUPPLEANT	\N	\N
8502	2012CMP5	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	06004E	SUPPLEANT	\N	2014-09-28 17:03:42
8525	2012CMP7	2012-01-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11114F	SUPPLEANT	\N	2017-09-25 10:54:33
8526	2012CMP7	2012-01-26 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08049C	SUPPLEANT	\N	2014-09-28 19:07:43
8527	2012CMP7	2012-01-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	11099A	SUPPLEANT	\N	\N
8528	2012CMP7	2012-01-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	05012A	SUPPLEANT	\N	\N
7763	2011CMP6	2011-03-31 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08024S	SUPPLEANT	\N	\N
7764	2011CMP6	2011-03-31 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08055A	SUPPLEANT	\N	\N
7765	2011CMP6	2011-03-31 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08031R	SUPPLEANT	\N	\N
7905	2011CMP15	2011-06-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08071A	TITULAIRE	\N	2014-09-29 09:08:32
7903	2011CMP15	2011-06-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	TITULAIRE	\N	\N
7904	2011CMP15	2011-06-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	02001J	TITULAIRE	\N	\N
7907	2011CMP15	2011-06-30 00:00:00	2012-09-19 00:00:00	ANCIEN	\N	\N	\N	\N	95011X	TITULAIRE	\N	\N
7908	2011CMP15	2011-06-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01001E	SUPPLEANT	\N	\N
7909	2011CMP15	2011-06-30 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	08064B	SUPPLEANT	\N	\N
7945	2011CMP18	2011-07-05 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	TITULAIRE	\N	2014-09-28 18:00:58
7946	2011CMP18	2011-07-05 00:00:00	2015-04-21 00:00:00	ANCIEN	\N	\N	\N	\N	01042P	TITULAIRE	\N	2015-04-21 17:14:30
7947	2011CMP18	2011-07-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08025T	TITULAIRE	\N	2017-10-01 10:17:18
7948	2011CMP18	2011-07-05 00:00:00	2012-09-19 00:00:00	ANCIEN	\N	\N	\N	\N	95011X	TITULAIRE	\N	\N
7949	2011CMP18	2011-07-05 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08032S	TITULAIRE	\N	2014-09-28 17:34:16
7950	2011CMP18	2011-07-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01001E	SUPPLEANT	\N	\N
8174	NEANT	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98006P	\N	\N	2014-09-28 12:54:15
8179	AFCL	2011-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	01052R	\N	\N	2014-10-08 16:42:43
8300	2011CMP23	2011-11-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10003H	TITULAIRE	\N	2014-09-28 17:38:26
8301	2011CMP23	2011-11-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	09001P	TITULAIRE	\N	2017-09-24 17:47:27
8382	2011CMP27	2011-12-19 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
8383	2011CMP27	2011-12-19 00:00:00	2012-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	TITULAIRE	\N	\N
8385	2011CMP27	2011-12-19 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	TITULAIRE	\N	\N
8388	2011CMP27	2011-12-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	11070L	TITULAIRE	\N	\N
8390	2011CMP27	2011-12-19 00:00:00	2015-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	11068S	SUPPLEANT	\N	2015-01-23 15:38:35
8391	2011CMP27	2011-12-19 00:00:00	2015-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	11108H	SUPPLEANT	\N	2015-04-07 16:50:27
8392	2011CMP27	2011-12-19 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	SUPPLEANT	\N	2017-05-16 15:18:13
8394	2011CMP27	2011-12-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	08011M	SUPPLEANT	\N	\N
8395	2011CMP27	2011-12-19 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95030B	SUPPLEANT	\N	2014-09-28 18:58:21
8397	2011CMP26	2011-12-19 00:00:00	2012-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	TITULAIRE	\N	\N
8398	2011CMP26	2011-12-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04066L	TITULAIRE	\N	2017-09-24 17:47:28
8399	2011CMP26	2011-12-19 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	TITULAIRE	\N	\N
8400	2011CMP26	2011-12-19 00:00:00	2018-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	98053W	TITULAIRE	\N	2018-05-31 10:52:17
8401	2011CMP26	2011-12-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11088W	TITULAIRE	\N	2017-09-24 17:15:15
8402	2011CMP26	2011-12-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	11070L	TITULAIRE	\N	\N
8414	2012CMP1	2011-12-21 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08032S	TITULAIRE	\N	2014-09-28 17:34:16
8415	2012CMP1	2011-12-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	11026G	TITULAIRE	\N	\N
8416	2012CMP1	2011-12-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	04085P	TITULAIRE	\N	\N
8417	2012CMP1	2011-12-21 00:00:00	2015-04-21 00:00:00	ANCIEN	\N	\N	\N	\N	01042P	TITULAIRE	\N	2015-04-21 17:14:30
8431	2012CMP2	2012-12-21 00:00:00	2015-04-21 00:00:00	ANCIEN	\N	\N	\N	\N	01042P	TITULAIRE	\N	2015-04-21 17:14:30
8433	2012CMP2	2012-12-21 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	\N	\N
8434	2012CMP2	2012-12-21 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	95020Y	SUPPLEANT	\N	2015-06-12 16:01:25
8529	2012CMP7	2012-01-26 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01064V	SUPPLEANT	\N	2014-09-28 17:12:41
8530	2012CMP7	2012-01-26 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95021A	SUPPLEANT	\N	2014-09-28 16:40:50
8531	ECON	2012-02-07 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	08064B	\N	\N	\N
8555	2012CMP8	2012-02-08 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	SUPPLEANT	\N	2017-06-19 12:20:59
8204	ECON	2011-10-01 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	04094Q	\N	\N	\N
8205	FINC	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08073C	\N	\N	2017-10-04 00:00:00
8206	FINC	2011-10-01 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	08061X	\N	\N	2017-10-04 18:50:14
8208	ECON	2011-10-01 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	07025P	\N	\N	\N
8211	AFCL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08040S	\N	\N	2014-09-28 17:52:18
8212	AFCL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08072B	\N	\N	2014-09-29 09:05:47
8217	AFCL	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	06005F	\N	\N	2014-09-28 13:32:35
8215	AFCL	2011-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	04077P	\N	\N	2014-10-08 17:01:07
8216	AFCL	2011-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	80027E	\N	\N	2014-10-08 16:53:44
8255	AFCL	2011-10-18 00:00:00	2012-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	08070Y	\N	\N	\N
8256	FINC	2011-10-18 00:00:00	2014-08-26 00:00:00	ANCIEN	\N	\N	\N	\N	11018G	\N	\N	2014-08-27 16:33:37
8281	ETRD	2011-11-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	95035G	\N	\N	2017-09-24 18:17:56
8282	SOCI	2011-11-02 00:00:00	2012-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	11003M	\N	\N	\N
8283	2011CMP22	2011-11-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
8284	2011CMP22	2011-11-02 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08032S	TITULAIRE	\N	2014-09-28 17:34:16
8302	2011CMP23	2011-11-07 00:00:00	2013-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	95045J	TITULAIRE	\N	\N
8303	2011CMP23	2011-11-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	01034P	TITULAIRE	\N	\N
8304	2011CMP23	2011-11-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	10006L	SUPPLEANT	\N	\N
8305	2011CMP23	2011-11-07 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	08064B	SUPPLEANT	\N	\N
8306	2011CMP23	2011-11-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11061K	SUPPLEANT	\N	2017-09-24 17:42:25
8307	2011CMP23	2011-11-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08048B	SUPPLEANT	\N	\N
8308	2011CMP23	2011-11-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08037X	SUPPLEANT	\N	2014-09-28 17:34:16
8309	2011CMP23	2011-11-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	04092N	SUPPLEANT	\N	\N
8310	2011CMP23	2011-11-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	04045F	SUPPLEANT	\N	\N
8311	2011CMP23	2011-11-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	TITULAIRE	\N	2017-09-24 17:35:15
8312	2011CMP23	2011-11-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98029W	TITULAIRE	\N	\N
8403	2011CMP26	2011-12-19 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	98046X	SUPPLEANT	\N	2017-09-25 09:56:00
8404	2011CMP26	2011-12-19 00:00:00	2015-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	11108H	SUPPLEANT	\N	2015-04-07 16:50:27
8408	2011CMP26	2011-12-19 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	SUPPLEANT	\N	\N
8406	2011CMP26	2011-12-19 00:00:00	2015-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	11068S	SUPPLEANT	\N	2015-01-23 15:38:35
8409	2011CMP26	2011-12-19 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95030B	SUPPLEANT	\N	2014-09-28 18:58:21
8432	2012CMP2	2012-12-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	TITULAIRE	\N	\N
8411	2011CMP26	2011-12-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	08011M	SUPPLEANT	\N	\N
8443	2012CMP3	2012-01-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	04085P	TITULAIRE	\N	\N
8444	2012CMP3	2012-01-12 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-13 14:23:47
8445	2012CMP3	2012-01-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
8446	2012CMP3	2012-01-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	TITULAIRE	\N	\N
8448	2012CMP3	2012-01-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	\N	\N
8449	2012CMP3	2012-01-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11113E	SUPPLEANT	\N	2017-09-25 10:54:33
8450	2012CMP3	2012-01-12 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	SUPPLEANT	\N	2014-09-28 18:00:58
8451	2012CMP3	2012-01-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98035U	SUPPLEANT	\N	\N
8453	2012CMP3	2012-01-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	SUPPLEANT	\N	2017-09-24 13:29:42
8454	2012CMP4	2012-01-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
8455	2012CMP4	2012-01-12 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04084N	TITULAIRE	\N	2014-09-28 13:40:33
8456	2012CMP4	2012-01-12 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	TITULAIRE	\N	2017-06-19 12:20:59
8457	2012CMP4	2012-01-12 00:00:00	2012-09-19 00:00:00	ANCIEN	\N	\N	\N	\N	95011X	TITULAIRE	\N	\N
7902	2011CMP15	2011-06-30 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	01063U	TITULAIRE	\N	2014-09-29 13:41:53
7942	2011CMP17	2011-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10003H	SUPPLEANT	\N	2014-09-28 17:38:26
7980	2011CMP20	2011-07-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	10006L	SUPPLEANT	\N	\N
7981	2011CMP20	2011-07-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01030K	SUPPLEANT	\N	\N
7982	2011CMP20	2011-07-08 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10003H	SUPPLEANT	\N	2014-09-28 17:38:26
8232	AFEU	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01065W	\N	\N	2014-09-28 12:09:44
8233	AFEU	2011-10-01 00:00:00	2014-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	11039M	\N	\N	2014-10-09 15:39:29
8234	AFEU	2011-10-01 00:00:00	2014-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	11030C	\N	\N	2014-10-09 15:54:45
8235	AFEU	2011-10-01 00:00:00	2011-12-22 00:00:00	ANCIEN	\N	\N	\N	\N	11081P	\N	\N	\N
8239	AFEU	2011-10-01 00:00:00	2014-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	11023D	\N	\N	2014-10-09 15:39:54
8241	AFEU	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11035H	\N	\N	2017-09-24 18:16:52
8242	AFEU	2011-10-01 00:00:00	2017-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	95030B	\N	\N	2017-10-05 11:42:52
8243	AFEU	2011-10-01 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	04035D	\N	\N	2017-10-05 14:40:08
8244	AFEU	2011-10-01 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	11083R	\N	\N	2017-10-05 14:40:15
8245	AFEU	2011-10-01 00:00:00	2014-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	11064N	\N	\N	2014-10-09 15:40:13
8246	AFEU	2011-10-01 00:00:00	2014-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	08044W	\N	\N	2014-10-09 15:40:20
8248	AFEU	2011-10-01 00:00:00	2014-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	01061S	\N	\N	2014-10-09 15:56:30
8249	AFEU	2011-10-01 00:00:00	2013-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	95045J	\N	\N	\N
8250	AFEU	2011-10-01 00:00:00	2014-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	08012N	\N	\N	2014-10-09 15:40:35
8251	AFEU	2011-10-01 00:00:00	2014-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	04070G	\N	\N	2014-10-09 15:57:21
8253	AFEU	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	96006F	\N	\N	2014-09-28 16:50:17
8254	AFEU	2011-10-01 00:00:00	2017-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	\N	\N	2017-10-05 11:43:01
8327	COMAPLEG	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04059M	\N	\N	2014-11-19 17:52:46
8328	COMAPLEG	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	\N	\N	2014-11-19 17:50:38
8329	COMAPLEG	2011-11-30 00:00:00	2012-09-19 00:00:00	ANCIEN	\N	\N	\N	\N	95011X	\N	\N	\N
8330	COMAPLEG	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11029K	\N	\N	2014-11-19 17:50:38
8331	COMAPLEG	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	00003C	\N	\N	2014-11-19 17:51:45
8332	COMAPLEG	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11032E	\N	\N	2014-11-19 17:50:38
8333	COMAPLEG	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95021A	\N	\N	2014-09-28 16:40:50
8334	COMAPLEG	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04081K	\N	\N	2014-11-19 17:50:38
8335	COMAPLEG	2011-11-30 00:00:00	2012-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	98018T	\N	\N	\N
8336	COMAPLEG	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10006L	\N	\N	2014-11-19 17:50:38
8337	COMAPLEG	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11113E	\N	\N	2014-11-19 17:50:38
8338	COMAPLEG	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01024M	\N	\N	2014-11-19 17:50:38
8339	COMAPLEG	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11051H	\N	\N	2014-11-19 17:50:38
8340	COMAPLEG	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04051D	\N	\N	2014-09-28 17:07:41
8341	COMAPLEG	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89007P	\N	\N	2014-09-28 16:42:05
8342	COMAPLEG	2011-11-30 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	08064B	\N	\N	\N
8343	COMAPLEG	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11010L	\N	\N	2014-11-19 17:50:38
8344	COMAPLEG	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	94003T	\N	\N	2014-09-28 13:16:32
8345	COMAPLEG	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	\N	\N	2014-09-28 18:00:58
8346	COMAPLEG	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11089X	\N	\N	2014-11-19 17:50:38
8347	COMAPLEG	2011-11-30 00:00:00	2013-04-23 00:00:00	ANCIEN	\N	\N	\N	\N	11015D	\N	\N	2013-04-24 10:54:05
8348	COMAPLEG	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95038K	\N	\N	2014-09-28 17:40:23
8349	COMAPLEG	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	\N	\N	2014-11-19 17:50:38
8350	COMAPLEG	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08067E	\N	\N	2014-09-28 17:22:11
8351	COMAPLEG	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11084S	\N	\N	2014-11-19 17:50:38
8352	COMAPLEG	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	07029T	\N	\N	2014-11-19 17:50:38
8353	COMAPLEG	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92031P	\N	\N	2014-11-19 17:50:38
8354	COMAPLEG	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11100Y	\N	\N	2014-11-19 17:50:38
8355	COMAPLEG	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11104D	\N	\N	2014-11-19 17:50:38
8356	COMAPLEG	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	\N	\N	2014-11-19 17:50:38
8357	COMAPLEG	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04084N	\N	\N	2014-09-28 13:40:33
8358	COMAPLEG	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08042U	\N	\N	2014-11-19 17:50:38
8359	COMAPLEG	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08026U	\N	\N	2014-09-28 17:52:18
7987	AFCL	2011-10-01 00:00:00	2011-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	01048V	\N	\N	\N
7988	AFCL	2011-10-01 00:00:00	2011-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	11018G	\N	\N	\N
7989	LOIS	2011-10-01 00:00:00	2014-05-06 00:00:00	ANCIEN	\N	\N	\N	\N	11015D	\N	\N	2014-05-07 12:21:27
7990	AFCL	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11014C	\N	\N	2017-09-24 13:14:55
7991	ETRD	2011-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	11012A	\N	\N	2014-10-08 17:08:19
7992	SOCI	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11023D	\N	\N	2017-09-25 10:56:48
7993	LOIS	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11030C	\N	\N	2017-09-24 17:09:24
7994	AFCL	2011-10-01 00:00:00	2014-01-06 00:00:00	ANCIEN	\N	\N	\N	\N	11042G	\N	\N	2014-01-07 10:45:43
7995	AFCL	2011-10-01 00:00:00	2014-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	11057P	\N	\N	2014-07-22 12:08:05
8173	ECON	2011-10-01 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	96003C	\N	\N	\N
7591	MEDIATOR	2011-01-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01034P	\N	\N	\N
8360	COMAPLEG	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95055L	\N	\N	2014-09-28 13:21:47
8361	COMAPLEG	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11093T	\N	\N	2014-11-19 17:50:38
8362	COMAPLEG	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11046L	\N	\N	2014-11-19 17:50:38
8363	COMAPLEG	2011-11-30 00:00:00	2014-05-11 00:00:00	ANCIEN	\N	\N	\N	\N	11045K	\N	\N	2014-05-12 09:52:22
8364	COMAPLEG	2011-11-30 00:00:00	2013-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	86049M	\N	\N	\N
8365	COMAPLEG	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11037K	\N	\N	2014-11-19 18:02:17
8418	2012CMP1	2011-12-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	TITULAIRE	\N	\N
8458	2012CMP4	2012-01-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	04043D	TITULAIRE	\N	\N
8459	2012CMP4	2012-01-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	TITULAIRE	\N	\N
8460	2012CMP4	2012-01-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	08010L	TITULAIRE	\N	\N
8461	2012CMP4	2012-01-12 00:00:00	2020-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	08068F	SUPPLEANT	\N	\N
8462	2012CMP4	2012-01-12 00:00:00	2012-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	SUPPLEANT	\N	\N
8463	2012CMP4	2012-01-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11035H	SUPPLEANT	\N	2017-09-24 18:16:52
8467	2012CMP4	2012-01-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01019Q	SUPPLEANT	\N	2017-09-24 17:35:15
8492	2012CMP5	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95019G	TITULAIRE	\N	2014-09-28 16:59:41
8493	2012CMP5	2012-01-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01056V	TITULAIRE	\N	2017-09-24 17:04:02
8494	2012CMP5	2012-01-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11082Q	TITULAIRE	\N	2017-09-24 19:16:18
8495	2012CMP5	2012-01-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92018S	TITULAIRE	\N	2017-09-24 18:16:52
8496	2012CMP5	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	96006F	SUPPLEANT	\N	2014-09-28 16:50:17
8498	2012CMP5	2012-01-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11076S	SUPPLEANT	\N	2017-09-24 17:47:28
8508	2012CMP6	2012-01-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	04070G	TITULAIRE	\N	\N
8517	2012CMP7	2012-01-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	TITULAIRE	\N	2017-09-24 17:09:24
8518	2012CMP7	2012-01-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01022K	TITULAIRE	\N	2017-09-24 17:14:26
8520	2012CMP7	2012-01-26 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98038X	TITULAIRE	\N	2014-09-28 17:38:26
8521	2012CMP7	2012-01-26 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	90003B	TITULAIRE	\N	2017-10-01 10:01:39
8522	2012CMP7	2012-01-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	11053K	TITULAIRE	\N	\N
8523	2012CMP7	2012-01-26 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95062K	TITULAIRE	\N	\N
8524	2012CMP7	2012-01-26 00:00:00	2020-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	08068F	SUPPLEANT	\N	\N
8534	COUTELEC	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11065P	\N	\N	\N
8535	COUTELEC	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04067M	\N	\N	\N
8536	PESTICIDES	2012-02-15 00:00:00	2013-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	11099A	\N	\N	\N
8537	PESTICIDES	2012-02-15 00:00:00	2013-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	\N	\N	2018-01-25 13:10:11
8538	AGENCES	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01060R	\N	\N	2013-12-16 10:13:19
8544	2012CMP8	2012-02-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
8540	IMPLANTS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	\N	\N	\N
8543	IMPLANTS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01060R	\N	\N	\N
8545	2012CMP8	2012-02-08 00:00:00	2012-09-19 00:00:00	ANCIEN	\N	\N	\N	\N	95011X	TITULAIRE	\N	\N
8547	2012CMP8	2012-02-08 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04084N	TITULAIRE	\N	2014-09-28 13:40:33
8548	2012CMP8	2012-02-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	TITULAIRE	\N	\N
8549	2012CMP8	2012-02-08 00:00:00	2015-04-21 00:00:00	ANCIEN	\N	\N	\N	\N	01042P	TITULAIRE	\N	2015-04-21 17:14:30
8550	2012CMP8	2012-02-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
8551	2012CMP8	2012-02-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	05008E	SUPPLEANT	\N	\N
8552	2012CMP8	2012-02-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	11033F	SUPPLEANT	\N	\N
8553	2012CMP8	2012-02-08 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	SUPPLEANT	\N	2015-10-13 14:23:43
8554	2012CMP8	2012-02-08 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08032S	SUPPLEANT	\N	2014-09-28 17:34:16
7752	2011CMP6	2011-03-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92031P	TITULAIRE	\N	2017-09-24 18:16:52
7753	2011CMP6	2011-03-31 00:00:00	\N	ACTIF	\N	\N	\N	\N	04057K	TITULAIRE	\N	\N
7754	2011CMP6	2011-03-31 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	07033P	TITULAIRE	\N	\N
7755	2011CMP6	2011-03-31 00:00:00	\N	ACTIF	\N	\N	\N	\N	04070G	TITULAIRE	\N	\N
7756	2011CMP6	2011-03-31 00:00:00	\N	ACTIF	\N	\N	\N	\N	04059M	TITULAIRE	\N	\N
7757	2011CMP6	2011-03-31 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	97004H	TITULAIRE	\N	\N
7859	2011CMP12	2011-06-28 00:00:00	2015-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-12 09:39:30
7860	2011CMP12	2011-06-28 00:00:00	2015-04-21 00:00:00	ANCIEN	\N	\N	\N	\N	01042P	TITULAIRE	\N	2015-04-21 17:14:30
7861	2011CMP12	2011-06-28 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	07034Q	TITULAIRE	\N	\N
7869	2011CMP12	2011-06-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	SUPPLEANT	\N	\N
7870	2011CMP12	2011-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08032S	SUPPLEANT	\N	2014-09-28 17:34:16
7871	2011CMP12	2011-06-28 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	SUPPLEANT	\N	2017-06-19 12:20:59
7872	2011CMP12	2011-06-28 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	\N	\N
8368	2011CMP25	2011-12-08 00:00:00	2012-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	TITULAIRE	\N	\N
8369	2011CMP25	2011-12-08 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	98046X	TITULAIRE	\N	2017-09-25 09:56:00
8370	2011CMP25	2011-12-08 00:00:00	2014-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	01062T	TITULAIRE	\N	2014-12-18 16:15:04
8371	2011CMP25	2011-12-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	11040E	TITULAIRE	\N	\N
8372	2011CMP25	2011-12-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	08011M	TITULAIRE	\N	\N
8373	2011CMP25	2011-12-08 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	98032R	TITULAIRE	\N	2015-06-12 15:59:49
8374	2011CMP25	2011-12-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	11110B	SUPPLEANT	\N	\N
8375	2011CMP25	2011-12-08 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	11069T	SUPPLEANT	\N	2016-03-11 18:02:50
8376	2011CMP25	2011-12-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04066L	SUPPLEANT	\N	2017-09-24 17:47:28
8377	2011CMP25	2011-12-08 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	SUPPLEANT	\N	2017-05-16 15:18:13
8378	2011CMP25	2011-12-08 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	SUPPLEANT	\N	\N
8420	2012CMP1	2011-12-21 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	95020Y	SUPPLEANT	\N	2015-06-12 16:01:25
8380	2011CMP25	2011-12-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	99004R	SUPPLEANT	\N	\N
8422	2012CMP1	2011-12-21 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	SUPPLEANT	\N	2015-10-13 14:23:51
8423	2012CMP1	2011-12-21 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04084N	SUPPLEANT	\N	2014-09-28 13:40:33
8424	2012CMP1	2011-12-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	95063L	SUPPLEANT	\N	\N
8425	2012CMP1	2011-12-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	SUPPLEANT	\N	2017-09-24 13:29:42
8426	2012CMP2	2012-12-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
8427	2012CMP2	2012-12-21 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08032S	TITULAIRE	\N	2014-09-28 17:34:16
8428	2012CMP2	2012-12-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	11026G	TITULAIRE	\N	\N
8429	2012CMP2	2012-12-21 00:00:00	2012-09-19 00:00:00	ANCIEN	\N	\N	\N	\N	95011X	TITULAIRE	\N	\N
8430	2012CMP2	2012-12-21 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	07034Q	TITULAIRE	\N	\N
8435	2012CMP2	2012-12-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11035H	SUPPLEANT	\N	2017-09-24 18:16:52
8436	2012CMP2	2012-12-21 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	SUPPLEANT	\N	2015-10-13 14:23:22
8439	2012CMP2	2012-12-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	SUPPLEANT	\N	2017-09-24 13:29:42
8503	2012CMP6	2012-01-25 00:00:00	2017-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	01044R	TITULAIRE	\N	2017-07-04 15:08:09
8504	2012CMP6	2012-01-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04077P	TITULAIRE	\N	2017-09-24 17:47:27
8505	2012CMP6	2012-01-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11089X	TITULAIRE	\N	2017-09-24 17:15:15
8507	2012CMP6	2012-01-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11091R	TITULAIRE	\N	2017-09-24 18:17:56
8509	2012CMP6	2012-01-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	11056N	TITULAIRE	\N	\N
8510	2012CMP6	2012-01-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08024S	SUPPLEANT	\N	\N
8511	2012CMP6	2012-01-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	11083R	SUPPLEANT	\N	\N
8512	2012CMP6	2012-01-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	04057K	SUPPLEANT	\N	\N
8513	2012CMP6	2012-01-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	08012N	SUPPLEANT	\N	\N
8514	2012CMP6	2012-01-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11014C	SUPPLEANT	\N	2017-09-24 13:14:55
8515	2012CMP6	2012-01-25 00:00:00	2022-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	92040Q	SUPPLEANT	\N	\N
8516	2012CMP6	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98010K	SUPPLEANT	\N	2014-09-28 17:27:35
8541	INONDATIONS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11065P	\N	\N	\N
8542	AGENCES	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11076S	\N	\N	2013-12-16 10:13:19
7230	XYNTHIA	2010-03-30 00:00:00	2010-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	01050P	\N	\N	\N
7231	XYNTHIA	2010-03-30 00:00:00	2010-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	01013J	\N	\N	\N
7232	XYNTHIA	2010-03-30 00:00:00	2010-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	98038X	\N	\N	\N
7233	XYNTHIA	2010-03-30 00:00:00	2010-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	\N	\N	\N
7234	XYNTHIA	2010-03-30 00:00:00	2010-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	04033B	\N	\N	\N
7235	XYNTHIA	2010-03-30 00:00:00	2010-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	95021A	\N	\N	\N
7593	RGPP	2011-01-11 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	\N	\N	\N
7594	RGPP	2011-01-11 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	01008M	\N	\N	\N
7595	RGPP	2011-01-11 00:00:00	2011-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	01013J	\N	\N	\N
2197	20040123N2	2004-01-23 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	95020Y	SUPPLEANT	\N	2015-06-12 16:01:25
2714	20041214N17	2004-12-14 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77043E	TITULAIRE	\N	2014-09-28 16:59:41
2845	20050503N23	2005-05-03 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95038K	TITULAIRE	\N	2014-09-28 17:40:23
2791	20050119N20	2005-01-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92011K	TITULAIRE	\N	\N
8773	2012CMP9	2012-02-15 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	SUPPLEANT	\N	\N
8774	2012CMP9	2012-02-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04084N	SUPPLEANT	\N	2014-09-28 13:40:33
8902	2012CMP15	2012-09-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	TITULAIRE	\N	2017-09-24 17:35:15
8903	2012CMP15	2012-09-26 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08067E	TITULAIRE	\N	2014-09-28 17:22:11
8910	2012CMP15	2012-09-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08024S	SUPPLEANT	\N	\N
8914	2012CMP15	2012-09-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11093T	SUPPLEANT	\N	2017-09-24 12:57:09
8916	2012CMP16	2012-09-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	TITULAIRE	\N	2017-09-24 17:09:24
8917	2012CMP16	2012-09-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08055A	TITULAIRE	\N	\N
8918	2012CMP16	2012-09-27 00:00:00	2015-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	11051H	TITULAIRE	\N	2015-03-03 10:16:55
8919	2012CMP16	2012-09-27 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08054Y	TITULAIRE	\N	2014-09-28 12:39:09
8920	2012CMP16	2012-09-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	TITULAIRE	\N	\N
8921	2012CMP16	2012-09-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	11101A	TITULAIRE	\N	\N
8922	2012CMP16	2012-09-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04089T	TITULAIRE	\N	\N
8923	2012CMP16	2012-09-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11096W	SUPPLEANT	\N	2017-09-24 18:17:56
8928	2012CMP16	2012-09-27 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95038K	SUPPLEANT	\N	2014-09-28 17:40:23
8929	2012CMP16	2012-09-27 00:00:00	2016-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	04048J	SUPPLEANT	\N	2016-12-01 10:36:51
8930	COMSPEAPU	2012-10-03 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	11068S	\N	\N	2014-10-08 19:03:44
8931	COMSPEAPU	2012-10-03 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	11070L	\N	\N	2014-10-08 19:03:52
8932	COMSPEAPU	2012-10-09 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	01037S	\N	\N	2014-10-08 19:03:58
8911	2012CMP15	2012-09-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04067M	SUPPLEANT	\N	2017-09-24 17:47:27
8912	2012CMP15	2012-09-26 00:00:00	2020-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	08041T	SUPPLEANT	\N	\N
8913	2012CMP15	2012-09-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01011G	SUPPLEANT	\N	2017-09-24 16:43:43
8941	2012CMP17	2012-10-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	11072N	TITULAIRE	\N	\N
8942	2012CMP17	2012-10-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98038X	TITULAIRE	\N	2014-09-28 17:38:26
9470	2013CMP10	2013-07-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	11040E	TITULAIRE	\N	\N
8943	2012CMP17	2012-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01027Q	TITULAIRE	\N	2017-09-24 17:28:55
8966	2012CMP18	2012-11-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11088W	SUPPLEANT	\N	2017-09-24 17:15:15
8967	CAE	2012-11-12 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04083M	\N	\N	2014-09-28 16:40:50
8968	CDD	2012-11-12 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	11053K	\N	\N	2014-05-05 14:50:04
8970	SOCI	2012-11-13 00:00:00	2013-02-28 00:00:00	ANCIEN	\N	\N	\N	\N	11062L	\N	\N	\N
8972	2012CMP19	2012-11-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	TITULAIRE	\N	\N
8973	2012CMP19	2012-11-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01011G	TITULAIRE	\N	2017-09-24 16:43:43
8974	2012CMP19	2012-11-20 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10003H	TITULAIRE	\N	2014-09-28 17:38:26
8975	2012CMP19	2012-11-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	04092N	TITULAIRE	\N	\N
8977	2012CMP19	2012-11-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	01034P	TITULAIRE	\N	\N
8978	2012CMP19	2012-11-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	10006L	SUPPLEANT	\N	\N
9045	2012CMP24	2012-12-13 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
9046	2012CMP24	2012-12-13 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	98046X	TITULAIRE	\N	2017-09-25 09:56:00
9047	2012CMP24	2012-12-13 00:00:00	2015-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	11108H	TITULAIRE	\N	2015-04-07 16:50:27
9048	2012CMP24	2012-12-13 00:00:00	2014-08-26 00:00:00	ANCIEN	\N	\N	\N	\N	11018G	TITULAIRE	\N	2014-08-27 16:33:37
9049	2012CMP24	2012-12-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01013J	TITULAIRE	\N	2017-09-24 17:06:55
9050	2012CMP24	2012-12-13 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77043E	TITULAIRE	\N	2014-09-28 16:59:41
9055	2012CMP24	2012-12-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08014Q	SUPPLEANT	\N	\N
9056	2012CMP24	2012-12-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	08011M	SUPPLEANT	\N	\N
9076	2012CMP25	2012-12-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	04085P	TITULAIRE	\N	\N
9077	2012CMP25	2012-12-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
9078	2012CMP25	2012-12-13 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-13 14:23:26
9079	2012CMP25	2012-12-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	11026G	TITULAIRE	\N	\N
9080	2012CMP25	2012-12-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	TITULAIRE	\N	2017-09-24 13:29:42
9082	2012CMP25	2012-12-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	11033F	SUPPLEANT	\N	\N
9083	2012CMP25	2012-12-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	SUPPLEANT	\N	\N
9084	2012CMP25	2012-12-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	08018U	SUPPLEANT	\N	\N
9085	2012CMP25	2012-12-13 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08032S	SUPPLEANT	\N	2014-09-28 17:34:16
9074	2012CMP25	2012-12-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
9075	2012CMP25	2012-12-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11015D	TITULAIRE	\N	2017-09-24 13:42:35
9086	2012CMP25	2012-12-13 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04084N	SUPPLEANT	\N	2014-09-28 13:40:33
9091	2012CMP27	2012-12-18 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08033T	TITULAIRE	\N	2014-09-28 17:27:35
9089	2012CMP27	2012-12-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	TITULAIRE	\N	2017-09-24 17:09:24
9092	2012CMP27	2012-12-18 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08054Y	TITULAIRE	\N	2014-09-28 12:39:09
9093	2012CMP27	2012-12-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11100Y	TITULAIRE	\N	2017-09-24 13:57:40
9094	2012CMP27	2012-12-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98050T	TITULAIRE	\N	\N
9095	2012CMP27	2012-12-18 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04083M	TITULAIRE	\N	2014-09-28 16:40:50
9096	2012CMP27	2012-12-18 00:00:00	2020-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	08068F	SUPPLEANT	\N	\N
9097	2012CMP27	2012-12-18 00:00:00	2015-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	11051H	SUPPLEANT	\N	2015-03-03 10:16:55
9099	2012CMP27	2012-12-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	11012A	SUPPLEANT	\N	\N
9100	2012CMP27	2012-12-18 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	90003B	SUPPLEANT	\N	2017-10-01 10:01:39
9102	2012CMP27	2012-12-18 00:00:00	2016-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	04048J	SUPPLEANT	\N	2016-12-01 10:36:51
9103	2012CMP26	2012-12-15 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
9104	2012CMP26	2012-12-15 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	98046X	TITULAIRE	\N	2017-09-25 09:56:00
9105	2012CMP26	2012-12-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	TITULAIRE	\N	2017-09-24 18:20:10
8820	LOIS	2012-06-17 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	12035A	\N	\N	2014-05-05 10:34:09
8868	2012CMP14	2012-07-26 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08022Q	TITULAIRE	\N	2017-10-01 09:41:22
8869	2012CMP14	2012-07-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	11070L	TITULAIRE	\N	\N
8971	2012CMP19	2012-11-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	TITULAIRE	\N	2017-09-24 17:35:15
8976	2012CMP19	2012-11-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	11097X	TITULAIRE	\N	\N
8980	2012CMP19	2012-11-20 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08037X	SUPPLEANT	\N	2014-09-28 17:34:16
8981	2012CMP19	2012-11-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	11067R	SUPPLEANT	\N	\N
8983	2012CMP19	2012-11-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	04043D	SUPPLEANT	\N	\N
8985	NEANT	2012-12-03 00:00:00	2012-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	12042Y	\N	\N	\N
9107	2012CMP26	2012-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	11040E	TITULAIRE	\N	\N
9108	2012CMP26	2012-12-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11088W	TITULAIRE	\N	2017-09-24 17:15:15
9109	2012CMP26	2012-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	11070L	TITULAIRE	\N	\N
9110	2012CMP26	2012-12-15 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	01037S	SUPPLEANT	\N	2016-12-12 16:10:15
9111	2012CMP26	2012-12-15 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	SUPPLEANT	\N	\N
9112	2012CMP26	2012-12-15 00:00:00	2013-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	95003X	SUPPLEANT	\N	\N
9113	2012CMP26	2012-12-15 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	88008L	SUPPLEANT	\N	\N
9121	AFCL	2013-02-13 00:00:00	2013-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	13001T	\N	\N	\N
9355	COMAPLEG	2013-01-16 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08022Q	\N	2013-06-03 11:57:10	2014-11-19 17:50:38
9357	NEANT	2013-06-29 00:00:00	2013-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	13003V	\N	2013-07-01 09:35:52	2013-07-09 10:44:47
9358	SOCI	2013-07-09 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13003V	\N	2013-07-09 10:44:50	2014-09-28 17:14:21
9360	SOCI	2013-07-15 00:00:00	2013-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	98030P	\N	2013-07-15 18:33:09	2013-11-19 11:24:29
9361	AFCL	2013-07-15 00:00:00	2013-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	08035V	\N	2013-07-15 18:34:02	2013-12-04 11:25:30
9363	NEANT	2013-10-01 00:00:00	2013-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	13005X	\N	2013-10-01 15:26:12	2013-10-09 16:53:18
9366	SPORTS	2013-10-02 00:00:00	2014-05-01 00:00:00	ANCIEN	\N	\N	\N	\N	11039M	\N	\N	2014-11-18 15:42:14
9367	SPORTS	2013-10-02 00:00:00	2014-05-01 00:00:00	ANCIEN	\N	\N	\N	\N	13003V	\N	\N	2014-11-18 15:42:14
9368	SPORTS	2013-10-02 00:00:00	2014-05-01 00:00:00	ANCIEN	\N	\N	\N	\N	11029K	\N	\N	2014-11-18 15:42:14
9369	SPORTS	2013-10-02 00:00:00	2014-05-01 00:00:00	ANCIEN	\N	\N	\N	\N	01052R	\N	\N	2014-11-18 15:42:14
9370	SPORTS	2013-10-02 00:00:00	2014-05-01 00:00:00	ANCIEN	\N	\N	\N	\N	04073K	\N	\N	2014-11-18 15:42:14
9371	SPORTS	2013-10-02 00:00:00	2014-05-01 00:00:00	ANCIEN	\N	\N	\N	\N	08024S	\N	\N	2014-11-18 15:42:14
9372	SPORTS	2013-10-02 00:00:00	2014-05-01 00:00:00	ANCIEN	\N	\N	\N	\N	90003B	\N	\N	2014-11-18 15:42:14
9373	SPORTS	2013-10-02 00:00:00	2014-05-01 00:00:00	ANCIEN	\N	\N	\N	\N	95021A	\N	\N	2014-11-18 15:42:14
9374	SPORTS	2013-10-02 00:00:00	2014-05-01 00:00:00	ANCIEN	\N	\N	\N	\N	11088W	\N	\N	2014-11-18 15:42:14
9375	SPORTS	2013-10-02 00:00:00	2014-05-01 00:00:00	ANCIEN	\N	\N	\N	\N	11035H	\N	\N	2014-11-18 15:42:14
9376	SPORTS	2013-10-02 00:00:00	2014-05-01 00:00:00	ANCIEN	\N	\N	\N	\N	92018S	\N	\N	2014-11-18 15:42:14
9377	SPORTS	2013-10-02 00:00:00	2014-05-01 00:00:00	ANCIEN	\N	\N	\N	\N	87003B	\N	\N	2014-11-18 15:42:14
9378	SPORTS	2013-10-02 00:00:00	2014-05-01 00:00:00	ANCIEN	\N	\N	\N	\N	89007P	\N	\N	2014-11-18 15:42:14
9379	SPORTS	2013-10-02 00:00:00	2014-05-01 00:00:00	ANCIEN	\N	\N	\N	\N	98028V	\N	\N	2014-11-18 15:42:14
9380	SPORTS	2013-10-02 00:00:00	2014-05-01 00:00:00	ANCIEN	\N	\N	\N	\N	11098Y	\N	\N	2014-11-18 15:42:14
9381	SPORTS	2013-10-02 00:00:00	2014-05-01 00:00:00	ANCIEN	\N	\N	\N	\N	08012N	\N	\N	2014-11-18 15:42:14
9382	SPORTS	2013-10-02 00:00:00	2014-05-01 00:00:00	ANCIEN	\N	\N	\N	\N	95047L	\N	\N	2014-11-18 15:42:14
9383	SPORTS	2013-10-02 00:00:00	2014-05-01 00:00:00	ANCIEN	\N	\N	\N	\N	12039E	\N	\N	2014-11-18 15:42:14
9384	SPORTS	2013-10-02 00:00:00	2014-05-01 00:00:00	ANCIEN	\N	\N	\N	\N	08053X	\N	\N	2014-11-18 15:42:14
9385	SPORTS	2013-10-02 00:00:00	2014-05-01 00:00:00	ANCIEN	\N	\N	\N	\N	11014C	\N	\N	2014-11-18 15:42:14
9386	SPORTS	2013-10-02 00:00:00	2014-05-01 00:00:00	ANCIEN	\N	\N	\N	\N	11105E	\N	\N	2014-11-18 15:42:14
9387	SPORTS	2013-10-02 00:00:00	2014-05-01 00:00:00	ANCIEN	\N	\N	\N	\N	13002U	\N	\N	2014-11-18 15:42:14
9388	SPORTS	2013-10-02 00:00:00	2014-05-01 00:00:00	ANCIEN	\N	\N	\N	\N	01019Q	\N	\N	2014-11-18 15:42:14
9389	SPORTS	2013-10-02 00:00:00	2014-05-01 00:00:00	ANCIEN	\N	\N	\N	\N	11043H	\N	\N	2014-11-18 15:42:14
9390	SPORTS	2013-10-02 00:00:00	2014-05-01 00:00:00	ANCIEN	\N	\N	\N	\N	06004E	\N	\N	2014-11-18 15:42:14
9391	SPORTS	2013-10-02 00:00:00	2014-05-01 00:00:00	ANCIEN	\N	\N	\N	\N	01034P	\N	\N	2014-11-18 15:42:14
9392	SPORTS	2013-10-02 00:00:00	2014-05-01 00:00:00	ANCIEN	\N	\N	\N	\N	11057P	\N	\N	2014-11-18 15:42:14
9393	COMSPEAPU	2013-10-02 00:00:00	2015-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	11012A	\N	2013-10-03 18:07:44	2015-12-16 17:19:00
9409	2013CMP6	2013-04-17 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08067E	TITULAIRE	\N	2014-09-28 17:22:11
9410	2013CMP6	2013-04-17 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04046G	TITULAIRE	\N	2014-09-28 17:07:41
9411	2013CMP6	2013-04-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11061K	TITULAIRE	\N	2017-09-24 17:42:25
9412	2013CMP6	2013-04-17 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	11063M	TITULAIRE	\N	\N
9413	2013CMP6	2013-04-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	11103C	TITULAIRE	\N	\N
9414	2013CMP6	2013-04-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	11097X	TITULAIRE	\N	\N
9415	2013CMP6	2013-04-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	01034P	TITULAIRE	\N	\N
9416	2013CMP6	2013-04-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	SUPPLEANT	\N	2017-09-24 13:44:49
9417	2013CMP6	2013-04-17 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08020N	SUPPLEANT	\N	2014-09-28 17:03:42
9418	2013CMP6	2013-04-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04081K	SUPPLEANT	\N	2017-09-24 19:25:10
9419	2013CMP6	2013-04-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04067M	SUPPLEANT	\N	2017-09-24 17:47:27
9421	2013CMP6	2013-04-17 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10003H	SUPPLEANT	\N	2014-09-28 17:38:26
9422	2013CMP6	2013-04-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	04045F	SUPPLEANT	\N	\N
9423	2013CMP7	2013-05-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
9424	2013CMP7	2013-05-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	11026G	TITULAIRE	\N	\N
9425	2013CMP7	2013-05-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04056J	TITULAIRE	\N	2017-09-24 18:17:56
9426	2013CMP7	2013-05-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	04085P	TITULAIRE	\N	\N
9427	2013CMP7	2013-05-16 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-13 14:23:05
9428	2013CMP7	2013-05-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	08018U	TITULAIRE	\N	\N
9429	2013CMP7	2013-05-16 00:00:00	2014-04-23 00:00:00	ANCIEN	\N	\N	\N	\N	95049N	TITULAIRE	\N	2014-04-23 09:56:25
9430	2013CMP7	2013-05-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	\N	\N
9431	2013CMP7	2013-05-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	08010L	SUPPLEANT	\N	\N
9432	2013CMP7	2013-05-16 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	12035A	SUPPLEANT	\N	2014-05-05 10:34:09
9433	2013CMP7	2013-05-16 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04084N	SUPPLEANT	\N	2014-09-28 13:40:33
9434	2013CMP7	2013-05-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	95063L	SUPPLEANT	\N	\N
9435	2013CMP7	2013-05-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	\N	\N
9436	2013CMP7	2013-05-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	SUPPLEANT	\N	2017-09-24 13:29:42
9437	2013CMP8	2013-06-05 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08049C	TITULAIRE	\N	2014-09-28 19:07:43
9439	2013CMP8	2013-06-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80013X	TITULAIRE	\N	\N
9440	2013CMP8	2013-06-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	11065P	TITULAIRE	\N	\N
9441	2013CMP8	2013-06-05 00:00:00	2020-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	96004D	TITULAIRE	\N	\N
9442	2013CMP8	2013-06-05 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95036H	TITULAIRE	\N	2014-09-28 17:31:42
9444	2013CMP8	2013-06-05 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04065K	SUPPLEANT	\N	2014-09-28 17:31:42
9445	2013CMP8	2013-06-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11107G	SUPPLEANT	\N	2017-09-24 17:06:55
9446	2013CMP8	2013-06-05 00:00:00	2014-05-11 00:00:00	ANCIEN	\N	\N	\N	\N	11045K	SUPPLEANT	\N	2014-05-12 09:52:22
9447	2013CMP8	2013-06-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01015L	SUPPLEANT	\N	2017-09-24 17:19:42
9448	2013CMP8	2013-06-05 00:00:00	2018-12-30 00:00:00	ANCIEN	\N	\N	\N	\N	98023Q	SUPPLEANT	\N	\N
9449	2013CMP8	2013-06-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	05012A	SUPPLEANT	\N	\N
9450	2013CMP8	2013-06-05 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95062K	SUPPLEANT	\N	\N
9465	CDD	2013-10-09 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13005X	\N	2013-10-09 16:53:24	2014-09-28 18:00:58
9466	2013CMP10	2013-07-04 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
9467	2013CMP10	2013-07-04 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	TITULAIRE	\N	\N
9469	2013CMP10	2013-07-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	11072N	TITULAIRE	\N	\N
9471	2013CMP10	2013-07-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	08011M	TITULAIRE	\N	\N
9472	2013CMP10	2013-07-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	11070L	TITULAIRE	\N	\N
9473	2013CMP10	2013-07-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	11066Q	SUPPLEANT	\N	\N
9475	2013CMP10	2013-07-04 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95037J	SUPPLEANT	\N	\N
9476	2013CMP10	2013-07-04 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	SUPPLEANT	\N	2017-05-16 15:18:13
9477	2013CMP10	2013-07-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11088W	SUPPLEANT	\N	2017-09-24 17:15:15
9479	2013CMP10	2013-07-04 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86049M	SUPPLEANT	\N	2014-09-28 18:03:38
9480	2013CMP11	2013-07-12 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
9481	2013CMP11	2013-07-12 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	98046X	TITULAIRE	\N	2017-09-25 09:56:00
9482	2013CMP11	2013-07-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	TITULAIRE	\N	2017-09-24 18:20:10
9483	2013CMP11	2013-07-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	08061X	TITULAIRE	\N	\N
9484	2013CMP11	2013-07-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01013J	TITULAIRE	\N	2017-09-24 17:06:55
9486	2013CMP11	2013-07-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	11070L	TITULAIRE	\N	\N
9488	2013CMP11	2013-07-12 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	SUPPLEANT	\N	\N
9490	2013CMP11	2013-07-12 00:00:00	2015-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	11108H	SUPPLEANT	\N	2015-04-07 16:50:27
9492	2013CMP11	2013-07-12 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86049M	SUPPLEANT	\N	2014-09-28 18:03:38
9493	2013CMP11	2013-07-12 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	SUPPLEANT	\N	\N
9494	2013CMP12	2013-07-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
9495	2013CMP12	2013-07-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	95063L	TITULAIRE	\N	\N
9496	2013CMP12	2013-07-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04056J	TITULAIRE	\N	2017-09-24 18:17:56
9497	2013CMP12	2013-07-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	11056N	TITULAIRE	\N	\N
9498	2013CMP12	2013-07-12 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-13 14:23:01
9499	2013CMP12	2013-07-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04074L	TITULAIRE	\N	2017-09-24 17:15:15
9500	2013CMP12	2013-07-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	TITULAIRE	\N	\N
9501	2013CMP12	2013-07-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	11033F	SUPPLEANT	\N	\N
9502	2013CMP12	2013-07-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	04047H	SUPPLEANT	\N	\N
9503	2013CMP12	2013-07-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	\N	\N
9504	2013CMP12	2013-07-12 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	SUPPLEANT	\N	2014-09-28 18:00:58
9505	2013CMP12	2013-07-12 00:00:00	2017-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	01007L	SUPPLEANT	\N	2017-07-24 09:56:26
9506	2013CMP12	2013-07-12 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08032S	SUPPLEANT	\N	2014-09-28 17:34:16
9507	2013CMP12	2013-07-12 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04084N	SUPPLEANT	\N	2014-09-28 13:40:33
9508	RYTHMES	2013-10-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08072B	\N	2013-10-15 18:01:17	2014-09-29 09:05:47
9509	RYTHMES	2013-10-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08043V	\N	2013-10-15 18:01:25	2014-11-18 15:41:31
9510	RYTHMES	2013-10-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11060J	\N	2013-10-15 18:01:34	2014-11-18 15:41:31
9511	RYTHMES	2013-10-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95015C	\N	2013-10-15 18:01:48	2014-11-18 15:41:31
9512	RYTHMES	2013-10-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08024S	\N	2013-10-15 18:01:56	2014-11-18 15:41:31
9513	RYTHMES	2013-10-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11044J	\N	2013-10-15 18:02:06	2014-11-18 15:41:31
9514	RYTHMES	2013-10-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11042G	\N	2013-10-15 18:02:16	2014-11-18 15:41:31
9515	RYTHMES	2013-10-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95021A	\N	2013-10-15 18:02:25	2014-09-28 16:40:50
9516	RYTHMES	2013-10-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04046G	\N	2013-10-15 18:02:32	2014-09-28 17:07:41
9517	RYTHMES	2013-10-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11113E	\N	2013-10-15 18:02:41	2014-11-18 15:41:31
9518	RYTHMES	2013-10-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11091R	\N	2013-10-15 18:02:52	2014-11-18 15:41:31
9519	RYTHMES	2013-10-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08066D	\N	2013-10-15 18:02:59	2014-09-28 19:03:23
9520	RYTHMES	2013-10-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01025N	\N	2013-10-15 18:03:09	2014-11-18 15:41:31
9521	RYTHMES	2013-10-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	\N	2013-10-15 18:03:22	2014-11-18 15:41:31
9522	RYTHMES	2013-10-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11083R	\N	2013-10-15 18:03:29	2014-11-18 15:41:31
9523	RYTHMES	2013-10-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11089X	\N	2013-10-15 18:03:38	2014-11-18 15:41:31
9524	RYTHMES	2013-10-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	07026Q	\N	2013-10-15 18:03:45	2014-11-18 15:41:31
9525	RYTHMES	2013-10-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01007L	\N	2013-10-15 18:03:55	2014-11-18 15:41:31
9359	AFEU	2013-07-12 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13003V	\N	2013-07-12 11:35:08	2014-09-28 17:14:21
9451	2013CMP9	2013-06-21 00:00:00	2017-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	01044R	TITULAIRE	\N	2017-07-04 15:08:09
9452	2013CMP9	2013-06-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11089X	TITULAIRE	\N	2017-09-24 17:15:15
9453	2013CMP9	2013-06-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	04059M	TITULAIRE	\N	\N
9454	2013CMP9	2013-06-21 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08024S	TITULAIRE	\N	\N
9456	2013CMP9	2013-06-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	11090Q	TITULAIRE	\N	\N
9457	2013CMP9	2013-06-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	01043Q	TITULAIRE	\N	\N
9458	2013CMP9	2013-06-21 00:00:00	2018-08-06 00:00:00	ANCIEN	\N	\N	\N	\N	95015C	SUPPLEANT	\N	\N
9459	2013CMP9	2013-06-21 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89007P	SUPPLEANT	\N	2014-09-28 16:42:05
9460	2013CMP9	2013-06-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	07026Q	SUPPLEANT	\N	2017-09-24 19:25:10
9461	2013CMP9	2013-06-21 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08031R	SUPPLEANT	\N	\N
9462	2013CMP9	2013-06-21 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08063A	SUPPLEANT	\N	2014-09-28 17:07:07
9463	2013CMP9	2013-06-21 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08017T	SUPPLEANT	\N	\N
9464	2013CMP9	2013-06-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	04057K	SUPPLEANT	\N	\N
9526	RYTHMES	2013-10-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	\N	2013-10-15 18:04:02	2018-01-25 13:10:11
9527	RYTHMES	2013-10-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10003H	\N	2013-10-15 18:04:11	2014-09-28 17:38:26
9528	RYTHMES	2013-10-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08031R	\N	2013-10-15 18:04:18	2014-11-18 15:41:31
9529	RYTHMES	2013-10-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92031P	\N	2013-10-15 18:04:27	2014-11-18 15:41:31
9530	RYTHMES	2013-10-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08034U	\N	2013-10-15 18:04:34	2014-11-18 15:41:31
9531	RYTHMES	2013-10-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11098Y	\N	2013-10-15 18:04:42	2014-11-18 15:41:31
9532	RYTHMES	2013-10-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98046X	\N	2013-10-15 18:04:52	2014-11-18 15:41:31
9533	RYTHMES	2013-10-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95047L	\N	2013-10-15 18:04:59	2014-09-28 17:09:16
9534	RYTHMES	2013-10-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04057K	\N	2013-10-15 18:05:07	2014-11-18 15:41:31
9535	RYTHMES	2013-10-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11014C	\N	2013-10-15 18:05:21	2014-11-18 15:41:31
9536	RYTHMES	2013-10-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04070G	\N	2013-10-15 18:05:29	2014-11-18 15:41:31
9537	RYTHMES	2013-10-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	05012A	\N	2013-10-15 18:05:43	2014-11-18 15:41:31
9538	RYTHMES	2013-10-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11090Q	\N	2013-10-15 18:05:50	2014-11-18 15:41:31
9539	RYTHMES	2013-10-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11054L	\N	2013-10-15 18:05:58	2014-11-18 15:41:31
9540	RYTHMES	2013-10-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	\N	2013-10-15 18:06:06	2014-11-18 15:41:31
9542	2013CMP18	2013-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
9543	2013CMP18	2013-10-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98035U	TITULAIRE	\N	\N
9544	2013CMP18	2013-10-03 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08032S	TITULAIRE	\N	2014-09-28 17:34:16
9545	2013CMP18	2013-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	04085P	TITULAIRE	\N	\N
9546	2013CMP18	2013-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
9547	2013CMP18	2013-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
9549	2013CMP18	2013-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	SUPPLEANT	\N	\N
9550	2013CMP18	2013-10-03 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	SUPPLEANT	\N	2015-10-13 14:22:43
9551	2013CMP18	2013-10-03 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	12035A	SUPPLEANT	\N	2014-05-05 10:34:09
9552	2013CMP18	2013-10-03 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	SUPPLEANT	\N	2017-06-19 12:20:59
9553	2013CMP18	2013-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	95063L	SUPPLEANT	\N	\N
9554	2013CMP18	2013-10-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04056J	SUPPLEANT	\N	2017-09-24 18:17:56
9559	2013CMP19	2013-10-03 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08032S	TITULAIRE	\N	2014-09-28 17:34:16
9557	2013CMP19	2013-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
9558	2013CMP19	2013-10-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98035U	TITULAIRE	\N	\N
9560	2013CMP19	2013-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	04085P	TITULAIRE	\N	\N
9561	2013CMP19	2013-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
9562	2013CMP19	2013-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
9563	2013CMP19	2013-10-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	TITULAIRE	\N	2017-09-24 13:29:42
9564	2013CMP19	2013-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	SUPPLEANT	\N	\N
9565	2013CMP19	2013-10-03 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	SUPPLEANT	\N	2015-10-13 14:22:56
9566	2013CMP19	2013-10-03 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	12035A	SUPPLEANT	\N	2014-05-05 10:34:09
9567	2013CMP19	2013-10-03 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	SUPPLEANT	\N	2017-06-19 12:20:59
9568	2013CMP19	2013-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	95063L	SUPPLEANT	\N	\N
9569	2013CMP19	2013-10-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04056J	SUPPLEANT	\N	2017-09-24 18:17:56
9570	2013CMP19	2013-10-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	\N	\N
9571	2013CMP20	2013-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
9573	2013CMP20	2013-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	95063L	TITULAIRE	\N	\N
9574	2013CMP20	2013-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	04085P	TITULAIRE	\N	\N
9575	2013CMP20	2013-10-03 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	01063U	TITULAIRE	\N	2014-09-29 13:41:53
9576	2013CMP20	2013-10-03 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-13 14:22:38
9577	2013CMP20	2013-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	TITULAIRE	\N	\N
9578	2013CMP20	2013-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	04047H	SUPPLEANT	\N	\N
9579	2013CMP20	2013-10-03 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08032S	SUPPLEANT	\N	2014-09-28 17:34:16
9580	2013CMP20	2013-10-03 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	12035A	SUPPLEANT	\N	2014-05-05 10:34:09
9581	2013CMP20	2013-10-03 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	SUPPLEANT	\N	2017-06-19 12:20:59
9582	2013CMP20	2013-10-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98035U	SUPPLEANT	\N	\N
9583	2013CMP20	2013-10-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	\N	\N
9584	2013CMP20	2013-10-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	SUPPLEANT	\N	2017-09-24 13:29:42
9585	2013CMP21	2013-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
9586	2013CMP21	2013-10-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04056J	TITULAIRE	\N	2017-09-24 18:17:56
9587	2013CMP21	2013-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	95063L	TITULAIRE	\N	\N
9588	2013CMP21	2013-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	04085P	TITULAIRE	\N	\N
9589	2013CMP21	2013-10-03 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	01063U	TITULAIRE	\N	2014-09-29 13:41:53
9590	2013CMP21	2013-10-03 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-13 14:22:52
9591	2013CMP21	2013-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	TITULAIRE	\N	\N
9592	2013CMP21	2013-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	04047H	SUPPLEANT	\N	\N
9593	2013CMP21	2013-10-03 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08032S	SUPPLEANT	\N	2014-09-28 17:34:16
9594	2013CMP21	2013-10-03 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	12035A	SUPPLEANT	\N	2014-05-05 10:34:09
9595	2013CMP21	2013-10-03 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	SUPPLEANT	\N	2017-06-19 12:20:59
9596	2013CMP21	2013-10-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98035U	SUPPLEANT	\N	\N
9597	2013CMP21	2013-10-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	\N	\N
9599	2013CMP22	2013-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
9600	2013CMP22	2013-10-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04074L	TITULAIRE	\N	2017-09-24 17:15:15
9601	2013CMP22	2013-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	95063L	TITULAIRE	\N	\N
9603	2013CMP22	2013-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	04085P	TITULAIRE	\N	\N
9604	2013CMP22	2013-10-03 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-13 14:22:48
9605	2013CMP22	2013-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	TITULAIRE	\N	\N
9606	2013CMP22	2013-10-03 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08032S	SUPPLEANT	\N	2014-09-28 17:34:16
9607	2013CMP22	2013-10-03 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	12035A	SUPPLEANT	\N	2014-05-05 10:34:09
9608	2013CMP22	2013-10-03 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	SUPPLEANT	\N	2017-06-19 12:20:59
9609	2013CMP22	2013-10-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98035U	SUPPLEANT	\N	\N
9610	2013CMP22	2013-10-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	\N	\N
9611	2013CMP22	2013-10-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	SUPPLEANT	\N	\N
9612	2013CMP22	2013-10-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	SUPPLEANT	\N	2017-09-24 13:29:42
9613	2013CMP23	2013-10-03 00:00:00	2017-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	01044R	TITULAIRE	\N	2017-07-04 15:08:09
9614	2013CMP23	2013-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	04059M	TITULAIRE	\N	\N
9615	2013CMP23	2013-10-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08024S	TITULAIRE	\N	\N
9616	2013CMP23	2013-10-03 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08017T	TITULAIRE	\N	\N
9617	2013CMP23	2013-10-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08039A	TITULAIRE	\N	\N
9618	2013CMP23	2013-10-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92031P	TITULAIRE	\N	2017-09-24 18:16:52
9619	2013CMP23	2013-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	04070G	TITULAIRE	\N	\N
9620	2013CMP23	2013-10-03 00:00:00	2018-08-06 00:00:00	ANCIEN	\N	\N	\N	\N	95015C	SUPPLEANT	\N	\N
9621	2013CMP23	2013-10-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11042G	SUPPLEANT	\N	2017-09-24 17:35:15
9622	2013CMP23	2013-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	11083R	SUPPLEANT	\N	\N
9623	2013CMP23	2013-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	12041X	SUPPLEANT	\N	\N
9624	2013CMP23	2013-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	11104D	SUPPLEANT	\N	\N
9625	2013CMP23	2013-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	04057K	SUPPLEANT	\N	\N
9626	2013CMP23	2013-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	11090Q	SUPPLEANT	\N	\N
9627	2013CMP247	2013-10-03 00:00:00	2017-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	01044R	TITULAIRE	\N	2017-07-04 15:08:09
9628	2013CMP247	2013-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	04059M	TITULAIRE	\N	\N
9629	2013CMP247	2013-10-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08024S	TITULAIRE	\N	\N
9630	2013CMP247	2013-10-03 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08017T	TITULAIRE	\N	\N
9631	2013CMP247	2013-10-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08039A	TITULAIRE	\N	\N
8556	2012CMP8	2012-02-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04056J	SUPPLEANT	\N	2017-09-24 18:17:56
8557	2012CMP8	2012-02-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	SUPPLEANT	\N	2017-09-24 13:29:42
8558	COUTELEC	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08059E	\N	\N	\N
8559	COUTELEC	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08066D	\N	\N	\N
8560	COUTELEC	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11084S	\N	\N	\N
8171	ECON	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04096S	\N	\N	\N
8561	COUTELEC	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	10003H	\N	\N	\N
8562	COUTELEC	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08033T	\N	\N	\N
8563	COUTELEC	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	95052H	\N	\N	\N
8564	COUTELEC	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11045K	\N	\N	\N
8565	COUTELEC	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04091M	\N	\N	\N
8566	COUTELEC	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11049P	\N	\N	\N
8567	COUTELEC	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11100Y	\N	\N	\N
8568	COUTELEC	2012-02-15 00:00:00	2012-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	11003M	\N	\N	\N
8569	COUTELEC	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	98021N	\N	\N	\N
8570	COUTELEC	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	98050T	\N	\N	\N
8571	COUTELEC	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04069P	\N	\N	\N
8572	COUTELEC	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	\N	\N	\N
8573	COUTELEC	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11012A	\N	\N	\N
8574	COUTELEC	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11085T	\N	\N	\N
8575	COUTELEC	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04083M	\N	\N	\N
8576	IMPLANTS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	\N	\N	\N
8577	IMPLANTS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08020N	\N	\N	\N
8578	IMPLANTS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11044J	\N	\N	\N
8579	IMPLANTS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	10006L	\N	\N	\N
8580	IMPLANTS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11020A	\N	\N	\N
8581	IMPLANTS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	09001P	\N	\N	\N
8582	IMPLANTS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04036E	\N	\N	\N
8583	IMPLANTS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	\N	\N	\N
8584	IMPLANTS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11097X	\N	\N	\N
8585	IMPLANTS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08024S	\N	\N	\N
8586	IMPLANTS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	98029W	\N	\N	\N
8588	IMPLANTS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11061K	\N	\N	\N
8589	IMPLANTS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	10003H	\N	\N	\N
8775	2012CMP10	2012-02-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	TITULAIRE	\N	2017-09-24 17:35:15
8776	2012CMP10	2012-02-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08067E	TITULAIRE	\N	2014-09-28 17:22:11
8777	2012CMP10	2012-02-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11112D	TITULAIRE	\N	2017-09-24 16:45:26
8960	2012CMP18	2012-11-06 00:00:00	2015-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	11068S	SUPPLEANT	\N	2015-01-23 15:38:35
8961	2012CMP18	2012-11-06 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	01037S	SUPPLEANT	\N	2016-12-12 16:10:15
9017	2012CMP22	2012-11-27 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	98046X	TITULAIRE	\N	2017-09-25 09:56:00
9031	2012CMP23	2012-11-29 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	98046X	TITULAIRE	\N	2017-09-25 09:56:00
9032	2012CMP23	2012-11-29 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
9033	2012CMP23	2012-11-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	TITULAIRE	\N	2017-09-24 18:20:10
9034	2012CMP23	2012-11-29 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08027V	TITULAIRE	\N	2014-09-28 17:34:16
9037	2012CMP23	2012-11-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	08011M	TITULAIRE	\N	\N
9039	2012CMP23	2012-11-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08014Q	SUPPLEANT	\N	\N
9040	2012CMP23	2012-11-29 00:00:00	2014-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	01062T	SUPPLEANT	\N	2014-12-18 16:15:04
9041	2012CMP23	2012-11-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	88008L	SUPPLEANT	\N	\N
9042	2012CMP23	2012-11-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	01057W	SUPPLEANT	\N	\N
9098	2012CMP27	2012-12-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	11065P	SUPPLEANT	\N	\N
9114	2012CMP26	2012-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	08011M	SUPPLEANT	\N	\N
9115	2012CMP26	2012-12-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77043E	SUPPLEANT	\N	2014-09-28 16:59:41
9116	2012CMP26	2012-12-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08022Q	SUPPLEANT	\N	2017-10-01 09:41:22
9127	2013CMP1	2013-02-06 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04046G	TITULAIRE	\N	2014-09-28 17:07:41
9128	2013CMP1	2013-02-06 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08067E	TITULAIRE	\N	2014-09-28 17:22:11
9129	2013CMP1	2013-02-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	11085T	TITULAIRE	\N	\N
9130	2013CMP1	2013-02-06 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	11063M	TITULAIRE	\N	\N
9159	SOCI	2013-03-12 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	13002U	\N	2013-03-12 09:29:47	2014-10-08 16:53:57
9215	ACTION	2013-03-13 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	89017R	\N	\N	2013-12-16 10:28:45
9216	ACTION	2013-03-13 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	12040W	\N	\N	2013-12-16 10:28:45
9217	ACTION	2013-03-13 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	11068S	\N	\N	2013-12-16 10:28:45
9218	ACTION	2013-03-13 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	11029K	\N	\N	2013-12-16 10:28:45
9219	ACTION	2013-03-13 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	11042G	\N	\N	2013-12-16 10:28:45
9220	ACTION	2013-03-13 00:00:00	2013-04-23 00:00:00	ANCIEN	\N	\N	\N	\N	88008L	\N	\N	\N
9221	ACTION	2013-03-13 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	08038Y	\N	\N	2013-12-16 10:28:45
9222	ACTION	2013-03-13 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	92018S	\N	\N	2013-12-16 10:28:45
9223	ACTION	2013-03-13 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	11091R	\N	\N	2013-12-16 10:28:45
9224	ACTION	2013-03-13 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	92020L	\N	\N	2013-12-16 10:28:45
9225	ACTION	2013-03-13 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	04035D	\N	\N	2013-12-16 10:28:45
9226	ACTION	2013-03-13 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	07026Q	\N	\N	2013-12-16 10:28:45
9227	ACTION	2013-03-13 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	04036E	\N	\N	2013-12-16 10:28:45
9228	ACTION	2013-03-13 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	04061F	\N	\N	2013-12-16 10:28:45
9229	ACTION	2013-03-13 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	11026G	\N	\N	2013-12-16 10:28:45
9230	ACTION	2013-03-13 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	92031P	\N	\N	2013-12-16 10:28:45
9231	ACTION	2013-03-13 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	08017T	\N	\N	2013-12-16 10:28:45
9232	ACTION	2013-03-13 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	01043Q	\N	\N	2013-12-16 10:28:45
9233	ACTION	2013-03-13 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	08053X	\N	\N	2013-12-16 10:28:45
9234	ACTION	2013-03-13 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	04057K	\N	\N	2013-12-16 10:28:45
9235	ACTION	2013-03-13 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	04070G	\N	\N	2013-12-16 10:28:45
9236	ACTION	2013-03-13 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	08021P	\N	\N	2013-12-16 10:28:45
9237	ACTION	2013-03-13 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	96006F	\N	\N	2013-12-16 10:28:45
9238	ACTION	2013-03-13 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	77058M	\N	\N	2013-12-16 10:28:45
9239	ACTION	2013-03-13 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	11090Q	\N	\N	2013-12-16 10:28:45
9240	ACTION	2013-03-13 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	86044G	\N	\N	2013-12-16 10:28:45
9241	ACTION	2013-03-13 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	01056V	\N	\N	2013-12-16 10:28:45
9298	DECE	2013-04-23 00:00:00	2013-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	89017R	\N	\N	2013-12-16 10:30:09
9299	DECE	2013-04-23 00:00:00	2013-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	11081P	\N	\N	2013-12-16 10:30:09
9300	DECE	2013-04-23 00:00:00	2013-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	\N	\N	2013-12-16 10:30:09
9301	DECE	2013-04-23 00:00:00	2013-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	11095V	\N	\N	2013-12-16 10:30:09
9302	DECE	2013-04-23 00:00:00	2013-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	11032E	\N	\N	2013-12-16 10:30:09
8822	NEANT	2012-06-17 00:00:00	2012-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	95049N	\N	\N	\N
8823	NEANT	2012-06-17 00:00:00	2012-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	01048V	\N	\N	\N
8824	NEANT	2012-06-17 00:00:00	2012-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	86044G	\N	\N	\N
8840	EVASION	2012-07-04 00:00:00	2012-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	04066L	\N	\N	2013-12-16 10:26:49
8874	NEANT	2012-09-20 00:00:00	2012-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	12041X	\N	\N	\N
8879	ETRD	2012-10-01 00:00:00	2012-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	11062L	\N	\N	\N
8880	SOCI	2012-10-01 00:00:00	2012-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	11105E	\N	\N	\N
9016	2012CMP21	2012-11-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	11026G	SUPPLEANT	\N	\N
9024	2012CMP22	2012-11-27 00:00:00	2013-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	95003X	SUPPLEANT	\N	\N
9025	2012CMP22	2012-11-27 00:00:00	2014-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	01062T	SUPPLEANT	\N	2014-12-18 16:15:04
9028	2012CMP22	2012-11-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	01057W	SUPPLEANT	\N	\N
9030	2012CMP22	2012-11-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	04071H	SUPPLEANT	\N	\N
9125	2013CMP1	2013-02-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	11103C	TITULAIRE	\N	\N
9126	2013CMP1	2013-02-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04081K	TITULAIRE	\N	2017-09-24 19:25:10
9131	2013CMP1	2013-02-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04067M	SUPPLEANT	\N	2017-09-24 17:47:27
9132	2013CMP1	2013-02-06 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10003H	SUPPLEANT	\N	2014-09-28 17:38:26
9133	2013CMP1	2013-02-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	04045F	TITULAIRE	\N	\N
9303	DECE	2013-04-23 00:00:00	2013-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	\N	\N	2013-12-16 10:30:09
9304	DECE	2013-04-23 00:00:00	2013-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	08038Y	\N	\N	2013-12-16 10:30:09
9305	DECE	2013-04-23 00:00:00	2013-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	01027Q	\N	\N	2013-12-16 10:30:09
9306	DECE	2013-04-23 00:00:00	2013-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	98042T	\N	\N	2013-12-16 10:30:09
9307	DECE	2013-04-23 00:00:00	2013-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	04095R	\N	\N	2013-12-16 10:30:09
9308	DECE	2013-04-23 00:00:00	2013-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	01007L	\N	\N	2013-12-16 10:30:09
9309	DECE	2013-04-23 00:00:00	2013-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	01057W	\N	\N	2013-12-16 10:30:09
9310	DECE	2013-04-23 00:00:00	2013-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	03001N	\N	\N	2013-12-16 10:30:09
9311	DECE	2013-04-23 00:00:00	2013-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	86034E	\N	\N	2013-12-16 10:30:09
9353	ETRD	2013-05-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04054G	\N	2013-05-21 17:46:34	2017-09-24 17:18:03
9354	CDD	2013-05-21 00:00:00	2016-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	96003C	\N	2013-05-21 17:52:08	2016-11-14 11:07:47
8937	CAE	2012-10-23 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	11053K	\N	\N	2017-10-04 18:47:11
8938	CDD	2012-10-23 00:00:00	2012-11-11 00:00:00	ANCIEN	\N	\N	\N	\N	04083M	\N	\N	\N
8979	2012CMP19	2012-11-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11061K	SUPPLEANT	\N	2017-09-24 17:42:25
9118	CDD	2012-02-21 00:00:00	2013-05-20 00:00:00	ANCIEN	\N	\N	\N	\N	04054G	\N	\N	2017-12-19 14:40:50
9119	ETRD	2013-01-28 00:00:00	2013-05-20 00:00:00	ANCIEN	\N	\N	\N	\N	96003C	\N	\N	2013-05-21 17:51:58
9134	DOPAGE	2013-02-26 00:00:00	2013-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	11098Y	\N	\N	\N
9135	DOPAGE	2013-02-26 00:00:00	2013-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	12039E	\N	\N	\N
9136	DOPAGE	2013-02-26 00:00:00	2013-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	11039M	\N	\N	\N
9137	DOPAGE	2013-02-26 00:00:00	2013-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	11042G	\N	\N	\N
9138	DOPAGE	2013-02-26 00:00:00	2013-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	11110B	\N	\N	\N
9139	DOPAGE	2013-02-26 00:00:00	2013-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	10003H	\N	\N	\N
9140	DOPAGE	2013-02-26 00:00:00	2013-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	08012N	\N	\N	\N
9141	DOPAGE	2013-02-26 00:00:00	2013-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	11014C	\N	\N	\N
9142	DOPAGE	2013-02-26 00:00:00	2013-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	11105E	\N	\N	\N
9143	DOPAGE	2013-02-26 00:00:00	2013-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	01062T	\N	\N	\N
9144	DOPAGE	2013-02-26 00:00:00	2013-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	11070L	\N	\N	\N
9145	DOPAGE	2013-02-26 00:00:00	2013-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	09001P	\N	\N	\N
9146	DOPAGE	2013-02-26 00:00:00	2013-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	08020N	\N	\N	\N
9147	DOPAGE	2013-02-26 00:00:00	2013-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	95015C	\N	\N	\N
9148	DOPAGE	2013-02-26 00:00:00	2013-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	04099V	\N	\N	\N
9149	DOPAGE	2013-02-26 00:00:00	2013-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	87003B	\N	\N	\N
9150	DOPAGE	2013-02-26 00:00:00	2013-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	98028V	\N	\N	\N
9151	DOPAGE	2013-02-26 00:00:00	2013-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	07034Q	\N	\N	\N
9152	DOPAGE	2013-02-26 00:00:00	2013-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	01019Q	\N	\N	\N
9153	DOPAGE	2013-02-26 00:00:00	2013-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	11043H	\N	\N	\N
9154	DOPAGE	2013-02-26 00:00:00	2013-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	11069T	\N	\N	\N
9291	2013CMP5	2013-04-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11095V	SUPPLEANT	\N	2017-09-24 13:25:54
9292	2013CMP5	2013-04-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08045X	SUPPLEANT	\N	2014-09-28 17:00:59
9293	2013CMP5	2013-04-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01015L	SUPPLEANT	\N	2017-09-24 17:19:42
9349	ACTION	2013-03-13 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	04078Q	\N	\N	2013-12-16 10:28:45
9352	COMAPLEG	2013-04-24 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11110B	\N	2013-04-24 10:55:15	2014-11-19 17:50:38
8778	2012CMP10	2012-02-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	04045F	TITULAIRE	\N	\N
8779	2012CMP10	2012-02-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08020N	TITULAIRE	\N	2014-09-28 17:03:42
8781	2012CMP10	2012-02-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	04043D	TITULAIRE	\N	\N
8782	2012CMP10	2012-02-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	SUPPLEANT	\N	2017-09-24 13:44:49
8783	2012CMP10	2012-02-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11044J	SUPPLEANT	\N	2017-09-24 17:29:37
8784	2012CMP10	2012-02-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04067M	SUPPLEANT	\N	2017-09-24 17:47:27
8785	2012CMP10	2012-02-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98042T	SUPPLEANT	\N	2017-10-01 10:39:22
8786	2012CMP10	2012-02-15 00:00:00	2020-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	08041T	SUPPLEANT	\N	\N
8787	2012CMP10	2012-02-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10003H	SUPPLEANT	\N	2014-09-28 17:38:26
8788	2012CMP10	2012-02-15 00:00:00	2014-09-01 00:00:00	ANCIEN	\N	\N	\N	\N	96007G	SUPPLEANT	\N	2014-09-01 10:21:13
8826	COUTELEC	2012-07-03 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04097T	\N	\N	\N
8861	2012CMP14	2012-07-26 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
8862	2012CMP14	2012-07-26 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	98046X	TITULAIRE	\N	2017-09-25 09:56:00
8863	2012CMP14	2012-07-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	08061X	SUPPLEANT	\N	\N
8864	2012CMP14	2012-07-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	11040E	TITULAIRE	\N	\N
8865	2012CMP14	2012-07-26 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	SUPPLEANT	\N	2017-05-16 15:18:13
8866	2012CMP14	2012-07-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	TITULAIRE	\N	2017-09-24 18:20:10
8867	2012CMP14	2012-07-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04066L	TITULAIRE	\N	2017-09-24 17:47:28
8933	SECTES	2012-10-02 00:00:00	2013-06-11 00:00:00	ANCIEN	\N	\N	\N	\N	01019Q	\N	\N	\N
8997	2012CMP20	2012-11-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11095V	SUPPLEANT	\N	2017-09-24 13:25:54
8998	2012CMP20	2012-11-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01015L	SUPPLEANT	\N	2017-09-24 17:19:42
9018	2012CMP22	2012-11-27 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
9026	2012CMP22	2012-11-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08014Q	SUPPLEANT	\N	\N
9027	2012CMP22	2012-11-27 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	SUPPLEANT	\N	2017-05-16 15:18:13
9035	2012CMP23	2012-11-29 00:00:00	2014-07-01 00:00:00	ANCIEN	\N	\N	\N	\N	83011J	TITULAIRE	\N	2014-07-01 09:25:11
9036	2012CMP23	2012-11-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01013J	TITULAIRE	\N	2017-09-24 17:06:55
9157	NEANT	2013-03-01 00:00:00	2013-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	13002U	\N	\N	2013-03-12 09:30:08
9081	2012CMP25	2012-12-13 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01065W	SUPPLEANT	\N	2014-09-28 12:09:44
9158	AFCL	2013-02-14 00:00:00	2014-04-09 00:00:00	ANCIEN	\N	\N	\N	\N	11090Q	\N	\N	2014-04-10 10:15:28
9242	2013CMP3	2013-04-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11035H	TITULAIRE	\N	2017-09-24 18:16:52
9243	2013CMP3	2013-04-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
9244	2013CMP3	2013-04-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	04085P	TITULAIRE	\N	\N
9245	2013CMP3	2013-04-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11084S	TITULAIRE	\N	2017-09-24 19:25:10
9246	2013CMP3	2013-04-02 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-13 14:23:18
9247	2013CMP3	2013-04-02 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	TITULAIRE	\N	\N
9248	2013CMP3	2013-04-02 00:00:00	2014-04-23 00:00:00	ANCIEN	\N	\N	\N	\N	95049N	TITULAIRE	\N	2014-04-23 09:56:25
9249	2013CMP3	2013-04-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	08060W	SUPPLEANT	\N	\N
9250	2013CMP3	2013-04-02 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	\N	\N
9251	2013CMP3	2013-04-02 00:00:00	2017-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	01007L	SUPPLEANT	\N	2017-07-24 09:56:26
9252	2013CMP3	2013-04-02 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08032S	SUPPLEANT	\N	2014-09-28 17:34:16
9253	2013CMP3	2013-04-02 00:00:00	2015-04-21 00:00:00	ANCIEN	\N	\N	\N	\N	01042P	SUPPLEANT	\N	2015-04-21 17:14:30
9254	2013CMP3	2013-04-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	08010L	SUPPLEANT	\N	\N
9255	2013CMP3	2013-04-02 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	12035A	SUPPLEANT	\N	2014-05-05 10:34:09
9256	2013CMP2	2013-04-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
9257	2013CMP2	2013-04-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11084S	TITULAIRE	\N	2017-09-24 19:25:10
9739	2013CMP29	2013-11-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	11070L	TITULAIRE	\N	\N
9267	2013CMP2	2013-04-02 00:00:00	2015-04-21 00:00:00	ANCIEN	\N	\N	\N	\N	01042P	SUPPLEANT	\N	2015-04-21 17:14:30
9268	2013CMP2	2013-04-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	08010L	SUPPLEANT	\N	\N
9269	2013CMP2	2013-04-02 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	12035A	SUPPLEANT	\N	2014-05-05 10:34:09
9270	2013CMP4	2013-04-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	TITULAIRE	\N	2017-09-24 17:35:15
9271	2013CMP4	2013-04-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11061K	TITULAIRE	\N	2017-09-24 17:42:25
9272	2013CMP4	2013-04-04 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10003H	TITULAIRE	\N	2014-09-28 17:38:26
9273	2013CMP4	2013-04-04 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08037X	TITULAIRE	\N	2014-09-28 17:34:16
9274	2013CMP4	2013-04-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	04092N	TITULAIRE	\N	\N
9275	2013CMP4	2013-04-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	11097X	TITULAIRE	\N	\N
9276	2013CMP4	2013-04-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	01034P	TITULAIRE	\N	\N
9277	2013CMP4	2013-04-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11055M	SUPPLEANT	\N	2017-09-24 18:07:57
9123	CDD	2013-02-14 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13001T	\N	\N	2014-09-28 17:58:04
9280	2013CMP4	2013-04-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	10006L	SUPPLEANT	\N	\N
9279	2013CMP4	2013-04-04 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	SUPPLEANT	\N	\N
9286	2013CMP5	2013-04-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11107G	TITULAIRE	\N	2017-09-24 17:06:55
9287	2013CMP5	2013-04-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98037W	TITULAIRE	\N	2014-09-28 14:31:42
9288	2013CMP5	2013-04-10 00:00:00	2018-12-30 00:00:00	ANCIEN	\N	\N	\N	\N	98023Q	TITULAIRE	\N	\N
9289	2013CMP5	2013-04-10 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08022Q	TITULAIRE	\N	2017-10-01 09:41:22
9290	2013CMP5	2013-04-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	11053K	TITULAIRE	\N	\N
9294	2013CMP5	2013-04-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	11065P	SUPPLEANT	\N	\N
9295	2013CMP5	2013-04-10 00:00:00	2020-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	96004D	SUPPLEANT	\N	\N
9296	2013CMP5	2013-04-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11094U	SUPPLEANT	\N	2017-09-24 13:25:54
9297	2013CMP5	2013-04-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	05012A	SUPPLEANT	\N	\N
9312	DECE	2013-04-23 00:00:00	2013-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	08034U	\N	\N	2013-12-16 10:30:09
9313	DECE	2013-04-23 00:00:00	2013-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	12035A	\N	\N	2013-12-16 10:30:09
9314	DECE	2013-04-23 00:00:00	2013-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	08053X	\N	\N	2013-12-16 10:30:09
9315	DECE	2013-04-23 00:00:00	2013-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	11067R	\N	\N	2013-12-16 10:30:09
9316	DECE	2013-04-23 00:00:00	2013-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	95055L	\N	\N	2013-12-16 10:30:09
9317	DECE	2013-04-23 00:00:00	2013-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	95059Q	\N	\N	2013-12-16 10:30:09
9318	DECE	2013-04-23 00:00:00	2013-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	86044G	\N	\N	2013-12-16 10:30:09
9319	DECE	2013-04-23 00:00:00	2013-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	11046L	\N	\N	2013-12-16 10:30:09
9320	DECE	2013-04-23 00:00:00	2013-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	01058X	\N	\N	2013-12-16 10:30:09
9321	DECE	2013-04-23 00:00:00	2013-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	\N	\N	2013-12-16 10:30:09
9322	DECE	2013-04-23 00:00:00	2013-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	11037K	\N	\N	2013-12-16 10:30:09
9324	BANQ	2013-04-23 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	95009E	\N	\N	2014-04-14 14:28:41
9325	BANQ	2013-04-23 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	11068S	\N	\N	2014-04-14 14:28:41
9326	BANQ	2013-04-23 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	11040E	\N	\N	2014-04-14 14:28:41
9327	BANQ	2013-04-23 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	11029K	\N	\N	2014-04-14 14:28:41
9328	BANQ	2013-04-23 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	11042G	\N	\N	2014-04-14 14:28:41
9329	BANQ	2013-04-23 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	88008L	\N	\N	2014-04-14 14:28:41
9330	BANQ	2013-04-23 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	11088W	\N	\N	2014-04-14 14:28:41
9331	BANQ	2013-04-23 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	08022Q	\N	\N	2014-04-14 14:28:41
9332	BANQ	2013-04-23 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	04071H	\N	\N	2014-04-14 14:28:41
9333	BANQ	2013-04-23 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	11110B	\N	\N	2014-04-14 14:28:41
9334	BANQ	2013-04-23 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	08018U	\N	\N	2014-04-14 14:28:41
9335	BANQ	2013-04-23 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	07004J	\N	\N	2014-04-14 14:28:41
9336	BANQ	2013-04-23 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	11064N	\N	\N	2014-04-14 14:28:41
9337	BANQ	2013-04-23 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	11084S	\N	\N	2014-04-14 14:28:41
9338	BANQ	2013-04-23 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	11026G	\N	\N	2014-04-14 14:28:41
9339	BANQ	2013-04-23 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	11077T	\N	\N	2014-04-14 14:28:41
9340	BANQ	2013-04-23 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	77043E	\N	\N	2014-04-14 14:28:41
9341	BANQ	2013-04-23 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	07034Q	\N	\N	2014-04-14 14:28:41
9342	BANQ	2013-04-23 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	95062K	\N	\N	2014-04-14 14:28:41
9343	BANQ	2013-04-23 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	11045K	\N	\N	2014-04-14 14:28:41
9344	BANQ	2013-04-23 00:00:00	2013-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	\N	\N	2014-04-14 14:28:41
9345	DECE	2013-04-23 00:00:00	2013-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	11034G	\N	\N	2013-12-16 10:30:09
9346	DECE	2013-04-23 00:00:00	2013-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	08054Y	\N	\N	2013-12-16 10:30:09
8665	COUTELEC	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08054Y	\N	\N	\N
8666	INONDATIONS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01013J	\N	\N	\N
8667	INONDATIONS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08055A	\N	\N	\N
8668	INONDATIONS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08026U	\N	\N	\N
8669	PESTICIDES	2012-02-15 00:00:00	2013-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	11031D	\N	\N	\N
8670	PESTICIDES	2012-02-15 00:00:00	2013-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	98038X	\N	\N	\N
8671	IMPLANTS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11031D	\N	\N	\N
8672	IMPLANTS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08026U	\N	\N	\N
8673	IMPLANTS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	\N	\N	\N
8674	AGENCES	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11040E	\N	\N	2013-12-16 10:13:19
8675	AGENCES	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11034G	\N	\N	2013-12-16 10:13:19
8680	LOIS	2012-02-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11084S	\N	\N	2017-09-24 19:25:10
8681	ECON	2012-02-20 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	11046L	\N	\N	\N
8682	ETRD	2012-02-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11041F	\N	\N	2017-10-04 00:00:00
8684	CAE	2012-02-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01008M	\N	\N	2017-09-24 13:44:49
8687	CAE	2012-02-21 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95009E	\N	\N	2014-09-28 12:56:42
8688	CAE	2012-02-21 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	08055A	\N	\N	2014-10-08 17:05:06
8691	CAE	2012-02-21 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08050U	\N	\N	2014-09-28 12:44:31
8692	CAE	2012-02-21 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	11101A	\N	\N	2017-10-04 19:55:42
8696	CAE	2012-02-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08028W	\N	\N	2017-10-04 00:00:00
8698	CAE	2012-02-21 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80013X	\N	\N	2017-10-04 19:56:10
8700	CAE	2012-02-21 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	11051H	\N	\N	2014-10-08 17:05:35
8704	CAE	2012-02-21 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08066D	\N	\N	2014-09-28 19:03:23
8705	CAE	2012-02-21 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	08016S	\N	\N	2014-10-08 17:00:38
8706	CAE	2012-02-21 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95038K	\N	\N	2014-09-28 17:40:23
8708	CAE	2012-02-21 00:00:00	2016-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	04048J	\N	\N	2016-12-01 10:36:51
8710	CAE	2012-02-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11099A	\N	\N	2017-10-04 00:00:00
8712	CAE	2012-02-21 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	\N	\N	2017-10-04 19:57:54
8718	CAE	2012-02-21 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98038X	\N	\N	2014-09-28 17:38:26
8720	CAE	2012-02-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11100Y	\N	\N	2017-09-24 13:57:40
8722	CAE	2012-02-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01061S	\N	\N	2017-09-24 17:48:21
8728	CAE	2012-02-21 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08019V	\N	\N	2017-10-04 19:58:27
8730	CAE	2012-02-21 00:00:00	2012-10-22 00:00:00	ANCIEN	\N	\N	\N	\N	04083M	\N	\N	\N
8732	CAE	2012-02-21 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08033T	\N	\N	2014-09-28 17:27:35
8733	CAE	2012-02-21 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	09012S	\N	\N	2014-09-28 13:09:05
8735	CAE	2012-02-21 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04088S	\N	\N	2017-10-04 19:59:28
8737	CAE	2012-02-21 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	98050T	\N	\N	2017-10-04 19:02:02
8739	CAE	2012-02-21 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	\N	\N	2014-10-08 16:56:26
8741	CAE	2012-02-21 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	04090L	\N	\N	\N
8742	CAE	2012-02-21 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	04033B	\N	\N	2014-10-08 17:35:30
8745	CAE	2012-02-21 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08054Y	\N	\N	2014-09-28 12:39:09
8748	CAE	2012-02-21 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	06004E	\N	\N	2014-09-28 17:03:42
8749	CAE	2012-02-21 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	11066Q	\N	\N	2017-10-04 18:57:21
8751	CAE	2012-02-21 00:00:00	2012-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	05011Y	\N	\N	\N
8808	2012CMP12	2012-02-28 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95062K	TITULAIRE	\N	\N
8809	2012CMP12	2012-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	11053K	TITULAIRE	\N	\N
8810	2012CMP12	2012-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	11077T	SUPPLEANT	\N	\N
8812	2012CMP12	2012-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	11099A	SUPPLEANT	\N	\N
8813	2012CMP12	2012-02-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	06004E	SUPPLEANT	\N	2014-09-28 17:03:42
8814	2012CMP12	2012-02-28 00:00:00	2016-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	04048J	SUPPLEANT	\N	2016-12-01 10:36:51
8815	2012CMP12	2012-02-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	90003B	SUPPLEANT	\N	2017-10-01 10:01:39
8816	2012CMP12	2012-02-28 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	SUPPLEANT	\N	\N
8846	CAE	2012-07-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08038Y	\N	\N	2017-10-04 19:56:31
8827	SOCI	2012-07-03 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	01048V	\N	\N	2014-10-08 17:43:00
8828	SOCI	2012-07-03 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	86044G	\N	\N	2014-10-08 17:38:49
8829	FINC	2012-07-03 00:00:00	2014-05-02 00:00:00	ANCIEN	\N	\N	\N	\N	08070Y	\N	\N	2014-05-05 14:01:11
8871	2012CMP14	2012-07-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	11110B	SUPPLEANT	\N	\N
8872	2012CMP14	2012-07-26 00:00:00	2019-06-24 00:00:00	ANCIEN	\N	\N	\N	\N	04061F	SUPPLEANT	\N	\N
8873	2012CMP14	2012-07-26 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	SUPPLEANT	\N	\N
8587	IMPLANTS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08066D	\N	\N	\N
8881	SECTES	2012-10-02 00:00:00	2013-06-11 00:00:00	ANCIEN	\N	\N	\N	\N	11031D	\N	\N	\N
8882	SECTES	2012-10-02 00:00:00	2013-06-11 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	\N	\N	\N
8883	SECTES	2012-10-02 00:00:00	2013-06-11 00:00:00	ANCIEN	\N	\N	\N	\N	12039E	\N	\N	\N
8884	SECTES	2012-10-02 00:00:00	2013-06-11 00:00:00	ANCIEN	\N	\N	\N	\N	96007G	\N	\N	\N
8885	SECTES	2012-10-02 00:00:00	2013-06-11 00:00:00	ANCIEN	\N	\N	\N	\N	11061K	\N	\N	\N
8886	SECTES	2012-10-02 00:00:00	2013-06-11 00:00:00	ANCIEN	\N	\N	\N	\N	08060W	\N	\N	\N
8887	SECTES	2012-10-02 00:00:00	2013-06-11 00:00:00	ANCIEN	\N	\N	\N	\N	04084N	\N	\N	\N
8888	SECTES	2012-10-02 00:00:00	2013-06-11 00:00:00	ANCIEN	\N	\N	\N	\N	11066Q	\N	\N	\N
8889	SECTES	2012-10-02 00:00:00	2013-06-11 00:00:00	ANCIEN	\N	\N	\N	\N	11105E	\N	\N	\N
8890	SECTES	2012-10-02 00:00:00	2013-06-11 00:00:00	ANCIEN	\N	\N	\N	\N	08066D	\N	\N	\N
8891	SECTES	2012-10-02 00:00:00	2013-06-11 00:00:00	ANCIEN	\N	\N	\N	\N	04051D	\N	\N	\N
8892	SECTES	2012-10-02 00:00:00	2013-06-11 00:00:00	ANCIEN	\N	\N	\N	\N	11093T	\N	\N	\N
8893	SECTES	2012-10-02 00:00:00	2013-06-11 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	\N	\N	\N
8894	SECTES	2012-10-02 00:00:00	2013-06-11 00:00:00	ANCIEN	\N	\N	\N	\N	10006L	\N	\N	\N
8895	SECTES	2012-10-02 00:00:00	2013-06-11 00:00:00	ANCIEN	\N	\N	\N	\N	08069G	\N	\N	\N
8896	SECTES	2012-10-02 00:00:00	2013-06-11 00:00:00	ANCIEN	\N	\N	\N	\N	08044W	\N	\N	\N
8897	SECTES	2012-10-02 00:00:00	2013-06-11 00:00:00	ANCIEN	\N	\N	\N	\N	04036E	\N	\N	\N
8898	SECTES	2012-10-02 00:00:00	2013-06-11 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	\N	\N	\N
8899	SECTES	2012-10-02 00:00:00	2013-06-11 00:00:00	ANCIEN	\N	\N	\N	\N	11090Q	\N	\N	\N
8900	SECTES	2012-10-02 00:00:00	2012-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	86049M	\N	\N	\N
8901	SECTES	2012-10-02 00:00:00	2013-06-11 00:00:00	ANCIEN	\N	\N	\N	\N	12035A	\N	\N	\N
8904	2012CMP15	2012-09-26 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04046G	TITULAIRE	\N	2014-09-28 17:07:41
8905	2012CMP15	2012-09-26 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10003H	TITULAIRE	\N	2014-09-28 17:38:26
8906	2012CMP15	2012-09-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	04043D	TITULAIRE	\N	\N
8907	2012CMP15	2012-09-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	09001P	TITULAIRE	\N	2017-09-24 17:47:27
8908	2012CMP15	2012-09-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	11085T	TITULAIRE	\N	\N
8909	2012CMP15	2012-09-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	SUPPLEANT	\N	2017-09-24 13:44:49
8915	2012CMP15	2012-09-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	11097X	SUPPLEANT	\N	\N
8924	2012CMP16	2012-09-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	11077T	SUPPLEANT	\N	\N
8925	2012CMP16	2012-09-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	11099A	SUPPLEANT	\N	\N
8926	2012CMP16	2012-09-27 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	06004E	SUPPLEANT	\N	2014-09-28 17:03:42
8953	2012CMP18	2012-11-06 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
8955	2012CMP18	2012-11-06 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	TITULAIRE	\N	\N
8956	2012CMP18	2012-11-06 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	11069T	TITULAIRE	\N	2016-03-11 18:02:50
8957	2012CMP18	2012-11-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	11040E	TITULAIRE	\N	\N
8958	2012CMP18	2012-11-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	99004R	TITULAIRE	\N	\N
8959	2012CMP18	2012-11-06 00:00:00	2014-07-01 00:00:00	ANCIEN	\N	\N	\N	\N	83011J	TITULAIRE	\N	2014-07-01 09:25:11
8964	2012CMP18	2012-11-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	04071H	SUPPLEANT	\N	\N
8965	2012CMP18	2012-11-06 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86049M	SUPPLEANT	\N	2014-09-28 18:03:38
8996	2012CMP20	2012-11-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11107G	SUPPLEANT	\N	2017-09-24 17:06:55
9003	2012CMP21	2012-11-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
9004	2012CMP21	2012-11-29 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	TITULAIRE	\N	2017-06-19 12:20:59
9005	2012CMP21	2012-11-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08025T	TITULAIRE	\N	2017-10-01 10:17:18
9006	2012CMP21	2012-11-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	04085P	TITULAIRE	\N	\N
9007	2012CMP21	2012-11-29 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	95020Y	TITULAIRE	\N	2015-06-12 16:01:25
9008	2012CMP21	2012-11-29 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-13 14:23:32
9009	2012CMP21	2012-11-29 00:00:00	2014-04-23 00:00:00	ANCIEN	\N	\N	\N	\N	95049N	TITULAIRE	\N	2014-04-23 09:56:25
9010	2012CMP21	2012-11-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11030C	SUPPLEANT	\N	2017-09-24 17:09:24
9011	2012CMP21	2012-11-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	11033F	SUPPLEANT	\N	\N
8847	2012CMP13	2012-07-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
8848	2012CMP13	2012-07-24 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08025T	TITULAIRE	\N	2017-10-01 10:17:18
8849	2012CMP13	2012-07-24 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04046G	TITULAIRE	\N	2014-09-28 17:07:41
8850	2012CMP13	2012-07-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	04085P	TITULAIRE	\N	\N
8851	2012CMP13	2012-07-24 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-13 14:23:35
8852	2012CMP13	2012-07-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	TITULAIRE	\N	\N
8853	2012CMP13	2012-07-24 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	07034Q	TITULAIRE	\N	\N
8854	2012CMP13	2012-07-24 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01065W	SUPPLEANT	\N	2014-09-28 12:09:44
8855	2012CMP13	2012-07-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	11033F	SUPPLEANT	\N	\N
8856	2012CMP13	2012-07-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11084S	SUPPLEANT	\N	2017-09-24 19:25:10
8857	2012CMP13	2012-07-24 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08032S	SUPPLEANT	\N	2014-09-28 17:34:16
8858	2012CMP13	2012-07-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	10015M	SUPPLEANT	\N	\N
8859	2012CMP13	2012-07-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	\N	\N
8860	2012CMP13	2012-07-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	SUPPLEANT	\N	2017-09-24 13:29:42
8789	2012CMP11	2012-02-22 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
8790	2012CMP11	2012-02-22 00:00:00	2012-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	TITULAIRE	\N	\N
8791	2012CMP11	2012-02-22 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	TITULAIRE	\N	\N
8792	2012CMP11	2012-02-22 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	TITULAIRE	\N	\N
8793	2012CMP11	2012-02-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01013J	TITULAIRE	\N	2017-09-24 17:06:55
8794	2012CMP11	2012-02-22 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	TITULAIRE	\N	\N
8795	2012CMP11	2012-02-22 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	98032R	TITULAIRE	\N	2015-06-12 15:59:49
8796	2012CMP11	2012-02-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11068S	SUPPLEANT	\N	2017-09-24 18:05:41
8797	2012CMP11	2012-02-22 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	98046X	SUPPLEANT	\N	2017-09-25 09:56:00
8798	2012CMP11	2012-02-22 00:00:00	2013-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	95003X	SUPPLEANT	\N	\N
8799	2012CMP11	2012-02-22 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	SUPPLEANT	\N	2017-05-16 15:18:13
8800	2012CMP11	2012-02-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	04071H	SUPPLEANT	\N	\N
8801	2012CMP11	2012-02-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	99004R	SUPPLEANT	\N	\N
8802	2012CMP11	2012-02-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11088W	SUPPLEANT	\N	2017-09-24 17:15:15
8803	2012CMP12	2012-03-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	TITULAIRE	\N	2017-09-24 17:09:24
8804	2012CMP12	2012-02-28 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	04090L	TITULAIRE	\N	\N
8817	NEANT	2012-03-19 00:00:00	2012-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	11081P	\N	\N	\N
8936	COMAPLEG	2012-10-18 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11056N	\N	\N	2014-11-19 17:50:38
8946	2012CMP17	2012-10-23 00:00:00	2020-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	08068F	SUPPLEANT	\N	\N
8947	2012CMP17	2012-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01022K	SUPPLEANT	\N	2017-09-24 17:14:26
8948	2012CMP17	2012-10-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	11012A	SUPPLEANT	\N	\N
8949	2012CMP17	2012-10-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	11099A	SUPPLEANT	\N	\N
8962	2012CMP18	2012-11-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04066L	SUPPLEANT	\N	2017-09-24 17:47:28
8963	2012CMP18	2012-11-06 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	SUPPLEANT	\N	2017-05-16 15:18:13
8982	2012CMP19	2012-11-20 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08026U	SUPPLEANT	\N	2014-09-28 17:52:18
8986	ETRD	2012-12-05 00:00:00	2014-05-06 00:00:00	ANCIEN	\N	\N	\N	\N	11032E	\N	\N	2014-05-07 12:23:35
8987	SOCI	2012-12-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	12042Y	\N	\N	2017-09-24 19:31:54
8845	COMAPLEG	2013-01-23 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	12039E	\N	\N	2014-05-05 10:35:23
8988	2012CMP20	2012-11-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08049C	TITULAIRE	\N	2014-09-28 19:07:43
8989	2012CMP20	2012-11-28 00:00:00	2014-05-11 00:00:00	ANCIEN	\N	\N	\N	\N	11045K	TITULAIRE	\N	2014-05-12 09:52:22
9051	2012CMP24	2012-12-13 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	98032R	TITULAIRE	\N	2015-06-12 15:59:49
8991	2012CMP20	2012-11-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01022K	TITULAIRE	\N	2017-09-24 17:14:26
8992	2012CMP20	2012-11-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98037W	TITULAIRE	\N	2014-09-28 14:31:42
8993	2012CMP20	2012-11-28 00:00:00	2018-12-30 00:00:00	ANCIEN	\N	\N	\N	\N	98023Q	TITULAIRE	\N	\N
8995	2012CMP20	2012-11-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11094U	TITULAIRE	\N	2017-09-24 13:25:54
8999	2012CMP20	2012-11-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	11065P	SUPPLEANT	\N	\N
9052	2012CMP24	2012-12-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	SUPPLEANT	\N	2017-09-24 18:20:10
9053	2012CMP24	2012-12-13 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	SUPPLEANT	\N	\N
9054	2012CMP24	2012-12-13 00:00:00	2020-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	08068F	SUPPLEANT	\N	\N
9058	2012CMP24	2012-12-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08022Q	SUPPLEANT	\N	2017-10-01 09:41:22
9059	2012CMP24	2012-12-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11088W	SUPPLEANT	\N	2017-09-24 17:15:15
9161	VIANDE	2013-03-13 00:00:00	2013-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	01008M	\N	\N	\N
9162	VIANDE	2013-03-13 00:00:00	2013-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	04091M	\N	\N	\N
9163	VIANDE	2013-03-13 00:00:00	2013-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	08055A	\N	\N	\N
9164	VIANDE	2013-03-13 00:00:00	2013-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	08050U	\N	\N	\N
9165	VIANDE	2013-03-13 00:00:00	2013-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	08058D	\N	\N	\N
9166	VIANDE	2013-03-13 00:00:00	2013-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	90003B	\N	\N	\N
9167	VIANDE	2013-03-13 00:00:00	2013-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	11031D	\N	\N	\N
9168	VIANDE	2013-03-13 00:00:00	2013-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	80013X	\N	\N	\N
9169	VIANDE	2013-03-13 00:00:00	2013-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	95028H	\N	\N	\N
9170	VIANDE	2013-03-13 00:00:00	2013-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	12042Y	\N	\N	\N
9171	VIANDE	2013-03-13 00:00:00	2013-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	08066D	\N	\N	\N
9172	VIANDE	2013-03-13 00:00:00	2013-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	08045X	\N	\N	\N
9173	VIANDE	2013-03-13 00:00:00	2013-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	\N	\N	\N
9174	VIANDE	2013-03-13 00:00:00	2013-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	08056B	\N	\N	\N
9175	VIANDE	2013-03-13 00:00:00	2013-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	04097T	\N	\N	\N
8805	2012CMP12	2012-02-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11037K	TITULAIRE	\N	2017-09-24 18:16:52
8806	2012CMP12	2012-02-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98038X	TITULAIRE	\N	2014-09-28 17:38:26
8807	2012CMP12	2012-02-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04069P	TITULAIRE	\N	2014-09-28 17:31:41
8842	CDD	2012-07-24 00:00:00	2014-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	12038D	\N	\N	2014-05-05 10:35:50
8843	CDD	2012-07-24 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	12039E	\N	\N	2014-05-05 10:35:23
8844	ETRD	2012-07-24 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	12040W	\N	\N	2014-05-05 10:33:42
8878	LOIS	2012-09-25 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	11056N	\N	\N	2017-10-04 18:41:49
9120	AFEU	2013-02-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08014Q	\N	\N	2017-10-05 14:39:23
9176	VIANDE	2013-03-13 00:00:00	2013-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	\N	\N	2018-01-25 13:10:11
9177	VIANDE	2013-03-13 00:00:00	2013-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	11112D	\N	\N	\N
9178	VIANDE	2013-03-13 00:00:00	2013-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	11099A	\N	\N	\N
9180	VIANDE	2013-03-13 00:00:00	2013-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	11111C	\N	\N	\N
9181	VIANDE	2013-03-13 00:00:00	2013-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	98038X	\N	\N	\N
9182	VIANDE	2013-03-13 00:00:00	2013-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	11100Y	\N	\N	\N
9183	VIANDE	2013-03-13 00:00:00	2013-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	08033T	\N	\N	\N
9184	VIANDE	2013-03-13 00:00:00	2013-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	09012S	\N	\N	\N
9185	VIANDE	2013-03-13 00:00:00	2013-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	04088S	\N	\N	\N
9186	VIANDE	2013-03-13 00:00:00	2013-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	05012A	\N	\N	\N
9187	VIANDE	2013-03-13 00:00:00	2013-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	95062K	\N	\N	\N
9281	2013CMP4	2013-04-04 00:00:00	2020-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	08041T	SUPPLEANT	\N	\N
9282	2013CMP4	2013-04-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	11067R	SUPPLEANT	\N	\N
9283	2013CMP4	2013-04-04 00:00:00	2014-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	08046Y	SUPPLEANT	\N	\N
9284	2013CMP5	2013-04-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08049C	TITULAIRE	\N	2014-09-28 19:07:43
9285	2013CMP5	2013-04-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04065K	TITULAIRE	\N	2014-09-28 17:31:42
8832	SOCI	2012-07-03 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95005A	\N	\N	2014-09-28 17:40:23
8833	LOIS	2012-07-03 00:00:00	2014-04-23 00:00:00	ANCIEN	\N	\N	\N	\N	95049N	\N	\N	2014-04-23 09:56:25
8834	CAE	2012-07-03 00:00:00	2020-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	11081P	\N	\N	2017-10-04 19:55:24
8835	SOCI	2012-07-03 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	05011Y	\N	\N	2014-09-28 13:47:05
8836	AFCL	2012-07-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11029K	\N	\N	2017-09-24 17:09:24
8837	AFEU	2012-07-03 00:00:00	2014-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	11081P	\N	\N	2014-10-09 15:55:37
8839	COMAPLEG	2012-07-03 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95019G	\N	\N	2014-09-28 16:59:41
8939	2012CMP17	2012-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	TITULAIRE	\N	2017-09-24 17:09:24
8994	2012CMP20	2012-11-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	08069G	TITULAIRE	\N	\N
9019	2012CMP22	2012-11-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	TITULAIRE	\N	2017-09-24 18:20:10
9020	2012CMP22	2012-11-27 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08027V	TITULAIRE	\N	2014-09-28 17:34:16
9021	2012CMP22	2012-11-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01013J	TITULAIRE	\N	2017-09-24 17:06:55
9022	2012CMP22	2012-11-27 00:00:00	2014-07-01 00:00:00	ANCIEN	\N	\N	\N	\N	83011J	TITULAIRE	\N	2014-07-01 09:25:11
9023	2012CMP22	2012-11-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	08011M	TITULAIRE	\N	\N
9122	CDD	2013-02-13 00:00:00	2013-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	11090Q	\N	\N	\N
8945	2012CMP17	2012-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04080J	TITULAIRE	\N	2017-09-24 17:47:27
8950	2012CMP17	2012-10-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	SUPPLEANT	\N	\N
8951	2012CMP17	2012-10-23 00:00:00	2016-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	04048J	SUPPLEANT	\N	2016-12-01 10:36:51
8952	2012CMP17	2012-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11100Y	SUPPLEANT	\N	2017-09-24 13:57:40
9000	2012CMP20	2012-11-28 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95062K	SUPPLEANT	\N	\N
9001	2012CMP20	2012-11-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08042U	SUPPLEANT	\N	2017-10-01 10:20:50
9002	2012CMP20	2012-11-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	08009T	SUPPLEANT	\N	\N
9012	2012CMP21	2012-11-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11035H	SUPPLEANT	\N	2017-09-24 18:16:52
9013	2012CMP21	2012-11-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	SUPPLEANT	\N	\N
9014	2012CMP21	2012-11-29 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08032S	SUPPLEANT	\N	2014-09-28 17:34:16
9038	2012CMP23	2012-11-29 00:00:00	2013-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	95003X	SUPPLEANT	\N	\N
9043	2012CMP23	2012-11-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08022Q	SUPPLEANT	\N	2017-10-01 09:41:22
9044	2012CMP23	2012-11-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	04071H	SUPPLEANT	\N	\N
9258	2013CMP2	2013-04-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	04085P	TITULAIRE	\N	\N
9259	2013CMP2	2013-04-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11035H	TITULAIRE	\N	2017-09-24 18:16:52
9260	2013CMP2	2013-04-02 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-13 14:23:12
9261	2013CMP2	2013-04-02 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	TITULAIRE	\N	\N
9682	2013CMP27	2013-11-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	11097X	SUPPLEANT	\N	\N
9262	2013CMP2	2013-04-02 00:00:00	2014-04-23 00:00:00	ANCIEN	\N	\N	\N	\N	95049N	TITULAIRE	\N	2014-04-23 09:56:25
9263	2013CMP2	2013-04-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	08060W	SUPPLEANT	\N	\N
9264	2013CMP2	2013-04-02 00:00:00	2017-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	01007L	SUPPLEANT	\N	2017-07-24 09:56:26
9265	2013CMP2	2013-04-02 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	\N	\N
9266	2013CMP2	2013-04-02 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08032S	SUPPLEANT	\N	2014-09-28 17:34:16
8679	AGENCES	2012-02-20 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04046G	\N	\N	2013-12-16 10:13:19
8683	CDD	2012-02-21 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01064V	\N	\N	2014-09-28 17:12:41
8686	CDD	2012-02-21 00:00:00	2019-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	96004D	\N	\N	2017-10-04 19:42:38
8690	CDD	2012-02-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11095V	\N	\N	2017-09-24 13:25:54
8693	CDD	2012-02-21 00:00:00	2012-10-22 00:00:00	ANCIEN	\N	\N	\N	\N	11053K	\N	\N	\N
8695	CDD	2012-02-21 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08057C	\N	\N	2014-09-28 14:31:42
8697	CDD	2012-02-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11114F	\N	\N	2017-09-25 10:54:33
8699	CDD	2012-02-21 00:00:00	2018-12-30 00:00:00	ANCIEN	\N	\N	\N	\N	98023Q	\N	\N	2017-10-04 19:43:23
8703	CDD	2012-02-21 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95021A	\N	\N	2014-09-28 16:40:50
8707	CDD	2012-02-21 00:00:00	2012-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	08038Y	\N	\N	\N
8709	CDD	2012-02-21 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95025E	\N	\N	2014-09-28 17:09:16
8711	CDD	2012-02-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01015L	\N	\N	2017-09-24 17:19:42
8713	CDD	2012-02-21 00:00:00	2014-04-09 00:00:00	ANCIEN	\N	\N	\N	\N	89014N	\N	\N	2014-04-10 10:16:45
8715	CDD	2012-02-21 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	08064B	\N	\N	\N
8717	CDD	2012-02-21 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	11096W	\N	\N	2014-10-08 17:10:29
8719	CDD	2012-02-21 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08045X	\N	\N	2014-09-28 17:00:59
8721	CDD	2012-02-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11107G	\N	\N	2017-09-24 17:06:55
8723	CDD	2012-02-21 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	02002K	\N	\N	2017-10-04 19:44:02
8725	CDD	2012-02-21 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95036H	\N	\N	2014-09-28 17:31:42
8727	CDD	2012-02-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01022K	\N	\N	2017-09-24 17:14:26
8729	CDD	2012-02-21 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	08069G	\N	\N	2014-10-08 17:43:42
8731	CDD	2012-02-21 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04097T	\N	\N	2017-10-04 19:44:42
8734	CDD	2012-02-21 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	08015R	\N	\N	2014-10-08 17:12:39
8736	CDD	2012-02-21 00:00:00	2013-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	07025P	\N	\N	\N
8738	CDD	2012-02-21 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	08009T	\N	\N	2017-10-04 19:45:45
8740	CDD	2012-02-21 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	08062Y	\N	\N	2017-10-04 18:52:41
8743	CDD	2012-02-21 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	08021P	\N	\N	2014-10-08 16:48:24
8744	CDD	2012-02-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08042U	\N	\N	2017-10-01 10:20:50
8750	CDD	2012-02-21 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95062K	\N	\N	2017-10-04 19:46:33
8752	CDD	2012-02-21 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04065K	\N	\N	2014-09-28 17:31:42
8753	CDD	2012-02-21 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	11046L	\N	\N	2014-10-08 16:50:45
8754	CDD	2012-02-21 00:00:00	2014-05-11 00:00:00	ANCIEN	\N	\N	\N	\N	11045K	\N	\N	2014-05-12 09:52:22
8755	CDD	2012-02-21 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04069P	\N	\N	2014-09-28 17:31:41
8618	PESTICIDES	2012-02-15 00:00:00	2013-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	11045K	\N	\N	\N
8619	PESTICIDES	2012-02-15 00:00:00	2013-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	08056B	\N	\N	\N
8620	PESTICIDES	2012-02-15 00:00:00	2013-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	11094U	\N	\N	\N
8621	INONDATIONS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	\N	\N	\N
8622	INONDATIONS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11111C	\N	\N	\N
8623	INONDATIONS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08059E	\N	\N	\N
8624	INONDATIONS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	80013X	\N	\N	\N
8625	INONDATIONS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08038Y	\N	\N	\N
8626	INONDATIONS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	95037J	\N	\N	\N
8627	INONDATIONS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08063A	\N	\N	\N
8628	INONDATIONS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08033T	\N	\N	\N
8629	INONDATIONS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08021P	\N	\N	\N
8630	INONDATIONS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	95052H	\N	\N	\N
8631	INONDATIONS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	06005F	\N	\N	\N
8632	INONDATIONS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	90003B	\N	\N	\N
8633	INONDATIONS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	87003B	\N	\N	\N
8634	INONDATIONS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01027Q	\N	\N	\N
8635	INONDATIONS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	95031C	\N	\N	\N
8636	INONDATIONS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08065C	\N	\N	\N
8637	INONDATIONS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08041T	\N	\N	\N
8638	INONDATIONS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04048J	\N	\N	\N
8639	INONDATIONS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04041B	\N	\N	\N
8640	INONDATIONS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08042U	\N	\N	\N
8641	INONDATIONS	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	86049M	\N	\N	\N
8642	AGENCES	2012-02-15 00:00:00	2012-04-19 00:00:00	ANCIEN	\N	\N	\N	\N	04091M	\N	\N	\N
8643	AGENCES	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	96004D	\N	\N	2013-12-16 10:13:19
8644	AGENCES	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	98018T	\N	\N	2013-12-16 10:13:19
8645	AGENCES	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08022Q	\N	\N	2013-12-16 10:13:19
8646	AGENCES	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01027Q	\N	\N	2013-12-16 10:13:19
8647	AGENCES	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	95038K	\N	\N	2013-12-16 10:13:19
8648	AGENCES	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	99004R	\N	\N	2013-12-16 10:13:19
8649	AGENCES	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08034U	\N	\N	2013-12-16 10:13:19
8650	AGENCES	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08039A	\N	\N	2013-12-16 10:13:19
8651	AGENCES	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	95062K	\N	\N	2013-12-16 10:13:19
8652	AGENCES	2012-02-15 00:00:00	2012-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	\N	\N	\N
8653	AGENCES	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11068S	\N	\N	2013-12-16 10:13:19
8654	AGENCES	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04066L	\N	\N	2013-12-16 10:13:19
8655	AGENCES	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08038Y	\N	\N	2013-12-16 10:13:19
8656	AGENCES	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11096W	\N	\N	2013-12-16 10:13:19
8657	AGENCES	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11110B	\N	\N	2013-12-16 10:13:19
8658	AGENCES	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01037S	\N	\N	2013-12-16 10:13:19
8659	AGENCES	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11026G	\N	\N	2013-12-16 10:13:19
8660	AGENCES	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11077T	\N	\N	2013-12-16 10:13:19
8661	AGENCES	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	98046X	\N	\N	2013-12-16 10:13:19
8662	AGENCES	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	98032R	\N	\N	2013-12-16 10:13:19
8663	AGENCES	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11082Q	\N	\N	2013-12-16 10:13:19
8664	AGENCES	2012-02-15 00:00:00	2012-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	\N	\N	2013-12-16 10:13:19
8756	CDD	2012-02-21 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	11094U	\N	\N	2014-10-08 16:47:50
8757	CDD	2012-02-21 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98037W	\N	\N	2014-09-28 14:31:42
8758	CDD	2012-02-21 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08049C	\N	\N	2014-09-28 19:07:43
8759	CDD	2012-02-21 00:00:00	2013-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	96003C	\N	\N	\N
8760	CDD	2012-02-21 00:00:00	2013-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	08036W	\N	\N	\N
8761	2012CMP9	2012-02-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
8762	2012CMP9	2012-02-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04056J	TITULAIRE	\N	2017-09-24 18:17:56
8763	2012CMP9	2012-02-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	95063L	TITULAIRE	\N	\N
8764	2012CMP9	2012-02-15 00:00:00	2012-09-19 00:00:00	ANCIEN	\N	\N	\N	\N	95011X	TITULAIRE	\N	\N
8765	2012CMP9	2012-02-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95005A	TITULAIRE	\N	2014-09-28 17:40:23
8766	2012CMP9	2012-02-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	10015M	TITULAIRE	\N	\N
8767	2012CMP9	2012-02-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04074L	TITULAIRE	\N	2017-09-24 17:15:15
8768	2012CMP9	2012-02-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11029K	SUPPLEANT	\N	2017-09-24 17:09:24
8769	2012CMP9	2012-02-15 00:00:00	2017-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	01007L	SUPPLEANT	\N	2017-07-24 09:56:26
8770	2012CMP9	2012-02-15 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	SUPPLEANT	\N	2015-10-13 14:23:40
8771	2012CMP9	2012-02-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08032S	SUPPLEANT	\N	2014-09-28 17:34:16
8772	2012CMP9	2012-02-15 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	SUPPLEANT	\N	2017-06-19 12:20:59
9640	2013CMP247	2013-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	11090Q	SUPPLEANT	\N	\N
9632	2013CMP247	2013-10-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92031P	TITULAIRE	\N	2017-09-24 18:16:52
9633	2013CMP247	2013-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	04070G	TITULAIRE	\N	\N
9634	2013CMP247	2013-10-03 00:00:00	2018-08-06 00:00:00	ANCIEN	\N	\N	\N	\N	95015C	SUPPLEANT	\N	\N
9635	2013CMP247	2013-10-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11042G	SUPPLEANT	\N	2017-09-24 17:35:15
9636	2013CMP247	2013-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	11083R	SUPPLEANT	\N	\N
9637	2013CMP247	2013-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	12041X	SUPPLEANT	\N	\N
9638	2013CMP247	2013-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	11104D	SUPPLEANT	\N	\N
9639	2013CMP247	2013-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	04057K	SUPPLEANT	\N	\N
9679	2013CMP27	2013-11-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	01048V	TITULAIRE	\N	\N
9683	SOCI	2013-11-19 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	08035V	\N	2013-11-19 11:20:31	2014-10-08 17:03:08
9684	AFCL	2013-11-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98030P	\N	2013-11-19 11:24:46	2014-09-28 13:19:48
9685	GOUVERNANCE	2013-11-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89017R	\N	2013-11-19 18:42:27	2014-11-18 11:50:10
9686	GOUVERNANCE	2013-11-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	\N	2013-11-19 18:42:28	2014-11-18 11:50:10
9687	GOUVERNANCE	2013-11-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11039M	\N	2013-11-19 18:42:36	2014-11-18 11:50:10
9688	GOUVERNANCE	2013-11-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04054G	\N	2013-11-19 18:42:46	2014-11-18 11:50:10
9689	GOUVERNANCE	2013-11-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	96004D	\N	2013-11-19 18:42:53	2014-11-18 11:50:10
9690	GOUVERNANCE	2013-11-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08043V	\N	2013-11-19 18:43:00	2014-11-18 11:50:10
9691	GOUVERNANCE	2013-11-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04040A	\N	2013-11-19 18:43:06	2014-11-18 11:50:10
9692	GOUVERNANCE	2013-11-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11095V	\N	2013-11-19 18:43:14	2014-11-18 11:50:10
9693	GOUVERNANCE	2013-11-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11042G	\N	2013-11-19 18:43:23	2014-11-18 11:50:10
9694	GOUVERNANCE	2013-11-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	\N	2013-11-19 18:43:33	2014-11-18 11:50:10
9695	GOUVERNANCE	2013-11-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98018T	\N	2013-11-19 18:43:40	2014-11-18 11:50:10
9696	GOUVERNANCE	2013-11-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92018S	\N	2013-11-19 18:43:47	2014-11-18 11:50:10
9697	GOUVERNANCE	2013-11-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01024M	\N	2013-11-19 18:43:55	2014-11-18 11:50:10
9698	GOUVERNANCE	2013-11-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08022Q	\N	2013-11-19 18:44:01	2014-11-18 11:50:10
9699	GOUVERNANCE	2013-11-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11051H	\N	2013-11-19 18:44:10	2014-11-18 11:50:10
9700	GOUVERNANCE	2013-11-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11107G	\N	2013-11-19 18:44:18	2014-11-18 11:50:10
9701	GOUVERNANCE	2013-11-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08018U	\N	2013-11-19 18:44:27	2014-11-18 11:50:10
9702	GOUVERNANCE	2013-11-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04035D	\N	2013-11-19 18:44:32	2014-11-18 11:50:10
9704	GOUVERNANCE	2013-11-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11015D	\N	2013-11-19 18:44:46	2014-11-18 11:50:10
9705	GOUVERNANCE	2013-11-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95038K	\N	2013-11-19 18:44:53	2014-09-28 17:40:23
9706	GOUVERNANCE	2013-11-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08044W	\N	2013-11-19 18:44:59	2014-11-18 11:50:10
9708	GOUVERNANCE	2013-11-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11026G	\N	2013-11-19 18:45:11	2014-11-18 11:50:10
9709	GOUVERNANCE	2013-11-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08039A	\N	2013-11-19 18:45:17	2014-11-18 11:50:10
9711	GOUVERNANCE	2013-11-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11104D	\N	2013-11-19 18:45:34	2014-11-18 11:50:10
9712	GOUVERNANCE	2013-11-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	\N	2013-11-19 18:45:41	2014-11-18 11:50:10
9714	GOUVERNANCE	2013-11-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04070G	\N	2013-11-19 18:45:57	2014-11-18 11:50:10
9715	GOUVERNANCE	2013-11-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98010K	\N	2013-11-19 18:46:05	2014-09-28 17:27:35
9716	GOUVERNANCE	2013-11-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04033B	\N	2013-11-19 18:46:11	2014-11-18 11:50:10
9717	GOUVERNANCE	2013-11-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04045F	\N	2013-11-19 18:46:18	2014-11-18 11:50:10
9748	ECOMOUV	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08049C	\N	2013-12-10 15:07:04	2014-09-28 19:07:43
9749	ECOMOUV	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11110B	\N	2013-12-10 15:07:16	2014-11-18 15:39:16
9750	ECOMOUV	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08022Q	\N	2013-12-10 15:07:27	2014-11-18 15:39:16
9751	ECOMOUV	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01027Q	\N	2013-12-10 15:07:37	2014-11-18 15:39:16
9752	ECOMOUV	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95036H	\N	2013-12-10 15:07:47	2014-09-28 17:31:42
9754	ECOMOUV	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01057W	\N	2013-12-10 15:08:18	2014-11-18 15:39:16
9755	ECOMOUV	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01061S	\N	2013-12-10 15:08:30	2014-11-18 15:39:16
9757	DOCUMENTSADM	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01060R	\N	2013-12-10 15:12:09	2014-11-18 15:39:56
9758	DOCUMENTSADM	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	\N	2013-12-10 15:12:20	2014-11-18 15:39:56
9827	2013CMP31	2013-12-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08014Q	TITULAIRE	\N	\N
9761	DOCUMENTSADM	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11060J	\N	2013-12-10 15:13:01	2014-11-18 15:39:56
9762	DOCUMENTSADM	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	\N	2013-12-10 15:13:09	2014-11-18 15:39:56
9763	DOCUMENTSADM	2013-12-10 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	01063U	\N	2013-12-10 15:13:16	2014-09-29 13:41:53
9764	DOCUMENTSADM	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	07030L	\N	2013-12-10 15:13:24	2014-09-28 17:03:41
9765	DOCUMENTSADM	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98041S	\N	2013-12-10 15:13:33	2014-09-28 16:42:05
9766	DOCUMENTSADM	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	\N	2013-12-10 15:13:41	2014-09-28 18:00:58
9768	DOCUMENTSADM	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	\N	2013-12-10 15:13:57	2014-11-18 15:39:56
9769	DOCUMENTSADM	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04043D	\N	2013-12-10 15:14:05	2014-11-18 15:39:56
9771	DOCUMENTSADM	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04069P	\N	2013-12-10 15:14:22	2014-09-28 17:31:41
9791	ECOMOUV	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08054Y	\N	2013-12-10 17:25:39	2014-09-28 12:39:09
9792	DOCUMENTSADM	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11056N	\N	2013-12-10 17:26:39	2014-11-18 15:39:56
9793	DOCUMENTSADM	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11034G	\N	2013-12-10 17:26:52	2014-11-18 15:39:56
9826	2013CMP31	2013-12-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	TITULAIRE	\N	2017-09-24 18:20:10
9828	2013CMP31	2013-12-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11088W	TITULAIRE	\N	2017-09-24 17:15:15
9829	2013CMP31	2013-12-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	11070L	TITULAIRE	\N	\N
9830	2013CMP31	2013-12-09 00:00:00	2018-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	98053W	TITULAIRE	\N	2018-05-31 10:52:17
9831	2013CMP31	2013-12-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	88008L	SUPPLEANT	\N	\N
9832	2013CMP31	2013-12-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	11110B	SUPPLEANT	\N	\N
9833	2013CMP31	2013-12-09 00:00:00	2015-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	11108H	SUPPLEANT	\N	2015-04-07 16:50:27
9834	2013CMP31	2013-12-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	99004R	SUPPLEANT	\N	\N
9883	COTISATIONS	2014-02-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11044J	\N	2014-02-25 16:14:04	2014-11-18 15:38:05
9884	COTISATIONS	2014-02-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04071H	\N	2014-02-25 16:14:19	2014-11-18 15:38:05
9886	COTISATIONS	2014-02-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95036H	\N	2014-02-25 16:14:56	2014-09-28 17:31:42
9887	COTISATIONS	2014-02-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01057W	\N	2014-02-25 16:15:06	2014-11-18 15:38:05
9888	COTISATIONS	2014-02-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	\N	2014-02-25 16:15:14	2018-01-25 13:10:11
9890	COTISATIONS	2014-02-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01048V	\N	2014-02-25 16:16:02	2014-11-18 15:38:05
9891	COTISATIONS	2014-02-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77043E	\N	2014-02-25 16:16:18	2014-09-28 16:59:41
9892	COTISATIONS	2014-02-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04088S	\N	2014-02-25 16:16:50	2014-11-18 15:38:05
9907	COTISATIONS	2014-02-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	\N	2014-02-25 17:20:59	2014-11-18 15:38:05
9908	COTISATIONS	2014-02-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04055H	\N	2014-02-25 17:21:21	2014-11-18 15:38:05
9910	COTISATIONS	2014-02-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04089T	\N	2014-02-25 17:23:55	2014-11-18 15:38:05
9911	COTISATIONS	2014-02-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	09001P	\N	2014-02-25 17:24:21	2014-11-18 15:38:05
9912	COTISATIONS	2014-02-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98032R	\N	2014-02-25 17:24:42	2014-11-18 15:38:05
9913	COTISATIONS	2014-02-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98010K	\N	2014-02-25 17:24:57	2014-09-28 17:27:35
9925	LOIS	2014-05-05 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	11053K	\N	2014-05-05 14:48:49	2014-10-08 16:54:39
9926	CDD	2014-05-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	09001P	\N	2014-05-05 14:50:48	2017-09-24 17:47:27
9935	NEANT	2014-05-09 00:00:00	2014-05-12 00:00:00	ANCIEN	\N	\N	\N	\N	14013P	\N	2014-05-09 11:29:04	2014-05-13 14:42:35
9936	NEANT	2014-05-09 00:00:00	2014-05-12 00:00:00	ANCIEN	\N	\N	\N	\N	14014Q	\N	2014-05-09 11:37:36	2014-05-13 14:42:54
9942	REGIONS	2014-06-18 00:00:00	2015-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	\N	2014-06-19 09:33:30	2015-04-07 18:21:18
9944	REGIONS	2014-06-18 00:00:00	2015-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	01027Q	\N	2014-06-19 09:33:52	2015-04-07 18:21:18
9945	REGIONS	2014-06-18 00:00:00	2015-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	01057W	\N	2014-06-19 09:33:59	2015-04-07 18:21:18
9947	REGIONS	2014-06-18 00:00:00	2015-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	99004R	\N	2014-06-19 09:34:18	2015-04-07 18:21:18
9734	2013CMP29	2013-11-29 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
9735	2013CMP29	2013-11-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	11040E	TITULAIRE	\N	\N
9736	2013CMP29	2013-11-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	TITULAIRE	\N	2017-09-24 18:20:10
9737	2013CMP29	2013-11-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	08011M	TITULAIRE	\N	\N
9740	2013CMP29	2013-11-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95037J	SUPPLEANT	\N	\N
9741	2013CMP29	2013-11-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92039X	SUPPLEANT	\N	2017-09-24 13:47:46
9742	2013CMP29	2013-11-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11088W	SUPPLEANT	\N	2017-09-24 17:15:15
9743	2013CMP29	2013-11-29 00:00:00	2015-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	11108H	SUPPLEANT	\N	2015-04-07 16:50:27
9744	2013CMP29	2013-11-29 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86049M	SUPPLEANT	\N	2014-09-28 18:03:38
9745	2013CMP29	2013-11-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	08061X	SUPPLEANT	\N	\N
9746	2013CMP29	2013-11-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	99004R	SUPPLEANT	\N	\N
9803	ECOMOUV	2013-12-17 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08032S	\N	2013-12-17 09:56:53	2014-09-28 17:34:16
9918	PROSTITUTION	2014-04-14 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08066D	\N	2014-04-14 16:11:36	2014-09-28 19:03:23
9919	NEANT	2014-04-23 00:00:00	2014-05-12 00:00:00	ANCIEN	\N	\N	\N	\N	09010Q	\N	2014-04-23 09:57:24	2014-05-13 14:41:32
9923	NEANT	2014-05-05 00:00:00	2014-05-06 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	\N	2014-05-05 10:37:45	2014-05-07 09:32:54
9924	NEANT	2014-05-05 00:00:00	2014-05-06 00:00:00	ANCIEN	\N	\N	\N	\N	11027H	\N	2014-05-05 10:40:21	2014-05-07 12:20:13
9930	ETRD	2014-05-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11027H	\N	2014-05-07 00:00:00	2017-10-04 00:00:00
9931	LOIS	2014-05-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14012N	\N	2014-05-07 12:20:43	2014-09-28 16:54:10
9932	CDD	2014-05-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04090L	\N	2014-05-07 12:21:03	2014-09-28 19:29:39
9933	ETRD	2014-05-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11015D	\N	2014-05-07 12:21:26	2017-09-24 13:42:35
9957	REGIONS	2014-06-18 00:00:00	2014-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	98042T	\N	2014-06-19 09:48:27	2014-10-09 16:12:19
9956	REGIONS	2014-06-18 00:00:00	2014-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	01007L	\N	2014-06-19 09:48:16	2014-10-09 16:13:47
9958	REGIONS	2014-06-18 00:00:00	2015-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	11094U	\N	2014-06-19 09:48:34	2015-04-07 18:21:18
9979	REGIONS	2014-06-18 00:00:00	2015-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	\N	2014-06-19 11:14:27	2015-04-07 18:21:18
9980	REGIONS	2014-06-18 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08064B	\N	2014-06-19 11:14:40	2014-09-28 19:03:23
9987	NEANT	2014-08-27 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14018U	\N	2014-08-27 16:32:46	2014-10-08 17:09:40
9999	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14199E	\N	2014-09-28 14:31:41	2014-10-08 17:43:36
10053	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14251Q	\N	2014-09-28 18:32:19	2014-10-08 17:38:12
10055	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14121F	\N	2014-09-28 18:44:07	2014-10-08 17:06:34
10061	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14201E	\N	2014-09-28 18:59:41	2014-10-08 17:10:08
10131	ETRD	2014-10-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98029W	\N	2014-10-08 16:59:47	2017-10-04 19:51:43
10132	ETRD	2014-10-08 00:00:00	2015-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	08016S	\N	2014-10-08 17:00:38	2015-05-06 11:42:07
10134	ETRD	2014-10-08 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14039A	\N	2014-10-08 17:00:59	2017-10-04 19:11:24
10136	ETRD	2014-10-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	83042R	\N	2014-10-08 17:01:26	2017-09-24 17:48:21
10137	ETRD	2014-10-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14028W	\N	2014-10-08 17:01:47	2017-10-04 19:55:45
10138	AFCL	2014-10-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92015P	\N	2014-10-08 17:02:49	2017-09-24 13:14:55
10139	AFCL	2014-10-08 00:00:00	2020-08-03 00:00:00	ANCIEN	\N	\N	\N	\N	08035V	\N	2014-10-08 17:03:07	2017-10-04 19:43:04
10140	AFCL	2014-10-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14063N	\N	2014-10-08 17:03:34	2017-10-04 19:45:08
10143	AFCL	2014-10-08 00:00:00	2014-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	01062T	\N	2014-10-08 17:04:20	2015-01-05 16:08:38
10221	COMSPEAPU	2014-10-08 00:00:00	2015-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	11053K	\N	2014-10-08 18:09:25	2015-12-16 17:18:57
10222	COMSPEAPU	2014-10-08 00:00:00	2015-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	11080N	\N	2014-10-08 18:10:51	2015-12-16 17:18:58
10223	COMSPEAPU	2014-10-08 00:00:00	2015-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	01057W	\N	2014-10-08 18:11:02	2015-12-16 17:18:52
10224	COMSPEAPU	2014-10-08 00:00:00	2015-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	14157T	\N	2014-10-08 18:11:09	2015-12-16 17:19:01
10225	COMSPEAPU	2014-10-08 00:00:00	2015-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	14159V	\N	2014-10-08 18:11:54	2015-12-16 17:18:58
10226	COMSPEAPU	2014-10-08 00:00:00	2015-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	08025T	\N	2014-10-08 18:12:07	2015-12-16 17:18:54
10227	ETRD	2014-10-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11069T	\N	2014-10-08 18:14:12	2017-09-24 18:05:41
10228	FINC	2014-10-08 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	11083R	\N	2014-10-08 18:16:46	2017-10-04 19:19:03
10236	AFEU	2014-10-09 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08042U	\N	2014-10-09 09:40:26	2017-10-01 10:20:50
10237	AFEU	2014-10-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14135M	\N	2014-10-09 09:40:34	2017-10-05 14:42:43
10240	AFEU	2014-10-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95037J	\N	2014-10-09 10:40:47	2017-10-05 14:40:49
10241	AFEU	2014-10-09 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	11026G	\N	2014-10-09 10:41:01	2017-10-05 14:41:43
10242	AFEU	2014-10-09 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	98046X	\N	2014-10-09 10:41:10	2017-09-25 09:56:00
10243	AFEU	2014-10-09 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14001X	\N	2014-10-09 10:41:21	2017-10-05 14:41:58
10246	AFEU	2014-10-09 00:00:00	2014-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	01062T	\N	2014-10-09 10:42:07	2014-12-18 16:15:04
10247	AFEU	2014-10-09 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14089Y	\N	2014-10-09 11:08:47	2017-10-05 14:39:15
10249	AFEU	2014-10-09 00:00:00	2016-04-26 00:00:00	ANCIEN	\N	\N	\N	\N	95049N	\N	2014-10-09 11:09:06	2016-04-26 14:12:00
10250	AFEU	2014-10-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04080J	\N	2014-10-09 11:09:16	2017-09-24 17:47:27
10252	REGIONS	2014-10-09 00:00:00	2015-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	\N	2014-10-09 15:22:39	2015-04-07 18:21:18
10253	REGIONS	2014-10-09 00:00:00	2015-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	08014Q	\N	2014-10-09 15:29:16	2015-04-07 18:21:18
10254	REGIONS	2014-10-09 00:00:00	2015-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	14083S	\N	2014-10-09 15:59:48	2015-04-07 18:21:18
10255	REGIONS	2014-10-09 00:00:00	2015-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	98029W	\N	2014-10-09 16:00:13	2015-04-07 18:21:18
10266	PROSTITUTION	2014-10-09 00:00:00	2016-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	14239U	\N	2014-10-09 16:19:56	2016-07-07 18:06:54
10257	REGIONS	2014-10-09 00:00:00	2015-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	04095R	\N	2014-10-09 16:02:40	2015-04-07 18:21:18
10258	REGIONS	2014-10-09 00:00:00	2015-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	08044W	\N	2014-10-09 16:03:03	2015-04-07 18:21:18
10259	REGIONS	2014-10-09 00:00:00	2015-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	14073Q	\N	2014-10-09 16:04:33	2015-04-07 18:21:18
10260	REGIONS	2014-10-09 00:00:00	2015-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	14159V	\N	2014-10-09 16:04:49	2015-04-07 18:21:18
10261	REGIONS	2014-10-09 00:00:00	2015-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	11098Y	\N	2014-10-09 16:05:07	2015-04-07 18:21:18
10262	REGIONS	2014-10-09 00:00:00	2015-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	95049N	\N	2014-10-09 16:05:36	2015-04-07 18:21:18
10263	REGIONS	2014-10-09 00:00:00	2015-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	14028W	\N	2014-10-09 16:05:56	2015-04-07 18:21:18
10264	REGIONS	2014-10-09 00:00:00	2015-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	11097X	\N	2014-10-09 16:06:28	2015-04-07 18:21:18
10265	REGIONS	2014-10-09 00:00:00	2015-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	11066Q	\N	2014-10-09 16:06:51	2015-04-07 18:21:18
10267	PROSTITUTION	2014-10-09 00:00:00	2016-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	14065Q	\N	2014-10-09 16:20:55	2016-07-07 18:11:25
10269	PROSTITUTION	2014-10-09 00:00:00	2016-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	14053L	\N	2014-10-09 16:21:46	2016-07-07 18:14:42
10271	PROSTITUTION	2014-10-09 00:00:00	2016-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	14042U	\N	2014-10-09 16:23:58	2016-07-07 18:19:14
10272	PROSTITUTION	2014-10-09 00:00:00	2016-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	14087W	\N	2014-10-09 16:24:37	2016-07-07 18:19:39
10274	PROSTITUTION	2014-10-09 00:00:00	2016-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	08041T	\N	2014-10-09 16:25:27	2016-07-07 18:27:10
10275	PROSTITUTION	2014-10-09 00:00:00	2016-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	07026Q	\N	2014-10-09 16:26:01	2016-07-07 18:28:22
10277	PROSTITUTION	2014-10-09 00:00:00	2016-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	08044W	\N	2014-10-09 16:26:46	2016-07-07 18:29:48
10278	PROSTITUTION	2014-10-09 00:00:00	2016-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	04079R	\N	2014-10-09 16:27:14	2016-07-07 18:31:18
10280	PROSTITUTION	2014-10-09 00:00:00	2016-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	11043H	\N	2014-10-09 16:28:10	2016-07-07 18:33:24
10281	PROSTITUTION	2014-10-09 00:00:00	2016-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	98035U	\N	2014-10-09 16:28:26	2016-07-07 18:33:46
10282	PROSTITUTION	2014-10-09 00:00:00	2016-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	\N	2014-10-09 16:28:47	2016-07-07 18:34:33
10283	DJIHAD	2014-10-14 00:00:00	2015-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	\N	2014-10-14 17:40:16	2015-10-07 10:48:17
10284	DJIHAD	2014-10-14 00:00:00	2015-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	11033F	\N	2014-10-14 17:40:20	2015-10-07 10:48:17
10285	DJIHAD	2014-10-14 00:00:00	2015-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	08058D	\N	2014-10-14 17:40:28	2015-10-07 10:48:17
10286	DJIHAD	2014-10-14 00:00:00	2015-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	11080N	\N	2014-10-14 17:40:41	2015-10-07 10:48:17
11276	CDD	2015-02-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14237S	\N	2015-02-16 00:00:00	2017-10-04 00:00:00
9738	2013CMP29	2013-11-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	88008L	TITULAIRE	\N	\N
9797	DOCUMENTSADM	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95005A	\N	2013-12-10 17:48:15	2014-09-28 17:40:23
9798	DOCUMENTSADM	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11029K	\N	2013-12-10 17:48:27	2014-11-18 15:39:56
9799	DOCUMENTSADM	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01024M	\N	2013-12-10 17:49:01	2014-11-18 15:39:56
9800	DOCUMENTSADM	2013-12-10 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	12035A	\N	2013-12-10 17:49:37	2014-05-05 10:34:09
9802	DOCUMENTSADM	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	05011Y	\N	2013-12-10 17:50:15	2014-09-28 13:47:05
9835	2013CMP31	2013-12-09 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77043E	SUPPLEANT	\N	2014-09-28 16:59:41
9836	2013CMP31	2013-12-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	08011M	SUPPLEANT	\N	\N
9837	2013CMP31	2013-12-09 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	SUPPLEANT	\N	\N
9841	PROSTITUTION	2014-01-22 00:00:00	2014-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	11056N	\N	2014-01-21 17:10:05	2014-10-09 16:22:21
9843	PROSTITUTION	2014-01-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04051D	\N	2014-01-21 17:10:23	2014-09-28 17:07:41
9844	PROSTITUTION	2014-01-22 00:00:00	2016-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	09001P	\N	2014-01-21 17:10:39	2016-07-07 18:30:09
9846	PROSTITUTION	2014-01-22 00:00:00	2014-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	11096W	\N	2014-01-21 17:10:57	2014-10-09 16:24:23
9847	PROSTITUTION	2014-01-22 00:00:00	2016-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	11012A	\N	2014-01-21 17:11:13	2016-07-07 18:32:45
9848	PROSTITUTION	2014-01-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95009E	\N	2014-01-21 17:11:49	2014-09-28 12:56:42
9849	PROSTITUTION	2014-01-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13003V	\N	2014-01-21 17:13:19	2014-09-28 17:14:21
9850	PROSTITUTION	2014-01-22 00:00:00	2016-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	10006L	\N	2014-01-21 17:13:32	2016-07-07 18:18:24
9851	PROSTITUTION	2014-01-22 00:00:00	2016-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	04036E	\N	2014-01-21 17:13:45	2016-07-07 18:30:33
9852	PROSTITUTION	2014-01-22 00:00:00	2016-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	\N	2014-01-21 17:13:52	2016-07-07 18:32:24
9853	PROSTITUTION	2014-01-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04099V	\N	2014-01-21 17:14:00	2014-09-28 16:59:41
9856	PROSTITUTION	2014-01-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01064V	\N	2014-01-21 17:16:06	2014-09-28 17:12:41
9857	PROSTITUTION	2014-01-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13001T	\N	2014-01-21 17:16:16	2014-09-28 17:58:04
9858	PROSTITUTION	2014-01-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	94003T	\N	2014-01-21 17:16:25	2014-09-28 13:16:32
9859	PROSTITUTION	2014-01-22 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	01063U	\N	2014-01-21 17:16:33	2014-09-29 13:41:53
9861	PROSTITUTION	2014-01-22 00:00:00	2016-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	\N	2014-01-21 17:16:46	2016-07-07 18:35:27
9862	PROSTITUTION	2014-01-22 00:00:00	2016-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	11036J	\N	2014-01-21 17:16:53	2016-07-07 18:06:06
9863	PROSTITUTION	2014-01-22 00:00:00	2016-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	08043V	\N	2014-01-21 17:16:59	2016-07-07 18:14:15
9864	PROSTITUTION	2014-01-22 00:00:00	2016-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	80013X	\N	2014-01-21 17:17:06	2016-07-07 18:17:39
9865	PROSTITUTION	2014-01-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13005X	\N	2014-01-21 17:17:16	2014-09-28 18:00:58
9866	PROSTITUTION	2014-01-22 00:00:00	2016-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	11061K	\N	2014-01-21 17:17:25	2016-07-07 18:26:18
9867	PROSTITUTION	2014-01-22 00:00:00	2016-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	01011G	\N	2014-01-21 17:17:32	2016-07-07 18:27:49
9868	PROSTITUTION	2014-01-22 00:00:00	2014-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	11084S	\N	2014-01-21 17:17:37	2014-10-09 16:31:06
9869	PROSTITUTION	2014-01-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08032S	\N	2014-01-21 17:17:44	2014-09-28 17:34:16
9871	PROSTITUTION	2014-01-22 00:00:00	2016-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	11067R	\N	2014-01-21 17:18:07	2016-07-07 18:31:39
9872	PROSTITUTION	2014-01-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04084N	\N	2014-01-21 17:18:24	2014-09-28 13:40:33
9873	PROSTITUTION	2014-01-22 00:00:00	2014-09-01 00:00:00	ANCIEN	\N	\N	\N	\N	96007G	\N	2014-01-21 17:18:31	2014-09-01 10:21:13
9874	PROSTITUTION	2014-01-22 00:00:00	2014-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	11045K	\N	2014-01-21 17:18:37	2014-04-14 16:10:15
9875	PROSTITUTION	2014-01-22 00:00:00	2016-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	\N	2014-01-21 17:18:46	2016-07-07 18:35:56
9876	PROSTITUTION	2014-01-22 00:00:00	2016-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	11033F	\N	2014-01-21 17:18:55	2016-07-07 18:10:08
9877	PROSTITUTION	2014-01-22 00:00:00	2014-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	89017R	\N	2014-01-21 17:19:03	2014-01-23 14:21:31
9894	COTISATIONS	2014-02-25 00:00:00	2014-09-16 00:00:00	ANCIEN	\N	\N	\N	\N	98052V	\N	2014-02-25 16:22:34	2014-09-16 14:55:28
9895	COTISATIONS	2014-02-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14002L	\N	2014-02-25 16:34:17	2014-09-28 18:32:43
9896	COTISATIONS	2014-02-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11077T	\N	2014-02-25 16:34:26	2014-11-18 15:38:05
9897	COTISATIONS	2014-02-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12042Y	\N	2014-02-25 16:34:32	2014-11-18 15:38:05
9898	COTISATIONS	2014-02-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11110B	\N	2014-02-25 16:34:42	2014-11-18 15:38:05
9900	COTISATIONS	2014-02-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	\N	2014-02-25 16:34:53	2014-11-18 15:38:05
9901	COTISATIONS	2014-02-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14001X	\N	2014-02-25 16:35:00	2014-11-18 15:38:05
9903	COTISATIONS	2014-02-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08038Y	\N	2014-02-25 16:35:21	2014-11-18 15:38:05
9904	COTISATIONS	2014-02-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13002U	\N	2014-02-25 16:35:27	2014-11-18 15:38:05
9906	COTISATIONS	2014-02-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08033T	\N	2014-02-25 16:36:17	2014-09-28 17:27:35
9915	CDD	2014-04-10 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	11090Q	\N	2014-04-10 10:15:52	2014-10-08 17:15:26
9916	AFCL	2014-04-10 00:00:00	2014-04-24 00:00:00	ANCIEN	\N	\N	\N	\N	89014N	\N	2014-04-10 10:17:16	2014-04-25 17:05:01
9938	AFCL	2014-05-13 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	09010Q	\N	2014-05-13 14:41:32	2014-09-28 17:07:41
9939	CDD	2014-05-13 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14013P	\N	2014-05-13 14:42:35	2014-10-08 17:11:42
9941	REGIONS	2014-06-18 00:00:00	2015-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	11065P	\N	2014-06-18 22:21:48	2015-04-07 18:21:18
9959	REGIONS	2014-06-18 00:00:00	2015-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	89017R	\N	2014-06-19 10:57:51	2015-04-07 18:21:18
9961	REGIONS	2014-06-18 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98038X	\N	2014-06-19 11:02:47	2014-09-28 17:38:26
9962	REGIONS	2014-06-18 00:00:00	2015-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	\N	2014-06-19 11:03:01	2015-04-07 18:21:18
9982	AFCL	2014-07-02 00:00:00	2014-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	14017T	\N	2014-07-02 12:07:37	2014-07-04 14:37:06
9988	NEANT	2014-09-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	83042R	\N	2014-09-01 10:22:08	2014-10-08 17:01:27
9965	REGIONS	2014-06-18 00:00:00	2015-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	11084S	\N	2014-06-19 11:03:20	2015-04-07 18:21:18
9990	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14193X	\N	2014-09-28 12:32:22	2014-10-08 17:38:28
9968	REGIONS	2014-06-18 00:00:00	2014-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	11035H	\N	2014-06-19 11:08:36	2014-10-09 16:11:16
9969	REGIONS	2014-06-18 00:00:00	2015-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	\N	2014-06-19 11:08:50	2015-04-07 18:21:18
9970	REGIONS	2014-06-18 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08027V	\N	2014-06-19 11:09:40	2014-09-28 17:34:16
9971	REGIONS	2014-06-18 00:00:00	2015-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	11108H	\N	2014-06-19 11:09:50	2015-04-07 18:21:18
9972	REGIONS	2014-06-18 00:00:00	2014-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	11039M	\N	2014-06-19 11:09:57	2014-10-09 15:27:27
9973	REGIONS	2014-06-18 00:00:00	2014-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	11112D	\N	2014-06-19 11:10:06	2014-10-09 16:15:25
9974	REGIONS	2014-06-18 00:00:00	2014-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	11032E	\N	2014-06-19 11:10:13	2014-10-09 16:09:56
9975	REGIONS	2014-06-18 00:00:00	2015-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	08060W	\N	2014-06-19 11:10:20	2015-04-07 18:21:18
9976	REGIONS	2014-06-18 00:00:00	2014-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	04079R	\N	2014-06-19 11:10:29	2014-10-09 16:16:34
9977	REGIONS	2014-06-18 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	03001N	\N	2014-06-19 11:10:35	2014-09-28 13:40:33
9978	REGIONS	2014-06-18 00:00:00	2014-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	11072N	\N	2014-06-19 11:10:48	2014-10-09 16:17:12
9991	NEANT	2014-09-29 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14042U	\N	2014-09-28 12:34:20	2014-10-20 10:49:48
9992	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14195A	\N	2014-09-28 12:44:31	2014-10-08 17:24:40
9993	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14197C	\N	2014-09-28 12:54:15	2014-10-08 16:49:13
9994	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14103D	\N	2014-09-28 13:06:30	2014-10-08 16:45:15
9995	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	05004A	\N	2014-09-28 13:16:32	2014-10-08 17:42:00
10000	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14030Q	\N	2014-09-28 16:40:49	2014-10-08 16:51:17
10001	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14031R	\N	2014-09-28 16:40:49	2014-10-08 17:40:23
10002	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14137P	\N	2014-09-28 16:42:03	2014-10-08 16:52:28
10003	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14133K	\N	2014-09-28 16:42:03	2014-10-08 17:32:33
10004	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14105F	\N	2014-09-28 16:49:55	2014-10-08 17:32:40
10005	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14109K	\N	2014-09-28 16:49:55	2014-10-08 17:03:59
10006	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14205J	\N	2014-09-28 16:54:08	2014-10-08 16:47:37
9641	2013CMP25	2013-10-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
9642	2013CMP25	2013-10-16 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04084N	TITULAIRE	\N	2014-09-28 13:40:33
9643	2013CMP25	2013-10-16 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08032S	TITULAIRE	\N	2014-09-28 17:34:16
9644	2013CMP25	2013-10-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	11056N	TITULAIRE	\N	\N
9656	2013CMP26	2013-10-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04084N	TITULAIRE	\N	2014-09-28 13:40:33
9719	2013CMP28	2013-11-18 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08037X	TITULAIRE	\N	2014-09-28 17:34:16
9722	2013CMP28	2013-11-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	11031D	TITULAIRE	\N	\N
9723	2013CMP28	2013-11-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	11103C	TITULAIRE	\N	\N
9725	2013CMP28	2013-11-18 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04051D	TITULAIRE	\N	2014-09-28 17:07:41
9727	2013CMP28	2013-11-18 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10003H	SUPPLEANT	\N	2014-09-28 17:38:26
9728	2013CMP28	2013-11-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	SUPPLEANT	\N	2017-09-24 13:44:49
9731	2013CMP28	2013-11-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	11097X	SUPPLEANT	\N	\N
9732	2013CMP28	2013-11-18 00:00:00	2014-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	08046Y	SUPPLEANT	\N	\N
9772	DOCUMENTSADM	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10003H	\N	2013-12-10 16:45:48	2014-09-28 17:38:26
9773	DOCUMENTSADM	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	\N	2013-12-10 16:45:55	2014-11-18 15:39:56
9774	DOCUMENTSADM	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11074Q	\N	2013-12-10 16:46:04	2014-11-18 15:39:56
9775	DOCUMENTSADM	2013-12-10 00:00:00	2014-09-01 00:00:00	ANCIEN	\N	\N	\N	\N	96007G	\N	2013-12-10 16:46:10	2014-09-01 10:21:13
9776	DOCUMENTSADM	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98030P	\N	2013-12-10 16:46:19	2014-09-28 13:19:48
9777	DOCUMENTSADM	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08012N	\N	2013-12-10 16:46:34	2014-11-18 15:39:56
9778	DOCUMENTSADM	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	\N	2013-12-10 16:46:41	2014-11-18 15:39:56
9779	DOCUMENTSADM	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11104D	\N	2013-12-10 16:46:49	2014-11-18 15:39:56
9780	DOCUMENTSADM	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08037X	\N	2013-12-10 16:47:01	2014-09-28 17:34:16
9781	DOCUMENTSADM	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04045F	\N	2013-12-10 16:47:20	2014-11-18 15:39:56
9782	DOCUMENTSADM	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08024S	\N	2013-12-10 16:47:30	2014-11-18 15:39:56
9783	ECOMOUV	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11107G	\N	2013-12-10 16:48:04	2014-11-18 15:39:16
9784	ECOMOUV	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08045X	\N	2013-12-10 16:48:12	2014-09-28 17:00:59
9785	ECOMOUV	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	03001N	\N	2013-12-10 16:48:19	2014-09-28 13:40:33
9786	ECOMOUV	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	\N	2013-12-10 16:48:26	2014-11-18 15:39:16
9787	ECOMOUV	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98037W	\N	2013-12-10 16:48:33	2014-09-28 14:31:42
9788	ECOMOUV	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04065K	\N	2013-12-10 16:48:40	2014-09-28 17:31:42
9789	ECOMOUV	2013-12-10 00:00:00	2013-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	11041F	\N	2013-12-10 16:48:46	2013-12-17 09:59:48
9790	ECOMOUV	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11065P	\N	2013-12-10 16:49:12	2014-11-18 15:39:16
9794	ECOMOUV	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01008M	\N	2013-12-10 17:37:07	2014-11-18 15:39:16
9795	ECOMOUV	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11053K	\N	2013-12-10 17:37:16	2014-11-18 15:39:16
9796	ECOMOUV	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11070L	\N	2013-12-10 17:37:47	2014-11-18 15:39:16
9811	NEANT	2014-01-01 00:00:00	2014-01-06 00:00:00	ANCIEN	\N	\N	\N	\N	14001X	\N	2014-01-02 15:26:53	2014-01-07 10:46:27
9839	AFCL	2014-01-07 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14001X	\N	2014-01-07 10:46:26	2014-10-08 16:58:47
9840	FINC	2014-01-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11042G	\N	2014-01-07 10:47:37	2017-09-24 17:35:15
9881	SOCI	2014-02-21 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14002L	\N	2014-02-21 11:14:59	2014-09-28 18:32:43
9921	NEANT	2014-05-05 00:00:00	2014-05-06 00:00:00	ANCIEN	\N	\N	\N	\N	04090L	\N	2014-05-05 10:31:01	2014-05-07 12:21:03
9922	NEANT	2014-05-05 00:00:00	2014-05-06 00:00:00	ANCIEN	\N	\N	\N	\N	08064B	\N	2014-05-05 10:32:08	2014-05-07 09:36:43
9927	FINC	2014-05-07 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	\N	2014-05-07 09:32:54	2014-10-08 17:07:12
9928	CDD	2014-05-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08064B	\N	2014-05-07 09:36:42	2014-09-28 19:03:23
9929	COMAPLEG	2014-05-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08064B	\N	2014-05-07 09:37:02	2014-09-28 19:03:23
9948	REGIONS	2014-06-18 00:00:00	2014-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	86034E	\N	2014-06-19 09:34:24	2014-10-09 16:15:51
9949	REGIONS	2014-06-18 00:00:00	2015-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	08034U	\N	2014-06-19 09:34:31	2015-04-07 18:21:18
9950	REGIONS	2014-06-18 00:00:00	2015-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	01048V	\N	2014-06-19 09:34:43	2015-04-07 18:21:18
9951	REGIONS	2014-06-18 00:00:00	2015-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	86044G	\N	2014-06-19 09:34:50	2015-04-07 18:21:18
9952	REGIONS	2014-06-18 00:00:00	2015-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	95059Q	\N	2014-06-19 09:34:56	2015-04-07 18:21:18
9953	REGIONS	2014-06-18 00:00:00	2015-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	04033B	\N	2014-06-19 09:35:02	2015-04-07 18:21:18
9954	REGIONS	2014-06-18 00:00:00	2015-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	01058X	\N	2014-06-19 09:35:11	2015-04-07 18:21:18
9955	REGIONS	2014-06-18 00:00:00	2015-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	\N	2014-06-19 09:35:18	2015-04-07 18:21:18
9983	SOCI	2014-07-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14017T	\N	2014-07-04 14:37:06	2017-09-24 16:24:51
9986	FINC	2014-07-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11057P	\N	2014-07-22 12:09:43	2017-09-24 18:23:22
10038	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14233N	\N	2014-09-28 17:35:38	2014-10-08 16:53:24
10039	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14235Q	\N	2014-09-28 17:38:25	2014-10-08 17:32:26
10040	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14157T	\N	2014-09-28 17:38:25	2014-10-08 17:41:02
10048	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14187A	\N	2014-09-28 17:58:04	2014-10-08 17:12:17
10049	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14051J	\N	2014-09-28 18:00:57	2014-10-08 16:54:15
10050	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14053L	\N	2014-09-28 18:00:57	2014-10-08 17:24:15
10051	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14247U	\N	2014-09-28 18:03:38	2014-10-08 16:52:09
10054	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14253S	\N	2014-09-28 18:32:41	2014-10-08 17:38:18
10059	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14151M	\N	2014-09-28 18:58:20	2014-10-08 17:05:53
10063	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14111D	\N	2014-09-28 19:03:23	2014-10-08 17:19:14
10064	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14071N	\N	2014-09-28 19:05:58	2014-10-08 17:26:09
10065	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14119M	\N	2014-09-28 19:05:58	2014-10-08 17:26:02
10075	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14261S	\N	2014-09-29 09:03:10	2014-10-08 17:09:12
10076	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14039A	\N	2014-09-29 09:05:47	2014-10-08 17:01:00
10077	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14043V	\N	2014-09-29 09:08:32	2014-10-08 16:57:21
10078	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14044W	\N	2014-09-29 09:08:32	2014-10-08 16:54:49
10079	NEANT	2014-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	86034E	\N	2014-10-03 00:00:00	2017-10-05 00:00:00
10144	SOCI	2014-10-08 00:00:00	2015-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	08055A	\N	2014-10-08 17:05:05	2015-07-10 11:24:50
10145	SOCI	2014-10-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04066L	\N	2014-10-08 17:05:13	2017-09-24 17:47:28
10146	SOCI	2014-10-08 00:00:00	2015-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	11051H	\N	2014-10-08 17:05:34	2015-03-03 10:16:55
10148	SOCI	2014-10-08 00:00:00	2015-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	95037J	\N	2014-10-08 17:06:19	2015-05-06 11:42:37
10149	SOCI	2014-10-08 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14121F	\N	2014-10-08 17:06:33	2017-10-04 18:50:28
10150	SOCI	2014-10-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14227Q	\N	2014-10-08 17:07:01	2017-10-04 20:07:23
10151	SOCI	2014-10-08 00:00:00	2017-08-06 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	\N	2014-10-08 17:07:11	2017-08-07 16:31:39
10153	CDD	2014-10-08 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14261S	\N	2014-10-08 17:09:11	2017-10-04 18:53:19
10154	SOCI	2014-10-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14018U	\N	2014-10-08 17:09:39	2017-09-24 18:49:56
10156	AFCL	2014-10-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14201E	\N	2014-10-08 17:10:07	2017-10-04 19:42:00
10157	ETRD	2014-10-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11096W	\N	2014-10-08 17:10:28	2017-09-24 18:17:56
10158	CAE	2014-10-08 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	14013P	\N	2014-10-08 17:11:41	2017-06-19 16:06:01
10159	CAE	2014-10-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11098Y	\N	2014-10-08 17:11:49	2017-09-24 17:14:26
10160	CAE	2014-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14187A	\N	2014-10-08 00:00:00	2017-10-04 00:00:00
10161	CAE	2014-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14033T	\N	2014-10-08 00:00:00	2017-10-04 00:00:00
10162	CAE	2014-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08015R	\N	2014-10-08 00:00:00	2017-10-04 00:00:00
10163	CAE	2014-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11090Q	\N	2014-10-08 00:00:00	2017-10-04 00:00:00
10164	LOIS	2014-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14069U	\N	2014-10-08 00:00:00	2017-10-04 00:00:00
10166	LOIS	2014-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	\N	2014-10-08 00:00:00	2017-10-04 00:00:00
10167	LOIS	2014-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11010L	\N	2014-10-08 00:00:00	2017-10-04 00:00:00
9645	2013CMP25	2013-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04074L	TITULAIRE	\N	2017-09-24 17:15:15
9646	2013CMP25	2013-10-16 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-13 14:22:34
9647	2013CMP25	2013-10-16 00:00:00	2014-04-23 00:00:00	ANCIEN	\N	\N	\N	\N	95049N	TITULAIRE	\N	2014-04-23 09:56:25
9648	2013CMP25	2013-10-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	05008E	SUPPLEANT	\N	\N
9649	2013CMP25	2013-10-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	11033F	SUPPLEANT	\N	\N
9650	2013CMP25	2013-10-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	\N	\N
9651	2013CMP25	2013-10-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	SUPPLEANT	\N	\N
9652	2013CMP25	2013-10-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	08018U	SUPPLEANT	\N	\N
9653	2013CMP25	2013-10-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	11026G	SUPPLEANT	\N	\N
9654	2013CMP25	2013-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04079R	SUPPLEANT	\N	2017-09-24 17:47:27
9655	2013CMP26	2013-10-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
9657	2013CMP26	2013-10-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08032S	TITULAIRE	\N	2014-09-28 17:34:16
9658	2013CMP26	2013-10-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	11056N	TITULAIRE	\N	\N
9659	2013CMP26	2013-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04074L	TITULAIRE	\N	2017-09-24 17:15:15
9660	2013CMP26	2013-10-22 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-13 14:22:28
9661	2013CMP26	2013-10-22 00:00:00	2014-04-23 00:00:00	ANCIEN	\N	\N	\N	\N	95049N	TITULAIRE	\N	2014-04-23 09:56:25
9662	2013CMP26	2013-10-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	05008E	SUPPLEANT	\N	\N
9663	2013CMP26	2013-10-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	11033F	SUPPLEANT	\N	\N
9664	2013CMP26	2013-10-22 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	\N	\N
9665	2013CMP26	2013-10-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	SUPPLEANT	\N	\N
9666	2013CMP26	2013-10-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	08018U	SUPPLEANT	\N	\N
9667	2013CMP26	2013-10-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	11026G	SUPPLEANT	\N	\N
9668	2013CMP26	2013-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04079R	SUPPLEANT	\N	2017-09-24 17:47:27
9730	2013CMP28	2013-11-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	04092N	SUPPLEANT	\N	\N
9812	2013CMP30	2013-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
9813	2013CMP30	2013-12-16 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	99002P	TITULAIRE	\N	2017-06-19 12:20:22
9814	2013CMP30	2013-12-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11034G	TITULAIRE	\N	2017-09-24 17:55:12
9815	2013CMP30	2013-12-16 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-13 14:22:22
9816	2013CMP30	2013-12-16 00:00:00	2014-04-23 00:00:00	ANCIEN	\N	\N	\N	\N	95049N	TITULAIRE	\N	2014-04-23 09:56:25
9817	2013CMP30	2013-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
9818	2013CMP30	2013-12-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11037K	TITULAIRE	\N	2017-09-24 18:16:52
9819	2013CMP30	2013-12-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	\N	\N
9820	2013CMP30	2013-12-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	SUPPLEANT	\N	\N
9821	2013CMP30	2013-12-16 00:00:00	2015-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	11051H	SUPPLEANT	\N	2015-03-03 10:16:55
9822	2013CMP30	2013-12-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11107G	SUPPLEANT	\N	2017-09-24 17:06:55
9823	2013CMP30	2013-12-16 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	12035A	SUPPLEANT	\N	2014-05-05 10:34:09
9824	2013CMP30	2013-12-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	\N	\N
9920	NEANT	2014-05-05 00:00:00	2014-05-06 00:00:00	ANCIEN	\N	\N	\N	\N	14012N	\N	2014-05-05 10:30:19	2014-05-07 12:20:43
9989	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14191V	\N	2014-09-28 12:09:44	2014-10-08 17:35:00
9996	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14097Y	\N	2014-09-28 13:32:34	2014-10-08 17:00:53
10010	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14083S	\N	2014-09-28 17:00:59	2014-10-08 16:54:31
10011	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14207L	\N	2014-09-28 17:03:41	2014-10-08 16:48:58
10012	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14209N	\N	2014-09-28 17:03:41	2014-10-08 17:32:50
10013	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14211G	\N	2014-09-28 17:03:41	2014-10-08 17:37:16
10016	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14059S	\N	2014-09-28 17:07:07	2014-10-08 17:33:54
10021	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14093U	\N	2014-09-28 17:09:16	2014-10-08 17:39:36
10022	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14063N	\N	2014-09-28 17:09:16	2014-10-08 17:03:36
10056	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14255U	\N	2014-09-28 18:46:12	2014-10-08 16:42:51
10057	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	\N	2014-09-28 18:46:12	2014-10-08 17:18:27
10066	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14257W	\N	2014-09-28 19:07:43	2014-10-08 16:50:39
10070	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14034U	\N	2014-09-28 19:19:39	2014-10-08 16:43:22
10071	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14028W	\N	2014-09-28 19:19:39	2014-10-08 17:01:48
10073	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14175V	\N	2014-09-28 19:29:38	2014-10-08 17:42:07
10169	SOCI	2014-10-08 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14053L	\N	2014-10-08 17:24:14	2017-10-04 18:46:46
10171	SOCI	2014-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14217N	\N	2014-10-08 00:00:00	2017-10-04 00:00:00
10172	SOCI	2014-10-08 00:00:00	2014-12-27 00:00:00	ANCIEN	\N	\N	\N	\N	14129P	\N	2014-10-08 17:25:01	2014-12-29 15:40:09
10173	SOCI	2014-10-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14087W	\N	2014-10-08 17:25:14	2017-10-04 20:01:28
10174	SOCI	2014-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14026U	\N	2014-10-08 00:00:00	2017-10-04 00:00:00
10175	SOCI	2014-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14213J	\N	2014-10-08 00:00:00	2017-10-04 00:00:00
10176	SOCI	2014-10-08 00:00:00	2017-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	14037X	\N	2014-10-08 17:25:44	2017-07-24 09:58:00
10178	SOCI	2014-10-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14119M	\N	2014-10-08 17:26:01	2017-10-04 20:06:10
10179	SOCI	2014-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14071N	\N	2014-10-08 00:00:00	2017-10-04 00:00:00
10181	AFCL	2014-10-08 00:00:00	2017-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	14133K	\N	2014-10-08 17:32:32	2017-01-10 17:59:57
10182	AFCL	2014-10-08 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14105F	\N	2014-10-08 17:32:39	2017-10-04 19:12:40
10183	AFCL	2014-10-08 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14209N	\N	2014-10-08 17:32:48	2017-10-01 10:34:22
10184	AFCL	2014-10-08 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14079W	\N	2014-10-08 17:32:54	2017-10-04 19:15:31
10185	AFCL	2014-10-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14249W	\N	2014-10-08 17:33:10	2017-10-04 19:42:49
10187	AFCL	2014-10-08 00:00:00	2017-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	04041B	\N	2014-10-08 17:33:34	2017-09-24 11:09:53
10189	AFCL	2014-10-08 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	14059S	\N	2014-10-08 17:33:52	2017-10-04 19:44:45
10190	AFCL	2014-10-08 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	\N	2014-10-08 17:34:15	2015-01-08 17:14:28
10191	AFCL	2014-10-08 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14191V	\N	2014-10-08 17:34:59	2017-10-04 19:14:26
10192	AFCL	2014-10-08 00:00:00	2015-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	14237S	\N	2014-10-08 17:35:18	2015-02-16 17:25:25
10195	ETRD	2014-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	97011G	\N	2014-10-08 00:00:00	2017-10-04 00:00:00
10196	ETRD	2014-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14211G	\N	2014-10-08 00:00:00	2017-10-04 00:00:00
10197	ETRD	2014-10-08 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	95041E	\N	2014-10-08 17:37:21	2017-10-04 19:11:13
10198	ETRD	2014-10-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04036E	\N	2014-10-08 17:37:33	2017-09-24 18:59:59
10199	ETRD	2014-10-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92031P	\N	2014-10-08 17:38:04	2017-09-24 18:16:52
10201	ETRD	2014-10-08 00:00:00	2017-06-19 00:00:00	ANCIEN	\N	\N	\N	\N	14253S	\N	2014-10-08 17:38:18	2017-06-20 15:53:49
10203	ETRD	2014-10-08 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86044G	\N	2014-10-08 17:38:48	2017-10-01 10:32:58
10204	CDD	2014-10-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14093U	\N	2014-10-08 17:39:35	2017-10-04 19:42:23
10205	CDD	2014-10-09 00:00:00	2016-01-11 00:00:00	ANCIEN	\N	\N	\N	\N	11060J	\N	2014-10-08 17:39:46	2016-01-11 17:34:09
10206	CDD	2014-10-08 00:00:00	2020-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14038Y	\N	2014-10-08 17:39:52	2017-10-04 19:43:06
10207	CDD	2014-10-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11020A	\N	2014-10-08 17:40:08	2017-09-24 16:24:51
10208	CDD	2014-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14031R	\N	2014-10-08 00:00:00	2017-10-04 00:00:00
10209	CDD	2014-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14169X	\N	2014-10-08 00:00:00	2017-10-04 00:00:00
10210	CDD	2014-10-08 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14135M	\N	2014-10-08 17:40:53	2017-10-04 18:52:55
10211	CDD	2014-10-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14157T	\N	2014-10-08 17:41:01	2017-10-04 19:46:47
10212	FINC	2014-10-08 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	05004A	\N	2014-10-08 17:41:59	2017-10-01 10:22:23
10213	FINC	2014-10-08 00:00:00	2017-06-01 00:00:00	ANCIEN	\N	\N	\N	\N	14175V	\N	2014-10-08 17:42:06	2017-06-02 10:02:56
10214	FINC	2014-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01048V	\N	2014-10-08 00:00:00	2017-10-04 00:00:00
10215	FINC	2014-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14173T	\N	2014-10-08 00:00:00	2017-10-04 00:00:00
10216	FINC	2014-10-08 00:00:00	2020-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	14199E	\N	2014-10-08 17:43:35	2017-10-04 19:50:43
10218	FINC	2014-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	\N	2014-10-08 00:00:00	2017-10-04 00:00:00
10220	FINC	2014-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08010L	\N	2014-10-08 00:00:00	2017-10-04 00:00:00
10229	LOIS	2014-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14259Y	\N	2014-10-08 00:00:00	2017-10-04 00:00:00
10230	AFEU	2014-10-09 00:00:00	2017-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	11012A	\N	2014-10-09 09:38:32	2017-10-05 11:42:51
10233	AFEU	2014-10-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14249W	\N	2014-10-09 09:39:41	2017-10-05 14:39:37
10235	AFEU	2014-10-09 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	\N	2014-10-09 09:40:05	2015-10-13 14:19:58
9670	2013CMP27	2013-11-05 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04046G	TITULAIRE	\N	2014-09-28 17:07:41
9671	2013CMP27	2013-11-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	SUPPLEANT	\N	2017-09-24 13:44:49
9672	2013CMP27	2013-11-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	SUPPLEANT	\N	\N
9673	2013CMP27	2013-11-05 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98030P	TITULAIRE	\N	2014-09-28 13:19:48
9674	2013CMP27	2013-11-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	10006L	SUPPLEANT	\N	\N
9675	2013CMP27	2013-11-05 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08037X	TITULAIRE	\N	2014-09-28 17:34:16
9676	2013CMP27	2013-11-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04067M	SUPPLEANT	\N	2017-09-24 17:47:27
9677	2013CMP27	2013-11-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	11048N	TITULAIRE	\N	\N
9680	2013CMP27	2013-11-05 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10003H	SUPPLEANT	\N	2014-09-28 17:38:26
9681	2013CMP27	2013-11-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	01034P	TITULAIRE	\N	\N
9804	LOIS	2013-12-17 00:00:00	2020-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	11049P	\N	2013-12-17 17:04:52	2017-10-04 19:46:24
9805	AFCL	2013-12-17 00:00:00	2013-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	08023R	\N	2013-12-17 17:10:37	\N
9879	PROSTITUTION	2014-01-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95021A	\N	2014-01-23 11:50:35	2014-09-28 16:40:50
9880	NEANT	2014-02-14 00:00:00	2014-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	14002L	\N	2014-02-14 15:15:52	2014-02-21 11:15:00
9981	NEANT	2014-06-25 00:00:00	2014-07-01 00:00:00	ANCIEN	\N	\N	\N	\N	14017T	\N	2014-06-25 15:52:44	2014-07-02 12:07:38
9984	FINC	2014-07-16 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	11085T	\N	2014-07-16 17:22:41	2017-10-04 18:50:07
9997	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14135M	\N	2014-09-28 13:40:32	2014-10-08 17:40:54
9998	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	95041E	\N	2014-09-28 13:40:32	2014-10-08 17:37:22
10007	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14173T	\N	2014-09-28 16:59:40	2014-10-08 17:43:29
10008	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14167V	\N	2014-09-28 16:59:40	2014-10-08 16:55:33
10009	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14169X	\N	2014-09-28 16:59:40	2014-10-08 17:40:36
10014	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14213J	\N	2014-09-28 17:05:42	2014-10-08 17:25:38
10015	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14159V	\N	2014-09-28 17:05:42	2014-10-08 16:56:09
10017	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14087W	\N	2014-09-28 17:07:40	2014-10-08 17:25:15
10018	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	95049N	\N	2014-09-28 17:07:40	2014-10-08 16:57:42
10019	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14081Q	\N	2014-09-28 17:07:40	2014-10-08 16:50:09
10020	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	\N	2014-09-28 17:07:40	2014-10-08 17:18:38
10023	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14217N	\N	2014-09-28 17:12:40	2014-10-08 17:24:56
10024	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14079W	\N	2014-09-28 17:14:20	2014-10-08 17:32:56
10025	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14026U	\N	2014-09-28 17:15:41	2014-10-08 17:25:27
10026	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14219Q	\N	2014-09-28 17:22:10	2014-10-08 16:51:35
10027	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14123H	\N	2014-09-28 17:22:10	2014-10-08 17:33:28
10028	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14038Y	\N	2014-09-28 17:27:28	2014-10-08 17:39:53
10029	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14221J	\N	2014-09-28 17:27:34	2014-10-08 16:51:55
10030	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14223L	\N	2014-09-28 17:27:34	2014-10-08 17:25:53
10031	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14225N	\N	2014-09-28 17:27:34	2014-10-08 16:56:40
10032	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14073Q	\N	2014-09-28 17:31:41	2014-10-08 16:45:08
10033	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14065Q	\N	2014-09-28 17:31:41	2014-10-08 16:58:10
10034	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14061L	\N	2014-09-28 17:31:41	2014-10-08 17:33:43
10035	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14227Q	\N	2014-09-28 17:34:15	2014-10-08 17:07:01
10036	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14229S	\N	2014-09-28 17:34:15	2014-10-08 17:04:13
10037	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14231L	\N	2014-09-28 17:34:15	2014-10-08 16:43:32
10041	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14237S	\N	2014-09-28 17:40:23	2014-10-08 17:35:19
10042	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14179A	\N	2014-09-28 17:40:23	2014-10-08 16:45:00
10043	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14239U	\N	2014-09-28 17:52:17	2014-10-08 16:44:05
10044	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14241N	\N	2014-09-28 17:52:17	2014-10-08 16:45:34
10045	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14055N	\N	2014-09-28 17:52:17	2014-10-08 16:45:42
10081	ETRD	2014-10-09 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	98032R	\N	2014-10-08 16:41:15	2015-06-12 15:59:49
10082	ETRD	2014-10-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92044U	\N	2014-10-08 16:42:07	2017-09-24 18:16:52
10052	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14249W	\N	2014-09-28 18:19:47	2014-10-08 17:33:12
10058	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14033T	\N	2014-09-28 18:47:00	2014-10-08 17:12:24
10060	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14037X	\N	2014-09-28 18:58:25	2014-10-08 17:25:45
10062	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14069U	\N	2014-09-28 19:03:03	2014-10-08 17:17:51
10067	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14107H	\N	2014-09-28 19:09:43	2014-10-08 16:54:02
10068	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14085U	\N	2014-09-28 19:13:08	2014-10-08 16:55:39
10069	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14089Y	\N	2014-09-28 19:13:08	2014-10-08 16:44:31
10072	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14259Y	\N	2014-09-28 19:20:16	2014-10-08 18:47:21
10074	NEANT	2014-10-01 00:00:00	2014-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14129P	\N	2014-09-28 19:45:29	2014-10-08 17:25:03
10083	SOCI	2014-10-08 00:00:00	2014-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	01052R	\N	2014-10-08 16:42:42	2014-11-04 11:22:47
10084	SOCI	2014-10-08 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14255U	\N	2014-10-08 16:42:50	2017-10-04 18:48:12
10085	SOCI	2014-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14042U	\N	2014-10-08 00:00:00	2017-10-04 00:00:00
10088	SOCI	2014-10-08 00:00:00	2020-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	14239U	\N	2014-10-08 16:44:04	2017-10-04 19:58:24
10089	AFCL	2014-10-08 00:00:00	2017-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	14089Y	\N	2014-10-08 16:44:30	2017-08-01 16:20:18
10090	AFCL	2014-10-08 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14179A	\N	2014-10-08 16:44:59	2017-10-04 19:13:36
10091	AFCL	2014-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14073Q	\N	2014-10-08 00:00:00	2017-10-04 00:00:00
10093	AFCL	2014-10-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14241N	\N	2014-10-08 16:45:33	2017-10-04 19:43:38
10097	CAE	2014-10-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11094U	\N	2014-10-08 16:47:49	2017-09-24 13:25:54
10099	CAE	2014-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14207L	\N	2014-10-08 00:00:00	2017-10-04 00:00:00
10100	CAE	2014-10-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14197C	\N	2014-10-08 16:49:11	2017-10-04 19:56:52
10101	CAE	2014-10-08 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	11110B	\N	2014-10-08 16:49:22	2017-10-04 18:43:10
10102	CAE	2014-10-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14081Q	\N	2014-10-08 16:50:08	2017-10-04 19:57:32
10103	CAE	2014-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14257W	\N	2014-10-08 00:00:00	2017-10-04 00:00:00
10104	CAE	2014-10-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11046L	\N	2014-10-08 16:50:44	2017-09-24 17:29:37
10105	CDD	2014-10-08 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14030Q	\N	2014-10-08 16:51:16	2017-10-04 18:52:14
10106	CDD	2014-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14219Q	\N	2014-10-08 00:00:00	2017-10-04 00:00:00
10107	CDD	2014-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14221J	\N	2014-10-08 00:00:00	2017-10-04 00:00:00
10109	CDD	2014-10-08 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14137P	\N	2014-10-08 16:52:27	2015-06-12 15:59:18
10110	CDD	2014-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08060W	\N	2014-10-08 00:00:00	2017-10-04 00:00:00
10111	CDD	2014-10-08 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	14233N	\N	2014-10-08 16:53:24	2015-02-12 15:03:17
10112	CDD	2014-10-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11059R	\N	2014-10-08 16:53:33	2017-09-24 17:42:26
10114	CDD	2014-10-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92039X	\N	2014-10-08 16:53:49	2017-09-24 13:47:46
10115	CDD	2014-10-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	13002U	\N	2014-10-08 16:53:56	2017-09-24 17:42:26
10116	CDD	2014-10-08 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14107H	\N	2014-10-08 16:54:01	2017-10-04 18:53:00
10118	FINC	2014-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14083S	\N	2014-10-08 00:00:00	2017-10-04 00:00:00
10119	FINC	2014-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11053K	\N	2014-10-08 00:00:00	2017-10-04 00:00:00
10120	FINC	2014-10-08 00:00:00	2015-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	14044W	\N	2014-10-08 16:54:48	2015-02-06 14:32:44
10123	FINC	2014-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11074Q	\N	2014-10-08 00:00:00	2017-10-04 00:00:00
10124	FINC	2014-10-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14159V	\N	2014-10-08 16:56:08	2017-10-04 19:51:58
10125	FINC	2014-10-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	\N	2014-10-08 16:56:26	2017-09-24 17:09:24
10126	FINC	2014-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14225N	\N	2014-10-08 00:00:00	2017-10-04 00:00:00
10127	LOIS	2014-10-08 00:00:00	2015-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	14043V	\N	2014-10-08 16:57:20	2015-02-06 14:27:55
10128	LOIS	2014-10-08 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95049N	\N	2014-10-08 16:57:41	2017-10-01 10:42:05
10129	LOIS	2014-10-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14065Q	\N	2014-10-08 16:58:09	2017-10-04 19:54:58
10328	NEANT	2014-12-22 00:00:00	2015-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	14263U	\N	2014-12-18 16:18:16	2015-01-13 11:56:57
10342	2014CMP2	2014-02-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	TITULAIRE	\N	2017-09-24 17:35:15
10343	2014CMP2	2014-02-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	12042Y	TITULAIRE	\N	2017-09-24 19:31:54
10357	2014CMP3	2014-01-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11094U	TITULAIRE	\N	2017-09-24 13:25:54
10363	2014CMP3	2014-01-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04088S	SUPPLEANT	\N	\N
10372	2014CMP4	2014-02-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	90003B	SUPPLEANT	\N	2017-10-01 10:01:39
10376	2014CPM5	2014-02-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
10380	2014CPM5	2014-02-10 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-13 14:22:14
10402	2014CMP7	2014-04-30 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-13 14:22:05
10403	2014CMP7	2014-04-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	TITULAIRE	\N	\N
10405	2014CMP7	2014-04-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	11033F	SUPPLEANT	\N	\N
10406	2014CMP7	2014-04-30 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	95020Y	SUPPLEANT	\N	2015-06-12 16:01:25
10410	2014CMP7	2014-04-30 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	07034Q	SUPPLEANT	\N	\N
10411	2014CMP7	2014-04-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11037K	SUPPLEANT	\N	2017-09-24 18:16:52
10412	2014CMP8	2014-04-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
10413	2014CMP8	2014-04-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	11072N	TITULAIRE	\N	\N
10414	2014CMP8	2014-04-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	11056N	TITULAIRE	\N	\N
10415	2014CMP8	2014-04-30 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-13 14:22:10
10416	2014CMP8	2014-04-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	TITULAIRE	\N	\N
10417	2014CMP8	2014-04-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	TITULAIRE	\N	2017-09-24 13:29:42
10418	2014CMP8	2014-04-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	11033F	SUPPLEANT	\N	\N
10419	2014CMP8	2014-04-30 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	95020Y	SUPPLEANT	\N	2015-06-12 16:01:25
10420	2014CMP8	2014-04-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11035H	SUPPLEANT	\N	2017-09-24 18:16:52
10421	2014CMP8	2014-04-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	SUPPLEANT	\N	\N
10422	2014CMP8	2014-04-30 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	SUPPLEANT	\N	2017-06-19 12:20:59
10425	2014CMP9	2014-05-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	TITULAIRE	\N	2017-09-24 17:09:24
10427	2014CMP9	2014-05-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08055A	TITULAIRE	\N	\N
10429	2014CMP9	2014-05-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	90003B	TITULAIRE	\N	2017-10-01 10:01:39
10430	2014CMP9	2014-05-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	08060W	SUPPLEANT	\N	\N
10445	2014CMP10	2014-05-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08022Q	SUPPLEANT	\N	2017-10-01 09:41:22
10446	2014CMP10	2014-05-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	04071H	SUPPLEANT	\N	\N
10448	2014CMP10	2014-05-12 00:00:00	2015-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	11108H	SUPPLEANT	\N	2015-04-07 16:50:27
10449	2014CMP10	2014-05-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92039X	SUPPLEANT	\N	2017-09-24 13:47:46
10450	2014CMP11	2014-05-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01022K	TITULAIRE	\N	2017-09-24 17:14:26
10451	2014CMP11	2014-05-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04040A	TITULAIRE	\N	\N
10453	2014CMP11	2014-05-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	95063L	TITULAIRE	\N	\N
10456	2014CMP11	2014-05-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01015L	SUPPLEANT	\N	2017-09-24 17:19:42
10457	2014CMP11	2014-05-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	11072N	SUPPLEANT	\N	\N
10458	2014CMP11	2014-05-20 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95062K	SUPPLEANT	\N	\N
10579	CROISSANCE	2015-01-15 00:00:00	2015-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	14093U	\N	2015-01-09 11:40:16	2015-02-12 11:25:34
10580	CROISSANCE	2015-01-15 00:00:00	2015-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	96004D	\N	2015-01-09 11:40:28	2015-10-07 10:43:00
10851	2014CMP22	2014-07-16 00:00:00	2014-07-16 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	2015-01-26 11:23:48	2016-06-28 18:04:05
10582	CROISSANCE	2015-01-15 00:00:00	2015-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	10006L	\N	2015-01-09 11:40:41	2015-10-07 10:43:00
10487	2014CMP14	2014-05-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	07004J	TITULAIRE	\N	\N
10489	2014CMP14	2014-05-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11035H	SUPPLEANT	\N	2017-09-24 18:16:52
10584	CROISSANCE	2015-01-15 00:00:00	2015-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	04071H	\N	2015-01-09 11:41:04	2015-10-07 10:43:00
10585	CROISSANCE	2015-01-15 00:00:00	2015-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	14187A	\N	2015-01-09 11:41:15	2015-10-07 10:43:00
10587	CROISSANCE	2015-01-15 00:00:00	2015-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	14213J	\N	2015-01-09 11:41:32	2015-10-07 10:43:00
10588	CROISSANCE	2015-01-15 00:00:00	2015-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	04061F	\N	2015-01-09 11:41:45	2015-10-07 10:43:00
10590	CROISSANCE	2015-01-15 00:00:00	2015-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	11100Y	\N	2015-01-09 11:42:01	2015-10-07 10:43:00
10591	CROISSANCE	2015-01-15 00:00:00	2015-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	07034Q	\N	2015-01-09 11:42:12	2015-10-07 10:43:00
10761	CROISSANCE	2015-01-15 00:00:00	2015-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	\N	2015-01-13 19:14:17	2015-10-07 10:43:00
10762	CROISSANCE	2015-01-15 00:00:00	2015-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	04067M	\N	2015-01-13 19:14:29	2015-10-07 10:43:00
10763	CROISSANCE	2015-01-15 00:00:00	2015-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	12042Y	\N	2015-01-13 19:14:44	2015-10-07 10:43:00
10765	CROISSANCE	2015-01-15 00:00:00	2015-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	11061K	\N	2015-01-13 19:15:13	2015-10-07 10:43:00
10766	CROISSANCE	2015-01-15 00:00:00	2015-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	08044W	\N	2015-01-13 19:15:25	2015-10-07 10:43:00
10768	CROISSANCE	2015-01-15 00:00:00	2015-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	83042R	\N	2015-01-13 19:15:55	2015-10-07 10:43:00
10853	2014CMP1	2014-01-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	95009E	TITULAIRE	2015-01-26 11:56:36	2015-01-26 11:58:20
10854	NEANT	2015-01-26 00:00:00	2015-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	14267Y	\N	2015-01-26 16:17:48	2015-01-27 13:59:30
10771	CROISSANCE	2015-01-15 00:00:00	2015-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	14225N	\N	2015-01-13 19:16:40	2015-10-07 10:43:00
10773	CROISSANCE	2015-01-15 00:00:00	2015-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	\N	2015-01-13 19:17:02	2015-10-07 10:43:00
10774	CROISSANCE	2015-01-15 00:00:00	2015-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	11094U	\N	2015-01-13 19:17:11	2015-10-07 10:43:00
10852	2014CPM5	2015-01-26 00:00:00	2021-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	04084N	TITULAIRE	2015-01-26 11:47:47	\N
11218	CSCAFCL	\N	1984-09-04 00:00:00	ANCIEN	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000273	\N	2015-02-10 14:20:24	\N
11222	CSCECON	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000742	\N	2015-02-10 14:20:24	\N
11227	CSCCMPTE	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000083	\N	2015-02-10 14:20:24	\N
11228	CSCTRATEL	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	59219J	\N	2015-02-10 14:20:24	\N
11236	CSCAFCL	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	58342G	\N	2015-02-10 14:20:24	\N
11243	CSCCMPTE	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000753	\N	2015-02-10 14:20:24	\N
11249	CSCECON	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	57130R	\N	2015-02-10 14:20:24	\N
11264	CSCAFCL	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000379	\N	2015-02-10 14:20:24	\N
10331	2014CMP1	2014-01-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	TITULAIRE	\N	2017-09-24 17:09:24
10332	2014CMP1	2014-01-29 00:00:00	2015-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	11051H	TITULAIRE	\N	2015-03-03 10:16:55
10333	2014CMP1	2014-01-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08055A	TITULAIRE	\N	\N
10334	2014CMP1	2014-01-29 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	TITULAIRE	\N	\N
10335	2014CMP1	2014-01-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	01043Q	TITULAIRE	\N	\N
10336	2014CMP1	2014-01-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	90003B	SUPPLEANT	\N	2017-10-01 10:01:39
10337	2014CMP1	2014-01-29 00:00:00	2015-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	11108H	SUPPLEANT	\N	2015-04-07 16:50:27
10338	2014CMP1	2014-01-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	11099A	SUPPLEANT	\N	\N
10339	2014CMP1	2014-01-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	SUPPLEANT	\N	\N
10894	2015CMP2	2015-01-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	04057K	TITULAIRE	2015-01-30 09:29:18	\N
10353	2014CMP3	2014-01-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	TITULAIRE	\N	2017-09-24 17:09:24
10354	2014CMP3	2014-01-29 00:00:00	2020-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	08068F	TITULAIRE	\N	\N
10355	2014CMP3	2014-01-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	TITULAIRE	\N	\N
10356	2014CMP3	2014-01-29 00:00:00	2018-12-30 00:00:00	ANCIEN	\N	\N	\N	\N	98023Q	TITULAIRE	\N	\N
10358	2014CMP3	2014-01-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	SUPPLEANT	\N	2017-09-24 18:20:10
10359	2014CMP3	2014-01-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	08060W	SUPPLEANT	\N	\N
10361	2014CMP3	2014-01-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	11099A	SUPPLEANT	\N	\N
10362	2014CMP3	2014-01-29 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	SUPPLEANT	\N	2017-06-19 12:20:59
10371	2014CMP4	2014-02-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01008M	SUPPLEANT	\N	2017-09-24 13:44:49
10374	2014CMP4	2014-02-05 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	SUPPLEANT	\N	2017-06-19 12:20:59
10436	2014CMP10	2014-05-12 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
10437	2014CMP10	2014-05-12 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	98046X	TITULAIRE	\N	2017-09-25 09:56:00
10438	2014CMP10	2014-05-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01013J	TITULAIRE	\N	2017-09-24 17:06:55
10439	2014CMP10	2014-05-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11042G	TITULAIRE	\N	2017-09-24 17:35:15
10440	2014CMP10	2014-05-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	11070L	TITULAIRE	\N	\N
10442	2014CMP10	2014-05-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	11110B	TITULAIRE	\N	\N
10553	2014CMP19	2014-07-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	11033F	SUPPLEANT	\N	\N
10554	2014CMP19	2014-07-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	SUPPLEANT	\N	\N
10555	2014CMP19	2014-07-10 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	SUPPLEANT	\N	2017-06-19 12:20:59
10556	2014CMP19	2014-07-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	11072N	SUPPLEANT	\N	\N
10557	2014CMP19	2014-07-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	\N	\N
10568	2014CMP21	2014-07-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11107G	TITULAIRE	\N	2017-09-24 17:06:55
10570	2014CMP21	2014-07-10 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95062K	TITULAIRE	\N	\N
10571	2014CMP21	2014-07-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	11053K	TITULAIRE	\N	\N
10572	2014CMP21	2014-07-10 00:00:00	2020-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	96004D	SUPPLEANT	\N	\N
10573	2014CMP21	2014-07-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11095V	SUPPLEANT	\N	2017-09-24 13:25:54
10574	2014CMP21	2014-07-10 00:00:00	2018-12-30 00:00:00	ANCIEN	\N	\N	\N	\N	98023Q	SUPPLEANT	\N	\N
9825	2013CMP31	2013-12-09 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
10895	2015CMP2	2015-01-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	14059S	TITULAIRE	2015-01-30 09:30:04	\N
10607	2014CMP23	2014-07-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	TITULAIRE	\N	2017-09-24 17:35:15
10608	2014CMP23	2014-07-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	TITULAIRE	\N	\N
10627	2014CMP24	2014-07-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11095V	SUPPLEANT	\N	2017-09-24 13:25:54
10629	2014CMP24	2014-07-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	11099A	SUPPLEANT	\N	\N
10633	2014CMP25	2014-10-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	95063L	TITULAIRE	\N	\N
10753	CROISSANCE	2015-01-15 00:00:00	2015-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	89017R	\N	2015-01-13 19:12:16	2015-10-07 10:43:00
10635	2014CMP25	2014-10-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	04085P	TITULAIRE	\N	\N
10636	2014CMP25	2014-10-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
10639	2014CMP25	2014-10-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
10754	CROISSANCE	2015-01-15 00:00:00	2015-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	11081P	\N	2015-01-13 19:12:28	2015-10-07 10:43:00
10755	CROISSANCE	2015-01-15 00:00:00	2015-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	14065Q	\N	2015-01-13 19:12:40	2015-10-07 10:43:00
10756	CROISSANCE	2015-01-15 00:00:00	2015-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	14013P	\N	2015-01-13 19:12:51	2015-10-07 10:43:00
10757	CROISSANCE	2015-01-15 00:00:00	2015-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	\N	2015-01-13 19:13:01	2015-10-07 10:43:00
10758	CROISSANCE	2015-01-15 00:00:00	2015-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	14207L	\N	2015-01-13 19:13:11	2015-10-07 10:43:00
10759	CROISSANCE	2015-01-15 00:00:00	2015-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	11053K	\N	2015-01-13 19:13:20	2015-10-07 10:43:00
10760	CROISSANCE	2015-01-15 00:00:00	2015-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	\N	2015-01-13 19:13:32	2015-10-07 10:43:00
10893	2015CMP2	2015-01-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	04070G	TITULAIRE	2015-01-30 09:29:01	\N
10896	2015CMP2	2015-01-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11091R	TITULAIRE	2015-01-30 09:30:11	2017-09-24 18:17:56
10897	2015CMP2	2015-01-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	04059M	TITULAIRE	2015-01-30 09:30:20	\N
10898	2015CMP2	2015-01-30 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08017T	TITULAIRE	2015-01-30 09:30:26	\N
10899	2015CMP2	2015-01-30 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	14263U	TITULAIRE	2015-01-30 09:30:34	2017-06-19 16:04:13
10900	2015CMP2	2015-01-30 00:00:00	2018-08-06 00:00:00	ANCIEN	\N	\N	\N	\N	95015C	SUPPLEANT	2015-01-30 09:32:58	2015-01-30 09:37:08
10901	2015CMP2	2015-01-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08024S	SUPPLEANT	2015-01-30 09:33:26	2015-01-30 09:37:17
10902	2015CMP2	2015-01-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11089X	SUPPLEANT	2015-01-30 09:33:36	2017-09-24 17:15:15
10904	2015CMP2	2015-01-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08039A	SUPPLEANT	2015-01-30 09:38:37	2015-01-30 09:38:42
10905	2015CMP2	2015-01-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	14073Q	SUPPLEANT	2015-01-30 09:38:51	2015-01-30 09:38:56
10906	2015CMP2	2015-01-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	11043H	SUPPLEANT	2015-01-30 09:39:02	2015-01-30 09:39:07
11266	CSCAFCL	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000352	\N	2015-02-10 14:20:24	\N
11267	CSCTRATEL	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000725	\N	2015-02-10 14:20:24	\N
11066	CSCAFCL	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000713	\N	2015-02-10 14:20:24	\N
11071	CSCAFCL	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000720	\N	2015-02-10 14:20:24	\N
11085	CSCAFCL	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000767	\N	2015-02-10 14:20:24	\N
11095	CSCAFCL	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	59236K	\N	2015-02-10 14:20:24	\N
11119	CSCAFCL	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000672	\N	2015-02-10 14:20:24	\N
10330	NEANT	2014-12-28 00:00:00	2015-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	14265W	\N	2014-12-29 15:45:40	2015-01-13 11:58:37
10502	2014CMP15	2014-06-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	TITULAIRE	\N	2017-09-24 17:35:15
10503	2014CMP15	2014-06-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	00003C	TITULAIRE	\N	2017-09-24 18:05:40
10504	2014CMP15	2014-06-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	04043D	TITULAIRE	\N	\N
10497	2014CMP12	2014-05-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	11097X	TITULAIRE	\N	\N
10505	2014CMP15	2014-06-11 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	TITULAIRE	\N	\N
10506	2014CMP15	2014-06-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	11053K	TITULAIRE	\N	\N
10507	2014CMP15	2014-06-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11055M	SUPPLEANT	\N	2017-09-24 18:07:57
10508	2014CMP15	2014-06-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	SUPPLEANT	\N	2017-09-24 13:44:49
10509	2014CMP15	2014-06-11 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	SUPPLEANT	\N	\N
10510	2014CMP15	2014-06-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	12042Y	SUPPLEANT	\N	2017-09-24 19:31:54
10511	2014CMP15	2014-06-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11061K	SUPPLEANT	\N	2017-09-24 17:42:25
10512	2014CMP15	2014-06-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	11097X	SUPPLEANT	\N	\N
10514	2014CMP16	2014-07-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	11056N	TITULAIRE	\N	\N
10515	2014CMP16	2014-07-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	TITULAIRE	\N	\N
10516	2014CMP16	2014-07-02 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-13 14:20:56
10517	2014CMP16	2014-07-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04056J	TITULAIRE	\N	2017-09-24 18:17:56
10518	2014CMP16	2014-07-02 00:00:00	2015-04-21 00:00:00	ANCIEN	\N	\N	\N	\N	01042P	TITULAIRE	\N	2015-04-21 17:14:30
10519	2014CMP16	2014-07-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	11033F	SUPPLEANT	\N	\N
10520	2014CMP16	2014-07-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	11053K	SUPPLEANT	\N	\N
10521	2014CMP16	2014-07-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11084S	SUPPLEANT	\N	2017-09-24 19:25:10
10522	2014CMP16	2014-07-02 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	SUPPLEANT	\N	2017-06-19 12:20:59
10524	2014CMP16	2014-07-02 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	\N	\N
10525	2014CMP17	2014-07-08 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	TITULAIRE	\N	2015-01-08 17:14:28
10526	2014CMP17	2014-07-08 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	98046X	TITULAIRE	\N	2017-09-25 09:56:00
10527	2014CMP17	2014-07-08 00:00:00	2017-08-06 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	TITULAIRE	\N	2017-08-07 16:31:39
10528	2014CMP17	2014-07-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	11040E	TITULAIRE	\N	\N
10529	2014CMP17	2014-07-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11088W	TITULAIRE	\N	2017-09-24 17:15:15
10530	2014CMP17	2014-07-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	11070L	TITULAIRE	\N	\N
10531	2014CMP17	2014-07-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	SUPPLEANT	\N	2017-09-24 18:20:10
10532	2014CMP17	2014-07-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08014Q	SUPPLEANT	\N	\N
10533	2014CMP17	2014-07-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	88008L	SUPPLEANT	\N	\N
10534	2014CMP17	2014-07-08 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	SUPPLEANT	\N	\N
10536	2014CMP17	2014-07-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	04071H	SUPPLEANT	\N	\N
10537	2014CMP17	2014-07-08 00:00:00	2015-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	11108H	SUPPLEANT	\N	2015-04-07 16:50:27
10541	2014CMP18	2014-07-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	01043Q	TITULAIRE	\N	\N
10542	2014CMP18	2014-07-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11100Y	TITULAIRE	\N	2017-09-24 13:57:40
10543	2014CMP18	2014-07-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04088S	TITULAIRE	\N	\N
10544	2014CMP18	2014-07-10 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	90003B	SUPPLEANT	\N	2017-10-01 10:01:39
10545	2014CMP18	2014-07-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	11099A	SUPPLEANT	\N	\N
10546	2014CMP18	2014-07-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	SUPPLEANT	\N	\N
10547	2014CMP18	2014-07-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	11066Q	SUPPLEANT	\N	\N
10563	2014CMP20	2014-07-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11095V	SUPPLEANT	\N	2017-09-24 13:25:54
10596	2014CMP22	2014-07-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01013J	TITULAIRE	\N	2017-09-24 17:06:55
10597	2014CMP22	2014-07-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	11070L	TITULAIRE	\N	\N
10692	2014CMP13	2014-05-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	01048V	SUPPLEANT	\N	\N
10724	2014CMP31	2014-12-06 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	TITULAIRE	\N	\N
10725	2014CMP31	2014-12-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	11070L	TITULAIRE	\N	\N
10727	2014CMP31	2014-12-06 00:00:00	2018-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	98053W	TITULAIRE	\N	2018-05-31 10:52:17
10728	2014CMP31	2014-12-06 00:00:00	2015-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	11108H	TITULAIRE	\N	2015-04-07 16:50:27
10729	2014CMP31	2014-12-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14167V	SUPPLEANT	\N	2017-10-01 10:18:28
10730	2014CMP31	2014-12-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	11053K	SUPPLEANT	\N	\N
10731	2014CMP31	2014-12-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	88008L	SUPPLEANT	\N	\N
10732	2014CMP31	2014-12-06 00:00:00	2020-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	14199E	SUPPLEANT	\N	\N
10733	2014CMP31	2014-12-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	99004R	SUPPLEANT	\N	\N
10734	2014CMP31	2014-12-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	14225N	SUPPLEANT	\N	\N
10735	2014CMP31	2014-12-06 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	SUPPLEANT	\N	\N
10776	CROISSANCE	2015-01-15 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	99002P	\N	2015-01-14 08:41:21	2015-02-20 10:30:10
10777	CROISSANCE	2015-01-15 00:00:00	2015-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	14221J	\N	2015-01-14 08:41:31	2015-10-07 10:43:00
10855	2014CMP19	2014-07-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	08032S	TITULAIRE	2015-01-26 18:29:08	2015-01-26 18:31:12
10784	2014CMP1	2014-01-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	08054Y	TITULAIRE	2015-01-23 14:40:51	2015-01-23 15:02:20
10785	2014CMP1	2014-01-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	08033T	SUPPLEANT	2015-01-23 14:41:13	2015-01-23 14:41:51
10786	2014CMP1	2014-01-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	06004E	SUPPLEANT	2015-01-23 14:43:27	2015-01-23 15:16:06
10787	2014CMP3	2014-01-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	08066D	TITULAIRE	2015-01-23 14:48:39	\N
10788	2014CMP3	2014-01-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	98038X	TITULAIRE	2015-01-23 14:49:49	2015-01-23 15:41:21
10789	2014CMP3	2014-01-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	95009E	SUPPLEANT	2015-01-23 14:50:21	2015-01-23 15:02:38
10382	2014CPM5	2014-02-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	08060W	SUPPLEANT	\N	\N
10793	2014CMP4	2014-02-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	95009E	SUPPLEANT	2015-01-23 15:02:36	2015-01-23 15:42:04
10856	2014CMP12	2014-05-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	04087R	SUPPLEANT	2015-01-26 18:34:18	2015-01-26 18:37:00
10792	2014CMP4	2014-02-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	08054Y	TITULAIRE	2015-01-23 15:02:19	2015-01-23 15:14:55
10857	SOCI	2015-01-27 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14267Y	\N	2015-01-27 13:59:29	2017-10-04 18:48:32
10796	2014CPM5	2014-02-10 00:00:00	2014-07-01 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	SUPPLEANT	2015-01-23 15:06:40	2015-01-23 15:37:25
10797	2014CPM5	2014-02-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	12035A	SUPPLEANT	2015-01-23 15:07:53	2017-09-24 17:18:03
10798	2014CMP6	2014-02-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	08067E	TITULAIRE	2015-01-23 15:09:13	2015-01-23 15:28:28
10799	2014CMP6	2014-02-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	04046G	SUPPLEANT	2015-01-23 15:09:44	2015-01-23 15:43:18
10801	2014CMP8	2014-04-30 00:00:00	2021-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	04084N	TITULAIRE	2015-01-23 15:13:42	2015-01-23 15:37:01
10802	2014CMP9	2014-05-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	08054Y	TITULAIRE	2015-01-23 15:14:54	\N
10803	2014CMP9	2014-05-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	04051D	TITULAIRE	2015-01-23 15:15:08	2015-01-23 15:46:00
10804	2014CMP9	2014-05-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	06004E	SUPPLEANT	2015-01-23 15:16:05	2015-01-23 15:44:11
10805	2014CMP11	2014-05-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08049C	TITULAIRE	2015-01-23 15:17:51	2015-01-23 15:48:50
10806	2014CMP11	2014-05-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	13001T	TITULAIRE	2015-01-23 15:18:21	\N
10807	2014CMP11	2014-05-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	98037W	TITULAIRE	2015-01-23 15:18:34	2015-01-23 15:49:11
10808	2014CMP11	2014-05-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	13005X	SUPPLEANT	2015-01-23 15:18:56	2015-01-23 15:49:33
10809	2014CMP11	2014-05-20 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04069P	SUPPLEANT	2015-01-23 15:19:11	2015-01-26 11:36:57
10810	2014CMP12	2014-05-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	10003H	TITULAIRE	2015-01-23 15:20:29	2015-01-23 15:35:33
10811	2014CMP12	2014-05-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	13003V	SUPPLEANT	2015-01-23 15:21:32	2015-01-23 15:21:44
10812	2014CMP12	2014-05-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08020N	SUPPLEANT	2015-01-23 15:22:14	2015-01-23 15:35:54
10813	2014CMP12	2014-05-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	08037X	SUPPLEANT	2015-01-23 15:22:39	2015-01-23 15:55:23
10817	2014CMP14	2014-05-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	95055L	TITULAIRE	2015-01-23 15:32:41	\N
10818	2014CMP14	2014-05-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	04035D	TITULAIRE	2015-01-23 15:33:29	\N
10819	2014CMP14	2014-05-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	04091M	SUPPLEANT	2015-01-23 15:33:48	2015-01-23 15:33:58
10820	2014CMP14	2014-05-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	08059E	SUPPLEANT	2015-01-23 15:34:07	2015-01-23 15:34:16
10821	2014CMP15	2014-06-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	04087R	TITULAIRE	2015-01-23 15:35:14	2015-01-23 15:54:23
10822	2014CMP15	2014-06-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	10003H	TITULAIRE	2015-01-23 15:35:31	\N
10823	2014CMP15	2014-06-11 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08020N	SUPPLEANT	2015-01-23 15:35:52	2015-01-23 15:36:09
10824	2014CMP16	2014-07-02 00:00:00	2021-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	04084N	TITULAIRE	2015-01-23 15:36:59	2015-01-23 15:47:21
10825	2014CMP16	2014-07-02 00:00:00	2020-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	SUPPLEANT	2015-01-23 15:37:23	2015-01-23 15:46:40
10826	2014CMP17	2014-07-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11068S	TITULAIRE	2015-01-23 15:38:32	2017-09-24 18:05:41
10827	2014CMP18	2014-07-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	98038X	TITULAIRE	2015-01-23 15:41:19	2015-01-23 15:56:59
10828	2014CMP18	2014-07-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	95009E	SUPPLEANT	2015-01-23 15:42:02	2015-01-23 15:42:13
9703	GOUVERNANCE	2013-11-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11083R	\N	2013-11-19 18:44:40	2014-11-18 11:50:10
9707	GOUVERNANCE	2013-11-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08031R	\N	2013-11-19 18:45:05	2014-11-18 11:50:10
9710	GOUVERNANCE	2013-11-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01061S	\N	2013-11-19 18:45:24	2014-11-18 11:50:10
9713	GOUVERNANCE	2013-11-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08053X	\N	2013-11-19 18:45:47	2014-11-18 11:50:10
10399	2014CMP7	2014-04-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
10401	2014CMP7	2014-04-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	11056N	TITULAIRE	\N	\N
10408	2014CMP7	2014-04-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	SUPPLEANT	\N	\N
10426	2014CMP9	2014-05-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	11066Q	TITULAIRE	\N	\N
10431	2014CMP9	2014-05-14 00:00:00	2016-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	04048J	SUPPLEANT	\N	2016-12-01 10:36:51
10444	2014CMP10	2014-05-12 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	SUPPLEANT	\N	\N
10447	2014CMP10	2014-05-12 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	SUPPLEANT	\N	2017-05-16 15:18:13
10548	2014CMP19	2014-07-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
10550	2014CMP19	2014-07-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	11056N	TITULAIRE	\N	\N
10483	2014CMP14	2014-05-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92015P	TITULAIRE	\N	2017-09-24 13:14:55
10484	2014CMP14	2014-05-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	04042C	TITULAIRE	\N	\N
10485	2014CMP14	2014-05-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	11054L	TITULAIRE	\N	\N
10486	2014CMP14	2014-05-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04054G	TITULAIRE	\N	2017-09-24 17:18:03
10488	2014CMP14	2014-05-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11076S	SUPPLEANT	\N	2017-09-24 17:47:28
10494	2014CMP12	2014-05-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01011G	TITULAIRE	\N	2017-09-24 16:43:43
10513	2014CMP16	2014-07-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
10523	2014CMP16	2014-07-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	11072N	SUPPLEANT	\N	\N
10540	2014CMP18	2014-07-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	11077T	TITULAIRE	\N	\N
10551	2014CMP19	2014-07-10 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-13 14:20:46
10552	2014CMP19	2014-07-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	10015M	TITULAIRE	\N	\N
10558	2014CMP20	2014-07-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11107G	TITULAIRE	\N	2017-09-24 17:06:55
10559	2014CMP20	2014-07-10 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08042U	TITULAIRE	\N	2017-10-01 10:20:50
10560	2014CMP20	2014-07-10 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95062K	TITULAIRE	\N	\N
10561	2014CMP20	2014-07-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	11053K	TITULAIRE	\N	\N
10562	2014CMP20	2014-07-10 00:00:00	2020-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	96004D	SUPPLEANT	\N	\N
10575	2014CMP21	2014-07-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01015L	SUPPLEANT	\N	2017-09-24 17:19:42
10576	2014CMP21	2014-07-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	05012A	SUPPLEANT	\N	\N
10637	2014CMP25	2014-10-16 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	95020Y	TITULAIRE	\N	2015-06-12 16:01:25
10646	2014CMP25	2014-10-16 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	07034Q	SUPPLEANT	\N	\N
10641	2014CMP25	2014-10-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	11033F	SUPPLEANT	\N	\N
10642	2014CMP25	2014-10-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	SUPPLEANT	\N	\N
10643	2014CMP25	2014-10-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	08018U	SUPPLEANT	\N	\N
10644	2014CMP25	2014-10-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	11026G	SUPPLEANT	\N	\N
10645	2014CMP25	2014-10-16 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	SUPPLEANT	\N	2017-06-19 12:20:59
10647	2014CMP26	2014-10-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	04092N	TITULAIRE	\N	\N
10648	2014CMP26	2014-10-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	01034P	TITULAIRE	\N	\N
10663	2014CMP27	2014-10-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	10015M	TITULAIRE	\N	\N
10650	2014CMP26	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11044J	TITULAIRE	\N	2017-09-24 17:29:37
10651	2014CMP26	2014-10-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	11097X	TITULAIRE	\N	\N
10656	2014CMP26	2014-10-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	11103C	SUPPLEANT	\N	\N
10660	2014CMP26	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11093T	SUPPLEANT	\N	2017-09-24 12:57:09
10661	2014CMP26	2014-10-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14227Q	SUPPLEANT	\N	\N
10662	2014CMP27	2014-10-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
10664	2014CMP27	2014-10-19 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	TITULAIRE	\N	\N
10674	2014CMP27	2014-10-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	04071H	SUPPLEANT	\N	\N
10666	2014CMP27	2014-10-19 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14034U	TITULAIRE	\N	\N
10667	2014CMP27	2014-10-19 00:00:00	2020-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	08068F	TITULAIRE	\N	\N
10668	2014CMP27	2014-10-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	95063L	TITULAIRE	\N	\N
10669	2014CMP27	2014-10-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	11056N	TITULAIRE	\N	\N
10670	2014CMP27	2014-10-19 00:00:00	2017-08-06 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	SUPPLEANT	\N	2017-08-07 16:31:39
10671	2014CMP27	2014-10-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	14255U	SUPPLEANT	\N	\N
10672	2014CMP27	2014-10-19 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	\N	\N
10673	2014CMP27	2014-10-19 00:00:00	2018-12-30 00:00:00	ANCIEN	\N	\N	\N	\N	98023Q	SUPPLEANT	\N	\N
10675	2014CMP27	2014-10-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11107G	SUPPLEANT	\N	2017-09-24 17:06:55
10676	2014CMP27	2014-10-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	04043D	SUPPLEANT	\N	\N
10684	2014CMP28	2014-11-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11084S	TITULAIRE	\N	2017-09-24 19:25:10
10678	2014CMP28	2014-11-19 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-13 14:20:40
10679	2014CMP28	2014-11-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
10680	2014CMP28	2014-11-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
10681	2014CMP28	2014-11-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	SUPPLEANT	\N	\N
10682	2014CMP28	2014-11-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11094U	TITULAIRE	\N	2017-09-24 13:25:54
10683	2014CMP28	2014-11-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11037K	TITULAIRE	\N	2017-09-24 18:16:52
10685	2014CMP28	2014-11-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11034G	TITULAIRE	\N	2017-09-24 17:55:12
10687	2014CMP28	2014-11-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01027Q	SUPPLEANT	\N	2017-09-24 17:28:55
10688	2014CMP28	2014-11-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	01048V	SUPPLEANT	\N	\N
10689	2014CMP28	2014-11-19 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95049N	SUPPLEANT	\N	2017-10-01 10:42:05
10690	2014CMP28	2014-11-19 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	SUPPLEANT	\N	2017-06-19 12:20:59
10691	2014CMP28	2014-11-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	08034U	SUPPLEANT	\N	\N
10720	2014CMP30	2014-11-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	99004R	SUPPLEANT	\N	\N
10722	2014CMP31	2014-12-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	TITULAIRE	\N	2017-09-24 18:20:10
10723	2014CMP31	2014-12-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	08011M	TITULAIRE	\N	\N
10749	2014CMP32	2014-12-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	08010L	SUPPLEANT	\N	\N
10829	2014CMP18	2014-07-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	04046G	SUPPLEANT	2015-01-23 15:43:16	2015-01-23 15:54:04
10830	2014CMP18	2014-07-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	06004E	SUPPLEANT	2015-01-23 15:44:09	2015-01-23 15:44:24
10885	2015CMP1	2015-01-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	11040E	TITULAIRE	2015-01-28 16:37:09	\N
10832	2014CMP19	2014-07-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	04051D	TITULAIRE	2015-01-23 15:45:58	\N
10833	2014CMP19	2014-07-10 00:00:00	2020-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	SUPPLEANT	2015-01-23 15:46:37	2015-01-23 15:47:11
10834	2014CMP19	2014-07-10 00:00:00	2021-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	04084N	SUPPLEANT	2015-01-23 15:47:19	2015-01-23 15:47:30
10835	2014CMP20	2014-07-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08049C	TITULAIRE	2015-01-23 15:48:47	2015-01-23 15:51:22
10836	2014CMP20	2014-07-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	98037W	TITULAIRE	2015-01-23 15:49:09	2015-01-23 15:51:51
10837	2014CMP20	2014-07-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	13005X	TITULAIRE	2015-01-23 15:49:31	2015-01-23 15:52:19
10838	2014CMP20	2014-07-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	08057C	SUPPLEANT	2015-01-23 15:49:48	2015-01-23 15:52:46
10839	2014CMP20	2014-07-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	04065K	SUPPLEANT	2015-01-23 15:50:16	2015-01-23 15:53:00
10840	2014CMP21	2014-07-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08049C	TITULAIRE	2015-01-23 15:51:20	\N
10841	2014CMP21	2014-07-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	98037W	TITULAIRE	2015-01-23 15:51:49	\N
10842	2014CMP21	2014-07-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	13005X	TITULAIRE	2015-01-23 15:52:17	\N
10843	2014CMP21	2014-07-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	08057C	SUPPLEANT	2015-01-23 15:52:43	2015-01-23 15:52:54
10844	2014CMP21	2014-07-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	04065K	SUPPLEANT	2015-01-23 15:52:58	2015-01-23 15:53:07
10845	2014CMP23	2014-07-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	04046G	TITULAIRE	2015-01-23 15:54:02	\N
10846	2014CMP23	2014-07-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	04087R	SUPPLEANT	2015-01-23 15:54:20	2015-01-23 15:54:46
10847	2014CMP23	2014-07-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	08037X	SUPPLEANT	2015-01-23 15:55:21	2015-01-23 15:55:31
10848	2014CMP24	2014-07-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	09012S	TITULAIRE	2015-01-23 15:56:39	\N
10849	2014CMP24	2014-07-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	98038X	TITULAIRE	2015-01-23 15:56:57	\N
10850	2014CMP24	2014-07-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	08050U	SUPPLEANT	2015-01-23 15:57:12	2015-01-23 15:57:23
10879	2015CMP1	2015-01-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	TITULAIRE	2015-01-28 16:36:03	2017-09-24 18:20:10
10880	2015CMP1	2015-01-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	04071H	TITULAIRE	2015-01-28 16:36:14	\N
10881	2015CMP1	2015-01-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	08011M	TITULAIRE	2015-01-28 16:36:24	\N
10388	2014CMP6	2014-02-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	11103C	TITULAIRE	\N	\N
10882	2015CMP1	2015-01-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	14173T	TITULAIRE	2015-01-28 16:36:38	\N
10883	2015CMP1	2015-01-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	14255U	TITULAIRE	2015-01-28 16:36:48	\N
10884	2015CMP1	2015-01-14 00:00:00	2015-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	11108H	TITULAIRE	2015-01-28 16:36:57	2015-04-07 16:50:27
10305	DJIHAD	2014-10-14 00:00:00	2015-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	\N	2014-10-15 09:44:54	2015-10-07 10:48:17
9882	COTISATIONS	2014-02-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04067M	\N	2014-02-25 16:13:56	2014-11-18 15:38:05
9885	COTISATIONS	2014-02-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08041T	\N	2014-02-25 16:14:46	2014-11-18 15:38:05
9889	COTISATIONS	2014-02-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08034U	\N	2014-02-25 16:15:23	2014-11-18 15:38:05
9893	COTISATIONS	2014-02-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95062K	\N	2014-02-25 16:16:58	2014-11-18 15:38:05
9909	COTISATIONS	2014-02-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92018S	\N	2014-02-25 17:23:42	2014-11-18 15:38:05
9914	COTISATIONS	2014-02-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11063M	\N	2014-02-25 17:25:09	2014-11-18 15:38:05
9899	COTISATIONS	2014-02-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04066L	\N	2014-02-25 16:34:47	2014-11-18 15:38:05
9902	COTISATIONS	2014-02-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08068F	\N	2014-02-25 16:35:08	2014-11-18 15:38:05
9905	COTISATIONS	2014-02-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11042G	\N	2014-02-25 16:36:03	2014-11-18 15:38:05
9753	ECOMOUV	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11049P	\N	2013-12-10 15:07:53	2014-11-18 15:39:16
9756	ECOMOUV	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08042U	\N	2013-12-10 15:08:40	2014-11-18 15:39:16
9760	DOCUMENTSADM	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	\N	2013-12-10 15:12:53	2014-11-18 15:39:56
9767	DOCUMENTSADM	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04048J	\N	2013-12-10 15:13:50	2014-11-18 15:39:56
9770	DOCUMENTSADM	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01019Q	\N	2013-12-10 15:14:13	2014-11-18 15:39:56
9801	DOCUMENTSADM	2013-12-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04070G	\N	2013-12-10 17:49:54	2014-11-18 15:39:56
10306	CREDITIMPOT	2014-12-10 00:00:00	2015-06-09 00:00:00	ANCIEN	\N	\N	\N	\N	11068S	\N	2014-12-16 17:30:38	2015-10-07 10:47:49
10307	CREDITIMPOT	2014-12-10 00:00:00	2015-06-09 00:00:00	ANCIEN	\N	\N	\N	\N	14089Y	\N	2014-12-16 17:31:20	2015-10-07 10:47:49
10308	CREDITIMPOT	2014-12-10 00:00:00	2015-06-09 00:00:00	ANCIEN	\N	\N	\N	\N	11029K	\N	2014-12-16 17:31:30	2015-10-07 10:47:49
10309	CREDITIMPOT	2014-12-10 00:00:00	2015-06-09 00:00:00	ANCIEN	\N	\N	\N	\N	14083S	\N	2014-12-16 17:35:12	2015-10-07 10:47:49
10310	CREDITIMPOT	2014-12-10 00:00:00	2015-06-09 00:00:00	ANCIEN	\N	\N	\N	\N	14038Y	\N	2014-12-16 17:35:21	2015-10-07 10:47:49
10311	CREDITIMPOT	2014-12-10 00:00:00	2015-06-09 00:00:00	ANCIEN	\N	\N	\N	\N	11042G	\N	2014-12-16 17:35:33	2015-10-07 10:47:49
10312	CREDITIMPOT	2014-12-10 00:00:00	2015-06-09 00:00:00	ANCIEN	\N	\N	\N	\N	88008L	\N	2014-12-16 17:35:44	2015-10-07 10:47:49
10313	CREDITIMPOT	2014-12-10 00:00:00	2015-06-09 00:00:00	ANCIEN	\N	\N	\N	\N	08038Y	\N	2014-12-16 17:35:53	2015-10-07 10:47:49
10314	CREDITIMPOT	2014-12-10 00:00:00	2015-06-09 00:00:00	ANCIEN	\N	\N	\N	\N	11088W	\N	2014-12-16 17:36:04	2015-10-07 10:47:49
10315	CREDITIMPOT	2014-12-10 00:00:00	2015-06-09 00:00:00	ANCIEN	\N	\N	\N	\N	11089X	\N	2014-12-16 17:36:13	2015-10-07 10:47:49
10316	CREDITIMPOT	2014-12-10 00:00:00	2015-06-09 00:00:00	ANCIEN	\N	\N	\N	\N	07026Q	\N	2014-12-16 17:36:24	2015-10-07 10:47:49
10317	CREDITIMPOT	2014-12-10 00:00:00	2015-06-09 00:00:00	ANCIEN	\N	\N	\N	\N	14033T	\N	2014-12-16 17:36:34	2015-10-07 10:47:49
10318	CREDITIMPOT	2014-12-10 00:00:00	2015-06-09 00:00:00	ANCIEN	\N	\N	\N	\N	14123H	\N	2014-12-16 17:36:43	2015-10-07 10:47:49
10319	CREDITIMPOT	2014-12-10 00:00:00	2015-06-09 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	\N	2014-12-16 17:36:53	2018-01-25 13:10:11
10320	CREDITIMPOT	2014-12-10 00:00:00	2015-06-09 00:00:00	ANCIEN	\N	\N	\N	\N	14159V	\N	2014-12-16 17:37:01	2015-10-07 10:47:49
10321	CREDITIMPOT	2014-12-10 00:00:00	2015-06-09 00:00:00	ANCIEN	\N	\N	\N	\N	14031R	\N	2014-12-16 17:37:09	2015-10-07 10:47:49
10322	CREDITIMPOT	2014-12-10 00:00:00	2015-06-09 00:00:00	ANCIEN	\N	\N	\N	\N	14237S	\N	2014-12-16 17:37:19	2015-10-07 10:47:49
10323	CREDITIMPOT	2014-12-10 00:00:00	2015-06-09 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	\N	2014-12-16 17:37:28	2015-10-07 10:47:49
10324	CREDITIMPOT	2014-12-10 00:00:00	2015-06-09 00:00:00	ANCIEN	\N	\N	\N	\N	14157T	\N	2014-12-16 17:37:41	2015-10-07 10:47:49
10325	CREDITIMPOT	2014-12-10 00:00:00	2015-06-09 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	\N	2014-12-16 17:37:50	2015-10-07 10:47:49
10326	CREDITIMPOT	2014-12-10 00:00:00	2015-06-09 00:00:00	ANCIEN	\N	\N	\N	\N	11057P	\N	2014-12-16 17:38:16	2015-10-07 10:47:49
10344	2014CMP2	2014-02-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11112D	TITULAIRE	\N	2017-09-24 16:45:26
10345	2014CMP2	2014-02-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	04043D	TITULAIRE	\N	2015-01-23 14:52:13
10346	2014CMP2	2014-02-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	11085T	TITULAIRE	\N	\N
10347	2014CMP2	2014-02-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	SUPPLEANT	\N	2017-09-24 13:44:49
10348	2014CMP2	2014-02-03 00:00:00	2020-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	08068F	SUPPLEANT	\N	\N
10349	2014CMP2	2014-02-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	10006L	SUPPLEANT	\N	\N
10350	2014CMP2	2014-02-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04067M	SUPPLEANT	\N	2017-09-24 17:47:27
10351	2014CMP2	2014-02-03 00:00:00	2020-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	08041T	SUPPLEANT	\N	\N
10364	2014CMP4	2014-02-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	TITULAIRE	\N	2017-09-24 17:09:24
10365	2014CMP4	2014-02-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08055A	TITULAIRE	\N	\N
10366	2014CMP4	2014-02-05 00:00:00	2015-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	11051H	TITULAIRE	\N	2015-03-03 10:16:55
10367	2014CMP4	2014-02-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	TITULAIRE	\N	\N
10368	2014CMP4	2014-02-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11100Y	TITULAIRE	\N	2017-09-24 13:57:40
10369	2014CMP4	2014-02-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04089T	TITULAIRE	\N	\N
10373	2014CMP4	2014-02-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	11077T	SUPPLEANT	\N	\N
10375	2014CMP4	2014-02-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11037K	SUPPLEANT	\N	2017-09-24 18:16:52
10377	2014CPM5	2014-02-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	04085P	TITULAIRE	\N	\N
10378	2014CPM5	2014-02-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	TITULAIRE	\N	\N
10379	2014CPM5	2014-02-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11015D	TITULAIRE	\N	2017-09-24 13:42:35
10381	2014CPM5	2014-02-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	10015M	TITULAIRE	\N	\N
10389	2014CMP6	2014-02-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	11031D	TITULAIRE	\N	\N
10390	2014CMP6	2014-02-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04081K	TITULAIRE	\N	2017-09-24 19:25:10
10392	2014CMP6	2014-02-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	08061X	TITULAIRE	\N	\N
10393	2014CMP6	2014-02-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	SUPPLEANT	\N	2017-09-24 13:44:49
10394	2014CMP6	2014-02-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	10006L	SUPPLEANT	\N	\N
10395	2014CMP6	2014-02-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04067M	SUPPLEANT	\N	2017-09-24 17:47:27
10396	2014CMP6	2014-02-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	04043D	SUPPLEANT	\N	\N
10397	2014CMP6	2014-02-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	04045F	SUPPLEANT	\N	\N
10404	2014CMP7	2014-04-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	TITULAIRE	\N	2017-09-24 13:29:42
10432	2014CMP9	2014-05-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	11099A	SUPPLEANT	\N	\N
10433	2014CMP9	2014-05-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11100Y	SUPPLEANT	\N	2017-09-24 13:57:40
10434	2014CMP9	2014-05-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	01058X	SUPPLEANT	\N	\N
10435	2014CMP9	2014-05-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	14001X	SUPPLEANT	\N	\N
10652	2014CMP26	2014-10-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	TITULAIRE	\N	\N
10472	2014CMP13	2014-05-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	11048N	TITULAIRE	\N	\N
10473	2014CMP13	2014-05-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	01034P	TITULAIRE	\N	\N
10474	2014CMP13	2014-05-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	SUPPLEANT	\N	2017-09-24 13:44:49
10475	2014CMP13	2014-05-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04067M	SUPPLEANT	\N	2017-09-24 17:47:27
10476	2014CMP13	2014-05-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11061K	SUPPLEANT	\N	2017-09-24 17:42:25
10477	2014CMP13	2014-05-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	11097X	SUPPLEANT	\N	\N
10478	2014CMP13	2014-05-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	04045F	SUPPLEANT	\N	\N
10481	2014CMP13	2014-05-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	TITULAIRE	\N	2017-09-24 17:35:15
10493	2014CMP12	2014-05-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	TITULAIRE	\N	2017-09-24 17:35:15
10495	2014CMP12	2014-05-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11061K	TITULAIRE	\N	2017-09-24 17:42:25
10496	2014CMP12	2014-05-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	10006L	TITULAIRE	\N	\N
10498	2014CMP12	2014-05-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	01025N	TITULAIRE	\N	\N
10499	2014CMP12	2014-05-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	SUPPLEANT	\N	2017-09-24 13:44:49
10501	2014CMP12	2014-05-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	11067R	SUPPLEANT	\N	\N
10538	2014CMP18	2014-07-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	TITULAIRE	\N	2017-09-24 17:09:24
10539	2014CMP18	2014-07-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08038Y	TITULAIRE	\N	\N
10564	2014CMP20	2014-07-10 00:00:00	2018-12-30 00:00:00	ANCIEN	\N	\N	\N	\N	98023Q	SUPPLEANT	\N	\N
10566	2014CMP20	2014-07-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	05012A	SUPPLEANT	\N	\N
10288	DJIHAD	2014-10-14 00:00:00	2015-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	11096W	\N	2014-10-14 17:41:02	2015-10-07 10:48:17
10290	DJIHAD	2014-10-14 00:00:00	2015-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	08065C	\N	2014-10-14 17:41:19	2015-10-07 10:48:17
10291	DJIHAD	2014-10-14 00:00:00	2015-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	04035D	\N	2014-10-14 17:41:35	2015-10-07 10:48:17
10292	DJIHAD	2014-10-14 00:00:00	2015-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	07004J	\N	2014-10-14 17:41:47	2015-10-07 10:48:17
10294	DJIHAD	2014-10-14 00:00:00	2015-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	08056B	\N	2014-10-14 17:42:08	2015-10-07 10:48:17
10295	DJIHAD	2014-10-14 00:00:00	2015-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	11084S	\N	2014-10-14 17:42:18	2015-10-07 10:48:17
10297	DJIHAD	2014-10-14 00:00:00	2015-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	11026G	\N	2014-10-14 17:42:33	2015-10-07 10:48:17
10298	DJIHAD	2014-10-14 00:00:00	2015-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	92031P	\N	2014-10-14 17:42:47	2015-10-07 10:48:17
10300	DJIHAD	2014-10-14 00:00:00	2015-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	07034Q	\N	2014-10-14 17:43:06	2015-10-07 10:48:17
10301	DJIHAD	2014-10-14 00:00:00	2015-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	14225N	\N	2014-10-14 17:43:20	2015-10-07 10:48:17
10303	DJIHAD	2014-10-14 00:00:00	2015-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	\N	2014-10-14 17:43:38	2015-10-07 10:48:17
10384	2014CPM5	2014-02-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11113E	SUPPLEANT	\N	2017-09-25 10:54:33
10385	2014CPM5	2014-02-10 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	SUPPLEANT	\N	2017-06-19 12:20:59
10655	2014CMP26	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	SUPPLEANT	\N	2017-09-24 13:44:49
10658	2014CMP26	2014-10-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98024R	SUPPLEANT	\N	\N
10659	2014CMP26	2014-10-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	11067R	SUPPLEANT	\N	\N
10686	2014CMP28	2014-11-19 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08014Q	SUPPLEANT	\N	\N
10693	2014CMP2	2014-02-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	01048V	TITULAIRE	\N	\N
10694	2014CMP29	2014-11-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	TITULAIRE	\N	2017-09-24 18:20:10
10695	2014CMP29	2014-11-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	08011M	TITULAIRE	\N	\N
10697	2014CMP29	2014-11-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	11070L	TITULAIRE	\N	\N
10698	2014CMP29	2014-11-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11088W	TITULAIRE	\N	2017-09-24 17:15:15
10699	2014CMP29	2014-11-20 00:00:00	2018-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	98053W	TITULAIRE	\N	2018-05-31 10:52:17
10701	2014CMP29	2014-11-20 00:00:00	2017-06-01 00:00:00	ANCIEN	\N	\N	\N	\N	14175V	SUPPLEANT	\N	2017-06-02 10:02:56
10702	2014CMP29	2014-11-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	11053K	SUPPLEANT	\N	\N
10703	2014CMP29	2014-11-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	88008L	SUPPLEANT	\N	\N
10704	2014CMP29	2014-11-20 00:00:00	2020-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	14199E	SUPPLEANT	\N	\N
10705	2014CMP29	2014-11-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	99004R	SUPPLEANT	\N	\N
10706	2014CMP29	2014-11-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	14225N	SUPPLEANT	\N	\N
10707	2014CMP29	2014-11-20 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	SUPPLEANT	\N	\N
10708	2014CMP30	2014-11-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	TITULAIRE	\N	2017-09-24 18:20:10
10709	2014CMP30	2014-11-20 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	TITULAIRE	\N	\N
10710	2014CMP30	2014-11-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	08011M	TITULAIRE	\N	\N
10711	2014CMP30	2014-11-20 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	TITULAIRE	\N	\N
10712	2014CMP30	2014-11-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	11070L	TITULAIRE	\N	\N
10714	2014CMP30	2014-11-20 00:00:00	2018-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	98053W	TITULAIRE	\N	2018-05-31 10:52:17
10715	2014CMP30	2014-11-20 00:00:00	2017-06-01 00:00:00	ANCIEN	\N	\N	\N	\N	14175V	SUPPLEANT	\N	2017-06-02 10:02:56
10716	2014CMP30	2014-11-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	11053K	SUPPLEANT	\N	\N
10717	2014CMP30	2014-11-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	88008L	SUPPLEANT	\N	\N
10718	2014CMP30	2014-11-20 00:00:00	2020-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	14199E	SUPPLEANT	\N	\N
10719	2014CMP30	2014-11-20 00:00:00	2015-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	11108H	SUPPLEANT	\N	2015-04-07 16:50:27
10721	2014CMP30	2014-11-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	14225N	SUPPLEANT	\N	\N
10726	2014CMP31	2014-12-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11088W	TITULAIRE	\N	2017-09-24 17:15:15
10737	2014CMP32	2014-12-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	08011M	TITULAIRE	\N	\N
10738	2014CMP32	2014-12-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11088W	TITULAIRE	\N	2017-09-24 17:15:15
10739	2014CMP32	2014-12-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	04071H	TITULAIRE	\N	\N
10740	2014CMP32	2014-12-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	11070L	TITULAIRE	\N	\N
10741	2014CMP32	2014-12-12 00:00:00	2015-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	11108H	TITULAIRE	\N	2015-04-07 16:50:27
10742	2014CMP32	2014-12-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01013J	TITULAIRE	\N	2017-09-24 17:06:55
10743	2014CMP32	2014-12-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08014Q	SUPPLEANT	\N	\N
10744	2014CMP32	2014-12-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	11053K	SUPPLEANT	\N	\N
10745	2014CMP32	2014-12-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	88008L	SUPPLEANT	\N	\N
10746	2014CMP32	2014-12-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	11083R	SUPPLEANT	\N	\N
10748	2014CMP32	2014-12-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	99004R	SUPPLEANT	\N	\N
10751	SOCI	2015-01-13 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14265W	\N	2015-01-13 11:58:37	2017-10-04 18:50:51
10779	2014CMP2	2014-02-03 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04087R	SUPPLEANT	2015-01-22 17:04:41	2015-01-22 17:16:56
10780	2014CMP2	2014-02-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	08046Y	SUPPLEANT	2015-01-22 17:08:06	2015-01-26 11:55:05
10781	2014CMP2	2014-02-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	01062T	TITULAIRE	2015-01-22 17:12:55	2015-01-23 15:04:21
10888	2015CMP1	2015-01-14 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	SUPPLEANT	2015-01-28 16:37:43	2015-01-28 16:37:47
10814	2014CMP13	2014-05-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	08067E	TITULAIRE	2015-01-23 15:28:27	2015-01-26 11:17:23
10815	2014CMP13	2014-05-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	08037X	TITULAIRE	2015-01-23 15:28:45	2015-01-26 11:16:06
10816	2014CMP13	2014-05-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	04087R	SUPPLEANT	2015-01-23 15:29:07	2015-01-26 11:17:52
10887	2015CMP1	2015-01-14 00:00:00	2017-06-01 00:00:00	ANCIEN	\N	\N	\N	\N	14175V	SUPPLEANT	2015-01-28 16:37:31	2017-06-02 10:02:56
10889	2015CMP1	2015-01-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	11070L	SUPPLEANT	2015-01-28 16:37:57	2015-01-28 16:38:07
10890	2015CMP1	2015-01-14 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	SUPPLEANT	2015-01-28 16:38:14	2017-05-16 15:18:13
10891	2015CMP1	2015-01-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	08010L	SUPPLEANT	2015-01-28 16:38:33	2015-01-28 16:38:38
10892	2015CMP1	2015-01-14 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	SUPPLEANT	2015-01-28 16:38:52	2015-01-28 16:38:57
10927	CSCTRATEL	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000131	\N	2015-02-10 14:20:24	\N
10933	CSCAFCL	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000224	\N	2015-02-10 14:20:24	\N
10935	CSCAFCL	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000216	\N	2015-02-10 14:20:24	\N
10964	CSCTRATEL	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	86035F	\N	2015-02-10 14:20:24	\N
10594	2014CMP22	2014-07-16 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	98046X	TITULAIRE	\N	2017-09-25 09:56:00
10598	2014CMP22	2014-07-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11088W	TITULAIRE	\N	2017-09-24 17:15:15
10599	2014CMP22	2014-07-16 00:00:00	2015-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	11108H	TITULAIRE	\N	2015-04-07 16:50:27
10600	2014CMP22	2014-07-16 00:00:00	2015-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	11068S	SUPPLEANT	\N	2015-01-23 15:38:33
10601	2014CMP22	2014-07-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08014Q	SUPPLEANT	\N	\N
10602	2014CMP22	2014-07-16 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	SUPPLEANT	\N	\N
10603	2014CMP22	2014-07-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01027Q	SUPPLEANT	\N	2017-09-24 17:28:55
10604	2014CMP22	2014-07-16 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	SUPPLEANT	\N	2017-05-16 15:18:13
10605	2014CMP22	2014-07-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	99004R	SUPPLEANT	\N	\N
10606	2014CMP22	2014-07-16 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	SUPPLEANT	\N	\N
10778	AFCL	2015-01-14 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	\N	2015-01-14 12:02:56	2015-10-12 14:47:38
10972	CSCECON	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000201	\N	2015-02-10 14:20:24	\N
10975	CSCRELINT	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000144	\N	2015-02-10 14:20:24	\N
10977	CSCAFCL	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000017	\N	2015-02-10 14:20:24	\N
10996	CSCFINPLAN	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000400	\N	2015-02-10 14:20:24	\N
10998	CSCTRATEL	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000731	\N	2015-02-10 14:20:24	\N
11005	CSCRELINT	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	59522N	\N	2015-02-10 14:20:24	\N
11018	CSCAFCL	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000756	\N	2015-02-10 14:20:24	\N
11021	CSCFINPLAN	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000760	\N	2015-02-10 14:20:24	\N
11033	CSCTRATEL	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	56819Q	\N	2015-02-10 14:20:24	\N
11041	CSCRGLT	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000702	\N	2015-02-10 14:20:24	\N
11044	CSCRECEVA	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000205	\N	2015-02-10 14:20:24	\N
11045	CSCAFCL	\N	1991-10-12 00:00:00	ANCIEN	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000359	\N	2015-02-10 14:20:24	\N
11052	CSCTRATEL	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000685	\N	2015-02-10 14:20:24	\N
11072	CSCFINPLAN	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000197	\N	2015-02-10 14:20:24	\N
11078	CSCRGLT	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000236	\N	2015-02-10 14:20:24	\N
11098	CSCRECEVA	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000705	\N	2015-02-10 14:20:24	\N
11104	CSCECON	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000024	\N	2015-02-10 14:20:24	\N
11110	CSCLOIS	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000748	\N	2015-02-10 14:20:24	\N
11113	CSCRGLT	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000734	\N	2015-02-10 14:20:24	\N
10329	NEANT	2014-12-18 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	01062T	\N	2014-12-18 16:23:55	2017-06-28 09:52:21
10400	2014CMP7	2014-04-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	11072N	TITULAIRE	\N	\N
10455	2014CMP11	2014-05-20 00:00:00	2018-12-30 00:00:00	ANCIEN	\N	\N	\N	\N	98023Q	SUPPLEANT	\N	\N
10535	2014CMP17	2014-07-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01027Q	SUPPLEANT	\N	2017-09-24 17:28:55
10549	2014CMP19	2014-07-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	11067R	TITULAIRE	\N	\N
10610	2014CMP23	2014-07-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	11103C	TITULAIRE	\N	\N
10611	2014CMP23	2014-07-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04081K	TITULAIRE	\N	2017-09-24 19:25:10
10612	2014CMP23	2014-07-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11093T	TITULAIRE	\N	2017-09-24 12:57:09
10615	2014CMP23	2014-07-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	10006L	SUPPLEANT	\N	\N
10858	EDUCATION	2015-01-27 00:00:00	2015-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	14263U	\N	2015-01-27 16:36:49	2015-10-07 10:46:07
10618	2014CMP23	2014-07-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	11097X	SUPPLEANT	\N	\N
10619	2014CMP24	2014-07-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	TITULAIRE	\N	2017-09-24 17:09:24
10620	2014CMP24	2014-07-18 00:00:00	2018-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	08016S	TITULAIRE	\N	\N
10621	2014CMP24	2014-07-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01061S	TITULAIRE	\N	2017-09-24 17:48:21
10622	2014CMP24	2014-07-18 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	90003B	TITULAIRE	\N	2017-10-01 10:01:39
10623	2014CMP24	2014-07-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11111C	TITULAIRE	\N	2017-09-24 16:45:26
10907	2015CMP3	2015-01-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	05008E	TITULAIRE	2015-01-30 14:37:45	\N
10625	2014CMP24	2014-07-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01008M	SUPPLEANT	\N	2017-09-24 13:44:49
10626	2014CMP24	2014-07-18 00:00:00	2020-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	11081P	SUPPLEANT	\N	\N
10628	2014CMP24	2014-07-18 00:00:00	2016-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	04048J	SUPPLEANT	\N	2016-12-01 10:36:51
10859	EDUCATION	2015-01-27 00:00:00	2015-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	04059M	\N	2015-01-27 16:36:53	2015-10-07 10:46:07
10631	2014CMP24	2014-07-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	SUPPLEANT	\N	\N
10860	EDUCATION	2015-01-27 00:00:00	2015-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	01044R	\N	2015-01-27 16:36:59	2015-10-07 10:46:07
10861	EDUCATION	2015-01-27 00:00:00	2015-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	95015C	\N	2015-01-27 16:37:12	2015-10-07 10:46:07
10862	EDUCATION	2015-01-27 00:00:00	2015-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	08024S	\N	2015-01-27 16:37:29	2015-10-07 10:46:07
10864	EDUCATION	2015-01-27 00:00:00	2015-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	01025N	\N	2015-01-27 16:37:47	2015-10-07 10:46:07
10865	EDUCATION	2015-01-27 00:00:00	2015-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	14123H	\N	2015-01-27 16:37:56	2015-10-07 10:46:07
10867	EDUCATION	2015-01-27 00:00:00	2015-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	14097Y	\N	2015-01-27 16:38:19	2015-10-07 10:46:07
10868	EDUCATION	2015-01-27 00:00:00	2015-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	14061L	\N	2015-01-27 16:38:29	2015-10-07 10:46:07
10869	EDUCATION	2015-01-27 00:00:00	2015-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	14073Q	\N	2015-01-27 16:38:38	2015-10-07 10:46:07
10871	EDUCATION	2015-01-27 00:00:00	2015-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	92031P	\N	2015-01-27 16:38:58	2015-10-07 10:46:07
10872	EDUCATION	2015-01-27 00:00:00	2015-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	01048V	\N	2015-01-27 16:39:06	2015-10-07 10:46:07
10874	EDUCATION	2015-01-27 00:00:00	2015-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	14111D	\N	2015-01-27 16:39:25	2015-10-07 10:46:07
10875	EDUCATION	2015-01-27 00:00:00	2015-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	11014C	\N	2015-01-27 16:39:41	2015-10-07 10:46:07
10877	EDUCATION	2015-01-27 00:00:00	2015-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	11043H	\N	2015-01-27 16:39:59	2015-10-07 10:46:07
10878	EDUCATION	2015-01-27 00:00:00	2015-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	\N	2015-01-27 16:40:07	2015-10-07 10:46:07
10908	2015CMP3	2015-01-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14065Q	SUPPLEANT	2015-01-30 14:37:54	2015-01-30 14:40:37
10910	2015CMP3	2015-01-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	2015-01-30 14:38:10	2015-01-30 14:40:39
10911	2015CMP3	2015-01-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	14259Y	TITULAIRE	2015-01-30 14:38:16	\N
10912	2015CMP3	2015-01-30 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	95020Y	SUPPLEANT	2015-01-30 14:38:22	2015-06-12 16:01:25
10914	2015CMP3	2015-01-30 00:00:00	2017-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	01007L	SUPPLEANT	2015-01-30 14:38:39	2017-07-24 09:56:26
10915	2015CMP3	2015-01-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	TITULAIRE	2015-01-30 14:38:46	\N
10916	2015CMP3	2015-01-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11084S	SUPPLEANT	2015-01-30 14:38:53	2017-09-24 19:25:10
10917	2015CMP3	2015-01-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	95063L	TITULAIRE	2015-01-30 14:39:06	\N
10918	2015CMP3	2015-01-30 00:00:00	2015-04-21 00:00:00	ANCIEN	\N	\N	\N	\N	01042P	SUPPLEANT	2015-01-30 14:39:16	2015-04-21 17:14:30
10919	2015CMP3	2015-01-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11034G	TITULAIRE	2015-01-30 14:39:26	2017-09-24 17:55:12
10920	2015CMP3	2015-01-30 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	07034Q	SUPPLEANT	2015-01-30 14:39:33	2015-01-30 14:41:09
11140	CSCRELINT	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	74044S	\N	2015-02-10 14:20:24	\N
11147	CSCECON	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000120	\N	2015-02-10 14:20:24	\N
11155	CSCRGLT	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000417	\N	2015-02-10 14:20:24	\N
11184	CSCRELINT	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000442	\N	2015-02-10 14:20:24	\N
11191	CSCAFCL	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000198	\N	2015-02-10 14:20:24	\N
11194	CSCFINPLAN	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000061	\N	2015-02-10 14:20:24	\N
11197	CSCECON	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000397	\N	2015-02-10 14:20:24	\N
11211	CSCRGLT	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000698	\N	2015-02-10 14:20:24	\N
11074	CSCCMPTE	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	59521M	\N	2015-02-10 14:20:24	\N
11081	CSCCMPTE	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000746	\N	2015-02-10 14:20:24	\N
11171	CSCCMPTE	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000205	\N	2015-02-10 14:20:24	\N
11183	CSCCMPTE	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	86035F	\N	2015-02-10 14:20:24	\N
11220	CSCECON	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000063	\N	2015-02-10 14:20:24	\N
11232	CSCECON	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000245	\N	2015-02-10 14:20:24	\N
11239	CSCECON	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000079	\N	2015-02-10 14:20:24	\N
11253	CSCECON	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000391	\N	2015-02-10 14:20:24	\N
10954	CSCECON	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000348	\N	2015-02-10 14:20:24	\N
10982	CSCECON	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000425	\N	2015-02-10 14:20:24	\N
11000	CSCECON	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000013	\N	2015-02-10 14:20:24	\N
11019	CSCECON	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000020	\N	2015-02-10 14:20:24	\N
11086	CSCECON	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000355	\N	2015-02-10 14:20:24	\N
11101	CSCECON	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000242	\N	2015-02-10 14:20:24	\N
11109	CSCECON	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000688	\N	2015-02-10 14:20:24	\N
11178	CSCECON	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000732	\N	2015-02-10 14:20:24	\N
11205	CSCECON	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000001	\N	2015-02-10 14:20:24	\N
11230	CSCFINPLAN	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000272	\N	2015-02-10 14:20:24	\N
11238	CSCFINPLAN	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000705	\N	2015-02-10 14:20:24	\N
11247	CSCFINPLAN	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000107	\N	2015-02-10 14:20:24	\N
11001	CSCFINPLAN	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000021	\N	2015-02-10 14:20:24	\N
11017	CSCFINPLAN	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	59220B	\N	2015-02-10 14:20:24	\N
11084	CSCFINPLAN	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000080	\N	2015-02-10 14:20:24	\N
11112	CSCFINPLAN	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000734	\N	2015-02-10 14:20:24	\N
11132	CSCFINPLAN	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	57310T	\N	2015-02-10 14:20:24	\N
11152	CSCFINPLAN	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000251	\N	2015-02-10 14:20:24	\N
11161	CSCFINPLAN	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000094	\N	2015-02-10 14:20:24	\N
11196	CSCFINPLAN	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000702	\N	2015-02-10 14:20:24	\N
11204	CSCFINPLAN	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000746	\N	2015-02-10 14:20:24	\N
11255	CSCLOIS	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000191	\N	2015-02-10 14:20:24	\N
11257	CSCLOIS	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000205	\N	2015-02-10 14:20:24	\N
11265	CSCLOIS	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000284	\N	2015-02-10 14:20:24	\N
11024	CSCLOIS	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000003	\N	2015-02-10 14:20:24	\N
11058	CSCLOIS	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	65017N	\N	2015-02-10 14:20:24	\N
11079	CSCLOIS	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000236	\N	2015-02-10 14:20:24	\N
11100	CSCLOIS	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000145	\N	2015-02-10 14:20:24	\N
11275	AFCL	2015-02-16 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	87003B	\N	2015-02-16 17:21:48	2017-10-04 18:35:47
11281	POLLUTION	2015-02-18 00:00:00	2015-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	01015L	\N	2015-02-17 16:34:01	2015-10-07 10:45:34
11282	POLLUTION	2015-02-18 00:00:00	2015-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	90003B	\N	2015-02-17 16:35:25	2015-10-07 10:45:34
11283	POLLUTION	2015-02-18 00:00:00	2015-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	11049P	\N	2015-02-17 16:35:34	2015-10-07 10:45:34
11284	POLLUTION	2015-02-18 00:00:00	2015-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	04041B	\N	2015-02-17 16:35:42	2015-10-07 10:45:34
11285	POLLUTION	2015-02-18 00:00:00	2015-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	\N	2015-02-17 16:35:49	2018-01-25 13:10:11
11286	POLLUTION	2015-02-18 00:00:00	2015-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	04061F	\N	2015-02-17 16:35:56	2015-10-07 10:45:34
11287	POLLUTION	2015-02-18 00:00:00	2015-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	08042U	\N	2015-02-17 16:36:03	2015-10-07 10:45:34
11288	POLLUTION	2015-02-18 00:00:00	2015-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	95062K	\N	2015-02-17 16:36:13	2015-10-07 10:45:34
11333	2015CMP6	2015-03-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08039A	SUPPLEANT	2015-03-10 17:28:58	2015-03-10 17:29:03
11334	2015CMP6	2015-03-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	11109J	TITULAIRE	2015-03-10 17:29:11	\N
11335	2015CMP6	2015-03-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	14059S	SUPPLEANT	2015-03-10 17:29:19	2015-03-10 17:29:24
11336	2015CMP6	2015-03-10 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	14263U	TITULAIRE	2015-03-10 17:29:33	2017-06-19 16:04:13
11337	2015CMP6	2015-03-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	14109K	SUPPLEANT	2015-03-10 17:29:45	2015-03-10 17:29:50
11340	2014CMP11	2015-03-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08049C	TITULAIRE	2015-03-18 16:30:01	\N
11341	2014CMP11	2015-03-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	13005X	TITULAIRE	2015-03-18 16:30:36	\N
11342	2014CPM5	2015-03-18 00:00:00	2020-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	SUPPLEANT	2015-03-18 17:01:08	2015-03-18 17:14:19
11366	COMMANDE	2015-04-08 00:00:00	2015-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	08021P	\N	2015-04-14 15:09:13	2016-05-03 09:56:27
11344	2014CMP16	2015-03-18 00:00:00	2021-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	04084N	TITULAIRE	2015-03-18 17:03:18	\N
10700	2014CMP29	2014-11-20 00:00:00	2015-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	11108H	TITULAIRE	\N	2015-04-07 16:50:27
11361	NEANT	2015-04-08 00:00:00	2015-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	14271U	\N	2015-04-07 17:15:52	2015-05-06 11:43:03
9943	REGIONS	2014-06-18 00:00:00	2015-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	\N	2014-06-19 09:33:45	2015-04-07 18:21:18
9946	REGIONS	2014-06-18 00:00:00	2015-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	\N	2014-06-19 09:34:10	2015-04-07 18:21:18
9960	REGIONS	2014-06-18 00:00:00	2015-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	11034G	\N	2014-06-19 11:02:41	2015-04-07 18:21:18
9967	REGIONS	2014-06-18 00:00:00	2015-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	11037K	\N	2014-06-19 11:08:27	2015-04-07 18:21:18
11362	COMMANDE	2015-04-08 00:00:00	2015-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	11099A	\N	2015-04-14 14:59:27	2016-05-03 09:51:40
11363	COMMANDE	2015-04-08 00:00:00	2015-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	14205J	\N	2015-04-14 14:59:32	2016-05-03 09:55:39
11364	COMMANDE	2015-04-08 00:00:00	2015-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	14089Y	\N	2015-04-14 14:59:43	2016-05-03 09:50:18
11365	COMMANDE	2015-04-08 00:00:00	2015-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	14073Q	\N	2015-04-14 14:59:51	2016-05-03 09:55:01
11367	COMMANDE	2015-04-08 00:00:00	2015-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	01013J	\N	2015-04-14 15:16:09	2016-05-03 09:51:05
11368	COMMANDE	2015-04-08 00:00:00	2015-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	14133K	\N	2015-04-14 15:44:32	2016-05-03 09:49:50
11369	COMMANDE	2015-04-08 00:00:00	2015-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	14069U	\N	2015-04-14 15:44:40	2016-05-03 09:52:11
11370	COMMANDE	2015-04-08 00:00:00	2015-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	11060J	\N	2015-04-14 15:44:51	2016-05-03 09:48:35
11371	COMMANDE	2015-04-08 00:00:00	2015-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	90003B	\N	2015-04-14 15:45:01	2016-05-03 09:54:34
11372	COMMANDE	2015-04-08 00:00:00	2015-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	01027Q	\N	2015-04-14 15:45:08	2016-05-03 09:51:29
11373	COMMANDE	2015-04-08 00:00:00	2015-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	14037X	\N	2015-04-14 15:45:21	2016-05-03 09:55:27
11374	COMMANDE	2015-04-08 00:00:00	2015-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	14031R	\N	2015-04-14 15:45:29	2016-05-03 09:55:53
11375	COMMANDE	2015-04-08 00:00:00	2015-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	14237S	\N	2015-04-14 15:45:37	2016-05-03 09:56:36
11376	COMMANDE	2015-04-08 00:00:00	2015-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	04088S	\N	2015-04-14 15:45:44	2016-05-03 09:56:49
11377	COMMANDE	2015-04-08 00:00:00	2015-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	08068F	\N	2015-04-14 15:53:42	2016-05-03 09:51:59
11378	COMMANDE	2015-04-08 00:00:00	2015-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	11112D	\N	2015-04-14 15:53:52	2016-05-03 09:55:14
11379	COMMANDE	2015-04-08 00:00:00	2015-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	08053X	\N	2015-04-14 15:54:00	2016-05-03 09:56:14
11380	COMMANDE	2015-04-08 00:00:00	2015-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	14028W	\N	2015-04-14 15:54:15	2016-05-03 09:51:49
11381	COMMANDE	2015-04-08 00:00:00	2015-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	\N	2015-04-14 15:54:23	2016-05-03 09:57:00
11382	COMMANDE	2015-04-08 00:00:00	2015-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	14229S	\N	2015-04-14 15:54:31	2016-05-03 09:57:10
11383	COMMANDE	2015-04-08 00:00:00	2015-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	11037K	\N	2015-04-14 15:54:43	2016-05-03 09:57:21
11384	COMMANDE	2015-04-08 00:00:00	2015-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	11081P	\N	2015-04-14 16:09:51	2016-05-03 09:51:18
10632	2014CMP25	2014-10-16 00:00:00	2015-04-21 00:00:00	ANCIEN	\N	\N	\N	\N	01042P	TITULAIRE	\N	2015-04-21 17:14:30
11385	NEANT	2015-04-22 00:00:00	2015-05-03 00:00:00	ANCIEN	\N	\N	\N	\N	14273W	\N	2015-04-22 16:49:30	2015-05-04 11:14:58
11386	NEANT	2015-05-04 00:00:00	2015-05-11 00:00:00	ANCIEN	\N	\N	\N	\N	14275Y	\N	2015-05-04 10:27:12	2015-05-12 18:11:45
11387	NEANT	2015-05-04 00:00:00	2015-05-11 00:00:00	ANCIEN	\N	\N	\N	\N	14277B	\N	2015-05-04 10:29:04	2015-05-12 18:12:05
11391	AUTORITES	2015-05-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	11056N	\N	2015-05-05 14:58:50	\N
11392	AUTORITES	2015-05-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98042T	\N	2015-05-05 14:58:55	2017-10-01 10:39:22
11393	AUTORITES	2015-05-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	14083S	\N	2015-05-05 14:59:03	\N
11394	AUTORITES	2015-05-06 00:00:00	2016-01-11 00:00:00	ANCIEN	\N	\N	\N	\N	11060J	\N	2015-05-05 14:59:13	2016-01-11 17:34:09
11395	AUTORITES	2015-05-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	14053L	\N	2015-05-05 14:59:22	\N
11396	AUTORITES	2015-05-06 00:00:00	2018-12-30 00:00:00	ANCIEN	\N	\N	\N	\N	98023Q	\N	2015-05-05 14:59:29	\N
11397	AUTORITES	2015-05-06 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08022Q	\N	2015-05-05 14:59:36	2017-10-01 09:41:22
11398	AUTORITES	2015-05-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01061S	\N	2015-05-05 14:59:44	2017-09-24 17:48:21
11399	AUTORITES	2015-05-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	14169X	\N	2015-05-05 14:59:55	\N
11400	AUTORITES	2015-05-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04074L	\N	2015-05-05 15:00:27	2017-09-24 17:15:15
11401	AUTORITES	2015-05-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01056V	\N	2015-05-05 15:00:37	2017-09-24 17:04:02
11402	AUTORITES	2015-05-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14157T	\N	2015-05-05 15:00:45	\N
11403	AUTORITES	2015-05-06 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	11069T	\N	2015-05-05 15:00:52	2016-03-11 18:02:50
11404	AUTORITES	2015-05-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11068S	\N	2015-05-05 15:53:09	2017-09-24 18:05:41
11405	AUTORITES	2015-05-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11035H	\N	2015-05-05 15:53:17	2017-09-24 18:16:52
11406	AUTORITES	2015-05-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	11026G	\N	2015-05-05 15:53:23	\N
11407	AUTORITES	2015-05-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	14225N	\N	2015-05-05 15:53:30	\N
11408	AUTORITES	2015-05-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	95063L	\N	2015-05-05 15:53:37	\N
11409	AUTORITES	2015-05-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14227Q	\N	2015-05-05 15:53:46	\N
11410	AUTORITES	2015-05-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	\N	2015-05-05 16:18:15	\N
11411	AUTORITES	2015-05-06 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	\N	2015-05-05 16:18:24	2017-06-19 12:20:59
11413	FINC	2015-05-06 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	08016S	\N	2015-05-06 11:42:07	2017-10-04 18:49:44
11414	ETRD	2015-05-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95037J	\N	2015-05-06 11:42:36	2017-10-04 19:54:18
11415	SOCI	2015-05-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14271U	\N	2015-05-06 11:43:03	2017-09-24 17:06:55
11416	LOIS	2015-05-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14275Y	\N	2015-05-12 00:00:00	2017-10-04 00:00:00
11417	FINC	2015-05-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14277B	\N	2015-05-12 18:12:05	2017-10-04 19:52:20
11434	NEANT	2015-06-12 00:00:00	2015-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	14281W	\N	2015-06-12 15:35:57	2015-06-30 15:57:23
11435	NEANT	2015-06-12 00:00:00	2015-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	14147R	\N	2015-06-12 15:40:17	2015-06-17 12:12:37
9860	PROSTITUTION	2014-01-22 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	95020Y	\N	2014-01-21 17:16:39	2015-06-12 16:01:25
10383	2014CPM5	2014-02-10 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	95020Y	SUPPLEANT	\N	2015-06-12 16:01:25
11436	LOIS	2015-06-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14147R	\N	2015-06-17 00:00:00	2017-10-04 00:00:00
11439	2015CMP9	2015-06-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
11440	2015CMP9	2015-06-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	TITULAIRE	\N	\N
11441	2015CMP9	2015-06-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	TITULAIRE	\N	\N
11443	2015CMP9	2015-06-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	TITULAIRE	\N	\N
11444	2015CMP9	2015-06-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11084S	TITULAIRE	\N	2017-09-24 19:25:10
11273	CROISSANCE	2015-02-10 00:00:00	2015-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	14031R	\N	2015-02-11 10:18:23	2015-10-07 10:43:00
11277	POLLUTION	2015-02-18 00:00:00	2015-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	14179A	\N	2015-02-17 15:30:11	2015-10-07 10:45:34
11278	POLLUTION	2015-02-18 00:00:00	2015-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	04080J	\N	2015-02-17 15:30:14	2015-10-07 10:45:34
11279	POLLUTION	2015-02-18 00:00:00	2015-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	11076S	\N	2015-02-17 15:30:22	2015-10-07 10:45:34
11280	POLLUTION	2015-02-18 00:00:00	2015-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	\N	2015-02-17 15:30:31	2015-10-07 10:45:34
11308	CROISSANCE	2015-01-15 00:00:00	2015-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	11107G	\N	2015-02-20 10:30:22	2015-10-07 10:43:00
11338	SOCI	2015-03-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14269B	\N	2015-03-12 09:46:56	2017-09-24 18:07:57
11339	POLLUTION	2015-02-18 00:00:00	2015-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	11055M	\N	2015-03-16 16:46:04	2015-10-07 10:45:34
11346	2015CMP7	2015-03-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	05008E	TITULAIRE	2015-03-23 13:06:47	\N
11347	2015CMP7	2015-03-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	04047H	SUPPLEANT	2015-03-23 13:07:03	2015-03-23 13:07:05
11348	2015CMP7	2015-03-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01019Q	TITULAIRE	2015-03-23 13:07:13	2017-09-24 17:35:15
11349	2015CMP7	2015-03-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	2015-03-23 13:07:27	2015-03-23 13:07:33
11350	2015CMP7	2015-03-23 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	2015-03-23 13:07:41	2015-10-13 14:20:30
11351	2015CMP7	2015-03-23 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	95020Y	SUPPLEANT	2015-03-23 13:07:50	2015-06-12 16:01:25
11352	2015CMP7	2015-03-23 00:00:00	2017-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	01007L	TITULAIRE	2015-03-23 13:08:03	2017-07-24 09:56:26
11353	2015CMP7	2015-03-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11035H	SUPPLEANT	2015-03-23 13:08:16	2017-09-24 18:16:52
11354	2015CMP7	2015-03-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	TITULAIRE	2015-03-23 13:08:30	\N
11355	2015CMP7	2015-03-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	SUPPLEANT	2015-03-23 13:08:43	2015-03-23 13:08:47
11356	2015CMP7	2015-03-23 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08025T	TITULAIRE	2015-03-23 13:08:53	2017-10-01 10:17:18
11357	2015CMP7	2015-03-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	2015-03-23 13:09:05	2015-03-23 13:09:10
11358	2015CMP7	2015-03-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	11056N	TITULAIRE	2015-03-23 13:09:23	\N
11359	2015CMP7	2015-03-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11037K	SUPPLEANT	2015-03-23 13:09:38	2017-09-24 18:16:52
11388	LOIS	2015-05-04 00:00:00	2017-06-04 00:00:00	ANCIEN	\N	\N	\N	\N	14273W	\N	2015-05-04 11:14:58	2017-06-07 09:38:00
11418	2015CMP8	2015-06-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	11053K	TITULAIRE	2015-06-02 15:40:39	2015-06-02 15:40:56
11438	AFEU	2015-06-22 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	08018U	\N	2015-06-22 10:24:05	2017-10-05 14:39:59
11420	2015CMP8	2015-06-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	10006L	TITULAIRE	2015-06-02 15:41:03	\N
11421	2015CMP8	2015-06-02 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	SUPPLEANT	2015-06-02 15:41:12	2015-06-02 15:41:15
11422	2015CMP8	2015-06-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	14187A	TITULAIRE	2015-06-02 15:41:24	\N
11423	2015CMP8	2015-06-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11107G	SUPPLEANT	2015-06-02 15:41:32	2017-09-24 17:06:55
11424	2015CMP8	2015-06-02 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	07034Q	TITULAIRE	2015-06-02 15:42:19	2015-06-02 15:42:40
11425	2015CMP8	2015-06-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	14026U	SUPPLEANT	2015-06-02 15:42:31	2015-06-02 15:42:38
11426	2015CMP8	2015-06-02 00:00:00	2017-08-06 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	TITULAIRE	2015-06-02 15:42:49	2017-08-07 16:31:39
11427	2015CMP8	2015-06-02 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14135M	SUPPLEANT	2015-06-02 15:42:58	2015-06-02 15:43:03
11428	2015CMP8	2015-06-02 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14065Q	TITULAIRE	2015-06-02 15:43:17	\N
11429	2015CMP8	2015-06-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11094U	SUPPLEANT	2015-06-02 15:43:46	2017-09-24 13:25:54
11430	2015CMP8	2015-06-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	11066Q	SUPPLEANT	2015-06-02 15:44:03	2015-06-02 15:44:08
11431	2015CMP8	2015-06-02 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	14013P	TITULAIRE	2015-06-02 15:44:15	2017-06-19 16:06:01
11442	2015CMP9	2015-06-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	14259Y	TITULAIRE	\N	\N
11433	2015CMP8	2015-06-02 00:00:00	2020-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	11081P	SUPPLEANT	2015-06-02 15:47:06	2015-06-02 15:47:11
11445	2015CMP9	2015-06-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	04085P	TITULAIRE	\N	\N
11446	2015CMP9	2015-06-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08025T	SUPPLEANT	\N	2017-10-01 10:17:18
11447	2015CMP9	2015-06-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	14069U	SUPPLEANT	\N	\N
11448	2015CMP9	2015-06-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	04047H	SUPPLEANT	\N	\N
11449	2015CMP9	2015-06-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	01043Q	SUPPLEANT	\N	\N
11450	2015CMP9	2015-06-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	SUPPLEANT	\N	\N
11451	2015CMP9	2015-06-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04056J	SUPPLEANT	\N	2017-09-24 18:17:56
11452	CDD	2015-06-30 00:00:00	2015-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	14281W	\N	2015-06-30 15:57:23	2015-07-10 11:26:16
11453	2015CMP10	2015-06-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
11454	2015CMP10	2015-06-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
11455	2015CMP10	2015-06-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	99004R	TITULAIRE	\N	\N
11456	2015CMP10	2015-06-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	01043Q	TITULAIRE	\N	\N
11457	2015CMP10	2015-06-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04056J	TITULAIRE	\N	2017-09-24 18:17:56
11458	2015CMP10	2015-06-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	11026G	TITULAIRE	\N	\N
11459	2015CMP10	2015-06-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	04085P	TITULAIRE	\N	\N
11460	2015CMP10	2015-06-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08025T	SUPPLEANT	\N	2017-10-01 10:17:18
11461	2015CMP10	2015-06-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	14069U	SUPPLEANT	\N	\N
11462	2015CMP10	2015-06-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	\N	\N
11463	2015CMP10	2015-06-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	14259Y	SUPPLEANT	\N	\N
11464	2015CMP10	2015-06-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	SUPPLEANT	\N	\N
11468	2015CMP11	2015-06-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	TITULAIRE	\N	2017-09-24 18:20:10
11466	2015CMP10	2015-06-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	14097Y	SUPPLEANT	\N	\N
11467	2015CMP10	2015-06-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	\N	\N
11469	2015CMP11	2015-06-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01027Q	TITULAIRE	\N	2017-09-24 17:28:55
11470	2015CMP11	2015-06-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11088W	TITULAIRE	\N	2017-09-24 17:15:15
11471	2015CMP11	2015-06-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	04071H	TITULAIRE	\N	\N
11472	2015CMP11	2015-06-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	11070L	TITULAIRE	\N	\N
11473	2015CMP11	2015-06-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	08073C	TITULAIRE	\N	\N
11474	2015CMP11	2015-06-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	11040E	TITULAIRE	\N	\N
11475	2015CMP11	2015-06-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	14083S	SUPPLEANT	\N	\N
11483	2015CMP12	2015-06-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
11477	2015CMP11	2015-06-09 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	SUPPLEANT	\N	\N
11478	2015CMP11	2015-06-09 00:00:00	2020-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	14199E	SUPPLEANT	\N	\N
11479	2015CMP11	2015-06-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	99004R	SUPPLEANT	\N	\N
11480	2015CMP11	2015-06-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	11012A	SUPPLEANT	\N	\N
11481	2015CMP11	2015-06-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11057P	SUPPLEANT	\N	2017-09-24 18:23:22
11482	2015CMP11	2015-06-09 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	SUPPLEANT	\N	\N
11484	2015CMP12	2015-06-10 00:00:00	2017-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	95059Q	TITULAIRE	\N	2017-10-05 09:39:15
11485	2015CMP12	2015-06-10 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-13 14:20:25
11486	2015CMP12	2015-06-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	TITULAIRE	\N	\N
11487	2015CMP12	2015-06-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
11488	2015CMP12	2015-06-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08058D	TITULAIRE	\N	\N
11489	2015CMP12	2015-06-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	11056N	TITULAIRE	\N	\N
11490	2015CMP12	2015-06-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	\N	\N
11491	2015CMP12	2015-06-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11035H	SUPPLEANT	\N	2017-09-24 18:16:52
11492	2015CMP12	2015-06-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	14215L	SUPPLEANT	\N	\N
11493	2015CMP12	2015-06-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	08018U	SUPPLEANT	\N	\N
11494	2015CMP12	2015-06-10 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95049N	SUPPLEANT	\N	2017-10-01 10:42:05
11495	2015CMP12	2015-06-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	95063L	SUPPLEANT	\N	\N
11496	2015CMP12	2015-06-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	SUPPLEANT	\N	\N
11498	SOCI	2015-07-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14281W	\N	2015-07-10 00:00:00	2017-10-04 00:00:00
11499	NEANT	2015-09-07 00:00:00	2015-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	08049C	\N	2015-09-07 16:07:43	2015-09-16 11:31:44
11500	NEANT	2015-09-07 00:00:00	2015-09-13 00:00:00	ANCIEN	\N	\N	\N	\N	14327T	\N	2015-09-07 16:16:32	2015-09-14 14:28:13
11502	ETRD	2015-09-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08049C	\N	2015-09-16 11:32:41	2017-10-04 19:56:54
11503	PROSTITUTION	2015-09-28 00:00:00	2016-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	14259Y	\N	2015-09-28 19:10:49	2016-07-07 18:18:00
10578	CROISSANCE	2015-01-15 00:00:00	2015-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	\N	2015-01-09 11:40:12	2015-10-07 10:43:00
10583	CROISSANCE	2015-01-15 00:00:00	2015-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	\N	2015-01-09 11:40:55	2015-10-07 10:43:00
10586	CROISSANCE	2015-01-15 00:00:00	2015-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	14026U	\N	2015-01-09 11:41:23	2015-10-07 10:43:00
10589	CROISSANCE	2015-01-15 00:00:00	2015-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	\N	2015-01-09 11:41:53	2018-02-02 10:20:31
11139	CSCLOIS	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000278	\N	2015-02-10 14:20:24	\N
11156	CSCLOIS	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000417	\N	2015-02-10 14:20:24	\N
11193	CSCLOIS	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000326	\N	2015-02-10 14:20:24	\N
11210	CSCLOIS	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000208	\N	2015-02-10 14:20:24	\N
10966	CSCRECEVA	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	59542S	\N	2015-02-10 14:20:24	\N
11059	CSCRECEVA	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	65017N	\N	2015-02-10 14:20:24	\N
11090	CSCRECEVA	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000379	\N	2015-02-10 14:20:24	\N
11153	CSCRECEVA	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000251	\N	2015-02-10 14:20:24	\N
11186	CSCRECEVA	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000346	\N	2015-02-10 14:20:24	\N
11198	CSCRECEVA	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000250	\N	2015-02-10 14:20:24	\N
11221	CSCRELINT	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	59542S	\N	2015-02-10 14:20:24	\N
11244	CSCRELINT	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000097	\N	2015-02-10 14:20:24	\N
11250	CSCRELINT	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000346	\N	2015-02-10 14:20:24	\N
11252	CSCRELINT	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	56326X	\N	2015-02-10 14:20:24	\N
10973	CSCRELINT	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000206	\N	2015-02-10 14:20:24	\N
11047	CSCRELINT	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	59530N	\N	2015-02-10 14:20:24	\N
11051	CSCRELINT	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000250	\N	2015-02-10 14:20:24	\N
11069	CSCRELINT	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000511	\N	2015-02-10 14:20:24	\N
11077	CSCRELINT	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	56406W	\N	2015-02-10 14:20:24	\N
11087	CSCRELINT	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000129	\N	2015-02-10 14:20:24	\N
11099	CSCRELINT	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	57135W	\N	2015-02-10 14:20:24	\N
11103	CSCRELINT	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000736	\N	2015-02-10 14:20:24	\N
11170	CSCRELINT	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000083	\N	2015-02-10 14:20:24	\N
11176	CSCRELINT	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000753	\N	2015-02-10 14:20:24	\N
11189	CSCRELINT	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000116	\N	2015-02-10 14:20:24	\N
11190	CSCRELINT	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000036	\N	2015-02-10 14:20:24	\N
11195	CSCRELINT	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	57434F	\N	2015-02-10 14:20:24	\N
11226	CSCRGLT	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	56326X	\N	2015-02-10 14:20:24	\N
11254	CSCRGLT	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000003	\N	2015-02-10 14:20:24	\N
11263	CSCRGLT	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000080	\N	2015-02-10 14:20:24	\N
10965	CSCRGLT	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	59542S	\N	2015-02-10 14:20:24	\N
10997	CSCRGLT	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000116	\N	2015-02-10 14:20:24	\N
11027	CSCRGLT	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000061	\N	2015-02-10 14:20:24	\N
11073	CSCRGLT	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	59521M	\N	2015-02-10 14:20:24	\N
11089	CSCRGLT	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000379	\N	2015-02-10 14:20:24	\N
11208	CSCRGLT	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000352	\N	2015-02-10 14:20:24	\N
10945	CSCTRATEL	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000680	\N	2015-02-10 14:20:24	\N
10947	CSCTRATEL	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	59539X	\N	2015-02-10 14:20:24	\N
10956	CSCTRATEL	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000072	\N	2015-02-10 14:20:24	\N
10961	CSCTRATEL	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000230	\N	2015-02-10 14:20:24	\N
11034	CSCTRATEL	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000235	\N	2015-02-10 14:20:24	\N
11068	CSCTRATEL	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000105	\N	2015-02-10 14:20:24	\N
11115	CSCTRATEL	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000307	\N	2015-02-10 14:20:24	\N
11118	CSCTRATEL	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000698	\N	2015-02-10 14:20:24	\N
11164	CSCTRATEL	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000154	\N	2015-02-10 14:20:24	\N
11172	CSCTRATEL	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	59521M	\N	2015-02-10 14:20:24	\N
11173	CSCTRATEL	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000428	\N	2015-02-10 14:20:24	\N
11188	CSCTRATEL	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000292	\N	2015-02-10 14:20:24	\N
11209	CSCTRATEL	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000412	\N	2015-02-10 14:20:24	\N
11212	CSCTRATEL	\N	\N	ACTIF	\N	\N	\N	membre créé par script à partir de la table EXTSENCOM_MANDAT	000741	\N	2015-02-10 14:20:24	\N
11274	NEANT	2015-02-12 00:00:00	2015-02-15 00:00:00	ANCIEN	\N	\N	\N	\N	87003B	\N	2015-02-12 15:04:38	2015-02-16 17:21:48
11289	POLLUTION	2015-02-18 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	\N	08025T	\N	2015-02-18 10:02:56	2015-03-16 16:46:02
11290	POLLUTION	2015-02-18 00:00:00	2015-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	08068F	\N	2015-02-18 10:03:08	2015-10-07 10:45:34
11291	POLLUTION	2015-02-18 00:00:00	2015-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	11042G	\N	2015-02-18 10:03:17	2015-10-07 10:45:34
11292	POLLUTION	2015-02-18 00:00:00	2015-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	14051J	\N	2015-02-18 10:03:24	2015-10-07 10:45:34
11293	POLLUTION	2015-02-18 00:00:00	2015-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	11057P	\N	2015-02-18 10:03:34	2015-10-07 10:45:34
11294	2015CMP4	2015-02-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	04070G	TITULAIRE	2015-02-18 17:50:38	2015-02-18 17:51:28
11295	2015CMP4	2015-02-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11039M	SUPPLEANT	2015-02-18 17:50:52	2017-09-24 18:16:52
11296	2015CMP4	2015-02-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	14089Y	TITULAIRE	2015-02-18 17:51:05	\N
11297	2015CMP4	2015-02-18 00:00:00	2018-08-06 00:00:00	ANCIEN	\N	\N	\N	\N	95015C	SUPPLEANT	2015-02-18 17:51:17	2015-02-18 17:51:37
11298	2015CMP4	2015-02-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	04057K	TITULAIRE	2015-02-18 17:51:49	\N
11299	2015CMP4	2015-02-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11091R	SUPPLEANT	2015-02-18 17:52:03	2017-09-24 18:17:56
11300	2015CMP4	2015-02-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08039A	TITULAIRE	2015-02-18 17:52:14	\N
11301	2015CMP4	2015-02-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14249W	SUPPLEANT	2015-02-18 17:52:26	2015-02-18 17:52:29
11302	2015CMP4	2015-02-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	04059M	TITULAIRE	2015-02-18 17:52:36	\N
11303	2015CMP4	2015-02-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	14123H	SUPPLEANT	2015-02-18 17:52:57	2015-02-18 17:53:01
11304	2015CMP4	2015-02-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	11104D	TITULAIRE	2015-02-18 17:53:27	\N
11305	2015CMP4	2015-02-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08031R	SUPPLEANT	2015-02-18 17:53:39	2015-02-18 17:53:47
11306	2015CMP4	2015-02-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14235Q	TITULAIRE	2015-02-18 17:53:55	\N
11307	2015CMP4	2015-02-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11014C	SUPPLEANT	2015-02-18 17:54:26	2017-09-24 13:14:55
11309	NEANT	2015-03-04 00:00:00	2015-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	14269B	\N	2015-03-04 14:32:20	2015-03-12 09:46:57
11310	2015CMP5	2015-03-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11100Y	TITULAIRE	2015-03-10 17:24:06	2017-09-24 13:57:40
11311	2015CMP5	2015-03-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	14207L	SUPPLEANT	2015-03-10 17:24:17	2015-03-10 17:24:21
11312	2015CMP5	2015-03-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98050T	TITULAIRE	2015-03-10 17:24:28	\N
11313	2015CMP5	2015-03-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80013X	SUPPLEANT	2015-03-10 17:24:36	2015-03-10 17:24:42
11314	2015CMP5	2015-03-10 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08042U	TITULAIRE	2015-03-10 17:24:55	2017-10-01 10:20:50
11315	2015CMP5	2015-03-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	11065P	SUPPLEANT	2015-03-10 17:25:04	2015-03-10 17:25:10
11316	2015CMP5	2015-03-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	08009T	TITULAIRE	2015-03-10 17:25:19	\N
11317	2015CMP5	2015-03-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	14033T	SUPPLEANT	2015-03-10 17:25:27	2015-03-10 17:25:39
11318	2015CMP5	2015-03-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92039X	TITULAIRE	2015-03-10 17:25:51	2017-09-24 13:47:46
11319	2015CMP5	2015-03-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	11048N	SUPPLEANT	2015-03-10 17:25:59	2015-03-10 17:26:03
11320	2015CMP5	2015-03-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	14257W	TITULAIRE	2015-03-10 17:26:10	\N
11321	2015CMP5	2015-03-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	09001P	SUPPLEANT	2015-03-10 17:26:18	2017-09-24 17:47:27
11322	2015CMP5	2015-03-10 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	14013P	TITULAIRE	2015-03-10 17:26:31	2017-06-19 16:06:01
11323	2015CMP5	2015-03-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	14169X	SUPPLEANT	2015-03-10 17:26:45	2015-03-10 17:26:51
11324	2015CMP6	2015-03-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	04070G	TITULAIRE	2015-03-10 17:27:32	\N
11325	2015CMP6	2015-03-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08043V	SUPPLEANT	2015-03-10 17:27:40	2015-03-10 17:27:44
11326	2015CMP6	2015-03-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	14123H	TITULAIRE	2015-03-10 17:27:52	\N
11327	2015CMP6	2015-03-10 00:00:00	2018-08-06 00:00:00	ANCIEN	\N	\N	\N	\N	95015C	SUPPLEANT	2015-03-10 17:27:58	2015-03-10 17:28:02
11328	2015CMP6	2015-03-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	04057K	TITULAIRE	2015-03-10 17:28:10	\N
11329	2015CMP6	2015-03-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	14073Q	SUPPLEANT	2015-03-10 17:28:18	2015-03-10 17:28:21
11330	2015CMP6	2015-03-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	11043H	TITULAIRE	2015-03-10 17:28:28	\N
11331	2015CMP6	2015-03-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08031R	SUPPLEANT	2015-03-10 17:28:36	2015-03-10 17:28:40
11332	2015CMP6	2015-03-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11089X	TITULAIRE	2015-03-10 17:28:50	2017-09-24 17:15:15
11563	2015CMP14	2015-06-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	TITULAIRE	\N	\N
11570	2015CMP14	2015-06-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	SUPPLEANT	\N	\N
11572	2015CMP14	2015-06-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	10015M	SUPPLEANT	\N	\N
11575	2015CMP15	2015-07-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11037K	TITULAIRE	\N	2017-09-24 18:16:52
11588	2015CMP16	2015-07-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	08011M	TITULAIRE	\N	\N
11593	2015CMP16	2015-07-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01013J	TITULAIRE	\N	2017-09-24 17:06:55
11617	2015CMP18	2015-07-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	14071N	TITULAIRE	\N	\N
11629	2015CMP19	2015-09-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	04070G	TITULAIRE	\N	\N
11630	2015CMP19	2015-09-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	04033B	TITULAIRE	\N	\N
11631	2015CMP19	2015-09-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08039A	TITULAIRE	\N	\N
11635	2015CMP19	2015-09-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	14229S	TITULAIRE	\N	\N
11639	2015CMP19	2015-09-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	14105F	SUPPLEANT	\N	\N
11642	2015CMP19	2015-09-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	14179A	SUPPLEANT	\N	\N
11643	2015CMP19	2015-09-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14061L	SUPPLEANT	\N	\N
11644	2015CMP19	2015-09-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08031R	SUPPLEANT	\N	\N
11646	2015CMP20	2015-09-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	14259Y	TITULAIRE	\N	\N
11647	2015CMP20	2015-09-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	14275Y	TITULAIRE	\N	\N
11648	2015CMP20	2015-09-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	11072N	TITULAIRE	\N	\N
11649	2015CMP20	2015-09-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04056J	TITULAIRE	\N	2017-09-24 18:17:56
11650	2015CMP20	2015-09-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	04085P	TITULAIRE	\N	\N
11755	2015CMP27	2015-11-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	\N	\N
11652	2015CMP20	2015-09-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	\N	\N
11653	2015CMP20	2015-09-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11113E	SUPPLEANT	\N	2017-09-25 10:54:33
11654	2015CMP20	2015-09-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	14215L	SUPPLEANT	\N	\N
11655	2015CMP20	2015-09-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	14111D	SUPPLEANT	\N	\N
11657	2015CMP20	2015-09-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	\N	\N
11658	2015CMP20	2015-09-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	SUPPLEANT	\N	2017-09-24 13:29:42
12357	MAGISTRATURE	2016-06-15 00:00:00	2016-06-22 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	2016-06-15 15:22:28	2016-06-24 20:12:27
12358	MAGISTRATURE	2016-06-15 00:00:00	2016-06-22 00:00:00	ANCIEN	\N	\N	\N	\N	07034Q	TITULAIRE	2016-06-15 15:22:36	2016-06-24 20:12:27
12359	MAGISTRATURE	2016-06-15 00:00:00	2016-06-22 00:00:00	ANCIEN	\N	\N	\N	\N	10015M	TITULAIRE	2016-06-15 15:22:45	2016-06-24 20:12:27
12360	MAGISTRATURE	2016-06-15 00:00:00	2016-06-22 00:00:00	ANCIEN	\N	\N	\N	\N	01024M	TITULAIRE	2016-06-15 15:22:54	2016-06-24 20:12:27
12361	MAGISTRATURE	2016-06-15 00:00:00	2016-06-22 00:00:00	ANCIEN	\N	\N	\N	\N	14065Q	TITULAIRE	2016-06-15 15:23:18	2016-06-24 20:12:27
12362	MAGISTRATURE	2016-06-15 00:00:00	2016-06-22 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	TITULAIRE	2016-06-15 15:23:35	2016-06-24 20:12:27
12363	MAGISTRATURE	2016-06-15 00:00:00	2016-06-22 00:00:00	ANCIEN	\N	\N	\N	\N	11056N	TITULAIRE	2016-06-15 15:23:43	2016-06-24 20:12:27
12364	MAGISTRATURE	2016-06-15 00:00:00	2016-06-22 00:00:00	ANCIEN	\N	\N	\N	\N	08018U	SUPPLEANT	2016-06-15 15:24:02	2016-06-24 20:12:27
12365	MAGISTRATURE	2016-06-15 00:00:00	2016-06-22 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	SUPPLEANT	2016-06-15 15:24:08	2016-06-24 20:12:27
12366	MAGISTRATURE	2016-06-15 00:00:00	2016-06-22 00:00:00	ANCIEN	\N	\N	\N	\N	11072N	SUPPLEANT	2016-06-15 15:24:14	2016-06-24 20:12:27
12367	MAGISTRATURE	2016-06-15 00:00:00	2016-06-22 00:00:00	ANCIEN	\N	\N	\N	\N	04074L	SUPPLEANT	2016-06-15 15:24:21	2016-06-24 20:12:27
12368	MAGISTRATURE	2016-06-15 00:00:00	2016-06-22 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	SUPPLEANT	2016-06-15 15:24:28	2016-06-24 20:12:27
12369	MAGISTRATURE	2016-06-15 00:00:00	2016-06-22 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	2016-06-15 15:24:34	2016-06-24 20:12:27
12370	MAGISTRATURE	2016-06-15 00:00:00	2016-06-22 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	SUPPLEANT	2016-06-15 15:24:43	2016-06-24 20:12:27
12446	TRAVAIL	2016-06-23 00:00:00	2016-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	14265W	SUPPLEANT	2016-06-24 20:16:20	2016-06-30 15:31:51
12447	ELECTORALE	2016-06-30 00:00:00	2016-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	2016-06-30 15:35:51	2016-10-07 09:19:22
12451	ELECTORALE	2016-06-30 00:00:00	2016-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	TITULAIRE	2016-06-30 15:37:17	2016-10-07 09:19:22
12449	ELECTORALE	2016-06-30 00:00:00	2016-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	TITULAIRE	2016-06-30 15:36:23	2016-10-07 09:19:22
12450	ELECTORALE	2016-06-30 00:00:00	2016-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	08018U	TITULAIRE	2016-06-30 15:36:55	2016-10-07 09:19:22
12452	ELECTORALE	2016-06-30 00:00:00	2016-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	14275Y	TITULAIRE	2016-06-30 15:37:23	2016-10-07 09:19:22
12453	ELECTORALE	2016-06-30 00:00:00	2016-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	11026G	SUPPLEANT	2016-06-30 15:37:30	2016-10-07 09:19:22
12454	ELECTORALE	2016-06-30 00:00:00	2016-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	11034G	TITULAIRE	2016-06-30 15:37:35	2016-10-07 09:19:22
12455	ELECTORALE	2016-06-30 00:00:00	2016-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	TITULAIRE	2016-06-30 15:37:42	2016-10-07 09:19:22
12456	ELECTORALE	2016-06-30 00:00:00	2016-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	TITULAIRE	2016-06-30 15:37:47	2016-10-07 09:19:22
12457	ELECTORALE	2016-06-30 00:00:00	2016-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	11049P	TITULAIRE	2016-06-30 15:37:56	2016-10-07 09:19:22
12458	ELECTORALE	2016-06-30 00:00:00	2016-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	SUPPLEANT	2016-06-30 15:38:01	2016-10-07 09:19:22
12459	ELECTORALE	2016-06-30 00:00:00	2016-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	SUPPLEANT	2016-06-30 15:38:06	2016-10-07 09:19:22
12460	ELECTORALE	2016-06-30 00:00:00	2016-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	11037K	SUPPLEANT	2016-06-30 15:38:13	2016-10-07 09:19:22
12461	ELECTORALE	2016-06-30 00:00:00	2016-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	SUPPLEANT	2016-06-30 15:38:19	2016-10-07 09:19:22
12462	EGALITE	2016-07-07 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14235Q	\N	2016-07-07 17:23:36	2017-06-12 11:07:18
12463	EGALITE	2016-07-07 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	11034G	\N	2016-07-07 17:23:41	2017-06-12 11:07:18
12464	EGALITE	2016-07-07 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14231L	\N	2016-07-07 17:23:47	2017-06-12 11:07:18
12465	EGALITE	2016-07-07 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14179A	\N	2016-07-07 17:24:04	2017-06-12 11:07:18
12466	EGALITE	2016-07-07 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	11094U	\N	2016-07-07 17:24:09	2017-06-12 11:07:18
12467	EGALITE	2016-07-07 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	04089T	\N	2016-07-07 17:24:15	2017-06-12 11:07:18
12468	EGALITE	2016-07-07 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	08031R	\N	2016-07-07 17:24:20	2017-06-12 11:07:18
12469	EGALITE	2016-07-07 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	\N	2016-07-07 17:24:26	2017-06-12 11:07:18
12470	EGALITE	2016-07-07 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14053L	\N	2016-07-07 17:24:31	2017-06-12 11:07:18
12471	EGALITE	2016-07-07 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	95015C	\N	2016-07-07 17:24:37	2017-06-12 11:07:18
12472	EGALITE	2016-07-07 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	\N	2016-07-07 17:24:42	2017-06-12 11:07:18
12473	EGALITE	2016-07-07 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14079W	\N	2016-07-07 17:24:50	2017-06-12 11:07:18
12474	EGALITE	2016-07-07 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	11088W	\N	2016-07-07 17:24:59	2017-06-12 11:07:18
12475	EGALITE	2016-07-07 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	\N	2016-07-07 17:25:05	2017-06-12 11:07:18
12476	EGALITE	2016-07-07 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14187A	\N	2016-07-07 17:25:10	2017-06-12 11:07:18
12478	EGALITE	2016-07-07 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14213J	\N	2016-07-07 17:25:20	2017-06-12 11:07:18
10268	PROSTITUTION	2014-10-09 00:00:00	2016-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	14030Q	\N	2014-10-09 16:21:15	2016-07-07 18:13:47
12480	EGALITE	2016-07-07 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	11100Y	\N	2016-07-07 17:25:29	2017-06-12 11:07:18
12481	EGALITE	2016-07-07 00:00:00	2016-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	07032N	\N	2016-07-07 17:25:34	2016-11-18 12:37:49
12482	EGALITE	2016-07-07 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	04074L	\N	2016-07-07 17:25:39	2017-06-12 11:07:18
12483	EGALITE	2016-07-07 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	11090Q	\N	2016-07-07 17:25:44	2017-06-12 11:07:18
12484	EGALITE	2016-07-07 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14157T	\N	2016-07-07 17:25:49	2017-06-12 11:07:18
12485	EGALITE	2016-07-07 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	\N	2016-07-07 17:25:54	2017-06-12 11:07:18
12487	EGALITE	2016-07-07 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	08024S	\N	2016-07-07 17:26:03	2017-06-12 11:07:18
12488	EGALITE	2016-07-07 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	11027H	\N	2016-07-07 17:26:07	2017-06-12 11:07:18
12489	EGALITE	2016-07-07 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	11077T	\N	2016-07-07 17:26:15	2017-06-12 11:07:18
12491	EGALITE	2016-07-07 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	11104D	\N	2016-07-07 17:26:30	2017-06-12 11:07:18
12493	EGALITE	2016-07-07 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	\N	2016-07-07 17:27:33	2017-06-12 11:07:18
12495	EGALITE	2016-07-07 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	\N	2016-07-07 17:27:46	2017-06-12 11:07:18
12496	EGALITE	2016-07-07 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	11037K	\N	2016-07-07 17:28:04	2017-06-12 11:07:18
12498	EGALITE	2016-07-07 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14269B	\N	2016-07-07 17:28:15	2017-06-12 11:07:18
12499	EGALITE	2016-07-07 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	11055M	\N	2016-07-07 17:30:38	2017-06-12 11:07:18
10452	2014CMP11	2014-05-20 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	2015-10-13 14:22:01
10909	2015CMP3	2015-01-30 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	2015-01-30 14:38:03	2015-10-13 14:20:35
11504	AFCL	2015-10-12 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14329V	\N	2015-10-12 09:41:57	2017-10-04 19:12:55
11505	LOIS	2015-10-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	\N	2015-10-12 14:47:37	2017-09-24 17:29:37
11589	2015CMP16	2015-07-09 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	TITULAIRE	\N	\N
10750	AFCL	2015-01-13 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	14263U	\N	2015-01-13 11:56:57	2017-06-19 16:04:13
11507	AFEU	2015-10-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	\N	2015-10-12 14:48:15	2017-09-24 17:29:37
11802	2015CMP31	2015-11-19 00:00:00	2017-06-01 00:00:00	ANCIEN	\N	\N	\N	\N	14175V	SUPPLEANT	\N	2017-06-02 10:02:56
11609	2015CMP17	2015-07-08 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98018T	SUPPLEANT	\N	\N
11678	2015CMP22	2015-10-28 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08058D	TITULAIRE	\N	\N
11685	2015CMP22	2015-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	95063L	SUPPLEANT	\N	\N
11686	2015CMP22	2015-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	SUPPLEANT	\N	2017-09-24 13:29:42
11909	ZEROCHOMAGE	2016-02-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	01034P	TITULAIRE	2016-02-23 15:09:33	\N
11905	ZEROCHOMAGE	2016-02-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	04092N	TITULAIRE	2016-02-23 15:09:07	\N
11906	ZEROCHOMAGE	2016-02-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	12042Y	TITULAIRE	2016-02-23 15:09:15	2017-09-24 19:31:54
11981	PROTECTION	2016-01-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	11067R	TITULAIRE	2016-02-23 15:42:18	\N
11910	ZEROCHOMAGE	2016-02-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	14121F	TITULAIRE	2016-02-23 15:09:54	\N
11907	ZEROCHOMAGE	2016-02-02 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14087W	TITULAIRE	2016-02-23 15:09:20	\N
11908	ZEROCHOMAGE	2016-02-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	14071N	TITULAIRE	2016-02-23 15:09:26	\N
11911	ZEROCHOMAGE	2016-02-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	TITULAIRE	2016-02-23 15:10:02	2017-09-24 17:35:15
11912	ZEROCHOMAGE	2016-02-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	10006L	SUPPLEANT	2016-02-23 15:10:09	2016-02-23 15:10:15
11913	ZEROCHOMAGE	2016-02-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	14151M	SUPPLEANT	2016-02-23 15:11:23	2016-02-23 15:11:55
11914	ZEROCHOMAGE	2016-02-02 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14034U	SUPPLEANT	2016-02-23 15:11:28	2016-02-23 15:11:58
11915	ZEROCHOMAGE	2016-02-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11061K	SUPPLEANT	2016-02-23 15:11:33	2017-09-24 17:42:25
11980	PROTECTION	2016-01-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	04092N	TITULAIRE	2016-02-23 15:42:12	\N
11982	PROTECTION	2016-01-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	11103C	TITULAIRE	2016-02-23 15:42:25	\N
11955	FINDEVIE	2016-01-19 00:00:00	2016-02-23 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	TITULAIRE	2016-02-23 15:34:42	2016-02-23 15:36:55
11966	FINDEVIE	2016-01-19 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	07034Q	TITULAIRE	2016-02-23 15:37:10	\N
11965	FINDEVIE	2016-01-19 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98024R	TITULAIRE	2016-02-23 15:37:04	\N
11967	FINDEVIE	2016-01-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01011G	TITULAIRE	2016-02-23 15:37:15	2017-09-24 16:43:43
11968	FINDEVIE	2016-01-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11112D	TITULAIRE	2016-02-23 15:37:20	2017-09-24 16:45:26
11969	FINDEVIE	2016-01-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	14231L	TITULAIRE	2016-02-23 15:37:26	\N
11970	FINDEVIE	2016-01-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	11031D	TITULAIRE	2016-02-23 15:37:29	\N
11983	PROTECTION	2016-01-12 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	07034Q	TITULAIRE	2016-02-23 15:42:30	\N
11972	FINDEVIE	2016-01-19 00:00:00	2020-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	14239U	SUPPLEANT	2016-02-23 15:38:41	2016-02-23 15:38:43
11973	FINDEVIE	2016-01-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	14217N	SUPPLEANT	2016-02-23 15:38:48	2016-02-23 15:38:51
11974	FINDEVIE	2016-01-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11061K	SUPPLEANT	2016-02-23 15:38:56	2017-09-24 17:42:25
11975	FINDEVIE	2016-01-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	14223L	SUPPLEANT	2016-02-23 15:39:03	2016-02-23 15:39:05
11976	FINDEVIE	2016-01-19 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14265W	SUPPLEANT	2016-02-23 15:39:10	2016-02-23 15:39:13
11977	FINDEVIE	2016-01-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14271U	SUPPLEANT	2016-02-23 15:39:18	2017-09-24 17:06:55
11984	PROTECTION	2016-01-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	00003C	TITULAIRE	2016-02-23 15:42:38	2017-09-24 18:05:40
11985	PROTECTION	2016-01-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	14042U	TITULAIRE	2016-02-23 15:42:43	\N
11986	PROTECTION	2016-01-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	11031D	TITULAIRE	2016-02-23 15:42:50	\N
11987	PROTECTION	2016-01-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	14267Y	SUPPLEANT	2016-02-23 15:54:48	2016-02-23 15:55:08
11988	PROTECTION	2016-01-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	14281W	SUPPLEANT	2016-02-23 15:54:56	2016-02-23 15:55:11
11989	PROTECTION	2016-01-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	14213J	SUPPLEANT	2016-02-23 15:55:01	2016-02-23 15:55:05
11990	PROTECTION	2016-01-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14018U	SUPPLEANT	2016-02-23 15:55:16	2017-09-24 18:49:56
11991	PROTECTION	2016-01-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14119M	SUPPLEANT	2016-02-23 15:55:25	2016-02-23 15:55:28
11992	PROTECTION	2016-01-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	14071N	SUPPLEANT	2016-02-23 15:55:33	2016-02-23 15:55:35
11993	PROTECTION	2016-01-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14227Q	SUPPLEANT	2016-02-23 15:55:41	2016-02-23 15:55:43
11916	ZEROCHOMAGE	2016-02-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	14026U	SUPPLEANT	2016-02-23 15:11:38	2016-02-23 15:12:05
11917	ZEROCHOMAGE	2016-02-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14018U	SUPPLEANT	2016-02-23 15:11:42	2017-09-24 18:49:56
11918	ZEROCHOMAGE	2016-02-02 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14119M	SUPPLEANT	2016-02-23 15:11:47	2016-02-23 15:12:14
11919	CCI	2016-02-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11100Y	TITULAIRE	2016-02-23 15:16:52	2017-09-24 13:57:40
11920	CCI	2016-02-10 00:00:00	2016-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	14263U	TITULAIRE	2016-02-23 15:16:59	2016-12-01 10:36:51
11921	CCI	2016-02-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	11090Q	TITULAIRE	2016-02-23 15:17:05	\N
11922	CCI	2016-02-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	14205J	TITULAIRE	2016-02-23 15:17:09	\N
11923	CCI	2016-02-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	11066Q	TITULAIRE	2016-02-23 15:17:17	\N
11924	CCI	2016-02-10 00:00:00	2020-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	08068F	TITULAIRE	2016-02-23 15:17:23	\N
11925	CCI	2016-02-10 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	14013P	TITULAIRE	2016-02-23 15:17:27	2017-06-19 16:06:01
11926	CCI	2016-02-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01008M	SUPPLEANT	2016-02-23 15:17:35	2017-09-24 13:44:49
11927	CCI	2016-02-10 00:00:00	2020-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	11081P	SUPPLEANT	2016-02-23 15:17:44	2016-02-23 15:17:49
11928	CCI	2016-02-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80013X	SUPPLEANT	2016-02-23 15:17:57	2016-02-23 15:18:00
11929	CCI	2016-02-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04055H	SUPPLEANT	2016-02-23 15:18:06	2017-09-24 18:05:41
11930	CCI	2016-02-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	11099A	SUPPLEANT	2016-02-23 15:18:14	2016-02-23 15:18:20
11931	CCI	2016-02-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	SUPPLEANT	2016-02-23 15:18:25	2016-02-23 15:18:28
11932	CCI	2016-02-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11111C	SUPPLEANT	2016-02-23 15:18:32	2017-09-24 16:45:26
11940	SECURITE	2016-02-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	05008E	TITULAIRE	2016-02-23 15:21:36	\N
11941	SECURITE	2016-02-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	14069U	TITULAIRE	2016-02-23 15:21:42	\N
11942	SECURITE	2016-02-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	02002K	TITULAIRE	2016-02-23 15:21:48	\N
11944	SECURITE	2016-02-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	95063L	TITULAIRE	2016-02-23 15:21:59	\N
11945	SECURITE	2016-02-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11059R	TITULAIRE	2016-02-23 15:22:04	2017-09-24 17:42:26
11943	SECURITE	2016-02-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	TITULAIRE	2016-02-23 15:21:54	2017-09-24 13:29:42
11946	SECURITE	2016-02-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	04085P	TITULAIRE	2016-02-23 15:22:08	\N
11947	SECURITE	2016-02-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	2016-02-23 15:22:14	2016-02-23 15:22:18
11948	SECURITE	2016-02-10 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	SUPPLEANT	2016-02-23 15:22:24	2016-02-23 15:22:26
11949	SECURITE	2016-02-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11107G	SUPPLEANT	2016-02-23 15:22:31	2017-09-24 17:06:55
11950	SECURITE	2016-02-10 00:00:00	2020-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	08044W	SUPPLEANT	2016-02-23 15:22:39	2016-02-23 15:22:43
11951	SECURITE	2016-02-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04079R	SUPPLEANT	2016-02-23 15:22:48	2017-09-24 17:47:27
11954	SECURITE	2016-02-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	2016-02-23 15:26:53	2016-02-23 15:27:02
11953	SECURITE	2016-02-10 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08042U	SUPPLEANT	2016-02-23 15:23:20	2017-10-01 10:20:50
11979	FINDEVIE	2016-01-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11093T	SUPPLEANT	2016-02-23 15:39:39	2017-09-24 12:57:09
11616	2015CMP18	2015-07-08 00:00:00	2020-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	08041T	TITULAIRE	\N	\N
11687	2015CMP23	2015-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	08009T	TITULAIRE	\N	\N
11689	2015CMP23	2015-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	14031R	TITULAIRE	\N	\N
11690	2015CMP23	2015-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14135M	TITULAIRE	\N	\N
11700	2015CMP24	2015-11-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	08009T	TITULAIRE	\N	\N
11701	2015CMP24	2015-11-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14135M	TITULAIRE	\N	\N
11702	2015CMP24	2015-11-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	14031R	TITULAIRE	\N	\N
11703	2015CMP24	2015-11-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14157T	TITULAIRE	\N	\N
11704	2015CMP24	2015-11-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11107G	TITULAIRE	\N	2017-09-24 17:06:55
11705	2015CMP24	2015-11-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01015L	TITULAIRE	\N	2017-09-24 17:19:42
11709	2015CMP24	2015-11-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11059R	SUPPLEANT	\N	2017-09-24 17:42:26
11710	2015CMP24	2015-11-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	14221J	SUPPLEANT	\N	\N
11711	2015CMP24	2015-11-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	13002U	SUPPLEANT	\N	2017-09-24 17:42:26
11712	2015CMP24	2015-11-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	05012A	SUPPLEANT	\N	\N
11718	2015CMP25	2015-10-15 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08043V	TITULAIRE	\N	\N
11722	2015CMP25	2015-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11093T	SUPPLEANT	\N	2017-09-24 12:57:09
11723	2015CMP25	2015-10-15 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08017T	SUPPLEANT	\N	\N
11725	2015CMP25	2015-10-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	11012A	SUPPLEANT	\N	\N
12047	DEONTOLOGIE	2016-03-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	14215L	TITULAIRE	2016-03-11 14:58:12	2016-03-11 14:59:28
12045	DEONTOLOGIE	2016-03-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	05008E	TITULAIRE	2016-03-11 14:57:57	2016-03-11 14:59:02
12046	DEONTOLOGIE	2016-03-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	TITULAIRE	2016-03-11 14:58:04	2017-09-24 17:29:37
12048	DEONTOLOGIE	2016-03-02 00:00:00	2017-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	01007L	TITULAIRE	2016-03-11 14:58:20	2017-07-24 09:56:26
12049	DEONTOLOGIE	2016-03-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11037K	TITULAIRE	2016-03-11 14:58:35	2017-09-24 18:16:52
12050	DEONTOLOGIE	2016-03-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	95063L	TITULAIRE	2016-03-11 15:00:36	\N
12052	DEONTOLOGIE	2016-03-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	14069U	SUPPLEANT	2016-03-11 15:00:52	2016-03-11 15:00:58
12053	DEONTOLOGIE	2016-03-02 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	2016-03-11 15:01:09	2016-03-11 15:01:12
12054	DEONTOLOGIE	2016-03-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11035H	SUPPLEANT	2016-03-11 15:01:18	2017-09-24 18:16:52
12055	DEONTOLOGIE	2016-03-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	SUPPLEANT	2016-03-11 15:01:29	2016-03-11 15:01:34
12056	DEONTOLOGIE	2016-03-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	08018U	SUPPLEANT	2016-03-11 15:01:41	2016-03-11 15:01:45
12058	DEONTOLOGIE	2016-03-02 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98035U	SUPPLEANT	2016-03-11 15:02:03	2016-03-11 15:02:08
12059	NEANT	2016-03-12 00:00:00	2016-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	04050C	\N	2016-03-11 18:10:19	2016-03-15 16:03:57
12060	ETRD	2016-03-15 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	04050C	\N	2016-03-15 16:03:57	2017-06-19 16:03:48
12061	COMSPEAPU	2016-03-17 00:00:00	2016-04-06 00:00:00	ANCIEN	\N	\N	\N	\N	04067M	\N	2016-03-17 15:20:47	2016-05-04 17:11:08
12219	ABUS	2016-05-12 00:00:00	2016-05-17 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	TITULAIRE	2016-05-12 13:51:16	2016-05-18 08:49:08
12220	ABUS	2016-05-12 00:00:00	2016-05-17 00:00:00	ANCIEN	\N	\N	\N	\N	08011M	TITULAIRE	2016-05-12 13:51:34	2016-05-18 08:49:08
12221	ABUS	2016-05-12 00:00:00	2016-05-17 00:00:00	ANCIEN	\N	\N	\N	\N	07034Q	TITULAIRE	2016-05-12 13:51:40	2016-05-18 08:49:08
12222	ABUS	2016-05-12 00:00:00	2016-05-17 00:00:00	ANCIEN	\N	\N	\N	\N	01027Q	TITULAIRE	2016-05-12 13:51:45	2016-05-18 08:49:08
12223	ABUS	2016-05-12 00:00:00	2016-05-17 00:00:00	ANCIEN	\N	\N	\N	\N	11053K	TITULAIRE	2016-05-12 13:51:52	2016-05-18 08:49:08
12224	ABUS	2016-05-12 00:00:00	2016-05-17 00:00:00	ANCIEN	\N	\N	\N	\N	14225N	TITULAIRE	2016-05-12 13:52:00	2016-05-18 08:49:08
12225	ABUS	2016-05-12 00:00:00	2016-05-17 00:00:00	ANCIEN	\N	\N	\N	\N	11040E	TITULAIRE	2016-05-12 13:52:07	2016-05-18 08:49:08
12226	ABUS	2016-05-12 00:00:00	2016-05-17 00:00:00	ANCIEN	\N	\N	\N	\N	88008L	SUPPLEANT	2016-05-12 13:52:16	2016-05-18 08:49:08
12227	ABUS	2016-05-12 00:00:00	2016-05-17 00:00:00	ANCIEN	\N	\N	\N	\N	11070L	SUPPLEANT	2016-05-12 13:52:25	2016-05-18 08:49:08
12228	ABUS	2016-05-12 00:00:00	2016-05-17 00:00:00	ANCIEN	\N	\N	\N	\N	04071H	SUPPLEANT	2016-05-12 13:52:31	2016-05-18 08:49:08
12229	ABUS	2016-05-12 00:00:00	2016-05-17 00:00:00	ANCIEN	\N	\N	\N	\N	07029T	SUPPLEANT	2016-05-12 13:52:36	2016-05-18 08:49:08
12230	ABUS	2016-05-12 00:00:00	2016-05-17 00:00:00	ANCIEN	\N	\N	\N	\N	11057P	SUPPLEANT	2016-05-12 13:52:47	2016-05-18 08:49:08
12231	ABUS	2016-05-12 00:00:00	2016-05-17 00:00:00	ANCIEN	\N	\N	\N	\N	14173T	SUPPLEANT	2016-05-12 13:52:52	2016-05-18 08:49:08
12232	ABUS	2016-05-12 00:00:00	2016-05-17 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	SUPPLEANT	2016-05-12 13:52:56	2016-05-18 08:49:08
12316	ARCHITECTURE	2016-06-08 00:00:00	2016-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	04070G	TITULAIRE	2016-06-08 17:36:07	2016-06-24 20:13:48
12317	ARCHITECTURE	2016-06-08 00:00:00	2016-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	08039A	TITULAIRE	2016-06-08 17:36:12	2016-06-24 20:13:48
12318	ARCHITECTURE	2016-06-08 00:00:00	2016-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	01025N	TITULAIRE	2016-06-08 17:36:18	2016-06-24 20:13:48
12319	ARCHITECTURE	2016-06-08 00:00:00	2016-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	04057K	TITULAIRE	2016-06-08 17:36:23	2016-06-24 20:13:48
12320	ARCHITECTURE	2016-06-08 00:00:00	2016-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	04059M	TITULAIRE	2016-06-08 17:36:29	2016-06-24 20:13:48
12321	ARCHITECTURE	2016-06-08 00:00:00	2016-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	14109K	TITULAIRE	2016-06-08 17:36:34	2016-06-24 20:13:48
12322	ARCHITECTURE	2016-06-08 00:00:00	2016-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	12041X	TITULAIRE	2016-06-08 17:36:40	2016-06-24 20:13:48
12323	ARCHITECTURE	2016-06-08 00:00:00	2016-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	14133K	SUPPLEANT	2016-06-08 17:36:45	2016-06-24 20:13:49
12324	ARCHITECTURE	2016-06-08 00:00:00	2016-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	08043V	SUPPLEANT	2016-06-08 17:36:51	2016-06-24 20:13:49
12325	ARCHITECTURE	2016-06-08 00:00:00	2016-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	14249W	SUPPLEANT	2016-06-08 17:36:58	2016-06-24 20:13:49
12326	ARCHITECTURE	2016-06-08 00:00:00	2016-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	14061L	SUPPLEANT	2016-06-08 17:37:03	2016-06-24 20:13:49
12327	ARCHITECTURE	2016-06-08 00:00:00	2016-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	08031R	SUPPLEANT	2016-06-08 17:37:09	2016-06-24 20:13:49
14496	ENTREPRISES	2018-10-10 00:00:00	2019-05-23 00:00:00	ANCIEN	\N	\N	\N	\N	14187A	\N	\N	\N
12328	ARCHITECTURE	2016-06-08 00:00:00	2016-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	92040Q	SUPPLEANT	2016-06-08 17:37:14	2016-06-24 20:13:49
12329	MEDIAS	2016-06-08 00:00:00	2016-06-14 00:00:00	ANCIEN	\N	\N	\N	\N	14229S	TITULAIRE	2016-06-08 17:37:29	2016-06-24 20:13:42
12330	MEDIAS	2016-06-08 00:00:00	2016-06-14 00:00:00	ANCIEN	\N	\N	\N	\N	04070G	TITULAIRE	2016-06-08 17:41:47	2016-06-24 20:13:42
12331	MEDIAS	2016-06-08 00:00:00	2016-06-14 00:00:00	ANCIEN	\N	\N	\N	\N	04074L	TITULAIRE	2016-06-08 17:41:52	2016-06-24 20:13:42
12332	MEDIAS	2016-06-08 00:00:00	2016-06-14 00:00:00	ANCIEN	\N	\N	\N	\N	08039A	TITULAIRE	2016-06-08 17:41:56	2016-06-24 20:13:42
12333	MEDIAS	2016-06-08 00:00:00	2016-06-14 00:00:00	ANCIEN	\N	\N	\N	\N	04057K	TITULAIRE	2016-06-08 17:42:01	2016-06-24 20:13:42
12334	MEDIAS	2016-06-08 00:00:00	2016-06-14 00:00:00	ANCIEN	\N	\N	\N	\N	04059M	TITULAIRE	2016-06-08 17:42:07	2016-06-24 20:13:42
12335	MEDIAS	2016-06-08 00:00:00	2016-06-14 00:00:00	ANCIEN	\N	\N	\N	\N	14263U	TITULAIRE	2016-06-08 17:42:27	2016-06-24 20:13:42
12336	MEDIAS	2016-06-08 00:00:00	2016-06-14 00:00:00	ANCIEN	\N	\N	\N	\N	08043V	SUPPLEANT	2016-06-08 17:42:33	2016-06-24 20:13:42
12337	MEDIAS	2016-06-08 00:00:00	2016-06-14 00:00:00	ANCIEN	\N	\N	\N	\N	14089Y	SUPPLEANT	2016-06-08 17:42:39	2016-06-24 20:13:42
12338	MEDIAS	2016-06-08 00:00:00	2016-06-14 00:00:00	ANCIEN	\N	\N	\N	\N	92015P	SUPPLEANT	2016-06-08 17:42:44	2016-06-24 20:13:42
12339	MEDIAS	2016-06-08 00:00:00	2016-06-14 00:00:00	ANCIEN	\N	\N	\N	\N	14123H	SUPPLEANT	2016-06-08 17:42:49	2016-06-24 20:13:42
12340	MEDIAS	2016-06-08 00:00:00	2016-06-14 00:00:00	ANCIEN	\N	\N	\N	\N	14241N	SUPPLEANT	2016-06-08 17:42:57	2016-06-24 20:13:42
12341	MEDIAS	2016-06-08 00:00:00	2016-06-14 00:00:00	ANCIEN	\N	\N	\N	\N	14059S	SUPPLEANT	2016-06-08 17:43:02	2016-06-24 20:13:42
12342	MEDIAS	2016-06-08 00:00:00	2016-06-14 00:00:00	ANCIEN	\N	\N	\N	\N	11043H	SUPPLEANT	2016-06-08 17:43:06	2016-06-24 20:13:42
12371	CITOYENNETE	2016-06-22 00:00:00	2016-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	11055M	\N	2016-06-22 16:28:37	2016-07-07 16:33:43
12372	CITOYENNETE	2016-06-22 00:00:00	2016-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	08043V	\N	2016-06-22 16:28:42	2016-07-07 16:33:43
12373	CITOYENNETE	2016-06-22 00:00:00	2016-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	14053L	\N	2016-06-22 16:28:49	2016-07-07 16:33:43
12374	CITOYENNETE	2016-06-22 00:00:00	2016-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	95015C	\N	2016-06-22 16:29:18	2016-07-07 16:33:43
12375	CITOYENNETE	2016-06-22 00:00:00	2016-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	08024S	\N	2016-06-22 16:29:24	2016-07-07 16:33:43
12376	CITOYENNETE	2016-06-22 00:00:00	2016-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	11027H	\N	2016-06-22 16:29:30	2016-07-07 16:33:43
12377	CITOYENNETE	2016-06-22 00:00:00	2016-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	\N	2016-06-22 16:29:36	2016-07-07 16:33:43
12378	CITOYENNETE	2016-06-22 00:00:00	2016-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	14079W	\N	2016-06-22 16:29:42	2016-07-07 16:33:43
12379	CITOYENNETE	2016-06-22 00:00:00	2016-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	11088W	\N	2016-06-22 16:29:49	2016-07-07 16:33:43
12380	CITOYENNETE	2016-06-22 00:00:00	2016-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	\N	2016-06-22 16:29:56	2016-07-07 16:33:43
12381	CITOYENNETE	2016-06-22 00:00:00	2016-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	04089T	\N	2016-06-22 16:30:31	2016-07-07 16:33:43
11546	ISLAM	2015-12-16 00:00:00	2016-07-10 00:00:00	ANCIEN	\N	\N	\N	\N	14247U	\N	2015-12-16 11:28:07	2016-10-07 09:16:01
11592	2015CMP16	2015-07-09 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	98046X	TITULAIRE	\N	2017-09-25 09:56:00
11594	2015CMP16	2015-07-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	14083S	SUPPLEANT	\N	\N
11595	2015CMP16	2015-07-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11042G	SUPPLEANT	\N	2017-09-24 17:35:15
11596	2015CMP16	2015-07-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11088W	SUPPLEANT	\N	2017-09-24 17:15:15
11597	2015CMP16	2015-07-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	04071H	SUPPLEANT	\N	\N
11598	2015CMP16	2015-07-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	99004R	SUPPLEANT	\N	\N
11599	2015CMP16	2015-07-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	11012A	SUPPLEANT	\N	\N
11600	2015CMP16	2015-07-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11057P	SUPPLEANT	\N	2017-09-24 18:23:22
11613	2015CMP17	2015-07-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	11054L	SUPPLEANT	\N	\N
11614	2015CMP17	2015-07-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01056V	SUPPLEANT	\N	2017-09-24 17:04:02
11615	2015CMP18	2015-07-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	04092N	TITULAIRE	\N	\N
11619	2015CMP18	2015-07-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	00003C	TITULAIRE	\N	2017-09-24 18:05:40
11620	2015CMP18	2015-07-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	11067R	TITULAIRE	\N	\N
11624	2015CMP18	2015-07-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	12042Y	SUPPLEANT	\N	2017-09-24 19:31:54
11626	2015CMP18	2015-07-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	14026U	SUPPLEANT	\N	\N
11688	2015CMP23	2015-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14157T	TITULAIRE	\N	\N
11692	2015CMP23	2015-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14051J	TITULAIRE	\N	\N
11693	2015CMP23	2015-10-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01015L	TITULAIRE	\N	2017-09-24 17:19:42
11694	2015CMP23	2015-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14261S	SUPPLEANT	\N	\N
11695	2015CMP23	2015-10-26 00:00:00	2018-12-30 00:00:00	ANCIEN	\N	\N	\N	\N	98023Q	SUPPLEANT	\N	\N
11696	2015CMP23	2015-10-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11059R	SUPPLEANT	\N	2017-09-24 17:42:26
11697	2015CMP23	2015-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	14221J	SUPPLEANT	\N	\N
11726	2015CMP25	2015-10-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	11043H	SUPPLEANT	\N	\N
11731	2015CMP26	2015-11-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95049N	TITULAIRE	\N	2017-10-01 10:42:05
11732	2015CMP26	2015-11-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	04085P	TITULAIRE	\N	\N
11733	2015CMP26	2015-11-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	11026G	TITULAIRE	\N	\N
11735	2015CMP26	2015-11-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	\N	\N
11738	2015CMP26	2015-11-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04079R	SUPPLEANT	\N	2017-09-24 17:47:27
11739	2015CMP26	2015-11-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	10015M	SUPPLEANT	\N	\N
11740	2015CMP26	2015-11-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	\N	\N
12029	MINEURS	2016-03-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	05008E	TITULAIRE	2016-03-11 11:48:56	\N
11811	2015CMP31	2015-11-19 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08014Q	SUPPLEANT	\N	\N
11824	2015CMP32	2015-12-09 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	SUPPLEANT	\N	\N
12031	MINEURS	2016-03-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	TITULAIRE	2016-03-11 11:50:03	2017-09-24 13:29:42
12033	MINEURS	2016-03-02 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	TITULAIRE	2016-03-11 11:50:14	\N
12034	MINEURS	2016-03-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	11056N	TITULAIRE	2016-03-11 11:50:32	\N
12035	MINEURS	2016-03-02 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14065Q	TITULAIRE	2016-03-11 11:50:54	\N
12036	MINEURS	2016-03-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04056J	TITULAIRE	2016-03-11 11:51:00	2017-09-24 18:17:56
12037	MINEURS	2016-03-02 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	2016-03-11 11:51:09	2016-03-11 11:51:12
12038	MINEURS	2016-03-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	SUPPLEANT	2016-03-11 11:51:23	2016-03-11 11:51:27
12039	MINEURS	2016-03-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	11026G	SUPPLEANT	2016-03-11 11:51:41	2016-03-11 11:51:51
12040	MINEURS	2016-03-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	08018U	SUPPLEANT	2016-03-11 11:51:46	2016-03-11 11:51:49
12041	MINEURS	2016-03-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	14111D	SUPPLEANT	2016-03-11 11:51:59	2016-03-11 11:52:03
12042	MINEURS	2016-03-02 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	07034Q	SUPPLEANT	2016-03-11 11:52:07	2016-03-11 11:52:10
12043	MINEURS	2016-03-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	SUPPLEANT	2016-03-11 11:52:24	2016-03-11 11:52:29
12077	BLEUE	2016-04-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	08009T	TITULAIRE	2016-04-04 15:21:58	2016-04-04 15:24:24
12078	BLEUE	2016-04-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	14031R	TITULAIRE	2016-04-04 15:22:13	2016-04-04 15:24:44
12079	BLEUE	2016-04-01 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95062K	TITULAIRE	2016-04-04 15:22:25	2016-04-04 15:25:03
12080	BLEUE	2016-04-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14157T	TITULAIRE	2016-04-04 15:22:35	2016-04-04 15:25:23
12081	BLEUE	2016-04-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01022K	TITULAIRE	2016-04-04 15:22:52	2017-09-24 17:14:26
12082	BLEUE	2016-04-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14051J	TITULAIRE	2016-04-04 15:23:02	2016-04-04 15:25:52
12084	BLEUE	2016-04-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	11109J	SUPPLEANT	2016-04-04 15:29:15	2016-04-04 15:45:50
12085	BLEUE	2016-04-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14261S	SUPPLEANT	2016-04-04 15:29:43	2016-04-04 15:46:12
12086	BLEUE	2016-04-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	14030Q	SUPPLEANT	2016-04-04 15:30:00	2016-04-04 15:46:31
12087	BLEUE	2016-04-01 00:00:00	2020-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	96004D	SUPPLEANT	2016-04-04 15:30:11	2016-04-04 15:46:47
12233	COMSPEAPU	2016-05-13 00:00:00	2016-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04067M	\N	2016-05-13 09:47:19	2016-10-05 16:14:35
12382	CITOYENNETE	2016-06-22 00:00:00	2016-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	14187A	\N	2016-06-22 16:30:39	2016-07-07 16:33:43
12383	CITOYENNETE	2016-06-22 00:00:00	2016-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	11034G	\N	2016-06-22 16:30:50	2016-07-07 16:33:43
12384	CITOYENNETE	2016-06-22 00:00:00	2016-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	04035D	\N	2016-06-22 16:30:58	2016-07-07 16:33:43
12385	CITOYENNETE	2016-06-22 00:00:00	2016-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	14231L	\N	2016-06-22 16:31:03	2016-07-07 16:33:43
12386	CITOYENNETE	2016-06-22 00:00:00	2016-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	14179A	\N	2016-06-22 16:31:11	2016-07-07 16:33:43
12387	CITOYENNETE	2016-06-22 00:00:00	2016-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	14213J	\N	2016-06-22 16:31:16	2016-07-07 16:33:43
12388	CITOYENNETE	2016-06-22 00:00:00	2016-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	08031R	\N	2016-06-22 16:31:23	2016-07-07 16:33:43
12389	CITOYENNETE	2016-06-22 00:00:00	2016-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	11100Y	\N	2016-06-22 16:31:28	2016-07-07 16:33:43
12390	CITOYENNETE	2016-06-22 00:00:00	2016-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	11077T	\N	2016-06-22 16:31:36	2016-07-07 16:33:43
12391	CITOYENNETE	2016-06-22 00:00:00	2016-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	08012N	\N	2016-06-22 16:31:41	2016-07-07 16:33:43
12392	CITOYENNETE	2016-06-22 00:00:00	2016-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	11104D	\N	2016-06-22 16:31:48	2016-07-07 16:33:43
12393	CITOYENNETE	2016-06-22 00:00:00	2016-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	\N	2016-06-22 16:31:54	2016-07-07 16:33:43
12394	CITOYENNETE	2016-06-22 00:00:00	2016-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	07032N	\N	2016-06-22 16:32:01	2016-07-07 16:33:43
12395	CITOYENNETE	2016-06-22 00:00:00	2016-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	04074L	\N	2016-06-22 16:32:06	2016-07-07 16:33:43
12396	CITOYENNETE	2016-06-22 00:00:00	2016-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	11090Q	\N	2016-06-22 16:32:12	2016-07-07 16:33:43
12397	CITOYENNETE	2016-06-22 00:00:00	2016-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	14235Q	\N	2016-06-22 16:32:17	2016-07-07 16:33:43
12398	CITOYENNETE	2016-06-22 00:00:00	2016-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	\N	2016-06-22 16:32:26	2016-07-07 16:33:43
12399	CITOYENNETE	2016-06-22 00:00:00	2016-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	11046L	\N	2016-06-22 16:32:31	2016-07-07 16:33:43
12400	CITOYENNETE	2016-06-22 00:00:00	2016-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	\N	2016-06-22 16:32:36	2016-07-07 16:33:43
12401	CITOYENNETE	2016-06-22 00:00:00	2016-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	11094U	\N	2016-06-22 16:32:45	2016-07-07 16:33:43
12402	CITOYENNETE	2016-06-22 00:00:00	2016-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	11037K	\N	2016-06-22 16:32:52	2016-07-07 16:33:43
12403	CITOYENNETE	2016-06-22 00:00:00	2016-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	14157T	\N	2016-06-22 16:32:57	2016-07-07 16:33:43
12404	CITOYENNETE	2016-06-22 00:00:00	2016-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	\N	2016-06-22 16:33:01	2016-07-07 16:33:43
12405	CITOYENNETE	2016-06-22 00:00:00	2016-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	11066Q	\N	2016-06-22 16:33:07	2016-07-07 16:33:43
12406	CITOYENNETE	2016-06-22 00:00:00	2016-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	14269B	\N	2016-06-22 16:33:12	2016-07-07 16:33:43
12407	TELEPHONE	2016-06-22 00:00:00	2016-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11036J	\N	2016-06-22 16:42:44	2016-10-07 09:16:23
12408	TELEPHONE	2016-06-22 00:00:00	2016-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14093U	\N	2016-06-22 16:42:49	2016-10-07 09:16:23
12409	TELEPHONE	2016-06-22 00:00:00	2016-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14030Q	\N	2016-06-22 16:42:56	2016-10-07 09:16:23
12410	TELEPHONE	2016-06-22 00:00:00	2016-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01044R	\N	2016-06-22 16:43:00	2016-10-07 09:16:23
12411	TELEPHONE	2016-06-22 00:00:00	2016-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14013P	\N	2016-06-22 16:43:05	2016-10-07 09:16:23
12413	TELEPHONE	2016-06-22 00:00:00	2016-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14038Y	\N	2016-06-22 16:43:19	2016-10-07 09:16:23
12414	TELEPHONE	2016-06-22 00:00:00	2016-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80013X	\N	2016-06-22 16:43:26	2016-10-07 09:16:23
12416	TELEPHONE	2016-06-22 00:00:00	2016-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14197C	\N	2016-06-22 16:43:38	2016-10-07 09:16:23
12417	TELEPHONE	2016-06-22 00:00:00	2016-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11049P	\N	2016-06-22 16:43:44	2016-10-07 09:16:23
11559	CDD	2016-01-12 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14331P	\N	2016-01-12 09:45:37	2017-10-04 18:45:34
11673	2015CMP22	2015-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
11674	2015CMP22	2015-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	10015M	TITULAIRE	\N	\N
11675	2015CMP22	2015-10-28 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	TITULAIRE	\N	\N
11676	2015CMP22	2015-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	TITULAIRE	\N	\N
11677	2015CMP22	2015-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
11679	2015CMP22	2015-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	11056N	TITULAIRE	\N	\N
11680	2015CMP22	2015-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	14069U	SUPPLEANT	\N	\N
11681	2015CMP22	2015-10-28 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	\N	\N
11682	2015CMP22	2015-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11035H	SUPPLEANT	\N	2017-09-24 18:16:52
11683	2015CMP22	2015-10-28 00:00:00	2017-06-04 00:00:00	ANCIEN	\N	\N	\N	\N	14273W	SUPPLEANT	\N	2017-06-07 09:38:00
11684	2015CMP22	2015-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	14147R	SUPPLEANT	\N	\N
11724	2015CMP25	2015-10-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	14223L	SUPPLEANT	\N	\N
11727	2015CMP26	2015-11-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
11728	2015CMP26	2015-11-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
11730	2015CMP26	2015-11-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11084S	TITULAIRE	\N	2017-09-24 19:25:10
11736	2015CMP26	2015-11-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	08018U	SUPPLEANT	\N	\N
11737	2015CMP26	2015-11-05 00:00:00	2017-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	01007L	SUPPLEANT	\N	2017-07-24 09:56:26
11756	2015CMP28	2015-11-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	04092N	TITULAIRE	\N	\N
11757	2015CMP28	2015-11-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	01034P	TITULAIRE	\N	\N
11758	2015CMP28	2015-11-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11044J	TITULAIRE	\N	2017-09-24 17:29:37
11759	2015CMP28	2015-11-12 00:00:00	2020-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	08041T	TITULAIRE	\N	\N
11761	2015CMP28	2015-11-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	TITULAIRE	\N	\N
11762	2015CMP28	2015-11-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	11031D	TITULAIRE	\N	\N
11763	2015CMP28	2015-11-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	SUPPLEANT	\N	2017-09-24 13:44:49
11764	2015CMP28	2015-11-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	11103C	SUPPLEANT	\N	\N
11765	2015CMP28	2015-11-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11088W	SUPPLEANT	\N	2017-09-24 17:15:15
11766	2015CMP28	2015-11-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98024R	SUPPLEANT	\N	\N
11768	2015CMP28	2015-11-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11093T	SUPPLEANT	\N	2017-09-24 12:57:09
12089	BLEUE	2016-04-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14135M	TITULAIRE	2016-04-04 15:48:07	\N
12090	BLEUE	2016-04-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	14331P	TITULAIRE	2016-04-04 15:48:29	\N
12091	COMSPEAPU	2016-04-07 00:00:00	2016-05-12 00:00:00	ANCIEN	\N	\N	\N	\N	11029K	\N	2016-04-07 18:05:49	2016-05-13 09:49:49
12141	CHOMAGE	2016-04-27 00:00:00	2016-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	11081P	\N	2016-04-27 14:58:05	2017-06-12 11:08:12
12142	CHOMAGE	2016-04-27 00:00:00	2016-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	14255U	\N	2016-04-27 14:58:11	2017-06-12 11:08:12
12144	CHOMAGE	2016-04-27 00:00:00	2016-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04067M	\N	2016-04-27 14:58:22	2017-06-12 11:08:12
12145	CHOMAGE	2016-04-27 00:00:00	2016-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	01027Q	\N	2016-04-27 14:58:27	2017-06-12 11:08:12
12146	CHOMAGE	2016-04-27 00:00:00	2016-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	12042Y	\N	2016-04-27 14:58:34	2017-06-12 11:08:12
12147	CHOMAGE	2016-04-27 00:00:00	2016-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	11107G	\N	2016-04-27 14:58:40	2017-06-12 11:08:12
12148	CHOMAGE	2016-04-27 00:00:00	2016-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	11061K	\N	2016-04-27 14:58:46	2017-06-12 11:08:12
12149	CHOMAGE	2016-04-27 00:00:00	2016-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	14014Q	\N	2016-04-27 14:58:51	2017-06-12 11:08:12
12150	CHOMAGE	2016-04-27 00:00:00	2016-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	14026U	\N	2016-04-27 14:59:01	2017-06-12 11:08:12
12151	CHOMAGE	2016-04-27 00:00:00	2016-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	11112D	\N	2016-04-27 14:59:08	2017-06-12 11:08:12
12152	CHOMAGE	2016-04-27 00:00:00	2016-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	\N	2016-04-27 14:59:14	2018-02-02 10:20:31
12153	CHOMAGE	2016-04-27 00:00:00	2016-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	14037X	\N	2016-04-27 14:59:21	2017-06-12 11:08:12
12154	CHOMAGE	2016-04-27 00:00:00	2016-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	11100Y	\N	2016-04-27 14:59:28	2017-06-12 11:08:12
12155	CHOMAGE	2016-04-27 00:00:00	2016-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	14205J	\N	2016-04-27 14:59:33	2017-06-12 11:08:12
12156	CHOMAGE	2016-04-27 00:00:00	2016-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	\N	2016-04-27 14:59:38	2017-06-12 11:08:12
12157	CHOMAGE	2016-04-27 00:00:00	2016-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	14135M	\N	2016-04-27 14:59:43	2017-06-12 11:08:12
12158	CHOMAGE	2016-04-27 00:00:00	2016-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	11097X	\N	2016-04-27 14:59:48	2017-06-12 11:08:12
12159	CHOMAGE	2016-04-27 00:00:00	2016-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04045F	\N	2016-04-27 14:59:55	2017-06-12 11:08:12
12160	CHOMAGE	2016-04-27 00:00:00	2016-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	14227Q	\N	2016-04-27 15:00:01	2017-06-12 11:08:12
12161	CHOMAGE	2016-04-27 00:00:00	2016-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04050C	\N	2016-04-27 15:00:04	2017-06-12 11:08:12
12162	TURQUIE	2016-04-27 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	11076S	\N	2016-04-27 15:15:17	2017-06-12 11:08:26
12163	TURQUIE	2016-04-27 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	14133K	\N	2016-04-27 15:15:22	2017-06-12 11:08:26
12164	TURQUIE	2016-04-27 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	\N	2016-04-27 15:15:26	2017-06-12 11:08:26
12165	TURQUIE	2016-04-27 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	04054G	\N	2016-04-27 15:15:31	2017-06-12 11:08:26
12167	TURQUIE	2016-04-27 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	\N	2016-04-27 15:15:48	2017-06-12 11:08:26
12168	TURQUIE	2016-04-27 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	11027H	\N	2016-04-27 15:15:54	2017-06-12 11:08:26
12169	TURQUIE	2016-04-27 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	14079W	\N	2016-04-27 15:16:05	2017-06-12 11:08:26
12171	TURQUIE	2016-04-27 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	04035D	\N	2016-04-27 15:16:15	2017-06-12 11:08:26
12172	TURQUIE	2016-04-27 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	08041T	\N	2016-04-27 15:16:21	2017-06-12 11:08:26
12174	TURQUIE	2016-04-27 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	14073Q	\N	2016-04-27 15:16:32	2017-06-12 11:08:26
12175	TURQUIE	2016-04-27 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	95037J	\N	2016-04-27 15:16:38	2017-06-12 11:08:26
12177	TURQUIE	2016-04-27 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	11084S	\N	2016-04-27 15:16:48	2017-06-12 11:08:26
12178	TURQUIE	2016-04-27 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	11026G	\N	2016-04-27 15:16:53	2017-06-12 11:08:26
12180	TURQUIE	2016-04-27 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	14251Q	\N	2016-04-27 15:17:10	2017-06-12 11:08:26
12181	TURQUIE	2016-04-27 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	14001X	\N	2016-04-27 15:17:18	2017-06-12 11:08:26
12183	TURQUIE	2016-04-27 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	08021P	\N	2016-04-27 15:17:29	2017-06-12 11:08:26
12184	TURQUIE	2016-04-27 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	14237S	\N	2016-04-27 15:17:34	2017-06-12 11:08:26
12185	TURQUIE	2016-04-27 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	04080J	\N	2016-04-27 15:17:40	2017-06-12 11:08:26
12187	TURQUIE	2016-04-27 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	08049C	\N	2016-04-27 15:17:50	2017-06-12 11:08:26
12188	TURQUIE	2016-04-27 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	\N	2016-04-27 15:17:55	2017-06-12 11:08:26
12288	BIODIVERSITE	2016-05-18 00:00:00	2016-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	08009T	TITULAIRE	2016-05-18 08:53:38	2016-06-08 17:34:23
12289	BIODIVERSITE	2016-05-18 00:00:00	2016-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	14093U	TITULAIRE	2016-05-18 08:53:52	2016-06-08 17:34:23
12290	BIODIVERSITE	2016-05-18 00:00:00	2016-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	11090Q	TITULAIRE	2016-05-18 08:53:58	2016-06-08 17:34:23
12291	BIODIVERSITE	2016-05-18 00:00:00	2016-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	05012A	TITULAIRE	2016-05-18 08:54:07	2016-06-08 17:34:23
12292	BIODIVERSITE	2016-05-18 00:00:00	2016-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	08060W	TITULAIRE	2016-05-18 08:54:13	2016-06-08 17:34:23
12293	BIODIVERSITE	2016-05-18 00:00:00	2016-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	11107G	TITULAIRE	2016-05-18 08:54:18	2016-06-08 17:34:23
12294	BIODIVERSITE	2016-05-18 00:00:00	2016-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	01015L	TITULAIRE	2016-05-18 08:54:25	2016-06-08 17:34:23
12295	BIODIVERSITE	2016-05-18 00:00:00	2016-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	08055A	SUPPLEANT	2016-05-18 08:54:40	2016-06-08 17:34:23
12296	BIODIVERSITE	2016-05-18 00:00:00	2016-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	14038Y	SUPPLEANT	2016-05-18 08:54:46	2016-06-08 17:34:23
12297	BIODIVERSITE	2016-05-18 00:00:00	2016-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	11065P	SUPPLEANT	2016-05-18 08:54:56	2016-06-08 17:34:23
12298	BIODIVERSITE	2016-05-18 00:00:00	2016-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	14033T	SUPPLEANT	2016-05-18 08:55:01	2016-06-08 17:34:23
12299	BIODIVERSITE	2016-05-18 00:00:00	2016-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	09001P	SUPPLEANT	2016-05-18 08:55:07	2016-06-08 17:34:23
12300	BIODIVERSITE	2016-05-18 00:00:00	2016-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	80027E	SUPPLEANT	2016-05-18 08:55:14	2016-06-08 17:34:23
12301	BIODIVERSITE	2016-05-18 00:00:00	2016-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	95062K	SUPPLEANT	2016-05-18 08:55:19	2016-06-08 17:34:23
12419	TELEPHONE	2016-06-22 00:00:00	2016-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14031R	\N	2016-06-22 16:43:56	2016-10-07 09:16:23
12420	TELEPHONE	2016-06-22 00:00:00	2016-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14273W	\N	2016-06-22 16:44:02	2016-10-07 09:16:23
12421	TELEPHONE	2016-06-22 00:00:00	2016-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14221J	\N	2016-06-22 16:44:14	2016-10-07 09:16:23
12422	TELEPHONE	2016-06-22 00:00:00	2016-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04057K	\N	2016-06-22 16:44:20	2016-10-07 09:16:23
11509	2015CMP13	2015-06-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	04092N	TITULAIRE	\N	\N
11510	2015CMP13	2015-06-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	04043D	TITULAIRE	\N	\N
11512	2015CMP13	2015-06-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14034U	TITULAIRE	\N	\N
11513	2015CMP13	2015-06-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	12042Y	TITULAIRE	\N	2017-09-24 19:31:54
11514	2015CMP13	2015-06-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	04045F	TITULAIRE	\N	\N
11515	2015CMP13	2015-06-25 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	11063M	TITULAIRE	\N	\N
11516	2015CMP13	2015-06-25 00:00:00	2017-08-06 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	SUPPLEANT	\N	2017-08-07 16:31:39
11517	2015CMP13	2015-06-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	14255U	SUPPLEANT	\N	\N
11520	2015CMP13	2015-06-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	SUPPLEANT	\N	\N
11522	2015CMP13	2015-06-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	14026U	SUPPLEANT	\N	\N
11548	COMSPEAPU	2015-12-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01013J	\N	2015-12-16 17:19:49	2017-09-24 17:06:55
11550	COMSPEAPU	2015-12-16 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	11080N	\N	2015-12-16 17:20:05	\N
11552	COMSPEAPU	2015-12-16 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	01057W	\N	2015-12-16 17:20:18	\N
11553	COMSPEAPU	2015-12-16 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14159V	\N	2015-12-16 17:20:25	2017-10-04 20:36:44
11554	COMSPEAPU	2015-12-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92039X	\N	2015-12-16 17:20:34	2017-09-24 13:47:46
11555	COMSPEAPU	2015-12-16 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	11069T	\N	2015-12-16 17:20:41	2016-03-11 18:02:50
11556	COMSPEAPU	2015-12-16 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14225N	\N	2015-12-16 17:20:48	2017-10-04 20:37:03
11557	COMSPEAPU	2015-12-16 00:00:00	2017-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	11012A	\N	2015-12-16 17:20:57	2017-07-06 15:47:50
11558	COMSPEAPU	2015-12-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14157T	\N	2015-12-16 17:21:04	\N
11632	2015CMP19	2015-09-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	04057K	TITULAIRE	\N	\N
11633	2015CMP19	2015-09-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	04059M	TITULAIRE	\N	\N
11634	2015CMP19	2015-09-08 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	14263U	TITULAIRE	\N	2017-06-19 16:04:13
11656	2015CMP20	2015-09-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	SUPPLEANT	\N	\N
11645	2015CMP20	2015-09-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
11770	2015CMP29	2015-11-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
11771	2015CMP29	2015-11-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08025T	TITULAIRE	\N	2017-10-01 10:17:18
11772	2015CMP29	2015-11-05 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	TITULAIRE	\N	\N
11773	2015CMP29	2015-11-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04074L	TITULAIRE	\N	2017-09-24 17:15:15
11775	2015CMP29	2015-11-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	11074Q	TITULAIRE	\N	\N
11776	2015CMP29	2015-11-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	04085P	TITULAIRE	\N	\N
11777	2015CMP29	2015-11-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14065Q	SUPPLEANT	\N	\N
11781	2015CMP29	2015-11-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	08018U	SUPPLEANT	\N	\N
11783	2015CMP29	2015-11-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	11026G	SUPPLEANT	\N	\N
11785	2015CMP30	2015-11-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	04092N	TITULAIRE	\N	\N
11786	2015CMP30	2015-11-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11093T	TITULAIRE	\N	2017-09-24 12:57:09
11788	2015CMP30	2015-11-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	14033T	TITULAIRE	\N	\N
11795	2015CMP30	2015-11-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	11103C	SUPPLEANT	\N	\N
11790	2015CMP30	2015-11-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	14071N	TITULAIRE	\N	\N
11792	2015CMP30	2015-11-24 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	11063M	TITULAIRE	\N	\N
11794	2015CMP30	2015-11-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	14053L	SUPPLEANT	\N	\N
11796	2015CMP30	2015-11-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	14215L	SUPPLEANT	\N	\N
11798	2015CMP30	2015-11-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	01034P	SUPPLEANT	\N	\N
11799	2015CMP30	2015-11-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14269B	SUPPLEANT	\N	2017-09-24 18:07:57
11800	2015CMP31	2015-11-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	TITULAIRE	\N	2017-09-24 18:20:10
11801	2015CMP31	2015-11-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	08011M	TITULAIRE	\N	\N
11804	2015CMP31	2015-11-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	11070L	TITULAIRE	\N	\N
11805	2015CMP31	2015-11-19 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	TITULAIRE	\N	\N
11813	2015CMP31	2015-11-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11088W	SUPPLEANT	\N	2017-09-24 17:15:15
11807	2015CMP31	2015-11-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	11053K	SUPPLEANT	\N	\N
11808	2015CMP31	2015-11-19 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	TITULAIRE	\N	\N
11809	2015CMP31	2015-11-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	01057W	TITULAIRE	\N	\N
11810	2015CMP31	2015-11-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	11040E	TITULAIRE	\N	\N
11815	2015CMP31	2015-11-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11057P	SUPPLEANT	\N	2017-09-24 18:23:22
11817	2015CMP32	2015-12-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	08011M	TITULAIRE	\N	\N
11818	2015CMP32	2015-12-09 00:00:00	2017-06-01 00:00:00	ANCIEN	\N	\N	\N	\N	14175V	TITULAIRE	\N	2017-06-02 10:02:56
11819	2015CMP32	2015-12-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	04071H	TITULAIRE	\N	\N
11820	2015CMP32	2015-12-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	11070L	TITULAIRE	\N	\N
11821	2015CMP32	2015-12-09 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	TITULAIRE	\N	\N
11822	2015CMP32	2015-12-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01013J	TITULAIRE	\N	2017-09-24 17:06:55
11823	2015CMP32	2015-12-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	11053K	SUPPLEANT	\N	\N
12302	REPUBLIQUE	2016-06-01 00:00:00	2016-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	TITULAIRE	2016-06-02 11:04:30	2016-06-30 15:32:20
12303	REPUBLIQUE	2016-06-01 00:00:00	2016-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	08018U	TITULAIRE	2016-06-02 11:04:35	2016-06-30 15:32:20
12304	REPUBLIQUE	2016-06-01 00:00:00	2016-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	TITULAIRE	2016-06-02 11:04:44	2016-06-30 15:32:20
12305	REPUBLIQUE	2016-06-01 00:00:00	2016-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	04070G	TITULAIRE	2016-06-02 11:04:49	2016-06-30 15:32:20
12306	REPUBLIQUE	2016-06-01 00:00:00	2016-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	TITULAIRE	2016-06-02 11:04:55	2016-06-30 15:32:20
12307	REPUBLIQUE	2016-06-01 00:00:00	2016-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	11046L	TITULAIRE	2016-06-02 11:05:00	2016-06-30 15:32:20
12308	REPUBLIQUE	2016-06-01 00:00:00	2016-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	14013P	TITULAIRE	2016-06-02 11:05:06	2016-06-30 15:32:20
12309	REPUBLIQUE	2016-06-01 00:00:00	2016-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	11095V	SUPPLEANT	2016-06-02 11:05:11	2016-06-30 15:32:20
12310	REPUBLIQUE	2016-06-01 00:00:00	2016-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	14038Y	SUPPLEANT	2016-06-02 11:05:16	2016-06-30 15:32:20
12311	REPUBLIQUE	2016-06-01 00:00:00	2016-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	11089X	SUPPLEANT	2016-06-02 11:05:21	2016-06-30 15:32:20
12312	REPUBLIQUE	2016-06-01 00:00:00	2016-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	08009T	SUPPLEANT	2016-06-02 11:05:26	2016-06-30 15:32:20
12313	REPUBLIQUE	2016-06-01 00:00:00	2016-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	04057K	SUPPLEANT	2016-06-02 11:05:34	2016-06-30 15:32:20
12314	REPUBLIQUE	2016-06-01 00:00:00	2016-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	11012A	SUPPLEANT	2016-06-02 11:05:41	2016-06-30 15:32:20
12315	REPUBLIQUE	2016-06-01 00:00:00	2016-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	01058X	SUPPLEANT	2016-06-02 11:05:46	2016-06-30 15:32:20
12423	TELEPHONE	2016-06-22 00:00:00	2016-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92039X	\N	2016-06-22 16:44:27	2016-10-07 09:16:23
12424	TELEPHONE	2016-06-22 00:00:00	2016-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14265W	\N	2016-06-22 16:44:33	2016-10-07 09:16:23
12425	TELEPHONE	2016-06-22 00:00:00	2016-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14237S	\N	2016-06-22 16:44:38	2016-10-07 09:16:23
12426	TELEPHONE	2016-06-22 00:00:00	2016-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	05012A	\N	2016-06-22 16:44:44	2016-10-07 09:16:24
12427	TELEPHONE	2016-06-22 00:00:00	2016-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04043D	\N	2016-06-22 16:44:49	2016-10-07 09:16:24
12428	TELEPHONE	2016-06-22 00:00:00	2016-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	\N	2016-06-22 16:44:55	2016-10-07 09:16:24
12429	TELEPHONE	2016-06-22 00:00:00	2016-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14107H	\N	2016-06-22 16:44:59	2016-10-07 09:16:24
12430	TELEPHONE	2016-06-22 00:00:00	2016-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14051J	\N	2016-06-22 16:45:07	2016-10-07 09:16:24
12432	TELEPHONE	2016-06-22 00:00:00	2016-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08049C	\N	2016-06-22 16:45:33	2016-10-07 09:16:24
12433	TRAVAIL	2016-06-23 00:00:00	2016-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	TITULAIRE	2016-06-24 20:15:08	2016-06-30 15:31:51
12434	TRAVAIL	2016-06-23 00:00:00	2016-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	14037X	TITULAIRE	2016-06-24 20:15:15	2016-06-30 15:31:51
12435	TRAVAIL	2016-06-23 00:00:00	2016-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	14087W	TITULAIRE	2016-06-24 20:15:21	2016-06-30 15:31:51
12436	TRAVAIL	2016-06-23 00:00:00	2016-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	14034U	TITULAIRE	2016-06-24 20:15:26	2016-06-30 15:31:51
12437	TRAVAIL	2016-06-23 00:00:00	2016-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	TITULAIRE	2016-06-24 20:15:32	2016-06-30 15:31:51
12438	TRAVAIL	2016-06-23 00:00:00	2016-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	TITULAIRE	2016-06-24 20:15:38	2016-06-30 15:31:51
12439	TRAVAIL	2016-06-23 00:00:00	2016-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	11063M	TITULAIRE	2016-06-24 20:15:45	2016-06-30 15:31:51
12440	TRAVAIL	2016-06-23 00:00:00	2016-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	14239U	SUPPLEANT	2016-06-24 20:15:49	2016-06-30 15:31:51
12441	TRAVAIL	2016-06-23 00:00:00	2016-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	14255U	SUPPLEANT	2016-06-24 20:15:53	2016-06-30 15:31:51
12442	TRAVAIL	2016-06-23 00:00:00	2016-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	10006L	SUPPLEANT	2016-06-24 20:15:58	2016-06-30 15:31:51
12443	TRAVAIL	2016-06-23 00:00:00	2016-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	12042Y	SUPPLEANT	2016-06-24 20:16:03	2016-06-30 15:31:51
12444	TRAVAIL	2016-06-23 00:00:00	2016-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	11061K	SUPPLEANT	2016-06-24 20:16:07	2016-06-30 15:31:51
12445	TRAVAIL	2016-06-23 00:00:00	2016-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	14026U	SUPPLEANT	2016-06-24 20:16:14	2016-06-30 15:31:51
10592	CROISSANCE	2015-01-15 00:00:00	2015-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	14135M	\N	2015-01-09 11:42:20	2015-10-07 10:43:00
10764	CROISSANCE	2015-01-15 00:00:00	2015-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	14034U	\N	2015-01-13 19:15:00	2015-10-07 10:43:00
10767	CROISSANCE	2015-01-15 00:00:00	2015-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	14001X	\N	2015-01-13 19:15:41	2015-10-07 10:43:00
10772	CROISSANCE	2015-01-15 00:00:00	2015-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	\N	2015-01-13 19:16:52	2015-10-07 10:43:00
14497	ENTREPRISES	2018-10-10 00:00:00	2019-05-23 00:00:00	ANCIEN	\N	\N	\N	\N	14199E	\N	\N	\N
10775	CROISSANCE	2015-01-15 00:00:00	2015-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	11066Q	\N	2015-01-13 19:17:17	2015-10-07 10:43:00
10863	EDUCATION	2015-01-27 00:00:00	2015-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	11091R	\N	2015-01-27 16:37:39	2015-10-07 10:46:07
10866	EDUCATION	2015-01-27 00:00:00	2015-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	14121F	\N	2015-01-27 16:38:06	2015-10-07 10:46:07
10870	EDUCATION	2015-01-27 00:00:00	2015-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	08031R	\N	2015-01-27 16:38:48	2015-10-07 10:46:07
10873	EDUCATION	2015-01-27 00:00:00	2015-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	11104D	\N	2015-01-27 16:39:15	2015-10-07 10:46:07
10876	EDUCATION	2015-01-27 00:00:00	2015-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	14028W	\N	2015-01-27 16:39:50	2015-10-07 10:46:07
10289	DJIHAD	2014-10-14 00:00:00	2015-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	14087W	\N	2014-10-14 17:41:11	2015-10-07 10:48:17
10293	DJIHAD	2014-10-14 00:00:00	2015-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	95035G	\N	2014-10-14 17:41:58	2015-10-07 10:48:17
10296	DJIHAD	2014-10-14 00:00:00	2015-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	04077P	\N	2014-10-14 17:42:26	2015-10-07 10:48:17
10299	DJIHAD	2014-10-14 00:00:00	2015-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	11106F	\N	2014-10-14 17:42:55	2015-10-07 10:48:17
10302	DJIHAD	2014-10-14 00:00:00	2015-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	10015M	\N	2014-10-14 17:43:29	2015-10-07 10:48:17
11518	2015CMP13	2015-06-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	14053L	SUPPLEANT	\N	\N
11519	2015CMP13	2015-06-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	11103C	SUPPLEANT	\N	\N
11521	2015CMP13	2015-06-25 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	SUPPLEANT	\N	2017-05-16 15:18:13
11523	ISLAM	2015-12-16 00:00:00	2016-07-10 00:00:00	ANCIEN	\N	\N	\N	\N	07004J	\N	2015-12-16 11:11:46	2016-10-07 09:16:01
11524	ISLAM	2015-12-16 00:00:00	2016-07-10 00:00:00	ANCIEN	\N	\N	\N	\N	14089Y	\N	2015-12-16 11:12:25	2016-10-07 09:16:01
11525	ISLAM	2015-12-16 00:00:00	2016-07-10 00:00:00	ANCIEN	\N	\N	\N	\N	11082Q	\N	2015-12-16 11:12:42	2016-10-07 09:16:01
11526	ISLAM	2015-12-16 00:00:00	2016-07-10 00:00:00	ANCIEN	\N	\N	\N	\N	14239U	\N	2015-12-16 11:12:53	2016-10-07 09:16:01
11527	ISLAM	2015-12-16 00:00:00	2016-07-10 00:00:00	ANCIEN	\N	\N	\N	\N	14133K	\N	2015-12-16 11:13:05	2016-10-07 09:16:01
11528	ISLAM	2015-12-16 00:00:00	2016-07-10 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	\N	2015-12-16 11:13:46	2016-10-07 09:16:01
11529	ISLAM	2015-12-16 00:00:00	2016-07-10 00:00:00	ANCIEN	\N	\N	\N	\N	14217N	\N	2015-12-16 11:13:54	2016-10-07 09:16:01
11530	ISLAM	2015-12-16 00:00:00	2016-07-10 00:00:00	ANCIEN	\N	\N	\N	\N	08041T	\N	2015-12-16 11:14:05	2016-10-07 09:16:01
11531	ISLAM	2015-12-16 00:00:00	2016-07-10 00:00:00	ANCIEN	\N	\N	\N	\N	11049P	\N	2015-12-16 11:14:13	2016-10-07 09:16:01
11532	ISLAM	2015-12-16 00:00:00	2016-07-10 00:00:00	ANCIEN	\N	\N	\N	\N	14123H	\N	2015-12-16 11:14:30	2016-10-07 09:16:01
11533	ISLAM	2015-12-16 00:00:00	2016-07-10 00:00:00	ANCIEN	\N	\N	\N	\N	99004R	\N	2015-12-16 11:14:41	2016-10-07 09:16:01
11534	ISLAM	2015-12-16 00:00:00	2016-07-10 00:00:00	ANCIEN	\N	\N	\N	\N	04061F	\N	2015-12-16 11:14:48	2016-10-07 09:16:01
11535	ISLAM	2015-12-16 00:00:00	2016-07-10 00:00:00	ANCIEN	\N	\N	\N	\N	14193X	\N	2015-12-16 11:15:07	2016-10-07 09:16:01
11536	ISLAM	2015-12-16 00:00:00	2016-07-10 00:00:00	ANCIEN	\N	\N	\N	\N	14065Q	\N	2015-12-16 11:15:48	2016-10-07 09:16:01
11537	ISLAM	2015-12-16 00:00:00	2016-07-10 00:00:00	ANCIEN	\N	\N	\N	\N	10015M	\N	2015-12-16 11:16:02	2016-10-07 09:16:01
11538	ISLAM	2015-12-16 00:00:00	2016-07-10 00:00:00	ANCIEN	\N	\N	\N	\N	98029W	\N	2015-12-16 11:16:12	2016-10-07 09:16:01
11539	ISLAM	2015-12-16 00:00:00	2016-07-10 00:00:00	ANCIEN	\N	\N	\N	\N	92020L	\N	2015-12-16 11:16:19	2016-10-07 09:16:01
11540	ISLAM	2015-12-16 00:00:00	2016-07-10 00:00:00	ANCIEN	\N	\N	\N	\N	14281W	\N	2015-12-16 11:16:30	2016-10-07 09:16:01
11541	ISLAM	2015-12-16 00:00:00	2016-07-10 00:00:00	ANCIEN	\N	\N	\N	\N	08053X	\N	2015-12-16 11:16:39	2016-10-07 09:16:01
11542	ISLAM	2015-12-16 00:00:00	2016-07-10 00:00:00	ANCIEN	\N	\N	\N	\N	11054L	\N	2015-12-16 11:16:46	2016-10-07 09:16:01
11543	ISLAM	2015-12-16 00:00:00	2016-07-10 00:00:00	ANCIEN	\N	\N	\N	\N	11037K	\N	2015-12-16 11:16:53	2016-10-07 09:16:01
11544	ISLAM	2015-12-16 00:00:00	2016-07-10 00:00:00	ANCIEN	\N	\N	\N	\N	14269B	\N	2015-12-16 11:17:01	2016-10-07 09:16:01
11545	ISLAM	2015-12-16 00:00:00	2016-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	11033F	\N	2015-12-16 11:17:10	2016-01-26 16:42:52
11699	2015CMP23	2015-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	05012A	SUPPLEANT	\N	\N
11640	2015CMP19	2015-09-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14079W	SUPPLEANT	\N	\N
11659	2015CMP21	2015-10-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	04092N	TITULAIRE	\N	\N
11660	2015CMP21	2015-10-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	10006L	TITULAIRE	\N	\N
11661	2015CMP21	2015-10-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	10015M	TITULAIRE	\N	\N
11662	2015CMP21	2015-10-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	14042U	TITULAIRE	\N	\N
11663	2015CMP21	2015-10-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	TITULAIRE	\N	\N
11665	2015CMP21	2015-10-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	11031D	TITULAIRE	\N	\N
11668	2015CMP21	2015-10-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	14213J	SUPPLEANT	\N	\N
11669	2015CMP21	2015-10-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	14071N	SUPPLEANT	\N	\N
11670	2015CMP21	2015-10-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	04043D	SUPPLEANT	\N	\N
11672	2015CMP21	2015-10-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11093T	SUPPLEANT	\N	2017-09-24 12:57:09
11707	2015CMP24	2015-11-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14261S	SUPPLEANT	\N	\N
11708	2015CMP24	2015-11-05 00:00:00	2018-12-30 00:00:00	ANCIEN	\N	\N	\N	\N	98023Q	SUPPLEANT	\N	\N
11713	2015CMP25	2015-10-15 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	TITULAIRE	\N	\N
11714	2015CMP25	2015-10-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	11067R	TITULAIRE	\N	\N
11715	2015CMP25	2015-10-15 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	TITULAIRE	\N	\N
11716	2015CMP25	2015-10-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	14259Y	TITULAIRE	\N	\N
11717	2015CMP25	2015-10-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	14030Q	TITULAIRE	\N	\N
11719	2015CMP25	2015-10-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	11031D	TITULAIRE	\N	\N
11720	2015CMP25	2015-10-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	97011G	SUPPLEANT	\N	\N
11729	2015CMP26	2015-11-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14061L	TITULAIRE	\N	\N
11741	2015CMP27	2015-11-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
11742	2015CMP27	2015-11-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04074L	TITULAIRE	\N	2017-09-24 17:15:15
11744	2015CMP27	2015-11-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95049N	TITULAIRE	\N	2017-10-01 10:42:05
11745	2015CMP27	2015-11-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
11746	2015CMP27	2015-11-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	11072N	TITULAIRE	\N	\N
11747	2015CMP27	2015-11-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	04085P	TITULAIRE	\N	\N
11748	2015CMP27	2015-11-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08025T	SUPPLEANT	\N	2017-10-01 10:17:18
11750	2015CMP27	2015-11-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	04047H	SUPPLEANT	\N	\N
12008	ELECTION	2016-03-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	05008E	TITULAIRE	2016-03-11 10:36:49	2016-03-11 10:40:08
11752	2015CMP27	2015-11-05 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	SUPPLEANT	\N	\N
11753	2015CMP27	2015-11-05 00:00:00	2017-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	01007L	SUPPLEANT	\N	2017-07-24 09:56:26
11778	2015CMP29	2015-11-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	14069U	SUPPLEANT	\N	\N
11784	2015CMP29	2015-11-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	\N	\N
11793	2015CMP30	2015-11-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	SUPPLEANT	\N	2017-09-24 13:44:49
11812	2015CMP31	2015-11-19 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	88008L	SUPPLEANT	\N	\N
11814	2015CMP31	2015-11-19 00:00:00	2020-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	14199E	SUPPLEANT	\N	\N
11825	2015CMP32	2015-12-09 00:00:00	2020-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	14199E	SUPPLEANT	\N	\N
11826	2015CMP32	2015-12-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	07029T	SUPPLEANT	\N	\N
11827	2015CMP32	2015-12-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	SUPPLEANT	\N	2017-09-24 17:09:24
11828	2015CMP32	2015-12-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	11012A	SUPPLEANT	\N	\N
11829	2015CMP32	2015-12-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11057P	SUPPLEANT	\N	2017-09-24 18:23:22
12009	ELECTION	2016-03-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11030C	TITULAIRE	2016-03-11 10:37:00	2017-09-24 17:09:24
12010	ELECTION	2016-03-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04074L	TITULAIRE	2016-03-11 10:37:12	2017-09-24 17:15:15
12011	ELECTION	2016-03-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	04070G	TITULAIRE	2016-03-11 10:37:20	2016-03-11 10:40:59
12012	ELECTION	2016-03-02 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08025T	TITULAIRE	2016-03-11 10:37:26	2017-10-01 10:17:18
12013	ELECTION	2016-03-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	TITULAIRE	2016-03-11 10:37:36	2016-03-11 10:41:42
12014	ELECTION	2016-03-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	11056N	TITULAIRE	2016-03-11 10:37:53	2016-03-11 10:41:57
12015	ELECTION	2016-03-02 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	2016-03-11 10:38:02	2016-03-11 10:42:18
12017	ELECTION	2016-03-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	14215L	SUPPLEANT	2016-03-11 10:38:19	2016-03-11 10:42:51
11560	2015CMP14	2015-06-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	TITULAIRE	\N	\N
11561	2015CMP14	2015-06-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	TITULAIRE	\N	2017-09-24 13:29:42
11562	2015CMP14	2015-06-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14215L	TITULAIRE	\N	\N
11564	2015CMP14	2015-06-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
11565	2015CMP14	2015-06-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11084S	TITULAIRE	\N	2017-09-24 19:25:10
11566	2015CMP14	2015-06-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	11056N	TITULAIRE	\N	\N
11567	2015CMP14	2015-06-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14069U	SUPPLEANT	\N	\N
11568	2015CMP14	2015-06-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	04047H	SUPPLEANT	\N	\N
11569	2015CMP14	2015-06-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	\N	\N
11571	2015CMP14	2015-06-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04079R	SUPPLEANT	\N	2017-09-24 17:47:27
11574	2015CMP15	2015-07-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
11576	2015CMP15	2015-07-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	TITULAIRE	\N	\N
11578	2015CMP15	2015-07-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11084S	TITULAIRE	\N	2017-09-24 19:25:10
11579	2015CMP15	2015-07-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11034G	TITULAIRE	\N	2017-09-24 17:55:12
11581	2015CMP15	2015-07-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	14069U	SUPPLEANT	\N	\N
11582	2015CMP15	2015-07-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	14259Y	SUPPLEANT	\N	\N
11585	2015CMP15	2015-07-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	95063L	SUPPLEANT	\N	\N
11586	2015CMP15	2015-07-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	SUPPLEANT	\N	\N
11590	2015CMP16	2015-07-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04055H	TITULAIRE	\N	2017-09-24 18:05:41
11591	2015CMP16	2015-07-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	11070L	TITULAIRE	\N	\N
11602	2015CMP17	2015-07-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	08034U	TITULAIRE	\N	\N
11603	2015CMP17	2015-07-08 00:00:00	2016-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	07024N	TITULAIRE	\N	2017-01-03 11:09:24
11604	2015CMP17	2015-07-08 00:00:00	2017-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	95059Q	TITULAIRE	\N	2017-10-05 09:39:10
11606	2015CMP17	2015-07-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01014K	TITULAIRE	\N	2017-09-24 17:19:42
11611	2015CMP17	2015-07-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	07004J	SUPPLEANT	\N	\N
11612	2015CMP17	2015-07-08 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98021N	SUPPLEANT	\N	2017-10-01 09:22:38
11618	2015CMP18	2015-07-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11093T	TITULAIRE	\N	2017-09-24 12:57:09
11621	2015CMP18	2015-07-08 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	11063M	TITULAIRE	\N	\N
11622	2015CMP18	2015-07-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	14267Y	SUPPLEANT	\N	\N
11623	2015CMP18	2015-07-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	14217N	SUPPLEANT	\N	\N
11628	2015CMP18	2015-07-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	04043D	SUPPLEANT	\N	\N
11743	2015CMP27	2015-11-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	14069U	TITULAIRE	\N	\N
11754	2015CMP27	2015-11-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	\N	\N
11760	2015CMP28	2015-11-12 00:00:00	2017-08-06 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	TITULAIRE	\N	2017-08-07 16:31:39
11769	2015CMP28	2015-11-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14227Q	SUPPLEANT	\N	\N
12018	ELECTION	2016-03-02 00:00:00	2020-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	08044W	SUPPLEANT	2016-03-11 10:38:36	2016-03-11 10:43:07
12019	ELECTION	2016-03-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	11026G	SUPPLEANT	2016-03-11 10:38:47	2016-03-11 10:43:23
12020	ELECTION	2016-03-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04056J	SUPPLEANT	2016-03-11 10:39:02	2017-09-24 18:17:56
12021	ELECTION	2016-03-02 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	2016-03-11 10:39:13	2016-03-11 10:43:58
12206	CRIME	2016-04-27 00:00:00	2016-05-12 00:00:00	ANCIEN	\N	\N	\N	\N	95049N	TITULAIRE	2016-05-06 10:20:55	2016-05-12 13:47:41
12207	CRIME	2016-04-27 00:00:00	2016-05-12 00:00:00	ANCIEN	\N	\N	\N	\N	08011M	TITULAIRE	2016-05-06 10:21:02	2016-05-12 13:47:41
12205	CRIME	2016-04-27 00:00:00	2016-05-12 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	2016-05-06 10:20:50	2016-05-12 13:47:41
12208	CRIME	2016-04-27 00:00:00	2016-05-12 00:00:00	ANCIEN	\N	\N	\N	\N	08047A	TITULAIRE	2016-05-06 10:21:23	2016-05-12 13:47:41
12209	CRIME	2016-04-27 00:00:00	2016-05-12 00:00:00	ANCIEN	\N	\N	\N	\N	14065Q	TITULAIRE	2016-05-06 10:21:32	2016-05-12 13:47:41
12210	CRIME	2016-04-27 00:00:00	2016-05-12 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	TITULAIRE	2016-05-06 10:21:39	2016-05-12 13:47:41
12211	CRIME	2016-04-27 00:00:00	2016-05-12 00:00:00	ANCIEN	\N	\N	\N	\N	11056N	TITULAIRE	2016-05-06 10:21:44	2016-05-12 13:47:41
12212	CRIME	2016-04-27 00:00:00	2016-05-12 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	SUPPLEANT	2016-05-06 10:21:50	2016-05-12 13:47:41
12213	CRIME	2016-04-27 00:00:00	2016-05-12 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	SUPPLEANT	2016-05-06 10:22:04	2016-05-12 13:47:41
12214	CRIME	2016-04-27 00:00:00	2016-05-12 00:00:00	ANCIEN	\N	\N	\N	\N	10015M	SUPPLEANT	2016-05-06 10:22:13	2016-05-12 13:47:41
12215	CRIME	2016-04-27 00:00:00	2016-05-12 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	SUPPLEANT	2016-05-06 10:22:21	2016-05-12 13:47:41
12216	CRIME	2016-04-27 00:00:00	2016-05-12 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	2016-05-06 10:22:31	2016-05-12 13:47:41
12217	CRIME	2016-04-27 00:00:00	2016-05-12 00:00:00	ANCIEN	\N	\N	\N	\N	11037K	SUPPLEANT	2016-05-06 10:22:39	2016-05-12 13:47:41
12218	CRIME	2016-04-27 00:00:00	2016-05-12 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	SUPPLEANT	2016-05-06 10:22:47	2016-05-12 13:47:41
12261	REVENU	2016-05-18 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	14239U	\N	2016-05-17 17:42:57	2017-06-12 11:07:55
12262	REVENU	2016-05-18 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	11095V	\N	2016-05-17 17:43:04	2017-06-12 11:07:55
12263	REVENU	2016-05-18 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	14195A	\N	2016-05-17 17:43:10	2017-06-12 11:07:55
12264	REVENU	2016-05-18 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	14079W	\N	2016-05-17 17:43:16	2017-06-12 11:07:55
12265	REVENU	2016-05-18 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	04055H	\N	2016-05-17 17:43:22	2017-06-12 11:07:55
12266	REVENU	2016-05-18 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	\N	2016-05-17 17:43:29	2017-06-12 11:07:55
12267	REVENU	2016-05-18 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	04067M	\N	2016-05-17 17:43:35	2017-06-12 11:07:55
12268	REVENU	2016-05-18 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	14217N	\N	2016-05-17 17:43:41	2017-06-12 11:07:55
12269	REVENU	2016-05-18 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	14042U	\N	2016-05-17 17:43:48	2017-06-12 11:07:55
12270	REVENU	2016-05-18 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	14249W	\N	2016-05-17 17:43:54	2017-06-12 11:07:55
12271	REVENU	2016-05-18 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	11110B	\N	2016-05-17 17:44:00	2017-06-12 11:07:55
12272	REVENU	2016-05-18 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	14211G	\N	2016-05-17 17:44:06	2017-06-12 11:07:55
12273	REVENU	2016-05-18 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	\N	2016-05-17 17:44:13	2018-01-25 13:10:11
12274	REVENU	2016-05-18 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	14121F	\N	2016-05-17 17:44:20	2017-06-12 11:07:55
12275	REVENU	2016-05-18 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	08034U	\N	2016-05-17 17:44:27	2017-06-12 11:07:55
12276	REVENU	2016-05-18 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	14037X	\N	2016-05-17 17:44:34	2017-06-12 11:07:55
12277	REVENU	2016-05-18 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	11077T	\N	2016-05-17 17:44:40	2017-06-12 11:07:55
12278	REVENU	2016-05-18 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	14205J	\N	2016-05-17 17:44:45	2017-06-12 11:07:55
12279	REVENU	2016-05-18 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	14265W	\N	2016-05-17 17:44:52	2017-06-12 11:07:55
12280	REVENU	2016-05-18 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	08021P	\N	2016-05-17 17:44:59	2017-06-12 11:07:55
12281	REVENU	2016-05-18 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	83047W	\N	2016-05-17 17:45:06	2017-06-12 11:07:55
12282	REVENU	2016-05-18 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	14235Q	\N	2016-05-17 17:45:12	2017-06-12 11:07:55
12284	REVENU	2016-05-18 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	04045F	\N	2016-05-17 17:45:24	2017-06-12 11:07:55
12285	REVENU	2016-05-18 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	01034P	\N	2016-05-17 17:45:31	2017-06-12 11:07:55
12287	REVENU	2016-05-18 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	11066Q	\N	2016-05-17 17:45:46	2017-06-12 11:07:55
12343	JUSTICE	2016-06-15 00:00:00	2016-06-22 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	2016-06-15 15:17:06	2016-06-24 20:12:48
12344	JUSTICE	2016-06-15 00:00:00	2016-06-22 00:00:00	ANCIEN	\N	\N	\N	\N	01024M	TITULAIRE	2016-06-15 15:17:18	2016-06-24 20:12:48
12345	JUSTICE	2016-06-15 00:00:00	2016-06-22 00:00:00	ANCIEN	\N	\N	\N	\N	07034Q	TITULAIRE	2016-06-15 15:17:26	2016-06-24 20:12:48
12346	JUSTICE	2016-06-15 00:00:00	2016-06-22 00:00:00	ANCIEN	\N	\N	\N	\N	10015M	TITULAIRE	2016-06-15 15:17:34	2016-06-24 20:12:48
12347	JUSTICE	2016-06-15 00:00:00	2016-06-22 00:00:00	ANCIEN	\N	\N	\N	\N	14065Q	TITULAIRE	2016-06-15 15:17:42	2016-06-24 20:12:48
12348	JUSTICE	2016-06-15 00:00:00	2016-06-22 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	TITULAIRE	2016-06-15 15:17:50	2016-06-24 20:12:48
12349	JUSTICE	2016-06-15 00:00:00	2016-06-22 00:00:00	ANCIEN	\N	\N	\N	\N	11056N	TITULAIRE	2016-06-15 15:17:59	2016-06-24 20:12:48
12350	JUSTICE	2016-06-15 00:00:00	2016-06-22 00:00:00	ANCIEN	\N	\N	\N	\N	08018U	SUPPLEANT	2016-06-15 15:18:05	2016-06-24 20:12:48
12351	JUSTICE	2016-06-15 00:00:00	2016-06-22 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	SUPPLEANT	2016-06-15 15:18:17	2016-06-24 20:12:48
12352	JUSTICE	2016-06-15 00:00:00	2016-06-22 00:00:00	ANCIEN	\N	\N	\N	\N	11072N	SUPPLEANT	2016-06-15 15:18:25	2016-06-24 20:12:48
12353	JUSTICE	2016-06-15 00:00:00	2016-06-22 00:00:00	ANCIEN	\N	\N	\N	\N	04074L	SUPPLEANT	2016-06-15 15:18:32	2016-06-24 20:12:48
12354	JUSTICE	2016-06-15 00:00:00	2016-06-22 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	SUPPLEANT	2016-06-15 15:18:38	2016-06-24 20:12:48
12355	JUSTICE	2016-06-15 00:00:00	2016-06-22 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	2016-06-15 15:18:46	2016-06-24 20:12:48
12356	JUSTICE	2016-06-15 00:00:00	2016-06-22 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	SUPPLEANT	2016-06-15 15:18:56	2016-06-24 20:12:48
13028	NEANT	2017-06-18 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	11069T	\N	2017-06-19 15:51:10	2017-06-28 09:50:50
13030	NEANT	2017-06-18 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	11045K	\N	2017-06-19 15:58:23	2017-06-28 09:53:52
12516	TRANSPARENCE	2016-07-13 00:00:00	2016-09-14 00:00:00	ANCIEN	\N	\N	\N	\N	08011M	TITULAIRE	2016-07-13 16:26:10	2016-10-07 09:18:55
12517	TRANSPARENCE	2016-07-13 00:00:00	2016-09-14 00:00:00	ANCIEN	\N	\N	\N	\N	01007L	TITULAIRE	2016-07-13 16:26:18	2016-10-07 09:18:55
12518	TRANSPARENCE	2016-07-13 00:00:00	2016-09-14 00:00:00	ANCIEN	\N	\N	\N	\N	08025T	TITULAIRE	2016-07-13 16:26:26	2016-10-07 09:18:55
12519	TRANSPARENCE	2016-07-13 00:00:00	2016-09-14 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	TITULAIRE	2016-07-13 16:26:33	2016-10-07 09:18:55
12520	TRANSPARENCE	2016-07-13 00:00:00	2016-09-14 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	TITULAIRE	2016-07-13 16:26:42	2016-10-07 09:18:55
12601	PLFSS2017	2016-11-16 00:00:00	2016-11-24 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	TITULAIRE	2016-11-17 10:38:47	2016-11-24 11:54:25
12522	TRANSPARENCE	2016-07-13 00:00:00	2016-09-14 00:00:00	ANCIEN	\N	\N	\N	\N	11053K	SUPPLEANT	2016-07-13 16:27:38	2016-10-07 09:18:55
12523	TRANSPARENCE	2016-07-13 00:00:00	2016-09-14 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	2016-07-13 16:27:45	2016-10-07 09:18:55
12524	TRANSPARENCE	2016-07-13 00:00:00	2016-09-14 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	SUPPLEANT	2016-07-13 16:27:55	2016-10-07 09:18:55
15475	ASAP	2020-02-06 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	14219Q	\N	\N	\N
12525	TRANSPARENCE	2016-07-13 00:00:00	2016-09-14 00:00:00	ANCIEN	\N	\N	\N	\N	11110B	SUPPLEANT	2016-07-13 16:28:02	2016-10-07 09:18:55
12526	TRANSPARENCE	2016-07-13 00:00:00	2016-09-14 00:00:00	ANCIEN	\N	\N	\N	\N	14033T	SUPPLEANT	2016-07-13 16:28:08	2016-10-07 09:18:55
12527	TRANSPARENCE	2016-07-13 00:00:00	2016-09-14 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	SUPPLEANT	2016-07-13 16:28:17	2016-10-07 09:18:55
12528	TRANSPARENCE	2016-07-13 00:00:00	2016-09-14 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	SUPPLEANT	2016-07-13 16:28:25	2016-10-07 09:18:55
12805	PSYCHIATRIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14065Q	\N	2016-11-30 18:12:05	2017-06-12 11:07:11
12603	PLFSS2017	2016-11-16 00:00:00	2016-11-24 00:00:00	ANCIEN	\N	\N	\N	\N	01034P	TITULAIRE	2016-11-17 10:39:35	2016-11-24 11:54:25
12604	PLFSS2017	2016-11-16 00:00:00	2016-11-24 00:00:00	ANCIEN	\N	\N	\N	\N	11044J	TITULAIRE	2016-11-17 10:39:43	2016-11-24 11:54:25
12605	PLFSS2017	2016-11-16 00:00:00	2016-11-24 00:00:00	ANCIEN	\N	\N	\N	\N	11097X	TITULAIRE	2016-11-17 10:39:48	2016-11-24 11:54:25
12606	PLFSS2017	2016-11-16 00:00:00	2016-11-24 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	TITULAIRE	2016-11-17 10:39:56	2016-11-24 11:54:25
12607	PLFSS2017	2016-11-16 00:00:00	2016-11-24 00:00:00	ANCIEN	\N	\N	\N	\N	11061K	TITULAIRE	2016-11-17 10:40:03	2016-11-24 11:54:25
12608	PLFSS2017	2016-11-16 00:00:00	2016-11-24 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	TITULAIRE	2016-11-17 10:40:10	2016-11-24 11:54:25
12609	PLFSS2017	2016-11-16 00:00:00	2016-11-24 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	SUPPLEANT	2016-11-17 10:40:16	2016-11-24 11:54:25
12610	PLFSS2017	2016-11-16 00:00:00	2016-11-24 00:00:00	ANCIEN	\N	\N	\N	\N	11103C	SUPPLEANT	2016-11-17 10:40:21	2016-11-24 11:54:25
12611	PLFSS2017	2016-11-16 00:00:00	2016-11-24 00:00:00	ANCIEN	\N	\N	\N	\N	11088W	SUPPLEANT	2016-11-17 10:40:26	2016-11-24 11:54:25
12612	PLFSS2017	2016-11-16 00:00:00	2016-11-24 00:00:00	ANCIEN	\N	\N	\N	\N	98024R	SUPPLEANT	2016-11-17 10:40:30	2016-11-24 11:54:25
12613	PLFSS2017	2016-11-16 00:00:00	2016-11-24 00:00:00	ANCIEN	\N	\N	\N	\N	14281W	SUPPLEANT	2016-11-17 10:40:38	2016-11-24 11:54:25
12614	PLFSS2017	2016-11-16 00:00:00	2016-11-24 00:00:00	ANCIEN	\N	\N	\N	\N	11093T	SUPPLEANT	2016-11-17 10:40:43	2016-11-24 11:54:25
12615	PLFSS2017	2016-11-16 00:00:00	2016-11-24 00:00:00	ANCIEN	\N	\N	\N	\N	14227Q	SUPPLEANT	2016-11-17 10:40:48	2016-11-24 11:54:25
12806	DEMOCRATIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	11061K	\N	2016-11-30 18:15:59	2017-06-12 11:07:07
12812	VTC	2016-11-23 00:00:00	2016-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	14038Y	TITULAIRE	2016-12-01 14:29:27	2016-12-01 15:39:15
12813	CDGEXPRESS	2016-11-23 00:00:00	2016-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	14093U	SUPPLEANT	2016-12-01 14:31:06	2016-12-01 15:39:21
12815	EGALITE	2016-12-01 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14355X	\N	2016-12-07 11:19:56	2017-06-12 11:07:18
12909	IVG	2017-01-18 00:00:00	2017-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	TITULAIRE	2017-01-23 14:31:21	2017-01-31 14:13:20
12910	IVG	2017-01-18 00:00:00	2017-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	14271U	TITULAIRE	2017-01-23 14:31:27	2017-01-31 14:13:20
12911	IVG	2017-01-18 00:00:00	2017-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	10006L	TITULAIRE	2017-01-23 14:31:31	2017-01-31 14:13:20
12912	IVG	2017-01-18 00:00:00	2017-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	14213J	TITULAIRE	2017-01-23 14:31:36	2017-01-31 14:13:20
12913	IVG	2017-01-18 00:00:00	2017-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	95049N	TITULAIRE	2017-01-23 14:31:42	2017-01-31 14:13:20
12914	IVG	2017-01-18 00:00:00	2017-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	04045F	TITULAIRE	2017-01-23 14:31:46	2017-01-31 14:13:20
12915	IVG	2017-01-18 00:00:00	2017-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	11031D	TITULAIRE	2017-01-23 14:31:50	2017-01-31 14:13:20
12916	IVG	2017-01-18 00:00:00	2017-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	14239U	SUPPLEANT	2017-01-23 14:31:54	2017-01-31 14:13:20
12917	IVG	2017-01-18 00:00:00	2017-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	14217N	SUPPLEANT	2017-01-23 14:31:59	2017-01-31 14:13:20
12918	IVG	2017-01-18 00:00:00	2017-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	14281W	SUPPLEANT	2017-01-23 14:32:05	2017-01-31 14:13:20
12919	IVG	2017-01-18 00:00:00	2017-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	14231L	SUPPLEANT	2017-01-23 14:32:09	2017-01-31 14:13:20
12920	IVG	2017-01-18 00:00:00	2017-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	11061K	SUPPLEANT	2017-01-23 14:32:14	2017-01-31 14:13:20
12921	IVG	2017-01-18 00:00:00	2017-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	14026U	SUPPLEANT	2017-01-23 14:32:20	2017-01-31 14:13:20
12922	IVG	2017-01-18 00:00:00	2017-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	11097X	SUPPLEANT	2017-01-23 14:32:24	2017-01-31 14:13:20
11782	2015CMP29	2015-11-05 00:00:00	2017-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	01007L	SUPPLEANT	\N	2017-07-24 09:56:26
13039	LOIS	2017-06-28 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19251M	\N	2017-06-28 09:51:57	2017-10-04 18:52:02
13040	CAE	2017-06-28 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	11045K	\N	2017-06-28 09:53:51	2017-10-04 19:02:06
13041	NEANT	2017-07-04 00:00:00	2017-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	18127E	\N	2017-07-04 15:35:17	2017-07-10 16:44:14
11583	2015CMP15	2015-07-25 00:00:00	2017-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	01007L	SUPPLEANT	\N	2017-07-24 09:56:26
11511	2015CMP13	2015-06-25 00:00:00	2017-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	14037X	TITULAIRE	\N	2017-07-24 09:58:00
13045	NEANT	2017-07-22 00:00:00	2017-07-25 00:00:00	ANCIEN	\N	\N	\N	\N	19269X	\N	2017-07-24 10:01:14	2017-07-26 15:50:28
13052	DIALOGUE	2017-07-26 00:00:00	2017-08-01 00:00:00	ANCIEN	\N	\N	\N	\N	14034U	TITULAIRE	2017-07-27 11:23:47	2017-08-03 12:18:38
13053	DIALOGUE	2017-07-26 00:00:00	2017-08-01 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	TITULAIRE	2017-07-27 11:23:52	2017-08-03 12:18:38
13054	DIALOGUE	2017-07-26 00:00:00	2017-08-01 00:00:00	ANCIEN	\N	\N	\N	\N	14227Q	TITULAIRE	2017-07-27 11:23:56	2017-08-03 12:18:38
13055	DIALOGUE	2017-07-26 00:00:00	2017-08-01 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	TITULAIRE	2017-07-27 11:24:01	2017-08-03 12:18:38
13056	DIALOGUE	2017-07-26 00:00:00	2017-08-01 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	SUPPLEANT	2017-07-27 11:24:08	2017-08-03 12:18:38
13057	DIALOGUE	2017-07-26 00:00:00	2017-08-01 00:00:00	ANCIEN	\N	\N	\N	\N	11031D	SUPPLEANT	2017-07-27 11:24:15	2017-08-03 12:18:38
13058	DIALOGUE	2017-07-26 00:00:00	2017-08-01 00:00:00	ANCIEN	\N	\N	\N	\N	10006L	SUPPLEANT	2017-07-27 11:24:19	2017-08-03 12:18:38
13059	DIALOGUE	2017-07-26 00:00:00	2017-08-01 00:00:00	ANCIEN	\N	\N	\N	\N	08011M	SUPPLEANT	2017-07-27 11:24:46	2017-08-03 12:18:38
13060	DIALOGUE	2017-07-26 00:00:00	2017-08-01 00:00:00	ANCIEN	\N	\N	\N	\N	11097X	SUPPLEANT	2017-07-27 11:24:51	2017-08-03 12:18:38
13061	DIALOGUE	2017-07-26 00:00:00	2017-08-01 00:00:00	ANCIEN	\N	\N	\N	\N	14255U	SUPPLEANT	2017-07-27 11:25:50	2017-08-03 12:18:38
13062	DIALOGUE	2017-07-26 00:00:00	2017-08-01 00:00:00	ANCIEN	\N	\N	\N	\N	11061K	SUPPLEANT	2017-07-27 11:26:09	2017-08-03 12:18:38
13063	CONFIANCE	2017-07-26 00:00:00	2017-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	2017-07-27 11:30:40	2017-08-03 12:18:47
13064	CONFIANCE	2017-07-26 00:00:00	2017-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	TITULAIRE	2017-07-27 11:30:45	2017-08-03 12:18:47
13065	CONFIANCE	2017-07-26 00:00:00	2017-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	08011M	TITULAIRE	2017-07-27 11:30:50	2017-08-03 12:18:47
13066	CONFIANCE	2017-07-26 00:00:00	2017-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	95049N	TITULAIRE	2017-07-27 11:30:57	2017-08-03 12:18:47
13067	CONFIANCE	2017-07-26 00:00:00	2017-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	TITULAIRE	2017-07-27 11:31:02	2017-08-03 12:18:47
13068	CONFIANCE	2017-07-26 00:00:00	2017-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	11026G	TITULAIRE	2017-07-27 11:31:07	2017-08-03 12:18:47
13069	CONFIANCE	2017-07-26 00:00:00	2017-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	TITULAIRE	2017-07-27 11:31:12	2017-08-03 12:18:47
13070	CONFIANCE	2017-07-26 00:00:00	2017-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	SUPPLEANT	2017-07-27 11:31:17	2017-08-03 12:18:47
13071	CONFIANCE	2017-07-26 00:00:00	2017-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	14069U	SUPPLEANT	2017-07-27 11:31:24	2017-08-03 12:18:47
12500	REGLEMENT	2016-07-08 00:00:00	2016-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	TITULAIRE	2016-07-08 11:19:43	2016-10-07 09:19:09
12501	REGLEMENT	2016-07-08 00:00:00	2016-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	08011M	TITULAIRE	2016-07-08 11:19:51	2016-10-07 09:19:09
12502	REGLEMENT	2016-07-08 00:00:00	2016-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	14175V	TITULAIRE	2016-07-08 11:19:55	2016-10-07 09:19:09
12503	REGLEMENT	2016-07-08 00:00:00	2016-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	14173T	TITULAIRE	2016-07-08 11:20:00	2016-10-07 09:19:09
12504	REGLEMENT	2016-07-08 00:00:00	2016-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	11070L	TITULAIRE	2016-07-08 11:20:05	2016-10-07 09:19:09
12505	REGLEMENT	2016-07-08 00:00:00	2016-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	11042G	TITULAIRE	2016-07-08 11:20:10	2016-10-07 09:19:09
12506	REGLEMENT	2016-07-08 00:00:00	2016-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	01013J	TITULAIRE	2016-07-08 11:20:14	2016-10-07 09:19:09
12507	REGLEMENT	2016-07-08 00:00:00	2016-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	89017R	SUPPLEANT	2016-07-08 11:20:19	2016-10-07 09:19:09
12508	REGLEMENT	2016-07-08 00:00:00	2016-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	11053K	SUPPLEANT	2016-07-08 11:20:23	2016-10-07 09:19:09
12509	REGLEMENT	2016-07-08 00:00:00	2016-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	88008L	SUPPLEANT	2016-07-08 11:20:27	2016-10-07 09:19:09
12510	REGLEMENT	2016-07-08 00:00:00	2016-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	SUPPLEANT	2016-07-08 11:20:31	2016-10-07 09:19:09
12511	REGLEMENT	2016-07-08 00:00:00	2016-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	11088W	SUPPLEANT	2016-07-08 11:20:35	2016-10-07 09:19:09
12512	REGLEMENT	2016-07-08 00:00:00	2016-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	11057P	SUPPLEANT	2016-07-08 11:20:42	2016-10-07 09:19:09
12513	REGLEMENT	2016-07-08 00:00:00	2016-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	SUPPLEANT	2016-07-08 11:20:46	2016-10-07 09:19:09
12600	NEANT	2016-11-13 00:00:00	2016-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	05001W	\N	2016-11-14 18:40:41	2016-11-22 16:39:26
12763	CDD	2016-11-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	05001W	\N	2016-11-22 16:39:25	2017-09-24 16:24:51
12764	CDGEXPRESS	2016-11-23 00:00:00	2016-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	08009T	TITULAIRE	2016-11-24 11:55:43	2016-12-01 15:39:21
12765	CDGEXPRESS	2016-11-23 00:00:00	2016-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	08042U	TITULAIRE	2016-11-24 11:55:48	2016-12-01 15:39:21
12766	CDGEXPRESS	2016-11-23 00:00:00	2016-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	14038Y	TITULAIRE	2016-11-24 11:55:52	2016-12-01 15:39:21
12767	CDGEXPRESS	2016-11-23 00:00:00	2016-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	05012A	TITULAIRE	2016-11-24 11:55:57	2016-12-01 15:39:21
12768	CDGEXPRESS	2016-11-23 00:00:00	2016-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	08060W	TITULAIRE	2016-11-24 11:56:03	2016-12-01 15:39:21
12769	CDGEXPRESS	2016-11-23 00:00:00	2016-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	TITULAIRE	2016-11-24 11:56:09	2016-12-01 15:39:21
12770	CDGEXPRESS	2016-11-23 00:00:00	2016-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	01015L	TITULAIRE	2016-11-24 11:56:14	2016-12-01 15:39:21
12771	CDGEXPRESS	2016-11-23 00:00:00	2016-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	14261S	SUPPLEANT	2016-11-24 11:56:20	2016-12-01 15:39:21
12772	VTC	2016-11-23 00:00:00	2016-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	14093U	SUPPLEANT	2016-11-24 11:56:24	2016-12-01 15:39:15
12773	VTC	2016-11-23 00:00:00	2016-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	11053K	SUPPLEANT	2016-11-24 11:56:28	2016-12-01 15:39:15
12774	CDGEXPRESS	2016-11-23 00:00:00	2016-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	02002K	SUPPLEANT	2016-11-24 11:56:33	2016-12-01 15:39:21
12775	CDGEXPRESS	2016-11-23 00:00:00	2016-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	92039X	SUPPLEANT	2016-11-24 11:56:37	2016-12-01 15:39:21
12776	CDGEXPRESS	2016-11-23 00:00:00	2016-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	14051J	SUPPLEANT	2016-11-24 11:56:43	2016-12-01 15:39:21
12777	CDGEXPRESS	2016-11-23 00:00:00	2016-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	14157T	SUPPLEANT	2016-11-24 11:56:49	2016-12-01 15:39:21
12778	VTC	2016-11-23 00:00:00	2016-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	08009T	TITULAIRE	2016-11-24 11:59:09	2016-12-01 15:39:15
12779	VTC	2016-11-23 00:00:00	2016-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	14331P	TITULAIRE	2016-11-24 11:59:13	2016-12-01 15:39:15
12780	VTC	2016-11-23 00:00:00	2016-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	05012A	TITULAIRE	2016-11-24 11:59:23	2016-12-01 15:39:15
12781	VTC	2016-11-23 00:00:00	2016-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	08055A	TITULAIRE	2016-11-24 11:59:28	2016-12-01 15:39:15
12782	VTC	2016-11-23 00:00:00	2016-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	14107H	TITULAIRE	2016-11-24 11:59:31	2016-12-01 15:39:15
12783	VTC	2016-11-23 00:00:00	2016-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	01015L	TITULAIRE	2016-11-24 11:59:36	2016-12-01 15:39:15
12784	VTC	2016-11-23 00:00:00	2016-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	14261S	SUPPLEANT	2016-11-24 11:59:43	2016-12-01 15:39:15
12785	VTC	2016-11-23 00:00:00	2016-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	98023Q	SUPPLEANT	2016-11-24 12:00:00	2016-12-01 15:39:15
12786	VTC	2016-11-23 00:00:00	2016-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	14031R	SUPPLEANT	2016-11-24 12:00:05	2016-12-01 15:39:15
12787	VTC	2016-11-23 00:00:00	2016-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	92039X	SUPPLEANT	2016-11-24 12:00:10	2016-12-01 15:39:15
12788	VTC	2016-11-23 00:00:00	2016-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	14051J	SUPPLEANT	2016-11-24 12:00:16	2016-12-01 15:39:15
12810	NEANT	2016-12-01 00:00:00	2016-12-05 00:00:00	ANCIEN	\N	\N	\N	\N	14357A	\N	2016-12-01 10:39:20	2016-12-06 15:38:54
12954	ACCAPAREMENT	2017-02-09 00:00:00	2017-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	11100Y	TITULAIRE	2017-02-09 10:40:34	2017-02-14 16:23:34
12955	ACCAPAREMENT	2017-02-09 00:00:00	2017-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	14033T	TITULAIRE	2017-02-09 10:40:38	2017-02-14 16:23:34
12956	ACCAPAREMENT	2017-02-09 00:00:00	2017-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	11090Q	TITULAIRE	2017-02-09 10:40:43	2017-02-14 16:23:34
12957	ACCAPAREMENT	2017-02-09 00:00:00	2017-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	04089T	TITULAIRE	2017-02-09 10:40:48	2017-02-14 16:23:34
12958	ACCAPAREMENT	2017-02-09 00:00:00	2017-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	14207L	TITULAIRE	2017-02-09 10:40:53	2017-02-14 16:23:34
12959	ACCAPAREMENT	2017-02-09 00:00:00	2017-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	14257W	TITULAIRE	2017-02-09 10:41:13	2017-02-14 16:23:34
12960	ACCAPAREMENT	2017-02-09 00:00:00	2017-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	11098Y	TITULAIRE	2017-02-09 10:41:20	2017-02-14 16:23:34
12961	ACCAPAREMENT	2017-02-09 00:00:00	2017-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	11036J	SUPPLEANT	2017-02-09 10:41:26	2017-02-14 16:23:34
12962	ACCAPAREMENT	2017-02-09 00:00:00	2017-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	08068F	SUPPLEANT	2017-02-09 10:41:33	2017-02-14 16:23:34
12963	ACCAPAREMENT	2017-02-09 00:00:00	2017-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	14187A	SUPPLEANT	2017-02-09 10:41:40	2017-02-14 16:23:34
12964	ACCAPAREMENT	2017-02-09 00:00:00	2017-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	11099A	SUPPLEANT	2017-02-09 10:41:48	2017-02-14 16:23:34
12965	ACCAPAREMENT	2017-02-09 00:00:00	2017-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	SUPPLEANT	2017-02-09 10:41:54	2017-02-14 16:23:34
12966	ACCAPAREMENT	2017-02-09 00:00:00	2017-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	11111C	SUPPLEANT	2017-02-09 10:42:00	2017-02-14 16:23:34
12967	ACCAPAREMENT	2017-02-09 00:00:00	2017-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	04088S	SUPPLEANT	2017-02-09 10:42:11	2017-02-14 16:23:34
12968	PRESCRIPTION	2017-02-08 00:00:00	2017-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	2017-02-14 16:34:01	2017-02-14 16:44:06
12969	PRESCRIPTION	2017-02-08 00:00:00	2017-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	TITULAIRE	2017-02-14 16:34:06	2017-02-14 16:44:06
12970	PRESCRIPTION	2017-02-08 00:00:00	2017-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	07034Q	TITULAIRE	2017-02-14 16:34:11	2017-02-14 16:44:06
12971	PRESCRIPTION	2017-02-08 00:00:00	2017-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	14275Y	TITULAIRE	2017-02-14 16:34:20	2017-02-14 16:44:06
12972	PRESCRIPTION	2017-02-08 00:00:00	2017-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	11084S	TITULAIRE	2017-02-14 16:34:27	2017-02-14 16:44:06
12973	PRESCRIPTION	2017-02-08 00:00:00	2017-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	11037K	TITULAIRE	2017-02-14 16:34:35	2017-02-14 16:44:06
12974	PRESCRIPTION	2017-02-08 00:00:00	2017-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	11056N	TITULAIRE	2017-02-14 16:34:41	2017-02-14 16:44:06
12975	PRESCRIPTION	2017-02-08 00:00:00	2017-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	SUPPLEANT	2017-02-14 16:34:47	2017-02-14 16:44:06
12976	PRESCRIPTION	2017-02-08 00:00:00	2017-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	11049P	SUPPLEANT	2017-02-14 16:34:52	2017-02-14 16:44:06
12977	PRESCRIPTION	2017-02-08 00:00:00	2017-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	04079R	SUPPLEANT	2017-02-14 16:34:57	2017-02-14 16:44:06
12978	PRESCRIPTION	2017-02-08 00:00:00	2017-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	SUPPLEANT	2017-02-14 16:35:02	2017-02-14 16:44:06
12979	PRESCRIPTION	2017-02-08 00:00:00	2017-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	04074L	SUPPLEANT	2017-02-14 16:35:11	2017-02-14 16:44:06
12980	PRESCRIPTION	2017-02-08 00:00:00	2017-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	SUPPLEANT	2017-02-14 16:35:17	2017-02-14 16:44:06
12981	PRESCRIPTION	2017-02-08 00:00:00	2017-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	SUPPLEANT	2017-02-14 16:35:23	2017-02-14 16:44:06
12859	NEANT	2017-01-01 00:00:00	2017-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	14363X	\N	2017-01-03 11:10:58	2017-01-10 18:00:19
12924	ENERGIE	2017-01-26 00:00:00	2017-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	11100Y	TITULAIRE	2017-01-31 14:15:25	2017-02-07 09:57:49
12925	ENERGIE	2017-01-26 00:00:00	2017-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	98050T	TITULAIRE	2017-01-31 14:15:31	2017-02-07 09:57:49
12926	ENERGIE	2017-01-26 00:00:00	2017-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	08015R	TITULAIRE	2017-01-31 14:16:04	2017-02-07 09:57:49
12927	ENERGIE	2017-01-26 00:00:00	2017-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	14205J	TITULAIRE	2017-01-31 14:16:10	2017-02-07 09:57:49
12928	ENERGIE	2017-01-26 00:00:00	2017-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	80013X	TITULAIRE	2017-01-31 14:16:16	2017-02-07 09:57:49
12929	ENERGIE	2017-01-26 00:00:00	2017-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	14257W	TITULAIRE	2017-01-31 14:16:20	2017-02-07 09:57:49
12930	ENERGIE	2017-01-26 00:00:00	2017-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	14013P	TITULAIRE	2017-01-31 14:16:26	2017-02-07 09:57:49
12931	ENERGIE	2017-01-26 00:00:00	2017-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	01008M	SUPPLEANT	2017-01-31 14:16:34	2017-02-07 09:57:49
12932	ENERGIE	2017-01-26 00:00:00	2017-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	11036J	SUPPLEANT	2017-01-31 14:16:41	2017-02-07 09:57:49
12933	ENERGIE	2017-01-26 00:00:00	2017-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	08038Y	SUPPLEANT	2017-01-31 14:16:45	2017-02-07 09:57:49
12934	ENERGIE	2017-01-26 00:00:00	2017-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	04089T	SUPPLEANT	2017-01-31 14:16:49	2017-02-07 09:57:49
12935	ENERGIE	2017-01-26 00:00:00	2017-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	11099A	SUPPLEANT	2017-01-31 14:16:54	2017-02-07 09:57:49
12936	ENERGIE	2017-01-26 00:00:00	2017-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	SUPPLEANT	2017-01-31 14:16:59	2017-02-07 09:57:49
12937	ENERGIE	2017-01-26 00:00:00	2017-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	11090Q	SUPPLEANT	2017-01-31 14:17:03	2017-02-07 09:57:49
12938	OUTRE_MER	2017-01-31 00:00:00	2017-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	TITULAIRE	2017-01-31 14:39:27	2017-02-07 09:57:43
12939	OUTRE_MER	2017-01-31 00:00:00	2017-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	14259Y	TITULAIRE	2017-01-31 14:39:32	2017-02-07 09:57:43
12940	OUTRE_MER	2017-01-31 00:00:00	2017-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	08019V	TITULAIRE	2017-01-31 14:39:36	2017-02-07 09:57:43
12941	OUTRE_MER	2017-01-31 00:00:00	2017-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	14275Y	TITULAIRE	2017-01-31 14:39:41	2017-02-07 09:57:43
12942	OUTRE_MER	2017-01-31 00:00:00	2017-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	11072N	TITULAIRE	2017-01-31 14:39:49	2017-02-07 09:57:43
12943	OUTRE_MER	2017-01-31 00:00:00	2017-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	04094Q	TITULAIRE	2017-01-31 14:39:56	2017-02-07 09:57:43
12944	OUTRE_MER	2017-01-31 00:00:00	2017-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	05001W	TITULAIRE	2017-01-31 14:40:03	2017-02-07 09:57:43
12945	OUTRE_MER	2017-01-31 00:00:00	2017-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	14261S	SUPPLEANT	2017-01-31 14:40:08	2017-02-07 09:57:43
12946	OUTRE_MER	2017-01-31 00:00:00	2017-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	11023D	SUPPLEANT	2017-01-31 14:40:13	2017-02-07 09:57:43
12947	OUTRE_MER	2017-01-31 00:00:00	2017-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	14217N	SUPPLEANT	2017-01-31 14:40:20	2017-02-07 09:57:43
12948	OUTRE_MER	2017-01-31 00:00:00	2017-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	14059S	SUPPLEANT	2017-01-31 14:40:25	2017-02-07 09:57:43
12949	OUTRE_MER	2017-01-31 00:00:00	2017-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	08062Y	SUPPLEANT	2017-01-31 14:40:29	2017-02-07 09:57:43
12950	OUTRE_MER	2017-01-31 00:00:00	2017-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	08073C	SUPPLEANT	2017-01-31 14:40:35	2017-02-07 09:57:43
12951	OUTRE_MER	2017-01-31 00:00:00	2017-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	SUPPLEANT	2017-01-31 14:40:39	2017-02-07 09:57:43
12982	COLLCORSE	2017-02-08 00:00:00	2017-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	2017-02-14 17:57:04	2017-02-14 18:17:29
12983	COLLCORSE	2017-02-08 00:00:00	2017-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	04074L	TITULAIRE	2017-02-14 17:57:09	2017-02-14 18:17:29
12984	COLLCORSE	2017-02-08 00:00:00	2017-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	01057W	TITULAIRE	2017-02-14 17:57:15	2017-02-14 18:17:29
12985	COLLCORSE	2017-02-08 00:00:00	2017-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	14275Y	TITULAIRE	2017-02-14 17:57:20	2017-02-14 18:17:29
12986	COLLCORSE	2017-02-08 00:00:00	2017-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	11084S	TITULAIRE	2017-02-14 17:57:26	2017-02-14 18:17:29
12987	COLLCORSE	2017-02-08 00:00:00	2017-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	11037K	TITULAIRE	2017-02-14 17:57:32	2017-02-14 18:17:29
12988	COLLCORSE	2017-02-08 00:00:00	2017-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	11034G	TITULAIRE	2017-02-14 17:57:37	2017-02-14 18:17:29
12989	COLLCORSE	2017-02-08 00:00:00	2017-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	14259Y	SUPPLEANT	2017-02-14 17:57:42	2017-02-14 18:17:29
12990	COLLCORSE	2017-02-08 00:00:00	2017-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	04079R	SUPPLEANT	2017-02-14 17:57:47	2017-02-14 18:17:29
12991	COLLCORSE	2017-02-08 00:00:00	2017-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	SUPPLEANT	2017-02-14 17:57:53	2017-02-14 18:17:29
12992	COLLCORSE	2017-02-08 00:00:00	2017-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	SUPPLEANT	2017-02-14 17:57:58	2017-02-14 18:17:29
12993	COLLCORSE	2017-02-08 00:00:00	2017-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	2017-02-14 17:58:04	2017-02-14 18:17:29
12994	COLLCORSE	2017-02-08 00:00:00	2017-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	SUPPLEANT	2017-02-14 17:58:09	2017-02-14 18:17:29
12995	COLLCORSE	2017-02-08 00:00:00	2017-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	SUPPLEANT	2017-02-14 17:58:14	2017-02-14 18:17:29
13010	SECURITEPUBL	2017-02-08 00:00:00	2017-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	2017-02-14 18:06:22	2017-02-14 18:17:34
13011	SECURITEPUBL	2017-02-08 00:00:00	2017-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	11049P	TITULAIRE	2017-02-14 18:06:28	2017-02-14 18:17:34
13012	SECURITEPUBL	2017-02-08 00:00:00	2017-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	08047A	TITULAIRE	2017-02-14 18:06:33	2017-02-14 18:17:34
13013	SECURITEPUBL	2017-02-08 00:00:00	2017-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	14275Y	TITULAIRE	2017-02-14 18:06:39	2017-02-14 18:17:34
13014	SECURITEPUBL	2017-02-08 00:00:00	2017-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	11084S	TITULAIRE	2017-02-14 18:06:45	2017-02-14 18:17:34
13015	SECURITEPUBL	2017-02-08 00:00:00	2017-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	11037K	TITULAIRE	2017-02-14 18:06:53	2017-02-14 18:17:34
13016	SECURITEPUBL	2017-02-08 00:00:00	2017-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	TITULAIRE	2017-02-14 18:06:57	2017-02-14 18:17:34
13017	SECURITEPUBL	2017-02-08 00:00:00	2017-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	SUPPLEANT	2017-02-14 18:07:03	2017-02-14 18:17:34
13018	SECURITEPUBL	2017-02-08 00:00:00	2017-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	SUPPLEANT	2017-02-14 18:07:08	2017-02-14 18:17:34
13019	SECURITEPUBL	2017-02-08 00:00:00	2017-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	04079R	SUPPLEANT	2017-02-14 18:07:13	2017-02-14 18:17:34
13020	SECURITEPUBL	2017-02-08 00:00:00	2017-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	SUPPLEANT	2017-02-14 18:07:18	2017-02-14 18:17:34
13021	SECURITEPUBL	2017-02-08 00:00:00	2017-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	07034Q	SUPPLEANT	2017-02-14 18:07:22	2017-02-14 18:17:34
13022	SECURITEPUBL	2017-02-08 00:00:00	2017-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	SUPPLEANT	2017-02-14 18:07:27	2017-02-14 18:17:34
13023	SECURITEPUBL	2017-02-08 00:00:00	2017-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	SUPPLEANT	2017-02-14 18:07:32	2017-02-14 18:17:34
8407	2011CMP26	2011-12-19 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	SUPPLEANT	\N	2017-05-16 15:18:13
10155	SOCI	2014-10-08 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	\N	2014-10-08 17:09:46	2017-05-16 15:18:13
13026	NEANT	2017-05-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14365A	\N	2017-05-16 16:19:32	2017-09-24 12:39:59
12762	ATTEINTES	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	08049C	\N	2016-11-22 15:23:51	2017-06-12 11:06:58
12751	DEMOCRATIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	11023D	\N	2016-11-22 12:24:48	2017-06-12 11:07:07
12753	PSYCHIATRIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	11061K	\N	2016-11-22 12:25:01	2017-06-12 11:07:11
12759	PSYCHIATRIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14028W	\N	2016-11-22 12:28:19	2017-06-12 11:07:11
12486	EGALITE	2016-07-07 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	08043V	\N	2016-07-07 17:25:58	2017-06-12 11:07:18
12490	EGALITE	2016-07-07 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	08012N	\N	2016-07-07 17:26:21	2017-06-12 11:07:18
12494	EGALITE	2016-07-07 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	11046L	\N	2016-07-07 17:27:38	2017-06-12 11:07:18
12631	SCHENGEN	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	04054G	\N	2016-11-21 17:22:15	2017-06-12 11:06:53
12632	SCHENGEN	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14267Y	\N	2016-11-21 17:22:24	2017-06-12 11:06:53
12633	SCHENGEN	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14073Q	\N	2016-11-21 17:22:30	2017-06-12 11:06:53
12634	SCHENGEN	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	11012A	\N	2016-11-21 17:22:37	2017-06-12 11:06:53
12635	SCHENGEN	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14133K	\N	2016-11-21 17:22:47	2017-06-12 11:06:53
12636	SCHENGEN	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	96004D	\N	2016-11-21 17:22:56	2017-06-12 11:06:53
12637	SCHENGEN	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	\N	2016-11-21 17:23:10	2017-06-12 11:06:53
12638	SCHENGEN	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14079W	\N	2016-11-21 17:23:21	2017-06-12 11:06:53
12639	SCHENGEN	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14026U	\N	2016-11-21 17:23:32	2017-06-12 11:06:53
12640	SCHENGEN	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	92031P	\N	2016-11-21 17:23:39	2017-06-12 11:06:53
12641	SCHENGEN	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14193X	\N	2016-11-21 17:23:49	2017-06-12 11:06:53
12642	SCHENGEN	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	10015M	\N	2016-11-21 17:23:59	2017-06-12 11:06:53
12643	SCHENGEN	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	\N	2016-11-21 17:24:08	2017-06-12 11:06:53
12644	SCHENGEN	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	11083R	\N	2016-11-21 17:24:19	2017-06-12 11:06:53
12645	ATTEINTES	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	01015L	\N	2016-11-21 17:31:31	2017-06-12 11:06:58
12646	ATTEINTES	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	09001P	\N	2016-11-21 17:33:54	2017-06-12 11:06:58
12647	ATTEINTES	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14219Q	\N	2016-11-21 17:34:55	2017-06-12 11:06:58
12497	EGALITE	2016-07-07 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	11066Q	\N	2016-07-07 17:28:11	2017-06-12 11:07:18
12649	ATTEINTES	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	01008M	\N	2016-11-21 17:35:08	2017-06-12 11:06:58
12650	ATTEINTES	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14093U	\N	2016-11-21 17:35:13	2017-06-12 11:06:58
12651	ATTEINTES	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	90003B	\N	2016-11-21 17:35:20	2017-06-12 11:06:58
12652	ATTEINTES	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14033T	\N	2016-11-21 17:35:26	2017-06-12 11:06:58
12653	ATTEINTES	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	\N	2016-11-21 17:35:31	2018-01-25 13:10:11
12654	ATTEINTES	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	05012A	\N	2016-11-21 17:35:42	2017-06-12 11:06:58
12655	ATTEINTES	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	11090Q	\N	2016-11-21 17:35:47	2017-06-12 11:06:58
12656	ATTEINTES	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	01056V	\N	2016-11-21 17:35:51	2017-06-12 11:06:58
12657	ATTEINTES	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	\N	2016-11-21 17:35:56	2017-06-12 11:06:58
12658	ATTEINTES	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	11065P	\N	2016-11-21 17:36:00	2017-06-12 11:06:58
12659	ATTEINTES	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	13002U	\N	2016-11-21 17:36:06	2017-06-12 11:06:58
12721	DEMOCRATIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14231L	\N	2016-11-21 17:52:52	2017-06-12 11:07:07
12719	DEMOCRATIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	04050C	\N	2016-11-21 17:52:39	2017-06-12 11:07:07
12720	DEMOCRATIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	11034G	\N	2016-11-21 17:52:45	2017-06-12 11:07:07
12722	DEMOCRATIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14089Y	\N	2016-11-21 17:53:02	2017-06-12 11:07:07
12723	DEMOCRATIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	04089T	\N	2016-11-21 17:53:08	2017-06-12 11:07:07
12724	DEMOCRATIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	\N	2016-11-21 17:53:19	2017-06-12 11:07:07
12702	PSYCHIATRIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14235Q	\N	2016-11-21 17:46:58	2017-06-12 11:07:11
12725	DEMOCRATIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14053L	\N	2016-11-21 17:53:25	2017-06-12 11:07:07
12726	DEMOCRATIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14079W	\N	2016-11-21 17:53:30	2017-06-12 11:07:07
12727	DEMOCRATIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	\N	2016-11-21 17:53:36	2017-06-12 11:07:07
12728	DEMOCRATIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14249W	\N	2016-11-21 17:53:42	2017-06-12 11:07:07
12729	DEMOCRATIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14087W	\N	2016-11-21 17:53:49	2017-06-12 11:07:07
12730	DEMOCRATIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	04035D	\N	2016-11-21 17:53:54	2017-06-12 11:07:07
12731	DEMOCRATIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	95035G	\N	2016-11-21 17:53:59	2017-06-12 11:07:07
12732	DEMOCRATIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14031R	\N	2016-11-21 17:54:04	2017-06-12 11:07:07
12733	DEMOCRATIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	04057K	\N	2016-11-21 17:54:16	2017-06-12 11:07:07
12734	DEMOCRATIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14237S	\N	2016-11-21 17:54:23	2017-06-12 11:07:07
12735	DEMOCRATIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14135M	\N	2016-11-21 17:54:28	2017-06-12 11:07:07
12736	DEMOCRATIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	11029K	\N	2016-11-21 17:54:33	2017-06-12 11:07:07
12737	DEMOCRATIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	08021P	\N	2016-11-21 17:54:38	2017-06-12 11:07:07
12701	PSYCHIATRIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	11031D	\N	2016-11-21 17:46:52	2017-06-12 11:07:11
12703	PSYCHIATRIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14205J	\N	2016-11-21 17:47:04	2017-06-12 11:07:11
12704	PSYCHIATRIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14221J	\N	2016-11-21 17:47:10	2017-06-12 11:07:11
12705	PSYCHIATRIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	11094U	\N	2016-11-21 17:47:19	2017-06-12 11:07:11
12706	PSYCHIATRIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14239U	\N	2016-11-21 17:47:23	2017-06-12 11:07:11
12707	PSYCHIATRIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14195A	\N	2016-11-21 17:47:28	2017-06-12 11:07:11
12708	PSYCHIATRIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14217N	\N	2016-11-21 17:47:35	2017-06-12 11:07:11
12709	PSYCHIATRIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	\N	2016-11-21 17:47:40	2017-06-12 11:07:11
12710	PSYCHIATRIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	87003B	\N	2016-11-21 17:47:46	2017-06-12 11:07:11
12711	PSYCHIATRIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14213J	\N	2016-11-21 17:47:52	2017-06-12 11:07:11
12712	PSYCHIATRIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14147R	\N	2016-11-21 17:47:58	2017-06-12 11:07:11
12713	PSYCHIATRIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14223L	\N	2016-11-21 17:48:05	2017-06-12 11:07:11
12714	PSYCHIATRIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	\N	2016-11-21 17:48:09	2017-06-12 11:07:11
12715	PSYCHIATRIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14265W	\N	2016-11-21 17:48:17	2017-06-12 11:07:11
12716	PSYCHIATRIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14331P	\N	2016-11-21 17:49:32	2017-06-12 11:07:11
12717	PSYCHIATRIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	11097X	\N	2016-11-21 17:49:37	2017-06-12 11:07:11
12718	PSYCHIATRIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	11055M	\N	2016-11-21 17:49:43	2017-06-12 11:07:11
12283	REVENU	2016-05-18 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	11046L	\N	2016-05-17 17:45:18	2017-06-12 11:07:55
12286	REVENU	2016-05-18 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	\N	2016-05-17 17:45:39	2017-06-12 11:07:55
12166	TURQUIE	2016-04-27 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	14089Y	\N	2016-04-27 15:15:41	2017-06-12 11:08:26
12170	TURQUIE	2016-04-27 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	\N	2016-04-27 15:16:10	2017-06-12 11:08:26
12173	TURQUIE	2016-04-27 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	11015D	\N	2016-04-27 15:16:28	2017-06-12 11:08:26
12176	TURQUIE	2016-04-27 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	14097Y	\N	2016-04-27 15:16:43	2017-06-12 11:08:26
12179	TURQUIE	2016-04-27 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	92031P	\N	2016-04-27 15:17:03	2017-06-12 11:08:26
12586	VIGILANCE	2016-10-19 00:00:00	2016-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	2016-10-20 17:04:03	2016-11-03 17:03:58
12587	VIGILANCE	2016-10-19 00:00:00	2016-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	08018U	TITULAIRE	2016-10-20 17:04:08	2016-11-03 17:03:58
12588	VIGILANCE	2016-10-19 00:00:00	2016-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	TITULAIRE	2016-10-20 17:04:12	2016-11-03 17:03:58
12589	VIGILANCE	2016-10-19 00:00:00	2016-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	14205J	TITULAIRE	2016-10-20 17:04:19	2016-11-03 17:03:58
12590	VIGILANCE	2016-10-19 00:00:00	2016-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	14001X	TITULAIRE	2016-10-20 17:04:27	2016-11-03 17:03:58
12591	VIGILANCE	2016-10-19 00:00:00	2016-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	14151M	TITULAIRE	2016-10-20 17:04:33	2016-11-03 17:03:58
12592	VIGILANCE	2016-10-19 00:00:00	2016-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	11056N	TITULAIRE	2016-10-20 17:04:38	2016-11-03 17:03:58
12593	VIGILANCE	2016-10-19 00:00:00	2016-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	14065Q	SUPPLEANT	2016-10-20 17:04:43	2016-11-03 17:03:58
12594	VIGILANCE	2016-10-19 00:00:00	2016-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	14207L	SUPPLEANT	2016-10-20 17:04:47	2016-11-03 17:03:58
12595	VIGILANCE	2016-10-19 00:00:00	2016-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	2016-10-20 17:04:53	2016-11-03 17:03:58
12596	VIGILANCE	2016-10-19 00:00:00	2016-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	01024M	SUPPLEANT	2016-10-20 17:05:02	2016-11-03 17:03:58
12597	VIGILANCE	2016-10-19 00:00:00	2016-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	14147R	SUPPLEANT	2016-10-20 17:05:10	2016-11-03 17:03:58
12598	VIGILANCE	2016-10-19 00:00:00	2016-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	2016-10-20 17:05:18	2016-11-03 17:03:58
12599	VIGILANCE	2016-10-19 00:00:00	2016-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	SUPPLEANT	2016-10-20 17:05:24	2016-11-03 17:03:58
12616	NEANT	2016-11-18 00:00:00	2016-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	14355X	\N	2016-11-18 12:45:10	2016-11-30 10:35:16
12738	SCHENGEN	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14097Y	\N	2016-11-22 12:22:56	2017-06-12 11:06:53
12739	SCHENGEN	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	11084S	\N	2016-11-22 12:23:03	2017-06-12 11:06:53
12740	SCHENGEN	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	11026G	\N	2016-11-22 12:23:08	2017-06-12 11:06:53
12741	SCHENGEN	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14001X	\N	2016-11-22 12:23:17	2017-06-12 11:06:53
12816	NEANT	2016-12-11 00:00:00	2017-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	14361V	\N	2016-12-12 15:59:30	2017-01-24 18:11:28
12743	SCHENGEN	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	08053X	\N	2016-11-22 12:23:28	2017-06-12 11:06:53
12744	SCHENGEN	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14227Q	\N	2016-11-22 12:23:33	2017-06-12 11:06:53
12745	SCHENGEN	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	11066Q	\N	2016-11-22 12:23:39	2017-06-12 11:06:53
12746	ATTEINTES	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	80013X	\N	2016-11-22 12:24:05	2017-06-12 11:06:58
12747	ATTEINTES	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	11035H	\N	2016-11-22 12:24:11	2017-06-12 11:06:58
12749	DEMOCRATIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14207L	\N	2016-11-22 12:24:39	2017-06-12 11:07:07
12750	DEMOCRATIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	11095V	\N	2016-11-22 12:24:43	2017-06-12 11:07:07
12752	DEMOCRATIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14281W	\N	2016-11-22 12:24:56	2017-06-12 11:07:07
12754	DEMOCRATIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	11014C	\N	2016-11-22 12:25:12	2017-06-12 11:07:07
12755	DEMOCRATIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14229S	\N	2016-11-22 12:25:21	2017-06-12 11:07:07
12756	PSYCHIATRIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	08043V	\N	2016-11-22 12:27:59	2017-06-12 11:07:11
12757	PSYCHIATRIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	08024S	\N	2016-11-22 12:28:05	2017-06-12 11:07:11
12758	PSYCHIATRIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	\N	2016-11-22 12:28:10	2017-06-12 11:07:11
12760	PSYCHIATRIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14271U	\N	2016-11-22 12:28:24	2017-06-12 11:07:11
12761	PSYCHIATRIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	04045F	\N	2016-11-22 12:28:32	2017-06-12 11:07:11
9985	AFCL	2014-07-22 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	01037S	\N	2014-07-22 12:09:09	2016-12-12 16:10:15
12845	PLFR2016	2016-12-16 00:00:00	2016-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	TITULAIRE	2016-12-16 17:11:38	2016-12-21 14:17:50
12846	PLFR2016	2016-12-16 00:00:00	2016-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	08011M	TITULAIRE	2016-12-16 17:11:44	2016-12-21 14:17:51
12847	PLFR2016	2016-12-16 00:00:00	2016-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	TITULAIRE	2016-12-16 17:11:49	2016-12-21 14:17:51
12848	PLFR2016	2016-12-16 00:00:00	2016-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	14175V	TITULAIRE	2016-12-16 17:11:54	2016-12-21 14:17:51
12849	PLFR2016	2016-12-16 00:00:00	2016-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	11070L	TITULAIRE	2016-12-16 17:11:59	2016-12-21 14:17:51
12850	PLFR2016	2016-12-16 00:00:00	2016-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	TITULAIRE	2016-12-16 17:12:03	2016-12-21 14:17:51
12851	PLFR2016	2016-12-16 00:00:00	2016-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	98053W	TITULAIRE	2016-12-16 17:12:08	2016-12-21 14:17:51
12852	PLFR2016	2016-12-16 00:00:00	2016-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	11088W	SUPPLEANT	2016-12-16 17:12:13	2016-12-21 14:17:51
12853	PLFR2016	2016-12-16 00:00:00	2016-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	04071H	SUPPLEANT	2016-12-16 17:12:21	2016-12-21 14:17:51
12854	PLFR2016	2016-12-16 00:00:00	2016-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	99004R	SUPPLEANT	2016-12-16 17:12:29	2016-12-21 14:17:51
12855	PLFR2016	2016-12-16 00:00:00	2016-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	98046X	SUPPLEANT	2016-12-16 17:12:40	2016-12-21 14:17:51
12856	PLFR2016	2016-12-16 00:00:00	2016-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	11085T	SUPPLEANT	2016-12-16 17:12:48	2016-12-21 14:17:51
12857	PLFR2016	2016-12-16 00:00:00	2016-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	11012A	SUPPLEANT	2016-12-16 17:12:54	2016-12-21 14:17:51
12858	PLFR2016	2016-12-16 00:00:00	2016-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	11057P	SUPPLEANT	2016-12-16 17:13:04	2016-12-21 14:17:51
12862	CONSOMMATION	2017-01-12 00:00:00	2017-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	11100Y	TITULAIRE	2017-01-13 11:00:53	2017-01-18 10:55:00
12863	CONSOMMATION	2017-01-12 00:00:00	2017-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	TITULAIRE	2017-01-13 11:00:59	2017-01-18 10:55:00
12864	CONSOMMATION	2017-01-12 00:00:00	2017-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	14033T	TITULAIRE	2017-01-13 11:01:03	2017-01-18 10:55:00
12865	CONSOMMATION	2017-01-12 00:00:00	2017-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	11094U	TITULAIRE	2017-01-13 11:01:10	2017-01-18 10:55:00
12866	CONSOMMATION	2017-01-12 00:00:00	2017-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	08068F	TITULAIRE	2017-01-13 11:01:14	2017-01-18 10:55:00
12867	CONSOMMATION	2017-01-12 00:00:00	2017-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	11066Q	TITULAIRE	2017-01-13 11:01:19	2017-01-18 10:55:00
12868	CONSOMMATION	2017-01-12 00:00:00	2017-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	14013P	TITULAIRE	2017-01-13 11:01:24	2017-01-18 10:55:00
12869	CONSOMMATION	2017-01-12 00:00:00	2017-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	11036J	SUPPLEANT	2017-01-13 11:01:31	2017-01-18 10:55:00
12870	CONSOMMATION	2017-01-12 00:00:00	2017-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	11099A	SUPPLEANT	2017-01-13 11:01:36	2017-01-18 10:55:00
12871	CONSOMMATION	2017-01-12 00:00:00	2017-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	08015R	SUPPLEANT	2017-01-13 11:01:42	2017-01-18 10:55:00
12872	CONSOMMATION	2017-01-12 00:00:00	2017-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	01043Q	SUPPLEANT	2017-01-13 11:02:27	2017-01-18 10:55:00
12873	CONSOMMATION	2017-01-12 00:00:00	2017-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	11077T	SUPPLEANT	2017-01-13 11:02:33	2017-01-18 10:55:00
12874	CONSOMMATION	2017-01-12 00:00:00	2017-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	11090Q	SUPPLEANT	2017-01-13 11:02:37	2017-01-18 10:55:00
12875	CONSOMMATION	2017-01-12 00:00:00	2017-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	01058X	SUPPLEANT	2017-01-13 11:02:41	2017-01-18 10:55:00
12881	ANSM	2017-01-12 00:00:00	2017-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	TITULAIRE	2017-01-13 11:10:55	2017-01-18 10:55:07
12884	ANSM	2017-01-12 00:00:00	2017-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	14042U	TITULAIRE	2017-01-13 11:11:09	2017-01-18 10:55:07
12882	ANSM	2017-01-12 00:00:00	2017-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	TITULAIRE	2017-01-13 11:11:00	2017-01-18 10:55:07
12883	ANSM	2017-01-12 00:00:00	2017-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	14213J	TITULAIRE	2017-01-13 11:11:04	2017-01-18 10:55:07
12885	ANSM	2017-01-12 00:00:00	2017-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	TITULAIRE	2017-01-13 11:11:14	2017-01-18 10:55:07
12886	ANSM	2017-01-12 00:00:00	2017-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	11061K	TITULAIRE	2017-01-13 11:11:22	2017-01-18 10:55:07
12887	ANSM	2017-01-12 00:00:00	2017-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	TITULAIRE	2017-01-13 11:11:27	2017-01-18 10:55:07
12888	ANSM	2017-01-12 00:00:00	2017-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	10006L	SUPPLEANT	2017-01-13 11:11:34	2017-01-18 10:55:07
12889	ANSM	2017-01-12 00:00:00	2017-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	08041T	SUPPLEANT	2017-01-13 11:11:45	2017-01-18 10:55:07
12890	ANSM	2017-01-12 00:00:00	2017-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	11067R	SUPPLEANT	2017-01-13 11:11:56	2017-01-18 10:55:07
12891	ANSM	2017-01-12 00:00:00	2017-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	14223L	SUPPLEANT	2017-01-13 11:12:01	2017-01-18 10:55:07
12892	ANSM	2017-01-12 00:00:00	2017-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	14265W	SUPPLEANT	2017-01-13 11:12:06	2017-01-18 10:55:07
12893	ANSM	2017-01-12 00:00:00	2017-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	14227Q	SUPPLEANT	2017-01-13 11:12:11	2017-01-18 10:55:07
9842	PROSTITUTION	2014-01-22 00:00:00	2016-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	11031D	\N	2014-01-21 17:10:10	2016-07-07 18:15:08
9854	PROSTITUTION	2014-01-22 00:00:00	2016-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	97011G	\N	2014-01-21 17:15:20	2016-07-07 18:25:54
10273	PROSTITUTION	2014-10-09 00:00:00	2016-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	14014Q	\N	2014-10-09 16:25:08	2016-07-07 18:26:42
9855	PROSTITUTION	2014-01-22 00:00:00	2016-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	95035G	\N	2014-01-21 17:15:52	2016-07-07 18:29:03
10276	PROSTITUTION	2014-10-09 00:00:00	2016-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	14026U	\N	2014-10-09 16:26:24	2016-07-07 18:29:29
9870	PROSTITUTION	2014-01-22 00:00:00	2016-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	08017T	\N	2014-01-21 17:17:54	2016-07-07 18:30:57
10279	PROSTITUTION	2014-10-09 00:00:00	2016-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	14223L	\N	2014-10-09 16:27:41	2016-07-07 18:32:03
9845	PROSTITUTION	2014-01-22 00:00:00	2016-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	11093T	\N	2014-01-21 17:10:50	2016-07-07 18:33:03
10270	PROSTITUTION	2014-10-09 00:00:00	2016-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	\N	2014-10-09 16:23:34	2016-07-07 18:37:30
12529	URGENCE	2016-07-20 00:00:00	2016-07-20 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	2016-07-20 19:30:34	2016-10-07 09:17:16
12530	URGENCE	2016-07-20 00:00:00	2016-07-20 00:00:00	ANCIEN	\N	\N	\N	\N	95049N	TITULAIRE	2016-07-20 19:30:41	2016-10-07 09:17:16
12531	URGENCE	2016-07-20 00:00:00	2016-07-20 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	TITULAIRE	2016-07-20 19:30:47	2016-10-07 09:17:16
12532	URGENCE	2016-07-20 00:00:00	2016-07-20 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	TITULAIRE	2016-07-20 19:30:52	2016-10-07 09:17:16
12533	URGENCE	2016-07-20 00:00:00	2016-07-20 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	TITULAIRE	2016-07-20 19:30:57	2016-10-07 09:17:16
12534	URGENCE	2016-07-20 00:00:00	2016-07-20 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	TITULAIRE	2016-07-20 19:31:03	2016-10-07 09:17:16
12535	URGENCE	2016-07-20 00:00:00	2016-07-20 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	TITULAIRE	2016-07-20 19:31:08	2016-10-07 09:17:16
12536	URGENCE	2016-07-20 00:00:00	2016-07-20 00:00:00	ANCIEN	\N	\N	\N	\N	11113E	SUPPLEANT	2016-07-20 19:31:15	2016-10-07 09:17:16
12537	URGENCE	2016-07-20 00:00:00	2016-07-20 00:00:00	ANCIEN	\N	\N	\N	\N	08018U	SUPPLEANT	2016-07-20 19:31:21	2016-10-07 09:17:16
12538	URGENCE	2016-07-20 00:00:00	2016-07-20 00:00:00	ANCIEN	\N	\N	\N	\N	01007L	SUPPLEANT	2016-07-20 19:31:26	2016-10-07 09:17:16
12539	URGENCE	2016-07-20 00:00:00	2016-07-20 00:00:00	ANCIEN	\N	\N	\N	\N	11026G	SUPPLEANT	2016-07-20 19:31:31	2016-10-07 09:17:16
12540	URGENCE	2016-07-20 00:00:00	2016-07-20 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	SUPPLEANT	2016-07-20 19:31:37	2016-10-07 09:17:16
12541	URGENCE	2016-07-20 00:00:00	2016-07-20 00:00:00	ANCIEN	\N	\N	\N	\N	07034Q	SUPPLEANT	2016-07-20 19:31:42	2016-10-07 09:17:16
12542	URGENCE	2016-07-20 00:00:00	2016-07-20 00:00:00	ANCIEN	\N	\N	\N	\N	10015M	SUPPLEANT	2016-07-20 19:31:48	2016-10-07 09:17:16
12543	COMSPEAPU	2016-10-05 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	11083R	\N	2016-10-05 16:14:59	\N
12561	BREXIT	2016-07-13 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	04061F	\N	2016-10-07 09:12:09	2017-06-12 11:07:15
12552	BREXIT	2016-07-13 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	96004D	\N	2016-10-07 09:10:48	2017-06-12 11:07:15
12553	BREXIT	2016-07-13 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	11040E	\N	2016-10-07 09:10:53	2017-06-12 11:07:15
15476	ASAP	2020-02-06 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	19479G	\N	\N	\N
12554	BREXIT	2016-07-13 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	11083R	\N	2016-10-07 09:10:58	2017-06-12 11:07:15
12555	BREXIT	2016-07-13 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14001X	\N	2016-10-07 09:11:08	2017-06-12 11:07:15
12556	BREXIT	2016-07-13 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	04057K	\N	2016-10-07 09:11:17	2017-06-12 11:07:15
12562	BREXIT	2016-07-13 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	95059Q	\N	2016-10-07 09:12:17	2017-06-12 11:07:15
12563	BREXIT	2016-07-13 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	04040A	\N	2016-10-07 09:12:22	2017-06-12 11:07:15
12557	BREXIT	2016-07-13 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	04080J	\N	2016-10-07 09:11:23	2017-06-12 11:07:15
12558	BREXIT	2016-07-13 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	98035U	\N	2016-10-07 09:11:28	2017-06-12 11:07:15
12559	BREXIT	2016-07-13 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	\N	2016-10-07 09:11:34	2017-06-12 11:07:15
12560	BREXIT	2016-07-13 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14073Q	\N	2016-10-07 09:12:00	2017-06-12 11:07:15
12564	BREXIT	2016-07-13 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	04042C	\N	2016-10-07 09:12:27	2017-06-12 11:07:15
12566	BREXIT	2016-07-13 00:00:00	2016-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	07024N	\N	2016-10-07 09:12:37	2017-01-03 11:09:24
12567	BREXIT	2016-07-13 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14014Q	\N	2016-10-07 09:12:42	2017-06-12 11:07:15
12568	BREXIT	2016-07-13 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	98022P	\N	2016-10-07 09:12:47	2017-06-12 11:07:15
12569	BREXIT	2016-07-13 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14097Y	\N	2016-10-07 09:12:53	2017-06-12 11:07:15
12570	BREXIT	2016-07-13 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	83042R	\N	2016-10-07 09:12:58	2017-06-12 11:07:15
12571	BREXIT	2016-07-13 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	98021N	\N	2016-10-07 09:13:03	2017-06-12 11:07:15
12412	TELEPHONE	2016-06-22 00:00:00	2016-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11029K	\N	2016-06-22 16:43:11	2016-10-07 09:16:23
12415	TELEPHONE	2016-06-22 00:00:00	2016-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01015L	\N	2016-06-22 16:43:32	2016-10-07 09:16:23
12418	TELEPHONE	2016-06-22 00:00:00	2016-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14219Q	\N	2016-06-22 16:43:51	2016-10-07 09:16:23
12572	PLEC	2016-10-18 00:00:00	2016-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	11100Y	TITULAIRE	2016-10-19 10:53:41	2016-10-25 16:22:46
12573	PLEC	2016-10-18 00:00:00	2016-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	14187A	TITULAIRE	2016-10-19 10:53:47	2016-10-25 16:22:46
12574	PLEC	2016-10-18 00:00:00	2016-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	TITULAIRE	2016-10-19 10:53:52	2016-10-25 16:22:46
12575	PLEC	2016-10-18 00:00:00	2016-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	14231L	TITULAIRE	2016-10-19 10:53:57	2016-10-25 16:22:46
12576	PLEC	2016-10-18 00:00:00	2016-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	11104D	TITULAIRE	2016-10-19 10:54:02	2016-10-25 16:22:46
12577	PLEC	2016-10-18 00:00:00	2016-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	11046L	TITULAIRE	2016-10-19 10:54:08	2016-10-25 16:22:46
12578	PLEC	2016-10-18 00:00:00	2016-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	11034G	TITULAIRE	2016-10-19 10:54:13	2016-10-25 16:22:46
12579	PLEC	2016-10-18 00:00:00	2016-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	95015C	SUPPLEANT	2016-10-19 10:54:19	2016-10-25 16:22:46
12580	PLEC	2016-10-18 00:00:00	2016-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	04089T	SUPPLEANT	2016-10-19 10:54:23	2016-10-25 16:22:46
12581	PLEC	2016-10-18 00:00:00	2016-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	08031R	SUPPLEANT	2016-10-19 10:54:28	2016-10-25 16:22:46
12582	PLEC	2016-10-18 00:00:00	2016-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	11090Q	SUPPLEANT	2016-10-19 10:54:33	2016-10-25 16:22:46
12583	PLEC	2016-10-18 00:00:00	2016-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	SUPPLEANT	2016-10-19 10:54:39	2016-10-25 16:22:46
12584	PLEC	2016-10-18 00:00:00	2016-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	SUPPLEANT	2016-10-19 10:54:43	2016-10-25 16:22:46
12585	PLEC	2016-10-18 00:00:00	2016-10-25 00:00:00	ANCIEN	\N	\N	\N	\N	14157T	SUPPLEANT	2016-10-19 10:54:48	2016-10-25 16:22:46
12814	CAE	2016-12-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14357A	\N	2016-12-06 00:00:00	2017-10-04 00:00:00
12817	STATUT	2016-12-15 00:00:00	2016-12-21 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	2016-12-16 10:37:46	2016-12-21 14:17:28
12818	STATUT	2016-12-15 00:00:00	2016-12-21 00:00:00	ANCIEN	\N	\N	\N	\N	14259Y	TITULAIRE	2016-12-16 10:37:52	2016-12-21 14:17:28
12819	STATUT	2016-12-15 00:00:00	2016-12-21 00:00:00	ANCIEN	\N	\N	\N	\N	14069U	TITULAIRE	2016-12-16 10:37:57	2016-12-21 14:17:28
12820	STATUT	2016-12-15 00:00:00	2016-12-21 00:00:00	ANCIEN	\N	\N	\N	\N	04080J	TITULAIRE	2016-12-16 10:38:01	2016-12-21 14:17:28
12821	STATUT	2016-12-15 00:00:00	2016-12-21 00:00:00	ANCIEN	\N	\N	\N	\N	04079R	TITULAIRE	2016-12-16 10:38:05	2016-12-21 14:17:28
12822	STATUT	2016-12-15 00:00:00	2016-12-21 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	TITULAIRE	2016-12-16 10:38:12	2016-12-21 14:17:28
12823	STATUT	2016-12-15 00:00:00	2016-12-21 00:00:00	ANCIEN	\N	\N	\N	\N	11034G	TITULAIRE	2016-12-16 10:38:18	2016-12-21 14:17:28
12824	STATUT	2016-12-15 00:00:00	2016-12-21 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	2016-12-16 10:38:24	2016-12-21 14:17:28
12825	STATUT	2016-12-15 00:00:00	2016-12-21 00:00:00	ANCIEN	\N	\N	\N	\N	08018U	SUPPLEANT	2016-12-16 10:38:29	2016-12-21 14:17:28
12826	STATUT	2016-12-15 00:00:00	2016-12-21 00:00:00	ANCIEN	\N	\N	\N	\N	01007L	SUPPLEANT	2016-12-16 10:38:38	2016-12-21 14:17:28
12827	STATUT	2016-12-15 00:00:00	2016-12-21 00:00:00	ANCIEN	\N	\N	\N	\N	14111D	SUPPLEANT	2016-12-16 10:38:49	2016-12-21 14:17:28
12828	STATUT	2016-12-15 00:00:00	2016-12-21 00:00:00	ANCIEN	\N	\N	\N	\N	11072N	SUPPLEANT	2016-12-16 10:39:03	2016-12-21 14:17:28
12829	STATUT	2016-12-15 00:00:00	2016-12-21 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	SUPPLEANT	2016-12-16 10:39:10	2016-12-21 14:17:28
12830	STATUT	2016-12-15 00:00:00	2016-12-21 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	SUPPLEANT	2016-12-16 10:39:21	2016-12-21 14:17:28
12831	MONTAGNE	2016-12-13 00:00:00	2016-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	08009T	TITULAIRE	2016-12-16 10:41:45	2016-12-21 14:18:00
12832	MONTAGNE	2016-12-13 00:00:00	2016-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	14237S	TITULAIRE	2016-12-16 10:41:50	2016-12-21 14:18:00
12431	TELEPHONE	2016-06-22 00:00:00	2016-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01056V	\N	2016-06-22 16:45:12	2016-10-07 09:16:24
12789	SOCI	2016-11-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14355X	\N	2016-11-30 00:00:00	2017-10-04 00:00:00
12790	PLF2017	2016-11-29 00:00:00	2016-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	TITULAIRE	2016-11-30 12:10:47	2016-12-15 10:00:00
12791	PLF2017	2016-11-29 00:00:00	2016-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	08011M	TITULAIRE	2016-11-30 12:10:54	2016-12-15 10:00:00
12792	PLF2017	2016-11-29 00:00:00	2016-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	TITULAIRE	2016-11-30 12:11:00	2016-12-15 10:00:00
12793	PLF2017	2016-11-29 00:00:00	2016-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	11088W	TITULAIRE	2016-11-30 12:11:05	2016-12-15 10:00:00
12794	PLF2017	2016-11-29 00:00:00	2016-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	11070L	TITULAIRE	2016-11-30 12:11:11	2016-12-15 10:00:00
12795	PLF2017	2016-11-29 00:00:00	2016-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	11057P	TITULAIRE	2016-11-30 12:11:19	2016-12-15 10:00:00
12796	PLF2017	2016-11-29 00:00:00	2016-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	11040E	TITULAIRE	2016-11-30 12:11:25	2016-12-15 10:00:00
12797	PLF2017	2016-11-29 00:00:00	2016-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	11053K	SUPPLEANT	2016-11-30 12:11:30	2016-12-15 10:00:00
12798	PLF2017	2016-11-29 00:00:00	2016-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	04055H	SUPPLEANT	2016-11-30 12:11:38	2016-12-15 10:00:00
12799	PLF2017	2016-11-29 00:00:00	2016-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	04071H	SUPPLEANT	2016-11-30 12:11:47	2016-12-15 10:00:00
12800	PLF2017	2016-11-29 00:00:00	2016-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	99004R	SUPPLEANT	2016-11-30 12:11:56	2016-12-15 10:00:00
12801	PLF2017	2016-11-29 00:00:00	2016-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	98046X	SUPPLEANT	2016-11-30 12:12:10	2016-12-15 10:00:00
12802	PLF2017	2016-11-29 00:00:00	2016-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	11012A	SUPPLEANT	2016-11-30 12:12:20	2016-12-15 10:00:00
12803	PLF2017	2016-11-29 00:00:00	2016-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	SUPPLEANT	2016-11-30 12:12:29	2016-12-15 10:00:00
12811	CDGEXPRESS	2016-11-23 00:00:00	2016-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	11053K	SUPPLEANT	2016-12-01 10:41:05	2016-12-01 15:39:21
12833	MONTAGNE	2016-12-13 00:00:00	2016-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	01008M	TITULAIRE	2016-12-16 10:41:57	2016-12-21 14:18:00
12834	MONTAGNE	2016-12-13 00:00:00	2016-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	14265W	TITULAIRE	2016-12-16 10:42:02	2016-12-21 14:18:00
12835	MONTAGNE	2016-12-13 00:00:00	2016-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	14107H	TITULAIRE	2016-12-16 10:42:06	2016-12-21 14:18:00
12836	MONTAGNE	2016-12-13 00:00:00	2016-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	14197C	TITULAIRE	2016-12-16 10:42:11	2016-12-21 14:18:00
12837	MONTAGNE	2016-12-13 00:00:00	2016-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	01015L	TITULAIRE	2016-12-16 10:42:14	2016-12-21 14:18:00
12838	MONTAGNE	2016-12-13 00:00:00	2016-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	14261S	SUPPLEANT	2016-12-16 10:42:19	2016-12-21 14:18:00
12839	MONTAGNE	2016-12-13 00:00:00	2016-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	14038Y	SUPPLEANT	2016-12-16 10:42:27	2016-12-21 14:18:00
12840	MONTAGNE	2016-12-13 00:00:00	2016-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	14033T	SUPPLEANT	2016-12-16 10:42:35	2016-12-21 14:18:00
12841	MONTAGNE	2016-12-13 00:00:00	2016-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	14121F	SUPPLEANT	2016-12-16 10:42:43	2016-12-21 14:18:00
12842	MONTAGNE	2016-12-13 00:00:00	2016-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	14221J	SUPPLEANT	2016-12-16 10:42:53	2016-12-21 14:18:00
12843	MONTAGNE	2016-12-13 00:00:00	2016-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	SUPPLEANT	2016-12-16 10:43:03	2016-12-21 14:18:00
12844	MONTAGNE	2016-12-13 00:00:00	2016-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	SUPPLEANT	2016-12-16 10:43:07	2016-12-21 14:18:00
12860	AFCL	2017-01-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14363X	\N	2017-01-10 18:00:19	2017-09-24 19:25:10
12861	ETRD	2017-01-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14133K	\N	2017-01-10 00:00:00	2017-10-04 00:00:00
12894	ANSM	2017-01-12 00:00:00	2017-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	01034P	SUPPLEANT	2017-01-13 11:12:16	2017-01-18 10:55:07
12895	ANSP	2017-01-12 00:00:00	2017-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	TITULAIRE	2017-01-13 11:17:55	2017-01-18 10:55:04
12896	ANSP	2017-01-12 00:00:00	2017-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	TITULAIRE	2017-01-13 11:18:00	2017-01-18 10:55:04
12897	ANSP	2017-01-12 00:00:00	2017-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	14213J	TITULAIRE	2017-01-13 11:18:04	2017-01-18 10:55:04
12898	ANSP	2017-01-12 00:00:00	2017-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	14042U	TITULAIRE	2017-01-13 11:18:09	2017-01-18 10:55:04
12899	ANSP	2017-01-12 00:00:00	2017-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	TITULAIRE	2017-01-13 11:18:14	2017-01-18 10:55:04
12900	ANSP	2017-01-12 00:00:00	2017-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	11061K	TITULAIRE	2017-01-13 11:18:18	2017-01-18 10:55:04
12901	ANSP	2017-01-12 00:00:00	2017-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	TITULAIRE	2017-01-13 11:18:22	2017-01-18 10:55:04
12902	ANSP	2017-01-12 00:00:00	2017-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	10006L	SUPPLEANT	2017-01-13 11:18:27	2017-01-18 10:55:04
12903	ANSP	2017-01-12 00:00:00	2017-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	08041T	SUPPLEANT	2017-01-13 11:18:34	2017-01-18 10:55:04
12904	ANSP	2017-01-12 00:00:00	2017-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	11067R	SUPPLEANT	2017-01-13 11:18:38	2017-01-18 10:55:04
12905	ANSP	2017-01-12 00:00:00	2017-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	14223L	SUPPLEANT	2017-01-13 11:18:44	2017-01-18 10:55:04
12906	ANSP	2017-01-12 00:00:00	2017-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	14265W	SUPPLEANT	2017-01-13 11:18:49	2017-01-18 10:55:04
12907	ANSP	2017-01-12 00:00:00	2017-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	14227Q	SUPPLEANT	2017-01-13 11:18:53	2017-01-18 10:55:04
12908	ANSP	2017-01-12 00:00:00	2017-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	01034P	SUPPLEANT	2017-01-13 11:18:57	2017-01-18 10:55:04
12923	AFCL	2017-01-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14361V	\N	2017-01-24 18:11:26	2017-09-24 18:23:22
13027	NEANT	2017-06-05 00:00:00	2017-06-14 00:00:00	ANCIEN	\N	\N	\N	\N	07028S	\N	2017-06-07 15:17:54	2017-06-19 16:13:09
12953	BREXIT	2017-01-18 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14133K	\N	2017-02-06 16:37:27	2017-06-12 11:07:15
13024	TRANSPARENCE	2016-07-13 00:00:00	2016-09-14 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
13025	TRANSPARENCE	2016-07-13 00:00:00	2016-09-14 00:00:00	ANCIEN	\N	\N	\N	\N	07034Q	TITULAIRE	\N	\N
12182	TURQUIE	2016-04-27 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	08053X	\N	2016-04-27 15:17:23	2017-06-12 11:08:26
12186	TURQUIE	2016-04-27 00:00:00	2016-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	14331P	\N	2016-04-27 15:17:45	2017-06-12 11:08:26
12477	EGALITE	2016-07-07 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	04035D	\N	2016-07-07 17:25:15	2017-06-12 11:07:18
12143	CHOMAGE	2016-04-27 00:00:00	2016-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	\N	2016-04-27 14:58:16	2017-06-12 11:08:12
12748	DEMOCRATIE	2016-11-22 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14065Q	\N	2016-11-22 12:24:33	2017-06-12 11:07:07
12565	BREXIT	2016-07-13 00:00:00	2017-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	04035D	\N	2016-10-07 09:12:32	2017-06-12 11:07:15
10409	2014CMP7	2014-04-30 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	SUPPLEANT	\N	2017-06-19 12:20:59
11584	2015CMP15	2015-07-25 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	SUPPLEANT	\N	2017-06-19 12:20:59
13029	NEANT	2017-06-18 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	11041F	\N	2017-06-19 15:52:41	2017-06-28 09:51:15
9940	ETRD	2014-05-13 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	14014Q	\N	2014-05-13 14:42:54	2017-06-19 16:06:51
11721	2015CMP25	2015-10-15 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	14014Q	SUPPLEANT	\N	2017-06-19 16:06:51
13031	NEANT	2017-06-18 00:00:00	2018-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	19251M	\N	2017-06-19 16:45:46	2017-06-28 09:51:57
13032	NEANT	2017-06-18 00:00:00	2019-03-04 00:00:00	ANCIEN	\N	\N	\N	\N	19253P	\N	2017-06-19 16:48:14	2017-06-27 16:48:49
13044	COMSPEAPU	2017-07-11 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08049C	\N	2017-07-12 17:43:49	\N
13034	NEANT	2017-06-15 00:00:00	2017-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	16813M	\N	2017-06-19 17:55:47	2017-06-22 12:18:21
13035	FINC	2017-06-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14253S	\N	2017-06-20 00:00:00	2017-10-04 00:00:00
13036	LOIS	2017-06-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	16813M	\N	2017-06-22 12:18:21	2017-09-24 18:16:52
13037	LOIS	2017-06-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19253P	\N	2017-06-27 16:48:48	2017-10-04 19:43:42
13042	AFCL	2017-07-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	18127E	\N	2017-07-10 16:44:14	2017-09-24 18:16:52
13049	DIALOGUE	2017-07-26 00:00:00	2017-08-01 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	TITULAIRE	2017-07-27 11:23:30	2017-08-03 12:18:38
13046	SOCI	2017-07-26 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19269X	\N	2017-07-26 15:50:27	2017-10-04 19:01:46
13050	DIALOGUE	2017-07-26 00:00:00	2017-08-01 00:00:00	ANCIEN	\N	\N	\N	\N	14265W	TITULAIRE	2017-07-27 11:23:38	2017-08-03 12:18:38
13051	DIALOGUE	2017-07-26 00:00:00	2017-08-01 00:00:00	ANCIEN	\N	\N	\N	\N	14071N	TITULAIRE	2017-07-27 11:23:43	2017-08-03 12:18:38
13094	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	17583W	\N	2017-09-24 17:04:01	2017-10-04 18:57:19
10492	2014CMP14	2014-05-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01056V	SUPPLEANT	\N	2017-09-24 17:04:02
13098	NEANT	2017-10-02 00:00:00	2017-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	19545Y	\N	2017-09-24 17:09:23	2017-10-05 14:54:12
13099	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19549D	\N	2017-09-24 17:09:23	2017-10-04 18:53:33
13100	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19533U	\N	2017-09-24 17:09:23	2017-10-04 18:46:18
10244	AFEU	2014-10-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	\N	2014-10-09 10:41:39	2017-09-24 17:09:24
11580	2015CMP15	2015-07-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11030C	SUPPLEANT	\N	2017-09-24 17:09:24
13101	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	16685X	\N	2017-09-24 17:14:26	2017-10-04 18:54:36
9438	2013CMP8	2013-06-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01022K	TITULAIRE	\N	2017-09-24 17:14:26
12083	BLEUE	2016-04-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11098Y	TITULAIRE	2016-04-04 15:23:17	2017-09-24 17:14:26
13107	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19675J	\N	2017-09-24 17:18:02	2017-10-04 19:00:50
13111	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19421M	\N	2017-09-24 17:28:55	2017-10-04 18:56:09
9489	2013CMP11	2013-07-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01027Q	SUPPLEANT	\N	2017-09-24 17:28:55
11551	COMSPEAPU	2015-12-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01027Q	\N	2015-12-16 17:20:12	2017-09-24 17:28:55
13118	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19527W	\N	2017-09-24 17:42:25	2017-10-04 19:01:04
13119	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19521Q	\N	2017-09-24 17:42:25	2017-10-04 18:55:38
13120	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19525U	\N	2017-09-24 17:42:25	2017-10-04 18:54:27
13121	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19681G	\N	2017-09-24 17:42:25	2017-10-04 18:54:18
9678	2013CMP27	2013-11-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11061K	SUPPLEANT	\N	2017-09-24 17:42:25
10387	2014CMP6	2014-02-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11061K	TITULAIRE	\N	2017-09-24 17:42:25
10653	2014CMP26	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11061K	TITULAIRE	\N	2017-09-24 17:42:25
11625	2015CMP18	2015-07-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11061K	SUPPLEANT	\N	2017-09-24 17:42:25
11767	2015CMP28	2015-11-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11061K	SUPPLEANT	\N	2017-09-24 17:42:25
11664	2015CMP21	2015-10-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11061K	TITULAIRE	\N	2017-09-24 17:42:25
11698	2015CMP23	2015-10-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	13002U	SUPPLEANT	\N	2017-09-24 17:42:26
13122	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19649G	\N	2017-09-24 17:47:26	2017-10-04 19:10:08
13124	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19643A	\N	2017-09-24 17:47:26	2017-10-04 18:39:55
13125	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19683J	\N	2017-09-24 17:47:26	2017-10-04 18:57:07
10491	2014CMP14	2014-05-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04080J	SUPPLEANT	\N	2017-09-24 17:47:27
8209	LOIS	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04079R	\N	\N	2017-09-24 17:47:27
10135	ETRD	2014-10-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04077P	\N	2014-10-08 17:01:06	2017-09-24 17:47:27
10391	2014CMP6	2014-02-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	09001P	TITULAIRE	\N	2017-09-24 17:47:27
10500	2014CMP12	2014-05-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04067M	SUPPLEANT	\N	2017-09-24 17:47:27
8384	2011CMP27	2011-12-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04066L	TITULAIRE	\N	2017-09-24 17:47:28
9106	2012CMP26	2012-12-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04066L	TITULAIRE	\N	2017-09-24 17:47:28
9468	2013CMP10	2013-07-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04066L	TITULAIRE	\N	2017-09-24 17:47:28
9721	2013CMP28	2013-11-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04066L	TITULAIRE	\N	2017-09-24 17:47:28
10609	2014CMP23	2014-07-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04066L	TITULAIRE	\N	2017-09-24 17:47:28
11608	2015CMP17	2015-07-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11076S	SUPPLEANT	\N	2017-09-24 17:47:28
13129	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19687N	\N	2017-09-24 17:55:12	2017-10-04 18:45:46
13130	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19611R	\N	2017-09-24 17:55:12	2017-10-04 18:43:50
13131	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19689Q	\N	2017-09-24 17:55:12	2017-10-04 18:45:52
12051	DEONTOLOGIE	2016-03-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11034G	TITULAIRE	2016-03-11 15:00:42	2017-09-24 17:55:12
13132	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19289C	\N	2017-09-24 18:05:40	2017-10-04 18:56:08
13133	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19691J	\N	2017-09-24 18:05:40	2017-10-04 18:56:13
13134	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19399H	\N	2017-09-24 18:05:40	2017-10-04 18:43:08
13135	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19693L	\N	2017-09-24 18:05:40	2017-10-04 18:40:53
13138	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19329S	\N	2017-09-24 18:16:33	2017-10-04 18:42:53
13151	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19387D	\N	2017-09-24 18:20:09	2017-10-04 18:55:13
13152	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19383Y	\N	2017-09-24 18:20:09	2017-10-04 18:53:56
2273	20040415N5	2004-04-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	TITULAIRE	\N	2017-09-24 18:20:10
9474	2013CMP10	2013-07-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	SUPPLEANT	\N	2017-09-24 18:20:10
10443	2014CMP10	2014-05-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	SUPPLEANT	\N	2017-09-24 18:20:10
10736	2014CMP32	2014-12-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	TITULAIRE	\N	2017-09-24 18:20:10
10595	2014CMP22	2014-07-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	TITULAIRE	\N	2017-09-24 18:20:10
11587	2015CMP16	2015-07-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	TITULAIRE	\N	2017-09-24 18:20:10
11816	2015CMP32	2015-12-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	TITULAIRE	\N	2017-09-24 18:20:10
8969	ETRD	2012-11-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11105E	\N	\N	2017-09-24 18:20:10
13158	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	18083K	\N	2017-09-24 18:44:44	2017-10-04 18:54:10
13160	NEANT	2017-09-25 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19575F	\N	2017-09-24 18:51:50	2017-10-04 18:54:05
13166	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19563B	\N	2017-09-24 19:16:18	2017-10-04 19:08:06
13169	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19367Y	\N	2017-09-24 19:19:07	2017-10-04 18:54:25
13170	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	17637T	\N	2017-09-24 19:25:09	2017-10-04 18:56:58
13171	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19711U	\N	2017-09-24 19:25:09	2017-10-04 18:44:55
13172	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19591F	\N	2017-09-24 19:25:09	2017-10-04 19:04:26
13173	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19593H	\N	2017-09-24 19:25:09	2017-10-04 18:46:03
3898	2008CMP1	2008-01-24 00:00:00	2008-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	04081K	TITULAIRE	\N	2017-09-24 19:25:10
8780	2012CMP10	2012-02-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04081K	TITULAIRE	\N	2017-09-24 19:25:10
9724	2013CMP28	2013-11-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04081K	TITULAIRE	\N	2017-09-24 19:25:10
13176	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19531S	\N	2017-09-24 19:31:54	2017-10-04 18:43:54
13177	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19713W	\N	2017-09-24 19:31:54	2017-10-04 18:57:28
9420	2013CMP6	2013-04-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	12042Y	SUPPLEANT	\N	2017-09-24 19:31:54
10482	2014CMP13	2014-05-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	12042Y	TITULAIRE	\N	2017-09-24 19:31:54
11797	2015CMP30	2015-11-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	12042Y	SUPPLEANT	\N	2017-09-24 19:31:54
13184	NEANT	2017-10-01 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19719D	\N	2017-10-01 09:26:48	2017-10-04 19:10:14
8085	AFCL	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11104D	\N	\N	2017-10-04 00:00:00
10454	2014CMP11	2014-05-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92015P	SUPPLEANT	\N	2017-09-24 13:14:55
9443	2013CMP8	2013-06-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11094U	TITULAIRE	\N	2017-09-24 13:25:54
7978	2011CMP20	2011-07-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	SUPPLEANT	\N	2017-09-24 13:44:49
9278	2013CMP4	2013-04-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	SUPPLEANT	\N	2017-09-24 13:44:49
10614	2014CMP23	2014-07-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	SUPPLEANT	\N	2017-09-24 13:44:49
11667	2015CMP21	2015-10-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	SUPPLEANT	\N	2017-09-24 13:44:49
7914	2011CMP15	2011-06-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	SUPPLEANT	\N	2017-09-24 13:29:42
9029	2012CMP22	2012-11-27 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08022Q	SUPPLEANT	\N	2017-10-01 09:41:22
13185	NEANT	2017-10-01 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19721W	\N	2017-10-01 09:45:12	2017-10-04 18:50:26
8927	2012CMP16	2012-09-27 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	90003B	SUPPLEANT	\N	2017-10-01 10:01:39
8694	CAE	2012-02-21 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	90003B	\N	\N	2017-10-01 10:01:39
10360	2014CMP3	2014-01-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	90003B	SUPPLEANT	\N	2017-10-01 10:01:39
13186	NEANT	2017-10-01 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19723Y	\N	2017-10-01 10:06:58	2017-10-04 18:57:20
8447	2012CMP3	2012-01-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08025T	SUPPLEANT	\N	2017-10-01 10:17:18
8546	2012CMP8	2012-02-08 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08025T	TITULAIRE	\N	2017-10-01 10:17:18
11734	2015CMP26	2015-11-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08025T	SUPPLEANT	\N	2017-10-01 10:17:18
10121	FINC	2014-10-08 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14167V	\N	2014-10-08 16:55:32	2017-10-01 10:18:28
10569	2014CMP21	2014-07-10 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08042U	TITULAIRE	\N	2017-10-01 10:20:50
10108	CDD	2014-10-08 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14247U	\N	2014-10-08 16:52:08	2017-10-01 10:25:16
8830	AFCL	2012-07-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98042T	\N	\N	2017-10-01 10:39:22
10638	2014CMP25	2014-10-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95049N	TITULAIRE	\N	2017-10-01 10:42:05
10913	2015CMP3	2015-01-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95049N	TITULAIRE	2015-01-30 14:38:31	2017-10-01 10:42:05
11774	2015CMP29	2015-11-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95049N	TITULAIRE	\N	2017-10-01 10:42:05
11577	2015CMP15	2015-07-25 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95049N	TITULAIRE	\N	2017-10-01 10:42:05
13187	NEANT	2017-10-01 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19725B	\N	2017-10-01 10:44:23	2017-10-04 19:10:41
13188	NEANT	2017-10-01 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19727D	\N	2017-10-01 10:54:01	2017-10-04 18:55:56
13189	NEANT	2017-10-01 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19729F	\N	2017-10-01 11:03:20	2017-10-04 19:11:27
13190	NEANT	2017-10-01 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19731Y	\N	2017-10-01 11:13:13	2017-10-04 18:43:29
13191	NEANT	2017-10-01 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19733B	\N	2017-10-01 11:41:24	2017-10-04 18:53:49
13192	NEANT	2017-10-01 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19735D	\N	2017-10-01 11:48:00	2017-10-05 12:49:33
13193	NEANT	2017-10-01 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19737F	\N	2017-10-01 11:57:14	2017-10-04 18:57:36
10142	AFCL	2014-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14229S	\N	2014-10-08 00:00:00	2017-10-04 00:00:00
13536	CAE	2017-10-04 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14115H	\N	2017-10-04 20:31:04	\N
13537	CAE	2017-10-05 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04043D	\N	2017-10-04 20:33:13	2017-10-05 14:30:08
13574	AFEU	2017-10-24 00:00:00	2020-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14205J	\N	2017-10-24 11:23:00	\N
13577	ENVIRONNEMEN	2017-10-31 00:00:00	2017-12-21 00:00:00	ANCIEN	\N	\N	\N	\N	08009T	TITULAIRE	2017-11-08 14:25:30	2017-12-21 10:15:39
13078	LOIS	2017-08-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19285X	\N	2017-08-01 14:55:02	2017-09-24 17:55:12
13578	ENVIRONNEMEN	2017-10-31 00:00:00	2017-12-21 00:00:00	ANCIEN	\N	\N	\N	\N	02002K	TITULAIRE	2017-11-08 14:25:34	2017-12-21 10:15:39
13579	ENVIRONNEMEN	2017-10-31 00:00:00	2017-12-21 00:00:00	ANCIEN	\N	\N	\N	\N	98023Q	TITULAIRE	2017-11-08 14:25:41	2017-12-21 10:15:39
13580	ENVIRONNEMEN	2017-10-31 00:00:00	2017-12-21 00:00:00	ANCIEN	\N	\N	\N	\N	18083K	TITULAIRE	2017-11-08 14:25:46	2017-12-21 10:15:39
13581	ENVIRONNEMEN	2017-10-31 00:00:00	2017-12-21 00:00:00	ANCIEN	\N	\N	\N	\N	14051J	TITULAIRE	2017-11-08 14:25:52	2017-12-21 10:15:39
13582	ENVIRONNEMEN	2017-10-31 00:00:00	2017-12-21 00:00:00	ANCIEN	\N	\N	\N	\N	19551W	TITULAIRE	2017-11-08 14:25:58	2017-12-21 10:15:39
13583	ENVIRONNEMEN	2017-10-31 00:00:00	2017-12-21 00:00:00	ANCIEN	\N	\N	\N	\N	11065P	TITULAIRE	2017-11-08 14:26:02	2017-12-21 10:15:39
13584	ENVIRONNEMEN	2017-10-31 00:00:00	2017-12-21 00:00:00	ANCIEN	\N	\N	\N	\N	08055A	SUPPLEANT	2017-11-08 14:26:07	2017-12-21 10:15:39
13585	ENVIRONNEMEN	2017-10-31 00:00:00	2017-12-21 00:00:00	ANCIEN	\N	\N	\N	\N	14089Y	SUPPLEANT	2017-11-08 14:26:15	2017-12-21 10:15:39
13586	ENVIRONNEMEN	2017-10-31 00:00:00	2017-12-21 00:00:00	ANCIEN	\N	\N	\N	\N	19733B	SUPPLEANT	2017-11-08 14:26:22	2017-12-21 10:15:39
13587	ENVIRONNEMEN	2017-10-31 00:00:00	2017-12-21 00:00:00	ANCIEN	\N	\N	\N	\N	19347U	SUPPLEANT	2017-11-08 14:26:28	2017-12-21 10:15:39
13588	ENVIRONNEMEN	2017-10-31 00:00:00	2017-12-21 00:00:00	ANCIEN	\N	\N	\N	\N	14031R	SUPPLEANT	2017-11-08 14:26:36	2017-12-21 10:15:39
13589	ENVIRONNEMEN	2017-10-31 00:00:00	2017-12-21 00:00:00	ANCIEN	\N	\N	\N	\N	19637C	SUPPLEANT	2017-11-08 14:26:48	2017-12-21 10:15:39
13590	ENVIRONNEMEN	2017-10-31 00:00:00	2017-12-21 00:00:00	ANCIEN	\N	\N	\N	\N	14157T	SUPPLEANT	2017-11-08 14:26:55	2017-12-21 10:15:39
13694	PARIS	2017-12-01 00:00:00	2017-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	2017-12-01 16:42:07	2017-12-07 10:07:02
13695	PARIS	2017-12-01 00:00:00	2017-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	14259Y	TITULAIRE	2017-12-01 16:42:13	2017-12-07 10:07:02
13696	PARIS	2017-12-01 00:00:00	2017-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	TITULAIRE	2017-12-01 16:42:18	2017-12-07 10:07:02
13697	PARIS	2017-12-01 00:00:00	2017-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	11085T	TITULAIRE	2017-12-01 16:42:24	2017-12-07 10:07:02
13698	PARIS	2017-12-01 00:00:00	2017-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	19649G	TITULAIRE	2017-12-01 16:42:29	2017-12-07 10:07:02
13699	PARIS	2017-12-01 00:00:00	2017-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	19591F	TITULAIRE	2017-12-01 16:42:35	2017-12-07 10:07:02
13700	PARIS	2017-12-01 00:00:00	2017-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	19651A	TITULAIRE	2017-12-01 16:42:41	2017-12-07 10:07:02
13701	PARIS	2017-12-01 00:00:00	2017-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	14069U	SUPPLEANT	2017-12-01 16:42:48	2017-12-07 10:07:02
13702	PARIS	2017-12-01 00:00:00	2017-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	19719D	SUPPLEANT	2017-12-01 16:42:53	2017-12-07 10:07:02
13703	PARIS	2017-12-01 00:00:00	2017-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	SUPPLEANT	2017-12-01 16:42:58	2017-12-07 10:07:02
13704	PARIS	2017-12-01 00:00:00	2017-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	01024M	SUPPLEANT	2017-12-01 16:43:07	2017-12-07 10:07:02
13705	PARIS	2017-12-01 00:00:00	2017-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	19447X	SUPPLEANT	2017-12-01 16:43:15	2017-12-07 10:07:02
13706	PARIS	2017-12-01 00:00:00	2017-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	19593H	SUPPLEANT	2017-12-01 16:43:20	2017-12-07 10:07:02
13707	PARIS	2017-12-01 00:00:00	2017-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	SUPPLEANT	2017-12-01 16:43:24	2017-12-07 10:07:02
13736	PLFP2018	2017-12-13 00:00:00	2017-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	19651A	SUPPLEANT	2017-12-14 10:54:20	2017-12-20 10:15:11
13737	PLFR2017_2	2017-12-14 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	TITULAIRE	2017-12-18 09:21:26	2017-12-20 10:16:50
13738	PLFR2017_2	2017-12-14 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	11074Q	TITULAIRE	2017-12-18 09:21:41	2017-12-20 10:16:50
13739	PLFR2017_2	2017-12-14 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	08011M	TITULAIRE	2017-12-18 09:21:46	2017-12-20 10:16:50
13740	PLFR2017_2	2017-12-14 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	19711U	TITULAIRE	2017-12-18 09:21:51	2017-12-20 10:16:50
13741	PLFR2017_2	2017-12-14 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	11053K	TITULAIRE	2017-12-18 09:21:55	2017-12-20 10:16:50
13742	PLFR2017_2	2017-12-14 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	19689Q	TITULAIRE	2017-12-18 09:22:01	2017-12-20 10:16:50
13743	PLFR2017_2	2017-12-14 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	19651A	TITULAIRE	2017-12-18 09:22:07	2017-12-20 10:16:50
13744	PLFR2017_2	2017-12-14 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	11040E	SUPPLEANT	2017-12-18 09:22:12	2017-12-20 10:16:50
13745	PLFR2017_2	2017-12-14 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	88008L	SUPPLEANT	2017-12-18 09:22:16	2017-12-20 10:16:50
13746	PLFR2017_2	2017-12-14 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	14327T	SUPPLEANT	2017-12-18 09:22:21	2017-12-20 10:16:50
13080	NEANT	2017-08-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	12035A	\N	2017-08-07 17:15:07	2017-09-24 17:18:03
13081	NEANT	2017-09-22 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	15447F	\N	2017-09-22 10:59:04	2017-10-04 18:55:06
13091	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19333N	\N	2017-09-24 16:43:41	2017-10-04 18:55:38
13092	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19619A	\N	2017-09-24 16:45:25	2017-10-04 19:06:20
13093	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19621T	\N	2017-09-24 16:45:25	2017-10-04 18:40:00
9729	2013CMP28	2013-11-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11112D	SUPPLEANT	\N	2017-09-24 16:45:26
10398	2014CMP6	2014-02-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11112D	SUPPLEANT	\N	2017-09-24 16:45:26
10617	2014CMP23	2014-07-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11112D	SUPPLEANT	\N	2017-09-24 16:45:26
11787	2015CMP30	2015-11-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11112D	TITULAIRE	\N	2017-09-24 16:45:26
8716	CAE	2012-02-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11111C	\N	\N	2017-09-24 16:45:26
13095	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19443T	\N	2017-09-24 17:06:55	2017-10-04 18:55:46
13096	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19441R	\N	2017-09-24 17:06:55	2017-10-04 19:04:56
13097	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19515S	\N	2017-09-24 17:06:55	2017-10-04 19:02:31
11791	2015CMP30	2015-11-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14271U	TITULAIRE	\N	2017-09-24 17:06:55
11671	2015CMP21	2015-10-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14271U	SUPPLEANT	\N	2017-09-24 17:06:55
8811	2012CMP12	2012-02-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11107G	SUPPLEANT	\N	2017-09-24 17:06:55
11691	2015CMP23	2015-10-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11107G	TITULAIRE	\N	2017-09-24 17:06:55
12088	BLEUE	2016-04-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11107G	TITULAIRE	2016-04-04 15:47:45	2017-09-24 17:06:55
13104	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19669L	\N	2017-09-24 17:15:14	2017-10-04 18:56:23
13105	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19671E	\N	2017-09-24 17:15:14	2017-10-04 18:45:15
13106	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19673G	\N	2017-09-24 17:15:14	2017-10-04 19:10:26
12057	DEONTOLOGIE	2016-03-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04074L	SUPPLEANT	2016-03-11 15:01:54	2017-09-24 17:15:15
10490	2014CMP14	2014-05-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04078Q	SUPPLEANT	\N	2017-09-24 17:15:15
8387	2011CMP27	2011-12-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11088W	TITULAIRE	\N	2017-09-24 17:15:15
9485	2013CMP11	2013-07-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11088W	TITULAIRE	\N	2017-09-24 17:15:15
10441	2014CMP10	2014-05-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11088W	TITULAIRE	\N	2017-09-24 17:15:15
10657	2014CMP26	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11088W	SUPPLEANT	\N	2017-09-24 17:15:15
10713	2014CMP30	2014-11-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11088W	TITULAIRE	\N	2017-09-24 17:15:15
13109	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19551W	\N	2017-09-24 17:19:41	2017-10-04 18:55:47
13110	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19553Y	\N	2017-09-24 17:19:41	2017-10-04 18:56:31
10565	2014CMP20	2014-07-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01015L	SUPPLEANT	\N	2017-09-24 17:19:42
13112	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19573D	\N	2017-09-24 17:29:36	2017-10-04 18:46:10
13113	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19677L	\N	2017-09-24 17:29:36	2017-10-04 18:56:02
13114	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	11115U	\N	2017-09-24 17:29:36	2017-10-04 18:51:02
13115	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19349W	\N	2017-09-24 17:35:13	2017-10-04 18:45:29
13116	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19679N	\N	2017-09-24 17:35:13	2017-10-04 18:59:46
13117	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19347U	\N	2017-09-24 17:35:13	2017-10-04 18:55:19
7979	2011CMP20	2011-07-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	SUPPLEANT	\N	2017-09-24 17:35:15
9669	2013CMP27	2013-11-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	TITULAIRE	\N	2017-09-24 17:35:15
10654	2014CMP26	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	TITULAIRE	\N	2017-09-24 17:35:15
13127	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19335Q	\N	2017-09-24 17:48:20	2017-10-04 18:59:31
13128	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19685L	\N	2017-09-24 17:48:20	2017-10-04 18:55:32
13136	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19695N	\N	2017-09-24 18:07:56	2017-10-04 19:04:00
13137	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19663E	\N	2017-09-24 18:07:56	2017-10-04 18:54:58
8157	SOCI	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11055M	\N	\N	2017-09-24 18:07:57
9726	2013CMP28	2013-11-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11055M	SUPPLEANT	\N	2017-09-24 18:07:57
10370	2014CMP4	2014-02-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11055M	SUPPLEANT	\N	2017-09-24 18:07:57
10613	2014CMP23	2014-07-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11055M	SUPPLEANT	\N	2017-09-24 18:07:57
11666	2015CMP21	2015-10-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11055M	SUPPLEANT	\N	2017-09-24 18:07:57
13139	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14021P	\N	2017-09-24 18:16:50	2017-10-04 19:11:04
13140	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19637C	\N	2017-09-24 18:16:50	2017-10-04 18:56:36
13141	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19599P	\N	2017-09-24 18:16:50	2017-10-04 18:54:59
13142	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	17589D	\N	2017-09-24 18:16:51	2017-10-04 19:03:32
13143	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19581D	\N	2017-09-24 18:16:51	2017-10-04 19:11:33
13144	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19569H	\N	2017-09-24 18:16:51	2017-10-04 18:56:43
13145	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19565D	\N	2017-09-24 18:16:51	2017-10-04 19:04:07
13146	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19585H	\N	2017-09-24 18:16:51	2017-10-04 19:11:49
13147	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	04008A	\N	2017-09-24 18:16:51	2017-10-04 19:09:59
11636	2015CMP19	2015-09-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11039M	SUPPLEANT	\N	2017-09-24 18:16:52
8685	CAE	2012-02-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11036J	\N	\N	2017-09-24 18:16:52
8442	2012CMP3	2012-01-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11035H	TITULAIRE	\N	2017-09-24 18:16:52
8421	2012CMP1	2011-12-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11035H	SUPPLEANT	\N	2017-09-24 18:16:52
10407	2014CMP7	2014-04-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11035H	SUPPLEANT	\N	2017-09-24 18:16:52
3338	20060615N48	2006-06-15 00:00:00	2006-06-22 00:00:00	ANCIEN	\N	\N	\N	\N	92031P	TITULAIRE	\N	2017-09-24 18:16:52
8506	2012CMP6	2012-01-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92031P	TITULAIRE	\N	2017-09-24 18:16:52
9455	2013CMP9	2013-06-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92031P	TITULAIRE	\N	2017-09-24 18:16:52
10424	2014CMP8	2014-04-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11037K	SUPPLEANT	\N	2017-09-24 18:16:52
13148	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19697Q	\N	2017-09-24 18:17:55	2017-10-04 18:57:37
13149	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19699S	\N	2017-09-24 18:17:55	2017-10-04 18:44:07
13150	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19701S	\N	2017-09-24 18:17:55	2017-10-04 18:54:36
11610	2015CMP17	2015-07-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11096W	SUPPLEANT	\N	2017-09-24 18:17:56
2860	20050504N24	2005-05-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	95035G	TITULAIRE	\N	2017-09-24 18:17:56
7941	2011CMP17	2011-07-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	95035G	SUPPLEANT	\N	2017-09-24 18:17:56
8142	AFCL	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11091R	\N	\N	2017-09-24 18:17:56
8285	2011CMP22	2011-11-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04056J	TITULAIRE	\N	2017-09-24 18:17:56
9572	2013CMP20	2013-10-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04056J	TITULAIRE	\N	2017-09-24 18:17:56
9602	2013CMP22	2013-10-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04056J	TITULAIRE	\N	2017-09-24 18:17:56
15477	ASAP	2020-02-06 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	19575F	\N	\N	\N
13079	LOIS	2017-08-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14089Y	\N	2017-08-01 00:00:00	2017-10-04 00:00:00
9937	LOIS	2014-05-07 00:00:00	2017-07-28 00:00:00	ANCIEN	\N	\N	\N	\N	11032E	\N	2014-05-09 17:32:03	2017-08-03 11:38:41
8280	AFCL	2011-11-02 00:00:00	2017-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	89029V	\N	\N	2017-09-24 11:09:53
13083	NEANT	2017-09-23 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14115H	\N	2017-09-24 11:11:57	2017-10-04 19:02:49
13086	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19507S	\N	2017-09-24 12:57:08	2017-10-04 19:03:39
9548	2013CMP18	2013-10-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	TITULAIRE	\N	2017-09-24 13:29:42
9598	2013CMP21	2013-10-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	SUPPLEANT	\N	2017-09-24 13:29:42
10386	2014CPM5	2014-02-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	SUPPLEANT	\N	2017-09-24 13:29:42
9491	2013CMP11	2013-07-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92039X	SUPPLEANT	\N	2017-09-24 13:47:46
11573	2015CMP14	2015-06-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04056J	SUPPLEANT	\N	2017-09-24 18:17:56
13153	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19415P	\N	2017-09-24 18:23:21	2017-10-04 18:54:42
13154	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19413M	\N	2017-09-24 18:23:21	2017-10-04 19:06:33
13155	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19631V	\N	2017-09-24 18:27:44	2017-10-04 19:02:26
13156	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	17779H	\N	2017-09-24 18:41:37	2017-10-04 18:58:08
13157	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19489J	\N	2017-09-24 18:41:37	2017-10-04 19:11:10
13159	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19703U	\N	2017-09-24 18:49:56	2017-10-04 19:00:29
11627	2015CMP18	2015-07-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14018U	SUPPLEANT	\N	2017-09-24 18:49:56
13161	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19705W	\N	2017-09-24 18:59:59	2017-10-04 19:06:14
13162	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19707Y	\N	2017-09-24 18:59:59	2017-10-04 19:02:39
13163	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19709B	\N	2017-09-24 18:59:59	2017-10-04 18:54:30
13164	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19503N	\N	2017-09-24 19:05:36	2017-10-04 18:57:10
13165	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19511N	\N	2017-09-24 19:14:36	2017-10-04 19:04:32
8491	2012CMP5	2012-01-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11106F	TITULAIRE	\N	2017-09-24 19:14:37
11607	2015CMP17	2015-07-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11106F	TITULAIRE	\N	2017-09-24 19:14:37
13167	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19483C	\N	2017-09-24 19:17:41	2017-10-04 19:11:21
13174	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19479G	\N	2017-09-24 19:26:20	2017-10-04 18:45:58
13175	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19467C	\N	2017-09-24 19:26:20	2017-10-04 19:03:07
13178	NEANT	2017-09-25 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16431B	\N	2017-09-25 10:03:31	2017-10-01 10:37:45
8155	LOIS	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11033F	\N	\N	2017-10-04 00:00:00
8724	CAE	2012-02-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01043Q	\N	\N	2017-10-04 00:00:00
10165	LOIS	2014-10-08 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	\N	2014-10-08 17:18:26	2017-10-04 19:44:48
10202	ETRD	2014-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14193X	\N	2014-10-08 00:00:00	2017-10-04 00:00:00
10219	FINC	2014-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	07029T	\N	2014-10-08 00:00:00	2017-10-04 00:00:00
10096	CAE	2014-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14205J	\N	2014-10-08 00:00:00	2017-10-04 00:00:00
10113	CDD	2014-10-08 00:00:00	2019-08-27 00:00:00	ANCIEN	\N	\N	\N	\N	80027E	\N	2014-10-08 16:53:43	2017-10-04 19:45:29
10130	LOIS	2014-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14001X	\N	2014-10-08 00:00:00	2017-10-04 00:00:00
13372	AFCL	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14030Q	\N	2017-10-04 00:00:00	\N
13373	AFCL	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19643A	\N	2017-10-04 00:00:00	\N
13374	AFCL	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19621T	\N	2017-10-04 00:00:00	\N
13376	AFCL	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19693L	\N	2017-10-04 00:00:00	\N
13377	CDD	2017-10-04 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	\N	2017-10-04 19:42:14	\N
13379	CDD	2017-10-05 00:00:00	2020-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	19733B	\N	2017-10-04 19:42:50	2017-10-05 14:35:23
13380	CDD	2017-10-04 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08024S	\N	2017-10-04 19:43:01	\N
13382	CDD	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	18083K	\N	2017-10-04 00:00:00	\N
13383	CDD	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19681G	\N	2017-10-04 00:00:00	\N
13385	AFCL	2017-10-04 00:00:00	2018-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	08016S	\N	2017-10-04 19:43:19	\N
13386	AFCL	2017-10-04 00:00:00	2021-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	19329S	\N	2017-10-04 19:43:25	\N
13387	CDD	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19525U	\N	2017-10-04 00:00:00	\N
13388	AFCL	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19399H	\N	2017-10-04 00:00:00	\N
8701	CDD	2012-02-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11065P	\N	\N	2017-10-04 00:00:00
13389	CDD	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19701S	\N	2017-10-04 00:00:00	\N
13390	AFCL	2017-10-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14039A	\N	2017-10-04 19:43:44	2017-10-05 14:40:03
13391	CDD	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19659J	\N	2017-10-04 00:00:00	\N
13392	AFCL	2017-10-04 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19731Y	\N	2017-10-04 19:43:52	\N
13393	CDD	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19599P	\N	2017-10-04 00:00:00	\N
13394	CDD	2017-10-04 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	15447F	\N	2017-10-04 19:44:09	\N
13395	AFCL	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19611R	\N	2017-10-04 00:00:00	\N
13397	CDD	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19387D	\N	2017-10-04 00:00:00	\N
13398	AFCL	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19699S	\N	2017-10-04 00:00:00	\N
13399	CDD	2017-10-05 00:00:00	2020-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	19347U	\N	2017-10-04 19:44:20	2017-10-05 14:32:56
13401	CDD	2017-10-04 00:00:00	2017-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	01007L	\N	2017-10-04 19:44:26	2017-11-03 10:47:39
13403	CDD	2017-10-04 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	19685L	\N	2017-10-04 19:44:32	\N
13404	CDD	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19333N	\N	2017-10-04 00:00:00	\N
13406	CDD	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19551W	\N	2017-10-04 00:00:00	\N
13407	CDD	2017-10-04 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14029X	\N	2017-10-04 19:44:59	\N
13408	AFCL	2017-10-04 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	14251Q	\N	2017-10-04 19:45:04	\N
13409	CDD	2017-10-04 00:00:00	2017-11-24 00:00:00	ANCIEN	\N	\N	\N	\N	19677L	\N	2017-10-04 19:45:08	2017-11-24 23:59:34
13410	CDD	2017-10-04 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	19289C	\N	2017-10-04 19:45:13	\N
13412	CDD	2017-10-04 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14103D	\N	2017-10-04 19:45:24	\N
13414	CDD	2017-10-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19637C	\N	2017-10-04 00:00:00	2017-10-05 00:00:00
13416	AFCL	2017-10-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19593H	\N	2017-10-04 00:00:00	2017-10-05 00:00:00
13417	CDD	2017-10-04 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	14191V	\N	2017-10-04 19:45:58	\N
13418	AFCL	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19573D	\N	2017-10-04 00:00:00	\N
13419	CDD	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	17637T	\N	2017-10-04 00:00:00	\N
13420	AFCL	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19533U	\N	2017-10-04 00:00:00	\N
8747	CDD	2012-02-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	05012A	\N	\N	2017-10-04 00:00:00
13422	CDD	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19503N	\N	2017-10-04 00:00:00	\N
13423	CDD	2017-10-04 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	17583W	\N	2017-10-04 19:46:29	\N
13425	CDD	2017-10-04 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	19713W	\N	2017-10-04 19:46:37	\N
13426	AFCL	2017-10-04 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	14107H	\N	2017-10-04 19:46:43	\N
13428	CDD	2017-10-04 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19737F	\N	2017-10-04 19:46:52	\N
13430	AFCL	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19735D	\N	2017-10-04 00:00:00	\N
13435	CDD	2017-10-04 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	19383Y	\N	2017-10-04 19:48:33	\N
13437	FINC	2017-10-04 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	19651A	\N	2017-10-04 19:48:52	\N
13438	FINC	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19667J	\N	2017-10-04 00:00:00	\N
13439	FINC	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19545Y	\N	2017-10-04 00:00:00	2017-10-05 00:00:00
13441	FINC	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19647E	\N	2017-10-04 00:00:00	\N
13442	FINC	2017-10-04 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14034U	\N	2017-10-04 19:50:36	\N
13443	FINC	2017-10-05 00:00:00	2020-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	07004J	\N	2017-10-04 19:50:48	2017-10-05 14:37:35
10217	FINC	2014-10-08 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	08069G	\N	2014-10-08 17:43:41	2017-10-04 19:50:58
13444	FINC	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14121F	\N	2017-10-04 00:00:00	\N
13072	CONFIANCE	2017-07-26 00:00:00	2017-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	SUPPLEANT	2017-07-27 11:31:31	2017-08-03 12:18:47
13073	CONFIANCE	2017-07-26 00:00:00	2017-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	2017-07-27 11:31:38	2017-08-03 12:18:47
13074	CONFIANCE	2017-07-26 00:00:00	2017-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	01024M	SUPPLEANT	2017-07-27 11:31:45	2017-08-03 12:18:47
13075	CONFIANCE	2017-07-26 00:00:00	2017-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	SUPPLEANT	2017-07-27 11:31:52	2017-08-03 12:18:47
13076	CONFIANCE	2017-07-26 00:00:00	2017-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	11037K	SUPPLEANT	2017-07-27 11:32:02	2017-08-03 12:18:47
13082	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19319Q	\N	2017-09-24 10:41:27	2017-10-04 18:55:24
13445	FINC	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19531S	\N	2017-10-04 00:00:00	\N
13446	ETRD	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14105F	\N	2017-10-04 00:00:00	\N
13447	ETRD	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14255U	\N	2017-10-04 00:00:00	\N
13449	ETRD	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19721W	\N	2017-10-04 00:00:00	\N
13450	ETRD	2017-10-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14267Y	\N	2017-10-04 00:00:00	2017-10-05 00:00:00
13451	ETRD	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11115U	\N	2017-10-04 00:00:00	\N
13452	FINC	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19711U	\N	2017-10-04 00:00:00	\N
13453	ETRD	2017-10-04 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14079W	\N	2017-10-04 19:52:35	\N
10122	FINC	2014-10-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14085U	\N	2014-10-08 16:55:38	2017-10-04 19:49:35
13454	FINC	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	12016W	\N	2017-10-04 00:00:00	\N
13455	FINC	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19671E	\N	2017-10-04 00:00:00	\N
13456	ETRD	2017-10-04 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	19251M	\N	2017-10-04 19:53:04	\N
13457	FINC	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19349W	\N	2017-10-04 00:00:00	\N
13458	FINC	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14331P	\N	2017-10-04 00:00:00	\N
13459	ETRD	2017-10-05 00:00:00	2018-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	98053W	\N	2017-10-04 19:53:24	2018-05-31 10:52:17
10152	FINC	2014-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11012A	\N	2014-10-08 00:00:00	2017-10-04 00:00:00
13460	FINC	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19687N	\N	2017-10-04 00:00:00	\N
13461	FINC	2017-10-04 00:00:00	2022-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	19689Q	\N	2017-10-04 19:53:44	\N
13462	FINC	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19479G	\N	2017-10-04 00:00:00	\N
10086	SOCI	2014-10-08 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14034U	\N	2014-10-08 16:43:21	2017-10-04 19:05:47
13463	ETRD	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19709B	\N	2017-10-04 00:00:00	\N
13464	ETRD	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	16685X	\N	2017-10-04 00:00:00	\N
10087	SOCI	2014-10-08 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14231L	\N	2014-10-08 16:43:31	2017-10-04 18:49:49
13465	CAE	2017-10-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19631V	\N	2017-10-04 00:00:00	2017-10-05 00:00:00
13466	CAE	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19515S	\N	2017-10-04 00:00:00	\N
13467	CAE	2017-10-04 00:00:00	2018-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	19707Y	\N	2017-10-04 19:55:15	\N
13534	COMSPEAPU	2017-10-04 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	19611R	\N	2017-10-04 20:30:42	\N
8689	CAE	2012-02-21 00:00:00	2020-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	08068F	\N	\N	2017-10-04 19:55:34
13469	ETRD	2017-10-04 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	08061X	\N	2017-10-04 19:55:35	\N
13470	CAE	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14329V	\N	2017-10-04 00:00:00	\N
13471	ETRD	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19319Q	\N	2017-10-04 00:00:00	\N
13472	CAE	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19467C	\N	2017-10-04 00:00:00	\N
13473	ETRD	2017-10-04 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98050T	\N	2017-10-04 19:56:01	\N
13474	CAE	2017-10-04 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	19295A	\N	2017-10-04 19:56:04	\N
13475	ETRD	2017-10-04 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14235Q	\N	2017-10-04 19:56:07	\N
13476	ETRD	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19443T	\N	2017-10-04 00:00:00	\N
13477	ETRD	2017-10-04 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	14055N	\N	2017-10-04 19:56:17	\N
13478	CAE	2017-10-05 00:00:00	2020-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	11056N	\N	2017-10-04 19:56:20	2017-10-05 14:29:17
10147	SOCI	2014-10-08 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14151M	\N	2014-10-08 17:05:52	2017-10-04 18:48:59
13479	ETRD	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19421M	\N	2017-10-04 00:00:00	\N
13480	ETRD	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01058X	\N	2017-10-04 00:00:00	\N
13481	CAE	2017-10-05 00:00:00	2020-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	17589D	\N	2017-10-04 19:56:37	2017-10-05 14:29:30
13482	ETRD	2017-10-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19669L	\N	2017-10-04 00:00:00	2017-10-05 00:00:00
8702	CAE	2012-02-21 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04089T	\N	\N	2017-10-04 19:56:41
13483	CAE	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19507S	\N	2017-10-04 00:00:00	\N
13484	ETRD	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01062T	\N	2017-10-04 00:00:00	\N
13485	ETRD	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11066Q	\N	2017-10-04 00:00:00	\N
13486	ETRD	2017-10-04 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	\N	2017-10-04 19:57:07	\N
13487	CAE	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01025N	\N	2017-10-04 00:00:00	\N
13488	ETRD	2017-10-04 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	\N	2017-10-04 19:57:12	\N
13489	CAE	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19695N	\N	2017-10-04 00:00:00	\N
13490	CAE	2017-10-04 00:00:00	2019-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	19565D	\N	2017-10-04 19:57:19	\N
13491	CAE	2017-10-04 00:00:00	2020-02-25 00:00:00	ANCIEN	\N	\N	\N	\N	19591F	\N	2017-10-04 19:57:37	\N
13492	CAE	2017-10-04 00:00:00	2022-09-09 00:00:00	ANCIEN	\N	\N	\N	\N	19511N	\N	2017-10-04 19:57:43	\N
13493	ETRD	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19583F	\N	2017-10-04 00:00:00	\N
13494	CAE	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19441R	\N	2017-10-04 00:00:00	\N
13497	CAE	2017-10-04 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08062Y	\N	2017-10-04 19:58:34	\N
13498	CAE	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19563B	\N	2017-10-04 00:00:00	\N
13500	CAE	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19369B	\N	2017-10-04 00:00:00	\N
13502	CAE	2017-10-04 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14265W	\N	2017-10-04 19:59:02	\N
13504	CAE	2017-10-04 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14135M	\N	2017-10-04 19:59:46	\N
13505	CAE	2017-10-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19269X	\N	2017-10-04 19:59:51	2017-10-05 14:28:43
13507	CAE	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19705W	\N	2017-10-04 00:00:00	\N
13508	CAE	2017-10-04 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	19619A	\N	2017-10-04 20:00:06	\N
13509	CAE	2017-10-04 00:00:00	2018-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	19301E	\N	2017-10-04 20:00:12	\N
13510	CAE	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19413M	\N	2017-10-04 00:00:00	\N
11549	COMSPEAPU	2015-12-16 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	11053K	\N	2015-12-16 17:19:57	2017-10-04 20:36:19
13530	COMSPEAPU	2017-10-05 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	\N	2017-10-04 20:30:13	2017-10-05 14:44:40
13531	COMSPEAPU	2017-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19545Y	\N	2017-10-04 20:30:21	\N
13532	COMSPEAPU	2017-10-04 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14085U	\N	2017-10-04 20:30:26	\N
13533	COMSPEAPU	2017-10-05 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	14021P	\N	2017-10-04 20:30:37	2018-02-23 16:11:12
13535	COMSPEAPU	2017-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19687N	\N	2017-10-04 20:30:49	\N
13538	CDD	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19549D	\N	2017-10-04 00:00:00	\N
13540	AFEU	2017-10-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14065Q	\N	2017-10-05 14:38:56	\N
13541	AFEU	2017-10-05 00:00:00	2018-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	98053W	\N	2017-10-05 14:39:43	2018-05-31 10:52:17
13542	AFEU	2017-10-05 00:00:00	2017-10-23 00:00:00	ANCIEN	\N	\N	\N	\N	19521Q	\N	2017-10-05 14:39:52	2017-10-24 11:21:58
13543	AFEU	2017-10-05 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14033T	\N	2017-10-05 14:40:19	\N
13544	AFEU	2017-10-05 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19553Y	\N	2017-10-05 14:40:36	\N
13545	AFEU	2017-10-05 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19725B	\N	2017-10-05 14:40:42	\N
13546	AFEU	2017-10-05 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	19685L	\N	2017-10-05 14:40:59	2018-02-08 14:32:21
13547	AFEU	2017-10-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04097T	\N	2017-10-05 14:41:06	\N
13548	AFEU	2017-10-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14061L	\N	2017-10-05 14:41:32	\N
13549	AFEU	2017-10-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08039A	\N	2017-10-05 14:41:50	\N
13550	AFEU	2017-10-05 00:00:00	2021-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	14221J	\N	2017-10-05 14:42:03	\N
13551	AFEU	2017-10-05 00:00:00	2020-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	19563B	\N	2017-10-05 14:42:15	\N
8726	CAE	2012-02-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11077T	\N	\N	2017-10-04 00:00:00
13552	AFEU	2017-10-05 00:00:00	2018-04-03 00:00:00	ANCIEN	\N	\N	\N	\N	19335Q	\N	2017-10-05 14:42:21	2018-04-05 09:46:45
13553	AFEU	2017-10-05 00:00:00	2020-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	19593H	\N	2017-10-05 14:42:27	\N
13554	AFEU	2017-10-05 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14237S	\N	2017-10-05 14:42:38	\N
13555	AFEU	2017-10-05 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14331P	\N	2017-10-05 14:42:48	\N
13556	AFEU	2017-10-05 00:00:00	2020-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14225N	\N	2017-10-05 14:42:53	\N
13557	AFEU	2017-10-05 00:00:00	2020-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14229S	\N	2017-10-05 14:43:07	\N
13558	AFEU	2017-10-05 00:00:00	2017-10-16 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	\N	2017-10-05 14:43:18	2017-10-17 15:45:13
13559	TERRORISME	2017-10-05 00:00:00	2017-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	2017-10-09 17:30:16	2017-10-10 10:43:53
13168	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19369B	\N	2017-09-24 19:19:07	2017-10-04 19:05:32
13084	NEANT	2017-09-23 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14029X	\N	2017-09-24 11:13:08	2017-10-04 18:55:55
13085	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19629C	\N	2017-09-24 12:39:58	2017-10-04 19:09:54
8389	2011CMP27	2011-12-19 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	98046X	SUPPLEANT	\N	2017-09-25 09:56:00
8954	2012CMP18	2012-11-06 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	98046X	TITULAIRE	\N	2017-09-25 09:56:00
9838	2013CMP31	2013-12-09 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	98046X	TITULAIRE	\N	2017-09-25 09:56:00
9733	2013CMP29	2013-11-29 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	98046X	TITULAIRE	\N	2017-09-25 09:56:00
13568	TERRORISME	2017-10-05 00:00:00	2017-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	08018U	SUPPLEANT	2017-10-09 17:35:20	2017-10-10 10:43:53
13569	TERRORISME	2017-10-05 00:00:00	2017-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	11049P	SUPPLEANT	2017-10-09 17:35:25	2017-10-10 10:43:53
13570	TERRORISME	2017-10-05 00:00:00	2017-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	11026G	SUPPLEANT	2017-10-09 17:35:30	2017-10-10 10:43:53
13571	TERRORISME	2017-10-05 00:00:00	2017-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	11085T	SUPPLEANT	2017-10-09 17:35:36	2017-10-10 10:43:53
13572	TERRORISME	2017-10-05 00:00:00	2017-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	10015M	SUPPLEANT	2017-10-09 17:35:41	2017-10-10 10:43:53
13108	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19543W	\N	2017-09-24 17:18:02	2017-10-04 19:10:04
13620	PLFSS2018	2017-11-20 00:00:00	2017-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	TITULAIRE	2017-11-20 10:43:18	2017-12-07 10:05:36
13621	PLFSS2018	2017-11-20 00:00:00	2017-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	01034P	TITULAIRE	2017-11-20 10:43:25	2017-12-07 10:05:36
13622	PLFSS2018	2017-11-20 00:00:00	2017-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	10006L	TITULAIRE	2017-11-20 10:43:30	2017-12-07 10:05:36
13623	PLFSS2018	2017-11-20 00:00:00	2017-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	11097X	TITULAIRE	2017-11-20 10:43:35	2017-12-07 10:05:36
13624	PLFSS2018	2017-11-20 00:00:00	2017-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	TITULAIRE	2017-11-20 10:43:40	2017-12-07 10:05:36
13625	PLFSS2018	2017-11-20 00:00:00	2017-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	11067R	TITULAIRE	2017-11-20 10:43:45	2017-12-07 10:05:36
13626	PLFSS2018	2017-11-20 00:00:00	2017-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	14239U	TITULAIRE	2017-11-20 10:43:49	2017-12-07 10:05:36
13627	PLFSS2018	2017-11-20 00:00:00	2017-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	19415P	SUPPLEANT	2017-11-20 10:43:54	2017-12-07 10:05:36
13628	PLFSS2018	2017-11-20 00:00:00	2017-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	11031D	SUPPLEANT	2017-11-20 10:44:02	2017-12-07 10:05:36
13102	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19447X	\N	2017-09-24 17:14:26	2017-10-04 19:10:56
13629	PLFSS2018	2017-11-20 00:00:00	2017-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	98024R	SUPPLEANT	2017-11-20 10:44:12	2017-12-07 10:05:36
13630	PLFSS2018	2017-11-20 00:00:00	2017-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	14042U	SUPPLEANT	2017-11-20 10:44:20	2017-12-07 10:05:36
13631	PLFSS2018	2017-11-20 00:00:00	2017-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	19553Y	SUPPLEANT	2017-11-20 10:44:27	2017-12-07 10:05:36
13632	PLFSS2018	2017-11-20 00:00:00	2017-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	19683J	SUPPLEANT	2017-11-20 10:44:34	2017-12-07 10:05:36
13633	PLFSS2018	2017-11-20 00:00:00	2017-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	95041E	SUPPLEANT	2017-11-20 10:44:42	2017-12-07 10:05:36
13663	NEANT	2017-11-25 00:00:00	2017-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	19741B	\N	2017-11-24 18:17:29	2017-11-28 15:56:05
13708	PLF2018	2017-12-07 00:00:00	2017-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	11074Q	TITULAIRE	2017-12-08 15:34:34	2017-12-20 10:15:47
13560	TERRORISME	2017-10-05 00:00:00	2017-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	TITULAIRE	2017-10-09 17:30:25	2017-10-10 10:43:53
13561	TERRORISME	2017-10-05 00:00:00	2017-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	TITULAIRE	2017-10-09 17:30:30	2017-10-10 10:43:53
13562	TERRORISME	2017-10-05 00:00:00	2017-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	14089Y	TITULAIRE	2017-10-09 17:30:39	2017-10-10 10:43:53
13563	TERRORISME	2017-10-05 00:00:00	2017-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	14065Q	TITULAIRE	2017-10-09 17:30:47	2017-10-10 10:43:53
13564	TERRORISME	2017-10-05 00:00:00	2017-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	08058D	TITULAIRE	2017-10-09 17:34:41	2017-10-10 10:43:53
13565	TERRORISME	2017-10-05 00:00:00	2017-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	19543W	TITULAIRE	2017-10-09 17:34:48	2017-10-10 10:43:53
13566	TERRORISME	2017-10-05 00:00:00	2017-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	SUPPLEANT	2017-10-09 17:34:54	2017-10-10 10:43:53
13567	TERRORISME	2017-10-05 00:00:00	2017-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	19253P	SUPPLEANT	2017-10-09 17:35:00	2017-10-10 10:43:53
13709	PLF2018	2017-12-07 00:00:00	2017-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	08011M	TITULAIRE	2017-12-08 15:34:40	2017-12-20 10:15:47
13710	PLF2018	2017-12-07 00:00:00	2017-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	19711U	TITULAIRE	2017-12-08 15:34:49	2017-12-20 10:15:47
13711	PLF2018	2017-12-07 00:00:00	2017-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	04071H	TITULAIRE	2017-12-08 15:34:53	2017-12-20 10:15:47
13712	PLF2018	2017-12-07 00:00:00	2017-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	14327T	TITULAIRE	2017-12-08 15:34:58	2017-12-20 10:15:47
13713	PLF2018	2017-12-07 00:00:00	2017-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	14225N	TITULAIRE	2017-12-08 15:35:02	2017-12-20 10:15:47
13714	PLF2018	2017-12-07 00:00:00	2017-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	19651A	TITULAIRE	2017-12-08 15:35:08	2017-12-20 10:15:47
13715	PLF2018	2017-12-07 00:00:00	2017-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	88008L	SUPPLEANT	2017-12-08 15:35:12	2017-12-20 10:15:47
13716	PLF2018	2017-12-07 00:00:00	2017-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	11070L	SUPPLEANT	2017-12-08 15:35:21	2017-12-20 10:15:47
13717	PLF2018	2017-12-07 00:00:00	2017-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	19647E	SUPPLEANT	2017-12-08 15:35:25	2017-12-20 10:15:47
13718	PLF2018	2017-12-07 00:00:00	2017-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	SUPPLEANT	2017-12-08 15:35:29	2017-12-20 10:15:47
13719	PLF2018	2017-12-07 00:00:00	2017-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	99004R	SUPPLEANT	2017-12-08 15:35:34	2017-12-20 10:15:47
13720	PLF2018	2017-12-07 00:00:00	2017-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	19671E	SUPPLEANT	2017-12-08 15:35:38	2017-12-20 10:15:47
13721	PLF2018	2017-12-07 00:00:00	2017-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	19687N	SUPPLEANT	2017-12-08 15:35:44	2017-12-20 10:15:47
13722	PLFP2018	2017-12-07 00:00:00	2017-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	11074Q	TITULAIRE	2017-12-08 15:38:42	2017-12-20 10:15:11
13723	PLFP2018	2017-12-07 00:00:00	2017-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	08011M	TITULAIRE	2017-12-08 15:38:49	2017-12-20 10:15:11
13724	PLFP2018	2017-12-07 00:00:00	2017-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	SUPPLEANT	2017-12-08 15:38:54	2017-12-20 10:15:11
13725	PLFP2018	2017-12-07 00:00:00	2017-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	04071H	SUPPLEANT	2017-12-08 15:38:59	2017-12-20 10:15:11
13726	PLFP2018	2017-12-07 00:00:00	2017-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	11070L	SUPPLEANT	2017-12-08 15:39:06	2017-12-20 10:15:11
13727	PLFP2018	2017-12-07 00:00:00	2017-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	14225N	TITULAIRE	2017-12-08 15:39:10	2017-12-20 10:15:11
13728	PLFP2018	2017-12-07 00:00:00	2017-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	19349W	TITULAIRE	2017-12-08 15:39:16	2017-12-14 10:53:49
15478	ASAP	2020-02-06 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	19747H	\N	\N	\N
13729	PLFP2018	2017-12-07 00:00:00	2017-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	88008L	TITULAIRE	2017-12-08 15:39:24	2017-12-20 10:15:11
13730	PLFP2018	2017-12-07 00:00:00	2017-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	14327T	TITULAIRE	2017-12-08 15:39:29	2017-12-20 10:15:11
13731	PLFP2018	2017-12-07 00:00:00	2017-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	19647E	TITULAIRE	2017-12-08 15:39:34	2017-12-20 10:15:11
13732	PLFP2018	2017-12-07 00:00:00	2017-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	99004R	SUPPLEANT	2017-12-08 15:39:41	2017-12-20 10:15:11
13733	PLFP2018	2017-12-07 00:00:00	2017-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	19711U	SUPPLEANT	2017-12-08 15:39:46	2017-12-20 10:15:11
13734	PLFP2018	2017-12-07 00:00:00	2017-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	19671E	TITULAIRE	2017-12-08 15:39:53	2017-12-20 10:15:11
13735	PLFP2018	2017-12-07 00:00:00	2017-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	19687N	SUPPLEANT	2017-12-08 15:39:58	2017-12-20 10:15:11
13747	PLFR2017_2	2017-12-14 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	14199E	SUPPLEANT	2017-12-18 09:22:26	2017-12-20 10:16:50
13748	PLFR2017_2	2017-12-14 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	14121F	SUPPLEANT	2017-12-18 09:22:32	2017-12-20 10:16:50
13749	PLFR2017_2	2017-12-14 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	99004R	SUPPLEANT	2017-12-18 09:22:37	2017-12-20 10:16:50
13750	PLFR2017_2	2017-12-14 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	19671E	SUPPLEANT	2017-12-18 09:22:41	2017-12-20 10:16:50
13751	NEANT	2017-12-18 00:00:00	2018-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	19745F	\N	2017-12-18 14:31:40	2018-01-16 19:20:07
13752	NEANT	2017-12-18 00:00:00	2018-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	19747H	\N	2017-12-18 14:43:34	2018-01-16 19:14:10
13753	NEANT	2017-12-18 00:00:00	2018-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	19749K	\N	2017-12-18 14:52:08	2018-01-16 19:17:32
13754	GEMAPI	2017-12-19 00:00:00	2017-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	2017-12-20 10:09:29	2017-12-20 10:16:57
13755	GEMAPI	2017-12-19 00:00:00	2017-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	14259Y	TITULAIRE	2017-12-20 10:09:34	2017-12-20 10:16:57
13756	GEMAPI	2017-12-19 00:00:00	2017-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	TITULAIRE	2017-12-20 10:09:40	2017-12-20 10:16:57
13757	GEMAPI	2017-12-19 00:00:00	2017-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	14231L	TITULAIRE	2017-12-20 10:09:45	2017-12-20 10:16:57
13077	NEANT	2017-07-29 00:00:00	2017-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	19285X	\N	2017-07-31 12:02:13	2017-08-01 14:55:03
13087	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19657G	\N	2017-09-24 16:24:50	2017-10-04 18:58:37
13088	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19659J	\N	2017-09-24 16:24:50	2017-10-04 18:54:52
13089	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19577H	\N	2017-09-24 16:24:50	2017-10-04 18:55:16
13090	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19583F	\N	2017-09-24 16:24:50	2017-10-04 18:54:04
10188	AFCL	2014-10-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14061L	\N	2014-10-08 17:33:41	2017-10-04 19:43:56
10092	AFCL	2014-10-08 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14103D	\N	2014-10-08 16:45:14	2017-10-04 19:14:01
10141	AFCL	2014-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14109K	\N	2014-10-08 00:00:00	2017-10-04 00:00:00
10180	AFCL	2014-10-08 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14235Q	\N	2014-10-08 17:32:24	2017-10-04 19:14:29
10094	AFCL	2014-10-08 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14055N	\N	2014-10-08 16:45:41	2017-10-04 19:14:35
10193	AFCL	2014-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04033B	\N	2014-10-08 00:00:00	2017-10-04 00:00:00
8156	ETRD	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11054L	\N	\N	2017-10-04 00:00:00
8151	ETRD	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11080N	\N	\N	2017-10-04 00:00:00
10133	ETRD	2014-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14097Y	\N	2014-10-08 00:00:00	2017-10-04 00:00:00
10200	ETRD	2014-10-08 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14251Q	\N	2014-10-08 17:38:11	2017-10-04 19:11:34
10194	ETRD	2014-10-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95030B	\N	2014-10-08 17:36:47	2017-10-04 19:57:27
13539	LOIS	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19447X	\N	2017-10-04 00:00:00	\N
10245	AFEU	2014-10-09 00:00:00	2017-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04045F	\N	2014-10-09 10:41:50	2017-10-05 11:42:53
10231	AFEU	2014-10-09 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14133K	\N	2014-10-09 09:39:20	2017-10-05 14:38:49
8236	AFEU	2011-10-01 00:00:00	2017-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	11040E	\N	\N	2017-10-05 11:42:54
10234	AFEU	2014-10-09 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14026U	\N	2014-10-09 09:39:55	2017-10-05 14:40:26
12092	AFEU	2016-04-26 00:00:00	2020-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	08044W	\N	2016-04-26 14:12:08	2017-10-05 14:41:12
10752	AFEU	2015-01-13 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14097Y	\N	2015-01-13 11:59:09	2017-10-05 14:41:19
10248	AFEU	2014-10-09 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14073Q	\N	2014-10-09 11:08:55	2017-10-05 14:41:37
10239	AFEU	2014-10-09 00:00:00	2017-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	08021P	\N	2014-10-09 09:41:00	2017-10-05 11:43:00
8252	AFEU	2011-10-01 00:00:00	2019-04-03 00:00:00	ANCIEN	\N	\N	\N	\N	08073C	\N	\N	2017-10-05 14:42:32
13573	AFEU	2017-10-17 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14357A	\N	2017-10-17 15:45:33	\N
13575	NEANT	2017-11-03 00:00:00	2017-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	19739H	\N	2017-11-03 10:52:37	2017-11-07 16:24:40
13591	PLFR2017	2017-11-09 00:00:00	2017-11-10 00:00:00	ANCIEN	\N	\N	\N	\N	11074Q	TITULAIRE	2017-11-09 18:38:17	2017-11-20 10:47:06
13592	PLFR2017	2017-11-09 00:00:00	2017-11-10 00:00:00	ANCIEN	\N	\N	\N	\N	08011M	TITULAIRE	2017-11-09 18:38:24	2017-11-20 10:47:06
13593	PLFR2017	2017-11-09 00:00:00	2017-11-10 00:00:00	ANCIEN	\N	\N	\N	\N	04071H	TITULAIRE	2017-11-09 18:39:23	2017-11-20 10:47:06
13594	PLFR2017	2017-11-09 00:00:00	2017-11-10 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	TITULAIRE	2017-11-09 18:39:29	2017-11-20 10:47:06
13595	PLFR2017	2017-11-09 00:00:00	2017-11-10 00:00:00	ANCIEN	\N	\N	\N	\N	11053K	TITULAIRE	2017-11-09 18:39:34	2017-11-20 10:47:06
13596	PLFR2017	2017-11-09 00:00:00	2017-11-10 00:00:00	ANCIEN	\N	\N	\N	\N	14225N	TITULAIRE	2017-11-09 18:39:40	2017-11-20 10:47:06
13636	ALSTOM	2017-11-22 00:00:00	2018-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	14133K	\N	2017-11-21 15:45:25	2017-12-01 14:27:03
13598	PLFR2017	2017-11-09 00:00:00	2017-11-10 00:00:00	ANCIEN	\N	\N	\N	\N	19651A	TITULAIRE	2017-11-09 18:40:00	2017-11-20 10:47:06
13599	PLFR2017	2017-11-09 00:00:00	2017-11-10 00:00:00	ANCIEN	\N	\N	\N	\N	14085U	SUPPLEANT	2017-11-09 18:40:05	2017-11-20 10:47:06
13600	PLFR2017	2017-11-09 00:00:00	2017-11-10 00:00:00	ANCIEN	\N	\N	\N	\N	88008L	SUPPLEANT	2017-11-09 18:40:09	2017-11-20 10:47:06
13601	PLFR2017	2017-11-09 00:00:00	2017-11-10 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	SUPPLEANT	2017-11-09 18:40:14	2017-11-20 10:47:06
13658	ALSTOM	2017-11-22 00:00:00	2018-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	11090Q	\N	2017-11-21 15:47:47	\N
13602	PLFR2017	2017-11-09 00:00:00	2017-11-10 00:00:00	ANCIEN	\N	\N	\N	\N	14327T	SUPPLEANT	2017-11-09 18:40:18	2017-11-20 10:47:06
13603	PLFR2017	2017-11-09 00:00:00	2017-11-10 00:00:00	ANCIEN	\N	\N	\N	\N	99004R	SUPPLEANT	2017-11-09 18:40:24	2017-11-20 10:47:06
13604	PLFR2017	2017-11-09 00:00:00	2017-11-10 00:00:00	ANCIEN	\N	\N	\N	\N	19711U	SUPPLEANT	2017-11-09 18:40:29	2017-11-20 10:47:06
13605	PLFR2017	2017-11-09 00:00:00	2017-11-10 00:00:00	ANCIEN	\N	\N	\N	\N	19687N	SUPPLEANT	2017-11-09 18:40:34	2017-11-20 10:47:06
13606	HYDROCARBURE	2017-11-15 00:00:00	2017-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	11090Q	TITULAIRE	2017-11-16 10:16:04	2017-12-07 10:05:16
13607	HYDROCARBURE	2017-11-15 00:00:00	2017-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	TITULAIRE	2017-11-16 10:16:10	2017-12-07 10:05:16
13608	HYDROCARBURE	2017-11-15 00:00:00	2017-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	19383Y	TITULAIRE	2017-11-16 10:16:17	2017-12-07 10:05:16
13609	HYDROCARBURE	2017-11-15 00:00:00	2017-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	01025N	TITULAIRE	2017-11-16 10:16:22	2017-12-07 10:05:16
13610	HYDROCARBURE	2017-11-15 00:00:00	2017-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	08055A	TITULAIRE	2017-11-16 10:16:29	2017-12-07 10:05:16
13611	HYDROCARBURE	2017-11-15 00:00:00	2017-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	80013X	TITULAIRE	2017-11-16 10:16:34	2017-12-07 10:05:16
13612	HYDROCARBURE	2017-11-15 00:00:00	2017-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	19269X	TITULAIRE	2017-11-16 10:16:39	2017-12-07 10:05:16
13613	HYDROCARBURE	2017-11-15 00:00:00	2017-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	08068F	SUPPLEANT	2017-11-16 10:16:44	2017-12-07 10:05:16
13614	HYDROCARBURE	2017-11-15 00:00:00	2017-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	14329V	SUPPLEANT	2017-11-16 10:18:36	2017-12-07 10:05:16
8746	CAE	2012-02-21 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01058X	\N	\N	2017-10-04 18:56:16
13615	HYDROCARBURE	2017-11-15 00:00:00	2017-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	14357A	SUPPLEANT	2017-11-16 10:18:43	2017-12-07 10:05:16
13616	HYDROCARBURE	2017-11-15 00:00:00	2017-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	19695N	SUPPLEANT	2017-11-16 10:18:47	2017-12-07 10:05:16
13617	HYDROCARBURE	2017-11-15 00:00:00	2017-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	14033T	SUPPLEANT	2017-11-16 10:18:52	2017-12-07 10:05:16
13618	HYDROCARBURE	2017-11-15 00:00:00	2017-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	11099A	SUPPLEANT	2017-11-16 10:18:56	2017-12-07 10:05:16
13619	HYDROCARBURE	2017-11-15 00:00:00	2017-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	19619A	SUPPLEANT	2017-11-16 10:19:01	2017-12-07 10:05:16
8210	FINC	2011-10-01 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	\N	\N	2017-10-04 18:57:33
13644	ALSTOM	2017-11-22 00:00:00	2018-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	19695N	\N	2017-11-21 15:46:23	2017-12-01 14:43:29
13637	ALSTOM	2017-11-22 00:00:00	2018-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	19631V	\N	2017-11-21 15:45:31	\N
13638	ALSTOM	2017-11-22 00:00:00	2018-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	14065Q	\N	2017-11-21 15:45:38	2017-12-01 14:42:21
13639	ALSTOM	2017-11-22 00:00:00	2018-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	08068F	\N	2017-11-21 15:45:43	2017-12-01 14:26:15
13640	ALSTOM	2017-11-22 00:00:00	2017-11-28 00:00:00	ANCIEN	\N	\N	\N	\N	08028W	\N	2017-11-21 15:45:50	2017-12-01 14:23:06
13641	ALSTOM	2017-11-22 00:00:00	2018-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	19681G	\N	2017-11-21 15:46:07	\N
13642	ALSTOM	2017-11-22 00:00:00	2018-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	14079W	\N	2017-11-21 15:46:12	\N
13643	ALSTOM	2017-11-22 00:00:00	2018-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	19251M	\N	2017-11-21 15:46:19	\N
13645	ALSTOM	2017-11-22 00:00:00	2018-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	95041E	\N	2017-11-21 15:46:29	\N
13646	ALSTOM	2017-11-22 00:00:00	2018-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	04061F	\N	2017-11-21 15:46:34	\N
13647	ALSTOM	2017-11-22 00:00:00	2018-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	14061L	\N	2017-11-21 15:46:39	\N
13648	ALSTOM	2017-11-22 00:00:00	2018-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	14073Q	\N	2017-11-21 15:46:44	2017-12-01 14:44:22
13649	ALSTOM	2017-11-22 00:00:00	2018-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	08015R	\N	2017-11-21 15:46:51	\N
13650	ALSTOM	2017-11-22 00:00:00	2017-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	19697Q	\N	2017-11-21 15:46:56	2017-12-20 13:59:56
13651	ALSTOM	2017-11-22 00:00:00	2018-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	14219Q	\N	2017-11-21 15:47:02	\N
13652	ALSTOM	2017-11-22 00:00:00	2018-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	19563B	\N	2017-11-21 15:47:13	2017-12-01 14:44:57
13653	ALSTOM	2017-11-22 00:00:00	2018-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	19369B	\N	2017-11-21 15:47:18	2018-01-31 09:47:00
13654	ALSTOM	2017-11-22 00:00:00	2018-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	14257W	\N	2017-11-21 15:47:22	\N
13655	ALSTOM	2017-11-22 00:00:00	2018-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	14237S	\N	2017-11-21 15:47:29	\N
13656	ALSTOM	2017-11-22 00:00:00	2018-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	14028W	\N	2017-11-21 15:47:37	\N
13657	ALSTOM	2017-11-22 00:00:00	2018-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	14193X	\N	2017-11-21 15:47:42	\N
13179	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19301E	\N	2017-09-25 10:54:33	2017-10-04 19:06:25
13180	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19715Y	\N	2017-09-25 10:54:33	2017-10-04 18:56:56
13181	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	12016W	\N	2017-09-25 10:54:33	2017-10-04 18:45:06
13182	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19717B	\N	2017-09-25 10:56:48	2017-10-04 18:53:49
8519	2012CMP7	2012-01-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04094Q	TITULAIRE	\N	2017-09-25 10:58:49
8940	2012CMP17	2012-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04094Q	TITULAIRE	\N	2017-09-25 10:58:49
8714	CAE	2012-02-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04094Q	\N	\N	2017-09-25 10:58:49
13183	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19295A	\N	2017-09-25 11:00:40	2017-10-04 19:03:14
13576	CDD	2017-11-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19739H	\N	2017-11-07 00:00:00	\N
13381	LOIS	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14053L	\N	2017-10-04 00:00:00	\N
13384	LOIS	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19629C	\N	2017-10-04 00:00:00	\N
13396	LOIS	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04008A	\N	2017-10-04 00:00:00	\N
13400	LOIS	2017-10-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19543W	\N	2017-10-04 00:00:00	2017-10-05 00:00:00
13402	LOIS	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19649G	\N	2017-10-04 00:00:00	\N
13405	LOIS	2017-10-05 00:00:00	2020-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	19719D	\N	2017-10-04 19:44:39	2017-10-05 14:27:53
13411	LOIS	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14151M	\N	2017-10-04 00:00:00	\N
13413	LOIS	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19673G	\N	2017-10-04 00:00:00	\N
13415	LOIS	2017-10-04 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	08045X	\N	2017-10-04 19:45:44	\N
13421	LOIS	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14231L	\N	2017-10-04 00:00:00	\N
13424	LOIS	2017-10-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19725B	\N	2017-10-04 00:00:00	2017-10-05 00:00:00
13427	LOIS	2017-10-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14179A	\N	2017-10-04 00:00:00	2017-10-05 00:00:00
13431	LOIS	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14021P	\N	2017-10-04 00:00:00	\N
13432	LOIS	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19489J	\N	2017-10-04 00:00:00	\N
13433	LOIS	2017-10-04 00:00:00	2018-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	19483C	\N	2017-10-04 19:48:13	2018-04-13 17:54:29
13434	LOIS	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19729F	\N	2017-10-04 00:00:00	\N
13436	LOIS	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19581D	\N	2017-10-04 00:00:00	\N
13440	LOIS	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11085T	\N	2017-10-04 00:00:00	\N
13448	LOIS	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19585H	\N	2017-10-04 00:00:00	\N
13495	SOCI	2017-10-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14261S	\N	2017-10-04 19:58:30	2017-10-05 14:35:43
13496	SOCI	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19717B	\N	2017-10-04 00:00:00	\N
13499	SOCI	2017-10-04 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	19575F	\N	2017-10-04 19:58:42	\N
13501	SOCI	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19367Y	\N	2017-10-04 00:00:00	\N
13503	SOCI	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19415P	\N	2017-10-04 00:00:00	\N
13506	SOCI	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19663E	\N	2017-10-04 00:00:00	\N
13511	SOCI	2017-10-04 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	19577H	\N	2017-10-04 20:00:41	\N
13512	SOCI	2017-10-04 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	19521Q	\N	2017-10-04 20:01:45	\N
13513	SOCI	2017-10-04 00:00:00	2020-06-24 00:00:00	ANCIEN	\N	\N	\N	\N	19727D	\N	2017-10-04 20:03:05	\N
13514	SOCI	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19691J	\N	2017-10-04 00:00:00	\N
13515	SOCI	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19553Y	\N	2017-10-04 00:00:00	\N
13516	SOCI	2017-10-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19569H	\N	2017-10-04 00:00:00	2017-10-05 00:00:00
13517	SOCI	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19715Y	\N	2017-10-04 00:00:00	\N
13518	SOCI	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19683J	\N	2017-10-04 00:00:00	\N
13519	SOCI	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19723Y	\N	2017-10-04 00:00:00	\N
13520	SOCI	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19697Q	\N	2017-10-04 00:00:00	\N
13521	SOCI	2017-10-04 00:00:00	2019-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	11077T	\N	2017-10-04 20:04:55	\N
13522	SOCI	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	17779H	\N	2017-10-04 00:00:00	\N
13523	SOCI	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19657G	\N	2017-10-04 00:00:00	\N
10177	SOCI	2014-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14223L	\N	2014-10-08 00:00:00	2017-10-04 00:00:00
13524	SOCI	2017-10-04 00:00:00	2018-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	19335Q	\N	2017-10-04 20:05:59	\N
13525	SOCI	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19679N	\N	2017-10-04 00:00:00	\N
13526	SOCI	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11045K	\N	2017-10-04 00:00:00	\N
13527	SOCI	2017-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19703U	\N	2017-10-04 00:00:00	\N
13528	SOCI	2017-10-04 00:00:00	2019-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	19675J	\N	2017-10-04 20:07:14	\N
13529	SOCI	2017-10-04 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	19527W	\N	2017-10-04 20:07:33	\N
8113	SOCI	2011-10-01 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	11063M	\N	\N	2017-10-04 20:07:48
13659	ALSTOM	2017-11-22 00:00:00	2018-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	19349W	\N	2017-11-21 15:47:52	2017-12-01 14:45:33
13660	ALSTOM	2017-11-22 00:00:00	2018-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	11043H	\N	2017-11-21 15:47:56	\N
13661	ALSTOM	2017-11-22 00:00:00	2018-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	19737F	\N	2017-11-21 15:48:02	\N
13662	ALSTOM	2017-11-22 00:00:00	2018-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	19585H	\N	2017-11-21 15:48:09	2017-12-01 14:46:13
13664	CDD	2017-11-28 00:00:00	2018-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	19741B	\N	2017-11-28 15:56:04	2018-01-16 19:24:26
13665	PHYSICIEN	2017-12-01 00:00:00	2017-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	TITULAIRE	2017-12-01 11:36:06	2017-12-07 10:05:49
13666	PHYSICIEN	2017-12-01 00:00:00	2017-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	14213J	TITULAIRE	2017-12-01 11:36:11	2017-12-07 10:05:49
13667	PHYSICIEN	2017-12-01 00:00:00	2017-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	14217N	TITULAIRE	2017-12-01 11:36:16	2017-12-07 10:05:49
13668	PHYSICIEN	2017-12-01 00:00:00	2017-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	01034P	TITULAIRE	2017-12-01 11:36:22	2017-12-07 10:05:49
13669	PHYSICIEN	2017-12-01 00:00:00	2017-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	TITULAIRE	2017-12-01 11:36:27	2017-12-07 10:05:49
13670	PHYSICIEN	2017-12-01 00:00:00	2017-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	14227Q	TITULAIRE	2017-12-01 11:36:31	2017-12-07 10:05:49
13671	PHYSICIEN	2017-12-01 00:00:00	2017-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	14239U	TITULAIRE	2017-12-01 11:36:41	2017-12-07 10:05:49
13672	PHYSICIEN	2017-12-01 00:00:00	2017-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	11031D	SUPPLEANT	2017-12-01 11:36:47	2017-12-07 10:05:49
13673	PHYSICIEN	2017-12-01 00:00:00	2017-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	98024R	SUPPLEANT	2017-12-01 11:36:54	2017-12-07 10:05:49
13674	PHYSICIEN	2017-12-01 00:00:00	2017-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	14042U	SUPPLEANT	2017-12-01 11:37:00	2017-12-07 10:05:49
13675	PHYSICIEN	2017-12-01 00:00:00	2017-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	19553Y	SUPPLEANT	2017-12-01 11:37:06	2017-12-07 10:05:49
13676	PHYSICIEN	2017-12-01 00:00:00	2017-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	19723Y	SUPPLEANT	2017-12-01 11:37:11	2017-12-07 10:05:49
13677	PHYSICIEN	2017-12-01 00:00:00	2017-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	11067R	SUPPLEANT	2017-12-01 11:37:15	2017-12-07 10:05:49
13678	PHYSICIEN	2017-12-01 00:00:00	2017-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	11097X	SUPPLEANT	2017-12-01 11:37:20	2017-12-07 10:05:49
13679	ORDRE	2017-12-01 00:00:00	2017-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	TITULAIRE	2017-12-01 11:43:31	2017-12-07 10:05:56
13680	ORDRE	2017-12-01 00:00:00	2017-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	14213J	TITULAIRE	2017-12-01 11:43:36	2017-12-07 10:05:57
13681	ORDRE	2017-12-01 00:00:00	2017-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	14217N	TITULAIRE	2017-12-01 11:43:42	2017-12-07 10:05:57
13682	ORDRE	2017-12-01 00:00:00	2017-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	01034P	TITULAIRE	2017-12-01 11:43:47	2017-12-07 10:05:57
13683	ORDRE	2017-12-01 00:00:00	2017-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	TITULAIRE	2017-12-01 11:43:53	2017-12-07 10:05:57
13684	ORDRE	2017-12-01 00:00:00	2017-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	14227Q	TITULAIRE	2017-12-01 11:43:58	2017-12-07 10:05:57
13685	ORDRE	2017-12-01 00:00:00	2017-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	14239U	TITULAIRE	2017-12-01 11:44:02	2017-12-07 10:05:57
13686	ORDRE	2017-12-01 00:00:00	2017-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	11031D	SUPPLEANT	2017-12-01 11:44:06	2017-12-07 10:05:57
13687	ORDRE	2017-12-01 00:00:00	2017-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	98024R	SUPPLEANT	2017-12-01 11:44:11	2017-12-07 10:05:57
13688	ORDRE	2017-12-01 00:00:00	2017-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	14042U	SUPPLEANT	2017-12-01 11:44:15	2017-12-07 10:05:57
14495	ENTREPRISES	2018-10-10 00:00:00	2019-05-23 00:00:00	ANCIEN	\N	\N	\N	\N	04071H	\N	\N	\N
13689	ORDRE	2017-12-01 00:00:00	2017-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	19553Y	SUPPLEANT	2017-12-01 11:44:23	2017-12-07 10:05:57
13690	ORDRE	2017-12-01 00:00:00	2017-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	19723Y	SUPPLEANT	2017-12-01 11:44:27	2017-12-07 10:05:57
13691	ORDRE	2017-12-01 00:00:00	2017-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	11067R	SUPPLEANT	2017-12-01 11:44:32	2017-12-07 10:05:57
13692	ORDRE	2017-12-01 00:00:00	2017-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	11097X	SUPPLEANT	2017-12-01 11:44:37	2017-12-07 10:05:57
13693	ALSTOM	2017-11-29 00:00:00	2018-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	08028W	\N	2017-12-01 14:23:39	\N
13770	FORCES	2018-01-17 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	\N	2018-01-16 14:45:15	\N
13771	FORCES	2018-01-17 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	04071H	\N	2018-01-16 14:45:20	\N
13772	FORCES	2018-01-17 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	15447F	\N	2018-01-16 14:45:26	\N
13773	FORCES	2018-01-17 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	11049P	\N	2018-01-16 14:45:31	2018-01-31 11:37:18
13774	FORCES	2018-01-17 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	19729F	\N	2018-01-16 14:45:36	\N
13775	FORCES	2018-01-17 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	19581D	\N	2018-01-16 14:45:41	\N
13776	FORCES	2018-01-17 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	19443T	\N	2018-01-16 14:45:47	\N
13777	FORCES	2018-01-17 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	10015M	\N	2018-01-16 14:45:52	2018-02-07 11:35:41
13778	FORCES	2018-01-17 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	19703U	\N	2018-01-16 14:45:57	\N
13779	FORCES	2018-01-17 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	11053K	\N	2018-01-16 14:46:01	\N
13780	FORCES	2018-01-17 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	14205J	\N	2018-01-16 14:46:05	\N
13781	FORCES	2018-01-17 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	19721W	\N	2018-01-16 14:46:14	2018-01-31 11:41:44
13782	FORCES	2018-01-17 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	08058D	\N	2018-01-16 14:46:19	2018-01-31 11:36:30
13783	FORCES	2018-01-17 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	19251M	\N	2018-01-16 14:46:24	\N
13784	FORCES	2018-01-17 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	08035V	\N	2018-01-16 14:46:29	2018-01-31 11:42:41
13785	FORCES	2018-01-17 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	14097Y	\N	2018-01-16 14:46:36	\N
13786	FORCES	2018-01-17 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	14021P	\N	2018-01-16 14:47:07	\N
13787	FORCES	2018-01-17 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	19543W	\N	2018-01-16 14:47:12	2018-01-31 11:41:15
13788	FORCES	2018-01-17 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	19719D	\N	2018-01-16 14:47:19	2018-01-31 11:42:13
13789	FORCES	2018-01-17 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	14111D	\N	2018-01-16 14:47:33	2018-01-31 11:43:57
13790	ETAT	2018-01-17 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	19515S	\N	2018-01-16 14:55:43	2018-02-02 09:30:09
13791	ETAT	2018-01-17 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	14069U	\N	2018-01-16 14:55:48	2018-02-02 09:30:09
13792	ETAT	2018-01-17 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	\N	2018-01-16 14:55:54	2018-02-02 09:30:09
13793	ETAT	2018-01-17 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	14187A	\N	2018-01-16 14:55:59	2018-02-02 09:30:09
13794	ETAT	2018-01-17 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	14087W	\N	2018-01-16 14:56:04	2018-02-02 10:35:58
13795	ETAT	2018-01-17 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	14026U	\N	2018-01-16 14:56:08	2018-02-02 09:30:09
13796	ETAT	2018-01-17 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	19399H	\N	2018-01-16 14:56:15	2018-02-02 09:30:09
13797	ETAT	2018-01-17 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	\N	2018-01-16 14:56:19	2018-02-02 09:47:01
13798	ETAT	2018-01-17 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	\N	2018-01-16 14:56:24	2018-02-15 17:54:51
13799	ETAT	2018-01-17 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	19711U	\N	2018-01-16 14:56:30	2018-02-02 10:35:00
13800	ETAT	2018-01-17 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	14031R	\N	2018-01-16 14:56:35	2018-02-02 09:30:09
13801	ETAT	2018-01-17 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	14071N	\N	2018-01-16 14:56:40	2018-02-02 09:30:09
13802	ETAT	2018-01-17 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	19573D	\N	2018-01-16 14:56:45	2018-02-02 09:30:09
13803	ETAT	2018-01-17 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	19533U	\N	2018-01-16 14:56:50	2018-02-02 09:30:09
13804	ETAT	2018-01-17 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	14157T	\N	2018-01-16 14:56:55	2018-02-02 09:30:09
13805	ETAT	2018-01-17 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	14173T	\N	2018-01-16 14:57:01	2018-02-02 09:30:09
13806	ETAT	2018-01-17 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	19749K	\N	2018-01-16 14:57:11	2018-02-02 09:30:09
13807	ETAT	2018-01-17 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	14103D	\N	2018-01-16 14:57:16	2018-02-02 10:12:16
13808	ETAT	2018-01-17 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	19479G	\N	2018-01-16 14:58:17	2018-02-02 09:30:09
13809	ETAT	2018-01-17 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	19441R	\N	2018-01-16 14:58:22	2018-02-02 09:30:09
13810	ETAT	2018-01-17 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	01024M	\N	2018-01-16 14:58:31	2018-02-02 09:30:09
13811	ETAT	2018-01-17 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	\N	2018-01-16 14:58:38	2018-02-02 09:30:09
13812	ETAT	2018-01-17 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	19651A	\N	2018-01-16 14:58:44	2018-02-02 09:30:09
13813	ETAT	2018-01-17 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	19253P	\N	2018-01-16 14:58:49	2018-02-02 09:30:09
13814	ETAT	2018-01-17 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	19719D	\N	2018-01-16 14:58:55	2018-02-02 09:30:09
13815	ETAT	2018-01-17 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	19545Y	\N	2018-01-16 14:59:00	2018-02-02 09:30:09
13816	FORCES	2018-01-17 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	\N	2018-01-16 15:51:04	2018-01-31 11:39:35
13817	ETAT	2018-01-17 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	14207L	\N	2018-01-16 16:46:59	2018-02-02 09:30:09
13818	ETAT	2018-01-17 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	14151M	\N	2018-01-16 16:47:04	2018-02-02 10:21:31
13819	ETAT	2018-01-17 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	11110B	\N	2018-01-16 16:47:09	2018-02-02 09:30:09
13820	ETAT	2018-01-17 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	12016W	\N	2018-01-16 16:47:14	2018-02-02 09:30:09
13821	ETAT	2018-01-17 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	08053X	\N	2018-01-16 16:47:18	2018-02-02 09:30:09
13822	ETAT	2018-01-17 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	11067R	\N	2018-01-16 16:47:23	2018-02-02 10:37:48
13823	ETAT	2018-01-17 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	19503N	\N	2018-01-16 16:47:35	2018-02-02 09:30:09
13824	ETAT	2018-01-17 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	19689Q	\N	2018-01-16 16:47:40	2018-02-02 09:30:09
13825	ETAT	2018-01-17 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	11040E	\N	2018-01-16 16:49:55	2018-02-02 09:30:09
9179	VIANDE	2013-03-13 00:00:00	2013-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	\N	\N	2018-02-02 10:20:31
13827	ETAT	2018-01-17 00:00:00	2018-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	\N	2018-01-16 16:50:03	2018-02-02 09:30:09
13884	SOCIETE	2018-01-31 00:00:00	2018-08-10 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	\N	2018-02-02 10:20:53	\N
13887	SOCIETE	2018-01-31 00:00:00	2018-08-10 00:00:00	ANCIEN	\N	\N	\N	\N	14087W	\N	2018-02-02 10:36:55	\N
13886	SOCIETE	2018-01-31 00:00:00	2018-08-10 00:00:00	ANCIEN	\N	\N	\N	\N	14151M	\N	2018-02-02 10:29:18	\N
13888	SOCIETE	2018-01-31 00:00:00	2018-08-10 00:00:00	ANCIEN	\N	\N	\N	\N	11067R	\N	2018-02-02 10:38:14	\N
13889	SOCIETE	2018-01-31 00:00:00	2018-08-10 00:00:00	ANCIEN	\N	\N	\N	\N	19711U	\N	2018-02-02 10:39:32	\N
13971	COMSPEAPU	2018-02-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08055A	\N	2018-02-23 16:12:59	\N
14040	EFFICACITE	2018-03-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	11048N	TITULAIRE	2018-03-21 14:05:53	\N
14041	EFFICACITE	2018-03-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	14026U	TITULAIRE	2018-03-21 14:05:58	\N
14042	EFFICACITE	2018-03-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14103D	TITULAIRE	2018-03-21 14:06:02	\N
14043	EFFICACITE	2018-03-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	TITULAIRE	2018-03-21 14:06:08	\N
14044	EFFICACITE	2018-03-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	11067R	TITULAIRE	2018-03-21 14:06:13	\N
14045	EFFICACITE	2018-03-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	19503N	TITULAIRE	2018-03-21 14:06:18	\N
14046	EFFICACITE	2018-03-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	19651A	TITULAIRE	2018-03-21 14:06:24	\N
14047	EFFICACITE	2018-03-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	11040E	SUPPLEANT	2018-03-21 14:06:29	2018-03-21 14:07:12
14048	EFFICACITE	2018-03-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	19719D	SUPPLEANT	2018-03-21 14:06:35	2018-03-21 14:07:16
14049	EFFICACITE	2018-03-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	SUPPLEANT	2018-03-21 14:06:44	2018-03-21 14:07:19
14050	EFFICACITE	2018-03-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14087W	SUPPLEANT	2018-03-21 14:06:49	2018-03-21 14:07:23
14051	EFFICACITE	2018-03-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	14031R	SUPPLEANT	2018-03-21 14:06:54	2018-03-21 14:07:27
14052	EFFICACITE	2018-03-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	19533U	SUPPLEANT	2018-03-21 14:06:59	2018-03-21 14:07:31
14053	EFFICACITE	2018-03-14 00:00:00	2022-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	19689Q	SUPPLEANT	2018-03-21 14:07:04	2018-03-21 14:07:33
14178	SECRET	2018-05-22 00:00:00	2018-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	2018-05-22 16:46:11	2018-06-07 17:10:53
14179	SECRET	2018-05-22 00:00:00	2018-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	08018U	TITULAIRE	2018-05-22 16:46:15	2018-06-07 17:10:53
14180	SECRET	2018-05-22 00:00:00	2018-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	14069U	TITULAIRE	2018-05-22 16:46:21	2018-06-07 17:10:53
14181	SECRET	2018-05-22 00:00:00	2018-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	14089Y	TITULAIRE	2018-05-22 16:46:28	2018-06-07 17:10:53
14182	SECRET	2018-05-22 00:00:00	2018-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	11026G	TITULAIRE	2018-05-22 16:46:35	2018-06-07 17:10:53
14183	SECRET	2018-05-22 00:00:00	2018-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	14151M	TITULAIRE	2018-05-22 16:46:39	2018-06-07 17:10:53
14184	SECRET	2018-05-22 00:00:00	2018-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	11072N	TITULAIRE	2018-05-22 16:46:48	2018-06-07 17:10:53
13828	CAE	2018-01-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19747H	\N	2018-01-16 00:00:00	\N
13829	AFCL	2018-01-16 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	19749K	\N	2018-01-16 19:17:56	\N
13830	CDD	2018-01-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19745F	\N	2018-01-16 00:00:00	\N
13831	FINC	2018-01-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19741B	\N	2018-01-16 00:00:00	\N
13957	CONTRATS	2018-02-22 00:00:00	2018-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	2018-02-22 10:59:20	2018-03-21 14:02:21
13958	CONTRATS	2018-02-22 00:00:00	2018-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	07034Q	TITULAIRE	2018-02-22 10:59:26	2018-03-21 14:02:21
13959	CONTRATS	2018-02-22 00:00:00	2018-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	19447X	TITULAIRE	2018-02-22 10:59:30	2018-03-21 14:02:21
13960	CONTRATS	2018-02-22 00:00:00	2018-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	14205J	TITULAIRE	2018-02-22 10:59:35	2018-03-21 14:02:21
13961	CONTRATS	2018-02-22 00:00:00	2018-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	14065Q	TITULAIRE	2018-02-22 10:59:40	2018-03-21 14:02:21
13962	CONTRATS	2018-02-22 00:00:00	2018-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	19649G	TITULAIRE	2018-02-22 10:59:46	2018-03-21 14:02:21
13963	CONTRATS	2018-02-22 00:00:00	2018-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	19543W	TITULAIRE	2018-02-22 10:59:51	2018-03-21 14:02:21
13964	CONTRATS	2018-02-22 00:00:00	2018-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	14069U	SUPPLEANT	2018-02-22 10:59:55	2018-03-21 14:02:21
13965	CONTRATS	2018-02-22 00:00:00	2018-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	19629C	SUPPLEANT	2018-02-22 11:00:03	2018-03-21 14:02:21
13966	CONTRATS	2018-02-22 00:00:00	2018-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	2018-02-22 11:00:11	2018-03-21 14:02:21
13967	CONTRATS	2018-02-22 00:00:00	2018-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	SUPPLEANT	2018-02-22 11:00:19	2018-03-21 14:02:21
13968	CONTRATS	2018-02-22 00:00:00	2018-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	14151M	SUPPLEANT	2018-02-22 11:00:28	2018-03-21 14:02:21
13969	CONTRATS	2018-02-22 00:00:00	2018-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	08044W	SUPPLEANT	2018-02-22 11:00:35	2018-03-21 14:02:21
13970	CONTRATS	2018-02-22 00:00:00	2018-03-14 00:00:00	ANCIEN	\N	\N	\N	\N	14147R	SUPPLEANT	2018-02-22 11:00:42	2018-03-21 14:02:21
14185	SECRET	2018-05-22 00:00:00	2018-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	11040E	SUPPLEANT	2018-05-22 16:46:56	2018-06-07 17:10:53
14278	PENURIE	2018-06-27 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04045F	\N	\N	\N
14311	SOCI	2018-07-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19760E	\N	\N	\N
14312	LOIS	2018-07-04 00:00:00	2020-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	19762G	\N	\N	\N
14386	NEANT	2018-07-28 00:00:00	2018-09-13 00:00:00	ANCIEN	\N	\N	\N	\N	19766L	\N	\N	\N
14403	MANIPULATION	2018-09-25 00:00:00	2018-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	07034Q	SUPPLEANT	\N	\N
14404	MANIPULATION	2018-09-25 00:00:00	2018-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	14229S	SUPPLEANT	\N	\N
14405	INFORMATION	2018-09-25 00:00:00	2018-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
14406	INFORMATION	2018-09-25 00:00:00	2018-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	08018U	TITULAIRE	\N	\N
14407	INFORMATION	2018-09-25 00:00:00	2018-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	08039A	TITULAIRE	\N	\N
14408	INFORMATION	2018-09-25 00:00:00	2018-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	04070G	TITULAIRE	\N	\N
14409	INFORMATION	2018-09-25 00:00:00	2018-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	14151M	TITULAIRE	\N	\N
14410	INFORMATION	2018-09-25 00:00:00	2018-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	04059M	TITULAIRE	\N	\N
14411	INFORMATION	2018-09-25 00:00:00	2018-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	19629C	TITULAIRE	\N	\N
14412	INFORMATION	2018-09-25 00:00:00	2018-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	14069U	SUPPLEANT	\N	\N
14413	INFORMATION	2018-09-25 00:00:00	2018-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	11083R	SUPPLEANT	\N	\N
14414	INFORMATION	2018-09-25 00:00:00	2018-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	19699S	SUPPLEANT	\N	\N
14415	INFORMATION	2018-09-25 00:00:00	2018-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	19593H	SUPPLEANT	\N	\N
14416	INFORMATION	2018-09-25 00:00:00	2018-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	19573D	SUPPLEANT	\N	\N
14417	INFORMATION	2018-09-25 00:00:00	2018-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	07034Q	SUPPLEANT	\N	\N
14418	INFORMATION	2018-09-25 00:00:00	2018-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	14229S	SUPPLEANT	\N	\N
14419	FRAUDE	2018-10-02 00:00:00	2018-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	11074Q	TITULAIRE	\N	\N
14420	FRAUDE	2018-10-02 00:00:00	2018-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	08011M	TITULAIRE	\N	\N
14421	FRAUDE	2018-10-02 00:00:00	2018-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04071H	TITULAIRE	\N	\N
14422	FRAUDE	2018-10-02 00:00:00	2018-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	TITULAIRE	\N	\N
14423	FRAUDE	2018-10-02 00:00:00	2018-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	19479G	TITULAIRE	\N	\N
14424	FRAUDE	2018-10-02 00:00:00	2018-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	19689Q	TITULAIRE	\N	\N
14425	FRAUDE	2018-10-02 00:00:00	2018-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	19719D	TITULAIRE	\N	\N
14426	FRAUDE	2018-10-02 00:00:00	2018-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	19651A	SUPPLEANT	\N	\N
14427	FRAUDE	2018-10-02 00:00:00	2018-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	19741B	SUPPLEANT	\N	\N
14428	FRAUDE	2018-10-02 00:00:00	2018-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	11040E	SUPPLEANT	\N	\N
14429	FRAUDE	2018-10-02 00:00:00	2018-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	14085U	SUPPLEANT	\N	\N
14430	FRAUDE	2018-10-02 00:00:00	2018-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	SUPPLEANT	\N	\N
14431	FRAUDE	2018-10-02 00:00:00	2018-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	11070L	SUPPLEANT	\N	\N
14432	FRAUDE	2018-10-02 00:00:00	2018-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	19711U	SUPPLEANT	\N	\N
14433	RETRAIT	2018-10-10 00:00:00	2019-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	96004D	\N	\N	\N
14434	RETRAIT	2018-10-10 00:00:00	2019-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	14069U	\N	\N	\N
14435	RETRAIT	2018-10-10 00:00:00	2019-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	14053L	\N	\N	\N
14436	RETRAIT	2018-10-10 00:00:00	2019-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	19507S	\N	\N	\N
14437	RETRAIT	2018-10-10 00:00:00	2019-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	04035D	\N	\N	\N
14438	RETRAIT	2018-10-10 00:00:00	2019-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	01057W	\N	\N	\N
14439	RETRAIT	2018-10-10 00:00:00	2019-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	04097T	\N	\N	\N
14440	RETRAIT	2018-10-10 00:00:00	2019-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	04061F	\N	\N	\N
14441	RETRAIT	2018-10-10 00:00:00	2019-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	19709B	\N	\N	\N
14442	RETRAIT	2018-10-10 00:00:00	2019-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	92040Q	\N	\N	\N
14443	RETRAIT	2018-10-10 00:00:00	2019-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	14169X	\N	\N	\N
14444	RETRAIT	2018-10-10 00:00:00	2019-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	19573D	\N	\N	\N
14445	RETRAIT	2018-10-10 00:00:00	2019-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	98050T	\N	\N	\N
14446	RETRAIT	2018-10-10 00:00:00	2019-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	14331P	\N	\N	\N
14447	RETRAIT	2018-10-10 00:00:00	2019-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	19421M	\N	\N	\N
14448	RETRAIT	2018-10-10 00:00:00	2019-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	01058X	\N	\N	\N
14449	RETRAIT	2018-10-10 00:00:00	2019-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	11083R	\N	\N	\N
14450	RETRAIT	2018-10-10 00:00:00	2019-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	\N	\N	\N
14451	RETRAIT	2018-10-10 00:00:00	2019-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	98022P	\N	\N	\N
14452	RETRAIT	2018-10-10 00:00:00	2019-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	08031R	\N	\N	\N
14453	RETRAIT	2018-10-10 00:00:00	2019-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	04057K	\N	\N	\N
14454	RETRAIT	2018-10-10 00:00:00	2019-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	01060R	\N	\N	\N
14455	RETRAIT	2018-10-10 00:00:00	2019-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	08043V	\N	\N	\N
14456	RETRAIT	2018-10-10 00:00:00	2019-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	19251M	\N	\N	\N
14457	RETRAIT	2018-10-10 00:00:00	2019-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	19333N	\N	\N	\N
14458	RETRAIT	2018-10-10 00:00:00	2019-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	14097Y	\N	\N	\N
14459	RETRAIT	2018-10-10 00:00:00	2019-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	08017T	\N	\N	\N
14460	RETRAIT	2018-10-10 00:00:00	2019-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	14001X	\N	\N	\N
14461	RETRAIT	2018-10-10 00:00:00	2019-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	98035U	\N	\N	\N
14462	RETRAIT	2018-10-10 00:00:00	2019-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	01062T	\N	\N	\N
14463	SURTRANSPO	2018-10-10 00:00:00	2018-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	14133K	\N	\N	\N
14464	SURTRANSPO	2018-10-10 00:00:00	2018-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	14115H	\N	\N	\N
14465	SURTRANSPO	2018-10-10 00:00:00	2018-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	96004D	\N	\N	\N
14466	SURTRANSPO	2018-10-10 00:00:00	2018-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	19747H	\N	\N	\N
14467	SURTRANSPO	2018-10-10 00:00:00	2018-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	19701S	\N	\N	\N
14468	SURTRANSPO	2018-10-10 00:00:00	2018-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	14079W	\N	\N	\N
14469	SURTRANSPO	2018-10-10 00:00:00	2018-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	\N	\N	\N
14470	SURTRANSPO	2018-10-10 00:00:00	2018-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	14033T	\N	\N	\N
14471	SURTRANSPO	2018-10-10 00:00:00	2018-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	14213J	\N	\N	\N
14472	SURTRANSPO	2018-10-10 00:00:00	2018-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	14061L	\N	\N	\N
14473	SURTRANSPO	2018-10-10 00:00:00	2018-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	\N	\N	\N
14474	SURTRANSPO	2018-10-10 00:00:00	2018-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	08039A	\N	\N	\N
14475	SURTRANSPO	2018-10-10 00:00:00	2018-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	14031R	\N	\N	\N
14476	SURTRANSPO	2018-10-10 00:00:00	2018-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	14237S	\N	\N	\N
14477	SURTRANSPO	2018-10-10 00:00:00	2018-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	10015M	\N	\N	\N
14478	SURTRANSPO	2018-10-10 00:00:00	2018-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	\N	\N	\N
14479	SURTRANSPO	2018-10-10 00:00:00	2018-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	11083R	\N	\N	\N
14480	SURTRANSPO	2018-10-10 00:00:00	2018-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	\N	\N	\N
14481	SURTRANSPO	2018-10-10 00:00:00	2018-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	19553Y	\N	\N	\N
14482	SURTRANSPO	2018-10-10 00:00:00	2018-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	19563B	\N	\N	\N
14483	SURTRANSPO	2018-10-10 00:00:00	2018-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	17589D	\N	\N	\N
14484	SURTRANSPO	2018-10-10 00:00:00	2018-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	19549D	\N	\N	\N
14485	SURTRANSPO	2018-10-10 00:00:00	2018-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	14207L	\N	\N	\N
14486	SURTRANSPO	2018-10-10 00:00:00	2018-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	19725B	\N	\N	\N
14487	SURTRANSPO	2018-10-10 00:00:00	2018-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	14001X	\N	\N	\N
14488	SURTRANSPO	2018-10-10 00:00:00	2018-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	14257W	\N	\N	\N
14489	SURTRANSPO	2018-10-10 00:00:00	2018-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	19503N	\N	\N	\N
14490	SURTRANSPO	2018-10-10 00:00:00	2018-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	14229S	\N	\N	\N
14491	SURTRANSPO	2018-10-10 00:00:00	2018-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	19669L	\N	\N	\N
14492	ENTREPRISES	2018-10-10 00:00:00	2019-05-23 00:00:00	ANCIEN	\N	\N	\N	\N	19515S	\N	\N	\N
14493	ENTREPRISES	2018-10-10 00:00:00	2019-05-23 00:00:00	ANCIEN	\N	\N	\N	\N	19667J	\N	\N	\N
14494	ENTREPRISES	2018-10-10 00:00:00	2019-05-23 00:00:00	ANCIEN	\N	\N	\N	\N	14329V	\N	\N	\N
13993	BREXIT2	2017-11-08 00:00:00	2020-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	96004D	\N	2018-03-12 16:11:16	\N
13994	BREXIT2	2017-11-08 00:00:00	2018-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	98053W	\N	2018-03-12 16:11:21	2018-05-31 10:52:17
13995	BREXIT2	2017-11-08 00:00:00	2020-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	04097T	\N	2018-03-12 16:11:26	\N
13996	BREXIT2	2017-11-08 00:00:00	2020-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	14097Y	\N	2018-03-12 16:11:32	\N
13997	BREXIT2	2017-11-08 00:00:00	2019-06-24 00:00:00	ANCIEN	\N	\N	\N	\N	04061F	\N	2018-03-12 16:11:36	\N
13998	BREXIT2	2017-11-08 00:00:00	2020-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	14073Q	\N	2018-03-12 16:11:42	\N
13999	BREXIT2	2017-11-08 00:00:00	2020-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	14001X	\N	2018-03-12 16:11:48	\N
14000	BREXIT2	2017-11-08 00:00:00	2020-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	14221J	\N	2018-03-12 16:11:55	\N
14001	BREXIT2	2017-11-08 00:00:00	2020-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	04057K	\N	2018-03-12 16:12:00	\N
14002	BREXIT2	2017-11-08 00:00:00	2020-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	98035U	\N	2018-03-12 16:12:05	\N
14003	BREXIT2	2017-11-08 00:00:00	2020-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	04042C	\N	2018-03-12 16:12:10	\N
14004	BREXIT2	2017-11-08 00:00:00	2020-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	14133K	\N	2018-03-12 16:12:14	\N
14005	BREXIT2	2017-11-08 00:00:00	2020-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	14255U	\N	2018-03-12 16:12:19	\N
14006	BREXIT2	2017-11-08 00:00:00	2020-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	19251M	\N	2018-03-12 16:12:26	\N
14007	BREXIT2	2017-11-08 00:00:00	2020-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	04035D	\N	2018-03-12 16:12:31	\N
14008	BREXIT2	2017-11-08 00:00:00	2020-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	98022P	\N	2018-03-12 16:12:37	\N
14009	BREXIT2	2017-11-08 00:00:00	2020-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	19709B	\N	2018-03-12 16:12:42	\N
14010	BREXIT2	2017-11-08 00:00:00	2020-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	98050T	\N	2018-03-12 16:12:49	\N
14011	BREXIT2	2017-11-08 00:00:00	2020-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	01062T	\N	2018-03-12 16:12:55	\N
14012	BREXIT2	2017-11-08 00:00:00	2020-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	\N	2018-03-12 16:12:59	\N
14150	MARCHE	2018-04-18 00:00:00	2018-04-20 00:00:00	ANCIEN	\N	\N	\N	\N	11074Q	TITULAIRE	2018-04-18 11:42:06	2018-05-22 16:39:12
14151	MARCHE	2018-04-18 00:00:00	2018-04-20 00:00:00	ANCIEN	\N	\N	\N	\N	08011M	TITULAIRE	2018-04-18 11:42:12	2018-05-22 16:39:12
14152	MARCHE	2018-04-18 00:00:00	2018-04-20 00:00:00	ANCIEN	\N	\N	\N	\N	19741B	TITULAIRE	2018-04-18 11:42:19	2018-05-22 16:39:12
14153	MARCHE	2018-04-18 00:00:00	2018-04-20 00:00:00	ANCIEN	\N	\N	\N	\N	14331P	TITULAIRE	2018-04-18 11:42:24	2018-05-22 16:39:12
14154	MARCHE	2018-04-18 00:00:00	2018-04-20 00:00:00	ANCIEN	\N	\N	\N	\N	19479G	TITULAIRE	2018-04-18 11:42:32	2018-05-22 16:39:12
14155	MARCHE	2018-04-18 00:00:00	2018-04-20 00:00:00	ANCIEN	\N	\N	\N	\N	14225N	TITULAIRE	2018-04-18 11:42:36	2018-05-22 16:39:12
14156	MARCHE	2018-04-18 00:00:00	2018-04-20 00:00:00	ANCIEN	\N	\N	\N	\N	19349W	TITULAIRE	2018-04-18 11:42:41	2018-05-22 16:39:12
14157	MARCHE	2018-04-18 00:00:00	2018-04-20 00:00:00	ANCIEN	\N	\N	\N	\N	11040E	SUPPLEANT	2018-04-18 11:42:49	2018-05-22 16:39:12
14158	MARCHE	2018-04-18 00:00:00	2018-04-20 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	SUPPLEANT	2018-04-18 11:42:59	2018-05-22 16:39:12
14159	MARCHE	2018-04-18 00:00:00	2018-04-20 00:00:00	ANCIEN	\N	\N	\N	\N	11070L	SUPPLEANT	2018-04-18 11:45:34	2018-05-22 16:39:12
14160	MARCHE	2018-04-18 00:00:00	2018-04-20 00:00:00	ANCIEN	\N	\N	\N	\N	14034U	SUPPLEANT	2018-04-18 11:45:44	2018-05-22 16:39:12
14161	MARCHE	2018-04-18 00:00:00	2018-04-20 00:00:00	ANCIEN	\N	\N	\N	\N	14121F	SUPPLEANT	2018-04-18 11:45:51	2018-05-22 16:39:12
14162	MARCHE	2018-04-18 00:00:00	2018-04-20 00:00:00	ANCIEN	\N	\N	\N	\N	19711U	SUPPLEANT	2018-04-18 11:47:04	2018-05-22 16:39:12
14163	MARCHE	2018-04-18 00:00:00	2018-04-20 00:00:00	ANCIEN	\N	\N	\N	\N	19671E	SUPPLEANT	2018-04-18 11:47:11	2018-05-22 16:39:12
14164	EUROPEEN	2018-04-17 00:00:00	2018-04-20 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	2018-04-18 11:49:27	2018-05-22 16:39:37
14165	EUROPEEN	2018-04-17 00:00:00	2018-04-20 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	TITULAIRE	2018-04-18 11:49:31	2018-05-22 16:39:37
14166	EUROPEEN	2018-04-17 00:00:00	2018-04-20 00:00:00	ANCIEN	\N	\N	\N	\N	14069U	TITULAIRE	2018-04-18 11:49:35	2018-05-22 16:39:37
14167	EUROPEEN	2018-04-17 00:00:00	2018-04-20 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	TITULAIRE	2018-04-18 11:49:40	2018-05-22 16:39:37
14168	EUROPEEN	2018-04-17 00:00:00	2018-04-20 00:00:00	ANCIEN	\N	\N	\N	\N	14089Y	TITULAIRE	2018-04-18 11:49:45	2018-05-22 16:39:37
14169	EUROPEEN	2018-04-17 00:00:00	2018-04-20 00:00:00	ANCIEN	\N	\N	\N	\N	11026G	TITULAIRE	2018-04-18 11:49:50	2018-05-22 16:39:37
14170	EUROPEEN	2018-04-17 00:00:00	2018-04-20 00:00:00	ANCIEN	\N	\N	\N	\N	14001X	TITULAIRE	2018-04-18 11:49:56	2018-05-22 16:39:37
14171	EUROPEEN	2018-04-17 00:00:00	2018-04-20 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	SUPPLEANT	2018-04-18 11:50:02	2018-05-22 16:39:37
14172	EUROPEEN	2018-04-17 00:00:00	2018-04-20 00:00:00	ANCIEN	\N	\N	\N	\N	19253P	SUPPLEANT	2018-04-18 11:50:16	2018-05-22 16:39:37
14173	EUROPEEN	2018-04-17 00:00:00	2018-04-20 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	SUPPLEANT	2018-04-18 11:50:24	2018-05-22 16:39:37
14174	EUROPEEN	2018-04-17 00:00:00	2018-04-20 00:00:00	ANCIEN	\N	\N	\N	\N	19447X	SUPPLEANT	2018-04-18 11:50:34	2018-05-22 16:39:37
14175	EUROPEEN	2018-04-17 00:00:00	2018-04-20 00:00:00	ANCIEN	\N	\N	\N	\N	12016W	SUPPLEANT	2018-04-18 11:50:43	2018-05-22 16:39:37
14176	EUROPEEN	2018-04-17 00:00:00	2018-04-20 00:00:00	ANCIEN	\N	\N	\N	\N	11085T	SUPPLEANT	2018-04-18 11:50:58	2018-05-22 16:39:37
14177	EUROPEEN	2018-04-17 00:00:00	2018-04-20 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	2018-04-18 11:51:05	2018-05-22 16:39:37
14186	SECRET	2018-05-22 00:00:00	2018-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	19629C	SUPPLEANT	2018-05-22 16:47:03	2018-06-07 17:10:53
14187	SECRET	2018-05-22 00:00:00	2018-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	14259Y	SUPPLEANT	2018-05-22 16:47:09	2018-06-07 17:10:53
14188	SECRET	2018-05-22 00:00:00	2018-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	SUPPLEANT	2018-05-22 16:47:15	2018-06-07 17:10:53
14189	SECRET	2018-05-22 00:00:00	2018-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	19649G	SUPPLEANT	2018-05-22 16:47:20	2018-06-07 17:10:53
14190	SECRET	2018-05-22 00:00:00	2018-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	19447X	SUPPLEANT	2018-05-22 16:47:28	2018-06-07 17:10:53
14191	SECRET	2018-05-22 00:00:00	2018-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	11085T	SUPPLEANT	2018-05-22 16:47:33	2018-06-07 17:10:53
14192	EAU	2018-04-18 00:00:00	2018-05-18 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	2018-05-22 16:49:50	2018-06-07 17:11:04
14193	EAU	2018-04-18 00:00:00	2018-05-18 00:00:00	ANCIEN	\N	\N	\N	\N	14069U	TITULAIRE	2018-05-22 16:49:56	2018-06-07 17:11:04
14194	EAU	2018-04-18 00:00:00	2018-05-18 00:00:00	ANCIEN	\N	\N	\N	\N	14259Y	TITULAIRE	2018-05-22 16:50:04	2018-06-07 17:11:04
14195	EAU	2018-04-18 00:00:00	2018-05-18 00:00:00	ANCIEN	\N	\N	\N	\N	11085T	TITULAIRE	2018-05-22 16:50:09	2018-06-07 17:11:04
14196	EAU	2018-04-18 00:00:00	2018-05-18 00:00:00	ANCIEN	\N	\N	\N	\N	19725B	TITULAIRE	2018-05-22 16:50:15	2018-06-07 17:11:04
14197	EAU	2018-04-18 00:00:00	2018-05-18 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	TITULAIRE	2018-05-22 16:50:20	2018-06-07 17:11:04
14198	EAU	2018-04-18 00:00:00	2018-05-18 00:00:00	ANCIEN	\N	\N	\N	\N	19543W	TITULAIRE	2018-05-22 16:50:26	2018-06-07 17:11:04
14199	EAU	2018-04-18 00:00:00	2018-05-18 00:00:00	ANCIEN	\N	\N	\N	\N	14089Y	SUPPLEANT	2018-05-22 16:50:31	2018-06-07 17:11:04
14200	EAU	2018-04-18 00:00:00	2018-05-18 00:00:00	ANCIEN	\N	\N	\N	\N	19629C	SUPPLEANT	2018-05-22 16:50:38	2018-06-07 17:11:04
14201	EAU	2018-04-18 00:00:00	2018-05-18 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	2018-05-22 16:50:47	2018-06-07 17:11:04
14202	EAU	2018-04-18 00:00:00	2018-05-18 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	SUPPLEANT	2018-05-22 16:50:54	2018-06-07 17:11:04
14203	EAU	2018-04-18 00:00:00	2018-05-18 00:00:00	ANCIEN	\N	\N	\N	\N	19507S	SUPPLEANT	2018-05-22 16:51:02	2018-06-07 17:11:04
14204	EAU	2018-04-18 00:00:00	2018-05-18 00:00:00	ANCIEN	\N	\N	\N	\N	11049P	SUPPLEANT	2018-05-22 16:51:11	2018-06-07 17:11:04
14205	EAU	2018-04-18 00:00:00	2018-05-18 00:00:00	ANCIEN	\N	\N	\N	\N	14001X	SUPPLEANT	2018-05-22 16:51:20	2018-06-07 17:11:04
14242	OEP	2018-06-19 00:00:00	2018-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
14243	OEP	2018-06-19 00:00:00	2018-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	14179A	TITULAIRE	\N	\N
14244	OEP	2018-06-19 00:00:00	2018-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	TITULAIRE	\N	\N
14245	OEP	2018-06-19 00:00:00	2018-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	19447X	TITULAIRE	\N	\N
14246	OEP	2018-06-19 00:00:00	2018-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	11026G	TITULAIRE	\N	\N
14247	OEP	2018-06-19 00:00:00	2018-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
14248	OEP	2018-06-19 00:00:00	2018-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	19719D	TITULAIRE	\N	\N
14249	OEP	2018-06-19 00:00:00	2018-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	14053L	SUPPLEANT	\N	\N
14250	OEP	2018-06-19 00:00:00	2018-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	\N	\N
14251	OEP	2018-06-19 00:00:00	2018-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	19673G	SUPPLEANT	\N	\N
14252	OEP	2018-06-19 00:00:00	2018-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	08045X	SUPPLEANT	\N	\N
14253	OEP	2018-06-19 00:00:00	2018-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	08018U	SUPPLEANT	\N	\N
14254	OEP	2018-06-19 00:00:00	2018-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	11085T	SUPPLEANT	\N	\N
14255	OEP	2018-06-19 00:00:00	2018-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	SUPPLEANT	\N	\N
14313	PENURIE	2018-07-10 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19421M	\N	\N	\N
13847	SOCIETE	2018-01-31 00:00:00	2018-08-10 00:00:00	ANCIEN	\N	\N	\N	\N	19515S	\N	2018-02-02 09:38:52	\N
13848	SOCIETE	2018-01-31 00:00:00	2018-08-10 00:00:00	ANCIEN	\N	\N	\N	\N	19651A	\N	2018-02-02 09:39:05	\N
13849	SOCIETE	2018-01-31 00:00:00	2018-08-10 00:00:00	ANCIEN	\N	\N	\N	\N	11040E	\N	2018-02-02 09:39:12	\N
13850	SOCIETE	2018-01-31 00:00:00	2018-08-10 00:00:00	ANCIEN	\N	\N	\N	\N	14069U	\N	2018-02-02 09:39:23	\N
13851	SOCIETE	2018-01-31 00:00:00	2018-08-10 00:00:00	ANCIEN	\N	\N	\N	\N	14207L	\N	2018-02-02 09:39:29	\N
13852	SOCIETE	2018-01-31 00:00:00	2018-08-10 00:00:00	ANCIEN	\N	\N	\N	\N	19545Y	\N	2018-02-02 09:39:34	\N
13853	SOCIETE	2018-01-31 00:00:00	2018-08-10 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	\N	2018-02-02 09:39:45	\N
13854	SOCIETE	2018-01-31 00:00:00	2018-08-10 00:00:00	ANCIEN	\N	\N	\N	\N	19253P	\N	2018-02-02 09:39:49	\N
13855	SOCIETE	2018-01-31 00:00:00	2018-08-10 00:00:00	ANCIEN	\N	\N	\N	\N	19719D	\N	2018-02-02 09:39:55	\N
13856	SOCIETE	2018-01-31 00:00:00	2018-08-10 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	\N	2018-02-02 09:40:37	\N
13857	SOCIETE	2018-01-31 00:00:00	2018-08-10 00:00:00	ANCIEN	\N	\N	\N	\N	01024M	\N	2018-02-02 09:40:48	\N
14013	MINEURSENF	2018-03-14 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14239U	\N	2018-03-13 16:56:38	2018-03-22 12:02:08
13859	SOCIETE	2018-01-31 00:00:00	2018-08-10 00:00:00	ANCIEN	\N	\N	\N	\N	11110B	\N	2018-02-02 09:41:02	\N
13860	SOCIETE	2018-01-31 00:00:00	2018-08-10 00:00:00	ANCIEN	\N	\N	\N	\N	14187A	\N	2018-02-02 09:41:09	\N
14014	MINEURSENF	2018-03-14 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	\N	2018-03-13 16:56:46	2018-03-22 12:04:42
13862	SOCIETE	2018-01-31 00:00:00	2018-08-10 00:00:00	ANCIEN	\N	\N	\N	\N	14026U	\N	2018-02-02 09:41:22	\N
13863	SOCIETE	2018-01-31 00:00:00	2018-08-10 00:00:00	ANCIEN	\N	\N	\N	\N	19399H	\N	2018-02-02 09:41:29	\N
14015	MINEURSENF	2018-03-14 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14065Q	\N	2018-03-13 16:56:53	\N
14016	MINEURSENF	2018-03-14 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19549D	\N	2018-03-13 16:56:58	\N
14017	MINEURSENF	2018-03-14 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19367Y	\N	2018-03-13 16:57:08	\N
13867	SOCIETE	2018-01-31 00:00:00	2018-08-10 00:00:00	ANCIEN	\N	\N	\N	\N	19441R	\N	2018-02-02 09:41:49	\N
13868	SOCIETE	2018-01-31 00:00:00	2018-08-10 00:00:00	ANCIEN	\N	\N	\N	\N	14103D	\N	2018-02-02 09:41:54	2018-02-02 10:12:25
13869	SOCIETE	2018-01-31 00:00:00	2018-08-10 00:00:00	ANCIEN	\N	\N	\N	\N	12016W	\N	2018-02-02 09:41:59	\N
13870	SOCIETE	2018-01-31 00:00:00	2018-08-10 00:00:00	ANCIEN	\N	\N	\N	\N	14031R	\N	2018-02-02 09:42:05	\N
13871	SOCIETE	2018-01-31 00:00:00	2018-08-10 00:00:00	ANCIEN	\N	\N	\N	\N	08053X	\N	2018-02-02 09:42:11	\N
14018	MINEURSENF	2018-03-14 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14053L	\N	2018-03-13 16:57:13	\N
13873	SOCIETE	2018-01-31 00:00:00	2018-08-10 00:00:00	ANCIEN	\N	\N	\N	\N	14071N	\N	2018-02-02 09:43:26	\N
13874	SOCIETE	2018-01-31 00:00:00	2018-08-10 00:00:00	ANCIEN	\N	\N	\N	\N	19573D	\N	2018-02-02 09:43:32	\N
13875	SOCIETE	2018-01-31 00:00:00	2018-08-10 00:00:00	ANCIEN	\N	\N	\N	\N	19533U	\N	2018-02-02 09:43:38	\N
13876	SOCIETE	2018-01-31 00:00:00	2018-08-10 00:00:00	ANCIEN	\N	\N	\N	\N	19503N	\N	2018-02-02 09:43:50	\N
13877	SOCIETE	2018-01-31 00:00:00	2018-08-10 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	\N	2018-02-02 09:43:58	\N
13878	SOCIETE	2018-01-31 00:00:00	2018-08-10 00:00:00	ANCIEN	\N	\N	\N	\N	19689Q	\N	2018-02-02 09:44:04	\N
13879	SOCIETE	2018-01-31 00:00:00	2018-08-10 00:00:00	ANCIEN	\N	\N	\N	\N	14157T	\N	2018-02-02 09:44:12	\N
13880	SOCIETE	2018-01-31 00:00:00	2018-08-10 00:00:00	ANCIEN	\N	\N	\N	\N	19749K	\N	2018-02-02 09:44:17	\N
13881	SOCIETE	2018-01-31 00:00:00	2018-08-10 00:00:00	ANCIEN	\N	\N	\N	\N	19479G	\N	2018-02-02 09:44:23	\N
13882	SOCIETE	2018-01-31 00:00:00	2018-08-10 00:00:00	ANCIEN	\N	\N	\N	\N	14173T	\N	2018-02-02 09:44:27	\N
13883	SOCIETE	2018-01-31 00:00:00	2018-08-10 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	\N	2018-02-02 09:53:31	2018-02-02 09:54:06
14019	MINEURSENF	2018-03-14 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14195A	\N	2018-03-13 16:57:19	2018-03-22 12:05:43
14020	MINEURSENF	2018-03-14 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19295A	\N	2018-03-13 16:57:24	2018-03-22 12:07:32
14021	MINEURSENF	2018-03-14 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19253P	\N	2018-03-13 16:57:29	2018-03-22 12:08:08
14022	MINEURSENF	2018-03-14 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	\N	2018-03-13 16:57:35	\N
14023	MINEURSENF	2018-03-14 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14217N	\N	2018-03-13 16:57:42	\N
14024	MINEURSENF	2018-03-14 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	\N	2018-03-13 16:57:47	\N
14025	MINEURSENF	2018-03-14 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19577H	\N	2018-03-13 16:57:55	\N
14026	MINEURSENF	2018-03-14 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08045X	\N	2018-03-13 16:58:01	\N
14027	MINEURSENF	2018-03-14 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14087W	\N	2018-03-13 16:58:07	2018-03-22 12:09:35
14028	MINEURSENF	2018-03-14 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14231L	\N	2018-03-13 16:58:13	2018-03-22 12:11:14
14029	MINEURSENF	2018-03-14 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19691J	\N	2018-03-13 16:58:19	\N
14030	MINEURSENF	2018-03-14 00:00:00	2018-05-29 00:00:00	ANCIEN	\N	\N	\N	\N	19553Y	\N	2018-03-13 16:58:25	2018-05-30 15:33:57
14031	MINEURSENF	2018-03-14 00:00:00	2018-04-10 00:00:00	ANCIEN	\N	\N	\N	\N	14213J	\N	2018-03-13 16:58:31	2018-04-10 16:18:44
14032	MINEURSENF	2018-03-14 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19697Q	\N	2018-03-13 16:58:50	\N
14033	MINEURSENF	2018-03-14 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14031R	\N	2018-03-13 16:58:56	\N
14034	MINEURSENF	2018-03-14 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14147R	\N	2018-03-13 16:59:01	\N
14035	MINEURSENF	2018-03-14 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11067R	\N	2018-03-13 16:59:08	\N
14036	MINEURSENF	2018-03-14 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14223L	\N	2018-03-13 16:59:14	\N
14037	MINEURSENF	2018-03-14 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19319Q	\N	2018-03-13 16:59:19	\N
14038	MINEURSENF	2018-03-14 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11045K	\N	2018-03-13 16:59:24	2018-03-22 12:11:41
14039	MINEURSENF	2018-03-14 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	\N	2018-03-13 16:59:29	2018-03-22 12:00:39
2717	20041214N17	2004-12-14 00:00:00	2018-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	98053W	TITULAIRE	\N	2018-05-31 10:52:17
14207	MINEURSENF	2018-05-30 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19629C	\N	2018-05-30 15:37:08	\N
14212	AFCL	2018-06-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19758L	\N	2018-06-05 00:00:00	\N
8386	2011CMP27	2011-12-19 00:00:00	2018-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	98053W	TITULAIRE	\N	2018-05-31 10:52:17
14209	NEANT	2018-06-01 00:00:00	2018-06-04 00:00:00	ANCIEN	\N	\N	\N	\N	19758L	\N	2018-05-31 11:00:21	2018-06-05 20:09:48
8875	AFCL	2012-09-25 00:00:00	2018-06-04 00:00:00	ANCIEN	\N	\N	\N	\N	12041X	\N	\N	2018-06-05 20:05:47
14210	ETRD	2018-06-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	12041X	\N	2018-06-05 00:00:00	\N
14211	AFEU	2018-06-05 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	12041X	\N	2018-06-05 20:07:04	\N
14279	POLYNESIE	2018-06-28 00:00:00	2018-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
14280	POLYNESIE	2018-06-28 00:00:00	2018-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	TITULAIRE	\N	\N
14281	POLYNESIE	2018-06-28 00:00:00	2018-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	19447X	TITULAIRE	\N	\N
14282	POLYNESIE	2018-06-28 00:00:00	2018-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	14089Y	TITULAIRE	\N	\N
14283	POLYNESIE	2018-06-28 00:00:00	2018-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	14065Q	TITULAIRE	\N	\N
14284	POLYNESIE	2018-06-28 00:00:00	2018-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	11026G	TITULAIRE	\N	\N
14285	POLYNESIE	2018-06-28 00:00:00	2018-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	19719D	TITULAIRE	\N	\N
14286	POLYNESIE	2018-06-28 00:00:00	2018-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	14053L	SUPPLEANT	\N	\N
14287	POLYNESIE	2018-06-28 00:00:00	2018-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	\N	\N
14288	POLYNESIE	2018-06-28 00:00:00	2018-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	SUPPLEANT	\N	\N
14289	POLYNESIE	2018-06-28 00:00:00	2018-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	19673G	SUPPLEANT	\N	\N
14290	POLYNESIE	2018-06-28 00:00:00	2018-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	14179A	SUPPLEANT	\N	\N
14291	POLYNESIE	2018-06-28 00:00:00	2018-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	19489J	SUPPLEANT	\N	\N
14292	POLYNESIE	2018-06-28 00:00:00	2018-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	11072N	SUPPLEANT	\N	\N
14293	OEP	2018-06-28 00:00:00	2018-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	14065Q	TITULAIRE	\N	\N
14294	OEP	2018-06-28 00:00:00	2018-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	19489J	SUPPLEANT	\N	\N
14295	ASILE	2018-06-28 00:00:00	2018-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
14296	ASILE	2018-06-28 00:00:00	2018-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
14297	ASILE	2018-06-28 00:00:00	2018-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	14123H	TITULAIRE	\N	\N
14298	ASILE	2018-06-28 00:00:00	2018-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	14089Y	TITULAIRE	\N	\N
14299	ASILE	2018-06-28 00:00:00	2018-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	11026G	TITULAIRE	\N	\N
14300	ASILE	2018-06-28 00:00:00	2018-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	19649G	TITULAIRE	\N	\N
14301	ASILE	2018-06-28 00:00:00	2018-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	19253P	TITULAIRE	\N	\N
14302	ASILE	2018-06-28 00:00:00	2018-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	SUPPLEANT	\N	\N
14303	ASILE	2018-06-28 00:00:00	2018-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	14065Q	SUPPLEANT	\N	\N
14304	ASILE	2018-06-28 00:00:00	2018-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	SUPPLEANT	\N	\N
14305	ASILE	2018-06-28 00:00:00	2018-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	19673G	SUPPLEANT	\N	\N
14306	ASILE	2018-06-28 00:00:00	2018-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	14179A	SUPPLEANT	\N	\N
14307	ASILE	2018-06-28 00:00:00	2018-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	19447X	SUPPLEANT	\N	\N
14308	ASILE	2018-06-28 00:00:00	2018-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	SUPPLEANT	\N	\N
14314	HERBE	2018-07-11 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80013X	\N	\N	\N
14315	EGALIM	2018-07-03 00:00:00	2018-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	11090Q	TITULAIRE	\N	\N
14316	EGALIM	2018-07-03 00:00:00	2018-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	14135M	TITULAIRE	\N	\N
14317	EGALIM	2018-07-03 00:00:00	2018-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	14205J	TITULAIRE	\N	\N
14318	EGALIM	2018-07-03 00:00:00	2018-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	14033T	TITULAIRE	\N	\N
14319	EGALIM	2018-07-03 00:00:00	2018-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	14207L	TITULAIRE	\N	\N
13904	CHUTE	2018-02-07 00:00:00	2018-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	11033F	\N	2018-02-06 16:32:50	\N
13905	CHUTE	2018-02-07 00:00:00	2018-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	19575F	\N	2018-02-06 16:32:56	\N
13906	CHUTE	2018-02-07 00:00:00	2018-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	14089Y	\N	2018-02-06 16:33:04	\N
13907	CHUTE	2018-02-07 00:00:00	2018-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	98029W	\N	2018-02-06 16:33:09	\N
13908	CHUTE	2018-02-07 00:00:00	2018-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	11080N	\N	2018-02-06 16:33:14	\N
13909	CHUTE	2018-02-07 00:00:00	2018-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	11027H	\N	2018-02-06 16:33:28	\N
13910	CHUTE	2018-02-07 00:00:00	2018-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	04008A	\N	2018-02-06 16:33:35	\N
13911	CHUTE	2018-02-07 00:00:00	2018-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	19673G	\N	2018-02-06 16:42:59	\N
13912	CHUTE	2018-02-07 00:00:00	2018-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	02002K	\N	2018-02-06 16:43:06	\N
13913	CHUTE	2018-02-07 00:00:00	2018-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	14199E	\N	2018-02-06 16:43:13	\N
13914	CHUTE	2018-02-07 00:00:00	2018-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	19649G	\N	2018-02-06 16:43:19	\N
13915	CHUTE	2018-02-07 00:00:00	2018-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	08056B	\N	2018-02-06 16:43:24	\N
13916	CHUTE	2018-02-07 00:00:00	2018-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	98022P	\N	2018-02-06 16:43:29	\N
13917	CHUTE	2018-02-07 00:00:00	2018-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	19611R	\N	2018-02-06 16:43:35	\N
13918	CHUTE	2018-02-07 00:00:00	2018-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	11026G	\N	2018-02-06 16:43:39	\N
13919	CHUTE	2018-02-07 00:00:00	2018-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	08010L	\N	2018-02-06 16:43:48	\N
13920	CHUTE	2018-02-07 00:00:00	2018-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	08053X	\N	2018-02-06 16:43:54	\N
14258	PENURIE	2018-06-27 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11031D	\N	\N	\N
13922	CHUTE	2018-02-07 00:00:00	2018-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	98050T	\N	2018-02-06 16:44:03	\N
13923	CHUTE	2018-02-07 00:00:00	2018-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	10015M	\N	2018-02-06 16:44:09	\N
13924	CHUTE	2018-02-07 00:00:00	2018-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	19421M	\N	2018-02-06 16:44:13	\N
13925	CHUTE	2018-02-07 00:00:00	2018-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	19669L	\N	2018-02-06 16:44:18	\N
14259	PENURIE	2018-06-27 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80013X	\N	\N	\N
14260	PENURIE	2018-06-27 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	\N	\N	\N
14261	PENURIE	2018-06-27 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19727D	\N	\N	\N
14262	PENURIE	2018-06-27 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19683J	\N	\N	\N
14263	PENURIE	2018-06-27 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14227Q	\N	\N	\N
14264	PENURIE	2018-06-27 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19575F	\N	\N	\N
14265	PENURIE	2018-06-27 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14357A	\N	\N	\N
14266	PENURIE	2018-06-27 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98024R	\N	\N	\N
14267	PENURIE	2018-06-27 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04061F	\N	\N	\N
14268	PENURIE	2018-06-27 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14213J	\N	\N	\N
14269	PENURIE	2018-06-27 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14223L	\N	\N	\N
14270	PENURIE	2018-06-27 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14237S	\N	\N	\N
14271	PENURIE	2018-06-27 00:00:00	2018-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	19443T	\N	\N	\N
14272	PENURIE	2018-06-27 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95062K	\N	\N	\N
14273	PENURIE	2018-06-27 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19553Y	\N	\N	\N
14274	PENURIE	2018-06-27 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19735D	\N	\N	\N
14275	PENURIE	2018-06-27 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14221J	\N	\N	\N
14276	PENURIE	2018-06-27 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19713W	\N	\N	\N
14277	PENURIE	2018-06-27 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17589D	\N	\N	\N
14309	NEANT	2018-07-01 00:00:00	2018-07-01 00:00:00	ANCIEN	\N	\N	\N	\N	19760E	\N	\N	\N
14310	NEANT	2018-07-01 00:00:00	2018-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	19762G	\N	\N	\N
14320	EGALIM	2018-07-03 00:00:00	2018-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	14257W	TITULAIRE	\N	\N
14321	EGALIM	2018-07-03 00:00:00	2018-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	19563B	TITULAIRE	\N	\N
14322	EGALIM	2018-07-03 00:00:00	2018-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	14115H	SUPPLEANT	\N	\N
14323	EGALIM	2018-07-03 00:00:00	2018-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	08060W	SUPPLEANT	\N	\N
14324	EGALIM	2018-07-03 00:00:00	2018-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	11056N	SUPPLEANT	\N	\N
14325	EGALIM	2018-07-03 00:00:00	2018-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	14357A	SUPPLEANT	\N	\N
14326	EGALIM	2018-07-03 00:00:00	2018-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	19507S	SUPPLEANT	\N	\N
14327	EGALIM	2018-07-03 00:00:00	2018-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	14221J	SUPPLEANT	\N	\N
14328	EGALIM	2018-07-03 00:00:00	2018-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	19269X	SUPPLEANT	\N	\N
14329	AVENIR	2018-07-13 00:00:00	2018-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	TITULAIRE	\N	\N
14330	AVENIR	2018-07-13 00:00:00	2018-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	14087W	TITULAIRE	\N	\N
14331	AVENIR	2018-07-13 00:00:00	2018-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	19679N	TITULAIRE	\N	\N
14332	AVENIR	2018-07-13 00:00:00	2018-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	19521Q	TITULAIRE	\N	\N
14333	AVENIR	2018-07-13 00:00:00	2018-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	TITULAIRE	\N	\N
14334	AVENIR	2018-07-13 00:00:00	2018-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	11067R	TITULAIRE	\N	\N
14335	AVENIR	2018-07-13 00:00:00	2018-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	19553Y	TITULAIRE	\N	\N
14336	AVENIR	2018-07-13 00:00:00	2018-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	19575F	SUPPLEANT	\N	\N
14337	AVENIR	2018-07-13 00:00:00	2018-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	11031D	SUPPLEANT	\N	\N
14338	AVENIR	2018-07-13 00:00:00	2018-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	10006L	SUPPLEANT	\N	\N
14339	AVENIR	2018-07-13 00:00:00	2018-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	19611R	SUPPLEANT	\N	\N
14340	AVENIR	2018-07-13 00:00:00	2018-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	19697Q	SUPPLEANT	\N	\N
14341	AVENIR	2018-07-13 00:00:00	2018-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	14071N	SUPPLEANT	\N	\N
14342	AVENIR	2018-07-13 00:00:00	2018-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	14227Q	SUPPLEANT	\N	\N
14343	VIOLENCES	2018-07-10 00:00:00	2018-07-24 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
14344	VIOLENCES	2018-07-10 00:00:00	2018-07-24 00:00:00	ANCIEN	\N	\N	\N	\N	14147R	TITULAIRE	\N	\N
14345	VIOLENCES	2018-07-10 00:00:00	2018-07-24 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	TITULAIRE	\N	\N
14346	VIOLENCES	2018-07-10 00:00:00	2018-07-24 00:00:00	ANCIEN	\N	\N	\N	\N	11085T	TITULAIRE	\N	\N
14347	VIOLENCES	2018-07-10 00:00:00	2018-07-24 00:00:00	ANCIEN	\N	\N	\N	\N	19649G	TITULAIRE	\N	\N
14348	VIOLENCES	2018-07-10 00:00:00	2018-07-24 00:00:00	ANCIEN	\N	\N	\N	\N	11045K	TITULAIRE	\N	\N
14349	VIOLENCES	2018-07-10 00:00:00	2018-07-24 00:00:00	ANCIEN	\N	\N	\N	\N	19629C	TITULAIRE	\N	\N
14350	VIOLENCES	2018-07-10 00:00:00	2018-07-24 00:00:00	ANCIEN	\N	\N	\N	\N	19543W	SUPPLEANT	\N	\N
14351	VIOLENCES	2018-07-10 00:00:00	2018-07-24 00:00:00	ANCIEN	\N	\N	\N	\N	11033F	SUPPLEANT	\N	\N
14352	VIOLENCES	2018-07-10 00:00:00	2018-07-24 00:00:00	ANCIEN	\N	\N	\N	\N	14069U	SUPPLEANT	\N	\N
14353	VIOLENCES	2018-07-10 00:00:00	2018-07-24 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	SUPPLEANT	\N	\N
14354	VIOLENCES	2018-07-10 00:00:00	2018-07-24 00:00:00	ANCIEN	\N	\N	\N	\N	14179A	SUPPLEANT	\N	\N
14355	VIOLENCES	2018-07-10 00:00:00	2018-07-24 00:00:00	ANCIEN	\N	\N	\N	\N	11026G	SUPPLEANT	\N	\N
14356	VIOLENCES	2018-07-10 00:00:00	2018-07-24 00:00:00	ANCIEN	\N	\N	\N	\N	19581D	SUPPLEANT	\N	\N
14357	PORTABLE	2018-07-16 00:00:00	2018-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	14123H	TITULAIRE	\N	\N
14372	ELAN	2018-07-27 00:00:00	2018-09-12 00:00:00	ANCIEN	\N	\N	\N	\N	11090Q	TITULAIRE	\N	\N
14359	PORTABLE	2018-07-16 00:00:00	2018-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	19533U	TITULAIRE	\N	\N
14360	PORTABLE	2018-07-16 00:00:00	2018-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	19621T	TITULAIRE	\N	\N
14361	PORTABLE	2018-07-16 00:00:00	2018-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	19735D	TITULAIRE	\N	\N
14362	PORTABLE	2018-07-16 00:00:00	2018-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	08012N	TITULAIRE	\N	\N
14363	PORTABLE	2018-07-16 00:00:00	2018-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	08017T	TITULAIRE	\N	\N
14364	PORTABLE	2018-07-16 00:00:00	2018-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	14241N	TITULAIRE	\N	\N
14365	PORTABLE	2018-07-16 00:00:00	2018-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	14030Q	SUPPLEANT	\N	\N
14366	PORTABLE	2018-07-16 00:00:00	2018-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	19693L	SUPPLEANT	\N	\N
14367	PORTABLE	2018-07-16 00:00:00	2018-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	14039A	SUPPLEANT	\N	\N
14368	PORTABLE	2018-07-16 00:00:00	2018-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	11104D	SUPPLEANT	\N	\N
14369	PORTABLE	2018-07-16 00:00:00	2018-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	19593H	SUPPLEANT	\N	\N
14370	PORTABLE	2018-07-16 00:00:00	2018-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	19573D	SUPPLEANT	\N	\N
14371	PORTABLE	2018-07-16 00:00:00	2018-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	04018C	SUPPLEANT	\N	\N
14373	ELAN	2018-07-27 00:00:00	2018-09-12 00:00:00	ANCIEN	\N	\N	\N	\N	14187A	TITULAIRE	\N	\N
14374	ELAN	2018-07-27 00:00:00	2018-09-12 00:00:00	ANCIEN	\N	\N	\N	\N	04008A	TITULAIRE	\N	\N
14375	ELAN	2018-07-27 00:00:00	2018-09-12 00:00:00	ANCIEN	\N	\N	\N	\N	08038Y	TITULAIRE	\N	\N
14376	ELAN	2018-07-27 00:00:00	2018-09-12 00:00:00	ANCIEN	\N	\N	\N	\N	19591F	TITULAIRE	\N	\N
14377	ELAN	2018-07-27 00:00:00	2018-09-12 00:00:00	ANCIEN	\N	\N	\N	\N	01043Q	TITULAIRE	\N	\N
14378	ELAN	2018-07-27 00:00:00	2018-09-12 00:00:00	ANCIEN	\N	\N	\N	\N	11012A	TITULAIRE	\N	\N
14379	ELAN	2018-07-27 00:00:00	2018-09-12 00:00:00	ANCIEN	\N	\N	\N	\N	19651A	SUPPLEANT	\N	\N
14380	ELAN	2018-07-27 00:00:00	2018-09-12 00:00:00	ANCIEN	\N	\N	\N	\N	14038Y	SUPPLEANT	\N	\N
14381	ELAN	2018-07-27 00:00:00	2018-09-12 00:00:00	ANCIEN	\N	\N	\N	\N	11056N	SUPPLEANT	\N	\N
14382	ELAN	2018-07-27 00:00:00	2018-09-12 00:00:00	ANCIEN	\N	\N	\N	\N	08039A	SUPPLEANT	\N	\N
14383	ELAN	2018-07-27 00:00:00	2018-09-12 00:00:00	ANCIEN	\N	\N	\N	\N	19735D	SUPPLEANT	\N	\N
14384	ELAN	2018-07-27 00:00:00	2018-09-12 00:00:00	ANCIEN	\N	\N	\N	\N	14229S	SUPPLEANT	\N	\N
14385	ELAN	2018-07-27 00:00:00	2018-09-12 00:00:00	ANCIEN	\N	\N	\N	\N	14157T	SUPPLEANT	\N	\N
14387	NEANT	2018-08-07 00:00:00	2018-09-13 00:00:00	ANCIEN	\N	\N	\N	\N	19768N	\N	\N	\N
14392	MANIPULATION	2018-09-25 00:00:00	2018-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	08018U	TITULAIRE	\N	\N
14391	MANIPULATION	2018-09-25 00:00:00	2018-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
14393	MANIPULATION	2018-09-25 00:00:00	2018-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	08039A	TITULAIRE	\N	\N
14394	MANIPULATION	2018-09-25 00:00:00	2018-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	04070G	TITULAIRE	\N	\N
14395	MANIPULATION	2018-09-25 00:00:00	2018-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	14151M	TITULAIRE	\N	\N
14396	MANIPULATION	2018-09-25 00:00:00	2018-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	04059M	TITULAIRE	\N	\N
14397	MANIPULATION	2018-09-25 00:00:00	2018-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	19629C	TITULAIRE	\N	\N
14398	MANIPULATION	2018-09-25 00:00:00	2018-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	14069U	SUPPLEANT	\N	\N
14399	MANIPULATION	2018-09-25 00:00:00	2018-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	11083R	SUPPLEANT	\N	\N
13758	GEMAPI	2017-12-19 00:00:00	2017-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	19489J	TITULAIRE	2017-12-20 10:09:51	2017-12-20 10:16:57
13759	GEMAPI	2017-12-19 00:00:00	2017-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	14151M	TITULAIRE	2017-12-20 10:10:00	2017-12-20 10:16:57
13846	ALSTOM	2018-01-24 00:00:00	2018-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	01043Q	\N	2018-01-31 09:48:22	2018-01-31 09:48:39
13761	GEMAPI	2017-12-19 00:00:00	2017-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	TITULAIRE	2017-12-20 10:11:17	2017-12-20 10:16:57
13762	GEMAPI	2017-12-19 00:00:00	2017-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	14069U	SUPPLEANT	2017-12-20 10:11:27	2017-12-20 10:16:57
13763	GEMAPI	2017-12-19 00:00:00	2017-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	19629C	SUPPLEANT	2017-12-20 10:11:37	2017-12-20 10:16:57
13764	GEMAPI	2017-12-19 00:00:00	2017-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	2017-12-20 10:11:42	2017-12-20 10:16:57
13765	GEMAPI	2017-12-19 00:00:00	2017-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	08018U	SUPPLEANT	2017-12-20 10:11:47	2017-12-20 10:16:57
13766	GEMAPI	2017-12-19 00:00:00	2017-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	19725B	SUPPLEANT	2017-12-20 10:11:53	2017-12-20 10:16:57
13767	GEMAPI	2017-12-19 00:00:00	2017-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	19447X	SUPPLEANT	2017-12-20 10:12:00	2017-12-20 10:16:57
13768	GEMAPI	2017-12-19 00:00:00	2017-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	11085T	SUPPLEANT	2017-12-20 10:12:05	2017-12-20 10:16:57
13769	ALSTOM	2017-12-19 00:00:00	2018-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	19637C	\N	2017-12-20 13:58:45	2017-12-20 13:59:06
13890	DDADUE	2018-01-31 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	2018-02-06 12:22:27	2018-02-14 10:45:52
13891	DDADUE	2018-01-31 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	14089Y	TITULAIRE	2018-02-06 12:22:32	2018-02-14 10:45:52
13892	DDADUE	2018-01-31 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	08018U	TITULAIRE	2018-02-06 12:22:37	2018-02-14 10:45:52
13893	DDADUE	2018-01-31 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	19581D	TITULAIRE	2018-02-06 12:22:42	2018-02-14 10:45:52
13894	DDADUE	2018-01-31 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	19725B	TITULAIRE	2018-02-06 12:22:47	2018-02-14 10:45:52
13895	DDADUE	2018-01-31 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	98035U	TITULAIRE	2018-02-06 12:22:51	2018-02-14 10:45:52
13896	DDADUE	2018-01-31 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	TITULAIRE	2018-02-06 12:22:58	2018-02-14 10:45:52
13897	DDADUE	2018-01-31 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	11033F	SUPPLEANT	2018-02-06 12:23:03	2018-02-14 10:45:52
13898	DDADUE	2018-01-31 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	19629C	SUPPLEANT	2018-02-06 12:23:09	2018-02-14 10:45:52
13899	DDADUE	2018-01-31 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	19673G	SUPPLEANT	2018-02-06 12:23:17	2018-02-14 10:45:52
13900	DDADUE	2018-01-31 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	11049P	SUPPLEANT	2018-02-06 12:23:25	2018-02-14 10:45:52
13901	DDADUE	2018-01-31 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	08044W	SUPPLEANT	2018-02-06 12:23:33	2018-02-14 10:45:52
13902	DDADUE	2018-01-31 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	11026G	SUPPLEANT	2018-02-06 12:23:41	2018-02-14 10:45:52
13903	DDADUE	2018-01-31 00:00:00	2018-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	19729F	SUPPLEANT	2018-02-06 12:23:48	2018-02-14 10:45:52
14078	HERBE	2018-04-11 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14195A	\N	2018-04-10 16:04:41	\N
14079	HERBE	2018-04-11 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19347U	\N	2018-04-10 16:04:47	\N
14080	HERBE	2018-04-11 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14079W	\N	2018-04-10 16:04:55	\N
14081	HERBE	2018-04-11 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98024R	\N	2018-04-10 16:05:02	\N
14082	HERBE	2018-04-11 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10006L	\N	2018-04-10 16:05:11	\N
14083	HERBE	2018-04-11 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14213J	\N	2018-04-10 16:05:16	\N
14084	HERBE	2018-04-11 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	\N	2018-04-10 16:05:20	\N
14085	HERBE	2018-04-11 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08015R	\N	2018-04-10 16:05:27	\N
14086	HERBE	2018-04-11 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08039A	\N	2018-04-10 16:05:34	\N
14087	HERBE	2018-04-11 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	\N	2018-04-10 16:05:39	\N
14088	HERBE	2018-04-11 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14169X	\N	2018-04-10 16:05:45	\N
14089	HERBE	2018-04-11 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04043D	\N	2018-04-10 16:06:13	\N
14090	HERBE	2018-04-11 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14173T	\N	2018-04-10 16:06:18	\N
14091	HERBE	2018-04-11 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04045F	\N	2018-04-10 16:06:32	\N
14092	HERBE	2018-04-11 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95037J	\N	2018-04-10 16:06:39	\N
14093	HERBE	2018-04-11 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19441R	\N	2018-04-10 16:06:48	\N
14094	HERBE	2018-04-11 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14221J	\N	2018-04-10 16:06:56	\N
14095	HERBE	2018-04-11 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14327T	\N	2018-04-10 16:07:01	\N
14096	HERBE	2018-04-11 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19369B	\N	2018-04-10 16:07:13	\N
14097	HERBE	2018-04-11 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11099A	\N	2018-04-10 16:07:36	\N
14098	HERBE	2018-04-11 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08049C	\N	2018-04-10 16:07:41	\N
14099	HERBE	2018-04-11 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11109J	\N	2018-04-10 16:07:47	\N
14100	HERBE	2018-04-11 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08045X	\N	2018-04-10 16:07:51	\N
14101	HERBE	2018-04-11 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19683J	\N	2018-04-10 16:07:55	\N
14102	HERBE	2018-04-11 00:00:00	2018-07-10 00:00:00	ANCIEN	\N	\N	\N	\N	08017T	\N	2018-04-10 16:08:01	\N
14103	HERBE	2018-04-11 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14109K	\N	2018-04-10 16:08:07	\N
14104	HERBE	2018-04-11 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19503N	\N	2018-04-10 16:08:15	\N
14128	HAUTE	2018-04-11 00:00:00	2018-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	19545Y	\N	2018-04-10 16:14:33	2018-04-18 11:37:39
14129	HAUTE	2018-04-11 00:00:00	2018-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	\N	2018-04-10 16:14:41	2018-04-18 11:31:57
14130	HAUTE	2018-04-11 00:00:00	2018-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	19253P	\N	2018-04-10 16:14:48	2018-04-18 11:37:17
14131	HAUTE	2018-04-11 00:00:00	2018-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14133K	\N	2018-04-10 16:14:56	\N
14132	HAUTE	2018-04-11 00:00:00	2018-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	19741B	\N	2018-04-10 16:15:01	\N
14133	HAUTE	2018-04-11 00:00:00	2018-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14357A	\N	2018-04-10 16:15:05	2018-04-18 11:32:23
14134	HAUTE	2018-04-11 00:00:00	2018-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	04097T	\N	2018-04-10 16:15:09	\N
14135	HAUTE	2018-04-11 00:00:00	2018-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	19711U	\N	2018-04-10 16:15:14	2018-04-18 11:34:16
14136	HAUTE	2018-04-11 00:00:00	2018-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	19671E	\N	2018-04-10 16:15:19	\N
14137	HAUTE	2018-04-11 00:00:00	2018-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	17637T	\N	2018-04-10 16:15:24	\N
14138	HAUTE	2018-04-11 00:00:00	2018-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	19533U	\N	2018-04-10 16:15:33	\N
14139	HAUTE	2018-04-11 00:00:00	2018-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	95062K	\N	2018-04-10 16:15:38	\N
14140	HAUTE	2018-04-11 00:00:00	2018-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	08021P	\N	2018-04-10 16:16:06	2018-04-18 11:36:55
14141	HAUTE	2018-04-11 00:00:00	2018-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14179A	\N	2018-04-10 16:16:14	\N
14142	HAUTE	2018-04-11 00:00:00	2018-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14267Y	\N	2018-04-10 16:16:21	\N
14143	HAUTE	2018-04-11 00:00:00	2018-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	11070L	\N	2018-04-10 16:16:27	2018-04-18 11:31:08
14144	HAUTE	2018-04-11 00:00:00	2018-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	08043V	\N	2018-04-10 16:16:35	\N
14145	HAUTE	2018-04-11 00:00:00	2018-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	19531S	\N	2018-04-10 16:16:40	\N
14146	HAUTE	2018-04-11 00:00:00	2018-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	12016W	\N	2018-04-10 16:16:46	\N
14147	HAUTE	2018-04-11 00:00:00	2018-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	19689Q	\N	2018-04-10 16:16:54	2018-04-18 11:36:29
14148	HAUTE	2018-04-11 00:00:00	2018-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	11041F	\N	2018-04-10 16:17:00	2018-04-18 11:36:07
14149	MINEURSENF	2018-04-10 00:00:00	2018-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14119M	\N	2018-04-10 16:19:34	\N
14227	LPM	2018-06-19 00:00:00	2018-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	04042C	TITULAIRE	\N	\N
14228	LPM	2018-06-19 00:00:00	2018-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	14133K	TITULAIRE	\N	\N
14229	LPM	2018-06-19 00:00:00	2018-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	14193X	TITULAIRE	\N	\N
14230	LPM	2018-06-19 00:00:00	2018-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	14267Y	TITULAIRE	\N	\N
14389	AFCL	2018-09-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19766L	\N	\N	\N
14232	LPM	2018-06-19 00:00:00	2018-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	11027H	TITULAIRE	\N	\N
14233	LPM	2018-06-19 00:00:00	2018-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	01062T	TITULAIRE	\N	\N
14234	LPM	2018-06-19 00:00:00	2018-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	08049C	TITULAIRE	\N	\N
14235	LPM	2018-06-19 00:00:00	2018-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	14089Y	SUPPLEANT	\N	\N
14236	LPM	2018-06-19 00:00:00	2018-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	08034U	SUPPLEANT	\N	\N
14237	LPM	2018-06-19 00:00:00	2018-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	08047A	SUPPLEANT	\N	\N
14238	LPM	2018-06-19 00:00:00	2018-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	98050T	SUPPLEANT	\N	\N
14239	LPM	2018-06-19 00:00:00	2018-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	14235Q	SUPPLEANT	\N	\N
14240	LPM	2018-06-19 00:00:00	2018-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	11066Q	SUPPLEANT	\N	\N
14241	LPM	2018-06-19 00:00:00	2018-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	SUPPLEANT	\N	\N
14390	CAE	2018-09-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19768N	\N	\N	\N
14400	MANIPULATION	2018-09-25 00:00:00	2018-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	19699S	SUPPLEANT	\N	\N
14401	MANIPULATION	2018-09-25 00:00:00	2018-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	19593H	SUPPLEANT	\N	\N
14402	MANIPULATION	2018-09-25 00:00:00	2018-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	19573D	SUPPLEANT	\N	\N
13832	SOCIAL	2018-01-24 00:00:00	2018-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	TITULAIRE	2018-01-24 17:41:42	2018-02-06 12:25:06
13833	SOCIAL	2018-01-24 00:00:00	2018-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	14071N	TITULAIRE	2018-01-24 17:41:46	2018-02-06 12:25:06
13834	SOCIAL	2018-01-24 00:00:00	2018-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	10006L	TITULAIRE	2018-01-24 17:41:50	2018-02-06 12:25:06
13835	SOCIAL	2018-01-24 00:00:00	2018-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	19521Q	TITULAIRE	2018-01-24 17:41:57	2018-02-06 12:25:06
13836	SOCIAL	2018-01-24 00:00:00	2018-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	14227Q	TITULAIRE	2018-01-24 17:42:02	2018-02-06 12:25:06
13837	SOCIAL	2018-01-24 00:00:00	2018-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	19727D	TITULAIRE	2018-01-24 17:42:06	2018-02-06 12:25:06
13838	SOCIAL	2018-01-24 00:00:00	2018-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	04045F	TITULAIRE	2018-01-24 17:42:12	2018-02-06 12:25:06
13839	SOCIAL	2018-01-24 00:00:00	2018-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	19717B	SUPPLEANT	2018-01-24 17:42:17	2018-02-06 12:25:06
13840	SOCIAL	2018-01-24 00:00:00	2018-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	98024R	SUPPLEANT	2018-01-24 17:42:22	2018-02-06 12:25:06
13841	SOCIAL	2018-01-24 00:00:00	2018-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	14217N	SUPPLEANT	2018-01-24 17:42:27	2018-02-06 12:25:06
13842	SOCIAL	2018-01-24 00:00:00	2018-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	14026U	SUPPLEANT	2018-01-24 17:42:31	2018-02-06 12:25:06
13843	SOCIAL	2018-01-24 00:00:00	2018-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	19569H	SUPPLEANT	2018-01-24 17:42:36	2018-02-06 12:25:06
13844	SOCIAL	2018-01-24 00:00:00	2018-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	17779H	SUPPLEANT	2018-01-24 17:42:40	2018-02-06 12:25:06
13845	SOCIAL	2018-01-24 00:00:00	2018-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	11063M	SUPPLEANT	2018-01-24 17:42:45	2018-02-06 12:25:06
13926	FORCES	2018-02-06 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	08034U	\N	2018-02-07 11:36:08	\N
13927	AFEU	2018-01-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19731Y	\N	2018-02-08 13:07:48	2018-02-08 14:33:44
13928	ORIENTATION	2018-02-07 00:00:00	2018-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	04070G	TITULAIRE	2018-02-14 10:47:30	2018-02-16 09:34:55
13929	ORIENTATION	2018-02-07 00:00:00	2018-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	14123H	TITULAIRE	2018-02-14 10:47:35	2018-02-16 09:34:55
13930	ORIENTATION	2018-02-07 00:00:00	2018-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	14355X	TITULAIRE	2018-02-14 10:47:41	2018-02-16 09:34:55
13931	ORIENTATION	2018-02-07 00:00:00	2018-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	19533U	TITULAIRE	2018-02-14 10:47:46	2018-02-16 09:34:55
13932	ORIENTATION	2018-02-07 00:00:00	2018-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	14229S	TITULAIRE	2018-02-14 10:47:54	2018-02-16 09:34:55
13933	ORIENTATION	2018-02-07 00:00:00	2018-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	04059M	TITULAIRE	2018-02-14 10:48:02	2018-02-16 09:34:55
13934	ORIENTATION	2018-02-07 00:00:00	2018-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	14039A	TITULAIRE	2018-02-14 10:48:07	2018-02-16 09:34:55
13935	ORIENTATION	2018-02-07 00:00:00	2018-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	95015C	SUPPLEANT	2018-02-14 10:48:15	2018-02-16 09:34:55
13936	ORIENTATION	2018-02-07 00:00:00	2018-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	19693L	SUPPLEANT	2018-02-14 10:48:23	2018-02-16 09:34:55
13937	ORIENTATION	2018-02-07 00:00:00	2018-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	19727D	SUPPLEANT	2018-02-14 10:48:31	2018-02-16 09:34:55
13938	ORIENTATION	2018-02-07 00:00:00	2018-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	14241N	SUPPLEANT	2018-02-14 10:48:38	2018-02-16 09:34:55
13939	ORIENTATION	2018-02-07 00:00:00	2018-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	19611R	SUPPLEANT	2018-02-14 10:48:45	2018-02-16 09:34:55
13940	ORIENTATION	2018-02-07 00:00:00	2018-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	19593H	SUPPLEANT	2018-02-14 10:48:53	2018-02-16 09:34:55
13941	ORIENTATION	2018-02-07 00:00:00	2018-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	19573D	SUPPLEANT	2018-02-14 10:49:02	2018-02-16 09:34:55
13942	JO2024	2018-02-07 00:00:00	2018-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	2018-02-14 10:53:03	2018-02-22 10:57:50
13943	JO2024	2018-02-07 00:00:00	2018-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	19447X	TITULAIRE	2018-02-14 10:53:10	2018-02-22 10:57:50
13944	JO2024	2018-02-07 00:00:00	2018-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	11090Q	TITULAIRE	2018-02-14 10:53:15	2018-02-22 10:57:50
13945	JO2024	2018-02-07 00:00:00	2018-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	14073Q	TITULAIRE	2018-02-14 10:53:19	2018-02-22 10:57:50
13946	JO2024	2018-02-07 00:00:00	2018-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	19649G	TITULAIRE	2018-02-14 10:53:24	2018-02-22 10:57:50
13947	JO2024	2018-02-07 00:00:00	2018-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	08012N	TITULAIRE	2018-02-14 10:53:30	2018-02-22 10:57:50
13948	JO2024	2018-02-07 00:00:00	2018-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	19301E	TITULAIRE	2018-02-14 10:53:35	2018-02-22 10:57:50
14054	DONNEES	2018-03-29 00:00:00	2018-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	2018-03-29 17:21:55	2018-05-22 16:40:01
13950	JO2024	2018-02-07 00:00:00	2018-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	19629C	SUPPLEANT	2018-02-14 10:54:15	2018-02-22 10:57:50
13951	JO2024	2018-02-07 00:00:00	2018-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	08038Y	SUPPLEANT	2018-02-14 10:54:23	2018-02-22 10:57:50
13952	JO2024	2018-02-07 00:00:00	2018-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	SUPPLEANT	2018-02-14 10:54:30	2018-02-22 10:57:50
13953	JO2024	2018-02-07 00:00:00	2018-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	12041X	SUPPLEANT	2018-02-14 10:54:40	2018-02-22 10:57:50
13954	JO2024	2018-02-07 00:00:00	2018-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	11085T	SUPPLEANT	2018-02-14 10:54:44	2018-02-22 10:57:50
13955	JO2024	2018-02-07 00:00:00	2018-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	17637T	SUPPLEANT	2018-02-14 10:54:49	2018-02-22 10:57:50
13956	JO2024	2018-02-07 00:00:00	2018-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	11043H	SUPPLEANT	2018-02-14 10:54:54	2018-02-22 10:57:50
14056	DONNEES	2018-03-29 00:00:00	2018-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	TITULAIRE	2018-03-29 17:22:05	2018-05-22 16:40:01
14055	DONNEES	2018-03-29 00:00:00	2018-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	08044W	TITULAIRE	2018-03-29 17:22:00	2018-05-22 16:40:01
14057	DONNEES	2018-03-29 00:00:00	2018-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	19673G	TITULAIRE	2018-03-29 17:22:10	2018-05-22 16:40:01
14058	DONNEES	2018-03-29 00:00:00	2018-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	14151M	TITULAIRE	2018-03-29 17:22:15	2018-05-22 16:40:01
14059	DONNEES	2018-03-29 00:00:00	2018-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	11026G	TITULAIRE	2018-03-29 17:22:19	2018-05-22 16:40:01
14060	DONNEES	2018-03-29 00:00:00	2018-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	19543W	TITULAIRE	2018-03-29 17:22:24	2018-05-22 16:40:01
14061	DONNEES	2018-03-29 00:00:00	2018-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	11033F	SUPPLEANT	2018-03-29 17:22:30	2018-05-22 16:40:01
14062	DONNEES	2018-03-29 00:00:00	2018-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	19629C	SUPPLEANT	2018-03-29 17:22:37	2018-05-22 16:40:01
14063	DONNEES	2018-03-29 00:00:00	2018-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	14259Y	SUPPLEANT	2018-03-29 17:22:42	2018-05-22 16:40:01
14064	DONNEES	2018-03-29 00:00:00	2018-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	SUPPLEANT	2018-03-29 17:22:46	2018-05-22 16:40:01
14065	DONNEES	2018-03-29 00:00:00	2018-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	08018U	SUPPLEANT	2018-03-29 17:22:53	2018-05-22 16:40:01
14066	DONNEES	2018-03-29 00:00:00	2018-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	19649G	SUPPLEANT	2018-03-29 17:22:59	2018-05-22 16:40:01
14067	DONNEES	2018-03-29 00:00:00	2018-04-08 00:00:00	ANCIEN	\N	\N	\N	\N	14179A	SUPPLEANT	2018-03-29 17:23:05	2018-05-22 16:40:01
14068	AFEU	2018-04-04 00:00:00	2020-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	19569H	\N	2018-04-05 09:49:39	\N
14213	PACTE	2018-06-07 00:00:00	2018-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	08009T	TITULAIRE	2018-06-07 17:07:24	\N
14214	PACTE	2018-06-07 00:00:00	2018-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	98023Q	TITULAIRE	2018-06-07 17:07:29	\N
14215	PACTE	2018-06-07 00:00:00	2018-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	19733B	TITULAIRE	2018-06-07 17:07:34	\N
14216	PACTE	2018-06-07 00:00:00	2018-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14157T	TITULAIRE	2018-06-07 17:07:39	\N
14217	PACTE	2018-06-07 00:00:00	2018-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	19525U	TITULAIRE	2018-06-07 17:07:45	\N
14218	PACTE	2018-06-07 00:00:00	2018-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	19551W	TITULAIRE	2018-06-07 17:07:51	\N
14219	PACTE	2018-06-07 00:00:00	2018-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	19681G	TITULAIRE	2018-06-07 17:07:57	\N
14220	PACTE	2018-06-07 00:00:00	2018-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	SUPPLEANT	2018-06-07 17:08:02	2018-06-07 17:08:05
14221	PACTE	2018-06-07 00:00:00	2018-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	04061F	SUPPLEANT	2018-06-07 17:08:09	2018-06-07 17:08:12
14222	PACTE	2018-06-07 00:00:00	2018-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14219Q	SUPPLEANT	2018-06-07 17:08:17	2018-06-07 17:08:19
14223	PACTE	2018-06-07 00:00:00	2018-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	19637C	SUPPLEANT	2018-06-07 17:08:25	2018-06-07 17:08:28
14224	PACTE	2018-06-07 00:00:00	2018-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14169X	SUPPLEANT	2018-06-07 17:08:33	2018-06-07 17:08:36
14225	PACTE	2018-06-07 00:00:00	2018-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	17637T	SUPPLEANT	2018-06-07 17:08:41	2018-06-07 17:08:43
14226	PACTE	2018-06-07 00:00:00	2018-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	19503N	SUPPLEANT	2018-06-07 17:08:49	2018-06-07 17:08:53
14665	NEANT	2018-12-31 00:00:00	2019-01-14 00:00:00	ANCIEN	\N	\N	\N	\N	19794Q	\N	\N	\N
14722	SIDERURGIE	2019-01-30 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	14073Q	\N	\N	\N
14723	SIDERURGIE	2019-01-30 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	01043Q	\N	\N	\N
14724	SIDERURGIE	2019-01-30 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	14205J	\N	\N	\N
14725	SIDERURGIE	2019-01-30 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	19713W	\N	\N	\N
14726	SIDERURGIE	2019-01-30 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	19575F	\N	\N	\N
14727	SIDERURGIE	2019-01-30 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	11049P	\N	\N	\N
14728	SIDERURGIE	2019-01-30 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	\N	\N	\N
14729	SIDERURGIE	2019-01-30 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	07029T	\N	\N	\N
14730	SIDERURGIE	2019-01-30 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	19711U	\N	\N	\N
14731	SIDERURGIE	2019-01-30 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	01048V	\N	\N	\N
14732	SIDERURGIE	2019-01-30 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	14265W	\N	\N	\N
14733	SIDERURGIE	2019-01-30 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	19768N	\N	\N	\N
14734	SIDERURGIE	2019-01-30 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	14237S	\N	\N	\N
14735	SIDERURGIE	2019-01-30 00:00:00	2019-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	11090Q	\N	\N	\N
14736	SIDERURGIE	2019-01-30 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	\N	\N	\N
14737	SIDERURGIE	2019-01-30 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	19681G	\N	\N	\N
14738	SIDERURGIE	2019-01-30 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	19563B	\N	\N	\N
14739	SIDERURGIE	2019-01-30 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	08068F	\N	\N	\N
14740	SIDERURGIE	2019-01-30 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	19599P	\N	\N	\N
14741	SIDERURGIE	2019-01-30 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	19503N	\N	\N	\N
14742	SIDERURGIE	2019-01-30 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	19413M	\N	\N	\N
14743	SIDERURGIE	2019-01-30 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	01062T	\N	\N	\N
14744	SIDERURGIE	2019-01-30 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	19527W	\N	\N	\N
14745	SIDERURGIE	2019-01-30 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	19695N	\N	\N	\N
14746	SIDERURGIE	2019-01-30 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	19585H	\N	\N	\N
14827	SOUVERAINETE	2019-04-10 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	14179A	\N	\N	\N
14828	SOUVERAINETE	2019-04-10 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	19611R	\N	\N	\N
14829	SOUVERAINETE	2019-04-10 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04070G	\N	\N	\N
14830	SOUVERAINETE	2019-04-10 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	19631V	\N	\N	\N
14831	SOUVERAINETE	2019-04-10 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	19599P	\N	\N	\N
14832	SOUVERAINETE	2019-04-10 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	08053X	\N	\N	\N
14833	SOUVERAINETE	2019-04-10 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	14257W	\N	\N	\N
14834	SOUVERAINETE	2019-04-10 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	14229S	\N	\N	\N
14920	FONDS	2019-05-22 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	14107H	\N	\N	\N
15200	NEANT	2019-10-01 00:00:00	2019-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19826F	\N	\N	\N
14921	FONDS	2019-05-22 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	08073C	\N	\N	\N
15198	NEANT	2019-08-28 00:00:00	2019-09-19 00:00:00	ANCIEN	\N	\N	\N	\N	19820Y	\N	\N	\N
15433	HADOPI	2020-01-28 00:00:00	2020-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	19629C	SUPPLEANT	\N	\N
15434	HADOPI	2020-01-28 00:00:00	2020-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	SUPPLEANT	\N	\N
15435	AUTOROUT	2020-02-04 00:00:00	2020-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	14121F	\N	\N	\N
15437	AUTOROUT	2020-02-04 00:00:00	2020-09-16 00:00:00	ANCIEN	\N	\N	\N	\N	14121F	\N	\N	\N
15438	SOLS	2020-02-05 00:00:00	2020-09-08 00:00:00	ANCIEN	\N	\N	\N	\N	19687N	\N	\N	\N
15439	SOLS	2020-02-05 00:00:00	2020-09-08 00:00:00	ANCIEN	\N	\N	\N	\N	19611R	\N	\N	\N
15440	SOLS	2020-02-05 00:00:00	2020-09-08 00:00:00	ANCIEN	\N	\N	\N	\N	19369B	\N	\N	\N
15441	SOLS	2020-02-05 00:00:00	2020-09-08 00:00:00	ANCIEN	\N	\N	\N	\N	19735D	\N	\N	\N
15442	SOLS	2020-02-05 00:00:00	2020-09-08 00:00:00	ANCIEN	\N	\N	\N	\N	19549D	\N	\N	\N
15443	SOLS	2020-02-05 00:00:00	2020-09-08 00:00:00	ANCIEN	\N	\N	\N	\N	14197C	\N	\N	\N
15444	SOLS	2020-02-05 00:00:00	2020-09-08 00:00:00	ANCIEN	\N	\N	\N	\N	14097Y	\N	\N	\N
15445	SOLS	2020-02-05 00:00:00	2020-09-08 00:00:00	ANCIEN	\N	\N	\N	\N	19527W	\N	\N	\N
15446	SOLS	2020-02-05 00:00:00	2020-09-08 00:00:00	ANCIEN	\N	\N	\N	\N	14079W	\N	\N	\N
15447	SOLS	2020-02-05 00:00:00	2020-09-08 00:00:00	ANCIEN	\N	\N	\N	\N	14033T	\N	\N	\N
15448	SOLS	2020-02-05 00:00:00	2020-09-08 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	\N	\N	\N
15449	SOLS	2020-02-05 00:00:00	2020-09-08 00:00:00	ANCIEN	\N	\N	\N	\N	19723Y	\N	\N	\N
15450	SOLS	2020-02-05 00:00:00	2020-09-08 00:00:00	ANCIEN	\N	\N	\N	\N	19581D	\N	\N	\N
15451	SOLS	2020-02-05 00:00:00	2020-09-08 00:00:00	ANCIEN	\N	\N	\N	\N	14031R	\N	\N	\N
15452	SOLS	2020-02-05 00:00:00	2020-09-08 00:00:00	ANCIEN	\N	\N	\N	\N	92040Q	\N	\N	\N
15453	SOLS	2020-02-05 00:00:00	2020-09-08 00:00:00	ANCIEN	\N	\N	\N	\N	14237S	\N	\N	\N
15454	SOLS	2020-02-05 00:00:00	2020-09-08 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	\N	\N	\N
15455	SOLS	2020-02-05 00:00:00	2020-09-08 00:00:00	ANCIEN	\N	\N	\N	\N	19591F	\N	\N	\N
15456	SOLS	2020-02-05 00:00:00	2020-09-08 00:00:00	ANCIEN	\N	\N	\N	\N	08073C	\N	\N	\N
15457	SOLS	2020-02-05 00:00:00	2020-09-08 00:00:00	ANCIEN	\N	\N	\N	\N	14093U	\N	\N	\N
15458	SOLS	2020-02-05 00:00:00	2020-09-08 00:00:00	ANCIEN	\N	\N	\N	\N	19629C	\N	\N	\N
15459	ASAP	2020-02-06 00:00:00	2020-08-06 00:00:00	ANCIEN	\N	\N	\N	\N	19782L	\N	\N	\N
15460	ASAP	2020-02-06 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	19349W	\N	\N	\N
15461	ASAP	2020-02-06 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	\N	\N	\N
15462	ASAP	2020-02-06 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	11056N	\N	\N	\N
15463	ASAP	2020-02-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	\N	\N	\N
15464	ASAP	2020-02-06 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	19631V	\N	\N	\N
15465	ASAP	2020-02-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14085U	\N	\N	\N
15466	ASAP	2020-02-06 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	19333N	\N	\N	\N
15467	ASAP	2020-02-06 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	19489J	\N	\N	\N
15468	ASAP	2020-02-06 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	19503N	\N	\N	\N
15469	ASAP	2020-02-06 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	14225N	\N	\N	\N
15470	ASAP	2020-02-06 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	14229S	\N	\N	\N
15471	ASAP	2020-02-06 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	\N	\N	\N
15472	ASAP	2020-02-06 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	19521Q	\N	\N	\N
15473	ASAP	2020-02-06 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	14073Q	\N	\N	\N
15474	ASAP	2020-02-06 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	14205J	\N	\N	\N
15479	ASAP	2020-02-06 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	19621T	\N	\N	\N
15480	ASAP	2020-02-06 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	11101A	\N	\N	\N
15481	ASAP	2020-02-06 00:00:00	2020-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	19701S	\N	\N	\N
15482	ASAP	2020-02-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14079W	\N	\N	\N
15483	ASAP	2020-02-06 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	\N	\N	\N
15484	ASAP	2020-02-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14087W	\N	\N	\N
15485	ASAP	2020-02-06 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	14213J	\N	\N	\N
15486	ASAP	2020-02-06 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	19711U	\N	\N	\N
15487	ASAP	2020-02-06 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	14059S	\N	\N	\N
15488	ASAP	2020-02-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14265W	\N	\N	\N
15489	ASAP	2020-02-06 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	19768N	\N	\N	\N
15490	ASAP	2020-02-06 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	01058X	\N	\N	\N
15491	ASAP	2020-02-06 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	19703U	\N	\N	\N
15492	ASAP	2020-02-06 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	19629C	\N	\N	\N
15493	ASAP	2020-02-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19253P	\N	\N	\N
15494	ASAP	2020-02-06 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	19585H	\N	\N	\N
15495	ASAP	2020-02-06 00:00:00	2020-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	01060R	\N	\N	\N
15496	ASAP	2020-02-06 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	19399H	\N	\N	\N
15497	DEPARTEMENT	2020-02-19 00:00:00	2020-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	04045F	\N	\N	\N
15498	DEPARTEMENT	2020-02-19 00:00:00	2020-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	19349W	\N	\N	\N
15499	DEPARTEMENT	2020-02-19 00:00:00	2020-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	19667J	\N	\N	\N
15500	DEPARTEMENT	2020-02-19 00:00:00	2020-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	19415P	\N	\N	\N
15501	DEPARTEMENT	2020-02-19 00:00:00	2020-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	19383Y	\N	\N	\N
15502	DEPARTEMENT	2020-02-19 00:00:00	2020-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	19621T	\N	\N	\N
15503	DEPARTEMENT	2020-02-19 00:00:00	2020-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	04097T	\N	\N	\N
15504	DEPARTEMENT	2020-02-19 00:00:00	2020-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	14213J	\N	\N	\N
15505	DEPARTEMENT	2020-02-19 00:00:00	2020-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	14061L	\N	\N	\N
15506	DEPARTEMENT	2020-02-19 00:00:00	2020-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	19679N	\N	\N	\N
15507	DEPARTEMENT	2020-02-19 00:00:00	2020-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	10015M	\N	\N	\N
15508	DEPARTEMENT	2020-02-19 00:00:00	2020-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	19820Y	\N	\N	\N
15509	DEPARTEMENT	2020-02-19 00:00:00	2020-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	19725B	\N	\N	\N
15510	DEPARTEMENT	2020-02-19 00:00:00	2020-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	19531S	\N	\N	\N
15511	DEPARTEMENT	2020-02-19 00:00:00	2020-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	14001X	\N	\N	\N
15512	DEPARTEMENT	2020-02-19 00:00:00	2020-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	11056N	\N	\N	\N
15513	DEPARTEMENT	2020-02-19 00:00:00	2020-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	14327T	\N	\N	\N
15514	DEPARTEMENT	2020-02-19 00:00:00	2020-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	19441R	\N	\N	\N
15515	DEPARTEMENT	2020-02-19 00:00:00	2020-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	14221J	\N	\N	\N
15516	DEPARTEMENT	2020-02-19 00:00:00	2020-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	19387D	\N	\N	\N
15517	DEPARTEMENT	2020-02-19 00:00:00	2020-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	19563B	\N	\N	\N
15521	CAE	2020-02-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04045F	\N	\N	\N
15522	NEANT	2020-03-04 00:00:00	2020-03-24 00:00:00	ANCIEN	\N	\N	\N	\N	19866P	\N	\N	\N
15520	SOCI	2020-02-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19591F	\N	\N	\N
15526	FEDERATION	2020-03-04 00:00:00	2020-09-08 00:00:00	ANCIEN	\N	\N	\N	\N	14030Q	\N	\N	\N
15524	FEDERATION	2020-03-04 00:00:00	2020-09-08 00:00:00	ANCIEN	\N	\N	\N	\N	19349W	\N	\N	\N
15525	FEDERATION	2020-03-04 00:00:00	2020-09-08 00:00:00	ANCIEN	\N	\N	\N	\N	08024S	\N	\N	\N
15527	FEDERATION	2020-03-04 00:00:00	2020-09-08 00:00:00	ANCIEN	\N	\N	\N	\N	19721W	\N	\N	\N
15528	FEDERATION	2020-03-04 00:00:00	2020-09-08 00:00:00	ANCIEN	\N	\N	\N	\N	14073Q	\N	\N	\N
15529	FEDERATION	2020-03-04 00:00:00	2020-09-08 00:00:00	ANCIEN	\N	\N	\N	\N	02002K	\N	\N	\N
15530	FEDERATION	2020-03-04 00:00:00	2020-09-08 00:00:00	ANCIEN	\N	\N	\N	\N	19725B	\N	\N	\N
15531	FEDERATION	2020-03-04 00:00:00	2020-09-08 00:00:00	ANCIEN	\N	\N	\N	\N	08012N	\N	\N	\N
15532	FEDERATION	2020-03-04 00:00:00	2020-09-08 00:00:00	ANCIEN	\N	\N	\N	\N	19669L	\N	\N	\N
15533	FEDERATION	2020-03-04 00:00:00	2020-09-08 00:00:00	ANCIEN	\N	\N	\N	\N	19251M	\N	\N	\N
15534	FEDERATION	2020-03-04 00:00:00	2020-09-08 00:00:00	ANCIEN	\N	\N	\N	\N	87003B	\N	\N	\N
15535	FEDERATION	2020-03-04 00:00:00	2020-09-08 00:00:00	ANCIEN	\N	\N	\N	\N	14249W	\N	\N	\N
15536	FEDERATION	2020-03-04 00:00:00	2020-09-08 00:00:00	ANCIEN	\N	\N	\N	\N	19399H	\N	\N	\N
15537	FEDERATION	2020-03-04 00:00:00	2020-09-08 00:00:00	ANCIEN	\N	\N	\N	\N	19711U	\N	\N	\N
15538	FEDERATION	2020-03-04 00:00:00	2020-09-08 00:00:00	ANCIEN	\N	\N	\N	\N	19581D	\N	\N	\N
14577	AFCL	2018-11-20 00:00:00	2018-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	19782L	\N	\N	\N
14693	CLIMATIQUE	2019-01-16 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	14093U	\N	\N	\N
14694	CLIMATIQUE	2019-01-16 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	19629C	\N	\N	\N
14695	CLIMATIQUE	2019-01-16 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	08049C	\N	\N	\N
14696	CLIMATIQUE	2019-01-16 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	19733B	\N	\N	\N
14697	CLIMATIQUE	2019-01-16 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	14038Y	\N	\N	\N
14698	CLIMATIQUE	2019-01-16 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	14187A	\N	\N	\N
14699	CLIMATIQUE	2019-01-16 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	14033T	\N	\N	\N
14700	CLIMATIQUE	2019-01-16 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	\N	\N	\N
14701	CLIMATIQUE	2019-01-16 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	08019V	\N	\N	\N
14702	CLIMATIQUE	2019-01-16 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	14031R	\N	\N	\N
14703	CLIMATIQUE	2019-01-16 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	19762G	\N	\N	\N
14704	CLIMATIQUE	2019-01-16 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	14157T	\N	\N	\N
14705	CLIMATIQUE	2019-01-16 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	\N	\N	\N
14706	CLIMATIQUE	2019-01-16 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	19721W	\N	\N	\N
14707	CLIMATIQUE	2019-01-16 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	14221J	\N	\N	\N
14708	CLIMATIQUE	2019-01-16 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	19369B	\N	\N	\N
14709	CLIMATIQUE	2019-01-16 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	19745F	\N	\N	\N
14710	CLIMATIQUE	2019-01-16 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	19347U	\N	\N	\N
14711	CLIMATIQUE	2019-01-16 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	08024S	\N	\N	\N
14712	CLIMATIQUE	2019-01-16 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	\N	\N	\N
14713	CLIMATIQUE	2019-01-16 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	08060W	\N	\N	\N
14714	CLIMATIQUE	2019-01-16 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	14207L	\N	\N	\N
14715	CLIMATIQUE	2019-01-16 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	08038Y	\N	\N	\N
14716	CLIMATIQUE	2019-01-16 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	19715Y	\N	\N	\N
14717	CLIMATIQUE	2019-01-16 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	14097Y	\N	\N	\N
14718	CLIMATIQUE	2019-01-16 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	14051J	\N	\N	\N
14719	CLIMATIQUE	2019-01-16 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	19747H	\N	\N	\N
14750	CROISSENTRE	2019-02-12 00:00:00	2019-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	19521Q	TITULAIRE	\N	\N
14751	CROISSENTRE	2019-02-12 00:00:00	2019-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	TITULAIRE	\N	\N
14752	CROISSENTRE	2019-02-12 00:00:00	2019-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	TITULAIRE	\N	\N
14753	CROISSENTRE	2019-02-12 00:00:00	2019-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	11090Q	TITULAIRE	\N	\N
14754	CROISSENTRE	2019-02-12 00:00:00	2019-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	08068F	TITULAIRE	\N	\N
14755	CROISSENTRE	2019-02-12 00:00:00	2019-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	11110B	TITULAIRE	\N	\N
14756	CROISSENTRE	2019-02-12 00:00:00	2019-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	08073C	TITULAIRE	\N	\N
14757	CROISSENTRE	2019-02-12 00:00:00	2019-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	19515S	SUPPLEANT	\N	\N
14758	CROISSENTRE	2019-02-12 00:00:00	2019-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	14083S	SUPPLEANT	\N	\N
14759	CROISSENTRE	2019-02-12 00:00:00	2019-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	04071H	SUPPLEANT	\N	\N
14760	CROISSENTRE	2019-02-12 00:00:00	2019-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	14034U	SUPPLEANT	\N	\N
14761	CROISSENTRE	2019-02-12 00:00:00	2019-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	19695N	SUPPLEANT	\N	\N
14762	CROISSENTRE	2019-02-12 00:00:00	2019-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	19711U	SUPPLEANT	\N	\N
14763	CROISSENTRE	2019-02-12 00:00:00	2019-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	14227Q	SUPPLEANT	\N	\N
14848	AERIEN	2019-04-30 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	14069U	\N	\N	\N
14849	AERIEN	2019-04-30 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	19383Y	\N	\N	\N
14850	AERIEN	2019-04-30 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	14357A	\N	\N	\N
14851	AERIEN	2019-04-30 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	14199E	\N	\N	\N
14852	AERIEN	2019-04-30 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	15447F	\N	\N	\N
14856	AERIEN	2019-04-30 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	14031R	\N	\N	\N
14854	AERIEN	2019-04-30 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04097T	\N	\N	\N
14855	AERIEN	2019-04-30 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	19729F	\N	\N	\N
14857	AERIEN	2019-04-30 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	19671E	\N	\N	\N
14858	AERIEN	2019-04-30 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	14237S	\N	\N	\N
14859	AERIEN	2019-04-30 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	19703U	\N	\N	\N
14860	AERIEN	2019-04-30 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	14083S	\N	\N	\N
14861	AERIEN	2019-04-30 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	11053K	\N	\N	\N
14862	AERIEN	2019-04-30 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	14103D	\N	\N	\N
14863	AERIEN	2019-04-30 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	19735D	\N	\N	\N
14864	AERIEN	2019-04-30 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	19549D	\N	\N	\N
14865	AERIEN	2019-04-30 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	08045X	\N	\N	\N
14866	AERIEN	2019-04-30 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	19333N	\N	\N	\N
14867	AERIEN	2019-04-30 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	19715Y	\N	\N	\N
14868	AERIEN	2019-04-30 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	14225N	\N	\N	\N
14869	AERIEN	2019-04-30 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	19669L	\N	\N	\N
14870	AERIEN	2019-04-30 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	19301E	\N	\N	\N
14871	AERIEN	2019-04-30 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	19349W	\N	\N	\N
14872	AERIEN	2019-04-30 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	19253P	\N	\N	\N
14873	AERIEN	2019-04-30 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	19387D	\N	\N	\N
14874	AERIEN	2019-04-30 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	11064N	\N	\N	\N
14875	AERIEN	2019-04-30 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	11077T	\N	\N	\N
14890	POLYNESIE3	2019-04-30 00:00:00	2019-05-08 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
14891	POLYNESIE3	2019-04-30 00:00:00	2019-05-08 00:00:00	ANCIEN	\N	\N	\N	\N	14259Y	TITULAIRE	\N	\N
14892	POLYNESIE3	2019-04-30 00:00:00	2019-05-08 00:00:00	ANCIEN	\N	\N	\N	\N	19447X	TITULAIRE	\N	\N
14893	POLYNESIE3	2019-04-30 00:00:00	2019-05-08 00:00:00	ANCIEN	\N	\N	\N	\N	14275Y	TITULAIRE	\N	\N
14894	POLYNESIE3	2019-04-30 00:00:00	2019-05-08 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
14895	POLYNESIE3	2019-04-30 00:00:00	2019-05-08 00:00:00	ANCIEN	\N	\N	\N	\N	14151M	TITULAIRE	\N	\N
14896	POLYNESIE3	2019-04-30 00:00:00	2019-05-08 00:00:00	ANCIEN	\N	\N	\N	\N	11072N	TITULAIRE	\N	\N
14897	POLYNESIE3	2019-04-30 00:00:00	2019-05-08 00:00:00	ANCIEN	\N	\N	\N	\N	11033F	SUPPLEANT	\N	\N
14898	POLYNESIE3	2019-04-30 00:00:00	2019-05-08 00:00:00	ANCIEN	\N	\N	\N	\N	19629C	SUPPLEANT	\N	\N
14899	POLYNESIE3	2019-04-30 00:00:00	2019-05-08 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	SUPPLEANT	\N	\N
14900	POLYNESIE3	2019-04-30 00:00:00	2019-05-08 00:00:00	ANCIEN	\N	\N	\N	\N	19673G	SUPPLEANT	\N	\N
14901	POLYNESIE3	2019-04-30 00:00:00	2019-05-08 00:00:00	ANCIEN	\N	\N	\N	\N	19691J	SUPPLEANT	\N	\N
14902	POLYNESIE3	2019-04-30 00:00:00	2019-05-08 00:00:00	ANCIEN	\N	\N	\N	\N	12016W	SUPPLEANT	\N	\N
14903	POLYNESIE3	2019-04-30 00:00:00	2019-05-08 00:00:00	ANCIEN	\N	\N	\N	\N	19762G	SUPPLEANT	\N	\N
14904	SANTE	2019-05-02 00:00:00	2019-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	TITULAIRE	\N	\N
14905	SANTE	2019-05-02 00:00:00	2019-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	14239U	TITULAIRE	\N	\N
14906	SANTE	2019-05-02 00:00:00	2019-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	10006L	TITULAIRE	\N	\N
14907	SANTE	2019-05-02 00:00:00	2019-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	11097X	TITULAIRE	\N	\N
14908	SANTE	2019-05-02 00:00:00	2019-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	TITULAIRE	\N	\N
14909	SANTE	2019-05-02 00:00:00	2019-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	11067R	TITULAIRE	\N	\N
14910	SANTE	2019-05-02 00:00:00	2019-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	19569H	TITULAIRE	\N	\N
14911	SANTE	2019-05-02 00:00:00	2019-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	19717B	SUPPLEANT	\N	\N
14912	SANTE	2019-05-02 00:00:00	2019-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	11031D	SUPPLEANT	\N	\N
14913	SANTE	2019-05-02 00:00:00	2019-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	14217N	SUPPLEANT	\N	\N
14914	SANTE	2019-05-02 00:00:00	2019-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	14281W	SUPPLEANT	\N	\N
14915	SANTE	2019-05-02 00:00:00	2019-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	14026U	SUPPLEANT	\N	\N
14916	SANTE	2019-05-02 00:00:00	2019-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	19679N	SUPPLEANT	\N	\N
14917	SANTE	2019-05-02 00:00:00	2019-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	01034P	SUPPLEANT	\N	\N
15058	MARITIME	2019-06-26 00:00:00	2019-10-22 00:00:00	ANCIEN	\N	\N	\N	\N	19681G	\N	\N	\N
15059	MARITIME	2019-06-26 00:00:00	2019-10-22 00:00:00	ANCIEN	\N	\N	\N	\N	98029W	\N	\N	\N
15060	MARITIME	2019-06-26 00:00:00	2019-10-22 00:00:00	ANCIEN	\N	\N	\N	\N	11064N	\N	\N	\N
15061	MARITIME	2019-06-26 00:00:00	2019-10-22 00:00:00	ANCIEN	\N	\N	\N	\N	14235Q	\N	\N	\N
15062	MARITIME	2019-06-26 00:00:00	2019-10-22 00:00:00	ANCIEN	\N	\N	\N	\N	14133K	\N	\N	\N
15063	MARITIME	2019-06-26 00:00:00	2019-10-22 00:00:00	ANCIEN	\N	\N	\N	\N	14187A	\N	\N	\N
15064	MARITIME	2019-06-26 00:00:00	2019-10-22 00:00:00	ANCIEN	\N	\N	\N	\N	08034U	\N	\N	\N
15065	MARITIME	2019-06-26 00:00:00	2019-10-22 00:00:00	ANCIEN	\N	\N	\N	\N	19729F	\N	\N	\N
15066	MARITIME	2019-06-26 00:00:00	2019-10-22 00:00:00	ANCIEN	\N	\N	\N	\N	14031R	\N	\N	\N
15067	MARITIME	2019-06-26 00:00:00	2019-10-22 00:00:00	ANCIEN	\N	\N	\N	\N	17583W	\N	\N	\N
15068	MARITIME	2019-06-26 00:00:00	2019-10-22 00:00:00	ANCIEN	\N	\N	\N	\N	14331P	\N	\N	\N
15069	MARITIME	2019-06-26 00:00:00	2019-10-22 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	\N	\N	\N
15070	MARITIME	2019-06-26 00:00:00	2019-10-22 00:00:00	ANCIEN	\N	\N	\N	\N	14157T	\N	\N	\N
15071	MARITIME	2019-06-26 00:00:00	2019-10-22 00:00:00	ANCIEN	\N	\N	\N	\N	14030Q	\N	\N	\N
15072	MARITIME	2019-06-26 00:00:00	2019-10-22 00:00:00	ANCIEN	\N	\N	\N	\N	14083S	\N	\N	\N
15073	MARITIME	2019-06-26 00:00:00	2019-10-22 00:00:00	ANCIEN	\N	\N	\N	\N	14275Y	\N	\N	\N
15199	CDD	2019-09-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19820Y	\N	\N	\N
15075	MARITIME	2019-06-26 00:00:00	2019-10-22 00:00:00	ANCIEN	\N	\N	\N	\N	08043V	\N	\N	\N
15076	MARITIME	2019-06-26 00:00:00	2019-10-22 00:00:00	ANCIEN	\N	\N	\N	\N	14281W	\N	\N	\N
15077	MARITIME	2019-06-26 00:00:00	2019-10-22 00:00:00	ANCIEN	\N	\N	\N	\N	08045X	\N	\N	\N
15078	MARITIME	2019-06-26 00:00:00	2019-10-22 00:00:00	ANCIEN	\N	\N	\N	\N	11066Q	\N	\N	\N
10098	CAE	2014-10-08 00:00:00	2019-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	08021P	\N	2014-10-08 16:48:23	2017-10-04 20:32:48
15096	NEANT	2019-07-01 00:00:00	2019-07-10 00:00:00	ANCIEN	\N	\N	\N	\N	19812Y	\N	\N	\N
14498	ENTREPRISES	2018-10-10 00:00:00	2019-05-23 00:00:00	ANCIEN	\N	\N	\N	\N	14026U	\N	\N	\N
14499	ENTREPRISES	2018-10-10 00:00:00	2019-05-23 00:00:00	ANCIEN	\N	\N	\N	\N	19399H	\N	\N	\N
14500	ENTREPRISES	2018-10-10 00:00:00	2019-05-23 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	\N	\N	\N
14501	ENTREPRISES	2018-10-10 00:00:00	2019-05-23 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	\N	\N	\N
14502	ENTREPRISES	2018-10-10 00:00:00	2019-05-23 00:00:00	ANCIEN	\N	\N	\N	\N	19711U	\N	\N	\N
14503	ENTREPRISES	2018-10-10 00:00:00	2019-05-23 00:00:00	ANCIEN	\N	\N	\N	\N	08034U	\N	\N	\N
14504	ENTREPRISES	2018-10-10 00:00:00	2019-05-23 00:00:00	ANCIEN	\N	\N	\N	\N	11090Q	\N	\N	\N
14505	ENTREPRISES	2018-10-10 00:00:00	2019-05-23 00:00:00	ANCIEN	\N	\N	\N	\N	19762G	\N	\N	\N
14506	ENTREPRISES	2018-10-10 00:00:00	2019-05-23 00:00:00	ANCIEN	\N	\N	\N	\N	14157T	\N	\N	\N
14507	ENTREPRISES	2018-10-10 00:00:00	2019-05-23 00:00:00	ANCIEN	\N	\N	\N	\N	14173T	\N	\N	\N
14508	ENTREPRISES	2018-10-10 00:00:00	2019-05-23 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	\N	\N	\N
14509	ENTREPRISES	2018-10-10 00:00:00	2019-05-23 00:00:00	ANCIEN	\N	\N	\N	\N	08073C	\N	\N	\N
14510	ENTREPRISES	2018-10-10 00:00:00	2019-05-23 00:00:00	ANCIEN	\N	\N	\N	\N	19717B	\N	\N	\N
14511	ENTREPRISES	2018-10-10 00:00:00	2019-05-23 00:00:00	ANCIEN	\N	\N	\N	\N	14034U	\N	\N	\N
14512	ENTREPRISES	2018-10-10 00:00:00	2019-05-23 00:00:00	ANCIEN	\N	\N	\N	\N	19545Y	\N	\N	\N
14513	ENTREPRISES	2018-10-10 00:00:00	2019-05-23 00:00:00	ANCIEN	\N	\N	\N	\N	89017R	\N	\N	\N
14514	ENTREPRISES	2018-10-10 00:00:00	2019-05-23 00:00:00	ANCIEN	\N	\N	\N	\N	19631V	\N	\N	\N
14515	ENTREPRISES	2018-10-10 00:00:00	2019-05-23 00:00:00	ANCIEN	\N	\N	\N	\N	08068F	\N	\N	\N
14516	ENTREPRISES	2018-10-10 00:00:00	2019-05-23 00:00:00	ANCIEN	\N	\N	\N	\N	14151M	\N	\N	\N
14517	ENTREPRISES	2018-10-10 00:00:00	2019-05-23 00:00:00	ANCIEN	\N	\N	\N	\N	11110B	\N	\N	\N
14518	ENTREPRISES	2018-10-10 00:00:00	2019-05-23 00:00:00	ANCIEN	\N	\N	\N	\N	14159V	\N	\N	\N
14519	ENTREPRISES	2018-10-10 00:00:00	2019-05-23 00:00:00	ANCIEN	\N	\N	\N	\N	12016W	\N	\N	\N
14520	ENTREPRISES	2018-10-10 00:00:00	2019-05-23 00:00:00	ANCIEN	\N	\N	\N	\N	14051J	\N	\N	\N
14521	ENTREPRISES	2018-10-10 00:00:00	2019-05-23 00:00:00	ANCIEN	\N	\N	\N	\N	14227Q	\N	\N	\N
14547	INFRACTIONS	2018-10-31 00:00:00	2019-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	11083R	\N	\N	\N
14548	INFRACTIONS	2018-10-31 00:00:00	2019-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	19697Q	\N	\N	\N
14549	INFRACTIONS	2018-10-31 00:00:00	2019-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	14030Q	\N	\N	\N
14550	INFRACTIONS	2018-10-31 00:00:00	2019-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	14231L	\N	\N	\N
14551	INFRACTIONS	2018-10-31 00:00:00	2019-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	19569H	\N	\N	\N
14552	INFRACTIONS	2018-10-31 00:00:00	2019-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	19749K	\N	\N	\N
14553	INFRACTIONS	2018-10-31 00:00:00	2019-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	19553Y	\N	\N	\N
14554	INFRACTIONS	2018-10-31 00:00:00	2019-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	08031R	\N	\N	\N
14555	INFRACTIONS	2018-10-31 00:00:00	2019-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	11033F	\N	\N	\N
14556	INFRACTIONS	2018-10-31 00:00:00	2019-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	19585H	\N	\N	\N
14557	INFRACTIONS	2018-10-31 00:00:00	2019-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	08043V	\N	\N	\N
14558	INFRACTIONS	2018-10-31 00:00:00	2019-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	19295A	\N	\N	\N
14559	INFRACTIONS	2018-10-31 00:00:00	2019-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	19649G	\N	\N	\N
14560	INFRACTIONS	2018-10-31 00:00:00	2019-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	11067R	\N	\N	\N
14561	INFRACTIONS	2018-10-31 00:00:00	2019-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	11045K	\N	\N	\N
14562	INFRACTIONS	2018-10-31 00:00:00	2019-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	\N	\N	\N
14563	INFRACTIONS	2018-10-31 00:00:00	2019-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	19415P	\N	\N	\N
14564	INFRACTIONS	2018-10-31 00:00:00	2019-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	19621T	\N	\N	\N
14565	INFRACTIONS	2018-10-31 00:00:00	2019-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	\N	\N	\N
14566	INFRACTIONS	2018-10-31 00:00:00	2019-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	10006L	\N	\N	\N
14567	INFRACTIONS	2018-10-31 00:00:00	2019-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	19673G	\N	\N	\N
14568	INFRACTIONS	2018-10-31 00:00:00	2019-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	14213J	\N	\N	\N
14569	INFRACTIONS	2018-10-31 00:00:00	2019-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	19447X	\N	\N	\N
14570	INFRACTIONS	2018-10-31 00:00:00	2019-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	19723Y	\N	\N	\N
14571	INFRACTIONS	2018-10-31 00:00:00	2019-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	14147R	\N	\N	\N
14572	INFRACTIONS	2018-10-31 00:00:00	2019-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	14223L	\N	\N	\N
14573	INFRACTIONS	2018-10-31 00:00:00	2019-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	19533U	\N	\N	\N
14574	INFRACTIONS	2018-10-31 00:00:00	2019-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	11043H	\N	\N	\N
14575	NEANT	2018-11-04 00:00:00	2018-12-05 00:00:00	ANCIEN	\N	\N	\N	\N	99002P	\N	\N	\N
14578	AFCL	2018-11-20 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	19335Q	\N	\N	\N
14579	SOCI	2018-11-20 00:00:00	2022-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	19301E	\N	\N	\N
14580	CAE	2018-11-21 00:00:00	2020-08-06 00:00:00	ANCIEN	\N	\N	\N	\N	19782L	\N	\N	\N
14589	PLFR2018	2018-11-19 00:00:00	2018-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	SUPPLEANT	\N	\N
14590	PLFR2018	2018-11-19 00:00:00	2018-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	14327T	SUPPLEANT	\N	\N
14591	PLFR2018	2018-11-19 00:00:00	2018-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	19647E	SUPPLEANT	\N	\N
14592	PLFR2018	2018-11-19 00:00:00	2018-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	19711U	SUPPLEANT	\N	\N
14593	PLFR2018	2018-11-19 00:00:00	2018-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	19671E	SUPPLEANT	\N	\N
14594	PLFR2018	2018-11-19 00:00:00	2018-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	08073C	SUPPLEANT	\N	\N
14595	PLFSS2019	2018-11-15 00:00:00	2018-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	TITULAIRE	\N	\N
14596	PLFSS2019	2018-11-15 00:00:00	2018-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	01034P	TITULAIRE	\N	\N
14597	PLFSS2019	2018-11-15 00:00:00	2018-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	10006L	TITULAIRE	\N	\N
14598	PLFSS2019	2018-11-15 00:00:00	2018-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	11097X	TITULAIRE	\N	\N
14599	PLFSS2019	2018-11-15 00:00:00	2018-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	TITULAIRE	\N	\N
14600	PLFSS2019	2018-11-15 00:00:00	2018-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	11067R	TITULAIRE	\N	\N
14601	PLFSS2019	2018-11-15 00:00:00	2018-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	14261S	TITULAIRE	\N	\N
14602	PLFSS2019	2018-11-15 00:00:00	2018-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	14239U	SUPPLEANT	\N	\N
14603	PLFSS2019	2018-11-15 00:00:00	2018-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	19415P	SUPPLEANT	\N	\N
14604	PLFSS2019	2018-11-15 00:00:00	2018-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	11031D	SUPPLEANT	\N	\N
14605	PLFSS2019	2018-11-15 00:00:00	2018-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	98024R	SUPPLEANT	\N	\N
14606	PLFSS2019	2018-11-15 00:00:00	2018-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	14042U	SUPPLEANT	\N	\N
14607	PLFSS2019	2018-11-15 00:00:00	2018-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	14227Q	SUPPLEANT	\N	\N
14608	PLFSS2019	2018-11-15 00:00:00	2018-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	95041E	SUPPLEANT	\N	\N
14651	ORDONNANCES	2018-12-12 00:00:00	2018-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	96004D	TITULAIRE	\N	\N
14652	ORDONNANCES	2018-12-12 00:00:00	2018-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	98050T	TITULAIRE	\N	\N
14653	ORDONNANCES	2018-12-12 00:00:00	2018-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	14331P	TITULAIRE	\N	\N
14654	ORDONNANCES	2018-12-12 00:00:00	2018-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	19569H	TITULAIRE	\N	\N
14655	ORDONNANCES	2018-12-12 00:00:00	2018-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	14001X	TITULAIRE	\N	\N
14656	ORDONNANCES	2018-12-12 00:00:00	2018-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	01062T	TITULAIRE	\N	\N
14657	ORDONNANCES	2018-12-12 00:00:00	2018-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	11083R	TITULAIRE	\N	\N
14658	ORDONNANCES	2018-12-12 00:00:00	2018-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	11040E	SUPPLEANT	\N	\N
14659	ORDONNANCES	2018-12-12 00:00:00	2018-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	98022P	SUPPLEANT	\N	\N
14660	ORDONNANCES	2018-12-12 00:00:00	2018-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	04097T	SUPPLEANT	\N	\N
14661	ORDONNANCES	2018-12-12 00:00:00	2018-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	14073Q	SUPPLEANT	\N	\N
14662	ORDONNANCES	2018-12-12 00:00:00	2018-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	19709B	SUPPLEANT	\N	\N
14663	ORDONNANCES	2018-12-12 00:00:00	2018-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	08017T	SUPPLEANT	\N	\N
14664	ORDONNANCES	2018-12-12 00:00:00	2018-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	19573D	SUPPLEANT	\N	\N
14823	AFEU	2019-04-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14241N	\N	\N	\N
14835	SOUVERAINETE	2019-04-10 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	14093U	\N	\N	\N
14922	FONDS	2019-05-22 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	11056N	\N	\N	\N
14923	FONDS	2019-05-22 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	08014Q	\N	\N	\N
14924	FONDS	2019-05-22 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	19295A	\N	\N	\N
14925	FONDS	2019-05-22 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	19725B	\N	\N	\N
14926	FONDS	2019-05-22 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	19531S	\N	\N	\N
14927	FONDS	2019-05-22 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	14001X	\N	\N	\N
14928	FONDS	2019-05-22 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	14030Q	\N	\N	\N
14929	FONDS	2019-05-22 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	14327T	\N	\N	\N
14930	FONDS	2019-05-22 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	19441R	\N	\N	\N
14934	FONDS	2019-05-22 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	14053L	\N	\N	\N
14932	FONDS	2019-05-22 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04057K	\N	\N	\N
14933	FONDS	2019-05-22 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	19747H	\N	\N	\N
14935	FONDS	2019-05-22 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	14033T	\N	\N	\N
14936	FONDS	2019-05-22 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	14026U	\N	\N	\N
14937	FONDS	2019-05-22 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	08069G	\N	\N	\N
14938	FONDS	2019-05-22 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04097T	\N	\N	\N
14939	FONDS	2019-05-22 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	08015R	\N	\N	\N
14940	FONDS	2019-05-22 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	19581D	\N	\N	\N
14941	FONDS	2019-05-22 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	14071N	\N	\N	\N
15141	CLIMAT	2019-07-17 00:00:00	2019-07-26 00:00:00	ANCIEN	\N	\N	\N	\N	11090Q	TITULAIRE	\N	\N
15142	CLIMAT	2019-07-17 00:00:00	2019-07-26 00:00:00	ANCIEN	\N	\N	\N	\N	14033T	TITULAIRE	\N	\N
15143	CLIMAT	2019-07-17 00:00:00	2019-07-26 00:00:00	ANCIEN	\N	\N	\N	\N	19733B	TITULAIRE	\N	\N
15144	CLIMAT	2019-07-17 00:00:00	2019-07-26 00:00:00	ANCIEN	\N	\N	\N	\N	19369B	TITULAIRE	\N	\N
15145	CLIMAT	2019-07-17 00:00:00	2019-07-26 00:00:00	ANCIEN	\N	\N	\N	\N	19631V	TITULAIRE	\N	\N
15146	CLIMAT	2019-07-17 00:00:00	2019-07-26 00:00:00	ANCIEN	\N	\N	\N	\N	19503N	TITULAIRE	\N	\N
15147	CLIMAT	2019-07-17 00:00:00	2019-07-26 00:00:00	ANCIEN	\N	\N	\N	\N	19782L	TITULAIRE	\N	\N
15148	CLIMAT	2019-07-17 00:00:00	2019-07-26 00:00:00	ANCIEN	\N	\N	\N	\N	14357A	SUPPLEANT	\N	\N
15149	CLIMAT	2019-07-17 00:00:00	2019-07-26 00:00:00	ANCIEN	\N	\N	\N	\N	11065P	SUPPLEANT	\N	\N
15150	CLIMAT	2019-07-17 00:00:00	2019-07-26 00:00:00	ANCIEN	\N	\N	\N	\N	14187A	SUPPLEANT	\N	\N
15151	CLIMAT	2019-07-17 00:00:00	2019-07-26 00:00:00	ANCIEN	\N	\N	\N	\N	19695N	SUPPLEANT	\N	\N
15152	CLIMAT	2019-07-17 00:00:00	2019-07-26 00:00:00	ANCIEN	\N	\N	\N	\N	19591F	SUPPLEANT	\N	\N
15153	CLIMAT	2019-07-17 00:00:00	2019-07-26 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	SUPPLEANT	\N	\N
15154	CLIMAT	2019-07-17 00:00:00	2019-07-26 00:00:00	ANCIEN	\N	\N	\N	\N	14219Q	SUPPLEANT	\N	\N
15155	AGENCESPORT	2019-07-17 00:00:00	2019-07-24 00:00:00	ANCIEN	\N	\N	\N	\N	04070G	TITULAIRE	\N	\N
15156	AGENCESPORT	2019-07-17 00:00:00	2019-07-24 00:00:00	ANCIEN	\N	\N	\N	\N	14073Q	TITULAIRE	\N	\N
15157	AGENCESPORT	2019-07-17 00:00:00	2019-07-24 00:00:00	ANCIEN	\N	\N	\N	\N	19447X	TITULAIRE	\N	\N
14637	PLF2019	2018-12-07 00:00:00	2018-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	11074Q	TITULAIRE	\N	\N
14638	PLF2019	2018-12-07 00:00:00	2018-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	08011M	TITULAIRE	\N	\N
14639	PLF2019	2018-12-07 00:00:00	2018-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	TITULAIRE	\N	\N
14640	PLF2019	2018-12-07 00:00:00	2018-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	TITULAIRE	\N	\N
14641	PLF2019	2018-12-07 00:00:00	2018-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	14327T	TITULAIRE	\N	\N
14642	PLF2019	2018-12-07 00:00:00	2018-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	14225N	TITULAIRE	\N	\N
14643	PLF2019	2018-12-07 00:00:00	2018-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	19651A	TITULAIRE	\N	\N
14644	PLF2019	2018-12-07 00:00:00	2018-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	14085U	SUPPLEANT	\N	\N
14645	PLF2019	2018-12-07 00:00:00	2018-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	11070L	SUPPLEANT	\N	\N
14646	PLF2019	2018-12-07 00:00:00	2018-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	19711U	SUPPLEANT	\N	\N
14647	PLF2019	2018-12-07 00:00:00	2018-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	01048V	SUPPLEANT	\N	\N
14648	PLF2019	2018-12-07 00:00:00	2018-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	19671E	SUPPLEANT	\N	\N
14649	PLF2019	2018-12-07 00:00:00	2018-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	11012A	SUPPLEANT	\N	\N
14650	PLF2019	2018-12-07 00:00:00	2018-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	19687N	SUPPLEANT	\N	\N
8288	2011CMP22	2011-11-02 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	07034Q	TITULAIRE	\N	\N
8413	2012CMP1	2011-12-21 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	07034Q	TITULAIRE	\N	\N
10423	2014CMP8	2014-04-30 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	07034Q	SUPPLEANT	\N	\N
14764	NEANT	2019-03-04 00:00:00	2019-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	19798U	\N	\N	\N
14794	TRANSPORTS	2019-03-13 00:00:00	2019-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	19585H	\N	\N	\N
15094	CDD	2019-06-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04069P	\N	\N	\N
15095	FINC	2019-06-27 00:00:00	2020-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	96004D	\N	\N	\N
15158	AGENCESPORT	2019-07-17 00:00:00	2019-07-24 00:00:00	ANCIEN	\N	\N	\N	\N	19399H	TITULAIRE	\N	\N
15159	AGENCESPORT	2019-07-17 00:00:00	2019-07-24 00:00:00	ANCIEN	\N	\N	\N	\N	14021P	TITULAIRE	\N	\N
15160	AGENCESPORT	2019-07-17 00:00:00	2019-07-24 00:00:00	ANCIEN	\N	\N	\N	\N	08012N	TITULAIRE	\N	\N
15161	AGENCESPORT	2019-07-17 00:00:00	2019-07-24 00:00:00	ANCIEN	\N	\N	\N	\N	19349W	TITULAIRE	\N	\N
15162	AGENCESPORT	2019-07-17 00:00:00	2019-07-24 00:00:00	ANCIEN	\N	\N	\N	\N	19643A	SUPPLEANT	\N	\N
15163	AGENCESPORT	2019-07-17 00:00:00	2019-07-24 00:00:00	ANCIEN	\N	\N	\N	\N	19758L	SUPPLEANT	\N	\N
15164	AGENCESPORT	2019-07-17 00:00:00	2019-07-24 00:00:00	ANCIEN	\N	\N	\N	\N	19693L	SUPPLEANT	\N	\N
15165	AGENCESPORT	2019-07-17 00:00:00	2019-07-24 00:00:00	ANCIEN	\N	\N	\N	\N	14249W	SUPPLEANT	\N	\N
15166	AGENCESPORT	2019-07-17 00:00:00	2019-07-24 00:00:00	ANCIEN	\N	\N	\N	\N	14123H	SUPPLEANT	\N	\N
15167	AGENCESPORT	2019-07-17 00:00:00	2019-07-24 00:00:00	ANCIEN	\N	\N	\N	\N	14241N	SUPPLEANT	\N	\N
15168	AGENCESPORT	2019-07-17 00:00:00	2019-07-24 00:00:00	ANCIEN	\N	\N	\N	\N	14229S	SUPPLEANT	\N	\N
15169	MUSIQUE	2019-07-24 00:00:00	2019-09-14 00:00:00	ANCIEN	\N	\N	\N	\N	04070G	TITULAIRE	\N	\N
15170	MUSIQUE	2019-07-24 00:00:00	2019-09-14 00:00:00	ANCIEN	\N	\N	\N	\N	19399H	TITULAIRE	\N	\N
15171	MUSIQUE	2019-07-24 00:00:00	2019-09-14 00:00:00	ANCIEN	\N	\N	\N	\N	08039A	TITULAIRE	\N	\N
15172	MUSIQUE	2019-07-24 00:00:00	2019-09-14 00:00:00	ANCIEN	\N	\N	\N	\N	14249W	TITULAIRE	\N	\N
15173	MUSIQUE	2019-07-24 00:00:00	2019-09-14 00:00:00	ANCIEN	\N	\N	\N	\N	14229S	TITULAIRE	\N	\N
15174	MUSIQUE	2019-07-24 00:00:00	2019-09-14 00:00:00	ANCIEN	\N	\N	\N	\N	08043V	TITULAIRE	\N	\N
15175	MUSIQUE	2019-07-24 00:00:00	2019-09-14 00:00:00	ANCIEN	\N	\N	\N	\N	11083R	TITULAIRE	\N	\N
15176	MUSIQUE	2019-07-24 00:00:00	2019-09-14 00:00:00	ANCIEN	\N	\N	\N	\N	19643A	SUPPLEANT	\N	\N
15177	MUSIQUE	2019-07-24 00:00:00	2019-09-14 00:00:00	ANCIEN	\N	\N	\N	\N	19621T	SUPPLEANT	\N	\N
15178	MUSIQUE	2019-07-24 00:00:00	2019-09-14 00:00:00	ANCIEN	\N	\N	\N	\N	08031R	SUPPLEANT	\N	\N
15179	MUSIQUE	2019-07-24 00:00:00	2019-09-14 00:00:00	ANCIEN	\N	\N	\N	\N	08017T	SUPPLEANT	\N	\N
15180	MUSIQUE	2019-07-24 00:00:00	2019-09-14 00:00:00	ANCIEN	\N	\N	\N	\N	19593H	SUPPLEANT	\N	\N
15181	MUSIQUE	2019-07-24 00:00:00	2019-09-14 00:00:00	ANCIEN	\N	\N	\N	\N	19573D	SUPPLEANT	\N	\N
15182	MUSIQUE	2019-07-24 00:00:00	2019-09-14 00:00:00	ANCIEN	\N	\N	\N	\N	19735D	SUPPLEANT	\N	\N
15183	PRESSE	2019-07-24 00:00:00	2019-09-25 00:00:00	ANCIEN	\N	\N	\N	\N	04070G	TITULAIRE	\N	\N
15184	PRESSE	2019-07-24 00:00:00	2019-09-25 00:00:00	ANCIEN	\N	\N	\N	\N	19699S	TITULAIRE	\N	\N
15185	PRESSE	2019-07-24 00:00:00	2019-09-25 00:00:00	ANCIEN	\N	\N	\N	\N	08039A	TITULAIRE	\N	\N
15186	PRESSE	2019-07-24 00:00:00	2019-09-25 00:00:00	ANCIEN	\N	\N	\N	\N	19399H	TITULAIRE	\N	\N
15187	PRESSE	2019-07-24 00:00:00	2019-09-25 00:00:00	ANCIEN	\N	\N	\N	\N	04059M	TITULAIRE	\N	\N
15188	PRESSE	2019-07-24 00:00:00	2019-09-25 00:00:00	ANCIEN	\N	\N	\N	\N	14229S	TITULAIRE	\N	\N
15189	PRESSE	2019-07-24 00:00:00	2019-09-25 00:00:00	ANCIEN	\N	\N	\N	\N	11083R	TITULAIRE	\N	\N
15190	PRESSE	2019-07-24 00:00:00	2019-09-25 00:00:00	ANCIEN	\N	\N	\N	\N	08043V	SUPPLEANT	\N	\N
15191	PRESSE	2019-07-24 00:00:00	2019-09-25 00:00:00	ANCIEN	\N	\N	\N	\N	19758L	SUPPLEANT	\N	\N
15192	PRESSE	2019-07-24 00:00:00	2019-09-25 00:00:00	ANCIEN	\N	\N	\N	\N	19693L	SUPPLEANT	\N	\N
15193	PRESSE	2019-07-24 00:00:00	2019-09-25 00:00:00	ANCIEN	\N	\N	\N	\N	14123H	SUPPLEANT	\N	\N
15194	PRESSE	2019-07-24 00:00:00	2019-09-25 00:00:00	ANCIEN	\N	\N	\N	\N	14241N	SUPPLEANT	\N	\N
15195	PRESSE	2019-07-24 00:00:00	2019-09-25 00:00:00	ANCIEN	\N	\N	\N	\N	14061L	SUPPLEANT	\N	\N
15196	PRESSE	2019-07-24 00:00:00	2019-09-25 00:00:00	ANCIEN	\N	\N	\N	\N	19533U	SUPPLEANT	\N	\N
15265	RADICALI	2019-11-14 00:00:00	2020-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	04040A	\N	\N	\N
15266	RADICALI	2019-11-14 00:00:00	2020-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	19721W	\N	\N	\N
15267	RADICALI	2019-11-14 00:00:00	2020-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	07004J	\N	\N	\N
15268	RADICALI	2019-11-14 00:00:00	2020-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	14097Y	\N	\N	\N
15269	RADICALI	2019-11-14 00:00:00	2020-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	11026G	\N	\N	\N
15270	RADICALI	2019-11-14 00:00:00	2020-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	08053X	\N	\N	\N
15271	RADICALI	2019-11-14 00:00:00	2020-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	19669L	\N	\N	\N
15272	RADICALI	2019-11-14 00:00:00	2020-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	11080N	\N	\N	\N
15273	RADICALI	2019-11-14 00:00:00	2020-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	14249W	\N	\N	\N
15274	RADICALI	2019-11-14 00:00:00	2020-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	14187A	\N	\N	\N
15275	RADICALI	2019-11-14 00:00:00	2020-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	19673G	\N	\N	\N
15276	RADICALI	2019-11-14 00:00:00	2020-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	08010L	\N	\N	\N
15277	RADICALI	2019-11-14 00:00:00	2020-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	19671E	\N	\N	\N
15278	RADICALI	2019-11-14 00:00:00	2020-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	10015M	\N	\N	\N
15279	RADICALI	2019-11-14 00:00:00	2020-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	19421M	\N	\N	\N
15280	RADICALI	2019-11-14 00:00:00	2020-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	\N	\N	\N
15281	RADICALI	2019-11-14 00:00:00	2020-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	08056B	\N	\N	\N
15282	RADICALI	2019-11-14 00:00:00	2020-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	19719D	\N	\N	\N
15283	RADICALI	2019-11-14 00:00:00	2020-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	\N	\N	\N
15284	RADICALI	2019-11-14 00:00:00	2020-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	19585H	\N	\N	\N
15285	RADICALI	2019-11-14 00:00:00	2020-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	19651A	\N	\N	\N
15300	PLFR2019	2019-11-15 00:00:00	2019-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	11074Q	TITULAIRE	\N	\N
15301	PLFR2019	2019-11-15 00:00:00	2019-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	08011M	TITULAIRE	\N	\N
15302	PLFR2019	2019-11-15 00:00:00	2019-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	TITULAIRE	\N	\N
15303	PLFR2019	2019-11-15 00:00:00	2019-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	19711U	TITULAIRE	\N	\N
15304	PLFR2019	2019-11-15 00:00:00	2019-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	07004J	TITULAIRE	\N	\N
15305	PLFR2019	2019-11-15 00:00:00	2019-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	14225N	TITULAIRE	\N	\N
15306	PLFR2019	2019-11-15 00:00:00	2019-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	19349W	TITULAIRE	\N	\N
15307	PLFR2019	2019-11-15 00:00:00	2019-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	SUPPLEANT	\N	\N
15308	PLFR2019	2019-11-15 00:00:00	2019-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	04071H	SUPPLEANT	\N	\N
15309	PLFR2019	2019-11-15 00:00:00	2019-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	19671E	SUPPLEANT	\N	\N
15310	PLFR2019	2019-11-15 00:00:00	2019-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	14327T	SUPPLEANT	\N	\N
15311	PLFR2019	2019-11-15 00:00:00	2019-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	14085U	SUPPLEANT	\N	\N
15312	PLFR2019	2019-11-15 00:00:00	2019-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	11012A	SUPPLEANT	\N	\N
15313	PLFR2019	2019-11-15 00:00:00	2019-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	11040E	SUPPLEANT	\N	\N
15328	PROXIMITE	2019-11-28 00:00:00	2019-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
15329	PROXIMITE	2019-11-28 00:00:00	2019-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	14259Y	TITULAIRE	\N	\N
15330	PROXIMITE	2019-11-28 00:00:00	2019-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	14231L	TITULAIRE	\N	\N
15331	PROXIMITE	2019-11-28 00:00:00	2019-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	TITULAIRE	\N	\N
15332	PROXIMITE	2019-11-28 00:00:00	2019-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	19489J	TITULAIRE	\N	\N
15333	PROXIMITE	2019-11-28 00:00:00	2019-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	14001X	TITULAIRE	\N	\N
15334	PROXIMITE	2019-11-28 00:00:00	2019-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	TITULAIRE	\N	\N
15335	PROXIMITE	2019-11-28 00:00:00	2019-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	08018U	SUPPLEANT	\N	\N
15336	PROXIMITE	2019-11-28 00:00:00	2019-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	14147R	SUPPLEANT	\N	\N
15337	PROXIMITE	2019-11-28 00:00:00	2019-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	19762G	SUPPLEANT	\N	\N
15338	PROXIMITE	2019-11-28 00:00:00	2019-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	14179A	SUPPLEANT	\N	\N
15339	PROXIMITE	2019-11-28 00:00:00	2019-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	SUPPLEANT	\N	\N
15340	PROXIMITE	2019-11-28 00:00:00	2019-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	\N	\N
15341	PROXIMITE	2019-11-28 00:00:00	2019-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	19719D	SUPPLEANT	\N	\N
15342	PLF2020	2019-12-06 00:00:00	2019-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	11074Q	TITULAIRE	\N	\N
15343	PLF2020	2019-12-06 00:00:00	2019-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	08011M	TITULAIRE	\N	\N
15344	PLF2020	2019-12-06 00:00:00	2019-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	TITULAIRE	\N	\N
15345	PLF2020	2019-12-06 00:00:00	2019-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	01057W	TITULAIRE	\N	\N
15346	PLF2020	2019-12-06 00:00:00	2019-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	14327T	TITULAIRE	\N	\N
15347	PLF2020	2019-12-06 00:00:00	2019-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	14225N	TITULAIRE	\N	\N
15348	PLF2020	2019-12-06 00:00:00	2019-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	19651A	TITULAIRE	\N	\N
14581	PLFR2018	2018-11-19 00:00:00	2018-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	11074Q	TITULAIRE	\N	\N
14582	PLFR2018	2018-11-19 00:00:00	2018-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	08011M	TITULAIRE	\N	\N
14583	PLFR2018	2018-11-19 00:00:00	2018-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	08034U	TITULAIRE	\N	\N
14584	PLFR2018	2018-11-19 00:00:00	2018-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	19741B	TITULAIRE	\N	\N
14585	PLFR2018	2018-11-19 00:00:00	2018-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	14083S	TITULAIRE	\N	\N
14586	PLFR2018	2018-11-19 00:00:00	2018-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	14225N	TITULAIRE	\N	\N
14587	PLFR2018	2018-11-19 00:00:00	2018-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	11012A	TITULAIRE	\N	\N
14588	PLFR2018	2018-11-19 00:00:00	2018-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	11040E	SUPPLEANT	\N	\N
14609	REFORME	2018-11-26 00:00:00	2018-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
14610	REFORME	2018-11-26 00:00:00	2018-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
14611	REFORME	2018-11-26 00:00:00	2018-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	01024M	TITULAIRE	\N	\N
14612	REFORME	2018-11-26 00:00:00	2018-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	19447X	TITULAIRE	\N	\N
14613	REFORME	2018-11-26 00:00:00	2018-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	14065Q	TITULAIRE	\N	\N
14614	REFORME	2018-11-26 00:00:00	2018-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
14615	REFORME	2018-11-26 00:00:00	2018-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	11072N	TITULAIRE	\N	\N
14616	REFORME	2018-11-26 00:00:00	2018-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	SUPPLEANT	\N	\N
14617	REFORME	2018-11-26 00:00:00	2018-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	19629C	SUPPLEANT	\N	\N
14618	REFORME	2018-11-26 00:00:00	2018-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	SUPPLEANT	\N	\N
14619	REFORME	2018-11-26 00:00:00	2018-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	19649G	SUPPLEANT	\N	\N
14620	REFORME	2018-11-26 00:00:00	2018-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	19729F	SUPPLEANT	\N	\N
14621	REFORME	2018-11-26 00:00:00	2018-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	11085T	SUPPLEANT	\N	\N
14622	REFORME	2018-11-26 00:00:00	2018-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	\N	\N
14623	JURIDICTIONS	2018-11-26 00:00:00	2018-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
14624	JURIDICTIONS	2018-11-26 00:00:00	2018-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
14625	JURIDICTIONS	2018-11-26 00:00:00	2018-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	01024M	TITULAIRE	\N	\N
14626	JURIDICTIONS	2018-11-26 00:00:00	2018-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	19447X	TITULAIRE	\N	\N
14627	JURIDICTIONS	2018-11-26 00:00:00	2018-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	14065Q	TITULAIRE	\N	\N
14628	JURIDICTIONS	2018-11-26 00:00:00	2018-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
14629	JURIDICTIONS	2018-11-26 00:00:00	2018-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	11072N	TITULAIRE	\N	\N
14630	JURIDICTIONS	2018-11-26 00:00:00	2018-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	SUPPLEANT	\N	\N
14631	JURIDICTIONS	2018-11-26 00:00:00	2018-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	19629C	SUPPLEANT	\N	\N
14632	JURIDICTIONS	2018-11-26 00:00:00	2018-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	SUPPLEANT	\N	\N
14633	JURIDICTIONS	2018-11-26 00:00:00	2018-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	19649G	SUPPLEANT	\N	\N
14634	JURIDICTIONS	2018-11-26 00:00:00	2018-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	19729F	SUPPLEANT	\N	\N
14635	JURIDICTIONS	2018-11-26 00:00:00	2018-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	11085T	SUPPLEANT	\N	\N
14636	JURIDICTIONS	2018-11-26 00:00:00	2018-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	\N	\N
14749	SIDERURGIE	2019-01-31 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	11101A	\N	\N	\N
14795	ANCT	2019-03-20 00:00:00	2019-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	08009T	TITULAIRE	\N	\N
14796	ANCT	2019-03-20 00:00:00	2019-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	14169X	TITULAIRE	\N	\N
14797	ANCT	2019-03-20 00:00:00	2019-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	14038Y	TITULAIRE	\N	\N
14798	ANCT	2019-03-20 00:00:00	2019-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	05012A	TITULAIRE	\N	\N
14799	ANCT	2019-03-20 00:00:00	2019-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	14051J	TITULAIRE	\N	\N
14800	ANCT	2019-03-20 00:00:00	2019-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	19549D	TITULAIRE	\N	\N
14801	ANCT	2019-03-20 00:00:00	2019-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	08024S	TITULAIRE	\N	\N
14802	ANCT	2019-03-20 00:00:00	2019-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	19383Y	SUPPLEANT	\N	\N
14803	ANCT	2019-03-20 00:00:00	2019-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	19701S	SUPPLEANT	\N	\N
14804	ANCT	2019-03-20 00:00:00	2019-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	19347U	SUPPLEANT	\N	\N
14805	ANCT	2019-03-20 00:00:00	2019-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	04097T	SUPPLEANT	\N	\N
14806	ANCT	2019-03-20 00:00:00	2019-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	14219Q	SUPPLEANT	\N	\N
14807	ANCT	2019-03-20 00:00:00	2019-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	19503N	SUPPLEANT	\N	\N
14808	ANCT	2019-03-20 00:00:00	2019-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	11012A	SUPPLEANT	\N	\N
14809	ANCTORG	2019-03-20 00:00:00	2019-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	08009T	TITULAIRE	\N	\N
14810	ANCTORG	2019-03-20 00:00:00	2019-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	14169X	TITULAIRE	\N	\N
14811	ANCTORG	2019-03-20 00:00:00	2019-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	14038Y	TITULAIRE	\N	\N
14812	ANCTORG	2019-03-20 00:00:00	2019-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	05012A	TITULAIRE	\N	\N
14813	ANCTORG	2019-03-20 00:00:00	2019-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	14051J	TITULAIRE	\N	\N
14814	ANCTORG	2019-03-20 00:00:00	2019-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	19549D	TITULAIRE	\N	\N
14815	ANCTORG	2019-03-20 00:00:00	2019-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	08024S	TITULAIRE	\N	\N
14816	ANCTORG	2019-03-20 00:00:00	2019-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	19383Y	SUPPLEANT	\N	\N
14817	ANCTORG	2019-03-20 00:00:00	2019-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	19701S	SUPPLEANT	\N	\N
14818	ANCTORG	2019-03-20 00:00:00	2019-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	19347U	SUPPLEANT	\N	\N
14819	ANCTORG	2019-03-20 00:00:00	2019-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	04097T	SUPPLEANT	\N	\N
14820	ANCTORG	2019-03-20 00:00:00	2019-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	14219Q	SUPPLEANT	\N	\N
14821	ANCTORG	2019-03-20 00:00:00	2019-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	19503N	SUPPLEANT	\N	\N
14822	ANCTORG	2019-03-20 00:00:00	2019-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	11012A	SUPPLEANT	\N	\N
14974	ECOLE	2019-06-05 00:00:00	2019-06-14 00:00:00	ANCIEN	\N	\N	\N	\N	04070G	TITULAIRE	\N	\N
14975	ECOLE	2019-06-05 00:00:00	2019-06-14 00:00:00	ANCIEN	\N	\N	\N	\N	19621T	TITULAIRE	\N	\N
14976	ECOLE	2019-06-05 00:00:00	2019-06-14 00:00:00	ANCIEN	\N	\N	\N	\N	14123H	TITULAIRE	\N	\N
14977	ECOLE	2019-06-05 00:00:00	2019-06-14 00:00:00	ANCIEN	\N	\N	\N	\N	19693L	TITULAIRE	\N	\N
14978	ECOLE	2019-06-05 00:00:00	2019-06-14 00:00:00	ANCIEN	\N	\N	\N	\N	08043V	TITULAIRE	\N	\N
14979	ECOLE	2019-06-05 00:00:00	2019-06-14 00:00:00	ANCIEN	\N	\N	\N	\N	14109K	TITULAIRE	\N	\N
14980	ECOLE	2019-06-05 00:00:00	2019-06-14 00:00:00	ANCIEN	\N	\N	\N	\N	14039A	TITULAIRE	\N	\N
14981	ECOLE	2019-06-05 00:00:00	2019-06-14 00:00:00	ANCIEN	\N	\N	\N	\N	19758L	SUPPLEANT	\N	\N
14982	ECOLE	2019-06-05 00:00:00	2019-06-14 00:00:00	ANCIEN	\N	\N	\N	\N	08031R	SUPPLEANT	\N	\N
14983	ECOLE	2019-06-05 00:00:00	2019-06-14 00:00:00	ANCIEN	\N	\N	\N	\N	19611R	SUPPLEANT	\N	\N
14984	ECOLE	2019-06-05 00:00:00	2019-06-14 00:00:00	ANCIEN	\N	\N	\N	\N	14071N	SUPPLEANT	\N	\N
14985	ECOLE	2019-06-05 00:00:00	2019-06-14 00:00:00	ANCIEN	\N	\N	\N	\N	19573D	SUPPLEANT	\N	\N
14986	ECOLE	2019-06-05 00:00:00	2019-06-14 00:00:00	ANCIEN	\N	\N	\N	\N	19533U	SUPPLEANT	\N	\N
14987	ECOLE	2019-06-05 00:00:00	2019-06-14 00:00:00	ANCIEN	\N	\N	\N	\N	14229S	SUPPLEANT	\N	\N
14988	SYSTEME	2019-06-05 00:00:00	2019-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	TITULAIRE	\N	\N
14989	SYSTEME	2019-06-05 00:00:00	2019-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	19575F	TITULAIRE	\N	\N
14990	SYSTEME	2019-06-05 00:00:00	2019-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	14213J	TITULAIRE	\N	\N
14991	SYSTEME	2019-06-05 00:00:00	2019-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	TITULAIRE	\N	\N
14992	SYSTEME	2019-06-05 00:00:00	2019-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	19683J	TITULAIRE	\N	\N
14993	SYSTEME	2019-06-05 00:00:00	2019-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	14042U	TITULAIRE	\N	\N
14994	SYSTEME	2019-06-05 00:00:00	2019-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	14239U	TITULAIRE	\N	\N
14995	SYSTEME	2019-06-05 00:00:00	2019-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	11031D	SUPPLEANT	\N	\N
14996	SYSTEME	2019-06-05 00:00:00	2019-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	14217N	SUPPLEANT	\N	\N
14997	SYSTEME	2019-06-05 00:00:00	2019-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	19727D	SUPPLEANT	\N	\N
14998	SYSTEME	2019-06-05 00:00:00	2019-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	19553Y	SUPPLEANT	\N	\N
14999	SYSTEME	2019-06-05 00:00:00	2019-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	11097X	SUPPLEANT	\N	\N
15000	SYSTEME	2019-06-05 00:00:00	2019-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	19703U	SUPPLEANT	\N	\N
15001	SYSTEME	2019-06-05 00:00:00	2019-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	01034P	SUPPLEANT	\N	\N
15097	MOBILITES	2019-07-03 00:00:00	2019-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	08009T	TITULAIRE	\N	\N
15098	MOBILITES	2019-07-03 00:00:00	2019-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	14031R	TITULAIRE	\N	\N
15099	MOBILITES	2019-07-03 00:00:00	2019-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	14038Y	TITULAIRE	\N	\N
15100	MOBILITES	2019-07-03 00:00:00	2019-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	14169X	TITULAIRE	\N	\N
15101	MOBILITES	2019-07-03 00:00:00	2019-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	08055A	TITULAIRE	\N	\N
15102	MOBILITES	2019-07-03 00:00:00	2019-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	19551W	TITULAIRE	\N	\N
15103	MOBILITES	2019-07-03 00:00:00	2019-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	19637C	TITULAIRE	\N	\N
15104	MOBILITES	2019-07-03 00:00:00	2019-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	19701S	SUPPLEANT	\N	\N
15105	MOBILITES	2019-07-03 00:00:00	2019-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	19599P	SUPPLEANT	\N	\N
15106	MOBILITES	2019-07-03 00:00:00	2019-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	19387D	SUPPLEANT	\N	\N
15107	MOBILITES	2019-07-03 00:00:00	2019-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	19347U	SUPPLEANT	\N	\N
15108	MOBILITES	2019-07-03 00:00:00	2019-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	04097T	SUPPLEANT	\N	\N
15109	MOBILITES	2019-07-03 00:00:00	2019-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	17583W	SUPPLEANT	\N	\N
15110	MOBILITES	2019-07-03 00:00:00	2019-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	19737F	SUPPLEANT	\N	\N
15111	ALSACE	2019-07-02 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
15112	ALSACE	2019-07-02 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	14053L	TITULAIRE	\N	\N
15113	ALSACE	2019-07-02 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	TITULAIRE	\N	\N
15114	ALSACE	2019-07-02 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	14231L	TITULAIRE	\N	\N
15115	ALSACE	2019-07-02 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	19725B	TITULAIRE	\N	\N
14576	NEANT	2018-11-17 00:00:00	2018-11-19 00:00:00	ANCIEN	\N	\N	\N	\N	19782L	\N	\N	\N
14767	TRANSPORTS	2019-03-06 00:00:00	2019-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	19515S	\N	\N	\N
14768	TRANSPORTS	2019-03-06 00:00:00	2019-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	19549D	\N	\N	\N
14769	TRANSPORTS	2019-03-06 00:00:00	2019-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	19643A	\N	\N	\N
14770	TRANSPORTS	2019-03-06 00:00:00	2019-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	19525U	\N	\N	\N
14771	TRANSPORTS	2019-03-06 00:00:00	2019-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	\N	\N	\N
14772	TRANSPORTS	2019-03-06 00:00:00	2019-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	14079W	\N	\N	\N
14773	TRANSPORTS	2019-03-06 00:00:00	2019-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	19251M	\N	\N	\N
14774	TRANSPORTS	2019-03-06 00:00:00	2019-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	14087W	\N	\N	\N
14775	TRANSPORTS	2019-03-06 00:00:00	2019-03-13 00:00:00	ANCIEN	\N	\N	\N	\N	02002K	\N	\N	\N
14776	TRANSPORTS	2019-03-06 00:00:00	2019-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	19347U	\N	\N	\N
14777	TRANSPORTS	2019-03-06 00:00:00	2019-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	11049P	\N	\N	\N
14778	TRANSPORTS	2019-03-06 00:00:00	2019-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	14081Q	\N	\N	\N
14779	TRANSPORTS	2019-03-06 00:00:00	2019-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	19569H	\N	\N	\N
14780	TRANSPORTS	2019-03-06 00:00:00	2019-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	14179A	\N	\N	\N
14781	TRANSPORTS	2019-03-06 00:00:00	2019-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	19551W	\N	\N	\N
14782	TRANSPORTS	2019-03-06 00:00:00	2019-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	14241N	\N	\N	\N
14783	TRANSPORTS	2019-03-06 00:00:00	2019-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	19289C	\N	\N	\N
14784	TRANSPORTS	2019-03-06 00:00:00	2019-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	14031R	\N	\N	\N
14785	TRANSPORTS	2019-03-06 00:00:00	2019-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	19637C	\N	\N	\N
14786	TRANSPORTS	2019-03-06 00:00:00	2019-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	19335Q	\N	\N	\N
14787	TRANSPORTS	2019-03-06 00:00:00	2019-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	14169X	\N	\N	\N
14788	TRANSPORTS	2019-03-06 00:00:00	2019-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	14237S	\N	\N	\N
14789	TRANSPORTS	2019-03-06 00:00:00	2019-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	17637T	\N	\N	\N
14790	TRANSPORTS	2019-03-06 00:00:00	2019-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	19349W	\N	\N	\N
14791	TRANSPORTS	2019-03-06 00:00:00	2019-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	19794Q	\N	\N	\N
14792	TRANSPORTS	2019-03-06 00:00:00	2019-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	19689Q	\N	\N	\N
14793	TRANSPORTS	2019-03-06 00:00:00	2019-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	19737F	\N	\N	\N
15002	GAFA	2019-06-05 00:00:00	2019-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	11074Q	TITULAIRE	\N	\N
15003	GAFA	2019-06-05 00:00:00	2019-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	08011M	TITULAIRE	\N	\N
15004	GAFA	2019-06-05 00:00:00	2019-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	19711U	TITULAIRE	\N	\N
15005	GAFA	2019-06-05 00:00:00	2019-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	TITULAIRE	\N	\N
15006	GAFA	2019-06-05 00:00:00	2019-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	14327T	TITULAIRE	\N	\N
15007	GAFA	2019-06-05 00:00:00	2019-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	19689Q	TITULAIRE	\N	\N
15008	GAFA	2019-06-05 00:00:00	2019-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	19651A	TITULAIRE	\N	\N
15009	GAFA	2019-06-05 00:00:00	2019-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	14085U	SUPPLEANT	\N	\N
15010	GAFA	2019-06-05 00:00:00	2019-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	SUPPLEANT	\N	\N
15011	GAFA	2019-06-05 00:00:00	2019-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	11070L	SUPPLEANT	\N	\N
15012	GAFA	2019-06-05 00:00:00	2019-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	19671E	SUPPLEANT	\N	\N
15013	GAFA	2019-06-05 00:00:00	2019-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	14331P	SUPPLEANT	\N	\N
15014	GAFA	2019-06-05 00:00:00	2019-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	11012A	SUPPLEANT	\N	\N
15015	GAFA	2019-06-05 00:00:00	2019-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	19687N	SUPPLEANT	\N	\N
15016	ARTICLE13	2019-05-22 00:00:00	2019-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	08009T	TITULAIRE	\N	\N
15017	ARTICLE13	2019-05-22 00:00:00	2019-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	14103D	\N	\N	\N
15018	ARTICLE13	2019-05-22 00:00:00	2019-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	11103C	\N	\N	\N
15019	ARTICLE13	2019-05-22 00:00:00	2019-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	14329V	\N	\N	\N
15020	ARTICLE13	2019-05-22 00:00:00	2019-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	08055A	\N	\N	\N
15021	ARTICLE13	2019-05-22 00:00:00	2019-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	19333N	\N	\N	\N
15022	ARTICLE13	2019-05-22 00:00:00	2019-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	08061X	\N	\N	\N
15023	ARTICLE13	2019-05-22 00:00:00	2019-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	14038Y	SUPPLEANT	\N	\N
15024	ARTICLE13	2019-05-22 00:00:00	2019-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	11080N	SUPPLEANT	\N	\N
15025	ARTICLE13	2019-05-22 00:00:00	2019-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	18083K	SUPPLEANT	\N	\N
15026	ARTICLE13	2019-05-22 00:00:00	2019-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	11065P	SUPPLEANT	\N	\N
15027	ARTICLE13	2019-05-22 00:00:00	2019-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	19599P	SUPPLEANT	\N	\N
15028	ARTICLE13	2019-05-22 00:00:00	2019-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	19347U	SUPPLEANT	\N	\N
15029	ARTICLE13	2019-05-22 00:00:00	2019-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	17583W	SUPPLEANT	\N	\N
15030	FONCTION	2019-06-20 00:00:00	2019-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
15031	FONCTION	2019-06-20 00:00:00	2019-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	TITULAIRE	\N	\N
15032	FONCTION	2019-06-20 00:00:00	2019-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	14179A	TITULAIRE	\N	\N
15033	FONCTION	2019-06-20 00:00:00	2019-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	TITULAIRE	\N	\N
15034	FONCTION	2019-06-20 00:00:00	2019-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	14151M	TITULAIRE	\N	\N
15035	FONCTION	2019-06-20 00:00:00	2019-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	14001X	TITULAIRE	\N	\N
15036	FONCTION	2019-06-20 00:00:00	2019-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	19543W	TITULAIRE	\N	\N
15037	FONCTION	2019-06-20 00:00:00	2019-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	14053L	SUPPLEANT	\N	\N
15038	FONCTION	2019-06-20 00:00:00	2019-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	\N	\N
15039	FONCTION	2019-06-20 00:00:00	2019-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	19719D	SUPPLEANT	\N	\N
15040	FONCTION	2019-06-20 00:00:00	2019-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	SUPPLEANT	\N	\N
15041	FONCTION	2019-06-20 00:00:00	2019-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	19673G	SUPPLEANT	\N	\N
15042	FONCTION	2019-06-20 00:00:00	2019-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	14231L	SUPPLEANT	\N	\N
15043	FONCTION	2019-06-20 00:00:00	2019-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	SUPPLEANT	\N	\N
15044	OFBC	2019-05-22 00:00:00	2019-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	08009T	TITULAIRE	\N	\N
15045	OFBC	2019-05-22 00:00:00	2019-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	14103D	TITULAIRE	\N	\N
15046	OFBC	2019-05-22 00:00:00	2019-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	11103C	TITULAIRE	\N	\N
15047	OFBC	2019-05-22 00:00:00	2019-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	14329V	TITULAIRE	\N	\N
15048	OFBC	2019-05-22 00:00:00	2019-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	08055A	TITULAIRE	\N	\N
15049	OFBC	2019-05-22 00:00:00	2019-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	19333N	TITULAIRE	\N	\N
15050	OFBC	2019-05-22 00:00:00	2019-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	08061X	TITULAIRE	\N	\N
15051	OFBC	2019-05-22 00:00:00	2019-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	14038Y	SUPPLEANT	\N	\N
15052	OFBC	2019-05-22 00:00:00	2019-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	11080N	SUPPLEANT	\N	\N
15053	OFBC	2019-05-22 00:00:00	2019-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	18083K	SUPPLEANT	\N	\N
15054	OFBC	2019-05-22 00:00:00	2019-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	11065P	SUPPLEANT	\N	\N
15055	OFBC	2019-05-22 00:00:00	2019-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	19599P	SUPPLEANT	\N	\N
15056	OFBC	2019-05-22 00:00:00	2019-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	19347U	SUPPLEANT	\N	\N
15057	OFBC	2019-05-22 00:00:00	2019-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	17583W	SUPPLEANT	\N	\N
15079	NEANT	2019-06-24 00:00:00	2019-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	04069P	\N	\N	\N
15116	ALSACE	2019-07-02 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	14065Q	TITULAIRE	\N	\N
15117	ALSACE	2019-07-02 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	04045F	TITULAIRE	\N	\N
15118	ALSACE	2019-07-02 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	19629C	SUPPLEANT	\N	\N
15119	ALSACE	2019-07-02 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	\N	\N
15120	ALSACE	2019-07-02 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	SUPPLEANT	\N	\N
15121	ALSACE	2019-07-02 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	14179A	SUPPLEANT	\N	\N
15122	ALSACE	2019-07-02 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	14147R	SUPPLEANT	\N	\N
15123	ALSACE	2019-07-02 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	SUPPLEANT	\N	\N
15124	ALSACE	2019-07-02 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	19675J	SUPPLEANT	\N	\N
15202	BREXIT2	2017-11-08 00:00:00	2020-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	12041X	\N	\N	\N
15203	BIOETHIQUE	2019-10-16 00:00:00	2021-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	\N	\N	\N
15204	BIOETHIQUE	2019-10-16 00:00:00	2021-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	19575F	\N	\N	\N
15205	BIOETHIQUE	2019-10-16 00:00:00	2021-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	19415P	\N	\N	\N
15206	BIOETHIQUE	2019-10-16 00:00:00	2021-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	18083K	\N	\N	\N
15207	BIOETHIQUE	2019-10-16 00:00:00	2021-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	10006L	\N	\N	\N
15208	BIOETHIQUE	2019-10-16 00:00:00	2021-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	\N	\N	\N
15209	BIOETHIQUE	2019-10-16 00:00:00	2021-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	14217N	\N	\N	\N
15210	BIOETHIQUE	2019-10-16 00:00:00	2021-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	\N	\N	\N
15211	BIOETHIQUE	2019-10-16 00:00:00	2021-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	14213J	\N	\N	\N
15212	BIOETHIQUE	2019-10-16 00:00:00	2021-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	19447X	\N	\N	\N
15213	BIOETHIQUE	2019-10-16 00:00:00	2021-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	99004R	\N	\N	\N
15214	BIOETHIQUE	2019-10-16 00:00:00	2021-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	08034U	\N	\N	\N
15215	BIOETHIQUE	2019-10-16 00:00:00	2021-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	01048V	\N	\N	\N
15216	BIOETHIQUE	2019-10-16 00:00:00	2021-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	14147R	\N	\N	\N
15217	BIOETHIQUE	2019-10-16 00:00:00	2021-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	\N	\N	\N
15218	BIOETHIQUE	2019-10-16 00:00:00	2020-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	\N	\N	\N
15219	BIOETHIQUE	2019-10-16 00:00:00	2021-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	11031D	\N	\N	\N
15220	BIOETHIQUE	2019-10-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14065Q	\N	\N	\N
15221	BIOETHIQUE	2019-10-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08043V	\N	\N	\N
15222	BIOETHIQUE	2019-10-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	\N	\N	\N
15223	BIOETHIQUE	2019-10-16 00:00:00	2021-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	19649G	\N	\N	\N
15224	BIOETHIQUE	2019-10-16 00:00:00	2019-10-23 00:00:00	ANCIEN	\N	\N	\N	\N	19591F	\N	\N	\N
15225	BIOETHIQUE	2019-10-16 00:00:00	2021-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	19683J	\N	\N	\N
15226	BIOETHIQUE	2019-10-16 00:00:00	2021-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	11067R	\N	\N	\N
15227	BIOETHIQUE	2019-10-16 00:00:00	2021-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	11045K	\N	\N	\N
15228	BIOETHIQUE	2019-10-16 00:00:00	2020-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	19685L	\N	\N	\N
15229	BIOETHIQUE	2019-10-16 00:00:00	2021-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	19553Y	\N	\N	\N
15230	BIOETHIQUE	2019-10-16 00:00:00	2020-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	14239U	\N	\N	\N
15231	BIOETHIQUE	2019-10-16 00:00:00	2021-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	11072N	\N	\N	\N
14720	CDD	2019-01-15 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19794Q	\N	\N	\N
14747	SIDERURGIE	2019-01-30 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	19782L	\N	\N	\N
14748	SIDERURGIE	2019-01-30 00:00:00	2019-07-12 00:00:00	ANCIEN	\N	\N	\N	\N	19637C	\N	\N	\N
14765	LOIS	2019-03-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19675J	\N	\N	\N
14766	SOCI	2019-03-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19798U	\N	\N	\N
14836	SOUVERAINETE	2019-04-10 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	88008L	\N	\N	\N
14837	SOUVERAINETE	2019-04-10 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	19741B	\N	\N	\N
14838	SOUVERAINETE	2019-04-10 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	19415P	\N	\N	\N
14839	SOUVERAINETE	2019-04-10 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	14038Y	\N	\N	\N
14840	SOUVERAINETE	2019-04-10 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	08018U	\N	\N	\N
14841	SOUVERAINETE	2019-04-10 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	01048V	\N	\N	\N
14842	SOUVERAINETE	2019-04-10 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	19533U	\N	\N	\N
14843	SOUVERAINETE	2019-04-10 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	11090Q	\N	\N	\N
14844	SOUVERAINETE	2019-04-10 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	19679N	\N	\N	\N
14845	SOUVERAINETE	2019-04-10 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	19421M	\N	\N	\N
14846	SOUVERAINETE	2019-04-10 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	19593H	\N	\N	\N
14847	SOUVERAINETE	2019-04-10 00:00:00	2019-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	11083R	\N	\N	\N
14876	POLYNESIE2	2019-04-30 00:00:00	2019-05-08 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
14877	POLYNESIE2	2019-04-30 00:00:00	2019-05-08 00:00:00	ANCIEN	\N	\N	\N	\N	14259Y	TITULAIRE	\N	\N
14878	POLYNESIE2	2019-04-30 00:00:00	2019-05-08 00:00:00	ANCIEN	\N	\N	\N	\N	19447X	TITULAIRE	\N	\N
14879	POLYNESIE2	2019-04-30 00:00:00	2019-05-08 00:00:00	ANCIEN	\N	\N	\N	\N	14275Y	TITULAIRE	\N	\N
14880	POLYNESIE2	2019-04-30 00:00:00	2019-05-08 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
14881	POLYNESIE2	2019-04-30 00:00:00	2019-05-08 00:00:00	ANCIEN	\N	\N	\N	\N	14151M	TITULAIRE	\N	\N
14882	POLYNESIE2	2019-04-30 00:00:00	2019-05-08 00:00:00	ANCIEN	\N	\N	\N	\N	11072N	TITULAIRE	\N	\N
14883	POLYNESIE2	2019-04-30 00:00:00	2019-05-08 00:00:00	ANCIEN	\N	\N	\N	\N	11033F	SUPPLEANT	\N	\N
14884	POLYNESIE2	2019-04-30 00:00:00	2019-05-08 00:00:00	ANCIEN	\N	\N	\N	\N	19629C	SUPPLEANT	\N	\N
14885	POLYNESIE2	2019-04-30 00:00:00	2019-05-08 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	SUPPLEANT	\N	\N
14886	POLYNESIE2	2019-04-30 00:00:00	2019-05-08 00:00:00	ANCIEN	\N	\N	\N	\N	19673G	SUPPLEANT	\N	\N
14887	POLYNESIE2	2019-04-30 00:00:00	2019-05-08 00:00:00	ANCIEN	\N	\N	\N	\N	19691J	SUPPLEANT	\N	\N
14888	POLYNESIE2	2019-04-30 00:00:00	2019-05-08 00:00:00	ANCIEN	\N	\N	\N	\N	12016W	SUPPLEANT	\N	\N
14889	POLYNESIE2	2019-04-30 00:00:00	2019-05-08 00:00:00	ANCIEN	\N	\N	\N	\N	19762G	SUPPLEANT	\N	\N
15127	COMPTES2018	2019-07-11 00:00:00	2019-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	11074Q	TITULAIRE	\N	\N
15128	COMPTES2018	2019-07-11 00:00:00	2019-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	08011M	TITULAIRE	\N	\N
15129	COMPTES2018	2019-07-11 00:00:00	2019-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	19741B	TITULAIRE	\N	\N
15130	COMPTES2018	2019-07-11 00:00:00	2019-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	99004R	TITULAIRE	\N	\N
15131	COMPTES2018	2019-07-11 00:00:00	2019-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	11070L	TITULAIRE	\N	\N
15132	COMPTES2018	2019-07-11 00:00:00	2019-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	14085U	TITULAIRE	\N	\N
15133	COMPTES2018	2019-07-11 00:00:00	2019-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	19651A	TITULAIRE	\N	\N
15134	COMPTES2018	2019-07-11 00:00:00	2019-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	11040E	SUPPLEANT	\N	\N
15135	COMPTES2018	2019-07-11 00:00:00	2019-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	14083S	SUPPLEANT	\N	\N
15136	COMPTES2018	2019-07-11 00:00:00	2019-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	14121F	SUPPLEANT	\N	\N
15137	COMPTES2018	2019-07-11 00:00:00	2019-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	19711U	SUPPLEANT	\N	\N
15138	COMPTES2018	2019-07-11 00:00:00	2019-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	08034U	SUPPLEANT	\N	\N
15139	COMPTES2018	2019-07-11 00:00:00	2019-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	14331P	SUPPLEANT	\N	\N
15140	COMPTES2018	2019-07-11 00:00:00	2019-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	14225N	SUPPLEANT	\N	\N
15232	BIOETHIQUE	2019-10-16 00:00:00	2021-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	04045F	\N	\N	\N
15233	BIOETHIQUE	2019-10-16 00:00:00	2021-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	14195A	\N	\N	\N
15234	BIOETHIQUE	2019-10-16 00:00:00	2020-10-15 00:00:00	ANCIEN	\N	\N	\N	\N	19681G	\N	\N	\N
15235	BIOETHIQUE	2019-10-16 00:00:00	2021-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	14042U	\N	\N	\N
15243	LUBRIZOL	2019-10-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	04070G	\N	\N	\N
15237	BIOETHIQUE	2019-10-16 00:00:00	2021-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	19569H	\N	\N	\N
15238	BIOETHIQUE	2019-10-16 00:00:00	2021-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	14179A	\N	\N	\N
15239	BIOETHIQUE	2019-10-16 00:00:00	2020-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	11085T	\N	\N	\N
15240	BIOETHIQUE	2019-10-16 00:00:00	2021-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	19335Q	\N	\N	\N
15241	LUBRIZOL	\N	\N	ACTIF	\N	\N	\N	\N	08009T	\N	\N	\N
15242	LUBRIZOL	2019-10-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	19826F	\N	\N	\N
15244	LUBRIZOL	2019-10-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	08060W	\N	\N	\N
15245	LUBRIZOL	2019-10-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	19251M	\N	\N	\N
15246	LUBRIZOL	2019-10-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	19413M	\N	\N	\N
15247	LUBRIZOL	2019-10-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14051J	\N	\N	\N
15264	BIOETHIQUE	2019-10-23 00:00:00	2021-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	11066Q	\N	\N	\N
15263	LUBRIZOL	2019-10-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	08009T	\N	\N	\N
15286	PLFSS2020	2019-11-14 00:00:00	2019-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	TITULAIRE	\N	\N
15287	PLFSS2020	2019-11-14 00:00:00	2019-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	01034P	TITULAIRE	\N	\N
15288	PLFSS2020	2019-11-14 00:00:00	2019-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	10006L	TITULAIRE	\N	\N
15289	PLFSS2020	2019-11-14 00:00:00	2019-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	11097X	TITULAIRE	\N	\N
15290	PLFSS2020	2019-11-14 00:00:00	2019-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	TITULAIRE	\N	\N
15291	PLFSS2020	2019-11-14 00:00:00	2019-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	14281W	TITULAIRE	\N	\N
15292	PLFSS2020	2019-11-14 00:00:00	2019-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	19301E	TITULAIRE	\N	\N
15293	PLFSS2020	2019-11-14 00:00:00	2019-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	19415P	SUPPLEANT	\N	\N
15294	PLFSS2020	2019-11-14 00:00:00	2019-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	98024R	SUPPLEANT	\N	\N
15295	PLFSS2020	2019-11-14 00:00:00	2019-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	14213J	SUPPLEANT	\N	\N
15296	PLFSS2020	2019-11-14 00:00:00	2019-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	14042U	SUPPLEANT	\N	\N
15297	PLFSS2020	2019-11-14 00:00:00	2019-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	14227Q	SUPPLEANT	\N	\N
15298	PLFSS2020	2019-11-14 00:00:00	2019-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	14261S	SUPPLEANT	\N	\N
15299	PLFSS2020	2019-11-14 00:00:00	2019-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	11031D	SUPPLEANT	\N	\N
15349	PLF2020	2019-12-06 00:00:00	2019-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	19741B	SUPPLEANT	\N	\N
15350	PLF2020	2019-12-06 00:00:00	2019-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	SUPPLEANT	\N	\N
15351	PLF2020	2019-12-06 00:00:00	2019-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	19711U	SUPPLEANT	\N	\N
15352	PLF2020	2019-12-06 00:00:00	2019-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	11070L	SUPPLEANT	\N	\N
15353	PLF2020	2019-12-06 00:00:00	2019-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	14085U	SUPPLEANT	\N	\N
15354	PLF2020	2019-12-06 00:00:00	2019-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	14121F	SUPPLEANT	\N	\N
15355	PLF2020	2019-12-06 00:00:00	2019-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	11040E	SUPPLEANT	\N	\N
15373	GASPILLE	2019-12-18 00:00:00	2020-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	14038Y	TITULAIRE	\N	\N
15371	GASPILLE	2019-12-18 00:00:00	2020-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	08009T	TITULAIRE	\N	\N
15372	GASPILLE	2019-12-18 00:00:00	2020-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	19701S	TITULAIRE	\N	\N
15374	GASPILLE	2019-12-18 00:00:00	2020-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	14031R	TITULAIRE	\N	\N
15375	GASPILLE	2019-12-18 00:00:00	2020-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	19549D	TITULAIRE	\N	\N
15376	GASPILLE	2019-12-18 00:00:00	2020-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	19503N	TITULAIRE	\N	\N
15377	GASPILLE	2019-12-18 00:00:00	2020-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	19637C	TITULAIRE	\N	\N
15378	GASPILLE	2019-12-18 00:00:00	2020-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	18083K	SUPPLEANT	\N	\N
15379	GASPILLE	2019-12-18 00:00:00	2020-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	14169X	SUPPLEANT	\N	\N
15380	GASPILLE	2019-12-18 00:00:00	2020-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	19794Q	SUPPLEANT	\N	\N
15381	GASPILLE	2019-12-18 00:00:00	2020-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	14205J	SUPPLEANT	\N	\N
15382	GASPILLE	2019-12-18 00:00:00	2020-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	14051J	SUPPLEANT	\N	\N
15383	GASPILLE	2019-12-18 00:00:00	2020-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	19387D	SUPPLEANT	\N	\N
15384	GASPILLE	2019-12-18 00:00:00	2020-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	19347U	SUPPLEANT	\N	\N
15385	AUTOROUT	2020-01-29 00:00:00	2020-09-16 00:00:00	ANCIEN	\N	\N	\N	\N	19741B	\N	\N	\N
15386	AUTOROUT	2020-01-29 00:00:00	2020-09-16 00:00:00	ANCIEN	\N	\N	\N	\N	14069U	\N	\N	\N
15387	AUTOROUT	2020-01-29 00:00:00	2020-09-16 00:00:00	ANCIEN	\N	\N	\N	\N	14038Y	\N	\N	\N
15388	AUTOROUT	2020-01-29 00:00:00	2020-09-16 00:00:00	ANCIEN	\N	\N	\N	\N	87003B	\N	\N	\N
15389	AUTOROUT	2020-01-29 00:00:00	2020-09-16 00:00:00	ANCIEN	\N	\N	\N	\N	19399H	\N	\N	\N
15390	AUTOROUT	2020-01-29 00:00:00	2020-09-16 00:00:00	ANCIEN	\N	\N	\N	\N	15447F	\N	\N	\N
15391	AUTOROUT	2020-01-29 00:00:00	2020-09-16 00:00:00	ANCIEN	\N	\N	\N	\N	19711U	\N	\N	\N
15392	AUTOROUT	2020-01-29 00:00:00	2020-09-16 00:00:00	ANCIEN	\N	\N	\N	\N	08034U	\N	\N	\N
15393	AUTOROUT	2020-01-29 00:00:00	2020-09-16 00:00:00	ANCIEN	\N	\N	\N	\N	14169X	\N	\N	\N
15394	AUTOROUT	2020-01-29 00:00:00	2020-09-16 00:00:00	ANCIEN	\N	\N	\N	\N	19269X	\N	\N	\N
15395	AUTOROUT	2020-01-29 00:00:00	2020-09-16 00:00:00	ANCIEN	\N	\N	\N	\N	19543W	\N	\N	\N
15396	AUTOROUT	2020-01-29 00:00:00	2020-09-16 00:00:00	ANCIEN	\N	\N	\N	\N	80013X	\N	\N	\N
15397	AUTOROUT	2020-01-29 00:00:00	2020-09-16 00:00:00	ANCIEN	\N	\N	\N	\N	19525U	\N	\N	\N
15398	AUTOROUT	2020-01-29 00:00:00	2020-09-16 00:00:00	ANCIEN	\N	\N	\N	\N	19551W	\N	\N	\N
15399	AUTOROUT	2020-01-29 00:00:00	2020-09-16 00:00:00	ANCIEN	\N	\N	\N	\N	19531S	\N	\N	\N
15400	AUTOROUT	2020-01-29 00:00:00	2020-09-16 00:00:00	ANCIEN	\N	\N	\N	\N	11070L	\N	\N	\N
15401	AUTOROUT	2020-01-29 00:00:00	2020-09-16 00:00:00	ANCIEN	\N	\N	\N	\N	14205J	\N	\N	\N
15402	AUTOROUT	2020-01-29 00:00:00	2020-09-16 00:00:00	ANCIEN	\N	\N	\N	\N	19737F	\N	\N	\N
15403	AUTOROUT	2020-01-29 00:00:00	2020-09-16 00:00:00	ANCIEN	\N	\N	\N	\N	11040E	\N	\N	\N
15404	AUTOROUT	2020-01-29 00:00:00	2020-09-16 00:00:00	ANCIEN	\N	\N	\N	\N	02002K	\N	\N	\N
15405	AUTOROUT	2020-01-29 00:00:00	2020-02-03 00:00:00	ANCIEN	\N	\N	\N	\N	88008L	\N	\N	\N
15406	BREXIT2	2019-11-28 00:00:00	2020-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	14331P	\N	\N	\N
14522	RETRAIT	2018-10-10 00:00:00	2019-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	11040E	\N	\N	\N
14523	RETRAIT	2018-10-10 00:00:00	2019-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	12041X	\N	\N	\N
14527	ENTREPRISES	2018-10-10 00:00:00	2019-05-23 00:00:00	ANCIEN	\N	\N	\N	\N	19695N	\N	\N	\N
14525	SURTRANSPO	2018-10-10 00:00:00	2018-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	19347U	\N	\N	\N
14526	SURTRANSPO	2018-10-10 00:00:00	2018-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	19593H	\N	\N	\N
14528	ENTREPRISES	2018-10-10 00:00:00	2019-05-23 00:00:00	ANCIEN	\N	\N	\N	\N	19760E	\N	\N	\N
14529	RETRAIT	2018-10-10 00:00:00	2019-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	19569H	\N	\N	\N
14530	RETRAIT	2018-10-10 00:00:00	2019-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	14073Q	\N	\N	\N
14531	RETRAIT	2018-10-10 00:00:00	2019-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	14089Y	\N	\N	\N
14532	RETRAIT	2018-10-10 00:00:00	2019-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	14205J	\N	\N	\N
14533	RETRAIT	2018-10-10 00:00:00	2019-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	14221J	\N	\N	\N
14534	ENTREPRISES	2018-10-10 00:00:00	2019-05-23 00:00:00	ANCIEN	\N	\N	\N	\N	11053K	\N	\N	\N
14535	ENTREPRISES	2018-10-10 00:00:00	2019-05-23 00:00:00	ANCIEN	\N	\N	\N	\N	14083S	\N	\N	\N
14536	ENTREPRISES	2018-10-10 00:00:00	2019-05-23 00:00:00	ANCIEN	\N	\N	\N	\N	11070L	\N	\N	\N
14537	ENTREPRISES	2018-10-10 00:00:00	2019-05-23 00:00:00	ANCIEN	\N	\N	\N	\N	19521Q	\N	\N	\N
14538	ENTREPRISES	2018-10-10 00:00:00	2019-05-23 00:00:00	ANCIEN	\N	\N	\N	\N	19441R	\N	\N	\N
14542	SURTRANSPO	2018-10-10 00:00:00	2018-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	14255U	\N	\N	\N
14544	SURTRANSPO	2018-10-10 00:00:00	2018-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	19335Q	\N	\N	\N
14543	SURTRANSPO	2018-10-10 00:00:00	2018-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	04089T	\N	\N	\N
14545	SURTRANSPO	2018-10-10 00:00:00	2018-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	19739H	\N	\N	\N
14546	SURTRANSPO	2018-10-10 00:00:00	2018-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	19735D	\N	\N	\N
14721	SOCI	2019-01-24 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	19565D	\N	\N	\N
14961	NOTREDAME	2019-05-28 00:00:00	2019-06-05 00:00:00	ANCIEN	\N	\N	\N	\N	08039A	TITULAIRE	\N	\N
14959	NOTREDAME	2019-05-28 00:00:00	2019-06-05 00:00:00	ANCIEN	\N	\N	\N	\N	04018C	TITULAIRE	\N	\N
14960	NOTREDAME	2019-05-28 00:00:00	2019-06-05 00:00:00	ANCIEN	\N	\N	\N	\N	08011M	TITULAIRE	\N	\N
14962	NOTREDAME	2019-05-28 00:00:00	2019-06-05 00:00:00	ANCIEN	\N	\N	\N	\N	04070G	TITULAIRE	\N	\N
14963	NOTREDAME	2019-05-28 00:00:00	2019-06-05 00:00:00	ANCIEN	\N	\N	\N	\N	04059M	TITULAIRE	\N	\N
14964	NOTREDAME	2019-05-28 00:00:00	2019-06-05 00:00:00	ANCIEN	\N	\N	\N	\N	14229S	TITULAIRE	\N	\N
14965	NOTREDAME	2019-05-28 00:00:00	2019-06-05 00:00:00	ANCIEN	\N	\N	\N	\N	11083R	TITULAIRE	\N	\N
14966	NOTREDAME	2019-05-28 00:00:00	2019-06-05 00:00:00	ANCIEN	\N	\N	\N	\N	19593H	SUPPLEANT	\N	\N
14967	NOTREDAME	2019-05-28 00:00:00	2019-06-05 00:00:00	ANCIEN	\N	\N	\N	\N	14241N	SUPPLEANT	\N	\N
14968	NOTREDAME	2019-05-28 00:00:00	2019-06-05 00:00:00	ANCIEN	\N	\N	\N	\N	19399H	SUPPLEANT	\N	\N
15080	RADIO	2019-06-26 00:00:00	2019-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	11090Q	TITULAIRE	\N	\N
14970	NOTREDAME	2019-05-28 00:00:00	2019-06-05 00:00:00	ANCIEN	\N	\N	\N	\N	19573D	SUPPLEANT	\N	\N
14971	NOTREDAME	2019-05-28 00:00:00	2019-06-05 00:00:00	ANCIEN	\N	\N	\N	\N	19749K	SUPPLEANT	\N	\N
14972	NOTREDAME	2019-05-28 00:00:00	2019-06-05 00:00:00	ANCIEN	\N	\N	\N	\N	14109K	SUPPLEANT	\N	\N
14973	NOTREDAME	2019-05-28 00:00:00	2019-06-05 00:00:00	ANCIEN	\N	\N	\N	\N	11043H	SUPPLEANT	\N	\N
15081	RADIO	2019-06-26 00:00:00	2019-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	04043D	TITULAIRE	\N	\N
15082	RADIO	2019-06-26 00:00:00	2019-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	14133K	TITULAIRE	\N	\N
15083	RADIO	2019-06-26 00:00:00	2019-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	14205J	TITULAIRE	\N	\N
15084	RADIO	2019-06-26 00:00:00	2019-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	19631V	TITULAIRE	\N	\N
15085	RADIO	2019-06-26 00:00:00	2019-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	08053X	TITULAIRE	\N	\N
15086	RADIO	2019-06-26 00:00:00	2019-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	19269X	TITULAIRE	\N	\N
15087	RADIO	2019-06-26 00:00:00	2019-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	14038Y	SUPPLEANT	\N	\N
15088	RADIO	2019-06-26 00:00:00	2019-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	14267Y	SUPPLEANT	\N	\N
15089	RADIO	2019-06-26 00:00:00	2019-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	88008L	SUPPLEANT	\N	\N
15090	RADIO	2019-06-26 00:00:00	2019-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	19695N	SUPPLEANT	\N	\N
15091	RADIO	2019-06-26 00:00:00	2019-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	14257W	SUPPLEANT	\N	\N
15092	RADIO	2019-06-26 00:00:00	2019-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	14265W	SUPPLEANT	\N	\N
15093	RADIO	2019-06-26 00:00:00	2019-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	19768N	SUPPLEANT	\N	\N
15125	CAE	2019-07-11 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19812Y	\N	\N	\N
15126	AFEU	2019-07-11 00:00:00	2020-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14191V	\N	\N	\N
15201	CDD	2019-10-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19826F	\N	\N	\N
15248	LUBRIZOL	2019-10-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	19758L	\N	\N	\N
15249	LUBRIZOL	2019-10-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14093U	\N	\N	\N
15250	LUBRIZOL	2019-10-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	11065P	\N	\N	\N
15251	LUBRIZOL	2019-10-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	19367Y	\N	\N	\N
15252	LUBRIZOL	2019-10-16 00:00:00	2020-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	19733B	\N	\N	\N
15253	LUBRIZOL	2019-10-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	14053L	\N	\N	\N
15254	LUBRIZOL	2019-10-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14079W	\N	\N	\N
15255	LUBRIZOL	2019-10-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	14033T	\N	\N	\N
15256	LUBRIZOL	2019-10-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	14026U	\N	\N	\N
15257	LUBRIZOL	2019-10-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	11048N	\N	\N	\N
15258	LUBRIZOL	2019-10-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	19581D	\N	\N	\N
15259	LUBRIZOL	2019-10-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	\N	\N	\N
15260	LUBRIZOL	2019-10-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08024S	\N	\N	\N
15261	LUBRIZOL	2019-10-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	19637C	\N	\N	\N
15314	FAMILLE	2019-11-21 00:00:00	2019-11-28 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
15315	FAMILLE	2019-11-21 00:00:00	2019-11-28 00:00:00	ANCIEN	\N	\N	\N	\N	14147R	TITULAIRE	\N	\N
15316	FAMILLE	2019-11-21 00:00:00	2019-11-28 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	TITULAIRE	\N	\N
15317	FAMILLE	2019-11-21 00:00:00	2019-11-28 00:00:00	ANCIEN	\N	\N	\N	\N	14030Q	TITULAIRE	\N	\N
15318	FAMILLE	2019-11-21 00:00:00	2019-11-28 00:00:00	ANCIEN	\N	\N	\N	\N	19649G	TITULAIRE	\N	\N
15319	FAMILLE	2019-11-21 00:00:00	2019-11-28 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
15320	FAMILLE	2019-11-21 00:00:00	2019-11-28 00:00:00	ANCIEN	\N	\N	\N	\N	08024S	TITULAIRE	\N	\N
15321	FAMILLE	2019-11-21 00:00:00	2019-11-28 00:00:00	ANCIEN	\N	\N	\N	\N	19447X	SUPPLEANT	\N	\N
15322	FAMILLE	2019-11-21 00:00:00	2019-11-28 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	SUPPLEANT	\N	\N
15323	FAMILLE	2019-11-21 00:00:00	2019-11-28 00:00:00	ANCIEN	\N	\N	\N	\N	19673G	SUPPLEANT	\N	\N
15324	FAMILLE	2019-11-21 00:00:00	2019-11-28 00:00:00	ANCIEN	\N	\N	\N	\N	14179A	SUPPLEANT	\N	\N
15325	FAMILLE	2019-11-21 00:00:00	2019-11-28 00:00:00	ANCIEN	\N	\N	\N	\N	11045K	SUPPLEANT	\N	\N
15326	FAMILLE	2019-11-21 00:00:00	2019-11-28 00:00:00	ANCIEN	\N	\N	\N	\N	11033F	SUPPLEANT	\N	\N
15327	FAMILLE	2019-11-21 00:00:00	2019-11-28 00:00:00	ANCIEN	\N	\N	\N	\N	19253P	SUPPLEANT	\N	\N
15356	HAINE	2019-12-18 00:00:00	2020-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
15357	HAINE	2019-12-18 00:00:00	2020-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	08018U	TITULAIRE	\N	\N
15358	HAINE	2019-12-18 00:00:00	2020-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	TITULAIRE	\N	\N
15359	HAINE	2019-12-18 00:00:00	2020-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	14089Y	TITULAIRE	\N	\N
15360	HAINE	2019-12-18 00:00:00	2020-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	04059M	TITULAIRE	\N	\N
15361	HAINE	2019-12-18 00:00:00	2020-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	19649G	TITULAIRE	\N	\N
15362	HAINE	2019-12-18 00:00:00	2020-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	11072N	TITULAIRE	\N	\N
15363	HAINE	2019-12-18 00:00:00	2020-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	14053L	SUPPLEANT	\N	\N
15364	HAINE	2019-12-18 00:00:00	2020-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	19673G	SUPPLEANT	\N	\N
15365	HAINE	2019-12-18 00:00:00	2020-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	14147R	SUPPLEANT	\N	\N
15366	HAINE	2019-12-18 00:00:00	2020-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	11085T	SUPPLEANT	\N	\N
15367	HAINE	2019-12-18 00:00:00	2020-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	14257W	SUPPLEANT	\N	\N
15368	HAINE	2019-12-18 00:00:00	2020-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	19629C	SUPPLEANT	\N	\N
15369	HAINE	2019-12-18 00:00:00	2020-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	19593H	SUPPLEANT	\N	\N
15407	PJLO13	2020-01-28 00:00:00	2020-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
15408	PJLO13	2020-01-28 00:00:00	2020-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	01024M	TITULAIRE	\N	\N
15409	PJLO13	2020-01-28 00:00:00	2020-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	TITULAIRE	\N	\N
15410	PJLO13	2020-01-28 00:00:00	2020-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	14031R	TITULAIRE	\N	\N
15411	PJLO13	2020-01-28 00:00:00	2020-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	11026G	TITULAIRE	\N	\N
15412	PJLO13	2020-01-28 00:00:00	2020-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
15413	PJLO13	2020-01-28 00:00:00	2020-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	19543W	TITULAIRE	\N	\N
15414	PJLO13	2020-01-28 00:00:00	2020-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	14053L	SUPPLEANT	\N	\N
15415	PJLO13	2020-01-28 00:00:00	2020-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	19673G	SUPPLEANT	\N	\N
15416	PJLO13	2020-01-28 00:00:00	2020-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	19675J	SUPPLEANT	\N	\N
15417	PJLO13	2020-01-28 00:00:00	2020-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	14089Y	SUPPLEANT	\N	\N
15418	PJLO13	2020-01-28 00:00:00	2020-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	19489J	SUPPLEANT	\N	\N
15419	PJLO13	2020-01-28 00:00:00	2020-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	19629C	SUPPLEANT	\N	\N
15420	PJLO13	2020-01-28 00:00:00	2020-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	SUPPLEANT	\N	\N
15421	HADOPI	2020-01-28 00:00:00	2020-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
15422	HADOPI	2020-01-28 00:00:00	2020-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	01024M	TITULAIRE	\N	\N
15423	HADOPI	2020-01-28 00:00:00	2020-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	TITULAIRE	\N	\N
15424	HADOPI	2020-01-28 00:00:00	2020-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	14031R	TITULAIRE	\N	\N
15425	HADOPI	2020-01-28 00:00:00	2020-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	11026G	TITULAIRE	\N	\N
15426	HADOPI	2020-01-28 00:00:00	2020-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
15427	HADOPI	2020-01-28 00:00:00	2020-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	19543W	TITULAIRE	\N	\N
15428	HADOPI	2020-01-28 00:00:00	2020-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	14053L	SUPPLEANT	\N	\N
15429	HADOPI	2020-01-28 00:00:00	2020-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	19673G	SUPPLEANT	\N	\N
15430	HADOPI	2020-01-28 00:00:00	2020-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	19675J	SUPPLEANT	\N	\N
15431	HADOPI	2020-01-28 00:00:00	2020-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	14089Y	SUPPLEANT	\N	\N
15432	HADOPI	2020-01-28 00:00:00	2020-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	19489J	SUPPLEANT	\N	\N
15569	GUYANE	2020-05-13 00:00:00	2020-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	\N	\N	\N
15570	GUYANE	2020-05-13 00:00:00	2020-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	14259Y	\N	\N	\N
15571	GUYANE	2020-05-13 00:00:00	2020-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	14217N	\N	\N	\N
15572	GUYANE	2020-05-13 00:00:00	2020-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	04035D	\N	\N	\N
15573	GUYANE	2020-05-13 00:00:00	2020-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	19447X	\N	\N	\N
15574	GUYANE	2020-05-13 00:00:00	2020-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	19729F	\N	\N	\N
15575	GUYANE	2020-05-13 00:00:00	2020-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	14059S	\N	\N	\N
15576	GUYANE	2020-05-13 00:00:00	2020-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	19675J	\N	\N	\N
15577	GUYANE	2020-05-13 00:00:00	2020-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	\N	\N	\N
15578	GUYANE	2020-05-13 00:00:00	2020-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	14267Y	\N	\N	\N
15579	GUYANE	2020-05-13 00:00:00	2020-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	16685X	\N	\N	\N
15580	GUYANE	2020-05-13 00:00:00	2020-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	19826F	\N	\N	\N
15581	GUYANE	2020-05-13 00:00:00	2020-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	19295A	\N	\N	\N
15582	GUYANE	2020-05-13 00:00:00	2020-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	19525U	\N	\N	\N
15583	GUYANE	2020-05-13 00:00:00	2020-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	08045X	\N	\N	\N
15584	GUYANE	2020-05-13 00:00:00	2020-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	19715Y	\N	\N	\N
15585	GUYANE	2020-05-13 00:00:00	2020-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	11026G	\N	\N	\N
15586	GUYANE	2020-05-13 00:00:00	2020-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	14039A	\N	\N	\N
15587	GUYANE	2020-05-13 00:00:00	2020-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	08073C	\N	\N	\N
15588	GUYANE	2020-05-13 00:00:00	2020-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	14261S	\N	\N	\N
15589	GUYANE	2020-05-13 00:00:00	2020-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	19629C	\N	\N	\N
15590	GUYANE	2020-05-13 00:00:00	2020-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	19695N	\N	\N	\N
15591	GUYANE	2020-05-13 00:00:00	2020-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	11064N	\N	\N	\N
15873	AFCL	2020-08-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19968U	\N	\N	\N
15874	SOCI	2020-08-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19958S	\N	\N	\N
15875	LOIS	2020-08-09 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	19966S	\N	\N	\N
19022	DDADUE23	2023-11-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	14189C	\N	\N	\N
19023	DDADUE23	2023-11-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	21084L	\N	\N	\N
19024	DDADUE23	2023-11-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	20022R	\N	\N	\N
19025	DDADUE23	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	19575F	\N	\N	\N
19026	DDADUE23	2023-11-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	20086J	\N	\N	\N
19027	DDADUE23	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	20094J	\N	\N	\N
19028	DDADUE23	2023-11-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	20114U	\N	\N	\N
19029	DDADUE23	2023-11-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	21052C	\N	\N	\N
19030	DDADUE23	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	11053K	\N	\N	\N
19031	DDADUE23	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	21057H	\N	\N	\N
19032	DDADUE23	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	11065P	\N	\N	\N
19033	DDADUE23	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	19251M	\N	\N	\N
19034	DDADUE23	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	19507S	\N	\N	\N
19035	DDADUE23	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	21086N	\N	\N	\N
19036	DDADUE23	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	08018U	\N	\N	\N
19037	DDADUE23	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	20286Q	\N	\N	\N
19038	DDADUE23	2023-11-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	21032X	\N	\N	\N
19039	DDADUE23	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	20180F	\N	\N	\N
19040	DDADUE23	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	21066J	\N	\N	\N
19041	DDADUE23	2023-11-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	14026U	\N	\N	\N
19042	DDADUE23	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	20106U	\N	\N	\N
19043	DDADUE23	2023-11-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	21093M	\N	\N	\N
19044	DDADUE23	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	21044C	\N	\N	\N
19045	DDADUE23	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	20126Y	\N	\N	\N
19046	DDADUE23	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	19711U	\N	\N	\N
19047	DDADUE23	2023-11-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	18207D	\N	\N	\N
19048	DDADUE23	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	14219Q	\N	\N	\N
19049	DDADUE23	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	14031R	\N	\N	\N
19050	DDADUE23	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	14001X	\N	\N	\N
19051	DDADUE23	2023-11-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	19826F	\N	\N	\N
19052	DDADUE23	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	04092N	\N	\N	\N
19053	DDADUE23	2023-11-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	11072N	\N	\N	\N
19054	DDADUE23	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	14237S	\N	\N	\N
19055	DDADUE23	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	21049H	\N	\N	\N
19056	DDADUE23	2023-11-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	20084G	\N	\N	\N
19057	DDADUE23	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	21076L	\N	\N	\N
19510	AGE	2024-03-12 00:00:00	2024-03-13 00:00:00	ANCIEN	\N	\N	\N	\N	21097R	TITULAIRE	\N	\N
16887	AFCL	2021-05-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20016T	\N	\N	\N
16888	ETRD	2021-05-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08061X	\N	\N	\N
16889	LOIS	2021-05-25 00:00:00	2022-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	20128B	\N	\N	\N
19058	PARTAGE	2023-11-15 00:00:00	2023-11-15 00:00:00	ANCIEN	\N	\N	\N	\N	14071N	TITULAIRE	\N	\N
19059	PARTAGE	2023-11-15 00:00:00	2023-11-15 00:00:00	ANCIEN	\N	\N	\N	\N	19679N	TITULAIRE	\N	\N
19060	PARTAGE	2023-11-15 00:00:00	2023-11-15 00:00:00	ANCIEN	\N	\N	\N	\N	20090E	TITULAIRE	\N	\N
19061	PARTAGE	2023-11-15 00:00:00	2023-11-15 00:00:00	ANCIEN	\N	\N	\N	\N	19569H	TITULAIRE	\N	\N
19062	PARTAGE	2023-11-15 00:00:00	2023-11-15 00:00:00	ANCIEN	\N	\N	\N	\N	17779H	TITULAIRE	\N	\N
19063	PARTAGE	2023-11-15 00:00:00	2023-11-15 00:00:00	ANCIEN	\N	\N	\N	\N	14281W	TITULAIRE	\N	\N
19064	PARTAGE	2023-11-15 00:00:00	2023-11-15 00:00:00	ANCIEN	\N	\N	\N	\N	19591F	TITULAIRE	\N	\N
19065	PARTAGE	2023-11-15 00:00:00	2023-11-15 00:00:00	ANCIEN	\N	\N	\N	\N	14026U	SUPPLEANT	\N	\N
19066	PARTAGE	2023-11-15 00:00:00	2023-11-15 00:00:00	ANCIEN	\N	\N	\N	\N	14217N	SUPPLEANT	\N	\N
19067	PARTAGE	2023-11-15 00:00:00	2023-11-15 00:00:00	ANCIEN	\N	\N	\N	\N	20248J	SUPPLEANT	\N	\N
19068	PARTAGE	2023-11-15 00:00:00	2023-11-15 00:00:00	ANCIEN	\N	\N	\N	\N	11045K	SUPPLEANT	\N	\N
19069	PARTAGE	2023-11-15 00:00:00	2023-11-15 00:00:00	ANCIEN	\N	\N	\N	\N	19760E	SUPPLEANT	\N	\N
19070	PARTAGE	2023-11-15 00:00:00	2023-11-15 00:00:00	ANCIEN	\N	\N	\N	\N	21046E	SUPPLEANT	\N	\N
19071	PARTAGE	2023-11-15 00:00:00	2023-11-15 00:00:00	ANCIEN	\N	\N	\N	\N	20130U	SUPPLEANT	\N	\N
16207	NEANT	2020-11-01 00:00:00	2020-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	20172F	\N	\N	\N
16383	AFEU	2021-02-09 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19563B	\N	\N	\N
19570	ASSO	2024-03-22 00:00:00	2024-03-28 00:00:00	ANCIEN	\N	\N	\N	\N	20180F	SUPPLEANT	\N	\N
19571	ASSO	2024-03-22 00:00:00	2024-03-28 00:00:00	ANCIEN	\N	\N	\N	\N	21091K	SUPPLEANT	\N	\N
19572	ASSO	2024-03-22 00:00:00	2024-03-28 00:00:00	ANCIEN	\N	\N	\N	\N	20052X	SUPPLEANT	\N	\N
19573	ASSO	2024-03-22 00:00:00	2024-03-28 00:00:00	ANCIEN	\N	\N	\N	\N	18395Y	SUPPLEANT	\N	\N
19574	ASSO	2024-03-22 00:00:00	2024-03-28 00:00:00	ANCIEN	\N	\N	\N	\N	20102Q	SUPPLEANT	\N	\N
19575	ASSO	2024-03-22 00:00:00	2024-03-28 00:00:00	ANCIEN	\N	\N	\N	\N	19693L	SUPPLEANT	\N	\N
19576	ASSO	2024-03-22 00:00:00	2024-03-28 00:00:00	ANCIEN	\N	\N	\N	\N	21037D	SUPPLEANT	\N	\N
19577	ASSO	2024-03-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	19611R	TITULAIRE	\N	\N
19578	ASSO	2024-03-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	20264J	TITULAIRE	\N	\N
19579	ASSO	2024-03-22 00:00:00	2024-03-28 00:00:00	ANCIEN	\N	\N	\N	\N	19954N	TITULAIRE	\N	\N
19580	ASSO	2024-03-22 00:00:00	2024-03-28 00:00:00	ANCIEN	\N	\N	\N	\N	20026V	TITULAIRE	\N	\N
19586	CIVI	2024-03-22 00:00:00	2024-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	SUPPLEANT	\N	\N
19582	ASSO	2024-03-22 00:00:00	2024-03-28 00:00:00	ANCIEN	\N	\N	\N	\N	20058E	TITULAIRE	\N	\N
19583	ASSO	2024-03-22 00:00:00	2024-03-28 00:00:00	ANCIEN	\N	\N	\N	\N	14109K	TITULAIRE	\N	\N
19584	ASSO	2024-03-22 00:00:00	2024-03-28 00:00:00	ANCIEN	\N	\N	\N	\N	19697Q	TITULAIRE	\N	\N
19585	CIVI	2024-03-22 00:00:00	2024-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	20098N	SUPPLEANT	\N	\N
19587	CIVI	2024-03-22 00:00:00	2024-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	14089Y	SUPPLEANT	\N	\N
19588	CIVI	2024-03-22 00:00:00	2024-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	20114U	SUPPLEANT	\N	\N
19589	CIVI	2024-03-22 00:00:00	2024-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	21088Q	SUPPLEANT	\N	\N
19590	CIVI	2024-03-22 00:00:00	2024-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	14111D	SUPPLEANT	\N	\N
19591	CIVI	2024-03-22 00:00:00	2024-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	20110Q	SUPPLEANT	\N	\N
19592	CIVI	2024-03-22 00:00:00	2024-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
19593	CIVI	2024-03-22 00:00:00	2024-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	14231L	TITULAIRE	\N	\N
19594	CIVI	2024-03-22 00:00:00	2024-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	20022R	TITULAIRE	\N	\N
19595	CIVI	2024-03-22 00:00:00	2024-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	20074E	TITULAIRE	\N	\N
19596	CIVI	2024-03-22 00:00:00	2024-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	18207D	TITULAIRE	\N	\N
19597	CIVI	2024-03-22 00:00:00	2024-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	21057H	TITULAIRE	\N	\N
19598	CIVI	2024-03-22 00:00:00	2024-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	21043B	TITULAIRE	\N	\N
15887	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20034V	\N	\N	\N
8944	2012CMP17	2012-10-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08019V	TITULAIRE	\N	\N
16146	CMPASAP	2020-10-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	14219Q	TITULAIRE	\N	\N
16147	CMPASAP	2020-10-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	14033T	TITULAIRE	\N	\N
16148	CMPASAP	2020-10-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	19747H	TITULAIRE	\N	\N
16149	CMPASAP	2020-10-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	19711U	TITULAIRE	\N	\N
16150	CMPASAP	2020-10-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	19631V	TITULAIRE	\N	\N
16151	CMPASAP	2020-10-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
16152	CMPASAP	2020-10-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	19349W	TITULAIRE	\N	\N
16153	CMPASAP	2020-10-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	19399H	SUPPLEANT	\N	\N
16154	CMPASAP	2020-10-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	19701S	SUPPLEANT	\N	\N
16155	CMPASAP	2020-10-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	14215L	SUPPLEANT	\N	\N
16156	CMPASAP	2020-10-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	14229S	SUPPLEANT	\N	\N
16157	CMPASAP	2020-10-21 00:00:00	2021-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	19521Q	SUPPLEANT	\N	\N
16158	CMPASAP	2020-10-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	19629C	SUPPLEANT	\N	\N
16159	CMPASAP	2020-10-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	11056N	SUPPLEANT	\N	\N
17231	AVENCOMM	2023-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	14189C	\N	\N	\N
17232	AVENCOMM	2023-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	19954N	\N	\N	\N
17233	AVENCOMM	2023-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	20110Q	\N	\N	\N
17234	AVENCOMM	2023-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	19383Y	\N	\N	\N
17235	AVENCOMM	2023-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	19629C	\N	\N	\N
17236	AVENCOMM	2023-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	14329V	\N	\N	\N
17237	AVENCOMM	2023-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	19467C	\N	\N	\N
17238	AVENCOMM	2023-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	11056N	\N	\N	\N
17239	AVENCOMM	2023-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	14259Y	\N	\N	\N
17240	AVENCOMM	2023-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	20248J	\N	\N	\N
17241	AVENCOMM	2023-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	11110B	\N	\N	\N
17242	AVENCOMM	2023-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	01025N	\N	\N	\N
17243	AVENCOMM	2023-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	20172F	\N	\N	\N
17244	AVENCOMM	2023-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	11064N	\N	\N	\N
17245	AVENCOMM	2023-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	19489J	\N	\N	\N
17246	AVENCOMM	2023-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	14001X	\N	\N	\N
17247	AVENCOMM	2023-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	08073C	\N	\N	\N
17248	AVENCOMM	2023-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	14331P	\N	\N	\N
17249	AVENCOMM	2023-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	20082E	\N	\N	\N
17250	AVENCOMM	2023-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	19421M	\N	\N	\N
17251	AVENCOMM	2023-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	19703U	\N	\N	\N
19684	ARTI	2024-03-07 00:00:00	2024-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	14187A	SUPPLEANT	\N	\N
19685	ARTI	2024-03-07 00:00:00	2024-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	20136B	SUPPLEANT	\N	\N
19686	ARTI	2024-03-07 00:00:00	2024-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	19619A	SUPPLEANT	\N	\N
19687	ARTI	2024-03-07 00:00:00	2024-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	14257W	SUPPLEANT	\N	\N
19688	ARTI	2024-03-07 00:00:00	2024-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	19695N	SUPPLEANT	\N	\N
19689	ARTI	2024-03-07 00:00:00	2024-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	21070E	SUPPLEANT	\N	\N
19690	ARTI	2024-03-07 00:00:00	2024-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	11065P	SUPPLEANT	\N	\N
19691	ARTI	2024-03-07 00:00:00	2024-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	14219Q	TITULAIRE	\N	\N
19692	ARTI	2024-03-07 00:00:00	2024-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	19826F	TITULAIRE	\N	\N
19693	ARTI	2024-03-07 00:00:00	2024-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	14038Y	TITULAIRE	\N	\N
19694	ARTI	2024-03-07 00:00:00	2024-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	14031R	TITULAIRE	\N	\N
19695	ARTI	2024-03-07 00:00:00	2024-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	19251M	TITULAIRE	\N	\N
19696	ARTI	2024-03-07 00:00:00	2024-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	21062E	TITULAIRE	\N	\N
19697	ARTI	2024-03-07 00:00:00	2024-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	20106U	TITULAIRE	\N	\N
17939	EMPLOI	2022-11-09 00:00:00	2022-11-10 00:00:00	ANCIEN	\N	\N	\N	\N	10006L	TITULAIRE	\N	\N
17918	PLFR22	2022-11-22 00:00:00	2022-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	19711U	SUPPLEANT	\N	\N
17926	PLFR22	2022-11-22 00:00:00	2022-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	TITULAIRE	\N	\N
17906	OPMI	2022-12-01 00:00:00	2022-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	14053L	SUPPLEANT	\N	\N
17915	OPMI	2022-12-01 00:00:00	2022-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	14151M	TITULAIRE	\N	\N
17273	MEDIC	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20096L	\N	\N	\N
15634	SANITAIRE	2020-05-04 00:00:00	2020-05-10 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
15635	SANITAIRE	2020-05-04 00:00:00	2020-05-10 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
15636	SANITAIRE	2020-05-04 00:00:00	2020-05-10 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	TITULAIRE	\N	\N
15637	SANITAIRE	2020-05-04 00:00:00	2020-05-10 00:00:00	ANCIEN	\N	\N	\N	\N	14089Y	TITULAIRE	\N	\N
15638	SANITAIRE	2020-05-04 00:00:00	2020-05-10 00:00:00	ANCIEN	\N	\N	\N	\N	11045K	TITULAIRE	\N	\N
15639	SANITAIRE	2020-05-04 00:00:00	2020-05-10 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
15640	SANITAIRE	2020-05-04 00:00:00	2020-05-10 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	TITULAIRE	\N	\N
15641	SANITAIRE	2020-05-04 00:00:00	2020-05-10 00:00:00	ANCIEN	\N	\N	\N	\N	14259Y	SUPPLEANT	\N	\N
15642	SANITAIRE	2020-05-04 00:00:00	2020-05-10 00:00:00	ANCIEN	\N	\N	\N	\N	19673G	SUPPLEANT	\N	\N
15643	SANITAIRE	2020-05-04 00:00:00	2020-05-10 00:00:00	ANCIEN	\N	\N	\N	\N	19762G	SUPPLEANT	\N	\N
15644	SANITAIRE	2020-05-04 00:00:00	2020-05-10 00:00:00	ANCIEN	\N	\N	\N	\N	11085T	SUPPLEANT	\N	\N
15645	SANITAIRE	2020-05-04 00:00:00	2020-05-10 00:00:00	ANCIEN	\N	\N	\N	\N	08045X	SUPPLEANT	\N	\N
15646	SANITAIRE	2020-05-04 00:00:00	2020-05-10 00:00:00	ANCIEN	\N	\N	\N	\N	19629C	SUPPLEANT	\N	\N
15647	SANITAIRE	2020-05-04 00:00:00	2020-05-10 00:00:00	ANCIEN	\N	\N	\N	\N	11033F	SUPPLEANT	\N	\N
15806	APPROBATION	2020-07-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	11074Q	TITULAIRE	\N	\N
15807	APPROBATION	2020-07-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	08011M	TITULAIRE	\N	\N
15808	APPROBATION	2020-07-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	99004R	TITULAIRE	\N	\N
15809	APPROBATION	2020-07-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	19711U	TITULAIRE	\N	\N
15810	APPROBATION	2020-07-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	11053K	TITULAIRE	\N	\N
15811	APPROBATION	2020-07-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14085U	TITULAIRE	\N	\N
15812	APPROBATION	2020-07-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	19349W	TITULAIRE	\N	\N
15813	APPROBATION	2020-07-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	19741B	SUPPLEANT	\N	\N
15814	APPROBATION	2020-07-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	19671E	SUPPLEANT	\N	\N
15815	APPROBATION	2020-07-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	14331P	SUPPLEANT	\N	\N
15816	APPROBATION	2020-07-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	11070L	SUPPLEANT	\N	\N
15817	APPROBATION	2020-07-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	19647E	SUPPLEANT	\N	\N
15818	APPROBATION	2020-07-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	11012A	SUPPLEANT	\N	\N
15819	APPROBATION	2020-07-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	11040E	SUPPLEANT	\N	\N
17274	BIOCARBU	2023-02-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	19762G	\N	\N	\N
17317	CINC	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20076G	\N	\N	\N
17318	CINC	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20024T	\N	\N	\N
17319	CINC	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20094J	\N	\N	\N
17320	CINC	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20114U	\N	\N	\N
17321	CINC	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19782L	\N	\N	\N
17322	CINC	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20090E	\N	\N	\N
17323	CINC	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19721W	\N	\N	\N
17324	CINC	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19701S	\N	\N	\N
17325	CINC	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	14267Y	\N	\N	\N
17326	CINC	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19719D	\N	\N	\N
17327	CINC	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20140W	\N	\N	\N
17328	CINC	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20248J	\N	\N	\N
17329	CINC	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20074E	\N	\N	\N
17330	CINC	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	08045X	\N	\N	\N
17334	CINC	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	14033T	\N	\N	\N
17332	CINC	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19695N	\N	\N	\N
17333	CINC	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19820Y	\N	\N	\N
17335	CINC	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20072C	\N	\N	\N
17336	CINC	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19725B	\N	\N	\N
17337	CINC	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20106U	\N	\N	\N
17338	CINC	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20056C	\N	\N	\N
17339	CINC	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	14097Y	\N	\N	\N
17340	CINC	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19723Y	\N	\N	\N
17341	CINC	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	16685X	\N	\N	\N
17342	CINC	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	14205J	\N	\N	\N
17343	CINC	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20142Y	\N	\N	\N
17344	CINC	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19826F	\N	\N	\N
17345	CINC	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20096L	\N	\N	\N
17346	CINC	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20050V	\N	\N	\N
17347	CINC	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20118Y	\N	\N	\N
17348	CINC	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19503N	\N	\N	\N
17349	CINC	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19798U	\N	\N	\N
17350	CINC	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20054A	\N	\N	\N
17351	CINC	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	04045F	\N	\N	\N
17352	CINC	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20026V	\N	\N	\N
17353	CINC	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20046A	\N	\N	\N
17354	CINC	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	14173T	\N	\N	\N
17355	CZAN	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20032T	\N	\N	\N
17359	CZAN	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19549D	\N	\N	\N
17357	CZAN	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19631V	\N	\N	\N
17358	CZAN	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	05008E	\N	\N	\N
17360	CZAN	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20086J	\N	\N	\N
17361	CZAN	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	14069U	\N	\N	\N
17362	CZAN	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19383Y	\N	\N	\N
17363	CZAN	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19545Y	\N	\N	\N
17364	CZAN	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	11056N	\N	\N	\N
17365	CZAN	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19525U	\N	\N	\N
17366	CZAN	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	11065P	\N	\N	\N
17367	CZAN	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	11110B	\N	\N	\N
17368	CZAN	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	14231L	\N	\N	\N
17369	CZAN	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20120S	\N	\N	\N
17370	CZAN	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19387D	\N	\N	\N
17371	CZAN	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20068G	\N	\N	\N
17372	CZAN	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	11064N	\N	\N	\N
17373	CZAN	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19399H	\N	\N	\N
17374	CZAN	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19531S	\N	\N	\N
17375	CZAN	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19489J	\N	\N	\N
17376	CZAN	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19735D	\N	\N	\N
17377	CZAN	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20108W	\N	\N	\N
17378	CZAN	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	01043Q	\N	\N	\N
17379	CZAN	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	14205J	\N	\N	\N
17380	CZAN	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	14219Q	\N	\N	\N
17381	CZAN	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19637C	\N	\N	\N
17382	CZAN	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19573D	\N	\N	\N
17383	CZAN	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	17637T	\N	\N	\N
17384	CZAN	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19503N	\N	\N	\N
17385	CZAN	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20298U	\N	\N	\N
17386	CZAN	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19349W	\N	\N	\N
17387	CZAN	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20082E	\N	\N	\N
17388	CZAN	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20020P	\N	\N	\N
17389	CZAN	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20044X	\N	\N	\N
17390	CZAN	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20098N	\N	\N	\N
17391	CZAN	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20046A	\N	\N	\N
17392	CZAN	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20058E	\N	\N	\N
19330	INFLU	2024-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	14133K	\N	\N	\N
19331	INFLU	2024-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19575F	\N	\N	\N
19332	INFLU	2024-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	17367Q	\N	\N	\N
19433	PERI	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	19711U	\N	\N	\N
19334	INFLU	2024-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	08034U	\N	\N	\N
19335	INFLU	2024-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19709B	\N	\N	\N
19336	INFLU	2024-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	14059S	\N	\N	\N
19337	INFLU	2024-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	10015M	\N	\N	\N
19338	INFLU	2024-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	11043H	\N	\N	\N
19339	INFLU	2024-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	07004J	\N	\N	\N
19340	INFLU	2024-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	14179A	\N	\N	\N
19341	INFLU	2024-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	04070G	\N	\N	\N
19342	INFLU	2024-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19745F	\N	\N	\N
19343	INFLU	2024-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	14097Y	\N	\N	\N
19344	INFLU	2024-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	14225N	\N	\N	\N
19345	INFLU	2024-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	14229S	\N	\N	\N
19346	INFLU	2024-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19669L	\N	\N	\N
19347	INFLU	2024-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	14249W	\N	\N	\N
19348	INFLU	2024-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20150Y	\N	\N	\N
19349	INFLU	2024-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	21041Y	\N	\N	\N
19434	PERI	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	20024T	\N	\N	\N
19351	INFLU	2024-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	11040E	\N	\N	\N
19352	INFLU	2024-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20050V	\N	\N	\N
19353	INFLU	2024-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	21073H	\N	\N	\N
19435	PERI	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	20056C	\N	\N	\N
19436	PERI	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	19723Y	\N	\N	\N
19437	PERI	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	14147R	\N	\N	\N
19438	PERI	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	20096L	\N	\N	\N
19439	PERI	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	19798U	\N	\N	\N
19440	PERI	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	20098N	\N	\N	\N
19441	PERI	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	20062A	\N	\N	\N
19442	PERI	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	14030Q	\N	\N	\N
19443	PERI	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	19691J	\N	\N	\N
19444	PERI	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	20066E	\N	\N	\N
19445	PERI	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	21064G	\N	\N	\N
19446	PERI	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	21045D	\N	\N	\N
19447	PERI	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	19531S	\N	\N	\N
19448	PERI	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	18193Q	\N	\N	\N
19449	PERI	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	17965H	\N	\N	\N
19450	PERI	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	19331L	\N	\N	\N
19451	PERI	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	21043B	\N	\N	\N
19452	PERI	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	19553Y	\N	\N	\N
17059	SECUECO	2021-11-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	19577H	\N	\N	\N
17060	SECUECO	2021-11-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	19569H	\N	\N	\N
17061	SECUECO	2021-11-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	14205J	\N	\N	\N
17062	SECUECO	2021-11-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	20106U	\N	\N	\N
17063	SECUECO	2021-11-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	19575F	\N	\N	\N
17064	SECUECO	2021-11-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	19701S	\N	\N	\N
17065	SECUECO	2021-11-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	18083K	\N	\N	\N
17066	SECUECO	2021-11-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	14259Y	\N	\N	\N
17067	SECUECO	2021-11-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	20034V	\N	\N	\N
17068	SECUECO	2021-11-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	14031R	\N	\N	\N
17069	SECUECO	2021-11-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	19679N	\N	\N	\N
17070	SECUECO	2021-11-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	19760E	\N	\N	\N
17071	SECUECO	2021-11-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	14111D	\N	\N	\N
17072	SECUECO	2021-11-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	19549D	\N	\N	\N
17073	SECUECO	2021-11-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	18193Q	\N	\N	\N
17074	SECUECO	2021-11-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	17965H	\N	\N	\N
17075	SECUECO	2021-11-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	19866P	\N	\N	\N
17076	SECUECO	2021-11-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	19387D	\N	\N	\N
17077	SECUECO	2021-11-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	20266L	\N	\N	\N
17078	SECUECO	2021-11-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	19347U	\N	\N	\N
17079	SECUECO	2021-11-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	11101A	\N	\N	\N
19242	PLFSS	2023-11-15 00:00:00	2023-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	14071N	TITULAIRE	\N	\N
19243	PLFSS	2023-11-15 00:00:00	2023-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	14213J	TITULAIRE	\N	\N
19244	PLFSS	2023-11-15 00:00:00	2023-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	14026U	TITULAIRE	\N	\N
19245	PLFSS	2023-11-15 00:00:00	2023-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	14042U	TITULAIRE	\N	\N
19246	PLFSS	2023-11-15 00:00:00	2023-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	19683J	TITULAIRE	\N	\N
19247	PLFSS	2023-11-15 00:00:00	2023-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	17779H	TITULAIRE	\N	\N
19248	PLFSS	2023-11-15 00:00:00	2023-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	19591F	TITULAIRE	\N	\N
19249	PLFSS	2023-11-15 00:00:00	2023-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	14217N	SUPPLEANT	\N	\N
19250	PLFSS	2023-11-15 00:00:00	2023-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	19798U	SUPPLEANT	\N	\N
19251	PLFSS	2023-11-15 00:00:00	2023-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	19569H	SUPPLEANT	\N	\N
19252	PLFSS	2023-11-15 00:00:00	2023-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	21045D	SUPPLEANT	\N	\N
19253	PLFSS	2023-11-15 00:00:00	2023-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	19760E	SUPPLEANT	\N	\N
19254	PLFSS	2023-11-15 00:00:00	2023-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	21087P	SUPPLEANT	\N	\N
19255	PLFSS	2023-11-15 00:00:00	2023-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	21094N	SUPPLEANT	\N	\N
19256	PLFSS	2023-11-15 00:00:00	2023-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	21071F	TITULAIRE	\N	\N
19260	EMPLO	2024-01-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	17965H	TITULAIRE	\N	\N
19258	EMPLO	2024-01-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	20090E	TITULAIRE	\N	\N
19259	EMPLO	2024-01-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	19569H	TITULAIRE	\N	\N
19261	EMPLO	2024-01-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	14281W	TITULAIRE	\N	\N
19262	EMPLO	2024-01-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	21097R	TITULAIRE	\N	\N
19263	EMPLO	2024-01-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	14223L	SUPPLEANT	\N	\N
19264	EMPLO	2024-01-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	19703U	SUPPLEANT	\N	\N
19265	EMPLO	2024-01-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	19691J	SUPPLEANT	\N	\N
19266	EMPLO	2024-01-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	18193Q	SUPPLEANT	\N	\N
19267	EMPLO	2024-01-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	19760E	SUPPLEANT	\N	\N
19268	EMPLO	2024-01-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	21087P	TITULAIRE	\N	\N
19269	EMPLO	2024-01-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	20130U	SUPPLEANT	\N	\N
19270	EMPLO	2023-10-19 00:00:00	2023-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	19760E	SUPPLEANT	\N	\N
19271	EMPLO	2023-10-19 00:00:00	2023-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	20090E	TITULAIRE	\N	\N
19272	EMPLO	2023-10-19 00:00:00	2023-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	14026U	TITULAIRE	\N	\N
19273	EMPLO	2023-10-19 00:00:00	2023-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	14071N	TITULAIRE	\N	\N
19274	EMPLO	2023-10-19 00:00:00	2023-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	19569H	TITULAIRE	\N	\N
19275	EMPLO	2023-10-19 00:00:00	2023-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	17965H	TITULAIRE	\N	\N
19276	EMPLO	2023-10-19 00:00:00	2023-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	21097R	TITULAIRE	\N	\N
19277	EMPLO	2023-10-19 00:00:00	2023-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	14223L	SUPPLEANT	\N	\N
19278	EMPLO	2023-10-19 00:00:00	2023-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	19703U	SUPPLEANT	\N	\N
19287	INDUS	2023-10-06 00:00:00	2023-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	20120S	TITULAIRE	\N	\N
19280	EMPLO	2023-10-19 00:00:00	2023-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	19691J	SUPPLEANT	\N	\N
19281	EMPLO	2023-10-19 00:00:00	2023-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	18193Q	SUPPLEANT	\N	\N
19282	EMPLO	2023-10-19 00:00:00	2023-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	21087P	SUPPLEANT	\N	\N
19283	EMPLO	2023-10-19 00:00:00	2023-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	20130U	SUPPLEANT	\N	\N
19285	INDUS	2023-10-06 00:00:00	2023-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	20062A	TITULAIRE	\N	\N
19286	INDUS	2023-10-06 00:00:00	2023-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	14187A	TITULAIRE	\N	\N
19288	INDUS	2023-10-06 00:00:00	2023-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	20144B	TITULAIRE	\N	\N
19289	INDUS	2023-10-06 00:00:00	2023-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	20080C	TITULAIRE	\N	\N
19290	INDUS	2023-10-06 00:00:00	2023-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	14257W	TITULAIRE	\N	\N
19291	INDUS	2023-10-06 00:00:00	2023-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	19782L	TITULAIRE	\N	\N
19292	INDUS	2023-10-06 00:00:00	2023-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	19711U	SUPPLEANT	\N	\N
19293	INDUS	2023-10-06 00:00:00	2023-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	14031R	SUPPLEANT	\N	\N
19294	INDUS	2023-10-06 00:00:00	2023-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	14219Q	TITULAIRE	\N	\N
19295	INDUS	2023-10-06 00:00:00	2023-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	20028X	SUPPLEANT	\N	\N
19296	INDUS	2023-10-06 00:00:00	2023-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	21071F	TITULAIRE	\N	\N
19297	INDUS	2023-10-06 00:00:00	2023-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	19695N	SUPPLEANT	\N	\N
19298	INDUS	2023-10-06 00:00:00	2023-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	14221J	SUPPLEANT	\N	\N
19299	INDUS	2023-10-06 00:00:00	2023-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	20092G	TITULAIRE	\N	\N
19300	PJLO	2023-10-05 00:00:00	2023-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
19301	PJLO	2023-10-05 00:00:00	2023-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14053L	TITULAIRE	\N	\N
19302	PJLO	2023-10-05 00:00:00	2023-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	19749K	TITULAIRE	\N	\N
19303	PJLO	2023-10-05 00:00:00	2023-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	TITULAIRE	\N	\N
19304	PJLO	2023-10-05 00:00:00	2023-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	19649G	TITULAIRE	\N	\N
19305	PJLO	2023-10-05 00:00:00	2023-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	20114U	TITULAIRE	\N	\N
19306	PJLO	2023-10-05 00:00:00	2023-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	11072N	TITULAIRE	\N	\N
19307	PJLO	2023-10-05 00:00:00	2023-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	19447X	SUPPLEANT	\N	\N
19308	PJLO	2023-10-05 00:00:00	2023-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	10015M	SUPPLEANT	\N	\N
19309	PJLO	2023-10-05 00:00:00	2023-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14089Y	SUPPLEANT	\N	\N
19310	PJLO	2023-10-05 00:00:00	2023-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	19725B	SUPPLEANT	\N	\N
19311	PJLO	2023-10-05 00:00:00	2023-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	11056N	SUPPLEANT	\N	\N
19312	PJLO	2023-10-05 00:00:00	2023-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14111D	SUPPLEANT	\N	\N
19313	PJLO	2023-10-05 00:00:00	2023-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	20110Q	SUPPLEANT	\N	\N
19314	JUST	2023-10-05 00:00:00	2023-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
19319	JUST	2023-10-05 00:00:00	2023-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	19649G	TITULAIRE	\N	\N
19316	JUST	2023-10-05 00:00:00	2023-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14053L	TITULAIRE	\N	\N
19317	JUST	2023-10-05 00:00:00	2023-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	19749K	TITULAIRE	\N	\N
19318	JUST	2023-10-05 00:00:00	2023-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	TITULAIRE	\N	\N
19320	JUST	2023-10-05 00:00:00	2023-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	20114U	TITULAIRE	\N	\N
19321	JUST	2023-10-05 00:00:00	2023-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	11072N	TITULAIRE	\N	\N
19322	JUST	2023-10-05 00:00:00	2023-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	19447X	SUPPLEANT	\N	\N
19323	JUST	2023-10-05 00:00:00	2023-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	10015M	SUPPLEANT	\N	\N
19324	JUST	2023-10-05 00:00:00	2023-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14089Y	SUPPLEANT	\N	\N
19325	JUST	2023-10-05 00:00:00	2023-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	19725B	SUPPLEANT	\N	\N
19326	JUST	2023-10-05 00:00:00	2023-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	11056N	SUPPLEANT	\N	\N
19327	JUST	2023-10-05 00:00:00	2023-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14111D	TITULAIRE	\N	\N
19328	JUST	2023-10-05 00:00:00	2023-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	20110Q	SUPPLEANT	\N	\N
19378	COMP	2024-02-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	21071F	\N	\N	\N
19379	COMP	2024-02-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	21042A	\N	\N	\N
19380	COMP	2024-02-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	20080C	\N	\N	\N
19381	COMP	2024-02-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	14189C	\N	\N	\N
19382	COMP	2024-02-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	21090J	\N	\N	\N
19383	COMP	2024-02-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	20140W	\N	\N	\N
19384	COMP	2024-02-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	14215L	\N	\N	\N
19385	COMP	2024-02-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	20040T	\N	\N	\N
19386	COMP	2024-02-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	20132W	\N	\N	\N
19387	COMP	2024-02-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	20106U	\N	\N	\N
19388	COMP	2024-02-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	19591F	\N	\N	\N
19389	COMP	2024-02-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	14213J	\N	\N	\N
19390	COMP	2024-02-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	14073Q	\N	\N	\N
19391	COMP	2024-02-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	21081H	\N	\N	\N
19392	COMP	2024-02-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	18193Q	\N	\N	\N
19393	COMP	2024-02-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	21087P	\N	\N	\N
19394	COMP	2024-02-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	19657G	\N	\N	\N
19395	COMP	2024-02-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	20028X	\N	\N	\N
19396	COMP	2024-02-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	04092N	\N	\N	\N
19397	COMP	2024-02-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	17965H	\N	\N	\N
19398	COMP	2024-02-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	10015M	\N	\N	\N
19399	COMP	2024-02-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	21049H	\N	\N	\N
15878	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20016T	\N	\N	\N
15880	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20020P	\N	\N	\N
9487	2013CMP11	2013-07-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	88008L	SUPPLEANT	\N	\N
15884	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20028X	\N	\N	\N
9090	2012CMP27	2012-12-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08055A	TITULAIRE	\N	\N
11497	CDD	2015-07-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08055A	\N	2015-07-10 11:25:43	2017-10-04 19:42:19
10340	2014CMP1	2014-01-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04088S	SUPPLEANT	\N	\N
15885	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20030R	\N	\N	\N
7810	2011CMP8	2011-06-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80013X	SUPPLEANT	\N	\N
16515	PJLELEC	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
16516	PJLELEC	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	TITULAIRE	\N	\N
16517	PJLELEC	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
16518	PJLELEC	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	14179A	TITULAIRE	\N	\N
16519	PJLELEC	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	14001X	TITULAIRE	\N	\N
16520	PJLELEC	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19489J	TITULAIRE	\N	\N
16521	PJLELEC	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	11072N	TITULAIRE	\N	\N
16522	PJLELEC	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19447X	SUPPLEANT	\N	\N
16523	PJLELEC	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	SUPPLEANT	\N	\N
16524	PJLELEC	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19673G	SUPPLEANT	\N	\N
16525	PJLELEC	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	11085T	SUPPLEANT	\N	\N
16526	PJLELEC	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	14151M	SUPPLEANT	\N	\N
16527	PJLELEC	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	14107H	SUPPLEANT	\N	\N
16528	PJLELEC	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	11056N	SUPPLEANT	\N	\N
16529	PARQUETEURO	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
16530	PARQUETEURO	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	14089Y	TITULAIRE	\N	\N
16531	PARQUETEURO	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	08018U	TITULAIRE	\N	\N
16532	PARQUETEURO	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	TITULAIRE	\N	\N
16533	PARQUETEURO	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	14151M	TITULAIRE	\N	\N
16534	PARQUETEURO	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
16535	PARQUETEURO	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	11072N	TITULAIRE	\N	\N
16536	PARQUETEURO	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	SUPPLEANT	\N	\N
16537	PARQUETEURO	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	20108W	SUPPLEANT	\N	\N
16538	PARQUETEURO	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19954N	SUPPLEANT	\N	\N
16539	PARQUETEURO	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19749K	SUPPLEANT	\N	\N
16540	PARQUETEURO	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	11026G	SUPPLEANT	\N	\N
16541	PARQUETEURO	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19629C	SUPPLEANT	\N	\N
16542	PARQUETEURO	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	SUPPLEANT	\N	\N
16543	URGSAN	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
16544	URGSAN	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
16545	URGSAN	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	SUPPLEANT	\N	\N
16546	URGSAN	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19447X	SUPPLEANT	\N	\N
16547	URGSAN	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	08018U	SUPPLEANT	\N	\N
16548	URGSAN	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	11085T	SUPPLEANT	\N	\N
16549	URGSAN	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	14001X	SUPPLEANT	\N	\N
16550	URGSAN	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	14107H	SUPPLEANT	\N	\N
16551	URGSAN	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	SUPPLEANT	\N	\N
16552	URGSAN	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19673G	TITULAIRE	\N	\N
16553	URGSAN	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	14089Y	TITULAIRE	\N	\N
16554	URGSAN	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19649G	TITULAIRE	\N	\N
16555	URGSAN	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	11026G	TITULAIRE	\N	\N
16556	URGSAN	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	11072N	TITULAIRE	\N	\N
16557	JUSTMINEURS	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
16558	JUSTMINEURS	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	14053L	TITULAIRE	\N	\N
16559	JUSTMINEURS	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	SUPPLEANT	\N	\N
16560	JUSTMINEURS	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	SUPPLEANT	\N	\N
16565	JUSTMINEURS	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	14107H	SUPPLEANT	\N	\N
16562	JUSTMINEURS	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19675J	SUPPLEANT	\N	\N
16563	JUSTMINEURS	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	11085T	SUPPLEANT	\N	\N
16564	JUSTMINEURS	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19649G	SUPPLEANT	\N	\N
16566	JUSTMINEURS	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	SUPPLEANT	\N	\N
16567	JUSTMINEURS	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
16568	JUSTMINEURS	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19749K	TITULAIRE	\N	\N
16569	JUSTMINEURS	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
16570	JUSTMINEURS	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	11026G	TITULAIRE	\N	\N
16571	JUSTMINEURS	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	11072N	TITULAIRE	\N	\N
16572	BIOETHIQ	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	TITULAIRE	\N	\N
16573	BIOETHIQ	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19447X	TITULAIRE	\N	\N
16574	BIOETHIQ	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	10006L	SUPPLEANT	\N	\N
16575	BIOETHIQ	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	SUPPLEANT	\N	\N
16576	BIOETHIQ	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	18083K	SUPPLEANT	\N	\N
16577	BIOETHIQ	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	20066E	SUPPLEANT	\N	\N
16578	BIOETHIQ	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	11026G	SUPPLEANT	\N	\N
16579	BIOETHIQ	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19553Y	SUPPLEANT	\N	\N
16580	BIOETHIQ	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	11031D	SUPPLEANT	\N	\N
16581	BIOETHIQ	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	14213J	TITULAIRE	\N	\N
16582	BIOETHIQ	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19569H	TITULAIRE	\N	\N
16583	BIOETHIQ	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19683J	TITULAIRE	\N	\N
16584	BIOETHIQ	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19649G	TITULAIRE	\N	\N
16585	BIOETHIQ	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	11072N	TITULAIRE	\N	\N
17997	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19713W	\N	\N	\N
19453	PERI	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	19758L	\N	\N	\N
19454	PERI	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	21087P	\N	\N	\N
19455	PERI	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	21094N	\N	\N	\N
19456	ARCH	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	20032T	\N	\N	\N
19457	ARCH	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	20022R	\N	\N	\N
19458	ARCH	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	20124W	\N	\N	\N
19459	ARCH	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	20056C	\N	\N	\N
19460	ARCH	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	95041E	\N	\N	\N
19461	ARCH	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	21039F	\N	\N	\N
19462	ARCH	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	21068L	\N	\N	\N
19463	ARCH	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	20026V	\N	\N	\N
19464	ARCH	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	20058E	\N	\N	\N
19465	ARCH	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	21086N	\N	\N	\N
19466	ARCH	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	19735D	\N	\N	\N
19467	ARCH	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	19611R	\N	\N	\N
19468	ARCH	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	14205J	\N	\N	\N
19469	ARCH	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	21089R	\N	\N	\N
19470	ARCH	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	11074Q	\N	\N	\N
19471	ARCH	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	14109K	\N	\N	\N
19472	ARCH	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	21077M	\N	\N	\N
19473	ARCH	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	14249W	\N	\N	\N
19474	ARCH	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	14037X	\N	\N	\N
19475	ARCH	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	19866P	\N	\N	\N
19476	ARCH	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	21084L	\N	\N	\N
19477	ARCH	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	20122U	\N	\N	\N
19478	ARCH	2024-02-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	20142Y	\N	\N	\N
15692	CAE	2020-06-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19912C	\N	\N	\N
10471	2014CMP13	2014-05-28 00:00:00	2020-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	96004D	TITULAIRE	\N	\N
16215	NEANT	2020-12-01 00:00:00	2020-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	20176K	\N	\N	\N
16891	UBER	2021-06-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	19717B	\N	\N	\N
16892	UBER	2021-06-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	19575F	\N	\N	\N
16893	UBER	2021-06-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	14329V	\N	\N	\N
16894	UBER	2021-06-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	14038Y	\N	\N	\N
16895	UBER	2021-06-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	14083S	\N	\N	\N
16896	UBER	2021-06-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	19545Y	\N	\N	\N
16897	UBER	2021-06-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	14357A	\N	\N	\N
16898	UBER	2021-06-18 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	\N	\N	\N
16899	UBER	2021-06-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	14217N	\N	\N	\N
16900	UBER	2021-06-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	08045X	\N	\N	\N
16901	UBER	2021-06-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	14026U	\N	\N	\N
16902	UBER	2021-06-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	20128B	\N	\N	\N
16903	UBER	2021-06-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	19685L	\N	\N	\N
16904	UBER	2021-06-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	19551W	\N	\N	\N
16905	UBER	2021-06-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	17779H	\N	\N	\N
16906	UBER	2021-06-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	19369B	\N	\N	\N
16907	UBER	2021-06-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	14071N	\N	\N	\N
16908	UBER	2021-06-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	17965H	\N	\N	\N
16909	UBER	2021-06-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	19679N	\N	\N	\N
16910	UBER	2021-06-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	20020P	\N	\N	\N
16911	UBER	2021-06-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	19687N	\N	\N	\N
16912	UBER	2021-06-18 00:00:00	2022-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	19689Q	\N	\N	\N
16913	UBER	2021-06-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	19749K	\N	\N	\N
17174	NEANT	2022-06-21 00:00:00	2022-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	14037X	\N	\N	\N
17175	AFEU	2022-06-17 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19681G	\N	\N	\N
19400	COMP	2024-02-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	21094N	\N	\N	\N
15694	NEANT	2020-06-26 00:00:00	2020-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	19926J	\N	\N	\N
17393	BATI	2023-02-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	20038A	\N	\N	\N
17394	BATI	2023-02-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	11026G	\N	\N	\N
18356	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21074J	\N	\N	\N
18357	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20142Y	\N	\N	\N
18358	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21037D	\N	\N	\N
18527	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21084L	\N	\N	\N
18528	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19681G	\N	\N	\N
18529	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20046A	\N	\N	\N
18596	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19697Q	\N	\N	\N
18597	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19057M	\N	\N	\N
18598	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20016T	\N	\N	\N
18599	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	11072N	\N	\N	\N
18600	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21043B	\N	\N	\N
18601	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	04045F	\N	\N	\N
18606	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14037X	\N	\N	\N
18607	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14249W	\N	\N	\N
18608	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20128B	\N	\N	\N
18609	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19782L	\N	\N	\N
18610	CAE	2023-10-04 00:00:00	2029-11-27 00:00:00	ACTIF	\N	\N	\N	\N	21033Y	\N	\N	\N
18611	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21096Q	\N	\N	\N
18612	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20106U	\N	\N	\N
18613	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20146D	\N	\N	\N
18614	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19331L	\N	\N	\N
18615	ETRD	2023-10-04 00:00:00	2024-03-20 00:00:00	ANCIEN	\N	\N	\N	\N	98022P	\N	\N	\N
18616	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20072C	\N	\N	\N
18666	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19553Y	\N	\N	\N
18667	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19866P	\N	\N	\N
18668	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19629C	\N	\N	\N
18669	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19387D	\N	\N	\N
18670	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14107H	\N	\N	\N
18689	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21069M	\N	\N	\N
15693	NEANT	2020-06-25 00:00:00	2020-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	19920C	\N	\N	\N
15662	ELECTIONS	2020-06-10 00:00:00	2020-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
15663	ELECTIONS	2020-06-10 00:00:00	2020-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	TITULAIRE	\N	\N
15664	ELECTIONS	2020-06-10 00:00:00	2020-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	19447X	TITULAIRE	\N	\N
15665	ELECTIONS	2020-06-10 00:00:00	2020-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	19611R	TITULAIRE	\N	\N
15666	ELECTIONS	2020-06-10 00:00:00	2020-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	11026G	TITULAIRE	\N	\N
15667	ELECTIONS	2020-06-10 00:00:00	2020-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
15668	ELECTIONS	2020-06-10 00:00:00	2020-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	TITULAIRE	\N	\N
15669	ELECTIONS	2020-06-10 00:00:00	2020-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	SUPPLEANT	\N	\N
15670	ELECTIONS	2020-06-10 00:00:00	2020-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	19673G	SUPPLEANT	\N	\N
15671	ELECTIONS	2020-06-10 00:00:00	2020-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	19675J	SUPPLEANT	\N	\N
15672	ELECTIONS	2020-06-10 00:00:00	2020-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	11085T	SUPPLEANT	\N	\N
15673	ELECTIONS	2020-06-10 00:00:00	2020-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	14151M	SUPPLEANT	\N	\N
15674	ELECTIONS	2020-06-10 00:00:00	2020-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	19629C	SUPPLEANT	\N	\N
15675	ELECTIONS	2020-06-10 00:00:00	2020-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	\N	\N
15764	CONJUGALE	2020-06-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
15765	CONJUGALE	2020-06-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	14147R	TITULAIRE	\N	\N
15766	CONJUGALE	2020-06-24 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	TITULAIRE	\N	\N
15767	CONJUGALE	2020-06-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	14030Q	TITULAIRE	\N	\N
15768	CONJUGALE	2020-06-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	19649G	TITULAIRE	\N	\N
15769	CONJUGALE	2020-06-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	11045K	TITULAIRE	\N	\N
15770	CONJUGALE	2020-06-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	11072N	TITULAIRE	\N	\N
15771	CONJUGALE	2020-06-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	14069U	SUPPLEANT	\N	\N
15772	CONJUGALE	2020-06-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	14215L	SUPPLEANT	\N	\N
15773	CONJUGALE	2020-06-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	19673G	SUPPLEANT	\N	\N
15774	CONJUGALE	2020-06-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	19749K	SUPPLEANT	\N	\N
15775	CONJUGALE	2020-06-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	19725B	SUPPLEANT	\N	\N
15776	CONJUGALE	2020-06-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	19629C	SUPPLEANT	\N	\N
15777	CONJUGALE	2020-06-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	11033F	SUPPLEANT	\N	\N
16987	AFCL	2021-10-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20264J	\N	\N	\N
16988	AFCL	2021-10-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19057M	\N	\N	\N
16989	ETRD	2021-10-05 00:00:00	2022-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	19329S	\N	\N	\N
16990	AFEU	2021-10-05 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	04045F	\N	\N	\N
18342	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21092L	\N	\N	\N
18343	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21093M	\N	\N	\N
18344	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20092G	\N	\N	\N
18345	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14195A	\N	\N	\N
18346	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21046E	\N	\N	\N
18347	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21087P	\N	\N	\N
18348	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21052C	\N	\N	\N
18349	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21054E	\N	\N	\N
18350	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14221J	\N	\N	\N
18351	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21065H	\N	\N	\N
18352	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21070E	\N	\N	\N
18359	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14111D	\N	\N	\N
18360	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21076L	\N	\N	\N
18361	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19585H	\N	\N	\N
18362	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20114U	\N	\N	\N
18363	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21057H	\N	\N	\N
18364	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19649G	\N	\N	\N
18365	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14151M	\N	\N	\N
18366	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19725B	\N	\N	\N
18367	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19489J	\N	\N	\N
18368	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	18207D	\N	\N	\N
18369	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	18231D	\N	\N	\N
18370	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21056G	\N	\N	\N
18371	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21045D	\N	\N	\N
18372	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19295A	\N	\N	\N
18373	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14281W	\N	\N	\N
18374	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	08045X	\N	\N	\N
18375	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19683J	\N	\N	\N
18376	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	18193Q	\N	\N	\N
18377	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	17779H	\N	\N	\N
18378	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	17965H	\N	\N	\N
18379	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	11045K	\N	\N	\N
18458	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14030Q	\N	\N	\N
18459	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20286Q	\N	\N	\N
18460	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21050A	\N	\N	\N
18461	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21083K	\N	\N	\N
18462	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20144B	\N	\N	\N
18463	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21086N	\N	\N	\N
18464	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20066E	\N	\N	\N
18465	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14205J	\N	\N	\N
18466	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19563B	\N	\N	\N
18467	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20032T	\N	\N	\N
18468	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20076G	\N	\N	\N
18469	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	18083K	\N	\N	\N
18470	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19701S	\N	\N	\N
18471	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20120S	\N	\N	\N
18472	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20068G	\N	\N	\N
18473	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14031R	\N	\N	\N
18474	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21080G	\N	\N	\N
18475	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21029D	\N	\N	\N
18476	CDD	2023-10-04 00:00:00	2023-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	21039F	\N	\N	\N
18477	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14169X	\N	\N	\N
18478	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14237S	\N	\N	\N
18479	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21047F	\N	\N	\N
18480	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20118Y	\N	\N	\N
18481	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	05012A	\N	\N	\N
18482	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21068L	\N	\N	\N
18483	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20020P	\N	\N	\N
18484	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20136B	\N	\N	\N
18485	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21061D	\N	\N	\N
18486	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21071F	\N	\N	\N
18487	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19367Y	\N	\N	\N
18488	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20090E	\N	\N	\N
18489	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20140W	\N	\N	\N
18490	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14217N	\N	\N	\N
18491	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14355X	\N	\N	\N
18492	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14026U	\N	\N	\N
18493	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14213J	\N	\N	\N
18494	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21081H	\N	\N	\N
18495	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19723Y	\N	\N	\N
18496	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19657G	\N	\N	\N
18497	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14223L	\N	\N	\N
18498	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	04092N	\N	\N	\N
18499	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14071N	\N	\N	\N
18500	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20096L	\N	\N	\N
18501	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20148F	\N	\N	\N
18502	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19679N	\N	\N	\N
18503	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19798U	\N	\N	\N
18504	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19703U	\N	\N	\N
18505	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	05008E	\N	\N	\N
18506	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20022R	\N	\N	\N
18507	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14069U	\N	\N	\N
18508	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	04047H	\N	\N	\N
18509	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14053L	\N	\N	\N
18510	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14259Y	\N	\N	\N
18511	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	04008A	\N	\N	\N
18512	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14215L	\N	\N	\N
18513	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20074E	\N	\N	\N
18514	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19673G	\N	\N	\N
18515	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	08018U	\N	\N	\N
18516	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21044C	\N	\N	\N
18517	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19447X	\N	\N	\N
18518	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19729F	\N	\N	\N
18519	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20108W	\N	\N	\N
18520	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14147R	\N	\N	\N
18521	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	10015M	\N	\N	\N
18522	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20098N	\N	\N	\N
18523	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21095P	\N	\N	\N
18524	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19760E	\N	\N	\N
18525	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19758L	\N	\N	\N
18526	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21049H	\N	\N	\N
18569	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19707Y	\N	\N	\N
18570	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19575F	\N	\N	\N
18571	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20078J	\N	\N	\N
18572	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19383Y	\N	\N	\N
18573	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20104S	\N	\N	\N
18574	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14329V	\N	\N	\N
18575	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14038Y	\N	\N	\N
18576	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	08028W	\N	\N	\N
18577	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14357A	\N	\N	\N
18578	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19507S	\N	\N	\N
18579	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14187A	\N	\N	\N
18580	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20038A	\N	\N	\N
18581	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14033T	\N	\N	\N
18582	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20034V	\N	\N	\N
18583	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	08015R	\N	\N	\N
18584	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19768N	\N	\N	\N
18585	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	11090Q	\N	\N	\N
18586	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19705W	\N	\N	\N
18587	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20054A	\N	\N	\N
18588	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21034A	\N	\N	\N
18589	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19695N	\N	\N	\N
18590	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21075K	\N	\N	\N
18591	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19565D	\N	\N	\N
18592	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21030V	\N	\N	\N
18602	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19591F	\N	\N	\N
18603	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	08061X	\N	\N	\N
18604	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21097R	\N	\N	\N
18605	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19301E	\N	\N	\N
11638	2015CMP19	2015-09-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08024S	SUPPLEANT	\N	\N
15950	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20142Y	\N	\N	\N
15952	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	17965H	\N	\N	\N
7307	2010CMP5	2010-05-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08031R	SUPPLEANT	\N	\N
10903	2015CMP2	2015-01-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08031R	SUPPLEANT	2015-01-30 09:37:27	2015-01-30 09:37:33
16144	BIOETHIQUE	2020-10-15 00:00:00	2021-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	20132W	\N	\N	\N
19354	COPRO	2024-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20090E	\N	\N	\N
19355	COPRO	2024-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20124W	\N	\N	\N
19356	COPRO	2024-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19447X	\N	\N	\N
19357	COPRO	2024-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	14147R	\N	\N	\N
19358	COPRO	2024-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19768N	\N	\N	\N
19359	COPRO	2024-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19679N	\N	\N	\N
19360	COPRO	2024-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20044X	\N	\N	\N
19361	COPRO	2024-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	21083K	\N	\N	\N
19362	COPRO	2024-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	17229F	\N	\N	\N
19511	AGE	2024-03-08 00:00:00	2024-03-13 00:00:00	ANCIEN	\N	\N	\N	\N	14071N	TITULAIRE	\N	\N
19364	COPRO	2024-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20286Q	\N	\N	\N
19365	COPRO	2024-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20114U	\N	\N	\N
19512	AGE	2024-03-08 00:00:00	2024-03-13 00:00:00	ANCIEN	\N	\N	\N	\N	19703U	TITULAIRE	\N	\N
19367	COPRO	2024-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20060X	\N	\N	\N
19368	COPRO	2024-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	18207D	\N	\N	\N
19369	COPRO	2024-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	21059K	\N	\N	\N
19370	COPRO	2024-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19782L	\N	\N	\N
19513	AGE	2024-03-08 00:00:00	2024-03-13 00:00:00	ANCIEN	\N	\N	\N	\N	20098N	TITULAIRE	\N	\N
19372	COPRO	2024-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	21078N	\N	\N	\N
19373	COPRO	2024-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	21075K	\N	\N	\N
19374	COPRO	2024-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	21065H	\N	\N	\N
19375	COPRO	2024-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	21092L	\N	\N	\N
19514	AGE	2024-03-08 00:00:00	2024-03-13 00:00:00	ANCIEN	\N	\N	\N	\N	19691J	TITULAIRE	\N	\N
19515	AGE	2024-03-08 00:00:00	2024-03-13 00:00:00	ANCIEN	\N	\N	\N	\N	14281W	TITULAIRE	\N	\N
19516	AGE	2024-03-08 00:00:00	2024-03-13 00:00:00	ANCIEN	\N	\N	\N	\N	18193Q	TITULAIRE	\N	\N
19517	AGE	2024-03-08 00:00:00	2024-03-13 00:00:00	ANCIEN	\N	\N	\N	\N	21097R	TITULAIRE	\N	\N
19518	AGE	2024-03-08 00:00:00	2024-03-13 00:00:00	ANCIEN	\N	\N	\N	\N	14217N	SUPPLEANT	\N	\N
19519	AGE	2024-03-08 00:00:00	2024-03-13 00:00:00	ANCIEN	\N	\N	\N	\N	14213J	SUPPLEANT	\N	\N
19520	AGE	2024-03-08 00:00:00	2024-03-13 00:00:00	ANCIEN	\N	\N	\N	\N	01034P	SUPPLEANT	\N	\N
19521	AGE	2024-03-08 00:00:00	2024-03-13 00:00:00	ANCIEN	\N	\N	\N	\N	17779H	SUPPLEANT	\N	\N
19522	AGE	2024-03-08 00:00:00	2024-03-13 00:00:00	ANCIEN	\N	\N	\N	\N	19760E	SUPPLEANT	\N	\N
19523	AGE	2024-03-08 00:00:00	2024-03-13 00:00:00	ANCIEN	\N	\N	\N	\N	14195A	SUPPLEANT	\N	\N
19524	AGE	2024-03-08 00:00:00	2024-03-13 00:00:00	ANCIEN	\N	\N	\N	\N	21094N	SUPPLEANT	\N	\N
15728	PANDEMIE	2020-07-01 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	19667J	\N	\N	\N
15729	PANDEMIE	2020-07-01 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	19643A	\N	\N	\N
15730	PANDEMIE	2020-07-01 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	19663E	\N	\N	\N
15731	PANDEMIE	2020-07-01 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	10006L	\N	\N	\N
15732	PANDEMIE	2020-07-01 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	\N	\N	\N
15733	PANDEMIE	2020-07-01 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	\N	\N	\N
15734	PANDEMIE	2020-07-01 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	19447X	\N	\N	\N
15735	PANDEMIE	2020-07-01 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	95041E	\N	\N	\N
15736	PANDEMIE	2020-07-01 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	99004R	\N	\N	\N
15737	PANDEMIE	2020-07-01 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	\N	\N	\N
15738	PANDEMIE	2020-07-01 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	19573D	\N	\N	\N
15739	PANDEMIE	2020-07-01 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	14331P	\N	\N	\N
15740	PANDEMIE	2020-07-01 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	19766L	\N	\N	\N
15741	PANDEMIE	2020-07-01 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	11097X	\N	\N	\N
15742	PANDEMIE	2020-07-01 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	19703U	\N	\N	\N
15743	PANDEMIE	2020-07-01 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	11070L	\N	\N	\N
15744	PANDEMIE	2020-07-01 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	19569H	\N	\N	\N
15745	PANDEMIE	2020-07-01 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	19479G	\N	\N	\N
15746	PANDEMIE	2020-07-01 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	01034P	\N	\N	\N
15747	PANDEMIE	2020-07-01 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	19691J	\N	\N	\N
15748	PANDEMIE	2020-07-01 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	04059M	\N	\N	\N
15749	PANDEMIE	2020-07-01 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	19649G	\N	\N	\N
15750	PANDEMIE	2020-07-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14081Q	\N	\N	\N
15751	PANDEMIE	2020-07-01 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	19715Y	\N	\N	\N
15752	PANDEMIE	2020-07-01 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	19683J	\N	\N	\N
15753	PANDEMIE	2020-07-01 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	11067R	\N	\N	\N
15754	PANDEMIE	2020-07-01 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	19503N	\N	\N	\N
15755	PANDEMIE	2020-07-01 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	19697Q	\N	\N	\N
15756	PANDEMIE	2020-07-01 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	19349W	\N	\N	\N
15757	PANDEMIE	2020-07-01 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	19553Y	\N	\N	\N
15758	PANDEMIE	2020-07-01 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	11012A	\N	\N	\N
15759	PANDEMIE	2020-07-01 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	\N	\N	\N
15760	PANDEMIE	2020-07-01 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	11031D	\N	\N	\N
15761	PANDEMIE	2020-07-01 00:00:00	2020-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	14251Q	\N	\N	\N
15762	PANDEMIE	2020-07-01 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	19545Y	\N	\N	\N
15763	PANDEMIE	2020-07-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89017R	\N	\N	\N
16213	AFCL	2020-11-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01060R	\N	\N	\N
16949	INFLUENCES	2021-06-30 00:00:00	2021-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	20058E	\N	\N	\N
18673	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20116W	\N	\N	\N
18674	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20132W	\N	\N	\N
18675	AFCL	2023-10-04 00:00:00	2024-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	21032X	\N	\N	\N
18676	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21078N	\N	\N	\N
18677	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14207L	\N	\N	\N
18678	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21066J	\N	\N	\N
18690	ESNU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	14189C	\N	\N	\N
18691	ESNU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20022R	\N	\N	\N
18692	ESNU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	14030Q	\N	\N	\N
18693	ESNU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20094J	\N	\N	\N
18694	ESNU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20138D	\N	\N	\N
18695	ESNU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	19383Y	\N	\N	\N
18696	ESNU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20060X	\N	\N	\N
18697	ESNU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	14038Y	\N	\N	\N
18698	ESNU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20140W	\N	\N	\N
18699	ESNU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20134Y	\N	\N	\N
18700	ESNU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	14151M	\N	\N	\N
18701	ESNU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	19647E	\N	\N	\N
18702	ESNU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20132W	\N	\N	\N
18703	ESNU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	19387D	\N	\N	\N
18704	ESNU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	14026U	\N	\N	\N
18705	ESNU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20128B	\N	\N	\N
18706	ESNU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	14179A	\N	\N	\N
18707	ESNU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	19591F	\N	\N	\N
18708	ESNU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20034V	\N	\N	\N
18709	ESNU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20052X	\N	\N	\N
18710	ESNU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	14205J	\N	\N	\N
18711	ESNU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	14251Q	\N	\N	\N
18712	ESNU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	14147R	\N	\N	\N
18713	ESNU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	04070G	\N	\N	\N
18714	ESNU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20096L	\N	\N	\N
18715	ESNU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	19768N	\N	\N	\N
18716	ESNU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	21037D	\N	\N	\N
18717	ESNU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	19593H	\N	\N	\N
18718	ESNU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	14237S	\N	\N	\N
18719	ESNU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20082E	\N	\N	\N
18720	ESNU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	10015M	\N	\N	\N
18721	ESNU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	14229S	\N	\N	\N
18722	ESNU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	11045K	\N	\N	\N
18723	ESNU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	19687N	\N	\N	\N
18724	ESNU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20098N	\N	\N	\N
18725	ESNU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20062A	\N	\N	\N
18726	ESNU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20122U	\N	\N	\N
19599	NEANT	2024-03-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	21125C	\N	\N	\N
15648	CRISE	2020-05-27 00:00:00	2020-06-03 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
15649	CRISE	2020-05-27 00:00:00	2020-06-03 00:00:00	ANCIEN	\N	\N	\N	\N	19447X	TITULAIRE	\N	\N
15650	CRISE	2020-05-27 00:00:00	2020-06-03 00:00:00	ANCIEN	\N	\N	\N	\N	11097X	TITULAIRE	\N	\N
15651	CRISE	2020-05-27 00:00:00	2020-06-03 00:00:00	ANCIEN	\N	\N	\N	\N	14179A	TITULAIRE	\N	\N
15652	CRISE	2020-05-27 00:00:00	2020-06-03 00:00:00	ANCIEN	\N	\N	\N	\N	17779H	TITULAIRE	\N	\N
15653	CRISE	2020-05-27 00:00:00	2020-06-03 00:00:00	ANCIEN	\N	\N	\N	\N	14001X	TITULAIRE	\N	\N
15654	CRISE	2020-05-27 00:00:00	2020-06-03 00:00:00	ANCIEN	\N	\N	\N	\N	11072N	TITULAIRE	\N	\N
15655	CRISE	2020-05-27 00:00:00	2020-06-03 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	SUPPLEANT	\N	\N
15656	CRISE	2020-05-27 00:00:00	2020-06-03 00:00:00	ANCIEN	\N	\N	\N	\N	19673G	SUPPLEANT	\N	\N
15657	CRISE	2020-05-27 00:00:00	2020-06-03 00:00:00	ANCIEN	\N	\N	\N	\N	08011M	SUPPLEANT	\N	\N
15658	CRISE	2020-05-27 00:00:00	2020-06-03 00:00:00	ANCIEN	\N	\N	\N	\N	11085T	SUPPLEANT	\N	\N
15659	CRISE	2020-05-27 00:00:00	2020-06-03 00:00:00	ANCIEN	\N	\N	\N	\N	19489J	SUPPLEANT	\N	\N
15660	CRISE	2020-05-27 00:00:00	2020-06-03 00:00:00	ANCIEN	\N	\N	\N	\N	19253P	SUPPLEANT	\N	\N
15661	CRISE	2020-05-27 00:00:00	2020-06-03 00:00:00	ANCIEN	\N	\N	\N	\N	11033F	SUPPLEANT	\N	\N
15678	SORTIE	2020-06-22 00:00:00	2020-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
15679	SORTIE	2020-06-22 00:00:00	2020-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	TITULAIRE	\N	\N
15680	SORTIE	2020-06-22 00:00:00	2020-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	19673G	TITULAIRE	\N	\N
15681	SORTIE	2020-06-22 00:00:00	2020-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	14089Y	TITULAIRE	\N	\N
15682	SORTIE	2020-06-22 00:00:00	2020-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	08045X	TITULAIRE	\N	\N
15683	SORTIE	2020-06-22 00:00:00	2020-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
15684	SORTIE	2020-06-22 00:00:00	2020-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	TITULAIRE	\N	\N
15685	SORTIE	2020-06-22 00:00:00	2020-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	SUPPLEANT	\N	\N
15686	SORTIE	2020-06-22 00:00:00	2020-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	14147R	SUPPLEANT	\N	\N
15687	SORTIE	2020-06-22 00:00:00	2020-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	19762G	SUPPLEANT	\N	\N
15688	SORTIE	2020-06-22 00:00:00	2020-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	11085T	SUPPLEANT	\N	\N
15689	SORTIE	2020-06-22 00:00:00	2020-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	11026G	SUPPLEANT	\N	\N
15690	SORTIE	2020-06-22 00:00:00	2020-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	19719D	SUPPLEANT	\N	\N
15691	SORTIE	2020-06-22 00:00:00	2020-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	11033F	SUPPLEANT	\N	\N
15959	ETRD	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20042V	\N	\N	\N
15960	ETRD	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01024M	\N	\N	\N
15961	ETRD	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	17023S	\N	\N	\N
15962	SOCI	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20040T	\N	\N	\N
15963	SOCI	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20066E	\N	\N	\N
15964	SOCI	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19713W	\N	\N	\N
15965	AFCL	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20048C	\N	\N	\N
15966	AFCL	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20052X	\N	\N	\N
15967	CAE	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20144B	\N	\N	\N
15968	CAE	2020-10-06 00:00:00	2021-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	19521Q	\N	\N	\N
15969	CDD	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	17229F	\N	\N	\N
15970	CDD	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19577H	\N	\N	\N
15971	CDD	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19619A	\N	\N	\N
15972	FINC	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14189C	\N	\N	\N
15973	FINC	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19335Q	\N	\N	\N
15974	FINC	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08009T	\N	\N	\N
15975	LOIS	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	07004J	\N	\N	\N
15976	LOIS	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19749K	\N	\N	\N
15978	SOCI	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08045X	\N	\N	\N
15979	SOCI	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	18193Q	\N	\N	\N
15980	SOCI	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	17965H	\N	\N	\N
15981	CAE	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20094J	\N	\N	\N
15982	CAE	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20088L	\N	\N	\N
15983	CAE	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20060X	\N	\N	\N
15984	CAE	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20018V	\N	\N	\N
15985	CAE	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20030R	\N	\N	\N
15986	CAE	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20082E	\N	\N	\N
15987	CDD	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19251M	\N	\N	\N
15988	CDD	2020-10-06 00:00:00	2020-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	20028X	\N	\N	\N
15989	FINC	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20080C	\N	\N	\N
15990	FINC	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20070A	\N	\N	\N
15991	ETRD	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	12028B	\N	\N	\N
15992	ETRD	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20064C	\N	\N	\N
15993	AFCL	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20084G	\N	\N	\N
15994	AFCL	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19527W	\N	\N	\N
15995	FINC	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20116W	\N	\N	\N
15996	LOIS	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14107H	\N	\N	\N
15997	SOCI	2020-10-06 00:00:00	2022-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	19289C	\N	\N	\N
15998	AFCL	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19719D	\N	\N	\N
16000	ETRD	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20072C	\N	\N	\N
16001	FINC	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20050V	\N	\N	\N
16002	CAE	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14251Q	\N	\N	\N
16003	CDD	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20122U	\N	\N	\N
16004	SOCI	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04057K	\N	\N	\N
16005	AFCL	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	17589D	\N	\N	\N
16065	FINC	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20150Y	\N	\N	\N
16066	LOIS	2020-10-06 00:00:00	2021-05-24 00:00:00	ANCIEN	\N	\N	\N	\N	20016T	\N	\N	\N
16067	CAE	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14038Y	\N	\N	\N
16009	LOIS	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	\N	\N	\N
16010	LOIS	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11056N	\N	\N	\N
16011	CDD	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20102Q	\N	\N	\N
16012	CDD	2020-10-06 00:00:00	2020-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	11109J	\N	\N	\N
16013	CDD	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20046A	\N	\N	\N
16014	AFCL	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20112S	\N	\N	\N
16015	ETRD	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19565D	\N	\N	\N
16016	LOIS	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20110Q	\N	\N	\N
16017	SOCI	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20130U	\N	\N	\N
16018	FINC	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20036X	\N	\N	\N
16019	AFCL	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20142Y	\N	\N	\N
16020	AFCL	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20134Y	\N	\N	\N
16021	CAE	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20092G	\N	\N	\N
16022	CDD	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20100N	\N	\N	\N
16023	ETRD	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08069G	\N	\N	\N
16024	ETRD	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	95041E	\N	\N	\N
16025	ETRD	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14059S	\N	\N	\N
16026	ETRD	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14191V	\N	\N	\N
16027	FINC	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20126Y	\N	\N	\N
16028	FINC	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20044X	\N	\N	\N
16029	LOIS	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	17737W	\N	\N	\N
16030	LOIS	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20074E	\N	\N	\N
16031	LOIS	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20108W	\N	\N	\N
16032	AFCL	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20138D	\N	\N	\N
16033	AFCL	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20152B	\N	\N	\N
16034	AFCL	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20124W	\N	\N	\N
16035	AFCL	2020-10-06 00:00:00	2020-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	20120S	\N	\N	\N
16036	AFCL	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20056C	\N	\N	\N
16037	AFCL	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20098N	\N	\N	\N
16038	AFCL	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20026V	\N	\N	\N
16039	AFCL	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20058E	\N	\N	\N
16040	CAE	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19575F	\N	\N	\N
16041	CAE	2020-10-06 00:00:00	2021-09-08 00:00:00	ANCIEN	\N	\N	\N	\N	20086J	\N	\N	\N
16042	CAE	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20078J	\N	\N	\N
16043	CAE	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19383Y	\N	\N	\N
16044	CAE	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20104S	\N	\N	\N
16045	CAE	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20034V	\N	\N	\N
16046	CAE	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20054A	\N	\N	\N
16047	CAE	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20062A	\N	\N	\N
16048	SOCI	2020-10-06 00:00:00	2021-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	19966S	\N	\N	\N
16049	SOCI	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20090E	\N	\N	\N
16050	SOCI	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20148F	\N	\N	\N
16051	SOCI	2020-10-06 00:00:00	2020-10-31 00:00:00	ANCIEN	\N	\N	\N	\N	17583W	\N	\N	\N
16052	CDD	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20032T	\N	\N	\N
16053	CDD	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20076G	\N	\N	\N
16054	CDD	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20024T	\N	\N	\N
16055	CDD	2020-10-06 00:00:00	2020-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	20022R	\N	\N	\N
16056	CDD	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	17367Q	\N	\N	\N
16057	CDD	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11101A	\N	\N	\N
16058	CDD	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20140W	\N	\N	\N
16059	CDD	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20038A	\N	\N	\N
16060	CDD	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20068G	\N	\N	\N
16061	CDD	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20096L	\N	\N	\N
16062	CDD	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20118Y	\N	\N	\N
16063	CDD	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20020P	\N	\N	\N
16064	CDD	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20136B	\N	\N	\N
16068	SOCI	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19295A	\N	\N	\N
16069	CAE	2020-10-06 00:00:00	2020-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	14037X	\N	\N	\N
16070	CAE	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20028X	\N	\N	\N
16071	SOCI	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04043D	\N	\N	\N
16073	NEANT	2020-10-06 00:00:00	2020-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	14055N	\N	\N	\N
16074	NEANT	2020-10-06 00:00:00	2020-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	19685L	\N	\N	\N
16075	ETRD	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19347U	\N	\N	\N
16076	CDD	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20106U	\N	\N	\N
16077	CDD	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20146D	\N	\N	\N
16078	AFCL	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19651A	\N	\N	\N
16079	ETRD	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11083R	\N	\N	\N
16080	AFCL	2020-10-06 00:00:00	2021-05-24 00:00:00	ANCIEN	\N	\N	\N	\N	08061X	\N	\N	\N
15977	LOIS	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20114U	\N	\N	\N
15695	NEANT	2020-06-28 00:00:00	2020-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	19930E	\N	\N	\N
15820	NEANT	2020-07-14 00:00:00	2020-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	19954N	\N	\N	\N
19102	TOTA	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	19954N	\N	\N	\N
19103	TOTA	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	21090J	\N	\N	\N
19104	TOTA	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	20038A	\N	\N	\N
19105	TOTA	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	99004R	\N	\N	\N
19106	TOTA	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	08034U	\N	\N	\N
19107	TOTA	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	14031R	\N	\N	\N
19108	TOTA	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	11090Q	\N	\N	\N
19109	TOTA	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	21050A	\N	\N	\N
19110	TOTA	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	20248J	\N	\N	\N
19111	TOTA	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	17023S	\N	\N	\N
19112	TOTA	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	21056G	\N	\N	\N
19113	TOTA	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	19413M	\N	\N	\N
19114	TOTA	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	21031W	\N	\N	\N
19115	TOTA	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	21082J	\N	\N	\N
19116	TOTA	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	19782L	\N	\N	\N
19117	TOTA	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	21066J	\N	\N	\N
19118	TOTA	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	21084L	\N	\N	\N
19119	TOTA	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	14221J	\N	\N	\N
19120	TOTA	2023-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	21093M	\N	\N	\N
16081	ETRD	2020-10-06 00:00:00	2021-05-24 00:00:00	ANCIEN	\N	\N	\N	\N	20128B	\N	\N	\N
16082	ETRD	2020-10-06 00:00:00	2020-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	19265T	\N	\N	\N
16145	AFEU	2020-10-20 00:00:00	2021-06-02 00:00:00	ANCIEN	\N	\N	\N	\N	19251M	\N	\N	\N
16950	NEANT	2021-07-06 00:00:00	2021-07-14 00:00:00	ANCIEN	\N	\N	\N	\N	20248J	\N	\N	\N
17185	NEANT	2023-01-01 00:00:00	2023-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	20980G	\N	\N	\N
17272	AVENCOMM	2023-01-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	20036X	\N	\N	\N
18108	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19699S	\N	\N	\N
18109	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21079P	\N	\N	\N
18111	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19347U	\N	\N	\N
18331	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14055N	\N	\N	\N
18332	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21085M	\N	\N	\N
16928	INFLUENCES	2021-06-30 00:00:00	2021-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	17367Q	\N	\N	\N
16929	INFLUENCES	2021-06-30 00:00:00	2021-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	19621T	\N	\N	\N
16930	INFLUENCES	2021-06-30 00:00:00	2021-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	97011G	\N	\N	\N
16931	INFLUENCES	2021-06-30 00:00:00	2021-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	20180F	\N	\N	\N
16932	INFLUENCES	2021-06-30 00:00:00	2021-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	04035D	\N	\N	\N
16933	INFLUENCES	2021-06-30 00:00:00	2021-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	19709B	\N	\N	\N
16934	INFLUENCES	2021-06-30 00:00:00	2021-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	19533U	\N	\N	\N
16935	INFLUENCES	2021-06-30 00:00:00	2021-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	11115U	\N	\N	\N
16936	INFLUENCES	2021-06-30 00:00:00	2021-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	14255U	\N	\N	\N
16937	INFLUENCES	2021-06-30 00:00:00	2021-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	07004J	\N	\N	\N
16938	INFLUENCES	2021-06-30 00:00:00	2021-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	20048C	\N	\N	\N
16939	INFLUENCES	2021-06-30 00:00:00	2021-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	19369B	\N	\N	\N
16940	INFLUENCES	2021-06-30 00:00:00	2021-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	20080C	\N	\N	\N
16941	INFLUENCES	2021-06-30 00:00:00	2021-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	19333N	\N	\N	\N
16942	INFLUENCES	2021-06-30 00:00:00	2021-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	11026G	\N	\N	\N
16943	INFLUENCES	2021-06-30 00:00:00	2021-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	20082E	\N	\N	\N
16944	INFLUENCES	2021-06-30 00:00:00	2021-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	11083R	\N	\N	\N
16945	INFLUENCES	2021-06-30 00:00:00	2021-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	20132W	\N	\N	\N
16946	INFLUENCES	2021-06-30 00:00:00	2021-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	19593H	\N	\N	\N
16947	INFLUENCES	2021-06-30 00:00:00	2021-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	20050V	\N	\N	\N
16948	INFLUENCES	2021-06-30 00:00:00	2021-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	20134Y	\N	\N	\N
16951	SOCI	2021-07-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20248J	\N	\N	\N
18041	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21056G	\N	\N	\N
18042	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19619A	\N	\N	\N
18043	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19621T	\N	\N	\N
18044	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	11110B	\N	\N	\N
18110	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19295A	\N	\N	\N
18112	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	11043H	\N	\N	\N
18113	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19679N	\N	\N	\N
18114	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21080G	\N	\N	\N
18115	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19349W	\N	\N	\N
15677	NEANT	2020-06-18 00:00:00	2020-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	19914E	\N	\N	\N
16208	NEANT	2020-11-02 00:00:00	2020-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	20174H	\N	\N	\N
17176	NEANT	2022-07-04 00:00:00	2022-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	20914V	\N	\N	\N
17529	NUCLEAIRE	2023-04-20 00:00:00	2023-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	11090Q	TITULAIRE	\N	\N
17530	NUCLEAIRE	2023-04-20 00:00:00	2023-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	14033T	TITULAIRE	\N	\N
17531	NUCLEAIRE	2023-04-20 00:00:00	2023-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	14031R	TITULAIRE	\N	\N
17532	NUCLEAIRE	2023-04-20 00:00:00	2023-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	19369B	TITULAIRE	\N	\N
17533	NUCLEAIRE	2023-04-20 00:00:00	2023-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	19251M	TITULAIRE	\N	\N
17534	NUCLEAIRE	2023-04-20 00:00:00	2023-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	14257W	TITULAIRE	\N	\N
17535	NUCLEAIRE	2023-04-20 00:00:00	2023-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	19782L	TITULAIRE	\N	\N
17536	NUCLEAIRE	2023-04-20 00:00:00	2023-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	20062A	SUPPLEANT	\N	\N
17537	NUCLEAIRE	2023-04-20 00:00:00	2023-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	19515S	SUPPLEANT	\N	\N
17538	NUCLEAIRE	2023-04-20 00:00:00	2023-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	20054A	SUPPLEANT	\N	\N
17539	NUCLEAIRE	2023-04-20 00:00:00	2023-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	20286Q	SUPPLEANT	\N	\N
17540	NUCLEAIRE	2023-04-20 00:00:00	2023-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	20018V	SUPPLEANT	\N	\N
17541	NUCLEAIRE	2023-04-20 00:00:00	2023-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	19681G	SUPPLEANT	\N	\N
17542	NUCLEAIRE	2023-04-20 00:00:00	2023-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	19695N	SUPPLEANT	\N	\N
17608	PLPM	2023-07-10 00:00:00	2023-07-10 00:00:00	ANCIEN	\N	\N	\N	\N	08047A	SUPPLEANT	\N	\N
17609	PLPM	2023-07-10 00:00:00	2023-07-10 00:00:00	ANCIEN	\N	\N	\N	\N	08034U	SUPPLEANT	\N	\N
17610	PLPM	2023-07-10 00:00:00	2023-07-10 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	SUPPLEANT	\N	\N
17611	PLPM	2023-07-10 00:00:00	2023-07-10 00:00:00	ANCIEN	\N	\N	\N	\N	14083S	SUPPLEANT	\N	\N
17612	PLPM	2023-07-10 00:00:00	2023-07-10 00:00:00	ANCIEN	\N	\N	\N	\N	11066Q	SUPPLEANT	\N	\N
17613	PLPM	2023-07-10 00:00:00	2023-07-10 00:00:00	ANCIEN	\N	\N	\N	\N	20072C	SUPPLEANT	\N	\N
17614	PLPM	2023-07-10 00:00:00	2023-07-10 00:00:00	ANCIEN	\N	\N	\N	\N	12041X	SUPPLEANT	\N	\N
17615	PLPM	2023-07-10 00:00:00	2023-07-10 00:00:00	ANCIEN	\N	\N	\N	\N	14133K	TITULAIRE	\N	\N
17616	PLPM	2023-07-10 00:00:00	2023-07-10 00:00:00	ANCIEN	\N	\N	\N	\N	04042C	TITULAIRE	\N	\N
17617	PLPM	2023-07-10 00:00:00	2023-07-10 00:00:00	ANCIEN	\N	\N	\N	\N	14193X	TITULAIRE	\N	\N
17618	PLPM	2023-07-10 00:00:00	2023-07-10 00:00:00	ANCIEN	\N	\N	\N	\N	14267Y	TITULAIRE	\N	\N
17619	PLPM	2023-07-10 00:00:00	2023-07-10 00:00:00	ANCIEN	\N	\N	\N	\N	19669L	TITULAIRE	\N	\N
17620	PLPM	2023-07-10 00:00:00	2023-07-10 00:00:00	ANCIEN	\N	\N	\N	\N	01062T	TITULAIRE	\N	\N
17621	PLPM	2023-07-10 00:00:00	2023-07-10 00:00:00	ANCIEN	\N	\N	\N	\N	20128B	TITULAIRE	\N	\N
17632	PZAN	2023-07-06 00:00:00	2023-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	20108W	SUPPLEANT	\N	\N
17630	PZAN	2023-07-06 00:00:00	2023-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	19383Y	SUPPLEANT	\N	\N
17631	PZAN	2023-07-06 00:00:00	2023-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	19399H	SUPPLEANT	\N	\N
17633	PZAN	2023-07-06 00:00:00	2023-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	14219Q	SUPPLEANT	\N	\N
17634	PZAN	2023-07-06 00:00:00	2023-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	19631V	SUPPLEANT	\N	\N
17635	PZAN	2023-07-06 00:00:00	2023-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	19681G	SUPPLEANT	\N	\N
17636	PZAN	2023-07-06 00:00:00	2023-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	11056N	SUPPLEANT	\N	\N
17637	PZAN	2023-07-06 00:00:00	2023-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	01043Q	TITULAIRE	\N	\N
17638	PZAN	2023-07-06 00:00:00	2023-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	20086J	TITULAIRE	\N	\N
17639	PZAN	2023-07-06 00:00:00	2023-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	20032T	TITULAIRE	\N	\N
17640	PZAN	2023-07-06 00:00:00	2023-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	20120S	TITULAIRE	\N	\N
17641	PZAN	2023-07-06 00:00:00	2023-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	19489J	TITULAIRE	\N	\N
17642	PZAN	2023-07-06 00:00:00	2023-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	20082E	TITULAIRE	\N	\N
17643	PZAN	2023-07-06 00:00:00	2023-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	19525U	TITULAIRE	\N	\N
17644	PCMF	2023-06-28 00:00:00	2023-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	20044X	SUPPLEANT	\N	\N
17645	PCMF	2023-06-28 00:00:00	2023-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	19711U	SUPPLEANT	\N	\N
17646	PCMF	2023-06-28 00:00:00	2023-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	19667J	SUPPLEANT	\N	\N
17647	PCMF	2023-06-28 00:00:00	2023-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	14083S	SUPPLEANT	\N	\N
17648	PCMF	2023-06-28 00:00:00	2023-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	19647E	SUPPLEANT	\N	\N
17649	PCMF	2023-06-28 00:00:00	2023-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	11012A	SUPPLEANT	\N	\N
17650	PCMF	2023-06-28 00:00:00	2023-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	19687N	SUPPLEANT	\N	\N
17651	PCMF	2023-06-28 00:00:00	2023-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	14225N	TITULAIRE	\N	\N
17652	PCMF	2023-06-28 00:00:00	2023-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	08009T	TITULAIRE	\N	\N
17653	PCMF	2023-06-28 00:00:00	2023-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	TITULAIRE	\N	\N
17654	PCMF	2023-06-28 00:00:00	2023-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	08011M	TITULAIRE	\N	\N
17655	PCMF	2023-06-28 00:00:00	2023-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	19741B	TITULAIRE	\N	\N
17656	PCMF	2023-06-28 00:00:00	2023-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	20070A	TITULAIRE	\N	\N
17657	PCMF	2023-06-28 00:00:00	2023-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	TITULAIRE	\N	\N
17658	DOUA	2023-06-28 00:00:00	2023-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	19741B	SUPPLEANT	\N	\N
17659	DOUA	2023-06-28 00:00:00	2023-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	20044X	SUPPLEANT	\N	\N
17660	DOUA	2023-06-28 00:00:00	2023-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	14053L	SUPPLEANT	\N	\N
17661	DOUA	2023-06-28 00:00:00	2023-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	19479G	SUPPLEANT	\N	\N
17662	DOUA	2023-06-28 00:00:00	2023-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	19647E	SUPPLEANT	\N	\N
17663	DOUA	2023-06-28 00:00:00	2023-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	20116W	SUPPLEANT	\N	\N
17664	DOUA	2023-06-28 00:00:00	2023-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	19687N	SUPPLEANT	\N	\N
17665	DOUA	2023-06-28 00:00:00	2023-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	14225N	TITULAIRE	\N	\N
17666	DOUA	2023-06-28 00:00:00	2023-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	08011M	TITULAIRE	\N	\N
17667	DOUA	2023-06-28 00:00:00	2023-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	TITULAIRE	\N	\N
17668	DOUA	2023-06-28 00:00:00	2023-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
17669	DOUA	2023-06-28 00:00:00	2023-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	14083S	TITULAIRE	\N	\N
17670	DOUA	2023-06-28 00:00:00	2023-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	20070A	TITULAIRE	\N	\N
17671	DOUA	2023-06-28 00:00:00	2023-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	TITULAIRE	\N	\N
17672	PAFP	2023-06-28 00:00:00	2023-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	19447X	SUPPLEANT	\N	\N
17673	PAFP	2023-06-28 00:00:00	2023-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	14053L	SUPPLEANT	\N	\N
17674	PAFP	2023-06-28 00:00:00	2023-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	14147R	SUPPLEANT	\N	\N
17675	PAFP	2023-06-28 00:00:00	2023-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	14030Q	SUPPLEANT	\N	\N
17676	PAFP	2023-06-28 00:00:00	2023-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	20114U	SUPPLEANT	\N	\N
17677	PAFP	2023-06-28 00:00:00	2023-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	14107H	SUPPLEANT	\N	\N
17678	PAFP	2023-06-28 00:00:00	2023-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	11056N	SUPPLEANT	\N	\N
17679	EHAI	2023-06-20 00:00:00	2023-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	19611R	TITULAIRE	\N	\N
17680	EHAI	2023-06-20 00:00:00	2023-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	19643A	SUPPLEANT	\N	\N
17681	EHAI	2023-06-20 00:00:00	2023-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	20058E	SUPPLEANT	\N	\N
17682	EHAI	2023-06-20 00:00:00	2023-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	20180F	SUPPLEANT	\N	\N
17683	EHAI	2023-06-20 00:00:00	2023-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	14030Q	SUPPLEANT	\N	\N
17684	EHAI	2023-06-20 00:00:00	2023-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	08012N	SUPPLEANT	\N	\N
17685	EHAI	2023-06-20 00:00:00	2023-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	20132W	SUPPLEANT	\N	\N
17686	EHAI	2023-06-20 00:00:00	2023-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	20112S	SUPPLEANT	\N	\N
17687	EHAI	2023-06-20 00:00:00	2023-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	20138D	TITULAIRE	\N	\N
17688	EHAI	2023-06-20 00:00:00	2023-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	20152B	TITULAIRE	\N	\N
17689	EHAI	2023-06-20 00:00:00	2023-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	20098N	TITULAIRE	\N	\N
17690	EHAI	2023-06-20 00:00:00	2023-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	04059M	TITULAIRE	\N	\N
17691	EHAI	2023-06-20 00:00:00	2023-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	19527W	TITULAIRE	\N	\N
17692	EHAI	2023-06-20 00:00:00	2023-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	19651A	TITULAIRE	\N	\N
17693	INCE	2023-06-19 00:00:00	2023-06-19 00:00:00	ANCIEN	\N	\N	\N	\N	20024T	SUPPLEANT	\N	\N
17694	INCE	2023-06-19 00:00:00	2023-06-19 00:00:00	ANCIEN	\N	\N	\N	\N	20056C	SUPPLEANT	\N	\N
17695	INCE	2023-06-19 00:00:00	2023-06-19 00:00:00	ANCIEN	\N	\N	\N	\N	20026V	SUPPLEANT	\N	\N
17696	INCE	2023-06-19 00:00:00	2023-06-19 00:00:00	ANCIEN	\N	\N	\N	\N	14205J	SUPPLEANT	\N	\N
17697	INCE	2023-06-19 00:00:00	2023-06-19 00:00:00	ANCIEN	\N	\N	\N	\N	20114U	SUPPLEANT	\N	\N
17698	INCE	2023-06-19 00:00:00	2023-06-19 00:00:00	ANCIEN	\N	\N	\N	\N	19719D	SUPPLEANT	\N	\N
17699	INCE	2023-06-19 00:00:00	2023-06-19 00:00:00	ANCIEN	\N	\N	\N	\N	20046A	SUPPLEANT	\N	\N
17700	INCE	2023-06-19 00:00:00	2023-06-19 00:00:00	ANCIEN	\N	\N	\N	\N	20076G	TITULAIRE	\N	\N
17701	INCE	2023-06-19 00:00:00	2023-06-19 00:00:00	ANCIEN	\N	\N	\N	\N	20054A	TITULAIRE	\N	\N
17702	INCE	2023-06-19 00:00:00	2023-06-19 00:00:00	ANCIEN	\N	\N	\N	\N	19826F	TITULAIRE	\N	\N
17703	INCE	2023-06-19 00:00:00	2023-06-19 00:00:00	ANCIEN	\N	\N	\N	\N	19725B	TITULAIRE	\N	\N
17704	INCE	2023-06-19 00:00:00	2023-06-19 00:00:00	ANCIEN	\N	\N	\N	\N	14097Y	TITULAIRE	\N	\N
17705	INCE	2023-06-19 00:00:00	2023-06-19 00:00:00	ANCIEN	\N	\N	\N	\N	04045F	TITULAIRE	\N	\N
17706	INCE	2023-06-19 00:00:00	2023-06-19 00:00:00	ANCIEN	\N	\N	\N	\N	20090E	TITULAIRE	\N	\N
18153	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19820Y	\N	\N	\N
18154	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20120S	\N	\N	\N
18155	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20024T	\N	\N	\N
18156	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19826F	\N	\N	\N
18157	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14237S	\N	\N	\N
18158	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14221J	\N	\N	\N
18159	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20046A	\N	\N	\N
18160	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	05012A	\N	\N	\N
18161	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	08060W	\N	\N	\N
18162	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14031R	\N	\N	\N
18163	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14219Q	\N	\N	\N
18164	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20146D	\N	\N	\N
16219	NEANT	2020-12-02 00:00:00	2020-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	20178M	\N	\N	\N
15888	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20036X	\N	\N	\N
15889	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	14189C	\N	\N	\N
15892	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20042V	\N	\N	\N
15893	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	14037X	\N	\N	\N
15896	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20048C	\N	\N	\N
15897	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20050V	\N	\N	\N
15899	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20054A	\N	\N	\N
15901	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20058E	\N	\N	\N
15905	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20064C	\N	\N	\N
15907	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20068G	\N	\N	\N
15913	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	17023S	\N	\N	\N
15916	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20084G	\N	\N	\N
15917	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20086J	\N	\N	\N
15921	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20094J	\N	\N	\N
15925	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20102Q	\N	\N	\N
15926	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	18193Q	\N	\N	\N
15927	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20104S	\N	\N	\N
10886	2015CMP1	2015-01-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08014Q	SUPPLEANT	2015-01-28 16:37:16	2015-01-28 16:37:22
15928	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20106U	\N	\N	\N
15936	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	19265T	\N	\N	\N
15937	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20118Y	\N	\N	\N
15940	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20124W	\N	\N	\N
15941	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20126Y	\N	\N	\N
15942	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20128B	\N	\N	\N
8452	2012CMP3	2012-01-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	\N	\N
9015	2012CMP21	2012-11-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	\N	\N
9087	2012CMP25	2012-12-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	\N	\N
9555	2013CMP18	2013-10-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	\N	\N
10232	AFEU	2014-10-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14079W	\N	2014-10-09 09:39:31	2017-10-05 14:39:30
11605	2015CMP17	2015-07-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04040A	TITULAIRE	\N	\N
11641	2015CMP19	2015-09-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14079W	SUPPLEANT	\N	\N
12032	MINEURS	2016-03-02 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	TITULAIRE	2016-03-11 11:50:09	\N
17820	ACCI	2023-07-06 00:00:00	2023-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	14026U	SUPPLEANT	\N	\N
17821	ACCI	2023-07-06 00:00:00	2023-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	19679N	SUPPLEANT	\N	\N
17822	ACCI	2023-07-06 00:00:00	2023-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	14223L	SUPPLEANT	\N	\N
17823	ACCI	2023-07-06 00:00:00	2023-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	20040T	SUPPLEANT	\N	\N
17824	ACCI	2023-07-06 00:00:00	2023-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	19683J	SUPPLEANT	\N	\N
17825	ACCI	2023-07-06 00:00:00	2023-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	19553Y	SUPPLEANT	\N	\N
17826	ACCI	2023-07-06 00:00:00	2023-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	19760E	SUPPLEANT	\N	\N
17827	ACCI	2023-07-06 00:00:00	2023-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	10006L	TITULAIRE	\N	\N
17828	ACCI	2023-07-06 00:00:00	2023-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	19798U	TITULAIRE	\N	\N
17829	ACCI	2023-07-06 00:00:00	2023-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	14213J	TITULAIRE	\N	\N
17830	ACCI	2023-07-06 00:00:00	2023-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	20248J	TITULAIRE	\N	\N
17831	ACCI	2023-07-06 00:00:00	2023-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	18193Q	TITULAIRE	\N	\N
17832	ACCI	2023-07-06 00:00:00	2023-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	17965H	TITULAIRE	\N	\N
17833	ACCI	2023-07-06 00:00:00	2023-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	19591F	TITULAIRE	\N	\N
17834	RENO	2023-03-09 00:00:00	2023-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	19954N	SUPPLEANT	\N	\N
17835	RENO	2023-03-09 00:00:00	2023-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	08018U	SUPPLEANT	\N	\N
17836	RENO	2023-03-09 00:00:00	2023-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	14147R	SUPPLEANT	\N	\N
17837	RENO	2023-03-09 00:00:00	2023-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	11085T	SUPPLEANT	\N	\N
17838	RENO	2023-03-09 00:00:00	2023-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	14151M	SUPPLEANT	\N	\N
17839	RENO	2023-03-09 00:00:00	2023-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	19629C	SUPPLEANT	\N	\N
17840	RENO	2023-03-09 00:00:00	2023-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	11056N	SUPPLEANT	\N	\N
17841	RENO	2023-03-09 00:00:00	2023-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
17842	RENO	2023-03-09 00:00:00	2023-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	19673G	TITULAIRE	\N	\N
17843	RENO	2023-03-09 00:00:00	2023-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	TITULAIRE	\N	\N
17844	RENO	2023-03-09 00:00:00	2023-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	14179A	TITULAIRE	\N	\N
17845	RENO	2023-03-09 00:00:00	2023-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	20114U	TITULAIRE	\N	\N
17846	RENO	2023-03-09 00:00:00	2023-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	11026G	TITULAIRE	\N	\N
17847	RENO	2023-03-09 00:00:00	2023-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	TITULAIRE	\N	\N
17848	DADU	2023-02-09 00:00:00	2023-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	14217N	SUPPLEANT	\N	\N
17849	DADU	2023-02-09 00:00:00	2023-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	14237S	SUPPLEANT	\N	\N
17850	DADU	2023-02-09 00:00:00	2023-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	14331P	SUPPLEANT	\N	\N
17851	DADU	2023-02-09 00:00:00	2023-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	14083S	SUPPLEANT	\N	\N
17852	DADU	2023-02-09 00:00:00	2023-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	17779H	SUPPLEANT	\N	\N
17853	DADU	2023-02-09 00:00:00	2023-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	19717B	SUPPLEANT	\N	\N
17854	DADU	2023-02-09 00:00:00	2023-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	19760E	SUPPLEANT	\N	\N
17855	DADU	2023-02-09 00:00:00	2023-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	10006L	TITULAIRE	\N	\N
17856	DADU	2023-02-09 00:00:00	2023-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	14026U	TITULAIRE	\N	\N
17857	DADU	2023-02-09 00:00:00	2023-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	19507S	TITULAIRE	\N	\N
17858	DADU	2023-02-09 00:00:00	2023-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	08009T	TITULAIRE	\N	\N
17859	DADU	2023-02-09 00:00:00	2023-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	14001X	TITULAIRE	\N	\N
17860	DADU	2023-02-09 00:00:00	2023-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	14281W	TITULAIRE	\N	\N
17861	DADU	2023-02-09 00:00:00	2023-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	14249W	TITULAIRE	\N	\N
17862	PENR	2023-01-24 00:00:00	2023-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	18083K	SUPPLEANT	\N	\N
17863	PENR	2023-01-24 00:00:00	2023-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	20136B	SUPPLEANT	\N	\N
17864	PENR	2023-01-24 00:00:00	2023-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	14033T	SUPPLEANT	\N	\N
17865	PENR	2023-01-24 00:00:00	2023-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	14219Q	SUPPLEANT	\N	\N
17866	PENR	2023-01-24 00:00:00	2023-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	19599P	SUPPLEANT	\N	\N
17867	PENR	2023-01-24 00:00:00	2023-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	19681G	SUPPLEANT	\N	\N
17868	PENR	2023-01-24 00:00:00	2023-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	20046A	SUPPLEANT	\N	\N
17869	PENR	2023-01-24 00:00:00	2023-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	14031R	TITULAIRE	\N	\N
17870	PENR	2023-01-24 00:00:00	2023-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	11090Q	TITULAIRE	\N	\N
17871	PENR	2023-01-24 00:00:00	2023-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	20172F	TITULAIRE	\N	\N
17872	PENR	2023-01-24 00:00:00	2023-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	20144B	TITULAIRE	\N	\N
17873	PENR	2023-01-24 00:00:00	2023-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	14257W	TITULAIRE	\N	\N
17874	PENR	2023-01-24 00:00:00	2023-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	19820Y	TITULAIRE	\N	\N
17875	PENR	2023-01-24 00:00:00	2023-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	20106U	TITULAIRE	\N	\N
17876	FIPU	2022-12-15 00:00:00	2022-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	99004R	SUPPLEANT	\N	\N
17877	FIPU	2022-12-15 00:00:00	2022-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	19667J	SUPPLEANT	\N	\N
17878	FIPU	2022-12-15 00:00:00	2022-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	19741B	SUPPLEANT	\N	\N
17879	FIPU	2022-12-15 00:00:00	2022-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	11070L	SUPPLEANT	\N	\N
17880	FIPU	2022-12-15 00:00:00	2022-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	20070A	SUPPLEANT	\N	\N
17881	FIPU	2022-12-15 00:00:00	2022-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	19687N	SUPPLEANT	\N	\N
17882	FIPU	2022-12-15 00:00:00	2022-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	11012A	SUPPLEANT	\N	\N
17883	FIPU	2022-12-15 00:00:00	2022-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	14225N	TITULAIRE	\N	\N
17884	FIPU	2022-12-15 00:00:00	2022-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	TITULAIRE	\N	\N
17885	FIPU	2022-12-15 00:00:00	2022-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	20044X	TITULAIRE	\N	\N
17886	FIPU	2022-12-15 00:00:00	2022-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	08034U	TITULAIRE	\N	\N
17887	FIPU	2022-12-15 00:00:00	2022-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	14083S	TITULAIRE	\N	\N
17888	FIPU	2022-12-15 00:00:00	2022-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	20080C	TITULAIRE	\N	\N
17889	FIPU	2022-12-15 00:00:00	2022-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	19349W	TITULAIRE	\N	\N
17890	PLF23	2022-12-06 00:00:00	2022-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	20044X	SUPPLEANT	\N	\N
17891	PLF23	2022-12-06 00:00:00	2022-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	20086J	SUPPLEANT	\N	\N
17892	PLF23	2022-12-06 00:00:00	2022-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	08010L	SUPPLEANT	\N	\N
17893	PLF23	2022-12-06 00:00:00	2022-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	14327T	SUPPLEANT	\N	\N
17894	PLF23	2022-12-06 00:00:00	2022-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	20080C	SUPPLEANT	\N	\N
17895	PLF23	2022-12-06 00:00:00	2022-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	19687N	SUPPLEANT	\N	\N
17896	PLF23	2022-12-06 00:00:00	2022-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	11012A	SUPPLEANT	\N	\N
17897	PLF23	2022-12-06 00:00:00	2022-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	14225N	TITULAIRE	\N	\N
17898	PLF23	2022-12-06 00:00:00	2022-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	TITULAIRE	\N	\N
17899	PLF23	2022-12-06 00:00:00	2022-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	19711U	TITULAIRE	\N	\N
17900	PLF23	2022-12-06 00:00:00	2022-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	19741B	TITULAIRE	\N	\N
17901	PLF23	2022-12-06 00:00:00	2022-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	19479G	TITULAIRE	\N	\N
17902	PLF23	2022-12-06 00:00:00	2022-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	19647E	TITULAIRE	\N	\N
17903	PLF23	2022-12-06 00:00:00	2022-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	19349W	TITULAIRE	\N	\N
17904	OPMI	2022-12-01 00:00:00	2022-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	SUPPLEANT	\N	\N
17905	OPMI	2022-12-01 00:00:00	2022-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	20022R	SUPPLEANT	\N	\N
15568	CAE	2020-03-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19866P	\N	\N	\N
15696	SOCI	2020-06-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19926J	\N	\N	\N
17707	ENFA	2023-06-01 00:00:00	2023-06-01 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	SUPPLEANT	\N	\N
17708	ENFA	2023-06-01 00:00:00	2023-06-01 00:00:00	ANCIEN	\N	\N	\N	\N	14069U	SUPPLEANT	\N	\N
17709	ENFA	2023-06-01 00:00:00	2023-06-01 00:00:00	ANCIEN	\N	\N	\N	\N	19673G	SUPPLEANT	\N	\N
17710	ENFA	2023-06-01 00:00:00	2023-06-01 00:00:00	ANCIEN	\N	\N	\N	\N	11085T	SUPPLEANT	\N	\N
17711	ENFA	2023-06-01 00:00:00	2023-06-01 00:00:00	ANCIEN	\N	\N	\N	\N	14151M	SUPPLEANT	\N	\N
17712	ENFA	2023-06-01 00:00:00	2023-06-01 00:00:00	ANCIEN	\N	\N	\N	\N	19629C	SUPPLEANT	\N	\N
17713	ENFA	2023-06-01 00:00:00	2023-06-01 00:00:00	ANCIEN	\N	\N	\N	\N	11056N	SUPPLEANT	\N	\N
17714	ENFA	2023-06-01 00:00:00	2023-06-01 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
17715	ENFA	2023-06-01 00:00:00	2023-06-01 00:00:00	ANCIEN	\N	\N	\N	\N	17737W	TITULAIRE	\N	\N
17716	ENFA	2023-06-01 00:00:00	2023-06-01 00:00:00	ANCIEN	\N	\N	\N	\N	19581D	TITULAIRE	\N	\N
17717	ENFA	2023-06-01 00:00:00	2023-06-01 00:00:00	ANCIEN	\N	\N	\N	\N	19749K	TITULAIRE	\N	\N
17718	ENFA	2023-06-01 00:00:00	2023-06-01 00:00:00	ANCIEN	\N	\N	\N	\N	19649G	TITULAIRE	\N	\N
17719	ENFA	2023-06-01 00:00:00	2023-06-01 00:00:00	ANCIEN	\N	\N	\N	\N	20114U	TITULAIRE	\N	\N
17720	ENFA	2023-06-01 00:00:00	2023-06-01 00:00:00	ANCIEN	\N	\N	\N	\N	04045F	TITULAIRE	\N	\N
17735	INFL	2023-05-25 00:00:00	2023-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	19747H	SUPPLEANT	\N	\N
17736	INFL	2023-05-25 00:00:00	2023-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	14329V	SUPPLEANT	\N	\N
17737	INFL	2023-05-25 00:00:00	2023-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	19768N	SUPPLEANT	\N	\N
17738	INFL	2023-05-25 00:00:00	2023-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	14205J	SUPPLEANT	\N	\N
17739	INFL	2023-05-25 00:00:00	2023-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	14257W	SUPPLEANT	\N	\N
17740	INFL	2023-05-25 00:00:00	2023-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	14207L	SUPPLEANT	\N	\N
17741	INFL	2023-05-25 00:00:00	2023-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	19695N	SUPPLEANT	\N	\N
17742	INFL	2023-05-25 00:00:00	2023-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	11090Q	TITULAIRE	\N	\N
17743	INFL	2023-05-25 00:00:00	2023-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	20286Q	TITULAIRE	\N	\N
17744	INFL	2023-05-25 00:00:00	2023-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	20062A	TITULAIRE	\N	\N
17745	INFL	2023-05-25 00:00:00	2023-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	20034V	TITULAIRE	\N	\N
17746	INFL	2023-05-25 00:00:00	2023-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	20094J	TITULAIRE	\N	\N
17747	INFL	2023-05-25 00:00:00	2023-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	20060X	TITULAIRE	\N	\N
17748	INFL	2023-05-25 00:00:00	2023-05-25 00:00:00	ANCIEN	\N	\N	\N	\N	14037X	TITULAIRE	\N	\N
17749	INTE	2023-05-04 00:00:00	2023-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	14026U	SUPPLEANT	\N	\N
17750	INTE	2023-05-04 00:00:00	2023-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	14213J	SUPPLEANT	\N	\N
17751	INTE	2023-05-04 00:00:00	2023-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	SUPPLEANT	\N	\N
17752	INTE	2023-05-04 00:00:00	2023-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	20040T	SUPPLEANT	\N	\N
17753	INTE	2023-05-04 00:00:00	2023-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	17965H	SUPPLEANT	\N	\N
17754	INTE	2023-05-04 00:00:00	2023-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	19553Y	SUPPLEANT	\N	\N
17755	INTE	2023-05-04 00:00:00	2023-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	11031D	SUPPLEANT	\N	\N
17756	INTE	2023-05-04 00:00:00	2023-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	14217N	TITULAIRE	\N	\N
17757	INTE	2023-05-04 00:00:00	2023-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	19697Q	TITULAIRE	\N	\N
17758	INTE	2023-05-04 00:00:00	2023-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	19663E	TITULAIRE	\N	\N
17759	INTE	2023-05-04 00:00:00	2023-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	20148F	TITULAIRE	\N	\N
17760	INTE	2023-05-04 00:00:00	2023-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	19691J	TITULAIRE	\N	\N
17761	INTE	2023-05-04 00:00:00	2023-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	11067R	TITULAIRE	\N	\N
17762	INTE	2023-05-04 00:00:00	2023-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	18193Q	TITULAIRE	\N	\N
17763	JOPA	2023-04-04 00:00:00	2023-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	SUPPLEANT	\N	\N
17764	JOPA	2023-04-04 00:00:00	2023-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	19643A	SUPPLEANT	\N	\N
17765	JOPA	2023-04-04 00:00:00	2023-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	14217N	SUPPLEANT	\N	\N
17766	JOPA	2023-04-04 00:00:00	2023-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	14179A	SUPPLEANT	\N	\N
17767	JOPA	2023-04-04 00:00:00	2023-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	19649G	SUPPLEANT	\N	\N
17768	JOPA	2023-04-04 00:00:00	2023-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	20132W	SUPPLEANT	\N	\N
17769	JOPA	2023-04-04 00:00:00	2023-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	SUPPLEANT	\N	\N
17770	JOPA	2023-04-04 00:00:00	2023-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
17771	JOPA	2023-04-04 00:00:00	2023-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	14053L	TITULAIRE	\N	\N
17772	JOPA	2023-04-04 00:00:00	2023-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	19723Y	TITULAIRE	\N	\N
17773	JOPA	2023-04-04 00:00:00	2023-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	14073Q	TITULAIRE	\N	\N
17774	JOPA	2023-04-04 00:00:00	2023-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	14151M	TITULAIRE	\N	\N
17775	JOPA	2023-04-04 00:00:00	2023-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	08012N	TITULAIRE	\N	\N
17776	JOPA	2023-04-04 00:00:00	2023-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	11072N	TITULAIRE	\N	\N
17777	RETRAITES	2023-03-15 00:00:00	2023-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	SUPPLEANT	\N	\N
17778	RETRAITES	2023-03-15 00:00:00	2023-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	14026U	SUPPLEANT	\N	\N
17779	RETRAITES	2023-03-15 00:00:00	2023-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	14217N	SUPPLEANT	\N	\N
17780	RETRAITES	2023-03-15 00:00:00	2023-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	19479G	SUPPLEANT	\N	\N
17781	RETRAITES	2023-03-15 00:00:00	2023-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	20130U	SUPPLEANT	\N	\N
17782	RETRAITES	2023-03-15 00:00:00	2023-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	14207L	SUPPLEANT	\N	\N
17783	RETRAITES	2023-03-15 00:00:00	2023-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	19760E	SUPPLEANT	\N	\N
17784	RETRAITES	2023-03-15 00:00:00	2023-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	10006L	TITULAIRE	\N	\N
17785	RETRAITES	2023-03-15 00:00:00	2023-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	11097X	TITULAIRE	\N	\N
17786	RETRAITES	2023-03-15 00:00:00	2023-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	14071N	TITULAIRE	\N	\N
17787	RETRAITES	2023-03-15 00:00:00	2023-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	14042U	TITULAIRE	\N	\N
17788	RETRAITES	2023-03-15 00:00:00	2023-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	17779H	TITULAIRE	\N	\N
17789	RETRAITES	2023-03-15 00:00:00	2023-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	14281W	TITULAIRE	\N	\N
17790	RETRAITES	2023-03-15 00:00:00	2023-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	19591F	TITULAIRE	\N	\N
17791	SOIN	2023-04-06 00:00:00	2023-04-06 00:00:00	ANCIEN	\N	\N	\N	\N	14026U	SUPPLEANT	\N	\N
17792	SOIN	2023-04-06 00:00:00	2023-04-06 00:00:00	ANCIEN	\N	\N	\N	\N	20090E	SUPPLEANT	\N	\N
17793	SOIN	2023-04-06 00:00:00	2023-04-06 00:00:00	ANCIEN	\N	\N	\N	\N	19723Y	SUPPLEANT	\N	\N
17794	SOIN	2023-04-06 00:00:00	2023-04-06 00:00:00	ANCIEN	\N	\N	\N	\N	20248J	SUPPLEANT	\N	\N
17795	SOIN	2023-04-06 00:00:00	2023-04-06 00:00:00	ANCIEN	\N	\N	\N	\N	18193Q	SUPPLEANT	\N	\N
17796	SOIN	2023-04-06 00:00:00	2023-04-06 00:00:00	ANCIEN	\N	\N	\N	\N	19553Y	SUPPLEANT	\N	\N
17797	SOIN	2023-04-06 00:00:00	2023-04-06 00:00:00	ANCIEN	\N	\N	\N	\N	11031D	SUPPLEANT	\N	\N
17798	SOIN	2023-04-06 00:00:00	2023-04-06 00:00:00	ANCIEN	\N	\N	\N	\N	10006L	TITULAIRE	\N	\N
17799	SOIN	2023-04-06 00:00:00	2023-04-06 00:00:00	ANCIEN	\N	\N	\N	\N	14213J	TITULAIRE	\N	\N
17800	SOIN	2023-04-06 00:00:00	2023-04-06 00:00:00	ANCIEN	\N	\N	\N	\N	19703U	TITULAIRE	\N	\N
17801	SOIN	2023-04-06 00:00:00	2023-04-06 00:00:00	ANCIEN	\N	\N	\N	\N	14042U	TITULAIRE	\N	\N
17802	SOIN	2023-04-06 00:00:00	2023-04-06 00:00:00	ANCIEN	\N	\N	\N	\N	19683J	TITULAIRE	\N	\N
17986	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19631V	\N	\N	\N
17804	SOIN	2023-04-06 00:00:00	2023-04-06 00:00:00	ANCIEN	\N	\N	\N	\N	17965H	TITULAIRE	\N	\N
17805	SOIN	2023-04-06 00:00:00	2023-04-06 00:00:00	ANCIEN	\N	\N	\N	\N	19329S	TITULAIRE	\N	\N
17987	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19629C	\N	\N	\N
17988	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19866P	\N	\N	\N
17999	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	11072N	\N	\N	\N
18000	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19331L	\N	\N	\N
18681	COMSPEAPU	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20080C	\N	\N	\N
18682	COMSPEAPU	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21041Y	\N	\N	\N
18683	COMSPEAPU	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	11070L	\N	\N	\N
18684	COMSPEAPU	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21086N	\N	\N	\N
18685	COMSPEAPU	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	99004R	\N	\N	\N
18686	COMSPEAPU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	08034U	\N	\N	\N
18687	COMSPEAPU	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20150Y	\N	\N	\N
18688	COMSPEAPU	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21079P	\N	\N	\N
19219	ELEC	2024-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19575F	\N	\N	\N
19220	ELEC	2024-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20042V	\N	\N	\N
19221	ELEC	2024-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14207L	\N	\N	\N
19222	ELEC	2024-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	18083K	\N	\N	\N
19223	ELEC	2024-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	11070L	\N	\N	\N
19224	ELEC	2024-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	21033Y	\N	\N	\N
19225	ELEC	2024-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19695N	\N	\N	\N
19226	ELEC	2024-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20120S	\N	\N	\N
19227	ELEC	2024-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14033T	\N	\N	\N
19228	ELEC	2024-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20068G	\N	\N	\N
19229	ELEC	2024-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20106U	\N	\N	\N
19230	ELEC	2024-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19685L	\N	\N	\N
19231	ELEC	2024-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19711U	\N	\N	\N
19232	ELEC	2024-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	12016W	\N	\N	\N
19233	ELEC	2024-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14031R	\N	\N	\N
19234	ELEC	2024-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14221J	\N	\N	\N
19235	ELEC	2024-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20018V	\N	\N	\N
19236	ELEC	2024-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14257W	\N	\N	\N
19237	ELEC	2024-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	21060C	\N	\N	\N
19238	ELEC	2024-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14237S	\N	\N	\N
19239	ELEC	2024-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19533U	\N	\N	\N
19240	ELEC	2024-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19619A	\N	\N	\N
19241	ELEC	2024-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20092G	\N	\N	\N
15957	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	04018C	\N	\N	\N
15958	AFCL	2017-10-04 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04018C	\N	\N	\N
17170	CAE	2022-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20286Q	\N	\N	\N
17907	OPMI	2022-12-01 00:00:00	2022-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	19749K	SUPPLEANT	\N	\N
17908	OPMI	2022-12-01 00:00:00	2022-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	19649G	SUPPLEANT	\N	\N
17909	OPMI	2022-12-01 00:00:00	2022-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	19629C	SUPPLEANT	\N	\N
17910	OPMI	2022-12-01 00:00:00	2022-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	SUPPLEANT	\N	\N
17911	OPMI	2022-12-01 00:00:00	2022-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
17912	OPMI	2022-12-01 00:00:00	2022-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	04008A	TITULAIRE	\N	\N
17913	OPMI	2022-12-01 00:00:00	2022-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	14179A	TITULAIRE	\N	\N
17914	OPMI	2022-12-01 00:00:00	2022-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	19729F	TITULAIRE	\N	\N
17916	OPMI	2022-12-01 00:00:00	2022-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	11026G	TITULAIRE	\N	\N
17917	OPMI	2022-12-01 00:00:00	2022-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	TITULAIRE	\N	\N
17919	PLFR22	2022-11-22 00:00:00	2022-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	19762G	SUPPLEANT	\N	\N
17920	PLFR22	2022-11-22 00:00:00	2022-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	08010L	SUPPLEANT	\N	\N
17921	PLFR22	2022-11-22 00:00:00	2022-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	19335Q	SUPPLEANT	\N	\N
17922	PLFR22	2022-11-22 00:00:00	2022-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	20080C	SUPPLEANT	\N	\N
17923	PLFR22	2022-11-22 00:00:00	2022-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	11040E	SUPPLEANT	\N	\N
17924	PLFR22	2022-11-22 00:00:00	2022-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	20116W	SUPPLEANT	\N	\N
17925	PLFR22	2022-11-22 00:00:00	2022-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	14225N	TITULAIRE	\N	\N
17927	PLFR22	2022-11-22 00:00:00	2022-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	19667J	TITULAIRE	\N	\N
17928	PLFR22	2022-11-22 00:00:00	2022-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	19741B	TITULAIRE	\N	\N
17929	PLFR22	2022-11-22 00:00:00	2022-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	11053K	TITULAIRE	\N	\N
17930	PLFR22	2022-11-22 00:00:00	2022-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	20070A	TITULAIRE	\N	\N
17931	PLFR22	2022-11-22 00:00:00	2022-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	19349W	TITULAIRE	\N	\N
17932	EMPLOI	2022-11-09 00:00:00	2022-11-10 00:00:00	ANCIEN	\N	\N	\N	\N	14026U	SUPPLEANT	\N	\N
17933	EMPLOI	2022-11-09 00:00:00	2022-11-10 00:00:00	ANCIEN	\N	\N	\N	\N	14217N	SUPPLEANT	\N	\N
17934	EMPLOI	2022-11-09 00:00:00	2022-11-10 00:00:00	ANCIEN	\N	\N	\N	\N	19723Y	SUPPLEANT	\N	\N
17935	EMPLOI	2022-11-09 00:00:00	2022-11-10 00:00:00	ANCIEN	\N	\N	\N	\N	20066E	SUPPLEANT	\N	\N
17936	EMPLOI	2022-11-09 00:00:00	2022-11-10 00:00:00	ANCIEN	\N	\N	\N	\N	17965H	SUPPLEANT	\N	\N
17937	EMPLOI	2022-11-09 00:00:00	2022-11-10 00:00:00	ANCIEN	\N	\N	\N	\N	19629C	SUPPLEANT	\N	\N
17938	EMPLOI	2022-11-09 00:00:00	2022-11-10 00:00:00	ANCIEN	\N	\N	\N	\N	19760E	SUPPLEANT	\N	\N
17940	EMPLOI	2022-11-09 00:00:00	2022-11-10 00:00:00	ANCIEN	\N	\N	\N	\N	19679N	TITULAIRE	\N	\N
17941	EMPLOI	2022-11-09 00:00:00	2022-11-10 00:00:00	ANCIEN	\N	\N	\N	\N	14071N	TITULAIRE	\N	\N
17942	EMPLOI	2022-11-09 00:00:00	2022-11-10 00:00:00	ANCIEN	\N	\N	\N	\N	19569H	TITULAIRE	\N	\N
17943	EMPLOI	2022-11-09 00:00:00	2022-11-10 00:00:00	ANCIEN	\N	\N	\N	\N	18193Q	TITULAIRE	\N	\N
17944	EMPLOI	2022-11-09 00:00:00	2022-11-10 00:00:00	ANCIEN	\N	\N	\N	\N	11067R	TITULAIRE	\N	\N
17946	PLFSS2023	2022-11-15 00:00:00	2022-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	11097X	SUPPLEANT	\N	\N
17947	PLFSS2023	2022-11-15 00:00:00	2022-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	14026U	SUPPLEANT	\N	\N
17948	PLFSS2023	2022-11-15 00:00:00	2022-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	14217N	SUPPLEANT	\N	\N
17949	PLFSS2023	2022-11-15 00:00:00	2022-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	19569H	SUPPLEANT	\N	\N
17950	PLFSS2023	2022-11-15 00:00:00	2022-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	17779H	SUPPLEANT	\N	\N
17951	PLFSS2023	2022-11-15 00:00:00	2022-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	19553Y	SUPPLEANT	\N	\N
17952	PLFSS2023	2022-11-15 00:00:00	2022-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	11031D	SUPPLEANT	\N	\N
17953	PLFSS2023	2022-11-15 00:00:00	2022-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	10006L	TITULAIRE	\N	\N
17954	PLFSS2023	2022-11-15 00:00:00	2022-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	14042U	TITULAIRE	\N	\N
17955	PLFSS2023	2022-11-15 00:00:00	2022-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	14071N	TITULAIRE	\N	\N
17956	PLFSS2023	2022-11-15 00:00:00	2022-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	14213J	TITULAIRE	\N	\N
17957	PLFSS2023	2022-11-15 00:00:00	2022-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	19683J	TITULAIRE	\N	\N
17958	PLFSS2023	2022-11-15 00:00:00	2022-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	11067R	TITULAIRE	\N	\N
17959	PLFSS2023	2022-11-15 00:00:00	2022-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	19697Q	TITULAIRE	\N	\N
18165	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20106U	\N	\N	\N
18166	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20136B	\N	\N	\N
18167	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20020P	\N	\N	\N
18168	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20118Y	\N	\N	\N
18169	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20096L	\N	\N	\N
18170	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20068G	\N	\N	\N
18171	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20038A	\N	\N	\N
18172	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20140W	\N	\N	\N
18173	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	17367Q	\N	\N	\N
18174	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20076G	\N	\N	\N
18175	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20032T	\N	\N	\N
18176	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20100N	\N	\N	\N
18177	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20102Q	\N	\N	\N
18178	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20122U	\N	\N	\N
18179	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19251M	\N	\N	\N
18180	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	17229F	\N	\N	\N
18181	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19745F	\N	\N	\N
18182	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14169X	\N	\N	\N
18183	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14037X	\N	\N	\N
18184	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	04045F	\N	\N	\N
18185	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19707Y	\N	\N	\N
18186	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20060X	\N	\N	\N
18187	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19768N	\N	\N	\N
18188	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	08015R	\N	\N	\N
18189	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14207L	\N	\N	\N
18190	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19782L	\N	\N	\N
18191	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14205J	\N	\N	\N
18192	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14257W	\N	\N	\N
18193	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14038Y	\N	\N	\N
18194	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14187A	\N	\N	\N
18195	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	08028W	\N	\N	\N
18196	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20028X	\N	\N	\N
18197	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20062A	\N	\N	\N
18198	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20054A	\N	\N	\N
18199	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20034V	\N	\N	\N
18200	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20104S	\N	\N	\N
18201	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20078J	\N	\N	\N
18202	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19575F	\N	\N	\N
18203	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20092G	\N	\N	\N
18204	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14251Q	\N	\N	\N
18205	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20082E	\N	\N	\N
18206	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20030R	\N	\N	\N
18207	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20018V	\N	\N	\N
18208	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20088L	\N	\N	\N
18209	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20094J	\N	\N	\N
18210	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20144B	\N	\N	\N
18211	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14033T	\N	\N	\N
18212	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19747H	\N	\N	\N
18236	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20266L	\N	\N	\N
18237	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14281W	\N	\N	\N
18238	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19723Y	\N	\N	\N
18239	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20130U	\N	\N	\N
18240	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14195A	\N	\N	\N
10170	SOCI	2014-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14195A	\N	2014-10-08 00:00:00	2017-10-04 00:00:00
18241	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	\N	\N	\N
18242	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14217N	\N	\N	\N
18243	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14071N	\N	\N	\N
18244	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20248J	\N	\N	\N
18245	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20148F	\N	\N	\N
18246	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20090E	\N	\N	\N
18247	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	17965H	\N	\N	\N
18248	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	18193Q	\N	\N	\N
18249	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	08045X	\N	\N	\N
18250	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20066E	\N	\N	\N
18251	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20040T	\N	\N	\N
18252	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14213J	\N	\N	\N
18253	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14026U	\N	\N	\N
18254	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19798U	\N	\N	\N
18255	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14355X	\N	\N	\N
18256	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14223L	\N	\N	\N
18284	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20086J	\N	\N	\N
18285	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14253S	\N	\N	\N
18286	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20044X	\N	\N	\N
18287	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	07029T	\N	\N	\N
18288	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	08011M	\N	\N	\N
18289	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	08034U	\N	\N	\N
18290	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14327T	\N	\N	\N
18291	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14225N	\N	\N	\N
18292	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20126Y	\N	\N	\N
18293	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20036X	\N	\N	\N
18294	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20150Y	\N	\N	\N
18295	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20050V	\N	\N	\N
18296	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20116W	\N	\N	\N
18297	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20070A	\N	\N	\N
18298	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20080C	\N	\N	\N
18299	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	08009T	\N	\N	\N
18300	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14189C	\N	\N	\N
18301	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	08073C	\N	\N	\N
18302	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14121F	\N	\N	\N
18303	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14083S	\N	\N	\N
18304	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	08010L	\N	\N	\N
18305	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14173T	\N	\N	\N
16216	FINC	2020-12-01 00:00:00	2021-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	20022R	\N	\N	\N
16217	CDD	2020-12-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20120S	\N	\N	\N
16218	AFEU	2020-12-01 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19711U	\N	\N	\N
16292	AFCL	2020-12-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20180F	\N	\N	\N
16952	NEANT	2021-07-28 00:00:00	2021-09-08 00:00:00	ANCIEN	\N	\N	\N	\N	20252E	\N	\N	\N
16991	LOIS	2021-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20022R	\N	\N	\N
16992	FINC	2021-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20252E	\N	\N	\N
16993	CAE	2021-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19707Y	\N	\N	\N
16994	ETRD	2021-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	07033P	\N	\N	\N
17984	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14267Y	\N	\N	\N
17985	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19507S	\N	\N	\N
18137	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21088Q	\N	\N	\N
18138	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21089R	\N	\N	\N
18139	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21090J	\N	\N	\N
18140	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19649G	\N	\N	\N
18141	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19647E	\N	\N	\N
18142	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	07033P	\N	\N	\N
18143	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21091K	\N	\N	\N
16293	BIOETHIQUE	2021-01-12 00:00:00	2021-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	17737W	\N	\N	\N
17056	CULTURE	2021-11-18 00:00:00	2022-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	20132W	\N	\N	\N
17057	CULTURE	2021-11-18 00:00:00	2022-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	20110Q	\N	\N	\N
18353	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	11064N	\N	\N	\N
18354	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14211G	\N	\N	\N
18355	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14251Q	\N	\N	\N
18380	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19693L	\N	\N	\N
18381	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20122U	\N	\N	\N
18391	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21035B	\N	\N	\N
18392	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	08060W	\N	\N	\N
18393	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19251M	\N	\N	\N
18394	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21062E	\N	\N	\N
18395	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19820Y	\N	\N	\N
18396	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19551W	\N	\N	\N
18397	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21060C	\N	\N	\N
18398	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21051B	\N	\N	\N
18399	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21082J	\N	\N	\N
18410	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21089R	\N	\N	\N
18411	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20264J	\N	\N	\N
18412	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	18395Y	\N	\N	\N
18413	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14021P	\N	\N	\N
18414	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	08012N	\N	\N	\N
18415	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14109K	\N	\N	\N
18416	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14229S	\N	\N	\N
18417	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21059K	\N	\N	\N
18418	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21077M	\N	\N	\N
18435	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20248J	\N	\N	\N
18436	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14042U	\N	\N	\N
18437	SOCI	2023-10-04 00:00:00	2023-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	20040T	\N	\N	\N
18438	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19691J	\N	\N	\N
18439	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19569H	\N	\N	\N
18440	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21064G	\N	\N	\N
18441	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19713W	\N	\N	\N
18442	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	01034P	\N	\N	\N
18451	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19735D	\N	\N	\N
18452	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19611R	\N	\N	\N
18453	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19699S	\N	\N	\N
18454	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20048C	\N	\N	\N
18455	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14073Q	\N	\N	\N
18456	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20052X	\N	\N	\N
18457	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	04070G	\N	\N	\N
18671	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21040X	\N	\N	\N
18672	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19719D	\N	\N	\N
17945	EMPLOI	2022-11-09 00:00:00	2022-11-10 00:00:00	ANCIEN	\N	\N	\N	\N	19697Q	TITULAIRE	\N	\N
19401	IFAM	2024-02-15 00:00:00	2024-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
19402	IFAM	2024-02-15 00:00:00	2024-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	14147R	TITULAIRE	\N	\N
19403	IFAM	2024-02-15 00:00:00	2024-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	21095P	TITULAIRE	\N	\N
19404	IFAM	2024-02-15 00:00:00	2024-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	19749K	TITULAIRE	\N	\N
19405	IFAM	2024-02-15 00:00:00	2024-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	18231D	TITULAIRE	\N	\N
19406	IFAM	2024-02-15 00:00:00	2024-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	14225N	TITULAIRE	\N	\N
19407	IFAM	2024-02-15 00:00:00	2024-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	11072N	TITULAIRE	\N	\N
19408	IFAM	2024-02-15 00:00:00	2024-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	19673G	SUPPLEANT	\N	\N
19409	IFAM	2024-02-15 00:00:00	2024-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	20098N	SUPPLEANT	\N	\N
19410	IFAM	2024-02-15 00:00:00	2024-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	11085T	SUPPLEANT	\N	\N
19411	IFAM	2024-02-15 00:00:00	2024-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	19649G	SUPPLEANT	\N	\N
19412	IFAM	2024-02-15 00:00:00	2024-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	21088Q	SUPPLEANT	\N	\N
19413	IFAM	2024-02-15 00:00:00	2024-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	21046E	SUPPLEANT	\N	\N
19414	IFAM	2024-02-15 00:00:00	2024-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	20266L	SUPPLEANT	\N	\N
19415	SECT	2024-02-27 00:00:00	2024-02-28 00:00:00	ANCIEN	\N	\N	\N	\N	20022R	SUPPLEANT	\N	\N
19416	SECT	2024-02-27 00:00:00	2024-02-28 00:00:00	ANCIEN	\N	\N	\N	\N	14147R	SUPPLEANT	\N	\N
19417	SECT	2024-02-27 00:00:00	2024-02-28 00:00:00	ANCIEN	\N	\N	\N	\N	14189C	SUPPLEANT	\N	\N
19418	SECT	2024-02-27 00:00:00	2024-02-28 00:00:00	ANCIEN	\N	\N	\N	\N	19489J	SUPPLEANT	\N	\N
19419	SECT	2024-02-27 00:00:00	2024-02-28 00:00:00	ANCIEN	\N	\N	\N	\N	11056N	SUPPLEANT	\N	\N
19420	SECT	2024-02-27 00:00:00	2024-02-28 00:00:00	ANCIEN	\N	\N	\N	\N	14111D	SUPPLEANT	\N	\N
19421	SECT	2024-02-27 00:00:00	2024-02-28 00:00:00	ANCIEN	\N	\N	\N	\N	20110Q	SUPPLEANT	\N	\N
19422	SECT	2024-02-27 00:00:00	2024-02-28 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
19423	SECT	2024-02-27 00:00:00	2024-02-28 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	TITULAIRE	\N	\N
19424	SECT	2024-02-27 00:00:00	2024-02-28 00:00:00	ANCIEN	\N	\N	\N	\N	14259Y	TITULAIRE	\N	\N
19425	SECT	2024-02-27 00:00:00	2024-02-28 00:00:00	ANCIEN	\N	\N	\N	\N	14231L	TITULAIRE	\N	\N
19426	SECT	2024-02-27 00:00:00	2024-02-28 00:00:00	ANCIEN	\N	\N	\N	\N	19649G	TITULAIRE	\N	\N
19427	SECT	2024-02-27 00:00:00	2024-02-28 00:00:00	ANCIEN	\N	\N	\N	\N	20114U	TITULAIRE	\N	\N
19428	SECT	2024-02-27 00:00:00	2024-02-28 00:00:00	ANCIEN	\N	\N	\N	\N	04045F	TITULAIRE	\N	\N
19569	NEANT	2024-03-21 00:00:00	2024-04-02 00:00:00	ANCIEN	\N	\N	\N	\N	14241N	\N	\N	\N
19629	DDAD	2024-04-04 00:00:00	2024-04-05 00:00:00	ANCIEN	\N	\N	\N	\N	14133K	TITULAIRE	\N	\N
19630	DDAD	2024-04-04 00:00:00	2024-04-05 00:00:00	ANCIEN	\N	\N	\N	\N	20022R	SUPPLEANT	\N	\N
19631	DDAD	2024-04-04 00:00:00	2024-04-05 00:00:00	ANCIEN	\N	\N	\N	\N	14026U	SUPPLEANT	\N	\N
19632	DDAD	2024-04-04 00:00:00	2024-04-05 00:00:00	ANCIEN	\N	\N	\N	\N	11053K	SUPPLEANT	\N	\N
19633	DDAD	2024-04-04 00:00:00	2024-04-05 00:00:00	ANCIEN	\N	\N	\N	\N	21082J	SUPPLEANT	\N	\N
19634	DDAD	2024-04-04 00:00:00	2024-04-05 00:00:00	ANCIEN	\N	\N	\N	\N	21084L	SUPPLEANT	\N	\N
19635	DDAD	2024-04-04 00:00:00	2024-04-05 00:00:00	ANCIEN	\N	\N	\N	\N	21052C	SUPPLEANT	\N	\N
19636	DDAD	2024-04-04 00:00:00	2024-04-05 00:00:00	ANCIEN	\N	\N	\N	\N	21093M	SUPPLEANT	\N	\N
19637	DDAD	2024-04-04 00:00:00	2024-04-05 00:00:00	ANCIEN	\N	\N	\N	\N	14237S	TITULAIRE	\N	\N
19638	DDAD	2024-04-04 00:00:00	2024-04-05 00:00:00	ANCIEN	\N	\N	\N	\N	21086N	TITULAIRE	\N	\N
19639	DDAD	2024-04-04 00:00:00	2024-04-05 00:00:00	ANCIEN	\N	\N	\N	\N	19711U	TITULAIRE	\N	\N
19640	DDAD	2024-04-04 00:00:00	2024-04-05 00:00:00	ANCIEN	\N	\N	\N	\N	20084G	TITULAIRE	\N	\N
19641	DDAD	2024-04-04 00:00:00	2024-04-05 00:00:00	ANCIEN	\N	\N	\N	\N	18207D	TITULAIRE	\N	\N
19642	DDAD	2024-04-04 00:00:00	2024-04-05 00:00:00	ANCIEN	\N	\N	\N	\N	11072N	TITULAIRE	\N	\N
19644	AFCL	2024-04-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	14241N	\N	\N	\N
19645	TEST	2024-04-03 00:00:00	2024-04-10 00:00:00	ANCIEN	\N	\N	\N	\N	14147R	SUPPLEANT	\N	\N
19646	TEST	2024-04-03 00:00:00	2024-04-10 00:00:00	ANCIEN	\N	\N	\N	\N	19447X	SUPPLEANT	\N	\N
19647	TEST	2024-04-03 00:00:00	2024-04-10 00:00:00	ANCIEN	\N	\N	\N	\N	11085T	SUPPLEANT	\N	\N
19648	TEST	2024-04-03 00:00:00	2024-04-10 00:00:00	ANCIEN	\N	\N	\N	\N	21056G	SUPPLEANT	\N	\N
19649	TEST	2024-04-03 00:00:00	2024-04-10 00:00:00	ANCIEN	\N	\N	\N	\N	21088Q	SUPPLEANT	\N	\N
19650	TEST	2024-04-03 00:00:00	2024-04-10 00:00:00	ANCIEN	\N	\N	\N	\N	14111D	SUPPLEANT	\N	\N
19651	TEST	2024-04-03 00:00:00	2024-04-10 00:00:00	ANCIEN	\N	\N	\N	\N	20266L	SUPPLEANT	\N	\N
19652	TEST	2024-04-03 00:00:00	2024-04-10 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
19653	TEST	2024-04-03 00:00:00	2024-04-10 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	TITULAIRE	\N	\N
19654	TEST	2024-04-03 00:00:00	2024-04-10 00:00:00	ANCIEN	\N	\N	\N	\N	20074E	TITULAIRE	\N	\N
19655	TEST	2024-04-03 00:00:00	2024-04-10 00:00:00	ANCIEN	\N	\N	\N	\N	14189C	TITULAIRE	\N	\N
19656	TEST	2024-04-03 00:00:00	2024-04-10 00:00:00	ANCIEN	\N	\N	\N	\N	18231D	TITULAIRE	\N	\N
19657	TEST	2024-04-03 00:00:00	2024-04-10 00:00:00	ANCIEN	\N	\N	\N	\N	18207D	TITULAIRE	\N	\N
19658	TEST	2024-04-03 00:00:00	2024-04-10 00:00:00	ANCIEN	\N	\N	\N	\N	04045F	TITULAIRE	\N	\N
15876	CAE	2020-08-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19782L	\N	\N	\N
15879	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20018V	\N	\N	\N
15881	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20022R	\N	\N	\N
15882	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20024T	\N	\N	\N
15883	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20026V	\N	\N	\N
16209	NEANT	2020-11-02 00:00:00	2020-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	14249W	\N	\N	\N
16214	AFEU	2020-11-26 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20094J	\N	\N	\N
18149	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21096Q	\N	\N	\N
18150	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	12016W	\N	\N	\N
18734	AFEU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	19701S	\N	\N	\N
18735	AFEU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	14357A	\N	\N	\N
18736	AFEU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	18395Y	\N	\N	\N
18737	AFEU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20248J	\N	\N	\N
18738	AFEU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20100N	\N	\N	\N
18739	AFEU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	08018U	\N	\N	\N
18740	AFEU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20286Q	\N	\N	\N
18742	AFEU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	21032X	\N	\N	\N
18743	AFEU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	14033T	\N	\N	\N
18744	AFEU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	14026U	\N	\N	\N
18745	AFEU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20106U	\N	\N	\N
18747	AFEU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	19569H	\N	\N	\N
18748	AFEU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	19683J	\N	\N	\N
18749	AFEU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	14097Y	\N	\N	\N
18750	AFEU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	14073Q	\N	\N	\N
18752	AFEU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	21078N	\N	\N	\N
18753	AFEU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	19711U	\N	\N	\N
18754	AFEU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	19709B	\N	\N	\N
18755	AFEU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	08034U	\N	\N	\N
18756	AFEU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	18207D	\N	\N	\N
18757	AFEU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	21054E	\N	\N	\N
18758	AFEU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	14169X	\N	\N	\N
18759	AFEU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	14001X	\N	\N	\N
18760	AFEU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	04070G	\N	\N	\N
18761	AFEU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	21037D	\N	\N	\N
18762	AFEU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	08073C	\N	\N	\N
18764	AFEU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	14237S	\N	\N	\N
18765	AFEU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	14331P	\N	\N	\N
18767	AFEU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	10015M	\N	\N	\N
18768	AFEU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20150Y	\N	\N	\N
18770	AFEU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20098N	\N	\N	\N
18771	AFEU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	21049H	\N	\N	\N
18772	AFEU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	21076L	\N	\N	\N
18774	AFEU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	21082J	\N	\N	\N
16085	BIOETHIQUE	2020-10-07 00:00:00	2020-10-15 00:00:00	ANCIEN	\N	\N	\N	\N	17737W	\N	\N	\N
16086	BIOETHIQUE	2020-10-07 00:00:00	2021-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	20066E	\N	\N	\N
16087	BIOETHIQUE	2020-10-07 00:00:00	2021-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	19691J	\N	\N	\N
16088	BIOETHIQUE	2020-10-07 00:00:00	2021-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	19715Y	\N	\N	\N
16089	BIOETHIQUE	2020-10-07 00:00:00	2021-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	11026G	\N	\N	\N
16090	BIOETHIQUE	2020-10-07 00:00:00	2021-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	19593H	\N	\N	\N
16091	BIOETHIQUE	2020-10-07 00:00:00	2021-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	20092G	\N	\N	\N
16092	ASAP	2020-10-07 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	20110Q	\N	\N	\N
16093	ASAP	2020-10-07 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	19758L	\N	\N	\N
16094	ASAP	2020-10-07 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	19701S	\N	\N	\N
16095	ASAP	2020-10-07 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	14327T	\N	\N	\N
16096	ASAP	2020-10-07 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	19507S	\N	\N	\N
16097	ASAP	2020-10-07 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	14033T	\N	\N	\N
16098	ASAP	2020-10-07 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	08034U	\N	\N	\N
16099	ASAP	2020-10-07 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	14107H	\N	\N	\N
16100	PANDEMIE	2020-10-07 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	08045X	\N	\N	\N
16101	PANDEMIE	2020-10-07 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	20130U	\N	\N	\N
16102	PANDEMIE	2020-10-07 00:00:00	2020-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	19713W	\N	\N	\N
16444	BIENCULT	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19611R	TITULAIRE	\N	\N
16445	BIENCULT	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	04070G	TITULAIRE	\N	\N
16446	BIENCULT	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19621T	TITULAIRE	\N	\N
16447	BIENCULT	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	07033P	TITULAIRE	\N	\N
16448	BIENCULT	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	08017T	TITULAIRE	\N	\N
16449	BIENCULT	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	14109K	TITULAIRE	\N	\N
16450	BIENCULT	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19329S	TITULAIRE	\N	\N
16451	BIENCULT	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19399H	SUPPLEANT	\N	\N
16452	BIENCULT	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	20098N	SUPPLEANT	\N	\N
16453	BIENCULT	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19573D	SUPPLEANT	\N	\N
16454	BIENCULT	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	20058E	SUPPLEANT	\N	\N
16455	BIENCULT	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	20084G	SUPPLEANT	\N	\N
16456	BIENCULT	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	20132W	SUPPLEANT	\N	\N
16457	BIENCULT	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19593H	SUPPLEANT	\N	\N
16464	PLFSS21	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	17779H	TITULAIRE	\N	\N
16459	PLFSS21	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	10006L	TITULAIRE	\N	\N
16460	PLFSS21	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	01034P	TITULAIRE	\N	\N
16461	PLFSS21	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	14213J	TITULAIRE	\N	\N
16462	PLFSS21	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	11097X	TITULAIRE	\N	\N
16463	PLFSS21	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19683J	TITULAIRE	\N	\N
16465	PLFSS21	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19697Q	TITULAIRE	\N	\N
16466	PLFSS21	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	14071N	SUPPLEANT	\N	\N
16467	PLFSS21	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	14026U	SUPPLEANT	\N	\N
16468	PLFSS21	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	14217N	SUPPLEANT	\N	\N
16469	PLFSS21	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	14042U	SUPPLEANT	\N	\N
16470	PLFSS21	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	14281W	SUPPLEANT	\N	\N
16471	PLFSS21	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19553Y	SUPPLEANT	\N	\N
16472	PLFSS21	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	11031D	SUPPLEANT	\N	\N
16473	PLFR420	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	14225N	TITULAIRE	\N	\N
16474	PLFR420	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	TITULAIRE	\N	\N
16475	PLFR420	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19711U	TITULAIRE	\N	\N
16476	PLFR420	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19762G	TITULAIRE	\N	\N
16477	PLFR420	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	14083S	TITULAIRE	\N	\N
16478	PLFR420	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19647E	TITULAIRE	\N	\N
16479	PLFR420	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19349W	TITULAIRE	\N	\N
16480	PLFR420	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19741B	SUPPLEANT	\N	\N
16481	PLFR420	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19667J	SUPPLEANT	\N	\N
16482	PLFR420	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	20044X	SUPPLEANT	\N	\N
16483	PLFR420	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	11053K	SUPPLEANT	\N	\N
16484	PLFR420	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	12016W	SUPPLEANT	\N	\N
16485	PLFR420	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	11012A	SUPPLEANT	\N	\N
16486	PLFR420	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	11040E	SUPPLEANT	\N	\N
16487	PLF2021	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	14225N	TITULAIRE	\N	\N
16488	PLF2021	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	TITULAIRE	\N	\N
16489	PLF2021	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19711U	TITULAIRE	\N	\N
16490	PLF2021	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19741B	TITULAIRE	\N	\N
16491	PLF2021	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	14327T	TITULAIRE	\N	\N
16492	PLF2021	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19647E	TITULAIRE	\N	\N
16493	PLF2021	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19349W	TITULAIRE	\N	\N
16494	PLF2021	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	20044X	SUPPLEANT	\N	\N
16495	PLF2021	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19667J	SUPPLEANT	\N	\N
16496	PLF2021	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	08010L	SUPPLEANT	\N	\N
16497	PLF2021	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19479G	SUPPLEANT	\N	\N
16498	PLF2021	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	20080C	SUPPLEANT	\N	\N
16499	PLF2021	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	11012A	SUPPLEANT	\N	\N
16500	PLF2021	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	11040E	SUPPLEANT	\N	\N
16501	PJLOELEC	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
16502	PJLOELEC	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	TITULAIRE	\N	\N
16503	PJLOELEC	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
16504	PJLOELEC	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	14179A	TITULAIRE	\N	\N
16505	PJLOELEC	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	14001X	TITULAIRE	\N	\N
16506	PJLOELEC	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19489J	TITULAIRE	\N	\N
16507	PJLOELEC	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	11072N	TITULAIRE	\N	\N
16508	PJLOELEC	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19447X	SUPPLEANT	\N	\N
16509	PJLOELEC	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	SUPPLEANT	\N	\N
16510	PJLOELEC	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19673G	SUPPLEANT	\N	\N
16511	PJLOELEC	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	11085T	SUPPLEANT	\N	\N
16512	PJLOELEC	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	14151M	SUPPLEANT	\N	\N
16513	PJLOELEC	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	14107H	SUPPLEANT	\N	\N
16514	PJLOELEC	2021-03-11 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	11056N	SUPPLEANT	\N	\N
19485	DERI	2024-03-07 00:00:00	2024-03-08 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	SUPPLEANT	\N	\N
19486	DERI	2024-03-07 00:00:00	2024-03-08 00:00:00	ANCIEN	\N	\N	\N	\N	18207D	SUPPLEANT	\N	\N
19487	DERI	2024-03-07 00:00:00	2024-03-08 00:00:00	ANCIEN	\N	\N	\N	\N	11056N	SUPPLEANT	\N	\N
19488	DERI	2024-03-07 00:00:00	2024-03-08 00:00:00	ANCIEN	\N	\N	\N	\N	21054E	SUPPLEANT	\N	\N
19483	DERI	2024-03-07 00:00:00	2024-03-08 00:00:00	ANCIEN	\N	\N	\N	\N	20022R	SUPPLEANT	\N	\N
19484	DERI	2024-03-07 00:00:00	2024-03-08 00:00:00	ANCIEN	\N	\N	\N	\N	21038E	SUPPLEANT	\N	\N
19489	DERI	2024-03-07 00:00:00	2024-03-08 00:00:00	ANCIEN	\N	\N	\N	\N	20110Q	SUPPLEANT	\N	\N
19490	DERI	2024-03-08 00:00:00	2024-03-08 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
19491	DERI	2024-03-08 00:00:00	2024-03-08 00:00:00	ANCIEN	\N	\N	\N	\N	21044C	TITULAIRE	\N	\N
19492	DERI	2024-03-07 00:00:00	2024-03-08 00:00:00	ANCIEN	\N	\N	\N	\N	21095P	TITULAIRE	\N	\N
19493	DERI	2024-03-07 00:00:00	2024-03-08 00:00:00	ANCIEN	\N	\N	\N	\N	19749K	TITULAIRE	\N	\N
19494	DERI	2024-03-07 00:00:00	2024-03-08 00:00:00	ANCIEN	\N	\N	\N	\N	21057H	TITULAIRE	\N	\N
19495	DERI	2024-03-07 00:00:00	2024-03-08 00:00:00	ANCIEN	\N	\N	\N	\N	19649G	TITULAIRE	\N	\N
19496	DERI	2024-03-07 00:00:00	2024-03-08 00:00:00	ANCIEN	\N	\N	\N	\N	11072N	TITULAIRE	\N	\N
19497	AGE	2024-03-12 00:00:00	2024-03-13 00:00:00	ANCIEN	\N	\N	\N	\N	14217N	SUPPLEANT	\N	\N
19498	AGE	2024-03-12 00:00:00	2024-03-13 00:00:00	ANCIEN	\N	\N	\N	\N	14213J	SUPPLEANT	\N	\N
19499	AGE	2024-03-12 00:00:00	2024-03-13 00:00:00	ANCIEN	\N	\N	\N	\N	01034P	SUPPLEANT	\N	\N
19500	AGE	2024-03-12 00:00:00	2024-03-13 00:00:00	ANCIEN	\N	\N	\N	\N	17779H	SUPPLEANT	\N	\N
19501	AGE	2024-03-12 00:00:00	2024-03-13 00:00:00	ANCIEN	\N	\N	\N	\N	19760E	SUPPLEANT	\N	\N
19502	AGE	2024-03-12 00:00:00	2024-03-13 00:00:00	ANCIEN	\N	\N	\N	\N	14195A	SUPPLEANT	\N	\N
19503	AGE	2024-03-12 00:00:00	2024-03-13 00:00:00	ANCIEN	\N	\N	\N	\N	21094N	SUPPLEANT	\N	\N
19504	AGE	2024-03-13 00:00:00	2024-03-13 00:00:00	ANCIEN	\N	\N	\N	\N	14071N	TITULAIRE	\N	\N
19505	AGE	2024-03-12 00:00:00	2024-03-13 00:00:00	ANCIEN	\N	\N	\N	\N	19703U	TITULAIRE	\N	\N
19506	AGE	2024-03-12 00:00:00	2024-03-13 00:00:00	ANCIEN	\N	\N	\N	\N	20098N	TITULAIRE	\N	\N
19508	AGE	2024-03-12 00:00:00	2024-03-13 00:00:00	ANCIEN	\N	\N	\N	\N	14281W	TITULAIRE	\N	\N
19509	AGE	2024-03-12 00:00:00	2024-03-13 00:00:00	ANCIEN	\N	\N	\N	\N	18193Q	TITULAIRE	\N	\N
16955	NEANT	2021-10-01 00:00:00	2021-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	19707Y	\N	\N	\N
16956	NEANT	2021-10-01 00:00:00	2021-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	19057M	\N	\N	\N
16957	NEANT	2021-10-01 00:00:00	2021-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20264J	\N	\N	\N
16958	NEANT	2021-10-01 00:00:00	2021-10-13 00:00:00	ANCIEN	\N	\N	\N	\N	20266L	\N	\N	\N
12016	ELECTION	2016-03-02 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	SUPPLEANT	2016-03-11 10:38:13	2016-03-11 10:42:38
17418	TIKTO	2023-03-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19717B	\N	\N	\N
18151	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19301E	\N	\N	\N
17420	TIKTO	2023-03-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	14030Q	\N	\N	\N
17421	TIKTO	2023-03-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19643A	\N	\N	\N
17422	TIKTO	2023-03-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20152B	\N	\N	\N
17423	TIKTO	2023-03-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	17737W	\N	\N	\N
17424	TIKTO	2023-03-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20060X	\N	\N	\N
17425	TIKTO	2023-03-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20134Y	\N	\N	\N
17426	TIKTO	2023-03-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	11083R	\N	\N	\N
17427	TIKTO	2023-03-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20068G	\N	\N	\N
17428	TIKTO	2023-03-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	14179A	\N	\N	\N
17429	TIKTO	2023-03-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19711U	\N	\N	\N
17430	TIKTO	2023-03-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	14251Q	\N	\N	\N
17431	TIKTO	2023-03-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	14147R	\N	\N	\N
17432	TIKTO	2023-03-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	04070G	\N	\N	\N
17433	TIKTO	2023-03-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19593H	\N	\N	\N
17434	TIKTO	2023-03-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	14193X	\N	\N	\N
17435	TIKTO	2023-03-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	11090Q	\N	\N	\N
17436	TIKTO	2023-03-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	11045K	\N	\N	\N
17437	TIKTO	2023-03-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20064C	\N	\N	\N
18152	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21097R	\N	\N	\N
16294	PAUP	2021-01-13 00:00:00	2021-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	19760E	\N	\N	\N
16296	PAUP	2021-01-13 00:00:00	2021-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	19631V	\N	\N	\N
16295	PAUP	2021-01-13 00:00:00	2021-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	19717B	\N	\N	\N
16297	PAUP	2021-01-13 00:00:00	2021-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	19515S	\N	\N	\N
16298	PAUP	2021-01-13 00:00:00	2021-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	19667J	\N	\N	\N
16299	PAUP	2021-01-13 00:00:00	2021-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	19367Y	\N	\N	\N
16300	PAUP	2021-01-13 00:00:00	2021-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	11053K	\N	\N	\N
16301	PAUP	2021-01-13 00:00:00	2021-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	20040T	\N	\N	\N
16302	PAUP	2021-01-13 00:00:00	2021-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	14187A	\N	\N	\N
16303	PAUP	2021-01-13 00:00:00	2021-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	20066E	\N	\N	\N
16304	PAUP	2021-01-13 00:00:00	2021-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	18193Q	\N	\N	\N
16305	PAUP	2021-01-13 00:00:00	2021-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	14205J	\N	\N	\N
16306	PAUP	2021-01-13 00:00:00	2021-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	19657G	\N	\N	\N
16307	PAUP	2021-01-13 00:00:00	2021-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	20018V	\N	\N	\N
16308	PAUP	2021-01-13 00:00:00	2021-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	14071N	\N	\N	\N
16309	PAUP	2021-01-13 00:00:00	2021-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	20130U	\N	\N	\N
16310	PAUP	2021-01-13 00:00:00	2021-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	17965H	\N	\N	\N
16311	PAUP	2021-01-13 00:00:00	2021-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	19679N	\N	\N	\N
16312	PAUP	2021-01-13 00:00:00	2021-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	20044X	\N	\N	\N
16313	PAUP	2021-01-13 00:00:00	2021-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	20098N	\N	\N	\N
16314	PAUP	2021-01-13 00:00:00	2021-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	04045F	\N	\N	\N
16315	PAUP	2021-01-13 00:00:00	2021-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	19703U	\N	\N	\N
16316	PAUP	2021-01-13 00:00:00	2021-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	19585H	\N	\N	\N
16317	CONF	2021-01-13 00:00:00	2021-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	14189C	\N	\N	\N
16318	CONF	2021-01-13 00:00:00	2021-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	11033F	\N	\N	\N
16319	CONF	2021-01-13 00:00:00	2021-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	14207L	\N	\N	\N
16320	CONF	2021-01-13 00:00:00	2021-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	11031D	\N	\N	\N
16321	CONF	2021-01-13 00:00:00	2021-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	10006L	\N	\N	\N
16322	CONF	2021-01-13 00:00:00	2021-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	20120S	\N	\N	\N
16323	CONF	2021-01-13 00:00:00	2021-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	19569H	\N	\N	\N
16324	CONF	2021-01-13 00:00:00	2021-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	19683J	\N	\N	\N
16325	CONF	2021-01-13 00:00:00	2021-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	19447X	\N	\N	\N
16326	CONF	2021-01-13 00:00:00	2021-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	99004R	\N	\N	\N
16327	CONF	2021-01-13 00:00:00	2021-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	19699S	\N	\N	\N
16328	CONF	2021-01-13 00:00:00	2021-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	19697Q	\N	\N	\N
16329	CONF	2021-01-13 00:00:00	2021-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	19563B	\N	\N	\N
16330	CONF	2021-01-13 00:00:00	2021-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	\N	\N	\N
16331	CONF	2021-01-13 00:00:00	2021-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	19573D	\N	\N	\N
16332	CONF	2021-01-13 00:00:00	2021-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	20030R	\N	\N	\N
16333	CONF	2021-01-13 00:00:00	2021-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	11090Q	\N	\N	\N
16334	CONF	2021-01-13 00:00:00	2021-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	19705W	\N	\N	\N
16335	CONF	2021-01-13 00:00:00	2021-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	14229S	\N	\N	\N
17125	NEANT	2021-12-08 00:00:00	2022-01-03 00:00:00	ANCIEN	\N	\N	\N	\N	20286Q	\N	\N	\N
17126	FONDSMER	2021-12-09 00:00:00	2022-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	19717B	\N	\N	\N
17127	FONDSMER	2021-12-09 00:00:00	2022-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	20114U	\N	\N	\N
17128	FONDSMER	2021-12-09 00:00:00	2022-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	20104S	\N	\N	\N
17129	FONDSMER	2021-12-09 00:00:00	2022-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	14083S	\N	\N	\N
17133	FONDSMER	2021-12-09 00:00:00	2022-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	17023S	\N	\N	\N
17131	FONDSMER	2021-12-09 00:00:00	2022-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	19507S	\N	\N	\N
17132	FONDSMER	2021-12-09 00:00:00	2022-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	20100N	\N	\N	\N
17134	FONDSMER	2021-12-09 00:00:00	2022-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	11064N	\N	\N	\N
17135	FONDSMER	2021-12-09 00:00:00	2022-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	19333N	\N	\N	\N
17136	FONDSMER	2021-12-09 00:00:00	2022-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	20034V	\N	\N	\N
17137	FONDSMER	2021-12-09 00:00:00	2022-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	19447X	\N	\N	\N
17138	FONDSMER	2021-12-09 00:00:00	2022-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	20102Q	\N	\N	\N
17139	FONDSMER	2021-12-09 00:00:00	2022-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	14059S	\N	\N	\N
17140	FONDSMER	2021-12-09 00:00:00	2022-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	14031R	\N	\N	\N
17141	FONDSMER	2021-12-09 00:00:00	2022-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	19826F	\N	\N	\N
17142	FONDSMER	2021-12-09 00:00:00	2022-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	20096L	\N	\N	\N
17143	FONDSMER	2021-12-09 00:00:00	2022-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	19503N	\N	\N	\N
17144	FONDSMER	2021-12-09 00:00:00	2022-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	04043D	\N	\N	\N
17148	RECHINNO	2021-12-09 00:00:00	2022-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	19747H	\N	\N	\N
17146	FONDSMER	2021-12-09 00:00:00	2022-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	20150Y	\N	\N	\N
17147	RECHINNO	2021-12-09 00:00:00	2022-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	19515S	\N	\N	\N
17149	RECHINNO	2021-12-09 00:00:00	2022-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	20264J	\N	\N	\N
17150	RECHINNO	2021-12-09 00:00:00	2022-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	20144B	\N	\N	\N
17151	RECHINNO	2021-12-09 00:00:00	2022-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	19693L	\N	\N	\N
17152	RECHINNO	2021-12-09 00:00:00	2022-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	20140W	\N	\N	\N
17153	RECHINNO	2021-12-09 00:00:00	2022-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	20074E	\N	\N	\N
17154	RECHINNO	2021-12-09 00:00:00	2022-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	14213J	\N	\N	\N
17158	RECHINNO	2021-12-09 00:00:00	2022-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	14097Y	\N	\N	\N
17159	RECHINNO	2021-12-09 00:00:00	2022-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	20126Y	\N	\N	\N
17157	RECHINNO	2021-12-09 00:00:00	2022-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	20066E	\N	\N	\N
17160	RECHINNO	2021-12-09 00:00:00	2022-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	11077T	\N	\N	\N
17161	RECHINNO	2021-12-09 00:00:00	2022-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	19369B	\N	\N	\N
17162	RECHINNO	2021-12-09 00:00:00	2022-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	11072N	\N	\N	\N
17163	RECHINNO	2021-12-09 00:00:00	2022-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	19866P	\N	\N	\N
17164	RECHINNO	2021-12-09 00:00:00	2022-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	20050V	\N	\N	\N
17165	RECHINNO	2021-12-09 00:00:00	2022-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	14193X	\N	\N	\N
17166	RECHINNO	2021-12-09 00:00:00	2022-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	20082E	\N	\N	\N
17167	RECHINNO	2021-12-09 00:00:00	2022-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	20092G	\N	\N	\N
17255	MEDIC	2023-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	20114U	\N	\N	\N
17253	MEDIC	2023-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	20024T	\N	\N	\N
17254	MEDIC	2023-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	20138D	\N	\N	\N
17256	MEDIC	2023-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	11031D	\N	\N	\N
17257	MEDIC	2023-01-24 00:00:00	2023-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	14123H	\N	\N	\N
17258	MEDIC	2023-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	14026U	\N	\N	\N
17259	MEDIC	2023-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	19553Y	\N	\N	\N
17260	MEDIC	2023-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	19725B	\N	\N	\N
17261	MEDIC	2023-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	08069G	\N	\N	\N
17262	MEDIC	2023-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	14213J	\N	\N	\N
17263	MEDIC	2023-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	20066E	\N	\N	\N
17264	MEDIC	2023-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	20126Y	\N	\N	\N
17265	MEDIC	2023-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	19735D	\N	\N	\N
17266	MEDIC	2023-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	04092N	\N	\N	\N
17267	MEDIC	2023-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	19369B	\N	\N	\N
17268	MEDIC	2023-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	20050V	\N	\N	\N
17269	MEDIC	2023-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	17965H	\N	\N	\N
17270	MEDIC	2023-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	04045F	\N	\N	\N
17271	MEDIC	2023-01-24 00:00:00	\N	ACTIF	\N	\N	\N	\N	20266L	\N	\N	\N
18790	SOCI	2023-10-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	21039F	\N	\N	\N
15700	DEMARCHAGE	2020-06-24 00:00:00	2020-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
15701	DEMARCHAGE	2020-06-24 00:00:00	2020-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	10015M	TITULAIRE	\N	\N
15702	DEMARCHAGE	2020-06-24 00:00:00	2020-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	19447X	TITULAIRE	\N	\N
15703	DEMARCHAGE	2020-06-24 00:00:00	2020-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	01024M	TITULAIRE	\N	\N
15704	DEMARCHAGE	2020-06-24 00:00:00	2020-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	14097Y	TITULAIRE	\N	\N
15705	DEMARCHAGE	2020-06-24 00:00:00	2020-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
15706	DEMARCHAGE	2020-06-24 00:00:00	2020-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	19697Q	TITULAIRE	\N	\N
15707	DEMARCHAGE	2020-06-24 00:00:00	2020-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	SUPPLEANT	\N	\N
15708	DEMARCHAGE	2020-06-24 00:00:00	2020-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	SUPPLEANT	\N	\N
15709	DEMARCHAGE	2020-06-24 00:00:00	2020-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	\N	\N
15710	DEMARCHAGE	2020-06-24 00:00:00	2020-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	14219Q	SUPPLEANT	\N	\N
15711	DEMARCHAGE	2020-06-24 00:00:00	2020-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	11066Q	SUPPLEANT	\N	\N
15712	DEMARCHAGE	2020-06-24 00:00:00	2020-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	11065P	SUPPLEANT	\N	\N
15713	DEMARCHAGE	2020-06-24 00:00:00	2020-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	\N	\N
15714	CHEQUEVAC	2020-06-24 00:00:00	2020-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	TITULAIRE	\N	\N
15715	CHEQUEVAC	2020-06-24 00:00:00	2020-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	19679N	TITULAIRE	\N	\N
15716	CHEQUEVAC	2020-06-24 00:00:00	2020-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	14026U	TITULAIRE	\N	\N
15717	CHEQUEVAC	2020-06-24 00:00:00	2020-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	19691J	TITULAIRE	\N	\N
15718	CHEQUEVAC	2020-06-24 00:00:00	2020-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	TITULAIRE	\N	\N
15719	CHEQUEVAC	2020-06-24 00:00:00	2020-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	19683J	TITULAIRE	\N	\N
15720	CHEQUEVAC	2020-06-24 00:00:00	2020-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	19697Q	TITULAIRE	\N	\N
15721	CHEQUEVAC	2020-06-24 00:00:00	2020-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	10006L	SUPPLEANT	\N	\N
15722	CHEQUEVAC	2020-06-24 00:00:00	2020-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	14213J	SUPPLEANT	\N	\N
15723	CHEQUEVAC	2020-06-24 00:00:00	2020-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	14071N	SUPPLEANT	\N	\N
15724	CHEQUEVAC	2020-06-24 00:00:00	2020-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	11067R	SUPPLEANT	\N	\N
15725	CHEQUEVAC	2020-06-24 00:00:00	2020-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	14042U	SUPPLEANT	\N	\N
15726	CHEQUEVAC	2020-06-24 00:00:00	2020-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	19553Y	SUPPLEANT	\N	\N
15727	CHEQUEVAC	2020-06-24 00:00:00	2020-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	19760E	SUPPLEANT	\N	\N
15891	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20040T	\N	\N	\N
15894	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20044X	\N	\N	\N
15908	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20070A	\N	\N	\N
15909	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20072C	\N	\N	\N
15910	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20074E	\N	\N	\N
15911	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20076G	\N	\N	\N
15912	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20078J	\N	\N	\N
11779	2015CMP29	2015-11-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	SUPPLEANT	\N	\N
15914	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20080C	\N	\N	\N
15915	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20082E	\N	\N	\N
15922	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20096L	\N	\N	\N
15923	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20098N	\N	\N	\N
15924	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20100N	\N	\N	\N
11749	2015CMP27	2015-11-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14065Q	SUPPLEANT	\N	\N
15934	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20114U	\N	\N	\N
15935	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20116W	\N	\N	\N
15939	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20122U	\N	\N	\N
9720	2013CMP28	2013-11-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	TITULAIRE	\N	\N
15947	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20136B	\N	\N	\N
15948	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20138D	\N	\N	\N
15949	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20140W	\N	\N	\N
15953	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20146D	\N	\N	\N
15954	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20148F	\N	\N	\N
15955	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20150Y	\N	\N	\N
17171	NEANT	2022-02-03 00:00:00	2022-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	20298U	\N	\N	\N
17186	AFCL	2023-01-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20980G	\N	\N	\N
17580	LOCATIF	2023-06-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	11090Q	TITULAIRE	\N	\N
17581	LOCATIF	2023-06-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	14187A	TITULAIRE	\N	\N
17582	LOCATIF	2023-06-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	20034V	TITULAIRE	\N	\N
17583	LOCATIF	2023-06-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	19441R	TITULAIRE	\N	\N
17584	LOCATIF	2023-06-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	20088L	TITULAIRE	\N	\N
17585	LOCATIF	2023-06-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	20018V	TITULAIRE	\N	\N
17586	LOCATIF	2023-06-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	19651A	TITULAIRE	\N	\N
17587	LOCATIF	2023-06-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	19515S	SUPPLEANT	\N	\N
17588	LOCATIF	2023-06-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	14033T	SUPPLEANT	\N	\N
17589	LOCATIF	2023-06-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	19507S	SUPPLEANT	\N	\N
17590	LOCATIF	2023-06-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	19735D	SUPPLEANT	\N	\N
17591	LOCATIF	2023-06-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	20060X	SUPPLEANT	\N	\N
17592	LOCATIF	2023-06-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	14207L	SUPPLEANT	\N	\N
17593	LOCATIF	2023-06-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	11077T	SUPPLEANT	\N	\N
19121	IMMI	2023-12-18 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
19122	IMMI	2023-12-18 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	19447X	TITULAIRE	\N	\N
19123	IMMI	2023-12-18 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	14089Y	TITULAIRE	\N	\N
19124	IMMI	2023-12-18 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	04033B	TITULAIRE	\N	\N
19125	IMMI	2023-12-18 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	19649G	TITULAIRE	\N	\N
19126	IMMI	2023-12-18 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	18231D	TITULAIRE	\N	\N
19127	IMMI	2023-12-18 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	21043B	TITULAIRE	\N	\N
19128	IMMI	2023-12-18 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	19673G	SUPPLEANT	\N	\N
19129	IMMI	2023-12-18 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	20022R	SUPPLEANT	\N	\N
19130	IMMI	2023-12-18 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	19111A	SUPPLEANT	\N	\N
19131	IMMI	2023-12-18 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	14021P	SUPPLEANT	\N	\N
19132	IMMI	2023-12-18 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	21088Q	SUPPLEANT	\N	\N
19133	IMMI	2023-12-18 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	14251Q	SUPPLEANT	\N	\N
19134	IMMI	2023-12-18 00:00:00	2023-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	20110Q	SUPPLEANT	\N	\N
19135	PLF2024	2023-12-12 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	21090J	SUPPLEANT	\N	\N
19136	PLF2024	2023-12-12 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	20062A	SUPPLEANT	\N	\N
19137	PLF2024	2023-12-12 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	14083S	SUPPLEANT	\N	\N
19138	PLF2024	2023-12-12 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	20080C	SUPPLEANT	\N	\N
19139	PLF2024	2023-12-12 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	19687N	SUPPLEANT	\N	\N
19140	PLF2024	2023-12-12 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	19545Y	SUPPLEANT	\N	\N
19141	PLF2024	2023-12-12 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	21048G	SUPPLEANT	\N	\N
19142	PLF2024	2023-12-12 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	14225N	TITULAIRE	\N	\N
19143	PLF2024	2023-12-12 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	TITULAIRE	\N	\N
19144	PLF2024	2023-12-12 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	19711U	TITULAIRE	\N	\N
19145	PLF2024	2023-12-12 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	20044X	TITULAIRE	\N	\N
19146	PLF2024	2023-12-12 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	14327T	TITULAIRE	\N	\N
19147	PLF2024	2023-12-12 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	20070A	TITULAIRE	\N	\N
19148	PLF2024	2023-12-12 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	\N	19349W	TITULAIRE	\N	\N
19149	RATP	2023-12-06 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	14169X	SUPPLEANT	\N	\N
19150	RATP	2023-12-06 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	20120S	SUPPLEANT	\N	\N
19151	RATP	2023-12-06 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	11053K	SUPPLEANT	\N	\N
19152	RATP	2023-12-06 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	19820Y	SUPPLEANT	\N	\N
19153	RATP	2023-12-06 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	21084L	SUPPLEANT	\N	\N
19154	RATP	2023-12-06 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	21076L	SUPPLEANT	\N	\N
19155	RATP	2023-12-06 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	20100N	SUPPLEANT	\N	\N
19156	RATP	2023-12-06 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	14031R	TITULAIRE	\N	\N
19157	RATP	2023-12-06 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	15197G	TITULAIRE	\N	\N
19158	RATP	2023-12-06 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	20136B	TITULAIRE	\N	\N
19159	RATP	2023-12-06 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	19701S	TITULAIRE	\N	\N
19160	RATP	2023-12-06 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	21051B	TITULAIRE	\N	\N
19161	RATP	2023-12-06 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	19551W	TITULAIRE	\N	\N
19162	RATP	2023-12-06 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	20106U	TITULAIRE	\N	\N
19163	PLFFG23	2023-11-21 00:00:00	2023-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	21090J	SUPPLEANT	\N	\N
19164	PLFFG23	2023-11-21 00:00:00	2023-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	21072G	SUPPLEANT	\N	\N
19165	PLFFG23	2023-11-21 00:00:00	2023-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	11053K	SUPPLEANT	\N	\N
19166	PLFFG23	2023-11-21 00:00:00	2023-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	20080C	SUPPLEANT	\N	\N
19167	PLFFG23	2023-11-21 00:00:00	2023-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	19687N	SUPPLEANT	\N	\N
19168	PLFFG23	2023-11-21 00:00:00	2023-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	19545Y	SUPPLEANT	\N	\N
19169	PLFFG23	2023-11-21 00:00:00	2023-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	20134Y	SUPPLEANT	\N	\N
19170	PLFFG23	2023-11-21 00:00:00	2023-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	14225N	TITULAIRE	\N	\N
19171	PLFFG23	2023-11-21 00:00:00	2023-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	TITULAIRE	\N	\N
16959	PPLEGALIM	2021-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14205J	TITULAIRE	\N	\N
16960	PPLEGALIM	2021-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14357A	TITULAIRE	\N	\N
16961	PPLEGALIM	2021-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19507S	TITULAIRE	\N	\N
16962	PPLEGALIM	2021-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20028X	TITULAIRE	\N	\N
16963	PPLEGALIM	2021-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14257W	TITULAIRE	\N	\N
16964	PPLEGALIM	2021-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19782L	TITULAIRE	\N	\N
16965	PPLEGALIM	2021-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	11090Q	TITULAIRE	\N	\N
16966	PPLEGALIM	2021-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19383Y	SUPPLEANT	\N	\N
16967	PPLEGALIM	2021-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19467C	SUPPLEANT	\N	\N
16968	PPLEGALIM	2021-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20054A	SUPPLEANT	\N	\N
16969	PPLEGALIM	2021-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19441R	SUPPLEANT	\N	\N
16970	PPLEGALIM	2021-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20082E	SUPPLEANT	\N	\N
16971	PPLEGALIM	2021-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14207L	SUPPLEANT	\N	\N
16972	PPLEGALIM	2021-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19695N	SUPPLEANT	\N	\N
16973	PPLPOMPIERS	2021-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
16974	PPLPOMPIERS	2021-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20074E	TITULAIRE	\N	\N
16975	PPLPOMPIERS	2021-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	14179A	TITULAIRE	\N	\N
16976	PPLPOMPIERS	2021-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	14151M	TITULAIRE	\N	\N
16977	PPLPOMPIERS	2021-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	14021P	TITULAIRE	\N	\N
16978	PPLPOMPIERS	2021-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20128B	TITULAIRE	\N	\N
16979	PPLPOMPIERS	2021-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20108W	SUPPLEANT	\N	\N
16980	PPLPOMPIERS	2021-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	19673G	SUPPLEANT	\N	\N
16981	PPLPOMPIERS	2021-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	14147R	SUPPLEANT	\N	\N
16982	PPLPOMPIERS	2021-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	11085T	SUPPLEANT	\N	\N
16983	PPLPOMPIERS	2021-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	19725B	SUPPLEANT	\N	\N
16984	PPLPOMPIERS	2021-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	14107H	SUPPLEANT	\N	\N
16985	PPLPOMPIERS	2021-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	04085P	SUPPLEANT	\N	\N
16986	PPLPOMPIERS	2021-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	14133K	TITULAIRE	\N	\N
18871	SEPA	2021-05-12 00:00:00	2021-05-13 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	SUPPLEANT	\N	\N
18872	SEPA	2021-05-12 00:00:00	2021-05-13 00:00:00	ANCIEN	\N	\N	\N	\N	19629C	SUPPLEANT	\N	\N
18873	SEPA	2021-05-12 00:00:00	2021-05-13 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	SUPPLEANT	\N	\N
18874	SEPA	2021-05-12 00:00:00	2021-05-13 00:00:00	ANCIEN	\N	\N	\N	\N	19611R	SUPPLEANT	\N	\N
18875	SEPA	2021-05-12 00:00:00	2021-05-13 00:00:00	ANCIEN	\N	\N	\N	\N	19621T	SUPPLEANT	\N	\N
18876	SEPA	2021-05-12 00:00:00	2021-05-13 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	SUPPLEANT	\N	\N
18877	SEPA	2021-05-12 00:00:00	2021-05-13 00:00:00	ANCIEN	\N	\N	\N	\N	08011M	SUPPLEANT	\N	\N
18878	SEPA	2021-05-12 00:00:00	2021-05-13 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
18879	SEPA	2021-05-12 00:00:00	2021-05-13 00:00:00	ANCIEN	\N	\N	\N	\N	19673G	TITULAIRE	\N	\N
18880	SEPA	2021-05-12 00:00:00	2021-05-13 00:00:00	ANCIEN	\N	\N	\N	\N	19533U	TITULAIRE	\N	\N
18881	SEPA	2021-05-12 00:00:00	2021-05-13 00:00:00	ANCIEN	\N	\N	\N	\N	19749K	TITULAIRE	\N	\N
18882	SEPA	2021-05-12 00:00:00	2021-05-13 00:00:00	ANCIEN	\N	\N	\N	\N	19649G	TITULAIRE	\N	\N
18883	SEPA	2021-05-12 00:00:00	2021-05-13 00:00:00	ANCIEN	\N	\N	\N	\N	14229S	TITULAIRE	\N	\N
18884	SEPA	2021-05-12 00:00:00	2021-05-13 00:00:00	ANCIEN	\N	\N	\N	\N	11072N	TITULAIRE	\N	\N
18885	CRIS	2021-05-20 00:00:00	2021-05-21 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	SUPPLEANT	\N	\N
18886	CRIS	2021-05-20 00:00:00	2021-05-21 00:00:00	ANCIEN	\N	\N	\N	\N	08018U	SUPPLEANT	\N	\N
18887	CRIS	2021-05-20 00:00:00	2021-05-21 00:00:00	ANCIEN	\N	\N	\N	\N	14147R	SUPPLEANT	\N	\N
18888	CRIS	2021-05-20 00:00:00	2021-05-21 00:00:00	ANCIEN	\N	\N	\N	\N	11085T	SUPPLEANT	\N	\N
18889	CRIS	2021-05-20 00:00:00	2021-05-21 00:00:00	ANCIEN	\N	\N	\N	\N	14151M	SUPPLEANT	\N	\N
18890	CRIS	2021-05-20 00:00:00	2021-05-21 00:00:00	ANCIEN	\N	\N	\N	\N	19629C	SUPPLEANT	\N	\N
18891	CRIS	2021-05-20 00:00:00	2021-05-21 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	SUPPLEANT	\N	\N
18892	CRIS	2021-05-20 00:00:00	2021-05-21 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
18893	CRIS	2021-05-20 00:00:00	2021-05-21 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
18894	CRIS	2021-05-20 00:00:00	2021-05-21 00:00:00	ANCIEN	\N	\N	\N	\N	20108W	TITULAIRE	\N	\N
18895	CRIS	2021-05-20 00:00:00	2021-05-21 00:00:00	ANCIEN	\N	\N	\N	\N	14089Y	TITULAIRE	\N	\N
18896	CRIS	2021-05-20 00:00:00	2021-05-21 00:00:00	ANCIEN	\N	\N	\N	\N	19649G	TITULAIRE	\N	\N
18897	CRIS	2021-05-20 00:00:00	2021-05-21 00:00:00	ANCIEN	\N	\N	\N	\N	11026G	TITULAIRE	\N	\N
18898	CRIS	2021-05-20 00:00:00	2021-05-21 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	TITULAIRE	\N	\N
18899	CLIM	2021-07-12 00:00:00	2021-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	14187A	SUPPLEANT	\N	\N
18900	CLIM	2021-07-12 00:00:00	2021-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	14033T	SUPPLEANT	\N	\N
18901	CLIM	2021-07-12 00:00:00	2021-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	14031R	SUPPLEANT	\N	\N
18902	CLIM	2021-07-12 00:00:00	2021-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	19826F	SUPPLEANT	\N	\N
18903	CLIM	2021-07-12 00:00:00	2021-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	19599P	SUPPLEANT	\N	\N
18904	CLIM	2021-07-12 00:00:00	2021-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	19681G	SUPPLEANT	\N	\N
18905	CLIM	2021-07-12 00:00:00	2021-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	20046A	SUPPLEANT	\N	\N
18906	CLIM	2021-07-12 00:00:00	2021-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	14219Q	TITULAIRE	\N	\N
18907	CLIM	2021-07-12 00:00:00	2021-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	19701S	TITULAIRE	\N	\N
18908	CLIM	2021-07-12 00:00:00	2021-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	20136B	TITULAIRE	\N	\N
18909	CLIM	2021-07-12 00:00:00	2021-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	11090Q	TITULAIRE	\N	\N
18910	CLIM	2021-07-12 00:00:00	2021-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	19549D	TITULAIRE	\N	\N
18911	CLIM	2021-07-12 00:00:00	2021-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	14257W	TITULAIRE	\N	\N
18912	CLIM	2021-07-12 00:00:00	2021-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	19637C	TITULAIRE	\N	\N
18913	FR21	2021-07-05 00:00:00	2021-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	19741B	SUPPLEANT	\N	\N
18914	FR21	2021-07-05 00:00:00	2021-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	19762G	SUPPLEANT	\N	\N
18915	FR21	2021-07-05 00:00:00	2021-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	20022R	SUPPLEANT	\N	\N
18916	FR21	2021-07-05 00:00:00	2021-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	19479G	SUPPLEANT	\N	\N
18917	FR21	2021-07-05 00:00:00	2021-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	20070A	SUPPLEANT	\N	\N
18918	FR21	2021-07-05 00:00:00	2021-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	11012A	SUPPLEANT	\N	\N
18919	FR21	2021-07-05 00:00:00	2021-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	11040E	SUPPLEANT	\N	\N
18920	FR21	2021-07-05 00:00:00	2021-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	14225N	TITULAIRE	\N	\N
18921	FR21	2021-07-05 00:00:00	2021-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	TITULAIRE	\N	\N
18922	FR21	2021-07-05 00:00:00	2021-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	19711U	TITULAIRE	\N	\N
18923	FR21	2021-07-05 00:00:00	2021-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	20044X	TITULAIRE	\N	\N
18924	FR21	2021-07-05 00:00:00	2021-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	14327T	TITULAIRE	\N	\N
18925	FR21	2021-07-05 00:00:00	2021-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	19647E	TITULAIRE	\N	\N
18926	FR21	2021-07-05 00:00:00	2021-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	19349W	TITULAIRE	\N	\N
18927	OA13	2021-07-01 00:00:00	2021-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	19643A	SUPPLEANT	\N	\N
18928	OA13	2021-07-01 00:00:00	2021-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	20180F	SUPPLEANT	\N	\N
18929	OA13	2021-07-01 00:00:00	2021-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	07033P	SUPPLEANT	\N	\N
18930	OA13	2021-07-01 00:00:00	2021-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	04070G	SUPPLEANT	\N	\N
18931	OA13	2021-07-01 00:00:00	2021-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	08017T	SUPPLEANT	\N	\N
18932	OA13	2021-07-01 00:00:00	2021-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	20132W	SUPPLEANT	\N	\N
18933	OA13	2021-07-01 00:00:00	2021-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	20112S	SUPPLEANT	\N	\N
18934	OA13	2021-07-01 00:00:00	2021-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	19611R	TITULAIRE	\N	\N
18935	OA13	2021-07-01 00:00:00	2021-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	19399H	TITULAIRE	\N	\N
18936	OA13	2021-07-01 00:00:00	2021-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	19621T	TITULAIRE	\N	\N
18937	OA13	2021-07-01 00:00:00	2021-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	20152B	TITULAIRE	\N	\N
18938	OA13	2021-07-01 00:00:00	2021-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	04059M	TITULAIRE	\N	\N
18939	OA13	2021-07-01 00:00:00	2021-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	14229S	TITULAIRE	\N	\N
18940	OA13	2021-07-01 00:00:00	2021-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	19651A	TITULAIRE	\N	\N
18941	OECU	2021-07-01 00:00:00	2021-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	19643A	SUPPLEANT	\N	\N
18942	OECU	2021-07-01 00:00:00	2021-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	20180F	SUPPLEANT	\N	\N
18943	OECU	2021-07-01 00:00:00	2021-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	07033P	SUPPLEANT	\N	\N
18944	OECU	2021-07-01 00:00:00	2021-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	04070G	SUPPLEANT	\N	\N
18945	OECU	2021-07-01 00:00:00	2021-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	08017T	SUPPLEANT	\N	\N
18946	OECU	2021-07-01 00:00:00	2021-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	20132W	SUPPLEANT	\N	\N
18947	OECU	2021-07-01 00:00:00	2021-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	20112S	SUPPLEANT	\N	\N
18948	OECU	2021-07-01 00:00:00	2021-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	19611R	TITULAIRE	\N	\N
18949	OECU	2021-07-01 00:00:00	2021-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	19399H	TITULAIRE	\N	\N
18950	OECU	2021-07-01 00:00:00	2021-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	19621T	TITULAIRE	\N	\N
18951	OECU	2021-07-01 00:00:00	2021-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	20152B	TITULAIRE	\N	\N
18952	OECU	2021-07-01 00:00:00	2021-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	04059M	TITULAIRE	\N	\N
18953	OECU	2021-07-01 00:00:00	2021-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	14229S	TITULAIRE	\N	\N
18954	OECU	2021-07-01 00:00:00	2021-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	19651A	TITULAIRE	\N	\N
18955	INEG	2021-06-24 00:00:00	2021-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	01058X	SUPPLEANT	\N	\N
18956	INEG	2021-06-24 00:00:00	2021-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	11115U	SUPPLEANT	\N	\N
18957	INEG	2021-06-24 00:00:00	2021-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	14211G	SUPPLEANT	\N	\N
18958	INEG	2021-06-24 00:00:00	2021-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	14255U	SUPPLEANT	\N	\N
18959	INEG	2021-06-24 00:00:00	2021-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	11027H	SUPPLEANT	\N	\N
18960	INEG	2021-06-24 00:00:00	2021-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	11012A	SUPPLEANT	\N	\N
16886	HARCEL	2021-05-12 00:00:00	2021-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	20106U	\N	\N	\N
19172	PLFFG23	2023-11-21 00:00:00	2023-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	19711U	TITULAIRE	\N	\N
19173	PLFFG23	2023-11-21 00:00:00	2023-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	20044X	TITULAIRE	\N	\N
19174	PLFFG23	2023-11-21 00:00:00	2023-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	11070L	TITULAIRE	\N	\N
19175	PLFFG23	2023-11-21 00:00:00	2023-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	20070A	TITULAIRE	\N	\N
19176	PLFFG23	2023-11-21 00:00:00	2023-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	19349W	TITULAIRE	\N	\N
19177	SECR	2023-12-13 00:00:00	2023-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	20022R	SUPPLEANT	\N	\N
19178	SECR	2023-12-13 00:00:00	2023-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	14147R	SUPPLEANT	\N	\N
19179	SECR	2023-12-13 00:00:00	2023-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	19749K	SUPPLEANT	\N	\N
19180	SECR	2023-12-13 00:00:00	2023-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	19725B	SUPPLEANT	\N	\N
19181	SECR	2023-12-13 00:00:00	2023-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	11056N	SUPPLEANT	\N	\N
19182	SECR	2023-12-13 00:00:00	2023-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	20122U	SUPPLEANT	\N	\N
19183	SECR	2023-12-13 00:00:00	2023-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	20110Q	SUPPLEANT	\N	\N
19184	SECR	2023-12-13 00:00:00	2023-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
19185	SECR	2023-12-13 00:00:00	2023-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	TITULAIRE	\N	\N
19186	SECR	2023-12-13 00:00:00	2023-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	20074E	TITULAIRE	\N	\N
19187	SECR	2023-12-13 00:00:00	2023-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	14231L	TITULAIRE	\N	\N
19188	SECR	2023-12-13 00:00:00	2023-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	20114U	TITULAIRE	\N	\N
19189	SECR	2023-12-13 00:00:00	2023-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	14151M	TITULAIRE	\N	\N
19190	SECR	2023-12-13 00:00:00	2023-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	04045F	TITULAIRE	\N	\N
19191	RESTHUM	2023-12-06 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	20026V	SUPPLEANT	\N	\N
19192	RESTHUM	2023-12-06 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	21055F	SUPPLEANT	\N	\N
19193	RESTHUM	2023-12-06 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	20056C	SUPPLEANT	\N	\N
19194	RESTHUM	2023-12-06 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	14229S	SUPPLEANT	\N	\N
19195	RESTHUM	2023-12-06 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	19593H	SUPPLEANT	\N	\N
19196	RESTHUM	2023-12-06 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	20122U	SUPPLEANT	\N	\N
19197	RESTHUM	2023-12-06 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	20142Y	SUPPLEANT	\N	\N
19198	RESTHUM	2023-12-06 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	19611R	TITULAIRE	\N	\N
19199	RESTHUM	2023-12-06 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	04070G	TITULAIRE	\N	\N
19200	RESTHUM	2023-12-06 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	19621T	TITULAIRE	\N	\N
19201	RESTHUM	2023-12-06 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	20180F	TITULAIRE	\N	\N
19202	RESTHUM	2023-12-06 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	21089R	TITULAIRE	\N	\N
19203	RESTHUM	2023-12-06 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	21077M	TITULAIRE	\N	\N
19204	RESTHUM	2023-12-06 00:00:00	2023-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	19697Q	TITULAIRE	\N	\N
19205	SOINS	2023-12-07 00:00:00	2023-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	14217N	SUPPLEANT	\N	\N
19206	SOINS	2023-12-07 00:00:00	2023-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	19657G	SUPPLEANT	\N	\N
19207	SOINS	2023-12-07 00:00:00	2023-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	19691J	SUPPLEANT	\N	\N
19208	SOINS	2023-12-07 00:00:00	2023-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	19758L	SUPPLEANT	\N	\N
19209	SOINS	2023-12-07 00:00:00	2023-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	21046E	SUPPLEANT	\N	\N
19210	SOINS	2023-12-07 00:00:00	2023-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	21094N	SUPPLEANT	\N	\N
19211	SOINS	2023-12-07 00:00:00	2023-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	18193Q	SUPPLEANT	\N	\N
19212	SOINS	2023-12-07 00:00:00	2023-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	14071N	TITULAIRE	\N	\N
19213	SOINS	2023-12-07 00:00:00	2023-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	14213J	TITULAIRE	\N	\N
19214	SOINS	2023-12-07 00:00:00	2023-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	19723Y	TITULAIRE	\N	\N
19215	SOINS	2023-12-07 00:00:00	2023-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	19713W	TITULAIRE	\N	\N
19216	SOINS	2023-12-07 00:00:00	2023-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	19683J	TITULAIRE	\N	\N
19217	SOINS	2023-12-07 00:00:00	2023-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	17965H	TITULAIRE	\N	\N
19218	SOINS	2023-12-07 00:00:00	2023-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	21097R	TITULAIRE	\N	\N
17180	SOCI	2022-08-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19329S	\N	\N	\N
17181	LOIS	2022-08-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19301E	\N	\N	\N
17182	ETRD	2022-08-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20128B	\N	\N	\N
18961	INEG	2021-06-24 00:00:00	2021-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	12041X	SUPPLEANT	\N	\N
18962	INEG	2021-06-24 00:00:00	2021-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	04042C	TITULAIRE	\N	\N
18963	INEG	2021-06-24 00:00:00	2021-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	19421M	TITULAIRE	\N	\N
18964	INEG	2021-06-24 00:00:00	2021-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	19669L	TITULAIRE	\N	\N
18965	INEG	2021-06-24 00:00:00	2021-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	14133K	TITULAIRE	\N	\N
18966	INEG	2021-06-24 00:00:00	2021-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	16685X	TITULAIRE	\N	\N
18967	INEG	2021-06-24 00:00:00	2021-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	12028B	TITULAIRE	\N	\N
18968	INEG	2021-06-24 00:00:00	2021-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	TITULAIRE	\N	\N
19527	HABI	2024-03-14 00:00:00	2024-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	19575F	SUPPLEANT	\N	\N
19526	HABI	2024-03-14 00:00:00	2024-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	19768N	SUPPLEANT	\N	\N
19528	HABI	2024-03-14 00:00:00	2024-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	21050A	SUPPLEANT	\N	\N
19529	HABI	2024-03-14 00:00:00	2024-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	19647E	SUPPLEANT	\N	\N
19530	HABI	2024-03-14 00:00:00	2024-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	21075K	SUPPLEANT	\N	\N
19531	HABI	2024-03-14 00:00:00	2024-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	21070E	SUPPLEANT	\N	\N
19532	HABI	2024-03-14 00:00:00	2024-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	21092L	SUPPLEANT	\N	\N
19533	HABI	2024-03-14 00:00:00	2024-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	14187A	TITULAIRE	\N	\N
19534	HABI	2024-03-14 00:00:00	2024-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	20286Q	TITULAIRE	\N	\N
19535	HABI	2024-03-14 00:00:00	2024-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	14329V	TITULAIRE	\N	\N
19536	HABI	2024-03-14 00:00:00	2024-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	20074E	TITULAIRE	\N	\N
19537	HABI	2024-03-14 00:00:00	2024-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	19631V	TITULAIRE	\N	\N
19538	HABI	2024-03-14 00:00:00	2024-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	18207D	TITULAIRE	\N	\N
19539	HABI	2024-03-14 00:00:00	2024-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	21033Y	TITULAIRE	\N	\N
16995	AFCL	2021-10-14 00:00:00	2021-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	20266L	\N	\N	\N
17196	BIOCARBU	2023-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19575F	\N	\N	\N
17197	BIOCARBU	2023-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	17367Q	\N	\N	\N
17199	BIOCARBU	2023-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19367Y	\N	\N	\N
17201	BIOCARBU	2023-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19782L	\N	\N	\N
17202	BIOCARBU	2023-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14207L	\N	\N	\N
17204	BIOCARBU	2023-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	11053K	\N	\N	\N
17206	BIOCARBU	2023-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14357A	\N	\N	\N
17208	BIOCARBU	2023-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20140W	\N	\N	\N
17209	BIOCARBU	2023-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	17229F	\N	\N	\N
17211	BIOCARBU	2023-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19251M	\N	\N	\N
17213	BIOCARBU	2023-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20180F	\N	\N	\N
17216	BIOCARBU	2023-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20106U	\N	\N	\N
17219	BIOCARBU	2023-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20102Q	\N	\N	\N
17220	BIOCARBU	2023-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20052X	\N	\N	\N
17221	BIOCARBU	2023-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19563B	\N	\N	\N
17222	BIOCARBU	2023-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20028X	\N	\N	\N
17223	BIOCARBU	2023-01-17 00:00:00	2023-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	20096L	\N	\N	\N
17224	BIOCARBU	2023-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14237S	\N	\N	\N
17225	BIOCARBU	2023-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20030R	\N	\N	\N
17226	BIOCARBU	2023-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20092G	\N	\N	\N
17227	BIOCARBU	2023-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	11097X	\N	\N	\N
17228	BIOCARBU	2023-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19713W	\N	\N	\N
17229	BIOCARBU	2023-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20084G	\N	\N	\N
15697	CDD	2020-06-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19914E	\N	\N	\N
15698	LOIS	2020-06-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19930E	\N	\N	\N
15699	FINC	2020-06-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19762G	\N	\N	\N
16341	EGALCHAN	2021-02-03 00:00:00	2021-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	19701S	\N	\N	\N
16337	EGALCHAN	2021-02-03 00:00:00	2021-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	20078J	\N	\N	\N
16338	EGALCHAN	2021-02-03 00:00:00	2021-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	20090E	\N	\N	\N
16339	EGALCHAN	2021-02-03 00:00:00	2021-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	20086J	\N	\N	\N
16340	EGALCHAN	2021-02-03 00:00:00	2021-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	14053L	\N	\N	\N
16342	EGALCHAN	2021-02-03 00:00:00	2021-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	14123H	\N	\N	\N
16343	EGALCHAN	2021-02-03 00:00:00	2021-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	20056C	\N	\N	\N
16344	EGALCHAN	2021-02-03 00:00:00	2021-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	19581D	\N	\N	\N
16345	EGALCHAN	2021-02-03 00:00:00	2021-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	20062A	\N	\N	\N
16346	EGALCHAN	2021-02-03 00:00:00	2021-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	20058E	\N	\N	\N
16347	EGALCHAN	2021-02-03 00:00:00	2021-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	19543W	\N	\N	\N
16348	EGALCHAN	2021-02-03 00:00:00	2021-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	14179A	\N	\N	\N
16349	EGALCHAN	2021-02-03 00:00:00	2021-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	20048C	\N	\N	\N
16350	EGALCHAN	2021-02-03 00:00:00	2021-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	20052X	\N	\N	\N
16351	EGALCHAN	2021-02-03 00:00:00	2021-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	20060X	\N	\N	\N
16352	EGALCHAN	2021-02-03 00:00:00	2021-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	17779H	\N	\N	\N
16353	EGALCHAN	2021-02-03 00:00:00	2021-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	11067R	\N	\N	\N
16354	EGALCHAN	2021-02-03 00:00:00	2021-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	20084G	\N	\N	\N
16355	EGALCHAN	2021-02-03 00:00:00	2021-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	19651A	\N	\N	\N
16356	EGALCHAN	2021-02-03 00:00:00	2021-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	19866P	\N	\N	\N
16357	EGALCHAN	2021-02-03 00:00:00	2021-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	20112S	\N	\N	\N
16358	EGALCHAN	2021-02-03 00:00:00	2021-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	20122U	\N	\N	\N
16359	EGALCHAN	2021-02-03 00:00:00	2021-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	19689Q	\N	\N	\N
17187	RENOV	2023-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20090E	\N	\N	\N
17188	RENOV	2023-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	11101A	\N	\N	\N
17189	RENOV	2023-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	18083K	\N	\N	\N
17190	RENOV	2023-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19701S	\N	\N	\N
17191	RENOV	2023-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14187A	\N	\N	\N
17192	RENOV	2023-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19711U	\N	\N	\N
17193	RENOV	2023-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20062A	\N	\N	\N
17194	RENOV	2023-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	17023S	\N	\N	\N
17195	RENOV	2023-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20286Q	\N	\N	\N
17198	RENOV	2023-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20298U	\N	\N	\N
17200	RENOV	2023-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19549D	\N	\N	\N
17203	RENOV	2023-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20018V	\N	\N	\N
17205	RENOV	2023-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14257W	\N	\N	\N
17207	RENOV	2023-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19525U	\N	\N	\N
17210	RENOV	2023-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19681G	\N	\N	\N
17212	RENOV	2023-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	11077T	\N	\N	\N
17215	RENOV	2023-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14221J	\N	\N	\N
17218	RENOV	2023-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19347U	\N	\N	\N
17230	RENOV	2023-01-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20124W	\N	\N	\N
18969	CONSO	2023-10-31 00:00:00	2023-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	14187A	TITULAIRE	\N	\N
18970	CONSO	2023-10-31 00:00:00	2023-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	14205J	TITULAIRE	\N	\N
18971	CONSO	2023-10-31 00:00:00	2023-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	14329V	TITULAIRE	\N	\N
18972	CONSO	2023-10-31 00:00:00	2023-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	20054A	TITULAIRE	\N	\N
18973	CONSO	2023-10-31 00:00:00	2023-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	14257W	TITULAIRE	\N	\N
18974	CONSO	2023-10-31 00:00:00	2023-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	20082E	TITULAIRE	\N	\N
18975	CONSO	2023-10-31 00:00:00	2023-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	21096Q	TITULAIRE	\N	\N
18976	CONSO	2023-10-31 00:00:00	2023-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	14357A	TITULAIRE	\N	\N
18977	CONSO	2023-10-31 00:00:00	2023-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	19575F	TITULAIRE	\N	\N
18978	CONSO	2023-10-31 00:00:00	2023-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	19563B	TITULAIRE	\N	\N
18979	CONSO	2023-10-31 00:00:00	2023-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	20018V	TITULAIRE	\N	\N
18980	CONSO	2023-10-31 00:00:00	2023-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	21075K	TITULAIRE	\N	\N
18981	CONSO	2023-10-31 00:00:00	2023-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	21054E	TITULAIRE	\N	\N
18982	CONSO	2023-10-31 00:00:00	2023-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	21092L	TITULAIRE	\N	\N
15592	COVID19	2020-03-19 00:00:00	2020-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
15593	COVID19	2020-03-19 00:00:00	2020-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	11090Q	TITULAIRE	\N	\N
15594	COVID19	2020-03-19 00:00:00	2020-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	TITULAIRE	\N	\N
15595	COVID19	2020-03-19 00:00:00	2020-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	11085T	TITULAIRE	\N	\N
15596	COVID19	2020-03-19 00:00:00	2020-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
15597	COVID19	2020-03-19 00:00:00	2020-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19649G	TITULAIRE	\N	\N
15598	COVID19	2020-03-19 00:00:00	2020-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	TITULAIRE	\N	\N
15599	COVID19	2020-03-19 00:00:00	2020-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	14329V	SUPPLEANT	\N	\N
15600	COVID19	2020-03-19 00:00:00	2020-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19673G	SUPPLEANT	\N	\N
15601	COVID19	2020-03-19 00:00:00	2020-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	11097X	SUPPLEANT	\N	\N
15602	COVID19	2020-03-19 00:00:00	2020-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19611R	SUPPLEANT	\N	\N
15603	COVID19	2020-03-19 00:00:00	2020-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	11026G	SUPPLEANT	\N	\N
15604	COVID19	2020-03-19 00:00:00	2020-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19719D	SUPPLEANT	\N	\N
15605	COVID19	2020-03-19 00:00:00	2020-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	11033F	SUPPLEANT	\N	\N
15606	PLFR2	2020-04-21 00:00:00	2020-04-24 00:00:00	ANCIEN	\N	\N	\N	\N	11074Q	TITULAIRE	\N	\N
15607	PLFR2	2020-04-21 00:00:00	2020-04-24 00:00:00	ANCIEN	\N	\N	\N	\N	08011M	TITULAIRE	\N	\N
15608	PLFR2	2020-04-21 00:00:00	2020-04-24 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	TITULAIRE	\N	\N
15609	PLFR2	2020-04-21 00:00:00	2020-04-24 00:00:00	ANCIEN	\N	\N	\N	\N	19741B	TITULAIRE	\N	\N
15610	PLFR2	2020-04-21 00:00:00	2020-04-24 00:00:00	ANCIEN	\N	\N	\N	\N	19479G	TITULAIRE	\N	\N
15611	PLFR2	2020-04-21 00:00:00	2020-04-24 00:00:00	ANCIEN	\N	\N	\N	\N	14225N	TITULAIRE	\N	\N
15612	PLFR2	2020-04-21 00:00:00	2020-04-24 00:00:00	ANCIEN	\N	\N	\N	\N	19651A	TITULAIRE	\N	\N
15613	PLFR2	2020-04-21 00:00:00	2020-04-24 00:00:00	ANCIEN	\N	\N	\N	\N	19667J	SUPPLEANT	\N	\N
15614	PLFR2	2020-04-21 00:00:00	2020-04-24 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	SUPPLEANT	\N	\N
15615	PLFR2	2020-04-21 00:00:00	2020-04-24 00:00:00	ANCIEN	\N	\N	\N	\N	08010L	SUPPLEANT	\N	\N
15616	PLFR2	2020-04-21 00:00:00	2020-04-24 00:00:00	ANCIEN	\N	\N	\N	\N	11070L	SUPPLEANT	\N	\N
15617	PLFR2	2020-04-21 00:00:00	2020-04-24 00:00:00	ANCIEN	\N	\N	\N	\N	14085U	SUPPLEANT	\N	\N
15618	PLFR2	2020-04-21 00:00:00	2020-04-24 00:00:00	ANCIEN	\N	\N	\N	\N	14034U	SUPPLEANT	\N	\N
15619	PLFR2	2020-04-21 00:00:00	2020-04-24 00:00:00	ANCIEN	\N	\N	\N	\N	19687N	SUPPLEANT	\N	\N
16398	METHANIS	2021-02-17 00:00:00	2021-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	20032T	\N	\N	\N
16399	METHANIS	2021-02-17 00:00:00	2021-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	20076G	\N	\N	\N
16400	METHANIS	2021-02-17 00:00:00	2021-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	19782L	\N	\N	\N
16401	METHANIS	2021-02-17 00:00:00	2021-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	20144B	\N	\N	\N
16402	METHANIS	2021-02-17 00:00:00	2021-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	19681G	\N	\N	\N
16403	METHANIS	2021-02-17 00:00:00	2021-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	20070A	\N	\N	\N
16404	METHANIS	2021-02-17 00:00:00	2021-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	14357A	\N	\N	\N
16405	METHANIS	2021-02-17 00:00:00	2021-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	17229F	\N	\N	\N
16406	METHANIS	2021-02-17 00:00:00	2021-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	19507S	\N	\N	\N
16407	METHANIS	2021-02-17 00:00:00	2021-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	19820Y	\N	\N	\N
16408	METHANIS	2021-02-17 00:00:00	2021-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	14033T	\N	\N	\N
16409	METHANIS	2021-02-17 00:00:00	2021-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	\N	\N	\N
16410	METHANIS	2021-02-17 00:00:00	2021-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	20126Y	\N	\N	\N
16411	METHANIS	2021-02-17 00:00:00	2021-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	20102Q	\N	\N	\N
16412	METHANIS	2021-02-17 00:00:00	2021-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	19711U	\N	\N	\N
16413	METHANIS	2021-02-17 00:00:00	2021-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	20050V	\N	\N	\N
16414	METHANIS	2021-02-17 00:00:00	2021-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	14237S	\N	\N	\N
16415	METHANIS	2021-02-17 00:00:00	2021-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	19503N	\N	\N	\N
16416	METHANIS	2021-02-17 00:00:00	2021-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	19739H	\N	\N	\N
16417	METHANIS	2021-02-17 00:00:00	2021-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	20054A	\N	\N	\N
16418	METHANIS	2021-02-17 00:00:00	2021-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	19619A	\N	\N	\N
16419	METHANIS	2021-02-17 00:00:00	2021-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	20092G	\N	\N	\N
16420	METHANIS	2021-02-17 00:00:00	2021-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	19413M	\N	\N	\N
16421	VIETUDIA	2021-02-17 00:00:00	2021-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	04059M	\N	\N	\N
16422	VIETUDIA	2021-02-17 00:00:00	2021-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	19954N	\N	\N	\N
16423	VIETUDIA	2021-02-17 00:00:00	2021-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	19643A	\N	\N	\N
16424	VIETUDIA	2021-02-17 00:00:00	2021-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	20114U	\N	\N	\N
16425	VIETUDIA	2021-02-17 00:00:00	2021-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	19721W	\N	\N	\N
16426	VIETUDIA	2021-02-17 00:00:00	2021-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	11115U	\N	\N	\N
16427	VIETUDIA	2021-02-17 00:00:00	2021-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	19693L	\N	\N	\N
16428	VIETUDIA	2021-02-17 00:00:00	2021-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	20132W	\N	\N	\N
16429	VIETUDIA	2021-02-17 00:00:00	2021-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	20172F	\N	\N	\N
16430	VIETUDIA	2021-02-17 00:00:00	2021-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	20180F	\N	\N	\N
16431	VIETUDIA	2021-02-17 00:00:00	2021-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	19591F	\N	\N	\N
16432	VIETUDIA	2021-02-17 00:00:00	2021-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	19715Y	\N	\N	\N
16433	VIETUDIA	2021-02-17 00:00:00	2021-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	19735D	\N	\N	\N
16434	VIETUDIA	2021-02-17 00:00:00	2021-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	19611R	\N	\N	\N
16435	VIETUDIA	2021-02-17 00:00:00	2021-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	14059S	\N	\N	\N
16436	VIETUDIA	2021-02-17 00:00:00	2021-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	20142Y	\N	\N	\N
16437	VIETUDIA	2021-02-17 00:00:00	2021-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	14147R	\N	\N	\N
16438	VIETUDIA	2021-02-17 00:00:00	2021-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	20096L	\N	\N	\N
16439	VIETUDIA	2021-02-17 00:00:00	2021-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	19593H	\N	\N	\N
16440	VIETUDIA	2021-02-17 00:00:00	2021-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	20050V	\N	\N	\N
16441	VIETUDIA	2021-02-17 00:00:00	2021-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	19745F	\N	\N	\N
16442	VIETUDIA	2021-02-17 00:00:00	2021-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	19533U	\N	\N	\N
16443	VIETUDIA	2021-02-17 00:00:00	2021-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	20082E	\N	\N	\N
17173	AFEU	2022-03-01 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20286Q	\N	\N	\N
18333	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20130U	\N	\N	\N
18334	SOCI	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21094N	\N	\N	\N
18335	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21073H	\N	\N	\N
18336	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19347U	\N	\N	\N
18337	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20110Q	\N	\N	\N
18338	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20266L	\N	\N	\N
18339	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20036X	\N	\N	\N
18382	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	12028B	\N	\N	\N
18383	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	11027H	\N	\N	\N
18384	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21067K	\N	\N	\N
18385	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19531S	\N	\N	\N
18386	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14097Y	\N	\N	\N
18387	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14001X	\N	\N	\N
18388	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19669L	\N	\N	\N
18389	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20064C	\N	\N	\N
18390	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21031W	\N	\N	\N
18400	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19631V	\N	\N	\N
18401	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20088L	\N	\N	\N
18402	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20060X	\N	\N	\N
18403	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20028X	\N	\N	\N
18404	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20018V	\N	\N	\N
18405	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14257W	\N	\N	\N
18406	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20030R	\N	\N	\N
18407	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20082E	\N	\N	\N
18408	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20084G	\N	\N	\N
18409	CAE	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19413M	\N	\N	\N
18419	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14189C	\N	\N	\N
18420	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14089Y	\N	\N	\N
18421	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19111A	\N	\N	\N
18422	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14231L	\N	\N	\N
18423	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	11085T	\N	\N	\N
18424	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21038E	\N	\N	\N
18425	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14275Y	\N	\N	\N
18426	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19749K	\N	\N	\N
18427	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21042A	\N	\N	\N
18428	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	17229F	\N	\N	\N
18429	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	15197G	\N	\N	\N
18430	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19685L	\N	\N	\N
18431	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14219Q	\N	\N	\N
18432	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19826F	\N	\N	\N
18433	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21053D	\N	\N	\N
18434	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19619A	\N	\N	\N
18443	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20042V	\N	\N	\N
18444	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14255U	\N	\N	\N
18445	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19721W	\N	\N	\N
18446	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14267Y	\N	\N	\N
18447	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	11115U	\N	\N	\N
18448	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	17023S	\N	\N	\N
18449	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14179A	\N	\N	\N
18450	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19745F	\N	\N	\N
18983	SER	2023-11-07 00:00:00	2023-11-09 00:00:00	ANCIEN	\N	\N	\N	\N	14219Q	TITULAIRE	\N	\N
18984	SER	2023-11-07 00:00:00	2023-11-09 00:00:00	ANCIEN	\N	\N	\N	\N	20136B	TITULAIRE	\N	\N
18985	SER	2023-11-07 00:00:00	2023-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	14031R	TITULAIRE	\N	\N
18986	SER	2023-11-07 00:00:00	2023-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	20120S	TITULAIRE	\N	\N
18987	SER	2023-11-07 00:00:00	2023-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	19820Y	TITULAIRE	\N	\N
18988	SER	2023-11-07 00:00:00	2023-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	21051B	TITULAIRE	\N	\N
18989	SER	2023-11-07 00:00:00	2023-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	20106U	TITULAIRE	\N	\N
18990	SER	2023-11-07 00:00:00	2023-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	18083K	SUPPLEANT	\N	\N
18991	SER	2023-11-07 00:00:00	2023-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	19701S	SUPPLEANT	\N	\N
18992	SER	2023-11-07 00:00:00	2023-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	15197G	SUPPLEANT	\N	\N
18993	SER	2023-11-07 00:00:00	2023-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	19251M	SUPPLEANT	\N	\N
18994	SER	2023-11-07 00:00:00	2023-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	21084L	SUPPLEANT	\N	\N
18997	NARCO	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	20110Q	\N	\N	\N
18995	SER	2023-11-07 00:00:00	2023-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	19693L	SUPPLEANT	\N	\N
18996	SER	2023-11-07 00:00:00	2023-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	20100N	SUPPLEANT	\N	\N
18998	NARCO	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	17367Q	\N	\N	\N
18999	NARCO	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	20078J	\N	\N	\N
19000	NARCO	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	17737W	\N	\N	\N
19001	NARCO	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	21088Q	\N	\N	\N
19002	NARCO	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	20090E	\N	\N	\N
19003	NARCO	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	14255U	\N	\N	\N
19004	NARCO	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	12028B	\N	\N	\N
19006	NARCO	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	21072G	\N	\N	\N
19007	NARCO	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	19295A	\N	\N	\N
19008	NARCO	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	18395Y	\N	\N	\N
19009	NARCO	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	15197G	\N	\N	\N
19010	NARCO	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	14151M	\N	\N	\N
19011	NARCO	2023-11-08 00:00:00	2024-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	99004R	\N	\N	\N
19012	NARCO	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	21081H	\N	\N	\N
19013	NARCO	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	20108W	\N	\N	\N
19014	NARCO	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	20252E	\N	\N	\N
19015	NARCO	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	19826F	\N	\N	\N
19016	NARCO	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	21040X	\N	\N	\N
19017	NARCO	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	19563B	\N	\N	\N
19018	NARCO	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	20050V	\N	\N	\N
19019	NARCO	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	20146D	\N	\N	\N
19020	NARCO	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	19349W	\N	\N	\N
8128	AFCL	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11043H	\N	\N	2017-10-04 00:00:00
17439	BREXIT3	2020-01-31 00:00:00	\N	ACTIF	\N	\N	\N	\N	20104S	\N	\N	\N
17440	BREXIT3	2020-01-31 00:00:00	\N	ACTIF	\N	\N	\N	\N	14357A	\N	\N	\N
17441	BREXIT3	2020-01-31 00:00:00	\N	ACTIF	\N	\N	\N	\N	19725B	\N	\N	\N
17442	BREXIT3	2020-01-31 00:00:00	\N	ACTIF	\N	\N	\N	\N	14097Y	\N	\N	\N
17443	BREXIT3	2020-01-31 00:00:00	\N	ACTIF	\N	\N	\N	\N	14073Q	\N	\N	\N
17444	BREXIT3	2020-01-31 00:00:00	\N	ACTIF	\N	\N	\N	\N	12041X	\N	\N	\N
17445	BREXIT3	2020-01-31 00:00:00	\N	ACTIF	\N	\N	\N	\N	14001X	\N	\N	\N
17446	BREXIT3	2020-01-31 00:00:00	\N	ACTIF	\N	\N	\N	\N	04057K	\N	\N	\N
17447	BREXIT3	2020-01-31 00:00:00	\N	ACTIF	\N	\N	\N	\N	04070G	\N	\N	\N
17448	BREXIT3	2020-01-31 00:00:00	\N	ACTIF	\N	\N	\N	\N	14331P	\N	\N	\N
17449	BREXIT3	2020-01-31 00:00:00	\N	ACTIF	\N	\N	\N	\N	04042C	\N	\N	\N
17450	BREXIT3	2020-01-31 00:00:00	\N	ACTIF	\N	\N	\N	\N	14133K	\N	\N	\N
17451	BREXIT3	2020-01-31 00:00:00	\N	ACTIF	\N	\N	\N	\N	14255U	\N	\N	\N
17452	BREXIT3	2020-01-31 00:00:00	\N	ACTIF	\N	\N	\N	\N	11115U	\N	\N	\N
17453	BREXIT3	2020-01-31 00:00:00	\N	ACTIF	\N	\N	\N	\N	04035D	\N	\N	\N
17454	BREXIT3	2020-01-31 00:00:00	\N	ACTIF	\N	\N	\N	\N	11083R	\N	\N	\N
17455	BREXIT3	2020-01-31 00:00:00	\N	ACTIF	\N	\N	\N	\N	19347U	\N	\N	\N
17456	BREXIT3	2020-01-31 00:00:00	\N	ACTIF	\N	\N	\N	\N	98022P	\N	\N	\N
17457	BREXIT3	2020-01-31 00:00:00	\N	ACTIF	\N	\N	\N	\N	19709B	\N	\N	\N
17458	BREXIT3	2020-01-31 00:00:00	\N	ACTIF	\N	\N	\N	\N	01062T	\N	\N	\N
17543	ESNU	2023-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20022R	\N	\N	\N
17544	ESNU	2023-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20138D	\N	\N	\N
17545	ESNU	2023-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20152B	\N	\N	\N
17546	ESNU	2023-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19383Y	\N	\N	\N
17547	ESNU	2023-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14038Y	\N	\N	\N
17548	ESNU	2023-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20140W	\N	\N	\N
17549	ESNU	2023-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14026U	\N	\N	\N
17550	ESNU	2023-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20034V	\N	\N	\N
17551	ESNU	2023-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14147R	\N	\N	\N
17552	ESNU	2023-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20096L	\N	\N	\N
17553	ESNU	2023-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19768N	\N	\N	\N
17554	ESNU	2023-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14237S	\N	\N	\N
17555	ESNU	2023-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	10015M	\N	\N	\N
17556	ESNU	2023-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20098N	\N	\N	\N
17557	ESNU	2023-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20062A	\N	\N	\N
17558	ESNU	2023-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14189C	\N	\N	\N
17559	ESNU	2023-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14030Q	\N	\N	\N
17560	ESNU	2023-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14179A	\N	\N	\N
17561	ESNU	2023-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20052X	\N	\N	\N
17562	ESNU	2023-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14205J	\N	\N	\N
17563	ESNU	2023-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04070G	\N	\N	\N
17564	ESNU	2023-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20094J	\N	\N	\N
17565	ESNU	2023-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20060X	\N	\N	\N
17566	ESNU	2023-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14151M	\N	\N	\N
17567	ESNU	2023-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19647E	\N	\N	\N
17568	ESNU	2023-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20082E	\N	\N	\N
17569	ESNU	2023-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14229S	\N	\N	\N
17570	ESNU	2023-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11045K	\N	\N	\N
17571	ESNU	2023-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19591F	\N	\N	\N
17572	ESNU	2023-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19651A	\N	\N	\N
17573	ESNU	2023-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20128B	\N	\N	\N
17574	ESNU	2023-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20132W	\N	\N	\N
17575	ESNU	2023-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19719D	\N	\N	\N
17576	ESNU	2023-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11077T	\N	\N	\N
17577	ESNU	2023-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19593H	\N	\N	\N
17578	ESNU	2023-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20122U	\N	\N	\N
17579	ESNU	2023-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20134Y	\N	\N	\N
10117	CDD	2014-10-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14051J	\N	2014-10-08 16:54:14	2017-10-04 19:46:42
11706	2015CMP24	2015-11-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14051J	TITULAIRE	\N	\N
15951	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20144B	\N	\N	\N
16210	SOCI	2020-11-03 00:00:00	2021-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	20172F	\N	\N	\N
16211	CAE	2020-11-03 00:00:00	2022-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	20174H	\N	\N	\N
16212	ETRD	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14249W	\N	\N	\N
16222	EMPL	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	10006L	TITULAIRE	\N	\N
16223	EMPL	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	19679N	TITULAIRE	\N	\N
16224	EMPL	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	14071N	TITULAIRE	\N	\N
16225	EMPL	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	14042U	TITULAIRE	\N	\N
16226	EMPL	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	17779H	TITULAIRE	\N	\N
16227	EMPL	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	11067R	TITULAIRE	\N	\N
16228	EMPL	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	19591F	TITULAIRE	\N	\N
16229	EMPL	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	14217N	SUPPLEANT	\N	\N
16230	EMPL	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	14026U	SUPPLEANT	\N	\N
16231	EMPL	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	04043D	SUPPLEANT	\N	\N
16232	EMPL	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	19713W	SUPPLEANT	\N	\N
16233	EMPL	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	14281W	SUPPLEANT	\N	\N
16234	EMPL	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	19553Y	SUPPLEANT	\N	\N
16235	EMPL	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	11031D	SUPPLEANT	\N	\N
18213	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	08047A	\N	\N	\N
18214	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14055N	\N	\N	\N
18215	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	08056B	\N	\N	\N
10080	ETRD	2014-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08056B	\N	2014-10-08 00:00:00	2017-10-04 00:00:00
18216	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14249W	\N	\N	\N
18217	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20128B	\N	\N	\N
18218	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14193X	\N	\N	\N
18219	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	98022P	\N	\N	\N
18220	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14255U	\N	\N	\N
18221	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14133K	\N	\N	\N
18222	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14191V	\N	\N	\N
18223	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14059S	\N	\N	\N
18224	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	95041E	\N	\N	\N
18225	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	08069G	\N	\N	\N
18226	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20072C	\N	\N	\N
18227	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20064C	\N	\N	\N
18228	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	17023S	\N	\N	\N
18229	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20042V	\N	\N	\N
18230	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	12028B	\N	\N	\N
18231	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	08061X	\N	\N	\N
18232	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14097Y	\N	\N	\N
18233	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14211G	\N	\N	\N
18234	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19721W	\N	\N	\N
18235	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14105F	\N	\N	\N
17117	HOPITAL	2021-12-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	19691J	\N	\N	\N
17118	HOPITAL	2021-12-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	19735D	\N	\N	\N
17119	HOPITAL	2021-12-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19713W	\N	\N	\N
17120	JUDI	2021-12-01 00:00:00	2022-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	14089Y	\N	\N	\N
17121	JUDI	2021-12-01 00:00:00	2022-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	20040T	\N	\N	\N
17122	JUDI	2021-12-01 00:00:00	2022-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	19826F	\N	\N	\N
17123	JUDI	2021-12-01 00:00:00	2022-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	19749K	\N	\N	\N
17124	JUDI	2021-12-01 00:00:00	2022-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	14107H	\N	\N	\N
18006	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19705W	\N	\N	\N
18007	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	11027H	\N	\N	\N
18008	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19709B	\N	\N	\N
18009	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21037D	\N	\N	\N
18010	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21038E	\N	\N	\N
18011	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01058X	\N	\N	\N
18029	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21048G	\N	\N	\N
18034	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19447X	\N	\N	\N
18035	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21050A	\N	\N	\N
18036	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21051B	\N	\N	\N
18037	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21052C	\N	\N	\N
18038	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21053D	\N	\N	\N
18039	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21054E	\N	\N	\N
18040	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21055F	\N	\N	\N
18084	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19687N	\N	\N	\N
18085	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19611R	\N	\N	\N
18088	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19711U	\N	\N	\N
18089	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19593H	\N	\N	\N
18091	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21073H	\N	\N	\N
18093	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14329V	\N	\N	\N
18094	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14357A	\N	\N	\N
18095	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	11074Q	\N	\N	\N
18096	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21075K	\N	\N	\N
18097	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21076L	\N	\N	\N
18101	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21078N	\N	\N	\N
18124	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19565D	\N	\N	\N
18125	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21083K	\N	\N	\N
18126	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	04008A	\N	\N	\N
18127	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	15197G	\N	\N	\N
18128	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19667J	\N	\N	\N
18129	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19673G	\N	\N	\N
18130	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19669L	\N	\N	\N
18133	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21085M	\N	\N	\N
18134	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21086N	\N	\N	\N
18136	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19585H	\N	\N	\N
18144	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21092L	\N	\N	\N
18145	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21093M	\N	\N	\N
18146	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19683J	\N	\N	\N
18147	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21094N	\N	\N	\N
18148	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21095P	\N	\N	\N
10747	2014CMP32	2014-12-12 00:00:00	2020-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	14199E	SUPPLEANT	\N	\N
16103	AFEU	2020-10-07 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14189C	\N	\N	\N
16104	AFEU	2020-10-07 00:00:00	2022-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	20112S	\N	\N	\N
16105	AFEU	2020-10-07 00:00:00	2022-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	14207L	\N	\N	\N
16106	AFEU	2020-10-07 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20104S	\N	\N	\N
16107	AFEU	2020-10-07 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	11101A	\N	\N	\N
16108	AFEU	2020-10-07 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19701S	\N	\N	\N
16109	AFEU	2020-10-07 00:00:00	2023-02-28 00:00:00	ANCIEN	\N	\N	\N	\N	19507S	\N	\N	\N
16110	AFEU	2020-10-07 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20100N	\N	\N	\N
16111	AFEU	2020-10-07 00:00:00	2021-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	19521Q	\N	\N	\N
16112	AFEU	2020-10-07 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20128B	\N	\N	\N
16113	AFEU	2020-10-07 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19531S	\N	\N	\N
16114	AFEU	2020-10-07 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	08034U	\N	\N	\N
16115	AFEU	2020-10-07 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19441R	\N	\N	\N
16116	AFEU	2020-10-07 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	12016W	\N	\N	\N
16117	AFEU	2020-10-07 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	04070G	\N	\N	\N
16118	AFEU	2020-10-07 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14169X	\N	\N	\N
16119	AFEU	2020-10-07 00:00:00	2020-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	19413M	\N	\N	\N
16120	AFEU	2020-10-07 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20098N	\N	\N	\N
16121	AFEU	2020-10-07 00:00:00	2020-11-25 00:00:00	ANCIEN	\N	\N	\N	\N	11066Q	\N	\N	\N
16122	AFEU	2020-10-07 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	\N	\N	\N
16123	NEANT	2017-10-02 00:00:00	2017-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	07033P	\N	\N	\N
16124	AFCL	2007-12-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	07033P	\N	\N	\N
11501	FINC	2015-09-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14327T	\N	2015-09-14 00:00:00	2017-10-04 00:00:00
16250	CESE	2020-10-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
16251	CESE	2020-10-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
16252	CESE	2020-10-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	19447X	TITULAIRE	\N	\N
16253	CESE	2020-10-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	19543W	TITULAIRE	\N	\N
16254	CESE	2020-10-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	11026G	TITULAIRE	\N	\N
16255	CESE	2020-10-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	14151M	TITULAIRE	\N	\N
16256	CESE	2020-10-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	19591F	TITULAIRE	\N	\N
16257	CESE	2020-10-30 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	SUPPLEANT	\N	\N
16258	CESE	2020-10-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	14215L	SUPPLEANT	\N	\N
16259	CESE	2020-10-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	19673G	SUPPLEANT	\N	\N
16260	CESE	2020-10-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	11085T	SUPPLEANT	\N	\N
16261	CESE	2020-10-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	19649G	SUPPLEANT	\N	\N
16262	CESE	2020-10-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	04085P	SUPPLEANT	\N	\N
16263	CESE	2020-10-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	14107H	SUPPLEANT	\N	\N
16264	CSE	2020-10-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
16265	CSE	2020-10-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
16266	CSE	2020-10-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	19447X	TITULAIRE	\N	\N
16267	CSE	2020-10-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	19543W	TITULAIRE	\N	\N
16268	CSE	2020-10-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	19649G	TITULAIRE	\N	\N
16269	CSE	2020-10-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	11026G	TITULAIRE	\N	\N
16270	CSE	2020-10-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	20106U	TITULAIRE	\N	\N
16271	CSE	2020-10-30 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	SUPPLEANT	\N	\N
16272	CSE	2020-10-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	14215L	SUPPLEANT	\N	\N
16273	CSE	2020-10-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	19673G	SUPPLEANT	\N	\N
16274	CSE	2020-10-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	11085T	SUPPLEANT	\N	\N
16275	CSE	2020-10-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	14151M	SUPPLEANT	\N	\N
16276	CSE	2020-10-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	19629C	SUPPLEANT	\N	\N
16277	CSE	2020-10-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	04085P	SUPPLEANT	\N	\N
16278	PHYT	2020-10-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	11090Q	TITULAIRE	\N	\N
16279	PHYT	2020-10-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	14357A	TITULAIRE	\N	\N
16280	PHYT	2020-10-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	20118Y	TITULAIRE	\N	\N
16281	PHYT	2020-10-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	19441R	TITULAIRE	\N	\N
16282	PHYT	2020-10-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	19503N	TITULAIRE	\N	\N
16283	PHYT	2020-10-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	19413M	TITULAIRE	\N	\N
16284	PHYT	2020-10-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	19637C	TITULAIRE	\N	\N
16285	PHYT	2020-10-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	20024T	SUPPLEANT	\N	\N
16286	PHYT	2020-10-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	14038Y	SUPPLEANT	\N	\N
16287	PHYT	2020-10-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	14033T	SUPPLEANT	\N	\N
16288	PHYT	2020-10-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	19369B	SUPPLEANT	\N	\N
16289	PHYT	2020-10-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	14207L	SUPPLEANT	\N	\N
16290	PHYT	2020-10-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	19695N	SUPPLEANT	\N	\N
16291	PHYT	2020-10-29 00:00:00	\N	ACTIF	\N	\N	\N	\N	14257W	SUPPLEANT	\N	\N
19377	INFLU	2024-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20086J	\N	\N	\N
15868	NEANT	2020-08-03 00:00:00	2020-08-08 00:00:00	ANCIEN	\N	\N	\N	\N	19966S	\N	\N	\N
16384	RECHERCH	2021-02-15 00:00:00	2021-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	19611R	TITULAIRE	\N	\N
16385	RECHERCH	2021-02-15 00:00:00	2021-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	19693L	TITULAIRE	\N	\N
16386	RECHERCH	2021-02-15 00:00:00	2021-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	19533U	TITULAIRE	\N	\N
16387	RECHERCH	2021-02-15 00:00:00	2021-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	14331P	TITULAIRE	\N	\N
16388	RECHERCH	2021-02-15 00:00:00	2021-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	14109K	TITULAIRE	\N	\N
16389	RECHERCH	2021-02-15 00:00:00	2021-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	14229S	TITULAIRE	\N	\N
16390	RECHERCH	2021-02-15 00:00:00	2021-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	19651A	TITULAIRE	\N	\N
16391	RECHERCH	2021-02-15 00:00:00	2021-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	19621T	TITULAIRE	\N	\N
16392	RECHERCH	2021-02-15 00:00:00	2021-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	19573D	TITULAIRE	\N	\N
16393	RECHERCH	2021-02-15 00:00:00	2021-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	19399H	TITULAIRE	\N	\N
16394	RECHERCH	2021-02-15 00:00:00	2021-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	20048C	TITULAIRE	\N	\N
16395	RECHERCH	2021-02-15 00:00:00	2021-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	08017T	TITULAIRE	\N	\N
16396	RECHERCH	2021-02-15 00:00:00	2021-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	20132W	TITULAIRE	\N	\N
16397	RECHERCH	2021-02-15 00:00:00	2021-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	19593H	TITULAIRE	\N	\N
17115	HOPITAL	2021-12-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	19301E	\N	\N	\N
17116	JUDI	2021-12-01 00:00:00	2022-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	\N	\N	\N
17459	RETRAITES	2023-03-30 00:00:00	2023-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	10006L	TITULAIRE	\N	\N
17460	RETRAITES	2023-03-30 00:00:00	2023-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	11097X	TITULAIRE	\N	\N
17461	RETRAITES	2023-03-29 00:00:00	2023-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	14071N	TITULAIRE	\N	\N
17462	RETRAITES	2023-03-30 00:00:00	2023-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	14042U	TITULAIRE	\N	\N
17463	RETRAITES	2023-03-29 00:00:00	2023-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	17779H	TITULAIRE	\N	\N
17464	RETRAITES	2023-03-29 00:00:00	2023-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	14281W	TITULAIRE	\N	\N
17465	RETRAITES	2023-03-29 00:00:00	2023-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	19591F	TITULAIRE	\N	\N
17466	RETRAITES	2023-03-29 00:00:00	2023-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	SUPPLEANT	\N	\N
17467	RETRAITES	2023-03-29 00:00:00	2023-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	14026U	SUPPLEANT	\N	\N
17468	RETRAITES	2023-03-29 00:00:00	2023-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	14217N	SUPPLEANT	\N	\N
17469	RETRAITES	2023-03-29 00:00:00	2023-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	19479G	SUPPLEANT	\N	\N
17470	RETRAITES	2023-03-29 00:00:00	2023-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	20130U	SUPPLEANT	\N	\N
17471	RETRAITES	2023-03-29 00:00:00	2023-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	14207L	SUPPLEANT	\N	\N
17472	RETRAITES	2023-03-29 00:00:00	2023-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	19760E	SUPPLEANT	\N	\N
17487	RELCOM	2023-03-15 00:00:00	2023-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	14329V	SUPPLEANT	\N	\N
17488	RELCOM	2023-03-15 00:00:00	2023-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	19467C	SUPPLEANT	\N	\N
17489	RELCOM	2023-03-15 00:00:00	2023-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	20054A	SUPPLEANT	\N	\N
17490	RELCOM	2023-03-15 00:00:00	2023-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	20286Q	SUPPLEANT	\N	\N
17491	RELCOM	2023-03-15 00:00:00	2023-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	14257W	SUPPLEANT	\N	\N
17492	RELCOM	2023-03-15 00:00:00	2023-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	14207L	SUPPLEANT	\N	\N
17493	RELCOM	2023-03-15 00:00:00	2023-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	19695N	SUPPLEANT	\N	\N
17494	RELCOM	2023-03-15 00:00:00	2023-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	11090Q	TITULAIRE	\N	\N
17495	RELCOM	2023-03-15 00:00:00	2023-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	14033T	TITULAIRE	\N	\N
17496	RELCOM	2023-03-15 00:00:00	2023-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	19507S	TITULAIRE	\N	\N
17497	RELCOM	2023-03-15 00:00:00	2023-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	14205J	TITULAIRE	\N	\N
17498	RELCOM	2023-03-15 00:00:00	2023-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	20028X	TITULAIRE	\N	\N
17499	RELCOM	2023-03-15 00:00:00	2023-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	20030R	TITULAIRE	\N	\N
17500	RELCOM	2023-03-15 00:00:00	2023-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	14037X	TITULAIRE	\N	\N
15839	PLFR3	2020-07-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	99004R	TITULAIRE	\N	\N
15837	PLFR3	2020-07-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	11074Q	TITULAIRE	\N	\N
15838	PLFR3	2020-07-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	08011M	TITULAIRE	\N	\N
15840	PLFR3	2020-07-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19711U	TITULAIRE	\N	\N
15841	PLFR3	2020-07-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	11053K	TITULAIRE	\N	\N
15842	PLFR3	2020-07-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19531S	TITULAIRE	\N	\N
15843	PLFR3	2020-07-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19651A	TITULAIRE	\N	\N
15844	PLFR3	2020-07-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19741B	SUPPLEANT	\N	\N
15845	PLFR3	2020-07-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	11048N	SUPPLEANT	\N	\N
15846	PLFR3	2020-07-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19762G	SUPPLEANT	\N	\N
15847	PLFR3	2020-07-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	07004J	SUPPLEANT	\N	\N
15848	PLFR3	2020-07-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	12016W	SUPPLEANT	\N	\N
15849	PLFR3	2020-07-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	11012A	SUPPLEANT	\N	\N
15850	PLFR3	2020-07-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19687N	SUPPLEANT	\N	\N
15851	SURETE	2020-07-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
15852	SURETE	2020-07-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	19673G	TITULAIRE	\N	\N
15853	SURETE	2020-07-21 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	TITULAIRE	\N	\N
15854	SURETE	2020-07-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	14089Y	TITULAIRE	\N	\N
15855	SURETE	2020-07-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	19649G	TITULAIRE	\N	\N
15856	SURETE	2020-07-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	11026G	TITULAIRE	\N	\N
15857	SURETE	2020-07-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	19543W	TITULAIRE	\N	\N
15858	SURETE	2020-07-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	14215L	SUPPLEANT	\N	\N
15859	SURETE	2020-07-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	14147R	SUPPLEANT	\N	\N
15860	SURETE	2020-07-21 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	SUPPLEANT	\N	\N
15861	SURETE	2020-07-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	01024M	SUPPLEANT	\N	\N
15862	SURETE	2020-07-21 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14065Q	SUPPLEANT	\N	\N
15863	SURETE	2020-07-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	19629C	SUPPLEANT	\N	\N
15864	SURETE	2020-07-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	11033F	SUPPLEANT	\N	\N
15877	NEANT	2020-09-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20014R	\N	\N	\N
15890	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20038A	\N	\N	\N
15895	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20046A	\N	\N	\N
15898	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20052X	\N	\N	\N
15900	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20056C	\N	\N	\N
7808	2011CMP8	2011-06-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04097T	SUPPLEANT	\N	\N
15902	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20060X	\N	\N	\N
15903	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20062A	\N	\N	\N
15904	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	17229F	\N	\N	\N
15906	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20066E	\N	\N	\N
15918	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20088L	\N	\N	\N
15919	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20090E	\N	\N	\N
7926	2011CMP16	2011-07-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98035U	SUPPLEANT	\N	\N
15920	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20092G	\N	\N	\N
15929	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	17737W	\N	\N	\N
15930	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20108W	\N	\N	\N
15931	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20110Q	\N	\N	\N
15932	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20112S	\N	\N	\N
15933	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	12028B	\N	\N	\N
15938	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20120S	\N	\N	\N
15943	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20130U	\N	\N	\N
15944	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	17367Q	\N	\N	\N
17989	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19489J	\N	\N	\N
15946	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20134Y	\N	\N	\N
9101	2012CMP27	2012-12-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	SUPPLEANT	\N	\N
10428	2014CMP9	2014-05-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	TITULAIRE	\N	\N
17990	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	17779H	\N	\N	\N
18016	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21042A	\N	\N	\N
17992	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14042U	\N	\N	\N
17996	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	07004J	\N	\N	\N
18017	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	18083K	\N	\N	\N
18022	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19383Y	\N	\N	\N
18023	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19387D	\N	\N	\N
18024	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21045D	\N	\N	\N
18105	NEANT	2023-10-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	86034E	\N	\N	\N
18106	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	11090Q	\N	\N	\N
18107	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19701S	\N	\N	\N
16600	ELECTPDR	2021-03-02 00:00:00	2021-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	SUPPLEANT	\N	\N
16601	ELECTPDR	2021-03-02 00:00:00	2021-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	19447X	SUPPLEANT	\N	\N
16602	ELECTPDR	2021-03-02 00:00:00	2021-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	14147R	SUPPLEANT	\N	\N
16603	ELECTPDR	2021-03-02 00:00:00	2021-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	11085T	SUPPLEANT	\N	\N
16604	ELECTPDR	2021-03-02 00:00:00	2021-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	14151M	SUPPLEANT	\N	\N
16605	ELECTPDR	2021-03-02 00:00:00	2021-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	19629C	SUPPLEANT	\N	\N
16606	ELECTPDR	2021-03-02 00:00:00	2021-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	SUPPLEANT	\N	\N
16607	ELECTPDR	2021-03-02 00:00:00	2021-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
16608	ELECTPDR	2021-03-02 00:00:00	2021-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	20108W	TITULAIRE	\N	\N
16615	DDADUEF	2020-10-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	19711U	SUPPLEANT	\N	\N
16610	ELECTPDR	2021-03-02 00:00:00	2021-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	08018U	TITULAIRE	\N	\N
16611	ELECTPDR	2021-03-02 00:00:00	2021-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	19543W	TITULAIRE	\N	\N
16612	ELECTPDR	2021-03-02 00:00:00	2021-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	19489J	TITULAIRE	\N	\N
16613	ELECTPDR	2021-03-02 00:00:00	2021-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
16614	ELECTPDR	2021-03-02 00:00:00	2021-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	TITULAIRE	\N	\N
16616	DDADUEF	2020-10-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	14033T	SUPPLEANT	\N	\N
16617	DDADUEF	2020-10-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	14331P	SUPPLEANT	\N	\N
16618	DDADUEF	2020-10-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	19441R	SUPPLEANT	\N	\N
16619	DDADUEF	2020-10-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	19631V	SUPPLEANT	\N	\N
16620	DDADUEF	2020-10-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	11012A	SUPPLEANT	\N	\N
16621	DDADUEF	2020-10-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	11040E	SUPPLEANT	\N	\N
16622	DDADUEF	2020-10-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	96004D	TITULAIRE	\N	\N
16623	DDADUEF	2020-10-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	19507S	TITULAIRE	\N	\N
16624	DDADUEF	2020-10-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	14225N	TITULAIRE	\N	\N
16625	DDADUEF	2020-10-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	08034U	TITULAIRE	\N	\N
16626	DDADUEF	2020-10-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	14083S	TITULAIRE	\N	\N
16627	DDADUEF	2020-10-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	19531S	TITULAIRE	\N	\N
16628	DDADUEF	2020-10-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	11083R	TITULAIRE	\N	\N
16629	RECHERCH	2020-11-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	19621T	SUPPLEANT	\N	\N
16630	RECHERCH	2020-11-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	19573D	SUPPLEANT	\N	\N
16631	RECHERCH	2020-11-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	19399H	SUPPLEANT	\N	\N
16632	RECHERCH	2020-11-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	20048C	SUPPLEANT	\N	\N
16633	RECHERCH	2020-11-09 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08017T	SUPPLEANT	\N	\N
16634	RECHERCH	2020-11-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	20132W	SUPPLEANT	\N	\N
16635	RECHERCH	2020-11-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	19593H	SUPPLEANT	\N	\N
16636	RECHERCH	2020-11-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	19611R	TITULAIRE	\N	\N
16637	RECHERCH	2020-11-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	19693L	TITULAIRE	\N	\N
16638	RECHERCH	2020-11-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	19533U	TITULAIRE	\N	\N
16639	RECHERCH	2020-11-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	14331P	TITULAIRE	\N	\N
16640	RECHERCH	2020-11-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	14109K	TITULAIRE	\N	\N
16641	RECHERCH	2020-11-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	14229S	TITULAIRE	\N	\N
16642	RECHERCH	2020-11-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	19651A	TITULAIRE	\N	\N
16643	BIENCULT	2020-11-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	19399H	SUPPLEANT	\N	\N
16644	BIENCULT	2020-11-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	20098N	SUPPLEANT	\N	\N
16645	BIENCULT	2020-11-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	19573D	SUPPLEANT	\N	\N
16646	BIENCULT	2020-11-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	20058E	SUPPLEANT	\N	\N
16647	BIENCULT	2020-11-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	20084G	SUPPLEANT	\N	\N
16648	BIENCULT	2020-11-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	20132W	SUPPLEANT	\N	\N
16649	BIENCULT	2020-11-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	19593H	SUPPLEANT	\N	\N
16650	BIENCULT	2020-11-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	19611R	TITULAIRE	\N	\N
16651	BIENCULT	2020-11-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	04070G	TITULAIRE	\N	\N
16652	BIENCULT	2020-11-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	19621T	TITULAIRE	\N	\N
16653	BIENCULT	2020-11-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	07033P	TITULAIRE	\N	\N
16654	BIENCULT	2020-11-19 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08017T	TITULAIRE	\N	\N
16655	BIENCULT	2020-11-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	14109K	TITULAIRE	\N	\N
16656	BIENCULT	2020-11-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	19329S	TITULAIRE	\N	\N
16657	PLFSS21	2020-11-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14071N	SUPPLEANT	\N	\N
16658	PLFSS21	2020-11-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14026U	SUPPLEANT	\N	\N
16659	PLFSS21	2020-11-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14217N	SUPPLEANT	\N	\N
16660	PLFSS21	2020-11-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14042U	SUPPLEANT	\N	\N
16661	PLFSS21	2020-11-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14281W	SUPPLEANT	\N	\N
16662	PLFSS21	2020-11-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19553Y	SUPPLEANT	\N	\N
16663	PLFSS21	2020-11-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	11031D	SUPPLEANT	\N	\N
16664	PLFSS21	2020-11-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	10006L	TITULAIRE	\N	\N
16665	PLFSS21	2020-11-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	01034P	TITULAIRE	\N	\N
16666	PLFSS21	2020-11-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14213J	TITULAIRE	\N	\N
16667	PLFSS21	2020-11-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	11097X	TITULAIRE	\N	\N
16668	PLFSS21	2020-11-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19683J	TITULAIRE	\N	\N
16669	PLFSS21	2020-11-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	17779H	TITULAIRE	\N	\N
16670	PLFSS21	2020-11-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19697Q	TITULAIRE	\N	\N
16671	PLFR420	2020-11-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19741B	SUPPLEANT	\N	\N
16672	PLFR420	2020-11-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19667J	SUPPLEANT	\N	\N
16673	PLFR420	2020-11-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20044X	SUPPLEANT	\N	\N
16674	PLFR420	2020-11-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	11053K	SUPPLEANT	\N	\N
16675	PLFR420	2020-11-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	12016W	SUPPLEANT	\N	\N
16676	PLFR420	2020-11-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	11012A	SUPPLEANT	\N	\N
16677	PLFR420	2020-11-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	11040E	SUPPLEANT	\N	\N
16678	PLFR420	2020-11-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14225N	TITULAIRE	\N	\N
16679	PLFR420	2020-11-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	11048N	TITULAIRE	\N	\N
16680	PLFR420	2020-11-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19711U	TITULAIRE	\N	\N
16681	PLFR420	2020-11-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19762G	TITULAIRE	\N	\N
16682	PLFR420	2020-11-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14083S	TITULAIRE	\N	\N
16683	PLFR420	2020-11-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19647E	TITULAIRE	\N	\N
16684	PLFR420	2020-11-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19349W	TITULAIRE	\N	\N
16685	PLF2021	2020-12-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	20044X	SUPPLEANT	\N	\N
16686	PLF2021	2020-12-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	19667J	SUPPLEANT	\N	\N
16687	PLF2021	2020-12-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	08010L	SUPPLEANT	\N	\N
16688	PLF2021	2020-12-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	19479G	SUPPLEANT	\N	\N
16689	PLF2021	2020-12-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	20080C	SUPPLEANT	\N	\N
16690	PLF2021	2020-12-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	11012A	SUPPLEANT	\N	\N
16691	PLF2021	2020-12-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	11040E	SUPPLEANT	\N	\N
16692	PLF2021	2020-12-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	14225N	TITULAIRE	\N	\N
16693	PLF2021	2020-12-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	11048N	TITULAIRE	\N	\N
16694	PLF2021	2020-12-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	19711U	TITULAIRE	\N	\N
16695	PLF2021	2020-12-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	19741B	TITULAIRE	\N	\N
16696	PLF2021	2020-12-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	14327T	TITULAIRE	\N	\N
16697	PLF2021	2020-12-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	19647E	TITULAIRE	\N	\N
16698	PLF2021	2020-12-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	19349W	TITULAIRE	\N	\N
16699	PJLOELEC	2020-12-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
16700	PJLOELEC	2020-12-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	14215L	TITULAIRE	\N	\N
16701	PJLOELEC	2020-12-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	19447X	SUPPLEANT	\N	\N
16702	PJLOELEC	2020-12-10 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	SUPPLEANT	\N	\N
16703	PJLOELEC	2020-12-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	19673G	SUPPLEANT	\N	\N
16704	PJLOELEC	2020-12-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	11085T	SUPPLEANT	\N	\N
16705	PJLOELEC	2020-12-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	14151M	SUPPLEANT	\N	\N
16706	PJLOELEC	2020-12-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	14107H	SUPPLEANT	\N	\N
16707	PJLOELEC	2020-12-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	11056N	SUPPLEANT	\N	\N
16708	PJLOELEC	2020-12-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
15778	DETTESOCIALE	2020-07-01 00:00:00	2020-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	TITULAIRE	\N	\N
15779	DETTESOCIALE	2020-07-01 00:00:00	2020-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	01034P	TITULAIRE	\N	\N
15780	DETTESOCIALE	2020-07-01 00:00:00	2020-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	14071N	TITULAIRE	\N	\N
15781	DETTESOCIALE	2020-07-01 00:00:00	2020-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	11097X	TITULAIRE	\N	\N
15782	DETTESOCIALE	2020-07-01 00:00:00	2020-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	TITULAIRE	\N	\N
15783	DETTESOCIALE	2020-07-01 00:00:00	2020-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	11067R	TITULAIRE	\N	\N
15784	DETTESOCIALE	2020-07-01 00:00:00	2020-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	19301E	TITULAIRE	\N	\N
15785	DETTESOCIALE	2020-07-01 00:00:00	2020-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	10006L	SUPPLEANT	\N	\N
15786	DETTESOCIALE	2020-07-01 00:00:00	2020-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	14217N	SUPPLEANT	\N	\N
15787	DETTESOCIALE	2020-07-01 00:00:00	2020-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	14026U	SUPPLEANT	\N	\N
15788	DETTESOCIALE	2020-07-01 00:00:00	2020-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	19569H	SUPPLEANT	\N	\N
15789	DETTESOCIALE	2020-07-01 00:00:00	2020-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	17779H	SUPPLEANT	\N	\N
15790	DETTESOCIALE	2020-07-01 00:00:00	2020-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	14261S	SUPPLEANT	\N	\N
15791	DETTESOCIALE	2020-07-01 00:00:00	2020-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	19760E	SUPPLEANT	\N	\N
15792	AUTONOMIE	2020-07-01 00:00:00	2020-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	TITULAIRE	\N	\N
15793	AUTONOMIE	2020-07-01 00:00:00	2020-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	01034P	TITULAIRE	\N	\N
15794	AUTONOMIE	2020-07-01 00:00:00	2020-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	14071N	TITULAIRE	\N	\N
15795	AUTONOMIE	2020-07-01 00:00:00	2020-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	11097X	TITULAIRE	\N	\N
15796	AUTONOMIE	2020-07-01 00:00:00	2020-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	TITULAIRE	\N	\N
15797	AUTONOMIE	2020-07-01 00:00:00	2020-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	11067R	TITULAIRE	\N	\N
15798	AUTONOMIE	2020-07-01 00:00:00	2020-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	19301E	TITULAIRE	\N	\N
15799	AUTONOMIE	2020-07-01 00:00:00	2020-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	10006L	SUPPLEANT	\N	\N
15800	AUTONOMIE	2020-07-01 00:00:00	2020-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	14217N	SUPPLEANT	\N	\N
15801	AUTONOMIE	2020-07-01 00:00:00	2020-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	14026U	SUPPLEANT	\N	\N
15802	AUTONOMIE	2020-07-01 00:00:00	2020-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	19569H	SUPPLEANT	\N	\N
15803	AUTONOMIE	2020-07-01 00:00:00	2020-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	17779H	SUPPLEANT	\N	\N
15804	AUTONOMIE	2020-07-01 00:00:00	2020-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	14261S	SUPPLEANT	\N	\N
15805	AUTONOMIE	2020-07-01 00:00:00	2020-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	19760E	SUPPLEANT	\N	\N
17982	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21029D	\N	\N	\N
17983	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21030V	\N	\N	\N
17993	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19563B	\N	\N	\N
17994	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21031W	\N	\N	\N
17995	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19479G	\N	\N	\N
18004	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21035B	\N	\N	\N
18019	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19531S	\N	\N	\N
18045	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21057H	\N	\N	\N
18046	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21058J	\N	\N	\N
18047	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19421M	\N	\N	\N
18048	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19399H	\N	\N	\N
18049	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	11070L	\N	\N	\N
18050	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19691J	\N	\N	\N
18051	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19693L	\N	\N	\N
18052	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21059K	\N	\N	\N
18054	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21060C	\N	\N	\N
18055	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19573D	\N	\N	\N
18056	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21061D	\N	\N	\N
18057	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	\N	\N	\N
18058	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20180F	\N	\N	\N
18059	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21062E	\N	\N	\N
18061	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21064G	\N	\N	\N
18062	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21065H	\N	\N	\N
18131	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19569H	\N	\N	\N
18132	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21084L	\N	\N	\N
18135	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21087P	\N	\N	\N
15539	FEDERATION	2020-03-04 00:00:00	2020-09-08 00:00:00	ANCIEN	\N	\N	\N	\N	14147R	\N	\N	\N
15540	FEDERATION	2020-03-04 00:00:00	2020-09-08 00:00:00	ANCIEN	\N	\N	\N	\N	19533U	\N	\N	\N
15541	FEDERATION	2020-03-04 00:00:00	2020-09-08 00:00:00	ANCIEN	\N	\N	\N	\N	11043H	\N	\N	\N
15542	FEDERATION	2020-03-04 00:00:00	2020-09-08 00:00:00	ANCIEN	\N	\N	\N	\N	14173T	\N	\N	\N
15543	FEDERATION	2020-03-04 00:00:00	2020-09-08 00:00:00	ANCIEN	\N	\N	\N	\N	14241N	\N	\N	\N
15544	FEDERATION	2020-03-04 00:00:00	2020-09-08 00:00:00	ANCIEN	\N	\N	\N	\N	19758L	\N	\N	\N
16129	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20132W	\N	\N	\N
16130	AFCL	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20132W	\N	\N	\N
16709	PJLOELEC	2020-12-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	14179A	TITULAIRE	\N	\N
16710	PJLOELEC	2020-12-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	14001X	TITULAIRE	\N	\N
16711	PJLOELEC	2020-12-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	19489J	TITULAIRE	\N	\N
16712	PJLOELEC	2020-12-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	11072N	TITULAIRE	\N	\N
16713	PJLELEC	2020-12-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	19447X	SUPPLEANT	\N	\N
16714	PJLELEC	2020-12-10 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	SUPPLEANT	\N	\N
16715	PJLELEC	2020-12-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	19673G	SUPPLEANT	\N	\N
16716	PJLELEC	2020-12-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	11085T	SUPPLEANT	\N	\N
16717	PJLELEC	2020-12-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	14151M	SUPPLEANT	\N	\N
16718	PJLELEC	2020-12-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	14107H	SUPPLEANT	\N	\N
16719	PJLELEC	2020-12-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	11056N	SUPPLEANT	\N	\N
16720	PJLELEC	2020-12-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
16721	PARQUETEURO	2020-12-15 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	SUPPLEANT	\N	\N
16722	PARQUETEURO	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	20108W	SUPPLEANT	\N	\N
16723	PARQUETEURO	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	19954N	SUPPLEANT	\N	\N
16724	PARQUETEURO	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	19749K	SUPPLEANT	\N	\N
16725	PARQUETEURO	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	11026G	SUPPLEANT	\N	\N
16729	PARQUETEURO	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
16727	PARQUETEURO	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	19629C	SUPPLEANT	\N	\N
16728	PARQUETEURO	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	04085P	SUPPLEANT	\N	\N
16730	PARQUETEURO	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	14089Y	TITULAIRE	\N	\N
16731	PARQUETEURO	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	08018U	TITULAIRE	\N	\N
16732	PARQUETEURO	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	14215L	TITULAIRE	\N	\N
16733	PARQUETEURO	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	14151M	TITULAIRE	\N	\N
16734	PARQUETEURO	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
16735	PARQUETEURO	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	11072N	TITULAIRE	\N	\N
16736	URGSAN	2021-01-28 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	SUPPLEANT	\N	\N
16737	URGSAN	2021-01-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	19447X	SUPPLEANT	\N	\N
16738	URGSAN	2021-01-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	08018U	SUPPLEANT	\N	\N
16739	URGSAN	2021-01-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	11085T	SUPPLEANT	\N	\N
16740	URGSAN	2021-01-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	14001X	SUPPLEANT	\N	\N
16741	URGSAN	2021-01-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	14107H	SUPPLEANT	\N	\N
16742	URGSAN	2021-01-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	04085P	SUPPLEANT	\N	\N
16743	URGSAN	2021-01-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
16744	URGSAN	2021-01-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
16745	URGSAN	2021-01-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	19673G	TITULAIRE	\N	\N
16746	URGSAN	2021-01-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	14089Y	TITULAIRE	\N	\N
16747	URGSAN	2021-01-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	19649G	TITULAIRE	\N	\N
16748	URGSAN	2021-01-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	11026G	TITULAIRE	\N	\N
16749	URGSAN	2021-01-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	11072N	TITULAIRE	\N	\N
16750	URGSAN	2021-01-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	83008P	TITULAIRE	\N	\N
16751	JUSTMINEURS	2021-02-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14215L	SUPPLEANT	\N	\N
16752	JUSTMINEURS	2021-02-04 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	SUPPLEANT	\N	\N
16753	JUSTMINEURS	2021-02-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19675J	SUPPLEANT	\N	\N
16754	JUSTMINEURS	2021-02-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	11085T	SUPPLEANT	\N	\N
16755	JUSTMINEURS	2021-02-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19649G	SUPPLEANT	\N	\N
16756	JUSTMINEURS	2021-02-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14107H	SUPPLEANT	\N	\N
16757	JUSTMINEURS	2021-02-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	04085P	SUPPLEANT	\N	\N
16758	JUSTMINEURS	2021-02-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
16759	JUSTMINEURS	2021-02-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14053L	TITULAIRE	\N	\N
16760	JUSTMINEURS	2021-02-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
16761	JUSTMINEURS	2021-02-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19749K	TITULAIRE	\N	\N
16762	JUSTMINEURS	2021-02-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
16763	JUSTMINEURS	2021-02-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	11026G	TITULAIRE	\N	\N
16764	JUSTMINEURS	2021-02-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	11072N	TITULAIRE	\N	\N
16765	REPORT	2021-02-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	20108W	SUPPLEANT	\N	\N
16766	REPORT	2021-02-11 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	SUPPLEANT	\N	\N
16767	REPORT	2021-02-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	20074E	SUPPLEANT	\N	\N
16768	REPORT	2021-02-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	11085T	SUPPLEANT	\N	\N
16769	REPORT	2021-02-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	14151M	SUPPLEANT	\N	\N
16770	REPORT	2021-02-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	14107H	SUPPLEANT	\N	\N
16771	REPORT	2021-02-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	11056N	SUPPLEANT	\N	\N
16772	REPORT	2021-02-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
16776	REPORT	2021-02-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	19543W	TITULAIRE	\N	\N
16774	REPORT	2021-02-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	05008E	TITULAIRE	\N	\N
16775	REPORT	2021-02-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	14053L	TITULAIRE	\N	\N
16777	REPORT	2021-02-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	19489J	TITULAIRE	\N	\N
16778	REPORT	2021-02-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	14001X	TITULAIRE	\N	\N
16779	REPORT	2021-02-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	95063L	TITULAIRE	\N	\N
16780	BIOETHIQ	2021-02-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	04092N	TITULAIRE	\N	\N
16781	BIOETHIQ	2021-02-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	10006L	SUPPLEANT	\N	\N
16782	BIOETHIQ	2021-02-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14215L	SUPPLEANT	\N	\N
16783	BIOETHIQ	2021-02-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	18083K	SUPPLEANT	\N	\N
16784	BIOETHIQ	2021-02-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20066E	SUPPLEANT	\N	\N
16785	BIOETHIQ	2021-02-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	11026G	SUPPLEANT	\N	\N
16786	BIOETHIQ	2021-02-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19553Y	SUPPLEANT	\N	\N
16787	BIOETHIQ	2021-02-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	11031D	SUPPLEANT	\N	\N
16788	BIOETHIQ	2021-02-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19447X	TITULAIRE	\N	\N
16789	BIOETHIQ	2021-02-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14213J	TITULAIRE	\N	\N
16790	BIOETHIQ	2021-02-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19569H	TITULAIRE	\N	\N
16791	BIOETHIQ	2021-02-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19683J	TITULAIRE	\N	\N
16792	BIOETHIQ	2021-02-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19649G	TITULAIRE	\N	\N
16793	BIOETHIQ	2021-02-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	11072N	TITULAIRE	\N	\N
16794	COURTAGE	2021-03-10 00:00:00	2021-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	19741B	SUPPLEANT	\N	\N
16795	COURTAGE	2021-03-10 00:00:00	2021-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	19711U	SUPPLEANT	\N	\N
16796	COURTAGE	2021-03-10 00:00:00	2021-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	19667J	SUPPLEANT	\N	\N
16797	COURTAGE	2021-03-10 00:00:00	2021-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	14327T	SUPPLEANT	\N	\N
16798	COURTAGE	2021-03-10 00:00:00	2021-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	19647E	SUPPLEANT	\N	\N
16799	COURTAGE	2021-03-10 00:00:00	2021-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	20116W	SUPPLEANT	\N	\N
16800	COURTAGE	2021-03-10 00:00:00	2021-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	11040E	SUPPLEANT	\N	\N
16801	COURTAGE	2021-03-10 00:00:00	2021-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	14225N	TITULAIRE	\N	\N
16802	COURTAGE	2021-03-10 00:00:00	2021-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	TITULAIRE	\N	\N
16803	COURTAGE	2021-03-10 00:00:00	2021-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	08011M	TITULAIRE	\N	\N
16804	COURTAGE	2021-03-10 00:00:00	2021-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	19762G	TITULAIRE	\N	\N
16805	COURTAGE	2021-03-10 00:00:00	2021-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	14189C	TITULAIRE	\N	\N
16806	COURTAGE	2021-03-10 00:00:00	2021-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	20080C	TITULAIRE	\N	\N
16807	COURTAGE	2021-03-10 00:00:00	2021-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	11072N	TITULAIRE	\N	\N
16808	SYSANTE	2021-03-02 00:00:00	2021-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	19415P	SUPPLEANT	\N	\N
16809	SYSANTE	2021-03-02 00:00:00	2021-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	19723Y	SUPPLEANT	\N	\N
16810	SYSANTE	2021-03-02 00:00:00	2021-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	14071N	SUPPLEANT	\N	\N
16811	SYSANTE	2021-03-02 00:00:00	2021-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	01034P	SUPPLEANT	\N	\N
16812	SYSANTE	2021-03-02 00:00:00	2021-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	08045X	SUPPLEANT	\N	\N
16813	SYSANTE	2021-03-02 00:00:00	2021-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	19553Y	SUPPLEANT	\N	\N
16814	SYSANTE	2021-03-02 00:00:00	2021-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	11031D	SUPPLEANT	\N	\N
16815	SYSANTE	2021-03-02 00:00:00	2021-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	10006L	TITULAIRE	\N	\N
16816	SYSANTE	2021-03-02 00:00:00	2021-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	19591F	TITULAIRE	\N	\N
16817	SYSANTE	2021-03-02 00:00:00	2021-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	TITULAIRE	\N	\N
16818	SYSANTE	2021-03-02 00:00:00	2021-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	14213J	TITULAIRE	\N	\N
16819	SYSANTE	2021-03-02 00:00:00	2021-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	14042U	TITULAIRE	\N	\N
16820	SYSANTE	2021-03-02 00:00:00	2021-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	19683J	TITULAIRE	\N	\N
16821	SYSANTE	2021-03-02 00:00:00	2021-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	18193Q	TITULAIRE	\N	\N
16822	JUSTIPEN	2021-03-04 00:00:00	2021-03-09 00:00:00	ANCIEN	\N	\N	\N	\N	14069U	SUPPLEANT	\N	\N
10800	2014CMP7	2014-04-30 00:00:00	2021-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	04084N	TITULAIRE	2015-01-23 15:11:25	2015-01-23 15:13:44
16823	JUSTIPEN	2021-03-04 00:00:00	2021-03-09 00:00:00	ANCIEN	\N	\N	\N	\N	20108W	SUPPLEANT	\N	\N
16824	JUSTIPEN	2021-03-04 00:00:00	2021-03-09 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	SUPPLEANT	\N	\N
16825	JUSTIPEN	2021-03-04 00:00:00	2021-03-09 00:00:00	ANCIEN	\N	\N	\N	\N	11085T	SUPPLEANT	\N	\N
16826	JUSTIPEN	2021-03-04 00:00:00	2021-03-09 00:00:00	ANCIEN	\N	\N	\N	\N	14001X	SUPPLEANT	\N	\N
16827	JUSTIPEN	2021-03-04 00:00:00	2021-03-09 00:00:00	ANCIEN	\N	\N	\N	\N	19629C	SUPPLEANT	\N	\N
16828	JUSTIPEN	2021-03-04 00:00:00	2021-03-09 00:00:00	ANCIEN	\N	\N	\N	\N	11056N	SUPPLEANT	\N	\N
16829	JUSTIPEN	2021-03-04 00:00:00	2021-03-09 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
16830	JUSTIPEN	2021-03-04 00:00:00	2021-03-09 00:00:00	ANCIEN	\N	\N	\N	\N	14111D	TITULAIRE	\N	\N
16831	JUSTIPEN	2021-03-04 00:00:00	2021-03-09 00:00:00	ANCIEN	\N	\N	\N	\N	19581D	TITULAIRE	\N	\N
16832	JUSTIPEN	2021-03-04 00:00:00	2021-03-09 00:00:00	ANCIEN	\N	\N	\N	\N	19749K	TITULAIRE	\N	\N
16833	JUSTIPEN	2021-03-04 00:00:00	2021-03-09 00:00:00	ANCIEN	\N	\N	\N	\N	19649G	TITULAIRE	\N	\N
16834	JUSTIPEN	2021-03-04 00:00:00	2021-03-09 00:00:00	ANCIEN	\N	\N	\N	\N	14151M	TITULAIRE	\N	\N
16835	JUSTIPEN	2021-03-04 00:00:00	2021-03-09 00:00:00	ANCIEN	\N	\N	\N	\N	11072N	TITULAIRE	\N	\N
16836	EAUPOTAB	2021-03-23 00:00:00	2021-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	19447X	SUPPLEANT	\N	\N
16837	EAUPOTAB	2021-03-23 00:00:00	2021-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	19954N	SUPPLEANT	\N	\N
16838	EAUPOTAB	2021-03-23 00:00:00	2021-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	SUPPLEANT	\N	\N
16839	EAUPOTAB	2021-03-23 00:00:00	2021-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	11085T	SUPPLEANT	\N	\N
16840	EAUPOTAB	2021-03-23 00:00:00	2021-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	14151M	SUPPLEANT	\N	\N
16841	EAUPOTAB	2021-03-23 00:00:00	2021-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	19717B	SUPPLEANT	\N	\N
16842	EAUPOTAB	2021-03-23 00:00:00	2021-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	SUPPLEANT	\N	\N
16843	EAUPOTAB	2021-03-23 00:00:00	2021-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
16844	EAUPOTAB	2021-03-23 00:00:00	2021-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	20074E	TITULAIRE	\N	\N
16845	EAUPOTAB	2021-03-23 00:00:00	2021-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	14259Y	TITULAIRE	\N	\N
16846	EAUPOTAB	2021-03-23 00:00:00	2021-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	14179A	TITULAIRE	\N	\N
16847	EAUPOTAB	2021-03-23 00:00:00	2021-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	20114U	TITULAIRE	\N	\N
16848	EAUPOTAB	2021-03-23 00:00:00	2021-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	19531S	TITULAIRE	\N	\N
16849	EAUPOTAB	2021-03-23 00:00:00	2021-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	11072N	TITULAIRE	\N	\N
16850	DETENTIO	2021-03-23 00:00:00	2021-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	20074E	SUPPLEANT	\N	\N
16851	DETENTIO	2021-03-23 00:00:00	2021-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	19954N	SUPPLEANT	\N	\N
16852	DETENTIO	2021-03-23 00:00:00	2021-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	14259Y	SUPPLEANT	\N	\N
16853	DETENTIO	2021-03-23 00:00:00	2021-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	11085T	SUPPLEANT	\N	\N
16854	DETENTIO	2021-03-23 00:00:00	2021-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	14151M	SUPPLEANT	\N	\N
16855	DETENTIO	2021-03-23 00:00:00	2021-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	19629C	SUPPLEANT	\N	\N
16856	DETENTIO	2021-03-23 00:00:00	2021-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	SUPPLEANT	\N	\N
16857	DETENTIO	2021-03-23 00:00:00	2021-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
16858	DETENTIO	2021-03-23 00:00:00	2021-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	08018U	TITULAIRE	\N	\N
16859	DETENTIO	2021-03-23 00:00:00	2021-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	TITULAIRE	\N	\N
16860	DETENTIO	2021-03-23 00:00:00	2021-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	01024M	TITULAIRE	\N	\N
16861	DETENTIO	2021-03-23 00:00:00	2021-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	TITULAIRE	\N	\N
16862	DETENTIO	2021-03-23 00:00:00	2021-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	20114U	TITULAIRE	\N	\N
16863	DETENTIO	2021-03-23 00:00:00	2021-03-25 00:00:00	ANCIEN	\N	\N	\N	\N	11072N	TITULAIRE	\N	\N
16864	HARCEL	2021-05-12 00:00:00	2021-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	19954N	\N	\N	\N
16865	HARCEL	2021-05-12 00:00:00	2021-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	19643A	\N	\N	\N
16866	HARCEL	2021-05-12 00:00:00	2021-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	20152B	\N	\N	\N
16867	HARCEL	2021-05-12 00:00:00	2021-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	18083K	\N	\N	\N
16868	HARCEL	2021-05-12 00:00:00	2021-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	20124W	\N	\N	\N
16869	HARCEL	2021-05-12 00:00:00	2021-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	19673G	\N	\N	\N
16870	HARCEL	2021-05-12 00:00:00	2021-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	04035D	\N	\N	\N
16871	HARCEL	2021-05-12 00:00:00	2021-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	14123H	\N	\N	\N
16872	HARCEL	2021-05-12 00:00:00	2021-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	20034V	\N	\N	\N
16873	HARCEL	2021-05-12 00:00:00	2021-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	20098N	\N	\N	\N
16874	HARCEL	2021-05-12 00:00:00	2021-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	14030Q	\N	\N	\N
16875	HARCEL	2021-05-12 00:00:00	2021-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	19691J	\N	\N	\N
16876	HARCEL	2021-05-12 00:00:00	2021-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	14073Q	\N	\N	\N
16877	HARCEL	2021-05-12 00:00:00	2021-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	04070G	\N	\N	\N
16878	HARCEL	2021-05-12 00:00:00	2021-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	20114U	\N	\N	\N
16879	HARCEL	2021-05-12 00:00:00	2021-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	14021P	\N	\N	\N
16880	HARCEL	2021-05-12 00:00:00	2021-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	08017T	\N	\N	\N
16881	HARCEL	2021-05-12 00:00:00	2021-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	19527W	\N	\N	\N
16882	HARCEL	2021-05-12 00:00:00	2021-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	19553Y	\N	\N	\N
16883	HARCEL	2021-05-12 00:00:00	2021-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	19593H	\N	\N	\N
16884	HARCEL	2021-05-12 00:00:00	2021-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	04057K	\N	\N	\N
16885	HARCEL	2021-05-12 00:00:00	2021-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	20134Y	\N	\N	\N
16890	AFEU	2021-06-03 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19333N	\N	\N	\N
17080	HOPITAL	2021-12-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	11031D	\N	\N	\N
17081	HOPITAL	2021-12-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19467C	\N	\N	\N
17082	HOPITAL	2021-12-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	10006L	\N	\N	\N
17083	HOPITAL	2021-12-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19723Y	\N	\N	\N
17084	HOPITAL	2021-12-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	14147R	\N	\N	\N
17085	HOPITAL	2021-12-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	04092N	\N	\N	\N
17086	HOPITAL	2021-12-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20148F	\N	\N	\N
17087	HOPITAL	2021-12-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	19703U	\N	\N	\N
17088	HOPITAL	2021-12-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20062A	\N	\N	\N
17089	HOPITAL	2021-12-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	19553Y	\N	\N	\N
17090	HOPITAL	2021-12-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19295A	\N	\N	\N
17091	HOPITAL	2021-12-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	19683J	\N	\N	\N
17092	HOPITAL	2021-12-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	01062T	\N	\N	\N
17093	JUDI	2021-12-01 00:00:00	2022-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	11056N	\N	\N	\N
17113	HOPITAL	2021-12-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	14221J	\N	\N	\N
17095	JUDI	2021-12-01 00:00:00	2022-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	19649G	\N	\N	\N
17096	JUDI	2021-12-01 00:00:00	2022-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	08045X	\N	\N	\N
17097	JUDI	2021-12-01 00:00:00	2022-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	11026G	\N	\N	\N
17098	JUDI	2021-12-01 00:00:00	2022-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	14225N	\N	\N	\N
17099	JUDI	2021-12-01 00:00:00	2022-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	20266L	\N	\N	\N
17100	JUDI	2021-12-01 00:00:00	2022-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	\N	\N	\N
17101	JUDI	2021-12-01 00:00:00	2022-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	20024T	\N	\N	\N
17102	JUDI	2021-12-01 00:00:00	2022-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	17367Q	\N	\N	\N
17103	JUDI	2021-12-01 00:00:00	2022-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	20086J	\N	\N	\N
17104	JUDI	2021-12-01 00:00:00	2022-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	20138D	\N	\N	\N
17105	JUDI	2021-12-01 00:00:00	2022-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	\N	\N	\N
17106	JUDI	2021-12-01 00:00:00	2022-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	14053L	\N	\N	\N
17107	JUDI	2021-12-01 00:00:00	2022-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	14187A	\N	\N	\N
17108	JUDI	2021-12-01 00:00:00	2022-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	20108W	\N	\N	\N
17109	JUDI	2021-12-01 00:00:00	2022-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	20098N	\N	\N	\N
17112	JUDI	2021-12-01 00:00:00	2022-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	19563B	\N	\N	\N
17114	HOPITAL	2021-12-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	20130U	\N	\N	\N
17172	SOCI	2022-02-15 00:00:00	2022-09-09 00:00:00	ANCIEN	\N	\N	\N	\N	20298U	\N	\N	\N
17275	GEAU	2023-02-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	20076G	\N	\N	\N
17276	GEAU	2023-02-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	20094J	\N	\N	\N
17277	GEAU	2023-02-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	20078J	\N	\N	\N
17278	GEAU	2023-02-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	20914V	\N	\N	\N
17279	GEAU	2023-02-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	20104S	\N	\N	\N
17280	GEAU	2023-02-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	20070A	\N	\N	\N
17281	GEAU	2023-02-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	14259Y	\N	\N	\N
17282	GEAU	2023-02-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	14169X	\N	\N	\N
17283	GEAU	2023-02-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	19820Y	\N	\N	\N
17284	GEAU	2023-02-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	19387D	\N	\N	\N
17285	GEAU	2023-02-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	20128B	\N	\N	\N
17286	GEAU	2023-02-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	14205J	\N	\N	\N
17287	GEAU	2023-02-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	14219Q	\N	\N	\N
17288	GEAU	2023-02-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	14221J	\N	\N	\N
17289	GEAU	2023-02-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	19768N	\N	\N	\N
17290	GEAU	2023-02-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	14237S	\N	\N	\N
17291	GEAU	2023-02-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	19745F	\N	\N	\N
17292	GEAU	2023-02-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	20118Y	\N	\N	\N
17293	GEAU	2023-02-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	05012A	\N	\N	\N
17294	GEAU	2023-02-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	14229S	\N	\N	\N
17295	GEAU	2023-02-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	20046A	\N	\N	\N
17296	BATI	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20086J	\N	\N	\N
17297	BATI	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19643A	\N	\N	\N
17298	BATI	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20152B	\N	\N	\N
17299	BATI	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19621T	\N	\N	\N
17300	BATI	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19758L	\N	\N	\N
17301	BATI	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	12028B	\N	\N	\N
17302	BATI	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20264J	\N	\N	\N
17303	BATI	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20980G	\N	\N	\N
17304	BATI	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20132W	\N	\N	\N
17305	BATI	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	14123H	\N	\N	\N
17306	BATI	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19691J	\N	\N	\N
17307	BATI	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20106U	\N	\N	\N
16360	ENSAGRIC	2021-02-03 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14133K	\N	\N	\N
16361	ENSAGRIC	2021-02-03 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19621T	\N	\N	\N
16362	ENSAGRIC	2021-02-03 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19383Y	\N	\N	\N
16363	ENSAGRIC	2021-02-03 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19467C	\N	\N	\N
16364	ENSAGRIC	2021-02-03 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20140W	\N	\N	\N
16365	ENSAGRIC	2021-02-03 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20038A	\N	\N	\N
16366	ENSAGRIC	2021-02-03 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14026U	\N	\N	\N
16367	ENSAGRIC	2021-02-03 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19798U	\N	\N	\N
16368	ENSAGRIC	2021-02-03 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19762G	\N	\N	\N
16369	ENSAGRIC	2021-02-03 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20026V	\N	\N	\N
16370	ENSAGRIC	2021-02-03 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14030Q	\N	\N	\N
16371	ENSAGRIC	2021-02-03 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01025N	\N	\N	\N
16372	ENSAGRIC	2021-02-03 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19441R	\N	\N	\N
16373	ENSAGRIC	2021-02-03 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19713W	\N	\N	\N
16374	ENSAGRIC	2021-02-03 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19295A	\N	\N	\N
16375	ENSAGRIC	2021-02-03 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19551W	\N	\N	\N
16376	ENSAGRIC	2021-02-03 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20028X	\N	\N	\N
16377	ENSAGRIC	2021-02-03 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14109K	\N	\N	\N
16378	ENSAGRIC	2021-02-03 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19637C	\N	\N	\N
16379	ENSAGRIC	2021-02-03 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19719D	\N	\N	\N
16380	ENSAGRIC	2021-02-03 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19758L	\N	\N	\N
16381	ENSAGRIC	2021-02-03 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17589D	\N	\N	\N
16382	ENSAGRIC	2021-02-03 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11099A	\N	\N	\N
17438	AFEU	2023-03-01 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	17737W	\N	\N	\N
15886	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20032T	\N	\N	\N
17183	SOCI	2022-09-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19511N	\N	\N	\N
17184	CAE	2022-09-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20298U	\N	\N	\N
17308	BATI	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19685L	\N	\N	\N
17309	BATI	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19591F	\N	\N	\N
17310	BATI	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20056C	\N	\N	\N
17311	BATI	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20142Y	\N	\N	\N
17312	BATI	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	04057K	\N	\N	\N
17313	BATI	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19335Q	\N	\N	\N
17314	BATI	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	14109K	\N	\N	\N
17315	BATI	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19739H	\N	\N	\N
17316	BATI	2023-02-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20026V	\N	\N	\N
17501	PAPIER	2023-04-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	19701S	TITULAIRE	\N	\N
17502	PAPIER	2023-03-28 00:00:00	2023-03-31 00:00:00	ANCIEN	\N	\N	\N	\N	14031R	TITULAIRE	\N	\N
17503	PAPIER	2023-03-28 00:00:00	2023-03-31 00:00:00	ANCIEN	\N	\N	\N	\N	18083K	TITULAIRE	\N	\N
17504	PAPIER	2023-03-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	14219Q	TITULAIRE	\N	\N
17505	PAPIER	2023-03-28 00:00:00	2023-03-31 00:00:00	ANCIEN	\N	\N	\N	\N	19549D	TITULAIRE	\N	\N
17506	PAPIER	2023-03-28 00:00:00	2023-03-31 00:00:00	ANCIEN	\N	\N	\N	\N	19503N	TITULAIRE	\N	\N
17507	PAPIER	2023-03-28 00:00:00	2023-03-31 00:00:00	ANCIEN	\N	\N	\N	\N	19637C	TITULAIRE	\N	\N
17508	PAPIER	2023-03-28 00:00:00	2023-03-31 00:00:00	ANCIEN	\N	\N	\N	\N	20032T	SUPPLEANT	\N	\N
17509	PAPIER	2023-03-28 00:00:00	2023-03-31 00:00:00	ANCIEN	\N	\N	\N	\N	20038A	SUPPLEANT	\N	\N
17510	PAPIER	2023-03-28 00:00:00	2023-03-31 00:00:00	ANCIEN	\N	\N	\N	\N	11101A	SUPPLEANT	\N	\N
17511	PAPIER	2023-03-28 00:00:00	2023-03-31 00:00:00	ANCIEN	\N	\N	\N	\N	19699S	SUPPLEANT	\N	\N
17512	PAPIER	2023-03-28 00:00:00	2023-03-31 00:00:00	ANCIEN	\N	\N	\N	\N	19333N	SUPPLEANT	\N	\N
17513	PAPIER	2023-03-28 00:00:00	2023-03-31 00:00:00	ANCIEN	\N	\N	\N	\N	20132W	SUPPLEANT	\N	\N
17514	PAPIER	2023-03-28 00:00:00	2023-03-31 00:00:00	ANCIEN	\N	\N	\N	\N	20102Q	SUPPLEANT	\N	\N
17515	RELCOM	2023-04-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	11090Q	TITULAIRE	\N	\N
17516	RELCOM	2023-04-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	14033T	TITULAIRE	\N	\N
17517	RELCOM	2023-04-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	19507S	TITULAIRE	\N	\N
17518	RELCOM	2023-04-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	14205J	TITULAIRE	\N	\N
17519	RELCOM	2023-04-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	20028X	TITULAIRE	\N	\N
17520	RELCOM	2023-04-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	20030R	TITULAIRE	\N	\N
17521	RELCOM	2023-04-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	14037X	TITULAIRE	\N	\N
17522	RELCOM	2023-04-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	14329V	SUPPLEANT	\N	\N
17523	RELCOM	2023-04-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	19467C	SUPPLEANT	\N	\N
17524	RELCOM	2023-04-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	20054A	SUPPLEANT	\N	\N
17525	RELCOM	2023-04-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	20286Q	SUPPLEANT	\N	\N
17526	RELCOM	2023-04-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	14257W	SUPPLEANT	\N	\N
17527	RELCOM	2023-04-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	14207L	SUPPLEANT	\N	\N
17528	RELCOM	2023-04-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	19695N	SUPPLEANT	\N	\N
8074	AFCL	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11109J	\N	\N	2017-10-04 00:00:00
18001	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19657G	\N	\N	\N
18002	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21033Y	\N	\N	\N
18003	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21034A	\N	\N	\N
18005	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21036C	\N	\N	\N
18012	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21039F	\N	\N	\N
18013	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19367Y	\N	\N	\N
18014	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21040X	\N	\N	\N
18015	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21041Y	\N	\N	\N
18018	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21043B	\N	\N	\N
18020	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21044C	\N	\N	\N
18021	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19703U	\N	\N	\N
18025	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19533U	\N	\N	\N
18026	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19545Y	\N	\N	\N
18027	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21046E	\N	\N	\N
18028	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21047F	\N	\N	\N
18030	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	\N	\N	\N
18031	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19553Y	\N	\N	\N
18032	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19551W	\N	\N	\N
18033	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21049H	\N	\N	\N
18053	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	11115U	\N	\N	\N
18060	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21063F	\N	\N	\N
18063	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	18395Y	\N	\N	\N
18064	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	11065P	\N	\N	\N
18065	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20172F	\N	\N	\N
18066	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21066J	\N	\N	\N
18067	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	11064N	\N	\N	\N
18074	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14331P	\N	\N	\N
18075	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21068L	\N	\N	\N
18076	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21069M	\N	\N	\N
18077	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01034P	\N	\N	\N
18078	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21070E	\N	\N	\N
18079	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21071F	\N	\N	\N
18080	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19111A	\N	\N	\N
18081	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	11085T	\N	\N	\N
18082	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	11045K	\N	\N	\N
18083	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19591F	\N	\N	\N
18104	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19697Q	\N	\N	\N
18116	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19335Q	\N	\N	\N
18117	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19954N	\N	\N	\N
18118	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21081H	\N	\N	\N
18119	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21082J	\N	\N	\N
18120	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19685L	\N	\N	\N
18121	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14021P	\N	\N	\N
18122	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	18207D	\N	\N	\N
18123	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	11040E	\N	\N	\N
18257	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20056C	\N	\N	\N
18258	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20132W	\N	\N	\N
18259	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19735D	\N	\N	\N
18260	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14109K	\N	\N	\N
18261	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20142Y	\N	\N	\N
18262	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20058E	\N	\N	\N
18263	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20026V	\N	\N	\N
18264	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20098N	\N	\N	\N
18265	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20124W	\N	\N	\N
18266	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20138D	\N	\N	\N
18267	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20134Y	\N	\N	\N
18268	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20112S	\N	\N	\N
18269	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14229S	\N	\N	\N
18270	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19719D	\N	\N	\N
18271	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20084G	\N	\N	\N
18272	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20052X	\N	\N	\N
18273	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20048C	\N	\N	\N
18274	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14073Q	\N	\N	\N
18275	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14123H	\N	\N	\N
10186	AFCL	2014-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14123H	\N	2014-10-08 00:00:00	2017-10-04 00:00:00
18276	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	04070G	\N	\N	\N
18277	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19057M	\N	\N	\N
18278	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20264J	\N	\N	\N
18279	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20016T	\N	\N	\N
18280	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19758L	\N	\N	\N
18281	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	04033B	\N	\N	\N
18282	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	08012N	\N	\N	\N
18283	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14030Q	\N	\N	\N
18306	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14053L	\N	\N	\N
18307	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19725B	\N	\N	\N
18308	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	10015M	\N	\N	\N
18309	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20110Q	\N	\N	\N
18310	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14111D	\N	\N	\N
10168	LOIS	2014-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14111D	\N	2014-10-08 00:00:00	2017-10-04 00:00:00
18311	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14089Y	\N	\N	\N
18312	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14151M	\N	\N	\N
18313	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	\N	\N	\N
18314	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	\N	\N	\N
18315	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20022R	\N	\N	\N
18316	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20108W	\N	\N	\N
18317	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20074E	\N	\N	\N
18318	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	17737W	\N	\N	\N
18319	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14107H	\N	\N	\N
18320	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20114U	\N	\N	\N
18321	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19749K	\N	\N	\N
18322	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14147R	\N	\N	\N
18323	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14179A	\N	\N	\N
18324	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	08018U	\N	\N	\N
18325	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19729F	\N	\N	\N
18326	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14231L	\N	\N	\N
18327	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14275Y	\N	\N	\N
18328	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14001X	\N	\N	\N
18329	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14259Y	\N	\N	\N
18330	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14069U	\N	\N	\N
15870	NEANT	2020-08-07 00:00:00	2020-08-07 00:00:00	ANCIEN	\N	\N	\N	\N	08016S	\N	\N	\N
17395	LOCA	2023-02-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	19631V	\N	\N	\N
17396	LOCA	2023-02-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19741B	\N	\N	\N
17397	LOCA	2023-02-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	19667J	\N	\N	\N
17398	LOCA	2023-02-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	20042V	\N	\N	\N
17399	LOCA	2023-02-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	20914V	\N	\N	\N
17400	LOCA	2023-02-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	20080C	\N	\N	\N
17401	LOCA	2023-02-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	14053L	\N	\N	\N
17402	LOCA	2023-02-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	11070L	\N	\N	\N
17403	LOCA	2023-02-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	14249W	\N	\N	\N
17404	LOCA	2023-02-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	14033T	\N	\N	\N
17405	LOCA	2023-02-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	19569H	\N	\N	\N
17406	LOCA	2023-02-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	20108W	\N	\N	\N
17407	LOCA	2023-02-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	08010L	\N	\N	\N
17408	LOCA	2023-02-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	12016W	\N	\N	\N
17409	LOCA	2023-02-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	19866P	\N	\N	\N
17410	LOCA	2023-02-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	08073C	\N	\N	\N
17411	LOCA	2023-02-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	10015M	\N	\N	\N
17412	LOCA	2023-02-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	19619A	\N	\N	\N
17413	LOCA	2023-02-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	20044X	\N	\N	\N
17414	LOCA	2023-02-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	19687N	\N	\N	\N
17415	LOCA	2023-02-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	20084G	\N	\N	\N
17416	LOCA	2023-02-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	19585H	\N	\N	\N
17417	LOCA	2023-02-16 00:00:00	\N	ACTIF	\N	\N	\N	\N	19533U	\N	\N	\N
17998	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21032X	\N	\N	\N
18068	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19760E	\N	\N	\N
18069	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19681G	\N	\N	\N
18070	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21067K	\N	\N	\N
18071	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19413M	\N	\N	\N
18072	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20286Q	\N	\N	\N
18073	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	11056N	\N	\N	\N
18532	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14133K	\N	\N	\N
18533	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	17367Q	\N	\N	\N
18534	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14105F	\N	\N	\N
18535	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	17737W	\N	\N	\N
18536	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	04042C	\N	\N	\N
18537	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	07033P	\N	\N	\N
18538	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	08056B	\N	\N	\N
18539	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	08069G	\N	\N	\N
18540	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	95041E	\N	\N	\N
18541	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	99004R	\N	\N	\N
18542	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19709B	\N	\N	\N
18543	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14059S	\N	\N	\N
18544	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20252E	\N	\N	\N
18545	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14191V	\N	\N	\N
18546	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	08047A	\N	\N	\N
18547	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14193X	\N	\N	\N
18548	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21036C	\N	\N	\N
18549	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19421M	\N	\N	\N
18550	ETRD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	01058X	\N	\N	\N
18551	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19954N	\N	\N	\N
18552	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20138D	\N	\N	\N
18553	AFCL	2023-10-04 00:00:00	2023-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19747H	\N	\N	\N
18554	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19621T	\N	\N	\N
18555	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21063F	\N	\N	\N
18556	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20124W	\N	\N	\N
18557	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21091K	\N	\N	\N
18558	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20172F	\N	\N	\N
18559	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20180F	\N	\N	\N
18560	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14123H	\N	\N	\N
18561	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20056C	\N	\N	\N
18562	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21058J	\N	\N	\N
18563	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21055F	\N	\N	\N
18564	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19533U	\N	\N	\N
18565	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	04033B	\N	\N	\N
18566	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	11043H	\N	\N	\N
18567	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20026V	\N	\N	\N
18568	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20058E	\N	\N	\N
18593	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20112S	\N	\N	\N
18594	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20102Q	\N	\N	\N
18595	AFCL	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19593H	\N	\N	\N
19329	NARCO	2024-01-23 00:00:00	\N	ACTIF	\N	\N	\N	\N	21095P	\N	\N	\N
18618	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14225N	\N	\N	\N
18619	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	11048N	\N	\N	\N
18620	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20024T	\N	\N	\N
18621	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21048G	\N	\N	\N
18622	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21041Y	\N	\N	\N
18623	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21090J	\N	\N	\N
18624	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19399H	\N	\N	\N
18625	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19573D	\N	\N	\N
18626	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20062A	\N	\N	\N
18627	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20094J	\N	\N	\N
18628	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20050V	\N	\N	\N
18629	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19545Y	\N	\N	\N
18630	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20080C	\N	\N	\N
18631	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20070A	\N	\N	\N
18632	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	11074Q	\N	\N	\N
18633	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	11110B	\N	\N	\N
18634	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19647E	\N	\N	\N
18635	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14121F	\N	\N	\N
18636	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	12016W	\N	\N	\N
18637	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21079P	\N	\N	\N
18638	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20134Y	\N	\N	\N
18640	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14083S	\N	\N	\N
18641	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	11053K	\N	\N	\N
18642	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	11070L	\N	\N	\N
18643	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14327T	\N	\N	\N
18644	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	07004J	\N	\N	\N
18645	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	08009T	\N	\N	\N
18646	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19335Q	\N	\N	\N
18647	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19479G	\N	\N	\N
18648	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19667J	\N	\N	\N
18649	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21072G	\N	\N	\N
18650	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20126Y	\N	\N	\N
18651	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	07029T	\N	\N	\N
18652	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19711U	\N	\N	\N
18653	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	08010L	\N	\N	\N
18654	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	08034U	\N	\N	\N
18655	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	08011M	\N	\N	\N
18656	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14253S	\N	\N	\N
18657	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14331P	\N	\N	\N
18658	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20044X	\N	\N	\N
18659	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	14173T	\N	\N	\N
18660	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	11040E	\N	\N	\N
18661	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19687N	\N	\N	\N
18662	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20086J	\N	\N	\N
18663	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19349W	\N	\N	\N
18664	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	08073C	\N	\N	\N
18665	FINC	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20150Y	\N	\N	\N
15956	NEANT	2020-10-01 00:00:00	2020-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	20152B	\N	\N	\N
18086	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	99004R	\N	\N	\N
18087	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	04042C	\N	\N	\N
18090	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21072G	\N	\N	\N
18092	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21074J	\N	\N	\N
18098	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	18231D	\N	\N	\N
18099	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	21077M	\N	\N	\N
18100	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20252E	\N	\N	\N
18102	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19695N	\N	\N	\N
18103	NEANT	2023-10-02 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	11053K	\N	\N	\N
18840	EMPLO	2023-10-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	14071N	TITULAIRE	\N	\N
18841	EMPLO	2023-10-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	14026U	TITULAIRE	\N	\N
18842	EMPLO	2023-10-20 00:00:00	2023-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	20090E	TITULAIRE	\N	\N
18843	EMPLO	2023-10-20 00:00:00	2023-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	19569H	TITULAIRE	\N	\N
18844	EMPLO	2023-10-20 00:00:00	2023-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	17965H	TITULAIRE	\N	\N
18848	EMPLO	2023-10-20 00:00:00	2023-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	14223L	TITULAIRE	\N	\N
18846	EMPLO	2023-10-20 00:00:00	2023-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	14281W	TITULAIRE	\N	\N
18847	EMPLO	2023-10-20 00:00:00	2023-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	21097R	TITULAIRE	\N	\N
18849	EMPLO	2023-10-20 00:00:00	2023-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	19703U	TITULAIRE	\N	\N
18850	EMPLO	2023-10-20 00:00:00	2023-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	19691J	TITULAIRE	\N	\N
18851	EMPLO	2023-10-20 00:00:00	2023-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	18193Q	TITULAIRE	\N	\N
18852	EMPLO	2023-10-20 00:00:00	2023-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	19760E	TITULAIRE	\N	\N
18853	EMPLO	2023-10-20 00:00:00	2023-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	21087P	TITULAIRE	\N	\N
18854	EMPLO	2023-10-20 00:00:00	2023-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	20130U	TITULAIRE	\N	\N
16131	COMSPEAPU	2020-10-13 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19651A	\N	\N	\N
16132	COMSPEAPU	2020-10-13 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20116W	\N	\N	\N
16133	COMSPEAPU	2020-10-13 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20042V	\N	\N	\N
16134	COMSPEAPU	2020-10-13 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	11080N	\N	\N	\N
16135	COMSPEAPU	2020-10-13 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	11074Q	\N	\N	\N
16136	COMSPEAPU	2020-10-13 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19347U	\N	\N	\N
16137	COMSPEAPU	2020-10-13 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	01057W	\N	\N	\N
16138	COMSPEAPU	2020-10-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	14121F	\N	\N	\N
16139	COMSPEAPU	2020-10-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	19711U	\N	\N	\N
16140	COMSPEAPU	2020-10-13 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19335Q	\N	\N	\N
16141	COMSPEAPU	2020-10-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	05012A	\N	\N	\N
16142	ETRD	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14055N	\N	\N	\N
16143	CDD	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19685L	\N	\N	\N
16160	DDADUEF	2020-10-23 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	14225N	TITULAIRE	\N	\N
16161	DDADUEF	2020-10-23 00:00:00	2020-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	96004D	TITULAIRE	\N	\N
16162	DDADUEF	2020-10-23 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19507S	TITULAIRE	\N	\N
16163	DDADUEF	2020-10-23 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	08034U	TITULAIRE	\N	\N
16164	DDADUEF	2020-10-23 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	14083S	TITULAIRE	\N	\N
16165	DDADUEF	2020-10-23 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19531S	TITULAIRE	\N	\N
16166	DDADUEF	2020-10-23 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	11083R	TITULAIRE	\N	\N
16167	DDADUEF	2020-10-23 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19711U	SUPPLEANT	\N	\N
16168	DDADUEF	2020-10-23 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	14331P	SUPPLEANT	\N	\N
16169	DDADUEF	2020-10-23 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	14033T	SUPPLEANT	\N	\N
16170	DDADUEF	2020-10-23 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19441R	SUPPLEANT	\N	\N
16171	DDADUEF	2020-10-23 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19631V	SUPPLEANT	\N	\N
16172	DDADUEF	2020-10-23 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	11012A	SUPPLEANT	\N	\N
16173	DDADUEF	2020-10-23 00:00:00	2021-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	11040E	SUPPLEANT	\N	\N
16193	CSI	2020-10-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
16194	CSI	2020-10-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	04008A	TITULAIRE	\N	\N
16195	CSI	2020-10-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	19447X	TITULAIRE	\N	\N
16196	CSI	2020-10-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	14089Y	TITULAIRE	\N	\N
16197	CSI	2020-10-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	11026G	TITULAIRE	\N	\N
16198	CSI	2020-10-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	19649G	TITULAIRE	\N	\N
16199	CSI	2020-10-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	95063L	TITULAIRE	\N	\N
16200	CSI	2020-10-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	14069U	SUPPLEANT	\N	\N
16201	CSI	2020-10-22 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	SUPPLEANT	\N	\N
16202	CSI	2020-10-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	19673G	SUPPLEANT	\N	\N
16203	CSI	2020-10-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	11085T	SUPPLEANT	\N	\N
16204	CSI	2020-10-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	01028R	SUPPLEANT	\N	\N
16205	CSI	2020-10-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	04085P	SUPPLEANT	\N	\N
16206	CSI	2020-10-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	14107H	SUPPLEANT	\N	\N
16914	SEGL	2021-03-29 00:00:00	2021-04-02 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
16915	SEGL	2021-03-29 00:00:00	2021-04-02 00:00:00	ANCIEN	\N	\N	\N	\N	04008A	TITULAIRE	\N	\N
16916	SEGL	2021-03-29 00:00:00	2021-04-02 00:00:00	ANCIEN	\N	\N	\N	\N	17367Q	TITULAIRE	\N	\N
16917	SEGL	2021-03-29 00:00:00	2021-04-02 00:00:00	ANCIEN	\N	\N	\N	\N	14179A	TITULAIRE	\N	\N
16918	SEGL	2021-03-29 00:00:00	2021-04-02 00:00:00	ANCIEN	\N	\N	\N	\N	19649G	TITULAIRE	\N	\N
16919	SEGL	2021-03-29 00:00:00	2021-04-02 00:00:00	ANCIEN	\N	\N	\N	\N	20114U	TITULAIRE	\N	\N
16920	SEGL	2021-03-29 00:00:00	2021-04-02 00:00:00	ANCIEN	\N	\N	\N	\N	11072N	TITULAIRE	\N	\N
16921	SEGL	2021-03-29 00:00:00	2021-04-02 00:00:00	ANCIEN	\N	\N	\N	\N	19581D	SUPPLEANT	\N	\N
16922	SEGL	2021-03-29 00:00:00	2021-04-02 00:00:00	ANCIEN	\N	\N	\N	\N	20108W	SUPPLEANT	\N	\N
16923	SEGL	2021-03-29 00:00:00	2021-04-02 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	SUPPLEANT	\N	\N
16924	SEGL	2021-03-29 00:00:00	2021-04-02 00:00:00	ANCIEN	\N	\N	\N	\N	14231L	SUPPLEANT	\N	\N
16925	SEGL	2021-03-29 00:00:00	2021-04-02 00:00:00	ANCIEN	\N	\N	\N	\N	11026G	SUPPLEANT	\N	\N
16926	SEGL	2021-03-29 00:00:00	2021-04-02 00:00:00	ANCIEN	\N	\N	\N	\N	14107H	SUPPLEANT	\N	\N
16927	SEGL	2021-03-29 00:00:00	2021-04-02 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	SUPPLEANT	\N	\N
19100	DDADUE23	2023-11-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	14133K	\N	\N	\N
19670	NUCL	2024-03-07 00:00:00	2024-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	14187A	SUPPLEANT	\N	\N
19671	NUCL	2024-03-07 00:00:00	2024-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	20136B	SUPPLEANT	\N	\N
19672	NUCL	2024-03-07 00:00:00	2024-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	19619A	SUPPLEANT	\N	\N
19673	NUCL	2024-03-07 00:00:00	2024-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	14257W	SUPPLEANT	\N	\N
19674	NUCL	2024-03-07 00:00:00	2024-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	21070E	SUPPLEANT	\N	\N
19675	NUCL	2024-03-07 00:00:00	2024-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	11065P	SUPPLEANT	\N	\N
19676	NUCL	2024-03-07 00:00:00	2024-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	19695N	SUPPLEANT	\N	\N
19677	NUCL	2024-03-07 00:00:00	2024-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	14219Q	TITULAIRE	\N	\N
19678	NUCL	2024-03-07 00:00:00	2024-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	19826F	TITULAIRE	\N	\N
19679	NUCL	2024-03-07 00:00:00	2024-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	14038Y	TITULAIRE	\N	\N
19680	NUCL	2024-03-07 00:00:00	2024-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	14031R	TITULAIRE	\N	\N
19681	NUCL	2024-03-07 00:00:00	2024-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	19251M	TITULAIRE	\N	\N
19682	NUCL	2024-03-07 00:00:00	2024-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	21062E	TITULAIRE	\N	\N
19683	NUCL	2024-03-07 00:00:00	2024-04-04 00:00:00	ANCIEN	\N	\N	\N	\N	20106U	TITULAIRE	\N	\N
15865	NEANT	2020-08-03 00:00:00	2020-08-08 00:00:00	ANCIEN	\N	\N	\N	\N	19958S	\N	\N	\N
8393	2011CMP27	2011-12-19 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	SUPPLEANT	\N	\N
8870	2012CMP14	2012-07-26 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	SUPPLEANT	\N	\N
9478	2013CMP10	2013-07-04 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	SUPPLEANT	\N	\N
10696	2014CMP29	2014-11-20 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	TITULAIRE	\N	\N
16953	FINC	2021-09-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20086J	\N	\N	\N
16954	CAE	2021-09-09 00:00:00	2021-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	20252E	\N	\N	\N
17177	FINC	2022-07-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20914V	\N	\N	\N
17178	CAE	2022-07-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14037X	\N	\N	\N
17179	AFEU	2022-07-06 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19593H	\N	\N	\N
18340	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	11065P	\N	\N	\N
18341	CDD	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	20100N	\N	\N	\N
19541	VAPO	2024-03-21 00:00:00	2024-03-21 00:00:00	ANCIEN	\N	\N	\N	\N	14071N	TITULAIRE	\N	\N
19542	VAPO	2024-03-21 00:00:00	2024-03-21 00:00:00	ANCIEN	\N	\N	\N	\N	21081H	TITULAIRE	\N	\N
19543	VAPO	2024-03-20 00:00:00	2024-03-21 00:00:00	ANCIEN	\N	\N	\N	\N	14026U	TITULAIRE	\N	\N
19544	VAPO	2024-03-20 00:00:00	2024-03-21 00:00:00	ANCIEN	\N	\N	\N	\N	19691J	TITULAIRE	\N	\N
19545	VAPO	2024-03-20 00:00:00	2024-03-21 00:00:00	ANCIEN	\N	\N	\N	\N	17965H	TITULAIRE	\N	\N
19546	VAPO	2024-03-20 00:00:00	2024-03-21 00:00:00	ANCIEN	\N	\N	\N	\N	14281W	TITULAIRE	\N	\N
19547	VAPO	2024-03-20 00:00:00	2024-03-21 00:00:00	ANCIEN	\N	\N	\N	\N	20106U	TITULAIRE	\N	\N
19548	VAPO	2024-03-20 00:00:00	2024-03-21 00:00:00	ANCIEN	\N	\N	\N	\N	19723Y	SUPPLEANT	\N	\N
19549	VAPO	2024-03-20 00:00:00	2024-03-21 00:00:00	ANCIEN	\N	\N	\N	\N	19798U	SUPPLEANT	\N	\N
19550	VAPO	2024-03-20 00:00:00	2024-03-21 00:00:00	ANCIEN	\N	\N	\N	\N	19569H	SUPPLEANT	\N	\N
19551	VAPO	2024-03-20 00:00:00	2024-03-21 00:00:00	ANCIEN	\N	\N	\N	\N	18193Q	SUPPLEANT	\N	\N
19552	VAPO	2024-03-20 00:00:00	2024-03-21 00:00:00	ANCIEN	\N	\N	\N	\N	21049H	SUPPLEANT	\N	\N
19553	VAPO	2024-03-20 00:00:00	2024-03-21 00:00:00	ANCIEN	\N	\N	\N	\N	21046E	SUPPLEANT	\N	\N
19554	VAPO	2024-03-20 00:00:00	2024-03-21 00:00:00	ANCIEN	\N	\N	\N	\N	21094N	SUPPLEANT	\N	\N
19555	NUME	2024-03-20 00:00:00	2024-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	20098N	SUPPLEANT	\N	\N
19556	NUME	2024-03-20 00:00:00	2024-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	20034V	SUPPLEANT	\N	\N
19557	NUME	2024-03-20 00:00:00	2024-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	14179A	SUPPLEANT	\N	\N
19558	NUME	2024-03-20 00:00:00	2024-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	20094J	SUPPLEANT	\N	\N
19559	NUME	2024-03-20 00:00:00	2024-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	19593H	SUPPLEANT	\N	\N
19560	NUME	2024-03-20 00:00:00	2024-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	20122U	SUPPLEANT	\N	\N
19561	NUME	2024-03-20 00:00:00	2024-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	20134Y	SUPPLEANT	\N	\N
19562	NUME	2024-03-20 00:00:00	2024-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	04070G	TITULAIRE	\N	\N
19563	NUME	2024-03-20 00:00:00	2024-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	14038Y	TITULAIRE	\N	\N
19564	NUME	2024-03-20 00:00:00	2024-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	20022R	TITULAIRE	\N	\N
19565	NUME	2024-03-20 00:00:00	2024-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	20062A	TITULAIRE	\N	\N
19566	NUME	2024-03-20 00:00:00	2024-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	20060X	TITULAIRE	\N	\N
19567	NUME	2024-03-20 00:00:00	2024-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	11045K	TITULAIRE	\N	\N
19568	NUME	2024-03-20 00:00:00	2024-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	20128B	TITULAIRE	\N	\N
19600	AFCL	2024-03-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	21125C	\N	\N	\N
15869	NEANT	2020-08-04 00:00:00	2020-08-08 00:00:00	ANCIEN	\N	\N	\N	\N	19968U	\N	\N	\N
19072	PLFSS	2023-11-17 00:00:00	2023-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	14217N	SUPPLEANT	\N	\N
19073	PLFSS	2023-11-17 00:00:00	2023-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	19798U	SUPPLEANT	\N	\N
19074	PLFSS	2023-11-17 00:00:00	2023-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	19569H	SUPPLEANT	\N	\N
19075	PLFSS	2023-11-17 00:00:00	2023-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	21045D	SUPPLEANT	\N	\N
19076	PLFSS	2023-11-17 00:00:00	2023-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	19760E	SUPPLEANT	\N	\N
19077	PLFSS	2023-11-17 00:00:00	2023-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	21087P	SUPPLEANT	\N	\N
19078	PLFSS	2023-11-17 00:00:00	2023-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	21094N	SUPPLEANT	\N	\N
19079	PLFSS	2023-11-17 00:00:00	2023-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	14071N	TITULAIRE	\N	\N
19080	PLFSS	2023-11-17 00:00:00	2023-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	14042U	TITULAIRE	\N	\N
19081	PLFSS	2023-11-17 00:00:00	2023-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	14213J	TITULAIRE	\N	\N
19082	PLFSS	2023-11-17 00:00:00	2023-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	14026U	TITULAIRE	\N	\N
19083	PLFSS	2023-11-17 00:00:00	2023-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	19683J	TITULAIRE	\N	\N
19084	PLFSS	2023-11-17 00:00:00	2023-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	17779H	TITULAIRE	\N	\N
19085	PLFSS	2023-11-17 00:00:00	2023-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	19591F	TITULAIRE	\N	\N
19086	PLFFG	2023-11-17 00:00:00	2023-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	21090J	SUPPLEANT	\N	\N
19087	PLFFG	2023-11-17 00:00:00	2023-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	21072G	SUPPLEANT	\N	\N
19088	PLFFG	2023-11-17 00:00:00	2023-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	11053K	SUPPLEANT	\N	\N
19089	PLFFG	2023-11-17 00:00:00	2023-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	20080C	SUPPLEANT	\N	\N
19090	PLFFG	2023-11-17 00:00:00	2023-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	19687N	SUPPLEANT	\N	\N
19091	PLFFG	2023-11-17 00:00:00	2023-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	19545Y	SUPPLEANT	\N	\N
19092	PLFFG	2023-11-17 00:00:00	2023-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	20134Y	SUPPLEANT	\N	\N
19093	PLFFG	2023-11-17 00:00:00	2023-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	14225N	TITULAIRE	\N	\N
19094	PLFFG	2023-11-17 00:00:00	2023-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	TITULAIRE	\N	\N
19095	PLFFG	2023-11-17 00:00:00	2023-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	19711U	TITULAIRE	\N	\N
19096	PLFFG	2023-11-17 00:00:00	2023-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	20044X	TITULAIRE	\N	\N
19097	PLFFG	2023-11-17 00:00:00	2023-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	11070L	TITULAIRE	\N	\N
19098	PLFFG	2023-11-17 00:00:00	2023-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	20070A	TITULAIRE	\N	\N
19099	PLFFG	2023-11-17 00:00:00	2023-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	19349W	TITULAIRE	\N	\N
19540	NEANT	2024-03-18 00:00:00	2024-03-26 00:00:00	ANCIEN	\N	\N	\N	\N	21125C	\N	\N	\N
19698	CRIM	2024-04-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
19699	CRIM	2024-04-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	19447X	TITULAIRE	\N	\N
19700	CRIM	2024-04-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	20098N	TITULAIRE	\N	\N
19701	CRIM	2024-04-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	20074E	SUPPLEANT	\N	\N
19702	CRIM	2024-04-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	14215L	SUPPLEANT	\N	\N
19703	CRIM	2024-04-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	14089Y	SUPPLEANT	\N	\N
19704	CRIM	2024-04-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	21056G	SUPPLEANT	\N	\N
19705	CRIM	2024-04-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	21088Q	SUPPLEANT	\N	\N
19709	CRIM	2024-04-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	20036X	TITULAIRE	\N	\N
19707	CRIM	2024-04-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	14111D	SUPPLEANT	\N	\N
19708	CRIM	2024-04-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	20110Q	SUPPLEANT	\N	\N
19710	CRIM	2024-04-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	14151M	TITULAIRE	\N	\N
19711	CRIM	2024-04-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	19649G	TITULAIRE	\N	\N
19712	CRIM	2024-04-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	04045F	TITULAIRE	\N	\N
15676	NEANT	2020-06-16 00:00:00	2020-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	19912C	\N	\N	\N
15821	LOIS	2020-07-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19954N	\N	\N	\N
10238	AFEU	2014-10-09 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	10015M	\N	2014-10-09 09:40:42	2017-10-05 14:42:58
18727	AFEU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	14133K	\N	\N	\N
18728	AFEU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	19760E	\N	\N	\N
18729	AFEU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	14189C	\N	\N	\N
18730	AFEU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20094J	\N	\N	\N
18731	AFEU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20042V	\N	\N	\N
18732	AFEU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	17737W	\N	\N	\N
18733	AFEU	2023-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20104S	\N	\N	\N
16996	CULTURE	2021-11-18 00:00:00	2022-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	20112S	\N	\N	\N
17000	CULTURE	2021-11-18 00:00:00	2022-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	19643A	\N	\N	\N
16998	CULTURE	2021-11-18 00:00:00	2022-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	19954N	\N	\N	\N
16999	CULTURE	2021-11-18 00:00:00	2022-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	20042V	\N	\N	\N
17001	CULTURE	2021-11-18 00:00:00	2022-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	20114U	\N	\N	\N
17002	CULTURE	2021-11-18 00:00:00	2022-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	14207L	\N	\N	\N
17003	CULTURE	2021-11-18 00:00:00	2022-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	14267Y	\N	\N	\N
17004	CULTURE	2021-11-18 00:00:00	2022-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	19693L	\N	\N	\N
17005	CULTURE	2021-11-18 00:00:00	2022-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	17589D	\N	\N	\N
17006	CULTURE	2021-11-18 00:00:00	2022-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	\N	\N	\N
17007	CULTURE	2021-11-18 00:00:00	2022-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	20134Y	\N	\N	\N
17008	CULTURE	2021-11-18 00:00:00	2022-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	20124W	\N	\N	\N
17009	CULTURE	2021-11-18 00:00:00	2022-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	19599P	\N	\N	\N
17010	CULTURE	2021-11-18 00:00:00	2022-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	17023S	\N	\N	\N
17011	CULTURE	2021-11-18 00:00:00	2022-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	19820Y	\N	\N	\N
17012	CULTURE	2021-11-18 00:00:00	2022-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	20096L	\N	\N	\N
17013	CULTURE	2021-11-18 00:00:00	2022-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	19533U	\N	\N	\N
17014	CULTURE	2021-11-18 00:00:00	2022-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	19798U	\N	\N	\N
17015	CULTURE	2021-11-18 00:00:00	2022-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	04045F	\N	\N	\N
17016	MEDIA	2021-11-18 00:00:00	2022-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	04059M	\N	\N	\N
17017	MEDIA	2021-11-18 00:00:00	2022-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	19651A	\N	\N	\N
17018	MEDIA	2021-11-18 00:00:00	2022-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	20086J	\N	\N	\N
17019	MEDIA	2021-11-18 00:00:00	2022-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	20152B	\N	\N	\N
17020	MEDIA	2021-11-18 00:00:00	2022-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	19621T	\N	\N	\N
17021	MEDIA	2021-11-18 00:00:00	2022-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	11053K	\N	\N	\N
17022	MEDIA	2021-11-18 00:00:00	2022-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	11080N	\N	\N	\N
17023	MEDIA	2021-11-18 00:00:00	2022-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	20142Y	\N	\N	\N
17024	MEDIA	2021-11-18 00:00:00	2022-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	19673G	\N	\N	\N
17025	MEDIA	2021-11-18 00:00:00	2022-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	20132W	\N	\N	\N
17026	MEDIA	2021-11-18 00:00:00	2022-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	19725B	\N	\N	\N
17027	MEDIA	2021-11-18 00:00:00	2022-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	19399H	\N	\N	\N
17028	MEDIA	2021-11-18 00:00:00	2022-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	20056C	\N	\N	\N
17029	MEDIA	2021-11-18 00:00:00	2022-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	19611R	\N	\N	\N
17030	MEDIA	2021-11-18 00:00:00	2022-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	19699S	\N	\N	\N
17031	MEDIA	2021-11-18 00:00:00	2022-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	12041X	\N	\N	\N
17032	MEDIA	2021-11-18 00:00:00	2022-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	19705W	\N	\N	\N
17033	MEDIA	2021-11-18 00:00:00	2022-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	14229S	\N	\N	\N
17034	MEDIA	2021-11-18 00:00:00	2022-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	19669L	\N	\N	\N
17035	MEDIA	2021-11-18 00:00:00	2022-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	20026V	\N	\N	\N
17036	MEDIA	2021-11-18 00:00:00	2022-03-29 00:00:00	ANCIEN	\N	\N	\N	\N	20122U	\N	\N	\N
17037	CABINETS	2021-11-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	04085P	\N	\N	\N
17038	CABINETS	2021-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19741B	\N	\N	\N
17039	CABINETS	2021-11-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	19667J	\N	\N	\N
17040	CABINETS	2021-11-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	17737W	\N	\N	\N
17041	CABINETS	2021-11-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	20090E	\N	\N	\N
17042	CABINETS	2021-11-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	19681G	\N	\N	\N
17043	CABINETS	2021-11-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	14249W	\N	\N	\N
17044	CABINETS	2021-11-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	20038A	\N	\N	\N
17045	CABINETS	2021-11-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	07004J	\N	\N	\N
17046	CABINETS	2021-11-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	19511N	\N	\N	\N
17047	CABINETS	2021-11-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	19531S	\N	\N	\N
17048	CABINETS	2021-11-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	19711U	\N	\N	\N
17049	CABINETS	2021-11-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	19671E	\N	\N	\N
17050	CABINETS	2021-11-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	19335Q	\N	\N	\N
17051	CABINETS	2021-11-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	14257W	\N	\N	\N
17052	CABINETS	2021-11-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	20044X	\N	\N	\N
17053	CABINETS	2021-11-18 00:00:00	2022-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	19689Q	\N	\N	\N
17054	CABINETS	2021-11-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	20064C	\N	\N	\N
17055	CABINETS	2021-11-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	19585H	\N	\N	\N
17168	SOCI	2021-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20266L	\N	\N	\N
17169	AFCL	2021-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20172F	\N	\N	\N
17961	SPOL	2023-07-06 00:00:00	2023-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	19611R	TITULAIRE	\N	\N
17962	SPOL	2023-07-06 00:00:00	2023-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	20180F	TITULAIRE	\N	\N
17963	SPOL	2023-07-06 00:00:00	2023-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	20056C	TITULAIRE	\N	\N
17964	SPOL	2023-07-06 00:00:00	2023-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	20124W	TITULAIRE	\N	\N
17965	SPOL	2023-07-06 00:00:00	2023-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	20084G	TITULAIRE	\N	\N
17966	SPOL	2023-07-06 00:00:00	2023-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	20264J	TITULAIRE	\N	\N
17967	SPOL	2023-07-06 00:00:00	2023-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	19651A	TITULAIRE	\N	\N
17968	SPOL	2023-07-06 00:00:00	2023-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	20098N	SUPPLEANT	\N	\N
17969	SPOL	2023-07-06 00:00:00	2023-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	20980G	SUPPLEANT	\N	\N
17970	SPOL	2023-07-06 00:00:00	2023-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	19643A	SUPPLEANT	\N	\N
17971	SPOL	2023-07-06 00:00:00	2023-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	04070G	SUPPLEANT	\N	\N
17972	SPOL	2023-07-06 00:00:00	2023-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	14229S	SUPPLEANT	\N	\N
17973	SPOL	2023-07-06 00:00:00	2023-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	20132W	SUPPLEANT	\N	\N
17974	SPOL	2023-07-06 00:00:00	2023-07-06 00:00:00	ANCIEN	\N	\N	\N	\N	19593H	SUPPLEANT	\N	\N
17975	PAFP	2023-06-28 00:00:00	2023-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	TITULAIRE	\N	\N
17976	PAFP	2023-06-28 00:00:00	2023-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	20074E	TITULAIRE	\N	\N
17977	PAFP	2023-06-28 00:00:00	2023-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	TITULAIRE	\N	\N
17978	PAFP	2023-06-28 00:00:00	2023-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	19749K	TITULAIRE	\N	\N
17979	PAFP	2023-06-28 00:00:00	2023-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	19599P	TITULAIRE	\N	\N
17980	PAFP	2023-06-28 00:00:00	2023-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	14001X	TITULAIRE	\N	\N
17981	PAFP	2023-06-28 00:00:00	2023-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	11072N	TITULAIRE	\N	\N
19643	ETRD	2024-04-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	21032X	\N	\N	\N
15545	ILLECTRONISM	2020-03-04 00:00:00	2020-09-17 00:00:00	ANCIEN	\N	\N	\N	\N	19591F	\N	\N	\N
15546	ILLECTRONISM	2020-03-04 00:00:00	2020-09-17 00:00:00	ANCIEN	\N	\N	\N	\N	11083R	\N	\N	\N
15547	ILLECTRONISM	2020-03-04 00:00:00	2020-09-17 00:00:00	ANCIEN	\N	\N	\N	\N	19631V	\N	\N	\N
15548	ILLECTRONISM	2020-03-04 00:00:00	2020-09-17 00:00:00	ANCIEN	\N	\N	\N	\N	19489J	\N	\N	\N
15549	ILLECTRONISM	2020-03-04 00:00:00	2020-09-17 00:00:00	ANCIEN	\N	\N	\N	\N	11104D	\N	\N	\N
15550	ILLECTRONISM	2020-03-04 00:00:00	2020-09-17 00:00:00	ANCIEN	\N	\N	\N	\N	19503N	\N	\N	\N
15551	ILLECTRONISM	2020-03-04 00:00:00	2020-09-17 00:00:00	ANCIEN	\N	\N	\N	\N	19689Q	\N	\N	\N
15552	ILLECTRONISM	2020-03-04 00:00:00	2020-09-17 00:00:00	ANCIEN	\N	\N	\N	\N	19577H	\N	\N	\N
15553	ILLECTRONISM	2020-03-04 00:00:00	2020-09-17 00:00:00	ANCIEN	\N	\N	\N	\N	19335Q	\N	\N	\N
15554	ILLECTRONISM	2020-03-04 00:00:00	2020-09-17 00:00:00	ANCIEN	\N	\N	\N	\N	19619A	\N	\N	\N
15555	ILLECTRONISM	2020-03-04 00:00:00	2020-09-17 00:00:00	ANCIEN	\N	\N	\N	\N	19515S	\N	\N	\N
15556	ILLECTRONISM	2020-03-04 00:00:00	2020-09-17 00:00:00	ANCIEN	\N	\N	\N	\N	19575F	\N	\N	\N
15557	ILLECTRONISM	2020-03-04 00:00:00	2020-09-17 00:00:00	ANCIEN	\N	\N	\N	\N	14069U	\N	\N	\N
15558	ILLECTRONISM	2020-03-04 00:00:00	2020-09-17 00:00:00	ANCIEN	\N	\N	\N	\N	14038Y	\N	\N	\N
15559	ILLECTRONISM	2020-03-04 00:00:00	2020-09-17 00:00:00	ANCIEN	\N	\N	\N	\N	14026U	\N	\N	\N
15560	ILLECTRONISM	2020-03-04 00:00:00	2020-09-17 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	\N	\N	\N
15561	ILLECTRONISM	2020-03-04 00:00:00	2020-09-17 00:00:00	ANCIEN	\N	\N	\N	\N	14071N	\N	\N	\N
15562	ILLECTRONISM	2020-03-04 00:00:00	2020-09-17 00:00:00	ANCIEN	\N	\N	\N	\N	14237S	\N	\N	\N
15563	ILLECTRONISM	2020-03-04 00:00:00	2020-09-17 00:00:00	ANCIEN	\N	\N	\N	\N	19798U	\N	\N	\N
15564	ILLECTRONISM	2020-03-04 00:00:00	2020-09-17 00:00:00	ANCIEN	\N	\N	\N	\N	19545Y	\N	\N	\N
15565	ILLECTRONISM	2020-03-04 00:00:00	2020-09-17 00:00:00	ANCIEN	\N	\N	\N	\N	19387D	\N	\N	\N
15566	ILLECTRONISM	2020-03-04 00:00:00	2020-09-17 00:00:00	ANCIEN	\N	\N	\N	\N	08049C	\N	\N	\N
15567	ILLECTRONISM	2020-03-04 00:00:00	2020-09-17 00:00:00	ANCIEN	\N	\N	\N	\N	19593H	\N	\N	\N
18530	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	21088Q	\N	\N	\N
18531	LOIS	2023-10-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	11056N	\N	\N	\N
18788	CDD	2023-10-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	20040T	\N	\N	\N
\.


--
-- Data for Name: memdelega; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY memdelega (memdelegaid, orgcod, memdelegadatdeb, memdelegadatfin, temvalcod, evelic, evelib, evelil, eveobs, senmat, designcod, syscredat, sysmajdat) FROM stdin;
860	211	2001-10-10 00:00:00	2002-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	97007L	MEMBRE	\N	\N
861	211	2001-10-10 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	98030P	MEMBRE	\N	\N
862	211	2001-10-10 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92020L	MEMBRE	\N	\N
754	211	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	98015Q	MEMBRE	\N	\N
755	211	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	95058P	MEMBRE	\N	\N
757	211	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	92005M	MEMBRE	\N	\N
758	211	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	97005J	MEMBRE	\N	\N
759	211	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	92044U	MEMBRE	\N	\N
760	202	1999-10-20 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	98051U	MEMBRE	\N	\N
762	206	1999-12-01 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	96006F	TITULAIRE	\N	\N
763	202	2000-03-22 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	98031Q	MEMBRE	\N	\N
764	205	2000-05-03 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	80039J	MEMBRE	\N	\N
765	207	2000-05-03 00:00:00	2000-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	95058P	MEMBRE	\N	\N
753	211	1999-10-13 00:00:00	2000-10-24 00:00:00	ANCIEN	\N	\N	\N	\N	95051G	MEMBRE	\N	\N
733	211	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	98031Q	MEMBRE	\N	\N
734	211	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	97007L	MEMBRE	\N	\N
735	211	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	98030P	MEMBRE	\N	\N
737	211	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	92020L	MEMBRE	\N	\N
738	211	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	98019U	MEMBRE	\N	\N
739	211	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	MEMBRE	\N	\N
740	211	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	98017S	MEMBRE	\N	\N
741	211	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	95035G	MEMBRE	\N	\N
742	211	1999-10-13 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92025R	MEMBRE	\N	\N
743	211	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	95041E	MEMBRE	\N	\N
744	211	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	97004H	MEMBRE	\N	\N
745	211	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	98025S	MEMBRE	\N	\N
747	211	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	77044F	MEMBRE	\N	\N
749	211	1999-10-13 00:00:00	1999-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	95050F	MEMBRE	\N	\N
761	211	1999-11-03 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	94003T	MEMBRE	\N	\N
751	211	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	92040Q	MEMBRE	\N	\N
752	211	1999-10-13 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83046V	MEMBRE	\N	\N
650	207	1998-10-21 00:00:00	2000-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	MEMBRE	\N	\N
651	207	1998-10-21 00:00:00	2000-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	92041R	MEMBRE	\N	\N
652	207	1998-10-21 00:00:00	2000-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	98019U	MEMBRE	\N	\N
653	207	1998-10-21 00:00:00	2000-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	89045V	MEMBRE	\N	\N
654	207	1998-10-21 00:00:00	2000-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	83028T	MEMBRE	\N	\N
655	207	1998-10-21 00:00:00	2000-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	86041D	MEMBRE	\N	\N
656	207	1998-10-21 00:00:00	2000-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	92022N	MEMBRE	\N	\N
657	208	1998-10-21 00:00:00	2001-10-24 00:00:00	ANCIEN	\N	\N	\N	\N	77033C	TITULAIRE	\N	\N
659	208	1998-10-21 00:00:00	2001-10-24 00:00:00	ANCIEN	\N	\N	\N	\N	95013A	TITULAIRE	\N	\N
661	208	1998-10-21 00:00:00	2001-10-24 00:00:00	ANCIEN	\N	\N	\N	\N	95014B	TITULAIRE	\N	\N
662	208	1998-10-21 00:00:00	2001-10-24 00:00:00	ANCIEN	\N	\N	\N	\N	66002K	TITULAIRE	\N	\N
663	208	1998-10-21 00:00:00	2001-10-24 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	TITULAIRE	\N	\N
664	208	1998-10-21 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83010H	TITULAIRE	\N	\N
665	208	1998-10-21 00:00:00	2001-10-24 00:00:00	ANCIEN	\N	\N	\N	\N	95006B	TITULAIRE	\N	\N
666	208	1998-10-21 00:00:00	2001-10-24 00:00:00	ANCIEN	\N	\N	\N	\N	97007L	TITULAIRE	\N	\N
667	208	1998-10-21 00:00:00	2000-03-28 00:00:00	ANCIEN	\N	\N	\N	\N	97003G	TITULAIRE	\N	\N
668	208	1998-10-21 00:00:00	2001-10-24 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	TITULAIRE	\N	\N
669	208	1998-10-21 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83038V	TITULAIRE	\N	\N
670	208	1998-10-21 00:00:00	2001-10-24 00:00:00	ANCIEN	\N	\N	\N	\N	92030N	TITULAIRE	\N	\N
673	DELCONEUR	1998-10-20 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83046V	TITULAIRE	\N	\N
674	DELCONEUR	1998-10-20 00:00:00	2001-10-23 00:00:00	ANCIEN	\N	\N	\N	\N	82002D	TITULAIRE	\N	\N
689	DELCONEUR	1998-10-20 00:00:00	2001-10-23 00:00:00	ANCIEN	\N	\N	\N	\N	92020L	TITULAIRE	\N	\N
680	DELCONEUR	1998-10-20 00:00:00	2001-10-23 00:00:00	ANCIEN	\N	\N	\N	\N	77017C	SUPPLEANT	\N	\N
691	CSCE	\N	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	92012L	MEMBRE	\N	\N
683	DELCONEUR	1998-10-20 00:00:00	2001-10-23 00:00:00	ANCIEN	\N	\N	\N	\N	92031P	SUPPLEANT	\N	\N
685	DELCONEUR	1998-10-20 00:00:00	2001-10-23 00:00:00	ANCIEN	\N	\N	\N	\N	95058P	SUPPLEANT	\N	\N
692	CSCE	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83020K	MEMBRE	\N	\N
694	CSCE	2001-11-29 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77046H	MEMBRE	\N	\N
695	202	1995-10-12 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	95004Y	MEMBRE	\N	\N
700	202	1998-12-08 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	78007E	MEMBRE	\N	\N
701	202	1998-12-08 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	98032R	MEMBRE	\N	\N
704	202	1999-10-05 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	98018T	MEMBRE	\N	\N
703	CSCE	\N	1999-02-17 00:00:00	ANCIEN	\N	\N	\N	\N	95007C	MEMBRE	\N	\N
723	211	1999-10-13 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	94004U	MEMBRE	\N	\N
707	210	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	86011W	MEMBRE	\N	\N
708	210	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	89013M	MEMBRE	\N	\N
709	210	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	89010J	MEMBRE	\N	\N
711	210	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	83033Q	MEMBRE	\N	\N
712	210	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	89030N	MEMBRE	\N	\N
713	210	1999-10-13 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83035S	MEMBRE	\N	\N
715	210	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	98038X	MEMBRE	\N	\N
716	210	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	86041D	MEMBRE	\N	\N
718	210	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	96006F	MEMBRE	\N	\N
719	210	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	95059Q	MEMBRE	\N	\N
720	210	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	MEMBRE	\N	\N
721	210	1999-10-13 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	94004U	MEMBRE	\N	\N
724	211	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	89019T	MEMBRE	\N	\N
725	211	1999-10-13 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92009R	MEMBRE	\N	\N
727	211	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	88004G	MEMBRE	\N	\N
728	211	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	98014P	MEMBRE	\N	\N
729	211	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	89023P	MEMBRE	\N	\N
731	211	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	95019G	MEMBRE	\N	\N
732	211	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	98023Q	MEMBRE	\N	\N
574	205	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	83047W	MEMBRE	\N	\N
588	206	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	85003S	TITULAIRE	\N	\N
576	205	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	98010K	MEMBRE	\N	\N
583	202	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	95025E	MEMBRE	\N	\N
580	205	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	97005J	MEMBRE	\N	\N
581	205	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	MEMBRE	\N	\N
584	206	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	\N	95025E	TITULAIRE	\N	\N
587	206	1998-10-14 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83028T	TITULAIRE	\N	\N
589	206	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	92039X	TITULAIRE	\N	\N
591	206	1998-10-14 00:00:00	1999-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	77066M	TITULAIRE	\N	\N
592	206	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	86047K	TITULAIRE	\N	\N
593	206	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	80046H	TITULAIRE	\N	\N
594	206	1998-10-14 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83036T	SUPPLEANT	\N	\N
596	206	1998-10-14 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	74042Q	SUPPLEANT	\N	\N
601	206	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	85002R	SUPPLEANT	\N	\N
602	206	1998-10-14 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	74015M	SUPPLEANT	\N	\N
603	206	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	89040Q	SUPPLEANT	\N	\N
604	206	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	92011K	MEMBRE	\N	\N
608	206	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	\N	92005M	TITULAIRE	\N	\N
611	203	1998-10-14 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	86005Y	MEMBRE	\N	\N
612	203	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	89019T	MEMBRE	\N	\N
613	203	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	92011K	MEMBRE	\N	\N
616	203	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	77013X	MEMBRE	\N	\N
617	203	1998-10-14 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92019T	MEMBRE	\N	\N
619	203	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	95033E	MEMBRE	\N	\N
642	207	1998-10-21 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	86005Y	MEMBRE	\N	\N
643	207	1998-10-21 00:00:00	2000-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	81015E	MEMBRE	\N	\N
688	DELCONEUR	1998-10-20 00:00:00	2001-10-23 00:00:00	ANCIEN	\N	\N	\N	\N	77029G	TITULAIRE	\N	\N
644	207	1998-10-21 00:00:00	2000-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	95018F	TITULAIRE	\N	\N
645	207	1998-10-21 00:00:00	2000-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	77017C	MEMBRE	\N	\N
646	207	1998-10-21 00:00:00	2000-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	97011G	MEMBRE	\N	\N
647	207	1998-10-21 00:00:00	2000-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	98047Y	MEMBRE	\N	\N
648	207	1998-10-21 00:00:00	2000-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	86037H	MEMBRE	\N	\N
699	207	1998-10-21 00:00:00	2000-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	92029V	MEMBRE	\N	\N
179	208	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'evaluation de la legislation/ 	83020K	MEMBRE	\N	\N
180	208	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'evaluation de la legislation/ 	83038V	MEMBRE	\N	\N
181	208	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'evaluation de la legislation/ 	83052T	MEMBRE	\N	\N
182	208	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'evaluation de la legislation/ 	83010H	MEMBRE	\N	\N
183	208	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Problemes demographiques/ Office parlementaire d'evaluation de la legislation/ 	95014B	MEMBRE	\N	\N
184	208	\N	1998-10-02 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'evaluation de la legislation/ 	88006J	MEMBRE	\N	\N
185	208	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'evaluation de la legislation/ 	95034F	MEMBRE	\N	\N
186	208	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'evaluation de la legislation/ 	77033C	MEMBRE	\N	\N
187	208	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'evaluation de la legislation/ 	95039L	MEMBRE	\N	\N
188	208	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'evaluation de la legislation/ 	95028H	MEMBRE	\N	\N
509	205	1998-10-14 00:00:00	2000-10-16 00:00:00	ANCIEN	\N	\N	\N	\N	98036V	MEMBRE	\N	\N
510	202	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	97009N	MEMBRE	\N	\N
544	202	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	86025D	MEMBRE	\N	\N
517	202	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	84004P	MEMBRE	\N	\N
518	202	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	96004D	MEMBRE	\N	\N
522	206	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	95025E	TITULAIRE	\N	\N
524	202	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	90002A	MEMBRE	\N	\N
525	202	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	89027T	MEMBRE	\N	\N
527	202	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	98019U	MEMBRE	\N	\N
531	202	1998-10-14 00:00:00	1999-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	86030A	MEMBRE	\N	\N
533	202	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	97004H	MEMBRE	\N	\N
535	202	1998-10-14 00:00:00	2000-10-24 00:00:00	ANCIEN	\N	\N	\N	\N	92033R	MEMBRE	\N	\N
537	202	1998-10-14 00:00:00	1998-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	98032R	MEMBRE	\N	\N
539	202	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	98035U	MEMBRE	\N	\N
541	202	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	95066P	MEMBRE	\N	\N
543	202	1998-10-14 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	92012L	MEMBRE	\N	\N
545	202	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	92022N	MEMBRE	\N	\N
546	202	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	86031B	MEMBRE	\N	\N
547	202	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	95006B	MEMBRE	\N	\N
548	202	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	95007C	MEMBRE	\N	\N
549	202	1998-10-14 00:00:00	1999-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	95008D	MEMBRE	\N	\N
551	202	1998-10-14 00:00:00	1998-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	78007E	MEMBRE	\N	\N
552	202	1998-10-14 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92019T	MEMBRE	\N	\N
553	202	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	\N	83003J	TITULAIRE	\N	\N
554	202	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	94003T	MEMBRE	\N	\N
555	202	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	77029G	MEMBRE	\N	\N
556	202	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	88013H	MEMBRE	\N	\N
557	202	1998-10-14 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83043S	MEMBRE	\N	\N
558	202	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	86041D	MEMBRE	\N	\N
559	202	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	95058P	MEMBRE	\N	\N
561	202	1998-10-14 00:00:00	2000-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	86047K	MEMBRE	\N	\N
562	202	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	86050E	MEMBRE	\N	\N
927	206	2001-10-10 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89040Q	MEMBRE	\N	\N
928	206	2001-10-10 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	MEMBRE	\N	\N
929	206	2001-10-10 00:00:00	2002-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	98038X	SUPPLEANT	\N	\N
930	206	2001-10-10 00:00:00	2004-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	01019Q	MEMBRE	\N	\N
931	206	2001-10-10 00:00:00	2004-10-13 00:00:00	ANCIEN	\N	\N	\N	\N	01060R	MEMBRE	\N	\N
934	211	2001-10-18 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	88008L	MEMBRE	\N	\N
678	DELCONEUR	1998-10-20 00:00:00	2001-10-23 00:00:00	ANCIEN	\N	\N	\N	\N	92024Q	SUPPLEANT	\N	\N
690	DELCONEUR	1998-10-20 00:00:00	2001-10-23 00:00:00	ANCIEN	\N	\N	\N	\N	98014P	SUPPLEANT	\N	\N
936	DELCONEUR	2001-10-23 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98014P	SUPPLEANT	\N	\N
937	DELCONEUR	2001-10-23 00:00:00	2008-09-07 00:00:00	ANCIEN	\N	\N	\N	\N	80017C	SUPPLEANT	\N	\N
939	DELCONEUR	2001-10-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83042R	SUPPLEANT	\N	\N
940	DELCONEUR	2001-10-23 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	01060R	SUPPLEANT	\N	\N
941	DELCONEUR	2001-10-23 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	98021N	SUPPLEANT	\N	\N
942	DELCONEUR	2001-10-23 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77017C	MEMBRE	\N	\N
945	DELCONEUR	2001-10-23 00:00:00	2008-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	92031P	TITULAIRE	\N	\N
946	DELCONEUR	2001-10-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	82002D	SUPPLEANT	\N	\N
947	DELCONEUR	2001-10-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92040Q	TITULAIRE	\N	\N
660	208	1998-10-21 00:00:00	2001-10-24 00:00:00	ANCIEN	\N	\N	\N	\N	92024Q	TITULAIRE	\N	\N
671	208	1998-10-21 00:00:00	2001-10-24 00:00:00	ANCIEN	\N	\N	\N	\N	95046K	TITULAIRE	\N	\N
948	208	2001-10-24 00:00:00	2004-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	98041S	MEMBRE	\N	\N
949	208	2001-10-24 00:00:00	2004-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	87003B	MEMBRE	\N	\N
950	208	2001-10-24 00:00:00	2004-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	01057W	MEMBRE	\N	\N
951	208	2001-10-24 00:00:00	2004-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	92024Q	MEMBRE	\N	\N
952	208	2001-10-24 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95014B	TITULAIRE	\N	\N
953	208	2001-10-24 00:00:00	2004-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	66002K	MEMBRE	\N	\N
954	208	2001-10-24 00:00:00	2004-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	MEMBRE	\N	\N
955	208	2001-10-24 00:00:00	2004-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	MEMBRE	\N	\N
957	208	2001-10-24 00:00:00	2004-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	98016R	MEMBRE	\N	\N
958	208	2001-10-24 00:00:00	2002-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	97007L	MEMBRE	\N	\N
959	208	2001-10-24 00:00:00	2004-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	MEMBRE	\N	\N
960	208	2001-10-24 00:00:00	2004-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	01042P	MEMBRE	\N	\N
961	208	2001-10-24 00:00:00	2004-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	95046K	MEMBRE	\N	\N
962	208	2001-10-24 00:00:00	2004-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	01019Q	MEMBRE	\N	\N
28	DELCONEUR	\N	1998-10-20 00:00:00	ANCIEN	\N	\N	\N	Conseil de l'Europe (delegue titulaire)/ Union de l'Europe occidentale (delegue titulaire)/ 	82002D	TITULAIRE	\N	\N
29	DELCONEUR	\N	1998-10-20 00:00:00	ANCIEN	\N	\N	\N	Conseil de l'Europe (delegue suppleant)/ Union de l'Europe occidentale (delegue suppleant)/ 	92031P	SUPPLEANT	\N	\N
31	DELCONEUR	\N	1998-10-20 00:00:00	ANCIEN	\N	\N	\N	Conseil de l'Europe (delegue titulaire)/ Union de l'Europe occidentale (delegue titulaire)/ 	77029G	TITULAIRE	\N	\N
68	202	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	94003T	MEMBRE	\N	\N
69	202	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'evaluation de la legislation/ Union Europeenne/ 	80017C	MEMBRE	\N	\N
70	202	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	89044U	MEMBRE	\N	\N
71	202	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	89039X	MEMBRE	\N	\N
72	202	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	89007P	MEMBRE	\N	\N
73	202	1979-10-11 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	71017B	MEMBRE	\N	\N
74	202	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	94002S	MEMBRE	\N	\N
75	202	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	80040B	MEMBRE	\N	\N
76	202	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	95007C	MEMBRE	\N	\N
77	202	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ Office parlementaire d'evaluation de la legislation/ 	95006B	MEMBRE	\N	\N
78	202	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	80015A	MEMBRE	\N	\N
79	202	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ Office parlementaire d'evaluation des politiques publiques/ 	92012L	MEMBRE	\N	\N
80	202	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ Office parlementaire d'evaluation des politiques publiques/ 	92022N	MEMBRE	\N	\N
81	202	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Problemes demographiques/ Union  europeenne/ 	92019T	MEMBRE	\N	\N
82	202	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	83043S	MEMBRE	\N	\N
83	202	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	83033Q	MEMBRE	\N	\N
84	202	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	86025D	MEMBRE	\N	\N
85	202	1980-10-31 00:00:00	1998-10-14 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	77009C	MEMBRE	\N	\N
86	202	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	95058P	MEMBRE	\N	\N
87	202	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union europeenne/ 	77046H	MEMBRE	\N	\N
88	202	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	77029G	MEMBRE	\N	\N
89	202	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ Choix scientifiques et technologiques (titulaire)/ 	86047K	MEMBRE	\N	\N
90	202	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	86031B	MEMBRE	\N	\N
91	202	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union europeenne/ 	95030B	MEMBRE	\N	\N
92	202	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union europeenne/ 	95008D	MEMBRE	\N	\N
93	202	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	83003J	MEMBRE	\N	\N
94	202	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	78007E	MEMBRE	\N	\N
95	202	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	88013H	MEMBRE	\N	\N
96	202	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne / 	97009N	MEMBRE	\N	\N
97	202	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	79004F	MEMBRE	\N	\N
1012	DELCONEUR	\N	1998-12-12 00:00:00	ANCIEN	\N	\N	\N	 Conseil de l'Europe (délégué titulaire)/ Union de l'Europe occidentale (délégué titulaire)/	59223E	TITULAIRE	\N	\N
1013	DELCONEUR	1995-09-01 00:00:00	1995-09-30 00:00:00	ANCIEN	\N	\N	\N	 Conseil de l'Europe (délégué )/ Union de l'Europe occidentale (délégué )/	59573A	MEMBRE	\N	2016-06-23 09:52:49
894	210	2001-10-10 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	86034E	MEMBRE	\N	\N
895	210	2001-09-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86041D	MEMBRE	\N	\N
896	210	2001-09-10 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	95055L	MEMBRE	\N	\N
897	210	2001-09-10 00:00:00	2004-10-13 00:00:00	ANCIEN	\N	\N	\N	\N	96006F	MEMBRE	\N	\N
898	210	2001-10-10 00:00:00	2002-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	95059Q	MEMBRE	\N	\N
900	210	2001-09-10 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	MEMBRE	\N	\N
577	205	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	77060F	MEMBRE	\N	\N
902	205	2001-10-10 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	01008M	MEMBRE	\N	\N
903	205	2001-10-10 00:00:00	2008-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	89022N	MEMBRE	\N	\N
904	205	2001-10-10 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	88008L	MEMBRE	\N	\N
905	205	2001-10-10 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	01015L	MEMBRE	\N	\N
906	205	2001-10-10 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	01021J	MEMBRE	\N	\N
907	205	2001-10-10 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	\N	98043U	MEMBRE	\N	\N
909	205	2001-10-10 00:00:00	2007-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	89006N	MEMBRE	\N	\N
910	205	2001-10-10 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	95053J	MEMBRE	\N	\N
911	205	2001-10-10 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	83047W	MEMBRE	\N	\N
912	205	2001-10-10 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	98010K	MEMBRE	\N	\N
913	205	2001-10-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77060F	MEMBRE	\N	\N
914	205	2001-10-10 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	80039J	MEMBRE	\N	\N
915	205	2001-10-10 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	01058X	MEMBRE	\N	\N
595	206	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	96004D	SUPPLEANT	\N	\N
590	206	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	89037V	TITULAIRE	\N	\N
916	206	2001-10-10 00:00:00	2004-10-13 00:00:00	ANCIEN	\N	\N	\N	\N	95025E	MEMBRE	\N	\N
917	206	2001-10-10 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	85003S	TITULAIRE	\N	\N
918	206	2001-10-10 00:00:00	2004-10-13 00:00:00	ANCIEN	\N	\N	\N	\N	92039X	TITULAIRE	\N	\N
921	206	2001-10-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	85002R	MEMBRE	\N	\N
1070	203	\N	2009-06-25 00:00:00	ANCIEN	\N	\N	\N	Problèmes démographiques/	58921V	TITULAIRE	\N	\N
1071	203	\N	2009-06-25 00:00:00	ANCIEN	\N	\N	\N	Problèmes démographiques/	92014N	TITULAIRE	\N	\N
1072	203	\N	1997-06-19 00:00:00	ANCIEN	\N	\N	\N	Union Européenne/ Problèmes démographiques/	92018S	TITULAIRE	\N	\N
1073	203	\N	2009-06-25 00:00:00	ANCIEN	\N	\N	\N	Problèmes démographiques/	58631N	TITULAIRE	\N	\N
1074	203	\N	2006-04-25 00:00:00	ANCIEN	\N	\N	\N	Problèmes démographiques/	58913V	TITULAIRE	\N	\N
1075	203	\N	2002-01-27 00:00:00	ANCIEN	\N	\N	\N	Problèmes démographiques/ Planification/	59548Y	TITULAIRE	\N	\N
1076	205	\N	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	Planification/	79005G	TITULAIRE	\N	\N
1077	205	\N	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	Planification/	000621	TITULAIRE	\N	\N
1079	205	\N	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	Planification/	59232F	TITULAIRE	\N	\N
1080	205	\N	1999-07-22 00:00:00	ANCIEN	\N	\N	\N	Planification/	000630	TITULAIRE	\N	\N
1081	205	\N	2002-01-27 00:00:00	ANCIEN	\N	\N	\N	Problèmes démographiques/ Planification/	59548Y	TITULAIRE	\N	\N
1082	205	\N	2007-05-17 00:00:00	ANCIEN	\N	\N	\N	Planification/	59553V	TITULAIRE	\N	\N
1083	205	\N	2009-02-15 00:00:00	ANCIEN	\N	\N	\N	Planification/	58918B	TITULAIRE	\N	\N
1084	205	\N	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	Planification/	58938F	TITULAIRE	\N	\N
1093	206	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	Choix scientifiques et technologiques/	58939G	TITULAIRE	\N	\N
1095	206	\N	1995-09-30 00:00:00	ANCIEN	\N	\N	\N	Choix scientifiques et technologiques/	000586	MEMBRE	\N	2015-07-01 09:33:35
1096	206	1983-10-20 00:00:00	2014-08-20 00:00:00	ANCIEN	\N	\N	\N	choix scientifiques et technologiques/	58636T	TITULAIRE	\N	\N
1097	206	\N	1986-09-30 00:00:00	ANCIEN	\N	\N	\N	Choix scientifiques et technologiques/	000521	MEMBRE	\N	2015-07-01 09:36:13
1098	206	\N	1996-07-21 00:00:00	ANCIEN	\N	\N	\N	Choix scientifiques et technologiques/	000470	MEMBRE	\N	\N
1099	206	\N	1986-09-30 00:00:00	ANCIEN	\N	\N	\N	Choix scientifiques et technologiques/	58662V	MEMBRE	\N	2015-07-01 09:37:10
1101	207	\N	1997-06-30 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'évaluation des politiques publiques/	95067Q	MEMBRE	\N	\N
1103	206	2003-05-06 00:00:00	2010-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	01017N	MEMBRE	\N	\N
1105	205	2003-10-08 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	01061S	MEMBRE	\N	\N
1107	202	2003-11-20 00:00:00	2004-10-13 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	MEMBRE	\N	\N
1109	205	2004-05-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98013N	MEMBRE	\N	\N
1110	211	2004-05-18 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	04017B	MEMBRE	\N	\N
1111	210	2004-05-18 00:00:00	2004-10-13 00:00:00	ANCIEN	\N	\N	\N	\N	95030B	TITULAIRE	\N	\N
693	CSCE	2001-11-29 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86025D	MEMBRE	\N	\N
1113	205	2004-10-13 00:00:00	2008-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	03001N	MEMBRE	\N	\N
1114	205	2004-10-13 00:00:00	2008-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	98010K	MEMBRE	\N	\N
1115	205	2004-10-13 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89040Q	MEMBRE	\N	\N
1117	211	2004-10-13 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	04087R	MEMBRE	\N	\N
1118	211	2004-10-13 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04059M	MEMBRE	\N	\N
1119	211	2004-10-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04052E	MEMBRE	\N	\N
1121	211	2004-10-13 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	MEMBRE	\N	\N
1122	211	2004-10-13 00:00:00	2008-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	04081K	MEMBRE	\N	\N
1126	202	2004-10-13 00:00:00	2006-11-09 00:00:00	ANCIEN	\N	\N	\N	\N	04052E	MEMBRE	\N	\N
1127	202	2004-10-13 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	01051Q	MEMBRE	\N	\N
1129	202	2004-10-13 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	04063H	MEMBRE	\N	\N
1130	211	2004-10-13 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	MEMBRE	\N	\N
1133	211	2004-10-13 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01033N	MEMBRE	\N	\N
1134	211	2004-10-13 00:00:00	2012-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	04041B	MEMBRE	\N	\N
1135	202	2004-10-13 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	01063U	MEMBRE	\N	\N
1136	211	2004-10-13 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04036E	MEMBRE	\N	\N
1137	202	2004-10-13 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	\N	95028H	MEMBRE	\N	\N
1138	211	2004-10-13 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	04077P	MEMBRE	\N	\N
1139	202	2004-10-13 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	78003A	MEMBRE	\N	\N
1140	211	2004-10-13 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	MEMBRE	\N	\N
1141	202	2004-10-13 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	04075M	MEMBRE	\N	\N
1142	202	2004-10-13 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	04061F	MEMBRE	\N	\N
1143	211	2004-10-13 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	\N	77044F	MEMBRE	\N	\N
1144	202	2004-10-13 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	98038X	MEMBRE	\N	\N
1146	202	2004-10-13 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	04057K	MEMBRE	\N	\N
1147	211	2004-10-13 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	04043D	MEMBRE	\N	\N
1148	202	2004-10-13 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	01054T	MEMBRE	\N	\N
1149	211	2004-10-13 00:00:00	2010-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	04069P	MEMBRE	\N	\N
1150	202	2004-10-13 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	04080J	MEMBRE	\N	\N
1151	211	2004-10-13 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	MEMBRE	\N	\N
1153	211	2004-10-13 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89042S	MEMBRE	\N	\N
1154	202	2004-10-13 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	04056J	MEMBRE	\N	\N
1156	210	2004-10-13 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	04087R	MEMBRE	\N	\N
1157	210	2004-10-13 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	01049W	MEMBRE	\N	\N
1158	210	2004-10-13 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	98032R	MEMBRE	\N	\N
1159	206	2004-10-13 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	96008H	MEMBRE	\N	\N
1160	206	2004-10-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92011K	MEMBRE	\N	\N
1161	206	2004-10-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	02003L	MEMBRE	\N	\N
1162	206	2004-10-13 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80013X	MEMBRE	\N	\N
1163	206	2004-10-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	97004H	MEMBRE	\N	\N
1165	206	2004-10-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04043D	MEMBRE	\N	2017-10-18 16:31:17
1168	206	2004-10-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	MEMBRE	\N	\N
1169	DELCONEUR	2004-10-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95007C	TITULAIRE	\N	\N
1171	DELCONEUR	2004-10-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04080J	SUPPLEANT	\N	\N
1172	208	2004-10-20 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	03002P	MEMBREDRTCOM	\N	\N
1177	208	2004-10-20 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	MEMBREGRPPOL	\N	\N
1178	208	2004-10-20 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	04052E	MEMBREGRPPOL	\N	\N
1180	208	2004-10-20 00:00:00	2008-09-07 00:00:00	ANCIEN	\N	\N	\N	\N	80017C	MEMBREGRPPOL	\N	\N
1181	208	2004-10-20 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	04083M	MEMBREGRPPOL	\N	\N
1182	208	2004-10-20 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	95055L	MEMBREGRPPOL	\N	\N
1184	SANTE	2004-10-20 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	98029W	MEMBREGRPPOL	\N	\N
1186	SANTE	2004-10-20 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	01011G	MEMBREGRPPOL	\N	\N
1188	SANTE	2004-10-20 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	MEMBREGRPPOL	\N	\N
1189	206	2004-12-02 00:00:00	2006-03-07 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	MEMBRE	\N	\N
1191	ODD	2005-01-19 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80035E	MEMBRE	\N	\N
1192	ODD	2005-01-19 00:00:00	2009-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	95021A	MEMBRE	\N	\N
1193	ODD	2005-01-19 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80015A	MEMBRE	\N	\N
1194	ODD	2005-01-19 00:00:00	2007-06-24 00:00:00	ANCIEN	\N	\N	\N	\N	99004R	MEMBRE	\N	\N
1196	ODD	2005-01-19 00:00:00	2009-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	83011J	MEMBRE	\N	\N
1197	ODD	2005-01-19 00:00:00	2009-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	89022N	MEMBRE	\N	\N
1198	ODD	2005-01-19 00:00:00	2009-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	MEMBRE	\N	\N
1199	ODD	2005-01-19 00:00:00	2009-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	95020Y	MEMBRE	\N	\N
1200	ODD	2005-01-19 00:00:00	2009-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	MEMBRE	\N	\N
1202	ODD	2005-01-19 00:00:00	2009-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	83033Q	MEMBRE	\N	\N
1205	ODD	2005-01-19 00:00:00	2009-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	86044G	MEMBRE	\N	\N
1206	ODD	2005-01-19 00:00:00	2009-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	01019Q	MEMBRE	\N	\N
2376	208	2004-10-20 00:00:00	2007-02-25 00:00:00	ANCIEN	\N	\N	\N	\N	92024Q	MEMBREDRTCOM	\N	\N
2377	208	2004-10-20 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	MEMBREDRTCOM	\N	\N
2375	208	2004-10-20 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	87003B	MEMBREDRTCOM	\N	\N
2379	CSCE	\N	2009-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	83050R	MEMBRE	\N	\N
2380	CSCE	2009-01-14 00:00:00	2012-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	01062T	MEMBRE	\N	\N
2381	CSCE	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98016R	MEMBRE	\N	\N
854	211	2001-10-10 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	00003C	MEMBRE	\N	\N
746	211	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	95045J	MEMBRE	\N	\N
679	DELCONEUR	1998-10-20 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	92012L	SUPPLEANT	\N	\N
726	211	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	95014B	MEMBRE	\N	\N
640	207	1998-10-21 00:00:00	2000-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	89019T	MEMBRE	\N	\N
560	202	1998-10-14 00:00:00	1999-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	80040B	MEMBRE	\N	\N
956	208	2001-10-24 00:00:00	2004-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	95006B	MEMBRE	\N	\N
920	206	2001-10-10 00:00:00	2004-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	96006F	MEMBRE	\N	\N
1132	202	2004-10-13 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98048A	MEMBRE	\N	\N
1166	206	2004-10-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01058X	MEMBRE	\N	2017-10-18 16:31:21
1173	208	2004-10-20 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	95035G	MEMBREDRTCOM	\N	\N
2544	SFAPF	\N	2004-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	86037H	MEMBRE	\N	\N
2545	SFAPF	\N	2011-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre du bureau de la section française de l'Assemblée Parlementaire de la Francophonie	Membre du bureau de la section française de l'Assemblée Parlementaire de la Francophonie	92033R	MEMBRE	\N	\N
2546	SFAPF	\N	2014-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	77043E	MEMBRE	\N	2014-09-28 16:59:41
2547	SFAPF	\N	2015-01-08 00:00:00	ANCIEN	\N	Secrét de la section française de l'Assemblée Parlementaire 	Secrétaire général de la section française de l'Assemblée Parlementaire de la Francophonie	Secrétaire général de la section française de l'Assemblée Parlementaire de la Francophonie	92035T	MEMBRE	\N	2015-01-08 17:14:29
2548	SFAPF	\N	2013-12-31 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	95003X	MEMBRE	\N	\N
2549	SFAPF	\N	2004-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	77047J	MEMBRE	\N	\N
2550	SFAPF	\N	2011-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	92037V	MEMBRE	\N	\N
2551	SFAPF	\N	2008-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	80031A	MEMBRE	\N	\N
3469	206	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11036J	MEMBRE	\N	\N
2533	SFAPF	\N	2008-04-18 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre du bureau de la section française de l'Assemblée Parlementaire de la Francophonie	Membre du bureau de la section française de l'Assemblée Parlementaire de la Francophonie	95031C	MEMBRE	\N	\N
963	203	2001-10-10 00:00:00	2009-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	01029S	MEMBRE	\N	\N
964	211	2002-02-19 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92008Q	MEMBRE	\N	\N
965	211	2002-02-19 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	MEMBRE	\N	\N
968	CSCE	2001-11-29 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	92022N	MEMBRE	\N	\N
969	CSCE	2001-11-29 00:00:00	2012-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	98021N	MEMBRE	\N	\N
994	SANTE	2003-01-21 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	MEMBREGRPPOL	\N	\N
973	206	2002-07-04 00:00:00	2004-10-13 00:00:00	ANCIEN	\N	\N	\N	\N	89041R	MEMBRE	\N	\N
974	206	2002-07-04 00:00:00	2004-10-13 00:00:00	ANCIEN	\N	\N	\N	\N	98017S	MEMBRE	\N	\N
992	202	2002-10-16 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	02001J	MEMBRE	\N	\N
978	206	2002-07-04 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	01044R	MEMBRE	\N	\N
979	206	2002-07-04 00:00:00	2003-05-06 00:00:00	ANCIEN	\N	\N	\N	\N	01006K	MEMBRE	\N	\N
983	211	2002-07-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	02003L	MEMBRE	\N	\N
985	202	2002-07-04 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	90003B	MEMBRE	\N	\N
995	SANTE	2003-01-21 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95017E	MEMBRE	\N	\N
996	SANTE	2003-01-21 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	98024R	MEMBREGRPPOL	\N	\N
997	SANTE	2003-01-21 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	MEMBREGRPPOL	\N	\N
998	SANTE	2003-01-21 00:00:00	2004-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	98017S	MEMBRE	\N	\N
999	SANTE	2003-01-21 00:00:00	2004-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	78006D	MEMBRE	\N	\N
1000	SANTE	2003-01-21 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95045J	MEMBRE	\N	\N
1001	SANTE	2003-01-21 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98015Q	MEMBREGRPPOL	\N	\N
1002	SANTE	2003-01-21 00:00:00	2004-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	01034P	MEMBRE	\N	\N
1003	SANTE	2003-01-21 00:00:00	2004-10-20 00:00:00	ANCIEN	\N	\N	\N	\N	01023L	MEMBRE	\N	\N
1011	DELCONEUR	\N	1986-12-18 00:00:00	ANCIEN	\N	\N	\N	 Conseil de l'Europe (délégué titulaire)/ Union de l'Europe occidentale (délégué titulaire)/ Secrétaire du groupe des sénateurs-maires/	000353	TITULAIRE	\N	2015-10-08 16:11:30
863	211	2001-10-10 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	01025N	MEMBRE	\N	\N
864	211	2001-10-10 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	98019U	MEMBRE	\N	\N
865	211	2001-10-10 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	94003T	MEMBRE	\N	\N
866	211	2001-10-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01055U	MEMBRE	\N	\N
867	211	2001-10-10 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	MEMBRE	\N	\N
868	211	2001-10-10 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	98017S	MEMBRE	\N	\N
869	211	2001-10-10 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	95035G	MEMBRE	\N	\N
870	211	2001-10-10 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	01033N	MEMBRE	\N	\N
871	211	2001-10-10 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	97004H	MEMBRE	\N	\N
872	211	2001-10-10 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	98025S	MEMBRE	\N	\N
873	211	2001-10-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01043Q	MEMBRE	\N	2017-10-18 16:17:30
874	211	2001-10-10 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	77044F	MEMBRE	\N	\N
875	211	2001-10-10 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	01038T	MEMBRE	\N	\N
876	211	2001-10-10 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	92040Q	MEMBRE	\N	\N
877	211	2001-10-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01009N	MEMBRE	\N	\N
878	211	2001-10-10 00:00:00	2002-02-01 00:00:00	ANCIEN	\N	\N	\N	\N	98015Q	MEMBRE	\N	\N
880	211	2001-10-10 00:00:00	2014-09-01 00:00:00	ANCIEN	\N	\N	\N	\N	96007G	MEMBRE	\N	2014-09-01 10:21:13
881	211	2001-10-10 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01029S	MEMBRE	\N	\N
882	211	2001-10-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	97005J	MEMBRE	\N	\N
883	211	2001-10-10 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	01056V	MEMBRE	\N	2017-02-20 10:15:49
884	211	2001-10-10 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	89042S	MEMBRE	\N	\N
885	202	2001-10-10 00:00:00	2004-10-13 00:00:00	ANCIEN	\N	\N	\N	\N	92018S	MEMBRE	\N	\N
710	210	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	98049B	MEMBRE	\N	\N
717	210	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	95055L	MEMBRE	\N	\N
889	210	2001-10-10 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	01015L	MEMBRE	\N	\N
890	210	2001-10-10 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	83033Q	MEMBRE	\N	\N
892	210	2001-10-10 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89030N	MEMBRE	\N	\N
893	210	2001-10-10 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	01030K	MEMBRE	\N	\N
923	206	2001-10-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86047K	TITULAIRE	\N	\N
924	206	2001-10-10 00:00:00	2004-10-13 00:00:00	ANCIEN	\N	\N	\N	\N	80046H	MEMBRE	\N	\N
925	206	2001-10-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95045J	MEMBRE	\N	\N
926	206	2001-10-10 00:00:00	2002-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	78003A	SUPPLEANT	\N	\N
766	208	2000-05-03 00:00:00	2001-10-24 00:00:00	ANCIEN	\N	\N	\N	\N	98016R	TITULAIRE	\N	\N
767	205	2000-06-14 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	00004D	MEMBRE	\N	\N
768	205	2000-10-17 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	98036V	MEMBRE	\N	\N
769	202	2000-10-25 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	89045V	MEMBRE	\N	\N
770	211	2000-10-25 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	00004D	MEMBRE	\N	\N
801	202	2001-10-10 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	97009N	MEMBRE	\N	\N
802	202	2001-10-10 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	95006B	MEMBRE	\N	\N
803	202	2001-10-10 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	95007C	MEMBRE	\N	\N
804	202	2001-10-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86011W	MEMBRE	\N	\N
807	202	2001-10-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	78007E	MEMBRE	\N	\N
808	202	2001-10-10 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	96004D	MEMBRE	\N	\N
809	202	2001-10-10 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	01005J	MEMBRE	\N	\N
810	202	2001-10-10 00:00:00	2004-10-13 00:00:00	ANCIEN	\N	\N	\N	\N	71003U	MEMBRE	\N	\N
811	202	2001-10-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95017E	MEMBRE	\N	\N
812	202	2001-10-10 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	98031Q	MEMBRE	\N	\N
813	202	2001-10-10 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	98018T	MEMBRE	\N	\N
816	202	2001-10-10 00:00:00	2004-10-13 00:00:00	ANCIEN	\N	\N	\N	\N	98042T	MEMBRE	\N	\N
817	202	2001-10-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	90002A	MEMBRE	\N	\N
818	202	2001-10-10 00:00:00	2004-10-13 00:00:00	ANCIEN	\N	\N	\N	\N	89027T	MEMBRE	\N	\N
819	202	2001-10-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86025D	MEMBRE	\N	\N
820	202	2001-10-10 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	92022N	MEMBRE	\N	\N
821	202	2001-10-10 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	98019U	MEMBRE	\N	\N
823	202	2001-10-10 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	83033Q	MEMBRE	\N	\N
824	202	2001-10-10 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	94003T	MEMBRE	\N	\N
825	202	1999-10-10 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	86030A	MEMBRE	\N	\N
826	202	2001-10-10 00:00:00	2003-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	86031B	MEMBRE	\N	\N
827	202	2001-10-10 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	97004H	MEMBRE	\N	\N
828	202	2001-10-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	88013H	MEMBRE	\N	\N
829	202	2001-10-10 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98051U	MEMBRE	\N	\N
830	202	2001-10-10 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	98032R	MEMBRE	\N	\N
832	202	2001-10-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86041D	MEMBRE	\N	\N
833	202	2001-10-10 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	98035U	MEMBRE	\N	\N
834	202	2001-10-10 00:00:00	2004-10-13 00:00:00	ANCIEN	\N	\N	\N	\N	01034P	MEMBRE	\N	\N
835	202	2001-10-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86050E	MEMBRE	\N	\N
836	202	2001-10-10 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	89045V	MEMBRE	\N	\N
837	202	2001-10-10 00:00:00	2004-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	96003C	MEMBRE	\N	\N
615	203	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	95015C	MEMBRE	\N	\N
621	203	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	98017S	MEMBRE	\N	\N
838	203	2001-10-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95014B	MEMBRE	\N	\N
839	203	2001-10-10 00:00:00	2009-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	95015C	MEMBRE	\N	\N
841	203	2001-10-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77013X	MEMBRE	\N	\N
842	203	2001-10-10 00:00:00	2009-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	98030P	MEMBRE	\N	\N
846	203	2001-10-10 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89042S	MEMBRE	\N	\N
847	203	2001-10-10 00:00:00	2004-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	96003C	MEMBRE	\N	\N
848	211	2001-10-10 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	89019T	MEMBRE	\N	\N
623	203	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	96003C	MEMBRE	\N	\N
850	211	2001-10-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95014B	MEMBRE	\N	\N
851	211	2001-10-10 00:00:00	2001-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	88004G	MEMBRE	\N	\N
852	211	2001-10-10 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98014P	MEMBRE	\N	\N
855	211	2001-10-10 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	95019G	MEMBRE	\N	\N
856	211	2001-10-10 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98023Q	MEMBRE	\N	\N
857	211	2001-10-10 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	98031Q	MEMBRE	\N	\N
858	211	2001-10-10 00:00:00	2004-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	98018T	MEMBRE	\N	\N
859	211	2001-10-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01045S	MEMBRE	\N	\N
1015	DELCONEUR	\N	2008-05-22 00:00:00	ANCIEN	\N	\N	\N	 Conseil de l'Europe (délégué suppléant)/ Union de l'Europe occidentale (délégué suppléant)/	80022Y	SUPPLEANT	\N	\N
1017	DELCONEUR	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	 Conseil de l'Europe (délégué titulaire)/ Union de l'Europe occidentale ((délégué titulaire)/	000502	TITULAIRE	\N	2015-10-08 16:13:13
1018	DELCONEUR	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	 Conseil de l'Europe (délégué suppléant)/ Union de l'Europe occidentale (délégué suppléant)/	000337	SUPPLEANT	\N	2015-10-08 16:19:10
1019	DELCONEUR	\N	1992-03-20 00:00:00	ANCIEN	\N	\N	\N	 Conseil de l'Europe (délégué titulaire)/ Union de l'Europe occidentale (délégué titulaire)/	000476	TITULAIRE	\N	2015-10-08 16:15:31
1020	DELCONEUR	\N	2009-06-12 00:00:00	ANCIEN	\N	\N	\N	 Conseil de l'Europe (délégué titulaire)/ Union de l'Europe occidentale (délégué titulaire)/	58917A	TITULAIRE	\N	\N
1021	DELCONEUR	\N	2011-06-18 00:00:00	ANCIEN	\N	\N	\N	 Conseil de l'Europe (délégué suppléant)/ Union de l'Europe occidentale (délégué suppléant)/	59558B	SUPPLEANT	\N	\N
1022	DELCONEUR	\N	2001-01-26 00:00:00	ANCIEN	\N	\N	\N	 Conseil de l'Europe (délégué suppléant)/ Union de l'Europe occidentale (délégué suppléant)/	58928D	SUPPLEANT	\N	\N
1023	DELCONEUR	\N	2005-05-16 00:00:00	ANCIEN	\N	\N	\N	 Haute Cour de justice (juge titulaire)/ Conseil de l'Europe (délégué titulaire)/ Union de l'Europe occidentale (délégué titulaire)/	59248P	TITULAIRE	\N	\N
1044	202	\N	2005-09-22 00:00:00	ANCIEN	\N	\N	\N	Union Européenne/	59215E	TITULAIRE	\N	\N
1045	202	\N	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	Union Européenne/	000663	TITULAIRE	\N	\N
1046	202	\N	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	Union Européenne/	000353	TITULAIRE	\N	\N
3013	COLTER	2009-09-23 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	07003H	MEMBRE	\N	\N
3014	COLTER	2009-09-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95013A	MEMBRE	\N	\N
3015	COLTER	2009-09-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08020N	MEMBRE	\N	2014-09-28 17:03:42
3016	COLTER	2009-09-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	MEMBRE	\N	\N
3017	COLTER	2009-09-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95020Y	MEMBRE	\N	\N
3018	COLTER	2009-09-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	MEMBRE	\N	\N
3019	COLTER	2009-09-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01027Q	MEMBRE	\N	\N
3020	COLTER	2009-09-23 00:00:00	2013-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	95038K	MEMBRE	\N	2013-10-15 10:34:34
3021	COLTER	2009-09-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98027U	MEMBRE	\N	\N
3022	COLTER	2009-09-23 00:00:00	2010-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	92029V	MEMBRE	\N	\N
3023	COLTER	2009-09-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08010L	MEMBRE	\N	\N
3024	COLTER	2009-09-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77043E	MEMBRE	\N	2014-09-28 16:59:41
3025	COLTER	2009-09-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	05012A	MEMBRE	\N	\N
3026	COLTER	2009-09-23 00:00:00	2013-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	08036W	MEMBRE	\N	\N
3027	COLTER	2009-09-23 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	99002P	MEMBRE	\N	\N
3028	COLTER	2009-09-23 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	MEMBRE	\N	\N
3029	COLTER	2009-09-23 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	MEMBRE	\N	\N
3030	COLTER	2009-09-23 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	08016S	MEMBRE	\N	\N
3031	COLTER	2009-09-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08027V	MEMBRE	\N	2014-09-28 17:34:16
3032	COLTER	2009-09-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08067E	MEMBRE	\N	2014-09-28 17:22:11
3033	COLTER	2009-09-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	03001N	MEMBRE	\N	2014-09-28 13:40:33
3034	COLTER	2009-09-23 00:00:00	2009-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	97004H	MEMBRE	\N	\N
3035	COLTER	2009-09-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08033T	MEMBRE	\N	2014-09-28 17:27:35
3036	COLTER	2009-09-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95055L	MEMBRE	\N	2014-09-28 13:21:47
3037	COLTER	2009-09-23 00:00:00	2014-05-02 00:00:00	ANCIEN	\N	\N	\N	\N	08070Y	MEMBRE	\N	2014-05-05 10:59:42
3038	COLTER	2009-09-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04082L	MEMBRE	\N	\N
3039	COLTER	2009-09-23 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	01024M	MEMBRE	\N	\N
3040	COLTER	2009-09-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01007L	MEMBRE	\N	\N
3041	COLTER	2009-09-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08009T	MEMBRE	\N	\N
3042	COLTER	2009-09-23 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	01013J	MEMBRE	\N	\N
3043	COLTER	2009-09-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04039H	MEMBRE	\N	\N
3044	COLTER	2009-09-23 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	86010V	MEMBRE	\N	\N
3045	COLTER	2009-09-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	MEMBRE	\N	\N
3046	COLTER	2009-09-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04033B	MEMBRE	\N	\N
3047	COLTER	2009-09-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01058X	MEMBRE	\N	\N
3048	PROS	2009-09-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89022N	MEMBRE	\N	2014-09-28 18:19:47
3049	PROS	2009-09-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98036V	MEMBRE	\N	2014-09-28 17:15:42
3050	PROS	2009-09-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	97009N	MEMBRE	\N	\N
3051	PROS	2009-09-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01015L	MEMBRE	\N	\N
3052	PROS	2009-09-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01021J	MEMBRE	\N	\N
3053	PROS	2009-09-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	88008L	MEMBRE	\N	\N
2709	DELCONEUR	2007-07-31 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01001E	MEMBRE	\N	\N
2710	DELCONEUR	2007-07-31 00:00:00	2008-10-28 00:00:00	ANCIEN	\N	\N	\N	\N	04065K	MEMBRE	\N	\N
3054	PROS	2009-09-23 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	08056B	MEMBRE	\N	2017-10-19 18:17:13
3055	PROS	2009-09-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04087R	MEMBRE	\N	2014-09-28 13:39:21
3056	PROS	2009-09-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01008M	MEMBRE	\N	\N
3057	PROS	2009-09-23 00:00:00	2012-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	08050U	MEMBRE	\N	\N
3058	PROS	2009-09-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08045X	MEMBRE	\N	2017-10-18 16:02:09
3059	PROS	2009-09-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01061S	MEMBRE	\N	\N
3060	PROS	2009-09-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08012N	MEMBRE	\N	2017-10-18 16:03:13
3061	PROS	2009-09-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08062Y	MEMBRE	\N	2017-10-18 16:00:02
3062	PROS	2009-09-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08047A	MEMBRE	\N	\N
3063	PROS	2009-09-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	90003B	MEMBRE	\N	\N
3064	PROS	2009-09-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08028W	MEMBRE	\N	\N
3065	PROS	2009-09-23 00:00:00	2010-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	01026P	MEMBRE	\N	\N
3066	PROS	2009-09-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04075M	MEMBRE	\N	\N
3067	PROS	2009-09-23 00:00:00	2019-06-23 00:00:00	ANCIEN	\N	\N	\N	\N	04061F	MEMBRE	\N	2017-10-18 15:59:29
3068	PROS	2009-09-23 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	MEMBRE	\N	\N
3069	PROS	2009-09-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	82002D	MEMBRE	\N	\N
3070	PROS	2009-09-23 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	\N	01039U	MEMBRE	\N	\N
3071	PROS	2009-09-23 00:00:00	2012-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	09011R	MEMBRE	\N	\N
3072	PROS	2009-09-23 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	08060W	MEMBRE	\N	\N
3073	PROS	2009-09-23 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	04066L	MEMBRE	\N	\N
3074	PROS	2009-09-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08038Y	MEMBRE	\N	\N
3075	PROS	2009-09-23 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	92039X	MEMBRE	\N	\N
3076	PROS	2009-09-23 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	MEMBRE	\N	\N
3077	PROS	2009-09-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	MEMBRE	\N	2017-10-18 16:03:45
3078	PROS	2009-09-23 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	04045F	MEMBRE	\N	\N
3079	PROS	2009-09-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95007C	MEMBRE	\N	\N
3080	PROS	2009-09-23 00:00:00	2010-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	01017N	MEMBRE	\N	\N
3081	PROS	2009-09-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	97005J	MEMBRE	\N	\N
3082	PROS	2009-09-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	02053W	MEMBRE	\N	2014-09-28 12:32:23
3083	PROS	2009-09-23 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	95021A	MEMBRE	\N	\N
1170	DELCONEUR	2004-10-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04040A	SUPPLEANT	\N	\N
2909	OTAN	2008-11-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83050R	MEMBRE	\N	\N
806	202	2001-10-10 00:00:00	2002-10-15 00:00:00	ANCIEN	\N	\N	\N	\N	89019T	MEMBRE	\N	\N
822	202	2001-10-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83003J	MEMBRE	\N	\N
831	202	2001-10-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	91002E	MEMBRE	\N	\N
843	203	2001-10-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95033E	MEMBRE	\N	\N
756	211	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	96007G	MEMBRE	\N	\N
736	211	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	80017C	MEMBRE	\N	\N
748	211	1999-10-13 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83040P	MEMBRE	\N	\N
658	208	1998-10-21 00:00:00	2001-10-24 00:00:00	ANCIEN	\N	\N	\N	\N	80046H	TITULAIRE	\N	\N
675	DELCONEUR	1998-10-20 00:00:00	2001-10-23 00:00:00	ANCIEN	\N	\N	\N	\N	95004Y	TITULAIRE	\N	\N
684	DELCONEUR	1998-10-20 00:00:00	2001-10-23 00:00:00	ANCIEN	\N	\N	\N	\N	80017C	SUPPLEANT	\N	\N
714	210	1999-10-13 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	86034E	MEMBRE	\N	\N
730	211	1999-10-13 00:00:00	2001-06-04 00:00:00	ANCIEN	\N	\N	\N	\N	83020K	MEMBRE	\N	\N
614	203	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	95014B	MEMBRE	\N	\N
520	202	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	71003U	MEMBRE	\N	\N
529	202	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	77019E	MEMBRE	\N	\N
550	202	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	79004F	MEMBRE	\N	\N
944	DELCONEUR	2001-10-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95036H	TITULAIRE	\N	2014-09-28 17:31:42
981	210	2002-07-04 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	02002K	MEMBRE	\N	\N
1005	SANTE	2003-01-21 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	Président de la Commission des Affaires sociales	\N	95004Y	MEMBREDRT	\N	\N
879	211	2001-10-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95058P	MEMBRE	\N	\N
908	205	2001-10-10 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	98025S	MEMBRE	\N	\N
1078	205	\N	2009-05-09 00:00:00	ANCIEN	\N	\N	\N	Planification/	58420D	TITULAIRE	\N	\N
1100	206	\N	1995-09-30 00:00:00	ANCIEN	\N	\N	\N	Choix scientifiques et technologiques/	59582B	MEMBRE	\N	2015-07-01 09:38:23
1108	205	2004-05-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98047Y	MEMBRE	\N	\N
1123	202	2004-10-13 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	86010V	MEMBRE	\N	\N
1155	202	2004-10-13 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	92044U	MEMBRE	\N	\N
1174	208	2004-10-20 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	94003T	MEMBREDRTCOM	\N	\N
151	206	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Choix scientifiques et technologiques (suppleant)/ 	88004G	SUPPLEANT	\N	\N
112	203	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Problemes demographiques/ 	95015C	MEMBRE	\N	\N
147	206	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Choix scientifiques et technologiques (suppleant)/ Office parlementaire d'evaluation de la legislation/ 	80046H	SUPPLEANT	\N	\N
887	210	2001-09-10 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89010J	MEMBRE	\N	\N
888	210	2001-09-10 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98049B	MEMBRE	\N	\N
1120	211	2004-10-13 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98049B	MEMBRE	\N	\N
853	211	2001-10-10 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89023P	MEMBRE	\N	\N
844	203	2001-10-10 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98017S	MEMBRE	\N	\N
922	206	2001-10-10 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89037V	MEMBRE	\N	\N
899	210	2001-10-10 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89040Q	MEMBRE	\N	\N
1024	DELCONEUR	\N	1999-07-13 00:00:00	ANCIEN	\N	\N	\N	 Conseil de l'Europe (délégué titulaire)/ Union de l'Europe occidentale (délégué titulaire)/	58647W	TITULAIRE	\N	\N
2888	DELCONEUR	2008-10-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01055U	MEMBRE	\N	\N
2890	DELCONEUR	2008-10-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08043V	MEMBRE	\N	\N
2891	DELCONEUR	2008-10-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	97011G	MEMBRE	\N	\N
2892	DELCONEUR	2008-10-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01037S	SUPPLEANT	\N	\N
2686	SFAPF	\N	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	77002U	MEMBRE	\N	2015-02-13 16:06:15
2687	SFAPF	\N	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	MEMBRE	\N	2015-02-13 16:06:37
1131	202	2004-10-13 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98016R	MEMBRE	\N	\N
815	202	2001-10-10 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	95025E	MEMBRE	\N	\N
1152	202	2004-10-13 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	04065K	MEMBRE	\N	\N
1050	202	\N	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	Union Européenne/	59575C	TITULAIRE	\N	\N
3288	SFAPF	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98010K	MEMBRE	\N	2014-09-28 17:27:35
3289	SFAPF	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04064J	MEMBRE	\N	\N
3290	SFAPF	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01006K	MEMBRE	\N	\N
3291	SFAPF	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89015P	MEMBRE	\N	2014-09-28 16:50:17
3293	SFAPF	2015-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04054G	MEMBRE	\N	2017-09-24 17:18:03
3294	SFAPF	\N	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	MEMBRE	\N	2015-02-13 16:06:19
3295	SFAPF	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	90004C	MEMBRE	\N	2014-09-28 13:21:47
3296	SFAPF	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	97004H	MEMBRE	\N	\N
3297	SFAPF	\N	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	04094Q	MEMBRE	\N	2015-02-13 16:06:31
3300	SFAPF	\N	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	04070G	MEMBRE	\N	2015-02-13 16:06:34
3301	SFAPF	\N	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	08073C	MEMBRE	\N	2015-02-13 16:06:35
3302	SFAPF	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	96006F	MEMBRE	\N	2014-09-28 16:50:17
3303	SFAPF	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04052E	MEMBRE	\N	\N
3304	SFAPF	\N	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	95015C	MEMBRE	\N	2015-02-13 16:06:16
3305	SFAPF	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	02053W	MEMBRE	\N	2014-09-28 12:32:23
3306	SFAPF	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89007P	MEMBRE	\N	2014-09-28 16:42:05
3307	SFAPF	\N	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	MEMBRE	\N	2015-02-13 16:06:22
3308	SFAPF	\N	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	08018U	MEMBRE	\N	2015-02-13 16:06:24
3309	SFAPF	\N	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	01037S	MEMBRE	\N	2015-02-13 16:06:24
3310	SFAPF	\N	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	08039A	MEMBRE	\N	2015-02-13 16:06:33
3311	SFAPF	\N	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	95062K	MEMBRE	\N	2015-02-13 16:06:37
2552	SFAPF	\N	2004-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	86041D	MEMBRE	\N	\N
2553	UIP	\N	2011-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	01054T	MEMBRE	\N	\N
2554	SFAPF	\N	2015-02-12 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	95053J	MEMBRE	\N	2015-02-13 16:06:36
2555	SFAPF	\N	2007-09-03 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	66002K	MEMBRE	\N	\N
2556	SFAPF	\N	2004-09-30 00:00:00	ANCIEN	\N	VP dél de la section française de l'Assemblée Parlementaire 	Vice président délégué de la section française de l'Assemblée Parlementaire de la Francophonie	Vice président délégué de la section française de l'Assemblée Parlementaire de la Francophonie	86042E	MEMBRE	\N	\N
2557	SFAPF	\N	2004-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	95057N	MEMBRE	\N	\N
3470	206	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11068S	MEMBRE	\N	\N
3471	206	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11029K	MEMBRE	\N	\N
3472	206	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92018S	MEMBRE	\N	\N
3473	206	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	09001P	MEMBRE	\N	\N
3474	206	2011-11-30 00:00:00	2018-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	04061F	MEMBRE	\N	2017-10-18 16:30:49
3475	206	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08032S	MEMBRE	\N	2014-09-28 17:34:16
3476	206	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08039A	MEMBRE	\N	\N
3477	206	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11100Y	MEMBRE	\N	\N
3478	206	2011-11-30 00:00:00	2013-02-26 00:00:00	ANCIEN	\N	\N	\N	\N	92039X	MEMBRE	\N	\N
3479	206	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11082Q	MEMBRE	\N	\N
3483	211	2011-11-30 00:00:00	2012-01-31 00:00:00	ANCIEN	\N	\N	\N	\N	11033F	MEMBRE	\N	\N
3484	PROS	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11060J	MEMBRE	\N	\N
3485	PROS	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11101A	MEMBRE	\N	\N
3486	211	2011-11-30 00:00:00	2014-08-26 00:00:00	ANCIEN	\N	\N	\N	\N	11018G	MEMBRE	\N	2014-08-27 16:33:37
3487	PROS	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11053K	MEMBRE	\N	\N
3488	PROS	2011-11-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11056N	MEMBRE	\N	2017-10-18 16:08:03
3489	211	2011-11-30 00:00:00	2014-10-28 00:00:00	ANCIEN	\N	\N	\N	\N	11044J	MEMBRE	\N	2014-11-03 09:53:41
3490	PROS	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04067M	MEMBRE	\N	\N
3491	211	2011-11-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11031D	MEMBRE	\N	2017-10-18 16:19:30
3492	PROS	2011-11-30 00:00:00	2013-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	11051H	MEMBRE	\N	\N
3493	211	2011-11-30 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	11027H	MEMBRE	\N	\N
3495	211	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98023Q	MEMBRE	\N	\N
3496	PROS	2011-11-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	02002K	MEMBRE	\N	2017-10-18 16:08:22
3497	211	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04046G	MEMBRE	\N	2014-09-28 17:07:41
3498	PROS	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08035V	MEMBRE	\N	\N
3499	211	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04089T	MEMBRE	\N	\N
3500	PROS	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10003H	MEMBRE	\N	2014-09-28 17:38:26
3501	211	2011-11-30 00:00:00	2014-07-01 00:00:00	ANCIEN	\N	\N	\N	\N	11022C	MEMBRE	\N	2014-07-01 09:29:53
3503	211	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	02002K	MEMBRE	\N	\N
3505	211	2011-11-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04035D	MEMBRE	\N	2017-10-18 16:13:04
3506	PROS	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98032R	MEMBRE	\N	\N
3508	PROS	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08021P	MEMBRE	\N	\N
3507	211	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11061K	MEMBRE	\N	\N
3509	PROS	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98010K	MEMBRE	\N	2014-09-28 17:27:35
3510	PROS	2011-11-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11066Q	MEMBRE	\N	2017-10-18 16:03:59
3511	PROS	2011-11-30 00:00:00	2013-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	08036W	MEMBRE	\N	\N
3516	211	2011-11-30 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	07026Q	MEMBRE	\N	\N
3515	211	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01011G	MEMBRE	\N	\N
3517	211	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	MEMBRE	\N	\N
3518	211	2011-11-30 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	09001P	MEMBRE	\N	\N
3519	211	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01043Q	MEMBRE	\N	\N
3520	211	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11067R	MEMBRE	\N	\N
3521	211	2011-11-30 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	11014C	MEMBRE	\N	\N
3523	211	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11090Q	MEMBRE	\N	\N
3524	COLTER	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08072B	MEMBRE	\N	2014-09-29 09:05:47
3525	COLTER	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89013M	MEMBRE	\N	2014-09-28 17:05:42
3628	MECSS	2011-12-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04087R	MEMBRE	\N	2014-09-28 13:39:21
3629	MECSS	2011-12-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11103C	MEMBRE	\N	2017-11-28 10:08:26
3528	COLTER	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11035H	MEMBRE	\N	\N
3529	COLTER	2011-11-30 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	08064B	MEMBRE	\N	\N
3530	COLTER	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11034G	MEMBRE	\N	\N
3531	COLTER	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08045X	MEMBRE	\N	2014-09-28 17:00:59
3532	COLTER	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11049P	MEMBRE	\N	\N
3533	COLTER	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95037J	MEMBRE	\N	\N
3534	COLTER	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11112D	MEMBRE	\N	\N
3535	COLTER	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11099A	MEMBRE	\N	\N
3536	COLTER	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98038X	MEMBRE	\N	2014-09-28 17:38:26
3537	COLTER	2011-11-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01060R	MEMBRE	\N	2017-10-18 16:29:02
3538	COLTER	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08053X	MEMBRE	\N	\N
3539	COLTER	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	09012S	MEMBRE	\N	2014-09-28 13:09:05
3540	COLTER	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10015M	MEMBRE	\N	\N
3541	COLTER	2011-11-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	MEMBRE	\N	2017-10-18 16:28:25
3542	COLTER	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04045F	MEMBRE	\N	\N
3543	DSOM	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11055M	MEMBRE	\N	\N
3544	DSOM	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	MEMBRE	\N	\N
3545	DSOM	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08059E	MEMBRE	\N	2014-09-28 17:27:29
3546	DSOM	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	96004D	MEMBRE	\N	\N
3547	DSOM	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04040A	MEMBRE	\N	\N
3548	DSOM	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	90003B	MEMBRE	\N	\N
3549	DSOM	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01063U	MEMBRE	\N	2014-10-01 11:16:13
3550	DSOM	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01027Q	MEMBRE	\N	\N
3551	DSOM	2011-11-30 00:00:00	2014-02-20 00:00:00	ANCIEN	\N	\N	\N	\N	98030P	MEMBRE	\N	2014-02-21 11:14:03
3552	DSOM	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11064N	MEMBRE	\N	\N
3553	DSOM	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	MEMBRE	\N	\N
3554	DSOM	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08037X	MEMBRE	\N	2014-09-28 17:34:16
3555	DSOM	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11106F	MEMBRE	\N	\N
3556	DSOM	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77043E	MEMBRE	\N	2014-09-28 16:59:41
3557	DSOM	2011-11-30 00:00:00	2013-02-26 00:00:00	ANCIEN	\N	\N	\N	\N	92039X	MEMBRE	\N	\N
3558	DSOM	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11105E	MEMBRE	\N	\N
3560	DSOM	2011-11-30 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	04090L	MEMBRE	\N	\N
3561	DSOM	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11012A	MEMBRE	\N	\N
3562	DSOM	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95062K	MEMBRE	\N	\N
3563	DSOM	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04056J	MEMBRE	\N	\N
3564	DSOM	2011-11-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11109J	MEMBREDRT	\N	2017-10-18 16:29:01
3565	DSOM	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08072B	MEMBREDRT	\N	2014-09-29 09:05:47
3566	DSOM	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11023D	MEMBREDRT	\N	\N
3567	DSOM	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11114F	MEMBREDRT	\N	\N
3568	DSOM	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11113E	MEMBREDRT	\N	\N
3569	DSOM	2011-11-30 00:00:00	2014-07-01 00:00:00	ANCIEN	\N	\N	\N	\N	11022C	MEMBREDRT	\N	2014-07-01 09:29:53
3570	DSOM	2011-11-30 00:00:00	2013-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	08023R	MEMBREDRT	\N	\N
3571	DSOM	2011-11-30 00:00:00	2014-09-16 00:00:00	ANCIEN	\N	\N	\N	\N	98052V	MEMBREDRT	\N	2014-09-16 14:55:28
3572	DSOM	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11020A	MEMBREDRT	\N	\N
3573	DSOM	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11010L	MEMBREDRT	\N	\N
3574	DSOM	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04095R	MEMBREDRT	\N	\N
3575	DSOM	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04094Q	MEMBREDRT	\N	\N
3579	DSOM	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08019V	MEMBREDRT	\N	\N
3580	DSOM	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11072N	MEMBREDRT	\N	\N
3581	DSOM	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08073C	MEMBREDRT	\N	\N
3582	DSOM	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11071M	MEMBREDRT	\N	\N
3583	DSOM	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08071A	MEMBREDRT	\N	2014-09-29 09:08:32
3584	DSOM	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11011M	MEMBREDRT	\N	\N
3585	DSOM	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	96003C	MEMBREDRT	\N	\N
3586	DSOM	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11025F	MEMBREDRT	\N	\N
3635	MECSS	2011-12-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10003H	MEMBRE	\N	2014-09-28 17:38:26
3588	211	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08041T	MEMBRE	\N	\N
3630	MECSS	2011-12-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	MEMBRE	\N	2017-11-28 10:08:40
3590	211	2011-11-30 00:00:00	2012-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	09012S	MEMBRE	\N	\N
3593	COLTER	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08014Q	MEMBRE	\N	\N
3594	COLTER	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	07030L	MEMBRE	\N	2014-09-28 17:03:41
3595	PROS	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08055A	MEMBRE	\N	\N
3596	PROS	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11096W	MEMBRE	\N	\N
3597	PROS	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08063A	MEMBRE	\N	2014-09-28 17:07:07
3598	PROS	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08033T	MEMBRE	\N	2014-09-28 17:27:35
3631	MECSS	2011-12-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	MEMBRE	\N	2017-09-24 17:35:15
3633	MECSS	2011-12-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01011G	MEMBRE	\N	2017-09-24 16:43:43
3634	MECSS	2011-12-07 00:00:00	2012-10-23 00:00:00	ANCIEN	\N	\N	\N	\N	09001P	MEMBRE	\N	\N
3636	MECSS	2011-12-07 00:00:00	2012-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	11003M	MEMBRE	\N	\N
3637	MECSS	2011-12-07 00:00:00	2013-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	95045J	MEMBRE	\N	\N
3638	MECSS	2011-12-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	MEMBREDRT	\N	2017-11-28 10:09:31
3639	MECSS	2011-12-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08026U	MEMBRE	\N	2014-09-28 17:52:18
3669	RENSEIGNEMEN	2011-11-01 00:00:00	2014-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	MEMBREDRT	\N	2014-12-09 17:05:04
3670	RENSEIGNEMEN	2011-11-01 00:00:00	2014-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	92015P	MEMBREDRT	\N	2014-12-09 17:05:07
3710	DELCONEUR	2011-12-13 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11040E	MEMBRE	\N	\N
3711	DELCONEUR	2011-12-13 00:00:00	2013-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	95045J	MEMBRE	\N	\N
3712	DELCONEUR	2011-12-13 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08050U	MEMBRE	\N	2014-09-28 12:44:31
3713	DELCONEUR	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92031P	MEMBRE	\N	\N
3714	DELCONEUR	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04084N	MEMBRE	\N	2014-09-28 13:40:33
3728	211	2012-01-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11091R	MEMBRE	\N	\N
3730	211	2012-01-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04069P	MEMBRE	\N	2014-09-28 17:31:41
3749	MECSS	2012-01-25 00:00:00	2014-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	04067M	MEMBRE	\N	2014-12-10 16:24:10
3770	211	2012-02-01 00:00:00	2013-09-12 00:00:00	ANCIEN	\N	\N	\N	\N	11069T	MEMBRE	\N	2013-09-13 16:55:43
3788	211	2012-02-20 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08050U	MEMBRE	\N	2014-09-28 12:44:31
3789	PROS	2012-02-20 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	09012S	MEMBRE	\N	2014-09-28 13:09:05
3808	OTAN	\N	2015-10-15 00:00:00	ANCIEN	\N	\N	\N	\N	92015P	TITULAIRE	\N	2015-10-15 17:58:08
3809	OTAN	\N	2015-10-15 00:00:00	ANCIEN	\N	\N	\N	\N	04035D	TITULAIRE	\N	2015-10-15 18:03:35
3811	OTAN	\N	2015-10-15 00:00:00	ANCIEN	\N	\N	\N	\N	07004J	TITULAIRE	\N	2015-10-15 17:58:14
3812	OTAN	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95052H	SUPPLEANT	\N	2014-09-28 13:39:20
3813	OTAN	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	96006F	SUPPLEANT	\N	2014-09-28 16:50:17
3814	OTAN	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04091M	SUPPLEANT	\N	2014-09-28 17:55:39
3815	OTAN	\N	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04040A	SUPPLEANT	\N	2015-10-15 18:02:15
3850	COMITEDEONTO	2012-02-22 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	11033F	MEMBRE	\N	\N
3868	MECSS	2012-06-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11097X	MEMBRE	\N	2017-11-28 10:10:05
3888	COLTER	2012-07-24 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	12039E	MEMBRE	\N	2014-05-05 10:35:23
3889	DSOM	2012-07-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11054L	MEMBRE	\N	2017-10-18 16:27:51
3908	CSCE	2012-06-16 00:00:00	2013-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	11105E	MEMBRE	\N	\N
3909	CSCE	2012-06-16 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	96004D	MEMBRE	\N	\N
3911	CSCE	2012-06-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04080J	MEMBRE	\N	2017-09-24 17:47:27
3928	COMITEDEONTO	2012-10-10 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	12035A	MEMBRE	\N	2014-05-05 10:34:09
3929	COMITEDEONTO	2012-10-10 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	MEMBRE	\N	2015-01-12 18:27:47
3948	PROS	2012-09-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08022Q	MEMBRE	\N	\N
3988	211	2012-11-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11045K	MEMBRE	\N	2017-10-18 16:15:57
2534	UIP	\N	2014-09-29 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	98019U	MEMBRE	\N	2014-09-29 13:43:10
177	208	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Choix scientifiques et technologiques (suppleant)/ Office parlementaire d'evaluation de la legislation/ 	80046H	MEMBRE	\N	\N
2535	SFAPF	\N	2015-02-12 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	97011G	MEMBRE	\N	2015-02-13 16:06:23
2536	SFAPF	\N	2014-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	94003T	MEMBRE	\N	2014-09-28 13:16:32
2537	UIP	\N	2011-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre du bureau de la section française de l'Assemblée Parlementaire de la Francophonie	Membre du bureau de la section française de l'Assemblée Parlementaire de la Francophonie	78006D	MEMBRE	\N	\N
2372	UEO	2005-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83042R	MEMBRE	\N	\N
2373	206	2006-03-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95019G	MEMBRE	\N	2014-09-28 16:59:41
1203	ODD	2005-01-19 00:00:00	2009-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	95038K	MEMBRE	\N	\N
2538	SFAPF	\N	2014-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	95038K	MEMBRE	\N	2014-09-28 17:40:23
2539	SFAPF	\N	2004-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	77046H	MEMBRE	\N	\N
2540	SFAPF	\N	2010-10-18 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	92029V	MEMBRE	\N	\N
2541	SFAPF	\N	2015-02-12 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	86034E	MEMBRE	\N	2015-02-13 16:06:29
2542	SFAPF	\N	2015-02-12 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	98005N	MEMBRE	\N	2015-02-13 16:06:32
2543	SFAPF	\N	2015-02-12 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	92031P	MEMBRE	\N	2015-02-13 16:06:32
563	205	1998-10-14 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	94004U	MEMBRE	\N	\N
564	205	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	89022N	MEMBRE	\N	\N
565	205	1998-10-14 00:00:00	2000-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	95018F	MEMBRE	\N	\N
566	205	1998-10-14 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	\N	83037U	MEMBRE	\N	\N
573	205	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	80031A	MEMBRE	\N	\N
568	205	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	98043U	MEMBRE	\N	\N
569	205	1998-10-14 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	81011A	MEMBRE	\N	\N
571	205	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	98025S	MEMBRE	\N	\N
572	205	1998-10-14 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	89006N	MEMBRE	\N	\N
150	206	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Choix scientifiques et technologiques (titulaire)/ 	92039X	TITULAIRE	\N	\N
152	206	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Problemes demographiques/ Choix scientifiques et technologiques (suppleant)/ 	83036T	SUPPLEANT	\N	\N
153	206	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Problemes demographiques/ Choix scientifiques et technologiques (suppleant)/ 	92011K	MEMBRE	\N	\N
155	206	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ Choix scientifiques et technologiques (titulaire)/ 	86047K	TITULAIRE	\N	\N
156	206	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Choix scientifiques et technologiques (titulaire)/ 	77066M	TITULAIRE	\N	\N
157	202	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Choix scientifiques et technologiques (titulaire)/ 	95025E	TITULAIRE	\N	\N
158	207	1996-06-28 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'evaluation des politiques publiques/ 	71009B	MEMBRE	\N	\N
159	207	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'evaluation des politiques publiques/ 	96005E	MEMBRE	\N	\N
160	207	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'evaluation des politiques publiques/ 	89045V	MEMBRE	\N	\N
161	207	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Choix scientifiques et technologiques (titulaire)/ Office parlementaire d'evaluation des politiques publiques/ 	89037V	MEMBRE	\N	\N
162	207	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	Planification/ Office parlementaire d'evaluation des politiques publiques/ 	80036F	MEMBRE	\N	\N
163	207	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'evaluation des politiques publiques/ 	86037H	MEMBRE	\N	\N
164	207	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ Office parlementaire d'evaluation des politiques publiques/ 	92012L	MEMBRE	\N	\N
165	207	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Choix scientifiques et technologiques (titulaire)/ Office parlementaire d'evaluation des politiques publiques/ 	83028T	MEMBRE	\N	\N
166	207	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ Office parlementaire d'evaluation des politiques publiques/ 	92022N	MEMBRE	\N	\N
167	207	\N	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'evaluation des politiques publiques/ 	86005Y	MEMBRE	\N	\N
168	207	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'evaluation des politiques publiques/ 	92035T	MEMBRE	\N	\N
169	207	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'evaluation des politiques publiques/ 	92029V	MEMBRE	\N	\N
170	207	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Planification/ Office parlementaire d'evaluation des politiques publiques/ 	95018F	MEMBRE	\N	\N
171	207	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'evaluation des politiques publiques/ 	81015E	MEMBRE	\N	\N
172	207	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'evaluation des politiques publiques/ 	77017C	MEMBRE	\N	\N
173	207	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'evaluation des politiques publiques/ 	77058M	MEMBRE	\N	\N
174	208	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'evaluation de la legislation/ Union Europeenne/ 	80017C	MEMBRE	\N	\N
175	208	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'evaluation de la legislation/ 	83004K	MEMBRE	\N	\N
176	208	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Problemes demographiques/ Office parlementaire d'evaluation de la legislation/ 	89019T	MEMBRE	\N	\N
178	208	\N	1998-10-21 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ Office parlementaire d'evaluation de la legislation/ 	95006B	MEMBRE	\N	\N
98	202	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	86041D	MEMBRE	\N	\N
99	CSCE	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	95004Y	MEMBRE	\N	\N
100	202	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	89035T	MEMBRE	\N	\N
101	202	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	77001T	MEMBRE	\N	\N
102	202	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	69001W	MEMBRE	\N	\N
103	202	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Union Europeenne/ 	86050E	MEMBRE	\N	\N
104	203	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Problemes demographiques/ Office parlementaire d'evaluation de la legislation/ 	89019T	MEMBRE	\N	\N
105	203	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	Problemes demographiques/ 	93006S	MEMBRE	\N	\N
106	203	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Problemes demographiques/ Union  europeenne/ 	92019T	MEMBRE	\N	\N
107	203	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Problemes demographiques/ Choix scientifiques et technologiques (suppleant)/ 	83036T	MEMBRE	\N	\N
109	203	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Problemes demographiques/ 	95011X	MEMBRE	\N	\N
110	203	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Problemes demographiques/ 	77013X	MEMBRE	\N	\N
111	203	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Problemes demographiques/ Choix scientifiques et technologiques (suppleant)/ 	92011K	MEMBRE	\N	\N
113	203	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Problemes demographiques/ Office parlementaire d'evaluation de la legislation/ 	95014B	MEMBRE	\N	\N
114	205	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	Planification/ 	71006X	MEMBRE	\N	\N
115	205	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Planification/ 	89006N	MEMBRE	\N	\N
116	205	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	Planification/ 	80021X	MEMBRE	\N	\N
117	205	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	Planification/ 	78010Y	MEMBRE	\N	\N
118	205	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Planification/ 	80031A	MEMBRE	\N	\N
119	205	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	Planification/ Office parlementaire d'evaluation des politiques publiques/ 	80036F	MEMBRE	\N	\N
120	205	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Planification/ 	88003F	MEMBRE	\N	\N
121	205	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Planification/ 	89022N	MEMBRE	\N	\N
122	205	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Planification/ 	94004U	MEMBRE	\N	\N
123	205	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Planification/ 	81011A	MEMBRE	\N	\N
124	205	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Planification/ 	83037U	MEMBRE	\N	\N
125	205	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Planification/ Office parlementaire d'evaluation des politiques publiques/ 	95018F	MEMBRE	\N	\N
126	205	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Planification/ 	83047W	MEMBRE	\N	\N
127	205	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Planification/ 	77060F	MEMBRE	\N	\N
128	205	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Planification/ 	95057N	MEMBRE	\N	\N
142	206	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Choix scientifiques et technologiques (titulaire)/ 	85003S	TITULAIRE	\N	\N
143	206	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Choix scientifiques et technologiques (titulaire)/ 	89013M	TITULAIRE	\N	\N
144	206	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Choix scientifiques et technologiques (titulaire)/ Office parlementaire d'evaluation des politiques publiques/ 	89037V	TITULAIRE	\N	\N
145	206	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Choix scientifiques et technologiques (suppleant)/ 	89040Q	SUPPLEANT	\N	\N
146	206	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Choix scientifiques et technologiques (suppleant)/ 	86039K	SUPPLEANT	\N	\N
148	206	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	Choix scientifiques et technologiques (titulaire)/ Office parlementaire d'evaluation des politiques publiques/ 	83028T	TITULAIRE	\N	\N
149	206	\N	1998-10-13 00:00:00	ANCIEN	\N	\N	\N	choix scientifiques et technologiques (suppleant)/ 	74015M	SUPPLEANT	\N	\N
23	DELCONEUR	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	Conseil de l'Europe (delegue titulaire)/ Union de l'Europe occidentale (delegue titulaire)/ 	80002U	TITULAIRE	\N	\N
24	DELCONEUR	\N	1998-10-20 00:00:00	ANCIEN	\N	\N	\N	Conseil de l'Europe (delegue suppleant)/ Union de l'Europe occidentale (delegue suppleant)/ 	89045V	SUPPLEANT	\N	\N
25	DELCONEUR	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	Conseil de l'Europe (delegue suppleant)/ Union de l'Europe occidentale (delegue suppleant)/ 	71024A	SUPPLEANT	\N	\N
26	DELCONEUR	\N	1998-10-20 00:00:00	ANCIEN	\N	\N	\N	Conseil de l'Europe (delegue suppleant)/ Union de l'Europe occidentale (delegue suppleant)/ 	92012L	SUPPLEANT	\N	\N
27	DELCONEUR	\N	1998-10-20 00:00:00	ANCIEN	\N	\N	\N	Conseil de l'Europe (delegue titulaire)/ Union de l'Europe occidentale (delegue titulaire)/ Haute Cour de Justice (juge titulaire)/ 	74024N	TITULAIRE	\N	\N
2517	SFAPF	\N	2014-09-30 00:00:00	ANCIEN	\N	Trésorier de la sect° française de l'Assemblée Parlement 	Trésorier de la section française de l'Assemblée Parlementaire de la Francophonie	Trésorier de la section française de l'Assemblée Parlementaire de la Francophonie	89022N	MEMBRE	\N	2014-09-28 18:19:47
2518	SFAPF	\N	2008-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	98049B	MEMBRE	\N	\N
2519	SFAPF	\N	2008-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	89023P	MEMBRE	\N	\N
2520	UIP	\N	2015-02-13 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	77002U	MEMBRE	\N	2015-02-13 15:49:54
2521	SFAPF	\N	2015-02-12 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	\N	Membre du bureau de la section française de l'Assemblée Parlementaire de la Francophonie	92008Q	MEMBRE	\N	2015-02-13 16:06:17
2522	SFAPF	\N	2020-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	88008L	MEMBRE	\N	2015-02-13 16:06:18
3480	PROS	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95005A	MEMBRE	\N	2014-09-28 17:40:23
3482	PROS	2011-11-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	07003H	MEMBRE	\N	2014-09-28 12:21:28
886	210	2001-09-10 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	89013M	MEMBRE	\N	\N
2523	SFAPF	\N	2002-06-07 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Trésorier adjoint de la section française de l'Assemblée Parlementaire de la Francophonie	Trésorier adjoint de la section française de l'Assemblée Parlementaire de la Francophonie	98031Q	MEMBRE	\N	\N
2524	SFAPF	\N	2014-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	\N	Membre du bureau de la section française de l'Assemblée Parlementaire de la Francophonie	95021A	MEMBRE	\N	2014-09-28 16:40:50
2525	SFAPF	\N	2011-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	01012H	MEMBRE	\N	\N
2526	SFAPF	\N	2015-02-12 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	01059Y	MEMBRE	\N	2015-02-13 16:06:20
2527	SFAPF	\N	2021-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	98018T	MEMBRE	\N	\N
2528	UIP	\N	2008-09-07 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Secrétaire de la section française de l'Assemblée Parlementaire de la Francophonie	Secrétaire de la section française de l'Assemblée Parlementaire de la Francophonie	80017C	MEMBRE	\N	\N
2688	208	2007-07-25 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	04035D	MEMBRE	\N	\N
1145	211	2004-10-13 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	66002K	MEMBRE	\N	\N
3350	OTAN	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92013M	MEMBRE	\N	\N
3351	OTAN	\N	2016-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	07024N	TITULAIRE	\N	2017-01-03 11:09:24
3352	OTAN	\N	2015-10-15 00:00:00	ANCIEN	\N	\N	\N	\N	01014K	SUPPLEANT	\N	2015-10-15 18:04:51
3353	OTAN	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04065K	MEMBRE	\N	2014-09-28 17:31:42
3354	OTAN	\N	2015-10-15 00:00:00	ANCIEN	\N	\N	\N	\N	01056V	MEMBRE	\N	2017-02-20 10:15:21
3368	PROS	2010-12-08 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	04089T	MEMBRE	\N	\N
3369	PROS	2010-12-08 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	08039A	MEMBRE	\N	\N
3370	PROS	2010-12-08 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08019V	MEMBRE	\N	\N
3371	206	2010-12-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95024D	MEMBRE	\N	\N
3372	206	2010-12-08 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	08009T	MEMBRE	\N	\N
3248	211	2010-05-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08043V	MEMBRE	\N	2017-10-18 16:13:57
3270	SFAPF	\N	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	04042C	MEMBRE	\N	2015-02-13 16:06:14
3271	SFAPF	\N	2018-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	08016S	MEMBRE	\N	2015-02-13 16:06:26
932	206	2001-10-10 00:00:00	2010-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	01026P	MEMBRE	\N	\N
2602	UIP	\N	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	92022N	MEMBRE	\N	\N
2793	MECSS	2006-01-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01018P	MEMBRE	\N	\N
2794	MECSS	2006-01-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92030N	MEMBRE	\N	\N
2795	MECSS	2006-01-23 00:00:00	2011-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	98029W	MEMBRE	\N	2016-01-27 14:17:27
2796	MECSS	2006-01-23 00:00:00	2008-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	98030P	MEMBRE	\N	\N
2797	MECSS	2006-01-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	MEMBRE	\N	2014-09-28 17:07:41
2798	MECSS	2006-01-23 00:00:00	2008-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	01011G	MEMBRE	\N	\N
2799	MECSS	2006-01-23 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89041R	MEMBRE	\N	\N
2800	MECSS	2006-01-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01034P	MEMBRE	\N	2017-11-28 10:10:10
2801	MECSS	2006-01-23 00:00:00	2009-07-07 00:00:00	ANCIEN	\N	\N	Président de la Commission des Affaires sociales	\N	95004Y	MEMBREDRT	\N	\N
2869	MECSS	2008-10-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01045S	MEMBRE	\N	\N
2870	MECSS	2008-10-08 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04046G	MEMBRE	\N	2014-09-28 17:07:41
2871	MECSS	2008-10-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	MEMBRE	\N	2017-09-24 13:44:49
2872	MECSS	2008-10-08 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08037X	MEMBRE	\N	2014-09-28 17:34:16
2949	211	2008-11-18 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	MEMBRE	\N	\N
2950	211	2008-11-18 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08060W	MEMBRE	\N	\N
2951	211	2008-11-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08020N	MEMBRE	\N	2017-10-18 16:11:25
2952	211	2008-11-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08024S	MEMBRE	\N	2017-10-18 16:14:19
2953	211	2008-11-18 00:00:00	2010-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	08013P	MEMBRE	\N	\N
2954	211	2008-11-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80013X	MEMBRE	\N	2017-10-18 16:14:37
2955	211	2008-11-18 00:00:00	2012-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	08022Q	MEMBRE	\N	\N
2956	211	2008-11-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	07033P	MEMBRE	\N	\N
2957	211	2008-11-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04058L	MEMBRE	\N	\N
2958	211	2008-11-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08031R	MEMBRE	\N	2017-10-18 16:19:02
2959	211	2008-11-18 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	08063A	MEMBRE	\N	\N
2960	211	2008-11-18 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08017T	MEMBRE	\N	\N
2961	211	2008-12-03 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	04070G	MEMBRE	\N	2016-06-02 17:13:50
2962	211	2008-11-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	07023M	MEMBRE	\N	\N
2963	211	2008-11-18 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	08054Y	MEMBRE	\N	\N
2374	208	2004-10-20 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	MEMBREDRTCOM	\N	\N
1179	208	2004-10-20 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	04063H	MEMBREGRPPOL	\N	\N
1006	SANTE	2003-01-21 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	Rapporteur de la Commission des Affaires Sociales sur le projet de loi de financement de la sécurité sociale pour l'assurance-maladie	\N	92045V	MEMBREDRT	\N	\N
1183	SANTE	2004-10-20 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	92011K	MEMBREGRPPOL	\N	\N
943	DELCONEUR	2001-10-23 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92020L	TITULAIRE	\N	\N
2729	211	2007-10-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	97005J	MEMBRE	\N	\N
2731	211	2007-10-03 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89035T	MEMBRE	\N	\N
2989	MECSS	2009-07-08 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04051D	MEMBREDRT	\N	2014-09-28 17:07:41
1124	211	2004-10-13 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	04051D	MEMBRE	\N	\N
3012	COLTER	2009-09-23 00:00:00	2011-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	89013M	MEMBRE	\N	\N
2829	RENSEIGNEMEN	2007-10-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Président de la commission des Affaires étrangères, de la défense et des forces armées	\N	83050R	MEMBREDRT	\N	\N
2529	SFAPF	\N	2015-02-12 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	92020L	MEMBRE	\N	2015-02-13 16:06:21
2530	SFAPF	\N	2008-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	89025R	MEMBRE	\N	\N
2531	SFAPF	\N	2015-02-12 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	01041N	MEMBRE	\N	2015-02-13 16:06:07
2532	SFAPF	\N	2004-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	86025D	MEMBRE	\N	\N
2664	OTAN	\N	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	\N	77044F	TITULAIRE	\N	\N
2665	OTAN	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98044V	TITULAIRE	\N	\N
2666	OTAN	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80035E	TITULAIRE	\N	\N
2667	OTAN	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80040B	TITULAIRE	\N	\N
2668	OTAN	\N	2012-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01051Q	TITULAIRE	\N	\N
2669	OTAN	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98016R	SUPPLEANT	\N	\N
2670	OTAN	\N	2007-02-25 00:00:00	ANCIEN	\N	\N	\N	\N	92024Q	SUPPLEANT	\N	\N
2671	OTAN	\N	2015-10-15 00:00:00	ANCIEN	\N	\N	\N	\N	92031P	SUPPLEANT	\N	2015-10-15 17:58:15
2672	OTAN	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80039J	SUPPLEANT	\N	\N
2673	OTAN	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89042S	SUPPLEANT	\N	\N
2589	UIP	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04063H	MEMBRE	\N	\N
2592	UIP	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98014P	MEMBRE	\N	\N
2594	UIP	\N	2015-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	95015C	MEMBRE	\N	2015-02-13 15:49:55
2596	UIP	\N	2015-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	90003B	MEMBRE	\N	2015-02-13 15:49:58
2611	UIP	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98051U	MEMBRE	\N	\N
2613	UIP	\N	2015-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	92039X	MEMBRE	\N	2015-02-13 15:49:51
2616	UIP	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98044V	MEMBRE	\N	\N
2618	SFAPF	\N	2009-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	86044G	MEMBRE	\N	\N
2621	UIP	\N	2015-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	80048K	MEMBRE	\N	2015-02-13 15:49:48
2626	UIP	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77058M	MEMBRE	\N	2014-09-28 12:52:10
2635	SFAPF	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95044H	MEMBRE	\N	\N
2638	SFAPF	\N	2008-09-07 00:00:00	ANCIEN	\N	\N	\N	\N	80017C	MEMBRE	\N	\N
2641	SFAPF	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01001E	MEMBRE	\N	\N
2643	SFAPF	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01063U	MEMBRE	\N	2014-10-01 11:15:39
2646	SFAPF	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83031N	MEMBRE	\N	\N
2648	SFAPF	\N	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	04095R	MEMBRE	\N	2015-02-13 16:06:25
2651	SFAPF	\N	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	\N	77044F	MEMBRE	\N	\N
2654	SFAPF	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01054T	MEMBRE	\N	\N
800	211	2001-06-25 00:00:00	2001-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	89042S	TITULAIRE	\N	\N
605	206	1998-10-14 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92032Q	SUPPLEANT	\N	\N
2681	202	2006-11-09 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	06006G	MEMBRE	\N	\N
2683	202	2007-02-14 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	07003H	MEMBRE	\N	\N
938	DELCONEUR	2001-10-23 00:00:00	2007-02-25 00:00:00	ANCIEN	\N	\N	\N	\N	92024Q	SUPPLEANT	\N	\N
2772	RENSEIGNEMEN	2007-10-10 00:00:00	2011-10-01 00:00:00	ANCIEN	\N	\N	Président de la commission des Lois constitutionnelles, de législation, du suffrage universel, du Règlement et d'administration générale	\N	95039L	MEMBREDRT	\N	\N
2773	RENSEIGNEMEN	2007-10-10 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	Président de la commission des Affaires étrangères, de la défense et des forces armées 	\N	89045V	MEMBREDRT	\N	\N
2774	RENSEIGNEMEN	2007-10-10 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	95020Y	MEMBRE	\N	2015-06-12 16:01:25
2775	RENSEIGNEMEN	2007-10-10 00:00:00	2012-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01051Q	MEMBRE	\N	\N
2791	MECSS	2006-01-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	Rapporteur général de la commission des affaires sociales	\N	92045V	MEMBREDRT	\N	\N
2792	MECSS	2006-01-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98024R	MEMBRE	\N	2017-11-28 10:08:46
2848	ODD	2008-04-01 00:00:00	2009-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	07003H	MEMBRE	\N	\N
1204	ODD	2005-01-19 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	02005N	MEMBRE	\N	\N
1176	208	2004-10-20 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	96008H	MEMBREGRPPOL	\N	\N
1116	205	2004-10-13 00:00:00	2008-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	01050P	MEMBRE	\N	\N
2929	205	2008-11-04 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	04087R	MEMBRE	\N	\N
2930	205	2008-11-04 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	08050U	MEMBRE	\N	\N
2931	205	2008-11-04 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	08045X	MEMBRE	\N	\N
2932	205	2008-11-04 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	08056B	MEMBRE	\N	2017-10-19 18:17:19
2933	205	2008-11-04 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	08012N	MEMBRE	\N	\N
2934	205	2008-11-04 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	08062Y	MEMBRE	\N	\N
2935	205	2008-11-04 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	08047A	MEMBRE	\N	\N
2936	205	2008-11-04 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	89022N	MEMBRE	\N	\N
2939	206	2008-11-04 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	MEMBRE	\N	\N
2940	206	2008-11-04 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	08038Y	MEMBRE	\N	\N
2941	206	2008-11-04 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95025E	MEMBRE	\N	2014-09-28 17:09:16
2968	CSCE	2009-01-14 00:00:00	2015-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	04054G	MEMBRE	\N	2015-06-16 18:05:16
2944	206	2008-11-04 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95052H	MEMBRE	\N	2014-09-28 13:39:20
2945	206	2008-11-04 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	98021N	MEMBRE	\N	\N
1164	206	2004-10-13 00:00:00	2008-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	82002D	MEMBRE	\N	\N
2946	SANTE	2008-11-04 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	08043V	MEMBREGRPPOL	\N	\N
2947	SANTE	2008-11-04 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	08033T	MEMBREGRPPOL	\N	\N
2969	CSCE	2009-01-14 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98010K	MEMBRE	\N	2014-09-28 17:27:35
901	205	2001-10-10 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	98036V	MEMBRE	\N	\N
1112	205	2004-10-13 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	97009N	MEMBRE	\N	\N
2809	202	2008-01-22 00:00:00	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	83050R	MEMBRE	\N	\N
891	210	2001-09-10 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	01007L	MEMBRE	\N	\N
840	203	2001-10-10 00:00:00	2009-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	92008Q	MEMBRE	\N	\N
1195	ODD	2005-01-19 00:00:00	2009-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	95049N	MEMBRE	\N	\N
1201	ODD	2005-01-19 00:00:00	2009-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	01027Q	MEMBRE	\N	\N
1102	208	\N	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'évaluation de la législation/ Union Européenne/	95063L	MEMBRE	\N	\N
1175	208	2004-10-20 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	01065W	MEMBREGRPPOL	\N	\N
1187	SANTE	2004-10-20 00:00:00	2009-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	92030N	MEMBREGRPPOL	\N	\N
3148	211	2010-01-13 00:00:00	2014-10-28 00:00:00	ANCIEN	\N	\N	\N	\N	08056B	MEMBRE	\N	2017-10-19 18:17:01
3168	COMITEDEONTO	2010-02-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95006B	MEMBRE	\N	\N
3169	COMITEDEONTO	2010-02-10 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	98042T	MEMBRE	\N	2015-01-12 18:27:44
3170	COMITEDEONTO	2010-02-10 00:00:00	2012-09-19 00:00:00	ANCIEN	\N	\N	\N	\N	95011X	MEMBRE	\N	\N
3171	COMITEDEONTO	2010-02-10 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	81015E	MEMBRE	\N	\N
3172	COMITEDEONTO	2010-02-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83050R	MEMBRE	\N	\N
3188	UIP	2008-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	08009T	MEMBRE	\N	2015-02-13 15:55:45
3209	COMITEDEONTO	2010-03-31 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	01065W	MEMBRE	\N	2015-01-12 18:27:45
3328	COLTER	2010-10-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01057W	MEMBRE	\N	\N
3348	OTAN	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95028H	SUPPLEANT	\N	2014-09-28 12:56:41
3349	OTAN	\N	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04054G	MEMBRE	\N	2017-09-24 17:18:03
814	CSCE	2001-11-29 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92018S	MEMBRE	\N	\N
1047	202	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	Union Européenne/	59569E	TITULAIRE	\N	\N
1048	202	\N	1997-06-19 00:00:00	ANCIEN	\N	\N	\N	Union Européenne/ Problèmes démographiques/	92018S	TITULAIRE	\N	\N
1049	202	\N	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	Union Européenne/	59534S	TITULAIRE	\N	\N
1051	202	\N	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	Union Européenne/	89032Q	TITULAIRE	\N	\N
1052	202	\N	2000-04-21 00:00:00	ANCIEN	\N	\N	\N	Union Européenne/	59539X	TITULAIRE	\N	\N
1053	202	\N	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	Union européenne/	92028U	TITULAIRE	\N	\N
1054	202	\N	1998-09-25 00:00:00	ANCIEN	\N	\N	\N	Union Européenne/	59543T	TITULAIRE	\N	\N
1055	202	\N	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	Union Européenne/	000502	TITULAIRE	\N	\N
1056	202	\N	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'évaluation des choix scientifiques et technologiques/ Union Européenne/	58914W	TITULAIRE	\N	\N
1057	202	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	Union Européenne/	59556Y	MEMBRE	\N	\N
1058	202	\N	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	Union Européenne/	000476	TITULAIRE	\N	\N
1059	202	\N	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	Union Européenne/	000104	TITULAIRE	\N	\N
1060	202	\N	2008-10-07 00:00:00	ANCIEN	\N	\N	\N	Office parlementaire d'évaluation de la législation/ Union Européenne/	95063L	TITULAIRE	\N	\N
1061	202	\N	1996-05-15 00:00:00	ANCIEN	\N	\N	\N	Union Européenne/	83001G	TITULAIRE	\N	\N
1062	202	\N	1999-07-13 00:00:00	ANCIEN	\N	\N	\N	Union Européenne/	58647W	TITULAIRE	\N	\N
1069	203	\N	2009-06-25 00:00:00	ANCIEN	\N	\N	\N	Problèmes démographiques/	000553	TITULAIRE	\N	\N
2558	SFAPF	\N	2014-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	77058M	MEMBRE	\N	2014-09-28 12:52:10
2559	SFAPF	\N	2004-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre du bureau de la section française de l'Assemblée Parlementaire de la Francophonie	Membre du bureau de la section française de l'Assemblée Parlementaire de la Francophonie	95058P	MEMBRE	\N	\N
2560	SFAPF	\N	2011-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Secrétaire de la section française de l'Assemblée Parlementaire de la Francophonie	Secrétaire de la section française de l'Assemblée Parlementaire de la Francophonie	85002R	MEMBRE	\N	\N
2561	SFAPF	\N	2004-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre du bureau de la section française de l'Assemblée Parlementaire de la Francophonie	Membre du bureau de la section française de l'Assemblée Parlementaire de la Francophonie	95061J	MEMBRE	\N	\N
2562	SFAPF	\N	2008-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	89037V	MEMBRE	\N	\N
2563	SFAPF	\N	2008-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	98039Y	MEMBRE	\N	\N
2564	SFAPF	\N	2004-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	77060F	MEMBRE	\N	\N
2565	SFAPF	\N	2008-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	89040Q	MEMBRE	\N	\N
2566	SFAPF	\N	2008-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	80046H	MEMBRE	\N	\N
2567	UIP	\N	2008-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Secrétaire de la section française de l'Assemblée Parlementaire de la Francophonie	Secrétaire de la section française de l'Assemblée Parlementaire de la Francophonie	89042S	MEMBRE	\N	\N
2568	SFAPF	\N	2004-09-30 00:00:00	ANCIEN	\N	1er VP de la section française de l'Assemblée Parlementaire 	Premier vice-président de la section française de l'Assemblée Parlementaire de la Francophonie	Premier vice-président de la section française de l'Assemblée Parlementaire de la Francophonie	86050E	MEMBRE	\N	\N
2656	SFAPF	\N	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	04056J	MEMBRE	\N	2015-02-13 16:06:11
2657	SFAPF	\N	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	MEMBRE	\N	2015-02-13 16:06:12
2659	OTAN	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	90004C	TITULAIRE	\N	2014-09-28 13:21:47
2663	OTAN	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98014P	TITULAIRE	\N	\N
3088	COLTER	2009-10-06 00:00:00	2011-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	08055A	MEMBRE	\N	\N
2570	UIP	2002-02-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	Membre de la délégation au Comité des régions de l'Union eur	Membre de la délégation au Comité des régions de l'Union européenne	Membre de la délégation au Comité des régions de l'Union européenne	95050F	MEMBRE	\N	\N
2577	SFAPF	\N	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	04035D	MEMBRE	\N	2015-02-13 16:06:09
2579	UIP	\N	2015-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	04035D	MEMBRE	\N	2015-02-13 15:49:59
2580	UIP	\N	2015-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	04059M	MEMBRE	\N	2015-02-13 15:49:53
2581	UIP	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98011L	MEMBRE	\N	2014-09-28 17:27:35
2582	UIP	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83012K	MEMBRE	\N	\N
2583	UIP	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89019T	MEMBRE	\N	\N
2584	UIP	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89015P	MEMBRE	\N	2014-09-28 16:50:17
2585	UIP	\N	2009-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	01064V	MEMBRE	\N	\N
2587	UIP	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01005J	MEMBRE	\N	\N
2588	UIP	\N	2012-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01051Q	MEMBRE	\N	\N
2590	UIP	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98049B	MEMBRE	\N	\N
2591	UIP	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01052R	MEMBRE	\N	\N
2593	UIP	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98016R	MEMBRE	\N	\N
2595	UIP	\N	2015-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	92015P	MEMBRE	\N	2015-02-13 15:49:56
2597	UIP	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80015A	MEMBRE	\N	\N
2598	UIP	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	90004C	MEMBRE	\N	2014-09-28 13:21:47
2599	UIP	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01045S	MEMBRE	\N	\N
2600	UIP	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95028H	MEMBRE	\N	2014-09-28 12:56:41
2601	UIP	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89007P	MEMBRE	\N	2014-09-28 16:42:05
2603	UIP	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83031N	MEMBRE	\N	\N
2604	UIP	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01055U	MEMBRE	\N	\N
2606	UIP	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	78003A	MEMBRE	\N	\N
2607	UIP	\N	2007-02-25 00:00:00	ANCIEN	\N	\N	\N	\N	92024Q	MEMBRE	\N	\N
2608	UIP	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01040M	MEMBRE	\N	\N
2609	UIP	1999-10-07 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	86030A	MEMBRE	\N	\N
2610	UIP	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01021J	MEMBRE	\N	\N
2612	UIP	\N	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	\N	77044F	MEMBRE	\N	\N
2614	UIP	\N	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	98032R	MEMBRE	\N	2015-06-12 15:59:49
2615	UIP	\N	2015-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	92040Q	MEMBRE	\N	2015-02-13 15:49:52
2617	UIP	\N	2015-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	98021N	MEMBRE	\N	2015-02-13 15:49:50
2619	UIP	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80040B	MEMBRE	\N	\N
2620	UIP	\N	2017-11-07 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	MEMBRE	\N	2017-11-14 11:42:48
2622	UIP	\N	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	89045V	MEMBRE	\N	\N
2625	UIP	\N	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98018T	MEMBRE	\N	2015-02-13 15:53:04
2629	OTAN	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89023P	TITULAIRE	\N	\N
2634	OTAN	2008-11-04 00:00:00	2015-10-15 00:00:00	ANCIEN	\N	\N	\N	\N	98021N	TITULAIRE	\N	2015-10-15 18:04:13
2636	SFAPF	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01009N	MEMBRE	\N	\N
2637	UIP	\N	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	MEMBRE	\N	2015-01-08 17:14:29
2639	SFAPF	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89042S	MEMBRE	\N	\N
2640	SFAPF	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	78006D	MEMBRE	\N	\N
2642	SFAPF	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95019G	MEMBRE	\N	2014-09-28 16:59:41
2644	SFAPF	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04093P	MEMBRE	\N	\N
2645	SFAPF	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98030P	MEMBRE	\N	2014-09-28 13:19:48
2647	SFAPF	\N	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	98019U	MEMBRE	\N	2014-09-29 13:43:10
2649	SFAPF	\N	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	04078Q	MEMBRE	\N	2015-02-13 16:06:27
2650	SFAPF	\N	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	04037F	MEMBRE	\N	2015-02-13 16:06:28
2652	SFAPF	\N	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	92039X	MEMBRE	\N	2015-02-13 16:06:10
2653	SFAPF	\N	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	92040Q	MEMBRE	\N	2015-02-13 16:06:35
2655	SFAPF	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98015Q	MEMBRE	\N	\N
2509	SFAPF	\N	2011-01-23 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	95004Y	MEMBRE	\N	\N
2510	SFAPF	\N	2015-02-12 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre du bureau de la section française de l'Assemblée Parlementaire de la Francophonie	Membre du bureau de la section française de l'Assemblée Parlementaire de la Francophonie	01031L	MEMBRE	\N	2015-02-13 16:06:06
2605	UIP	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	MEMBRE	\N	\N
3448	COMITEDEONTO	2011-11-16 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	98041S	MEMBRE	\N	2015-01-12 18:27:48
3449	COMITEDEONTO	2011-11-16 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	04056J	MEMBRE	\N	2015-01-12 18:27:37
2511	SFAPF	\N	2011-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	95006B	MEMBRE	\N	\N
2512	SFAPF	\N	2011-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Secrétaire de la section française de l'Assemblée Parlementaire de la Francophonie	Secrétaire de la section française de l'Assemblée Parlementaire de la Francophonie	95007C	MEMBRE	\N	\N
2513	SFAPF	\N	2014-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre du bureau de la section française de l'Assemblée Parlementaire de la Francophonie	Membre du bureau de la section française de l'Assemblée Parlementaire de la Francophonie	95009E	MEMBRE	\N	2014-09-28 12:56:42
2514	SFAPF	\N	2008-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	89021M	MEMBRE	\N	\N
2515	SFAPF	\N	2004-09-30 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	78007E	MEMBRE	\N	\N
5582	PROS	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19647E	MEMBRE	2017-10-18 16:01:49	\N
2516	SFAPF	\N	2007-07-04 00:00:00	ANCIEN	\N	Membre de la section française de l'Assemblée Parlementaire 	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	Membre de la section française de l'Assemblée Parlementaire de la Francophonie	71003U	MEMBRE	\N	\N
3968	RENSEIGNEMEN	2012-10-23 00:00:00	2014-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	08058D	MEMBRE	\N	2014-12-09 17:05:06
4008	206	2013-02-27 00:00:00	2013-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	11077T	MEMBRE	\N	2013-10-04 14:27:21
4009	DSOM	2013-02-27 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01022K	MEMBRE	\N	\N
1014	DELCONEUR	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	 Conseil de l'Europe (délégué titulaire)/ Union de l'Europe occidentale (délégué titulaire)/	59540Q	TITULAIRE	\N	2015-10-08 16:12:20
4028	211	2013-09-13 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11029K	MEMBRE	2013-09-13 16:55:49	\N
4048	206	2013-10-03 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11089X	MEMBRE	2013-10-04 14:27:34	\N
4068	PROS	2013-10-08 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08042U	MEMBRE	\N	2013-10-08 18:24:18
4091	COLTER	2013-10-15 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	MEMBRE	2013-10-15 10:36:36	2013-10-15 10:37:17
4408	206	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14209N	MEMBRE	2014-10-29 17:00:31	2017-10-01 10:34:22
4409	206	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	08069G	MEMBRE	2014-10-29 17:00:44	2017-10-17 09:38:29
4410	206	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	04061F	MEMBRE	2014-10-29 17:00:51	2017-10-17 09:38:31
4411	206	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	08039A	MEMBRE	2014-10-29 17:00:58	2017-10-17 09:38:33
4412	206	2014-10-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01048V	MEMBRE	2014-10-29 17:01:15	2017-10-18 16:31:06
4413	206	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	04043D	MEMBRE	2014-10-29 17:01:24	2017-10-17 09:38:19
4414	206	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	01058X	MEMBRE	2014-10-29 17:01:33	2017-10-17 09:38:14
4415	206	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11036J	MEMBRE	2014-10-29 17:01:41	2017-09-24 18:16:52
4416	206	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11068S	MEMBRE	2014-10-29 17:01:48	2017-09-24 18:05:41
4417	206	2014-10-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80013X	MEMBRE	2014-10-29 17:01:54	2017-10-18 16:31:26
4418	206	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11089X	MEMBRE	2014-10-29 17:02:02	2017-09-24 17:15:15
4419	206	2014-10-29 00:00:00	2016-03-08 00:00:00	ANCIEN	\N	\N	\N	\N	83042R	MEMBRE	2014-10-29 17:02:10	2016-03-15 15:59:26
4420	206	2014-10-29 00:00:00	2016-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	MEMBRE	2014-10-29 17:02:18	2016-03-15 17:20:27
4421	206	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11082Q	MEMBRE	2014-10-29 17:02:24	2017-09-24 19:16:18
4422	206	2014-10-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14221J	MEMBRE	2014-10-29 17:02:32	2017-10-18 16:32:00
4423	206	2014-10-29 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	07026Q	MEMBRE	2014-10-29 17:02:40	2015-02-23 15:04:07
4424	206	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	MEMBRE	2014-10-29 17:02:47	2017-09-24 13:44:49
4425	206	2014-10-29 00:00:00	2016-04-28 00:00:00	ANCIEN	\N	\N	\N	\N	01044R	MEMBRE	2014-10-29 17:02:57	2016-04-29 16:27:53
4426	206	\N	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	58914W	MEMBRE	2014-10-29 00:00:00	2014-10-29 00:00:00
4648	ENTREPRISES	2015-01-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14265W	MEMBRE	2015-01-13 12:01:31	2017-10-18 16:21:13
4808	206	2015-02-20 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	14263U	MEMBRE	2015-02-23 15:04:33	2017-06-19 16:04:13
4908	APUPM	2014-11-04 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08042U	MEMBRE	2015-08-25 15:10:09	2017-10-01 10:20:50
4928	CONEUR	2015-09-16 00:00:00	2015-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	08056B	MEMBRE	2015-09-16 15:50:28	2017-10-19 18:15:59
5148	UIP	2015-11-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	14281W	MEMBRE	2015-11-30 17:14:51	\N
5149	UIP	2015-11-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14093U	MEMBRE	2015-11-30 17:14:58	\N
5150	UIP	2015-11-30 00:00:00	2017-11-07 00:00:00	ANCIEN	\N	\N	\N	\N	14267Y	MEMBRE	2015-11-30 17:15:08	2017-11-14 11:41:29
5168	211	2015-12-08 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	14265W	MEMBRE	2015-12-09 10:31:52	2017-10-17 09:39:30
5288	SFAPF	2016-04-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	14071N	MEMBRE	2016-04-21 12:03:43	\N
5488	206	2017-07-12 00:00:00	2022-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	18003S	MEMBRE	2017-07-12 18:08:58	\N
5548	RENSEIGNEMEN	2017-07-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04042C	MEMBRE	2017-07-17 00:00:00	\N
4511	ENTREPRISES	2014-11-26 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	14207L	MEMBRE	2014-11-26 13:28:15	2017-10-17 09:40:57
4513	ENTREPRISES	2014-11-26 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	11110B	MEMBRE	2014-11-26 13:28:29	2017-10-17 09:40:59
4522	ENTREPRISES	2014-11-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14034U	MEMBRE	2014-11-26 13:29:28	2017-10-18 16:24:33
4501	ENTREPRISES	2014-11-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14253S	MEMBRE	2014-11-26 13:27:15	2017-10-18 16:21:19
4548	ENTREPRISES	2014-12-03 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	MEMBRE	2014-12-08 11:43:49	2017-10-17 09:41:03
5568	PROS	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19515S	MEMBRE	2017-10-18 15:57:06	\N
5577	PROS	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14147R	MEMBRE	2017-10-18 16:00:29	\N
5570	PROS	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19667J	MEMBRE	2017-10-18 15:57:37	\N
5571	PROS	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19467C	MEMBRE	2017-10-18 15:57:50	\N
5572	PROS	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11115U	MEMBRE	2017-10-18 15:58:04	\N
5573	PROS	2017-10-18 00:00:00	2020-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	08041T	MEMBRE	2017-10-18 15:58:36	\N
5574	PROS	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08069G	MEMBRE	2017-10-18 15:58:51	\N
5575	PROS	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19399H	MEMBRE	2017-10-18 15:59:03	\N
5576	PROS	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19711U	MEMBRE	2017-10-18 15:59:48	\N
5578	PROS	2017-10-18 00:00:00	2020-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	17637T	MEMBRE	2017-10-18 16:00:45	\N
5579	PROS	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19421M	MEMBRE	2017-10-18 16:00:56	\N
5580	PROS	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11097X	MEMBRE	2017-10-18 16:01:10	\N
5581	PROS	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08024S	MEMBRE	2017-10-18 16:01:24	\N
7256	COLTER	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14327T	MEMBRE	\N	\N
5583	PROS	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19551W	MEMBRE	2017-10-18 16:02:52	\N
5584	PROS	2017-10-18 00:00:00	2017-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	01007L	MEMBRE	2017-10-18 16:04:19	2017-11-03 10:47:39
5585	PROS	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19569H	MEMBRE	2017-10-18 16:04:40	\N
5586	PROS	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19369B	MEMBRE	2017-10-18 16:04:58	\N
5587	PROS	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19479G	MEMBRE	2017-10-18 16:05:23	\N
5588	PROS	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19737F	MEMBRE	2017-10-18 16:05:40	\N
5589	PROS	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19651A	MEMBRE	2017-10-18 16:05:57	\N
5590	PROS	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19349W	MEMBRE	2017-10-18 16:06:34	\N
5591	PROS	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19629C	MEMBRE	2017-10-18 16:06:58	\N
5592	PROS	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11065P	MEMBRE	2017-10-18 16:07:32	\N
5593	PROS	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89017R	MEMBRE	2017-10-18 16:08:42	\N
5594	211	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14115H	MEMBRE	2017-10-18 16:10:37	\N
5595	211	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19367Y	MEMBRE	2017-10-18 16:10:50	\N
5596	211	2017-10-18 00:00:00	2017-10-23 00:00:00	ANCIEN	\N	\N	\N	\N	19415P	MEMBRE	2017-10-18 16:11:00	2017-10-24 11:24:44
5597	211	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19643A	MEMBRE	2017-10-18 16:11:11	\N
5598	211	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	18083K	MEMBRE	2017-10-18 16:11:37	\N
5599	211	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19701S	MEMBRE	2017-10-18 16:11:50	\N
5600	211	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19693L	MEMBRE	2017-10-18 16:12:02	\N
5601	211	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14249W	MEMBRE	2017-10-18 16:12:26	\N
5602	211	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19673G	MEMBRE	2017-10-18 16:12:50	\N
5603	211	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19657G	MEMBRE	2017-10-18 16:13:25	\N
5604	211	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19679N	MEMBRE	2017-10-18 16:13:44	\N
5605	211	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19599P	MEMBRE	2017-10-18 16:14:58	\N
5606	211	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19715Y	MEMBRE	2017-10-18 16:15:11	\N
5607	211	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19577H	MEMBRE	2017-10-18 16:16:20	\N
5608	211	2017-10-18 00:00:00	2018-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	14042U	MEMBRE	2017-10-18 16:16:35	2018-02-06 18:53:04
5609	211	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14179A	MEMBRE	2017-10-18 16:16:51	\N
5610	211	2017-10-18 00:00:00	2019-03-13 00:00:00	ANCIEN	\N	\N	\N	\N	19697Q	MEMBRE	2017-10-18 16:18:17	\N
5611	211	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19269X	MEMBRE	2017-10-18 16:18:30	\N
5612	211	2017-10-18 00:00:00	2019-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	19563B	MEMBRE	2017-10-18 16:19:15	\N
5613	ENTREPRISES	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19575F	MEMBRE	2017-10-18 16:19:31	\N
5614	ENTREPRISES	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14053L	MEMBRE	2017-10-18 16:19:44	\N
5615	211	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14235Q	MEMBRE	2017-10-18 16:19:49	\N
5616	ENTREPRISES	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14329V	MEMBRE	2017-10-18 16:19:50	\N
5617	211	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14251Q	MEMBRE	2017-10-18 16:20:03	\N
5618	ENTREPRISES	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14187A	MEMBRE	2017-10-18 16:20:05	\N
5619	ENTREPRISES	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14026U	MEMBRE	2017-10-18 16:20:15	\N
5620	211	2017-10-18 00:00:00	2018-01-29 00:00:00	ANCIEN	\N	\N	\N	\N	19685L	MEMBRE	2017-10-18 16:20:17	2018-02-01 20:26:59
5621	ENTREPRISES	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08015R	MEMBRE	2017-10-18 16:20:46	\N
5622	ENTREPRISES	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19671E	MEMBRE	2017-10-18 16:20:58	\N
5623	ENTREPRISES	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08047A	MEMBRE	2017-10-18 16:21:25	\N
5624	ENTREPRISES	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04088S	MEMBRE	2017-10-18 16:21:46	\N
5625	ENTREPRISES	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08060W	MEMBRE	2017-10-18 16:22:02	\N
5626	ENTREPRISES	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19591F	MEMBRE	2017-10-18 16:22:23	\N
4468	SFAPF	2014-11-18 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	11091R	MEMBRE	2014-11-18 16:23:03	2015-02-13 16:06:20
4588	MECSS	2014-12-10 00:00:00	2017-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	14151M	MEMBRE	2014-12-10 16:24:51	2017-11-28 10:07:56
4589	MECSS	2014-12-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11055M	MEMBRE	2014-12-10 16:25:47	2017-09-24 18:07:57
4593	MECSS	2014-12-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	12042Y	MEMBRE	2014-12-10 16:30:39	2017-09-24 19:31:54
4592	MECSS	2014-12-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11044J	MEMBRE	2014-12-10 16:28:52	2017-09-24 17:29:37
4594	MECSS	2014-12-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11061K	MEMBRE	2014-12-10 16:31:04	2017-09-24 17:42:25
4628	COMITEDEONTO	2014-11-04 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	MEMBRE	2015-01-12 19:00:49	\N
4596	MECSS	2014-12-10 00:00:00	2017-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	14071N	MEMBRE	2014-12-10 16:32:00	2017-11-28 10:08:01
4597	MECSS	2014-12-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11093T	MEMBRE	2014-12-10 16:32:10	2017-09-24 12:57:09
4629	COMITEDEONTO	2014-11-04 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08022Q	MEMBRE	2015-01-12 19:00:59	2017-10-01 09:41:22
4630	COMITEDEONTO	2014-11-05 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	MEMBRE	2015-01-12 19:01:04	2015-10-13 14:17:21
4631	COMITEDEONTO	2014-11-04 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	MEMBRE	2015-01-12 19:01:11	2017-06-19 12:20:59
4632	COMITEDEONTO	2014-11-04 00:00:00	2017-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	11067R	MEMBRE	2015-01-12 19:01:18	2017-11-09 14:47:40
4633	COMITEDEONTO	2014-11-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04074L	MEMBRE	2015-01-12 19:01:26	2017-09-24 17:15:15
4634	COMITEDEONTO	2014-11-04 00:00:00	2017-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	04043D	MEMBRE	2015-01-12 19:01:33	2017-11-09 14:47:45
4635	COMITEDEONTO	2014-11-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	MEMBRE	2015-01-12 19:01:39	2015-01-13 16:17:44
4636	COMITEDEONTO	2014-11-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11094U	MEMBRE	2015-01-12 19:01:45	2017-09-24 13:25:54
4638	COMITEDEONTO	2014-11-04 00:00:00	2017-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	11083R	MEMBRE	2015-01-12 19:01:57	2017-11-09 14:47:36
4748	SFAPF	2015-02-13 00:00:00	2018-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	04059M	MEMBRE	2015-02-13 16:09:07	2018-01-09 14:21:23
5029	DELCONEUR	2015-10-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14249W	MEMBRE	2015-10-08 14:47:42	\N
4750	SFAPF	2015-02-13 00:00:00	2017-11-13 00:00:00	ANCIEN	\N	\N	\N	\N	04040A	MEMBRE	2015-02-13 16:09:24	2017-11-14 14:41:13
4751	SFAPF	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	77002U	MEMBRE	2015-02-13 16:09:53	2017-09-24 18:59:59
4752	SFAPF	2015-02-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	08028W	MEMBRE	2015-02-13 16:10:04	\N
4753	SFAPF	2015-02-13 00:00:00	2018-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	11056N	MEMBRE	2015-02-13 16:10:18	2018-01-09 14:21:47
4756	SFAPF	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04067M	MEMBRE	2015-02-13 16:10:45	2017-09-24 17:47:27
4757	SFAPF	2015-02-13 00:00:00	2016-04-14 00:00:00	ANCIEN	\N	\N	\N	\N	11091R	MEMBRE	2015-02-13 16:10:55	2016-04-21 12:13:50
4759	SFAPF	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01041N	MEMBRE	2015-02-13 16:11:06	2017-09-24 18:59:59
4760	SFAPF	2015-02-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11074Q	MEMBRE	2015-02-13 00:00:00	\N
4762	SFAPF	2015-02-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	97011G	MEMBRE	2015-02-13 00:00:00	\N
4763	SFAPF	2015-02-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	08018U	MEMBRE	2015-02-13 16:11:29	\N
4764	SFAPF	2015-02-13 00:00:00	2023-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	04035D	MEMBRE	2015-02-13 16:11:35	\N
4765	SFAPF	2015-02-13 00:00:00	2015-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	11108H	MEMBRE	2015-02-13 16:11:39	2015-04-07 16:50:27
4766	SFAPF	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11015D	MEMBRE	2015-02-13 16:11:49	2017-09-24 13:42:35
4767	SFAPF	2015-02-13 00:00:00	2018-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	11064N	MEMBRE	2015-02-13 16:12:01	2018-01-09 14:22:40
4768	SFAPF	2015-02-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	14179A	MEMBRE	2015-02-13 16:12:11	\N
4769	SFAPF	2015-02-13 00:00:00	2018-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	08044W	MEMBRE	2015-02-13 16:12:21	2018-01-09 14:23:05
4770	SFAPF	2015-02-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14241N	MEMBRE	2015-02-13 16:12:27	\N
4771	SFAPF	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04036E	MEMBRE	2015-02-13 16:12:36	2017-09-24 18:59:59
4772	SFAPF	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04094Q	MEMBRE	2015-02-13 16:12:47	2017-09-25 10:58:49
4773	SFAPF	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92031P	MEMBRE	2015-02-13 16:12:53	2017-09-24 18:16:52
4774	SFAPF	2015-02-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	08034U	MEMBRE	2015-02-13 16:12:57	\N
4775	SFAPF	2015-02-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08039A	MEMBRE	2015-02-13 16:13:01	\N
4776	SFAPF	2015-02-13 00:00:00	2017-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	14037X	MEMBRE	2015-02-13 16:13:04	2017-07-24 09:58:00
4777	SFAPF	2015-02-13 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08017T	MEMBRE	2015-02-13 16:13:08	\N
4778	SFAPF	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01061S	MEMBRE	2015-02-13 16:13:15	2017-09-24 17:48:21
4782	SFAPF	2015-02-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	04070G	MEMBRE	2015-02-13 16:14:08	\N
4781	SFAPF	2015-02-13 00:00:00	2018-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	08009T	MEMBRE	2015-02-13 16:13:49	2018-01-09 14:24:10
4783	SFAPF	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11105E	MEMBRE	2015-02-13 16:14:19	2017-09-24 18:20:10
4784	SFAPF	2015-02-13 00:00:00	2023-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	14237S	MEMBRE	2015-02-13 16:14:25	\N
4785	SFAPF	2015-02-13 00:00:00	2018-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	14028W	MEMBRE	2015-02-13 16:14:32	2018-01-09 14:24:51
4786	SFAPF	2015-02-13 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	11069T	MEMBRE	2015-02-13 16:14:38	2016-03-11 18:02:50
4787	SFAPF	2015-02-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04043D	MEMBRE	2015-02-13 00:00:00	\N
4788	SFAPF	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	MEMBRE	2015-02-13 16:14:56	2017-09-24 17:09:24
4789	SFAPF	2015-02-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	10015M	MEMBRE	2015-02-13 16:15:05	\N
4790	SFAPF	2015-02-13 00:00:00	2018-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	11012A	MEMBRE	2015-02-13 16:15:09	2018-01-09 14:25:18
4792	SFAPF	2015-02-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	MEMBRE	2015-02-13 00:00:00	\N
4793	SFAPF	2015-02-13 00:00:00	2018-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	98035U	MEMBRE	2015-02-13 16:15:28	2018-01-09 14:25:36
4794	SFAPF	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04056J	MEMBRE	2015-02-13 16:15:32	2017-09-24 18:17:56
4795	SFAPF	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92044U	MEMBRE	2015-02-13 16:15:38	2017-09-24 18:16:52
4796	SFAPF	2015-02-13 00:00:00	2018-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	14157T	MEMBRE	2015-02-13 16:15:42	2018-01-09 14:25:40
4797	SFAPF	2015-02-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	MEMBRE	2015-02-13 16:15:48	\N
4798	SFAPF	2015-02-13 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	MEMBRE	2015-02-13 16:15:53	\N
4828	UIP	2015-02-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	MEMBRE	2015-02-25 16:03:13	2017-09-24 18:20:10
4829	UIP	2015-02-25 00:00:00	2017-11-07 00:00:00	ANCIEN	\N	\N	\N	\N	14239U	MEMBRE	2015-02-25 16:05:17	2017-11-14 11:40:44
4830	UIP	2015-02-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11068S	MEMBRE	2015-02-25 16:05:22	2017-09-24 18:05:41
4831	UIP	2015-02-25 00:00:00	2017-11-07 00:00:00	ANCIEN	\N	\N	\N	\N	04042C	MEMBRE	2015-02-25 16:06:01	2017-11-14 11:41:13
4832	UIP	2015-02-25 00:00:00	2018-08-06 00:00:00	ANCIEN	\N	\N	\N	\N	95015C	MEMBRE	2015-02-25 16:06:07	\N
4833	UIP	2015-02-25 00:00:00	2017-11-07 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	MEMBRE	2015-02-25 16:06:22	2017-11-14 11:41:33
4834	UIP	2015-02-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92018S	MEMBRE	2015-02-25 16:06:54	2017-09-24 18:16:52
4835	UIP	2015-02-25 00:00:00	2015-02-27 00:00:00	ANCIEN	\N	\N	\N	\N	14263U	MEMBRE	2015-02-25 16:06:58	2015-02-27 14:21:27
4837	UIP	2015-02-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92020L	MEMBRE	2015-02-25 16:07:48	2017-09-24 12:39:59
4838	UIP	2015-02-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11084S	MEMBRE	2015-02-25 16:09:01	2017-09-24 19:25:10
4839	UIP	2015-02-25 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	92040Q	MEMBRE	2015-02-25 16:10:01	\N
4868	PROS	2015-05-20 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	98018T	MEMBRE	2015-05-20 17:54:48	2017-10-17 09:40:16
4968	PROS	2015-09-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	MEMBRE	2015-09-24 09:51:06	2017-09-24 17:29:37
5028	DELCONEUR	2015-10-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08043V	MEMBRE	2015-10-08 14:47:23	\N
5030	DELCONEUR	2015-10-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92020L	MEMBRE	2015-10-08 14:47:53	2017-09-24 12:39:59
5031	DELCONEUR	2015-10-08 00:00:00	2018-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	08056B	MEMBRE	2015-10-08 14:48:08	\N
5032	DELCONEUR	2015-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	97011G	MEMBRE	2015-10-08 00:00:00	\N
5033	DELCONEUR	2015-10-08 00:00:00	2020-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	11049P	MEMBRE	2015-10-08 14:48:29	\N
5034	DELCONEUR	2015-10-08 00:00:00	2017-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	14065Q	MEMBRE	2015-10-08 14:48:45	2017-11-07 18:31:53
5035	DELCONEUR	2015-10-08 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	01037S	MEMBRE	2015-10-08 14:49:56	2016-12-12 16:10:15
5036	DELCONEUR	2015-10-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14061L	MEMBRE	2015-10-08 14:50:13	\N
5037	DELCONEUR	2015-10-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92031P	MEMBRE	2015-10-08 14:50:43	2017-09-24 18:16:52
5038	DELCONEUR	2015-10-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04080J	MEMBRE	2015-10-08 14:50:57	2017-09-24 17:47:27
5039	DELCONEUR	2015-10-08 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	10015M	MEMBRE	2015-10-08 14:51:12	\N
5129	211	2015-11-17 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	14281W	MEMBRE	2015-11-17 21:41:41	2017-10-17 09:39:28
5188	COMITEDEONTO	2015-12-18 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	07034Q	MEMBRE	2015-12-18 10:06:14	\N
5408	COLTER	2016-11-22 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14069U	MEMBRE	2016-11-22 16:43:22	2017-10-18 16:25:50
4208	211	2014-07-09 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11027H	MEMBRE	2014-07-09 11:17:14	\N
4488	ENTREPRISES	2014-11-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14105F	MEMBRE	2014-11-26 13:25:47	2017-10-18 16:19:38
4489	ENTREPRISES	2014-11-26 00:00:00	2014-12-02 00:00:00	ANCIEN	\N	\N	\N	\N	08028W	MEMBRE	2014-11-26 13:25:53	2014-12-08 11:43:42
4490	ENTREPRISES	2014-11-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14079W	MEMBRE	2014-11-26 13:25:58	2017-10-18 16:19:55
4491	ENTREPRISES	2014-11-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04055H	MEMBRE	2014-11-26 13:26:04	2017-09-24 18:05:41
4492	ENTREPRISES	2014-11-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11088W	MEMBRE	2014-11-26 13:26:09	2017-09-24 17:15:15
4493	ENTREPRISES	2014-11-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	MEMBRE	2014-11-26 13:26:15	2017-10-18 16:20:00
4495	ENTREPRISES	2014-11-26 00:00:00	2014-12-27 00:00:00	ANCIEN	\N	\N	\N	\N	14129P	MEMBRE	2014-11-26 13:26:26	2014-12-29 15:40:09
4496	ENTREPRISES	2014-11-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14087W	MEMBRE	2014-11-26 13:26:30	2017-10-18 16:20:11
4497	ENTREPRISES	2014-11-26 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	02002K	MEMBRE	2014-11-26 13:26:36	2017-10-17 09:41:00
4498	ENTREPRISES	2014-11-26 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	95041E	MEMBRE	2014-11-26 13:26:42	2017-10-17 09:40:53
4499	ENTREPRISES	2014-11-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14061L	MEMBRE	2014-11-26 13:26:55	2017-10-18 16:20:21
4502	ENTREPRISES	2014-11-26 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	11090Q	MEMBRE	2014-11-26 13:27:21	2017-10-17 09:40:53
4503	ENTREPRISES	2014-11-26 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	10015M	MEMBRE	2014-11-26 13:27:27	2017-10-17 09:41:03
4504	ENTREPRISES	2014-11-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14157T	MEMBRE	2014-11-26 13:27:34	2017-10-18 16:21:53
4505	ENTREPRISES	2014-11-26 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14137P	MEMBRE	2014-11-26 13:27:41	2015-06-12 15:59:18
4506	ENTREPRISES	2014-11-26 00:00:00	2016-01-04 00:00:00	ANCIEN	\N	\N	\N	\N	08055A	MEMBRE	2014-11-26 13:27:46	2016-01-05 11:34:09
4507	ENTREPRISES	2014-11-26 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	14065Q	MEMBRE	2014-11-26 13:27:52	2017-10-17 09:40:56
4508	ENTREPRISES	2014-11-26 00:00:00	2016-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	08014Q	MEMBRE	2014-11-26 13:27:58	2016-01-27 16:39:45
4509	ENTREPRISES	2014-11-26 00:00:00	2020-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	08068F	MEMBRE	2014-11-26 13:28:03	2017-10-18 16:22:07
4510	ENTREPRISES	2014-11-26 00:00:00	2017-08-06 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	MEMBRE	2014-11-26 13:28:09	2017-08-07 16:31:39
4512	ENTREPRISES	2014-11-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14151M	MEMBRE	2014-11-26 13:28:22	2017-10-18 16:22:15
4514	ENTREPRISES	2014-11-26 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	11061K	MEMBRE	2014-11-26 13:28:35	2015-06-23 09:37:29
4516	ENTREPRISES	2014-11-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14039A	MEMBRE	2014-11-26 13:28:49	2017-10-18 16:24:05
4517	ENTREPRISES	2014-11-26 00:00:00	2016-01-04 00:00:00	ANCIEN	\N	\N	\N	\N	04077P	MEMBRE	2014-11-26 13:28:55	2016-01-05 11:34:16
4518	ENTREPRISES	2014-11-26 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	11077T	MEMBRE	2014-11-26 13:29:00	2017-10-17 09:40:55
4519	ENTREPRISES	2014-11-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14030Q	MEMBRE	2014-11-26 13:29:06	2017-10-18 16:23:15
4520	ENTREPRISES	2014-11-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14255U	MEMBRE	2014-11-26 13:29:12	2017-10-18 16:23:19
4521	ENTREPRISES	2014-11-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14083S	MEMBRE	2014-11-26 13:29:19	2017-10-18 16:23:27
4523	ENTREPRISES	2014-11-26 00:00:00	2016-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	01043Q	MEMBRE	2014-11-26 13:29:36	2016-07-05 09:50:11
4524	ENTREPRISES	2014-11-26 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	14013P	MEMBRE	2014-11-26 13:29:45	2017-06-19 16:06:01
4527	ENTREPRISES	2014-11-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14018U	MEMBRE	2014-11-26 13:30:05	2017-09-24 18:49:56
4528	ENTREPRISES	2014-11-26 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	11069T	MEMBRE	2014-11-26 13:30:14	2016-03-11 18:02:50
4529	ENTREPRISES	2014-11-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89017R	MEMBRE	2014-11-26 13:30:20	2017-10-18 16:24:52
4688	UIP	2015-02-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	86034E	MEMBRE	2015-02-13 00:00:00	\N
4689	SFAPF	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	MEMBRE	2015-02-13 15:50:22	2017-09-24 18:20:10
4690	UIP	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11076S	MEMBRE	2015-02-13 15:50:51	2017-09-24 17:47:28
4691	UIP	2015-02-13 00:00:00	2015-02-25 00:00:00	ANCIEN	\N	\N	\N	\N	11109J	MEMBRE	2015-02-13 15:51:00	2015-02-25 16:04:41
4692	SFAPF	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11068S	MEMBRE	2015-02-13 15:51:27	2017-09-24 18:05:41
4693	UIP	2015-02-13 00:00:00	2017-11-07 00:00:00	ANCIEN	\N	\N	\N	\N	14065Q	MEMBRE	2015-02-13 15:51:31	2017-12-06 16:54:25
4694	UIP	2015-02-13 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	14030Q	MEMBRE	2015-02-13 15:51:35	\N
4695	UIP	2015-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04054G	MEMBRE	2015-02-13 15:51:39	2017-09-24 17:18:03
4696	UIP	\N	2020-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	96004D	MEMBRE	2015-02-13 15:51:42	2016-06-30 11:51:10
4697	UIP	2015-02-13 00:00:00	2017-11-07 00:00:00	ANCIEN	\N	\N	\N	\N	11040E	MEMBRE	2015-02-13 15:51:47	2017-11-14 11:40:58
4698	UIP	2015-02-13 00:00:00	2015-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	MEMBRE	2015-02-13 15:51:56	2015-11-30 17:14:40
4699	SFAPF	2015-02-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04042C	MEMBRE	2015-02-13 00:00:00	2015-02-13 00:00:00
4700	SFAPF	2015-02-13 00:00:00	2018-08-06 00:00:00	ANCIEN	\N	\N	\N	\N	95015C	MEMBRE	2015-02-13 15:52:11	2015-02-13 16:09:58
4701	UIP	2015-02-13 00:00:00	2017-07-28 00:00:00	ANCIEN	\N	\N	\N	\N	11032E	MEMBRE	2015-02-13 15:52:14	2017-08-03 11:38:41
4702	UIP	2015-02-13 00:00:00	2017-11-07 00:00:00	ANCIEN	\N	\N	\N	\N	11080N	MEMBRE	2015-02-13 15:52:20	2017-11-14 11:41:28
4704	UIP	2015-02-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08038Y	MEMBRE	2015-02-13 15:52:46	\N
4705	UIP	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04081K	MEMBRE	2015-02-13 15:52:50	2017-09-24 19:25:10
4706	UIP	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11035H	MEMBRE	2015-02-13 15:52:55	2017-09-24 18:16:52
4707	UIP	\N	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98018T	MEMBRE	2015-02-13 15:53:04	2015-05-20 17:55:46
4708	SFAPF	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92018S	MEMBRE	2015-02-13 15:53:09	2017-09-24 18:16:52
4710	SFAPF	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92020L	MEMBRE	2015-02-13 15:53:27	2017-09-24 12:39:59
4711	UIP	2015-02-13 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	04035D	MEMBRE	2015-02-13 15:53:40	\N
4712	UIP	2015-02-13 00:00:00	2016-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	07024N	MEMBRE	2015-02-13 15:53:47	2017-01-03 11:09:24
4713	UIP	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11061K	MEMBRE	2015-02-13 15:53:50	2017-09-24 17:42:25
4714	UIP	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11089X	MEMBRE	2015-02-13 15:54:03	2017-09-24 17:15:15
4715	UIP	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	95035G	MEMBRE	2015-02-13 15:54:13	2017-09-24 18:17:56
4716	UIP	2015-02-13 00:00:00	2017-11-07 00:00:00	ANCIEN	\N	\N	\N	\N	08056B	MEMBRE	2015-02-13 15:54:17	2017-11-14 11:41:58
4717	UIP	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04078Q	MEMBRE	2015-02-13 15:54:31	2017-09-24 17:15:15
4718	UIP	2015-02-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	14097Y	MEMBRE	2015-02-13 15:54:40	2017-11-14 11:44:49
4719	UIP	2015-02-13 00:00:00	2017-11-07 00:00:00	ANCIEN	\N	\N	\N	\N	95041E	MEMBRE	2015-02-13 15:54:47	2017-11-14 11:42:04
4720	SFAPF	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11084S	MEMBRE	2015-02-13 15:54:53	2017-09-24 19:25:10
4721	UIP	2015-02-13 00:00:00	2017-11-07 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	MEMBRE	2015-02-13 15:55:02	2017-11-14 11:42:08
4722	UIP	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92031P	MEMBRE	2015-02-13 15:55:11	2017-09-24 18:16:52
4723	UIP	2015-02-13 00:00:00	2017-11-07 00:00:00	ANCIEN	\N	\N	\N	\N	14205J	MEMBRE	2015-02-13 15:55:18	2017-11-14 11:42:11
4724	UIP	2015-02-13 00:00:00	2017-11-07 00:00:00	ANCIEN	\N	\N	\N	\N	14251Q	MEMBRE	2015-02-13 15:55:28	2017-11-14 11:42:13
4725	UIP	2015-02-13 00:00:00	\N	ACTIF	\N	\N	\N	\N	14001X	MEMBRE	2015-02-13 15:55:34	\N
4726	UIP	\N	\N	ACTIF	\N	\N	\N	\N	08009T	MEMBRE	2015-02-13 15:55:45	2015-10-08 15:57:42
4727	UIP	\N	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	98032R	MEMBRE	2015-02-13 15:55:56	2015-06-12 15:59:49
4728	SFAPF	2015-02-13 00:00:00	2018-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	92040Q	MEMBRE	2015-02-13 15:56:03	2018-01-09 14:24:40
4729	UIP	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04080J	MEMBRE	2015-02-13 15:56:19	2017-09-24 17:47:27
4730	UIP	2015-02-13 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	11090Q	MEMBRE	2015-02-13 15:56:23	\N
4731	UIP	2015-02-13 00:00:00	2017-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	95059Q	MEMBRE	2015-02-13 15:56:30	2017-10-05 09:36:37
4732	UIP	2015-02-13 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86044G	MEMBRE	2015-02-13 15:56:34	2017-10-01 10:32:58
4733	UIP	2015-02-13 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	14225N	MEMBRE	2015-02-13 15:56:38	\N
4734	UIP	2015-02-13 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	04045F	MEMBRE	2015-02-13 15:56:47	\N
4735	UIP	\N	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	MEMBRE	2015-02-13 00:00:00	2015-06-16 00:00:00
4848	DSOM	2015-05-04 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14277B	MEMBREDRT	2015-05-05 16:30:42	2017-10-18 16:41:23
4849	DSOM	2015-05-04 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14275Y	MEMBREDRT	2015-05-05 16:31:21	2017-10-18 16:42:04
4108	DSOM	2014-04-08 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11077T	MEMBRE	2014-02-21 11:14:13	2014-04-09 16:52:36
4128	COLTER	2014-05-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08064B	MEMBRE	2014-05-07 09:40:20	2014-09-28 19:03:23
4168	COMITEDEONTO	2014-05-21 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	11083R	MEMBRE	2014-05-22 10:58:21	2015-01-12 18:27:49
4895	206	2015-07-01 00:00:00	2022-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	14299H	MEMBRE	2015-07-01 18:11:13	\N
4948	ACMN	2014-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	97011G	MEMBRE	2015-09-16 00:00:00	\N
4949	APM	2014-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14209N	MEMBRE	2015-09-16 23:41:31	2017-10-01 10:34:22
4950	APM	2014-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98035U	MEMBRE	2015-09-16 23:41:41	\N
4988	DSOM	2015-09-28 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14259Y	MEMBRE	2015-09-28 09:39:25	2017-10-18 16:24:26
5048	OTAN	2015-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92018S	MEMBRE	2015-10-15 18:03:08	2017-09-24 18:16:52
5049	OTAN	2015-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11054L	MEMBRE	2015-10-15 00:00:00	\N
5050	OTAN	2015-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04054G	MEMBRE	2015-10-15 18:06:07	2017-09-24 17:18:03
5051	OTAN	2015-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11027H	MEMBRE	2015-10-15 00:00:00	\N
5268	206	2016-03-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11061K	MEMBRE	2016-03-15 15:53:10	2017-09-24 17:42:25
5053	OTAN	2015-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	95035G	MEMBRE	2015-10-15 18:07:05	2017-09-24 18:17:56
5054	OTAN	2015-10-15 00:00:00	2017-11-07 00:00:00	ANCIEN	\N	\N	\N	\N	11064N	MEMBRE	2015-10-15 18:07:18	2017-11-14 11:35:39
5055	OTAN	2015-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04077P	MEMBRE	2015-10-15 18:07:30	2017-09-24 17:47:27
5056	OTAN	2015-10-15 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	08047A	MEMBRE	2015-10-15 18:07:43	\N
5128	RENSEIGNEMEN	2015-11-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	04047H	MEMBRE	2015-11-17 15:27:56	\N
5228	211	2016-01-19 00:00:00	2017-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	04041B	MEMBRE	2016-01-19 10:42:39	2017-09-24 11:09:53
5269	206	2016-03-10 00:00:00	2017-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	14257W	MEMBRE	2016-03-15 15:53:45	2017-11-28 15:53:47
5348	CSCE	2016-06-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	14133K	MEMBRE	2016-06-30 11:52:27	\N
5328	206	2016-04-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	13002U	MEMBRE	2016-04-29 16:28:05	2017-09-24 17:42:26
5349	CSCE	2016-06-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11105E	MEMBRE	2016-06-30 11:52:44	2017-09-24 18:20:10
5350	CSCE	2016-06-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11015D	MEMBRE	2016-06-30 11:52:59	2017-09-24 13:42:36
5368	ENTREPRISES	2016-07-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14205J	MEMBRE	2016-07-05 09:41:25	2017-10-18 16:23:58
5448	COMITEDEONTO	2017-06-30 00:00:00	2017-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	19253P	MEMBRE	2017-06-30 09:52:24	2017-11-09 14:47:31
5468	COLTER	2017-07-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19253P	MEMBRE	2017-07-11 09:58:44	2017-10-18 16:28:36
4316	COLTER	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11035H	MEMBRE	2014-10-29 12:32:57	2017-09-24 18:16:52
5528	206	2017-07-12 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	14235Q	MEMBRE	2017-07-12 22:11:20	2017-10-17 09:38:42
4237	211	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04036E	MEMBRE	2014-10-29 12:16:35	2017-09-24 18:59:59
4246	211	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	12042Y	MEMBRE	2014-10-29 12:18:05	2017-09-24 19:31:54
4233	211	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	04035D	MEMBRE	2014-10-29 12:15:58	2017-10-17 09:39:18
4241	211	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	14237S	MEMBRE	2014-10-29 12:17:12	2017-10-17 09:39:21
4254	211	2014-10-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14030Q	MEMBRE	2014-10-29 12:18:53	2017-10-18 16:16:08
4230	211	2014-10-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14217N	MEMBRE	2014-10-29 12:15:02	2017-10-18 16:12:11
4256	211	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	08056B	MEMBRE	2014-10-29 12:19:09	2017-10-19 18:16:25
4253	211	2014-10-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14109K	MEMBRE	2014-10-29 12:18:46	2017-10-18 16:15:37
4326	COLTER	2014-10-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04040A	MEMBRE	2014-10-29 12:35:18	2017-10-18 16:27:52
4333	COLTER	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	11099A	MEMBRE	2014-10-29 12:36:58	2017-10-17 09:39:46
4301	COLTER	2014-10-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	MEMBRE	2014-10-29 12:31:25	2017-10-18 16:26:02
4327	COLTER	2014-10-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14231L	MEMBRE	2014-10-29 12:35:24	2017-10-18 16:28:04
4309	COLTER	2014-10-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92040Q	MEMBRE	2014-10-29 12:32:14	2017-10-18 16:26:54
4324	COLTER	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	14051J	MEMBRE	2014-10-29 12:35:03	2017-10-17 09:39:54
4317	COLTER	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	11074Q	MEMBRE	2014-10-29 12:33:04	2017-10-17 09:39:55
7257	COLTER	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14231L	MEMBRE	\N	\N
4271	PROS	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	02002K	MEMBRE	2014-10-29 12:23:30	2017-10-17 09:40:08
4288	PROS	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	11066Q	MEMBRE	2014-10-29 12:27:34	2017-10-17 09:40:09
4277	PROS	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	08062Y	MEMBRE	2014-10-29 12:25:06	2017-10-17 09:40:10
4296	PROS	2014-10-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	MEMBRE	2014-10-29 12:28:41	2017-10-18 16:07:46
4289	PROS	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	14179A	MEMBRE	2014-10-29 12:27:43	2017-10-17 09:40:14
4228	211	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	14259Y	MEMBRE	2014-10-29 12:14:47	2017-10-17 09:39:22
4229	211	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	MEMBRE	2014-10-29 12:14:54	2017-10-17 09:39:23
4231	211	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	14187A	MEMBRE	2014-10-29 12:15:33	2017-10-17 09:39:27
4232	211	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	02002K	MEMBRE	2014-10-29 12:15:50	2017-10-17 09:39:27
4234	211	2014-10-29 00:00:00	2015-12-08 00:00:00	ANCIEN	\N	\N	\N	\N	08041T	MEMBRE	2014-10-29 12:16:07	2015-12-09 10:32:07
4235	211	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	95035G	MEMBRE	2014-10-29 12:16:13	2017-09-24 18:17:56
4236	211	2014-10-29 00:00:00	2016-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	08069G	MEMBRE	2014-10-29 12:16:25	2016-02-08 10:46:36
4238	211	2014-10-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	07029T	MEMBRE	2014-10-29 12:16:42	2017-10-18 16:13:14
4239	211	2014-10-29 00:00:00	2016-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	14059S	MEMBRE	2014-10-29 12:16:51	2016-01-19 10:43:00
4240	211	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	08047A	MEMBRE	2014-10-29 12:17:07	2017-10-17 09:39:31
4242	211	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	08043V	MEMBRE	2014-10-29 12:17:20	2017-10-17 09:39:24
4243	211	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	08060W	MEMBRE	2014-10-29 12:17:24	2017-10-17 09:39:25
4244	211	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	11027H	MEMBRE	2014-10-29 12:17:32	2017-10-17 09:39:16
4245	211	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	80013X	MEMBRE	2014-10-29 12:17:37	2017-10-17 09:39:17
4247	211	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11061K	MEMBRE	2014-10-29 12:18:11	2017-09-24 17:42:25
4248	211	2014-10-29 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	14014Q	MEMBRE	2014-10-29 12:18:18	2017-06-19 16:06:51
4249	211	2014-10-29 00:00:00	2015-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	01011G	MEMBRE	2014-10-29 12:18:24	2015-11-17 21:42:15
4250	211	2014-10-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08017T	MEMBRE	2014-10-29 12:18:28	2017-10-18 16:15:24
4251	211	2014-10-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11067R	MEMBRE	2014-10-29 12:18:35	2017-10-17 09:39:20
4252	211	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11014C	MEMBRE	2014-10-29 12:18:42	2017-09-24 13:14:55
4255	211	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98042T	MEMBRE	2014-10-29 12:19:02	2017-10-01 10:39:22
4257	211	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	09001P	MEMBRE	2014-10-29 12:19:15	2017-09-24 17:47:27
4258	211	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	11031D	MEMBRE	2014-10-29 12:19:46	2017-10-17 09:39:26
4259	211	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	07026Q	MEMBRE	2014-10-29 12:19:51	2017-09-24 19:25:10
4260	211	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	08031R	MEMBRE	2014-10-29 12:19:58	2017-10-17 09:39:19
4261	211	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11029K	MEMBRE	2014-10-29 12:20:07	2017-09-24 17:09:24
4262	211	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	14241N	MEMBRE	2014-10-29 12:20:13	2017-10-17 09:39:29
4263	PROS	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01008M	MEMBRE	2014-10-29 12:22:36	2017-09-24 13:44:49
4264	PROS	2014-10-29 00:00:00	2015-05-20 00:00:00	ANCIEN	\N	\N	\N	\N	11060J	MEMBRE	2014-10-29 12:22:41	2015-05-20 17:52:24
4265	PROS	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	11080N	MEMBRE	2014-10-29 12:22:49	2017-10-17 09:40:12
4266	PROS	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	08028W	MEMBRE	2014-10-29 12:22:55	2017-10-17 09:40:12
4267	PROS	2014-10-29 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	95020Y	MEMBRE	2014-10-29 12:23:01	2015-06-12 16:01:25
4268	PROS	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11088W	MEMBRE	2014-10-29 12:23:12	2017-09-24 17:15:15
4269	PROS	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01041N	MEMBRE	2014-10-29 12:23:17	2017-09-24 18:59:59
4270	PROS	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	14187A	MEMBRE	2014-10-29 12:23:23	2017-10-17 09:40:13
4272	PROS	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	08048B	MEMBRE	2014-10-29 12:23:37	2017-10-17 09:40:14
4273	PROS	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	14026U	MEMBRE	2014-10-29 12:23:44	2017-10-17 09:40:09
4274	PROS	2014-10-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	99004R	MEMBRE	2014-10-29 12:23:52	2017-10-18 15:59:15
4275	PROS	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	04061F	MEMBRE	2014-10-29 12:24:54	2017-10-17 09:40:08
4276	PROS	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01061S	MEMBRE	2014-10-29 12:25:00	2017-09-24 17:48:21
4278	PROS	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	08060W	MEMBRE	2014-10-29 12:25:15	2017-10-17 09:40:11
4279	PROS	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11089X	MEMBRE	2014-10-29 12:25:20	2017-09-24 17:15:15
4280	PROS	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	14121F	MEMBRE	2014-10-29 12:25:29	2017-10-17 09:40:14
4281	PROS	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11084S	MEMBRE	2014-10-29 12:25:35	2017-09-24 19:25:10
4282	PROS	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	08012N	MEMBRE	2014-10-29 12:25:42	2017-10-17 09:40:10
4284	PROS	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	14229S	MEMBRE	2014-10-29 12:25:58	2017-10-17 09:40:08
4285	PROS	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11046L	MEMBRE	2014-10-29 12:26:05	2017-09-24 17:29:37
4286	PROS	2014-10-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14107H	MEMBRE	2014-10-29 12:27:22	2017-10-18 16:03:29
4287	PROS	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	MEMBRE	2014-10-29 12:27:28	2017-10-17 09:40:16
4290	PROS	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	14103D	MEMBRE	2014-10-29 12:27:50	2017-10-17 09:40:15
4291	PROS	2014-10-29 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	98032R	MEMBRE	2014-10-29 12:27:57	2015-06-12 15:59:49
4292	PROS	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11094U	MEMBRE	2014-10-29 12:28:03	2017-09-24 13:25:54
4293	PROS	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	MEMBRE	2014-10-29 12:28:10	2017-09-24 17:35:15
4294	PROS	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01015L	MEMBRE	2014-10-29 12:28:19	2017-09-24 17:19:42
4295	PROS	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	88008L	MEMBRE	2014-10-29 12:28:34	2017-10-17 09:40:07
4297	PROS	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11029K	MEMBRE	2014-10-29 12:28:48	2017-09-24 17:09:24
4298	PROS	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	08021P	MEMBRE	2014-10-29 12:28:55	2017-10-17 09:40:15
4299	COLTER	2014-10-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11101A	MEMBRE	2014-10-29 12:31:14	2017-10-18 16:25:56
4300	COLTER	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11044J	MEMBRE	2014-10-29 12:31:20	2017-09-24 17:29:37
4302	COLTER	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01027Q	MEMBRE	2014-10-29 12:31:31	2017-09-24 17:28:55
4303	COLTER	2014-10-29 00:00:00	2020-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	11049P	MEMBRE	2014-10-29 12:31:36	2017-10-18 16:26:18
4304	COLTER	2014-10-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01057W	MEMBRE	2014-10-29 12:31:42	2017-10-18 16:26:25
4305	COLTER	2014-10-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	MEMBRE	2014-10-29 12:31:48	2017-10-18 16:26:30
4306	COLTER	2014-10-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08010L	MEMBRE	2014-10-29 12:31:54	2017-10-18 16:26:36
4307	COLTER	2014-10-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08034U	MEMBRE	2014-10-29 12:32:00	2017-10-18 16:26:42
4308	COLTER	2014-10-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14071N	MEMBRE	2014-10-29 12:32:06	2017-10-18 16:26:49
4310	COLTER	2014-10-29 00:00:00	2016-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	07032N	MEMBRE	2014-10-29 12:32:20	2016-11-18 12:37:49
4311	COLTER	2014-10-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	05012A	MEMBRE	2014-10-29 12:32:28	2017-10-18 16:26:59
4312	COLTER	2014-10-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	MEMBRE	2014-10-29 12:32:33	2017-10-18 16:27:04
4313	COLTER	2014-10-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	MEMBRE	2014-10-29 12:32:38	2017-10-18 16:27:09
4314	COLTER	2014-10-29 00:00:00	2017-07-28 00:00:00	ANCIEN	\N	\N	\N	\N	11032E	MEMBRE	2014-10-29 12:32:45	2017-08-03 11:38:41
4315	COLTER	2014-10-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08038Y	MEMBRE	2014-10-29 12:32:50	2017-10-18 16:27:18
4318	COLTER	2014-10-29 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	14014Q	MEMBRE	2014-10-29 12:33:11	2017-06-19 16:06:51
4319	COLTER	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11112D	MEMBRE	2014-10-29 12:33:18	2017-09-24 16:45:26
4320	COLTER	2014-10-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14063N	MEMBRE	2014-10-29 12:33:24	2017-10-18 16:27:37
4321	COLTER	2014-10-29 00:00:00	2019-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	14028W	MEMBRE	2014-10-29 12:33:32	2017-10-18 16:27:47
4322	COLTER	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	MEMBRE	2014-10-29 12:34:49	2017-10-17 09:39:54
4323	COLTER	2014-10-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04045F	MEMBRE	2014-10-29 12:34:56	2017-10-18 16:28:31
4325	COLTER	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11037K	MEMBRE	2014-10-29 12:35:10	2017-09-24 18:16:52
4328	COLTER	2014-10-29 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	98027U	MEMBRE	2014-10-29 12:36:20	2015-06-12 16:01:58
4329	COLTER	2014-10-29 00:00:00	2015-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	08009T	MEMBRE	2014-10-29 12:36:28	2015-10-07 11:00:33
4330	COLTER	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11034G	MEMBRE	2014-10-29 12:36:35	2017-09-24 17:55:12
4331	COLTER	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11098Y	MEMBRE	2014-10-29 12:36:43	2017-09-24 17:14:26
4332	COLTER	2014-10-29 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	MEMBRE	2014-10-29 12:36:50	2017-06-19 12:20:59
4188	DSOM	2014-07-03 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14017T	MEMBRE	2014-07-03 15:21:31	\N
4334	COLTER	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	01060R	MEMBRE	2014-10-29 12:37:03	2017-10-17 09:39:53
4335	DSOM	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	14093U	MEMBRE	2014-10-29 12:37:56	2017-10-17 09:40:30
4336	DSOM	2014-10-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	96004D	MEMBRE	2014-10-29 12:38:06	2017-10-18 16:24:04
4337	DSOM	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	14053L	MEMBRE	2014-10-29 12:38:12	2017-10-17 09:40:33
4338	DSOM	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01027Q	MEMBRE	2014-10-29 12:38:18	2017-09-24 17:28:55
4339	DSOM	2014-10-29 00:00:00	2015-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	02002K	MEMBRE	2014-10-29 12:38:23	2015-11-03 17:06:46
4340	DSOM	2014-10-29 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	08065C	MEMBRE	2014-10-29 12:38:32	2017-09-25 09:57:52
4341	DSOM	2014-10-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14033T	MEMBRE	2014-10-29 12:38:40	2017-10-18 16:24:48
4342	DSOM	2014-10-29 00:00:00	2015-09-28 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	MEMBRE	2014-10-29 12:38:45	2015-09-28 09:39:18
4343	DSOM	2014-10-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14059S	MEMBRE	2014-10-29 12:38:51	2017-10-18 16:25:08
4344	DSOM	2014-10-29 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95062K	MEMBRE	2014-10-29 12:38:57	2017-10-18 16:26:03
4345	DSOM	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01022K	MEMBRE	2014-10-29 12:39:03	2017-09-24 17:14:26
4346	DSOM	2014-10-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14097Y	MEMBRE	2014-10-29 12:39:10	2017-10-18 16:27:16
4347	DSOM	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11106F	MEMBRE	2014-10-29 12:39:18	2017-09-24 19:14:37
4429	CONEUR	2014-10-29 00:00:00	2015-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	14249W	MEMBRE	2014-10-29 19:32:59	2015-10-08 14:53:29
4368	DSOM	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	11054L	MEMBRE	2014-10-29 12:46:19	2017-10-17 09:40:31
4369	DSOM	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	14034U	MEMBRE	2014-10-29 12:46:26	2017-10-17 09:40:35
4370	DSOM	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	11064N	MEMBRE	2014-10-29 12:46:35	2017-10-17 09:40:29
4371	DSOM	2014-10-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14219Q	MEMBRE	2014-10-29 12:46:44	2017-10-18 16:28:14
4372	DSOM	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	MEMBRE	2014-10-29 12:46:51	2017-10-17 09:40:28
7258	COLTER	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19735D	MEMBRE	\N	\N
4373	DSOM	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	14201E	MEMBRE	2014-10-29 12:46:59	2017-10-17 09:40:34
4374	DSOM	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11055M	MEMBRE	2014-10-29 12:47:06	2017-09-24 18:07:57
4375	DSOM	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	14055N	MEMBRE	2014-10-29 12:47:12	2017-10-17 09:40:38
4376	DSOM	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	11109J	MEMBRE	2014-10-29 12:47:22	2017-10-17 09:40:32
4377	DSOM	2014-10-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14261S	MEMBREDRT	2014-10-29 12:47:34	2017-10-18 16:39:41
4378	DSOM	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11023D	MEMBRE	2014-10-29 12:47:47	2017-09-25 10:56:48
4379	DSOM	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11114F	MEMBRE	2014-10-29 12:47:59	2017-09-25 10:54:33
4380	DSOM	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11113E	MEMBRE	2014-10-29 12:48:08	2017-09-25 10:54:33
4381	DSOM	2014-10-29 00:00:00	2015-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	14043V	MEMBRE	2014-10-29 12:48:23	2015-02-06 14:27:55
4382	DSOM	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11020A	MEMBRE	2014-10-29 12:48:34	2017-09-24 16:24:51
4383	DSOM	2014-10-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11010L	MEMBREDRT	2014-10-29 12:48:45	2017-10-18 16:40:17
4384	DSOM	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04095R	MEMBRE	2014-10-29 12:48:56	2017-09-25 10:54:33
4385	DSOM	2014-10-29 00:00:00	2015-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	14044W	MEMBRE	2014-10-29 12:49:08	2015-02-06 14:32:44
4386	DSOM	2014-10-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14039A	MEMBREDRT	2014-10-29 12:49:20	2017-10-18 16:40:53
4387	DSOM	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04094Q	MEMBRE	2014-10-29 12:49:30	2017-09-25 10:58:49
4388	DSOM	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	98005N	MEMBRE	2014-10-29 12:49:44	2017-10-17 09:40:31
4389	DSOM	2014-10-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08019V	MEMBREDRT	2014-10-29 12:49:53	2017-10-18 16:41:25
4390	DSOM	2014-10-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11072N	MEMBREDRT	2014-10-29 12:50:07	2017-10-18 16:41:26
4391	DSOM	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11071M	MEMBRE	2014-10-29 12:50:25	2017-09-24 18:16:33
4392	DSOM	2014-10-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08073C	MEMBREDRT	2014-10-29 12:50:35	2017-10-18 17:57:00
4393	DSOM	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14017T	MEMBRE	2014-10-29 12:50:45	2017-09-24 16:24:51
4394	DSOM	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11011M	MEMBRE	2014-10-29 12:51:01	2017-09-24 10:41:28
4395	DSOM	2014-10-29 00:00:00	2016-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	96003C	MEMBRE	2014-10-29 12:51:10	2016-11-14 11:07:47
4396	DSOM	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11025F	MEMBRE	2014-10-29 12:51:18	2017-09-24 16:24:51
4428	CONEUR	2014-10-29 00:00:00	2015-09-16 00:00:00	ANCIEN	\N	\N	\N	\N	04040A	MEMBRE	2014-10-29 19:32:44	2015-09-16 15:50:22
4430	CONEUR	2014-10-29 00:00:00	2015-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	92020L	MEMBRE	2014-10-29 19:33:10	2015-10-08 14:53:31
4431	CONEUR	2014-10-29 00:00:00	2015-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	97011G	MEMBRE	2014-10-29 19:33:22	2015-10-08 14:53:32
4432	CONEUR	2014-10-29 00:00:00	2015-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	11049P	MEMBRE	2014-10-29 19:33:38	2015-10-08 14:53:35
4433	CONEUR	2014-10-29 00:00:00	2014-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	01062T	MEMBRE	2014-10-29 19:33:48	2014-12-18 16:15:04
4434	CONEUR	2014-10-29 00:00:00	2015-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	08043V	MEMBRE	2014-10-29 19:34:05	2015-10-08 14:53:28
4435	CONEUR	2014-10-29 00:00:00	2015-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	01037S	MEMBRE	2014-10-29 19:34:11	2015-10-08 14:53:38
4436	CONEUR	2014-10-29 00:00:00	2015-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	14061L	MEMBRE	2014-10-29 19:34:18	2015-10-08 14:53:39
4437	CONEUR	2014-10-29 00:00:00	2015-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	92031P	MEMBRE	2014-10-29 19:34:25	2015-10-08 14:53:41
4438	CONEUR	2014-10-29 00:00:00	2015-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	04080J	MEMBRE	2014-10-29 19:34:33	2015-10-08 14:53:42
4439	CONEUR	2014-10-29 00:00:00	2015-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	10015M	MEMBRE	2014-10-29 19:34:41	2015-10-08 14:53:43
4448	211	2014-10-29 00:00:00	2016-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	11091R	MEMBRE	2014-10-30 10:08:56	2016-01-12 18:23:53
4568	RENSEIGNEMEN	2014-12-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	MEMBRE	2014-12-09 17:05:13	\N
4569	RENSEIGNEMEN	2014-12-09 00:00:00	2017-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	95059Q	MEMBRE	2014-12-09 17:05:35	2017-07-17 17:40:37
4570	RENSEIGNEMEN	2014-12-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08058D	MEMBRE	2014-12-09 17:05:52	\N
4668	CONEUR	2015-02-03 00:00:00	2015-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	14065Q	MEMBRE	2015-02-04 15:36:14	2015-10-08 14:53:36
5008	COLTER	2015-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14327T	MEMBRE	2015-10-07 11:00:47	2017-10-18 16:27:58
5009	COLTER	2015-10-07 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	14034U	MEMBRE	2015-10-07 11:01:00	2017-10-17 09:39:51
5068	OTAN	2015-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04035D	MEMBRE	2015-10-16 00:00:00	\N
5069	OTAN	2015-10-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98021N	MEMBRE	2015-10-16 11:10:29	2017-10-01 09:22:38
5070	OTAN	2015-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01014K	MEMBRE	2015-10-16 11:10:38	2017-09-24 17:19:42
5071	OTAN	2015-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01056V	MEMBRE	2015-10-16 11:10:49	2017-09-24 17:04:02
5088	PROS	2015-10-21 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	14089Y	MEMBRE	2015-10-21 10:24:58	2017-10-17 09:40:11
5108	DSOM	2015-10-14 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	04043D	MEMBRE	2015-11-03 17:06:52	2017-10-17 09:40:38
5208	211	2016-01-12 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	14031R	MEMBRE	2016-01-12 18:24:02	2017-10-17 09:39:30
5248	211	2016-02-08 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	14038Y	MEMBRE	2016-02-08 10:46:47	2017-10-17 09:39:25
5388	DSOM	2016-11-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	05001W	MEMBRE	2016-11-16 18:41:45	2017-09-24 16:24:51
4283	PROS	2014-10-29 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	14257W	MEMBRE	2014-10-29 12:25:48	2017-10-17 09:40:15
4500	ENTREPRISES	2014-11-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	MEMBRE	2014-11-26 13:27:01	2017-10-18 16:20:26
4494	ENTREPRISES	2014-11-26 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	04071H	MEMBRE	2014-11-26 13:26:20	2017-10-17 09:40:52
4525	ENTREPRISES	2014-11-26 00:00:00	2017-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	11063M	MEMBRE	2014-11-26 13:29:51	2017-10-17 09:40:54
4526	ENTREPRISES	2014-11-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14261S	MEMBRE	2014-11-26 13:29:58	2017-10-18 16:24:25
5808	PROS	2017-11-21 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19713W	MEMBRE	2017-11-21 18:25:57	\N
6088	MECSS	2018-12-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19760E	MEMBRE	\N	\N
6148	COMITEDEONTO	2019-06-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19667J	MEMBRE	\N	\N
6188	PROS	2019-10-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19741B	MEMBRE	\N	\N
6228	COLTER	2019-12-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19820Y	MEMBRE	\N	\N
6288	ENTREPRISES	2020-06-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19912C	MEMBRE	\N	\N
6308	SFAPF	2020-09-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	05012A	MEMBRE	\N	\N
6628	RENSEIGNEMEN	2020-11-05 00:00:00	2022-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	14299H	MEMBRE	\N	\N
6629	RENSEIGNEMEN	2020-11-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11066Q	MEMBRE	\N	\N
6630	RENSEIGNEMEN	2020-11-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	14053L	MEMBRE	\N	\N
6634	CVFS	2020-11-05 00:00:00	2022-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	14299H	MEMBRE	\N	\N
6632	CVFS	2020-11-05 00:00:00	2021-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	MEMBRE	\N	\N
6633	CVFS	2020-11-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11066Q	MEMBRE	\N	\N
7316	ENTREPRISES	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	21040X	MEMBRE	\N	\N
7335	211	2023-10-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	18193Q	MEMBRE	\N	\N
7352	COMITEDEONTO	2023-10-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	19667J	MEMBRE	\N	\N
7353	COMITEDEONTO	2023-10-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	19725B	MEMBRE	\N	\N
7354	COMITEDEONTO	2023-10-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	11040E	MEMBRE	\N	\N
7355	COMITEDEONTO	2023-10-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	14207L	MEMBRE	\N	\N
7356	COMITEDEONTO	2023-10-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	19545Y	MEMBRE	\N	\N
7357	COMITEDEONTO	2023-10-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	20100N	MEMBRE	\N	\N
7358	COMITEDEONTO	2023-10-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	20172F	MEMBRE	\N	\N
7359	COMITEDEONTO	2023-10-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	20052X	MEMBRE	\N	\N
7360	COMITEDEONTO	2023-10-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	11072N	MEMBRE	\N	\N
7361	RENSEIGNEMEN	2023-10-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	14193X	MEMBRE	\N	\N
7362	RENSEIGNEMEN	2023-10-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	14097Y	MEMBRE	\N	\N
7363	CVFS	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	14097Y	MEMBRE	\N	\N
7368	DSOM	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	21071F	MEMBRE	\N	\N
7369	DSOM	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	19631V	MEMBRE	\N	\N
7370	DSOM	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	05008E	MEMBRE	\N	\N
7371	DSOM	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	21035B	MEMBRE	\N	\N
7372	DSOM	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	21096Q	MEMBRE	\N	\N
7373	DSOM	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	04042C	MEMBRE	\N	\N
7374	DSOM	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	14053L	MEMBRE	\N	\N
7375	DSOM	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	18083K	MEMBRE	\N	\N
7376	DSOM	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	19295A	MEMBRE	\N	\N
7377	DSOM	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	21034A	MEMBRE	\N	\N
7378	DSOM	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	14259Y	MEMBRE	\N	\N
7379	DSOM	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	17229F	MEMBRE	\N	\N
7380	DSOM	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	19673G	MEMBRE	\N	\N
7381	DSOM	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	17023S	MEMBRE	\N	\N
7382	DSOM	2023-11-08 00:00:00	2029-11-27 00:00:00	ACTIF	\N	\N	\N	\N	21033Y	MEMBRE	\N	\N
7383	DSOM	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	21032X	MEMBRE	\N	\N
7384	DSOM	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	19691J	MEMBRE	\N	\N
7385	DSOM	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	20034V	MEMBRE	\N	\N
7386	DSOM	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	14121F	MEMBRE	\N	\N
7387	DSOM	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	20016T	MEMBRE	\N	\N
7388	DSOM	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	08010L	MEMBRE	\N	\N
7389	DSOM	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	14219Q	MEMBRE	\N	\N
7390	DSOM	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	14059S	MEMBRE	\N	\N
7391	DSOM	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	12016W	MEMBRE	\N	\N
7392	DSOM	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	19657G	MEMBRE	\N	\N
7393	DSOM	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	21073H	MEMBRE	\N	\N
7394	DSOM	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	11072N	MEMBRE	\N	\N
7395	DSOM	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	21097R	MEMBRE	\N	\N
7396	DSOM	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	21029D	MEMBRE	\N	\N
7397	DSOM	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	19331L	MEMBRE	\N	\N
7398	DSOM	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	08073C	MEMBRE	\N	\N
7399	DSOM	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	21055F	MEMBRE	\N	\N
7400	DSOM	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	19745F	MEMBRE	\N	\N
7401	DSOM	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	20148F	MEMBRE	\N	\N
7402	DSOM	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	20146D	MEMBRE	\N	\N
7403	DSOM	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	11090Q	MEMBRE	\N	\N
7404	DSOM	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	20150Y	MEMBRE	\N	\N
7405	DSOM	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	19669L	MEMBRE	\N	\N
7406	DSOM	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	14275Y	MEMBRE	\N	\N
7407	DSOM	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	19301E	MEMBRE	\N	\N
7408	DSOM	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	20122U	MEMBRE	\N	\N
7409	DSOM	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	21030V	MEMBRE	\N	\N
7428	COLTER	2023-11-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	20068G	MEMBRE	\N	\N
7528	DELCONEUR	2024-02-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	21043B	MEMBRE	\N	\N
7529	DELCONEUR	2024-02-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	20104S	MEMBRE	\N	\N
7530	DELCONEUR	2024-02-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	19565D	MEMBRE	\N	\N
7531	DELCONEUR	2024-02-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	20042V	MEMBRE	\N	\N
7532	DELCONEUR	2024-02-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	21057H	MEMBRE	\N	\N
7533	DELCONEUR	2024-02-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	21049H	MEMBRE	\N	\N
7535	APUPM	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	95041E	MEMBRE	\N	\N
7536	ACMN	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	19701S	MEMBRE	\N	\N
7618	SFAPF	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	20122U	MEMBRE	\N	\N
7619	SFAPF	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	20266L	MEMBRE	\N	\N
5728	APUPM	2017-11-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	14211G	MEMBRE	2017-11-14 11:32:06	2017-11-14 11:32:25
5729	CSCE	2017-11-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08058D	MEMBRE	2017-11-14 11:34:04	\N
5730	CSCE	2017-11-07 00:00:00	2018-09-20 00:00:00	ANCIEN	\N	\N	\N	\N	07004J	MEMBRE	2017-11-14 11:34:10	\N
5731	CSCE	2017-11-07 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	11012A	MEMBRE	2017-11-14 11:34:16	\N
5732	OTAN	2017-11-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04042C	MEMBRE	2017-11-14 00:00:00	\N
5733	OTAN	2017-11-07 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	98022P	MEMBRE	2017-11-14 11:36:09	\N
7259	COLTER	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14205J	MEMBRE	\N	\N
5734	OTAN	2017-11-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	14193X	MEMBRE	2017-11-14 11:36:20	\N
5735	OTAN	2017-11-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01062T	MEMBRE	2017-11-14 00:00:00	\N
5736	OTAN	2017-11-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	19721W	MEMBRE	2017-11-14 11:36:47	\N
5737	OTAN	2017-11-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	08034U	MEMBRE	2017-11-14 11:37:27	\N
5738	OTAN	2017-11-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19709B	MEMBRE	2017-11-14 00:00:00	\N
5739	OTAN	2017-11-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08049C	MEMBRE	2017-11-14 11:37:57	\N
5744	UIP	2017-11-07 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	14069U	MEMBRE	2017-11-14 11:43:14	\N
5741	OTAN	2017-11-14 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	11041F	MEMBRE	2017-11-14 11:39:32	\N
4836	UIP	2015-02-25 00:00:00	2017-11-07 00:00:00	ANCIEN	\N	\N	\N	\N	10006L	MEMBRE	2015-02-25 16:07:28	2017-11-14 11:41:40
4736	UIP	2015-02-13 00:00:00	2017-11-07 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	MEMBRE	2015-02-13 15:57:01	2017-11-14 11:42:51
5742	UIP	2017-11-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89017R	MEMBRE	2017-11-14 11:43:02	\N
5743	UIP	2017-11-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08055A	MEMBRE	2017-11-14 11:43:07	\N
5745	UIP	2017-11-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	04047H	MEMBRE	2017-11-14 11:43:21	\N
5746	UIP	2017-11-07 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	11101A	MEMBRE	2017-11-14 11:43:28	\N
5747	UIP	2017-11-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08024S	MEMBRE	2017-11-14 11:43:33	\N
5748	UIP	2017-11-07 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	19721W	MEMBRE	2017-11-14 11:43:38	\N
5749	UIP	2017-11-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	88008L	MEMBRE	2017-11-14 11:43:56	\N
5750	UIP	2017-11-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11115U	MEMBRE	2017-11-14 00:00:00	\N
5751	UIP	2017-11-07 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	MEMBRE	2017-11-14 11:44:09	\N
5752	UIP	2017-11-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11065P	MEMBRE	2017-11-14 00:00:00	\N
5753	UIP	2017-11-07 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	07004J	MEMBRE	2017-11-14 11:44:23	\N
5754	UIP	2017-11-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11064N	MEMBRE	2017-11-14 00:00:00	\N
5755	UIP	2017-11-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95037J	MEMBRE	2017-11-14 11:44:37	\N
5756	UIP	2017-11-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19511N	MEMBRE	2017-11-14 00:00:00	\N
5757	UIP	2017-11-07 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	19611R	MEMBRE	2017-11-14 11:44:54	\N
5758	UIP	2017-11-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14159V	MEMBRE	2017-11-14 11:44:59	\N
5759	UIP	2017-11-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98005N	MEMBRE	2017-11-14 11:45:12	\N
5760	UIP	2017-11-07 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	14059S	MEMBRE	2017-11-14 11:45:17	\N
5761	UIP	2017-11-07 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	08012N	MEMBRE	2017-11-14 11:45:27	\N
5762	UIP	2017-11-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19637C	MEMBRE	2017-11-14 00:00:00	\N
5763	UIP	2017-11-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	14147R	MEMBRE	2017-11-14 11:45:38	\N
5764	UIP	2017-11-07 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	19335Q	MEMBRE	2017-11-14 11:45:43	\N
5765	UIP	2017-11-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14265W	MEMBRE	2017-11-14 11:45:49	\N
5766	UIP	2017-11-07 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	19593H	MEMBRE	2017-11-14 11:45:55	\N
5767	UIP	2017-11-07 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	04043D	MEMBRE	2017-11-14 11:46:00	\N
5768	UIP	2017-11-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14235Q	MEMBRE	2017-11-14 11:46:06	\N
5769	UIP	2017-11-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14135M	MEMBRE	2017-11-14 11:46:11	\N
5770	UIP	2017-11-07 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	10015M	MEMBRE	2017-11-14 11:46:16	\N
5771	UIP	2017-11-07 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	19703U	MEMBRE	2017-11-14 11:46:25	\N
5772	UIP	2017-11-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08049C	MEMBRE	2017-11-14 11:46:30	\N
5773	UIP	2017-11-07 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	11066Q	MEMBRE	2017-11-14 11:46:35	\N
5928	211	2018-02-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19749K	MEMBRE	2018-02-06 19:00:24	\N
6208	DSOM	2019-10-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	07033P	MEMBRE	\N	\N
6069	DSOM	2018-12-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14021P	MEMBRE	\N	\N
6108	SFAPF	2019-03-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	12041X	MEMBRE	\N	\N
6111	SFAPF	2019-03-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14265W	MEMBRE	\N	\N
6168	ENTREPRISES	2019-09-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19697Q	MEMBRE	\N	\N
6248	COLTER	2020-01-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	17637T	MEMBRE	\N	\N
6648	SFAPF	2020-12-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19415P	MEMBRE	\N	\N
6649	SFAPF	2020-12-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	17737W	MEMBRE	\N	\N
6650	SFAPF	2020-12-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	12028B	MEMBRE	\N	\N
6651	SFAPF	2020-12-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14357A	MEMBRE	\N	\N
6652	SFAPF	2020-12-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	19719D	MEMBRE	\N	\N
6653	SFAPF	2020-12-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	17229F	MEMBRE	\N	\N
6654	SFAPF	2020-12-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	14187A	MEMBRE	\N	\N
6655	SFAPF	2020-12-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	20132W	MEMBRE	\N	\N
6656	SFAPF	2020-12-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	17023S	MEMBRE	\N	\N
6657	SFAPF	2020-12-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19565D	MEMBRE	\N	\N
6658	SFAPF	2020-12-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19553Y	MEMBRE	\N	\N
6672	SFAPF	2020-12-11 00:00:00	2020-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	19782L	MEMBRE	\N	\N
6660	SFAPF	2020-12-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	08015R	MEMBRE	\N	\N
6661	SFAPF	2020-12-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19711U	MEMBRE	\N	\N
6662	SFAPF	2020-12-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11026G	MEMBRE	\N	\N
6663	SFAPF	2020-12-11 00:00:00	2023-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	20142Y	MEMBRE	\N	\N
6664	SFAPF	2020-12-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04057K	MEMBRE	\N	\N
6665	SFAPF	2020-12-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19593H	MEMBRE	\N	\N
6673	SFAPF	2020-12-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	08073C	MEMBRE	\N	\N
6667	SFAPF	2020-12-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	20130U	MEMBRE	\N	\N
6668	SFAPF	2020-12-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	20098N	MEMBRE	\N	\N
6669	SFAPF	2020-12-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19669L	MEMBRE	\N	\N
6670	SFAPF	2020-12-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19301E	MEMBRE	\N	\N
6671	SFAPF	2020-12-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19527W	MEMBRE	\N	\N
6708	CVFS	2021-01-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	14053L	MEMBRE	\N	\N
6848	ENTREPRISES	2021-10-26 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20108W	MEMBRE	\N	\N
6888	SFAPF	2021-11-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20084G	MEMBRE	\N	\N
7028	CSCE	2022-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20128B	MEMBRE	\N	\N
7088	SFAPF	2023-01-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19954N	MEMBRE	\N	\N
7089	SFAPF	2023-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	20264J	MEMBRE	\N	\N
7090	SFAPF	2023-01-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	20036X	MEMBRE	\N	\N
7185	PROS	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20140W	MEMBRE	\N	\N
7187	PROS	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20068G	MEMBRE	\N	\N
7229	COLTER	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20032T	MEMBRE	\N	\N
7230	COLTER	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20022R	MEMBRE	\N	\N
7231	COLTER	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14069U	MEMBRE	\N	\N
7232	COLTER	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19621T	MEMBRE	\N	\N
7233	COLTER	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20090E	MEMBRE	\N	\N
7234	COLTER	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14053L	MEMBRE	\N	\N
7235	COLTER	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14215L	MEMBRE	\N	\N
7237	COLTER	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20120S	MEMBRE	\N	\N
7238	COLTER	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14026U	MEMBRE	\N	\N
7239	COLTER	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19447X	MEMBRE	\N	\N
7240	COLTER	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19768N	MEMBRE	\N	\N
7241	COLTER	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19573D	MEMBRE	\N	\N
7242	COLTER	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	05012A	MEMBRE	\N	\N
7243	COLTER	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	21068L	MEMBRE	\N	\N
7244	COLTER	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20062A	MEMBRE	\N	\N
7245	COLTER	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20058E	MEMBRE	\N	\N
7246	COLTER	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14173T	MEMBRE	\N	\N
7247	COLTER	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20070A	MEMBRE	\N	\N
7248	COLTER	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14151M	MEMBRE	\N	\N
7249	COLTER	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14281W	MEMBRE	\N	\N
7250	COLTER	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19820Y	MEMBRE	\N	\N
5988	CSCE	2018-09-21 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	08056B	MEMBRE	\N	\N
6028	DELCONEUR	2018-10-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	16685X	MEMBRE	\N	\N
6048	COLTER	2018-11-21 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	MEMBRE	\N	\N
6688	MECSS	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19760E	MEMBRE	\N	\N
6689	MECSS	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11103C	MEMBRE	\N	\N
6690	MECSS	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	14195A	MEMBRE	\N	\N
6691	MECSS	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	10006L	MEMBRE	\N	\N
6692	MECSS	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14042U	MEMBRE	\N	\N
6693	MECSS	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19553Y	MEMBRE	\N	\N
6694	MECSS	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	14026U	MEMBRE	\N	\N
6695	MECSS	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	14213J	MEMBRE	\N	\N
6699	MECSS	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19697Q	MEMBRE	\N	\N
6697	MECSS	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19683J	MEMBRE	\N	\N
6698	MECSS	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	18193Q	MEMBRE	\N	\N
6700	MECSS	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	17779H	MEMBRE	\N	\N
6701	MECSS	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	04092N	MEMBRE	\N	\N
6702	MECSS	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	14071N	MEMBRE	\N	\N
6703	MECSS	2020-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	20130U	MEMBRE	\N	\N
6704	MECSS	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11097X	MEMBRE	\N	\N
6705	MECSS	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01034P	MEMBRE	\N	\N
6706	PROS	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19703U	MEMBRE	\N	\N
6748	206	2021-02-09 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14221J	MEMBRE	\N	\N
7128	SFAPF	2023-05-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	MEMBRE	\N	\N
7149	PROS	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20024T	MEMBRE	\N	\N
7150	PROS	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20086J	MEMBRE	\N	\N
7151	PROS	2023-10-17 00:00:00	2023-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19747H	MEMBRE	\N	\N
7152	PROS	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	21063F	MEMBRE	\N	\N
7448	COLTER	2023-11-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	21079P	MEMBRE	\N	\N
7155	PROS	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19399H	MEMBRE	\N	\N
7156	PROS	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	99004R	MEMBRE	\N	\N
7157	PROS	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19711U	MEMBRE	\N	\N
7158	PROS	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14169X	MEMBRE	\N	\N
7159	PROS	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19798U	MEMBRE	\N	\N
7160	PROS	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20044X	MEMBRE	\N	\N
7161	PROS	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19703U	MEMBRE	\N	\N
7162	PROS	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20026V	MEMBRE	\N	\N
7163	PROS	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20060X	MEMBRE	\N	\N
7164	PROS	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	21057H	MEMBRE	\N	\N
7165	PROS	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20018V	MEMBRE	\N	\N
7166	PROS	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	21060C	MEMBRE	\N	\N
7167	PROS	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20082E	MEMBRE	\N	\N
7168	PROS	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	21056G	MEMBRE	\N	\N
7169	PROS	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20042V	MEMBRE	\N	\N
7170	PROS	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	21083K	MEMBRE	\N	\N
7171	PROS	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	11070L	MEMBRE	\N	\N
7172	PROS	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20286Q	MEMBRE	\N	\N
7173	PROS	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20066E	MEMBRE	\N	\N
7174	PROS	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19479G	MEMBRE	\N	\N
7175	PROS	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20106U	MEMBRE	\N	\N
7177	PROS	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19349W	MEMBRE	\N	\N
7178	PROS	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	21084L	MEMBRE	\N	\N
7180	PROS	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	11056N	MEMBRE	\N	\N
7182	PROS	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	21054E	MEMBRE	\N	\N
7184	PROS	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20050V	MEMBRE	\N	\N
7186	PROS	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	21093M	MEMBRE	\N	\N
7188	PROS	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20266L	MEMBRE	\N	\N
7190	PROS	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	21041Y	MEMBRE	\N	\N
7192	PROS	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20132W	MEMBRE	\N	\N
7251	COLTER	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19531S	MEMBRE	\N	\N
7252	COLTER	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19489J	MEMBRE	\N	\N
7253	COLTER	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	08012N	MEMBRE	\N	\N
7254	COLTER	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14257W	MEMBRE	\N	\N
7255	COLTER	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20084G	MEMBRE	\N	\N
7260	COLTER	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19826F	MEMBRE	\N	\N
7261	COLTER	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19335Q	MEMBRE	\N	\N
7262	COLTER	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	01034P	MEMBRE	\N	\N
7263	COLTER	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19782L	MEMBRE	\N	\N
7264	COLTER	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19349W	MEMBRE	\N	\N
7265	COLTER	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	04045F	MEMBRE	\N	\N
7266	COLTER	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19758L	MEMBRE	\N	\N
7267	COLTER	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20102Q	MEMBRE	\N	\N
7268	COLTER	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	21065H	MEMBRE	\N	\N
7269	COLTER	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	21070E	MEMBRE	\N	\N
7271	COLTER	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	21048G	MEMBRE	\N	\N
7272	COLTER	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19866P	MEMBRE	\N	\N
7273	COLTER	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14107H	MEMBRE	\N	\N
7274	COLTER	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	21085M	MEMBRE	\N	\N
7317	206	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19667J	MEMBRE	\N	\N
7318	206	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19575F	MEMBRE	\N	\N
7319	206	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20138D	MEMBRE	\N	\N
7320	206	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14038Y	MEMBRE	\N	\N
7321	206	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19723Y	MEMBRE	\N	\N
7322	206	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19533U	MEMBRE	\N	\N
7323	206	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	01058X	MEMBRE	\N	\N
7324	206	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	18231D	MEMBRE	\N	\N
7325	206	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	21059K	MEMBRE	\N	\N
7326	206	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	21082J	MEMBRE	\N	\N
7327	206	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19569H	MEMBRE	\N	\N
7328	206	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19735D	MEMBRE	\N	\N
7329	206	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14205J	MEMBRE	\N	\N
7330	206	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20128B	MEMBRE	\N	\N
7331	206	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19593H	MEMBRE	\N	\N
7332	206	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14221J	MEMBRE	\N	\N
7333	206	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20092G	MEMBRE	\N	\N
7334	206	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20072C	MEMBRE	\N	\N
7508	PROS	2024-02-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	21081H	MEMBRE	\N	\N
7534	CSCE	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	14097Y	MEMBRE	\N	\N
7546	UIP	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	20116W	MEMBRE	\N	\N
7547	UIP	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	20094J	MEMBRE	\N	\N
7548	UIP	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	14069U	MEMBRE	\N	\N
7549	UIP	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	19782L	MEMBRE	\N	\N
7550	UIP	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	14255U	MEMBRE	\N	\N
7551	UIP	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	14053L	MEMBRE	\N	\N
7552	UIP	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	19057M	MEMBRE	\N	\N
7553	UIP	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	11115U	MEMBRE	\N	\N
7554	UIP	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	14357A	MEMBRE	\N	\N
7555	UIP	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	11065P	MEMBRE	\N	\N
7556	UIP	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	19693L	MEMBRE	\N	\N
7557	UIP	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	20074E	MEMBRE	\N	\N
7558	UIP	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	20172F	MEMBRE	\N	\N
7559	UIP	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	21032X	MEMBRE	\N	\N
7560	UIP	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	08056B	MEMBRE	\N	\N
7561	UIP	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	19565D	MEMBRE	\N	\N
7562	UIP	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	19591F	MEMBRE	\N	\N
7563	UIP	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	20034V	MEMBRE	\N	\N
7564	UIP	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	19683J	MEMBRE	\N	\N
7565	UIP	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	20126Y	MEMBRE	\N	\N
7566	UIP	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	14031R	MEMBRE	\N	\N
7567	UIP	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	21075K	MEMBRE	\N	\N
7568	UIP	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	20252E	MEMBRE	\N	\N
7569	UIP	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	14257W	MEMBRE	\N	\N
7570	UIP	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	21037D	MEMBRE	\N	\N
7571	UIP	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	14237S	MEMBRE	\N	\N
7572	UIP	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	20148F	MEMBRE	\N	\N
7573	UIP	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	14225N	MEMBRE	\N	\N
7574	UIP	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	10015M	MEMBRE	\N	\N
7575	UIP	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	21056G	MEMBRE	\N	\N
7576	UIP	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	21064G	MEMBRE	\N	\N
7577	UIP	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	20122U	MEMBRE	\N	\N
7578	UIP	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	21030V	MEMBRE	\N	\N
7579	UIP	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	21077M	MEMBRE	\N	\N
7580	SFAPF	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	20024T	MEMBRE	\N	\N
7581	SFAPF	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	19954N	MEMBRE	\N	\N
7582	SFAPF	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	21046E	MEMBRE	\N	\N
7583	SFAPF	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	20114U	MEMBRE	\N	\N
7584	SFAPF	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	19782L	MEMBRE	\N	\N
7585	SFAPF	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	20104S	MEMBRE	\N	\N
7586	SFAPF	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	04042C	MEMBRE	\N	\N
7587	SFAPF	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	18083K	MEMBRE	\N	\N
7588	SFAPF	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	19701S	MEMBRE	\N	\N
7589	SFAPF	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	11027H	MEMBRE	\N	\N
7590	SFAPF	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	11115U	MEMBRE	\N	\N
5688	211	2017-10-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19621T	MEMBRE	2017-10-24 11:25:41	\N
5848	UIP	2017-11-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19549D	MEMBRE	2017-12-06 00:00:00	\N
6008	206	2018-10-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19693L	MEMBRE	\N	\N
6249	PROS	2020-01-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08048B	MEMBRE	\N	\N
4703	SFAPF	2015-02-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	MEMBRE	2015-02-13 15:52:28	2015-02-13 16:10:12
6568	UIP	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	19575F	MEMBRE	\N	\N
6569	UIP	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	17367Q	MEMBRE	\N	\N
6570	UIP	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11040E	MEMBRE	\N	\N
6571	UIP	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19701S	MEMBRE	\N	\N
6572	UIP	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11027H	MEMBRE	\N	\N
6573	UIP	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14357A	MEMBRE	\N	\N
6574	UIP	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04008A	MEMBRE	\N	\N
6575	UIP	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	17229F	MEMBRE	\N	\N
6576	UIP	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	07033P	MEMBRE	\N	\N
6577	UIP	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	17023S	MEMBRE	\N	\N
6578	UIP	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	08018U	MEMBRE	\N	\N
6579	UIP	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	20120S	MEMBRE	\N	\N
6580	UIP	2020-10-28 00:00:00	2021-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	19387D	MEMBRE	\N	\N
6581	UIP	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19565D	MEMBRE	\N	\N
6582	UIP	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	20068G	MEMBRE	\N	\N
6583	UIP	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	14179A	MEMBRE	\N	\N
6584	UIP	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	20048C	MEMBRE	\N	\N
6585	UIP	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19591F	MEMBRE	\N	\N
6586	UIP	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11099A	MEMBRE	\N	\N
6587	UIP	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	08015R	MEMBRE	\N	\N
6588	UIP	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	18193Q	MEMBRE	\N	\N
6589	UIP	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	08010L	MEMBRE	\N	\N
6590	UIP	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	20052X	MEMBRE	\N	\N
6591	UIP	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19441R	MEMBRE	\N	\N
6592	UIP	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	14221J	MEMBRE	\N	\N
6593	UIP	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	20018V	MEMBRE	\N	\N
6594	UIP	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	14169X	MEMBRE	\N	\N
6595	UIP	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	20146D	MEMBRE	\N	\N
6596	UIP	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19503N	MEMBRE	\N	\N
6597	UIP	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	14055N	MEMBRE	\N	\N
6598	UIP	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19766L	MEMBRE	\N	\N
6599	UIP	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11012A	MEMBRE	\N	\N
6600	UIP	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	19798U	MEMBRE	\N	\N
6601	UIP	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	20084G	MEMBRE	\N	\N
6603	DELCONEUR	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11101A	MEMBRE	\N	\N
6604	DELCONEUR	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	04092N	MEMBRE	\N	\N
6605	DELCONEUR	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	20022R	MEMBRE	\N	\N
6606	DELCONEUR	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	08056B	MEMBRE	\N	\N
6607	DELCONEUR	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	20126Y	MEMBRE	\N	\N
6608	DELCONEUR	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	14001X	MEMBRE	\N	\N
6609	DELCONEUR	2020-10-28 00:00:00	2020-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	19265T	MEMBRE	\N	\N
6610	OTAN	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	17023S	MEMBRE	\N	\N
6611	OTAN	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	19782L	MEMBRE	\N	\N
6612	OTAN	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19525U	MEMBRE	\N	\N
6613	OTAN	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19766L	MEMBRE	\N	\N
6614	OTAN	2020-10-28 00:00:00	2020-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	19265T	MEMBRE	\N	\N
6615	CSCE	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	17737W	MEMBRE	\N	\N
6616	CSCE	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	17229F	MEMBRE	\N	\N
6617	CSCE	2020-10-28 00:00:00	2022-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11083R	MEMBRE	\N	\N
6618	CSCE	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11026G	MEMBRE	\N	\N
6619	APM	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	12028B	MEMBRE	\N	\N
6620	APM	2020-10-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	08056B	MEMBRE	\N	\N
6728	COMITEDEONTO	2021-02-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11067R	MEMBRE	\N	\N
6729	COMITEDEONTO	2021-02-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11040E	MEMBRE	\N	\N
6730	COMITEDEONTO	2021-02-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19545Y	MEMBRE	\N	\N
6731	COMITEDEONTO	2021-02-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19629C	MEMBRE	\N	\N
6829	COLTER	2021-10-14 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14217N	MEMBRE	\N	\N
6733	COMITEDEONTO	2021-02-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11099A	MEMBRE	\N	\N
6830	COLTER	2021-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19447X	MEMBRE	\N	\N
6735	COMITEDEONTO	2021-02-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11072N	MEMBRE	\N	\N
6832	COLTER	2021-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19573D	MEMBRE	\N	\N
6831	COLTER	2021-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19711U	MEMBRE	\N	\N
6833	COLTER	2021-10-14 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20070A	MEMBRE	\N	\N
6834	COLTER	2021-10-14 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19820Y	MEMBRE	\N	\N
6835	COLTER	2021-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19335Q	MEMBRE	\N	\N
6836	COLTER	2021-10-14 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19782L	MEMBRE	\N	\N
6837	COLTER	2021-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19563B	MEMBRE	\N	\N
6838	COLTER	2021-10-14 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20134Y	MEMBRE	\N	\N
6948	DELCONEUR	2020-11-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	14249W	MEMBRE	\N	\N
7048	ENTREPRISES	2022-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19525U	MEMBRE	\N	\N
7108	SFAPF	2023-03-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04035D	MEMBRE	\N	\N
6428	211	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19749K	MEMBRE	\N	\N
6788	COLTER	2021-08-06 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20062A	MEMBRE	\N	\N
7488	MECSS	2023-12-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	19798U	MEMBRE	\N	\N
7489	MECSS	2023-12-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	14217N	MEMBRE	\N	\N
7490	MECSS	2023-12-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	19703U	MEMBRE	\N	\N
7491	MECSS	2023-12-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	19683J	MEMBRE	\N	\N
7492	MECSS	2023-12-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	17965H	MEMBRE	\N	\N
7493	MECSS	2023-12-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	14042U	MEMBRE	\N	\N
7494	MECSS	2023-12-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	19569H	MEMBRE	\N	\N
7495	MECSS	2023-12-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	21097R	MEMBRE	\N	\N
7496	MECSS	2023-12-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	19760E	MEMBRE	\N	\N
7497	MECSS	2023-12-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	19553Y	MEMBRE	\N	\N
7498	MECSS	2023-12-06 00:00:00	\N	ACTIF	\N	\N	\N	\N	21087P	MEMBRE	\N	\N
7537	OTAN	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	04042C	MEMBRE	\N	\N
7538	OTAN	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	14249W	MEMBRE	\N	\N
7539	OTAN	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	19421M	MEMBRE	\N	\N
7540	OTAN	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	19669L	MEMBRE	\N	\N
7541	OTAN	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	11027H	MEMBRE	\N	\N
7542	OTAN	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	07033P	MEMBRE	\N	\N
7543	OTAN	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	20128B	MEMBRE	\N	\N
7544	OTAN	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	19709B	MEMBRE	\N	\N
7545	OTAN	2023-10-26 00:00:00	\N	ACTIF	\N	\N	\N	\N	20122U	MEMBRE	\N	\N
7591	SFAPF	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	18395Y	MEMBRE	\N	\N
7592	SFAPF	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	21074J	MEMBRE	\N	\N
7593	SFAPF	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	11074Q	MEMBRE	\N	\N
7594	SFAPF	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	14281W	MEMBRE	\N	\N
7595	SFAPF	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	20120S	MEMBRE	\N	\N
7596	SFAPF	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	21032X	MEMBRE	\N	\N
7597	SFAPF	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	07004J	MEMBRE	\N	\N
7598	SFAPF	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	19565D	MEMBRE	\N	\N
7599	SFAPF	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	19553Y	MEMBRE	\N	\N
7600	SFAPF	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	19569H	MEMBRE	\N	\N
7601	SFAPF	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	11048N	MEMBRE	\N	\N
7602	SFAPF	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	20102Q	MEMBRE	\N	\N
7603	SFAPF	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	19699S	MEMBRE	\N	\N
7604	SFAPF	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	19711U	MEMBRE	\N	\N
7605	SFAPF	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	14037X	MEMBRE	\N	\N
7606	SFAPF	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	21087P	MEMBRE	\N	\N
7607	SFAPF	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	20252E	MEMBRE	\N	\N
7608	SFAPF	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	21073H	MEMBRE	\N	\N
7609	SFAPF	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	19563B	MEMBRE	\N	\N
7610	SFAPF	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	21037D	MEMBRE	\N	\N
7611	SFAPF	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	19593H	MEMBRE	\N	\N
7612	SFAPF	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	19573D	MEMBRE	\N	\N
7613	SFAPF	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	11045K	MEMBRE	\N	\N
7614	SFAPF	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	19421M	MEMBRE	\N	\N
7615	SFAPF	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	19669L	MEMBRE	\N	\N
7616	SFAPF	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	19301E	MEMBRE	\N	\N
7617	SFAPF	2023-12-27 00:00:00	\N	ACTIF	\N	\N	\N	\N	20064C	MEMBRE	\N	\N
6009	UIP	2018-10-10 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	19709B	MEMBRE	\N	\N
6268	CVFS	2017-07-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	MEMBRE	\N	\N
6269	CVFS	2019-04-04 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08058D	MEMBRE	\N	\N
4758	SFAPF	2015-02-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14249W	MEMBRE	2015-02-13 16:11:00	\N
3559	DSOM	2011-11-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04043D	MEMBRE	\N	2017-10-18 16:25:25
4515	ENTREPRISES	2014-11-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14121F	MEMBRE	2014-11-26 13:28:41	2017-10-18 16:22:43
6423	211	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14189C	MEMBRE	\N	\N
6424	211	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14030Q	MEMBRE	\N	\N
6425	211	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14179A	MEMBRE	\N	\N
6426	211	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20066E	MEMBRE	\N	\N
6427	211	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14275Y	MEMBRE	\N	\N
6429	211	2020-10-20 00:00:00	2021-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	08061X	MEMBRE	\N	\N
6430	211	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20106U	MEMBRE	\N	\N
6431	211	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19681G	MEMBRE	\N	\N
6432	211	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19866P	MEMBRE	\N	\N
6433	211	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11031D	MEMBRE	\N	\N
6434	211	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20046A	MEMBRE	\N	\N
6435	211	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14221J	MEMBRE	\N	\N
6436	211	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20130U	MEMBRE	\N	\N
6437	ENTREPRISES	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19515S	MEMBRE	\N	\N
6438	ENTREPRISES	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19575F	MEMBRE	\N	\N
6439	ENTREPRISES	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14105F	MEMBRE	\N	\N
6440	ENTREPRISES	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14329V	MEMBRE	\N	\N
6441	ENTREPRISES	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	08028W	MEMBRE	\N	\N
6442	ENTREPRISES	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19467C	MEMBRE	\N	\N
6458	ENTREPRISES	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20060X	MEMBRE	\N	\N
6444	ENTREPRISES	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14357A	MEMBRE	\N	\N
6445	ENTREPRISES	2020-10-20 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	MEMBRE	\N	\N
6446	ENTREPRISES	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14026U	MEMBRE	\N	\N
6447	ENTREPRISES	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20126Y	MEMBRE	\N	\N
6448	ENTREPRISES	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	08015R	MEMBRE	\N	\N
6449	ENTREPRISES	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14031R	MEMBRE	\N	\N
6450	ENTREPRISES	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19671E	MEMBRE	\N	\N
6451	ENTREPRISES	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	08011M	MEMBRE	\N	\N
6452	ENTREPRISES	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14253S	MEMBRE	\N	\N
6453	ENTREPRISES	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19679N	MEMBRE	\N	\N
6454	ENTREPRISES	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20054A	MEMBRE	\N	\N
6455	ENTREPRISES	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19762G	MEMBRE	\N	\N
6456	ENTREPRISES	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20094J	MEMBRE	\N	\N
6457	ENTREPRISES	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	08060W	MEMBRE	\N	\N
6459	ENTREPRISES	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19251M	MEMBRE	\N	\N
6460	ENTREPRISES	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	17965H	MEMBRE	\N	\N
6461	ENTREPRISES	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20030R	MEMBRE	\N	\N
6462	ENTREPRISES	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20082E	MEMBRE	\N	\N
6463	ENTREPRISES	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14030Q	MEMBRE	\N	\N
6464	ENTREPRISES	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14083S	MEMBRE	\N	\N
6465	ENTREPRISES	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20040T	MEMBRE	\N	\N
6466	ENTREPRISES	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20048C	MEMBRE	\N	\N
6467	ENTREPRISES	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	16685X	MEMBRE	\N	\N
6468	ENTREPRISES	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19369B	MEMBRE	\N	\N
6469	ENTREPRISES	2020-10-20 00:00:00	2022-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	08073C	MEMBRE	\N	\N
6470	ENTREPRISES	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19301E	MEMBRE	\N	\N
6471	ENTREPRISES	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19697Q	MEMBRE	\N	\N
6472	ENTREPRISES	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19717B	MEMBRE	\N	\N
6473	ENTREPRISES	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19866P	MEMBRE	\N	\N
6474	ENTREPRISES	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19760E	MEMBRE	\N	\N
6475	ENTREPRISES	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19695N	MEMBRE	\N	\N
6476	ENTREPRISES	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19545Y	MEMBRE	\N	\N
6477	ENTREPRISES	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14195A	MEMBRE	\N	\N
6478	ENTREPRISES	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20134Y	MEMBRE	\N	\N
6479	ENTREPRISES	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20092G	MEMBRE	\N	\N
6480	206	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19593H	MEMBRE	\N	\N
6481	206	2020-10-20 00:00:00	2021-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	19563B	MEMBRE	\N	\N
6482	206	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20072C	MEMBRE	\N	\N
6483	206	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20128B	MEMBRE	\N	\N
6484	206	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19569H	MEMBRE	\N	\N
6485	206	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20066E	MEMBRE	\N	\N
6486	206	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19735D	MEMBRE	\N	\N
6487	206	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19683J	MEMBRE	\N	\N
6488	206	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11067R	MEMBRE	\N	\N
6489	206	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19503N	MEMBRE	\N	\N
6490	206	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19693L	MEMBRE	\N	\N
6491	206	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19663E	MEMBRE	\N	\N
6492	206	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04043D	MEMBRE	\N	\N
6493	206	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01048V	MEMBRE	\N	\N
6494	206	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19709B	MEMBRE	\N	\N
6495	206	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01058X	MEMBRE	\N	\N
6496	206	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19723Y	MEMBRE	\N	\N
6497	206	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19533U	MEMBRE	\N	\N
6498	DSOM	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19347U	MEMBRE	\N	\N
6499	DSOM	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	MEMBRE	\N	\N
6500	DSOM	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19631V	MEMBRE	\N	\N
6501	DSOM	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14097Y	MEMBRE	\N	\N
6502	DSOM	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20028X	MEMBRE	\N	\N
6503	DSOM	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	MEMBRE	\N	\N
6504	DSOM	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14053L	MEMBRE	\N	\N
6505	DSOM	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	18083K	MEMBRE	\N	\N
6506	DSOM	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14259Y	MEMBRE	\N	\N
6507	DSOM	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19673G	MEMBRE	\N	\N
6508	DSOM	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	97011G	MEMBRE	\N	\N
6509	DSOM	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14033T	MEMBRE	\N	\N
6510	DSOM	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	08034U	MEMBRE	\N	\N
6511	DSOM	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14059S	MEMBRE	\N	\N
6522	DSOM	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19691J	MEMBRE	\N	\N
6513	DSOM	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14147R	MEMBRE	\N	\N
6514	DSOM	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11090Q	MEMBRE	\N	\N
6515	DSOM	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14331P	MEMBRE	\N	\N
6516	DSOM	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11043H	MEMBRE	\N	\N
6517	DSOM	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19715Y	MEMBRE	\N	\N
6518	DSOM	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	12016W	MEMBRE	\N	\N
6519	DSOM	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19301E	MEMBRE	\N	\N
6520	DSOM	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	08073C	MEMBRE	\N	\N
6521	DSOM	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	17023S	MEMBRE	\N	\N
6523	DSOM	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14219Q	MEMBRE	\N	\N
6524	DSOM	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20146D	MEMBRE	\N	\N
6525	DSOM	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11109J	MEMBRE	\N	\N
6526	DSOM	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19295A	MEMBRE	\N	\N
6528	DSOM	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19659J	MEMBRE	\N	\N
6529	DSOM	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19577H	MEMBRE	\N	\N
6530	DSOM	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19583F	MEMBRE	\N	\N
6531	DSOM	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19657G	MEMBRE	\N	\N
6532	DSOM	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19329S	MEMBRE	\N	\N
6533	DSOM	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11072N	MEMBRE	\N	\N
6534	DSOM	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20034V	MEMBRE	\N	\N
6535	DSOM	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20148F	MEMBRE	\N	\N
6536	DSOM	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19717B	MEMBRE	\N	\N
6537	DSOM	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20016T	MEMBRE	\N	\N
6538	DSOM	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20150Y	MEMBRE	\N	\N
6539	DSOM	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14275Y	MEMBRE	\N	\N
6540	DSOM	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11010L	MEMBRE	\N	\N
6541	DSOM	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19319Q	MEMBRE	\N	\N
5627	ENTREPRISES	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19669L	MEMBRE	2017-10-18 16:22:53	\N
5628	ENTREPRISES	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14051J	MEMBRE	2017-10-18 16:22:58	\N
5629	ENTREPRISES	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14227Q	MEMBRE	2017-10-18 16:23:04	\N
5630	ENTREPRISES	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19527W	MEMBRE	2017-10-18 16:23:09	\N
5631	ENTREPRISES	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19521Q	MEMBRE	2017-10-18 16:23:35	\N
5632	ENTREPRISES	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16685X	MEMBRE	2017-10-18 16:23:42	\N
5633	ENTREPRISES	2017-10-18 00:00:00	2018-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	MEMBRE	2017-10-18 16:24:11	\N
5634	DSOM	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14038Y	MEMBRE	2017-10-18 16:24:14	\N
5635	DSOM	2017-10-18 00:00:00	2020-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	14199E	MEMBRE	2017-10-18 16:24:36	\N
5636	ENTREPRISES	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11099A	MEMBRE	2017-10-18 16:24:41	\N
5637	DSOM	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19729F	MEMBRE	2017-10-18 16:24:58	\N
5638	ENTREPRISES	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11031D	MEMBRE	2017-10-18 16:25:04	\N
5639	ENTREPRISES	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19695N	MEMBRE	2017-10-18 16:25:11	\N
5640	ENTREPRISES	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19545Y	MEMBRE	2017-10-18 16:25:16	\N
5641	DSOM	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14135M	MEMBRE	2017-10-18 16:25:37	\N
5642	DSOM	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14331P	MEMBRE	2017-10-18 16:25:53	\N
5643	COLTER	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14259Y	MEMBRE	2017-10-18 16:26:08	\N
5644	DSOM	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19703U	MEMBRE	2017-10-18 16:26:14	\N
5645	COLTER	2017-10-18 00:00:00	2020-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	08048B	MEMBRE	2017-10-18 16:26:14	\N
5646	DSOM	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14157T	MEMBRE	2017-10-18 16:26:24	\N
5647	DSOM	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19631V	MEMBRE	2017-10-18 16:26:37	\N
5648	DSOM	2017-10-18 00:00:00	2018-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	08016S	MEMBRE	2017-10-18 16:26:57	\N
5649	COLTER	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19525U	MEMBRE	2017-10-18 16:27:13	\N
5650	COLTER	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11110B	MEMBRE	2017-10-18 16:27:23	\N
5651	COLTER	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14281W	MEMBRE	2017-10-18 16:27:29	\N
5652	DSOM	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14225N	MEMBRE	2017-10-18 16:27:32	\N
5653	COLTER	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19489J	MEMBRE	2017-10-18 16:27:33	\N
5654	COLTER	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14257W	MEMBRE	2017-10-18 16:27:42	\N
5655	COLTER	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19735D	MEMBRE	2017-10-18 16:28:08	\N
5656	COLTER	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14103D	MEMBRE	2017-10-18 16:28:15	\N
5657	DSOM	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19691J	MEMBRE	2017-10-18 16:28:34	\N
5658	COLTER	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08049C	MEMBRE	2017-10-18 16:28:42	\N
5659	DSOM	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11033F	MEMBRE	2017-10-18 16:28:46	\N
5660	COLTER	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19565D	MEMBRE	2017-10-18 16:28:47	\N
5661	COLTER	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19687N	MEMBRE	2017-10-18 16:28:53	\N
5662	COLTER	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14195A	MEMBRE	2017-10-18 16:28:58	\N
5663	DSOM	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19717B	MEMBREDRT	2017-10-18 16:30:21	2017-10-18 16:39:58
5664	206	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19663E	MEMBRE	2017-10-18 16:30:45	\N
5665	DSOM	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19295A	MEMBREDRT	2017-10-18 16:30:52	2017-10-18 16:39:58
5666	206	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19723Y	MEMBRE	2017-10-18 16:30:55	\N
5667	206	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19709B	MEMBRE	2017-10-18 16:31:00	\N
5668	DSOM	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19659J	MEMBREDRT	2017-10-18 16:31:03	2017-10-18 16:39:59
5669	206	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19533U	MEMBRE	2017-10-18 16:31:12	\N
5670	DSOM	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19577H	MEMBREDRT	2017-10-18 16:31:16	2017-10-18 16:40:17
5671	206	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19683J	MEMBRE	2017-10-18 16:31:32	\N
5672	206	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19503N	MEMBRE	2017-10-18 16:31:48	\N
5673	DSOM	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19329S	MEMBREDRT	2017-10-18 16:31:54	2017-10-18 16:40:17
5674	206	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19511N	MEMBRE	2017-10-18 16:31:55	\N
5675	206	2017-10-18 00:00:00	2020-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	14239U	MEMBRE	2017-10-18 16:32:07	\N
5676	DSOM	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19715Y	MEMBREDRT	2017-10-18 16:32:10	2017-10-18 16:40:17
5677	206	2017-10-18 00:00:00	2017-11-15 00:00:00	ANCIEN	\N	\N	\N	\N	19563B	MEMBRE	2017-10-18 16:32:14	2017-11-16 16:21:16
5678	206	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19593H	MEMBRE	2017-10-18 16:32:21	\N
5679	206	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14093U	MEMBRE	2017-10-18 16:32:31	\N
5680	DSOM	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19583F	MEMBREDRT	2017-10-18 16:32:35	2017-10-18 16:41:22
3576	DSOM	2011-11-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98005N	MEMBREDRT	\N	2017-10-18 16:32:52
5681	DSOM	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	12016W	MEMBREDRT	2017-10-18 16:33:53	2017-10-18 16:41:24
5682	DSOM	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19657G	MEMBREDRT	2017-10-18 16:34:30	2017-10-18 16:41:26
5683	DSOM	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19319Q	MEMBREDRT	2017-10-18 16:35:24	2017-10-18 17:57:01
5684	DSOM	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19301E	MEMBREDRT	2017-10-18 16:35:51	2017-10-18 17:58:13
4591	MECSS	2014-12-10 00:00:00	2017-11-20 00:00:00	ANCIEN	\N	\N	\N	\N	14053L	MEMBRE	2014-12-10 16:28:29	2017-11-28 10:07:57
3632	MECSS	2011-12-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10006L	MEMBRE	\N	2017-11-28 10:08:53
5828	MECSS	2017-11-21 00:00:00	2020-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	14239U	MEMBRE	2017-11-28 10:08:14	\N
5829	MECSS	2017-11-21 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19415P	MEMBRE	2017-11-28 10:08:21	\N
5830	MECSS	2017-11-21 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14195A	MEMBRE	2017-11-28 10:08:31	\N
5831	MECSS	2017-11-21 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14042U	MEMBRE	2017-11-28 10:09:01	\N
6369	PROS	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14259Y	MEMBRE	\N	\N
5832	MECSS	2017-11-21 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14281W	MEMBRE	2017-11-28 10:09:07	\N
5833	MECSS	2017-11-21 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14026U	MEMBRE	2017-11-28 10:09:14	\N
5834	MECSS	2017-11-21 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19553Y	MEMBRE	2017-11-28 10:09:19	\N
5835	MECSS	2017-11-21 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11067R	MEMBRE	2017-11-28 10:09:27	\N
5836	MECSS	2017-11-21 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	11063M	MEMBRE	2017-11-28 10:10:16	\N
6109	SFAPF	2019-03-26 00:00:00	2020-09-17 00:00:00	ANCIEN	\N	\N	\N	\N	14133K	MEMBRE	\N	\N
6110	SFAPF	2019-03-26 00:00:00	2020-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	14239U	MEMBRE	\N	\N
6128	211	2019-05-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14261S	MEMBRE	\N	\N
5428	UIP	2017-01-30 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	MEMBRE	2017-01-30 11:22:17	\N
6808	211	2021-10-06 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20114U	MEMBRE	\N	\N
6828	211	2021-10-12 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19057M	MEMBRE	\N	\N
6868	UIP	2021-10-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	20056C	MEMBRE	\N	\N
6869	UIP	2021-10-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	20026V	MEMBRE	\N	\N
6870	UIP	2021-10-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	20058E	MEMBRE	\N	\N
6908	UIP	2021-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19681G	MEMBRE	\N	\N
6928	PROS	2022-01-05 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20068G	MEMBRE	\N	\N
5708	DELCONEUR	2017-11-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98029W	MEMBRE	2017-11-07 18:29:29	\N
5709	DELCONEUR	2017-11-07 00:00:00	2018-06-24 00:00:00	ANCIEN	\N	\N	\N	\N	14079W	MEMBRE	2017-11-07 18:30:08	\N
5710	DELCONEUR	2017-11-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11083R	MEMBRE	2017-11-07 00:00:00	\N
5711	DELCONEUR	2017-11-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	14073Q	MEMBRE	2017-11-07 18:30:42	\N
5712	DELCONEUR	2017-11-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11041F	MEMBRE	2017-11-07 00:00:00	\N
5788	206	2017-11-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19553Y	MEMBRE	2017-11-16 16:21:36	\N
5968	DELCONEUR	2018-06-25 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	19667J	MEMBRE	\N	\N
6328	COLTER	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20022R	MEMBRE	\N	\N
6329	COLTER	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14069U	MEMBRE	\N	\N
6330	COLTER	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20090E	MEMBRE	\N	\N
6331	COLTER	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14053L	MEMBRE	\N	\N
6332	COLTER	2020-10-20 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	MEMBRE	\N	\N
6333	COLTER	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	MEMBRE	\N	\N
6334	COLTER	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14187A	MEMBRE	\N	\N
6335	COLTER	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20120S	MEMBRE	\N	\N
6336	COLTER	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01057W	MEMBRE	\N	\N
6337	COLTER	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	08010L	MEMBRE	\N	\N
6338	COLTER	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14071N	MEMBRE	\N	\N
6339	COLTER	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	17637T	MEMBRE	\N	\N
6340	COLTER	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	05012A	MEMBRE	\N	\N
6341	COLTER	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20058E	MEMBRE	\N	\N
6342	COLTER	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14173T	MEMBRE	\N	\N
6343	COLTER	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14151M	MEMBRE	\N	\N
6344	COLTER	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14281W	MEMBRE	\N	\N
6345	COLTER	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19333N	MEMBRE	\N	\N
6346	COLTER	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19489J	MEMBRE	\N	\N
6347	COLTER	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14257W	MEMBRE	\N	\N
6348	COLTER	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14229S	MEMBRE	\N	\N
6349	COLTER	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20084G	MEMBRE	\N	\N
6350	COLTER	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14327T	MEMBRE	\N	\N
6351	COLTER	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14231L	MEMBRE	\N	\N
6352	COLTER	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14205J	MEMBRE	\N	\N
6353	COLTER	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	08009T	MEMBRE	\N	\N
6358	COLTER	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19349W	MEMBRE	\N	\N
6355	COLTER	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19826F	MEMBRE	\N	\N
6356	COLTER	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19735D	MEMBRE	\N	\N
6357	COLTER	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	04045F	MEMBRE	\N	\N
6359	COLTER	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19681G	MEMBRE	\N	\N
6360	COLTER	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14107H	MEMBRE	\N	\N
6361	COLTER	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19758L	MEMBRE	\N	\N
6362	COLTER	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19565D	MEMBRE	\N	\N
6363	COLTER	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20122U	MEMBRE	\N	\N
6364	COLTER	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20110Q	MEMBRE	\N	\N
6365	PROS	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20032T	MEMBRE	\N	\N
6366	PROS	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19954N	MEMBRE	\N	\N
6367	PROS	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19643A	MEMBRE	\N	\N
6368	PROS	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19747H	MEMBRE	\N	\N
6370	PROS	2020-10-20 00:00:00	2021-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	04008A	MEMBRE	\N	\N
6371	PROS	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04071H	MEMBRE	\N	\N
6372	PROS	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19399H	MEMBRE	\N	\N
6373	PROS	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	99004R	MEMBRE	\N	\N
6374	PROS	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19711U	MEMBRE	\N	\N
6375	PROS	2020-10-20 00:00:00	2020-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	08011M	MEMBRE	\N	\N
6376	PROS	2020-10-20 00:00:00	2021-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	14237S	MEMBRE	\N	\N
6377	PROS	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14193X	MEMBRE	\N	\N
6378	PROS	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20044X	MEMBRE	\N	\N
6379	PROS	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11097X	MEMBRE	\N	\N
6380	PROS	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19295A	MEMBRE	\N	\N
6381	PROS	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19725B	MEMBRE	\N	\N
6382	PROS	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19551W	MEMBRE	\N	\N
6383	PROS	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	08012N	MEMBRE	\N	\N
6384	PROS	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20018V	MEMBRE	\N	\N
6385	PROS	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	MEMBRE	\N	\N
6386	PROS	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19669L	MEMBRE	\N	\N
6387	PROS	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19543W	MEMBRE	\N	\N
6388	PROS	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20042V	MEMBRE	\N	\N
6389	PROS	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20144B	MEMBRE	\N	\N
6390	PROS	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19569H	MEMBRE	\N	\N
6391	PROS	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	04070G	MEMBRE	\N	\N
6392	PROS	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19479G	MEMBRE	\N	\N
6393	PROS	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19651A	MEMBRE	\N	\N
6394	PROS	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	MEMBRE	\N	\N
6395	PROS	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20132W	MEMBRE	\N	\N
6396	PROS	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19553Y	MEMBRE	\N	\N
6397	PROS	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11040E	MEMBRE	\N	\N
6398	PROS	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11056N	MEMBRE	\N	\N
6399	PROS	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20050V	MEMBRE	\N	\N
6400	PROS	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11065P	MEMBRE	\N	\N
6401	211	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20024T	MEMBRE	\N	\N
6402	211	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20138D	MEMBRE	\N	\N
6403	211	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	17737W	MEMBRE	\N	\N
6404	211	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19621T	MEMBRE	\N	\N
6405	211	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19693L	MEMBRE	\N	\N
6406	211	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20140W	MEMBRE	\N	\N
6407	211	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04035D	MEMBRE	\N	\N
6408	211	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20034V	MEMBRE	\N	\N
6409	211	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20056C	MEMBRE	\N	\N
6410	211	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	07029T	MEMBRE	\N	\N
6411	211	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19657G	MEMBRE	\N	\N
6412	211	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19768N	MEMBRE	\N	\N
6413	211	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20118Y	MEMBRE	\N	\N
6414	211	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	19798U	MEMBRE	\N	\N
6415	211	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20098N	MEMBRE	\N	\N
6416	211	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	20080C	MEMBRE	\N	\N
6417	211	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19599P	MEMBRE	\N	\N
6418	211	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19715Y	MEMBRE	\N	\N
6419	211	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11045K	MEMBRE	\N	\N
6420	211	2020-10-20 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08017T	MEMBRE	\N	\N
6421	211	2020-10-20 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14109K	MEMBRE	\N	\N
6422	211	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19527W	MEMBRE	\N	\N
6768	PROS	2021-03-03 00:00:00	2023-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	14038Y	MEMBRE	\N	\N
7275	ENTREPRISES	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20078J	MEMBRE	\N	\N
7276	ENTREPRISES	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20104S	MEMBRE	\N	\N
7277	ENTREPRISES	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14357A	MEMBRE	\N	\N
7278	ENTREPRISES	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20038A	MEMBRE	\N	\N
7279	ENTREPRISES	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20172F	MEMBRE	\N	\N
7280	ENTREPRISES	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	21044C	MEMBRE	\N	\N
7281	ENTREPRISES	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20056C	MEMBRE	\N	\N
7282	ENTREPRISES	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20126Y	MEMBRE	\N	\N
7283	ENTREPRISES	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	08015R	MEMBRE	\N	\N
7284	ENTREPRISES	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	21058J	MEMBRE	\N	\N
7285	ENTREPRISES	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	21080G	MEMBRE	\N	\N
7286	ENTREPRISES	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	21039F	MEMBRE	\N	\N
7287	ENTREPRISES	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14237S	MEMBRE	\N	\N
7288	ENTREPRISES	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	21047F	MEMBRE	\N	\N
7289	ENTREPRISES	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20054A	MEMBRE	\N	\N
4637	COMITEDEONTO	2014-11-04 00:00:00	2017-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	14227Q	MEMBRE	2015-01-12 19:01:51	2017-11-09 14:47:51
5714	COMITEDEONTO	2017-11-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14093U	MEMBRE	2017-11-09 14:48:12	\N
5715	COMITEDEONTO	2017-11-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14085U	MEMBRE	2017-11-09 14:48:19	\N
5716	COMITEDEONTO	2017-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14267Y	MEMBRE	2017-11-09 00:00:00	\N
5717	COMITEDEONTO	2017-11-09 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	MEMBRE	2017-11-09 00:00:00	\N
5718	COMITEDEONTO	2017-11-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08031R	MEMBRE	2017-11-09 14:48:43	\N
5719	APM	2017-11-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	87003B	MEMBRE	2017-11-09 15:24:49	\N
5837	206	2017-11-28 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08053X	MEMBRE	2017-11-28 15:53:59	\N
4755	SFAPF	2015-02-13 00:00:00	2018-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	MEMBRE	2015-02-13 16:10:38	2018-01-09 14:21:55
4780	SFAPF	2015-02-13 00:00:00	2018-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	11104D	MEMBRE	2015-02-13 16:13:41	2018-01-09 14:23:50
4791	SFAPF	2015-02-13 00:00:00	2018-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	14229S	MEMBRE	2015-02-13 16:15:15	2018-01-09 14:25:27
4754	SFAPF	2015-02-13 00:00:00	2018-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	98018T	MEMBRE	2015-02-13 16:10:29	2018-01-09 14:26:50
5868	SFAPF	2018-01-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89017R	MEMBRE	2018-01-09 14:28:52	\N
5869	SFAPF	2018-01-08 00:00:00	2020-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	19717B	MEMBRE	2018-01-09 14:28:58	\N
5870	SFAPF	2018-01-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19651A	MEMBRE	2018-01-09 00:00:00	\N
5871	SFAPF	2018-01-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08024S	MEMBRE	2018-01-09 14:29:29	\N
5872	SFAPF	2018-01-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98029W	MEMBRE	2018-01-09 14:29:35	\N
5873	SFAPF	2018-01-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	18083K	MEMBRE	2018-01-09 00:00:00	\N
5874	SFAPF	2018-01-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19701S	MEMBRE	2018-01-09 00:00:00	\N
5875	SFAPF	2018-01-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11027H	MEMBRE	2018-01-09 00:00:00	\N
5876	SFAPF	2018-01-08 00:00:00	2018-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	19253P	MEMBRE	2018-01-09 14:30:19	\N
5877	SFAPF	2018-01-08 00:00:00	2023-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	14259Y	MEMBRE	2018-01-09 14:30:27	\N
5878	SFAPF	2018-01-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	MEMBRE	2018-01-09 14:30:32	\N
5879	SFAPF	2018-01-08 00:00:00	2020-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	17589D	MEMBRE	2018-01-09 14:30:54	\N
5880	SFAPF	2018-01-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	19251M	MEMBRE	2018-01-09 14:31:07	\N
5881	SFAPF	2018-01-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19577H	MEMBRE	2018-01-09 00:00:00	\N
5882	SFAPF	2018-01-08 00:00:00	2020-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	19599P	MEMBRE	2018-01-09 14:33:49	\N
5883	SFAPF	2018-01-08 00:00:00	2018-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	98053W	MEMBRE	2018-01-09 14:33:52	2018-05-31 10:52:17
5892	SFAPF	2018-01-08 00:00:00	2020-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	19709B	MEMBRE	2018-01-09 14:36:04	\N
5885	SFAPF	2018-01-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11010L	MEMBRE	2018-01-09 00:00:00	\N
5886	SFAPF	2018-01-08 00:00:00	2020-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	08041T	MEMBRE	2018-01-09 14:34:38	\N
5887	SFAPF	2018-01-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95037J	MEMBRE	2018-01-09 14:35:07	\N
5888	SFAPF	2018-01-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19569H	MEMBRE	2018-01-09 00:00:00	\N
5889	SFAPF	2018-01-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	08069G	MEMBRE	2018-01-09 14:35:26	\N
5890	SFAPF	2018-01-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	14073Q	MEMBRE	2018-01-09 14:35:41	\N
5891	SFAPF	2018-01-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19699S	MEMBRE	2018-01-09 00:00:00	\N
5893	SFAPF	2018-01-08 00:00:00	2020-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	12016W	MEMBRE	2018-01-09 14:36:21	\N
5894	SFAPF	2018-01-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	14001X	MEMBRE	2018-01-09 14:36:34	\N
5895	SFAPF	2018-01-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08053X	MEMBRE	2018-01-09 14:36:43	\N
5896	SFAPF	2018-01-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19563B	MEMBRE	2018-01-09 00:00:00	\N
5897	SFAPF	2018-01-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19573D	MEMBRE	2018-01-09 00:00:00	\N
5898	SFAPF	2018-01-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	14193X	MEMBRE	2018-01-09 14:37:19	\N
5899	SFAPF	2018-01-08 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	07034Q	MEMBRE	2018-01-09 14:37:23	\N
5900	SFAPF	2018-01-08 00:00:00	2020-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	19735D	MEMBRE	2018-01-09 14:38:11	\N
5901	SFAPF	2018-01-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14051J	MEMBRE	2018-01-09 14:38:46	\N
5902	SFAPF	2018-01-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11041F	MEMBRE	2018-01-09 00:00:00	\N
5903	SFAPF	2018-01-08 00:00:00	2020-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	19585H	MEMBRE	2018-01-09 14:39:00	\N
5904	SFAPF	2018-01-08 00:00:00	2020-08-03 00:00:00	ANCIEN	\N	\N	\N	\N	08035V	MEMBRE	2018-01-09 14:42:57	\N
5908	211	2018-01-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19731Y	MEMBRE	2018-02-01 20:32:15	\N
4709	SFAPF	2015-02-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	10006L	MEMBRE	2015-02-13 00:00:00	2015-02-13 00:00:00
4761	SFAPF	2015-02-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01025N	MEMBRE	2015-02-13 00:00:00	\N
7193	211	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	21071F	MEMBRE	\N	\N
7194	211	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	21091K	MEMBRE	\N	\N
7195	211	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20038A	MEMBRE	\N	\N
7196	211	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20180F	MEMBRE	\N	\N
7197	211	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20034V	MEMBRE	\N	\N
7198	211	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	21044C	MEMBRE	\N	\N
7199	211	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20056C	MEMBRE	\N	\N
7200	211	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	07029T	MEMBRE	\N	\N
7201	211	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14147R	MEMBRE	\N	\N
7202	211	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14223L	MEMBRE	\N	\N
7203	211	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19798U	MEMBRE	\N	\N
7204	211	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20098N	MEMBRE	\N	\N
7205	211	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20062A	MEMBRE	\N	\N
7206	211	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	21061D	MEMBRE	\N	\N
7207	211	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20114U	MEMBRE	\N	\N
7208	211	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	21089R	MEMBRE	\N	\N
7210	211	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14109K	MEMBRE	\N	\N
7211	211	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	11045K	MEMBRE	\N	\N
7212	211	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	21077M	MEMBRE	\N	\N
7213	211	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	21042A	MEMBRE	\N	\N
7214	211	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14189C	MEMBRE	\N	\N
7215	211	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14030Q	MEMBRE	\N	\N
7216	211	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14179A	MEMBRE	\N	\N
7217	211	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	21038E	MEMBRE	\N	\N
7218	211	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19749K	MEMBRE	\N	\N
7219	211	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19057M	MEMBRE	\N	\N
7220	211	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20146D	MEMBRE	\N	\N
7221	211	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	21034A	MEMBRE	\N	\N
7222	211	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20046A	MEMBRE	\N	\N
7223	211	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19693L	MEMBRE	\N	\N
7224	211	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	21087P	MEMBRE	\N	\N
7225	211	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20130U	MEMBRE	\N	\N
7226	211	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	21094N	MEMBRE	\N	\N
7227	211	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19553Y	MEMBRE	\N	\N
7228	211	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19866P	MEMBRE	\N	\N
7290	ENTREPRISES	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	21061D	MEMBRE	\N	\N
7291	ENTREPRISES	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20088L	MEMBRE	\N	\N
7292	ENTREPRISES	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	21045D	MEMBRE	\N	\N
7293	ENTREPRISES	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19295A	MEMBRE	\N	\N
7294	ENTREPRISES	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	21067K	MEMBRE	\N	\N
7295	ENTREPRISES	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19551W	MEMBRE	\N	\N
7296	ENTREPRISES	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20028X	MEMBRE	\N	\N
7297	ENTREPRISES	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20030R	MEMBRE	\N	\N
7298	ENTREPRISES	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	21051B	MEMBRE	\N	\N
7299	ENTREPRISES	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	21050A	MEMBRE	\N	\N
7300	ENTREPRISES	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14083S	MEMBRE	\N	\N
7301	ENTREPRISES	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20144B	MEMBRE	\N	\N
7302	ENTREPRISES	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20248J	MEMBRE	\N	\N
7303	ENTREPRISES	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	20052X	MEMBRE	\N	\N
7304	ENTREPRISES	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19563B	MEMBRE	\N	\N
7305	ENTREPRISES	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	21064G	MEMBRE	\N	\N
7306	ENTREPRISES	2023-10-17 00:00:00	2029-11-27 00:00:00	ACTIF	\N	\N	\N	\N	21033Y	MEMBRE	\N	\N
7307	ENTREPRISES	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19697Q	MEMBRE	\N	\N
7308	ENTREPRISES	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19301E	MEMBRE	\N	\N
7309	ENTREPRISES	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	21088Q	MEMBRE	\N	\N
7310	ENTREPRISES	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19695N	MEMBRE	\N	\N
7311	ENTREPRISES	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	21052C	MEMBRE	\N	\N
7312	ENTREPRISES	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19545Y	MEMBRE	\N	\N
7313	ENTREPRISES	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19347U	MEMBRE	\N	\N
7314	ENTREPRISES	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	21092L	MEMBRE	\N	\N
7315	ENTREPRISES	2023-10-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	19719D	MEMBRE	\N	\N
\.


--
-- Data for Name: memextpar; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY memextpar (memextparid, orgcod, memextpardatdeb, memextpardatfin, memextpartitsup, temvalcod, evelic, evelib, evelil, eveobs, senmat, memextparrngele, designcod, syscredat, sysmajdat, fonmemextparcod, avis_senat, texte_avis_senat, avis_an, texte_avis_an, avis_global, texte_avis_global, date_saisine_exec, date_annonce_seance, date_audition_senat, date_avis_senat, date_avis_an, date_avis_global, date_reponse_exec, date_publication_jo) FROM stdin;
13	20	1995-10-25 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89039X	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
14	20	1993-04-08 00:00:00	2001-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83050R	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
15	21	1997-12-18 00:00:00	1998-12-09 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83021L	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
18	23	1993-11-04 00:00:00	1998-11-04 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	78006D	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
19	23	1995-10-31 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	69001W	\N	SENCOMETRD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
20	24	1998-04-28 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89037V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
21	24	1996-02-15 00:00:00	2001-11-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95013A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
22	25	1996-10-03 00:00:00	1999-10-03 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89037V	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
23	29	1993-05-12 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89007P	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
24	29	1993-05-12 00:00:00	1998-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	80048K	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
25	29	1993-05-12 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	80003V	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
26	29	1997-11-04 00:00:00	1998-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	74050Q	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
28	31	1996-06-24 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86049M	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
36	34	1998-06-17 00:00:00	2001-04-25 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86041D	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
37	34	1998-06-17 00:00:00	2001-04-25 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95049N	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
38	34	1998-06-17 00:00:00	2001-04-25 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83016P	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
39	34	1998-06-17 00:00:00	1999-02-15 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	74013K	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
41	36	1993-04-13 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	81007E	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
42	37	1996-05-21 00:00:00	1999-05-19 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83003J	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
43	37	1995-10-25 00:00:00	1998-10-20 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	89027T	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
44	39	1998-04-09 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89037V	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
45	42	1992-11-06 00:00:00	2001-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92044U	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
46	42	1995-10-24 00:00:00	2000-02-22 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95057N	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
47	43	1998-01-20 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89039X	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
48	43	1998-01-20 00:00:00	2002-01-20 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89006N	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
50	46	1995-10-31 00:00:00	2001-05-09 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89004L	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
51	49	1995-10-26 00:00:00	1999-02-10 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95053J	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
52	49	1998-04-09 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89024Q	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
53	49	1993-11-08 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	80048K	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
54	50	1995-12-19 00:00:00	1998-12-08 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89041R	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
55	50	1995-12-19 00:00:00	1998-12-08 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89022N	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
56	50	1997-09-17 00:00:00	1998-12-08 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	80039J	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
57	50	1995-12-19 00:00:00	1998-12-08 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	83040P	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
58	52	1995-10-24 00:00:00	1998-10-24 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95058P	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
59	52	1995-07-05 00:00:00	1998-07-05 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92012L	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
60	52	1995-07-05 00:00:00	1998-07-05 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	78007E	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
61	52	1995-07-05 00:00:00	1998-07-05 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	92041R	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
62	53	1997-11-04 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	77002U	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
65	65	1995-10-18 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	79004F	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
67	66	1995-10-26 00:00:00	1998-10-26 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95035G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
69	66	1995-10-26 00:00:00	1998-10-26 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	94003T	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
70	67	1993-04-05 00:00:00	2001-09-23 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	74015M	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
71	67	1993-04-05 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83028T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
73	67	1995-11-23 00:00:00	2001-10-18 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86041D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
74	69	1995-10-19 00:00:00	1998-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	80036F	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
75	69	1995-11-14 00:00:00	1998-10-07 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86031B	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
76	69	1995-10-19 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86041D	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
77	70	1994-10-13 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	74013K	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
78	70	1996-06-11 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	94002S	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
79	70	1995-10-31 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86035F	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
80	70	1989-11-17 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	80004W	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
81	72	1995-10-24 00:00:00	1998-11-03 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	85002R	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
82	73	1998-01-22 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	96005E	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
83	73	1998-01-22 00:00:00	2004-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95040D	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
84	74	1998-04-02 00:00:00	2003-04-02 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89037V	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
85	75	1996-12-17 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	80021X	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
86	75	1996-12-17 00:00:00	1999-11-23 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95040D	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
87	75	1996-12-17 00:00:00	1998-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	89039X	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
89	76	2002-10-02 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	00002B	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
90	77	1995-10-31 00:00:00	2001-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92011K	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
91	77	1996-10-09 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92027T	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
92	81	1996-12-17 00:00:00	1999-12-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	87002A	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
93	81	1996-12-17 00:00:00	1999-12-17 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95019G	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
94	82	1998-04-29 00:00:00	2001-04-29 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	74022L	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
95	82	1998-04-29 00:00:00	2001-04-29 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83003J	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
96	84	1998-04-09 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89024Q	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
97	84	1989-11-02 00:00:00	1998-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	71009B	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
98	84	1993-04-07 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83026R	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
100	87	1995-06-30 00:00:00	1998-10-09 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92035T	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
101	87	1995-10-26 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86037H	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
105	91	1996-10-16 00:00:00	2000-06-20 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95050F	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
106	93	1995-10-24 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89026S	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
107	94	1998-05-11 00:00:00	2001-05-02 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89030N	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
108	94	1998-05-11 00:00:00	2000-10-25 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	92021M	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
109	95	2000-02-09 00:00:00	2003-02-08 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95038K	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
110	95	1997-01-30 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	80021X	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
111	95	2000-02-09 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89004L	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
112	95	1997-01-30 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	80004W	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
113	96	1998-04-29 00:00:00	2001-04-25 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95006B	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
114	97	1993-03-24 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	84004P	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
115	97	1993-09-29 00:00:00	2001-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	92019T	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
119	100	1995-10-24 00:00:00	1998-10-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95053J	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
120	101	1995-10-24 00:00:00	1998-10-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	65017N	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
121	102	1995-12-21 00:00:00	1998-12-15 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95057N	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
122	103	1995-12-21 00:00:00	1998-12-15 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	74019R	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
123	104	1995-12-21 00:00:00	1998-12-15 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95041E	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
125	108	1994-06-15 00:00:00	1998-06-15 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89024Q	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
130	112	1996-10-15 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	80015A	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
131	112	1996-10-15 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95038K	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
132	112	1996-03-19 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86049M	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
133	112	1996-10-15 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86047K	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
149	115	1996-11-14 00:00:00	1999-11-14 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	74032N	\N	SENCOMETRD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
150	116	1996-11-19 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	71006X	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
152	119	1995-11-21 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89022N	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
153	120	1996-10-15 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83054V	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
158	124	1995-10-12 00:00:00	2000-10-12 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	77019E	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
159	124	1996-02-13 00:00:00	1998-11-24 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95045J	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
160	125	1995-07-05 00:00:00	1998-07-05 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	88005H	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
161	126	1995-10-26 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	77012W	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
162	126	1992-12-23 00:00:00	2001-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	81015E	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
177	128	1997-03-19 00:00:00	2000-03-19 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83028T	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
178	128	1997-03-19 00:00:00	2000-03-19 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92045V	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
179	129	1994-08-28 00:00:00	1996-09-11 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89041R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
180	130	1995-04-05 00:00:00	1996-06-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	80026D	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
181	130	1995-04-05 00:00:00	1996-06-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	80041C	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
184	130	1996-10-09 00:00:00	1996-06-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92019T	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
185	132	1995-04-05 00:00:00	2001-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83033Q	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
186	132	1995-04-05 00:00:00	2001-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92035T	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
188	135	1995-04-05 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89030N	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
189	135	1995-10-26 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	88008L	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
196	134	1995-06-27 00:00:00	1998-06-27 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89022N	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
197	134	1995-06-27 00:00:00	1998-06-27 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86047K	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
213	69	1995-12-06 00:00:00	1998-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	94003T	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
216	144	1995-12-20 00:00:00	1998-11-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95042F	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
599	109	1998-10-28 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95034F	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
600	109	1998-10-28 00:00:00	2008-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	98039Y	\N	COMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
601	72	1998-11-04 00:00:00	2001-11-04 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	96004D	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
602	72	1998-11-04 00:00:00	2001-11-04 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98042T	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
603	72	1998-11-04 00:00:00	2001-11-04 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95040D	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
604	72	1998-11-04 00:00:00	2001-11-04 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98015Q	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
605	75	1998-11-04 00:00:00	1999-11-23 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	88009M	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
606	97	1998-11-04 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83020K	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
607	87	1998-11-10 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95042F	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
608	111	1998-11-10 00:00:00	2001-11-10 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	91002E	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
609	9	1998-11-12 00:00:00	2001-11-12 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	77043E	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
610	16	1998-11-18 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98054X	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
611	144	1998-11-18 00:00:00	2006-06-29 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	80045G	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
612	112	1998-12-02 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	74042Q	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
613	21	1998-12-09 00:00:00	1999-11-16 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83021L	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
614	50	1998-12-09 00:00:00	2001-12-09 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89022N	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
615	50	1998-12-09 00:00:00	2001-09-23 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	74015M	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
616	50	1998-12-09 00:00:00	2001-12-09 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	98054X	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
617	50	1998-12-09 00:00:00	2001-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	83040P	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
618	50bis	1998-12-09 00:00:00	2001-12-09 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89022N	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
619	50bis	1998-12-09 00:00:00	2001-12-09 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	98054X	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
620	102	1998-12-16 00:00:00	2001-12-16 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92005M	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
621	103	1998-12-16 00:00:00	1999-11-03 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	74019R	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
622	104	1998-12-16 00:00:00	2001-12-06 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95029J	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
191	136	1995-04-05 00:00:00	2001-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	92027T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
192	137	1995-11-21 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	77013X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
193	137	1995-04-26 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	80026D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
194	138	1996-10-02 00:00:00	1999-10-02 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	87003B	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
195	138	1996-10-02 00:00:00	1999-10-02 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	92009R	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
198	139	1995-09-06 00:00:00	2001-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92007P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
199	139	1995-09-06 00:00:00	2001-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83021L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
201	139	1998-04-28 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95019G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
202	139	1995-11-21 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89006N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
203	141	1996-02-01 00:00:00	2000-09-19 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83033Q	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
204	141	1996-02-01 00:00:00	2000-09-19 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86034E	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
205	141	1996-02-01 00:00:00	2000-09-19 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89013M	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
206	140	1998-04-28 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95002W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
207	140	1995-11-23 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95050F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
208	140	1995-11-23 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89035T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
209	142	1995-12-06 00:00:00	1996-06-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83021L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
210	142	1995-12-06 00:00:00	1996-06-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89006N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
211	142	1995-12-06 00:00:00	1996-06-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	86031B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
212	142	1995-10-06 00:00:00	1996-06-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	74022L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
219	146	1996-03-26 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	80026D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
220	146	1996-03-26 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92019T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
221	145	1996-03-27 00:00:00	1997-12-31 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83050R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
225	98	1996-06-24 00:00:00	1999-06-24 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86037H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
226	98	1996-06-24 00:00:00	1999-06-24 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89015P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
227	98	1996-06-24 00:00:00	1999-06-24 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89007P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
228	98	1996-06-24 00:00:00	1999-06-24 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95040D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
229	98	1996-06-24 00:00:00	1999-06-24 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	77012W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
230	98	1996-06-24 00:00:00	1999-06-24 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	89019T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
231	98	1996-06-24 00:00:00	1999-06-24 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95050F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
232	98	1996-06-24 00:00:00	1999-06-24 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95038K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
236	148	1996-12-12 00:00:00	2001-09-23 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	74015M	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
237	148	1996-12-12 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86041D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
238	148	1996-12-12 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83012K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
239	149	1996-12-12 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83036T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
627	49	1999-02-11 00:00:00	2000-09-22 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89007P	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
628	34	1999-02-16 00:00:00	2001-04-25 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	98047Y	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
629	153	1999-03-11 00:00:00	2002-12-31 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92035T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
630	22	1999-03-11 00:00:00	2002-03-11 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95005A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
631	22	1999-03-17 00:00:00	2002-03-17 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	96007G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
583	612	1998-10-27 00:00:00	2001-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95057N	5	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
584	612	1998-10-27 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83043S	6	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
585	29	1998-10-28 00:00:00	2006-08-11 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	74050Q	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
586	29	1998-10-28 00:00:00	2007-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89007P	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
587	29	1998-10-28 00:00:00	2004-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95005A	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
588	29	1998-10-28 00:00:00	2006-07-08 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	80048K	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
591	95	1998-10-28 00:00:00	2001-10-28 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98006P	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
590	95	1998-10-28 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	94004U	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
592	66	1998-10-28 00:00:00	2001-10-28 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	71003U	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
593	66	1998-10-28 00:00:00	2001-10-28 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98047Y	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
594	66	1998-10-28 00:00:00	2001-10-28 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95035G	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
595	70	1998-10-28 00:00:00	2001-10-22 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98028V	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
596	70	1998-10-28 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95055L	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
597	141	1998-10-28 00:00:00	2000-09-19 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98041S	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
548	13	1998-10-21 00:00:00	2001-10-21 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92029V	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
504	50bis	1995-12-19 00:00:00	1998-12-08 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	89022N	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
502	50bis	1997-09-17 00:00:00	1998-12-08 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	80039J	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
505	66	1995-10-26 00:00:00	1998-10-26 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95005A	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
506	67	1995-11-23 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89022N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
509	134	1998-10-14 00:00:00	2000-12-12 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98042T	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
679	69	1999-10-27 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95012Y	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
680	103	1999-11-04 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92026S	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
681	21	1999-11-17 00:00:00	2000-10-25 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83021L	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
682	25	1999-11-17 00:00:00	2002-11-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89037V	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
683	115	1999-11-17 00:00:00	2001-10-10 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	74032N	\N	SENCOMETRD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
684	75	1999-11-24 00:00:00	2002-11-24 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89030N	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
685	75	1999-11-24 00:00:00	2002-11-24 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95040D	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
686	75	1999-11-24 00:00:00	2000-10-25 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	92021M	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
687	75	1999-11-24 00:00:00	2002-11-24 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	88009M	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
688	108	1999-12-03 00:00:00	2003-12-03 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95042F	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
689	612	1998-10-27 00:00:00	2001-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	86035F	6	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
690	127	2000-01-28 00:00:00	2003-01-27 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89041R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
691	127	2000-01-28 00:00:00	2003-01-27 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95035G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
693	42	2000-02-23 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	74013K	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
694	162	2000-03-01 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83028T	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
695	162	2000-03-01 00:00:00	2001-05-29 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83036T	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
696	162	2000-03-01 00:00:00	2005-03-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95003X	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
697	81	2000-03-15 00:00:00	2003-03-15 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	87002A	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
699	163	2000-03-15 00:00:00	2008-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98036V	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
700	128	2000-03-22 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83028T	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
701	128	2000-03-22 00:00:00	2003-03-22 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92045V	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
702	30	2000-03-24 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83036T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
703	155	2000-04-05 00:00:00	2008-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98023Q	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
704	164	2000-06-07 00:00:00	2004-06-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89022N	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
705	164	2000-06-07 00:00:00	2004-06-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98030P	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
706	164	2000-06-07 00:00:00	2001-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92045V	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
707	91	2002-10-15 00:00:00	2005-06-20 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01006K	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
708	611	2000-05-16 00:00:00	2001-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95011X	10	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
709	113	2000-06-27 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98017S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
710	165	2000-06-27 00:00:00	2003-06-27 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	93005R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
711	157	2000-09-06 00:00:00	2003-09-06 00:00:00	\N	ANCIEN	\N	\N	\N	\N	95007C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
712	166	2000-10-03 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95012Y	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
713	100	2000-10-05 00:00:00	2005-10-05 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92040Q	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
714	101	2000-10-05 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	65017N	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
715	133	2000-10-05 00:00:00	2005-10-05 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	85003S	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
716	167	2000-10-05 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92026S	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
720	21	2000-10-26 00:00:00	2001-11-26 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83021L	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
721	75	2000-10-26 00:00:00	2004-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	86011W	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
722	94	2000-10-26 00:00:00	2001-05-02 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	98010K	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
723	141	2000-10-26 00:00:00	2008-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89013M	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
724	141	2000-10-26 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98049B	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
725	141	2000-10-26 00:00:00	2001-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83033Q	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
726	141	2000-10-26 00:00:00	2001-11-20 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98041S	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
727	141	2000-10-26 00:00:00	2004-04-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86034E	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
728	168	2000-11-03 00:00:00	2001-10-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98011L	1	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
729	168	2000-11-03 00:00:00	2007-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89045V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
730	168	2000-11-03 00:00:00	2002-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	77009C	3	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
731	168	2000-11-03 00:00:00	2001-12-10 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	80040B	4	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
732	169	2000-11-14 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92009R	1	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
733	169	2000-11-14 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86021Y	2	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
734	169	2000-11-14 00:00:00	2008-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98019U	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
735	169	2000-11-14 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	88013H	4	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
736	171	2000-11-16 00:00:00	2003-11-16 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95015C	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
737	49	2000-11-16 00:00:00	2008-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	94003T	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
738	49	2000-11-16 00:00:00	2006-07-08 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	80048K	2	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
739	12	2000-12-06 00:00:00	2003-12-06 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95051G	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
740	134	2000-12-13 00:00:00	2003-12-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98042T	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
741	134	2000-12-13 00:00:00	2003-12-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	85002R	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
742	17	2000-12-18 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89023P	\N	SENCOMETRD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
743	17	2000-12-18 00:00:00	2001-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	81015E	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
744	170	2000-12-20 00:00:00	2003-12-20 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	77002U	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
802	172	2001-04-26 00:00:00	2001-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	96004D	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
805	172	2001-04-26 00:00:00	2004-01-19 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89007P	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
806	172	2001-04-26 00:00:00	2004-01-19 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	93005R	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
807	96	2001-04-26 00:00:00	2004-04-07 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95006B	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
808	34	2001-04-26 00:00:00	2004-04-14 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98041S	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
809	34	2001-04-26 00:00:00	2004-04-14 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86041D	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
810	34	2001-04-26 00:00:00	2004-04-14 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	98047Y	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
811	34	2001-04-26 00:00:00	2004-04-14 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95049N	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
812	94	2001-05-03 00:00:00	2004-05-03 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89030N	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
813	94	2001-05-03 00:00:00	2004-05-03 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	98010K	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
814	152	2001-05-03 00:00:00	2006-05-03 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	96004D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
815	82	2001-05-03 00:00:00	2004-05-03 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83003J	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
816	82	2001-05-03 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	74022L	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
817	46	2001-05-10 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89004L	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
818	162	2001-05-30 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95045J	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
819	107	2001-05-28 00:00:00	2001-10-26 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98044V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
820	131	2001-05-28 00:00:00	2004-05-18 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95042F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
821	131	2001-05-28 00:00:00	2004-05-18 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	92031P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
822	64	2001-05-28 00:00:00	2004-05-18 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92045V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
823	64	2001-05-28 00:00:00	2001-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	92019T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
824	88	2001-06-20 00:00:00	2004-06-20 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	77002U	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
825	66	2001-06-25 00:00:00	2004-06-25 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86041D	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
826	173	2001-06-27 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	91002E	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
827	173	2001-06-27 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	79004F	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
828	173	2001-06-27 00:00:00	2007-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98023Q	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
829	173	2001-06-27 00:00:00	2004-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95007C	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
830	173	2001-06-27 00:00:00	2007-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	94003T	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
831	173	2001-06-27 00:00:00	2001-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	92042S	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
832	174	2001-07-11 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	91002E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
833	174	2001-07-11 00:00:00	2001-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	96007G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
834	42	2001-10-09 00:00:00	2011-10-09 00:00:00	TITULAIRE	ANCIEN	\N	président	\N	président	92044U	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
835	42	2001-10-16 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98044V	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
836	611	2001-10-16 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	84004P	5	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
837	611	2001-10-16 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95011X	11	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
838	611	2001-10-16 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86030A	1	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
839	611	2001-10-16 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	88013H	2	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
840	611	2001-10-16 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	93005R	3	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
841	611	2001-10-16 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95034F	4	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
842	611	2001-10-16 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	77002U	6	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
843	611	2001-10-16 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95057N	7	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
844	611	2001-10-16 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89035T	8	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
845	611	2001-10-16 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	80013X	9	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
846	611	2001-10-16 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92015P	10	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
847	611	2001-10-16 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	80017C	12	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
848	611	2001-10-16 00:00:00	2004-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	83031N	2	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
849	611	2001-10-16 00:00:00	2004-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	99004R	3	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
850	611	2001-10-16 00:00:00	2004-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	86049M	1	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
851	611	2001-10-16 00:00:00	2004-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95052H	4	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
852	611	2001-10-16 00:00:00	2004-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	89040Q	5	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
853	611	2001-10-16 00:00:00	2004-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	98040R	6	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
854	612	2001-10-16 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86030A	1	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
855	612	2001-10-16 00:00:00	2004-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	86035F	1	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
856	612	2001-10-16 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95034F	2	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
858	612	2001-10-16 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	84004P	3	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
859	612	2001-10-16 00:00:00	2004-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	86049M	3	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
860	612	2001-10-16 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95039L	4	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
861	612	2001-10-16 00:00:00	2004-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95057N	4	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
862	612	2001-10-16 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89040Q	5	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
863	612	2001-10-16 00:00:00	2004-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	98015Q	5	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
864	612	2001-10-16 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	80017C	6	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
865	612	2001-10-16 00:00:00	2004-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	92020L	6	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
866	169	2001-10-18 00:00:00	2008-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98005N	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
867	101	2001-10-18 00:00:00	2004-11-26 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92005M	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
868	167	2001-10-18 00:00:00	2006-10-18 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98048A	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
869	103	2001-10-18 00:00:00	2006-10-18 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01041N	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
870	99	2001-10-18 00:00:00	2006-10-18 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98015Q	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
871	138	2001-10-18 00:00:00	2004-10-18 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01025N	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
872	52	2001-10-18 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95029J	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
873	52	2001-10-18 00:00:00	2004-10-18 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98015Q	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
874	52	2001-10-18 00:00:00	2004-10-18 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01059Y	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
875	52	2001-10-18 00:00:00	2004-10-18 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	98042T	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
876	125	2001-10-18 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95023C	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
877	135 bis	2001-10-23 00:00:00	2004-12-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89030N	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
878	82	2001-10-23 00:00:00	2004-10-23 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01024M	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
879	173	2001-10-23 00:00:00	2010-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	92042S	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
880	20	2001-10-23 00:00:00	2004-12-06 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01056V	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
881	20	2001-10-23 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95062K	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
882	120	2001-10-23 00:00:00	2006-10-23 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01017N	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
883	172	2001-10-23 00:00:00	2004-01-19 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01058X	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
884	43	2009-12-14 00:00:00	2010-08-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95062K	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
885	112	2001-10-23 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	80015A	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
886	112	2001-10-23 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	88009M	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
887	112	2001-10-23 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95038K	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
888	112	2001-10-23 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	85003S	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
889	112	2001-10-23 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86047K	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
890	112	2001-10-23 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98012M	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
891	112	2001-10-23 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86049M	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
892	70	2001-10-24 00:00:00	2007-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98027U	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
893	4	2001-10-24 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01001E	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2236	231	2006-09-08 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	03002P	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2237	231	2008-12-04 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01022K	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
894	17	2001-10-24 00:00:00	2010-03-06 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	81015E	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
895	126	2001-10-24 00:00:00	2007-06-26 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	81015E	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
896	13	2001-10-24 00:00:00	2002-06-07 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92029V	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
897	36	2001-10-24 00:00:00	2008-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	94003T	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
898	3	2001-10-17 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89035T	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
899	3	2001-10-17 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98039Y	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
900	176	2001-10-25 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	88013H	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
901	115	2001-10-25 00:00:00	2004-02-11 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98018T	\N	SENCOMETRD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
902	95	2001-10-25 00:00:00	2004-10-25 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01031L	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
903	95	2001-10-25 00:00:00	2004-10-25 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92011K	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
904	95	2001-10-25 00:00:00	2004-10-25 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95067Q	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
905	66	2001-10-25 00:00:00	2004-10-25 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98047Y	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
906	66	2001-10-25 00:00:00	2004-10-25 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01042P	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
907	66	2001-10-25 00:00:00	2004-10-25 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01010F	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
908	141	2001-10-30 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95040D	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
909	161	2001-10-30 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01049W	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
623	124	1998-12-16 00:00:00	2003-12-16 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95033E	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
624	118	1998-12-16 00:00:00	2001-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92022N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
625	158	1998-12-16 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83043S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
626	140	1999-01-08 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89035T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
598	69	1998-10-28 00:00:00	1999-10-26 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86047K	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
549	39	1998-10-21 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89037V	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
550	53	1998-10-21 00:00:00	2001-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	77002U	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
551	65	1998-10-21 00:00:00	2001-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	88013H	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
552	2	1998-10-21 00:00:00	2007-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89022N	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
553	69	1998-10-21 00:00:00	2001-12-12 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	89019T	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
555	611	1998-10-27 00:00:00	2001-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95034F	\N	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
556	611	1998-10-27 00:00:00	2001-02-07 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	74024N	2	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
557	611	1998-10-27 00:00:00	2001-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86030A	3	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
558	611	1998-10-27 00:00:00	2001-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	84004P	4	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
559	611	1998-10-27 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	74019R	5	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
560	611	1998-10-27 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	65017N	6	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
561	611	1998-10-27 00:00:00	2001-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92015P	7	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
562	611	1998-10-27 00:00:00	2001-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95057N	8	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
563	611	1998-10-27 00:00:00	2001-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	77033C	9	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
565	611	1998-10-27 00:00:00	2001-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	80017C	11	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
566	611	1998-10-27 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83043S	12	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
567	611	1998-10-27 00:00:00	2001-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	83031N	13	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
568	611	1998-10-27 00:00:00	2001-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	80013X	14	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
569	611	1998-10-27 00:00:00	2001-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95052H	15	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
570	611	1998-10-27 00:00:00	2001-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	88013H	16	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
571	611	1998-10-27 00:00:00	2001-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	83025Q	17	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
572	611	1998-10-27 00:00:00	2001-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95031C	18	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
573	612	1998-10-27 00:00:00	1999-03-25 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83012K	\N	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
574	612	1999-03-25 00:00:00	2001-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89040Q	\N	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
575	612	1999-12-01 00:00:00	2001-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	92016Q	1	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
576	612	1998-10-27 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83025Q	2	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
577	612	1998-10-27 00:00:00	2001-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95034F	2	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
578	612	1998-10-27 00:00:00	2001-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	80017C	3	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
579	612	1998-10-27 00:00:00	2001-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	92020L	3	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
580	612	1998-10-27 00:00:00	2001-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95031C	4	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
581	612	1998-10-27 00:00:00	2001-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	84004P	4	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
582	612	1998-10-27 00:00:00	2001-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95039L	5	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
510	134	1998-10-14 00:00:00	2000-12-12 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86047K	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
511	108	2002-10-30 00:00:00	2006-10-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98042T	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
527	49	1998-10-21 00:00:00	2000-09-22 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	80048K	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
529	112	1998-10-21 00:00:00	2001-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95038K	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
530	112	1998-10-21 00:00:00	1998-12-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95040D	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
516	125	1998-10-14 00:00:00	2001-10-14 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95023C	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
517	93	1998-10-14 00:00:00	2000-03-03 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92034S	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
518	99	1998-10-14 00:00:00	2001-10-14 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	80017C	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
519	100	1998-10-14 00:00:00	2000-10-04 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92040Q	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
520	101	1998-10-14 00:00:00	2000-10-04 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	65017N	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
522	52	1998-10-14 00:00:00	2001-10-14 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95029J	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
523	52	1998-10-14 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	97008M	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
524	52	1998-10-14 00:00:00	2001-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	92041R	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
525	52	1998-10-14 00:00:00	2001-10-14 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	85002R	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
526	49	1998-10-21 00:00:00	2000-09-22 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	94003T	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
531	112	1998-10-21 00:00:00	2001-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	85003S	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
532	112	1998-10-21 00:00:00	2001-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86034E	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
533	112	1998-10-21 00:00:00	2001-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86047K	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
534	112	1998-10-21 00:00:00	2001-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86049M	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
535	23	1998-10-21 00:00:00	2002-06-07 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98031Q	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
536	23	1998-10-21 00:00:00	2003-10-21 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92024Q	\N	SENCOMETRD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
537	20	1998-10-21 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86006A	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
538	20	1998-10-21 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92025R	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
539	73	1998-10-21 00:00:00	2004-10-18 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	96005E	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
540	135	1998-10-21 00:00:00	2004-12-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89030N	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
541	43	1998-10-21 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92025R	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
542	75	1998-10-21 00:00:00	1999-11-23 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89030N	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
543	75	1998-10-21 00:00:00	1999-11-23 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	92021M	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
544	116	1998-10-21 00:00:00	2001-10-21 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98036V	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
545	37	1998-10-21 00:00:00	2001-10-21 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	89027T	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
546	119	1998-10-21 00:00:00	2007-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89022N	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
547	143	1998-10-21 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95042F	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
240	149	1996-12-12 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	77013X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
241	149	1996-12-12 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92019T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
242	150	1996-12-12 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92045V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
243	150	1996-12-12 00:00:00	2001-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86005Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
244	150	1996-12-12 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95049N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
245	151	1996-12-12 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83028T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
246	151	1996-12-12 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86049M	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
247	151	1996-12-12 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86037H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
252	154	1997-03-13 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	94003T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
253	154	1997-03-13 00:00:00	1998-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	89022N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
66	66	1998-07-08 00:00:00	2001-06-24 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89017R	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1	3	1992-11-10 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83020K	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2	3	1993-04-08 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	74019R	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3	3	1995-11-16 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86030A	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4	4	1993-04-13 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83052T	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
6	9	1995-11-21 00:00:00	1998-11-11 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	77043E	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
7	12	2000-02-09 00:00:00	2003-02-08 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92011K	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
8	13	1995-11-14 00:00:00	1998-10-20 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	77058M	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
9	16	1995-10-31 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95030B	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
10	16	1995-10-31 00:00:00	1998-11-02 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95048M	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
11	17	1992-11-25 00:00:00	2000-12-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	81015E	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
12	20	1989-11-16 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	80036F	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1057	37	2002-11-21 00:00:00	2007-11-21 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01061S	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1058	37	2002-11-21 00:00:00	2007-11-21 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89027T	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1059	98	2002-11-21 00:00:00	2007-11-21 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89015P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1060	98	2002-11-21 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95040D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1061	98	2002-11-21 00:00:00	2007-11-21 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95038K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1427	13	2005-07-30 00:00:00	2008-07-23 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92035T	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1428	216	2005-09-27 00:00:00	2007-11-19 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83042R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1429	216	2005-09-27 00:00:00	2007-11-19 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01027Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1688	243	2008-07-04 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95013A	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1431	182	2005-09-21 00:00:00	2005-09-21 00:00:00	\N	ANCIEN	\N	\N	\N	\N	01018P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1689	243	2008-07-04 00:00:00	2012-07-21 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04090L	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1433	182	2005-09-21 00:00:00	2008-09-21 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98024R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1434	182	2005-09-21 00:00:00	2008-09-21 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01018P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1435	159	2005-09-22 00:00:00	2008-09-22 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01026P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1436	159	2005-09-22 00:00:00	2008-09-22 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89030N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2265	301	2012-07-31 00:00:00	2014-06-04 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	07024N	\N	PDTSEN	\N	2014-06-04 17:33:00	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2286	115	2012-10-03 00:00:00	2014-05-03 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	12040W	\N	SENCOMETRD	\N	2014-05-05 14:36:30	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1439	215	2005-10-13 00:00:00	2007-10-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04072J	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1440	81	2005-10-13 00:00:00	2008-10-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95013A	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1442	189	2005-10-13 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	88009M	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1443	138	2008-12-04 00:00:00	2011-12-04 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	08045X	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1444	100	2005-10-13 00:00:00	2008-12-10 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92040Q	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1445	133	2005-10-13 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	85003S	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1446	22	2010-11-17 00:00:00	2011-10-21 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	démissionnaire	08010L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1450	95	2005-11-17 00:00:00	2008-11-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01031L	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1451	95	2005-11-17 00:00:00	2008-11-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92011K	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1452	98	2005-11-17 00:00:00	2010-11-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89013M	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1454	98	2005-11-17 00:00:00	2010-11-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98053W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1455	98	2005-11-17 00:00:00	2010-11-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98021N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1456	98	2005-11-17 00:00:00	2010-11-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01050P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1457	123	2005-11-24 00:00:00	2006-12-04 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83021L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1460	218	2005-11-28 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	02002K	\N	PDTSEN	\N	2014-12-11 14:28:38	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1464	221	2006-01-16 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95062K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1466	219	2006-01-16 00:00:00	2011-01-16 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01006K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1467	219	2006-01-16 00:00:00	2011-01-16 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95034F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1468	219	2006-01-16 00:00:00	2011-01-16 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01021J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1469	219	2006-01-16 00:00:00	2011-01-16 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01056V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1470	219	2006-01-16 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98049B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1471	21	2006-01-23 00:00:00	2007-01-16 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83021L	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1472	220	2009-07-21 00:00:00	2012-07-21 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95030B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1473	220	2009-07-21 00:00:00	2012-07-21 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95052H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1474	220	2009-07-21 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01050P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1475	222	2006-02-02 00:00:00	2008-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98042T	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1476	91	2006-02-07 00:00:00	2006-10-24 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04071H	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1477	217	2006-02-07 00:00:00	2010-09-07 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	88008L	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1478	217	2006-02-07 00:00:00	2008-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	89030N	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1479	95	2006-02-07 00:00:00	2009-02-07 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95067Q	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1480	95	2006-02-07 00:00:00	2009-02-07 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01003G	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1481	95	2006-02-07 00:00:00	2009-02-07 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95038K	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1482	187	2006-02-09 00:00:00	2009-02-09 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04053F	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1483	191	2006-02-09 00:00:00	2010-09-09 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95028H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1484	191	2006-02-09 00:00:00	2010-09-09 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01012H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
554	69	1998-10-21 00:00:00	2002-06-18 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95041E	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
564	611	1998-10-27 00:00:00	2000-03-28 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	97003G	\N	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
528	112	1998-10-21 00:00:00	2001-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	80015A	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
521	108	1995-12-08 00:00:00	1999-12-02 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95042F	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
88	75	1996-12-17 00:00:00	1998-10-20 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	89030N	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
187	133	1998-04-29 00:00:00	2000-10-04 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	85003S	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
127	109	1993-07-08 00:00:00	1998-10-07 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83052T	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
200	139	1995-09-06 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	74050Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
698	81	2000-03-15 00:00:00	2003-03-15 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95019G	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
857	612	2001-10-16 00:00:00	2004-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	88013H	2	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
912	77	2001-10-30 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92011K	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1011	22	2002-04-25 00:00:00	2005-04-25 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95005A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1118	193	2003-10-09 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86018E	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1485	12	2006-02-21 00:00:00	2007-05-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04092N	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1486	8	2006-02-21 00:00:00	2007-06-21 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92007P	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1090	612	\N	2006-03-09 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	59523P	\N	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1487	4	2009-05-14 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01029S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1488	223	2006-03-14 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89030N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1489	184	2006-03-14 00:00:00	2006-06-07 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95013A	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1492	224	2006-03-15 00:00:00	2014-02-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95036H	\N	PDTSEN	\N	2014-02-19 10:06:30	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1493	224	2006-03-15 00:00:00	2008-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98046X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1497	12	2009-06-01 00:00:00	2012-10-31 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	décret  n°2011-1518  prorogation des membres	96007G	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1502	225	2009-07-21 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01046T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1503	225	2009-07-21 00:00:00	2012-07-21 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	90003B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1504	225	2009-07-21 00:00:00	2012-07-21 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	80013X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1505	225	2009-07-21 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01025N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1506	227	2006-05-09 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89010J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1508	227	2006-05-09 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95030B	\N	PDTSEN	\N	2014-09-23 15:20:15	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1509	227	2006-05-09 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95052H	\N	PDTSEN	\N	2014-09-23 15:20:23	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1515	228	2006-06-13 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	80035E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1516	228	2006-06-13 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92045V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1517	608	\N	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83011J	\N	MEMBREDRT	\N	2014-07-18 11:49:42	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1518	608	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	92035T	\N	MEMBREDRT	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1520	608	\N	2009-07-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	95049N	\N	MEMBREDRT	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1522	229	2006-06-19 00:00:00	2009-05-27 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	durée du mandat non précisée	92035T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1523	229	2006-06-19 00:00:00	2009-07-23 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86044G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1524	229	2006-06-19 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	80045G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1525	229	2006-06-19 00:00:00	2006-09-27 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04037F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1526	229	2006-06-19 00:00:00	2009-05-27 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98046X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1527	229	2006-06-19 00:00:00	2009-05-27 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	05001W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1528	229	2006-06-19 00:00:00	2009-05-27 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01009N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1529	229	2006-06-19 00:00:00	2009-05-27 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04093P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1530	229	2006-06-19 00:00:00	2009-05-27 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95044H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1531	229	2006-06-19 00:00:00	2009-05-27 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	président	92033R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1532	229	2006-06-19 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89035T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1533	144	2006-06-29 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	80045G	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1535	112	2006-09-08 00:00:00	2008-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98037W	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1537	232	2006-09-08 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89041R	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1538	232	2006-09-08 00:00:00	2007-07-19 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01043Q	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1200	203	2004-10-05 00:00:00	2007-10-05 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95046K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1548	229	2006-09-27 00:00:00	2009-05-27 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95007C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1551	29	2006-10-05 00:00:00	2008-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	06004E	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1552	49	2006-10-04 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98015Q	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1553	72	2009-10-08 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01012H	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1557	103	2006-10-12 00:00:00	2011-10-12 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01041N	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1558	99	2006-10-12 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98015Q	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1559	167	2006-10-12 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98048A	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1694	612	2008-10-21 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01001E	1	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1695	612	2008-10-21 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04047H	2	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1539	157	2009-10-05 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95007C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1540	24	2006-09-11 00:00:00	2008-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98050T	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1542	230	2006-09-08 00:00:00	2007-10-09 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01052R	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1543	128	2003-07-10 00:00:00	2006-07-10 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92045V	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1545	202	2004-09-14 00:00:00	2006-06-20 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01047U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1547	102	2004-11-17 00:00:00	2006-06-22 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89042S	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1560	91	2006-10-25 00:00:00	2009-12-03 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95067Q	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1562	148	2006-11-06 00:00:00	2011-11-06 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98029W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1563	148	2006-11-06 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98017S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1564	149	2006-11-06 00:00:00	2011-11-06 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95035G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1565	150	2006-11-06 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92011K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1566	150	2006-11-06 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04037F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1567	150	2006-11-06 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92030N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1568	151	2006-11-06 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Président	92045V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1569	151	2006-11-06 00:00:00	2011-11-06 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04092N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1570	228	2006-06-15 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01037S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1571	108	2010-11-18 00:00:00	2012-06-16 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	09010Q	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1577	233	2006-12-13 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89037V	\N	SENCOMECON	\N	2014-11-05 11:49:15	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1578	233	2006-12-13 00:00:00	2008-12-04 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	96006F	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1572	236	2006-11-29 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	78003A	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1573	236	2006-11-29 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	78006D	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1583	21	2007-01-16 00:00:00	2008-01-10 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83021L	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1575	162	2006-11-13 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92045V	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1576	235	2010-12-09 00:00:00	2012-12-09 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	07034Q	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1579	175	2009-12-23 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01042P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1584	124	2007-01-16 00:00:00	2009-02-18 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01045S	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1585	194	2007-01-17 00:00:00	2008-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98029W	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1586	194	2007-01-17 00:00:00	2008-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92045V	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1587	123	2010-02-19 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01045S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2360	307	2013-04-04 00:00:00	2013-10-04 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04047H	\N	PDTSEN	2013-04-05 09:48:15	2013-10-17 09:31:19	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1589	170	2010-02-03 00:00:00	2013-02-04 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04036E	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1590	120	2009-10-27 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01050P	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1591	194	2007-02-06 00:00:00	2008-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04037F	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1598	126	2007-06-26 00:00:00	2010-03-06 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	81015E	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1593	235	2007-02-22 00:00:00	2008-09-07 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	80017C	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1595	50	2010-05-25 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04037F	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1453	98	2005-11-17 00:00:00	2010-11-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89015P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1596	609	2007-02-08 00:00:00	2010-10-11 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01017N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1597	126	2010-09-09 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	78006D	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1549	234	2006-09-07 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04076N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2369	170	2013-05-22 00:00:00	2016-05-22 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04036E	\N	SENCOMSOCI	2013-05-24 16:03:17	2014-11-25 14:53:53	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2359	307	2013-04-04 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08031R	\N	PDTSEN	2013-04-05 09:47:32	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1550	234	2006-09-07 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04092N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1554	29	2006-10-05 00:00:00	2008-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98035U	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1556	186	2006-10-10 00:00:00	2010-10-10 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	92040Q	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1599	237	2009-12-09 00:00:00	2011-07-25 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95020Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1601	237	2007-07-11 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98015Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1602	118	2007-07-04 00:00:00	2008-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86030A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1603	64	2010-11-25 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01018P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1604	96	2010-07-08 00:00:00	2011-12-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	démission	04084N	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1605	43	2007-07-18 00:00:00	2010-08-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01011G	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1606	181	2007-06-26 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01061S	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1607	181	2007-06-26 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01015L	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1608	69	2007-07-19 00:00:00	2008-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	98047Y	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1609	76	2007-07-19 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01059Y	\N	COMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1610	23	2010-06-04 00:00:00	2014-06-04 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95047L	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1611	177	2007-07-31 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89041R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1612	211	2010-12-16 00:00:00	2012-01-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95015C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1613	211	2010-12-16 00:00:00	2012-01-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04051D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1614	213	2007-07-31 00:00:00	2008-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01034P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1615	238	2007-08-02 00:00:00	2008-04-07 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01051Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1616	238	2007-08-02 00:00:00	2007-12-16 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89045V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
910	161	2001-10-30 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01057W	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
911	37	2001-10-30 00:00:00	2004-10-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	89027T	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
913	77	2001-10-30 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01036R	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
914	50	2001-10-30 00:00:00	2004-10-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01030K	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
915	50	2001-10-30 00:00:00	2004-10-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	89006N	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
916	46	2001-10-30 00:00:00	2002-02-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95035G	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
917	164	2001-10-30 00:00:00	2004-06-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92030N	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
918	162	2001-10-30 00:00:00	2006-10-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92045V	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
919	128	2001-10-30 00:00:00	2004-10-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92030N	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
920	147	2001-10-30 00:00:00	2004-10-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92045V	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
921	65	2001-10-24 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	88013H	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
922	53	2001-10-24 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	77002U	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
923	97	2001-10-24 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95004Y	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
924	97	2001-10-24 00:00:00	2004-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	00003C	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
925	124	2001-10-24 00:00:00	2006-10-24 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95004Y	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
926	176	2001-11-06 00:00:00	2004-11-06 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	88009M	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
927	32	2001-10-30 00:00:00	2010-03-06 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	81015E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
928	32	2001-11-06 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92033R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
929	32	2001-10-29 00:00:00	2008-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	80031A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
930	118	2001-11-06 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95028H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
931	175	2001-11-06 00:00:00	2004-11-06 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95039L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1272	611	2004-10-26 00:00:00	2007-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	84004P	10	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1273	611	2004-11-26 00:00:00	2007-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95011X	11	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1274	611	2004-10-26 00:00:00	2007-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	80017C	12	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1275	611	2004-10-26 00:00:00	2007-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04038G	1	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1276	611	2004-10-26 00:00:00	2007-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	92022N	2	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1277	611	2004-10-26 00:00:00	2007-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	83031N	3	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1278	611	2004-10-26 00:00:00	2007-06-24 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	99004R	4	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1279	611	2004-10-26 00:00:00	2007-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	81015E	5	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1280	611	2004-10-26 00:00:00	2007-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	98040R	6	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1281	612	2004-10-26 00:00:00	2007-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92020L	1	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1282	612	2004-10-26 00:00:00	2008-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	89040Q	1	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1283	612	2004-10-26 00:00:00	2007-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	80017C	2	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1284	612	2004-10-26 00:00:00	2007-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	98015Q	2	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1285	612	2004-10-26 00:00:00	2007-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86030A	3	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1286	612	2004-10-26 00:00:00	2007-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01057W	3	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1287	612	2004-10-26 00:00:00	2007-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92022N	4	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1731	29	2008-12-04 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89007P	\N	SENCOMAFCL	\N	2014-08-26 10:36:51	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1732	31	2008-12-11 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01014K	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1733	34	2008-12-11 00:00:00	2011-12-11 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01057W	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1734	34	2008-12-11 00:00:00	2011-12-11 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01037S	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1735	34	2008-12-18 00:00:00	2011-12-15 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01019Q	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1736	34	2008-12-18 00:00:00	2011-12-15 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	08025T	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1737	39	2008-12-04 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95025E	\N	SENAT	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1738	49	2008-12-04 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	07033P	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1739	69	2008-12-16 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01013J	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1740	69	2008-12-16 00:00:00	2011-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04050C	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1741	72	2008-12-04 00:00:00	2011-12-04 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95009E	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1742	73	2008-12-04 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	97005J	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1743	75	2008-12-08 00:00:00	2011-12-08 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95062K	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1744	75	2008-12-08 00:00:00	2011-12-08 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98037W	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1745	75	2008-12-08 00:00:00	2011-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01049W	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1746	75	2008-12-08 00:00:00	2011-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	07001F	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1747	81	2008-12-04 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95013A	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1748	94	2008-12-04 00:00:00	2010-09-07 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	08033T	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1749	94	2008-12-04 00:00:00	2010-09-07 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	05012A	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1750	99	2008-12-04 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	97004H	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1751	109	2008-12-11 00:00:00	2012-07-21 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	08064B	\N	COMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1752	133	2008-12-04 00:00:00	2009-03-05 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98010K	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1628	94	2007-10-09 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89030N	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1629	94	2007-10-09 00:00:00	2008-12-04 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01014K	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1630	230	2007-10-09 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01005J	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1631	240	2007-10-09 00:00:00	2011-11-30 00:00:00	TITULAIRE	ANCIEN	\N	président	\N	Président	04033B	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1632	240	2007-10-09 00:00:00	2011-11-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95038K	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1633	240	2007-10-09 00:00:00	2008-04-09 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98048A	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1634	240	2007-10-09 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04059M	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1635	201	2007-10-11 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	78003A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1636	160	2007-10-08 00:00:00	2008-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92018S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1643	176	2010-11-18 00:00:00	2013-11-18 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95020Y	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1678	198	2008-04-03 00:00:00	2011-04-03 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92031P	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1679	198	2008-04-03 00:00:00	2010-12-14 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	92005M	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1680	208	2008-04-03 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	80046H	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1681	8	2008-03-25 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04058L	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1685	203	2010-04-26 00:00:00	2013-04-26 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95055L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1690	244	2008-07-23 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83011J	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1691	244	2008-07-23 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01018P	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1692	13	2008-07-23 00:00:00	2010-10-18 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92029V	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1753	141	2008-12-04 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	dev dur ensuite	95021A	\N	SENCOMECON	\N	2014-07-11 10:46:00	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1754	141	2008-12-04 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	dev dur ensuite	04049K	\N	SENCOMECON	\N	2014-07-11 10:45:54	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1755	141	2008-12-04 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92042S	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1756	141	2008-12-11 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98046X	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1757	141	2008-12-11 00:00:00	2011-12-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	démission	08032S	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1807	224	2009-02-17 00:00:00	2014-02-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98046X	\N	PDTSEN	\N	2014-02-19 10:06:30	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1808	136	2009-02-17 00:00:00	2013-01-11 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04045F	\N	PDTSEN	\N	2014-12-11 16:42:52	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1809	158	2009-02-17 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83050R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1810	22	2009-02-17 00:00:00	2012-02-07 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	démissionnaire	04038G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1811	188	2009-02-17 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95028H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1812	188	2009-02-17 00:00:00	2009-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Démissionnaire  30/09/2009	98046X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1813	154	2009-02-17 00:00:00	2010-09-07 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	94003T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1814	86	2009-02-17 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08044W	\N	PDTSEN	\N	2014-07-11 11:57:25	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1815	118	2009-02-17 00:00:00	2010-03-06 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86030A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1816	237	2009-02-17 00:00:00	2011-07-25 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01053S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1817	227	2010-05-25 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	remplacement de M. Doligé, démissionnaire	05012A	\N	PDTSEN	\N	2014-09-23 15:20:52	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1831	127	2009-03-04 00:00:00	2011-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01009N	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2258	294	2012-07-17 00:00:00	2014-02-17 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	98037W	\N	SENCOMCDD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2263	300	2012-07-26 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04059M	\N	COMAFCL	\N	2013-10-14 17:25:12	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1907	267	2010-09-27 00:00:00	2011-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	06001B	267	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1927	270	2010-12-22 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04043D	270	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1929	270	2010-12-22 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04094Q	270	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1930	270	2010-12-22 00:00:00	2011-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01009N	270	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
217	143	1995-12-20 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	94003T	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
218	141	1996-02-01 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	71018C	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
222	152	1996-06-27 00:00:00	2001-05-02 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	82002D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
223	147	1996-05-23 00:00:00	1999-05-19 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83028T	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
224	147	1996-05-23 00:00:00	1999-05-19 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86041D	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
233	138	1996-10-02 00:00:00	1999-10-02 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	77044F	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
234	112	1996-10-15 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	85003S	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
235	112	1996-10-15 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86034E	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
248	2	1996-01-17 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89022N	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
249	153	1997-01-07 00:00:00	1999-03-10 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	77058M	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
250	153	1997-01-07 00:00:00	2002-06-07 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92029V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
251	2	1997-11-05 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	87002A	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
254	155	1997-03-11 00:00:00	2000-03-18 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	88003F	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
255	156	2001-10-29 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	87002A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
256	113	1997-07-09 00:00:00	2004-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95032D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
257	157	1997-09-17 00:00:00	2000-09-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95007C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
258	112	1998-01-29 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95040D	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
259	110	1993-12-20 00:00:00	1996-12-20 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83050R	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
260	110	1993-12-20 00:00:00	1996-12-20 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	83054V	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5	8	1995-10-31 00:00:00	1999-10-20 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89006N	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
16	22	1995-12-13 00:00:00	1998-12-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92022N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
17	22	1995-11-21 00:00:00	1998-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	80004W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
27	30	1995-11-21 00:00:00	1999-11-21 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83036T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
29	32	1989-11-13 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	77001T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
30	32	1995-11-23 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	77043E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
31	32	1993-04-22 00:00:00	2001-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	86005Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
32	32	1992-12-17 00:00:00	2001-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	81015E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
33	33	1995-11-23 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95002W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
34	33	1995-11-23 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	77043E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
35	33	1995-11-23 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86021Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
40	35	1995-11-21 00:00:00	2001-10-10 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	74032N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
49	44	1995-11-23 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	88005H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
63	64	1998-05-14 00:00:00	2001-05-14 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92045V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
64	64	1998-05-14 00:00:00	2001-05-14 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	92019T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
99	86	1995-11-21 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83026R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
102	88	1998-07-08 00:00:00	2001-06-19 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	77002U	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
103	90	1993-04-29 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83026R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
104	90	1992-12-09 00:00:00	1998-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	88005H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
116	98	1996-06-24 00:00:00	1999-06-24 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89013M	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
117	98	1996-06-24 00:00:00	1999-06-24 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	88012G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
118	99	1995-10-24 00:00:00	1998-10-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95058P	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
124	107	1997-05-26 00:00:00	2001-05-26 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95045J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
128	109	1997-04-16 00:00:00	1998-10-27 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95034F	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
129	111	1998-04-22 00:00:00	1998-11-09 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92035T	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
134	113	1993-05-12 00:00:00	2001-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83021L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
135	113	1995-11-23 00:00:00	2003-11-04 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	86031B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
136	113	1992-12-04 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89038W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
137	113	1990-10-25 00:00:00	1998-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	80007A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
138	113	1998-04-28 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95019G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
139	113	1995-11-23 00:00:00	2004-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	77019E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
140	113	1995-11-23 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89006N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
141	113	1995-11-23 00:00:00	2001-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	74022L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
142	113	1999-07-13 00:00:00	2001-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	96007G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
143	113	1990-10-25 00:00:00	1998-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	80039J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
144	113	1995-11-23 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95040D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
145	113	1993-05-12 00:00:00	2001-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	86005Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
146	113	1999-07-13 00:00:00	2000-04-28 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83037U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
147	114	1990-09-18 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83004K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
148	114	1990-09-18 00:00:00	1998-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	80043E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
151	118	1995-10-17 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95005A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
154	121	1991-09-25 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89023P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
155	121	1995-11-21 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86050E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
156	123	1992-05-12 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	84004P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
157	123	1995-11-23 00:00:00	1999-09-14 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92017R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
163	127	1997-02-11 00:00:00	2000-01-27 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89041R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
164	127	1997-02-11 00:00:00	2000-01-27 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	80041C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
165	612	1997-04-15 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95040D	\N	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
166	612	1997-04-15 00:00:00	1998-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	78003A	\N	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
167	612	1995-10-26 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95039L	\N	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
168	612	1995-10-26 00:00:00	1998-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	77001T	\N	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
169	612	1995-10-26 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83025Q	\N	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
170	612	1995-10-26 00:00:00	1998-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	83052T	\N	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
171	612	1995-10-26 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83043S	\N	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
172	612	1995-10-26 00:00:00	1998-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	86035F	\N	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
173	612	1996-06-04 00:00:00	1998-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95031C	\N	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
174	612	1996-06-04 00:00:00	1998-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	70001N	\N	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
175	612	1995-10-26 00:00:00	1998-10-02 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	80017C	\N	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
176	612	1995-10-26 00:00:00	1998-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	80004W	\N	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
182	131	1998-05-14 00:00:00	2001-05-14 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95042F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
183	131	1998-05-14 00:00:00	2001-05-14 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	92031P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
190	136	1995-04-05 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83046V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1183	198	2004-06-28 00:00:00	2007-06-28 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92031P	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1184	198	2004-06-28 00:00:00	2004-11-26 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	92005M	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1186	164	2004-06-30 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89022N	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1187	164	2004-06-30 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98030P	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1188	164	2004-06-30 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92030N	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1189	164	2004-06-30 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	80031A	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1190	66	2004-07-01 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86041D	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1191	88	2004-07-01 00:00:00	2007-07-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	77002U	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1199	203	2003-10-14 00:00:00	2006-10-14 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95020Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1201	200	2004-06-18 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	77043E	\N	PDTSEN	\N	2014-09-23 15:33:30	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1202	200	2004-06-18 00:00:00	2011-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95007C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1204	202	2004-09-14 00:00:00	2007-09-14 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	78003A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1205	202	2006-07-11 00:00:00	2007-09-14 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	77053G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1207	199	2004-10-12 00:00:00	2007-10-12 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01026P	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1208	109	2004-10-20 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95034F	\N	COMLOIS	\N	2014-09-23 15:24:06	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1209	53	2004-10-20 00:00:00	2008-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	77002U	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1210	76	2004-10-20 00:00:00	2007-06-28 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	00002B	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1211	65	2004-10-20 00:00:00	2008-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04043D	\N	COMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1212	97	2004-10-20 00:00:00	2009-02-18 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04042C	\N	COMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1213	97	2004-10-20 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	avait été nommée par cion aff soc	04045F	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1214	124	2004-10-20 00:00:00	2006-01-11 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Fin du mandat par démission	04058L	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1215	124	2010-01-19 00:00:00	2015-01-19 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01046T	\N	COMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1216	4	2004-10-26 00:00:00	2005-12-31 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04047H	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1217	16	2004-10-26 00:00:00	2008-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98019U	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1218	16	2004-10-26 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	96007G	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1219	20	2004-10-26 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	depuis affaires économiques	95062K	\N	SENCOMECON	\N	2014-08-26 10:32:07	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1220	73	2004-10-26 00:00:00	2009-10-26 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04083M	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1221	112	2004-10-26 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	80015A	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1222	112	2004-10-26 00:00:00	2008-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95038K	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1223	112	2004-10-26 00:00:00	2008-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01058X	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1224	112	2004-10-26 00:00:00	2006-06-29 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98012M	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1225	112	2004-10-26 00:00:00	2007-12-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	85003S	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1226	141	2004-10-26 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89016Q	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1227	164	2004-10-26 00:00:00	2008-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98030P	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1228	164	2004-10-26 00:00:00	2008-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01018P	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1229	164	2004-10-26 00:00:00	2008-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92030N	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1230	169	2004-10-26 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01016M	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1231	169	2004-10-26 00:00:00	2014-09-29 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01063U	\N	SENCOMLOIS	\N	2014-09-29 13:41:53	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2243	606	2011-10-01 00:00:00	2013-04-04 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01062T	\N	MEMBREDRT	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2264	301	2012-07-31 00:00:00	2014-06-04 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01014K	\N	PDTSEN	\N	2014-06-04 17:33:00	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1232	172	2004-10-26 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01057W	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1233	194	2004-10-26 00:00:00	2007-01-16 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98029W	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1234	194	2004-10-26 00:00:00	2007-01-16 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92045V	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1235	197	2004-10-26 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01058X	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1236	52	2004-10-26 00:00:00	2007-10-25 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04044E	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1237	72	2004-10-26 00:00:00	2007-10-26 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01003G	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1238	75	2004-10-26 00:00:00	2007-10-26 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01014K	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1239	75	2004-10-26 00:00:00	2007-10-26 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95025E	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1241	98	2004-10-26 00:00:00	2009-10-26 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01050P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1242	104	2009-10-21 00:00:00	2014-10-21 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08039A	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1243	138	2004-10-26 00:00:00	2004-10-26 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98013N	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1244	176	2004-10-26 00:00:00	2007-10-26 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95020Y	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1245	50	2004-10-26 00:00:00	2007-10-26 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01030K	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1246	50	2004-10-26 00:00:00	2007-01-25 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	89006N	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1247	52	2004-10-26 00:00:00	2007-10-25 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01059Y	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1248	52	2004-10-26 00:00:00	2007-10-25 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	89042S	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1249	52	2004-10-26 00:00:00	2007-10-25 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04052E	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1250	66	2004-10-26 00:00:00	2007-10-26 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04092N	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1251	66	2004-10-26 00:00:00	2007-10-26 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01010F	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
990	168	2001-12-19 00:00:00	2008-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	98010K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
991	179	2002-01-17 00:00:00	2005-03-27 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98023Q	\N	COMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
992	69	2002-01-16 00:00:00	2010-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01027Q	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
993	8	2002-02-14 00:00:00	2006-02-14 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89006N	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
994	46	2002-02-14 00:00:00	2008-02-08 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95035G	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
995	180	2002-02-14 00:00:00	2002-06-18 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95041E	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
996	180	2002-02-14 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92030N	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
997	180	2002-02-14 00:00:00	2008-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	98030P	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
998	180	2002-02-14 00:00:00	2008-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	98047Y	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
999	37	2002-02-21 00:00:00	2005-02-21 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01061S	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1000	602	\N	2002-06-07 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92029V	\N	MEMBREDRT	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1002	602	\N	2009-08-26 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92035T	\N	MEMBREDRT	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1003	604	\N	2002-04-25 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98041S	\N	MEMBREDRT	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1004	605	\N	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	80046H	\N	MEMBREDRT	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1005	606	1997-10-01 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92043T	\N	MEMBREDRT	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1006	606	\N	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98007Q	\N	MEMBREDRT	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1007	607	\N	2004-08-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95004Y	\N	MEMBREDRT	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1008	183	2002-04-25 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95050F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1009	183	2002-04-25 00:00:00	2005-04-25 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01010F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1010	183	2002-04-25 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95044H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2310	270	2012-11-27 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11055M	1	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2311	270	2012-11-27 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11025F	2	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1252	82	2004-10-26 00:00:00	2007-10-26 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95062K	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1253	95	2004-10-26 00:00:00	2007-10-26 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01031L	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1254	95	2004-10-26 00:00:00	2007-10-26 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92011K	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1255	95	2004-10-26 00:00:00	2007-10-26 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95067Q	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1256	128	2004-10-26 00:00:00	2007-10-26 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92030N	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1257	138	2004-10-26 00:00:00	2007-10-26 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01062T	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1258	147	2004-10-26 00:00:00	2007-10-26 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92045V	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1259	141	2004-10-26 00:00:00	2008-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98027U	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1260	166	2004-10-26 00:00:00	2010-09-07 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01007L	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1261	34	2004-10-26 00:00:00	2008-04-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01057W	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1262	34	2004-10-26 00:00:00	2008-04-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01019Q	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1263	611	2004-10-26 00:00:00	2007-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	80013X	1	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1264	611	2004-10-26 00:00:00	2007-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89040Q	2	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1265	611	2004-10-26 00:00:00	2007-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01024M	3	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1266	611	2004-10-26 00:00:00	2007-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86030A	4	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1267	611	2004-10-26 00:00:00	2007-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95034F	5	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1268	611	2004-10-26 00:00:00	2007-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95039L	6	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1269	611	2004-10-26 00:00:00	2007-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89035T	7	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1270	611	2004-10-26 00:00:00	2007-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01019Q	8	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1271	611	2004-10-26 00:00:00	2007-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	77002U	9	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
932	158	2001-10-29 00:00:00	2002-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	77009C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
933	150	2001-11-06 00:00:00	2006-11-06 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Vice-Président	98024R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
934	149	2001-11-06 00:00:00	2006-11-06 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	77019E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
935	30	2001-11-06 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95045J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
936	67	2001-10-30 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01030K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
937	67	2001-10-30 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92045V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
938	151	2001-10-29 00:00:00	2006-10-29 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92045V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
939	148	2001-10-29 00:00:00	2006-10-29 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95004Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
940	86	2001-10-29 00:00:00	2010-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01048V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
941	90	2001-10-29 00:00:00	2007-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98042T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
942	90	2001-10-29 00:00:00	2004-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95015C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
943	33	2001-10-29 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95050F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
944	140	2001-10-29 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95061J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
945	136	2001-10-29 00:00:00	2008-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	98029W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
946	136	2001-10-29 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01018P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
947	64	2001-10-29 00:00:00	2004-10-29 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	98030P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
948	113	\N	2005-05-27 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83021L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
949	113	\N	2005-05-27 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	96007G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
950	113	2001-10-30 00:00:00	2010-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01046T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
951	113	2001-10-29 00:00:00	2010-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01055U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
952	174	2001-10-29 00:00:00	2010-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	96007G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
953	139	2001-10-29 00:00:00	2007-06-21 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92007P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
954	139	2001-10-29 00:00:00	2010-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83021L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
955	146	2001-10-29 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01011G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
956	160	2001-10-29 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	79004F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
957	160	2001-10-29 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	77046H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
958	98	2001-10-31 00:00:00	2004-10-31 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	92042S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
959	151	2001-11-08 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86037H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
960	151	2001-11-08 00:00:00	2006-11-08 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89022N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
961	149	2001-11-08 00:00:00	2006-11-08 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95035G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
962	149	2001-11-08 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95017E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
963	150	2001-11-08 00:00:00	2006-11-08 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92030N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
964	150	2001-11-08 00:00:00	2006-11-08 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95049N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
965	148	2001-11-08 00:00:00	2006-11-08 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98029W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
966	35	2001-11-06 00:00:00	2004-11-26 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98018T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
967	168	2001-11-07 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83042R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
968	177	2001-10-29 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95042F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
969	177	2001-10-29 00:00:00	2007-07-19 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01043Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
970	67	2001-11-08 00:00:00	2002-06-18 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95041E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
971	107	2001-11-14 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95033E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
972	177	2001-11-13 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	00003C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
973	148	2001-11-15 00:00:00	2002-06-18 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95041E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
974	70	2001-11-15 00:00:00	2010-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01019Q	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
975	72	2001-11-22 00:00:00	2004-11-22 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	96004D	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
976	72	2001-11-22 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95040D	4	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
977	72	2001-11-22 00:00:00	2004-11-22 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01044R	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
978	72	2001-11-22 00:00:00	2004-11-22 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89007P	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
979	147	2001-11-27 00:00:00	2002-06-18 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95041E	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
980	111	2001-11-27 00:00:00	2004-11-27 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92035T	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
981	9	2001-11-27 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86041D	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
982	21	2002-12-16 00:00:00	2003-12-16 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83021L	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
983	141	2001-11-29 00:00:00	2010-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01019Q	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
984	104	2001-12-07 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95029J	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
985	24	2001-12-07 00:00:00	2003-02-04 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89014N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
986	178	2001-12-12 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	91002E	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
987	178	2001-12-12 00:00:00	2004-12-12 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92045V	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
988	50	2001-12-17 00:00:00	2004-12-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89022N	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
989	50	2001-12-17 00:00:00	2004-12-17 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	98030P	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
653	139	1999-07-13 00:00:00	2007-01-25 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89006N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
654	139	1999-07-13 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98054X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
655	113	1999-07-13 00:00:00	2008-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	98018T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
656	113	1999-07-13 00:00:00	2007-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	80039J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
657	113	1999-07-13 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95011X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
658	113	1999-07-13 00:00:00	2007-01-25 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89006N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
659	123	1999-09-15 00:00:00	2002-09-15 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	84004P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
660	123	1999-09-15 00:00:00	2002-06-07 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92017R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
661	98	1999-10-13 00:00:00	2002-10-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89013M	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
662	98	1999-10-13 00:00:00	2002-10-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	79004F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
663	98	1999-10-13 00:00:00	2002-10-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	88012G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
664	98	1999-10-13 00:00:00	2002-10-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89015P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
665	98	1999-10-13 00:00:00	2002-10-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98021N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
666	98	1999-10-13 00:00:00	2001-09-23 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	83017Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
667	98	1999-10-13 00:00:00	2002-10-13 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	77012W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
668	98	1999-10-13 00:00:00	2002-10-13 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95038K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
669	98	1999-10-13 00:00:00	2002-10-13 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95050F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
670	98	1999-10-13 00:00:00	2002-10-13 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	98032R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
671	138	2002-10-30 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95029J	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
672	138	1999-10-14 00:00:00	2001-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	92009R	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
673	138	2002-10-30 00:00:00	2005-10-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01059Y	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
674	8	1999-10-21 00:00:00	2002-02-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89006N	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
675	135 bis	1999-10-21 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	88008L	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
676	135 bis	1999-10-21 00:00:00	2001-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83033Q	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
677	161	1999-10-27 00:00:00	1973-09-23 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	74011H	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
678	161	1999-10-27 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	74022L	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1062	98	2002-11-21 00:00:00	2007-11-21 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	92042S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1063	98	2002-11-21 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	79004F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1064	98	2002-11-21 00:00:00	2007-11-21 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89013M	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1065	98	2002-11-21 00:00:00	2004-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	77012W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1066	98	2002-11-21 00:00:00	2007-11-21 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	98032R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1067	98	2002-11-21 00:00:00	2007-11-21 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98021N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1068	98	2002-11-21 00:00:00	2007-11-21 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95050F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1070	190	2002-11-29 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92011K	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1071	127	2003-01-21 00:00:00	2006-01-21 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95035G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1072	127	2003-01-21 00:00:00	2006-01-21 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89041R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1073	158	2003-01-22 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89045V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1074	86	2003-01-21 00:00:00	2007-12-16 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89045V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1075	191	2003-01-21 00:00:00	2006-01-21 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83031N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1076	191	2003-01-21 00:00:00	2006-01-21 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01012H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1077	127	2006-02-01 00:00:00	2009-02-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95035G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1078	127	2006-02-01 00:00:00	2009-02-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01009N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1079	611	\N	2005-09-22 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	59215E	\N	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1080	611	1983-10-26 00:00:00	1989-09-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	000474	\N	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1081	611	\N	2006-03-09 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	59523P	\N	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1082	611	\N	2010-05-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	58923X	\N	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1083	611	\N	1986-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	000114	\N	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1084	611	\N	1986-06-23 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	000095	\N	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1085	611	\N	2005-05-16 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	59248P	\N	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1086	611	\N	2006-05-04 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	58805S	\N	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1087	611	\N	2009-07-29 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	58630M	\N	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1088	611	\N	2000-04-21 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	59539X	\N	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1089	611	\N	1986-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	58626R	\N	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1091	612	\N	1997-03-07 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	62001R	\N	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1092	612	\N	1996-05-15 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83001G	\N	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1093	12	2003-04-08 00:00:00	2004-04-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95051G	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1095	12	2003-04-08 00:00:00	2006-04-08 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01064V	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1096	43	2003-05-21 00:00:00	2007-01-25 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89006N	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1102	81	2009-07-20 00:00:00	2012-07-20 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04090L	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1103	95	2003-06-03 00:00:00	2006-06-03 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95038K	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2238	231	2011-12-15 00:00:00	2017-06-22 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	depuis, dev dur	01022K	\N	SENCOMECON	\N	2017-06-26 11:36:27	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2242	605	2011-10-01 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01044R	\N	MEMBREDRT	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1104	74	2003-07-08 00:00:00	2008-07-08 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89037V	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1105	192	2003-07-08 00:00:00	2004-01-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98019U	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1106	128	2009-10-07 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92045V	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1107	24	2003-07-08 00:00:00	2006-06-11 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	a démissionné le 27/06/2006.	90003B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1108	152	2003-09-17 00:00:00	2008-09-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01057W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1109	157	2003-09-16 00:00:00	2006-09-11 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95007C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1110	171	2003-10-09 00:00:00	2006-10-09 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95015C	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1111	194	2003-10-09 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95004Y	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1112	194	2003-10-09 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92045V	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1113	194	2003-10-09 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	78006D	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1116	193	2003-10-09 00:00:00	2008-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98050T	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1117	193	2003-10-09 00:00:00	2008-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	89015P	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1119	193	2003-10-09 00:00:00	2011-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	92043T	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1120	23	2003-10-09 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	99003Q	\N	SENCOMETRD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1121	112	2003-10-09 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01058X	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1122	195	2003-11-27 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95012Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1123	195	2003-11-27 00:00:00	2008-11-27 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01037S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1124	195	2003-11-27 00:00:00	2008-11-27 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01019Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1125	195	2003-11-27 00:00:00	2008-11-27 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01038T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1126	195	2003-11-27 00:00:00	2008-11-27 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95005A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1127	195	2003-11-27 00:00:00	2008-11-27 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01003G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1128	123	2003-12-04 00:00:00	2006-12-04 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	84004P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1129	123	2003-12-04 00:00:00	2006-12-04 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95020Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1130	108	2003-12-16 00:00:00	2004-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	86047K	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1131	21	2003-12-16 00:00:00	2003-12-16 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83021L	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1132	21	2003-12-16 00:00:00	2004-12-16 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83021L	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1133	170	2003-12-18 00:00:00	2006-12-18 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	77002U	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1134	29	2003-12-17 00:00:00	2008-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89007P	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1135	29	2003-12-17 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01006K	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1136	29	2003-12-17 00:00:00	2006-08-11 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	74050Q	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1137	29	2003-12-17 00:00:00	2006-07-08 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	80048K	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1138	29	2003-12-17 00:00:00	2011-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01042P	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1139	29	2003-12-17 00:00:00	2011-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01021J	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1144	172	2004-01-20 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01024M	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1145	172	2004-01-20 00:00:00	2008-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89007P	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1146	172	2004-01-20 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	93005R	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1147	165	2004-02-03 00:00:00	2010-02-03 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95020Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1148	165	2004-02-03 00:00:00	2010-02-03 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95055L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1150	196	2004-02-10 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01042P	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1151	115	2004-02-12 00:00:00	2007-02-12 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98018T	\N	SENCOMETRD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1152	115	2004-02-12 00:00:00	2007-02-12 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	92008Q	\N	SENCOMETRD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1153	197	2004-02-24 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95038K	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1155	192	2004-03-04 00:00:00	2008-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98019U	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1158	96	2004-04-08 00:00:00	2007-04-08 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98035U	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1159	171	2004-04-08 00:00:00	2007-04-08 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01054T	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1161	34	2004-04-15 00:00:00	2008-04-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98047Y	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1162	34	2004-04-15 00:00:00	2007-04-15 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95039L	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1163	34	2004-04-15 00:00:00	2008-04-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95049N	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1164	34	2004-04-15 00:00:00	2007-04-15 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01057W	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1165	12	2004-05-13 00:00:00	2005-06-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04017B	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1166	141	2004-05-19 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89030N	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1167	64	2004-05-19 00:00:00	2007-05-19 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92030N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1178	131	2004-05-19 00:00:00	2004-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95014B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1179	131	2004-05-19 00:00:00	2007-05-19 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01039U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1180	94	2004-06-17 00:00:00	2007-06-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89030N	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1181	94	2004-06-17 00:00:00	2007-06-17 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01014K	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1182	82	2004-06-17 00:00:00	2007-06-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95025E	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1288	612	2004-10-26 00:00:00	2007-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95049N	4	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1289	612	2004-10-26 00:00:00	2008-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	84004P	5	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1290	612	2004-10-26 00:00:00	2007-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04074L	5	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1291	612	2004-10-26 00:00:00	2007-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01001E	6	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1292	612	2004-10-26 00:00:00	2007-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01042P	6	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1293	162	2004-10-26 00:00:00	2007-07-19 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01043Q	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1294	69	2004-10-28 00:00:00	2009-07-23 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86044G	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1295	69	2004-10-28 00:00:00	2008-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98046X	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1296	69	2009-09-30 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01027Q	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1297	69	2004-10-28 00:00:00	2007-06-24 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	99004R	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1298	3	2004-10-28 00:00:00	2011-01-24 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	77043E	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1299	23	2009-11-14 00:00:00	2013-11-14 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04035D	\N	SENCOMETRD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1300	201	2004-10-26 00:00:00	2005-03-23 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92029V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1301	201	2004-10-26 00:00:00	2008-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	98046X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1302	30	2004-10-26 00:00:00	2008-10-26 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04075M	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1303	33	\N	2003-06-27 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04094Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1304	33	2004-10-26 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	80045G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1305	33	\N	2003-06-27 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95050F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1306	32	2004-10-26 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	80045G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1307	140	2004-10-26 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95050F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1308	140	2004-10-26 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04093P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1309	64	2004-10-26 00:00:00	2007-10-26 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	98030P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1310	44	2009-05-20 00:00:00	2011-03-09 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86049M	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1311	113	\N	2005-05-27 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95032D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1312	113	\N	2005-05-27 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95011X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1313	113	2004-10-26 00:00:00	2010-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01018P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1314	113	\N	2005-05-27 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92030N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1315	113	2004-10-26 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	80031A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1316	158	2004-10-26 00:00:00	2007-12-16 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89045V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1317	188	2004-10-26 00:00:00	2008-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	77019E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1318	188	2004-10-26 00:00:00	2008-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98046X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1319	67	2004-10-26 00:00:00	2009-07-23 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95049N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1320	183	2004-10-26 00:00:00	2007-10-26 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95050F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1321	183	2004-10-26 00:00:00	2007-10-26 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95044H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1322	174	2004-10-26 00:00:00	2007-01-25 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89006N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1323	154	2004-10-26 00:00:00	2010-09-07 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95034F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1324	118	2004-10-26 00:00:00	2007-06-21 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92007P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1325	121	2004-10-26 00:00:00	2008-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98019U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1326	146	2004-10-26 00:00:00	2007-07-19 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01043Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
632	137	1999-04-12 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95014B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
633	146	1999-04-12 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95014B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
635	121	1999-04-28 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89023P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
636	160	1999-05-06 00:00:00	2001-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	79004F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
637	160	1999-05-06 00:00:00	2001-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92024Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
638	24	1999-05-15 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89037V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
639	90	1999-05-12 00:00:00	2001-09-23 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	92012L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
640	123	1999-05-14 00:00:00	1999-09-14 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	84004P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
641	37	1999-05-20 00:00:00	2002-02-20 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83003J	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
642	147	1999-05-20 00:00:00	2001-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83028T	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
643	147	1999-05-20 00:00:00	2001-10-18 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86041D	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
644	114	1999-05-25 00:00:00	1999-06-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	90003B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
645	159	1999-05-25 00:00:00	2002-05-25 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89030N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
646	159	1999-05-25 00:00:00	2002-05-25 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86011W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
647	159	1999-05-25 00:00:00	2002-05-25 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86030A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
648	114	1999-05-25 00:00:00	1999-06-17 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95052H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
649	67	1999-05-31 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95049N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
650	154	1999-05-31 00:00:00	2008-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	94003T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
651	154	1999-05-31 00:00:00	2004-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	77012W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
652	44	2002-11-06 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86049M	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1012	22	2002-04-25 00:00:00	2005-04-25 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01036R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1013	184	2002-07-10 00:00:00	2004-11-26 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95036H	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1014	184	2002-07-10 00:00:00	2005-07-10 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95019G	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1015	186	2002-07-10 00:00:00	2004-11-26 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92005M	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1016	186	2002-07-10 00:00:00	2006-07-10 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	92040Q	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1017	185	2005-10-13 00:00:00	2008-10-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95025E	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1018	185	2005-10-13 00:00:00	2008-10-13 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	98038X	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1019	602	\N	2009-08-26 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83011J	\N	MEMBREDRT	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1020	181	2002-07-23 00:00:00	2006-12-21 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01060R	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1021	181	2002-07-23 00:00:00	2006-12-21 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01014K	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1022	1	2002-07-23 00:00:00	2007-07-23 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98044V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1023	102	2002-07-23 00:00:00	2007-07-23 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98044V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1024	23	2002-07-23 00:00:00	2007-07-23 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95047L	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1025	13	2002-07-29 00:00:00	2005-07-29 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92035T	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1026	187	2002-07-29 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86037H	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1027	148	2002-09-16 00:00:00	2007-09-16 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	78006D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1028	182	2002-09-16 00:00:00	2005-09-16 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98024R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1029	182	2002-09-16 00:00:00	2005-09-16 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01018P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1030	24	2002-09-16 00:00:00	2008-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	89015P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1031	24	2002-09-16 00:00:00	2010-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01021J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2312	270	2012-11-27 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01027Q	3	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2335	123	2013-02-01 00:00:00	2016-02-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11090Q	\N	PDTSEN	\N	2014-11-05 11:00:40	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1032	188	2002-09-16 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98046X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1033	188	2002-09-16 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89045V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1034	123	2002-09-16 00:00:00	2005-09-16 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95020Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1035	123	2002-09-16 00:00:00	2005-09-16 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	84004P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1036	153	2002-09-16 00:00:00	2002-12-31 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83011J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1037	152	2002-09-16 00:00:00	2003-08-28 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98043U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1038	159	2002-09-16 00:00:00	2005-09-16 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89030N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1039	159	2002-09-16 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86011W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1040	159	2002-09-16 00:00:00	2005-09-16 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86030A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1041	67	2002-09-16 00:00:00	2005-03-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	78006D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1042	69	2002-10-01 00:00:00	2004-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	99004R	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1043	147	2002-10-01 00:00:00	2005-03-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	78006D	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1044	180	2002-10-01 00:00:00	2005-03-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	78006D	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1045	158	2002-10-07 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	59312E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1046	168	2002-10-07 00:00:00	2004-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	59312E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1047	2	2002-10-15 00:00:00	2010-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01024M	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1048	81	2002-10-15 00:00:00	2005-10-15 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95038K	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1050	189	2002-11-21 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86041D	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1051	189	2002-11-21 00:00:00	2005-11-21 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	88009M	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1052	143	2002-11-21 00:00:00	2004-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	77043E	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1053	75	2002-11-21 00:00:00	2004-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95040D	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1054	75	2005-10-13 00:00:00	2008-10-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	88009M	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1055	75	2002-11-21 00:00:00	2004-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	86011W	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1056	75	2005-10-13 00:00:00	2008-10-13 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	89030N	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1666	189	2008-01-24 00:00:00	2010-10-18 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92029V	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1667	115	2008-01-23 00:00:00	2011-01-23 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98018T	\N	SENCOMETRD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1668	115	2008-01-23 00:00:00	2011-01-23 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	92008Q	\N	SENCOMETRD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1795	49	2008-12-11 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	94003T	\N	SENCOMFINC	\N	2014-09-23 15:22:46	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1796	112	2008-12-04 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98028V	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1797	112	2008-12-11 00:00:00	2010-10-11 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01017N	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1798	112	2008-12-11 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01037S	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1799	606	2008-10-01 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	87003B	\N	COMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1800	95	2009-02-18 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92011K	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1801	95	2009-02-18 00:00:00	2012-02-18 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01003G	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1802	95	2009-02-18 00:00:00	2012-02-18 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04088S	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1803	95	2009-02-18 00:00:00	2012-02-18 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04090L	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1804	95	2009-02-18 00:00:00	2012-02-18 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95067Q	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1805	201	2009-02-17 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08011M	\N	PDTSEN	\N	2014-09-23 15:34:07	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1806	201	2009-02-17 00:00:00	2011-01-06 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	démission par lettre du 22/12/2010 	08032S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1868	188	2009-11-26 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	remplaçant de M. Marc, démissionnaire	01051Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1950	186	2011-01-13 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89007P	\N	SENCOMAFCL	\N	2014-09-28 16:42:05	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1951	186	2011-01-13 00:00:00	2011-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	85002R	186	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1953	198	2011-01-12 00:00:00	2014-01-12 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	92040Q	198	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1968	143	2011-03-08 00:00:00	2013-05-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08011M	\N	SENCOMFINC	\N	2013-11-23 17:20:12	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1644	64	2012-10-01 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	nommé suppléant 25 11 2010 devenu titulaire 01 10 2012	98030P	\N	PDTSEN	\N	2014-09-28 13:19:48	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1645	203	2010-04-26 00:00:00	2013-04-26 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04047H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1646	183	2007-11-12 00:00:00	2010-11-12 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95050F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1647	183	2007-11-14 00:00:00	2010-11-14 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95044H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1648	202	2007-11-12 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	78003A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1686	147	2011-05-26 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04037F	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1720	100	2008-12-04 00:00:00	2009-03-05 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Supprimé par l'article 10 de la loi n° 2009-258 du 5 mars 2009	04059M	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1721	167	2008-12-04 00:00:00	2010-04-16 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01039U	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1722	42	2014-11-13 00:00:00	2019-11-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14179A	\N	SENCOMAFCL	\N	2014-11-14 11:45:57	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1723	17	2008-12-04 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04042C	\N	SENCOMETRD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1724	3	2008-12-11 00:00:00	2011-01-24 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01042P	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1725	3	2008-12-11 00:00:00	2011-01-24 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04063H	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1726	12	2008-12-04 00:00:00	2011-12-04 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04045F	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1727	16	2008-12-04 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04071H	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1728	20	2008-12-04 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01022K	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1729	29	2008-12-04 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04099V	\N	SENCOMAFCL	\N	2014-08-26 10:37:00	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1730	29	2008-12-11 00:00:00	2011-12-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	démission	98035U	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1972	198	2011-04-26 00:00:00	2014-01-12 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92031P	198	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2112	240	2011-12-15 00:00:00	2012-01-31 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11090Q	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2113	270	2011-12-15 00:00:00	2012-10-31 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11109J	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2114	270	2011-12-15 00:00:00	2012-10-31 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11071M	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2115	278	2011-12-15 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11089X	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2116	283	2011-12-15 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11104D	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2117	49	2011-12-15 00:00:00	2014-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	07026Q	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2118	99	2011-12-15 00:00:00	2012-07-26 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	démission	04059M	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2119	53	2011-12-20 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	09001P	\N	COMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2120	65	2011-12-20 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04043D	\N	COMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2121	76	2011-12-20 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01011G	\N	COMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2122	97	2011-12-20 00:00:00	2012-07-21 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08064B	\N	COMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2123	12	2011-12-20 00:00:00	2014-12-20 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08041T	\N	SENCOMSOCI	\N	2014-11-05 11:20:29	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2124	127	2011-12-20 00:00:00	2014-12-20 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11048N	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2125	128	2011-12-20 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04046G	\N	SENCOMSOCI	\N	2014-09-28 17:07:41	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2126	128	2011-12-20 00:00:00	2014-12-20 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08041T	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2127	147	2011-12-20 00:00:00	2014-12-15 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08052W	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2128	16	2011-12-20 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08020N	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2129	162	2011-12-20 00:00:00	2016-11-10 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11093T	\N	SENCOMSOCI	\N	2016-12-06 16:44:32	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2130	162	2011-12-20 00:00:00	2016-11-10 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04092N	\N	SENCOMSOCI	\N	2016-12-06 16:44:42	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2001	270	2011-12-15 00:00:00	2012-10-31 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04057K	\N	SENCOMAFEU	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2002	17	2011-12-15 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04078Q	\N	SENCOMETRD	\N	2014-11-07 12:08:26	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2003	280	2011-12-15 00:00:00	2014-12-08 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11064N	\N	SENCOMETRD	\N	2014-12-17 10:36:52	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2004	126	2011-12-15 00:00:00	2014-12-15 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04042C	\N	SENCOMETRD	\N	2015-02-11 17:14:15	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2005	126	2011-12-15 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95055L	\N	SENCOMETRD	\N	2014-07-11 16:04:43	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2006	273	2011-12-15 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89015P	\N	COMETRD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2007	279	2011-12-15 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08059E	\N	COMETRD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2131	164	2011-12-20 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04046G	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2132	164	2011-12-20 00:00:00	2014-02-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08046Y	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2133	164	2011-12-20 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04081K	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2134	180	2011-12-20 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04051D	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2135	190	2011-12-20 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08026U	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2136	194	2011-12-20 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98029W	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2137	194	2011-12-20 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11061K	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2138	212	2011-12-20 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11063M	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2139	214	2011-12-20 00:00:00	2013-06-27 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95045J	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2140	232	2011-12-20 00:00:00	2016-03-23 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04067M	\N	SENCOMSOCI	\N	2016-03-23 17:50:29	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2141	232	2011-12-20 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	07029T	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2142	247	2011-12-20 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	10006L	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1327	177	2004-10-26 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	00003C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1328	177	2004-10-26 00:00:00	2004-11-26 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04069P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1329	160	2004-10-26 00:00:00	2008-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04035D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1330	160	2004-10-26 00:00:00	2007-09-18 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	77044F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1331	156	2004-10-26 00:00:00	2008-10-26 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04070G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1332	149	2004-10-26 00:00:00	2009-10-26 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	00003C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1333	151	2010-02-19 00:00:00	2011-12-21 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95032D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1334	195	2004-10-26 00:00:00	2009-07-23 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86044G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1335	131	2004-10-26 00:00:00	2007-10-26 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01025N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1336	107	2010-02-10 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01046T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1337	137	2004-10-26 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04081K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1338	137	2004-10-26 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04037F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1339	159	2004-10-26 00:00:00	2007-10-26 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01014K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1340	31	2004-11-04 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98047Y	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1341	112	2004-11-04 00:00:00	2007-07-04 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	71003U	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1342	112	2004-11-04 00:00:00	2008-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01037S	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1343	126	2004-11-04 00:00:00	2007-06-26 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	78006D	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1344	135	2004-11-04 00:00:00	2004-12-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	88008L	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1345	135 bis	2004-11-04 00:00:00	2004-12-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	88008L	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1940	270	2010-12-22 00:00:00	2012-10-31 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	77043E	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1941	270	2010-12-22 00:00:00	2011-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01031L	270	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1942	270	2010-12-22 00:00:00	2012-10-31 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01063U	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1943	270	2010-12-22 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01007L	270	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1944	270	2010-12-22 00:00:00	2012-10-31 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01065W	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1945	270	2010-12-22 00:00:00	2011-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04085P	270	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1946	270	2010-12-22 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04062G	270	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1947	270	2010-12-22 00:00:00	2011-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04100U	270	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1948	270	2010-12-22 00:00:00	2011-12-20 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	démission	98035U	270	SENCOMAFEU	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1949	270	2010-12-22 00:00:00	2011-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04057K	270	SENCOMAFEU	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1623	148	2007-09-26 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	78006D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1676	242	2008-02-07 00:00:00	2008-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	89017R	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1677	242	2008-02-07 00:00:00	2008-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98042T	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1818	121	2009-02-17 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98019U	\N	PDTSEN	\N	2014-11-24 09:48:11	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1819	121	2009-02-17 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04036E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1820	177	2009-02-19 00:00:00	2013-02-11 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08031R	\N	PDTSEN	\N	2014-09-26 13:56:20	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1821	160	2009-02-17 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04035D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1823	228	2009-02-17 00:00:00	2010-10-18 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92029V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1824	213	2009-02-17 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01034P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1825	213	2009-02-17 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95035G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1826	210	2009-02-17 00:00:00	2012-02-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04044E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1827	219	2009-02-17 00:00:00	2011-01-16 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08047A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1828	168	2009-02-17 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95028H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1829	159	2009-02-17 00:00:00	2010-09-07 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01049W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1849	249	2009-05-26 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	1ere nomination	97004H	\N	COMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1850	249	2009-05-26 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	08039A	\N	COMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1863	612	2009-09-15 00:00:00	2011-01-23 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	suite nomination M. Mercier au Gouvernement	95004Y	5	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1465	203	2006-01-16 00:00:00	2007-11-29 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Arrêté du 17 août 2005 (JO du 31 août 2005 portant nomination au conseil d'orientation de l'observatiure de la délinquance prévoit un mandat de 3 ans à compter de la signature de l'arrêté	04072J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1507	227	2006-05-09 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01052R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1758	144	2008-12-11 00:00:00	2010-03-06 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	81015E	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1759	155	2008-12-04 00:00:00	2011-12-04 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	02002K	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1760	162	2008-12-11 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	77019E	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1761	163	2008-12-04 00:00:00	2012-07-21 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04090L	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1762	164	2008-12-11 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98011L	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1763	164	2008-12-04 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08046Y	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2267	109	2012-09-12 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95063L	\N	COMLOIS	\N	2014-12-17 16:15:21	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2268	104	2012-09-13 00:00:00	2014-12-10 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11083R	\N	SENCOMAFCL	\N	2014-12-12 10:35:08	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2269	99	2012-09-13 00:00:00	2014-11-25 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11057P	\N	SENCOMAFCL	\N	2014-12-16 08:40:46	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1764	164	2008-12-04 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01018P	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1765	164	2008-12-04 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92030N	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1766	169	2008-12-04 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98005N	\N	SENCOMAFCL	\N	2014-11-03 09:43:00	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1767	169	2008-12-04 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	depuis dev dur	08019V	\N	SENCOMECON	\N	2014-08-26 10:26:01	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1768	172	2008-12-04 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01012H	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1769	180	2008-12-04 00:00:00	2014-02-13 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	08046Y	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1770	180	2008-12-04 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	98011L	\N	SENCOMFINC	\N	2014-09-23 15:13:35	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1771	185	2008-12-04 00:00:00	2011-12-04 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95025E	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1772	185	2008-12-04 00:00:00	2011-12-04 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01015L	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1773	189	2008-12-04 00:00:00	2011-12-04 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95036H	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1774	192	2008-12-04 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	depuis, aff éco	90003B	\N	SENCOMECON	\N	2014-08-26 10:39:34	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1775	194	2008-12-04 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98029W	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1776	194	2008-12-04 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92045V	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1777	194	2008-12-11 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04037F	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1778	207	2008-12-04 00:00:00	2011-12-04 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04089T	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1779	206	2008-12-04 00:00:00	2012-01-11 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	date de saisine pour désignation	04049K	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1780	208	2008-12-04 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92031P	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1781	212	2008-12-04 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01018P	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1782	217	2008-12-04 00:00:00	2010-09-07 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08038Y	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2270	97	2012-09-12 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01046T	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1783	222	2008-12-04 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98042T	\N	SENCOMAFCL	\N	2014-09-23 15:17:24	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1784	223	2008-12-04 00:00:00	2010-09-07 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08038Y	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2301	188	2012-10-05 00:00:00	2014-06-04 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	remplacement de M. Boulaud, démissionnaire	92015P	\N	PDTSEN	\N	2014-06-04 17:34:24	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1786	232	2008-12-04 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	96007G	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1787	232	2008-12-04 00:00:00	2011-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04058L	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1788	235	2010-12-09 00:00:00	2012-12-09 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04085P	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1789	236	2008-12-11 00:00:00	2011-10-16 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04053F	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1790	242	2008-12-04 00:00:00	2014-05-27 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98042T	\N	SENCOMAFCL	\N	2014-05-27 17:41:10	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1791	21	2009-01-30 00:00:00	2010-01-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83021L	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1792	610	2009-02-04 00:00:00	2010-11-02 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01026P	\N	PDTOPECST	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1793	610	2009-02-04 00:00:00	2014-02-04 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01016M	\N	PDTOPECST	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1846	13	2008-12-13 00:00:00	2011-12-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04053F	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1873	257	2009-12-14 00:00:00	2012-12-14 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98036V	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1830	248	2009-03-03 00:00:00	2012-03-03 00:00:00	TITULAIRE	ANCIEN	\N	président	\N	nommé président fin mai 2009 par M. Novelli	98023Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1860	225	2009-05-09 00:00:00	2009-05-09 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95049N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1861	253	2009-09-06 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	ou à la fin de son mandat de président de commission de l'économie	95030B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1874	257	2009-12-14 00:00:00	2012-07-21 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04090L	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1888	261	2010-04-06 00:00:00	2015-04-06 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	depuis, dev dur	08028W	261	SENCOMECON	\N	2014-11-05 11:53:55	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2302	270	2012-10-25 00:00:00	2012-10-31 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	12039E	\N	SENCOMCDD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2303	230	2012-10-25 00:00:00	2017-06-22 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08038Y	\N	SENCOMCDD	\N	2017-06-26 11:40:09	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1912	268	2010-11-08 00:00:00	2013-11-08 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01052R	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1913	268	2010-11-08 00:00:00	2013-11-08 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	08038Y	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1959	272	2011-02-17 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95019G	\N	SENCOMETRD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1960	272	2011-02-17 00:00:00	2011-11-28 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	démission	95032D	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1961	612	2011-02-16 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	remplacement de M. Fauchon	01024M	7	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1962	612	2011-02-16 00:00:00	2011-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	remplacement de M. About	95005A	7	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1969	275	2011-03-11 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	membre du (1) et (2)	86049M	\N	PDTSEN	\N	2014-09-23 15:16:16	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1970	275	2011-03-15 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	membre du (2)	08022Q	\N	PDTSEN	\N	2014-09-23 15:16:40	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1971	275	2011-03-11 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	membre du (1)	89007P	\N	PDTSEN	\N	2014-09-23 15:16:26	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1696	612	2008-10-21 00:00:00	2011-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04074L	2	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1697	612	2008-10-21 00:00:00	2011-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01057W	1	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1698	612	2008-10-21 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92020L	3	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1699	612	2008-10-21 00:00:00	2011-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01051Q	3	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1700	612	2008-10-21 00:00:00	2010-03-06 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86030A	4	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1701	612	2010-03-30 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	suite nomination M. Haenel au CC	01019Q	6	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1702	612	2008-10-21 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	02001J	4	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2232	244	2012-03-15 00:00:00	2014-06-18 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83011J	\N	PDTSEN	\N	2014-07-21 10:55:24	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2244	13	2012-07-05 00:00:00	2015-06-18 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	rapporteur gén remplaçant de Mme Bricq	98046X	\N	SENCOMFINC	\N	2015-06-19 09:47:26	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2259	95	2012-07-24 00:00:00	2015-07-24 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04088S	\N	SENCOMCDD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1703	612	2008-10-21 00:00:00	2011-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04077P	4	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1704	612	2008-10-21 00:00:00	2011-01-23 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92022N	5	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1705	612	2008-10-21 00:00:00	2009-07-23 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95049N	6	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1706	245	2008-10-16 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01015L	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1707	245	2008-10-16 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01058X	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1708	205	2008-10-16 00:00:00	2011-05-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01057W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1709	205	2008-10-16 00:00:00	2011-05-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95055L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1669	199	2008-02-08 00:00:00	2010-11-02 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01026P	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1670	46	2008-02-08 00:00:00	2014-02-08 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95035G	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1671	72	2008-02-07 00:00:00	2011-02-07 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89007P	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1683	176	2011-04-06 00:00:00	2013-11-18 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01008M	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1684	240	2008-04-09 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	07033P	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1794	30	2009-02-04 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04075M	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1896	263	2010-05-25 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	1ere nomination	01058X	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1914	189	2010-11-12 00:00:00	2013-11-12 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08022Q	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1916	9	2010-11-12 00:00:00	2009-01-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08022Q	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1917	13	2010-11-12 00:00:00	2013-11-12 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83011J	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1918	112	2010-11-12 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98019U	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1919	108	2010-11-12 00:00:00	2015-05-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	89017R	\N	SENCOMFINC	\N	2015-01-14 16:08:48	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2260	95	2012-07-24 00:00:00	2014-05-03 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	12038D	\N	SENCOMCDD	\N	2014-05-05 14:38:45	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2261	95	2012-07-24 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08050U	\N	SENCOMCAE	\N	2014-09-28 12:44:31	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1618	88	2010-12-17 00:00:00	2013-12-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	77002U	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1619	162	2007-09-25 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01009N	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1620	207	2010-06-28 00:00:00	2013-06-28 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04046G	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1621	232	2007-09-25 00:00:00	2008-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	96007G	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1622	239	2010-10-13 00:00:00	2013-10-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98010K	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1652	50	2010-05-25 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01030K	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1654	147	2010-12-17 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92045V	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1655	128	2010-12-17 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92030N	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1656	241	2009-12-23 00:00:00	2011-12-15 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04047H	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1682	202	2010-02-11 00:00:00	2013-02-11 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95020Y	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1842	65	2008-12-05 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04043D	\N	COMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1843	53	2011-02-16 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	77002U	\N	COMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1973	276	2011-05-10 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04070G	276	SENCOMAFCL	\N	2014-09-23 15:34:37	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1976	277	2011-05-12 00:00:00	2013-05-12 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04071H	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1977	278	2011-05-18 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	97004H	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1978	278	2011-05-18 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08039A	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1979	115	2011-05-24 00:00:00	2011-12-19 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	démisssion	98018T	\N	SENCOMETRD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1980	115	2011-05-24 00:00:00	2014-05-24 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08017T	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1989	193	2008-12-05 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	depuis aff éco	98050T	\N	SENCOMECON	\N	2014-07-11 16:40:40	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1990	193	2008-12-05 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	depuis, aff éco	08054Y	\N	SENCOMECON	\N	2014-07-11 16:40:54	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1991	118	2011-12-06 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95039L	118	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1992	158	2011-12-06 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86034E	158	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1993	188	2011-12-06 00:00:00	2012-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01051Q	188	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1994	188	2011-12-06 00:00:00	2014-06-04 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95028H	188	PDTSEN	\N	2014-06-04 17:34:24	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1996	72	2011-12-13 00:00:00	2014-12-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11074Q	\N	SENCOMAFCL	\N	2014-10-30 17:49:55	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1997	67	2011-12-20 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04092N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1999	160	2011-12-20 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04035D	\N	PDTSEN	\N	2014-11-07 12:18:07	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2000	228	2011-12-20 00:00:00	2013-04-10 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	77043E	\N	PDTSEN	\N	2014-09-26 10:47:46	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2009	112	2011-12-15 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95038K	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2010	112	2011-12-15 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	depuis, dev dur	01058X	\N	SENCOMECON	\N	2014-07-11 15:55:34	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2011	112	2011-12-15 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98037W	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2012	112	2011-12-15 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	depuis, dev dur	98038X	\N	SENCOMECON	\N	2014-07-11 15:55:19	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2013	120	2011-12-15 00:00:00	2016-12-15 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	depuis, dev dur	08055A	\N	SENCOMECON	\N	2014-07-11 16:02:11	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2014	141	2011-12-15 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	dev dur ensuite	08050U	\N	SENCOMECON	\N	2014-07-11 10:46:16	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2015	155	2011-12-15 00:00:00	2014-12-15 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	depuis, aff éco	11095V	\N	SENCOMECON	\N	2014-07-11 16:11:38	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2016	16	2011-12-15 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	depuis, aff éco	90003B	\N	SENCOMECON	\N	2014-07-11 16:32:07	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2266	301	2012-07-31 00:00:00	2014-06-04 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92015P	\N	MEMBREDRT	\N	2014-06-04 17:33:00	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2309	12	2012-11-22 00:00:00	2014-08-31 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	96007G	\N	SENCOMSOCI	\N	2014-09-01 17:59:09	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2017	161	2011-12-15 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	depuis dev dur	95021A	\N	SENCOMECON	\N	2014-07-11 11:35:22	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2018	161	2011-12-15 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	depuis aff éco	04088S	\N	SENCOMECON	\N	2014-07-11 11:35:13	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2019	169	2011-12-15 00:00:00	2017-03-20 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	depuis dev dur	11114F	\N	SENCOMECON	\N	2017-03-21 10:14:30	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2020	172	2011-12-15 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	dev dur depuis	80013X	\N	SENCOMECON	\N	2014-11-05 11:39:42	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2021	181	2011-12-15 00:00:00	2014-02-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	depuis dev dur	01015L	\N	SENCOMECON	\N	2014-09-26 14:14:41	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2022	181	2011-12-15 00:00:00	2014-02-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	depuis affaires éco	01061S	\N	SENCOMECON	\N	2014-09-26 14:14:28	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2023	185	2011-12-15 00:00:00	2014-12-15 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	dev dur depuis	11065P	\N	SENCOMECON	\N	2014-12-19 14:47:36	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2025	189	2011-12-15 00:00:00	2013-11-12 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95036H	\N	SENCOMECON	\N	2014-08-26 10:38:36	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2026	20	2011-12-15 00:00:00	2017-03-07 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	depuis aff éco	01022K	\N	SENCOMECON	\N	2017-04-12 11:02:16	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2028	230	2011-12-15 00:00:00	2012-07-21 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04090L	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2030	24	2011-12-15 00:00:00	2015-03-20 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	aff éco depuis	11100Y	\N	SENCOMECON	\N	2015-04-13 18:17:39	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2031	24	2011-12-15 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	aff éco depuis	08016S	\N	SENCOMECON	\N	2014-07-11 10:48:53	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2032	240	2011-12-15 00:00:00	2012-01-31 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04033B	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2033	240	2011-12-15 00:00:00	2012-01-31 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95038K	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2034	243	2011-12-15 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	depuis aff éco	04089T	\N	SENCOMECON	\N	2014-07-11 11:50:46	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2035	245	2011-12-15 00:00:00	2014-04-23 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89014N	\N	SENCOMECON	\N	2014-04-23 16:22:41	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2036	245	2011-12-15 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	depuis dev dur	11094U	\N	SENCOMECON	\N	2014-12-19 14:34:38	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1984	279	2011-06-22 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01021J	\N	COMETRD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1985	279	2011-06-22 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08018U	\N	COMLOIS	\N	2014-09-23 15:22:14	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1986	280	2011-06-22 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92008Q	\N	SENCOMETRD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1987	205	2011-06-22 00:00:00	2014-06-22 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04044E	205	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1988	205	2011-06-22 00:00:00	2014-06-22 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95055L	205	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2037	251	2012-09-13 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	depuis, aff éco	09012S	\N	SENCOMECON	\N	2014-07-11 16:10:44	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2038	252	2011-12-15 00:00:00	2014-02-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11051H	\N	SENCOMECON	\N	2014-02-19 09:15:26	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2040	263	2011-12-15 00:00:00	2014-02-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11045K	\N	SENCOMECON	\N	2014-02-19 10:13:32	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2041	270	2011-12-15 00:00:00	2011-12-22 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	invalidation de son élection	11081P	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2042	270	2011-12-15 00:00:00	2012-10-31 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	reste à l'économie	04094Q	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2043	282	2011-12-15 00:00:00	2014-12-15 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	dev dur ensuite	08019V	\N	SENCOMECON	\N	2014-11-05 17:04:09	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2044	282	2011-12-15 00:00:00	2014-12-15 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	dev dur ensuite	01022K	\N	SENCOMECON	\N	2014-11-14 18:00:37	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2045	282	2011-12-15 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	dev dur ensuite	06004E	\N	SENCOMECON	\N	2014-07-11 10:44:39	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2046	282	2011-12-15 00:00:00	2013-02-06 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	08036W	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2047	284	2011-12-15 00:00:00	2017-06-20 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	depuis dev dur	11107G	\N	SENCOMECON	\N	2017-06-20 17:45:04	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2048	285	2011-12-15 00:00:00	2014-03-05 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11077T	\N	SENCOMECON	\N	2014-03-06 14:46:34	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2049	287	2011-12-15 00:00:00	2016-12-15 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	depuis, aff éco	11099A	\N	SENCOMECON	\N	2014-07-11 16:39:39	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2050	287	2011-12-15 00:00:00	2016-12-15 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	depuis, dev dur	01008M	\N	SENCOMECON	\N	2014-07-11 16:39:57	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2051	29	2011-12-15 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	depuis, dev dur	08021P	\N	SENCOMECON	\N	2014-07-11 16:17:15	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2287	157	2012-10-03 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11106F	\N	SENCOMETRD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2052	29	2011-12-15 00:00:00	2016-07-07 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	depuis, dev dur	11111C	\N	SENCOMECON	\N	2016-07-19 10:47:32	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2159	98	2011-12-20 00:00:00	2016-12-20 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98053W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2053	72	2011-12-15 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	depuis développement durable	95009E	\N	SENCOMECON	\N	2014-10-30 17:50:30	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2054	75	2011-12-15 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95062K	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2055	75	2011-12-15 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98037W	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2056	75	2011-12-15 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01043Q	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2057	75	2011-12-15 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	08054Y	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2058	81	2011-12-15 00:00:00	2014-12-15 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04089T	\N	SENCOMCAE	\N	2014-07-11 10:41:40	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2059	73	2011-12-15 00:00:00	2016-12-15 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	depuis aff éco	01015L	\N	SENCOMECON	\N	2014-07-11 16:30:00	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2060	207	2011-12-15 00:00:00	2014-04-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11051H	\N	SENCOMECON	\N	2014-11-05 11:04:45	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2061	112	2011-12-15 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01037S	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2062	112	2011-12-15 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98027U	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2065	126	2011-12-15 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	88008L	\N	SENCOMFINC	\N	2014-07-11 16:04:34	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2066	126	2011-12-15 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04061F	\N	SENCOMFINC	\N	2014-07-11 16:04:49	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2067	13	2011-12-15 00:00:00	2012-06-16 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04053F	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2068	144	2011-12-15 00:00:00	2015-10-07 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01037S	\N	SENCOMFINC	\N	2015-10-08 11:43:54	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2069	147	2011-12-15 00:00:00	2014-12-15 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04066L	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2070	162	2011-12-15 00:00:00	2016-11-10 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04055H	\N	SENCOMFINC	\N	2016-12-06 16:44:57	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2071	164	2011-12-15 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01013J	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2072	180	2011-12-15 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11088W	\N	SENCOMFINC	\N	2015-03-04 09:41:59	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2073	187	2011-12-15 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01031L	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2340	37	2013-02-20 00:00:00	2013-01-24 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08050U	\N	SENCOMCAE	\N	2014-09-23 14:25:47	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2341	37	2013-02-20 00:00:00	2015-01-05 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01061S	\N	SENCOMCAE	\N	2015-01-16 15:38:35	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2074	193	2011-12-15 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11040E	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2076	194	2011-12-15 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11070L	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2077	236	2011-12-15 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08011M	\N	SENCOMFINC	\N	2014-11-05 11:52:22	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2078	236	2011-12-15 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	77043E	\N	SENCOMFINC	\N	2014-09-28 16:59:41	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2079	254	2011-12-15 00:00:00	2016-03-11 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11069T	\N	SENCOMFINC	\N	2016-03-11 18:02:51	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2080	270	2011-12-15 00:00:00	2012-10-31 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01027Q	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2081	270	2011-12-15 00:00:00	2012-10-31 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01031L	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2083	34	2011-12-15 00:00:00	2014-12-15 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92039X	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2084	34	2011-12-15 00:00:00	2014-12-15 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01057W	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2085	50	2011-12-15 00:00:00	2016-12-15 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08014Q	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2086	69	2011-12-15 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95037J	\N	COMFINC	\N	2014-07-11 11:24:00	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2087	69	2011-12-15 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08061X	\N	COMFINC	\N	2014-07-11 11:24:15	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2088	69	2011-12-15 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04034C	\N	COMFINC	\N	2014-07-11 11:24:36	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2089	172	2011-12-15 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01019Q	\N	SENCOMLOIS	\N	2014-11-05 11:41:08	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2090	196	2015-10-26 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04085P	\N	SENCOMLOIS	\N	2015-10-27 12:35:56	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2092	270	2011-12-15 00:00:00	2012-10-31 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11072N	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2093	270	2011-12-15 00:00:00	2012-10-31 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11113E	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2094	282	2011-12-15 00:00:00	2014-12-15 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11072N	\N	SENCOMLOIS	\N	2014-11-14 18:01:33	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2095	282	2011-12-15 00:00:00	2014-11-18 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11029K	\N	SENCOMLOIS	\N	2014-11-20 09:54:06	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2096	286	2011-12-15 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08032S	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2097	286	2011-12-15 00:00:00	2013-04-09 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04047H	\N	SENCOMLOIS	\N	2015-03-04 11:33:37	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2098	29	2011-12-15 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11026G	\N	SENCOMLOIS	\N	2015-01-09 18:23:52	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2100	34	2011-12-15 00:00:00	2014-12-15 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01007L	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2101	42	2011-11-15 00:00:00	2016-11-15 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11015D	\N	SENCOMLOIS	\N	2016-12-01 15:25:11	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2102	249	2011-12-15 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11089X	\N	COMAFCL	\N	2014-12-18 09:58:12	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2160	98	2011-12-20 00:00:00	2016-12-20 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08055A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2103	250	2011-12-15 00:00:00	2015-03-18 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08017T	\N	COMAFCL	\N	2015-03-26 10:41:39	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2104	273	2011-12-15 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92031P	\N	COMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2105	112	2011-12-15 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11042G	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2107	138	2011-12-15 00:00:00	2014-12-15 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	08024S	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2108	172	2011-12-15 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08063A	\N	SENCOMAFCL	\N	2014-11-05 11:41:28	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2109	186	2011-12-15 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	08031R	\N	SENCOMAFCL	\N	2014-11-05 11:42:39	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2110	208	2011-12-15 00:00:00	2014-12-15 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08024S	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2111	240	2011-12-15 00:00:00	2012-01-31 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11083R	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2368	258	2014-02-20 00:00:00	2015-03-03 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11051H	\N	SENCOMCAE	2013-05-24 09:54:31	2015-03-03 10:16:55	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2206	612	2011-12-13 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01019Q	6	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2207	612	2011-12-13 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04047H	1	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2208	612	2011-12-13 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01024M	2	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2209	612	2011-12-13 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	96006F	5	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2210	612	2011-12-13 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92020L	3	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2211	612	2011-12-13 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04084N	4	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2212	612	2011-12-13 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	02002K	6	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2213	612	2011-12-13 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04044E	1	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2214	612	2011-12-13 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95005A	2	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2215	612	2011-12-13 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11054L	5	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2216	612	2011-12-13 00:00:00	2012-09-19 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95011X	3	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2217	612	2011-12-13 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11026G	4	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2290	297	2012-10-01 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08032S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2291	297	2012-10-01 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11012A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2292	206	2012-10-01 00:00:00	2014-05-03 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	12039E	\N	PDTSEN	\N	2014-05-05 14:37:26	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2293	64	2012-10-01 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95032D	\N	PDTSEN	\N	2014-09-28 17:07:41	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2294	257	2012-10-09 00:00:00	2014-04-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11051H	\N	SENCOMCAE	\N	2014-11-05 11:03:18	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2296	258	2012-10-09 00:00:00	2013-04-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11051H	\N	SENCOMCAE	\N	2016-07-11 12:09:26	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2297	243	2012-10-09 00:00:00	2014-04-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11051H	\N	SENCOMCAE	\N	2014-05-07 16:05:41	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2299	163	2012-10-09 00:00:00	2014-04-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11051H	\N	SENCOMCAE	\N	2014-05-07 16:04:54	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2300	81	2012-10-09 00:00:00	2014-04-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11051H	\N	SENCOMCAE	\N	2014-05-07 16:08:31	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2361	123	2013-02-07 00:00:00	2013-02-19 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11090Q	\N	PDTSEN	2013-04-24 16:39:30	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2342	306	2013-02-20 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	En fonction du mandat	01031L	\N	PDTSEN	\N	2015-03-09 15:31:01	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2343	306	2013-02-20 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	En fonction du mandat	08011M	\N	PDTSEN	\N	2014-08-01 11:09:22	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2344	305	2012-12-06 00:00:00	2016-12-06 00:00:00	TITULAIRE	ANCIEN	\N	Président	\N	Désigné par arrêté interministériel	08039A	\N	PDTSEN	\N	2014-11-05 18:38:07	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2203	29	2012-02-07 00:00:00	2014-03-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Rplct M. Sutour , démissionnaire	11035H	\N	SENCOMLOIS	\N	2015-02-06 16:02:47	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2204	96	2012-02-07 00:00:00	2013-10-03 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Rplct M. Michel , démissionnaire	01024M	\N	SENCOMLOIS	\N	2014-09-26 13:55:22	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2205	141	2012-02-07 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Rplct Mmem Klès, démissionaire	11029K	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2313	270	2012-11-27 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08073C	4	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2314	270	2012-11-27 00:00:00	2014-09-29 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01063U	5	SENCOMLOIS	\N	2014-09-29 13:41:53	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2315	270	2012-11-27 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11113E	6	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2316	270	2012-11-27 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11109J	7	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2317	270	2012-11-27 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04094Q	8	SENCOMCAE	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2318	270	2012-11-27 00:00:00	2014-05-03 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	12039E	9	SENCOMCDD	\N	2014-05-05 14:38:04	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2319	270	2012-11-27 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11023D	10	SENCOMAFEU	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2320	270	2012-11-27 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11020A	11	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2321	270	2012-11-27 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	07029T	12	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2322	270	2012-11-27 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	77043E	13	SENCOMFINC	\N	2014-09-28 16:59:41	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2323	270	2012-11-27 00:00:00	2013-12-31 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95003X	14	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2324	270	2012-11-27 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01065W	15	SENCOMLOIS	\N	2014-09-28 12:09:44	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2325	270	2012-11-27 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11072N	16	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2326	270	2012-11-27 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11071M	17	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2327	270	2012-11-27 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	08019V	18	SENCOMCAE	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2328	270	2012-11-27 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	96003C	19	SENCOMCDD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2329	270	2012-11-27 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04057K	20	SENCOMAFEU	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2245	108	2012-07-10 00:00:00	2015-05-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11089X	\N	SENCOMAFCL	\N	2015-01-14 16:09:02	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2246	138	2012-07-10 00:00:00	2014-11-04 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01052R	\N	SENCOMAFCL	\N	2014-11-04 11:22:47	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2247	296	2012-07-10 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04066L	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2248	296	2012-07-10 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08052W	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2249	296	2012-07-10 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04055H	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2250	296	2012-07-10 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04092N	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2251	127	2012-07-10 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Rplct M. Gournac	08020N	\N	SENCOMSOCI	\N	2014-09-28 17:03:42	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2271	152	2012-09-14 00:00:00	2014-03-15 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11045K	\N	PDTSEN	\N	2014-04-22 14:21:55	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2272	299	2012-09-14 00:00:00	2013-06-27 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95045J	1	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2273	299	2012-09-14 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98029W	2	PDTSEN	\N	2015-02-19 17:39:13	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2274	299	2012-09-14 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11031D	\N	PDTSEN	\N	2015-03-23 16:30:18	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2305	612	2012-10-30 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	remplace Mme Borvo Cohen Sénat, fin de mandat	04085P	3	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2200	115	2012-01-23 00:00:00	2012-07-21 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11027H	\N	SENCOMETRD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2352	257	2013-03-14 00:00:00	2016-03-14 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11101A	\N	SENCOMCAE	\N	2014-10-30 17:38:27	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2228	291	2012-03-07 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01022K	\N	PDTSEN	\N	2015-03-23 17:02:10	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2229	291	2012-03-07 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	98038X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2308	302	2012-11-08 00:00:00	2013-03-12 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08012N	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2226	272	2012-02-16 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	nommée par aff soc même si membre des aff.etrangères 	92018S	\N	SENCOMSOCI	\N	2015-10-20 11:14:27	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2227	206	2012-02-16 00:00:00	2012-07-21 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08064B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2201	290	2012-01-31 00:00:00	2017-01-31 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	1ere désignation	11104D	\N	SENCOMAFCL	\N	2014-11-05 17:11:20	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2202	290	2012-01-31 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95047L	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2196	253	2012-01-13 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01016M	\N	PDTSEN	\N	2014-09-25 08:56:50	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2143	247	2011-12-20 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11067R	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2144	256	2011-12-20 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08067E	\N	SENCOMSOCI	\N	2014-09-28 17:22:11	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2145	267	2011-12-20 00:00:00	2015-06-05 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11085T	\N	SENCOMSOCI	\N	2015-06-24 11:51:42	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2146	270	2011-12-20 00:00:00	2012-10-31 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11055M	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2147	270	2011-12-20 00:00:00	2012-10-31 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11025F	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2148	270	2011-12-20 00:00:00	2012-10-31 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04043D	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2149	270	2011-12-20 00:00:00	2012-10-31 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11020A	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2150	50	2011-12-20 00:00:00	2016-12-15 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11093T	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2151	8	2011-12-20 00:00:00	2015-12-03 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04036E	\N	PDTSEN	\N	2015-12-03 14:56:18	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2152	95	2011-12-20 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04087R	\N	SENCOMSOCI	\N	2014-09-28 13:39:21	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2153	22	2011-12-20 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11029K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2154	4	2011-12-20 00:00:00	2017-09-19 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11112D	\N	PDTSEN	\N	2017-10-11 11:40:22	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2155	30	2013-06-26 00:00:00	2017-06-26 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11067R	\N	PDTSEN	\N	2016-02-09 16:36:55	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2156	67	2011-12-20 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04066L	\N	PDTSEN	\N	2014-12-11 10:01:42	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2157	67	2011-12-20 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08052W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2158	67	2011-12-20 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08026U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2161	98	2011-12-20 00:00:00	2016-12-20 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11111C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2162	98	2011-12-20 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08033T	\N	PDTSEN	\N	2014-09-28 17:27:35	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2163	107	2011-12-20 00:00:00	2015-02-24 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01046T	\N	PDTSEN	\N	2015-04-17 10:20:41	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2164	121	2011-12-20 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08017T	\N	PDTSEN	\N	2014-07-11 15:52:11	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2165	123	2011-12-20 00:00:00	2014-04-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11051H	\N	PDTSEN	\N	2014-11-05 10:56:39	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1933	270	2010-12-22 00:00:00	2011-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	05001W	270	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1934	270	2010-12-22 00:00:00	2012-10-31 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08073C	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1935	270	2010-12-22 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04096S	270	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1936	270	2010-12-22 00:00:00	2011-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95044H	270	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1937	270	2010-12-22 00:00:00	2012-10-31 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	reste à l'économie	08019V	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1938	270	2010-12-22 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01027Q	270	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1710	112	2008-12-02 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	Président	\N	Président	95038K	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1711	112	2008-12-02 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01058X	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1712	112	2008-12-02 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98037W	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1713	112	2008-12-02 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95021A	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1714	24	2008-12-02 00:00:00	2008-12-04 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98050T	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1715	24	2008-12-02 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	Président	\N	aff éco depuis	80013X	\N	SENCOMECON	\N	2014-08-26 10:48:20	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1716	24	2008-12-02 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	aff éco depuis	04083M	\N	SENCOMECON	\N	2014-08-26 10:48:56	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1717	24	2008-12-02 00:00:00	2011-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01016M	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1939	270	2010-12-22 00:00:00	2012-10-31 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95003X	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2282	248	2012-09-24 00:00:00	2013-04-11 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98023Q	\N	PDTSEN	\N	2014-09-26 13:57:52	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2283	225	2012-09-24 00:00:00	2014-02-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	90003B	\N	PDTSEN	\N	2014-09-26 14:06:21	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1832	127	2009-03-04 00:00:00	2012-03-04 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95035G	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1833	187	2009-03-04 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04053F	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1857	251	2009-07-20 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01022K	251	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1858	252	2009-07-20 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95013A	\N	SENCOMECON	\N	2014-09-26 14:04:12	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1719	242	2008-12-04 00:00:00	2014-05-27 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	89017R	\N	SENCOMAFCL	\N	2014-05-27 17:41:10	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1866	168	2011-12-20 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	98010K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1867	168	2009-11-20 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	08047A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1871	138	2008-12-04 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	07026Q	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1872	255	2009-12-05 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	dev dur depuis	04088S	\N	SENCOMECON	\N	2014-09-23 15:36:17	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1882	260	2010-02-05 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	Président	\N	préside le comité de suivi	77019E	260	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1908	228	2010-11-04 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83011J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1926	271	2010-12-17 00:00:00	2015-12-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Première nomination. Depuis aff éco	01016M	271	SENCOMECON	\N	2014-07-11 11:45:51	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1954	199	2011-01-19 00:00:00	2013-06-27 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95045J	1	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1963	609	2011-03-03 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95024D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1964	610	2011-03-03 00:00:00	2014-02-04 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95025E	\N	PDTOPECST	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1965	274	2011-03-03 00:00:00	2014-03-03 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08017T	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1966	273	2011-03-03 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04056J	\N	COMETRD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1967	273	2011-03-03 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01041N	\N	COMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1687	211	2011-05-24 00:00:00	2012-01-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04043D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2284	225	2012-09-24 00:00:00	2014-02-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	80013X	\N	PDTSEN	\N	2014-09-26 14:06:21	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2285	210	2012-09-24 00:00:00	2015-09-24 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04044E	\N	PDTSEN	\N	2015-03-04 17:08:16	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1851	250	2009-05-29 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01041N	\N	COMAFCL	\N	2015-03-26 10:42:41	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1899	118	2010-06-02 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95039L	118	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1956	608	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	04051D	\N	MEMBREDRT	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1957	608	\N	2011-09-30 00:00:00	\N	ANCIEN	\N	\N	\N	\N	98027U	\N	MEMBREDRT	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1864	69	2009-09-30 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	07003H	\N	COMFINC	\N	2014-09-23 15:14:28	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1883	67	2010-02-19 00:00:00	2011-01-23 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95004Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1903	266	2010-07-30 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04071H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1637	52	2010-12-09 00:00:00	2011-05-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04073K	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1638	52	2010-12-09 00:00:00	2011-05-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04057K	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1639	52	2010-12-09 00:00:00	2011-05-17 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01041N	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1640	52	2010-12-09 00:00:00	2011-05-17 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	07026Q	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1658	9	2008-01-10 00:00:00	2009-01-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92029V	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1659	21	2008-01-10 00:00:00	2009-01-10 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83021L	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1660	143	2008-01-10 00:00:00	2011-01-10 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	77043E	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1661	86	2008-01-09 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98014P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1662	238	2008-01-09 00:00:00	2008-06-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95028H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1663	158	2008-01-09 00:00:00	2008-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83050R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1834	124	2010-01-19 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08037X	\N	COMSOCI	\N	2014-09-28 17:34:16	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1835	97	2009-02-18 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04075M	\N	COMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1836	246	2009-03-11 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98041S	\N	SENCOMLOIS	\N	2014-09-23 15:23:33	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1889	126	2010-04-29 00:00:00	2011-12-14 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	88008L	\N	COMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1891	144	2010-04-29 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	remplace M. Charasse nommé au CC 	77019E	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1892	17	2010-04-29 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	88008L	0	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1893	167	2010-04-29 00:00:00	2015-04-29 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	remplace M. Thiollière (fin de mandat)	08039A	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1894	123	2007-01-17 00:00:00	2010-01-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95020Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1838	233	2008-12-04 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	remplacement de M. Revol. depuis, aff éco	01058X	\N	SENCOMECON	\N	2014-11-05 11:49:32	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1839	233	2008-12-04 00:00:00	2014-12-04 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	remplacement de M. Piras. depuis, dév dur	80013X	\N	SENCOMECON	\N	2016-03-23 17:51:10	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1875	256	2009-12-15 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	06001B	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1876	254	2009-12-15 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	97009N	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1886	612	2010-03-30 00:00:00	2011-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	suite nomination M. Haenel au CC	95020Y	6	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1901	265	2010-06-25 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04049K	\N	PDTSEN	\N	2014-09-23 15:32:56	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1902	262	2010-06-25 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01058X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1519	608	\N	2011-01-23 00:00:00	\N	ANCIEN	\N	\N	\N	\N	95004Y	\N	MEMBREDRT	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1958	72	2011-02-17 00:00:00	2014-02-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89007P	\N	SENCOMAFCL	\N	2014-10-30 17:49:15	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1624	108	2007-10-01 00:00:00	2010-10-11 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01017N	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1625	112	2007-10-01 00:00:00	2008-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01017N	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1626	186	2007-10-01 00:00:00	2010-12-14 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92005M	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2275	199	2012-10-01 00:00:00	2015-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01046T	\N	SENCOMSOCI	\N	2014-02-17 17:36:53	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2276	199	2012-10-01 00:00:00	2015-04-23 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98029W	\N	SENCOMSOCI	\N	2015-05-22 14:50:20	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2277	199	2012-10-01 00:00:00	2015-04-07 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04092N	\N	SENCOMSOCI	\N	2015-04-13 18:22:14	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1649	75	2007-11-15 00:00:00	2008-12-08 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01014K	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1650	75	2007-11-15 00:00:00	2008-12-08 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95025E	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1651	72	2010-12-02 00:00:00	2013-12-02 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08049C	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1657	112	2007-12-13 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98048A	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1920	269	2010-12-08 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01024M	269	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1921	138	2010-12-09 00:00:00	2011-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	08024S	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1922	259	2010-04-29 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98042T	\N	PDTSEN	\N	2014-09-23 15:18:22	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1923	259	2010-04-29 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08027V	\N	PDTSEN	\N	2014-09-23 15:19:29	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1924	259	2010-04-29 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04061F	\N	PDTSEN	\N	2014-09-23 15:19:17	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1925	259	2010-04-29 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04033B	\N	PDTSEN	\N	2014-09-23 15:19:06	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1837	156	2009-03-31 00:00:00	2013-03-31 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04070G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1856	24	2009-06-24 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04071H	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1840	247	2009-03-26 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	00003C	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1841	247	2009-03-26 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01018P	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1884	258	2010-02-22 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	Président	\N	\N	95013A	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1885	258	2010-02-22 00:00:00	2012-07-21 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04090L	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1897	264	2010-06-01 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95024D	264	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1898	264	2011-12-20 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	88008L	\N	PDTSEN	\N	2014-09-23 15:15:01	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1906	267	2010-09-27 00:00:00	2013-06-27 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95045J	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2279	298	2012-09-24 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98037W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2280	220	2012-09-24 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95052H	\N	PDTSEN	\N	2014-09-28 13:39:21	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2281	220	2014-09-24 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01064V	\N	PDTSEN	\N	2014-09-28 17:12:41	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1346	143	2004-11-04 00:00:00	2007-11-03 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	77043E	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1347	164	2004-11-04 00:00:00	2008-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04037F	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1348	166	2004-11-04 00:00:00	2009-07-23 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86044G	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1349	193	2004-11-04 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01027Q	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1350	194	2004-11-04 00:00:00	2007-11-04 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04037F	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1351	98	2004-11-04 00:00:00	2009-11-04 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98053W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1352	98	2004-11-04 00:00:00	2008-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	78003A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1353	108	2004-11-04 00:00:00	2007-07-04 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	71003U	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1354	187	2004-11-04 00:00:00	2005-07-29 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04053F	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1355	9	2004-11-04 00:00:00	2007-11-04 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92029V	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1356	66	2004-11-04 00:00:00	2005-03-16 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98047Y	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1357	66	2004-11-04 00:00:00	2007-11-04 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01027Q	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1358	189	2004-11-04 00:00:00	2007-11-04 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92029V	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1364	204	2009-07-21 00:00:00	2011-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04052E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1360	138	2004-10-26 00:00:00	2007-10-26 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98013N	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1361	168	2004-10-26 00:00:00	2010-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	59312E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1362	168	2004-10-26 00:00:00	2008-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	98040R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1363	204	2009-07-21 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83050R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1367	205	2004-12-08 00:00:00	2005-04-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01057W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1368	205	2004-12-08 00:00:00	2005-04-13 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95055L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1369	102	2006-06-22 00:00:00	2011-06-22 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04064J	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1370	113	\N	2005-05-27 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	86049M	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1371	24	2004-11-29 00:00:00	2008-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	96008H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1372	22	2004-12-01 00:00:00	2007-12-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01024M	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1374	73	2004-12-09 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	03002P	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1375	149	2004-12-15 00:00:00	2009-12-15 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Président	95004Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1376	168	2004-12-15 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98014P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1377	175	2005-01-17 00:00:00	2008-01-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04047H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1379	206	2005-01-18 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89016Q	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1380	21	2005-01-19 00:00:00	2006-01-19 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83021L	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1382	208	2005-01-25 00:00:00	2008-01-25 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	80046H	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1383	50	2005-02-01 00:00:00	2007-11-29 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	98030P	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1384	50	2005-02-01 00:00:00	2007-02-22 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89022N	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1385	72	2005-02-09 00:00:00	2008-02-08 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89007P	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1386	72	2005-02-09 00:00:00	2006-07-08 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	80048K	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1387	72	2005-02-09 00:00:00	2008-02-09 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01052R	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1388	176	2005-02-09 00:00:00	2008-02-09 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95038K	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1389	207	2005-02-09 00:00:00	2008-02-09 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98036V	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1390	207	2005-02-09 00:00:00	2005-02-09 00:00:00	\N	ANCIEN	\N	\N	\N	\N	01043Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1391	207	2005-02-09 00:00:00	2007-07-19 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01043Q	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1392	20	2005-02-15 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	depuis aff éco	95009E	\N	SENCOMECON	\N	2014-08-26 10:32:39	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1393	152	2005-03-11 00:00:00	2010-03-11 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	démission le 26 mai 2009	95028H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1394	210	2005-03-11 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	78003A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1395	210	2005-03-11 00:00:00	2008-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01027Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1396	66	2005-03-16 00:00:00	2008-03-16 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	78003A	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1397	177	2005-03-11 00:00:00	2013-02-11 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04069P	\N	PDTSEN	\N	2014-09-26 13:56:43	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1398	211	2005-03-16 00:00:00	2007-06-24 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	99004R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1399	211	2005-03-16 00:00:00	2007-07-19 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01043Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1400	211	2005-03-16 00:00:00	2008-06-19 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04044E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1401	211	2011-03-31 00:00:00	2012-01-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	96007G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1402	101	2005-03-29 00:00:00	2010-03-29 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Supprimé par l'article 10 de la loi n° 2009-258 du 5 mars 2009	92005M	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1403	186	2005-03-29 00:00:00	2007-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92005M	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1404	198	2005-03-29 00:00:00	2008-03-29 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	92005M	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1405	209	2008-04-10 00:00:00	2011-04-10 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04037F	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1406	209	2008-04-10 00:00:00	2011-04-10 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01030K	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1407	209	2008-04-10 00:00:00	2011-04-10 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04087R	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2252	295	2012-07-17 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	05012A	\N	SENCOMCDD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2254	295	2012-07-17 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04065K	\N	SENCOMCDD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1408	67	2005-04-12 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04037F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1409	201	2005-04-12 00:00:00	2007-10-11 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01048V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1410	184	2005-05-02 00:00:00	2006-06-07 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95036H	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1412	212	2005-05-04 00:00:00	2008-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01018P	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1413	205	2005-05-04 00:00:00	2008-05-04 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01057W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1414	205	2005-05-04 00:00:00	2008-05-04 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95055L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1415	183	2005-05-11 00:00:00	2008-05-11 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01010F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1416	213	2005-05-12 00:00:00	2007-07-19 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01043Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1417	213	2005-05-12 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	80041C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1420	214	2005-06-14 00:00:00	2010-06-14 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92011K	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1421	214	2005-06-14 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04045F	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1422	147	2005-05-14 00:00:00	2008-05-14 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04037F	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1423	180	2005-06-14 00:00:00	2011-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04037F	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1425	162	2005-06-14 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	73006G	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1426	179	2005-06-08 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	02002K	\N	COMCAE	\N	2014-07-11 11:48:40	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1641	138	2007-11-08 00:00:00	2008-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98013N	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1642	138	2007-11-08 00:00:00	2010-11-08 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95047L	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1664	37	2008-01-24 00:00:00	2013-01-24 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01061S	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1665	37	2008-01-24 00:00:00	2013-01-24 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04088S	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2255	295	2012-07-17 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	08042U	\N	SENCOMCDD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2256	295	2012-07-17 00:00:00	2015-07-15 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11107G	\N	SENCOMCDD	\N	2015-07-16 17:13:53	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2257	294	2012-07-17 00:00:00	2014-02-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08042U	\N	SENCOMCDD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2379	203	2013-05-30 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08032S	\N	PDTSEN	2013-07-24 11:19:26	2014-10-23 10:38:24	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2380	203	2015-03-24 00:00:00	2016-02-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14065Q	\N	PDTSEN	2013-07-24 11:22:05	2016-02-29 11:56:19	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2371	203	2013-05-30 00:00:00	2015-04-21 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01042P	\N	PDTSEN	2013-05-30 16:50:44	2015-04-21 17:14:30	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2381	199	2013-07-25 00:00:00	2014-01-24 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	10006L	\N	SENCOMSOCI	2013-07-25 12:13:24	2014-02-17 17:38:40	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2382	207	2013-07-25 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04046G	\N	SENCOMSOCI	2013-07-25 12:15:47	2014-10-30 17:55:16	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2383	214	2013-07-25 00:00:00	2014-07-02 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11097X	\N	SENCOMSOCI	2013-07-25 12:18:47	2014-07-09 17:49:56	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2384	267	2013-07-25 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	07029T	\N	SENCOMSOCI	2013-07-25 12:20:56	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2166	136	2011-12-20 00:00:00	2013-01-11 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95021A	\N	PDTSEN	\N	2014-12-11 16:42:52	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2167	137	2011-12-20 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01059Y	\N	PDTSEN	\N	2015-01-15 15:35:26	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2168	137	2011-12-20 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04046G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2169	152	2011-12-20 00:00:00	2012-05-29 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	démission transmise le 29/05/2012	11015D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2170	157	2011-12-20 00:00:00	2012-07-21 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11027H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2172	160	2011-12-20 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92018S	\N	PDTSEN	\N	2014-11-07 12:16:50	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2173	168	2011-12-20 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08058D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2174	175	2011-12-20 00:00:00	2014-12-20 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01042P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2175	177	2011-12-20 00:00:00	2013-02-11 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	00003C	\N	PDTSEN	\N	2014-09-26 13:56:57	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2176	200	2011-12-20 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	08014Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2177	201	2011-12-20 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04034C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2178	204	2011-12-20 00:00:00	2015-12-20 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01011G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2179	204	2011-12-20 00:00:00	2015-12-20 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11082Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2180	210	2012-09-24 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	devenue titulaire au moment de la reconduction de Mme Troendle	08032S	\N	PDTSEN	\N	2014-09-28 17:34:16	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2181	213	2011-12-20 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08067E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2182	213	2011-12-20 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01034P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2183	220	2011-12-20 00:00:00	2014-12-20 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01025N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2184	225	2011-12-20 00:00:00	2014-02-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01046T	\N	PDTSEN	\N	2014-09-26 14:06:21	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2185	225	2011-12-20 00:00:00	2014-02-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11031D	\N	PDTSEN	\N	2014-09-26 14:06:21	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2186	227	2011-12-20 00:00:00	2016-05-18 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01022K	\N	PDTSEN	\N	2017-04-12 11:04:44	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2187	228	2011-12-20 00:00:00	2013-04-10 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01013J	\N	PDTSEN	\N	2014-09-26 10:48:09	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2188	228	2011-12-20 00:00:00	2013-04-10 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01037S	\N	PDTSEN	\N	2014-09-26 10:48:38	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2189	234	2011-12-20 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04087R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2190	260	2011-12-20 00:00:00	2013-04-11 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08037X	\N	PDTSEN	\N	2014-09-26 16:06:27	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2191	262	2011-12-20 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08050U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2192	264	2011-12-20 00:00:00	2014-12-20 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11033F	\N	PDTSEN	\N	2016-04-21 11:27:40	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2193	266	2011-12-20 00:00:00	2014-02-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11068S	\N	PDTSEN	\N	2014-09-26 14:02:13	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2194	269	2011-12-20 00:00:00	2017-08-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01024M	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2239	293	2012-04-11 00:00:00	2013-04-10 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08012N	\N	PDTSEN	\N	2013-08-28 16:27:35	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2233	244	2012-03-15 00:00:00	2015-01-20 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04066L	\N	PDTSEN	\N	2015-01-20 16:26:44	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2234	22	2012-03-15 00:00:00	2014-09-29 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	remplacement de M. Collombat, démissionnaire	01063U	\N	PDTSEN	\N	2014-09-29 13:41:53	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2240	293	2012-04-11 00:00:00	2013-04-10 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95047L	\N	PDTSEN	\N	2013-08-28 16:27:35	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2330	303	2013-01-07 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	80013X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2331	303	2013-01-07 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04035D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2332	303	2013-01-07 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	08056B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2333	303	2013-01-07 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11031D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2230	292	2012-02-29 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04091M	\N	COMETRD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2231	292	2012-02-19 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11089X	\N	COMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2364	258	2015-05-18 00:00:00	2016-07-12 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01043Q	\N	SENCOMCAE	2013-04-30 15:51:27	2016-07-19 12:44:50	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2219	609	2012-02-08 00:00:00	2016-02-08 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11068S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2220	211	2012-02-08 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08067E	\N	PDTSEN	\N	2014-09-28 17:22:11	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2221	211	2012-02-08 00:00:00	2014-10-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01059Y	\N	PDTSEN	\N	2014-10-13 15:54:52	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2222	211	2012-02-08 00:00:00	2014-10-13 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95015C	\N	PDTSEN	\N	2014-10-13 15:55:53	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2223	211	2012-02-08 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04051D	\N	PDTSEN	\N	2014-09-28 17:07:41	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2224	270	2012-02-13 00:00:00	2012-10-31 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11023D	\N	SENCOMAFEU	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2225	270	2012-02-14 00:00:00	2012-07-21 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	08064B	\N	SENCOMECON	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2197	288	2012-01-18 00:00:00	2016-07-12 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11068S	\N	PDTSEN	\N	2016-07-21 10:30:24	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2198	288	2012-01-18 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04066L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2199	289	2012-01-18 00:00:00	2015-01-18 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11113E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2354	304	2013-03-27 00:00:00	2016-03-27 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11095V	\N	SENCOMCDD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2355	304	2013-03-27 00:00:00	2016-03-27 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	88008L	\N	SENCOMFINC	\N	2014-11-06 17:08:30	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2356	304	2013-03-27 00:00:00	2015-02-11 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11090Q	\N	SENCOMAFCL	\N	2015-02-20 16:17:54	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2353	304	2013-03-27 00:00:00	2016-03-27 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04033B	\N	SENCOMCAE	\N	2014-11-05 17:43:19	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2357	282	2013-03-27 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	13001T	\N	SENCOMCDD	\N	2014-08-26 10:42:36	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2358	202	2013-03-18 00:00:00	2015-06-12 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95020Y	\N	SENCOMLOIS	\N	2015-06-12 16:01:25	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2375	310	2013-06-21 00:00:00	2014-09-29 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01063U	\N	SENCOMLOIS	2013-06-27 10:25:11	2014-09-29 13:41:53	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2376	310	2013-06-21 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	08059E	\N	SENCOMLOIS	2013-06-27 10:25:42	2014-08-01 11:15:26	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2377	309	2013-07-03 00:00:00	2018-07-03 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08043V	\N	SENCOMAFCL	2013-07-04 16:56:34	2014-11-05 18:38:49	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2378	309	2013-07-03 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	92044U	\N	SENCOMAFCL	2013-07-04 16:57:06	2014-08-01 11:14:21	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2390	314	2013-09-16 00:00:00	2016-09-16 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	96004D	\N	PDTSEN	2013-09-17 17:23:54	2016-10-05 17:45:50	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2391	314	2013-09-16 00:00:00	2016-09-16 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95063L	\N	PDTSEN	2013-09-17 17:24:59	2016-10-05 17:45:40	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2392	314	2013-09-16 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08049C	\N	PDTSEN	2013-09-17 17:25:53	2014-08-01 11:24:19	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2393	314	2013-09-16 00:00:00	2016-09-16 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11065P	\N	PDTSEN	2013-09-17 17:26:32	2016-10-05 17:46:08	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2394	314	2013-09-16 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	08054Y	\N	PDTSEN	2013-09-17 17:27:10	2014-08-01 11:24:54	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2395	314	2013-09-16 00:00:00	2016-09-16 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11094U	\N	PDTSEN	2013-09-17 17:27:50	2016-10-05 17:45:59	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2388	308	2013-04-26 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08012N	\N	PDTSEN	2013-08-27 11:54:39	2014-08-01 11:11:47	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2389	308	2013-04-26 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95047L	\N	PDTSEN	2013-08-27 11:55:13	2014-08-01 11:12:03	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2397	313	2013-10-08 00:00:00	2017-07-03 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01044R	\N	COMAFCL	2013-10-18 09:43:51	2017-07-04 15:08:09	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2398	313	2013-10-08 00:00:00	2014-10-15 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92031P	\N	COMAFCL	2013-10-18 09:44:38	2014-10-16 17:40:37	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2399	313	2013-10-08 00:00:00	2018-10-08 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11104D	\N	COMAFCL	2013-10-18 09:45:43	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2402	315	2013-10-30 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	13003V	\N	PDTSEN	2013-11-04 10:27:03	2014-08-01 11:27:10	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2403	315	2013-10-30 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08026U	\N	PDTSEN	2013-11-04 10:28:58	2014-08-01 11:26:56	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2423	268	2014-01-22 00:00:00	2015-06-24 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08038Y	\N	SENCOMCAE	2014-01-23 15:21:05	2015-11-10 16:49:56	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2424	268	2014-01-22 00:00:00	2015-06-24 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01043Q	\N	SENCOMCAE	2014-01-23 15:21:26	2015-11-10 16:50:23	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2425	318	2014-01-23 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95055L	\N	SENCOMETRD	2014-01-23 15:49:08	2014-08-01 11:32:55	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2426	318	2014-01-23 00:00:00	2015-12-15 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04042C	\N	SENCOMETRD	2014-01-23 15:49:37	2015-12-16 09:00:34	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2427	318	2014-01-23 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	08059E	\N	SENCOMETRD	2014-01-23 15:50:05	2014-08-01 11:33:31	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2428	318	2014-01-23 00:00:00	2017-01-23 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01056V	\N	SENCOMETRD	2014-01-23 15:50:41	2014-12-15 08:49:56	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2436	152	2014-04-15 00:00:00	2015-05-04 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11012A	\N	PDTSEN	2014-04-22 14:22:07	2015-05-18 11:33:16	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2442	95	2014-06-10 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04090L	\N	SENCOMCDD	2014-06-11 16:34:22	2014-09-28 19:29:39	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2630	286	2014-12-17 00:00:00	2015-06-12 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95020Y	\N	SENCOMLOIS	2014-12-24 09:22:56	2015-06-12 16:01:25	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2633	270	2015-02-04 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14249W	\N	SENCOMAFEU	2015-02-05 09:03:34	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2634	270	2015-02-04 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	14097Y	\N	SENCOMAFEU	2015-02-05 09:05:29	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2635	214	2015-02-04 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04043D	\N	SENCOMSOCI	2015-02-05 09:07:28	2015-02-05 09:09:02	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2636	214	2015-02-04 00:00:00	2015-10-21 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	14239U	\N	SENCOMSOCI	2015-02-05 09:07:59	2015-11-03 15:26:14	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2645	328	2015-02-19 00:00:00	2020-02-19 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08018U	\N	COMLOIS	2015-02-19 10:58:39	2015-02-19 11:08:05	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2646	328	2015-02-19 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11035H	\N	COMLOIS	2015-02-19 10:59:02	2015-02-19 11:08:15	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2647	29	2015-02-19 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08047A	\N	SENCOMLOIS	2015-02-19 11:18:00	2015-02-19 11:19:00	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2655	328	2015-03-11 00:00:00	2020-03-11 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14028W	\N	COMETRD	2015-03-11 16:12:45	2015-03-11 16:15:32	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2907	189	2017-12-07 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19737F	\N	SENCOMCDD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2656	328	2015-03-11 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04042C	\N	COMETRD	2015-03-11 16:13:46	2015-03-11 16:16:04	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2669	193	2015-03-18 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11048N	\N	SENCOMFINC	2015-03-20 09:55:03	2015-03-20 09:57:35	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2670	193	2015-03-18 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11040E	\N	SENCOMFINC	2015-03-20 09:55:45	2015-03-20 09:57:47	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2837	258	2016-07-19 00:00:00	2019-07-19 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	14257W	\N	SENCOMCAE	2016-07-19 12:45:57	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2838	29	2016-09-29 00:00:00	2020-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	14030Q	\N	SENCOMCDD	2016-10-05 18:40:21	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2839	351	2016-10-05 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01024M	\N	SENCOMLOIS	2016-10-11 17:26:01	2016-10-11 17:28:24	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2840	351	2016-10-05 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11056N	\N	SENCOMLOIS	2016-10-11 17:27:28	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2842	612	2015-06-16 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	Remplacement de M. Lecerf	14215L	5	SENAT	2016-11-23 11:51:50	2017-01-16 14:08:32	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2843	355	2016-11-23 00:00:00	2019-12-31 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14093U	\N	SENCOMCDD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2844	355	2016-11-23 00:00:00	2019-12-31 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08060W	\N	SENCOMCDD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2845	42	2016-12-01 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14229S	\N	SENCOMLOIS	2016-12-01 15:25:18	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2846	162	2016-12-06 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04092N	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2847	162	2016-12-06 00:00:00	2017-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11093T	\N	SENCOMSOCI	2016-12-06 16:45:47	2017-09-24 12:57:09	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2848	346	2017-01-11 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04086Q	\N	SENCOMCAE	2017-01-12 10:12:55	2017-01-12 10:14:20	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2850	270	2017-01-24 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	05001W	\N	SENCOMCDD	2017-01-24 12:53:34	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2865	612	2017-10-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19543W	1	SCRUTIN	2017-10-19 11:37:57	2017-10-19 17:39:54	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2866	612	2017-10-18 00:00:00	2019-07-22 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04047H	2	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2853	358	2017-02-22 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14093U	\N	SENCOMCDD	2017-02-22 17:49:08	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2855	359	2017-02-22 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92031P	\N	SENCOMCDD	2017-02-22 18:24:17	2017-02-22 18:26:53	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2856	359	2017-02-22 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14051J	\N	SENCOMCDD	2017-02-22 18:26:53	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2859	22	2017-05-31 00:00:00	2017-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	92045V	\N	PDTSEN	2017-06-02 10:35:21	2017-09-24 17:29:37	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2867	612	2017-10-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14053L	3	SCRUTIN	2017-10-19 11:40:02	2017-10-19 17:39:28	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2868	612	2017-10-18 00:00:00	2020-06-26 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01024M	4	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2869	612	2017-10-18 00:00:00	2019-03-03 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	07034Q	5	SCRUTIN	2017-10-19 11:41:29	2017-10-19 17:39:38	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2870	612	2017-10-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11045K	6	SCRUTIN	2017-10-19 11:42:05	2017-10-19 17:40:01	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2871	612	2017-10-18 00:00:00	2020-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	98029W	1	SCRUTIN	2017-10-19 11:43:01	2017-10-19 17:40:10	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2872	612	2017-10-18 00:00:00	2019-05-06 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04044E	2	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2873	612	2017-10-18 00:00:00	2020-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	19581D	3	SCRUTIN	2017-10-19 11:44:31	2017-10-19 17:40:43	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2874	612	2017-10-18 00:00:00	2020-06-26 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01025N	4	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2875	612	2017-10-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14215L	2	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2876	612	2017-10-18 00:00:00	2020-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	08045X	6	SCRUTIN	2017-10-19 11:47:12	2017-10-19 17:41:23	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2877	30	2017-11-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14213J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2879	270	2017-11-15 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14249W	\N	SENCOMAFEU	2017-11-17 15:44:00	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2880	270	2017-11-15 00:00:00	2020-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	14097Y	\N	SENCOMAFEU	2017-11-17 15:44:56	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2897	13	2017-12-05 00:00:00	2019-01-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14199E	\N	SENCOMFINC	2017-12-06 18:24:45	2018-12-10 09:59:04	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2898	13	2017-12-05 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14225N	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2899	359	2017-12-07 00:00:00	2020-02-21 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19681G	\N	SENCOMCDD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2900	270	2017-12-07 00:00:00	2020-12-07 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19659J	\N	SENCOMCDD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2901	270	2017-12-07 00:00:00	2020-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	08024S	\N	SENCOMCDD	2017-12-08 18:10:04	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2902	311	2017-12-07 00:00:00	2018-09-12 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	17583W	\N	SENCOMCDD	2017-12-08 18:12:25	2018-09-21 17:55:55	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2903	72	2017-12-07 00:00:00	2020-12-07 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19701S	\N	SENCOMCDD	2017-12-08 18:18:15	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2904	72	2017-12-07 00:00:00	2020-12-07 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	19347U	\N	SENCOMCDD	2017-12-08 18:19:02	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2905	120	2017-12-07 00:00:00	2022-12-07 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19549D	\N	SENCOMCDD	2017-12-08 18:20:44	2017-12-08 18:22:40	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2908	141	2017-12-07 00:00:00	2018-09-12 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19733B	\N	SENCOMCDD	2017-12-08 18:26:17	2018-09-21 17:45:55	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2909	141	2017-12-07 00:00:00	2018-09-12 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14103D	\N	SENCOMCDD	2017-12-08 18:27:33	2018-09-21 17:45:38	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2910	282	2017-12-07 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14029X	\N	SENCOMCDD	2017-12-08 18:36:28	2017-12-08 18:39:09	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2953	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Aisne	08010L	\N	PDTSEN	2017-12-18 16:01:25	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2954	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Aisne	08052W	\N	PDTSEN	2017-12-18 16:02:45	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2955	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Allier	98024R	\N	PDTSEN	2017-12-18 16:03:25	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2956	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Allier	14251Q	\N	PDTSEN	2017-12-18 16:04:46	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2957	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Alpes-Maritimes	14187A	\N	PDTSEN	2017-12-18 16:05:22	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2958	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Alpes-Maritimes	08039A	\N	PDTSEN	2017-12-18 16:06:24	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2959	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Ardèche	14259Y	\N	PDTSEN	2017-12-18 16:07:19	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2430	88	2014-02-06 00:00:00	2017-02-06 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	77002U	\N	SENCOMSOCI	2014-02-06 18:29:07	2014-11-25 12:47:34	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2441	245	2014-05-28 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04090L	\N	SENCOMCDD	2014-05-30 11:27:58	2014-07-11 11:37:12	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2485	317	2014-11-18 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01061S	\N	COMCAE	2014-11-20 10:09:39	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2497	272	2014-12-12 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98021N	\N	SENCOMETRD	2014-12-15 08:40:18	2017-10-01 09:22:38	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2498	126	2014-12-12 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86044G	\N	SENCOMETRD	2014-12-15 08:42:15	2017-10-01 10:32:58	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2510	69	2014-12-17 00:00:00	2017-06-12 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04034C	\N	COMFINC	2014-12-18 08:59:41	2017-06-13 10:45:05	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2500	157	2014-12-12 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11106F	\N	SENCOMETRD	2014-12-15 08:45:01	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2501	318	2014-12-12 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11064N	\N	SENCOMETRD	2014-12-15 08:48:08	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2502	318	2014-12-12 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	92018S	\N	SENCOMETRD	2014-12-15 08:50:13	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2507	69	2014-12-17 00:00:00	2017-06-12 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04071H	\N	COMFINC	2014-12-18 08:57:57	2017-06-13 10:45:05	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2508	69	2014-12-17 00:00:00	2017-06-12 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11070L	\N	COMFINC	2014-12-18 08:58:28	2017-06-13 10:45:05	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2509	69	2014-12-17 00:00:00	2017-06-12 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	14199E	\N	COMFINC	2014-12-18 08:59:05	2017-06-13 10:45:05	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2637	329	2015-02-05 00:00:00	2020-02-05 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08028W	\N	SENCOMCAE	2015-02-05 11:35:13	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2640	147	2015-02-11 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11103C	\N	SENCOMSOCI	2015-02-12 11:57:56	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2649	147	2015-02-19 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11088W	\N	SENCOMFINC	2015-02-20 09:26:06	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2650	128	2015-02-19 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11112D	\N	SENCOMSOCI	2015-02-20 09:28:44	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2658	292	2015-03-18 00:00:00	2018-03-18 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14061L	\N	COMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2659	273	2015-03-18 00:00:00	2021-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08017T	\N	COMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2728	332	2015-04-09 00:00:00	2020-04-09 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08009T	\N	SENCOMCDD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2744	250	2015-05-13 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01041N	\N	COMAFCL	2015-05-15 14:17:40	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2745	331	2015-05-13 00:00:00	2019-03-20 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14123H	\N	COMAFCL	2015-05-15 14:19:07	2019-04-02 17:57:24	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2753	282	2015-06-04 00:00:00	2016-01-14 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11010L	\N	SENCOMLOIS	2015-06-04 17:11:44	2016-03-03 09:51:28	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2754	282	2015-06-04 00:00:00	2016-01-14 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11072N	\N	SENCOMLOIS	2015-06-04 17:13:01	2016-03-03 09:51:54	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2763	267	2015-07-07 00:00:00	2017-06-20 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11093T	\N	SENCOMSOCI	2015-07-07 11:59:35	2017-06-20 17:57:32	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2764	243	2015-07-07 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11077T	\N	SENCOMCAE	2015-07-07 12:02:24	2015-07-07 12:04:01	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2772	108	2015-07-15 00:00:00	2019-07-15 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	89017R	\N	SENCOMFINC	2015-07-16 09:55:09	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2776	205	2015-09-16 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04044E	\N	PDTSEN	2015-09-16 16:36:06	2015-09-16 16:40:15	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2777	205	2015-09-16 00:00:00	2020-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	14001X	\N	PDTSEN	2015-09-16 16:36:43	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2778	141	2015-09-29 00:00:00	2018-09-12 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14327T	\N	SENCOMFINC	2015-09-30 08:55:10	2018-09-21 17:45:44	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2805	158	2015-11-04 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08034U	\N	PDTSEN	2015-11-04 10:58:51	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2818	318	2016-01-19 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	86044G	\N	SENCOMETRD	2016-01-19 17:43:59	2017-10-01 10:32:58	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2821	282	2016-03-02 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11010L	\N	SENCOMLOIS	2016-03-03 09:52:27	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2822	282	2016-03-02 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11072N	\N	SENCOMLOIS	2016-03-03 09:53:25	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2823	282	2016-03-02 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01022K	\N	SENCOMCDD	2016-03-03 09:54:19	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2824	282	2016-03-02 00:00:00	2020-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	14030Q	\N	SENCOMCDD	2016-03-03 09:55:10	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2878	158	2017-11-14 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08034U	\N	PDTSEN	2017-11-14 18:01:31	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2911	285	2017-12-13 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01025N	\N	SENCOMCAE	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2912	161	2017-12-13 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19563B	\N	SENCOMCAE	2017-12-18 10:14:18	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2913	243	2017-12-13 00:00:00	2020-12-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19591F	\N	SENCOMCAE	2017-12-18 10:19:30	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2914	270	2017-12-13 00:00:00	2020-12-07 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19301E	\N	SENCOMCAE	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2915	270	2017-12-13 00:00:00	2020-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	14135M	\N	SENCOMCAE	2017-12-18 10:39:13	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2916	311	2017-12-13 00:00:00	2018-09-12 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11101A	\N	SENCOMCAE	2017-12-18 10:42:06	2018-09-21 17:55:35	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2917	311	2017-12-13 00:00:00	2018-09-12 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	19511N	\N	SENCOMCAE	2017-12-18 10:59:45	2018-09-21 17:55:42	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2918	258	2017-12-13 00:00:00	2020-12-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01043Q	\N	SENCOMCAE	2017-12-18 11:13:06	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2919	251	2017-12-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14135M	\N	SENCOMCAE	2017-12-18 11:17:44	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2920	155	2017-12-13 00:00:00	2019-10-21 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19591F	\N	SENCOMCAE	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2921	346	2017-12-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04049K	\N	SENCOMCAE	2017-12-18 11:25:22	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2922	73	2017-12-13 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19695N	\N	SENCOMCAE	2017-12-18 11:28:55	2017-12-18 11:31:08	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2923	95	2017-12-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14265W	\N	SENCOMCAE	2017-12-18 11:31:49	2017-12-18 11:37:31	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2924	95	2017-12-13 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11056N	\N	SENCOMCAE	2017-12-18 11:32:20	2017-12-18 11:38:53	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2925	24	2017-12-13 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	17589D	\N	SENCOMCAE	2017-12-18 11:44:25	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2926	24	2017-12-13 00:00:00	2020-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	19269X	\N	SENCOMCAE	2017-12-18 11:45:01	2017-12-18 11:46:28	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2927	233	2017-12-13 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19515S	\N	SENCOMCAE	2017-12-18 11:47:53	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2928	344	2017-12-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14115H	\N	SENCOMCAE	2017-12-18 11:50:19	2017-12-18 11:51:23	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2929	270	2017-12-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14261S	\N	SENCOMSOCI	2017-12-18 11:52:46	2017-12-18 11:56:05	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2930	270	2017-12-13 00:00:00	2020-12-07 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19657G	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2931	270	2017-12-13 00:00:00	2020-12-07 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	19691J	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2932	270	2017-12-13 00:00:00	2020-12-07 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	19703U	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2933	147	2017-12-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08010L	\N	SENCOMFINC	2017-12-18 11:57:24	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2934	34	2017-12-13 00:00:00	2020-12-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01057W	\N	SENCOMFINC	2017-12-18 11:59:34	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2935	34	2017-12-13 00:00:00	2020-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	14225N	\N	SENCOMFINC	2017-12-18 11:59:56	2017-12-18 12:01:39	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2936	270	2017-12-13 00:00:00	2020-12-07 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	12016W	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2937	270	2017-12-13 00:00:00	2020-12-07 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11012A	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2938	270	2017-12-13 00:00:00	2020-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	14083S	\N	SENCOMFINC	2017-12-18 12:04:56	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2939	270	2017-12-13 00:00:00	2020-12-07 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	14331P	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2940	126	2017-12-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14034U	\N	SENCOMFINC	2017-12-18 12:08:00	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2941	126	2017-12-13 00:00:00	2019-06-24 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04061F	\N	SENCOMFINC	2017-12-18 12:08:31	2017-12-18 12:10:51	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2942	189	2017-12-13 00:00:00	2020-12-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19711U	\N	SENCOMFINC	2017-12-18 12:11:28	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2943	164	2017-12-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19479G	\N	SENCOMFINC	2017-12-18 12:12:42	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2944	162	2017-12-13 00:00:00	2020-12-14 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19349W	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2945	320	2017-12-13 00:00:00	2020-12-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19667J	\N	SENCOMFINC	2017-12-18 12:15:28	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2946	320	2017-12-13 00:00:00	2020-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	08014Q	\N	SENCOMFINC	2017-12-18 12:15:58	2017-12-18 12:16:50	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2947	187	2017-12-13 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11040E	\N	SENCOMFINC	2017-12-18 12:17:29	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2948	317	2017-12-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14197C	\N	COMCAE	2017-12-18 12:18:43	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2949	317	2017-12-13 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04043D	\N	COMCAE	2017-12-18 12:19:44	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2950	322	2017-12-13 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	19671E	\N	COMFINC	2017-12-18 12:21:35	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2951	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Ain	14038Y	\N	PDTSEN	2017-12-18 15:59:59	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2429	270	2014-01-29 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11042G	14	SENCOMFINC	2014-01-30 08:45:39	2014-01-30 08:48:32	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2431	319	2014-02-26 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	07026Q	\N	COMAFCL	2014-03-03 12:05:33	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2432	319	2014-02-26 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04057K	\N	COMAFCL	2014-03-03 12:06:22	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2433	319	2014-02-26 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11039M	\N	COMAFCL	2014-03-03 12:07:04	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2434	319	2014-02-26 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95047L	\N	COMAFCL	2014-03-03 12:07:41	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2435	199	2014-02-26 00:00:00	2017-02-26 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	10006L	\N	SENCOMSOCI	2014-03-03 12:13:20	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2447	321	2014-06-25 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04066L	\N	PDTSEN	2014-06-30 15:39:24	2014-06-30 15:45:57	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2448	321	2014-06-25 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	99004R	\N	PDTSEN	2014-06-30 15:40:39	2014-06-30 15:45:22	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2462	115	2014-06-11 00:00:00	2014-05-24 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11027H	\N	SENCOMETRD	2014-07-11 15:43:25	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2463	115	2014-06-11 00:00:00	2017-06-11 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08017T	\N	SENCOMAFCL	2014-07-11 15:44:13	2014-10-13 15:02:16	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2464	115	2014-06-11 00:00:00	2014-05-24 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08017T	\N	SENCOMAFCL	2014-07-11 15:45:03	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2482	49	2014-11-13 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	07026Q	\N	SENCOMAFCL	2014-11-14 11:46:28	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2483	313	2014-11-13 00:00:00	2015-06-10 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14123H	\N	COMAFCL	2014-11-14 11:48:26	2015-06-10 16:03:12	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2484	317	2014-11-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04033B	\N	COMAFCL	2014-11-14 11:57:11	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2486	137	2014-11-21 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04081K	\N	PDTSEN	2014-11-25 10:59:36	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2487	205	2014-11-21 00:00:00	2015-06-24 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04044E	\N	PDTSEN	2014-11-25 11:04:21	2015-06-26 09:14:16	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2491	324	2014-12-02 00:00:00	2015-06-12 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95020Y	\N	PDTSEN	2014-12-01 14:41:00	2015-06-12 16:01:25	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2503	158	2014-12-12 00:00:00	2015-10-11 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95039L	\N	PDTSEN	2014-12-15 15:55:28	2015-10-13 14:18:12	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2504	325	2014-12-12 00:00:00	2017-12-12 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95015C	\N	PDTSEN	2014-12-15 15:57:25	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2506	109	2014-12-17 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04074L	\N	COMLOIS	2014-12-17 16:15:29	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2562	290	2014-12-18 00:00:00	2019-12-18 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	14249W	\N	SENCOMAFCL	2014-12-19 11:56:21	2015-01-23 15:08:00	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2563	169	2014-12-18 00:00:00	2017-03-20 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11011M	\N	SENCOMAFCL	2014-12-19 11:59:00	2017-03-21 10:14:09	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2564	276	2014-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04070G	\N	SENCOMAFCL	2014-12-19 12:00:41	2015-01-23 15:12:43	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2565	72	2014-12-18 00:00:00	2017-12-18 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14089Y	\N	SENCOMAFCL	2014-12-19 12:02:12	2015-01-09 10:48:10	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2566	112	2014-12-18 00:00:00	2016-12-10 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01037S	\N	SENCOMAFCL	2014-12-19 12:03:50	2016-12-12 09:34:30	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2567	239	2014-12-18 00:00:00	2017-12-18 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14073Q	\N	SENCOMAFCL	2014-12-19 12:05:07	2015-01-23 15:20:07	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2568	222	2014-12-18 00:00:00	2017-12-20 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08031R	\N	SENCOMAFCL	2014-12-19 12:06:07	2017-12-22 14:32:19	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2569	29	2014-12-18 00:00:00	2017-12-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14133K	\N	SENCOMAFCL	2014-12-19 12:07:16	2017-12-22 14:31:26	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2570	29	2014-12-18 00:00:00	2018-04-17 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	14059S	\N	SENCOMAFCL	2014-12-19 12:07:48	2018-04-19 19:20:34	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2571	172	2014-12-18 00:00:00	2015-06-03 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14237S	\N	SENCOMAFCL	2014-12-19 12:10:29	2015-06-09 12:24:06	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2572	186	2014-12-18 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01025N	\N	SENCOMAFCL	2014-12-19 12:12:14	2015-01-23 15:29:57	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2573	186	2014-12-18 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	92040Q	\N	SENCOMAFCL	2014-12-19 12:12:34	2015-01-23 15:30:02	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2574	270	2014-12-17 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11071M	\N	SENCOMAFCL	2014-12-19 12:15:06	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2575	270	2014-12-17 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11109J	\N	SENCOMAFCL	2014-12-19 12:15:55	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2631	22	2014-12-24 00:00:00	2016-09-08 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	10015M	\N	PDTSEN	2014-12-31 10:51:23	2016-09-19 11:15:11	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2638	72	2015-02-04 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92039X	\N	SENCOMCDD	2015-02-05 17:52:37	2015-02-05 17:56:16	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2639	233	2015-02-04 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	02002K	\N	SENCOMCDD	2015-02-05 17:54:10	2015-02-05 17:55:22	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2740	34	2015-05-07 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11030C	\N	SENCOMLOIS	2015-05-07 16:30:42	2015-05-07 16:34:14	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2741	34	2015-05-07 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01057W	\N	SENCOMFINC	2015-05-07 16:31:07	2015-05-07 16:34:57	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2742	34	2015-05-07 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	95063L	\N	SENCOMLOIS	2015-05-07 16:31:40	2015-05-07 16:35:41	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2743	34	2015-05-07 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11074Q	\N	SENCOMFINC	2015-05-07 16:32:28	2015-05-07 16:36:10	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2770	108	2015-07-08 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11089X	\N	SENCOMAFCL	2015-07-09 14:29:08	2015-07-09 14:29:56	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2771	172	2015-07-09 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14209N	\N	SENCOMAFCL	2015-07-09 14:30:37	2017-10-01 10:34:22	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2773	295	2015-07-16 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11107G	\N	SENCOMCDD	2015-07-16 17:14:00	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2774	295	2015-07-16 00:00:00	2019-02-12 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	14107H	\N	SENCOMCDD	2015-07-16 17:14:58	2019-02-26 14:56:31	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2779	342	2015-09-30 00:00:00	2018-03-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04044E	\N	SENCOMLOIS	2015-09-30 16:21:01	2018-03-15 14:49:02	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2780	342	2015-09-30 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08058D	\N	SENCOMETRD	2015-09-30 16:21:26	2015-09-30 16:24:07	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2791	199	2015-10-08 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01046T	\N	SENCOMSOCI	2015-10-08 11:01:56	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2792	344	2015-10-08 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11099A	\N	SENCOMCAE	2015-10-08 11:04:38	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2815	8	2015-12-18 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04036E	\N	PDTSEN	2015-12-18 12:00:21	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2816	327	2015-12-18 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	14269B	\N	PDTSEN	2015-12-18 12:03:47	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2817	194	2016-01-13 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11088W	\N	SENCOMFINC	2016-01-14 08:56:29	2016-01-14 08:57:53	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2820	203	2016-02-29 00:00:00	2019-02-28 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14065Q	\N	PDTSEN	2016-02-29 15:33:50	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2830	170	2016-06-09 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04036E	\N	SENCOMSOCI	2016-06-09 12:44:38	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2841	204	2016-11-04 00:00:00	2019-02-28 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08034U	\N	PDTSEN	2016-11-04 19:19:11	2019-03-15 17:26:11	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2849	176	2017-01-19 00:00:00	2020-01-19 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14275Y	\N	SENCOMLOIS	2017-01-19 18:03:00	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2861	112	2017-07-20 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14063N	\N	SENCOMAFCL	2017-07-20 16:23:08	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2862	362	2017-07-20 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08039A	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2863	362	2017-07-20 00:00:00	2017-11-21 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01025N	\N	SENCOMAFCL	2017-07-20 16:27:02	2017-11-23 14:34:24	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2881	147	2017-11-30 00:00:00	2020-11-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11103C	\N	SENCOMSOCI	2017-11-30 16:15:08	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2882	128	2017-11-30 00:00:00	2020-11-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11097X	\N	SENCOMSOCI	2017-11-30 16:17:19	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2883	128	2017-11-30 00:00:00	2020-11-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	17779H	\N	SENCOMSOCI	2017-11-30 16:17:43	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2884	272	2017-11-30 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11031D	\N	SENCOMSOCI	2017-11-30 16:51:40	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2885	199	2017-11-30 00:00:00	2018-06-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	10006L	\N	SENCOMSOCI	2017-11-30 17:02:05	2018-11-08 16:08:35	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2886	199	2017-11-30 00:00:00	2020-11-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19683J	\N	SENCOMSOCI	2017-11-30 17:19:19	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2887	199	2017-11-30 00:00:00	2020-08-02 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14239U	\N	SENCOMSOCI	2017-11-30 17:20:00	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2888	164	2017-11-30 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11097X	\N	SENCOMSOCI	2017-11-30 17:44:23	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2889	164	2017-11-30 00:00:00	2018-01-10 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11077T	\N	SENCOMSOCI	2017-11-30 17:44:48	2018-06-07 10:05:25	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2890	164	2017-11-30 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01034P	\N	SENCOMSOCI	2017-11-30 17:45:41	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2891	212	2017-11-30 00:00:00	2019-01-23 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11097X	\N	SENCOMSOCI	2017-11-30 17:50:57	2019-02-01 17:33:03	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2892	162	2017-11-30 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08052W	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2893	127	2017-11-30 00:00:00	2020-06-24 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19727D	\N	SENCOMSOCI	2017-11-30 18:00:01	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2894	127	2017-11-30 00:00:00	2020-11-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	19569H	\N	SENCOMSOCI	2017-11-30 18:01:24	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2895	124	2017-11-29 00:00:00	2022-11-29 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19577H	\N	COMSOCI	2017-11-30 18:02:57	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2896	76	2017-11-30 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14026U	\N	COMSOCI	2017-11-30 18:04:45	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2952	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Ain	08056B	\N	PDTSEN	2017-12-18 16:00:24	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2404	316	2013-11-13 00:00:00	2019-09-24 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08024S	\N	COMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2405	316	2013-11-13 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98042T	\N	COMAFCL	2013-11-13 11:00:49	2017-10-01 10:39:23	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2407	143	2013-07-09 00:00:00	2014-03-08 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01037S	\N	SENCOMFINC	2013-11-23 17:20:43	2013-11-23 17:22:25	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2466	13	2014-07-23 00:00:00	2017-07-23 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11070L	\N	SENCOMFINC	2014-09-04 14:23:07	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2469	115	2014-06-11 00:00:00	2017-06-11 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11027H	\N	SENCOMETRD	2014-10-13 15:02:23	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2492	112	2014-12-02 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01061S	\N	SENCOMCAE	2014-12-01 14:48:02	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2505	124	2014-12-17 00:00:00	2017-07-24 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14071N	\N	COMSOCI	2014-12-17 15:38:00	2017-07-31 09:25:18	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2516	179	2014-12-17 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14033T	\N	COMCAE	2014-12-18 18:32:16	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2517	31	2014-12-17 00:00:00	2015-10-07 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08034U	\N	SENCOMFINC	2014-12-19 10:02:30	2015-10-08 11:37:17	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2518	270	2014-12-17 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01027Q	\N	SENCOMFINC	2014-12-19 10:04:24	2014-12-19 10:14:52	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2519	270	2014-12-17 00:00:00	2015-02-06 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14044W	\N	SENCOMFINC	2014-12-19 10:04:58	2015-02-06 14:32:44	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2520	270	2014-12-17 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08073C	\N	SENCOMFINC	2014-12-19 10:05:44	2014-12-19 10:12:45	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2521	270	2014-12-17 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	14083S	\N	SENCOMFINC	2014-12-19 10:06:39	2014-12-19 10:12:58	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2522	112	2014-12-18 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11085T	\N	SENCOMFINC	2014-12-19 10:15:23	2015-01-23 15:17:49	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2523	112	2014-12-18 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14159V	\N	SENCOMFINC	2014-12-19 10:16:40	2015-01-23 15:17:30	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2524	126	2014-12-17 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04061F	\N	SENCOMFINC	2014-12-19 10:18:25	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2525	126	2014-12-17 00:00:00	2017-12-17 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04061F	\N	SENCOMFINC	2014-12-19 10:19:26	2017-10-11 18:12:55	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2526	126	2014-12-17 00:00:00	2017-12-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	88008L	\N	SENCOMFINC	2014-12-19 10:20:33	2017-10-11 18:12:48	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2527	49	2014-12-17 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11074Q	\N	SENCOMFINC	2014-12-19 10:22:14	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2528	236	2014-12-17 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01027Q	\N	SENCOMFINC	2014-12-19 10:25:16	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2529	236	2014-12-17 00:00:00	2017-06-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14175V	\N	SENCOMFINC	2014-12-19 10:26:08	2017-06-02 10:02:56	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2530	180	2014-12-17 00:00:00	2020-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	08034U	\N	SENCOMFINC	2014-12-19 10:27:30	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2531	164	2014-12-17 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01013J	\N	SENCOMFINC	2014-12-19 10:28:46	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2532	17	2014-12-17 00:00:00	2019-06-24 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04061F	\N	SENCOMFINC	2014-12-19 10:30:07	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2533	141	2014-12-17 00:00:00	2015-06-12 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98027U	\N	SENCOMFINC	2014-12-19 10:31:33	2015-06-12 16:01:58	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2534	296	2014-12-17 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11088W	\N	SENCOMFINC	2014-12-19 10:32:39	2014-12-19 10:34:06	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2535	296	2014-12-17 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	14167V	\N	SENCOMFINC	2014-12-19 10:33:01	2014-12-19 10:34:14	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2536	194	2014-12-17 00:00:00	2015-11-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08022Q	\N	SENCOMFINC	2014-12-19 10:34:52	2015-11-24 17:27:19	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2537	270	2014-12-17 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11023D	\N	SENCOMSOCI	2014-12-19 10:37:42	2014-12-19 10:40:50	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2538	270	2014-12-17 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14017T	\N	SENCOMSOCI	2014-12-19 10:38:23	2014-12-19 10:41:00	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2539	270	2014-12-17 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11025F	\N	SENCOMSOCI	2014-12-19 10:39:09	2014-12-19 10:41:08	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2540	270	2014-12-17 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04043D	\N	SENCOMSOCI	2014-12-19 10:39:51	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2541	212	2014-12-17 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11097X	\N	SENCOMSOCI	2014-12-19 10:41:53	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2542	128	2014-12-17 00:00:00	2017-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11093T	\N	SENCOMSOCI	2014-12-19 10:43:09	2017-09-24 12:57:09	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2543	232	2014-12-17 00:00:00	2016-03-23 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	14053L	\N	SENCOMSOCI	2014-12-19 10:44:56	2016-03-23 17:50:40	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2544	97	2014-12-17 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04043D	\N	SENCOMSOCI	2014-12-19 10:46:54	2015-01-06 14:41:25	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2545	180	2014-12-17 00:00:00	2017-11-29 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14034U	\N	SENCOMSOCI	2014-12-19 10:49:05	2017-12-11 17:08:25	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2546	164	2014-12-17 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04043D	\N	SENCOMSOCI	2014-12-19 10:50:08	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2547	164	2014-12-17 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11112D	\N	SENCOMSOCI	2014-12-19 10:50:46	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2548	164	2014-12-17 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11093T	\N	SENCOMSOCI	2014-12-19 10:51:19	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2549	190	2014-12-17 00:00:00	2019-06-20 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08041T	\N	SENCOMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2550	95	2014-12-17 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01059Y	\N	SENCOMSOCI	2014-12-19 10:53:46	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2551	127	2014-12-17 00:00:00	2017-11-29 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14053L	\N	SENCOMSOCI	2014-12-19 10:55:15	2017-11-30 18:02:41	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2552	16	2014-12-17 00:00:00	2015-05-26 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01011G	\N	SENCOMSOCI	2014-12-19 10:56:55	2017-03-30 14:58:25	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2553	267	2014-12-17 00:00:00	2017-06-20 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11063M	\N	SENCOMSOCI	2014-12-19 10:58:27	2017-06-20 17:57:01	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2554	247	2014-12-17 00:00:00	2017-06-09 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11044J	\N	SENCOMSOCI	2014-12-19 10:59:50	2017-06-13 11:59:19	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2555	247	2014-12-17 00:00:00	2017-06-09 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11067R	\N	SENCOMSOCI	2014-12-19 11:00:15	2017-06-13 11:59:19	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2556	296	2014-12-17 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01034P	\N	SENCOMSOCI	2014-12-19 11:01:20	2014-12-19 11:02:43	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2557	296	2014-12-17 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	08052W	\N	SENCOMSOCI	2014-12-19 11:01:52	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2558	194	2014-12-17 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08052W	\N	SENCOMSOCI	2014-12-19 11:03:30	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2559	194	2014-12-17 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08052W	\N	SENCOMSOCI	2014-12-19 11:04:20	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2560	194	2014-12-17 00:00:00	2017-07-22 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14037X	\N	SENCOMSOCI	2014-12-19 11:04:51	2017-07-24 09:58:00	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2576	285	2014-12-18 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11090Q	\N	SENCOMCAE	2014-12-19 13:59:00	2015-01-06 10:39:16	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2577	161	2014-12-17 00:00:00	2017-10-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04088S	\N	SENCOMCAE	2014-12-19 14:00:28	2017-10-23 11:05:13	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2578	243	2014-12-17 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14187A	\N	SENCOMCAE	2014-12-19 14:01:47	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2579	311	2014-12-17 00:00:00	2018-09-12 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08068F	\N	SENCOMCAE	2014-12-19 14:03:06	2018-09-21 17:55:29	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2580	20	2014-12-17 00:00:00	2017-03-07 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08015R	\N	SENCOMCAE	2014-12-19 14:04:19	2017-04-12 11:02:27	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2581	20	2014-12-17 00:00:00	2017-03-07 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08019V	\N	SENCOMCAE	2014-12-19 14:04:36	2017-04-12 11:02:34	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2582	270	2014-12-17 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04094Q	\N	SENCOMCAE	2014-12-19 14:06:00	2014-12-19 14:07:31	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2583	270	2014-12-17 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	08019V	\N	SENCOMCAE	2014-12-19 14:06:34	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2584	251	2015-10-08 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	90003B	\N	SENCOMCAE	2014-12-19 14:08:34	2017-10-01 10:01:39	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2585	192	2014-12-17 00:00:00	2015-01-09 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04049K	\N	SENCOMCAE	2014-12-19 14:09:35	2015-01-16 16:47:25	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2586	95	2014-12-17 00:00:00	2017-12-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14197C	\N	SENCOMCAE	2014-12-19 14:10:28	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2587	16	2014-12-17 00:00:00	2015-05-26 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11111C	\N	SENCOMCAE	2014-12-19 14:12:39	2017-03-30 14:58:35	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2589	24	2014-12-17 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11081P	\N	SENCOMCAE	2014-12-19 14:18:10	2014-12-19 14:20:55	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2590	24	2014-12-17 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	Président	\N	\N	80013X	\N	SENCOMCAE	2014-12-19 14:18:48	2015-10-01 14:51:18	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2591	24	2014-12-17 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11094U	\N	SENCOMCAE	2014-12-19 14:19:31	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2592	81	2014-12-17 00:00:00	2017-12-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04089T	\N	SENCOMCAE	2014-12-19 14:21:32	2014-12-19 14:22:55	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2593	81	2014-12-17 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11046L	\N	SENCOMCAE	2014-12-19 14:21:51	2014-12-19 14:23:03	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2594	207	2014-12-17 00:00:00	2015-03-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14081Q	\N	SENCOMCAE	2014-12-19 14:23:52	2017-04-12 11:04:00	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2595	333	2014-12-17 00:00:00	2015-03-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14257W	\N	SENCOMCAE	2014-12-19 14:25:11	2017-04-12 11:05:20	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2596	233	2014-12-17 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01058X	\N	SENCOMCAE	2014-12-19 14:26:42	2014-12-19 14:27:49	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2597	193	2014-12-17 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98050T	\N	SENCOMCAE	2014-12-19 14:28:32	2014-12-19 14:29:43	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2598	193	2014-12-17 00:00:00	2017-06-17 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	14013P	\N	SENCOMCAE	2014-12-19 14:28:47	2017-06-19 16:06:01	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2599	161	2014-12-17 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14135M	\N	SENCOMCDD	2014-12-19 14:32:22	2014-12-19 14:33:24	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2412	311	2013-09-12 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08055A	\N	SENCOMCAE	2014-01-09 15:52:31	2014-08-01 10:54:12	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2413	311	2013-09-12 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11094U	\N	SENCOMCDD	2014-01-09 15:53:38	2014-08-01 10:55:05	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2414	311	2013-09-12 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11101A	\N	SENCOMCAE	2014-01-09 15:54:21	2014-08-01 10:55:14	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2415	311	2013-09-12 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11077T	\N	SENCOMCAE	2014-01-09 15:55:21	2014-08-01 10:57:38	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2416	312	2013-09-11 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08055A	\N	PDTSEN	2014-01-09 16:02:43	2014-08-01 11:18:03	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2417	312	2013-09-11 00:00:00	2016-11-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04048J	\N	PDTSEN	2014-01-09 16:03:32	2016-11-30 17:57:14	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2419	317	2014-01-20 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04070G	\N	SENCOMAFCL	2014-01-20 16:47:37	2014-08-01 11:30:01	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2420	317	2014-01-20 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04059M	\N	COMAFCL	2014-01-20 16:48:16	2014-11-13 17:18:49	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2421	317	2014-01-20 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04033B	\N	SENCOMCAE	2014-01-20 16:50:02	2014-08-01 11:30:23	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2422	317	2014-01-20 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11066Q	\N	COMCAE	2014-01-20 16:51:11	2014-11-13 17:18:41	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2438	176	2014-05-05 00:00:00	2013-11-18 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04069P	\N	SENCOMCDD	2014-04-30 14:49:14	2014-09-28 17:31:42	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2439	164	2014-05-05 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11112D	\N	SENCOMSOCI	2014-05-07 09:29:18	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2440	180	2014-05-05 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11112D	\N	SENCOMSOCI	2014-05-07 09:31:31	2014-11-25 15:06:48	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2459	322	2014-07-10 00:00:00	2015-04-07 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11108H	\N	COMFINC	2014-07-10 14:55:53	2015-04-07 16:50:27	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2460	322	2014-07-10 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11088W	\N	COMFINC	2014-07-10 14:57:41	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2493	112	2014-12-20 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01058X	\N	SENCOMCAE	2014-12-02 14:59:48	2014-12-02 15:00:55	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2494	292	2014-12-10 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92031P	\N	COMETRD	2014-12-12 16:31:48	2014-12-12 16:33:34	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2495	279	2014-12-10 00:00:00	2015-01-06 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14028W	\N	COMETRD	2014-12-12 16:34:31	2015-01-06 16:40:24	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2496	273	2014-12-10 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11015D	\N	COMETRD	2014-12-12 16:36:33	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2600	245	2014-12-17 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	13002U	\N	SENCOMCDD	2014-12-19 14:33:44	2014-12-19 14:34:45	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2601	169	2014-12-18 00:00:00	2017-03-20 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14093U	\N	SENCOMCDD	2014-12-19 14:35:09	2017-03-21 10:13:37	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2602	270	2014-12-17 00:00:00	2016-11-12 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	96003C	\N	SENCOMCDD	2014-12-19 14:37:25	2016-11-14 09:20:58	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2603	270	2014-12-17 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11020A	\N	SENCOMCDD	2014-12-19 14:38:13	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2604	72	2014-12-18 00:00:00	2017-12-06 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14169X	\N	SENCOMCDD	2014-12-19 14:39:09	2017-12-08 18:18:05	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2605	112	2014-12-18 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11095V	\N	SENCOMCDD	2014-12-19 14:40:20	2015-01-23 15:17:55	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2606	112	2014-12-18 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14038Y	\N	SENCOMCDD	2014-12-19 14:41:00	2015-01-23 15:18:03	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2607	29	2014-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14093U	\N	SENCOMCDD	2014-12-19 14:42:12	2015-01-23 15:25:08	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2608	189	2014-12-17 00:00:00	2017-12-06 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14219Q	\N	SENCOMCDD	2014-12-19 14:43:28	2017-12-08 18:23:55	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2609	185	2014-12-17 00:00:00	2017-02-20 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	14261S	\N	SENCOMCDD	2014-12-19 14:44:52	2017-03-16 12:24:36	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2610	172	2014-12-18 00:00:00	2019-05-24 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Démission de M. Mandelli de cet OEP	14031R	\N	SENCOMCDD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2611	282	2014-12-17 00:00:00	2016-01-14 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	14030Q	\N	SENCOMCDD	2014-12-19 14:49:17	2016-03-03 09:51:39	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2612	282	2014-12-17 00:00:00	2016-01-14 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	14051J	\N	SENCOMCDD	2014-12-19 14:53:11	2016-03-03 09:51:34	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2613	176	2014-12-17 00:00:00	2017-05-05 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14169X	\N	SENCOMCDD	2014-12-19 14:54:25	2017-01-18 17:35:15	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2614	141	2014-12-17 00:00:00	2018-09-12 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	05012A	\N	SENCOMCDD	2014-12-19 14:55:41	2018-09-21 17:45:31	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2615	141	2014-12-17 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11059R	\N	SENCOMCDD	2014-12-19 14:57:07	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2616	295	2014-12-17 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	08042U	\N	SENCOMCDD	2014-12-19 14:58:49	2017-10-01 10:20:50	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2617	295	2014-12-17 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	05012A	\N	SENCOMCDD	2014-12-19 14:59:25	2014-12-19 15:03:06	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2618	295	2014-12-17 00:00:00	2015-06-12 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14137P	\N	SENCOMCDD	2014-12-19 14:59:57	2015-06-12 15:59:18	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2619	169	2014-12-18 00:00:00	2015-02-06 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14043V	\N	SENCOMLOIS	2014-12-19 15:07:36	2015-02-06 14:27:55	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2632	124	2015-02-04 00:00:00	2020-02-04 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	14227Q	\N	COMSOCI	2015-02-04 11:11:07	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2621	310	2014-12-17 00:00:00	2020-12-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08018U	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2622	310	2014-12-17 00:00:00	2020-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	14093U	\N	SENCOMLOIS	2014-12-19 15:11:07	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2623	141	2014-12-17 00:00:00	2017-12-19 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04038G	\N	SENCOMLOIS	2014-12-19 15:12:13	2017-12-26 11:50:25	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2624	246	2014-12-17 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	05008E	\N	SENCOMLOIS	2014-12-19 15:13:33	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2625	270	2014-12-17 00:00:00	2015-10-12 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95039L	\N	SENCOMLOIS	2014-12-19 15:15:07	2015-10-12 09:39:31	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2626	270	2014-12-17 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11113E	\N	SENCOMLOIS	2014-12-19 15:15:51	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2627	270	2014-12-17 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11010L	\N	SENCOMLOIS	2014-12-19 15:16:31	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2628	270	2014-12-17 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11072N	\N	SENCOMLOIS	2014-12-19 15:17:03	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2629	270	2014-12-17 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11113E	\N	SENCOMLOIS	2014-12-19 15:22:43	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2652	275	2015-03-03 00:00:00	2016-11-03 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Membre du (1) et (2)	08022Q	\N	PDTSEN	2015-03-05 10:35:58	2017-03-15 16:41:49	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2653	275	2015-03-03 00:00:00	2016-11-03 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Membre du (1)	01031L	\N	PDTSEN	2015-03-05 10:40:07	2017-03-15 16:41:13	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2654	275	2015-03-03 00:00:00	2016-11-03 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	Membre du (2)	14133K	\N	PDTSEN	2015-03-05 10:44:50	2017-03-15 16:41:54	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2657	155	2015-03-12 00:00:00	2017-03-12 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14257W	\N	SENCOMCAE	2015-03-12 16:03:13	2015-03-12 16:04:52	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2731	333	2015-04-15 00:00:00	2018-04-15 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14257W	\N	SENCOMCAE	2015-04-27 12:37:59	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2732	333	2015-04-15 00:00:00	2018-04-15 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14187A	\N	SENCOMCAE	2015-04-27 12:40:54	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2739	199	2015-05-06 00:00:00	2018-05-06 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14195A	\N	SENCOMSOCI	2015-05-07 09:07:01	2015-05-18 08:38:19	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2746	24	2015-05-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14033T	\N	SENCOMCAE	2015-05-20 08:08:52	2015-05-20 08:10:47	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2747	258	2015-05-18 00:00:00	2016-07-12 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	14257W	\N	SENCOMCAE	2015-05-20 08:13:08	2016-07-19 12:45:07	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2748	304	2015-05-19 00:00:00	2015-05-19 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	08039A	\N	SENCOMAFCL	2015-05-20 08:16:29	2015-05-20 08:17:56	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2749	304	2015-05-19 00:00:00	2017-12-08 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	08039A	\N	SENCOMAFCL	2015-05-20 08:18:26	2018-01-16 17:21:03	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2750	330	2015-05-19 00:00:00	2018-05-19 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14235Q	\N	SENCOMAFCL	2015-05-20 08:20:46	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2751	334	2015-05-19 00:00:00	2015-10-05 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11101A	\N	SENCOMCAE	2015-05-20 08:22:52	2015-10-12 11:03:48	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2755	199	2015-06-16 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11061K	\N	SENCOMSOCI	2015-06-16 17:12:23	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2762	167	2015-06-24 00:00:00	2020-06-24 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04070G	\N	SENCOMAFCL	2015-06-29 15:34:59	2015-06-29 15:36:18	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2765	313	2015-07-08 00:00:00	2017-11-14 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14073Q	\N	COMAFCL	2015-07-08 14:33:19	2017-11-17 17:52:05	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2775	341	2015-07-22 00:00:00	2017-11-14 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14249W	\N	COMAFCL	2015-07-23 10:02:39	2017-11-16 17:15:26	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2799	334	2015-10-21 00:00:00	2018-10-21 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14187A	\N	SENCOMCAE	2015-10-26 12:08:47	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2800	344	2015-10-22 00:00:00	2015-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	14169X	\N	SENCOMCDD	2015-10-26 12:11:54	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2801	344	2015-10-22 00:00:00	2020-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	14169X	\N	SENCOMCDD	2015-10-26 12:13:22	2015-10-26 12:14:35	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2803	270	2015-10-29 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14259Y	\N	SENCOMLOIS	2015-10-29 16:12:27	2015-10-29 16:14:13	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2804	152	2015-10-29 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14187A	\N	PDTSEN	2015-10-29 19:36:06	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2807	339	2015-11-20 00:00:00	2017-07-03 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01044R	\N	PDTSEN	2015-11-20 14:54:03	2017-07-04 15:08:09	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2808	339	2015-11-20 00:00:00	2017-10-05 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14193X	\N	PDTSEN	2015-11-20 14:54:25	2017-10-16 15:07:39	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2809	343	2015-11-20 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	99004R	\N	PDTSEN	2015-11-20 15:07:42	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2418	42	2008-12-04 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98030P	\N	SENCOMAFCL	2014-01-13 08:54:25	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2470	612	2014-10-29 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04047H	1	SENAT	2014-11-10 10:52:34	2014-11-12 17:01:10	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2471	612	2014-10-29 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01024M	2	SENAT	2014-11-10 10:53:04	2014-11-12 17:01:36	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2446	206	2014-06-19 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08064B	\N	PDTSEN	2014-06-20 11:17:36	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2455	320	2014-07-02 00:00:00	2017-07-02 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01027Q	\N	SENCOMFINC	2014-07-03 09:38:25	2014-08-01 11:36:13	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2456	320	2014-07-02 00:00:00	2017-07-02 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01028R	\N	SENCOMLOIS	2014-07-03 09:39:28	2014-07-03 09:45:02	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2457	320	2014-07-02 00:00:00	2017-07-02 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	08014Q	\N	SENCOMFINC	2014-07-03 09:39:53	2014-11-05 18:45:08	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2458	320	2014-07-02 00:00:00	2017-07-02 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01007L	\N	SENCOMLOIS	2014-07-03 09:40:18	2014-08-01 11:37:01	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2472	612	2014-10-29 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92020L	3	SENAT	2014-11-10 10:53:48	2014-11-12 17:01:48	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2473	612	2014-10-29 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04077P	4	SENAT	2014-11-10 10:54:25	2014-11-12 17:02:00	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2474	612	2014-10-29 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	07034Q	5	SENAT	2014-11-10 10:55:07	2014-11-12 17:02:14	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2475	612	2014-10-29 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01019Q	6	SENAT	2014-11-10 10:55:47	2014-11-12 17:02:28	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2476	612	2014-10-29 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04044E	1	SENAT	2014-11-10 10:56:57	2014-11-12 17:02:55	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2477	612	2014-10-29 00:00:00	2017-07-21 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01007L	2	SENAT	2014-11-10 10:57:29	2017-07-24 09:56:26	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2478	612	2014-10-29 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	08025T	3	SENAT	2014-11-10 10:58:03	2014-11-12 17:03:35	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2479	612	2014-10-29 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01028R	4	SENAT	2014-11-10 10:59:01	2014-11-12 17:03:52	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2480	612	2014-10-29 00:00:00	2015-04-21 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01042P	5	SENAT	2014-11-10 10:59:27	2015-04-21 17:14:30	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2481	612	2014-10-29 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	02002K	6	SENAT	2014-11-10 11:00:17	2014-11-12 17:04:33	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2488	610	2014-11-26 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14221J	\N	PDTOPECST	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2489	610	2014-11-26 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01046T	\N	PDTOPECST	2014-11-27 16:41:27	2014-11-27 16:45:11	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2511	319	2014-12-17 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	07026Q	\N	COMAFCL	2014-12-18 09:51:32	2014-12-18 09:53:57	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2512	319	2014-12-17 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11091R	\N	COMAFCL	2014-12-18 09:51:50	2014-12-18 09:54:04	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2513	319	2014-12-17 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11043H	\N	COMAFCL	2014-12-18 09:52:31	2014-12-18 09:54:12	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2514	319	2014-12-17 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11039M	\N	COMAFCL	2014-12-18 09:53:13	2014-12-18 09:54:19	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2515	249	2014-12-17 00:00:00	2018-09-12 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	08039A	\N	COMAFCL	2014-12-18 09:56:23	2018-09-21 18:01:42	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2648	118	2014-11-24 00:00:00	2015-09-29 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04047H	\N	PDTSEN	2015-02-19 18:20:35	2015-10-02 11:22:09	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2651	306	2015-03-04 00:00:00	2017-06-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14175V	\N	PDTSEN	2015-03-04 11:27:32	2017-06-02 10:02:56	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2671	262	2015-03-24 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11090Q	\N	PDTSEN	2015-03-23 15:40:54	2015-03-23 15:42:02	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2672	201	2015-03-24 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11053K	\N	PDTSEN	2015-03-23 15:43:08	2015-03-23 15:44:49	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2673	201	2015-03-24 00:00:00	2020-12-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04034C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2674	200	2015-03-24 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04071H	\N	PDTSEN	2015-03-23 15:46:07	2015-03-23 15:47:33	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2675	200	2015-03-24 00:00:00	2020-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	08014Q	\N	PDTSEN	2015-03-23 15:46:29	2015-03-23 15:47:44	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2676	234	2015-03-24 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11044J	\N	PDTSEN	2015-03-23 15:48:40	2015-03-23 15:50:05	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2677	234	2015-03-24 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11067R	\N	PDTSEN	2015-03-23 15:48:57	2015-03-23 15:50:12	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2678	64	2015-03-24 00:00:00	2017-06-09 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11093T	\N	PDTSEN	2015-03-23 15:53:06	2017-06-13 11:56:08	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2679	64	2015-03-24 00:00:00	2017-06-09 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11112D	\N	PDTSEN	2015-03-23 15:53:25	2017-06-13 11:56:21	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2680	175	2015-03-24 00:00:00	2017-10-04 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14069U	\N	PDTSEN	2015-03-23 16:00:21	2017-10-10 14:51:20	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2681	67	2015-03-24 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11103C	\N	PDTSEN	2015-03-23 16:04:10	2015-03-23 16:11:32	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2682	67	2015-03-24 00:00:00	2017-12-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04092N	\N	PDTSEN	2015-03-23 16:04:50	2017-12-05 17:54:18	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2683	67	2015-03-24 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01034P	\N	PDTSEN	2015-03-23 16:09:02	2015-03-23 16:12:50	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2684	227	2015-03-24 00:00:00	2016-05-18 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	05012A	\N	PDTSEN	2015-03-23 16:13:31	2017-04-12 11:04:46	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2685	227	2015-03-24 00:00:00	2016-05-18 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14107H	\N	PDTSEN	2015-03-23 16:14:04	2017-04-12 11:04:49	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2686	121	2015-03-24 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01041N	\N	PDTSEN	2015-03-23 16:16:17	2015-03-23 16:17:24	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2687	121	2015-03-24 00:00:00	2020-12-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08017T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2688	312	2015-03-24 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08055A	\N	PDTSEN	2015-03-23 16:18:13	2015-03-23 16:19:12	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2689	298	2015-03-24 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11100Y	\N	PDTSEN	2015-03-23 16:19:59	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2690	220	2015-03-24 00:00:00	0207-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11095V	\N	PDTSEN	2015-03-23 16:21:06	2015-03-23 16:23:44	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2691	220	2015-03-24 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01025N	\N	PDTSEN	2015-03-23 16:21:21	2015-03-23 16:25:14	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2692	220	2015-03-24 00:00:00	2018-03-24 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14031R	\N	PDTSEN	2015-03-23 16:21:46	2015-03-23 16:23:10	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2693	220	2015-03-24 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11095V	\N	PDTSEN	2015-03-23 16:23:56	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2694	265	2015-03-24 00:00:00	2017-11-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08028W	\N	PDTSEN	2015-03-23 16:27:01	2018-01-16 17:02:50	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2695	299	2015-03-24 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01046T	\N	PDTSEN	2015-03-23 16:30:18	2015-03-23 16:31:39	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2696	299	2015-03-24 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98024R	\N	PDTSEN	2015-03-23 16:30:51	2017-11-13 13:03:12	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2697	221	2015-03-24 00:00:00	2016-11-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95062K	\N	PDTSEN	2015-03-23 16:32:22	2016-11-22 15:51:51	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2698	206	2015-03-24 00:00:00	2017-12-26 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	05012A	\N	PDTSEN	2015-03-23 16:33:28	2018-05-03 10:54:42	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2699	213	2015-03-24 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	12042Y	\N	PDTSEN	2015-03-23 16:36:22	2015-03-23 16:37:33	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2700	213	2015-03-24 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14034U	\N	PDTSEN	2015-03-23 16:36:40	2015-03-23 16:37:40	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2701	314	2015-03-24 00:00:00	2018-03-24 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14219Q	\N	PDTSEN	2015-03-23 16:38:11	2016-10-05 18:00:17	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2702	314	2015-03-24 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01015L	\N	PDTSEN	2015-03-23 16:38:42	2015-05-07 11:38:21	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2703	325	2015-03-24 00:00:00	2018-03-24 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	14121F	\N	PDTSEN	2015-03-23 16:40:39	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2704	297	2015-03-24 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04044E	\N	PDTSEN	2015-03-23 16:42:13	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2705	308	2015-03-24 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11043H	\N	PDTSEN	2015-03-23 16:43:26	2015-03-23 16:44:52	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2706	308	2015-03-24 00:00:00	2020-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	08012N	\N	PDTSEN	2015-03-23 16:43:42	2015-03-23 16:45:19	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2707	98	2015-03-24 00:00:00	2018-09-12 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14105F	\N	PDTSEN	2015-03-23 16:46:00	2018-09-21 17:37:55	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2708	98	2015-03-24 00:00:00	2018-09-12 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14135M	\N	PDTSEN	2015-03-23 16:46:53	2018-09-21 17:38:05	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2709	168	2015-03-24 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08058D	\N	PDTSEN	2015-03-23 16:49:26	2015-03-23 16:51:28	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2710	168	2015-03-24 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04035D	\N	PDTSEN	2015-03-23 16:49:40	2015-03-23 16:51:21	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2711	168	2015-03-24 00:00:00	2020-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	08047A	\N	PDTSEN	2015-03-23 16:50:02	2015-03-23 16:51:42	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2712	168	2015-03-24 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11054L	\N	PDTSEN	2015-03-23 16:50:28	2015-03-23 16:52:00	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2713	291	2015-03-24 00:00:00	2019-02-12 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	14157T	\N	PDTSEN	2015-03-23 16:52:43	2019-02-26 12:09:47	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2714	303	2015-03-24 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	80013X	\N	PDTSEN	2015-03-23 16:54:52	2015-07-08 14:54:00	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2715	303	2015-03-24 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14059S	\N	PDTSEN	2015-03-23 16:55:06	2015-03-23 16:57:03	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2716	303	2015-03-24 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11031D	\N	PDTSEN	2015-03-23 16:55:45	2015-03-23 16:57:13	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2717	303	2015-03-24 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	08056B	\N	PDTSEN	2015-03-23 16:56:14	2015-03-23 16:57:20	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2400	156	2013-10-30 00:00:00	2017-10-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04070G	\N	PDTSEN	2013-11-04 09:57:40	2015-07-20 18:44:16	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2401	307	2013-10-30 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98041S	\N	PDTSEN	2013-11-04 10:12:21	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2406	189	2013-12-03 00:00:00	2016-12-03 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08022Q	\N	SENCOMFINC	2013-11-13 17:52:55	2017-02-27 18:31:06	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2408	176	2013-12-03 00:00:00	2015-06-12 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95020Y	\N	SENCOMLOIS	2013-12-03 09:27:35	2015-06-12 16:01:25	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2409	189	2013-12-03 00:00:00	2013-11-12 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	depuis, dev dur	08022Q	\N	SENCOMFINC	2013-12-04 09:28:15	2014-07-11 16:19:30	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2410	13	2013-12-03 00:00:00	2014-06-18 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	83011J	\N	SENCOMFINC	2013-12-04 09:30:01	2014-07-10 14:54:15	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2411	239	2013-12-12 00:00:00	2013-10-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98010K	\N	SENCOMAFCL	2013-12-12 10:31:48	2014-09-28 17:27:35	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2465	323	2014-07-18 00:00:00	2017-07-18 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08042U	\N	PDTSEN	2014-07-21 18:29:36	2017-06-14 16:02:19	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2641	259	2015-02-16 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11042G	\N	PDTSEN	2015-02-13 14:10:01	2015-02-13 14:14:02	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2642	259	2015-02-16 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08028W	\N	PDTSEN	2015-02-13 14:10:27	2015-02-13 14:12:53	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2643	259	2015-02-16 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98042T	\N	PDTSEN	2015-02-13 14:11:03	2017-10-01 10:39:23	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2644	259	2015-02-16 00:00:00	2019-06-24 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04061F	\N	PDTSEN	2015-02-13 14:11:31	2015-02-13 14:13:16	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2660	208	2015-03-19 00:00:00	2018-03-19 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08024S	\N	SENCOMAFCL	2015-03-19 09:43:40	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2661	72	2015-03-19 00:00:00	2018-03-19 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14229S	\N	SENCOMAFCL	2015-03-19 09:45:28	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2662	138	2015-03-19 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	92045V	\N	SENCOMAFCL	2015-03-19 09:48:00	2015-03-19 09:53:33	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2663	138	2015-03-19 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11104D	\N	SENCOMAFCL	2015-03-19 09:48:23	2015-03-19 09:52:50	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2664	138	2015-03-19 00:00:00	2017-09-22 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04041B	\N	SENCOMAFCL	2015-03-19 09:49:00	2017-09-24 11:09:53	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2665	99	2015-03-19 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11043H	\N	SENCOMAFCL	2015-03-19 09:54:11	2015-03-19 09:56:12	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2666	104	2015-03-19 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04057K	\N	SENCOMAFCL	2015-03-19 09:57:20	2015-03-19 10:02:56	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2667	104	2015-03-19 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11029K	\N	SENCOMAFCL	2015-03-19 09:57:51	2015-03-19 10:04:03	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2668	274	2015-03-19 00:00:00	2018-03-19 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04070G	\N	SENCOMAFCL	2015-03-19 09:59:46	2015-03-19 10:00:58	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2718	307	2015-03-24 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08031R	\N	PDTSEN	2015-03-23 16:58:10	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2719	307	2015-03-24 00:00:00	2015-11-19 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04074L	\N	PDTSEN	2015-03-23 16:58:32	2015-11-24 16:45:52	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2720	324	2015-03-24 00:00:00	2015-10-06 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	08044W	\N	PDTSEN	2015-03-23 16:59:29	2015-10-07 12:24:50	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2721	218	2015-03-24 00:00:00	2017-04-20 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	89017R	\N	PDTSEN	2015-03-23 17:01:34	2017-04-20 18:01:39	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2722	315	2015-03-24 00:00:00	2017-09-19 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14205J	\N	PDTSEN	2015-03-23 17:02:36	2017-10-11 11:58:03	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2723	315	2015-03-24 00:00:00	2017-09-19 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04045F	\N	PDTSEN	2015-03-23 17:02:56	2017-10-11 11:58:03	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2724	137	2015-03-24 00:00:00	2017-08-06 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04053F	\N	PDTSEN	2015-03-23 17:04:32	2017-08-07 16:31:39	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2725	327	2015-03-24 00:00:00	2016-01-11 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11060J	\N	PDTSEN	2015-03-23 17:05:40	2016-01-11 17:34:09	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2726	327	2015-03-24 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11066Q	\N	PDTSEN	2015-03-23 17:05:58	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2727	126	2015-04-01 00:00:00	2017-12-11 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	08056B	\N	SENCOMETRD	2015-04-01 14:56:08	2017-12-18 12:35:47	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2733	205	2015-03-25 00:00:00	2015-06-24 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	14001X	\N	PDTSEN	2015-04-29 11:38:28	2015-06-26 09:14:28	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2735	322	2015-05-06 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14225N	\N	COMFINC	2015-05-06 15:15:20	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2736	185	2015-05-06 00:00:00	2017-02-20 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11065P	\N	SENCOMCDD	2015-05-06 15:23:43	2017-03-16 12:24:59	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2737	282	2015-05-06 00:00:00	2016-01-14 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01022K	\N	SENCOMCDD	2015-05-06 15:26:21	2016-03-03 09:51:22	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2738	282	2015-05-06 00:00:00	2016-01-14 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08019V	\N	SENCOMCDD	2015-05-06 15:27:28	2016-03-03 09:51:13	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2752	270	2015-05-28 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14277B	\N	SENCOMFINC	2015-05-27 14:40:52	2015-05-28 14:40:10	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2756	326	2015-06-16 00:00:00	2017-07-21 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01007L	\N	PDTSEN	2015-06-17 12:06:36	2017-07-24 09:56:26	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2757	338	2015-06-18 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11111C	\N	SENCOMCAE	2015-06-19 09:34:15	2015-06-19 09:38:45	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3143	186	2017-12-20 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04018C	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2758	338	2015-06-18 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01011G	\N	SENCOMSOCI	2015-06-19 09:34:43	2015-06-19 09:38:51	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2759	338	2015-06-18 00:00:00	2020-06-18 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	08038Y	\N	SENCOMCAE	2015-06-19 09:35:17	2015-06-19 09:37:48	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2760	338	2015-06-18 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	12042Y	\N	SENCOMSOCI	2015-06-19 09:35:50	2015-06-19 09:38:59	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2761	13	2015-06-18 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11057P	\N	SENCOMFINC	2015-06-19 09:44:51	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2766	176	2015-07-08 00:00:00	2016-03-03 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01024M	\N	SENCOMLOIS	2015-07-08 15:32:51	2017-01-18 17:35:34	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2767	202	2015-07-07 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11049P	\N	SENCOMLOIS	2015-07-08 15:34:58	2015-07-08 15:35:56	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2768	286	2015-07-08 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11049P	\N	SENCOMLOIS	2015-07-08 15:36:35	2015-07-08 15:38:11	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2769	286	2015-07-08 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11084S	\N	SENCOMLOIS	2015-07-08 15:37:02	2015-07-08 15:38:19	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2781	86	2015-10-07 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14053L	\N	PDTSEN	2015-10-07 12:07:39	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2782	337	2015-10-07 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11090Q	\N	PDTSEN	2015-10-07 12:10:43	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2783	203	2015-10-07 00:00:00	2017-10-11 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	07034Q	\N	PDTSEN	2015-10-07 12:12:07	2017-10-18 17:10:27	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2784	289	2015-10-07 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11113E	\N	PDTSEN	2015-10-07 12:14:00	2015-10-07 12:14:49	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2785	335	2015-10-07 00:00:00	2018-09-15 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14239U	\N	PDTSEN	2015-10-07 12:15:31	2018-10-22 18:09:29	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2786	340	2015-10-07 00:00:00	2018-10-07 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08038Y	\N	PDTSEN	2015-10-07 12:20:01	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2787	340	2015-10-07 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01043Q	\N	PDTSEN	2015-10-07 12:20:46	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2788	336	2015-10-07 00:00:00	2018-12-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	98023Q	\N	PDTSEN	2015-10-07 12:22:21	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2789	336	2015-10-07 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11107G	\N	PDTSEN	2015-10-07 12:22:45	2015-10-07 12:23:49	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2790	324	2015-10-07 00:00:00	2019-10-07 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08044W	\N	PDTSEN	2015-10-07 12:25:07	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2802	196	2015-10-26 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04047H	\N	SENCOMLOIS	2015-10-27 12:36:02	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2806	261	2015-11-04 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	96004D	\N	SENCOMCDD	2015-11-05 09:04:37	2015-11-05 09:05:56	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2810	327	2015-11-20 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11063M	\N	PDTSEN	2015-11-20 15:10:12	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2811	324	2015-11-20 00:00:00	2017-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11056N	\N	PDTSEN	2015-11-20 15:11:38	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2812	210	2015-11-20 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01027Q	\N	PDTSEN	2015-11-20 15:13:47	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2813	210	2015-11-20 00:00:00	2017-12-20 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04038G	\N	PDTSEN	2015-11-20 15:14:28	2018-01-08 17:33:52	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2814	37	2015-12-02 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14205J	\N	SENCOMCAE	2015-12-03 09:06:30	2015-12-03 09:07:56	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2825	95	2016-05-10 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95067Q	\N	SENCOMLOIS	2016-05-11 15:20:10	2017-12-18 11:40:49	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2826	95	2016-05-10 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14107H	\N	SENCOMCDD	2016-05-11 15:20:44	2017-12-18 11:41:07	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2827	95	2016-05-10 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14237S	\N	SENCOMCDD	2016-05-11 15:22:00	2017-12-18 11:40:29	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2828	169	2016-05-12 00:00:00	2017-03-20 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14275Y	\N	SENCOMLOIS	2016-05-12 16:38:00	2017-03-21 10:13:24	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2829	346	2016-05-18 00:00:00	2016-10-20 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01058X	\N	SENCOMCAE	2016-05-19 12:01:49	2016-11-24 16:04:10	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2831	348	2016-07-08 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14071N	\N	PDTSEN	2016-07-08 15:04:17	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2832	258	2011-12-15 00:00:00	2014-01-21 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08045X	\N	SENCOMECON	2016-07-11 11:57:48	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2833	258	2014-02-20 00:00:00	2015-05-17 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01043Q	\N	SENCOMECON	2016-07-11 12:01:10	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2834	258	2013-05-22 00:00:00	2014-01-20 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11051H	\N	SENCOMECON	2016-07-11 12:09:26	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2835	349	2016-07-19 00:00:00	2019-07-19 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04089T	\N	SENCOMCAE	2016-07-19 12:41:07	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2836	258	2016-07-19 00:00:00	2017-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01043Q	\N	SENCOMCAE	2016-07-19 12:45:31	2016-07-19 12:46:48	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3135	270	2017-12-20 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14039A	\N	SENCOMAFCL	2017-12-27 09:32:49	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3136	270	2017-12-20 00:00:00	2020-12-07 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11109J	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3138	72	2017-12-20 00:00:00	2020-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04018C	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3139	115	2017-12-20 00:00:00	2020-12-20 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08017T	\N	SENCOMAFCL	2017-12-27 09:36:49	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3140	99	2017-12-20 00:00:00	2022-12-20 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19399H	\N	SENCOMAFCL	2017-12-27 09:38:37	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3141	104	2017-12-20 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14249W	\N	SENCOMAFCL	2017-12-27 09:40:00	2017-12-27 09:41:20	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3142	104	2017-12-20 00:00:00	2021-02-04 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04057K	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3144	186	2017-12-20 00:00:00	2021-01-31 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	07033P	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3145	362	2017-12-20 00:00:00	2020-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04070G	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3146	300	2017-12-20 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04059M	\N	COMAFCL	2017-12-27 09:45:02	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3147	249	2017-12-20 00:00:00	2018-09-12 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08031R	\N	COMAFCL	2017-12-27 09:45:49	2018-09-21 18:01:34	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3148	313	2017-12-20 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19735D	\N	COMAFCL	2017-12-27 09:46:57	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3149	313	2017-12-20 00:00:00	2022-12-20 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19621T	\N	COMAFCL	2017-12-27 09:48:16	2018-12-19 11:55:39	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3150	341	2017-12-20 00:00:00	2018-04-15 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19643A	\N	COMAFCL	2017-12-27 09:49:49	2018-09-21 17:02:48	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3151	319	2017-12-20 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08043V	\N	COMAFCL	2017-12-27 09:51:18	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3152	319	2017-12-20 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04057K	\N	COMAFCL	2017-12-27 09:51:44	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3153	319	2017-12-20 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19593H	\N	COMAFCL	2017-12-27 09:52:10	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3154	319	2017-12-20 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19573D	\N	COMAFCL	2017-12-27 09:52:39	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3155	317	2017-12-20 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11083R	\N	COMAFCL	2017-12-27 09:59:29	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3156	250	2017-12-20 00:00:00	2022-12-20 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19643A	\N	COMAFCL	2017-12-27 10:01:24	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3157	316	2017-12-20 00:00:00	2019-09-24 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19611R	\N	COMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3158	292	2017-12-20 00:00:00	2020-12-20 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19709B	\N	COMETRD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3159	273	2017-12-20 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08049C	\N	COMETRD	2017-12-27 10:07:03	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3160	328	2017-12-20 00:00:00	2022-12-20 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	19443T	\N	COMETRD	2017-12-27 10:08:08	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3187	363	2018-01-30 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14135M	\N	PDTSEN	2018-01-26 10:52:42	2018-01-31 10:20:30	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3188	363	2018-01-30 00:00:00	2020-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	14207L	\N	PDTSEN	2018-01-26 10:55:54	2018-01-31 10:20:37	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3189	259	2018-01-30 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14159V	\N	PDTSEN	2018-01-26 10:58:25	2018-01-31 10:21:09	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3190	259	2018-01-30 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19735D	\N	PDTSEN	2018-01-26 10:59:00	2018-01-31 10:21:19	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3191	264	2018-01-30 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	88008L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3192	264	2018-01-30 00:00:00	2021-01-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19573D	\N	PDTSEN	2018-01-26 11:01:04	2018-01-31 10:23:40	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3193	288	2018-01-30 00:00:00	2021-07-27 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04086Q	\N	PDTSEN	2018-01-26 11:08:13	2018-02-05 11:22:13	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3194	288	2018-01-30 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11085T	\N	PDTSEN	2018-01-26 11:08:29	2018-02-05 11:22:20	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3195	22	2018-01-30 00:00:00	2018-03-27 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14215L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3196	175	2018-01-30 00:00:00	2020-07-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11049P	\N	PDTSEN	2018-01-26 11:10:39	2018-01-31 10:26:30	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3197	67	2018-01-30 00:00:00	2022-07-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11067R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3198	67	2018-01-30 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11103C	\N	PDTSEN	2018-01-26 11:11:54	2018-01-31 10:27:11	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3199	67	2018-01-30 00:00:00	2022-07-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01034P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3200	67	2018-01-30 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	10006L	\N	PDTSEN	2018-01-26 11:13:05	2018-01-31 10:27:19	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3201	339	2018-01-30 00:00:00	2022-01-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19691J	\N	PDTSEN	2018-01-26 11:14:18	2018-01-31 10:28:21	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3202	339	2018-01-30 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14093U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3205	299	2018-01-30 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11031D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3206	361	2018-01-30 00:00:00	2019-02-06 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19415P	\N	PDTSEN	2018-01-26 11:28:38	2019-02-27 10:27:08	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3207	221	2018-01-30 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04089T	\N	PDTSEN	2018-01-26 11:29:31	2018-01-31 10:32:49	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3208	343	2018-01-30 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	99004R	\N	PDTSEN	2018-01-26 11:30:42	2018-01-31 10:33:15	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3209	325	2018-01-30 00:00:00	2018-09-05 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14217N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3210	340	2018-01-30 00:00:00	2020-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	19565D	\N	PDTSEN	2018-01-26 11:34:24	2019-02-26 11:40:50	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3211	336	2018-01-30 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04045F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3212	303	2018-01-30 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14151M	\N	PDTSEN	2018-01-26 11:36:05	2018-01-31 10:34:56	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3213	303	2018-01-30 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08031R	\N	PDTSEN	2018-01-26 11:36:23	2018-01-31 10:35:01	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3214	303	2018-01-30 00:00:00	2020-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	19697Q	\N	PDTSEN	2018-01-26 11:36:46	2018-01-31 10:35:08	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2980	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Côte-d'Or	08069G	\N	PDTSEN	2017-12-18 16:21:04	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3215	303	2018-01-30 00:00:00	2020-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04057K	\N	PDTSEN	2018-01-26 11:37:43	2018-01-31 10:35:15	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3279	383	2018-08-03 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Rhône	14081Q	\N	PDTSEN	2018-08-27 17:36:00	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3280	383	2018-08-03 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Rhône	04049K	\N	PDTSEN	2018-08-27 17:36:53	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3281	383	2018-08-03 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Seine-Maritime	19758L	\N	PDTSEN	2018-08-27 17:37:25	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3282	383	2018-08-03 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Rhône	04049K	\N	PDTSEN	2018-08-27 17:38:40	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3283	383	2018-08-03 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Seine-Maritime	14053L	\N	PDTSEN	2018-08-27 17:39:18	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3284	383	2018-08-03 00:00:00	2019-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Seine-Maritime	95062K	\N	PDTSEN	2018-08-27 17:39:59	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3285	383	2018-08-03 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Seine-Maritime	14051J	\N	PDTSEN	2018-08-27 17:40:49	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3286	383	2018-08-03 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Var	04038G	\N	PDTSEN	2018-08-27 17:41:24	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3287	383	2018-08-03 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Var	15447F	\N	PDTSEN	2018-08-27 17:43:37	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3288	383	2018-08-03 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Var	14029X	\N	PDTSEN	2018-08-27 17:44:13	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3289	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	La Réunion	19659J	\N	PDTSEN	2018-08-27 17:44:53	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3290	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	La Réunion	19577H	\N	PDTSEN	2018-08-27 17:45:35	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3291	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	La Réunion	19583F	\N	PDTSEN	2018-08-27 17:46:15	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3292	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Paris	04071H	\N	PDTSEN	2018-08-27 17:46:55	2018-08-27 17:47:33	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3293	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Paris	19647E	\N	PDTSEN	2018-08-27 17:47:35	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3294	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Paris	19683J	\N	PDTSEN	2018-08-27 17:48:08	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3295	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Paris	12041X	\N	PDTSEN	2018-08-27 17:48:40	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3296	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Seine-et-Marne	19543W	\N	PDTSEN	2018-08-27 17:49:47	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3297	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Seine-et-Marne	14329V	\N	PDTSEN	2018-08-27 17:50:54	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3298	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Seine-et-Marne	14357A	\N	PDTSEN	2018-08-27 17:51:42	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3299	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Seine-et-Marne	04057K	\N	PDTSEN	2018-08-27 17:52:24	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3300	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Yvelines	19697Q	\N	PDTSEN	2018-08-27 17:53:19	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2960	357	2017-12-18 00:00:00	2020-06-27 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Ardèche	14199E	\N	PDTSEN	2017-12-18 16:07:59	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2961	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Ardennes	04097T	\N	PDTSEN	2017-12-18 16:08:41	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2962	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Ardennes	07029T	\N	PDTSEN	2017-12-18 16:09:23	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2963	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Aube	89017R	\N	PDTSEN	2017-12-18 16:10:04	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2964	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Aude	80013X	\N	PDTSEN	2017-12-18 16:10:33	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2965	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Aude	14097Y	\N	PDTSEN	2017-12-18 16:11:15	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2966	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Aveyron	14103D	\N	PDTSEN	2017-12-18 16:11:51	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2967	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Aveyron	14111D	\N	PDTSEN	2017-12-18 16:12:33	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2968	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Bas-Rhin	14065Q	\N	PDTSEN	2017-12-18 16:13:18	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2969	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Bas-Rhin	14061L	\N	PDTSEN	2017-12-18 16:13:58	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2970	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Bouches-du-Rhône	08048B	\N	PDTSEN	2017-12-18 16:14:31	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2971	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Bouches-du-Rhône	98022P	\N	PDTSEN	2017-12-18 16:15:08	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2972	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Calvados	14133K	\N	PDTSEN	2017-12-18 16:15:47	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2973	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Calvados	19735D	\N	PDTSEN	2017-12-18 16:16:14	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2974	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Charente	08060W	\N	PDTSEN	2017-12-18 16:17:05	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2975	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Charente	08058D	\N	PDTSEN	2017-12-18 16:17:34	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2976	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Charente-Maritime	14159V	\N	PDTSEN	2017-12-18 16:18:03	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2977	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Charente-Maritime	08015R	\N	PDTSEN	2017-12-18 16:18:48	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2978	357	2017-12-18 00:00:00	2019-03-03 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Cher	07034Q	\N	PDTSEN	2017-12-18 16:19:38	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2979	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Cher	05012A	\N	PDTSEN	2017-12-18 16:20:23	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2981	357	2017-12-18 00:00:00	2018-01-26 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Côte-d'Or	08061X	\N	PDTSEN	2017-12-18 16:21:44	2018-01-26 17:31:25	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2982	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Côtes-d'Armor	08014Q	\N	PDTSEN	2017-12-18 16:22:25	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2983	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Côtes-d'Armor	14157T	\N	PDTSEN	2017-12-18 16:23:08	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2984	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Deux-Sèvres	14119M	\N	PDTSEN	2017-12-18 16:23:56	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2985	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Deux-Sèvres	14071N	\N	PDTSEN	2017-12-18 16:24:43	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2986	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Dordogne	08055A	\N	PDTSEN	2017-12-18 16:25:29	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2987	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Dordogne	98029W	\N	PDTSEN	2017-12-18 16:26:15	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2988	357	2017-12-18 00:00:00	2020-06-15 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Doubs	08068F	\N	PDTSEN	2017-12-18 16:28:01	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2989	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Doubs	14123H	\N	PDTSEN	2017-12-18 16:28:34	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2990	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Drôme	14105F	\N	PDTSEN	2017-12-18 16:29:14	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2991	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Drôme	14109K	\N	PDTSEN	2017-12-18 16:30:09	2017-12-18 16:31:57	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2992	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Essonne	11070L	\N	PDTSEN	2017-12-18 16:30:49	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2993	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Essonne	19399H	\N	PDTSEN	2017-12-18 16:32:17	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2994	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Eure	14249W	\N	PDTSEN	2017-12-18 16:32:58	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2995	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Eure	08009T	\N	PDTSEN	2017-12-18 16:33:37	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2996	357	2017-12-18 00:00:00	2018-12-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Eure-et-Loir	98023Q	\N	PDTSEN	2017-12-18 16:34:07	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2997	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Eure-et-Loir	08011M	\N	PDTSEN	2017-12-18 16:34:47	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2998	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Finistère	08043V	\N	PDTSEN	2017-12-18 16:35:58	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2999	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Finistère	08047A	\N	PDTSEN	2017-12-18 16:36:32	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3000	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Gard	14059S	\N	PDTSEN	2017-12-18 16:37:16	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3001	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Gard	98035U	\N	PDTSEN	2017-12-18 16:37:55	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3002	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Gironde	19723Y	\N	PDTSEN	2017-12-18 16:38:39	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3003	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Gironde	08024S	\N	PDTSEN	2017-12-18 16:39:19	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3004	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Guadeloupe	12016W	\N	PDTSEN	2017-12-18 16:39:47	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3005	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Guadeloupe	19301E	\N	PDTSEN	2017-12-18 16:40:40	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3006	357	2017-12-18 00:00:00	2017-12-20 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Haut-Rhin	04040A	\N	PDTSEN	2017-12-18 16:41:14	2018-01-26 17:31:40	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3007	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Haut-Rhin	04044E	\N	PDTSEN	2017-12-18 16:41:47	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3008	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Haute-Garonne	08028W	\N	PDTSEN	2017-12-18 16:42:24	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3009	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Haute-Garonne	14225N	\N	PDTSEN	2017-12-18 16:43:11	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3010	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Haute-Vienne	14034U	\N	PDTSEN	2017-12-18 16:43:46	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3011	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Haute-Vienne	14028W	\N	PDTSEN	2017-12-18 16:44:32	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3012	357	2017-12-18 00:00:00	2018-08-06 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Haute-Savoie	95015C	\N	PDTSEN	2017-12-18 16:45:13	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3013	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Haute-Savoie	14179A	\N	PDTSEN	2017-12-18 16:46:00	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3014	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Hauts-de-Seine	11085T	\N	PDTSEN	2017-12-18 16:46:38	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3015	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Hauts-de-Seine	17637T	\N	PDTSEN	2017-12-18 16:47:26	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3016	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Hérault	14207L	\N	PDTSEN	2017-12-18 16:48:08	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3017	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Hérault	14211G	\N	PDTSEN	2017-12-18 16:48:42	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3018	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Ille-et-Vilaine	14231L	\N	PDTSEN	2017-12-18 16:49:33	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3019	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Ille-et-Vilaine	14229S	\N	PDTSEN	2017-12-18 16:50:15	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3020	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Indre-et-Loire	19515S	\N	PDTSEN	2017-12-18 16:50:54	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3021	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Indre-et-Loire	19441R	\N	PDTSEN	2017-12-18 16:51:28	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3022	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Isère	19347U	\N	PDTSEN	2017-12-18 16:52:14	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3023	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Isère	11043H	\N	PDTSEN	2017-12-18 16:53:05	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3024	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Jura	19467C	\N	PDTSEN	2017-12-18 16:53:54	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3025	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Jura	19479G	\N	PDTSEN	2017-12-18 16:55:05	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3026	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Landes	19489J	\N	PDTSEN	2017-12-18 16:56:00	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3027	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Landes	17779H	\N	PDTSEN	2017-12-18 16:57:01	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3028	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Loir-et-Cher	19511N	\N	PDTSEN	2017-12-18 16:57:54	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3029	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Loir-et-Cher	19739H	\N	PDTSEN	2017-12-18 17:00:07	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3030	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Loire	19415P	\N	PDTSEN	2017-12-18 17:23:44	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3031	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Loire	11056N	\N	PDTSEN	2017-12-18 17:24:50	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3032	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Loire-Atlantique	11064N	\N	PDTSEN	2017-12-18 17:25:34	2017-12-18 17:26:20	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3033	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Loire-Atlantique	11066Q	\N	PDTSEN	2017-12-18 17:26:20	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3034	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Loiret	19421M	\N	PDTSEN	2017-12-18 17:27:05	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3035	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Loiret	01028R	\N	PDTSEN	2017-12-18 17:27:44	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3036	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Lot-et-Garonne	19367Y	\N	PDTSEN	2017-12-18 17:28:57	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3037	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Lot-et-Garonne	19369B	\N	PDTSEN	2017-12-18 17:29:36	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3038	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Maine-et-Loire	19545Y	\N	PDTSEN	2017-12-18 17:30:18	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3039	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Maine-et-Loire	19533U	\N	PDTSEN	2017-12-18 17:31:02	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3040	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Manche	05008E	\N	PDTSEN	2017-12-18 17:31:43	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3041	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Manche	19333N	\N	PDTSEN	2017-12-18 17:32:13	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3042	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Marne	01024M	\N	PDTSEN	2017-12-18 17:32:49	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3043	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Marne	11097X	\N	PDTSEN	2017-12-18 17:33:20	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3044	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Martinique	11109J	\N	PDTSEN	2017-12-18 17:33:59	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3045	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Martinique	19295A	\N	PDTSEN	2017-12-18 17:34:26	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3046	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Mayenne	18083K	\N	PDTSEN	2017-12-18 17:35:35	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3047	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Mayenne	14042U	\N	PDTSEN	2017-12-18 17:36:17	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3048	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Meurthe-et-Moselle	11048N	\N	PDTSEN	2017-12-18 17:36:54	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3049	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Meurthe-et-Moselle	19551W	\N	PDTSEN	2017-12-18 17:37:53	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3050	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Morbihan	19447X	\N	PDTSEN	2017-12-18 17:38:39	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3051	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Morbihan	11099A	\N	PDTSEN	2017-12-18 17:39:13	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3052	357	2017-12-18 00:00:00	2020-07-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Moselle	11049P	\N	PDTSEN	2017-12-18 17:39:49	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3053	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Moselle	19685L	\N	PDTSEN	2017-12-18 17:40:23	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3054	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Nord	19599P	\N	PDTSEN	2017-12-18 17:59:39	2017-12-18 18:01:17	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3055	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Nord	01043Q	\N	PDTSEN	2017-12-18 18:01:17	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3056	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Oise	11115U	\N	PDTSEN	2017-12-18 18:01:53	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3057	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Oise	19573D	\N	PDTSEN	2017-12-18 18:02:26	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3058	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Orne	07004J	\N	PDTSEN	2017-12-18 18:03:02	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3059	357	2017-12-18 00:00:00	2018-04-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Orne	19483C	\N	PDTSEN	2017-12-18 18:03:44	2018-04-13 17:54:30	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3060	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Pas-de-Calais	19525U	\N	PDTSEN	2017-12-18 18:05:01	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3061	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Pas-de-Calais	14331P	\N	PDTSEN	2017-12-18 18:05:54	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3062	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Puy-de-Dôme	19383Y	\N	PDTSEN	2017-12-18 18:08:22	2017-12-18 18:09:12	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3063	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Puy-de-Dôme	11104D	\N	PDTSEN	2017-12-18 18:09:12	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3064	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Pyrénées-Atlantiques	11110B	\N	PDTSEN	2017-12-18 18:10:22	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3065	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Pyrénées-Atlantiques	19619A	\N	PDTSEN	2017-12-18 18:11:19	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3066	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Pyrénées-Orientales	11101A	\N	PDTSEN	2017-12-18 18:12:11	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3067	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Pyrénées-Orientales	19703U	\N	PDTSEN	2017-12-18 18:12:53	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3068	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	La Réunion	19577H	\N	PDTSEN	2017-12-18 18:14:01	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3069	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	La Réunion	19657G	\N	PDTSEN	2017-12-18 18:14:44	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3070	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Rhône	04047H	\N	PDTSEN	2017-12-18 18:15:32	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3071	357	2017-12-18 00:00:00	2018-11-03 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Rhône	19251M	\N	PDTSEN	2017-12-18 18:16:12	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3072	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Saône-et-Loire	14151M	\N	PDTSEN	2017-12-18 18:16:46	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3073	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Saône-et-Loire	14147R	\N	PDTSEN	2017-12-18 18:17:41	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3074	357	2017-12-18 00:00:00	2020-06-24 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Sarthe	19727D	\N	PDTSEN	2017-12-18 18:18:17	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3075	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Sarthe	14169X	\N	PDTSEN	2017-12-18 18:18:58	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3076	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Savoie	19575F	\N	PDTSEN	2017-12-18 18:19:40	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3077	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Savoie	95067Q	\N	PDTSEN	2017-12-18 18:20:07	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3078	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Seine-Maritime	14001X	\N	PDTSEN	2017-12-18 18:20:44	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3079	357	2017-12-18 00:00:00	2019-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Seine-Maritime	95062K	\N	PDTSEN	2017-12-18 18:21:53	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3080	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Seine-et-Marne	19543W	\N	PDTSEN	2017-12-18 18:22:39	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3081	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Seine-et-Marne	14329V	\N	PDTSEN	2017-12-18 18:23:13	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3082	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Seine-Saint-Denis	04085P	\N	PDTSEN	2017-12-18 18:24:04	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3083	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Seine-Saint-Denis	04086Q	\N	PDTSEN	2017-12-18 18:24:57	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3084	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Somme	14093U	\N	PDTSEN	2017-12-18 18:25:47	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3085	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Somme	04089T	\N	PDTSEN	2017-12-18 18:26:13	2017-12-20 11:28:07	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3086	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Tarn	14089Y	\N	PDTSEN	2017-12-18 18:26:49	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3087	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Tarn	14085U	\N	PDTSEN	2017-12-18 18:27:21	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3088	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Val-de-Marne	04042C	\N	PDTSEN	2017-12-18 18:28:02	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3089	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Val-de-Marne	19687N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3090	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Val-d'Oise	19667J	\N	PDTSEN	2017-12-18 18:29:57	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3091	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Val-d'Oise	95063L	\N	PDTSEN	2017-12-18 18:30:52	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3092	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Var	04038G	\N	PDTSEN	2017-12-18 18:37:00	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3093	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Var	15447F	\N	PDTSEN	2017-12-18 18:37:53	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3094	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Vaucluse	95037J	\N	PDTSEN	2017-12-18 18:38:35	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3095	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Vaucluse	04092N	\N	PDTSEN	2017-12-18 18:39:10	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3096	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Vendée	14030Q	\N	PDTSEN	2017-12-18 18:39:56	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3097	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Vendée	04033B	\N	PDTSEN	2017-12-18 18:40:35	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3098	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Vienne	02002K	\N	PDTSEN	2017-12-18 18:41:22	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3099	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Vosges	14033T	\N	PDTSEN	2017-12-18 18:41:57	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3100	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Vosges	04088S	\N	PDTSEN	2017-12-18 18:43:20	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3101	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Yonne	19269X	\N	PDTSEN	2017-12-18 18:44:00	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3102	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Yvelines	19699S	\N	PDTSEN	2017-12-18 18:45:11	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3103	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Yvelines	11090Q	\N	PDTSEN	2017-12-18 18:45:42	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3130	137	2017-12-20 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14026U	\N	PDTSEN	2017-12-20 18:07:48	2017-12-20 18:08:59	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3131	137	2017-12-20 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14227Q	\N	PDTSEN	2017-12-20 18:08:10	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3183	306	2018-01-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14083S	\N	PDTSEN	2018-01-18 15:39:11	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3184	306	2018-01-18 00:00:00	2022-01-10 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19689Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3185	380	2018-01-18 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11070L	\N	PDTSEN	2018-01-18 15:41:36	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3186	380	2018-01-18 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11110B	\N	PDTSEN	2018-01-18 15:41:56	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3222	342	2018-03-29 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14215L	\N	SENCOMLOIS	2018-03-29 11:13:59	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3301	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Yvelines	11090Q	\N	PDTSEN	2018-08-27 17:55:46	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3223	29	2018-04-18 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	19621T	\N	SENCOMAFCL	2018-04-19 19:19:06	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3224	29	2018-04-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14059S	\N	SENCOMAFCL	2018-04-19 19:20:34	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3225	72	2018-04-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14109K	\N	SENCOMAFCL	2018-04-19 19:21:49	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3302	383	2018-08-03 00:00:00	2020-09-29 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Yvelines	04018C	\N	PDTSEN	2018-08-27 17:56:22	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3303	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Essonne	11070L	\N	PDTSEN	2018-08-27 17:56:59	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3304	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Essonne	19691J	\N	PDTSEN	2018-08-27 17:57:50	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3305	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Essonne	19399H	\N	PDTSEN	2018-08-27 17:58:41	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3306	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Hauts-de-Seine	19591F	\N	PDTSEN	2018-08-27 17:59:17	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3307	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Hauts-de-Seine	19711U	\N	PDTSEN	2018-08-27 18:00:00	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3308	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Hauts-de-Seine	19593H	\N	PDTSEN	2018-08-27 18:00:44	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3309	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Hauts-de-Seine	17637T	\N	PDTSEN	2018-08-27 18:01:42	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3310	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Seine-Saint-Denis	04086Q	\N	PDTSEN	2018-08-27 18:02:33	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3311	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Seine-Saint-Denis	19695N	\N	PDTSEN	2018-08-27 18:03:26	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3312	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Seine-Saint-Denis	11054L	\N	PDTSEN	2018-08-27 18:04:11	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3313	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Val-de-Marne	19611R	\N	PDTSEN	2018-08-27 18:05:11	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3314	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Val-de-Marne	04043D	\N	PDTSEN	2018-08-27 18:05:52	2018-08-27 18:18:06	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3315	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Val-de-Marne	19687N	\N	PDTSEN	2018-08-27 18:06:29	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3316	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Val-de-Marne	19689Q	\N	PDTSEN	2018-08-27 18:07:03	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3317	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Val-d'Oise	19667J	\N	PDTSEN	2018-08-27 18:07:53	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3318	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Val-d'Oise	19673G	\N	PDTSEN	2018-08-27 18:08:36	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3319	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Val-d'Oise	95063L	\N	PDTSEN	2018-08-27 18:09:12	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3328	383	2018-10-12 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	La Réunion	19657G	\N	PDTSEN	2018-10-12 10:51:38	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1983	281	2011-06-17 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95062K	\N	PDTSEN	\N	2014-09-23 15:38:22	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
1998	98	2011-12-20 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95009E	\N	PDTSEN	\N	2014-09-28 12:56:42	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2262	95	2012-07-24 00:00:00	2015-07-24 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95067Q	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2024	185	2011-12-15 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	dev dur depuis	95025E	\N	SENCOMECON	\N	2014-07-11 10:51:34	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2075	193	2011-12-15 00:00:00	2014-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	01027Q	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2082	31	2011-12-15 00:00:00	2014-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	03001N	\N	SENCOMFINC	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2091	241	2011-12-15 00:00:00	2013-12-15 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04084N	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2099	34	2011-12-15 00:00:00	2014-12-15 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95063L	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2106	138	2011-12-15 00:00:00	2014-12-15 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11098Y	\N	SENCOMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2561	207	2014-12-17 00:00:00	2015-03-17 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	14087W	\N	SENCOMSOCI	2014-12-19 11:06:24	2017-04-12 11:03:43	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
2588	37	2014-12-17 00:00:00	2019-12-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11081P	\N	SENCOMCAE	2014-12-19 14:14:22	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3331	2000	2018-11-22 00:00:00	2020-02-10 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01058X	\N	OPECST	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3332	314	2018-11-29 00:00:00	2021-11-29 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19549D	\N	PDTSEN	2018-11-29 11:19:37	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3333	314	2018-11-29 00:00:00	2021-11-29 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11048N	\N	PDTSEN	2018-11-29 11:19:54	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3334	314	2018-11-29 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19737F	\N	PDTSEN	2018-11-29 11:20:17	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3338	201	2019-02-13 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11064N	\N	PDTSEN	2019-02-25 10:19:16	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3339	290	2019-02-13 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11104D	\N	PDTSEN	2019-02-25 10:49:17	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3340	200	2019-02-13 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04071H	\N	PDTSEN	2019-02-25 10:55:24	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3341	255	2019-02-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19737F	\N	PDTSEN	2019-02-25 11:28:12	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3342	245	2019-02-13 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	18083K	\N	PDTSEN	2019-02-25 11:34:12	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3343	245	2019-02-13 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19713W	\N	PDTSEN	2019-02-25 11:34:30	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3344	169	2019-02-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14059S	\N	PDTSEN	2019-02-25 11:39:45	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3345	169	2019-02-13 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	12016W	\N	PDTSEN	2019-02-25 11:40:00	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3346	169	2019-02-13 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19319Q	\N	PDTSEN	2019-02-25 11:41:02	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3347	169	2019-02-13 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19301E	\N	PDTSEN	2019-02-25 11:41:50	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3348	326	2019-02-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14215L	\N	PDTSEN	2019-02-25 11:46:41	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3349	22	2019-02-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14053L	\N	PDTSEN	2019-02-25 11:49:16	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3350	345	2019-02-13 00:00:00	2022-02-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19515S	\N	PDTSEN	2019-02-25 11:57:07	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3351	337	2019-02-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14237S	\N	PDTSEN	2019-02-25 11:59:57	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3352	312	2019-02-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08055A	\N	PDTSEN	2019-02-25 12:06:16	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3353	160	2019-02-13 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04035D	\N	PDTSEN	2019-02-25 12:10:21	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3354	160	2019-02-13 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	12041X	\N	PDTSEN	2019-02-25 12:11:17	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3355	109	2019-02-13 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95063L	\N	PDTSEN	2019-02-25 12:29:56	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3356	356	2019-02-13 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95063L	\N	PDTSEN	2019-02-25 12:34:17	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3357	323	2019-02-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14031R	\N	PDTSEN	2019-02-25 12:40:49	2019-02-25 12:41:49	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3358	379	2019-02-13 00:00:00	2019-02-19 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04043D	\N	PDTSEN	2019-02-25 16:36:51	2019-02-27 10:27:45	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3104	369	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19725B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3105	370	2017-12-18 00:00:00	2020-11-12 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19525U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3106	371	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	05012A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3107	373	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14087W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3108	372	2017-12-18 00:00:00	2020-11-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11048N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3109	374	2017-12-18 00:00:00	2020-11-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	96004D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3110	364	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14187A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3111	364	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14237S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3112	364	2017-12-18 00:00:00	2020-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	14179A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3113	364	2017-12-18 00:00:00	2020-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	14107H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3114	365	2017-12-18 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19507S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3115	365	2017-12-18 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19503N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3116	365	2017-12-18 00:00:00	2020-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	19383Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3117	365	2017-12-18 00:00:00	2023-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	14327T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3118	366	2017-12-18 00:00:00	2020-11-12 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19467C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3119	366	2017-12-18 00:00:00	2020-11-12 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19479G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3120	366	2017-12-18 00:00:00	2020-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	14038Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3121	366	2017-12-18 00:00:00	2020-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	08053X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3122	367	2017-12-18 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11101A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3123	367	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14197C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3124	367	2017-12-18 00:00:00	2020-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	08031R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3125	367	2017-12-18 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	19619A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3126	368	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14033T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3127	368	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14135M	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3128	368	2017-12-18 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	19551W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3129	368	2017-12-18 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	19335Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3320	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Loire-Atlantique	11067R	\N	PDTSEN	2018-08-27 18:18:06	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3335	313	2018-12-19 00:00:00	2021-03-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08017T	\N	COMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3359	157	2019-02-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04035D	\N	PDTSEN	2019-02-25 16:45:05	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3360	239	2019-02-13 00:00:00	2022-02-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11083R	\N	PDTSEN	2019-02-25 16:52:06	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3361	202	2019-02-13 00:00:00	2020-07-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11049P	\N	PDTSEN	2019-02-25 17:00:45	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3362	8	2019-02-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14026U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3363	222	2019-02-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14241N	\N	PDTSEN	2019-02-25 17:49:56	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3364	330	2019-02-13 00:00:00	2022-02-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19693L	\N	PDTSEN	2019-02-25 17:51:56	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3365	199	2019-02-13 00:00:00	2021-05-25 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14195A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3366	199	2019-02-13 00:00:00	2021-05-25 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19723Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3367	213	2019-02-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19719D	\N	PDTSEN	2019-02-25 17:57:18	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3368	213	2019-02-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14227Q	\N	PDTSEN	2019-02-25 17:59:06	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3369	172	2019-02-13 00:00:00	2020-06-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19733B	\N	PDTSEN	2019-02-25 18:05:53	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3370	172	2019-02-13 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19347U	\N	PDTSEN	2019-02-25 18:06:48	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3371	236	2019-02-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14085U	\N	PDTSEN	2019-02-25 18:09:05	2019-02-25 18:14:03	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3372	236	2019-02-13 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19711U	\N	PDTSEN	2019-02-25 18:12:17	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3373	180	2019-02-13 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19741B	\N	PDTSEN	2019-02-25 18:17:39	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3374	180	2019-02-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	88008L	\N	PDTSEN	2019-02-25 18:19:48	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3375	269	2019-02-13 00:00:00	2020-12-07 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11072N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3376	108	2019-02-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14229S	\N	PDTSEN	2019-02-25 18:29:32	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3377	378	2019-02-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14039A	\N	PDTSEN	2019-02-25 18:34:25	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3378	378	2019-02-13 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	19593H	\N	PDTSEN	2019-02-25 18:34:54	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3379	81	2019-02-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19735D	\N	PDTSEN	2019-02-25 18:39:18	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3380	81	2019-02-13 00:00:00	2020-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	14001X	\N	PDTSEN	2019-02-25 18:40:25	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3381	265	2019-02-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08028W	\N	PDTSEN	2019-02-25 18:43:48	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3382	176	2019-02-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14169X	\N	PDTSEN	2019-02-25 18:45:57	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3383	309	2019-02-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08043V	\N	PDTSEN	2019-02-26 10:07:29	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3384	333	2019-02-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19251M	\N	PDTSEN	2019-02-26 10:12:07	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3385	333	2019-02-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14187A	\N	PDTSEN	2019-02-26 10:12:56	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3386	12	2019-02-13 00:00:00	2022-02-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19701S	\N	PDTSEN	2019-02-26 10:19:08	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3387	318	2019-02-13 00:00:00	2022-02-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04057K	\N	PDTSEN	2019-02-26 10:31:28	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3388	318	2019-02-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95067Q	\N	PDTSEN	2019-02-26 10:31:57	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3389	304	2019-02-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14038Y	\N	PDTSEN	2019-02-26 10:50:23	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3390	304	2019-02-13 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19599P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3216	357	2018-02-01 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Côte-d'Or	14205J	\N	PDTSEN	2018-02-01 15:25:43	2018-02-01 15:26:55	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3217	357	2018-02-01 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Haut-Rhin	04045F	\N	PDTSEN	2018-02-01 15:26:55	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3218	22	2018-02-21 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	19333N	\N	PDTSEN	2018-02-21 15:56:03	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3219	156	2018-02-21 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19749K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3220	299	2018-02-21 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19717B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3221	361	2018-02-21 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19553Y	\N	PDTSEN	2018-02-21 16:11:46	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3226	164	2018-06-14 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	17779H	\N	SENCOMSOCI	2018-06-14 15:10:39	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3321	112	2018-09-21 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14038Y	\N	PDTSEN	2018-09-21 10:18:03	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3322	112	2018-09-21 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	88008L	\N	PDTSEN	2018-09-21 10:18:25	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3323	112	2018-09-21 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14327T	\N	PDTSEN	2018-09-21 10:18:51	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3324	112	2018-09-21 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19599P	\N	PDTSEN	2018-09-21 10:19:31	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3325	112	2018-09-21 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14063N	\N	PDTSEN	2018-09-21 10:19:58	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3326	112	2018-09-21 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14265W	\N	PDTSEN	2018-09-21 10:20:27	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3327	112	2018-09-21 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19619A	\N	PDTSEN	2018-09-21 10:20:50	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3329	341	2018-10-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19643A	\N	COMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3336	357	2017-12-18 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Haute-Marne	01058X	\N	MEMBREDRT	2019-01-21 17:50:51	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3337	13	2019-01-25 00:00:00	2021-01-29 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19741B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3391	335	2019-02-13 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19367Y	\N	PDTSEN	2019-02-26 11:01:19	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3392	360	2019-02-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19673G	\N	PDTSEN	2019-02-26 11:06:19	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3393	261	2019-02-13 00:00:00	2020-11-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	96004D	\N	PDTSEN	2019-02-26 11:12:14	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3394	340	2019-02-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08038Y	\N	PDTSEN	2019-02-26 11:37:58	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3395	24	2019-02-13 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19619A	\N	PDTSEN	2019-02-26 11:44:52	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3396	46	2019-02-13 00:00:00	2020-12-07 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19569H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3397	291	2019-02-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14157T	\N	PDTSEN	2019-02-26 12:08:28	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3398	50	2019-02-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14281W	\N	PDTSEN	2019-02-26 12:26:48	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3399	50	2019-02-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14103D	\N	PDTSEN	2019-02-26 12:27:37	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3400	295	2019-02-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14107H	\N	PDTSEN	2019-02-26 14:54:37	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3401	283	2019-02-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19758L	\N	PDTSEN	2019-02-26 15:04:11	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3402	377	2019-02-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19717B	\N	PDTSEN	2019-02-26 15:09:00	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3403	376	2019-02-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19683J	\N	PDTSEN	2019-02-26 15:10:13	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3404	375	2019-02-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11097X	\N	PDTSEN	2019-02-26 15:11:29	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3405	296	2019-02-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11103C	\N	PDTSEN	2019-02-26 15:16:14	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3406	296	2019-02-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01034P	\N	PDTSEN	2019-02-26 15:16:44	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3407	194	2019-02-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08052W	\N	PDTSEN	2019-02-26 15:25:39	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3408	194	2019-02-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	10006L	\N	PDTSEN	2019-02-26 15:25:56	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3409	194	2019-02-13 00:00:00	2020-02-10 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	95041E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3410	350	2019-02-13 00:00:00	2022-02-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19669L	\N	PDTSEN	2019-02-26 15:30:43	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3411	307	2019-02-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19447X	\N	PDTSEN	2019-02-26 15:37:38	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3412	307	2019-02-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19289C	\N	PDTSEN	2019-02-26 15:37:51	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3413	138	2019-02-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14123H	\N	PDTSEN	2019-02-26 15:42:22	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3414	138	2019-02-13 00:00:00	2020-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	14109K	\N	PDTSEN	2019-02-26 15:43:59	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3415	336	2019-02-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14219Q	\N	PDTSEN	2019-02-26 15:45:10	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3416	386	2019-02-13 00:00:00	2022-02-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11048N	\N	PDTSEN	2019-02-26 15:55:17	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3417	381	2019-02-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14179A	\N	PDTSEN	2019-02-26 16:02:56	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3418	387	2019-02-13 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01043Q	\N	PDTSEN	2019-02-26 16:14:06	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3419	384	2019-02-13 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11043H	\N	PDTSEN	2019-02-26 16:18:44	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3420	385	2019-02-13 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19699S	\N	PDTSEN	2019-02-26 16:20:55	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3422	379	2019-03-13 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19533U	\N	PDTSEN	2019-03-13 18:25:49	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3423	361	2019-03-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19575F	\N	PDTSEN	2019-03-13 18:27:09	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3424	212	2019-03-13 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19415P	\N	PDTSEN	2019-03-13 18:28:16	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3425	204	2019-03-29 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14123H	\N	PDTSEN	2019-03-29 18:45:45	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3426	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Ain	14038Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3427	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Ain	08056B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3428	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Aisne	08052W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3429	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Aisne	14026U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3430	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Allier	98024R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3132	357	2017-12-21 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Aube	19745F	\N	PDTSEN	2017-12-22 14:14:43	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3133	357	2017-12-21 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Vienne	19747H	\N	PDTSEN	2017-12-22 14:15:18	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3134	357	2017-12-21 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Yonne	19749K	\N	PDTSEN	2017-12-22 14:15:56	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3161	272	2018-01-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01058X	\N	SENCOMETRD	2018-01-17 12:46:04	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3162	126	2018-01-16 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14105F	\N	SENCOMETRD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3163	126	2018-01-16 00:00:00	2020-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04040A	\N	SENCOMETRD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3164	115	2018-01-16 00:00:00	2021-01-16 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04034C	\N	SENCOMETRD	2018-01-17 12:57:33	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3165	382	2018-01-17 00:00:00	2022-06-29 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11010L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3166	382	2018-01-17 00:00:00	2022-06-29 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19333N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3167	382	2018-01-17 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14275Y	\N	PDTSEN	2018-01-17 15:31:56	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3168	34	2018-01-17 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14069U	\N	SENCOMLOIS	2018-01-17 15:37:40	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3169	34	2018-01-17 00:00:00	2020-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	14001X	\N	SENCOMLOIS	2018-01-17 15:38:42	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3170	286	2018-01-17 00:00:00	2018-09-12 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19719D	\N	SENCOMLOIS	2018-01-17 15:58:20	2018-09-21 17:40:42	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3171	286	2018-01-17 00:00:00	2018-09-12 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14065Q	\N	SENCOMLOIS	2018-01-17 16:06:08	2018-09-21 17:40:56	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3172	270	2018-01-17 00:00:00	2020-12-07 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11072N	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3173	270	2018-01-17 00:00:00	2020-12-07 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	14021P	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3174	270	2018-01-17 00:00:00	2020-12-07 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11010L	\N	SENCOMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3175	196	2018-01-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04085P	\N	SENCOMLOIS	2018-01-17 16:56:37	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3176	29	2018-01-17 00:00:00	2020-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	08045X	\N	SENCOMLOIS	2018-01-17 17:20:16	2018-01-17 17:22:44	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3177	320	2018-01-17 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14231L	\N	SENCOMLOIS	2018-01-17 17:25:47	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3178	320	2018-01-17 00:00:00	2021-01-17 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	19543W	\N	SENCOMLOIS	2018-01-17 17:27:10	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3179	282	2018-01-17 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19725B	\N	SENCOMLOIS	2018-01-17 17:28:29	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3180	282	2018-01-17 00:00:00	2020-07-31 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	08044W	\N	SENCOMLOIS	2018-01-17 17:29:58	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3181	246	2018-01-17 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14179A	\N	SENCOMLOIS	2018-01-17 17:32:20	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3182	141	2018-01-17 00:00:00	2018-04-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19483C	\N	SENCOMLOIS	2018-01-17 17:33:32	2018-04-13 17:54:30	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3227	383	2018-08-03 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Alpes-Maritimes	08038Y	\N	PDTSEN	2018-08-27 16:44:45	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3228	383	2018-08-03 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Alpes-Maritimes	14187A	\N	PDTSEN	2018-08-27 16:45:20	2018-08-27 16:46:15	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3229	383	2018-08-03 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Alpes-Maritimes	08039A	\N	PDTSEN	2018-08-27 16:46:15	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3230	383	2018-08-03 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Alpes-Maritimes	19729F	\N	PDTSEN	2018-08-27 16:47:16	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3231	383	2018-08-03 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Bouches-du-Rhône	08048B	\N	PDTSEN	2018-08-27 16:47:52	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3232	383	2018-08-03 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Bouches-du-Rhône	98022P	\N	PDTSEN	2018-08-27 16:48:58	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3233	383	2018-08-03 00:00:00	2020-07-31 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Bouches-du-Rhône	08044W	\N	PDTSEN	2018-08-27 16:49:49	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3234	383	2018-08-03 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Finistère	08043V	\N	PDTSEN	2018-08-27 16:50:35	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3235	383	2018-08-03 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Finistère	14083S	\N	PDTSEN	2018-08-27 16:51:41	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3236	383	2018-08-03 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Finistère	08047A	\N	PDTSEN	2018-08-27 16:52:22	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3237	383	2018-08-03 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Haute-Garonne	08028W	\N	PDTSEN	2018-08-27 16:53:15	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3238	383	2018-08-03 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Haute-Garonne	08031R	\N	PDTSEN	2018-08-27 16:54:10	2018-08-27 16:55:24	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3239	383	2018-08-03 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Haute-Garonne	14225N	\N	PDTSEN	2018-08-27 16:55:24	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3240	383	2018-08-03 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Gironde	19725B	\N	PDTSEN	2018-08-27 16:56:03	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3241	383	2018-08-03 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Gironde	19723Y	\N	PDTSEN	2018-08-27 16:56:47	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3242	383	2018-08-03 00:00:00	2019-08-27 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Gironde	80027E	\N	PDTSEN	2018-08-27 16:57:39	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3243	383	2018-08-03 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Hérault	08020N	\N	PDTSEN	2018-08-27 16:58:27	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3244	383	2018-08-03 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Hérault	14207L	\N	PDTSEN	2018-08-27 16:59:17	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3245	383	2018-08-03 00:00:00	2019-06-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Hérault	08021P	\N	PDTSEN	2018-08-27 17:00:12	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3246	383	2018-08-03 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Ille-et-Vilaine	08034U	\N	PDTSEN	2018-08-27 17:00:55	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3247	383	2018-08-03 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Ille-et-Vilaine	14229S	\N	PDTSEN	2018-08-27 17:01:42	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3248	383	2018-08-03 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Ille-et-Vilaine	14227Q	\N	PDTSEN	2018-08-27 17:02:29	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3249	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Isère	19349W	\N	PDTSEN	2018-08-27 17:03:13	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3250	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Isère	19347U	\N	PDTSEN	2018-08-27 17:04:06	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3251	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Isère	19679N	\N	PDTSEN	2018-08-27 17:04:51	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3252	383	2018-08-03 00:00:00	0203-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Loire-Atlantique	11067R	\N	PDTSEN	2018-08-27 17:05:35	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3253	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Loire-Atlantique	11066Q	\N	PDTSEN	2018-08-27 17:07:21	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3254	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Loire-Atlantique	17583W	\N	PDTSEN	2018-08-27 17:08:19	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3255	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Maine-et-Loire	19549D	\N	PDTSEN	2018-08-27 17:09:11	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3256	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Maine-et-Loire	19545Y	\N	PDTSEN	2018-08-27 17:10:02	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3257	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Maine-et-Loire	10006L	\N	PDTSEN	2018-08-27 17:10:56	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3258	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Maine-et-Loire	19533U	\N	PDTSEN	2018-08-27 17:11:36	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3259	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Moselle	01060R	\N	PDTSEN	2018-08-27 17:12:40	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3260	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Moselle	01062T	\N	PDTSEN	2018-08-27 17:13:22	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3261	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Moselle	19335Q	\N	PDTSEN	2018-08-27 17:14:06	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3262	383	2018-08-03 00:00:00	2020-07-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Moselle	11049P	\N	PDTSEN	2018-08-27 17:14:47	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3263	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Nord	19599P	\N	PDTSEN	2018-08-27 17:15:38	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3264	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Nord	19565D	\N	PDTSEN	2018-08-27 17:16:34	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3265	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Nord	19569H	\N	PDTSEN	2018-08-27 17:17:11	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3266	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Oise	19741B	\N	PDTSEN	2018-08-27 17:17:49	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3267	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Oise	11115U	\N	PDTSEN	2018-08-27 17:18:33	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3268	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Oise	19573D	\N	PDTSEN	2018-08-27 17:19:15	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3269	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Oise	11045K	\N	PDTSEN	2018-08-27 17:22:00	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3270	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Pas-de-Calais	19760E	\N	PDTSEN	2018-08-27 17:22:43	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3271	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Pas-de-Calais	19521Q	\N	PDTSEN	2018-08-27 17:24:20	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3272	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Pas-de-Calais	14331P	\N	PDTSEN	2018-08-27 17:25:21	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3273	383	2018-08-03 00:00:00	2020-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Pas-de-Calais	19527W	\N	PDTSEN	2018-08-27 17:26:11	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3274	383	2018-08-03 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Bas-Rhin	14065Q	\N	PDTSEN	2018-08-27 17:26:50	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3275	383	2018-08-03 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Bas-Rhin	14061L	\N	PDTSEN	2018-08-27 17:28:20	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3276	383	2018-08-03 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Bas-Rhin	14073Q	\N	PDTSEN	2018-08-27 17:29:06	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3277	383	2018-08-03 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Bas-Rhin	10015M	\N	PDTSEN	2018-08-27 17:29:43	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3278	383	2018-08-03 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Rhône	14087W	\N	PDTSEN	2018-08-27 17:30:39	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3537	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Pyrénées-Orientales	11101A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3538	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Pyrénées-Orientales	19703U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3539	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Rhône	19251M	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3540	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Saône-et-Loire	95030B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3541	388	2019-03-25 00:00:00	2020-06-24 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Sarthe	19727D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3542	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Sarthe	14173T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3543	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Savoie	19575F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3544	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Savoie	95067Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3545	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Seine-et-Marne	19543W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3546	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Seine-et-Marne	19675J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3547	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Seine-Maritime	14053L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3548	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Seine-Maritime	14051J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3549	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Seine-Saint-Denis	04085P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3550	388	2019-03-25 00:00:00	2021-07-27 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Seine-Saint-Denis	04086Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3551	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Somme	14093U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3552	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Tarn	14089Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3553	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Tarn	14085U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3554	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Val-de-Marne	11031D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3555	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Val-de-Marne	04043D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3556	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Val-d'Oise	19667J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3557	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Val-d'Oise	95063L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3558	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Var	04038G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3559	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Var	15447F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3560	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Vaucluse	95037J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3561	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Vaucluse	04092N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3562	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Vendée	14030Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3563	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Vendée	04033B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3564	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Vienne	02002K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3565	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Vosges	04088S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3566	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Yonne	19269X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3567	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Yonne	19749K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3568	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Yvelines	19701S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3569	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Yvelines	19699S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3570	388	2019-03-28 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Calvados	14281W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3571	388	2019-03-28 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Pas-de-Calais	19525U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3572	388	2019-03-28 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Rhône	14215L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3573	388	2019-03-28 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Somme	14063N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3579	612	2019-05-14 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04044E	5	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3580	612	2019-05-14 00:00:00	2020-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	19447X	2	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3585	172	2019-06-07 00:00:00	2020-10-31 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	17583W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3588	292	2019-07-10 00:00:00	2021-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04034C	\N	COMETRD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3589	259	2019-07-11 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14253S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3592	612	2019-07-23 00:00:00	2020-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	19673G	5	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3632	2000	2020-02-06 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19563B	\N	OPECST	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3577	357	2019-05-02 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Rhône	19251M	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3587	190	2019-07-09 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14071N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3602	391	2019-10-30 00:00:00	2022-11-24 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Démission de l'OEP de M. Lafon	19611R	\N	COMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3603	391	2019-10-30 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14241N	\N	COMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3658	395	2020-06-11 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19447X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3659	395	2020-06-11 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11026G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3689	362	2020-11-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	08011M	\N	PDTSEN	\N	\N	PDT	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3693	357	2020-11-26 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Manche	05008E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3692	329	2020-11-24 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	08028W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3694	357	2020-11-26 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Manche	19333N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3695	76	2020-11-25 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14026U	\N	COMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3697	DSPB-007	2020-11-20 00:00:00	2026-07-16 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	collège compétent en matière de déontologie de la sécurité	02002K	\N	PQPDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3701	DSPB-007	2020-11-20 00:00:00	2026-07-16 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	collège compétent en matière de défense et de promotion des droits de l'enfant	14093U	\N	PQPDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3703	DSPB-007	2020-11-20 00:00:00	2026-07-16 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	collège compétent en matière de lutte contre les discriminations et de promotion de l'égalité	14061L	\N	PQPDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3705	167	2020-12-09 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19611R	\N	COMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3706	95	2020-12-09 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14259Y	\N	COMLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3604	331	2019-11-13 00:00:00	2020-12-10 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04057K	\N	COMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3605	108	2019-11-21 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	19593H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3606	349	2019-11-21 00:00:00	2022-11-21 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19591F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3607	389	2019-11-21 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	10006L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3608	389	2019-11-21 00:00:00	2020-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	19691J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3609	392	2019-11-21 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11043H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3610	392	2019-11-21 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14229S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3611	393	2019-11-21 00:00:00	2020-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	14093U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3612	393	2019-11-21 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11103C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3614	393	2019-11-21 00:00:00	2020-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	08060W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3615	394	2019-11-21 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14169X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3616	394	2019-11-21 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08031R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3617	274	2019-11-27 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04070G	\N	COMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3622	357	2020-01-27 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Seine-Maritime	14053L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3623	383	2020-01-27 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Seine-Maritime	19826F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3707	95	2020-12-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19383Y	\N	COMCAE	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3708	391	2020-12-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14109K	\N	COMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3709	317	2020-12-16 00:00:00	2023-12-08 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	20138D	\N	COMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3710	313	2020-12-16 00:00:00	2025-12-16 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14030Q	\N	COMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3711	274	2020-12-16 00:00:00	2023-12-15 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04070G	\N	COMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3712	179	2020-12-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14033T	\N	COMCAE	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3713	317	2020-12-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20060X	\N	COMCAE	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3575	357	2019-04-12 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Eure-et-Loir	14217N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3576	357	2019-04-12 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Haute-Savoie	14237S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3613	393	2019-11-21 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19577H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3774	388	2021-01-05 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Allier	14251Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3775	388	2021-01-05 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Allier	20020P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3776	388	2021-01-05 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Ardèche	14259Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3777	388	2021-01-05 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Ardèche	20026V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3778	388	2021-01-05 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Ardennes	20056C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3779	388	2021-01-05 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Ardennes	07029T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3780	388	2021-01-05 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Aube	20050V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3781	388	2021-01-05 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Aube	19745F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3782	388	2021-01-05 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Aude	14097Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3783	388	2021-01-05 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Aude	20030R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3784	388	2021-01-05 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Aude	14097Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3785	388	2021-01-05 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Aveyron	20032T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3786	388	2021-01-05 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Aveyron	14111D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3787	388	2021-01-05 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Charente	20042V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3788	388	2021-01-05 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Charente	08060W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3789	388	2021-01-05 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Cher	05012A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3790	388	2021-01-05 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Cher	19798U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3791	388	2021-01-05 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Deux-Sèvres	20038A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3792	388	2021-01-05 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Deux-Sèvres	14071N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3793	388	2021-01-05 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Dordogne	20028X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3794	388	2021-01-05 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Dordogne	20046A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3795	388	2021-01-05 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Haute-Vienne	20080C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3796	388	2021-01-05 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Haute-Vienne	20082E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3797	388	2021-01-05 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Polynésie française	20150Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3798	388	2021-01-05 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Polynésie française	14275Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3799	388	2021-01-05 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Savoie	19575F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3800	388	2021-01-05 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Savoie	20058E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3801	388	2021-01-05 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Tarn	14089Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3802	388	2021-01-05 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Tarn	17023S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3803	388	2021-01-05 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Vienne	20024T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3804	388	2021-01-05 00:00:00	2023-12-31 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Vienne	19747H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3805	388	2021-01-05 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Vosges	14033T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3806	388	2021-01-05 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Vosges	20048C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3807	388	2021-01-05 00:00:00	2022-06-20 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Yonne	20174H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3808	388	2021-01-05 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Yonne	19749K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3809	259	2021-01-07 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	08028W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3810	259	2021-01-07 00:00:00	2024-01-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14253S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3811	259	2021-01-07 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19735D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3812	259	2021-01-07 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19527W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3813	340	2021-01-11 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	20094J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3814	397	2021-01-11 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04043D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3815	397	2021-01-11 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20024T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3586	388	2019-07-01 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Bas-Rhin	10015M	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3770	357	2021-01-05 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Orne	07004J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3620	37	2020-01-10 00:00:00	2020-03-03 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11081P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3654	37	2020-05-20 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14121F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3655	359	2020-05-20 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04008A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3656	176	2020-05-20 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14275Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3657	194	2020-05-20 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14331P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3675	612	2020-10-21 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14217N	1	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3676	612	2020-10-21 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14215L	2	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3677	612	2020-10-21 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08045X	3	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3678	612	2020-10-21 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08010L	4	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3679	612	2020-10-21 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19745F	5	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3680	612	2020-10-21 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	20150Y	6	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3681	612	2020-10-21 00:00:00	2023-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	20108W	1	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3682	612	2020-10-21 00:00:00	2022-09-16 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	19581D	2	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3683	612	2020-10-21 00:00:00	2021-01-15 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	14281W	3	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3684	612	2020-10-21 00:00:00	2023-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	20022R	4	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3685	612	2020-10-21 00:00:00	2021-12-07 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	19521Q	5	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3686	612	2020-10-21 00:00:00	2023-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	19782L	6	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3724	357	2021-01-05 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Allier	14251Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3725	357	2021-01-05 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Allier	20020P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3726	357	2021-01-05 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Ardèche	14259Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3727	357	2021-01-05 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Ardèche	20026V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3728	357	2021-01-05 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Ardennes	20056C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3729	357	2021-01-05 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Ardennes	07029T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3730	357	2021-01-05 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Aube	20050V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3731	357	2021-01-05 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Aube	19745F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3732	357	2021-01-05 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Aude	14097Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3733	357	2021-01-05 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Aude	20030R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3734	357	2021-01-05 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Aveyron	20032T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3735	357	2021-01-05 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Aveyron	14111D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3736	357	2021-01-05 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Charente	20042V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3737	357	2021-01-05 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Charente	08060W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3738	357	2021-01-05 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Cher	05012A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3739	357	2021-01-05 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Cher	19798U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3740	357	2021-01-05 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Deux-Sèvres	20038A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3741	357	2021-01-05 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Deux-Sèvres	14071N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3742	357	2021-01-05 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Dordogne	20028X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3743	357	2021-01-05 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Dordogne	20046A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3744	357	2021-01-05 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Haute-Vienne	20080C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3771	357	2021-01-05 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Orne	19762G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3745	357	2021-01-05 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Haute-Vienne	20082E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3582	49	2019-06-05 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	07033P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3583	49	2019-06-05 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19647E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3584	390	2019-06-05 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19507S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3590	388	2019-07-19 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Aude	80013X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3591	388	2019-07-19 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Aude	14097Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3600	10007	2019-02-21 00:00:00	2028-02-21 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	08051V	\N	NOMART13LOIS	\N	\N	MEMBRE	FAVORABLE	Favorable (16 voix pour, 1 voix contre)	FAVORABLE	Favorable (13 voix pour, 1 voix contre)	FAVORABLE	Favorable (29 voix pour, 2 voix contre)	2019-02-13 00:00:00	2019-02-22 00:00:00	2019-02-21 00:00:00	\N	\N	\N	2019-02-21 00:00:00	2019-02-23 00:00:00
3601	10007	2019-02-21 00:00:00	2028-02-21 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	07034Q	\N	PQPDTSENLOIS	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3621	42	2020-01-15 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Aux termes de l'art. 9 de la loi n° 78-17, le mandat est renouvelable une fois. M. Hervé pourra-t-il néanmoins être renouvelé en septembre 2020 ?	14179A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3667	357	2020-07-27 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Moselle	19954N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3668	383	2020-07-27 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Moselle	19954N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3669	388	2020-07-27 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Moselle	19954N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3690	342	2020-11-23 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14217N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3691	342	2020-11-23 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11066Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3746	357	2021-01-05 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Polynésie française	20150Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3747	357	2021-01-05 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Polynésie française	14275Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3748	357	2021-01-05 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Savoie	19575F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3749	357	2021-01-05 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Savoie	20058E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3750	357	2021-01-05 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Tarn	14089Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3751	357	2021-01-05 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Tarn	17023S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3752	357	2021-01-05 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Vienne	20024T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3753	357	2021-01-05 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Vienne	19747H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3754	357	2021-01-05 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Vosges	14033T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3755	357	2021-01-05 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Vosges	20048C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3756	357	2021-01-05 00:00:00	2022-06-20 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Yonne	20174H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3757	357	2021-01-05 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Yonne	19749K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3758	357	2021-01-05 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Jura	19467C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3759	357	2021-01-05 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Jura	19479G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3760	357	2021-01-05 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Landes	19489J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3761	357	2021-01-05 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Landes	17779H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3762	357	2021-01-05 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Loir-et-Cher	19511N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3763	357	2021-01-05 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Loir-et-Cher	19739H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3764	357	2021-01-05 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Lot-et-Garonne	19367Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3765	357	2021-01-05 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Lot-et-Garonne	19369B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3766	357	2021-01-05 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Martinique	11109J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3767	357	2021-01-05 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Martinique	19295A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3768	357	2021-01-05 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Mayenne	18083K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3769	357	2021-01-05 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Mayenne	14042U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3772	357	2021-01-05 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Pyrénées-Orientales	11101A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3773	357	2021-01-05 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Pyrénées-Orientales	19703U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3431	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Aisne	08052W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3432	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Aisne	14026U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3433	388	2019-03-25 00:00:00	2019-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Allier	14251Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3434	388	2019-03-25 00:00:00	2020-09-24 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Alpes-Maritimes	08041T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3435	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Alpes-Maritimes	08039A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3436	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Ardèche	14259Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3437	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Ardennes	07029T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3438	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Aube	89017R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3439	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Aube	19745F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3440	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Aveyron	14103D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3441	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Aveyron	14111D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3442	388	2019-03-25 00:00:00	2019-06-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Bas-Rhin	14065Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3443	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Bas-Rhin	14061L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3444	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Bouches-du-Rhône	14115H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3445	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Bouches-du-Rhône	14241N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3446	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Calvados	14133K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3447	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Charente	08060W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3448	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Charente	08058D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3449	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Charente-Maritime	08015R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3450	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Cher	19798U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3451	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Côtes-d'Or	08069G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3452	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Côtes-d'Or	08061X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3453	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Côtes-d'Armor	08014Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3454	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Côtes-d'Armor	14157T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3455	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Deux-Sèvres	14119M	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3456	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Dordogne	08055A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3457	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Dordogne	98029W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3458	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Doubs	14123H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3459	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Doubs	14219Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3460	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Drôme	14105F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3461	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Drôme	14109K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3462	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Essonne	19693L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3463	388	2019-03-25 00:00:00	2021-09-23 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Essonne	19693L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3464	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Essonne	11070L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3465	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Eure	14249W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3466	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Eure	98050T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3467	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Eure-et-Loir	14217N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3468	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Eure-et-Loir	19794Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3469	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Finistère	08043V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3470	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Finistère	08047A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3471	388	2019-03-25 00:00:00	2020-06-17 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Gard	19733B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3472	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Gard	98035U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3473	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Gironde	19721W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3474	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Gironde	19725B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3475	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Guadeloupe	19715Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3476	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Guadeloupe	19301E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3477	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Haute-Garonne	14221J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3478	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Haute-Garonne	14225N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3479	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Haute-Savoie	19768N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3480	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Haute-Savoie	14237S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3481	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Haute-Vienne	14028W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3482	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Haut-Rhin	04040A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3483	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Haut-Rhin	04044E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3484	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Hauts-de-Seine	17637T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3485	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Hérault	08020N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3486	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Hérault	14207L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3487	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Ille-et-Vilaine	08034U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3488	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Ille-et-Vilaine	14229S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3489	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Indre-et-Loire	19441R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3490	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Indre-et-Loire	19443T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3491	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Isère	19347U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3492	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Isère	11043H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3493	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Jura	19467C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3494	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Jura	19479G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3495	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	La Réunion	19659J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3496	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	La Réunion	19577H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3497	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Landes	17779H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3498	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Loire	11056N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3499	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Loire	97011G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3500	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Loire-Atlantique	11064N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3501	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Loire-Atlantique	11067R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3502	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Loiret	11103C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3503	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Loiret	01028R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3504	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Loir-et-Cher	19511N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3505	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Loir-et-Cher	19739H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3506	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Lot-et-Garonne	19367Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3507	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Lot-et-Garonne	19369B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3508	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Maine-et-Loire	19545Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3509	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Maine-et-Loire	19533U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3510	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Manche	05008E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3511	388	2019-03-25 00:00:00	2020-11-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Manche	96004D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3512	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Marne	01025N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3513	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Marne	11097X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3514	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Martinique	11109J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3515	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Martinique	19295A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3516	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Mayenne	18083K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3517	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Mayenne	14042U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3518	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Meurthe-et-Moselle	19553Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3519	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Meurthe-et-Moselle	19551W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3520	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Morbihan	19447X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3521	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Morbihan	11099A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3522	388	2019-03-25 00:00:00	2020-07-13 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Moselle	11049P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3523	388	2019-03-25 00:00:00	2021-09-14 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Moselle	01060R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3524	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Nord	04008A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3525	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Nord	19599P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3526	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Oise	19741B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3527	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Oise	11115U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3528	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Orne	07004J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3529	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Orne	19762G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3530	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Pas-de-Calais	14331P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3531	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Polynésie Française	14277B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3532	388	2019-03-25 00:00:00	2020-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Polynésie Française	14275Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3533	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Puy-de-Dôme	19383Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3534	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Puy-de-Dôme	11104D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3535	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Pyrénées-Atlantiques	19621T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3536	388	2019-03-25 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Pyrénées-Atlantiques	11110B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3816	397	2021-01-11 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19441R	\N	PDTSEN	\N	\N	PDT	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3817	397	2021-01-11 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19503N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3829	112	2021-01-27 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	20152B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3830	112	2021-01-27 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14038Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3831	112	2021-01-27 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19681G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3832	112	2021-01-27 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14327T	\N	PDTSEN	\N	\N	VICEPRESIDENT	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3833	112	2021-01-27 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19599P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3834	112	2021-01-27 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19619A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3835	112	2021-01-27 00:00:00	2021-07-22 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14257W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3906	29	2021-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14059S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3907	29	2021-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14221J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3908	29	2021-02-01 00:00:00	2021-06-14 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08047A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3909	29	2021-02-01 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	\N	14030Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3910	29	2021-02-01 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	\N	20114U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3911	194	2021-02-01 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14213J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3912	194	2021-02-01 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08045X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3913	194	2021-02-01 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19703U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3914	299	2021-02-01 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11097X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3915	34	2021-02-01 00:00:00	2022-12-14 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14053L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3916	34	2021-02-01 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01057W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3917	34	2021-02-01 00:00:00	2023-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	14225N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3918	34	2021-02-01 00:00:00	2023-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	19749K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3919	37	2021-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14205J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3920	37	2021-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14107H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3921	50	2021-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19782L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3922	50	2021-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	18193Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3923	72	2021-02-01 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19573D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3924	72	2021-02-01 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19503N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3925	115	2021-02-01 00:00:00	2021-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08017T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3926	128	2021-02-01 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19295A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3927	128	2021-02-01 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11097X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3928	147	2021-02-01 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14042U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3929	147	2021-02-01 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11097X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3930	161	2021-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20056C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3931	164	2021-02-01 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	17779H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3932	164	2021-02-01 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11097X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3933	164	2021-02-01 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01034P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3934	164	2021-02-01 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19479G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3935	176	2021-02-01 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11033F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3936	176	2021-02-01 00:00:00	2024-02-01 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14169X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3937	180	2021-02-01 00:00:00	2022-06-20 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	20174H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3938	196	2021-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19729F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3939	199	2021-02-01 00:00:00	2022-02-23 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19683J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3940	199	2021-02-01 00:00:00	2022-02-23 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04045F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3941	213	2021-02-01 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19719D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3942	213	2021-02-01 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14257W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3943	233	2021-02-01 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11077T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3944	236	2021-02-01 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19647E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3945	243	2021-02-01 00:00:00	2024-02-01 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20088L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3946	243	2021-02-01 00:00:00	2024-02-01 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14187A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3947	282	2021-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19820Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3948	282	2021-02-01 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19657G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3949	295	2021-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20100N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3950	295	2021-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20146D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3951	296	2021-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20066E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3952	296	2021-02-01 00:00:00	2024-01-09 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Démission de l'OEP de Philippe Mouiller	14071N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3953	303	2021-02-01 00:00:00	2021-09-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	20114U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3819	95	2020-12-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14237S	\N	COMCDD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3820	95	2020-12-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19503N	\N	COMCDD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3821	398	2021-01-18 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19543W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3822	398	2021-01-18 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19447X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3823	398	2021-01-18 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11026G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3836	331	2021-01-27 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19735D	\N	COMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3954	303	2021-02-01 00:00:00	2021-09-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19866P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4103	357	2021-02-17 00:00:00	2021-05-11 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Maine-et-Loire	10006L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4104	357	2021-02-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Maine-et-Loire	19545Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4105	357	2021-02-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Marne	01025N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4106	357	2021-02-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Marne	11097X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4107	357	2021-02-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Meurthe-et-Moselle	11048N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4108	357	2021-02-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Meurthe-et-Moselle	19553Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4109	357	2021-02-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Morbihan	19447X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4110	357	2021-02-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Morbihan	11099A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4111	357	2021-02-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Moselle	19954N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4112	357	2021-02-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Moselle	01060R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4113	357	2021-02-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Nord	01043Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4114	357	2021-02-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Nord	14021P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4115	357	2021-02-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Oise	11045K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4116	357	2021-02-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Oise	11115U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4117	357	2021-02-17 00:00:00	2021-12-07 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Pas-de-Calais	19521Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4118	357	2021-02-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Pas-de-Calais	19525U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4119	357	2021-02-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Puy-de-Dôme	11104D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4120	357	2021-02-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Puy-de-Dôme	19383Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4121	357	2021-02-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Hauts-de-Seine	11085T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4122	357	2021-02-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Pyrénées-Atlantiques	11110B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4123	357	2021-02-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Pyrénées-Atlantiques	19621T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4124	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Rhône	14215L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4125	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Rhône	20134Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4126	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Saône-et-Loire	14147R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4127	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Saône-et-Loire	14151M	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4128	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Sarthe	14169X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4129	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Sarthe	20070A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4130	357	2021-02-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Seine-et-Marne	14329V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4131	357	2021-02-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Seine-et-Marne	19543W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4133	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Seine-Maritime	14053L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4134	357	2021-02-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Seine-Saint-Denis	04085P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4135	357	2021-02-17 00:00:00	2021-07-27 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Seine-Saint-Denis	04086Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4136	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Somme	20062A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4137	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Somme	17229F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4138	357	2021-02-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Val-de-Marne	11031D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4139	357	2021-02-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Val-de-Marne	04042C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4140	357	2021-02-17 00:00:00	2021-04-07 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Val-d'Oise	19673G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4141	357	2021-02-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Val-d'Oise	95063L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4142	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Var	20074E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4143	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Var	20072C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4144	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Vendée	14030Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4145	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Vendée	04033B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3990	310	2021-02-04 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	\N	17023S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4146	357	2021-02-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Yvelines	11090Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4147	357	2021-02-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Yvelines	19699S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4148	357	2021-02-18 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Vaucluse	04092N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4149	357	2021-02-18 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Vaucluse	20084G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4150	388	2021-02-18 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Vaucluse	20086J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4151	388	2021-02-18 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Vaucluse	20084G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4152	388	2021-02-18 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Manche	20180F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4153	292	2021-02-03 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04035D	\N	COMETRD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4154	273	2021-02-10 00:00:00	2021-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14255U	\N	COMETRD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4155	328	2021-02-10 00:00:00	2022-01-11 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	12028B	\N	COMETRD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4156	328	2021-02-10 00:00:00	2022-01-11 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14133K	\N	COMETRD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4157	DSPB-010	2021-02-23 00:00:00	2026-02-22 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	mandat de cinq ans, renouvelable une fois	95035G	\N	PQPDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4158	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Seine-Maritime	19826F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4159	399	2021-03-04 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19525U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4160	399	2021-03-04 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19685L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4161	399	2021-03-04 00:00:00	2024-02-11 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20136B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4162	DSPB-011	2021-03-08 00:00:00	2027-03-08 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	6 ans non renouvelable	14061L	\N	PQPDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4163	DSPB-011	2021-03-08 00:00:00	2027-03-08 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	6 ans non renouvelable	08031R	\N	PQPDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4164	169	2021-03-08 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14059S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4165	115	2021-03-08 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19709B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4166	221	2021-03-12 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19387D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4167	264	2021-03-12 00:00:00	2024-03-12 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	08056B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4168	396	2021-03-18 00:00:00	2024-02-11 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20114U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4169	396	2021-03-18 00:00:00	2024-03-18 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	17737W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4170	126	2021-03-24 00:00:00	2024-03-24 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20080C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4171	126	2021-03-24 00:00:00	2024-03-24 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	95041E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4172	299	2021-04-07 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19717B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4173	299	2021-04-07 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19760E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4174	261	2021-04-08 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20024T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4175	264	2021-04-12 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19573D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4179	346	2021-04-14 00:00:00	2021-09-15 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11077T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4178	357	2021-04-14 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Val-d'Oise	19667J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4180	320	2021-04-20 00:00:00	2024-04-20 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	\N	20116W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4181	357	2021-05-20 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Maine-et-Loire	19533U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4182	313	2021-05-26 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19527W	\N	COMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4183	323	2021-06-02 00:00:00	2022-07-06 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11030C	\N	NOMART13CDD	\N	\N	PDTCA	FAVORABLE	20 voix pour	FAVORABLE	17 voix pour	FAVORABLE	37 voix pour, aucune voix contre	2021-05-03 00:00:00	2021-06-02 00:00:00	2021-05-26 00:00:00	\N	\N	\N	2021-06-07 00:00:00	\N
4190	29	2021-06-21 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20104S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3837	8	2021-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14026U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3838	22	2021-02-01 00:00:00	2024-01-31 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	17737W	\N	PDTSEN	\N	\N	MEMBRE	INDETERMINE	\N	INDETERMINE	\N	INDETERMINE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3839	30	2021-02-01 00:00:00	2025-02-01 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14213J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3840	81	2021-02-01 00:00:00	2024-02-01 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14187A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3841	81	2021-02-01 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	19631V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3842	86	2021-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14147R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3843	246	2021-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20134Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3844	212	2021-02-01 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19415P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3845	204	2021-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14123H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3846	190	2021-02-01 00:00:00	2024-03-19 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14071N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3847	157	2021-02-01 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04035D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3848	156	2021-02-01 00:00:00	2025-02-01 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20146D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3849	152	2021-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20118Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3850	108	2021-02-01 00:00:00	2025-02-01 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14229S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3851	42	2021-02-01 00:00:00	2024-02-28 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Démission	14179A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3852	42	2021-02-01 00:00:00	2024-02-28 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Démission	14229S	\N	PDTSEN	\N	\N	MEMBRE	INDETERMINE	\N	INDETERMINE	\N	INDETERMINE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3991	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Ain	20094J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3992	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Ain	14038Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3993	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Aisne	14026U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3994	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Alpes-Maritimes	20138D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3995	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Alpes-Maritimes	20136B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3996	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Bas-Rhin	20098N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3997	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Bas-Rhin	20100N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3998	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Bouches-du-Rhône	17737W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3999	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Bouches-du-Rhône	20112S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4000	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Calvados	14281W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4001	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Calvados	14133K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4002	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Charente-Maritime	08015R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4003	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Charente-Maritime	20064C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4004	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Côte-d'Or	14205J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4005	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Côte-d'Or	08069G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4006	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Côtes-d'Armor	18193Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4007	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Côtes-d'Armor	20104S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4008	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Doubs	20066E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4009	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Doubs	14123H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4010	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Drôme	14109K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4011	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Drôme	14105F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4012	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Eure-et-Loir	14217N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4013	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Eure-et-Loir	20068G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4014	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Finistère	20106U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4015	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Finistère	08045X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4016	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Gard	20088L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4017	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Gard	20090E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4018	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Gironde	19725B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4019	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Gironde	19721W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4020	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Haute-Garonne	17965H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4021	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Haute-Garonne	08028W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4022	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Haute-Savoie	19768N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4023	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Haute-Savoie	14237S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4024	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Haut-Rhin	20124W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4025	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Haut-Rhin	20128B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4026	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Aisne	20122U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4027	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Hérault	20114U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4028	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Hérault	14211G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3987	DSPB-008	2021-01-27 00:00:00	2027-01-26 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Parité à respecter	04049K	\N	PQPDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4029	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Ille-et-Vilaine	14229S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4030	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Ille-et-Vilaine	08034U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4031	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Rhône	20130U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4032	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Rhône	04047H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4033	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Saône-et-Loire	14147R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4034	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Saône-et-Loire	14151M	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4035	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Sarthe	14173T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4036	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Sarthe	20070A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4037	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Seine-Maritime	14053L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4038	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Seine-Maritime	14001X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4039	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Somme	20060X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4040	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Somme	17229F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4041	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Var	20074E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4042	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Var	20072C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4043	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Vendée	14030Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4044	388	2021-02-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Vendée	04033B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4045	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Ain	20094J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4046	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Ain	14038Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4047	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Aisne	14026U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4048	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Aisne	08010L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4049	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Alpes-Maritimes	14187A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4050	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Alpes-Maritimes	20136B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4051	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Bas-Rhin	20096L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4056	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Calvados	19735D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4053	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Bas-Rhin	14073Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4054	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Bouches-du-Rhône	12028B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4055	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Bouches-du-Rhône	20108W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4057	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Calvados	14133K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4058	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Charente-Maritime	14213J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4059	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Charente-Maritime	20064C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4060	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Côte-d'Or	14205J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4061	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Côte-d'Or	08069G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4062	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Côtes-d'Armor	18193Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4063	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Côtes-d'Armor	20104S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4064	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Doubs	20066E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4065	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Doubs	14123H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4066	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Drôme	14109K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4067	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Drôme	14105F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4068	357	2021-02-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Essonne	19693L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4069	357	2021-02-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Essonne	11070L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4070	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Eure-et-Loir	14217N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4071	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Eure-et-Loir	08011M	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4072	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Finistère	20106U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4073	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Finistère	14083S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4074	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Gard	20088L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4075	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Gard	14059S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4076	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Gironde	19719D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4077	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Gironde	19820Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4078	357	2021-02-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Guadeloupe	19715Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4079	357	2021-02-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Guadeloupe	19301E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4080	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Haute-Garonne	14223L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4081	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Haute-Garonne	14225N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3824	357	2021-01-21 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Eure	08009T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3825	357	2021-01-21 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Eure	20118Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3955	304	2021-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14038Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3956	306	2021-02-01 00:00:00	2024-02-01 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14083S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3957	307	2021-02-01 00:00:00	2021-07-07 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19447X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3958	307	2021-02-01 00:00:00	2021-07-07 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11012A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3959	318	2021-02-01 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19421M	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3960	320	2021-02-01 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19667J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3961	320	2021-02-01 00:00:00	2024-02-01 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14231L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3962	320	2021-02-01 00:00:00	2024-02-01 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	\N	20094J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3963	333	2021-02-01 00:00:00	2024-02-01 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14187A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3964	333	2021-02-01 00:00:00	2024-02-01 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20028X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3965	336	2021-02-01 00:00:00	2026-02-01 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	17229F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3966	336	2021-02-01 00:00:00	2026-02-01 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20106U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3967	339	2021-02-01 00:00:00	2025-02-01 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20122U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3968	359	2021-02-01 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19599P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3969	361	2021-02-01 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19553Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3970	361	2021-02-01 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19703U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3971	363	2021-02-01 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14207L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3972	363	2021-02-01 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11090Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3973	364	2021-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14187A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3974	364	2021-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14237S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3975	394	2021-02-01 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19629C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3976	394	2021-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14169X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3977	393	2021-02-01 00:00:00	2026-02-01 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	\N	19251M	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3978	393	2021-02-01 00:00:00	2026-02-01 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	\N	20050V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3979	392	2021-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19725B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3980	368	2021-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14033T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3981	368	2021-02-01 00:00:00	2024-02-28 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Démission de l'OEP	20096L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3982	367	2021-02-01 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19631V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3983	366	2021-02-01 00:00:00	2024-02-18 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14219Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3984	366	2021-02-01 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19467C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3988	DSPB-009	2021-04-11 00:00:00	2024-04-10 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	3 ans non renouvelable	08039A	\N	PQPDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3989	DSPB-009	2021-02-05 00:00:00	2024-04-10 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	3 ans non renouvelable à compter du 11 avril 2021	08039A	\N	PQPDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4082	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Haute-Savoie	19768N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4083	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Haute-Savoie	14179A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4084	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Haut-Rhin	04045F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4085	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Haut-Rhin	20126Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4086	357	2021-02-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Hauts-de-Seine	19711U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4087	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Hérault	20114U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4088	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Hérault	14211G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4089	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Ille-et-Vilaine	14231L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4090	357	2021-02-17 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Ille-et-Vilaine	20092G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4091	357	2021-02-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Indre-et-Loire	19443T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4092	357	2021-02-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Indre-et-Loire	19441R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4093	357	2021-02-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Isère	19347U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4094	357	2021-02-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Isère	11043H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4095	357	2021-02-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	La Réunion	19577H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4096	357	2021-02-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	La Réunion	19583F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4097	357	2021-02-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Loire	19415P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4098	357	2021-02-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Loire	11056N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4099	357	2021-02-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Loire-Atlantique	20172F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4100	357	2021-02-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Loire-Atlantique	11066Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4101	357	2021-02-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Loiret	19421M	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4102	357	2021-02-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Loiret	01028R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3818	158	2021-01-12 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19954N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3826	388	2021-01-21 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Eure	08009T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3827	388	2021-01-21 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Eure	14249W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3828	612	2021-01-21 00:00:00	2023-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	12028B	3	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3853	13	2021-02-01 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19741B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3854	13	2021-02-01 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19631V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3855	258	2021-02-01 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01043Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3856	265	2021-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	08028W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3857	283	2021-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19758L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3858	310	2021-02-01 00:00:00	2021-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08018U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3859	323	2021-02-01 00:00:00	2024-02-01 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20136B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3860	326	2021-02-01 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19673G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3861	334	2021-02-01 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19701S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3862	337	2021-02-01 00:00:00	2026-02-01 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14237S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3863	348	2021-02-01 00:00:00	2021-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14071N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3864	360	2021-02-01 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19673G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3865	362	2021-02-01 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	\N	20048C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3866	369	2021-02-01 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19503N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3867	369	2021-02-01 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	\N	20142Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3868	371	2021-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	05012A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3869	371	2021-02-01 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	11099A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3870	370	2021-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20060X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3871	370	2021-02-01 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	19637C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3872	372	2021-02-01 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11048N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3873	372	2021-02-01 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	\N	20100N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3874	374	2021-02-01 00:00:00	2024-02-14 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20062A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3875	374	2021-02-01 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	19591F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3876	375	2021-02-01 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	20090E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3877	376	2021-02-01 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	08045X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3878	377	2021-02-01 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19717B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3879	381	2021-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14179A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3880	389	2021-02-01 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	10006L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3881	389	2021-02-01 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	19691J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3882	610	2021-02-01 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19569H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3883	104	2021-02-01 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19643A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3884	127	2021-02-01 00:00:00	2024-02-01 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	08045X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3885	168	2021-02-01 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	01062T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3886	186	2021-02-01 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	07033P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3887	205	2021-02-01 00:00:00	2021-09-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	20074E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3888	214	2021-02-01 00:00:00	2024-02-11 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20130U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3889	214	2021-02-01 00:00:00	2021-10-07 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	04045F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3890	222	2021-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20132W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3891	251	2021-02-01 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19467C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3892	255	2021-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20102Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3893	291	2021-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14053L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3894	297	2021-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20024T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3895	309	2021-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14229S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3896	344	2021-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20076G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3897	373	2021-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14187A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3898	373	2021-02-01 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	\N	19866P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3899	378	2021-02-01 00:00:00	2026-02-01 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14249W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3900	172	2021-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19729F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3901	172	2021-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20148F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3902	314	2021-02-01 00:00:00	2024-02-01 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19745F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3903	382	2021-02-01 00:00:00	2022-06-29 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14275Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3904	24	2021-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14033T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
3905	24	2021-02-01 00:00:00	2022-06-27 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19413M	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4215	115	2021-10-28 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11027H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4484	406	2022-04-01 00:00:00	2026-04-01 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19798U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4506	408	2022-06-10 00:00:00	2024-03-13 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Nouvelle-Aquitaine	14213J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4507	408	2022-06-10 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Normandie	14281W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4509	408	2022-06-10 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Bretagne	18193Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4512	408	2022-06-10 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Corse	14191V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4513	408	2022-06-10 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	GUadeloupe	19715Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4519	408	2022-06-10 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Occitanie	19703U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4522	408	2022-06-10 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Provence-Alpes-Côte d'Azur	04092N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4523	408	2022-06-10 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Auvergne-Rhône-Alpes	19415P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4563	349	2023-02-07 00:00:00	2026-02-07 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20146D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4566	239	2023-02-14 00:00:00	2026-02-14 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20106U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4573	410	2023-05-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20114U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4196	112	2021-07-28 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	en remplacement de M. MONTAUGÉ, démissionnaire	20082E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4292	401	2022-03-16 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Gard	20090E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4223	612	2021-12-14 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	Remplaçant de Mme FOURNIER	19543W	5	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4234	401	2022-03-16 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Aisne	08010L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4236	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Allier	14251Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4237	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Allier	20020P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4238	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Alpes-Maritimes	14187A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4240	401	2022-03-16 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Alpes-Maritimes	20140W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4242	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Ardèche	14259Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4243	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Ardèche	20026V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4244	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Ardennes	20056C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4245	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Ardennes	07029T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4248	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Aude	14097Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4249	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Aude	20030R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4250	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Aveyron	20032T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4252	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Bouches-du-Rhône	20112S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4254	401	2022-03-16 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Bouches-du-Rhône	20110Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4255	401	2022-03-16 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Bouches-du-Rhône	20248J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4257	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Calvados	14281W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4259	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Charente	20042V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4262	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Charente-Maritime	20064C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4263	401	2022-03-16 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Charente-Maritime	08015R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4264	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Cher	05012A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4265	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Cher	19798U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4266	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Côte-d'Or	14205J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4267	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Côte-d'Or	08061X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4268	401	2022-03-16 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Côte-d'Or	08069G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4269	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Côtes-d'Armor	20104S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4270	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Côtes-d'Armor	18193Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4271	401	2022-03-16 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Côtes-d'Armor	20102Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4272	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Dordogne	20028X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4273	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Dordogne	20046A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4274	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Doubs	14123H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4275	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Doubs	20066E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4276	401	2022-03-16 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Doubs	14219Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4277	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Drôme	14105F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4278	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Drôme	14109K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4279	401	2022-03-16 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Drôme	19782L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4280	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Eure	14249W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4281	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Eure	08009T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4282	401	2022-03-16 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Eure	20118Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4283	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Eure-et-Loir	14217N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4284	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Eure-et-Loir	20068G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4285	401	2022-03-16 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Eure-et-Loir	08011M	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4286	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Finistère	20106U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4287	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Finistère	08047A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4288	401	2022-03-16 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Finistère	14083S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4289	401	2022-03-16 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Finistère	08045X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4290	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Gard	20088L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4291	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Gard	14059S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4293	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Haute-Garonne	14223L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4294	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Haute-Garonne	14225N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4295	401	2022-03-16 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Haute-Garonne	14221J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4227	306	2022-01-24 00:00:00	2022-07-03 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19689Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4228	358	2022-01-28 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20062A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4296	401	2022-03-16 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Haute-Garonne	17965H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4297	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Gironde	19719D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4300	401	2022-03-16 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Gironde	19721W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4302	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Hérault	20116W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4304	401	2022-03-16 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Hérault	14207L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4306	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Ille-et-Vilaine	14229S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4308	401	2022-03-16 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Ille-et-Vilaine	20092G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4310	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Indre-et-Loire	19443T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4312	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Isère	19347U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4315	401	2022-03-16 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	Isère	11043H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4317	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Jura	19479G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4319	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Landes	17779H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4321	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Loir-et-Cher	19739H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4323	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Loire	11056N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4325	401	2022-03-16 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	Loire	19413M	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4327	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Loire-Atlantique	11067R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4329	401	2022-03-16 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	Loire-Atlantique	20172F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4332	401	2022-03-16 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	Loiret	19421M	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4334	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Lot-et-Garonne	19369B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4336	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Maine-et-Loire	10006L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4338	401	2022-03-16 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	Maine-et-Loire	19533U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4340	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Manche	19333N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4342	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Marne	01025N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4344	401	2022-03-16 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	Marne	01024M	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4346	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Mayenne	14042U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4348	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Meurthe-et-Moselle	11048N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4350	401	2022-03-16 00:00:00	2022-12-31 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	Meurthe-et-Moselle	92040Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4352	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Morbihan	11099A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4355	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Moselle	01060R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4358	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Nord	14021P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4360	401	2022-03-16 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	Nord	04008A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4362	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Oise	19741B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4364	401	2022-03-16 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	Oise	11115U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4366	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Orne	07004J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4369	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Paris	19647E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4371	401	2022-03-16 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	Paris	11077T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4372	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Pas-de-Calais	14331P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4374	401	2022-03-16 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	Pas-de-Calais	19760E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4377	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Puy-de-Dôme	19387D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4381	401	2022-03-16 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	Pyrénées-Atlantiques	19619A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4384	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Bas-Rhin	14073Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4386	401	2022-03-16 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Bas-Rhin	20100N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4387	401	2022-03-16 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Bas-Rhin	20096L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4389	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Haut-Rhin	04045F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4391	401	2022-03-16 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Haut-Rhin	20128B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4394	401	2022-03-16 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Rhône	14215L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4396	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Saône-et-Loire	14151M	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4399	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Sarthe	20070A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4400	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Sarthe	14173T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4401	401	2022-03-16 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Sarthe	14169X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4402	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Savoie	19575F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4220	292	2021-11-23 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11083R	\N	COMETRD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4221	273	2021-11-23 00:00:00	2024-11-23 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14255U	\N	COMETRD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4222	273	2021-11-23 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11027H	\N	COMETRD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4404	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Haute-Savoie	14179A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4406	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Seine-Maritime	14053L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4408	401	2022-03-16 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Seine-Maritime	19758L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4410	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Seine-et-Marne	19543W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4413	401	2022-03-16 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	Seine-et-Marne	04057K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4415	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Yvelines	11090Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4417	401	2022-03-16 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	Yvelines	19699S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4420	403	2022-03-24 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	17229F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4421	404	2022-03-24 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20110Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4422	404	2022-03-24 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14053L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4423	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Somme	17229F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4424	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Somme	20062A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4425	401	2022-03-16 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Somme	20060X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4426	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Tarn	14089Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4427	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Tarn	17023S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4428	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Var	20074E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4429	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Var	20072C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4430	401	2022-03-16 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Var	20076G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4431	401	2022-03-16 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Var	20078J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4432	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Vaucluse	04092N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4433	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Vaucluse	20084G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4434	401	2022-03-16 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Vaucluse	20086J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4435	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Vendée	14030Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4436	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Vendée	14031R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4437	401	2022-03-16 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Vendée	04033B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4438	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Vienne	20024T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4439	401	2022-03-16 00:00:00	2023-12-31 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Vienne	19747H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4440	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Haute-Vienne	20080C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4441	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Haute-Vienne	20082E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4442	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Vosges	14033T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4443	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Vosges	20048C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4444	401	2022-03-16 00:00:00	2022-06-20 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Yonne	20174H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4445	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Yonne	19749K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4446	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Polynésie française	20150Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4447	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Polynésie française	14275Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4448	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Corse	14191V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4449	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Corse	20036X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4450	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Essonne	19691J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4451	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Essonne	19399H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4453	401	2022-03-16 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	Essonne	19693L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4454	401	2022-03-16 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	Essonne	11070L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4455	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Hauts-de-Seine	19711U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4456	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Hauts-de-Seine	11085T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4457	401	2022-03-16 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	Hauts-de-Seine	11083R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4458	401	2022-03-16 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	Hauts-de-Seine	99004R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4459	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Seine-Saint-Denis	04085P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4460	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Seine-Saint-Denis	20252E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4202	388	2021-09-27 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Moselle	01062T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4212	310	2021-10-21 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	08018U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4217	214	2021-11-03 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	\N	20106U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4219	346	2021-11-04 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20046A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4461	401	2022-03-16 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	Seine-Saint-Denis	11053K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4462	401	2022-03-16 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	Seine-Saint-Denis	19663E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4463	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Val-de-Marne	04042C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4464	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Val-de-Marne	11031D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4465	401	2022-03-16 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	Val-de-Marne	19611R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4466	401	2022-03-16 00:00:00	2022-07-03 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	Val-de-Marne	19689Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4467	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Val-d'Oise	19673G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4468	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Val-d'Oise	95063L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4469	401	2022-03-16 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	Val-d'Oise	19667J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4470	401	2022-03-16 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	Val-d'Oise	19669L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4471	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Guadeloupe	19715Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4472	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Guadeloupe	19301E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4473	401	2022-03-16 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	Guadeloupe	12016W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4474	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Martinique	11109J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4475	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Martinique	19295A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4476	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	La Réunion	19577H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4477	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	La Réunion	19583F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4478	401	2022-03-16 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	La Réunion	19659J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4479	401	2022-03-16 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	La Réunion	19657G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4343	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Marne	11097X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4483	10007	2022-03-07 00:00:00	2031-03-07 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	01007L	\N	NOMART13LOIS	\N	\N	MEMBRE	DEFAVORABLE	(12 voix pour, 16 voix contre) \n\n	FAVORABLE	Favorable (29 voix pour, 15 contre)\n	FAVORABLE	(41 voix pour, 31 voix contre) 	2022-02-15 00:00:00	2022-02-24 00:00:00	2022-03-23 00:00:00	\N	\N	\N	2022-03-23 00:00:00	\N
4485	199	2022-04-04 00:00:00	2024-01-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	04045F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4486	199	2022-04-04 00:00:00	2025-04-04 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19723Y	\N	PDTSEN	\N	\N	AUCUNE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4487	199	2022-04-04 00:00:00	2025-04-04 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14221J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4488	328	2022-04-04 00:00:00	2023-12-08 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14133K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4489	328	2022-04-04 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	12028B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4491	323	2018-03-29 00:00:00	2021-06-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11030C	\N	NOMART13CDD	\N	\N	PDTCA	FAVORABLE	Favorable (24 voix pour, 4 contre )\n\n	FAVORABLE	Favorable (35 voix pour, 5 contre)\n	FAVORABLE	Favorable (59 voix pour, 9 contre)	2018-03-05 00:00:00	2018-03-28 00:00:00	2018-03-27 00:00:00	\N	\N	\N	2018-03-28 00:00:00	2018-03-29 00:00:00
4501	236	2022-05-17 00:00:00	2026-10-07 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Commissionreconduite pour 5ans jusqu'au 7 octobre 2026	04086Q	\N	PQPDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4502	318	2022-05-31 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	04057K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4197	303	2021-09-02 00:00:00	2024-09-02 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20114U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4198	303	2021-09-02 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19866P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4199	205	2021-09-02 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20074E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4206	400	2021-10-04 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19701S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4207	400	2021-10-04 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	\N	20106U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4226	357	2022-01-11 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Pas-de-Calais	20286Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4299	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Gironde	19820Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4301	401	2022-03-16 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Gironde	19725B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4303	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Hérault	20114U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4305	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Ille-et-Vilaine	08034U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4307	401	2022-03-16 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Ille-et-Vilaine	14231L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4309	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Indre-et-Loire	19441R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4311	401	2022-03-16 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	Indre-et-Loire	19515S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4313	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Isère	19679N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4314	401	2022-03-16 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	Isère	19349W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4316	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Jura	19467C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4318	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Landes	19489J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4320	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Loir-et-Cher	19511N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4322	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Loire	19415P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4324	401	2022-03-16 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	Loire	97011G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4326	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Loire-Atlantique	11064N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4328	401	2022-03-16 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	Loire-Atlantique	11065P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4330	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Loiret	11103C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4331	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Loiret	01028R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4333	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Lot-et-Garonne	19367Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4335	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Maine-et-Loire	19545Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4337	401	2022-03-16 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	Maine-et-Loire	19549D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4339	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Manche	20180F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4341	401	2022-03-16 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	Manche	05008E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4345	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Mayenne	18083K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4347	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Meurthe-et-Moselle	19553Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4349	401	2022-03-16 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	Meurthe-et-Moselle	19551W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4351	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Morbihan	19447X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4353	401	2022-03-16 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	Morbihan	16685X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4354	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Moselle	19954N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4356	401	2022-03-16 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	Moselle	19685L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4357	401	2022-03-16 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	Moselle	01062T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4359	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Nord	01043Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4361	401	2022-03-16 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	Nord	19565D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4363	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Oise	11045K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4365	401	2022-03-16 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	Oise	19573D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4367	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Orne	19762G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4368	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Paris	19643A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4370	401	2022-03-16 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	Paris	19651A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4373	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Pas-de-Calais	19527W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4375	401	2022-03-16 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	Pas-de-Calais	01034P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4376	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Puy-de-Dôme	19383Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4378	401	2022-03-16 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	Puy-de-Dôme	11104D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4379	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Pyrénées-Atlantiques	19621T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4380	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Pyrénées-Atlantiques	11110B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4204	357	2021-09-27 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Seine-Saint-Denis	20252E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4201	DSPB-012	2021-04-21 00:00:00	2027-04-07 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	mandat de 6 ans (renouvelable une fois) / Denis Badré déja nommé en 2015	95007C	\N	PQPDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4203	288	2021-09-27 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19711U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4205	388	2021-09-27 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Seine-Saint-Denis	20252E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4208	388	2021-10-05 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Essonne	19691J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4382	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Pyrénées-Orientales	11101A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4383	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Pyrénées-Orientales	19703U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4385	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Bas-Rhin	20098N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4388	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Haut-Rhin	20126Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4390	401	2022-03-16 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Haut-Rhin	20124W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4392	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Rhône	04047H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4393	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Rhône	20130U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4395	401	2022-03-16 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Rhône	20132W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4397	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Saône-et-Loire	14147R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4398	401	2022-03-16 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Saône-et-Loire	20120S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4403	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Savoie	20058E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4405	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Haute-Savoie	19768N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4407	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Seine-Maritime	19826F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4409	401	2022-03-16 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Seine-Maritime	14001X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4411	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Seine-et-Marne	14329V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4412	401	2022-03-16 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	Seine-et-Marne	14357A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4414	401	2022-03-16 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Yvelines	19697Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4416	401	2022-03-16 00:00:00	2023-10-01 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	Yvelines	19701S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4418	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Deux-Sèvres	20038A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4419	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Deux-Sèvres	14071N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4533	388	2022-09-07 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Yonne	14037X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4493	152	2018-03-09 00:00:00	2023-03-09 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	09001P	\N	NOMART13CDD	\N	\N	PDT	FAVORABLE	Favorable (29 voix pour, 1 contre)\n	FAVORABLE	Favorable (28 voix pour, 4 contre)\n	FAVORABLE	Favorable (57 voix pour, 5 contre)	2018-02-23 00:00:00	2018-03-07 00:00:00	2018-03-07 00:00:00	\N	\N	\N	2018-03-09 00:00:00	2018-03-09 00:00:00
4500	12	2022-05-09 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19701S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4503	345	2022-05-31 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19515S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4504	386	2022-06-07 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	18083K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4505	330	2022-06-07 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19693L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4508	408	2022-06-10 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Bourgogne-Franche-Comté	19713W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4510	408	2022-06-10 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Centre-Val de Loire	14217N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4511	408	2022-06-10 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Grand Est	11097X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4514	408	2022-06-10 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Guyane	08073C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4515	408	2022-06-10 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Île-de-France	19691J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4516	408	2022-06-10 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	La Réunion	19657G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4517	408	2022-06-10 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Martinique	19295A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4518	408	2022-06-10 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Mayotte	11072N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4520	408	2022-06-10 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Hauts-de-France	01034P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4521	408	2022-06-10 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Pays de la Loire	10006L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4524	339	2022-06-14 00:00:00	2026-06-14 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20248J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4525	24	2022-07-06 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Remplacement de M. Tissot démissionnaire de son mandat.	14257W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4526	67	2022-07-11 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	14042U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4527	67	2022-07-19 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19683J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4230	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Ain	20094J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4231	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Ain	14038Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4232	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Aisne	14026U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4241	401	2022-03-16 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Alpes-Maritimes	19729F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4235	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Aisne	20122U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4239	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Alpes-Maritimes	20136B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4246	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Aube	20050V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4247	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Aube	19745F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4251	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Aveyron	14111D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4253	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Bouches-du-Rhône	17737W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4256	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Calvados	14133K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4258	401	2022-03-16 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Calvados	19735D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4260	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Charente	08060W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4261	401	2022-03-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Charente-Maritime	14213J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4531	180	2022-09-07 00:00:00	2024-01-31 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	04045F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4532	357	2022-09-07 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	Yonne	14037X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4534	401	2022-09-07 00:00:00	2026-09-06 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Yonne	14037X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4535	306	2022-09-12 00:00:00	2025-09-11 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20130U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4539	612	2022-10-11 00:00:00	2023-09-30 00:00:00	SUPPLEANT	ANCIEN	\N	\N	\N	Remplacement de Mme Lherbier.	20038A	2	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4540	2006	2022-10-20 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19503N	\N	OPECST	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4547	158	2017-02-16 00:00:00	2023-02-16 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	000663	\N	NOMART13ETRD	\N	\N	PDT	FAVORABLE	Favorable (17 voix pour, 10 contre, 9 bulletins blancs)\n	FAVORABLE	Favorable (11 voix pour, 6 contre)\n	FAVORABLE	Favorable (28 voix pour, 16 contre)	2017-01-31 00:00:00	2017-02-14 00:00:00	2017-02-14 00:00:00	\N	\N	\N	2017-02-16 00:00:00	2017-02-16 00:00:00
4550	350	2022-12-06 00:00:00	2025-12-06 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19725B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4551	391	2022-12-14 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20048C	\N	COMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4555	34	2023-01-23 00:00:00	2023-09-30 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	20022R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4556	250	2023-01-18 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19399H	\N	COMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4557	99	2023-01-18 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19643A	\N	COMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4586	612	2023-10-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14215L	1	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4587	612	2023-10-17 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	\N	20108W	1	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4588	612	2023-10-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20038A	2	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4589	612	2023-10-17 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	\N	20022R	2	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4590	612	2023-10-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	08045X	3	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4591	612	2023-10-17 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	\N	18193Q	3	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4592	612	2023-10-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14211G	4	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4593	612	2023-10-17 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	\N	21076L	4	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4594	612	2023-10-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	11072N	5	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4595	612	2023-10-17 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	\N	04045F	5	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4596	612	2023-10-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19745F	6	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4597	612	2023-10-17 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	\N	19335Q	6	SCRUTIN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4622	13	2024-01-10 00:00:00	2027-01-10 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19631V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4669	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Vienne	20024T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4670	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Vosges	14033T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4671	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Vosges	20048C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4672	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Yonne	14037X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4673	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Yonne	19749K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4674	388	2024-02-01 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Jura	21047F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4675	388	2024-02-01 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Jura	19479G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4676	388	2024-02-01 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Landes	19489J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4677	388	2024-02-01 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Landes	17779H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4678	388	2024-02-01 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Loir-et-Cher	21052C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4679	388	2024-02-01 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Loir-et-Cher	21053D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4680	388	2024-02-01 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Lot-et-Garonne	19367Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4733	393	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20090E	\N	PDTSEN	\N	\N	AUCUNE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4734	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Côtes-d'Armor	20104S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4735	258	2024-02-12 00:00:00	2027-02-12 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	21083K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4736	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Puy-de-Dôme	21045D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4737	236	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14083S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4738	168	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	12028B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4739	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Loiret	21057H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4740	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Ain	14038Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4741	290	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20264J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4742	245	2024-02-12 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	18083K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4743	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Val-de-Marne	21072G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4744	127	2024-02-12 00:00:00	2027-02-12 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19295A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4745	115	2024-02-12 00:00:00	2027-02-12 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	11027H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4746	272	2024-02-12 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	21034A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4747	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Sarthe	20070A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4748	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Loire	11056N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4749	251	2024-02-12 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14357A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4750	259	2024-02-12 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	18395Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4751	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Loire-Atlantique	11065P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4752	285	2024-02-12 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19693L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4753	359	2024-02-12 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	04008A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4754	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Gironde	19719D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4755	335	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20140W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4756	169	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	17229F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4757	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Somme	17229F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4758	212	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14217N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4759	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Eure-et-Loir	14217N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4760	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Rhône	14215L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4624	366	2024-01-25 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19479G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4710	157	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14133K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4711	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Calvados	14133K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4712	314	2024-02-12 00:00:00	2027-02-12 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	21042A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4713	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	La Réunion	21035B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4714	384	2024-02-12 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19954N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4715	397	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19575F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4716	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Vendée	14030Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4717	81	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20086J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4718	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Morbihan	21050A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4719	72	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	08060W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4720	397	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	08060W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4721	81	2024-02-12 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	\N	20088L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4725	236	2024-02-12 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	21046E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4723	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Gard	20088L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4724	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Drôme	14105F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4726	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Maine-et-Loire	21046E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4727	396	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20114U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4728	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Puy-de-Dôme	19383Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4729	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Pyrénées-Atlantiques	19621T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4730	304	2024-02-12 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	21089R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4731	72	2024-02-12 00:00:00	2027-02-12 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	21063F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4732	199	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19782L	\N	PDTSEN	\N	\N	AUCUNE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4761	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Rhône	20134Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4800	360	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	99004R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4801	389	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	21081H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4802	22	2024-02-12 00:00:00	2029-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	\N	19649G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4803	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Yvelines	19699S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4804	314	2024-02-12 00:00:00	2027-02-12 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19711U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4805	288	2024-02-12 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19711U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4806	115	2024-02-12 00:00:00	2027-02-12 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19709B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4807	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Côtes-d'Armor	18193Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4808	320	2024-02-12 00:00:00	2027-02-12 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	\N	18207D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4809	359	2024-02-12 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	18207D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4810	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Nord	18207D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4811	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Gard	14059S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4812	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Guadeloupe	12016W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4813	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Saône-et-Loire	14147R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4814	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Seine-Saint-Denis	20252E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4815	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Eure	08009T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4816	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Loiret	21058J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4817	259	2024-02-12 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	21054E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4818	282	2024-02-12 00:00:00	2024-03-13 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Démission de Mme Malet de l'OEP	19657G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4819	400	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14031R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4820	196	2024-02-12 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	21075K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4821	288	2024-02-12 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	11085T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4822	161	2024-02-12 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19563B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4823	340	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20018V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4880	395	2024-02-12 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	21056G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4881	357	2024-02-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Bouches-du-Rhône	12028B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4882	357	2024-02-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Bouches-du-Rhône	20108W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4883	357	2024-02-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Côte-d'Or	14205J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4884	357	2024-02-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Côte-d'Or	08061X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4885	357	2024-02-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Hérault	20116W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4886	357	2024-02-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Hérault	20114U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4602	273	2023-11-30 00:00:00	2026-11-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	11027H	\N	COMETRD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4603	292	2023-11-30 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	08056B	\N	COMETRD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4604	292	2023-11-30 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14037X	\N	COMETRD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4887	357	2024-02-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Ille-et-Vilaine	14231L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4888	357	2024-02-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Ille-et-Vilaine	20092G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4889	357	2024-02-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Haut-Rhin	20126Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4890	357	2024-02-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Haut-Rhin	04045F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4892	361	2024-02-19 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19760E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4893	408	2024-02-19 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Hauts-de-France	19760E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4894	357	2024-02-19 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Moselle	19954N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4895	390	2024-02-19 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	21088Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4896	126	2024-02-19 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	\N	14255U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4897	357	2024-02-19 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Seine-Maritime	14053L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4898	357	2024-02-19 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Seine-et-Marne	14329V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4899	408	2024-02-19 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Martinique	19295A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4900	357	2024-02-19 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Pas-de-Calais	19681G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4901	334	2024-02-19 00:00:00	2027-02-19 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	21041Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4902	221	2024-02-19 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19719D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4903	112	2024-02-19 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14327T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4904	112	2024-02-19 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20140W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4905	370	2024-02-19 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	\N	17229F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4906	373	2024-02-19 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	\N	20248J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4907	408	2024-02-19 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Pays de la Loire	14042U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4908	357	2024-02-19 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Seine-et-Marne	11074Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4909	357	2024-02-19 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Pas-de-Calais	20286Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4910	126	2024-02-19 00:00:00	2027-02-19 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	\N	21032X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4911	394	2024-02-19 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	21032X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4912	366	2024-02-19 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14123H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4913	164	2024-02-19 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14026U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4914	357	2024-02-19 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Aisne	14026U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4915	408	2024-02-19 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Île-de-France	19691J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4916	377	2024-02-19 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19553Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4917	399	2024-02-19 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20106U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4918	164	2024-02-19 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19569H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4919	399	2024-02-19 00:00:00	2027-02-19 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19685L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4920	357	2024-02-19 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Bas-Rhin	14073Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4921	385	2024-02-19 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19699S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4922	357	2024-02-19 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Hauts-de-Seine	19711U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4923	112	2024-02-19 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	18207D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4924	164	2024-02-19 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	17779H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4925	408	2024-02-19 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Guadeloupe	12016W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4926	408	2024-02-19 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	La Réunion	19657G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4927	357	2024-02-19 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Hauts-de-Seine	11085T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4928	357	2024-02-19 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Seine-Maritime	19826F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4929	112	2024-02-19 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	21080G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4930	357	2024-02-19 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Haute-Garonne	14223L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4931	408	2024-02-19 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Mayotte	11072N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4932	357	2024-02-19 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Bas-Rhin	20096L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4933	374	2024-02-19 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19573D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4934	408	2024-02-19 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Guyane	08073C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4935	408	2024-02-19 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Auvergne-Rhône-Alpes	19679N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4824	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Vaucluse	04092N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4825	67	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	04092N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4826	109	2024-02-12 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	11072N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4827	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Drôme	14109K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4828	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Eure-et-Loir	08011M	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4829	147	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14071N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4830	180	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14071N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4831	375	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20096L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4832	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Guadeloupe	21097R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4833	180	2024-02-12 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	21097R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4834	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Seine-Saint-Denis	18231D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4835	12	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14169X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4836	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Sarthe	14169X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4837	345	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19768N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4838	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Haute-Savoie	19768N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4839	201	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20050V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4840	330	2024-02-12 00:00:00	2027-02-12 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	21055F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4841	186	2024-02-12 00:00:00	2028-02-12 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	21055F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4842	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Indre-et-Loire	21055F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4843	379	2024-02-12 00:00:00	2029-02-12 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19533U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4844	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Maine-et-Loire	19533U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4845	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Eure	20118Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4854	169	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20150Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4855	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Indre-et-Loire	21056G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4856	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Essonne	21059K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4857	376	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	11045K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4858	24	2024-02-12 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19619A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4859	158	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19421M	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4860	392	2024-02-12 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	11043H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4861	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Val-de-Marne	19687N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4862	172	2024-02-12 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	21079P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4863	272	2024-02-12 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	01058X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4864	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Meurthe-et-Moselle	21049H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4865	245	2024-02-12 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19713W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4866	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Somme	20062A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4867	214	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Remplacement de Mme Poncet-Monge en cours de mandat	21094N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4868	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Vaucluse	20084G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4869	326	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	21095P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4870	399	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20136B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4871	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Alpes-Maritimes	20136B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4872	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Val-d'Oise	19669L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4873	393	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14275Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4874	386	2024-02-12 00:00:00	2027-02-12 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	21061D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4875	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Charente-Maritime	20064C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4876	104	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20058E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4877	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Nord	19585H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4878	49	2024-02-12 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	21077M	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4879	333	2024-02-12 00:00:00	2027-02-12 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	21077M	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4936	357	2024-02-19 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Haute-Garonne	14225N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4937	112	2024-02-19 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20082E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4938	408	2024-02-19 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Grand Est	21064G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4939	357	2024-02-19 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Moselle	21082J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4940	357	2024-02-19 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Aisne	20122U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4941	112	2024-02-19 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14107H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4942	112	2024-02-19 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19619A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4581	124	2023-06-07 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20248J	\N	COMSOCI	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4605	167	2023-12-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20138D	\N	COMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4606	99	2023-12-12 00:00:00	2028-12-12 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19611R	\N	COMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4607	250	2023-12-12 00:00:00	2028-12-12 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19954N	\N	COMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4608	341	2023-12-12 00:00:00	2028-12-12 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19621T	\N	COMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4609	313	2023-12-12 00:00:00	2028-12-12 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19621T	\N	COMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4610	300	2023-12-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14229S	\N	COMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4611	317	2023-12-12 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19697Q	\N	COMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4612	313	2023-12-12 00:00:00	2028-12-12 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	21059K	\N	COMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4613	274	2023-12-16 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20048C	\N	COMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4681	388	2024-02-01 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Lot-et-Garonne	21040X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4682	388	2024-02-01 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Martinique	21096Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4683	388	2024-02-01 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Martinique	19295A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4684	388	2024-02-01 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Mayenne	18083K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4685	388	2024-02-01 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Mayenne	14042U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4686	388	2024-02-01 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Orne	21043B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4687	388	2024-02-01 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Orne	07004J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4688	388	2024-02-01 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Pyrénées-Orientales	19703U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4689	388	2024-02-01 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Pyrénées-Orientales	21044C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4690	401	2024-02-01 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Jura	21047F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4691	401	2024-02-01 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Jura	19479G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4692	401	2024-02-01 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Landes	19489J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4693	401	2024-02-01 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Landes	17779H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4694	401	2024-02-01 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Loir-et-Cher	21052C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4695	401	2024-02-01 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Loir-et-Cher	21053D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4696	401	2024-02-01 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Lot-et-Garonne	19367Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4697	401	2024-02-01 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Lot-et-Garonne	21040X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4698	401	2024-02-01 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Martinique	21096Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4699	401	2024-02-01 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Martinique	19295A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4700	401	2024-02-01 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Mayenne	18083K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4701	401	2024-02-01 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Mayenne	14042U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4702	401	2024-02-01 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Orne	21043B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4703	401	2024-02-01 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Orne	07004J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4704	401	2024-02-01 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Pyrénées-Orientales	21044C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4705	401	2024-02-01 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Pyrénées-Orientales	19703U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4846	323	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20118Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4847	320	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	05012A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4848	363	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	11090Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4849	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Yvelines	11090Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4850	67	2024-02-12 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19679N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4851	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Isère	19679N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4852	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Vendée	04033B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4853	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Loire	21068L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4891	372	2024-02-19 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	21042A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4943	361	2024-02-19 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19703U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4944	408	2024-02-19 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Occitanie	19703U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4945	408	2024-02-19 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Bourgogne-Franche-Comté	19713W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4946	164	2024-02-19 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	01034P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4947	357	2024-03-04 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Marne	21063F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4948	357	2024-03-04 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Marne	21065H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4949	388	2024-03-04 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Marne	21065H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4950	388	2024-03-04 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Marne	21064G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4574	314	2023-05-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	11048N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4575	314	2023-05-17 00:00:00	2026-05-17 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19820Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4576	120	2023-05-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	08060W	\N	PDTSEN	\N	\N	AUCUNE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4577	409	2023-05-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19575F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4578	409	2023-05-17 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14225N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4579	409	2023-05-17 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19479G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4601	13	2023-11-13 00:00:00	2026-11-13 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19667J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4706	34	2024-02-02 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20022R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4707	34	2024-02-02 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20044X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4708	34	2024-02-02 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	\N	19479G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4709	34	2024-02-02 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	\N	14225N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4762	147	2024-02-12 00:00:00	2027-02-12 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14042U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4763	67	2024-02-12 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14042U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4764	389	2024-02-12 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	\N	20040T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4765	49	2024-02-12 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	07033P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4766	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Var	20074E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4767	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Saône-et-Loire	14151M	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4768	356	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14249W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4769	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Pyrénées-Atlantiques	11110B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4770	243	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14187A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4771	333	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14187A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4772	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Alpes-Maritimes	14187A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4773	343	2024-02-12 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19673G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4774	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Val-d'Oise	19673G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4775	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Manche	21062E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4776	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Calvados	14281W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4777	128	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	08045X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4778	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Finistère	08045X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4779	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	La Réunion	21033Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4780	387	2024-02-12 00:00:00	2029-02-12 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20286Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4781	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Loire-Atlantique	20172F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4782	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Gironde	19820Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4783	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Isère	19347U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4784	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Manche	20180F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4785	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Ain	08056B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4786	320	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14231L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4787	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Doubs	14123H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4788	128	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14026U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4789	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Essonne	19691J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4790	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Var	20072C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4791	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Finistère	20106U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4792	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Haute-Savoie	14179A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4793	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Meurthe-et-Moselle	11048N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4794	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Charente-Maritime	14213J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4795	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Doubs	20066E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4796	67	2024-02-12 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19683J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4797	22	2024-02-12 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	21044C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4798	395	2024-02-12 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19447X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4799	357	2024-02-12 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Morbihan	19447X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4583	313	2023-06-28 00:00:00	2023-10-01 00:00:00	TITULAIRE	ANCIEN	\N	\N	\N	\N	19621T	\N	COMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4600	342	2023-11-06 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	21067K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4614	2000	2023-12-12 00:00:00	2028-12-12 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19563B	\N	OPECST	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4618	95	2023-12-26 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	21035B	\N	COMCDD	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4619	317	2023-12-26 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20056C	\N	COMAFCL	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4625	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Jura	21047F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4626	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Jura	19479G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4627	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Landes	19489J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4628	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Landes	17779H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4629	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Loir-et-Cher	21052C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4630	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Loir-et-Cher	21053D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4631	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Lot-et-Garonne	19367Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4632	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Lot-et-Garonne	21040X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4633	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Martinique	21096Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4634	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Martinique	19295A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4635	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Mayenne	18083K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4636	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Mayenne	14042U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4637	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Orne	21043B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4638	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Orne	07004J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4639	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Pyrénées-Orientales	21044C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4640	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Pyrénées-Orientales	19703U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4641	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Allier	14251Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4642	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Allier	20020P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4643	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Ardèche	14259Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4644	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Ardèche	20026V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4645	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Ardennes	20056C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4646	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Ardennes	07029T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4647	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Aube	20050V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4648	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Aube	19745F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4649	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Aude	14097Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4650	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Aude	20030R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4651	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Aveyron	20032T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4652	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Aveyron	14111D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4653	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Charente	20042V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4654	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Charente	08060W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4655	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Cher	05012A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4656	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Cher	19798U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4657	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Deux-Sèvres	20038A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4658	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Deux-Sèvres	14071N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4659	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Dordogne	20028X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4660	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Dordogne	20046A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4661	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Haute-Vienne	20080C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4662	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Haute-Vienne	20082E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4663	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Polynésie française	20150Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4664	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Polynésie française	14275Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4665	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Savoie	19575F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4666	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Savoie	20058E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4667	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Tarn	14089Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4668	357	2024-02-01 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Tarn	17023S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4955	95	2024-03-08 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	21034A	\N	COMCAE	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4956	95	2024-03-08 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19383Y	\N	COMCAE	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4957	317	2024-03-08 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19768N	\N	COMCAE	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5093	401	2024-03-11 00:00:00	2029-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Pyrénées-Atlantiques	19619A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5094	401	2024-03-11 00:00:00	2029-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Loiret	19421M	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5095	401	2024-03-11 00:00:00	2029-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Isère	11043H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5096	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Val-de-Marne	19687N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5097	401	2024-03-11 00:00:00	2029-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Val-de-Marne	19687N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5098	401	2024-03-11 00:00:00	2029-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Yvelines	21079P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5099	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Meurthe-et-Moselle	21049H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5100	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Val-d'Oise	19669L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5101	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Val-d'Oise	19669L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5102	401	2024-03-11 00:00:00	2029-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Guadeloupe	19301E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5103	401	2024-03-11 00:00:00	2029-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Loire	19413M	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5104	401	2024-03-11 00:00:00	2029-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Morbihan	21051B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5105	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Oise	21061D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5106	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Oise	21061D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5107	401	2024-03-11 00:00:00	2029-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Seine-et-Marne	21076L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5108	264	2024-03-11 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20058E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5114	282	2024-03-20 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20034V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5115	408	2024-03-20 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Nouvelle Aquitaine	19723Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5118	42	2024-03-30 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14151M	\N	PDTSEN	\N	\N	AUCUNE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5119	42	2024-03-30 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	04070G	\N	PDTSEN	\N	\N	AUCUNE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5120	176	2024-03-30 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	21052C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5121	176	2024-03-30 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19685L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5122	411	2024-04-03 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20042V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5123	411	2024-04-03 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14097Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5127	29	2024-04-11 00:00:00	2029-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	\N	11065P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5128	73	2024-04-11 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20130U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5129	160	2024-04-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19347U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5130	160	2024-04-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19565D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5131	296	2024-04-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	21073H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5132	378	2024-04-11 00:00:00	2026-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	\N	20142Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5133	409	2024-04-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	21048G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4951	401	2024-03-04 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Marne	21065H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4952	401	2024-03-04 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Marne	21064G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4953	401	2024-03-04 00:00:00	2029-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Marne	21063F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4958	194	2024-03-11 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	21071F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4959	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Pas-de-Calais	19760E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4960	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Pas-de-Calais	19760E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4961	401	2024-03-11 00:00:00	2029-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Manche	05008E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4962	401	2024-03-11 00:00:00	2029-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Val-d'Oise	19667J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4963	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	La Réunion	21035B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4964	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	La Réunion	21035B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4965	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Moselle	19954N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4966	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Moselle	19954N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4967	401	2024-03-11 00:00:00	2029-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Maine-et-Loire	21048G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4968	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Morbihan	21050A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4969	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Morbihan	21050A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4970	318	2024-03-11 00:00:00	2027-03-11 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	21046E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4971	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Maine-et-Loire	21046E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4972	401	2024-03-11 00:00:00	2029-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Maine-et-Loire	21046E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4973	401	2024-03-11 00:00:00	2029-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Puy-de-Dôme	19383Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4974	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Pyrénées-Atlantiques	19621T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4975	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Pyrénées-Atlantiques	19621T	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4976	401	2024-03-11 00:00:00	2029-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Paris	21088Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4977	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Nord	21083K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4978	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Val-de-Marne	04042C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4979	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Puy-de-Dôme	21045D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4980	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Puy-de-Dôme	21045D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4981	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Maine-et-Loire	19545Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4982	213	2024-03-11 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20060X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4983	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Loiret	21057H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4984	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Loiret	21057H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4985	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Seine-et-Marne	14329V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4986	194	2024-03-11 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14195A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4987	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Yvelines	19701S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4988	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Val-de-Marne	21072G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4989	401	2024-03-11 00:00:00	2029-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Val-de-Marne	21072G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4990	401	2024-03-11 00:00:00	2029-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	La Réunion	21034A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4991	401	2024-03-11 00:00:00	2029-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Oise	11115U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4992	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Loire	11056N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4993	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Loire	11056N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4994	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Seine-et-Marne	14357A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4995	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Seine-et-Marne	14357A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4996	401	2024-03-11 00:00:00	2029-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Loire-Atlantique	18395Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4997	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Loire-Atlantique	11065P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4998	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Loire-Atlantique	11065P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
4999	108	2024-03-11 00:00:00	2028-03-11 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	\N	19693L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5000	401	2024-03-11 00:00:00	2029-09-23 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Essonne	19693L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5001	401	2024-03-11 00:00:00	2029-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Pas-de-Calais	21067K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5002	401	2024-03-11 00:00:00	2029-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Nord	04008A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5003	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Pyrénées-Atlantiques	11110B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5004	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Pyrénées-Atlantiques	11110B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5005	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Val-d'Oise	19673G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5006	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Val-d'Oise	19673G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5007	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Paris	21091K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5008	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Manche	21062E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5009	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Manche	21062E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5010	401	2024-03-11 00:00:00	2029-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Val-d'Oise	21086N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5011	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Paris	19647E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5012	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Hauts-de-Seine	19111A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5013	401	2024-03-11 00:00:00	2029-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Hauts-de-Seine	19111A	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5014	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	La Réunion	21033Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5015	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	La Réunion	21033Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5016	401	2024-03-11 00:00:00	2029-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Pas-de-Calais	20286Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5017	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Loire-Atlantique	20172F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5018	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Loire-Atlantique	20172F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5019	401	2024-03-11 00:00:00	2029-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Seine-Saint-Denis	19695N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5020	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Puy-de-Dôme	19387D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5021	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Puy-de-Dôme	19387D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5022	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Isère	19347U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5023	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Isère	19347U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5024	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Manche	20180F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5025	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Manche	20180F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5026	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Nord	19565D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5027	401	2024-03-11 00:00:00	2029-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Nord	19565D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5028	401	2024-03-11 00:00:00	2029-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Loire-Atlantique	21066J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5029	401	2024-03-11 00:00:00	2029-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Paris	21092L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5030	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Essonne	19691J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5031	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Essonne	19691J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5032	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Meurthe-et-Moselle	19553Y	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5033	401	2024-03-11 00:00:00	2029-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Moselle	19685L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5034	401	2024-03-11 00:00:00	2029-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Essonne	19399H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5035	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Meurthe-et-Moselle	11048N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5036	401	2024-03-11 00:00:00	2029-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Meurthe-et-Moselle	11048N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5037	194	2024-03-11 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14213J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5038	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Meurthe-et-Moselle	19551W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5039	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Morbihan	19447X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5040	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Morbihan	19447X	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5041	401	2024-03-11 00:00:00	2029-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Hauts-de-Seine	99004R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5042	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Hauts-de-Seine	99004R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5043	318	2024-03-11 00:00:00	2027-03-11 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	21078N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5044	401	2024-03-11 00:00:00	2029-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Seine-Saint-Denis	21078N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5045	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Yvelines	19699S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5046	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Yvelines	19699S	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5047	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Hauts-de-Seine	19711U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5048	264	2024-03-11 00:00:00	2027-03-11 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	21087P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5049	401	2024-03-11 00:00:00	2029-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Yvelines	19697Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5050	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Nord	18207D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5051	401	2024-03-11 00:00:00	2029-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Indre-et-Loire	21054E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5052	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Guadeloupe	12016W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5053	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Guadeloupe	12016W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5054	213	2024-03-11 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19866P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5055	401	2024-03-11 00:00:00	2029-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	La Réunion	19657G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5056	401	2024-03-11 00:00:00	2029-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Seine-et-Marne	21075K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5057	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Loiret	21058J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5058	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Seine-Saint-Denis	20252E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5059	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Moselle	19335Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5060	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Guadeloupe	21097R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5061	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Seine-Saint-Denis	18231D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5062	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Oise	21060C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5063	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Hauts-de-Seine	19593H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5064	401	2024-03-11 00:00:00	2029-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Oise	19573D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5065	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Seine-et-Marne	21075K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5066	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Loiret	21058J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5067	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Seine-Saint-Denis	20252E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5068	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Guadeloupe	21097R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5069	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Seine-Saint-Denis	18231D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5070	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Oise	21060C	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5071	200	2024-03-11 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20050V	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5072	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Indre-et-Loire	21055F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5073	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Indre-et-Loire	21055F	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5074	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Maine-et-Loire	19533U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5075	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Maine-et-Loire	19533U	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5076	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Yvelines	11090Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5077	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Isère	19679N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5078	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Isère	19679N	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5079	401	2024-03-11 00:00:00	2029-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Isère	19349W	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5080	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Pas-de-Calais	14331P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5081	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Pas-de-Calais	14331P	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5082	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Loire	21068L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5083	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Loire	21068L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5084	401	2024-03-11 00:00:00	2029-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Loire	21070E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5085	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Indre-et-Loire	21056G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5086	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Indre-et-Loire	21056G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5087	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Essonne	21059K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5088	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Essonne	21059K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5089	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Val-de-Marne	11045K	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5090	401	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Nord	19585H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5091	401	2024-03-11 00:00:00	2029-09-30 00:00:00	SUPPLEANT	ACTIF	\N	\N	\N	Moselle	21082J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5092	388	2024-03-11 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Moselle	21082J	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5109	398	2024-03-15 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	21088Q	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5110	398	2024-03-15 00:00:00	2029-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	21054E	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5111	398	2024-03-15 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19725B	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5112	412	2024-03-15 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	20022R	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5113	412	2024-03-15 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	14151M	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5116	357	2024-03-25 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Oise	19573D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5117	357	2024-03-25 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	Oise	21061D	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5124	299	2024-04-08 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	19758L	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5125	299	2024-04-08 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	21064G	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
5126	299	2024-04-08 00:00:00	2026-09-30 00:00:00	TITULAIRE	ACTIF	\N	\N	\N	\N	21081H	\N	PDTSEN	\N	\N	MEMBRE	NON_APPLICABLE	\N	NON_APPLICABLE	\N	NON_APPLICABLE	\N	\N	\N	\N	\N	\N	\N	\N	\N
\.


--
-- Data for Name: memgrppol; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY memgrppol (memgrppolid, grppolcod, typapppolcod, memgrppoldatdeb, memgrppoldatfin, temvalcod, evelic, evelib, evelil, eveobs, senmat, syscredat, sysmajdat) FROM stdin;
269	SOC	N	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	97009N	\N	\N
271	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	95051G	\N	\N
272	RI	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	95042F	\N	\N
273	RI	N	\N	2002-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	95031C	\N	\N
274	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	86035F	\N	\N
276	SOC	N	1995-10-01 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	95037J	\N	2017-06-29 09:54:19
277	RPR	N	1987-09-30 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	87003B	\N	\N
278	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	86041D	\N	\N
279	NI	N	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95021A	\N	2014-09-28 16:40:50
280	UC	N	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	87002A	\N	\N
282	RI	N	\N	2002-06-06 00:00:00	ANCIEN	\N	\N	\N	\N	95059Q	\N	\N
283	SOC	N	1990-10-02 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	90004C	\N	2014-09-28 13:21:47
284	SOC	N	1995-10-02 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95055L	\N	2014-09-28 13:21:47
285	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	77058M	\N	\N
286	RPR	A	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	95012Y	\N	\N
287	UC	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	95033E	\N	\N
288	RI	N	1986-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	86044G	\N	2014-10-09 09:08:15
289	RI	A	\N	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	95004Y	\N	\N
290	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	86034E	\N	\N
291	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	95035G	\N	\N
292	SOC	N	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86011W	\N	\N
293	RPR	A	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	95013A	\N	\N
294	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	95050F	\N	\N
295	SOC	A	\N	2002-09-09 00:00:00	ANCIEN	\N	\N	\N	\N	95043G	\N	\N
296	RDSE	N	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89035T	\N	\N
297	SOC	A	\N	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	86021Y	\N	\N
298	SOC	A	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95044H	\N	\N
299	RDSE	N	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98002K	\N	\N
300	RPR	N	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95002W	\N	\N
301	CRC	N	\N	2004-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	96003C	\N	\N
302	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	92033R	\N	\N
303	UC	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77001T	\N	\N
304	UC	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98004M	\N	\N
305	UC	N	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77028F	\N	\N
306	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	95061J	\N	\N
307	NI	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	69001W	\N	\N
308	RI	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98001J	\N	\N
309	SOC	N	\N	2001-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	89021M	\N	\N
310	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	89023P	\N	\N
311	RPR	N	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	74019R	\N	\N
312	UC	R	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	77002U	\N	\N
313	SOC	N	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92008Q	\N	\N
314	NI	N	\N	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	92034S	\N	\N
315	NI	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	90002A	\N	\N
316	RPR	N	\N	2000-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	74032N	\N	\N
317	UC	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	86050E	\N	\N
318	SOC	N	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86042E	\N	\N
319	AUCUN	N	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	98005N	\N	\N
321	AUCUN	N	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	98007Q	\N	\N
322	SOC	N	1998-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98006P	\N	2014-09-28 12:54:15
323	AUCUN	N	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	98008R	\N	\N
324	AUCUN	N	1998-09-28 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	98009S	\N	\N
325	AUCUN	N	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	98010K	\N	\N
326	AUCUN	N	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	98011L	\N	\N
327	AUCUN	N	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	98012M	\N	\N
328	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	98013N	\N	\N
329	UC	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	98014P	\N	\N
330	AUCUN	N	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	98015Q	\N	\N
331	RI	N	1989-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	89029V	\N	\N
332	CRC	N	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98016R	\N	\N
333	RPR	N	1998-10-01 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	98017S	\N	\N
334	AUCUN	N	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	98018T	\N	\N
335	RI	N	1998-10-01 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	98019U	\N	\N
336	SOC	N	1998-10-01 00:00:00	2004-12-23 00:00:00	ANCIEN	\N	\N	\N	\N	98020M	\N	\N
339	AUCUN	N	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	98022P	\N	\N
338	AUCUN	N	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	98021N	\N	\N
340	RPR	N	1998-10-01 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	98023Q	\N	\N
341	UC	N	1998-10-01 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	98024R	\N	\N
342	AUCUN	N	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	98025S	\N	\N
343	AUCUN	N	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	98026T	\N	\N
344	AUCUN	N	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	98027U	\N	\N
345	AUCUN	N	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	98028V	\N	\N
346	SOC	N	1998-10-01 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	98029W	\N	2017-06-29 09:53:37
347	SOC	N	1998-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98030P	\N	2014-09-28 13:19:48
348	AUCUN	N	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	80024B	\N	\N
349	RPR	R	1998-10-05 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	98031Q	\N	\N
350	AUCUN	N	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	98032R	\N	\N
351	AUCUN	N	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	98033S	\N	\N
352	AUCUN	N	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	98034T	\N	\N
353	AUCUN	N	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	98035U	\N	\N
354	RPR	N	1998-10-01 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	98036V	\N	\N
355	AUCUN	N	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	66002K	\N	\N
356	AUCUN	N	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	98037W	\N	\N
357	AUCUN	N	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	98038X	\N	\N
358	AUCUN	N	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	98039Y	\N	\N
359	AUCUN	N	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	98040R	\N	\N
360	RI	N	1998-10-01 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	98041S	\N	\N
361	RI	N	1998-10-01 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	98042T	\N	\N
362	AUCUN	N	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	98043U	\N	\N
363	AUCUN	N	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	98044V	\N	\N
364	RPR	N	1998-10-01 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	98045W	\N	\N
365	AUCUN	N	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	98046X	\N	\N
366	UC	N	1998-10-01 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	98047Y	\N	\N
367	RPR	N	1998-10-01 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	98048A	\N	\N
368	AUCUN	N	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	98049B	\N	\N
369	AUCUN	N	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	98050T	\N	\N
370	AUCUN	N	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	98051U	\N	\N
371	AUCUN	N	\N	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	98052V	\N	\N
372	NI	N	1998-10-03 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	98053W	\N	\N
373	RDSE	N	1998-10-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98032R	\N	\N
374	RDSE	N	1998-10-05 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	66002K	\N	\N
375	RDSE	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	78003A	\N	\N
376	RI	N	1998-10-05 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	98028V	\N	\N
377	RI	N	1998-10-05 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	98021N	\N	\N
378	RI	N	1998-10-05 00:00:00	2002-01-15 00:00:00	ANCIEN	\N	\N	\N	\N	98050T	\N	\N
379	RPR	N	1998-10-05 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	90003B	\N	\N
380	RPR	N	1998-10-05 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	98052V	\N	\N
381	RPR	N	1998-10-05 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	98025S	\N	\N
382	RPR	N	1998-10-05 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	98007Q	\N	\N
383	RPR	N	1998-10-05 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	98008R	\N	\N
384	RPR	N	1998-10-05 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	98039Y	\N	\N
385	RPR	N	1998-10-05 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98026T	\N	\N
386	AUCUN	N	1998-10-01 00:00:00	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	98031Q	\N	\N
387	RPR	R	1998-10-05 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	98018T	\N	\N
388	RPR	R	1998-10-05 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	98005N	\N	\N
389	RPR	R	1998-10-05 00:00:00	2001-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	98033S	\N	\N
390	SOC	N	1998-10-05 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98011L	\N	2014-09-28 17:27:34
391	SOC	N	1998-10-05 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98049B	\N	\N
392	SOC	N	1998-10-05 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98009S	\N	\N
393	SOC	N	1998-10-05 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	98022P	\N	2014-10-07 17:17:30
394	SOC	N	1998-10-05 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98034T	\N	\N
395	SOC	N	1998-10-05 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98051U	\N	\N
396	SOC	N	1998-10-05 00:00:00	2009-09-09 00:00:00	ANCIEN	\N	\N	\N	\N	80024B	\N	\N
397	SOC	N	1998-10-05 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	98046X	\N	2017-09-25 09:56:00
398	SOC	N	1998-10-05 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98015Q	\N	\N
400	SOC	N	1998-10-05 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98010K	\N	\N
401	SOC	N	1998-10-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98035U	\N	\N
402	SOC	N	1998-10-05 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98037W	\N	2014-09-28 14:31:42
403	SOC	N	1998-10-05 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	98012M	\N	\N
404	UC	N	1998-10-05 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	95009E	\N	\N
405	UC	R	1998-10-05 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92034S	\N	\N
406	UC	N	1998-10-05 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	98027U	\N	\N
407	UC	N	1998-10-05 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98044V	\N	\N
408	RPR	N	1998-10-05 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	98040R	\N	\N
409	NI	N	1998-10-05 00:00:00	1999-05-12 00:00:00	ANCIEN	\N	\N	\N	\N	80015A	\N	\N
410	CRC	N	1998-10-05 00:00:00	2018-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	98053W	\N	2018-05-31 10:52:17
411	CRC	N	1998-10-05 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98038X	\N	2014-09-28 17:38:26
412	RDSE	N	1998-10-08 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	77019E	\N	\N
413	RDSE	N	1998-10-08 00:00:00	1998-10-08 00:00:00	ANCIEN	\N	\N	\N	\N	89041R	\N	\N
414	NI	N	1998-10-09 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	89041R	\N	\N
415	NI	N	1998-11-03 00:00:00	1998-11-09 00:00:00	ANCIEN	\N	\N	\N	\N	98054X	\N	\N
416	SOC	N	1998-11-09 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98054X	\N	\N
417	RDSE	N	1999-05-12 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80015A	\N	\N
418	NI	N	1999-10-17 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	99001N	\N	\N
419	SOC	N	1999-11-02 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	99002P	\N	2017-06-19 12:20:21
420	NI	N	1999-11-14 00:00:00	1999-11-15 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	\N	\N
421	RPR	N	1995-11-02 00:00:00	1997-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	\N	\N
422	RPR	N	1999-11-16 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	\N	\N
423	NI	N	1999-11-28 00:00:00	1999-12-09 00:00:00	ANCIEN	\N	\N	\N	\N	99003Q	\N	\N
424	RPR	R	1999-12-09 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	99003Q	\N	\N
425	NI	N	1999-12-17 00:00:00	1999-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	99004R	\N	\N
427	RPR	R	2000-01-27 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83043S	\N	\N
428	RPR	R	2000-01-27 00:00:00	2001-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	74032N	\N	\N
429	NI	N	2000-01-28 00:00:00	2000-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	00001A	\N	\N
430	CRC	N	2000-02-04 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	00001A	\N	\N
431	NI	N	2000-03-19 00:00:00	2000-03-24 00:00:00	ANCIEN	\N	\N	\N	\N	93007T	\N	\N
432	RPR	N	2000-03-24 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	93007T	\N	\N
433	NI	N	2000-03-29 00:00:00	2000-04-03 00:00:00	ANCIEN	\N	\N	\N	\N	00002B	\N	\N
434	CRC	N	2000-04-03 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	00002B	\N	\N
435	NI	N	2000-04-28 00:00:00	2000-05-02 00:00:00	ANCIEN	\N	\N	\N	\N	00003C	\N	\N
436	SOC	N	2000-05-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	00003C	\N	2017-09-24 18:05:40
437	NI	N	2000-04-29 00:00:00	2000-05-17 00:00:00	ANCIEN	\N	\N	\N	\N	00004D	\N	\N
438	RPR	A	2000-05-17 00:00:00	2001-08-29 00:00:00	ANCIEN	\N	\N	\N	\N	00004D	\N	\N
439	NI	N	2001-01-17 00:00:00	2001-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	01001E	\N	\N
440	RPR	N	2001-01-18 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	01001E	\N	\N
441	NI	N	2001-02-08 00:00:00	2001-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	01002F	\N	\N
442	RDSE	N	2001-02-13 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01002F	\N	\N
443	NI	N	2001-03-03 00:00:00	2001-03-19 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	\N	\N
502	RDSE	N	2001-03-20 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	01003G	\N	2017-05-16 15:18:13
504	SOC	N	2001-03-28 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01004H	\N	\N
506	RPR	N	2001-08-29 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	00004D	\N	\N
507	NI	N	2001-08-23 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89004L	\N	\N
509	CRC	N	2001-09-04 00:00:00	2005-03-17 00:00:00	ANCIEN	\N	\N	\N	\N	89021M	\N	\N
512	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01005J	\N	\N
513	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01006K	\N	\N
514	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01007L	\N	2017-10-03 17:35:01
515	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01008M	\N	\N
516	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01009N	\N	\N
517	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01010F	\N	\N
518	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01011G	\N	\N
519	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01012H	\N	\N
520	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01013J	\N	\N
521	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01014K	\N	\N
522	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01015L	\N	\N
523	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	\N	\N
524	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01017N	\N	\N
525	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01018P	\N	\N
526	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01019Q	\N	\N
527	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01020H	\N	\N
528	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01021J	\N	\N
529	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01022K	\N	\N
530	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01023L	\N	\N
531	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01024M	\N	\N
532	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01025N	\N	\N
533	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01026P	\N	\N
534	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01027Q	\N	\N
535	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	\N	\N
536	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01029S	\N	\N
537	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01030K	\N	\N
538	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	\N	\N
539	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01032M	\N	\N
540	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01033N	\N	\N
541	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01034P	\N	\N
542	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01035Q	\N	\N
543	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01036R	\N	\N
544	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01037S	\N	\N
545	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01038T	\N	\N
546	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01039U	\N	\N
547	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01040M	\N	\N
548	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01041N	\N	\N
167	CRC	N	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	97006K	\N	\N
549	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01042P	\N	\N
550	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01043Q	\N	\N
552	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01044R	\N	\N
553	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01045S	\N	\N
554	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	\N	\N
555	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	\N	\N
556	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01048V	\N	\N
557	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01049W	\N	\N
558	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01050P	\N	\N
559	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01051Q	\N	\N
1	RI	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	89016Q	\N	\N
2	RI	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	89027T	\N	\N
3	RDSE	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	88005H	\N	\N
4	RPR	N	1998-10-05 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	98043U	\N	\N
5	RPR	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	71006X	\N	\N
6	UC	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	71009B	\N	\N
7	UC	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	89018S	\N	\N
8	SOC	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80043E	\N	\N
9	UC	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	89006N	\N	\N
10	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	88012G	\N	\N
11	RPR	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89046W	\N	\N
12	RI	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	84004P	\N	\N
13	RDSE	N	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	85003S	\N	\N
14	RI	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	80045G	\N	\N
15	RPR	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80021X	\N	\N
16	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	96005E	\N	\N
17	UC	N	\N	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	71003U	\N	\N
18	SOC	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80004W	\N	\N
19	NI	N	\N	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89017R	\N	2017-10-03 17:27:53
20	RPR	A	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	94003T	\N	\N
21	SOC	N	\N	2006-08-11 00:00:00	ANCIEN	\N	\N	\N	\N	74050Q	\N	\N
22	SOC	N	1980-10-02 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80013X	\N	\N
23	RI	N	\N	1998-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	89041R	\N	\N
24	RI	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	80035E	\N	\N
25	SOC	N	\N	2008-09-07 00:00:00	ANCIEN	\N	\N	\N	\N	80017C	\N	\N
26	CRC	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	78010Y	\N	\N
27	RPR	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89024Q	\N	\N
28	RDSE	N	2004-10-05 00:00:00	2004-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	89042S	\N	\N
29	RDSE	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89044U	\N	\N
30	UC	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89039X	\N	\N
31	SOC	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89036U	\N	\N
32	NI	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95068R	\N	\N
33	RI	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	71018C	\N	\N
34	RI	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	70001N	\N	\N
35	RI	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	89007P	\N	\N
36	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	89010J	\N	\N
37	RPR	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89038W	\N	\N
38	RPR	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80002U	\N	\N
39	UC	N	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	96008H	\N	\N
40	UC	R	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	89013M	\N	\N
41	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	89014N	\N	\N
42	UC	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89012L	\N	\N
43	UC	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	71017B	\N	\N
44	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	89045V	\N	\N
45	RDSE	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	80031A	\N	\N
46	RPR	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80007A	\N	\N
47	RI	N	\N	2001-09-20 00:00:00	ANCIEN	\N	\N	\N	\N	94002S	\N	\N
705	UMP	N	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95024D	\N	\N
707	UMP	N	2002-12-11 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95047L	\N	2014-09-28 17:09:16
708	UMP	N	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	88013H	\N	\N
709	UMP	N	2002-12-11 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	95051G	\N	\N
710	UMP	N	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86035F	\N	\N
711	UMP	N	2002-12-11 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	87003B	\N	2014-09-28 17:35:38
712	UMP	N	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86041D	\N	\N
713	UMP	N	2002-12-11 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77058M	\N	2014-09-28 12:52:11
714	UMP	A	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95012Y	\N	\N
715	UMP	N	2002-12-11 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	86034E	\N	\N
716	UMP	N	2002-12-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	95035G	\N	2017-09-24 18:17:56
717	UMP	N	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95013A	\N	\N
718	UMP	N	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95050F	\N	\N
719	UMP	N	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92033R	\N	\N
720	UMP	N	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95061J	\N	\N
721	UMP	N	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89023P	\N	\N
722	UMP	N	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98013N	\N	\N
723	UMP	N	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98017S	\N	\N
724	UMP	A	2002-12-11 00:00:00	2018-12-30 00:00:00	ANCIEN	\N	\N	\N	\N	98023Q	\N	2017-10-03 17:31:58
725	UMP	N	2002-12-11 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98036V	\N	2014-09-28 17:15:42
726	UMP	N	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98045W	\N	\N
727	UMP	N	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98048A	\N	\N
728	UMP	N	2002-12-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	90003B	\N	2017-10-01 10:01:39
729	UMP	N	2002-12-11 00:00:00	2008-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	98052V	\N	\N
730	UMP	N	2002-12-11 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	98025S	\N	\N
731	UMP	N	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98007Q	\N	\N
732	UMP	N	2002-12-11 00:00:00	2005-03-19 00:00:00	ANCIEN	\N	\N	\N	\N	98008R	\N	\N
733	UMP	N	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98039Y	\N	\N
734	UMP	R	2002-12-11 00:00:00	2003-01-14 00:00:00	ANCIEN	\N	\N	\N	\N	98018T	\N	\N
735	UMP	R	2002-12-11 00:00:00	2018-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	98005N	\N	\N
736	UMP	N	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98040R	\N	\N
737	UMP	N	2002-12-11 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95067Q	\N	\N
738	UMP	N	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	99003Q	\N	\N
739	UMP	N	2002-12-11 00:00:00	2007-06-24 00:00:00	ANCIEN	\N	\N	\N	\N	99004R	\N	\N
740	UMP	N	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	93007T	\N	\N
741	UMP	N	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01001E	\N	\N
742	UMP	N	2002-12-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01008M	\N	2017-09-24 13:44:49
743	UMP	N	2002-12-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01027Q	\N	2017-09-24 17:28:55
744	UMP	R	2002-12-11 00:00:00	2003-01-14 00:00:00	ANCIEN	\N	\N	\N	\N	01041N	\N	\N
745	UMP	N	2002-12-11 00:00:00	2010-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	01026P	\N	\N
746	UMP	N	2002-12-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01057W	\N	\N
747	UMP	N	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01040M	\N	\N
748	UMP	N	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01018P	\N	\N
749	UMP	N	2002-12-11 00:00:00	2015-04-21 00:00:00	ANCIEN	\N	\N	\N	\N	01042P	\N	2015-04-21 17:14:30
750	UMP	N	2002-12-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01061S	\N	2017-09-24 17:48:21
752	UMP	N	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01029S	\N	\N
753	UMP	N	2002-12-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01058X	\N	\N
754	UMP	N	2002-12-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01056V	\N	2017-09-24 17:04:02
755	UMP	N	2002-12-11 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	01063U	\N	2014-09-29 13:41:53
756	UMP	N	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98033S	\N	\N
757	UMP	N	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	02003L	\N	\N
758	UMP	N	2002-12-11 00:00:00	2002-12-19 00:00:00	ANCIEN	\N	\N	\N	\N	02007Q	\N	\N
759	UMP	N	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	59312E	\N	\N
124	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	78006D	\N	\N
158	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	83050R	\N	\N
181	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	92024Q	\N	\N
193	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	77013X	\N	\N
760	UMP	N	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89016Q	\N	\N
761	UMP	N	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89027T	\N	\N
762	UMP	N	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	84004P	\N	\N
763	UMP	N	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80045G	\N	\N
764	UMP	N	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80035E	\N	\N
765	UMP	N	2002-12-11 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89007P	\N	2014-09-28 16:42:05
766	UMP	N	2002-12-11 00:00:00	2004-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	98003L	\N	\N
767	UMP	N	2002-12-11 00:00:00	2004-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	89037V	\N	\N
768	UMP	N	2002-12-11 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	95053J	\N	\N
769	UMP	N	2002-12-11 00:00:00	2014-06-10 00:00:00	ANCIEN	\N	\N	\N	\N	89022N	\N	2014-06-11 18:22:49
770	UMP	N	2002-12-11 00:00:00	2022-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	92040Q	\N	\N
771	UMP	N	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95056M	\N	\N
126	RI	N	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83023N	\N	\N
127	SOC	N	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92019T	\N	\N
128	RPR	N	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92032Q	\N	\N
130	RI	N	\N	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	74015M	\N	\N
131	RPR	N	\N	2000-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	83043S	\N	\N
132	UC	N	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	74028S	\N	\N
133	SOC	N	\N	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	92039X	\N	2017-06-29 09:54:43
134	RDSE	N	\N	2008-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	88004G	\N	\N
136	RDSE	N	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	81001X	\N	\N
137	RI	N	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	94004U	\N	\N
138	RI	N	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83038V	\N	\N
139	UC	N	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83035S	\N	\N
140	RPR	N	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92026S	\N	\N
141	RI	N	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92025R	\N	\N
142	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	82002D	\N	\N
143	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	96004D	\N	\N
144	UC	N	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83040P	\N	\N
145	RPR	N	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92010J	\N	\N
146	UC	N	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83056X	\N	\N
147	RPR	N	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	81007E	\N	\N
148	RDSE	N	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	74011H	\N	\N
149	UC	N	\N	2014-07-01 00:00:00	ANCIEN	\N	\N	\N	\N	83011J	\N	2014-07-01 09:25:11
150	UC	N	\N	2001-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	74008N	\N	\N
151	UC	N	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92009R	\N	\N
152	UC	N	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83036T	\N	\N
153	UC	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	92007P	\N	\N
154	RI	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	92040Q	\N	\N
155	RPR	N	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83052T	\N	\N
156	UC	N	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	74022L	\N	\N
157	RI	N	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83016P	\N	\N
159	UC	N	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	81011A	\N	\N
160	RDSE	R	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	74042Q	\N	\N
161	RPR	N	\N	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	\N	83037U	\N	\N
162	UC	N	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	74013K	\N	\N
163	SOC	N	1996-09-10 00:00:00	2014-09-01 00:00:00	ANCIEN	\N	\N	\N	\N	96007G	\N	2014-09-01 10:21:13
164	SOC	N	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	97008M	\N	\N
165	SOC	N	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92016Q	\N	\N
166	SOC	N	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86053H	\N	\N
168	UC	N	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	65017N	\N	\N
169	SOC	N	\N	2002-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	97007L	\N	\N
170	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	92031P	\N	\N
171	NI	N	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92023P	\N	\N
172	RI	N	\N	1999-10-16 00:00:00	ANCIEN	\N	\N	\N	\N	83013L	\N	\N
173	CRC	N	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	85002R	\N	\N
174	NI	N	\N	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92044U	\N	2017-09-24 18:16:52
175	SOC	N	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92037V	\N	\N
176	SOC	N	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92042S	\N	\N
177	SOC	N	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83010H	\N	\N
888	RPR	N	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59566B	\N	\N
889	SOC	N	\N	1973-09-26 00:00:00	ANCIEN	\N	\N	\N	\N	000285	\N	\N
890	SOC	N	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59583C	\N	\N
891	SOC	N	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000340	\N	\N
892	SOC	N	\N	1961-09-19 00:00:00	ANCIEN	\N	\N	\N	\N	000113	\N	\N
893	RDE	N	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58911T	\N	\N
894	UCDP	N	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000036	\N	\N
895	RI	N	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59522N	\N	\N
896	SOC	N	\N	1997-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	79002D	\N	\N
897	RPR	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	57741P	\N	\N
898	UREI	N	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000016	\N	\N
899	UDR	N	\N	1971-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	000490	\N	\N
900	UCDP	N	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000339	\N	\N
901	SOC	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000115	\N	\N
902	RI	N	\N	1998-02-25 00:00:00	ANCIEN	\N	\N	\N	\N	79005G	\N	\N
903	GD	N	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000282	\N	\N
904	C	N	\N	1973-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	58109Y	\N	\N
905	UNR	N	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58515K	\N	\N
906	UCDP	N	\N	1975-11-08 00:00:00	ANCIEN	\N	\N	\N	\N	000002	\N	\N
907	RPR	N	\N	1990-04-11 00:00:00	ANCIEN	\N	\N	\N	\N	000529	\N	\N
908	SOC	N	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000277	\N	\N
909	RIAS	N	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000032	\N	\N
910	UNR	N	\N	1967-04-03 00:00:00	ANCIEN	\N	\N	\N	\N	000400	\N	\N
911	RDE	N	\N	1992-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	59721T	\N	\N
912	SOC	N	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000663	\N	\N
913	UNR	N	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000116	\N	\N
914	GD	N	\N	1986-09-09 00:00:00	ANCIEN	\N	\N	\N	\N	000460	\N	\N
915	RPR	N	\N	1986-04-02 00:00:00	ANCIEN	\N	\N	\N	\N	58819Y	\N	\N
916	NI	N	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000091	\N	\N
917	NI	N	\N	1973-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	000425	\N	\N
918	RI	N	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	57316A	\N	\N
919	GD	N	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000346	\N	\N
920	SOC	A	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000448	\N	\N
921	RI	N	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59533R	\N	\N
922	NI	N	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	58343H	\N	\N
923	RI	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	57773X	\N	\N
924	SOC	N	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000087	\N	\N
925	RPR	N	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59214D	\N	\N
926	SOC	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	57716N	\N	\N
927	RPR	N	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59215E	\N	\N
928	RPR	N	\N	1995-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	000465	\N	\N
929	RI	N	\N	1974-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	000037	\N	\N
930	RI	N	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59520L	\N	\N
931	SOC	N	\N	1962-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	000012	\N	\N
932	SOC	N	\N	1969-08-22 00:00:00	ANCIEN	\N	\N	\N	\N	000146	\N	\N
933	C	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	58614M	\N	\N
934	RPR	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000098	\N	\N
935	GD	N	\N	1962-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	000292	\N	\N
936	NI	N	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000184	\N	\N
937	RPR	N	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59219J	\N	\N
938	GD	N	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000295	\N	\N
939	RPR	N	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59220B	\N	\N
940	CRARS	N	\N	1959-07-14 00:00:00	ANCIEN	\N	\N	\N	\N	000140	\N	\N
941	UC	N	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59568D	\N	\N
942	SOC	N	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58951C	\N	\N
943	UC	N	\N	1989-09-17 00:00:00	ANCIEN	\N	\N	\N	\N	000474	\N	\N
944	GDSRG	N	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000039	\N	\N
945	SOC	N	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000020	\N	\N
946	RDE	N	\N	1995-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	59523P	\N	\N
947	C	N	\N	1977-09-25 00:00:00	ANCIEN	\N	\N	\N	\N	000365	\N	\N
948	GD	N	\N	1976-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	000574	\N	\N
949	UREI	N	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000035	\N	\N
950	RI	N	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000049	\N	\N
951	RI	N	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	57432D	\N	\N
952	UNR	N	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000010	\N	\N
953	RI	N	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000150	\N	\N
954	RPR	N	\N	1995-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	59524Q	\N	\N
955	NI	N	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	58366Q	\N	\N
956	GDSRG	N	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	58411C	\N	\N
957	UC	N	\N	1987-02-27 00:00:00	ANCIEN	\N	\N	\N	\N	000538	\N	\N
958	SOC	N	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59525R	\N	\N
959	SOC	N	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000076	\N	\N
960	UC	N	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59526S	\N	\N
962	UNR	N	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000003	\N	\N
963	UREI	N	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58936D	\N	\N
964	NI	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000350	\N	\N
966	UC	N	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000327	\N	\N
967	RI	N	\N	1994-09-09 00:00:00	ANCIEN	\N	\N	\N	\N	000510	\N	\N
968	RI	N	\N	1974-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	58202U	\N	\N
970	UC	N	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58657Y	\N	\N
971	RPR	N	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59571X	\N	\N
972	NI	N	\N	1974-08-26 00:00:00	ANCIEN	\N	\N	\N	\N	000111	\N	\N
973	SOC	N	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000061	\N	\N
975	RI	N	\N	1965-08-19 00:00:00	ANCIEN	\N	\N	\N	\N	000191	\N	\N
976	C	N	\N	1979-06-11 00:00:00	ANCIEN	\N	\N	\N	\N	000439	\N	\N
977	RPR	N	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59221C	\N	\N
979	UDR	N	\N	1972-09-14 00:00:00	ANCIEN	\N	\N	\N	\N	000222	\N	\N
980	RP	N	\N	1962-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	58113U	\N	\N
981	SOC	N	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	58349P	\N	\N
983	RI	N	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	57434F	\N	\N
984	RI	N	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59527T	\N	\N
985	SOC	N	\N	1981-04-23 00:00:00	ANCIEN	\N	\N	\N	\N	000195	\N	\N
986	UC	N	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59222D	\N	\N
988	RP	N	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	56819Q	\N	\N
989	GD	N	\N	1967-08-03 00:00:00	ANCIEN	\N	\N	\N	\N	000060	\N	\N
990	UCDP	N	\N	1978-08-29 00:00:00	ANCIEN	\N	\N	\N	\N	000235	\N	\N
992	UCDP	N	\N	1976-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	000494	\N	\N
993	RPR	N	\N	1994-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	000501	\N	\N
994	RPR	N	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59223E	\N	\N
995	GD	N	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000196	\N	\N
997	SOC	N	\N	1996-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	89011K	\N	\N
998	RI	N	\N	1968-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	000073	\N	\N
999	SOC	N	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59224F	\N	\N
1001	GD	N	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000121	\N	\N
1002	SOC	N	\N	1974-09-20 00:00:00	ANCIEN	\N	\N	\N	\N	000205	\N	\N
1003	RI	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000359	\N	\N
1005	RPR	N	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59529V	\N	\N
1006	RI	N	\N	1998-01-19 00:00:00	ANCIEN	\N	\N	\N	\N	71011U	\N	\N
1007	RI	N	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59530N	\N	\N
1008	SOC	N	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58649Y	\N	\N
1009	RDE	N	\N	1995-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	000397	\N	\N
1010	NI	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000416	\N	\N
1011	SOC	N	\N	1992-01-06 00:00:00	ANCIEN	\N	\N	\N	\N	000524	\N	\N
1012	UC	N	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000438	\N	\N
1013	UCDP	N	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58019X	\N	\N
1014	C	N	\N	1978-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	57826T	\N	\N
1015	SOC	N	\N	1979-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	000031	\N	\N
1016	RI	N	\N	1974-03-16 00:00:00	ANCIEN	\N	\N	\N	\N	000194	\N	\N
1017	SOC	N	\N	1962-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	000250	\N	\N
1018	RP	N	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000245	\N	\N
1019	SOC	N	\N	1974-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	000066	\N	\N
1020	RI	N	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000199	\N	\N
1021	SOC	N	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59226H	\N	\N
1022	NI	N	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59572Y	\N	\N
1023	RIAS	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000188	\N	\N
1024	C	N	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000180	\N	\N
1025	SOC	N	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58670V	\N	\N
1026	UREI	N	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000331	\N	\N
1027	NI	N	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	58367R	\N	\N
1028	UC	N	\N	1997-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	86001U	\N	\N
1029	UC	N	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000084	\N	\N
1030	RI	N	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58043X	\N	\N
1031	RDE	N	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58943C	\N	\N
1032	RI	N	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000220	\N	\N
1033	UCDP	N	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	58330C	\N	\N
1034	NI	N	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000203	\N	\N
1035	RPR	N	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59227J	\N	\N
1036	RI	N	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000105	\N	\N
1037	SOC	N	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000164	\N	\N
1038	GD	N	\N	1973-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	000011	\N	\N
1039	GD	N	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000009	\N	\N
1040	RPR	N	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59531P	\N	\N
1041	UC	N	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000511	\N	\N
1042	RI	N	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59573A	\N	\N
1043	C	N	\N	1984-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	58420D	\N	\N
1044	GD	N	\N	1988-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	57714L	\N	\N
1045	UCDP	N	\N	1983-03-28 00:00:00	ANCIEN	\N	\N	\N	\N	000041	\N	\N
1046	RI	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000255	\N	\N
1047	SOC	N	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000647	\N	\N
1048	NI	N	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58643S	\N	\N
1049	SOC	N	\N	1981-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	59509R	\N	\N
1050	SOC	N	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000122	\N	\N
1051	C	N	\N	1988-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	59305F	\N	\N
1052	C	N	\N	1967-05-11 00:00:00	ANCIEN	\N	\N	\N	\N	000134	\N	\N
1053	RPR	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000082	\N	\N
1054	C	N	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58630M	\N	\N
1055	C	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	57721K	\N	\N
1056	SOC	N	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58942B	\N	\N
1057	C	N	\N	1985-04-02 00:00:00	ANCIEN	\N	\N	\N	\N	58502E	\N	\N
1058	UCDP	N	\N	1971-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	000215	\N	\N
1059	SOC	N	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	58351H	\N	\N
1060	GD	N	\N	1962-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000057	\N	\N
1061	SOC	N	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58934B	\N	\N
1062	UREI	N	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000380	\N	\N
1063	GD	N	\N	1988-03-30 00:00:00	ANCIEN	\N	\N	\N	\N	000197	\N	\N
1064	GD	N	\N	1988-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	58818X	\N	\N
1065	RP	N	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	57613G	\N	\N
1066	UC	N	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000177	\N	\N
1068	RI	N	\N	1962-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	56905M	\N	\N
1069	GDSRG	N	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000135	\N	\N
1070	RI	N	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000043	\N	\N
1071	RPR	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000046	\N	\N
1073	RPR	N	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000451	\N	\N
1074	UC	N	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59521M	\N	\N
1075	C	N	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59574B	\N	\N
1077	UC	N	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58944D	\N	\N
1078	CRC	N	\N	1997-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	86027F	\N	\N
1079	UCDP	N	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000139	\N	\N
1081	SOC	N	\N	1992-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	59229L	\N	\N
1082	RPR	N	\N	1980-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	000455	\N	\N
1083	C	N	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58668C	\N	\N
1084	C	N	\N	1962-10-31 00:00:00	ANCIEN	\N	\N	\N	\N	56601X	\N	\N
1086	RI	N	\N	1972-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	000131	\N	\N
1087	SOC	N	\N	1996-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	80020W	\N	\N
1088	SOC	N	\N	1978-01-02 00:00:00	ANCIEN	\N	\N	\N	\N	000306	\N	\N
1090	SOC	N	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000137	\N	\N
1091	UC	N	\N	1995-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	59535T	\N	\N
1092	RPR	N	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000319	\N	\N
1094	SOC	N	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000114	\N	\N
1095	RDSE	N	\N	1997-03-07 00:00:00	ANCIEN	\N	\N	\N	\N	62001R	\N	\N
1096	RPR	N	\N	1988-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	000599	\N	\N
1098	SOC	N	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58631N	\N	\N
1099	UC	N	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59575C	\N	\N
1100	UDR	N	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000062	\N	\N
1101	SOC	N	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000210	\N	\N
1103	UREI	N	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59231E	\N	\N
1104	C	N	\N	1978-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	58673Y	\N	\N
1105	GD	N	\N	1978-05-08 00:00:00	ANCIEN	\N	\N	\N	\N	000097	\N	\N
1107	UCDP	N	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000370	\N	\N
1108	RI	N	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	57445J	\N	\N
1109	RPR	N	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59537V	\N	\N
1111	SOC	N	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59232F	\N	\N
1112	GD	N	\N	1985-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	000551	\N	\N
1113	RI	N	\N	1977-03-04 00:00:00	ANCIEN	\N	\N	\N	\N	000067	\N	\N
1114	RPR	N	\N	1997-01-12 00:00:00	ANCIEN	\N	\N	\N	\N	89032Q	\N	\N
1115	UC	N	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58949J	\N	\N
1116	UNR	N	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000224	\N	\N
1117	UNR	N	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	56531B	\N	\N
1118	UREI	N	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	58332E	\N	\N
1119	SOC	N	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59233G	\N	\N
1120	UREI	N	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58625Q	\N	\N
1121	SOC	N	\N	1967-04-03 00:00:00	ANCIEN	\N	\N	\N	\N	000216	\N	\N
1122	UCDP	N	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000459	\N	\N
1123	UC	N	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59538W	\N	\N
1124	C	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000092	\N	\N
1125	UNR	N	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000271	\N	\N
48	SOC	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	97002F	\N	\N
49	RI	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	98003L	\N	\N
50	RPR	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80025C	\N	\N
51	RI	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	89037V	\N	\N
52	SOC	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80036F	\N	\N
53	CRC	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	97010F	\N	\N
54	SOC	N	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89040Q	\N	\N
55	SOC	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	81010Y	\N	\N
56	SOC	N	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	73006G	\N	\N
57	RPR	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	97001E	\N	\N
58	SOC	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80028F	\N	\N
59	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	88009M	\N	\N
60	UC	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	88002E	\N	\N
61	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	80041C	\N	\N
62	SOC	N	1989-10-02 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89015P	\N	2014-09-28 16:50:17
63	SOC	N	1996-09-04 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	96006F	\N	2014-09-28 16:50:17
64	CRC	N	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86037H	\N	\N
65	RPR	N	\N	2001-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	95027G	\N	\N
66	RI	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	95053J	\N	\N
67	SOC	N	\N	2000-04-27 00:00:00	ANCIEN	\N	\N	\N	\N	86039K	\N	\N
68	RPR	N	\N	2000-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	88003F	\N	\N
69	RI	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	89022N	\N	\N
70	RDSE	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	81014D	\N	\N
71	RPR	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83004K	\N	\N
72	RPR	N	\N	2001-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	89009R	\N	\N
73	NI	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89031P	\N	\N
74	UC	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80003V	\N	\N
75	UC	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	71024A	\N	\N
76	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	86006A	\N	\N
77	RPR	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89034S	\N	\N
78	SOC	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92046W	\N	\N
79	SOC	N	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80040B	\N	\N
80	SOC	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80033C	\N	\N
81	SOC	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	96001A	\N	\N
82	SOC	N	1980-10-02 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80039J	\N	\N
83	SOC	N	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89019T	\N	\N
84	SOC	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89008Q	\N	\N
85	SOC	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89028U	\N	\N
86	RDSE	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	93006S	\N	\N
87	RPR	A	\N	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	90003B	\N	\N
88	SOC	N	1980-09-28 00:00:00	2019-08-27 00:00:00	ANCIEN	\N	\N	\N	\N	80027E	\N	\N
89	SOC	N	\N	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89025R	\N	\N
90	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	80046H	\N	\N
91	CRC	N	\N	2000-03-28 00:00:00	ANCIEN	\N	\N	\N	\N	97003G	\N	\N
92	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	93005R	\N	\N
93	UC	N	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95007C	\N	\N
94	SOC	N	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95006B	\N	\N
95	RI	N	\N	1998-10-07 00:00:00	ANCIEN	\N	\N	\N	\N	77019E	\N	\N
96	RPR	N	\N	1999-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	77053G	\N	\N
97	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	95016D	\N	\N
98	SOC	N	\N	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	80015A	\N	\N
99	SOC	N	\N	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	89043T	\N	\N
100	SOC	N	\N	2005-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	80048K	\N	\N
101	UC	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80026D	\N	\N
102	UC	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80014Y	\N	\N
103	RPR	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80011V	\N	\N
104	UC	N	\N	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89026S	\N	\N
105	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	89030N	\N	\N
106	UC	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	89020L	\N	\N
107	RI	N	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83026R	\N	\N
108	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	92030N	\N	\N
109	RI	N	\N	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	92012L	\N	\N
110	RDSE	N	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83020K	\N	\N
111	RI	N	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83018R	\N	\N
112	RPR	N	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83028T	\N	\N
113	UC	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	83031N	\N	\N
114	RDSE	N	\N	2001-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	74024N	\N	\N
115	RPR	N	\N	2001-08-22 00:00:00	ANCIEN	\N	\N	\N	\N	89004L	\N	\N
116	SOC	N	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83039W	\N	\N
117	SOC	N	1992-10-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92015P	\N	2017-09-24 13:14:55
118	UC	N	\N	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	92022N	\N	\N
119	RDSE	N	\N	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	86005Y	\N	\N
120	RPR	N	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83046V	\N	\N
121	RI	N	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92041R	\N	\N
122	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	97011G	\N	\N
123	UC	N	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83044T	\N	\N
125	RPR	N	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83025Q	\N	\N
178	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	\N	\N
179	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	\N	\N
180	UC	N	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83054V	\N	\N
182	UC	N	\N	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	92029V	\N	\N
183	CRC	N	1995-10-02 00:00:00	2012-09-19 00:00:00	ANCIEN	\N	\N	\N	\N	95011X	\N	\N
184	RI	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	95056M	\N	\N
185	SOC	N	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86025D	\N	\N
187	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	86028G	\N	\N
188	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	93003P	\N	\N
189	SOC	N	\N	2001-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	95022B	\N	\N
191	SOC	N	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95058P	\N	\N
192	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	77046H	\N	\N
194	SOC	N	\N	2000-01-27 00:00:00	ANCIEN	\N	\N	\N	\N	95018F	\N	\N
195	SOC	N	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92043T	\N	\N
196	RPR	N	\N	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	\N	92017R	\N	\N
197	RPR	A	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86004X	\N	\N
198	CRC	N	\N	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	84003N	\N	\N
199	SOC	N	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92021M	\N	\N
200	SOC	N	1983-10-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	83047W	\N	2017-09-24 17:42:26
201	SOC	N	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92027T	\N	\N
202	SOC	N	\N	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	83017Q	\N	\N
203	SOC	N	\N	2008-06-03 00:00:00	ANCIEN	\N	\N	\N	\N	81015E	\N	\N
204	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	83021L	\N	\N
205	RPR	N	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92006N	\N	\N
206	UC	N	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92013M	\N	\N
207	SOC	N	1992-10-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92020L	\N	2017-09-24 12:39:59
208	RDSE	N	\N	2001-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	83008P	\N	\N
209	UC	N	\N	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92036U	\N	\N
210	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	92011K	\N	\N
211	UC	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	95036H	\N	\N
212	UC	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	92005M	\N	\N
213	UC	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	77029G	\N	\N
214	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	91002E	\N	\N
215	RPR	A	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	95029J	\N	\N
216	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	86030A	\N	\N
217	UC	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	95045J	\N	\N
219	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	86047K	\N	\N
220	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	86031B	\N	\N
221	RI	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	77047J	\N	\N
222	SOC	N	\N	1999-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	77066M	\N	\N
223	UC	N	\N	2009-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	95049N	\N	\N
224	CRC	N	1995-10-02 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95032D	\N	2014-09-28 17:07:41
225	RDSE	N	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95040D	\N	\N
226	RPR	N	\N	2002-06-18 00:00:00	ANCIEN	\N	\N	\N	\N	95041E	\N	\N
227	RI	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	95030B	\N	\N
228	RI	R	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	86043F	\N	\N
229	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	95020Y	\N	\N
230	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	77012W	\N	\N
231	RI	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	77043E	\N	\N
232	RI	R	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	95019G	\N	\N
233	RPR	N	\N	1999-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	95008D	\N	\N
234	SOC	N	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77060F	\N	\N
235	RI	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	95015C	\N	\N
237	UC	N	1995-10-02 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95005A	\N	2014-09-28 17:40:23
238	UC	N	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95014B	\N	\N
239	RI	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	95062K	\N	\N
240	SOC	N	\N	2004-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	95066P	\N	\N
241	SOC	N	1995-07-06 00:00:00	2013-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	95003X	\N	\N
242	CRC	N	\N	1998-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	88006J	\N	\N
243	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	\N	\N
244	RPR	N	\N	1999-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	95054K	\N	\N
245	RI	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	77033C	\N	\N
246	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	83003J	\N	\N
247	UC	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	\N	\N
248	CRC	N	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	78007E	\N	\N
249	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	95024D	\N	\N
250	SOC	N	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95046K	\N	\N
251	SOC	N	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77017C	\N	\N
252	CRC	N	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95060H	\N	\N
253	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	86014A	\N	\N
254	UC	R	\N	1998-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	95009E	\N	\N
257	UC	N	1995-10-02 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95025E	\N	2014-09-28 17:09:16
258	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	95047L	\N	\N
259	SOC	N	\N	1998-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	95048M	\N	\N
260	SOC	N	1995-10-02 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95052H	\N	2014-09-28 13:39:20
261	RDSE	N	\N	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86010V	\N	2014-09-28 19:03:04
262	RDSE	N	\N	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	88008L	\N	\N
263	CRC	N	\N	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	\N	77044F	\N	\N
264	RPR	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	88013H	\N	\N
265	UC	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	95057N	\N	\N
266	SOC	N	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	97004H	\N	\N
267	RI	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	86018E	\N	\N
268	CRC	N	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	97005J	\N	\N
2126	UMP	N	2011-10-01 00:00:00	2011-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	01048V	\N	\N
2127	RDSE	N	2011-10-04 00:00:00	2014-08-26 00:00:00	ANCIEN	\N	\N	\N	\N	11018G	\N	2014-08-27 16:33:37
2128	SOC	N	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11015D	\N	2017-09-24 13:42:36
2129	SOC	N	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11014C	\N	2017-09-24 13:14:55
2130	RDSE	N	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11012A	\N	\N
2131	SOC	N	2011-10-01 00:00:00	2017-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	11023D	\N	2017-07-17 11:07:22
2132	UMP	N	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11030C	\N	2017-09-24 17:09:24
2133	SOC	N	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11042G	\N	2017-09-24 17:35:15
2134	SOC	N	2011-10-01 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	11057P	\N	2017-06-29 09:55:44
2143	SOC	N	2017-06-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11069T	\N	2017-09-24 18:05:41
2334	SOC	N	2011-10-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11084S	\N	2017-09-24 19:25:10
2353	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04087R	\N	\N
2146	UC	N	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11070L	\N	\N
2147	SOC	N	2011-10-01 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	11068S	\N	2017-06-29 09:53:25
2371	RDSE	N	2012-03-19 00:00:00	2020-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	11081P	\N	\N
2149	SOC	N	2011-10-01 00:00:00	2013-10-21 00:00:00	ANCIEN	\N	\N	\N	\N	11096W	\N	2013-10-22 16:15:00
2383	RDSE	N	2012-09-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04078Q	\N	2017-09-24 17:15:15
2154	UMP	N	2011-10-01 00:00:00	2020-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	11049P	\N	\N
2155	SOC	N	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11035H	\N	2017-09-24 18:16:52
2156	SOC	N	2011-10-01 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	11036J	\N	2017-06-29 09:53:19
2157	SOC	N	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11039M	\N	2017-09-24 18:16:52
2159	SOC	N	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11037K	\N	2017-09-24 18:16:52
2165	SOC	R	2011-10-01 00:00:00	2012-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	11029K	\N	\N
2167	NI	N	2011-10-01 00:00:00	2013-09-10 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	\N	2013-09-11 15:01:59
2170	SOC	N	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11095V	\N	2017-09-24 13:25:54
2171	UC	N	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11094U	\N	2017-09-24 13:25:54
2172	UC	N	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11082Q	\N	2017-09-24 19:16:18
2174	CRC	N	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11098Y	\N	2017-09-24 17:14:26
2175	SOC	R	2011-10-01 00:00:00	2012-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	11099A	\N	\N
2176	RDSE	N	2011-10-04 00:00:00	2011-12-22 00:00:00	ANCIEN	\N	\N	\N	\N	11081P	\N	\N
2179	UMP	N	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	\N	\N
2182	UMP	N	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11097X	\N	\N
772	UMP	N	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95026F	\N	\N
773	UMP	N	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77047J	\N	\N
774	UMP	N	2002-12-11 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95030B	\N	2014-09-28 18:58:21
775	UMP	R	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86043F	\N	\N
776	UMP	N	2002-12-11 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77043E	\N	2014-09-28 16:59:41
777	UMP	N	2002-12-11 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95019G	\N	2014-09-28 16:59:41
778	UMP	N	2002-12-11 00:00:00	2018-08-06 00:00:00	ANCIEN	\N	\N	\N	\N	95015C	\N	\N
779	UMP	N	2002-12-11 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95062K	\N	\N
780	UMP	N	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77033C	\N	\N
781	UMP	N	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86018E	\N	\N
782	UMP	N	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95042F	\N	\N
783	UMP	N	2002-12-11 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86049M	\N	2014-09-28 18:03:38
785	UMP	N	2002-12-11 00:00:00	2017-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	89029V	\N	2017-09-24 11:09:53
786	UMP	N	2002-12-11 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	98019U	\N	2014-09-29 13:43:10
787	UMP	N	2002-12-11 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98041S	\N	2014-09-28 16:42:05
788	UC	N	2002-12-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98042T	\N	2017-10-01 10:39:22
789	UMP	N	2002-12-11 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98028V	\N	2014-09-28 17:22:11
790	UMP	N	2002-12-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98021N	\N	2017-10-01 09:22:37
792	UMP	N	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01005J	\N	\N
793	UMP	N	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01033N	\N	\N
794	UMP	N	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01030K	\N	\N
796	UMP	N	2002-12-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01019Q	\N	2017-09-24 17:35:15
797	UMP	N	2002-12-11 00:00:00	2003-08-01 00:00:00	ANCIEN	\N	\N	\N	\N	95004Y	\N	\N
798	UMP	N	2002-12-11 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01064V	\N	2014-09-28 17:12:41
799	UMP	N	2002-12-11 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	02002K	\N	2017-10-03 16:54:03
800	UMP	N	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	02006P	\N	\N
186	RI	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	95026F	\N	\N
275	RI	N	1986-09-28 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	86049M	\N	\N
801	UMP	N	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01010F	\N	\N
802	UMP	N	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86050E	\N	\N
803	UMP	N	2002-12-11 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	01039U	\N	\N
805	UMP	N	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95057N	\N	\N
806	UMP	N	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01054T	\N	\N
807	UMP	N	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	02005N	\N	\N
808	UMP	N	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	68036E	\N	\N
1437	SOC	N	\N	1979-05-28 00:00:00	ANCIEN	\N	\N	\N	\N	000360	\N	\N
1438	SOC	N	\N	1988-02-05 00:00:00	ANCIEN	\N	\N	\N	\N	000621	\N	\N
1439	SOC	N	\N	1973-09-09 00:00:00	ANCIEN	\N	\N	\N	\N	000322	\N	\N
1440	SOC	N	\N	1975-12-29 00:00:00	ANCIEN	\N	\N	\N	\N	000106	\N	\N
1441	RI	N	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000056	\N	\N
1442	UCDP	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000388	\N	\N
1443	SOC	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000309	\N	\N
1444	UREI	N	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000110	\N	\N
1445	NI	N	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000072	\N	\N
1446	RI	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000133	\N	\N
1447	RI	N	\N	1976-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	000325	\N	\N
1448	UC	N	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58925A	\N	\N
1449	UC	N	\N	1987-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	000611	\N	\N
1450	SOC	N	\N	1988-07-29 00:00:00	ANCIEN	\N	\N	\N	\N	000323	\N	\N
1451	SOC	N	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000088	\N	\N
1452	UCDP	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000119	\N	\N
1453	RDE	N	\N	1995-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	59578F	\N	\N
1454	RDE	N	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59241G	\N	\N
1455	RI	N	\N	1979-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	000007	\N	\N
1456	SOC	N	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000044	\N	\N
1457	RPR	N	\N	1996-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	89005M	\N	\N
1458	UREI	N	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59248P	\N	\N
1459	GD	N	\N	1985-09-01 00:00:00	ANCIEN	\N	\N	\N	\N	000595	\N	\N
1460	C	N	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58644T	\N	\N
1461	UCDP	N	\N	1970-06-13 00:00:00	ANCIEN	\N	\N	\N	\N	000015	\N	\N
1462	UCDP	N	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000190	\N	\N
1463	RI	N	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000703	\N	\N
1464	RI	N	\N	1967-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	000724	\N	\N
1465	RI	N	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000689	\N	\N
1466	UNR	N	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000757	\N	\N
1467	GD	N	\N	1966-12-22 00:00:00	ANCIEN	\N	\N	\N	\N	000733	\N	\N
1468	RI	N	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000731	\N	\N
1469	GD	N	\N	1959-08-28 00:00:00	ANCIEN	\N	\N	\N	\N	000759	\N	\N
1470	RPR	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000701	\N	\N
1471	GD	N	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000711	\N	\N
1472	SOC	N	\N	1970-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	000682	\N	\N
1473	RI	N	\N	1961-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	000761	\N	\N
1474	RI	N	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000696	\N	\N
1475	RI	N	\N	1965-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	000718	\N	\N
1476	SOC	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000690	\N	\N
1477	RI	N	\N	1962-11-23 00:00:00	ANCIEN	\N	\N	\N	\N	000756	\N	\N
1478	CRARS	N	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000760	\N	\N
1480	CRARS	N	\N	1966-05-26 00:00:00	ANCIEN	\N	\N	\N	\N	000755	\N	\N
1481	UC	N	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000722	\N	\N
1482	UNR	N	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000723	\N	\N
1483	GD	N	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000715	\N	\N
1485	GD	N	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000763	\N	\N
1486	UCDP	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000702	\N	\N
1487	GD	N	\N	1976-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	000769	\N	\N
1489	SOC	N	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000709	\N	\N
1490	RI	N	\N	1969-01-11 00:00:00	ANCIEN	\N	\N	\N	\N	000744	\N	\N
1491	GD	N	\N	1966-03-09 00:00:00	ANCIEN	\N	\N	\N	\N	000685	\N	\N
1493	RI	N	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000713	\N	\N
1494	C	N	\N	1975-04-25 00:00:00	ANCIEN	\N	\N	\N	\N	000681	\N	\N
1495	GD	N	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000687	\N	\N
1496	RP	N	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000764	\N	\N
1498	RPR	N	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000720	\N	\N
1499	GD	N	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000719	\N	\N
1500	SOC	N	\N	1968-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	000678	\N	\N
1503	RI	N	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000766	\N	\N
1504	GD	N	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000675	\N	\N
1506	UNR	N	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000700	\N	\N
1507	GD	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000765	\N	\N
1508	SOC	N	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000721	\N	\N
1509	RI	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000732	\N	\N
1511	UNR	N	\N	1964-08-07 00:00:00	ANCIEN	\N	\N	\N	\N	000737	\N	\N
1512	UCDP	N	\N	1976-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	000727	\N	\N
1513	SOC	N	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000686	\N	\N
1514	RI	N	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000706	\N	\N
1516	RI	N	\N	1971-10-28 00:00:00	ANCIEN	\N	\N	\N	\N	000693	\N	\N
1517	RI	N	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000707	\N	\N
1518	RI	N	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000710	\N	\N
1520	RI	N	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000762	\N	\N
1521	GD	N	\N	1968-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	000746	\N	\N
1522	C	N	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000738	\N	\N
1524	RI	N	\N	1963-01-22 00:00:00	ANCIEN	\N	\N	\N	\N	000767	\N	\N
1525	SOC	N	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000751	\N	\N
1526	RPR	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000671	\N	\N
1527	GD	N	\N	1974-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	000677	\N	\N
1528	RPR	N	\N	1993-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	000705	\N	\N
1529	GD	N	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000691	\N	\N
1530	SOC	N	\N	1968-10-29 00:00:00	ANCIEN	\N	\N	\N	\N	000736	\N	\N
1531	RI	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000688	\N	\N
1532	GD	N	\N	1965-12-17 00:00:00	ANCIEN	\N	\N	\N	\N	000725	\N	\N
1533	CNIP	N	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000748	\N	\N
1534	GD	N	\N	1972-10-19 00:00:00	ANCIEN	\N	\N	\N	\N	000734	\N	\N
1535	RI	N	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000714	\N	\N
1536	CNIP	N	\N	1968-09-19 00:00:00	ANCIEN	\N	\N	\N	\N	000694	\N	\N
1537	RI	N	\N	1979-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	000747	\N	\N
1538	RI	N	\N	1961-08-22 00:00:00	ANCIEN	\N	\N	\N	\N	000730	\N	\N
1539	RI	N	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000698	\N	\N
1540	RI	N	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000672	\N	\N
1541	UNR	N	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000772	\N	\N
1542	RI	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000741	\N	\N
1543	NI	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000752	\N	\N
1544	UNR	N	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000743	\N	\N
1545	GD	N	\N	1971-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	000750	\N	\N
1546	GD	N	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000704	\N	\N
1548	RI	N	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000754	\N	\N
1549	UNR	N	\N	1966-04-24 00:00:00	ANCIEN	\N	\N	\N	\N	000768	\N	\N
1550	RI	N	\N	1973-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	000749	\N	\N
1551	RI	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000673	\N	\N
1552	GD	N	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000716	\N	\N
1553	SOC	N	\N	1968-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	000692	\N	\N
1554	CRARS	N	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000717	\N	\N
1555	CRARS	N	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000674	\N	\N
1556	UC	N	\N	1992-04-06 00:00:00	ANCIEN	\N	\N	\N	\N	000667	\N	\N
1557	RPR	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000684	\N	\N
1558	GDSRG	N	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000770	\N	\N
1559	RI	N	\N	1962-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000676	\N	\N
1560	NI	N	\N	1966-06-02 00:00:00	ANCIEN	\N	\N	\N	\N	000668	\N	\N
1561	RI	N	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000669	\N	\N
1562	MRP	N	\N	1959-04-29 00:00:00	ANCIEN	\N	\N	\N	\N	000740	\N	\N
1563	UNR	N	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000729	\N	\N
1564	UC	R	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000374	\N	\N
1565	UC	R	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59213C	\N	\N
1566	UC	R	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000399	\N	\N
1567	UREI	R	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000053	\N	\N
1568	UC	R	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59528U	\N	\N
1569	UREI	R	\N	1986-07-31 00:00:00	ANCIEN	\N	\N	\N	\N	000411	\N	\N
1860	CRC	N	2007-07-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	07026Q	\N	2017-09-24 19:25:10
1861	SOC	N	2007-07-04 00:00:00	2013-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	07025P	\N	\N
1864	NI	N	2007-07-20 00:00:00	2007-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	07027R	\N	\N
1865	UMP	A	2007-07-20 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	07028S	\N	\N
1881	NI	N	2007-12-17 00:00:00	2008-01-16 00:00:00	ANCIEN	\N	\N	\N	\N	07034Q	\N	\N
1890	SOC	N	2008-09-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08008S	\N	\N
2100	SOC	N	2010-03-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10003H	\N	2014-09-28 17:38:25
2109	UMP	N	2010-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	10006L	\N	\N
1843	CRC	N	2007-01-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	07001F	\N	\N
1851	NI	N	2007-06-18 00:00:00	2007-06-19 00:00:00	ANCIEN	\N	\N	\N	\N	04099V	\N	\N
1862	UMP	R	2007-07-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	07023M	\N	\N
1870	UMP	N	2007-09-04 00:00:00	2022-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	07029T	\N	\N
1875	UMP	N	2007-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	86034E	\N	\N
2115	UC	N	2010-12-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01043Q	\N	\N
2097	SOC	N	2010-03-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98009S	\N	\N
1895	SOC	N	2008-10-01 00:00:00	2010-03-15 00:00:00	ANCIEN	\N	\N	\N	\N	08013P	\N	\N
1896	SOC	N	2008-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08014Q	\N	\N
2116	RDSE	N	2010-12-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04040A	\N	\N
1903	UMP	A	2008-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08020N	\N	2017-10-03 17:31:16
2117	UMP	N	2010-12-14 00:00:00	2017-09-21 00:00:00	ANCIEN	\N	\N	\N	\N	95031C	\N	2017-09-22 10:42:23
1958	RDSE	N	2008-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	02053W	\N	2014-09-28 12:32:23
1966	SOC	N	2008-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08043V	\N	\N
1987	SOC	N	2008-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08057C	\N	2014-09-28 14:31:42
2112	UMP	N	2010-11-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10007M	\N	\N
1846	RDSE	N	1992-10-02 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	89042S	\N	\N
1854	UMP	N	2007-06-19 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04099V	\N	2014-09-28 16:59:41
1871	UMP	N	2007-09-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	07030L	\N	2014-09-28 17:03:41
1880	UMP	N	2007-11-30 00:00:00	2016-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	07032N	\N	2016-11-18 12:37:49
1883	UMP	R	2008-01-16 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	07034Q	\N	\N
2071	UC	N	2008-10-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	07004J	\N	\N
2073	UMP	R	2008-10-02 00:00:00	2010-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98027U	\N	\N
2075	RDSE	N	2008-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98010K	\N	2014-09-28 17:27:35
2076	UMP	N	2008-10-01 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	\N	01039U	\N	\N
2077	RDSE	N	2008-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	06004E	\N	2014-09-28 17:03:42
2113	NI	N	2010-01-08 00:00:00	2010-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	10001F	\N	\N
795	UMP	N	2002-12-11 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	\N	01048V	\N	\N
2103	UMP	A	2010-05-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08056B	\N	\N
2122	UMP	N	2011-03-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11003M	\N	\N
1877	NI	N	2007-11-22 00:00:00	2007-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	07032N	\N	\N
1889	NI	N	2008-09-08 00:00:00	2008-09-10 00:00:00	ANCIEN	\N	\N	\N	\N	08008S	\N	\N
426	RPR	N	1999-12-21 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	99004R	\N	\N
751	UMP	N	2002-12-11 00:00:00	2003-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	01060R	\N	\N
2102	UMP	N	2010-04-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10005K	\N	\N
2110	NI	N	2010-10-12 00:00:00	2010-10-12 00:00:00	ANCIEN	\N	\N	\N	\N	10006L	\N	\N
1844	NI	N	2007-01-26 00:00:00	2007-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	07003H	\N	\N
1848	NI	N	2007-02-26 00:00:00	2007-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	07004J	\N	\N
2119	AUCUN	N	2011-01-23 00:00:00	2011-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	11001K	\N	\N
1886	UMP	N	2008-04-19 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	08007R	\N	\N
2120	UC	N	2011-01-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	11001K	\N	\N
1250	UC	N	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59236K	\N	\N
1251	UCDP	N	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	57135W	\N	\N
1252	UCDP	N	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000209	\N	\N
1253	UDR	N	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000290	\N	\N
1254	GD	N	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58026W	\N	\N
1255	RPR	N	\N	1995-07-01 00:00:00	ANCIEN	\N	\N	\N	\N	000597	\N	\N
1256	RPR	N	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000100	\N	\N
1257	GD	N	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000027	\N	\N
1258	UC	N	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000586	\N	\N
1259	UCDP	N	\N	1971-08-10 00:00:00	ANCIEN	\N	\N	\N	\N	000145	\N	\N
1260	UNR	N	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000242	\N	\N
1261	RPR	N	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59237L	\N	\N
1262	GD	A	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000024	\N	\N
1263	C	N	\N	1975-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	000187	\N	\N
1264	RPR	N	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000126	\N	\N
1265	SOC	N	\N	1967-04-03 00:00:00	ANCIEN	\N	\N	\N	\N	000079	\N	\N
1266	SOC	N	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000352	\N	\N
1267	NI	N	\N	1972-05-08 00:00:00	ANCIEN	\N	\N	\N	\N	000166	\N	\N
1268	RI	N	\N	1963-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	000428	\N	\N
1269	SOC	N	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58636T	\N	\N
1270	UCDP	N	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000096	\N	\N
1271	C	N	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58645U	\N	\N
1272	UCDP	N	\N	1977-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	000019	\N	\N
1273	NI	N	\N	1994-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	000419	\N	\N
1274	UC	N	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000437	\N	\N
1276	UC	N	\N	1989-05-18 00:00:00	ANCIEN	\N	\N	\N	\N	000488	\N	\N
1277	RI	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000254	\N	\N
1278	UC	N	\N	1985-05-13 00:00:00	ANCIEN	\N	\N	\N	\N	000393	\N	\N
1279	GD	N	\N	1981-02-19 00:00:00	ANCIEN	\N	\N	\N	\N	000412	\N	\N
1280	RPR	N	\N	1998-04-05 00:00:00	ANCIEN	\N	\N	\N	\N	71031Y	\N	\N
1282	SOC	N	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000521	\N	\N
1283	GD	N	\N	1979-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	000109	\N	\N
1284	RI	N	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000182	\N	\N
1286	SOC	N	\N	1973-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	000048	\N	\N
1287	CRARS	N	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000008	\N	\N
1288	SOC	N	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000208	\N	\N
1289	C	N	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58628T	\N	\N
1291	SOC	N	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59580Y	\N	\N
1292	NI	N	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	58335H	\N	\N
1293	SOC	N	\N	1978-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	000643	\N	\N
1295	SOC	N	\N	1977-12-20 00:00:00	ANCIEN	\N	\N	\N	\N	000434	\N	\N
784	UMP	N	2002-12-11 00:00:00	2009-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	86044G	\N	2014-10-09 09:08:12
2083	UC	N	2009-07-24 00:00:00	2012-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	09010Q	\N	\N
2084	UMP	R	2009-07-24 00:00:00	2012-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	09011R	\N	\N
2093	CRC	N	2010-01-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	10001F	\N	\N
2107	UC	N	2010-10-01 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	98027U	\N	2015-06-12 16:01:58
2118	UMP	A	2010-12-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	10015M	\N	\N
1960	SOC	N	2008-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08040S	\N	2014-09-28 17:52:18
1989	SOC	A	2008-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08059E	\N	2014-09-28 17:27:29
1842	UMP	N	2007-01-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01055U	\N	\N
1858	NI	N	2007-06-29 00:00:00	2007-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	07025P	\N	\N
1859	NI	N	2007-06-29 00:00:00	2007-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	07026Q	\N	\N
1866	SOC	R	2007-07-24 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	07027R	\N	\N
2007	UC	N	2008-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	08009T	\N	2014-10-07 15:51:03
2008	UMP	N	2008-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	08011M	\N	\N
2087	SOC	N	2009-09-16 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	09012S	\N	2014-09-28 13:09:05
2095	NI	N	2010-03-07 00:00:00	2010-03-08 00:00:00	ANCIEN	\N	\N	\N	\N	98009S	\N	\N
2011	UMP	N	2008-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	08018U	\N	\N
2105	RDSE	N	2010-05-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04093P	\N	\N
2013	SOC	A	2008-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08021P	\N	2014-10-07 16:59:15
2014	UMP	N	2008-10-01 00:00:00	2013-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	08023R	\N	\N
2015	SOC	N	2008-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08027V	\N	2014-09-28 17:34:15
2016	UMP	R	2008-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	08047A	\N	\N
2017	SOC	A	2008-10-01 00:00:00	2013-06-04 00:00:00	ANCIEN	\N	\N	\N	\N	08032S	\N	2013-06-04 17:13:15
2018	UMP	N	2008-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	08034U	\N	\N
2019	SOC	N	2008-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08037X	\N	2014-09-28 17:34:15
2022	SOC	N	2008-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08045X	\N	2017-10-03 17:08:23
2023	RDSE	N	2008-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08049C	\N	2014-09-28 19:07:43
2025	CRC	N	2008-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08054Y	\N	2014-09-28 12:39:09
2027	SOC	N	2008-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08063A	\N	2014-09-28 17:07:07
2029	SOC	N	2008-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08067E	\N	2014-09-28 17:22:11
2030	UMP	N	2008-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	08015R	\N	\N
2031	UMP	N	2008-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	08010L	\N	\N
2032	SOC	N	2008-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	08012N	\N	\N
2034	CRC	N	2008-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08026U	\N	2014-09-28 17:52:18
2035	SOC	N	2008-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08029X	\N	2014-09-28 17:52:18
2037	UMP	N	2008-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08044W	\N	2014-10-07 15:53:46
2038	UMP	N	2008-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08048B	\N	\N
2039	SOC	N	2008-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08053X	\N	\N
2040	UMP	N	2008-10-01 00:00:00	2010-05-02 00:00:00	ANCIEN	\N	\N	\N	\N	08056B	\N	\N
2042	SOC	N	2008-10-01 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	08061X	\N	2017-06-29 09:52:44
1838	SOC	N	2006-08-21 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	06005F	\N	2014-09-28 13:32:35
1884	NI	N	1965-08-20 00:00:00	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	08001K	\N	\N
2004	RDSE	N	2008-10-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08074D	\N	\N
2006	NI	N	2008-10-02 00:00:00	2014-09-16 00:00:00	ANCIEN	\N	\N	\N	\N	98052V	\N	2014-09-16 14:55:27
2043	SOC	N	2008-10-01 00:00:00	2014-05-02 00:00:00	ANCIEN	\N	\N	\N	\N	08070Y	\N	2014-10-02 10:18:44
2045	SOC	A	2008-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08071A	\N	2014-09-29 09:08:32
2086	UMP	N	2009-07-29 00:00:00	2016-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	07024N	\N	2017-01-03 11:09:24
2047	SOC	N	2008-10-01 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	08073C	\N	2017-06-29 09:54:57
2048	SOC	N	2008-10-01 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08017T	\N	\N
1733	UMP	N	2004-09-27 00:00:00	2010-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	92029V	\N	\N
2054	RDSE	N	2008-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08031R	\N	\N
2055	SOC	N	2008-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08033T	\N	2014-09-28 17:27:34
2056	UMP	N	2008-10-01 00:00:00	2013-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	08036W	\N	\N
2058	UMP	N	2008-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08039A	\N	2017-10-03 18:21:27
2059	UMP	N	2008-10-01 00:00:00	2020-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	08041T	\N	2014-10-07 15:27:49
2061	SOC	N	2008-10-01 00:00:00	2014-02-13 00:00:00	ANCIEN	\N	\N	\N	\N	08046Y	\N	2014-02-14 10:05:07
2067	UMP	N	2008-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08062Y	\N	\N
2069	SOC	N	2008-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08066D	\N	2014-09-28 19:03:23
1868	NI	N	2007-08-27 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	07029T	\N	\N
1869	NI	N	2007-08-27 00:00:00	2007-09-10 00:00:00	ANCIEN	\N	\N	\N	\N	07030L	\N	\N
1887	RDSE	N	2008-06-04 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	81015E	\N	\N
2085	NI	N	2009-07-24 00:00:00	2009-07-28 00:00:00	ANCIEN	\N	\N	\N	\N	99004R	\N	\N
2002	SOC	A	2008-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08072B	\N	2014-09-29 09:05:47
1837	NI	N	2006-08-12 00:00:00	2006-08-20 00:00:00	ANCIEN	\N	\N	\N	\N	06005F	\N	\N
1845	UMP	N	2007-02-05 00:00:00	2011-09-25 00:00:00	ANCIEN	\N	\N	\N	\N	07003H	\N	\N
1873	CRC	N	2007-09-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	97005J	\N	\N
1878	UMP	N	2007-11-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	07033P	\N	2017-10-03 17:19:59
2082	CRC	N	2009-05-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83012K	\N	\N
2098	UMP	N	2010-03-10 00:00:00	2013-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	95045J	\N	\N
1841	NI	N	2007-01-02 00:00:00	2007-01-03 00:00:00	ANCIEN	\N	\N	\N	\N	07002G	\N	\N
1850	RDSE	N	2007-03-06 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	07004J	\N	\N
1856	NI	N	2007-06-22 00:00:00	2007-07-10 00:00:00	ANCIEN	\N	\N	\N	\N	07023M	\N	\N
1906	UMP	N	2008-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08022Q	\N	2017-10-01 09:41:22
1908	SOC	N	2008-10-01 00:00:00	2018-07-17 00:00:00	ANCIEN	\N	\N	\N	\N	08024S	\N	2014-10-07 16:59:24
1909	SOC	N	2008-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08025T	\N	2017-10-01 10:17:18
1928	UMP	N	2008-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	08028W	\N	2014-10-07 15:28:17
1975	SOC	N	2008-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08050U	\N	2014-09-28 12:44:31
1977	SOC	N	2008-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08052W	\N	\N
1980	SOC	N	2008-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08055A	\N	\N
1988	SOC	N	2008-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08058D	\N	\N
1990	SOC	N	2008-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	08060W	\N	\N
1994	RDSE	N	2008-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	08064B	\N	\N
1857	UMP	N	2007-06-25 00:00:00	2009-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	07024N	\N	\N
2081	CRC	N	2008-11-28 00:00:00	2010-01-07 00:00:00	ANCIEN	\N	\N	\N	\N	86039K	\N	\N
2096	NI	N	2010-03-07 00:00:00	2010-03-09 00:00:00	ANCIEN	\N	\N	\N	\N	95045J	\N	\N
2123	NI	N	2011-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	82002D	\N	\N
2124	UMP	N	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11010L	\N	\N
2136	SOC	N	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11074Q	\N	\N
2315	UMP	N	2011-10-01 00:00:00	2012-10-22 00:00:00	ANCIEN	\N	\N	\N	\N	09001P	\N	\N
2317	UC	N	2011-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04040A	\N	\N
2318	UC	N	2011-10-01 00:00:00	2019-06-13 00:00:00	ANCIEN	\N	\N	\N	\N	08056B	\N	\N
2335	RDSE	N	2011-10-27 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	\N	2017-10-03 16:43:56
2321	UC	N	2011-10-01 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	98032R	\N	2015-06-12 15:59:49
2332	NI	N	2011-10-11 00:00:00	2011-10-17 00:00:00	ANCIEN	\N	\N	\N	\N	11084S	\N	\N
2336	UMP	A	2011-11-02 00:00:00	2012-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	11003M	\N	\N
2324	UMP	N	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	99004R	\N	\N
2341	UMP	N	2011-12-01 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	\N	\N
2192	SOC	N	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11106F	\N	2017-09-24 19:14:37
2354	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	\N	\N
2194	UC	N	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11093T	\N	2017-09-24 12:57:09
2355	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04059M	\N	\N
2328	UMP	R	2011-10-01 00:00:00	2012-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	04033B	\N	\N
2356	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04054G	\N	\N
2198	UMP	N	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11103C	\N	\N
2330	UMP	R	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89013M	\N	2014-09-28 17:05:42
2203	SOC	N	2011-10-01 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	11107G	\N	2017-06-29 09:54:00
2204	SOC	N	2011-10-01 00:00:00	2015-04-07 00:00:00	ANCIEN	\N	\N	\N	\N	11108H	\N	2015-04-07 16:50:27
2206	UC	N	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11111C	\N	2017-09-24 16:45:26
2207	SOC	N	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11110B	\N	2014-10-07 00:00:00
2357	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04040A	\N	\N
2358	AUCUN	N	2011-10-01 00:00:00	2011-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	11018G	\N	\N
2359	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	\N	\N
2211	UMP	N	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11101A	\N	\N
2213	SOC	N	2011-10-01 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	11114F	\N	2017-06-29 09:53:43
2360	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04066L	\N	\N
2361	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	\N	\N
2219	SOC	N	2011-10-01 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	11072N	\N	2017-06-29 09:54:50
2363	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04046G	\N	\N
2364	AUCUN	N	2010-03-16 00:00:00	2010-03-21 00:00:00	ANCIEN	\N	\N	\N	\N	10003H	\N	\N
2365	AUCUN	N	2009-09-10 00:00:00	2009-09-15 00:00:00	ANCIEN	\N	\N	\N	\N	09012S	\N	\N
2367	AUCUN	N	2011-10-01 00:00:00	2011-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	11081P	\N	\N
2368	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04052E	\N	\N
2226	SOC	N	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11105E	\N	2017-09-24 18:20:10
2227	SOC	N	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11104D	\N	\N
2228	SOC	N	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	11027H	\N	\N
2229	SOC	N	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11026G	\N	\N
2369	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04063H	\N	\N
2377	UMP	N	2012-06-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01048V	\N	\N
2376	UC	N	2012-06-17 00:00:00	2014-04-23 00:00:00	ANCIEN	\N	\N	\N	\N	95049N	\N	2014-04-23 09:56:25
2378	UMP	N	2012-06-17 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	86044G	\N	2014-10-09 09:10:11
2380	SOC	N	2012-07-22 00:00:00	2014-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	12038D	\N	2014-05-05 10:35:50
2235	UMP	N	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11088W	\N	2017-09-24 17:15:15
2236	SOC	N	2011-10-01 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	\N	2017-06-29 09:55:04
2381	RDSE	N	2012-07-22 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	12039E	\N	2014-05-05 10:35:23
2239	UMP	N	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11020A	\N	2017-09-24 16:24:51
2240	UMP	N	2011-10-01 00:00:00	2014-07-01 00:00:00	ANCIEN	\N	\N	\N	\N	11022C	\N	2014-07-01 09:29:53
2382	ECO	N	2012-07-22 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	12040W	\N	2014-05-05 10:33:42
2242	SOC	N	2011-10-01 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	11025F	\N	2017-06-29 09:55:31
2248	SOC	N	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11045K	\N	2017-06-19 00:00:00
2250	SOC	N	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11061K	\N	2017-09-24 17:42:25
2251	SOC	N	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11059R	\N	2017-09-24 17:42:26
2252	SOC	N	2011-10-01 00:00:00	2013-02-28 00:00:00	ANCIEN	\N	\N	\N	\N	11062L	\N	\N
2254	UMP	N	2011-10-01 00:00:00	2016-01-11 00:00:00	ANCIEN	\N	\N	\N	\N	11060J	\N	2016-01-11 17:34:09
2255	CRC	N	2011-10-01 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	11063M	\N	\N
2344	ECO	N	2012-01-11 00:00:00	2017-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	04067M	\N	2017-06-30 09:58:09
2259	CRC	N	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11056N	\N	\N
2347	ECO	N	2012-01-11 00:00:00	2017-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	11065P	\N	2017-06-30 09:52:11
2348	ECO	N	2012-01-11 00:00:00	2017-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	11055M	\N	2017-06-30 09:52:11
2264	SOC	N	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11066Q	\N	\N
2266	SOC	R	2011-10-01 00:00:00	2012-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	11065P	\N	\N
2351	ECO	N	2012-01-11 00:00:00	2017-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	11099A	\N	2017-06-30 09:52:11
2268	UC	N	2011-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	11064N	\N	2017-10-03 16:54:08
2384	CRC	N	2012-09-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	12041X	\N	\N
2270	UMP	N	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11043H	\N	\N
2271	SOC	N	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11041F	\N	2017-06-19 00:00:00
2389	UMP	R	2012-12-04 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95036H	\N	2014-09-28 17:31:42
2393	SOC	N	2013-03-01 00:00:00	2016-03-08 00:00:00	ANCIEN	\N	\N	\N	\N	13002U	\N	2017-09-24 17:42:26
2288	SOC	N	2011-10-01 00:00:00	2018-10-15 00:00:00	ANCIEN	\N	\N	\N	\N	11077T	\N	\N
1126	GDSRG	N	\N	1978-08-27 00:00:00	ANCIEN	\N	\N	\N	\N	000602	\N	\N
1127	RPR	N	\N	1995-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	58115W	\N	\N
1128	UC	N	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000218	\N	\N
1129	UREI	N	\N	1981-10-09 00:00:00	ANCIEN	\N	\N	\N	\N	000186	\N	\N
1130	RPR	N	\N	1993-01-18 00:00:00	ANCIEN	\N	\N	\N	\N	000310	\N	\N
1131	SOC	A	\N	1978-06-09 00:00:00	ANCIEN	\N	\N	\N	\N	000406	\N	\N
1132	SOC	N	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000185	\N	\N
1133	GD	N	\N	1981-09-29 00:00:00	ANCIEN	\N	\N	\N	\N	000243	\N	\N
1134	GD	N	\N	1965-02-10 00:00:00	ANCIEN	\N	\N	\N	\N	000040	\N	\N
1135	RI	N	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000273	\N	\N
1136	RPR	N	\N	1983-04-18 00:00:00	ANCIEN	\N	\N	\N	\N	000308	\N	\N
1137	NI	N	\N	1975-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	000403	\N	\N
1138	UCDP	N	\N	1983-07-28 00:00:00	ANCIEN	\N	\N	\N	\N	000207	\N	\N
1139	SOC	N	\N	1986-04-02 00:00:00	ANCIEN	\N	\N	\N	\N	000630	\N	\N
1140	C	N	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	58348N	\N	\N
1141	RPR	N	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59539X	\N	\N
1142	SOC	N	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000171	\N	\N
1143	GD	N	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58650R	\N	\N
1144	UREI	N	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58039C	\N	\N
1146	UC	N	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59540Q	\N	\N
1147	NI	N	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000225	\N	\N
1148	UNR	N	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	57208W	\N	\N
1149	UCDP	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000348	\N	\N
1150	RPR	N	\N	1991-11-03 00:00:00	ANCIEN	\N	\N	\N	\N	000516	\N	\N
1151	UCDP	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000149	\N	\N
1152	UCDP	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000213	\N	\N
1153	C	N	\N	1962-12-06 00:00:00	ANCIEN	\N	\N	\N	\N	000124	\N	\N
1154	UREI	N	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58945E	\N	\N
1155	GD	N	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000068	\N	\N
1156	UREI	N	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58913V	\N	\N
1157	UCDP	N	\N	1980-07-28 00:00:00	ANCIEN	\N	\N	\N	\N	000458	\N	\N
1158	RI	N	\N	1981-11-22 00:00:00	ANCIEN	\N	\N	\N	\N	000237	\N	\N
1159	GD	N	\N	1975-07-29 00:00:00	ANCIEN	\N	\N	\N	\N	000231	\N	\N
1160	RI	N	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000153	\N	\N
1161	CRARS	N	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	57449N	\N	\N
1162	GD	N	\N	1967-04-18 00:00:00	ANCIEN	\N	\N	\N	\N	000086	\N	\N
1163	UREI	N	\N	1974-10-13 00:00:00	ANCIEN	\N	\N	\N	\N	000063	\N	\N
1164	C	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	57728S	\N	\N
1165	UC	N	\N	1998-02-16 00:00:00	ANCIEN	\N	\N	\N	\N	92028U	\N	\N
1166	SOC	N	\N	1967-04-03 00:00:00	ANCIEN	\N	\N	\N	\N	56812H	\N	\N
1167	SOC	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000230	\N	\N
1169	GD	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000219	\N	\N
1170	SOC	N	\N	1995-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	000107	\N	\N
1171	SOC	N	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59541R	\N	\N
1173	UC	N	\N	1994-07-15 00:00:00	ANCIEN	\N	\N	\N	\N	000456	\N	\N
1174	GD	N	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000042	\N	\N
1175	RPR	N	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59542S	\N	\N
1177	SOC	N	\N	1972-12-05 00:00:00	ANCIEN	\N	\N	\N	\N	000093	\N	\N
1178	SOC	N	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58626R	\N	\N
1179	UCDP	N	\N	1983-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	000170	\N	\N
1180	C	N	\N	1981-07-23 00:00:00	ANCIEN	\N	\N	\N	\N	58652T	\N	\N
1182	UC	N	\N	1993-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	000442	\N	\N
1183	SOC	N	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58941A	\N	\N
1184	GD	N	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000248	\N	\N
1186	C	N	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000280	\N	\N
1187	UREI	N	\N	1989-01-30 00:00:00	ANCIEN	\N	\N	\N	\N	000201	\N	\N
1188	RDE	N	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000531	\N	\N
1190	UC	N	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000320	\N	\N
1191	RDE	N	\N	1995-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	59545V	\N	\N
1192	C	N	\N	1978-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	57830P	\N	\N
1193	CRARS	N	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	57130R	\N	\N
1195	SOC	N	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000005	\N	\N
1196	UNR	N	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000200	\N	\N
1197	UC	N	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59546W	\N	\N
1199	SOC	N	\N	1990-08-11 00:00:00	ANCIEN	\N	\N	\N	\N	000351	\N	\N
1200	SOC	N	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59547X	\N	\N
1201	RI	N	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59548Y	\N	\N
1202	RIAS	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000004	\N	\N
1204	SOC	N	\N	1982-08-15 00:00:00	ANCIEN	\N	\N	\N	\N	000633	\N	\N
1205	GD	N	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000223	\N	\N
1206	UCDP	N	\N	1973-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	000518	\N	\N
1208	UREI	N	\N	1981-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	59715V	\N	\N
1209	RI	N	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	56406W	\N	\N
1210	NI	N	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000236	\N	\N
1212	RPR	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	57749X	\N	\N
1213	RI	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000227	\N	\N
1214	C	N	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58633Q	\N	\N
1215	RDE	N	\N	1993-11-07 00:00:00	ANCIEN	\N	\N	\N	\N	000561	\N	\N
1216	UREI	N	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59235J	\N	\N
1217	NI	N	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	57456M	\N	\N
1218	C	N	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58621L	\N	\N
1219	GD	N	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000136	\N	\N
1220	RPR	N	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58939G	\N	\N
1221	GD	N	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000080	\N	\N
1222	UC	N	\N	1997-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	88011F	\N	\N
1223	SOC	N	\N	1982-03-20 00:00:00	ANCIEN	\N	\N	\N	\N	000269	\N	\N
1224	SOC	N	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000502	\N	\N
1225	RPR	N	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59550S	\N	\N
1226	UCDP	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000179	\N	\N
1227	UREI	N	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000355	\N	\N
1228	UCDP	N	\N	1970-08-19 00:00:00	ANCIEN	\N	\N	\N	\N	000233	\N	\N
1229	GD	N	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000337	\N	\N
1230	GD	N	\N	1988-06-24 00:00:00	ANCIEN	\N	\N	\N	\N	59717X	\N	\N
1231	UCDP	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000050	\N	\N
1232	SOC	N	\N	1979-06-05 00:00:00	ANCIEN	\N	\N	\N	\N	000129	\N	\N
1233	SOC	N	\N	1996-09-10 00:00:00	ANCIEN	\N	\N	\N	\N	92038W	\N	\N
1234	CNIP	N	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000102	\N	\N
1235	UNR	N	\N	1959-05-28 00:00:00	ANCIEN	\N	\N	\N	\N	000025	\N	\N
1236	C	N	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58635S	\N	\N
1237	RI	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000356	\N	\N
1238	NI	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	58003P	\N	\N
1239	SOC	N	\N	1962-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000065	\N	\N
1240	SOC	N	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000070	\N	\N
1241	RI	N	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59551T	\N	\N
1242	RPR	N	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59552U	\N	\N
1243	SOC	N	\N	1981-08-29 00:00:00	ANCIEN	\N	\N	\N	\N	000103	\N	\N
1244	GD	N	\N	1962-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	000379	\N	\N
1245	RDE	N	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58914W	\N	\N
1246	UNR	N	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000034	\N	\N
1247	CRARS	N	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000069	\N	\N
1248	CRARS	N	\N	1977-10-05 00:00:00	ANCIEN	\N	\N	\N	\N	000033	\N	\N
1249	GD	N	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000022	\N	\N
560	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01052R	\N	\N
561	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01053S	\N	\N
562	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01054T	\N	\N
563	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01055U	\N	\N
564	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01056V	\N	\N
565	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01057W	\N	\N
566	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01058X	\N	\N
567	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	\N	\N
568	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	83042R	\N	\N
569	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01060R	\N	\N
570	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01061S	\N	\N
571	AUCUN	N	2001-10-01 00:00:00	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01062T	\N	2017-06-19 15:56:26
572	UC	N	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	01006K	\N	\N
573	SOC	N	2001-10-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01031L	\N	2017-09-24 18:20:10
574	RPR	N	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	01008M	\N	\N
575	RDSE	N	2001-10-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01046T	\N	2017-09-24 13:44:49
576	UC	N	2001-10-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01049W	\N	\N
577	RI	N	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	01005J	\N	\N
578	SOC	R	2001-10-02 00:00:00	2012-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	01044R	\N	\N
579	SOC	N	2001-10-02 00:00:00	2012-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01051Q	\N	\N
580	CRC	N	2001-10-02 00:00:00	2007-01-01 00:00:00	ANCIEN	\N	\N	\N	\N	01035Q	\N	\N
581	SOC	N	2001-10-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01012H	\N	\N
582	CRC	N	2001-10-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01059Y	\N	2017-09-24 17:35:15
583	CRC	N	2001-10-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01013J	\N	2017-09-24 17:06:55
584	UC	N	2001-10-02 00:00:00	2014-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	01052R	\N	2014-11-04 11:22:47
585	NI	N	2001-10-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01045S	\N	\N
586	CRC	N	2001-10-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01015L	\N	2017-09-24 17:19:42
588	RPR	N	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	01027Q	\N	\N
589	RPR	R	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	01041N	\N	\N
591	RPR	N	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	01026P	\N	\N
592	UC	N	2001-10-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01025N	\N	2014-10-07 00:00:00
593	SOC	N	2001-10-02 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	01037S	\N	2016-12-12 16:10:14
594	UC	N	2001-10-02 00:00:00	2010-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	01017N	\N	\N
595	SOC	N	2001-10-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01053S	\N	\N
596	UC	N	2001-10-02 00:00:00	2007-01-07 00:00:00	ANCIEN	\N	\N	\N	\N	01055U	\N	\N
597	SOC	N	2001-10-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01011G	\N	2017-09-24 16:43:43
598	UC	N	2001-10-02 00:00:00	2017-11-02 00:00:00	ANCIEN	\N	\N	\N	\N	01007L	\N	2017-11-03 10:47:39
599	RPR	N	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	01057W	\N	\N
600	RPR	N	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	01040M	\N	\N
601	RI	N	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	01033N	\N	\N
602	SOC	N	2001-10-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01022K	\N	2017-09-24 17:14:26
603	RI	N	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	01030K	\N	\N
604	UC	N	2001-10-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01021J	\N	\N
605	SOC	N	2001-10-02 00:00:00	2006-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	01032M	\N	\N
606	RPR	N	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	01018P	\N	\N
607	RPR	N	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	01042P	\N	\N
608	RPR	N	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	01061S	\N	\N
609	UC	N	2001-10-02 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	01043Q	\N	\N
610	RI	N	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	01048V	\N	\N
611	SOC	N	2001-10-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83042R	\N	\N
612	RPR	N	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	01060R	\N	\N
613	CRC	N	2001-10-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01038T	\N	\N
614	SOC	N	2001-10-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01020H	\N	\N
615	UC	N	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	01054T	\N	\N
616	UC	N	2001-10-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01009N	\N	\N
617	SOC	N	2001-10-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01016M	\N	2017-09-24 17:09:24
619	SOC	N	2001-10-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01014K	\N	2017-09-24 17:19:42
620	RPR	R	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	01029S	\N	\N
621	SOC	N	2001-10-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01036R	\N	\N
622	RI	N	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	01019Q	\N	\N
623	RPR	N	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	01058X	\N	\N
624	RDSE	N	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	01050P	\N	\N
625	SOC	N	2001-10-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01028R	\N	\N
626	UC	N	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	01039U	\N	\N
627	SOC	N	2001-10-02 00:00:00	2014-12-21 00:00:00	ANCIEN	\N	\N	\N	\N	01062T	\N	2017-06-19 15:56:26
628	RPR	N	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	01056V	\N	\N
629	UC	N	2001-10-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01034P	\N	\N
630	SOC	N	2001-10-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01023L	\N	\N
631	UC	N	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	01010F	\N	\N
632	UC	N	2001-10-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01047U	\N	2017-09-24 13:29:42
633	CRC	N	1992-10-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92018S	\N	2017-09-24 18:16:52
129	SOC	N	\N	2001-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	83012K	\N	\N
634	CRC	R	2001-10-02 00:00:00	2009-05-12 00:00:00	ANCIEN	\N	\N	\N	\N	83012K	\N	\N
635	UC	N	2001-10-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01024M	\N	\N
636	RI	N	2001-10-02 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	95004Y	\N	\N
637	RDSE	R	2001-10-02 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86021Y	\N	\N
638	RPR	N	2001-10-10 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	01063U	\N	\N
639	NI	N	2001-10-15 00:00:00	2001-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	01064V	\N	\N
640	RI	N	2001-11-06 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	01064V	\N	\N
641	RPR	A	2001-11-22 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	98033S	\N	\N
642	NI	N	2001-12-02 00:00:00	2001-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	01065W	\N	\N
643	RDSE	N	2001-12-04 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01065W	\N	2014-09-28 12:09:44
644	AUCUN	N	2002-01-20 00:00:00	2002-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	02001J	\N	\N
645	SOC	N	2002-01-25 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	02001J	\N	\N
646	NI	N	2002-06-07 00:00:00	2002-06-19 00:00:00	ANCIEN	\N	\N	\N	\N	02002K	\N	\N
647	AUCUN	N	2002-06-08 00:00:00	2002-06-10 00:00:00	ANCIEN	\N	\N	\N	\N	02003L	\N	\N
648	NI	N	2002-06-08 00:00:00	2002-06-19 00:00:00	ANCIEN	\N	\N	\N	\N	02004M	\N	\N
649	NI	N	2002-06-08 00:00:00	2002-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	02005N	\N	\N
650	RPR	A	2002-06-10 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	02003L	\N	\N
651	UC	N	2002-06-19 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	02004M	\N	\N
652	RI	N	2002-06-20 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	02002K	\N	\N
655	UC	N	2002-06-28 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	02005N	\N	\N
660	NI	N	2002-07-18 00:00:00	2002-07-30 00:00:00	ANCIEN	\N	\N	\N	\N	02006P	\N	\N
661	RI	N	2002-07-30 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	02006P	\N	\N
662	RDSE	N	2002-09-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95043G	\N	\N
664	RPR	N	2002-10-01 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	02007Q	\N	\N
190	RPR	N	\N	2002-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77009C	\N	\N
665	RPR	N	2002-10-01 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	59312E	\N	\N
666	UMP	N	2002-12-11 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	\N	98043U	\N	\N
667	UMP	N	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	88012G	\N	\N
668	UMP	N	2002-12-11 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	\N	96005E	\N	\N
669	UMP	N	2002-12-11 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	94003T	\N	2014-09-28 13:16:32
670	UMP	N	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89010J	\N	\N
671	UMP	N	2002-12-11 00:00:00	2014-04-24 00:00:00	ANCIEN	\N	\N	\N	\N	89014N	\N	2014-04-25 17:05:01
672	UMP	N	2002-12-11 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	\N	89045V	\N	\N
673	UMP	N	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	88009M	\N	\N
674	UMP	N	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80041C	\N	\N
675	UMP	N	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86006A	\N	\N
676	UMP	N	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80046H	\N	\N
677	UMP	N	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	93005R	\N	\N
678	UMP	N	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95016D	\N	\N
679	UMP	N	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89030N	\N	\N
680	UMP	N	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92030N	\N	\N
681	UMP	N	2002-12-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	97011G	\N	\N
682	UMP	N	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	78006D	\N	\N
683	UMP	N	2002-12-11 00:00:00	2011-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	82002D	\N	\N
684	UMP	N	2002-12-11 00:00:00	2020-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	96004D	\N	\N
685	UMP	N	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83050R	\N	\N
686	UMP	N	2002-12-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92031P	\N	2017-09-24 18:16:52
687	UMP	N	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	\N	\N
688	UMP	N	2002-12-11 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	\N	92035T	\N	2015-01-08 17:14:28
689	UMP	N	2002-12-11 00:00:00	2007-02-25 00:00:00	ANCIEN	\N	\N	\N	\N	92024Q	\N	\N
690	UMP	N	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86028G	\N	\N
691	UMP	N	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	93003P	\N	\N
692	UMP	R	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77046H	\N	\N
693	UMP	N	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77013X	\N	\N
694	UMP	N	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83021L	\N	\N
695	UMP	N	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	92011K	\N	\N
696	UMP	N	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	91002E	\N	\N
697	UMP	N	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95029J	\N	\N
698	UMP	N	2002-12-11 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	86030A	\N	\N
699	UMP	N	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86047K	\N	\N
700	UMP	N	2002-12-11 00:00:00	2003-11-04 00:00:00	ANCIEN	\N	\N	\N	\N	86031B	\N	\N
701	UMP	N	2002-12-11 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	95020Y	\N	2015-06-12 16:01:25
702	UMP	N	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77012W	\N	\N
703	UMP	N	2002-12-11 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95034F	\N	2014-09-28 18:00:58
704	UMP	N	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83003J	\N	\N
1676	SOC	N	2004-10-05 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04046G	\N	2014-09-28 17:07:41
1677	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04047H	\N	\N
1679	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04048J	\N	\N
1680	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	\N	\N
1681	CRC	N	2004-10-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04050C	\N	\N
1682	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04051D	\N	\N
1683	SOC	N	2004-10-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04052E	\N	\N
1684	SOC	N	2004-10-05 00:00:00	2012-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	\N	\N
1686	CRC	N	2004-10-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04054G	\N	2017-09-24 17:18:03
1687	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04055H	\N	\N
1688	SOC	N	2004-10-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04056J	\N	2017-09-24 18:17:56
1689	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04057K	\N	\N
1690	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04058L	\N	\N
1691	SOC	N	2004-10-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04059M	\N	\N
1692	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04060E	\N	\N
1694	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04062G	\N	\N
1695	SOC	R	2004-10-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04063H	\N	\N
1697	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04064J	\N	\N
1698	SOC	N	2004-10-05 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	04065K	\N	\N
1699	SOC	N	2004-10-05 00:00:00	2017-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	04066L	\N	2017-06-30 09:47:45
1700	SOC	R	2004-10-05 00:00:00	2012-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	04067M	\N	\N
1701	SOC	N	2004-10-05 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	04068N	\N	\N
1702	SOC	N	2004-10-01 00:00:00	2008-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	86039K	\N	\N
1703	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04069P	\N	\N
1704	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04070G	\N	\N
1705	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04071H	\N	\N
1706	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04072J	\N	\N
1707	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04073K	\N	\N
1708	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	95051G	\N	\N
1709	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04074L	\N	\N
1710	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04075M	\N	\N
1711	SOC	N	2004-10-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04076N	\N	\N
1712	SOC	N	2004-10-05 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	04077P	\N	2017-06-29 09:54:25
1713	CRC	N	2004-10-05 00:00:00	2012-09-13 00:00:00	ANCIEN	\N	\N	\N	\N	04078Q	\N	\N
1714	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	77053G	\N	\N
1715	SOC	N	2004-10-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04079R	\N	2017-09-24 17:47:27
1716	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04080J	\N	\N
1717	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04081K	\N	\N
1718	SOC	R	2004-10-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04082L	\N	\N
1719	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04083M	\N	\N
1720	SOC	N	2004-10-05 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04084N	\N	2014-09-28 13:40:33
1721	CRC	N	2004-10-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04085P	\N	\N
1723	SOC	N	2004-10-05 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04087R	\N	2014-09-28 13:39:20
1724	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04088S	\N	\N
256	RDSE	N	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95023C	\N	\N
1725	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04089T	\N	\N
1726	SOC	N	2004-10-05 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	04090L	\N	\N
1727	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04091M	\N	\N
1730	SOC	N	2004-10-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04094Q	\N	2017-09-25 10:58:49
1734	UMP	N	2004-10-05 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04091M	\N	2014-09-28 17:55:39
1735	UMP	N	2004-10-05 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04073K	\N	2014-09-28 18:58:25
1736	UMP	N	2004-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	04047H	\N	2014-10-07 15:28:02
1737	UC	N	2004-10-05 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04051D	\N	2014-09-28 17:07:41
1738	UC	N	2004-10-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04089T	\N	\N
1739	UMP	N	2004-10-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04042C	\N	\N
1740	UMP	N	2004-10-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04055H	\N	2017-09-24 18:05:41
1741	UC	N	2004-10-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04064J	\N	\N
1742	UMP	N	2004-10-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04081K	\N	2017-09-24 19:25:10
1743	UC	N	2004-10-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04037F	\N	\N
1744	UC	N	2004-10-05 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04083M	\N	2014-09-28 16:40:50
1745	UC	N	2004-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	04070G	\N	\N
1746	UC	N	2004-10-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04080J	\N	2017-09-24 17:47:27
1747	UMP	N	2004-10-05 00:00:00	2008-04-18 00:00:00	ANCIEN	\N	\N	\N	\N	95031C	\N	\N
1748	RDSE	N	2004-10-05 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	80031A	\N	\N
1749	UMP	N	2004-10-05 00:00:00	2004-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	02009S	\N	\N
1750	RDSE	N	2004-10-05 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89041R	\N	\N
2314	NI	N	2011-09-26 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	07003H	\N	2014-09-28 12:21:28
1751	RDSE	N	2004-10-05 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01039U	\N	\N
1753	UMP	N	2004-10-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04035D	\N	2014-10-07 00:00:00
1754	UMP	N	2004-10-05 00:00:00	2007-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	04072J	\N	\N
1755	UMP	N	2004-10-05 00:00:00	2007-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04060E	\N	\N
1756	UMP	N	2004-10-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04075M	\N	\N
1757	UMP	N	2004-10-05 00:00:00	2016-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	04048J	\N	2016-12-01 10:36:51
1758	UMP	N	2004-10-05 00:00:00	2017-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	04041B	\N	2017-09-24 11:09:53
1759	UMP	N	2004-10-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04062G	\N	\N
1760	UMP	N	2004-10-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04036E	\N	2017-09-24 18:59:59
1761	UMP	N	2004-10-05 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	04061F	\N	\N
1762	UMP	N	2004-10-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04049K	\N	\N
1763	UMP	N	2004-10-05 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	04057K	\N	2017-10-03 16:54:49
1728	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04092N	\N	\N
1764	UMP	N	2004-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	04092N	\N	\N
1765	UMP	N	2004-10-05 00:00:00	2004-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	95051G	\N	\N
1766	UMP	N	2004-10-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04088S	\N	\N
1767	UMP	N	2004-10-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04074L	\N	2017-09-24 17:15:15
1671	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04043D	\N	\N
1768	UMP	N	2004-10-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04043D	\N	\N
1650	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	95059Q	\N	\N
1769	UMP	N	2004-10-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	\N	2014-10-07 15:27:58
1770	UMP	A	2004-10-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04058L	\N	\N
1771	UMP	A	2004-10-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77053G	\N	\N
1772	UMP	A	2004-10-05 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	04069P	\N	\N
1722	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	\N	\N
1773	UMP	R	2004-10-05 00:00:00	2011-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	04086Q	\N	\N
1729	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04093P	\N	\N
1774	UMP	R	2004-10-05 00:00:00	2005-02-24 00:00:00	ANCIEN	\N	\N	\N	\N	04093P	\N	\N
1775	NI	N	2004-10-05 00:00:00	2007-07-16 00:00:00	ANCIEN	\N	\N	\N	\N	04071H	\N	\N
1776	NI	N	2004-10-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04033B	\N	\N
1777	UMP	N	2004-10-05 00:00:00	2004-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	95059Q	\N	\N
1778	UC	N	2004-10-06 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89042S	\N	\N
1779	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04067M	\N	\N
2316	CRC	N	2011-10-01 00:00:00	2016-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	96003C	\N	2016-11-14 11:07:47
1781	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04078Q	\N	\N
1782	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04068N	\N	\N
1783	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04077P	\N	\N
1784	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04094Q	\N	\N
1785	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04076N	\N	\N
1786	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04079R	\N	\N
1787	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04084N	\N	\N
1788	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04090L	\N	\N
1789	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04065K	\N	\N
1790	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04045F	\N	\N
1791	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04056J	\N	\N
1792	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04050C	\N	\N
1793	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04039H	\N	\N
1794	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04082L	\N	\N
1795	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	\N	\N
1799	UMP	N	2004-10-21 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04097T	\N	2014-10-08 09:41:07
1801	UMP	N	2004-11-02 00:00:00	2005-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	04098U	\N	\N
1802	UMP	N	2004-11-02 00:00:00	2005-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	04099V	\N	\N
1803	UMP	N	2004-11-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04100U	\N	\N
804	UMP	N	2002-12-11 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	92005M	\N	\N
1804	NI	N	2004-12-24 00:00:00	2005-01-17 00:00:00	ANCIEN	\N	\N	\N	\N	04101V	\N	\N
1805	SOC	N	2005-01-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04101V	\N	\N
1806	NI	N	2005-02-21 00:00:00	2005-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	95036H	\N	\N
1807	NI	N	2005-02-21 00:00:00	2005-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	04061F	\N	\N
1808	NI	N	2005-02-21 00:00:00	2005-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	92005M	\N	\N
1809	NI	N	2005-02-21 00:00:00	2005-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	04065K	\N	\N
1810	NI	N	2005-02-21 00:00:00	2005-02-22 00:00:00	ANCIEN	\N	\N	\N	\N	04069P	\N	\N
1811	UMP	N	2005-02-22 00:00:00	2012-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	95036H	\N	\N
1813	UMP	N	2005-02-22 00:00:00	2010-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	92005M	\N	\N
1814	UMP	A	2005-02-22 00:00:00	2005-11-15 00:00:00	ANCIEN	\N	\N	\N	\N	04069P	\N	\N
1815	SOC	N	2005-02-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04065K	\N	2014-09-28 17:31:41
1816	CRC	N	2005-02-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	05001W	\N	\N
1817	UMP	R	2005-02-22 00:00:00	2019-04-03 00:00:00	ANCIEN	\N	\N	\N	\N	04061F	\N	2014-10-07 15:28:09
1818	CRC	R	2005-03-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89021M	\N	\N
1819	UMP	N	2005-02-25 00:00:00	2010-05-17 00:00:00	ANCIEN	\N	\N	\N	\N	04093P	\N	\N
1820	NI	N	2005-06-19 00:00:00	2005-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	05011Y	\N	\N
1821	RDSE	N	2005-06-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	05011Y	\N	2014-09-28 13:47:05
1822	SOC	R	2005-06-28 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	80048K	\N	\N
1824	AUCUN	N	2005-09-19 00:00:00	2005-09-21 00:00:00	ANCIEN	\N	\N	\N	\N	05012A	\N	\N
1826	AUCUN	N	2005-09-19 00:00:00	2005-09-21 00:00:00	ANCIEN	\N	\N	\N	\N	02009S	\N	\N
1827	AUCUN	N	2005-09-19 00:00:00	2005-09-22 00:00:00	ANCIEN	\N	\N	\N	\N	95059Q	\N	\N
1828	UMP	N	2005-09-22 00:00:00	\N	ACTIF	\N	\N	\N	\N	05012A	\N	\N
1829	UMP	N	2005-09-22 00:00:00	2007-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	02009S	\N	\N
1830	UMP	N	2005-09-23 00:00:00	2017-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	95059Q	\N	2017-10-05 09:36:59
1831	UMP	N	2005-11-16 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04069P	\N	2014-09-28 17:31:41
1832	UNR	N	1961-11-13 00:00:00	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	05015D	\N	\N
1833	NI	N	2006-05-17 00:00:00	2006-05-22 00:00:00	ANCIEN	\N	\N	\N	\N	06001B	\N	\N
1834	SOC	N	2006-05-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	06001B	\N	\N
1835	NI	N	2006-07-09 00:00:00	2006-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	06004E	\N	\N
1836	SOC	N	2006-07-20 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	06004E	\N	\N
1839	SOC	N	2006-09-25 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	06006G	\N	\N
1840	NI	N	2007-01-03 00:00:00	2007-01-04 00:00:00	ANCIEN	\N	\N	\N	\N	07001F	\N	\N
1296	SOC	N	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000023	\N	\N
1297	CRARS	N	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000030	\N	\N
1299	SOC	N	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000307	\N	\N
1300	UCDP	N	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	58341F	\N	\N
1301	GD	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000143	\N	\N
1302	UREI	N	\N	1990-06-14 00:00:00	ANCIEN	\N	\N	\N	\N	000514	\N	\N
1304	RI	N	\N	1973-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	000543	\N	\N
1305	SOC	N	\N	1981-05-26 00:00:00	ANCIEN	\N	\N	\N	\N	57321W	\N	\N
1306	RI	N	\N	1998-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	96002B	\N	\N
1308	UC	N	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58916Y	\N	\N
1309	RI	N	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000108	\N	\N
1310	RI	N	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59556Y	\N	\N
1312	SOC	N	\N	1992-03-20 00:00:00	ANCIEN	\N	\N	\N	\N	000476	\N	\N
1313	RI	N	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000156	\N	\N
1314	RPR	N	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58917A	\N	\N
1315	UC	N	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59242H	\N	\N
1317	SOC	N	\N	1997-09-11 00:00:00	ANCIEN	\N	\N	\N	\N	88010E	\N	\N
1318	UCDP	N	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000202	\N	\N
1319	UC	N	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000275	\N	\N
1320	UREI	N	\N	1978-03-12 00:00:00	ANCIEN	\N	\N	\N	\N	000639	\N	\N
1321	SOC	N	\N	1977-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	000085	\N	\N
1322	UC	N	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58918B	\N	\N
1323	RI	N	\N	1959-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	000212	\N	\N
1324	SOC	N	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59245L	\N	\N
1325	SOC	N	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58926B	\N	\N
1326	RDE	N	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000104	\N	\N
1327	RPR	N	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000293	\N	\N
1328	RI	N	\N	1976-12-15 00:00:00	ANCIEN	\N	\N	\N	\N	000077	\N	\N
1329	CNIP	N	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000158	\N	\N
1330	SOC	N	\N	1997-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	\N	\N
1331	UNR	N	\N	1967-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	57310T	\N	\N
1332	RDE	N	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58938F	\N	\N
1333	UNR	N	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000142	\N	\N
1334	UC	N	\N	1997-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	77003V	\N	\N
1335	RDE	N	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58919C	\N	\N
1336	GD	N	\N	1984-12-25 00:00:00	ANCIEN	\N	\N	\N	\N	000125	\N	\N
1337	SOC	N	\N	1997-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	95064M	\N	\N
1338	GD	N	\N	1962-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	000281	\N	\N
1339	RI	N	\N	1959-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	56305S	\N	\N
1340	RPR	N	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59557A	\N	\N
1341	C	N	\N	1969-09-12 00:00:00	ANCIEN	\N	\N	\N	\N	000537	\N	\N
1342	RDE	N	\N	1995-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	59558B	\N	\N
1343	GD	N	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000174	\N	\N
1344	GD	N	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000128	\N	\N
1345	UDR	N	\N	1974-02-04 00:00:00	ANCIEN	\N	\N	\N	\N	000172	\N	\N
1346	C	N	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58638V	\N	\N
1347	SOC	N	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58929E	\N	\N
1348	SOC	N	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	57146A	\N	\N
1349	UREI	N	\N	1985-05-26 00:00:00	ANCIEN	\N	\N	\N	\N	000443	\N	\N
1350	SOC	N	\N	1997-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	95065N	\N	\N
1351	UC	N	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000214	\N	\N
1352	UC	N	\N	1992-03-05 00:00:00	ANCIEN	\N	\N	\N	\N	000505	\N	\N
1353	UREI	N	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58928D	\N	\N
1354	UNR	N	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000305	\N	\N
1355	UREI	N	\N	1983-05-31 00:00:00	ANCIEN	\N	\N	\N	\N	000453	\N	\N
1356	UC	N	\N	1989-01-09 00:00:00	ANCIEN	\N	\N	\N	\N	000564	\N	\N
1357	RPR	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	57752S	\N	\N
1358	UCDP	N	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	58336J	\N	\N
1359	UCDP	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	57738U	\N	\N
1360	UC	N	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59559C	\N	\N
1361	UREI	N	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000278	\N	\N
1362	C	N	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58662V	\N	\N
1363	UREI	N	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	58352J	\N	\N
1364	RPR	N	\N	1998-02-09 00:00:00	ANCIEN	\N	\N	\N	\N	74044S	\N	\N
1365	RI	N	\N	1960-05-09 00:00:00	ANCIEN	\N	\N	\N	\N	000147	\N	\N
1366	SOC	N	\N	1988-06-24 00:00:00	ANCIEN	\N	\N	\N	\N	59307H	\N	\N
1367	SOC	N	\N	1995-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	59581A	\N	\N
1368	UC	N	\N	1992-02-23 00:00:00	ANCIEN	\N	\N	\N	\N	000440	\N	\N
1369	NI	N	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000168	\N	\N
1370	UCDP	N	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000101	\N	\N
1371	UC	N	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000369	\N	\N
1372	RPR	N	\N	1993-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	000373	\N	\N
1373	UREI	N	\N	1980-11-18 00:00:00	ANCIEN	\N	\N	\N	\N	000364	\N	\N
1374	SOC	N	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000279	\N	\N
1375	UREI	N	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000452	\N	\N
1376	RPCD	N	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000123	\N	\N
1377	UDR	N	\N	1974-06-28 00:00:00	ANCIEN	\N	\N	\N	\N	000298	\N	\N
1379	SOC	N	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000334	\N	\N
1380	SOC	N	\N	1983-08-20 00:00:00	ANCIEN	\N	\N	\N	\N	000330	\N	\N
1381	SOC	N	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000287	\N	\N
1382	RPCD	N	\N	1966-10-14 00:00:00	ANCIEN	\N	\N	\N	\N	000499	\N	\N
1384	SOC	N	\N	1986-06-23 00:00:00	ANCIEN	\N	\N	\N	\N	000095	\N	\N
1385	RI	N	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59560U	\N	\N
1386	GDSRG	N	\N	1984-03-20 00:00:00	ANCIEN	\N	\N	\N	\N	000592	\N	\N
1388	UREI	N	\N	1978-10-13 00:00:00	ANCIEN	\N	\N	\N	\N	000006	\N	\N
1389	SOC	N	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000118	\N	\N
1390	C	N	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	56829S	\N	\N
1392	UCDP	N	\N	1981-09-09 00:00:00	ANCIEN	\N	\N	\N	\N	000268	\N	\N
1393	RI	N	\N	1996-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	83001G	\N	\N
1394	RPR	N	\N	1983-05-05 00:00:00	ANCIEN	\N	\N	\N	\N	000417	\N	\N
1395	SOC	N	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000301	\N	\N
1397	GD	N	\N	1982-11-17 00:00:00	ANCIEN	\N	\N	\N	\N	000405	\N	\N
1398	UREI	N	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59249Q	\N	\N
1399	RPR	N	\N	1988-05-10 00:00:00	ANCIEN	\N	\N	\N	\N	58808V	\N	\N
1401	RPR	N	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000311	\N	\N
1402	C	N	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	55510R	\N	\N
1403	UC	N	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59582B	\N	\N
1405	SOC	N	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000377	\N	\N
1406	CRARS	N	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000078	\N	\N
1407	SOC	N	\N	1974-10-19 00:00:00	ANCIEN	\N	\N	\N	\N	000154	\N	\N
1408	SOC	N	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58048D	\N	\N
1410	CRARS	N	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000055	\N	\N
1411	RIAS	N	\N	1975-07-21 00:00:00	ANCIEN	\N	\N	\N	\N	000283	\N	\N
1412	UC	N	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59251J	\N	\N
1414	SOC	N	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000117	\N	\N
1415	C	N	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59562W	\N	\N
1416	RI	N	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59563X	\N	\N
1417	RPCD	N	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000148	\N	\N
1419	GD	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000239	\N	\N
1420	UC	N	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58647W	\N	\N
1421	UNR	N	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000029	\N	\N
1422	UREI	N	\N	1979-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	000169	\N	\N
1423	UCDP	N	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	58355M	\N	\N
1424	UC	N	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58655W	\N	\N
1425	SOC	N	\N	1998-07-14 00:00:00	ANCIEN	\N	\N	\N	\N	74041P	\N	\N
1426	UREI	N	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000099	\N	\N
1427	SOC	N	\N	1986-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	000353	\N	\N
1428	SOC	N	\N	1986-07-16 00:00:00	ANCIEN	\N	\N	\N	\N	58613L	\N	\N
1429	RI	N	\N	1960-10-23 00:00:00	ANCIEN	\N	\N	\N	\N	000054	\N	\N
1430	SOC	N	\N	1983-05-10 00:00:00	ANCIEN	\N	\N	\N	\N	000376	\N	\N
1431	RI	N	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000391	\N	\N
1432	RPR	N	\N	1976-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	000018	\N	\N
1433	RI	N	\N	1996-01-24 00:00:00	ANCIEN	\N	\N	\N	\N	83022M	\N	\N
1434	UREI	N	\N	1987-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	000572	\N	\N
1435	C	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000058	\N	\N
1436	UREI	N	\N	1982-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	000089	\N	\N
809	UMP	N	2002-12-11 00:00:00	2004-06-01 00:00:00	ANCIEN	\N	\N	\N	\N	02004M	\N	\N
810	UMP	N	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95045J	\N	\N
811	UMP	N	2002-12-11 00:00:00	2007-01-25 00:00:00	ANCIEN	\N	\N	\N	\N	89006N	\N	\N
812	UMP	N	2002-12-11 00:00:00	2008-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	98027U	\N	\N
813	UMP	N	2002-12-11 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	\N	95039L	\N	2015-10-13 14:17:47
814	UMP	N	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77029G	\N	\N
815	UMP	N	2002-12-11 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95038K	\N	2014-09-28 17:40:23
816	UMP	N	2002-12-11 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	95036H	\N	\N
817	UMP	R	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98047Y	\N	\N
818	UMP	N	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95033E	\N	\N
819	UMP	N	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83031N	\N	\N
820	UMP	N	2002-12-11 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95028H	\N	2014-09-28 12:56:42
821	UMP	R	2002-12-11 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98024R	\N	\N
822	UMP	N	2002-12-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	77002U	\N	2017-09-24 18:59:59
823	UMP	N	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98014P	\N	\N
824	UMP	N	2002-12-11 00:00:00	2007-11-21 00:00:00	ANCIEN	\N	\N	\N	\N	89020L	\N	\N
825	UMP	N	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89013M	\N	\N
826	UMP	N	2002-12-11 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95009E	\N	2014-09-28 12:56:42
827	UMP	N	2002-12-11 00:00:00	2007-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	92007P	\N	\N
828	UMP	R	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89018S	\N	\N
829	UMP	N	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01006K	\N	\N
281	UC	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	68036E	\N	\N
236	UC	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	95038K	\N	\N
255	UC	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	95028H	\N	\N
830	UC	N	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	01050P	\N	\N
831	UMP	R	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	90002A	\N	\N
832	UMP	N	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	77019E	\N	\N
135	RDSE	N	\N	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	\N	83033Q	\N	\N
833	UMP	N	2002-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	83033Q	\N	\N
834	UMP	N	2002-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	78003A	\N	\N
835	UMP	A	2002-12-11 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	80031A	\N	\N
836	RDSE	N	2002-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	59569E	\N	\N
840	UMP	N	2003-01-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01041N	\N	2017-09-24 18:59:59
839	UMP	N	2003-01-15 00:00:00	2014-07-08 00:00:00	ANCIEN	\N	\N	\N	\N	98018T	\N	2014-07-09 18:28:14
855	AUCUN	N	2003-02-09 00:00:00	2003-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	03001N	\N	\N
856	SOC	N	2003-02-12 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	03001N	\N	2014-09-28 13:40:33
859	CRC	N	\N	1997-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	95010W	\N	\N
860	GDSRG	N	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	58328J	\N	\N
861	GDSRG	N	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000083	\N	\N
862	UC	N	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59567C	\N	\N
863	NI	N	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	57426F	\N	\N
864	CRARS	N	\N	1971-02-25 00:00:00	ANCIEN	\N	\N	\N	\N	000165	\N	\N
865	SOC	N	\N	1993-08-27 00:00:00	ANCIEN	\N	\N	\N	\N	000634	\N	\N
866	UC	N	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59218H	\N	\N
867	GD	N	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000176	\N	\N
868	RDE	N	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58920U	\N	\N
869	SOC	N	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58921V	\N	\N
870	GD	N	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58619S	\N	\N
871	RI	N	\N	1973-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	000160	\N	\N
872	GD	N	\N	1981-01-03 00:00:00	ANCIEN	\N	\N	\N	\N	000198	\N	\N
873	UC	N	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58654V	\N	\N
874	C	N	\N	1969-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	000081	\N	\N
875	C	N	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58620K	\N	\N
876	SOC	N	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000328	\N	\N
877	RP	N	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000316	\N	\N
878	UNR	N	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000013	\N	\N
879	SOC	N	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59217G	\N	\N
880	NI	N	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	57701F	\N	\N
881	NI	N	\N	1961-11-12 00:00:00	ANCIEN	\N	\N	\N	\N	000021	\N	\N
882	UREI	N	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000321	\N	\N
883	SOC	N	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000047	\N	\N
884	SOC	N	\N	1988-06-24 00:00:00	ANCIEN	\N	\N	\N	\N	59309K	\N	\N
885	SOC	N	\N	1967-04-03 00:00:00	ANCIEN	\N	\N	\N	\N	58302X	\N	\N
886	UNR	N	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	56326X	\N	\N
887	GD	N	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000553	\N	\N
1570	UC	R	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58656X	\N	\N
1571	GD	R	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000162	\N	\N
1572	GD	R	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	56405V	\N	\N
1573	RDSE	R	\N	1996-07-13 00:00:00	ANCIEN	\N	\N	\N	\N	80022Y	\N	\N
1574	UC	R	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58924Y	\N	\N
1575	UCDP	R	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000144	\N	\N
1576	UREI	R	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	58342G	\N	\N
1577	GD	R	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000332	\N	\N
1578	UDR	R	\N	1974-05-22 00:00:00	ANCIEN	\N	\N	\N	\N	000314	\N	\N
1579	GD	R	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000284	\N	\N
1580	UC	R	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000528	\N	\N
1581	UREI	R	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59240F	\N	\N
1582	RDE	R	\N	1995-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	59553V	\N	\N
1583	SOC	R	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59579G	\N	\N
1584	UC	R	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59561V	\N	\N
1585	GD	R	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000246	\N	\N
1586	SOC	R	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000178	\N	\N
1587	GD	R	\N	1961-07-18 00:00:00	ANCIEN	\N	\N	\N	\N	000300	\N	\N
1589	GD	R	\N	1961-02-21 00:00:00	ANCIEN	\N	\N	\N	\N	000742	\N	\N
1590	UREI	A	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58041V	\N	\N
1591	GD	A	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000028	\N	\N
1593	GD	A	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000064	\N	\N
1594	RPR	A	\N	1987-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	000541	\N	\N
1595	GD	A	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000665	\N	\N
1596	C	A	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59564Y	\N	\N
1598	UC	A	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000051	\N	\N
1599	RPR	A	\N	1990-11-29 00:00:00	ANCIEN	\N	\N	\N	\N	000545	\N	\N
1600	RPR	A	\N	1996-01-20 00:00:00	ANCIEN	\N	\N	\N	\N	92014N	\N	\N
1602	GD	A	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000257	\N	\N
1603	RPR	A	\N	1995-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	000449	\N	\N
1604	C	A	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58641Q	\N	\N
1606	RPR	A	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58947G	\N	\N
1607	UNR	N	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000001	\N	\N
1608	GD	A	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000132	\N	\N
1609	RI	A	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000090	\N	\N
1611	UNR	A	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000141	\N	\N
1612	RPR	A	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59244K	\N	\N
1613	RDE	A	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58933A	\N	\N
1615	SOC	A	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58950B	\N	\N
1616	RI	A	\N	1969-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	000251	\N	\N
1617	SOC	A	\N	1968-10-24 00:00:00	ANCIEN	\N	\N	\N	\N	000094	\N	\N
1618	UNR	A	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000259	\N	\N
1620	GD	A	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000670	\N	\N
1621	GD	A	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000712	\N	\N
1622	C	A	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000739	\N	\N
961	RPR	N	\N	1990-01-14 00:00:00	ANCIEN	\N	\N	\N	\N	000326	\N	\N
965	UC	N	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59570W	\N	\N
969	RI	N	\N	1995-11-09 00:00:00	ANCIEN	\N	\N	\N	\N	59601L	\N	\N
974	SOC	N	\N	1967-03-08 00:00:00	ANCIEN	\N	\N	\N	\N	000038	\N	\N
978	UC	N	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000272	\N	\N
982	UREI	N	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	58419L	\N	\N
987	SOC	N	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58923X	\N	\N
991	UC	N	\N	1988-05-13 00:00:00	ANCIEN	\N	\N	\N	\N	58805S	\N	\N
996	UNR	N	\N	1962-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	57710G	\N	\N
1000	UDR	A	\N	1977-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000192	\N	\N
1004	SOC	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000173	\N	\N
1067	GD	N	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000075	\N	\N
1072	GD	N	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58021R	\N	\N
1076	RI	N	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000296	\N	\N
1080	SOC	N	\N	1995-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	000533	\N	\N
1085	C	N	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59534S	\N	\N
1089	C	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000536	\N	\N
1093	RI	N	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000071	\N	\N
1097	UC	N	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59536U	\N	\N
1102	RPR	N	\N	1992-09-27 00:00:00	ANCIEN	\N	\N	\N	\N	59230D	\N	\N
1106	UC	N	\N	1988-07-01 00:00:00	ANCIEN	\N	\N	\N	\N	58816V	\N	\N
1110	NI	N	\N	1982-10-22 00:00:00	ANCIEN	\N	\N	\N	\N	000226	\N	\N
1168	GD	N	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000303	\N	\N
1172	RI	N	\N	1971-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	57129Y	\N	\N
1176	UREI	N	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58948H	\N	\N
1181	RI	N	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000014	\N	\N
1185	C	N	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59543T	\N	\N
1189	RDE	N	\N	1995-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	000206	\N	\N
1194	CRC	N	\N	1997-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	89033R	\N	\N
1198	GD	N	\N	1969-03-20 00:00:00	ANCIEN	\N	\N	\N	\N	000017	\N	\N
1203	RI	N	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59549A	\N	\N
1207	RPR	N	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000059	\N	\N
1211	UNR	N	\N	1962-05-15 00:00:00	ANCIEN	\N	\N	\N	\N	000498	\N	\N
1275	NI	N	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000026	\N	\N
1281	UCDP	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	57761T	\N	\N
1285	RI	N	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000112	\N	\N
1290	GD	N	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000161	\N	\N
1294	UREI	N	\N	1983-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000138	\N	\N
1298	UC	N	\N	1995-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	59554W	\N	\N
1303	GD	N	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000052	\N	\N
1307	UC	N	\N	1995-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000211	\N	\N
1311	UNR	N	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	56522A	\N	\N
1316	UREI	N	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000470	\N	\N
1378	C	N	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59247N	\N	\N
1383	SOC	N	\N	1971-08-01 00:00:00	ANCIEN	\N	\N	\N	\N	000120	\N	\N
1387	C	N	\N	1975-04-30 00:00:00	ANCIEN	\N	\N	\N	\N	000302	\N	\N
1391	UCDP	N	\N	1984-03-06 00:00:00	ANCIEN	\N	\N	\N	\N	000312	\N	\N
1396	SOC	N	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58036Y	\N	\N
1400	RPR	N	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59250H	\N	\N
1404	SOC	N	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000074	\N	\N
1409	RPR	N	\N	1980-10-03 00:00:00	ANCIEN	\N	\N	\N	\N	000354	\N	\N
1413	C	N	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59252K	\N	\N
1418	SOC	N	\N	1981-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	59308J	\N	\N
1479	GD	N	\N	1979-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	000735	\N	\N
1484	RP	N	\N	1966-03-09 00:00:00	ANCIEN	\N	\N	\N	\N	000726	\N	\N
1488	SOC	N	\N	1974-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000683	\N	\N
1492	UNR	N	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000728	\N	\N
1497	RI	N	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000699	\N	\N
1501	SOC	N	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000697	\N	\N
1505	UNR	N	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000753	\N	\N
1510	CRARS	N	\N	1970-10-24 00:00:00	ANCIEN	\N	\N	\N	\N	000680	\N	\N
1515	UNR	N	\N	1965-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000679	\N	\N
1519	GD	N	\N	1962-09-23 00:00:00	ANCIEN	\N	\N	\N	\N	000708	\N	\N
1523	GD	N	\N	1972-11-27 00:00:00	ANCIEN	\N	\N	\N	\N	000771	\N	\N
1588	RPR	R	\N	1977-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	000758	\N	\N
1592	RI	A	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000234	\N	\N
1597	UNR	A	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000260	\N	\N
1601	RPR	A	\N	1989-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58946F	\N	\N
1605	UNR	A	\N	1968-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000204	\N	\N
1610	SOC	A	\N	1986-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59619W	\N	\N
1614	RPR	N	\N	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	58508L	\N	\N
1619	RPR	A	\N	1992-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	59253L	\N	\N
1623	GD	A	\N	1962-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	000745	\N	\N
1145	UREI	N	\N	1983-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	58303Y	\N	\N
1626	UC	N	2003-08-02 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	\N	95004Y	\N	\N
1627	NI	N	2003-08-29 00:00:00	2003-09-03 00:00:00	ANCIEN	\N	\N	\N	\N	03002P	\N	\N
1628	UMP	N	2003-09-04 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	03002P	\N	\N
1632	NI	N	2003-11-05 00:00:00	2003-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	03003Q	\N	\N
1633	UC	N	2003-11-07 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	03003Q	\N	\N
1634	UMP	A	2003-11-13 00:00:00	2004-04-06 00:00:00	ANCIEN	\N	\N	\N	\N	01060R	\N	\N
1636	NI	N	2004-02-13 00:00:00	2004-02-23 00:00:00	ANCIEN	\N	\N	\N	\N	03004R	\N	\N
1637	UC	N	2004-02-24 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	03004R	\N	\N
1638	NI	N	2004-04-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01060R	\N	\N
1639	UMP	A	2004-04-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89037V	\N	\N
1641	NI	N	2004-05-01 00:00:00	2004-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	04016A	\N	\N
1642	NI	N	2004-05-01 00:00:00	2004-05-03 00:00:00	ANCIEN	\N	\N	\N	\N	04017B	\N	\N
1643	NI	N	2004-05-01 00:00:00	2004-05-03 00:00:00	ANCIEN	\N	\N	\N	\N	04018C	\N	\N
1644	UMP	N	2004-05-04 00:00:00	2005-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	04017B	\N	\N
1645	UMP	N	2004-05-04 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04018C	\N	2017-10-03 17:26:36
1646	UMP	A	2004-05-05 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04016A	\N	\N
1647	UMP	A	2004-05-17 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98003L	\N	\N
218	SOC	N	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95017E	\N	\N
270	CRC	N	\N	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	79004F	\N	\N
1649	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04033B	\N	\N
1651	AUCUN	N	2004-09-26 00:00:00	2004-09-26 00:00:00	ANCIEN	\N	\N	\N	\N	92029V	\N	\N
1653	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	02009S	\N	\N
1654	SOC	N	2004-10-05 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	\N	2017-06-29 09:55:49
1658	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04035D	\N	\N
1659	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04036E	\N	\N
1660	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04037F	\N	\N
1662	SOC	N	2004-10-05 00:00:00	2011-10-26 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	\N	\N
1663	CRC	N	2004-10-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04039H	\N	\N
1664	SOC	N	2004-10-05 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	\N	04040A	\N	\N
1667	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04041B	\N	\N
1668	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04042C	\N	\N
1670	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	95031C	\N	\N
1672	AUCUN	N	2004-10-01 00:00:00	2004-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	04044E	\N	\N
1673	SOC	N	2004-10-05 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	04045F	\N	2017-06-29 09:55:22
2398	UMP	R	2013-09-11 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	2013-09-11 15:02:44	2014-10-07 19:25:11
2395	SOC	N	2013-06-05 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08032S	2013-06-04 17:13:26	2014-09-28 17:34:15
2397	UMP	N	2013-06-29 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13003V	2013-07-01 09:35:52	2014-09-28 17:14:21
2402	RDSE	N	2013-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11096W	2013-10-22 16:16:00	2017-09-24 18:17:56
2292	SOC	R	2011-10-01 00:00:00	2012-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	11076S	\N	\N
2293	UMP	N	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11080N	\N	\N
2294	SOC	N	2011-10-01 00:00:00	2017-07-28 00:00:00	ANCIEN	\N	\N	\N	\N	11032E	\N	2017-08-03 11:38:41
2295	CRC	N	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11031D	\N	\N
2296	CRC	N	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11034G	\N	2017-09-24 17:55:12
2297	SOC	R	2011-10-01 00:00:00	2012-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	11033F	\N	\N
2298	SOC	N	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11054L	\N	\N
2299	SOC	R	2011-10-01 00:00:00	2012-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	11055M	\N	\N
2300	SOC	N	2011-10-01 00:00:00	2015-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	11051H	\N	2015-03-03 10:16:55
2301	UC	N	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11053K	\N	\N
2307	SOC	N	2011-10-01 00:00:00	2011-10-10 00:00:00	ANCIEN	\N	\N	\N	\N	11084S	\N	\N
2309	SOC	R	2011-10-01 00:00:00	2012-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	11083R	\N	\N
2310	UC	N	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11085T	\N	2014-10-07 00:00:00
2313	RDSE	N	\N	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04096S	\N	\N
2373	ECO	N	2012-06-17 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	\N	12035A	\N	2014-05-05 10:34:09
2385	UC	N	2012-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	09001P	\N	2017-09-24 17:47:27
2388	SOC	N	2012-12-03 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	12042Y	\N	2017-06-29 09:53:55
2390	UMP	N	2013-02-07 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13001T	\N	2014-09-28 17:58:04
2400	SOC	N	2013-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	13005X	2013-10-01 15:26:12	2014-09-28 18:00:57
2431	UMP	R	2014-07-09 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98018T	2014-07-09 18:28:40	2014-07-09 18:28:49
2425	CRC	N	2014-05-10 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	14013P	2014-05-09 11:36:02	2017-06-19 16:06:01
2426	AUCUN	N	2014-05-09 00:00:00	2014-05-11 00:00:00	ANCIEN	\N	\N	\N	\N	14014Q	2014-05-09 11:37:36	2014-05-12 11:26:57
2432	AUCUN	N	2014-08-27 00:00:00	2014-09-08 00:00:00	ANCIEN	\N	\N	\N	\N	14018U	2014-08-27 16:32:46	2014-09-09 15:48:13
2435	RDSE	N	2014-09-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14018U	2014-09-09 15:48:11	2017-09-24 18:49:56
2436	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14191V	2014-09-28 12:09:44	2014-10-07 15:39:32
2446	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14199E	2014-09-28 14:31:41	2014-10-07 15:36:26
2500	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14251Q	2014-09-28 18:32:19	2014-10-07 15:40:07
2502	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14121F	2014-09-28 18:44:07	2014-10-07 17:08:27
2505	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14033T	2014-09-28 18:47:00	2014-10-07 15:36:42
2506	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14151M	2014-09-28 18:58:20	2014-10-07 17:05:59
2508	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14201E	2014-09-28 18:59:41	2014-10-07 17:37:28
2677	RDSE	N	2017-05-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14365A	2017-05-24 14:34:24	2017-09-24 12:39:59
2632	AUCUN	N	2015-02-12 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	87003B	2015-02-12 15:04:38	2015-02-13 10:24:28
2024	RDSE	N	2008-10-01 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	\N	08051V	\N	2017-06-19 12:20:59
2551	UMP	N	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	14026U	2014-10-07 15:39:04	\N
2667	NI	N	2016-12-01 00:00:00	2016-12-04 00:00:00	ANCIEN	\N	\N	\N	\N	14357A	2016-12-01 18:23:34	2016-12-05 18:12:01
2683	SOC	N	2017-06-18 00:00:00	\N	ACTIF	\N	\N	\N	\N	19251M	2017-06-19 16:45:46	\N
2684	AUCUN	N	2017-06-18 00:00:00	2017-06-18 00:00:00	ANCIEN	\N	\N	\N	\N	19253P	2017-06-19 16:48:14	2017-06-22 15:10:04
2689	NI	N	2017-06-19 00:00:00	2017-06-26 00:00:00	ANCIEN	\N	\N	\N	\N	19253P	2017-06-22 15:10:03	2017-06-27 16:44:35
2727	UC	N	2017-07-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11076S	2017-07-04 10:54:38	2017-09-24 17:47:28
2690	RDSE	N	2017-06-27 00:00:00	2018-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	19253P	2017-06-27 16:44:34	\N
2898	SOC	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19631V	2017-10-03 00:00:00	\N
2751	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19333N	2017-09-24 16:43:41	2017-10-03 17:09:16
2899	SOC	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19549D	2017-10-03 00:00:00	\N
2926	UMP	N	2017-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19575F	2017-10-03 17:15:43	\N
2901	SOC	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19295A	2017-10-03 00:00:00	\N
2902	SOC	N	2017-10-03 00:00:00	2021-11-30 00:00:00	ANCIEN	\N	\N	\N	\N	19525U	2017-10-03 17:06:32	\N
2903	SOC	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19649G	2017-10-03 00:00:00	\N
2904	SOC	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19647E	2017-10-03 00:00:00	\N
2905	SOC	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19599P	2017-10-03 00:00:00	\N
2906	SOC	N	2017-10-03 00:00:00	2020-06-24 00:00:00	ANCIEN	\N	\N	\N	\N	19727D	2017-10-03 17:08:45	\N
2907	SOC	N	2017-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19725B	2017-10-03 17:09:07	\N
2908	SOC	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19333N	2017-10-03 00:00:00	\N
2909	SOC	N	2017-10-03 00:00:00	2019-10-27 00:00:00	ANCIEN	\N	\N	\N	\N	19591F	2017-10-03 17:09:23	\N
2910	SOC	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19551W	2017-10-03 00:00:00	\N
2911	SOC	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19715Y	2017-10-03 00:00:00	\N
2912	SOC	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19531S	2017-10-03 00:00:00	\N
2913	SOC	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19683J	2017-10-03 00:00:00	2017-10-19 00:00:00
2914	SOC	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14021P	2017-10-03 00:00:00	2018-01-23 00:00:00
2915	SOC	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19489J	2017-10-03 00:00:00	\N
2916	SOC	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	17779H	2017-10-03 00:00:00	\N
2917	SOC	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	12016W	2017-10-03 00:00:00	\N
2918	SOC	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19503N	2017-10-03 00:00:00	\N
2919	SOC	A	2017-10-03 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	19689Q	2017-10-03 17:12:04	\N
2920	SOC	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19669L	2017-10-03 00:00:00	\N
2921	SOC	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19413M	2017-10-03 00:00:00	\N
2922	SOC	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19527W	2017-10-03 00:00:00	\N
2923	UMP	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19515S	2017-10-03 00:00:00	\N
2924	UMP	R	2017-10-03 00:00:00	2018-07-27 00:00:00	ANCIEN	\N	\N	\N	\N	19707Y	2017-10-03 17:15:31	2017-10-03 17:29:30
2925	UMP	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19667J	2017-10-03 00:00:00	\N
2927	UMP	N	2017-10-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14115H	2017-10-03 17:15:49	\N
2928	UMP	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19367Y	2017-10-03 00:00:00	\N
2929	UMP	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19415P	2017-10-03 00:00:00	\N
2930	UMP	N	2017-10-03 00:00:00	2020-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	19733B	2017-10-03 17:16:11	\N
2931	UMP	A	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19643A	2017-10-03 00:00:00	2017-10-03 00:00:00
2932	UMP	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19383Y	2017-10-03 00:00:00	\N
2933	UMP	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19621T	2017-10-03 00:00:00	\N
2934	UMP	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19467C	2017-10-03 00:00:00	\N
2935	UMP	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	18083K	2017-10-03 00:00:00	\N
2936	UMP	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19701S	2017-10-03 00:00:00	\N
2967	UC	N	2017-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19721W	2017-10-03 17:34:07	\N
2938	UMP	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11115U	2017-10-03 00:00:00	\N
2939	UMP	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19693L	2017-10-03 00:00:00	\N
2940	UMP	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04008A	2017-10-03 00:00:00	\N
2941	UMP	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19663E	2017-10-03 00:00:00	\N
2942	UMP	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19507S	2017-10-03 00:00:00	\N
2943	UMP	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19673G	2017-10-03 00:00:00	\N
2944	UMP	N	2017-10-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	15447F	2017-10-03 17:20:55	\N
2945	UMP	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19399H	2017-10-03 00:00:00	\N
2946	UMP	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19447X	2017-10-03 00:00:00	\N
2947	UMP	A	2017-10-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14029X	2017-10-03 17:22:09	2017-10-03 17:32:43
2948	UMP	N	2017-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19723Y	2017-10-03 17:22:19	\N
2949	UMP	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19711U	2017-10-03 00:00:00	\N
2950	UMP	N	2017-10-03 00:00:00	2017-11-24 00:00:00	ANCIEN	\N	\N	\N	\N	19677L	2017-10-03 17:22:46	2017-11-24 23:59:34
2951	UMP	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19709B	2017-10-03 00:00:00	2018-06-06 00:00:00
2952	UMP	N	2017-10-03 00:00:00	2018-04-13 00:00:00	ANCIEN	\N	\N	\N	\N	19483C	2017-10-03 17:23:07	2018-04-13 17:54:29
2953	UMP	N	2017-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19729F	2017-10-03 17:23:14	\N
2954	UMP	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19581D	2017-10-03 00:00:00	\N
2955	UMP	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19657G	2017-10-03 00:00:00	\N
2956	UMP	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19671E	2017-10-03 00:00:00	\N
2765	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19671E	2017-09-24 17:15:14	2017-10-03 17:23:50
2957	UMP	R	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19573D	2017-10-03 00:00:00	\N
2958	UMP	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	17637T	2017-10-03 00:00:00	\N
2959	UMP	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19533U	2017-10-03 00:00:00	\N
2960	UMP	N	2017-10-03 00:00:00	2020-10-31 00:00:00	ANCIEN	\N	\N	\N	\N	17583W	2017-10-03 17:25:01	\N
2754	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	17583W	2017-09-24 17:04:01	2017-10-03 17:25:01
2961	UMP	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19679N	2017-10-03 00:00:00	\N
2962	UMP	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19443T	2017-10-03 00:00:00	\N
2963	UMP	R	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19705W	2017-10-03 00:00:00	2017-10-03 00:00:00
2964	UMP	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19421M	2017-10-03 00:00:00	2017-10-03 00:00:00
2771	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19421M	2017-09-24 17:28:55	2017-10-03 17:26:26
2965	UMP	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19703U	2017-10-03 00:00:00	\N
2966	UMP	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19675J	2017-10-03 00:00:00	\N
2968	UC	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19577H	2017-10-03 00:00:00	\N
2969	UC	N	2017-10-03 00:00:00	2021-12-07 00:00:00	ANCIEN	\N	\N	\N	\N	19521Q	2017-10-03 17:34:36	\N
2779	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19521Q	2017-09-24 17:42:25	2017-10-03 17:34:36
2970	UC	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19691J	2017-10-03 00:00:00	\N
2971	UC	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19569H	2017-10-03 00:00:00	\N
2972	UC	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19511N	2017-10-03 00:00:00	\N
2973	UC	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19611R	2017-10-03 00:00:00	\N
2974	UC	A	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19699S	2017-10-03 00:00:00	2017-10-03 00:00:00
2975	UC	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	16685X	2017-10-03 00:00:00	\N
2412	AUCUN	N	2014-04-23 00:00:00	2014-04-27 00:00:00	ANCIEN	\N	\N	\N	\N	09010Q	2014-04-23 09:57:24	2014-04-28 10:39:24
2623	CRC	N	2014-12-22 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	14263U	2014-12-22 15:50:06	2017-06-19 16:04:13
2639	UMP	N	2015-04-22 00:00:00	2017-06-04 00:00:00	ANCIEN	\N	\N	\N	\N	14273W	2015-04-22 16:49:30	2017-06-07 09:38:00
2421	SOC	N	2014-05-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11027H	2014-05-05 00:00:00	\N
2422	SOC	N	2014-05-05 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	2014-05-05 10:41:54	2017-06-29 09:53:31
2651	NI	N	2015-09-07 00:00:00	2015-09-09 00:00:00	ANCIEN	\N	\N	\N	\N	08049C	2015-09-07 16:07:43	2015-09-10 15:46:13
2652	NI	N	2015-09-07 00:00:00	2015-09-09 00:00:00	ANCIEN	\N	\N	\N	\N	14327T	2015-09-07 16:16:32	2015-09-10 15:45:53
2345	ECO	N	2012-01-11 00:00:00	2017-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	11029K	\N	2017-06-30 09:52:11
2691	LREM	N	2017-06-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	08061X	2017-06-29 09:52:44	\N
2693	LREM	N	2017-06-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11036J	2017-06-29 09:53:18	2017-09-24 18:16:52
2692	LREM	N	2017-06-28 00:00:00	2020-03-02 00:00:00	ANCIEN	\N	\N	\N	\N	14239U	2017-06-29 09:53:11	2017-06-30 10:59:13
2694	LREM	N	2017-06-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11068S	2017-06-29 09:53:25	2017-09-24 18:05:41
2695	LREM	N	2017-06-28 00:00:00	2017-08-06 00:00:00	ANCIEN	\N	\N	\N	\N	04053F	2017-06-29 09:53:31	2017-08-07 16:31:39
2696	LREM	N	2017-06-28 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98029W	2017-06-29 09:53:37	\N
2697	LREM	N	2017-06-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11114F	2017-06-29 09:53:43	2017-09-25 10:54:33
2698	LREM	A	2017-06-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11113E	2017-06-29 09:53:49	2017-09-25 10:54:33
2214	SOC	N	2011-10-01 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	11113E	\N	2017-06-29 09:53:49
2699	LREM	N	2017-06-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	12042Y	2017-06-29 09:53:55	2017-09-24 19:31:54
2700	LREM	N	2017-06-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11107G	2017-06-29 09:54:00	2017-09-24 17:06:55
2701	LREM	N	2017-06-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11083R	2017-06-29 00:00:00	\N
2350	ECO	N	2012-01-11 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	11083R	\N	2017-06-29 09:54:06
2702	LREM	N	2017-06-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04095R	2017-06-29 09:54:13	2017-09-25 10:54:33
2703	LREM	N	2017-06-28 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95037J	2017-06-29 09:54:18	\N
2704	LREM	N	2017-06-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04077P	2017-06-29 09:54:25	2017-09-24 17:47:27
2705	LREM	N	2017-06-28 00:00:00	2017-07-22 00:00:00	ANCIEN	\N	\N	\N	\N	14037X	2017-06-29 09:54:31	2017-07-24 09:58:00
2706	LREM	N	2017-06-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	83042R	2017-06-29 09:54:37	2017-09-24 17:48:21
2707	LREM	N	2017-06-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92039X	2017-06-29 09:54:43	2017-09-24 13:47:46
2708	LREM	N	2017-06-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11072N	2017-06-29 00:00:00	\N
2709	LREM	N	2017-06-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	08073C	2017-06-29 09:54:57	\N
2710	LREM	N	2017-06-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	95063L	2017-06-29 00:00:00	\N
2711	LREM	N	2017-06-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14271U	2017-06-29 09:55:10	2017-09-24 17:06:55
2712	LREM	N	2017-06-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11046L	2017-06-29 09:55:16	2017-09-24 17:29:37
2247	SOC	N	2011-10-01 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	11046L	\N	2017-06-29 09:55:16
2713	LREM	N	2017-06-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	04045F	2017-06-29 09:55:22	\N
2714	LREM	N	2017-06-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11025F	2017-06-29 09:55:31	2017-09-24 16:24:51
2715	LREM	N	2017-06-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11057P	2017-06-29 09:55:44	2017-09-24 18:23:22
2716	LREM	N	2017-06-28 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04034C	2017-06-29 09:55:49	\N
2717	LREM	A	2017-06-28 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14039A	2017-06-29 09:55:56	2017-06-29 09:56:30
2732	LREM	N	2017-07-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11023D	2017-07-17 11:07:21	2017-09-25 10:56:48
2734	NI	N	2017-07-22 00:00:00	2017-07-24 00:00:00	ANCIEN	\N	\N	\N	\N	19269X	2017-07-24 16:38:43	2017-07-25 12:14:19
2850	AUCUN	N	2017-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19721W	2017-10-01 09:45:12	2017-10-03 17:34:07
2746	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19507S	2017-09-24 12:57:08	2017-10-03 17:20:12
2840	AUCUN	N	2017-09-25 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	08045X	2017-09-25 09:57:06	2017-10-03 17:08:23
2847	NI	N	2017-09-27 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	14029X	2017-09-27 18:53:55	2017-10-03 17:22:09
2848	NI	N	2017-09-23 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	14115H	2017-09-27 18:58:16	2017-10-03 17:15:49
2851	AUCUN	N	2017-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19723Y	2017-10-01 10:06:58	2017-10-03 17:22:19
2060	UMP	N	2008-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08042U	\N	2017-10-01 10:20:50
2852	AUCUN	N	2017-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19725B	2017-10-01 10:44:23	2017-10-03 17:09:07
2853	AUCUN	N	2017-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19727D	2017-10-01 10:54:01	2017-10-03 17:08:45
2854	AUCUN	N	2017-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19729F	2017-10-01 11:03:20	2017-10-03 17:23:14
2855	AUCUN	N	2017-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19731Y	2017-10-01 11:13:13	2017-10-03 17:40:49
2982	UC	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19713W	2017-10-03 00:00:00	\N
2857	AUCUN	N	2017-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19733B	2017-10-01 11:41:24	2017-10-03 17:16:11
2858	AUCUN	N	2017-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19735D	2017-10-01 11:48:00	2017-10-03 17:37:12
2859	AUCUN	N	2017-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19737F	2017-10-01 11:57:14	2017-10-03 17:37:42
2878	RDSE	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19717B	2017-10-03 00:00:00	\N
2880	RDSE	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19681G	2017-10-03 00:00:00	\N
2884	RDSE	R	2017-10-03 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	11065P	2017-10-03 16:56:55	2017-10-03 17:03:12
2887	RDSE	N	2017-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19719D	2017-10-03 16:57:16	\N
2889	RDSE	N	2017-10-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14034U	2017-10-03 16:57:46	\N
2891	RDSE	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19387D	2017-10-03 00:00:00	\N
2892	RDSE	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19553Y	2017-10-03 00:00:00	\N
2894	RDSE	R	2017-10-03 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	11099A	2017-10-03 16:58:46	2017-10-03 17:03:52
2895	RDSE	N	2017-10-03 00:00:00	2022-02-02 00:00:00	ANCIEN	\N	\N	\N	\N	19289C	2017-10-03 16:59:02	\N
2896	RDSE	N	2017-10-03 00:00:00	2019-05-14 00:00:00	ANCIEN	\N	\N	\N	\N	19563B	2017-10-03 16:59:15	\N
2897	RDSE	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19629C	2017-10-03 00:00:00	\N
2761	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	16685X	2017-09-24 17:14:26	2017-10-03 17:36:18
2976	UC	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19441R	2017-10-03 00:00:00	2017-10-03 00:00:00
2977	UC	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19335Q	2017-10-03 00:00:00	\N
2978	UC	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19369B	2017-10-03 00:00:00	\N
2979	UC	A	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19319Q	2017-10-03 00:00:00	2017-10-03 00:00:00
2980	UC	N	2017-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19735D	2017-10-03 17:37:12	\N
2981	UC	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19619A	2017-10-03 00:00:00	\N
2983	UC	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19479G	2017-10-03 00:00:00	\N
2984	UC	A	2017-10-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19737F	2017-10-03 17:37:42	2017-10-03 17:39:21
2985	NI	N	2017-10-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19731Y	2017-10-03 17:40:49	\N
2986	NI	N	2017-10-03 00:00:00	2021-02-08 00:00:00	ANCIEN	\N	\N	\N	\N	19685L	2017-10-03 17:41:07	\N
2789	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19685L	2017-09-24 17:48:20	2017-10-03 17:41:07
791	UMP	N	2002-12-11 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98050T	\N	2017-10-03 18:21:49
2993	UMP	N	2017-11-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19741B	2017-11-27 00:00:00	\N
2990	UC	N	2017-11-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19739H	2017-11-06 00:00:00	\N
2989	NI	N	2017-11-03 00:00:00	2017-11-05 00:00:00	ANCIEN	\N	\N	\N	\N	19739H	2017-11-06 15:15:01	2017-11-06 15:15:19
2998	NI	N	2017-12-18 00:00:00	2017-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	19747H	2017-12-18 15:12:00	2017-12-20 17:56:35
2992	NI	N	2017-11-25 00:00:00	2017-11-26 00:00:00	ANCIEN	\N	\N	\N	\N	19741B	2017-11-24 18:20:10	2017-11-27 18:37:30
2999	UC	N	2017-12-19 00:00:00	\N	ACTIF	\N	\N	\N	\N	19749K	2017-12-19 14:46:02	\N
2033	SOC	N	2008-10-01 00:00:00	2018-05-21 00:00:00	ANCIEN	\N	\N	\N	\N	08016S	\N	2018-05-22 17:59:38
2996	NI	N	2017-12-18 00:00:00	2017-12-18 00:00:00	ANCIEN	\N	\N	\N	\N	19749K	2017-12-18 14:52:08	2018-01-22 17:49:37
2997	NI	N	2017-12-18 00:00:00	2018-07-24 00:00:00	ANCIEN	\N	\N	\N	\N	19745F	2017-12-18 15:11:04	\N
3000	UMP	N	2017-12-19 00:00:00	2023-12-31 00:00:00	ANCIEN	\N	\N	\N	\N	19747H	2017-12-19 00:00:00	2017-12-19 00:00:00
3001	RDSE	N	2018-05-22 00:00:00	2018-11-16 00:00:00	ANCIEN	\N	\N	\N	\N	08016S	2018-05-22 18:00:01	\N
3002	NI	N	2018-06-01 00:00:00	2018-06-01 00:00:00	ANCIEN	\N	\N	\N	\N	19758L	2018-05-31 11:00:21	2018-06-01 18:48:14
2458	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14207L	2014-09-28 17:03:41	2014-10-07 17:04:53
2438	AUCUN	N	2014-09-29 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14042U	2014-09-28 12:34:20	2014-10-20 10:49:17
2457	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14083S	2014-09-28 17:00:59	2014-10-07 15:51:37
2459	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14209N	2014-09-28 17:03:41	2014-10-07 15:30:26
2460	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14211G	2014-09-28 17:03:41	2014-10-07 15:36:33
2463	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14059S	2014-09-28 17:07:07	2014-10-07 15:39:58
2468	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14093U	2014-09-28 17:09:16	2014-10-07 15:28:58
2469	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14063N	2014-09-28 17:09:16	2014-10-07 16:58:03
2513	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14257W	2014-09-28 19:07:43	2014-10-07 16:58:54
2517	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14034U	2014-09-28 19:19:39	2014-10-07 15:54:46
2518	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14028W	2014-09-28 19:19:39	2014-10-07 17:00:26
2520	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14175V	2014-09-28 19:29:38	2014-10-07 15:29:28
2541	UMP	N	2014-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14249W	2014-10-07 15:35:34	\N
2542	UMP	N	2014-10-07 00:00:00	2014-12-27 00:00:00	ANCIEN	\N	\N	\N	\N	14129P	2014-10-07 15:36:04	2014-12-29 15:40:09
2544	UMP	N	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	14187A	2014-10-07 15:36:13	\N
2545	UMP	N	2014-10-07 00:00:00	2020-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	14199E	2014-10-07 15:36:25	\N
2546	UMP	N	2014-10-07 00:00:00	2022-07-11 00:00:00	ANCIEN	\N	\N	\N	\N	14211G	2014-10-07 15:36:32	\N
2547	UMP	N	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	14033T	2014-10-07 15:36:41	\N
2549	UMP	N	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	14123H	2014-10-07 15:36:56	\N
2552	UMP	N	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	95041E	2014-10-07 15:39:17	2014-10-07 16:36:16
2557	UMP	N	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	14059S	2014-10-07 15:39:58	\N
2558	UMP	N	2014-10-07 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	14251Q	2014-10-07 15:40:07	2017-10-03 16:54:24
2559	UMP	N	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	14031R	2014-10-07 15:40:21	\N
2560	UMP	N	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	14223L	2014-10-07 15:40:33	\N
2561	UMP	N	2014-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14119M	2014-10-07 15:40:51	\N
2036	SOC	N	2008-10-01 00:00:00	2020-08-03 00:00:00	ANCIEN	\N	\N	\N	\N	08035V	\N	2014-10-07 16:59:29
2565	UMP	N	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	14169X	2014-10-07 15:41:59	\N
2567	UMP	N	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	14071N	2014-10-07 15:43:45	2014-10-07 16:25:38
2594	SOC	N	2014-10-07 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	\N	14137P	2014-10-07 17:00:28	2015-06-12 15:59:18
2597	SOC	N	2014-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14065Q	2014-10-07 17:01:23	\N
2601	SOC	N	2014-10-07 00:00:00	2017-07-10 00:00:00	ANCIEN	\N	\N	\N	\N	14167V	2014-10-07 17:04:16	2017-07-11 10:14:31
2602	SOC	N	2014-10-07 00:00:00	2019-04-29 00:00:00	ANCIEN	\N	\N	\N	\N	14207L	2014-10-07 17:04:53	\N
2603	SOC	N	2014-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14085U	2014-10-07 17:05:13	\N
2604	SOC	N	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	14151M	2014-10-07 17:05:59	\N
2605	SOC	N	2014-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14197C	2014-10-07 17:06:10	\N
2612	SOC	N	2014-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14081Q	2014-10-07 17:08:00	\N
2613	SOC	N	2014-10-07 00:00:00	2015-02-12 00:00:00	ANCIEN	\N	\N	\N	\N	14233N	2014-10-07 17:08:14	2015-02-12 15:03:17
2614	SOC	N	2014-10-07 00:00:00	2019-05-27 00:00:00	ANCIEN	\N	\N	\N	\N	14121F	2014-10-07 17:08:27	\N
2615	SOC	N	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	14097Y	2014-10-07 17:08:34	\N
2619	UMP	N	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	08069G	2014-10-07 19:32:02	\N
2635	NI	N	2015-03-04 00:00:00	2015-03-09 00:00:00	ANCIEN	\N	\N	\N	\N	14269B	2015-03-04 16:36:00	2015-03-10 16:55:28
2630	NI	N	2015-01-26 00:00:00	2015-01-26 00:00:00	ANCIEN	\N	\N	\N	\N	14267Y	2015-01-26 17:11:41	2015-01-27 13:55:40
2631	UC	N	2015-01-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14267Y	2015-01-27 00:00:00	\N
2633	UMP	N	2015-02-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	87003B	2015-02-13 10:24:27	\N
2638	SOC	N	2015-04-15 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	14271U	2015-04-15 12:04:29	2017-06-29 09:55:10
2644	NI	N	2015-06-12 00:00:00	2015-06-16 00:00:00	ANCIEN	\N	\N	\N	\N	14281W	2015-06-12 15:35:57	2015-06-17 10:08:02
2653	UC	N	2015-09-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	14327T	2015-09-10 15:45:51	\N
2654	RDSE	N	2015-09-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08049C	2015-09-10 15:46:12	\N
2665	UMP	N	2016-11-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	14355X	2016-11-25 14:56:53	\N
2664	NI	N	2016-11-18 00:00:00	2016-11-24 00:00:00	ANCIEN	\N	\N	\N	\N	14355X	2016-11-18 15:46:10	2016-11-25 14:59:02
2668	UMP	N	2016-12-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14357A	2016-12-05 00:00:00	\N
2670	CRC	N	2016-12-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14361V	2016-12-14 18:37:18	2017-09-24 18:23:22
2731	LREM	N	2017-07-11 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14167V	2017-07-11 10:14:30	2017-10-01 10:18:28
2674	AUCUN	N	2017-05-15 00:00:00	2017-05-16 00:00:00	ANCIEN	\N	\N	\N	\N	14365A	2017-05-16 16:19:32	2017-05-17 11:44:22
2679	NI	N	2017-06-05 00:00:00	2017-06-14 00:00:00	ANCIEN	\N	\N	\N	\N	07028S	2017-06-07 16:00:03	2017-06-19 16:13:09
2849	AUCUN	N	2017-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19719D	2017-10-01 09:26:48	2017-10-03 16:57:16
2747	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19657G	2017-09-24 16:24:50	2017-10-03 17:23:31
2748	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19659J	2017-09-24 16:24:50	2017-10-03 16:56:42
2749	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19577H	2017-09-24 16:24:50	2017-10-03 17:34:20
2750	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19583F	2017-09-24 16:24:50	2017-10-03 16:54:14
2755	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19443T	2017-09-24 17:06:55	2017-10-03 17:25:49
2756	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19441R	2017-09-24 17:06:55	2017-10-03 17:36:30
2757	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19515S	2017-09-24 17:06:55	2017-10-03 17:15:26
2758	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19545Y	2017-09-24 17:09:23	2017-10-03 16:53:38
2759	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19549D	2017-09-24 17:09:23	2017-10-03 17:05:35
2760	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19533U	2017-09-24 17:09:23	2017-10-03 17:24:48
2762	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19447X	2017-09-24 17:14:26	2017-10-03 17:21:30
2763	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19667J	2017-09-24 17:15:14	2017-10-03 17:15:38
2764	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19669L	2017-09-24 17:15:14	2017-10-03 17:12:11
2766	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19673G	2017-09-24 17:15:14	2017-10-03 17:20:33
2237	SOC	N	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11089X	\N	2017-09-24 17:15:15
2767	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19675J	2017-09-24 17:18:02	2017-10-03 17:26:54
2768	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19543W	2017-09-24 17:18:02	2017-10-03 16:56:37
2769	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19551W	2017-09-24 17:19:41	2017-10-03 17:09:46
2770	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19553Y	2017-09-24 17:19:41	2017-10-03 16:58:13
2772	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19573D	2017-09-24 17:29:36	2017-10-03 17:24:30
2773	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19677L	2017-09-24 17:29:36	2017-10-03 17:22:46
2774	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	11115U	2017-09-24 17:29:36	2017-10-03 17:18:14
2246	UMP	N	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11044J	\N	2017-09-24 17:29:37
2775	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19349W	2017-09-24 17:35:13	2017-10-03 16:57:32
2776	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19679N	2017-09-24 17:35:13	2017-10-03 17:25:23
2777	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19347U	2017-09-24 17:35:13	2017-10-03 16:44:20
2778	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19527W	2017-09-24 17:42:25	2017-10-03 17:12:37
2780	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19525U	2017-09-24 17:42:25	2017-10-03 17:06:32
2781	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19681G	2017-09-24 17:42:25	2017-10-03 16:56:33
2782	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19649G	2017-09-24 17:47:26	2017-10-03 17:07:39
2783	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	07033P	2017-09-24 17:47:26	2017-10-03 17:19:59
2784	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19651A	2017-09-24 17:47:26	2017-10-03 16:56:28
2785	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19643A	2017-09-24 17:47:26	2017-10-03 17:16:21
2786	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19683J	2017-09-24 17:47:26	2017-10-03 17:10:20
2787	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19647E	2017-09-24 17:47:26	2017-10-03 17:08:07
2788	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19335Q	2017-09-24 17:48:20	2017-10-03 17:36:48
2790	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19687N	2017-09-24 17:55:12	2017-10-03 16:45:07
2791	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19611R	2017-09-24 17:55:12	2017-10-03 17:36:04
2792	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19689Q	2017-09-24 17:55:12	2017-10-03 17:12:05
2793	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19289C	2017-09-24 18:05:40	2017-10-03 16:59:02
2794	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19691J	2017-09-24 18:05:40	2017-10-03 17:35:10
2408	AUCUN	N	2014-01-01 00:00:00	2014-01-06 00:00:00	ANCIEN	\N	\N	\N	\N	14001X	2014-01-02 15:38:53	2014-01-07 16:41:44
2413	UC	N	2014-04-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	09010Q	2014-04-28 10:39:23	2014-09-28 17:07:41
2428	UMP	R	2014-06-11 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	89022N	2014-06-11 18:26:34	2014-09-28 18:19:47
2429	AUCUN	N	2014-06-25 00:00:00	2014-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	14017T	2014-06-25 15:52:44	2014-07-01 15:32:42
2417	RDSE	N	2014-05-05 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08064B	2014-05-05 10:32:43	2014-09-28 19:03:23
2418	SOC	N	2014-05-05 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04090L	2014-05-05 10:33:21	2014-09-28 19:29:39
2427	SOC	N	2014-05-12 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	14014Q	2014-05-12 11:26:56	2017-06-19 16:06:51
2430	UMP	N	2014-07-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14017T	2014-07-01 15:32:41	2017-09-24 16:24:51
2434	SOC	N	2014-09-01 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	83042R	2014-09-01 11:40:21	2017-06-29 09:54:38
2454	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14173T	2014-09-28 16:59:40	2014-10-07 16:56:24
2455	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14167V	2014-09-28 16:59:40	2014-10-07 17:04:16
2456	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14169X	2014-09-28 16:59:40	2014-10-07 15:41:59
2461	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14213J	2014-09-28 17:05:42	2014-10-07 15:42:12
2462	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14159V	2014-09-28 17:05:42	2014-10-07 16:57:19
2464	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14087W	2014-09-28 17:07:40	2014-10-07 15:46:18
2465	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	95049N	2014-09-28 17:07:40	2014-10-07 15:55:04
2466	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14081Q	2014-09-28 17:07:40	2014-10-07 17:08:00
2467	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14215L	2014-09-28 17:07:40	2014-10-07 15:39:19
2470	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14217N	2014-09-28 17:12:40	2014-10-07 15:32:17
2471	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14079W	2014-09-28 17:14:20	2014-10-07 15:30:46
2472	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14026U	2014-09-28 17:15:41	2014-10-07 15:39:04
2473	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14219Q	2014-09-28 17:22:10	2014-10-07 15:54:21
2474	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14123H	2014-09-28 17:22:10	2014-10-07 15:36:56
2475	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14038Y	2014-09-28 17:27:28	2014-10-07 15:39:01
2476	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14221J	2014-09-28 17:27:34	2014-10-07 15:54:56
2477	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14223L	2014-09-28 17:27:34	2014-10-07 15:40:33
2478	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14225N	2014-09-28 17:27:34	2014-10-07 17:00:43
2479	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14073Q	2014-09-28 17:31:41	2014-10-07 15:54:00
2480	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14065Q	2014-09-28 17:31:41	2014-10-07 17:01:24
2481	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14061L	2014-09-28 17:31:41	2014-10-07 15:39:42
2482	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14227Q	2014-09-28 17:34:15	2014-10-07 17:03:14
2483	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14229S	2014-09-28 17:34:15	2014-10-07 17:01:23
2484	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14231L	2014-09-28 17:34:15	2014-10-07 15:55:40
2488	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14237S	2014-09-28 17:40:23	2014-10-07 15:35:03
2489	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14179A	2014-09-28 17:40:23	2014-10-07 15:53:26
2490	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14239U	2014-09-28 17:52:17	2014-10-07 17:06:22
2491	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14241N	2014-09-28 17:52:17	2014-10-07 17:17:59
2492	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14055N	2014-09-28 17:52:17	2014-10-07 17:07:51
2659	ECO	N	2016-03-09 00:00:00	2017-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	13002U	2016-03-09 11:10:18	2017-06-30 09:52:11
2342	ECO	N	2012-01-11 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	\N	11069T	\N	2016-03-11 18:02:50
2507	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14037X	2014-09-28 18:58:25	2014-10-07 15:39:27
2509	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14069U	2014-09-28 19:03:03	2014-10-07 15:41:43
2514	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14107H	2014-09-28 19:09:43	2014-10-07 17:02:06
2515	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14085U	2014-09-28 19:13:08	2014-10-07 17:05:13
2516	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14089Y	2014-09-28 19:13:08	2014-10-07 15:51:19
2519	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14259Y	2014-09-28 19:20:16	2014-10-07 15:31:07
2521	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14129P	2014-09-28 19:45:29	2014-10-07 15:36:04
2522	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14261S	2014-09-29 09:03:10	2014-10-07 17:37:09
2523	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14039A	2014-09-29 09:05:47	2014-10-07 18:46:59
2524	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14043V	2014-09-29 09:08:32	2014-10-07 15:52:39
2525	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14044W	2014-09-29 09:08:32	2014-10-07 15:53:35
2645	AUCUN	N	2015-06-12 00:00:00	2015-06-14 00:00:00	ANCIEN	\N	\N	\N	\N	14147R	2015-06-12 15:40:17	2015-06-15 18:12:01
2660	CRC	N	2016-03-12 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	\N	04050C	2016-03-11 18:10:19	2017-06-19 16:03:48
2661	AUCUN	N	2016-11-13 00:00:00	2016-11-13 00:00:00	ANCIEN	\N	\N	\N	\N	05001W	2016-11-14 18:40:41	2016-11-14 18:54:33
2662	CRC	N	2016-11-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	05001W	2016-11-14 18:54:33	2017-09-24 16:24:51
2672	NI	N	2017-01-01 00:00:00	2017-01-04 00:00:00	ANCIEN	\N	\N	\N	\N	14363X	2017-01-04 10:02:09	2017-01-06 09:29:16
2676	NI	N	2017-05-17 00:00:00	2017-05-23 00:00:00	ANCIEN	\N	\N	\N	\N	14365A	2017-05-17 11:44:22	2017-05-24 14:34:25
2687	NI	N	2017-06-15 00:00:00	2017-06-21 00:00:00	ANCIEN	\N	\N	\N	\N	16813M	2017-06-22 12:19:12	2017-06-22 12:19:42
2688	UMP	N	2017-06-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	16813M	2017-06-22 12:19:42	2017-09-24 18:16:52
2718	LREM	N	2017-06-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04066L	2017-06-30 09:47:44	2017-09-24 17:47:28
2343	ECO	N	2012-01-11 00:00:00	2017-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	01044R	\N	2017-06-30 09:52:11
2346	ECO	N	2012-01-11 00:00:00	2017-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	11076S	\N	2017-06-30 09:52:11
2349	ECO	N	2012-01-11 00:00:00	2017-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	11033F	\N	2017-06-30 09:52:11
2719	NI	N	2017-06-30 00:00:00	2017-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	11076S	2017-06-30 09:59:47	2017-07-07 17:34:47
2720	NI	N	2017-06-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11055M	2017-06-30 10:00:00	2017-09-24 18:07:57
2721	NI	N	2017-06-30 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	11033F	2017-06-30 10:00:08	2017-10-03 16:43:38
2722	NI	N	2017-06-30 00:00:00	2017-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	01044R	2017-06-30 10:00:17	2017-07-07 17:35:54
2723	NI	N	2017-06-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11029K	2017-06-30 10:00:25	2017-09-24 17:09:24
2724	NI	N	2017-06-30 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	11065P	2017-06-30 10:00:33	2017-10-03 16:56:55
2725	NI	N	2017-06-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04067M	2017-06-30 10:00:55	2017-09-24 17:47:27
2726	NI	N	2017-06-30 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	11099A	2017-06-30 10:01:05	2017-10-03 16:58:46
2730	SOC	N	2017-07-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	18127E	2017-07-05 17:48:05	2017-09-24 18:16:52
2224	UMP	N	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11100Y	\N	2017-09-24 13:57:40
2795	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19399H	2017-09-24 18:05:40	2017-10-03 17:21:18
2796	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19693L	2017-09-24 18:05:40	2017-10-03 17:18:45
2797	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19695N	2017-09-24 18:07:56	2017-10-03 16:44:13
2798	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19663E	2017-09-24 18:07:56	2017-10-03 17:19:06
2799	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19329S	2017-09-24 18:16:33	2017-10-03 16:56:50
2218	UMP	N	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11071M	\N	2017-09-24 18:16:33
2800	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	14021P	2017-09-24 18:16:50	2017-10-03 17:10:33
2801	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19637C	2017-09-24 18:16:50	2017-10-03 16:57:10
2802	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19599P	2017-09-24 18:16:50	2017-10-03 17:08:35
2803	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	17589D	2017-09-24 18:16:51	2017-10-03 16:53:56
2804	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19581D	2017-09-24 18:16:51	2017-10-03 17:23:19
2805	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19569H	2017-09-24 18:16:51	2017-10-03 17:35:15
2806	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19565D	2017-09-24 18:16:51	2017-10-03 16:44:36
2440	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14197C	2014-09-28 12:54:15	2014-10-07 17:06:10
2423	SOC	N	2014-05-05 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14012N	2014-05-05 10:59:01	2014-09-28 16:54:10
2437	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14193X	2014-09-28 12:32:22	2014-10-07 15:35:10
2439	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14195A	2014-09-28 12:44:31	2014-10-07 15:41:50
2441	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14103D	2014-09-28 13:06:30	2014-10-07 15:54:36
2442	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	05004A	2014-09-28 13:16:32	2014-10-07 15:28:36
2449	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14137P	2014-09-28 16:42:03	2014-10-07 17:00:28
2450	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14133K	2014-09-28 16:42:03	2014-10-07 15:28:26
2451	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14105F	2014-09-28 16:49:55	2014-10-07 15:29:12
2452	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14109K	2014-09-28 16:49:55	2014-10-07 16:58:47
2485	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14233N	2014-09-28 17:35:38	2014-10-07 17:08:14
2486	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14235Q	2014-09-28 17:38:25	2014-10-07 14:47:48
2487	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14157T	2014-09-28 17:38:25	2014-10-07 15:36:50
2495	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14187A	2014-09-28 17:58:04	2014-10-07 15:36:13
2496	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14051J	2014-09-28 18:00:57	2014-10-07 17:03:06
2497	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14053L	2014-09-28 18:00:57	2014-10-07 15:29:55
2498	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14247U	2014-09-28 18:03:38	2014-10-07 17:07:43
2501	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14253S	2014-09-28 18:32:41	2014-10-07 15:34:53
2503	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14255U	2014-09-28 18:46:12	2014-10-07 15:51:30
2504	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	2014-09-28 18:46:12	2014-10-07 15:31:26
2510	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14111D	2014-09-28 19:03:23	2014-10-07 15:45:08
2511	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14071N	2014-09-28 19:05:58	2014-10-07 15:41:39
2512	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14119M	2014-09-28 19:05:58	2014-10-07 15:40:52
2538	UMP	N	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	14253S	2014-10-07 15:34:52	\N
2539	UMP	R	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	14237S	2014-10-07 15:35:03	\N
2540	UMP	N	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	14193X	2014-10-07 15:35:10	\N
2543	UMP	N	2014-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14135M	2014-10-07 15:36:13	\N
2548	UMP	N	2014-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14157T	2014-10-07 15:36:50	\N
2550	UMP	N	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	14038Y	2014-10-07 15:39:00	2015-02-19 11:40:44
2553	UMP	A	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	14215L	2014-10-07 15:39:19	2014-10-07 15:40:58
2554	UMP	A	2014-10-07 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	14037X	2014-10-07 15:39:26	2017-06-29 09:54:31
2555	UMP	A	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	14191V	2014-10-07 15:39:32	2017-10-03 18:21:37
2563	UMP	A	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	14069U	2014-10-07 15:41:42	2017-02-01 16:24:19
2564	UMP	R	2014-10-07 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	14195A	2014-10-07 15:41:50	2017-10-03 16:53:48
2566	UMP	A	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	14213J	2014-10-07 00:00:00	2014-10-07 00:00:00
2568	UMP	R	2014-10-07 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	14111D	2014-10-07 15:45:08	2017-10-03 16:54:40
2569	UMP	N	2014-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14087W	2014-10-07 15:46:17	\N
2570	UC	N	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	14030Q	2014-10-07 15:50:47	\N
2571	UC	N	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	14089Y	2014-10-07 15:51:19	\N
2572	UC	N	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	14255U	2014-10-07 15:51:30	\N
2573	UC	N	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	14083S	2014-10-07 15:51:36	\N
2574	UC	N	2014-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14042U	2014-10-07 00:00:00	\N
2575	UC	A	2014-10-07 00:00:00	2015-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	14043V	2014-10-07 15:52:38	2015-02-06 14:27:53
2576	UC	N	2014-10-07 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	14034U	2014-10-07 15:53:01	2017-10-03 16:57:46
2577	UC	N	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	14231L	2014-10-07 15:53:09	\N
2578	UC	N	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	14179A	2014-10-07 15:53:26	\N
2579	UC	A	2014-10-07 00:00:00	2015-02-06 00:00:00	ANCIEN	\N	\N	\N	\N	14044W	2014-10-07 15:53:35	2015-02-06 14:32:44
2580	UC	N	2014-10-07 00:00:00	2020-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	08044W	2014-10-07 15:53:46	\N
2581	UC	N	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	14073Q	2014-10-07 15:54:00	\N
2582	UC	R	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	14205J	2014-10-07 15:54:12	2014-10-07 20:11:18
2583	UC	N	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	14219Q	2014-10-07 15:54:21	\N
2584	UC	N	2014-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14103D	2014-10-07 15:54:36	\N
2585	UC	N	2014-10-07 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	14221J	2014-10-07 15:54:56	\N
2586	UC	N	2014-10-07 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	95049N	2014-10-07 15:55:04	2017-10-01 10:42:05
2587	UMP	N	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	14173T	2014-10-07 16:56:22	\N
2588	SOC	N	2014-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14159V	2014-10-07 16:57:19	\N
2589	SOC	N	2014-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14063N	2014-10-07 16:58:03	\N
2590	SOC	N	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	14109K	2014-10-07 16:58:47	\N
2591	SOC	N	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	14257W	2014-10-07 16:58:54	\N
2593	SOC	N	2014-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14028W	2014-10-07 17:00:26	\N
2595	SOC	N	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	14225N	2014-10-07 17:00:43	\N
2596	SOC	N	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	14229S	2014-10-07 17:01:23	\N
2599	SOC	N	2014-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14051J	2014-10-07 17:03:06	\N
2600	SOC	N	2014-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14227Q	2014-10-07 17:03:14	\N
2606	NI	N	2014-10-07 00:00:00	2015-07-14 00:00:00	ANCIEN	\N	\N	\N	\N	14239U	2014-10-07 17:06:21	2017-09-13 11:15:11
2607	NI	N	2014-10-07 00:00:00	2015-07-14 00:00:00	ANCIEN	\N	\N	\N	\N	98022P	2014-10-07 17:06:29	2015-07-15 14:47:14
2608	NI	N	2014-10-07 00:00:00	2015-07-14 00:00:00	ANCIEN	\N	\N	\N	\N	14241N	2014-10-07 17:06:35	2015-07-15 14:47:21
2044	UMP	R	2008-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	08069G	\N	2014-10-07 19:32:09
2618	UMP	N	2014-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	2014-10-07 00:00:00	\N
2620	UMP	R	2014-10-07 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	86044G	2014-10-09 09:10:32	2017-10-01 10:32:58
2637	NI	N	2015-04-08 00:00:00	2015-04-14 00:00:00	ANCIEN	\N	\N	\N	\N	14271U	2015-04-07 17:15:52	2015-04-15 12:04:30
2646	UMP	N	2015-06-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	14147R	2015-06-15 18:12:01	\N
2648	RDSE	N	2015-07-15 00:00:00	2024-03-20 00:00:00	ANCIEN	\N	\N	\N	\N	98022P	2015-07-15 00:00:00	2017-10-03 00:00:00
2649	RDSE	N	2015-07-15 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14241N	2015-07-15 14:47:20	2017-10-03 18:19:53
2650	RDSE	R	2015-07-15 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	14239U	2015-07-15 14:47:27	2017-06-29 09:53:12
2658	UMP	N	2016-01-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14331P	2016-01-12 00:00:00	\N
2742	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19319Q	2017-09-24 10:41:27	2017-10-03 17:37:06
2808	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	04008A	2017-09-24 18:16:51	2017-10-03 17:18:56
2737	SOC	N	2017-07-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19285X	2017-07-31 12:04:06	2017-09-24 17:55:12
2739	NI	N	2017-08-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	12035A	2017-08-07 17:16:36	2017-09-24 17:18:03
2741	NI	N	2017-09-22 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	15447F	2017-09-22 11:11:24	2017-10-03 17:20:55
2125	UMP	N	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11011M	\N	2017-09-24 10:41:28
2752	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19619A	2017-09-24 16:45:25	2017-10-03 17:37:19
2753	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19621T	2017-09-24 16:45:25	2017-10-03 17:16:33
2201	SOC	N	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11112D	\N	2017-09-24 16:45:26
2807	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19585H	2017-09-24 18:16:51	2017-10-03 16:54:55
2809	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	04018C	2017-09-24 18:17:55	2017-10-03 17:26:36
3210	UMP	A	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20076G	\N	\N
2810	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19697Q	2017-09-24 18:17:55	2017-10-03 16:57:04
2811	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19699S	2017-09-24 18:17:55	2017-10-03 17:36:10
2812	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19701S	2017-09-24 18:17:55	2017-10-03 17:17:16
2331	UMP	R	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11091R	\N	2017-09-24 18:17:56
2813	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19387D	2017-09-24 18:20:09	2017-10-03 16:57:58
2814	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19383Y	2017-09-24 18:20:09	2017-10-03 17:16:27
2815	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19415P	2017-09-24 18:23:21	2017-10-03 17:16:05
2816	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19413M	2017-09-24 18:23:21	2017-10-03 17:12:17
2817	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19631V	2017-09-24 18:27:44	2017-10-03 17:05:06
2818	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	17779H	2017-09-24 18:41:37	2017-10-03 17:11:00
2409	SOC	N	2014-01-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	14001X	2014-01-07 16:41:44	\N
2445	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	95041E	2014-09-28 13:40:32	2014-10-07 15:39:17
2411	SOC	N	2014-02-14 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14002L	2014-02-14 17:27:28	2014-09-28 18:32:43
2443	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14097Y	2014-09-28 13:32:34	2014-10-07 17:08:34
2444	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14135M	2014-09-28 13:40:32	2014-10-07 15:36:13
2447	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14030Q	2014-09-28 16:40:49	2014-10-07 15:50:47
2448	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14031R	2014-09-28 16:40:49	2014-10-07 15:40:21
2453	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14205J	2014-09-28 16:54:08	2014-10-07 15:54:12
2499	AUCUN	N	2014-10-01 00:00:00	2014-10-06 00:00:00	ANCIEN	\N	\N	\N	\N	14249W	2014-09-28 18:19:47	2014-10-07 15:35:35
2526	CRC	N	2014-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14235Q	2014-10-07 14:47:48	\N
2527	UMP	N	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	14133K	2014-10-07 15:28:26	\N
2528	UMP	N	2014-10-07 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	05004A	2014-10-07 15:28:35	2017-10-01 10:22:23
2529	UMP	N	2014-10-07 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	14093U	2014-10-07 15:28:58	2017-10-03 16:53:31
2530	UMP	N	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	14105F	2014-10-07 15:29:12	\N
2531	UMP	N	2014-10-07 00:00:00	2017-06-01 00:00:00	ANCIEN	\N	\N	\N	\N	14175V	2014-10-07 15:29:28	2017-06-02 10:02:56
2532	UMP	R	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	14053L	2014-10-07 00:00:00	2014-10-07 00:00:00
2533	UMP	N	2014-10-07 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14209N	2014-10-07 15:30:26	2017-10-01 10:34:22
2534	UMP	N	2014-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14079W	2014-10-07 15:30:46	2014-10-07 16:34:16
2535	UMP	N	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	14259Y	2014-10-07 15:31:07	2014-10-07 16:34:33
2536	UMP	N	2014-10-07 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14041T	2014-10-07 15:31:26	2014-10-07 16:34:47
2537	UMP	N	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	14217N	2014-10-07 15:32:16	\N
2592	SOC	N	2014-10-07 00:00:00	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	14039A	2014-10-07 16:59:58	2017-06-29 09:55:57
2609	NI	N	2014-10-07 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	08021P	2014-10-07 17:07:33	2017-10-03 16:58:35
2610	NI	N	2014-10-07 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14247U	2014-10-07 17:07:43	2017-10-01 10:25:16
2611	NI	N	2014-10-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	14055N	2014-10-07 17:07:51	\N
2616	RDSE	N	2014-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14261S	2014-10-07 17:37:09	\N
2617	RDSE	N	2014-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14201E	2014-10-07 17:37:28	\N
2625	NI	N	2014-12-28 00:00:00	2015-01-04 00:00:00	ANCIEN	\N	\N	\N	\N	14265W	2015-01-02 11:36:27	2015-01-05 11:56:06
2626	UMP	N	2015-01-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14265W	2015-01-05 11:56:04	2017-01-25 15:21:02
2640	NI	N	2015-05-04 00:00:00	2015-05-11 00:00:00	ANCIEN	\N	\N	\N	\N	14275Y	2015-05-04 10:27:12	2015-05-12 16:49:01
2628	UMP	N	2015-01-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	92045V	2015-01-09 15:18:35	2017-09-24 17:29:37
2636	SOC	N	2015-03-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14269B	2015-03-10 16:55:27	2017-09-24 18:07:57
2641	NI	N	2015-05-04 00:00:00	2015-05-11 00:00:00	ANCIEN	\N	\N	\N	\N	14277B	2015-05-04 10:29:04	2015-05-12 16:49:08
2642	UC	A	2015-05-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	14275Y	2015-05-12 16:49:00	2015-05-12 18:11:15
2643	UC	A	2015-05-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14277B	2015-05-12 16:49:08	2015-05-12 18:11:30
2216	SOC	N	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11109J	\N	2015-06-11 00:00:00
2212	SOC	N	\N	2017-06-27 00:00:00	ANCIEN	\N	\N	\N	\N	04095R	\N	2017-06-29 09:54:14
2647	SOC	N	2015-06-17 00:00:00	\N	ACTIF	\N	\N	\N	\N	14281W	2015-06-17 10:08:01	\N
2673	UMP	N	2017-01-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14363X	2017-01-06 09:29:15	2017-09-24 19:25:10
2657	UMP	N	2015-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	14329V	2015-10-12 00:00:00	\N
2669	AUCUN	N	2016-12-11 00:00:00	2016-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	14361V	2016-12-12 15:59:30	2016-12-14 18:37:23
2729	NI	N	2017-07-04 00:00:00	2017-07-04 00:00:00	ANCIEN	\N	\N	\N	\N	18127E	2017-07-04 16:05:20	2017-07-05 17:48:06
2735	LREM	N	2017-07-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19269X	2017-07-25 12:14:19	\N
2744	AUCUN	N	2017-09-23 00:00:00	2017-09-26 00:00:00	ANCIEN	\N	\N	\N	\N	14029X	2017-09-24 11:13:08	2017-09-27 18:53:55
2745	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19629C	2017-09-24 12:39:58	2017-10-03 17:00:27
2819	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19489J	2017-09-24 18:41:37	2017-10-03 17:10:44
2820	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	18083K	2017-09-24 18:44:44	2017-10-03 17:17:08
2821	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19703U	2017-09-24 18:49:56	2017-10-03 17:26:45
2822	AUCUN	N	2017-09-25 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19575F	2017-09-24 18:51:50	2017-10-03 17:15:44
2823	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19705W	2017-09-24 18:59:59	2017-10-03 17:26:04
2824	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19707Y	2017-09-24 18:59:59	2017-10-03 17:15:31
2825	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19709B	2017-09-24 18:59:59	2017-10-03 17:23:00
2826	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19503N	2017-09-24 19:05:36	2017-10-03 17:11:46
2827	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19511N	2017-09-24 19:14:36	2017-10-03 17:35:32
2828	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19563B	2017-09-24 19:16:18	2017-10-03 16:59:15
2829	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19483C	2017-09-24 19:17:41	2017-10-03 17:23:08
2830	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19369B	2017-09-24 19:19:07	2017-10-03 17:36:56
2831	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19367Y	2017-09-24 19:19:07	2017-10-03 17:15:57
2832	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	17637T	2017-09-24 19:25:09	2017-10-03 17:24:40
2833	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19711U	2017-09-24 19:25:09	2017-10-03 17:22:29
2834	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19591F	2017-09-24 19:25:09	2017-10-03 17:09:23
2835	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19593H	2017-09-24 19:25:09	2017-10-03 16:44:56
2836	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19479G	2017-09-24 19:26:20	2017-10-03 17:37:37
2837	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19467C	2017-09-24 19:26:20	2017-10-03 17:17:02
2838	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19531S	2017-09-24 19:31:54	2017-10-03 17:10:10
2839	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19713W	2017-09-24 19:31:54	2017-10-03 17:37:26
2028	UMP	N	2008-10-01 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	\N	08065C	\N	2017-09-25 09:57:52
2841	AUCUN	N	2017-09-25 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	16431B	2017-09-25 10:03:31	2017-10-01 10:37:45
2842	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19301E	2017-09-25 10:54:33	2017-10-03 16:57:54
2843	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19715Y	2017-09-25 10:54:33	2017-10-03 17:10:01
2844	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	12016W	2017-09-25 10:54:33	2017-10-03 17:11:14
2845	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19717B	2017-09-25 10:56:48	2017-10-03 16:56:02
2846	AUCUN	N	2017-10-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19295A	2017-09-25 11:00:40	2017-10-03 17:06:12
2860	CRC	R	2017-10-03 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	11033F	2017-10-03 16:43:38	2017-10-03 16:45:44
2861	CRC	R	2017-10-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04038G	2017-10-03 16:43:56	2017-10-03 16:45:58
2862	CRC	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19695N	2017-10-03 00:00:00	\N
2863	CRC	R	2017-10-03 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	19347U	2017-10-03 16:44:20	2017-10-03 16:46:12
2864	CRC	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19565D	2017-10-03 00:00:00	\N
2865	CRC	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19593H	2017-10-03 00:00:00	\N
2866	CRC	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19687N	2017-10-03 00:00:00	\N
2867	RTLI	N	2017-10-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14093U	2017-10-03 16:53:31	\N
2868	RTLI	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19545Y	2017-10-03 00:00:00	\N
2869	RTLI	N	2017-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	14195A	2017-10-03 16:53:47	\N
2870	RTLI	A	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	17589D	2017-10-03 00:00:00	2017-10-03 00:00:00
2871	RTLI	N	2017-10-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	02002K	2017-10-03 16:54:02	\N
2872	RTLI	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11064N	2017-10-03 00:00:00	\N
2873	RTLI	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19583F	2017-10-03 00:00:00	\N
2874	RTLI	N	2017-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	14251Q	2017-10-03 16:54:24	\N
2875	RTLI	N	2017-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	14111D	2017-10-03 16:54:40	\N
2876	RTLI	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04057K	2017-10-03 00:00:00	\N
2877	RTLI	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19585H	2017-10-03 00:00:00	\N
2879	LREM	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19651A	2017-10-03 00:00:00	\N
2881	LREM	N	2017-10-03 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	19543W	2017-10-03 16:56:36	\N
2882	LREM	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19659J	2017-10-03 00:00:00	\N
2883	LREM	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19329S	2017-10-03 00:00:00	\N
2885	LREM	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19697Q	2017-10-03 00:00:00	\N
2886	LREM	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19637C	2017-10-03 00:00:00	\N
2888	LREM	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19349W	2017-10-03 00:00:00	\N
2890	LREM	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19301E	2017-10-03 00:00:00	\N
2893	LREM	R	2017-10-03 00:00:00	2019-06-30 00:00:00	ANCIEN	\N	\N	\N	\N	08021P	2017-10-03 16:58:35	2017-10-03 17:00:20
3010	SOC	N	2014-10-07 00:00:00	2018-07-09 00:00:00	ANCIEN	\N	\N	\N	\N	14107H	\N	\N
3035	NI	N	2019-04-04 00:00:00	2019-06-23 00:00:00	ANCIEN	\N	\N	\N	\N	04061F	\N	\N
3039	RDSE	N	2019-03-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19253P	\N	\N
3040	NI	N	2019-03-04 00:00:00	2019-03-04 00:00:00	ANCIEN	\N	\N	\N	\N	19253P	\N	\N
3045	RDSE	N	2019-05-28 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	14121F	\N	\N
3049	NI	N	2019-06-24 00:00:00	2019-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	04069P	\N	\N
3052	NI	N	2019-07-01 00:00:00	2019-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	19812Y	\N	\N
3056	SOC	N	2019-09-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19820Y	\N	\N
3055	NI	N	2019-08-28 00:00:00	2019-09-02 00:00:00	ANCIEN	\N	\N	\N	\N	19820Y	\N	\N
3057	NI	N	2019-10-01 00:00:00	2019-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19826F	\N	\N
3072	UMP	N	2020-06-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19930E	\N	\N
3162	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20142Y	\N	\N
3073	UC	A	2020-07-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19914E	\N	\N
3083	SOC	N	2020-08-04 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19968U	\N	\N
3164	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	17965H	\N	\N
3169	RDSE	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20116W	\N	\N
3170	RDSE	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20132W	\N	\N
3171	RDSE	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20072C	\N	\N
3172	CRC	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20112S	\N	\N
3173	CRC	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20102Q	\N	\N
3174	CRC	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20046A	\N	\N
3175	UMP	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20032T	\N	\N
3176	UMP	R	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20024T	\N	\N
3177	UMP	A	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20022R	\N	\N
3178	UMP	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	17367Q	\N	\N
3180	UMP	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20086J	\N	\N
3181	UMP	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20078J	\N	\N
3182	UMP	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20138D	\N	\N
3183	UMP	A	2020-10-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20152B	\N	\N
3184	UMP	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	17737W	\N	\N
3185	UMP	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20090E	\N	\N
3186	UMP	A	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20104S	\N	\N
3187	UMP	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20140W	\N	\N
3188	UMP	A	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20124W	\N	\N
3189	UMP	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20074E	\N	\N
3190	UMP	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20038A	\N	\N
3191	UMP	R	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20120S	\N	\N
3192	UMP	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	08056B	\N	\N
3193	UMP	R	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20068G	\N	\N
3194	UMP	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20034V	\N	\N
3195	UMP	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20056C	\N	\N
3196	UMP	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20126Y	\N	\N
3197	UMP	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20108W	\N	\N
3198	UMP	A	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20096L	\N	\N
3199	UMP	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20148F	\N	\N
3200	UMP	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20118Y	\N	\N
3201	UMP	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20054A	\N	\N
3202	UMP	R	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20020P	\N	\N
3203	UMP	A	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20044X	\N	\N
3204	UMP	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20098N	\N	\N
3205	UMP	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20062A	\N	\N
3206	UMP	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20136B	\N	\N
3207	UMP	A	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20026V	\N	\N
3208	UMP	R	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20058E	\N	\N
3212	SOC	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20088L	\N	\N
3211	SOC	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20094J	\N	\N
3213	SOC	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20114U	\N	\N
3214	SOC	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20080C	\N	\N
3215	SOC	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	12028B	\N	\N
3216	SOC	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20070A	\N	\N
3217	SOC	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	18193Q	\N	\N
3218	SOC	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20028X	\N	\N
3219	SOC	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20030R	\N	\N
3220	SOC	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	17965H	\N	\N
3221	SOC	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20082E	\N	\N
3222	SOC	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20084G	\N	\N
3223	SOC	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20064C	\N	\N
3224	SOC	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20060X	\N	\N
3228	RTLI	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	14221J	\N	\N
3226	SOC	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	14121F	\N	\N
3227	SOC	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20018V	\N	\N
3229	RTLI	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20050V	\N	\N
3230	RTLI	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20122U	\N	\N
3231	LREM	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20106U	\N	\N
3232	LREM	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20128B	\N	\N
3233	LREM	N	2020-10-05 00:00:00	2020-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	19265T	\N	\N
3234	LREM	N	2020-10-05 00:00:00	2020-11-01 00:00:00	ANCIEN	\N	\N	\N	\N	14037X	\N	\N
3235	LREM	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20016T	\N	\N
3236	LREM	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20146D	\N	\N
3237	LREM	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20150Y	\N	\N
3238	GEST	N	2020-10-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19347U	\N	\N
3239	GEST	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20110Q	\N	\N
3243	GEST	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20134Y	\N	\N
3241	GEST	N	2020-10-05 00:00:00	2021-09-14 00:00:00	ANCIEN	\N	\N	\N	\N	11033F	\N	\N
3242	GEST	N	2020-10-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11065P	\N	\N
3244	GEST	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20100N	\N	\N
3245	GEST	N	2020-10-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11099A	\N	\N
3246	GEST	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20142Y	\N	\N
3247	GEST	N	2020-10-05 00:00:00	2023-12-13 00:00:00	ANCIEN	\N	\N	\N	\N	20036X	\N	\N
3248	GEST	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20130U	\N	\N
3249	GEST	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20092G	\N	\N
3250	GEST	N	2020-10-05 00:00:00	2022-07-03 00:00:00	ANCIEN	\N	\N	\N	\N	19689Q	\N	\N
3251	UC	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	14189C	\N	\N
3252	UC	A	2020-10-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19543W	\N	\N
3253	UC	A	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20042V	\N	\N
3254	UC	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20144B	\N	\N
3255	UC	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	17229F	\N	\N
3256	UC	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20040T	\N	\N
3257	UC	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	17023S	\N	\N
3258	UC	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20048C	\N	\N
3259	UC	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20066E	\N	\N
3260	UC	N	2020-10-05 00:00:00	\N	ACTIF	\N	\N	\N	\N	20052X	\N	\N
3307	UMP	A	2023-01-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20980G	\N	\N
3300	GEST	N	2022-07-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20914V	\N	\N
3310	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	14267Y	\N	\N
3311	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19507S	\N	\N
3667	NI	N	2024-03-21 00:00:00	2024-04-01 00:00:00	ANCIEN	\N	\N	\N	\N	14241N	\N	\N
3668	RDSE	N	2024-04-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	14241N	\N	\N
3658	UMP	N	2023-11-14 00:00:00	\N	ACTIF	\N	\N	\N	\N	21058J	\N	\N
3009	RDSE	N	2018-07-10 00:00:00	\N	ACTIF	\N	\N	\N	\N	14107H	\N	\N
3018	SOC	N	2017-06-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	13002U	2018-10-01 10:58:22	\N
3019	SOC	N	2011-10-01 00:00:00	2012-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	11069T	2018-10-01 11:10:37	\N
3020	AUCUN	N	2017-06-18 00:00:00	2017-06-18 00:00:00	ANCIEN	\N	\N	\N	\N	01062T	2018-10-01 11:21:56	\N
3021	SOC	N	2017-06-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	01062T	2018-10-01 00:00:00	\N
3031	UMP	A	2019-01-11 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19794Q	\N	\N
3050	UMP	N	2019-06-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04069P	\N	\N
3168	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20152B	\N	\N
3067	NI	N	2020-06-18 00:00:00	2020-07-07 00:00:00	ANCIEN	\N	\N	\N	\N	19914E	\N	\N
3266	LREM	N	2020-11-02 00:00:00	2022-06-20 00:00:00	ANCIEN	\N	\N	\N	\N	20174H	\N	\N
3267	LREM	N	2020-11-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	14249W	\N	\N
3277	UC	N	2021-07-15 00:00:00	\N	ACTIF	\N	\N	\N	\N	20248J	\N	\N
3272	UMP	A	2020-12-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20180F	\N	\N
3279	UMP	N	2021-09-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20252E	\N	\N
3291	LREM	N	2021-12-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19525U	\N	\N
3292	NI	N	2021-12-08 00:00:00	2021-12-14 00:00:00	ANCIEN	\N	\N	\N	\N	20286Q	\N	\N
3332	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19705W	\N	\N
3333	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	11027H	\N	\N
3334	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19709B	\N	\N
3335	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21037D	\N	\N
3336	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21038E	\N	\N
3337	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	01058X	\N	\N
3355	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21048G	\N	\N
3360	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19447X	\N	\N
3361	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21050A	\N	\N
3362	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21051B	\N	\N
3363	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21052C	\N	\N
3364	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21053D	\N	\N
3365	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21054E	\N	\N
3366	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21055F	\N	\N
3410	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19687N	\N	\N
3411	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19611R	\N	\N
3412	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	99004R	\N	\N
3413	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	04042C	\N	\N
3414	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19711U	\N	\N
3415	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19593H	\N	\N
3416	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21072G	\N	\N
3417	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21073H	\N	\N
3418	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21074J	\N	\N
3419	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	14329V	\N	\N
3420	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	14357A	\N	\N
3421	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	11074Q	\N	\N
3422	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21075K	\N	\N
3423	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21076L	\N	\N
3424	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	18231D	\N	\N
3425	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21077M	\N	\N
3426	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	20252E	\N	\N
3427	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21078N	\N	\N
3428	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19695N	\N	\N
3429	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	11053K	\N	\N
3450	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19565D	\N	\N
3451	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21083K	\N	\N
3452	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	04008A	\N	\N
3453	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	15197G	\N	\N
3454	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19667J	\N	\N
3455	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19673G	\N	\N
3456	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19669L	\N	\N
3459	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21085M	\N	\N
3460	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21086N	\N	\N
3462	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19585H	\N	\N
3470	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21092L	\N	\N
3471	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21093M	\N	\N
3472	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19683J	\N	\N
3473	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21094N	\N	\N
3474	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21095P	\N	\N
3663	AUCUN	N	2024-03-18 00:00:00	2024-03-18 00:00:00	ANCIEN	\N	\N	\N	\N	21125C	\N	\N
3012	UC	N	2018-07-25 00:00:00	\N	ACTIF	\N	\N	\N	\N	19745F	\N	\N
3071	NI	N	2020-06-28 00:00:00	2020-06-29 00:00:00	ANCIEN	\N	\N	\N	\N	19930E	\N	\N
3024	NI	N	2018-11-04 00:00:00	2018-12-05 00:00:00	ANCIEN	\N	\N	\N	\N	99002P	\N	\N
3030	NI	N	2018-12-31 00:00:00	2019-01-10 00:00:00	ANCIEN	\N	\N	\N	\N	19794Q	\N	\N
3047	NI	N	2019-06-14 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	08056B	\N	\N
3062	NI	N	2020-03-04 00:00:00	2020-03-23 00:00:00	ANCIEN	\N	\N	\N	\N	19866P	\N	\N
3278	NI	N	2021-07-28 00:00:00	2021-09-07 00:00:00	ANCIEN	\N	\N	\N	\N	20252E	\N	\N
3273	UC	R	2021-02-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19685L	\N	\N
3295	UC	N	2022-02-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20298U	\N	\N
3306	NI	N	2023-01-01 00:00:00	2023-01-04 00:00:00	ANCIEN	\N	\N	\N	\N	20980G	\N	\N
3463	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21088Q	\N	\N
3305	UMP	A	2022-07-28 00:00:00	\N	ACTIF	\N	\N	\N	\N	07029T	\N	\N
3464	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21089R	\N	\N
3465	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21090J	\N	\N
3466	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19649G	\N	\N
3467	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19647E	\N	\N
3468	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	07033P	\N	\N
3469	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21091K	\N	\N
3532	CRC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19760E	\N	\N
3533	CRC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21084L	\N	\N
3534	CRC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	11040E	\N	\N
3535	CRC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21088Q	\N	\N
3536	CRC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21034A	\N	\N
3537	CRC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19681G	\N	\N
3538	CRC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	11056N	\N	\N
3539	CRC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19695N	\N	\N
3540	CRC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19565D	\N	\N
3541	CRC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21075K	\N	\N
3542	CRC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19593H	\N	\N
3543	CRC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19687N	\N	\N
3544	CRC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21049H	\N	\N
3545	CRC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21030V	\N	\N
3546	SOC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19631V	\N	\N
3547	SOC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21035B	\N	\N
3548	SOC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21089R	\N	\N
3549	SOC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21045D	\N	\N
3550	SOC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19295A	\N	\N
3551	SOC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	11027H	\N	\N
3552	SOC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	18395Y	\N	\N
3553	SOC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21067K	\N	\N
3554	SOC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19649G	\N	\N
3555	SOC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	11074Q	\N	\N
3556	SOC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	11110B	\N	\N
3557	SOC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21062E	\N	\N
3558	SOC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19647E	\N	\N
3559	SOC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19551W	\N	\N
3560	SOC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19531S	\N	\N
3561	SOC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19683J	\N	\N
3562	SOC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	14021P	\N	\N
3563	SOC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19489J	\N	\N
3564	SOC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	18207D	\N	\N
3565	SOC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	17779H	\N	\N
3566	SOC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	12016W	\N	\N
3567	SOC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	18231D	\N	\N
3568	SOC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21060C	\N	\N
3569	SOC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21056G	\N	\N
3570	SOC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21059K	\N	\N
3571	SOC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	11045K	\N	\N
3572	SOC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19669L	\N	\N
3573	SOC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19413M	\N	\N
3574	SOC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21051B	\N	\N
3575	SOC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21031W	\N	\N
3576	SOC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21082J	\N	\N
3577	SOC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21077M	\N	\N
3578	SOC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21057H	\N	\N
3665	UMP	A	2024-03-20 00:00:00	\N	ACTIF	\N	\N	\N	\N	21125C	\N	\N
3003	CRC	N	2018-06-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	19758L	2018-06-01 18:48:36	\N
3004	AUCUN	N	2018-07-01 00:00:00	2018-07-01 00:00:00	ANCIEN	\N	\N	\N	\N	19760E	\N	\N
3037	RDSE	N	2019-04-30 00:00:00	\N	ACTIF	\N	\N	\N	\N	14207L	\N	\N
3006	CRC	N	2018-07-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19760E	\N	\N
3015	UMP	N	2018-08-09 00:00:00	\N	ACTIF	\N	\N	\N	\N	19768N	\N	\N
1998	SOC	N	2008-10-01 00:00:00	2020-06-15 00:00:00	ANCIEN	\N	\N	\N	\N	08068F	\N	\N
3033	UMP	R	2019-03-04 00:00:00	\N	ACTIF	\N	\N	\N	\N	19798U	\N	\N
3076	UMP	N	2020-07-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19954N	\N	\N
3070	SOC	N	2020-06-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19926J	\N	\N
3075	NI	N	2020-07-14 00:00:00	2020-07-14 00:00:00	ANCIEN	\N	\N	\N	\N	19954N	\N	\N
3103	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20040T	\N	\N
3106	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20044X	\N	\N
3120	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20070A	\N	\N
3121	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20072C	\N	\N
3122	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20074E	\N	\N
3123	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20076G	\N	\N
3124	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20078J	\N	\N
3126	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20080C	\N	\N
3127	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20082E	\N	\N
3134	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20096L	\N	\N
2556	UMP	N	2014-10-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	14061L	2014-10-07 15:39:42	\N
3135	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20098N	\N	\N
3136	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20100N	\N	\N
3146	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20114U	\N	\N
3147	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20116W	\N	\N
3151	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20122U	\N	\N
3159	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20136B	\N	\N
3160	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20138D	\N	\N
3161	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20140W	\N	\N
1957	SOC	N	2008-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08038Y	\N	\N
3165	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20146D	\N	\N
3166	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20148F	\N	\N
3167	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20150Y	\N	\N
3280	NI	N	2021-09-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11033F	\N	\N
3290	UMP	R	2021-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19707Y	\N	\N
3294	NI	N	2022-02-03 00:00:00	2022-02-07 00:00:00	ANCIEN	\N	\N	\N	\N	20298U	\N	\N
3308	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21029D	\N	\N
3309	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21030V	\N	\N
3319	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19563B	\N	\N
3320	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21031W	\N	\N
3321	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19479G	\N	\N
3330	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21035B	\N	\N
3345	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19531S	\N	\N
3371	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21057H	\N	\N
3372	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21058J	\N	\N
3373	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19421M	\N	\N
3374	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19399H	\N	\N
3375	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	11070L	\N	\N
3376	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19691J	\N	\N
3377	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19693L	\N	\N
3378	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21059K	\N	\N
3380	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21060C	\N	\N
3381	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19573D	\N	\N
3382	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21061D	\N	\N
3383	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	05008E	\N	\N
3384	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	20180F	\N	\N
3385	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21062E	\N	\N
3387	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21064G	\N	\N
3388	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21065H	\N	\N
3457	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19569H	\N	\N
3458	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21084L	\N	\N
3461	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21087P	\N	\N
3479	UMP	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21071F	\N	\N
3480	UMP	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	05008E	\N	\N
3481	UMP	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19667J	\N	\N
3482	UMP	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19954N	\N	\N
3483	UMP	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19367Y	\N	\N
3484	UMP	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19383Y	\N	\N
3485	UMP	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19621T	\N	\N
3486	UMP	A	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21063F	\N	\N
3487	UMP	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	04042C	\N	\N
3488	UMP	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21090J	\N	\N
3489	UMP	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	14329V	\N	\N
3490	UMP	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	18083K	\N	\N
3491	UMP	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19701S	\N	\N
3492	UMP	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21072G	\N	\N
3493	UMP	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	14357A	\N	\N
3494	UMP	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	04008A	\N	\N
3495	UMP	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	07033P	\N	\N
3496	UMP	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19507S	\N	\N
3497	UMP	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19673G	\N	\N
3498	UMP	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21091K	\N	\N
3499	UMP	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	20172F	\N	\N
3500	UMP	A	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	20180F	\N	\N
3501	UMP	A	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19399H	\N	\N
3502	UMP	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	11048N	\N	\N
3503	UMP	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21044C	\N	\N
3504	UMP	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19447X	\N	\N
3505	UMP	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	99004R	\N	\N
3506	UMP	A	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21081H	\N	\N
3507	UMP	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	86034E	\N	\N
3508	UMP	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19711U	\N	\N
3509	UMP	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19709B	\N	\N
3510	UMP	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19657G	\N	\N
3511	UMP	A	2023-10-03 00:00:00	2023-11-13 00:00:00	ANCIEN	\N	\N	\N	\N	21058J	\N	\N
3512	UMP	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	20252E	\N	\N
3513	UMP	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21080G	\N	\N
3514	UMP	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21029D	\N	\N
3515	UMP	A	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21039F	\N	\N
3516	UMP	A	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19573D	\N	\N
3517	UMP	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21055F	\N	\N
3518	UMP	R	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21047F	\N	\N
3519	UMP	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19533U	\N	\N
3520	UMP	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	11090Q	\N	\N
3521	UMP	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19679N	\N	\N
3522	UMP	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	14331P	\N	\N
3523	UMP	R	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19705W	\N	\N
3524	UMP	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21068L	\N	\N
3525	UMP	R	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21036C	\N	\N
3526	UMP	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19421M	\N	\N
3527	UMP	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	11043H	\N	\N
3528	UMP	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	01058X	\N	\N
3529	UMP	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19703U	\N	\N
3530	UMP	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21095P	\N	\N
3531	UMP	A	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21061D	\N	\N
3579	UC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21042A	\N	\N
3580	UC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21050A	\N	\N
3581	UC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21083K	\N	\N
3582	UC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	11053K	\N	\N
3583	UC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	14267Y	\N	\N
3584	UC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	11115U	\N	\N
3585	UC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	11070L	\N	\N
3586	UC	A	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	15197G	\N	\N
3587	UC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	14042U	\N	\N
3588	UC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21086N	\N	\N
3589	UC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19111A	\N	\N
3590	UC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	20286Q	\N	\N
3591	UC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	07004J	\N	\N
3592	UC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19691J	\N	\N
3593	UC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19569H	\N	\N
3594	UC	R	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19685L	\N	\N
3595	UC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19611R	\N	\N
3596	UC	A	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19699S	\N	\N
3597	UC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	11085T	\N	\N
3598	UC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19563B	\N	\N
3599	UC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19335Q	\N	\N
3600	UC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21053D	\N	\N
3601	UC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21038E	\N	\N
3602	UC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21064G	\N	\N
3603	UC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19619A	\N	\N
3604	UC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19713W	\N	\N
3605	UC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	01034P	\N	\N
3606	UC	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19479G	\N	\N
3646	NI	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21074J	\N	\N
3647	NI	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21085M	\N	\N
3648	NI	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21069M	\N	\N
3007	NI	N	2018-07-02 00:00:00	2018-07-02 00:00:00	ANCIEN	\N	\N	\N	\N	19762G	\N	\N
3022	CRC	R	2018-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11077T	\N	\N
3090	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20016T	\N	\N
3059	NI	N	2019-10-28 00:00:00	2019-11-06 00:00:00	ANCIEN	\N	\N	\N	\N	19591F	\N	\N
3091	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20018V	\N	\N
3092	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20020P	\N	\N
3093	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20022R	\N	\N
3094	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20024T	\N	\N
3095	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20026V	\N	\N
3096	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20028X	\N	\N
3097	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20030R	\N	\N
3099	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20034V	\N	\N
2049	UMP	N	2008-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08019V	\N	\N
3100	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20036X	\N	\N
3101	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	14189C	\N	\N
3104	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20042V	\N	\N
3105	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	14037X	\N	\N
3108	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20048C	\N	\N
3109	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20050V	\N	\N
3111	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20054A	\N	\N
3113	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20058E	\N	\N
3117	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20064C	\N	\N
3119	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20068G	\N	\N
3125	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	17023S	\N	\N
3128	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20084G	\N	\N
3129	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20086J	\N	\N
3133	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20094J	\N	\N
3137	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20102Q	\N	\N
3138	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	18193Q	\N	\N
3139	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20104S	\N	\N
3140	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20106U	\N	\N
3148	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	19265T	\N	\N
3149	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20118Y	\N	\N
3152	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20124W	\N	\N
3153	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20126Y	\N	\N
3154	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20128B	\N	\N
3367	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21056G	\N	\N
3368	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19619A	\N	\N
3369	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19621T	\N	\N
3289	LREM	N	2021-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	19057M	\N	\N
3285	SOC	N	2021-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20264J	\N	\N
3286	GEST	N	2021-10-01 00:00:00	\N	ACTIF	\N	\N	\N	\N	20266L	\N	\N
3370	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	11110B	\N	\N
3434	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19699S	\N	\N
3435	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21079P	\N	\N
3437	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19347U	\N	\N
3477	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19301E	\N	\N
3478	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21097R	\N	\N
3661	NI	N	2023-12-14 00:00:00	2024-03-10 00:00:00	ANCIEN	\N	\N	\N	\N	20036X	\N	\N
3008	UMP	N	2018-07-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19762G	\N	\N
3016	UMP	N	2018-09-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19766L	\N	\N
3061	RTLI	N	2020-03-03 00:00:00	2020-08-02 00:00:00	ANCIEN	\N	\N	\N	\N	14239U	\N	\N
3026	LREM	N	2018-11-17 00:00:00	2020-08-06 00:00:00	ANCIEN	\N	\N	\N	\N	19782L	\N	\N
3038	RTLI	N	2019-05-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19563B	\N	\N
3060	LREM	N	2019-11-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19591F	\N	\N
3274	RPR	A	1977-10-05 00:00:00	1980-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	000192	2021-03-26 14:18:45	\N
3098	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20032T	\N	\N
2386	UMP	N	2012-11-07 00:00:00	\N	ACTIF	\N	\N	\N	\N	04033B	\N	\N
3327	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19657G	\N	\N
3328	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21033Y	\N	\N
3329	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21034A	\N	\N
3331	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21036C	\N	\N
3338	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21039F	\N	\N
3339	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19367Y	\N	\N
3340	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21040X	\N	\N
3341	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21041Y	\N	\N
3344	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21043B	\N	\N
3346	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21044C	\N	\N
3347	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19703U	\N	\N
3351	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19533U	\N	\N
3352	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19545Y	\N	\N
3353	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21046E	\N	\N
3354	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21047F	\N	\N
3356	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	11048N	\N	\N
3357	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19553Y	\N	\N
3358	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19551W	\N	\N
3359	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21049H	\N	\N
3379	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	11115U	\N	\N
3386	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21063F	\N	\N
3389	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	18395Y	\N	\N
3390	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	11065P	\N	\N
3391	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	20172F	\N	\N
3392	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21066J	\N	\N
3393	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	11064N	\N	\N
3400	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	14331P	\N	\N
3401	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21068L	\N	\N
3402	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21069M	\N	\N
3403	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	01034P	\N	\N
3404	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21070E	\N	\N
3405	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21071F	\N	\N
3406	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19111A	\N	\N
3407	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	11085T	\N	\N
3408	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	11045K	\N	\N
3409	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19591F	\N	\N
3430	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19697Q	\N	\N
3442	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19335Q	\N	\N
3443	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19954N	\N	\N
3444	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21081H	\N	\N
3445	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21082J	\N	\N
3446	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19685L	\N	\N
3447	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	14021P	\N	\N
3448	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	18207D	\N	\N
3449	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	11040E	\N	\N
2161	CRC	N	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11040E	\N	\N
3662	UC	R	2024-03-11 00:00:00	\N	ACTIF	\N	\N	\N	\N	20036X	\N	\N
3664	NI	N	2024-03-19 00:00:00	2024-03-19 00:00:00	ANCIEN	\N	\N	\N	\N	21125C	\N	\N
3011	LREM	N	2018-07-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	08024S	\N	\N
3013	NI	N	2018-07-28 00:00:00	2018-09-02 00:00:00	ANCIEN	\N	\N	\N	\N	19766L	\N	\N
3027	RTLI	N	2018-12-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	98005N	\N	\N
3041	UMP	N	2017-10-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	07033P	\N	\N
3042	SOC	N	2017-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	08045X	\N	\N
3043	UMP	N	2017-10-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	04018C	\N	\N
3053	LREM	A	2019-07-04 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19812Y	\N	\N
3063	RDSE	N	2020-03-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	19866P	\N	\N
3065	SOC	N	2020-06-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19912C	\N	\N
3068	NI	N	2020-06-25 00:00:00	2020-06-25 00:00:00	ANCIEN	\N	\N	\N	\N	19920C	\N	\N
3268	NI	N	2020-12-01 00:00:00	2020-12-01 00:00:00	ANCIEN	\N	\N	\N	\N	20176K	\N	\N
3269	NI	N	2020-12-02 00:00:00	2020-12-03 00:00:00	ANCIEN	\N	\N	\N	\N	20178M	\N	\N
3293	UC	N	2021-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20286Q	\N	\N
3276	NI	N	2021-07-06 00:00:00	2021-07-14 00:00:00	ANCIEN	\N	\N	\N	\N	20248J	\N	\N
3298	LREM	N	2022-06-21 00:00:00	\N	ACTIF	\N	\N	\N	\N	14037X	\N	\N
3301	RTLI	N	2022-07-12 00:00:00	\N	ACTIF	\N	\N	\N	\N	14211G	\N	\N
3312	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19631V	\N	\N
3313	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19629C	\N	\N
3314	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19866P	\N	\N
3323	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19713W	\N	\N
3325	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	11072N	\N	\N
3326	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19331L	\N	\N
3436	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19295A	\N	\N
3438	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	11043H	\N	\N
3439	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19679N	\N	\N
3440	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21080G	\N	\N
3441	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19349W	\N	\N
3475	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21096Q	\N	\N
3476	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	12016W	\N	\N
3014	NI	N	2018-08-07 00:00:00	2018-08-08 00:00:00	ANCIEN	\N	\N	\N	\N	19768N	\N	\N
3081	UMP	N	2020-08-03 00:00:00	2021-07-05 00:00:00	ANCIEN	\N	\N	\N	\N	19966S	\N	\N
3058	UC	N	2019-10-02 00:00:00	\N	ACTIF	\N	\N	\N	\N	19826F	\N	\N
3077	NI	N	2020-08-03 00:00:00	2020-08-05 00:00:00	ANCIEN	\N	\N	\N	\N	19958S	\N	\N
3084	RDSE	N	2020-08-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	19958S	\N	\N
3088	LREM	N	2020-08-08 00:00:00	\N	ACTIF	\N	\N	\N	\N	19782L	\N	\N
3086	NI	N	2020-08-07 00:00:00	2020-08-07 00:00:00	ANCIEN	\N	\N	\N	\N	08016S	\N	\N
3107	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20046A	\N	\N
3089	AUCUN	N	2020-09-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	\N	20014R	\N	\N
3102	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20038A	\N	\N
3110	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20052X	\N	\N
3112	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20056C	\N	\N
3114	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20060X	\N	\N
3115	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20062A	\N	\N
3116	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	17229F	\N	\N
3118	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20066E	\N	\N
3130	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20088L	\N	\N
3131	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20090E	\N	\N
3132	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20092G	\N	\N
3141	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	17737W	\N	\N
3142	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20108W	\N	\N
3143	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20110Q	\N	\N
3144	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20112S	\N	\N
3145	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	12028B	\N	\N
3150	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20120S	\N	\N
3155	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20130U	\N	\N
3156	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	17367Q	\N	\N
3157	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20132W	\N	\N
3158	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20134Y	\N	\N
3163	AUCUN	N	2020-10-01 00:00:00	2020-10-04 00:00:00	ANCIEN	\N	\N	\N	\N	20144B	\N	\N
2265	SOC	N	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11067R	\N	\N
3265	UMP	N	2020-11-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	20172F	\N	\N
1863	UMP	A	2007-07-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	04071H	\N	2017-10-03 00:00:00
3324	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21032X	\N	\N
3316	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	17779H	\N	\N
3317	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19489J	\N	\N
3318	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	14042U	\N	\N
3322	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	07004J	\N	\N
3342	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21042A	\N	\N
3343	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	18083K	\N	\N
3348	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19383Y	\N	\N
3349	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19387D	\N	\N
3350	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21045D	\N	\N
3394	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19760E	\N	\N
3395	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19681G	\N	\N
3396	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	21067K	\N	\N
3397	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19413M	\N	\N
3398	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	20286Q	\N	\N
3399	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	11056N	\N	\N
3431	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	86034E	\N	\N
3432	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	11090Q	\N	\N
2135	UMP	N	2011-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	\N	11090Q	\N	\N
3433	AUCUN	N	2023-10-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	\N	19701S	\N	\N
3607	RTLI	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21046E	\N	\N
3608	RTLI	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21052C	\N	\N
3609	RTLI	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19545Y	\N	\N
3610	RTLI	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21065H	\N	\N
3611	RTLI	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19693L	\N	\N
3612	RTLI	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	11064N	\N	\N
3613	RTLI	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21087P	\N	\N
3614	RTLI	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21054E	\N	\N
3615	RTLI	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21070E	\N	\N
3616	RTLI	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21076L	\N	\N
3617	RTLI	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19585H	\N	\N
3618	GEST	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21048G	\N	\N
3619	GEST	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	11065P	\N	\N
3620	GEST	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19347U	\N	\N
3621	GEST	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21092L	\N	\N
3622	GEST	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21093M	\N	\N
3623	GEST	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21073H	\N	\N
3624	GEST	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21037D	\N	\N
3625	GEST	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21094N	\N	\N
3626	GEST	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21079P	\N	\N
3627	RDSE	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19629C	\N	\N
3628	RDSE	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21041Y	\N	\N
3629	RDSE	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21032X	\N	\N
3630	RDSE	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19387D	\N	\N
3631	RDSE	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21066J	\N	\N
3632	RDSE	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19553Y	\N	\N
3633	RDSE	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21078N	\N	\N
3634	RDSE	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21040X	\N	\N
3635	RDSE	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19866P	\N	\N
3636	LREM	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21043B	\N	\N
3637	LREM	A	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21096Q	\N	\N
3638	LREM	A	2023-10-03 00:00:00	2029-11-27 00:00:00	ACTIF	\N	\N	\N	\N	21033Y	\N	\N
3639	LREM	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19591F	\N	\N
3640	LREM	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19697Q	\N	\N
3641	LREM	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	11072N	\N	\N
3642	LREM	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	21097R	\N	\N
3643	LREM	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19331L	\N	\N
3644	LREM	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19349W	\N	\N
3645	LREM	N	2023-10-03 00:00:00	\N	ACTIF	\N	\N	\N	\N	19301E	\N	\N
\.


--
-- Data for Name: memgrpsen; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY memgrpsen (memgrpsenid, orgcod, memgrpsendatent, memgrpsendatsor, temvalcod, evelic, evelib, evelil, senmat, syscredat, sysmajdat) FROM stdin;
2658	577	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	93003P	\N	\N
2659	577	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
2660	646	1999-01-01 00:00:00	2001-10-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
2661	646	1999-01-01 00:00:00	2001-10-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
2662	646	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
2663	646	1999-01-01 00:00:00	2001-10-30 00:00:00	ANCIEN	\N	\N	\N	95036H	\N	\N
2664	646	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	81011A	\N	\N
2665	646	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	97006K	\N	\N
2666	646	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98051U	\N	\N
2667	646	1999-01-01 00:00:00	2001-10-30 00:00:00	ANCIEN	\N	\N	\N	95053J	\N	\N
2572	621	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92006N	\N	\N
2573	621	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	98020M	\N	\N
2574	621	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
2575	621	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78007E	\N	\N
2576	621	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98016R	\N	\N
2577	621	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
2578	621	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
2579	621	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86018E	\N	\N
2580	621	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74019R	\N	\N
2581	621	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	77017C	\N	\N
2582	621	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86004X	\N	\N
2584	621	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
2585	621	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95029J	\N	\N
2586	621	1999-01-01 00:00:00	2002-07-17 00:00:00	ANCIEN	\N	\N	\N	95031C	\N	\N
2588	621	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
2589	621	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	96005E	\N	\N
2591	621	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89029V	\N	\N
2596	621	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
2599	621	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92032Q	\N	\N
2601	621	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	77044F	\N	\N
2603	621	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
2605	621	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	95051G	\N	\N
2607	621	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
2609	621	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
2611	621	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
2613	621	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	89042S	\N	\N
2524	604	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
2526	642	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
2527	604	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98020M	\N	\N
2529	590	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98022P	\N	\N
2531	573	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98023Q	\N	\N
2533	604	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98026T	\N	\N
2535	595	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98029W	\N	\N
2537	595	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98031Q	\N	\N
2539	534	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
2541	584	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
2543	574	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98033S	\N	\N
2545	590	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98033S	\N	\N
2547	642	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98033S	\N	\N
2549	620	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
2551	573	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98039Y	\N	\N
2553	598	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98039Y	\N	\N
2555	590	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
2556	590	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98046X	\N	\N
2557	620	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98046X	\N	\N
2559	590	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98048A	\N	\N
2561	604	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98048A	\N	\N
2563	590	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98049B	\N	\N
2565	642	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98049B	\N	\N
2567	573	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98051U	\N	\N
2569	556	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98053W	\N	\N
2571	642	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98053W	\N	\N
2520	584	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
2521	590	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
2522	595	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
2440	580	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
2441	590	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
2442	573	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	97006K	\N	\N
2443	575	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	97006K	\N	\N
2444	578	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	97006K	\N	\N
2445	584	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	97006K	\N	\N
2446	622	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	97006K	\N	\N
2447	642	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	97006K	\N	\N
2448	591	1998-10-01 00:00:00	2002-01-19 00:00:00	ANCIEN	\N	\N	\N	97007L	\N	\N
2449	598	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	97008M	\N	\N
2131	580	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95014B	\N	\N
2450	604	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	97008M	\N	\N
2451	624	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	97008M	\N	\N
2453	582	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
2454	602	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
2455	626	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
2457	532	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98002K	\N	\N
2459	556	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98002K	\N	\N
2461	590	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98002K	\N	\N
2463	598	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98002K	\N	\N
2464	663	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98002K	\N	\N
2466	574	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98003L	\N	\N
16335	908	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	2014-09-28 12:09:44
2469	620	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98006P	\N	\N
2471	578	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98007Q	\N	\N
2473	598	1998-10-01 00:00:00	2005-03-19 00:00:00	ANCIEN	\N	\N	\N	98008R	\N	\N
2475	620	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98009S	\N	\N
2477	590	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
2479	556	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
2480	573	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
2482	578	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
2484	642	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
2485	663	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
2487	584	1998-10-01 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	98012M	\N	\N
2489	620	1998-10-01 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	98012M	\N	\N
2491	595	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98013N	\N	\N
2493	642	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98013N	\N	\N
2496	584	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
2498	595	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
2500	620	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
2502	575	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98016R	\N	\N
2504	598	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98016R	\N	\N
2506	574	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98017S	\N	\N
2508	532	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
2510	574	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
2511	595	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
2513	604	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
2515	556	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
2517	574	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
2519	578	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
2435	584	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
2436	595	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
2437	598	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
2438	642	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
2355	590	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
2356	598	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
2357	600	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89016Q	\N	\N
2358	604	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
2359	608	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
2360	611	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
2361	617	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
2362	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
2363	619	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
2364	620	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
2365	624	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
2366	626	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
2367	642	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
2369	646	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
2371	851	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
2373	574	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95058P	\N	\N
2375	579	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95058P	\N	\N
2376	584	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95058P	\N	\N
2377	587	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95058P	\N	\N
2378	589	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95058P	\N	\N
2381	602	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95058P	\N	\N
2382	604	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95058P	\N	\N
2383	605	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95058P	\N	\N
2384	608	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95058P	\N	\N
2385	611	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95058P	\N	\N
2386	617	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95058P	\N	\N
2388	624	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95058P	\N	\N
2389	625	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95058P	\N	\N
2390	626	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95058P	\N	\N
2391	642	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95058P	\N	\N
2392	644	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95058P	\N	\N
2394	851	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95058P	\N	\N
2397	590	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95061J	\N	\N
2399	574	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
2730	530	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98002K	\N	\N
2731	530	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
2732	530	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
2733	530	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89042S	\N	\N
2738	600	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98026T	\N	\N
2736	530	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	74011H	\N	\N
2737	600	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
2741	600	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
2740	532	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
2742	600	1999-01-01 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	98012M	\N	\N
2743	600	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92030N	\N	\N
2744	585	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	74011H	\N	\N
2745	585	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78007E	\N	\N
2746	585	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
2747	585	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74019R	\N	\N
2748	585	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92019T	\N	\N
2749	585	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	97008M	\N	\N
2750	585	1999-01-01 00:00:00	2009-09-09 00:00:00	ANCIEN	\N	\N	\N	80024B	\N	\N
2751	585	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95051G	\N	\N
2752	585	1999-01-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
2753	585	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
2754	585	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95058P	\N	\N
2755	585	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98033S	\N	\N
2756	585	1999-01-01 00:00:00	1999-11-30 00:00:00	ANCIEN	\N	\N	\N	77066M	\N	\N
2757	585	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
2759	572	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
2760	572	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
2761	572	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	84003N	\N	\N
2762	572	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	74011H	\N	\N
2763	572	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78007E	\N	\N
2231	577	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	\N
2232	580	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	\N
2233	582	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	\N
2235	586	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	\N
2236	600	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98047Y	\N	\N
2237	604	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	\N
2238	605	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	\N
2239	608	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	\N
2240	609	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	\N
2242	612	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	\N
2243	613	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	\N
2245	626	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	\N
2247	642	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	\N
2248	851	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	\N
2250	602	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95035G	\N	\N
2251	604	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95035G	\N	\N
2252	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95035G	\N	\N
2254	583	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95036H	\N	\N
2256	604	1998-10-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	95036H	\N	\N
2257	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95036H	\N	\N
2258	619	1999-01-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	95036H	\N	\N
2260	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95039L	\N	\N
2262	579	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95039L	\N	\N
2264	590	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95039L	\N	\N
2266	604	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95039L	\N	\N
2184	578	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95025E	\N	\N
2185	602	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95025E	\N	\N
2186	604	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95025E	\N	\N
2103	620	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
2104	624	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
2106	627	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
2107	640	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
2110	663	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
2111	574	1998-10-01 00:00:00	1999-09-30 00:00:00	ANCIEN	\N	\N	\N	95008D	\N	\N
2112	576	1999-01-01 00:00:00	1999-11-30 00:00:00	ANCIEN	\N	\N	\N	95008D	\N	\N
2113	578	1998-10-01 00:00:00	1999-11-30 00:00:00	ANCIEN	\N	\N	\N	95008D	\N	\N
2114	590	1998-10-01 00:00:00	1999-09-30 00:00:00	ANCIEN	\N	\N	\N	95008D	\N	\N
2116	604	1998-10-01 00:00:00	1999-09-30 00:00:00	ANCIEN	\N	\N	\N	95008D	\N	\N
2118	534	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	\N
2119	583	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	\N
2120	598	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	\N
2121	617	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	\N
2122	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	\N
2126	602	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95013A	\N	\N
2127	617	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	95013A	\N	\N
2128	626	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95013A	\N	\N
2129	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95014B	\N	\N
2688	609	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
2689	609	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	98033S	\N	\N
2690	609	1999-01-01 00:00:00	2000-03-18 00:00:00	ANCIEN	\N	\N	\N	88003F	\N	\N
2691	609	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83054V	\N	\N
2692	609	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	92045V	\N	\N
2693	609	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
2694	609	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	80041C	\N	\N
2695	599	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	94004U	\N	\N
2697	599	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	74011H	\N	\N
2698	599	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
2700	599	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
2703	599	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
2704	599	1999-01-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	98031Q	\N	\N
2705	599	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
2706	599	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
2707	599	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	81011A	\N	\N
2708	599	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
2709	599	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	68036E	\N	\N
2710	599	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
2711	599	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80040B	\N	\N
2712	599	1999-01-01 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	80048K	\N	\N
2713	599	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
2715	530	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
2716	600	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
2718	600	1999-01-01 00:00:00	1999-09-30 00:00:00	ANCIEN	\N	\N	\N	95008D	\N	\N
2719	600	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
2720	600	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
2721	600	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95002W	\N	\N
2061	574	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95004Y	\N	\N
2062	575	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95004Y	\N	\N
2064	583	1998-09-30 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95004Y	\N	\N
2065	589	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95004Y	\N	\N
2067	598	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95004Y	\N	\N
2069	602	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95004Y	\N	\N
2071	605	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95004Y	\N	\N
2072	608	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95004Y	\N	\N
2074	617	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95004Y	\N	\N
2075	620	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95004Y	\N	\N
2076	624	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95004Y	\N	\N
2078	626	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95004Y	\N	\N
2081	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95005A	\N	\N
2082	532	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
2084	556	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
2087	577	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
2088	578	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
2089	579	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
2091	584	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
2092	588	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
2094	598	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
2095	600	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
2096	602	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
2098	605	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
2016	640	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92045V	\N	\N
2017	598	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	93005R	\N	\N
2018	575	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	93006S	\N	\N
1935	532	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
1936	556	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
1937	571	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
1938	573	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
1939	574	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
1940	576	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
1941	579	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
1942	583	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
1944	588	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
1945	590	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
1947	598	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
1948	600	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
1949	602	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
1951	609	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
1952	611	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
1954	613	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
1956	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
1957	642	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
1959	646	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
1961	532	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
1962	579	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
1964	600	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
1965	602	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
1966	608	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
1969	625	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
1970	644	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
1973	604	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92036U	\N	\N
1976	556	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
1977	571	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
1979	574	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
1981	584	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
1982	585	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
1984	598	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
1985	605	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
1986	608	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
1987	609	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
1989	626	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
1992	532	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
1993	576	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
1995	604	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
1996	611	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
1997	613	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
1999	624	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
2000	627	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
2003	663	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92042S	\N	\N
2004	590	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92043T	\N	\N
2005	617	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92043T	\N	\N
2006	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92043T	\N	\N
2009	589	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92045V	\N	\N
2010	590	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92045V	\N	\N
2014	608	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92045V	\N	\N
2015	625	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92045V	\N	\N
1932	584	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92033R	\N	\N
1933	598	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92033R	\N	\N
1934	663	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92033R	\N	\N
1851	605	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92021M	\N	\N
1852	609	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92021M	\N	\N
1853	619	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92021M	\N	\N
1854	625	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92021M	\N	\N
1856	640	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92021M	\N	\N
1857	642	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92021M	\N	\N
1859	576	1999-01-01 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	92022N	\N	\N
1860	579	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92022N	\N	\N
1861	580	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92022N	\N	\N
1862	598	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92022N	\N	\N
1863	604	1998-10-01 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	92022N	\N	\N
1864	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92022N	\N	\N
1867	575	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92024Q	\N	\N
1868	584	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92024Q	\N	\N
1869	598	1998-10-01 00:00:00	2007-02-25 00:00:00	ANCIEN	\N	\N	\N	92024Q	\N	\N
1870	612	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92024Q	\N	\N
1871	617	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92024Q	\N	\N
1872	620	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92024Q	\N	\N
1873	624	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92024Q	\N	\N
1874	626	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92024Q	\N	\N
1875	627	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92024Q	\N	\N
1878	646	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92024Q	\N	\N
1881	640	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92025R	\N	\N
1883	598	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92026S	\N	\N
1886	573	1998-10-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	92029V	\N	\N
1888	580	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92029V	\N	\N
1889	625	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92029V	\N	\N
1891	574	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92030N	\N	\N
1893	604	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92030N	\N	\N
1894	609	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92030N	\N	\N
1896	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92030N	\N	\N
1898	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92030N	\N	\N
1901	530	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
1903	556	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
1906	576	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
1907	577	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
1908	580	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
1909	582	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
1910	583	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
1911	588	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
1913	598	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
1914	600	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
1915	602	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
1916	605	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
1917	608	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
1920	617	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
1921	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
1923	626	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
1924	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
1925	642	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
1927	644	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
1928	646	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
1931	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92032Q	\N	\N
1847	583	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92021M	\N	\N
1848	584	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92021M	\N	\N
1849	590	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92021M	\N	\N
1850	598	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92021M	\N	\N
1767	584	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	91002E	\N	\N
1768	595	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	91002E	\N	\N
1770	600	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	91002E	\N	\N
1771	604	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	91002E	\N	\N
1772	611	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	91002E	\N	\N
1773	613	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	91002E	\N	\N
1774	619	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	91002E	\N	\N
2764	572	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	\N
2765	572	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	74015M	\N	\N
2766	572	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
2767	572	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98029W	\N	\N
2768	572	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98023Q	\N	\N
2769	572	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74019R	\N	\N
2770	572	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77017C	\N	\N
2771	572	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
2772	572	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
2773	572	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83028T	\N	\N
2774	572	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
2775	572	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83031N	\N	\N
2776	572	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
2777	572	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	96005E	\N	\N
2778	572	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	\N
2779	572	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
2780	572	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95002W	\N	\N
2781	572	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	81011A	\N	\N
2783	572	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	97006K	\N	\N
2784	572	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
2785	572	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98051U	\N	\N
2786	572	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
2787	572	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
2788	572	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
2789	572	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
2790	572	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
2668	646	1999-01-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
2669	646	1999-01-01 00:00:00	2001-10-30 00:00:00	ANCIEN	\N	\N	\N	98033S	\N	\N
2670	646	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
2671	609	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
2672	609	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78007E	\N	\N
2673	609	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
2674	609	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98023Q	\N	\N
2675	609	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74019R	\N	\N
2676	609	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
2677	609	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
2678	609	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
2679	609	1999-01-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	83037U	\N	\N
2680	609	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	83039W	\N	\N
2681	609	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95002W	\N	\N
2682	609	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	97006K	\N	\N
2683	609	1999-01-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	95051G	\N	\N
2684	609	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
2685	609	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	83047W	\N	\N
2686	609	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
2687	609	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
2722	530	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83035S	\N	\N
2723	530	1999-01-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	83037U	\N	\N
2724	530	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95040D	\N	\N
2726	530	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95002W	\N	\N
2727	530	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
2728	530	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
2729	530	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83046V	\N	\N
2590	621	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83003J	\N	\N
2592	621	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
2595	621	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83036T	\N	\N
2597	621	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
2598	621	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	85003S	\N	\N
2600	621	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86037H	\N	\N
2602	621	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83043S	\N	\N
2604	621	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	98008R	\N	\N
2606	621	1999-01-01 00:00:00	2001-10-10 00:00:00	ANCIEN	\N	\N	\N	74032N	\N	\N
2608	621	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
2610	621	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	95058P	\N	\N
2612	621	1999-01-01 00:00:00	2001-09-20 00:00:00	ANCIEN	\N	\N	\N	94002S	\N	\N
2614	621	1999-01-01 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	80048K	\N	\N
2615	621	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
2627	640	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92006N	\N	\N
2628	640	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
2629	640	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	74011H	\N	\N
2630	640	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	96004D	\N	2015-02-02 16:43:25
2631	640	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95015C	\N	\N
2632	640	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98031Q	\N	\N
2633	640	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77019E	\N	\N
2634	640	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98047Y	\N	\N
2635	640	1999-01-01 00:00:00	2001-02-07 00:00:00	ANCIEN	\N	\N	\N	74024N	\N	\N
2636	640	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
2637	640	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98038X	\N	\N
2638	640	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80024B	\N	\N
2639	640	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77044F	\N	\N
2640	640	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
2641	640	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95003X	\N	\N
2642	640	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98007Q	\N	\N
2643	640	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83047W	\N	\N
2644	640	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83050R	\N	\N
2645	640	1999-01-01 00:00:00	1999-11-30 00:00:00	ANCIEN	\N	\N	\N	77066M	\N	\N
2646	640	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83054V	\N	\N
2647	640	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
2648	577	1999-01-01 00:00:00	1999-09-30 00:00:00	ANCIEN	\N	\N	\N	95008D	\N	\N
2649	577	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	74011H	\N	\N
2650	577	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74019R	\N	\N
2651	577	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
2652	577	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98003L	\N	\N
2653	577	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
2654	577	1999-01-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	98043U	\N	\N
2655	577	1999-01-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	95051G	\N	\N
2656	577	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95058P	\N	\N
2657	577	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98039Y	\N	\N
1014	608	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	84003N	\N	\N
1015	612	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	84003N	\N	\N
1016	617	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	84003N	\N	\N
1017	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	84003N	\N	\N
1018	624	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	84003N	\N	\N
1019	626	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	84003N	\N	\N
1020	646	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	84003N	\N	\N
1021	530	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
1022	534	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
1024	571	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
1025	574	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
1026	576	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
1028	590	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
1030	604	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
1031	608	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
1032	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
1035	646	1999-01-01 00:00:00	2001-10-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
1037	663	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
1040	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
1042	574	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
1044	576	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
1045	577	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
1046	579	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
1048	582	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
1049	583	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
1051	585	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
1052	587	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
1053	589	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
1054	590	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
1055	595	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
1057	600	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
1058	602	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
1059	604	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
1060	605	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
1061	608	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
1063	611	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
1064	612	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
1069	642	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
2132	583	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95014B	\N	\N
2133	604	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95014B	\N	\N
2134	609	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95014B	\N	\N
2137	534	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95015C	\N	\N
2138	576	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95015C	\N	\N
2140	583	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95015C	\N	\N
2142	575	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95016D	\N	\N
2144	598	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95016D	\N	\N
2146	595	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95017E	\N	\N
2147	611	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95017E	\N	\N
2148	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95017E	\N	\N
2151	626	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95018F	\N	\N
2152	576	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95019G	\N	\N
2153	590	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95019G	\N	\N
2154	583	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95020Y	\N	\N
2157	598	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95020Y	\N	\N
2158	611	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95020Y	\N	\N
2159	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95020Y	\N	\N
2163	574	1998-10-01 00:00:00	2001-03-27 00:00:00	ANCIEN	\N	\N	\N	95022B	\N	\N
2165	584	1998-10-01 00:00:00	2001-03-27 00:00:00	ANCIEN	\N	\N	\N	95022B	\N	\N
2167	595	1998-10-01 00:00:00	2001-03-27 00:00:00	ANCIEN	\N	\N	\N	95022B	\N	\N
2169	609	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95022B	\N	\N
2170	617	1999-01-01 00:00:00	2001-03-27 00:00:00	ANCIEN	\N	\N	\N	95022B	\N	\N
2171	620	1998-10-01 00:00:00	2001-03-27 00:00:00	ANCIEN	\N	\N	\N	95022B	\N	\N
2175	573	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95023C	\N	\N
1553	612	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
1554	613	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
1555	617	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
1557	619	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
1558	620	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
1559	624	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
1560	625	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
1561	626	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
1562	627	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
1563	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
1567	646	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
1568	659	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
1571	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89024Q	\N	\N
1574	663	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89024Q	\N	\N
1576	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89026S	\N	\N
1577	571	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89026S	\N	\N
1579	574	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89026S	\N	\N
1580	576	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89026S	\N	\N
1583	579	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89026S	\N	\N
1584	580	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89026S	\N	\N
1585	582	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89026S	\N	\N
1588	589	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89026S	\N	\N
1589	590	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89026S	\N	\N
1592	602	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89026S	\N	\N
1593	604	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89026S	\N	\N
1595	609	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89026S	\N	\N
1513	611	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89020L	\N	\N
1514	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89021M	\N	\N
1515	575	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89021M	\N	\N
1516	584	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89021M	\N	\N
1433	626	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
1434	640	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
1436	530	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89008Q	\N	\N
1437	571	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89008Q	\N	\N
1438	575	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89008Q	\N	\N
1439	585	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89008Q	\N	\N
1440	598	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89008Q	\N	\N
1441	611	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89008Q	\N	\N
1442	620	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89008Q	\N	\N
1443	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89008Q	\N	\N
1444	642	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89008Q	\N	\N
1446	530	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89009R	\N	\N
1449	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89009R	\N	\N
1450	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89010J	\N	\N
1452	584	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89010J	\N	\N
1455	604	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89012L	\N	\N
1456	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89012L	\N	\N
1457	619	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89012L	\N	\N
1458	576	2004-09-30 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89013M	\N	\N
1459	642	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89013M	\N	\N
1460	576	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
1461	583	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
1462	589	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
1464	611	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
1465	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
1466	619	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
678	598	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	81007E	\N	\N
1467	642	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
1471	573	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
1473	576	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
1474	578	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
1476	587	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
1477	590	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
1479	602	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
1480	605	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
1481	609	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
906	580	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83036T	\N	\N
907	590	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83036T	\N	\N
908	598	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83036T	\N	\N
911	609	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83036T	\N	\N
912	612	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83036T	\N	\N
914	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83036T	\N	\N
916	576	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83037U	\N	\N
917	590	1998-10-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	83037U	\N	\N
919	598	1998-10-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	83037U	\N	\N
921	605	1999-01-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	83037U	\N	\N
924	625	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83037U	\N	\N
841	578	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83025Q	\N	\N
842	590	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83025Q	\N	\N
844	571	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83026R	\N	\N
761	626	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83016P	\N	\N
762	585	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83017Q	\N	\N
763	626	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83017Q	\N	\N
764	640	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83017Q	\N	\N
765	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83017Q	\N	\N
766	530	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83018R	\N	\N
767	532	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83018R	\N	\N
768	534	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83018R	\N	\N
769	556	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83018R	\N	\N
770	571	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83018R	\N	\N
771	576	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83018R	\N	\N
772	579	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83018R	\N	\N
775	598	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83018R	\N	\N
776	600	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83018R	\N	\N
777	605	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83018R	\N	\N
778	611	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83018R	\N	\N
779	613	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83018R	\N	\N
780	617	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83018R	\N	\N
782	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83018R	\N	\N
783	851	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83018R	\N	\N
786	573	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83020K	\N	\N
787	579	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83020K	\N	\N
788	590	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83020K	\N	\N
790	605	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83020K	\N	\N
791	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
793	574	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
795	576	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
797	578	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
798	583	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
799	585	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
800	587	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
801	588	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
802	589	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
804	595	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
806	602	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
807	604	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
808	608	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
809	611	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
811	617	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
812	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
816	627	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
817	640	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
819	642	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
821	644	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
822	646	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
827	574	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83023N	\N	\N
828	576	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83023N	\N	\N
829	579	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83023N	\N	\N
830	580	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83023N	\N	\N
831	583	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83023N	\N	\N
833	595	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83023N	\N	\N
835	600	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
836	605	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83023N	\N	\N
839	620	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83023N	\N	\N
758	598	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83016P	\N	\N
759	604	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83016P	\N	\N
760	620	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83016P	\N	\N
679	604	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	81007E	\N	\N
680	611	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	81007E	\N	\N
681	619	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	81007E	\N	\N
682	624	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	81007E	\N	\N
683	644	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	81007E	\N	\N
685	575	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	81010Y	\N	\N
686	582	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	81010Y	\N	\N
687	584	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	81010Y	\N	\N
688	585	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	81010Y	\N	\N
689	587	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	81010Y	\N	\N
690	589	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	81010Y	\N	\N
692	611	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	81010Y	\N	\N
693	613	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	81010Y	\N	\N
694	619	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77012W	\N	\N
696	626	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	81010Y	\N	\N
697	627	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	81010Y	\N	\N
698	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	81010Y	\N	\N
699	642	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	81010Y	\N	\N
700	576	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	81011A	\N	\N
701	579	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	81011A	\N	\N
702	580	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	81011A	\N	\N
703	583	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	81011A	\N	\N
705	590	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	81011A	\N	\N
706	602	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	81011A	\N	\N
708	605	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	81011A	\N	\N
710	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	81011A	\N	\N
711	619	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	81011A	\N	\N
712	626	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	81011A	\N	\N
713	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	81014D	\N	\N
715	625	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	81014D	\N	\N
717	587	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	82002D	\N	\N
718	590	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	82002D	\N	\N
722	640	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	82002D	\N	\N
723	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	82002D	\N	\N
724	663	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	82002D	\N	\N
726	598	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83004K	\N	\N
729	608	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83004K	\N	\N
730	626	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83004K	\N	\N
731	587	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83008P	\N	\N
733	598	1998-10-01 00:00:00	2001-03-02 00:00:00	ANCIEN	\N	\N	\N	83008P	\N	\N
735	575	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83010H	\N	\N
738	576	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83011J	\N	\N
739	580	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83011J	\N	\N
740	590	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83011J	\N	\N
742	604	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83011J	\N	\N
745	609	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83012K	\N	\N
746	611	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83012K	\N	\N
747	620	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83012K	\N	\N
749	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83012K	\N	\N
751	532	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83016P	\N	\N
752	576	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83016P	\N	\N
753	579	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83016P	\N	\N
755	589	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83016P	\N	\N
756	590	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83016P	\N	\N
674	611	1999-01-01 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	80048K	\N	\N
675	574	0098-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	81007E	\N	\N
676	579	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	81007E	\N	\N
677	589	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	81007E	\N	\N
594	584	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80036F	\N	\N
595	586	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80036F	\N	\N
596	587	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80036F	\N	\N
597	602	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80036F	\N	\N
598	608	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80036F	\N	\N
599	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80036F	\N	\N
600	626	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80036F	\N	\N
601	627	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80036F	\N	\N
603	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80039J	\N	\N
604	573	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80039J	\N	\N
605	584	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80039J	\N	\N
606	585	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80039J	\N	\N
607	595	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80039J	\N	\N
609	612	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80039J	\N	\N
610	642	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80039J	\N	\N
612	646	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80039J	\N	\N
614	576	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80040B	\N	\N
615	584	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80040B	\N	\N
616	585	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80040B	\N	\N
619	644	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80040B	\N	\N
620	646	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80040B	\N	\N
621	583	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80041C	\N	\N
622	584	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80041C	\N	\N
623	590	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80041C	\N	\N
624	598	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80041C	\N	\N
626	602	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80041C	\N	\N
627	612	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80041C	\N	\N
629	627	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80041C	\N	\N
630	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80041C	\N	\N
632	642	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80043E	\N	\N
634	573	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80045G	\N	\N
636	578	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80045G	\N	\N
638	587	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80045G	\N	\N
640	598	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80045G	\N	\N
641	626	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80045G	\N	\N
642	642	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80045G	\N	\N
643	646	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80045G	\N	\N
645	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80046H	\N	\N
647	576	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80046H	\N	\N
648	582	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80046H	\N	\N
650	590	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80046H	\N	\N
653	608	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80046H	\N	\N
655	612	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80046H	\N	\N
656	620	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80046H	\N	\N
657	624	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80046H	\N	\N
658	625	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80046H	\N	\N
659	626	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80046H	\N	\N
660	627	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80046H	\N	\N
664	530	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80048K	\N	\N
666	575	1998-10-01 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	80048K	\N	\N
667	579	1999-01-01 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	80048K	\N	\N
668	589	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80048K	\N	\N
670	591	1998-10-01 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	80048K	\N	\N
671	600	1999-01-01 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	80048K	\N	\N
673	608	1999-01-01 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	80048K	\N	\N
590	572	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80036F	\N	\N
591	574	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80036F	\N	\N
592	575	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80036F	\N	\N
593	578	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80036F	\N	\N
510	627	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80025C	\N	\N
511	640	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80025C	\N	\N
513	575	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80026D	\N	\N
514	580	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80026D	\N	\N
515	583	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80026D	\N	\N
516	608	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80026D	\N	\N
517	619	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80026D	\N	\N
518	625	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80026D	\N	\N
519	574	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
1775	624	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	91002E	\N	\N
1778	580	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
1779	595	1998-10-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
1780	602	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
1782	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
1783	619	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
1785	663	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
1786	556	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92006N	\N	\N
1788	574	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92006N	\N	\N
1789	576	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92006N	\N	\N
1790	583	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92006N	\N	\N
1792	587	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92006N	\N	\N
1793	588	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92006N	\N	\N
1794	589	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92006N	\N	\N
1795	590	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92006N	\N	\N
1797	595	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92006N	\N	\N
1799	602	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92006N	\N	\N
1800	604	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92006N	\N	\N
1801	608	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92006N	\N	\N
1803	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92006N	\N	\N
1806	663	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92006N	\N	\N
1808	575	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92008Q	\N	\N
1810	595	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92009R	\N	\N
1811	613	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92009R	\N	\N
1812	619	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92009R	\N	\N
1813	626	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92009R	\N	\N
1818	620	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92010J	\N	\N
1819	624	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92010J	\N	\N
1821	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92011K	\N	\N
1822	663	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92011K	\N	\N
1824	583	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	92012L	\N	\N
1826	576	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92013M	\N	\N
1827	604	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92013M	\N	\N
1828	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92013M	\N	\N
1830	575	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92015P	\N	\N
1832	598	1998-10-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	92017R	\N	\N
1833	600	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	92017R	\N	\N
1834	624	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92017R	\N	\N
1836	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92017R	\N	\N
1838	583	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92019T	\N	\N
1839	534	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92020L	\N	\N
1841	851	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92020L	\N	\N
1843	573	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92021M	\N	\N
1845	576	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92021M	\N	\N
1846	577	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92021M	\N	\N
1764	556	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	91002E	\N	\N
1765	579	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	91002E	\N	\N
1766	583	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	91002E	\N	\N
1683	595	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89043T	\N	\N
1684	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89043T	\N	\N
1685	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89044U	\N	\N
1686	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89044U	\N	\N
1687	646	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89044U	\N	\N
1688	530	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89045V	\N	\N
1689	582	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89045V	\N	\N
1690	590	1998-10-01 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	89045V	\N	\N
1691	598	1998-10-01 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	89045V	\N	\N
1692	600	1999-01-01 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	89045V	\N	\N
1694	605	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89045V	\N	\N
1695	608	1999-01-01 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	89045V	\N	\N
1696	609	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89045V	\N	\N
1697	619	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89045V	\N	\N
1698	640	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89045V	\N	\N
1699	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89045V	\N	\N
2400	583	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
2402	608	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
2404	577	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95068R	\N	\N
2406	609	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95068R	\N	\N
2407	611	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95068R	\N	\N
2409	624	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95068R	\N	\N
2410	587	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	96001A	\N	\N
2411	590	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	96004D	\N	2015-02-02 16:43:48
2416	604	1998-10-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	96005E	\N	\N
2417	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	96005E	\N	\N
2420	556	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
2422	574	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
2423	576	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
2425	584	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
2429	573	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
2431	611	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
2432	642	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
2433	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	96008H	\N	\N
2351	583	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
2352	584	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
2353	586	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
2354	589	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
2271	589	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95040D	\N	\N
2272	590	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95040D	\N	\N
2273	609	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95040D	\N	\N
2274	617	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95040D	\N	\N
2275	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95040D	\N	\N
2276	626	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95040D	\N	\N
2278	590	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95042F	\N	\N
2279	626	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95042F	\N	\N
2280	587	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95043G	\N	\N
2281	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95043G	\N	\N
2282	602	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95044H	\N	\N
2283	642	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95044H	\N	\N
2284	644	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95044H	\N	\N
2287	604	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95045J	\N	\N
2288	613	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95045J	\N	\N
2289	642	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95045J	\N	\N
2292	587	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95046K	\N	\N
2293	642	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95046K	\N	\N
2295	576	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95047L	\N	\N
2296	578	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95047L	\N	\N
2297	583	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95047L	\N	\N
2299	642	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95047L	\N	\N
2304	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95049N	\N	\N
2305	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95050F	\N	\N
2306	583	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95050F	\N	\N
2309	584	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95051G	\N	\N
2311	595	1998-10-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	95051G	\N	\N
2313	620	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95051G	\N	\N
2314	625	1999-01-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	95051G	\N	\N
2317	556	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
2319	576	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
2320	589	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
16336	908	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11109J	\N	\N
2321	591	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
2322	611	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
2323	642	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
2325	573	1998-10-01 00:00:00	2000-02-08 00:00:00	ANCIEN	\N	\N	\N	95053J	\N	\N
2327	577	1999-01-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	95053J	\N	\N
2328	583	1999-01-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	95053J	\N	\N
2329	598	1998-10-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	95053J	\N	\N
2330	602	1999-01-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	95053J	\N	\N
2332	602	1999-01-01 00:00:00	1999-11-27 00:00:00	ANCIEN	\N	\N	\N	95054K	\N	\N
2333	626	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95054K	\N	\N
2334	575	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95055L	\N	\N
2336	608	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95055L	\N	\N
2337	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95055L	\N	\N
2341	530	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
2342	532	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
2343	556	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
2345	575	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
2346	576	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
2347	577	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
2349	579	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
2267	613	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95039L	\N	\N
2268	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95039L	\N	\N
2269	532	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95040D	\N	\N
2270	576	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95040D	\N	\N
2188	576	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95026F	\N	\N
2189	590	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95026F	\N	\N
2191	598	1998-10-01 00:00:00	2001-01-16 00:00:00	ANCIEN	\N	\N	\N	95027G	\N	\N
2193	583	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	\N
2194	600	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	\N
2196	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	\N
2197	626	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	\N
2199	583	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95029J	\N	\N
2200	590	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95029J	\N	\N
2202	608	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95030B	\N	\N
2204	625	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95030B	\N	\N
2205	640	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95030B	\N	\N
2206	556	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95031C	\N	\N
2209	579	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95031C	\N	\N
2210	583	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95031C	\N	\N
2211	589	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95031C	\N	\N
2212	590	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95031C	\N	\N
2214	598	1998-10-01 00:00:00	2002-07-17 00:00:00	ANCIEN	\N	\N	\N	95031C	\N	\N
2217	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95031C	\N	\N
2218	620	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95031C	\N	\N
2222	578	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95032D	\N	\N
2223	622	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95032D	\N	\N
2225	613	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95033E	\N	\N
2226	530	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	\N
2227	532	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	\N
2230	576	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	\N
1310	576	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
1312	579	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
1313	584	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
1314	589	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
1316	595	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
1319	602	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
1320	604	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
1321	609	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
1322	611	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
1323	619	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
1325	625	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
1327	598	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	87003B	\N	\N
1331	580	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88002E	\N	\N
1332	585	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88002E	\N	\N
1334	589	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88002E	\N	\N
1336	602	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88002E	\N	\N
1337	604	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88002E	\N	\N
1339	612	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88002E	\N	\N
1340	617	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88002E	\N	\N
1342	619	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88002E	\N	\N
1343	626	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88002E	\N	\N
1262	602	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
1263	604	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
1264	609	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
1182	626	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86039K	\N	\N
1183	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86039K	\N	\N
1184	646	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86039K	\N	\N
1185	530	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
1186	534	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
1188	576	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
1189	577	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
1190	578	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
1191	579	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
1194	590	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
1196	598	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
1198	602	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
1199	608	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
1200	617	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
1201	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
1203	626	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
1204	640	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
1205	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
1207	646	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
1209	530	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86042E	\N	\N
1211	573	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86042E	\N	\N
1213	577	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86042E	\N	\N
1214	578	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86042E	\N	\N
1216	580	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86042E	\N	\N
1218	583	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86042E	\N	\N
1219	584	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86042E	\N	\N
1220	588	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98008R	\N	\N
1223	595	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86042E	\N	\N
1224	598	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86042E	\N	\N
1226	602	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86042E	\N	\N
1228	605	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86042E	\N	\N
1229	608	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86042E	\N	\N
1230	609	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
1232	617	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86042E	\N	\N
1233	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86042E	\N	\N
1234	620	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86042E	\N	\N
1235	624	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86042E	\N	\N
1236	625	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86042E	\N	\N
1238	627	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86042E	\N	\N
1239	571	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86043F	\N	\N
1241	590	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86047K	\N	\N
1243	608	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86047K	\N	\N
1244	530	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
1245	532	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
1247	556	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
1249	574	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
1250	576	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
1251	577	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
1254	584	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
1255	587	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
1256	588	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
1258	591	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
1260	598	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
1177	587	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86039K	\N	\N
1178	589	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86039K	\N	\N
1179	598	1998-10-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	86039K	\N	\N
1180	617	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86039K	\N	\N
1097	611	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	\N
1098	619	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
1099	625	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
1100	640	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
1103	571	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	\N
1104	582	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	\N
1105	583	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	\N
1107	591	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	\N
1109	602	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	\N
1110	609	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	\N
1111	617	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	\N
1112	620	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	\N
1116	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86014A	\N	\N
1117	583	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86014A	\N	\N
1119	604	1998-10-01 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	86014A	\N	\N
1120	605	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86014A	\N	\N
1122	534	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86018E	\N	\N
1124	571	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86018E	\N	\N
1125	574	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86018E	\N	\N
1126	583	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86018E	\N	\N
1128	602	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86018E	\N	\N
1129	624	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86018E	\N	\N
1744	573	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
1746	575	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
1747	576	1998-09-30 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
1749	584	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
1750	585	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
1753	598	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
1754	602	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
1756	611	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
1758	620	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
1759	625	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
1760	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
1680	620	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89042S	\N	\N
1681	642	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89042S	\N	\N
1600	620	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89026S	\N	\N
1601	624	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89026S	\N	\N
1602	625	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89026S	\N	\N
1603	626	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89026S	\N	\N
1604	640	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89026S	\N	\N
1605	642	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89026S	\N	\N
1607	646	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89026S	\N	\N
1608	851	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89026S	\N	\N
1609	576	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89027T	\N	\N
1611	589	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89028U	\N	\N
1612	607	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89028U	\N	\N
1613	620	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89028U	\N	\N
1614	626	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89028U	\N	\N
1615	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89028U	\N	\N
1617	851	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89028U	\N	\N
1618	595	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89029V	\N	\N
1620	584	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89030N	\N	\N
1622	598	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89030N	\N	\N
1623	602	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89030N	\N	\N
1626	573	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89035T	\N	\N
1628	530	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89037V	\N	\N
1629	584	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89037V	\N	\N
1631	605	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89037V	\N	\N
1632	608	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89037V	\N	\N
1633	627	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89037V	\N	\N
1635	579	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89038W	\N	\N
1636	589	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89038W	\N	\N
1637	598	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89038W	\N	\N
1639	620	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89038W	\N	\N
1641	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89039X	\N	\N
1643	575	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89040Q	\N	\N
1644	576	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89040Q	\N	\N
1646	582	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89040Q	\N	\N
1647	583	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89040Q	\N	\N
1649	585	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89040Q	\N	\N
1651	587	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89040Q	\N	\N
1652	590	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89040Q	\N	\N
1654	595	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89040Q	\N	\N
1655	602	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89040Q	\N	\N
1656	626	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89040Q	\N	\N
1659	573	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
1660	576	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
1661	577	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
1662	579	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
1663	580	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
1665	584	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
1666	588	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
1668	600	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
1670	609	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
1671	611	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
1672	617	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
1675	626	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
1676	663	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
1677	574	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89042S	\N	\N
1679	584	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89042S	\N	\N
1596	611	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89026S	\N	\N
1597	612	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89026S	\N	\N
1598	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89026S	\N	\N
1599	619	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89026S	\N	\N
1517	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89021M	\N	\N
1518	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	\N
1519	573	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	\N
1520	574	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	\N
1521	590	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	\N
1522	598	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	\N
1523	609	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	\N
1524	613	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	\N
1525	619	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	\N
1527	646	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	\N
1529	556	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
1530	573	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
1532	575	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
1533	576	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
1534	577	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
1536	579	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
1537	580	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
1538	582	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
1539	583	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
1541	588	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
1542	589	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
1543	590	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
1545	598	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
1546	600	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
1547	602	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
1550	608	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
1551	609	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
1552	611	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
2176	576	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95023C	\N	\N
2178	584	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95023C	\N	\N
2180	602	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95023C	\N	\N
2181	642	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95023C	\N	\N
2183	576	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95025E	\N	\N
2099	609	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
2101	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
2019	576	1999-01-01 00:00:00	2001-09-20 00:00:00	ANCIEN	\N	\N	\N	94002S	\N	\N
2020	590	1998-10-01 00:00:00	2001-09-20 00:00:00	ANCIEN	\N	\N	\N	94002S	\N	\N
2021	556	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	\N
2022	571	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	\N
2024	576	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	\N
2025	588	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	\N
2026	589	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	\N
2027	605	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	\N
2028	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	\N
2030	625	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	\N
2031	642	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	\N
2033	573	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	94004U	\N	\N
2034	579	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	94004U	\N	\N
2035	583	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	94004U	\N	\N
2037	604	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	94004U	\N	\N
2039	534	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95002W	\N	\N
2041	574	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95002W	\N	\N
2043	584	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95002W	\N	\N
2045	602	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95002W	\N	\N
2046	605	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95002W	\N	\N
2047	611	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95002W	\N	\N
2048	624	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95002W	\N	\N
2050	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95002W	\N	\N
2051	646	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95002W	\N	\N
2053	573	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95003X	\N	\N
2054	585	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95003X	\N	\N
2056	598	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95003X	\N	\N
2058	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95003X	\N	\N
2060	571	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95004Y	\N	\N
1483	612	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
1484	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
1485	620	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
1488	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
1490	576	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89016Q	\N	\N
1491	576	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
1493	589	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
1494	611	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
1495	556	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
1497	578	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
1498	583	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
1500	591	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
1502	600	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
1503	604	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
1506	640	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
1507	575	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89019T	\N	\N
1509	611	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89019T	\N	\N
1511	626	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89019T	\N	\N
1512	642	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89019T	\N	\N
1429	608	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
1430	609	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
1431	617	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
1432	619	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
1349	578	1998-10-01 00:00:00	2000-03-18 00:00:00	ANCIEN	\N	\N	\N	88003F	\N	\N
1350	583	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88003F	\N	\N
1351	584	1998-10-01 00:00:00	2000-03-18 00:00:00	ANCIEN	\N	\N	\N	88003F	\N	\N
1352	586	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88003F	\N	\N
1353	598	1998-10-01 00:00:00	2000-03-18 00:00:00	ANCIEN	\N	\N	\N	88003F	\N	\N
1354	602	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88003F	\N	\N
1355	608	1999-01-01 00:00:00	2000-03-18 00:00:00	ANCIEN	\N	\N	\N	88003F	\N	\N
1356	612	1999-01-01 00:00:00	2000-03-18 00:00:00	ANCIEN	\N	\N	\N	88003F	\N	\N
1357	619	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88003F	\N	\N
1359	663	1998-10-01 00:00:00	2000-03-18 00:00:00	ANCIEN	\N	\N	\N	88003F	\N	\N
1360	556	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88004G	\N	\N
1361	577	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88004G	\N	\N
1362	584	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88004G	\N	\N
1364	609	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88004G	\N	\N
1365	626	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88004G	\N	\N
1368	530	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88005H	\N	\N
1369	571	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88005H	\N	\N
1370	573	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88005H	\N	\N
1373	584	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88005H	\N	\N
1374	586	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88005H	\N	\N
1377	608	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88005H	\N	\N
1379	613	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88005H	\N	\N
1380	617	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88005H	\N	\N
1382	627	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88005H	\N	\N
1383	642	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88005H	\N	\N
1385	851	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88005H	\N	\N
1386	587	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88006J	\N	\N
1388	642	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88006J	\N	\N
1389	530	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
1391	574	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
1392	576	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
1393	577	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
1395	583	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
1396	584	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
1397	587	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
1400	598	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
1401	609	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
1402	617	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
1403	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
1404	626	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
1408	583	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	88009M	\N	\N
1409	590	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	88009M	\N	\N
1410	602	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	88009M	\N	\N
1411	663	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88012G	\N	\N
1413	590	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
1415	604	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
1417	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
1418	663	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
1420	624	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89004L	\N	\N
1421	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89006N	\N	\N
1423	556	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
1424	576	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
1425	577	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
1428	590	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
1348	530	1999-01-01 00:00:00	2000-03-18 00:00:00	ANCIEN	\N	\N	\N	88003F	\N	\N
1265	612	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
1266	617	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
1267	620	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
1269	625	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
1271	627	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
1272	642	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
1274	644	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
1275	646	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
1278	663	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
1279	530	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
1280	534	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
1281	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
1282	574	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
1283	575	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
1284	576	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
1285	578	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
1286	579	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
1287	580	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
1288	583	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
1289	584	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
1290	585	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
1291	590	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
1293	598	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
1294	600	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
1296	605	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
1297	608	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
1298	611	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
1299	617	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
1300	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
1301	620	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
1302	624	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
1304	571	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86053H	\N	\N
1307	532	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
1309	573	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
1164	600	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86037H	\N	\N
1165	602	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86037H	\N	\N
1167	605	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86037H	\N	\N
1168	608	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86037H	\N	\N
1170	626	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86037H	\N	\N
1171	642	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86037H	\N	\N
1173	573	1998-10-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	86039K	\N	\N
1176	584	1998-10-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	86039K	\N	\N
1095	604	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
1096	608	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
1013	584	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	84003N	\N	\N
163	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	74032N	\N	\N
164	620	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	74032N	\N	\N
165	624	1999-01-01 00:00:00	2001-10-10 00:00:00	ANCIEN	\N	\N	\N	74032N	\N	\N
166	626	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	74032N	\N	\N
168	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	74032N	\N	\N
169	644	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	74032N	\N	\N
173	604	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74042Q	\N	\N
176	624	1998-09-30 00:00:00	1998-02-09 00:00:00	ANCIEN	\N	\N	\N	74044S	\N	\N
2791	572	1999-01-01 00:00:00	2001-10-10 00:00:00	ANCIEN	\N	\N	\N	74032N	\N	\N
2792	572	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98002K	\N	\N
2793	572	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95053J	\N	\N
2794	572	1999-01-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
2795	572	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86042E	\N	\N
2796	572	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
2797	572	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80035E	\N	\N
2798	572	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98039Y	\N	\N
2799	572	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
2800	572	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98033S	\N	\N
2802	572	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80039J	\N	\N
2803	572	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80040B	\N	\N
2804	572	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83054V	\N	\N
2805	572	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80045G	\N	\N
2806	572	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
2807	572	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
2808	572	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98026T	\N	\N
2809	602	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	94004U	\N	\N
2810	602	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89013M	\N	\N
2811	602	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	\N
2812	602	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98049B	\N	\N
2813	602	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74019R	\N	\N
2814	602	1999-01-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	98031Q	\N	\N
2815	602	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
2816	602	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
2817	602	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98047Y	\N	\N
2818	576	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98049B	\N	\N
2819	576	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	\N
2820	576	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98031Q	\N	\N
2821	576	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77017C	\N	\N
2822	576	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83025Q	\N	\N
2823	576	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
430	582	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80004W	\N	\N
431	584	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80004W	\N	\N
432	585	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80004W	\N	\N
433	587	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80004W	\N	\N
434	589	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80004W	\N	\N
435	590	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80004W	\N	\N
436	598	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80004W	\N	\N
437	608	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80004W	\N	\N
438	609	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80004W	\N	\N
439	612	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80004W	\N	\N
440	613	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80004W	\N	\N
441	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80004W	\N	\N
442	625	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80004W	\N	\N
443	626	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80004W	\N	\N
444	640	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80004W	\N	\N
445	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80004W	\N	\N
446	642	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80004W	\N	\N
448	646	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80004W	\N	\N
449	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80007A	\N	\N
450	575	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80007A	\N	\N
936	598	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83043S	\N	\N
937	608	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83043S	\N	\N
938	576	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83044T	\N	\N
939	578	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83044T	\N	\N
940	534	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83046V	\N	\N
941	576	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83046V	\N	\N
943	578	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83046V	\N	\N
944	579	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83046V	\N	\N
945	584	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83046V	\N	\N
946	589	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83046V	\N	\N
947	590	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83046V	\N	\N
948	598	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83046V	\N	\N
950	602	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83046V	\N	\N
952	609	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83046V	\N	\N
953	613	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83046V	\N	\N
955	624	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83046V	\N	\N
957	626	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83046V	\N	\N
958	627	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83046V	\N	\N
959	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83046V	\N	\N
960	642	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83046V	\N	\N
965	590	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83047W	\N	\N
967	580	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83050R	\N	\N
969	605	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83050R	\N	\N
970	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83050R	\N	\N
971	534	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83052T	\N	\N
973	573	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83052T	\N	\N
974	576	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83052T	\N	\N
976	580	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83052T	\N	\N
977	583	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83052T	\N	\N
980	590	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83052T	\N	\N
982	604	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83052T	\N	\N
983	612	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83052T	\N	\N
984	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83052T	\N	\N
987	624	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83052T	\N	\N
988	625	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83052T	\N	\N
991	530	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83054V	\N	\N
992	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83054V	\N	\N
993	573	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83054V	\N	\N
995	576	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83054V	\N	\N
996	578	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83054V	\N	\N
998	595	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83054V	\N	\N
1000	611	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83054V	\N	\N
1001	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83054V	\N	\N
1002	619	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83054V	\N	\N
1003	625	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83054V	\N	\N
1004	646	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83054V	\N	\N
1006	663	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83054V	\N	\N
925	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83037U	\N	\N
926	642	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83037U	\N	\N
928	644	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83037U	\N	\N
845	575	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83026R	\N	\N
846	583	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83026R	\N	\N
847	590	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83026R	\N	\N
849	602	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83026R	\N	\N
850	604	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83026R	\N	\N
852	611	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83026R	\N	\N
853	620	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83026R	\N	\N
855	573	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83028T	\N	\N
857	576	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83028T	\N	\N
858	577	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83028T	\N	\N
859	584	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83028T	\N	\N
861	595	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83028T	\N	\N
864	608	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83028T	\N	\N
865	609	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83028T	\N	\N
866	612	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83028T	\N	\N
867	613	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83028T	\N	\N
868	617	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83028T	\N	\N
869	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83028T	\N	\N
870	619	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83028T	\N	\N
871	620	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83028T	\N	\N
872	624	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83028T	\N	\N
873	626	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83028T	\N	\N
874	627	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83028T	\N	\N
877	646	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83028T	\N	\N
878	530	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83031N	\N	\N
879	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83031N	\N	\N
881	576	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83031N	\N	\N
882	577	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83031N	\N	\N
883	584	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83031N	\N	\N
884	587	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83031N	\N	\N
886	609	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83031N	\N	\N
887	613	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83031N	\N	\N
888	626	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83031N	\N	\N
889	642	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83031N	\N	\N
890	646	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83031N	\N	\N
894	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83033Q	\N	\N
895	578	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83035S	\N	\N
899	604	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83035S	\N	\N
900	605	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83035S	\N	\N
901	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83035S	\N	\N
902	619	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83035S	\N	\N
903	626	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83035S	\N	\N
329	611	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
330	613	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
331	626	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
332	627	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
336	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
338	575	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
339	576	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
341	598	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
258	587	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77044F	\N	\N
259	589	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77044F	\N	\N
177	640	1998-09-30 00:00:00	1998-02-09 00:00:00	ANCIEN	\N	\N	\N	74044S	\N	\N
178	578	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77001T	\N	\N
179	619	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77001T	\N	\N
180	532	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
181	534	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
182	556	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
183	571	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
184	573	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
187	578	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
190	584	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
191	585	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
192	588	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
194	598	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
196	602	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
198	608	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
199	609	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
200	611	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
201	612	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
202	613	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
204	619	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
205	620	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
206	624	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
208	626	1999-01-01 00:00:00	2002-09-30 00:00:00	ANCIEN	\N	\N	\N	77009C	\N	\N
210	646	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
211	663	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
213	530	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77012W	\N	\N
214	573	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77012W	\N	\N
216	590	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77012W	\N	\N
219	608	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77012W	\N	\N
220	609	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77012W	\N	\N
221	617	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	77012W	\N	\N
222	620	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77012W	\N	\N
223	626	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77012W	\N	\N
227	595	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77013X	\N	\N
228	609	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77013X	\N	\N
229	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77017C	\N	\N
231	574	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77017C	\N	\N
233	584	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77017C	\N	\N
235	595	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77017C	\N	\N
237	620	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77017C	\N	\N
239	532	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77019E	\N	\N
241	575	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77029G	\N	\N
243	595	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77029G	\N	\N
245	604	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77029G	\N	\N
246	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77029G	\N	\N
248	576	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77043E	\N	\N
3191	617	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
3192	617	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	98013N	\N	\N
3193	617	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98002K	\N	\N
3194	617	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
3195	617	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	83047W	\N	\N
3196	617	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
3197	617	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80035E	\N	\N
1065	617	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
3198	617	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80040B	\N	\N
3199	616	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92006N	\N	\N
3200	616	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
3201	616	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
3202	616	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80046H	\N	\N
3203	616	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
3204	616	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	\N
3205	616	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95014B	\N	\N
3206	616	1999-01-01 00:00:00	2008-09-24 00:00:00	ANCIEN	\N	\N	\N	88004G	\N	\N
556	617	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
557	619	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
32	590	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	70001N	\N	\N
558	624	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
559	626	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
561	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
562	642	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
564	644	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
568	573	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80035E	\N	\N
570	576	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80035E	\N	\N
571	577	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80035E	\N	\N
572	578	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80035E	\N	\N
574	585	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80035E	\N	\N
575	590	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80035E	\N	\N
578	605	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80035E	\N	\N
579	608	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80035E	\N	\N
580	609	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80035E	\N	\N
581	613	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80035E	\N	\N
583	627	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80035E	\N	\N
585	646	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80035E	\N	\N
587	530	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80036F	\N	\N
588	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80036F	\N	\N
589	571	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80036F	\N	\N
507	611	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80025C	\N	\N
508	620	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80025C	\N	\N
509	624	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80025C	\N	\N
428	576	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80004W	\N	\N
429	578	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80004W	\N	\N
2824	576	1999-01-01 00:00:00	2001-03-27 00:00:00	ANCIEN	\N	\N	\N	95022B	\N	\N
2825	576	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95029J	\N	\N
2826	576	2001-12-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
2827	576	1999-01-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	96005E	\N	\N
2828	576	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98009S	\N	\N
1071	530	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	85003S	\N	\N
1072	583	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	85003S	\N	\N
1074	589	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	85003S	\N	\N
1075	590	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	85003S	\N	\N
1077	598	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	85003S	\N	\N
1080	608	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	85003S	\N	\N
1081	617	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	85003S	\N	\N
1082	620	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	85003S	\N	\N
1083	624	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	85003S	\N	\N
1084	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	85003S	\N	\N
1085	588	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86004X	\N	\N
1086	600	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86004X	\N	\N
1088	663	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86004X	\N	\N
1090	532	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
1091	577	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
1009	573	1998-10-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	84003N	\N	\N
1010	574	1998-10-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	84003N	\N	\N
1011	577	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	84003N	\N	\N
1012	583	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	84003N	\N	\N
930	590	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83038V	\N	\N
931	576	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83040P	\N	\N
932	590	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83040P	\N	\N
933	604	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83040P	\N	\N
934	619	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83040P	\N	\N
935	580	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83043S	\N	\N
487	600	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83023N	\N	\N
488	602	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80014Y	\N	\N
490	617	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80014Y	\N	\N
491	619	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80014Y	\N	\N
493	627	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80014Y	\N	\N
494	575	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80017C	\N	\N
495	576	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80017C	\N	\N
496	587	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80017C	\N	\N
497	595	1998-10-01 00:00:00	2008-09-07 00:00:00	ANCIEN	\N	\N	\N	80017C	\N	\N
501	604	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80021X	\N	\N
503	575	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80024B	\N	\N
505	602	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80025C	\N	\N
506	608	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80025C	\N	\N
425	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80004W	\N	\N
426	573	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80004W	\N	\N
427	574	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80004W	\N	\N
345	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
346	620	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
347	626	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
348	627	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
349	642	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
350	644	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
351	646	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
353	556	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78007E	\N	\N
354	573	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78007E	\N	\N
355	574	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78007E	\N	\N
356	575	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78007E	\N	\N
357	576	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78007E	\N	\N
358	583	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78007E	\N	\N
359	584	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78007E	\N	\N
360	587	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	78007E	\N	\N
361	590	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78007E	\N	\N
362	595	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78007E	\N	\N
363	598	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78007E	\N	\N
365	608	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78007E	\N	\N
366	617	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78007E	\N	\N
367	627	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	78007E	\N	\N
368	642	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78007E	\N	\N
370	646	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	78007E	\N	\N
372	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	78010Y	\N	\N
373	571	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	78010Y	\N	\N
374	573	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	78010Y	\N	\N
375	574	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	78010Y	\N	\N
376	582	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	78010Y	\N	\N
377	585	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	78010Y	\N	\N
378	589	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	78010Y	\N	\N
379	604	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	78010Y	\N	\N
380	612	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	78010Y	\N	\N
381	617	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	78010Y	\N	\N
382	625	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	78010Y	\N	\N
383	640	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	78010Y	\N	\N
385	576	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	79004F	\N	\N
386	582	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	79004F	\N	\N
388	587	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	79004F	\N	\N
389	595	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	79004F	\N	\N
390	611	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	79004F	\N	\N
392	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	79004F	\N	\N
394	571	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	79005G	\N	\N
395	574	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	79005G	\N	\N
398	584	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	79005G	\N	\N
401	608	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	79005G	\N	\N
402	611	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	79005G	\N	\N
404	626	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	79005G	\N	\N
405	640	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	79005G	\N	\N
409	576	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80002U	\N	\N
410	586	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80002U	\N	\N
411	587	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80002U	\N	\N
413	608	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80002U	\N	\N
414	617	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80002U	\N	\N
416	624	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80002U	\N	\N
417	625	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80002U	\N	\N
422	604	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80003V	\N	\N
423	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80003V	\N	\N
424	619	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80003V	\N	\N
343	608	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
344	612	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
261	608	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77044F	\N	\N
262	609	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98051U	\N	\N
263	612	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77044F	\N	\N
264	626	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77044F	\N	\N
265	642	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77044F	\N	\N
267	577	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77046H	\N	\N
268	609	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77046H	\N	\N
269	530	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77047J	\N	\N
270	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77047J	\N	\N
271	571	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77047J	\N	\N
272	573	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77047J	\N	\N
273	574	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77047J	\N	\N
274	575	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77047J	\N	\N
276	583	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77047J	\N	\N
277	595	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77047J	\N	\N
279	617	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77047J	\N	\N
281	627	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77047J	\N	\N
282	644	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77047J	\N	\N
285	663	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77047J	\N	\N
287	598	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77053G	\N	\N
289	577	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77058M	\N	\N
290	578	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77058M	\N	\N
292	583	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77058M	\N	\N
293	584	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77058M	\N	\N
295	595	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77058M	\N	\N
297	600	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95058P	\N	\N
299	609	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77058M	\N	\N
300	617	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77058M	\N	\N
302	574	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77060F	\N	\N
304	575	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77066M	\N	\N
305	582	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77066M	\N	\N
306	587	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77066M	\N	\N
307	588	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77066M	\N	\N
309	620	1998-10-01 00:00:00	1999-11-01 00:00:00	ANCIEN	\N	\N	\N	77066M	\N	\N
311	530	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
312	532	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
315	574	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
316	576	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
318	579	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
319	580	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
320	583	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
321	584	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
323	595	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
325	600	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
326	604	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
327	608	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
328	609	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
3004	596	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98051U	\N	\N
3005	596	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86037H	\N	\N
3006	596	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92033R	\N	\N
3007	596	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77043E	\N	\N
3008	596	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74028S	\N	\N
3009	596	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95047L	\N	\N
3010	596	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
3011	596	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98007Q	\N	\N
3012	596	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83046V	\N	\N
3013	596	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
3014	596	1999-01-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	95051G	\N	\N
3015	596	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	91002E	\N	\N
3016	596	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
3017	596	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83047W	\N	\N
3018	596	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98021N	\N	\N
3019	596	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
3020	596	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80035E	\N	\N
3021	596	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89037V	\N	\N
3022	596	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98033S	\N	\N
3023	596	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80039J	\N	\N
3024	596	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80040B	\N	\N
3025	596	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83054V	\N	\N
3026	596	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80041C	\N	\N
3027	596	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80046H	\N	\N
3028	596	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
3029	603	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	74011H	\N	\N
3030	603	2009-10-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92018S	\N	\N
3031	603	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74019R	\N	\N
3032	603	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
3033	603	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04069P	\N	\N
3034	603	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83046V	\N	\N
3035	603	1999-01-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	95051G	\N	\N
3036	603	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
3037	603	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
3038	603	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
3039	603	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89042S	\N	\N
3040	603	1999-01-01 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	89045V	\N	\N
3041	604	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98021N	\N	\N
3042	605	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
3043	605	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98049B	\N	\N
3044	605	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98031Q	\N	\N
3045	605	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	\N
3046	605	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83026R	\N	\N
3047	605	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
3048	605	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
3049	605	1999-01-01 00:00:00	1999-01-01 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
3050	605	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
3051	605	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98003L	\N	\N
3052	605	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
3053	605	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
3054	605	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77047J	\N	\N
3055	605	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	91002E	\N	\N
3056	605	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98002K	\N	\N
3057	605	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
3058	605	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98033S	\N	\N
3063	607	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83018R	\N	\N
3064	607	1999-01-01 00:00:00	2003-06-17 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
3061	605	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89042S	\N	\N
3062	607	1999-01-01 00:00:00	2003-06-17 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
3065	607	1999-01-01 00:00:00	2003-06-17 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
3066	607	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
3067	607	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74019R	\N	\N
3068	607	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86004X	\N	\N
3069	607	1999-01-01 00:00:00	2001-02-07 00:00:00	ANCIEN	\N	\N	\N	74024N	\N	\N
3070	607	1999-01-01 00:00:00	2003-06-17 00:00:00	ANCIEN	\N	\N	\N	83047W	\N	\N
3071	607	1999-01-01 00:00:00	2003-06-17 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
3072	607	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
3073	608	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83011J	\N	\N
3074	608	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
3075	608	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	71003U	\N	\N
3076	608	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	88004G	\N	\N
3077	608	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
3078	608	1999-01-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	98031Q	\N	\N
3079	608	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
3080	608	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	65017N	\N	\N
3081	608	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
3082	608	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	96005E	\N	\N
3083	608	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83003J	\N	\N
3084	608	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
3085	608	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86031B	\N	\N
3086	608	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
3087	608	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98038X	\N	\N
3088	608	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
3089	608	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	68036E	\N	\N
3090	608	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
3091	608	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83046V	\N	\N
3092	608	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98021N	\N	\N
3093	608	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98050T	\N	\N
3094	608	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98033S	\N	\N
3095	608	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83050R	\N	\N
3096	608	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
3097	608	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83054V	\N	\N
3098	608	1999-01-01 00:00:00	2004-07-19 00:00:00	ANCIEN	\N	\N	\N	95066P	\N	\N
3099	602	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
3100	602	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98009S	\N	\N
3101	602	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86031B	\N	\N
3102	602	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	97008M	\N	\N
3103	602	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83035S	\N	\N
3104	602	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92027T	\N	\N
3105	602	1999-01-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	83037U	\N	\N
3106	602	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98038X	\N	\N
3107	602	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92030N	\N	\N
3108	602	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	82002D	\N	\N
3109	602	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92032Q	\N	\N
3110	602	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98046X	\N	\N
3111	602	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95047L	\N	\N
2057	602	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95003X	\N	\N
3112	602	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77047J	\N	\N
3113	602	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83044T	\N	\N
3114	602	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95049N	\N	\N
3115	602	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98007Q	\N	\N
3116	602	1999-01-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	95051G	\N	\N
3117	602	1999-01-01 00:00:00	2001-10-10 00:00:00	ANCIEN	\N	\N	\N	74032N	\N	\N
3118	602	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	91002E	\N	\N
3119	602	1999-01-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
3120	602	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
520	575	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
521	578	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
522	579	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
523	583	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
524	585	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
526	589	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
527	590	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
528	595	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
529	598	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
530	613	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
531	624	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
537	530	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
538	532	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
540	573	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
541	576	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
542	577	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
544	584	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
545	585	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
549	602	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
550	605	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
551	608	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
16337	908	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	05008E	\N	\N
553	611	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
554	612	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
555	613	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
1700	644	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89045V	\N	\N
1701	659	1999-01-01 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	89045V	\N	\N
1704	530	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
1706	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
1707	573	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
1709	576	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
1710	577	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
1711	578	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
1713	583	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
1714	584	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
1715	585	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
1716	586	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
1717	587	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
1718	588	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
1720	598	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
1722	602	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
1723	608	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
1724	609	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
1725	612	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
1728	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
1732	627	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
1733	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
1734	642	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
1736	646	1999-01-01 00:00:00	2001-10-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
1739	851	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
1741	578	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	90003B	\N	\N
1131	627	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86018E	\N	\N
1133	573	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86021Y	\N	\N
1135	583	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86021Y	\N	\N
1137	642	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86021Y	\N	\N
1140	620	1998-10-01 00:00:00	2002-09-30 00:00:00	ANCIEN	\N	\N	\N	86025D	\N	\N
1141	626	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86025D	\N	\N
1142	579	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
1144	604	1998-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
1146	590	1998-10-01 00:00:00	2003-11-04 00:00:00	ANCIEN	\N	\N	\N	86031B	\N	\N
1148	609	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	86031B	\N	\N
1149	619	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86031B	\N	\N
1150	534	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86034E	\N	\N
1152	620	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86035F	\N	\N
1155	575	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86037H	\N	\N
1156	576	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86037H	\N	\N
1157	577	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86037H	\N	\N
1158	583	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86037H	\N	\N
1159	584	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86037H	\N	\N
1160	587	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86037H	\N	\N
1161	589	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86037H	\N	\N
1163	595	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86037H	\N	\N
249	590	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77043E	\N	\N
251	626	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77043E	\N	\N
252	642	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77043E	\N	\N
254	575	2000-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77044F	\N	\N
257	584	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77044F	\N	\N
1	575	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	65017N	\N	\N
2	580	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	65017N	\N	\N
3	595	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	65017N	\N	\N
5	602	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	65017N	\N	\N
6	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	65017N	\N	\N
7	532	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
8	573	1998-10-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
9	578	1998-10-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
10	584	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
11	595	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
12	620	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
13	642	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
14	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	69001W	\N	\N
15	583	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	69001W	\N	\N
16	590	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	69001W	\N	\N
17	598	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	69001W	\N	\N
19	602	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	69001W	\N	\N
20	608	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	69001W	\N	\N
21	612	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	69001W	\N	\N
22	619	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	69001W	\N	\N
25	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	70001N	\N	\N
26	576	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	70001N	\N	\N
27	579	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	70001N	\N	\N
28	580	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	70001N	\N	\N
29	583	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	70001N	\N	\N
31	589	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	70001N	\N	\N
35	602	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	70001N	\N	\N
36	604	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	70001N	\N	\N
37	609	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	70001N	\N	\N
40	640	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	70001N	\N	\N
41	576	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	71003U	\N	\N
42	578	1998-10-01 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	71003U	\N	\N
43	579	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	71003U	\N	\N
46	663	1998-10-01 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	71003U	\N	\N
47	530	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	71006X	\N	\N
48	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	71009B	\N	\N
51	604	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	71009B	\N	\N
52	626	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	71009B	\N	\N
53	530	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	71017B	\N	\N
56	580	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	71017B	\N	\N
57	584	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	71017B	\N	\N
58	585	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	71017B	\N	\N
59	589	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	71017B	\N	\N
61	600	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
62	604	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	71017B	\N	\N
64	624	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	71017B	\N	\N
65	625	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	71017B	\N	\N
68	532	1998-10-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	74011H	\N	\N
70	556	1998-09-30 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	74011H	\N	\N
72	576	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	74011H	\N	\N
73	584	1998-10-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	74011H	\N	\N
74	588	1998-09-30 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	74011H	\N	\N
76	605	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	74011H	\N	\N
77	607	1998-09-30 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	74011H	\N	\N
78	609	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	74011H	\N	\N
79	612	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	74011H	\N	\N
81	619	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	74011H	\N	\N
82	624	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	74011H	\N	\N
83	627	1998-09-30 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	74011H	\N	\N
84	642	1998-10-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	74011H	\N	\N
86	646	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	74011H	\N	\N
89	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	74013K	\N	\N
90	556	1998-10-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	74015M	\N	\N
91	573	1998-10-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	74015M	\N	\N
92	574	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	74015M	\N	\N
93	576	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	74015M	\N	\N
94	578	1998-10-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	74015M	\N	\N
95	584	1998-10-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	74015M	\N	\N
97	609	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	74015M	\N	\N
98	613	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	74015M	\N	\N
99	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	74015M	\N	\N
100	627	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	74015M	\N	\N
102	646	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	74015M	\N	\N
451	579	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80007A	\N	\N
452	587	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80007A	\N	\N
453	598	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80007A	\N	\N
455	608	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80007A	\N	\N
456	617	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80007A	\N	\N
457	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80007A	\N	\N
458	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80011V	\N	\N
459	573	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80011V	\N	\N
460	576	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80011V	\N	\N
461	579	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80011V	\N	\N
462	584	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80011V	\N	\N
463	589	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80011V	\N	\N
464	590	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80011V	\N	\N
465	598	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80011V	\N	\N
468	604	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80011V	\N	\N
470	613	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80011V	\N	\N
471	617	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80011V	\N	\N
473	646	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80011V	\N	\N
475	530	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80014Y	\N	\N
476	571	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80014Y	\N	\N
477	573	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80014Y	\N	\N
479	582	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80014Y	\N	\N
480	583	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80014Y	\N	\N
481	584	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80014Y	\N	\N
482	585	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80014Y	\N	\N
484	588	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80014Y	\N	\N
485	590	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80014Y	\N	\N
486	598	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80014Y	\N	\N
104	663	1998-10-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	74015M	\N	\N
105	534	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74019R	\N	\N
106	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	74019R	\N	\N
107	571	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	74019R	\N	\N
108	573	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74019R	\N	\N
109	582	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74019R	\N	\N
110	583	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74019R	\N	\N
111	588	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74019R	\N	\N
112	589	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	74019R	\N	\N
113	590	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74019R	\N	\N
114	598	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74019R	\N	\N
115	600	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74019R	\N	\N
118	624	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74019R	\N	\N
120	640	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	74019R	\N	\N
122	646	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74019R	\N	\N
125	580	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	74022L	\N	\N
126	595	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74022L	\N	\N
127	600	1999-01-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	83037U	\N	\N
130	626	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	74022L	\N	\N
131	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	74022L	\N	\N
133	589	1999-01-01 00:00:00	2001-02-07 00:00:00	ANCIEN	\N	\N	\N	74024N	\N	\N
134	595	1998-10-01 00:00:00	2001-02-07 00:00:00	ANCIEN	\N	\N	\N	74024N	\N	\N
136	602	1999-01-01 00:00:00	2001-02-07 00:00:00	ANCIEN	\N	\N	\N	74024N	\N	\N
137	604	1998-10-01 00:00:00	2001-02-07 00:00:00	ANCIEN	\N	\N	\N	74024N	\N	\N
138	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	74024N	\N	\N
139	624	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	74024N	\N	\N
142	530	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	74028S	\N	\N
144	580	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	74028S	\N	\N
145	590	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74028S	\N	\N
148	620	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	74028S	\N	\N
151	571	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	74032N	\N	\N
152	576	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	74032N	\N	\N
154	584	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	74032N	\N	\N
155	588	1999-01-01 00:00:00	2001-10-10 00:00:00	ANCIEN	\N	\N	\N	74032N	\N	\N
157	598	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74032N	\N	\N
158	600	1999-01-01 00:00:00	2001-10-10 00:00:00	ANCIEN	\N	\N	\N	74032N	\N	\N
160	607	1999-01-01 00:00:00	2001-10-10 00:00:00	ANCIEN	\N	\N	\N	74032N	\N	\N
161	608	1999-01-01 00:00:00	2001-10-10 00:00:00	ANCIEN	\N	\N	\N	74032N	\N	\N
162	612	1999-01-01 00:00:00	2001-10-10 00:00:00	ANCIEN	\N	\N	\N	74032N	\N	\N
3578	657	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
3579	657	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	\N
3580	657	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
3581	657	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92020L	\N	\N
3582	657	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83031N	\N	\N
3583	657	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
3584	657	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83035S	\N	\N
3585	657	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77047J	\N	\N
3586	657	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
3587	657	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80040B	\N	\N
3588	657	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
3589	657	1999-01-01 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	89045V	\N	\N
3590	657	1999-01-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	95036H	\N	\N
3591	625	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92006N	\N	\N
3594	625	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
3240	616	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83052T	\N	\N
3241	616	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83054V	\N	\N
3242	616	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89045V	\N	\N
3244	616	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
3246	612	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83011J	\N	\N
117	612	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74019R	\N	\N
3247	612	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
3248	612	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98053W	\N	\N
1866	612	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92023P	\N	\N
1919	612	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
1953	612	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
3249	612	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
3250	612	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
3251	612	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
2100	611	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
3252	611	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95019G	\N	\N
3253	611	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86018E	\N	\N
838	611	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83023N	\N	\N
3254	611	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74019R	\N	\N
3255	611	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98031Q	\N	\N
3256	611	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83026R	\N	\N
3257	611	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
3258	611	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
3259	611	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
2241	611	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98047Y	\N	\N
11756	659	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
3260	611	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
3261	611	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
3262	611	1999-01-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	83037U	\N	\N
3263	611	1999-01-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	98043U	\N	\N
1967	611	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
3264	611	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83046V	\N	\N
3265	611	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89016Q	\N	\N
3266	611	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
3267	611	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
3268	611	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
3270	619	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95005A	\N	\N
3271	619	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83011J	\N	\N
2102	619	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
1033	619	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
3272	619	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	\N
3273	619	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
3274	619	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83018R	\N	\N
3275	619	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	74015M	\N	\N
3276	619	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	\N
3277	619	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
3278	619	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
913	619	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83036T	\N	\N
3279	619	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95039L	\N	\N
3280	619	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92029V	\N	\N
3281	619	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95045J	\N	\N
3282	619	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
3283	619	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95059Q	\N	\N
3285	619	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
3286	619	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
3289	615	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
3290	615	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
3291	615	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	79004F	\N	\N
3292	615	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	84003N	\N	\N
3293	615	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	74011H	\N	\N
3294	615	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
3295	615	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83018R	\N	\N
3296	615	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
3297	615	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
3298	615	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86018E	\N	\N
3299	615	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95020Y	\N	\N
3300	615	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77017C	\N	\N
3301	615	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86004X	\N	\N
3302	615	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
3303	615	1999-01-01 00:00:00	2009-04-28 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
3304	615	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89030N	\N	\N
3305	615	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
3306	615	1999-01-01 00:00:00	2009-04-28 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
3307	615	1999-01-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	83037U	\N	\N
3308	615	1999-01-01 00:00:00	2001-02-07 00:00:00	ANCIEN	\N	\N	\N	74024N	\N	\N
3309	615	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
3310	615	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95002W	\N	\N
11757	659	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04084N	\N	\N
3311	615	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86037H	\N	\N
3312	615	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77047J	\N	\N
3313	615	1999-01-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	86039K	\N	\N
3314	615	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
3315	615	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
3316	615	1999-01-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	95053J	\N	\N
3317	615	1999-01-01 00:00:00	2009-04-28 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
3318	615	1999-01-01 00:00:00	2000-03-18 00:00:00	ANCIEN	\N	\N	\N	88003F	\N	\N
3319	615	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
3320	615	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80045G	\N	\N
3321	615	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
3322	615	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89045V	\N	\N
3323	615	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
3324	624	1999-01-01 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	71003U	\N	\N
3325	624	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83018R	\N	\N
3326	624	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98031Q	\N	\N
3327	624	1999-01-01 00:00:00	2001-03-27 00:00:00	ANCIEN	\N	\N	\N	95022B	\N	\N
3328	624	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
1730	624	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
3329	624	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
3330	624	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
2029	624	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	\N
923	624	1999-01-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	83037U	\N	\N
3331	624	1999-01-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	98043U	\N	\N
3332	624	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	81011A	\N	\N
1169	624	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86037H	\N	\N
3333	624	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
3334	624	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
3335	624	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98002K	\N	\N
3336	624	1999-01-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	95053J	\N	\N
1268	624	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
3337	624	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92045V	\N	\N
1805	626	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92006N	\N	\N
3339	626	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
1034	626	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
3340	626	1999-01-01 00:00:00	1999-09-30 00:00:00	ANCIEN	\N	\N	\N	95008D	\N	\N
3341	626	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	79004F	\N	\N
1486	626	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
3342	626	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98016R	\N	\N
3343	626	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98048A	\N	\N
3344	626	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83020K	\N	\N
3345	626	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
815	626	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
3346	626	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74019R	\N	\N
3347	626	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98031Q	\N	\N
3348	626	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
1731	626	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
2219	626	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95031C	\N	\N
1855	626	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92021M	\N	\N
3349	626	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
3350	626	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	\N
3351	626	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
3352	626	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83036T	\N	\N
1884	626	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92026S	\N	\N
3353	626	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
2049	626	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95002W	\N	\N
3356	626	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	82002D	\N	\N
3357	626	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98051U	\N	\N
3358	626	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
1955	626	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
3359	626	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
3360	626	1999-01-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	95051G	\N	\N
3361	626	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
3362	626	1999-01-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	95053J	\N	\N
3363	626	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
582	626	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80035E	\N	\N
1068	626	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
3364	626	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98039Y	\N	\N
3365	626	1999-01-01 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	98012M	\N	\N
1270	626	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
3366	626	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	93003P	\N	\N
3367	626	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
3368	644	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
3369	644	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
3370	644	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	96004D	\N	2015-02-02 16:43:40
11754	659	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
3775	601	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
3776	601	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
3777	601	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
3778	601	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89040Q	\N	\N
3779	601	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
3780	601	1999-01-01 00:00:00	1999-11-02 00:00:00	ANCIEN	\N	\N	\N	77066M	\N	\N
3784	617	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
3782	601	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
3785	616	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
3786	628	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
3787	628	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	96008H	\N	\N
3788	628	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83011J	\N	\N
3789	628	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
3790	628	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	84003N	\N	\N
3791	628	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	\N
3792	628	1999-01-01 00:00:00	1992-09-26 00:00:00	ANCIEN	\N	\N	\N	86005Y	\N	\N
3793	628	1999-01-01 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	71003U	\N	\N
3794	628	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83018R	\N	\N
3795	628	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
3796	628	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98029W	\N	\N
3797	628	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	90003B	\N	\N
3798	628	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
3799	628	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	\N
3800	628	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95023C	\N	\N
3801	628	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	\N
3802	628	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
3803	628	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92021M	\N	\N
3804	628	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92022N	\N	\N
3805	628	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
3806	628	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77019E	\N	\N
3807	628	1999-01-01 00:00:00	1999-12-31 00:00:00	ANCIEN	\N	\N	\N	92023P	\N	\N
3808	628	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98017S	\N	\N
3809	628	1999-01-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	95036H	\N	\N
3810	628	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77029G	\N	\N
3811	628	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83036T	\N	\N
3812	628	1999-01-01 00:00:00	2001-02-07 00:00:00	ANCIEN	\N	\N	\N	74024N	\N	\N
3813	628	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	85003S	\N	\N
3814	628	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
3815	628	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
3816	628	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95045J	\N	\N
3817	628	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
3818	628	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95003X	\N	\N
3819	628	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77047J	\N	\N
3820	628	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
3821	628	1999-01-01 00:00:00	2001-10-10 00:00:00	ANCIEN	\N	\N	\N	74032N	\N	\N
3822	628	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98002K	\N	\N
3823	628	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77060F	\N	\N
3824	628	1999-01-01 00:00:00	2000-03-18 00:00:00	ANCIEN	\N	\N	\N	88003F	\N	\N
3825	628	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83054V	\N	\N
3826	628	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92044U	\N	\N
3827	628	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89042S	\N	\N
11759	659	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
3828	628	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
3829	628	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89045V	\N	\N
3830	532	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78007E	\N	\N
3542	591	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95058P	\N	\N
3544	591	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
3566	594	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
3564	596	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
3525	620	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
2523	598	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
2525	620	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
2528	584	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98022P	\N	\N
2530	595	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98022P	\N	\N
2532	642	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98023Q	\N	\N
2534	574	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98029W	\N	\N
2536	590	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98031Q	\N	\N
2538	598	1998-10-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	98031Q	\N	\N
2540	556	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
2542	604	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
2544	584	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98033S	\N	\N
2546	598	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98033S	\N	\N
2548	595	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
2550	574	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98038X	\N	\N
2552	584	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98039Y	\N	\N
2554	620	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98039Y	\N	\N
2558	556	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98048A	\N	\N
2560	598	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98048A	\N	\N
2562	575	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98049B	\N	\N
2564	595	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98049B	\N	\N
2566	590	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98050T	\N	\N
2568	642	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98051U	\N	\N
2456	642	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
2458	534	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98002K	\N	\N
2460	584	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98002K	\N	\N
2462	595	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98002K	\N	\N
2465	556	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98003L	\N	\N
2467	642	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98003L	\N	\N
2470	574	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98007Q	\N	\N
2472	590	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98007Q	\N	\N
2474	590	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98009S	\N	\N
2476	584	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
2478	595	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
2481	575	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
2483	584	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
2486	573	1998-10-01 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	98012M	\N	\N
2488	595	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98012M	\N	\N
2490	574	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98013N	\N	\N
2492	598	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98013N	\N	\N
2495	598	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
2497	590	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
2499	604	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
2501	574	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98016R	\N	\N
2503	595	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98016R	\N	\N
2505	620	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98016R	\N	\N
2507	590	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98017S	\N	\N
3683	629	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
3684	629	1999-01-01 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	89045V	\N	\N
3685	622	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92006N	\N	\N
3686	622	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
3687	622	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	84003N	\N	\N
3688	622	1999-01-01 00:00:00	2001-10-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	\N
3689	622	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	74011H	\N	\N
3690	622	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92009R	\N	\N
3691	622	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
3692	622	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95014B	\N	\N
3693	622	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	83017Q	\N	\N
3694	622	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	92012L	\N	\N
3695	622	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88004G	\N	\N
3696	622	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	74015M	\N	\N
3697	622	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98048A	\N	\N
3698	622	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
3699	622	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
3700	622	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95020Y	\N	\N
3701	622	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
3121	602	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
3122	602	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
3123	602	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89042S	\N	\N
2013	602	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92045V	\N	\N
1726	613	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
1895	613	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92030N	\N	\N
3124	613	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
3125	613	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	79004F	\N	\N
3126	613	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	74011H	\N	\N
3127	613	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95014B	\N	\N
3128	613	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	88004G	\N	\N
3129	613	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95002W	\N	\N
3130	613	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83054V	\N	\N
3131	613	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
3132	613	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
3133	623	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95004Y	\N	\N
3134	623	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98036V	\N	\N
3135	623	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
3136	623	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
3137	623	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	74015M	\N	\N
3138	623	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98049B	\N	\N
3139	623	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
3140	623	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
3141	623	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
3142	623	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92021M	\N	\N
3143	623	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
3144	623	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86031B	\N	\N
3145	623	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92025R	\N	\N
3146	623	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83035S	\N	\N
3147	623	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95002W	\N	\N
3148	623	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86037H	\N	\N
3149	623	2010-03-30 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95045J	\N	\N
3150	623	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83040P	\N	\N
3151	623	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
3152	623	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77047J	\N	\N
3153	623	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95051G	\N	\N
3154	623	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
3155	623	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98002K	\N	\N
3156	623	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83047W	\N	\N
3157	623	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
3158	623	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
3159	623	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74042Q	\N	\N
3160	623	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
3161	623	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
3162	529	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
3163	529	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
3164	529	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
3165	529	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
3166	529	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
3167	529	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98047Y	\N	\N
3168	529	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	\N
3169	529	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
3170	529	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
3171	529	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74028S	\N	\N
3172	529	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
3173	529	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	68036E	\N	\N
3174	529	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	91002E	\N	\N
3175	529	1999-01-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
3176	529	1999-01-01 00:00:00	2001-10-14 00:00:00	ANCIEN	\N	\N	\N	89009R	\N	\N
3177	529	1999-01-01 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	89045V	\N	\N
3178	617	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98016R	\N	\N
3179	617	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83020K	\N	\N
3180	617	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98023Q	\N	\N
1757	617	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
3181	617	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92019T	\N	\N
3182	617	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	86025D	\N	\N
3183	617	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
3184	617	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	96005E	\N	\N
3185	617	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
3186	617	1999-01-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	83037U	\N	\N
3187	617	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
3188	617	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86037H	\N	\N
3189	617	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	98046X	\N	\N
3190	617	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	95003X	\N	\N
2989	596	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98052V	\N	\N
2990	596	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	\N
2991	596	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
2992	596	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
2993	596	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
2994	596	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98003L	\N	\N
2995	596	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	\N
2996	596	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92026S	\N	\N
2997	596	1999-01-01 00:00:00	2001-02-07 00:00:00	ANCIEN	\N	\N	\N	74024N	\N	\N
2998	596	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95040D	\N	\N
2999	596	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	85003S	\N	\N
3000	596	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
3001	596	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
3002	596	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95002W	\N	\N
3003	596	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92032Q	\N	\N
1566	644	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
3371	644	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
1877	644	1999-01-01 00:00:00	2007-02-25 00:00:00	ANCIEN	\N	\N	\N	92024Q	\N	\N
3372	644	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
3373	644	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
3374	644	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
3375	644	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
3376	632	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	79004F	\N	\N
3377	632	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78007E	\N	\N
3378	632	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
3379	632	1999-01-01 00:00:00	2001-03-27 00:00:00	ANCIEN	\N	\N	\N	95022B	\N	\N
3380	632	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92024Q	\N	\N
3381	632	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
3382	632	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
3383	632	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86037H	\N	\N
3384	632	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77047J	\N	\N
3385	632	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
3386	632	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95058P	\N	\N
3387	632	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
3388	632	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98039Y	\N	\N
3389	632	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
3390	632	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
3391	651	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
3393	651	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
3394	651	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
3395	651	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	74011H	\N	\N
3396	651	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89019T	\N	\N
3397	651	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92009R	\N	\N
3398	651	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83018R	\N	\N
3399	651	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83020K	\N	\N
3401	651	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
3402	651	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
3403	651	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74019R	\N	\N
3404	651	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83025Q	\N	\N
3405	651	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
3406	651	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95023C	\N	\N
3407	651	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
3408	651	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92021M	\N	\N
3409	651	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83031N	\N	\N
3410	651	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98053W	\N	\N
3411	651	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
3412	651	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
3413	651	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98003L	\N	\N
3414	651	1999-01-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	83037U	\N	\N
3415	651	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
3416	651	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92033R	\N	\N
3417	651	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
3418	651	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95047L	\N	\N
3419	651	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
3420	651	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83046V	\N	\N
3421	651	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
3422	651	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
3423	651	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
3424	651	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
3523	661	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
3524	643	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
3526	620	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
3527	642	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	79004F	\N	\N
3528	642	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
3529	642	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98046X	\N	\N
3530	642	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98021N	\N	\N
3531	642	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
3532	642	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98012M	\N	\N
3534	591	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
3535	591	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
3536	591	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98016R	\N	\N
3537	591	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
3538	591	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95031C	\N	\N
3539	591	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
3540	591	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	\N
3541	591	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
3543	591	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92043T	\N	\N
3545	591	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
3546	535	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92006N	\N	\N
3547	535	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	\N
3548	535	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88004G	\N	\N
3549	535	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
3425	651	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98033S	\N	\N
3426	651	1999-01-01 00:00:00	2000-03-18 00:00:00	ANCIEN	\N	\N	\N	88003F	\N	\N
3427	651	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80040B	\N	\N
3428	651	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
3429	651	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89042S	\N	\N
3430	651	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
3431	651	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98005N	\N	\N
3433	643	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92006N	\N	\N
3435	643	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
3437	643	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	79004F	\N	\N
3439	643	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	74011H	\N	\N
3442	643	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88004G	\N	\N
3444	643	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98049B	\N	\N
3446	643	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
3448	643	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
3449	643	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98023Q	\N	\N
3450	643	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98031Q	\N	\N
3451	643	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
3453	643	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83028T	\N	\N
3454	643	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	\N
3455	643	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
3456	643	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
3457	643	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
3459	643	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
3461	643	1999-01-01 00:00:00	2001-02-07 00:00:00	ANCIEN	\N	\N	\N	74024N	\N	\N
3462	643	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95002W	\N	\N
3463	643	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	97006K	\N	\N
3464	643	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98051U	\N	\N
3465	643	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86037H	\N	\N
3466	643	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77043E	\N	\N
3467	643	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
3468	643	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
3469	643	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95047L	\N	\N
3470	643	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
3471	643	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	68036E	\N	\N
3472	643	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
3473	643	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
3474	643	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83046V	\N	\N
3475	643	1999-01-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	95051G	\N	\N
3476	643	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
3477	643	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
3478	643	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
3479	643	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
3480	643	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
3481	643	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80040B	\N	\N
3482	643	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83054V	\N	\N
3483	643	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
3484	643	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
3485	643	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92045V	\N	\N
11755	659	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98023Q	\N	\N
3486	643	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
3447	643	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
3445	643	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
3443	643	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	74015M	\N	\N
3441	643	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92013M	\N	\N
3440	643	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78007E	\N	\N
3438	643	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89013M	\N	\N
3436	643	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
3434	643	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
3488	659	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
3489	659	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	84003N	\N	\N
3490	659	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74019R	\N	\N
3491	659	1999-01-01 00:00:00	2001-03-27 00:00:00	ANCIEN	\N	\N	\N	95022B	\N	\N
3492	659	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87003B	\N	\N
3493	659	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
3494	659	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
3495	659	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92024Q	\N	\N
3496	659	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
3497	659	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	88009M	\N	\N
3498	659	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
3499	659	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
3500	659	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
3501	659	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77047J	\N	\N
3502	659	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	68036E	\N	\N
3503	659	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
3504	659	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
3505	659	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	95058P	\N	\N
3506	659	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	95051G	\N	\N
3507	659	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
3508	659	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
3510	661	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78007E	\N	\N
3511	661	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	96004D	\N	2015-02-02 16:43:48
3512	661	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
3513	661	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74019R	\N	\N
3514	661	1999-01-01 00:00:00	2001-03-27 00:00:00	ANCIEN	\N	\N	\N	95022B	\N	\N
3515	661	1999-01-01 00:00:00	2007-02-25 00:00:00	ANCIEN	\N	\N	\N	92024Q	\N	\N
3516	661	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	92029V	\N	\N
3517	661	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95002W	\N	\N
3518	661	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95045J	\N	\N
3519	661	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
3520	661	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	77047J	\N	\N
3521	661	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
2852	584	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98021N	\N	\N
2853	578	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98005N	\N	\N
2570	578	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98053W	\N	\N
2854	583	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	\N
2855	583	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
2856	583	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95019G	\N	\N
2857	583	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	65017N	\N	\N
2858	583	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
2859	583	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	96005E	\N	\N
2860	583	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
2861	583	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98038X	\N	\N
2862	583	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92030N	\N	\N
2863	583	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83046V	\N	\N
2864	583	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
2865	583	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
2866	583	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89042S	\N	\N
2867	583	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98036V	\N	\N
2868	588	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
2869	588	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	84003N	\N	\N
2870	588	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	78007E	\N	\N
2871	588	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	\N
2872	588	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83018R	\N	\N
2873	588	1999-01-01 00:00:00	2009-02-28 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
2874	588	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
2875	588	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
2876	588	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80045G	\N	\N
2877	588	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89045V	\N	\N
2878	586	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
2879	586	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	79004F	\N	\N
2880	586	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	74011H	\N	\N
2881	586	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95014B	\N	\N
2882	586	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83018R	\N	\N
2883	586	1999-01-01 00:00:00	2008-09-24 00:00:00	ANCIEN	\N	\N	\N	88004G	\N	\N
2884	586	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
2885	586	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83028T	\N	\N
2886	586	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83031N	\N	\N
2887	586	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95002W	\N	\N
2888	586	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92030N	\N	\N
2889	586	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95045J	\N	\N
2890	586	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
2891	586	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80035E	\N	\N
2892	586	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83054V	\N	\N
2893	586	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
2894	586	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
2895	589	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98036V	\N	\N
2896	589	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
2897	589	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
2898	589	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
2899	589	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
2900	589	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98006P	\N	\N
2901	589	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	74011H	\N	\N
2902	589	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92011K	\N	\N
2903	589	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	71003U	\N	\N
2904	589	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92013M	\N	\N
2905	589	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	\N
2906	589	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98049B	\N	\N
2907	589	1999-01-01 00:00:00	2001-09-03 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
2908	589	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98016R	\N	\N
2909	589	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
2910	589	1999-01-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
2911	589	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83047W	\N	\N
2912	589	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
2913	589	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80045G	\N	\N
2914	589	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86047K	\N	\N
2915	589	1999-01-01 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	98012M	\N	\N
2916	589	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
2917	589	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89045V	\N	\N
2918	589	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	90003B	\N	\N
2919	589	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
2920	589	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
2921	589	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
2922	589	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98017S	\N	\N
2923	589	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95035G	\N	\N
2924	589	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98027U	\N	\N
2925	589	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
2926	589	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
2927	589	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98043U	\N	\N
2928	589	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95002W	\N	\N
2929	589	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98051U	\N	\N
2930	589	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92030N	\N	\N
2931	589	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80024B	\N	\N
2932	589	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	68036E	\N	\N
2933	589	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
2934	589	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95051G	\N	\N
2935	589	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	91002E	\N	\N
2936	590	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83033Q	\N	\N
2937	590	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	68036E	\N	\N
2938	590	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98021N	\N	\N
2939	595	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
2940	594	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
2941	594	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
2942	594	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	78007E	\N	\N
2943	594	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92011K	\N	\N
2944	594	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
2945	594	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77012W	\N	\N
2946	594	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
2947	594	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
2948	594	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98041S	\N	\N
2949	594	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98038X	\N	\N
2950	594	1999-01-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	98025S	\N	\N
2951	594	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86037H	\N	\N
2952	594	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
2953	594	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95003X	\N	\N
2954	594	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
2955	594	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
2956	594	1999-01-01 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	98012M	\N	\N
2957	594	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
2958	594	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92045V	\N	\N
2959	594	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
2960	594	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86042E	\N	\N
2961	594	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	82002D	\N	\N
2962	596	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95004Y	\N	\N
2963	596	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92006N	\N	\N
2964	596	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83011J	\N	\N
2965	596	1999-01-01 00:00:00	2001-01-26 00:00:00	ANCIEN	\N	\N	\N	74008N	\N	\N
2966	596	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
2967	596	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	79004F	\N	\N
2968	596	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	74011H	\N	\N
2969	596	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
2970	596	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78007E	\N	\N
2971	596	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	74015M	\N	\N
2972	596	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98049B	\N	\N
2973	596	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
2974	596	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83020K	\N	\N
2975	596	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
2976	596	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
2977	596	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74019R	\N	\N
2978	596	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83023N	\N	\N
2979	596	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77017C	\N	\N
2980	596	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
2981	596	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83026R	\N	\N
2982	596	1999-01-01 00:00:00	2001-03-27 00:00:00	ANCIEN	\N	\N	\N	95022B	\N	\N
2983	596	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95023C	\N	\N
2984	596	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83028T	\N	\N
2985	596	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95029J	\N	\N
2986	596	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98045W	\N	\N
2987	596	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92021M	\N	\N
2988	596	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
2509	573	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
2512	598	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
2514	534	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
2516	573	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
2518	575	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
2372	534	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95058P	\N	\N
2374	575	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95058P	\N	\N
2379	598	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95058P	\N	\N
2387	620	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95058P	\N	\N
2395	590	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95059Q	\N	\N
2398	573	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
2401	590	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
2413	642	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	96004D	\N	2015-02-02 16:43:48
2418	642	1998-10-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	96005E	\N	\N
2421	573	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
2424	578	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
2427	642	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
2430	604	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
2434	573	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
2291	575	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95046K	\N	\N
2294	573	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95047L	\N	\N
2298	590	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95047L	\N	\N
2303	604	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95049N	\N	\N
2308	534	1998-10-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	95051G	\N	\N
2310	590	1998-10-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	95051G	\N	\N
2312	598	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95051G	\N	\N
2316	534	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
2318	575	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
2324	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95053J	\N	\N
2326	575	1998-10-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	95053J	\N	\N
2331	584	1998-10-01 00:00:00	1999-11-27 00:00:00	ANCIEN	\N	\N	\N	95054K	\N	\N
2338	598	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95056M	\N	\N
2344	574	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
2348	578	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
2190	573	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95027G	\N	\N
2192	534	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	\N
2201	604	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95029J	\N	\N
2208	578	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95031C	\N	\N
2213	595	1998-10-01 00:00:00	2002-07-17 00:00:00	ANCIEN	\N	\N	\N	95031C	\N	\N
2215	604	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95031C	\N	\N
2221	574	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95032D	\N	\N
2224	584	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95033E	\N	\N
2228	556	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	\N
2234	584	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	\N
2244	620	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	\N
2249	534	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95035G	\N	\N
2255	595	1998-10-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	95036H	\N	\N
2261	578	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95039L	\N	\N
2829	576	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98003L	\N	\N
2830	576	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83035S	\N	\N
2831	576	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95002W	\N	\N
2832	576	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98038X	\N	\N
2833	576	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	82002D	\N	\N
2834	576	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98051U	\N	\N
2835	576	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
2836	576	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77047J	\N	\N
2837	576	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
2838	576	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98013N	\N	\N
2839	576	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95051G	\N	\N
2840	576	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98002K	\N	\N
2841	576	1999-01-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	95053J	\N	\N
2842	576	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83047W	\N	\N
2843	576	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98021N	\N	\N
2844	576	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
2845	576	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98050T	\N	\N
2846	576	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
2847	576	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80039J	\N	\N
2848	576	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
2849	576	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98012M	\N	\N
2850	576	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89045V	\N	\N
2851	576	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77012W	\N	\N
3550	535	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83020K	\N	\N
3551	535	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
3552	535	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
3553	535	1999-01-01 00:00:00	2009-06-04 00:00:00	ANCIEN	\N	\N	\N	95020Y	\N	\N
3554	535	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74019R	\N	\N
3555	535	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
3565	621	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
3558	535	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92024Q	\N	\N
3559	535	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
3560	535	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95003X	\N	\N
3561	535	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
3562	535	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
3563	615	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
3567	657	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
3568	657	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
3569	657	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	84003N	\N	\N
3570	657	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	\N
3571	657	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78007E	\N	\N
3572	657	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
3573	657	1999-01-01 00:00:00	2008-09-24 00:00:00	ANCIEN	\N	\N	\N	88004G	\N	\N
3574	657	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
3575	657	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	\N
3576	657	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77017C	\N	\N
3577	657	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95025E	\N	\N
3216	616	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
3217	616	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95036H	\N	\N
3224	616	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74022L	\N	\N
3225	616	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83035S	\N	\N
3226	616	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
3227	616	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74028S	\N	\N
3228	616	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
3229	616	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83036T	\N	\N
3230	616	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
3231	616	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	68036E	\N	\N
3232	616	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
3234	616	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
3235	616	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98002K	\N	\N
3236	616	1999-01-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	95053J	\N	\N
3237	616	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
3238	616	1999-01-01 00:00:00	2000-03-18 00:00:00	ANCIEN	\N	\N	\N	88003F	\N	\N
3239	616	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80040B	\N	\N
11758	659	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
3593	625	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
3595	625	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
3596	625	1999-01-01 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	71003U	\N	\N
3597	625	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
3598	625	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89030N	\N	\N
3599	625	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
3600	625	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
3601	625	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
3602	625	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
3603	625	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98013N	\N	\N
3604	625	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
3605	625	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98002K	\N	\N
3606	625	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
3607	625	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89042S	\N	\N
3608	579	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92006N	\N	\N
3609	579	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
3610	579	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	96005E	\N	\N
3611	579	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98047Y	\N	\N
3612	579	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	97008M	\N	\N
3613	579	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77029G	\N	\N
3614	579	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83035S	\N	\N
3615	579	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83036T	\N	\N
3616	579	1999-01-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	83037U	\N	\N
3617	579	1999-01-01 00:00:00	2001-02-07 00:00:00	ANCIEN	\N	\N	\N	74024N	\N	\N
3618	579	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	85003S	\N	\N
3619	579	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
3620	579	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92032Q	\N	\N
3621	579	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86037H	\N	\N
3622	579	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95045J	\N	\N
3623	579	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83040P	\N	\N
3624	579	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74028S	\N	\N
3625	579	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
3626	579	1999-01-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
3627	579	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89042S	\N	\N
3628	629	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
3629	629	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
3630	629	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	\N
3631	629	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
3632	629	1999-01-01 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	71003U	\N	\N
3633	629	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83018R	\N	\N
3634	629	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98048A	\N	\N
3635	629	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
3636	629	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77013X	\N	\N
3637	629	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86018E	\N	\N
3638	629	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83023N	\N	\N
3639	629	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98031Q	\N	\N
3640	629	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86004X	\N	\N
3641	629	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
3642	629	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83028T	\N	\N
3643	629	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
3644	629	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98045W	\N	\N
3645	629	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95031C	\N	\N
3646	629	1999-01-01 00:00:00	1999-01-01 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
3647	629	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89029V	\N	\N
3648	629	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	\N
3649	629	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
3650	629	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98017S	\N	\N
3651	629	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
3652	629	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
3653	629	1999-01-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
3654	629	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92025R	\N	\N
3655	629	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83035S	\N	\N
3656	629	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83036T	\N	\N
3657	629	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95039L	\N	\N
3658	629	1999-01-01 00:00:00	2001-02-07 00:00:00	ANCIEN	\N	\N	\N	74024N	\N	\N
3659	629	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89004L	\N	\N
3660	629	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
3661	629	1999-01-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	86034E	\N	\N
3662	629	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98005N	\N	\N
3663	629	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	81011A	\N	\N
3664	629	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92032Q	\N	\N
3665	629	1999-01-01 00:00:00	2007-01-25 00:00:00	ANCIEN	\N	\N	\N	89006N	\N	\N
3666	629	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95045J	\N	\N
3667	629	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83040P	\N	\N
3668	629	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77046H	\N	\N
3669	629	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83044T	\N	\N
3670	629	1999-01-01 00:00:00	2009-07-23 00:00:00	ANCIEN	\N	\N	\N	95049N	\N	\N
3671	629	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
3672	629	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
3673	629	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
3674	629	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
3675	629	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92041R	\N	\N
3676	629	1999-01-01 00:00:00	2009-07-23 00:00:00	ANCIEN	\N	\N	\N	86044G	\N	\N
3677	629	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
3678	629	1999-01-01 00:00:00	2000-03-18 00:00:00	ANCIEN	\N	\N	\N	88003F	\N	\N
3679	629	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
3680	629	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83054V	\N	\N
3681	629	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80046H	\N	\N
3682	629	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92045V	\N	\N
4017	598	1999-12-01 00:00:00	2009-09-09 00:00:00	ANCIEN	\N	\N	\N	80024B	\N	\N
4018	598	1999-12-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95045J	\N	\N
4019	598	1999-12-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
4020	598	1999-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86044G	\N	\N
4021	598	1999-12-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
4022	598	1999-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83050R	\N	\N
4023	598	1999-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80040B	\N	\N
4024	598	1999-12-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80041C	\N	\N
4026	598	1998-10-01 00:00:00	1999-09-30 00:00:00	ANCIEN	\N	\N	\N	95008D	\N	\N
4030	627	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
4031	627	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	88004G	\N	\N
4033	627	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
4034	627	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
4035	627	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83028T	\N	\N
4036	627	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
4037	627	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
4038	627	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
4039	627	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
4040	627	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77047J	\N	\N
4041	627	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
4042	627	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
4043	627	1999-01-01 00:00:00	2001-10-10 00:00:00	ANCIEN	\N	\N	\N	74032N	\N	\N
4044	627	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
4045	627	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
4046	627	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95058P	\N	\N
4047	627	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80035E	\N	\N
4048	627	1999-01-01 00:00:00	2000-03-18 00:00:00	ANCIEN	\N	\N	\N	88003F	\N	\N
4049	627	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
4050	627	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83054V	\N	\N
4051	627	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80041C	\N	\N
4052	627	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
4053	627	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
4054	627	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	74015M	\N	\N
4055	642	1999-12-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92044U	\N	\N
4060	576	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92044U	\N	\N
4061	611	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74042Q	\N	\N
4058	576	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	99001N	\N	\N
4059	576	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	99002P	\N	\N
4062	604	1998-10-01 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	71003U	\N	\N
4063	578	2000-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83054V	\N	\N
4064	611	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95025E	\N	\N
4065	578	2000-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95004Y	\N	\N
4066	578	2000-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	94004U	\N	\N
4067	578	2000-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	92012L	\N	\N
4068	578	2000-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	\N
4069	590	2000-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	99001N	\N	\N
2265	595	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95039L	\N	\N
2125	584	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95013A	\N	\N
2130	578	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95014B	\N	\N
2139	578	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95015C	\N	\N
2143	595	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95016D	\N	\N
2145	575	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95017E	\N	\N
2150	584	1998-10-01 00:00:00	1999-12-05 00:00:00	ANCIEN	\N	\N	\N	95018F	\N	\N
2156	590	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95020Y	\N	\N
2161	573	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	\N
2164	575	1998-10-01 00:00:00	2001-03-27 00:00:00	ANCIEN	\N	\N	\N	95022B	\N	\N
2166	590	1998-10-01 00:00:00	2001-03-27 00:00:00	ANCIEN	\N	\N	\N	95022B	\N	\N
2168	598	1998-10-01 00:00:00	2001-03-27 00:00:00	ANCIEN	\N	\N	\N	95022B	\N	\N
2174	532	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95023C	\N	\N
2177	578	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95023C	\N	\N
2179	590	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95023C	\N	\N
2023	573	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	\N
2032	532	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	94004U	\N	\N
2036	598	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	94004U	\N	\N
2038	532	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95002W	\N	\N
2040	573	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95002W	\N	\N
2042	575	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95002W	\N	\N
2044	595	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95002W	\N	\N
2055	591	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95003X	\N	\N
2059	642	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95003X	\N	\N
2350	580	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
2187	663	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95025E	\N	\N
2195	609	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	\N
2203	611	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95030B	\N	\N
2207	576	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95031C	\N	\N
2216	609	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95031C	\N	\N
2229	571	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	\N
2246	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	\N
2253	580	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95036H	\N	\N
2259	619	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	\N
2117	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95008D	\N	\N
2124	626	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95011X	\N	\N
2135	617	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95014B	\N	\N
2141	619	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95015C	\N	\N
2149	579	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95018F	\N	\N
2155	585	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95020Y	\N	\N
2162	602	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	\N
2063	580	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95004Y	\N	\N
2073	611	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95004Y	\N	\N
2086	576	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
1968	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
1974	619	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92036U	\N	\N
1990	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
2002	580	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92042S	\N	\N
2007	626	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92043T	\N	\N
1876	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92024Q	\N	\N
1897	626	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92030N	\N	\N
1904	571	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
1918	611	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
1929	851	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
1802	609	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92006N	\N	\N
1807	619	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92007P	\N	\N
1815	589	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92010J	\N	\N
1823	579	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92012L	\N	\N
1835	625	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92017R	\N	\N
1840	605	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92020L	\N	\N
1703	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89046W	\N	\N
1727	617	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
1738	663	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
1751	588	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
1625	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89030N	\N	\N
1634	640	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89037V	\N	\N
1640	611	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89039X	\N	\N
1650	586	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89040Q	\N	\N
1658	571	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
1664	583	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
1674	624	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
1549	605	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
1556	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
1570	663	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
1575	530	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89026S	\N	\N
1581	577	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89026S	\N	\N
1586	583	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89026S	\N	\N
1594	608	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89026S	\N	\N
1470	571	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
1482	611	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
1487	627	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
1504	608	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
1510	625	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89019T	\N	\N
1358	627	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88003F	\N	\N
1363	605	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88004G	\N	\N
1371	579	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88005H	\N	\N
1378	612	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88005H	\N	\N
1381	619	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88005H	\N	\N
1387	602	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88006J	\N	\N
1398	589	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
1416	622	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
1419	583	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89004L	\N	\N
1426	583	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
1306	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86053H	\N	\N
1329	576	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88002E	\N	\N
1333	587	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88002E	\N	\N
1338	609	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88002E	\N	\N
1341	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88002E	\N	\N
1344	627	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88002E	\N	\N
1192	583	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
1202	625	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
1208	663	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
1215	579	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86042E	\N	\N
1221	589	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86042E	\N	\N
1231	611	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86042E	\N	\N
1237	626	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86042E	\N	\N
1253	579	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
1101	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
1106	587	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	\N
1113	626	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	\N
1130	626	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86018E	\N	\N
1136	602	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86021Y	\N	\N
1153	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86035F	\N	\N
1175	583	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86039K	\N	\N
1038	530	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
1047	580	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
1062	609	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
1067	625	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
1087	609	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86004X	\N	\N
1092	583	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
942	577	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83046V	\N	\N
951	608	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83046V	\N	\N
956	625	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83046V	\N	\N
966	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83047W	\N	\N
975	579	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83052T	\N	\N
979	588	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83052T	\N	\N
985	619	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83052T	\N	\N
989	627	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83052T	\N	\N
1007	530	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	84003N	\N	\N
896	580	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83035S	\N	\N
904	530	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83036T	\N	\N
915	851	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83036T	\N	\N
774	585	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83018R	\N	\N
781	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83018R	\N	\N
784	530	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83020K	\N	\N
796	577	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
810	612	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
813	619	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
818	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
825	663	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
837	609	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83023N	\N	\N
709	611	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	81011A	\N	\N
714	576	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	81014D	\N	\N
720	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	82002D	\N	\N
728	602	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83004K	\N	\N
737	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83010H	\N	\N
743	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83011J	\N	\N
748	626	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83012K	\N	\N
628	619	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80041C	\N	\N
637	583	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80045G	\N	\N
654	609	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80046H	\N	\N
661	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80046H	\N	\N
1740	573	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	90003B	\N	\N
1743	556	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
1745	574	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
1748	578	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
1752	595	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
1755	604	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
1761	642	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
1610	584	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89028U	\N	\N
1619	598	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89029V	\N	\N
1621	590	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89030N	\N	\N
1624	604	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89030N	\N	\N
1627	642	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89035T	\N	\N
1630	590	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89037V	\N	\N
1638	604	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89038W	\N	\N
1642	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89040Q	\N	\N
1645	578	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89040Q	\N	\N
1648	584	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89040Q	\N	\N
1653	591	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89040Q	\N	\N
1657	642	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89040Q	\N	\N
1673	620	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
1678	578	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89042S	\N	\N
1526	620	1998-09-30 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	\N
1531	574	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
1535	578	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
1540	584	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
1544	595	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
1548	604	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
1564	642	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
1578	573	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89026S	\N	\N
1582	578	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89026S	\N	\N
1587	584	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89026S	\N	\N
1590	598	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89026S	\N	\N
1447	574	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89009R	\N	\N
1451	573	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89010J	\N	\N
1453	598	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89010J	\N	\N
1463	598	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
1469	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
1472	574	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
1475	584	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
1478	598	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
1492	584	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
1496	573	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
1499	590	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
1501	598	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
1505	620	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
1508	590	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89019T	\N	\N
1366	642	1998-10-01 00:00:00	2008-09-24 00:00:00	ANCIEN	\N	\N	\N	88004G	\N	\N
1372	582	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88005H	\N	\N
1375	590	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88005H	\N	\N
1390	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
1394	578	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
1399	590	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
1405	642	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
1412	578	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
1414	598	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
1422	534	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
1427	584	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
1292	595	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
1295	604	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
1305	582	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86053H	\N	\N
1308	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
1311	578	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
1315	590	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
1317	598	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
1324	620	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
1330	578	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88002E	\N	\N
1345	642	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	88002E	\N	\N
1181	620	1998-10-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	86039K	\N	\N
1187	574	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
1193	584	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
1195	595	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
1210	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86042E	\N	\N
1212	575	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86042E	\N	\N
1217	582	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86042E	\N	\N
1222	590	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86042E	\N	\N
1227	604	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86042E	\N	\N
1240	584	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86047K	\N	\N
1242	604	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86047K	\N	\N
1246	534	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
1248	573	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
11760	659	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01045S	\N	\N
1252	578	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
1257	590	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
1259	595	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
1108	598	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	\N
1114	642	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	\N
1118	598	1998-10-01 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	86014A	\N	\N
1121	620	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86014A	\N	\N
1123	556	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86018E	\N	\N
1127	598	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86018E	\N	\N
1134	575	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86021Y	\N	\N
1138	575	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86025D	\N	\N
1143	598	1998-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
1145	532	1998-10-01 00:00:00	2003-11-04 00:00:00	ANCIEN	\N	\N	\N	86031B	\N	\N
1147	604	1998-10-01 00:00:00	2003-11-04 00:00:00	ANCIEN	\N	\N	\N	86031B	\N	\N
1151	598	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86034E	\N	\N
1154	573	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86037H	\N	\N
1162	590	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86037H	\N	\N
1166	604	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86037H	\N	\N
1172	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86039K	\N	\N
1174	575	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	86039K	\N	\N
1023	556	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
1027	578	1998-10-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
1029	595	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
1039	534	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
1041	573	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
1043	575	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
1050	584	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
1056	598	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
1066	620	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
1073	584	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	85003S	\N	\N
1076	595	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	85003S	\N	\N
1079	604	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	85003S	\N	\N
1089	556	1998-09-30 00:00:00	1992-09-26 00:00:00	ANCIEN	\N	\N	\N	86005Y	\N	\N
1093	595	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
954	620	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83046V	\N	\N
964	578	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83047W	\N	\N
968	604	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83050R	\N	\N
972	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83052T	\N	\N
978	584	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83052T	\N	\N
981	598	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83052T	\N	\N
986	620	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83052T	\N	\N
994	574	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83054V	\N	\N
997	584	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83054V	\N	\N
999	598	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83054V	\N	\N
848	595	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83026R	\N	\N
854	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83028T	\N	\N
856	574	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83028T	\N	\N
860	590	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83028T	\N	\N
862	598	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83028T	\N	\N
875	642	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83028T	\N	\N
880	573	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83031N	\N	\N
885	598	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83031N	\N	\N
891	532	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83033Q	\N	\N
893	604	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83033Q	\N	\N
897	584	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83035S	\N	\N
905	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83036T	\N	\N
910	604	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83036T	\N	\N
918	595	1998-10-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	83037U	\N	\N
922	620	1998-10-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	83037U	\N	\N
773	584	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83018R	\N	\N
785	532	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83020K	\N	\N
789	598	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83020K	\N	\N
792	573	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
794	575	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
803	590	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
805	598	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
814	620	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
826	534	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83023N	\N	\N
832	590	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83023N	\N	\N
834	598	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83023N	\N	\N
840	574	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83025Q	\N	\N
695	620	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	81010Y	\N	\N
704	584	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	81011A	\N	\N
707	604	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	81011A	\N	\N
716	582	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	82002D	\N	\N
732	590	1998-10-01 00:00:00	2001-03-02 00:00:00	ANCIEN	\N	\N	\N	83008P	\N	\N
734	642	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83008P	\N	\N
736	595	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83010H	\N	\N
3976	618	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80035E	\N	\N
3978	618	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83052T	\N	\N
3980	618	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
3982	618	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
3954	618	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	\N
3956	618	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
3958	618	1999-01-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	95036H	\N	\N
3960	618	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95039L	\N	\N
3962	618	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95002W	\N	\N
3964	618	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98051U	\N	\N
3966	618	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74028S	\N	\N
3967	618	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
3969	618	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
3971	618	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
3973	618	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83047W	\N	\N
3975	618	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95058P	\N	\N
3977	618	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98033S	\N	\N
3979	618	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83054V	\N	\N
3981	618	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
3985	592	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98049B	\N	\N
3986	592	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
3988	617	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	92044U	\N	\N
3989	621	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	\N
3995	643	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92044U	\N	\N
3996	584	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92044U	\N	\N
3994	621	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	95040D	\N	\N
4000	651	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
4029	627	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92010J	\N	\N
4001	651	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92044U	\N	\N
4002	598	1999-12-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89013M	\N	\N
4003	598	1999-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95013A	\N	\N
4004	598	1999-12-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86018E	\N	\N
4005	598	1999-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
4006	598	1999-12-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86004X	\N	\N
4007	598	1999-12-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83025Q	\N	\N
4008	598	1999-12-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	81007E	\N	\N
4009	598	1999-12-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92019T	\N	\N
4010	598	1999-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
4028	627	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	74011H	\N	\N
4012	598	1999-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	\N
4013	598	1999-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
4014	598	1999-12-01 00:00:00	2001-02-07 00:00:00	ANCIEN	\N	\N	\N	74024N	\N	\N
4015	598	1999-12-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	85003S	\N	\N
4016	598	1999-12-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	98043U	\N	\N
298	608	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77058M	\N	\N
301	626	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77058M	\N	\N
314	571	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
335	530	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
186	576	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
203	617	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
224	646	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77012W	\N	\N
255	576	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77044F	\N	\N
39	626	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	70001N	\N	\N
50	580	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	71009B	\N	\N
55	579	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	71017B	\N	\N
63	608	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	71017B	\N	\N
66	619	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	71024A	\N	\N
80	618	1998-09-30 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	74011H	\N	\N
129	617	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	74022L	\N	\N
132	583	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	74024N	\N	\N
141	663	1998-10-01 00:00:00	2001-02-07 00:00:00	ANCIEN	\N	\N	\N	74024N	\N	\N
147	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	74028S	\N	\N
3702	622	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	81007E	\N	\N
3703	622	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
3704	622	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83028T	\N	\N
3705	622	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	\N
3706	622	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
3707	622	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92021M	\N	\N
3708	622	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83031N	\N	\N
3709	622	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
3710	622	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98053W	\N	\N
3711	622	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	\N
3712	622	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
3713	622	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	\N
3714	622	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74022L	\N	\N
3715	622	1999-01-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	83037U	\N	\N
3716	622	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95002W	\N	\N
3717	622	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	82002D	\N	\N
3718	622	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98051U	\N	\N
3719	622	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
3720	622	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77044F	\N	\N
3721	622	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74028S	\N	\N
3722	622	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
3723	622	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95003X	\N	\N
3724	622	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77047J	\N	\N
3725	622	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83044T	\N	\N
3726	622	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	68036E	\N	\N
3727	622	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
3728	622	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
3729	622	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
3730	622	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98002K	\N	\N
3731	622	1999-01-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
3732	622	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
3733	622	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95056M	\N	\N
3734	622	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
3735	622	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80035E	\N	\N
3736	622	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77060F	\N	\N
3737	622	1999-01-01 00:00:00	2000-03-18 00:00:00	ANCIEN	\N	\N	\N	88003F	\N	\N
3738	622	1999-01-01 00:00:00	2001-09-20 00:00:00	ANCIEN	\N	\N	\N	94002S	\N	\N
3739	622	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80039J	\N	\N
3740	622	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83054V	\N	\N
3741	622	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80045G	\N	\N
3742	622	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86047K	\N	\N
3743	622	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
3744	622	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80046H	\N	\N
3745	622	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
3746	599	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
3747	601	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92006N	\N	\N
3749	601	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	79004F	\N	\N
3750	601	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83016P	\N	\N
3751	601	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98049B	\N	\N
3752	601	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98016R	\N	\N
75	595	1998-10-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	74011H	\N	\N
88	604	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74013K	\N	\N
116	604	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74019R	\N	\N
128	604	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74022L	\N	\N
135	598	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	74024N	\N	\N
143	574	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74028S	\N	\N
146	604	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74028S	\N	\N
150	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	74032N	\N	\N
156	590	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	74032N	\N	\N
159	604	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74032N	\N	\N
172	595	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74042Q	\N	\N
174	556	1998-09-30 00:00:00	1998-02-09 00:00:00	ANCIEN	\N	\N	\N	74044S	\N	\N
3533	620	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	98053W	\N	\N
2439	576	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
2452	576	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
2468	663	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98003L	\N	\N
2396	583	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95061J	\N	\N
2405	580	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95068R	\N	\N
2408	613	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95068R	\N	\N
2412	624	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	96004D	\N	2015-02-02 16:43:40
2426	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
2285	583	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95045J	\N	\N
2302	589	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95048M	\N	\N
2307	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95050F	\N	\N
2335	583	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95055L	\N	\N
2339	609	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95056M	\N	\N
3753	601	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
3754	601	1999-01-01 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	86014A	\N	\N
3760	601	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86004X	\N	\N
3783	601	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
3757	601	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
3759	601	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92016Q	\N	\N
3761	601	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
3762	601	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
3763	601	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95037J	\N	\N
3764	601	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92027T	\N	\N
3765	601	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
3766	601	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95002W	\N	\N
3767	601	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	81011A	\N	\N
3768	601	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80024B	\N	\N
3769	601	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
3770	601	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	68036E	\N	\N
3771	601	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83046V	\N	\N
3772	601	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95051G	\N	\N
3773	601	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	91002E	\N	\N
3774	601	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
741	598	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83011J	\N	\N
744	598	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83012K	\N	\N
750	642	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83012K	\N	\N
754	584	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	83016P	\N	\N
757	595	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83016P	\N	\N
608	598	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80039J	\N	\N
613	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80040B	\N	\N
617	590	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80040B	\N	\N
631	575	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80043E	\N	\N
633	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80045G	\N	\N
635	574	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80045G	\N	\N
639	590	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80045G	\N	\N
644	532	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80046H	\N	\N
646	573	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80046H	\N	\N
649	584	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80046H	\N	\N
651	598	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80046H	\N	\N
665	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80048K	\N	\N
669	590	1998-10-01 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	80048K	\N	\N
672	604	1998-10-01 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	80048K	\N	\N
533	642	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
539	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
543	582	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
547	595	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
567	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80035E	\N	\N
569	574	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80035E	\N	\N
573	584	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80035E	\N	\N
576	598	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80035E	\N	\N
498	642	1998-10-01 00:00:00	2008-09-07 00:00:00	ANCIEN	\N	\N	\N	80017C	\N	\N
502	574	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80024B	\N	\N
387	584	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	79004F	\N	\N
393	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	79005G	\N	\N
397	582	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	79005G	\N	\N
419	642	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80002U	\N	\N
275	578	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77047J	\N	\N
278	598	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77047J	\N	\N
288	575	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77058M	\N	\N
291	582	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77058M	\N	\N
294	590	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77058M	\N	\N
296	598	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77058M	\N	\N
303	590	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77060F	\N	\N
308	604	1998-10-01 00:00:00	1999-11-30 00:00:00	ANCIEN	\N	\N	\N	77066M	\N	\N
310	642	1998-10-01 00:00:00	1999-11-01 00:00:00	ANCIEN	\N	\N	\N	77066M	\N	\N
313	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
317	578	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
322	590	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
324	598	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
333	642	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
337	573	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
340	584	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
185	574	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
189	582	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
193	590	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
197	604	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
212	598	1998-10-01 00:00:00	2002-09-30 00:00:00	ANCIEN	\N	\N	\N	77009C	\N	\N
215	575	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77012W	\N	\N
217	598	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77012W	\N	\N
226	590	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77013X	\N	\N
230	573	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77017C	\N	\N
232	575	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77017C	\N	\N
234	590	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77017C	\N	\N
236	604	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77017C	\N	\N
238	642	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77017C	\N	\N
240	590	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77019E	\N	\N
242	590	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77029G	\N	\N
244	598	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77029G	\N	\N
247	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77033C	\N	\N
250	620	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77043E	\N	\N
256	582	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77044F	\N	\N
23	642	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	69001W	\N	\N
30	584	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	70001N	\N	\N
33	598	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	70001N	\N	\N
38	620	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	70001N	\N	\N
45	604	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	71003U	\N	\N
49	578	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	71009B	\N	\N
54	556	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	71017B	\N	\N
60	598	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	71017B	\N	\N
67	590	1998-10-01 00:00:00	2001-01-26 00:00:00	ANCIEN	\N	\N	\N	74008N	\N	\N
69	534	1998-10-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	74011H	\N	\N
71	573	1998-10-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	74011H	\N	\N
2066	590	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	95004Y	\N	\N
2070	604	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95004Y	\N	\N
2080	534	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95005A	\N	\N
2083	534	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
2085	574	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
2090	582	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
2093	595	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
2097	604	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
1943	584	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
1946	591	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
1950	604	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
1963	598	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
1975	532	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
1978	573	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
1980	575	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
1983	590	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
1988	620	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
1994	590	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
1998	620	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
2008	578	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92045V	\N	\N
2011	598	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92045V	\N	\N
1882	595	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92026S	\N	\N
1885	591	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92027T	\N	\N
1887	574	0098-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92029V	\N	\N
3207	616	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
3209	616	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83023N	\N	\N
3210	616	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95025E	\N	\N
3211	616	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
3212	616	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83028T	\N	\N
3213	616	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98047Y	\N	\N
3214	616	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	\N
3215	616	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	\N
4621	648	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
4622	648	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80035E	\N	\N
4625	633	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
4626	633	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01046T	\N	\N
4627	633	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83031N	\N	\N
4628	633	2001-10-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	98043U	\N	\N
4629	633	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
4630	633	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98046X	\N	\N
4631	633	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
4632	633	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
4633	633	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80040B	\N	\N
4634	633	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
4635	585	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
4636	585	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01051Q	\N	\N
4637	585	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88004G	\N	\N
4638	585	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95020Y	\N	\N
4639	585	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
4640	585	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
4641	585	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
4642	585	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
4643	585	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
4644	585	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
4645	585	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77060F	\N	\N
4646	585	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
4647	585	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01023L	\N	\N
4649	642	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
4650	642	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97009N	\N	\N
4651	642	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
4652	642	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98048A	\N	\N
4653	642	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95019G	\N	\N
4654	642	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
4655	642	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92024Q	\N	\N
4656	642	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01007L	\N	\N
4657	642	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
4658	642	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95043G	\N	\N
4659	642	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
4660	642	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83042R	\N	\N
4661	642	2001-10-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	95051G	\N	\N
4662	642	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77060F	\N	\N
4663	642	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92043T	\N	\N
4664	642	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01062T	\N	\N
4665	642	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01010F	\N	\N
4666	642	2001-10-01 00:00:00	2004-07-19 00:00:00	ANCIEN	\N	\N	\N	95066P	\N	\N
4667	591	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	97009N	\N	\N
4668	591	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
4669	591	2001-10-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	92029V	\N	\N
4670	591	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86037H	\N	\N
4671	591	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
4672	591	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83042R	\N	\N
4673	591	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77047J	\N	\N
4674	591	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
4675	591	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
4676	591	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
4677	591	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98039Y	\N	\N
4678	591	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77060F	\N	\N
4679	591	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80040B	\N	\N
4681	595	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
4682	595	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
4683	595	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
4684	595	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95006B	\N	\N
4685	595	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	\N
4686	595	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92008Q	\N	\N
4687	595	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95026F	\N	\N
4688	595	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	99003Q	\N	\N
4689	595	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77019E	\N	\N
4690	595	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92024Q	\N	\N
4691	595	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	88009M	\N	\N
4692	595	2001-10-01 00:00:00	2007-06-24 00:00:00	ANCIEN	\N	\N	\N	99004R	\N	\N
4693	595	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
4694	595	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
4700	595	2001-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98002K	\N	\N
4222	571	2000-11-10 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
4223	571	2000-11-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86018E	\N	\N
4224	571	2000-11-10 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74019R	\N	\N
4225	571	2000-11-10 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95025E	\N	\N
4226	571	2000-11-10 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
4227	571	2000-11-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
4228	571	2000-11-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	\N
4229	571	2000-11-10 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
4230	571	2000-11-10 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
4231	571	2000-11-10 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
4232	571	2000-11-10 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
4233	571	2000-11-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
4234	571	2000-11-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77047J	\N	\N
4235	571	2000-11-10 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	68036E	\N	\N
4236	571	2000-11-10 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
4237	571	2000-11-10 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83046V	\N	\N
4238	571	2000-11-10 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74032N	\N	\N
4239	571	2000-11-10 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
4240	571	2000-11-10 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	95053J	\N	\N
4241	571	2000-11-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89016Q	\N	\N
4242	571	2000-11-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
4243	571	2000-11-10 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86043F	\N	\N
4244	571	2000-11-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
4245	571	2000-11-10 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
4246	642	2000-10-03 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92020L	\N	\N
4247	591	2000-10-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
4248	629	2000-10-08 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	92029V	\N	\N
4249	629	2000-12-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	00004D	\N	\N
4250	629	2000-12-06 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	94004U	\N	\N
4251	626	2000-11-28 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83026R	\N	\N
4252	626	2000-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89040Q	\N	\N
4253	582	2000-12-18 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83018R	\N	\N
4254	595	2000-12-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97009N	\N	\N
4255	601	2000-12-14 00:00:00	2001-06-30 00:00:00	ANCIEN	\N	\N	\N	97009N	\N	\N
4256	643	2000-12-14 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	97009N	\N	\N
4257	620	2000-12-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97009N	\N	\N
4258	609	2000-11-30 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
4259	609	2000-11-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
4260	609	2000-11-28 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77013X	\N	\N
4261	556	2000-12-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	\N
4262	657	2001-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
4264	641	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83010H	\N	\N
4265	641	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
4266	641	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
4267	641	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	79004F	\N	\N
4268	641	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83018R	\N	\N
4269	641	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
4303	610	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	99001N	\N	\N
4271	641	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95017E	\N	\N
4272	641	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74019R	\N	\N
4273	641	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
4274	641	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
4276	641	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89029V	\N	\N
4277	641	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	\N
4278	641	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92024Q	\N	\N
4279	641	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95035G	\N	\N
4280	641	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83036T	\N	\N
4281	641	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	85003S	\N	\N
4282	641	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
4283	641	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95002W	\N	\N
4284	641	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
4285	641	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	82002D	\N	\N
4286	641	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
4287	641	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
4288	641	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95003X	\N	\N
4289	641	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
4291	641	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83046V	\N	\N
4292	641	1998-10-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	95051G	\N	\N
4293	641	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
4294	641	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
4295	641	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
4296	641	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
4297	641	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
4298	641	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80041C	\N	\N
4299	641	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
4300	641	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89045V	\N	\N
11761	644	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
4301	641	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
4302	610	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80017C	\N	\N
4304	610	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
4305	610	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
4306	610	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
4307	610	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80041C	\N	\N
4308	610	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
4309	610	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
4400	610	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
4401	610	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	\N
4402	610	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
4404	610	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89016Q	\N	\N
4405	610	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83046V	\N	\N
4406	610	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
4407	610	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89004L	\N	\N
4408	610	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77029G	\N	\N
4409	610	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
4410	610	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95029J	\N	\N
4411	610	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
4412	610	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	00003C	\N	\N
4413	610	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
4414	610	1998-10-01 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	71003U	\N	\N
4415	610	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
4417	610	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95005A	\N	\N
4419	624	2001-05-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95066P	\N	\N
4424	647	2001-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
4421	595	2001-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01001E	\N	\N
4423	620	2001-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92008Q	\N	\N
4425	647	2001-05-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
4426	647	2001-05-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	74011H	\N	\N
4427	647	2001-05-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
4428	647	2001-05-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98048A	\N	\N
4429	647	2001-05-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95025E	\N	\N
4431	647	2001-05-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92020L	\N	\N
4432	647	2001-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	\N
4434	647	2001-05-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
4435	647	2001-05-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
4436	647	2001-05-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
4437	647	2001-05-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83035S	\N	\N
5126	629	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83050R	\N	\N
5127	629	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01052R	\N	\N
5128	629	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95004Y	\N	\N
5129	629	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01006K	\N	\N
5130	629	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	\N
5131	629	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89010J	\N	\N
5132	629	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
5133	629	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	88009M	\N	\N
5134	629	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
5135	629	2001-10-01 00:00:00	2003-11-04 00:00:00	ANCIEN	\N	\N	\N	86031B	\N	\N
5136	629	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	\N
5137	629	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01042P	\N	\N
5138	629	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	93007T	\N	\N
5139	629	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
5140	629	2001-10-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	95051G	\N	\N
5141	629	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01054T	\N	\N
5142	629	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01009N	\N	\N
5143	629	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
5144	629	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
5145	629	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98050T	\N	\N
5146	629	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01029S	\N	\N
5147	629	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01058X	\N	\N
5148	629	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80041C	\N	\N
5149	629	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
5150	629	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
5151	629	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01047U	\N	\N
5152	596	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
5153	596	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
5154	596	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
5155	596	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88004G	\N	\N
5156	596	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77012W	\N	\N
5157	596	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
5158	596	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01041N	\N	\N
5159	596	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01027Q	\N	\N
5160	596	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
5161	596	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83031N	\N	\N
5162	596	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01055U	\N	\N
5163	596	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98017S	\N	\N
5164	596	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98022P	\N	\N
4195	634	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77043E	\N	\N
4197	634	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83040P	\N	\N
4198	634	2000-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
4199	634	2000-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
4200	634	2000-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
4201	634	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83046V	\N	\N
4202	634	2000-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
4203	634	2000-11-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	95051G	\N	\N
4204	634	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	91002E	\N	\N
4205	634	2000-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
4206	634	2000-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
4207	634	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
4208	634	2000-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
4209	634	2000-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89037V	\N	\N
4210	634	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
4211	634	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80041C	\N	\N
4212	634	2000-11-01 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	98012M	\N	\N
4213	634	2000-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
4214	634	2000-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92045V	\N	\N
4215	657	2000-11-01 00:00:00	2001-09-10 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
4216	571	2000-11-10 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
4217	571	2000-11-10 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
4218	571	2000-11-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
4219	571	2000-11-10 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	88004G	\N	\N
4220	571	2000-11-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
4221	571	2000-11-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
4701	595	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01009N	\N	\N
4702	595	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
4703	595	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01028R	\N	\N
4705	595	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01006K	\N	\N
4814	626	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01014K	\N	\N
4816	626	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01029S	\N	\N
4817	626	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01058X	\N	\N
4818	626	2001-10-01 00:00:00	2004-07-19 00:00:00	ANCIEN	\N	\N	\N	96003C	\N	\N
4819	608	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	\N
4820	608	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
4821	608	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	00001A	\N	\N
4822	608	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01058X	\N	\N
4823	608	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88009M	\N	\N
4824	608	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77029G	\N	\N
4825	608	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
4826	608	2001-10-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	92029V	\N	\N
4827	608	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
4828	608	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95024D	\N	\N
4829	608	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
4830	608	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01028R	\N	\N
4831	608	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92020L	\N	\N
4832	608	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
4833	608	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
4834	608	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	79004F	\N	\N
4835	608	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
4836	608	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83033Q	\N	\N
4837	608	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95023C	\N	\N
4707	616	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77012W	\N	\N
4708	616	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83031N	\N	\N
4709	616	2001-10-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	96005E	\N	\N
4710	616	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
4711	616	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77029G	\N	\N
4712	616	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	85003S	\N	\N
4713	616	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
4714	616	2001-10-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	92029V	\N	\N
4715	616	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
4716	616	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
4717	616	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
4718	616	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
4719	616	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
4720	616	2001-10-01 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	01039U	\N	\N
4722	616	2001-10-01 00:00:00	2004-10-15 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
153	580	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	74032N	\N	\N
167	627	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	74032N	\N	\N
3831	604	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
3832	615	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	\N
3833	661	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
3834	661	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
3835	661	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	92011K	\N	\N
3836	661	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
3837	661	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
3838	661	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
3839	661	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
3840	661	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
3841	661	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
3842	661	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
3843	661	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	98003L	\N	\N
3844	661	1999-01-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	83037U	\N	\N
3845	661	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
3846	661	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	97006K	\N	\N
3847	661	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
3848	661	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
3849	661	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
3850	661	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
3851	661	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	98039Y	\N	\N
3852	661	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
3853	661	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	89045V	\N	\N
2077	625	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95004Y	\N	\N
2105	625	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
207	625	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
119	625	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74019R	\N	\N
721	625	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	82002D	\N	\N
1693	602	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89045V	\N	\N
3855	600	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	\N
1667	598	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
3857	591	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
3858	581	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95004Y	\N	\N
3859	581	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
3860	581	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89019T	\N	\N
3861	581	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
3862	581	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83020K	\N	\N
3863	581	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77013X	\N	\N
3864	581	1999-01-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	98031Q	\N	\N
3865	581	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83023N	\N	\N
3866	581	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98039Y	\N	\N
3867	581	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
3868	581	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
3869	581	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83026R	\N	\N
3870	581	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77043E	\N	\N
3871	581	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
3872	581	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
3873	581	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95030B	\N	\N
3874	581	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92021M	\N	\N
3875	581	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
3876	581	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	\N
3877	581	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
3878	581	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92025R	\N	\N
4485	648	2000-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
4486	648	2000-06-20 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
4488	648	2000-06-06 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
4489	595	2001-06-07 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
4490	657	2001-10-06 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
4491	623	2001-05-31 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83054V	\N	\N
4492	576	2001-05-15 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	01001E	\N	\N
4493	576	2001-05-15 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
4494	647	2001-04-26 00:00:00	2007-02-25 00:00:00	ANCIEN	\N	\N	\N	92024Q	\N	\N
4495	647	2001-04-22 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	98043U	\N	\N
4496	595	2001-06-26 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01004H	\N	\N
4497	573	2001-06-26 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01004H	\N	\N
4498	609	2001-07-19 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80046H	\N	\N
4499	597	2000-12-12 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95004Y	\N	\N
4500	597	2000-12-12 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98036V	\N	\N
4501	597	2000-12-19 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
4502	597	2000-12-18 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
4503	597	2000-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	79004F	\N	\N
4504	597	2000-12-15 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92009R	\N	\N
492	624	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80014Y	\N	\N
4505	597	2000-12-15 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
4510	597	2000-12-20 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98016R	\N	\N
4507	597	2000-12-15 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	78007E	\N	\N
4508	597	2000-12-12 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92011K	\N	\N
3879	581	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	85003S	\N	\N
3880	581	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
3881	581	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	81011A	\N	\N
3882	581	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
3883	581	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	68036E	\N	\N
3884	581	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
3885	581	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83046V	\N	\N
3886	581	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
3887	581	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98021N	\N	\N
3888	581	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
3889	581	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
3890	581	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80048K	\N	\N
3891	622	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98005N	\N	\N
1669	605	1998-09-30 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
3893	851	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	74011H	\N	\N
3894	851	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88004G	\N	\N
3895	851	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74019R	\N	\N
3896	851	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
3897	851	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
3898	851	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
3899	851	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	89040Q	\N	\N
87	663	1998-10-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	74011H	\N	\N
1814	663	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92009R	\N	\N
2136	663	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95014B	\N	\N
2419	663	1998-10-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	96005E	\N	\N
1900	663	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92030N	\N	\N
536	663	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
1960	663	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
2301	663	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95047L	\N	\N
2494	663	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98013N	\N	\N
1326	663	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
1008	556	1998-10-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	84003N	\N	\N
3900	607	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
3904	629	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	\N
3903	607	1999-01-01 00:00:00	2003-06-17 00:00:00	ANCIEN	\N	\N	\N	80046H	\N	\N
3907	592	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
3906	621	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	96004D	\N	2015-02-02 16:43:25
3908	592	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78007E	\N	\N
3909	592	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83018R	\N	\N
3910	592	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
3911	592	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98048A	\N	\N
3912	592	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
3913	592	1999-01-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	98031Q	\N	\N
3914	592	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83025Q	\N	\N
3915	592	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
3916	592	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	96005E	\N	\N
3917	592	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98047Y	\N	\N
3918	592	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	\N
3920	592	1999-01-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	86034E	\N	\N
3921	592	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
3922	592	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
3923	592	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
3924	592	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
3925	592	1999-01-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	95051G	\N	\N
3926	592	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
3927	592	1999-01-01 00:00:00	2001-10-14 00:00:00	ANCIEN	\N	\N	\N	89009R	\N	\N
3928	592	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
3929	592	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80048K	\N	\N
3931	598	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83003J	\N	\N
3932	618	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83011J	\N	\N
3933	618	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92006N	\N	\N
3934	618	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
3935	618	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
3936	618	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
3937	618	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	79004F	\N	\N
3938	618	1999-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	74011H	\N	\N
3939	618	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92009R	\N	\N
3940	618	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	\N
3941	618	1999-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	74015M	\N	\N
3942	618	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
3943	618	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77012W	\N	\N
3944	618	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
3945	618	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77017C	\N	\N
3947	618	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92019T	\N	\N
3948	618	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
3949	618	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
3950	618	1999-01-01 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	92022N	\N	\N
3951	618	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
3952	618	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83033Q	\N	\N
3953	618	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98047Y	\N	\N
3955	618	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98017S	\N	\N
3957	618	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
3959	618	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83035S	\N	\N
3961	618	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	85003S	\N	\N
3963	618	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92030N	\N	\N
3965	618	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92033R	\N	\N
3968	618	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
3970	618	1999-01-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	95051G	\N	\N
3972	618	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98002K	\N	\N
3974	618	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
4483	648	2000-11-28 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80039J	\N	\N
4484	648	2000-06-20 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	98012M	\N	\N
4095	585	2000-03-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	\N
3919	592	1999-01-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	83037U	\N	\N
3460	643	1999-01-01 00:00:00	2000-04-28 00:00:00	ANCIEN	\N	\N	\N	83037U	\N	\N
4097	592	2000-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	74011H	\N	\N
4098	592	2000-01-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	92012L	\N	\N
4099	592	2000-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
4100	592	2000-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83023N	\N	\N
4101	592	2000-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
4102	592	2000-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	81007E	\N	\N
4103	592	2000-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	99001N	\N	\N
4104	592	2000-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
4107	592	2000-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89030N	\N	\N
4108	592	2000-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92026S	\N	\N
4109	592	2000-01-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	98043U	\N	\N
4110	592	2000-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	81011A	\N	\N
4111	592	2000-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80024B	\N	\N
4112	592	2000-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83046V	\N	\N
4113	592	2000-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89016Q	\N	\N
4114	592	2000-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
4115	629	2000-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98039Y	\N	\N
4116	598	2000-05-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	98025S	\N	\N
4117	629	2000-05-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83031N	\N	\N
4118	627	2000-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78007E	\N	\N
4119	556	2000-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
4120	629	2000-08-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
4122	625	2000-09-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	00002B	\N	\N
4123	633	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
4124	633	2000-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
4125	633	2000-11-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	74011H	\N	\N
4126	633	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
4127	633	2000-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
4128	633	2000-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77012W	\N	\N
4129	633	2000-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
4130	633	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
4131	633	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	99001N	\N	\N
4132	633	2000-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
4133	633	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
4134	633	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
4135	633	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80024B	\N	\N
4137	633	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
4138	633	2000-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
4139	633	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
4140	633	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
4141	633	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
4142	633	2000-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92044U	\N	\N
4143	534	2000-10-20 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
4144	634	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98036V	\N	\N
4145	634	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95006B	\N	\N
4146	634	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
4147	634	2000-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
4148	634	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	\N
4149	634	2000-11-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	84003N	\N	\N
4150	634	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	\N
4151	634	2000-11-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	74011H	\N	\N
4152	634	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89019T	\N	\N
4153	634	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92010J	\N	\N
4154	634	2000-11-01 00:00:00	1992-09-26 00:00:00	ANCIEN	\N	\N	\N	86005Y	\N	\N
4156	634	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95014B	\N	\N
4157	634	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83018R	\N	\N
4158	634	2000-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
4159	634	2000-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95013A	\N	\N
4160	634	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
4161	634	2000-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98048A	\N	\N
4163	634	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
4164	634	2000-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95017E	\N	\N
4165	634	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86018E	\N	\N
4167	634	2000-11-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	98031Q	\N	\N
4168	634	2000-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
4169	634	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
4170	634	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95024D	\N	\N
4171	634	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95025E	\N	\N
4172	634	2000-11-01 00:00:00	2002-01-19 00:00:00	ANCIEN	\N	\N	\N	97007L	\N	\N
4173	634	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92019T	\N	\N
4174	634	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	65017N	\N	\N
4175	634	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	\N
4176	634	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
4177	634	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
4178	634	2000-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
4179	634	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98045W	\N	\N
4180	634	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
4181	634	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98017S	\N	\N
4182	634	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95036H	\N	\N
4183	634	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98003L	\N	\N
4184	634	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
4185	634	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74022L	\N	\N
4186	634	2000-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	\N
4187	634	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83036T	\N	\N
4188	634	2000-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95040D	\N	\N
4189	634	2000-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
4190	634	2000-11-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	98043U	\N	\N
4191	634	2000-11-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95002W	\N	\N
4192	634	2000-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
4193	634	2000-11-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	98025S	\N	\N
4194	634	2000-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95045J	\N	\N
1892	578	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92030N	\N	\N
1902	534	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
1905	573	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
1912	590	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
1922	620	1998-10-01 00:00:00	2002-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
1930	598	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92032Q	\N	\N
1769	598	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	91002E	\N	\N
1777	578	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
1781	604	1998-10-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
1787	573	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92006N	\N	\N
1791	584	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92006N	\N	\N
1796	591	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92006N	\N	\N
1798	598	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92006N	\N	\N
1804	620	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92006N	\N	\N
1809	620	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92008Q	\N	\N
1816	598	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92010J	\N	\N
1820	595	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92011K	\N	\N
1831	575	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92016Q	\N	\N
1837	575	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92019T	\N	\N
1842	556	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92021M	\N	\N
1844	574	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	92021M	\N	\N
1705	534	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
1708	574	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
1712	582	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
1719	595	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
1729	620	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
525	587	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
532	627	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
546	587	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
552	609	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
560	627	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
566	851	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
586	663	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80035E	\N	\N
469	608	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80011V	\N	\N
472	625	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80011V	\N	\N
478	580	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80014Y	\N	\N
483	587	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80014Y	\N	\N
489	612	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80014Y	\N	\N
500	602	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80021X	\N	\N
384	641	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	78010Y	\N	\N
391	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	79004F	\N	\N
396	580	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	79005G	\N	\N
403	624	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	79005G	\N	\N
407	644	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	79005G	\N	\N
412	588	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80002U	\N	\N
415	618	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80002U	\N	\N
418	626	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	80002U	\N	\N
280	619	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77047J	\N	\N
286	851	1998-09-30 00:00:00	1998-09-30 00:00:00	ANCIEN	\N	\N	\N	77047J	\N	\N
4438	647	2001-05-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86037H	\N	\N
4439	647	2001-05-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	93007T	\N	\N
4440	647	2001-05-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	91002E	\N	\N
4441	647	2001-05-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
4442	647	2001-05-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
4443	647	2001-05-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95055L	\N	\N
4444	647	2001-05-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
4445	647	2001-05-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80041C	\N	\N
4446	647	2001-05-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
4447	647	2001-05-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80048K	\N	\N
4449	647	2001-05-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
4450	647	2001-05-01 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	89045V	\N	\N
4454	627	2001-05-29 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80040B	\N	\N
4455	648	2000-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
4456	648	2000-06-27 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83012K	\N	\N
4457	648	2000-07-04 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	79004F	\N	\N
4458	648	2000-06-21 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	74011H	\N	\N
4459	648	2000-06-26 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98049B	\N	\N
4460	648	2000-06-12 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98048A	\N	\N
4461	648	2000-06-20 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98029W	\N	\N
4463	648	2000-12-22 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	77012W	\N	\N
4464	648	2000-11-28 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	99002P	\N	\N
4465	648	2000-12-06 00:00:00	2002-01-19 00:00:00	ANCIEN	\N	\N	\N	97007L	\N	\N
4466	648	2000-11-27 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92019T	\N	\N
4467	648	2001-11-28 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	\N
4468	648	2000-11-28 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	\N
4469	648	2000-12-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
4470	648	2000-06-22 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
4471	648	2000-06-26 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
4472	648	2000-06-30 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80024B	\N	\N
4473	648	2000-12-07 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95045J	\N	\N
4474	648	2000-11-28 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83040P	\N	\N
4475	648	2000-12-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
4476	648	2000-06-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
4477	648	2000-06-26 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
4478	648	2000-06-26 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
4479	648	2000-11-28 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
4480	648	2000-06-28 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95058P	\N	\N
4482	648	2000-06-23 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
4906	556	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
4907	556	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	79004F	\N	\N
4908	556	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	\N
4909	556	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	\N
4910	556	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
4911	556	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77012W	\N	\N
4912	556	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
4070	596	2000-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	99001N	\N	\N
4071	595	1999-12-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	99002P	\N	\N
4072	623	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
4073	626	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92044U	\N	\N
4074	611	2000-02-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98051U	\N	\N
4075	600	2000-02-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	92017R	\N	\N
4076	578	2000-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	88004G	\N	\N
4077	578	2000-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
4078	629	2000-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
4079	577	2000-02-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	99003Q	\N	\N
4080	578	2000-01-01 00:00:00	1973-09-23 00:00:00	ANCIEN	\N	\N	\N	74011H	\N	\N
4081	573	2000-02-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	99004R	\N	\N
4082	604	2000-03-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	00001A	\N	\N
4083	608	2000-02-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	99004R	\N	\N
4084	621	2000-02-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
4085	581	2000-03-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92022N	\N	\N
4086	602	2000-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	00001A	\N	\N
4087	602	2000-01-01 00:00:00	2002-06-06 00:00:00	ANCIEN	\N	\N	\N	95059Q	\N	\N
4088	575	2000-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	00001A	\N	\N
4094	598	2000-03-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98049B	\N	\N
4093	629	2000-03-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
4091	620	2000-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	00001A	\N	\N
4092	573	2000-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	00001A	\N	\N
4509	597	2000-12-12 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	92012L	\N	\N
4511	597	2000-12-10 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
4512	597	2000-12-12 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98048A	\N	\N
4513	597	2000-12-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
4514	597	2000-12-14 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
4515	597	2000-12-19 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77012W	\N	\N
4517	597	2000-12-13 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86018E	\N	\N
4518	597	2000-12-11 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	74019R	\N	\N
4519	597	2000-12-12 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	98031Q	\N	\N
4520	597	2001-02-23 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	\N
4521	597	2000-12-11 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	65017N	\N	\N
4522	597	2000-12-19 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
4523	597	2000-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	87003B	\N	\N
4524	597	2000-12-13 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
4525	597	2000-12-11 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
4526	597	2001-01-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
4527	597	2000-12-14 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77019E	\N	\N
4528	597	2000-12-20 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98047Y	\N	\N
4529	597	2000-12-12 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
4530	597	2000-12-11 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
4531	597	2000-12-12 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89030N	\N	\N
4532	597	2000-12-12 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
4533	597	2000-12-18 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98009S	\N	\N
4534	597	2000-12-12 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95035G	\N	\N
4535	597	2000-12-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
4536	597	2000-01-10 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	\N
4537	597	2000-12-14 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92026S	\N	\N
4538	597	2000-12-13 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	85003S	\N	\N
4539	597	2001-01-04 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
4540	597	2000-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
4541	597	2000-12-14 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	86034E	\N	\N
4542	597	2000-12-14 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	97006K	\N	\N
4543	597	2000-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
4544	597	2000-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	82002D	\N	\N
4545	597	2000-12-13 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
4546	597	2001-01-10 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92034S	\N	\N
4547	597	2000-12-19 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	93007T	\N	\N
4548	597	2000-12-12 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
4549	597	2000-12-12 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
4550	597	2000-12-12 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83046V	\N	\N
4551	597	2000-12-12 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
4552	597	2000-12-11 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95051G	\N	\N
4553	597	2000-12-10 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	91002E	\N	\N
4554	597	2000-12-19 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
4555	597	2000-12-26 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
4556	597	2000-12-12 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
4557	597	2000-12-12 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86042E	\N	\N
4558	597	2000-12-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89016Q	\N	\N
4559	597	2001-01-05 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
4560	597	2000-12-20 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
4561	597	2000-12-22 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95058P	\N	\N
4562	597	2000-12-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80035E	\N	\N
4563	597	2000-12-13 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86044G	\N	\N
4564	597	2000-12-12 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
4565	597	2001-02-12 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80039J	\N	\N
4566	597	2000-12-14 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
4567	597	2000-12-11 00:00:00	2000-09-30 00:00:00	ANCIEN	\N	\N	\N	83054V	\N	\N
4568	597	2000-12-13 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	89009R	\N	\N
4569	597	2000-12-10 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
4570	597	2000-12-15 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80046H	\N	\N
4571	597	2000-12-11 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
4572	597	2000-12-12 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	89045V	\N	\N
4573	597	2000-12-13 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98026T	\N	\N
4574	597	2000-12-11 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83054V	\N	\N
3458	643	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	92021M	\N	\N
3946	618	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83028T	\N	\N
2593	621	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	98009S	\N	\N
3522	661	1999-01-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	83046V	\N	\N
1448	605	1999-01-01 00:00:00	2001-10-14 00:00:00	ANCIEN	\N	\N	\N	89009R	\N	\N
4577	575	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92018S	\N	\N
4578	575	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01041N	\N	\N
4579	575	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01053S	\N	\N
4580	573	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
4581	573	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
4582	573	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
4583	573	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01001E	\N	\N
4584	573	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	79004F	\N	\N
4585	573	2001-10-01 00:00:00	2008-09-24 00:00:00	ANCIEN	\N	\N	\N	88004G	\N	\N
4586	573	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
4587	573	2001-10-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	98031Q	\N	\N
4588	573	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01045S	\N	\N
4589	573	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01027Q	\N	\N
4590	573	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01041N	\N	\N
4591	573	2001-10-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	96005E	\N	\N
4592	573	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
4593	573	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
4594	573	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98003L	\N	\N
4595	573	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
4596	573	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
4597	573	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	93007T	\N	\N
4598	573	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
4599	573	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
4600	573	2001-10-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	95053J	\N	\N
4601	573	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01014K	\N	\N
4602	573	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
4603	573	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01050P	\N	\N
4604	573	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01028R	\N	\N
4605	573	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
4606	648	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
4608	648	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01006K	\N	\N
4609	648	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
4610	648	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01012H	\N	\N
4611	648	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92018S	\N	\N
4612	648	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	99003Q	\N	\N
4613	648	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01022K	\N	\N
4614	648	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
4615	648	2001-10-01 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	77044F	\N	\N
4616	648	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77047J	\N	\N
4617	648	2001-10-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	95051G	\N	\N
4618	648	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
4619	648	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01009N	\N	\N
4620	648	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86042E	\N	\N
5104	604	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01049W	\N	\N
5105	604	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
5106	604	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01045S	\N	\N
5107	604	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01024M	\N	\N
5108	604	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
5109	604	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01022K	\N	\N
5111	604	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98054X	\N	\N
5112	604	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
5113	604	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01020H	\N	\N
5114	604	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
5115	604	2001-10-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
5116	604	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86042E	\N	\N
5117	604	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
5118	604	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77060F	\N	\N
5119	604	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92044U	\N	\N
5120	604	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80046H	\N	\N
5121	604	2001-10-01 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	89045V	\N	\N
5124	629	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95030B	\N	\N
5125	629	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	91002E	\N	\N
5223	600	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
5224	600	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
5225	600	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
5226	600	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01054T	\N	\N
5227	600	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
5228	600	2001-10-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
5229	600	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
5230	600	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
5231	600	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98050T	\N	\N
5232	600	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98033S	\N	\N
5233	600	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01036R	\N	\N
5234	600	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01050P	\N	\N
5235	600	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80041C	\N	\N
5236	600	2001-10-01 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	01039U	\N	\N
5237	600	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
5238	600	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
5239	590	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01006K	\N	\N
5240	590	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
5241	590	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
5242	590	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
5243	590	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01046T	\N	\N
5244	590	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89010J	\N	\N
5245	590	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01049W	\N	\N
5246	590	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96004D	\N	2015-02-02 16:43:25
5249	590	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
5250	590	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
5251	590	2001-10-01 00:00:00	2002-09-30 00:00:00	ANCIEN	\N	\N	\N	77009C	\N	\N
5252	590	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95016D	\N	\N
5253	590	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	\N
5254	590	2001-10-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	92017R	\N	\N
5255	590	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
5256	590	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95024D	\N	\N
5257	590	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01045S	\N	\N
5258	590	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01027Q	\N	\N
5259	590	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
5260	590	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
5261	590	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01041N	\N	\N
5262	590	2001-10-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	96005E	\N	\N
5263	590	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01055U	\N	\N
5264	590	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
5265	590	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
5266	590	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
5267	590	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01021J	\N	\N
5268	590	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
5269	590	2001-10-01 00:00:00	2007-01-25 00:00:00	ANCIEN	\N	\N	\N	89006N	\N	\N
5270	590	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86037H	\N	\N
4913	556	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	99003Q	\N	\N
4914	556	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
4915	556	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89027T	\N	\N
4916	556	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92022N	\N	\N
4917	556	2001-10-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	98043U	\N	\N
4918	556	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83042R	\N	\N
4919	556	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
4920	556	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
4921	556	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
4922	556	2001-10-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	95053J	\N	\N
4923	556	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89016Q	\N	\N
4924	556	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
4925	556	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95056M	\N	\N
4926	556	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80035E	\N	\N
4927	556	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01014K	\N	\N
4928	556	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
4929	556	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80040B	\N	\N
4930	556	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01058X	\N	\N
4931	556	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92044U	\N	\N
4932	556	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80046H	\N	\N
4933	556	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
4934	556	2001-10-01 00:00:00	2004-07-19 00:00:00	ANCIEN	\N	\N	\N	95066P	\N	\N
4935	627	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95004Y	\N	\N
4838	608	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01027Q	\N	\N
4839	608	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98033S	\N	\N
4840	608	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
4842	623	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	79004F	\N	\N
4843	623	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	\N
4844	623	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
4845	623	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
4846	623	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	99003Q	\N	\N
4847	623	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95029J	\N	\N
4848	623	2001-10-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	96005E	\N	\N
4849	623	2001-10-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	95036H	\N	\N
4850	623	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98003L	\N	\N
4851	623	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
4852	623	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
4853	623	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
4854	623	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	68036E	\N	\N
4855	623	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01054T	\N	\N
4856	623	2001-10-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	95053J	\N	\N
4857	623	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
4858	623	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
4859	623	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
4860	623	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92045V	\N	\N
4861	623	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89045V	\N	\N
4862	575	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
4863	626	2001-10-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
4866	598	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01006K	\N	\N
4867	598	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
4868	598	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89019T	\N	\N
4869	598	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
4871	598	2001-10-01 00:00:00	2008-09-24 00:00:00	ANCIEN	\N	\N	\N	88004G	\N	\N
4872	598	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95019G	\N	\N
4873	598	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01063U	\N	\N
4874	598	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01045S	\N	\N
4875	598	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01027Q	\N	\N
4876	598	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	99003Q	\N	\N
4877	598	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01026P	\N	\N
4878	598	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
4879	598	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
4880	598	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98017S	\N	\N
4881	598	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95035G	\N	\N
4882	598	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98022P	\N	\N
4883	598	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
4884	598	2001-10-01 00:00:00	2007-06-24 00:00:00	ANCIEN	\N	\N	\N	99004R	\N	\N
4885	598	2001-10-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	92029V	\N	\N
4886	598	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01042P	\N	\N
4887	598	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
4888	598	2001-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
4889	598	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
4890	598	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83042R	\N	\N
4891	598	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	68036E	\N	\N
4892	598	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
4893	598	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
4894	598	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
4895	598	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
4896	598	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
4897	598	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01029S	\N	\N
4898	598	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01050P	\N	\N
4899	598	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01039U	\N	\N
4900	598	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89042S	\N	\N
4901	598	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01023L	\N	\N
4902	598	2001-10-01 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	89043T	\N	\N
4903	598	2001-10-01 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	80048K	\N	\N
4904	598	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
5357	584	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	85003S	\N	\N
5358	584	2001-10-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	92029V	\N	\N
5359	584	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
5360	584	2001-10-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	98043U	\N	\N
5361	584	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92030N	\N	\N
5362	584	2001-10-01 00:00:00	2009-09-09 00:00:00	ANCIEN	\N	\N	\N	80024B	\N	\N
5363	584	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
5364	584	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86037H	\N	\N
5365	584	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77047J	\N	\N
5366	584	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
5367	584	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
5368	584	2001-10-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
5369	584	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83047W	\N	\N
5370	584	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01016M	\N	\N
5371	584	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01014K	\N	\N
5372	584	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
5373	584	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89040Q	\N	\N
5374	584	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
5375	584	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01062T	\N	\N
5376	584	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80045G	\N	\N
5378	584	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92045V	\N	\N
5379	584	2001-10-01 00:00:00	2004-07-19 00:00:00	ANCIEN	\N	\N	\N	96003C	\N	\N
5380	584	2001-10-01 00:00:00	2004-07-19 00:00:00	ANCIEN	\N	\N	\N	95066P	\N	\N
5384	584	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92020L	\N	\N
5385	617	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	79004F	\N	\N
5383	584	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98023Q	\N	\N
5386	617	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
5387	617	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92008Q	\N	\N
5388	617	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86018E	\N	\N
5389	648	2001-12-03 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98027U	\N	\N
5390	648	2001-11-13 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01027Q	\N	\N
5391	648	2001-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
5392	648	2001-12-05 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	\N
5395	617	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01024M	\N	\N
5396	617	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	99003Q	\N	\N
5400	617	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01041N	\N	\N
5401	617	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	\N
5402	617	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89030N	\N	\N
5403	617	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92024Q	\N	\N
5404	617	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
5405	617	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
5406	617	2001-10-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	98043U	\N	\N
5409	617	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
5414	617	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77047J	\N	\N
5415	617	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89035T	\N	\N
5419	617	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95056M	\N	\N
5421	617	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01014K	\N	\N
5422	617	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
5423	580	2001-12-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
5425	617	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98039Y	\N	\N
5427	617	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
5428	617	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01028R	\N	\N
5429	617	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
5437	646	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
5438	646	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
5439	646	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
5440	646	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80015A	\N	\N
5441	646	2001-10-01 00:00:00	2002-07-17 00:00:00	ANCIEN	\N	\N	\N	95031C	\N	\N
5442	646	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77019E	\N	\N
5443	646	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95040D	\N	\N
5444	646	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	85003S	\N	\N
5445	646	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
5448	646	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98003L	\N	\N
5449	646	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
5450	646	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
5451	646	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
5453	646	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92044U	\N	\N
5454	646	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
5455	646	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77060F	\N	\N
5456	646	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01001E	\N	\N
5457	646	2001-10-01 00:00:00	2008-09-24 00:00:00	ANCIEN	\N	\N	\N	88004G	\N	\N
5458	646	2001-10-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	96005E	\N	\N
5459	646	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
5460	646	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
5461	646	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80046H	\N	\N
5462	646	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83047W	\N	\N
5463	646	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	\N
5464	646	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80039J	\N	\N
5465	646	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
5466	646	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
5467	646	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98029W	\N	\N
5469	641	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98016R	\N	\N
5470	641	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01059Y	\N	\N
5471	641	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	99003Q	\N	\N
5472	641	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
5473	641	2001-10-01 00:00:00	2002-07-17 00:00:00	ANCIEN	\N	\N	\N	95031C	\N	\N
5474	641	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
5475	641	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
5476	641	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
5477	641	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98022P	\N	\N
5478	641	2001-10-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	98043U	\N	\N
5479	641	2001-10-01 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	77044F	\N	\N
5480	641	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95055L	\N	\N
5481	641	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
5482	657	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01047U	\N	\N
5483	657	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
5484	657	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95014B	\N	\N
5485	657	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
5486	657	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
5487	657	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
5488	657	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
5489	657	2001-10-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	95053J	\N	\N
5490	657	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
5491	657	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
16338	908	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11060J	\N	\N
5494	572	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	79004F	\N	\N
5496	572	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
5497	572	2001-10-01 00:00:00	2008-09-24 00:00:00	ANCIEN	\N	\N	\N	88004G	\N	\N
5498	572	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
5499	572	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
5500	572	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
5501	572	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
5502	572	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01012H	\N	\N
5503	572	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01027Q	\N	\N
5504	572	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01017N	\N	\N
5505	572	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01011G	\N	\N
5506	572	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88009M	\N	\N
5507	572	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
5508	572	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86037H	\N	\N
5509	572	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01004H	\N	\N
5510	572	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89035T	\N	\N
5511	572	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
5512	572	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95056M	\N	\N
5513	572	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
5514	572	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
5515	572	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77060F	\N	\N
5516	572	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98012M	\N	\N
5517	572	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
5518	572	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92044U	\N	\N
5520	619	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
5521	619	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
5522	619	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	79004F	\N	\N
5523	619	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88004G	\N	\N
5524	619	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
5525	619	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
5526	619	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	\N
5527	619	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
5528	619	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
5529	619	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
5530	619	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
5531	619	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
5532	619	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98039Y	\N	\N
5533	619	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80041C	\N	\N
5534	619	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
5556	532	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
5557	532	2001-10-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	98043U	\N	\N
5558	532	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92044U	\N	\N
5559	640	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
5560	640	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89019T	\N	\N
5561	640	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
5562	640	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	\N
5563	640	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	00002B	\N	\N
5564	640	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	91002E	\N	\N
11763	617	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	\N
5565	640	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
5566	640	2001-10-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
5567	640	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
5568	640	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80048K	\N	\N
5569	610	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	\N
5570	610	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01052R	\N	\N
5571	610	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95015C	\N	\N
5572	610	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89027T	\N	\N
5573	610	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
5574	610	2001-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
5575	610	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
5576	610	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
5577	610	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83050R	\N	\N
5578	610	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89042S	\N	\N
5579	583	2001-10-01 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	98012M	\N	\N
5580	583	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77060F	\N	\N
5582	583	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
5583	583	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
5584	583	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
5585	583	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01030K	\N	\N
5586	583	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83011J	\N	\N
5587	583	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
5588	583	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
5590	583	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95025E	\N	\N
5591	583	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98024R	\N	\N
5592	583	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	\N
5593	583	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01055U	\N	\N
5594	583	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95036H	\N	\N
5595	583	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77029G	\N	\N
5596	583	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95004Y	\N	\N
5597	583	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
5598	583	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89013M	\N	\N
5599	583	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01064V	\N	\N
5600	583	2001-10-01 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	71003U	\N	\N
5601	583	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
5602	583	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89027T	\N	\N
5603	583	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95030B	\N	\N
5604	583	2001-10-01 00:00:00	2002-07-17 00:00:00	ANCIEN	\N	\N	\N	95031C	\N	\N
5605	583	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92022N	\N	\N
5606	583	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95033E	\N	\N
5607	583	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98041S	\N	\N
5608	583	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89029V	\N	\N
5609	583	2001-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95037J	\N	\N
5610	583	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01033N	\N	\N
5611	583	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	\N
5612	583	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92044U	\N	\N
5613	583	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
5614	583	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95061J	\N	\N
5615	583	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01054T	\N	\N
5616	583	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
5617	583	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95039L	\N	\N
5618	583	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95042F	\N	\N
5192	600	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
5193	600	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
5194	600	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01049W	\N	\N
5195	600	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
5196	600	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92011K	\N	\N
5198	600	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98048A	\N	\N
5199	600	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77012W	\N	\N
5200	600	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77013X	\N	\N
5201	600	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86018E	\N	\N
5202	600	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95023C	\N	\N
5203	600	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01045S	\N	\N
5204	600	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
5205	600	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01041N	\N	\N
5206	600	2001-10-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	96005E	\N	\N
5207	600	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	\N
5208	600	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
5209	600	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
5210	600	2001-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
5211	600	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01033N	\N	\N
5212	600	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95040D	\N	\N
5213	600	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77046H	\N	\N
5214	600	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
5215	600	2001-10-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	98043U	\N	\N
5216	600	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01042P	\N	\N
5217	600	2001-10-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	98025S	\N	\N
5218	600	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
5219	600	2001-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
5220	600	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95045J	\N	\N
5221	600	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	93007T	\N	\N
5222	600	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
5917	579	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
5918	579	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
5919	579	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
5920	579	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
5921	647	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
5922	647	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95040D	\N	\N
5923	647	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
5924	647	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
5925	647	2001-10-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
5926	647	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
5928	643	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
5929	611	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01062T	\N	\N
5930	651	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98017S	\N	\N
5931	651	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
5932	651	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95040D	\N	\N
5933	612	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
5934	612	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
5935	612	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98048A	\N	\N
5936	612	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
5937	612	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77012W	\N	\N
5938	612	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
5939	612	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
5940	612	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	\N
5177	596	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
5941	612	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98003L	\N	\N
5942	612	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
5943	612	2001-10-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	98043U	\N	\N
5944	612	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01042P	\N	\N
5946	612	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
5947	612	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
5948	612	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
5949	612	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
5950	612	2001-10-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
5951	612	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80040B	\N	\N
5952	612	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
5984	598	2002-03-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98013N	\N	\N
5955	578	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
5956	578	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95014B	\N	\N
5957	578	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
5958	578	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01063U	\N	\N
5959	578	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98023Q	\N	\N
5960	578	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	\N
5961	578	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	99003Q	\N	\N
5962	578	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01017N	\N	\N
5963	578	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
5964	578	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95040D	\N	\N
5965	578	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01021J	\N	\N
5966	578	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
5967	578	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92033R	\N	\N
5968	578	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98046X	\N	\N
5969	578	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
5970	578	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
5971	578	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98021N	\N	\N
5972	578	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
5973	578	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95056M	\N	\N
5974	578	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01016M	\N	\N
5975	578	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
5976	578	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77060F	\N	\N
5977	578	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80039J	\N	\N
5978	578	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80045G	\N	\N
5979	663	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87003B	\N	\N
5980	629	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
5981	643	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98017S	\N	\N
5982	643	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88009M	\N	\N
5983	646	2002-03-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
5985	608	2002-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
5986	627	2002-03-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98051U	\N	\N
5990	609	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
5991	609	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
5992	609	2000-11-23 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95011X	\N	\N
5993	609	2000-11-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01051Q	\N	\N
5994	609	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95023C	\N	\N
5995	609	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	99003Q	\N	\N
5996	609	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
5997	609	1999-01-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	96005E	\N	\N
5999	609	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
6000	609	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
6001	609	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
6002	609	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95045J	\N	\N
6003	609	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92033R	\N	\N
6004	609	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01054T	\N	\N
6005	609	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
6006	609	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01014K	\N	\N
6007	609	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92044U	\N	\N
6009	621	2001-10-25 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
6010	621	2001-10-25 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95005A	\N	\N
6011	621	2001-10-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
6012	621	2001-10-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
6013	621	2001-10-18 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01052R	\N	\N
6014	621	2001-10-18 00:00:00	2002-09-30 00:00:00	ANCIEN	\N	\N	\N	77009C	\N	\N
6015	621	2001-10-18 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95019G	\N	\N
6016	621	2001-10-18 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	98031Q	\N	\N
6017	621	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95026F	\N	\N
6018	621	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	99003Q	\N	\N
6019	621	2001-10-17 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01007L	\N	\N
6020	621	2001-10-17 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95040D	\N	\N
6021	621	2001-10-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01021J	\N	\N
6022	621	2001-10-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
6023	621	2001-10-17 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
6024	621	2001-10-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
6025	621	2001-10-17 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
6026	621	2001-10-17 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98008R	\N	\N
6027	621	2001-10-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01054T	\N	\N
6028	621	2001-10-27 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77060F	\N	\N
4723	616	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
4724	595	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92020L	\N	\N
4728	573	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	99003Q	\N	\N
4727	573	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
4729	585	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01054T	\N	\N
4730	577	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
4731	577	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01006K	\N	\N
4732	577	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
4733	577	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	79004F	\N	\N
4734	577	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	\N
4735	577	2001-10-01 00:00:00	2008-09-24 00:00:00	ANCIEN	\N	\N	\N	88004G	\N	\N
4736	577	2001-10-01 00:00:00	2002-09-30 00:00:00	ANCIEN	\N	\N	\N	77009C	\N	\N
4737	577	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77012W	\N	\N
4738	577	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95019G	\N	\N
4739	577	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01063U	\N	\N
4740	577	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01012H	\N	\N
4741	577	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
4742	577	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95023C	\N	\N
4743	577	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
4744	577	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	\N
4745	577	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
4746	577	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
4747	577	2004-10-29 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
4748	577	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
4749	577	2001-10-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
4750	577	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
4751	577	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01014K	\N	\N
4752	577	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80040B	\N	\N
4753	577	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92043T	\N	\N
4755	663	2001-10-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	92011K	\N	\N
4756	663	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95012Y	\N	\N
4757	663	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	90003B	\N	\N
4758	663	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01063U	\N	\N
4759	663	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98023Q	\N	\N
4760	663	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95024D	\N	\N
4761	663	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95035G	\N	\N
4762	663	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01021J	\N	\N
4763	663	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98005N	\N	\N
4764	663	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
4765	663	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
4775	575	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01006K	\N	\N
4767	663	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98021N	\N	\N
4769	663	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
4770	663	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
4772	663	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
4776	575	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
4777	575	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
4778	575	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
4779	575	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	\N
4780	575	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83031N	\N	\N
4781	575	2001-10-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	96005E	\N	\N
4782	575	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
4783	575	2001-10-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	92029V	\N	\N
4784	575	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80035E	\N	\N
4785	575	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
4786	575	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89040Q	\N	\N
4787	575	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01023L	\N	\N
4788	626	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
4789	626	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01006K	\N	\N
4790	626	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01001E	\N	\N
4791	626	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78007E	\N	\N
4792	626	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92011K	\N	\N
4793	626	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01044R	\N	\N
4794	626	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	\N
4795	626	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
4796	626	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98023Q	\N	\N
4797	626	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01012H	\N	\N
4798	626	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
4799	626	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01007L	\N	\N
4800	626	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01022K	\N	\N
4801	626	2001-10-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	92029V	\N	\N
4802	626	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
4803	626	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01004H	\N	\N
4804	626	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95003X	\N	\N
4805	626	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
4806	626	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95056M	\N	\N
4815	626	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80040B	\N	\N
4936	627	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
4937	627	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	79004F	\N	\N
4938	627	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98048A	\N	\N
4939	627	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
4940	627	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95015C	\N	\N
4941	627	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86018E	\N	\N
4942	627	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
4943	627	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	\N
4944	627	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	\N
4945	627	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
4946	627	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
4947	627	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89027T	\N	\N
4948	627	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
4949	627	2001-10-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	86034E	\N	\N
4950	627	2001-10-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	98043U	\N	\N
4951	627	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
4952	627	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86037H	\N	\N
4953	627	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
4954	627	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
4955	627	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
4956	627	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
4957	627	2001-10-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	95053J	\N	\N
4958	627	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
4959	627	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
4960	627	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89037V	\N	\N
4961	627	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
4962	574	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95023C	\N	\N
4963	574	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95004Y	\N	\N
4964	574	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
4965	574	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95006B	\N	\N
4966	574	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	79004F	\N	\N
4967	574	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
4968	574	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95014B	\N	\N
4969	574	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
4970	574	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90003B	\N	\N
4971	574	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95019G	\N	\N
4972	574	2001-10-01 00:00:00	2000-09-30 04:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
4973	574	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01017N	\N	\N
4974	574	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
4975	574	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
4976	574	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01021J	\N	\N
4977	574	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
4978	574	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
4979	574	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
4980	574	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
4981	574	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01054T	\N	\N
4982	574	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
4983	574	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89016Q	\N	\N
4993	663	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	96008H	\N	\N
4986	574	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98021N	\N	\N
4987	574	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95056M	\N	\N
4988	574	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89037V	\N	\N
4989	574	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
4990	574	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01050P	\N	\N
4992	574	2001-10-01 00:00:00	2004-07-19 00:00:00	ANCIEN	\N	\N	\N	96003C	\N	\N
4994	663	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
4995	663	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98024R	\N	\N
4996	663	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	\N
4997	663	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92022N	\N	\N
4998	663	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77029G	\N	\N
4999	663	2001-10-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	92029V	\N	\N
5032	581	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
5033	581	2001-10-01 00:00:00	2003-11-04 00:00:00	ANCIEN	\N	\N	\N	86031B	\N	\N
5034	581	2001-09-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
5035	581	2001-09-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
5036	581	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
5037	581	2001-09-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
5038	581	2001-10-01 00:00:00	2004-08-31 00:00:00	ANCIEN	\N	\N	\N	77060F	\N	\N
5039	581	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01039U	\N	\N
5040	581	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92044U	\N	\N
5041	581	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92045V	\N	\N
5031	581	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01006K	\N	\N
5042	581	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86037H	\N	\N
5043	581	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
5046	627	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95025E	\N	\N
5047	626	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95011X	\N	\N
5048	626	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01063U	\N	\N
5049	626	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01059Y	\N	\N
5050	626	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	99003Q	\N	\N
5051	626	2001-10-01 00:00:00	2007-11-28 00:00:00	ANCIEN	\N	\N	\N	01041N	\N	\N
5052	626	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01053S	\N	\N
5053	626	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
5055	613	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
5062	613	2001-10-01 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	71003U	\N	\N
5063	613	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
5064	613	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01027Q	\N	\N
5065	613	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
5066	613	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
5067	613	2001-10-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	92029V	\N	\N
5068	613	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
5069	613	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83042R	\N	\N
5070	613	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
5073	613	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
5074	613	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
5075	613	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86042E	\N	\N
5076	613	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80040B	\N	\N
5077	601	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
5078	601	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01006K	\N	\N
5079	601	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
5080	601	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97009N	\N	\N
5081	601	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
5082	601	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
5083	601	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01052R	\N	\N
5084	601	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	\N
5085	601	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01055U	\N	\N
5086	601	2001-10-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	92029V	\N	\N
5087	601	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86037H	\N	\N
5088	601	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
5089	601	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01004H	\N	\N
5091	601	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
5092	601	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01054T	\N	\N
5093	601	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
5094	601	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
5095	601	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01062T	\N	\N
5096	601	2001-10-01 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	80048K	\N	\N
5097	601	2001-10-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	98031Q	\N	\N
5098	601	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80035E	\N	\N
5101	604	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01006K	\N	\N
5102	604	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01046T	\N	\N
5103	604	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	\N
6384	595	2002-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01007L	\N	\N
6386	598	2002-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	02002K	\N	\N
6387	626	2002-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
6388	583	2002-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01057W	\N	\N
6389	597	2002-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
6390	597	2002-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
6391	620	2002-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01006K	\N	\N
6392	620	2002-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
6393	620	2002-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92007P	\N	\N
6394	620	2002-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89019T	\N	\N
6395	620	2002-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
6396	620	2002-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98049B	\N	\N
6397	620	2002-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
6398	620	2002-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	00003C	\N	\N
6399	620	2002-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
6400	620	2002-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
6401	620	2002-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01012H	\N	\N
6402	620	2002-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01027Q	\N	\N
6403	620	2002-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	99003Q	\N	\N
6404	620	2002-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77019E	\N	\N
6405	620	2002-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
6406	620	2002-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
6407	620	2002-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01057W	\N	\N
6408	620	2002-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
6409	620	2002-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
6410	620	2002-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01022K	\N	\N
6411	620	2002-11-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	98043U	\N	\N
6412	620	2002-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86037H	\N	\N
6413	620	2002-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01004H	\N	\N
6414	620	2002-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77047J	\N	\N
6415	620	2002-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
6416	620	2002-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
6417	620	2002-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80039J	\N	\N
6418	620	2002-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89040Q	\N	\N
6419	620	2002-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01028R	\N	\N
6420	620	2002-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01039U	\N	\N
6421	620	2002-11-01 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	89043T	\N	\N
6422	620	2002-11-01 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	80048K	\N	\N
6425	588	2002-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
6424	584	2002-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89037V	\N	\N
6426	588	2002-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
6427	588	2002-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88004G	\N	\N
6428	588	2002-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98048A	\N	\N
6429	588	2002-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01063U	\N	\N
6430	588	2002-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
6431	588	2002-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98023Q	\N	\N
6432	588	2002-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
6433	588	2002-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01041N	\N	\N
6434	588	2002-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
6435	588	2002-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
6436	588	2002-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80024B	\N	\N
6437	588	2002-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
6438	588	2002-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92044U	\N	\N
6439	588	2002-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
6440	594	2002-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01021J	\N	\N
6441	632	2002-11-01 00:00:00	2007-02-25 00:00:00	ANCIEN	\N	\N	\N	92024Q	\N	\N
6442	632	2002-12-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	95053J	\N	\N
6448	582	2002-12-01 00:00:00	2007-02-25 00:00:00	ANCIEN	\N	\N	\N	92024Q	\N	\N
6444	582	2002-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01059Y	\N	\N
6451	590	2002-12-01 00:00:00	2002-12-31 00:00:00	ANCIEN	\N	\N	\N	01007L	\N	\N
6452	851	2002-12-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	96005E	\N	\N
6453	851	2002-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
6454	851	2002-12-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89006N	\N	\N
6455	851	2002-12-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
6456	851	2002-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01054T	\N	\N
6457	851	2002-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
6459	590	2002-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01007L	\N	\N
6460	608	2002-12-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77043E	\N	\N
6461	588	2002-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
6463	588	2002-12-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
6464	588	2002-12-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
6465	588	2002-12-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
6466	588	2002-12-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80039J	\N	\N
6467	588	2002-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80040B	\N	\N
6468	588	2002-12-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
6469	609	2002-12-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86037H	\N	\N
6470	609	2002-12-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
6471	644	2003-01-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
6472	640	2003-01-15 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	02002K	\N	\N
6473	584	2003-01-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	02002K	\N	\N
6475	643	2002-04-07 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92022N	\N	\N
6476	662	2002-07-01 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
6477	662	2002-07-01 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	95011X	\N	\N
6478	662	2002-07-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
6479	662	2002-07-01 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	98016R	\N	\N
6480	662	2002-07-01 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	98048A	\N	\N
6481	662	2002-07-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77012W	\N	\N
6482	662	2002-07-01 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
6483	662	2002-07-01 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	\N
6484	662	2002-07-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92024Q	\N	\N
6485	662	2002-07-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86037H	\N	\N
6486	662	2002-07-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77044F	\N	\N
6487	662	2002-07-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01054T	\N	\N
6488	662	2002-07-01 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	95060H	\N	\N
6489	662	2002-07-01 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
6490	662	2002-07-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
6491	644	2003-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	\N
6310	618	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
6311	618	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
6312	618	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98039Y	\N	\N
7319	917	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01049W	\N	\N
7320	917	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01052R	\N	\N
7321	917	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
7322	917	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98016R	\N	\N
7323	917	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	95025E	\N	\N
7324	917	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01024M	\N	\N
7325	917	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01015L	\N	\N
7326	917	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01027Q	\N	\N
7327	917	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
7328	917	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
7329	917	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95030B	\N	\N
7330	917	2001-10-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	96005E	\N	\N
7331	917	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98047Y	\N	\N
7334	917	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88009M	\N	\N
7335	917	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	\N
7336	917	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01022K	\N	\N
7337	917	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77029G	\N	\N
7338	917	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98027U	\N	\N
7339	917	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
7340	917	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
7341	917	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01042P	\N	\N
7342	917	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77043E	\N	\N
7343	917	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
7344	917	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
7345	917	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
7346	917	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
7347	917	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
7348	917	2001-10-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
7349	917	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86042E	\N	\N
7350	917	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80035E	\N	\N
7351	917	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
7352	917	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01058X	\N	\N
7353	917	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01050P	\N	\N
7354	917	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80041C	\N	\N
7355	917	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
7356	917	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01039U	\N	\N
7357	917	2001-10-01 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	98012M	\N	\N
7358	917	2001-10-01 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	89043T	\N	\N
7359	917	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
7360	917	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01047U	\N	\N
7361	917	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	92042S	\N	\N
7362	924	2002-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	95005A	\N	\N
7363	924	2002-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	83011J	\N	\N
7364	924	2002-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
7365	924	2002-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01046T	\N	\N
7366	924	2002-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	92007P	\N	\N
7367	924	2002-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	\N
7368	924	2002-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01049W	\N	\N
7369	924	2002-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	71003U	\N	\N
7370	924	2002-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
7371	924	2002-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
7372	924	2002-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
7373	924	2002-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86018E	\N	\N
7374	924	2002-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01035Q	\N	\N
7375	924	2002-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
7376	924	2002-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	95025E	\N	\N
7377	924	2002-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	\N
7378	924	2002-01-01 00:00:00	2004-01-28 00:00:00	ANCIEN	\N	\N	\N	92022N	\N	\N
7379	924	2002-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01025N	\N	\N
7380	924	2002-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98053W	\N	\N
7381	924	2002-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01017N	\N	\N
7382	924	2002-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01055U	\N	\N
7383	924	2002-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	89030N	\N	\N
7384	924	2002-01-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	95036H	\N	\N
7385	924	2002-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01057W	\N	\N
7386	924	2002-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	\N
7484	918	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	\N
7485	918	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	89027T	\N	\N
7486	918	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83031N	\N	\N
7487	918	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
7488	918	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
7489	918	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
7490	918	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	02006P	\N	\N
7491	918	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	88012G	\N	\N
7492	918	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98003L	\N	\N
7493	918	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	88009M	\N	\N
7494	918	2001-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
7495	918	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01033N	\N	\N
7496	918	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	\N
7497	918	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	\N
7498	918	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98027U	\N	\N
7499	918	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01030K	\N	\N
7500	918	2001-10-01 00:00:00	2007-01-25 00:00:00	ANCIEN	\N	\N	\N	89006N	\N	\N
7501	918	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77047J	\N	\N
7502	918	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	95049N	\N	\N
7503	918	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
7504	918	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01009N	\N	\N
7505	918	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89016Q	\N	\N
7506	918	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80035E	\N	\N
7387	924	2002-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77029G	\N	\N
7388	924	2002-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98027U	\N	\N
7389	924	2002-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01021J	\N	\N
7390	924	2002-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01042P	\N	\N
7391	924	2002-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
7392	924	2002-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	93007T	\N	\N
7393	924	2002-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	95047L	\N	\N
7394	924	2002-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
7395	924	2002-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98008R	\N	\N
7396	924	2002-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
7397	924	2002-01-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
7398	924	2002-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	80041C	\N	\N
7399	924	2002-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98012M	\N	\N
7400	924	2002-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01034P	\N	\N
7401	924	2002-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01047U	\N	\N
7402	920	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	80015A	\N	\N
7403	920	2001-10-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	96005E	\N	\N
7404	920	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	82002D	\N	\N
7405	920	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	77044F	\N	\N
7406	920	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	89035T	\N	\N
7408	920	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
7409	920	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01039U	\N	\N
7410	920	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
7411	922	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01006K	\N	\N
7412	922	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98036V	\N	\N
7413	922	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
7414	922	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01064V	\N	\N
7415	922	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01049W	\N	\N
7416	922	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95012Y	\N	\N
7418	922	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
7419	922	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
7420	922	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	\N
7421	922	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01024M	\N	\N
7422	922	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01015L	\N	\N
7423	922	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
7424	922	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95029J	\N	\N
7425	922	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95030B	\N	\N
7426	922	2001-10-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	96005E	\N	\N
7427	922	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
7428	922	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89030N	\N	\N
7429	922	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88009M	\N	\N
7430	922	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	\N
7431	922	2001-10-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	98025S	\N	\N
7432	922	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	93007T	\N	\N
7434	922	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	91002E	\N	\N
7435	922	2001-10-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	95053J	\N	\N
7436	922	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
7437	922	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
7438	922	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01050P	\N	\N
7439	922	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92045V	\N	\N
7440	922	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
7441	922	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80048K	\N	\N
7442	922	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01010F	\N	\N
7443	922	2001-10-01 00:00:00	2011-02-08 00:00:00	ANCIEN	\N	\N	\N	01047U	\N	\N
7444	921	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	\N
7445	921	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
7446	921	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
7447	921	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
7448	921	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01052R	\N	\N
7449	921	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98049B	\N	\N
7450	921	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	92008Q	\N	\N
7451	921	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	80013X	\N	\N
7452	921	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80015A	\N	\N
7453	921	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	\N
7454	921	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
7455	921	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	02006P	\N	\N
7456	921	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98017S	\N	\N
7457	921	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	82002D	\N	\N
7458	921	2001-10-01 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	77044F	\N	\N
7459	921	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
7460	921	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
7461	921	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
7462	921	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80040B	\N	\N
7463	921	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
7464	921	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
7465	921	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89042S	\N	\N
7466	921	2001-10-01 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	89043T	\N	\N
7467	921	2001-10-01 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	80048K	\N	\N
7468	918	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01006K	\N	\N
7469	918	2001-10-01 00:00:00	2004-11-25 00:00:00	ANCIEN	\N	\N	\N	95005A	\N	\N
7471	918	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
7472	918	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
7473	918	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	\N
7475	918	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
7476	918	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89010J	\N	\N
7477	918	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
7479	918	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01052R	\N	\N
7480	918	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95012Y	\N	\N
7481	918	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95015C	\N	\N
7482	918	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
7483	918	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01059Y	\N	\N
6154	576	2001-12-18 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86021Y	\N	\N
6155	576	2001-12-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
6156	576	2001-12-18 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92020L	\N	\N
6157	576	2001-12-18 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01041N	\N	\N
6158	576	2001-12-18 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77019E	\N	\N
6159	576	2001-12-18 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
6160	576	2001-12-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01007L	\N	\N
6161	576	2001-12-18 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88009M	\N	\N
6162	576	2001-12-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
6163	576	2001-12-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01021J	\N	\N
6164	576	2001-12-18 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	85003S	\N	\N
6165	576	2001-12-18 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
6029	621	2001-10-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01029S	\N	\N
6030	621	2001-10-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01062T	\N	\N
6031	621	2001-10-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01023L	\N	\N
6032	621	2001-10-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
6033	621	2001-10-27 00:00:00	2004-07-19 00:00:00	ANCIEN	\N	\N	\N	95066P	\N	\N
6034	621	2001-10-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01047U	\N	\N
6037	632	2001-10-17 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
6038	632	2001-10-17 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	77044F	\N	\N
6039	610	2002-04-27 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92008Q	\N	\N
6041	623	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01025N	\N	\N
6042	623	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
6044	585	2002-02-06 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	\N
6045	629	2002-04-29 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98003L	\N	\N
6073	634	2001-11-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
6074	634	2001-11-07 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
6075	634	2001-11-07 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	71003U	\N	\N
6076	634	2001-11-07 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77012W	\N	\N
6077	634	2001-11-07 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01012H	\N	\N
6078	634	2001-11-07 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	99003Q	\N	\N
6079	634	2001-11-07 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95029J	\N	\N
6080	634	2001-11-07 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83031N	\N	\N
5166	596	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
5167	596	2001-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
5168	596	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
5169	596	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89035T	\N	\N
5170	596	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01054T	\N	\N
5171	596	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
5172	596	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
5173	596	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
5174	596	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
5175	596	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01028R	\N	\N
5176	596	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
5178	596	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92044U	\N	\N
5179	596	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80048K	\N	\N
5180	594	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
5181	594	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89019T	\N	\N
5182	594	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
5183	594	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
5184	594	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01027Q	\N	\N
5185	594	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98047Y	\N	\N
5186	594	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01007L	\N	\N
5187	594	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
5188	594	2001-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
5189	594	2001-10-01 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	00002B	\N	\N
5190	594	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98050T	\N	\N
5191	594	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77060F	\N	\N
5619	583	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77033C	\N	\N
5620	583	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
5621	583	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95049N	\N	\N
5622	583	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89016Q	\N	\N
5623	583	2001-10-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
5624	583	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01028R	\N	\N
5625	583	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
5626	583	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	\N
5627	583	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80035E	\N	\N
5628	583	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98021N	\N	\N
5629	583	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86044G	\N	\N
5630	583	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77043E	\N	\N
5631	583	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
5632	583	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01049W	\N	\N
5633	583	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90003B	\N	\N
5634	583	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01041N	\N	\N
5635	583	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83031N	\N	\N
5636	583	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01017N	\N	\N
5637	583	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
5638	583	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01021J	\N	\N
5639	583	2001-10-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	92029V	\N	\N
5640	583	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
5641	651	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	\N
5642	651	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
5643	651	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98048A	\N	\N
5644	651	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01063U	\N	\N
5645	651	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98023Q	\N	\N
5646	651	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98027U	\N	\N
5647	651	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
5648	602	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
5649	602	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
5650	602	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98036V	\N	\N
5651	602	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83011J	\N	\N
5652	602	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
5296	642	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92018S	\N	\N
5297	642	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95047L	\N	\N
5298	642	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
5300	534	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
5301	534	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	79004F	\N	\N
5302	534	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01026P	\N	\N
5303	534	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	\N
5304	534	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92024Q	\N	\N
5305	534	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
5306	534	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
5307	534	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80024B	\N	\N
5308	534	2001-10-01 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	77044F	\N	\N
5309	534	2001-10-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	95053J	\N	\N
5310	534	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
5311	534	2001-10-01 00:00:00	2009-07-23 00:00:00	ANCIEN	\N	\N	\N	86044G	\N	\N
5313	661	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
5315	661	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89030N	\N	\N
5316	661	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
5317	661	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
5318	661	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
5319	661	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
5322	659	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	79004F	\N	\N
5321	577	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77013X	\N	\N
5323	659	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89019T	\N	\N
5325	659	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
5326	659	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98023Q	\N	\N
5327	659	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92018S	\N	\N
5328	659	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01024M	\N	\N
5329	659	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	99003Q	\N	\N
11762	644	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	\N
5331	659	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	\N
5332	659	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
5333	659	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89030N	\N	\N
5334	659	2001-10-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	98043U	\N	\N
5335	659	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
5336	659	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
5337	659	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
5338	659	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80039J	\N	\N
5339	584	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
5340	584	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01049W	\N	\N
5341	584	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98049B	\N	\N
5342	584	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
5343	584	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98048A	\N	\N
5344	584	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98029W	\N	\N
5345	584	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90003B	\N	\N
5346	584	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77012W	\N	\N
5347	584	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01063U	\N	\N
5348	584	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
5349	584	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	99003Q	\N	\N
5350	584	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	\N
5351	584	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89027T	\N	\N
5352	584	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83031N	\N	\N
5353	584	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83033Q	\N	\N
5354	584	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	\N
5355	584	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
5356	584	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01022K	\N	\N
5826	582	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
5827	582	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
5828	582	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
5829	582	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
5834	580	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01049W	\N	\N
5835	580	1998-10-01 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	71003U	\N	\N
5836	580	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01052R	\N	\N
5837	580	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
5838	580	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
5839	580	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01063U	\N	\N
5840	580	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	\N
5841	580	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
5842	580	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
5843	580	1998-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
5844	580	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
5845	580	2001-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01042P	\N	\N
5847	580	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
5848	580	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
5849	580	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
5850	580	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89016Q	\N	\N
5851	580	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
5852	580	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
5853	580	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
5854	580	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
5855	580	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80041C	\N	\N
5856	580	2001-12-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01039U	\N	\N
5857	580	2001-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01023L	\N	\N
5858	573	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
5859	573	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86037H	\N	\N
5860	573	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01034P	\N	\N
5861	600	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	\N
5862	629	1998-10-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	98043U	\N	\N
5863	629	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92045V	\N	\N
5864	574	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98051U	\N	\N
5865	585	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98051U	\N	\N
5866	584	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
5867	584	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
5868	591	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
5870	643	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
5871	643	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95011X	\N	\N
5872	643	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90003B	\N	\N
5873	643	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87003B	\N	\N
5874	643	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83031N	\N	\N
5875	643	2001-10-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	96005E	\N	\N
5876	643	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	\N
5877	643	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
5878	643	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01011G	\N	\N
5879	643	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
5880	643	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
5881	643	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01021J	\N	\N
5882	643	2001-10-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	92029V	\N	\N
5883	643	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
5884	643	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95003X	\N	\N
5885	643	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01054T	\N	\N
5887	643	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
5888	643	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80039J	\N	\N
5889	643	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89040Q	\N	\N
5890	643	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01058X	\N	\N
5891	643	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01050P	\N	\N
5892	643	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89045V	\N	\N
5893	611	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	\N
5894	611	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95056M	\N	\N
5895	611	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
5896	611	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95004Y	\N	\N
5897	611	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
5898	611	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	\N
5899	611	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
5900	611	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98049B	\N	\N
5901	611	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
5902	611	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
5903	611	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95003X	\N	\N
5904	611	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
5905	611	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89027T	\N	\N
5906	611	2001-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
5907	611	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98012M	\N	\N
5909	611	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
5910	579	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98047Y	\N	\N
5911	579	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	\N
5912	579	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
5913	579	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95019G	\N	\N
5914	579	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89030N	\N	\N
5915	579	2001-10-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	95036H	\N	\N
5916	579	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
6492	644	2003-04-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89019T	\N	\N
6493	644	2003-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89021M	\N	\N
6494	644	2003-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
6495	644	2003-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77012W	\N	\N
6496	644	2003-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98023Q	\N	\N
6497	644	2003-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01012H	\N	\N
6498	644	2003-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
6499	644	2003-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
6500	644	2003-04-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01026P	\N	\N
6501	644	2003-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
6502	644	2003-04-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
6503	644	2003-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	85003S	\N	\N
6504	644	2003-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
6505	644	2003-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01042P	\N	\N
6506	644	2003-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
6507	644	2003-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
6508	644	2003-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
6509	644	2003-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
6510	644	2003-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80041C	\N	\N
96	598	1998-10-01 00:00:00	2001-09-23 00:00:00	ANCIEN	\N	\N	\N	74015M	\N	\N
6511	600	2003-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	\N
6512	596	2003-04-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98029W	\N	\N
6513	596	2003-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98023Q	\N	\N
6514	596	2003-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
6515	596	2003-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95026F	\N	\N
6516	596	2003-04-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
6517	596	2003-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01026P	\N	\N
6518	596	2003-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
6519	596	2003-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92024Q	\N	\N
6520	596	2003-04-01 00:00:00	2003-11-04 00:00:00	ANCIEN	\N	\N	\N	86031B	\N	\N
6521	596	2003-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01042P	\N	\N
6522	596	2003-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98051U	\N	\N
6523	596	2003-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
6524	596	2003-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	85003S	\N	\N
6525	596	2003-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
6526	596	2003-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
6527	596	2003-04-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83050R	\N	\N
6528	571	2003-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
6529	598	2003-04-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89010J	\N	\N
6530	598	2003-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01001E	\N	\N
6531	598	2003-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
6532	598	2003-04-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95024D	\N	\N
6533	598	2003-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92020L	\N	\N
6534	598	2003-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01055U	\N	\N
6535	598	2003-04-01 00:00:00	2003-11-04 00:00:00	ANCIEN	\N	\N	\N	86031B	\N	\N
6536	598	2003-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01033N	\N	\N
5271	590	2001-10-01 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	77044F	\N	\N
5272	590	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01004H	\N	\N
5273	590	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	93007T	\N	\N
5274	590	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
5275	590	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
5276	590	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	91002E	\N	\N
5277	590	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
5278	590	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01009N	\N	\N
5279	590	2001-10-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
5280	590	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95056M	\N	\N
5281	590	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
5282	590	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
5283	590	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98039Y	\N	\N
5284	590	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01028R	\N	\N
5285	590	2001-10-01 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	01039U	\N	\N
5286	590	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
5287	590	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
5288	590	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92044U	\N	\N
5289	590	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89042S	\N	\N
5290	590	2001-10-01 00:00:00	2004-07-19 00:00:00	ANCIEN	\N	\N	\N	95066P	\N	\N
5291	590	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01047U	\N	\N
5294	642	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
5295	642	2001-10-01 00:00:00	2007-01-01 00:00:00	ANCIEN	\N	\N	\N	01035Q	\N	\N
5653	602	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	\N
5654	602	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	\N
5655	602	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01064V	\N	\N
5656	602	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	96004D	\N	2015-02-02 16:43:25
5657	602	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95014B	\N	\N
5658	602	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92013M	\N	\N
5659	602	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
5660	602	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98048A	\N	\N
5661	602	2001-10-01 00:00:00	2002-12-10 00:00:00	ANCIEN	\N	\N	\N	86014A	\N	\N
5662	602	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01063U	\N	\N
5663	602	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95020Y	\N	\N
5664	602	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01027Q	\N	\N
5665	602	2001-10-01 00:00:00	2004-10-01 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	\N
5666	602	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92020L	\N	\N
5667	602	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01041N	\N	\N
5668	602	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89027T	\N	\N
5669	602	2001-10-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	96005E	\N	\N
5670	602	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83003J	\N	\N
5671	602	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
5672	602	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98017S	\N	\N
5673	602	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01007L	\N	\N
5674	602	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
5675	602	2001-10-01 00:00:00	2002-06-18 00:00:00	ANCIEN	\N	\N	\N	95041E	\N	\N
5676	602	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01021J	\N	\N
5677	602	2001-10-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	92029V	\N	\N
5678	602	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
5680	602	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01042P	\N	\N
5681	602	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
5682	602	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
5683	602	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
5684	602	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01004H	\N	\N
5685	602	2001-10-01 00:00:00	2004-02-29 00:00:00	ANCIEN	\N	\N	\N	01060R	\N	\N
5686	602	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01020H	\N	\N
5687	602	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
5688	602	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01054T	\N	\N
5689	602	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
5690	602	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
5691	602	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
5692	602	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
5693	602	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95061J	\N	\N
5694	602	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98039Y	\N	\N
5695	602	2001-10-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
5696	602	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98033S	\N	\N
5697	602	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83050R	\N	\N
5698	602	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01036R	\N	\N
5700	602	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	93005R	\N	\N
5701	602	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80041C	\N	\N
5702	602	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86047K	\N	\N
5703	602	2001-10-01 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	98012M	\N	\N
5704	602	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92044U	\N	\N
5705	602	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01034P	\N	\N
5706	602	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01023L	\N	\N
5707	602	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01010F	\N	\N
5709	628	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
5710	628	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	\N
5711	628	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
5712	628	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01046T	\N	\N
5713	628	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92007P	\N	\N
5714	628	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88004G	\N	\N
5716	628	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80015A	\N	\N
5717	628	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98024R	\N	\N
5718	628	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01045S	\N	\N
5719	628	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83031N	\N	\N
5720	628	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01055U	\N	\N
5721	628	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
5722	628	2001-10-01 00:00:00	2004-05-25 00:00:00	ANCIEN	\N	\N	\N	01007L	\N	\N
5723	628	2001-10-01 00:00:00	2006-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
5724	628	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
11764	617	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
5725	628	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
5726	628	2001-10-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	95051G	\N	\N
5727	628	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89035T	\N	\N
5728	628	2001-10-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	95053J	\N	\N
5729	628	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
5730	628	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98021N	\N	\N
5731	628	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01034P	\N	\N
5732	628	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92045V	\N	\N
5733	628	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	79004F	\N	\N
5734	628	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78007E	\N	\N
5735	628	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
5736	628	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
5737	628	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01027Q	\N	\N
5738	628	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92030N	\N	\N
5739	628	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
5740	628	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80035E	\N	\N
5741	628	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
5742	644	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	\N
5743	644	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
5744	644	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
5745	644	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
5746	644	2001-10-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	98043U	\N	\N
5747	644	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92030N	\N	\N
5748	644	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83047W	\N	\N
5749	644	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
5750	644	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89045V	\N	\N
5756	644	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01047U	\N	\N
5758	632	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
5759	632	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98016R	\N	\N
5760	632	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92008Q	\N	\N
5761	632	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
5762	632	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
5763	632	2001-10-01 00:00:00	2003-11-04 00:00:00	ANCIEN	\N	\N	\N	86031B	\N	\N
5764	632	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01004H	\N	\N
5765	632	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
5766	632	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
5767	632	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95060H	\N	\N
5769	632	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
5771	625	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	79004F	\N	\N
5772	625	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95019G	\N	\N
5773	625	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	\N
5774	625	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95023C	\N	\N
5775	625	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83031N	\N	\N
5776	625	2001-10-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	96005E	\N	\N
5777	625	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01007L	\N	\N
5778	625	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
5779	625	2001-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
5780	625	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
5781	625	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86037H	\N	\N
5782	625	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	91002E	\N	\N
5783	625	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01054T	\N	\N
5784	625	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
5785	625	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
5787	625	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01029S	\N	\N
5788	625	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01028R	\N	\N
5789	625	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01062T	\N	\N
5790	625	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01023L	\N	\N
5791	624	2001-10-01 00:00:00	2008-09-24 00:00:00	ANCIEN	\N	\N	\N	88004G	\N	\N
5792	624	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	\N
5793	624	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90003B	\N	\N
5794	624	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77012W	\N	\N
5796	624	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83033Q	\N	\N
5797	624	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
5798	624	2001-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
5799	624	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92030N	\N	\N
5800	624	2001-10-01 00:00:00	2009-07-23 00:00:00	ANCIEN	\N	\N	\N	86044G	\N	\N
5801	624	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80039J	\N	\N
5802	624	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01047U	\N	\N
5804	624	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
5818	582	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
5833	580	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	\N
5820	582	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
5821	582	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77012W	\N	\N
5822	582	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
5823	582	1998-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	\N
5824	582	1998-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
5825	582	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
6313	618	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80040B	\N	\N
6315	618	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92044U	\N	\N
6316	618	2001-10-01 00:00:00	2004-07-19 00:00:00	ANCIEN	\N	\N	\N	96003C	\N	\N
6317	597	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01006K	\N	\N
6318	597	2001-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
6319	597	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01046T	\N	\N
6320	597	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
6321	597	2001-10-01 00:00:00	2008-09-24 00:00:00	ANCIEN	\N	\N	\N	88004G	\N	\N
6335	597	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
6336	597	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01027Q	\N	\N
6337	597	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	99003Q	\N	\N
6338	597	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01041N	\N	\N
6339	597	2001-10-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	96005E	\N	\N
6340	597	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
6341	597	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
6342	597	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01018P	\N	\N
6343	597	2001-10-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	98043U	\N	\N
6344	597	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80024B	\N	\N
6345	597	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
6346	597	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98039Y	\N	\N
6347	597	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
6348	597	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01023L	\N	\N
6349	597	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01047U	\N	\N
6350	618	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98049B	\N	\N
6351	651	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
6352	583	2001-10-01 00:00:00	2007-02-25 00:00:00	ANCIEN	\N	\N	\N	92024Q	\N	\N
6353	605	2002-01-14 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95058P	\N	\N
6354	622	2001-10-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
6355	622	2001-10-19 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
6356	622	2001-10-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
6357	622	2001-10-24 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92007P	\N	\N
6358	622	2001-10-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
6359	622	2001-10-24 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	\N
6360	622	2001-10-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98016R	\N	\N
6361	622	2001-10-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
6362	622	2001-10-24 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95024D	\N	\N
6363	622	2001-10-24 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95025E	\N	\N
6364	622	2001-10-24 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01041N	\N	\N
6365	622	2001-10-24 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	96005E	\N	\N
6366	622	2001-10-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
6367	622	2001-10-24 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
6368	622	2001-10-24 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
6369	622	2001-10-24 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
6370	622	2001-10-24 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
6371	622	2001-10-24 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
6372	622	2001-10-24 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	95051G	\N	\N
6373	622	2001-10-24 00:00:00	0200-09-30 00:00:00	ANCIEN	\N	\N	\N	01009N	\N	\N
6374	622	2001-10-24 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98039Y	\N	\N
6375	622	2001-10-24 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01039U	\N	\N
6376	622	2001-10-24 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92044U	\N	\N
6377	622	2001-10-24 00:00:00	2004-07-19 00:00:00	ANCIEN	\N	\N	\N	96003C	\N	\N
6378	622	2001-10-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01010F	\N	\N
6379	598	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	02003L	\N	\N
6381	575	2002-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
6382	578	2002-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
6383	647	2002-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
7508	918	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77060F	\N	\N
7509	918	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
7510	918	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
7511	918	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98037W	\N	\N
7512	918	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80045G	\N	\N
7513	918	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
7514	918	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	92044U	\N	\N
7515	918	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
7516	913	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
7517	913	2001-10-01 00:00:00	2004-10-01 00:00:00	ANCIEN	\N	\N	\N	98036V	\N	\N
7518	913	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	\N
7519	913	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01013J	\N	\N
7520	913	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86011W	\N	\N
7521	913	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92011K	\N	\N
7522	913	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01052R	\N	\N
7523	913	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95015C	\N	\N
7524	913	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77017C	\N	\N
7525	913	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
7526	913	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80015A	\N	\N
7527	913	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
7528	913	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	02002K	\N	\N
7529	913	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01017N	\N	\N
7530	913	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89030N	\N	\N
6081	634	2001-11-07 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
6082	634	2001-11-07 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	88009M	\N	\N
6083	634	2001-11-07 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01057W	\N	\N
6084	634	2001-11-07 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
6085	634	2001-11-07 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
6091	634	2001-11-07 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89016Q	\N	\N
6092	634	2001-11-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
6093	634	2001-11-07 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95056M	\N	\N
6094	634	2001-11-07 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98039Y	\N	\N
6095	634	2001-11-07 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01058X	\N	\N
6096	634	2001-11-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01028R	\N	\N
6098	589	2000-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01006K	\N	\N
6099	589	2000-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	\N
6100	589	2002-01-23 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01052R	\N	\N
6101	589	2002-01-23 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
6102	589	2002-01-23 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	92017R	\N	\N
6103	589	2002-01-23 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
6104	589	2002-01-23 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95023C	\N	\N
6105	589	2002-01-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95024D	\N	\N
6106	589	2002-01-23 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
6107	589	2002-01-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
6108	589	2002-01-23 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01057W	\N	\N
6109	589	2002-01-23 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
6110	589	2002-01-23 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01033N	\N	\N
6111	589	2002-01-23 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77029G	\N	\N
6112	589	2002-01-23 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01021J	\N	\N
6113	589	2002-01-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	82002D	\N	\N
6114	589	2002-01-23 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
6115	589	2002-01-23 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98007Q	\N	\N
6116	589	2002-01-23 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
6117	589	2002-01-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01029S	\N	\N
6118	589	2002-01-23 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
6119	589	2002-01-23 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89042S	\N	\N
6120	605	2002-01-09 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98006P	\N	\N
6121	605	2002-01-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01001E	\N	\N
6122	605	2002-01-09 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01049W	\N	\N
6123	605	2002-01-09 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86018E	\N	\N
6124	605	2002-01-09 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95025E	\N	\N
6125	605	2002-01-09 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01041N	\N	\N
6126	605	2002-01-09 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01025N	\N	\N
6127	605	2002-01-09 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	96005E	\N	\N
6128	605	2002-01-09 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
6129	605	2002-01-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
6130	605	2002-01-09 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
6131	605	2002-01-09 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
6132	605	2002-01-09 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
6133	605	2002-01-09 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
6134	605	2002-01-09 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
6135	605	2002-01-09 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
6136	605	2002-01-09 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
6137	605	2002-01-09 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01023L	\N	\N
6138	576	2001-12-18 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95004Y	\N	\N
6545	588	2003-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77044F	\N	\N
6546	599	2003-03-21 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
6547	599	2003-03-21 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
6548	599	2003-03-21 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95003X	\N	\N
6549	599	2003-03-21 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
6550	599	2003-03-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
6551	599	2003-03-21 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
6552	599	2003-03-21 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01028R	\N	\N
6553	599	2003-03-21 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
6555	599	2003-03-21 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	01045S	\N	\N
6556	599	2003-03-21 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	02002K	\N	\N
6557	599	2003-03-21 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
6558	599	2003-03-21 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
6559	534	2003-05-02 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	\N
6560	661	2003-05-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96004D	\N	2015-02-02 16:43:48
6561	623	2003-06-25 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
6562	908	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01006K	\N	\N
6563	908	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
6564	908	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98049B	\N	\N
6565	908	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98016R	\N	\N
6566	908	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	\N
6567	908	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95023C	\N	\N
6568	908	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95024D	\N	\N
6569	908	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
6570	908	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86028G	\N	\N
6571	908	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01055U	\N	\N
6573	908	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
6574	908	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01011G	\N	\N
6575	908	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01022K	\N	\N
6576	908	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
6577	908	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98005N	\N	\N
6578	908	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	98038X	\N	\N
6579	908	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	82002D	\N	\N
6580	908	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98051U	\N	\N
6581	908	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95003X	\N	\N
6582	908	2004-10-01 00:00:00	2005-03-19 00:00:00	ANCIEN	\N	\N	\N	98008R	\N	\N
6583	908	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
6584	908	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95061J	\N	\N
6585	908	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
6586	908	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98039Y	\N	\N
6587	908	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	83050R	\N	\N
6588	908	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89040Q	\N	\N
6589	908	2004-10-01 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	98012M	\N	\N
6590	908	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
6591	908	2001-10-01 00:00:00	2004-07-19 00:00:00	ANCIEN	\N	\N	\N	95066P	\N	\N
6592	908	2002-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86021Y	\N	\N
6593	908	2002-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
6594	908	2002-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
6595	908	2003-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01053S	\N	\N
6596	908	2003-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92024Q	\N	\N
6597	908	2003-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88009M	\N	\N
6598	908	2003-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01021J	\N	\N
6599	908	2003-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
6600	908	2003-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
6602	573	2003-06-25 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	02002K	\N	\N
6603	918	2003-06-25 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
6604	920	2003-06-25 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	\N
6605	641	2003-06-25 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95035G	\N	\N
6606	623	2003-06-25 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98048A	\N	\N
6607	623	2003-06-25 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92033R	\N	\N
6608	623	2003-06-25 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01049W	\N	\N
6609	661	2003-06-25 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	\N
3355	626	1999-01-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	98043U	\N	\N
7221	904	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01006K	\N	\N
7224	904	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01012H	\N	\N
7226	904	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95029J	\N	\N
7227	904	2001-10-01 00:00:00	2004-09-29 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
7228	904	2001-10-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	95036H	\N	\N
7229	904	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
7230	904	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
7231	904	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
7232	904	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
7233	904	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
7234	904	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86044G	\N	\N
7235	904	2001-10-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
7236	904	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01029S	\N	\N
7237	904	2001-10-01 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	80048K	\N	\N
7238	904	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
7239	912	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	95004Y	\N	\N
7242	912	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
7241	912	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
7244	917	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01006K	\N	\N
7245	912	2001-10-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	86034E	\N	\N
7246	912	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95030B	\N	\N
7247	912	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83011J	\N	\N
7248	912	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95014B	\N	\N
7249	912	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
7250	912	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83050R	\N	\N
7251	912	2001-10-01 00:00:00	2007-07-01 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
7252	912	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	\N
7253	912	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
7254	912	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77012W	\N	\N
7255	912	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86018E	\N	\N
7256	912	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	95025E	\N	\N
7257	912	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01027Q	\N	\N
7258	912	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	89027T	\N	\N
7259	912	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
7260	912	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01007L	\N	\N
7261	912	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98003L	\N	\N
7262	912	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01042P	\N	\N
7265	912	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
7264	912	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	77043E	\N	\N
7266	912	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98021N	\N	\N
7267	912	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
7268	912	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98039Y	\N	\N
7269	912	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01050P	\N	\N
7270	912	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
7271	912	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92045V	\N	\N
7272	909	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77047J	\N	\N
7273	909	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	90003B	\N	\N
7274	909	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
7275	909	2001-10-01 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
7276	909	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89025R	\N	\N
7277	909	2001-10-01 00:00:00	2003-11-04 00:00:00	ANCIEN	\N	\N	\N	86031B	\N	\N
7278	909	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98021N	\N	\N
7279	909	2001-10-01 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	80048K	\N	\N
7280	909	2001-10-01 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	87003B	\N	\N
7281	909	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89037V	\N	\N
7282	909	2001-10-01 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	89042S	\N	\N
7283	909	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86037H	\N	\N
7285	909	2001-10-01 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	95004Y	\N	\N
7286	909	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
7287	909	2001-10-01 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	\N
7288	909	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
7289	909	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92011K	\N	\N
7290	909	2001-10-01 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
7291	909	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86018E	\N	\N
7292	909	2001-10-01 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	74050Q	\N	\N
7293	909	2001-10-01 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	01012H	\N	\N
7294	909	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95023C	\N	\N
7295	909	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
7296	909	2001-10-01 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	95030B	\N	\N
7297	909	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01026P	\N	\N
7298	909	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01025N	\N	\N
7299	909	2001-10-01 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	83033Q	\N	\N
7300	909	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98003L	\N	\N
7301	909	2001-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
7302	909	2001-10-01 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	95037J	\N	\N
7303	909	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
7304	909	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95047L	\N	\N
7305	909	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
7306	909	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
7307	909	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
7308	909	2001-10-01 00:00:00	2005-03-19 00:00:00	ANCIEN	\N	\N	\N	98008R	\N	\N
7309	909	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	91002E	\N	\N
7310	909	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86042E	\N	\N
7311	909	2001-10-01 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	89016Q	\N	\N
7312	909	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
7313	909	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86044G	\N	\N
7314	909	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98039Y	\N	\N
7315	909	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
7316	909	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01050P	\N	\N
7317	909	2001-10-01 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
7318	917	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	79004F	\N	\N
7714	929	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
7715	929	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95045J	\N	\N
7716	929	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
7717	929	2001-10-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	95051G	\N	\N
8319	932	2001-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
8418	932	2001-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
8419	932	2001-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01046T	\N	\N
8420	932	2001-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
13253	674	2008-10-01 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	07027R	\N	\N
7727	919	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
7728	919	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
7729	940	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01006K	\N	\N
13254	647	2008-10-01 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	07027R	\N	\N
7731	940	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	96008H	\N	\N
13255	619	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
13256	602	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
13257	597	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04077P	\N	\N
7735	940	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01027Q	\N	\N
7736	940	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
7738	940	2001-10-01 00:00:00	2003-11-04 00:00:00	ANCIEN	\N	\N	\N	86031B	\N	\N
13259	623	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
7741	940	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	99004R	\N	\N
7742	940	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
7743	940	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95045J	\N	\N
7744	940	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	77044F	\N	\N
7745	940	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
7746	940	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
7747	940	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	89016Q	\N	\N
13971	918	2009-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	09012S	\N	\N
7749	940	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95056M	\N	\N
7750	940	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95061J	\N	\N
7751	940	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	80040B	\N	\N
7752	940	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	93005R	\N	\N
7753	940	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	80041C	\N	\N
7754	940	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98012M	\N	\N
4290	641	1998-10-01 00:00:00	2001-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
7756	940	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	92044U	\N	\N
7757	940	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	80046H	\N	\N
7758	940	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	89042S	\N	\N
7759	940	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
7760	940	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
7762	915	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98036V	\N	\N
7763	934	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83031N	\N	\N
7764	934	2001-10-01 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	77044F	\N	\N
7765	934	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92043T	\N	\N
7766	934	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	\N
7768	905	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
7778	901	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01055U	\N	\N
7773	901	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86011W	\N	\N
7774	901	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01064V	\N	\N
7775	901	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	99003Q	\N	\N
7777	901	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01017N	\N	\N
7779	901	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
7780	901	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01021J	\N	\N
7781	901	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	85003S	\N	\N
7782	901	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
7783	901	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83042R	\N	\N
7784	901	2001-10-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
7785	901	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
7786	901	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86047K	\N	\N
7787	901	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98012M	\N	\N
7788	901	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
7789	901	2001-10-01 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	80048K	\N	\N
7790	901	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89027T	\N	\N
7791	906	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
7792	906	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86011W	\N	\N
7793	906	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89013M	\N	\N
7794	906	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
7795	906	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01052R	\N	\N
7632	919	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
7633	919	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89042S	\N	\N
7634	919	2001-10-01 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	89043T	\N	\N
7635	911	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80035E	\N	\N
7636	919	2001-10-01 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	80048K	\N	\N
7637	911	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	86044G	\N	\N
7638	911	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
7639	911	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
7640	911	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01050P	\N	\N
7641	911	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01062T	\N	\N
7642	911	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98012M	\N	\N
7643	911	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
7644	911	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92045V	\N	\N
7645	911	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	89045V	\N	\N
7646	911	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98038X	\N	\N
7647	911	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	92042S	\N	\N
7648	911	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98007Q	\N	\N
7649	911	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	86053H	\N	\N
7675	928	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
7674	928	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01049W	\N	\N
7652	928	2001-10-01 00:00:00	2007-01-01 00:00:00	ANCIEN	\N	\N	\N	01035Q	\N	\N
7653	928	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
7656	928	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	83031N	\N	\N
7655	928	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01041N	\N	\N
7657	928	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
7658	928	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86028G	\N	\N
7659	928	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98017S	\N	\N
7660	928	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
7661	928	2001-10-01 00:00:00	2003-11-04 00:00:00	ANCIEN	\N	\N	\N	86031B	\N	\N
7662	928	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95040D	\N	\N
7663	928	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
7664	928	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77033C	\N	\N
7665	928	2001-10-01 00:00:00	2007-01-25 00:00:00	ANCIEN	\N	\N	\N	89006N	\N	\N
7666	928	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77047J	\N	\N
7667	928	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	91002E	\N	\N
7668	928	2001-10-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	95053J	\N	\N
7669	928	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
7670	928	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
7671	928	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77060F	\N	\N
7672	928	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
7673	928	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95019G	\N	\N
13228	592	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01063U	\N	\N
13229	592	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
13230	592	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
13231	592	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04100U	\N	\N
13232	592	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
7681	927	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
7682	927	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	00003C	\N	\N
7683	927	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
7684	927	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	95035G	\N	\N
7685	927	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
7686	927	2001-10-01 00:00:00	2003-11-04 00:00:00	ANCIEN	\N	\N	\N	86031B	\N	\N
7687	927	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
7688	927	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98054X	\N	\N
7689	927	2001-10-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	86034E	\N	\N
7691	927	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
7692	927	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
7693	927	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
7694	927	2002-07-24 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
7695	927	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	80035E	\N	\N
7696	927	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
7697	927	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
7698	927	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
7699	927	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98012M	\N	\N
7700	927	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
7701	929	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
7702	929	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	79004F	\N	\N
7703	929	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	92011K	\N	\N
7704	929	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
8219	907	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
8220	907	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89025R	\N	\N
8221	907	2001-10-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	96005E	\N	\N
8222	907	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83003J	\N	\N
8223	907	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	83033Q	\N	\N
8224	907	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
8225	907	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	92024Q	\N	\N
8226	907	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01007L	\N	\N
8227	907	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
8228	907	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98003L	\N	\N
8229	907	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01057W	\N	\N
8230	907	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	\N
8231	907	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
8232	907	2001-10-01 00:00:00	2004-03-30 00:00:00	ANCIEN	\N	\N	\N	86034E	\N	\N
8233	907	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98038X	\N	\N
8234	907	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
8235	907	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	82002D	\N	\N
8236	907	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77043E	\N	\N
8237	907	2001-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
8238	907	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
8239	907	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95047L	\N	\N
8240	907	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77047J	\N	\N
8241	907	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
7705	929	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	95013A	\N	\N
7706	929	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
7707	929	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98048A	\N	\N
7708	929	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95017E	\N	\N
7709	929	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77013X	\N	\N
7710	929	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	95035G	\N	\N
7711	929	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
7712	929	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
7713	929	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77046H	\N	\N
7690	927	2002-07-24 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01018P	\N	\N
8136	937	2001-10-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	86034E	\N	\N
8137	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98038X	\N	\N
8139	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
8140	937	2001-10-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	98025S	\N	\N
8141	937	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
8142	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86037H	\N	\N
8143	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95045J	\N	\N
8144	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77043E	\N	\N
8145	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77044F	\N	\N
8146	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
8147	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01004H	\N	\N
8148	937	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	98046X	\N	\N
8149	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	93007T	\N	\N
8150	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95047L	\N	\N
8151	937	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	83042R	\N	\N
8152	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95003X	\N	\N
8153	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77047J	\N	\N
8154	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
8155	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
8156	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	68036E	\N	\N
8157	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98008R	\N	\N
8158	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
8159	937	2001-10-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	95051G	\N	\N
8160	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	91002E	\N	\N
8161	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89035T	\N	\N
8162	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
8163	937	2001-10-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	95053J	\N	\N
8164	937	2001-10-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
8165	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89016Q	\N	\N
8166	937	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	95055L	\N	\N
8167	937	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
8168	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98021N	\N	\N
8169	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95056M	\N	\N
8170	937	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	77058M	\N	\N
8171	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95058P	\N	\N
8172	937	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80035E	\N	\N
8173	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86044G	\N	\N
8174	937	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01016M	\N	\N
8175	937	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
8176	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
8177	937	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89037V	\N	\N
8178	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98039Y	\N	\N
8179	937	2001-10-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
8180	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77060F	\N	\N
8181	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83050R	\N	\N
8182	937	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89040Q	\N	\N
8183	937	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
8184	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92043T	\N	\N
8185	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86047K	\N	\N
8186	937	2001-10-01 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	98012M	\N	\N
8187	937	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
8188	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	93003P	\N	\N
8189	937	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80046H	\N	\N
8190	937	2001-10-01 00:00:00	2004-07-19 00:00:00	ANCIEN	\N	\N	\N	96003C	\N	\N
8191	937	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
8192	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
8193	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89045V	\N	\N
8194	937	2001-10-01 00:00:00	2004-07-19 00:00:00	ANCIEN	\N	\N	\N	95066P	\N	\N
8195	907	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
8196	907	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	\N
8197	907	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	79004F	\N	\N
8198	907	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	\N
8199	907	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01064V	\N	\N
8200	907	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
8201	907	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92011K	\N	\N
8202	907	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	88004G	\N	\N
8203	907	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
8204	907	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95012Y	\N	\N
8205	907	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
8206	907	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92015P	\N	\N
8207	907	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
8208	907	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	90003B	\N	\N
8209	907	2001-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	81015E	\N	\N
8210	907	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86018E	\N	\N
8211	907	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
8212	907	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98023Q	\N	\N
8213	907	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
8214	907	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95023C	\N	\N
8215	907	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01027Q	\N	\N
8216	907	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
8217	907	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	87003B	\N	\N
8218	907	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
7884	915	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95040D	\N	\N
7885	915	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
7886	915	2001-10-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	86034E	\N	\N
7887	915	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
7888	915	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	95046K	\N	\N
7889	915	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	91002E	\N	\N
6166	576	2001-12-18 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86037H	\N	\N
6167	576	2001-12-18 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	00002B	\N	\N
6168	576	2001-12-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
6169	576	2001-12-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
6170	576	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01009N	\N	\N
6171	576	2001-12-18 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
6172	576	2001-12-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89016Q	\N	\N
6173	576	2001-12-18 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95056M	\N	\N
6174	576	2001-12-18 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
6175	576	2001-12-18 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
6176	576	2001-12-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01029S	\N	\N
6177	576	2001-12-18 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
6178	576	2001-12-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01058X	\N	\N
6179	576	2001-12-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01050P	\N	\N
6180	576	2001-12-18 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01028R	\N	\N
6181	576	2001-12-18 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
6182	576	2001-12-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80045G	\N	\N
6183	576	2001-12-18 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01034P	\N	\N
6184	576	2001-12-18 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	89043T	\N	\N
6185	576	2001-12-18 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
6186	576	2001-12-18 00:00:00	2004-07-19 00:00:00	ANCIEN	\N	\N	\N	95066P	\N	\N
6188	586	1999-01-01 00:00:00	2001-12-31 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
6189	586	2002-02-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
6190	586	2002-02-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
6191	586	2002-02-20 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98049B	\N	\N
6192	586	2002-02-20 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92008Q	\N	\N
6193	586	2002-02-20 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92018S	\N	\N
6194	586	2002-02-20 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77012W	\N	\N
6195	586	2002-02-20 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	\N
6196	586	2002-02-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
6197	586	2002-02-20 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
6198	586	2002-02-20 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86042E	\N	\N
6199	586	2002-02-20 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
6200	586	2002-02-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
6201	586	2002-02-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
6203	586	2002-02-20 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80039J	\N	\N
6209	627	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89016Q	\N	\N
6210	615	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83011J	\N	\N
6211	615	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83012K	\N	\N
6212	615	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89021M	\N	\N
6213	615	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
6214	615	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
6215	615	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92008Q	\N	\N
6216	615	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
6218	615	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
6219	615	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
6220	615	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89027T	\N	\N
6221	615	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83031N	\N	\N
6222	615	2001-10-01 00:00:00	2009-04-28 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
6223	615	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95003X	\N	\N
6224	615	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
6225	615	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
6226	615	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
6229	615	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
6230	615	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98039Y	\N	\N
6231	615	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80039J	\N	\N
6232	530	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
6233	530	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	79004F	\N	\N
6235	530	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
6236	530	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77012W	\N	\N
6237	530	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
6238	530	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
6239	530	2001-10-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	96005E	\N	\N
6240	530	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	\N
6241	530	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88009M	\N	\N
6242	530	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
6243	530	2001-10-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	98043U	\N	\N
6244	530	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	91002E	\N	\N
6245	530	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
6246	530	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
6247	530	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80040B	\N	\N
6248	530	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
6249	530	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
6250	571	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	\N
6251	571	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89021M	\N	\N
6252	571	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
6253	571	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83031N	\N	\N
6254	571	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	\N
6255	571	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	\N
6256	571	2001-10-01 00:00:00	2003-08-28 00:00:00	ANCIEN	\N	\N	\N	98043U	\N	\N
6257	571	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80039J	\N	\N
6258	625	2000-11-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89016Q	\N	\N
6263	590	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95011X	\N	\N
6264	556	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83031N	\N	\N
6265	647	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01017N	\N	\N
6266	592	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
6267	592	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90003B	\N	\N
6268	592	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95019G	\N	\N
6269	592	2001-10-01 00:00:00	2002-06-07 00:00:00	ANCIEN	\N	\N	\N	98031Q	\N	\N
6270	592	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	\N
6271	592	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01027Q	\N	\N
6272	592	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	99003Q	\N	\N
6273	592	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98003L	\N	\N
6274	592	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
6275	592	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	\N
6276	592	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
6277	592	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01018P	\N	\N
6294	618	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	\N
6281	592	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98051U	\N	\N
6282	592	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
6283	592	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98046X	\N	\N
6284	592	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	68036E	\N	\N
6285	592	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	91002E	\N	\N
6286	592	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01054T	\N	\N
6287	592	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
6288	592	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80035E	\N	\N
6289	592	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
6290	592	2001-10-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
6291	592	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98012M	\N	\N
6292	592	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
6293	592	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80046H	\N	\N
6295	618	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	71003U	\N	\N
6296	618	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95014B	\N	\N
6297	618	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	90003B	\N	\N
6298	618	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98023Q	\N	\N
6299	618	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86021Y	\N	\N
6300	618	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83031N	\N	\N
6301	618	2001-10-01 00:00:00	2010-10-11 00:00:00	ANCIEN	\N	\N	\N	01017N	\N	\N
6302	618	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01053S	\N	\N
6303	618	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01007L	\N	\N
6304	618	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
6305	618	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
6306	618	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83042R	\N	\N
6307	618	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
6308	618	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
6309	618	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
7796	906	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
7797	906	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	90003B	\N	\N
7798	906	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	\N
7799	906	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
7800	906	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89027T	\N	\N
7801	906	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83031N	\N	\N
7802	906	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
7803	906	2001-10-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	96005E	\N	\N
7804	906	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
7805	906	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89030N	\N	\N
7807	906	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
7808	906	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98003L	\N	\N
7809	906	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
7810	906	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	\N
7811	906	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	85003S	\N	\N
7812	906	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
7813	906	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
7814	906	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	82002D	\N	\N
7815	906	2001-10-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	98025S	\N	\N
7816	906	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86037H	\N	\N
7817	906	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77043E	\N	\N
7818	906	2001-10-01 00:00:00	2004-04-06 00:00:00	ANCIEN	\N	\N	\N	01060R	\N	\N
7819	906	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
7820	906	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
7821	906	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	91002E	\N	\N
7822	906	2001-10-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	95053J	\N	\N
7823	906	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
7824	906	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89016Q	\N	\N
7825	906	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
7826	906	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98021N	\N	\N
7827	906	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
7828	906	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
7829	906	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98050T	\N	\N
7830	906	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
7831	906	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89037V	\N	\N
7832	906	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77060F	\N	\N
7833	906	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80040B	\N	\N
7834	906	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01058X	\N	\N
7835	906	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
7836	906	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92044U	\N	\N
7837	906	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
7838	906	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
7839	906	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80046H	\N	\N
7844	933	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89030N	\N	\N
7842	933	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
7845	933	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92030N	\N	\N
7848	933	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	82002D	\N	\N
6537	598	2003-04-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	85003S	\N	\N
6538	598	2003-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
6539	598	2003-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	82002D	\N	\N
6540	598	2003-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01054T	\N	\N
6541	598	2003-04-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01009N	\N	\N
6542	598	2003-04-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98050T	\N	\N
6543	598	2003-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01058X	\N	\N
6544	642	2003-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
6139	576	2001-12-18 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	\N
6140	576	2001-12-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
6141	576	2001-12-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97009N	\N	\N
6142	576	2001-12-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
6143	576	2001-12-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
6144	576	2001-12-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
6145	576	2001-12-18 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	79004F	\N	\N
6146	576	2001-12-18 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01064V	\N	\N
6147	576	2001-12-18 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	71003U	\N	\N
6148	576	2001-12-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92013M	\N	\N
6149	576	2001-12-18 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95011X	\N	\N
6150	576	2001-12-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
6151	576	2001-12-18 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86018E	\N	\N
6152	576	2001-12-18 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01035Q	\N	\N
6153	576	2001-12-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98023Q	\N	\N
7507	918	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	89037V	\N	\N
8126	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88009M	\N	\N
8127	937	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
8128	937	2001-10-01 00:00:00	2003-11-04 00:00:00	ANCIEN	\N	\N	\N	86031B	\N	\N
8129	937	2001-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	\N
8130	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77029G	\N	\N
8131	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	99004R	\N	\N
8132	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95042F	\N	\N
8133	937	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	85003S	\N	\N
8806	624	2004-10-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04052E	\N	\N
8398	670	2003-06-30 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
8399	670	2003-06-30 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01026P	\N	\N
8400	670	2003-06-30 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	\N
8401	670	2003-06-30 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
8402	670	2003-06-30 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
8403	670	2003-06-30 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	03001N	\N	\N
8404	670	2003-06-30 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
8405	670	2003-06-30 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80024B	\N	\N
8408	670	2003-06-30 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	02004M	\N	\N
8409	670	2003-06-30 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
8410	670	2003-06-30 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
8411	670	2003-06-30 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
8412	670	2003-06-30 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	89016Q	\N	\N
8413	670	2003-06-30 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
8414	670	2003-06-30 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80041C	\N	\N
8415	670	2003-06-30 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
8416	670	2003-06-30 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
8417	556	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
13217	595	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04053F	\N	\N
13218	947	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08024S	\N	\N
13219	947	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	02002K	\N	\N
13220	947	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
13221	947	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04078Q	\N	\N
13222	947	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
13223	947	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08039A	\N	\N
13224	947	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
13225	947	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95060H	\N	\N
13226	947	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
13227	947	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
7718	929	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
7719	929	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
7720	929	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
7721	929	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
7722	929	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
7723	929	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	92044U	\N	\N
7724	929	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	80046H	\N	\N
7725	929	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	92045V	\N	\N
7726	929	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
7676	927	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98020M	\N	\N
7677	927	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
7678	927	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	79004F	\N	\N
7679	927	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	92011K	\N	\N
8451	941	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
8452	941	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	81015E	\N	\N
8453	941	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98047Y	\N	\N
8454	941	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86037H	\N	\N
8455	941	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
8456	629	2003-10-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98036V	\N	\N
8457	634	2003-08-21 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98049B	\N	\N
8460	902	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	92011K	\N	\N
8461	902	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
8462	902	2003-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77012W	\N	\N
8463	902	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98023Q	\N	\N
8464	902	2003-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95023C	\N	\N
8465	902	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	95024D	\N	\N
8470	902	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
8468	902	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
8469	902	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01025N	\N	\N
8471	902	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
8472	902	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
8473	902	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98003L	\N	\N
8474	902	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
8475	902	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01022K	\N	\N
8476	902	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	95039L	\N	\N
8477	902	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98027U	\N	\N
8478	902	2003-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95040D	\N	\N
8479	902	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
8480	902	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
8994	534	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01054T	\N	\N
8995	534	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04090L	\N	\N
8996	534	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01047U	\N	\N
8997	556	2003-06-30 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
8998	556	2003-06-30 00:00:00	2007-02-25 00:00:00	ANCIEN	\N	\N	\N	92024Q	\N	\N
9000	556	2003-06-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
9001	556	2003-06-30 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	77044F	\N	\N
9002	556	2003-06-30 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
9003	556	2003-06-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98046X	\N	\N
9004	556	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01054T	\N	\N
9005	556	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77053G	\N	\N
9006	556	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04090L	\N	\N
9007	556	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80039J	\N	\N
9008	556	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
9009	556	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	03002P	\N	\N
9010	556	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77043E	\N	\N
9012	598	2001-10-01 00:00:00	2005-06-28 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
9013	598	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	\N
9014	598	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04077P	\N	\N
9015	901	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
9017	907	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95005A	\N	\N
9018	907	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04091M	\N	\N
9019	907	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04073K	\N	\N
8481	902	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
8482	902	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	89016Q	\N	\N
8483	902	2003-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95056M	\N	\N
8484	902	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98050T	\N	\N
8485	902	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	80035E	\N	\N
8486	902	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
8487	902	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	80041C	\N	\N
8488	902	2003-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
8489	902	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98012M	\N	\N
8490	902	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	89042S	\N	\N
8491	902	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01034P	\N	\N
8492	902	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	80048K	\N	\N
8493	902	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	89045V	\N	\N
8494	951	2003-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	92011K	\N	\N
8495	951	2003-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77012W	\N	\N
8496	951	2003-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	99003Q	\N	\N
8497	951	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01025N	\N	\N
8499	951	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
8500	951	2003-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
8501	951	2003-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	98027U	\N	\N
8502	951	2003-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95040D	\N	\N
8503	951	2003-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
8504	951	2003-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
8505	951	2003-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95056M	\N	\N
8506	951	2003-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	98050T	\N	\N
8507	951	2003-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80035E	\N	\N
8508	951	2003-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
8509	951	2003-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80041C	\N	\N
8510	951	2003-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
8511	951	2003-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89042S	\N	\N
8512	951	2003-10-01 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	80048K	\N	\N
8513	951	2003-10-01 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	89045V	\N	\N
8514	643	2003-11-28 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95040D	\N	\N
8515	589	2003-06-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98006P	\N	\N
8516	902	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	99003Q	\N	\N
8517	912	2003-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01030K	\N	\N
8518	906	2000-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	02002K	\N	\N
8519	922	2004-09-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
8520	623	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	03002P	\N	\N
8522	534	2004-01-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
8523	594	2004-01-27 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	02002K	\N	\N
8524	598	2004-01-29 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	03002P	\N	\N
8525	643	2004-01-29 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	03002P	\N	\N
8526	600	2004-02-03 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	03002P	\N	\N
8527	613	2004-01-29 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01042P	\N	\N
8528	629	2004-02-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
8529	629	2004-01-13 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	03002P	\N	\N
8531	909	2001-10-26 00:00:00	2004-11-02 00:00:00	ANCIEN	\N	\N	\N	98016R	\N	\N
8533	906	2003-01-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	80013X	\N	\N
8534	906	2003-01-26 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83003J	\N	\N
8536	906	2004-05-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01024M	\N	\N
8537	906	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98036V	\N	\N
8538	906	2004-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
8539	623	2004-05-12 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
8541	624	2004-04-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
8543	918	2004-04-29 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
8544	907	2004-06-01 00:00:00	2005-06-30 00:00:00	ANCIEN	\N	\N	\N	04017B	\N	\N
8545	911	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	80013X	\N	\N
8548	947	2004-06-10 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95040D	\N	\N
8547	584	2004-05-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	02001J	\N	\N
8550	623	2004-07-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
8551	644	2004-05-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
8552	644	2004-05-06 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98007Q	\N	\N
8553	934	2004-07-06 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89042S	\N	\N
8554	623	2004-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
3930	592	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
364	605	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78007E	\N	\N
3354	626	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
1197	600	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
3452	643	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95023C	\N	\N
1139	608	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86025D	\N	\N
8555	918	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01006K	\N	\N
8556	917	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04087R	\N	\N
8559	917	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89030N	\N	\N
8558	917	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
8560	917	2004-10-01 00:00:00	2005-06-30 00:00:00	ANCIEN	\N	\N	\N	04017B	\N	\N
8561	917	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98051U	\N	\N
8562	917	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	98046X	\N	\N
8563	917	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01009N	\N	\N
8579	917	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	83033Q	\N	\N
8581	917	2004-10-01 00:00:00	2005-06-28 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
8584	906	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04087R	\N	\N
8585	906	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95005A	\N	\N
8586	906	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01013J	\N	\N
8587	906	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96004D	\N	\N
8987	556	2003-06-30 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98049B	\N	\N
8988	534	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98003L	\N	\N
8989	556	2003-06-30 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98029W	\N	\N
8990	556	2003-06-30 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
8991	534	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98046X	\N	\N
8992	534	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
8993	534	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83042R	\N	\N
8660	913	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98053W	\N	\N
8661	913	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
8662	913	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
8663	913	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01030K	\N	\N
8664	913	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04077P	\N	\N
8665	913	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80024B	\N	\N
8666	913	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01016M	\N	\N
8667	913	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04033B	\N	\N
8668	913	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89040Q	\N	\N
8669	913	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98037W	\N	\N
8670	583	2004-10-15 00:00:00	2005-06-28 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
8671	583	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01063U	\N	\N
8672	583	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
8673	583	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04038G	\N	\N
8674	583	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	\N
8675	583	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92018S	\N	\N
8677	917	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
8676	583	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04093P	\N	\N
8678	583	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
8679	583	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
8680	583	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
8681	583	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89030N	\N	\N
8682	583	2004-10-15 00:00:00	2005-06-30 00:00:00	ANCIEN	\N	\N	\N	04017B	\N	\N
8683	583	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
8684	583	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98003L	\N	\N
8709	922	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
8686	583	2004-10-15 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
8687	583	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	\N
8688	583	2004-10-15 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	04068N	\N	\N
8689	583	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	03001N	\N	\N
8690	583	2004-10-15 00:00:00	2010-10-18 00:00:00	ANCIEN	\N	\N	\N	92029V	\N	\N
8691	583	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04094Q	\N	\N
8692	583	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98046X	\N	\N
8693	583	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83042R	\N	\N
8694	583	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
8696	583	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04043D	\N	\N
8697	583	2004-11-03 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89037V	\N	\N
8698	583	2004-11-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01029S	\N	\N
8699	583	2004-11-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
8700	583	2004-11-03 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	03002P	\N	\N
8701	583	2004-11-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01062T	\N	\N
8702	583	2004-11-03 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80045G	\N	\N
8705	583	2004-11-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
8706	583	2004-11-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92045V	\N	\N
8707	922	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04091M	\N	\N
8708	922	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01001E	\N	\N
8710	922	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
8711	922	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95024D	\N	\N
8712	922	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95025E	\N	\N
8713	922	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04089T	\N	\N
8714	922	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
8716	922	2004-10-01 00:00:00	2005-06-30 00:00:00	ANCIEN	\N	\N	\N	04017B	\N	\N
8717	922	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04062G	\N	\N
8718	922	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	03001N	\N	\N
8719	922	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92030N	\N	\N
8720	922	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04096S	\N	\N
8721	922	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	02005N	\N	\N
8722	922	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98007Q	\N	\N
8723	922	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89016Q	\N	\N
8724	922	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
11697	906	2008-07-10 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	07023M	\N	\N
8725	918	2004-10-01 00:00:00	2005-03-19 00:00:00	ANCIEN	\N	\N	\N	98008R	\N	\N
8726	922	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01016M	\N	\N
8727	918	2004-10-01 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	80048K	\N	\N
8728	922	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01014K	\N	\N
8729	922	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04090L	\N	\N
8730	922	2004-10-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	04069P	\N	\N
8731	922	2004-10-01 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	98012M	\N	\N
8732	922	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01034P	\N	\N
8733	912	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04091M	\N	\N
8734	912	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01001E	\N	\N
8735	912	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01064V	\N	\N
8736	912	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04073K	\N	\N
8737	912	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
8738	912	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
8739	912	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95013A	\N	\N
8740	912	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
8741	912	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
8742	912	2004-10-01 00:00:00	2007-02-25 00:00:00	ANCIEN	\N	\N	\N	92024Q	\N	\N
8743	912	2004-10-01 00:00:00	2010-10-18 00:00:00	ANCIEN	\N	\N	\N	92029V	\N	\N
8744	912	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04096S	\N	\N
8745	912	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
8746	912	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
8747	912	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98050T	\N	\N
8748	912	2004-10-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
8749	912	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04044E	\N	\N
8750	917	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	82002D	\N	\N
8751	909	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
8752	909	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01006K	\N	\N
8753	909	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01046T	\N	\N
8754	909	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04091M	\N	\N
8755	909	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98048A	\N	\N
8756	909	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04047H	\N	\N
8757	909	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	80013X	\N	\N
8758	909	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80015A	\N	\N
8759	909	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
8760	909	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	87003B	\N	\N
8761	909	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
8762	909	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98053W	\N	\N
8763	909	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
8764	909	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89030N	\N	\N
7890	915	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
7891	915	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
7892	915	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	89016Q	\N	\N
7893	915	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
7894	915	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
7895	915	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
7896	915	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	89037V	\N	\N
7897	915	2001-10-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
7898	915	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
7899	931	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
7900	931	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
7901	931	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	79004F	\N	\N
7902	931	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	89013M	\N	\N
7903	931	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
7904	931	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	92011K	\N	\N
7905	931	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95012Y	\N	\N
7906	931	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92015P	\N	\N
7907	931	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
7908	931	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	98024R	\N	\N
7909	931	2001-10-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	\N
7910	931	2001-03-10 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01030K	\N	\N
7911	931	2003-02-24 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
7912	931	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89016Q	\N	\N
7913	931	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
7914	931	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
7915	934	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98036V	\N	\N
7916	934	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
7918	934	2001-10-01 00:00:00	2004-10-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
7919	934	2001-10-01 00:00:00	2004-10-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
7920	934	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77012W	\N	\N
7921	934	2001-10-01 00:00:00	2004-10-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
7922	934	2001-10-01 00:00:00	2008-10-30 00:00:00	ANCIEN	\N	\N	\N	98023Q	\N	\N
7923	934	2001-10-01 00:00:00	2008-10-30 00:00:00	ANCIEN	\N	\N	\N	92018S	\N	\N
7924	934	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	87003B	\N	\N
7925	934	2001-10-01 00:00:00	2004-10-30 00:00:00	ANCIEN	\N	\N	\N	01027Q	\N	\N
7926	934	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95029J	\N	\N
7928	934	2001-10-01 00:00:00	2004-10-30 00:00:00	ANCIEN	\N	\N	\N	01055U	\N	\N
7929	934	2001-10-01 00:00:00	2004-10-30 00:00:00	ANCIEN	\N	\N	\N	92024Q	\N	\N
7930	934	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
7931	934	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
7932	934	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92030N	\N	\N
7933	934	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
7934	934	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95047L	\N	\N
7935	934	2001-10-01 00:00:00	2008-10-30 00:00:00	ANCIEN	\N	\N	\N	83042R	\N	\N
7936	934	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
7937	934	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
7938	934	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98007Q	\N	\N
7939	934	2001-10-01 00:00:00	2004-10-30 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
7940	934	2001-10-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	95051G	\N	\N
7941	934	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	91002E	\N	\N
7942	934	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
7943	934	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
7944	934	2001-10-01 00:00:00	2004-10-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
7945	934	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77060F	\N	\N
7946	934	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
7947	934	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01062T	\N	\N
7948	934	2001-10-01 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	98012M	\N	\N
7949	934	2001-10-01 00:00:00	2004-10-30 00:00:00	ANCIEN	\N	\N	\N	92044U	\N	\N
7950	934	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01034P	\N	\N
7559	919	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	92008Q	\N	\N
7560	919	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	90003B	\N	\N
7562	919	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80015A	\N	\N
7563	919	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95025E	\N	\N
7564	919	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	\N
7565	919	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
7566	911	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
7567	919	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
7568	911	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	\N
7569	919	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89025R	\N	\N
7570	911	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
7571	911	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	92007P	\N	\N
7572	919	2001-10-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	96005E	\N	\N
7573	911	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89010J	\N	\N
7574	919	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
7575	911	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01064V	\N	\N
7576	919	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	02006P	\N	\N
7577	911	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01049W	\N	\N
7578	919	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
7579	911	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	96004D	\N	\N
7580	919	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98017S	\N	\N
7581	911	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
7582	919	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98003L	\N	\N
7583	911	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	\N
7584	911	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01052R	\N	\N
7585	911	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
7586	919	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98038X	\N	\N
7587	911	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	95025E	\N	\N
7588	911	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98024R	\N	\N
7589	919	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	82002D	\N	\N
7590	911	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
7591	919	2001-10-01 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	77044F	\N	\N
7592	911	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
7593	911	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95030B	\N	\N
7594	911	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	83031N	\N	\N
7595	911	2001-10-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	96005E	\N	\N
7596	911	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
7598	911	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
7597	919	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77047J	\N	\N
7599	911	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98003L	\N	\N
7600	919	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
7601	911	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	88009M	\N	\N
7602	919	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
7603	911	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98027U	\N	\N
7604	919	2001-10-01 00:00:00	2005-03-19 00:00:00	ANCIEN	\N	\N	\N	98008R	\N	\N
7605	919	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	89035T	\N	\N
7606	911	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01018P	\N	\N
7607	919	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
7608	911	2001-10-01 00:00:00	2009-09-09 00:00:00	ANCIEN	\N	\N	\N	80024B	\N	\N
7609	919	2001-10-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	95053J	\N	\N
7610	911	2001-10-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	98025S	\N	\N
7611	919	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
7612	911	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	77043E	\N	\N
7613	919	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
7614	911	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	95047L	\N	\N
7615	919	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
7616	911	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77047J	\N	\N
7617	919	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
7618	911	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
7619	919	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98033S	\N	\N
7620	911	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	73006G	\N	\N
7621	919	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80040B	\N	\N
7622	911	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
7623	919	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01058X	\N	\N
7624	911	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
7625	919	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01050P	\N	\N
7626	911	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	91002E	\N	\N
7628	911	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
7629	919	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01039U	\N	\N
7630	911	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89016Q	\N	\N
7631	919	2001-10-01 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	98012M	\N	\N
8134	937	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
8135	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
8588	906	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
8589	906	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04053F	\N	\N
8590	906	2004-10-01 00:00:00	2007-01-01 00:00:00	ANCIEN	\N	\N	\N	01035Q	\N	\N
8591	906	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95025E	\N	\N
8592	906	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04071H	\N	\N
8593	906	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
8594	906	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
8595	906	2004-10-01 00:00:00	2007-09-30 00:00:00	ANCIEN	\N	\N	\N	04060E	\N	\N
8596	906	2004-10-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	95036H	\N	\N
8597	906	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04037F	\N	\N
8598	906	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
8599	906	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92029V	\N	\N
8600	906	2004-10-01 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
8601	906	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98046X	\N	\N
8602	906	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04083M	\N	\N
8603	906	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04080J	\N	\N
8604	906	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01016M	\N	\N
8605	906	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92042S	\N	\N
8606	906	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01050P	\N	\N
8607	906	2004-10-01 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	98012M	\N	\N
8608	917	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04090L	\N	\N
8609	906	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
8610	906	2004-10-01 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	04068N	\N	\N
8611	577	2004-10-19 00:00:00	2007-06-21 00:00:00	ANCIEN	\N	\N	\N	92007P	\N	\N
8612	577	2004-10-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01001E	\N	\N
8613	577	2004-10-21 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
8614	577	2004-10-21 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98049B	\N	\N
8616	577	2004-10-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98029W	\N	\N
8617	577	2004-10-21 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
8618	577	2004-10-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
8619	577	2004-10-21 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
8620	577	2004-10-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
8621	577	2004-10-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	03001N	\N	\N
8622	577	2004-10-21 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
8623	577	2004-10-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95055L	\N	\N
8624	577	2004-10-21 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
8625	577	2004-10-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
8626	577	2004-10-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04056J	\N	\N
8627	577	2004-10-21 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	03002P	\N	\N
8629	670	2004-11-01 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
8630	581	2004-11-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
8631	581	2004-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
8632	581	2004-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
8633	581	2004-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92008Q	\N	\N
7850	933	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
7851	933	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
7852	933	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89013M	\N	\N
7856	933	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
7865	915	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	\N
7866	915	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98016R	\N	\N
7867	915	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98048A	\N	\N
7868	915	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	95015C	\N	\N
7869	915	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
7870	915	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95023C	\N	\N
7871	915	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	95025E	\N	\N
7872	915	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95029J	\N	\N
7873	915	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	89027T	\N	\N
7874	915	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	95030B	\N	\N
7875	915	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	89030N	\N	\N
7876	915	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
7877	915	2001-10-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	95036H	\N	\N
7878	915	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98003L	\N	\N
7879	915	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	88009M	\N	\N
7880	915	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
7881	915	2001-10-01 00:00:00	2003-11-04 00:00:00	ANCIEN	\N	\N	\N	86031B	\N	\N
7882	915	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	\N
7883	915	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77029G	\N	\N
8242	907	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
8243	907	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
8244	907	2001-10-01 00:00:00	2005-03-19 00:00:00	ANCIEN	\N	\N	\N	98008R	\N	\N
8245	907	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
8246	907	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
8247	907	2001-10-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	95053J	\N	\N
8248	907	2001-10-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
8249	907	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89016Q	\N	\N
8250	907	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	95055L	\N	\N
8251	907	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98021N	\N	\N
8252	907	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	77058M	\N	\N
8253	907	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98050T	\N	\N
8254	907	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86044G	\N	\N
8255	907	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
8256	907	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89037V	\N	\N
8257	907	2001-10-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
8258	907	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01050P	\N	\N
8259	907	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	80045G	\N	\N
8260	907	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
8261	907	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
8262	907	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	80046H	\N	\N
8263	907	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01023L	\N	\N
8264	907	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92045V	\N	\N
8265	948	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95005A	\N	\N
8266	948	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83011J	\N	\N
8267	948	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
8268	948	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01049W	\N	\N
8269	948	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95014B	\N	\N
8270	948	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	\N
8271	948	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01052R	\N	\N
8272	948	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95012Y	\N	\N
8273	948	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
8274	948	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
8275	948	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	90003B	\N	\N
8276	948	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	74050Q	\N	\N
8277	948	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80013X	\N	\N
8278	948	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01059Y	\N	\N
8279	948	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95024D	\N	\N
8280	948	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89027T	\N	\N
8281	948	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95030B	\N	\N
8282	948	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01025N	\N	\N
8283	948	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
8284	948	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
8285	948	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83003J	\N	\N
8286	948	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	\N
8287	948	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	02006P	\N	\N
8288	948	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92024Q	\N	\N
8289	948	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98003L	\N	\N
8290	948	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88009M	\N	\N
8291	948	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	\N
8292	948	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98027U	\N	\N
8293	948	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95040D	\N	\N
8294	948	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
8295	948	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98038X	\N	\N
8296	948	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
8297	948	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
8298	948	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77043E	\N	\N
8299	948	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83042R	\N	\N
8300	948	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
8301	948	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	68036E	\N	\N
8302	948	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	02005N	\N	\N
8303	948	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
8304	948	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98008R	\N	\N
8305	948	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	91002E	\N	\N
8306	948	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
8307	948	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01009N	\N	\N
8308	948	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89016Q	\N	\N
8309	948	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
8310	948	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98050T	\N	\N
8311	948	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98039Y	\N	\N
8312	948	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80046H	\N	\N
8313	948	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01023L	\N	\N
8314	948	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92045V	\N	\N
8315	948	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
8316	948	2001-10-01 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	80048K	\N	\N
8317	948	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89045V	\N	\N
8318	948	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89030N	\N	\N
11596	534	2007-11-01 00:00:00	2010-09-20 00:00:00	ANCIEN	\N	\N	\N	07004J	\N	\N
8321	905	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	95006B	\N	\N
8322	905	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78007E	\N	\N
11598	964	2007-11-27 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	86034E	\N	\N
8325	905	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01052R	\N	\N
11599	919	2007-11-27 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86034E	\N	\N
11600	580	2007-11-01 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	07028S	\N	\N
11602	583	2007-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95059Q	\N	\N
11603	583	2007-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
11606	623	2007-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	07028S	\N	\N
8332	905	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77012W	\N	\N
8333	905	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
8334	905	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01012H	\N	\N
8335	905	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77017C	\N	\N
8336	905	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
11607	951	2008-01-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
8338	905	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95023C	\N	\N
8339	905	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	95025E	\N	\N
8340	905	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86021Y	\N	\N
8341	905	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	\N
11618	948	2005-02-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04033B	\N	\N
11626	901	2008-02-14 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	86034E	\N	\N
8344	905	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95029J	\N	\N
7531	913	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
7532	913	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88009M	\N	\N
7533	913	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	\N
7534	913	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01021J	\N	\N
7535	913	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	85003S	\N	\N
7536	913	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
7537	913	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
7538	913	2001-10-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	86034E	\N	\N
7539	913	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	93007T	\N	\N
7540	913	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	91002E	\N	\N
7541	913	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
7542	913	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
7543	913	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98033S	\N	\N
7544	913	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01058X	\N	\N
7545	913	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01050P	\N	\N
7546	913	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01028R	\N	\N
7547	913	2001-10-01 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	98012M	\N	\N
7548	913	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
7549	913	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
7552	919	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
7553	919	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01064V	\N	\N
7554	919	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
7555	919	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01049W	\N	\N
7557	919	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01052R	\N	\N
7558	919	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98049B	\N	\N
7951	934	2001-10-01 00:00:00	2004-10-30 00:00:00	ANCIEN	\N	\N	\N	80048K	\N	\N
7952	934	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
7953	934	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01009N	\N	\N
7954	920	2001-10-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	95053J	\N	\N
7955	901	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	\N
7956	901	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
7957	901	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
7959	901	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01012H	\N	\N
7960	901	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
7961	901	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
7963	901	2001-10-01 00:00:00	2004-01-30 00:00:00	ANCIEN	\N	\N	\N	02004M	\N	\N
7964	901	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	93007T	\N	\N
7965	901	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
7966	901	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
7967	901	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
7968	901	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
7970	901	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89040Q	\N	\N
7971	901	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
7972	901	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80046H	\N	\N
7973	901	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01010F	\N	\N
7974	901	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	91002E	\N	\N
7975	933	2003-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	59569E	\N	\N
7976	529	2003-06-25 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
7977	529	2003-06-25 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77012W	\N	\N
7978	529	2003-06-25 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	96005E	\N	\N
7979	529	2003-06-25 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
7980	529	2003-06-25 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77029G	\N	\N
7983	529	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
7984	529	1999-01-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	95051G	\N	\N
7985	529	1999-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
7986	529	1999-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
7987	915	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01013J	\N	\N
7988	947	2002-12-04 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
7989	947	2002-12-04 00:00:00	2004-03-01 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	\N
7990	947	2002-12-04 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
7991	947	2002-12-04 00:00:00	2003-11-04 00:00:00	ANCIEN	\N	\N	\N	86031B	\N	\N
7992	947	2002-12-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98027U	\N	\N
7993	947	2002-12-04 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
7994	947	2002-12-04 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
7995	947	2002-12-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01009N	\N	\N
7996	947	2002-12-04 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	95053J	\N	\N
7997	947	2002-12-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
7998	947	2002-12-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01029S	\N	\N
7999	947	2002-12-04 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	80041C	\N	\N
8000	947	2002-12-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01028R	\N	\N
8001	947	2002-12-04 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
8002	947	2002-12-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01062T	\N	\N
8003	947	2002-12-04 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92044U	\N	\N
8004	947	2002-12-04 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89042S	\N	\N
8005	947	2002-12-04 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	80048K	\N	\N
8006	947	2002-12-04 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	89045V	\N	\N
8007	947	2002-12-04 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
8008	910	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95005A	\N	\N
8009	910	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98036V	\N	\N
8010	910	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	79004F	\N	\N
8011	910	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	89013M	\N	\N
8012	910	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
8013	910	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95014B	\N	\N
8014	910	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	92013M	\N	\N
8015	910	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98049B	\N	\N
8016	910	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
8017	910	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98029W	\N	\N
8018	910	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98023Q	\N	\N
8019	910	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95023C	\N	\N
8020	910	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98024R	\N	\N
8021	910	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	99003Q	\N	\N
8022	910	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	89025R	\N	\N
8023	910	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
8024	910	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
8025	910	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
8026	910	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	88009M	\N	\N
8027	910	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	\N
8028	910	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95040D	\N	\N
8029	910	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
8030	910	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	80024B	\N	\N
8031	910	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
8032	910	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	95047L	\N	\N
8033	910	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98008R	\N	\N
8034	910	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	91002E	\N	\N
8035	910	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86041D	\N	\N
8036	910	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95056M	\N	\N
8037	910	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
8038	910	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	80040B	\N	\N
8039	910	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
8040	910	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98012M	\N	\N
8041	910	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	89042S	\N	\N
8042	910	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
8043	910	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	80048K	\N	\N
8044	910	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	88012G	\N	\N
13249	938	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	\N
8046	938	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	79004F	\N	\N
11747	604	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	02053W	\N	\N
8049	938	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
8050	938	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
8052	938	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98029W	\N	\N
8053	938	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86018E	\N	\N
8054	938	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
8055	938	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
8056	938	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	83031N	\N	\N
13263	912	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
8058	938	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
8059	938	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
8060	938	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77029G	\N	\N
13270	979	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
8062	938	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01054T	\N	\N
13271	979	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	\N
8064	938	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
8065	938	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	89016Q	\N	\N
8066	938	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98039Y	\N	\N
8067	938	2001-10-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
8068	938	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	80040B	\N	\N
8071	938	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	80046H	\N	\N
8074	938	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
8073	938	2001-10-01 00:00:00	2004-07-19 00:00:00	ANCIEN	\N	\N	\N	96003C	\N	\N
8075	938	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
8076	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95004Y	\N	\N
8077	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
8078	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95005A	\N	\N
8079	937	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	98036V	\N	\N
8080	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83011J	\N	\N
8081	937	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
8082	937	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
8083	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92007P	\N	\N
8084	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	79004F	\N	\N
8085	937	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	89013M	\N	\N
8086	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89010J	\N	\N
8087	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
8088	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	96004D	\N	\N
8089	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	92011K	\N	\N
8090	937	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	\N
8091	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88004G	\N	\N
8092	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95012Y	\N	\N
8093	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95013A	\N	\N
8094	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
8095	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98048A	\N	\N
8096	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95015C	\N	\N
8097	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98029W	\N	\N
8098	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95017E	\N	\N
8099	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77012W	\N	\N
8100	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86018E	\N	\N
8101	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95020Y	\N	\N
8102	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
8103	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95023C	\N	\N
8104	937	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	95024D	\N	\N
8105	937	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01024M	\N	\N
8106	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
8107	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	99003Q	\N	\N
8108	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90002A	\N	\N
8109	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95029J	\N	\N
8110	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89027T	\N	\N
8111	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
8112	937	2001-10-01 00:00:00	2004-10-18 00:00:00	ANCIEN	\N	\N	\N	96005E	\N	\N
8113	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98053W	\N	\N
8114	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95033E	\N	\N
8115	937	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	83033Q	\N	\N
8116	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98047Y	\N	\N
8117	937	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01017N	\N	\N
8118	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	\N
8119	937	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
8120	937	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89030N	\N	\N
8121	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98017S	\N	\N
8122	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
8123	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01011G	\N	\N
8124	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
8125	937	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98003L	\N	\N
9123	632	2004-10-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
9124	632	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04056J	\N	\N
9126	661	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	\N
9128	661	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
9129	661	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89019T	\N	\N
9130	661	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
9131	661	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
9132	661	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04063H	\N	\N
9133	661	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
9134	661	2004-10-01 00:00:00	2005-06-28 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
9135	661	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04055H	\N	\N
9137	661	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
9138	661	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
9139	661	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
9140	661	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04077P	\N	\N
9141	661	2004-10-01 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	77044F	\N	\N
9142	661	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
9143	661	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01054T	\N	\N
9144	661	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98050T	\N	\N
9145	661	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80040B	\N	\N
9146	661	2004-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	04056J	\N	\N
9147	661	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
9148	661	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98049B	\N	\N
9151	605	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
9152	605	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04091M	\N	\N
9153	605	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	\N
9154	605	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
9155	605	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
9156	605	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
9157	605	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
9158	605	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	02002K	\N	\N
9159	605	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	02001J	\N	\N
9160	605	2004-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
9161	605	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	\N
9162	605	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01022K	\N	\N
9163	532	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
9164	605	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04041B	\N	\N
9166	605	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	03001N	\N	\N
9167	605	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
9168	605	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01018P	\N	\N
9169	605	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
9170	605	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80024B	\N	\N
9171	605	2004-10-01 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	77044F	\N	\N
9172	605	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
9173	605	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04083M	\N	\N
9175	605	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
9174	583	2004-10-01 00:00:00	2010-10-11 00:00:00	ANCIEN	\N	\N	\N	01017N	\N	\N
9176	605	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89016Q	\N	\N
9177	605	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83047W	\N	\N
9178	605	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92042S	\N	\N
9179	605	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01014K	\N	\N
9180	605	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01034P	\N	\N
9181	605	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
9182	605	2004-10-01 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	98012M	\N	\N
9183	608	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	\N
9184	608	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
9185	608	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
9186	608	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
9187	608	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
9188	608	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04055H	\N	\N
9189	608	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
9190	608	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
9191	608	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
9192	608	2004-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
9193	608	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98038X	\N	\N
9194	608	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98046X	\N	\N
9195	608	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
9196	608	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04080J	\N	\N
9197	608	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04043D	\N	\N
9198	608	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	03002P	\N	\N
9199	608	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04044E	\N	\N
9200	608	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
9201	608	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
9202	590	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95006B	\N	\N
9203	590	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	\N
9204	590	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01064V	\N	\N
9205	590	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92011K	\N	\N
9206	590	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
9208	590	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92008Q	\N	\N
9209	590	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04055H	\N	\N
9210	590	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
9211	590	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
9212	590	2004-10-01 00:00:00	2005-06-30 00:00:00	ANCIEN	\N	\N	\N	04017B	\N	\N
9214	590	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
8345	905	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01026P	\N	\N
8346	905	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01025N	\N	\N
8347	905	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
8348	905	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
11595	609	2007-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04082L	\N	\N
8350	905	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	02001J	\N	\N
8351	905	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	\N
11622	964	2008-02-05 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	95059Q	\N	\N
11629	901	2008-02-22 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89037V	\N	\N
8354	905	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
8355	905	2001-10-01 00:00:00	2003-11-04 00:00:00	ANCIEN	\N	\N	\N	86031B	\N	\N
11632	901	2008-02-22 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01006K	\N	\N
8357	905	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	77029G	\N	\N
11638	595	2008-02-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04081K	\N	\N
8359	905	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98027U	\N	\N
8360	905	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95040D	\N	\N
8361	905	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98034T	\N	\N
11639	597	2008-02-01 00:00:00	2010-09-24 00:00:00	ANCIEN	\N	\N	\N	07004J	\N	\N
8363	905	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	88013H	\N	\N
8366	905	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
8365	905	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	82002D	\N	\N
8367	905	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98051U	\N	\N
8369	905	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01004H	\N	\N
8370	905	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
8371	905	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	68036E	\N	\N
11707	659	2008-07-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92011K	\N	\N
8373	905	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
11615	965	2008-02-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
8375	905	2001-10-01 00:00:00	2004-02-12 00:00:00	ANCIEN	\N	\N	\N	95053J	\N	\N
8376	905	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
11623	919	2008-02-05 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95059Q	\N	\N
8378	905	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95057N	\N	\N
8379	905	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95058P	\N	\N
11624	901	2008-02-22 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
8381	905	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	80035E	\N	\N
11698	974	2008-07-10 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	07023M	\N	\N
11630	901	2008-02-15 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
8384	905	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
11693	583	2008-05-19 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92022N	\N	\N
8386	905	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
11708	659	2008-07-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
11710	659	2008-07-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01055U	\N	\N
11711	659	2008-07-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01033N	\N	\N
8391	905	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	86050E	\N	\N
8392	905	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	89045V	\N	\N
8393	670	2003-06-30 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	01051Q	\N	\N
8394	670	2004-06-30 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
8395	670	2003-06-30 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
8396	670	2003-06-30 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	01012H	\N	\N
8397	670	2003-06-30 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	\N
8807	624	2004-10-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04063H	\N	\N
8808	624	2004-10-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
8809	624	2004-10-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
8810	624	2004-10-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01012H	\N	\N
8811	624	2004-10-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80015A	\N	\N
8812	624	2004-10-18 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	92022N	\N	\N
8813	624	2004-10-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
8814	624	2004-10-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
8815	624	2004-10-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
8816	624	2004-10-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04075M	\N	\N
8817	624	2004-10-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01030K	\N	\N
8818	624	2004-10-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
8819	624	2004-10-18 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	77044F	\N	\N
8820	624	2004-10-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
8821	624	2004-10-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98050T	\N	\N
8822	624	2004-10-18 00:00:00	2005-12-19 00:00:00	ANCIEN	\N	\N	\N	01039U	\N	\N
8823	624	2004-10-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80045G	\N	\N
8824	624	2004-10-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04082L	\N	\N
8827	642	2004-10-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	\N
8828	642	2004-10-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98016R	\N	\N
8829	642	2004-10-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98029W	\N	\N
8830	642	2004-10-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92008Q	\N	\N
8831	642	2004-10-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
8832	642	2004-10-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
8833	642	2004-10-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
8835	642	2004-10-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
8836	642	2004-10-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01022K	\N	\N
8837	642	2004-10-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	03001N	\N	\N
8838	642	2004-10-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
8839	642	2004-10-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04096S	\N	\N
8840	642	2004-10-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98013N	\N	\N
8841	642	2004-10-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
8842	642	2004-10-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
8843	642	2004-10-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01016M	\N	\N
8845	642	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01029S	\N	\N
8848	642	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	03002P	\N	\N
8849	642	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04082L	\N	\N
8857	670	2004-10-22 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
8858	670	2003-06-30 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
8859	670	2003-06-30 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	01054T	\N	\N
8860	670	2003-06-30 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
8861	670	2003-06-30 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	80040B	\N	\N
8863	529	2003-06-30 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
8864	529	2003-06-30 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
8865	529	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04038G	\N	\N
8866	529	2003-06-30 00:00:00	2005-06-30 00:00:00	ANCIEN	\N	\N	\N	04017B	\N	\N
8867	901	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
8868	901	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
8869	901	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	\N
8870	901	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	82002D	\N	\N
8872	901	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80035E	\N	\N
8871	529	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
8873	529	2004-10-15 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
8874	529	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
8875	529	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
8876	529	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89016Q	\N	\N
8877	529	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
8880	591	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04087R	\N	\N
8881	591	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
8882	591	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98016R	\N	\N
8883	591	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
8884	591	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
8885	591	2004-10-15 00:00:00	2007-01-01 00:00:00	ANCIEN	\N	\N	\N	01035Q	\N	\N
8886	591	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
8887	591	2004-10-15 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
8888	591	2004-10-15 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	77044F	\N	\N
8889	591	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98046X	\N	\N
8890	591	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95055L	\N	\N
8891	591	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98050T	\N	\N
8894	598	2003-06-30 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98036V	\N	\N
8895	598	2003-06-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04059M	\N	\N
8896	598	2003-06-30 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
8897	598	2003-06-30 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92011K	\N	\N
8898	620	2004-10-15 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
9579	625	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
9580	625	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04080J	\N	\N
9581	625	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92043T	\N	\N
9582	625	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01010F	\N	\N
9587	623	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89010J	\N	\N
9588	623	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	02003L	\N	\N
9590	623	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01045S	\N	\N
9591	623	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
9592	623	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
9593	623	2004-10-01 00:00:00	2007-09-30 00:00:00	ANCIEN	\N	\N	\N	04060E	\N	\N
9594	623	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
9596	623	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04044E	\N	\N
9599	590	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
9600	594	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	82002D	\N	\N
9602	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04087R	\N	\N
9603	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
9604	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	\N
9605	626	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04091M	\N	\N
9606	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89019T	\N	\N
9607	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
9608	626	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
9609	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04052E	\N	\N
9611	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	02003L	\N	\N
9612	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04053F	\N	\N
9614	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04042C	\N	\N
9616	626	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	00003C	\N	\N
9617	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
9619	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92015P	\N	\N
9620	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
9621	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92008Q	\N	\N
9622	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95019G	\N	\N
9624	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04038G	\N	\N
9626	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
9627	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04046G	\N	\N
9628	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	\N
9629	626	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	\N
9630	626	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
9631	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89027T	\N	\N
9632	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95030B	\N	\N
9633	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98053W	\N	\N
9634	626	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
9636	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
9637	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	88009M	\N	\N
9638	626	2004-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
9639	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01033N	\N	\N
9640	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	\N
9321	585	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
9322	585	2004-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
9323	585	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04041B	\N	\N
9324	585	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	82002D	\N	\N
9325	585	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92030N	\N	\N
9327	573	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
9331	582	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
9333	582	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
9334	582	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
9342	582	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
9332	573	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98016R	\N	\N
9335	573	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92018S	\N	\N
9336	573	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89025R	\N	\N
9337	573	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
9339	573	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
9340	573	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
9341	573	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01022K	\N	\N
9343	573	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04078Q	\N	\N
9344	582	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
9345	573	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04062G	\N	\N
9346	582	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
9347	573	2004-10-01 00:00:00	2010-10-18 00:00:00	ANCIEN	\N	\N	\N	92029V	\N	\N
9348	573	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01042P	\N	\N
9349	582	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04041B	\N	\N
9350	573	2004-10-01 00:00:00	2009-09-09 00:00:00	ANCIEN	\N	\N	\N	80024B	\N	\N
9351	573	2004-10-01 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	77044F	\N	\N
9353	582	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
9352	573	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04096S	\N	\N
9354	573	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
9355	582	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80040B	\N	\N
9356	573	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
9358	582	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
9357	573	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77053G	\N	\N
9359	573	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
9360	582	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89042S	\N	\N
9361	573	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
9362	573	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01016M	\N	\N
9363	573	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04090L	\N	\N
9364	573	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98039Y	\N	\N
9365	573	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04056J	\N	\N
9366	573	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92044U	\N	\N
9367	573	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
9369	579	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95005A	\N	\N
9370	579	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	\N
9371	579	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01049W	\N	\N
9372	579	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
9373	579	2004-10-01 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	71003U	\N	\N
9374	579	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
9641	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	\N
9642	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04077P	\N	\N
9643	626	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	03001N	\N	\N
9644	626	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
9646	626	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98005N	\N	\N
9647	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04076N	\N	\N
9648	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95044H	\N	\N
9649	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04079R	\N	\N
9650	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95046K	\N	\N
9651	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98046X	\N	\N
9652	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83042R	\N	\N
9683	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
9684	912	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	96004D	\N	\N
9655	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	73006G	\N	\N
9656	626	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
9657	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	02005N	\N	\N
9658	626	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01054T	\N	\N
9659	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
9660	626	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77058M	\N	\N
9661	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
9662	626	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01016M	\N	\N
9663	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04090L	\N	\N
9664	626	2004-10-01 00:00:00	2005-12-31 00:00:00	ANCIEN	\N	\N	\N	89037V	\N	\N
9666	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
9667	626	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92043T	\N	\N
9668	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86053H	\N	\N
9669	626	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
9670	626	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04056J	\N	\N
9243	584	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	\N
9244	584	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
9245	584	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
9246	584	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
9247	584	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98041S	\N	\N
9248	584	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01055U	\N	\N
9249	584	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01017N	\N	\N
9250	584	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89030N	\N	\N
9251	584	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01011G	\N	\N
9252	584	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
9253	584	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	\N
9254	584	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04078Q	\N	\N
9255	584	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	03001N	\N	\N
9256	584	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98051U	\N	\N
9257	584	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92033R	\N	\N
9258	584	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
9259	584	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95046K	\N	\N
9260	584	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98046X	\N	\N
9261	584	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83042R	\N	\N
9262	584	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
9263	584	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04083M	\N	\N
9264	584	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
9265	584	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77053G	\N	\N
9267	584	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04080J	\N	\N
9269	584	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80040B	\N	\N
9270	584	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01036R	\N	\N
9271	584	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92043T	\N	\N
9272	584	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01050P	\N	\N
9273	584	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01028R	\N	\N
9274	584	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	03002P	\N	\N
9275	584	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04044E	\N	\N
9276	584	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01023L	\N	\N
9277	584	2004-10-01 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	80048K	\N	\N
9279	584	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04082L	\N	\N
9280	584	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04034C	\N	\N
9281	584	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
9289	618	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
9290	618	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
9291	618	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
9292	618	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
9293	618	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95019G	\N	\N
9294	618	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
9295	618	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
9296	618	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	02001J	\N	\N
9297	618	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01055U	\N	\N
9299	618	2005-02-21 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95036H	\N	\N
9300	618	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04078Q	\N	\N
9301	618	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	03001N	\N	\N
9302	618	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98051U	\N	\N
9303	618	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98046X	\N	\N
9304	618	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
9305	618	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98050T	\N	\N
9306	618	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04090L	\N	\N
9307	618	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01050P	\N	\N
9308	618	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
9309	618	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04044E	\N	\N
9310	618	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
9311	618	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92045V	\N	\N
9312	901	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04071H	\N	\N
9314	909	2005-02-21 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
9315	909	2005-02-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95036H	\N	\N
9317	585	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04087R	\N	\N
9318	585	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
9319	585	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98016R	\N	\N
8973	532	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
8974	532	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01023L	\N	\N
8975	532	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01047U	\N	\N
8980	534	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
8981	534	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04073K	\N	\N
8983	534	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
8984	534	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04086Q	\N	\N
8985	534	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
8986	534	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
9421	623	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01041N	\N	\N
9422	623	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01001E	\N	\N
9423	623	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
9424	623	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
9425	623	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
9426	623	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01055U	\N	\N
9427	623	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
9428	623	2005-02-21 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95036H	\N	\N
9429	623	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92029V	\N	\N
9430	623	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89016Q	\N	\N
9431	623	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83047W	\N	\N
9432	623	2004-10-01 00:00:00	2007-06-21 00:00:00	ANCIEN	\N	\N	\N	92007P	\N	\N
9433	623	2004-10-01 00:00:00	2005-06-30 00:00:00	ANCIEN	\N	\N	\N	04017B	\N	\N
9436	609	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	\N
9437	609	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
9438	609	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
9439	609	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
9440	609	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
9441	609	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98049B	\N	\N
9442	609	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
9443	609	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
9444	609	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04055H	\N	\N
9445	609	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01012H	\N	\N
9446	609	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	\N
9447	609	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
9448	609	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
9449	609	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
9450	609	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01055U	\N	\N
9451	609	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
9452	609	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
9453	609	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98005N	\N	\N
9454	609	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
9455	609	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
9456	609	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98046X	\N	\N
9457	609	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83042R	\N	\N
9458	609	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80040B	\N	\N
9459	609	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
9460	609	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89040Q	\N	\N
9461	609	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92043T	\N	\N
9462	609	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	03002P	\N	\N
9463	609	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
9464	609	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92045V	\N	\N
9466	599	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
9467	599	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	\N
9468	599	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04041B	\N	\N
9470	901	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	95025E	\N	\N
9471	934	2004-10-01 00:00:00	2008-10-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	\N
9472	934	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
9473	934	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
9474	934	2004-10-01 00:00:00	2005-06-28 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
9475	934	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
9476	934	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98003L	\N	\N
9477	934	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	\N
9478	934	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	\N
9479	934	2004-10-01 00:00:00	2007-01-25 00:00:00	ANCIEN	\N	\N	\N	89006N	\N	\N
9480	934	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04083M	\N	\N
9481	934	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04090L	\N	\N
9482	917	2004-12-09 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	98027U	\N	\N
9484	601	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04087R	\N	\N
9487	601	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
9488	601	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98016R	\N	\N
9489	601	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
9490	601	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	00003C	\N	\N
9491	601	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
9492	601	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
9493	601	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04086Q	\N	\N
9494	601	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
9495	601	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
9496	601	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
9497	601	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	02001J	\N	\N
9499	601	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89030N	\N	\N
9500	601	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
9501	601	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01007L	\N	\N
9502	601	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
9503	601	2004-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
9504	601	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04037F	\N	\N
9505	601	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04076N	\N	\N
9506	601	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
9510	601	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
9511	601	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92045V	\N	\N
9513	572	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01063U	\N	\N
9515	572	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	\N
9516	572	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
9518	572	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
9519	572	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	\N
9520	572	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
9521	572	2004-10-01 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	77044F	\N	\N
9522	572	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
9523	572	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
8765	909	2004-10-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	95036H	\N	\N
8766	909	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01057W	\N	\N
8767	909	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04041B	\N	\N
8768	909	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
8769	909	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98038X	\N	\N
8770	909	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92030N	\N	\N
8771	909	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
8772	909	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	02005N	\N	\N
8773	909	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77053G	\N	\N
8774	909	2004-10-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
8775	909	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98033S	\N	\N
8776	909	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
8777	909	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98037W	\N	\N
8778	909	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04044E	\N	\N
8779	909	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
8780	909	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04073K	\N	\N
8786	904	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89030N	\N	\N
8787	904	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
8788	904	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
8789	904	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
8790	904	2004-10-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
8791	904	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95055L	\N	\N
8792	904	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04066L	\N	\N
8793	904	2004-10-01 00:00:00	2005-06-28 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
8794	904	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04093P	\N	\N
8795	904	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
8796	947	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04073K	\N	\N
8797	947	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98049B	\N	\N
8798	947	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	\N
8799	947	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
8800	947	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04084N	\N	\N
8801	947	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
8802	947	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
8803	947	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04044E	\N	\N
8804	624	2004-10-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	\N
8805	624	2004-10-16 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
8899	620	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04063H	\N	\N
8900	620	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04066L	\N	\N
8901	620	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04081K	\N	\N
8902	598	2003-06-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04063H	\N	\N
8903	620	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89030N	\N	\N
8904	620	2004-10-15 00:00:00	2007-02-25 00:00:00	ANCIEN	\N	\N	\N	92024Q	\N	\N
8905	620	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
8906	620	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98022P	\N	\N
8907	620	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
8908	598	2003-06-30 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04066L	\N	\N
8909	598	2003-06-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04042C	\N	\N
8911	620	2003-06-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77053G	\N	\N
8912	598	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83033Q	\N	\N
8913	598	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
8914	598	2004-10-01 00:00:00	2005-06-30 00:00:00	ANCIEN	\N	\N	\N	04017B	\N	\N
8915	598	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01007L	\N	\N
8916	598	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04075M	\N	\N
8917	598	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
8918	598	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	03001N	\N	\N
8919	598	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92029V	\N	\N
8920	598	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
8923	598	2004-10-01 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	77044F	\N	\N
8922	598	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01042P	\N	\N
8924	598	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04083M	\N	\N
8925	598	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04084N	\N	\N
8926	598	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
8927	598	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
8928	598	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77053G	\N	\N
8929	598	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89016Q	\N	\N
8930	598	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04090L	\N	\N
8931	598	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01010F	\N	\N
8932	598	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01047U	\N	\N
8933	620	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
8934	620	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04034C	\N	\N
8935	620	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04079R	\N	\N
8936	641	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
8937	641	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
8938	641	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
8940	641	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04086Q	\N	\N
8941	641	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92022N	\N	\N
8942	641	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
8943	641	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04041B	\N	\N
8944	641	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	03001N	\N	\N
8946	641	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80040B	\N	\N
8947	641	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01023L	\N	\N
8948	616	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	\N
8634	581	2004-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
8635	581	2004-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
8637	581	2004-11-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
8638	581	2004-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
8639	581	2004-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
8640	581	2004-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	02005N	\N	\N
8641	581	2004-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83050R	\N	\N
8642	581	2004-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
8643	581	2004-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
8644	581	2004-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04034C	\N	\N
8645	583	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
8646	583	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	\N
8647	583	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01001E	\N	\N
8648	583	2004-10-15 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
8649	583	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04052E	\N	\N
8650	913	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01064V	\N	\N
8651	913	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04038G	\N	\N
8652	913	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89042S	\N	\N
8654	913	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
8655	913	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01049W	\N	\N
8656	913	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
8657	913	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04052E	\N	\N
8658	913	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
9020	907	2004-10-01 00:00:00	2007-01-01 00:00:00	ANCIEN	\N	\N	\N	01035Q	\N	\N
9021	907	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95025E	\N	\N
9022	907	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04089T	\N	\N
9023	907	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98041S	\N	\N
9024	907	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89030N	\N	\N
9025	907	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01033N	\N	\N
9026	907	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04096S	\N	\N
9027	907	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04083M	\N	\N
9028	907	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	02005N	\N	\N
9029	907	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
9030	907	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04082L	\N	\N
9031	908	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
9032	908	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
9033	908	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	90003B	\N	\N
9034	908	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04093P	\N	\N
9035	908	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	\N
9036	908	2004-10-01 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	04068N	\N	\N
9037	908	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04083M	\N	\N
9039	620	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04090L	\N	\N
9040	901	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
9041	922	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04083M	\N	\N
9042	602	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01001E	\N	\N
9043	602	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01049W	\N	\N
9044	602	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
9045	602	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92011K	\N	\N
9046	602	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
9047	602	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04052E	\N	\N
9048	602	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95013A	\N	\N
9049	602	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04047H	\N	\N
9050	602	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04042C	\N	\N
9051	602	2004-10-01 00:00:00	2005-06-28 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
9052	602	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95019G	\N	\N
9053	602	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04038G	\N	\N
9054	602	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04086Q	\N	\N
9055	602	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04093P	\N	\N
9056	602	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
9057	602	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01025N	\N	\N
9058	602	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
9059	602	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	02001J	\N	\N
9060	602	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89030N	\N	\N
9061	602	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
9062	602	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
9063	602	2004-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
9064	602	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01033N	\N	\N
9065	602	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	\N
9066	602	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04078Q	\N	\N
9067	602	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	\N
9068	602	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	03001N	\N	\N
9069	602	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92029V	\N	\N
9070	602	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98005N	\N	\N
9071	602	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	82002D	\N	\N
9072	602	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04096S	\N	\N
9073	602	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77053G	\N	\N
9074	602	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89016Q	\N	\N
9075	602	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04074L	\N	\N
9076	602	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01016M	\N	\N
9077	602	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04090L	\N	\N
9078	602	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89037V	\N	\N
9079	602	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01029S	\N	\N
9080	602	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
9083	602	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01028R	\N	\N
9084	602	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04056J	\N	\N
9085	602	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	03002P	\N	\N
9086	602	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01062T	\N	\N
9088	922	2004-12-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	02003L	\N	\N
9090	594	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
9091	594	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
9092	594	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92008Q	\N	\N
9093	594	2004-10-01 00:00:00	2007-01-01 00:00:00	ANCIEN	\N	\N	\N	01035Q	\N	\N
9094	594	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
9095	594	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
9097	594	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
9098	594	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	\N
9099	594	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98013N	\N	\N
9100	594	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
9101	594	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92043T	\N	\N
9102	594	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
9103	632	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01006K	\N	\N
9104	632	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04085P	\N	\N
9108	632	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
9109	632	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01013J	\N	\N
9110	632	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89019T	\N	\N
9112	632	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04063H	\N	\N
9113	632	2004-10-01 00:00:00	2005-06-28 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
9114	632	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92018S	\N	\N
9115	632	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
9116	632	2004-10-01 00:00:00	2007-10-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
9117	632	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04077P	\N	\N
9118	632	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
9119	632	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
9120	632	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04084N	\N	\N
10522	622	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
10523	622	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95055L	\N	\N
10524	622	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
10525	622	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92043T	\N	\N
10526	622	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01023L	\N	\N
10527	622	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04034C	\N	\N
10528	578	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04087R	\N	\N
10529	578	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
10530	578	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
10531	578	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
10532	578	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92008Q	\N	\N
10533	578	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	90003B	\N	\N
10535	578	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95024D	\N	\N
10536	578	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95025E	\N	\N
10537	578	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
10538	578	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95032D	\N	\N
10539	578	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
10540	578	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
10541	578	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
10514	622	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
10542	578	2004-10-01 00:00:00	2007-09-30 00:00:00	ANCIEN	\N	\N	\N	04060E	\N	\N
10543	578	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	88009M	\N	\N
10544	578	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04080J	\N	\N
10545	578	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80040B	\N	\N
10547	578	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	03002P	\N	\N
10548	578	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01010F	\N	\N
10549	578	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04082L	\N	\N
10550	578	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98049B	\N	\N
10558	590	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	\N
10559	629	2004-10-01 00:00:00	2008-04-18 00:00:00	ANCIEN	\N	\N	\N	95031C	\N	\N
10560	629	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	\N
10561	640	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98047Y	\N	\N
10562	589	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04052E	\N	\N
10563	589	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
10564	643	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01027Q	\N	\N
10565	904	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
10566	924	2005-04-11 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
10567	924	2005-04-11 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	\N
10568	924	2005-04-11 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
10570	938	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
10571	851	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04087R	\N	\N
10150	633	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04090L	\N	\N
10151	633	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	03002P	\N	\N
10154	634	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01001E	\N	\N
10155	634	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01044R	\N	\N
10156	634	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
10157	634	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
10158	634	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04046G	\N	\N
10159	634	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89027T	\N	\N
10160	634	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
10161	634	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
10172	621	2004-10-01 00:00:00	2005-06-30 00:00:00	ANCIEN	\N	\N	\N	04017B	\N	\N
10163	634	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01011G	\N	\N
10164	634	2004-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
10165	634	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
10167	634	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
10169	634	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80039J	\N	\N
10170	634	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	03002P	\N	\N
10173	627	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	\N
10174	627	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04063H	\N	\N
10175	627	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
10176	627	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04051D	\N	\N
10177	627	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
10178	627	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04084N	\N	\N
10179	627	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	03002P	\N	\N
10180	627	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89042S	\N	\N
10181	648	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
10182	573	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	\N
10183	585	2004-10-01 00:00:00	2008-09-24 00:00:00	ANCIEN	\N	\N	\N	88004G	\N	\N
10184	585	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
10186	634	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04090L	\N	\N
10187	604	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04074L	\N	\N
10198	592	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98049B	\N	\N
10194	922	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98047Y	\N	\N
10199	592	2004-10-01 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	80048K	\N	\N
10200	640	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98038X	\N	\N
10202	629	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	02003L	\N	\N
10203	629	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01033N	\N	\N
10204	911	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01022K	\N	\N
10205	928	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
10206	928	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	77053G	\N	\N
10207	908	2004-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95004Y	\N	\N
10208	908	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	03002P	\N	\N
10210	662	2004-10-01 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	04087R	\N	\N
10213	662	2004-10-01 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
10214	662	2004-10-01 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
10215	662	2004-10-01 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
10216	662	2004-10-01 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
10217	662	2004-10-01 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	89021M	\N	\N
10218	662	2004-10-01 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
10219	571	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
10220	571	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01026P	\N	\N
10221	571	2004-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
10223	571	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98013N	\N	\N
10224	571	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
10225	571	2004-10-01 00:00:00	2005-03-19 00:00:00	ANCIEN	\N	\N	\N	98008R	\N	\N
16344	908	2011-10-01 00:00:00	2014-04-24 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
10227	571	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89016Q	\N	\N
10228	571	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
10230	615	2004-10-01 00:00:00	2009-04-28 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
10233	615	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
10234	615	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04063H	\N	\N
10235	615	2004-10-01 00:00:00	2009-04-28 00:00:00	ANCIEN	\N	\N	\N	83033Q	\N	\N
10236	615	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
10237	615	2004-10-01 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	77044F	\N	\N
10238	530	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
10239	530	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	\N
10240	530	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01049W	\N	\N
10241	530	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
9825	575	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04077P	\N	\N
9826	575	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	03001N	\N	\N
9827	575	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
9828	575	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
9829	575	2004-10-01 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	77044F	\N	\N
9830	575	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95046K	\N	\N
9831	575	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04084N	\N	\N
9832	575	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77053G	\N	\N
9833	575	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
9834	575	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
9835	575	2004-10-01 00:00:00	2008-05-30 00:00:00	ANCIEN	\N	\N	\N	04056J	\N	\N
9836	575	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
9837	575	2004-10-01 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	89043T	\N	\N
9838	575	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92029V	\N	\N
9841	611	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
9842	611	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77019E	\N	\N
9843	611	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	03002P	\N	\N
9845	600	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
9846	600	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	02003L	\N	\N
9848	600	2004-10-01 00:00:00	2007-01-01 00:00:00	ANCIEN	\N	\N	\N	01035Q	\N	\N
9849	600	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89030N	\N	\N
9850	600	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98017S	\N	\N
9851	600	2004-10-01 00:00:00	2007-09-30 00:00:00	ANCIEN	\N	\N	\N	04060E	\N	\N
9852	600	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04041B	\N	\N
9853	600	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04037F	\N	\N
9854	600	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92029V	\N	\N
9855	600	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98038X	\N	\N
9856	600	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98051U	\N	\N
9857	600	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
9858	600	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95047L	\N	\N
9859	600	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04083M	\N	\N
9860	600	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
9861	600	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77053G	\N	\N
9862	600	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
9863	600	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
9864	600	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04056J	\N	\N
9866	909	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04048J	\N	\N
9867	917	2004-11-16 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04083M	\N	\N
9868	604	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
9871	604	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
9870	604	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04091M	\N	\N
9872	604	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
9874	604	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	02002K	\N	\N
9875	604	2004-10-01 00:00:00	2007-11-29 00:00:00	ANCIEN	\N	\N	\N	04072J	\N	\N
9876	604	2005-02-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95036H	\N	\N
9877	604	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04037F	\N	\N
9878	604	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01030K	\N	\N
9879	604	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
9880	604	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98051U	\N	\N
9881	604	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83042R	\N	\N
9882	604	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
9883	604	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
9884	604	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
9888	604	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83050R	\N	\N
9889	604	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
10337	646	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95035G	\N	\N
10338	646	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
10339	646	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
10341	576	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04087R	\N	\N
10342	576	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01001E	\N	\N
10343	576	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
10344	576	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
10345	576	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04073K	\N	\N
10346	576	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95013A	\N	\N
10347	576	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98016R	\N	\N
10348	576	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
10349	576	2004-10-01 00:00:00	2005-06-28 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
10350	576	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95019G	\N	\N
10351	576	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04055H	\N	\N
10352	576	2004-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
10353	576	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95024D	\N	\N
10354	576	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95025E	\N	\N
10355	576	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04071H	\N	\N
10356	576	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
10357	576	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
10358	576	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
10359	576	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04078Q	\N	\N
10360	576	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04037F	\N	\N
10361	576	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01030K	\N	\N
10362	576	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
10363	576	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	03001N	\N	\N
10364	576	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	82002D	\N	\N
10365	576	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
10368	576	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92043T	\N	\N
10369	576	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04056J	\N	\N
10371	576	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	03002P	\N	\N
10372	576	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92045V	\N	\N
10374	577	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04051D	\N	\N
10375	577	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	02003L	\N	\N
10376	911	2005-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
10377	934	2004-10-01 00:00:00	2008-10-30 00:00:00	ANCIEN	\N	\N	\N	92011K	\N	\N
10378	934	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
10379	934	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
10380	947	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	\N
10382	619	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	03002P	\N	\N
10384	619	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
10385	908	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	95037J	\N	\N
10386	908	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
10387	908	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01016M	\N	\N
10388	908	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98051U	\N	\N
10389	908	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	80013X	\N	\N
10390	908	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
10391	908	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01045S	\N	\N
10392	908	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01006K	\N	\N
10393	908	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
10394	600	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
10408	938	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
10396	535	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
10398	535	2004-10-01 00:00:00	2009-06-04 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
10399	535	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92029V	\N	\N
10400	535	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01054T	\N	\N
10401	535	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04044E	\N	\N
10409	938	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
10404	938	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
10405	938	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
10410	938	2008-10-01 00:00:00	2010-10-11 00:00:00	ANCIEN	\N	\N	\N	01017N	\N	\N
10411	938	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95039L	\N	\N
10412	938	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
10413	938	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
10414	938	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01029S	\N	\N
10415	938	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
10416	938	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
10417	938	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	\N
10418	938	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01001E	\N	\N
10419	938	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01023L	\N	\N
10420	917	2005-03-10 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
10421	938	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01015L	\N	\N
10422	938	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80045G	\N	\N
10423	938	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
10424	595	2004-02-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95036H	\N	\N
10426	938	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01063U	\N	\N
10427	957	2005-03-15 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
10428	957	2005-03-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01051Q	\N	\N
10429	957	2005-03-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
10430	957	2005-03-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98023Q	\N	\N
10431	957	2005-03-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95025E	\N	\N
10432	957	2005-03-15 00:00:00	2005-06-30 00:00:00	ANCIEN	\N	\N	\N	04017B	\N	\N
10433	957	2005-03-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	88009M	\N	\N
10973	919	2006-03-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98041S	\N	\N
10975	919	2006-03-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04101V	\N	\N
10976	964	2006-03-14 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	98041S	\N	\N
10977	964	2006-03-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04101V	\N	\N
10978	964	2006-03-14 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01058X	\N	\N
16847	957	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	98023Q	\N	\N
10124	597	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
10125	597	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95055L	\N	\N
10126	597	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
10127	597	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
10129	911	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04073K	\N	\N
10130	911	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01045S	\N	\N
10131	911	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89030N	\N	\N
10132	911	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01030K	\N	\N
10133	911	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
10134	911	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
10135	911	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	03002P	\N	\N
10136	911	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	02005N	\N	\N
10137	911	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
10138	911	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01014K	\N	\N
10139	911	2004-10-01 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
10140	911	2004-10-01 00:00:00	2005-06-30 00:00:00	ANCIEN	\N	\N	\N	04017B	\N	\N
16851	957	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11096W	\N	\N
10141	911	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
10142	911	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
10143	911	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	\N
10144	633	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
10145	633	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
10146	633	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
10147	633	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
10148	633	2004-10-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
10153	634	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
10572	851	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04084N	\N	\N
10573	851	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80039J	\N	\N
10574	851	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01028R	\N	\N
10575	924	2005-04-11 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	95036H	\N	\N
10576	605	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95015C	\N	\N
10577	924	2005-04-11 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01029S	\N	\N
10578	924	2005-04-11 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	98012M	\N	\N
10579	924	2005-04-11 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
10580	924	2005-04-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	88009M	\N	\N
10581	924	2005-04-11 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01047U	\N	\N
10582	924	2005-04-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
10583	924	2005-04-11 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
9524	572	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80039J	\N	\N
9525	572	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04056J	\N	\N
9526	572	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01034P	\N	\N
9528	922	2004-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01045S	\N	\N
9529	918	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95005A	\N	\N
9530	921	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04041B	\N	\N
9531	921	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89019T	\N	\N
9532	921	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
9533	921	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
9534	921	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
9535	921	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	87003B	\N	\N
9536	921	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01025N	\N	\N
9537	921	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
9538	921	2004-10-01 00:00:00	2005-03-19 00:00:00	ANCIEN	\N	\N	\N	98008R	\N	\N
9539	921	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
9540	948	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04087R	\N	\N
9541	948	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	\N
9542	948	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
9543	948	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
9544	948	2004-10-01 00:00:00	2005-06-30 00:00:00	ANCIEN	\N	\N	\N	04017B	\N	\N
9545	901	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	98046X	\N	\N
9548	934	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80046H	\N	\N
9556	647	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01051Q	\N	\N
9557	647	2004-10-01 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	92022N	\N	\N
9558	647	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
9559	647	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	03001N	\N	\N
9560	647	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
9561	647	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
9562	647	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
9563	647	2005-02-21 00:00:00	2010-12-14 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
9565	647	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
9567	901	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01016M	\N	\N
9569	625	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	\N
9570	625	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
9571	625	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
9572	625	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
9573	625	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01026P	\N	\N
9574	625	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
9575	625	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
9576	625	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	\N
9577	625	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98046X	\N	\N
9578	625	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04083M	\N	\N
9716	629	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	88012G	\N	\N
9717	629	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01007L	\N	\N
9718	629	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04075M	\N	\N
9719	629	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	\N
9720	629	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
9722	629	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04074L	\N	\N
9723	629	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04080J	\N	\N
9724	629	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89037V	\N	\N
9725	629	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04044E	\N	\N
9726	629	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01010F	\N	\N
9728	657	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89019T	\N	\N
9729	657	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
9730	657	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04063H	\N	\N
9731	657	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04055H	\N	\N
9732	657	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83031N	\N	\N
9733	657	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
9735	657	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04084N	\N	\N
9736	657	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
9737	657	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
9738	657	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
9739	657	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
9741	628	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89019T	\N	\N
9742	628	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04063H	\N	\N
9744	628	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83033Q	\N	\N
9745	628	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
9746	628	2004-10-01 00:00:00	2007-09-30 00:00:00	ANCIEN	\N	\N	\N	04060E	\N	\N
9748	641	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
9750	641	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
9751	641	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04038G	\N	\N
9752	641	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04046G	\N	\N
9753	641	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	02001J	\N	\N
9755	641	2004-10-01 00:00:00	2009-09-09 00:00:00	ANCIEN	\N	\N	\N	80024B	\N	\N
9756	641	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01020H	\N	\N
9757	641	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01016M	\N	\N
9758	534	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
9760	640	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
9761	640	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
9762	640	2004-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
9765	651	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
9766	651	2004-10-01 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	77044F	\N	\N
9767	651	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01054T	\N	\N
9768	651	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	03002P	\N	\N
9769	651	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80045G	\N	\N
9770	651	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01010F	\N	\N
9771	651	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04082L	\N	\N
9773	648	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
8949	616	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
8950	616	2004-10-15 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
8951	616	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04038G	\N	\N
8952	616	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04051D	\N	\N
8953	616	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
8954	616	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	02001J	\N	\N
8955	616	2004-10-15 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
8956	616	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04037F	\N	\N
8957	616	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	03001N	\N	\N
8958	616	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
8959	616	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
8960	616	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98046X	\N	\N
8961	616	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
8962	616	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04090L	\N	\N
8963	616	2004-10-15 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
8964	556	2003-06-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	\N
8967	556	2003-06-30 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
8966	616	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
8968	556	2003-06-30 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
8969	532	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
8970	532	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
8971	532	2004-10-15 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
8972	532	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01033N	\N	\N
16341	908	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11032E	\N	\N
9376	579	2004-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
9377	579	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
9378	579	2005-02-21 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
9379	579	2004-10-01 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	92022N	\N	\N
9381	621	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	\N
9382	621	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
9383	621	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95013A	\N	\N
16342	908	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11114F	\N	\N
9385	621	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
9386	621	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01063U	\N	\N
9387	621	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01024M	\N	\N
9388	621	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
9389	621	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83033Q	\N	\N
16343	908	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
9391	621	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98017S	\N	\N
9392	621	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
9393	621	2004-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
9394	621	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01033N	\N	\N
9395	621	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	\N
9396	621	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04037F	\N	\N
9397	621	2004-10-01 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	77044F	\N	\N
9398	621	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
9399	621	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
9400	621	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77053G	\N	\N
9401	621	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95055L	\N	\N
9402	621	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04074L	\N	\N
9403	621	2004-10-01 00:00:00	2009-01-31 00:00:00	ANCIEN	\N	\N	\N	04080J	\N	\N
9404	621	2004-10-01 00:00:00	2005-09-30 00:00:00	ANCIEN	\N	\N	\N	04043D	\N	\N
9405	621	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04090L	\N	\N
9407	621	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
9408	621	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04044E	\N	\N
9409	621	2004-10-01 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	89043T	\N	\N
9410	621	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01010F	\N	\N
9412	621	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98047Y	\N	\N
9415	901	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01026P	\N	\N
9417	623	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	\N
9418	623	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95047L	\N	\N
9419	623	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95020Y	\N	\N
9420	623	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
9890	604	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04044E	\N	\N
9891	604	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
9892	604	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04082L	\N	\N
9893	604	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04034C	\N	\N
9894	933	2004-12-01 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	71003U	\N	\N
9895	933	2004-12-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01049W	\N	\N
9896	933	2004-12-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
9897	933	2004-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
9898	933	2004-12-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
9899	933	2004-12-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
9900	933	2004-12-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
9901	933	2004-12-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01014K	\N	\N
9902	933	2004-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
9903	933	2004-12-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01050P	\N	\N
9904	933	2004-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
9909	644	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
9910	644	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04063H	\N	\N
9912	644	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04058L	\N	\N
9914	644	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
9915	644	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
9916	644	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
9917	644	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
9918	644	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77043E	\N	\N
9919	644	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04084N	\N	\N
9920	644	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
9921	644	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
9922	644	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89016Q	\N	\N
9923	644	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01023L	\N	\N
9924	659	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
9925	659	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04063H	\N	\N
9926	659	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
9927	659	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
9928	659	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
9929	659	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
9930	659	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
9931	659	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89016Q	\N	\N
9932	659	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83047W	\N	\N
9933	913	2005-01-05 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04090L	\N	\N
9937	954	2004-12-14 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01006K	\N	\N
9938	954	2004-12-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98016R	\N	\N
9939	954	2004-12-14 00:00:00	2005-06-28 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
9940	954	2004-12-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
9941	954	2004-12-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
9942	954	2004-12-14 00:00:00	2005-06-30 00:00:00	ANCIEN	\N	\N	\N	04017B	\N	\N
9943	954	2004-12-14 00:00:00	2007-09-30 00:00:00	ANCIEN	\N	\N	\N	04060E	\N	\N
9944	954	2004-12-14 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01022K	\N	\N
9945	954	2004-12-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04041B	\N	\N
9946	954	2004-12-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
9947	954	2004-12-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	82002D	\N	\N
9948	954	2004-12-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	02005N	\N	\N
9949	954	2004-12-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89040Q	\N	\N
9950	954	2004-12-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
9951	954	2004-12-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01050P	\N	\N
9952	954	2004-12-14 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	98012M	\N	\N
9953	598	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04081K	\N	\N
9954	632	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04090L	\N	\N
9955	610	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01015L	\N	\N
9956	610	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04083M	\N	\N
9957	624	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83042R	\N	\N
9958	624	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04078Q	\N	\N
9959	624	2004-10-01 00:00:00	2005-06-28 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
9960	599	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
9961	599	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
9962	581	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04086Q	\N	\N
9963	581	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
9964	919	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01006K	\N	\N
9967	919	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04091M	\N	\N
9966	919	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	2013-03-26 11:18:20
9968	919	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89019T	\N	\N
9971	919	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
9970	919	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	96004D	\N	\N
9972	919	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92011K	\N	\N
9973	919	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
9974	919	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98016R	\N	\N
9975	919	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
9976	919	2004-10-01 00:00:00	2005-06-28 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
9977	919	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01024M	\N	\N
9978	919	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	87003B	\N	\N
9979	919	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01025N	\N	\N
9980	919	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
9981	919	2004-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	2013-03-26 11:25:03
9982	919	2004-10-01 00:00:00	2005-06-30 00:00:00	ANCIEN	\N	\N	\N	04017B	\N	\N
9983	919	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
9984	919	2004-10-01 00:00:00	2007-09-30 00:00:00	ANCIEN	\N	\N	\N	04060E	\N	\N
9985	651	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89042S	\N	\N
9986	625	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95047L	\N	\N
9987	625	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01054T	\N	\N
9988	919	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	88009M	\N	\N
9989	919	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01033N	\N	\N
9990	919	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01022K	\N	\N
9991	919	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04041B	\N	\N
9992	919	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01030K	\N	\N
9996	919	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
9997	919	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
9998	919	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	02005N	\N	\N
9995	586	2004-10-01 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	71003U	\N	\N
10000	919	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
9999	586	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04087R	\N	\N
10001	586	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04052E	\N	\N
10003	919	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89016Q	\N	\N
10002	586	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92020L	\N	\N
10004	586	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	\N
10005	586	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	03002P	\N	\N
10006	586	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
10007	919	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92042S	\N	\N
10008	586	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
10009	919	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04033B	\N	\N
10010	919	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89040Q	\N	\N
10012	919	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98037W	\N	\N
10013	919	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	03002P	\N	\N
10014	919	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80046H	\N	\N
10015	613	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
10016	613	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	96008H	\N	\N
10017	613	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
10018	613	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95025E	\N	\N
10019	613	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
10020	613	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
10021	613	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01055U	\N	\N
10022	613	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
10023	613	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92029V	\N	\N
10024	613	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
10025	613	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	03002P	\N	\N
10026	919	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98036V	\N	\N
10027	919	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
10028	919	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
10030	589	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04087R	\N	\N
10031	589	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
10032	589	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
10033	589	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
10034	589	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
10035	589	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98029W	\N	\N
10036	589	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92008Q	\N	\N
10037	589	2004-10-01 00:00:00	2005-06-28 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
10038	589	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80013X	\N	\N
10039	589	2004-10-01 00:00:00	2006-08-11 00:00:00	ANCIEN	\N	\N	\N	74050Q	\N	\N
10040	589	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04086Q	\N	\N
10041	589	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
10042	589	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	\N
10044	589	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89030N	\N	\N
10045	589	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
10046	589	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
10047	589	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
10048	589	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
10049	589	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
10050	589	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01016M	\N	\N
10051	589	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98033S	\N	\N
10052	589	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
10053	589	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86053H	\N	\N
10054	589	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
10055	589	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01062T	\N	\N
10056	589	2004-10-01 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	89043T	\N	\N
10057	589	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04047H	\N	\N
10060	643	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	\N
10061	643	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95013A	\N	\N
10062	643	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98016R	\N	\N
16339	908	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	\N	2014-09-28 17:03:42
10064	643	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	\N
10065	643	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
10066	643	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	03001N	\N	\N
10067	643	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04094Q	\N	\N
10068	643	2004-10-01 00:00:00	2007-06-28 00:00:00	ANCIEN	\N	\N	\N	00002B	\N	\N
10069	643	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01029S	\N	\N
10070	643	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01010F	\N	\N
10072	643	2004-10-01 00:00:00	2005-02-01 00:00:00	ANCIEN	\N	\N	\N	04047H	\N	\N
10075	592	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
10076	592	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
10077	592	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
10078	592	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77043E	\N	\N
10079	592	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
10080	592	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
10081	592	2004-10-01 00:00:00	2005-06-30 00:00:00	ANCIEN	\N	\N	\N	04017B	\N	\N
10082	592	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
10083	592	2004-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
10084	592	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	03001N	\N	\N
10085	592	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95047L	\N	\N
10086	592	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95003X	\N	\N
10087	592	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
10089	597	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	\N
10095	597	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89019T	\N	\N
10096	597	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04063H	\N	\N
10097	597	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98049B	\N	\N
10098	597	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04047H	\N	\N
10099	597	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04066L	\N	\N
10100	597	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
10101	597	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04086Q	\N	\N
10102	597	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92018S	\N	\N
10104	597	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04058L	\N	\N
10106	597	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
10107	597	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98041S	\N	\N
10108	597	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
10109	597	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
10110	597	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89030N	\N	\N
10111	597	2004-10-01 00:00:00	2005-06-30 00:00:00	ANCIEN	\N	\N	\N	04017B	\N	\N
10112	597	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98017S	\N	\N
10113	597	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
10114	597	2004-10-01 00:00:00	2007-11-29 00:00:00	ANCIEN	\N	\N	\N	04072J	\N	\N
10115	597	2004-10-01 00:00:00	2007-02-25 00:00:00	ANCIEN	\N	\N	\N	92024Q	\N	\N
10116	597	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01007L	\N	\N
10117	597	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04041B	\N	\N
10118	597	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
10120	597	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
10121	597	2004-10-01 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	77044F	\N	\N
10122	597	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
10123	597	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98046X	\N	\N
9215	590	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04094Q	\N	\N
9216	590	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
9217	590	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
9218	590	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01054T	\N	\N
9219	590	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77053G	\N	\N
9220	590	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89016Q	\N	\N
9221	590	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04043D	\N	\N
9222	590	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	03002P	\N	\N
9223	590	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04082L	\N	\N
9224	590	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83050R	\N	\N
9226	584	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	\N
9227	584	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04087R	\N	\N
9228	584	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
9229	584	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04059M	\N	\N
9230	584	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04091M	\N	\N
9231	584	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	\N
9232	584	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
9233	584	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
9234	584	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01051Q	\N	\N
9235	584	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
9236	584	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98016R	\N	\N
9238	584	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04038G	\N	\N
9240	584	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04055H	\N	\N
9241	584	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01012H	\N	\N
9242	584	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95025E	\N	\N
9671	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	03002P	\N	\N
9672	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01062T	\N	\N
9673	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
9674	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04044E	\N	\N
9675	626	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
9676	626	2004-10-01 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	80048K	\N	\N
9677	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98006P	\N	\N
9678	626	2004-10-01 00:00:00	2010-01-07 00:00:00	ANCIEN	\N	\N	\N	86039K	\N	\N
9680	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89025R	\N	\N
9682	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98049B	\N	\N
9695	580	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04058L	\N	\N
9698	610	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
9699	610	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
9690	580	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
9691	580	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92042S	\N	\N
9692	580	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
9694	580	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
9700	610	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	\N
9701	610	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
9702	610	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
9703	610	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
9705	610	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
9706	610	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04044E	\N	\N
9707	610	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
9708	610	2004-10-01 00:00:00	2008-09-07 00:00:00	ANCIEN	\N	\N	\N	80017C	\N	\N
9709	629	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
9711	629	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
9712	629	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04042C	\N	\N
9713	629	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04058L	\N	\N
9714	629	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95032D	\N	\N
9715	629	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
10434	957	2005-03-15 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
10435	957	2005-03-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	\N
10436	957	2005-03-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	03001N	\N	\N
10437	957	2005-03-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
10438	957	2005-03-15 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
10439	957	2005-03-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
10440	957	2005-03-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83042R	\N	\N
10441	957	2005-03-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
10443	957	2005-03-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04101V	\N	\N
10444	957	2005-03-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80041C	\N	\N
10445	957	2005-03-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	03002P	\N	\N
10446	957	2005-03-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89042S	\N	\N
10447	938	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04065K	\N	\N
10448	915	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04065K	\N	\N
10449	915	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	95030B	\N	\N
10450	915	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95015C	\N	\N
10451	915	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89037V	\N	\N
10452	915	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01014K	\N	\N
10453	915	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98003L	\N	\N
10454	915	2004-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
10455	915	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98016R	\N	\N
10456	915	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04069P	\N	\N
10458	915	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80041C	\N	\N
10459	915	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95025E	\N	\N
10460	915	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04047H	\N	\N
10461	915	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
10462	915	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
10463	915	2004-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	95036H	\N	\N
10464	915	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89030N	\N	\N
10465	915	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	88009M	\N	\N
10466	915	2004-10-01 00:00:00	2010-12-14 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
10467	915	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04044E	\N	\N
10468	915	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
10469	915	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95036H	\N	\N
10470	922	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04055H	\N	\N
10471	938	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	82002D	\N	\N
10472	907	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04055H	\N	\N
10474	904	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95036H	\N	\N
10475	904	2004-10-01 00:00:00	2010-12-14 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
10476	938	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01030K	\N	\N
10484	596	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04091M	\N	\N
10485	596	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
10483	596	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04059M	\N	\N
10486	596	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95011X	\N	\N
10487	596	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04042C	\N	\N
10488	596	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
10489	596	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	\N
10490	596	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
10491	596	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	\N
10492	596	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
10493	596	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	03001N	\N	\N
10494	596	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95044H	\N	\N
10495	596	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92033R	\N	\N
10496	596	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
10497	596	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
10498	596	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01010F	\N	\N
10499	596	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04034C	\N	\N
10500	596	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01006K	\N	\N
10501	590	2005-03-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
10504	534	2005-03-23 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04065K	\N	\N
10503	588	2005-03-23 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80039J	\N	\N
10505	534	2005-03-23 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
10506	571	2005-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
10507	624	2005-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
10508	622	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	\N
10509	622	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
10510	622	2004-10-01 00:00:00	2005-06-28 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
10511	622	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01063U	\N	\N
10512	622	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
10513	622	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
10515	622	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
10516	622	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04064J	\N	\N
10517	622	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98003L	\N	\N
10518	622	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
10519	622	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92029V	\N	\N
10520	622	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
10521	622	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95050F	\N	\N
10841	963	2005-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01052R	\N	\N
10842	963	2005-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01045S	\N	\N
10843	963	2005-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92020L	\N	\N
10844	963	2005-12-01 00:00:00	2007-12-31 00:00:00	ANCIEN	\N	\N	\N	01041N	\N	\N
10845	963	2005-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
10846	963	2005-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
10847	963	2005-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
10848	963	2005-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92029V	\N	\N
10849	963	2005-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
10850	963	2005-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01029S	\N	\N
10851	963	2005-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04101V	\N	\N
10852	963	2005-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80013X	\N	\N
10853	621	2005-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04056J	\N	\N
10854	963	2005-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
10855	600	2005-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	\N
10856	600	2005-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	\N
10857	600	2005-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04091M	\N	\N
10858	600	2005-12-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
10860	600	2005-12-01 00:00:00	2007-06-17 00:00:00	ANCIEN	\N	\N	\N	02009S	\N	\N
10861	600	2005-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
10862	600	2005-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
10863	600	2005-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
10864	600	2005-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	73006G	\N	\N
10865	600	2005-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
10866	600	2005-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92042S	\N	\N
10867	600	2005-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04065K	\N	\N
10868	600	2005-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01036R	\N	\N
10869	947	2005-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	05011Y	\N	\N
10870	583	2005-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04055H	\N	\N
10871	934	2005-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
10872	947	2006-01-16 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
10873	964	2006-01-31 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
10874	919	2006-01-31 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
10875	964	2006-01-31 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
10876	964	2006-01-31 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
16846	957	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	2014-09-28 16:59:41
10879	919	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
10880	964	2006-01-31 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
10881	919	2006-01-31 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
10882	964	2006-01-31 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
10883	919	2006-01-31 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98007Q	\N	\N
10884	964	2006-01-31 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98007Q	\N	\N
10885	964	2006-01-31 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
10886	919	2006-02-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
10887	964	2006-02-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
10888	964	2006-02-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	87003B	\N	\N
10889	627	2005-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
10890	627	2005-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04058L	\N	\N
10891	627	2005-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
10892	627	2005-12-01 00:00:00	2007-09-30 00:00:00	ANCIEN	\N	\N	\N	04041B	\N	\N
10893	947	2006-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
10894	626	2006-01-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01020H	\N	\N
10895	580	2006-01-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
10896	598	2006-01-24 00:00:00	2007-09-30 00:00:00	ANCIEN	\N	\N	\N	04060E	\N	\N
10897	598	2006-01-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04100U	\N	\N
10899	598	2006-01-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
10900	598	2006-01-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04069P	\N	\N
10901	919	2006-02-02 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	05011Y	\N	\N
10904	964	2006-02-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	\N
10905	964	2006-02-02 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
10906	964	2006-01-31 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	77053G	\N	\N
10907	964	2006-01-31 00:00:00	2006-07-08 00:00:00	ANCIEN	\N	\N	\N	80048K	\N	\N
10908	919	2006-02-02 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
10909	964	2006-02-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
10910	964	2006-02-02 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	05011Y	\N	\N
10911	919	2006-01-31 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
10912	964	2006-01-31 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
10913	580	2006-01-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01052R	\N	\N
34469	907	2023-12-14 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	21076L	\N	\N
10914	535	2006-01-24 00:00:00	2009-06-04 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
10915	535	2006-01-24 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
10916	535	2006-01-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
10917	535	2006-01-24 00:00:00	2009-06-04 00:00:00	ANCIEN	\N	\N	\N	04077P	\N	\N
10918	535	2006-01-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
10919	535	2006-01-24 00:00:00	2009-06-04 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
10920	535	2006-01-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
10921	535	2006-01-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	05011Y	\N	\N
10922	963	2006-01-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
10923	963	2006-01-24 00:00:00	2007-02-25 00:00:00	ANCIEN	\N	\N	\N	92024Q	\N	\N
10924	963	2006-01-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	05011Y	\N	\N
10925	600	2006-01-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
10927	598	2006-01-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04043D	\N	\N
10928	964	2006-03-16 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	02005N	\N	\N
10931	919	2006-02-02 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04087R	\N	\N
10933	919	2006-02-06 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
10934	919	2006-02-07 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	\N
10935	919	2006-02-02 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	\N
10936	919	2006-01-31 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95037J	\N	\N
10937	919	2006-02-06 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01016M	\N	\N
10938	964	2006-02-01 00:00:00	2009-09-09 00:00:00	ANCIEN	\N	\N	\N	80024B	\N	\N
10939	964	2006-02-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95015C	\N	\N
10940	964	2006-02-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04087R	\N	\N
10941	964	2006-02-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
10942	964	2006-01-31 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
10943	964	2006-02-06 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
10944	964	2006-02-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	\N
10945	964	2006-02-02 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	\N
10946	964	2006-01-31 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95037J	\N	\N
10947	964	2006-01-31 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
10948	964	2006-02-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01016M	\N	\N
10949	964	2006-02-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
10950	964	2006-01-31 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01050P	\N	\N
10951	964	2006-02-02 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	03002P	\N	\N
10952	919	2006-02-07 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
10953	964	2006-02-07 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
10954	919	2006-02-07 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04053F	\N	\N
10955	964	2006-02-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04053F	\N	\N
10956	919	2006-02-22 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01015L	\N	\N
10957	964	2006-02-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01015L	\N	\N
10958	964	2006-03-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
10959	964	2006-03-14 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	98037W	\N	\N
10961	580	2006-01-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
10962	964	2006-03-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
10963	964	2006-03-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	\N
10965	964	2006-03-14 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	98012M	\N	\N
10966	964	2006-03-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04034C	\N	\N
10967	589	2006-01-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
10968	919	2006-03-12 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92043T	\N	\N
10969	964	2006-03-12 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92043T	\N	\N
10970	623	2006-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04069P	\N	\N
10971	919	2006-03-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
10972	964	2006-03-15 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
11106	532	2006-09-21 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	01039U	\N	\N
11107	643	2006-09-21 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	06004E	\N	\N
11109	913	2006-09-13 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	06004E	\N	\N
11110	575	2006-09-21 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	06004E	\N	\N
11112	917	2006-10-01 00:00:00	2007-10-01 00:00:00	ANCIEN	\N	\N	\N	06004E	\N	\N
11163	572	2006-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
11164	572	2006-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
11165	572	2006-11-28 00:00:00	2007-06-21 00:00:00	ANCIEN	\N	\N	\N	92007P	\N	\N
11166	572	2006-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	\N
11167	572	2006-11-28 00:00:00	2007-11-21 00:00:00	ANCIEN	\N	\N	\N	89020L	\N	\N
11168	572	2006-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92011K	\N	\N
11169	572	2006-11-28 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
11170	572	2006-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
11171	572	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	90003B	\N	\N
11172	572	2006-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
11173	572	2006-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98024R	\N	\N
11174	572	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
11175	572	2006-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01045S	\N	\N
11176	572	2006-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
11177	572	2006-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92020L	\N	\N
11178	572	2006-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	02002K	\N	\N
11179	572	2006-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77019E	\N	\N
11180	572	2006-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	\N
11242	911	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98050T	\N	\N
11246	911	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
11344	628	2007-03-07 00:00:00	2010-09-22 00:00:00	ANCIEN	\N	\N	\N	07004J	\N	\N
11345	628	2007-02-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
11346	921	2007-04-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
11348	661	2007-04-22 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92030N	\N	\N
11462	663	2007-07-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	82002D	\N	\N
11463	663	2007-07-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07024N	\N	\N
11788	590	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01052R	\N	\N
11789	590	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95015C	\N	\N
11470	919	2007-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	07027R	\N	\N
11633	901	2008-02-22 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
11652	583	2004-11-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
11637	912	2008-02-29 00:00:00	2011-03-31 00:00:00	ANCIEN	\N	\N	\N	07004J	\N	\N
11653	623	2008-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
13371	966	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
11656	966	2008-03-31 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
13372	966	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01025N	\N	\N
13373	966	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08039A	\N	\N
13374	966	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
11695	922	2008-05-19 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	\N
11696	902	2008-06-25 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07023M	\N	\N
11790	590	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	02053W	\N	\N
11791	590	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	\N	\N
11093	965	2006-06-23 00:00:00	2008-10-30 00:00:00	ANCIEN	\N	\N	\N	01058X	\N	\N
11097	966	2006-07-08 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04039H	\N	\N
11098	919	2006-09-12 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98029W	\N	\N
11099	964	2006-09-12 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98029W	\N	\N
11181	572	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04078Q	\N	\N
11182	572	2006-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95039L	\N	\N
11183	572	2006-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	06006G	\N	\N
11184	572	2006-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92029V	\N	\N
11185	572	2006-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
11186	572	2006-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98051U	\N	\N
11187	572	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95047L	\N	\N
11188	572	2006-11-28 00:00:00	2007-01-25 00:00:00	ANCIEN	\N	\N	\N	89006N	\N	\N
11189	572	2006-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	02005N	\N	\N
11190	572	2006-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
11192	572	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
11193	572	2006-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04080J	\N	\N
11194	572	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
11195	572	2006-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
11196	572	2006-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
11197	572	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04069P	\N	\N
11198	572	2006-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80041C	\N	\N
11199	572	2006-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	06004E	\N	\N
11291	674	2007-02-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80040B	\N	\N
11292	674	2007-02-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
11293	674	2007-02-14 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
11294	674	2007-02-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
11295	674	2007-02-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
11296	674	2007-02-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89016Q	\N	\N
11297	674	2007-02-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89021M	\N	\N
11298	674	2007-02-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
11299	674	2007-02-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
11300	674	2007-02-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95006B	\N	\N
11301	674	2007-02-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95011X	\N	\N
11302	674	2007-02-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	\N
11303	674	2007-02-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95060H	\N	\N
11304	674	2007-02-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
11305	674	2007-02-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
11306	674	2007-02-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
11307	674	2007-02-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
11308	674	2007-02-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98016R	\N	\N
11309	674	2007-02-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	\N
11310	674	2007-02-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98048A	\N	\N
11500	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95025E	\N	\N
11501	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
11502	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01024M	\N	\N
16345	908	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	2014-09-28 18:00:58
11200	572	2006-11-28 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	89045V	\N	\N
11201	572	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04034C	\N	\N
11202	618	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77043E	\N	\N
11203	907	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	06005F	\N	\N
11204	634	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
11206	634	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04084N	\N	\N
11207	634	2006-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
11208	634	2006-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
11209	634	2006-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98017S	\N	\N
11210	634	2006-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
11211	634	2006-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83033Q	\N	\N
11212	634	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
11220	919	2006-12-29 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	\N
11248	535	2007-01-01 00:00:00	2009-06-04 00:00:00	ANCIEN	\N	\N	\N	04080J	\N	\N
11453	912	2007-07-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
11454	912	2007-07-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07023M	\N	\N
11455	640	2007-07-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
11487	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
11457	640	2007-07-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
11458	640	2007-07-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
11459	640	2007-07-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
11460	640	2007-07-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01029S	\N	\N
11461	640	2007-07-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01036R	\N	\N
11464	598	2007-07-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07024N	\N	\N
11488	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89013M	\N	\N
11489	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01001E	\N	\N
11601	623	2007-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07023M	\N	\N
11616	909	2008-02-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07030L	\N	\N
11113	621	2006-09-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04038G	\N	\N
11114	621	2006-09-21 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	06004E	\N	\N
11160	909	2006-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	06005F	\N	\N
11218	964	2006-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
11224	911	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83011J	\N	\N
11232	911	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
11233	911	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
11234	911	2006-04-13 00:00:00	2008-04-18 00:00:00	ANCIEN	\N	\N	\N	95031C	\N	\N
11335	634	2007-02-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01042P	\N	\N
11343	661	2007-04-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	02003L	\N	\N
11471	620	2007-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
11472	627	2007-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
11473	651	2007-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
11474	583	2007-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
11475	598	2007-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
11476	661	2007-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
11477	595	2007-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
11478	597	2007-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86034E	\N	\N
11479	586	2007-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92029V	\N	\N
11493	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92011K	\N	\N
11494	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
11495	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04053F	\N	\N
11496	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98048A	\N	\N
11507	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01025N	\N	\N
11508	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
11509	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89030N	\N	\N
11510	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
11511	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01011G	\N	\N
11513	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	88009M	\N	\N
11514	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04048J	\N	\N
11515	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04037F	\N	\N
11516	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01030K	\N	\N
11517	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	85003S	\N	\N
11518	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
11519	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
11520	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	82002D	\N	\N
11521	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80024B	\N	\N
11548	906	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98036V	\N	\N
11549	906	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	\N
11550	906	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
11551	906	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01001E	\N	\N
11552	906	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01049W	\N	\N
11553	906	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92011K	\N	\N
11554	906	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98048A	\N	\N
11567	906	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
11569	906	2006-09-01 00:00:00	2009-09-09 00:00:00	ANCIEN	\N	\N	\N	80024B	\N	\N
11570	906	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
11571	906	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95047L	\N	\N
11572	906	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
11226	911	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01001E	\N	\N
11227	911	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01064V	\N	\N
11228	911	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	96004D	\N	\N
11279	674	2007-02-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
11280	674	2007-02-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01012H	\N	\N
11281	674	2007-02-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
11282	674	2007-02-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
11283	674	2007-02-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01042P	\N	\N
11284	674	2007-02-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01051Q	\N	\N
11285	674	2007-02-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01054T	\N	\N
11286	674	2007-02-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	03001N	\N	\N
11287	674	2007-02-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
11288	674	2007-02-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04087R	\N	\N
11289	674	2007-02-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
11290	674	2007-02-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
10613	940	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	85003S	\N	\N
10614	940	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
10615	940	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
10616	940	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95055L	\N	\N
10617	940	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
10618	940	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
10619	940	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83050R	\N	\N
10620	940	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
10621	940	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
10622	940	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01023L	\N	\N
10623	940	2004-10-01 00:00:00	2007-12-16 00:00:00	ANCIEN	\N	\N	\N	89045V	\N	\N
10624	940	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04082L	\N	\N
10625	940	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04034C	\N	\N
10626	924	2005-04-11 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01016M	\N	\N
10627	924	2005-04-11 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
10628	924	2005-04-11 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04037F	\N	\N
10629	917	2005-05-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04069P	\N	\N
10630	924	2005-04-11 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01057W	\N	\N
10631	924	2005-04-11 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
10632	924	2005-04-11 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
10634	591	2005-05-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
10635	613	2005-04-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
10636	924	2005-04-11 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01050P	\N	\N
10637	648	2005-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	00003C	\N	\N
10638	648	2005-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04082L	\N	\N
10639	585	2005-02-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04074L	\N	\N
10640	609	2004-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
10641	924	2005-04-11 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04055H	\N	\N
10642	924	2005-04-11 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	82002D	\N	\N
10646	924	2005-04-11 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01042P	\N	\N
10645	924	2005-04-11 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
10647	924	2005-04-11 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01049W	\N	\N
10648	924	2005-04-11 00:00:00	2007-01-01 00:00:00	ANCIEN	\N	\N	\N	01035Q	\N	\N
10649	556	2005-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04041B	\N	\N
10657	905	2005-06-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01006K	\N	\N
10658	905	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
10660	905	2005-06-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
10661	905	2005-06-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
10662	905	2005-06-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01046T	\N	\N
10663	905	2005-06-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	\N
10664	905	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01044R	\N	\N
10665	905	2005-06-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
10667	905	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	95011X	\N	\N
10668	905	2005-06-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04063H	\N	\N
10669	905	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98049B	\N	\N
10670	905	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98016R	\N	\N
10671	905	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	00003C	\N	\N
10672	905	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
10673	905	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	92008Q	\N	\N
10674	905	2005-06-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01063U	\N	\N
10675	905	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
10676	905	2005-06-01 00:00:00	2008-03-01 00:00:00	ANCIEN	\N	\N	\N	95024D	\N	\N
10677	905	2005-06-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04071H	\N	\N
10678	905	2005-06-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
10679	905	2001-10-01 00:00:00	2008-09-07 00:00:00	ANCIEN	\N	\N	\N	80017C	\N	\N
10680	905	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
10681	905	2005-06-01 00:00:00	2007-09-30 00:00:00	ANCIEN	\N	\N	\N	01055U	\N	\N
10682	905	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
10683	905	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
10685	905	2005-06-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
10686	905	2005-06-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	95036H	\N	\N
10687	905	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01022K	\N	\N
10688	905	2005-06-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	\N
10689	905	2005-06-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04041B	\N	\N
10690	905	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	95039L	\N	\N
10691	905	2005-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	85003S	\N	\N
10692	905	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
10693	905	2005-06-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
10694	905	2001-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
10695	905	2005-06-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
10696	905	2005-06-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04079R	\N	\N
10697	905	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
10698	905	2005-06-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
10699	905	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
10700	905	2005-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89035T	\N	\N
10701	905	2001-10-01 00:00:00	2007-09-06 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
10702	905	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
10703	905	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
10704	905	2005-06-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04065K	\N	\N
10705	905	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80040B	\N	\N
10741	937	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04091M	\N	\N
10707	905	2005-06-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
10709	905	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01039U	\N	\N
10710	905	2001-10-01 00:00:00	2006-06-29 00:00:00	ANCIEN	\N	\N	\N	98012M	\N	\N
10711	905	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
10712	905	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89042S	\N	\N
10713	905	2005-06-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04039H	\N	\N
10714	905	2005-06-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04034C	\N	\N
10715	905	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89040Q	\N	\N
10716	575	2004-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04051D	\N	\N
10719	528	2004-11-01 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
10721	528	2004-11-01 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	95006B	\N	\N
10722	528	2004-11-01 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	01051Q	\N	\N
10723	528	2004-11-01 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
10724	528	2004-11-01 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
10725	528	2004-11-01 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	01042P	\N	\N
10726	528	2004-11-01 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
10727	528	2004-11-01 00:00:00	2007-02-14 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
10728	621	2004-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
10729	610	2004-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01046T	\N	\N
10730	580	2008-09-30 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
10731	580	2004-11-01 00:00:00	2008-08-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
10732	575	2004-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95005A	\N	\N
10733	575	2004-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
10734	575	2004-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
10735	575	2004-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01024M	\N	\N
10736	575	2004-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01025N	\N	\N
10737	575	2004-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01055U	\N	\N
10738	575	2004-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04083M	\N	\N
2263	580	1998-09-30 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95039L	\N	\N
10740	948	2004-11-01 00:00:00	2007-12-31 00:00:00	ANCIEN	\N	\N	\N	04033B	\N	\N
10742	937	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
10743	937	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
10744	937	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
10745	937	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	90003B	\N	\N
10746	937	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	\N
10747	937	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04081K	\N	\N
10748	937	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	95025E	\N	\N
10749	937	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
10750	937	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04071H	\N	\N
10751	937	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01026P	\N	\N
10752	937	2001-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	83031N	\N	\N
10753	937	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
10754	937	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	98041S	\N	\N
10755	937	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
10756	937	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04075M	\N	\N
10757	937	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04097T	\N	\N
10758	937	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
10759	937	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01018P	\N	\N
10760	937	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	82002D	\N	\N
10761	937	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
10762	937	2004-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	98013N	\N	\N
10763	937	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
10765	937	2004-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	04080J	\N	\N
10766	937	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04043D	\N	\N
10767	937	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01050P	\N	\N
11161	572	2006-11-28 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
11162	572	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
11137	968	2006-11-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01057W	\N	\N
11138	968	2006-11-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04048J	\N	\N
11139	968	2006-11-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04041B	\N	\N
11140	968	2006-11-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04097T	\N	\N
11141	968	2006-11-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
11142	968	2006-11-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04083M	\N	\N
11143	968	2006-11-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	02005N	\N	\N
11144	968	2006-11-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
11145	968	2006-11-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98007Q	\N	\N
11146	968	2006-11-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
11147	968	2006-11-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
11148	968	2006-11-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
11149	968	2006-11-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
11151	968	2006-11-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80035E	\N	\N
11152	968	2006-11-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92042S	\N	\N
11153	968	2006-11-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04033B	\N	\N
11154	968	2006-11-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
11155	968	2006-11-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
11157	968	2006-11-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80041C	\N	\N
11158	968	2006-11-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	06004E	\N	\N
11235	911	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
11331	595	2007-02-14 00:00:00	2007-07-26 00:00:00	ANCIEN	\N	\N	\N	07004J	\N	\N
11332	632	2007-02-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	07004J	\N	\N
11333	661	2007-02-14 00:00:00	2010-09-23 00:00:00	ANCIEN	\N	\N	\N	07004J	\N	\N
11334	535	2007-02-14 00:00:00	2009-06-04 00:00:00	ANCIEN	\N	\N	\N	07004J	\N	\N
11359	632	2007-04-22 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
11360	632	2007-04-22 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01063U	\N	\N
11361	632	2007-04-22 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01041N	\N	\N
11362	632	2009-09-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04051D	\N	\N
11363	632	2007-04-22 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04075M	\N	\N
11364	632	2007-04-22 00:00:00	2007-09-30 00:00:00	ANCIEN	\N	\N	\N	04060E	\N	\N
11365	632	2007-04-22 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
11378	595	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
11379	632	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04087R	\N	\N
11380	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04091M	\N	\N
11124	968	2006-11-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	\N
10584	924	2005-04-11 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
10585	915	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	\N
9774	648	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
9775	648	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04063H	\N	\N
9776	648	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
9777	648	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98029W	\N	\N
9778	648	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92008Q	\N	\N
9779	648	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
9780	648	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	\N
9782	648	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83033Q	\N	\N
9783	648	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
9784	648	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
9785	648	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
9786	648	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04090L	\N	\N
9788	617	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	\N
9789	617	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89019T	\N	\N
9790	617	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
9791	617	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04063H	\N	\N
9793	617	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
9794	617	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92022N	\N	\N
9795	617	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	02001J	\N	\N
9796	617	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98017S	\N	\N
9797	617	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
9798	617	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
9799	617	2004-10-01 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	77044F	\N	\N
9800	617	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98046X	\N	\N
9801	617	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
9802	617	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04084N	\N	\N
9803	617	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
9804	617	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95055L	\N	\N
9805	617	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	03002P	\N	\N
9807	575	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	\N
9808	575	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01049W	\N	\N
9809	575	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
9810	575	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
9811	575	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04052E	\N	\N
9812	575	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04063H	\N	\N
9813	575	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95013A	\N	\N
9814	575	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04066L	\N	\N
9815	575	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
9817	575	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	90003B	\N	\N
9818	575	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95024D	\N	\N
9819	575	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83033Q	\N	\N
9820	575	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	02001J	\N	\N
9821	575	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
9822	575	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
9823	575	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04075M	\N	\N
9824	575	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
10242	530	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
10243	530	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
10244	530	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01042P	\N	\N
10247	588	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04091M	\N	\N
10248	588	2004-10-01 00:00:00	2009-02-28 00:00:00	ANCIEN	\N	\N	\N	01051Q	\N	\N
10249	588	2004-10-01 00:00:00	2009-02-28 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	\N
10250	588	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
10251	588	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
10252	588	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
10253	588	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	03002P	\N	\N
10254	612	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
10255	612	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89021M	\N	\N
10257	612	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83031N	\N	\N
10258	612	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04090L	\N	\N
10259	612	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01023L	\N	\N
10260	595	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04059M	\N	\N
10261	595	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
10262	595	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
10263	595	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04063H	\N	\N
10264	595	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
10265	595	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04053F	\N	\N
10266	595	2004-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
10267	595	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04086Q	\N	\N
10268	595	2004-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
10269	595	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
10270	595	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	\N
10271	595	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04041B	\N	\N
10272	595	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04077P	\N	\N
10273	595	2004-10-01 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	77044F	\N	\N
10275	595	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
10276	595	2004-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98007Q	\N	\N
10278	595	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
10279	595	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	03002P	\N	\N
10280	595	2004-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
10282	663	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
10283	663	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95025E	\N	\N
10284	663	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
10286	851	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
10287	851	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
10288	851	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92008Q	\N	\N
10289	851	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	03001N	\N	\N
10290	851	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89040Q	\N	\N
10291	851	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
10293	611	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04074L	\N	\N
10294	597	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92042S	\N	\N
10295	917	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	\N
10296	931	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
10297	931	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
10298	931	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
10299	931	2004-10-01 00:00:00	2007-01-25 00:00:00	ANCIEN	\N	\N	\N	89006N	\N	\N
10300	931	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98033S	\N	\N
10301	604	2005-02-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04065K	\N	\N
10302	604	2005-02-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04069P	\N	\N
10303	582	2005-02-21 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04065K	\N	\N
10304	642	2005-02-21 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04065K	\N	\N
10305	584	2005-02-21 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04065K	\N	\N
10308	922	2005-02-21 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04061F	\N	\N
10307	912	2005-02-21 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
10309	922	2005-02-21 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04069P	\N	\N
10310	906	2005-02-21 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95036H	\N	\N
10311	590	2005-02-21 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
10312	595	2005-02-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04069P	\N	\N
10314	657	2005-02-21 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95036H	\N	\N
10315	616	2005-02-21 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
10316	616	2005-02-21 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04065K	\N	\N
10318	605	2005-02-21 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04065K	\N	\N
10319	634	2005-02-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04065K	\N	\N
10320	574	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
10321	574	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
10322	574	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
10323	574	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04075M	\N	\N
10324	574	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
10325	574	2004-10-01 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	77044F	\N	\N
10326	574	2004-10-01 00:00:00	2007-09-03 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
10327	574	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89016Q	\N	\N
10328	574	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95055L	\N	\N
10329	574	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01010F	\N	\N
10331	633	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
10332	646	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
10333	646	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
10335	646	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
10768	937	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04034C	\N	\N
10771	937	2004-10-01 00:00:00	2007-12-31 00:00:00	ANCIEN	\N	\N	\N	01029S	\N	\N
10772	583	2005-07-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98040R	\N	\N
10773	651	2005-07-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01036R	\N	\N
10774	588	2005-09-01 00:00:00	2009-02-28 00:00:00	ANCIEN	\N	\N	\N	01063U	\N	\N
10775	588	2005-09-01 00:00:00	2009-02-28 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
10776	588	2005-09-01 00:00:00	2009-02-28 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
10777	588	2005-09-01 00:00:00	2009-02-28 00:00:00	ANCIEN	\N	\N	\N	04034C	\N	\N
10778	940	2004-10-01 00:00:00	2008-03-01 00:00:00	ANCIEN	\N	\N	\N	01053S	\N	\N
10782	940	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
10783	623	2005-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04043D	\N	\N
10784	626	2005-09-01 00:00:00	2007-09-18 00:00:00	ANCIEN	\N	\N	\N	77044F	\N	\N
10785	599	2005-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
10786	599	2005-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
10787	599	2005-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
10788	599	2005-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
10789	599	2005-10-01 00:00:00	2005-11-30 00:00:00	ANCIEN	\N	\N	\N	98039Y	\N	\N
10790	534	2005-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04043D	\N	\N
10791	623	2005-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
10792	599	2005-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
10794	918	2005-10-26 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	88012G	\N	\N
10795	918	2005-10-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04090L	\N	\N
10796	918	2005-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01030K	\N	\N
10797	602	2005-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95059Q	\N	\N
10798	583	2005-10-01 00:00:00	2007-06-17 00:00:00	ANCIEN	\N	\N	\N	02009S	\N	\N
10799	583	2005-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
10800	907	2005-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
10801	584	2005-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01027Q	\N	\N
10802	599	2005-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
10803	599	2005-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01036R	\N	\N
10804	599	2005-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92042S	\N	\N
10805	530	2005-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
10806	571	2005-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04100U	\N	\N
10807	584	2005-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95059Q	\N	\N
10808	597	2005-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89010J	\N	\N
10809	534	2005-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
10810	623	2005-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95019G	\N	\N
10811	623	2005-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
10812	599	2005-10-27 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
10813	611	2005-11-22 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04080J	\N	\N
10814	619	2005-10-25 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04083M	\N	\N
10815	619	2005-10-25 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01050P	\N	\N
10816	661	2005-11-25 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
10817	573	2005-11-25 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
10818	609	2005-06-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
10820	584	2005-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01054T	\N	\N
10821	623	2005-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77019E	\N	\N
10822	947	2005-12-16 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89018S	\N	\N
10823	947	2005-12-16 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92013M	\N	\N
10824	947	2005-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	\N
10826	947	2005-12-16 00:00:00	2007-09-30 00:00:00	ANCIEN	\N	\N	\N	04060E	\N	\N
10827	947	2005-12-16 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	\N
10828	947	2005-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
10829	947	2005-12-16 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04100U	\N	\N
10830	947	2005-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
10831	947	2005-12-16 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80040B	\N	\N
10832	947	2005-12-16 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80046H	\N	\N
10833	947	2005-12-16 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04034C	\N	\N
10834	963	2005-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01006K	\N	\N
10835	963	2005-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
10836	963	2005-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
10837	963	2005-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01001E	\N	\N
10838	963	2005-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
10839	963	2005-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92011K	\N	\N
10840	963	2005-12-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	02003L	\N	\N
12036	657	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01042P	\N	\N
12037	657	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07023M	\N	\N
12038	657	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01054T	\N	\N
12039	657	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	05011Y	\N	\N
12040	657	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
12041	617	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	02053W	\N	\N
12042	617	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07030L	\N	\N
12043	617	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
12044	617	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
12045	617	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
12046	617	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04077P	\N	\N
12047	617	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08015R	\N	\N
12048	617	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08039A	\N	\N
12049	617	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83047W	\N	\N
12050	617	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
12051	617	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
12052	617	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	05011Y	\N	\N
12053	529	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01006K	\N	\N
12054	529	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92011K	\N	\N
12055	529	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
12056	529	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
12057	529	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04048J	\N	\N
11876	597	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	\N
11877	597	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08059E	\N	\N
11878	597	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
11879	597	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08052W	\N	\N
11880	597	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
11881	597	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08041T	\N	\N
11882	597	2008-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
11883	597	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08067E	\N	\N
11884	597	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
11885	597	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04084N	\N	\N
11886	597	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08011M	\N	\N
10990	964	2006-03-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
10991	627	2006-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01063U	\N	\N
10992	627	2006-03-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89037V	\N	\N
10993	919	2006-03-23 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98053W	\N	\N
10994	964	2006-03-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98053W	\N	\N
10995	576	2006-03-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04059M	\N	\N
10996	576	2006-03-01 00:00:00	2007-07-04 00:00:00	ANCIEN	\N	\N	\N	71003U	\N	\N
10997	576	2006-03-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98050T	\N	\N
11000	598	2006-03-01 00:00:00	2008-04-18 00:00:00	ANCIEN	\N	\N	\N	95031C	\N	\N
11001	919	2006-03-21 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01051Q	\N	\N
11005	597	2006-03-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
11003	964	2006-03-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01051Q	\N	\N
11006	597	2006-03-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98007Q	\N	\N
11007	597	2006-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	59312E	\N	\N
11008	643	2006-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
11009	623	2006-03-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80024B	\N	\N
11401	632	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92020L	\N	\N
11403	632	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
11404	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	02001J	\N	\N
11405	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	\N
11406	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
11407	632	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01053S	\N	\N
11408	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95035G	\N	\N
11409	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01033N	\N	\N
11410	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01022K	\N	\N
11411	632	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	06001B	\N	\N
11412	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	06006G	\N	\N
11413	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
11414	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98051U	\N	\N
11415	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
11416	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04100U	\N	\N
11417	632	2007-06-01 00:00:00	2010-01-07 00:00:00	ANCIEN	\N	\N	\N	86039K	\N	\N
11418	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
11419	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01020H	\N	\N
11420	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
11421	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	73006G	\N	\N
11422	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	02005N	\N	\N
11423	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
11424	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98040R	\N	\N
11425	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
11426	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
11427	632	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
11428	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04043D	\N	\N
11429	632	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01016M	\N	\N
11430	632	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92042S	\N	\N
11431	632	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
11432	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
11433	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01029S	\N	\N
11434	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01036R	\N	\N
11435	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
11436	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89040Q	\N	\N
11437	632	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
11438	632	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01028R	\N	\N
11439	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
11440	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04044E	\N	\N
11441	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	06004E	\N	\N
11442	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
11443	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01023L	\N	\N
11444	632	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04034C	\N	\N
11445	595	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
11608	580	2008-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01045S	\N	\N
11613	902	2008-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
11644	901	2008-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
11645	901	2008-02-19 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98048A	\N	\N
11647	901	2008-02-22 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
11100	947	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95011X	\N	\N
11159	623	2006-10-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
11243	911	2005-02-21 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
11604	595	2007-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04058L	\N	\N
11635	901	2008-02-22 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
11641	583	2008-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
11668	659	2008-04-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	02003L	\N	\N
11651	901	2008-02-19 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	92042S	\N	\N
11669	659	2008-04-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01063U	\N	\N
11670	618	2008-04-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95004Y	\N	\N
11671	618	2008-04-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
11672	618	2008-04-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01024M	\N	\N
11673	618	2008-04-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04051D	\N	\N
11674	618	2008-04-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04089T	\N	\N
11675	618	2008-04-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
11676	618	2008-04-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01009N	\N	\N
11677	618	2008-04-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04080J	\N	\N
11678	618	2008-04-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01047U	\N	\N
11679	634	2008-04-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	\N
11680	634	2008-04-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	00003C	\N	\N
11681	634	2008-04-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	07030L	\N	\N
11682	634	2008-04-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	\N
11683	634	2008-04-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86044G	\N	\N
11684	634	2008-04-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04051D	\N	\N
11685	634	2008-04-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
11686	634	2008-04-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77043E	\N	\N
11687	634	2008-04-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98027U	\N	\N
11688	634	2008-04-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86034E	\N	\N
11689	634	2008-04-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04083M	\N	\N
11690	634	2008-04-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07023M	\N	\N
11691	634	2008-04-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01009N	\N	\N
11692	634	2008-04-24 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
11694	532	2008-05-19 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
11716	585	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
11729	596	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08055A	\N	\N
11746	604	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08017T	\N	\N
11834	647	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01006K	\N	\N
11835	647	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	\N
11836	647	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95013A	\N	\N
11837	647	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
11838	647	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	06001B	\N	\N
11839	647	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92042S	\N	\N
11840	595	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	\N
11841	595	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	\N
11842	595	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95006B	\N	\N
11843	595	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
11844	595	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
11845	595	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
11846	595	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
11070	634	2006-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98003L	\N	\N
11071	634	2006-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83031N	\N	\N
11088	627	2006-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
11089	627	2006-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80039J	\N	\N
11216	597	2006-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
11219	657	2006-12-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
11247	934	2007-02-01 00:00:00	2008-10-30 00:00:00	ANCIEN	\N	\N	\N	06004E	\N	\N
11277	572	2007-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01042P	\N	\N
11278	572	2007-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
11311	674	2007-02-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	\N
11312	674	2007-02-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95005A	\N	\N
11313	674	2007-02-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04046G	\N	\N
11314	674	2007-02-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92020L	\N	\N
11315	674	2007-02-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	06006G	\N	\N
11316	674	2008-02-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
11317	674	2007-02-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
11318	674	2007-02-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
11319	674	2007-02-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01023L	\N	\N
11449	590	2007-07-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07024N	\N	\N
11847	595	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	02053W	\N	\N
11848	595	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07030L	\N	\N
11849	595	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01045S	\N	\N
11850	595	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04051D	\N	\N
11851	595	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
13875	634	2009-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08064B	\N	\N
12265	611	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	\N
12266	611	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01030K	\N	\N
12267	611	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08010L	\N	\N
12268	611	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
12269	611	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
12270	611	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
12271	619	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
12272	619	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
12273	619	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04043D	\N	\N
12274	619	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04090L	\N	\N
12275	646	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
12276	646	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92011K	\N	\N
12277	646	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08058D	\N	\N
12278	646	2008-10-01 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	08007R	\N	\N
12279	646	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	90003B	\N	\N
12280	646	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04071H	\N	\N
12281	646	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	\N
12303	595	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
12304	595	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08039A	\N	\N
12305	583	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08033T	\N	\N
12306	651	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	02003L	\N	\N
12307	651	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98023Q	\N	\N
12308	651	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
12309	651	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	\N
12310	651	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08045X	\N	\N
12311	651	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01055U	\N	\N
12312	651	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
12313	651	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01030K	\N	\N
12314	651	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07023M	\N	\N
12315	651	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
12316	651	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07034Q	\N	\N
12317	651	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04043D	\N	\N
12318	651	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01016M	\N	\N
12319	651	2008-10-01 00:00:00	2010-12-14 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
12320	651	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
12321	651	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08071A	\N	\N
12322	623	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	\N
12323	623	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	\N	\N
12324	623	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04055H	\N	\N
12325	623	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
12326	623	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	\N
12327	623	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92030N	\N	\N
12328	623	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04083M	\N	\N
12329	623	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
12330	623	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
12331	623	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
11386	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	02003L	\N	\N
11387	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
11388	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98048A	\N	\N
11389	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98049B	\N	\N
11390	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
11391	632	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	00003C	\N	\N
11392	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
11393	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80013X	\N	\N
11394	632	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01012H	\N	\N
11395	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
11396	632	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04046G	\N	\N
11397	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01045S	\N	\N
11398	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	\N
11400	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89025R	\N	\N
10980	919	2006-03-16 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
10981	964	2006-03-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
10982	919	2006-03-17 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01023L	\N	\N
10983	964	2006-03-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01023L	\N	\N
16848	957	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04055H	\N	\N
10985	964	2006-03-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04046G	\N	\N
10986	919	2006-03-21 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92020L	\N	\N
10987	964	2006-03-21 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	92020L	\N	\N
10988	919	2006-03-13 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
11910	577	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01016M	\N	\N
11912	577	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
11913	575	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
11914	575	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	02053W	\N	\N
11915	575	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07030L	\N	\N
11916	575	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	\N
11917	575	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
11918	575	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
11919	575	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
11920	575	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
11921	575	2008-10-01 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	01039U	\N	\N
11922	575	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01023L	\N	\N
11923	575	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08061X	\N	\N
12058	529	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01030K	\N	\N
12163	621	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01006K	\N	\N
12164	621	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08068F	\N	\N
12133	626	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	\N
12134	626	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
12135	626	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08024S	\N	\N
12136	626	2008-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98023Q	\N	\N
12137	626	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01012H	\N	\N
12138	626	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04051D	\N	\N
12139	626	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
12140	626	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
12141	626	2008-10-01 00:00:00	2010-11-02 00:00:00	ANCIEN	\N	\N	\N	01026P	\N	\N
12142	626	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
12143	626	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04078Q	\N	\N
12144	626	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
12145	626	2008-10-01 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
12146	626	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04100U	\N	\N
12147	626	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	\N
12148	626	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
12149	626	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07023M	\N	\N
12150	626	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77053G	\N	\N
12151	626	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07030L	\N	\N
12165	621	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	02053W	\N	\N
12166	621	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
12167	621	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
12168	621	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
12169	621	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08048B	\N	\N
12170	621	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04041B	\N	\N
12171	621	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95039L	\N	\N
12172	621	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08067E	\N	\N
12173	621	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
12174	621	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08042U	\N	\N
12175	621	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
12176	621	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
12177	621	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
12178	621	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92042S	\N	\N
11156	968	2006-11-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04069P	\N	\N
11240	911	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04096S	\N	\N
11241	911	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98021N	\N	\N
11244	911	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83050R	\N	\N
11245	911	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04044E	\N	\N
11381	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	\N
11382	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
11383	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
11384	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04052E	\N	\N
11385	632	2007-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01051Q	\N	\N
10587	915	2004-10-01 00:00:00	2007-07-01 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
10588	915	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04061F	\N	\N
10589	915	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01013J	\N	\N
10590	617	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92011K	\N	\N
10591	617	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01045S	\N	\N
10592	617	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
10593	617	2004-10-01 00:00:00	2005-06-28 00:00:00	ANCIEN	\N	\N	\N	04098U	\N	\N
10594	617	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
10595	940	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
10596	940	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
10597	940	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01013J	\N	\N
10598	940	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04091M	\N	\N
10599	940	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98016R	\N	\N
10600	940	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
10601	940	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
10602	940	2004-10-01 00:00:00	2008-03-01 00:00:00	ANCIEN	\N	\N	\N	95024D	\N	\N
10603	940	2004-10-01 00:00:00	2008-03-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
10605	940	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
10607	940	2004-10-01 00:00:00	2007-07-30 00:00:00	ANCIEN	\N	\N	\N	04072J	\N	\N
10608	940	2004-10-01 00:00:00	2007-09-30 00:00:00	ANCIEN	\N	\N	\N	04060E	\N	\N
10609	940	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01057W	\N	\N
10610	940	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
10611	940	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	\N
11503	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01015L	\N	\N
11504	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
11505	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
11506	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89025R	\N	\N
11555	906	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98023Q	\N	\N
11556	906	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
11573	906	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	02005N	\N	\N
11574	906	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
11575	906	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
11576	906	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
11010	578	2006-03-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98017S	\N	\N
11011	578	2006-03-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
11012	619	2006-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95036H	\N	\N
11013	598	2006-04-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
11014	584	2006-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
11015	602	2006-04-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
11016	596	2006-04-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98036V	\N	\N
11017	912	2006-04-13 00:00:00	2008-04-18 00:00:00	ANCIEN	\N	\N	\N	95031C	\N	\N
11018	919	2006-04-21 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98021N	\N	\N
11019	964	2006-04-21 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	98021N	\N	\N
11020	623	2006-05-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98036V	\N	\N
11023	616	2006-04-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
11024	642	2006-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
11025	597	2006-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04091M	\N	\N
11026	608	2006-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
11027	964	2006-06-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
11028	917	2006-06-13 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
11029	619	2006-04-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01023L	\N	\N
11030	625	2006-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	\N
11031	598	2006-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	05011Y	\N	\N
11032	965	2006-06-23 00:00:00	2008-10-30 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	\N
11033	965	2006-06-23 00:00:00	2008-10-30 00:00:00	ANCIEN	\N	\N	\N	89013M	\N	\N
11034	965	2006-06-23 00:00:00	2008-10-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
11035	965	2006-06-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92011K	\N	\N
11036	965	2006-06-23 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
11037	965	2006-06-23 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98048A	\N	\N
11038	965	2006-06-23 00:00:00	2008-10-30 00:00:00	ANCIEN	\N	\N	\N	04047H	\N	\N
11039	965	2006-06-23 00:00:00	2008-10-30 00:00:00	ANCIEN	\N	\N	\N	01059Y	\N	\N
11040	965	2006-06-23 00:00:00	2008-10-30 00:00:00	ANCIEN	\N	\N	\N	95025E	\N	\N
11041	965	2006-06-23 00:00:00	2008-10-30 00:00:00	ANCIEN	\N	\N	\N	04071H	\N	\N
11042	965	2006-06-23 00:00:00	2008-10-30 00:00:00	ANCIEN	\N	\N	\N	01025N	\N	\N
11043	965	2006-06-23 00:00:00	2008-10-30 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
11044	965	2006-06-23 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89030N	\N	\N
11045	965	2006-06-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	\N
11046	965	2006-06-23 00:00:00	2007-06-24 00:00:00	ANCIEN	\N	\N	\N	99004R	\N	\N
11047	965	2006-06-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
11048	965	2006-06-23 00:00:00	2008-10-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
11049	965	2006-06-23 00:00:00	2008-10-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
11050	965	2006-06-23 00:00:00	2008-10-30 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
11051	965	2006-06-23 00:00:00	2008-10-30 00:00:00	ANCIEN	\N	\N	\N	83042R	\N	\N
11052	965	2006-06-23 00:00:00	2008-10-30 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
11053	965	2006-06-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
11054	965	2006-06-23 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	02005N	\N	\N
11055	965	2006-06-23 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
11056	965	2006-06-23 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
11058	965	2006-06-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
11059	965	2006-06-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04033B	\N	\N
11060	965	2006-06-23 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89037V	\N	\N
11061	965	2006-06-23 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89040Q	\N	\N
11062	965	2006-06-23 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
11063	965	2006-06-23 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80041C	\N	\N
11064	965	2006-06-23 00:00:00	2008-10-30 00:00:00	ANCIEN	\N	\N	\N	92044U	\N	\N
11065	965	2006-06-23 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80046H	\N	\N
11066	965	2006-06-23 00:00:00	2008-10-30 00:00:00	ANCIEN	\N	\N	\N	05011Y	\N	\N
11067	965	2006-06-23 00:00:00	2008-10-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
11068	934	2006-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01055U	\N	\N
11069	588	2006-06-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	85003S	\N	\N
11122	968	2006-11-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
11222	909	2007-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95020Y	\N	\N
11231	911	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95013A	\N	\N
11236	911	2004-10-01 00:00:00	2007-02-25 00:00:00	ANCIEN	\N	\N	\N	92024Q	\N	\N
11237	911	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01007L	\N	\N
11239	911	2001-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
11557	906	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01045S	\N	\N
11558	906	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01015L	\N	\N
11559	906	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
11560	906	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89025R	\N	\N
11561	906	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01025N	\N	\N
11562	906	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
11563	906	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
11564	906	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	88009M	\N	\N
11565	906	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04048J	\N	\N
11566	906	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01030K	\N	\N
11577	906	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
11578	906	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86044G	\N	\N
11347	918	2007-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07003H	\N	\N
11466	922	2007-10-01 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	07027R	\N	\N
11579	906	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04090L	\N	\N
11580	906	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04065K	\N	\N
11581	906	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89040Q	\N	\N
11582	906	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
11583	906	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04069P	\N	\N
11584	906	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01034P	\N	\N
11585	906	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92045V	\N	\N
11586	906	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	05011Y	\N	\N
11587	576	2007-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
11588	576	2007-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04075M	\N	\N
11589	584	2007-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04081K	\N	\N
11590	584	2007-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	59312E	\N	\N
11591	608	2007-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	59312E	\N	\N
11592	583	2007-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	07028S	\N	\N
11593	620	2007-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	59312E	\N	\N
11636	901	2008-02-12 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	05011Y	\N	\N
11699	617	2008-05-19 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	85003S	\N	\N
11642	627	2008-01-01 00:00:00	2011-06-10 00:00:00	ANCIEN	\N	\N	\N	07004J	\N	\N
11648	901	2008-02-19 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	92011K	\N	\N
11666	901	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
11700	621	2008-05-19 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	85003S	\N	\N
11701	595	2008-05-19 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	85003S	\N	\N
11090	592	2006-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
11223	964	2007-01-17 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
11702	573	2008-05-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
11703	644	2008-05-19 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
11704	634	2008-05-19 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98051U	\N	\N
11705	634	2008-05-19 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	07003H	\N	\N
11706	634	2008-05-19 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04069P	\N	\N
11713	582	2008-10-29 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
11766	571	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01006K	\N	\N
11767	571	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01051Q	\N	\N
11768	571	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
11769	571	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	\N
11776	571	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
11777	571	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
11778	571	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01030K	\N	\N
11779	571	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
11780	571	2008-10-01 00:00:00	2010-12-14 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
11781	590	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	\N
11782	590	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04087R	\N	\N
11783	590	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08025T	\N	\N
11784	590	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	\N
11785	590	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
11786	590	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04063H	\N	\N
11787	590	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	02003L	\N	\N
11250	673	2007-01-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
11251	673	2007-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96004D	\N	2015-02-02 16:43:25
11252	673	2007-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
11253	673	2007-01-15 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
11254	673	2007-01-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
11255	673	2007-01-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
11256	673	2007-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01063U	\N	\N
11257	673	2007-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
11258	673	2007-01-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	\N
11259	673	2007-01-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
11260	673	2007-01-15 00:00:00	2008-04-18 00:00:00	ANCIEN	\N	\N	\N	95031C	\N	\N
11261	673	2007-01-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
11262	673	2007-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01055U	\N	\N
11263	673	2007-01-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
11264	673	2007-01-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
11265	673	2007-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
11266	673	2007-01-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
11267	673	2007-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
11268	673	2007-01-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	85003S	\N	\N
11269	673	2007-01-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
11270	673	2007-01-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98040R	\N	\N
11271	673	2007-01-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	03002P	\N	\N
11273	673	2007-01-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92044U	\N	\N
11274	673	2007-01-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89042S	\N	\N
11275	673	2007-01-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
11368	661	2007-04-22 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01041N	\N	\N
11369	661	2007-04-22 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95015C	\N	\N
11370	661	2007-04-22 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	\N
11371	661	2007-04-22 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04042C	\N	\N
11372	661	2007-04-22 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98041S	\N	\N
11375	572	2007-04-22 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	05011Y	\N	\N
11376	572	2007-04-22 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
11377	651	2007-06-07 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01064V	\N	\N
11446	623	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01029S	\N	\N
11447	578	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	06004E	\N	\N
11484	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04087R	\N	\N
11467	917	2007-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	07027R	\N	\N
11485	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98036V	\N	\N
11490	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
11491	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	96004D	\N	\N
11492	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01049W	\N	\N
11497	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	90003B	\N	\N
11512	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
11526	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
11527	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	02005N	\N	\N
11528	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
11529	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
11530	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
11531	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
11096	965	2006-06-23 00:00:00	2008-10-30 00:00:00	ANCIEN	\N	\N	\N	04039H	\N	\N
11101	851	0206-09-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01023L	\N	\N
11103	907	2006-09-21 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	06004E	\N	\N
11105	589	2006-09-21 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	06004E	\N	\N
11115	623	2006-10-17 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04080J	\N	\N
11116	618	2006-10-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01012H	\N	\N
11117	618	2006-10-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
11118	573	2006-10-17 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95005A	\N	\N
11320	902	2006-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92011K	\N	\N
11321	902	2006-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
11322	902	2006-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
11323	902	2006-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89025R	\N	\N
11324	902	2006-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
11325	902	2006-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98005N	\N	\N
11326	902	2006-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
11327	902	2006-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
11328	902	2006-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95059Q	\N	\N
11329	902	2006-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
11448	595	2007-07-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07024N	\N	\N
11498	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98023Q	\N	\N
11499	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01045S	\N	\N
11522	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
11523	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
11525	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04083M	\N	\N
11532	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86044G	\N	\N
11753	624	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08034U	\N	\N
11792	590	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
11793	590	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08023R	\N	\N
11794	590	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
11795	590	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	\N
11796	590	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
11797	590	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04077P	\N	\N
11798	590	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08031R	\N	\N
11799	590	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08010L	\N	\N
11800	590	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08062Y	\N	\N
11801	590	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08074D	\N	\N
11802	590	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08011M	\N	\N
11803	590	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07023M	\N	\N
11804	590	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08073C	\N	\N
11805	590	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08047A	\N	\N
11806	590	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07032N	\N	\N
11807	590	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04074L	\N	\N
11808	590	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95059Q	\N	\N
11809	590	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
11810	590	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01062T	\N	\N
11811	590	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92045V	\N	\N
11812	590	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	05011Y	\N	\N
11813	590	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
11814	620	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04087R	\N	\N
11213	919	2006-12-06 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01062T	\N	\N
11214	964	2006-12-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01062T	\N	\N
11215	571	2006-11-28 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	03002P	\N	\N
11221	964	2006-12-29 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	\N
11230	911	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98014P	\N	\N
11238	911	2004-10-01 00:00:00	2010-10-18 00:00:00	ANCIEN	\N	\N	\N	92029V	\N	\N
11480	624	2007-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
11481	907	2007-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86034E	\N	\N
11482	592	2007-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86034E	\N	\N
11483	906	2005-10-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04055H	\N	\N
11533	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92042S	\N	\N
11534	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01016M	\N	\N
11535	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04090L	\N	\N
11537	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89037V	\N	\N
11538	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04065K	\N	\N
11539	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89040Q	\N	\N
11540	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
11541	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01058X	\N	\N
11542	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04069P	\N	\N
11543	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01050P	\N	\N
11544	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01034P	\N	\N
11545	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92045V	\N	\N
11546	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	05011Y	\N	\N
11547	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
11594	573	2007-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04046G	\N	\N
11617	974	2008-02-06 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	07030L	\N	\N
11619	623	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
11620	934	2008-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	\N
11621	906	2008-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07030L	\N	\N
11640	578	2008-01-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95015C	\N	\N
11815	620	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	\N
11816	620	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
11817	620	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	02053W	\N	\N
11818	620	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04038G	\N	\N
11819	620	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07030L	\N	\N
11820	620	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	\N
11821	620	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	\N
11822	620	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
11823	620	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
11824	620	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04077P	\N	\N
11825	620	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01042P	\N	\N
11826	620	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08039A	\N	\N
11827	620	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
11828	620	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04083M	\N	\N
11829	620	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04084N	\N	\N
11830	620	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
11831	620	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
11832	620	2008-10-01 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	01039U	\N	\N
11833	620	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	06004E	\N	\N
11119	968	2006-11-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	\N
11121	968	2006-11-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92011K	\N	\N
11123	968	2006-11-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98023Q	\N	\N
11125	968	2006-11-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95024D	\N	\N
11126	968	2006-11-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01045S	\N	\N
11127	968	2006-11-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01024M	\N	\N
11128	968	2006-11-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04071H	\N	\N
11129	968	2006-11-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
11130	968	2006-11-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89025R	\N	\N
11131	968	2006-11-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
11132	968	2006-11-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	02002K	\N	\N
11133	968	2006-11-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
11134	968	2006-11-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89030N	\N	\N
11135	968	2006-11-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	88012G	\N	\N
11136	968	2006-11-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95036H	\N	\N
13876	634	2009-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
11717	585	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
11718	577	2008-12-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04038G	\N	\N
11719	577	2008-12-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07034Q	\N	\N
11720	577	2008-12-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08050U	\N	\N
11721	597	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08010L	\N	\N
11722	597	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	02053W	\N	\N
11723	597	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07030L	\N	\N
11725	596	2008-12-09 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	01039U	\N	\N
11726	596	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
16340	908	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11101A	\N	\N
11730	596	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	\N
11735	647	2008-12-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08052W	\N	\N
11736	647	2008-12-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98027U	\N	\N
11737	647	2008-12-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
11739	647	2008-12-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01047U	\N	\N
11740	628	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	\N
11741	628	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	\N
11743	529	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
11744	529	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
11745	529	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
11748	604	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
11749	624	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
11750	624	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
11751	624	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	90003B	\N	\N
11752	624	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	\N
11072	966	2006-07-08 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04073K	\N	\N
11073	966	2006-07-08 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01051Q	\N	\N
11074	966	2006-07-08 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04051D	\N	\N
11075	966	2006-07-08 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98049B	\N	\N
11076	966	2006-07-08 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01025N	\N	\N
11077	966	2006-07-08 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
11078	966	2006-07-08 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	88012G	\N	\N
11079	966	2006-07-08 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	\N
11080	966	2006-07-08 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04037F	\N	\N
11081	966	2006-07-08 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
11082	966	2006-07-08 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
11084	966	2006-07-08 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
11086	966	2006-07-08 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80046H	\N	\N
11087	966	2006-07-08 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01034P	\N	\N
11337	576	2007-02-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	06004E	\N	\N
11095	965	2006-06-23 00:00:00	2008-10-30 00:00:00	ANCIEN	\N	\N	\N	04043D	\N	\N
11336	576	2007-02-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86039K	\N	\N
11338	661	2007-02-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
11339	661	2007-02-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
11340	661	2007-02-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	05011Y	\N	\N
11341	661	2007-02-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89035T	\N	\N
11342	661	2007-02-14 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	85003S	\N	\N
11366	661	2007-04-22 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98033S	\N	\N
11367	661	2007-04-22 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80041C	\N	\N
11869	598	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07030L	\N	\N
11870	598	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	\N
11872	598	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	\N
11873	648	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
11874	648	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	\N
11875	648	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07024N	\N	\N
12152	624	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
12153	624	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01030K	\N	\N
12154	598	2008-10-01 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
12155	598	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01027Q	\N	\N
12156	598	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	05011Y	\N	\N
12157	620	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	05011Y	\N	\N
12158	620	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
12159	590	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	\N
12160	575	2008-10-01 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
12161	575	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
12162	575	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01030K	\N	\N
12568	640	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
12593	629	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98022P	\N	\N
11887	597	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77053G	\N	\N
11888	597	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	05011Y	\N	\N
11889	632	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	\N
11890	632	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04059M	\N	\N
11891	632	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
11892	632	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	02053W	\N	\N
11893	632	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
11894	632	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07030L	\N	\N
11895	632	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01011G	\N	\N
11896	632	2008-10-01 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
11897	632	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
11898	632	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
11899	632	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
11900	577	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
11901	577	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08059E	\N	\N
11902	577	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
11903	577	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
11904	577	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
11905	577	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	06001B	\N	\N
11906	577	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
11907	577	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08037X	\N	\N
11908	577	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
11909	577	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
12594	629	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	\N
12595	629	2009-02-03 00:00:00	2010-12-14 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
12596	629	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
12597	629	2009-02-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01045S	\N	\N
12598	673	2009-02-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
12599	673	2009-02-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08041T	\N	\N
12607	904	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04058L	\N	\N
12608	904	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
12609	904	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08065C	\N	\N
12610	904	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	\N
12611	904	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01007L	\N	\N
12612	904	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08034U	\N	\N
12613	904	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08039A	\N	\N
12614	904	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
12615	904	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08011M	\N	\N
12616	904	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
12617	904	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
12618	904	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92042S	\N	\N
12619	904	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
12631	556	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04087R	\N	\N
12632	556	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	\N
12633	556	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
12634	556	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	\N
12635	556	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	\N
12636	556	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
12637	556	2008-10-01 00:00:00	2010-09-20 00:00:00	ANCIEN	\N	\N	\N	07004J	\N	\N
12638	556	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	\N
12639	556	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
12640	556	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
12641	556	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
12642	556	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01023L	\N	\N
11978	613	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	\N
11979	613	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
11981	613	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
11986	589	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08031R	\N	\N
11989	589	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08016S	\N	\N
11991	589	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
11993	657	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
11994	657	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
11995	608	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	02053W	\N	\N
11996	608	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04038G	\N	\N
11998	608	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07003H	\N	\N
11999	608	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
12000	608	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
12001	608	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	\N
12003	608	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08034U	\N	\N
12006	626	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	\N
12011	626	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98029W	\N	\N
12024	583	2008-12-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08017T	\N	\N
12025	583	2008-12-18 00:00:00	2010-03-15 00:00:00	ANCIEN	\N	\N	\N	08013P	\N	\N
12026	597	2008-10-01 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
12027	657	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01006K	\N	\N
12028	657	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	\N
12030	657	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
12031	657	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07030L	\N	\N
12032	657	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04058L	\N	\N
12033	657	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
12034	657	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01057W	\N	\N
12035	657	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	\N
12083	591	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
12084	591	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	\N
12085	591	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
12086	591	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	\N
12087	591	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08048B	\N	\N
12088	591	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	06001B	\N	\N
12089	591	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
12090	591	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08037X	\N	\N
12091	591	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
12092	591	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
12093	591	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01009N	\N	\N
12094	591	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
12095	591	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	05011Y	\N	\N
12096	591	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
12097	598	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	\N
12098	598	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
12099	598	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08024S	\N	\N
12100	598	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
12101	598	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	\N	\N
12102	598	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
12103	598	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	\N
12104	598	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
12105	598	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08065C	\N	\N
11852	595	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	\N
11853	595	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
11854	595	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01055U	\N	\N
11855	595	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08048B	\N	\N
11856	595	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08041T	\N	\N
11857	595	2008-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
11858	595	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	\N
11859	595	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92030N	\N	\N
11860	595	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04100U	\N	\N
11861	595	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07023M	\N	\N
11862	595	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
11863	595	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
11864	595	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
11865	595	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01016M	\N	\N
11866	595	2008-10-01 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	01039U	\N	\N
11867	595	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
11868	595	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04034C	\N	\N
12106	598	2008-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
12108	598	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	06001B	\N	\N
12109	598	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08067E	\N	\N
12110	598	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
12111	598	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08010L	\N	2017-10-09 09:55:18
12112	598	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08034U	\N	\N
12113	598	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
12114	598	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08061X	\N	\N
12115	598	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
12116	598	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
12117	598	2008-10-01 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	01039U	\N	\N
12118	598	2008-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92045V	\N	\N
12261	647	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	\N
12262	611	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
12263	611	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
12264	611	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08027V	\N	\N
12520	573	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08067E	\N	\N
12521	573	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01030K	\N	\N
12522	573	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
12523	573	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08031R	\N	\N
12524	573	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
12525	573	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
12526	573	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08037X	\N	\N
12528	573	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04083M	\N	\N
12529	573	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
12530	573	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08021P	\N	\N
12531	573	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
12532	573	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08073C	\N	\N
12533	573	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92042S	\N	\N
12535	573	2008-10-01 00:00:00	2010-12-14 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
12536	573	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08054Y	\N	\N
12537	573	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04039H	\N	\N
12538	902	2008-10-01 00:00:00	2008-10-30 00:00:00	ANCIEN	\N	\N	\N	08007R	\N	\N
12539	902	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08050U	\N	\N
12540	902	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04073K	\N	\N
12541	902	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01025N	\N	\N
12542	902	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
12543	902	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	\N
12544	902	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04048J	\N	\N
13291	534	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
13292	534	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	05011Y	\N	\N
13293	610	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07003H	\N	\N
13294	610	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08068F	\N	\N
13295	610	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
13296	610	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04055H	\N	\N
13297	610	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08053X	\N	\N
13298	610	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01009N	\N	\N
13299	610	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
13305	581	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
13307	922	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	\N
13069	911	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04097T	\N	\N
13070	911	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98038X	\N	\N
13094	934	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
13110	919	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08060W	\N	\N
13111	919	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08050U	\N	\N
13112	919	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08028W	\N	\N
13113	919	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
13114	919	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	\N	\N
13126	919	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
13127	919	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04069P	\N	\N
13128	919	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92045V	\N	\N
13129	919	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	\N
12506	641	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01030K	\N	\N
12507	641	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08021P	\N	\N
12508	641	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
12509	641	2008-10-01 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	01039U	\N	\N
12510	573	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08050U	\N	\N
12511	573	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	90003B	\N	\N
12512	573	2008-10-01 00:00:00	2010-03-15 00:00:00	ANCIEN	\N	\N	\N	08013P	\N	\N
12380	641	2009-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
12381	641	2009-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
12382	641	2009-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
12442	584	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77058M	\N	\N
12385	851	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
12514	573	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08038Y	\N	\N
12387	622	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07023M	\N	\N
12441	610	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
12443	584	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	02053W	\N	\N
12444	584	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
12445	584	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98022P	\N	\N
12513	573	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07030L	\N	\N
12515	573	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
12517	573	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	\N
12518	573	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
12519	573	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98027U	\N	\N
13235	980	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08021P	\N	\N
13236	588	2009-02-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04038G	\N	\N
13237	588	2009-02-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
13239	581	2008-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
13240	581	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
13241	581	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
13242	581	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92042S	\N	\N
13251	584	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95015C	\N	\N
13252	584	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04078Q	\N	\N
13260	624	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08035V	\N	\N
13261	624	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04056J	\N	\N
13262	576	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
13300	934	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01052R	\N	\N
13246	938	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
13247	938	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	02002K	\N	\N
13306	922	2008-10-01 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	08007R	\N	\N
13302	534	2008-10-01 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	07027R	\N	\N
13303	979	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01058X	\N	\N
13308	922	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08049C	\N	\N
13317	908	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08034U	\N	\N
13318	908	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08071A	\N	\N
13320	908	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95019G	\N	\N
13323	909	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	\N
12545	902	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	\N
12546	902	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
12547	902	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08031R	\N	\N
12548	902	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
12549	902	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
12550	902	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
12551	902	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
12552	902	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
12553	608	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	\N
12554	608	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08015R	\N	2017-10-10 11:04:14
11924	572	2008-10-01 00:00:00	2006-01-23 00:00:00	ANCIEN	\N	\N	\N	59213C	\N	\N
11925	572	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04087R	\N	\N
11926	572	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	\N
11927	572	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01001E	\N	\N
11928	572	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04063H	\N	\N
11929	572	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07030L	\N	\N
11930	572	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
11931	572	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	\N
11932	572	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
11933	572	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01030K	\N	\N
11934	572	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
11935	572	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	2015-03-02 10:42:04
11936	572	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08073C	\N	\N
13325	978	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	\N
13326	978	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97009N	\N	\N
13327	978	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98023Q	\N	\N
13328	978	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01001E	\N	\N
13330	908	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08019V	\N	\N
13332	910	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	\N
13341	910	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	\N
13342	910	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04071H	\N	\N
13343	910	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	\N
13344	910	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01025N	\N	\N
13345	910	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
13346	910	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04064J	\N	\N
13347	910	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
13348	910	2009-03-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
13350	910	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	06001B	\N	\N
12763	597	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08035V	\N	\N
12764	573	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
12765	573	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08065C	\N	\N
12766	573	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08035V	\N	\N
13309	594	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
13310	963	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
13311	963	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
13315	908	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	\N
11937	572	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
11938	572	2008-10-01 00:00:00	2010-12-14 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
11939	642	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04087R	\N	\N
11940	642	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01001E	\N	\N
11941	642	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96004D	\N	2015-02-02 16:56:12
11942	642	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
11943	642	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
11944	642	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
11945	642	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
11946	642	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	\N
11947	642	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08045X	\N	\N
11948	642	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	2014-10-28 17:03:22
11949	642	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08016S	\N	\N
11950	642	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	06001B	\N	\N
11951	642	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04094Q	\N	\N
11952	642	2008-10-01 00:00:00	2009-09-09 00:00:00	ANCIEN	\N	\N	\N	80024B	\N	\N
11953	642	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08012N	\N	\N
11954	642	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08019V	\N	\N
11955	642	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98046X	\N	\N
11956	642	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95050F	\N	\N
11957	642	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
11958	642	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
11959	642	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08073C	\N	\N
13319	908	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08036W	\N	\N
13321	908	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08045X	\N	\N
13334	910	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01064V	\N	\N
13336	910	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08060W	\N	\N
13352	910	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08010L	\N	\N
13353	910	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08039A	\N	\N
13354	910	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08009T	\N	\N
13355	910	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08033T	\N	\N
13356	910	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
13357	910	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04090L	\N	\N
13358	910	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
13359	910	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01050P	\N	\N
13360	910	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08049C	\N	\N
13361	910	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08036W	\N	\N
13362	910	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
13364	965	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01006K	\N	\N
13365	965	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08055A	\N	\N
12971	909	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
13366	965	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	\N
13313	640	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98038X	\N	\N
13314	908	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	\N	\N
13368	907	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01023L	\N	\N
13369	901	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
11960	642	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08029X	\N	\N
11961	642	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04043D	\N	\N
11962	642	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08070Y	\N	\N
11963	642	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
11964	642	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
11965	642	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
11966	642	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
11967	642	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
11968	532	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92011K	\N	\N
11969	532	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
11970	532	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04038G	\N	\N
11971	532	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	\N
11972	532	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
11973	532	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
11974	532	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
11975	532	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
11976	532	2008-10-01 00:00:00	2010-12-14 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
11977	597	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
11980	597	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
11982	595	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	\N
11983	595	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
11984	595	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08009T	\N	\N
11985	595	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04059M	\N	\N
13370	901	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04034C	\N	\N
13375	966	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01006K	\N	\N
13376	901	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08038Y	\N	\N
13377	901	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08055A	\N	\N
13379	940	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04058L	\N	\N
13380	940	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08064B	\N	\N
13381	940	2008-10-01 00:00:00	2009-07-23 00:00:00	ANCIEN	\N	\N	\N	07024N	\N	\N
13391	908	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08021P	\N	\N
13395	966	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
13393	908	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
13394	908	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95044H	\N	\N
13396	966	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08024S	\N	\N
13397	966	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08050U	\N	\N
13398	966	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08045X	\N	\N
13401	901	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	\N
13404	901	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
13407	911	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	87003B	\N	\N
13408	911	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01011G	\N	\N
12849	629	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95036H	\N	\N
12850	629	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04041B	\N	\N
12851	629	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08034U	\N	\N
12852	629	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
12853	629	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
11987	595	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
11988	595	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
12005	659	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07030L	\N	\N
12007	659	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
12008	659	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
12009	659	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
12010	659	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
12012	659	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
12013	659	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04069P	\N	\N
12014	659	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01023L	\N	\N
12015	613	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
12016	613	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01045S	\N	\N
12017	613	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
12018	613	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
12019	613	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92033R	\N	\N
12020	613	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
12650	619	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
12651	619	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	\N
12652	619	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04058L	\N	\N
12653	619	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
12654	619	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
12656	619	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01023L	\N	\N
12662	574	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08009T	\N	\N
12854	629	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08011M	\N	\N
12855	629	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07023M	\N	\N
12856	629	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01054T	\N	\N
12857	629	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77053G	\N	\N
12858	629	2008-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98021N	\N	\N
12859	629	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98021N	\N	\N
12860	629	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	05011Y	\N	\N
12861	629	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08036W	\N	\N
12914	979	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	\N
12915	979	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97009N	\N	\N
12916	979	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
12917	979	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	\N
12918	979	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	\N
12919	979	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89013M	\N	\N
12920	979	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01001E	\N	\N
12921	979	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92013M	\N	\N
12922	979	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	90003B	\N	\N
12923	979	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
12924	979	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98023Q	\N	\N
12926	979	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	\N
12753	582	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
12754	582	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
12755	582	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01030K	\N	\N
12666	613	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
12690	618	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
12694	623	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
12692	644	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
12693	623	2008-10-01 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	07028S	\N	\N
12695	595	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04046G	\N	\N
12696	673	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
12697	673	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
12698	673	2008-10-01 00:00:00	2010-10-11 00:00:00	ANCIEN	\N	\N	\N	01017N	\N	\N
12699	673	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
12700	673	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08036W	\N	\N
12701	968	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
12703	968	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	\N
12704	968	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	\N
12705	968	2008-10-01 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	08007R	\N	\N
12706	968	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
12707	968	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	\N	\N
12710	968	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
12840	623	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
12901	912	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
5407	617	2001-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92030N	\N	\N
12903	912	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08042U	\N	\N
12904	912	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
12756	582	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01014K	\N	\N
12757	579	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04087R	\N	\N
12758	579	2008-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
12759	579	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
12760	579	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
12897	912	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
12898	912	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95024D	\N	\N
12899	912	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08045X	\N	\N
12900	912	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98041S	\N	\N
12925	957	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04073K	\N	\N
12927	979	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92018S	\N	\N
12928	979	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
12930	979	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
12931	979	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
12932	979	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
12933	979	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08065C	\N	\N
12934	979	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	06001B	\N	\N
12935	979	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
12936	979	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08031R	\N	\N
12937	979	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
12938	979	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95047L	\N	\N
12939	979	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08011M	\N	\N
12972	909	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08015R	\N	\N
12905	912	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04033B	\N	\N
12907	534	2008-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	07027R	\N	\N
12908	598	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98022P	\N	\N
12909	598	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08026U	\N	\N
12910	909	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08025T	\N	\N
12911	909	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01064V	\N	\N
12912	909	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08060W	\N	\N
12913	909	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08058D	\N	\N
12957	605	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01057W	\N	\N
12958	605	2009-02-17 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
12959	605	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
12960	605	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
12961	605	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
12963	909	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
12964	909	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04038G	\N	\N
12965	909	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	\N	\N
12967	909	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
12968	909	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	\N
12969	909	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
12712	968	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
12713	968	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
12714	968	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
12715	968	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
12981	909	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
12983	909	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
12982	909	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08021P	\N	\N
12984	909	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08061X	\N	\N
12985	909	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
12986	909	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
13001	906	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04061F	\N	\N
13002	907	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
13003	907	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	\N
13004	907	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	\N
13005	907	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	02003L	\N	\N
13006	907	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95013A	\N	\N
13062	911	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
13063	911	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	\N
13064	911	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08045X	\N	\N
13065	911	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08065C	\N	\N
13066	911	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
13071	934	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
13072	934	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01064V	\N	\N
13073	934	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01049W	\N	\N
13074	934	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
13075	934	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08028W	\N	\N
12716	968	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08010L	\N	\N
12717	968	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08009T	\N	\N
12718	968	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08073C	\N	\N
12719	968	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
12804	634	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95006B	\N	\N
12805	634	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08037X	\N	\N
12808	906	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
12809	906	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04091M	\N	\N
12810	906	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01064V	\N	\N
12811	906	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	\N
12812	906	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08050U	\N	\N
12813	906	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
12814	906	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07001F	\N	\N
12815	906	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04089T	\N	\N
12816	906	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	87003B	\N	\N
12817	906	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08045X	\N	\N
12818	906	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	02002K	\N	\N
12819	906	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
12820	906	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98041S	\N	\N
12821	906	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08016S	\N	\N
12822	906	2008-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
12767	641	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08035V	\N	\N
12769	979	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
13076	934	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
12702	596	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	\N	\N
12708	617	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
12709	590	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	02002K	\N	\N
12711	640	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08024S	\N	\N
12720	616	2009-02-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
12721	616	2009-02-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
12722	616	2009-02-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95035G	\N	\N
12723	616	2009-02-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
12724	579	2009-02-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08058D	\N	\N
12725	579	2009-02-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
12726	627	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	\N
12727	627	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
12751	627	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	\N
12752	627	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
12940	979	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
12941	979	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08021P	\N	\N
12942	979	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
12943	979	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08073C	\N	\N
12944	979	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01009N	\N	\N
12945	979	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98021N	\N	\N
12946	979	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
12947	979	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
12770	978	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
12823	906	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01022K	\N	\N
12824	906	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
12825	906	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04041B	\N	\N
12826	906	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04097T	\N	\N
12827	906	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08034U	\N	\N
12828	906	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08039A	\N	\N
12829	906	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08009T	\N	\N
12830	906	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08062Y	\N	\N
12831	906	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	\N
12832	906	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
12179	621	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	05011Y	\N	\N
12180	621	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08036W	\N	\N
12426	633	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07003H	\N	\N
12182	578	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04043D	\N	\N
12183	578	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
12184	578	2008-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	\N
12217	674	2009-01-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08070Y	\N	\N
12218	674	2009-01-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07034Q	\N	\N
12219	674	2009-01-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04084N	\N	\N
12388	598	2008-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08038Y	\N	\N
12425	633	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	\N
12427	633	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
12428	633	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01051Q	\N	\N
12429	633	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
12430	633	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
12431	633	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08045X	\N	\N
12432	633	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
12433	633	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
12119	596	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08025T	\N	\N
12120	596	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
12121	596	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04038G	\N	\N
12122	596	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
12123	596	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
12124	596	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
12125	596	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
12126	596	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92030N	\N	\N
12127	596	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
12128	596	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
12129	596	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08011M	\N	\N
12130	596	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
12131	596	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95055L	\N	\N
12132	596	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
12220	600	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01006K	\N	\N
12221	600	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
12222	600	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08043V	\N	\N
12223	600	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08024S	\N	\N
12224	600	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04038G	\N	\N
12225	600	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
12226	600	2008-10-01 00:00:00	2010-10-11 00:00:00	ANCIEN	\N	\N	\N	01017N	\N	\N
12227	600	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	\N
12228	600	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08067E	\N	\N
12229	600	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01030K	\N	\N
12230	600	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08039A	\N	\N
12231	600	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08009T	\N	\N
12232	600	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04084N	\N	\N
12233	600	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08074D	\N	\N
12234	600	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07023M	\N	\N
12235	600	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01054T	\N	\N
12236	600	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
12237	608	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
12238	608	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
12239	608	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
12240	608	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	\N	\N
12241	608	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
12242	608	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	\N
12243	608	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
12244	608	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	\N
12245	608	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77019E	\N	\N
12246	608	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
12247	608	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08041T	\N	\N
12248	608	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01030K	\N	\N
12249	608	2008-10-01 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
12250	608	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	\N
12251	608	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
12252	608	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08011M	\N	\N
12253	608	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08047A	\N	\N
12254	608	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
12255	608	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
12256	608	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
12257	608	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77058M	\N	\N
12258	608	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
12259	608	2008-10-01 00:00:00	2010-12-14 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
12260	608	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04065K	\N	\N
12299	596	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	\N
12300	596	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98029W	\N	\N
12301	596	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
12302	596	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
12350	624	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
12351	598	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
12352	620	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
12359	586	2008-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
12360	586	2008-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
12361	586	2008-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
12362	586	2008-12-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
12367	643	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08015R	\N	\N
12364	643	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92018S	\N	\N
12365	643	2009-01-13 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
12366	643	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
12389	642	2008-12-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77043E	\N	\N
12390	642	2008-12-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98023Q	\N	\N
12434	633	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
12435	633	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
12436	633	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
12438	633	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
12439	633	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08049C	\N	\N
11997	608	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01055U	\N	\N
11727	596	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	02053W	\N	\N
12440	610	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08067E	\N	\N
34479	1010	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	14193X	\N	\N
12447	601	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01052R	\N	\N
12448	618	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	\N
12449	618	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
12450	618	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
12451	618	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
12452	618	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01051Q	\N	\N
12453	618	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08050U	\N	\N
12454	618	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	02053W	\N	\N
12455	618	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04055H	\N	\N
12456	618	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08038Y	\N	\N
12457	618	2008-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
12458	618	2008-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77043E	\N	\N
12459	618	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	\N
12460	618	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08045X	\N	\N
12461	618	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
12463	618	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	06001B	\N	\N
12464	618	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08015R	\N	2017-10-10 11:04:14
12465	618	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
12466	618	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
12185	625	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
12186	625	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01059Y	\N	\N
12187	625	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	\N
12188	625	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
12189	625	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
12190	625	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01030K	\N	\N
12191	625	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08010L	\N	\N
12192	625	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
12193	529	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
12298	617	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92030N	\N	\N
12467	618	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08009T	\N	\N
12468	618	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
12469	618	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
12470	618	2008-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01016M	\N	\N
12471	618	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
12472	618	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01016M	\N	\N
12473	618	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
12474	618	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01028R	\N	\N
12475	618	2008-10-01 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	01039U	\N	\N
12477	612	2009-01-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
12478	612	2009-01-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04087R	\N	\N
12479	612	2009-01-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
12480	622	2008-12-09 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	05001W	\N	\N
12481	622	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08009T	\N	\N
12482	622	2008-12-09 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	\N
12574	661	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07030L	\N	\N
12575	661	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
12576	661	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77019E	\N	\N
12577	661	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	2014-10-28 17:03:15
12578	661	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	\N
12579	661	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
12580	661	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
12581	661	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77043E	\N	\N
12582	661	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08011M	\N	\N
12583	661	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08036W	\N	\N
12584	535	2008-10-01 00:00:00	2009-06-04 00:00:00	ANCIEN	\N	\N	\N	07030L	\N	\N
12585	535	2008-10-01 00:00:00	2009-06-04 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
12586	535	2008-10-01 00:00:00	2009-06-04 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
12587	535	2008-10-01 00:00:00	2009-06-04 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
12588	535	2008-10-01 00:00:00	2009-06-04 00:00:00	ANCIEN	\N	\N	\N	07023M	\N	\N
12589	586	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	\N
12590	586	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
12591	586	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08016S	\N	\N
12592	586	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
12600	673	2009-02-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04080J	\N	\N
12601	673	2009-02-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08042U	\N	\N
12602	673	2009-02-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08010L	\N	\N
12603	904	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04073K	\N	\N
12604	904	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08050U	\N	\N
12605	904	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	\N	\N
12606	904	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
12021	613	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08011M	\N	\N
12022	613	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
12023	613	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01016M	\N	\N
12059	624	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01006K	\N	\N
12060	624	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
12061	624	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	\N
12062	624	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08050U	\N	\N
12063	624	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	\N	\N
12064	624	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07030L	\N	\N
12066	624	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
12067	624	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
12068	624	2008-10-01 00:00:00	2010-09-20 00:00:00	ANCIEN	\N	\N	\N	07004J	\N	\N
12069	624	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
12070	624	2008-10-01 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
12071	624	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
12072	624	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
12073	624	2008-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	86044G	\N	\N
12074	624	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
12075	624	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04065K	\N	\N
12076	624	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01028R	\N	\N
12077	624	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
12078	591	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01006K	\N	\N
12079	591	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	\N
12080	591	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
12081	591	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	\N
12082	591	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04038G	\N	\N
13814	653	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04069P	\N	\N
13815	653	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98005N	\N	\N
13829	622	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
13830	622	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98023Q	\N	\N
13523	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
13605	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	\N
13606	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
13607	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
13608	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01023L	\N	\N
13649	640	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92011K	\N	\N
13650	640	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01011G	\N	\N
13651	641	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01059Y	\N	\N
13654	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
13697	964	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97009N	\N	\N
13870	651	2009-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	\N
13871	651	2009-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
13911	599	2009-10-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08063A	\N	\N
9911	644	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04066L	\N	\N
9237	584	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95019G	\N	\N
9693	580	2004-10-01 00:00:00	2007-07-19 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
9754	641	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98027U	\N	\N
9792	617	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04066L	\N	\N
9847	600	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
10569	924	2005-04-11 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04069P	\N	\N
10903	919	2006-02-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	77053G	\N	\N
13652	913	2008-10-01 00:00:00	2010-10-11 00:00:00	ANCIEN	\N	\N	\N	01017N	\N	\N
13658	934	2008-10-01 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	01039U	\N	\N
13889	651	2009-10-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	\N
13893	915	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
13894	915	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08036W	\N	\N
13895	915	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04079R	\N	\N
13896	915	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
13954	617	2010-01-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08031R	\N	\N
13952	653	2010-01-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
13953	596	2010-01-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	09010Q	\N	\N
10336	646	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
9781	648	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
16346	908	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01011G	\N	\N
16347	908	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	2014-09-28 17:40:23
16351	908	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08037X	\N	2014-09-28 17:34:16
16392	948	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11044J	\N	\N
16369	918	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
16370	918	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
16371	918	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	2014-09-28 17:40:23
16380	918	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
16390	948	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
16391	948	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08050U	\N	2014-09-28 12:44:31
16393	948	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	90003B	\N	\N
16394	948	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
16395	948	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	2014-09-28 13:21:47
16396	948	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08022Q	\N	\N
16397	948	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11096W	\N	\N
16398	948	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	2014-09-28 19:03:23
16404	948	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11048N	\N	\N
16407	948	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
16409	948	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
16419	910	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	2014-09-28 12:56:42
16420	910	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	2014-09-28 16:50:17
16432	910	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01025N	\N	\N
13124	919	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08061X	\N	\N
13125	919	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
13195	922	2008-10-01 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	07028S	\N	\N
13196	922	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	\N
13197	922	2008-10-01 00:00:00	2009-07-23 00:00:00	ANCIEN	\N	\N	\N	07024N	\N	\N
13199	922	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01057W	\N	\N
13200	922	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08009T	\N	\N
13202	922	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08062Y	\N	\N
13204	922	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08074D	\N	\N
13205	922	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01062T	\N	\N
13206	922	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08036W	\N	\N
13210	965	2008-10-01 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	01039U	\N	\N
13045	909	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08063A	\N	\N
13046	948	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08050U	\N	\N
13047	948	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	\N	\N
13048	948	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
13049	948	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
13050	948	2008-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
13057	911	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08060W	\N	\N
13081	934	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92020L	\N	\N
13082	934	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08064B	\N	\N
13083	934	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08065C	\N	\N
13084	934	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08016S	\N	\N
13698	964	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08059E	\N	\N
13699	964	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08060W	\N	\N
13794	621	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08038Y	\N	\N
13749	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	02001J	\N	\N
13780	964	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01053S	\N	\N
13786	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01053S	\N	\N
13787	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	\N
13795	621	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08035V	\N	\N
13796	621	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04042C	\N	\N
13874	609	2009-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
13877	634	2009-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	\N
13878	634	2009-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08074D	\N	\N
13879	634	2009-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	06004E	\N	\N
13916	674	2009-10-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	02003L	\N	\N
13659	931	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
13660	931	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89013M	\N	\N
13661	931	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01005J	\N	\N
13662	931	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92011K	\N	\N
13663	931	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
13664	931	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98024R	\N	\N
13665	931	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	\N
13666	931	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
13667	931	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
11205	634	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92008Q	\N	\N
9816	575	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92008Q	\N	\N
11465	617	2007-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01006K	\N	\N
7806	906	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01011G	\N	\N
11057	965	2006-06-23 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01016M	\N	\N
9721	629	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01018P	\N	\N
5314	661	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01027Q	\N	\N
13714	615	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92008Q	\N	\N
13715	615	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
13716	615	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
13717	615	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08053X	\N	\N
13718	615	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83047W	\N	\N
13719	615	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
13720	659	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	\N	\N
13721	642	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98006P	\N	\N
13722	585	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
13745	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95013A	\N	\N
13746	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08021P	\N	\N
13747	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08068F	\N	\N
13748	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95037J	\N	\N
13880	651	2009-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86053H	\N	\N
13844	629	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08064B	\N	\N
13872	621	2009-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08063A	\N	\N
14135	931	2011-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
16513	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01022K	\N	\N
16514	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01011G	\N	\N
16545	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11077T	\N	\N
16580	910	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11113E	\N	\N
16578	965	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	2014-09-28 17:40:23
16579	908	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11113E	\N	\N
16589	911	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	\N	2014-09-28 17:03:42
16590	911	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	2014-09-28 13:21:47
16591	911	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08067E	\N	2014-09-28 17:22:11
16599	911	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08054Y	\N	2014-09-28 12:39:09
16600	918	2011-10-01 00:00:00	2013-02-06 00:00:00	ANCIEN	\N	\N	\N	08036W	\N	\N
16601	911	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
16602	911	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08060W	\N	\N
16604	911	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11112D	\N	\N
16605	908	2011-10-01 00:00:00	2013-02-06 00:00:00	ANCIEN	\N	\N	\N	08036W	\N	\N
16606	911	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11088W	\N	\N
16607	911	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11015D	\N	\N
16608	911	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01007L	\N	\N
16625	922	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01024M	\N	\N
16626	922	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01015L	\N	\N
16627	922	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:20
12887	584	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08009T	\N	\N
12888	584	2008-10-01 00:00:00	2010-01-07 00:00:00	ANCIEN	\N	\N	\N	86039K	\N	\N
12889	584	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08011M	\N	\N
12890	584	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08021P	\N	\N
12891	584	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08073C	\N	\N
12892	584	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08047A	\N	\N
12893	584	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
12894	584	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
13926	957	2010-01-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
12980	909	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08010L	\N	\N
12987	909	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01029S	\N	\N
12988	909	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
13116	919	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08045X	\N	\N
12990	909	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04069P	\N	\N
12991	909	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04034C	\N	\N
13115	919	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
13117	919	2008-10-01 00:00:00	2011-06-01 00:00:00	ANCIEN	\N	\N	\N	07004J	\N	\N
13118	919	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
13119	919	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
13120	919	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04097T	\N	\N
13121	919	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08010L	\N	\N
13122	919	2008-10-01 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
13123	919	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08021P	\N	\N
13668	931	2008-11-26 00:00:00	2011-06-10 00:00:00	ANCIEN	\N	\N	\N	07004J	\N	\N
13669	931	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01030K	\N	\N
13670	931	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08021P	\N	\N
13671	931	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01009N	\N	\N
13672	931	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
13673	931	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
13674	931	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
13675	931	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
13704	964	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
13705	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97009N	\N	\N
13706	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08059E	\N	\N
13710	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08057C	\N	\N
13708	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01051Q	\N	\N
13709	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04053F	\N	\N
13711	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04038G	\N	\N
13712	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	80013X	\N	\N
13429	908	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	\N	\N
13566	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
13572	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01016M	\N	\N
13573	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01062T	\N	\N
13574	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08049C	\N	\N
13575	928	2009-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	\N
13641	964	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98006P	\N	\N
13917	922	2009-10-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08059E	\N	\N
13918	922	2009-10-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07024N	\N	\N
13966	911	2009-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	09012S	\N	\N
13930	626	2010-01-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	10001F	\N	\N
13931	629	2010-01-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04080J	\N	\N
10929	919	2006-02-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	80024B	\N	\N
10659	905	2005-06-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	04059M	\N	\N
13625	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
13740	964	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95013A	\N	\N
13741	964	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08021P	\N	\N
13742	964	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08068F	\N	\N
13882	603	2009-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
13744	964	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	02001J	\N	\N
13881	603	2009-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01006K	\N	\N
13883	603	2009-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08050U	\N	\N
13884	603	2009-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
13885	603	2009-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
13886	603	2009-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
13887	603	2009-04-22 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
13888	603	2009-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01030K	\N	\N
13890	603	2009-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
13891	603	2009-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
13898	915	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	\N
16628	922	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
16629	922	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	2014-09-28 17:40:23
16849	957	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04046G	\N	2014-09-28 17:07:41
16659	909	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	2014-09-28 16:50:17
16882	957	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
16980	919	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08050U	\N	2014-09-28 12:44:31
16707	918	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	2014-09-28 13:19:48
17028	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01016M	\N	\N
16775	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08016S	\N	\N
17043	934	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	2014-09-28 18:03:38
16884	957	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08054Y	\N	2014-09-28 12:39:09
17053	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	80013X	\N	\N
16886	957	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04069P	\N	2014-09-28 17:31:41
16887	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
16888	957	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98037W	\N	2014-09-28 14:31:42
16889	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	95037J	\N	\N
16890	957	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
16891	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01022K	\N	\N
16892	957	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11066Q	\N	\N
16894	957	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11063M	\N	\N
16895	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04097T	\N	\N
16896	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
16897	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	86034E	\N	\N
13156	918	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
13157	918	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
13158	918	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
13159	918	2008-10-01 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	01039U	\N	\N
13160	918	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
13214	594	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
13211	965	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
13213	594	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
13215	594	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04041B	\N	\N
13216	594	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
8422	932	2001-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
8423	932	2001-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	00003C	\N	\N
8424	932	2001-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	95015C	\N	\N
8425	932	2001-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	\N
8426	932	2001-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01045S	\N	\N
8427	932	2001-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
8428	932	2001-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	86006A	\N	\N
8429	932	2001-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98017S	\N	\N
8430	932	2001-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	78003A	\N	\N
8431	932	2001-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01011G	\N	\N
8432	932	2001-01-01 00:00:00	2004-11-26 00:00:00	ANCIEN	\N	\N	\N	95036H	\N	\N
8433	932	2001-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	88009M	\N	\N
8434	932	2001-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
8435	932	2001-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98054X	\N	\N
8436	932	2001-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01018P	\N	\N
8437	932	2001-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
13642	964	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	\N
13643	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	\N
13644	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98006P	\N	\N
13655	622	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
13656	622	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08065C	\N	\N
13657	622	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01009N	\N	\N
13847	532	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08063A	\N	\N
13903	915	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04046G	\N	\N
13904	915	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08072B	\N	\N
13905	915	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95020Y	\N	\N
13906	915	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
13907	915	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08061X	\N	\N
13908	915	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
13909	612	2009-10-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07034Q	\N	\N
13910	934	2009-10-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
13928	642	2009-06-25 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	10001F	\N	\N
13438	911	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
13567	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08055A	\N	\N
13713	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
13738	947	2008-11-26 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	01039U	\N	\N
13750	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04087R	\N	\N
13792	659	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
13818	623	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04056J	\N	\N
13899	915	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77058M	\N	\N
13900	915	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92042S	\N	\N
12833	906	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
12834	906	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
13053	948	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
12836	906	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04033B	\N	\N
12837	906	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	59312E	\N	\N
12838	906	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92043T	\N	\N
12839	906	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
12970	909	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08016S	\N	\N
13051	948	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04097T	\N	\N
13052	948	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08061X	\N	\N
13054	948	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77058M	\N	\N
13055	948	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
12332	623	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01010F	\N	\N
12333	596	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04042C	\N	\N
12334	596	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
12335	596	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01027Q	\N	\N
12336	596	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
12337	596	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	\N
12338	596	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01054T	\N	\N
12340	601	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
12341	601	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	\N
12342	601	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
12343	601	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
12344	601	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08009T	\N	\N
12345	601	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
12346	601	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	05011Y	\N	\N
12347	601	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
12348	674	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92008Q	\N	\N
12349	674	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08032S	\N	\N
12354	632	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08014Q	\N	\N
12355	632	2009-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	\N
12356	632	2009-01-01 00:00:00	2009-05-20 00:00:00	ANCIEN	\N	\N	\N	07004J	\N	\N
12357	632	2009-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04082L	\N	\N
12368	590	2009-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08042U	\N	\N
12370	657	2009-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
13056	948	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
13059	911	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01052R	\N	\N
13060	911	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07030L	\N	\N
13061	911	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	\N	\N
13067	911	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08016S	\N	\N
13068	911	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
13304	625	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01062T	\N	\N
13322	908	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
13399	966	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08043V	\N	\N
13400	966	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
13402	901	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08025T	\N	\N
13403	901	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08050U	\N	\N
13409	911	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04041B	\N	\N
13410	911	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08063A	\N	\N
13411	911	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08021P	\N	\N
13412	911	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07023M	\N	\N
13413	911	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	06004E	\N	\N
13414	910	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08068F	\N	\N
13415	642	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
13416	642	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08026U	\N	\N
13417	591	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08035V	\N	\N
13418	966	2008-10-01 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	01039U	\N	\N
13419	648	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
12371	597	2008-01-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08038Y	\N	\N
12372	647	2008-01-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08038Y	\N	\N
12418	556	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
12419	556	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	02003L	\N	\N
11724	597	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
11742	529	2008-12-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
12420	556	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04080J	\N	\N
12421	556	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08050U	\N	\N
12422	556	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07023M	\N	\N
12423	556	2009-01-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
12446	598	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01029S	\N	\N
12555	623	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07024N	\N	\N
12559	582	2009-01-27 00:00:00	2009-07-23 00:00:00	ANCIEN	\N	\N	\N	95049N	\N	\N
12560	582	2009-01-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08050U	\N	\N
12561	582	2009-01-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
12562	582	2009-01-27 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	2014-10-28 17:07:02
12563	582	2009-01-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08016S	\N	\N
12564	582	2009-01-27 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
12566	599	2009-01-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08055A	\N	\N
12567	599	2009-01-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
12571	661	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92008Q	\N	\N
12572	661	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
12573	661	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
13420	648	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
13421	585	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
13274	911	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	05011Y	\N	\N
13316	908	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04041B	\N	\N
13329	908	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04064J	\N	\N
13331	910	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01006K	\N	\N
13333	910	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	\N
13335	910	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01049W	\N	\N
13337	910	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08057C	\N	\N
13338	910	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	\N
13339	910	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92018S	\N	\N
13340	910	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	\N	\N
13349	910	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04048J	\N	\N
13351	910	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
13363	965	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04059M	\N	\N
13378	901	2008-10-01 00:00:00	2010-03-15 00:00:00	ANCIEN	\N	\N	\N	08013P	\N	\N
13382	940	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08010L	\N	\N
13383	940	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07034Q	\N	\N
13384	940	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01029S	\N	\N
13385	940	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
13386	940	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04044E	\N	\N
13387	940	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
13388	901	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
12194	572	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01006K	\N	\N
12195	583	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98036V	\N	\N
12196	583	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08014Q	\N	\N
12197	583	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	\N	\N
12198	583	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95015C	\N	\N
12199	583	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
12200	583	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
12201	583	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
12202	583	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08023R	\N	\N
12203	583	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
12204	583	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
12205	583	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
12206	583	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98005N	\N	\N
12207	583	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08019V	\N	\N
12208	583	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01020H	\N	\N
12209	583	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08011M	\N	\N
12210	583	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
12211	583	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77053G	\N	\N
12212	583	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
12213	583	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01009N	\N	\N
12214	583	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
12215	583	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	05011Y	\N	\N
12216	583	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
13389	901	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08060W	\N	\N
13390	901	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
13405	911	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	\N	\N
13406	911	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95020Y	\N	\N
12864	957	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08068F	\N	\N
12865	957	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07001F	\N	\N
12866	957	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	\N
12867	957	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04097T	\N	\N
13007	907	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
13008	907	2008-10-01 00:00:00	2008-10-01 00:00:00	ANCIEN	\N	\N	\N	95019G	\N	\N
13009	907	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	\N
13010	907	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95024D	\N	\N
13011	907	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	\N	\N
13012	907	2008-10-01 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	07028S	\N	\N
13013	907	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
13014	907	2008-10-01 00:00:00	2010-11-02 00:00:00	ANCIEN	\N	\N	\N	01026P	\N	\N
13015	907	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	\N
13016	907	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
13017	907	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	02002K	\N	\N
13018	907	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04048J	\N	\N
13019	907	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
13020	907	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01030K	\N	\N
13022	907	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08010L	\N	\N
12282	646	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
12283	646	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01041N	\N	\N
12284	646	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
12285	646	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	\N
12286	646	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
12287	646	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98041S	\N	\N
12288	646	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07024N	\N	\N
12289	646	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01030K	\N	\N
12290	646	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01021J	\N	\N
12291	646	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77043E	\N	\N
12292	646	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08009T	\N	\N
12293	646	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
12294	646	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
12296	646	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98050T	\N	\N
12297	646	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04074L	\N	\N
12358	625	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04051D	\N	\N
12402	530	2009-01-14 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
12403	644	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92011K	\N	\N
12404	644	2009-01-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95013A	\N	\N
12405	644	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	02053W	\N	\N
12406	644	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07030L	\N	\N
12407	644	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01012H	\N	\N
12408	644	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
13023	907	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08034U	\N	\N
13024	907	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08039A	\N	\N
13025	907	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
13026	907	2008-10-01 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
13027	907	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08009T	\N	\N
12955	909	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	\N	\N
12956	909	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08024S	\N	\N
12974	592	2009-02-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
12976	592	2009-02-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04038G	\N	\N
12977	592	2009-02-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
12978	592	2009-02-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98029W	\N	\N
12979	592	2009-02-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
12994	594	2009-02-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	02002K	\N	\N
12995	594	2009-02-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	\N
13030	907	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
12997	594	2009-02-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04039H	\N	\N
13028	907	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08053X	\N	\N
13029	907	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08074D	\N	\N
13031	907	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08033T	\N	\N
13032	907	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08011M	\N	\N
13033	907	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
13034	907	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08021P	\N	\N
13035	907	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07023M	\N	\N
12409	644	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	\N
12410	644	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04077P	\N	\N
12411	574	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08038Y	\N	\N
12412	574	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	\N
12339	625	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
12375	651	2009-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08015R	\N	\N
12376	575	2009-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	\N
12377	575	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08038Y	\N	\N
12392	574	2009-01-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04078Q	\N	\N
12379	620	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08038Y	\N	\N
12483	620	2009-01-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08021P	\N	\N
12393	574	2009-01-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01013J	\N	\N
12394	574	2009-01-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08017T	\N	\N
12395	574	2009-01-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
12396	574	2009-01-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95019G	\N	\N
12397	574	2009-01-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	\N
12398	574	2009-01-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
12399	574	2009-01-06 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
12401	591	2008-12-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95003X	\N	\N
12413	574	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95032D	\N	\N
12414	574	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07026Q	\N	\N
12415	574	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	05001W	\N	\N
12416	574	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01030K	\N	\N
13036	907	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08061X	\N	\N
13037	907	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07034Q	\N	\N
13038	907	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77058M	\N	\N
13039	907	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95059Q	\N	\N
13040	907	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
13041	907	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
13042	907	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01058X	\N	\N
13043	907	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04069P	\N	\N
13044	907	2008-10-01 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	01039U	\N	\N
13167	965	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08009T	\N	\N
13168	965	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08049C	\N	\N
13169	965	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01010F	\N	\N
13170	965	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04034C	\N	\N
13194	922	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97009N	\N	\N
7680	927	2002-07-24 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95014B	\N	\N
8421	932	2001-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	79004F	\N	\N
13258	980	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	\N	\N
13272	979	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01016M	\N	\N
13273	979	2008-10-01 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	07027R	\N	\N
13275	980	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01011G	\N	\N
13276	590	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
13277	641	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
13278	534	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	\N
12417	574	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04039H	\N	\N
12424	659	2008-10-01 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
12484	530	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	\N
12485	530	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
12486	530	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
12487	530	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
12488	530	2008-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
12489	530	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08031R	\N	\N
12490	530	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	\N
12491	530	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08074D	\N	\N
12492	530	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07023M	\N	\N
12493	530	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04074L	\N	\N
12494	530	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
12495	530	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
12496	530	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04039H	\N	\N
12497	625	2008-10-01 00:00:00	2009-03-30 00:00:00	ANCIEN	\N	\N	\N	04080J	\N	\N
12498	618	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08021P	\N	\N
12500	641	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
12501	641	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07003H	\N	\N
12502	641	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08059E	\N	\N
12503	641	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08048B	\N	\N
12504	641	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08067E	\N	\N
12505	641	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	\N
13279	534	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
13280	534	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	\N
13281	534	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
13282	534	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
13283	534	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
13284	534	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
13285	534	2008-10-01 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
13286	534	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01030K	\N	\N
13287	534	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
12862	957	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98036V	\N	\N
12863	957	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01064V	\N	\N
12868	957	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01042P	\N	\N
12869	957	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
12870	957	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08042U	\N	\N
12871	957	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
12896	957	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
12906	968	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01030K	\N	\N
12998	906	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01013J	\N	\N
12999	906	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08038Y	\N	\N
13000	906	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83031N	\N	\N
13288	534	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
13289	534	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07023M	\N	\N
13290	534	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
13565	978	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04039H	\N	\N
13576	928	2009-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01052R	\N	\N
13577	928	2009-04-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	06004E	\N	\N
13761	628	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
13762	628	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	02053W	\N	\N
13763	628	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
13764	628	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
13765	628	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08074D	\N	\N
13789	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
13441	588	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
13442	588	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08012N	\N	\N
13443	588	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
13444	588	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
13445	588	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
13446	963	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08033T	\N	\N
13447	579	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
13448	579	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
13449	979	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
13450	979	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92045V	\N	\N
13451	979	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
13452	979	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01045S	\N	\N
13453	979	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
13454	979	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
9266	584	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95055L	\N	\N
9906	617	2004-10-01 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	95004Y	\N	\N
10612	940	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95039L	\N	\N
13696	908	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	\N
13873	922	2008-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	08059E	\N	\N
13939	915	2010-02-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01057W	\N	\N
8999	556	2003-06-30 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
9089	922	2004-12-03 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
9213	590	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	\N
8834	642	2004-10-18 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98041S	\N	\N
8893	598	2003-06-30 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04087R	\N	\N
8945	641	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01054T	\N	\N
8979	534	2004-10-15 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95005A	\N	\N
9610	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04073K	\N	\N
9635	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	02001J	\N	\N
9665	626	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
9268	584	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04090L	\N	\N
9298	618	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
9320	585	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
9411	621	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04042C	\N	\N
13925	957	2010-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08053X	\N	\N
6462	588	2002-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	\N
5886	643	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
14070	643	2010-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
14037	647	2010-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
14038	590	2010-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
14039	626	2010-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
14064	618	2010-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
14033	963	2010-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07030L	\N	\N
14034	963	2010-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08028W	\N	\N
14035	963	2010-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
14063	618	2010-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
14065	632	2010-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
14068	595	2010-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	10015M	\N	\N
14072	618	2010-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
14050	912	2011-01-04 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
14074	608	2010-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04042C	\N	\N
14052	912	2011-01-12 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04041B	\N	\N
14040	625	2010-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
14075	674	2011-03-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	\N
14077	646	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
14078	594	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
14079	933	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
14080	915	2011-04-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
14083	909	2011-05-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
14090	618	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
13207	605	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01030K	\N	\N
13208	605	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
13209	605	2008-10-01 00:00:00	2010-12-14 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
13265	601	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01059Y	\N	\N
13233	965	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
13266	601	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
13267	601	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08035V	\N	\N
13269	979	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
12872	584	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
12873	584	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
12874	584	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
12875	584	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
12876	584	2008-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01055U	\N	\N
12877	584	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08067E	\N	\N
12878	584	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	\N
12879	584	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
12880	584	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98005N	\N	\N
12881	584	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08015R	\N	\N
12882	584	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08010L	\N	\N
12883	584	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08034U	\N	\N
12884	584	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95044H	\N	\N
12885	584	2008-10-01 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
12886	584	2008-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98046X	\N	\N
13455	979	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
13456	674	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	85002R	\N	\N
13457	592	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83012K	\N	\N
13458	601	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83012K	\N	\N
13510	964	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
13591	966	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
13592	911	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
13594	911	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98041S	\N	\N
13595	911	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08042U	\N	\N
13596	911	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04033B	\N	\N
13604	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
13568	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01015L	\N	\N
13569	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	87003B	\N	\N
13570	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08016S	\N	\N
13571	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
13597	909	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08040S	\N	\N
13609	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95015C	\N	\N
13610	964	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08040S	\N	\N
13646	921	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08038Y	\N	\N
13647	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08038Y	\N	\N
13648	908	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08042U	\N	\N
13653	909	2008-10-01 00:00:00	2010-10-11 00:00:00	ANCIEN	\N	\N	\N	01017N	\N	\N
13788	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08067E	\N	\N
5417	617	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
8826	642	2004-10-18 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
9096	594	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	\N
9239	584	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	80013X	\N	\N
11225	911	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
11568	906	2006-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
10442	957	2005-03-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92042S	\N	\N
8785	904	2004-10-01 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	92022N	\N	\N
11402	632	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
7433	922	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
9278	584	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
9011	556	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
8653	913	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
5554	532	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
13695	908	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08040S	\N	\N
13739	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98053W	\N	\N
13798	589	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08063A	\N	\N
13799	632	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
13800	601	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08063A	\N	\N
13801	598	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08063A	\N	\N
13902	599	2009-10-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	09012S	\N	\N
13803	600	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08063A	\N	\N
13804	647	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08063A	\N	\N
14091	595	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
14092	624	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92020L	\N	\N
14093	588	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
14094	529	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
14095	623	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
14096	626	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
14097	608	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
14098	584	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
14099	582	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
14100	659	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
14101	648	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
14102	585	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
14103	625	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
14104	600	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
14105	575	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
14106	617	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
14107	596	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
14111	940	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
14112	938	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
14138	576	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
14136	642	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08023R	\N	\N
14139	590	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
14140	579	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
13135	576	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08038Y	\N	\N
13136	576	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08035V	\N	\N
13137	576	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	06001B	\N	\N
13138	576	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08031R	\N	\N
13139	576	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08034U	\N	\N
13324	978	2009-03-03 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77043E	\N	\N
13142	576	2008-10-01 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	07027R	\N	\N
13143	576	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08021P	\N	\N
13144	576	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07023M	\N	\N
13145	576	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83047W	\N	\N
13146	576	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
13147	576	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
13148	576	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
13149	576	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08036W	\N	\N
13161	965	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08050U	\N	\N
13171	911	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08064B	\N	\N
13188	980	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	06004E	\N	\N
13189	980	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07030L	\N	\N
13190	980	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
13201	605	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
13193	851	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01030K	\N	\N
13198	605	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	\N	\N
13203	605	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	\N
13805	653	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04042C	\N	\N
13806	653	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
13807	653	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98024R	\N	\N
13808	653	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04058L	\N	\N
13809	653	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
13810	653	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04075M	\N	\N
13811	653	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07029T	\N	\N
13812	653	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92030N	\N	\N
13813	653	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
20183	912	2013-06-12 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	09001P	\N	\N
20187	609	2013-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08067E	2013-07-17 17:47:45	2014-09-28 17:22:11
20188	613	2013-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08067E	2013-07-17 17:50:31	2014-09-28 17:22:11
20184	911	2013-06-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	09001P	2013-06-12 15:22:40	\N
20181	629	2013-05-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04057K	2013-05-31 10:48:25	2013-05-31 10:49:07
19675	674	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11012A	\N	\N
19676	653	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
19677	674	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
19678	674	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
19679	653	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
19680	653	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	10006L	\N	\N
19681	674	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08053X	\N	\N
19682	674	2011-10-01 00:00:00	2014-05-02 00:00:00	ANCIEN	\N	\N	\N	08070Y	\N	\N
19683	653	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
19684	653	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
19157	646	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	2014-09-28 18:03:38
19158	646	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11030C	\N	\N
19159	646	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	2014-09-28 18:19:47
19160	646	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
19161	646	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	2014-09-28 12:56:42
19162	646	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	2014-09-28 12:56:42
19163	646	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95025E	\N	2014-09-28 17:09:16
19164	646	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
19165	529	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
19166	530	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
19167	530	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
19333	556	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
19334	556	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
19335	571	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
19336	571	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	2014-09-28 18:03:38
19337	571	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	2014-09-28 16:50:17
19338	571	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	2014-09-28 13:16:32
19339	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
19340	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11054L	\N	\N
19341	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11114F	\N	\N
19342	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11089X	\N	\N
19343	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11099A	\N	\N
19509	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04083M	\N	2014-09-28 16:40:50
19510	574	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
19511	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11085T	\N	\N
19512	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11100Y	\N	\N
19513	572	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04056J	\N	\N
19514	572	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	2014-09-28 16:42:05
19515	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	2014-09-28 16:59:41
19516	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11042G	\N	\N
19517	574	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
19518	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11069T	\N	\N
19519	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11070L	\N	\N
19685	674	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
19686	674	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04084N	\N	2014-09-28 13:40:33
19687	653	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04086Q	\N	\N
19688	653	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	2014-09-28 16:59:41
19689	653	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04043D	\N	\N
19690	934	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95047L	\N	2014-09-28 17:09:16
19691	912	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04044E	\N	\N
19692	571	2011-05-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	2014-09-28 19:03:23
19693	620	2011-05-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08049C	\N	2014-09-28 19:07:43
19694	912	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08034U	\N	\N
19695	912	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11088W	\N	\N
19696	918	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98037W	\N	2014-09-28 14:31:42
19700	912	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04073K	\N	2014-09-28 18:58:25
19698	912	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11112D	\N	\N
19699	912	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	2014-09-28 18:03:38
19701	659	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92018S	\N	\N
19702	912	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08042U	\N	\N
19179	646	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04034C	\N	\N
19180	529	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
19181	529	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04044E	\N	\N
19182	530	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08031R	\N	\N
19183	530	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	03001N	\N	2014-09-28 13:40:33
19184	530	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01042P	\N	\N
19185	646	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
19186	646	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	2014-09-28 16:50:17
19187	646	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98050T	\N	\N
19188	529	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	2014-09-28 18:00:58
19189	529	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	\N	2014-09-28 17:03:42
19344	574	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11112D	\N	\N
19345	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
19346	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07030L	\N	2014-09-28 17:03:41
19347	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	2014-09-28 13:21:47
19348	596	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	2014-09-28 13:16:32
19349	596	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:20
19350	596	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
19351	596	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
19352	596	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11060J	\N	\N
19353	596	2011-10-01 00:00:00	2012-02-22 00:00:00	ANCIEN	\N	\N	\N	11010L	\N	\N
19354	572	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11091R	\N	\N
19520	596	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95055L	\N	2014-09-28 13:21:47
19521	572	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
19522	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11049P	\N	\N
19523	573	2011-10-01 00:00:00	2013-02-28 00:00:00	ANCIEN	\N	\N	\N	11062L	\N	\N
19524	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
19525	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11106F	\N	\N
19526	574	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11064N	\N	\N
19527	574	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11100Y	\N	\N
19528	574	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
19529	596	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	77043E	\N	2014-09-28 16:59:41
19530	596	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	2014-09-28 17:40:23
19703	912	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
19704	912	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	2014-09-28 18:19:47
19705	992	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	98053W	\N	\N
19706	640	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11101A	\N	\N
19708	534	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
19709	966	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	98027U	\N	\N
19710	991	2011-12-14 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11091R	\N	\N
19711	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	92020L	\N	\N
19712	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	98053W	\N	\N
19713	909	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98038X	\N	2014-09-28 17:38:26
19715	646	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	90003B	\N	\N
19716	571	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
19717	556	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	2015-03-02 10:42:04
19718	534	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
19719	851	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
19720	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
19721	922	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
19722	911	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
19724	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11036J	\N	\N
19725	991	2011-12-14 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95047L	\N	2014-09-28 17:09:16
19726	938	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
19727	938	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04091M	\N	2014-09-28 17:55:39
19728	938	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08059E	\N	2014-09-28 17:27:29
19168	646	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
19169	646	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	2014-09-29 13:43:10
19170	529	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96004D	\N	2015-02-02 16:43:40
19171	529	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	2014-09-28 17:27:35
19172	530	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98053W	\N	\N
19173	530	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	2014-09-28 18:00:58
19174	529	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
19175	529	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
19176	530	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
19177	532	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08063A	\N	2014-09-28 17:07:07
19178	646	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
19355	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07030L	\N	2014-09-28 17:03:42
19356	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	2014-09-28 13:21:47
19357	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11090Q	\N	\N
19358	574	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95055L	\N	2014-09-28 13:21:47
19359	574	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95032D	\N	2014-09-28 17:07:41
19360	574	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
19361	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	77058M	\N	2014-09-28 12:52:11
19362	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95039L	\N	\N
19363	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	2014-09-28 17:40:23
19364	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95036H	\N	2014-09-28 17:31:42
19365	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	2014-09-28 18:03:38
19531	596	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	2014-09-28 16:40:50
19532	596	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
19533	596	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	2014-09-28 16:50:17
19534	596	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11030C	\N	\N
19535	572	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11085T	\N	\N
19536	572	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
19537	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
19538	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
19539	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11064N	\N	\N
19540	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11084S	\N	\N
19541	673	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08010L	\N	\N
19714	991	2011-12-14 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08012N	\N	\N
19729	938	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
19730	938	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	01063U	\N	2014-09-29 13:41:53
19731	938	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95025E	\N	2014-09-28 17:09:16
19732	938	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11113E	\N	\N
19733	938	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	02002K	\N	\N
19734	938	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
19735	938	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95039L	\N	\N
19736	938	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01042P	\N	\N
19737	938	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08034U	\N	\N
19738	938	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08053X	\N	\N
19739	938	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:20
19740	938	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07034Q	\N	\N
19741	938	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95063L	\N	\N
19742	918	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08053X	\N	\N
19743	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
19744	851	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
19745	657	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
19746	571	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04077P	\N	\N
19747	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08017T	\N	\N
19748	851	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:20
19749	571	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
19750	963	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08055A	\N	\N
19190	646	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08010L	\N	\N
19191	646	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	2014-09-28 17:22:11
19192	646	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08015R	\N	2017-10-10 11:04:14
19193	529	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
19194	530	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08009T	\N	\N
19195	646	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
19196	646	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
19197	529	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
19198	530	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	2014-09-28 16:42:05
19199	530	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
19200	646	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08053X	\N	\N
19366	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	2014-09-28 16:40:50
19367	596	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98029W	\N	\N
19368	596	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
19369	596	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
19370	596	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	2014-09-29 13:43:10
19371	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
19372	573	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	11027H	\N	2015-02-03 14:09:39
19373	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	2014-09-28 18:03:38
19374	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	2014-09-28 16:40:50
19375	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	90003B	\N	\N
19376	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	2014-09-28 16:50:17
19542	644	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
19543	597	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
19544	597	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11061K	\N	\N
19545	597	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
19546	673	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11012A	\N	\N
19547	673	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01041N	\N	\N
19548	673	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	01063U	\N	2014-09-29 13:41:53
19549	673	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
19550	644	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04084N	\N	2014-09-28 13:40:33
19551	597	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08038Y	\N	\N
19552	597	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08011M	\N	\N
19751	571	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08053X	\N	\N
19752	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07004J	\N	\N
19754	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04047H	\N	\N
19755	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11110B	\N	\N
19756	918	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11025F	\N	\N
19760	918	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11110B	\N	\N
19758	918	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	77058M	\N	2014-09-28 12:52:11
19759	918	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
19761	934	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	95031C	\N	\N
19762	934	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
19763	571	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11069T	\N	\N
19764	992	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	2014-09-28 16:50:17
19765	918	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11042G	\N	\N
19766	918	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04038G	\N	\N
19767	992	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08033T	\N	2014-09-28 17:27:35
19768	601	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
19769	601	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	\N
19770	602	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	11027H	\N	\N
19771	934	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	2014-09-28 17:40:23
19772	599	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92018S	\N	\N
19773	615	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	00003C	\N	\N
19774	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
19775	912	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
19201	529	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
19202	530	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
19203	532	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11046L	\N	\N
19204	646	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04078Q	\N	\N
19205	529	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
19206	529	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04043D	\N	\N
19207	530	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11100Y	\N	\N
19208	534	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
19209	534	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	2014-09-28 18:03:38
19210	529	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04048J	\N	\N
19211	529	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
19377	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11035H	\N	\N
19378	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07024N	\N	\N
19379	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
19380	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11030C	\N	\N
19381	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	2014-09-28 18:19:47
19382	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	2014-09-28 13:16:32
19383	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	2014-09-28 12:56:42
19384	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95047L	\N	2014-09-28 17:09:16
19385	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
19386	574	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
19387	574	2011-10-01 00:00:00	2014-06-30 00:00:00	ANCIEN	\N	\N	\N	11022C	\N	2014-08-06 16:27:11
19553	673	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
19554	673	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08016S	\N	\N
19555	673	2011-10-01 00:00:00	2013-02-06 00:00:00	ANCIEN	\N	\N	\N	08036W	\N	\N
19556	644	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
19557	963	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11101A	\N	\N
19558	597	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	\N	2014-09-28 17:03:42
19559	597	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
19560	597	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08010L	\N	\N
19561	673	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
19562	673	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
19563	673	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08041T	\N	\N
19776	910	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	\N
19777	612	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
19778	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04034C	\N	\N
19779	992	2012-01-25 00:00:00	2012-06-16 00:00:00	ANCIEN	\N	\N	\N	04053F	\N	\N
19780	992	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
19781	992	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08021P	\N	\N
19782	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08021P	\N	\N
19783	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	\N
19784	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11080N	\N	\N
19785	992	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	\N
19786	919	2011-10-01 00:00:00	2012-06-16 00:00:00	ANCIEN	\N	\N	\N	04053F	\N	\N
19787	919	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08033T	\N	2014-09-28 17:27:35
19788	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
19789	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01022K	\N	\N
19790	912	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	2014-09-28 16:59:41
19791	913	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	06004E	\N	2014-09-28 17:03:42
19792	913	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
19793	913	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98038X	\N	2014-09-28 17:38:26
19794	992	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	92015P	\N	\N
19795	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	92015P	\N	\N
19796	907	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98038X	\N	2014-09-28 17:38:26
19797	534	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04086Q	\N	\N
19798	627	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
19799	627	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04077P	\N	\N
20082	634	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
20132	653	2013-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11097X	\N	\N
19991	909	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	06005F	\N	2014-09-28 13:32:35
20133	653	2013-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	\N	2014-09-28 17:03:42
20186	922	2013-07-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11074Q	\N	2013-08-12 17:04:33
20031	938	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11069T	\N	\N
20108	625	2013-01-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	10006L	\N	\N
20134	653	2013-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11100Y	\N	\N
20000	998	2012-10-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11097X	\N	\N
20001	998	2012-10-10 00:00:00	2014-08-26 00:00:00	ANCIEN	\N	\N	\N	11018G	\N	\N
20002	998	2012-10-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11029K	\N	\N
20003	998	2012-10-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	2014-09-28 19:03:23
20019	902	2012-10-01 00:00:00	2012-11-30 00:00:00	ANCIEN	\N	\N	\N	01044R	\N	\N
20020	902	2012-10-01 00:00:00	2012-11-30 00:00:00	ANCIEN	\N	\N	\N	08043V	\N	\N
20021	902	2012-10-01 00:00:00	2012-11-30 00:00:00	ANCIEN	\N	\N	\N	11029K	\N	\N
20022	902	2012-10-01 00:00:00	2012-11-30 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
20023	902	2012-10-01 00:00:00	2012-11-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
20024	902	2012-10-01 00:00:00	2012-11-30 00:00:00	ANCIEN	\N	\N	\N	11089X	\N	\N
20025	902	2012-10-01 00:00:00	2012-11-30 00:00:00	ANCIEN	\N	\N	\N	08031R	\N	\N
20026	902	2012-10-01 00:00:00	2012-11-30 00:00:00	ANCIEN	\N	\N	\N	12041X	\N	\N
20027	902	2012-10-01 00:00:00	2012-11-30 00:00:00	ANCIEN	\N	\N	\N	11098Y	\N	\N
20028	902	2012-10-01 00:00:00	2012-11-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
20029	902	2012-10-01 00:00:00	2012-11-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
20030	902	2012-10-01 00:00:00	2012-11-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
20136	629	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96004D	2013-03-08 17:50:40	2015-02-02 16:56:04
19967	582	2012-08-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
19968	605	2012-08-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11029K	\N	2014-10-14 16:12:12
19969	634	2012-08-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	2014-10-14 16:36:00
19970	598	2012-08-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01057W	\N	2014-10-14 16:35:17
20052	851	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11100Y	\N	\N
20055	582	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11082Q	\N	\N
20056	634	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08048B	\N	\N
19988	626	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	12041X	\N	2014-10-14 16:36:53
20130	626	2013-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
20131	626	2013-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96003C	\N	\N
19941	642	2012-06-28 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	12035A	\N	\N
19942	621	2012-06-28 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	12035A	\N	\N
19943	651	2012-06-28 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	12035A	\N	\N
19995	998	2012-10-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11061K	\N	\N
19996	998	2012-10-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01011G	\N	\N
19997	998	2012-10-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11104D	\N	\N
19998	998	2012-10-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11094U	\N	\N
19999	998	2012-10-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08071A	\N	2014-09-29 09:08:32
19945	997	2012-07-13 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11099A	\N	\N
20048	998	2012-10-10 00:00:00	2012-10-10 00:00:00	ANCIEN	\N	\N	\N	04046G	\N	\N
20049	998	2012-10-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11069T	\N	\N
20035	998	2012-10-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11035H	\N	\N
19957	992	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	2014-09-28 16:50:17
19959	661	2012-08-01 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	12039E	\N	\N
19960	576	2012-08-01 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	12039E	\N	\N
19961	590	2012-08-01 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	12039E	\N	\N
19962	595	2012-08-01 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	12039E	\N	\N
19963	622	2012-08-01 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	12039E	\N	\N
19964	598	2012-08-01 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	12039E	\N	\N
19965	601	2012-08-01 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	12039E	\N	\N
19946	990	2011-12-14 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	2014-09-28 17:27:35
20036	998	2012-10-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01044R	\N	\N
20177	912	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	12042Y	2013-05-07 14:03:10	\N
20178	627	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	2013-05-07 14:05:12	\N
19949	990	2011-12-14 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	2014-09-28 16:42:05
19989	966	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
20050	998	2012-10-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11025F	\N	\N
20051	998	2012-10-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
20172	642	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	13001T	2013-04-04 10:07:03	2014-09-28 17:58:04
20173	590	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	13001T	2013-04-04 10:14:32	2014-09-28 17:58:04
20174	622	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	13001T	2013-04-04 10:39:10	2014-09-28 17:58:04
19990	907	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	06005F	\N	2014-09-28 13:32:35
19950	990	2011-12-14 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11098Y	\N	\N
19951	990	2011-12-14 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08031R	\N	\N
19952	990	2011-12-14 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08043V	\N	\N
20085	933	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
19954	990	2011-12-14 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01044R	\N	\N
19955	904	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11015D	\N	\N
19981	634	2012-08-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	2014-10-14 16:27:39
20084	933	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
20086	933	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89013M	\N	\N
19956	990	2011-12-14 00:00:00	2014-01-01 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
19958	997	2012-07-13 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11095V	\N	\N
20012	998	2012-10-10 00:00:00	2014-02-13 00:00:00	ANCIEN	\N	\N	\N	08046Y	\N	\N
20014	582	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11085T	\N	\N
20097	933	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08031R	\N	\N
20098	933	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08033T	\N	\N
20099	933	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
20124	626	2013-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11029K	\N	\N
19947	990	2011-12-14 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11029K	\N	\N
20103	933	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11054L	\N	\N
20101	933	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
20102	933	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
20104	933	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11046L	\N	\N
20105	933	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11097X	\N	\N
20106	933	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08071A	\N	\N
20107	933	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
20171	629	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95005A	2013-04-02 11:00:16	2014-09-28 17:40:23
20011	998	2012-10-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98037W	\N	2014-09-28 14:31:42
20013	998	2012-10-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	\N
20015	998	2012-10-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	09012S	\N	2014-09-28 13:09:05
20040	998	2012-10-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08038Y	\N	\N
20057	990	2012-02-14 00:00:00	2012-12-04 00:00:00	ANCIEN	\N	\N	\N	11089X	\N	\N
20058	990	2012-02-14 00:00:00	2012-11-28 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
20064	912	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08012N	\N	\N
20185	609	2013-06-01 00:00:00	2014-05-11 00:00:00	ANCIEN	\N	\N	\N	11045K	2013-06-14 09:50:50	\N
20065	919	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11101A	\N	\N
20066	919	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	2014-09-28 17:40:23
20067	919	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11099A	\N	\N
20068	919	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
20069	919	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08026U	\N	2014-09-28 17:52:18
19993	990	2011-12-14 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	12041X	\N	\N
20004	534	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	10015M	\N	2014-10-14 16:37:26
20005	613	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
20006	613	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	2014-09-28 18:03:38
20007	613	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04061F	\N	\N
20008	613	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11100Y	\N	\N
20009	586	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08024S	\N	\N
20010	616	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11069T	\N	\N
20087	933	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
20088	933	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08060W	\N	\N
20089	933	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08058D	\N	\N
20090	933	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	\N	\N
20091	933	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11053K	\N	\N
20092	933	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08028W	\N	\N
20093	933	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
20061	911	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08012N	\N	\N
20016	582	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11064N	\N	\N
20017	998	2012-10-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11110B	\N	\N
20071	992	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08012N	\N	\N
20072	992	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08031R	\N	\N
20073	992	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
20074	992	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11014C	\N	\N
20076	992	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	98022P	\N	\N
19944	990	2011-12-14 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
19985	910	2011-10-01 00:00:00	2014-05-01 00:00:00	ANCIEN	\N	\N	\N	12038D	\N	\N
20037	998	2012-10-10 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	12035A	\N	\N
20041	998	2012-10-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11059R	\N	\N
20042	998	2012-10-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
20043	998	2012-10-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04046G	\N	2014-09-28 17:07:41
20044	998	2012-10-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	\N
20045	998	2012-10-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11055M	\N	\N
20046	998	2012-10-10 00:00:00	2013-06-27 00:00:00	ANCIEN	\N	\N	\N	95045J	\N	\N
20047	998	2012-10-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
19966	906	2011-10-01 00:00:00	2014-05-02 00:00:00	ANCIEN	\N	\N	\N	12038D	\N	2014-08-06 16:33:35
19983	948	2011-10-01 00:00:00	2014-05-02 00:00:00	ANCIEN	\N	\N	\N	12038D	\N	2014-08-06 16:34:54
19984	918	2011-10-01 00:00:00	2014-04-30 00:00:00	ANCIEN	\N	\N	\N	12038D	\N	\N
20032	998	2012-10-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11091R	\N	\N
20033	998	2012-10-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08050U	\N	2014-09-28 12:44:31
20038	634	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01044R	\N	\N
20039	634	2012-10-01 00:00:00	2013-06-27 00:00:00	ANCIEN	\N	\N	\N	95045J	\N	\N
20062	604	2012-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11069T	\N	\N
20063	990	2012-10-01 00:00:00	2012-12-05 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
20138	908	2013-02-13 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	13001T	\N	2014-09-28 17:58:04
19971	648	2012-08-01 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	12040W	\N	\N
19972	646	2012-08-01 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	12040W	\N	\N
19973	572	2012-08-01 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	12040W	\N	\N
19974	573	2012-08-01 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	12040W	\N	\N
19975	574	2012-08-01 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	12040W	\N	\N
19976	609	2012-08-01 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	12040W	\N	\N
19977	584	2012-08-01 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	12040W	\N	\N
19978	588	2012-08-01 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	12040W	\N	\N
19979	624	2012-08-01 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	12040W	\N	\N
20034	998	2012-10-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
20077	992	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11081P	\N	\N
20175	626	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01044R	2013-04-10 10:18:04	\N
19980	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11081P	\N	\N
20060	998	2012-10-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98038X	\N	2014-09-28 17:38:26
20100	933	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08047A	\N	\N
19982	938	2012-06-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
19986	597	2012-08-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07004J	\N	2014-10-14 16:34:20
19987	579	2012-08-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04044E	\N	2014-10-14 16:38:42
20129	626	2013-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92018S	\N	\N
20111	948	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	12042Y	\N	\N
20140	573	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	13002U	2013-03-26 11:35:29	\N
20141	599	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	13002U	2013-03-26 11:37:10	\N
20142	661	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08047A	2013-03-26 11:39:18	\N
20143	653	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04044E	2013-03-26 11:41:53	\N
20144	922	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	13001T	2013-03-26 11:44:17	2014-09-28 17:58:04
20145	625	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	12042Y	2013-03-26 11:50:48	\N
20146	604	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	12042Y	2013-03-26 11:52:20	\N
20147	600	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	12042Y	2013-03-26 11:53:52	\N
20148	629	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	2013-03-26 11:55:14	2014-09-28 17:03:42
20149	629	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	2013-03-26 11:55:29	2014-09-28 18:00:58
20150	629	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95036H	2013-03-26 11:55:44	2014-09-28 17:31:42
20151	629	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	77058M	2013-03-26 11:55:54	2014-09-28 12:52:11
20152	629	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04069P	2013-03-26 11:56:57	2014-09-28 17:31:41
20153	629	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04080J	2013-03-26 11:57:13	\N
20154	629	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04035D	2013-03-26 11:57:47	\N
20155	629	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	77043E	2013-03-26 11:58:34	2014-09-28 16:59:41
20094	933	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
20095	933	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11096W	\N	\N
20125	626	2013-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11033F	\N	\N
20126	626	2013-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
20127	626	2013-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11055M	\N	\N
20075	992	2012-01-25 00:00:00	2014-05-11 00:00:00	ANCIEN	\N	\N	\N	11045K	\N	\N
20096	933	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
20165	629	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04083M	2013-03-27 16:04:43	2014-09-28 16:40:50
20166	641	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	13001T	2013-03-29 12:17:23	2014-09-28 17:58:04
20204	625	2013-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11065P	2013-10-15 09:53:51	\N
20167	595	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	13001T	2013-03-29 12:19:08	2014-09-28 17:58:04
20168	673	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	13001T	2013-03-29 12:19:54	2014-09-28 17:58:04
20169	608	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	13001T	2013-03-29 12:21:14	2014-09-28 17:58:05
20170	629	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	13001T	2013-03-29 12:21:47	2014-09-28 17:58:05
20053	998	2012-10-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08045X	\N	2014-09-28 17:00:59
20054	998	2012-10-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11077T	\N	\N
20112	634	2012-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	2014-05-16 10:43:57
20113	634	2012-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11101A	\N	\N
20114	634	2012-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	2014-09-28 12:56:42
20115	919	2013-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11081P	\N	\N
20116	919	2013-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11042G	\N	\N
20117	919	2013-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98022P	\N	\N
20118	919	2013-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	10003H	\N	2014-09-28 17:38:26
20119	919	2013-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08031R	\N	\N
20120	919	2013-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
20121	919	2013-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08012N	\N	\N
20122	919	2013-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11014C	\N	\N
20123	919	2013-02-01 00:00:00	2014-05-11 00:00:00	ANCIEN	\N	\N	\N	11045K	\N	\N
19994	934	2011-10-01 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	12039E	\N	\N
20078	992	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	10003H	\N	2014-09-28 17:38:26
20079	992	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
20080	992	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11042G	\N	\N
20081	992	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	\N
20156	629	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08044W	2013-03-26 11:58:41	\N
20157	629	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	05008E	2013-03-26 11:59:25	\N
20158	629	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	2013-03-26 11:59:44	\N
20159	629	2013-03-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	98019U	2013-03-26 12:00:17	2014-09-29 13:43:10
20160	629	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11048N	2013-03-26 12:00:43	\N
20161	629	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08039A	2013-03-26 12:01:05	\N
20162	629	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95025E	2013-03-26 12:01:32	2014-09-28 17:09:16
20163	629	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	10015M	2013-03-26 12:01:51	\N
20164	573	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11112D	2013-03-26 12:13:09	\N
20180	998	2012-10-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
20018	998	2012-10-10 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08057C	\N	2014-09-28 14:31:42
20070	998	2012-10-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11109J	\N	\N
19992	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
20059	998	2012-10-10 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08055A	\N	\N
20137	918	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	13001T	\N	2014-09-28 17:58:05
20179	584	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04097T	2013-05-15 10:44:33	\N
20109	911	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	12042Y	\N	\N
20182	632	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11069T	2013-06-11 17:52:04	\N
20201	612	2013-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	2013-08-14 09:24:01	2014-09-28 16:50:17
20191	584	2013-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	13001T	2013-08-12 16:45:51	2014-09-28 17:58:05
20192	609	2013-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	2013-08-12 16:57:19	2013-08-12 16:57:36
20193	646	2013-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92020L	2013-08-12 16:59:24	\N
20195	604	2013-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	13003V	2013-08-12 17:01:58	2014-09-28 17:14:21
20196	580	2013-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	13003V	2013-08-12 17:02:47	2014-09-28 17:14:21
20200	556	2013-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08058D	2013-08-12 17:17:06	\N
20198	978	2013-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04067M	2013-08-12 17:07:14	\N
20199	651	2013-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	2013-08-12 17:08:02	\N
20203	629	2013-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	13003V	2013-09-18 14:55:40	2014-09-28 17:14:21
17857	591	2011-10-01 00:00:00	2013-12-31 00:00:00	ANCIEN	\N	\N	\N	95003X	\N	\N
17858	591	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11012A	\N	\N
17859	591	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
17860	591	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01007L	\N	\N
17861	591	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
17862	591	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08060W	\N	\N
17863	591	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08063A	\N	2014-09-28 17:07:07
17864	591	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08037X	\N	2014-09-28 17:34:16
17865	591	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08048B	\N	\N
17866	591	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08053X	\N	\N
17867	591	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08050U	\N	2014-09-28 12:44:31
17473	581	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04034C	\N	\N
17474	581	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
17475	581	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	2014-09-28 18:00:58
17476	581	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08010L	\N	\N
17477	581	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
17478	581	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
17479	581	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04086Q	\N	\N
17480	581	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95063L	\N	\N
17481	581	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11044J	\N	\N
17482	581	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
17483	581	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
17228	992	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04038G	\N	\N
17229	992	2012-01-25 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	11027H	\N	\N
17230	992	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	80013X	\N	\N
17256	992	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11069T	\N	\N
17262	992	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
17263	992	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98037W	\N	2014-09-28 14:31:42
17264	992	2012-01-25 00:00:00	2014-12-18 00:00:00	ANCIEN	\N	\N	\N	01062T	\N	2014-12-18 16:15:04
17274	912	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08045X	\N	2014-09-28 17:00:59
17514	583	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
17515	583	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89029V	\N	\N
17516	583	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08014Q	\N	\N
17517	583	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	\N	2014-09-28 17:03:42
17518	583	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
17519	583	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08017T	\N	\N
17520	583	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08019V	\N	\N
17686	979	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01016M	\N	\N
17687	979	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11014C	\N	\N
17688	979	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	\N
17689	979	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
17690	979	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11034G	\N	\N
17691	979	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
17692	979	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
17693	979	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	2014-09-28 16:50:17
19806	965	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08017T	\N	\N
17694	979	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08011M	\N	\N
17695	979	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	\N	2014-09-28 17:03:42
17696	979	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
17868	591	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	08064B	\N	\N
17869	591	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	2014-09-28 19:03:23
18177	605	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	2014-09-28 19:03:23
18178	605	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08055A	\N	\N
18179	603	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
18180	604	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04065K	\N	2014-09-28 17:31:42
18181	604	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11044J	\N	\N
18182	604	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04061F	\N	\N
17239	992	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	2014-09-28 16:42:05
17242	992	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11107G	\N	\N
17243	992	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
17244	992	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
17245	992	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08016S	\N	\N
17246	992	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	95037J	\N	\N
18261	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11080N	\N	\N
18262	609	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11100Y	\N	\N
18263	610	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04051D	\N	2014-09-28 17:07:41
18264	610	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04055H	\N	\N
18265	610	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
18266	610	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95015C	\N	\N
18267	610	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	2014-09-28 17:40:23
18268	610	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95005A	\N	2014-09-28 17:40:23
18445	620	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
18446	621	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11014C	\N	\N
18447	621	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	\N
18448	621	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
18449	622	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08043V	\N	\N
18450	623	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
18451	623	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
18452	620	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:21
18453	621	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11061K	\N	\N
18454	621	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04038G	\N	\N
18455	621	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04042C	\N	\N
18011	600	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:21
18012	600	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11059R	\N	\N
18013	600	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
18014	600	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
18015	600	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04041B	\N	\N
18016	600	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
18017	600	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98050T	\N	\N
18018	600	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	2014-09-28 18:00:58
34485	1010	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	17737W	\N	\N
18019	600	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08043V	\N	\N
18020	600	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08024S	\N	\N
18021	600	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08039A	\N	\N
17000	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01016M	\N	\N
18183	604	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04069P	\N	2014-09-28 17:31:41
18184	604	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
18185	605	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
18186	605	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11064N	\N	\N
18187	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95055L	\N	2014-09-28 13:21:47
18188	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	77058M	\N	2014-09-28 12:52:11
18189	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
18160	604	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11098Y	\N	\N
18161	605	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04083M	\N	2014-09-28 16:40:50
18162	605	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04091M	\N	2014-09-28 17:55:39
18163	605	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
18164	605	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	2014-09-28 17:40:23
17061	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
17062	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
17064	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
17065	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
17067	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
17068	909	2011-10-01 00:00:00	2014-05-02 00:00:00	ANCIEN	\N	\N	\N	08070Y	\N	\N
17069	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04044E	\N	\N
17070	909	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	06004E	\N	2014-09-28 17:03:42
17071	909	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	2014-09-28 18:03:38
17072	909	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	2014-09-28 16:42:05
17075	957	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
17078	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08015R	\N	\N
17081	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01013J	\N	\N
17083	911	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
17111	904	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01025N	\N	\N
17112	904	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01007L	\N	\N
17114	904	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
17115	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08038Y	\N	\N
17117	904	2011-10-01 00:00:00	2012-06-16 00:00:00	ANCIEN	\N	\N	\N	11003M	\N	\N
17118	904	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
17120	919	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98038X	\N	2014-09-28 17:38:26
17121	928	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
18412	618	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08045X	\N	2014-09-28 17:00:59
18413	618	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	04090L	\N	\N
18414	615	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	02053W	\N	2014-09-28 12:32:23
18415	615	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08053X	\N	\N
18416	616	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
18417	616	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
18418	617	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	2014-09-28 19:03:23
18419	617	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04080J	\N	\N
18420	617	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04084N	\N	2014-09-28 13:40:33
18421	618	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95063L	\N	\N
18422	618	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08009T	\N	\N
19036	657	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	2014-09-28 12:56:42
19037	657	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95047L	\N	2014-09-28 17:09:16
19038	657	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:21
19039	657	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07024N	\N	\N
19040	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98022P	\N	\N
19041	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01025N	\N	\N
19042	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	\N
19043	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98036V	\N	2014-09-28 17:15:42
19044	651	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
19045	651	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11055M	\N	\N
19046	651	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11069T	\N	\N
18599	626	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11063M	\N	\N
18600	626	2011-10-01 00:00:00	2014-05-11 00:00:00	ANCIEN	\N	\N	\N	11045K	\N	\N
18601	626	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
18602	623	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	2014-09-28 12:09:44
18603	623	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
18604	623	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
18605	624	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	2014-09-28 19:03:23
18606	624	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04078Q	\N	\N
18607	624	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04056J	\N	\N
18572	623	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04034C	\N	\N
18573	623	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
18574	623	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
18575	621	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95055L	\N	2014-09-28 13:21:47
18576	621	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95039L	\N	\N
18741	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
18742	632	2011-10-01 00:00:00	2012-09-19 00:00:00	ANCIEN	\N	\N	\N	95011X	\N	\N
18743	632	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11035H	\N	\N
18744	640	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
18745	641	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
18746	641	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98022P	\N	\N
18747	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	2014-09-28 16:50:17
18748	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
18749	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	2014-09-28 18:00:58
18750	632	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	2014-09-28 13:19:48
18751	632	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
18917	663	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	01063U	\N	2014-09-29 13:41:53
18918	663	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01007L	\N	\N
18919	643	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
18920	659	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
18921	661	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
18922	663	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08053X	\N	\N
18923	643	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	2014-09-28 16:42:05
18924	659	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04084N	\N	2014-09-28 13:40:33
18925	661	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	08064B	\N	\N
18926	661	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04080J	\N	\N
18927	663	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08071A	\N	2014-09-29 09:08:33
16581	911	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	2014-09-28 18:19:47
16909	908	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04083M	\N	2014-09-28 16:40:50
16910	908	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04033B	\N	\N
16966	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	98021N	\N	\N
16967	919	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	2014-09-28 19:03:23
16968	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08060W	\N	\N
16969	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01015L	\N	\N
16970	919	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
16973	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01025N	\N	\N
16978	919	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04069P	\N	2014-09-28 17:31:41
16979	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
16981	919	2011-10-01 00:00:00	2014-04-24 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
16986	918	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
16987	910	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11069T	\N	\N
16988	957	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01016M	\N	\N
16989	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11096W	\N	\N
16990	907	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95047L	\N	2014-09-28 17:09:16
17012	966	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01044R	\N	\N
17013	966	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08043V	\N	\N
17014	966	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11053K	\N	\N
17015	966	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
17016	966	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	2014-09-28 16:59:41
17017	966	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08022Q	\N	\N
18577	621	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95005A	\N	2014-09-28 17:40:23
18578	625	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08065C	\N	\N
18579	626	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	10006L	\N	\N
18580	626	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	\N
18581	626	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
18582	626	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
18583	625	2011-10-01 00:00:00	2012-06-16 00:00:00	ANCIEN	\N	\N	\N	11003M	\N	\N
18584	625	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
17870	591	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
17871	591	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
17872	591	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	\N
17873	591	2011-10-01 00:00:00	2014-05-11 00:00:00	ANCIEN	\N	\N	\N	11045K	\N	\N
17874	591	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11077T	\N	\N
17875	591	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11099A	\N	\N
17876	591	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11098Y	\N	\N
17877	592	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11030C	\N	\N
17878	592	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95047L	\N	2014-09-28 17:09:16
17484	581	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11098Y	\N	\N
17485	582	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
17486	582	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
17487	582	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
17488	582	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
17489	582	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
17490	582	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	2014-09-28 18:00:58
17491	582	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	2014-10-28 17:06:36
19807	993	2012-02-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08040S	\N	2014-09-28 17:52:18
17492	582	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04080J	\N	\N
17493	582	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
17494	582	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
17521	583	2011-10-01 00:00:00	2013-12-31 00:00:00	ANCIEN	\N	\N	\N	08023R	\N	\N
17522	583	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89013M	\N	2014-09-28 17:05:42
17523	583	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01034P	\N	\N
17524	583	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01062T	\N	\N
17525	583	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
17526	583	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01041N	\N	\N
17527	583	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	01063U	\N	2014-09-29 13:41:53
17528	583	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01064V	\N	2014-09-28 17:12:41
17529	583	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
17530	583	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	02002K	\N	\N
17531	583	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
17697	979	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
17698	979	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08031R	\N	\N
17699	979	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89013M	\N	2014-09-28 17:05:42
17700	979	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01044R	\N	\N
17701	979	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01058X	\N	\N
17702	979	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	2014-09-28 12:09:44
17703	979	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08065C	\N	\N
17704	979	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
17705	979	2011-10-01 00:00:00	2013-02-06 00:00:00	ANCIEN	\N	\N	\N	08036W	\N	\N
17706	979	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	2014-09-28 19:03:23
17707	979	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	2014-09-28 16:42:05
17333	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
17334	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08024S	\N	\N
17335	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08031R	\N	\N
17336	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	03001N	\N	2014-09-28 13:40:33
18190	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
18191	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	2014-09-28 13:16:32
18192	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:21
18269	610	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
18270	610	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
18271	610	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	\N
18272	610	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01015L	\N	\N
18273	610	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
18274	610	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
18275	610	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04044E	\N	\N
18276	610	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
18277	610	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07003H	\N	2014-09-28 12:21:28
18278	610	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
18279	610	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	2014-09-28 18:00:58
18456	621	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
18457	621	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	2014-09-28 16:50:17
18458	622	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08017T	\N	\N
18459	622	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08012N	\N	\N
18460	622	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
18461	619	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	2014-09-28 18:19:47
18462	619	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	2014-09-28 13:16:32
18463	619	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	2014-09-28 12:56:42
18464	620	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98027U	\N	\N
18465	620	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	2014-09-28 13:19:48
18466	620	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
18022	600	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	10003H	\N	2014-09-28 17:38:26
18023	600	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08065C	\N	\N
18024	600	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
18025	600	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
18026	600	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
18027	600	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95063L	\N	\N
18028	600	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
18029	600	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04069P	\N	2014-09-28 17:31:41
18030	600	2011-10-01 00:00:00	2013-02-28 00:00:00	ANCIEN	\N	\N	\N	11062L	\N	\N
18031	600	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11063M	\N	\N
18032	600	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	2017-10-10 09:45:39
17009	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08043V	\N	\N
18193	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96004D	\N	2015-02-02 16:43:25
18194	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
18195	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11048N	\N	\N
18196	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
18197	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98021N	\N	\N
18198	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11036J	\N	\N
18199	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
18200	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
18201	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04038G	\N	\N
18202	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04042C	\N	\N
18608	624	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04065K	\N	2014-09-28 17:31:42
18609	625	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11074Q	\N	\N
18774	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01062T	\N	\N
18775	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
18776	632	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
18777	632	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04046G	\N	2014-09-28 17:07:41
18778	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
18779	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08060W	\N	\N
34486	919	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	19954N	\N	\N
18780	632	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01013J	\N	\N
18781	632	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04034C	\N	\N
18782	632	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
18783	640	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98038X	\N	2014-09-28 17:38:26
18784	641	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
17215	992	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08040S	\N	2014-09-28 17:52:18
17086	965	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04059M	\N	\N
17216	992	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
17217	992	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	2014-09-28 19:03:04
17218	992	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08055A	\N	\N
18950	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	\N	\N
18951	651	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	2014-09-28 13:21:47
18952	628	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	2014-09-28 17:27:35
18953	657	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
18954	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
18955	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01047U	\N	\N
18956	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
18957	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
19047	657	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98023Q	\N	\N
19048	657	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92018S	\N	\N
19049	657	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
19050	657	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	2014-09-28 17:27:35
19051	657	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
19052	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01015L	\N	\N
19053	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
19054	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04033B	\N	\N
19055	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
19056	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04042C	\N	\N
19057	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04044E	\N	\N
18610	625	2011-10-01 00:00:00	2013-02-28 00:00:00	ANCIEN	\N	\N	\N	11062L	\N	\N
18611	626	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11100Y	\N	\N
18612	626	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11069T	\N	\N
18613	624	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	2014-09-28 16:42:05
18614	624	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
18615	624	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04077P	\N	\N
18616	624	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11033F	\N	\N
18617	625	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
18618	625	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
18619	625	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11064N	\N	\N
18620	626	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11089X	\N	\N
18785	641	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
18585	626	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04091M	\N	2014-09-28 17:55:39
18586	627	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
18587	624	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	2014-09-28 12:09:44
18752	632	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92018S	\N	\N
18753	632	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
18754	632	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	2014-09-28 17:27:35
18755	632	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
18756	640	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:21
18757	641	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11032E	\N	\N
18758	641	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
18759	641	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04041B	\N	\N
18760	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
18761	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
18762	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08019V	\N	\N
18928	643	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08050U	\N	2014-09-28 12:44:31
18929	659	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04069P	\N	2014-09-28 17:31:41
18930	661	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08009T	\N	\N
18931	661	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	2014-09-28 16:59:41
18932	661	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04055H	\N	\N
18933	663	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04083M	\N	2014-09-28 16:40:50
18934	643	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
18935	643	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	\N
18936	659	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
18937	661	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04077P	\N	\N
18938	663	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04061F	\N	\N
16921	922	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04033B	\N	\N
16922	922	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	95063L	\N	\N
16931	913	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11095V	\N	\N
16947	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	92015P	\N	\N
17018	966	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	02002K	\N	\N
17019	966	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	2014-09-28 13:16:32
17020	966	2011-10-01 00:00:00	2012-12-04 00:00:00	ANCIEN	\N	\N	\N	11089X	\N	\N
17021	966	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11064N	\N	\N
17022	966	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11099A	\N	\N
17023	966	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11098Y	\N	\N
17026	966	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
17027	906	2011-10-01 00:00:00	2013-09-30 00:00:00	ANCIEN	\N	\N	\N	07025P	\N	\N
17030	965	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11114F	\N	\N
17108	904	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08011M	\N	\N
17109	904	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	2014-09-28 16:42:05
17113	928	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	\N
17157	908	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08014Q	\N	\N
17158	934	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11039M	\N	\N
17161	904	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11106F	\N	\N
17162	904	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
17174	904	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
17175	948	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08061X	\N	\N
17178	934	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
18588	624	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
18589	624	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01028R	\N	\N
18590	624	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
18591	625	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	2014-09-28 19:03:23
18592	625	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95063L	\N	\N
18593	626	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
18594	624	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	\N
18595	624	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08050U	\N	2014-09-28 12:44:31
18596	625	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04083M	\N	2014-09-28 16:40:50
18597	625	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11043H	\N	\N
18598	626	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11074Q	\N	\N
18763	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08012N	\N	\N
18764	642	2011-10-01 00:00:00	2013-12-31 00:00:00	ANCIEN	\N	\N	\N	08023R	\N	\N
18765	632	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01014K	\N	\N
18766	632	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01011G	\N	\N
18767	640	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
18768	641	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	2014-09-28 16:50:17
18769	641	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89029V	\N	\N
18770	641	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	2014-09-28 18:00:58
18771	641	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08040S	\N	2014-09-28 17:52:18
18772	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08033T	\N	2014-09-28 17:27:35
18773	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11012A	\N	\N
18939	663	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
18940	643	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11113E	\N	\N
18941	643	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11111C	\N	\N
18942	659	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
18943	628	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	2014-09-28 12:56:42
18944	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89029V	\N	\N
18945	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08034U	\N	\N
18946	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08011M	\N	\N
18947	628	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
18948	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	2014-09-28 17:22:11
18949	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08015R	\N	\N
16697	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
16972	919	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	2014-09-28 16:59:41
16974	919	2011-10-01 00:00:00	2012-05-31 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
16952	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08038Y	\N	\N
17048	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08058D	\N	\N
17066	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08021P	\N	\N
17074	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
17182	908	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11049P	\N	\N
17183	957	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11055M	\N	\N
17207	991	2011-12-14 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:21
17208	991	2011-12-14 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
17209	991	2011-12-14 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11105E	\N	\N
17221	992	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08050U	\N	2014-09-28 12:44:31
17222	992	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	\N	2014-09-28 17:03:42
19032	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	2014-09-28 17:27:35
19033	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98021N	\N	\N
19034	851	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08050U	\N	2014-09-28 12:44:31
19035	651	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11109J	\N	\N
19800	912	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08050U	\N	2014-09-28 12:44:31
19801	963	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11095V	\N	\N
19802	963	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	80013X	\N	\N
19803	963	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	2014-09-28 19:03:23
19804	640	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	10006L	\N	\N
19805	657	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08053X	\N	\N
19808	993	2012-02-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08050U	\N	2014-09-28 12:44:31
19809	993	2012-02-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	2014-09-28 13:19:48
19810	993	2012-02-22 00:00:00	2014-04-24 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
19811	993	2012-02-22 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08016S	\N	\N
19812	993	2012-02-22 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04041B	\N	\N
19813	993	2012-02-22 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08053X	\N	\N
19814	993	2012-02-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:21
19815	993	2012-02-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	2014-09-28 16:50:17
19816	993	2012-02-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98037W	\N	2014-09-28 14:31:42
19817	993	2012-02-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	2014-09-28 18:03:38
19818	948	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95047L	\N	2014-09-28 17:09:16
19819	912	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98038X	\N	2014-09-28 17:38:26
19821	911	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98038X	\N	2014-09-28 17:38:26
19822	615	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11089X	\N	\N
19823	615	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
19824	591	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08054Y	\N	2014-09-28 12:39:09
19223	978	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11112D	\N	\N
19224	978	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11094U	\N	\N
19225	572	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
19226	572	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07030L	\N	2014-09-28 17:03:42
19227	556	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
19228	556	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
19229	571	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
19230	978	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
19231	978	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98023Q	\N	\N
19232	978	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
19233	572	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	11027H	\N	2015-02-03 14:09:39
19388	574	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98023Q	\N	\N
19389	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11018G	\N	\N
19390	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
19391	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
19392	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	2014-09-28 17:27:35
19393	595	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	2014-09-29 13:43:10
19394	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98022P	\N	\N
19395	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01014K	\N	\N
19396	572	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
19397	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98027U	\N	\N
19398	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
19564	596	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
19565	596	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
19566	596	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04042C	\N	\N
19567	596	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	2014-09-28 18:00:58
19568	597	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
19569	597	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01047U	\N	\N
19570	597	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
19571	597	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01007L	\N	\N
19572	673	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04080J	\N	\N
19573	644	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
34487	1005	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	19954N	\N	\N
19574	596	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
19825	627	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
19826	627	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04051D	\N	2014-09-28 17:07:41
19827	918	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	92020L	\N	\N
19828	906	2011-10-01 00:00:00	2014-05-11 00:00:00	ANCIEN	\N	\N	\N	11045K	\N	\N
19829	992	2012-01-25 00:00:00	2014-04-24 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
19831	963	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08021P	\N	\N
19832	963	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11105E	\N	\N
19833	615	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08055A	\N	\N
19834	586	2011-10-01 00:00:00	2014-05-11 00:00:00	ANCIEN	\N	\N	\N	11045K	\N	\N
19835	851	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
19836	532	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
19837	532	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	2014-10-28 17:04:46
19838	992	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08059E	\N	2014-09-28 17:27:29
19839	993	2012-02-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	2014-09-28 16:50:17
19840	993	2012-02-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
19841	992	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
19842	904	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
19843	993	2012-02-22 00:00:00	2014-08-26 00:00:00	ANCIEN	\N	\N	\N	11018G	\N	\N
19844	613	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95063L	\N	\N
19845	612	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
19846	532	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	\N
19847	532	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:21
19212	534	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	2014-09-28 18:19:47
19213	534	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	2014-09-28 12:56:42
19214	534	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:21
19215	534	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
19216	534	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
19217	646	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
19218	571	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
19219	978	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
19220	978	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:21
19221	978	2011-10-01 00:00:00	2014-04-24 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
19222	978	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07024N	\N	\N
19399	574	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
19400	574	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
19401	574	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
19402	574	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	2014-09-29 13:43:10
19403	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	99004R	\N	\N
19404	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
19405	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11032E	\N	\N
19406	572	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
19407	572	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	2014-09-29 13:43:10
19408	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	2014-09-28 17:27:35
19409	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
19575	597	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
19576	597	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
19577	597	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08067E	\N	2014-09-28 17:22:11
19578	597	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	02053W	\N	2014-09-28 12:32:23
19579	597	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08059E	\N	2014-09-28 17:27:29
16936	957	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11095V	\N	\N
19580	596	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08011M	\N	\N
19581	597	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08052W	\N	\N
19582	673	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
19583	596	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	2014-09-28 12:09:44
19584	596	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01028R	\N	\N
19585	596	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
19848	913	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11048N	\N	\N
19849	912	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	98021N	\N	\N
19850	957	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08028W	\N	\N
19851	904	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	2014-09-28 17:27:35
19852	851	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11046L	\N	\N
19853	532	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92020L	\N	\N
19854	911	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11100Y	\N	\N
19855	993	2012-02-22 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08057C	\N	2014-09-28 14:31:42
19856	912	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11100Y	\N	\N
19857	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	90003B	\N	\N
19858	627	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
19859	577	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	01063U	\N	2014-09-29 13:41:53
19860	634	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
19861	963	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11110B	\N	\N
19862	908	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08045X	\N	2014-09-28 17:00:59
19863	948	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11099A	\N	\N
19864	918	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08012N	\N	\N
19865	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	98023Q	\N	\N
19866	532	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11085T	\N	\N
19869	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
19870	919	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08059E	\N	2014-09-28 17:27:29
19871	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04074L	\N	\N
19872	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11113E	\N	\N
19234	572	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	2014-09-28 18:03:38
19235	572	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
19236	556	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
19237	556	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
19238	556	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01014K	\N	\N
19239	571	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
19240	978	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	2014-09-29 13:43:10
19241	978	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11036J	\N	\N
19242	978	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
19243	572	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	2014-09-28 18:19:47
19244	572	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	2014-09-28 12:56:42
19410	573	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	2014-09-29 13:43:10
19411	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01014K	\N	\N
19412	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01016M	\N	\N
19413	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01022K	\N	\N
19414	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11039M	\N	\N
19415	574	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
19416	574	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01013J	\N	\N
19417	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04034C	\N	\N
19418	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
19419	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
19420	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04041B	\N	\N
16937	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11095V	\N	\N
19586	596	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08025T	\N	\N
19587	596	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	02053W	\N	2014-09-28 12:32:23
19588	597	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04084N	\N	2014-09-28 13:40:33
19589	597	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04086Q	\N	\N
19590	597	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04091M	\N	2014-09-28 17:55:39
19591	963	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:21
19592	596	2011-10-01 00:00:00	2012-06-16 00:00:00	ANCIEN	\N	\N	\N	09010Q	\N	\N
19593	596	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
19594	597	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04066L	\N	\N
19595	644	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
19596	963	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11018G	\N	\N
19873	529	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
19874	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11094U	\N	\N
19875	963	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04034C	\N	\N
19876	938	2011-10-01 00:00:00	2011-10-01 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	\N
19877	634	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
19878	938	2011-10-01 00:00:00	2011-10-01 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
19879	934	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	04090L	\N	\N
19880	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08050U	\N	2014-09-28 12:44:31
19881	582	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08050U	\N	2014-09-28 12:44:31
19882	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08031R	\N	\N
19883	919	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	\N
19884	634	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11090Q	\N	\N
19885	612	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
19886	661	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
19887	608	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
19888	624	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
19889	578	2012-06-28 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	12035A	\N	\N
19890	934	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
19891	909	2011-10-01 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	12035A	\N	\N
19892	909	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08033T	\N	2014-09-28 17:27:35
19893	625	2012-06-28 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	12035A	\N	\N
19894	573	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86044G	\N	\N
19895	579	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86044G	\N	\N
19245	572	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	2014-09-28 12:56:42
19246	572	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:21
19247	572	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
19248	556	2011-10-01 00:00:00	2014-02-28 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	2013-04-09 11:49:35
19249	556	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	2014-09-28 16:50:17
19250	556	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98053W	\N	\N
19251	556	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	2014-09-28 18:00:58
19252	571	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	2014-09-28 18:00:58
19253	978	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
19254	534	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
19255	534	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07004J	\N	\N
19421	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
19422	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
19423	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	2014-09-28 19:03:04
19424	572	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
19425	572	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
19426	572	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04034C	\N	\N
16938	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
19427	572	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
19428	572	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
19429	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
19430	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
19431	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
19597	963	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
19598	597	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	2017-10-10 09:45:39
19599	597	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
19600	963	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
19601	596	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	2014-09-28 16:42:05
19602	596	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04059M	\N	\N
19603	596	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
19604	597	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11094U	\N	\N
19605	644	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
19606	644	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
19607	963	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
19723	966	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	87003B	\N	2014-09-28 17:35:38
19896	534	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86044G	\N	\N
19897	598	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86044G	\N	\N
19898	629	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86044G	\N	\N
19899	575	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08033T	\N	2014-09-28 17:27:35
19900	997	2012-07-13 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11036J	\N	\N
19901	997	2012-07-13 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08055A	\N	\N
19902	997	2012-07-13 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08050U	\N	2014-09-28 12:44:31
19903	997	2012-07-13 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11101A	\N	\N
19904	997	2012-07-13 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
19905	997	2012-07-13 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04038G	\N	\N
19906	997	2012-07-13 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01015L	\N	\N
19907	997	2012-07-13 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	2014-09-28 19:03:23
19908	997	2012-07-13 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08016S	\N	\N
19909	997	2012-07-13 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	2014-09-28 17:40:23
19910	997	2012-07-13 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
19911	997	2012-07-13 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	09012S	\N	2014-09-28 13:09:05
19912	997	2012-07-13 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04069P	\N	2014-09-28 17:31:41
19913	997	2012-07-13 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11094U	\N	\N
19914	572	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11106F	\N	\N
20135	629	2013-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11110B	2013-03-07 16:15:41	\N
19916	620	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11069T	\N	\N
19256	534	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08019V	\N	\N
19257	556	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
19258	556	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07004J	\N	\N
19259	978	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	2014-09-28 16:50:17
19260	978	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98038X	\N	2014-09-28 17:38:26
19261	978	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
19262	978	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98053W	\N	\N
19263	978	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	2014-09-28 19:03:04
19264	978	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08011M	\N	\N
19265	534	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01007L	\N	\N
19266	534	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	2014-09-28 12:09:44
19432	574	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
19433	574	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	2014-09-28 16:50:17
19434	574	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
19435	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04079R	\N	\N
19436	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	2014-09-28 17:22:11
19437	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
19438	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04046G	\N	2014-09-28 17:07:41
19439	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	2014-09-28 16:50:17
19440	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	06004E	\N	2014-09-28 17:03:42
19441	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08039A	\N	\N
19442	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11012A	\N	\N
19608	596	2011-10-01 00:00:00	2014-05-11 00:00:00	ANCIEN	\N	\N	\N	11045K	\N	\N
19609	597	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11108H	\N	\N
19610	597	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11046L	\N	\N
19611	673	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
19612	673	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
19613	644	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	2014-09-28 17:27:35
19614	644	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
19615	644	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	2014-09-29 13:43:10
19616	596	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11100Y	\N	\N
19617	596	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11055M	\N	\N
19618	673	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95031C	\N	\N
19917	997	2012-07-13 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08040S	\N	2014-09-28 17:52:18
19918	648	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	2014-09-28 16:50:17
19919	648	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08058D	\N	\N
19920	648	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92020L	\N	\N
19921	648	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95035G	\N	\N
19922	648	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86034E	\N	\N
19923	648	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11106F	\N	\N
19924	648	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08053X	\N	\N
19925	648	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:21
19926	648	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95055L	\N	2014-09-28 13:21:47
19927	648	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98021N	\N	\N
19928	648	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	2014-09-28 16:50:17
19929	648	2012-06-28 00:00:00	2012-10-31 00:00:00	ANCIEN	\N	\N	\N	77058M	\N	\N
19930	648	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01014K	\N	\N
19931	648	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11054L	\N	\N
19932	648	2012-06-28 00:00:00	2014-05-11 00:00:00	ANCIEN	\N	\N	\N	11041F	\N	\N
19933	904	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08017T	\N	\N
19934	997	2012-07-13 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98038X	\N	2014-09-28 17:38:26
19935	997	2012-07-13 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08026U	\N	2014-09-28 17:52:18
19936	997	2012-07-13 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08033T	\N	2014-09-28 17:27:35
19938	957	2012-07-20 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04085P	\N	\N
19939	653	2012-06-28 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	90003B	\N	\N
19940	576	2012-06-28 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	12035A	\N	\N
19267	534	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
19268	534	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
19269	571	2011-10-01 00:00:00	2012-09-30 00:00:00	ANCIEN	\N	\N	\N	01051Q	\N	\N
19270	978	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
19271	978	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08012N	\N	\N
19272	534	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
19273	556	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
19274	556	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	2014-09-28 12:09:44
19275	556	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
19276	978	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08024S	\N	\N
19277	978	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08031R	\N	\N
19443	572	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08017T	\N	\N
19444	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08038Y	\N	\N
19445	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	05008E	\N	\N
19446	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
19447	574	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	\N	\N
19448	574	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07026Q	\N	\N
19449	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
19450	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	2014-09-28 12:09:44
19451	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
19452	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01028R	\N	\N
19453	572	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01041N	\N	\N
19619	644	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11061K	\N	\N
19620	644	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
19621	963	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08028W	\N	\N
19622	963	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08033T	\N	2014-09-28 17:27:35
19623	963	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
19624	597	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86034E	\N	\N
19625	597	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	87003B	\N	2014-09-28 17:35:38
19626	597	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	2014-09-28 16:40:50
19627	597	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
19628	673	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96004D	\N	2015-02-02 16:43:25
19629	673	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	2014-09-28 13:19:48
19102	634	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
19103	634	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	2014-09-28 18:19:47
19104	634	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
19105	647	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
19106	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11069T	\N	\N
19107	647	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	2014-09-28 18:00:58
19108	634	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	2014-09-28 17:27:35
19109	647	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08012N	\N	\N
19110	647	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
19111	633	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:21
19112	633	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
19278	978	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
19279	978	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89013M	\N	2014-09-28 17:05:42
19280	978	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11012A	\N	\N
19281	534	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08009T	\N	\N
19282	534	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04091M	\N	2014-09-28 17:55:39
19283	534	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	2014-09-28 16:42:05
19284	978	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	01063U	\N	2014-09-29 13:41:53
19285	978	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01007L	\N	\N
19286	978	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	2014-09-28 12:09:44
19287	556	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
19288	556	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
19454	572	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	01063U	\N	2014-09-29 13:41:53
19455	572	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
19456	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08031R	\N	\N
19457	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
19458	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01044R	\N	\N
19459	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	02053W	\N	2014-09-28 12:32:23
19460	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08048B	\N	\N
19461	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
19462	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
19463	572	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11012A	\N	\N
19464	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01041N	\N	\N
19630	596	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11089X	\N	\N
19631	597	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
19632	673	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
19633	673	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
19634	673	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	2014-09-29 13:43:10
19635	644	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07004J	\N	\N
19636	644	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
19637	597	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:21
19638	597	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
19639	673	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
19640	644	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01047U	\N	\N
19113	633	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11018G	\N	\N
19114	634	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
19115	647	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
19116	648	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	04090L	\N	\N
19117	633	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
19118	633	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
19119	634	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08040S	\N	2014-09-28 17:52:18
19120	634	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	\N	2014-09-28 17:03:42
19121	647	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08063A	\N	2014-09-28 17:07:07
19122	648	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	2014-09-28 19:03:23
19123	633	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
19289	556	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08050U	\N	2014-09-28 12:44:31
19290	556	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	2014-09-28 19:03:23
19291	556	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04080J	\N	\N
19152	534	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95035G	\N	\N
19292	571	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04084N	\N	2014-09-28 13:40:33
19293	978	2011-10-01 00:00:00	2013-02-06 00:00:00	ANCIEN	\N	\N	\N	08036W	\N	\N
19294	534	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04061F	\N	\N
19295	534	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
19296	534	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04073K	\N	2014-09-28 18:58:25
19297	534	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	\N
19298	556	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04087R	\N	2014-09-28 13:39:21
19299	556	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04043D	\N	\N
19465	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
19466	574	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08071A	\N	2014-09-29 09:08:33
19467	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	10015M	\N	\N
19468	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	2014-09-28 19:03:23
19469	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04078Q	\N	\N
19470	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04086Q	\N	\N
19471	572	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
19472	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08067E	\N	2014-09-28 17:22:11
19473	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08065C	\N	\N
19474	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08037X	\N	2014-09-28 17:34:16
19475	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08049C	\N	2014-09-28 19:07:43
19641	597	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
19642	597	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
19643	597	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	2014-09-28 17:27:35
19644	597	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
19645	597	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	2014-09-29 13:43:10
19646	673	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08042U	\N	\N
19647	653	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
19648	653	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04069P	\N	2014-09-28 17:31:42
19649	653	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
19650	674	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04091M	\N	2014-09-28 17:55:39
19651	674	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04065K	\N	2014-09-28 17:31:42
19135	633	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08040S	\N	2014-09-28 17:52:18
19136	634	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
19137	634	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01028R	\N	\N
19138	633	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	2014-09-28 17:22:11
19139	634	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08025T	\N	\N
19140	634	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08037X	\N	2014-09-28 17:34:16
19141	530	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07030L	\N	2014-09-28 17:03:42
19142	530	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
19143	534	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
19144	534	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01025N	\N	\N
19145	534	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
19300	978	2011-10-01 00:00:00	2013-02-21 00:00:00	ANCIEN	\N	\N	\N	10015M	\N	2013-03-26 10:04:27
19301	978	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	2014-09-28 19:03:23
19302	978	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08055A	\N	\N
19303	534	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	2017-10-10 09:45:39
19304	534	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11106F	\N	\N
19305	534	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
19306	556	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
19307	571	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11068S	\N	\N
19308	571	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11081P	\N	\N
19309	571	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
19310	978	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04087R	\N	2014-09-28 13:39:21
19476	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
19477	574	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	09012S	\N	2014-09-28 13:09:05
19478	574	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	10015M	\N	\N
19479	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08009T	\N	\N
19480	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	2014-09-28 16:59:41
19481	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04065K	\N	2014-09-28 17:31:42
19482	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04051D	\N	2014-09-28 17:07:41
19483	595	2011-10-01 00:00:00	2012-06-16 00:00:00	ANCIEN	\N	\N	\N	04053F	\N	\N
19484	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04059M	\N	\N
19485	595	2011-10-01 00:00:00	2014-05-11 00:00:00	ANCIEN	\N	\N	\N	11041F	\N	\N
19486	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04069P	\N	2014-09-28 17:31:42
19652	653	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
19653	674	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
19654	674	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	2017-10-10 09:45:39
19655	674	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
19656	653	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	2014-09-28 12:56:42
19657	653	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
19658	653	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07024N	\N	\N
19659	674	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
19660	653	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98024R	\N	\N
19661	653	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98005N	\N	\N
19662	653	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
19124	633	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
19125	634	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	2014-09-28 17:22:11
19126	634	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
19127	634	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
19128	634	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01042P	\N	\N
19129	647	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
19130	647	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08052W	\N	\N
19131	647	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08055A	\N	\N
16918	957	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04033B	\N	\N
19132	647	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04084N	\N	2014-09-28 13:40:33
19133	633	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	2014-09-28 16:50:17
19134	633	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07003H	\N	2014-09-28 12:21:28
19311	556	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
19312	556	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11063M	\N	\N
19313	556	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
19315	978	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04073K	\N	2014-09-28 18:58:25
19316	978	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	\N
19317	534	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11100Y	\N	\N
19318	556	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11105E	\N	\N
19319	556	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11100Y	\N	\N
19320	978	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11068S	\N	\N
19321	978	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
19487	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
19488	572	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	2015-03-02 10:42:04
19489	572	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	2014-09-28 19:03:23
19490	572	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04078Q	\N	\N
19491	572	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04080J	\N	\N
19492	573	2011-10-01 00:00:00	2012-06-16 00:00:00	ANCIEN	\N	\N	\N	09010Q	\N	\N
19493	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
19494	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
19495	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08050U	\N	2014-09-28 12:44:31
19496	574	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04078Q	\N	\N
19497	574	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08009T	\N	\N
19663	674	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
19664	674	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
19665	653	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
19666	653	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	2014-09-28 16:50:17
19667	674	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	2014-09-28 18:00:58
19668	674	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07034Q	\N	\N
19669	674	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	\N	2014-09-28 17:03:42
19670	674	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	2014-09-28 17:22:11
19671	653	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08012N	\N	\N
19672	674	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
19673	674	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	03001N	\N	2014-09-28 13:40:33
19146	646	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11085T	\N	\N
19147	532	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
19148	534	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
19149	532	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
19150	534	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89029V	\N	\N
19151	534	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	2014-09-28 18:00:58
16919	957	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08033T	\N	2014-09-28 17:27:35
19153	534	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	\N	2014-09-28 17:03:42
19154	529	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
19155	530	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	2014-09-28 17:27:35
19156	532	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	2014-09-28 18:00:58
19322	978	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
19323	978	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11064N	\N	\N
19324	556	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
19325	556	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	2014-09-28 18:19:47
19326	556	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	2014-09-28 12:56:42
19327	978	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	2014-09-28 16:50:17
19328	978	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11105E	\N	\N
19329	978	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
19330	978	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11054L	\N	\N
19331	556	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:21
19332	556	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11020A	\N	\N
19498	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04077P	\N	\N
19499	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11033F	\N	\N
19500	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	\N
19501	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11049P	\N	\N
19502	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
19503	595	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11106F	\N	\N
19504	572	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04061F	\N	\N
19505	572	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11042G	\N	\N
19506	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	2014-09-28 19:03:23
19507	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04078Q	\N	\N
19508	573	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04056J	\N	\N
19674	674	2011-10-01 00:00:00	2012-09-30 00:00:00	ANCIEN	\N	\N	\N	01051Q	\N	\N
13915	915	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	02003L	\N	\N
13919	599	2009-10-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08031R	\N	\N
13927	600	2009-06-25 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
13970	910	2009-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	09012S	\N	\N
12569	640	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92043T	\N	\N
13624	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04046G	\N	\N
13770	609	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98006P	\N	\N
13771	609	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
13772	609	2008-11-26 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	08007R	\N	\N
13773	609	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
13774	609	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	\N	\N
13775	609	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
13776	609	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08009T	\N	\N
13777	609	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
13779	609	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04034C	\N	\N
13861	651	2009-09-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08060W	\N	\N
13862	651	2009-09-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	\N
13912	599	2009-10-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08060W	\N	\N
13864	632	2007-04-22 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	\N
13913	599	2009-10-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08058D	\N	\N
13914	599	2009-10-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
16898	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
16899	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
17055	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11014C	\N	\N
16901	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	07032N	\N	\N
17063	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
16903	919	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	2014-09-28 18:03:38
16939	906	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89013M	\N	2014-09-28 17:05:42
16940	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
16941	906	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04091M	\N	2014-09-28 17:55:39
16942	906	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95025E	\N	2014-09-28 17:09:16
16944	910	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
16945	910	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08033T	\N	2014-09-28 17:27:35
17073	909	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	87003B	\N	2014-09-28 17:35:38
17102	948	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	\N
17103	904	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01044R	\N	\N
17104	904	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04073K	\N	2014-09-28 18:58:25
17105	904	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11060J	\N	\N
17106	904	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	2014-09-28 16:59:41
8438	932	2001-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	95045J	\N	\N
8439	932	2001-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	87002A	\N	\N
8440	932	2001-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	80031A	\N	\N
8441	932	2001-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98044V	\N	\N
8442	932	2001-01-01 00:00:00	2004-04-30 00:00:00	ANCIEN	\N	\N	\N	95051G	\N	\N
8443	932	2001-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	91002E	\N	\N
8444	932	2001-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01054T	\N	\N
8445	932	2001-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98015Q	\N	\N
8446	932	2001-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
8447	932	2001-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	01029S	\N	\N
8448	932	2001-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	89041R	\N	\N
8449	932	2001-01-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	80041C	\N	\N
8450	932	2001-01-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
10989	927	2004-10-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	95004Y	\N	\N
13234	922	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92042S	\N	\N
13248	938	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08034U	\N	\N
13250	938	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01009N	\N	\N
13264	581	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98021N	\N	\N
12728	913	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98036V	\N	\N
12729	913	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	\N
12730	913	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08068F	\N	\N
12731	913	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08050U	\N	\N
12732	913	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01052R	\N	\N
12733	913	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
12734	913	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07001F	\N	\N
13831	622	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
13832	622	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95024D	\N	\N
13833	622	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	\N
13834	622	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	2014-10-28 17:07:07
13835	622	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04062G	\N	\N
13836	622	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08067E	\N	\N
13837	622	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
13838	622	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01020H	\N	\N
13839	622	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
13840	622	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08073C	\N	\N
13841	622	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
13842	622	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	05011Y	\N	\N
13924	608	2009-06-25 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92042S	\N	\N
14020	642	2010-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
14021	642	2010-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04096S	\N	\N
14022	623	2010-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04080J	\N	\N
13676	584	2009-01-13 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83031N	\N	\N
13752	616	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92011K	\N	\N
13753	616	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
13754	616	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	\N
13755	616	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04100U	\N	\N
13756	616	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92042S	\N	\N
13757	616	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
13929	931	2009-04-08 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08054Y	\N	\N
10684	905	2005-06-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	95035G	\N	\N
10708	905	2001-01-01 00:00:00	2009-03-01 00:00:00	ANCIEN	\N	\N	\N	01028R	\N	\N
10739	575	2004-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01034P	\N	\N
10764	937	2004-10-01 00:00:00	2004-12-31 00:00:00	ANCIEN	\N	\N	\N	04074L	\N	\N
11536	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
13687	653	2009-05-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04043D	\N	\N
17337	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
17338	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	2014-09-28 12:09:44
17339	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
17340	576	2011-10-01 00:00:00	2013-02-06 00:00:00	ANCIEN	\N	\N	\N	08036W	\N	\N
13184	980	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08063A	\N	\N
17341	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08072B	\N	2014-09-29 09:05:47
17342	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08073C	\N	\N
17343	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04094Q	\N	\N
17267	928	2011-10-01 00:00:00	2014-11-04 00:00:00	ANCIEN	\N	\N	\N	01052R	\N	2014-11-04 11:22:47
17268	928	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	2014-09-28 12:56:42
17269	928	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01041N	\N	\N
17270	928	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
17495	581	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11051H	\N	\N
17496	581	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
17497	581	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11064N	\N	\N
17498	583	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	2014-09-28 13:21:47
17499	583	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
17500	583	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	11027H	\N	\N
17501	583	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	2014-09-28 18:19:47
17502	583	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95047L	\N	2014-09-28 17:09:16
17503	583	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:21
17532	583	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	10006L	\N	\N
17533	583	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
17534	583	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08009T	\N	\N
17535	583	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	2014-09-28 16:59:41
17536	583	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04043D	\N	\N
17537	583	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
17538	583	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
17539	583	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	\N
17540	583	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
17541	583	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
17542	583	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11100Y	\N	\N
17708	979	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
17709	979	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	\N
17710	979	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11106F	\N	\N
17711	979	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
17712	979	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11105E	\N	\N
17713	979	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11100Y	\N	\N
17714	979	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11099A	\N	\N
17715	588	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
17716	588	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
17717	588	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92020L	\N	\N
17718	588	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	2014-09-28 18:03:38
17344	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
17345	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
17346	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11043H	\N	\N
17347	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	2014-09-28 16:42:05
17348	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
17349	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04055H	\N	\N
18280	610	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	03001N	\N	2014-09-28 13:40:33
18281	610	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01046T	\N	\N
18282	610	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	01063U	\N	2014-09-29 13:41:53
18283	610	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
18284	610	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08068F	\N	\N
18285	610	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08067E	\N	2014-09-28 17:22:11
18286	610	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08053X	\N	\N
18287	610	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
18288	611	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
18289	611	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
18290	611	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
18478	621	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01047U	\N	\N
18479	622	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08067E	\N	2014-09-28 17:22:11
18480	622	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08065C	\N	\N
18481	620	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
18482	620	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	2014-09-28 19:03:04
18483	620	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	2014-09-28 18:00:58
18484	621	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
18485	621	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01062T	\N	\N
18486	621	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	2014-09-28 12:09:44
18487	621	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08068F	\N	\N
18488	621	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08067E	\N	2014-09-28 17:22:11
18033	600	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
18034	600	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11077T	\N	\N
18035	600	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11054L	\N	\N
18036	600	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11069T	\N	\N
18037	601	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	2014-09-28 13:21:47
18038	601	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
18039	601	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11018G	\N	\N
18040	601	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
18041	601	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
18042	601	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
18043	601	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01062T	\N	\N
18203	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04044E	\N	\N
18204	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	2014-09-28 16:50:17
18205	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07003H	\N	2014-09-28 12:21:28
18206	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98038X	\N	2014-09-28 17:38:26
18207	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
18208	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	2014-09-28 18:00:58
18209	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08034U	\N	\N
18210	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08011M	\N	\N
13185	980	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07023M	\N	\N
18211	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
18212	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
18291	611	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
18292	611	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
18293	611	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04041B	\N	\N
18786	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08016S	\N	\N
18787	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08072B	\N	2014-09-29 09:05:47
18788	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08073C	\N	\N
18789	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08045X	\N	2014-09-28 17:00:59
18790	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04094Q	\N	\N
18791	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04095R	\N	\N
18792	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
18793	632	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08014Q	\N	\N
18794	632	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
18795	640	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07034Q	\N	\N
17006	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11106F	\N	\N
17007	957	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08040S	\N	2014-09-28 17:52:18
18958	629	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	01063U	\N	2014-09-29 13:41:53
18959	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
18960	651	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
18961	651	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	2014-09-28 12:56:42
18962	628	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
18963	628	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
18964	657	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
18965	851	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92020L	\N	\N
18966	651	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:21
18967	651	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11020A	\N	\N
19058	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01052R	\N	\N
19059	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07003H	\N	2014-09-28 12:21:28
19060	651	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11094U	\N	\N
19061	634	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	04090L	\N	\N
19062	648	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	2013-11-26 18:00:24
19063	634	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04087R	\N	2014-09-28 13:39:21
19064	647	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	2017-10-10 09:45:39
19065	647	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
19066	647	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11104D	\N	\N
19067	633	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
19068	633	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
18621	627	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
18622	623	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04056J	\N	\N
18623	624	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11049P	\N	\N
18624	624	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	2017-10-10 09:45:39
18625	624	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11106F	\N	\N
18626	624	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
18627	625	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11095V	\N	\N
18628	627	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	2014-09-28 18:03:38
18629	627	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	2014-09-28 16:50:17
18630	627	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	2014-09-28 18:19:47
18631	623	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	2014-09-28 16:42:05
18796	640	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	\N	2014-09-28 17:03:42
18797	640	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	2014-09-28 17:22:11
18798	641	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08048B	\N	\N
13688	653	2009-05-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	\N
13689	653	2009-05-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08012N	\N	\N
13690	653	2009-05-20 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	01039U	\N	\N
13691	653	2009-05-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
13692	653	2009-05-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01033N	\N	\N
13693	653	2009-05-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
13694	653	2009-05-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01029S	\N	\N
13759	966	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
9598	623	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04034C	\N	\N
10425	595	2005-03-25 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
9747	628	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
9038	908	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04033B	\N	\N
11990	589	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04038G	\N	\N
11272	673	2007-01-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04044E	\N	\N
10011	919	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
10859	600	2005-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01052R	\N	\N
16993	907	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	09012S	\N	2014-09-28 13:09:05
17107	904	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07030L	\N	2014-09-28 17:03:42
17145	918	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08038Y	\N	\N
17146	965	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11107G	\N	\N
17159	904	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11089X	\N	\N
17160	904	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04091M	\N	2014-09-28 17:55:39
17167	948	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04091M	\N	2014-09-28 17:55:39
17168	918	2011-10-01 00:00:00	2014-11-04 00:00:00	ANCIEN	\N	\N	\N	01052R	\N	2014-11-04 11:22:47
17173	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08068F	\N	\N
17176	934	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08016S	\N	\N
17177	991	2011-12-14 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11089X	\N	\N
17179	957	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11049P	\N	\N
17180	922	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11049P	\N	\N
17181	948	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11049P	\N	\N
17185	934	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	2014-09-28 17:22:11
17192	909	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:21
17193	909	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04091M	\N	2014-09-28 17:55:39
17198	966	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	2014-09-28 16:40:50
17240	992	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	2014-09-28 19:03:23
17265	992	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	2014-09-28 18:03:38
17266	992	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04034C	\N	\N
17272	904	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11101A	\N	\N
17273	991	2011-12-14 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04046G	\N	2014-09-28 17:07:41
12776	576	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
13162	965	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	\N	\N
13163	965	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95024D	\N	\N
13164	965	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08045X	\N	\N
13173	980	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
13166	965	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	\N
13172	980	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
13174	980	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95020Y	\N	\N
13175	980	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	\N	\N
13176	980	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
13177	980	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	87003B	\N	\N
13178	980	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
13179	980	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	\N
13180	980	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
13181	980	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08065C	\N	\N
13182	980	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08016S	\N	\N
13183	980	2009-02-17 00:00:00	2009-02-17 00:00:00	ANCIEN	\N	\N	\N	04041B	\N	\N
13186	980	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07032N	\N	\N
12643	556	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
12644	612	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08050U	\N	\N
13820	626	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
13821	580	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
13923	957	2009-12-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
13956	906	2010-02-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08015R	\N	\N
5708	628	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
11992	657	2008-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
10633	591	2005-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04055H	\N	\N
10819	584	2005-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04071H	\N	\N
9338	573	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
9517	572	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
12516	573	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
11871	598	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	02053W	\N	\N
13973	629	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
13580	928	2009-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01029S	\N	\N
13582	663	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
13583	663	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	\N	\N
13584	663	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	\N
13585	663	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
13586	663	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08053X	\N	\N
13587	663	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07032N	\N	\N
13588	663	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01050P	\N	\N
13589	663	2008-11-26 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	01039U	\N	\N
13590	663	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08071A	\N	\N
10245	530	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
7284	909	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
13493	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08040S	\N	\N
13790	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08053X	\N	\N
13791	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	06001B	\N	\N
13977	530	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
11486	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	\N
11524	974	2006-09-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	95047L	\N	\N
13979	965	2010-06-02 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08039A	\N	\N
13986	579	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01041N	\N	\N
13987	579	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	\N
13988	579	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07024N	\N	\N
17350	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04059M	\N	\N
17351	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
17352	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04071H	\N	\N
17353	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	\N
17354	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11109J	\N	\N
17169	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11089X	\N	\N
17170	922	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04091M	\N	2014-09-28 17:55:39
17504	583	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11048N	\N	\N
17505	583	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98005N	\N	\N
17506	583	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	2014-09-28 17:27:35
17507	583	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
17508	583	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11015D	\N	\N
17509	583	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	2014-09-29 13:43:10
17510	583	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11023D	\N	\N
17511	583	2011-10-01 00:00:00	2013-09-30 00:00:00	ANCIEN	\N	\N	\N	07025P	\N	\N
17512	583	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
17513	583	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04038G	\N	\N
17543	583	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11054L	\N	\N
17544	583	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11055M	\N	\N
17545	583	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11114F	\N	\N
17546	583	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11094U	\N	\N
17276	912	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	2014-09-28 16:50:17
17547	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	2014-09-28 16:40:50
17548	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	2014-09-28 16:50:17
17549	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
17550	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	2014-09-28 13:16:32
17551	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	2014-09-28 12:56:42
17552	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:21
17553	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
17719	588	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
17720	588	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	2014-09-28 18:19:47
17721	588	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	2014-09-28 12:56:42
17722	588	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
17723	588	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	2014-09-29 13:43:10
17724	588	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04034C	\N	\N
17725	588	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
17726	588	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04038G	\N	\N
17727	588	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
17728	588	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08038Y	\N	\N
17729	588	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
17355	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11113E	\N	\N
17356	576	2011-10-01 00:00:00	2014-05-11 00:00:00	ANCIEN	\N	\N	\N	11045K	\N	\N
17357	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11106F	\N	\N
17358	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
17359	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11057P	\N	\N
17360	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11111C	\N	\N
17361	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11100Y	\N	\N
17362	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11055M	\N	\N
18294	611	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	2014-09-28 18:00:58
18295	611	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
18296	611	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	2014-09-28 17:22:11
18297	611	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08027V	\N	2014-09-28 17:34:16
18298	611	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
18299	611	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01062T	\N	\N
18300	611	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
18301	611	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08065C	\N	\N
18467	620	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	2014-09-28 17:27:35
18468	620	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
18469	621	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08042U	\N	\N
18470	621	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08011M	\N	\N
18471	622	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11012A	\N	\N
18472	622	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
18473	622	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01041N	\N	\N
17277	912	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	2014-09-28 16:42:05
18474	622	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01064V	\N	2014-09-28 17:12:41
18475	622	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
18476	620	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11031D	\N	\N
18477	621	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
18044	599	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08012N	\N	\N
18045	599	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
18046	601	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	2014-09-28 19:03:23
18047	601	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04086Q	\N	\N
18048	601	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04069P	\N	2014-09-28 17:31:42
18049	601	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
18050	601	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11084S	\N	\N
18051	601	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11105E	\N	\N
18052	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95059Q	\N	\N
18053	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95055L	\N	2014-09-28 13:21:47
18054	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95015C	\N	\N
18213	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
18214	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
18215	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	2014-09-28 12:09:44
18216	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
18217	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	02053W	\N	2014-09-28 12:32:23
18218	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
18219	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08047A	\N	\N
18220	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	\N
18221	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04080J	\N	\N
18222	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
18223	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04065K	\N	2014-09-28 17:31:42
18302	611	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
18303	611	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
18304	609	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11049P	\N	\N
18305	609	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
18306	612	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
18799	641	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08053X	\N	\N
18800	641	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08059E	\N	2014-09-28 17:27:29
18801	632	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
18802	640	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08024S	\N	\N
18803	640	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08039A	\N	\N
18804	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04061F	\N	\N
18805	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11042G	\N	\N
18806	632	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	02053W	\N	2014-09-28 12:32:23
18968	651	2011-10-01 00:00:00	2012-02-22 00:00:00	ANCIEN	\N	\N	\N	11010L	\N	\N
16926	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08038Y	\N	\N
16928	965	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
18969	651	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11011M	\N	\N
18970	651	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	2014-09-28 13:19:48
18971	657	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
18972	657	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01057W	\N	\N
18973	651	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11048N	\N	\N
18974	651	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98005N	\N	\N
18975	651	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
18976	651	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	2014-09-29 13:43:10
18977	651	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01016M	\N	\N
19069	633	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08049C	\N	2017-01-25 15:45:09
19070	634	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04069P	\N	2014-09-28 17:31:42
19071	634	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
19072	634	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11109J	\N	\N
19073	634	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11068S	\N	\N
19074	647	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11107G	\N	\N
19075	646	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	2015-01-14 16:43:47
19076	646	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95015C	\N	\N
19077	633	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08045X	\N	2014-09-28 17:00:59
19078	633	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	04090L	\N	\N
19079	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08048B	\N	\N
18632	623	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04069P	\N	2014-09-28 17:31:42
18633	623	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	\N
18634	626	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
18635	626	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	77058M	\N	2014-09-28 12:52:11
18636	626	2011-10-01 00:00:00	2012-09-19 00:00:00	ANCIEN	\N	\N	\N	95011X	\N	\N
18637	623	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
18638	624	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11091R	\N	\N
18639	626	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	90003B	\N	\N
18640	626	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
18641	626	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
18642	626	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:21
18807	640	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
18808	640	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	02002K	\N	\N
18809	641	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04086Q	\N	\N
18810	641	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	2014-09-28 16:42:05
18811	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	\N
13989	579	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	78006D	\N	\N
13990	579	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01018P	\N	\N
13991	579	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08017T	\N	\N
13992	579	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
13993	579	2010-03-30 00:00:00	2011-03-27 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
13994	579	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04100U	\N	\N
13995	579	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08009T	\N	\N
13996	579	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
13997	579	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01029S	\N	\N
13998	579	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04069P	\N	\N
13999	579	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
17275	912	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
17284	575	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04061F	\N	\N
17285	575	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04066L	\N	\N
17286	575	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04077P	\N	\N
17287	575	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11049P	\N	\N
17288	575	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11063M	\N	\N
17289	575	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07030L	\N	2014-09-28 17:03:42
17290	575	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	2014-09-28 13:21:47
17291	575	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95055L	\N	2014-09-28 13:21:47
17292	575	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
12735	913	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	\N
12736	913	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08038Y	\N	\N
12737	913	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	\N	\N
12738	913	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04071H	\N	\N
12739	913	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08064B	\N	\N
12740	913	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01025N	\N	\N
12741	913	2008-10-01 00:00:00	2011-03-01 00:00:00	ANCIEN	\N	\N	\N	07004J	\N	\N
12742	913	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08016S	\N	\N
12743	913	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
12744	913	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08009T	\N	\N
12745	913	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08033T	\N	\N
12746	913	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
12747	913	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
12748	913	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08054Y	\N	\N
12749	913	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08049C	\N	\N
12750	913	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	05011Y	\N	\N
12761	590	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08035V	\N	\N
12762	620	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08035V	\N	\N
12771	581	2008-12-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
12772	576	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08072B	\N	\N
12773	576	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08073C	\N	\N
12774	576	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08011M	\N	\N
12775	576	2009-01-20 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	\N
13593	911	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95024D	\N	\N
13701	964	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08057C	\N	\N
13702	964	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04038G	\N	\N
13703	964	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	80013X	\N	\N
13826	580	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
13827	580	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01030K	\N	\N
13828	968	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04097T	\N	\N
13850	653	2009-09-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95019G	\N	\N
13851	653	2009-09-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
13852	947	2009-09-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08017T	\N	\N
13853	901	2009-09-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08017T	\N	\N
13854	913	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
13855	957	2005-03-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98023Q	\N	\N
13950	957	2010-02-12 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04091M	\N	\N
13431	901	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01016M	\N	\N
13598	911	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07004J	\N	\N
13614	947	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
13615	947	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	\N	\N
13616	947	2008-11-26 00:00:00	2010-03-06 00:00:00	ANCIEN	\N	\N	\N	86030A	\N	\N
13617	947	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77053G	\N	\N
13618	947	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	\N
13645	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	\N
13727	964	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08061X	\N	\N
14000	579	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
13435	966	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98027U	\N	\N
13600	901	2008-10-01 00:00:00	2010-10-11 00:00:00	ANCIEN	\N	\N	\N	01017N	\N	\N
13601	901	2008-10-01 00:00:00	2010-11-02 00:00:00	ANCIEN	\N	\N	\N	01026P	\N	\N
13602	901	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
13816	906	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08037X	\N	\N
13921	629	2009-12-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
13941	933	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
13948	933	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
10586	915	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	03001N	\N	\N
11191	572	2006-11-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01054T	\N	\N
10367	576	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01054T	\N	\N
11022	619	2006-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
10546	578	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
9380	621	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	\N
10825	947	2005-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
10043	589	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	02001J	\N	\N
12527	573	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08017T	\N	\N
17363	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11114F	\N	\N
17364	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11088W	\N	\N
17365	575	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
17188	912	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04091M	\N	2014-09-28 17:55:39
17189	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11049P	\N	\N
17194	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
17195	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08061X	\N	\N
17196	912	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	2014-09-28 12:56:42
17197	912	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
17201	912	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95030B	\N	2014-09-28 17:55:37
17202	991	2011-12-14 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	\N
17204	912	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	2015-01-08 17:14:29
17205	912	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
17210	934	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:21
17233	992	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	2014-09-28 13:21:47
17234	992	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04046G	\N	2014-09-28 17:07:41
17235	992	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01015L	\N	\N
17241	992	2012-01-25 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	2014-09-29 13:43:10
17247	992	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	2014-09-28 17:22:11
17248	992	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	86034E	\N	\N
17255	992	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	98021N	\N	\N
17257	992	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
17258	992	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	06005F	\N	2014-09-28 13:32:35
17259	992	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11012A	\N	\N
17260	992	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
17261	992	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01028R	\N	\N
17554	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07024N	\N	\N
17555	584	2011-10-01 00:00:00	2014-06-30 00:00:00	ANCIEN	\N	\N	\N	11022C	\N	2014-08-06 16:28:26
17556	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
17557	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	2014-09-28 13:19:48
17558	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
17559	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
17560	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98005N	\N	\N
17561	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	2014-09-28 17:27:35
17562	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
17563	584	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	2014-09-29 13:43:10
17564	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98021N	\N	\N
17730	588	2011-10-01 00:00:00	2012-09-30 00:00:00	ANCIEN	\N	\N	\N	01051Q	\N	\N
17731	588	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01041N	\N	\N
17732	588	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	01063U	\N	2014-09-29 13:41:53
17733	588	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
17734	588	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04078Q	\N	\N
17735	588	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04091M	\N	2014-09-28 17:55:39
17736	588	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11106F	\N	\N
17737	588	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
17738	588	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11114F	\N	\N
17739	979	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
17740	979	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98023Q	\N	\N
34488	957	2023-12-14 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	19954N	\N	\N
17366	575	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11106F	\N	\N
17367	575	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
17368	575	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
17369	575	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11084S	\N	\N
17370	575	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11105E	\N	\N
17371	575	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11069T	\N	\N
17372	575	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11070L	\N	\N
17373	575	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11099A	\N	\N
17374	577	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	2014-09-28 18:03:38
17375	577	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
18307	613	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08062Y	\N	\N
18308	612	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	\N
18309	613	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
18310	612	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04061F	\N	\N
18311	612	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
18312	613	2011-10-01 00:00:00	2014-05-11 00:00:00	ANCIEN	\N	\N	\N	11045K	\N	\N
17879	592	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
17880	592	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04038G	\N	\N
17881	592	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98038X	\N	2014-09-28 17:38:26
17882	592	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	2014-09-28 18:00:58
17883	592	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
17884	592	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01059Y	\N	\N
17885	592	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07026Q	\N	\N
17886	592	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
17887	592	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11068S	\N	\N
17888	592	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11063M	\N	\N
17889	592	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	2017-10-10 09:45:39
18055	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	2014-09-28 17:40:23
18056	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
18057	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92020L	\N	\N
18058	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
18059	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	2014-09-28 16:50:17
18060	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11030C	\N	\N
18061	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	2014-09-28 18:19:47
18062	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95047L	\N	2014-09-28 17:09:16
18063	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:21
18064	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
18065	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
17278	912	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01007L	\N	\N
17279	934	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01034P	\N	\N
17280	912	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
17281	918	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08057C	\N	2014-09-28 14:31:42
17283	904	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
18224	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	2014-09-28 16:42:05
18225	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04055H	\N	\N
18226	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	\N
18227	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
18228	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11069T	\N	\N
18229	609	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	2014-09-28 13:21:47
18230	609	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	2014-09-28 16:50:17
18231	609	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:21
18313	613	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
18314	613	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11069T	\N	\N
18315	612	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11100Y	\N	\N
18316	613	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
18317	612	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	2014-09-28 18:03:38
18318	612	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	2014-09-28 13:16:32
18319	612	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:21
18320	612	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
18812	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08026U	\N	2014-09-28 17:52:18
18813	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11109J	\N	\N
18814	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11063M	\N	\N
18815	632	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
18816	632	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01028R	\N	\N
18817	640	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08065C	\N	\N
18978	628	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07004J	\N	\N
18979	657	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
18980	651	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11036J	\N	\N
18981	651	2011-10-01 00:00:00	2012-07-31 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
18982	628	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
18983	657	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04084N	\N	2014-09-28 13:40:33
18984	851	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
18985	651	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04046G	\N	2014-09-28 17:07:41
18986	651	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	2014-09-28 16:50:17
18987	651	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07034Q	\N	\N
18988	657	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	2014-09-28 16:59:41
19080	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
19081	629	2011-10-01 00:00:00	2013-02-06 00:00:00	ANCIEN	\N	\N	\N	08036W	\N	\N
19082	633	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	2014-09-28 16:42:05
19083	648	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07024N	\N	\N
19084	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08041T	\N	\N
19085	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04074L	\N	\N
19086	648	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
19087	629	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	08064B	\N	\N
19088	633	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11068S	\N	\N
19089	633	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
19090	647	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	2014-09-28 13:16:32
18643	626	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
18644	626	2011-10-01 00:00:00	2014-04-24 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
18645	627	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	2014-09-29 13:43:10
18646	624	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07030L	\N	2014-09-28 17:03:42
18647	624	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95039L	\N	\N
18648	625	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	2014-09-28 16:40:50
18649	626	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
18650	626	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11060J	\N	\N
18651	626	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98029W	\N	\N
18652	626	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
18653	626	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98005N	\N	\N
18818	640	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08059E	\N	2014-09-28 17:27:29
18819	641	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	\N
18820	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11064N	\N	\N
18821	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11084S	\N	\N
18822	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11104D	\N	\N
18823	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11055M	\N	\N
18824	632	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	\N
12565	599	2009-01-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08012N	\N	\N
13599	928	2008-11-26 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95019G	\N	\N
13785	964	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	06001B	\N	\N
13782	964	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08067E	\N	\N
13784	964	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08053X	\N	\N
17293	575	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
17294	575	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	2014-09-28 13:19:48
17295	575	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
17296	575	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
17297	575	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11040E	\N	\N
17298	575	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11037K	\N	\N
17299	575	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
17300	575	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08035V	\N	\N
17301	575	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08038Y	\N	\N
17302	575	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	06004E	\N	2014-09-28 17:03:42
17303	575	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
12645	612	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
12646	612	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
12647	612	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	\N
12648	612	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
17166	948	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08038Y	\N	\N
12655	602	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
12657	602	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08043V	\N	\N
12658	602	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08068F	\N	\N
12659	602	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95015C	\N	\N
12660	602	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
12661	602	1999-01-01 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	07028S	\N	\N
12663	602	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
12664	602	1999-01-01 00:00:00	2011-01-23 00:00:00	ANCIEN	\N	\N	\N	92022N	\N	\N
12665	602	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08023R	\N	\N
12667	602	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	02002K	\N	\N
12668	602	1999-01-01 00:00:00	2010-10-11 00:00:00	ANCIEN	\N	\N	\N	01017N	\N	\N
12669	602	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
12670	602	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	06001B	\N	\N
12671	602	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08067E	\N	\N
12672	602	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
12673	602	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
12674	602	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04094Q	\N	\N
12675	602	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08034U	\N	\N
13728	964	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
13729	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08058D	\N	\N
13737	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04034C	\N	\N
13901	599	2009-10-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01063U	\N	\N
13958	623	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95045J	\N	\N
13959	600	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01021J	\N	\N
13960	625	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
13974	584	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	\N
13976	964	2010-05-07 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
13980	603	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08054Y	\N	\N
13981	579	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	\N
13982	579	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92011K	\N	\N
13983	579	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	\N	\N
13631	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	\N	\N
13632	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98029W	\N	\N
13633	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	\N
13843	901	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
13938	933	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08028W	\N	\N
13942	933	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	\N
13943	933	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	03001N	\N	\N
13951	653	2010-01-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
9840	611	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
13858	632	2009-09-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95032D	\N	\N
13897	915	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
13972	632	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	10001F	\N	\N
13975	623	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
13978	584	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	\N	\N
14003	579	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	82002D	\N	\N
14004	582	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04080J	\N	\N
14005	603	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
14006	579	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	10005K	\N	\N
14007	579	2010-07-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
14008	600	2010-07-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	10003H	\N	\N
14014	651	2010-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	09012S	\N	\N
14010	979	2010-07-01 00:00:00	2011-06-10 00:00:00	ANCIEN	\N	\N	\N	07004J	\N	\N
14011	979	2010-07-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	\N
14012	573	2010-07-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04096S	\N	\N
14013	617	2010-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	2015-03-02 10:42:04
14016	579	2010-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
14017	922	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04069P	\N	\N
14019	647	2010-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08012N	\N	\N
13783	964	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
13859	651	2009-09-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08063A	\N	\N
13867	609	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	06001B	\N	\N
13868	609	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
17376	577	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
16354	908	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
16355	908	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11066Q	\N	\N
16356	918	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04087R	\N	2014-09-28 13:39:21
16357	918	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95005A	\N	2014-09-28 17:40:23
16358	918	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	\N
16359	918	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01046T	\N	\N
16360	918	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07003H	\N	2014-09-28 12:21:28
16361	918	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08050U	\N	2014-09-28 12:44:31
16362	918	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11101A	\N	\N
16366	918	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01059Y	\N	\N
16376	918	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
16384	948	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04087R	\N	2014-09-28 13:39:21
16385	908	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08021P	\N	\N
16388	948	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01046T	\N	\N
16389	948	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08059E	\N	2014-09-28 17:27:29
16399	948	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01025N	\N	\N
16400	948	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
16401	948	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
16403	948	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
16405	948	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	\N
16406	948	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08031R	\N	\N
16408	948	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11077T	\N	\N
16410	948	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	09012S	\N	2014-09-28 13:09:05
17565	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01016M	\N	\N
17566	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98036V	\N	2014-09-28 17:15:42
17567	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04034C	\N	\N
17568	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
17569	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
17570	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04044E	\N	\N
17571	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	2014-09-28 16:50:17
17572	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
17573	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98052V	\N	\N
17574	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	2014-09-28 18:00:58
17575	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08042U	\N	\N
16832	922	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11088W	\N	\N
16833	922	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	98024R	\N	\N
16834	922	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11059R	\N	\N
16835	922	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04083M	\N	2014-09-28 16:40:50
17741	979	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
16837	957	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	2014-09-28 12:56:42
17742	979	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92018S	\N	\N
16839	957	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11068S	\N	\N
16841	957	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08059E	\N	2014-09-28 17:27:29
16842	957	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
16843	957	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08068F	\N	\N
17743	589	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:21
17744	589	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
17745	589	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11018G	\N	\N
17746	589	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98027U	\N	\N
17377	577	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:21
17378	577	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
17379	577	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
17380	577	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
17381	577	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04038G	\N	\N
17382	577	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	2014-09-28 16:50:17
17383	577	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
17384	577	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	2014-09-28 18:00:58
17385	577	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07034Q	\N	\N
17386	577	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11012A	\N	\N
17387	577	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
16364	918	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11032E	\N	\N
16365	918	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
16411	948	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
16412	948	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	04090L	\N	\N
16413	948	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
18321	613	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
18322	613	2011-10-01 00:00:00	2012-02-28 00:00:00	ANCIEN	\N	\N	\N	11010L	\N	\N
18323	613	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
17890	592	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
34492	1010	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	20172F	\N	\N
17891	592	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
17892	592	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11064N	\N	\N
17893	592	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11098Y	\N	\N
17894	594	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	11027H	\N	\N
17895	594	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
17896	594	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95025E	\N	2014-09-28 17:09:16
17897	594	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
17898	594	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
17899	594	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01025N	\N	\N
17900	594	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11040E	\N	\N
18066	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98005N	\N	\N
18067	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
18068	602	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	2014-09-29 13:43:10
18069	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01027Q	\N	\N
18070	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11023D	\N	\N
18071	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	99004R	\N	\N
18072	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11037K	\N	\N
18073	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11034G	\N	\N
18074	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01015L	\N	\N
18075	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
18076	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04038G	\N	\N
18232	609	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
18233	609	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
18234	609	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
18235	609	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98005N	\N	\N
18236	609	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
18237	609	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11015D	\N	\N
18238	609	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
18239	609	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	2014-09-28 16:50:17
18240	609	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	\N	\N
18241	609	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
18242	609	2011-10-01 00:00:00	2012-09-30 00:00:00	ANCIEN	\N	\N	\N	01051Q	\N	\N
18324	612	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
18325	613	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98038X	\N	2014-09-28 17:38:26
18326	613	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	2014-09-28 18:00:58
18327	612	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	2014-09-28 16:50:17
18328	612	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98053W	\N	\N
18329	612	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	2014-09-28 19:03:04
18330	612	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	2014-09-28 18:00:58
18331	612	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07034Q	\N	\N
18332	613	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
18333	612	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01042P	\N	\N
18825	632	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	04090L	\N	\N
18826	640	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
18827	641	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11068S	\N	\N
18828	641	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	2017-10-10 09:45:39
18989	657	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	2014-09-28 16:42:05
18990	657	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
18991	851	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	2014-09-28 16:50:17
18992	651	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08015R	\N	\N
18993	657	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
18994	651	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11012A	\N	\N
18995	651	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	01063U	\N	2014-09-29 13:41:53
18996	657	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11066Q	\N	\N
18997	851	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	2014-09-28 18:00:58
18998	851	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08043V	\N	\N
18999	651	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
19091	647	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:21
19092	648	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
19093	629	2011-10-01 00:00:00	2014-05-11 00:00:00	ANCIEN	\N	\N	\N	11041F	\N	\N
19094	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
19095	647	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98027U	\N	\N
19096	647	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
19097	648	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11031D	\N	\N
19098	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
19099	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11101A	\N	\N
19100	647	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
19101	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11091R	\N	\N
18654	627	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
18655	623	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11100Y	\N	\N
18656	625	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	2014-09-28 13:16:32
18657	625	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95047L	\N	2014-09-28 17:09:16
18658	626	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
18659	626	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01016M	\N	\N
18660	624	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92020L	\N	\N
18661	624	2011-10-01 00:00:00	2013-06-27 00:00:00	ANCIEN	\N	\N	\N	95045J	\N	\N
18662	624	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86034E	\N	\N
18663	624	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
18664	624	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	2014-09-28 13:16:32
18829	641	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11084S	\N	\N
18830	641	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11085T	\N	\N
18831	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11114F	\N	\N
18832	643	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	2014-09-28 13:21:47
18833	632	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	2014-09-28 19:03:23
18834	632	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04078Q	\N	\N
18835	632	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04084N	\N	2014-09-28 13:40:33
18836	661	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
18837	661	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07030L	\N	2014-09-28 17:03:42
14081	957	2011-04-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
14082	906	2011-04-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
14110	595	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
14137	604	2011-05-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
16852	957	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11107G	\N	\N
17304	575	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	02053W	\N	2014-09-28 12:32:23
17305	575	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08053X	\N	\N
17306	575	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	2015-03-02 10:42:04
17307	575	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04084N	\N	2014-09-28 13:40:33
17308	575	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11091R	\N	\N
17309	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
17310	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	2014-09-28 13:21:47
17311	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95055L	\N	2014-09-28 13:21:47
12676	602	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08037X	\N	\N
12677	602	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08017T	\N	\N
12678	602	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08019V	\N	\N
12679	602	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04083M	\N	\N
12680	602	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08011M	\N	\N
12681	602	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
12682	602	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01009N	\N	\N
12683	602	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95055L	\N	\N
12684	602	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
12685	602	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92042S	\N	\N
12686	602	1999-01-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
12687	902	2009-01-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08028W	\N	\N
12688	595	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
12689	532	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04042C	\N	\N
12777	578	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	02003L	\N	\N
12778	578	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08045X	\N	\N
12779	578	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
12780	578	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	\N
12781	578	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08041T	\N	\N
12782	578	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01030K	\N	\N
12783	578	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
12784	578	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
12785	578	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
13968	948	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	09012S	\N	\N
13969	906	2010-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	09012S	\N	\N
8982	534	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
8939	641	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
9207	590	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
8615	577	2004-10-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
4275	641	1998-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95032D	\N	\N
12570	661	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95015C	\N	\N
10717	934	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95015C	\N	\N
9618	626	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95015C	\N	\N
9704	610	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
13430	908	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	06001B	\N	\N
13578	910	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04077P	\N	\N
13581	928	2009-04-01 00:00:00	2013-02-06 00:00:00	ANCIEN	\N	\N	\N	08036W	\N	\N
13723	964	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08058D	\N	\N
13724	964	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92015P	\N	\N
13725	964	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98046X	\N	\N
13726	964	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08033T	\N	\N
13730	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92015P	\N	\N
13731	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
13732	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98046X	\N	\N
13733	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08033T	\N	\N
13734	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08061X	\N	\N
13869	609	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04044E	\N	\N
13922	599	2009-06-25 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
13957	640	2010-01-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
11108	909	2006-09-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	06004E	\N	\N
10274	595	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04079R	\N	\N
11150	968	2006-11-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
10166	634	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
10119	597	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
11399	632	2007-06-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04058L	\N	\N
11709	659	2008-07-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04058L	\N	\N
11120	968	2006-11-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04091M	\N	\N
10128	911	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04091M	\N	\N
10457	915	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04091M	\N	\N
12437	633	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04065K	\N	\N
13427	966	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	\N
13428	908	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	\N
13459	589	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01052R	\N	\N
13460	589	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08024S	\N	\N
13461	589	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
13462	589	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
13463	589	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	\N	\N
13464	589	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92020L	\N	\N
13465	589	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	\N
16348	908	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08027V	\N	2014-09-28 17:34:16
16349	908	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01022K	\N	\N
17312	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	77043E	\N	2014-09-28 16:59:41
17313	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86034E	\N	\N
16414	948	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11097X	\N	\N
16415	948	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11043H	\N	\N
16416	948	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01058X	\N	\N
16417	948	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
16421	910	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08060W	\N	\N
16422	910	2011-10-01 00:00:00	2014-08-26 00:00:00	ANCIEN	\N	\N	\N	11018G	\N	\N
16423	910	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	\N	2014-09-28 17:03:42
16424	910	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11032E	\N	\N
16425	910	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08057C	\N	2014-09-28 14:31:42
16426	910	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11114F	\N	\N
16427	910	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
16428	910	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	92018S	\N	\N
16433	910	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	2014-09-29 13:43:10
16434	910	2011-10-01 00:00:00	2013-12-31 00:00:00	ANCIEN	\N	\N	\N	08023R	\N	\N
16435	910	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08065C	\N	\N
16436	910	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
16439	910	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	\N
16440	910	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
17576	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08011M	\N	\N
17577	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95035G	\N	\N
17578	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
17579	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
17580	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07004J	\N	\N
17581	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08010L	\N	\N
17582	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	\N	\N
17583	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08027V	\N	2014-09-28 17:34:16
17584	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11012A	\N	\N
17585	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
17586	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01062T	\N	\N
17747	589	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	2014-09-28 13:19:48
17748	589	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
17749	589	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11036J	\N	\N
17750	589	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
17751	589	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98036V	\N	2014-09-28 17:15:42
12788	578	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95055L	\N	\N
17752	589	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11061K	\N	\N
17753	589	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
17754	589	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04038G	\N	\N
17755	589	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04047H	\N	\N
17756	589	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	2014-09-28 16:50:17
17757	589	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08040S	\N	2014-09-28 17:52:18
17388	577	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08059E	\N	2014-09-28 17:27:29
17389	577	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08050U	\N	2014-09-28 12:44:31
17390	577	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04056J	\N	\N
17391	577	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	2014-09-28 16:42:05
17392	577	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
17393	577	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	\N
17394	577	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11074Q	\N	\N
17395	577	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
17396	577	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11100Y	\N	\N
17397	578	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95055L	\N	2014-09-28 13:21:47
17398	578	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95032D	\N	2014-09-28 17:07:41
16386	948	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08072B	\N	2014-09-29 09:05:47
16402	948	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	2014-09-28 13:16:32
16429	910	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
16430	910	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11096W	\N	\N
16442	910	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11111C	\N	\N
16446	910	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
16448	910	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
16449	910	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	04090L	\N	\N
16450	910	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
16451	910	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11043H	\N	\N
16452	910	2011-10-01 00:00:00	2014-02-13 00:00:00	ANCIEN	\N	\N	\N	08046Y	\N	\N
18334	612	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	2014-09-28 12:09:44
17901	594	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
17902	591	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
17903	591	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11018G	\N	\N
17904	591	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	2014-09-28 13:19:48
17905	591	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
17906	591	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92018S	\N	\N
17907	591	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
17908	594	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	2014-09-28 17:22:11
17909	594	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	\N	\N
17910	594	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08031R	\N	\N
17911	594	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01007L	\N	\N
18077	602	2011-10-01 00:00:00	2012-07-17 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
18078	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
18079	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08043V	\N	\N
18080	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95035G	\N	\N
18081	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
18082	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	2014-09-28 17:22:11
12789	578	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
18083	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08019V	\N	\N
18084	602	2011-10-01 00:00:00	2013-12-31 00:00:00	ANCIEN	\N	\N	\N	08023R	\N	\N
18085	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08028W	\N	\N
18086	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
18087	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
16935	922	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11095V	\N	\N
16946	948	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
17153	934	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	95015C	\N	\N
17154	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11088W	\N	\N
17155	907	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04091M	\N	2014-09-28 17:55:39
17156	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
18243	609	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11012A	\N	\N
18244	609	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
18245	609	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
18246	609	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	01063U	\N	2014-09-29 13:41:53
18247	609	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01064V	\N	2014-09-28 17:12:41
18248	609	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
18249	609	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	10003H	\N	2014-09-28 17:38:26
18250	609	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
18335	616	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11081P	\N	\N
18336	617	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
18337	617	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
18338	617	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04077P	\N	\N
18339	617	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
18340	618	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11074Q	\N	\N
18341	618	2011-10-01 00:00:00	2014-05-11 00:00:00	ANCIEN	\N	\N	\N	11045K	\N	\N
18342	618	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	2017-10-10 09:45:39
18343	618	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
18344	618	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11057P	\N	\N
18345	618	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11084S	\N	\N
17912	594	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
18838	661	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95055L	\N	2014-09-28 13:21:47
18839	661	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95020Y	\N	\N
16694	909	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08050U	\N	2014-09-28 12:44:31
19009	651	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08071A	\N	2014-09-29 09:08:33
16696	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11048N	\N	\N
19000	651	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
19001	651	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08060W	\N	\N
19002	651	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08063A	\N	2014-09-28 17:07:07
19003	651	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08067E	\N	2014-09-28 17:22:11
19004	651	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08053X	\N	\N
19005	628	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11063M	\N	\N
19006	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
19007	851	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	03001N	\N	2014-09-28 13:40:33
19008	851	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
18489	622	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08045X	\N	2014-09-28 17:00:59
18490	622	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	2014-09-28 19:03:23
18491	619	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
18492	620	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04079R	\N	\N
18493	621	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08048B	\N	\N
18494	621	2011-10-01 00:00:00	2013-02-06 00:00:00	ANCIEN	\N	\N	\N	08036W	\N	\N
18495	621	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	2015-03-02 10:42:04
18496	621	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
18497	622	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04085P	\N	\N
18498	622	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08009T	\N	\N
18499	620	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08039A	\N	\N
18665	625	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
18666	625	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11015D	\N	\N
18667	626	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
18668	626	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04044E	\N	\N
18669	627	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07004J	\N	\N
18670	624	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:21
18671	625	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	\N
18672	625	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11023D	\N	\N
18673	625	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11037K	\N	\N
18674	625	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
18675	626	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	2014-09-28 16:50:17
18840	661	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	77043E	\N	2014-09-28 16:59:41
18841	661	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
18842	643	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11105E	\N	\N
18843	661	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11105E	\N	\N
18844	661	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11080N	\N	\N
18845	661	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11100Y	\N	\N
18846	661	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11054L	\N	\N
18847	663	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11111C	\N	\N
18848	663	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11100Y	\N	\N
18849	661	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	2014-09-28 18:19:47
18850	661	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	83047W	\N	\N
17314	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	2014-09-28 16:40:50
17315	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	2014-09-28 16:50:17
17316	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	83047W	\N	\N
17317	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11035H	\N	\N
17318	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95047L	\N	2014-09-28 17:09:16
17319	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:21
17320	576	2011-10-01 00:00:00	2014-04-24 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
17321	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07024N	\N	\N
12786	578	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08011M	\N	\N
12787	578	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
12790	578	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
12791	578	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
12792	578	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08071A	\N	\N
12793	578	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	05011Y	\N	\N
12794	604	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83011J	\N	\N
12795	604	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95007C	\N	\N
12796	604	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	\N
12797	604	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01049W	\N	\N
12798	604	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01052R	\N	\N
12799	604	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08052W	\N	\N
12800	604	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	77019E	\N	\N
12801	604	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
12802	604	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08042U	\N	\N
12803	604	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08010L	\N	\N
12807	646	2009-02-11 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
12841	629	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01001E	\N	\N
12842	629	2008-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
12843	629	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01049W	\N	\N
12844	629	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01052R	\N	\N
13735	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
13736	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92043T	\N	\N
13797	901	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
13856	651	2009-09-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08067E	\N	\N
13857	651	2009-09-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08050U	\N	\N
13944	933	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08031R	\N	\N
13945	933	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
13946	933	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	\N
13947	933	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08033T	\N	\N
13984	579	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01063U	\N	\N
13985	579	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04058L	\N	\N
13638	615	2009-04-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08058D	\N	\N
13639	615	2009-04-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
13758	966	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08031R	\N	\N
13760	901	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04097T	\N	\N
13860	928	2009-04-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01062T	\N	\N
13769	912	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08034U	\N	\N
13845	911	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08067E	\N	\N
13961	653	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	90003B	\N	\N
13962	653	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
13963	653	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01030K	\N	\N
13964	629	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	\N	\N
13965	629	2010-03-30 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95045J	\N	\N
13466	589	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08035V	\N	\N
13467	589	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08033T	\N	\N
13468	589	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
13469	589	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
13470	589	2008-11-26 00:00:00	2010-04-16 00:00:00	ANCIEN	\N	\N	\N	01039U	\N	\N
13472	589	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08049C	\N	\N
13473	643	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08072B	\N	\N
13474	643	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89013M	\N	\N
13475	643	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01001E	\N	\N
13476	643	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01049W	\N	\N
13477	643	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
13478	643	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	\N
13479	643	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04071H	\N	\N
13480	643	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
13481	643	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
13482	643	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	\N
13422	585	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	\N
13423	585	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
13424	585	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	06001B	\N	\N
13425	585	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01030K	\N	\N
13426	585	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08026U	\N	\N
13436	966	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95060H	\N	\N
13437	980	2009-02-17 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
17322	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
17323	576	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	2014-09-29 13:43:10
17324	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11039M	\N	\N
17325	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11031D	\N	\N
17326	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
16453	910	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11066Q	\N	\N
16454	965	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
16458	907	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	2014-09-28 19:03:04
16459	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08055A	\N	\N
16460	907	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01064V	\N	2014-09-28 17:12:41
16461	907	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04073K	\N	2014-09-28 18:58:25
16462	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11103C	\N	\N
16463	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11044J	\N	\N
16464	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
16465	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	80013X	\N	\N
16466	907	2011-10-01 00:00:00	2014-04-24 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
16467	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04089T	\N	\N
17587	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
17588	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	2014-09-28 12:09:44
17589	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
17590	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01028R	\N	\N
17591	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
17592	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	02053W	\N	2014-09-28 12:32:23
17593	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08053X	\N	\N
17594	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08059E	\N	2014-09-28 17:27:29
17595	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08071A	\N	2014-09-29 09:08:33
17596	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08072B	\N	2014-09-29 09:05:47
17597	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08073C	\N	\N
17758	589	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95035G	\N	\N
17759	589	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	\N	\N
17760	589	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08024S	\N	\N
17761	589	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08028W	\N	\N
17762	589	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08031R	\N	\N
17763	589	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08033T	\N	2014-09-28 17:27:35
17764	589	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01057W	\N	\N
17765	589	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01062T	\N	\N
17766	589	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08049C	\N	2014-09-28 19:07:43
17767	589	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08016S	\N	\N
17768	589	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
17399	578	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	90003B	\N	\N
17400	578	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	2014-09-28 16:50:17
17401	578	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07024N	\N	\N
17402	578	2011-10-01 00:00:00	2014-06-30 00:00:00	ANCIEN	\N	\N	\N	11022C	\N	2014-08-06 16:27:53
17403	578	2011-10-01 00:00:00	2012-02-22 00:00:00	ANCIEN	\N	\N	\N	11010L	\N	\N
17404	578	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98005N	\N	\N
17405	578	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
17406	578	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	2014-09-29 13:43:10
17407	578	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11036J	\N	\N
17408	578	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11025F	\N	\N
17409	578	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
16372	918	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	98027U	\N	\N
16479	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08010L	\N	\N
16480	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08034U	\N	\N
16375	918	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	09012S	\N	\N
16445	910	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08012N	\N	\N
16378	918	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	04090L	\N	\N
16379	918	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11043H	\N	\N
16481	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08053X	\N	\N
16482	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
16483	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08021P	\N	\N
16484	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
16485	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	07034Q	\N	\N
16490	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
16487	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	98021N	\N	\N
16488	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
16489	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	98050T	\N	\N
16491	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
17913	594	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	02002K	\N	\N
17914	594	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04083M	\N	2014-09-28 16:40:50
17915	594	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98041S	\N	2014-09-28 16:42:05
17916	594	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04051D	\N	2014-09-28 17:07:41
17917	594	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
17918	594	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
17919	594	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11111C	\N	\N
17920	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
17921	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07030L	\N	2014-09-28 17:03:42
17922	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95055L	\N	2014-09-28 13:21:47
18088	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89013M	\N	2014-09-28 17:05:42
18089	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01062T	\N	\N
18090	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01041N	\N	\N
18091	602	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	01063U	\N	2014-09-29 13:41:53
18092	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
18093	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08068F	\N	\N
18094	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08067E	\N	2014-09-28 17:22:11
18095	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08065C	\N	\N
18096	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04086Q	\N	\N
18097	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04083M	\N	2014-09-28 16:40:50
18098	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	2014-09-28 16:59:41
18251	609	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
17271	912	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	05008E	\N	\N
18252	609	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95063L	\N	\N
18253	609	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08009T	\N	\N
18254	609	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	2014-09-28 16:42:05
18255	609	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
18256	609	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
18257	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11106F	\N	\N
18258	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
18259	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
18260	608	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11064N	\N	\N
18346	616	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11077T	\N	\N
18347	617	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
18348	618	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
18349	615	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
18350	616	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11114F	\N	\N
18351	618	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11046L	\N	\N
18352	619	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95020Y	\N	\N
18353	617	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95055L	\N	2014-09-28 13:21:47
18354	617	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	2014-09-28 18:03:38
18355	618	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	90003B	\N	\N
18356	618	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
17923	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92020L	\N	\N
17924	598	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	11027H	\N	\N
17925	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95031C	\N	\N
17926	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	2014-09-28 18:03:38
19010	651	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08045X	\N	2014-09-28 17:00:59
19011	651	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	\N
19012	651	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
19013	651	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	09012S	\N	2014-09-28 13:09:05
19014	628	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
19015	628	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
19016	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95039L	\N	\N
19017	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
19018	629	2011-10-01 00:00:00	2013-06-27 00:00:00	ANCIEN	\N	\N	\N	95045J	\N	\N
19019	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86034E	\N	\N
19020	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95031C	\N	\N
18500	621	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04074L	\N	\N
18501	622	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04043D	\N	\N
18502	622	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
18503	619	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08031R	\N	\N
18504	619	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
18505	619	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
18506	620	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01057W	\N	\N
18507	620	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
18508	620	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01028R	\N	\N
18509	621	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11043H	\N	\N
18510	621	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04059M	\N	\N
18676	626	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
18677	626	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	2014-09-28 18:00:58
18678	626	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
18679	627	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
18680	627	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	01063U	\N	2014-09-29 13:41:53
18681	624	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
18682	625	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04042C	\N	\N
18683	626	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08024S	\N	\N
13634	615	2009-04-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98029W	\N	\N
18684	624	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
18685	624	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
18686	625	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98046X	\N	\N
18851	661	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	2014-09-28 13:16:32
18852	661	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07024N	\N	\N
18853	661	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96004D	\N	2015-02-02 16:56:04
18854	661	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11069T	\N	\N
18855	663	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11055M	\N	\N
18856	659	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
18857	659	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
18858	661	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98023Q	\N	\N
18859	661	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
18860	643	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	2014-09-28 13:19:48
18861	643	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
19021	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	2014-09-28 16:40:50
19022	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	90003B	\N	\N
17327	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04038G	\N	\N
17328	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	2014-09-28 16:50:17
17329	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98038X	\N	2014-09-28 17:38:26
17330	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08011M	\N	\N
17331	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	\N	2014-09-28 17:03:42
17332	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
12845	629	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
12846	629	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
12847	629	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08048B	\N	\N
12848	629	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08041T	\N	\N
13483	643	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08065C	\N	\N
13484	643	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	\N
13485	643	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08031R	\N	\N
13487	643	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
13488	643	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01016M	\N	\N
13489	643	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
13490	643	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
13491	643	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
13492	643	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08049C	\N	\N
13494	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	\N
13495	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	\N
13496	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92011K	\N	\N
13497	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08060W	\N	\N
13498	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08050U	\N	\N
13499	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
13500	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	\N
13501	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
13502	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08045X	\N	\N
13503	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
9406	621	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
8878	529	2004-10-15 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
5786	625	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
10926	963	2006-01-24 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
10334	646	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
9313	918	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92020L	\N	\N
7478	918	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92011K	\N	\N
11330	902	2006-10-01 00:00:00	2010-12-14 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
9885	604	2005-02-21 00:00:00	2010-12-14 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
13611	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
13612	954	2008-10-01 00:00:00	2009-09-09 00:00:00	ANCIEN	\N	\N	\N	80024B	\N	\N
13613	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
13635	615	2009-04-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
13636	615	2009-04-28 00:00:00	2010-10-05 00:00:00	ANCIEN	\N	\N	\N	07004J	\N	\N
13637	615	2009-04-28 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08055A	\N	\N
13640	921	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98022P	\N	\N
13955	623	2010-01-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	\N
5555	532	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	98038X	\N	\N
5324	659	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	83021L	\N	\N
5908	611	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	66002K	\N	\N
5715	628	2001-10-01 00:00:00	2004-09-30 00:00:00	ANCIEN	\N	\N	\N	89023P	\N	\N
5817	582	1998-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
13439	908	2008-10-01 00:00:00	2010-11-02 00:00:00	ANCIEN	\N	\N	\N	01026P	\N	\N
13507	964	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08055A	\N	\N
13516	921	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
13517	921	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92011K	\N	\N
13518	921	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08050U	\N	\N
13520	921	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
13521	921	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01050P	\N	\N
13525	978	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
13526	978	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	\N
13527	978	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04087R	\N	\N
13528	978	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
13529	978	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04059M	\N	\N
13530	978	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89013M	\N	\N
13531	978	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08055A	\N	\N
13532	978	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04073K	\N	\N
13533	978	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92013M	\N	\N
13534	978	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08024S	\N	\N
10277	595	2004-10-01 00:00:00	2010-12-14 00:00:00	ANCIEN	\N	\N	\N	92005M	\N	\N
14058	608	2010-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
14060	964	2010-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08012N	\N	\N
14041	912	2010-12-16 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	\N	\N
14067	617	2010-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
14053	912	2011-01-10 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04097T	\N	\N
12948	979	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98050T	\N	\N
12949	979	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
12950	979	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
12951	979	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
12929	957	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08061X	\N	\N
12952	979	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08036W	\N	\N
12954	979	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
12962	909	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
13077	934	2008-10-01 00:00:00	2010-03-15 00:00:00	ANCIEN	\N	\N	\N	08013P	\N	\N
13080	934	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	\N
13079	934	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01024M	\N	\N
13085	934	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08031R	\N	\N
13086	934	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
13087	934	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08012N	\N	\N
13088	934	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	\N
16492	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04044E	\N	\N
16493	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11066Q	\N	\N
16494	965	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11074Q	\N	\N
16495	965	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
16496	965	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
16497	965	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	2014-09-28 13:16:32
16498	965	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
17598	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08047A	\N	\N
17599	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	\N
17600	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04094Q	\N	\N
17601	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
17602	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
17603	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08050U	\N	2014-09-28 12:44:31
17604	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08062Y	\N	\N
17605	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04078Q	\N	\N
17606	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04080J	\N	\N
17607	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04086Q	\N	\N
17608	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95063L	\N	\N
16845	957	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08057C	\N	2014-09-28 14:31:42
17769	589	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04086Q	\N	\N
17770	589	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	2014-09-28 16:59:41
17771	589	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
17772	589	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11111C	\N	\N
17773	589	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11067R	\N	\N
17774	589	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11096W	\N	\N
17775	589	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11110B	\N	\N
17776	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
17777	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95059Q	\N	\N
17778	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95039L	\N	\N
17779	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	77043E	\N	2014-09-28 16:59:41
17410	578	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
17411	578	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98046X	\N	\N
17412	578	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08038Y	\N	\N
17413	578	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
17414	578	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
17415	578	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	01063U	\N	2014-09-29 13:41:53
17416	578	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
17417	578	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08045X	\N	2014-09-28 17:00:59
17418	578	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
17419	578	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04087R	\N	2014-09-28 13:39:21
17420	578	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04043D	\N	\N
16503	965	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04071H	\N	\N
16504	965	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08016S	\N	\N
16505	965	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
16506	965	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
16507	965	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11046L	\N	\N
16508	965	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
16509	965	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08045X	\N	2014-09-28 17:00:59
16515	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11100Y	\N	\N
16516	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08034U	\N	\N
16517	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11068S	\N	\N
16518	906	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	2014-09-28 16:50:17
16519	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
16520	906	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95005A	\N	2014-09-28 17:40:23
16521	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11114F	\N	\N
16523	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11012A	\N	\N
16524	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01058X	\N	\N
16525	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11084S	\N	\N
16526	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04080J	\N	\N
16527	906	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04087R	\N	2014-09-28 13:39:21
16528	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
16537	906	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:21
16538	906	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95019G	\N	2014-09-28 16:59:41
17927	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	87003B	\N	2014-09-28 17:35:38
17928	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:21
17929	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11018G	\N	\N
17930	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	2014-09-28 13:19:48
17931	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07032N	\N	\N
17932	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
17933	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	2014-09-28 17:27:35
18099	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04051D	\N	2014-09-28 17:07:41
18100	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11106F	\N	\N
18101	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11051H	\N	\N
18102	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
18103	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11067R	\N	\N
18104	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11100Y	\N	\N
18105	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
18106	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11069T	\N	\N
18107	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11114F	\N	\N
18108	603	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	2014-09-28 13:21:47
18109	603	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
16350	908	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04094Q	\N	\N
16352	908	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11098Y	\N	\N
16353	908	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
16455	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
16456	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11109J	\N	\N
16457	907	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95005A	\N	2014-09-28 17:40:23
16511	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
16512	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01024M	\N	\N
16532	906	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	2014-09-28 17:40:23
16533	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08016S	\N	\N
16534	906	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08037X	\N	2014-09-28 17:34:16
16655	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08053X	\N	\N
16656	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01025N	\N	\N
16657	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
16663	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11012A	\N	\N
16676	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	\N
16680	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11097X	\N	\N
16682	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01007L	\N	\N
16683	909	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98037W	\N	2014-09-28 14:31:42
16711	948	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04097T	\N	\N
18357	616	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
18358	616	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95047L	\N	2014-09-28 17:09:16
18359	617	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	83047W	\N	\N
18360	617	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95025E	\N	2014-09-28 17:09:16
18361	618	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	2014-09-28 16:50:17
18362	618	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	2014-09-28 13:16:32
18363	618	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:21
18364	618	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
18365	618	2011-10-01 00:00:00	2014-06-30 00:00:00	ANCIEN	\N	\N	\N	11022C	\N	2014-08-06 16:29:20
18366	615	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98029W	\N	\N
18367	615	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
17934	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
17935	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01022K	\N	\N
17936	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01025N	\N	\N
17937	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11039M	\N	\N
17938	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	99004R	\N	\N
17939	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
17940	598	2011-10-01 00:00:00	2014-06-30 00:00:00	ANCIEN	\N	\N	\N	83011J	\N	2014-08-06 16:25:35
17941	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01015L	\N	\N
19023	851	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08060W	\N	\N
19024	628	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11069T	\N	\N
19025	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	2014-09-28 16:50:17
19026	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11030C	\N	\N
19027	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95009E	\N	2014-09-28 12:56:42
19028	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
19029	651	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04043D	\N	\N
19030	651	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
19031	629	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
18511	621	2011-10-01 00:00:00	2014-05-11 00:00:00	ANCIEN	\N	\N	\N	11041F	\N	\N
18512	621	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
18513	622	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11072N	\N	\N
18515	620	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	02053W	\N	2014-09-28 12:32:23
18516	621	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08054Y	\N	2014-09-28 12:39:09
18517	622	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11084S	\N	\N
18518	622	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11085T	\N	\N
18519	622	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11080N	\N	\N
18520	622	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11100Y	\N	\N
18521	622	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
18687	625	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98053W	\N	\N
18688	625	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07034Q	\N	\N
18689	625	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	05008E	\N	\N
18690	626	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11012A	\N	\N
18691	626	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01058X	\N	\N
18692	626	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01007L	\N	\N
18693	626	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	2014-09-28 12:09:44
18694	624	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08034U	\N	\N
18695	625	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	2014-09-28 17:22:11
18696	626	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
18697	626	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08059E	\N	2014-09-28 17:27:29
18862	643	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	2014-09-29 13:43:10
18863	659	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	2014-09-28 18:03:38
18864	659	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:21
18865	661	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
18866	661	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
18867	661	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01027Q	\N	\N
18868	663	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95025E	\N	2014-09-28 17:09:16
18869	643	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11034G	\N	\N
18870	643	2011-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	2017-07-21 09:12:41
18871	659	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98024R	\N	\N
18872	659	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
16844	957	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11053K	\N	\N
16719	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11059R	\N	\N
16863	957	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11077T	\N	\N
16957	919	2011-10-01 00:00:00	2014-12-18 00:00:00	ANCIEN	\N	\N	\N	01062T	\N	2014-12-18 16:15:04
16722	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08053X	\N	\N
16958	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
16959	919	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	2014-09-28 16:42:05
16960	919	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08045X	\N	2014-09-28 17:00:59
16868	957	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
16869	957	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08021P	\N	\N
16961	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
13089	934	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08033T	\N	\N
13090	934	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
13091	934	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07023M	\N	\N
13104	911	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08061X	\N	\N
13106	911	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
13107	911	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92042S	\N	\N
13108	911	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01050P	\N	\N
13109	911	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
13504	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97004H	\N	\N
13505	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04069P	\N	\N
13506	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
13508	964	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92011K	\N	\N
13509	964	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08050U	\N	\N
13511	964	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08016S	\N	\N
13535	978	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
13536	978	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92018S	\N	\N
13537	978	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
13538	978	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	\N
13539	978	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
13540	978	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
13541	978	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
13542	978	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01007L	\N	\N
13543	978	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
13544	978	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04075M	\N	\N
13545	978	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	06001B	\N	\N
13546	978	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08067E	\N	\N
13547	978	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01021J	\N	\N
13548	978	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08031R	\N	\N
13549	978	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98038X	\N	\N
13550	978	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
13551	978	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
6458	851	2002-12-01 00:00:00	2004-09-01 00:00:00	ANCIEN	\N	\N	\N	89037V	\N	\N
7474	918	2001-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	84004P	\N	\N
8636	581	2004-11-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	01040M	\N	\N
8659	913	2004-10-01 00:00:00	2008-09-30 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	\N
8498	951	2003-10-01 00:00:00	2005-03-01 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	\N
13579	928	2009-04-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
13619	674	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
13620	674	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
13621	591	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08064B	\N	\N
13622	591	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01028R	\N	\N
13628	921	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	82002D	\N	\N
13629	964	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	\N	\N
13630	964	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	\N
13766	584	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07023M	\N	\N
13793	947	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08050U	\N	\N
13892	938	2009-10-27 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	05001W	\N	\N
13932	573	2010-01-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	10001F	\N	\N
13940	933	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
13949	933	2009-03-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
9645	626	2004-10-01 00:00:00	2010-10-18 00:00:00	ANCIEN	\N	\N	\N	92029V	\N	\N
9111	632	2004-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95011X	\N	\N
7417	922	2001-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95013A	\N	\N
10878	964	2006-01-31 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
14049	674	2010-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	\N	\N
14061	530	2010-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07030L	\N	\N
14025	642	2010-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04095R	\N	\N
14024	577	2010-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
14073	909	2011-03-09 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	10007M	\N	\N
14031	534	2010-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08064B	\N	\N
14032	632	2010-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01014K	\N	\N
14051	912	2010-12-21 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01033N	\N	\N
14029	661	2010-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04083M	\N	\N
14030	598	2010-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04061F	\N	\N
14054	609	2010-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
14055	603	2010-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
14056	904	2010-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01025N	\N	\N
14028	608	2010-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96004D	\N	2015-02-02 16:43:25
14042	594	2010-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
14043	964	2010-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98021N	\N	\N
14044	634	2010-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
14046	641	2010-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
14047	584	2010-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
14036	598	2010-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07032N	\N	\N
14023	625	2010-09-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04042C	\N	\N
14026	653	2010-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
14048	588	2010-11-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
13150	918	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04087R	\N	\N
13151	918	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08050U	\N	\N
13152	918	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	\N
13153	918	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
13154	918	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08012N	\N	\N
13155	918	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	\N
13078	934	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98024R	\N	\N
13092	934	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	\N
13093	934	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07032N	\N	\N
13095	934	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08070Y	\N	\N
13096	934	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
13097	934	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
13098	934	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
13099	934	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08049C	\N	\N
13100	934	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04039H	\N	\N
13101	911	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08010L	\N	\N
13102	911	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
13103	911	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	\N
13105	911	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	07032N	\N	\N
16539	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
16540	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04094Q	\N	\N
17609	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08009T	\N	\N
17610	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04083M	\N	2014-09-28 16:40:50
17611	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04091M	\N	2014-09-28 17:55:39
17612	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	2014-09-28 16:42:05
17613	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11044J	\N	\N
17614	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
17615	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04069P	\N	2014-09-28 17:31:42
17616	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
17617	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04071H	\N	\N
17618	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11074Q	\N	\N
17619	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11068S	\N	\N
17780	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
17781	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
17782	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	2014-09-28 16:50:17
17783	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	83047W	\N	\N
17784	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
17785	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
17786	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	2014-09-28 17:27:35
17787	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
17788	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11015D	\N	\N
17789	590	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	2014-09-29 13:43:10
17790	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98021N	\N	\N
17421	578	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04059M	\N	\N
17422	578	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11072N	\N	\N
17423	578	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
17424	578	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11100Y	\N	\N
17425	578	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11055M	\N	\N
17426	578	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11112D	\N	\N
17427	576	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11098Y	\N	\N
17428	577	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
17429	577	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95055L	\N	2014-09-28 13:21:47
17430	577	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	11027H	\N	\N
17431	577	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11091R	\N	\N
16541	906	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	09012S	\N	2014-09-28 13:09:05
16542	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	90003B	\N	\N
16543	906	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	2014-09-29 13:43:10
16544	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	\N
16547	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
16548	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
16549	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04061F	\N	\N
16550	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	80013X	\N	\N
16551	906	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04069P	\N	2014-09-28 17:31:42
16552	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04071H	\N	\N
16553	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
16554	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11088W	\N	\N
16555	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
16556	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	98050T	\N	\N
16557	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11094U	\N	\N
16558	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
16559	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
16560	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11096W	\N	\N
16561	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
16562	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
16563	906	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	2014-09-28 18:03:38
16564	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
16565	965	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11029K	\N	\N
16566	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11066Q	\N	\N
16567	906	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08050U	\N	2014-09-28 12:44:31
17942	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11061K	\N	\N
17943	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
17944	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
18110	603	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	2014-09-28 16:40:50
18111	603	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
18112	603	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11048N	\N	\N
18113	603	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07032N	\N	\N
18114	603	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
18115	603	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
18116	603	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04033B	\N	\N
18117	603	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
18118	603	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
18119	603	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08062Y	\N	\N
18120	601	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08063A	\N	2014-09-28 17:07:07
16363	918	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	95015C	\N	\N
16431	910	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11022C	\N	\N
16522	906	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	2014-09-28 17:27:35
16582	911	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	98021N	\N	\N
16715	965	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04056J	\N	\N
16727	919	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	\N	2014-09-28 17:03:42
16728	919	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08057C	\N	2014-09-28 14:31:42
16996	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11069T	\N	\N
16730	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04034C	\N	\N
16818	913	2011-10-01 00:00:00	2014-04-24 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
16819	913	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11096W	\N	\N
16824	913	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08009T	\N	\N
16825	913	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
16826	913	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
16827	913	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	2014-09-28 17:27:35
16828	913	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11046L	\N	\N
16853	957	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
16854	957	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95036H	\N	2014-09-28 17:31:42
16855	957	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04097T	\N	\N
16856	957	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11048N	\N	\N
16992	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
16999	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
18368	616	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
18369	616	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11048N	\N	\N
18370	617	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
18371	617	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	2014-09-28 17:27:35
18372	618	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
18373	616	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
18374	617	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01025N	\N	\N
18375	618	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
18376	615	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	2014-09-28 19:03:04
18377	616	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
18378	616	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04038G	\N	\N
17945	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04042C	\N	\N
17946	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
17947	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
17948	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	\N	\N
17949	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08024S	\N	\N
17950	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	06004E	\N	2014-09-28 17:03:42
17951	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
17952	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01058X	\N	\N
17953	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
17954	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	2014-09-28 12:09:44
17955	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
16737	919	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	06005F	\N	2014-09-28 13:32:35
16738	919	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	2014-09-28 16:50:17
16739	919	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95030B	\N	2014-09-28 17:55:37
16740	919	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	2014-09-29 13:43:10
16873	957	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
16748	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
16749	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08062Y	\N	\N
16874	919	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	2014-09-28 13:19:48
16751	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11088W	\N	\N
16752	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11090Q	\N	\N
16875	957	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
18522	622	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11069T	\N	\N
18523	619	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
18524	620	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	2014-09-28 19:03:23
18525	620	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04084N	\N	2014-09-28 13:40:33
18526	621	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11101A	\N	\N
18527	621	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
18528	622	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11114F	\N	\N
18529	622	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11046L	\N	\N
18530	622	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11098Y	\N	\N
18531	620	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04083M	\N	2014-09-28 16:40:50
18532	620	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04059M	\N	\N
18698	624	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	\N	2014-09-28 17:03:42
18699	624	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
18700	624	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07004J	\N	\N
18701	625	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01062T	\N	\N
18702	632	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04056J	\N	\N
18703	632	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
18704	640	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
18705	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	2014-09-28 13:21:47
18706	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92020L	\N	\N
18707	643	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	90003B	\N	\N
18708	643	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	2014-09-28 13:16:32
18873	659	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	2014-09-28 17:27:35
18874	661	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95019G	\N	2014-09-28 16:59:41
18875	663	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:21
18876	663	2011-10-01 00:00:00	2012-02-22 00:00:00	ANCIEN	\N	\N	\N	11010L	\N	\N
18877	643	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
18878	659	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
18879	659	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	2014-09-29 13:43:10
18880	661	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
18881	661	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
18882	663	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98005N	\N	\N
18883	663	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
16701	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11044J	\N	\N
16865	957	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08062Y	\N	\N
16703	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11061K	\N	\N
16955	919	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	2014-09-28 17:22:11
16705	910	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	2014-09-28 16:59:41
16706	908	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	2014-09-28 16:59:41
16708	965	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	2014-09-28 19:03:04
16709	965	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08050U	\N	2014-09-28 12:44:31
16710	965	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11101A	\N	\N
16712	908	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08071A	\N	2014-09-29 09:08:33
16754	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04038G	\N	\N
16755	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11094U	\N	\N
16756	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11096W	\N	\N
16956	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
16962	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
16763	919	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	11027H	\N	\N
16764	919	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08040S	\N	2014-09-28 17:52:18
16877	957	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11090Q	\N	\N
13130	576	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04091M	\N	\N
13131	576	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	89013M	\N	\N
13132	576	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08024S	\N	\N
13134	576	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92018S	\N	\N
13552	978	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08011M	\N	\N
13553	978	2008-11-26 00:00:00	2010-12-13 00:00:00	ANCIEN	\N	\N	\N	07027R	\N	\N
13554	978	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08021P	\N	\N
13555	978	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08073C	\N	\N
13556	978	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98021N	\N	\N
13557	978	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	\N
13558	978	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	\N
13559	978	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
13432	908	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01033N	\N	\N
13433	908	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01022K	\N	\N
13434	908	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	83047W	\N	\N
13512	964	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
13513	964	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
13514	964	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	\N
13515	964	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08049C	\N	\N
13519	921	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
13522	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	\N
13524	954	2008-10-01 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
13560	978	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	01050P	\N	\N
13561	978	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	97005J	\N	\N
13562	978	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	\N
13563	978	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	92045V	\N	\N
13564	978	2008-11-26 00:00:00	2011-09-30 00:00:00	ANCIEN	\N	\N	\N	08036W	\N	\N
17813	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01028R	\N	\N
17814	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	02002K	\N	\N
17815	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
17816	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08025T	\N	\N
17818	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08073C	\N	\N
17819	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08047A	\N	\N
17820	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
17821	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
17822	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
17823	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95063L	\N	\N
16943	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	95063L	\N	\N
17191	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
17079	906	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08054Y	\N	2014-09-28 12:39:09
17080	906	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08033T	\N	2014-09-28 17:27:35
17213	992	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
17214	992	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04087R	\N	2014-09-28 13:39:21
17219	992	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08060W	\N	\N
17220	992	2012-01-25 00:00:00	2014-08-26 00:00:00	ANCIEN	\N	\N	\N	11018G	\N	\N
17249	992	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08063A	\N	2014-09-28 17:07:07
17250	992	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08053X	\N	\N
17251	992	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
17252	992	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
17253	992	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	09012S	\N	2014-09-28 13:09:05
17443	579	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	01063U	\N	2014-09-29 13:41:53
17444	579	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
17445	579	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04069P	\N	2014-09-28 17:31:42
17446	580	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11035H	\N	\N
16613	911	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	2014-09-28 16:42:05
16614	911	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	07032N	\N	\N
16615	911	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11096W	\N	\N
16616	911	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	2015-01-08 17:14:29
16617	911	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
16618	911	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	2014-09-28 18:03:38
16619	911	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08050U	\N	2014-09-28 12:44:31
16620	911	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
16621	911	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	2014-09-28 19:03:23
16622	911	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
16623	948	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	77043E	\N	2014-09-28 16:59:41
16624	922	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	95035G	\N	\N
16630	922	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	\N
16631	922	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11107G	\N	\N
16632	922	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08055A	\N	\N
16633	922	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04069P	\N	2014-09-28 17:31:42
16634	922	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08072B	\N	2014-09-29 09:05:47
16635	922	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	\N
16636	922	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
16640	922	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98036V	\N	2014-09-28 17:15:42
16641	922	2011-10-01 00:00:00	2014-12-18 00:00:00	ANCIEN	\N	\N	\N	01062T	\N	2014-12-18 16:15:04
16642	922	2011-10-01 00:00:00	2013-12-31 00:00:00	ANCIEN	\N	\N	\N	08023R	\N	\N
16643	922	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11044J	\N	\N
16644	922	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04044E	\N	\N
17642	584	2011-10-01 00:00:00	2013-06-27 00:00:00	ANCIEN	\N	\N	\N	95045J	\N	\N
17620	584	2011-10-01 00:00:00	2014-05-11 00:00:00	ANCIEN	\N	\N	\N	11045K	\N	\N
17621	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
17622	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11106F	\N	\N
17623	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
17624	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11084S	\N	\N
17625	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11085T	\N	\N
17626	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11100Y	\N	\N
17627	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
17628	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11069T	\N	\N
17629	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11095V	\N	\N
17630	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11108H	\N	\N
17791	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95019G	\N	2014-09-28 16:59:41
17792	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11061K	\N	\N
17793	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
17794	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
17795	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
17796	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04044E	\N	\N
17797	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04047H	\N	\N
17798	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
17799	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98046X	\N	\N
17800	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89029V	\N	\N
17801	591	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
17432	579	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
17433	579	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	2014-09-28 12:56:42
17434	579	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
17435	579	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
17436	579	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
17437	579	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
17438	579	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
17439	579	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
17440	579	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08010L	\N	\N
17441	579	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08012N	\N	\N
17442	579	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
16568	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
16569	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11048N	\N	\N
16570	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
16571	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	98029W	\N	\N
16572	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
16573	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	02002K	\N	\N
16574	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04089T	\N	\N
16583	911	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
16576	906	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	2014-09-28 19:03:23
16577	965	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04033B	\N	\N
16584	911	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	05008E	\N	\N
16585	911	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01022K	\N	\N
16586	911	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
16587	911	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08034U	\N	\N
16592	911	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	2014-09-28 12:56:42
16593	911	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	09012S	\N	2014-09-28 13:09:05
16594	911	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04073K	\N	2014-09-28 18:58:25
16595	911	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08045X	\N	2014-09-28 17:00:59
16596	911	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	2014-09-28 16:50:17
16597	911	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11111C	\N	\N
16598	911	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95030B	\N	2014-09-28 17:55:37
16609	911	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11090Q	\N	\N
16610	910	2011-10-01 00:00:00	2013-02-06 00:00:00	ANCIEN	\N	\N	\N	08036W	\N	\N
16611	911	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
16612	948	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	98024R	\N	\N
17631	585	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	2014-09-28 13:21:47
18121	602	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	04090L	\N	\N
18122	602	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04094Q	\N	\N
18123	603	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04069P	\N	2014-09-28 17:31:42
18124	603	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
18125	603	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
18126	604	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04091M	\N	2014-09-28 17:55:39
18127	604	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95039L	\N	\N
18128	604	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95036H	\N	2014-09-28 17:31:42
18129	604	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11029K	\N	\N
18130	604	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
18131	604	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
16816	913	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	11027H	\N	\N
16817	913	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
16916	913	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04033B	\N	\N
16933	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11110B	\N	\N
16927	957	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08038Y	\N	\N
16932	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11095V	\N	\N
16934	907	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08033T	\N	2014-09-28 17:27:35
17001	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11069T	\N	\N
17002	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	\N
17010	966	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	05008E	\N	\N
17011	966	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	2014-09-28 19:03:04
17024	966	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	\N
17025	966	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
17087	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11108H	\N	\N
17088	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	98029W	\N	\N
17089	965	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01044R	\N	\N
17090	913	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11036J	\N	\N
17091	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11036J	\N	\N
17092	957	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11036J	\N	\N
17093	934	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01044R	\N	\N
17098	934	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08065C	\N	\N
17099	934	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04059M	\N	\N
17110	904	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11074Q	\N	\N
18379	617	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11061K	\N	\N
18380	617	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
18381	617	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
18382	618	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
18383	618	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
18384	618	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04044E	\N	\N
18385	618	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
18386	618	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	\N	\N
18387	618	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98046X	\N	\N
18388	615	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
18389	616	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	2014-09-28 18:00:58
17956	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08063A	\N	2014-09-28 17:07:07
17957	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08067E	\N	2014-09-28 17:22:11
17958	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08065C	\N	\N
17959	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	02053W	\N	2014-09-28 12:32:23
17960	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	2014-09-28 19:03:23
17961	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04084N	\N	2014-09-28 13:40:33
17962	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
17963	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	2014-09-28 16:59:41
17964	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04065K	\N	2014-09-28 17:31:42
17965	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
17966	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04059M	\N	\N
18132	604	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
18133	604	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
16766	919	2011-10-01 00:00:00	2014-08-26 00:00:00	ANCIEN	\N	\N	\N	11018G	\N	\N
16767	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11095V	\N	\N
16768	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
16769	919	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	2014-09-28 12:56:42
16963	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
18533	620	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04061F	\N	\N
18534	620	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04066L	\N	\N
18535	621	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11069T	\N	\N
18536	621	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11107G	\N	\N
18537	621	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11093T	\N	\N
18538	622	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
18539	622	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	2014-09-28 13:21:47
18540	622	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95055L	\N	2014-09-28 13:21:47
18541	623	2011-10-01 00:00:00	2013-06-27 00:00:00	ANCIEN	\N	\N	\N	95045J	\N	\N
18542	623	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	2014-09-28 16:50:17
18543	623	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
18709	643	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95047L	\N	2014-09-28 17:09:16
18710	643	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:21
18711	632	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04059M	\N	\N
18712	632	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04077P	\N	\N
18713	632	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11033F	\N	\N
18714	632	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11049P	\N	\N
16965	919	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	2014-09-28 13:21:47
18715	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	2014-09-28 18:03:38
18716	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
18717	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	2014-09-28 13:16:32
18718	643	2011-10-01 00:00:00	2014-04-24 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
18719	643	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
18884	643	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	2014-09-28 16:50:17
18885	643	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08011M	\N	\N
18886	659	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11061K	\N	\N
18887	659	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
18888	659	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04044E	\N	\N
18889	661	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08011M	\N	\N
18890	663	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11061K	\N	\N
18891	643	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
18892	643	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
18893	643	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08015R	\N	2017-10-10 11:04:14
18894	643	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08017T	\N	\N
16438	910	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	2014-09-28 17:40:23
16441	910	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04094Q	\N	\N
16443	910	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08010L	\N	\N
16444	910	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11098Y	\N	\N
16447	910	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
16468	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08022Q	\N	\N
16469	907	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	87003B	\N	2014-09-28 17:35:38
16470	907	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	2014-09-28 19:03:23
16471	907	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98041S	\N	2014-09-28 16:42:05
16472	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01007L	\N	\N
16473	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01057W	\N	\N
16474	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08016S	\N	\N
16475	907	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	2014-09-28 17:40:23
16476	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11048N	\N	\N
16477	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	86034E	\N	\N
16478	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04094Q	\N	\N
16499	965	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	2014-09-28 16:40:50
16500	965	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08039A	\N	\N
16501	965	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
16502	965	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98037W	\N	2014-09-28 14:31:42
16530	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	98021N	\N	\N
16685	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01046T	\N	\N
17643	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86034E	\N	\N
17644	585	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
17645	585	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
17646	585	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
17647	585	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
17648	585	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08014Q	\N	\N
17649	585	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
17650	585	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	2014-09-28 17:22:11
17651	585	2011-10-01 00:00:00	2013-12-31 00:00:00	ANCIEN	\N	\N	\N	95003X	\N	\N
17652	585	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
17824	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	2014-09-28 16:59:41
17825	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11044J	\N	\N
17826	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
17827	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04077P	\N	\N
17828	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11106F	\N	\N
17829	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
17830	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11084S	\N	\N
17831	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11082Q	\N	\N
17832	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11067R	\N	\N
17833	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11096W	\N	\N
17834	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11110B	\N	\N
16994	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11101A	\N	\N
17003	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08015R	\N	\N
17004	907	2011-10-01 00:00:00	2014-02-13 00:00:00	ANCIEN	\N	\N	\N	08046Y	\N	\N
17076	934	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
17082	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
17084	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04055H	\N	\N
17085	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08038Y	\N	\N
17447	580	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
17448	580	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11059R	\N	\N
17449	580	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	\N
17450	580	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01015L	\N	\N
17451	580	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
17452	580	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
17453	580	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
16645	922	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11094U	\N	\N
16646	922	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04089T	\N	\N
16857	957	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	03001N	\N	2014-09-28 13:40:33
16654	909	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08063A	\N	2014-09-28 17:07:07
16713	948	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11059R	\N	\N
16714	965	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11048N	\N	\N
16858	957	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
16859	957	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11059R	\N	\N
16733	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	80013X	\N	\N
16860	957	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
16741	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04094Q	\N	\N
16742	919	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	09012S	\N	2014-09-28 13:09:05
16743	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08055A	\N	\N
16758	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11048N	\N	\N
16862	957	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
16904	910	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
16761	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11111C	\N	\N
16785	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11012A	\N	\N
16793	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	96004D	\N	\N
16800	911	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08042U	\N	\N
16801	911	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04044E	\N	\N
17653	585	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08053X	\N	\N
17654	585	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08066D	\N	2014-09-28 19:03:23
17655	585	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08026U	\N	2014-09-28 17:52:18
17656	585	2011-10-01 00:00:00	2013-02-28 00:00:00	ANCIEN	\N	\N	\N	11062L	\N	\N
17657	585	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
17632	585	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95055L	\N	2014-09-28 13:21:47
17633	585	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95020Y	\N	\N
17634	585	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
17635	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95059Q	\N	\N
17636	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	2014-09-28 13:21:47
17637	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95055L	\N	2014-09-28 13:21:47
17638	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	77058M	\N	2014-09-28 12:52:11
17639	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95020Y	\N	\N
17640	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95015C	\N	\N
17641	584	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92020L	\N	\N
17802	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08042U	\N	\N
17803	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08011M	\N	\N
17804	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	2014-09-28 17:22:11
17805	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08010L	\N	2017-10-04 12:51:44
17806	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	\N	\N
17807	590	2011-10-01 00:00:00	2013-12-31 00:00:00	ANCIEN	\N	\N	\N	08023R	\N	\N
17808	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08031R	\N	\N
17809	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
17810	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01062T	\N	\N
17811	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	2014-09-28 12:09:44
17812	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
18423	618	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	2014-09-28 16:59:41
18424	616	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95063L	\N	\N
18425	617	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
18426	618	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	2014-09-28 16:42:05
18427	618	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	\N
18428	618	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
18429	618	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	\N
18430	616	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
18431	621	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
18432	622	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
18433	623	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	2014-09-28 16:50:17
17989	599	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
17990	599	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
17991	599	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	2014-09-29 13:43:10
17992	599	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	\N
17993	599	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
17994	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89029V	\N	\N
17995	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	2014-09-28 19:03:04
17996	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08038Y	\N	\N
17997	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95035G	\N	\N
17998	599	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08060W	\N	\N
17999	599	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	09012S	\N	2014-09-28 13:09:05
16983	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11105E	\N	\N
16984	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08024S	\N	\N
17077	911	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	\N
17187	966	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	\N
17203	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04048J	\N	\N
17254	992	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:21
18134	604	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98021N	\N	\N
16881	957	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	10015M	\N	\N
18135	604	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	\N
18136	604	2011-10-01 00:00:00	2014-06-30 00:00:00	ANCIEN	\N	\N	\N	83011J	\N	2014-08-06 16:26:08
18137	604	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04034C	\N	\N
18138	604	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
18139	604	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04044E	\N	\N
18140	604	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
18141	604	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	2014-09-28 18:00:58
18142	604	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08042U	\N	\N
16529	906	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	2014-09-28 16:50:17
16531	906	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08059E	\N	2014-09-28 17:27:29
16535	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	\N
16536	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
16588	911	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
16637	922	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11048N	\N	\N
16638	922	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11096W	\N	\N
16639	922	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
16666	909	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04073K	\N	2014-09-28 18:58:25
16667	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08055A	\N	\N
16905	948	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
16669	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11107G	\N	\N
16670	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08016S	\N	\N
16671	909	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08057C	\N	2014-09-28 14:31:42
16917	957	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	95063L	\N	\N
16674	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	10015M	\N	\N
16925	907	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	10003H	\N	2014-09-28 17:38:26
16677	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08010L	\N	\N
16930	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
16679	909	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04069P	\N	2014-09-28 17:31:42
16689	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
16690	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11096W	\N	\N
16950	911	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
18390	616	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95035G	\N	\N
18391	618	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08015R	\N	\N
18392	616	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	05008E	\N	\N
18393	616	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	2014-09-28 17:22:11
18394	616	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
18395	617	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08015R	\N	\N
18396	617	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08039A	\N	\N
18397	617	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08031R	\N	\N
18398	617	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
18399	618	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01034P	\N	\N
18400	616	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11012A	\N	\N
17967	598	2011-10-01 00:00:00	2014-05-11 00:00:00	ANCIEN	\N	\N	\N	11041F	\N	\N
17968	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04061F	\N	\N
17969	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04069P	\N	2014-09-28 17:31:42
17970	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
17971	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04077P	\N	\N
17972	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08026U	\N	2014-09-28 17:52:18
17973	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11049P	\N	\N
17974	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
17975	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
16780	919	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04046G	\N	2014-09-28 17:07:41
17976	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11084S	\N	\N
17977	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11085T	\N	\N
18143	604	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95035G	\N	\N
18144	604	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01059Y	\N	\N
18145	604	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08017T	\N	\N
18146	604	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08010L	\N	\N
18544	620	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04077P	\N	\N
18545	620	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11049P	\N	\N
18546	620	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	2017-10-10 09:45:39
18547	622	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	11027H	\N	\N
18548	623	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	2014-09-28 13:16:32
18549	623	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	2014-09-28 12:56:42
18550	623	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:21
18551	620	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
18552	620	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11077T	\N	\N
18553	620	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
18554	622	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	2014-09-28 18:19:47
18720	643	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
18721	643	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98023Q	\N	\N
18722	632	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
18723	632	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
18724	641	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95032D	\N	2014-09-28 17:07:41
18725	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95047L	\N	2014-09-28 17:09:16
18726	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:21
18727	642	2011-10-01 00:00:00	2014-04-24 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
18728	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96004D	\N	2015-02-02 16:56:12
18729	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
18730	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98023Q	\N	\N
18895	659	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	\N	2014-09-28 17:03:42
18896	659	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	05008E	\N	\N
18897	661	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07004J	\N	\N
18898	643	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11012A	\N	\N
18899	643	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
18900	643	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	2014-09-28 12:09:44
18901	643	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
18902	659	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
18903	661	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
18904	643	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08031R	\N	\N
18905	643	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	03001N	\N	2014-09-28 13:40:33
16879	957	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
16688	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01057W	\N	\N
16772	919	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	2014-09-28 19:03:04
16773	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	95015C	\N	\N
16777	919	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08063A	\N	2014-09-28 17:07:07
16781	919	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04051D	\N	2014-09-28 17:07:41
16782	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01028R	\N	\N
16913	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11014C	\N	\N
16914	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08061X	\N	\N
16954	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	\N
16953	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11107G	\N	\N
16790	919	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	2014-09-28 16:40:50
16964	919	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	87003B	\N	2014-09-28 17:35:38
16794	906	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04083M	\N	2014-09-28 16:40:50
16795	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11059R	\N	\N
16796	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04097T	\N	\N
16797	906	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	77043E	\N	2014-09-28 16:59:41
16798	911	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04097T	\N	\N
16799	911	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	2014-09-28 13:19:48
18555	622	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	2014-09-28 13:16:32
18556	622	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	2014-09-28 12:56:42
18557	622	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:21
17658	585	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
17659	586	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	2014-09-28 13:21:47
17660	586	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92020L	\N	\N
17661	586	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	2014-09-28 18:19:47
17662	586	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:21
17663	586	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
17835	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11114F	\N	\N
17836	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11093T	\N	\N
17837	591	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	90004C	\N	2014-09-28 13:21:47
17838	591	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95020Y	\N	\N
17839	591	2011-10-01 00:00:00	2013-06-27 00:00:00	ANCIEN	\N	\N	\N	95045J	\N	\N
17840	589	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	11027H	\N	\N
17841	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	2014-09-28 13:16:32
17842	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07024N	\N	\N
17843	590	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96004D	\N	2015-02-02 16:43:25
17844	591	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
17845	591	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11023D	\N	\N
16997	919	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98037W	\N	2014-09-28 14:31:42
16998	919	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:21
17008	957	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08055A	\N	\N
17454	580	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01042P	\N	\N
17455	580	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
17456	580	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	01063U	\N	2014-09-29 13:41:53
17457	580	2011-10-01 00:00:00	2012-06-16 00:00:00	ANCIEN	\N	\N	\N	11003M	\N	\N
17458	580	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04051D	\N	2014-09-28 17:07:41
17459	580	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11049P	\N	\N
17460	580	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
17461	578	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11091R	\N	\N
17462	579	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	77043E	\N	2014-09-28 16:59:41
16802	911	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	2014-09-28 16:59:41
16815	913	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11114F	\N	\N
16906	948	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	2014-09-28 18:19:47
16907	948	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	95063L	\N	\N
16908	908	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	98046X	\N	\N
16911	918	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
16912	918	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08059E	\N	2014-09-28 17:27:29
17031	934	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11043H	\N	\N
17032	934	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08012N	\N	\N
17033	934	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11098Y	\N	\N
17034	934	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	2014-09-28 16:40:50
17035	934	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	2014-09-28 13:19:48
17036	934	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	87003B	\N	2014-09-28 17:35:38
17038	934	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08031R	\N	\N
17039	934	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
17040	934	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11105E	\N	\N
17041	934	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	83047W	\N	\N
17042	934	2011-10-01 00:00:00	2014-12-18 00:00:00	ANCIEN	\N	\N	\N	01062T	\N	2014-12-18 16:15:04
17094	934	2011-10-01 00:00:00	2013-02-06 00:00:00	ANCIEN	\N	\N	\N	08036W	\N	\N
17095	966	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08039A	\N	\N
17096	966	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08031R	\N	\N
17097	966	2011-10-01 00:00:00	2013-02-06 00:00:00	ANCIEN	\N	\N	\N	08036W	\N	\N
17664	586	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	2014-09-28 18:00:58
17665	586	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95037J	\N	\N
17666	979	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07024N	\N	\N
17667	586	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
17668	586	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
17669	586	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
17670	586	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95063L	\N	\N
17671	586	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11068S	\N	\N
18165	605	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
18166	605	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11030C	\N	\N
18167	605	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
18168	605	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01014K	\N	\N
18169	605	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01022K	\N	\N
18170	605	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	2014-09-28 18:00:58
18171	605	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	\N	2014-09-28 17:03:42
18172	605	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
17122	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11036J	\N	\N
17133	991	2011-12-14 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
17125	928	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	2014-09-29 13:43:10
17126	928	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08037X	\N	\N
17127	928	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
17134	991	2011-12-14 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11109J	\N	\N
17135	991	2011-12-14 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01044R	\N	\N
17136	991	2011-12-14 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08043V	\N	\N
17137	991	2011-12-14 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08024S	\N	\N
17138	991	2011-12-14 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	2014-09-28 13:19:48
17139	991	2011-12-14 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11014C	\N	\N
17140	991	2011-12-14 00:00:00	2014-02-13 00:00:00	ANCIEN	\N	\N	\N	08046Y	\N	\N
17150	991	2011-12-14 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11104D	\N	\N
17163	904	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11108H	\N	\N
17164	904	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11091R	\N	\N
17165	904	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
17171	934	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11089X	\N	\N
17206	904	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:21
17231	992	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	2014-09-28 16:40:50
17232	992	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08038Y	\N	\N
17236	992	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	2014-09-28 13:19:48
17237	992	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	87003B	\N	2014-09-28 17:35:38
17238	992	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95028H	\N	2014-09-28 12:56:42
18434	620	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07030L	\N	2014-09-28 17:03:42
17049	909	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	\N	2014-09-28 17:03:42
18435	620	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95055L	\N	2014-09-28 13:21:47
18436	621	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
18437	622	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
18438	622	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04034C	\N	\N
18439	622	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
18440	622	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
18441	622	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	2014-09-28 16:50:17
18442	623	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	\N	2014-09-28 17:03:42
18443	623	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
18444	623	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08017T	\N	\N
18000	599	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08055A	\N	\N
18001	599	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89007P	\N	2014-09-28 16:42:05
18002	599	2011-10-01 00:00:00	2013-02-28 00:00:00	ANCIEN	\N	\N	\N	11062L	\N	\N
18003	599	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
18004	600	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	2014-09-28 17:40:23
18005	600	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
18006	600	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92031P	\N	\N
18007	600	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	2014-09-28 16:50:17
18008	600	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	83047W	\N	\N
18009	600	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	2014-09-28 13:16:32
18010	600	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95047L	\N	2014-09-28 17:09:16
17190	906	2011-10-01 00:00:00	2012-03-31 00:00:00	ANCIEN	\N	\N	\N	11049P	\N	\N
17212	912	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
18173	605	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	03001N	\N	2014-09-28 13:40:33
18174	605	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01057W	\N	\N
18175	605	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
18176	605	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
18147	604	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01046T	\N	\N
18148	604	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
18149	604	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	02053W	\N	2014-09-28 12:32:23
18150	604	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08016S	\N	\N
18151	604	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
18152	604	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08052W	\N	\N
18153	604	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95063L	\N	\N
16924	910	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08055A	\N	\N
16929	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04079R	\N	\N
16948	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11095V	\N	\N
16951	911	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04091M	\N	2014-09-28 17:55:39
16971	919	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89022N	\N	2014-09-28 18:19:47
16975	919	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01024M	\N	\N
16976	919	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	2014-09-28 16:50:17
16977	919	2011-10-01 00:00:00	2012-05-31 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	\N
16982	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	98046X	\N	\N
17029	907	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	2014-09-28 16:50:17
17044	909	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
17045	909	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86010V	\N	2014-09-28 19:03:04
17046	909	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89015P	\N	2014-09-28 16:50:17
17047	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08060W	\N	\N
17050	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	90003B	\N	\N
17051	909	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04099V	\N	2014-09-28 16:59:41
17052	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04038G	\N	\N
17054	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	95020Y	\N	\N
17056	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08022Q	\N	\N
17057	909	2011-10-01 00:00:00	2014-04-24 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
17059	919	2011-10-01 00:00:00	2012-05-31 00:00:00	ANCIEN	\N	\N	\N	11061K	\N	\N
17060	919	2011-10-01 00:00:00	2012-05-31 00:00:00	ANCIEN	\N	\N	\N	01007L	\N	\N
18401	617	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
18402	617	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
18403	617	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	2014-09-28 12:09:44
18404	618	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	\N
18405	618	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01028R	\N	\N
18406	618	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
18407	618	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08065C	\N	\N
18408	618	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	02053W	\N	2014-09-28 12:32:23
18409	616	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01041N	\N	\N
18410	617	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	02053W	\N	2014-09-28 12:32:23
18411	617	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	2015-03-02 10:42:04
17978	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11082Q	\N	\N
17979	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11067R	\N	\N
17980	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11080N	\N	\N
17981	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11069T	\N	\N
17982	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11070L	\N	\N
17983	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11089X	\N	\N
17984	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11108H	\N	\N
17985	598	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11090Q	\N	\N
17986	599	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
17987	599	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
17988	599	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11059R	\N	\N
18154	604	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08026U	\N	2014-09-28 17:52:18
18155	604	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11049P	\N	\N
18156	604	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11064N	\N	\N
18157	604	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11077T	\N	\N
18158	604	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11055M	\N	\N
18159	604	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11090Q	\N	\N
18558	622	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11020A	\N	\N
18559	622	2011-10-01 00:00:00	2014-06-30 00:00:00	ANCIEN	\N	\N	\N	11022C	\N	2014-08-06 16:29:49
18560	622	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
18561	623	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98010K	\N	2014-09-28 17:27:35
18562	619	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	2017-10-10 09:45:39
18563	619	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11076S	\N	\N
18564	620	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11066Q	\N	\N
18565	620	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11070L	\N	\N
16850	957	2011-10-01 00:00:00	2013-02-28 00:00:00	ANCIEN	\N	\N	\N	11062L	\N	\N
18731	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
18732	632	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95032D	\N	2014-09-28 17:07:41
18733	632	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92020L	\N	\N
18734	632	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11054L	\N	\N
18735	641	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	2014-09-28 16:40:50
18736	641	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:21
18737	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
18738	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01016M	\N	\N
18739	642	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01022K	\N	\N
18740	641	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11060J	\N	\N
18906	659	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92035T	\N	\N
18907	659	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	01063U	\N	2014-09-29 13:41:53
18908	659	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
18909	661	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
18910	661	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01065W	\N	2014-09-28 12:09:44
18911	661	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
18912	643	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08065C	\N	\N
18913	659	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
18914	659	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
18915	661	2011-10-01 00:00:00	2013-02-06 00:00:00	ANCIEN	\N	\N	\N	08036W	\N	\N
18916	663	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01034P	\N	\N
16437	910	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08016S	\N	\N
16812	913	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
16650	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	98021N	\N	\N
16813	913	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08068F	\N	\N
16652	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
16814	913	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11042G	\N	\N
16820	913	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	02002K	\N	\N
16662	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11067R	\N	\N
16664	948	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11014C	\N	\N
16665	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
16821	913	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	\N
16804	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11030C	\N	\N
16805	909	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98030P	\N	2014-09-28 13:19:48
16822	913	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95038K	\N	2014-09-28 17:40:23
16807	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11059R	\N	\N
16809	907	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	77043E	\N	2014-09-28 16:59:41
16810	907	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04083M	\N	2014-09-28 16:40:50
16811	907	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11063M	\N	\N
16823	913	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	\N
16829	913	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01058X	\N	\N
16830	913	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01028R	\N	\N
16831	913	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98037W	\N	2014-09-28 14:31:42
18566	620	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11107G	\N	\N
18567	622	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98023Q	\N	\N
18568	622	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98027U	\N	\N
18569	622	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
18570	622	2011-10-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	98019U	\N	2014-09-29 13:43:10
18571	623	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
17672	586	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
17673	586	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11100Y	\N	\N
17674	586	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11069T	\N	\N
17846	591	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	\N
17847	591	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11032E	\N	\N
17848	591	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	\N
17849	591	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04038G	\N	\N
17850	591	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07003H	\N	2014-09-28 12:21:28
17851	591	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95034F	\N	2014-09-28 18:00:58
17852	591	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08040S	\N	2014-09-28 17:52:18
17853	591	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96007G	\N	\N
17854	591	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98028V	\N	2014-09-28 17:22:11
17855	591	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08012N	\N	\N
17856	591	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	06004E	\N	2014-09-28 17:03:42
17005	907	2011-10-01 00:00:00	2012-07-21 00:00:00	ANCIEN	\N	\N	\N	11027H	\N	\N
17463	580	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
17464	580	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11114F	\N	\N
17465	581	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
17466	581	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
17467	581	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98032R	\N	\N
17468	581	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
17469	581	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
17470	581	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11015D	\N	\N
17471	581	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98021N	\N	\N
17472	581	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11040E	\N	\N
17100	934	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	96006F	\N	2014-09-28 16:50:17
17101	906	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	\N
17141	922	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98038X	\N	2014-09-28 17:38:26
17129	928	2011-10-01 00:00:00	2014-02-13 00:00:00	ANCIEN	\N	\N	\N	08046Y	\N	\N
17130	934	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04083M	\N	2014-09-28 16:40:50
17142	922	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08054Y	\N	2014-09-28 12:39:09
17143	913	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08038Y	\N	\N
17144	934	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11057P	\N	\N
17147	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04041B	\N	\N
17148	965	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11110B	\N	\N
17149	991	2011-12-14 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11051H	\N	\N
17151	991	2011-12-14 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11039M	\N	\N
17172	934	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	92018S	\N	\N
17184	934	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11014C	\N	\N
17186	934	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08072B	\N	2014-09-29 09:05:47
17199	912	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11015D	\N	\N
17200	908	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08043V	\N	\N
17211	919	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04087R	\N	2014-09-28 13:39:21
17223	992	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11095V	\N	\N
17224	992	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	95015C	\N	\N
17225	992	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	98029W	\N	\N
17226	992	2012-01-25 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08057C	\N	2014-09-28 14:31:42
17227	992	2012-01-25 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
17675	979	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95055L	\N	2014-09-28 13:21:47
17676	979	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	86049M	\N	2014-09-28 18:03:38
17677	979	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95021A	\N	2014-09-28 16:40:50
17678	979	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	83047W	\N	\N
17679	979	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
17680	979	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95047L	\N	2014-09-28 17:09:16
21902	626	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	88008L	2014-10-31 10:07:00	\N
17681	979	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	95052H	\N	2014-09-28 13:39:21
17682	979	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11020A	\N	\N
17683	979	2011-10-01 00:00:00	2014-04-24 00:00:00	ANCIEN	\N	\N	\N	89014N	\N	\N
17684	586	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
17685	979	2011-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	98011L	\N	2014-09-28 17:27:35
20334	590	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14257W	2014-10-15 09:39:30	\N
20335	584	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14257W	2014-10-15 09:39:31	\N
20336	595	2014-10-14 00:00:00	2017-08-06 00:00:00	ANCIEN	\N	\N	\N	04053F	2014-10-15 09:39:55	2017-08-07 16:31:39
20337	571	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	2014-10-15 09:40:13	\N
20338	595	2014-10-14 00:00:00	2017-07-28 00:00:00	ANCIEN	\N	\N	\N	11032E	2014-10-15 09:40:28	2017-08-03 11:38:41
20339	591	2014-10-14 00:00:00	2017-07-28 00:00:00	ANCIEN	\N	\N	\N	11032E	2014-10-15 09:40:28	2017-08-03 11:38:41
20340	641	2014-10-14 00:00:00	2017-07-28 00:00:00	ANCIEN	\N	\N	\N	11032E	2014-10-15 09:40:28	2017-08-03 11:38:41
20341	584	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04034C	2014-10-15 09:40:46	\N
20342	622	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04034C	2014-10-15 09:40:46	\N
20343	581	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04034C	2014-10-15 09:40:46	\N
20344	623	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04034C	2014-10-15 09:40:46	\N
20345	632	2014-10-14 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	14013P	2014-10-15 09:40:58	2017-06-19 16:06:01
20346	595	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11070L	2014-10-15 09:41:11	\N
20347	620	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11070L	2014-10-15 09:41:11	\N
20348	598	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11070L	2014-10-15 09:41:11	\N
20349	575	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11070L	2014-10-15 09:41:11	\N
20350	608	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98022P	2014-10-15 09:52:15	\N
20351	642	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98022P	2014-10-15 09:52:15	\N
20352	629	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98022P	2014-10-15 09:52:15	\N
20353	581	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14221J	2014-10-15 10:19:41	\N
20354	629	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11101A	2014-10-15 10:21:30	\N
20355	963	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11101A	2014-10-15 10:21:30	2015-03-04 10:25:37
20356	621	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11101A	2014-10-15 10:21:30	\N
21275	653	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04043D	2014-10-28 15:29:38	\N
21276	625	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04043D	2014-10-28 15:29:38	\N
21277	599	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04043D	2014-10-28 15:29:38	\N
21278	651	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04043D	2014-10-28 15:29:38	\N
21279	590	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04043D	2014-10-28 15:29:38	\N
21280	556	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04043D	2014-10-28 15:29:38	\N
21281	578	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04043D	2014-10-28 15:29:38	2015-03-19 10:02:59
21282	590	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14071N	2014-10-28 15:30:34	\N
21283	589	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04047H	2014-10-28 15:30:53	\N
21284	629	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04047H	2014-10-28 15:30:53	\N
21296	604	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01015L	2014-10-28 16:02:23	\N
21297	629	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01015L	2014-10-28 16:02:23	\N
21298	622	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01015L	2014-10-28 16:02:23	\N
21299	591	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01015L	2014-10-28 16:02:23	2017-09-24 17:19:42
21300	610	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01015L	2014-10-28 16:02:23	2017-09-24 17:19:42
21301	575	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01015L	2014-10-28 16:02:23	\N
21886	615	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04033B	2014-10-31 10:05:40	\N
21887	598	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04033B	2014-10-31 10:05:40	\N
21888	629	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04033B	2014-10-31 10:05:40	\N
21889	595	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	10006L	2014-10-31 10:06:00	\N
21890	626	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	10006L	2014-10-31 10:06:00	\N
21891	600	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	10006L	2014-10-31 10:06:00	\N
21892	653	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	10006L	2014-10-31 10:06:00	\N
21893	612	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	2014-10-31 10:06:28	\N
21894	632	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	11026G	2014-10-31 10:06:28	2017-10-10 09:45:39
21895	577	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	88008L	2014-10-31 10:06:59	2015-03-20 09:52:32
21896	618	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	88008L	2014-10-31 10:06:59	\N
21897	609	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	88008L	2014-10-31 10:06:59	\N
21898	634	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	88008L	2014-10-31 10:06:59	\N
21899	613	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	88008L	2014-10-31 10:06:59	\N
21900	598	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	88008L	2014-10-31 10:06:59	\N
21901	584	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	88008L	2014-10-31 10:06:59	\N
34438	938	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	14231L	\N	\N
21903	978	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	88008L	2014-10-31 10:07:00	\N
21904	633	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	88008L	2014-10-31 10:07:00	\N
21905	659	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	88008L	2014-10-31 10:07:00	\N
21906	602	2014-10-30 00:00:00	2017-10-04 00:00:00	ANCIEN	\N	\N	\N	95059Q	2014-10-31 10:10:54	2017-10-05 09:38:11
21907	596	2014-10-30 00:00:00	2017-10-04 00:00:00	ANCIEN	\N	\N	\N	95059Q	2014-10-31 10:10:54	2017-10-05 09:37:46
21908	584	2014-10-30 00:00:00	2017-10-04 00:00:00	ANCIEN	\N	\N	\N	95059Q	2014-10-31 10:10:54	2017-10-05 09:38:03
21909	590	2014-10-30 00:00:00	2017-10-04 00:00:00	ANCIEN	\N	\N	\N	95059Q	2014-10-31 10:10:54	2017-10-05 09:38:16
21910	583	2014-10-30 00:00:00	2017-10-04 00:00:00	ANCIEN	\N	\N	\N	95059Q	2014-10-31 10:10:54	2017-10-05 09:37:55
22232	647	2014-11-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14001X	2014-11-18 10:20:50	\N
22259	963	2014-11-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11111C	2014-11-20 11:29:24	\N
22953	922	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11023D	\N	2017-09-25 10:56:48
23183	919	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14073Q	\N	\N
23382	906	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04097T	\N	\N
23646	550	2016-06-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04067M	2016-06-09 16:37:12	2017-09-24 17:47:27
23647	633	2016-05-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11012A	2016-06-10 17:40:03	\N
21828	851	2014-10-29 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	01037S	2014-10-31 09:26:53	2016-12-12 16:10:15
21834	632	2014-10-29 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	01037S	2014-10-31 09:26:53	2016-12-12 16:10:15
21840	629	2014-10-29 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	01037S	2014-10-31 09:26:53	2016-12-12 16:10:15
21845	556	2014-10-29 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	01037S	2014-10-31 09:26:53	2016-12-12 16:10:15
23826	604	2017-01-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04097T	2017-01-16 18:17:51	\N
23827	580	2017-01-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04097T	2017-01-16 18:17:51	\N
24079	595	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08069G	2017-10-12 18:26:55	\N
24080	534	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08069G	2017-10-12 18:26:55	\N
24081	661	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08069G	2017-10-12 18:26:55	\N
24246	580	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19637C	2017-10-18 10:27:57	\N
20218	919	2013-11-01 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	12039E	2013-12-04 16:39:24	\N
20264	616	2014-05-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11099A	2014-06-04 13:51:27	\N
20223	589	2014-01-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	14001X	2014-01-16 10:05:08	2014-01-16 10:05:32
20224	591	2014-01-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	14001X	2014-01-16 10:06:52	\N
20225	978	2014-01-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	14001X	2014-01-16 10:33:21	\N
20265	616	2014-05-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11029K	2014-06-04 13:52:50	\N
20266	616	2014-05-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11083R	2014-06-04 13:59:34	\N
22859	908	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14173T	\N	\N
22860	908	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
22861	908	2014-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	14209N	\N	2017-10-01 10:34:22
22862	908	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	13002U	\N	2017-09-24 17:42:26
22864	908	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11099A	\N	\N
22865	998	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11099A	\N	\N
22866	642	2015-02-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	89017R	2015-02-19 10:02:03	2015-02-19 11:14:18
22867	595	2015-02-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11099A	2015-02-19 10:02:17	\N
22868	620	2015-02-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11099A	2015-02-19 10:02:17	\N
22869	577	2015-02-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11090Q	2015-02-19 10:02:28	2015-02-19 10:02:28
22870	911	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11099A	\N	\N
22872	911	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
22873	911	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11059R	\N	2017-09-24 17:42:26
22874	911	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	\N	\N
22875	911	2014-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	08042U	\N	2017-10-01 10:20:50
22876	906	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	02002K	\N	\N
22877	906	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04089T	\N	\N
22987	908	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08047A	\N	\N
23061	919	2012-09-30 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	14157T	\N	\N
23062	910	2014-10-01 00:00:00	2016-01-11 00:00:00	ANCIEN	\N	\N	\N	11060J	\N	2016-01-11 17:34:09
23064	919	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11098Y	\N	2017-09-24 17:14:26
23066	908	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	04094Q	\N	2017-09-25 10:58:49
23067	908	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11098Y	\N	2017-09-24 17:14:26
23068	642	2015-02-19 00:00:00	2015-05-06 00:00:00	ANCIEN	\N	\N	\N	92015P	2015-03-03 17:42:47	2015-05-11 17:08:32
23116	1003	2015-01-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
23246	948	2014-10-01 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	2016-12-12 16:10:15
23288	911	2014-10-01 00:00:00	2017-07-21 00:00:00	ANCIEN	\N	\N	\N	01007L	\N	2017-07-24 09:56:26
23401	948	2015-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	\N	\N
23531	CHRETORIENT	2016-02-12 00:00:00	2017-07-22 00:00:00	ANCIEN	\N	\N	\N	14037X	2016-02-12 12:34:26	2017-07-24 09:58:00
23532	CHRETORIENT	2016-02-12 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01061S	2016-02-12 12:34:32	2017-09-24 17:48:21
23533	CHRETORIENT	2016-02-12 00:00:00	2023-10-05 00:00:00	ANCIEN	\N	\N	\N	01043Q	2016-02-12 12:34:38	\N
23534	CHRETORIENT	2016-02-12 00:00:00	2023-10-05 00:00:00	ANCIEN	\N	\N	\N	11077T	2016-02-12 12:34:44	\N
23535	CHRETORIENT	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	14219Q	2016-02-12 12:34:55	\N
23536	CHRETORIENT	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	14059S	2016-02-12 12:35:07	\N
23537	CHRETORIENT	2016-02-12 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11106F	2016-02-12 12:35:13	2017-09-24 19:14:37
23538	CHRETORIENT	2016-02-12 00:00:00	2023-10-09 00:00:00	ANCIEN	\N	\N	\N	14031R	2016-02-12 12:35:20	\N
23539	CHRETORIENT	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	11085T	2016-02-12 12:35:27	\N
23540	CHRETORIENT	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	08009T	2016-02-12 12:35:33	\N
23541	CHRETORIENT	2016-02-12 00:00:00	2020-11-25 00:00:00	ANCIEN	\N	\N	\N	14221J	2016-02-12 12:35:41	\N
23542	CHRETORIENT	2016-02-12 00:00:00	2023-10-05 00:00:00	ANCIEN	\N	\N	\N	04057K	2016-02-12 12:35:49	\N
23543	CHRETORIENT	2016-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	95049N	2016-02-12 12:35:58	2017-10-01 10:42:05
23544	CHRETORIENT	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	14223L	2016-02-12 12:36:05	\N
23545	CHRETORIENT	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	04092N	2016-02-12 12:36:10	\N
23546	CHRETORIENT	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	11072N	2016-02-12 12:36:17	\N
23547	CHRETORIENT	2016-02-12 00:00:00	2020-10-19 00:00:00	ANCIEN	\N	\N	\N	14265W	2016-02-12 12:36:24	\N
23548	CHRETORIENT	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	04070G	2016-02-12 12:36:29	2018-01-05 11:28:46
23549	CHRETORIENT	2016-02-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14119M	2016-02-12 12:36:34	\N
23550	CHRETORIENT	2016-02-12 00:00:00	2017-10-10 00:00:00	ANCIEN	\N	\N	\N	14253S	2016-02-12 12:36:40	2017-10-11 16:36:24
23551	CHRETORIENT	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	08047A	2016-02-12 12:37:01	\N
23552	CHRETORIENT	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	14237S	2016-02-12 12:37:09	\N
23553	CHRETORIENT	2016-02-12 00:00:00	2020-10-19 00:00:00	ANCIEN	\N	\N	\N	04088S	2016-02-12 12:37:43	\N
23554	CHRETORIENT	2016-02-12 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	07034Q	2016-02-12 12:37:55	\N
23555	CHRETORIENT	2016-02-12 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	11069T	2016-02-12 12:38:03	2016-03-11 18:02:50
23556	CHRETORIENT	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	05012A	2016-02-12 12:38:16	\N
23557	CHRETORIENT	2016-02-12 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	04074L	2016-02-12 12:38:21	2017-09-24 17:15:15
23558	CHRETORIENT	2016-02-12 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	04080J	2016-02-12 12:38:27	2017-09-24 17:47:27
23559	CHRETORIENT	2016-02-12 00:00:00	2017-10-31 00:00:00	ANCIEN	\N	\N	\N	04043D	2016-02-12 12:38:38	2017-11-06 15:38:28
23560	CHRETORIENT	2016-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	14247U	2016-02-12 12:38:44	2017-10-01 10:25:16
23561	CHRETORIENT	2016-02-12 00:00:00	2020-10-19 00:00:00	ANCIEN	\N	\N	\N	14135M	2016-02-12 12:38:49	\N
23562	CHRETORIENT	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	14225N	2016-02-12 12:38:54	\N
23563	CHRETORIENT	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	10015M	2016-02-12 12:39:00	\N
23564	CHRETORIENT	2016-02-12 00:00:00	2023-10-05 00:00:00	ANCIEN	\N	\N	\N	11012A	2016-02-12 12:39:05	\N
23565	CHRETORIENT	2016-02-12 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	2016-02-12 12:39:15	\N
23566	CHRETORIENT	2016-02-12 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11093T	2016-02-12 12:39:21	2017-09-24 12:57:09
23567	CHRETORIENT	2016-02-12 00:00:00	2023-10-05 00:00:00	ANCIEN	\N	\N	\N	11054L	2016-02-12 12:39:30	\N
23568	CHRETORIENT	2016-02-12 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01019Q	2016-02-12 12:39:37	2017-09-24 17:35:15
23569	CHRETORIENT	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	01058X	2016-02-12 12:39:43	\N
23570	CHRETORIENT	2016-02-12 00:00:00	2023-10-05 00:00:00	ANCIEN	\N	\N	\N	01028R	2016-02-12 12:39:50	\N
23571	CHRETORIENT	2016-02-12 00:00:00	2020-11-02 00:00:00	ANCIEN	\N	\N	\N	14227Q	2016-02-12 12:39:56	\N
23572	CHRETORIENT	2016-02-12 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01056V	2016-02-12 12:40:02	2017-09-24 17:04:02
23573	CHRETORIENT	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	01034P	2016-02-12 12:40:10	\N
23574	CHRETORIENT	2016-02-12 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	11066Q	2016-02-12 12:40:18	\N
23575	CHRETORIENT	2016-02-12 00:00:00	2020-10-19 00:00:00	ANCIEN	\N	\N	\N	95067Q	2016-02-12 12:40:24	\N
23576	CHRETORIENT	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	14173T	2016-02-12 12:40:29	\N
23577	CHRETORIENT	2016-02-12 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	04034C	2016-02-12 12:40:36	\N
23578	CHRETORIENT	2016-02-12 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01047U	2016-02-12 12:40:42	2017-09-24 13:29:42
23579	CHRETORIENT	2016-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	14167V	2016-02-12 12:41:21	2017-10-01 10:18:28
23580	CHRETORIENT	2016-02-12 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	77002U	2016-02-12 12:41:32	2017-09-24 18:59:59
22010	598	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04061F	2014-11-03 13:43:34	\N
21285	602	2014-10-28 00:00:00	2014-12-18 00:00:00	ANCIEN	\N	\N	\N	01062T	2014-10-28 15:41:39	2014-12-18 16:15:04
21286	590	2014-10-28 00:00:00	2014-12-18 00:00:00	ANCIEN	\N	\N	\N	01062T	2014-10-28 15:41:39	2014-12-18 16:15:04
21287	608	2014-10-28 00:00:00	2014-12-18 00:00:00	ANCIEN	\N	\N	\N	01062T	2014-10-28 15:41:39	2014-12-18 16:15:04
21288	584	2014-10-28 00:00:00	2014-12-18 00:00:00	ANCIEN	\N	\N	\N	01062T	2014-10-28 15:41:39	2014-12-18 16:15:04
21289	580	2014-10-28 00:00:00	2014-12-18 00:00:00	ANCIEN	\N	\N	\N	01062T	2014-10-28 15:41:39	2014-12-18 16:15:04
21290	583	2014-10-28 00:00:00	2014-12-18 00:00:00	ANCIEN	\N	\N	\N	01062T	2014-10-28 15:41:39	2014-12-18 16:15:04
21291	642	2014-10-28 00:00:00	2014-12-18 00:00:00	ANCIEN	\N	\N	\N	01062T	2014-10-28 15:41:39	2014-12-18 16:15:04
21292	621	2014-10-28 00:00:00	2014-12-18 00:00:00	ANCIEN	\N	\N	\N	01062T	2014-10-28 15:41:39	2014-12-18 16:15:04
21293	589	2014-10-28 00:00:00	2014-12-18 00:00:00	ANCIEN	\N	\N	\N	01062T	2014-10-28 15:41:39	2014-12-18 16:15:04
21294	601	2014-10-28 00:00:00	2014-12-18 00:00:00	ANCIEN	\N	\N	\N	01062T	2014-10-28 15:41:39	2014-12-18 16:15:04
21295	625	2014-10-28 00:00:00	2014-12-18 00:00:00	ANCIEN	\N	\N	\N	01062T	2014-10-28 15:41:39	2014-12-18 16:15:04
22009	642	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04061F	2014-11-03 13:43:34	\N
22011	573	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04061F	2014-11-03 13:43:35	\N
22012	624	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04061F	2014-11-03 13:43:35	\N
22013	613	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04049K	2014-11-03 14:38:21	\N
22014	597	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04049K	2014-11-03 14:38:21	\N
22015	609	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04049K	2014-11-03 14:38:21	\N
22016	979	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04049K	2014-11-03 14:38:21	\N
22017	641	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04049K	2014-11-03 14:38:21	\N
22018	618	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04049K	2014-11-03 14:38:21	\N
22019	534	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04049K	2014-11-03 14:38:21	\N
22020	583	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04049K	2014-11-03 14:38:21	\N
22021	584	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04049K	2014-11-03 14:38:21	\N
22022	643	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04049K	2014-11-03 14:38:21	\N
22023	661	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04049K	2014-11-03 14:38:21	\N
22024	574	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04049K	2014-11-03 14:38:21	\N
22025	598	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04049K	2014-11-03 14:38:21	\N
22026	623	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04049K	2014-11-03 14:38:21	2015-03-06 09:53:01
22027	622	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04049K	2014-11-03 14:38:21	\N
22028	632	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04049K	2014-11-03 14:38:21	\N
22029	608	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04049K	2014-11-03 14:38:21	\N
22030	634	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04049K	2014-11-03 14:38:21	\N
22031	624	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04049K	2014-11-03 14:38:22	\N
22032	578	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04049K	2014-11-03 14:38:22	\N
22033	595	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04049K	2014-11-03 14:38:22	\N
22034	596	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04049K	2014-11-03 14:38:22	\N
22035	612	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04049K	2014-11-03 14:38:22	\N
22036	576	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04049K	2014-11-03 14:38:22	\N
22376	578	2015-01-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	07004J	2015-01-13 09:23:58	2015-03-19 10:03:44
22404	659	2015-01-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11091R	2015-01-19 17:41:50	\N
22530	582	2015-02-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2015-02-10 15:53:33	\N
22935	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
22952	913	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08038Y	\N	\N
22988	908	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	\N	\N
22991	908	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11114F	\N	2017-09-25 10:54:33
23084	908	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14133K	\N	\N
23097	919	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14093U	\N	\N
23099	919	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11111C	\N	2017-09-24 16:45:26
23100	919	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14031R	\N	\N
23101	910	2014-10-01 00:00:00	2015-04-03 00:00:00	ANCIEN	\N	\N	\N	11111C	\N	\N
23110	918	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14265W	\N	\N
23118	532	2015-02-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	2015-03-10 09:31:37	\N
23125	673	2015-01-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08038Y	2015-03-10 15:12:21	\N
23172	617	2015-03-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	2015-03-25 10:11:28	\N
23189	918	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95015C	\N	\N
23190	918	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11101A	\N	\N
23191	918	2014-10-01 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	2017-05-16 15:18:13
23247	534	2015-04-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14219Q	2015-04-27 11:38:23	\N
23248	661	2015-04-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14219Q	2015-04-27 11:38:23	\N
23271	910	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	04094Q	\N	2017-09-25 10:58:49
23290	907	2014-10-01 00:00:00	2017-06-04 00:00:00	ANCIEN	\N	\N	\N	14273W	\N	2017-06-07 09:38:00
23294	628	2015-06-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11064N	2015-06-26 10:19:06	\N
23335	933	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14065Q	\N	\N
23342	933	2015-01-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	08028W	\N	\N
23352	933	2015-01-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	04067M	\N	\N
23353	933	2015-01-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11020A	\N	\N
23354	933	2015-01-01 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	2016-12-12 16:10:15
23355	933	2015-01-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14199E	\N	\N
23356	933	2015-01-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14211G	\N	\N
23357	933	2015-01-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14081Q	\N	\N
23359	933	2015-01-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14061L	\N	\N
23360	933	2015-01-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11112D	\N	\N
23361	933	2015-01-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	08031R	\N	\N
23363	933	2015-01-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11077T	\N	\N
23364	933	2015-01-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	08019V	\N	\N
23366	933	2015-01-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	08047A	\N	\N
23367	933	2015-01-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01016M	\N	\N
23368	933	2015-01-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14225N	\N	\N
23369	933	2015-01-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11046L	\N	\N
23370	933	2015-01-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	\N
23378	598	2015-07-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14281W	2015-07-22 15:49:27	2015-07-22 15:53:59
23380	919	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04097T	\N	\N
23384	674	2015-08-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14281W	2015-08-10 16:09:13	\N
23396	590	2015-09-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14277B	2015-10-05 16:53:17	\N
23416	918	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14327T	\N	\N
23425	616	2015-11-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08044W	2015-11-18 11:06:26	\N
23426	613	2015-11-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14237S	2015-11-18 11:06:52	\N
23427	616	2015-11-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11076S	2015-11-18 18:11:57	2017-09-24 17:47:28
23428	616	2015-11-10 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	98021N	2015-11-18 18:12:20	2017-10-01 09:22:38
23429	613	2015-11-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	97011G	2015-11-20 15:55:20	\N
20504	979	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	89017R	2014-10-17 14:40:39	\N
20505	613	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	89017R	2014-10-17 14:40:39	2014-10-20 16:27:18
20506	978	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	89017R	2014-10-17 14:40:39	\N
20507	626	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	89017R	2014-10-17 14:40:39	\N
20508	623	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	89017R	2014-10-17 14:40:39	2015-03-06 09:53:10
20509	643	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	89017R	2014-10-17 14:40:39	\N
20510	584	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	89017R	2014-10-17 14:40:39	\N
20511	642	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11084S	2014-10-17 14:42:06	\N
20512	623	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11084S	2014-10-17 14:42:06	\N
20513	596	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11084S	2014-10-17 14:42:06	\N
20514	641	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11084S	2014-10-17 14:42:07	\N
20515	573	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11084S	2014-10-17 14:42:07	\N
20516	598	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11084S	2014-10-17 14:42:07	\N
20517	608	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11084S	2014-10-17 14:42:07	\N
20518	584	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11084S	2014-10-17 14:42:07	\N
20519	590	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11084S	2014-10-17 14:42:07	\N
20520	661	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11084S	2014-10-17 14:42:07	2017-09-24 19:25:10
20521	609	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11084S	2014-10-17 14:42:07	\N
20522	602	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92031P	2014-10-17 14:43:11	\N
20523	530	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92031P	2014-10-17 14:43:11	\N
20524	588	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92031P	2014-10-17 14:43:11	\N
20525	573	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92031P	2014-10-17 14:43:11	\N
20526	616	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92031P	2014-10-17 14:43:11	\N
20527	608	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92031P	2014-10-17 14:43:11	\N
20528	584	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92031P	2014-10-17 14:43:11	\N
20529	600	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92031P	2014-10-17 14:43:11	\N
20530	590	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92031P	2014-10-17 14:43:11	\N
20531	572	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92031P	2014-10-17 14:43:11	\N
20532	657	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11066Q	2014-10-17 14:43:54	2015-03-09 14:10:54
20533	620	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11066Q	2014-10-17 14:43:54	\N
21271	617	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01025N	2014-10-28 15:02:31	\N
21272	598	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01025N	2014-10-28 15:02:31	\N
21273	620	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01025N	2014-10-28 15:02:31	\N
21274	583	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01025N	2014-10-28 15:02:31	\N
21572	591	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14235Q	2014-10-30 10:50:18	2017-07-20 14:38:49
21573	632	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14235Q	2014-10-30 10:50:18	\N
21574	581	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14235Q	2014-10-30 10:50:18	\N
21575	575	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14235Q	2014-10-30 10:50:19	\N
21576	978	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14235Q	2014-10-30 10:50:19	\N
21577	596	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14089Y	2014-10-30 10:52:15	2015-03-20 09:20:30
21578	629	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14089Y	2014-10-30 10:52:15	\N
21579	604	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14089Y	2014-10-30 10:52:15	\N
21580	602	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11034G	2014-10-30 10:52:37	\N
21581	643	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11034G	2014-10-30 10:52:37	\N
21582	591	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11034G	2014-10-30 10:52:37	2017-09-24 17:55:12
21583	979	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11034G	2014-10-30 10:52:37	\N
21584	626	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11034G	2014-10-30 10:52:37	\N
21585	584	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	09001P	2014-10-30 10:53:11	\N
21586	634	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	09001P	2014-10-30 10:53:11	\N
21587	623	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	09001P	2014-10-30 10:53:11	\N
21588	643	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	90003B	2014-10-30 10:54:41	2017-10-01 10:01:39
21589	979	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	90003B	2014-10-30 10:54:41	2017-10-01 10:01:39
21590	663	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	90003B	2014-10-30 10:54:41	2017-10-01 10:01:39
21591	573	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	90003B	2014-10-30 10:54:41	2017-10-01 10:01:39
21592	584	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01061S	2014-10-30 10:55:21	\N
21593	598	2014-10-29 00:00:00	2016-11-17 00:00:00	ANCIEN	\N	\N	\N	07032N	2014-10-30 10:55:59	2016-11-18 12:37:49
21594	591	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01059Y	2014-10-30 10:56:57	2017-09-24 17:35:15
21595	604	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01059Y	2014-10-30 10:56:57	\N
21596	632	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01059Y	2014-10-30 10:56:57	\N
21597	620	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01059Y	2014-10-30 10:56:57	\N
21598	642	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01059Y	2014-10-30 10:56:57	\N
21599	591	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11100Y	2014-10-30 10:57:45	2017-09-24 13:57:40
21600	571	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11100Y	2014-10-30 10:57:45	\N
21601	663	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11100Y	2014-10-30 10:57:45	\N
21602	979	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11100Y	2014-10-30 10:57:45	2017-09-24 13:57:40
21603	574	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11100Y	2014-10-30 10:57:45	\N
21604	609	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11100Y	2014-10-30 10:57:45	\N
21605	584	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11100Y	2014-10-30 10:57:45	\N
21606	596	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11100Y	2014-10-30 10:57:45	\N
21607	629	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11100Y	2014-10-30 10:57:45	\N
21608	576	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11100Y	2014-10-30 10:57:45	\N
21609	661	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11100Y	2014-10-30 10:57:45	\N
21610	626	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11100Y	2014-10-30 10:57:45	\N
21611	578	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11100Y	2014-10-30 10:57:45	2017-09-24 13:57:40
21612	608	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08034U	2014-10-30 11:19:10	\N
21613	624	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08034U	2014-10-30 11:19:26	\N
21641	604	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01008M	2014-10-30 11:56:56	\N
21642	580	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01008M	2014-10-30 11:57:16	2017-09-24 13:44:49
21643	610	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01008M	2014-10-30 11:57:40	2017-09-24 13:44:49
21644	621	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01008M	2014-10-30 11:58:00	\N
21645	979	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01008M	2014-10-30 11:58:16	2017-09-24 13:44:49
21646	600	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01008M	2014-10-30 11:58:30	\N
21647	608	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01008M	2014-10-30 11:58:44	\N
21648	629	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01008M	2014-10-30 11:59:08	\N
21649	620	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14085U	2014-10-30 12:06:01	\N
21650	583	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14085U	2014-10-30 12:06:01	\N
20288	596	2014-10-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04036E	2014-10-13 15:05:40	\N
20289	604	2014-10-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04036E	2014-10-13 15:05:40	\N
20290	581	2014-10-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04036E	2014-10-13 15:05:40	\N
20291	595	2014-10-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04036E	2014-10-13 15:05:40	\N
20292	632	2014-10-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04036E	2014-10-13 15:05:40	\N
20293	626	2014-10-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04036E	2014-10-13 15:05:40	\N
20294	609	2014-10-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04036E	2014-10-13 15:05:40	\N
20295	979	2014-10-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04036E	2014-10-13 15:05:40	2017-09-24 18:59:59
20296	621	2014-10-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04036E	2014-10-13 15:05:40	\N
20297	608	2014-10-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04036E	2014-10-13 15:05:40	\N
20298	643	2014-10-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04036E	2014-10-13 15:05:40	\N
20299	610	2014-10-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04036E	2014-10-13 15:05:40	2017-09-24 18:59:59
20300	601	2014-10-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04036E	2014-10-13 15:05:40	2017-09-24 18:59:59
20301	623	2014-10-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04036E	2014-10-13 15:05:40	\N
20302	573	2014-10-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04036E	2014-10-13 15:05:40	\N
20303	634	2014-10-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04036E	2014-10-13 15:05:40	\N
20304	641	2014-10-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04036E	2014-10-13 15:05:40	\N
20305	628	2014-10-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04036E	2014-10-13 15:05:40	2017-09-24 18:59:59
20306	618	2014-10-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04036E	2014-10-13 15:05:40	\N
20307	597	2014-10-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04036E	2014-10-13 15:05:40	\N
20308	633	2014-10-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04036E	2014-10-13 15:05:40	2017-09-24 18:59:59
20309	580	2014-10-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04036E	2014-10-13 15:05:40	2017-09-24 18:59:59
20310	659	2014-10-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04036E	2014-10-13 15:05:40	\N
20311	572	2014-10-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04036E	2014-10-13 15:05:40	\N
20312	620	2014-10-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04036E	2014-10-13 15:05:41	\N
20313	598	2014-10-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04036E	2014-10-13 15:05:41	\N
20314	644	2014-10-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04036E	2014-10-13 15:05:41	2017-09-24 18:59:59
20315	591	2014-10-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04036E	2014-10-13 15:05:41	2017-09-24 18:59:59
20316	589	2014-10-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04036E	2014-10-13 15:05:41	\N
20317	978	2014-10-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04036E	2014-10-13 15:05:41	\N
20318	617	2014-10-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04036E	2014-10-13 15:05:41	\N
20319	602	2014-10-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04036E	2014-10-13 15:05:41	\N
20320	556	2014-10-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04036E	2014-10-13 15:05:41	\N
20321	673	2014-10-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04036E	2014-10-13 15:05:41	\N
20322	584	2014-10-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04036E	2014-10-13 15:05:41	\N
20323	629	2014-10-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04036E	2014-10-13 15:05:41	\N
20324	661	2014-10-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04036E	2014-10-13 15:05:41	2017-09-24 18:59:59
20325	583	2014-10-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04036E	2014-10-13 15:05:41	\N
20326	585	2014-10-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04036E	2014-10-13 15:05:41	2017-09-24 18:59:59
20327	590	2014-10-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04036E	2014-10-13 15:05:41	\N
20328	575	2014-10-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04036E	2014-10-13 15:05:41	\N
22817	908	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14093U	\N	\N
23060	640	2015-02-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14193X	2015-03-03 15:22:48	\N
23117	1003	2015-01-28 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01015L	\N	2017-09-24 17:19:42
23126	583	2015-03-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14259Y	2015-03-11 09:14:33	\N
23127	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08016S	\N	\N
23132	913	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	2017-09-24 17:48:21
23139	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08016S	\N	\N
23179	659	2015-03-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14215L	2015-04-01 13:34:06	\N
23196	906	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14257W	\N	\N
23197	906	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11048N	\N	\N
23217	659	2015-04-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14135M	2015-04-16 15:17:17	\N
23593	963	2016-02-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14103D	2016-02-16 15:58:33	\N
23594	963	2016-02-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14111D	2016-02-16 17:34:17	\N
23720	965	2016-06-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11015D	\N	2017-09-24 13:42:36
23736	919	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08010L	\N	\N
23861	934	2017-07-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	19251M	\N	\N
24247	596	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19637C	2017-10-18 10:27:57	\N
24248	580	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	2017-10-18 10:29:38	\N
24249	581	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	2017-10-18 10:29:38	\N
24250	589	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	2017-10-18 10:29:38	\N
24251	599	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	2017-10-18 10:29:38	\N
24252	620	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	2017-10-18 10:29:38	\N
24253	661	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	2017-10-18 10:29:38	\N
24254	978	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	2017-10-18 10:29:38	\N
24255	598	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	2017-10-18 10:29:38	\N
24256	610	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	2017-10-18 10:29:38	\N
24257	597	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	2017-10-18 10:29:38	\N
24258	590	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	2017-10-18 10:29:38	\N
24259	601	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	2017-10-18 10:29:38	\N
24260	602	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	2017-10-18 10:29:38	\N
24261	595	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	2017-10-18 10:29:38	\N
24262	584	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	2017-10-18 10:29:38	\N
24263	572	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	2017-10-18 10:29:38	\N
24264	621	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	2017-10-18 10:29:38	\N
24265	625	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	2017-10-18 10:29:38	\N
24266	573	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	2017-10-18 10:29:38	\N
24267	578	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	2017-10-18 10:29:38	\N
24268	583	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	2017-10-18 10:29:38	\N
24269	643	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	2017-10-18 10:29:38	\N
24270	617	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	2017-10-18 10:29:38	\N
24271	979	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	2017-10-18 10:29:38	\N
24272	609	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	2017-10-18 10:29:38	\N
24273	657	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11066Q	2017-10-18 10:30:01	\N
24274	602	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11067R	2017-10-18 10:30:23	\N
24275	589	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11067R	2017-10-18 10:30:23	\N
21227	573	2014-10-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95062K	2014-10-27 16:00:30	\N
21427	592	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11098Y	2014-10-29 10:16:09	\N
21428	591	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11098Y	2014-10-29 10:16:09	2017-09-24 17:14:26
21429	622	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11098Y	2014-10-29 10:16:09	2017-09-24 17:14:27
21430	576	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11098Y	2014-10-29 10:16:09	\N
21431	581	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11098Y	2014-10-29 10:16:09	\N
21432	584	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08069G	2014-10-29 10:17:04	\N
21433	626	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08069G	2014-10-29 10:17:04	\N
21434	661	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08069G	2014-10-29 10:17:04	\N
21435	590	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08069G	2014-10-29 10:17:04	\N
21436	556	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08069G	2014-10-29 10:17:04	\N
21437	634	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08069G	2014-10-29 10:17:04	\N
21438	595	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08069G	2014-10-29 10:17:04	\N
21439	609	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08069G	2014-10-29 10:17:04	\N
21440	576	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08069G	2014-10-29 10:17:04	\N
21442	641	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11085T	2014-10-29 10:17:32	\N
21443	598	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11085T	2014-10-29 10:17:32	\N
21444	584	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11085T	2014-10-29 10:17:32	\N
21445	629	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11085T	2014-10-29 10:17:32	\N
21446	532	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11085T	2014-10-29 10:17:32	2015-03-10 17:27:31
21447	595	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11085T	2014-10-29 10:17:32	\N
21553	659	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01043Q	2014-10-30 09:30:15	\N
21554	621	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14205J	2014-10-30 09:30:41	\N
21555	590	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14205J	2014-10-30 09:30:41	\N
21556	596	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11048N	2014-10-30 09:35:00	\N
21557	629	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11048N	2014-10-30 09:35:00	\N
21558	600	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14119M	2014-10-30 09:35:13	\N
21559	573	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14119M	2014-10-30 09:35:13	\N
21560	979	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11031D	2014-10-30 09:35:36	\N
21561	591	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11031D	2014-10-30 09:35:36	2017-07-20 14:38:34
21562	620	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11031D	2014-10-30 09:35:36	\N
21563	576	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11031D	2014-10-30 09:35:36	\N
21564	978	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11031D	2014-10-30 09:35:36	\N
21565	589	2014-10-29 00:00:00	2015-05-05 00:00:00	ANCIEN	\N	\N	\N	08041T	2014-10-30 09:35:54	2015-05-06 17:28:40
21566	591	2014-10-29 00:00:00	2015-05-05 00:00:00	ANCIEN	\N	\N	\N	08041T	2014-10-30 09:35:54	2015-05-06 17:28:40
21567	621	2014-10-29 00:00:00	2015-05-05 00:00:00	ANCIEN	\N	\N	\N	08041T	2014-10-30 09:35:54	2015-05-06 17:28:40
21568	590	2014-10-29 00:00:00	2015-05-05 00:00:00	ANCIEN	\N	\N	\N	08041T	2014-10-30 09:35:54	2015-05-06 17:28:40
21569	673	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08041T	2014-10-30 09:35:54	\N
21570	629	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08041T	2014-10-30 09:35:54	\N
21571	583	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08014Q	2014-10-30 09:36:10	\N
21913	584	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11095V	2014-10-31 12:46:20	\N
21914	625	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11095V	2014-10-31 12:46:20	\N
21915	963	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11095V	2014-10-31 12:46:20	\N
22037	612	2014-10-30 00:00:00	2017-07-22 00:00:00	ANCIEN	\N	\N	\N	14037X	2014-11-03 15:08:04	2017-07-24 09:58:00
22038	641	2014-10-30 00:00:00	2016-01-11 00:00:00	ANCIEN	\N	\N	\N	11060J	2014-11-03 15:08:32	2016-01-11 17:34:09
22039	626	2014-10-30 00:00:00	2016-01-11 00:00:00	ANCIEN	\N	\N	\N	11060J	2014-11-03 15:08:32	2016-01-11 17:34:09
22040	578	2014-10-30 00:00:00	2016-01-11 00:00:00	ANCIEN	\N	\N	\N	11060J	2014-11-03 15:08:32	2016-01-11 17:34:09
22041	978	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	2014-11-03 15:12:01	\N
22042	581	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	2014-11-03 15:12:01	\N
22043	584	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	2014-11-03 15:12:01	\N
22044	618	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	2014-11-03 15:12:01	\N
22045	609	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	2014-11-03 15:12:01	\N
22046	534	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	2014-11-03 15:12:01	\N
22047	617	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	2014-11-03 15:12:01	\N
22048	595	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	2014-11-03 15:12:01	\N
22049	589	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	2014-11-03 15:12:01	\N
22050	626	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	2014-11-03 15:12:01	\N
22051	586	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	2014-11-03 15:12:01	\N
22052	979	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	2014-11-03 15:12:01	\N
22053	642	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	2014-11-03 15:12:01	\N
22054	601	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	2014-11-03 15:12:01	\N
22055	661	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	2014-11-03 15:12:01	\N
22056	598	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	2014-11-03 15:12:01	\N
22057	576	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	2014-11-03 15:12:01	\N
22058	628	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	2014-11-03 15:12:01	\N
22059	629	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	2014-11-03 15:12:01	\N
22060	643	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	2014-11-03 15:12:02	\N
22061	608	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	2014-11-03 15:12:02	\N
22062	590	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	2014-11-03 15:12:02	\N
22063	591	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	2014-11-03 15:12:02	2017-07-20 14:38:36
22064	556	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	2014-11-03 15:12:02	\N
22065	621	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	2014-11-03 15:12:02	\N
22066	633	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	2014-11-03 15:12:02	\N
22067	573	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	2014-11-03 15:12:02	\N
22068	613	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	2014-11-03 15:12:02	\N
22069	624	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	2014-11-03 15:12:02	\N
22070	603	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	2014-11-03 15:12:02	\N
22071	580	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14195A	2014-11-03 15:12:43	2015-04-10 15:10:48
22072	622	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14195A	2014-11-03 15:12:43	\N
22073	605	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14195A	2014-11-03 15:12:43	\N
22343	591	2014-12-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14207L	2014-12-16 18:17:37	2017-07-20 14:38:34
22344	591	2014-12-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14151M	2014-12-16 18:17:48	2017-07-20 14:38:34
22345	629	2014-12-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	2014-12-16 18:18:13	\N
22346	622	2014-12-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	2014-12-16 18:18:14	\N
22347	583	2014-12-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	2014-12-16 18:18:14	\N
22348	978	2014-12-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	2014-12-16 18:18:14	\N
20236	625	2014-01-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11083R	2014-04-01 15:44:26	\N
20237	938	2014-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04080J	2014-04-01 15:55:26	\N
20485	598	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14227Q	2014-10-16 15:09:20	\N
20486	651	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14227Q	2014-10-16 15:09:20	\N
20487	673	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	2014-10-16 15:09:41	\N
20488	609	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	2014-10-16 15:09:41	\N
20489	578	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	2014-10-16 15:10:11	2017-10-01 09:41:22
20490	598	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	2014-10-16 15:10:11	2017-10-01 09:41:22
20491	596	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	2014-10-16 15:10:11	2017-10-01 09:41:22
20492	629	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	2014-10-16 15:10:11	2017-10-01 09:41:22
20493	590	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	2014-10-16 15:10:11	2017-10-01 09:41:22
20494	609	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	2014-10-16 15:10:11	2017-10-01 09:41:22
20495	584	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	2014-10-16 15:10:11	2017-10-01 09:41:22
20496	576	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	2014-10-16 15:10:11	2017-10-01 09:41:22
20497	602	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11023D	2014-10-16 15:10:23	\N
20498	583	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11023D	2014-10-16 15:10:23	\N
22477	578	2015-01-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11106F	2015-01-29 10:36:18	\N
23199	957	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
23200	1003	2015-01-28 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14018U	\N	2017-09-24 18:49:56
23201	910	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14018U	\N	2017-09-24 18:49:56
23202	909	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14018U	\N	2017-09-24 18:49:56
23203	998	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11055M	\N	2017-09-24 18:07:57
23215	911	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14249W	\N	\N
23387	998	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14281W	\N	\N
23388	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	\N	\N
23440	628	2016-01-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2016-01-25 10:28:34	\N
23420	918	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14197C	\N	\N
23610	912	2016-04-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14231L	\N	\N
23617	617	2016-05-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11085T	2016-05-20 10:07:45	\N
23618	978	2016-05-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2016-05-26 09:58:01	\N
23622	624	2016-05-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14327T	2016-05-30 09:58:48	\N
23625	1004	2016-06-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14195A	\N	\N
23626	1004	2016-06-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14267Y	\N	\N
23627	1004	2016-06-07 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11088W	\N	2017-09-24 17:15:15
23657	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08068F	\N	\N
23631	1004	2016-06-07 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11061K	\N	2017-09-24 17:42:25
23632	1004	2016-06-07 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	95035G	\N	2017-09-24 18:17:56
23633	1004	2016-06-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	\N
23634	1004	2016-06-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08053X	\N	\N
23655	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08060W	\N	\N
23656	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14105F	\N	\N
23658	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14207L	\N	\N
23660	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14085U	\N	\N
23661	1005	2016-06-15 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	92015P	\N	2017-09-24 13:14:55
23662	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14038Y	\N	\N
23664	1005	2016-06-15 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11042G	\N	2017-09-24 17:35:15
23665	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04038G	\N	\N
23666	1005	2016-06-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	14209N	\N	2017-10-01 10:34:22
23667	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	\N	\N
23668	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	80013X	\N	\N
23725	919	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
23726	919	2014-10-01 00:00:00	2017-07-28 00:00:00	ANCIEN	\N	\N	\N	11032E	\N	2017-08-03 11:38:41
23727	919	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14195A	\N	\N
23729	919	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14197C	\N	\N
23730	919	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14249W	\N	\N
23731	919	2014-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	\N	2017-10-01 09:41:22
23732	919	2014-10-01 00:00:00	2016-11-30 00:00:00	ANCIEN	\N	\N	\N	04048J	\N	2016-12-01 10:36:51
23733	919	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14061L	\N	\N
23734	919	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	04077P	\N	2017-09-24 17:47:27
23735	919	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	04094Q	\N	2017-09-25 10:58:49
23737	919	2014-10-01 00:00:00	2017-07-22 00:00:00	ANCIEN	\N	\N	\N	14037X	\N	2017-07-24 09:58:00
23738	919	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14219Q	\N	\N
23739	919	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14018U	\N	2017-09-24 18:49:56
23740	919	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14063N	\N	\N
23741	919	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11014C	\N	2017-09-24 13:14:55
23742	919	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
23743	919	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08021P	\N	\N
23744	919	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14135M	\N	\N
23745	919	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14271U	\N	2017-09-24 17:06:55
23746	919	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11043H	\N	\N
23747	919	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11066Q	\N	\N
23756	918	2017-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
23757	918	2016-10-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
23774	919	2016-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	92015P	\N	2017-09-24 13:14:55
23775	919	2016-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14038Y	\N	\N
23810	919	2016-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
23825	644	2016-12-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11090Q	2017-01-02 12:13:37	\N
23834	597	2017-01-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04088S	2017-01-30 15:34:50	2017-01-30 15:36:28
23852	532	2017-04-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14221J	2017-04-07 09:08:21	\N
23853	534	2017-04-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08015R	2017-04-07 10:12:21	\N
23952	963	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11101A	2017-10-11 15:13:17	\N
23953	589	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11101A	2017-10-11 15:13:17	\N
23954	629	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11101A	2017-10-11 15:13:17	\N
24116	CHRETORIENT	2017-10-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	19269X	2017-10-17 11:07:57	\N
24398	634	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2017-10-19 15:01:57	\N
24393	597	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2017-10-19 15:01:57	\N
24394	617	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2017-10-19 15:01:57	\N
24395	602	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2017-10-19 15:01:57	\N
24396	608	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2017-10-19 15:01:57	\N
24397	585	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2017-10-19 15:01:57	\N
20226	904	2014-01-27 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	14001X	\N	\N
20227	966	2014-01-27 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	14001X	\N	\N
20230	585	2014-01-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	14001X	2014-02-03 10:53:12	\N
20499	584	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14133K	2014-10-16 15:37:04	\N
20270	674	2014-06-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	14012N	2014-07-03 10:42:22	2014-09-28 16:54:10
20500	624	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14133K	2014-10-16 15:37:04	\N
20501	589	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14133K	2014-10-16 15:37:04	\N
20502	979	2014-10-15 00:00:00	2017-04-27 00:00:00	ANCIEN	\N	\N	\N	14133K	2014-10-16 15:37:04	2017-04-27 16:00:50
20503	608	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14133K	2014-10-16 15:37:04	\N
21651	611	2014-10-30 00:00:00	2017-09-22 00:00:00	ANCIEN	\N	\N	\N	04041B	2014-10-30 12:06:37	2017-09-24 11:09:53
21652	597	2014-10-30 00:00:00	2017-09-22 00:00:00	ANCIEN	\N	\N	\N	04041B	2014-10-30 12:06:37	2017-09-24 11:09:53
21653	595	2014-10-30 00:00:00	2017-09-22 00:00:00	ANCIEN	\N	\N	\N	04041B	2014-10-30 12:06:38	2017-09-24 11:09:53
21654	621	2014-10-30 00:00:00	2017-09-22 00:00:00	ANCIEN	\N	\N	\N	04041B	2014-10-30 12:06:38	2017-09-24 11:09:53
21655	600	2014-10-30 00:00:00	2017-09-22 00:00:00	ANCIEN	\N	\N	\N	04041B	2014-10-30 12:06:38	2017-09-24 11:09:53
21656	641	2014-10-30 00:00:00	2017-09-22 00:00:00	ANCIEN	\N	\N	\N	04041B	2014-10-30 12:06:38	2017-09-24 11:09:53
21657	629	2014-10-30 00:00:00	2017-09-22 00:00:00	ANCIEN	\N	\N	\N	04041B	2014-10-30 12:06:38	2017-09-24 11:09:53
21658	605	2014-10-30 00:00:00	2017-09-22 00:00:00	ANCIEN	\N	\N	\N	04041B	2014-10-30 12:06:38	2017-09-24 11:09:53
21659	594	2014-10-30 00:00:00	2017-09-22 00:00:00	ANCIEN	\N	\N	\N	04041B	2014-10-30 12:06:38	2017-09-24 11:09:53
21660	627	2014-10-30 00:00:00	2017-09-22 00:00:00	ANCIEN	\N	\N	\N	04041B	2014-10-30 12:06:38	2017-09-24 11:09:53
21686	620	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01057W	2014-10-30 14:17:28	\N
21687	605	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01057W	2014-10-30 14:17:28	\N
21688	598	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01057W	2014-10-30 14:17:28	\N
21689	581	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01057W	2014-10-30 14:17:28	\N
21690	589	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01057W	2014-10-30 14:17:28	\N
21691	608	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01057W	2014-10-30 14:17:28	\N
22224	579	2014-11-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01019Q	2014-11-14 14:49:37	\N
22233	588	2014-11-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08017T	2014-11-18 14:12:56	\N
22342	591	2014-12-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	2014-12-16 10:50:29	2017-07-20 14:38:36
22364	619	2014-12-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11039M	2014-12-18 16:35:35	\N
22386	615	2015-01-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95067Q	2015-01-14 16:27:09	\N
22450	530	2015-01-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98053W	2015-01-26 12:04:28	\N
22471	619	2015-01-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	10006L	2015-01-28 12:22:23	\N
22472	530	2015-01-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14093U	2015-01-28 12:22:46	\N
22473	578	2015-01-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2015-01-28 12:23:00	\N
22505	582	2015-01-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08009T	2015-02-03 10:48:53	\N
22784	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08055A	\N	\N
22785	909	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	2017-09-24 17:04:02
22786	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	\N	\N
22788	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08024S	\N	\N
22789	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14038Y	\N	\N
22790	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	\N
22791	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01057W	\N	\N
22792	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01025N	\N	\N
22793	909	2014-10-01 00:00:00	2017-09-22 00:00:00	ANCIEN	\N	\N	\N	04041B	\N	2017-09-24 11:09:53
22795	909	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11107G	\N	2017-09-24 17:06:55
22796	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04044E	\N	\N
22797	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14239U	\N	\N
22798	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14061L	\N	\N
22799	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14207L	\N	\N
22800	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14123H	\N	\N
22801	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04038G	\N	\N
22802	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11097X	\N	\N
22803	909	2014-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	90003B	\N	2017-10-01 10:01:39
22804	909	2014-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	\N	2017-10-01 09:41:22
22805	909	2014-10-01 00:00:00	2017-07-22 00:00:00	ANCIEN	\N	\N	\N	14037X	\N	2017-07-24 09:58:00
22806	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14151M	\N	\N
22807	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14213J	\N	\N
22808	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
22809	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	80013X	\N	\N
22810	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
22811	909	2014-10-01 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	95020Y	\N	2015-06-12 16:01:25
22815	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14259Y	\N	\N
22818	908	2014-10-01 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	98046X	\N	2017-09-25 09:56:00
22819	908	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11109J	\N	\N
22820	908	2014-10-01 00:00:00	2014-11-30 00:00:00	ANCIEN	\N	\N	\N	14053L	\N	\N
22821	908	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14030Q	\N	\N
22822	908	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	\N	\N
22946	640	2015-02-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14038Y	2015-02-19 18:06:00	\N
22950	918	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11043H	\N	\N
22956	918	2014-10-01 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	98027U	\N	2015-06-12 16:01:58
22957	918	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01059Y	\N	2017-09-24 17:35:15
22963	922	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11020A	\N	2017-09-24 16:24:51
22964	922	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	\N
22984	532	2015-02-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01016M	2015-03-03 10:25:00	\N
22986	908	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04033B	\N	\N
22989	918	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08031R	\N	\N
22992	908	2014-10-01 00:00:00	2016-01-11 00:00:00	ANCIEN	\N	\N	\N	11060J	\N	2016-01-11 17:34:09
22994	965	2014-09-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11029K	2015-03-03 13:28:18	\N
22995	965	2014-09-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11095V	2015-03-03 13:28:35	\N
22996	965	2014-09-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14083S	2015-03-03 13:28:49	\N
22997	965	2014-09-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14038Y	2015-03-03 13:29:01	\N
22998	965	2014-09-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	14209N	2015-03-03 13:29:12	2017-10-01 10:34:22
22999	965	2014-09-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	2015-03-03 13:29:30	2017-10-01 09:41:22
23000	965	2014-09-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01024M	2015-03-03 13:29:39	\N
23001	965	2014-09-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14042U	2015-03-03 13:29:54	\N
23002	965	2014-09-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11083R	2015-03-03 13:30:09	\N
23003	965	2014-09-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14179A	2015-03-03 13:30:20	\N
23004	965	2014-09-01 00:00:00	2017-09-22 00:00:00	ANCIEN	\N	\N	\N	04041B	2015-03-03 13:30:32	2017-09-24 11:09:53
23005	965	2014-09-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	08044W	2015-03-03 13:30:48	\N
23006	965	2014-09-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14241N	2015-03-03 13:31:02	\N
23007	965	2014-09-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14159V	2015-03-03 13:31:11	\N
23008	965	2014-09-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11111C	2015-03-03 13:31:23	\N
23009	965	2014-09-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	08039A	2015-03-03 13:31:34	\N
23010	965	2014-09-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	08017T	2015-03-03 13:31:49	\N
23011	965	2014-09-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01061S	2015-03-03 13:32:01	\N
23012	965	2014-09-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14205J	2015-03-03 13:32:12	\N
20357	598	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98022P	2014-10-15 11:55:09	2016-03-31 15:51:47
20358	629	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08039A	2014-10-15 11:56:13	\N
20359	600	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08039A	2014-10-15 11:56:13	\N
20360	620	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08039A	2014-10-15 11:56:13	\N
20361	617	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08039A	2014-10-15 11:56:13	\N
20362	595	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08039A	2014-10-15 11:56:13	\N
20363	629	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14223L	2014-10-15 11:56:32	\N
20364	589	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14223L	2014-10-15 11:56:32	\N
20365	595	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14223L	2014-10-15 11:56:32	\N
20377	572	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	77002U	2014-10-15 16:14:32	2015-01-14 16:22:04
20378	583	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01041N	2014-10-15 16:19:01	\N
21699	581	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	2014-10-30 14:57:29	2017-10-01 10:39:22
20380	602	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01041N	2014-10-15 16:19:01	\N
20381	572	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01041N	2014-10-15 16:19:01	\N
20382	622	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01041N	2014-10-15 16:19:01	\N
20383	588	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01041N	2014-10-15 16:19:01	\N
20384	590	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11044J	2014-10-15 16:19:22	\N
21692	592	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	05012A	2014-10-30 14:45:13	\N
21693	576	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	05012A	2014-10-30 14:45:13	\N
21694	978	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	05012A	2014-10-30 14:45:13	\N
21695	578	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	05012A	2014-10-30 14:45:13	\N
21696	602	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	05012A	2014-10-30 14:45:13	\N
21697	590	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	05012A	2014-10-30 14:45:14	\N
21698	978	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	2014-10-30 14:57:29	2017-10-01 10:39:22
21700	602	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	2014-10-30 14:57:29	2017-10-01 10:39:22
21701	577	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	2014-10-30 14:57:30	2017-10-01 10:39:22
21702	582	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	2014-10-30 14:57:30	2017-10-01 10:39:22
21703	640	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	2014-10-30 14:57:30	2017-10-01 10:39:22
21704	584	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	2014-10-30 14:57:30	2017-10-01 10:39:22
21705	653	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	2014-10-30 14:57:30	2017-10-01 10:39:22
21706	578	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	2014-10-30 14:57:30	2017-10-01 10:39:23
21707	608	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	2014-10-30 14:57:30	2017-10-01 10:39:23
21708	622	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	2014-10-30 14:57:30	2017-10-01 10:39:23
21709	583	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	2014-10-30 14:57:30	2017-10-01 10:39:23
21710	616	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	2014-10-30 14:57:30	2017-10-01 10:39:23
21711	590	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	2014-10-30 14:57:30	2017-10-01 10:39:23
21712	626	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04092N	2014-10-30 15:01:22	\N
21713	651	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04092N	2014-10-30 15:01:22	\N
21714	659	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04092N	2014-10-30 15:01:22	\N
21715	653	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04092N	2014-10-30 15:01:22	\N
21717	625	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14231L	2014-10-30 15:34:50	\N
21718	600	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14231L	2014-10-30 15:34:50	\N
21719	602	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14038Y	2014-10-30 15:35:26	\N
21720	622	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14038Y	2014-10-30 15:35:26	2015-03-10 10:00:45
21721	629	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14038Y	2014-10-30 15:35:27	\N
21722	610	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14038Y	2014-10-30 15:35:27	\N
21723	578	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14038Y	2014-10-30 15:35:27	\N
21724	642	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14038Y	2014-10-30 15:35:27	\N
34439	938	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	21064G	\N	\N
21725	550	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14038Y	2014-10-30 15:35:27	\N
21726	615	2014-10-29 00:00:00	2017-07-22 00:00:00	ANCIEN	\N	\N	\N	14037X	2014-10-30 15:35:53	2017-07-24 09:58:00
21727	602	2014-10-29 00:00:00	2017-07-22 00:00:00	ANCIEN	\N	\N	\N	14037X	2014-10-30 15:35:53	2017-07-24 09:58:00
21728	573	2014-10-29 00:00:00	2017-07-22 00:00:00	ANCIEN	\N	\N	\N	14037X	2014-10-30 15:35:54	2017-07-24 09:58:00
21729	629	2014-10-29 00:00:00	2017-07-22 00:00:00	ANCIEN	\N	\N	\N	14037X	2014-10-30 15:35:54	2017-07-24 09:58:00
21730	534	2014-10-29 00:00:00	2017-07-22 00:00:00	ANCIEN	\N	\N	\N	14037X	2014-10-30 15:35:54	2017-07-24 09:58:00
21731	580	2014-10-29 00:00:00	2017-07-22 00:00:00	ANCIEN	\N	\N	\N	14037X	2014-10-30 15:35:54	2017-07-24 09:58:00
21732	634	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04067M	2014-10-30 15:36:54	\N
21733	616	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04067M	2014-10-30 15:36:54	\N
21734	532	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04067M	2014-10-30 15:36:54	\N
21735	617	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04067M	2014-10-30 15:36:54	\N
21736	851	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04067M	2014-10-30 15:36:54	\N
21737	979	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04067M	2014-10-30 15:36:54	2017-09-24 17:47:27
21738	556	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04067M	2014-10-30 15:36:54	\N
21739	529	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04067M	2014-10-30 15:36:54	\N
21740	626	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04067M	2014-10-30 15:36:54	\N
21741	590	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	07026Q	2014-10-30 15:38:28	\N
21742	572	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	07026Q	2014-10-30 15:38:28	\N
21743	577	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	07026Q	2014-10-30 15:38:28	2017-09-24 19:25:10
21744	621	2014-10-30 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	95039L	2014-10-30 15:39:11	2015-10-13 14:18:31
21745	590	2014-10-30 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	95039L	2014-10-30 15:39:11	2015-10-13 14:18:46
21746	629	2014-10-30 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	95039L	2014-10-30 15:39:11	2015-10-13 14:18:56
21747	604	2014-10-30 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	95039L	2014-10-30 15:39:11	2015-10-13 14:18:39
21748	595	2014-10-30 00:00:00	2015-10-11 00:00:00	ANCIEN	\N	\N	\N	95039L	2014-10-30 15:39:11	2015-10-13 14:18:52
21749	603	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01056V	2014-10-30 15:40:13	\N
21750	590	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01056V	2014-10-30 15:40:13	\N
21751	584	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01056V	2014-10-30 15:40:13	\N
21752	629	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01056V	2014-10-30 15:40:13	\N
21753	579	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01056V	2014-10-30 15:40:13	\N
21754	556	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01056V	2014-10-30 15:40:13	\N
21755	597	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01056V	2014-10-30 15:40:13	\N
21756	608	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01056V	2014-10-30 15:40:13	\N
21757	661	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01056V	2014-10-30 15:40:13	\N
21758	576	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11088W	2014-10-30 15:40:32	\N
21759	602	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08043V	2014-10-30 15:40:52	\N
21760	622	2014-10-29 00:00:00	2015-04-08 00:00:00	ANCIEN	\N	\N	\N	08043V	2014-10-30 15:40:52	2015-04-15 15:22:20
21761	619	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08043V	2014-10-30 15:40:52	\N
21762	600	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08043V	2014-10-30 15:40:52	\N
21763	625	2014-10-24 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	98046X	2014-10-30 15:41:17	2017-09-25 09:56:00
20385	584	2014-10-14 00:00:00	2015-04-07 00:00:00	ANCIEN	\N	\N	\N	11108H	2014-10-15 16:46:40	2015-04-07 16:50:27
20386	661	2014-10-14 00:00:00	2015-04-07 00:00:00	ANCIEN	\N	\N	\N	11108H	2014-10-15 16:46:40	2015-04-07 16:50:27
20387	597	2014-10-14 00:00:00	2015-04-07 00:00:00	ANCIEN	\N	\N	\N	11108H	2014-10-15 16:46:40	2015-04-07 16:50:27
20388	628	2014-10-14 00:00:00	2015-04-07 00:00:00	ANCIEN	\N	\N	\N	11108H	2014-10-15 16:46:40	2015-04-07 16:50:27
20389	622	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11072N	2014-10-15 16:47:00	\N
20390	578	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11072N	2014-10-15 16:47:00	\N
22349	643	2014-12-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	2014-12-16 18:18:14	\N
22350	577	2014-12-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	2014-12-16 18:18:14	2015-03-20 09:52:38
22351	659	2014-12-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	2014-12-16 18:18:14	\N
22352	590	2014-12-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	2014-12-16 18:18:14	\N
22353	979	2014-12-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	2014-12-16 18:18:14	\N
22354	591	2014-12-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14051J	2014-12-16 18:18:36	2017-07-20 14:38:49
22355	591	2014-12-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04059M	2014-12-16 18:18:47	2017-07-20 14:38:10
22356	550	2014-12-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11099A	2014-12-17 09:45:59	\N
22357	963	2014-12-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11112D	2014-12-17 12:14:01	2017-09-24 16:45:26
22371	575	2014-11-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08038Y	2014-12-19 15:53:45	\N
22372	851	2014-12-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11014C	2014-12-19 18:00:30	\N
22403	578	2015-01-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11095V	2015-01-19 15:00:18	\N
22415	603	2015-01-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08021P	2015-01-21 10:08:50	\N
22436	651	2015-01-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04049K	2015-01-22 16:20:15	\N
22448	616	2015-01-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11077T	2015-01-23 17:55:23	\N
22449	615	2015-01-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92018S	2015-01-23 17:56:17	\N
22511	605	2015-02-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	05012A	2015-02-04 13:41:45	\N
22547	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14071N	\N	\N
22549	907	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11094U	\N	2017-09-24 13:25:54
22550	907	2014-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	90003B	\N	2017-10-01 10:01:39
22551	907	2014-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	\N	2017-10-01 09:41:22
22552	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11090Q	\N	\N
22553	907	2014-10-01 00:00:00	2017-07-22 00:00:00	ANCIEN	\N	\N	\N	14037X	\N	2017-07-24 09:58:00
22554	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
22555	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
22556	907	2014-10-01 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	95020Y	\N	2015-06-12 16:01:25
22557	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
22558	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14199E	\N	\N
22559	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14259Y	\N	\N
22560	907	2014-10-01 00:00:00	2016-11-17 00:00:00	ANCIEN	\N	\N	\N	07032N	\N	2016-11-18 12:37:49
22562	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98050T	\N	\N
22563	907	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11036J	\N	2017-09-24 18:16:52
22564	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14059S	\N	\N
22565	907	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	92045V	\N	2017-09-24 17:29:37
22566	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08062Y	\N	\N
22567	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11103C	\N	\N
22568	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14195A	\N	\N
22570	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14079W	\N	\N
22571	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14173T	\N	\N
22573	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11081P	\N	\N
22574	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08055A	\N	\N
22575	907	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	2017-09-24 17:04:02
22576	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	\N	\N
22577	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04033B	\N	\N
22578	907	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11112D	\N	2017-09-24 16:45:26
22579	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14221J	\N	\N
22580	907	2014-10-01 00:00:00	2014-10-01 00:00:00	ANCIEN	\N	\N	\N	14093U	\N	\N
22581	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14169X	\N	\N
22582	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08024S	\N	\N
22583	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01057W	\N	\N
22584	907	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	12042Y	\N	2017-09-24 19:31:54
22585	907	2014-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	98021N	\N	2017-10-01 09:22:38
22586	907	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01022K	\N	2017-09-24 17:14:26
22587	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08034U	\N	\N
22588	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	07034Q	\N	\N
22589	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14105F	\N	\N
22590	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
22658	1003	2015-01-28 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11094U	\N	2017-09-24 13:25:54
22660	1003	2015-01-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04038G	\N	\N
22962	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
22965	601	2015-02-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	2015-02-23 16:23:01	2015-03-11 10:58:01
23065	910	2014-09-03 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11098Y	\N	\N
23070	640	2015-02-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14061L	2015-03-04 09:43:51	\N
23102	550	2015-03-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	07004J	2015-03-05 16:03:39	\N
23103	612	2015-03-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	07004J	2015-03-05 16:03:39	\N
23170	979	2015-03-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14241N	2015-03-19 12:21:37	\N
23171	530	2015-03-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	07004J	2015-03-24 13:48:12	\N
23198	948	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11048N	\N	\N
23259	910	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14271U	\N	2017-09-24 17:06:55
23279	907	2014-10-01 00:00:00	2014-10-01 00:00:00	ANCIEN	\N	\N	\N	14265W	\N	\N
23285	576	2015-06-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14271U	2015-06-04 09:56:20	2017-09-24 17:06:55
23286	597	2015-06-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14271U	2015-06-04 09:56:20	2017-09-24 17:06:55
23392	919	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14231L	\N	\N
23393	910	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14231L	\N	\N
23419	928	2015-11-05 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	07029T	\N	\N
23581	CHRETORIENT	2016-02-12 00:00:00	2017-12-06 00:00:00	ANCIEN	\N	\N	\N	08024S	2016-02-12 12:41:52	2017-12-08 09:45:37
23582	CHRETORIENT	2016-02-12 00:00:00	2020-10-19 00:00:00	ANCIEN	\N	\N	\N	98029W	2016-02-12 12:42:02	\N
23583	CHRETORIENT	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	14195A	2016-02-12 12:42:13	\N
23584	CHRETORIENT	2016-02-12 00:00:00	2020-09-24 00:00:00	ANCIEN	\N	\N	\N	08041T	2016-02-12 12:42:52	\N
23585	CHRETORIENT	2016-02-12 00:00:00	2017-07-21 00:00:00	ANCIEN	\N	\N	\N	01007L	2016-02-12 12:43:01	2017-07-24 09:56:26
23586	CHRETORIENT	2016-02-12 00:00:00	2016-12-31 00:00:00	ANCIEN	\N	\N	\N	07024N	2016-02-12 12:57:08	2017-01-03 11:09:24
23587	CHRETORIENT	2016-02-12 00:00:00	2023-10-05 00:00:00	ANCIEN	\N	\N	\N	01048V	2016-02-12 12:57:19	\N
23588	CHRETORIENT	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	08034U	2016-02-12 12:57:29	\N
23589	CHRETORIENT	2016-02-12 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	08011M	2016-02-12 12:57:36	\N
23590	CHRETORIENT	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	14169X	2016-02-12 12:57:52	\N
23591	CHRETORIENT	2016-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	86044G	2016-02-12 12:57:59	2017-10-01 10:32:58
23601	623	2016-03-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14065Q	2016-03-31 09:41:21	\N
23612	604	2016-05-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14061L	2016-05-04 11:23:52	\N
20586	583	2014-10-17 00:00:00	2015-03-03 00:00:00	ANCIEN	\N	\N	\N	11051H	2014-10-21 09:23:47	2015-03-03 10:16:55
20587	584	2014-10-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14159V	2014-10-21 09:24:03	\N
20588	590	2014-10-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14159V	2014-10-21 09:24:03	\N
20589	595	2014-10-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14159V	2014-10-21 09:24:03	\N
20590	589	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14001X	2014-10-21 09:24:27	\N
20591	585	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14001X	2014-10-21 09:24:27	2017-07-17 11:34:11
20592	573	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14001X	2014-10-21 09:24:27	\N
20593	621	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14001X	2014-10-21 09:24:27	\N
20594	978	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14001X	2014-10-21 09:24:27	\N
20595	591	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14001X	2014-10-21 09:24:27	2017-07-17 11:32:43
21228	661	2014-10-27 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	92035T	2014-10-27 16:55:09	2015-01-08 17:14:29
21229	628	2014-10-27 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	92035T	2014-10-27 16:55:09	2015-01-08 17:14:29
21230	597	2014-10-27 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	92035T	2014-10-27 16:55:09	2015-01-08 17:14:29
21231	659	2014-10-27 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	92035T	2014-10-27 16:55:09	2015-01-08 17:14:29
21232	589	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11067R	2014-10-27 16:55:40	\N
21233	602	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11067R	2014-10-27 16:55:40	\N
21234	598	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11067R	2014-10-27 16:55:40	\N
21235	651	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01016M	2014-10-27 16:57:25	\N
21236	642	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01016M	2014-10-27 16:57:25	\N
21237	573	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01016M	2014-10-27 16:57:25	\N
21238	659	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98018T	2014-10-27 16:58:11	\N
21487	622	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04094Q	2014-10-29 13:22:07	\N
21488	583	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04094Q	2014-10-29 13:22:07	\N
21489	576	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04094Q	2014-10-29 13:22:07	\N
21490	602	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04094Q	2014-10-29 13:22:07	\N
21491	642	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04094Q	2014-10-29 13:22:07	\N
21498	578	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14017T	2014-10-29 14:28:24	\N
21499	618	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14017T	2014-10-29 14:28:24	\N
21500	584	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14017T	2014-10-29 14:28:24	\N
21501	574	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14017T	2014-10-29 14:28:24	\N
21502	622	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14017T	2014-10-29 14:28:24	\N
21614	644	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95067Q	2014-10-30 11:48:40	\N
21615	621	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95067Q	2014-10-30 11:48:40	\N
21616	594	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95067Q	2014-10-30 11:48:40	\N
21617	657	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95067Q	2014-10-30 11:48:40	2015-03-09 14:11:25
21618	581	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95067Q	2014-10-30 11:48:40	\N
21619	584	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95067Q	2014-10-30 11:48:40	\N
21620	617	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95067Q	2014-10-30 11:48:40	\N
21621	632	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95067Q	2014-10-30 11:48:40	\N
21622	573	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95067Q	2014-10-30 11:48:40	\N
21623	610	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95067Q	2014-10-30 11:48:40	\N
21624	659	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95067Q	2014-10-30 11:48:40	\N
21625	590	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95067Q	2014-10-30 11:48:40	\N
21626	591	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95067Q	2014-10-30 11:48:40	2017-07-20 14:38:49
21627	620	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95067Q	2014-10-30 11:48:40	\N
21628	597	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95067Q	2014-10-30 11:48:40	\N
21629	575	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95067Q	2014-10-30 11:48:40	\N
21630	979	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95067Q	2014-10-30 11:48:40	\N
21631	596	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95067Q	2014-10-30 11:48:40	\N
21632	576	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95067Q	2014-10-30 11:48:40	\N
21633	629	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95067Q	2014-10-30 11:48:40	\N
21634	604	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95067Q	2014-10-30 11:48:40	\N
21635	598	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95067Q	2014-10-30 11:48:40	\N
21636	595	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95067Q	2014-10-30 11:48:40	\N
21637	624	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95067Q	2014-10-30 11:48:40	\N
21638	626	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95067Q	2014-10-30 11:48:41	\N
21639	629	2014-10-30 00:00:00	2017-09-22 00:00:00	ANCIEN	\N	\N	\N	89029V	2014-10-30 11:49:08	2017-09-24 11:09:53
21640	584	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	12041X	2014-10-30 11:55:54	\N
22115	573	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14053L	2014-11-05 15:05:42	\N
34449	1010	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	08018U	\N	\N
22358	591	2014-12-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11035H	2014-12-18 09:26:55	2017-09-24 18:16:52
22359	613	2014-12-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95035G	2014-12-18 10:00:08	\N
22360	674	2014-12-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11091R	2014-12-18 13:13:13	\N
22361	619	2014-12-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	80013X	2014-12-18 14:35:25	\N
22362	584	2014-12-18 00:00:00	2014-12-18 00:00:00	ANCIEN	\N	\N	\N	14135M	2014-12-18 14:47:16	2014-12-23 09:10:35
22387	608	2015-01-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01048V	2015-01-14 17:19:16	\N
22388	578	2015-01-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11111C	2015-01-14 17:32:03	\N
22506	572	2015-02-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11105E	2015-02-03 15:26:59	\N
22827	615	2015-02-03 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	01037S	2015-02-17 10:22:10	2016-12-12 16:10:15
23069	909	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11098Y	\N	2017-09-24 17:14:27
23187	659	2015-04-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	2015-04-07 14:01:11	\N
23443	583	2016-01-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14193X	2016-01-28 16:39:12	\N
23653	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08055A	\N	\N
23671	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11110B	\N	\N
23675	1005	2016-06-15 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11061K	\N	2017-09-24 17:42:25
23679	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	\N	\N
23681	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08016S	\N	\N
23685	1005	2016-06-15 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11059R	\N	2017-09-24 17:42:26
23688	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08012N	\N	\N
23689	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14111D	\N	\N
23692	1005	2016-06-15 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	2017-06-19 12:20:59
23693	1005	2016-06-15 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11014C	\N	2017-09-24 13:14:55
23699	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14135M	\N	\N
23703	1005	2016-06-15 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	2017-09-24 17:35:15
23752	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08015R	\N	\N
23835	907	2017-02-07 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14363X	\N	2017-09-24 19:25:10
20558	621	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04056J	2014-10-20 14:22:34	\N
20559	632	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04056J	2014-10-20 14:22:34	\N
20560	620	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04056J	2014-10-20 14:22:34	\N
20561	572	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04056J	2014-10-20 14:22:34	\N
20562	626	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04056J	2014-10-20 14:22:34	\N
20563	577	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04056J	2014-10-20 14:22:34	\N
20564	623	2014-10-16 00:00:00	2014-11-05 00:00:00	ANCIEN	\N	\N	\N	04056J	2014-10-20 14:22:34	2014-11-07 11:31:42
20565	573	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04056J	2014-10-20 14:22:34	\N
20566	978	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14028W	2014-10-20 14:23:02	\N
20567	626	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14028W	2014-10-20 14:23:02	\N
20568	618	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14028W	2014-10-20 14:23:02	\N
20569	609	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14028W	2014-10-20 14:23:02	\N
20570	633	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14028W	2014-10-20 14:23:02	2015-05-27 16:33:22
20571	642	2014-10-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11042G	2014-10-20 14:30:51	\N
20572	572	2014-10-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11042G	2014-10-20 14:30:51	\N
22319	616	2014-12-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04040A	2014-12-09 17:47:51	\N
22437	979	2015-01-22 00:00:00	2015-01-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	2015-01-22 16:35:48	2015-01-30 15:27:04
22828	907	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11095V	\N	2017-09-24 13:25:54
22847	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08061X	\N	\N
22848	922	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
23013	965	2014-09-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	04057K	2015-03-03 13:32:26	\N
23014	965	2014-09-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	04033B	2015-03-03 13:32:33	\N
23015	965	2014-09-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	04070G	2015-03-03 13:36:46	\N
23017	990	2014-09-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	04070G	2015-03-03 13:38:52	\N
23018	990	2014-09-01 00:00:00	2017-07-03 00:00:00	ANCIEN	\N	\N	\N	01044R	2015-03-03 13:39:08	2017-07-04 15:08:09
23019	990	2014-09-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11029K	2015-03-03 13:39:20	\N
23020	990	2014-09-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	14209N	2015-03-03 13:39:33	2017-10-01 10:34:22
23021	990	2014-09-01 00:00:00	2015-08-31 00:00:00	ANCIEN	\N	\N	\N	04035D	2015-03-03 13:39:41	\N
23022	990	2014-09-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14071N	2015-03-03 13:39:55	\N
23023	934	2014-09-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	04070G	2015-03-03 13:41:36	\N
23024	934	2014-09-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11039M	2015-03-03 13:41:49	\N
23025	934	2014-09-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11029K	2015-03-03 13:42:02	\N
23026	934	2014-09-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	88008L	2015-03-03 13:42:22	\N
23027	934	2014-09-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14259Y	2015-03-03 13:42:34	\N
23028	934	2014-09-01 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	01003G	2015-03-03 13:42:49	2017-05-16 15:18:13
23029	934	2014-09-01 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	08065C	2015-03-03 13:42:58	2017-09-25 09:57:52
23030	934	2014-09-01 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	01037S	2015-03-03 13:43:35	2016-12-12 16:10:15
23031	934	2014-09-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14199E	2015-03-03 13:43:46	\N
23032	934	2014-09-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14061L	2015-03-03 13:43:56	\N
23033	934	2014-09-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14073Q	2015-03-03 13:44:07	\N
23034	934	2014-09-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	08031R	2015-03-03 13:44:20	\N
23035	934	2014-09-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	08012N	2015-03-03 13:44:32	\N
23036	934	2014-09-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11014C	2015-03-03 13:44:46	\N
23037	934	2014-09-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14071N	2015-03-03 13:44:56	\N
23038	934	2014-09-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14193X	2015-03-03 13:45:10	\N
23039	934	2014-09-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11043H	2015-03-03 13:45:23	\N
23040	991	2014-09-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2015-03-03 13:57:05	\N
23041	991	2014-09-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08043V	2015-03-03 13:57:25	\N
23042	991	2014-09-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11029K	2015-03-03 13:57:38	2017-09-24 17:09:24
23043	991	2014-09-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08024S	2015-03-03 13:57:50	\N
23044	991	2014-09-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08044W	2015-03-03 13:58:08	\N
23046	586	2015-03-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95035G	2015-03-03 13:58:22	\N
23045	991	2014-09-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11104D	2015-03-03 13:58:20	\N
23047	991	2014-09-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14063N	2015-03-03 13:58:33	\N
23048	991	2014-09-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11014C	2015-03-03 13:58:43	2017-09-24 13:14:55
23049	966	2014-09-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2015-03-03 13:59:49	\N
23050	966	2014-09-01 00:00:00	2017-07-03 00:00:00	ANCIEN	\N	\N	\N	01044R	2015-03-03 14:00:04	2017-07-04 15:08:09
23051	966	2014-09-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08043V	2015-03-03 14:00:18	\N
23052	966	2014-09-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11029K	2015-03-03 14:00:31	2017-09-24 17:09:24
23053	966	2014-09-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	14209N	2015-03-03 14:00:41	2017-10-01 10:34:22
23054	966	2014-09-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11107G	2015-03-03 14:00:59	2017-09-24 17:06:55
23055	966	2014-09-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	02002K	2015-03-03 14:01:15	\N
23056	966	2014-09-01 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	01037S	2015-03-03 14:01:36	2016-12-12 16:10:15
23057	966	2014-09-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08044W	2015-03-03 14:01:46	\N
23058	966	2014-09-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08031R	2015-03-03 14:01:55	\N
23059	966	2014-09-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14225N	2015-03-03 14:02:08	\N
23072	908	2014-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	14247U	\N	2017-10-01 10:25:16
23080	906	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	04080J	\N	2017-09-24 17:47:27
23089	948	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08038Y	\N	\N
23090	948	2014-10-01 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	2017-05-16 15:18:13
23091	948	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	\N	\N
23092	948	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11014C	\N	2017-09-24 13:14:55
23093	948	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08021P	\N	\N
23094	948	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14237S	\N	\N
23095	948	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	2017-09-24 17:48:21
23096	600	2015-03-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	2015-03-05 11:47:23	\N
23109	918	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
23112	640	2015-03-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	10006L	2015-03-09 15:28:08	\N
23113	998	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11077T	\N	\N
23114	998	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08038Y	\N	\N
23115	998	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
23165	911	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	09001P	\N	2017-09-24 17:47:27
23176	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
23177	948	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
23182	575	2015-04-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04061F	2015-04-02 17:39:51	\N
23186	575	2015-04-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11063M	2015-04-03 10:02:30	\N
23192	661	2015-04-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08039A	2015-04-08 17:57:06	\N
23214	912	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14249W	\N	\N
23242	907	2014-10-01 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	2016-12-12 16:10:15
23243	913	2014-10-01 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	2016-12-12 16:10:15
23244	911	2014-10-01 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	2016-12-12 16:10:15
20329	6432	2014-10-14 00:00:00	2014-10-21 00:00:00	ANCIEN	\N	\N	\N	14197C	2014-10-14 12:24:49	2014-10-22 16:49:18
21461	602	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14213J	2014-10-29 12:04:40	\N
21462	583	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14213J	2014-10-29 12:04:40	\N
21463	978	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14213J	2014-10-29 12:04:40	\N
21464	578	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14213J	2014-10-29 12:04:40	\N
21465	590	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14213J	2014-10-29 12:04:40	\N
21466	576	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14213J	2014-10-29 12:04:40	\N
21467	643	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14213J	2014-10-29 12:04:40	\N
21468	574	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14213J	2014-10-29 12:04:40	\N
21764	590	2014-10-24 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	98046X	2014-10-30 15:41:17	2017-09-25 09:56:00
21765	578	2014-10-24 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	98046X	2014-10-30 15:41:17	2017-09-25 09:56:00
21766	618	2014-10-24 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	98046X	2014-10-30 15:41:17	2017-09-25 09:56:00
21767	573	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04085P	2014-10-30 15:41:48	\N
21768	622	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04085P	2014-10-30 15:41:48	\N
21769	620	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04085P	2014-10-30 15:41:48	\N
21770	642	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04085P	2014-10-30 15:41:48	\N
21771	550	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04085P	2014-10-30 15:41:48	\N
22258	646	2014-11-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11030C	2014-11-20 10:27:25	\N
22365	619	2014-12-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11089X	2014-12-18 17:46:35	\N
22366	619	2014-12-17 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	01037S	2014-12-18 17:46:44	2016-12-12 16:10:15
22373	661	2015-01-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11082Q	2015-01-07 09:46:51	\N
22374	615	2015-01-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04036E	2015-01-09 09:15:06	\N
22383	674	2015-01-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08034U	2015-01-14 13:10:46	2015-01-14 14:22:32
22384	651	2015-01-14 00:00:00	2015-02-19 00:00:00	ANCIEN	\N	\N	\N	01027Q	2015-01-14 13:10:58	2015-02-19 17:17:22
22531	550	2015-01-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08024S	2015-02-10 18:20:05	\N
22532	622	2015-02-11 00:00:00	2017-07-21 00:00:00	ANCIEN	\N	\N	\N	01007L	2015-02-11 09:44:08	2017-07-24 09:56:26
22850	596	2015-02-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	11026G	2015-02-18 16:03:24	2017-10-10 09:45:39
22851	617	2015-02-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04040A	2015-02-18 16:03:34	\N
22852	601	2015-02-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08047A	2015-02-18 16:03:44	\N
22863	908	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08043V	\N	\N
23073	965	2014-09-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	14247U	2015-03-04 15:55:55	2017-10-01 10:25:16
23119	922	2014-10-01 00:00:00	2016-01-11 00:00:00	ANCIEN	\N	\N	\N	11060J	\N	2016-01-11 17:34:09
23120	922	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14237S	\N	\N
23121	922	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04089T	\N	\N
23122	922	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01024M	\N	\N
23123	922	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
23124	922	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	92045V	\N	2017-09-24 17:29:37
23151	910	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14197C	\N	\N
23152	910	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
23153	990	2014-09-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14229S	2015-03-11 13:55:25	2015-03-11 13:59:46
23154	934	2017-07-04 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	87003B	2015-03-11 13:56:38	\N
23155	966	2014-09-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	87003B	2015-03-11 13:58:13	\N
23156	966	2014-09-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14229S	2015-03-11 13:58:24	\N
23161	663	2015-02-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01043Q	2015-03-13 16:37:41	\N
23164	911	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
23193	659	2015-04-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01047U	2015-04-09 09:47:01	2017-09-24 13:29:42
23194	619	2015-03-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11020A	2015-04-10 14:38:27	2017-09-24 16:24:51
23195	578	2015-03-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11020A	2015-04-10 14:38:27	2017-09-24 16:24:51
23212	998	2014-10-01 00:00:00	2016-04-04 00:00:00	ANCIEN	\N	\N	\N	14073Q	\N	\N
23210	966	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08024S	\N	\N
23211	965	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
23256	600	2015-05-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98050T	2015-05-12 16:50:00	\N
23272	922	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14271U	\N	2017-09-24 17:06:55
23403	910	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	\N	\N
23421	632	2015-11-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14269B	2015-11-06 16:52:53	2017-09-24 18:07:57
23423	919	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14265W	\N	\N
23441	610	2016-01-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14079W	2016-01-28 11:52:02	\N
23672	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14187A	\N	\N
23673	1005	2016-06-15 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	08065C	\N	2017-09-25 09:57:52
23684	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14159V	\N	\N
23686	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
23687	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14059S	\N	\N
23698	1005	2016-06-15 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	98021N	\N	2017-10-01 09:22:38
23705	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
23845	909	2016-11-10 00:00:00	2016-11-29 00:00:00	ANCIEN	\N	\N	\N	14263U	\N	\N
23846	909	2017-01-20 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14363X	\N	2017-09-24 19:25:10
23847	1005	2017-01-16 00:00:00	2017-12-31 00:00:00	ANCIEN	\N	\N	\N	14107H	\N	\N
23848	1005	2016-12-20 00:00:00	2017-02-01 00:00:00	ANCIEN	\N	\N	\N	14121F	\N	\N
23872	979	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	2017-10-10 09:45:39	\N
23873	589	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	2017-10-10 09:45:39	\N
23874	616	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	2017-10-10 09:45:39	\N
23875	663	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	2017-10-10 09:45:39	\N
23876	590	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	2017-10-10 09:45:39	\N
23877	615	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	2017-10-10 09:45:39	\N
23878	643	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	2017-10-10 09:45:39	\N
23931	604	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	2017-10-10 18:10:30	\N
24276	CHRETORIENT	2017-10-17 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	14249W	2017-10-18 11:38:12	\N
24399	583	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2017-10-19 15:01:57	\N
24446	598	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08017T	2017-10-20 16:37:31	\N
24447	573	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08017T	2017-10-20 16:37:31	\N
24448	581	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08017T	2017-10-20 16:37:31	\N
24449	626	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08017T	2017-10-20 16:37:31	\N
24450	979	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08017T	2017-10-20 16:37:31	\N
24451	574	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08017T	2017-10-20 16:37:31	\N
24452	583	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08017T	2017-10-20 16:37:31	\N
24453	604	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08017T	2017-10-20 16:37:31	\N
24454	622	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19683J	2017-10-20 16:38:35	\N
20232	990	2014-02-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	94003T	\N	2014-09-28 13:16:32
20233	990	2014-02-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	2014-03-06 17:36:28
20735	600	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04045F	2014-10-22 15:19:34	\N
20736	579	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04045F	2014-10-22 15:19:34	\N
20737	580	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04045F	2014-10-22 15:19:34	2015-04-10 15:10:38
20738	621	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04045F	2014-10-22 15:19:34	\N
20739	610	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04045F	2014-10-22 15:19:34	2015-08-31 09:34:34
20740	618	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04045F	2014-10-22 15:19:34	\N
20741	604	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04045F	2014-10-22 15:19:34	\N
20742	598	2014-10-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	14209N	2014-10-22 15:41:43	2017-10-01 10:34:22
20743	629	2014-10-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	14209N	2014-10-22 15:41:43	2017-10-01 10:34:22
20744	621	2014-10-16 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	14209N	2014-10-22 15:41:43	2017-10-01 10:34:22
20745	604	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08010L	2014-10-22 15:42:36	\N
20746	597	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08010L	2014-10-22 15:42:36	\N
20747	646	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08010L	2014-10-22 15:42:36	\N
20748	590	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08010L	2014-10-22 15:42:36	\N
20749	579	2014-10-22 00:00:00	2017-10-05 00:00:00	ANCIEN	\N	\N	\N	08010L	2014-10-22 15:42:36	2017-10-09 09:55:18
20750	584	2014-10-22 00:00:00	2017-10-05 00:00:00	ANCIEN	\N	\N	\N	08010L	2014-10-22 15:42:36	2017-10-09 09:55:18
20751	673	2014-10-22 00:00:00	2017-10-05 00:00:00	ANCIEN	\N	\N	\N	08010L	2014-10-22 15:42:36	2017-10-09 09:55:18
22320	571	2014-12-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11107G	2014-12-09 18:47:15	\N
22321	621	2014-12-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11107G	2014-12-09 18:47:15	\N
22322	647	2014-12-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11107G	2014-12-09 18:47:15	\N
22323	620	2014-12-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11107G	2014-12-09 18:47:15	\N
22324	571	2014-11-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11015D	2014-12-10 09:12:10	\N
22369	619	2014-12-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14133K	2014-12-19 12:48:33	\N
22855	550	2015-02-19 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	01037S	2015-02-18 16:21:11	2016-12-12 16:10:15
23086	948	2014-10-01 00:00:00	2014-10-01 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
23087	948	2014-10-01 00:00:00	2014-10-01 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
23088	948	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
23204	912	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	09001P	\N	2017-09-24 17:47:27
23209	965	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
23228	938	2015-03-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
23229	938	2015-03-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11049P	\N	\N
23230	938	2015-03-02 00:00:00	2015-10-12 00:00:00	ANCIEN	\N	\N	\N	95039L	\N	2015-10-12 09:39:31
23231	938	2015-03-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11100Y	\N	\N
23232	938	2015-03-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14059S	\N	\N
23235	938	2015-03-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	08047A	\N	\N
23237	938	2015-03-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	04080J	\N	\N
23238	938	2015-03-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14017T	\N	\N
23281	659	2015-05-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08031R	2015-06-02 15:00:05	\N
23446	534	2016-02-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14079W	2016-02-03 12:14:45	\N
23448	628	2015-12-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04080J	2016-02-03 16:25:31	2017-09-24 17:47:27
23615	609	2016-05-17 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	2016-05-18 09:41:45	2017-10-01 10:39:23
23619	617	2016-05-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14030Q	2016-05-26 10:38:28	\N
23624	1004	2016-06-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14239U	\N	\N
23654	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08043V	\N	\N
23659	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11101A	\N	\N
23652	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
23663	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14195A	\N	\N
23669	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	87003B	\N	\N
23670	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14197C	\N	\N
23674	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14199E	\N	\N
23676	1005	2016-06-15 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	14014Q	\N	2017-06-19 16:06:51
23677	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08041T	\N	\N
23678	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
23680	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14123H	\N	\N
23682	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	\N	\N
23683	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08031R	\N	\N
23690	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08053X	\N	\N
23691	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14221J	\N	\N
23694	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
23695	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14109K	\N	\N
23696	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14265W	\N	\N
23697	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08021P	\N	\N
23700	1005	2016-06-15 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01016M	\N	2017-09-24 17:09:24
23701	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11012A	\N	\N
23702	1005	2016-06-15 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14271U	\N	2017-09-24 17:06:55
23704	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
23706	1005	2016-06-15 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	92045V	\N	2017-09-24 17:29:37
23707	550	2016-06-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14241N	2016-06-16 16:22:19	\N
23710	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95037J	\N	\N
23711	550	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14123H	2016-06-21 16:34:25	\N
23723	918	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14207L	\N	\N
23749	623	2016-09-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14237S	2016-09-12 15:37:03	\N
23753	596	2016-09-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	2016-09-28 16:44:33	\N
23763	590	2016-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	02002K	2016-10-31 14:15:41	\N
23818	657	2016-11-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11036J	2016-12-01 09:58:05	2017-09-24 18:16:52
23819	624	2016-11-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14249W	2016-12-01 12:19:58	\N
23820	644	2016-11-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14249W	2016-12-01 12:19:58	\N
23829	597	2017-01-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	2017-01-24 14:52:06	\N
23850	575	2017-02-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14249W	2017-02-27 15:46:47	\N
23857	578	2017-04-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14031R	2017-05-16 14:42:50	\N
23858	623	2017-04-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14031R	2017-05-16 14:42:50	\N
21996	608	2014-10-31 00:00:00	2017-06-01 00:00:00	ANCIEN	\N	\N	\N	14175V	2014-11-03 09:33:45	2017-06-02 10:02:56
22003	573	2014-10-31 00:00:00	2017-06-01 00:00:00	ANCIEN	\N	\N	\N	14175V	2014-11-03 09:33:46	2017-06-02 10:02:56
24014	608	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01048V	2017-10-11 16:30:13	\N
24015	591	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19663E	2017-10-11 16:31:09	\N
24016	589	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19663E	2017-10-11 16:31:09	\N
24048	629	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14038Y	2017-10-12 12:21:31	\N
21373	581	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14093U	2014-10-28 18:51:00	\N
21374	584	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14093U	2014-10-28 18:51:00	\N
21375	583	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14093U	2014-10-28 18:51:00	\N
21376	661	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95015C	2014-10-28 18:51:21	\N
21377	584	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95015C	2014-10-28 18:51:21	\N
21378	583	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95015C	2014-10-28 18:51:21	\N
21379	602	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95015C	2014-10-28 18:51:21	\N
21380	610	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95015C	2014-10-28 18:51:21	\N
21381	584	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08062Y	2014-10-28 18:52:03	\N
21382	590	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08062Y	2014-10-28 18:52:03	\N
21550	604	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14105F	2014-10-30 09:17:31	\N
21551	673	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14105F	2014-10-30 09:17:45	\N
21552	659	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14105F	2014-10-30 09:17:45	\N
22074	588	2014-11-03 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	92035T	2014-11-03 16:15:20	2015-01-08 17:14:29
22185	585	2014-11-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14215L	2014-11-13 09:28:05	2017-07-20 11:45:11
22186	595	2014-11-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04078Q	2014-11-13 09:31:01	\N
22187	608	2014-11-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04078Q	2014-11-13 09:31:01	\N
22188	624	2014-11-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04078Q	2014-11-13 09:31:01	\N
22189	572	2014-11-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04078Q	2014-11-13 09:31:01	\N
22190	621	2014-11-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04078Q	2014-11-13 09:31:01	\N
22191	626	2014-11-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04078Q	2014-11-13 09:31:01	\N
22192	584	2014-11-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04078Q	2014-11-13 09:31:01	\N
22193	588	2014-11-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04078Q	2014-11-13 09:31:01	\N
22194	573	2014-11-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04078Q	2014-11-13 09:31:01	\N
22195	632	2014-11-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04078Q	2014-11-13 09:31:01	\N
22196	529	2014-11-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95062K	2014-11-13 14:23:20	\N
22197	643	2014-11-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92039X	2014-11-13 15:41:13	\N
22198	615	2014-11-03 00:00:00	2014-11-12 00:00:00	ANCIEN	\N	\N	\N	92039X	2014-11-13 15:41:13	2014-11-13 15:44:58
22199	622	2014-11-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92039X	2014-11-13 15:41:13	\N
22200	589	2014-11-03 00:00:00	2014-11-12 00:00:00	ANCIEN	\N	\N	\N	92039X	2014-11-13 15:41:13	2014-11-13 15:44:58
22201	576	2014-11-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92039X	2014-11-13 15:41:13	\N
22202	618	2014-11-03 00:00:00	2014-11-12 00:00:00	ANCIEN	\N	\N	\N	92039X	2014-11-13 15:41:13	2014-11-13 15:44:58
22203	642	2014-11-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92039X	2014-11-13 15:41:13	\N
22204	978	2014-11-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92039X	2014-11-13 15:41:13	\N
22205	661	2014-11-03 00:00:00	2014-11-12 00:00:00	ANCIEN	\N	\N	\N	92039X	2014-11-13 15:41:13	2014-11-13 15:44:58
22206	590	2014-11-03 00:00:00	2014-11-12 00:00:00	ANCIEN	\N	\N	\N	92039X	2014-11-13 15:41:13	2014-11-13 15:44:58
22207	634	2014-11-03 00:00:00	2014-11-12 00:00:00	ANCIEN	\N	\N	\N	92039X	2014-11-13 15:41:13	2014-11-13 15:44:58
22208	609	2014-11-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92039X	2014-11-13 15:41:13	\N
22209	626	2014-11-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92039X	2014-11-13 15:41:13	\N
22210	556	2014-11-03 00:00:00	2014-11-12 00:00:00	ANCIEN	\N	\N	\N	92039X	2014-11-13 15:41:13	2014-11-13 15:44:58
22211	577	2014-11-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92039X	2014-11-13 15:41:13	2017-09-24 13:47:46
22212	596	2014-11-03 00:00:00	2014-11-12 00:00:00	ANCIEN	\N	\N	\N	92039X	2014-11-13 15:41:13	2014-11-13 15:44:58
22213	613	2014-11-03 00:00:00	2014-11-12 00:00:00	ANCIEN	\N	\N	\N	92039X	2014-11-13 15:41:13	2014-11-13 15:44:58
22214	584	2014-11-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92039X	2014-11-13 15:41:13	\N
22215	979	2014-11-03 00:00:00	2014-11-12 00:00:00	ANCIEN	\N	\N	\N	92039X	2014-11-13 15:41:13	2014-11-13 15:44:58
22390	550	2014-12-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11029K	2015-01-15 09:39:23	\N
22391	578	2015-01-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	2015-01-15 09:39:42	2015-03-19 10:03:28
22392	615	2015-01-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	2015-01-15 09:39:42	\N
22644	948	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11043H	\N	\N
22645	948	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08055A	\N	\N
22646	948	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	2017-09-24 17:04:02
22647	948	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01046T	\N	2017-09-24 13:44:49
22653	948	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
22664	1003	2015-01-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14227Q	\N	\N
22832	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	\N	\N
22835	922	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14031R	\N	\N
22837	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
22838	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14191V	\N	\N
22839	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14237S	\N	\N
22840	907	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11059R	\N	2017-09-24 17:42:26
22841	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04089T	\N	\N
23213	965	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
23253	612	2015-05-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14237S	2015-05-06 17:18:42	\N
23282	957	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08028W	\N	\N
23300	928	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
23325	928	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11105E	\N	2017-09-24 18:20:10
23377	928	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08055A	\N	\N
23762	659	2016-10-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11094U	2016-10-28 15:40:44	2017-09-24 13:25:54
23776	919	2016-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11042G	\N	2017-09-24 17:35:15
23779	919	2016-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	80013X	\N	\N
23780	919	2016-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	87003B	\N	\N
23811	919	2016-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
23836	948	2017-02-07 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14363X	\N	2017-09-24 19:25:10
24356	610	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14193X	2017-10-18 17:46:48	\N
24357	624	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14081Q	2017-10-19 10:27:17	\N
24358	604	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14081Q	2017-10-19 10:27:17	\N
24359	598	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14081Q	2017-10-19 10:27:17	\N
24360	594	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14081Q	2017-10-19 10:27:17	\N
24361	584	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14081Q	2017-10-19 10:27:17	\N
24362	590	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14081Q	2017-10-19 10:27:17	\N
24363	618	2017-10-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04045F	2017-10-19 10:28:01	\N
24364	604	2017-10-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04045F	2017-10-19 10:28:01	\N
24365	579	2017-10-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04045F	2017-10-19 10:28:01	\N
24366	610	2017-10-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04045F	2017-10-19 10:28:01	\N
24367	600	2017-10-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04045F	2017-10-19 10:28:01	\N
24368	621	2017-10-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04045F	2017-10-19 10:28:01	\N
24369	595	2017-10-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04045F	2017-10-19 10:28:02	\N
24370	590	2017-10-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04045F	2017-10-19 10:28:02	\N
22171	641	2014-11-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	86044G	2014-11-12 17:23:03	2017-10-01 10:32:58
22172	598	2014-11-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	86044G	2014-11-12 17:23:03	2017-10-01 10:32:58
22173	629	2014-11-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	86044G	2014-11-12 17:23:03	2017-10-01 10:32:58
22174	572	2014-11-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	86044G	2014-11-12 17:23:03	2017-10-01 10:32:58
22175	573	2014-11-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	86044G	2014-11-12 17:23:03	2017-10-01 10:32:58
22176	534	2014-11-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	86044G	2014-11-12 17:23:03	2017-10-01 10:32:58
22177	579	2014-11-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08012N	2014-11-12 17:25:10	\N
22178	598	2014-11-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14081Q	2014-11-12 17:25:26	\N
22179	584	2014-11-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14081Q	2014-11-12 17:25:27	\N
22180	594	2014-11-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14081Q	2014-11-12 17:25:27	\N
22181	624	2014-11-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14081Q	2014-11-12 17:25:27	\N
22182	604	2014-11-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14081Q	2014-11-12 17:25:27	\N
22183	590	2014-11-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14081Q	2014-11-12 17:25:27	\N
22184	529	2014-11-12 00:00:00	2016-11-30 00:00:00	ANCIEN	\N	\N	\N	04048J	2014-11-12 17:38:29	2016-12-01 10:36:51
22370	629	2014-12-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11080N	2014-12-19 15:47:28	\N
22399	590	2015-01-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14169X	2015-01-16 11:19:49	\N
22468	530	2015-01-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14249W	2015-01-28 09:13:50	\N
22469	619	2015-01-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	2015-01-28 09:14:09	2015-03-16 18:44:13
22470	619	2015-01-22 00:00:00	2015-06-16 00:00:00	ANCIEN	\N	\N	\N	14079W	2015-01-28 10:05:29	2015-06-17 13:55:29
23082	957	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08038Y	\N	\N
23083	957	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11077T	\N	\N
23245	912	2014-10-01 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	2016-12-12 16:10:15
23249	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11066Q	\N	\N
23257	906	2014-10-01 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	14013P	\N	2017-06-19 16:06:01
23264	907	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14271U	\N	2017-09-24 17:06:55
23274	612	2015-05-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14199E	2015-05-22 15:24:39	\N
23277	612	2015-05-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14071N	2015-05-26 15:13:43	\N
23287	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14265W	\N	\N
23289	912	2014-10-01 00:00:00	2017-07-21 00:00:00	ANCIEN	\N	\N	\N	01007L	\N	2017-07-24 09:56:26
23291	938	2015-02-26 00:00:00	2016-12-31 00:00:00	ANCIEN	\N	\N	\N	14001X	\N	\N
23293	578	2015-06-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14277B	2015-06-16 17:37:42	\N
23362	933	2015-01-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	08015R	\N	\N
23381	911	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04097T	\N	\N
23394	911	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14265W	\N	\N
23395	910	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14265W	\N	\N
23400	913	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	\N	\N
23402	919	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	\N	\N
23404	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	\N	\N
23407	592	2015-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14079W	2015-10-21 11:00:08	\N
23408	623	2015-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14079W	2015-10-21 11:00:08	\N
23409	641	2015-10-15 00:00:00	2016-03-18 00:00:00	ANCIEN	\N	\N	\N	14079W	2015-10-21 11:00:08	2016-03-22 14:44:18
23410	628	2015-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92018S	2015-10-21 11:00:52	2017-09-24 18:16:52
23411	617	2015-10-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14073Q	2015-10-21 11:02:19	\N
23414	628	2015-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92031P	2015-10-29 17:24:09	2017-09-24 18:16:52
23422	616	2015-11-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11054L	2015-11-10 10:11:42	\N
23431	661	2015-11-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11106F	2015-11-26 18:05:51	2017-09-24 19:14:37
23433	550	2015-12-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14031R	2015-12-03 13:46:25	\N
23434	530	2015-12-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11049P	2015-12-03 15:11:15	\N
23435	576	2015-11-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	83047W	2015-12-14 16:22:25	2017-09-24 17:42:26
23436	612	2015-12-03 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	01037S	2015-12-14 16:23:06	2016-12-12 16:10:15
23437	586	2015-12-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	07034Q	2015-12-14 16:23:27	\N
23444	626	2016-01-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	07026Q	2016-01-28 17:06:18	2017-09-24 19:25:10
23605	911	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
23613	604	2016-05-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14079W	2016-05-04 14:35:24	\N
23614	604	2016-05-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	99004R	2016-05-04 16:09:23	\N
23623	582	2016-05-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04097T	2016-05-31 14:42:51	\N
23645	1004	2016-06-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	10006L	\N	\N
23728	919	2014-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	14209N	\N	2017-10-01 10:34:22
23766	919	2016-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
23768	919	2016-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08043V	\N	\N
23778	919	2016-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	\N	\N
23781	919	2016-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11110B	\N	\N
23782	919	2016-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14187A	\N	\N
23783	919	2016-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11107G	\N	2017-09-24 17:06:55
23786	919	2016-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11061K	\N	2017-09-24 17:42:25
23787	919	2016-10-01 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	14014Q	\N	2017-06-19 16:06:51
23789	919	2016-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
23790	919	2016-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	\N	\N
23791	919	2016-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14123H	\N	\N
23804	919	2016-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14109K	\N	\N
23805	919	2016-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	98021N	\N	2017-10-01 09:22:38
23806	919	2016-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01016M	\N	2017-09-24 17:09:24
23807	919	2016-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11012A	\N	\N
23808	919	2016-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	2017-09-24 17:35:15
23809	919	2016-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11097X	\N	\N
23812	919	2016-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	92045V	\N	2017-09-24 17:29:37
23828	629	2017-01-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14357A	2017-01-18 17:45:25	\N
23851	534	2017-03-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14089Y	2017-04-03 09:57:07	\N
23860	912	2017-06-13 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14026U	\N	\N
24082	589	2017-10-11 00:00:00	2020-09-29 00:00:00	ANCIEN	\N	\N	\N	04018C	2017-10-13 10:05:22	\N
24083	604	2017-10-11 00:00:00	2020-09-29 00:00:00	ANCIEN	\N	\N	\N	04018C	2017-10-13 10:05:22	\N
24084	598	2017-10-11 00:00:00	2020-09-29 00:00:00	ANCIEN	\N	\N	\N	04018C	2017-10-13 10:05:22	\N
24085	608	2017-10-11 00:00:00	2020-09-29 00:00:00	ANCIEN	\N	\N	\N	04018C	2017-10-13 10:05:22	\N
24455	634	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19683J	2017-10-20 16:38:35	\N
24552	584	2017-10-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14051J	2017-10-25 09:51:38	\N
24553	611	2017-10-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14051J	2017-10-25 09:51:38	\N
24554	604	2017-10-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14051J	2017-10-25 09:51:39	\N
24555	621	2017-10-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14051J	2017-10-25 09:51:39	\N
20221	907	2013-12-17 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08009T	\N	\N
21249	584	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08053X	2014-10-28 10:40:02	\N
21250	571	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08053X	2014-10-28 10:40:02	\N
21251	591	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08053X	2014-10-28 10:40:02	2017-07-20 14:38:36
21252	585	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08053X	2014-10-28 10:40:02	2017-07-20 11:43:02
21253	615	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08053X	2014-10-28 10:40:02	\N
21254	657	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08053X	2014-10-28 10:40:02	2015-03-09 14:11:20
21255	674	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08053X	2014-10-28 10:40:02	\N
21256	663	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08053X	2014-10-28 10:40:02	\N
21257	641	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08053X	2014-10-28 10:40:02	\N
21258	651	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08053X	2014-10-28 10:40:02	\N
21259	575	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08053X	2014-10-28 10:40:02	\N
21260	610	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08053X	2014-10-28 10:40:02	\N
21261	646	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08053X	2014-10-28 10:40:02	\N
21262	550	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08053X	2014-10-28 10:40:02	\N
21263	621	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04074L	2014-10-28 10:57:02	\N
21264	608	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04074L	2014-10-28 10:57:02	\N
21265	629	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04074L	2014-10-28 10:57:02	\N
22132	647	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08055A	2014-11-06 15:52:46	\N
22133	599	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08055A	2014-11-06 15:52:46	2015-03-20 11:38:15
22134	978	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08055A	2014-11-06 15:52:46	\N
22235	616	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14063N	2014-11-19 09:34:35	\N
22236	640	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14063N	2014-11-19 09:34:35	2016-02-02 18:00:43
22237	621	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14063N	2014-11-19 09:34:35	\N
22238	647	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14063N	2014-11-19 09:34:35	\N
22527	573	2015-01-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01043Q	2015-02-06 15:59:38	\N
22528	978	2015-02-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14199E	2015-02-06 15:59:49	2015-02-06 16:41:08
22831	922	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01015L	\N	2017-09-24 17:19:42
22836	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14026U	\N	\N
22844	907	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11014C	\N	2017-09-24 13:14:55
22845	907	2014-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	14209N	\N	2017-10-01 10:34:22
22846	922	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11089X	\N	2017-09-24 17:15:15
22856	907	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	92015P	\N	2017-09-24 13:14:55
23188	918	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14221J	\N	\N
23252	556	2015-02-13 00:00:00	2017-06-01 00:00:00	ANCIEN	\N	\N	\N	14175V	2015-05-06 10:09:49	2017-06-02 10:02:56
23603	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95037J	\N	\N
23629	1004	2016-06-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	\N	\N
23635	1004	2016-06-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14221J	\N	\N
23636	1004	2016-06-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11067R	\N	\N
23637	1004	2016-06-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14223L	\N	\N
23638	1004	2016-06-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
23642	1004	2016-06-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14331P	\N	\N
23643	1004	2016-06-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
23644	1004	2016-06-07 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11093T	\N	2017-09-24 12:57:09
23760	628	2016-07-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01027Q	2016-10-26 12:08:16	2017-09-24 17:28:55
23859	912	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14026U	\N	\N
24277	CHRETORIENT	2017-10-17 00:00:00	2020-10-19 00:00:00	ANCIEN	\N	\N	\N	04044E	2017-10-18 11:49:10	\N
24278	578	2017-10-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04089T	2017-10-18 12:15:02	\N
24427	573	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	18083K	2017-10-19 16:48:34	\N
24428	641	2017-10-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08048B	2017-10-20 09:47:29	\N
24429	629	2017-10-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08048B	2017-10-20 09:47:29	\N
24430	595	2017-10-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08048B	2017-10-20 09:47:29	\N
24431	591	2017-10-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08048B	2017-10-20 09:47:29	\N
24432	621	2017-10-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08048B	2017-10-20 09:47:29	\N
24433	602	2017-10-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	2017-10-20 09:48:17	\N
24434	590	2017-10-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	2017-10-20 09:48:17	\N
24435	621	2017-10-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	2017-10-20 09:48:17	\N
24436	589	2017-10-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	2017-10-20 09:48:17	\N
24437	601	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19415P	2017-10-20 09:49:41	\N
24438	583	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19415P	2017-10-20 09:49:41	\N
24439	621	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19415P	2017-10-20 09:49:41	\N
24441	595	2017-10-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19573D	2017-10-20 10:16:47	\N
24442	608	2017-10-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19573D	2017-10-20 10:16:47	\N
24443	590	2017-10-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19573D	2017-10-20 10:16:47	\N
24444	621	2017-10-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19573D	2017-10-20 10:16:47	\N
24545	979	2017-10-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08024S	2017-10-24 17:07:20	\N
24546	625	2017-10-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08024S	2017-10-24 17:07:20	\N
24547	642	2017-10-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08024S	2017-10-24 17:07:20	\N
24548	550	2017-10-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08024S	2017-10-24 17:07:20	\N
24765	591	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04059M	2017-10-27 09:58:29	\N
24766	581	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19637C	2017-10-27 09:58:45	\N
24767	663	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14121F	2017-10-27 09:59:15	\N
24768	584	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14121F	2017-10-27 09:59:15	\N
24769	604	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14121F	2017-10-27 09:59:15	\N
24770	979	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14061L	2017-10-27 10:00:17	\N
24771	573	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14061L	2017-10-27 10:00:17	\N
24772	651	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14061L	2017-10-27 10:00:17	\N
24773	580	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14061L	2017-10-27 10:00:17	\N
24774	604	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14061L	2017-10-27 10:00:17	\N
24775	601	2017-10-26 00:00:00	2020-09-29 00:00:00	ANCIEN	\N	\N	\N	04018C	2017-10-27 10:00:36	\N
24776	622	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14028W	2017-10-27 10:01:06	\N
24777	628	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14028W	2017-10-27 10:01:06	\N
24778	633	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14028W	2017-10-27 10:01:06	\N
24779	591	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14028W	2017-10-27 10:01:06	\N
24780	575	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19631V	2017-10-27 10:01:38	\N
24781	602	2017-10-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08019V	2017-10-27 11:28:12	\N
24782	642	2017-10-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08019V	2017-10-27 11:28:12	\N
22519	605	2015-02-04 00:00:00	2017-10-06 00:00:00	ANCIEN	\N	\N	\N	14249W	2015-02-05 09:35:37	2017-10-09 09:54:08
22520	602	2015-02-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	2015-02-05 09:35:47	\N
22521	978	2015-02-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	97011G	2015-02-05 09:36:25	\N
22522	851	2015-02-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	12042Y	2015-02-05 10:00:03	\N
22523	647	2014-12-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11042G	2015-02-05 10:02:37	\N
23077	965	2014-09-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14133K	2015-03-04 16:34:55	\N
23178	534	2015-03-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11082Q	2015-04-01 09:46:08	2017-09-24 19:16:18
23397	644	2015-01-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11049P	2015-10-07 09:32:02	\N
23442	906	2016-01-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11066Q	\N	\N
23630	1004	2016-06-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14231L	\N	\N
23639	1004	2016-06-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08061X	\N	\N
23640	1004	2016-06-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
23641	1004	2016-06-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14135M	\N	\N
23716	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11081P	\N	\N
23854	911	2016-12-20 00:00:00	2017-12-25 00:00:00	ANCIEN	\N	\N	\N	14231L	\N	\N
23855	911	2016-12-20 00:00:00	2017-06-30 00:00:00	ANCIEN	\N	\N	\N	14231L	\N	\N
24049	550	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14038Y	2017-10-12 12:21:31	\N
24050	610	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14038Y	2017-10-12 12:21:31	\N
24051	625	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14038Y	2017-10-12 12:21:31	\N
24052	573	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14038Y	2017-10-12 12:21:31	\N
24053	583	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14038Y	2017-10-12 12:21:31	\N
24054	642	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14038Y	2017-10-12 12:21:31	\N
24055	622	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14038Y	2017-10-12 12:21:31	\N
24056	573	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14031R	2017-10-12 14:55:16	\N
24057	623	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14031R	2017-10-12 14:55:16	\N
24058	621	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14031R	2017-10-12 14:55:16	\N
24059	622	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14031R	2017-10-12 14:55:16	\N
24060	602	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08028W	2017-10-12 14:56:19	\N
24061	963	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08028W	2017-10-12 14:56:19	\N
24062	597	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08069G	2017-10-12 15:01:55	\N
24063	579	2017-10-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04044E	2017-10-12 15:20:28	\N
24064	604	2017-10-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04044E	2017-10-12 15:20:28	\N
24065	610	2017-10-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04044E	2017-10-12 15:20:28	\N
24066	608	2017-10-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04044E	2017-10-12 15:20:28	\N
24067	629	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14357A	2017-10-12 15:27:28	\N
24068	583	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14357A	2017-10-12 15:27:28	\N
24069	617	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14357A	2017-10-12 15:27:28	\N
24070	602	2017-10-12 00:00:00	2018-08-06 00:00:00	ANCIEN	\N	\N	\N	95015C	2017-10-12 15:45:44	\N
24071	610	2017-10-12 00:00:00	2018-08-06 00:00:00	ANCIEN	\N	\N	\N	95015C	2017-10-12 15:45:44	\N
24072	583	2017-10-12 00:00:00	2018-08-06 00:00:00	ANCIEN	\N	\N	\N	95015C	2017-10-12 15:45:44	\N
24073	575	2017-10-11 00:00:00	2018-11-03 00:00:00	ANCIEN	\N	\N	\N	19251M	2017-10-12 15:50:22	\N
24074	595	2017-10-11 00:00:00	2018-11-03 00:00:00	ANCIEN	\N	\N	\N	19251M	2017-10-12 15:50:22	\N
24075	621	2017-10-11 00:00:00	2018-11-03 00:00:00	ANCIEN	\N	\N	\N	19251M	2017-10-12 15:50:22	\N
24076	584	2017-10-11 00:00:00	2018-11-03 00:00:00	ANCIEN	\N	\N	\N	19251M	2017-10-12 15:50:22	\N
24077	610	2017-10-11 00:00:00	2018-11-03 00:00:00	ANCIEN	\N	\N	\N	19251M	2017-10-12 15:50:22	\N
24078	641	2017-10-11 00:00:00	2018-11-03 00:00:00	ANCIEN	\N	\N	\N	19251M	2017-10-12 15:50:22	\N
24089	640	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	10006L	2017-10-13 16:28:53	\N
24090	619	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	10006L	2017-10-13 16:28:53	\N
24091	595	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	10006L	2017-10-13 16:28:53	\N
24092	612	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	10006L	2017-10-13 16:28:53	\N
24093	626	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	10006L	2017-10-13 16:28:53	\N
24371	573	2017-10-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11099A	2017-10-19 10:30:36	\N
24372	625	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19723Y	2017-10-19 10:31:19	\N
24373	604	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	2017-10-19 10:32:14	\N
24374	632	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	2017-10-19 10:32:14	\N
24375	615	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	2017-10-19 10:32:14	\N
24376	621	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	2017-10-19 10:32:14	\N
24377	590	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	2017-10-19 10:32:14	\N
24378	602	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	2017-10-19 10:32:14	\N
24379	627	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	2017-10-19 10:32:14	\N
24380	618	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	2017-10-19 10:32:14	\N
24381	624	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	2017-10-19 10:32:14	\N
24382	634	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	2017-10-19 10:32:14	\N
24383	588	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	2017-10-19 10:32:14	\N
24384	641	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	2017-10-19 10:32:14	\N
24385	601	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	2017-10-19 10:32:14	\N
24386	609	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	2017-10-19 10:32:14	\N
24387	600	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	2017-10-19 10:32:14	\N
24388	572	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	2017-10-19 10:32:14	\N
24389	584	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	2017-10-19 10:32:14	\N
24390	595	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	2017-10-19 10:32:14	\N
24391	651	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19319Q	2017-10-19 11:27:20	\N
24392	583	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01034P	2017-10-19 11:50:33	\N
24474	CHRETORIENT	2017-10-23 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	14331P	2017-10-23 10:01:44	\N
24477	574	2017-10-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08060W	2017-10-24 09:57:23	\N
24478	588	2017-10-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08060W	2017-10-24 09:57:23	\N
24479	622	2017-10-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08060W	2017-10-24 09:57:23	\N
24480	620	2017-10-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08060W	2017-10-24 09:57:23	\N
24481	979	2017-10-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08060W	2017-10-24 09:57:23	\N
24482	578	2017-10-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	2017-10-24 09:58:20	\N
24483	629	2017-10-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	2017-10-24 09:58:20	\N
24484	621	2017-10-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	2017-10-24 09:58:20	\N
24485	577	2017-10-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	2017-10-24 09:58:20	\N
24486	653	2017-10-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	2017-10-24 09:58:20	\N
24487	608	2017-10-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	2017-10-24 09:58:20	\N
24488	609	2017-10-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	2017-10-24 09:58:20	\N
24489	673	2017-10-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	2017-10-24 09:58:20	\N
24490	584	2017-10-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	2017-10-24 09:58:20	\N
22116	529	2014-11-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	96004D	2014-11-05 17:07:55	\N
22117	590	2014-10-23 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	14137P	2014-11-05 17:20:06	2015-06-12 15:59:18
22118	584	2014-10-23 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	14137P	2014-11-05 17:20:06	2015-06-12 15:59:18
22119	581	2014-10-23 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	14137P	2014-11-05 17:20:06	2015-06-12 15:59:18
22120	584	2014-10-22 00:00:00	2015-02-06 00:00:00	ANCIEN	\N	\N	\N	14043V	2014-11-05 17:20:20	2015-02-06 14:27:55
22121	651	2014-10-22 00:00:00	2015-02-06 00:00:00	ANCIEN	\N	\N	\N	14043V	2014-11-05 17:20:20	2015-02-06 14:27:55
22122	578	2014-10-22 00:00:00	2015-02-06 00:00:00	ANCIEN	\N	\N	\N	14043V	2014-11-05 17:20:20	2015-02-06 14:27:55
22123	663	2014-10-22 00:00:00	2015-02-06 00:00:00	ANCIEN	\N	\N	\N	14043V	2014-11-05 17:20:20	2015-02-06 14:27:55
22124	584	2014-10-22 00:00:00	2015-02-06 00:00:00	ANCIEN	\N	\N	\N	14044W	2014-11-05 17:20:46	2015-02-06 14:32:44
22125	651	2014-10-22 00:00:00	2015-02-06 00:00:00	ANCIEN	\N	\N	\N	14044W	2014-11-05 17:20:46	2015-02-06 14:32:44
22126	578	2014-10-22 00:00:00	2015-02-06 00:00:00	ANCIEN	\N	\N	\N	14044W	2014-11-05 17:20:46	2015-02-06 14:32:44
22127	663	2014-10-22 00:00:00	2015-02-06 00:00:00	ANCIEN	\N	\N	\N	14044W	2014-11-05 17:20:46	2015-02-06 14:32:44
22479	578	2015-01-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14105F	2015-01-29 16:02:56	\N
23398	628	2015-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14073Q	2015-10-07 15:28:43	\N
23449	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14331P	\N	\N
24456	573	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19683J	2017-10-20 16:38:35	\N
24457	572	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19683J	2017-10-20 16:38:35	\N
24458	583	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19683J	2017-10-20 16:38:35	\N
24459	602	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19683J	2017-10-20 16:38:35	\N
24460	628	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	98050T	2017-10-20 16:39:07	\N
24461	608	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	98050T	2017-10-20 16:39:07	\N
24462	624	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	98050T	2017-10-20 16:39:07	\N
24463	600	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	98050T	2017-10-20 16:39:07	\N
24464	632	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08014Q	2017-10-20 16:39:23	\N
24465	583	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08014Q	2017-10-20 16:39:23	\N
24466	598	2017-10-12 00:00:00	2019-06-24 00:00:00	ANCIEN	\N	\N	\N	04061F	2017-10-20 17:23:17	\N
24467	573	2017-10-12 00:00:00	2019-06-24 00:00:00	ANCIEN	\N	\N	\N	04061F	2017-10-20 17:23:17	\N
24468	572	2017-10-12 00:00:00	2019-06-24 00:00:00	ANCIEN	\N	\N	\N	04061F	2017-10-20 17:23:17	\N
24469	624	2017-10-12 00:00:00	2019-06-24 00:00:00	ANCIEN	\N	\N	\N	04061F	2017-10-20 17:23:17	\N
24470	575	2017-10-12 00:00:00	2019-06-24 00:00:00	ANCIEN	\N	\N	\N	04061F	2017-10-20 17:23:17	\N
24471	604	2017-10-12 00:00:00	2019-06-24 00:00:00	ANCIEN	\N	\N	\N	04061F	2017-10-20 17:23:17	\N
24472	587	2017-10-12 00:00:00	2019-06-24 00:00:00	ANCIEN	\N	\N	\N	04061F	2017-10-20 17:23:17	\N
24473	CHRETORIENT	2017-10-19 00:00:00	2020-09-29 00:00:00	ANCIEN	\N	\N	\N	04018C	2017-10-20 17:23:42	\N
24556	609	2017-10-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2017-10-25 09:53:02	\N
24624	595	2017-10-20 00:00:00	2020-08-02 00:00:00	ANCIEN	\N	\N	\N	14239U	2017-10-25 17:14:42	\N
24625	577	2017-10-20 00:00:00	2020-08-02 00:00:00	ANCIEN	\N	\N	\N	14239U	2017-10-25 17:14:42	\N
24626	634	2017-10-20 00:00:00	2020-08-02 00:00:00	ANCIEN	\N	\N	\N	14239U	2017-10-25 17:14:42	\N
24627	641	2017-10-20 00:00:00	2020-08-02 00:00:00	ANCIEN	\N	\N	\N	14239U	2017-10-25 17:14:42	\N
24628	598	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14355X	2017-10-25 17:15:09	\N
24629	575	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19413M	2017-10-25 17:15:30	\N
24630	625	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19503N	2017-10-25 17:15:47	\N
24631	604	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19503N	2017-10-25 17:15:47	\N
24632	622	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11072N	2017-10-25 17:16:38	\N
24633	651	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11072N	2017-10-25 17:16:38	\N
24634	663	2017-10-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	95037J	2017-10-25 17:17:07	\N
24635	622	2017-10-24 00:00:00	2017-11-09 00:00:00	ANCIEN	\N	\N	\N	95037J	2017-10-25 17:17:07	2017-11-10 11:39:17
24636	576	2017-10-24 00:00:00	2017-11-09 00:00:00	ANCIEN	\N	\N	\N	95037J	2017-10-25 17:17:07	2017-11-10 11:39:17
24637	595	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11085T	2017-10-25 17:20:52	\N
24638	641	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11085T	2017-10-25 17:20:52	\N
24639	598	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11085T	2017-10-25 17:20:52	\N
24640	629	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11085T	2017-10-25 17:20:52	\N
24641	621	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11085T	2017-10-25 17:20:52	\N
24642	584	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11085T	2017-10-25 17:20:52	\N
24658	617	2017-10-26 00:00:00	2019-03-08 00:00:00	ANCIEN	\N	\N	\N	04040A	2017-10-26 09:38:17	\N
24659	588	2017-10-26 00:00:00	2019-03-08 00:00:00	ANCIEN	\N	\N	\N	04040A	2017-10-26 09:38:17	\N
24660	579	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	2017-10-26 09:38:17	\N
24661	595	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	2017-10-26 09:38:17	\N
24662	624	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	2017-10-26 09:38:17	\N
24663	628	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	2017-10-26 09:38:17	\N
24664	623	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14237S	2017-10-26 09:48:04	\N
24665	610	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14237S	2017-10-26 09:48:04	\N
24666	618	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14237S	2017-10-26 09:48:04	\N
24667	659	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14237S	2017-10-26 09:48:05	\N
24668	597	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14237S	2017-10-26 09:48:05	\N
24669	632	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14281W	2017-10-26 09:48:40	\N
24670	583	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14281W	2017-10-26 09:48:40	\N
24671	598	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14281W	2017-10-26 09:48:40	\N
24672	674	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14281W	2017-10-26 09:48:40	\N
24673	572	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19333N	2017-10-26 09:49:28	\N
24674	578	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19333N	2017-10-26 09:49:28	\N
24675	601	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19511N	2017-10-26 10:01:17	\N
24676	599	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19511N	2017-10-26 10:01:17	\N
24677	579	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19511N	2017-10-26 10:01:17	\N
24678	589	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19511N	2017-10-26 10:01:17	\N
24679	604	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19511N	2017-10-26 10:01:17	\N
24680	621	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19511N	2017-10-26 10:01:17	\N
24681	629	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19511N	2017-10-26 10:01:17	\N
24682	CHRETORIENT	2017-10-24 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	19669L	2017-10-26 10:02:03	\N
24683	632	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	2017-10-26 10:02:03	\N
24684	978	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	2017-10-26 10:02:03	\N
24685	575	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	2017-10-26 10:02:03	\N
24686	595	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	2017-10-26 10:02:03	\N
24687	625	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	2017-10-26 10:02:03	\N
24688	573	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	2017-10-26 10:02:03	\N
24689	602	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	2017-10-26 10:02:03	\N
20228	909	2014-10-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	07030L	\N	2014-09-28 17:03:42
20577	642	2014-10-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14053L	2014-10-20 17:44:43	\N
20578	626	2014-10-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14053L	2014-10-20 17:44:43	\N
20579	625	2014-10-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14053L	2014-10-20 17:44:43	\N
20580	583	2014-10-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14053L	2014-10-20 17:44:43	\N
20581	572	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04042C	2014-10-20 17:45:03	\N
20582	621	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04042C	2014-10-20 17:45:03	\N
20583	629	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04042C	2014-10-20 17:45:03	\N
20584	598	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04042C	2014-10-20 17:45:03	\N
20585	653	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	2014-10-20 17:45:19	\N
21821	571	2014-10-29 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	01037S	2014-10-31 09:26:52	2016-12-12 16:10:15
21822	585	2014-10-29 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	01037S	2014-10-31 09:26:52	2016-12-12 16:10:15
21823	586	2014-10-29 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	01037S	2014-10-31 09:26:52	2016-12-12 16:10:15
21824	641	2014-10-29 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	01037S	2014-10-31 09:26:53	2016-12-12 16:10:15
21825	534	2014-10-29 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	01037S	2014-10-31 09:26:53	2016-12-12 16:10:15
21826	583	2014-10-29 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	01037S	2014-10-31 09:26:53	2016-12-12 16:10:15
21827	642	2014-10-29 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	01037S	2014-10-31 09:26:53	2016-12-12 16:10:15
21829	673	2014-10-29 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	01037S	2014-10-31 09:26:53	2016-12-12 16:10:15
21830	602	2014-10-29 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	01037S	2014-10-31 09:26:53	2016-12-12 16:10:15
21831	595	2014-10-29 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	01037S	2014-10-31 09:26:53	2016-12-12 16:10:15
21832	661	2014-10-29 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	01037S	2014-10-31 09:26:53	2016-12-12 16:10:15
21833	577	2014-10-29 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	01037S	2014-10-31 09:26:53	2016-12-12 16:10:15
21835	623	2014-10-29 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	01037S	2014-10-31 09:26:53	2016-12-12 16:10:15
21836	634	2014-10-29 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	01037S	2014-10-31 09:26:53	2016-12-12 16:10:15
21837	659	2014-10-29 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	01037S	2014-10-31 09:26:53	2016-12-12 16:10:15
21838	597	2014-10-29 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	01037S	2014-10-31 09:26:53	2016-12-12 16:10:15
21839	620	2014-10-29 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	01037S	2014-10-31 09:26:53	2016-12-12 16:10:15
21841	575	2014-10-29 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	01037S	2014-10-31 09:26:53	2016-12-12 16:10:15
21842	613	2014-10-29 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	01037S	2014-10-31 09:26:53	2016-12-12 16:10:15
21843	674	2014-10-29 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	01037S	2014-10-31 09:26:53	2016-12-12 16:10:15
21844	651	2014-10-29 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	01037S	2014-10-31 09:26:53	2016-12-12 16:10:15
21846	584	2014-10-29 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	01037S	2014-10-31 09:26:53	2016-12-12 16:10:15
21847	573	2014-10-29 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	01037S	2014-10-31 09:26:54	2016-12-12 16:10:15
21848	600	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	11069T	2014-10-31 09:28:53	2016-03-11 18:02:50
21849	599	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	11069T	2014-10-31 09:28:53	2016-03-11 18:02:50
21850	571	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	11069T	2014-10-31 09:28:53	2016-03-11 18:02:50
21851	598	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	11069T	2014-10-31 09:28:53	2016-03-11 18:02:50
21852	586	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	11069T	2014-10-31 09:28:53	2016-03-11 18:02:50
21853	578	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	11069T	2014-10-31 09:28:53	2016-03-11 18:02:50
21854	610	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	11069T	2014-10-31 09:28:53	2016-03-11 18:02:50
21855	608	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	11069T	2014-10-31 09:28:53	2016-03-11 18:02:50
21856	963	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	11069T	2014-10-31 09:28:53	2016-03-11 18:02:50
21857	673	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	11069T	2014-10-31 09:28:53	2016-03-11 18:02:50
21858	602	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	11069T	2014-10-31 09:28:53	2016-03-11 18:02:50
21859	624	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	11069T	2014-10-31 09:28:53	2016-03-11 18:02:50
21860	595	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	11069T	2014-10-31 09:28:53	2016-03-11 18:02:50
21861	661	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	11069T	2014-10-31 09:28:53	2016-03-11 18:02:50
21862	621	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	11069T	2014-10-31 09:28:53	2016-03-11 18:02:50
21863	632	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	11069T	2014-10-31 09:28:53	2016-03-11 18:02:50
21864	627	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	11069T	2014-10-31 09:28:53	2016-03-11 18:02:50
21865	623	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	11069T	2014-10-31 09:28:53	2016-03-11 18:02:50
21866	634	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	11069T	2014-10-31 09:28:53	2016-03-11 18:02:50
21867	622	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	11069T	2014-10-31 09:28:53	2016-03-11 18:02:50
21868	626	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	11069T	2014-10-31 09:28:53	2016-03-11 18:02:50
21869	596	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	11069T	2014-10-31 09:28:53	2016-03-11 18:02:50
21870	620	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	11069T	2014-10-31 09:28:53	2016-03-11 18:02:50
21871	629	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	11069T	2014-10-31 09:28:53	2016-03-11 18:02:50
21872	575	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	11069T	2014-10-31 09:28:54	2016-03-11 18:02:50
21873	625	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	11069T	2014-10-31 09:28:54	2016-03-11 18:02:50
21874	616	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	11069T	2014-10-31 09:28:54	2016-03-11 18:02:50
21875	613	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	11069T	2014-10-31 09:28:54	2016-03-11 18:02:50
21876	604	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	11069T	2014-10-31 09:28:54	2016-03-11 18:02:50
21877	640	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	11069T	2014-10-31 09:28:54	2016-03-11 18:02:50
21878	579	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	11069T	2014-10-31 09:28:54	2016-03-11 18:02:51
21879	556	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	11069T	2014-10-31 09:28:54	2016-03-11 18:02:51
21880	584	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	11069T	2014-10-31 09:28:54	2016-03-11 18:02:51
21881	647	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	11069T	2014-10-31 09:28:54	2016-03-11 18:02:51
21882	592	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	11069T	2014-10-31 09:28:54	2016-03-11 18:02:51
21883	573	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	11069T	2014-10-31 09:28:54	2016-03-11 18:02:51
21884	603	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	11069T	2014-10-31 09:28:54	2016-03-11 18:02:51
21885	609	2014-10-30 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	11069T	2014-10-31 09:28:54	2016-03-11 18:02:51
21993	602	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14207L	2014-11-03 09:17:33	\N
21994	592	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14207L	2014-11-03 09:17:33	\N
21995	584	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14207L	2014-11-03 09:17:33	\N
21997	597	2014-10-31 00:00:00	2017-06-01 00:00:00	ANCIEN	\N	\N	\N	14175V	2014-11-03 09:33:45	2017-06-02 10:02:56
21998	610	2014-10-31 00:00:00	2017-06-01 00:00:00	ANCIEN	\N	\N	\N	14175V	2014-11-03 09:33:45	2017-06-02 10:02:56
21999	613	2014-10-31 00:00:00	2017-06-01 00:00:00	ANCIEN	\N	\N	\N	14175V	2014-11-03 09:33:45	2017-06-02 10:02:56
22000	602	2014-10-31 00:00:00	2017-06-01 00:00:00	ANCIEN	\N	\N	\N	14175V	2014-11-03 09:33:45	2017-06-02 10:02:56
22001	534	2014-10-31 00:00:00	2017-06-01 00:00:00	ANCIEN	\N	\N	\N	14175V	2014-11-03 09:33:45	2017-06-02 10:02:56
22002	598	2014-10-31 00:00:00	2017-06-01 00:00:00	ANCIEN	\N	\N	\N	14175V	2014-11-03 09:33:45	2017-06-02 10:02:56
22004	583	2014-10-31 00:00:00	2017-06-01 00:00:00	ANCIEN	\N	\N	\N	14175V	2014-11-03 09:33:46	2017-06-02 10:02:56
22239	646	2014-11-19 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	01037S	2014-11-19 11:38:20	2016-12-12 16:10:15
22279	572	2014-11-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11063M	2014-11-27 10:15:39	\N
22280	628	2014-11-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11063M	2014-11-27 10:15:39	2015-04-09 15:21:33
22281	626	2014-11-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11063M	2014-11-27 10:15:39	\N
22282	598	2014-11-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11063M	2014-11-27 10:15:39	\N
22283	600	2014-11-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11063M	2014-11-27 10:15:39	\N
22284	642	2014-11-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11063M	2014-11-27 10:15:39	\N
22285	590	2014-11-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08016S	2014-11-27 10:16:06	\N
22286	641	2014-11-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08016S	2014-11-27 10:16:06	\N
22287	589	2014-11-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08016S	2014-11-27 10:16:06	\N
22288	584	2014-11-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08016S	2014-11-27 10:16:06	\N
22858	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
23074	532	2015-03-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11015D	2015-03-04 16:17:27	2017-09-24 13:42:36
23075	601	2015-02-26 00:00:00	2016-12-31 00:00:00	ANCIEN	\N	\N	\N	07024N	2015-03-04 16:17:38	2017-01-03 11:09:24
23076	601	2015-03-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14199E	2015-03-04 16:17:46	\N
23142	918	2014-10-01 00:00:00	2017-06-01 00:00:00	ANCIEN	\N	\N	\N	14175V	\N	2017-06-02 10:02:56
23447	621	2016-02-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14267Y	2016-02-03 12:40:46	\N
23598	629	2016-03-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11076S	2016-03-25 10:40:00	2017-09-24 17:47:28
23765	919	2014-10-01 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	14263U	\N	2017-06-19 16:04:13
23769	919	2016-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
23770	919	2016-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08068F	\N	\N
23771	919	2016-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14207L	\N	\N
23772	919	2016-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11101A	\N	\N
23844	909	2017-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14363X	\N	2017-09-24 19:25:10
23856	979	2017-04-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14133K	2017-04-27 16:00:57	\N
24491	590	2017-10-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	2017-10-24 09:58:20	\N
24492	618	2017-10-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	2017-10-24 09:58:20	\N
24493	578	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2017-10-24 09:59:38	\N
24494	583	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2017-10-24 09:59:38	\N
24495	577	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2017-10-24 09:59:38	\N
24496	644	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2017-10-24 09:59:38	\N
24497	597	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2017-10-24 09:59:38	\N
24498	584	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2017-10-24 09:59:38	\N
24499	605	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2017-10-24 09:59:38	\N
24500	534	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2017-10-24 09:59:38	\N
24501	633	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2017-10-24 09:59:38	\N
24502	622	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2017-10-24 09:59:38	\N
24503	626	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2017-10-24 09:59:38	\N
24504	663	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2017-10-24 09:59:39	\N
24505	576	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2017-10-24 09:59:39	\N
24506	623	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2017-10-24 09:59:39	\N
24507	851	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2017-10-24 09:59:39	\N
24508	659	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2017-10-24 09:59:39	\N
24509	643	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2017-10-24 09:59:39	\N
24510	609	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2017-10-24 09:59:39	\N
24511	610	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2017-10-24 09:59:39	\N
24512	598	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2017-10-24 09:59:39	\N
24513	618	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2017-10-24 09:59:39	\N
24514	596	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2017-10-24 09:59:39	\N
24515	550	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2017-10-24 09:59:39	\N
24516	653	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2017-10-24 09:59:39	\N
24517	608	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2017-10-24 09:59:39	\N
24518	602	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2017-10-24 09:59:39	\N
24519	979	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2017-10-24 09:59:39	\N
24520	578	2017-10-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	98005N	2017-10-24 10:00:25	\N
24521	626	2017-10-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	98005N	2017-10-24 10:00:25	\N
24522	663	2017-10-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	98005N	2017-10-24 10:00:25	\N
24523	651	2017-10-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	98005N	2017-10-24 10:00:25	\N
24524	629	2017-10-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	98005N	2017-10-24 10:00:25	\N
24525	572	2017-10-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	98005N	2017-10-24 10:00:25	\N
24526	583	2017-10-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	98005N	2017-10-24 10:00:25	\N
24527	653	2017-10-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	98005N	2017-10-24 10:00:25	\N
24528	602	2017-10-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	98005N	2017-10-24 10:00:25	\N
24529	609	2017-10-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	98005N	2017-10-24 10:00:25	\N
24530	584	2017-10-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	98005N	2017-10-24 10:00:25	\N
24531	622	2017-10-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	98005N	2017-10-24 10:00:25	\N
24532	595	2017-10-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	2017-10-24 10:01:19	\N
24533	585	2017-10-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	2017-10-24 10:01:19	\N
24534	623	2017-10-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	2017-10-24 10:01:19	\N
24535	591	2017-10-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	2017-10-24 10:01:19	\N
24536	608	2017-10-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	2017-10-24 10:01:19	\N
24537	609	2017-10-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	2017-10-24 10:01:19	\N
24538	978	2017-10-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	2017-10-24 10:01:19	\N
24539	979	2017-10-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	2017-10-24 10:01:19	\N
24540	598	2017-10-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	2017-10-24 10:01:19	\N
24541	CHRETORIENT	2017-10-24 00:00:00	2018-07-27 00:00:00	ANCIEN	\N	\N	\N	19707Y	2017-10-24 10:51:14	\N
24542	CHRETORIENT	2017-10-24 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	19705W	2017-10-24 10:53:43	\N
24543	625	2017-10-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19735D	2017-10-24 15:05:56	\N
24544	581	2017-10-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19735D	2017-10-24 15:05:56	\N
24549	625	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	17779H	2017-10-24 17:45:36	\N
24550	621	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	17779H	2017-10-24 17:45:36	\N
24551	589	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	17779H	2017-10-24 17:45:36	\N
24557	588	2017-10-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2017-10-25 09:53:02	\N
24558	598	2017-10-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2017-10-25 09:53:02	\N
24559	618	2017-10-20 00:00:00	2017-11-23 00:00:00	ANCIEN	\N	\N	\N	08018U	2017-10-25 09:53:02	2017-11-24 16:57:56
24560	592	2017-10-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2017-10-25 09:53:02	\N
20234	990	2014-02-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	98027U	\N	2014-03-06 17:36:23
21266	573	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95041E	2014-10-28 11:52:33	\N
21267	572	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95041E	2014-10-28 11:52:33	\N
21268	608	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95041E	2014-10-28 11:52:34	\N
21269	622	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95041E	2014-10-28 11:52:35	\N
21270	590	2014-10-28 00:00:00	2015-01-08 00:00:00	ANCIEN	\N	\N	\N	92035T	2014-10-28 11:52:50	2015-01-08 17:14:29
21303	590	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11110B	2014-10-28 16:51:57	\N
21304	589	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11110B	2014-10-28 16:51:57	\N
21305	629	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11110B	2014-10-28 16:51:57	\N
22216	584	2014-11-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	2014-11-13 16:17:58	\N
22217	595	2014-11-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14239U	2014-11-13 16:18:09	\N
22218	634	2014-11-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14239U	2014-11-13 16:18:09	\N
22219	585	2014-11-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11015D	2014-11-13 16:18:23	2017-09-24 13:42:36
22220	585	2014-11-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	80027E	2014-11-13 16:18:38	2017-07-20 11:43:02
22240	596	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08011M	2014-11-19 12:10:19	\N
22241	661	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08011M	2014-11-19 12:10:19	\N
22242	590	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08011M	2014-11-19 12:10:19	\N
22243	576	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08011M	2014-11-19 12:10:19	\N
22244	979	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08011M	2014-11-19 12:10:19	2016-12-07 16:35:49
22245	629	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08011M	2014-11-19 12:10:19	\N
22246	597	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08011M	2014-11-19 12:10:19	\N
22247	608	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08011M	2014-11-19 12:10:19	\N
22248	643	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08011M	2014-11-19 12:10:19	\N
22249	584	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08011M	2014-11-19 12:10:19	\N
22250	978	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08011M	2014-11-19 12:10:19	\N
22299	550	2014-12-02 00:00:00	2017-07-03 00:00:00	ANCIEN	\N	\N	\N	01044R	2014-12-03 10:54:22	2017-07-04 15:08:09
22300	646	2014-12-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92020L	2014-12-03 10:54:34	\N
22301	572	2014-11-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98024R	2014-12-03 11:49:24	\N
22302	583	2014-11-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98024R	2014-12-03 11:49:24	\N
22303	653	2014-11-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98024R	2014-12-03 11:49:25	\N
22304	659	2014-11-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98024R	2014-12-03 11:49:25	\N
22305	851	2014-12-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	2014-12-03 14:21:37	\N
22306	571	2014-12-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	2014-12-03 14:21:37	\N
22394	578	2015-01-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08044W	2015-01-15 16:37:36	\N
22489	580	2015-01-28 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	14263U	2015-01-30 11:06:02	2017-06-19 16:04:13
22490	621	2015-01-28 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	14263U	2015-01-30 11:06:19	2017-06-19 16:04:13
22491	605	2015-01-28 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	14263U	2015-01-30 11:06:32	2017-06-19 16:04:13
23078	906	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08038Y	\N	\N
23079	906	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
23085	617	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08044W	2015-03-04 17:59:48	\N
23295	530	2015-06-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01014K	2015-06-29 16:52:38	2017-09-24 17:19:42
24400	659	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2017-10-19 15:01:57	\N
24401	644	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2017-10-19 15:01:58	\N
24402	629	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2017-10-19 15:01:58	\N
24403	581	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2017-10-19 15:01:58	\N
24404	596	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2017-10-19 15:01:58	\N
24405	609	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2017-10-19 15:01:58	\N
24406	628	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2017-10-19 15:01:58	\N
24407	626	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2017-10-19 15:01:58	\N
24408	663	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2017-10-19 15:01:58	\N
24409	979	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2017-10-19 15:01:58	\N
24410	576	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2017-10-19 15:01:58	\N
24411	624	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2017-10-19 15:01:58	\N
24412	598	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2017-10-19 15:01:58	\N
24413	595	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2017-10-19 15:01:58	\N
24414	618	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2017-10-19 15:01:58	\N
24415	584	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2017-10-19 15:01:59	\N
24416	591	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2017-10-19 15:01:59	\N
24417	621	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2017-10-19 15:01:59	\N
24418	620	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2017-10-19 15:01:59	\N
24419	604	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2017-10-19 15:01:59	\N
24420	594	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2017-10-19 15:01:59	\N
24421	574	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2017-10-19 15:01:59	\N
24422	590	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2017-10-19 15:01:59	\N
24423	642	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2017-10-19 15:01:59	\N
24424	581	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11040E	2017-10-19 15:04:56	\N
24425	608	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11040E	2017-10-19 15:04:56	\N
24426	594	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11040E	2017-10-19 15:04:56	\N
24475	CHRETORIENT	2017-10-23 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	19723Y	2017-10-23 15:23:09	\N
24476	CHRETORIENT	2017-10-20 00:00:00	2020-11-02 00:00:00	ANCIEN	\N	\N	\N	14115H	2017-10-23 15:52:46	\N
24594	673	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19581D	2017-10-25 12:28:03	\N
24595	579	2017-10-25 00:00:00	2017-10-26 00:00:00	ANCIEN	\N	\N	\N	19581D	2017-10-25 12:28:03	2017-10-31 18:09:28
24596	600	2017-10-25 00:00:00	2017-10-26 00:00:00	ANCIEN	\N	\N	\N	19581D	2017-10-25 12:28:03	2017-10-31 18:09:28
24597	599	2017-10-25 00:00:00	2017-10-26 00:00:00	ANCIEN	\N	\N	\N	19581D	2017-10-25 12:28:03	2017-10-31 18:09:28
24598	595	2017-10-25 00:00:00	2017-10-26 00:00:00	ANCIEN	\N	\N	\N	19581D	2017-10-25 12:28:03	2017-10-31 18:09:28
24599	610	2017-10-25 00:00:00	2017-10-26 00:00:00	ANCIEN	\N	\N	\N	19581D	2017-10-25 12:28:04	2017-10-31 18:09:28
24600	629	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19581D	2017-10-25 12:28:04	\N
24601	575	2017-10-25 00:00:00	2017-10-26 00:00:00	ANCIEN	\N	\N	\N	19581D	2017-10-25 12:28:04	2017-10-31 18:09:28
24602	581	2017-10-25 00:00:00	2017-10-26 00:00:00	ANCIEN	\N	\N	\N	19581D	2017-10-25 12:28:04	2017-10-31 18:09:28
24603	580	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19581D	2017-10-25 12:28:04	\N
24690	963	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19703U	2017-10-26 10:43:49	\N
24691	584	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14107H	2017-10-26 11:01:31	\N
24692	640	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2017-10-26 15:26:01	\N
24693	589	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19527W	2017-10-26 15:26:59	\N
24694	598	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19443T	2017-10-26 15:27:25	\N
21492	608	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14079W	2014-10-29 13:30:48	\N
21493	629	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14079W	2014-10-29 13:30:48	\N
21494	979	2014-10-29 00:00:00	2015-07-02 00:00:00	ANCIEN	\N	\N	\N	14079W	2014-10-29 13:30:48	2015-07-08 09:36:39
21495	583	2014-10-29 00:00:00	2015-06-24 00:00:00	ANCIEN	\N	\N	\N	14079W	2014-10-29 13:30:48	2015-06-24 12:06:17
21496	590	2014-10-29 00:00:00	2016-02-03 00:00:00	ANCIEN	\N	\N	\N	14079W	2014-10-29 13:30:48	2016-02-03 11:35:08
21497	643	2014-10-29 00:00:00	2015-02-04 00:00:00	ANCIEN	\N	\N	\N	14079W	2014-10-29 13:30:48	2015-02-09 11:12:01
21716	591	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	12041X	2014-10-30 15:08:31	2017-07-20 14:38:10
21772	573	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	14167V	2014-10-30 16:52:49	2017-10-01 10:18:28
21773	577	2014-10-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	14167V	2014-10-30 16:52:49	2017-10-01 10:18:28
21774	573	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01031L	2014-10-30 16:53:21	\N
21775	978	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01031L	2014-10-30 16:53:21	\N
21776	647	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01031L	2014-10-30 16:53:21	\N
21777	602	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01031L	2014-10-30 16:53:21	\N
22833	617	2015-02-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2015-02-17 17:36:11	\N
22849	907	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	2017-09-24 17:48:21
22853	907	2014-10-01 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	2017-05-16 15:18:13
22854	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14103D	\N	\N
22857	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08053X	\N	\N
23081	640	2015-03-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14059S	2015-03-04 17:13:49	\N
23181	911	2014-09-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11111C	2015-04-01 16:21:09	2017-09-24 16:45:26
23399	906	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
23620	907	2016-05-26 00:00:00	2017-07-21 00:00:00	ANCIEN	\N	\N	\N	01007L	\N	2017-07-24 09:56:26
23754	602	2016-09-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	2016-09-28 16:59:50	\N
23889	618	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08015R	2017-10-10 17:20:55	\N
23890	608	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08015R	2017-10-10 17:22:57	\N
23891	592	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	2017-10-10 17:23:20	\N
23892	600	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	2017-10-10 17:23:39	\N
23893	618	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	2017-10-10 17:24:00	\N
23894	620	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	2017-10-10 17:24:23	\N
23895	619	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	2017-10-10 17:24:46	\N
23896	624	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	2017-10-10 17:25:20	\N
23897	641	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	2017-10-10 17:25:38	2017-10-10 17:25:58
23898	6431	2017-10-10 00:00:00	2017-10-18 00:00:00	ANCIEN	\N	\N	\N	08015R	2017-10-10 17:26:20	2017-10-18 15:49:23
23899	647	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	2017-10-10 17:27:01	\N
23900	646	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08015R	2017-10-10 17:27:25	\N
23901	534	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	2017-10-10 17:27:42	\N
23902	597	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	2017-10-10 17:28:11	\N
23903	674	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	2017-10-10 17:29:21	\N
23904	628	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	2017-10-10 17:29:49	\N
23905	572	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	2017-10-10 17:30:18	\N
23906	659	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	2017-10-10 17:30:41	\N
23907	584	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	2017-10-10 17:30:52	\N
23908	595	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	2017-10-10 17:31:00	\N
23909	608	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	2017-10-10 17:31:07	\N
23910	556	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	2017-10-10 17:31:15	\N
23911	571	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	2017-10-10 17:31:23	\N
23912	530	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	2017-10-10 17:31:33	\N
23913	573	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	2017-10-10 17:31:44	\N
23914	605	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	2017-10-10 17:31:54	\N
23915	617	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	2017-10-10 17:32:02	\N
23916	576	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	2017-10-10 17:32:13	\N
23917	598	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	2017-10-10 17:32:24	\N
23918	582	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	2017-10-10 17:32:31	\N
23919	653	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	2017-10-10 17:32:42	\N
23920	632	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	2017-10-10 17:32:51	\N
23921	596	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	2017-10-10 17:33:01	\N
23928	661	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08015R	2017-10-10 17:39:27	\N
23930	623	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08015R	2017-10-10 17:40:57	\N
23924	617	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08015R	2017-10-10 17:33:42	\N
23925	979	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08015R	2017-10-10 17:33:49	\N
23926	577	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08015R	2017-10-10 17:33:58	\N
23927	629	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08015R	2017-10-10 17:34:07	\N
24783	583	2017-10-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08009T	2017-10-27 14:41:06	\N
24793	616	2017-10-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14079W	2017-10-27 16:19:38	\N
24794	629	2017-10-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14079W	2017-10-27 16:19:38	\N
24795	644	2017-10-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14079W	2017-10-27 16:19:38	\N
24796	659	2017-10-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14079W	2017-10-27 16:19:38	\N
24797	597	2017-10-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14079W	2017-10-27 16:19:38	\N
24798	604	2017-10-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14079W	2017-10-27 16:19:38	\N
24799	623	2017-10-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14079W	2017-10-27 16:19:38	\N
24800	556	2017-10-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14079W	2017-10-27 16:19:38	\N
24801	628	2017-10-27 00:00:00	2020-02-25 00:00:00	ANCIEN	\N	\N	\N	14079W	2017-10-27 16:19:38	\N
24802	608	2017-10-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14079W	2017-10-27 16:19:38	\N
24803	600	2017-10-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14079W	2017-10-27 16:19:38	\N
24804	584	2017-10-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19667J	2017-10-30 09:13:28	\N
24805	596	2017-10-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19667J	2017-10-30 09:13:28	\N
24806	608	2017-10-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19667J	2017-10-30 09:13:28	\N
24807	634	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	97011G	2017-10-30 09:46:48	\N
24808	576	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14021P	2017-10-30 09:47:16	\N
24809	618	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14021P	2017-10-30 09:47:16	\N
24810	590	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14021P	2017-10-30 09:47:16	\N
24811	595	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14021P	2017-10-30 09:47:16	\N
24812	602	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14021P	2017-10-30 09:47:16	\N
24813	574	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19577H	2017-10-30 09:47:41	\N
24814	622	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19577H	2017-10-30 09:47:41	\N
24815	598	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19577H	2017-10-30 09:47:41	\N
21017	620	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	2014-10-23 18:29:59	\N
21018	618	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	2014-10-23 18:29:59	\N
21019	574	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	2014-10-23 18:29:59	\N
21020	584	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	2014-10-23 18:29:59	\N
21021	572	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	2014-10-23 18:29:59	\N
21022	651	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	2014-10-23 18:29:59	\N
21023	978	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	2014-10-23 18:29:59	\N
21024	622	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	2014-10-23 18:29:59	\N
21025	602	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	2014-10-23 18:29:59	\N
21026	661	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	2014-10-23 18:29:59	\N
21027	979	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	2014-10-23 18:30:00	\N
21028	573	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	2014-10-23 18:30:00	\N
21029	659	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	2014-10-23 18:30:00	\N
21030	598	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	2014-10-23 18:30:00	2016-03-30 11:57:29
21661	634	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	2014-10-30 12:34:05	\N
21662	647	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	2014-10-30 12:34:05	\N
21663	602	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	2014-10-30 12:34:05	\N
21664	583	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	2014-10-30 12:34:05	\N
21665	621	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	2014-10-30 12:34:05	\N
21666	616	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	2014-10-30 12:34:05	\N
21667	625	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	2014-10-30 12:34:05	2016-03-16 11:35:59
21668	612	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	2014-10-30 12:34:05	\N
21669	529	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	2014-10-30 12:34:05	\N
21670	626	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	2014-10-30 12:34:05	\N
21671	577	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	2014-10-30 12:34:05	2015-03-20 09:53:01
21672	979	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11012A	2014-10-30 12:34:56	2016-12-07 16:42:27
21673	621	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11012A	2014-10-30 12:34:56	\N
21674	616	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11012A	2014-10-30 12:34:56	\N
21675	622	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11012A	2014-10-30 12:34:56	\N
21676	609	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11012A	2014-10-30 12:34:56	\N
21677	643	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11012A	2014-10-30 12:34:57	\N
21678	595	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11012A	2014-10-30 12:34:57	\N
21679	577	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11012A	2014-10-30 12:34:57	2015-03-20 09:53:26
21680	584	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11012A	2014-10-30 12:34:57	\N
21681	651	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11012A	2014-10-30 12:34:57	\N
21682	978	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11012A	2014-10-30 12:34:57	\N
21683	642	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11012A	2014-10-30 12:34:57	\N
21684	673	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11012A	2014-10-30 12:34:57	\N
21685	626	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11012A	2014-10-30 12:34:57	\N
22005	584	2014-10-31 00:00:00	2017-06-01 00:00:00	ANCIEN	\N	\N	\N	14175V	2014-11-03 09:33:46	2017-06-02 10:02:56
22006	621	2014-10-31 00:00:00	2017-06-01 00:00:00	ANCIEN	\N	\N	\N	14175V	2014-11-03 09:33:46	2017-06-02 10:02:56
22075	624	2014-11-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08031R	2014-11-04 10:20:05	\N
22097	642	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04095R	2014-11-04 17:18:07	\N
22098	624	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14018U	2014-11-05 09:37:10	\N
22099	594	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14135M	2014-11-05 09:37:28	\N
22100	621	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14135M	2014-11-05 09:37:29	\N
22101	608	2014-10-30 00:00:00	2014-12-17 00:00:00	ANCIEN	\N	\N	\N	14135M	2014-11-05 09:37:29	2014-12-23 09:10:35
22102	598	2014-10-30 00:00:00	2014-12-17 00:00:00	ANCIEN	\N	\N	\N	14135M	2014-11-05 09:37:29	2014-12-23 09:10:35
22103	584	2014-10-30 00:00:00	2014-12-17 00:00:00	ANCIEN	\N	\N	\N	14135M	2014-11-05 09:37:29	2014-12-18 14:47:10
22104	620	2014-11-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04079R	2014-11-05 09:37:47	\N
22105	595	2014-11-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04079R	2014-11-05 09:37:48	\N
22106	529	2014-11-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04036E	2014-11-05 09:39:19	\N
22107	621	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92040Q	2014-11-05 09:39:39	\N
22108	579	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92040Q	2014-11-05 09:39:39	\N
22109	604	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92040Q	2014-11-05 09:39:39	\N
22110	611	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92040Q	2014-11-05 09:39:39	\N
22111	599	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92040Q	2014-11-05 09:39:39	2015-03-20 11:38:27
22112	601	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92040Q	2014-11-05 09:39:39	2015-03-11 11:00:16
22113	581	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92040Q	2014-11-05 09:39:39	\N
22137	617	2014-11-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14191V	2014-11-07 11:25:05	\N
22138	576	2014-11-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14191V	2014-11-07 11:25:05	\N
22139	584	2014-11-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14191V	2014-11-07 11:25:05	\N
22140	596	2014-11-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14191V	2014-11-07 11:25:06	\N
22141	626	2014-11-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14191V	2014-11-07 11:25:06	\N
22142	644	2014-11-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04077P	2014-11-07 11:31:16	\N
22143	624	2014-11-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04077P	2014-11-07 11:31:16	\N
22144	575	2014-11-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04077P	2014-11-07 11:31:16	\N
22145	617	2014-11-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04077P	2014-11-07 11:31:16	\N
22146	585	2014-11-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04077P	2014-11-07 11:31:16	2017-09-24 17:47:27
22147	598	2014-11-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04077P	2014-11-07 11:31:17	2017-09-24 17:47:27
22148	661	2014-11-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04077P	2014-11-07 11:31:17	2017-09-24 17:47:27
22149	590	2014-11-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04077P	2014-11-07 11:31:17	\N
22150	632	2014-11-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04077P	2014-11-07 11:31:17	\N
22151	628	2014-11-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04077P	2014-11-07 11:31:17	\N
22152	597	2014-11-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04077P	2014-11-07 11:31:17	2017-09-24 17:47:27
22153	571	2014-11-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04077P	2014-11-07 11:31:17	\N
22154	624	2014-11-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04056J	2014-11-07 11:31:42	\N
22155	661	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11074Q	2014-11-07 11:32:07	\N
22156	584	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11074Q	2014-11-07 11:32:07	\N
22157	577	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11074Q	2014-11-07 11:32:07	\N
22158	626	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11074Q	2014-11-07 11:32:07	\N
22159	586	2014-11-06 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	95020Y	2014-11-07 11:32:29	2015-06-12 16:01:25
22160	642	2014-11-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14261S	2014-11-07 11:32:45	\N
22161	590	2014-11-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14261S	2014-11-07 11:32:45	\N
22162	618	2014-11-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14261S	2014-11-07 11:32:45	\N
22163	585	2014-11-05 00:00:00	2017-07-20 00:00:00	ANCIEN	\N	\N	\N	14051J	2014-11-07 11:33:05	2017-07-20 13:51:00
22234	601	2014-11-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08069G	2014-11-18 14:12:59	\N
22266	623	2014-11-17 00:00:00	2016-01-11 00:00:00	ANCIEN	\N	\N	\N	11060J	2014-11-21 11:51:31	2016-01-11 17:34:09
20992	663	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	83042R	2014-10-23 15:50:24	\N
20993	578	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	83042R	2014-10-23 15:50:24	\N
20994	534	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	83042R	2014-10-23 15:50:24	\N
20995	601	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	83042R	2014-10-23 15:50:24	2017-09-24 17:48:21
20996	584	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	83042R	2014-10-23 15:50:24	\N
20997	623	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98035U	2014-10-23 16:06:18	2015-03-06 09:53:23
20998	978	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98035U	2014-10-23 16:06:18	2015-05-26 11:54:43
20999	576	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98035U	2014-10-23 16:06:19	\N
21000	574	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98035U	2014-10-23 16:06:19	\N
21001	646	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98035U	2014-10-23 16:06:19	\N
21002	609	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98035U	2014-10-23 16:06:19	\N
21003	643	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98035U	2014-10-23 16:06:19	\N
21004	633	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98035U	2014-10-23 16:06:19	\N
21005	595	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98035U	2014-10-23 16:06:19	\N
21006	979	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98035U	2014-10-23 16:06:19	2016-12-07 16:39:48
21007	585	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98035U	2014-10-23 16:06:19	2017-07-20 11:43:24
21008	622	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98035U	2014-10-23 16:06:19	2015-03-10 10:01:38
21009	608	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98035U	2014-10-23 16:06:19	\N
21010	591	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98035U	2014-10-23 16:06:19	2015-05-26 11:57:55
21011	598	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98035U	2014-10-23 16:06:19	\N
21012	588	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98035U	2014-10-23 16:06:19	\N
21013	979	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14157T	2014-10-23 16:14:52	\N
21014	621	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14157T	2014-10-23 16:14:52	\N
21015	647	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14157T	2014-10-23 16:14:52	\N
21016	604	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14157T	2014-10-23 16:14:52	\N
22289	534	2014-11-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14093U	2014-11-28 10:00:01	\N
22290	529	2014-11-25 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	90003B	2014-11-28 10:00:13	2017-10-01 10:01:39
22291	625	2014-11-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04040A	2014-11-28 12:45:16	\N
22311	583	2014-10-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11114F	2014-12-04 10:15:26	\N
22312	642	2014-10-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11114F	2014-12-04 10:15:26	\N
22461	646	2015-01-26 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	90003B	2015-01-27 14:59:59	2017-10-01 10:01:39
22834	620	2015-02-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11029K	2015-02-18 09:08:55	\N
23616	617	2016-05-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14239U	2016-05-19 15:11:39	\N
24440	CHRETORIENT	2017-10-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	95030B	2017-10-20 10:10:41	\N
24695	621	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19443T	2017-10-26 15:27:25	\N
24696	663	2017-10-24 00:00:00	2018-12-30 00:00:00	ANCIEN	\N	\N	\N	98023Q	2017-10-26 15:27:51	\N
24697	616	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14065Q	2017-10-26 15:38:56	\N
24698	583	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14065Q	2017-10-26 15:38:56	\N
24700	663	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14065Q	2017-10-26 15:38:56	\N
24701	602	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14065Q	2017-10-26 15:38:56	\N
24702	604	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14065Q	2017-10-26 15:38:56	\N
24703	625	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14065Q	2017-10-26 15:38:56	\N
24704	622	2017-10-26 00:00:00	2018-12-30 00:00:00	ANCIEN	\N	\N	\N	98023Q	2017-10-26 15:43:48	\N
24705	618	2017-10-26 00:00:00	2018-12-30 00:00:00	ANCIEN	\N	\N	\N	98023Q	2017-10-26 15:43:48	\N
24706	979	2017-10-26 00:00:00	2017-11-13 00:00:00	ANCIEN	\N	\N	\N	98023Q	2017-10-26 15:43:48	2017-11-15 09:32:13
24707	598	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	07033P	2017-10-26 15:44:21	\N
24708	613	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	07033P	2017-10-26 15:44:21	\N
24709	620	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	07033P	2017-10-26 15:44:21	\N
24710	609	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	07033P	2017-10-26 15:44:21	\N
24711	590	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19649G	2017-10-26 15:44:57	\N
24712	583	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19649G	2017-10-26 15:44:57	\N
24713	575	2017-10-25 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	2017-10-26 15:45:24	\N
24714	604	2017-10-25 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	2017-10-26 15:45:24	\N
24715	629	2017-10-25 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	2017-10-26 15:45:24	\N
24716	573	2017-10-25 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	2017-10-26 15:45:24	\N
24717	625	2017-10-25 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	2017-10-26 15:45:24	\N
24718	595	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	2017-10-26 15:46:11	\N
24719	581	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	2017-10-26 15:46:11	\N
24720	594	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	2017-10-26 15:46:12	\N
24721	604	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	2017-10-26 15:46:12	\N
24722	608	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	2017-10-26 15:46:12	\N
24723	644	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	2017-10-26 15:46:12	\N
24724	615	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	2017-10-26 15:46:12	\N
24725	617	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	2017-10-26 15:46:12	\N
24726	659	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	2017-10-26 15:46:12	\N
24727	597	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	2017-10-26 15:46:12	\N
24728	598	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	2017-10-26 15:46:12	\N
24729	610	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	2017-10-26 15:46:12	\N
24730	575	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	2017-10-26 15:46:12	\N
24731	620	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	2017-10-26 15:46:12	\N
24732	621	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	2017-10-26 15:46:12	\N
24733	624	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	2017-10-26 15:46:12	\N
24734	629	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	2017-10-26 15:46:12	\N
24735	641	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	2017-10-26 15:46:12	\N
24736	632	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	2017-10-26 15:46:12	\N
24737	589	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08049C	2017-10-26 16:06:15	\N
24738	606	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08049C	2017-10-26 16:06:15	\N
24739	575	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08049C	2017-10-26 16:06:15	\N
24740	633	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08049C	2017-10-26 16:06:15	\N
24741	582	2017-10-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19701S	2017-10-26 16:30:56	\N
24742	622	2017-10-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19701S	2017-10-26 16:30:56	\N
24743	579	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	92040Q	2017-10-26 17:24:39	\N
24744	599	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	92040Q	2017-10-26 17:24:39	\N
24745	621	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	92040Q	2017-10-26 17:24:40	\N
22332	591	2014-12-11 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	14137P	2014-12-11 16:12:59	2015-06-12 15:59:18
22529	644	2015-02-03 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	95020Y	2015-02-10 12:18:49	2015-06-12 16:01:25
22674	612	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11091R	2015-02-16 10:02:28	\N
22675	550	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11091R	2015-02-16 10:02:28	\N
22961	918	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11081P	\N	\N
23224	938	2015-03-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11035H	\N	\N
23233	938	2015-03-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14111D	\N	\N
23236	938	2015-03-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14193X	\N	\N
23385	911	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14281W	\N	\N
23386	912	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14281W	\N	\N
23415	912	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14265W	\N	\N
23430	616	2015-11-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14030Q	2015-11-26 16:55:52	\N
24019	640	2017-10-11 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	07034Q	2017-10-12 09:52:52	\N
24020	674	2017-10-11 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	07034Q	2017-10-12 09:52:52	\N
24021	651	2017-10-11 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	07034Q	2017-10-12 09:52:52	\N
24022	577	2017-10-11 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	07034Q	2017-10-12 09:52:52	\N
24023	612	2017-10-11 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	07034Q	2017-10-12 09:52:52	\N
24784	584	2017-10-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08009T	2017-10-27 14:41:06	\N
24785	595	2017-10-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08009T	2017-10-27 14:41:06	\N
24786	661	2017-10-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08009T	2017-10-27 14:41:06	\N
24787	598	2017-10-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08009T	2017-10-27 14:41:07	\N
24788	609	2017-10-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08009T	2017-10-27 14:41:07	\N
24789	622	2017-10-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08009T	2017-10-27 14:41:07	\N
24790	530	2017-10-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08009T	2017-10-27 14:41:07	\N
24791	618	2017-10-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08009T	2017-10-27 14:41:07	\N
24792	574	2017-10-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08009T	2017-10-27 14:41:07	\N
24816	851	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	2017-10-30 09:48:29	\N
24817	632	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	2017-10-30 09:48:29	\N
24818	584	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	2017-10-30 09:48:29	\N
24819	626	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	2017-10-30 09:48:29	\N
24820	628	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	2017-10-30 09:48:29	\N
24821	625	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	2017-10-30 09:48:29	\N
24822	659	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	2017-10-30 09:48:29	\N
24823	532	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	2017-10-30 09:48:29	\N
24824	534	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	2017-10-30 09:48:29	\N
24825	608	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	2017-10-30 09:48:29	\N
24826	979	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	2017-10-30 09:48:29	\N
24827	978	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19549D	2017-10-30 09:48:52	\N
24828	606	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19549D	2017-10-30 09:48:52	\N
24829	643	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19657G	2017-10-30 09:50:08	\N
24830	622	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19657G	2017-10-30 09:50:08	\N
24831	604	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19533U	2017-10-30 09:50:24	\N
24832	583	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19533U	2017-10-30 09:50:24	\N
24833	584	2017-10-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	12041X	2017-10-30 09:53:35	\N
24834	591	2017-10-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	12041X	2017-10-30 09:53:35	\N
24835	979	2017-10-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	12041X	2017-10-30 09:53:35	\N
24836	579	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14157T	2017-10-30 09:53:52	\N
24837	979	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14157T	2017-10-30 09:53:52	\N
24847	576	2017-10-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11031D	2017-10-31 09:54:24	\N
24841	619	2017-10-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14265W	2017-10-30 11:49:02	\N
24842	633	2017-10-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14265W	2017-10-30 11:49:02	\N
24843	634	2017-10-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14265W	2017-10-30 11:49:02	\N
24844	621	2017-10-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14265W	2017-10-30 11:49:02	\N
24845	629	2017-10-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14265W	2017-10-30 11:49:02	\N
24846	621	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19367Y	2017-10-30 11:50:35	\N
24848	591	2017-10-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11031D	2017-10-31 09:54:24	\N
24849	620	2017-10-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11031D	2017-10-31 09:54:24	\N
24850	978	2017-10-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11031D	2017-10-31 09:54:24	\N
24851	632	2017-10-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11031D	2017-10-31 09:54:24	\N
24852	979	2017-10-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11031D	2017-10-31 09:54:24	\N
24853	595	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	99004R	2017-10-31 09:54:47	\N
24854	598	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	99004R	2017-10-31 09:56:04	\N
24855	617	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04086Q	2017-10-31 09:56:31	\N
24856	595	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04086Q	2017-10-31 09:56:31	\N
24857	659	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04086Q	2017-10-31 09:56:31	\N
24858	641	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04086Q	2017-10-31 09:56:32	\N
24859	601	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04086Q	2017-10-31 09:56:32	\N
24860	602	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04086Q	2017-10-31 09:56:32	\N
24861	581	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04086Q	2017-10-31 09:56:32	\N
24862	589	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04086Q	2017-10-31 09:56:32	\N
24863	574	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	2017-10-31 09:57:27	\N
24864	606	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	2017-10-31 09:57:27	\N
24865	598	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	2017-10-31 09:57:27	\N
24866	588	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	2017-10-31 09:57:27	\N
24867	622	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	2017-10-31 09:57:27	\N
24868	602	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	2017-10-31 09:57:27	\N
24869	651	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	2017-10-31 09:57:27	\N
24870	584	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	2017-10-31 09:57:27	\N
24871	618	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	2017-10-31 09:57:27	\N
24872	583	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	2017-10-31 09:57:27	\N
24873	625	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	2017-10-31 09:57:27	\N
24874	572	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	2017-10-31 09:57:27	\N
24875	600	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	2017-10-31 09:57:27	\N
24876	620	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	2017-10-31 09:57:27	\N
24877	978	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	2017-10-31 09:57:27	\N
24878	597	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	2017-10-31 09:57:27	\N
24879	590	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	2017-10-31 09:57:27	\N
24880	626	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	2017-10-31 09:57:27	\N
20273	584	2014-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11027H	2014-08-06 14:40:56	\N
20274	617	2014-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11027H	2014-08-06 14:42:01	\N
20275	659	2014-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11027H	2014-08-06 14:43:09	\N
20276	978	2014-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11027H	2014-08-06 14:44:04	\N
20277	600	2014-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11027H	2014-08-06 14:44:32	\N
20278	597	2014-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11027H	2014-08-06 14:45:04	\N
20279	661	2014-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11027H	2014-08-06 14:45:40	2015-02-03 14:09:39
20599	590	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14253S	2014-10-21 17:36:52	\N
20600	589	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14253S	2014-10-21 17:36:52	\N
20601	581	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14253S	2014-10-21 17:36:52	\N
20602	659	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	05008E	2014-10-21 17:38:20	\N
20603	625	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	05008E	2014-10-21 17:38:20	\N
20604	629	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	05008E	2014-10-21 17:38:20	\N
20605	616	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	05008E	2014-10-21 17:38:20	\N
20606	573	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	05008E	2014-10-21 17:38:20	\N
20607	584	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	05008E	2014-10-21 17:38:20	\N
20608	600	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11054L	2014-10-21 17:38:43	\N
20609	632	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11054L	2014-10-21 17:38:43	\N
22128	588	2014-11-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	2014-11-06 10:55:14	\N
22129	604	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	2014-11-06 10:55:25	\N
22130	621	2014-11-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	14247U	2014-11-06 10:55:40	2017-10-01 10:25:16
22131	979	2014-11-05 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	14247U	2014-11-06 10:55:40	2017-10-01 10:25:16
22268	622	2014-11-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01031L	2014-11-24 09:33:06	\N
22292	596	2014-11-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04042C	2014-12-01 09:37:06	\N
22395	644	2015-01-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95062K	2015-01-16 09:38:26	\N
22396	578	2015-01-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14199E	2015-01-16 09:38:37	2015-03-19 10:03:41
22397	578	2015-01-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14205J	2015-01-16 09:38:47	\N
22398	623	2015-01-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04056J	2015-01-16 09:38:57	\N
22407	646	2015-01-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14079W	2015-01-20 16:30:39	\N
22408	592	2015-01-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2015-01-20 17:02:10	\N
22454	532	2015-01-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04077P	2015-01-27 09:24:34	\N
22455	592	2015-01-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	2015-01-27 09:40:22	\N
22456	578	2015-01-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14042U	2015-01-27 09:40:34	\N
22457	592	2015-01-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08044W	2015-01-27 09:40:58	\N
22458	577	2015-01-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08044W	2015-01-27 10:09:45	\N
22459	634	2015-01-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08044W	2015-01-27 10:09:45	\N
22460	530	2015-01-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14221J	2015-01-27 10:12:38	\N
22497	573	2015-01-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08017T	2015-02-02 09:32:12	\N
22498	572	2015-01-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04061F	2015-02-02 10:44:29	\N
22671	908	2014-10-01 00:00:00	2017-07-28 00:00:00	ANCIEN	\N	\N	\N	11032E	\N	2017-08-03 11:38:41
22672	908	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
23708	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
24561	600	2017-10-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2017-10-25 09:53:02	\N
24562	606	2017-10-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2017-10-25 09:53:02	\N
24563	643	2017-10-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2017-10-25 09:53:02	\N
24564	646	2017-10-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2017-10-25 09:53:02	\N
24565	584	2017-10-20 00:00:00	2017-11-23 00:00:00	ANCIEN	\N	\N	\N	08018U	2017-10-25 09:53:02	2017-11-24 16:57:56
24566	629	2017-10-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2017-10-25 09:53:02	\N
24567	597	2017-10-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2017-10-25 09:53:02	\N
24568	616	2017-10-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2017-10-25 09:53:02	\N
24569	572	2017-10-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2017-10-25 09:53:02	\N
24570	622	2017-10-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2017-10-25 09:53:02	\N
24571	582	2017-10-20 00:00:00	2017-11-23 00:00:00	ANCIEN	\N	\N	\N	08018U	2017-10-25 09:53:02	2017-11-24 16:57:56
24572	586	2017-10-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2017-10-25 09:53:02	\N
24573	673	2017-10-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2017-10-25 09:53:02	\N
24574	556	2017-10-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2017-10-25 09:53:02	\N
24575	651	2017-10-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2017-10-25 09:53:03	\N
24576	534	2017-10-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2017-10-25 09:53:03	\N
24577	595	2017-10-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2017-10-25 09:53:03	\N
24578	642	2017-10-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2017-10-25 09:53:03	\N
24579	978	2017-10-20 00:00:00	2017-11-23 00:00:00	ANCIEN	\N	\N	\N	08018U	2017-10-25 09:53:03	2017-11-24 16:57:56
24580	590	2017-10-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	17637T	2017-10-25 09:53:36	\N
24581	608	2017-10-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	17637T	2017-10-25 09:53:37	\N
24582	584	2017-10-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	17637T	2017-10-25 09:53:37	\N
24583	641	2017-10-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	17637T	2017-10-25 09:53:37	\N
24584	616	2017-10-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	17637T	2017-10-25 09:53:37	\N
24585	576	2017-10-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14039A	2017-10-25 09:54:56	\N
24586	634	2017-10-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14030Q	2017-10-25 09:55:22	\N
24587	644	2017-10-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14249W	2017-10-25 09:55:41	\N
24588	615	2017-10-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14249W	2017-10-25 09:55:41	\N
24589	621	2017-10-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14249W	2017-10-25 09:55:41	\N
24590	598	2017-10-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19663E	2017-10-25 09:58:57	\N
24591	600	2017-10-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19663E	2017-10-25 09:58:57	\N
24592	583	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19637C	2017-10-25 10:19:19	\N
24593	621	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19637C	2017-10-25 10:19:19	\N
24604	620	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01057W	2017-10-25 14:47:45	\N
24605	598	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01057W	2017-10-25 14:47:45	\N
24606	605	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01057W	2017-10-25 14:47:45	\N
24607	581	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01057W	2017-10-25 14:47:45	\N
24608	589	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01057W	2017-10-25 14:47:45	\N
24609	608	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01057W	2017-10-25 14:47:45	\N
24610	629	2017-10-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	2017-10-25 17:06:35	\N
24611	651	2017-10-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	2017-10-25 17:06:35	\N
24612	576	2017-10-24 00:00:00	2018-02-16 00:00:00	ANCIEN	\N	\N	\N	08020N	2017-10-25 17:06:35	2018-02-22 10:21:36
24613	659	2017-10-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	2017-10-25 17:06:35	\N
24614	571	2017-10-24 00:00:00	2020-03-03 00:00:00	ANCIEN	\N	\N	\N	11081P	2017-10-25 17:07:02	\N
20209	912	2013-11-13 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	2013-11-19 11:00:23
20243	609	2014-05-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11069T	2014-05-16 09:19:20	\N
34450	1010	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	19705W	\N	\N
20244	618	2014-05-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04090L	2014-05-16 09:50:22	2014-09-28 19:29:39
20245	633	2014-05-01 00:00:00	2014-03-31 00:00:00	ANCIEN	\N	\N	\N	04090L	2014-05-16 09:51:01	2014-05-16 10:43:03
20246	634	2014-05-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04090L	2014-05-16 09:51:35	2014-09-28 19:29:39
20247	572	2014-05-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11027H	2014-05-16 10:12:04	2015-02-03 14:09:39
20248	573	2014-05-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11027H	2014-05-16 10:13:02	2015-02-03 14:09:39
20249	577	2014-05-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11027H	2014-05-16 10:13:32	2014-05-16 10:38:42
20250	583	2014-05-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11027H	2014-05-16 10:14:07	2014-05-16 10:39:19
20251	589	2014-05-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11027H	2014-05-16 10:14:58	2014-05-16 10:40:06
20252	594	2014-05-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11027H	2014-05-16 10:16:05	2014-05-16 10:16:31
20253	622	2014-05-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11027H	2014-05-16 10:17:19	\N
20254	598	2014-05-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11027H	2014-05-16 10:17:57	\N
20255	602	2014-05-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11027H	2014-05-16 10:19:03	\N
20256	595	2014-05-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04053F	2014-05-16 11:03:57	\N
20257	661	2014-05-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08069G	2014-05-16 11:07:39	\N
20258	661	2014-05-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08064B	2014-05-16 11:10:39	2014-09-28 19:03:23
20259	591	2014-05-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08064B	2014-05-16 11:13:48	2014-09-28 19:03:23
20260	629	2014-05-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08064B	2014-05-16 11:14:25	2014-09-28 19:03:23
22167	598	2014-10-31 00:00:00	2017-09-21 00:00:00	ANCIEN	\N	\N	\N	95031C	2014-11-10 09:22:57	2017-09-22 10:42:23
22168	629	2014-10-31 00:00:00	2017-09-21 00:00:00	ANCIEN	\N	\N	\N	95031C	2014-11-10 09:22:57	2017-09-22 10:42:23
22169	585	2014-11-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2014-11-10 09:23:34	2017-07-20 11:45:15
22225	663	2014-11-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11055M	2014-11-17 09:40:39	\N
22226	596	2014-11-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11055M	2014-11-17 09:40:39	\N
22227	578	2014-11-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11055M	2014-11-17 09:40:39	2017-09-24 18:07:57
22228	651	2014-11-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11055M	2014-11-17 09:40:39	\N
22229	642	2014-11-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11055M	2014-11-17 09:40:39	\N
22230	641	2014-11-06 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	14014Q	2014-11-17 09:40:59	2017-06-19 16:06:51
22231	585	2014-11-06 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	14014Q	2014-11-17 09:40:59	2017-06-19 16:06:51
22267	529	2014-11-19 00:00:00	2017-10-05 00:00:00	ANCIEN	\N	\N	\N	08010L	2014-11-21 11:51:44	2017-10-09 09:55:18
22307	642	2014-12-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	2014-12-03 15:41:24	\N
22308	963	2014-12-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14197C	2014-12-03 15:41:42	\N
22317	534	2014-12-08 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	11069T	2014-12-09 16:23:15	2016-03-11 18:02:51
22318	550	2014-12-08 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	11069T	2014-12-09 16:23:15	2016-03-11 18:02:51
22334	591	2014-12-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04094Q	2014-12-12 16:19:53	2017-09-25 10:58:49
22375	963	2015-01-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04036E	2015-01-09 16:54:54	2017-09-24 18:59:59
22478	619	2015-01-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14265W	2015-01-29 15:15:56	\N
22657	948	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
22665	1003	2015-01-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08024S	\N	\N
22667	1003	2015-01-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14105F	\N	\N
22668	1003	2015-01-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14239U	\N	\N
22670	908	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	05008E	\N	\N
22993	908	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14157T	\N	\N
23098	919	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01022K	\N	2017-09-24 17:14:26
23111	595	2015-03-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	2015-03-09 15:01:43	\N
23254	659	2015-03-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14026U	2015-05-11 10:10:05	\N
23255	530	2015-05-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	2015-05-12 10:11:55	\N
23278	948	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14265W	\N	\N
23292	978	2015-06-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11040E	2015-06-12 14:19:41	\N
23299	928	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14093U	\N	\N
23304	928	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
23306	928	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01041N	\N	2017-09-24 18:59:59
23308	928	2014-10-01 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	2016-12-12 16:10:15
23314	928	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	\N
23321	928	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14031R	\N	\N
23331	928	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
23374	575	2015-07-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2015-07-08 09:31:07	\N
23375	598	2015-07-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14079W	2015-07-08 09:36:39	\N
23608	584	2016-04-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14241N	2016-04-08 15:03:46	\N
23709	1005	2016-06-15 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01022K	\N	2017-09-24 17:14:26
23712	626	2016-06-23 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	08065C	2016-06-23 12:49:23	2017-09-25 09:57:52
23721	641	2016-06-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98022P	2016-07-11 15:56:57	\N
23722	617	2016-05-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	88008L	2016-07-11 15:58:03	\N
23751	575	2016-09-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11064N	2016-09-20 15:54:25	\N
23837	615	2017-02-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14363X	2017-02-08 10:56:07	2017-09-24 19:25:10
23838	612	2017-02-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14363X	2017-02-08 10:56:07	2017-09-24 19:25:10
23839	978	2017-02-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14363X	2017-02-08 10:56:07	2017-09-24 19:25:10
23840	556	2017-02-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14363X	2017-02-08 10:56:08	2017-09-24 19:25:10
23841	628	2017-02-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14363X	2017-02-08 10:56:08	2017-09-24 19:25:10
23842	596	2017-02-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14363X	2017-02-08 10:56:08	2017-09-24 19:25:10
23843	648	2017-02-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14363X	2017-02-08 10:56:08	2017-09-24 19:25:10
23864	659	2017-09-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14237S	2017-09-15 10:22:15	\N
23879	632	2017-10-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19591F	2017-10-10 09:48:39	\N
23880	575	2017-10-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19591F	2017-10-10 09:48:39	\N
23881	621	2017-10-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19591F	2017-10-10 09:48:39	\N
23882	595	2017-10-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19591F	2017-10-10 09:48:39	\N
23883	583	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19301E	2017-10-10 09:49:00	\N
23884	642	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19301E	2017-10-10 09:49:00	\N
24200	589	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	2017-10-17 12:19:06	\N
24201	584	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	2017-10-17 12:19:06	\N
24202	604	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	2017-10-17 12:19:06	\N
24203	595	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	2017-10-17 12:19:06	\N
20207	911	2013-11-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04057K	2013-11-14 09:47:06	2013-11-14 09:47:37
20208	642	2013-11-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	2013-11-14 09:49:29	2014-10-28 17:03:19
22410	851	2015-01-20 00:00:00	2015-06-17 00:00:00	ANCIEN	\N	\N	\N	14079W	2015-01-21 09:28:27	2015-06-18 10:57:46
22411	659	2015-01-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04086Q	2015-01-21 09:28:41	\N
22412	644	2015-01-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2015-01-21 09:28:58	2015-03-04 17:16:08
22413	532	2015-01-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	2015-01-21 09:29:20	2015-01-21 09:30:09
22414	644	2015-01-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	97011G	2015-01-21 09:29:31	\N
22438	644	2015-01-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14093U	2015-01-23 09:15:31	\N
22439	578	2015-01-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14093U	2015-01-23 09:15:31	2015-03-19 10:03:20
22440	651	2015-01-22 00:00:00	2016-12-31 00:00:00	ANCIEN	\N	\N	\N	07024N	2015-01-23 09:17:02	2017-01-03 11:09:24
22441	659	2015-01-22 00:00:00	2016-12-31 00:00:00	ANCIEN	\N	\N	\N	07024N	2015-01-23 09:17:02	2017-01-03 11:09:24
22442	578	2015-01-15 00:00:00	2015-05-05 00:00:00	ANCIEN	\N	\N	\N	04080J	2015-01-23 09:23:29	2015-06-15 10:19:50
22465	659	2015-01-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04077P	2015-01-27 17:35:28	\N
22466	613	2015-01-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04077P	2015-01-27 17:35:28	\N
22467	615	2015-01-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04077P	2015-01-27 17:35:28	\N
22508	979	2015-01-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	2015-02-03 18:40:32	2017-10-01 09:41:22
22509	615	2015-01-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14253S	2015-02-04 09:41:32	\N
22977	908	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11035H	\N	2017-09-24 18:16:52
23157	661	2015-03-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04042C	2015-03-11 15:21:53	\N
23158	600	2015-03-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14079W	2015-03-11 16:12:33	\N
23169	922	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	92039X	\N	2017-09-24 13:47:46
23219	938	2015-03-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	77002U	\N	\N
23276	616	2015-05-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	2015-05-26 10:26:10	\N
23226	938	2015-03-02 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	08065C	\N	2017-09-25 09:57:52
23275	657	2015-05-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2015-05-26 10:23:07	\N
23280	532	2015-05-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11061K	2015-05-29 10:08:00	2017-09-24 17:42:26
23283	612	2015-06-03 00:00:00	2017-06-04 00:00:00	ANCIEN	\N	\N	\N	14273W	2015-06-04 08:56:00	2017-06-07 09:38:00
23298	928	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	2017-09-24 13:44:49
23755	615	2016-09-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14071N	2016-10-03 15:58:59	\N
23759	623	2016-10-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11100Y	2016-10-18 09:32:30	2017-09-24 13:57:40
24103	CHRETORIENT	2017-10-16 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	11090Q	2017-10-16 14:22:33	\N
24280	643	2017-10-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08015R	2017-10-18 15:57:17	\N
24281	605	2017-10-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14195A	2017-10-18 16:05:47	\N
24282	581	2017-10-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19689Q	2017-10-18 16:23:39	\N
24283	632	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	97011G	2017-10-18 16:24:18	\N
24284	580	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	97011G	2017-10-18 16:24:18	\N
24285	641	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	97011G	2017-10-18 16:24:18	\N
24286	571	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	97011G	2017-10-18 16:24:18	\N
24287	629	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	97011G	2017-10-18 16:24:18	\N
24288	644	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	97011G	2017-10-18 16:24:18	\N
24289	602	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	97011G	2017-10-18 16:24:18	\N
24290	605	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	97011G	2017-10-18 16:24:18	\N
24291	597	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	97011G	2017-10-18 16:24:18	\N
24292	584	2017-10-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14087W	2017-10-18 16:24:57	\N
24293	615	2017-10-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08053X	2017-10-18 16:25:54	\N
24294	585	2017-10-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08053X	2017-10-18 16:25:54	\N
24295	978	2017-10-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08053X	2017-10-18 16:25:54	\N
24296	657	2017-10-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08053X	2017-10-18 16:25:54	\N
24297	591	2017-10-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08053X	2017-10-18 16:25:54	\N
24298	550	2017-10-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08053X	2017-10-18 16:25:54	\N
24299	584	2017-10-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08053X	2017-10-18 16:25:54	\N
24300	641	2017-10-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08053X	2017-10-18 16:25:54	\N
24301	571	2017-10-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08053X	2017-10-18 16:25:54	\N
24302	663	2017-10-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08053X	2017-10-18 16:25:54	\N
24303	651	2017-10-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08053X	2017-10-18 16:25:54	\N
24304	575	2017-10-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08053X	2017-10-18 16:25:54	\N
24305	646	2017-10-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08053X	2017-10-18 16:25:54	\N
24306	632	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01028R	2017-10-18 16:26:20	\N
24307	595	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01028R	2017-10-18 16:26:20	\N
24308	596	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01028R	2017-10-18 16:26:20	\N
24309	590	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01028R	2017-10-18 16:26:20	\N
24310	634	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01028R	2017-10-18 16:26:20	\N
24311	620	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01028R	2017-10-18 16:26:20	\N
24312	600	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19679N	2017-10-18 16:27:27	\N
24313	609	2017-10-12 00:00:00	2018-04-13 00:00:00	ANCIEN	\N	\N	\N	19483C	2017-10-18 16:27:54	2018-04-13 17:54:29
24314	623	2017-10-12 00:00:00	2018-04-13 00:00:00	ANCIEN	\N	\N	\N	19483C	2017-10-18 16:27:54	2018-04-13 17:54:29
24315	647	2017-10-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08055A	2017-10-18 16:28:53	\N
24316	978	2017-10-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08055A	2017-10-18 16:28:53	\N
24317	591	2017-10-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08055A	2017-10-18 16:28:53	\N
24318	599	2017-10-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08055A	2017-10-18 16:28:53	\N
24319	579	2017-10-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08058D	2017-10-18 16:29:09	\N
24320	604	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14026U	2017-10-18 16:30:02	\N
24321	580	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14026U	2017-10-18 16:30:02	\N
24322	629	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14026U	2017-10-18 16:30:02	\N
24323	634	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14026U	2017-10-18 16:30:02	\N
24324	589	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14026U	2017-10-18 16:30:02	\N
24325	595	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19621T	2017-10-18 16:30:25	\N
24326	598	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19621T	2017-10-18 16:30:25	\N
24327	573	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11045K	2017-10-18 16:30:44	\N
24328	641	2017-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14087W	2017-10-18 16:39:31	\N
24329	584	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	18083K	2017-10-18 17:43:40	\N
24330	596	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	18083K	2017-10-18 17:43:40	\N
24331	606	2017-10-17 00:00:00	2017-10-19 00:00:00	ANCIEN	\N	\N	\N	18083K	2017-10-18 17:43:40	2017-10-19 16:44:45
24332	572	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	18083K	2017-10-18 17:43:40	\N
21031	576	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08073C	2014-10-24 09:24:38	\N
21032	642	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08073C	2014-10-24 09:24:38	\N
21033	979	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08073C	2014-10-24 09:24:38	\N
21034	590	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08073C	2014-10-24 09:24:38	\N
21035	584	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08073C	2014-10-24 09:24:38	\N
21036	592	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2014-10-24 09:25:02	2015-03-11 12:57:26
21037	651	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2014-10-24 09:25:02	\N
21038	611	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2014-10-24 09:25:02	2015-03-20 18:13:34
21039	589	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14026U	2014-10-24 09:34:35	\N
21040	629	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14026U	2014-10-24 09:34:35	\N
21041	604	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14026U	2014-10-24 09:34:35	\N
21042	591	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14026U	2014-10-24 09:34:35	2017-07-20 14:38:36
21043	580	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14026U	2014-10-24 09:34:35	\N
21044	590	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14026U	2014-10-24 09:34:35	\N
21045	621	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01011G	2014-10-24 09:34:59	\N
21046	632	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01011G	2014-10-24 09:34:59	\N
21047	604	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14065Q	2014-10-24 09:35:49	\N
21048	602	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14065Q	2014-10-24 09:35:49	\N
21049	576	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14065Q	2014-10-24 09:35:49	\N
21050	616	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14065Q	2014-10-24 09:35:49	\N
21051	622	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14065Q	2014-10-24 09:35:49	\N
21052	626	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14065Q	2014-10-24 09:35:49	\N
21053	599	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	13002U	2014-10-24 09:36:09	2017-09-24 17:42:26
21054	573	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	13002U	2014-10-24 09:36:09	\N
21055	616	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	2014-10-24 09:38:25	\N
34451	1010	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	20074E	\N	\N
21056	590	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	2014-10-24 09:38:25	\N
21057	621	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	2014-10-24 09:38:25	\N
21058	589	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	2014-10-24 09:38:25	\N
21059	580	2014-10-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01061S	2014-10-24 09:39:14	\N
21060	596	2014-10-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01061S	2014-10-24 09:39:14	\N
21061	598	2014-10-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01061S	2014-10-24 09:39:14	\N
21062	629	2014-10-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01061S	2014-10-24 09:39:14	\N
22135	619	2014-11-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11014C	2014-11-07 09:49:50	2017-09-24 13:14:55
22136	585	2014-11-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11014C	2014-11-07 09:49:50	2017-09-24 13:14:55
22339	979	2014-12-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95037J	2014-12-16 09:52:30	2016-12-07 16:42:59
22340	556	2014-12-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95037J	2014-12-16 09:52:30	\N
22341	978	2014-12-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95037J	2014-12-16 09:52:30	\N
22536	584	2015-02-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14193X	2015-02-11 17:45:35	\N
22537	575	2015-02-09 00:00:00	2017-07-28 00:00:00	ANCIEN	\N	\N	\N	11032E	2015-02-12 09:05:56	2017-08-03 11:38:41
22538	601	2015-02-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	2015-02-12 09:06:15	2015-03-11 11:01:06
22539	586	2015-02-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	2015-02-12 09:06:15	\N
22540	609	2015-02-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11099A	2015-02-12 09:06:28	\N
22541	532	2015-02-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11076S	2015-02-12 09:51:50	2017-09-24 17:47:28
22878	906	2014-10-01 00:00:00	2015-04-16 00:00:00	ANCIEN	\N	\N	\N	14193X	\N	\N
22879	906	2014-10-01 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	2017-05-16 15:18:13
22880	906	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01024M	\N	\N
22881	906	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14237S	\N	\N
22882	906	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	\N	\N
22883	906	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11012A	\N	\N
22887	957	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14257W	\N	\N
22888	957	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14219Q	\N	\N
22889	957	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14157T	\N	\N
22890	957	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14026U	\N	\N
22891	957	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11059R	\N	2017-09-24 17:42:26
22892	957	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	\N	\N
22893	957	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11053K	\N	\N
22894	957	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11066Q	\N	\N
22895	957	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
22896	918	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
22897	918	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	2017-09-24 13:44:49
22898	918	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08053X	\N	\N
22899	918	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
22901	918	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11111C	\N	2017-09-24 16:45:26
22902	918	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14195A	\N	\N
22903	918	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14199E	\N	\N
22904	918	2014-10-01 00:00:00	2017-07-28 00:00:00	ANCIEN	\N	\N	\N	11032E	\N	2017-08-03 11:38:41
22905	918	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	2017-09-24 18:20:10
22906	918	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
22907	918	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14038Y	\N	\N
22975	642	2015-02-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98023Q	2015-03-02 14:58:56	\N
22981	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
23218	938	2015-03-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14093U	\N	\N
23221	938	2015-03-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11023D	\N	\N
23251	659	2015-05-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14265W	2015-05-05 09:21:44	\N
23268	910	2015-04-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11111C	\N	2017-09-24 16:45:26
23297	928	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14133K	\N	\N
23301	928	2014-10-01 00:00:00	2016-02-10 00:00:00	ANCIEN	\N	\N	\N	04047H	\N	\N
23302	928	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11095V	\N	2017-09-24 13:25:54
23303	928	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14053L	\N	\N
23305	928	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11091R	\N	2017-09-24 18:17:56
23307	928	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	12042Y	\N	2017-09-24 19:31:54
23309	928	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11061K	\N	2017-09-24 17:42:26
23310	928	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14026U	\N	\N
23311	928	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
23312	928	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01022K	\N	2017-09-24 17:14:26
23313	928	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11048N	\N	\N
23315	928	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	04036E	\N	2017-09-24 18:59:59
23316	928	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04061F	\N	\N
23317	928	2014-10-01 00:00:00	2017-07-22 00:00:00	ANCIEN	\N	\N	\N	14037X	\N	2017-07-24 09:58:00
23318	928	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	2017-09-24 17:48:21
23319	928	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14219Q	\N	\N
23320	928	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
23322	928	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14223L	\N	\N
23323	928	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14265W	\N	\N
23324	928	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14119M	\N	\N
23326	928	2014-10-01 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	11069T	\N	2016-03-11 18:02:51
23327	928	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
23328	928	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01019Q	\N	2017-09-24 17:35:15
23329	928	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
21063	590	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	2014-10-24 09:49:19	\N
21064	575	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	2014-10-24 09:49:19	\N
21065	620	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	2014-10-24 09:49:19	\N
21066	604	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	2014-10-24 09:49:19	\N
21067	598	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	2014-10-24 09:49:19	\N
21068	578	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	2014-10-24 09:49:19	\N
21069	589	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	2014-10-24 09:49:19	\N
21070	629	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	2014-10-24 09:49:19	\N
21071	584	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	2014-10-24 09:49:19	\N
21072	608	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	2014-10-24 09:49:19	\N
21073	595	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	2014-10-24 09:49:19	\N
21074	628	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	2014-10-24 09:50:07	\N
21075	584	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	2014-10-24 09:50:07	\N
21076	625	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	2014-10-24 09:50:07	\N
21077	608	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	2014-10-24 09:50:07	\N
21078	632	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	2014-10-24 09:50:07	\N
21079	598	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04059M	2014-10-24 09:50:45	\N
21080	578	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04059M	2014-10-24 09:50:45	2015-03-19 10:03:17
21081	978	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04059M	2014-10-24 09:50:45	\N
21082	596	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04059M	2014-10-24 09:50:45	\N
21083	632	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04059M	2014-10-24 09:50:45	\N
21084	595	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04059M	2014-10-24 09:50:45	\N
21085	590	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14030Q	2014-10-24 09:51:24	\N
21086	634	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14030Q	2014-10-24 09:51:24	\N
21087	598	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14030Q	2014-10-24 09:51:24	\N
21088	578	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14030Q	2014-10-24 09:51:24	2015-03-19 10:02:27
21089	583	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14030Q	2014-10-24 09:51:24	\N
21090	643	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14030Q	2014-10-24 09:51:24	\N
21503	588	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08069G	2014-10-29 15:29:20	\N
22335	591	2014-12-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08043V	2014-12-15 10:00:48	2017-07-20 14:38:10
22336	851	2014-12-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08043V	2014-12-15 10:00:48	\N
22409	640	2015-01-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11048N	2015-01-20 18:18:50	2015-01-22 17:04:47
22420	619	2015-01-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01056V	2015-01-21 15:11:00	2017-09-24 17:04:02
22421	615	2015-01-21 00:00:00	2015-06-16 00:00:00	ANCIEN	\N	\N	\N	14079W	2015-01-21 16:47:22	2015-06-17 13:55:29
22492	608	2015-01-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	96004D	2015-01-30 11:11:01	2015-02-02 16:43:12
22592	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14111D	\N	\N
22495	646	2015-01-26 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	14167V	2015-01-30 15:42:55	2017-10-01 10:18:28
22569	907	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	2017-09-24 18:20:10
22591	907	2014-10-01 00:00:00	2014-10-01 00:00:00	ANCIEN	\N	\N	\N	98046X	\N	\N
22594	907	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11088W	\N	2017-09-24 17:15:15
22595	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14119M	\N	\N
22596	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14207L	\N	\N
22597	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
22598	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	96004D	\N	\N
22599	913	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
22600	913	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
22601	913	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11036J	\N	2017-09-24 18:16:52
22602	913	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04033B	\N	\N
22603	913	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01028R	\N	\N
22604	913	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14038Y	\N	\N
22605	913	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08009T	\N	\N
22816	659	2015-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	2015-02-16 17:00:40	2017-10-01 10:39:23
22955	602	2015-02-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11089X	2015-02-23 09:42:25	\N
22967	922	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95063L	\N	\N
23144	911	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14133K	\N	\N
23145	911	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14121F	\N	\N
23160	640	2015-03-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11043H	2015-03-13 10:31:57	\N
23260	612	2015-05-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	10006L	2015-05-18 10:18:30	\N
23261	602	2015-05-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14271U	2015-05-18 11:52:01	2017-09-24 17:06:55
23445	632	2016-02-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11031D	2016-02-01 17:36:58	\N
23611	604	2016-05-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11080N	2016-05-04 09:41:36	\N
23773	919	2016-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14085U	\N	\N
23792	919	2016-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14213J	\N	\N
23794	919	2016-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08031R	\N	\N
23798	919	2016-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14059S	\N	\N
23799	919	2016-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08012N	\N	\N
23800	919	2016-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14111D	\N	\N
23802	919	2016-10-01 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	2017-06-19 12:20:59
23955	626	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11074Q	2017-10-11 15:51:06	\N
23956	577	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11074Q	2017-10-11 15:51:06	\N
23957	661	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11074Q	2017-10-11 15:51:06	\N
23958	575	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11074Q	2017-10-11 15:51:06	\N
23959	598	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11054L	2017-10-11 15:52:51	\N
23960	632	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11054L	2017-10-11 15:52:51	\N
23961	600	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11054L	2017-10-11 15:52:51	\N
23962	621	2017-10-10 00:00:00	2019-08-27 00:00:00	ANCIEN	\N	\N	\N	80027E	2017-10-11 15:53:47	\N
23963	626	2017-10-10 00:00:00	2019-08-27 00:00:00	ANCIEN	\N	\N	\N	80027E	2017-10-11 15:53:47	\N
23964	624	2017-10-10 00:00:00	2019-08-27 00:00:00	ANCIEN	\N	\N	\N	80027E	2017-10-11 15:53:47	\N
23965	594	2017-10-10 00:00:00	2019-08-27 00:00:00	ANCIEN	\N	\N	\N	80027E	2017-10-11 15:53:47	\N
23966	581	2017-10-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19719D	2017-10-11 15:54:40	\N
23967	589	2017-10-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19719D	2017-10-11 15:54:40	\N
23968	596	2017-10-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19719D	2017-10-11 15:54:40	\N
23969	584	2017-10-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19719D	2017-10-11 15:54:40	\N
23970	602	2017-10-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19719D	2017-10-11 15:54:40	\N
23971	978	2017-10-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19719D	2017-10-11 15:54:40	\N
23972	581	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14253S	2017-10-11 15:55:36	\N
23973	590	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14253S	2017-10-11 15:55:37	\N
23974	589	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14253S	2017-10-11 15:55:37	\N
20280	603	2014-09-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11027H	2014-09-03 09:32:32	\N
21306	584	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04054G	2014-10-28 16:56:46	\N
21307	674	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04054G	2014-10-28 16:56:46	\N
21308	632	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04054G	2014-10-28 16:56:46	\N
21309	574	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04054G	2014-10-28 16:56:46	\N
21310	978	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04054G	2014-10-28 16:56:46	\N
21311	643	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04054G	2014-10-28 16:56:46	\N
21312	626	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04054G	2014-10-28 16:56:46	\N
21313	979	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04054G	2014-10-28 16:56:47	2017-09-24 17:18:03
21314	576	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04054G	2014-10-28 16:56:47	\N
21315	592	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04054G	2014-10-28 16:56:47	2017-09-24 17:18:03
21316	608	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04054G	2014-10-28 16:56:47	\N
21317	598	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04054G	2014-10-28 16:56:47	\N
21318	590	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	98021N	2014-10-28 17:00:33	2017-10-01 09:22:38
21319	581	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	98021N	2014-10-28 17:00:33	2017-10-01 09:22:38
21320	584	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	98021N	2014-10-28 17:00:33	2017-10-01 09:22:38
21321	629	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	98021N	2014-10-28 17:00:33	2017-10-01 09:22:38
21322	608	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	98021N	2014-10-28 17:00:33	2017-10-01 09:22:38
21323	604	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	98021N	2014-10-28 17:00:33	2017-10-01 09:22:38
21324	622	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14031R	2014-10-28 17:08:58	\N
21325	621	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14031R	2014-10-28 17:08:58	\N
21326	573	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14031R	2014-10-28 17:08:58	\N
21327	584	2014-10-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04071H	2014-10-28 17:09:30	\N
21328	576	2014-10-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04071H	2014-10-28 17:09:30	\N
21329	618	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14259Y	2014-10-28 17:10:30	\N
21330	622	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14259Y	2014-10-28 17:10:30	\N
21331	584	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14259Y	2014-10-28 17:10:30	\N
21332	612	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14259Y	2014-10-28 17:10:30	\N
21333	663	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14259Y	2014-10-28 17:10:30	\N
21334	641	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14259Y	2014-10-28 17:10:30	\N
21335	580	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14259Y	2014-10-28 17:10:30	2015-04-10 15:10:05
21336	646	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14259Y	2014-10-28 17:10:30	\N
21337	978	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11094U	2014-10-28 17:10:59	\N
21338	589	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11094U	2014-10-28 17:10:59	\N
21339	651	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11094U	2014-10-28 17:10:59	\N
21340	597	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11094U	2014-10-28 17:10:59	\N
21341	659	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01019Q	2014-10-28 17:11:24	\N
21342	618	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14051J	2014-10-28 17:11:44	\N
21343	611	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14051J	2014-10-28 17:11:44	2015-03-20 18:13:30
21344	621	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14051J	2014-10-28 17:11:44	\N
21345	600	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98053W	2014-10-28 17:12:10	\N
21346	626	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98053W	2014-10-28 17:12:10	\N
21347	620	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98053W	2014-10-28 17:12:10	\N
21348	592	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98053W	2014-10-28 17:12:10	\N
21349	608	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98053W	2014-10-28 17:12:10	\N
21350	621	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01047U	2014-10-28 17:13:21	\N
21351	644	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01047U	2014-10-28 17:13:21	2017-09-24 13:29:42
21352	629	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01047U	2014-10-28 17:13:21	\N
21353	597	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01047U	2014-10-28 17:13:21	\N
21533	578	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08038Y	2014-10-29 18:10:51	\N
21534	584	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01013J	2014-10-29 18:11:26	\N
21535	574	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01013J	2014-10-29 18:11:26	\N
21536	576	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01013J	2014-10-29 18:11:26	\N
21537	632	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01013J	2014-10-29 18:11:26	\N
21538	979	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01013J	2014-10-29 18:11:26	\N
21539	978	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01013J	2014-10-29 18:11:26	\N
22422	595	2015-01-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04042C	2015-01-22 09:17:53	\N
22423	659	2015-01-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	2015-01-22 09:18:15	2017-10-01 09:41:22
22424	641	2015-01-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	97011G	2015-01-22 09:18:27	\N
22425	578	2015-01-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	2015-01-22 09:18:45	\N
22426	615	2015-01-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14001X	2015-01-22 09:18:56	\N
22427	592	2015-01-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95062K	2015-01-22 09:19:43	\N
22428	673	2015-01-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95067Q	2015-01-22 09:19:55	\N
22443	532	2015-01-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04034C	2015-01-23 09:34:56	\N
22676	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08010L	\N	\N
22842	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11080N	\N	\N
22843	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08021P	\N	\N
22969	530	2015-02-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	2015-02-26 09:16:47	\N
23159	601	2015-03-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	97011G	2015-03-12 09:58:42	\N
23162	912	2014-10-01 00:00:00	2014-10-02 00:00:00	ANCIEN	\N	\N	\N	09001P	\N	\N
23234	938	2015-03-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	08053X	\N	\N
23373	583	2015-07-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14277B	2015-07-07 09:13:16	\N
23606	963	2016-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	14209N	2016-04-07 09:18:03	2017-10-01 10:34:22
23607	978	2016-04-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11100Y	2016-04-08 09:24:37	2017-09-24 13:57:40
23718	623	2016-06-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14169X	2016-06-29 17:11:49	\N
23862	624	2017-07-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	19253P	2017-07-06 17:50:34	\N
23863	634	2017-07-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	2017-07-20 18:35:52	\N
24104	590	2017-10-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19651A	2017-10-17 11:05:25	\N
24105	601	2017-10-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19651A	2017-10-17 11:05:25	\N
24106	598	2017-10-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19651A	2017-10-17 11:05:25	\N
24107	621	2017-10-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19651A	2017-10-17 11:05:25	\N
24108	613	2017-10-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19651A	2017-10-17 11:05:25	\N
24109	576	2017-10-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19651A	2017-10-17 11:05:25	\N
24110	591	2017-10-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19651A	2017-10-17 11:05:25	\N
20330	643	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11113E	2014-10-14 18:31:30	\N
20331	642	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11113E	2014-10-14 18:31:30	\N
20332	576	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11113E	2014-10-14 18:31:30	\N
20333	584	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11113E	2014-10-14 18:31:31	\N
20756	591	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11091R	2014-10-22 16:34:14	2017-09-24 18:17:56
20757	583	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11091R	2014-10-22 16:34:14	\N
20758	572	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11091R	2014-10-22 16:34:14	\N
20759	589	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11091R	2014-10-22 16:34:14	\N
20760	626	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11091R	2014-10-22 16:34:14	\N
20761	621	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11091R	2014-10-22 16:34:14	\N
20762	575	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11091R	2014-10-22 16:34:14	\N
20763	629	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11091R	2014-10-22 16:34:14	\N
20764	602	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11091R	2014-10-22 16:34:14	\N
20765	577	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11091R	2014-10-22 16:34:14	2017-09-24 18:17:56
20766	610	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11091R	2014-10-22 16:34:14	2017-09-24 18:17:56
20767	578	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11091R	2014-10-22 16:34:14	2017-09-24 18:17:56
20768	589	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11111C	2014-10-22 16:36:52	\N
20769	594	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11111C	2014-10-22 16:36:52	\N
20771	581	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2014-10-22 16:40:05	\N
20772	573	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2014-10-22 16:40:05	\N
20773	598	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2014-10-22 16:40:06	\N
20774	583	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2014-10-22 16:40:06	\N
20775	590	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2014-10-22 16:40:06	\N
20776	618	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2014-10-22 16:40:06	\N
20777	580	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2014-10-22 16:40:06	\N
20778	625	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2014-10-22 16:40:06	\N
20779	610	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2014-10-22 16:40:06	\N
20780	594	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2014-10-22 16:40:06	\N
20781	578	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2014-10-22 16:40:06	\N
21206	979	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14039A	2014-10-27 09:21:50	\N
21207	530	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95062K	2014-10-27 09:24:36	\N
21208	583	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95062K	2014-10-27 09:24:36	\N
21209	620	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95062K	2014-10-27 09:24:36	\N
21210	602	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95062K	2014-10-27 09:24:36	\N
21211	590	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95062K	2014-10-27 09:24:36	\N
21212	608	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95062K	2014-10-27 09:24:37	\N
21213	629	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95062K	2014-10-27 09:24:37	\N
21214	600	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95062K	2014-10-27 09:24:37	\N
21215	659	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95062K	2014-10-27 09:24:37	\N
21216	575	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95062K	2014-10-27 09:24:37	\N
21217	599	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95062K	2014-10-27 09:24:37	\N
21218	579	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95062K	2014-10-27 09:24:37	\N
21219	606	2014-10-24 00:00:00	2014-10-26 00:00:00	ANCIEN	\N	\N	\N	95062K	2014-10-27 09:24:37	2014-10-27 15:59:49
21220	580	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95062K	2014-10-27 09:24:37	\N
21221	604	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95062K	2014-10-27 09:24:37	\N
21222	603	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95062K	2014-10-27 09:24:37	\N
21223	621	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95062K	2014-10-27 09:24:37	\N
21224	653	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08012N	2014-10-27 09:25:23	\N
21225	599	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08012N	2014-10-27 09:25:23	\N
21226	978	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08012N	2014-10-27 09:25:23	\N
21504	584	2014-10-28 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	08065C	2014-10-29 15:53:57	2017-09-25 09:57:52
21505	979	2014-10-28 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	08065C	2014-10-29 15:53:57	2017-09-25 09:57:52
21506	640	2014-10-28 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	08065C	2014-10-29 15:53:57	2017-09-25 09:57:52
21507	634	2014-10-28 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	08065C	2014-10-29 15:53:58	2017-09-25 09:57:52
21508	601	2014-10-28 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	08065C	2014-10-29 15:53:58	2017-09-25 09:57:52
21509	598	2014-10-28 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	08065C	2014-10-29 15:53:58	2017-09-25 09:57:52
21510	622	2014-10-28 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	08065C	2014-10-29 15:53:58	2017-09-25 09:57:52
21511	602	2014-10-28 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	08065C	2014-10-29 15:53:58	2017-09-25 09:57:52
21512	573	2014-10-28 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	08065C	2014-10-29 15:53:58	2017-09-25 09:57:52
21513	596	2014-10-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01028R	2014-10-29 15:55:41	\N
21514	590	2014-10-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01028R	2014-10-29 15:55:41	\N
21515	634	2014-10-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01028R	2014-10-29 15:55:41	\N
21516	595	2014-10-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01028R	2014-10-29 15:55:41	\N
21517	632	2014-10-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01028R	2014-10-29 15:55:41	\N
21518	624	2014-10-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01028R	2014-10-29 15:55:41	\N
21519	620	2014-10-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01028R	2014-10-29 15:55:41	\N
21520	618	2014-10-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01028R	2014-10-29 15:55:41	\N
21521	584	2014-10-24 00:00:00	2016-11-12 00:00:00	ANCIEN	\N	\N	\N	96003C	2014-10-29 15:56:10	2016-11-14 11:07:47
21522	626	2014-10-24 00:00:00	2016-11-12 00:00:00	ANCIEN	\N	\N	\N	96003C	2014-10-29 15:56:10	2016-11-14 11:07:47
21523	622	2014-10-24 00:00:00	2016-11-12 00:00:00	ANCIEN	\N	\N	\N	96003C	2014-10-29 15:56:10	2016-11-14 11:07:47
21524	574	2014-10-24 00:00:00	2016-11-12 00:00:00	ANCIEN	\N	\N	\N	96003C	2014-10-29 15:56:10	2016-11-14 11:07:47
21525	618	2014-10-24 00:00:00	2016-11-12 00:00:00	ANCIEN	\N	\N	\N	96003C	2014-10-29 15:56:10	2016-11-14 11:07:47
21526	591	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08048B	2014-10-29 16:19:47	2017-07-20 14:38:36
21527	621	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08048B	2014-10-29 16:19:47	\N
21528	641	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08048B	2014-10-29 16:19:47	\N
21529	595	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08048B	2014-10-29 16:19:47	\N
21530	629	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08048B	2014-10-29 16:19:47	\N
21783	621	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11076S	2014-10-30 18:34:28	\N
21784	572	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11076S	2014-10-30 18:34:28	\N
21785	623	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11076S	2014-10-30 18:34:28	2017-09-24 17:47:28
21786	609	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11076S	2014-10-30 18:34:28	\N
21787	556	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11076S	2014-10-30 18:34:28	\N
21788	625	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11076S	2014-10-30 18:34:28	\N
21789	598	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11076S	2014-10-30 18:34:28	\N
21790	653	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11076S	2014-10-30 18:34:28	\N
21791	590	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11076S	2014-10-30 18:34:29	\N
21792	628	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11076S	2014-10-30 18:34:29	2017-09-24 17:47:28
20222	580	2013-11-01 00:00:00	2014-09-29 00:00:00	ANCIEN	\N	\N	\N	98019U	2014-01-09 15:25:39	2014-09-29 13:43:10
20366	640	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	2014-10-15 13:26:29	\N
20367	532	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	2014-10-15 13:26:29	2015-03-10 17:27:36
20368	625	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	2014-10-15 13:26:29	\N
20369	590	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	2014-10-15 13:26:29	\N
20370	674	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	2014-10-15 13:26:29	\N
20371	621	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	2014-10-15 13:26:29	\N
20372	529	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	2014-10-15 13:26:29	\N
20373	604	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	2014-10-15 13:26:29	\N
20374	629	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	2014-10-15 13:26:29	\N
20375	581	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	2014-10-15 13:26:29	\N
20376	673	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	2014-10-15 13:26:29	\N
20598	573	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01041N	2014-10-21 17:21:57	2014-10-21 17:22:10
21302	626	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	12041X	2014-10-28 16:07:21	\N
21916	624	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	10015M	2014-10-31 14:45:14	\N
21917	534	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	10015M	2014-10-31 14:45:14	\N
21918	629	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	10015M	2014-10-31 14:45:14	\N
21919	556	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	10015M	2014-10-31 14:45:14	\N
21920	595	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	10015M	2014-10-31 14:45:14	\N
21921	661	2014-10-28 00:00:00	2015-01-12 00:00:00	ANCIEN	\N	\N	\N	10015M	2014-10-31 14:45:14	2015-01-26 14:59:13
21922	625	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14061L	2014-10-31 15:08:08	\N
21923	576	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14061L	2014-10-31 15:08:08	\N
21924	979	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14061L	2014-10-31 15:08:08	\N
21925	556	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14061L	2014-10-31 15:08:08	\N
21926	580	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14061L	2014-10-31 15:08:08	2015-04-10 15:10:26
21927	625	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11056N	2014-10-31 15:19:13	\N
21928	642	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11056N	2014-10-31 15:19:13	\N
21929	573	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11056N	2014-10-31 15:19:13	\N
21930	608	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11056N	2014-10-31 15:19:13	\N
21931	556	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11056N	2014-10-31 15:19:13	\N
21932	575	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11056N	2014-10-31 15:19:13	\N
21933	586	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11056N	2014-10-31 15:19:13	\N
22314	571	2014-12-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95062K	2014-12-04 15:49:08	\N
22444	578	2015-01-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	2015-01-23 11:13:34	\N
22494	646	2015-01-30 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	14263U	2015-01-30 12:40:35	2017-06-19 16:04:13
22510	622	2015-01-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14028W	2015-02-04 11:40:06	\N
22546	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14093U	\N	\N
22561	907	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11044J	\N	2017-09-24 17:29:37
22572	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14135M	\N	\N
22593	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11063M	\N	\N
22607	912	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11054L	\N	\N
22608	912	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	05008E	\N	\N
22609	912	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
22610	912	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
22611	912	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14205J	\N	\N
22612	912	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	92045V	\N	2017-09-24 17:29:37
22613	912	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14173T	\N	\N
22615	912	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11112D	\N	2017-09-24 16:45:26
22616	912	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08009T	\N	\N
22618	912	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
22620	912	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08034U	\N	\N
22621	912	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
22622	912	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11088W	\N	2017-09-24 17:15:15
22623	912	2014-10-01 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	14137P	\N	2015-06-12 15:59:18
22908	601	2015-02-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11101A	2015-02-19 14:12:32	2015-03-11 10:57:52
23063	590	2015-02-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14251Q	2015-03-03 15:34:29	\N
23239	659	2015-04-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14217N	2015-04-17 09:47:40	\N
23240	661	2015-04-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08015R	2015-04-17 09:52:41	2017-10-10 11:04:14
23241	957	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08068F	\N	\N
23330	928	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	2017-09-24 17:04:02
23372	588	2015-07-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2015-07-03 09:23:16	\N
23390	623	2015-09-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14028W	2015-09-16 17:35:51	\N
23406	991	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	\N	\N
23424	628	2015-11-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14034U	2015-11-13 15:12:22	\N
23432	612	2015-11-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14053L	2015-12-01 10:00:38	\N
23592	908	2016-02-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14331P	\N	\N
23595	618	2016-02-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04077P	2016-02-16 18:08:35	2017-09-24 17:47:27
23761	573	2016-10-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	2016-10-27 15:50:42	\N
24746	581	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	92040Q	2017-10-26 17:24:40	\N
24747	580	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	92040Q	2017-10-26 17:24:40	\N
24748	601	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	92040Q	2017-10-26 17:24:40	\N
24749	604	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	92040Q	2017-10-26 17:24:40	\N
24750	628	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	2017-10-27 09:56:07	\N
24751	534	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	2017-10-27 09:56:07	\N
24752	659	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	2017-10-27 09:56:07	\N
24753	602	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19693L	2017-10-27 09:57:22	\N
24754	621	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19693L	2017-10-27 09:57:22	\N
24755	590	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19693L	2017-10-27 09:57:22	\N
24756	598	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19693L	2017-10-27 09:57:22	\N
24757	580	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19693L	2017-10-27 09:57:22	\N
24758	622	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19329S	2017-10-27 09:57:49	\N
24759	573	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19329S	2017-10-27 09:57:49	\N
24760	595	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04059M	2017-10-27 09:58:29	\N
24761	978	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04059M	2017-10-27 09:58:29	\N
24762	596	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04059M	2017-10-27 09:58:29	\N
24763	598	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04059M	2017-10-27 09:58:29	\N
24764	632	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04059M	2017-10-27 09:58:29	\N
20770	643	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14197C	2014-10-22 16:39:52	\N
20782	978	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98018T	2014-10-22 16:46:22	\N
20783	963	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98018T	2014-10-22 16:46:22	\N
20784	579	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98018T	2014-10-22 16:46:22	\N
20785	643	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98018T	2014-10-22 16:46:22	\N
20786	572	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98018T	2014-10-22 16:46:22	\N
20787	629	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98018T	2014-10-22 16:46:22	\N
20788	580	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98018T	2014-10-22 16:46:22	\N
20789	583	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98018T	2014-10-22 16:46:22	\N
20790	590	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98018T	2014-10-22 16:46:22	\N
20791	584	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98018T	2014-10-22 16:46:22	\N
20792	608	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11080N	2014-10-22 16:53:26	\N
20793	622	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11080N	2014-10-22 16:53:26	\N
20794	661	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11080N	2014-10-22 16:53:26	\N
20795	598	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11080N	2014-10-22 16:53:26	\N
20796	573	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	77002U	2014-10-22 16:54:42	\N
20797	556	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	77002U	2014-10-22 16:54:43	\N
20798	588	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	77002U	2014-10-22 16:54:43	\N
20799	622	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	77002U	2014-10-22 16:54:43	\N
20800	673	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	77002U	2014-10-22 16:54:43	\N
20801	659	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	77002U	2014-10-22 16:54:43	\N
20802	598	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	77002U	2014-10-22 16:54:43	\N
20803	595	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14225N	2014-10-22 16:58:15	\N
20804	590	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14225N	2014-10-22 16:58:15	\N
20805	584	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14225N	2014-10-22 16:58:15	\N
21778	574	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92018S	2014-10-30 17:49:00	\N
21779	575	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92018S	2014-10-30 17:49:00	\N
21780	979	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92018S	2014-10-30 17:49:00	\N
21781	632	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92018S	2014-10-30 17:49:00	\N
21782	620	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92018S	2014-10-30 17:49:00	\N
22400	623	2015-01-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95063L	2015-01-16 16:31:55	\N
22401	584	2015-01-16 00:00:00	2017-07-28 00:00:00	ANCIEN	\N	\N	\N	11032E	2015-01-19 09:22:11	2017-08-03 11:38:41
22884	906	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04061F	\N	\N
22886	906	2014-10-01 00:00:00	2014-10-01 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
22912	910	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14219Q	\N	\N
22913	910	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14063N	\N	\N
22914	910	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14249W	\N	\N
22915	910	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11014C	\N	2017-09-24 13:14:55
22916	910	2014-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	14209N	\N	2017-10-01 10:34:22
22917	910	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08021P	\N	\N
22918	910	2014-10-01 00:00:00	2016-11-30 00:00:00	ANCIEN	\N	\N	\N	04048J	\N	2016-12-01 10:36:51
22919	910	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11066Q	\N	\N
22920	919	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14257W	\N	\N
22921	919	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11099A	\N	\N
22922	919	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08053X	\N	\N
22923	919	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14157T	\N	\N
22925	919	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14026U	\N	\N
22926	919	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
22927	919	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11059R	\N	2017-09-24 17:42:26
23621	633	2016-05-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98022P	2016-05-26 14:47:45	\N
23975	573	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14267Y	2017-10-11 16:12:53	\N
23976	621	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14267Y	2017-10-11 16:12:53	\N
23977	612	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14217N	2017-10-11 16:17:47	\N
23978	659	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14217N	2017-10-11 16:17:47	\N
23979	600	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14217N	2017-10-11 16:17:47	\N
23980	643	2017-10-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	2017-10-11 16:19:42	\N
23981	979	2017-10-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	2017-10-11 16:19:42	\N
23982	626	2017-10-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	2017-10-11 16:19:42	\N
23983	584	2017-10-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	2017-10-11 16:19:42	\N
23984	616	2017-10-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	2017-10-11 16:19:42	\N
23985	978	2017-10-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	2017-10-11 16:19:42	\N
23986	534	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	10015M	2017-10-11 16:21:36	\N
23987	595	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	10015M	2017-10-11 16:21:36	\N
23988	661	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	10015M	2017-10-11 16:21:36	\N
23989	556	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	10015M	2017-10-11 16:21:36	\N
23990	598	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	2017-10-11 16:23:07	\N
23991	604	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	2017-10-11 16:23:07	\N
23992	621	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	2017-10-11 16:23:07	\N
23993	595	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	2017-10-11 16:23:07	\N
23994	632	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	2017-10-11 16:23:07	\N
23995	613	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	2017-10-11 16:23:07	\N
23996	597	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	2017-10-11 16:23:07	\N
23997	575	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	2017-10-11 16:23:07	\N
23998	588	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	2017-10-11 16:23:07	\N
23999	602	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	2017-10-11 16:23:07	\N
24000	610	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	2017-10-11 16:23:07	\N
24001	582	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	2017-10-11 16:23:07	\N
24002	620	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	2017-10-11 16:23:07	\N
24003	590	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	2017-10-11 16:23:07	\N
24004	629	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	2017-10-11 16:23:07	\N
24005	634	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	2017-10-11 16:23:07	\N
24006	617	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	2017-10-11 16:23:07	\N
24007	641	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	2017-10-11 16:23:07	\N
24008	601	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14223L	2017-10-11 16:24:56	\N
24009	621	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14223L	2017-10-11 16:24:56	\N
24010	595	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14223L	2017-10-11 16:24:56	\N
24011	963	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14223L	2017-10-11 16:24:56	\N
24012	589	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14223L	2017-10-11 16:24:56	\N
24013	629	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14223L	2017-10-11 16:24:56	\N
21987	661	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	96004D	2014-10-31 17:53:27	\N
21988	579	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	96004D	2014-10-31 17:53:27	\N
21989	590	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	96004D	2014-10-31 17:53:27	\N
21990	629	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	96004D	2014-10-31 17:53:27	\N
21991	583	2014-10-31 00:00:00	2014-12-27 00:00:00	ANCIEN	\N	\N	\N	14129P	2014-10-31 18:02:46	2014-12-29 15:40:09
21992	625	2014-10-31 00:00:00	2014-12-27 00:00:00	ANCIEN	\N	\N	\N	14129P	2014-10-31 18:02:46	2014-12-29 15:40:09
22315	979	2014-12-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14225N	2014-12-05 18:37:59	2016-12-07 15:57:06
22316	978	2014-12-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14225N	2014-12-05 18:37:59	\N
22429	573	2015-01-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11107G	2015-01-22 12:37:00	2015-01-23 11:54:46
22430	578	2015-01-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08053X	2015-01-22 12:37:14	\N
22447	572	2015-01-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98005N	2015-01-23 17:18:43	\N
34452	1010	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	11027H	\N	\N
22432	646	2015-01-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	2015-01-22 14:46:39	2015-01-22 16:16:13
22548	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	05008E	\N	\N
22516	629	2015-01-30 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	90003B	2015-02-04 15:18:33	2017-10-01 10:01:39
22614	912	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04033B	\N	\N
22885	906	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08015R	\N	\N
22900	918	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14237S	\N	\N
22945	530	2015-02-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2015-02-19 16:34:53	\N
23450	642	2016-02-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11039M	2016-02-11 09:50:25	2017-09-24 18:16:52
23599	623	2016-03-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04080J	2016-03-29 15:45:33	2017-09-24 17:47:27
23600	592	2016-03-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	2016-03-30 15:40:09	\N
23602	651	2016-03-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14259Y	2016-04-01 09:31:55	\N
23609	673	2016-04-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92045V	2016-04-13 16:04:33	2017-09-24 17:29:37
23814	963	2016-11-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92045V	2016-11-17 09:45:28	2017-09-24 17:29:37
23833	1005	2017-01-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14225N	\N	\N
24111	851	2017-10-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08043V	2017-10-17 11:05:49	\N
24112	602	2017-10-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08043V	2017-10-17 11:05:49	\N
24113	600	2017-10-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08043V	2017-10-17 11:05:49	\N
24114	556	2017-10-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14085U	2017-10-17 11:06:12	\N
24115	620	2017-10-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14085U	2017-10-17 11:06:12	\N
24117	647	2017-10-11 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08052W	2017-10-17 11:08:45	\N
24118	590	2017-10-11 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08052W	2017-10-17 11:08:45	\N
24119	604	2017-10-11 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08052W	2017-10-17 11:08:45	\N
24120	608	2017-10-11 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08052W	2017-10-17 11:08:45	\N
24121	659	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14215L	2017-10-17 11:09:19	\N
24122	585	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14215L	2017-10-17 11:09:19	\N
24123	625	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14042U	2017-10-17 11:10:05	\N
24124	576	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04071H	2017-10-17 11:16:57	\N
24125	634	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19673G	2017-10-17 11:17:24	\N
24126	646	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19673G	2017-10-17 11:17:24	\N
24127	979	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19673G	2017-10-17 11:17:24	\N
24128	618	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08045X	2017-10-17 11:17:55	\N
24129	633	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08045X	2017-10-17 11:17:55	\N
24130	592	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	2017-10-17 11:18:42	\N
24131	616	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	2017-10-17 11:18:42	\N
24132	634	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	2017-10-17 11:18:42	\N
24133	530	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	2017-10-17 11:18:42	\N
24134	612	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	2017-10-17 11:18:42	\N
24135	602	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	2017-10-17 11:18:42	\N
24136	583	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	2017-10-17 11:18:42	\N
24137	611	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	2017-10-17 11:18:42	\N
24138	623	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	2017-10-17 11:18:42	\N
24139	625	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	2017-10-17 11:18:42	\N
24140	647	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	2017-10-17 11:18:42	\N
24141	621	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	2017-10-17 11:18:42	\N
24142	577	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	2017-10-17 11:18:42	\N
24143	640	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	2017-10-17 11:18:42	\N
24144	673	2017-10-10 00:00:00	2020-09-24 00:00:00	ANCIEN	\N	\N	\N	08041T	2017-10-17 11:19:04	\N
24145	661	2017-10-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04097T	2017-10-17 11:19:37	\N
24146	584	2017-10-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04097T	2017-10-17 11:19:37	\N
24147	582	2017-10-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04097T	2017-10-17 11:19:37	\N
24148	580	2017-10-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04097T	2017-10-17 11:19:37	\N
24149	604	2017-10-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04097T	2017-10-17 11:19:37	\N
24150	583	2017-10-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04097T	2017-10-17 11:19:37	\N
24151	608	2017-10-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04097T	2017-10-17 11:19:37	\N
24152	629	2017-10-11 00:00:00	2020-07-31 00:00:00	ANCIEN	\N	\N	\N	08044W	2017-10-17 11:20:35	\N
24153	634	2017-10-11 00:00:00	2020-07-31 00:00:00	ANCIEN	\N	\N	\N	08044W	2017-10-17 11:20:35	\N
24154	590	2017-10-11 00:00:00	2020-07-31 00:00:00	ANCIEN	\N	\N	\N	08044W	2017-10-17 11:20:35	\N
24155	618	2017-10-11 00:00:00	2020-07-31 00:00:00	ANCIEN	\N	\N	\N	08044W	2017-10-17 11:20:35	\N
24156	979	2017-10-11 00:00:00	2020-07-31 00:00:00	ANCIEN	\N	\N	\N	08044W	2017-10-17 11:20:35	\N
24157	583	2017-10-11 00:00:00	2020-07-31 00:00:00	ANCIEN	\N	\N	\N	08044W	2017-10-17 11:20:35	\N
24158	623	2017-10-11 00:00:00	2020-07-31 00:00:00	ANCIEN	\N	\N	\N	08044W	2017-10-17 11:20:35	\N
24159	642	2017-10-11 00:00:00	2020-07-31 00:00:00	ANCIEN	\N	\N	\N	08044W	2017-10-17 11:20:35	\N
24160	641	2017-10-11 00:00:00	2020-07-31 00:00:00	ANCIEN	\N	\N	\N	08044W	2017-10-17 11:20:35	\N
24161	643	2017-10-11 00:00:00	2020-07-31 00:00:00	ANCIEN	\N	\N	\N	08044W	2017-10-17 11:20:35	\N
24162	595	2017-10-11 00:00:00	2020-07-31 00:00:00	ANCIEN	\N	\N	\N	08044W	2017-10-17 11:20:36	\N
24163	608	2017-10-11 00:00:00	2020-07-31 00:00:00	ANCIEN	\N	\N	\N	08044W	2017-10-17 11:20:36	\N
24164	576	2017-10-11 00:00:00	2020-07-31 00:00:00	ANCIEN	\N	\N	\N	08044W	2017-10-17 11:20:36	\N
24165	622	2017-10-11 00:00:00	2020-07-31 00:00:00	ANCIEN	\N	\N	\N	08044W	2017-10-17 11:20:36	\N
24166	646	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08010L	2017-10-17 11:21:03	\N
24167	597	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08010L	2017-10-17 11:21:03	\N
24168	604	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08010L	2017-10-17 11:21:03	\N
24169	589	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14001X	2017-10-17 11:28:37	\N
24170	585	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14001X	2017-10-17 11:28:37	\N
24171	643	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14001X	2017-10-17 11:28:37	\N
24172	653	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14001X	2017-10-17 11:28:37	\N
20211	912	2013-11-29 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11054L	\N	2013-11-29 16:16:31
20212	912	2013-11-29 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08009T	\N	2013-11-29 16:16:45
21091	595	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01014K	2014-10-24 10:10:26	\N
21092	632	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01014K	2014-10-24 10:10:26	\N
21093	556	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01014K	2014-10-24 10:10:26	\N
21094	573	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01014K	2014-10-24 10:10:26	\N
21095	598	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08009T	2014-10-24 10:12:30	\N
21096	624	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08009T	2014-10-24 10:12:30	\N
21097	534	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08009T	2014-10-24 10:12:30	\N
21098	530	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08009T	2014-10-24 10:12:30	\N
21099	595	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08009T	2014-10-24 10:12:30	\N
21100	584	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08009T	2014-10-24 10:12:30	\N
21101	583	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08009T	2014-10-24 10:12:30	\N
21102	574	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08009T	2014-10-24 10:12:30	\N
21103	622	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08009T	2014-10-24 10:12:30	\N
21104	609	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08009T	2014-10-24 10:12:30	\N
21105	661	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08009T	2014-10-24 10:12:30	2015-03-19 09:58:10
21106	618	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08009T	2014-10-24 10:12:31	\N
21370	577	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04054G	2014-10-28 17:33:26	2017-09-24 17:18:03
21371	573	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04054G	2014-10-28 17:33:26	\N
21372	572	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04054G	2014-10-28 17:33:27	\N
21793	601	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11076S	2014-10-30 18:34:29	2017-09-24 17:47:28
21794	633	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11076S	2014-10-30 18:34:29	2017-09-24 17:47:28
21795	659	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11076S	2014-10-30 18:34:29	\N
21796	575	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11076S	2014-10-30 18:34:29	\N
21797	632	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11076S	2014-10-30 18:34:29	\N
21798	617	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11076S	2014-10-30 18:34:29	\N
21799	588	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11076S	2014-10-30 18:34:29	\N
21800	640	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11076S	2014-10-30 18:34:29	\N
21801	644	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11076S	2014-10-30 18:34:29	2017-09-24 17:47:28
21802	580	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11076S	2014-10-30 18:34:29	2017-09-24 17:47:28
21803	581	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11076S	2014-10-30 18:34:29	\N
21804	624	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11076S	2014-10-30 18:34:29	\N
21805	576	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11076S	2014-10-30 18:34:29	\N
21806	661	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11076S	2014-10-30 18:34:29	\N
21807	596	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11076S	2014-10-30 18:34:29	\N
21808	618	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11076S	2014-10-30 18:34:29	\N
21809	584	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11076S	2014-10-30 18:34:29	2017-09-24 17:47:28
21810	646	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11076S	2014-10-30 18:34:29	\N
21811	595	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11076S	2014-10-30 18:34:29	\N
21812	604	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11076S	2014-10-30 18:34:29	\N
21813	574	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11076S	2014-10-30 18:34:29	\N
21814	615	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11076S	2014-10-30 18:34:29	\N
21815	657	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11076S	2014-10-30 18:34:29	2017-09-24 17:47:28
21816	573	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11076S	2014-10-30 18:34:29	\N
21817	597	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11076S	2014-10-30 18:34:30	\N
21818	620	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11076S	2014-10-30 18:34:30	\N
21819	608	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11076S	2014-10-30 18:34:30	\N
21820	583	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11076S	2014-10-30 18:34:30	\N
22264	611	2014-11-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	2014-11-20 16:30:29	\N
22265	646	2014-11-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	2014-11-20 16:30:29	\N
22381	573	2015-01-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14071N	2015-01-13 14:49:45	\N
22416	592	2015-01-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08019V	2015-01-21 12:00:49	\N
22417	653	2015-01-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98018T	2015-01-21 12:01:06	\N
34453	1010	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	14037X	\N	\N
22418	573	2015-01-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98018T	2015-01-21 12:01:06	\N
22419	578	2015-01-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01016M	2015-01-21 12:01:25	\N
22512	578	2015-02-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14001X	2015-02-04 14:27:33	\N
22513	530	2015-01-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	96004D	2015-02-04 14:51:21	\N
22514	592	2015-02-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2015-02-04 15:15:36	\N
22515	582	2015-02-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2015-02-04 15:15:57	\N
22517	597	2015-02-02 00:00:00	2017-07-21 00:00:00	ANCIEN	\N	\N	\N	01007L	2015-02-04 16:20:18	2017-07-24 09:56:26
22518	530	2015-01-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92039X	2015-02-04 16:20:32	\N
22871	911	2014-10-01 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	01003G	\N	2017-05-16 15:18:14
22909	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14063N	\N	\N
22910	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14219Q	\N	\N
22911	586	2015-02-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11100Y	2015-02-19 15:20:50	\N
22928	919	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	\N	\N
22929	919	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11095V	\N	2017-09-24 13:25:54
22930	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
22931	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08015R	\N	\N
22933	909	2014-10-01 00:00:00	2016-11-30 00:00:00	ANCIEN	\N	\N	\N	04048J	\N	2016-12-01 10:36:51
22934	909	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11095V	\N	2017-09-24 13:25:54
22936	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
22938	909	2014-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	14209N	\N	2017-10-01 10:34:22
22939	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08061X	\N	\N
22940	909	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01061S	\N	2017-09-24 17:48:21
22941	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01024M	\N	\N
22942	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08053X	\N	\N
22943	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14249W	\N	\N
22944	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14257W	\N	\N
22947	640	2015-02-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	2015-02-20 10:18:28	\N
22948	640	2015-02-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95062K	2015-02-20 10:18:45	\N
22949	640	2015-02-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04088S	2015-02-20 10:18:52	\N
23266	911	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98050T	\N	\N
23412	628	2015-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01014K	2015-10-23 11:29:03	2017-09-24 17:19:42
23413	674	2015-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98053W	2015-10-29 14:32:51	\N
23417	616	2015-11-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14079W	2015-11-05 16:00:27	\N
23418	616	2015-11-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11064N	2015-11-05 16:01:00	\N
23439	628	2016-01-22 00:00:00	2016-03-11 00:00:00	ANCIEN	\N	\N	\N	11069T	2016-01-22 11:45:00	2016-03-11 18:02:51
21911	589	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11096W	2014-10-31 12:00:49	\N
21531	579	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04040A	2014-10-29 16:23:35	\N
21532	579	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04036E	2014-10-29 16:39:06	\N
21912	590	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11096W	2014-10-31 12:00:49	\N
21977	625	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	2014-10-31 16:32:11	\N
21978	598	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	2014-10-31 16:32:11	\N
21979	584	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	2014-10-31 16:32:11	\N
21980	663	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	2014-10-31 16:32:11	\N
21981	604	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	2014-10-31 16:32:11	\N
21982	643	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	2014-10-31 16:32:11	\N
21983	640	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	2014-10-31 16:32:11	\N
21984	583	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	2014-10-31 16:32:11	\N
21985	590	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	2014-10-31 16:32:11	\N
21986	579	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	2014-10-31 16:32:11	\N
22164	657	2014-11-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04040A	2014-11-07 14:31:19	2015-03-09 14:11:12
22165	673	2014-11-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04040A	2014-11-07 14:31:19	\N
22166	620	2014-11-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04040A	2014-11-07 14:31:19	\N
22221	642	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08060W	2014-11-14 10:37:18	\N
22222	651	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08060W	2014-11-14 10:37:18	\N
22223	622	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08060W	2014-11-14 10:37:18	\N
22269	963	2014-11-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14221J	2014-11-24 16:16:35	2015-03-04 10:25:54
22270	963	2014-11-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14223L	2014-11-24 16:16:52	\N
22271	529	2014-11-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11091R	2014-11-24 16:18:09	\N
22272	529	2014-11-20 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	2014-11-25 14:16:19	2017-10-01 09:41:22
22276	608	2014-11-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04042C	2014-11-26 15:16:37	\N
22277	641	2014-11-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14239U	2014-11-26 15:16:47	\N
22278	529	2014-11-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04044E	2014-11-26 15:17:07	\N
22377	608	2015-01-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14111D	2015-01-13 12:13:34	\N
22378	674	2015-01-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14111D	2015-01-13 12:13:34	\N
34454	1010	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	21036C	\N	\N
22379	532	2015-01-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14111D	2015-01-13 12:13:34	2015-03-10 17:27:27
22380	623	2015-01-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14111D	2015-01-13 12:13:34	\N
22474	605	2015-01-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95062K	2015-01-28 14:56:15	\N
22475	530	2015-01-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14030Q	2015-01-28 14:56:29	\N
22533	599	2015-02-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14121F	2015-02-11 15:37:50	2015-03-20 11:38:59
22534	532	2015-02-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08017T	2015-02-11 15:38:10	2015-03-10 17:27:20
22958	918	2014-10-01 00:00:00	2016-12-10 00:00:00	ANCIEN	\N	\N	\N	01037S	\N	2016-12-12 16:10:15
22959	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08038Y	\N	\N
22960	910	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	04077P	\N	2017-09-24 17:47:27
22966	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11067R	\N	\N
22970	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	87003B	\N	\N
22973	618	2015-02-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11090Q	2015-02-26 10:42:34	\N
22974	624	2015-02-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11090Q	2015-02-26 10:43:04	\N
23269	910	2015-04-01 00:00:00	2016-04-01 00:00:00	ANCIEN	\N	\N	\N	14263U	\N	\N
23270	910	2015-04-01 00:00:00	2015-05-01 00:00:00	ANCIEN	\N	\N	\N	11111C	\N	\N
23438	612	2015-12-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14187A	2015-12-17 09:33:54	\N
23764	919	2016-10-01 00:00:00	2016-11-01 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
23767	919	2016-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11081P	\N	\N
23784	919	2016-10-01 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	08065C	\N	2017-09-25 09:57:52
23785	919	2016-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14199E	\N	\N
23793	919	2016-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	\N
23796	919	2016-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08015R	\N	\N
23797	919	2016-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
23801	919	2016-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14221J	\N	\N
23803	919	2016-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
23816	CHRETORIENT	2016-11-21 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	14071N	2016-11-21 16:06:13	\N
23817	CHRETORIENT	2016-11-21 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	14193X	2016-11-21 16:06:34	\N
24094	629	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14089Y	2017-10-16 11:06:43	\N
24095	596	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14089Y	2017-10-16 11:06:43	\N
24096	616	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14089Y	2017-10-16 11:06:43	\N
24097	628	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14089Y	2017-10-16 11:06:43	\N
24098	643	2017-10-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14197C	2017-10-16 11:32:34	\N
24099	963	2017-10-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14197C	2017-10-16 11:32:34	\N
24100	CHRETORIENT	2017-10-16 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	14329V	2017-10-16 11:35:47	\N
24101	CHRETORIENT	2017-10-16 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	19663E	2017-10-16 11:38:09	\N
24102	CHRETORIENT	2017-10-13 00:00:00	2018-05-18 00:00:00	ANCIEN	\N	\N	\N	19697Q	2017-10-16 11:45:43	2018-06-11 17:35:24
24333	CHRETORIENT	2017-10-17 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	18083K	2017-10-18 17:43:40	\N
24334	622	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	18083K	2017-10-18 17:43:40	\N
24335	646	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	18083K	2017-10-18 17:43:40	\N
24336	576	2017-10-18 00:00:00	2018-07-27 00:00:00	ANCIEN	\N	\N	\N	19707Y	2017-10-18 17:44:23	\N
24337	641	2017-10-18 00:00:00	2018-07-27 00:00:00	ANCIEN	\N	\N	\N	19707Y	2017-10-18 17:44:23	\N
24338	595	2017-10-18 00:00:00	2018-07-27 00:00:00	ANCIEN	\N	\N	\N	19707Y	2017-10-18 17:44:23	\N
24339	590	2017-10-18 00:00:00	2018-07-27 00:00:00	ANCIEN	\N	\N	\N	19707Y	2017-10-18 17:44:23	\N
24340	576	2017-10-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19705W	2017-10-18 17:45:06	\N
24341	641	2017-10-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19705W	2017-10-18 17:45:06	\N
24342	595	2017-10-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19705W	2017-10-18 17:45:06	\N
24343	590	2017-10-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19705W	2017-10-18 17:45:06	\N
24344	634	2017-10-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14135M	2017-10-18 17:45:27	\N
24345	594	2017-10-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14135M	2017-10-18 17:45:27	\N
24346	621	2017-10-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14135M	2017-10-18 17:45:27	\N
24347	583	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14187A	2017-10-18 17:45:48	\N
24348	596	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14187A	2017-10-18 17:45:48	\N
24349	598	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14187A	2017-10-18 17:45:48	\N
24350	621	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14187A	2017-10-18 17:45:48	\N
24351	625	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14187A	2017-10-18 17:45:48	\N
24352	583	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14193X	2017-10-18 17:46:48	\N
24353	584	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14193X	2017-10-18 17:46:48	\N
24354	596	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14193X	2017-10-18 17:46:48	\N
22251	578	2014-11-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11025F	2014-11-19 17:25:50	2017-09-24 16:24:51
22252	851	2014-11-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04080J	2014-11-19 17:26:04	\N
22253	608	2014-11-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95067Q	2014-11-19 17:26:15	\N
22254	634	2014-11-07 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	08025T	2014-11-19 17:27:22	2017-10-01 10:17:18
22337	585	2014-12-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01031L	2014-12-15 15:28:35	2017-09-24 18:20:10
22338	591	2014-12-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01031L	2014-12-15 15:28:35	2017-09-24 18:20:10
22677	911	2014-10-01 00:00:00	2014-10-01 00:00:00	ANCIEN	\N	\N	\N	14053L	\N	\N
34455	1010	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	19707Y	\N	\N
22678	911	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14053L	\N	\N
22682	911	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11112D	\N	2017-09-24 16:45:26
22683	911	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08009T	\N	\N
22684	911	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	2017-09-24 13:44:49
22685	911	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	12042Y	\N	2017-09-24 19:31:54
22686	911	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
22687	911	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01022K	\N	2017-09-24 17:14:26
22688	911	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
22689	911	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04044E	\N	\N
22690	911	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08034U	\N	\N
22691	911	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
22692	911	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
22693	911	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11088W	\N	2017-09-24 17:15:15
22694	911	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14119M	\N	\N
22695	911	2014-10-01 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	14137P	\N	2015-06-12 15:59:18
22697	911	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11054L	\N	\N
22698	911	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	05008E	\N	\N
22700	922	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14030Q	\N	\N
22701	922	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14073Q	\N	\N
22702	922	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11085T	\N	\N
22703	922	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14089Y	\N	\N
22704	911	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
22705	911	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
22706	922	2014-10-01 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	2017-06-19 12:20:59
22707	911	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
22708	911	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14205J	\N	\N
22709	911	2014-10-01 00:00:00	2016-11-17 00:00:00	ANCIEN	\N	\N	\N	07032N	\N	2016-11-18 12:37:49
22710	911	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	92045V	\N	2017-09-24 17:29:37
22711	911	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11100Y	\N	2017-09-24 13:57:40
22712	911	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14173T	\N	\N
22713	906	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11068S	\N	2017-09-24 18:05:41
22714	906	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01016M	\N	2017-09-24 17:09:24
22716	906	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14038Y	\N	\N
22717	906	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14071N	\N	\N
22718	906	2014-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	98021N	\N	2017-10-01 09:22:38
22719	906	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
22720	906	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
22723	906	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
22724	906	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	80013X	\N	\N
22725	906	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14199E	\N	\N
22726	906	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14259Y	\N	\N
22727	906	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
22737	957	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11068S	\N	2017-09-24 18:05:41
22738	957	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01016M	\N	2017-09-24 17:09:24
22739	957	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	\N	\N
22748	1003	2015-01-28 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	98046X	\N	2017-09-25 09:56:00
23391	586	2015-09-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08009T	2015-09-17 15:25:26	\N
23604	919	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95037J	\N	\N
23865	576	2017-10-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14249W	2017-10-09 09:54:07	\N
23866	582	2017-10-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14249W	2017-10-09 09:54:07	\N
23867	598	2017-10-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14249W	2017-10-09 09:54:08	\N
23868	592	2017-10-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14249W	2017-10-09 09:54:08	\N
23869	617	2017-10-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14249W	2017-10-09 09:54:08	\N
23870	605	2017-10-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08010L	2017-10-09 09:55:18	\N
24017	598	2017-10-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08010L	2017-10-12 09:47:44	\N
24018	590	2017-10-03 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08010L	2017-10-12 09:48:17	\N
24086	629	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04042C	2017-10-13 11:05:09	\N
24087	598	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04042C	2017-10-13 11:05:09	\N
24088	608	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04042C	2017-10-13 11:05:09	\N
24445	CHRETORIENT	2017-10-20 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	19573D	2017-10-20 15:31:21	\N
24615	618	2017-10-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14261S	2017-10-25 17:07:21	\N
24616	634	2017-10-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14261S	2017-10-25 17:07:21	\N
24617	598	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11053K	2017-10-25 17:07:38	\N
24618	589	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11053K	2017-10-25 17:07:38	\N
24619	608	2017-10-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11053K	2017-10-25 17:07:38	\N
24620	610	2017-10-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14151M	2017-10-25 17:08:22	\N
24621	584	2017-10-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14151M	2017-10-25 17:08:22	\N
24622	574	2017-10-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14151M	2017-10-25 17:08:22	\N
24623	609	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14151M	2017-10-25 17:09:04	\N
24643	590	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	2017-10-26 09:38:17	\N
24644	534	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	2017-10-26 09:38:17	\N
24645	610	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	2017-10-26 09:38:17	\N
24646	572	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	2017-10-26 09:38:17	\N
24647	584	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	2017-10-26 09:38:17	\N
24648	616	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	2017-10-26 09:38:17	\N
24649	622	2017-10-26 00:00:00	2019-03-08 00:00:00	ANCIEN	\N	\N	\N	04040A	2017-10-26 09:38:17	\N
24650	661	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	2017-10-26 09:38:17	\N
24651	573	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	2017-10-26 09:38:17	\N
24652	604	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	2017-10-26 09:38:17	\N
24653	621	2017-10-26 00:00:00	2019-03-08 00:00:00	ANCIEN	\N	\N	\N	04040A	2017-10-26 09:38:17	\N
24654	673	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	2017-10-26 09:38:17	\N
24655	586	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	2017-10-26 09:38:17	\N
24656	629	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	2017-10-26 09:38:17	\N
24657	623	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	2017-10-26 09:38:17	\N
22076	621	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	12042Y	2014-11-04 14:30:53	\N
22077	604	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	12042Y	2014-11-04 14:30:53	\N
22078	595	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	08042U	2014-11-04 14:31:17	2017-10-01 10:20:50
22079	629	2014-10-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	08042U	2014-11-04 14:31:18	2017-10-01 10:20:50
22080	642	2014-11-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08019V	2014-11-04 14:31:50	\N
22081	602	2014-11-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08019V	2014-11-04 14:31:50	\N
22082	583	2014-11-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08019V	2014-11-04 14:31:50	\N
22083	581	2014-11-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	02002K	2014-11-04 14:32:10	\N
22084	608	2014-11-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	02002K	2014-11-04 14:32:10	\N
22085	594	2014-11-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	02002K	2014-11-04 14:32:10	\N
22086	641	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11033F	2014-11-04 14:32:35	\N
22087	632	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11033F	2014-11-04 14:32:35	\N
22088	595	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11033F	2014-11-04 14:32:35	2016-03-16 16:02:09
22089	979	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11033F	2014-11-04 14:32:35	\N
22090	624	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11033F	2014-11-04 14:32:35	\N
22091	577	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11033F	2014-11-04 14:32:35	\N
22092	620	2014-11-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14034U	2014-11-04 14:32:54	\N
22093	622	2014-11-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14034U	2014-11-04 14:32:54	\N
22094	595	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11011M	2014-11-04 14:33:22	\N
22095	651	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11011M	2014-11-04 14:33:22	\N
22096	629	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11011M	2014-11-04 14:33:22	\N
22382	556	2015-01-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04080J	2015-01-14 10:01:20	\N
22393	604	2015-01-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04061F	2015-01-15 11:45:16	\N
22445	615	2015-01-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14249W	2015-01-23 16:05:51	\N
22446	582	2015-01-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	2015-01-23 16:06:09	\N
22679	911	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04033B	\N	\N
22680	911	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11081P	\N	\N
22681	911	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	2017-09-24 17:04:02
23596	594	2016-02-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92045V	2016-02-18 14:06:20	2017-09-24 17:29:37
22715	906	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01058X	\N	\N
22721	906	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11094U	\N	2017-09-24 13:25:54
22722	906	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01011G	\N	2017-09-24 16:43:43
22728	906	2014-10-01 00:00:00	2014-10-01 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
22729	906	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	\N	\N
22730	906	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
22731	906	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98050T	\N	\N
22733	906	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	92045V	\N	2017-09-24 17:29:37
22734	906	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11100Y	\N	2017-09-24 13:57:40
22735	906	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14079W	\N	\N
22736	906	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	04054G	\N	2017-09-24 17:18:03
22740	957	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
22741	957	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14061L	\N	\N
22742	957	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
22932	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11012A	\N	\N
22937	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08021P	\N	\N
22951	599	2015-02-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01008M	2015-02-20 12:19:02	\N
23173	991	2014-09-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	2015-03-30 16:22:18	\N
23174	991	2014-09-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11089X	2015-03-30 16:22:45	2017-09-24 17:15:15
23175	934	2014-09-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14123H	2015-03-30 16:25:13	\N
23250	644	2015-04-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04074L	2015-04-30 14:08:03	2017-09-24 17:15:15
23597	581	2016-03-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14147R	2016-03-04 14:59:32	\N
23713	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	\N
23821	618	2016-07-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14059S	2016-12-01 12:41:37	\N
24173	651	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14001X	2017-10-17 11:28:37	\N
24174	591	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14001X	2017-10-17 11:28:37	\N
24175	629	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	2017-10-17 11:30:25	\N
24176	590	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	2017-10-17 11:30:25	\N
24177	674	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	2017-10-17 11:30:25	\N
24178	604	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	2017-10-17 11:30:25	\N
24179	611	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	2017-10-17 11:30:25	\N
24180	599	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	2017-10-17 11:30:25	\N
24181	625	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	2017-10-17 11:30:25	\N
24182	529	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	2017-10-17 11:30:25	\N
24183	581	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	2017-10-17 11:30:25	\N
24184	640	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	2017-10-17 11:30:25	\N
24185	532	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	2017-10-17 11:30:25	\N
24186	573	2017-10-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14119M	2017-10-17 11:30:51	\N
24187	600	2017-10-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14119M	2017-10-17 11:30:51	\N
24188	584	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08047A	2017-10-17 11:31:36	\N
24189	590	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08047A	2017-10-17 11:31:36	\N
24190	608	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08047A	2017-10-17 11:31:36	\N
24191	581	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08047A	2017-10-17 11:31:36	\N
24192	648	2017-10-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14227Q	2017-10-17 11:32:04	\N
24193	598	2017-10-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14227Q	2017-10-17 11:32:04	\N
24194	651	2017-10-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14227Q	2017-10-17 11:32:04	\N
24195	663	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01034P	2017-10-17 11:32:32	\N
24196	584	2017-10-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04034C	2017-10-17 11:34:29	\N
24197	623	2017-10-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04034C	2017-10-17 11:34:29	\N
24198	581	2017-10-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04034C	2017-10-17 11:34:29	\N
24199	622	2017-10-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04034C	2017-10-17 11:34:29	\N
24204	578	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	2017-10-17 12:19:06	\N
24205	608	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	2017-10-17 12:19:06	\N
24206	590	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	2017-10-17 12:19:06	\N
24207	575	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	2017-10-17 12:19:06	\N
24208	598	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	2017-10-17 12:19:06	\N
24209	620	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	2017-10-17 12:19:06	\N
24210	605	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	05012A	2017-10-17 15:10:18	\N
24211	578	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	05012A	2017-10-17 15:10:19	\N
22476	601	2015-01-28 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	14263U	2015-01-28 17:27:17	2017-06-19 16:04:13
22606	913	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08039A	\N	\N
22617	912	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	12042Y	\N	2017-09-24 19:31:54
22624	998	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14071N	\N	\N
22625	998	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11094U	\N	2017-09-24 13:25:54
22626	998	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
22627	998	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11109J	\N	\N
22628	998	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14227Q	\N	\N
22662	1003	2015-01-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
22924	919	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01024M	\N	\N
23108	948	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14197C	\N	\N
23128	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14107H	\N	\N
23129	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14133K	\N	\N
23130	912	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14133K	\N	\N
23131	912	2014-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	08042U	\N	2017-10-01 10:20:50
23133	913	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14237S	\N	\N
23134	913	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14193X	\N	\N
23135	913	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11046L	\N	2017-09-24 17:29:37
23136	913	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01058X	\N	\N
23137	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
23138	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
23140	919	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14121F	\N	\N
23141	919	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08016S	\N	\N
23143	911	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14157T	\N	\N
23146	911	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14107H	\N	\N
23147	906	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08016S	\N	\N
23148	957	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08016S	\N	\N
23149	957	2014-10-01 00:00:00	2016-01-11 00:00:00	ANCIEN	\N	\N	\N	11060J	\N	2016-01-11 17:34:09
23150	1003	2015-01-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08016S	\N	\N
23454	CHRETORIENT	2015-06-04 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	04033B	2016-02-11 18:02:43	2016-02-12 11:47:35
23376	529	2015-06-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14059S	2015-07-16 10:33:45	\N
23714	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11097X	\N	\N
23715	1005	2016-06-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14213J	\N	\N
23717	623	2016-06-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08015R	2016-06-29 10:11:46	2017-10-10 11:04:14
23724	1005	2016-06-15 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11107G	\N	2017-09-24 17:06:55
23777	919	2016-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04038G	\N	\N
23788	919	2016-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08041T	\N	\N
23795	919	2016-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14159V	\N	\N
23813	617	2016-11-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14089Y	2016-11-09 11:54:24	\N
23831	906	2017-01-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14357A	\N	\N
23832	919	2017-01-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14357A	\N	\N
23871	581	2017-10-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14331P	2017-10-09 10:42:53	\N
23885	628	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14229S	2017-10-10 11:06:29	2017-10-10 12:39:42
23886	618	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14229S	2017-10-10 11:06:29	2017-10-10 12:39:42
23887	620	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14229S	2017-10-10 11:06:29	2017-10-10 12:39:42
23888	598	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14229S	2017-10-10 11:06:29	2017-10-10 12:39:42
23932	573	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14071N	2017-10-11 10:22:19	2017-12-01 17:44:34
23933	612	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14071N	2017-10-11 10:22:19	\N
23934	596	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14071N	2017-10-11 10:22:19	\N
23935	604	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14105F	2017-10-11 10:24:07	\N
23936	578	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14105F	2017-10-11 10:24:08	\N
23937	596	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14105F	2017-10-11 10:24:08	\N
23938	618	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14059S	2017-10-11 10:25:00	\N
23939	622	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14059S	2017-10-11 10:25:00	\N
23940	625	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14059S	2017-10-11 10:25:00	\N
23941	640	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14059S	2017-10-11 10:25:00	\N
23942	532	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14221J	2017-10-11 10:27:03	\N
23943	594	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14221J	2017-10-11 10:27:03	\N
23944	603	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14221J	2017-10-11 10:27:03	\N
23945	963	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14221J	2017-10-11 10:27:04	\N
23946	626	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14221J	2017-10-11 10:27:04	\N
23947	595	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14221J	2017-10-11 10:27:04	\N
23948	530	2017-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14221J	2017-10-11 10:27:04	\N
23949	621	2017-10-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14063N	2017-10-11 10:27:57	\N
23950	616	2017-10-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14063N	2017-10-11 10:27:57	\N
23951	640	2017-10-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14063N	2017-10-11 10:27:57	\N
24024	608	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	98022P	2017-10-12 10:12:57	\N
24025	642	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	98022P	2017-10-12 10:12:57	\N
24026	598	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	98022P	2017-10-12 10:12:57	\N
24027	661	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	98022P	2017-10-12 10:12:57	\N
24028	596	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	98022P	2017-10-12 10:12:57	\N
24029	629	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	98022P	2017-10-12 10:12:57	\N
24030	608	2017-10-11 00:00:00	2017-10-16 00:00:00	ANCIEN	\N	\N	\N	14195A	2017-10-12 10:13:24	2017-10-18 16:05:47
24031	589	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14195A	2017-10-12 10:13:24	\N
24032	534	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	07004J	2017-10-12 10:14:00	\N
24033	595	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	07004J	2017-10-12 10:14:00	\N
24034	979	2017-10-11 00:00:00	2018-01-29 00:00:00	ANCIEN	\N	\N	\N	07004J	2017-10-12 10:14:00	2018-01-30 09:25:46
24035	661	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	07004J	2017-10-12 10:14:00	\N
24036	556	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	07004J	2017-10-12 10:14:00	\N
24037	578	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	07004J	2017-10-12 10:14:00	\N
24038	625	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	05008E	2017-10-12 10:14:28	\N
24039	646	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	05008E	2017-10-12 10:14:28	\N
24040	584	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	05008E	2017-10-12 10:14:28	\N
24041	573	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	05008E	2017-10-12 10:14:28	\N
24042	629	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	05008E	2017-10-12 10:14:28	\N
24043	599	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08012N	2017-10-12 10:15:28	\N
24044	602	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08012N	2017-10-12 10:15:28	\N
24045	653	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08012N	2017-10-12 10:15:28	\N
24046	978	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08012N	2017-10-12 10:15:28	\N
24047	647	2017-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08012N	2017-10-12 10:15:28	\N
24355	978	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14193X	2017-10-18 17:46:48	\N
20816	598	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14205J	2014-10-23 10:21:39	\N
20817	604	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14205J	2014-10-23 10:21:39	\N
20818	646	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04040A	2014-10-23 10:25:42	\N
20819	534	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04040A	2014-10-23 10:25:42	\N
20820	588	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04040A	2014-10-23 10:25:42	\N
20821	574	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04040A	2014-10-23 10:25:42	\N
20822	661	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04040A	2014-10-23 10:25:42	\N
20823	590	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04040A	2014-10-23 10:25:42	\N
20824	573	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04040A	2014-10-23 10:25:42	\N
20825	604	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04040A	2014-10-23 10:25:42	\N
20826	628	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04040A	2014-10-23 10:25:42	\N
20827	572	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04040A	2014-10-23 10:25:42	\N
20828	584	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04040A	2014-10-23 10:25:42	\N
20829	629	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04040A	2014-10-23 10:25:42	\N
20830	610	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04040A	2014-10-23 10:25:42	\N
20831	622	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04040A	2014-10-23 10:25:42	\N
20832	596	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04040A	2014-10-23 10:25:42	\N
20833	624	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04040A	2014-10-23 10:25:42	\N
20834	556	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04040A	2014-10-23 10:25:42	\N
20835	595	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04040A	2014-10-23 10:25:42	\N
20836	623	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04040A	2014-10-23 10:25:42	2015-03-06 09:53:15
20837	641	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14087W	2014-10-23 11:03:01	\N
20838	576	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11109J	2014-10-23 11:10:08	\N
20839	642	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11109J	2014-10-23 11:10:08	\N
20840	651	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11109J	2014-10-23 11:10:08	\N
20841	634	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11109J	2014-10-23 11:10:09	\N
20842	578	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11036J	2014-10-23 11:18:56	2017-09-24 18:16:52
20843	978	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11036J	2014-10-23 11:18:56	2017-09-24 18:16:52
20844	589	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11036J	2014-10-23 11:18:56	\N
20845	608	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11036J	2014-10-23 11:18:56	\N
20846	651	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11036J	2014-10-23 11:18:56	\N
20847	621	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11030C	2014-10-23 11:20:16	\N
20848	604	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11030C	2014-10-23 11:20:16	\N
20849	581	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11030C	2014-10-23 11:20:16	\N
20850	590	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11030C	2014-10-23 11:20:16	\N
20851	599	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11030C	2014-10-23 11:20:16	\N
20852	596	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11030C	2014-10-23 11:20:16	\N
20853	584	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11030C	2014-10-23 11:20:16	\N
20854	625	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11030C	2014-10-23 11:20:16	\N
20855	573	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11030C	2014-10-23 11:20:16	\N
20856	629	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11030C	2014-10-23 11:20:16	\N
20857	604	2014-10-22 00:00:00	2017-07-03 00:00:00	ANCIEN	\N	\N	\N	01044R	2014-10-23 11:21:12	2017-07-04 15:08:09
20858	622	2014-10-22 00:00:00	2017-07-03 00:00:00	ANCIEN	\N	\N	\N	01044R	2014-10-23 11:21:12	2017-07-04 15:08:09
20859	979	2014-10-22 00:00:00	2017-07-03 00:00:00	ANCIEN	\N	\N	\N	01044R	2014-10-23 11:21:12	2017-07-04 15:08:09
20860	573	2014-10-22 00:00:00	2017-07-03 00:00:00	ANCIEN	\N	\N	\N	01044R	2014-10-23 11:21:12	2017-07-04 15:08:09
20861	634	2014-10-22 00:00:00	2017-07-03 00:00:00	ANCIEN	\N	\N	\N	01044R	2014-10-23 11:21:12	2017-07-04 15:08:09
20862	626	2014-10-22 00:00:00	2017-07-03 00:00:00	ANCIEN	\N	\N	\N	01044R	2014-10-23 11:21:12	2017-07-04 15:08:09
20863	621	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04066L	2014-10-23 11:22:53	\N
20864	597	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04066L	2014-10-23 11:22:53	\N
20865	620	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04066L	2014-10-23 11:22:53	\N
20866	598	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04066L	2014-10-23 11:22:53	\N
20867	575	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04066L	2014-10-23 11:22:53	\N
20868	621	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04038G	2014-10-23 11:23:44	\N
20869	602	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04038G	2014-10-23 11:23:44	\N
20870	583	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04038G	2014-10-23 11:23:44	\N
20871	608	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04038G	2014-10-23 11:23:44	\N
20872	577	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04038G	2014-10-23 11:23:45	\N
20873	588	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04038G	2014-10-23 11:23:46	\N
20874	601	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04038G	2014-10-23 11:23:46	\N
20875	647	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08052W	2014-10-23 11:24:12	\N
20876	604	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08052W	2014-10-23 11:24:12	\N
20877	597	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08052W	2014-10-23 11:24:12	\N
20878	595	2014-10-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11035H	2014-10-23 11:25:47	\N
20879	622	2014-10-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11035H	2014-10-23 11:25:47	2017-09-24 18:16:52
20880	576	2014-10-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11035H	2014-10-23 11:25:47	\N
20881	573	2014-10-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11035H	2014-10-23 11:25:47	\N
20882	632	2014-10-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11035H	2014-10-23 11:25:47	\N
20883	580	2014-10-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11035H	2014-10-23 11:25:47	2017-09-24 18:16:52
34456	1010	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	19507S	\N	\N
20884	598	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92020L	2014-10-23 11:31:42	\N
20885	584	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92020L	2014-10-23 11:31:42	\N
20886	659	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92020L	2014-10-23 11:31:42	\N
20887	588	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92020L	2014-10-23 11:31:42	\N
20888	595	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92020L	2014-10-23 11:31:42	\N
20889	643	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92020L	2014-10-23 11:31:42	\N
20890	620	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92020L	2014-10-23 11:31:42	\N
20891	628	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92020L	2014-10-23 11:31:42	2017-09-24 12:39:59
20892	851	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92020L	2014-10-23 11:31:42	\N
20893	624	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92020L	2014-10-23 11:31:42	\N
20894	642	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92020L	2014-10-23 11:31:42	\N
20895	608	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92020L	2014-10-23 11:31:42	\N
20896	575	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92020L	2014-10-23 11:31:42	\N
20897	632	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92020L	2014-10-23 11:31:42	\N
20898	583	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11089X	2014-10-23 11:38:53	\N
20899	598	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11089X	2014-10-23 11:38:53	\N
20900	596	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11089X	2014-10-23 11:38:53	\N
20901	625	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11089X	2014-10-23 11:38:53	\N
20902	556	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11089X	2014-10-23 11:38:53	\N
20391	629	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08034U	2014-10-16 09:40:38	\N
20392	641	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04086Q	2014-10-16 09:41:01	\N
20393	581	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04086Q	2014-10-16 09:41:01	\N
20394	601	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04086Q	2014-10-16 09:41:01	\N
20395	595	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04086Q	2014-10-16 09:41:01	\N
20396	589	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04086Q	2014-10-16 09:41:01	\N
20397	534	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04086Q	2014-10-16 09:41:01	\N
20398	571	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	97011G	2014-10-16 09:41:29	\N
20399	629	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	97011G	2014-10-16 09:41:29	\N
20400	597	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	97011G	2014-10-16 09:41:29	\N
20401	605	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	97011G	2014-10-16 09:41:29	\N
20402	580	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	97011G	2014-10-16 09:41:29	\N
20403	634	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	97011G	2014-10-16 09:41:29	\N
20404	632	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	97011G	2014-10-16 09:41:29	\N
20405	602	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	97011G	2014-10-16 09:41:29	\N
20406	591	2014-10-15 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	95020Y	2014-10-16 09:42:58	2015-06-12 16:01:25
20407	585	2014-10-15 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	95020Y	2014-10-16 09:42:58	2015-06-12 16:01:25
20408	597	2014-10-15 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	95020Y	2014-10-16 09:42:58	2015-06-12 16:01:25
20409	624	2014-10-15 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	95020Y	2014-10-16 09:42:58	2015-06-12 16:01:25
20410	647	2014-10-15 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	95020Y	2014-10-16 09:42:58	2015-06-12 16:01:25
20411	661	2014-10-15 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	95020Y	2014-10-16 09:42:58	2015-06-12 16:01:25
20412	618	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11057P	2014-10-16 09:43:15	\N
20413	576	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11057P	2014-10-16 09:43:15	\N
20414	628	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	2014-10-16 09:44:43	2017-10-10 09:45:39
20415	572	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	11026G	2014-10-16 09:44:43	2017-10-10 09:45:39
20416	659	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	11026G	2014-10-16 09:44:43	2017-10-10 09:45:39
20417	575	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	2014-10-16 09:44:43	\N
20418	584	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	11026G	2014-10-16 09:44:43	2017-10-10 09:45:39
20419	600	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	2014-10-16 09:44:43	\N
20420	595	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	11026G	2014-10-16 09:44:43	2017-10-10 09:45:39
20421	647	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	2014-10-16 09:44:43	\N
20422	608	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	11026G	2014-10-16 09:44:43	2017-10-10 09:45:39
20423	641	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	2014-10-16 09:44:43	\N
20424	556	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	11026G	2014-10-16 09:44:43	2017-10-10 09:45:39
20425	571	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	11026G	2014-10-16 09:44:43	2017-10-10 09:45:39
20426	530	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	11026G	2014-10-16 09:44:43	2017-10-10 09:45:39
20427	618	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	2014-10-16 09:44:43	\N
20428	624	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	2014-10-16 09:44:43	\N
20429	573	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	11026G	2014-10-16 09:44:43	2017-10-10 09:45:39
20430	605	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	11026G	2014-10-16 09:44:43	2017-10-10 09:45:39
20431	617	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	11026G	2014-10-16 09:44:43	2017-10-10 09:45:39
20432	576	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	11026G	2014-10-16 09:44:43	2017-10-10 09:45:39
20433	598	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	11026G	2014-10-16 09:44:43	2017-10-10 09:45:39
20434	674	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	2014-10-16 09:44:43	\N
20435	582	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	11026G	2014-10-16 09:44:43	2017-10-10 09:45:39
20436	653	2014-10-14 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	11026G	2014-10-16 09:44:43	2017-10-10 09:45:39
20437	621	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11099A	2014-10-16 09:45:40	\N
20438	573	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11099A	2014-10-16 09:45:40	\N
20439	634	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11099A	2014-10-16 09:45:40	\N
20440	979	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11099A	2014-10-16 09:45:40	\N
20441	576	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14039A	2014-10-16 09:45:56	\N
20442	605	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01022K	2014-10-16 09:47:37	\N
20443	573	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01022K	2014-10-16 09:47:37	\N
20444	598	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01022K	2014-10-16 09:47:37	\N
20445	602	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01022K	2014-10-16 09:47:37	\N
20446	627	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	07004J	2014-10-16 09:48:18	\N
20447	628	2014-10-14 00:00:00	2014-11-11 00:00:00	ANCIEN	\N	\N	\N	07004J	2014-10-16 09:48:18	2014-11-13 09:30:36
20448	556	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	07004J	2014-10-16 09:48:18	\N
20449	615	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	07004J	2014-10-16 09:48:18	2015-11-12 15:26:22
20450	661	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	07004J	2014-10-16 09:48:18	\N
20451	534	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	07004J	2014-10-16 09:48:18	\N
20452	594	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11059R	2014-10-16 09:48:52	\N
20453	580	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11059R	2014-10-16 09:48:52	\N
20454	601	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11059R	2014-10-16 09:48:52	\N
20455	600	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11059R	2014-10-16 09:48:52	\N
20456	572	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11106F	2014-10-16 09:49:33	\N
20457	574	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11106F	2014-10-16 09:49:33	\N
20458	588	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11106F	2014-10-16 09:49:33	\N
20459	601	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11106F	2014-10-16 09:49:33	2017-09-24 19:14:37
20460	575	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11106F	2014-10-16 09:49:33	\N
20461	583	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11106F	2014-10-16 09:49:33	\N
20462	595	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11106F	2014-10-16 09:49:33	\N
20463	602	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11106F	2014-10-16 09:49:33	\N
20464	573	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11106F	2014-10-16 09:49:34	\N
20465	590	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11106F	2014-10-16 09:49:34	\N
20466	624	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11106F	2014-10-16 09:49:34	\N
20467	646	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11106F	2014-10-16 09:49:34	\N
20468	576	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11106F	2014-10-16 09:49:34	\N
20469	589	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11106F	2014-10-16 09:49:34	\N
20470	594	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	2014-10-16 09:53:42	\N
20471	629	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	2014-10-16 09:53:42	\N
20472	597	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	2014-10-16 09:53:42	\N
20473	573	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	2014-10-16 09:53:42	\N
20474	978	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	2014-10-16 09:53:42	\N
20475	617	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	2014-10-16 09:53:42	\N
20476	603	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	2014-10-16 09:53:42	\N
20477	584	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	2014-10-16 09:53:43	\N
20534	588	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04034C	2014-10-20 09:50:28	\N
20535	573	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04034C	2014-10-20 09:50:28	\N
20536	572	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04034C	2014-10-20 09:50:28	\N
20537	646	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04034C	2014-10-20 09:50:28	\N
20538	590	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01019Q	2014-10-20 09:51:29	\N
20539	618	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01019Q	2014-10-20 09:51:29	\N
20540	641	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01019Q	2014-10-20 09:51:29	\N
20541	609	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01019Q	2014-10-20 09:51:29	\N
20542	979	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01019Q	2014-10-20 09:51:29	2017-09-24 17:35:15
20543	617	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01019Q	2014-10-20 09:51:29	\N
20544	576	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01019Q	2014-10-20 09:51:29	\N
20545	642	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01019Q	2014-10-20 09:51:30	2017-09-24 17:35:15
20546	578	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01019Q	2014-10-20 09:51:30	2017-09-24 17:35:15
20547	583	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01019Q	2014-10-20 09:51:30	\N
20548	643	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01019Q	2014-10-20 09:51:30	\N
20549	584	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01019Q	2014-10-20 09:51:30	\N
20550	611	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01019Q	2014-10-20 09:51:30	\N
20551	979	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08024S	2014-10-20 09:52:08	\N
20552	625	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08024S	2014-10-20 09:52:08	\N
20553	619	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08024S	2014-10-20 09:52:08	2015-03-16 18:43:52
20554	978	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08024S	2014-10-20 09:52:08	\N
20555	621	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11014C	2014-10-20 09:52:24	\N
20556	979	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11014C	2014-10-20 09:52:24	\N
20557	576	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11014C	2014-10-20 09:52:24	\N
21140	621	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08068F	2014-10-24 12:44:33	\N
21141	602	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08068F	2014-10-24 12:44:33	\N
21142	610	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08068F	2014-10-24 12:44:33	2015-08-31 09:59:18
21143	590	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2014-10-24 12:53:46	\N
21144	610	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2014-10-24 12:53:46	2015-08-31 09:33:49
21145	628	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2014-10-24 12:53:46	\N
21146	626	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2014-10-24 12:53:46	\N
21147	618	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2014-10-24 12:53:46	\N
21148	597	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2014-10-24 12:53:46	\N
21149	584	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2014-10-24 12:53:46	\N
21150	623	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2014-10-24 12:53:46	2015-03-06 09:53:30
21151	633	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2014-10-24 12:53:46	2015-05-27 16:38:47
21152	576	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2014-10-24 12:53:46	\N
21153	651	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2014-10-24 12:53:46	\N
21154	583	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2014-10-24 12:53:46	\N
21155	659	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2014-10-24 12:53:46	\N
21156	661	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2014-10-24 12:53:46	\N
21157	978	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2014-10-24 12:53:46	\N
21158	608	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2014-10-24 12:53:46	\N
21159	653	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2014-10-24 12:53:46	\N
21160	556	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2014-10-24 12:53:46	\N
21161	622	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2014-10-24 12:53:46	\N
21162	643	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2014-10-24 12:53:46	\N
21163	609	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2014-10-24 12:53:46	\N
21164	624	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2014-10-24 12:53:46	\N
21165	605	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2014-10-24 12:53:46	\N
21166	550	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2014-10-24 12:53:46	\N
21167	534	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2014-10-24 12:53:46	\N
21168	642	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2014-10-24 12:53:46	\N
21169	632	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2014-10-24 12:53:46	\N
21170	574	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11064N	2014-10-24 12:54:38	\N
21171	605	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11064N	2014-10-24 12:54:38	\N
21172	625	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11064N	2014-10-24 12:54:38	\N
21173	592	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11064N	2014-10-24 12:54:38	2015-07-09 15:11:15
21174	608	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11064N	2014-10-24 12:54:38	\N
21175	642	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11064N	2014-10-24 12:54:38	\N
21176	573	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11064N	2014-10-24 12:54:38	\N
22256	646	2014-11-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01056V	2014-11-20 09:45:04	\N
22257	529	2014-11-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01056V	2014-11-20 09:45:04	\N
22329	851	2014-12-09 00:00:00	2017-10-05 00:00:00	ANCIEN	\N	\N	\N	08010L	2014-12-10 14:31:39	2017-10-09 09:55:18
22330	571	2014-12-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95063L	2014-12-11 09:28:27	\N
22331	586	2014-12-09 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08012N	2014-12-11 09:28:39	\N
22648	948	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14169X	\N	\N
22649	948	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08024S	\N	\N
22650	948	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	2017-09-24 13:44:49
22651	948	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	12042Y	\N	2017-09-24 19:31:54
22968	907	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14225N	\N	\N
22982	918	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14107H	\N	\N
22983	918	2014-10-01 00:00:00	2014-10-01 00:00:00	ANCIEN	\N	\N	\N	08031R	\N	\N
22985	908	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01022K	\N	2017-09-24 17:14:26
22990	908	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14053L	\N	\N
23184	919	2014-10-01 00:00:00	2014-11-01 00:00:00	ANCIEN	\N	\N	\N	11055M	\N	\N
23185	919	2014-10-01 00:00:00	2014-11-01 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
23296	623	2015-06-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14225N	2015-06-30 16:28:32	\N
23332	933	2015-01-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14133K	\N	\N
23333	933	2015-01-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	\N
23334	933	2015-01-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11068S	\N	\N
23336	933	2015-01-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
23337	933	2015-01-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
23338	933	2015-01-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	08060W	\N	\N
23339	933	2015-01-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14083S	\N	\N
23340	933	2015-01-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11053K	\N	\N
23341	933	2015-01-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	98029W	\N	\N
23343	933	2015-01-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11042G	\N	\N
23344	933	2015-01-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
23345	933	2015-01-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11027H	\N	\N
23346	933	2015-01-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	08038Y	\N	\N
20241	572	2014-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11063M	2014-05-13 10:01:24	\N
20242	584	2014-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	05008E	2014-05-13 10:02:29	\N
20610	575	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08035V	2014-10-22 10:15:43	\N
20611	616	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95035G	2014-10-22 10:36:50	\N
20612	604	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95035G	2014-10-22 10:36:50	\N
20613	602	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95035G	2014-10-22 10:36:50	\N
20614	589	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95035G	2014-10-22 10:36:50	\N
20615	534	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95035G	2014-10-22 10:36:50	\N
20616	598	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95035G	2014-10-22 10:36:50	\N
20617	590	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04044E	2014-10-22 10:41:16	\N
20618	629	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04044E	2014-10-22 10:41:16	\N
20619	579	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04044E	2014-10-22 10:41:16	\N
20620	604	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04044E	2014-10-22 10:41:16	\N
20621	608	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04044E	2014-10-22 10:41:16	\N
20622	610	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04044E	2014-10-22 10:41:16	2015-08-31 09:34:50
20623	575	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	2014-10-22 10:46:39	\N
20624	590	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	2014-10-22 10:46:39	\N
20625	620	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	2014-10-22 10:46:39	\N
20626	588	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	2014-10-22 10:46:39	\N
20627	629	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	2014-10-22 10:46:39	\N
20628	582	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	2014-10-22 10:46:39	\N
20629	608	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	2014-10-22 10:46:39	\N
20630	610	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	2014-10-22 10:46:39	\N
20631	632	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	2014-10-22 10:46:39	\N
20632	595	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	2014-10-22 10:46:39	\N
20633	602	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	2014-10-22 10:46:39	\N
20634	613	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	2014-10-22 10:46:39	\N
20635	604	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	2014-10-22 10:46:39	\N
20636	597	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	2014-10-22 10:46:39	\N
20637	573	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	2014-10-22 10:46:39	\N
20638	621	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	2014-10-22 10:46:39	\N
20639	624	2014-10-21 00:00:00	2017-07-20 00:00:00	ANCIEN	\N	\N	\N	14179A	2014-10-22 10:46:39	2017-07-20 18:35:52
20640	598	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	2014-10-22 10:46:39	\N
20641	594	2014-10-15 00:00:00	2017-07-21 00:00:00	ANCIEN	\N	\N	\N	01007L	2014-10-22 10:47:14	2017-07-24 09:56:26
20642	978	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14193X	2014-10-22 10:47:32	\N
20643	596	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14193X	2014-10-22 10:47:32	\N
20644	610	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14193X	2014-10-22 10:47:32	\N
20645	625	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14071N	2014-10-22 10:48:27	\N
20646	629	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14071N	2014-10-22 10:48:27	\N
20647	596	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14071N	2014-10-22 10:48:27	\N
20648	622	2014-10-17 00:00:00	2015-02-18 00:00:00	ANCIEN	\N	\N	\N	14071N	2014-10-22 10:48:27	2015-03-03 14:02:40
20649	584	2014-10-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14071N	2014-10-22 10:48:27	\N
20650	576	2014-10-14 00:00:00	2016-12-31 00:00:00	ANCIEN	\N	\N	\N	07024N	2014-10-22 10:49:21	2017-01-03 11:09:24
20651	590	2014-10-14 00:00:00	2016-12-31 00:00:00	ANCIEN	\N	\N	\N	07024N	2014-10-22 10:49:21	2017-01-03 11:09:24
20652	615	2014-10-14 00:00:00	2016-12-31 00:00:00	ANCIEN	\N	\N	\N	07024N	2014-10-22 10:49:21	2017-01-03 11:09:24
20653	663	2014-10-14 00:00:00	2016-12-31 00:00:00	ANCIEN	\N	\N	\N	07024N	2014-10-22 10:49:21	2017-01-03 11:09:24
20654	578	2014-10-14 00:00:00	2016-12-31 00:00:00	ANCIEN	\N	\N	\N	07024N	2014-10-22 10:49:21	2017-01-03 11:09:24
20655	653	2014-10-14 00:00:00	2016-12-31 00:00:00	ANCIEN	\N	\N	\N	07024N	2014-10-22 10:49:21	2017-01-03 11:09:24
20656	595	2014-10-14 00:00:00	2016-12-31 00:00:00	ANCIEN	\N	\N	\N	07024N	2014-10-22 10:49:21	2017-01-03 11:09:24
20657	657	2014-10-14 00:00:00	2016-12-31 00:00:00	ANCIEN	\N	\N	\N	07024N	2014-10-22 10:49:21	2017-01-03 11:09:24
20658	648	2014-10-14 00:00:00	2016-12-31 00:00:00	ANCIEN	\N	\N	\N	07024N	2014-10-22 10:49:21	2017-01-03 11:09:24
20659	608	2014-10-14 00:00:00	2016-12-31 00:00:00	ANCIEN	\N	\N	\N	07024N	2014-10-22 10:49:21	2017-01-03 11:09:24
20660	598	2014-10-14 00:00:00	2016-12-31 00:00:00	ANCIEN	\N	\N	\N	07024N	2014-10-22 10:49:21	2017-01-03 11:09:24
20661	979	2014-10-14 00:00:00	2016-12-31 00:00:00	ANCIEN	\N	\N	\N	07024N	2014-10-22 10:49:21	2017-01-03 11:09:24
20662	663	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11061K	2014-10-22 11:07:44	\N
20663	628	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11061K	2014-10-22 11:07:44	\N
20664	644	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11061K	2014-10-22 11:07:44	2017-09-24 17:42:26
20665	597	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11061K	2014-10-22 11:07:44	\N
20666	659	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11061K	2014-10-22 11:07:44	\N
20667	621	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11061K	2014-10-22 11:07:44	\N
20668	598	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11061K	2014-10-22 11:07:44	\N
20669	624	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11061K	2014-10-22 11:07:44	\N
20670	615	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98029W	2014-10-22 11:08:04	\N
20671	596	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98029W	2014-10-22 11:08:04	\N
20672	643	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98029W	2014-10-22 11:08:04	\N
20673	556	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14133K	2014-10-22 11:08:29	\N
20674	534	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14133K	2014-10-22 11:08:29	\N
20675	572	2014-10-20 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	98032R	2014-10-22 11:15:25	2015-06-12 15:59:49
20676	590	2014-10-20 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	98032R	2014-10-22 11:15:25	2015-06-12 15:59:49
20677	628	2014-10-20 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	98032R	2014-10-22 11:15:25	2015-06-12 15:59:49
20678	644	2014-10-20 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	98032R	2014-10-22 11:15:25	2015-06-12 15:59:49
20679	608	2014-10-20 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	98032R	2014-10-22 11:15:25	2015-06-12 15:59:49
20680	612	2014-10-20 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	98032R	2014-10-22 11:15:25	2015-06-12 15:59:49
20681	556	2014-10-20 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	98032R	2014-10-22 11:15:25	2015-06-12 15:59:49
20682	534	2014-10-20 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	98032R	2014-10-22 11:15:25	2015-06-12 15:59:49
20683	615	2014-10-20 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	98032R	2014-10-22 11:15:25	2015-06-12 15:59:49
20684	632	2014-10-20 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	98032R	2014-10-22 11:15:25	2015-06-12 15:59:49
20685	596	2014-10-20 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	98032R	2014-10-22 11:15:25	2015-06-12 15:59:49
20686	648	2014-10-20 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	98032R	2014-10-22 11:15:25	2015-06-12 15:59:49
20687	604	2014-10-20 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	98032R	2014-10-22 11:15:25	2015-06-12 15:59:49
20688	597	2014-10-20 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	98032R	2014-10-22 11:15:25	2015-06-12 15:59:49
20689	581	2014-10-20 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	98032R	2014-10-22 11:15:25	2015-06-12 15:59:49
20690	584	2014-10-20 00:00:00	2015-06-12 00:00:00	ANCIEN	\N	\N	\N	98032R	2014-10-22 11:15:25	2015-06-12 15:59:49
20691	622	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14237S	2014-10-22 11:28:24	\N
20692	574	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14237S	2014-10-22 11:28:24	\N
20693	610	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14237S	2014-10-22 11:28:24	\N
20694	584	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14237S	2014-10-22 11:28:24	\N
20287	663	2014-09-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11027H	2014-09-09 09:53:43	\N
20206	912	2013-11-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	2013-11-14 09:45:17
20596	629	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95030B	2014-10-21 12:51:34	\N
20597	608	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95030B	2014-10-21 12:51:34	\N
20903	594	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11015D	2014-10-23 11:40:00	\N
20904	609	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11015D	2014-10-23 11:40:01	\N
20905	624	2014-10-22 00:00:00	2015-03-05 00:00:00	ANCIEN	\N	\N	\N	07004J	2014-10-23 11:53:35	2015-03-05 11:46:42
20906	595	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11049P	2014-10-23 11:54:21	\N
20907	604	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11049P	2014-10-23 11:54:21	\N
20908	620	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11049P	2014-10-23 11:54:21	\N
20909	609	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11049P	2014-10-23 11:54:21	\N
20910	598	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11049P	2014-10-23 11:54:21	\N
20911	624	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11049P	2014-10-23 11:54:21	\N
20912	575	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11049P	2014-10-23 11:54:21	\N
20913	573	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11049P	2014-10-23 11:54:21	\N
20914	632	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11049P	2014-10-23 11:54:21	\N
20915	580	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11049P	2014-10-23 11:54:21	\N
20916	646	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08044W	2014-10-23 11:56:12	\N
20917	534	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08044W	2014-10-23 11:56:12	\N
20918	583	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08044W	2014-10-23 11:56:12	\N
20919	590	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08044W	2014-10-23 11:56:12	\N
20920	572	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08044W	2014-10-23 11:56:12	\N
20921	576	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08044W	2014-10-23 11:56:12	\N
20922	588	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08044W	2014-10-23 11:56:12	\N
20923	651	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08044W	2014-10-23 11:56:12	\N
20924	629	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08044W	2014-10-23 11:56:12	\N
20925	623	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08044W	2014-10-23 11:56:12	\N
20926	595	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08044W	2014-10-23 11:56:12	\N
20927	618	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08044W	2014-10-23 11:56:12	\N
20928	978	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08044W	2014-10-23 11:56:12	\N
20929	622	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08044W	2014-10-23 11:56:12	\N
20930	642	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08044W	2014-10-23 11:56:12	\N
20931	641	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08044W	2014-10-23 11:56:12	\N
20932	979	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08044W	2014-10-23 11:56:12	\N
20933	573	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08044W	2014-10-23 11:56:12	\N
20934	595	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	99004R	2014-10-23 11:56:44	\N
20935	598	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	99004R	2014-10-23 11:56:44	\N
20936	643	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08031R	2014-10-23 11:58:18	\N
20937	594	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08031R	2014-10-23 11:58:18	\N
20938	617	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08031R	2014-10-23 11:58:18	\N
20939	590	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08031R	2014-10-23 11:58:18	\N
20940	978	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08031R	2014-10-23 11:58:18	\N
20941	598	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08031R	2014-10-23 11:58:18	\N
20942	589	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08031R	2014-10-23 11:58:18	\N
20943	576	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08031R	2014-10-23 11:58:18	\N
20944	550	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08031R	2014-10-23 11:58:18	\N
20945	979	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08031R	2014-10-23 11:58:18	2016-12-07 16:41:20
20946	530	2014-10-22 00:00:00	2016-10-04 00:00:00	ANCIEN	\N	\N	\N	08031R	2014-10-23 11:58:18	2016-10-05 16:30:19
20947	626	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08031R	2014-10-23 11:58:18	\N
20948	623	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08017T	2014-10-23 12:07:32	\N
20949	604	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08017T	2014-10-23 12:07:32	\N
20950	583	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08017T	2014-10-23 12:07:32	\N
20951	574	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08017T	2014-10-23 12:07:32	\N
20952	979	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08017T	2014-10-23 12:07:32	2016-12-07 16:42:38
20953	604	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14221J	2014-10-23 12:13:26	\N
20954	589	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14221J	2014-10-23 12:13:26	\N
20955	646	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04088S	2014-10-23 12:14:53	\N
20956	579	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04088S	2014-10-23 12:14:53	\N
20957	534	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04088S	2014-10-23 12:14:53	\N
20958	583	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04088S	2014-10-23 12:14:53	\N
20959	603	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04088S	2014-10-23 12:14:53	\N
20960	592	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04088S	2014-10-23 12:14:53	\N
20961	598	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04088S	2014-10-23 12:14:53	\N
20962	529	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04088S	2014-10-23 12:14:53	\N
20963	623	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04088S	2014-10-23 12:14:53	\N
20964	591	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04088S	2014-10-23 12:14:53	2017-07-20 14:38:49
20965	600	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04088S	2014-10-23 12:14:53	\N
20966	610	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04088S	2014-10-23 12:14:53	\N
20967	979	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04088S	2014-10-23 12:14:53	\N
20968	608	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04088S	2014-10-23 12:14:53	\N
20969	611	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04088S	2014-10-23 12:14:53	2015-03-20 18:13:24
20970	590	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08047A	2014-10-23 12:17:24	\N
20971	584	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08047A	2014-10-23 12:17:24	\N
20972	608	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08047A	2014-10-23 12:17:24	\N
20973	661	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08047A	2014-10-23 12:17:24	\N
20974	674	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	07034Q	2014-10-23 12:18:22	\N
20975	640	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	07034Q	2014-10-23 12:18:22	\N
20976	625	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	07034Q	2014-10-23 12:18:22	\N
20977	556	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	07034Q	2014-10-23 12:18:22	\N
20978	612	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	07034Q	2014-10-23 12:18:22	\N
20979	577	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	07034Q	2014-10-23 12:18:22	2015-03-20 09:53:19
20980	651	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	07034Q	2014-10-23 12:18:22	\N
20981	621	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14229S	2014-10-23 12:20:34	2017-10-10 14:36:20
20982	602	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14229S	2014-10-23 12:20:34	2017-10-10 14:36:23
20983	642	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14229S	2014-10-23 12:20:34	2017-10-10 14:36:18
20984	613	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11046L	2014-10-23 12:22:05	\N
20985	597	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11046L	2014-10-23 12:22:05	\N
20483	602	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08028W	2014-10-16 09:54:12	\N
20478	575	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	2014-10-16 09:53:43	\N
20479	583	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	2014-10-16 09:53:43	\N
20480	661	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	2014-10-16 09:53:43	\N
20481	602	2014-10-14 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	2014-10-16 09:53:43	\N
20482	963	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08028W	2014-10-16 09:54:12	\N
20484	589	2014-10-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08028W	2014-10-16 09:54:12	\N
20573	651	2014-10-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14219Q	2014-10-20 15:06:27	\N
20574	643	2014-10-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14219Q	2014-10-20 15:06:27	\N
20575	642	2014-10-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14219Q	2014-10-20 15:06:27	\N
20576	573	2014-10-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14219Q	2014-10-20 15:06:27	\N
20752	642	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11020A	2014-10-22 15:49:52	\N
20753	622	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11020A	2014-10-22 15:49:52	\N
20754	651	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11020A	2014-10-22 15:49:52	\N
20755	643	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11020A	2014-10-22 15:49:52	\N
21405	647	2014-10-28 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	01003G	2014-10-29 10:13:10	2017-05-16 15:18:14
21406	571	2014-10-28 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	01003G	2014-10-29 10:13:10	2017-05-16 15:18:14
21407	624	2014-10-28 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	01003G	2014-10-29 10:13:10	2017-05-16 15:18:14
21408	608	2014-10-28 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	01003G	2014-10-29 10:13:10	2017-05-16 15:18:14
21409	618	2014-10-28 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	01003G	2014-10-29 10:13:10	2017-05-16 15:18:14
21410	591	2014-10-28 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	01003G	2014-10-29 10:13:10	2017-05-16 15:18:14
21411	674	2014-10-28 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	01003G	2014-10-29 10:13:10	2017-05-16 15:18:14
21412	601	2014-10-28 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	01003G	2014-10-29 10:13:10	2017-05-16 15:18:14
21413	574	2014-10-28 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	01003G	2014-10-29 10:13:10	2017-05-16 15:18:14
21414	643	2014-10-28 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	01003G	2014-10-29 10:13:10	2017-05-16 15:18:14
21415	603	2014-10-28 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	01003G	2014-10-29 10:13:10	2017-05-16 15:18:14
21416	978	2014-10-28 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	01003G	2014-10-29 10:13:10	2017-05-16 15:18:14
21417	597	2014-10-28 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	01003G	2014-10-29 10:13:10	2017-05-16 15:18:14
21418	979	2014-10-28 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	01003G	2014-10-29 10:13:10	2017-05-16 15:18:14
21419	622	2014-10-28 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	01003G	2014-10-29 10:13:10	2017-05-16 15:18:14
21420	598	2014-10-28 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	01003G	2014-10-29 10:13:10	2017-05-16 15:18:14
21421	963	2014-10-28 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	01003G	2014-10-29 10:13:10	2017-05-16 15:18:14
21422	661	2014-10-28 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	01003G	2014-10-29 10:13:10	2017-05-16 15:18:14
21423	534	2014-10-28 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	01003G	2014-10-29 10:13:10	2017-05-16 15:18:14
21424	589	2014-10-28 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	01003G	2014-10-29 10:13:10	2017-05-16 15:18:14
21425	628	2014-10-28 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	01003G	2014-10-29 10:13:10	2017-05-16 15:18:14
21426	648	2014-10-28 00:00:00	2017-05-15 00:00:00	ANCIEN	\N	\N	\N	01003G	2014-10-29 10:13:10	2017-05-16 15:18:14
21441	625	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14042U	2014-10-29 10:17:18	\N
21448	659	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04088S	2014-10-29 10:18:57	\N
21449	576	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11039M	2014-10-29 10:19:19	\N
21450	573	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11039M	2014-10-29 10:19:19	\N
21451	583	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01027Q	2014-10-29 10:23:36	\N
21452	602	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01027Q	2014-10-29 10:27:05	\N
21453	661	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01027Q	2014-10-29 10:27:05	\N
21454	588	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01027Q	2014-10-29 10:27:05	\N
21540	577	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	14209N	2014-10-29 18:51:15	2017-10-01 10:34:22
21541	584	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	14209N	2014-10-29 18:51:15	2017-10-01 10:34:22
21542	618	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	14209N	2014-10-29 18:51:15	2017-10-01 10:34:22
21543	585	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	14209N	2014-10-29 18:51:15	2017-10-01 10:34:22
21544	641	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11105E	2014-10-29 18:51:37	\N
21545	979	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11105E	2014-10-29 18:51:37	2017-09-24 18:20:10
21546	978	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11105E	2014-10-29 18:51:37	\N
21547	575	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11105E	2014-10-29 18:51:37	\N
21548	601	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11105E	2014-10-29 18:51:37	2017-09-24 18:20:10
21549	556	2014-10-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11105E	2014-10-29 18:51:37	\N
21934	608	2014-10-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04097T	2014-10-31 15:50:21	\N
21935	584	2014-10-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04097T	2014-10-31 15:50:21	\N
21936	661	2014-10-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04097T	2014-10-31 15:50:21	\N
21937	601	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	2014-10-31 15:50:51	2015-03-11 11:04:30
21938	978	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	2014-10-31 15:50:51	\N
21939	581	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2014-10-31 15:52:08	\N
21940	659	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2014-10-31 15:52:08	\N
21941	596	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2014-10-31 15:52:08	\N
21942	651	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2014-10-31 15:52:08	\N
21943	598	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2014-10-31 15:52:08	\N
21944	618	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2014-10-31 15:52:08	\N
21945	623	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2014-10-31 15:52:08	\N
21946	604	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2014-10-31 15:52:08	\N
21947	617	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2014-10-31 15:52:08	\N
34457	1010	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	14147R	\N	\N
21948	591	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2014-10-31 15:52:08	2017-07-20 14:38:10
21949	594	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2014-10-31 15:52:08	\N
21950	576	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2014-10-31 15:52:08	\N
21951	595	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2014-10-31 15:52:09	\N
21952	634	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2014-10-31 15:52:09	\N
21953	624	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2014-10-31 15:52:09	\N
21954	621	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2014-10-31 15:52:09	\N
21955	590	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2014-10-31 15:52:09	\N
21956	663	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2014-10-31 15:52:09	\N
21957	574	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2014-10-31 15:52:09	\N
21958	622	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2014-10-31 15:52:09	\N
21959	583	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2014-10-31 15:52:09	\N
21960	597	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2014-10-31 15:52:09	\N
21961	585	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2014-10-31 15:52:09	2017-07-20 11:43:35
21962	642	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2014-10-31 15:52:09	\N
21963	629	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2014-10-31 15:52:09	\N
21964	622	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98005N	2014-10-31 15:52:57	\N
21965	583	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98005N	2014-10-31 15:52:57	\N
20271	556	2014-06-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11089X	2014-07-04 15:04:01	\N
20263	918	2014-05-21 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04090L	\N	2014-09-28 19:29:39
20806	673	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	08042U	2014-10-22 18:10:34	2017-10-01 10:20:50
20807	584	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	08042U	2014-10-22 18:10:34	2017-10-01 10:20:50
20808	604	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	08042U	2014-10-22 18:10:34	2017-10-01 10:20:50
20809	621	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	08042U	2014-10-22 18:10:34	2017-10-01 10:20:50
20810	590	2014-10-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	08042U	2014-10-22 18:10:34	2017-10-01 10:20:50
20811	581	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14169X	2014-10-22 18:11:09	\N
20812	576	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14169X	2014-10-22 18:11:09	\N
20813	621	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14169X	2014-10-22 18:11:09	\N
20814	580	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14169X	2014-10-22 18:11:09	2015-04-10 15:10:32
20815	574	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14169X	2014-10-22 18:11:10	\N
22402	578	2015-01-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11035H	2015-01-19 11:29:08	\N
22451	661	2015-01-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	10015M	2015-01-26 14:38:42	2015-03-19 09:57:44
22462	530	2015-01-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11100Y	2015-01-27 16:18:48	\N
22463	613	2015-01-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11100Y	2015-01-27 16:18:48	\N
22464	612	2015-01-27 00:00:00	2015-04-21 00:00:00	ANCIEN	\N	\N	\N	01042P	2015-01-27 16:49:39	2015-04-21 17:14:30
22507	532	2015-02-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	12042Y	2015-02-03 18:04:24	2017-09-24 19:31:54
22535	620	2015-02-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11033F	2015-02-11 16:41:16	\N
22634	948	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11097X	\N	\N
22643	948	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14195A	\N	\N
22659	1003	2015-01-28 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	2017-06-19 12:20:59
22661	1003	2015-01-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11090Q	\N	\N
22663	1003	2015-01-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
22666	1003	2015-01-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
22751	919	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08060W	\N	\N
22779	910	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
22823	591	2015-02-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04067M	2015-02-16 17:50:20	2017-09-24 17:47:28
22824	595	2015-02-13 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	2015-02-16 17:50:31	\N
22825	605	2015-01-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92031P	2015-02-16 17:50:40	\N
22829	913	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11095V	\N	2017-09-24 13:25:54
22830	922	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11095V	\N	2017-09-24 13:25:54
22954	922	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08055A	\N	\N
23167	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
23168	532	2015-03-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14109K	2015-03-18 11:29:36	\N
23205	990	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01031L	\N	2017-09-24 18:20:10
23216	990	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08031R	\N	\N
23258	909	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14271U	\N	2017-09-24 17:06:55
23273	957	2014-10-01 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	14013P	\N	2017-06-19 16:06:01
23351	933	2015-01-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14041T	\N	\N
23349	933	2015-01-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14169X	\N	\N
23350	933	2015-01-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11035H	\N	\N
23358	933	2015-01-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
23365	933	2015-01-01 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	2017-06-19 12:20:59
23379	633	2015-07-22 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	08051V	2015-07-23 15:20:40	2017-06-19 12:20:59
23719	918	2014-10-01 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	14014Q	\N	2017-06-19 16:06:51
23748	612	2016-09-06 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	80013X	2016-09-08 10:20:36	\N
23750	584	2016-09-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01011G	2016-09-19 10:25:40	2017-09-24 16:43:43
23758	907	2016-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	14257W	\N	\N
23822	620	2016-12-20 00:00:00	2017-07-28 00:00:00	ANCIEN	\N	\N	\N	11032E	2016-12-21 10:09:54	2017-08-03 11:38:41
23823	598	2016-12-20 00:00:00	2017-07-28 00:00:00	ANCIEN	\N	\N	\N	11032E	2016-12-21 10:09:54	2017-08-03 11:38:41
23824	573	2016-12-20 00:00:00	2017-07-28 00:00:00	ANCIEN	\N	\N	\N	11032E	2016-12-21 10:09:54	2017-08-03 11:38:41
23849	659	2017-02-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14249W	2017-02-23 13:00:54	\N
24212	608	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	05012A	2017-10-17 15:10:19	\N
24213	574	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	05012A	2017-10-17 15:10:19	\N
24214	602	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	05012A	2017-10-17 15:10:19	\N
24215	583	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	05012A	2017-10-17 15:10:19	\N
24216	590	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	05012A	2017-10-17 15:10:19	\N
24217	978	2017-10-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	05012A	2017-10-17 15:10:19	\N
24218	615	2017-10-11 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	98029W	2017-10-17 15:10:43	\N
24219	596	2017-10-11 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	98029W	2017-10-17 15:10:43	\N
24220	598	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11080N	2017-10-17 15:11:11	\N
24221	608	2017-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11080N	2017-10-17 15:11:11	\N
24222	590	2017-10-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11053K	2017-10-17 15:12:13	\N
24223	597	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2017-10-18 10:22:37	\N
24224	590	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2017-10-18 10:22:37	\N
24225	580	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2017-10-18 10:22:37	\N
24226	581	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2017-10-18 10:22:37	\N
24227	594	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2017-10-18 10:22:37	\N
24228	625	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2017-10-18 10:22:37	\N
24229	575	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2017-10-18 10:22:37	\N
24230	663	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2017-10-18 10:22:37	\N
24231	573	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2017-10-18 10:22:38	\N
24232	578	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2017-10-18 10:22:38	\N
24233	588	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2017-10-18 10:22:38	\N
24234	641	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2017-10-18 10:22:38	\N
24235	618	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2017-10-18 10:22:38	\N
24236	589	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2017-10-18 10:22:38	\N
24237	583	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2017-10-18 10:22:38	\N
24238	643	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2017-10-18 10:22:38	\N
24239	617	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2017-10-18 10:22:38	\N
24240	620	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2017-10-18 10:22:38	\N
24241	661	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2017-10-18 10:22:38	\N
24242	598	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2017-10-18 10:22:38	\N
24243	610	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2017-10-18 10:22:38	\N
24244	622	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2017-10-18 10:22:38	\N
24245	633	2017-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2017-10-18 10:22:38	\N
20210	911	2013-11-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	01043Q	2013-11-19 11:01:32	\N
20695	616	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95063L	2014-10-22 11:46:04	\N
20696	590	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95063L	2014-10-22 11:46:04	\N
20697	625	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95063L	2014-10-22 11:46:04	\N
20698	600	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95063L	2014-10-22 11:46:04	\N
20699	586	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95063L	2014-10-22 11:46:04	\N
20700	613	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95063L	2014-10-22 11:46:04	\N
20701	618	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95063L	2014-10-22 11:46:04	\N
20702	604	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95063L	2014-10-22 11:46:04	\N
20703	581	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95063L	2014-10-22 11:46:04	\N
20704	609	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95063L	2014-10-22 11:46:04	\N
20705	584	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95063L	2014-10-22 11:46:04	\N
22170	632	2014-11-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01015L	2014-11-12 11:14:26	\N
22255	647	2014-11-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08012N	2014-11-20 09:45:02	\N
22260	529	2014-11-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98035U	2014-11-20 14:47:49	\N
22309	571	2014-12-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08012N	2014-12-04 09:27:18	\N
22310	599	2014-11-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11095V	2014-12-04 09:27:30	\N
22385	629	2014-12-04 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14053L	2015-01-14 16:09:02	\N
22434	651	2015-01-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	10006L	2015-01-22 14:58:23	\N
22435	651	2015-01-22 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	14209N	2015-01-22 14:58:36	2017-10-01 10:34:22
22499	619	2015-01-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11076S	2015-02-02 12:07:15	2017-09-24 17:47:28
22500	532	2015-01-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	77002U	2015-02-02 15:28:14	\N
22501	532	2015-01-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	2015-02-03 10:31:00	\N
22502	605	2015-02-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98005N	2015-02-03 10:31:08	\N
22503	605	2015-01-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95067Q	2015-02-03 10:31:25	\N
22504	648	2015-01-29 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2015-02-03 10:31:35	\N
22524	633	2015-02-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08031R	2015-02-05 11:58:23	\N
22525	598	2015-02-03 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	98042T	2015-02-05 16:34:34	2017-10-01 10:39:23
22526	659	2015-02-03 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	08065C	2015-02-06 09:23:15	2017-09-25 09:57:52
22631	998	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11072N	\N	\N
22633	948	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14123H	\N	\N
22635	948	2014-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	90003B	\N	2017-10-01 10:01:39
22638	948	2014-10-01 00:00:00	2015-12-04 00:00:00	ANCIEN	\N	\N	\N	80013X	\N	\N
22639	948	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
22641	948	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14227Q	\N	\N
22642	948	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	92045V	\N	2017-09-24 17:29:37
22652	948	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01022K	\N	2017-09-24 17:14:26
22654	948	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14042U	\N	\N
22655	948	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14207L	\N	\N
22656	948	2014-10-01 00:00:00	2014-10-01 00:00:00	ANCIEN	\N	\N	\N	08043V	\N	\N
22745	957	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	\N	\N
22747	957	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11100Y	\N	2017-09-24 13:57:40
22787	909	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01046T	\N	2017-09-24 13:44:49
22794	909	2014-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	98021N	\N	2017-10-01 09:22:38
22814	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14199E	\N	\N
23104	934	2014-09-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14121F	2015-03-06 14:17:16	\N
23105	990	2014-09-01 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	14014Q	2015-03-06 14:20:01	2017-06-19 16:06:51
23106	966	2014-09-01 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	14014Q	2015-03-06 14:22:26	2017-06-19 16:06:51
23107	991	2014-09-01 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	14014Q	2015-03-06 14:23:53	2017-06-19 16:06:51
23222	938	2015-03-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11027H	\N	\N
23223	938	2015-03-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14169X	\N	\N
23225	938	2015-03-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14041T	\N	\N
23227	938	2015-03-02 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
23262	906	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	14271U	\N	2017-09-24 17:06:55
23265	912	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98050T	\N	\N
23267	906	2014-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	90003B	\N	2017-10-01 10:01:39
23284	659	2015-05-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11106F	2015-06-04 09:36:25	2017-09-24 19:14:37
23371	933	2015-01-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
23383	957	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04097T	\N	\N
23455	CHRETORIENT	2016-02-12 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11076S	2016-02-12 12:17:23	2017-09-24 17:47:28
23456	CHRETORIENT	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	14133K	2016-02-12 12:17:51	\N
23457	CHRETORIENT	2016-02-12 00:00:00	2020-08-02 00:00:00	ANCIEN	\N	\N	\N	14239U	2016-02-12 12:18:00	2018-01-05 11:29:31
23458	CHRETORIENT	2016-02-12 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01008M	2016-02-12 12:18:54	2017-09-24 13:44:49
23459	CHRETORIENT	2016-02-12 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01046T	2016-02-12 12:19:02	2017-09-24 13:44:49
23460	CHRETORIENT	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	05008E	2016-02-12 12:19:07	\N
23461	CHRETORIENT	2016-02-12 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11030C	2016-02-12 12:19:10	2017-09-24 17:09:24
23462	CHRETORIENT	2016-02-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14093U	2016-02-12 12:19:16	\N
23463	CHRETORIENT	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	14030Q	2016-02-12 12:19:25	\N
23464	CHRETORIENT	2016-02-12 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	04054G	2016-02-12 12:19:28	2017-09-24 17:18:03
23465	CHRETORIENT	2016-02-12 00:00:00	2020-11-30 00:00:00	ANCIEN	\N	\N	\N	96004D	2016-02-12 12:19:37	\N
23466	CHRETORIENT	2016-02-12 00:00:00	2020-10-19 00:00:00	ANCIEN	\N	\N	\N	04040A	2016-02-12 12:19:44	\N
23467	CHRETORIENT	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	14089Y	2016-02-12 12:19:59	\N
23468	CHRETORIENT	2016-02-12 00:00:00	2020-10-07 00:00:00	ANCIEN	\N	\N	\N	14105F	2016-02-12 12:20:31	\N
23469	CHRETORIENT	2016-02-12 00:00:00	2020-11-02 00:00:00	ANCIEN	\N	\N	\N	08058D	2016-02-12 12:21:05	2018-01-05 11:29:19
23470	CHRETORIENT	2016-02-12 00:00:00	2017-06-01 00:00:00	ANCIEN	\N	\N	\N	14175V	2016-02-12 12:21:08	2017-06-02 10:02:56
23471	CHRETORIENT	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	2016-02-12 12:21:14	\N
23472	CHRETORIENT	2016-02-12 00:00:00	2020-10-08 00:00:00	ANCIEN	\N	\N	\N	11101A	2016-02-12 12:21:18	\N
23473	CHRETORIENT	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	04042C	2016-02-12 12:21:26	\N
23474	CHRETORIENT	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	14053L	2016-02-12 12:21:30	\N
23475	CHRETORIENT	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	14038Y	2016-02-12 12:22:32	\N
23476	CHRETORIENT	2016-02-12 00:00:00	2023-10-05 00:00:00	ANCIEN	\N	\N	\N	11080N	2016-02-12 12:22:36	\N
23477	CHRETORIENT	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	08028W	2016-02-12 12:22:51	\N
23478	CHRETORIENT	2016-02-12 00:00:00	2020-10-19 00:00:00	ANCIEN	\N	\N	\N	88008L	2016-02-12 12:22:57	\N
23479	CHRETORIENT	2016-02-12 00:00:00	2017-10-30 00:00:00	ANCIEN	\N	\N	\N	11027H	2016-02-12 12:23:23	2017-10-31 17:30:33
23480	CHRETORIENT	2016-02-12 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	04086Q	2016-02-12 12:23:31	\N
23481	CHRETORIENT	2016-02-12 00:00:00	2020-10-19 00:00:00	ANCIEN	\N	\N	\N	14079W	2016-02-12 12:23:38	\N
23482	CHRETORIENT	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	14259Y	2016-02-12 12:23:41	\N
23483	CHRETORIENT	2016-02-12 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	04081K	2016-02-12 12:24:29	2017-09-24 19:25:10
20215	909	2011-10-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11110B	\N	\N
20986	978	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11046L	2014-10-23 12:22:05	\N
20987	642	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11046L	2014-10-23 12:22:05	\N
20988	575	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11046L	2014-10-23 12:22:05	\N
20989	651	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11046L	2014-10-23 12:22:05	\N
20990	663	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01034P	2014-10-23 12:22:38	\N
20991	583	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01034P	2014-10-23 12:22:38	\N
21107	673	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2014-10-24 10:57:46	2014-10-28 17:12:31
21108	597	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2014-10-24 10:57:46	2014-10-28 17:13:47
21109	622	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2014-10-24 10:57:46	2014-10-28 17:13:00
21110	600	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2014-10-24 10:57:46	2014-10-28 17:11:53
21111	626	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2014-10-24 10:57:46	2014-10-28 17:15:56
21112	595	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2014-10-24 10:57:46	2014-10-28 17:06:23
21113	642	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2014-10-24 10:57:46	2014-10-28 17:10:09
21114	586	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2014-10-24 10:57:46	2014-10-28 17:15:48
21115	629	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2014-10-24 10:57:46	2014-10-28 17:16:21
21116	584	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2014-10-24 10:57:46	2014-10-28 17:16:31
21117	617	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2014-10-24 10:57:46	2014-10-28 17:10:52
21118	620	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2014-10-24 10:57:46	2014-10-28 17:16:04
21119	573	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2014-10-24 10:57:46	2014-10-28 17:02:06
21120	534	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2014-10-24 10:57:46	2014-10-28 17:10:28
21121	613	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2014-10-24 10:57:46	2014-10-28 17:10:38
21122	609	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2014-10-24 10:57:47	2014-10-28 17:08:39
21123	590	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2014-10-24 10:57:47	2014-10-28 17:11:01
21124	616	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2014-10-24 10:57:47	2014-10-28 17:12:18
21125	582	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2014-10-24 10:57:47	2014-10-28 17:09:29
21126	556	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2014-10-24 10:57:47	2014-10-28 17:08:22
21127	529	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2014-10-24 10:57:47	2014-10-28 17:16:13
21128	583	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2014-10-24 10:57:47	2014-10-28 17:09:53
21129	578	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2014-10-24 10:57:47	2014-10-28 17:09:02
21130	659	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2014-10-24 10:57:47	2014-10-28 17:14:30
21131	604	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2014-10-24 10:57:47	2014-10-28 17:02:06
21132	653	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2014-10-24 10:57:47	2014-10-28 17:11:18
21133	598	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2014-10-24 10:57:47	2014-10-28 17:12:41
21134	588	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2014-10-24 10:57:47	2014-10-28 17:12:06
21135	618	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2014-10-24 10:57:47	2014-10-28 17:11:10
21136	572	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2014-10-24 10:57:47	2014-10-28 17:02:06
21137	661	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2014-10-24 10:57:47	2015-03-19 09:58:05
21138	646	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2014-10-24 10:57:47	2014-10-28 17:01:27
21139	608	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2014-10-24 10:57:47	2014-10-28 17:11:40
21200	625	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11043H	2014-10-24 17:35:46	\N
21201	576	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11043H	2014-10-24 17:35:46	\N
21202	594	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14059S	2014-10-24 17:36:08	\N
21203	604	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14059S	2014-10-24 17:36:08	\N
21204	625	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14059S	2014-10-24 17:36:08	\N
21205	621	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14059S	2014-10-24 17:36:08	\N
22114	588	2014-11-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04036E	2014-11-05 10:22:57	\N
22295	584	2014-11-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04077P	2014-12-02 09:20:56	\N
22296	609	2014-11-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04077P	2014-12-02 09:20:56	\N
22452	556	2015-01-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11084S	2015-01-26 15:00:16	\N
22453	613	2015-01-26 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11084S	2015-01-26 15:00:16	\N
22481	578	2015-01-08 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08014Q	2015-01-30 09:46:54	\N
22482	605	2015-01-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11091R	2015-01-30 09:47:08	\N
22483	572	2015-01-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	2015-01-30 09:47:32	\N
22484	618	2015-01-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	2015-01-30 09:47:32	\N
22485	619	2015-01-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14237S	2015-01-30 09:47:49	\N
22486	578	2015-01-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14237S	2015-01-30 09:47:49	\N
22487	582	2015-01-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14237S	2015-01-30 09:47:49	\N
22488	592	2015-01-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11094U	2015-01-30 09:48:02	\N
22619	912	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04044E	\N	\N
22629	998	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08043V	\N	\N
22630	998	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	04094Q	\N	2017-09-25 10:58:49
22632	998	2014-10-01 00:00:00	2017-07-03 00:00:00	ANCIEN	\N	\N	\N	01044R	\N	2017-07-04 15:08:09
22636	948	2014-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	\N	2017-10-01 09:41:22
22637	948	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
22640	948	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14205J	\N	\N
22673	653	2015-02-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14265W	2015-02-13 16:36:18	\N
22699	911	2014-10-01 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	2017-06-19 12:20:59
22744	957	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
22749	919	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14105F	\N	\N
22752	919	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08055A	\N	\N
22759	919	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11090Q	\N	\N
22760	919	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
22761	919	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
22762	919	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	\N	\N
22763	919	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11036J	\N	2017-09-24 18:16:52
22764	919	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11100Y	\N	2017-09-24 13:57:40
22765	910	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08010L	\N	\N
22766	910	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08060W	\N	\N
22767	910	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14135M	\N	\N
22768	910	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11043H	\N	\N
22769	910	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14169X	\N	\N
22770	910	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08024S	\N	\N
22771	910	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	2017-09-24 13:44:49
22772	910	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
22773	910	2014-10-01 00:00:00	2014-11-03 00:00:00	ANCIEN	\N	\N	\N	04094Q	\N	\N
22774	910	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14061L	\N	\N
22812	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
22826	1003	2015-01-28 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11095V	\N	2017-09-24 13:25:54
20267	583	2014-06-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04055H	2014-07-01 10:10:47	\N
20268	590	2014-06-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04055H	2014-07-01 10:11:49	2014-07-01 10:11:56
20269	618	2014-06-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	04055H	2014-07-01 10:12:34	\N
20272	609	2014-07-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11095V	2014-07-18 16:44:24	\N
20281	575	2014-09-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11027H	2014-09-03 17:12:23	2015-02-03 14:09:39
20282	578	2014-09-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11027H	2014-09-03 17:12:55	2015-02-03 14:09:39
20283	642	2014-09-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11027H	2014-09-03 17:13:32	\N
20284	673	2014-09-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11027H	2014-09-03 17:14:14	\N
20285	629	2014-09-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11027H	2014-09-03 17:15:46	\N
20286	610	2014-09-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11027H	2014-09-03 17:16:20	\N
20706	596	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11112D	2014-10-22 14:43:56	\N
20707	573	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11112D	2014-10-22 14:43:56	\N
20708	534	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11112D	2014-10-22 14:43:56	\N
20709	578	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11112D	2014-10-22 14:43:56	\N
20710	978	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11112D	2014-10-22 14:43:56	\N
20711	659	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	2014-10-22 14:44:28	\N
20712	979	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98023Q	2014-10-22 14:45:05	2016-12-07 16:43:22
20713	609	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98023Q	2014-10-22 14:45:05	\N
20714	626	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98023Q	2014-10-22 14:45:06	\N
20715	618	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98023Q	2014-10-22 14:45:06	\N
20716	574	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98023Q	2014-10-22 14:45:06	\N
20717	622	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98023Q	2014-10-22 14:45:06	\N
20718	643	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98023Q	2014-10-22 14:45:06	\N
20719	583	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04055H	2014-10-22 14:45:52	\N
20720	576	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04055H	2014-10-22 14:45:52	\N
20721	618	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04055H	2014-10-22 14:45:52	\N
20722	661	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04055H	2014-10-22 14:45:52	\N
20723	610	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04055H	2014-10-22 14:45:52	\N
20724	608	2014-10-16 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04055H	2014-10-22 14:45:52	\N
20725	583	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01043Q	2014-10-22 14:46:22	\N
20726	590	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01043Q	2014-10-22 14:46:22	\N
20727	626	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01043Q	2014-10-22 14:46:22	\N
20728	618	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01043Q	2014-10-22 14:46:22	\N
20729	574	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01043Q	2014-10-22 14:46:22	\N
20730	622	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01043Q	2014-10-22 14:46:22	2015-03-10 10:01:22
20731	979	2014-10-14 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	14014Q	2014-10-22 14:47:16	2017-06-19 16:06:51
20732	576	2014-10-14 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	14014Q	2014-10-22 14:47:16	2017-06-19 16:06:51
20733	625	2014-10-14 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	14014Q	2014-10-22 14:47:16	2017-06-19 16:06:51
20734	978	2014-10-14 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	14014Q	2014-10-22 14:47:16	2017-06-19 16:06:51
21239	591	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14121F	2014-10-28 09:27:23	2017-07-20 14:38:36
21240	608	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14121F	2014-10-28 09:27:24	\N
21241	604	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14121F	2014-10-28 09:27:24	\N
21242	573	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14121F	2014-10-28 09:27:24	\N
21243	663	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14121F	2014-10-28 09:27:24	\N
21244	673	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14187A	2014-10-28 09:27:43	\N
21245	629	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14187A	2014-10-28 09:27:43	\N
21246	641	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14187A	2014-10-28 09:27:43	\N
21247	621	2014-10-23 00:00:00	2016-12-01 00:00:00	ANCIEN	\N	\N	\N	11097X	2014-10-28 09:28:02	2016-12-07 15:00:10
21248	622	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14173T	2014-10-28 10:00:15	\N
21966	651	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98005N	2014-10-31 15:52:57	\N
21967	584	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98005N	2014-10-31 15:52:57	\N
21968	626	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98005N	2014-10-31 15:52:57	\N
21969	609	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98005N	2014-10-31 15:52:57	\N
21970	578	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98005N	2014-10-31 15:52:57	\N
21971	653	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98005N	2014-10-31 15:52:57	\N
21972	629	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98005N	2014-10-31 15:52:57	\N
21973	602	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98005N	2014-10-31 15:52:57	\N
21974	663	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	98005N	2014-10-31 15:52:57	\N
21975	632	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08014Q	2014-10-31 15:55:26	\N
21976	572	2014-10-30 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	99004R	2014-10-31 15:55:53	\N
22007	659	2014-10-31 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	2014-11-03 10:14:00	\N
22008	588	2014-10-31 00:00:00	2015-06-08 00:00:00	ANCIEN	\N	\N	\N	11027H	2014-11-03 10:14:00	2015-06-08 09:43:37
22273	646	2014-11-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08041T	2014-11-26 09:42:01	\N
22274	646	2014-11-25 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	96004D	2014-11-26 09:42:12	\N
22275	647	2014-11-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04034C	2014-11-26 09:42:26	\N
22293	621	2014-11-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08031R	2014-12-01 16:38:15	\N
22294	618	2014-11-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08031R	2014-12-01 16:38:15	\N
22313	599	2014-12-03 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11068S	2014-12-04 15:08:24	\N
22496	653	2015-01-20 00:00:00	2016-12-01 00:00:00	ANCIEN	\N	\N	\N	11097X	2015-01-30 17:04:45	2016-12-07 15:00:10
22542	592	2015-02-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11072N	2015-02-13 09:02:22	2015-03-11 12:57:40
22543	620	2015-02-11 00:00:00	2017-07-03 00:00:00	ANCIEN	\N	\N	\N	01044R	2015-02-13 09:02:32	2017-07-04 15:08:09
22544	617	2015-02-12 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08009T	2015-02-13 09:28:20	\N
22545	591	2014-12-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08073C	2015-02-13 09:28:27	2017-07-20 14:38:36
22669	908	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	80013X	\N	\N
22732	906	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11036J	\N	2017-09-24 18:16:52
22743	957	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
22746	957	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11036J	\N	2017-09-24 18:16:52
22750	919	2014-10-01 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	98046X	\N	2017-09-25 09:56:00
22753	919	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08024S	\N	\N
22754	919	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01008M	\N	2017-09-24 13:44:49
22755	919	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	07034Q	\N	\N
22756	919	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
22757	919	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14169X	\N	\N
22758	919	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11094U	\N	2017-09-24 13:25:54
22775	910	2014-10-01 00:00:00	2017-07-28 00:00:00	ANCIEN	\N	\N	\N	11032E	\N	2017-08-03 11:38:41
22776	910	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
22777	910	2014-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	\N	2017-10-01 09:41:22
22778	910	2014-10-01 00:00:00	2017-07-22 00:00:00	ANCIEN	\N	\N	\N	14037X	\N	2017-07-24 09:58:00
22780	910	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14195A	\N	\N
22781	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14105F	\N	\N
22782	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14093U	\N	\N
22783	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08010L	\N	\N
20213	911	2013-11-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	11054L	2013-11-29 16:17:59	\N
20214	911	2013-11-01 00:00:00	2014-12-31 00:00:00	ANCIEN	\N	\N	\N	08009T	2013-11-29 16:17:36	\N
21354	575	2014-10-28 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	08051V	2014-10-28 17:20:49	2017-06-19 12:20:59
21355	621	2014-10-28 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	08051V	2014-10-28 17:20:49	2017-06-19 12:20:59
21356	626	2014-10-28 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	08051V	2014-10-28 17:20:49	2017-06-19 12:20:59
21357	617	2014-10-28 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	08051V	2014-10-28 17:20:49	2017-06-19 12:20:59
21358	632	2014-10-28 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	08051V	2014-10-28 17:20:49	2017-06-19 12:20:59
21359	624	2014-10-28 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	08051V	2014-10-28 17:20:49	2017-06-19 12:20:59
21360	598	2014-10-28 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	08051V	2014-10-28 17:20:49	2017-06-19 12:20:59
21361	584	2014-10-28 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	08051V	2014-10-28 17:20:49	2017-06-19 12:20:59
21362	651	2014-10-28 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	08051V	2014-10-28 17:20:49	2017-06-19 12:20:59
21363	608	2014-10-28 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	08051V	2014-10-28 17:20:49	2017-06-19 12:20:59
21364	556	2014-10-28 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	08051V	2014-10-28 17:20:49	2017-06-19 12:20:59
21365	594	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11040E	2014-10-28 17:21:36	\N
21366	581	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11040E	2014-10-28 17:21:36	\N
21367	608	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11040E	2014-10-28 17:21:36	\N
21368	590	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11040E	2014-10-28 17:21:36	\N
21369	642	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11040E	2014-10-28 17:21:36	\N
21383	617	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	08015R	2014-10-29 09:12:30	2017-10-10 11:04:14
21384	979	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	08015R	2014-10-29 09:12:30	2017-10-10 11:04:14
21385	646	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08015R	2014-10-29 09:12:30	\N
21386	577	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	08015R	2014-10-29 09:12:30	2017-10-10 11:04:14
21387	629	2014-10-28 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	08015R	2014-10-29 09:12:30	2017-10-10 11:04:14
21388	618	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08015R	2014-10-29 09:12:31	\N
21389	643	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08015R	2014-10-29 09:12:31	2017-10-18 15:52:14
21390	626	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11029K	2014-10-29 09:14:57	\N
21391	583	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11029K	2014-10-29 09:14:57	\N
21392	604	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11029K	2014-10-29 09:14:57	\N
21393	605	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11029K	2014-10-29 09:14:57	\N
21394	609	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14199E	2014-10-29 09:20:49	\N
21395	574	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14199E	2014-10-29 09:20:49	\N
21396	642	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14199E	2014-10-29 09:20:49	\N
21397	605	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14199E	2014-10-29 09:20:49	\N
21398	577	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14199E	2014-10-29 09:20:49	\N
21399	598	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14199E	2014-10-29 09:20:49	\N
21400	622	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14199E	2014-10-29 09:20:49	2015-03-10 10:01:54
21401	979	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01058X	2014-10-29 09:22:54	\N
21402	626	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01058X	2014-10-29 09:22:54	\N
21403	629	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01058X	2014-10-29 09:22:54	\N
21404	598	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01058X	2014-10-29 09:22:54	\N
21455	626	2014-10-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	80027E	2014-10-29 10:58:36	\N
21456	624	2014-10-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	80027E	2014-10-29 10:58:36	\N
21457	594	2014-10-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	80027E	2014-10-29 10:58:37	\N
21458	574	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14151M	2014-10-29 11:02:44	\N
21459	590	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14151M	2014-10-29 11:02:44	\N
21460	584	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14151M	2014-10-29 11:02:44	\N
21469	643	2014-10-28 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	14013P	2014-10-29 12:27:00	2017-06-19 16:06:01
21470	598	2014-10-28 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	14013P	2014-10-29 12:27:00	2017-06-19 16:06:01
21471	604	2014-10-28 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	14013P	2014-10-29 12:27:00	2017-06-19 16:06:01
21472	584	2014-10-28 00:00:00	2017-06-17 00:00:00	ANCIEN	\N	\N	\N	14013P	2014-10-29 12:27:00	2017-06-19 16:06:01
21473	626	2014-10-28 00:00:00	2017-10-06 00:00:00	ANCIEN	\N	\N	\N	14249W	2014-10-29 12:27:22	2017-10-09 09:54:08
21474	621	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14249W	2014-10-29 12:27:22	\N
21475	590	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11082Q	2014-10-29 12:27:36	\N
21476	598	2014-10-28 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11082Q	2014-10-29 12:27:36	\N
21477	590	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14073Q	2014-10-29 12:28:26	\N
21478	583	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14073Q	2014-10-29 12:28:26	\N
21479	598	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14073Q	2014-10-29 12:28:26	\N
21480	572	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14073Q	2014-10-29 12:28:27	\N
21481	620	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14073Q	2014-10-29 12:28:27	\N
21482	604	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14073Q	2014-10-29 12:28:27	\N
21483	622	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14073Q	2014-10-29 12:28:27	\N
21484	592	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14073Q	2014-10-29 12:28:27	2015-03-11 12:57:31
21485	579	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08058D	2014-10-29 12:28:43	\N
21486	659	2014-10-23 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04044E	2014-10-29 12:29:30	\N
22261	646	2014-11-19 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	77002U	2014-11-20 15:16:25	2015-01-30 15:14:01
22262	963	2014-11-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01031L	2014-11-20 15:16:38	\N
22263	599	2014-11-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	01031L	2014-11-20 15:16:38	2017-09-24 18:20:10
22297	599	2014-12-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11039M	2014-12-03 09:49:54	2017-09-24 18:16:52
22298	616	2014-12-02 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	89017R	2014-12-03 09:50:04	\N
22325	629	2014-11-27 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11064N	2014-12-10 10:39:42	\N
22326	596	2014-12-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11104D	2014-12-10 11:38:39	\N
22327	583	2014-12-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11104D	2014-12-10 11:38:39	\N
22328	609	2014-12-10 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14151M	2014-12-10 12:19:21	\N
22333	591	2014-12-11 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08055A	2014-12-12 10:20:34	2017-07-20 14:38:30
22363	634	2014-12-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14135M	2014-12-18 16:03:43	\N
22367	591	2014-12-18 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14065Q	2014-12-19 09:39:03	2017-07-20 14:38:10
22368	619	2014-12-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08031R	2014-12-19 09:39:27	2015-03-16 18:44:38
22978	908	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11023D	\N	2017-09-25 10:56:48
22406	978	2015-01-20 00:00:00	2015-05-06 00:00:00	ANCIEN	\N	\N	\N	92015P	2015-01-20 12:30:17	2015-05-11 17:08:32
22813	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14109K	\N	\N
22979	908	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01056V	\N	2017-09-24 17:04:02
23071	909	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11094U	\N	2017-09-24 13:25:54
23451	919	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14331P	\N	\N
23452	919	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
23453	910	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14331P	\N	\N
23815	598	2016-11-17 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	92045V	2016-11-18 09:41:45	2017-09-24 17:29:37
20216	992	2015-03-01 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	12039E	\N	\N
20217	992	2012-01-25 00:00:00	2014-05-04 00:00:00	ANCIEN	\N	\N	\N	12039E	\N	\N
20220	584	2013-11-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11113E	2013-12-13 15:10:32	2014-10-14 16:20:48
20240	938	2014-03-01 00:00:00	2014-09-30 00:00:00	ANCIEN	\N	\N	\N	11083R	2014-04-10 16:03:00	\N
21177	596	2014-10-24 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11042G	2014-10-24 14:17:12	\N
21178	619	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04080J	2014-10-24 14:19:00	2017-09-24 17:47:27
21179	674	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04080J	2014-10-24 14:19:00	\N
21180	608	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04080J	2014-10-24 14:19:00	\N
21181	584	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04080J	2014-10-24 14:19:00	\N
21182	661	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04080J	2014-10-24 14:19:00	\N
21183	556	2014-10-22 00:00:00	2015-01-13 00:00:00	ANCIEN	\N	\N	\N	04080J	2014-10-24 14:19:00	2015-01-14 10:00:40
21184	609	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04080J	2014-10-24 14:19:00	\N
21185	629	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04080J	2014-10-24 14:19:00	\N
21186	582	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	04080J	2014-10-24 14:19:00	\N
21187	577	2014-10-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14018U	2014-10-24 14:19:40	\N
21188	963	2014-10-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14018U	2014-10-24 14:19:40	\N
21189	589	2014-10-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14018U	2014-10-24 14:19:40	\N
21190	626	2014-10-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14018U	2014-10-24 14:19:40	\N
21191	598	2014-10-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14018U	2014-10-24 14:19:40	\N
21192	575	2014-10-20 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14018U	2014-10-24 14:19:40	\N
21193	571	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11081P	2014-10-24 14:21:32	\N
21194	592	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11068S	2014-10-24 14:22:06	\N
21195	633	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11068S	2014-10-24 14:22:06	\N
21196	634	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11068S	2014-10-24 14:22:06	\N
21197	586	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11068S	2014-10-24 14:22:06	\N
21198	571	2014-10-21 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11068S	2014-10-24 14:22:06	\N
21199	572	2014-10-22 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	05008E	2014-10-24 14:22:38	\N
22389	648	2015-01-15 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14227Q	2015-01-14 18:09:42	2015-01-15 15:10:48
22480	629	2015-01-30 00:00:00	2016-11-30 00:00:00	ANCIEN	\N	\N	\N	04048J	2015-01-30 09:40:01	2016-12-01 10:36:51
22971	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
22972	909	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	87003B	\N	\N
22976	908	2014-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11020A	\N	2017-09-24 16:24:51
22980	601	2015-02-05 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14059S	2015-03-02 17:08:20	2015-03-11 10:58:11
23166	906	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
23263	598	2015-05-07 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11039M	2015-05-19 09:37:59	2017-09-24 18:16:52
23405	911	2014-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	\N	\N
23484	CHRETORIENT	2016-02-12 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	2016-02-12 12:24:32	\N
23485	CHRETORIENT	2016-02-12 00:00:00	2023-10-05 00:00:00	ANCIEN	\N	\N	\N	10006L	2016-02-12 12:24:58	\N
23486	CHRETORIENT	2016-02-12 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	14041T	2016-02-12 12:25:01	\N
23487	CHRETORIENT	2016-02-12 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	08022Q	2016-02-12 12:25:04	2017-10-01 09:41:22
23488	CHRETORIENT	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	14217N	2016-02-12 12:25:11	\N
23489	CHRETORIENT	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	14215L	2016-02-12 12:25:14	\N
23490	CHRETORIENT	2016-02-12 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01015L	2016-02-12 12:25:18	2017-09-24 17:19:42
23491	CHRETORIENT	2016-02-12 00:00:00	2017-10-12 00:00:00	ANCIEN	\N	\N	\N	14042U	2016-02-12 12:25:24	2017-10-17 17:57:16
23492	CHRETORIENT	2016-02-12 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01027Q	2016-02-12 12:25:27	2017-09-24 17:28:55
34458	1010	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	21037D	\N	\N
23493	CHRETORIENT	2016-02-12 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11091R	2016-02-12 12:25:30	2017-09-24 18:17:56
23494	CHRETORIENT	2016-02-12 00:00:00	2020-10-19 00:00:00	ANCIEN	\N	\N	\N	87003B	2016-02-12 12:25:36	\N
23495	CHRETORIENT	2016-02-12 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	01041N	2016-02-12 12:25:44	2017-09-24 18:59:59
23496	CHRETORIENT	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	14187A	2016-02-12 12:25:52	\N
23497	CHRETORIENT	2016-02-12 00:00:00	2023-04-11 00:00:00	ANCIEN	\N	\N	\N	01025N	2016-02-12 12:25:58	\N
23498	CHRETORIENT	2016-02-12 00:00:00	2023-10-05 00:00:00	ANCIEN	\N	\N	\N	97011G	2016-02-12 12:26:06	\N
23499	CHRETORIENT	2016-02-12 00:00:00	2017-09-24 00:00:00	ANCIEN	\N	\N	\N	08065C	2016-02-12 12:26:09	2017-09-25 09:57:52
23500	CHRETORIENT	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	08018U	2016-02-12 12:26:14	\N
23501	CHRETORIENT	2016-02-12 00:00:00	2023-10-05 00:00:00	ANCIEN	\N	\N	\N	04035D	2016-02-12 12:26:17	\N
23503	CHRETORIENT	2016-02-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08056B	2016-02-12 12:28:40	\N
23504	CHRETORIENT	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	14211G	2016-02-12 12:28:57	\N
23505	CHRETORIENT	2016-02-12 00:00:00	2020-07-13 00:00:00	ANCIEN	\N	\N	\N	11049P	2016-02-12 12:29:04	\N
23506	CHRETORIENT	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	14026U	2016-02-12 12:29:28	\N
23507	CHRETORIENT	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	98022P	2016-02-12 12:31:00	\N
23508	CHRETORIENT	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	14179A	2016-02-12 12:31:10	\N
23509	CHRETORIENT	2016-02-12 00:00:00	2016-11-30 00:00:00	ANCIEN	\N	\N	\N	04048J	2016-02-12 12:31:23	2016-12-01 10:36:51
23510	CHRETORIENT	2016-02-12 00:00:00	2017-09-22 00:00:00	ANCIEN	\N	\N	\N	04041B	2016-02-12 12:31:30	2017-09-24 11:09:53
23511	CHRETORIENT	2016-02-12 00:00:00	2020-11-02 00:00:00	ANCIEN	\N	\N	\N	04097T	2016-02-12 12:31:36	\N
23512	CHRETORIENT	2016-02-12 00:00:00	2023-10-11 00:00:00	ANCIEN	\N	\N	\N	11048N	2016-02-12 12:31:41	\N
23513	CHRETORIENT	2016-02-12 00:00:00	2020-07-31 00:00:00	ANCIEN	\N	\N	\N	08044W	2016-02-12 12:31:47	\N
23514	CHRETORIENT	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	14097Y	2016-02-12 12:31:54	\N
23515	CHRETORIENT	2016-02-12 00:00:00	2020-10-16 00:00:00	ANCIEN	\N	\N	\N	95041E	2016-02-12 12:32:01	\N
23516	CHRETORIENT	2016-02-12 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11084S	2016-02-12 12:32:09	2017-09-24 19:25:10
23517	CHRETORIENT	2016-02-12 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	04036E	2016-02-12 12:32:14	2017-09-24 18:59:59
23518	CHRETORIENT	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	99004R	2016-02-12 12:32:21	\N
23519	CHRETORIENT	2016-02-12 00:00:00	2019-06-24 00:00:00	ANCIEN	\N	\N	\N	04061F	2016-02-12 12:32:30	\N
23520	CHRETORIENT	2016-02-12 00:00:00	2020-10-19 00:00:00	ANCIEN	\N	\N	\N	14061L	2016-02-12 12:32:35	\N
23521	CHRETORIENT	2016-02-12 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	04077P	2016-02-12 12:32:42	2017-09-24 17:47:27
23522	CHRETORIENT	2016-02-12 00:00:00	2020-11-02 00:00:00	ANCIEN	\N	\N	\N	04049K	2016-02-12 12:32:48	\N
23523	CHRETORIENT	2016-02-12 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	11111C	2016-02-12 12:32:58	2017-09-24 16:45:26
23524	CHRETORIENT	2016-02-12 00:00:00	2020-10-19 00:00:00	ANCIEN	\N	\N	\N	98005N	2016-02-12 12:33:05	\N
23525	CHRETORIENT	2016-02-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	08015R	2016-02-12 12:33:12	\N
23526	CHRETORIENT	2016-02-12 00:00:00	2023-10-05 00:00:00	ANCIEN	\N	\N	\N	11026G	2016-02-12 12:33:20	\N
23527	CHRETORIENT	2016-02-12 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	95035G	2016-02-12 12:33:27	2017-09-24 18:17:56
23528	CHRETORIENT	2016-02-12 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	92031P	2016-02-12 12:33:37	2017-09-24 18:16:52
23530	CHRETORIENT	2016-02-12 00:00:00	2020-10-19 00:00:00	ANCIEN	\N	\N	\N	08039A	2016-02-12 12:34:20	\N
25031	629	2017-11-02 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	95030B	2017-11-02 17:48:50	\N
25032	608	2017-11-02 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	95030B	2017-11-02 17:48:50	\N
25498	604	2017-11-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19651A	2017-11-30 09:48:11	\N
25499	651	2017-11-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14059S	2017-11-30 09:48:46	\N
25500	586	2017-11-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	2017-11-30 09:50:48	\N
25501	851	2017-11-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	98022P	2017-11-30 09:51:02	\N
25502	594	2017-11-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19563B	2017-11-30 09:51:49	\N
25503	580	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19563B	2017-11-30 09:52:56	\N
25504	575	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19563B	2017-11-30 09:52:56	\N
25505	661	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19563B	2017-11-30 09:53:57	\N
25506	573	2017-11-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	10015M	2017-11-30 09:54:13	\N
25507	616	2017-11-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	10015M	2017-11-30 09:54:13	\N
25534	599	2017-11-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08024S	2017-12-04 17:18:25	\N
25793	532	2017-12-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19685L	2018-01-10 17:08:20	\N
25928	909	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14213J	\N	\N
25930	909	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19611R	\N	\N
25933	909	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14205J	\N	\N
26127	928	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	11048N	\N	\N
26128	928	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08055A	\N	\N
26245	912	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14133K	\N	\N
26272	919	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	17589D	\N	\N
26460	918	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14195A	\N	\N
26463	918	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14197C	\N	\N
26467	918	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14103D	\N	\N
26556	933	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19667J	\N	\N
26620	934	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19569H	\N	\N
26737	617	2018-02-07 00:00:00	2020-09-29 00:00:00	ANCIEN	\N	\N	\N	04018C	2018-04-03 16:01:17	\N
26755	577	2018-05-02 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04043D	2018-05-03 18:24:45	\N
26910	934	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14103D	\N	\N
26911	934	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14221J	\N	\N
26978	674	2019-02-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19762G	\N	\N
26979	612	2019-02-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	\N	\N
27048	908	2019-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	19820Y	\N	\N
27088	979	2020-02-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
27106	624	2019-11-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
27159	608	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11080N	\N	\N
27160	598	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11080N	\N	\N
27334	634	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14030Q	\N	\N
27335	618	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14030Q	\N	\N
27336	617	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14030Q	\N	\N
27337	629	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14030Q	\N	\N
27338	663	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14030Q	\N	\N
27339	625	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14030Q	\N	\N
27340	641	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11064N	\N	\N
27341	642	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11064N	\N	\N
27342	597	2020-10-08 00:00:00	2021-03-02 00:00:00	ANCIEN	\N	\N	\N	11064N	\N	\N
27343	623	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11064N	\N	\N
27344	550	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11064N	\N	\N
27345	573	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11064N	\N	\N
27346	640	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19711U	\N	\N
27347	641	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19711U	\N	\N
27348	597	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19711U	\N	\N
27349	595	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19711U	\N	\N
27350	608	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19711U	\N	\N
27351	644	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19711U	\N	\N
27638	581	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
27639	629	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
27640	625	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
27641	592	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
27642	661	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
27643	640	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
27644	532	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
27645	604	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
27646	611	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
27647	556	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
27648	590	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
27649	599	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
27650	583	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
27651	550	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
27652	529	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
27653	674	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
27654	673	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
28227	643	2020-10-21 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
28228	978	2020-10-21 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
28229	572	2020-10-21 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
28230	619	2020-10-21 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
28231	584	2020-10-21 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
28232	576	2020-10-21 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
28233	583	2020-10-21 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
28234	591	2020-10-21 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
28235	598	2020-10-21 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
28236	604	2020-10-21 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
28237	602	2020-10-21 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
28238	579	2020-10-21 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
28239	589	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14327T	\N	\N
28240	598	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14327T	\N	\N
28241	595	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
28242	659	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
28243	584	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
28244	851	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
28245	588	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
28246	530	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
28247	574	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
28248	618	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
28249	661	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
28250	626	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
28251	573	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
28252	602	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
28253	622	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
28254	572	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
28255	590	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
28256	620	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
28257	583	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
28258	625	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
28401	578	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20084G	\N	\N
28402	663	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20084G	\N	\N
28403	612	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20084G	\N	\N
28404	586	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20084G	\N	\N
28405	573	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	95041E	\N	\N
28406	572	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	95041E	\N	\N
28407	643	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	95041E	\N	\N
28408	622	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	95041E	\N	\N
29027	673	2020-11-13 00:00:00	2023-09-28 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
29028	572	2020-11-13 00:00:00	2023-09-28 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
29029	612	2020-11-23 00:00:00	2023-09-28 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
29030	605	2020-11-23 00:00:00	2023-09-28 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
29031	852	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14225N	\N	\N
29511	908	2020-12-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19621T	\N	\N
29556	1005	2020-12-23 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
29660	907	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01058X	\N	\N
29661	948	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01058X	\N	\N
29734	909	2021-01-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19383Y	\N	\N
29735	919	2021-01-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19383Y	\N	\N
29736	907	2021-01-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19383Y	\N	\N
29746	919	2020-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14133K	\N	\N
29748	1005	2021-01-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	\N	\N
29757	532	2021-01-07 00:00:00	2022-07-03 00:00:00	ANCIEN	\N	\N	\N	19689Q	\N	\N
29758	644	2021-01-14 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	14041T	\N	\N
30211	918	2021-02-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20036X	\N	\N
30644	617	2022-06-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	\N	\N
31639	622	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19057M	\N	\N
31640	580	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19057M	\N	\N
31641	597	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19057M	\N	\N
31642	634	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19057M	\N	\N
31643	625	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19057M	\N	\N
31644	619	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19057M	\N	\N
31645	978	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19057M	\N	\N
31646	624	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21041Y	\N	\N
31751	573	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14229S	\N	\N
31752	612	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14229S	\N	\N
31753	641	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14229S	\N	\N
31754	621	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14229S	\N	\N
31755	620	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14229S	\N	\N
32000	596	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21058J	\N	\N
32022	622	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20110Q	\N	\N
32023	651	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20110Q	\N	\N
32028	979	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20172F	\N	\N
32141	623	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11064N	\N	\N
32177	623	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20138D	\N	\N
32187	585	2023-10-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20142Y	\N	\N
32188	625	2023-10-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20142Y	\N	\N
32189	621	2023-10-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20142Y	\N	\N
32190	602	2023-10-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20142Y	\N	\N
32191	601	2023-10-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21070E	\N	\N
32192	605	2023-10-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21070E	\N	\N
32193	673	2023-10-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21070E	\N	\N
32194	530	2023-10-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21070E	\N	\N
32195	534	2023-10-20 00:00:00	2023-10-20 00:00:00	ANCIEN	\N	\N	\N	21070E	\N	\N
32196	598	2023-10-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21070E	\N	\N
32197	629	2023-10-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21070E	\N	\N
32198	590	2023-10-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21070E	\N	\N
32219	643	2023-10-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19619A	\N	\N
32220	589	2023-10-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19619A	\N	\N
32224	597	2023-10-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19699S	\N	\N
32225	598	2023-10-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19699S	\N	\N
32226	622	2023-10-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19699S	\N	\N
32229	647	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20094J	\N	\N
32230	602	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20094J	\N	\N
32231	610	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20094J	\N	\N
32232	598	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20094J	\N	\N
32233	608	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20094J	\N	\N
32234	578	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20094J	\N	\N
32235	617	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20094J	\N	\N
32236	621	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20094J	\N	\N
32237	611	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20094J	\N	\N
32238	530	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20094J	\N	\N
32313	584	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20252E	\N	\N
32314	583	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20252E	\N	\N
32315	605	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20252E	\N	\N
32316	590	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20252E	\N	\N
32364	613	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20120S	\N	\N
32365	573	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20120S	\N	\N
32366	609	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20120S	\N	\N
32367	598	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20120S	\N	\N
32368	661	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20120S	\N	\N
32369	605	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20120S	\N	\N
32370	618	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20120S	\N	\N
32371	581	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20120S	\N	\N
32372	646	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20120S	\N	\N
32373	590	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20120S	\N	\N
32374	617	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20120S	\N	\N
32375	584	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20120S	\N	\N
32376	632	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20120S	\N	\N
32377	625	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20120S	\N	\N
32378	591	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20120S	\N	\N
32379	623	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20120S	\N	\N
32380	576	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20120S	\N	\N
32381	621	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20120S	\N	\N
32382	596	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20120S	\N	\N
32383	577	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20120S	\N	\N
32384	595	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20120S	\N	\N
32385	629	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20120S	\N	\N
32386	589	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20120S	\N	\N
32387	643	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20120S	\N	\N
32388	530	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20120S	\N	\N
32389	572	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20120S	\N	\N
32390	979	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20120S	\N	\N
32420	590	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11090Q	\N	\N
32421	598	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11090Q	\N	\N
32431	589	2023-10-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21031W	\N	\N
32607	592	2023-11-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20094J	\N	\N
32608	625	2023-11-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20094J	\N	\N
25474	529	2017-11-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	2017-11-29 09:42:14	\N
25475	613	2017-11-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	2017-11-29 09:42:14	\N
25476	673	2017-11-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	2017-11-29 09:42:44	\N
25477	640	2017-11-22 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	15447F	2017-11-29 09:43:03	\N
25478	592	2017-11-28 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	19731Y	2017-11-29 09:43:19	\N
25479	979	2017-11-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19525U	2017-11-29 09:43:36	\N
25480	599	2017-11-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19531S	2017-11-29 09:43:59	\N
25481	592	2017-11-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	2017-11-29 10:53:53	\N
25482	579	2017-11-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	2017-11-29 10:53:53	\N
25483	596	2017-11-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	2017-11-29 10:53:53	\N
25547	603	2017-12-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14151M	2017-12-06 09:45:40	\N
25794	674	2017-12-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19667J	2018-01-12 10:13:30	\N
25795	646	2017-12-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	2018-01-12 10:14:05	\N
25796	617	2018-01-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19699S	2018-01-12 10:14:28	\N
25797	609	2017-12-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14111D	2018-01-12 10:14:50	\N
25798	550	2017-12-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14111D	2018-01-12 10:14:50	\N
25799	578	2018-01-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14031R	2018-01-12 10:15:43	\N
25801	1007	2017-12-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08039A	\N	\N
25861	907	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08055A	\N	\N
25866	907	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	\N	\N
25868	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14329V	\N	\N
25870	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	18083K	\N	\N
25871	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
25872	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14357A	\N	\N
25873	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	17589D	\N	\N
25874	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19719D	\N	\N
25875	907	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	87003B	\N	\N
25876	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19507S	\N	\N
25877	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14187A	\N	\N
25878	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	\N	\N
25976	571	2018-01-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08052W	2018-01-22 11:40:31	\N
25977	582	2018-01-18 00:00:00	2019-03-08 00:00:00	ANCIEN	\N	\N	\N	04040A	2018-01-22 11:42:15	\N
25983	906	2017-09-29 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
26066	647	2018-01-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11045K	2018-01-25 14:48:01	\N
26070	633	2018-01-22 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08038Y	2018-01-25 14:48:23	\N
26071	647	2018-01-22 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08038Y	2018-01-25 14:48:23	\N
26072	571	2018-01-22 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08038Y	2018-01-25 14:48:23	\N
26075	578	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19659J	2018-01-25 14:48:40	\N
26149	909	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11097X	\N	\N
26206	1006	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19549D	\N	\N
26335	852	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19723Y	2018-02-08 09:50:33	\N
26336	623	2018-02-01 00:00:00	2018-06-19 00:00:00	ANCIEN	\N	\N	\N	19631V	2018-02-08 09:50:54	\N
26337	647	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04045F	2018-02-08 09:51:52	\N
26378	998	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19347U	\N	\N
26379	998	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14227Q	\N	\N
26388	911	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19467C	\N	\N
26391	911	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19507S	\N	\N
26392	911	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14249W	\N	\N
26397	911	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14026U	\N	\N
26398	911	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
26399	911	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04097T	\N	\N
26405	911	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19657G	\N	\N
26406	911	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14265W	\N	\N
26407	911	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
26557	933	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19333N	\N	\N
26610	612	2018-02-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14193X	2018-02-27 09:03:39	\N
26788	604	2018-06-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	95041E	\N	\N
26653	1008	2018-03-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
26656	1008	2018-03-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14038Y	\N	\N
26659	1008	2018-03-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19693L	\N	\N
26660	1008	2018-03-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08052W	\N	\N
26661	1008	2018-03-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08038Y	\N	\N
26667	1008	2018-03-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
26668	1008	2018-03-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19333N	\N	\N
26669	1008	2018-03-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19399H	\N	\N
26671	1008	2018-03-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19489J	\N	\N
26672	1008	2018-03-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19611R	\N	\N
26673	1008	2018-03-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14159V	\N	\N
26675	1008	2018-03-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19723Y	\N	\N
26676	1008	2018-03-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19711U	\N	\N
26677	1008	2018-03-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
26678	1008	2018-03-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08039A	\N	\N
26679	1008	2018-03-07 00:00:00	2018-04-13 00:00:00	ANCIEN	\N	\N	\N	19483C	\N	2018-04-13 17:54:29
26680	1008	2018-03-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11077T	\N	\N
26689	1008	2018-03-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08049C	\N	\N
26691	1008	2018-03-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14173T	\N	\N
26895	572	2018-11-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19563B	\N	\N
26896	963	2018-11-07 00:00:00	2019-06-30 00:00:00	ANCIEN	\N	\N	\N	08021P	\N	\N
26950	934	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19631V	\N	\N
27031	911	2019-07-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
27034	907	2019-09-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	19812Y	\N	\N
29462	922	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
29463	922	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20038A	\N	\N
29464	922	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20100N	\N	\N
29465	922	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19820Y	\N	\N
29495	919	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19369B	\N	\N
29664	911	2021-01-12 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20022R	\N	\N
29830	1004	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19663E	\N	\N
30149	1005	2021-02-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11099A	\N	\N
30153	1007	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19749K	\N	\N
30217	934	2020-10-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19585H	\N	\N
30501	648	2022-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20024T	\N	\N
30621	581	2022-05-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19673G	\N	\N
30675	659	2022-09-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14249W	\N	\N
30691	641	2022-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19551W	\N	\N
31290	646	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19447X	\N	\N
32513	589	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21040X	\N	\N
32682	612	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20058E	\N	\N
32683	632	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14097Y	\N	\N
32684	612	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14097Y	\N	\N
28266	573	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20146D	\N	\N
28372	583	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19637C	\N	\N
28373	659	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19637C	\N	\N
28374	621	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19637C	\N	\N
28375	612	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19421M	\N	\N
28376	673	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20136B	\N	\N
28377	534	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20136B	\N	\N
28378	579	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20136B	\N	\N
28379	589	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20136B	\N	\N
28380	595	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20136B	\N	\N
28381	674	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20136B	\N	\N
28382	634	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11109J	\N	\N
28383	642	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11109J	\N	\N
28384	632	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11109J	\N	\N
28385	651	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14275Y	\N	\N
28386	595	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14275Y	\N	\N
28387	578	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14275Y	\N	\N
28388	626	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14275Y	\N	\N
28389	627	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	\N	\N
28390	550	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14038Y	\N	\N
28391	622	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14038Y	\N	\N
28868	594	2020-11-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14221J	\N	\N
28869	603	2020-10-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11072N	\N	\N
29054	609	2020-11-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	\N	\N
29055	605	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
29056	604	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14193X	\N	\N
29057	612	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19762G	\N	\N
29058	588	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19762G	\N	\N
29059	588	2020-11-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14259Y	\N	\N
29060	592	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
29418	948	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11099A	\N	\N
29422	948	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20044X	\N	\N
29443	909	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14097Y	\N	\N
29522	948	2020-12-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
29524	911	2020-12-18 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14173T	\N	\N
29525	908	2020-12-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19489J	\N	\N
29593	909	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11097X	\N	\N
29594	948	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11097X	\N	\N
29648	909	2021-01-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11012A	\N	\N
29665	919	2021-01-12 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20022R	\N	\N
29723	918	2021-01-12 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	17367Q	\N	\N
29870	1007	2020-10-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20180F	\N	\N
29872	1007	2020-10-01 00:00:00	2026-03-01 00:00:00	ACTIF	\N	\N	\N	14059S	\N	\N
29873	1007	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	08012N	\N	\N
29874	1007	2020-10-01 00:00:00	2026-03-01 00:00:00	ACTIF	\N	\N	\N	14147R	\N	\N
29876	1007	2020-10-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19479G	\N	\N
29994	601	2021-01-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08009T	\N	\N
30015	1006	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14179A	\N	\N
30074	601	2021-01-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20120S	\N	\N
30075	661	2021-01-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20120S	\N	\N
30076	581	2021-01-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20120S	\N	\N
30077	619	2021-01-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	\N	\N
30078	619	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14281W	\N	\N
30080	644	2021-01-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04033B	\N	\N
30094	948	2021-02-02 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14219Q	\N	\N
30102	1010	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	\N	\N
30103	1010	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14357A	\N	\N
30104	1010	2021-02-03 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	04086Q	\N	\N
30129	1010	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19766L	\N	\N
30140	1010	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19671E	\N	\N
30230	911	2021-03-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14059S	\N	\N
30231	948	2021-03-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14059S	\N	\N
30292	1011	2021-03-25 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20124W	\N	\N
30293	1011	2021-03-25 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20038A	\N	\N
30294	1011	2021-03-25 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14033T	\N	\N
30295	1011	2021-03-25 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14026U	\N	\N
30296	1011	2021-03-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19685L	\N	\N
30297	1011	2021-03-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19333N	\N	\N
30322	579	2021-04-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	\N	\N
30329	603	2021-05-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20100N	\N	\N
30339	1012	2021-06-09 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	08015R	\N	\N
30420	550	2021-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19251M	\N	\N
30421	571	2021-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19251M	\N	\N
30509	1013	2022-01-21 00:00:00	2022-01-21 00:00:00	ANCIEN	\N	\N	\N	17737W	\N	\N
30519	640	2022-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14259Y	\N	\N
30610	933	2022-03-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19251M	\N	\N
30671	603	2021-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20126Y	\N	\N
30824	617	2023-05-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19711U	\N	\N
30865	1013	2023-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20026V	\N	\N
30869	578	2023-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20026V	\N	\N
30870	583	2023-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20026V	\N	\N
30871	634	2023-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20026V	\N	\N
30872	590	2023-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20026V	\N	\N
30875	626	2023-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20026V	\N	\N
30876	663	2023-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20026V	\N	\N
31592	618	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21090J	\N	\N
31593	590	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21090J	\N	\N
31594	578	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21090J	\N	\N
31596	598	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21090J	\N	\N
31597	581	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21090J	\N	\N
31606	621	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04042C	\N	\N
31607	629	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04042C	\N	\N
31608	641	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04042C	\N	\N
31609	851	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04042C	\N	\N
31610	598	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04042C	\N	\N
31611	605	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04042C	\N	\N
32201	610	2023-10-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14151M	\N	\N
32202	590	2023-10-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14151M	\N	\N
32203	659	2023-10-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14151M	\N	\N
32204	609	2023-10-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14151M	\N	\N
32205	612	2023-10-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14151M	\N	\N
32206	574	2023-10-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14151M	\N	\N
32207	584	2023-10-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14151M	\N	\N
32277	642	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19611R	\N	\N
32278	589	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11053K	\N	\N
25288	629	2017-11-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	07029T	2017-11-17 09:53:33	\N
25289	573	2017-11-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14034U	2017-11-17 09:55:19	\N
25290	620	2017-11-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14034U	2017-11-17 09:55:19	\N
25291	628	2017-11-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14034U	2017-11-17 09:55:20	\N
25292	583	2017-11-15 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	2017-11-17 09:55:56	\N
25293	574	2017-11-15 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	2017-11-17 09:55:56	\N
25294	643	2017-11-15 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	2017-11-17 09:55:56	\N
25295	629	2017-11-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11041F	2017-11-17 09:56:25	\N
25296	556	2017-11-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11041F	2017-11-17 09:56:25	\N
25297	573	2017-11-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11041F	2017-11-17 09:56:25	\N
25298	598	2017-11-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11041F	2017-11-17 09:56:25	\N
25299	621	2017-11-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11041F	2017-11-17 09:56:25	\N
25300	599	2017-11-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14159V	2017-11-17 09:56:41	\N
25301	618	2017-11-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19421M	2017-11-17 09:57:01	\N
25302	657	2017-11-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19421M	2017-11-17 09:57:01	\N
25303	608	2017-11-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19421M	2017-11-17 09:57:01	\N
25304	622	2017-11-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19421M	2017-11-17 09:57:01	\N
25305	609	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	16685X	2017-11-17 09:57:22	\N
25306	626	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	16685X	2017-11-17 09:57:22	\N
25307	584	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	16685X	2017-11-17 09:57:22	\N
25308	589	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	2017-11-17 09:57:42	\N
25309	556	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	2017-11-17 09:57:42	\N
25310	978	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	2017-11-17 09:57:42	\N
25311	663	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	2017-11-17 09:57:42	\N
25312	601	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	2017-11-17 09:57:42	\N
25528	661	2017-11-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	98029W	2017-12-04 09:34:28	\N
25767	579	2017-12-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14259Y	2017-12-26 10:23:01	\N
25768	534	2017-12-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14259Y	2017-12-26 10:23:57	\N
25769	579	2017-12-22 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14249W	2017-12-26 10:24:55	\N
25770	580	2017-12-22 00:00:00	2020-06-27 00:00:00	ANCIEN	\N	\N	\N	14199E	2017-12-26 10:25:09	\N
25771	615	2017-12-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11041F	2017-12-26 10:25:26	\N
25820	609	2018-01-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04008A	2018-01-16 12:41:24	2018-01-17 12:24:00
26045	934	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19725B	\N	\N
26342	1005	2018-01-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14105F	\N	\N
26536	852	2018-02-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14061L	2018-02-15 09:45:38	\N
26538	648	2018-02-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08031R	2018-02-15 10:14:53	\N
26539	646	2018-02-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14157T	2018-02-15 10:15:10	\N
26540	584	2018-02-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19725B	2018-02-15 10:15:54	\N
26967	907	2019-02-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14111D	\N	\N
26974	906	2019-02-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
26975	909	2019-02-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
26984	1005	2019-02-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19693L	\N	\N
27004	934	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19251M	\N	\N
27087	583	2020-01-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
27330	623	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14031R	\N	\N
27331	578	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14031R	\N	\N
27332	621	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14031R	\N	\N
27333	663	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14031R	\N	\N
27352	599	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17589D	\N	\N
27353	580	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17589D	\N	\N
27354	584	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14257W	\N	\N
27355	590	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14257W	\N	\N
27356	963	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14257W	\N	\N
27357	604	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20074E	\N	\N
27358	673	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20074E	\N	\N
27359	580	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20074E	\N	\N
27360	610	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20074E	\N	\N
27361	591	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20074E	\N	\N
27362	673	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19703U	\N	\N
27363	963	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19703U	\N	\N
27364	651	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19565D	\N	\N
27365	598	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19565D	\N	\N
27366	642	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19565D	\N	\N
27367	550	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19565D	\N	\N
27368	594	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20062A	\N	\N
27369	529	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20062A	\N	\N
27370	629	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20062A	\N	\N
27371	578	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20062A	\N	\N
27372	663	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20062A	\N	\N
27488	673	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14105F	\N	\N
27489	596	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14105F	\N	\N
27490	673	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19675J	\N	\N
27491	590	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19675J	\N	\N
27492	621	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19675J	\N	\N
27493	602	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19675J	\N	\N
27494	625	2020-10-12 00:00:00	2021-09-20 00:00:00	ANCIEN	\N	\N	\N	11067R	\N	\N
27495	602	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11067R	\N	\N
27496	592	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
27497	604	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
27498	618	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
27499	629	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
27500	621	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
27501	979	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
27502	580	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
27503	610	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
27504	595	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
27505	979	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14221J	\N	\N
27506	661	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14221J	\N	\N
27507	588	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14267Y	\N	\N
27508	573	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14267Y	\N	\N
27509	584	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08073C	\N	\N
27510	642	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08073C	\N	\N
27511	576	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08073C	\N	\N
27512	979	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08073C	\N	\N
27513	573	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08073C	\N	\N
27881	600	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17737W	\N	\N
27882	659	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17737W	\N	\N
27883	595	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17737W	\N	\N
27884	641	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17737W	\N	\N
28581	591	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20028X	\N	\N
28582	577	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20028X	\N	\N
28583	583	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19735D	\N	\N
28584	602	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19735D	\N	\N
28585	617	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19735D	\N	\N
28586	590	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19735D	\N	\N
28587	643	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19735D	\N	\N
28588	596	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19735D	\N	\N
28589	621	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19735D	\N	\N
28590	625	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19735D	\N	\N
28591	604	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19735D	\N	\N
28592	581	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19735D	\N	\N
28593	602	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20064C	\N	\N
28594	589	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20064C	\N	\N
28595	596	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20064C	\N	\N
28596	598	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20064C	\N	\N
28597	641	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20064C	\N	\N
28598	573	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20064C	\N	\N
28599	534	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20064C	\N	\N
28600	674	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20064C	\N	\N
28601	577	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20064C	\N	\N
28602	583	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20064C	\N	\N
28603	851	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20064C	\N	\N
28604	978	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20064C	\N	\N
28605	629	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20064C	\N	\N
28606	608	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20064C	\N	\N
28607	591	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20064C	\N	\N
28608	642	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20064C	\N	\N
28609	556	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20064C	\N	\N
28610	604	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20064C	\N	\N
28611	852	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20064C	\N	\N
28612	979	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20064C	\N	\N
28613	580	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20064C	\N	\N
28614	598	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19758L	\N	\N
28615	576	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19758L	\N	\N
28616	646	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14071N	\N	\N
28617	622	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14071N	\N	\N
28618	588	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14071N	\N	\N
28619	616	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20058E	\N	\N
28620	597	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20058E	\N	\N
28621	640	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20058E	\N	\N
28622	579	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20058E	\N	\N
28623	625	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20058E	\N	\N
28624	573	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	\N	\N
28625	851	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	\N	\N
28626	609	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	\N	\N
28627	530	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	\N	\N
28628	604	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	\N	\N
28629	626	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	\N	\N
28630	610	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	\N	\N
28631	584	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	\N	\N
28632	616	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	\N	\N
28633	598	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	\N	\N
28634	589	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	\N	\N
28635	574	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	\N	\N
28636	618	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	\N	\N
28637	590	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	\N	\N
28638	608	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	\N	\N
28639	596	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	\N	\N
28640	532	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	\N	\N
28641	852	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	\N	\N
28642	572	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	\N	\N
28643	576	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	\N	\N
28644	581	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	\N	\N
28645	611	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	\N	\N
28646	592	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	\N	\N
28647	598	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20070A	\N	\N
28648	573	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20070A	\N	\N
28649	643	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20070A	\N	\N
28650	673	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20040T	\N	\N
28651	632	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20040T	\N	\N
28652	576	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20040T	\N	\N
28988	640	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
28989	851	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19553Y	\N	\N
28990	640	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19553Y	\N	\N
29530	909	2020-12-21 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14038Y	\N	\N
29771	583	2021-01-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
30014	918	2021-01-26 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
30716	534	2022-11-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11064N	\N	\N
30909	596	2023-10-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17229F	\N	\N
30910	530	2023-10-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17229F	\N	\N
30911	626	2023-10-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17229F	\N	\N
30912	582	2023-10-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17229F	\N	\N
30913	673	2023-10-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17229F	\N	\N
30914	573	2023-10-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17229F	\N	\N
30915	577	2023-10-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17229F	\N	\N
30916	572	2023-10-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17229F	\N	\N
30917	598	2023-10-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17229F	\N	\N
30918	609	2023-10-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17229F	\N	\N
30919	590	2023-10-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17229F	\N	\N
30920	578	2023-10-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17229F	\N	\N
30921	641	2023-10-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17229F	\N	\N
30922	622	2023-10-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17229F	\N	\N
31568	595	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	99004R	\N	\N
31569	598	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	99004R	\N	\N
31598	598	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11085T	\N	\N
31599	629	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11085T	\N	\N
31600	621	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11085T	\N	\N
31601	584	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11085T	\N	\N
31602	641	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11085T	\N	\N
31603	1013	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11085T	\N	\N
31604	595	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11085T	\N	\N
31605	532	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11085T	\N	\N
32064	629	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19111A	\N	\N
32065	590	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19111A	\N	\N
32066	595	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19111A	\N	\N
32067	1013	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19111A	\N	\N
25150	577	2017-11-08 00:00:00	2020-07-13 00:00:00	ANCIEN	\N	\N	\N	11049P	2017-11-08 16:07:38	\N
25151	626	2017-11-08 00:00:00	2020-07-13 00:00:00	ANCIEN	\N	\N	\N	11049P	2017-11-08 16:07:38	\N
25152	598	2017-11-08 00:00:00	2020-07-13 00:00:00	ANCIEN	\N	\N	\N	11049P	2017-11-08 16:07:38	\N
25153	620	2017-11-08 00:00:00	2020-07-13 00:00:00	ANCIEN	\N	\N	\N	11049P	2017-11-08 16:07:38	\N
25154	595	2017-11-08 00:00:00	2020-07-13 00:00:00	ANCIEN	\N	\N	\N	11049P	2017-11-08 16:07:38	\N
25155	575	2017-11-08 00:00:00	2020-07-13 00:00:00	ANCIEN	\N	\N	\N	11049P	2017-11-08 16:07:38	\N
25573	604	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	2017-12-07 18:14:06	\N
25574	625	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	2017-12-07 18:14:06	\N
25575	583	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	2017-12-07 18:14:06	\N
25576	619	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	2017-12-07 18:14:06	\N
25577	640	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	2017-12-07 18:14:06	\N
25578	590	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	2017-12-07 18:14:06	\N
25579	608	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	2017-12-07 18:14:06	\N
25580	663	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	2017-12-07 18:14:06	\N
25581	646	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	2017-12-07 18:14:06	\N
25582	584	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	2017-12-07 18:14:06	\N
25583	576	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	2017-12-07 18:14:06	\N
25584	623	2017-12-06 00:00:00	2020-02-27 00:00:00	ANCIEN	\N	\N	\N	14071N	2017-12-07 18:22:18	\N
25585	572	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14071N	2017-12-07 18:22:18	\N
25586	613	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14071N	2017-12-07 18:22:18	\N
25587	619	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14071N	2017-12-07 18:22:18	\N
25588	629	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14071N	2017-12-07 18:22:18	\N
25589	659	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14071N	2017-12-07 18:22:18	\N
25590	588	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14071N	2017-12-07 18:22:18	\N
25591	673	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14071N	2017-12-07 18:22:18	\N
25592	609	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14071N	2017-12-07 18:22:18	\N
25593	584	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14071N	2017-12-07 18:22:18	\N
25881	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
25907	909	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19515S	\N	\N
25908	909	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08055A	\N	\N
25909	909	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
25910	909	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	\N	\N
25912	909	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08024S	\N	\N
26249	998	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11077T	\N	\N
26566	933	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14038Y	\N	\N
26579	933	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19569H	\N	\N
26590	934	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19301E	\N	\N
26728	585	2018-03-15 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08038Y	2018-03-28 17:07:52	\N
26800	643	2018-06-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
26801	556	2018-06-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
26802	578	2018-06-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
29575	1005	2020-12-28 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20062A	\N	\N
30038	909	2021-01-26 00:00:00	2022-12-31 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
30141	1010	2021-02-03 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14071N	\N	\N
30770	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	08047A	\N	\N
30790	1014	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19735D	\N	\N
30802	948	2023-01-31 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20980G	\N	\N
30805	CHRETORIENT	2023-02-09 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	19673G	\N	\N
30832	1006	2023-05-04 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20264J	\N	\N
31363	673	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20138D	\N	\N
31364	596	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20138D	\N	\N
31365	621	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20138D	\N	\N
31366	609	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20138D	\N	\N
31367	590	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20138D	\N	\N
31368	597	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20138D	\N	\N
31369	595	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20138D	\N	\N
32340	596	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19735D	\N	\N
32341	581	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19735D	\N	\N
32342	625	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19735D	\N	\N
32343	583	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19735D	\N	\N
32344	590	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19735D	\N	\N
32396	622	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20042V	\N	\N
32397	573	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20042V	\N	\N
32398	595	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20042V	\N	\N
32399	591	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20042V	\N	\N
32400	556	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20042V	\N	\N
32424	623	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14219Q	\N	\N
32568	641	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20134Y	\N	\N
32569	632	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20134Y	\N	\N
32570	623	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20134Y	\N	\N
32571	597	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20134Y	\N	\N
32572	530	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20134Y	\N	\N
32685	596	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14097Y	\N	\N
32686	608	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14097Y	\N	\N
32687	584	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14097Y	\N	\N
32688	963	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14097Y	\N	\N
32689	534	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14097Y	\N	\N
32690	621	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14097Y	\N	\N
32691	625	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14097Y	\N	\N
32692	579	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14097Y	\N	\N
32693	629	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14097Y	\N	\N
32694	851	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14097Y	\N	\N
32695	979	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14097Y	\N	\N
32696	581	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14097Y	\N	\N
32697	619	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14097Y	\N	\N
32767	604	2023-11-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20126Y	\N	\N
32768	610	2023-11-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20126Y	\N	\N
32769	623	2023-11-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20126Y	\N	\N
32770	579	2023-11-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20126Y	\N	\N
32771	609	2023-11-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20126Y	\N	\N
32772	651	2023-11-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20126Y	\N	\N
32773	598	2023-11-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20126Y	\N	\N
32774	CHRETORIENT	2023-11-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20126Y	\N	\N
32775	583	2023-11-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20126Y	\N	\N
32776	625	2023-11-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20126Y	\N	\N
32777	592	2023-11-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20126Y	\N	\N
32778	979	2023-11-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20126Y	\N	\N
32779	663	2023-11-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20126Y	\N	\N
32780	643	2023-11-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20126Y	\N	\N
33102	609	2023-11-22 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19693L	\N	\N
29642	918	2020-12-18 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14033T	\N	\N
29643	911	2021-01-04 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14109K	\N	\N
29770	908	2021-01-18 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20114U	\N	\N
29792	1008	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
29793	1008	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
29794	1008	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19820Y	\N	\N
29795	1008	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19387D	\N	\N
29796	1008	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20128B	\N	\N
29797	1008	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20048C	\N	\N
29798	1008	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19333N	\N	\N
29975	907	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11080N	\N	\N
30147	1008	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20106U	\N	\N
30205	934	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20096L	\N	\N
30347	919	2021-06-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19333N	\N	\N
30741	1014	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08045X	\N	\N
30752	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	19760E	\N	\N
30776	1014	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19719D	\N	\N
31771	608	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	95041E	\N	\N
31772	622	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	95041E	\N	\N
31773	573	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	95041E	\N	\N
31774	556	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19713W	\N	\N
31775	530	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19713W	\N	\N
31776	600	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19713W	\N	\N
31777	851	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19713W	\N	\N
32150	632	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14249W	\N	\N
32279	599	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11053K	\N	\N
32280	598	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11053K	\N	\N
32281	590	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11053K	\N	\N
32282	612	2023-10-24 00:00:00	2023-12-04 00:00:00	ANCIEN	\N	\N	\N	14259Y	\N	\N
32283	584	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14259Y	\N	\N
32284	621	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14259Y	\N	\N
32285	579	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14259Y	\N	\N
32286	651	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14259Y	\N	\N
32287	641	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14259Y	\N	\N
32716	661	2023-07-10 00:00:00	2023-11-03 00:00:00	ANCIEN	\N	\N	\N	20086J	\N	\N
32756	613	2023-11-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20252E	\N	\N
32758	612	2023-11-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19057M	\N	\N
32759	591	2023-11-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19057M	\N	\N
32829	641	2023-11-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21083K	\N	\N
32830	609	2023-11-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14097Y	\N	\N
32835	615	2023-11-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21075K	\N	\N
32836	618	2023-11-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21075K	\N	\N
32837	532	2023-11-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21075K	\N	\N
32838	529	2023-11-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21075K	\N	\N
32839	597	2023-11-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21075K	\N	\N
32840	643	2023-11-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21075K	\N	\N
32841	640	2023-11-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21075K	\N	\N
32842	628	2023-11-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21075K	\N	\N
32843	612	2023-11-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21084L	\N	\N
32844	534	2023-11-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21084L	\N	\N
32845	598	2023-11-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21084L	\N	\N
32846	661	2023-11-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21084L	\N	\N
32847	625	2023-11-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21084L	\N	\N
32848	556	2023-11-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21084L	\N	\N
32849	632	2023-11-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21084L	\N	\N
32850	573	2023-11-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21084L	\N	\N
32905	588	2023-11-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21041Y	\N	\N
33034	612	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14187A	\N	\N
33067	613	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14071N	\N	\N
33072	673	2023-11-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14329V	\N	\N
33086	583	2023-11-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11040E	\N	\N
33087	598	2023-11-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11040E	\N	\N
33476	529	2024-01-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21052C	\N	\N
33537	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19723Y	\N	\N
33538	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14169X	\N	\N
33569	1004	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	19723Y	\N	\N
33570	1004	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	14223L	\N	\N
33694	1006	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21077M	\N	\N
33706	647	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21057H	\N	\N
34133	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14329V	\N	\N
34246	621	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20140W	\N	\N
34249	657	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17023S	\N	\N
34271	640	2024-01-30 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19647E	\N	\N
34397	933	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	19669L	\N	\N
34398	933	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	14173T	\N	\N
34406	919	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	01058X	\N	\N
34407	907	2023-12-14 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	01058X	\N	\N
34441	918	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	20066E	\N	\N
34471	613	2024-03-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14169X	\N	\N
34484	577	2024-03-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20098N	\N	\N
34500	1007	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	21059K	\N	\N
25455	604	2017-11-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14357A	2017-11-24 16:57:32	\N
25456	613	2017-11-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2017-11-24 16:59:33	\N
25457	608	2017-11-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2017-11-24 16:59:33	\N
25458	653	2017-11-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2017-11-24 16:59:33	\N
25459	604	2017-11-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2017-11-24 16:59:33	\N
25460	605	2017-11-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	07033P	2017-11-24 16:59:48	\N
25958	588	2018-01-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14261S	2018-01-18 15:15:57	\N
25959	578	2018-01-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14065Q	2018-01-18 15:16:09	\N
25960	615	2018-01-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	2018-01-18 15:16:20	\N
25961	550	2018-01-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14241N	2018-01-18 15:16:51	\N
25962	615	2018-01-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14073Q	2018-01-18 15:17:05	\N
26119	556	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14133K	2018-01-26 09:28:38	\N
26120	616	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19549D	2018-01-26 09:29:43	\N
26121	610	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	2018-01-26 09:30:06	\N
26122	582	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	2018-01-26 09:30:24	\N
26123	616	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	2018-01-26 09:30:24	\N
26124	602	2018-01-17 00:00:00	2020-06-24 00:00:00	ANCIEN	\N	\N	\N	19727D	2018-01-26 09:30:42	\N
26328	629	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04033B	2018-02-07 15:28:32	2018-02-07 15:31:58
26329	615	2018-02-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04033B	2018-02-07 15:28:32	\N
26413	911	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	19269X	\N	\N
26415	911	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04044E	\N	\N
26958	588	2019-01-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	19794Q	\N	\N
26959	571	2019-01-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	19794Q	\N	\N
27011	608	2019-04-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	19253P	\N	\N
27058	1004	2020-01-01 00:00:00	2023-12-31 00:00:00	ANCIEN	\N	\N	\N	19798U	\N	\N
27885	608	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17737W	\N	\N
27886	629	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17737W	\N	\N
27887	CHRETORIENT	2020-10-16 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	17737W	\N	\N
27888	576	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19565D	\N	\N
27889	573	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	05008E	\N	\N
27890	625	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	05008E	\N	\N
27891	646	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	05008E	\N	\N
27892	584	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	05008E	\N	\N
27893	629	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	05008E	\N	\N
27894	583	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08060W	\N	\N
27895	574	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08060W	\N	\N
27896	651	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08060W	\N	\N
27897	590	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11053K	\N	\N
27898	589	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11053K	\N	\N
27899	608	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11053K	\N	\N
27900	598	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11053K	\N	\N
28259	651	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
28260	571	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
28261	978	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
28262	979	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
28263	600	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
28264	598	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
28265	597	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
29092	592	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19611R	\N	\N
29093	659	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
29094	643	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14225N	\N	\N
29095	632	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19551W	\N	\N
29096	673	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
29097	592	2020-11-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
29099	604	2020-11-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
29100	646	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11090Q	\N	\N
29101	572	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20038A	\N	\N
29263	918	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20044X	\N	\N
29482	909	2020-12-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19549D	\N	\N
29554	608	2020-12-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19713W	\N	\N
29588	1005	2020-12-21 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20088L	\N	\N
29759	909	2021-01-07 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20110Q	\N	\N
30482	597	2021-11-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14189C	\N	\N
30534	616	2022-03-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14089Y	\N	\N
30565	530	2022-03-31 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14281W	\N	\N
30616	530	2022-04-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14042U	\N	\N
30661	659	2022-09-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20052X	\N	\N
30674	633	2020-12-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14038Y	\N	\N
30758	1007	2020-10-01 00:00:00	2026-03-01 00:00:00	ACTIF	\N	\N	\N	20140W	\N	\N
31324	589	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14223L	\N	\N
31325	601	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14223L	\N	\N
31326	629	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14223L	\N	\N
31327	963	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14223L	\N	\N
31328	530	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14223L	\N	\N
31329	595	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14223L	\N	\N
32415	600	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21061D	\N	\N
32416	621	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21061D	\N	\N
32417	530	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21061D	\N	\N
32418	596	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21061D	\N	\N
32419	590	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21061D	\N	\N
32425	596	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21029D	\N	\N
32426	653	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21029D	\N	\N
32427	663	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21029D	\N	\N
32428	CHRETORIENT	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21029D	\N	\N
32429	651	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21029D	\N	\N
32430	578	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21029D	\N	\N
32662	628	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08061X	\N	\N
32663	595	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08061X	\N	\N
32664	615	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08061X	\N	\N
33157	574	2023-11-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21037D	\N	\N
33169	616	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19569H	\N	\N
33170	653	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19569H	\N	\N
33212	642	2023-11-30 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	10015M	\N	\N
33224	642	2023-12-01 00:00:00	2023-12-04 00:00:00	ANCIEN	\N	\N	\N	14259Y	\N	\N
33242	584	2023-12-04 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20264J	\N	\N
33244	592	2023-12-04 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14169X	\N	\N
33245	642	2023-12-04 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14169X	\N	\N
33466	529	2024-01-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21046E	\N	\N
33521	576	2024-01-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21077M	\N	\N
33522	596	2024-01-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21077M	\N	\N
33531	619	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20136B	\N	\N
33707	934	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21095P	\N	\N
28428	632	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	\N	\N
28429	556	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	\N	\N
28430	608	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	\N	\N
28431	595	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	\N	\N
28432	602	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	\N	\N
28433	584	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	\N	\N
28434	589	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	\N	\N
28435	978	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	\N	\N
28436	601	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	\N	\N
28437	572	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	\N	\N
28438	574	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	\N	\N
28439	590	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	\N	\N
28440	648	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	\N	\N
28441	597	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	\N	\N
28442	604	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	\N	\N
28443	573	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	\N	\N
28444	596	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	\N	\N
28445	575	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	\N	\N
28446	632	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04059M	\N	\N
28447	598	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04059M	\N	\N
28448	576	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04059M	\N	\N
28449	585	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04059M	\N	\N
28450	595	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04059M	\N	\N
28451	621	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04059M	\N	\N
28452	591	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04059M	\N	\N
28453	978	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04059M	\N	\N
28454	596	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04059M	\N	\N
28779	621	2020-10-16 00:00:00	2021-12-07 00:00:00	ANCIEN	\N	\N	\N	19521Q	\N	\N
28780	608	2020-10-16 00:00:00	2021-12-07 00:00:00	ANCIEN	\N	\N	\N	19521Q	\N	\N
28781	581	2020-10-16 00:00:00	2021-12-07 00:00:00	ANCIEN	\N	\N	\N	19521Q	\N	\N
28782	622	2020-10-16 00:00:00	2021-12-07 00:00:00	ANCIEN	\N	\N	\N	19521Q	\N	\N
28783	583	2020-10-16 00:00:00	2021-12-07 00:00:00	ANCIEN	\N	\N	\N	19521Q	\N	\N
28784	602	2020-10-16 00:00:00	2021-12-07 00:00:00	ANCIEN	\N	\N	\N	19521Q	\N	\N
28785	617	2020-10-29 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	04086Q	\N	\N
28786	613	2020-10-29 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	04086Q	\N	\N
29478	922	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19701S	\N	\N
29580	998	2020-12-28 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20018V	\N	\N
29680	907	2021-01-11 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20116W	\N	\N
29717	1005	2021-01-13 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20064C	\N	\N
29718	907	2021-01-13 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20064C	\N	\N
29979	919	2021-01-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19679N	\N	\N
30095	1010	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19515S	\N	\N
30096	1010	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	05008E	\N	\N
30097	1010	2021-02-03 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
30098	1010	2021-02-03 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
30099	1010	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11080N	\N	\N
30151	934	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19725B	\N	\N
30345	1012	2021-06-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14331P	\N	\N
30693	906	2022-10-06 00:00:00	2023-10-04 00:00:00	ANCIEN	\N	\N	\N	20096L	\N	\N
30734	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	19591F	\N	\N
32068	641	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19111A	\N	\N
32069	530	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19111A	\N	\N
32070	604	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19111A	\N	\N
32071	591	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19111A	\N	\N
32088	575	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20084G	\N	\N
32089	572	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20084G	\N	\N
32090	556	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20084G	\N	\N
32091	661	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20084G	\N	\N
32092	641	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20084G	\N	\N
32093	578	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20084G	\N	\N
32094	651	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20084G	\N	\N
32095	586	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20084G	\N	\N
32096	615	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20084G	\N	\N
32097	612	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20084G	\N	\N
32098	613	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20084G	\N	\N
32099	663	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20084G	\N	\N
32100	571	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20084G	\N	\N
32101	573	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20084G	\N	\N
32175	583	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	15197G	\N	\N
32176	573	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	15197G	\N	\N
32609	605	2023-11-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20094J	\N	\N
32610	600	2023-11-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20094J	\N	\N
32668	534	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20136B	\N	\N
32669	589	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20136B	\N	\N
32670	673	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20136B	\N	\N
32671	595	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20136B	\N	\N
32728	573	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21094N	\N	\N
32729	596	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21094N	\N	\N
32730	632	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21094N	\N	\N
32731	599	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21094N	\N	\N
32732	608	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21094N	\N	\N
32733	595	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21094N	\N	\N
32859	572	2023-11-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21075K	\N	\N
32922	573	2023-11-15 00:00:00	2029-11-27 00:00:00	ACTIF	\N	\N	\N	21033Y	\N	\N
32965	577	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
32966	575	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
32967	629	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
32968	644	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
32969	597	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
32970	573	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
32971	622	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
32972	588	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
32973	979	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
32974	628	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
32975	659	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
32976	626	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
32977	640	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
32978	572	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
32979	591	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
32980	571	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
32981	530	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
32982	646	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
32983	580	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
32984	576	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
32985	583	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
32986	596	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
32987	619	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
25260	653	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04092N	2017-11-15 10:12:25	\N
25261	626	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04092N	2017-11-15 10:12:25	\N
25262	651	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04092N	2017-11-15 10:12:25	\N
25263	659	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04092N	2017-11-15 10:12:25	\N
25694	609	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	07004J	2017-12-21 09:52:40	\N
25695	673	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19415P	2017-12-21 09:53:08	\N
25698	609	2017-12-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14265W	2017-12-21 12:27:23	\N
25973	907	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14135M	\N	\N
26138	998	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19657G	\N	\N
26139	998	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19637C	\N	\N
26150	673	2018-01-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19367Y	2018-01-29 15:17:33	\N
26702	612	2018-03-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	17589D	2018-03-15 09:48:30	\N
26703	634	2018-03-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	17589D	2018-03-15 09:48:30	\N
26767	627	2018-05-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19591F	2018-05-30 10:11:19	\N
26814	583	2018-09-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19766L	\N	\N
26815	602	2018-09-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19766L	\N	\N
26816	643	2018-09-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19766L	\N	\N
26817	978	2018-09-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19766L	\N	\N
26818	576	2018-09-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19766L	\N	\N
26819	578	2018-09-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19766L	\N	\N
26820	979	2018-09-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19766L	\N	\N
26821	663	2018-09-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19766L	\N	\N
27015	948	2019-04-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14034U	\N	\N
27016	957	2019-04-30 00:00:00	2019-04-30 00:00:00	ANCIEN	\N	\N	\N	14034U	\N	\N
27671	628	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14089Y	\N	\N
27672	629	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14089Y	\N	\N
27673	573	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	\N	\N
27674	594	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	\N	\N
27675	583	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	\N	\N
27676	674	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	\N	\N
27677	609	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	\N	\N
27678	642	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	\N	\N
27679	651	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	\N	\N
27680	575	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	\N	\N
27681	572	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	\N	\N
27682	661	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	\N	\N
27683	579	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14259Y	\N	\N
27684	580	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14259Y	\N	\N
27685	651	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14259Y	\N	\N
27686	584	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14259Y	\N	\N
27687	578	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14259Y	\N	\N
27688	641	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14259Y	\N	\N
27689	647	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14042U	\N	\N
27690	625	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14042U	\N	\N
27691	580	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19551W	\N	\N
27692	586	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19551W	\N	\N
27693	613	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19551W	\N	\N
27694	529	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19583F	\N	\N
27695	622	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19583F	\N	\N
27696	598	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19583F	\N	\N
27697	550	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19583F	\N	\N
27698	661	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19583F	\N	\N
27699	581	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14253S	\N	\N
27700	589	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14253S	\N	\N
27701	590	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14253S	\N	\N
27702	576	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19705W	\N	\N
27703	595	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19705W	\N	\N
27704	590	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19705W	\N	\N
27705	641	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19705W	\N	\N
27706	663	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01034P	\N	\N
27826	663	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20150Y	\N	\N
27827	651	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20150Y	\N	\N
27828	978	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20150Y	\N	\N
27829	584	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20150Y	\N	\N
27830	625	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20150Y	\N	\N
27831	596	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20150Y	\N	\N
27832	578	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20150Y	\N	\N
27833	575	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19413M	\N	\N
27834	622	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19413M	\N	\N
29102	573	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19703U	\N	\N
29103	572	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17229F	\N	\N
29805	1008	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
30341	1012	2021-06-09 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14053L	\N	\N
30358	1012	2021-06-18 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14033T	\N	\N
30427	632	2021-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	12041X	\N	\N
30773	1014	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19621T	\N	\N
31740	641	2023-10-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21032X	\N	\N
31741	602	2023-10-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21032X	\N	\N
31742	573	2023-10-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21032X	\N	\N
31743	583	2023-10-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21032X	\N	\N
31744	622	2023-10-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21032X	\N	\N
31745	591	2023-10-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21032X	\N	\N
31746	640	2023-10-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21032X	\N	\N
31747	598	2023-10-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21032X	\N	\N
31748	620	2023-10-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21032X	\N	\N
31749	626	2023-10-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21032X	\N	\N
31750	609	2023-10-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21032X	\N	\N
32026	597	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08010L	\N	\N
32027	604	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08010L	\N	\N
32029	609	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14357A	\N	\N
32030	583	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14357A	\N	\N
32031	629	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14357A	\N	\N
32032	644	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14357A	\N	\N
32033	598	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14357A	\N	\N
32034	610	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14357A	\N	\N
32035	604	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14357A	\N	\N
32036	617	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14357A	\N	\N
32046	673	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21068L	\N	\N
32047	613	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21068L	\N	\N
32048	590	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21068L	\N	\N
32401	574	2023-10-26 00:00:00	2023-10-31 00:00:00	ANCIEN	\N	\N	\N	20062A	\N	\N
32402	578	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20062A	\N	\N
32403	594	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20062A	\N	\N
32404	663	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20062A	\N	\N
28932	609	2020-11-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
28933	574	2020-11-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
29046	584	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04085P	\N	\N
29047	601	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04085P	\N	\N
29048	632	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04085P	\N	\N
29049	626	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04085P	\N	\N
29050	622	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04085P	\N	\N
29051	573	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04085P	\N	\N
29291	605	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14213J	\N	\N
29292	633	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
29410	948	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20024T	\N	\N
29411	948	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14195A	\N	\N
29447	909	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14205J	\N	\N
29448	909	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19441R	\N	\N
29486	912	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19545Y	\N	\N
29487	909	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19545Y	\N	\N
29549	907	2020-12-23 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19723Y	\N	\N
30030	907	2021-01-26 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20140W	\N	\N
30032	907	2021-01-26 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
30033	906	2021-01-22 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
30034	948	2021-01-26 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
30035	906	2021-01-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19695N	\N	\N
30275	933	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20044X	\N	\N
30699	907	2023-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19717B	\N	\N
30700	907	2022-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19717B	\N	\N
30841	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	20140W	\N	\N
33287	595	2023-12-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19826F	\N	\N
33288	595	2023-12-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20056C	\N	\N
33295	625	2023-12-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21094N	\N	\N
33296	633	2023-12-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21094N	\N	\N
33474	573	2024-01-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19703U	\N	\N
33528	641	2024-01-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20140W	\N	\N
33524	577	2024-01-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19745F	\N	\N
33525	963	2024-01-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19699S	\N	\N
33529	595	2024-01-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20140W	\N	\N
33532	619	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17367Q	\N	\N
33535	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20076G	\N	\N
33540	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14189C	\N	\N
33678	1007	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20114U	\N	\N
33848	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20024T	\N	\N
33853	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14069U	\N	\N
34034	1011	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19667J	\N	\N
34035	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20106U	\N	\N
34036	908	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14331P	\N	\N
34136	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21065H	\N	\N
34138	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	11056N	\N	\N
34143	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20040T	\N	\N
34144	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20074E	\N	\N
34145	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19673G	\N	\N
34147	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20120S	\N	\N
34148	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19820Y	\N	\N
34149	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	08056B	\N	\N
34150	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14211G	\N	\N
34151	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14026U	\N	\N
34153	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14213J	\N	\N
34154	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21044C	\N	\N
34185	928	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	19681G	\N	\N
34268	906	2023-12-14 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	19709B	\N	\N
34295	908	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	20116W	\N	\N
25108	634	2017-11-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08069G	2017-11-07 14:19:38	\N
25109	576	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08073C	2017-11-07 14:39:30	\N
25110	590	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08073C	2017-11-07 14:39:30	\N
25111	979	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08073C	2017-11-07 14:39:30	\N
25112	584	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08073C	2017-11-07 14:39:30	\N
25113	574	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08073C	2017-11-07 14:39:30	\N
25114	642	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08073C	2017-11-07 14:39:30	\N
25115	602	2017-11-02 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19441R	2017-11-07 15:13:17	\N
25116	642	2017-11-02 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19441R	2017-11-07 15:13:17	\N
25423	643	2017-11-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19467C	2017-11-23 17:46:12	\N
25627	963	2017-11-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14257W	2017-12-14 14:41:07	\N
25628	673	2017-12-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08039A	2017-12-14 14:41:30	\N
25696	608	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19721W	2017-12-21 11:10:41	\N
26109	928	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14265W	\N	\N
25831	1004	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
26112	928	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	19349W	\N	\N
26159	591	2018-01-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14051J	2018-01-30 17:32:56	\N
26166	909	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
26642	998	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19489J	\N	\N
26694	1007	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
26722	1007	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11090Q	\N	\N
26792	530	2018-06-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19689Q	\N	\N
26880	934	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14265W	\N	\N
26902	1008	2018-01-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14063N	\N	\N
26904	627	2018-11-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14051J	\N	\N
27005	634	2019-04-02 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14063N	\N	\N
27061	659	2019-12-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14331P	\N	\N
27063	659	2019-12-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19643A	\N	\N
30212	579	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19643A	\N	\N
30213	597	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19643A	\N	\N
30214	588	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19643A	\N	\N
30215	597	2021-02-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14026U	\N	\N
30562	530	2022-03-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11045K	\N	\N
30631	1013	2022-05-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	\N	\N
30685	581	2022-09-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14169X	\N	\N
30811	934	2023-03-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19705W	\N	\N
32179	589	2023-10-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20018V	\N	\N
32180	598	2023-10-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20018V	\N	\N
32181	963	2023-10-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20018V	\N	\N
32200	612	2023-10-22 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21082J	\N	\N
32874	661	2023-11-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11056N	\N	\N
32875	608	2023-11-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11056N	\N	\N
32876	625	2023-11-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11056N	\N	\N
32877	640	2023-11-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11056N	\N	\N
32878	595	2023-11-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11056N	\N	\N
32879	644	2023-11-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11056N	\N	\N
32880	556	2023-11-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11056N	\N	\N
32881	617	2023-11-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11056N	\N	\N
32882	582	2023-11-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11056N	\N	\N
32883	588	2023-11-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11056N	\N	\N
32884	585	2023-11-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11056N	\N	\N
32885	591	2023-11-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11056N	\N	\N
32886	979	2023-11-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11056N	\N	\N
32887	576	2023-11-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11056N	\N	\N
32888	657	2023-11-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11056N	\N	\N
32889	647	2023-11-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11056N	\N	\N
32890	646	2023-11-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11056N	\N	\N
32891	642	2023-11-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11056N	\N	\N
32892	659	2023-11-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11056N	\N	\N
32893	584	2023-11-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11056N	\N	\N
32894	651	2023-11-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11056N	\N	\N
32895	597	2023-11-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11056N	\N	\N
32949	602	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21074J	\N	\N
32950	603	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21074J	\N	\N
33035	641	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14195A	\N	\N
33036	963	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14195A	\N	\N
33068	978	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20046A	\N	\N
33069	653	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	05008E	\N	\N
33081	577	2023-11-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20102Q	\N	\N
33082	653	2023-11-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20102Q	\N	\N
33088	585	2023-11-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19057M	\N	\N
33587	619	2024-01-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20058E	\N	\N
33588	619	2024-01-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14211G	\N	\N
33590	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	21050A	\N	\N
33591	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	20114U	\N	\N
33699	928	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	14026U	\N	\N
33700	928	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	05008E	\N	\N
33708	1006	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21095P	\N	\N
34163	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21054E	\N	\N
34239	963	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20030R	\N	\N
34242	595	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20054A	\N	\N
34364	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	\N	\N	\N	\N	19758L	\N	\N
29083	592	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11041F	\N	\N
29084	627	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20112S	\N	\N
29085	612	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
29086	674	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
29178	633	2020-12-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20130U	\N	\N
29998	919	2021-01-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17589D	\N	\N
30000	919	2021-01-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
30082	906	2021-01-27 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20120S	\N	\N
30111	1010	2021-02-03 00:00:00	2022-06-20 00:00:00	ANCIEN	\N	\N	\N	20174H	\N	\N
30084	909	2021-01-27 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20120S	\N	\N
30085	919	2021-01-27 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20120S	\N	\N
30114	1010	2021-02-03 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
30115	1010	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
31948	616	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20114U	\N	\N
31949	580	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20114U	\N	\N
31950	530	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20114U	\N	\N
31951	591	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20114U	\N	\N
31952	625	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20114U	\N	\N
31953	583	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20114U	\N	\N
31954	659	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20114U	\N	\N
31955	674	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20114U	\N	\N
31956	599	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20114U	\N	\N
31957	589	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20114U	\N	\N
31958	585	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20114U	\N	\N
31959	575	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20114U	\N	\N
31960	598	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20114U	\N	\N
31961	604	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20114U	\N	\N
31962	573	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20114U	\N	\N
31963	641	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20114U	\N	\N
31964	595	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20114U	\N	\N
31965	632	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20114U	\N	\N
31966	617	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20114U	\N	\N
31967	597	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20114U	\N	\N
32167	621	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19768N	\N	\N
32168	602	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19768N	\N	\N
32169	610	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19768N	\N	\N
32223	602	2023-10-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19057M	\N	\N
32347	851	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19687N	\N	\N
32988	605	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
32989	594	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
32990	632	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
32991	574	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
32992	624	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
32993	598	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
32994	582	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
32995	618	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
32996	581	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
32997	578	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
32998	657	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
32999	617	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
33000	600	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
33001	978	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
33002	610	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
33003	608	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
33004	604	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
33005	589	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
33006	642	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
33007	590	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
33008	579	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
33009	615	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
33010	620	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
33011	625	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
33012	663	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
33013	584	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
33014	661	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
33015	609	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
33016	613	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
33017	621	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
33018	601	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
33019	627	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
33020	653	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
33021	647	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
33022	641	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
33023	599	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
33024	674	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
33025	643	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
33026	602	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21073H	\N	\N
33027	613	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21061D	\N	\N
33161	643	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21031W	\N	\N
33175	572	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	10015M	\N	\N
33176	573	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21045D	\N	\N
33213	608	2023-11-30 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20062A	\N	\N
33214	628	2023-11-30 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20062A	\N	\N
33215	632	2023-11-30 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20062A	\N	\N
33217	624	2023-11-30 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08015R	\N	\N
33234	620	2023-12-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14281W	\N	\N
33312	613	2023-12-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21053D	\N	\N
33318	663	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19349W	\N	\N
33353	632	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19687N	\N	\N
33381	579	2023-12-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20052X	\N	\N
33402	550	2023-12-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
33409	1008	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14107H	\N	\N
33419	1007	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21089R	\N	\N
33421	1007	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20124W	\N	\N
33425	1007	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21055F	\N	\N
33436	934	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19421M	\N	\N
33459	934	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19629C	\N	\N
33463	1008	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14030Q	\N	\N
33465	577	2024-01-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08056B	\N	\N
33513	619	2024-01-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20044X	\N	\N
33514	1008	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21078N	\N	\N
33519	529	2024-01-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20050V	\N	\N
33523	619	2024-01-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14187A	\N	\N
33534	619	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19447X	\N	\N
33547	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	11056N	\N	\N
33548	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21052C	\N	\N
33551	619	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19593H	\N	\N
33552	620	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19565D	\N	\N
25246	583	2017-11-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08062Y	2017-11-14 11:26:11	\N
25247	598	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19583F	2017-11-14 11:26:41	\N
25248	622	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19583F	2017-11-14 11:26:41	\N
25249	593	2017-10-25 00:00:00	2017-12-15 00:00:00	ANCIEN	\N	\N	\N	19583F	2017-11-14 11:26:41	2017-12-15 10:46:18
25377	617	2017-11-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19735D	2017-11-22 09:53:43	\N
25378	556	2017-11-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01025N	2017-11-22 09:57:39	\N
25379	550	2017-11-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14251Q	2017-11-22 09:57:56	\N
25380	529	2017-11-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14251Q	2017-11-22 09:57:56	\N
25543	851	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19553Y	2017-12-05 17:31:41	\N
25544	659	2017-12-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19637C	2017-12-05 17:31:56	\N
25545	663	2017-12-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19741B	2017-12-05 17:39:31	\N
25546	626	2017-12-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19741B	2017-12-05 17:39:31	\N
26095	928	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14215L	\N	\N
26169	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14105F	\N	\N
26358	1005	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14061L	\N	\N
26810	919	2018-09-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14059S	\N	\N
27952	CHRETORIENT	2020-10-19 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	14231L	\N	\N
27953	CHRETORIENT	2020-10-19 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	19667J	\N	\N
27954	CHRETORIENT	2020-10-16 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	20086J	\N	\N
27955	CHRETORIENT	2020-10-19 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	07033P	\N	\N
27956	CHRETORIENT	2020-10-19 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	19713W	\N	\N
27957	CHRETORIENT	2020-10-19 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	11041F	\N	\N
29397	912	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14205J	\N	\N
29466	922	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14073Q	\N	\N
30157	938	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14331P	\N	\N
30158	938	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
30159	938	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
30160	938	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19421M	\N	\N
30161	938	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11048N	\N	\N
32405	629	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20062A	\N	\N
30163	938	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20044X	\N	\N
30164	938	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	17367Q	\N	\N
30165	938	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	08015R	\N	\N
30166	938	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
30167	938	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
30168	938	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19711U	\N	\N
30169	938	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20024T	\N	\N
30170	938	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19657G	\N	\N
30171	938	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14059S	\N	\N
30694	623	2021-12-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11070L	\N	\N
32406	529	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20062A	\N	\N
32407	530	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20062A	\N	\N
32698	643	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14097Y	\N	\N
32699	576	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14097Y	\N	\N
32703	598	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14071N	\N	\N
32704	646	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14071N	\N	\N
32725	979	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19295A	\N	\N
32726	573	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19295A	\N	\N
32727	642	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19295A	\N	\N
32803	580	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19335Q	\N	\N
32906	657	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19565D	\N	\N
33160	674	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19725B	\N	\N
33165	609	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21056G	\N	\N
33166	588	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21089R	\N	\N
33196	588	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21069M	\N	\N
33197	603	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21069M	\N	\N
33202	632	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08060W	\N	\N
33203	620	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08060W	\N	\N
33205	642	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08060W	\N	\N
33249	623	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19719D	\N	\N
33311	595	2023-12-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17367Q	\N	\N
33606	1004	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	20138D	\N	\N
33844	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14259Y	\N	\N
34225	906	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20076G	\N	\N
34226	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21046E	\N	\N
34367	998	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	19820Y	\N	\N
34494	588	2024-03-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19585H	\N	\N
28719	574	2020-11-03 00:00:00	2023-09-12 00:00:00	ANCIEN	\N	\N	\N	14259Y	\N	\N
28720	612	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14259Y	\N	\N
28721	609	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14259Y	\N	\N
28945	613	2020-11-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
29913	928	2020-10-01 00:00:00	2023-12-31 00:00:00	ANCIEN	\N	\N	\N	19719D	\N	\N
29914	928	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01024M	\N	\N
29916	928	2020-10-01 00:00:00	2023-12-31 00:00:00	ANCIEN	\N	\N	\N	14026U	\N	\N
29917	928	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19691J	\N	\N
29918	928	2020-10-01 00:00:00	2023-12-31 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
29919	928	2020-10-01 00:00:00	2023-12-31 00:00:00	ANCIEN	\N	\N	\N	14213J	\N	\N
29920	928	2020-10-01 00:00:00	2023-12-31 00:00:00	ANCIEN	\N	\N	\N	14097Y	\N	\N
29921	928	2020-10-01 00:00:00	2023-12-31 00:00:00	ANCIEN	\N	\N	\N	07029T	\N	\N
29922	928	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
29923	928	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19657G	\N	\N
29924	928	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19563B	\N	\N
29925	928	2020-10-01 00:00:00	2023-12-31 00:00:00	ANCIEN	\N	\N	\N	14223L	\N	\N
29926	928	2020-10-01 00:00:00	2023-12-31 00:00:00	ANCIEN	\N	\N	\N	08047A	\N	\N
29928	928	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19349W	\N	\N
29929	928	2020-10-01 00:00:00	2023-12-31 00:00:00	ANCIEN	\N	\N	\N	19798U	\N	\N
29930	928	2020-10-01 00:00:00	2023-12-31 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
29931	928	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19713W	\N	\N
30017	619	2021-01-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14105F	\N	\N
30051	919	2021-01-27 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
30797	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ANCIEN	\N	\N	\N	11040E	\N	\N
30817	934	2023-03-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19563B	\N	\N
30823	621	2023-04-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20048C	\N	\N
31443	584	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21054E	\N	\N
31444	576	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21054E	\N	\N
31445	602	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21054E	\N	\N
31446	653	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21054E	\N	\N
31454	629	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17737W	\N	\N
31455	1013	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17737W	\N	\N
31456	623	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17737W	\N	\N
31457	601	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17737W	\N	\N
31458	659	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17737W	\N	\N
31459	617	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17737W	\N	\N
31460	604	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17737W	\N	\N
31461	600	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17737W	\N	\N
31462	595	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17737W	\N	\N
31463	674	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17737W	\N	\N
31464	641	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17737W	\N	\N
31490	589	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14253S	\N	\N
31491	581	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14253S	\N	\N
31492	590	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14253S	\N	\N
31813	583	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20024T	\N	\N
32001	602	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14179A	\N	\N
32002	582	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14179A	\N	\N
32003	588	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14179A	\N	\N
32004	674	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14179A	\N	\N
32005	598	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14179A	\N	\N
32006	613	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14179A	\N	\N
32007	620	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14179A	\N	\N
32008	575	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14179A	\N	\N
32009	629	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14179A	\N	\N
32010	597	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14179A	\N	\N
32011	610	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14179A	\N	\N
32012	604	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14179A	\N	\N
32013	632	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14179A	\N	\N
32014	641	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14179A	\N	\N
32015	595	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14179A	\N	\N
32016	621	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14179A	\N	\N
32017	624	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14179A	\N	\N
32276	623	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19349W	\N	\N
32391	609	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19531S	\N	\N
32392	979	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19531S	\N	\N
32393	605	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19531S	\N	\N
32394	589	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19531S	\N	\N
32395	573	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19531S	\N	\N
32448	596	2023-10-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21031W	\N	\N
32578	603	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21042A	\N	\N
32579	602	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21042A	\N	\N
33331	556	2023-12-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20248J	\N	\N
33403	612	2023-12-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14069U	\N	\N
33469	663	2024-01-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20094J	\N	\N
33470	651	2024-01-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20094J	\N	\N
33512	619	2024-01-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14173T	\N	\N
33676	966	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20106U	\N	\N
34076	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20044X	\N	\N
34077	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	04045F	\N	\N
34078	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19545Y	\N	\N
34272	605	2024-01-30 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19713W	\N	\N
34273	605	2024-01-30 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14071N	\N	\N
34274	612	2024-01-30 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20252E	\N	\N
34392	933	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	14257W	\N	\N
25366	529	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19583F	2017-11-20 14:33:59	\N
25381	592	2017-11-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19515S	2017-11-22 16:03:43	\N
25382	613	2017-11-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19643A	2017-11-22 16:04:27	\N
25383	600	2017-11-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19643A	2017-11-22 16:04:27	\N
25384	586	2017-11-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	16685X	2017-11-22 16:05:05	\N
25385	963	2017-11-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	2017-11-22 16:05:23	\N
25386	963	2017-11-21 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14103D	2017-11-22 16:05:43	\N
25387	592	2017-11-22 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14103D	2017-11-22 16:06:12	\N
25388	674	2017-11-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19701S	2017-11-22 16:06:45	\N
25389	609	2017-11-22 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	19731Y	2017-11-22 16:08:22	\N
25390	583	2017-11-22 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	19731Y	2017-11-22 16:08:22	\N
25391	595	2017-11-22 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	19731Y	2017-11-22 16:08:22	\N
25392	608	2017-11-21 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	15447F	2017-11-22 16:09:08	\N
25393	619	2017-11-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14281W	2017-11-22 17:15:39	\N
25394	613	2017-11-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14059S	2017-11-22 17:37:19	\N
25395	592	2017-11-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01025N	2017-11-22 17:37:35	\N
25396	592	2017-11-21 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14159V	2017-11-22 17:37:50	\N
25773	673	2017-12-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19399H	2017-12-27 14:40:20	\N
25846	1004	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14223L	\N	\N
26234	998	2017-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14026U	\N	\N
26235	998	2017-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
26236	998	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19413M	\N	\N
26237	998	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14051J	\N	\N
26402	911	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
26546	577	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19745F	2018-02-16 15:15:33	\N
26547	626	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19745F	2018-02-16 15:15:33	\N
26548	596	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19745F	2018-02-16 15:15:33	\N
26549	633	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19745F	2018-02-16 15:15:33	\N
26550	589	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19745F	2018-02-16 15:15:33	\N
26852	633	2018-10-04 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19563B	\N	\N
26879	909	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14265W	\N	\N
26993	919	2018-01-31 00:00:00	2019-03-01 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
27006	928	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19798U	\N	\N
27029	919	2019-07-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19798U	\N	\N
27030	604	2019-07-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04069P	\N	\N
27083	597	2020-01-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19591F	\N	\N
29179	646	2020-12-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19766L	\N	\N
29180	579	2020-12-04 00:00:00	2022-12-31 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
29398	912	2020-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	20144B	\N	\N
30050	919	2021-01-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
30194	550	2021-02-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19585H	\N	\N
30319	1011	2021-03-31 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19745F	\N	\N
30349	1012	2021-06-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	05008E	\N	\N
30354	532	2021-06-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	\N	\N
30506	623	2022-01-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14026U	\N	\N
30507	602	2021-11-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20248J	\N	\N
30639	673	2022-06-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14193X	\N	\N
30754	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	14331P	\N	\N
30755	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	19709B	\N	\N
30756	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	14223L	\N	\N
30763	1014	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19577H	\N	\N
30778	1014	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19611R	\N	\N
30852	651	2023-07-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14169X	\N	\N
31139	589	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20088L	\N	\N
31140	575	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20088L	\N	\N
31141	591	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20088L	\N	\N
31142	598	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20088L	\N	\N
31143	642	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20088L	\N	\N
31144	620	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20088L	\N	\N
32458	595	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19573D	\N	\N
32459	590	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19573D	\N	\N
32460	534	2023-10-31 00:00:00	2023-10-31 00:00:00	ANCIEN	\N	\N	\N	19573D	\N	\N
32461	608	2023-10-31 00:00:00	2023-10-31 00:00:00	ANCIEN	\N	\N	\N	19573D	\N	\N
32462	661	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19573D	\N	\N
32463	626	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19573D	\N	\N
32464	621	2023-10-31 00:00:00	2023-10-31 00:00:00	ANCIEN	\N	\N	\N	19573D	\N	\N
32665	616	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21081H	\N	\N
32666	674	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21081H	\N	\N
32667	580	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21081H	\N	\N
32721	532	2022-02-28 00:00:00	2023-11-03 00:00:00	ANCIEN	\N	\N	\N	20100N	\N	\N
32722	659	2022-11-15 00:00:00	2023-11-03 00:00:00	ANCIEN	\N	\N	\N	19643A	\N	\N
32723	624	2021-11-23 00:00:00	2023-11-03 00:00:00	ANCIEN	\N	\N	\N	14107H	\N	\N
32724	620	2021-02-17 00:00:00	2023-11-03 00:00:00	ANCIEN	\N	\N	\N	19729F	\N	\N
33177	616	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04008A	\N	\N
33209	642	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19723Y	\N	\N
33320	584	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14211G	\N	\N
33337	632	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	18231D	\N	\N
33406	1008	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19593H	\N	\N
34247	611	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20110Q	\N	\N
34370	957	2023-12-14 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	19768N	\N	\N
34420	938	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	11056N	\N	\N
34421	938	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	21032X	\N	\N
28713	591	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20114U	\N	\N
28714	617	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20114U	\N	\N
28715	583	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20114U	\N	\N
28716	580	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20114U	\N	\N
28717	625	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20114U	\N	\N
28718	604	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20114U	\N	\N
28722	651	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14251Q	\N	\N
28723	590	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14251Q	\N	\N
28724	661	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14251Q	\N	\N
28725	550	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14251Q	\N	\N
28726	529	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14251Q	\N	\N
28727	594	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14251Q	\N	\N
29112	673	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	05008E	\N	\N
29113	615	2020-11-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
29114	592	2020-11-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	18083K	\N	\N
29115	651	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
29116	615	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
29117	659	2020-11-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14221J	\N	\N
29118	592	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14147R	\N	\N
29119	579	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14147R	\N	\N
29120	613	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14147R	\N	\N
29121	613	2020-11-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11054L	\N	\N
29134	611	2020-11-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19782L	\N	\N
29304	618	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19629C	\N	\N
29311	852	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20024T	\N	\N
29312	599	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20024T	\N	\N
29415	948	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	17023S	\N	\N
29416	948	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
29417	948	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14097Y	\N	\N
29431	909	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	\N	\N
29432	909	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14259Y	\N	\N
29433	909	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19719D	\N	\N
29434	909	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01024M	\N	\N
29494	909	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
29990	919	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19447X	\N	\N
29999	919	2021-01-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19531S	\N	\N
30011	1007	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	04070G	\N	\N
30013	966	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
30016	919	2021-01-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19415P	\N	\N
30018	934	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14179A	\N	\N
30031	906	2021-01-26 00:00:00	2022-12-31 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
30036	919	2021-01-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19695N	\N	\N
30100	1010	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	18083K	\N	\N
30223	909	2021-03-04 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20128B	\N	\N
30250	933	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11053K	\N	\N
30740	1014	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19467C	\N	\N
33410	1008	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21032X	\N	\N
33429	1006	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14037X	\N	\N
33430	1006	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20252E	\N	\N
33431	1006	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	10015M	\N	\N
33432	1006	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21038E	\N	\N
33433	1006	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21064G	\N	\N
33567	1004	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	20064C	\N	\N
33609	928	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	20024T	\N	\N
33610	928	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	19954N	\N	\N
34459	1010	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	20266L	\N	\N
33614	928	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	21063F	\N	\N
33658	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20048C	\N	\N
33659	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20066E	\N	\N
33661	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19489J	\N	\N
33662	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14037X	\N	\N
33666	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19745F	\N	\N
33667	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20118Y	\N	\N
33671	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20062A	\N	\N
33672	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20046A	\N	\N
33673	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20058E	\N	\N
33756	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21091K	\N	\N
33757	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21062E	\N	\N
33758	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20038A	\N	\N
33759	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	08018U	\N	\N
33762	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20120S	\N	\N
33765	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14033T	\N	\N
33766	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14026U	\N	\N
33767	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20106U	\N	\N
33768	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14179A	\N	\N
33770	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19399H	\N	\N
33771	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14213J	\N	\N
33772	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19551W	\N	\N
33773	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21044C	\N	\N
33774	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20056C	\N	\N
33775	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14097Y	\N	\N
33777	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	99004R	\N	\N
33779	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19735D	\N	\N
33780	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19723Y	\N	\N
33781	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	08015R	\N	\N
33782	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19711U	\N	\N
33783	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19709B	\N	\N
33786	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14059S	\N	\N
33787	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21054E	\N	\N
33788	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14031R	\N	\N
33799	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14193X	\N	\N
33802	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21053D	\N	\N
33808	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	04033B	\N	\N
33830	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14169X	\N	\N
33831	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	04047H	\N	\N
33857	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19721W	\N	\N
34039	908	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20150Y	\N	\N
34042	908	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20136B	\N	\N
34054	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19723Y	\N	\N
34055	1011	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14026U	\N	\N
34056	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21054E	\N	\N
34060	1011	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20096L	\N	\N
34064	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19563B	\N	\N
34066	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14169X	\N	\N
34067	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20030R	\N	\N
34069	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	05012A	\N	\N
34152	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19725B	\N	\N
34189	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20018V	\N	\N
34233	611	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19866P	\N	\N
25620	556	2017-12-11 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	2017-12-13 11:38:45	\N
25777	657	2017-12-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14081Q	2017-12-28 15:29:35	\N
25934	909	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08053X	\N	\N
25935	909	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14109K	\N	\N
25986	1004	2017-12-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14275Y	\N	\N
26240	907	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
26300	919	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14221J	\N	\N
26304	919	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14265W	\N	\N
26646	1008	2018-03-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
26941	575	2019-01-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19251M	\N	\N
26942	648	2019-01-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19251M	\N	\N
26943	641	2019-01-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19251M	\N	\N
26944	584	2019-01-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19251M	\N	\N
26945	621	2019-01-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19251M	\N	\N
26946	578	2019-01-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19251M	\N	\N
26947	610	2019-01-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19251M	\N	\N
26948	595	2019-01-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19251M	\N	\N
27166	597	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	\N	\N
27167	641	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	\N	\N
27168	602	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	\N	\N
27169	590	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	\N	\N
27170	595	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	\N	\N
27171	584	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	\N	\N
27172	604	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	\N	\N
27173	644	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	\N	\N
27174	621	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	\N	\N
27175	596	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	\N	\N
27176	632	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	\N	\N
27177	601	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	\N	\N
27178	634	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	\N	\N
27179	615	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	\N	\N
27180	620	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	\N	\N
27181	623	2020-10-08 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	04034C	\N	\N
27182	622	2020-10-08 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	04034C	\N	\N
27183	608	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20086J	\N	\N
27184	621	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11041F	\N	\N
27185	629	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11041F	\N	\N
27186	573	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11041F	\N	\N
27187	598	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11041F	\N	\N
27188	623	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11041F	\N	\N
27189	556	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11041F	\N	\N
27190	615	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11041F	\N	\N
27191	598	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19663E	\N	\N
27192	600	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19663E	\N	\N
27193	673	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19581D	\N	\N
27194	580	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19581D	\N	\N
27195	596	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20128B	\N	\N
27196	590	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20128B	\N	\N
27197	657	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	\N	\N
27198	643	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	\N	\N
27199	608	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	\N	\N
27200	628	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	\N	\N
27201	851	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	\N	\N
27202	612	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	\N	\N
27203	632	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	\N	\N
27204	979	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	\N	\N
27205	625	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	\N	\N
27206	619	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	\N	\N
27207	589	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	\N	\N
27208	585	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	\N	\N
27209	534	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	\N	\N
27210	624	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
27211	621	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19515S	\N	\N
27212	641	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19515S	\N	\N
27213	592	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19515S	\N	\N
27214	584	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19515S	\N	\N
27215	604	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19515S	\N	\N
27216	640	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14059S	\N	\N
27217	618	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14059S	\N	\N
27218	625	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14059S	\N	\N
27219	613	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14059S	\N	\N
27220	608	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14059S	\N	\N
27221	622	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14059S	\N	\N
27222	621	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11101A	\N	\N
27223	629	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11101A	\N	\N
27224	963	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11101A	\N	\N
27225	589	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11101A	\N	\N
27460	609	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19673G	\N	\N
27461	646	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19673G	\N	\N
27462	617	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19673G	\N	\N
27463	634	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19673G	\N	\N
27464	573	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19591F	\N	\N
27465	632	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19591F	\N	\N
27466	595	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19591F	\N	\N
27467	627	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19591F	\N	\N
27468	621	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19591F	\N	\N
27469	659	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19591F	\N	\N
27470	597	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19591F	\N	\N
27471	572	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19591F	\N	\N
27472	661	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19591F	\N	\N
27473	574	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14053L	\N	\N
27474	584	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14053L	\N	\N
27475	573	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14053L	\N	\N
27476	600	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14053L	\N	\N
27477	598	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14053L	\N	\N
28152	585	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20106U	\N	\N
28153	640	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20118Y	\N	\N
28154	578	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20094J	\N	\N
28155	621	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20094J	\N	\N
28156	608	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20094J	\N	\N
28157	591	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20094J	\N	\N
28158	583	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20094J	\N	\N
28159	610	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20094J	\N	\N
28160	611	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20094J	\N	\N
28161	602	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20150Y	\N	\N
28162	590	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20150Y	\N	\N
28163	574	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20150Y	\N	\N
28465	600	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20032T	\N	\N
28466	596	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20032T	\N	\N
28467	978	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20032T	\N	\N
28468	620	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14229S	\N	\N
28469	596	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14229S	\N	\N
28470	594	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14229S	\N	\N
28471	621	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14229S	\N	\N
28941	628	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20122U	\N	\N
28942	651	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20122U	\N	\N
28943	580	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20122U	\N	\N
28944	534	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20122U	\N	\N
29298	907	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14105F	\N	\N
29300	907	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19467C	\N	\N
29301	907	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14169X	\N	\N
29623	532	2021-01-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20074E	\N	\N
30005	1006	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	04070G	\N	\N
33616	928	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	11056N	\N	\N
33617	928	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	14215L	\N	\N
33618	928	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	20074E	\N	\N
33674	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21082J	\N	\N
33620	928	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	14281W	\N	\N
33622	928	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	14179A	\N	\N
33623	928	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	14213J	\N	\N
34466	1010	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	20086J	\N	\N
33625	928	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	20126Y	\N	\N
33626	928	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	07029T	\N	\N
33633	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	05008E	\N	\N
33634	928	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	08047A	\N	\N
33637	928	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	21068L	\N	\N
33638	928	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	19798U	\N	\N
33670	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21079P	\N	\N
33680	1007	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20150Y	\N	\N
33682	1007	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21094N	\N	\N
33716	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20024T	\N	\N
33731	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20090E	\N	\N
33733	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14053L	\N	\N
33734	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14083S	\N	\N
33735	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19057M	\N	\N
33736	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14329V	\N	\N
33737	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14038Y	\N	\N
33738	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14195A	\N	\N
33739	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	08028W	\N	\N
33740	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20144B	\N	\N
33741	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21065H	\N	\N
33743	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	11027H	\N	\N
33745	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14357A	\N	\N
33746	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19693L	\N	\N
33747	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21041Y	\N	\N
33748	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14217N	\N	\N
33749	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14215L	\N	\N
33751	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20040T	\N	\N
33752	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	07033P	\N	\N
33753	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20074E	\N	\N
33820	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	04045F	\N	\N
33821	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19703U	\N	\N
33833	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19729F	\N	\N
33950	1005	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20062A	\N	\N
33951	1005	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20136B	\N	\N
33952	918	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14033T	\N	\N
33957	918	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20018V	\N	\N
34314	919	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	20140W	\N	\N
34483	602	2024-03-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14169X	\N	\N
34493	605	2024-03-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17965H	\N	\N
24882	628	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11033F	2017-10-31 15:23:03	\N
24883	574	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11033F	2017-10-31 15:23:03	\N
24884	595	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11033F	2017-10-31 15:23:03	\N
24885	632	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11033F	2017-10-31 15:23:03	\N
24886	550	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11033F	2017-10-31 15:23:03	\N
24887	588	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11033F	2017-10-31 15:23:03	\N
24888	609	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11033F	2017-10-31 15:23:03	\N
24889	641	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11033F	2017-10-31 15:23:03	\N
24890	578	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11033F	2017-10-31 15:23:03	\N
24891	602	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19575F	2017-10-31 15:58:18	\N
24892	621	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19575F	2017-10-31 15:58:18	\N
24893	978	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19575F	2017-10-31 15:58:18	\N
24894	610	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19575F	2017-10-31 15:58:18	\N
25469	581	2017-11-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19479G	2017-11-28 11:16:36	\N
25519	633	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11054L	2017-12-01 09:34:34	\N
25520	615	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11054L	2017-12-01 09:34:34	\N
25521	659	2017-11-30 00:00:00	2018-12-30 00:00:00	ANCIEN	\N	\N	\N	98023Q	2017-12-01 09:34:59	\N
25522	629	2017-11-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19741B	2017-12-01 09:48:51	\N
25523	621	2017-11-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19741B	2017-12-01 09:48:51	\N
25524	599	2017-11-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08052W	2017-12-01 10:07:33	\N
25525	615	2017-11-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08052W	2017-12-01 10:07:33	\N
25668	605	2017-12-19 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	2017-12-20 10:01:25	\N
25669	530	2017-12-19 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	2017-12-20 10:01:25	\N
25670	609	2017-12-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14135M	2017-12-20 10:02:31	\N
25671	609	2017-12-19 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	2017-12-20 10:02:50	\N
25672	571	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08012N	2017-12-20 10:03:05	\N
25673	588	2017-12-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14267Y	2017-12-20 10:06:04	\N
25674	661	2017-12-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14221J	2017-12-20 10:09:28	\N
25675	556	2017-12-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19739H	2017-12-20 10:09:42	\N
25676	530	2017-12-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14219Q	2017-12-20 10:10:02	\N
25677	617	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14030Q	2017-12-20 10:11:50	\N
25679	609	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14133K	2017-12-20 17:36:00	\N
25680	621	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04042C	2017-12-20 17:36:18	\N
25681	609	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14026U	2017-12-20 17:36:31	\N
25682	609	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14059S	2017-12-20 17:36:45	\N
25683	657	2017-12-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19551W	2017-12-20 17:37:00	\N
25684	609	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11097X	2017-12-20 17:37:14	\N
25685	571	2017-12-19 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14079W	2017-12-20 17:37:28	\N
25686	577	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19725B	2017-12-20 17:37:54	\N
25687	606	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19725B	2017-12-20 17:37:54	\N
25688	634	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19725B	2017-12-20 17:37:54	\N
25689	571	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19725B	2017-12-20 17:42:06	\N
25690	582	2017-12-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11056N	2017-12-20 17:42:34	\N
25691	596	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14021P	2017-12-20 17:42:52	2017-12-20 17:48:02
25692	579	2017-12-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14331P	2017-12-20 17:43:07	\N
25693	661	2017-11-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	2017-12-20 19:02:00	\N
26333	919	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08015R	\N	\N
26334	919	2018-01-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11097X	\N	\N
26361	1005	2018-01-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	17779H	\N	\N
26364	1005	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19563B	\N	\N
26365	1005	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14109K	\N	\N
26367	1005	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
26369	1005	2017-10-01 00:00:00	2017-12-31 00:00:00	ANCIEN	\N	\N	\N	14225N	\N	\N
26370	1005	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14107H	\N	\N
26371	1005	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
26372	1005	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01062T	\N	\N
26373	1005	2018-02-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11012A	\N	\N
26491	957	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19619A	\N	\N
26732	661	2018-03-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14169X	2018-03-30 15:01:24	\N
26746	673	2018-04-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19703U	2018-04-11 15:05:52	\N
26775	601	2018-05-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08060W	2018-06-06 16:33:04	\N
26869	610	2018-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19421M	\N	\N
26870	610	2018-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19729F	\N	\N
26871	673	2018-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19729F	\N	\N
26872	963	2018-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14111D	\N	\N
27064	641	2019-12-02 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11064N	\N	\N
27065	674	2019-11-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	\N	\N
27821	616	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20082E	\N	\N
27822	663	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20082E	\N	\N
29381	911	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	17023S	\N	\N
29382	911	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19511N	\N	\N
29384	911	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19447X	\N	\N
29483	922	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19577H	\N	\N
29935	934	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20152B	\N	\N
29941	919	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
30093	598	2021-02-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	\N	\N
30375	948	2021-07-07 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20124W	\N	\N
30376	948	2021-07-13 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20140W	\N	\N
30607	1013	2022-04-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14223L	\N	\N
30608	530	2022-04-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14223L	\N	\N
30666	530	2022-03-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20062A	\N	\N
30849	934	2023-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20980G	\N	\N
32914	653	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21081H	\N	\N
33089	613	2023-11-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21095P	\N	\N
33109	621	2023-11-22 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08015R	\N	\N
34374	933	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	20024T	\N	\N
34377	933	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	14069U	\N	\N
34378	933	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	21063F	\N	\N
34382	933	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	14169X	\N	\N
34383	933	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	19251M	\N	\N
28392	609	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19515S	\N	\N
29140	602	2020-11-25 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	08017T	\N	\N
29165	579	2020-12-01 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	08017T	\N	\N
30201	534	2021-02-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
30003	907	2021-01-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
30052	907	2021-01-20 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14221J	\N	\N
30079	928	2020-10-01 00:00:00	2023-12-31 00:00:00	ANCIEN	\N	\N	\N	14281W	\N	\N
30221	909	2021-03-03 00:00:00	2021-03-03 00:00:00	ANCIEN	\N	\N	\N	20042V	\N	\N
30240	623	2021-03-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	\N	\N
30271	933	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19735D	\N	\N
30272	933	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19349W	\N	\N
30327	596	2021-04-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19545Y	\N	\N
30845	1006	2023-10-01 00:00:00	2026-09-30 00:00:00	ANCIEN	\N	\N	\N	19593H	\N	\N
30848	1006	2023-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	\N	\N
31817	979	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08073C	\N	\N
31818	576	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08073C	\N	\N
31819	573	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08073C	\N	\N
31820	584	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08073C	\N	\N
31821	572	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08073C	\N	\N
31822	642	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08073C	\N	\N
31826	598	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	07033P	\N	\N
31827	591	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	07033P	\N	\N
31828	589	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	07033P	\N	\N
31829	596	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	07033P	\N	\N
31830	613	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	07033P	\N	\N
31831	595	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	07033P	\N	\N
31832	621	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	07033P	\N	\N
31833	584	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	07033P	\N	\N
31968	597	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08069G	\N	\N
31969	590	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08069G	\N	\N
31970	629	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08069G	\N	\N
31971	661	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08069G	\N	\N
31972	595	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08069G	\N	\N
31973	596	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08069G	\N	\N
31974	633	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08069G	\N	\N
31975	576	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08069G	\N	\N
31976	673	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08069G	\N	\N
31977	550	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08069G	\N	\N
31978	601	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08069G	\N	\N
31979	534	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08069G	\N	\N
31980	634	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08069G	\N	\N
31981	572	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08069G	\N	\N
32019	581	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14069U	\N	\N
32020	629	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14069U	\N	\N
32021	624	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14069U	\N	\N
32489	589	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21059K	\N	\N
32490	596	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21059K	\N	\N
33483	1008	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21084L	\N	\N
33510	619	2024-01-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14105F	\N	\N
33517	619	2024-01-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14059S	\N	\N
33530	1008	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21053D	\N	\N
33742	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	18083K	\N	\N
33744	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	11056N	\N	\N
33778	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20126Y	\N	\N
33785	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14205J	\N	\N
33832	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	07029T	\N	\N
34237	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	11065P	\N	\N
34279	603	2024-01-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21085M	\N	\N
34287	948	2023-12-14 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	21047F	\N	\N
34306	1006	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	18231D	\N	\N
34312	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	\N	\N	\N	\N	19533U	\N	\N
34324	907	2023-12-14 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	08061X	\N	\N
34329	919	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	19719D	\N	\N
34355	906	2023-12-14 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	21036C	\N	\N
34356	957	2023-12-14 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	21036C	\N	\N
34358	919	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	21036C	\N	\N
34360	1005	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	21036C	\N	\N
34363	908	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	14083S	\N	\N
34368	957	2023-12-14 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	19585H	\N	\N
34408	948	2023-12-14 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	01058X	\N	\N
34414	938	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	19421M	\N	\N
34426	938	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	19669L	\N	\N
34427	938	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	19631V	\N	\N
34428	938	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	21051B	\N	\N
34429	938	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	19649G	\N	\N
34433	938	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	20106U	\N	\N
34434	938	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	20150Y	\N	\N
34435	938	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	21043B	\N	\N
34436	938	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	14037X	\N	\N
34437	938	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	17023S	\N	\N
34443	1010	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	11115U	\N	\N
34444	1010	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	18083K	\N	\N
34447	1010	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	20150Y	\N	\N
34448	1010	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	19954N	\N	\N
34465	1010	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	20022R	\N	\N
34470	919	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	20060X	\N	\N
34490	919	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	19760E	\N	\N
34495	623	2024-04-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21029D	\N	\N
34498	632	2024-04-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21078N	\N	\N
34501	909	2024-04-15 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	20042V	\N	\N
25829	1004	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19717B	\N	\N
25902	609	2017-12-15 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14061L	2018-01-17 12:32:00	\N
25963	CHRETORIENT	2018-01-18 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	19367Y	2018-01-18 16:48:45	\N
26002	948	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08038Y	\N	\N
26005	948	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14197C	\N	\N
26006	948	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
26008	948	2017-10-01 00:00:00	2020-06-24 00:00:00	ANCIEN	\N	\N	\N	19727D	\N	\N
26009	948	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	\N	\N
26010	948	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19725B	\N	\N
26011	948	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
26012	948	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11048N	\N	\N
26013	948	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19551W	\N	\N
26014	948	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	\N	\N
26015	948	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19723Y	\N	\N
26246	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	\N	\N
26575	933	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19671E	\N	\N
26576	933	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11077T	\N	\N
26580	933	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14225N	\N	\N
26582	933	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14257W	\N	\N
26586	918	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14237S	\N	\N
26587	938	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
26729	1006	2017-12-07 00:00:00	2018-08-06 00:00:00	ANCIEN	\N	\N	\N	95015C	\N	\N
26913	596	2018-11-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19735D	\N	\N
26914	627	2018-11-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19503N	\N	\N
26954	909	2019-01-22 00:00:00	2020-08-06 00:00:00	ANCIEN	\N	\N	\N	19782L	\N	\N
27042	934	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19621T	\N	\N
28164	622	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20150Y	\N	\N
28165	611	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20150Y	\N	\N
28166	621	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19798U	\N	\N
28167	612	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19798U	\N	\N
28168	CHRETORIENT	2020-10-18 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	19798U	\N	\N
28176	CHRETORIENT	2020-10-20 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	20108W	\N	\N
28177	CHRETORIENT	2020-10-20 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	20038A	\N	\N
28187	626	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19782L	\N	\N
29509	908	2020-12-18 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20106U	\N	\N
29656	918	2021-01-08 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
29942	592	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14169X	\N	\N
30156	938	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
30172	938	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
30175	938	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11033F	\N	\N
30176	938	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20110Q	\N	\N
30177	938	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19503N	\N	\N
30178	938	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	\N	\N
30179	938	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19631V	\N	\N
30180	938	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14097Y	\N	\N
30183	938	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
30186	938	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14030Q	\N	\N
30187	938	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14219Q	\N	\N
30188	938	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
30260	933	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11048N	\N	\N
30458	906	2021-11-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19369B	\N	\N
30764	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	20062A	\N	\N
30766	1014	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19543W	\N	\N
31647	596	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14257W	\N	\N
31938	556	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08009T	\N	\N
31939	609	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08009T	\N	\N
31940	595	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08009T	\N	\N
31941	598	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08009T	\N	\N
31942	530	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08009T	\N	\N
31943	583	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08009T	\N	\N
31944	618	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08009T	\N	\N
31945	661	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08009T	\N	\N
31946	643	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08009T	\N	\N
31947	601	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08009T	\N	\N
31982	589	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08010L	\N	\N
31983	590	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08010L	\N	\N
31984	978	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08010L	\N	\N
32102	625	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20248J	\N	\N
32103	595	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20248J	\N	\N
32104	600	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20248J	\N	\N
32105	1013	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20248J	\N	\N
32106	583	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20248J	\N	\N
32107	579	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20248J	\N	\N
32108	530	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20248J	\N	\N
32109	641	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20248J	\N	\N
32110	590	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20248J	\N	\N
32111	642	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20248J	\N	\N
32112	629	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20248J	\N	\N
32113	618	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20248J	\N	\N
32114	623	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20248J	\N	\N
32115	571	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20248J	\N	\N
32116	602	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20248J	\N	\N
32117	597	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20248J	\N	\N
32149	625	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11043H	\N	\N
32468	661	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19565D	\N	\N
32469	578	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19565D	\N	\N
32470	618	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19565D	\N	\N
32471	617	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19565D	\N	\N
32472	644	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19565D	\N	\N
32477	590	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21057H	\N	\N
32478	591	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21057H	\N	\N
32479	600	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21057H	\N	\N
32480	621	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21057H	\N	\N
32481	604	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21057H	\N	\N
32482	605	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21057H	\N	\N
32483	595	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21057H	\N	\N
32484	674	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21057H	\N	\N
32485	589	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21057H	\N	\N
32486	601	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21057H	\N	\N
32487	581	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21057H	\N	\N
32488	530	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21057H	\N	\N
32605	597	2023-11-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21081H	\N	\N
32672	621	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14327T	\N	\N
32673	589	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14327T	\N	\N
32717	597	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20086J	\N	\N
32718	646	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20086J	\N	\N
29476	918	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19503N	\N	\N
29519	633	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11099A	\N	\N
29585	909	2020-12-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01057W	\N	\N
29681	919	2021-01-12 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20082E	\N	\N
29808	1008	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19657G	\N	\N
29809	1008	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	08009T	\N	\N
29810	1008	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14257W	\N	\N
31071	617	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14030Q	\N	\N
31072	634	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14030Q	\N	\N
31073	663	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14030Q	\N	\N
31074	643	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14030Q	\N	\N
31094	612	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19798U	\N	\N
31095	530	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19798U	\N	\N
31096	634	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19798U	\N	\N
31097	621	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19798U	\N	\N
31098	597	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19798U	\N	\N
31099	605	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19798U	\N	\N
33615	928	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
33642	659	2024-01-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14191V	\N	\N
33725	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20088L	\N	\N
33728	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19383Y	\N	\N
33840	603	2024-01-22 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19685L	\N	\N
34250	928	2024-01-02 00:00:00	2024-12-31 00:00:00	ACTIF	\N	\N	\N	21087P	\N	\N
34343	603	2024-02-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14111D	\N	\N
34357	909	2023-12-14 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	21036C	\N	\N
25117	621	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19335Q	2017-11-07 17:21:01	\N
25118	643	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19335Q	2017-11-07 17:21:01	\N
25974	934	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19289C	\N	\N
26374	1005	2018-02-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14257W	\N	\N
26375	1005	2018-01-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11097X	\N	\N
26480	957	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14187A	\N	\N
26568	933	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
26753	632	2018-04-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11074Q	2018-04-20 10:20:58	\N
27039	575	2019-09-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04069P	\N	\N
27056	622	2019-11-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
27478	618	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08015R	\N	\N
27479	643	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08015R	\N	\N
27480	577	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08015R	\N	\N
27481	608	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08015R	\N	\N
27482	629	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08015R	\N	\N
27483	979	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08015R	\N	\N
27484	661	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08015R	\N	\N
27485	556	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08015R	\N	\N
27486	595	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08015R	\N	\N
27487	646	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08015R	\N	\N
29181	556	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20084G	\N	\N
29182	651	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20084G	\N	\N
29184	613	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20084G	\N	\N
29497	998	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20094J	\N	\N
29498	906	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20094J	\N	\N
29520	907	2020-12-18 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14173T	\N	\N
29584	907	2020-12-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01057W	\N	\N
29877	934	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14189C	\N	\N
30181	938	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	08012N	\N	\N
30355	919	2021-06-17 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20106U	\N	\N
30356	1012	2021-06-09 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19719D	\N	\N
30357	1012	2021-06-17 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20106U	\N	\N
30363	1012	2021-06-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	16685X	\N	\N
30364	919	2021-06-21 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14221J	\N	\N
30422	590	2021-10-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20252E	\N	\N
30423	605	2021-10-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20252E	\N	\N
30424	584	2021-10-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20252E	\N	\N
30425	604	2021-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20252E	\N	\N
30426	571	2021-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14189C	\N	\N
30465	1010	2021-10-23 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19707Y	\N	\N
30466	1010	2021-10-23 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20266L	\N	\N
30492	CHRETORIENT	2021-12-09 00:00:00	2023-11-15 00:00:00	ANCIEN	\N	\N	\N	19551W	\N	\N
30505	934	2022-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19467C	\N	\N
30525	978	2022-02-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20124W	\N	\N
30532	629	2022-03-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20086J	\N	\N
30747	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	14215L	\N	\N
32734	581	2023-11-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19575F	\N	\N
32805	589	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21034A	\N	\N
32806	601	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21034A	\N	\N
32807	550	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21034A	\N	\N
32808	573	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21034A	\N	\N
32816	633	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19347U	\N	\N
33225	573	2023-12-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21082J	\N	\N
33226	529	2023-12-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21082J	\N	\N
33227	579	2023-12-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21082J	\N	\N
33228	640	2023-12-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21082J	\N	\N
33229	627	2023-12-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21082J	\N	\N
33515	619	2024-01-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20074E	\N	\N
33961	918	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19349W	\N	\N
34101	998	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14189C	\N	\N
34351	1005	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	17229F	\N	\N
34440	620	2024-03-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	07033P	\N	\N
29040	592	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19723Y	\N	\N
29041	609	2020-11-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19657G	\N	\N
29042	851	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19717B	\N	\N
29044	592	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14331P	\N	\N
29045	573	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14031R	\N	\N
29667	907	2021-01-05 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20038A	\N	\N
29702	595	2021-01-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14189C	\N	\N
29703	590	2021-01-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14189C	\N	\N
29714	534	2021-01-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20140W	\N	\N
29728	918	2021-01-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20048C	\N	\N
29767	948	2021-01-18 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20054A	\N	\N
29768	1005	2021-01-18 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20090E	\N	\N
29791	1008	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19599P	\N	\N
30045	619	2021-01-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04042C	\N	\N
30048	919	2021-01-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11103C	\N	\N
30081	911	2021-01-27 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20120S	\N	\N
30086	919	2021-01-26 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	04033B	\N	\N
30116	1010	2021-02-03 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14211G	\N	\N
30791	1014	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19766L	\N	\N
30923	609	2023-10-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14259Y	\N	\N
31738	591	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21041Y	\N	\N
31845	596	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20128B	\N	\N
31846	673	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20128B	\N	\N
31847	610	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20128B	\N	\N
31880	590	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14026U	\N	\N
31881	597	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14026U	\N	\N
31882	604	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14026U	\N	\N
31883	595	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14026U	\N	\N
31884	598	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14026U	\N	\N
31885	629	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14026U	\N	\N
31886	623	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14026U	\N	\N
31887	585	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14026U	\N	\N
31888	591	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14026U	\N	\N
31889	609	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14026U	\N	\N
31890	580	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14026U	\N	\N
31891	589	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14026U	\N	\N
31892	673	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14026U	\N	\N
31893	634	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14026U	\N	\N
31894	641	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14026U	\N	\N
31895	530	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14026U	\N	\N
31993	598	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14073Q	\N	\N
31994	673	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14073Q	\N	\N
31995	663	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14073Q	\N	\N
31996	592	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14073Q	\N	\N
31997	659	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14073Q	\N	\N
31998	620	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14073Q	\N	\N
31999	572	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14073Q	\N	\N
33253	624	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21078N	\N	\N
33292	584	2023-12-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14147R	\N	\N
33299	595	2023-12-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19723Y	\N	\N
33322	663	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20132W	\N	\N
33371	618	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21032X	\N	\N
33473	529	2024-01-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21076L	\N	\N
33484	1008	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21092L	\N	\N
33602	550	2024-01-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21065H	\N	\N
33635	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20110Q	\N	\N
34031	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14033T	\N	\N
34037	1011	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20022R	\N	\N
34192	573	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20106U	\N	\N
34193	611	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20106U	\N	\N
34209	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	08010L	\N	\N
34217	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20084G	\N	\N
34235	1004	2024-01-02 00:00:00	2024-12-31 00:00:00	ACTIF	\N	\N	\N	21087P	\N	\N
34313	919	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	19701S	\N	\N
34326	919	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	21067K	\N	\N
34327	919	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	14331P	\N	\N
34328	909	2023-12-14 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	07033P	\N	\N
34348	1011	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	20038A	\N	\N
25493	CHRETORIENT	2017-11-29 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	19709B	2017-11-29 17:52:46	\N
25494	584	2017-11-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	07033P	2017-11-29 17:53:01	\N
25495	574	2017-11-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	07033P	2017-11-29 17:53:01	\N
25496	648	2017-11-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11066Q	2017-11-29 17:53:57	\N
25497	530	2017-11-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01025N	2017-11-29 17:54:19	\N
25648	616	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19569H	2017-12-18 09:54:21	\N
34460	1010	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	21038E	\N	\N
25650	596	2017-12-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19649G	2017-12-18 18:15:25	\N
25994	948	2017-10-01 00:00:00	2020-03-03 00:00:00	ANCIEN	\N	\N	\N	11081P	\N	\N
26016	948	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	16685X	\N	\N
26017	948	2017-10-01 00:00:00	2018-04-13 00:00:00	ANCIEN	\N	\N	\N	19483C	\N	2018-04-13 17:54:29
26018	948	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14205J	\N	\N
26019	948	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	17779H	\N	\N
26276	919	2018-01-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14197C	\N	\N
26278	919	2018-01-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11110B	\N	\N
26279	919	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14187A	\N	\N
26280	919	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01025N	\N	\N
26282	919	2018-01-10 00:00:00	2020-06-24 00:00:00	ANCIEN	\N	\N	\N	19727D	\N	\N
26285	919	2018-01-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19725B	\N	\N
26286	919	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	95037J	\N	\N
26291	919	2018-01-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	\N	\N
26292	919	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14061L	\N	\N
26299	919	2018-01-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08053X	\N	\N
26858	610	2018-10-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	\N	\N
26859	663	2018-10-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19762G	\N	\N
26860	572	2018-10-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08052W	\N	\N
26861	613	2018-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19762G	\N	\N
26862	583	2018-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19762G	\N	\N
26920	948	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
27059	610	2019-12-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04069P	\N	\N
27948	608	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19349W	\N	\N
27949	641	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19349W	\N	\N
27950	581	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19349W	\N	\N
27951	584	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20050V	\N	\N
28200	978	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14225N	\N	\N
28201	578	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14225N	\N	\N
28202	584	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14225N	\N	\N
28203	609	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14225N	\N	\N
28204	595	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14225N	\N	\N
29390	911	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19713W	\N	\N
29545	906	2020-12-17 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20092G	\N	\N
30218	577	2021-03-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19954N	\N	\N
30326	909	2021-04-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20084G	\N	\N
30378	922	2021-07-20 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14083S	\N	\N
30379	908	2021-07-20 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20136B	\N	\N
30380	908	2021-07-20 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19826F	\N	\N
30387	590	2021-09-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20248J	\N	\N
30388	641	2021-09-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20248J	\N	\N
30389	583	2021-09-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20248J	\N	\N
30390	595	2021-09-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20248J	\N	\N
30431	1010	2021-10-12 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20138D	\N	\N
30460	1005	2021-10-08 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20084G	\N	\N
30468	603	2021-11-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20072C	\N	\N
30561	530	2022-03-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19782L	\N	\N
30655	598	2022-07-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17965H	\N	\N
30656	589	2022-07-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17965H	\N	\N
30768	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ANCIEN	\N	\N	\N	20074E	\N	\N
32719	590	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20086J	\N	\N
32720	581	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20086J	\N	\N
32810	641	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21085M	\N	\N
32811	580	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21085M	\N	\N
32852	589	2023-11-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21088Q	\N	\N
32898	623	2023-11-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19591F	\N	\N
32903	979	2023-11-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21096Q	\N	\N
32909	978	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20030R	\N	\N
32910	589	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20030R	\N	\N
32911	643	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20030R	\N	\N
32912	651	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20030R	\N	\N
32921	641	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19551W	\N	\N
33028	595	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19673G	\N	\N
33031	653	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	07033P	\N	\N
33032	612	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	07033P	\N	\N
33033	573	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21051B	\N	\N
33037	673	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20086J	\N	\N
33039	653	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	15197G	\N	\N
33061	580	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	15197G	\N	\N
33062	581	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	15197G	\N	\N
33085	633	2023-11-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20102Q	\N	\N
33115	572	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19669L	\N	\N
33116	571	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19669L	\N	\N
33117	601	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19669L	\N	\N
33118	852	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19669L	\N	\N
33119	619	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19669L	\N	\N
33120	609	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19669L	\N	\N
33121	604	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19669L	\N	\N
33122	653	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19669L	\N	\N
33123	588	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19669L	\N	\N
33124	574	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19669L	\N	\N
33125	584	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19669L	\N	\N
33126	616	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19669L	\N	\N
33127	659	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19669L	\N	\N
33128	621	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19669L	\N	\N
33129	613	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19669L	\N	\N
33130	608	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19669L	\N	\N
33131	640	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19669L	\N	\N
33132	617	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19669L	\N	\N
33133	597	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19669L	\N	\N
33134	651	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19669L	\N	\N
33135	576	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19669L	\N	\N
33136	624	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19669L	\N	\N
33137	590	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19669L	\N	\N
33138	641	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19669L	\N	\N
33139	595	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19669L	\N	\N
33140	596	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19669L	\N	\N
33141	602	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19669L	\N	\N
33142	628	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19669L	\N	\N
28946	589	2020-11-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19631V	\N	\N
29370	998	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19719D	\N	\N
29421	948	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19745F	\N	\N
29666	909	2021-01-12 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20022R	\N	\N
30009	1007	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19745F	\N	\N
30059	906	2021-01-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19563B	\N	\N
30277	599	2021-03-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20180F	\N	\N
30328	623	2021-04-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19545Y	\N	\N
30553	530	2022-03-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01024M	\N	\N
30836	1006	2023-05-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20084G	\N	\N
31648	600	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14001X	\N	\N
31649	591	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14001X	\N	\N
31650	578	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14001X	\N	\N
31651	585	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14001X	\N	\N
31652	621	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14001X	\N	\N
31653	643	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14001X	\N	\N
31654	978	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14001X	\N	\N
31655	589	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14001X	\N	\N
31656	571	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14001X	\N	\N
32018	641	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21080G	\N	\N
32024	618	2023-10-18 00:00:00	2024-03-20 00:00:00	ANCIEN	\N	\N	\N	98022P	\N	\N
32025	629	2023-10-18 00:00:00	2024-03-20 00:00:00	ANCIEN	\N	\N	\N	98022P	\N	\N
33328	613	2023-12-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14133K	\N	\N
33442	934	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19611R	\N	\N
33879	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20106U	\N	\N
33884	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19711U	\N	\N
33885	922	2023-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	\N	\N
33886	922	2023-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14195A	\N	\N
33888	922	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21065H	\N	\N
33889	922	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21092L	\N	\N
33891	922	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14213J	\N	\N
33892	922	2023-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	18207D	\N	\N
33893	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14031R	\N	\N
33894	922	2023-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	21040X	\N	\N
33899	1005	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14133K	\N	\N
33900	1005	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19631V	\N	\N
34160	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19709B	\N	\N
34171	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19745F	\N	\N
34172	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20030R	\N	\N
34174	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19798U	\N	\N
34175	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20150Y	\N	\N
34177	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21064G	\N	\N
34187	585	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14249W	\N	\N
34234	626	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20126Y	\N	\N
34320	1008	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	21091K	\N	\N
25033	632	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19599P	2017-11-03 10:58:55	\N
25034	573	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19599P	2017-11-03 10:58:56	\N
25035	621	2017-10-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19545Y	2017-11-03 10:59:42	\N
25036	979	2017-10-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19545Y	2017-11-03 10:59:42	\N
25037	602	2017-10-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19545Y	2017-11-03 10:59:42	\N
34461	1010	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	14026U	\N	\N
25038	629	2017-10-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19545Y	2017-11-03 10:59:42	\N
25039	644	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11090Q	2017-11-03 11:05:14	\N
25043	621	2017-10-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	2017-11-03 11:10:37	\N
25044	626	2017-10-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	2017-11-03 11:10:37	\N
25045	577	2017-10-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	2017-11-03 11:10:37	\N
25046	578	2017-10-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	2017-11-03 11:10:37	\N
25047	598	2017-10-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	2017-11-03 11:10:37	\N
25048	596	2017-10-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	2017-11-03 11:10:37	\N
25049	633	2017-10-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	2017-11-03 11:10:37	\N
25050	978	2017-10-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	2017-11-03 11:10:37	\N
25051	618	2017-10-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	2017-11-03 11:10:37	\N
25052	651	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	10006L	2017-11-03 11:10:57	\N
25053	595	2017-10-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11043H	2017-11-03 11:11:13	\N
25054	583	2017-10-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11043H	2017-11-03 11:11:13	\N
25055	CHRETORIENT	2017-10-18 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	11043H	2017-11-03 11:11:13	\N
25056	641	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14259Y	2017-11-03 11:11:43	\N
25057	651	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14259Y	2017-11-03 11:11:43	\N
25058	580	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14259Y	2017-11-03 11:11:43	\N
25059	584	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14259Y	2017-11-03 11:11:43	\N
25060	612	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14259Y	2017-11-03 11:11:43	\N
25061	651	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14219Q	2017-11-03 11:12:03	\N
25062	642	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14219Q	2017-11-03 11:12:03	\N
25063	634	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14219Q	2017-11-03 11:12:03	\N
25064	572	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14219Q	2017-11-03 11:12:03	\N
25657	618	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	95063L	2017-12-19 17:19:03	\N
25658	600	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	95063L	2017-12-19 17:19:03	\N
25659	604	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	95063L	2017-12-19 17:19:03	\N
25660	581	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	95063L	2017-12-19 17:19:03	\N
25661	584	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	95063L	2017-12-19 17:19:03	\N
25662	625	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	95063L	2017-12-19 17:19:03	\N
25663	609	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	95063L	2017-12-19 17:19:03	\N
25664	613	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	95063L	2017-12-19 17:19:03	\N
25665	590	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	95063L	2017-12-19 17:19:03	\N
25666	616	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	95063L	2017-12-19 17:19:03	\N
25667	623	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	95063L	2017-12-19 17:19:03	\N
25911	909	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11101A	\N	\N
25913	909	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14329V	\N	\N
25917	909	2017-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
25919	909	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	87003B	\N	\N
25921	909	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01025N	\N	\N
25925	909	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	95037J	\N	\N
25936	909	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14257W	\N	\N
25937	909	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
25938	909	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19443T	\N	\N
25939	909	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	19269X	\N	\N
25940	909	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
25941	909	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04044E	\N	\N
25942	909	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19723Y	\N	\N
25944	909	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	\N	\N
25945	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	\N	\N
26022	948	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
26024	948	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19533U	\N	\N
26026	948	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	98050T	\N	\N
26027	948	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11043H	\N	\N
26196	912	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19735D	\N	\N
26504	908	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11099A	\N	\N
26505	908	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14029X	\N	\N
26506	908	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08015R	\N	\N
26553	CHRETORIENT	2018-02-19 00:00:00	2023-10-05 00:00:00	ANCIEN	\N	\N	\N	19741B	2018-02-19 12:46:11	\N
26618	911	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19619A	\N	\N
27091	908	2020-03-02 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19599P	\N	\N
27101	623	2020-08-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19621T	\N	\N
29713	909	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20090E	\N	\N
30067	948	2021-01-19 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14189C	\N	\N
30284	1011	2021-03-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19667J	\N	\N
30285	1011	2021-03-25 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20022R	\N	\N
30288	1011	2021-03-25 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20090E	\N	\N
30289	1011	2021-03-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14329V	\N	\N
30464	1010	2021-11-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19057M	\N	\N
32705	600	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21046E	\N	\N
32706	629	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21046E	\N	\N
32707	610	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21046E	\N	\N
33070	623	2023-11-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14179A	\N	\N
33313	616	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11115U	\N	\N
33315	573	2023-12-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04070G	\N	\N
33495	619	2024-01-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19723Y	\N	\N
33497	619	2024-01-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19798U	\N	\N
33796	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20096L	\N	\N
33870	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14089Y	\N	\N
33871	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19695N	\N	\N
33872	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19383Y	\N	\N
33873	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20120S	\N	\N
33874	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19820Y	\N	\N
34336	918	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	19575F	\N	\N
29122	673	2020-11-26 00:00:00	2021-07-04 00:00:00	ANCIEN	\N	\N	\N	19966S	\N	\N
29161	653	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04008A	\N	\N
29322	919	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20086J	\N	\N
29663	907	2020-12-18 00:00:00	2020-12-18 00:00:00	ANCIEN	\N	\N	\N	14033T	\N	\N
29688	907	2021-01-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
29689	948	2021-01-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
29690	909	2021-01-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
29749	919	2021-01-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19507S	\N	\N
29750	907	2021-01-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19507S	\N	\N
29751	911	2021-01-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19507S	\N	\N
29753	948	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19739H	\N	\N
29754	907	2021-01-12 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	08034U	\N	\N
30132	1010	2021-02-03 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	04033B	\N	\N
30133	1010	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01058X	\N	\N
30727	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	19713W	\N	\N
30982	641	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17367Q	\N	\N
30983	534	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17367Q	\N	\N
30984	612	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17367Q	\N	\N
30985	1013	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17367Q	\N	\N
30986	597	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17367Q	\N	\N
30987	623	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17367Q	\N	\N
30988	530	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17367Q	\N	\N
30989	598	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17367Q	\N	\N
31435	530	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19782L	\N	\N
31436	641	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19782L	\N	\N
31437	623	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19782L	\N	\N
31438	611	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19782L	\N	\N
31451	641	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14193X	\N	\N
31557	979	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	01058X	\N	\N
31558	626	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	01058X	\N	\N
32296	581	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20054A	\N	\N
32317	647	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	18395Y	\N	\N
32318	602	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	18395Y	\N	\N
32319	550	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	18395Y	\N	\N
32320	622	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	18395Y	\N	\N
32321	625	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	18395Y	\N	\N
32322	596	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	18395Y	\N	\N
32323	641	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14189C	\N	\N
32324	673	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14189C	\N	\N
32325	596	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14189C	\N	\N
32326	597	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14189C	\N	\N
32327	595	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14189C	\N	\N
32328	571	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14189C	\N	\N
32329	621	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14189C	\N	\N
32330	629	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14189C	\N	\N
33258	642	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11040E	\N	\N
33368	594	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21059K	\N	\N
33415	966	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21089R	\N	\N
33560	1004	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	20056C	\N	\N
33601	934	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21065H	\N	\N
34275	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	\N	\N	\N	\N	21090J	\N	\N
34280	611	2024-01-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14033T	\N	\N
25315	574	2017-11-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14169X	2017-11-17 16:52:16	\N
25316	601	2017-11-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14169X	2017-11-17 16:52:16	\N
25468	661	2017-11-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19573D	2017-11-28 09:43:29	\N
25470	529	2017-11-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	07029T	2017-11-28 15:03:47	\N
25471	529	2017-11-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2017-11-28 15:04:01	\N
25472	653	2017-11-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	07033P	2017-11-28 15:04:20	\N
25473	651	2017-11-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	07033P	2017-11-28 15:04:20	\N
25536	661	2017-11-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14241N	2017-12-05 14:42:00	\N
25537	657	2017-11-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14227Q	2017-12-05 14:42:17	\N
25538	556	2017-12-04 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19543W	2017-12-05 14:42:40	\N
25539	629	2017-12-04 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19543W	2017-12-05 14:42:40	\N
25540	644	2017-12-04 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19543W	2017-12-05 14:42:40	\N
25541	608	2017-12-04 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19543W	2017-12-05 14:42:40	\N
25542	661	2017-12-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2017-12-05 14:42:58	\N
25789	581	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	2018-01-10 11:21:23	\N
25790	600	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	2018-01-10 11:21:23	\N
25800	615	2018-01-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	16685X	2018-01-12 14:04:36	\N
25943	909	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08015R	\N	\N
26187	912	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08045X	\N	\N
26215	647	2018-01-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04092N	2018-02-01 16:30:15	\N
26216	647	2018-02-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	98029W	2018-02-01 17:14:58	\N
26217	584	2018-02-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14197C	2018-02-01 17:17:15	\N
26295	919	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	16685X	\N	\N
26309	919	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
26311	919	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19349W	\N	\N
26312	919	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	19269X	\N	\N
26626	908	2018-03-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19447X	\N	\N
26643	852	2018-01-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01057W	2018-03-12 15:59:19	\N
26684	1008	2018-03-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
26773	578	2018-05-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14115H	2018-06-05 15:48:32	\N
26777	586	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	2018-06-08 16:10:41	\N
26899	948	2018-11-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19347U	\N	\N
26900	911	2018-11-06 00:00:00	2019-03-01 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
26939	674	2019-01-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19693L	\N	\N
26953	1005	2019-02-22 00:00:00	2019-03-05 00:00:00	ANCIEN	\N	\N	\N	11101A	\N	\N
26956	998	2017-10-01 00:00:00	2020-08-06 00:00:00	ANCIEN	\N	\N	\N	19782L	\N	\N
27069	659	2020-01-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
27260	651	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20044X	\N	\N
27261	594	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20044X	\N	\N
27262	576	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	18083K	\N	\N
27263	608	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	18083K	\N	\N
27264	618	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	18083K	\N	\N
27265	574	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	18083K	\N	\N
27266	646	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	18083K	\N	\N
27267	588	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	18083K	\N	\N
27268	661	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	18083K	\N	\N
27269	596	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	18083K	\N	\N
27270	575	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	18083K	\N	\N
27271	622	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	18083K	\N	\N
27272	572	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	18083K	\N	\N
27273	573	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	18083K	\N	\N
27274	641	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14055N	\N	\N
27275	632	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01028R	\N	\N
27276	620	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01028R	\N	\N
27277	596	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01028R	\N	\N
27278	602	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01028R	\N	\N
27279	595	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01028R	\N	\N
27280	600	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19745F	\N	\N
27281	626	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19745F	\N	\N
27282	613	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19745F	\N	\N
27283	577	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19745F	\N	\N
27284	596	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19745F	\N	\N
27285	589	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19745F	\N	\N
27286	629	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08034U	\N	\N
27287	605	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08010L	\N	\N
27288	597	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08010L	\N	\N
27289	598	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08010L	\N	\N
27290	604	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08010L	\N	\N
27291	673	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08010L	\N	\N
27292	590	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08010L	\N	\N
27293	581	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01057W	\N	\N
27294	605	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01057W	\N	\N
27295	620	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01057W	\N	\N
27296	852	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01057W	\N	\N
27297	608	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01057W	\N	\N
27298	598	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01057W	\N	\N
27299	589	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01057W	\N	\N
27300	632	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
27301	605	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
27302	571	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
27303	597	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
27304	641	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
27305	580	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
27306	634	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
27307	602	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
27308	629	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
27309	618	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19739H	\N	\N
27310	556	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19739H	\N	\N
27311	626	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19741B	\N	\N
27312	621	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19741B	\N	\N
27313	978	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19741B	\N	\N
27314	629	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19741B	\N	\N
27315	623	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11072N	\N	\N
27316	622	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11072N	\N	\N
27317	581	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14071N	\N	\N
27318	626	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14071N	\N	\N
27319	609	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14071N	\N	\N
27320	651	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14071N	\N	\N
27321	578	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14071N	\N	\N
27322	612	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14071N	\N	\N
27323	596	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14071N	\N	\N
27324	573	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14071N	\N	\N
29804	1008	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11077T	\N	\N
29991	919	2021-01-20 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14133K	\N	\N
30236	966	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20084G	\N	\N
30247	933	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20042V	\N	\N
31001	595	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19705W	\N	\N
31002	641	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19705W	\N	\N
31037	663	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14031R	\N	\N
31038	978	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14031R	\N	\N
31105	573	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20148F	\N	\N
31106	642	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20148F	\N	\N
31107	599	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20148F	\N	\N
31145	979	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19629C	\N	\N
31528	574	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19565D	\N	\N
31529	575	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19565D	\N	\N
31530	609	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19565D	\N	\N
31531	572	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19565D	\N	\N
31532	573	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19565D	\N	\N
31591	595	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20108W	\N	\N
31834	589	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14069U	\N	\N
31835	600	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14069U	\N	\N
31836	590	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14069U	\N	\N
31837	659	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14069U	\N	\N
31838	591	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14069U	\N	\N
31839	579	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14069U	\N	\N
31840	621	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14069U	\N	\N
31841	572	2023-10-17 00:00:00	2023-10-18 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
31842	596	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14069U	\N	\N
31843	576	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14069U	\N	\N
31844	592	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14069U	\N	\N
31857	625	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19649G	\N	\N
31858	597	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19649G	\N	\N
31859	576	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19649G	\N	\N
31860	590	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19649G	\N	\N
31861	618	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19649G	\N	\N
31862	596	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19649G	\N	\N
31863	583	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19649G	\N	\N
31864	632	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19649G	\N	\N
31865	595	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19649G	\N	\N
32297	530	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14213J	\N	\N
32298	602	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14213J	\N	\N
32299	583	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14213J	\N	\N
32300	596	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14213J	\N	\N
32301	653	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14213J	\N	\N
32302	573	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14213J	\N	\N
33301	599	2023-12-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19611R	\N	\N
33367	632	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20064C	\N	\N
33388	580	2023-12-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21040X	\N	\N
33389	621	2023-12-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21040X	\N	\N
33603	1004	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	14030Q	\N	\N
33654	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19820Y	\N	\N
33657	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14179A	\N	\N
33669	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	11043H	\N	\N
33911	918	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20032T	\N	\N
33913	1005	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14329V	\N	\N
34080	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20062A	\N	\N
34083	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14173T	\N	\N
34089	922	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19820Y	\N	\N
34096	957	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21052C	\N	\N
34103	998	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14083S	\N	\N
34104	998	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14195A	\N	\N
34105	998	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21065H	\N	\N
34112	998	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21040X	\N	\N
34118	957	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21064G	\N	\N
34208	1008	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20122U	\N	\N
34296	908	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	14211G	\N	\N
34298	659	2024-02-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20052X	\N	\N
34318	919	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	08045X	\N	\N
25376	532	2017-11-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	2017-11-22 09:44:26	\N
25979	586	2018-01-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04034C	2018-01-22 14:54:01	\N
26343	1005	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	\N	\N
26344	1005	2018-01-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14207L	\N	\N
26345	1005	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14085U	\N	\N
26346	1005	2018-01-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	\N	\N
26641	532	2018-03-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11085T	2018-03-12 14:56:35	\N
26747	588	2018-04-11 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14135M	2018-04-13 10:43:03	\N
26952	919	2019-01-22 00:00:00	2020-08-06 00:00:00	ANCIEN	\N	\N	\N	19782L	\N	\N
26962	1005	2019-01-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11101A	\N	\N
26989	1005	2019-01-22 00:00:00	2020-08-06 00:00:00	ANCIEN	\N	\N	\N	19782L	\N	\N
27107	590	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19489J	\N	\N
27108	596	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19489J	\N	\N
27109	602	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19489J	\N	\N
27110	598	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19699S	\N	\N
27111	622	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19699S	\N	\N
27112	617	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19699S	\N	\N
27113	597	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19699S	\N	\N
27114	573	2020-10-07 00:00:00	2020-10-27 00:00:00	ANCIEN	\N	\N	\N	19301E	\N	\N
27115	616	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	10015M	\N	\N
27116	627	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	10015M	\N	\N
27117	595	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	10015M	\N	\N
27118	573	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	10015M	\N	\N
27119	534	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	10015M	\N	\N
27120	556	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	10015M	\N	\N
27121	661	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	10015M	\N	\N
27122	598	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19693L	\N	\N
27123	621	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19693L	\N	\N
27124	674	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19693L	\N	\N
27125	590	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19693L	\N	\N
27126	598	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19443T	\N	\N
27127	621	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19443T	\N	\N
27128	644	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19443T	\N	\N
27129	621	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19415P	\N	\N
27130	601	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19415P	\N	\N
27131	610	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19415P	\N	\N
27132	590	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19467C	\N	\N
27133	610	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19467C	\N	\N
27134	572	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14237S	\N	\N
27135	618	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14237S	\N	\N
27136	659	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14237S	\N	\N
27137	610	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14237S	\N	\N
27138	597	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14237S	\N	\N
28671	576	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04071H	\N	\N
28672	616	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11048N	\N	\N
28673	597	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11048N	\N	\N
28674	629	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11048N	\N	\N
28675	580	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11048N	\N	\N
28676	640	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11048N	\N	\N
28677	575	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20112S	\N	\N
28678	642	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20112S	\N	\N
28679	979	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20112S	\N	\N
28680	626	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20112S	\N	\N
28681	622	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20112S	\N	\N
28682	641	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20112S	\N	\N
28683	591	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19725B	\N	\N
28712	674	2020-11-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19699S	\N	\N
29569	948	2020-12-28 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20062A	\N	\N
29840	1004	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11097X	\N	\N
29933	619	2021-01-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14249W	\N	\N
29934	534	2021-01-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14031R	\N	\N
30090	1008	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20134Y	\N	\N
30369	907	2021-06-30 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
30433	1010	2021-10-12 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20098N	\N	\N
30435	1010	2021-10-12 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20118Y	\N	\N
30502	906	2022-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11070L	\N	\N
31066	673	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19399H	\N	\N
31354	629	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21058J	\N	\N
31355	583	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21058J	\N	\N
31356	602	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21058J	\N	\N
31357	626	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21058J	\N	\N
31426	590	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19489J	\N	\N
31427	602	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19489J	\N	\N
31428	596	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19489J	\N	\N
31441	589	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21044C	\N	\N
31442	963	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21044C	\N	\N
31452	573	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20070A	\N	\N
31453	643	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20070A	\N	\N
32750	641	2023-11-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14021P	\N	\N
32751	583	2023-11-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14021P	\N	\N
32752	595	2023-11-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14021P	\N	\N
32753	576	2023-11-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14021P	\N	\N
32754	596	2023-11-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14021P	\N	\N
32755	530	2023-11-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14021P	\N	\N
34334	918	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	19768N	\N	\N
34340	918	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	19679N	\N	\N
34480	623	2024-03-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14189C	\N	\N
34481	530	2024-03-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14189C	\N	\N
34497	577	2024-04-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19669L	\N	\N
28921	609	2020-11-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19663E	\N	\N
29003	963	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14111D	\N	\N
29004	579	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14111D	\N	\N
29005	588	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14111D	\N	\N
29006	651	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14111D	\N	\N
29007	556	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14111D	\N	\N
29008	661	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14111D	\N	\N
29009	594	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14111D	\N	\N
29010	529	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14111D	\N	\N
29011	550	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14111D	\N	\N
29675	912	2020-12-18 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14033T	\N	\N
29677	948	2020-12-18 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14033T	\N	\N
29682	1005	2021-01-12 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20082E	\N	\N
29683	911	2021-01-12 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20082E	\N	\N
29706	907	2021-01-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14329V	\N	\N
29707	909	2021-01-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14329V	\N	\N
30554	530	2022-03-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20118Y	\N	\N
30669	600	2022-09-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20248J	\N	\N
30670	659	2022-09-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20248J	\N	\N
31003	604	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08018U	\N	\N
31004	608	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08018U	\N	\N
31005	556	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08018U	\N	\N
31006	642	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08018U	\N	\N
31007	663	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08018U	\N	\N
31008	534	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08018U	\N	\N
31009	629	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08018U	\N	\N
31010	572	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08018U	\N	\N
31011	641	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08018U	\N	\N
31012	609	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08018U	\N	\N
31013	598	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08018U	\N	\N
31014	653	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08018U	\N	\N
31015	595	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08018U	\N	\N
31016	573	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08018U	\N	\N
31017	592	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08018U	\N	\N
31018	586	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08018U	\N	\N
31019	622	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08018U	\N	\N
31020	673	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08018U	\N	\N
31021	643	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08018U	\N	\N
31279	621	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19749K	\N	\N
31280	572	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19749K	\N	\N
31281	583	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19749K	\N	\N
31282	530	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19749K	\N	\N
31283	573	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19749K	\N	\N
31284	622	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19749K	\N	\N
31285	604	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19749K	\N	\N
31306	621	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20036X	\N	\N
32252	851	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11115U	\N	\N
32253	529	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11115U	\N	\N
32254	589	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11115U	\N	\N
32255	573	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11115U	\N	\N
32256	605	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11115U	\N	\N
32257	604	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11115U	\N	\N
32258	609	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11115U	\N	\N
32259	596	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11115U	\N	\N
32260	611	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11115U	\N	\N
32261	532	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11115U	\N	\N
32262	590	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11115U	\N	\N
32263	592	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11115U	\N	\N
32264	626	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11115U	\N	\N
32265	647	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11115U	\N	\N
32266	582	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11115U	\N	\N
32267	674	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11115U	\N	\N
32268	576	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11115U	\N	\N
32269	574	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11115U	\N	\N
32270	979	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11115U	\N	\N
32271	642	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11115U	\N	\N
32272	584	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11115U	\N	\N
32273	581	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11115U	\N	\N
32274	610	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11115U	\N	\N
32275	598	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11115U	\N	\N
33364	653	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19531S	\N	\N
33365	646	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19531S	\N	\N
33366	632	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19531S	\N	\N
34365	604	2024-02-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19782L	\N	\N
25526	624	2017-11-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19629C	2017-12-01 15:49:40	\N
25527	657	2017-11-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	2017-12-01 16:29:16	\N
26338	608	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19619A	2018-02-08 14:48:57	\N
26347	1005	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	17589D	\N	\N
26349	1005	2019-02-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14249W	\N	\N
26356	1005	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14213J	\N	\N
26670	1008	2018-03-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11048N	\N	\N
26674	1008	2018-03-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
26681	1008	2018-03-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14031R	\N	\N
26682	1008	2018-03-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
26704	852	2018-03-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	2018-03-15 18:59:35	\N
26765	934	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19489J	\N	\N
26969	957	2019-02-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19762G	\N	\N
26980	911	2017-10-01 00:00:00	2017-10-02 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
26981	948	2017-10-01 00:00:00	2019-03-05 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
27102	597	2020-08-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	\N	\N
27325	584	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14071N	\N	\N
27326	629	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14071N	\N	\N
27327	632	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11054L	\N	\N
27655	661	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19826F	\N	\N
27656	622	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19826F	\N	\N
27657	583	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19826F	\N	\N
27658	626	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	12041X	\N	\N
27659	584	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	12041X	\N	\N
27660	661	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19329S	\N	\N
27661	659	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19329S	\N	\N
27662	622	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19329S	\N	\N
27663	573	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19329S	\N	\N
27664	653	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19329S	\N	\N
27665	608	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20054A	\N	\N
27666	643	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20054A	\N	\N
27667	604	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20054A	\N	\N
27668	610	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20054A	\N	\N
27669	634	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20054A	\N	\N
27670	590	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20054A	\N	\N
27707	852	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14147R	\N	\N
27708	609	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14147R	\N	\N
27709	653	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14147R	\N	\N
27710	580	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14147R	\N	\N
27711	619	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14147R	\N	\N
28455	622	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19631V	\N	\N
28456	530	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19713W	\N	\N
28457	597	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20138D	\N	\N
28458	595	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20138D	\N	\N
28459	596	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20138D	\N	\N
28460	673	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20138D	\N	\N
28461	621	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20138D	\N	\N
28462	623	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20138D	\N	\N
28463	621	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20152B	\N	\N
28464	CHRETORIENT	2020-10-27 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	17367Q	\N	\N
28559	576	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19695N	\N	\N
28560	556	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19695N	\N	\N
28561	595	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20098N	\N	\N
28562	625	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20098N	\N	\N
28653	CHRETORIENT	2020-10-23 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	20042V	\N	\N
28654	591	2020-10-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20042V	\N	\N
28655	608	2020-10-23 00:00:00	2022-04-11 00:00:00	ANCIEN	\N	\N	\N	20042V	\N	\N
28656	583	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19525U	\N	\N
28657	530	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19525U	\N	\N
28658	598	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19525U	\N	\N
28659	583	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20048C	\N	\N
28660	609	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20048C	\N	\N
28661	590	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20048C	\N	\N
28662	629	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20048C	\N	\N
28663	610	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20048C	\N	\N
28664	634	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20048C	\N	\N
28665	641	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20048C	\N	\N
28666	594	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20048C	\N	\N
28667	673	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20048C	\N	\N
28668	611	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20048C	\N	\N
28669	572	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20048C	\N	\N
28670	576	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20048C	\N	\N
29036	604	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
29037	580	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19760E	\N	\N
29038	600	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19760E	\N	\N
29039	584	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19760E	\N	\N
29508	922	2020-12-18 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20106U	\N	\N
29625	909	2021-01-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14357A	\N	\N
29652	906	2021-01-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19711U	\N	\N
29697	919	2021-01-13 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14026U	\N	\N
29698	907	2021-01-13 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14026U	\N	\N
29720	907	2021-01-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	18083K	\N	\N
29721	911	2021-01-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	18083K	\N	\N
29722	912	2021-01-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	18083K	\N	\N
29815	1008	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20044X	\N	\N
29816	1008	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20064C	\N	\N
30137	1010	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19741B	\N	\N
30138	1010	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19621T	\N	\N
30316	603	2021-03-31 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20130U	\N	\N
30348	1012	2021-06-09 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14083S	\N	\N
30518	615	2022-02-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20084G	\N	\N
30520	609	2022-02-02 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	20108W	\N	\N
30523	550	2022-02-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	95041E	\N	\N
30582	1013	2022-04-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	12028B	\N	\N
30634	934	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19782L	\N	\N
30648	615	2022-07-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20124W	\N	\N
30686	625	2022-09-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20248J	\N	\N
30687	588	2022-09-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	\N	\N
30698	618	2022-10-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19673G	\N	\N
30701	582	2022-11-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14151M	\N	\N
30702	623	2022-11-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11054L	\N	\N
30736	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	14042U	\N	\N
32348	613	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20096L	\N	\N
32363	590	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21095P	\N	\N
32714	673	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19383Y	\N	\N
28787	674	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19577H	\N	\N
28788	618	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19577H	\N	\N
28789	622	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19577H	\N	\N
29293	907	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11103C	\N	\N
29496	1005	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19369B	\N	\N
29589	908	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14053L	\N	\N
29607	906	2021-01-04 00:00:00	2022-06-20 00:00:00	ANCIEN	\N	\N	\N	20174H	\N	\N
29613	922	2021-01-06 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14237S	\N	\N
29614	918	2021-01-06 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14237S	\N	\N
29678	653	2021-01-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20110Q	\N	\N
29691	911	2021-01-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19667J	\N	\N
29712	575	2021-01-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19531S	\N	\N
29732	922	2021-01-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
29969	919	2021-01-20 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14071N	\N	\N
30135	1010	2021-02-03 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	04034C	\N	\N
30864	641	2023-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20056C	\N	\N
30866	617	2023-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20056C	\N	\N
30867	1013	2023-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20056C	\N	\N
30868	616	2023-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20056C	\N	\N
30873	588	2023-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20056C	\N	\N
30874	602	2023-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20056C	\N	\N
30978	663	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14221J	\N	\N
30979	963	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14221J	\N	\N
30980	594	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14221J	\N	\N
30981	659	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14221J	\N	\N
30998	581	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14109K	\N	\N
30999	641	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14109K	\N	\N
31000	1013	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14109K	\N	\N
31330	621	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19954N	\N	\N
31331	604	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19954N	\N	\N
31332	653	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19954N	\N	\N
31333	629	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19954N	\N	\N
31334	609	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19954N	\N	\N
31335	580	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19954N	\N	\N
31336	596	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19954N	\N	\N
31337	577	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19954N	\N	\N
31574	663	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20044X	\N	\N
31575	594	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20044X	\N	\N
31576	978	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20044X	\N	\N
33254	623	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11110B	\N	\N
33255	584	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11110B	\N	\N
33310	595	2023-12-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14071N	\N	\N
33326	595	2023-12-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14267Y	\N	\N
33327	632	2023-12-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14267Y	\N	\N
33335	633	2023-12-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19551W	\N	\N
33336	632	2023-12-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19711U	\N	\N
33385	619	2023-12-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14071N	\N	\N
33487	588	2024-01-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14071N	\N	\N
33643	928	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	20064C	\N	\N
33903	1005	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20088L	\N	\N
33915	1005	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14038Y	\N	\N
33916	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14193X	\N	\N
34074	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20092G	\N	\N
34173	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	05012A	\N	\N
34176	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21056G	\N	\N
34190	621	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21041Y	\N	\N
34293	979	2024-02-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20116W	\N	\N
34294	589	2024-02-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20116W	\N	\N
25226	978	2017-11-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	95037J	2017-11-10 11:39:17	\N
25227	594	2017-11-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	95037J	2017-11-10 11:39:17	\N
25228	611	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19651A	2017-11-10 12:13:11	\N
25529	661	2017-11-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19507S	2017-12-04 15:40:15	\N
25530	963	2017-12-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14085U	2017-12-04 15:40:37	\N
25757	1007	2017-12-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08024S	\N	\N
25760	934	2017-10-01 00:00:00	2018-11-03 00:00:00	ANCIEN	\N	\N	\N	19251M	\N	\N
25762	934	2017-10-01 00:00:00	2018-08-06 00:00:00	ANCIEN	\N	\N	\N	95015C	\N	\N
26218	530	2018-01-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19713W	2018-02-02 09:19:22	\N
26219	610	2018-01-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14031R	2018-02-02 09:19:40	\N
26220	647	2018-01-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14042U	2018-02-02 09:20:02	\N
26221	534	2018-01-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2018-02-02 09:20:22	\N
26256	919	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08055A	\N	\N
26257	919	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
26277	919	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14249W	\N	\N
26281	919	2018-01-23 00:00:00	2020-06-27 00:00:00	ANCIEN	\N	\N	\N	14199E	\N	\N
26283	919	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	\N	\N
26284	919	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14026U	\N	\N
26289	919	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14213J	\N	\N
26308	919	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19745F	\N	\N
26313	919	2018-01-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11012A	\N	\N
26315	919	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19619A	\N	\N
26319	919	2018-01-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14207L	\N	\N
26348	1005	2018-01-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14197C	\N	\N
26363	1005	2018-01-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08053X	\N	\N
26368	1005	2018-01-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19503N	\N	\N
26766	661	2018-05-22 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14249W	2018-05-29 09:39:04	\N
26811	595	2018-09-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19643A	\N	\N
26825	622	2018-09-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19631V	\N	\N
26827	610	2018-09-24 00:00:00	2020-07-31 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	\N
26864	610	2018-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14357A	\N	\N
27050	661	2019-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	18083K	\N	\N
27712	583	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19717B	\N	\N
27713	594	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19717B	\N	\N
27714	602	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19717B	\N	\N
27715	573	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19717B	\N	\N
29546	919	2020-12-18 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19735D	\N	\N
29547	911	2020-12-18 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19735D	\N	\N
29548	912	2020-12-18 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19735D	\N	\N
29632	919	2021-01-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14357A	\N	\N
29772	909	2021-01-18 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20114U	\N	\N
29773	919	2021-01-18 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20114U	\N	\N
29774	1005	2021-01-18 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20114U	\N	\N
30008	1008	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	04070G	\N	\N
30360	919	2021-06-22 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19820Y	\N	\N
30361	1012	2021-06-22 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19820Y	\N	\N
30602	1013	2022-04-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14109K	\N	\N
30815	596	2023-03-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20024T	\N	\N
30878	623	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20026V	\N	\N
30879	1013	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20026V	\N	\N
30880	641	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20026V	\N	\N
30881	578	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20026V	\N	\N
30882	597	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20026V	\N	\N
30883	581	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20026V	\N	\N
30884	618	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20026V	\N	\N
30885	583	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20026V	\N	\N
30886	663	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20026V	\N	\N
30887	634	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20026V	\N	\N
30888	609	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20026V	\N	\N
30889	599	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20026V	\N	\N
30890	590	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20026V	\N	\N
30891	626	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20026V	\N	\N
30892	602	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20056C	\N	\N
30893	623	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20056C	\N	\N
30894	1013	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20056C	\N	\N
30895	641	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20056C	\N	\N
30896	661	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20056C	\N	\N
30897	574	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20056C	\N	\N
30898	615	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20056C	\N	\N
30899	634	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20056C	\N	\N
30900	617	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20056C	\N	\N
30901	591	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20056C	\N	\N
30902	646	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20056C	\N	\N
30903	616	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20056C	\N	\N
30904	588	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20056C	\N	\N
30905	596	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20056C	\N	\N
30906	599	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20056C	\N	\N
30907	590	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20056C	\N	\N
30908	626	2023-10-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20056C	\N	\N
32711	573	2023-11-03 00:00:00	2023-11-03 00:00:00	ANCIEN	\N	\N	\N	21097R	\N	\N
32712	583	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21097R	\N	\N
32713	623	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21097R	\N	\N
32781	612	2023-11-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20054A	\N	\N
33105	609	2023-11-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20180F	\N	\N
33386	572	2023-12-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21045D	\N	\N
33396	661	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20140W	\N	\N
33397	605	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20140W	\N	\N
33398	609	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20140W	\N	\N
33464	1008	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21090J	\N	\N
34323	909	2023-12-14 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	08061X	\N	\N
29467	922	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19739H	\N	\N
29950	1006	2020-10-01 00:00:00	2026-03-01 00:00:00	ACTIF	\N	\N	\N	14069U	\N	\N
29951	1007	2020-10-01 00:00:00	2026-03-01 00:00:00	ACTIF	\N	\N	\N	14069U	\N	\N
29952	934	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19631V	\N	\N
30020	934	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
30041	919	2021-01-25 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14083S	\N	\N
30042	919	2021-01-26 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14259Y	\N	\N
30043	919	2021-01-26 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20026V	\N	\N
30972	646	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19723Y	\N	\N
30973	625	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19723Y	\N	\N
30974	530	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19723Y	\N	\N
30975	592	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19723Y	\N	\N
30976	616	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19723Y	\N	\N
30977	626	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19723Y	\N	\N
31341	852	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14147R	\N	\N
31342	619	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14147R	\N	\N
31343	583	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14147R	\N	\N
31344	592	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14147R	\N	\N
31345	673	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14147R	\N	\N
31346	629	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14147R	\N	\N
31347	602	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14147R	\N	\N
31348	581	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14147R	\N	\N
31349	609	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14147R	\N	\N
31350	530	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14147R	\N	\N
31402	616	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14059S	\N	\N
31403	640	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14059S	\N	\N
31404	618	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14059S	\N	\N
31405	625	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14059S	\N	\N
31406	579	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14059S	\N	\N
31407	609	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14059S	\N	\N
31408	661	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14059S	\N	\N
31409	622	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14059S	\N	\N
31433	613	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14059S	\N	\N
31936	576	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	07033P	\N	\N
33520	966	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	18395Y	\N	\N
33849	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19575F	\N	\N
33862	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14357A	\N	\N
33863	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	11070L	\N	\N
34038	1011	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19575F	\N	\N
34045	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20056C	\N	\N
34084	922	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	08028W	\N	\N
34087	922	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19507S	\N	\N
34102	998	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20110Q	\N	\N
34181	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20058E	\N	\N
34244	550	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14059S	\N	\N
34311	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	\N	\N	\N	\N	21039F	\N	\N
34344	918	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	20140W	\N	\N
25508	592	2017-11-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19585H	2017-11-30 14:57:42	\N
25509	851	2017-11-29 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08031R	2017-11-30 14:59:02	\N
25510	588	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19421M	2017-11-30 14:59:48	\N
25511	617	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19421M	2017-11-30 14:59:48	\N
25512	673	2017-11-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	2017-11-30 15:00:09	\N
25513	604	2017-11-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14215L	2017-11-30 15:00:29	\N
25514	653	2017-11-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04047H	2017-11-30 15:00:42	\N
25515	646	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14225N	2017-11-30 15:39:24	\N
25699	574	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	18083K	2017-12-21 15:14:50	\N
25700	617	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19611R	2017-12-21 15:15:00	\N
25701	571	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	2017-12-21 15:15:32	\N
25702	851	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	2017-12-21 15:15:33	\N
25703	530	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	2017-12-21 15:15:33	\N
25704	556	2017-12-20 00:00:00	2020-08-02 00:00:00	ANCIEN	\N	\N	\N	14239U	2017-12-21 15:15:48	\N
25705	673	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	05008E	2017-12-21 15:16:07	\N
26164	909	2017-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14259Y	\N	\N
26197	912	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04044E	\N	\N
26198	912	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14173T	\N	\N
26226	646	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11064N	2018-02-02 15:51:11	\N
26227	582	2018-02-02 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11064N	2018-02-02 15:51:52	\N
26228	616	2018-01-31 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14093U	2018-02-02 15:52:11	\N
26229	648	2018-02-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	2018-02-02 15:52:56	\N
26230	609	2018-02-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	2018-02-02 15:52:56	\N
26318	919	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08049C	\N	\N
26511	908	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14331P	\N	\N
26592	957	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19511N	\N	\N
26593	919	2018-02-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19511N	\N	\N
26613	596	2018-02-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19575F	2018-03-02 11:02:30	\N
26614	938	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
26743	928	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01025N	\N	\N
26791	907	2018-07-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14237S	\N	\N
26793	598	2018-07-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19760E	\N	\N
26794	632	2018-07-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19760E	\N	\N
26955	906	2017-10-01 00:00:00	2020-08-06 00:00:00	ANCIEN	\N	\N	\N	19782L	\N	\N
26957	907	2017-10-01 00:00:00	2020-08-06 00:00:00	ANCIEN	\N	\N	\N	19782L	\N	\N
27328	602	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19387D	\N	\N
27329	594	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19387D	\N	\N
29151	618	2020-12-01 00:00:00	2021-10-07 00:00:00	ANCIEN	\N	\N	\N	20132W	\N	\N
29488	908	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	05008E	\N	\N
29513	582	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
29514	616	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
29515	585	2020-12-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08060W	\N	\N
29516	646	2020-12-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
29550	948	2020-12-23 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19723Y	\N	\N
29551	909	2020-12-23 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19723Y	\N	\N
29571	911	2020-12-28 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20062A	\N	\N
29572	912	2020-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14133K	\N	\N
29633	919	2021-01-07 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19725B	\N	\N
30428	571	2021-10-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14059S	\N	\N
30571	1013	2022-04-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19515S	\N	\N
30572	1013	2022-04-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17367Q	\N	\N
31498	626	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19687N	\N	\N
31499	979	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19687N	\N	\N
31500	621	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19687N	\N	\N
31501	620	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19687N	\N	\N
31502	573	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19687N	\N	\N
31503	575	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19687N	\N	\N
31504	601	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19687N	\N	\N
32715	619	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19507S	\N	\N
32763	574	2023-11-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21033Y	\N	\N
32764	601	2023-11-07 00:00:00	2029-11-27 00:00:00	ACTIF	\N	\N	\N	21033Y	\N	\N
32765	591	2023-11-07 00:00:00	2029-11-27 00:00:00	ACTIF	\N	\N	\N	21033Y	\N	\N
32766	585	2023-11-07 00:00:00	2029-11-27 00:00:00	ACTIF	\N	\N	\N	21033Y	\N	\N
32827	623	2023-11-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08061X	\N	\N
32854	575	2023-11-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19669L	\N	\N
32855	623	2023-11-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19669L	\N	\N
32869	571	2023-11-13 00:00:00	2023-11-13 00:00:00	ANCIEN	\N	\N	\N	20046A	\N	\N
32870	632	2023-11-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20046A	\N	\N
32871	641	2023-11-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20046A	\N	\N
32897	634	2023-11-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19667J	\N	\N
33040	613	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04008A	\N	\N
33044	634	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20140W	\N	\N
33045	673	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20140W	\N	\N
33065	615	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20052X	\N	\N
33090	623	2023-11-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11074Q	\N	\N
33091	575	2023-11-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11074Q	\N	\N
33092	598	2023-11-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11074Q	\N	\N
33093	661	2023-11-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11074Q	\N	\N
33094	577	2023-11-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11074Q	\N	\N
33095	573	2023-11-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11074Q	\N	\N
33096	852	2023-11-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11074Q	\N	\N
33143	620	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19669L	\N	\N
33144	581	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19669L	\N	\N
33145	1013	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19669L	\N	\N
33146	632	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19669L	\N	\N
33147	979	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19669L	\N	\N
33148	648	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19669L	\N	\N
33149	556	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19669L	\N	\N
33150	618	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19669L	\N	\N
33151	598	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19669L	\N	\N
33152	661	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19669L	\N	\N
33153	530	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19669L	\N	\N
33154	625	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19669L	\N	\N
33158	618	2023-11-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17023S	\N	\N
33159	572	2023-11-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21094N	\N	\N
33168	572	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21067K	\N	\N
33173	598	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21047F	\N	\N
33174	610	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21047F	\N	\N
33198	651	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17023S	\N	\N
33199	641	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17023S	\N	\N
33200	586	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17023S	\N	\N
33201	594	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17023S	\N	\N
28871	609	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
28872	595	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
28873	629	2020-11-09 00:00:00	2021-10-07 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
28874	582	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
28875	661	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
28876	608	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
28877	574	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
28878	620	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
28879	651	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
28880	663	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
28902	618	2020-11-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	98022P	\N	\N
29191	582	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19585H	\N	\N
29192	579	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19367Y	\N	\N
29283	659	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	\N	\N
29318	907	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19760E	\N	\N
29319	919	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19760E	\N	\N
29489	908	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14097Y	\N	\N
29490	918	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14097Y	\N	\N
29622	918	2021-01-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19866P	\N	\N
30143	1007	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14083S	\N	\N
30576	934	2020-10-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19703U	\N	\N
30793	1014	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11064N	\N	\N
31085	594	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19826F	\N	\N
31086	612	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19826F	\N	\N
31087	661	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19826F	\N	\N
31088	659	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19826F	\N	\N
31089	622	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19826F	\N	\N
31090	578	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19826F	\N	\N
31243	590	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20128B	\N	\N
31416	575	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21091K	\N	\N
31417	613	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21091K	\N	\N
31418	597	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21091K	\N	\N
31585	530	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21043B	\N	\N
31586	595	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21043B	\N	\N
31587	598	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21043B	\N	\N
31588	584	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21043B	\N	\N
31589	623	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21043B	\N	\N
31590	624	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21043B	\N	\N
31657	640	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19711U	\N	\N
31658	597	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19711U	\N	\N
31659	595	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19711U	\N	\N
31660	617	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19711U	\N	\N
31661	641	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19711U	\N	\N
31662	1013	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19711U	\N	\N
31786	642	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20034V	\N	\N
31787	651	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20034V	\N	\N
31788	601	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20034V	\N	\N
32577	623	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14073Q	\N	\N
33526	963	2024-01-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14133K	\N	\N
33790	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19563B	\N	\N
33791	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20028X	\N	\N
33792	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14223L	\N	\N
33793	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14109K	\N	\N
33864	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20040T	\N	\N
34002	908	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21062E	\N	\N
34003	908	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19820Y	\N	\N
34004	908	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21032X	\N	\N
34006	912	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	05008E	\N	\N
34012	912	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	18083K	\N	\N
34013	908	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14213J	\N	\N
34016	912	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19735D	\N	\N
34029	908	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	04070G	\N	\N
34255	576	2024-01-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20138D	\N	\N
34256	617	2024-01-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19593H	\N	\N
34257	663	2024-01-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19593H	\N	\N
34258	576	2024-01-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17023S	\N	\N
34259	611	2024-01-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17023S	\N	\N
34261	550	2024-01-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19507S	\N	\N
34319	912	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	08045X	\N	\N
25424	657	2017-11-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	2017-11-24 09:41:29	\N
25425	550	2017-11-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19585H	2017-11-24 09:47:21	\N
25426	661	2017-11-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19585H	2017-11-24 09:47:21	\N
25427	529	2017-11-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19585H	2017-11-24 09:47:21	\N
25428	625	2017-11-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08038Y	2017-11-24 09:47:56	\N
25429	575	2017-11-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08038Y	2017-11-24 09:47:56	\N
25430	588	2017-11-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08038Y	2017-11-24 09:47:56	\N
25431	584	2017-11-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08038Y	2017-11-24 09:49:37	\N
25432	578	2017-11-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08038Y	2017-11-24 09:49:37	\N
25433	643	2017-11-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19569H	2017-11-24 09:50:34	\N
25434	597	2017-11-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19569H	2017-11-24 09:50:34	\N
25435	594	2017-11-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19569H	2017-11-24 09:50:34	\N
25436	573	2017-11-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19569H	2017-11-24 09:50:34	\N
25437	626	2017-11-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19569H	2017-11-24 09:50:34	\N
25438	584	2017-11-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	2017-11-24 09:51:19	\N
25439	613	2017-11-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	2017-11-24 09:51:19	\N
25440	623	2017-11-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	2017-11-24 09:51:19	\N
25441	634	2017-11-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	2017-11-24 09:51:19	\N
25442	595	2017-11-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	2017-11-24 09:51:19	\N
25443	632	2017-11-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	2017-11-24 09:51:19	\N
25444	596	2017-11-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	2017-11-24 09:51:19	\N
25445	963	2017-11-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19631V	2017-11-24 09:51:39	\N
25446	573	2017-11-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08012N	2017-11-24 09:51:56	\N
25447	633	2017-11-20 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08058D	2017-11-24 09:52:41	\N
25448	583	2017-11-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19735D	2017-11-24 09:52:59	\N
25449	651	2017-11-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11010L	2017-11-24 09:53:14	\N
25450	592	2017-11-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08061X	2017-11-24 09:53:27	\N
25451	529	2017-11-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14073Q	2017-11-24 10:20:38	\N
25452	589	2017-11-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19721W	2017-11-24 10:20:52	\N
25453	577	2017-11-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08045X	2017-11-24 10:21:07	\N
25454	851	2017-11-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19563B	2017-11-24 10:21:23	\N
25599	530	2017-12-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14169X	2017-12-08 16:41:52	\N
25600	CHRETORIENT	2017-11-29 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	19447X	2017-12-08 16:47:38	\N
25759	934	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14073Q	\N	\N
25763	966	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
25764	1006	2017-12-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08024S	\N	\N
25765	1006	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11041F	\N	\N
25997	948	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	80013X	\N	\N
26050	906	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19681G	\N	\N
26136	998	2017-10-01 00:00:00	2020-06-24 00:00:00	ANCIEN	\N	\N	\N	19727D	\N	\N
26137	998	2017-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	19581D	\N	\N
26178	582	2018-01-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19593H	2018-01-31 12:21:35	\N
26324	534	2018-01-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19349W	2018-02-07 11:00:01	\N
26325	578	2018-02-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14001X	2018-02-07 11:00:12	\N
26326	615	2018-02-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14001X	2018-02-07 11:03:33	\N
26327	584	2018-02-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14109K	2018-02-07 11:04:49	\N
26492	1005	2018-02-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08012N	\N	\N
26537	912	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19447X	\N	\N
26615	908	2018-02-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	96004D	\N	\N
26734	911	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19441R	\N	\N
26763	602	2018-05-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19717B	2018-05-22 15:34:30	\N
26803	588	2018-09-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	98029W	\N	\N
26804	576	2018-09-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11045K	\N	\N
26983	911	2019-02-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11033F	\N	\N
27071	573	2020-01-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	12016W	\N	\N
27072	618	2020-01-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	12016W	\N	\N
27073	590	2020-01-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	12016W	\N	\N
27074	617	2020-01-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14021P	\N	\N
27754	641	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19782L	\N	\N
28194	651	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20074E	\N	\N
28195	609	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20074E	\N	\N
28196	598	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19591F	\N	\N
28197	575	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19591F	\N	\N
28198	617	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19591F	\N	\N
28199	978	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19591F	\N	\N
28205	609	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	\N	\N
28206	589	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19527W	\N	\N
28207	583	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19527W	\N	\N
28208	572	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20092G	\N	\N
28209	576	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20092G	\N	\N
28210	640	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20092G	\N	\N
28211	608	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19563B	\N	\N
28212	629	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19563B	\N	\N
28213	851	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19563B	\N	\N
28214	601	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08034U	\N	\N
28215	609	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19531S	\N	\N
28216	622	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19531S	\N	\N
28217	573	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19531S	\N	\N
28218	584	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19531S	\N	\N
28219	605	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19531S	\N	\N
28220	579	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20068G	\N	\N
28221	610	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20068G	\N	\N
28222	604	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20068G	\N	\N
28223	625	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20068G	\N	\N
28224	598	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14026U	\N	\N
28225	595	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20124W	\N	\N
28226	598	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20124W	\N	\N
28728	618	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28729	620	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28730	978	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28731	673	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28732	633	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28733	601	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28734	642	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28735	621	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28736	534	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28737	852	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28738	674	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
29305	907	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	17023S	\N	\N
29307	907	2020-12-17 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
29320	919	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19631V	\N	\N
29321	919	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19954N	\N	\N
29324	919	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14105F	\N	\N
29325	919	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20060X	\N	\N
29326	919	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20144B	\N	\N
29671	919	2020-12-18 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14033T	\N	\N
29676	909	2021-01-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19443T	\N	\N
29755	918	2021-01-13 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14195A	\N	\N
29915	928	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19565D	\N	\N
29927	928	2020-10-01 00:00:00	2023-12-31 00:00:00	ANCIEN	\N	\N	\N	19745F	\N	\N
29932	928	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	\N	\N
30068	998	2021-01-19 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14189C	\N	\N
30235	911	2021-03-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11041F	\N	\N
30248	933	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20090E	\N	\N
30282	1007	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19349W	\N	\N
30362	1012	2021-06-22 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20104S	\N	\N
30499	615	2021-12-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11045K	\N	\N
30512	609	2022-01-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20138D	\N	\N
30600	1013	2022-04-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19673G	\N	\N
30647	979	2022-06-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20124W	\N	\N
30717	618	2022-12-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20248J	\N	\N
30799	1014	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14055N	\N	\N
31668	584	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14071N	\N	\N
31669	612	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14071N	\N	\N
31670	651	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14071N	\N	\N
31671	626	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14071N	\N	\N
31672	609	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14071N	\N	\N
31673	573	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14071N	\N	\N
32362	613	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17023S	\N	\N
33250	633	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14205J	\N	\N
33273	582	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20094J	\N	\N
33274	633	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20110Q	\N	\N
33418	1008	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21065H	\N	\N
33506	619	2024-01-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20024T	\N	\N
33575	978	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19866P	\N	\N
33582	657	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20054A	\N	\N
33598	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	11043H	\N	\N
33875	906	2023-09-30 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	21071F	\N	\N
34107	957	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	08028W	\N	\N
34108	998	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14213J	\N	\N
34182	908	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19681G	\N	\N
34321	1007	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	21091K	\N	\N
25531	851	2017-12-04 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11012A	2017-12-04 16:34:55	\N
25532	661	2017-12-04 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11012A	2017-12-04 16:34:55	\N
25533	673	2017-12-04 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11012A	2017-12-04 16:34:55	\N
25814	578	2018-01-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11110B	2018-01-15 16:07:11	\N
25815	609	2017-12-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14147R	2018-01-15 16:21:36	\N
25816	673	2018-01-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14147R	2018-01-15 16:43:38	\N
25825	934	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
25969	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14207L	\N	\N
25972	909	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01024M	\N	\N
26021	948	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14265W	\N	\N
26157	585	2018-01-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14109K	2018-01-30 14:45:41	\N
26171	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14259Y	\N	\N
26177	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14225N	\N	\N
26253	907	2017-10-01 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	11063M	\N	\N
26263	919	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08014Q	\N	\N
26322	928	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	11090Q	\N	\N
26493	908	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	05008E	\N	\N
26738	574	2018-03-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2018-04-05 10:10:00	\N
26739	577	2018-04-03 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11054L	2018-04-05 10:10:14	\N
26744	673	2018-04-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14115H	2018-04-11 09:28:53	\N
26760	907	2018-05-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	\N	\N
26830	922	2018-09-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19762G	\N	\N
26837	674	2018-10-03 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14031R	\N	\N
27025	615	2019-06-21 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
29104	588	2020-11-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19685L	\N	\N
29105	653	2020-11-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14331P	\N	\N
29106	604	2020-11-23 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	04034C	\N	\N
29107	648	2020-11-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14249W	\N	\N
29338	919	2020-12-17 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
29339	919	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19685L	\N	\N
29340	919	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14213J	\N	\N
29341	919	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19511N	\N	\N
29367	998	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19717B	\N	\N
29427	909	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20086J	\N	\N
29428	909	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
29429	909	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14105F	\N	\N
30073	919	2021-01-25 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	07029T	\N	\N
30139	1010	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
30189	623	2021-02-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14053L	\N	\N
30228	919	2021-03-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14059S	\N	\N
30229	1005	2021-03-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14059S	\N	\N
30393	907	2021-09-24 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	17367Q	\N	\N
30566	530	2022-03-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14205J	\N	\N
30925	604	2023-10-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	18207D	\N	\N
30926	578	2023-10-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	18207D	\N	\N
30927	623	2023-10-08 00:00:00	2023-12-01 00:00:00	ANCIEN	\N	\N	\N	18207D	\N	\N
31378	608	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20064C	\N	\N
31379	629	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20064C	\N	\N
31380	589	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20064C	\N	\N
31381	617	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20064C	\N	\N
31382	852	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20064C	\N	\N
31383	979	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20064C	\N	\N
31384	573	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20064C	\N	\N
31385	602	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20064C	\N	\N
31386	978	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20064C	\N	\N
31387	530	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20064C	\N	\N
31388	556	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20064C	\N	\N
31389	609	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20064C	\N	\N
31390	612	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20064C	\N	\N
31391	643	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20064C	\N	\N
31392	641	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20064C	\N	\N
31393	618	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20064C	\N	\N
31394	642	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20064C	\N	\N
31395	851	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20064C	\N	\N
31396	620	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20064C	\N	\N
31397	571	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20064C	\N	\N
31398	674	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20064C	\N	\N
31399	583	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20064C	\N	\N
31429	963	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19703U	\N	\N
31430	589	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19703U	\N	\N
31431	673	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19703U	\N	\N
31432	603	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19703U	\N	\N
31866	621	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21092L	\N	\N
31877	601	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08034U	\N	\N
31878	629	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08034U	\N	\N
31879	617	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08034U	\N	\N
32142	625	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	05008E	\N	\N
32143	609	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	05008E	\N	\N
32144	629	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	05008E	\N	\N
32145	573	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	05008E	\N	\N
32146	673	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	05008E	\N	\N
32147	646	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	05008E	\N	\N
32148	584	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	05008E	\N	\N
32184	628	2023-10-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14089Y	\N	\N
32185	663	2023-10-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14089Y	\N	\N
32851	653	2023-11-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20180F	\N	\N
33084	673	2023-11-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14219Q	\N	\N
33206	616	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14089Y	\N	\N
33216	651	2023-11-30 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21070E	\N	\N
33236	640	2023-12-04 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14259Y	\N	\N
33237	674	2023-12-04 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14259Y	\N	\N
33238	576	2023-12-04 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14259Y	\N	\N
33248	609	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19723Y	\N	\N
33329	575	2023-12-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21067K	\N	\N
33330	589	2023-12-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21067K	\N	\N
33369	674	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20120S	\N	\N
33412	1008	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20024T	\N	\N
33448	1007	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19575F	\N	\N
33449	934	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20052X	\N	\N
33450	934	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19575F	\N	\N
33451	966	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19575F	\N	\N
33452	966	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20052X	\N	\N
33453	966	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21094N	\N	\N
33472	573	2024-01-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14219Q	\N	\N
33490	619	2024-01-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20056C	\N	\N
29183	646	2020-12-03 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	04086Q	\N	\N
29269	918	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20032T	\N	\N
29271	918	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11043H	\N	\N
29424	948	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19713W	\N	\N
29695	912	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	05008E	\N	\N
29724	918	2021-01-12 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14105F	\N	\N
29943	583	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
29945	919	2021-01-14 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14207L	\N	\N
29946	948	2021-01-14 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14207L	\N	\N
29974	907	2021-01-21 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14211G	\N	\N
30058	912	2021-01-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19762G	\N	\N
30200	934	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20026V	\N	\N
31027	575	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19413M	\N	\N
31039	618	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19647E	\N	\N
31040	1013	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19647E	\N	\N
31041	597	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19647E	\N	\N
31042	632	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19647E	\N	\N
31043	571	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19647E	\N	\N
31044	600	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19647E	\N	\N
31045	644	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19647E	\N	\N
31046	604	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19647E	\N	\N
31047	595	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19647E	\N	\N
31048	615	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19647E	\N	\N
31049	621	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19647E	\N	\N
31050	623	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19647E	\N	\N
31051	596	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19647E	\N	\N
31052	629	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19647E	\N	\N
31053	627	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19647E	\N	\N
31054	659	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19647E	\N	\N
31055	602	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19647E	\N	\N
31056	641	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19647E	\N	\N
31057	590	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19647E	\N	\N
31058	601	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19647E	\N	\N
31059	620	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19647E	\N	\N
31060	584	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19647E	\N	\N
31061	634	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19647E	\N	\N
31062	617	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19647E	\N	\N
31789	978	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19575F	\N	\N
31790	594	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19575F	\N	\N
31791	604	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19575F	\N	\N
31792	596	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19575F	\N	\N
31793	602	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19575F	\N	\N
31794	621	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19575F	\N	\N
31795	622	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19575F	\N	\N
31796	610	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19575F	\N	\N
31797	625	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19575F	\N	\N
31798	663	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19575F	\N	\N
31799	651	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19575F	\N	\N
31800	583	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19575F	\N	\N
31801	573	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19575F	\N	\N
31802	579	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19575F	\N	\N
31803	673	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19575F	\N	\N
31804	612	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19575F	\N	\N
31805	574	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19575F	\N	\N
31806	575	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19575F	\N	\N
32581	589	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17779H	\N	\N
33437	934	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	01034P	\N	\N
33613	619	2024-01-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20126Y	\N	\N
33914	918	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14189C	\N	\N
33953	601	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19399H	\N	\N
34198	934	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21059K	\N	\N
34223	928	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	19657G	\N	\N
34341	619	2024-02-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14026U	\N	\N
34369	957	2023-12-14 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	19723Y	\N	\N
34410	938	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	14259Y	\N	\N
25467	604	2017-11-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04086Q	2017-11-27 15:36:29	\N
25636	657	2017-12-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14281W	2017-12-15 14:53:59	\N
25637	572	2017-11-11 00:00:00	2017-11-11 00:00:00	ANCIEN	\N	\N	\N	19669L	2017-12-15 15:20:37	2017-12-15 17:27:02
25638	573	2017-12-15 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	19737F	2017-12-15 15:38:08	\N
34462	1010	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	19709B	\N	\N
25639	534	2017-12-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	2017-12-15 16:07:16	\N
25640	634	2017-12-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	2017-12-15 16:07:16	\N
25641	574	2017-12-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	2017-12-15 16:07:16	\N
25642	590	2017-12-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19489J	2017-12-15 16:07:35	\N
25643	657	2017-12-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19489J	2017-12-15 16:08:16	\N
25644	640	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19553Y	2017-12-15 16:08:37	\N
25780	CHRETORIENT	2018-01-05 00:00:00	2023-10-05 00:00:00	ANCIEN	\N	\N	\N	16685X	2018-01-05 11:27:37	\N
25781	CHRETORIENT	2017-12-12 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	19545Y	2018-01-05 11:31:16	\N
25809	573	2018-01-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19749K	2018-01-15 11:23:13	\N
25810	621	2018-01-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19749K	2018-01-15 11:23:13	\N
25811	622	2018-01-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19749K	2018-01-15 11:23:13	\N
25823	1007	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
26020	948	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19563B	\N	\N
26156	948	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11097X	\N	\N
26298	919	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19657G	\N	\N
26475	957	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19631V	\N	\N
26476	957	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
26516	911	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08034U	\N	\N
26831	674	2018-10-03 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14123H	\N	\N
26832	674	2018-10-03 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14169X	\N	\N
26833	674	2018-10-03 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
26834	674	2018-10-03 00:00:00	2020-06-17 00:00:00	ANCIEN	\N	\N	\N	19733B	\N	\N
26835	588	2018-10-03 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19701S	\N	\N
26893	934	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01034P	\N	\N
26929	1008	2018-01-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
26931	644	2018-12-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19766L	\N	\N
27021	906	2019-05-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19721W	\N	\N
27022	909	2019-05-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19741B	\N	\N
27032	979	2019-09-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	19812Y	\N	\N
27033	963	2019-09-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	19812Y	\N	\N
27445	590	2020-10-07 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	14041T	\N	\N
27446	633	2020-10-07 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	14041T	\N	\N
27447	597	2020-10-07 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	14041T	\N	\N
27448	609	2020-10-07 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	14041T	\N	\N
27449	653	2020-10-07 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	14041T	\N	\N
27450	626	2020-10-07 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	14041T	\N	\N
27451	673	2020-10-07 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	14041T	\N	\N
27452	629	2020-10-07 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	14041T	\N	\N
28739	576	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28740	585	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28741	605	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28742	596	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28743	623	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28744	647	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28745	663	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28746	609	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28747	591	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28748	589	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28749	583	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28750	634	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28751	979	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28752	578	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28753	604	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28754	597	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28755	595	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28756	653	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28757	626	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28758	641	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28759	556	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28760	584	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28761	594	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28762	629	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28763	651	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28764	963	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28765	608	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28766	580	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28767	581	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28768	590	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28769	612	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28770	529	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28771	550	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28772	661	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28773	573	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28774	598	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28775	643	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28776	624	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28777	617	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
28778	603	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20036X	\N	\N
29098	609	2020-11-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20032T	\N	\N
29177	572	2020-12-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	12028B	\N	\N
29379	911	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	08045X	\N	\N
29485	911	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19545Y	\N	\N
29512	574	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14133K	\N	\N
29553	906	2020-12-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19681G	\N	\N
29817	1008	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14173T	\N	\N
29831	1004	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	10006L	\N	\N
29835	1004	2020-10-01 00:00:00	2023-12-31 00:00:00	ANCIEN	\N	\N	\N	14213J	\N	\N
29836	1004	2020-10-01 00:00:00	2023-12-31 00:00:00	ANCIEN	\N	\N	\N	19723Y	\N	\N
29879	934	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
29880	934	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14105F	\N	\N
29883	934	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	08028W	\N	\N
29884	934	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17589D	\N	\N
29885	934	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19251M	\N	\N
29886	934	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20040T	\N	\N
29887	934	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20132W	\N	\N
29888	934	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	17023S	\N	\N
29890	934	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14213J	\N	\N
29891	934	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20056C	\N	\N
29892	934	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14073Q	\N	\N
29893	934	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19723Y	\N	\N
29894	934	2020-10-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19699S	\N	\N
29172	590	2020-12-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20086J	\N	\N
29603	909	2021-01-05 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14257W	\N	\N
29604	919	2021-01-05 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14257W	\N	\N
29802	1008	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19723Y	\N	\N
29803	1008	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	18193Q	\N	\N
29811	1008	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14237S	\N	\N
29822	1004	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19717B	\N	\N
29825	1004	2020-10-01 00:00:00	2023-12-31 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
29826	1004	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19367Y	\N	\N
29827	1004	2020-10-01 00:00:00	2023-12-31 00:00:00	ANCIEN	\N	\N	\N	20138D	\N	\N
29828	1004	2020-10-01 00:00:00	2023-12-31 00:00:00	ANCIEN	\N	\N	\N	20090E	\N	\N
29829	1004	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19693L	\N	\N
30046	934	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20024T	\N	\N
30556	530	2022-03-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17367Q	\N	\N
30557	530	2022-03-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
30558	530	2022-03-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
30943	632	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20130U	\N	\N
31674	581	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19251M	\N	\N
31675	575	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19251M	\N	\N
31676	610	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19251M	\N	\N
31677	1013	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19251M	\N	\N
31678	595	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19251M	\N	\N
31679	621	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19251M	\N	\N
31680	641	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19251M	\N	\N
32331	622	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19725B	\N	\N
32332	625	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19725B	\N	\N
32333	588	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19725B	\N	\N
32334	578	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19725B	\N	\N
32335	577	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19725B	\N	\N
32499	580	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	18207D	\N	\N
32540	626	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11065P	\N	\N
32541	978	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11065P	\N	\N
32542	590	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11065P	\N	\N
32543	530	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11065P	\N	\N
32544	572	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11065P	\N	\N
32545	651	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11065P	\N	\N
32546	851	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11065P	\N	\N
32547	618	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11065P	\N	\N
32548	573	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11065P	\N	\N
32549	595	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11065P	\N	\N
32550	979	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11065P	\N	\N
32551	597	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11065P	\N	\N
32552	622	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11065P	\N	\N
32553	598	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11065P	\N	\N
32554	588	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11065P	\N	\N
32555	584	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11065P	\N	\N
32556	625	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11065P	\N	\N
32557	624	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11065P	\N	\N
32558	571	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11065P	\N	\N
32559	602	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11065P	\N	\N
32560	661	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11065P	\N	\N
32561	659	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11065P	\N	\N
32562	574	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11065P	\N	\N
32563	620	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11065P	\N	\N
32564	583	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11065P	\N	\N
32565	646	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11065P	\N	\N
32566	600	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11065P	\N	\N
33257	642	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
33262	633	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21093M	\N	\N
33391	584	2023-12-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20084G	\N	\N
33392	596	2023-12-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20084G	\N	\N
33573	1008	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21059K	\N	\N
33877	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20068G	\N	\N
33878	922	2023-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14189C	\N	\N
33918	1005	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	11027H	\N	\N
33920	1005	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14357A	\N	\N
33921	1005	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21041Y	\N	\N
33923	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19533U	\N	\N
34197	1012	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21067K	\N	\N
34338	908	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	20036X	\N	\N
34339	918	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	20036X	\N	\N
25250	643	2017-11-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14030Q	2017-11-14 14:45:07	\N
25601	653	2017-12-04 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19329S	2017-12-11 09:41:30	\N
25602	661	2017-12-04 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19329S	2017-12-11 09:41:30	\N
25603	659	2017-12-04 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19329S	2017-12-11 09:41:30	\N
25604	619	2017-12-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14249W	2017-12-11 09:42:00	\N
25605	530	2017-12-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14249W	2017-12-11 09:42:00	\N
25606	605	2017-12-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14249W	2017-12-11 09:42:00	\N
25607	530	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	2017-12-11 09:42:19	\N
25608	673	2017-11-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	96004D	2017-12-11 09:48:57	\N
25649	585	2017-12-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14051J	2017-12-18 11:50:54	\N
25678	611	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19721W	2017-12-20 12:15:34	\N
25782	673	2017-12-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19575F	2018-01-05 11:32:27	\N
25817	979	2017-11-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04045F	2018-01-16 10:07:39	\N
25818	624	2017-11-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04045F	2018-01-16 10:07:39	\N
25951	647	2018-01-17 00:00:00	2020-07-13 00:00:00	ANCIEN	\N	\N	\N	11049P	2018-01-17 18:53:19	\N
26046	906	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19667J	\N	\N
26047	906	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
26055	906	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08038Y	\N	\N
26057	906	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19719D	\N	\N
26061	906	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	\N	\N
26202	578	2018-01-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08053X	2018-01-31 18:18:43	\N
26203	619	2018-01-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08053X	2018-01-31 18:18:43	\N
26204	647	2018-01-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08053X	2018-01-31 18:18:43	\N
26380	919	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14159V	\N	\N
26494	908	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08043V	\N	\N
26551	922	2018-02-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14073Q	\N	\N
26555	933	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
26621	908	2018-03-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14213J	\N	\N
26798	909	2018-09-04 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
26822	622	2018-09-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19758L	\N	\N
26823	598	2018-09-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19758L	\N	\N
26828	674	2018-10-03 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14193X	\N	\N
26829	674	2018-10-03 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19643A	\N	\N
29108	620	2020-11-25 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	04034C	\N	\N
29620	615	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08061X	\N	\N
30062	1008	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20100N	\N	\N
30064	1008	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
30173	938	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19695N	\N	\N
30174	938	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19717B	\N	\N
30311	623	2021-03-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17737W	\N	\N
30595	1013	2022-04-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19591F	\N	\N
30596	1013	2022-04-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19705W	\N	\N
30659	629	2022-09-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
30720	1007	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20048C	\N	\N
30726	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	14281W	\N	\N
30739	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	19703U	\N	\N
30777	1014	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19717B	\N	\N
30792	1014	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20120S	\N	\N
32700	609	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20102Q	\N	\N
32701	618	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20102Q	\N	\N
32702	619	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20102Q	\N	\N
33029	584	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20016T	\N	\N
33030	609	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20016T	\N	\N
33496	619	2024-01-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20054A	\N	\N
33498	619	2024-01-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	07029T	\N	\N
33559	1004	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	20106U	\N	\N
33571	1004	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	19798U	\N	\N
33586	934	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	18231D	\N	\N
33595	934	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20150Y	\N	\N
33600	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	20026V	\N	\N
33701	532	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20100N	\N	\N
33810	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19798U	\N	\N
33813	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21064G	\N	\N
33828	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20058E	\N	\N
33854	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21052C	\N	\N
33855	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19782L	\N	\N
33856	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14083S	\N	\N
33858	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14038Y	\N	\N
34384	933	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	21086N	\N	\N
33860	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20144B	\N	\N
33861	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21065H	\N	\N
33867	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20086J	\N	\N
33868	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20038A	\N	\N
33869	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14069U	\N	\N
33880	922	2023-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20110Q	\N	\N
33992	908	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14053L	\N	\N
33993	1012	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14059S	\N	\N
33995	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21041Y	\N	\N
33996	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19507S	\N	\N
33997	1012	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20150Y	\N	\N
33998	1012	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20062A	\N	\N
33999	908	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	15197G	\N	\N
34000	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14187A	\N	\N
34001	1012	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14173T	\N	\N
34021	912	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20118Y	\N	\N
34032	908	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19331L	\N	\N
34109	957	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21041Y	\N	\N
34110	998	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	18207D	\N	\N
34111	957	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21086N	\N	\N
34113	998	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20018V	\N	\N
34114	957	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14033T	\N	\N
34115	957	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14179A	\N	\N
34116	957	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20066E	\N	\N
34117	957	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14257W	\N	\N
34119	957	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20062A	\N	\N
34125	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14105F	\N	\N
34170	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20050V	\N	\N
34263	957	2023-12-14 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	20126Y	\N	\N
34304	659	2024-02-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14331P	\N	\N
34335	603	2024-02-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20040T	\N	\N
34388	933	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	14073Q	\N	\N
34394	933	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	19349W	\N	\N
34396	933	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	20150Y	\N	\N
29242	604	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20100N	\N	\N
29243	633	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20100N	\N	\N
29244	582	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17229F	\N	\N
29245	604	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20128B	\N	\N
29265	659	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19826F	\N	\N
29618	918	2021-01-07 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20018V	\N	\N
29837	1004	2020-10-01 00:00:00	2023-12-31 00:00:00	ANCIEN	\N	\N	\N	14223L	\N	\N
29843	1004	2020-10-01 00:00:00	2023-12-31 00:00:00	ANCIEN	\N	\N	\N	19749K	\N	\N
30216	609	2021-02-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20140W	\N	\N
30337	934	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20074E	\N	\N
30649	908	2022-07-04 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
30859	673	2023-08-31 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17229F	\N	\N
30860	577	2023-08-31 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17229F	\N	\N
31700	602	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20264J	\N	\N
31701	573	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20264J	\N	\N
31702	576	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20264J	\N	\N
31703	589	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20264J	\N	\N
31704	604	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20264J	\N	\N
31705	978	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20264J	\N	\N
31706	642	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20264J	\N	\N
31707	620	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20264J	\N	\N
31708	577	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20264J	\N	\N
31709	575	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20264J	\N	\N
31710	583	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20264J	\N	\N
31711	581	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20264J	\N	\N
31712	572	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20264J	\N	\N
31713	578	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20264J	\N	\N
31714	590	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20264J	\N	\N
31715	609	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20264J	\N	\N
31716	598	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20264J	\N	\N
31717	617	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20264J	\N	\N
31718	641	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20264J	\N	\N
31719	618	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20264J	\N	\N
31720	625	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20264J	\N	\N
31721	595	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20264J	\N	\N
31722	626	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20264J	\N	\N
31723	613	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20264J	\N	\N
31724	597	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20264J	\N	\N
31725	530	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20264J	\N	\N
31726	646	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20264J	\N	\N
31727	601	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20264J	\N	\N
31728	632	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20264J	\N	\N
31729	596	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20264J	\N	\N
32178	604	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19399H	\N	\N
33393	529	2023-12-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19693L	\N	\N
33394	613	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20128B	\N	\N
33605	1004	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	21064G	\N	\N
33640	928	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	19713W	\N	\N
33641	928	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	19669L	\N	\N
33919	918	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20138D	\N	\N
33922	1005	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14215L	\N	\N
33925	1005	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	08056B	\N	\N
33926	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20118Y	\N	\N
34123	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21048G	\N	\N
34345	918	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	20048C	\N	\N
34489	1010	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	20058E	\N	\N
25785	598	2018-01-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	98018T	2018-01-09 11:35:03	\N
26054	906	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
26062	906	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19333N	\N	\N
26063	906	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04097T	\N	\N
26092	928	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	11115U	\N	\N
26093	928	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	17589D	\N	\N
26094	928	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	01024M	\N	\N
26096	928	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14281W	\N	\N
26267	919	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14329V	\N	\N
26268	919	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14195A	\N	\N
26269	919	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08028W	\N	\N
26270	919	2018-01-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	\N	\N
26323	578	2018-02-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14275Y	2018-02-06 18:56:27	\N
26410	911	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
26423	586	2018-02-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	2018-02-12 14:59:04	\N
26424	646	2018-02-02 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19507S	2018-02-12 14:59:21	\N
26699	1005	2017-10-01 00:00:00	2019-03-01 00:00:00	ANCIEN	\N	\N	\N	19511N	\N	\N
27012	584	2019-04-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	02002K	\N	\N
27013	584	2019-04-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19766L	\N	\N
27014	608	2019-04-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19766L	\N	\N
27019	612	2019-05-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19798U	\N	\N
27020	621	2019-05-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19798U	\N	\N
27085	576	2020-02-04 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	18083K	\N	\N
27086	618	2020-02-04 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	18083K	\N	\N
27587	640	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
27588	602	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
27589	612	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
27590	596	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
27591	651	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
27592	642	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
27593	621	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
27594	604	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
27595	575	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
27596	610	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
27597	673	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
27598	583	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
27599	594	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
27600	599	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19721W	\N	\N
27601	608	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19721W	\N	\N
27602	598	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19721W	\N	\N
27603	580	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19721W	\N	\N
27604	582	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19701S	\N	\N
27605	674	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19701S	\N	\N
27606	642	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20146D	\N	\N
27607	576	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20146D	\N	\N
27608	577	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08045X	\N	\N
27609	633	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08045X	\N	\N
27610	618	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08045X	\N	\N
27611	589	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14173T	\N	\N
27612	621	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14173T	\N	\N
27613	601	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14173T	\N	\N
27614	643	2020-10-14 00:00:00	2020-12-03 00:00:00	ANCIEN	\N	\N	\N	04008A	\N	\N
27615	608	2020-10-14 00:00:00	2022-04-08 00:00:00	ANCIEN	\N	\N	\N	04008A	\N	\N
27616	642	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04008A	\N	\N
27617	661	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04008A	\N	\N
27618	979	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04008A	\N	\N
27619	623	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19675J	\N	\N
27620	550	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14195A	\N	\N
27621	529	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14195A	\N	\N
27622	609	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19954N	\N	\N
27623	595	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19954N	\N	\N
27624	621	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19954N	\N	\N
27625	580	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19954N	\N	\N
27626	581	2020-10-13 00:00:00	2022-12-31 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
27627	599	2020-10-13 00:00:00	2022-12-31 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
27628	621	2020-10-13 00:00:00	2022-12-31 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
27629	580	2020-10-13 00:00:00	2022-12-31 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
27630	604	2020-10-13 00:00:00	2022-12-31 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
28400	CHRETORIENT	2020-10-22 00:00:00	2021-07-04 00:00:00	ANCIEN	\N	\N	\N	19966S	\N	\N
28506	585	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19503N	\N	\N
28507	604	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19503N	\N	\N
28508	625	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19503N	\N	\N
28509	608	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19503N	\N	\N
28510	CHRETORIENT	2020-10-27 00:00:00	2023-10-05 00:00:00	ANCIEN	\N	\N	\N	19503N	\N	\N
28511	598	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19503N	\N	\N
28512	624	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11031D	\N	\N
28513	978	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11031D	\N	\N
28514	576	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11031D	\N	\N
28515	620	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11031D	\N	\N
28516	632	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11031D	\N	\N
28517	591	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11031D	\N	\N
28518	979	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11031D	\N	\N
28519	597	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20026V	\N	\N
28520	641	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20026V	\N	\N
28521	580	2020-10-27 00:00:00	2023-10-04 00:00:00	ANCIEN	\N	\N	\N	20026V	\N	\N
28522	584	2020-10-27 00:00:00	2023-10-04 00:00:00	ANCIEN	\N	\N	\N	20026V	\N	\N
28523	618	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20026V	\N	\N
28524	581	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20026V	\N	\N
28525	595	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20114U	\N	\N
28526	575	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20114U	\N	\N
28527	597	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20114U	\N	\N
28528	641	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20114U	\N	\N
28529	589	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20114U	\N	\N
28530	598	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20114U	\N	\N
28531	573	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20114U	\N	\N
28532	632	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20114U	\N	\N
28533	641	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14109K	\N	\N
28534	581	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14109K	\N	\N
28535	595	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	98022P	\N	\N
28536	608	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	98022P	\N	\N
28537	641	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	98022P	\N	\N
28538	596	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11045K	\N	\N
28539	576	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11045K	\N	\N
28540	621	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20142Y	\N	\N
28541	602	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20142Y	\N	\N
28542	591	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20142Y	\N	\N
29266	922	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20032T	\N	\N
29471	908	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19745F	\N	\N
29472	908	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19619A	\N	\N
29501	906	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19551W	\N	\N
29599	919	2021-01-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11101A	\N	\N
29853	1008	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19768N	\N	\N
29867	1007	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17589D	\N	\N
29882	934	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19629C	\N	\N
29889	934	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19399H	\N	\N
29895	934	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20052X	\N	\N
29897	934	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14147R	\N	\N
29937	934	2020-10-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11043H	\N	\N
29961	1008	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04059M	\N	\N
29962	1008	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14026U	\N	\N
29984	919	2021-01-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01057W	\N	\N
30210	908	2021-02-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20036X	\N	\N
30405	571	2021-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20084G	\N	\N
30406	571	2021-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14001X	\N	\N
30407	571	2021-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
30440	1012	2021-10-19 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14001X	\N	\N
30503	948	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20050V	\N	\N
30504	909	2022-01-11 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20050V	\N	\N
30733	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	14071N	\N	\N
31091	571	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19593H	\N	\N
31092	641	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19593H	\N	\N
31093	1013	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19593H	\N	\N
31100	590	2023-10-09 00:00:00	2023-10-11 00:00:00	ANCIEN	\N	\N	\N	14193X	\N	\N
31101	978	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14193X	\N	\N
31102	595	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14193X	\N	\N
31103	610	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14193X	\N	\N
31104	588	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14193X	\N	\N
32473	625	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14033T	\N	\N
32474	646	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14033T	\N	\N
32475	640	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14033T	\N	\N
32476	626	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14033T	\N	\N
32495	621	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20074E	\N	\N
33261	633	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20134Y	\N	\N
33270	595	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19569H	\N	\N
33424	1007	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14037X	\N	\N
33438	934	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14030Q	\N	\N
33439	934	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14069U	\N	\N
33440	934	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21063F	\N	\N
33441	934	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20180F	\N	\N
34476	1010	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	14357A	\N	\N
25082	598	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19671E	2017-11-06 14:42:06	\N
25083	674	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19671E	2017-11-06 14:42:06	\N
25084	596	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19671E	2017-11-06 14:42:06	\N
25085	573	2017-10-26 00:00:00	2020-06-24 00:00:00	ANCIEN	\N	\N	\N	19727D	2017-11-06 15:28:50	\N
25086	622	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04085P	2017-11-06 15:37:00	\N
25087	626	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04085P	2017-11-06 15:37:00	\N
25088	584	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04085P	2017-11-06 15:37:00	\N
25089	632	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04085P	2017-11-06 15:37:00	\N
25090	601	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04085P	2017-11-06 15:37:00	\N
25091	573	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04085P	2017-11-06 15:37:00	\N
25092	534	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04043D	2017-11-06 15:38:28	\N
25093	590	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04043D	2017-11-06 15:38:28	\N
25094	651	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04043D	2017-11-06 15:38:28	\N
25095	625	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04043D	2017-11-06 15:38:28	\N
25096	578	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04043D	2017-11-06 15:38:28	\N
25097	591	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04043D	2017-11-06 15:38:28	\N
25098	653	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04043D	2017-11-06 15:38:28	\N
25099	556	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04043D	2017-11-06 15:38:28	\N
25264	643	2017-11-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01025N	2017-11-15 17:10:25	\N
25265	622	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19531S	2017-11-15 17:10:50	\N
25266	605	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19531S	2017-11-15 17:10:50	\N
25267	573	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19531S	2017-11-15 17:10:50	\N
25268	575	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19531S	2017-11-15 17:10:50	\N
25269	599	2017-11-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19525U	2017-11-15 17:11:09	\N
25317	592	2017-11-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14123H	2017-11-17 17:22:09	\N
25318	621	2017-11-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14123H	2017-11-17 17:22:09	\N
25319	629	2017-11-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14123H	2017-11-17 17:22:09	\N
25320	595	2017-11-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14123H	2017-11-17 17:22:09	\N
25321	592	2017-11-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14073Q	2017-11-17 17:22:44	\N
25322	598	2017-11-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14073Q	2017-11-17 17:22:44	\N
25323	620	2017-11-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14073Q	2017-11-17 17:22:44	\N
25324	572	2017-11-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14073Q	2017-11-17 17:22:44	\N
25325	617	2017-11-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14073Q	2017-11-17 17:22:44	\N
25326	583	2017-11-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14073Q	2017-11-17 17:22:44	\N
25327	575	2017-11-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14073Q	2017-11-17 17:22:44	\N
25328	604	2017-11-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14073Q	2017-11-17 17:22:44	\N
25329	594	2017-11-15 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14261S	2017-11-17 17:24:36	\N
25330	641	2017-11-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	98022P	2017-11-17 17:24:51	\N
25331	643	2017-11-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19735D	2017-11-17 17:25:38	\N
25332	602	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	07004J	2017-11-17 17:25:55	\N
25333	602	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08017T	2017-11-17 17:26:10	\N
25334	529	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14237S	2017-11-17 17:26:28	\N
25335	622	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14237S	2017-11-17 17:26:28	\N
25336	577	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2017-11-17 17:27:13	\N
25337	616	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2017-11-17 17:27:13	\N
25338	609	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2017-11-17 17:27:13	\N
25339	596	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2017-11-17 17:27:13	\N
25340	586	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2017-11-17 17:27:13	\N
25341	978	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2017-11-17 17:27:13	\N
25342	979	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2017-11-17 17:27:13	\N
25343	605	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2017-11-17 17:27:13	\N
25344	613	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2017-11-17 17:27:13	\N
25345	556	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2017-11-17 17:27:13	\N
25346	626	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2017-11-17 17:27:13	\N
25347	595	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2017-11-17 17:27:13	\N
25348	592	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2017-11-17 17:27:13	\N
25349	674	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2017-11-17 17:27:13	\N
25350	602	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2017-11-17 17:27:13	\N
25351	599	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2017-11-17 17:27:13	\N
25352	529	2017-11-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14249W	2017-11-17 17:27:39	\N
25353	623	2017-11-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14249W	2017-11-17 17:27:39	\N
25354	575	2017-11-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14249W	2017-11-17 17:27:39	\N
25355	659	2017-11-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14249W	2017-11-17 17:27:39	\N
25356	596	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11048N	2017-11-17 17:28:02	\N
25357	640	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11048N	2017-11-17 17:28:02	\N
25358	576	2017-11-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19295A	2017-11-17 17:28:31	\N
25359	642	2017-11-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19295A	2017-11-17 17:28:31	\N
25360	584	2017-11-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14231L	2017-11-17 17:29:10	\N
25361	625	2017-11-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14231L	2017-11-17 17:29:10	\N
25362	556	2017-11-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14231L	2017-11-17 17:29:10	\N
25363	599	2017-11-15 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08058D	2017-11-17 17:29:20	\N
25364	640	2017-11-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19711U	2017-11-17 17:29:35	\N
25397	674	2017-11-22 00:00:00	2020-07-13 00:00:00	ANCIEN	\N	\N	\N	11049P	2017-11-22 18:23:30	\N
25398	624	2017-11-22 00:00:00	2020-07-13 00:00:00	ANCIEN	\N	\N	\N	11049P	2017-11-22 18:23:30	\N
25399	589	2017-10-23 00:00:00	2018-11-16 00:00:00	ANCIEN	\N	\N	\N	08016S	2017-11-22 18:37:31	\N
25400	641	2017-10-23 00:00:00	2018-11-16 00:00:00	ANCIEN	\N	\N	\N	08016S	2017-11-22 18:37:31	\N
25401	584	2017-10-23 00:00:00	2018-11-16 00:00:00	ANCIEN	\N	\N	\N	08016S	2017-11-22 18:37:31	\N
25784	673	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14031R	2018-01-08 16:26:57	\N
26207	647	2018-01-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11056N	2018-02-01 09:34:40	\N
26208	604	2018-01-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19749K	2018-02-01 09:34:52	\N
26209	647	2018-01-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14026U	2018-02-01 09:35:11	\N
26210	582	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19569H	2018-02-01 09:35:26	\N
26222	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01057W	\N	\N
26223	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08034U	\N	\N
26332	919	2018-02-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19467C	\N	\N
26496	908	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11101A	\N	\N
26499	908	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19719D	\N	\N
26585	998	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19289C	\N	\N
29267	908	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19723Y	\N	\N
29268	908	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20074E	\N	\N
29376	911	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
29705	1005	2021-01-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14329V	\N	\N
29833	1004	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19673G	\N	\N
29875	1007	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20096L	\N	\N
29959	1008	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19711U	\N	\N
30241	933	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14189C	\N	\N
30304	911	2021-03-23 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20124W	\N	\N
30305	911	2021-03-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19333N	\N	\N
30307	911	2021-03-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11033F	\N	\N
30308	911	2021-03-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14329V	\N	\N
30383	908	2021-07-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19447X	\N	\N
30531	530	2022-03-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20120S	\N	\N
31465	1013	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19591F	\N	\N
31466	622	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19591F	\N	\N
31467	597	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19591F	\N	\N
31468	641	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19591F	\N	\N
31469	575	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19591F	\N	\N
31470	659	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19591F	\N	\N
31471	621	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19591F	\N	\N
31472	618	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19591F	\N	\N
31473	595	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19591F	\N	\N
31474	598	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19591F	\N	\N
31475	661	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19591F	\N	\N
31497	1013	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14223L	\N	\N
31681	598	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04070G	\N	\N
31682	594	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04070G	\N	\N
31683	597	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04070G	\N	\N
31684	661	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04070G	\N	\N
31685	617	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04070G	\N	\N
31686	596	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04070G	\N	\N
31687	601	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04070G	\N	\N
31688	583	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04070G	\N	\N
31689	591	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04070G	\N	\N
31690	595	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04070G	\N	\N
31691	1013	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04070G	\N	\N
31692	576	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04070G	\N	\N
31693	578	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04070G	\N	\N
31694	641	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04070G	\N	\N
31695	581	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04070G	\N	\N
33314	622	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14030Q	\N	\N
33927	1005	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14033T	\N	\N
33956	918	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20056C	\N	\N
33962	918	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14107H	\N	\N
33963	918	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20058E	\N	\N
34178	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	04045F	\N	\N
34179	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19713W	\N	\N
34180	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20026V	\N	\N
34468	919	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	21076L	\N	\N
25127	643	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14173T	2017-11-08 14:10:19	\N
25128	622	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14173T	2017-11-08 14:10:19	\N
25129	651	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14173T	2017-11-08 14:10:19	\N
25130	581	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	2017-11-08 14:13:24	\N
25131	629	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	2017-11-08 14:13:24	\N
25132	573	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	2017-11-08 14:13:24	\N
25133	576	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	2017-11-08 14:13:24	\N
25134	584	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	2017-11-08 14:13:24	\N
25135	608	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	2017-11-08 14:13:24	\N
25136	609	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	2017-11-08 14:13:24	\N
25137	651	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	2017-11-08 14:13:24	\N
25138	590	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	2017-11-08 14:15:38	\N
25139	642	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	2017-11-08 14:15:38	\N
25140	618	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	2017-11-08 14:15:38	\N
25141	598	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	2017-11-08 14:15:38	\N
25142	595	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	2017-11-08 14:15:38	\N
25143	621	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	2017-11-08 14:15:38	\N
25144	590	2017-11-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14159V	2017-11-08 14:26:54	\N
25145	584	2017-11-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14159V	2017-11-08 14:26:54	\N
25146	595	2017-11-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14159V	2017-11-08 14:26:54	\N
25147	600	2017-11-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08039A	2017-11-08 14:27:10	\N
25148	620	2017-11-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08039A	2017-11-08 14:27:10	\N
25149	978	2017-11-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04038G	2017-11-08 14:27:32	\N
25229	581	2017-11-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01043Q	2017-11-10 17:09:30	\N
25230	979	2017-11-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01043Q	2017-11-10 17:09:30	\N
25231	598	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19525U	2017-11-10 17:09:49	\N
25232	583	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19525U	2017-11-10 17:09:49	\N
25621	609	2017-12-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08069G	2017-12-13 17:09:53	\N
25622	580	2017-12-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19335Q	2017-12-14 11:33:16	\N
25623	550	2017-12-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14195A	2017-12-14 11:33:46	\N
25624	624	2017-12-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	2017-12-14 11:34:05	\N
25625	534	2017-12-13 00:00:00	2020-06-27 00:00:00	ANCIEN	\N	\N	\N	14199E	2017-12-14 11:34:48	\N
25626	575	2017-12-12 00:00:00	2020-09-29 00:00:00	ANCIEN	\N	\N	\N	04018C	2017-12-14 11:35:08	\N
25653	851	2017-11-29 00:00:00	2020-03-03 00:00:00	ANCIEN	\N	\N	\N	11081P	2017-12-19 14:36:14	\N
25654	622	2017-12-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19699S	2017-12-19 14:36:33	\N
25869	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19467C	\N	\N
25967	586	2018-01-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	2018-01-19 13:34:43	\N
25968	615	2018-01-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	2018-01-19 13:34:43	\N
26158	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	17583W	\N	\N
26224	909	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01057W	\N	\N
26414	911	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14107H	\N	\N
26422	1005	2018-02-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14195A	\N	\N
26552	906	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19503N	\N	\N
26600	998	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19619A	\N	\N
26901	911	2018-11-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19347U	\N	\N
26907	934	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14135M	\N	\N
26909	934	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14267Y	\N	\N
27024	908	2019-06-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14173T	\N	\N
28570	602	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20080C	\N	\N
28543	595	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14021P	\N	\N
28544	596	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14021P	\N	\N
28545	583	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14021P	\N	\N
28546	618	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14021P	\N	\N
28564	616	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17637T	\N	\N
28565	608	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17637T	\N	\N
28566	621	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17637T	\N	\N
28567	641	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17637T	\N	\N
28568	591	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17637T	\N	\N
28569	597	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17637T	\N	\N
28571	603	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20080C	\N	\N
28572	583	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20080C	\N	\N
28573	625	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20080C	\N	\N
28574	978	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20080C	\N	\N
28575	608	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20016T	\N	\N
28576	661	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20016T	\N	\N
28577	625	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20016T	\N	\N
28578	574	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20016T	\N	\N
28579	634	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20016T	\N	\N
28580	609	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	10006L	\N	\N
28803	609	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19447X	\N	\N
28804	651	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14195A	\N	\N
28805	661	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14195A	\N	\N
28806	556	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14195A	\N	\N
28807	588	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14195A	\N	\N
28808	594	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14195A	\N	\N
28809	661	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	98022P	\N	\N
28810	598	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14231L	\N	\N
28811	576	2020-11-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19569H	\N	\N
28812	572	2020-11-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19569H	\N	\N
28813	584	2020-11-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19569H	\N	\N
28814	597	2020-11-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19569H	\N	\N
28815	626	2020-11-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19569H	\N	\N
28816	616	2020-11-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19569H	\N	\N
28817	583	2020-11-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14357A	\N	\N
28818	609	2020-11-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14357A	\N	\N
28819	629	2020-11-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14357A	\N	\N
28820	644	2020-11-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14357A	\N	\N
28821	617	2020-11-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14357A	\N	\N
28822	629	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04033B	\N	\N
28823	609	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04033B	\N	\N
28824	615	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04033B	\N	\N
28825	597	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04033B	\N	\N
28996	579	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14249W	\N	\N
28997	605	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14249W	\N	\N
28998	624	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11012A	\N	\N
28999	579	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19369B	\N	\N
29000	594	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19369B	\N	\N
29001	851	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
29162	592	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	16685X	\N	\N
29163	615	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	16685X	\N	\N
29484	919	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19545Y	\N	\N
29938	934	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19643A	\N	\N
30136	1010	2021-02-03 00:00:00	2021-10-22 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
30312	934	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14249W	\N	\N
30313	934	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14221J	\N	\N
30342	1012	2021-06-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20180F	\N	\N
30343	1012	2021-06-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19333N	\N	\N
30370	615	2021-06-28 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	14041T	\N	\N
30429	571	2021-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
30430	530	2021-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11064N	\N	\N
30627	1013	2022-05-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20248J	\N	\N
30628	571	2022-05-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20248J	\N	\N
30629	629	2022-05-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20248J	\N	\N
30630	530	2022-05-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20248J	\N	\N
31247	571	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20180F	\N	\N
31248	573	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20180F	\N	\N
31249	979	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20180F	\N	\N
31250	643	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20180F	\N	\N
31251	674	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20180F	\N	\N
31252	625	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20180F	\N	\N
33967	1012	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14030Q	\N	\N
33972	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19782L	\N	\N
33973	1012	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20090E	\N	\N
33981	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14329V	\N	\N
33982	1012	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20180F	\N	\N
25280	623	2017-11-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14221J	2017-11-16 15:05:42	\N
25281	629	2017-11-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08034U	2017-11-16 15:06:01	\N
25282	597	2017-11-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08034U	2017-11-16 15:06:01	\N
25283	576	2017-11-14 00:00:00	2017-11-30 00:00:00	ANCIEN	\N	\N	\N	08034U	2017-11-16 15:06:01	2017-12-06 11:35:18
25284	978	2017-11-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19387D	2017-11-16 15:06:21	\N
25285	633	2017-11-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19387D	2017-11-16 15:06:22	\N
25402	592	2017-11-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	98018T	2017-11-23 09:41:31	\N
25403	579	2017-11-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	98018T	2017-11-23 09:41:31	\N
25404	604	2017-11-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	98018T	2017-11-23 09:41:31	\N
25405	550	2017-11-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19583F	2017-11-23 09:46:23	\N
25406	661	2017-11-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19583F	2017-11-23 09:46:23	\N
25407	592	2017-11-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14065Q	2017-11-23 09:46:41	\N
25408	663	2017-11-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19691J	2017-11-23 09:48:56	\N
25484	573	2017-11-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19591F	2017-11-29 11:56:06	\N
25486	594	2017-11-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19681G	2017-11-29 14:41:35	\N
25487	613	2017-11-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	96004D	2017-11-29 14:42:15	\N
25488	573	2017-11-27 00:00:00	2017-12-06 00:00:00	ANCIEN	\N	\N	\N	14059S	2017-11-29 14:42:42	2017-12-06 18:06:40
25489	616	2017-11-29 00:00:00	2019-10-02 00:00:00	ANCIEN	\N	\N	\N	07004J	2017-11-29 14:42:56	\N
25490	613	2017-11-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2017-11-29 14:43:15	\N
25491	598	2017-11-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14026U	2017-11-29 14:43:31	\N
25492	619	2017-11-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14026U	2017-11-29 14:43:31	\N
25888	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19563B	\N	\N
25889	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14109K	\N	\N
25890	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14257W	\N	\N
25897	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19679N	\N	\N
25899	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14107H	\N	\N
25900	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19619A	\N	\N
25901	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14173T	\N	\N
25975	934	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19611R	\N	\N
26160	644	2018-01-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19503N	2018-01-30 19:43:06	2018-01-31 18:43:28
26161	657	2018-01-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19503N	2018-01-30 19:43:06	\N
26250	852	2018-02-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11040E	2018-02-05 16:41:17	\N
26260	919	2018-01-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08043V	\N	\N
26261	919	2018-01-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19367Y	\N	\N
26262	919	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
26381	919	2018-02-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19347U	\N	\N
26383	911	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14133K	\N	\N
26384	911	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	05008E	\N	\N
26519	938	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
26596	998	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19531S	\N	\N
26606	1005	2018-02-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19369B	\N	\N
26751	644	2018-04-04 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04092N	2018-04-16 10:31:55	\N
26758	592	2018-04-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14241N	2018-05-17 16:23:35	\N
26759	641	2018-05-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19689Q	2018-05-17 16:24:00	\N
26764	919	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19747H	\N	\N
26903	998	2018-11-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01024M	\N	\N
27001	612	2019-03-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19766L	\N	\N
27049	911	2019-10-22 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	19713W	\N	\N
27077	629	2020-01-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19766L	\N	\N
27078	604	2019-10-03 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	\N	\N
27079	608	2019-10-03 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	\N	\N
27080	584	2019-10-03 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	\N	\N
27081	648	2019-10-03 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	\N	\N
27082	596	2019-10-03 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	\N	\N
27139	591	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20038A	\N	\N
27140	604	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20038A	\N	\N
27141	622	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20038A	\N	\N
27142	651	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20038A	\N	\N
27143	632	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19599P	\N	\N
27144	595	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19367Y	\N	\N
27145	629	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19367Y	\N	\N
27146	621	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19367Y	\N	\N
27147	578	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19333N	\N	\N
27148	609	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19333N	\N	\N
27149	617	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19333N	\N	\N
27150	661	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19333N	\N	\N
27151	657	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11066Q	\N	\N
27152	583	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19719D	\N	\N
27153	602	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19719D	\N	\N
27154	596	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19719D	\N	\N
27155	584	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19719D	\N	\N
27156	589	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19719D	\N	\N
27716	595	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11043H	\N	\N
27717	640	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11043H	\N	\N
28320	571	2020-10-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19593H	\N	\N
28321	641	2020-10-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19593H	\N	\N
28322	597	2020-10-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19593H	\N	\N
28323	573	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20084G	\N	\N
28324	572	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20084G	\N	\N
28325	641	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20084G	\N	\N
28338	604	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
28339	644	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
28340	595	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
28341	596	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
28342	575	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
28343	613	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
28344	572	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
28345	582	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
28346	620	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
28347	597	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
28348	621	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
28349	634	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
28350	602	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
28351	629	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
28352	598	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
28353	661	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
28354	610	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
28355	641	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
28356	617	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
28357	632	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
28499	597	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	\N	\N
28500	597	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14331P	\N	\N
28501	CHRETORIENT	2020-10-26 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	20118Y	\N	\N
28502	583	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11104D	\N	\N
28503	550	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	16685X	\N	\N
28504	626	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	16685X	\N	\N
28505	622	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	16685X	\N	\N
29799	1008	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20056C	\N	\N
30204	934	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20138D	\N	\N
30245	933	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
30279	998	2021-03-23 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20092G	\N	\N
30280	1007	2020-10-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19611R	\N	\N
30281	1007	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14219Q	\N	\N
30306	911	2021-03-24 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20066E	\N	\N
30384	571	2021-08-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19551W	\N	\N
30437	603	2021-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	\N	\N
30447	609	2021-10-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20058E	\N	\N
30467	646	2021-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20152B	\N	\N
30526	615	2022-02-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20060X	\N	\N
30672	603	2021-11-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14219Q	\N	\N
30673	598	2022-03-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	\N	\N
30780	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	14083S	\N	\N
30781	1014	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	\N	\N
31244	594	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21062E	\N	\N
31245	581	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21062E	\N	\N
32502	575	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21078N	\N	\N
32503	598	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21078N	\N	\N
32504	589	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21078N	\N	\N
32505	620	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21078N	\N	\N
32506	573	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21078N	\N	\N
32507	661	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21078N	\N	\N
32520	584	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21078N	\N	\N
32521	609	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21078N	\N	\N
32522	626	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21078N	\N	\N
33256	634	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14219Q	\N	\N
33263	576	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20100N	\N	\N
33264	633	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20100N	\N	\N
33265	604	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20100N	\N	\N
33266	622	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20100N	\N	\N
33267	613	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20100N	\N	\N
33383	556	2023-12-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	07004J	\N	\N
33644	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19575F	\N	\N
33645	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20114U	\N	\N
33930	1005	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14213J	\N	\N
34079	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19713W	\N	\N
34081	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20136B	\N	\N
34082	922	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20032T	\N	\N
34086	922	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20124W	\N	\N
34088	922	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20100N	\N	\N
34090	922	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14033T	\N	\N
34092	922	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20106U	\N	\N
34093	957	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19575F	\N	\N
34094	957	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21048G	\N	\N
34095	957	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20088L	\N	\N
34097	922	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14073Q	\N	\N
34098	922	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14237S	\N	\N
34099	957	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14083S	\N	\N
34100	922	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21051B	\N	\N
25725	934	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01062T	\N	\N
25965	673	2018-01-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19467C	2018-01-18 17:48:27	\N
26039	582	2017-12-12 00:00:00	2020-07-31 00:00:00	ANCIEN	\N	\N	\N	08044W	2018-01-25 09:51:52	\N
26040	603	2017-12-12 00:00:00	2020-07-31 00:00:00	ANCIEN	\N	\N	\N	08044W	2018-01-25 09:51:52	\N
26041	585	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14026U	2018-01-25 09:52:10	\N
26042	578	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19421M	2018-01-25 09:52:23	\N
26043	586	2018-01-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	2018-01-25 09:52:34	\N
26044	640	2018-01-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	19731Y	2018-01-25 09:52:45	\N
26146	909	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11012A	\N	\N
26151	909	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08061X	\N	\N
26418	623	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14073Q	2018-02-09 12:02:47	\N
26426	922	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
26428	922	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
26429	922	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08060W	\N	\N
26430	922	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	\N	\N
26520	938	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14093U	\N	\N
26522	938	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	\N	\N
26624	918	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14107H	\N	\N
26685	1008	2018-03-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14169X	\N	\N
26686	1008	2018-03-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19349W	\N	\N
26687	1008	2018-03-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14229S	\N	\N
26688	1008	2018-03-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14107H	\N	\N
26690	1008	2018-03-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19749K	\N	\N
26741	1008	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19621T	\N	\N
27823	598	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17367Q	\N	\N
27824	612	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17367Q	\N	\N
27825	597	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17367Q	\N	\N
29002	648	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	16685X	\N	\N
29012	579	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14042U	\N	\N
29016	579	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19671E	\N	\N
29026	851	2020-11-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19629C	\N	\N
29131	592	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20126Y	\N	\N
29132	610	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20126Y	\N	\N
29133	609	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20126Y	\N	\N
29135	673	2020-11-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	\N	\N
29136	529	2020-11-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08010L	\N	\N
29137	648	2020-11-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14073Q	\N	\N
29138	615	2020-11-25 00:00:00	2022-06-20 00:00:00	ANCIEN	\N	\N	\N	20174H	\N	\N
29272	599	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11053K	\N	\N
29273	647	2020-12-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14249W	\N	\N
29274	582	2020-12-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01025N	\N	\N
29275	616	2020-12-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01025N	\N	\N
29368	998	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20060X	\N	\N
29369	998	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14195A	\N	\N
29372	998	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14097Y	\N	\N
29374	998	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20044X	\N	\N
29375	998	2020-12-16 00:00:00	2022-07-03 00:00:00	ANCIEN	\N	\N	\N	19689Q	\N	\N
29400	906	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
29401	906	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19721W	\N	\N
29402	906	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20144B	\N	\N
29403	906	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19719D	\N	\N
29404	906	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01024M	\N	\N
29430	909	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19467C	\N	\N
29457	585	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14026U	\N	\N
29458	852	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19563B	\N	\N
29459	530	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19745F	\N	\N
29460	633	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19745F	\N	\N
29461	644	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19762G	\N	\N
29536	908	2020-12-17 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20116W	\N	\N
29537	919	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20040T	\N	\N
29539	906	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20040T	\N	\N
29540	909	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20040T	\N	\N
29541	911	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
29542	912	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
29543	922	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20096L	\N	\N
29581	530	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19553Y	\N	\N
29582	852	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19553Y	\N	\N
29635	918	2021-01-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11101A	\N	\N
29636	918	2021-01-07 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20138D	\N	\N
29637	918	2021-01-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19629C	\N	\N
29896	934	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	08012N	\N	\N
30061	1008	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19766L	\N	\N
30063	1008	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14033T	\N	\N
30069	919	2021-01-19 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14189C	\N	\N
30219	618	2021-03-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	\N	\N
30238	919	2021-03-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	16685X	\N	\N
30239	911	2021-03-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	16685X	\N	\N
30261	933	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20056C	\N	\N
30332	623	2021-05-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14169X	\N	\N
30367	919	2021-06-24 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20110Q	\N	\N
30377	908	2021-07-20 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14083S	\N	\N
30382	908	2021-07-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20172F	\N	\N
30443	908	2021-10-21 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20034V	\N	\N
30470	550	2021-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
30471	624	2021-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20072C	\N	\N
30535	632	2022-03-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19565D	\N	\N
30537	611	2022-03-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20086J	\N	\N
30538	581	2022-03-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20086J	\N	\N
30539	584	2022-03-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20086J	\N	\N
30540	642	2022-03-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20086J	\N	\N
30541	647	2022-03-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20086J	\N	\N
30542	623	2022-03-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20086J	\N	\N
30543	624	2022-03-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20086J	\N	\N
30544	591	2022-03-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20086J	\N	\N
30545	585	2022-03-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20086J	\N	\N
30546	578	2022-03-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20086J	\N	\N
30547	617	2022-03-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20086J	\N	\N
30619	912	2022-05-02 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14327T	\N	\N
30635	595	2022-05-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20048C	\N	\N
30654	1013	2022-07-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17023S	\N	\N
30660	623	2022-09-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20052X	\N	\N
30728	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	19798U	\N	\N
30729	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	14217N	\N	\N
30730	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	14237S	\N	\N
30731	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	19723Y	\N	\N
30732	1014	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19057M	\N	\N
30225	556	2021-03-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20118Y	\N	\N
30243	933	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20024T	\N	\N
30253	933	2020-10-01 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	14041T	\N	\N
30254	933	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	08045X	\N	\N
30255	933	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14211G	\N	\N
30256	933	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20106U	\N	\N
30257	933	2020-10-01 00:00:00	2021-05-13 00:00:00	ANCIEN	\N	\N	\N	20128B	\N	\N
30258	933	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
30398	571	2021-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14073Q	\N	\N
30399	571	2021-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	\N	\N
30401	571	2021-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20132W	\N	\N
30404	571	2021-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14147R	\N	\N
30787	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	19693L	\N	\N
32514	626	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20104S	\N	\N
32515	574	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20104S	\N	\N
32516	597	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20104S	\N	\N
32517	598	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20104S	\N	\N
32518	647	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20104S	\N	\N
32519	661	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20104S	\N	\N
33462	596	2024-01-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14193X	\N	\N
33983	1012	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20106U	\N	\N
33985	908	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20114U	\N	\N
25172	623	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14169X	2017-11-10 10:34:33	\N
25173	596	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14169X	2017-11-10 10:34:33	\N
25174	576	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14169X	2017-11-10 10:34:33	\N
25175	597	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14169X	2017-11-10 10:34:33	\N
25176	628	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14169X	2017-11-10 10:34:33	\N
25177	597	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19699S	2017-11-10 10:36:16	\N
25178	598	2017-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19699S	2017-11-10 10:36:16	\N
25179	583	2017-11-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	2017-11-10 10:43:59	\N
25180	591	2017-11-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	2017-11-10 10:43:59	\N
25181	640	2017-11-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	2017-11-10 10:43:59	\N
25182	579	2017-11-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	2017-11-10 10:43:59	\N
25183	529	2017-11-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	2017-11-10 10:43:59	\N
25184	603	2017-11-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	2017-11-10 10:43:59	\N
25185	611	2017-11-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	2017-11-10 10:43:59	\N
25186	608	2017-11-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	2017-11-10 10:44:00	\N
25187	600	2017-11-09 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	2017-11-10 10:44:00	\N
25188	634	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11109J	2017-11-10 10:44:21	\N
25189	642	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11109J	2017-11-10 10:44:21	\N
25190	653	2017-11-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	98024R	2017-11-10 10:45:47	\N
25191	605	2017-11-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14103D	2017-11-10 10:46:03	\N
25192	621	2017-11-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14103D	2017-11-10 10:46:03	\N
25193	591	2017-11-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01062T	2017-11-10 10:46:36	\N
25194	621	2017-11-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01062T	2017-11-10 10:46:36	\N
25195	575	2017-11-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01062T	2017-11-10 10:46:36	\N
25196	589	2017-11-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01062T	2017-11-10 10:46:36	\N
25197	602	2017-11-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01062T	2017-11-10 10:46:36	\N
25198	642	2017-11-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01062T	2017-11-10 10:46:36	\N
25199	625	2017-11-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01062T	2017-11-10 10:46:36	\N
25200	580	2017-11-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01062T	2017-11-10 10:46:36	\N
25201	633	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	2017-11-10 10:47:34	\N
25202	978	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	2017-11-10 10:47:34	\N
25203	609	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	2017-11-10 10:47:34	\N
25204	578	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	2017-11-10 10:47:35	\N
25205	599	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	2017-11-10 10:47:35	\N
25206	529	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	2017-11-10 10:47:35	\N
25207	603	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	2017-11-10 10:47:35	\N
25208	979	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	2017-11-10 10:47:35	\N
25209	596	2017-11-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19553Y	2017-11-10 10:48:17	\N
25210	580	2017-11-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19553Y	2017-11-10 10:48:17	\N
25211	643	2017-11-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	2017-11-10 10:49:26	\N
25212	574	2017-11-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	2017-11-10 10:49:26	\N
25213	598	2017-11-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	2017-11-10 10:49:26	\N
25214	618	2017-11-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	2017-11-10 10:49:26	\N
25215	979	2017-11-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	2017-11-10 10:49:26	\N
25216	534	2017-11-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	2017-11-10 10:49:26	\N
25217	646	2017-11-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	98029W	2017-11-10 10:49:44	\N
25218	550	2017-11-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	02002K	2017-11-10 10:50:29	\N
25219	594	2017-11-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	02002K	2017-11-10 10:50:29	\N
25220	661	2017-11-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	02002K	2017-11-10 10:50:29	\N
25221	529	2017-11-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	02002K	2017-11-10 10:50:29	\N
25222	608	2017-11-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	02002K	2017-11-10 10:50:29	\N
25223	602	2017-11-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19565D	2017-11-10 10:53:06	\N
25224	580	2017-11-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19565D	2017-11-10 10:53:06	\N
25225	601	2017-11-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19565D	2017-11-10 10:53:06	\N
25645	556	2017-12-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	2017-12-15 17:03:52	\N
25802	1007	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14229S	\N	\N
25651	534	2017-12-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19507S	2017-12-19 10:23:01	\N
25652	609	2017-12-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14215L	2017-12-19 10:23:32	\N
26065	906	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19551W	\N	\N
26064	906	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11048N	\N	\N
26077	906	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19533U	\N	\N
26082	906	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19619A	\N	\N
26083	906	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01058X	\N	\N
26084	906	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14051J	\N	\N
26233	998	2017-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	\N	\N
26238	948	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08061X	\N	\N
26524	938	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14079W	\N	\N
26526	938	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
26527	938	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19695N	\N	\N
26532	938	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14147R	\N	\N
26720	918	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14109K	\N	\N
26770	979	2018-05-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04086Q	2018-06-01 15:48:42	\N
26771	627	2018-05-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	2018-06-01 15:49:28	\N
26866	610	2018-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	98005N	\N	\N
26867	605	2018-10-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	98005N	\N	\N
26940	922	2018-11-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01024M	\N	\N
26960	588	2019-01-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	18083K	\N	\N
26961	1005	2019-02-22 00:00:00	2019-03-05 00:00:00	ANCIEN	\N	\N	\N	11101A	\N	\N
26977	906	2019-02-13 00:00:00	2019-02-13 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
28358	601	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	\N	\N
28359	586	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	\N	\N
28360	979	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	\N	\N
28361	622	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	\N	\N
28362	588	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	\N	\N
28363	978	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	\N	\N
28364	583	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	\N	\N
28365	592	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	\N	\N
28366	602	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	\N	\N
28367	589	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	\N	\N
28368	578	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	\N	\N
28369	576	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	\N	\N
28370	616	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	\N	\N
28371	580	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19637C	\N	\N
28903	642	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20034V	\N	\N
28904	651	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20034V	\N	\N
28905	596	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20034V	\N	\N
28906	577	2020-11-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	\N	\N
29651	907	2021-01-12 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14225N	\N	\N
29673	907	2020-12-18 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14033T	\N	\N
29818	1008	2020-10-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19585H	\N	\N
30119	1010	2021-02-03 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	08034U	\N	\N
30120	1010	2021-02-03 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	08010L	\N	\N
30202	1010	2021-02-03 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
30334	641	2021-05-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04033B	\N	\N
30488	640	2021-11-23 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	20108W	\N	\N
30489	615	2021-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19649G	\N	\N
30490	661	2021-12-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	\N	\N
30491	623	2021-12-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	\N	\N
30500	575	2021-12-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20264J	\N	\N
30604	530	2022-04-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19563B	\N	\N
30617	1013	2022-04-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14105F	\N	\N
30625	1007	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19735D	\N	\N
34373	933	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	14189C	\N	\N
34375	933	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	19575F	\N	\N
34376	933	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	20116W	\N	\N
34472	1010	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	20118Y	\N	\N
34473	1010	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	19673G	\N	\N
34474	1010	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	21068L	\N	\N
25859	1004	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14355X	\N	\N
26419	646	2018-02-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19447X	2018-02-09 15:23:59	\N
26420	979	2018-02-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	05012A	2018-02-09 15:24:24	\N
26454	918	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
26455	918	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19383Y	\N	\N
26466	918	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19347U	\N	\N
26470	918	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19679N	\N	\N
26730	615	2018-03-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	2018-03-29 15:18:13	\N
26799	590	2018-09-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19766L	\N	\N
26843	601	2018-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11070L	\N	\N
26938	957	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08028W	\N	\N
26994	919	2018-01-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19503N	\N	\N
28019	601	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19782L	\N	\N
28409	661	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11074Q	\N	\N
28410	625	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11074Q	\N	\N
28411	604	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11074Q	\N	\N
28412	573	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11074Q	\N	\N
28413	601	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11074Q	\N	\N
28414	621	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11074Q	\N	\N
28415	852	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11074Q	\N	\N
28416	641	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11074Q	\N	\N
28417	577	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11074Q	\N	\N
28418	979	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19549D	\N	\N
28419	573	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19549D	\N	\N
28420	674	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19549D	\N	\N
28421	573	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	12028B	\N	\N
28422	641	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	12028B	\N	\N
28423	584	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14151M	\N	\N
28424	609	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14151M	\N	\N
28425	574	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14151M	\N	\N
28426	610	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14151M	\N	\N
28427	590	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14151M	\N	\N
28870	651	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11010L	\N	\N
28991	579	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14193X	\N	\N
28992	612	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14193X	\N	\N
28993	529	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19563B	\N	\N
28994	588	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20054A	\N	\N
28995	588	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
29653	532	2021-01-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04008A	\N	\N
29679	600	2021-01-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
29752	907	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19739H	\N	\N
29878	934	2020-10-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19954N	\N	\N
30233	911	2021-03-08 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20090E	\N	\N
30234	911	2021-03-05 00:00:00	2021-03-05 00:00:00	ANCIEN	\N	\N	\N	14133K	\N	\N
30290	1011	2021-03-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19467C	\N	\N
30291	1011	2021-03-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17589D	\N	\N
30395	550	2021-09-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	12028B	\N	\N
30397	609	2021-10-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20098N	\N	\N
30735	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	19691J	\N	\N
30757	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ANCIEN	\N	\N	\N	14195A	\N	\N
30795	589	2023-01-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20120S	\N	\N
30796	591	2023-01-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20120S	\N	\N
30798	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	19575F	\N	\N
30810	600	2023-03-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14169X	\N	\N
30853	623	2023-07-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17367Q	\N	\N
30833	1006	2023-05-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19711U	\N	\N
30953	534	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	10015M	\N	\N
30954	661	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	10015M	\N	\N
30955	556	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	10015M	\N	\N
30956	595	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	10015M	\N	\N
30957	573	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	10015M	\N	\N
30958	616	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	10015M	\N	\N
30959	627	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	10015M	\N	\N
30964	586	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21069M	\N	\N
30965	613	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21069M	\N	\N
30966	596	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21069M	\N	\N
30967	581	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19673G	\N	\N
30968	646	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19673G	\N	\N
30969	618	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19673G	\N	\N
30970	634	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19673G	\N	\N
30971	1013	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19673G	\N	\N
31128	979	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04047H	\N	\N
31129	589	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04047H	\N	\N
31166	674	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19701S	\N	\N
31167	582	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19701S	\N	\N
31564	594	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21083K	\N	\N
31565	621	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21083K	\N	\N
31566	595	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21083K	\N	\N
31567	602	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21083K	\N	\N
31612	629	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14211G	\N	\N
31613	578	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14211G	\N	\N
31614	617	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14211G	\N	\N
31615	589	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14211G	\N	\N
31616	673	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14211G	\N	\N
31617	591	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14211G	\N	\N
31618	608	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14211G	\N	\N
31619	572	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14211G	\N	\N
31620	620	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14211G	\N	\N
31621	575	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14211G	\N	\N
31622	598	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14211G	\N	\N
31623	604	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14211G	\N	\N
31624	963	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14211G	\N	\N
31625	621	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14211G	\N	\N
31626	597	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14211G	\N	\N
31627	595	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14211G	\N	\N
31628	979	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19057M	\N	\N
31629	556	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19057M	\N	\N
31630	609	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19057M	\N	\N
31631	586	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19057M	\N	\N
31632	661	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19057M	\N	\N
31633	653	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19057M	\N	\N
31634	530	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19057M	\N	\N
31635	628	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19057M	\N	\N
31636	663	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19057M	\N	\N
31637	648	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19057M	\N	\N
31638	643	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19057M	\N	\N
29662	907	2020-12-18 00:00:00	2020-12-18 00:00:00	ANCIEN	\N	\N	\N	14033T	\N	\N
29738	534	2021-01-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20024T	\N	\N
29745	605	2021-01-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19798U	\N	\N
29764	922	2021-01-11 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20122U	\N	\N
29955	919	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04042C	\N	\N
30088	928	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19333N	\N	\N
30366	623	2021-06-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19503N	\N	\N
30498	657	2021-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
31374	648	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20108W	\N	\N
31375	641	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20108W	\N	\N
31376	597	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20108W	\N	\N
31377	1013	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20108W	\N	\N
31410	647	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08012N	\N	\N
31411	571	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08012N	\N	\N
31412	673	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08012N	\N	\N
31413	663	2023-10-10 00:00:00	2023-12-06 00:00:00	ANCIEN	\N	\N	\N	08012N	\N	\N
31414	599	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08012N	\N	\N
31415	602	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08012N	\N	\N
31553	596	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14123H	\N	\N
31554	609	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14123H	\N	\N
31555	629	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14123H	\N	\N
31556	621	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14123H	\N	\N
32056	579	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20096L	\N	\N
32057	589	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20096L	\N	\N
32058	621	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20096L	\N	\N
32059	550	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20096L	\N	\N
32060	610	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20096L	\N	\N
32061	640	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20096L	\N	\N
32062	604	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20096L	\N	\N
32063	626	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20096L	\N	\N
32072	582	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14083S	\N	\N
32073	979	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14083S	\N	\N
32074	592	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14083S	\N	\N
32075	622	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14083S	\N	\N
32076	579	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14083S	\N	\N
32077	589	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14083S	\N	\N
32078	978	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14083S	\N	\N
32079	572	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14083S	\N	\N
32080	616	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14083S	\N	\N
32081	601	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14083S	\N	\N
32082	594	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14083S	\N	\N
32083	851	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14083S	\N	\N
32084	532	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14083S	\N	\N
32085	576	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14083S	\N	\N
32086	588	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14083S	\N	\N
32087	573	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14083S	\N	\N
33309	580	2023-12-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21092L	\N	\N
33316	597	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21061D	\N	\N
33384	613	2023-12-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21086N	\N	\N
33646	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14038Y	\N	\N
33834	1008	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14251Q	\N	\N
33835	1006	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	17023S	\N	\N
34400	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	\N	\N	\N	\N	14355X	\N	\N
32291	598	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14281W	\N	\N
32292	632	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14281W	\N	\N
32293	589	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20068G	\N	\N
32294	598	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20068G	\N	\N
32295	629	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20068G	\N	\N
32303	663	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14121F	\N	\N
32346	978	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17965H	\N	\N
32350	589	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20046A	\N	\N
32358	584	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21071F	\N	\N
32359	608	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21071F	\N	\N
32360	661	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21071F	\N	\N
32361	610	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21071F	\N	\N
32408	596	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20098N	\N	\N
32409	583	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20098N	\N	\N
32410	625	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20098N	\N	\N
32411	602	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20098N	\N	\N
32412	609	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20098N	\N	\N
32413	604	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20098N	\N	\N
32414	595	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20098N	\N	\N
32422	586	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20040T	\N	\N
32442	661	2023-10-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19585H	\N	\N
32443	609	2023-10-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19585H	\N	\N
32444	642	2023-10-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19585H	\N	\N
32445	576	2023-10-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19585H	\N	\N
32446	583	2023-10-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19585H	\N	\N
32447	622	2023-10-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19585H	\N	\N
32453	625	2023-10-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21086N	\N	\N
32454	583	2023-10-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21086N	\N	\N
32455	978	2023-10-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21086N	\N	\N
32456	590	2023-10-30 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19479G	\N	\N
32465	663	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20082E	\N	\N
32466	616	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20082E	\N	\N
32467	625	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20082E	\N	\N
32491	641	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11045K	\N	\N
32492	576	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11045K	\N	\N
32493	625	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11045K	\N	\N
32494	595	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11045K	\N	\N
32496	978	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21055F	\N	\N
32497	601	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21055F	\N	\N
32498	578	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21055F	\N	\N
32500	851	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21065H	\N	\N
32573	625	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21053D	\N	\N
32574	978	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21053D	\N	\N
32575	605	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21053D	\N	\N
32576	575	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19531S	\N	\N
32611	623	2023-11-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21093M	\N	\N
32612	530	2023-11-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21093M	\N	\N
32613	646	2023-11-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21093M	\N	\N
32614	573	2023-11-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21093M	\N	\N
32615	609	2023-11-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21093M	\N	\N
32625	598	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11027H	\N	\N
32626	661	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11027H	\N	\N
32627	572	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11027H	\N	\N
32628	597	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11027H	\N	\N
32629	651	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11027H	\N	\N
32630	609	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11027H	\N	\N
32631	583	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11027H	\N	\N
32632	642	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11027H	\N	\N
32633	594	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11027H	\N	\N
32634	673	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11027H	\N	\N
32635	573	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11027H	\N	\N
32636	674	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11027H	\N	\N
32708	584	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21035B	\N	\N
32709	618	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21035B	\N	\N
32710	622	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21035B	\N	\N
32735	584	2023-11-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21030V	\N	\N
32736	575	2023-11-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21030V	\N	\N
32737	573	2023-11-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21030V	\N	\N
32738	661	2023-11-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21030V	\N	\N
32739	651	2023-11-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21030V	\N	\N
32740	578	2023-11-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21030V	\N	\N
32741	590	2023-11-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21030V	\N	\N
32743	590	2023-11-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19563B	\N	\N
32744	628	2023-11-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19563B	\N	\N
32745	572	2023-11-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19347U	\N	\N
32746	598	2023-11-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19347U	\N	\N
32747	632	2023-11-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19347U	\N	\N
32748	596	2023-11-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19347U	\N	\N
32749	573	2023-11-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19347U	\N	\N
32783	586	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20112S	\N	\N
32784	622	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20112S	\N	\N
32785	641	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20112S	\N	\N
32786	620	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20112S	\N	\N
32787	575	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20112S	\N	\N
32788	979	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20112S	\N	\N
32789	642	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20112S	\N	\N
32790	626	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20112S	\N	\N
32791	584	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20112S	\N	\N
32792	574	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21088Q	\N	\N
32793	979	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21088Q	\N	\N
32794	577	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21088Q	\N	\N
32795	576	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21088Q	\N	\N
32796	595	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21088Q	\N	\N
32797	632	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21088Q	\N	\N
32798	642	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21088Q	\N	\N
32799	643	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21088Q	\N	\N
32800	978	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21088Q	\N	\N
32801	623	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	95041E	\N	\N
32804	674	2023-11-08 00:00:00	2023-11-21 00:00:00	ANCIEN	\N	\N	\N	19954N	\N	\N
32809	623	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11027H	\N	\N
32817	978	2023-11-08 00:00:00	2023-12-13 00:00:00	ANCIEN	\N	\N	\N	21032X	\N	\N
32819	616	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19760E	\N	\N
32820	601	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19760E	\N	\N
32821	580	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19760E	\N	\N
32822	530	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19760E	\N	\N
32823	589	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19760E	\N	\N
32824	584	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19760E	\N	\N
32825	600	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19760E	\N	\N
25313	556	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14281W	2017-11-17 14:39:35	\N
25314	575	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19569H	2017-11-17 14:47:05	\N
25807	966	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08031R	\N	\N
25828	1004	2017-12-19 00:00:00	2020-08-02 00:00:00	ANCIEN	\N	\N	\N	14239U	\N	\N
25853	578	2018-01-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14093U	2018-01-16 18:17:36	\N
25867	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11103C	\N	\N
25880	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
25882	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19551W	\N	\N
25883	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19723Y	\N	\N
25884	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14059S	\N	\N
25886	907	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08053X	\N	\N
25887	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14221J	\N	\N
26403	911	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14205J	\N	\N
26404	911	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14103D	\N	\N
26411	911	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19735D	\N	\N
26412	911	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14135M	\N	\N
26427	922	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19549D	\N	\N
26627	594	2018-03-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14241N	2018-03-12 09:45:42	\N
26628	622	2018-03-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14241N	2018-03-12 09:45:42	\N
26629	651	2018-03-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14241N	2018-03-12 09:45:42	\N
26630	632	2018-03-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14241N	2018-03-12 09:45:42	\N
26631	851	2018-03-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14241N	2018-03-12 09:45:42	\N
26632	628	2018-03-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14241N	2018-03-12 09:45:42	\N
26633	979	2018-03-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14241N	2018-03-12 09:45:42	\N
26634	642	2018-03-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14241N	2018-03-12 09:45:42	\N
26635	584	2018-03-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14241N	2018-03-12 09:45:42	\N
26636	620	2018-03-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14241N	2018-03-12 09:45:42	\N
26637	641	2018-03-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14241N	2018-03-12 09:45:42	\N
26638	627	2018-03-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14241N	2018-03-12 09:45:42	\N
26639	625	2018-03-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14241N	2018-03-12 09:45:42	\N
26640	663	2018-03-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14241N	2018-03-12 09:45:42	\N
26707	1007	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14329V	\N	\N
26709	1007	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01025N	\N	\N
26716	1007	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08028W	\N	\N
26917	644	2018-11-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
29139	530	2020-11-30 00:00:00	2021-04-22 00:00:00	ANCIEN	\N	\N	\N	07004J	\N	\N
29169	588	2020-12-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14059S	\N	\N
29170	585	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11072N	\N	\N
29230	646	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19723Y	\N	\N
29419	948	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14205J	\N	\N
29480	912	2020-12-18 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	08012N	\N	\N
29577	919	2020-12-28 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20018V	\N	\N
29578	1005	2020-12-28 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20018V	\N	\N
29579	907	2020-12-28 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20018V	\N	\N
29605	907	2021-01-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19679N	\N	\N
29729	948	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	05008E	\N	\N
29741	906	2021-01-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
29744	907	2021-01-12 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14213J	\N	\N
29954	919	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19711U	\N	\N
30117	1010	2021-02-03 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14026U	\N	\N
30118	1010	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
30124	1010	2021-02-03 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14031R	\N	\N
30125	1010	2021-02-03 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14147R	\N	\N
30262	933	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19611R	\N	\N
30263	933	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20052X	\N	\N
30372	612	2021-07-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19741B	\N	\N
30373	612	2021-07-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20058E	\N	\N
30461	603	2021-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19719D	\N	\N
30462	603	2021-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20092G	\N	\N
30463	609	2021-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20120S	\N	\N
30688	934	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20042V	\N	\N
30707	534	2022-11-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14037X	\N	\N
30708	573	2022-11-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14037X	\N	\N
30709	641	2022-11-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14037X	\N	\N
30710	602	2022-11-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14037X	\N	\N
30711	590	2022-11-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14037X	\N	\N
30712	583	2022-11-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14037X	\N	\N
30713	556	2022-11-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14037X	\N	\N
30714	620	2022-11-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14037X	\N	\N
30800	948	2023-09-29 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20048C	\N	\N
30803	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	19681G	\N	\N
30837	1006	2023-05-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19611R	\N	\N
31108	646	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04045F	\N	\N
31109	604	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04045F	\N	\N
31110	583	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04045F	\N	\N
31111	618	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04045F	\N	\N
31112	610	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04045F	\N	\N
31113	CHRETORIENT	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04045F	\N	\N
31114	659	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04045F	\N	\N
31115	663	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04045F	\N	\N
31116	979	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04045F	\N	\N
31117	595	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04045F	\N	\N
31118	629	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04045F	\N	\N
31419	584	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20144B	\N	\N
31420	618	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20144B	\N	\N
31421	596	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20144B	\N	\N
31422	578	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20144B	\N	\N
31423	602	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20144B	\N	\N
31759	609	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20052X	\N	\N
31760	617	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20052X	\N	\N
31761	590	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20052X	\N	\N
31762	621	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20052X	\N	\N
31763	663	2023-10-16 00:00:00	2024-01-15 00:00:00	ANCIEN	\N	\N	\N	20052X	\N	\N
31764	576	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20052X	\N	\N
31765	595	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20052X	\N	\N
31766	963	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20052X	\N	\N
31767	673	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20052X	\N	\N
31768	622	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20052X	\N	\N
31769	603	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20052X	\N	\N
31770	623	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20052X	\N	\N
32160	622	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11072N	\N	\N
32161	623	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11072N	\N	\N
33099	580	2023-11-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21045D	\N	\N
28068	625	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28069	604	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28070	611	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28071	623	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28072	590	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28073	596	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28074	594	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28075	620	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28076	571	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28077	597	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28078	643	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
28079	621	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
28080	609	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
28081	592	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
28082	647	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
28083	589	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
28084	576	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
28085	590	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
28086	600	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
28087	622	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
28088	579	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
28089	602	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
28090	601	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
28091	581	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
28092	591	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
28093	621	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19251M	\N	\N
28094	610	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19251M	\N	\N
28095	641	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19251M	\N	\N
28096	595	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19251M	\N	\N
28097	626	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19723Y	\N	\N
28098	616	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19723Y	\N	\N
28099	625	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19723Y	\N	\N
28100	583	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19866P	\N	\N
28101	591	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19866P	\N	\N
28102	622	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20060X	\N	\N
28103	616	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20060X	\N	\N
28104	609	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17229F	\N	\N
28105	598	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17229F	\N	\N
28106	651	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17229F	\N	\N
28107	626	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
28108	651	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
28109	629	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14223L	\N	\N
28110	621	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14223L	\N	\N
28111	595	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14223L	\N	\N
28112	963	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14223L	\N	\N
28113	601	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14223L	\N	\N
28114	589	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14223L	\N	\N
28115	623	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14219Q	\N	\N
28116	578	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14219Q	\N	\N
28117	642	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14219Q	\N	\N
28118	550	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14219Q	\N	\N
28119	572	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14219Q	\N	\N
28120	651	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14219Q	\N	\N
28121	598	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14355X	\N	\N
28122	643	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20106U	\N	\N
28123	629	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20106U	\N	\N
28124	978	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20106U	\N	\N
28125	618	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20106U	\N	\N
28126	642	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20106U	\N	\N
28127	625	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20106U	\N	\N
28128	589	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20106U	\N	\N
28129	661	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20106U	\N	\N
28130	674	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20106U	\N	\N
28131	596	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20106U	\N	\N
28132	979	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20106U	\N	\N
28133	594	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20106U	\N	\N
28134	663	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20106U	\N	\N
28135	651	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20106U	\N	\N
28136	979	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	12041X	\N	\N
28137	674	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
28684	576	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20100N	\N	\N
28685	622	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20100N	\N	\N
29025	592	2020-11-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19369B	\N	\N
29233	595	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20122U	\N	\N
29234	597	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14229S	\N	\N
29235	599	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19713W	\N	\N
29239	604	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19565D	\N	\N
29356	1005	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01024M	\N	\N
29470	908	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	08015R	\N	\N
29526	948	2020-12-21 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14038Y	\N	\N
29527	919	2020-12-21 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14038Y	\N	\N
29528	1005	2020-12-21 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14038Y	\N	\N
29529	906	2020-12-21 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14038Y	\N	\N
29552	907	2020-12-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19681G	\N	\N
29586	909	2020-12-21 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20088L	\N	\N
29692	919	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	05008E	\N	\N
29733	909	2021-01-13 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	08061X	\N	\N
29820	1008	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19335Q	\N	\N
29940	912	2021-01-18 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14133K	\N	\N
30006	1006	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20098N	\N	\N
30007	1006	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20064C	\N	\N
30224	CHRETORIENT	2021-03-10 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	19954N	\N	\N
30310	1011	2021-03-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11090Q	\N	\N
30249	933	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14083S	\N	\N
30259	933	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19333N	\N	\N
30346	919	2021-06-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20180F	\N	\N
30391	580	2021-08-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20098N	\N	\N
30392	530	2021-09-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08012N	\N	\N
30409	571	2021-10-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20180F	\N	\N
30410	571	2021-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11041F	\N	\N
30457	603	2021-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19703U	\N	\N
30459	919	2021-10-08 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20084G	\N	\N
30536	532	2022-03-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20142Y	\N	\N
30555	530	2022-03-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14030Q	\N	\N
30563	530	2022-03-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19643A	\N	\N
30564	851	2022-03-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	\N	\N
30624	530	2022-03-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17023S	\N	\N
30636	589	2022-06-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04047H	\N	\N
25119	598	2017-11-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11070L	2017-11-08 09:24:21	\N
25120	595	2017-11-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11070L	2017-11-08 09:24:21	\N
25121	575	2017-11-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11070L	2017-11-08 09:24:21	\N
25122	620	2017-11-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11070L	2017-11-08 09:24:21	\N
25123	626	2017-11-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01058X	2017-11-08 09:43:13	\N
25124	979	2017-11-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01058X	2017-11-08 09:43:13	\N
25125	651	2017-11-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01058X	2017-11-08 09:43:13	\N
25463	642	2017-11-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11040E	2017-11-27 09:41:08	\N
25464	629	2017-11-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11040E	2017-11-27 09:41:08	\N
25612	534	2017-12-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	2017-12-12 17:43:32	\N
25613	596	2017-12-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	2017-12-12 18:25:37	\N
25879	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14026U	\N	\N
26085	928	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14133K	\N	\N
26086	928	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
26087	928	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14093U	\N	\N
26088	928	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
26089	928	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
26090	928	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
26162	572	2018-01-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	98050T	2018-01-31 09:50:23	\N
26301	919	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19563B	\N	\N
26330	648	2018-02-05 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14079W	2018-02-07 16:54:38	\N
26331	585	2018-02-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14151M	2018-02-07 17:02:56	\N
26441	922	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11085T	\N	\N
26443	922	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08049C	\N	\N
26472	585	2018-02-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08060W	2018-02-13 14:38:01	\N
26542	909	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
26783	576	2018-06-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19565D	\N	\N
26884	644	2018-10-31 00:00:00	2019-03-08 00:00:00	ANCIEN	\N	\N	\N	04040A	\N	\N
26886	934	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08028W	\N	\N
26887	934	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01024M	\N	\N
26888	934	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14197C	\N	\N
26889	934	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	95037J	\N	\N
26890	934	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14031R	\N	\N
26891	934	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14147R	\N	\N
26892	934	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
26963	1005	2019-02-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19631V	\N	\N
26964	919	2019-02-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19631V	\N	\N
27097	674	2020-06-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11090Q	\N	\N
27098	584	2020-07-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19441R	\N	\N
27514	642	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11040E	\N	\N
27515	629	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11040E	\N	\N
27516	618	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
27517	628	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
27518	643	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
27519	647	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
27520	534	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
27521	605	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
27522	575	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
27523	616	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
27524	530	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
27525	590	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
27526	621	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
27527	653	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
27528	592	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
27529	632	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
27530	615	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
27531	663	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
27532	597	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
27533	620	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
27534	674	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
27535	582	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
27536	571	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
27537	608	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
27538	556	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
27539	617	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
27540	573	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
27541	619	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
27542	659	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
27543	596	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
27544	979	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
27545	572	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
27546	576	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
27547	641	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
27548	598	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
27549	600	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
27550	613	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
27551	584	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
27552	624	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
27553	595	2020-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
27554	651	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19319Q	\N	\N
27555	651	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08012N	\N	\N
27556	647	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08012N	\N	\N
27557	602	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08012N	\N	\N
27558	599	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08012N	\N	\N
27559	571	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08012N	\N	\N
27560	979	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20090E	\N	\N
27561	642	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20024T	\N	\N
27562	573	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20024T	\N	\N
27563	978	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20024T	\N	\N
27564	963	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20024T	\N	\N
27565	602	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20024T	\N	\N
27566	597	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20024T	\N	\N
27567	598	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20024T	\N	\N
27568	600	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20024T	\N	\N
27569	580	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20024T	\N	\N
27570	629	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20024T	\N	\N
27571	619	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14217N	\N	\N
27572	600	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14217N	\N	\N
27573	580	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19335Q	\N	\N
27574	529	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	95063L	\N	\N
27575	604	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	95063L	\N	\N
27576	623	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	95063L	\N	\N
27577	590	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	95063L	\N	\N
27578	611	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	95063L	\N	\N
32826	618	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19760E	\N	\N
32857	623	2023-11-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20146D	\N	\N
32872	600	2023-11-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21067K	\N	\N
32899	581	2023-11-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11040E	\N	\N
32900	608	2023-11-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11040E	\N	\N
32901	594	2023-11-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11040E	\N	\N
32902	629	2023-11-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11040E	\N	\N
32917	634	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14147R	\N	\N
32944	661	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21038E	\N	\N
32945	623	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21038E	\N	\N
32951	595	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21072G	\N	\N
32952	622	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21072G	\N	\N
32953	598	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21072G	\N	\N
32954	590	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21072G	\N	\N
32955	575	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21072G	\N	\N
32956	584	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21072G	\N	\N
32957	601	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21072G	\N	\N
32958	530	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21072G	\N	\N
32959	573	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21072G	\N	\N
32960	605	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21072G	\N	\N
32961	604	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21072G	\N	\N
32962	632	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21072G	\N	\N
32963	577	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20028X	\N	\N
32964	591	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20028X	\N	\N
33038	673	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21058J	\N	\N
33074	583	2023-11-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21064G	\N	\N
33075	604	2023-11-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21064G	\N	\N
33076	653	2023-11-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21064G	\N	\N
33077	648	2023-11-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21064G	\N	\N
33078	643	2023-11-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21064G	\N	\N
33079	673	2023-11-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21064G	\N	\N
33080	530	2023-11-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21064G	\N	\N
33083	673	2023-11-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20122U	\N	\N
33103	595	2023-11-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19954N	\N	\N
33106	622	2023-11-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19331L	\N	\N
33107	573	2023-11-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19331L	\N	\N
33108	574	2023-11-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19331L	\N	\N
33111	644	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20122U	\N	\N
33112	673	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19507S	\N	\N
33113	556	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21052C	\N	\N
33114	674	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20068G	\N	\N
33155	623	2023-11-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19347U	\N	\N
33156	1013	2023-11-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19782L	\N	\N
33162	600	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21031W	\N	\N
33167	605	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08010L	\N	\N
33172	625	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20118Y	\N	\N
33204	673	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08010L	\N	\N
33207	623	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14205J	\N	\N
33220	674	2023-11-30 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04092N	\N	\N
33221	613	2023-11-30 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04092N	\N	\N
33230	963	2023-12-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19631V	\N	\N
33231	979	2023-12-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19631V	\N	\N
33232	629	2023-12-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14089Y	\N	\N
33233	642	2023-12-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21062E	\N	\N
33235	629	2023-12-04 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14030Q	\N	\N
33239	642	2023-12-04 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14219Q	\N	\N
33240	589	2023-12-04 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11110B	\N	\N
33241	590	2023-12-04 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11110B	\N	\N
33247	673	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14193X	\N	\N
33251	599	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08045X	\N	\N
33259	661	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14083S	\N	\N
33268	550	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14249W	\N	\N
33269	605	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14249W	\N	\N
33271	573	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21031W	\N	\N
33289	595	2023-12-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14053L	\N	\N
33291	651	2023-12-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08012N	\N	\N
33293	633	2023-12-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21079P	\N	\N
33294	594	2023-12-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21079P	\N	\N
33298	595	2023-12-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19447X	\N	\N
33300	613	2023-12-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19569H	\N	\N
33308	595	2023-12-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14215L	\N	\N
33317	852	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19563B	\N	\N
33321	663	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19782L	\N	\N
33325	584	2023-12-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20050V	\N	\N
33363	595	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14089Y	\N	\N
33370	584	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21056G	\N	\N
33374	674	2023-12-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21070E	\N	\N
33375	674	2023-12-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20122U	\N	\N
33376	632	2023-12-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	07029T	\N	\N
33390	616	2023-12-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20118Y	\N	\N
33395	640	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19713W	\N	\N
33399	615	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19611R	\N	\N
33411	1008	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20082E	\N	\N
33413	529	2023-12-22 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14195A	\N	\N
33414	529	2023-12-22 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21065H	\N	\N
33417	529	2023-12-22 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21087P	\N	\N
33420	1007	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14169X	\N	\N
33422	1007	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19673G	\N	\N
33423	1007	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20056C	\N	\N
33426	1006	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19693L	\N	\N
33427	1006	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21032X	\N	\N
33428	1006	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14026U	\N	\N
33443	934	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20026V	\N	\N
33445	966	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20026V	\N	\N
33454	1006	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19575F	\N	\N
33456	966	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20058E	\N	\N
33458	529	2024-01-04 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14211G	\N	\N
33460	934	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14189C	\N	\N
33467	529	2024-01-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21054E	\N	\N
33488	619	2024-01-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14357A	\N	\N
33491	595	2024-01-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14111D	\N	\N
33492	659	2024-01-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14111D	\N	\N
33493	529	2024-01-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14111D	\N	\N
33494	623	2024-01-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14111D	\N	\N
33499	641	2024-01-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19545Y	\N	\N
33500	1013	2024-01-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19545Y	\N	\N
33501	619	2024-01-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14223L	\N	\N
33502	619	2024-01-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11056N	\N	\N
33503	619	2024-01-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11043H	\N	\N
25026	621	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19593H	2017-11-02 11:15:51	\N
25027	580	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19593H	2017-11-02 11:15:51	\N
25028	604	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19593H	2017-11-02 11:15:51	\N
25029	647	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19593H	2017-11-02 11:15:51	\N
25030	641	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19593H	2017-11-02 11:15:51	\N
25656	588	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14193X	2017-12-19 15:35:12	\N
25830	1004	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19667J	\N	\N
25832	1004	2017-12-19 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	98029W	\N	\N
25833	1004	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14195A	\N	\N
25834	1004	2017-12-19 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14079W	\N	\N
25835	1004	2017-12-19 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08052W	\N	\N
25836	1004	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19663E	\N	\N
25837	1004	2017-12-19 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	98024R	\N	\N
25838	1004	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	10006L	\N	\N
25839	1004	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	\N	\N
25840	1004	2017-12-19 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	02002K	\N	\N
25841	1004	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14231L	\N	\N
25842	1004	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19565D	\N	\N
26147	909	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19549D	\N	\N
26172	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	16685X	\N	\N
26176	907	2017-10-01 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	07034Q	\N	\N
26290	919	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19551W	\N	\N
26569	933	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08073C	\N	\N
26570	933	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11053K	\N	\N
26571	933	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	\N	\N
26572	933	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08031R	\N	\N
26573	933	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
26574	933	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
26578	933	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
26581	933	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19399H	\N	\N
26584	585	2018-02-15 00:00:00	2020-06-15 00:00:00	ANCIEN	\N	\N	\N	08068F	2018-02-20 09:49:13	\N
26701	1007	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
26748	919	2018-03-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	\N	\N
26749	1005	2018-03-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	\N	\N
26757	906	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19747H	\N	\N
26853	674	2018-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
26854	556	2018-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
26856	610	2018-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19701S	\N	\N
26857	610	2018-10-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
28555	609	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14123H	\N	\N
28556	621	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14123H	\N	\N
28557	629	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14123H	\N	\N
28983	588	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14331P	\N	\N
28984	612	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19671E	\N	\N
28985	595	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14231L	\N	\N
28986	625	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14231L	\N	\N
28987	612	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19826F	\N	\N
29087	604	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14357A	\N	\N
29088	613	2020-11-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19711U	\N	\N
29089	640	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20022R	\N	\N
29090	661	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19507S	\N	\N
29091	579	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19735D	\N	\N
29492	907	2020-12-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17589D	\N	\N
29502	948	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19551W	\N	\N
29544	907	2020-12-17 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20092G	\N	\N
29563	909	2020-12-23 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
29564	907	2020-12-23 00:00:00	2020-12-23 00:00:00	ANCIEN	\N	\N	\N	20112S	\N	\N
29806	1008	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19651A	\N	\N
29844	1006	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19515S	\N	\N
29847	1006	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
29848	1006	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20132W	\N	\N
29849	1006	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
29995	919	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19741B	\N	\N
30001	911	2021-01-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19531S	\N	\N
30060	1006	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19766L	\N	\N
30091	919	2021-02-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04085P	\N	\N
30092	919	2021-02-02 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20024T	\N	\N
30134	1010	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11090Q	\N	\N
30148	1008	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20026V	\N	\N
30206	906	2021-02-16 00:00:00	2021-02-16 00:00:00	ANCIEN	\N	\N	\N	14133K	\N	\N
30434	1010	2021-10-12 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20108W	\N	\N
30497	908	2021-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20150Y	\N	\N
30597	1013	2022-04-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20118Y	\N	\N
30598	1013	2022-04-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19671E	\N	\N
30599	1013	2022-04-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19713W	\N	\N
30601	1013	2022-04-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
30603	1013	2022-04-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14055N	\N	\N
30640	911	2022-06-07 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20092G	\N	\N
30774	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	14053L	\N	\N
30928	583	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19301E	\N	\N
30929	618	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19301E	\N	\N
30930	623	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19301E	\N	\N
30931	642	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19301E	\N	\N
31124	979	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20090E	\N	\N
31125	589	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20090E	\N	\N
31126	643	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20090E	\N	\N
31127	978	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20090E	\N	\N
31130	610	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19533U	\N	\N
31131	646	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19533U	\N	\N
31132	574	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19533U	\N	\N
31133	578	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19533U	\N	\N
31134	622	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19533U	\N	\N
31135	573	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19533U	\N	\N
31136	625	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19533U	\N	\N
31137	663	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19533U	\N	\N
31138	642	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19533U	\N	\N
31184	641	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31185	581	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31186	618	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31187	663	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31188	573	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31189	978	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31190	625	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31191	583	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31192	572	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
30637	625	2022-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20124W	\N	\N
30638	612	2022-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20124W	\N	\N
30653	1011	2022-07-21 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20024T	\N	\N
30705	647	2022-11-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20106U	\N	\N
30742	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	14026U	\N	\N
30743	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	14147R	\N	\N
30785	572	2022-02-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20264J	\N	\N
30992	643	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19685L	\N	\N
30851	623	2023-06-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	95041E	\N	\N
30993	646	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19685L	\N	\N
30994	580	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19685L	\N	\N
31256	626	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	18193Q	\N	\N
31257	609	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	18193Q	\N	\N
31315	626	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20146D	\N	\N
31316	576	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20146D	\N	\N
31317	642	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20146D	\N	\N
31323	1013	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20180F	\N	\N
31373	641	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14055N	\N	\N
31424	603	2023-10-10 00:00:00	2024-01-12 00:00:00	ANCIEN	\N	\N	\N	20080C	\N	\N
31425	978	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20080C	\N	\N
31488	851	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19553Y	\N	\N
31489	580	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19553Y	\N	\N
31663	629	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19563B	\N	\N
31664	851	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19563B	\N	\N
31665	580	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19563B	\N	\N
31666	595	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19563B	\N	\N
31696	641	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20110Q	\N	\N
31697	532	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20110Q	\N	\N
31698	623	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20110Q	\N	\N
31699	580	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21091K	\N	\N
31778	573	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	18231D	\N	\N
31779	590	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	18231D	\N	\N
31780	583	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	18231D	\N	\N
31781	622	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	18231D	\N	\N
31782	598	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	18231D	\N	\N
31783	584	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	18231D	\N	\N
31784	575	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	18231D	\N	\N
31785	620	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	18231D	\N	\N
31823	575	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19631V	\N	\N
31824	583	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19631V	\N	\N
31825	622	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19631V	\N	\N
31985	583	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21051B	\N	\N
31986	604	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21051B	\N	\N
32037	851	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20132W	\N	\N
32038	624	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20132W	\N	\N
32039	604	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20132W	\N	\N
32040	597	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20132W	\N	\N
32041	579	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20132W	\N	\N
32049	580	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14331P	\N	\N
32050	592	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14331P	\N	\N
32051	604	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14331P	\N	\N
32052	579	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14331P	\N	\N
32053	621	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14331P	\N	\N
32054	530	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14331P	\N	\N
32055	581	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14331P	\N	\N
32183	623	2023-10-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20096L	\N	\N
32186	550	2023-10-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11064N	\N	\N
32208	602	2023-10-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21087P	\N	\N
32209	583	2023-10-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21087P	\N	\N
32210	599	2023-10-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21087P	\N	\N
32211	629	2023-10-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21087P	\N	\N
32212	530	2023-10-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21087P	\N	\N
32213	622	2023-10-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21034A	\N	\N
32214	640	2023-10-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20058E	\N	\N
32215	609	2023-10-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20058E	\N	\N
32216	616	2023-10-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20058E	\N	\N
32217	625	2023-10-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20058E	\N	\N
32218	579	2023-10-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20058E	\N	\N
32336	613	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14275Y	\N	\N
32337	613	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14205J	\N	\N
32423	597	2023-10-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19111A	\N	\N
32432	602	2023-10-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04070G	\N	\N
32457	604	2023-10-30 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21076L	\N	\N
32501	598	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20108W	\N	\N
32508	597	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04033B	\N	\N
32509	641	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04033B	\N	\N
32510	1013	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04033B	\N	\N
32511	615	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04033B	\N	\N
32512	629	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04033B	\N	\N
32523	612	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20138D	\N	\N
32525	612	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19709B	\N	\N
32526	529	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21037D	\N	\N
32527	572	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21037D	\N	\N
32528	651	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21037D	\N	\N
32529	579	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21037D	\N	\N
32530	618	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21037D	\N	\N
32531	532	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21037D	\N	\N
32532	596	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21037D	\N	\N
32533	604	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21037D	\N	\N
32534	590	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21037D	\N	\N
32535	605	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21037D	\N	\N
32536	643	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21037D	\N	\N
32537	573	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21037D	\N	\N
32538	621	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21037D	\N	\N
32539	598	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21037D	\N	\N
32582	583	2023-10-31 00:00:00	2023-11-15 00:00:00	ANCIEN	\N	\N	\N	21074J	\N	\N
32583	674	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21074J	\N	\N
32584	633	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20092G	\N	\N
32585	572	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20092G	\N	\N
32586	640	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20092G	\N	\N
32587	623	2023-11-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20150Y	\N	\N
32588	978	2023-11-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20150Y	\N	\N
32589	602	2023-11-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20150Y	\N	\N
32590	577	2023-11-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20150Y	\N	\N
32591	584	2023-11-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20150Y	\N	\N
32592	581	2023-11-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20150Y	\N	\N
32593	651	2023-11-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20150Y	\N	\N
32594	611	2023-11-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20150Y	\N	\N
25065	CHRETORIENT	2017-10-25 00:00:00	2023-10-05 00:00:00	ANCIEN	\N	\N	\N	17637T	2017-11-03 14:04:15	\N
25066	CHRETORIENT	2017-10-25 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	19647E	2017-11-03 14:08:12	\N
25067	CHRETORIENT	2017-10-20 00:00:00	2020-11-02 00:00:00	ANCIEN	\N	\N	\N	08048B	2017-11-03 14:09:30	\N
25126	575	2017-10-29 00:00:00	2020-08-03 00:00:00	ANCIEN	\N	\N	\N	08035V	2017-11-08 11:36:52	\N
25978	578	2018-01-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11045K	2018-01-22 11:53:25	\N
26091	928	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	19681G	\N	\N
26251	584	2018-02-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19659J	2018-02-06 15:02:49	\N
26252	573	2018-02-02 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08053X	2018-02-06 15:03:07	\N
26599	852	2018-02-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	2018-02-23 09:54:46	\N
26756	1008	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19549D	\N	\N
26762	906	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14265W	\N	\N
26776	852	2018-02-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14079W	2018-06-07 09:47:37	\N
26991	906	2018-01-18 00:00:00	2019-03-15 00:00:00	ANCIEN	\N	\N	\N	14079W	\N	\N
27043	1007	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14187A	\N	\N
27089	608	2020-02-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	18083K	\N	\N
29385	911	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14073Q	\N	\N
27579	674	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	95063L	\N	\N
27580	584	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	95063L	\N	\N
27581	609	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	95063L	\N	\N
27582	625	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	95063L	\N	\N
27583	659	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14331P	\N	\N
27584	579	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14331P	\N	\N
27585	674	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14331P	\N	\N
27586	581	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14331P	\N	\N
28267	588	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
28268	595	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
28269	608	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
28270	585	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
28271	591	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
28272	572	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
28273	582	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
28274	646	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
28275	556	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
28276	642	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
28277	647	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
28278	661	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
28279	575	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
28280	625	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
28281	651	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
28282	576	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19295A	\N	\N
28283	642	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19295A	\N	\N
28284	625	2020-10-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19782L	\N	\N
28285	609	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08010L	\N	\N
28286	532	2020-10-16 00:00:00	2020-11-25 00:00:00	ANCIEN	\N	\N	\N	19685L	\N	\N
28287	643	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19685L	\N	\N
28288	598	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01025N	\N	\N
28289	663	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19695N	\N	\N
28290	597	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19695N	\N	\N
28291	979	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19695N	\N	\N
28292	575	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19695N	\N	\N
28293	590	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19695N	\N	\N
28294	601	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19695N	\N	\N
28295	574	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19695N	\N	\N
28296	632	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19695N	\N	\N
28297	978	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19695N	\N	\N
28298	609	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19741B	\N	\N
28299	629	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19543W	\N	\N
28300	572	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19543W	\N	\N
28301	556	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19543W	\N	\N
28302	623	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19543W	\N	\N
28303	598	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19543W	\N	\N
28304	622	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19657G	\N	\N
28305	626	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14073Q	\N	\N
28306	661	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14073Q	\N	\N
28307	592	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14073Q	\N	\N
28308	572	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14073Q	\N	\N
28309	617	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14073Q	\N	\N
28310	623	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14073Q	\N	\N
28311	598	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14073Q	\N	\N
28312	615	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14073Q	\N	\N
28313	620	2020-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14073Q	\N	\N
28314	609	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14187A	\N	\N
28315	978	2020-10-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
28316	578	2020-10-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
28317	608	2020-10-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
28318	574	2020-10-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
28319	602	2020-10-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
29166	585	2020-12-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
29167	602	2020-12-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
29294	907	2020-12-18 00:00:00	2020-12-18 00:00:00	ANCIEN	\N	\N	\N	19760E	\N	\N
29295	907	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20086J	\N	\N
29386	911	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11099A	\N	\N
29468	908	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11109J	\N	\N
29469	908	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19820Y	\N	\N
29477	919	2020-12-17 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	08028W	\N	\N
29561	906	2020-12-23 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
29562	948	2020-12-23 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
29606	907	2021-01-06 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14237S	\N	\N
29609	919	2021-01-04 00:00:00	2022-06-20 00:00:00	ANCIEN	\N	\N	\N	20174H	\N	\N
29624	909	2021-01-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19515S	\N	\N
29640	911	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11097X	\N	\N
29761	907	2021-01-11 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20122U	\N	\N
29762	911	2021-01-11 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20122U	\N	\N
29936	1007	2020-10-01 00:00:00	2022-12-31 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
29939	911	2021-01-18 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14133K	\N	\N
29970	919	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11090Q	\N	\N
29971	919	2021-01-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11043H	\N	\N
29972	919	2021-01-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19413M	\N	\N
29985	919	2021-01-20 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20032T	\N	\N
30004	918	2020-01-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19383Y	\N	\N
30142	1006	2020-12-10 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20042V	\N	\N
30320	1011	2021-03-27 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20062A	\N	\N
30323	911	2021-04-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19413M	\N	\N
30324	1011	2021-04-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19413M	\N	\N
30333	603	2021-05-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20142Y	\N	\N
32913	622	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21092L	\N	\N
32916	576	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20048C	\N	\N
33505	619	2024-01-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19421M	\N	\N
33508	573	2024-01-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14211G	\N	\N
33509	619	2024-01-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08056B	\N	\N
33527	1008	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20132W	\N	\N
33533	619	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20022R	\N	\N
33539	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14033T	\N	\N
33544	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20082E	\N	\N
33550	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14205J	\N	\N
33553	1004	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	19667J	\N	\N
33554	1004	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	19295A	\N	\N
33555	1004	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	19693L	\N	\N
33556	1004	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	20140W	\N	\N
33557	1004	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	20074E	\N	\N
33558	1004	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	19553Y	\N	\N
33572	1004	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	14071N	\N	\N
33577	663	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21070E	\N	\N
33585	934	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21037D	\N	\N
33589	651	2024-01-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19507S	\N	\N
33592	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	20106U	\N	\N
33597	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	19679N	\N	\N
33594	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	07029T	\N	\N
33596	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	14109K	\N	\N
33607	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	21065H	\N	\N
33608	928	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	14133K	\N	\N
33611	928	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	14030Q	\N	\N
33612	928	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	20114U	\N	\N
33621	928	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	19691J	\N	\N
33627	928	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	19709B	\N	\N
33632	928	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	21039F	\N	\N
33636	928	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	19349W	\N	\N
33647	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14195A	\N	\N
33648	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21065H	\N	\N
33649	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21041Y	\N	\N
33650	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19719D	\N	\N
33651	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20140W	\N	\N
33652	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14042U	\N	\N
33653	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20038A	\N	\N
33655	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19725B	\N	\N
33660	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19551W	\N	\N
33663	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14059S	\N	\N
33664	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	04070G	\N	\N
33665	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20050V	\N	\N
33668	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20054A	\N	\N
33675	966	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14083S	\N	\N
33681	1007	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21079P	\N	\N
33684	1006	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20024T	\N	\N
33685	1006	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19954N	\N	\N
33686	1006	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	17367Q	\N	\N
33687	1006	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21089R	\N	\N
33690	1006	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21078N	\N	\N
33691	1006	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21029D	\N	\N
33692	1006	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20150Y	\N	\N
33695	550	2024-01-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14111D	\N	\N
33696	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20126Y	\N	\N
33697	1008	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	05008E	\N	\N
33698	1006	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21074J	\N	\N
33702	657	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14083S	\N	\N
33704	623	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14193X	\N	\N
33709	1013	2024-01-22 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19629C	\N	\N
33710	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14133K	\N	\N
33711	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14189C	\N	\N
33712	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19631V	\N	\N
33714	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	05008E	\N	\N
33715	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19667J	\N	\N
33717	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20022R	\N	\N
33718	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19575F	\N	\N
33719	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14030Q	\N	\N
33720	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	17367Q	\N	\N
33721	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20086J	\N	\N
33722	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21050A	\N	\N
33723	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14069U	\N	\N
33727	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20114U	\N	\N
33729	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19621T	\N	\N
33730	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19782L	\N	\N
33732	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14207L	\N	\N
33750	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20124W	\N	\N
33754	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19507S	\N	\N
33755	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14187A	\N	\N
33763	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20180F	\N	\N
33764	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	08056B	\N	\N
33769	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	08069G	\N	\N
33784	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	18193Q	\N	\N
33789	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14221J	\N	\N
33795	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14071N	\N	\N
33797	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19768N	\N	\N
33798	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14237S	\N	\N
33817	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20044X	\N	\N
33818	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	11043H	\N	\N
33824	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20136B	\N	\N
33826	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20046A	\N	\N
33836	578	2024-01-22 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08018U	\N	\N
33838	634	2024-01-22 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21039F	\N	\N
33839	643	2024-01-22 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21039F	\N	\N
33842	550	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21052C	\N	\N
33851	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20024T	\N	\N
33845	1012	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14331P	\N	\N
33850	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21084L	\N	\N
33852	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19575F	\N	\N
33881	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20066E	\N	\N
33882	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20126Y	\N	\N
33883	906	2023-09-30 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	21071F	\N	\N
33887	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	18207D	\N	\N
33890	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21054E	\N	\N
33898	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19563B	\N	\N
33902	1005	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19575F	\N	\N
33904	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14257W	\N	\N
33905	1005	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14105F	\N	\N
33906	1005	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20114U	\N	\N
33907	1005	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19621T	\N	\N
33908	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14071N	\N	\N
33909	1005	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19782L	\N	\N
33917	918	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19631V	\N	\N
25726	1007	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	05008E	\N	\N
25727	1007	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14030Q	\N	\N
25729	1007	2017-12-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	19731Y	\N	\N
25730	1007	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14059S	\N	\N
25731	1007	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
25732	966	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	05008E	\N	\N
25733	966	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08043V	\N	\N
25734	966	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	87003B	\N	\N
25735	966	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	19731Y	\N	\N
25736	966	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14229S	\N	\N
25737	1006	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19515S	\N	\N
25738	1006	2017-12-07 00:00:00	2018-07-27 00:00:00	ANCIEN	\N	\N	\N	19707Y	\N	\N
25739	1006	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14030Q	\N	\N
25740	1006	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	\N	\N
25741	1006	2017-12-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14249W	\N	\N
25742	1006	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
25743	1006	2017-12-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14241N	\N	\N
25744	1006	2017-12-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	19731Y	\N	\N
25745	1006	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08017T	\N	\N
25748	1006	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19705W	\N	\N
26031	609	2018-01-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	2018-01-24 14:43:45	\N
26032	647	2018-01-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19667J	2018-01-24 14:44:08	\N
26033	611	2018-01-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19667J	2018-01-24 14:44:08	\N
26034	647	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2018-01-24 14:48:01	\N
26036	616	2018-01-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19521Q	2018-01-24 16:35:32	\N
26037	586	2018-01-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19521Q	2018-01-24 16:35:32	\N
26038	586	2018-01-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	2018-01-24 17:38:18	\N
26103	928	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	07029T	\N	\N
26212	586	2018-01-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	07033P	2018-02-01 14:47:05	\N
26213	608	2018-01-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19503N	2018-02-01 14:47:49	\N
26214	598	2018-01-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19503N	2018-02-01 14:47:49	\N
26357	1005	2018-01-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	\N	\N
26745	908	2018-04-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19723Y	\N	\N
26779	616	2018-01-31 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	19269X	2018-06-12 15:16:17	\N
26780	578	2018-01-18 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14081Q	2018-06-12 15:16:29	\N
26789	CHRETORIENT	2018-06-27 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	14021P	\N	\N
26849	1005	2018-10-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
27066	659	2020-01-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14053L	\N	\N
28798	608	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
28799	674	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19447X	\N	\N
28800	646	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19447X	\N	\N
28801	597	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19447X	\N	\N
28802	604	2020-11-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20096L	\N	\N
29175	530	2020-12-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14147R	\N	\N
29176	633	2020-12-02 00:00:00	2022-07-03 00:00:00	ANCIEN	\N	\N	\N	19689Q	\N	\N
29302	907	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19719D	\N	\N
29303	907	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14187A	\N	\N
29393	912	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	08045X	\N	\N
29395	912	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19447X	\N	\N
29396	912	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14073Q	\N	\N
29425	948	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20058E	\N	\N
29426	948	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11043H	\N	\N
29782	1008	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19643A	\N	\N
29812	1008	2020-10-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19533U	\N	\N
29813	1008	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19349W	\N	\N
29814	1008	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19798U	\N	\N
29819	1008	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19701S	\N	\N
29821	1008	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	\N	\N
29850	1006	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14213J	\N	\N
29851	1006	2020-10-01 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	08017T	\N	\N
29852	1006	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11041F	\N	\N
29858	966	2020-10-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20180F	\N	\N
29859	966	2020-10-01 00:00:00	2026-03-01 00:00:00	ACTIF	\N	\N	\N	20056C	\N	\N
30072	919	2021-01-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19399H	\N	\N
30154	938	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14357A	\N	\N
30155	938	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14147R	\N	\N
30278	618	2021-03-24 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	14041T	\N	\N
30336	601	2021-05-31 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	10006L	\N	\N
30472	640	2021-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20098N	\N	\N
30527	530	2022-02-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14331P	\N	\N
30528	532	2022-02-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20092G	\N	\N
30552	530	2022-03-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	07004J	\N	\N
30622	673	2021-01-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20128B	\N	\N
30623	623	2022-05-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20128B	\N	\N
30664	623	2022-09-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14237S	\N	\N
30665	621	2022-09-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14331P	\N	\N
31193	621	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31194	851	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31195	601	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31196	613	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31197	611	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31198	609	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31199	616	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31200	659	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31201	620	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31202	626	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31203	646	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31204	605	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31205	577	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31206	979	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31207	574	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31208	643	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31209	594	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31210	598	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31211	530	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31212	963	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31213	582	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31214	580	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31215	578	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31216	585	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31217	591	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31218	571	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31219	622	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
32595	625	2023-11-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20150Y	\N	\N
32596	599	2023-11-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20150Y	\N	\N
32597	604	2023-11-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20150Y	\N	\N
32598	622	2023-11-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20150Y	\N	\N
32599	596	2023-11-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20150Y	\N	\N
32600	609	2023-11-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20150Y	\N	\N
32601	578	2023-11-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20150Y	\N	\N
32602	663	2023-11-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20150Y	\N	\N
32603	613	2023-11-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20150Y	\N	\N
32604	626	2023-11-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20150Y	\N	\N
32616	580	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20122U	\N	\N
32617	600	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20122U	\N	\N
32618	595	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20122U	\N	\N
32619	530	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04092N	\N	\N
32620	647	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04092N	\N	\N
32621	594	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04092N	\N	\N
32622	673	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04092N	\N	\N
32623	625	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04092N	\N	\N
32624	642	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04092N	\N	\N
32637	605	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21048G	\N	\N
32638	621	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21048G	\N	\N
32639	659	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21048G	\N	\N
32640	529	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21048G	\N	\N
32641	624	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21048G	\N	\N
32642	622	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21079P	\N	\N
32643	625	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21079P	\N	\N
32644	581	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21079P	\N	\N
32645	577	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21079P	\N	\N
32646	641	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14037X	\N	\N
32647	620	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14037X	\N	\N
32648	590	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14037X	\N	\N
32649	623	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14037X	\N	\N
32650	556	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14037X	\N	\N
32651	602	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14037X	\N	\N
32652	534	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14037X	\N	\N
32653	573	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14037X	\N	\N
32654	572	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14037X	\N	\N
32655	618	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14037X	\N	\N
32656	584	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14037X	\N	\N
32657	588	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14037X	\N	\N
32658	597	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14037X	\N	\N
32659	622	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14037X	\N	\N
32660	CHRETORIENT	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14037X	\N	\N
32661	583	2023-11-02 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14037X	\N	\N
32674	583	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21052C	\N	\N
32675	594	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21052C	\N	\N
32676	622	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21052C	\N	\N
32677	576	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21052C	\N	\N
32678	609	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21052C	\N	\N
32679	642	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21052C	\N	\N
32680	598	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21052C	\N	\N
32681	661	2023-11-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21052C	\N	\N
32761	CHRETORIENT	2023-11-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21083K	\N	\N
32762	622	2023-11-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21083K	\N	\N
32802	605	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	07033P	\N	\N
32812	597	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19593H	\N	\N
32813	644	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19593H	\N	\N
32814	659	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19593H	\N	\N
32815	852	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19593H	\N	\N
32818	617	2023-11-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19611R	\N	\N
32831	623	2023-11-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04045F	\N	\N
32860	674	2023-11-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21049H	\N	\N
32861	592	2023-11-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21049H	\N	\N
32862	605	2023-11-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21049H	\N	\N
32863	851	2023-11-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21049H	\N	\N
32864	621	2023-11-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21049H	\N	\N
32865	622	2023-11-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21049H	\N	\N
32866	611	2023-11-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21049H	\N	\N
32867	530	2023-11-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21049H	\N	\N
32868	571	2023-11-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21049H	\N	\N
32904	590	2023-11-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19575F	\N	\N
32918	576	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19758L	\N	\N
32919	602	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19758L	\N	\N
32920	594	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19758L	\N	\N
32924	604	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21059K	\N	\N
32925	632	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21059K	\N	\N
32926	573	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21059K	\N	\N
32927	608	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21059K	\N	\N
32928	530	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21059K	\N	\N
32929	590	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21059K	\N	\N
32930	598	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21059K	\N	\N
32931	577	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21059K	\N	\N
32932	595	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21059K	\N	\N
32933	583	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21059K	\N	\N
32934	626	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21059K	\N	\N
32935	601	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21059K	\N	\N
32936	597	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21059K	\N	\N
32937	584	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21059K	\N	\N
32938	613	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21059K	\N	\N
32939	604	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19565D	\N	\N
32940	580	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19565D	\N	\N
32941	610	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19565D	\N	\N
32942	579	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19565D	\N	\N
32943	599	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19565D	\N	\N
32947	581	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21059K	\N	\N
33071	673	2023-11-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14331P	\N	\N
33073	673	2023-11-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20126Y	\N	\N
33110	673	2023-11-22 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20248J	\N	\N
33163	585	2023-11-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04042C	\N	\N
33164	556	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21059K	\N	\N
33171	596	2023-11-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20094J	\N	\N
33180	628	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19611R	\N	\N
33181	595	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19611R	\N	\N
33182	601	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19611R	\N	\N
33183	621	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19611R	\N	\N
33184	608	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19611R	\N	\N
33185	592	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19611R	\N	\N
33186	573	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19611R	\N	\N
25548	601	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08034U	2017-12-06 11:35:18	\N
25549	530	2017-12-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	07004J	2017-12-06 11:35:50	\N
25550	601	2017-11-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19729F	2017-12-06 11:40:03	\N
25551	641	2017-11-29 00:00:00	2017-12-06 00:00:00	ANCIEN	\N	\N	\N	19729F	2017-12-06 11:40:03	2017-12-06 11:43:46
25552	605	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19729F	2017-12-06 11:40:52	\N
25553	603	2017-12-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	98022P	2017-12-06 11:52:22	\N
26125	948	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19745F	\N	\N
26523	938	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14357A	\N	\N
26525	938	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	\N	\N
26528	938	2017-10-01 00:00:00	2020-07-31 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	\N
26529	938	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14061L	\N	\N
26560	933	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19735D	\N	\N
26562	933	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	96004D	\N	\N
26563	933	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11048N	\N	\N
26795	588	2018-07-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
26847	674	2018-10-03 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14038Y	\N	\N
26848	602	2018-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19489J	\N	\N
26863	627	2018-10-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08024S	\N	\N
26919	934	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	98022P	\N	\N
26996	624	2019-03-11 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	19253P	\N	\N
27631	598	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04042C	\N	\N
27632	621	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04042C	\N	\N
27633	608	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04042C	\N	\N
27634	629	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04042C	\N	\N
27635	584	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14121F	\N	\N
27636	663	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14121F	\N	\N
27637	604	2020-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14121F	\N	\N
28138	602	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19441R	\N	\N
28139	584	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19441R	\N	\N
28140	626	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14217N	\N	\N
28141	595	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11085T	\N	\N
28142	532	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11085T	\N	\N
28143	621	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11085T	\N	\N
28144	584	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11085T	\N	\N
28145	598	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11085T	\N	\N
28146	629	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11085T	\N	\N
28147	641	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11085T	\N	\N
28148	580	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01062T	\N	\N
28149	602	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01062T	\N	\N
28150	621	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01062T	\N	\N
28151	529	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19585H	\N	\N
28886	598	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14249W	\N	\N
28887	622	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14249W	\N	\N
28888	609	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14249W	\N	\N
28889	625	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14249W	\N	\N
28890	575	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14249W	\N	\N
28891	621	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14249W	\N	\N
28892	576	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14249W	\N	\N
28893	592	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14249W	\N	\N
28894	615	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14249W	\N	\N
28895	611	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14249W	\N	\N
28896	624	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14249W	\N	\N
28897	642	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14249W	\N	\N
28898	529	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14249W	\N	\N
28899	608	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14249W	\N	\N
28900	629	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14249W	\N	\N
28901	644	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14249W	\N	\N
29187	644	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
29270	918	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14327T	\N	\N
29365	907	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20024T	\N	\N
29366	998	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11109J	\N	\N
29373	998	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11099A	\N	\N
29377	911	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19467C	\N	\N
29405	906	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19333N	\N	\N
29449	909	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20028X	\N	\N
29450	909	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19745F	\N	\N
29451	909	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20030R	\N	\N
29452	909	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19503N	\N	\N
29453	909	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
29454	909	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19713W	\N	\N
29455	909	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20026V	\N	\N
29456	909	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20058E	\N	\N
29493	911	2020-12-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17589D	\N	\N
29500	919	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19551W	\N	\N
30131	1010	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11012A	\N	\N
30190	919	2021-02-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20172F	\N	\N
30298	1011	2021-03-25 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20066E	\N	\N
30299	1011	2021-03-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	16685X	\N	\N
30300	1011	2021-03-25 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14059S	\N	\N
30301	1011	2021-03-25 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20054A	\N	\N
30302	1011	2021-03-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19713W	\N	\N
30303	1011	2021-03-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11041F	\N	\N
30338	597	2021-06-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19798U	\N	\N
30368	1012	2021-06-24 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20110Q	\N	\N
30386	530	2021-09-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19369B	\N	\N
30484	603	2021-12-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	16685X	\N	\N
30517	590	2022-02-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19479G	\N	\N
30548	948	2022-03-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
30573	1013	2022-04-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14147R	\N	\N
30575	530	2022-04-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
30577	530	2022-03-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19749K	\N	\N
30578	1013	2022-04-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	99004R	\N	\N
30605	623	2022-04-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19585H	\N	\N
30618	530	2022-04-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14213J	\N	\N
30626	623	2022-05-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20248J	\N	\N
30703	598	2022-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20094J	\N	\N
30721	CHRETORIENT	2023-01-10 00:00:00	2023-01-10 00:00:00	ANCIEN	\N	\N	\N	19707Y	\N	\N
30722	579	2023-01-10 00:00:00	2023-01-10 00:00:00	ANCIEN	\N	\N	\N	19707Y	\N	\N
30723	634	2023-01-10 00:00:00	2023-01-10 00:00:00	ANCIEN	\N	\N	\N	19707Y	\N	\N
30724	609	2023-01-10 00:00:00	2023-01-10 00:00:00	ANCIEN	\N	\N	\N	19707Y	\N	\N
30725	581	2023-01-10 00:00:00	2023-01-10 00:00:00	ANCIEN	\N	\N	\N	19707Y	\N	\N
30738	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	20090E	\N	\N
30761	1014	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14193X	\N	\N
30762	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	05008E	\N	\N
30767	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	19657G	\N	\N
30784	1014	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20130U	\N	\N
33928	1005	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14026U	\N	\N
33929	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14331P	\N	\N
33931	1005	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19551W	\N	\N
33932	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21056G	\N	\N
33934	1005	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14097Y	\N	\N
33936	1005	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	08015R	\N	\N
33939	1005	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21054E	\N	\N
33940	1005	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20028X	\N	\N
33941	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20062A	\N	\N
33942	1005	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14223L	\N	\N
33945	1005	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14257W	\N	\N
33946	1005	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20082E	\N	\N
33947	1005	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19421M	\N	\N
33949	918	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19629C	\N	\N
33960	918	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14237S	\N	\N
33968	1012	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20088L	\N	\N
33971	1012	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19621T	\N	\N
33974	908	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	05008E	\N	\N
33975	1012	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14053L	\N	\N
33976	1012	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14083S	\N	\N
33977	908	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14030Q	\N	\N
33978	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20090E	\N	\N
33979	1012	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21062E	\N	\N
33980	1012	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20172F	\N	\N
33986	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	11056N	\N	\N
33987	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14357A	\N	\N
33988	908	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19621T	\N	\N
33989	1012	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14213J	\N	\N
33991	1012	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	08015R	\N	\N
34005	912	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14133K	\N	\N
34008	912	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19667J	\N	\N
34033	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14026U	\N	\N
34068	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20118Y	\N	\N
34085	922	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19701S	\N	\N
34106	998	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21092L	\N	\N
34120	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20022R	\N	\N
34121	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20110Q	\N	\N
34122	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19575F	\N	\N
34126	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20114U	\N	\N
34127	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21052C	\N	\N
34128	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21063F	\N	\N
34129	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19782L	\N	\N
34166	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14223L	\N	\N
34183	928	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	19367Y	\N	\N
34188	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	21046E	\N	\N
34191	1004	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	20122U	\N	\N
34196	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21067K	\N	\N
34202	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14059S	\N	\N
34203	647	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21045D	\N	\N
34210	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20032T	\N	\N
34211	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20032T	\N	\N
34218	1005	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20084G	\N	\N
34219	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20084G	\N	\N
34222	928	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	17023S	\N	\N
34236	908	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	11065P	\N	\N
34241	611	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14249W	\N	\N
34243	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14231L	\N	\N
34245	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	08034U	\N	\N
34248	928	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	20056C	\N	\N
34253	928	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	19745F	\N	\N
34254	963	2024-01-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20088L	\N	\N
34260	852	2024-01-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20100N	\N	\N
34264	934	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	19301E	\N	\N
34265	1007	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	19111A	\N	\N
34266	611	2024-01-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14225N	\N	\N
34270	622	2024-01-30 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19657G	\N	\N
34282	957	2023-12-14 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	21047F	\N	\N
34284	912	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	21047F	\N	\N
34286	907	2023-12-14 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	21047F	\N	\N
34290	611	2024-02-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19713W	\N	\N
34291	934	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	19631V	\N	\N
34310	603	2024-02-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14055N	\N	\N
34300	934	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	19111A	\N	\N
34303	1011	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	20054A	\N	\N
34315	909	2023-12-14 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	04092N	\N	\N
34316	998	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	08045X	\N	\N
34317	906	2023-12-14 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	08045X	\N	\N
34322	659	2024-02-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14219Q	\N	\N
34330	912	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	19719D	\N	\N
34342	611	2024-02-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19697Q	\N	\N
34347	603	2024-02-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20248J	\N	\N
34349	922	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	21042A	\N	\N
34350	919	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	17229F	\N	\N
34352	906	2023-12-14 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	14053L	\N	\N
34354	909	2023-12-14 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	14187A	\N	\N
34361	909	2023-12-14 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	14205J	\N	\N
34372	933	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	17229F	\N	\N
34385	933	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	14211G	\N	\N
34386	933	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	20056C	\N	\N
34399	922	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	14083S	\N	\N
34401	603	2024-03-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20048C	\N	\N
34402	998	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	20094J	\N	\N
34404	922	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	19347U	\N	\N
34405	918	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	19347U	\N	\N
34411	938	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	14147R	\N	\N
34412	938	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	14169X	\N	\N
34415	938	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	20044X	\N	\N
34419	938	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	14059S	\N	\N
34424	938	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	14111D	\N	\N
34425	938	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	21082J	\N	\N
34442	1010	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	01058X	\N	\N
34445	1010	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	14255U	\N	\N
34446	1010	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	19647E	\N	\N
34464	1010	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	20264J	\N	\N
34467	585	2024-03-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20094J	\N	\N
34475	1010	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	08034U	\N	\N
34477	1010	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	04033B	\N	\N
34478	1010	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	08047A	\N	\N
34491	1010	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	14231L	\N	\N
34496	618	2024-04-03 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14241N	\N	\N
25255	627	2017-11-14 00:00:00	2020-08-02 00:00:00	ANCIEN	\N	\N	\N	14239U	2017-11-15 09:29:38	\N
25256	661	2017-11-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19591F	2017-11-15 09:31:38	\N
25257	621	2017-11-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04034C	2017-11-15 09:31:53	\N
25258	609	2017-11-13 00:00:00	2018-12-30 00:00:00	ANCIEN	\N	\N	\N	98023Q	2017-11-15 09:32:13	\N
25259	641	2017-11-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2017-11-15 09:32:34	\N
25985	578	2018-01-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14107H	2018-01-23 14:57:42	\N
26264	919	2018-01-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14105F	\N	\N
26483	957	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04097T	\N	\N
26484	957	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
26485	957	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
26487	957	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08062Y	\N	\N
26543	647	2018-02-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19333N	2018-02-15 16:34:02	\N
26561	933	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14221J	\N	\N
26915	963	2018-11-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14225N	\N	\N
26916	624	2018-11-19 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	\N
27007	909	2019-04-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19798U	\N	\N
28563	629	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19333N	\N	\N
28841	600	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19643A	\N	\N
28842	581	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19643A	\N	\N
28843	590	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19643A	\N	\N
28844	595	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19643A	\N	\N
28845	674	2020-11-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19643A	\N	\N
28846	852	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14026U	\N	\N
28847	612	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
28848	591	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
28849	618	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
28850	626	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
28851	621	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
28852	576	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
28853	581	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
28854	597	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
28855	617	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
28856	583	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
28857	590	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
28858	604	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
28859	643	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
28860	596	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
34463	1010	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	19057M	\N	\N
28861	659	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
28862	598	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
28863	600	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
29123	613	2020-11-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19413M	\N	\N
29299	907	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20090E	\N	\N
29383	911	2020-12-15 00:00:00	2023-03-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	\N	\N
29387	911	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14205J	\N	\N
29388	911	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19745F	\N	\N
29389	911	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20054A	\N	\N
29391	912	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	08034U	\N	\N
29392	912	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19719D	\N	\N
29406	906	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20126Y	\N	\N
29408	906	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19503N	\N	\N
29409	906	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19619A	\N	\N
29435	909	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20074E	\N	\N
29437	909	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01025N	\N	\N
29499	909	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19741B	\N	\N
29592	909	2021-01-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19611R	\N	\N
29600	1005	2021-01-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11101A	\N	\N
29650	1005	2021-01-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11012A	\N	\N
29747	919	2021-01-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	\N	\N
30237	998	2021-03-11 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20110Q	\N	\N
30446	1010	2021-10-26 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20120S	\N	\N
30759	590	2023-01-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20138D	\N	\N
30771	1014	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
31220	579	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31221	596	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31222	592	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31223	595	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31224	653	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31225	661	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31226	597	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31227	599	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31228	576	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31229	589	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31230	633	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31231	624	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31232	575	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31233	617	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31234	640	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31235	600	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31236	674	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31237	588	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31238	590	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31239	623	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31240	610	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31241	647	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
31242	604	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14255U	\N	\N
32182	595	2023-10-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14221J	\N	\N
32199	641	2023-10-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21070E	\N	\N
32221	619	2023-10-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14217N	\N	\N
32222	626	2023-10-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14217N	\N	\N
32227	615	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21043B	\N	\N
32228	590	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21043B	\N	\N
32250	596	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19553Y	\N	\N
32251	851	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19387D	\N	\N
32349	572	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20038A	\N	\N
32433	625	2023-10-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14030Q	\N	\N
32434	595	2023-10-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14030Q	\N	\N
32435	632	2023-10-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14030Q	\N	\N
32436	608	2023-10-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21095P	\N	\N
32437	588	2023-10-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21095P	\N	\N
32438	572	2023-10-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21095P	\N	\N
32439	573	2023-10-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21095P	\N	\N
32440	595	2023-10-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21095P	\N	\N
32441	598	2023-10-27 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21095P	\N	\N
32449	625	2023-10-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21031W	\N	\N
32450	978	2023-10-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21031W	\N	\N
33187	588	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19611R	\N	\N
33188	556	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19611R	\N	\N
33189	673	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14187A	\N	\N
33190	583	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14187A	\N	\N
33191	621	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14187A	\N	\N
33192	597	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14187A	\N	\N
33193	642	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14187A	\N	\N
33194	596	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14187A	\N	\N
33195	598	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14187A	\N	\N
33208	642	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21038E	\N	\N
33210	609	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08012N	\N	\N
33211	575	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20062A	\N	\N
33218	600	2023-11-30 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14249W	\N	\N
33219	674	2023-11-30 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14249W	\N	\N
33222	613	2023-12-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14225N	\N	\N
33223	618	2023-12-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14225N	\N	\N
33246	604	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14121F	\N	\N
33252	599	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14109K	\N	\N
33260	633	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14038Y	\N	\N
33272	589	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20052X	\N	\N
33275	599	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19531S	\N	\N
33276	978	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19531S	\N	\N
33277	582	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19531S	\N	\N
33278	575	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19701S	\N	\N
33279	619	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19531S	\N	\N
33280	534	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19531S	\N	\N
33281	640	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19531S	\N	\N
33282	626	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19531S	\N	\N
33283	651	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19531S	\N	\N
33284	643	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19531S	\N	\N
33285	851	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19531S	\N	\N
33286	633	2023-12-05 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19531S	\N	\N
33290	595	2023-12-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20090E	\N	\N
33297	642	2023-12-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14001X	\N	\N
33302	642	2023-12-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19866P	\N	\N
33303	530	2023-12-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19545Y	\N	\N
33304	613	2023-12-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19421M	\N	\N
33305	633	2023-12-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21092L	\N	\N
33306	602	2023-12-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19826F	\N	\N
33307	582	2023-12-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20042V	\N	\N
33319	572	2023-12-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14071N	\N	\N
33323	613	2023-12-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19111A	\N	\N
33324	663	2023-12-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14225N	\N	\N
33332	613	2023-12-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21090J	\N	\N
33333	646	2023-12-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11090Q	\N	\N
33334	572	2023-12-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11090Q	\N	\N
33338	602	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14069U	\N	\N
33339	602	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21051B	\N	\N
33340	590	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21051B	\N	\N
33341	530	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21051B	\N	\N
33342	595	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14073Q	\N	\N
33343	615	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14073Q	\N	\N
33344	601	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14001X	\N	\N
33345	647	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14001X	\N	\N
33346	653	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14001X	\N	\N
33347	609	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14001X	\N	\N
33348	613	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21038E	\N	\N
33349	632	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20122U	\N	\N
33350	634	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21054E	\N	\N
33351	618	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21054E	\N	\N
33352	648	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19563B	\N	\N
33354	625	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20066E	\N	\N
33355	623	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20066E	\N	\N
33356	599	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20066E	\N	\N
33357	602	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20066E	\N	\N
33358	633	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20066E	\N	\N
33359	624	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20066E	\N	\N
33360	574	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20066E	\N	\N
33361	601	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20066E	\N	\N
33362	651	2023-12-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20066E	\N	\N
33372	595	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14259Y	\N	\N
33373	632	2023-12-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14259Y	\N	\N
33377	617	2023-12-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14069U	\N	\N
33378	622	2023-12-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14069U	\N	\N
33379	556	2023-12-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14069U	\N	\N
33380	609	2023-12-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14069U	\N	\N
33382	632	2023-12-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11040E	\N	\N
33387	674	2023-12-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14031R	\N	\N
33400	530	2023-12-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19647E	\N	\N
33401	550	2023-12-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20050V	\N	\N
33404	1008	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21062E	\N	\N
33405	1008	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21080G	\N	\N
33407	1008	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21038E	\N	\N
33408	1008	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19749K	\N	\N
33416	966	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19611R	\N	\N
33434	1006	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21036C	\N	\N
33435	1006	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19421M	\N	\N
33444	966	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20096L	\N	\N
33446	1007	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20096L	\N	\N
33447	1007	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20026V	\N	\N
33455	934	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20058E	\N	\N
33457	934	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20096L	\N	\N
33461	663	2024-01-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20030R	\N	\N
33468	963	2024-01-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17965H	\N	\N
33471	529	2024-01-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21070E	\N	\N
33475	963	2024-01-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08028W	\N	\N
33477	612	2024-01-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20126Y	\N	\N
33478	529	2024-01-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20122U	\N	\N
33485	1008	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	18207D	\N	\N
33486	1008	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19687N	\N	\N
33489	619	2024-01-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20062A	\N	\N
33504	619	2024-01-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11115U	\N	\N
33507	619	2024-01-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04092N	\N	\N
33511	619	2024-01-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	07033P	\N	\N
33516	634	2024-01-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19551W	\N	\N
33518	619	2024-01-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17737W	\N	\N
33536	948	2023-09-30 00:00:00	2023-10-30 00:00:00	ANCIEN	\N	\N	\N	19725B	\N	\N
33541	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19563B	\N	\N
33542	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19713W	\N	\N
25156	612	2017-11-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	2017-11-08 17:10:53	\N
25157	608	2017-11-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14133K	2017-11-08 17:11:21	\N
25158	584	2017-11-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14133K	2017-11-08 17:11:21	\N
25159	619	2017-11-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14133K	2017-11-08 17:11:21	\N
25160	624	2017-11-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14133K	2017-11-08 17:11:21	\N
25161	608	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19521Q	2017-11-08 17:11:42	\N
25162	621	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19521Q	2017-11-08 17:11:42	\N
25163	583	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19521Q	2017-11-08 17:11:42	\N
25164	610	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19467C	2017-11-08 17:11:57	\N
25165	590	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19467C	2017-11-08 17:11:57	\N
25619	572	2017-12-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	2017-12-13 10:36:12	\N
25630	609	2017-12-13 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	2017-12-14 17:09:15	\N
25631	534	2017-12-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19573D	2017-12-14 17:09:31	\N
25803	934	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11048N	\N	\N
26030	966	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19749K	\N	\N
27036	998	2019-09-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	19812Y	\N	\N
26242	906	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
26243	948	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
26244	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14133K	\N	\N
26693	1007	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14213J	\N	\N
26705	642	2018-03-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14227Q	2018-03-16 09:28:10	\N
26809	1004	2018-09-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19693L	\N	\N
27035	909	2019-09-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	19812Y	\N	\N
27041	575	2019-10-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	18083K	\N	\N
27051	661	2019-11-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19826F	\N	\N
27052	622	2019-11-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19826F	\N	\N
29018	673	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11012A	\N	\N
29019	595	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11012A	\N	\N
29020	605	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11012A	\N	\N
29021	591	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11012A	\N	\N
29152	618	2020-12-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19553Y	\N	\N
29153	579	2020-11-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
29154	573	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14219Q	\N	\N
29155	612	2020-12-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14151M	\N	\N
29157	963	2020-12-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19782L	\N	\N
29164	633	2020-12-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14205J	\N	\N
29173	646	2020-12-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14169X	\N	\N
29313	907	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11090Q	\N	\N
29314	907	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14331P	\N	\N
29315	907	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19619A	\N	\N
29316	907	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20044X	\N	\N
29357	1005	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14187A	\N	\N
29358	1005	2020-12-17 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
29359	1005	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14213J	\N	\N
29360	1005	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14097Y	\N	\N
29361	1005	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	08015R	\N	\N
29362	1005	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20028X	\N	\N
29363	1005	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19745F	\N	\N
29364	1005	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19503N	\N	\N
29394	912	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14097Y	\N	\N
29420	948	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20028X	\N	\N
29423	948	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
29565	948	2020-12-23 00:00:00	2020-12-23 00:00:00	ANCIEN	\N	\N	\N	20112S	\N	\N
29591	919	2021-01-05 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19798U	\N	\N
29596	1005	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11097X	\N	\N
29616	918	2021-01-07 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19768N	\N	\N
29617	918	2021-01-07 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14221J	\N	\N
29619	918	2021-01-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19349W	\N	\N
29710	911	2021-01-13 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
29711	912	2021-01-13 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
29838	1004	2020-10-01 00:00:00	2023-12-31 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
29956	673	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19383Y	\N	\N
29981	906	2021-01-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19413M	\N	\N
29987	911	2021-01-20 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20032T	\N	\N
30145	919	2021-02-04 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20096L	\N	\N
30150	934	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20134Y	\N	\N
30232	911	2021-03-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19643A	\N	\N
30330	532	2021-05-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20036X	\N	\N
30331	603	2021-05-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20110Q	\N	\N
30335	641	2021-04-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17367Q	\N	\N
30350	1012	2021-06-10 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14133K	\N	\N
30411	578	2021-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20264J	\N	\N
30412	602	2021-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20264J	\N	\N
30413	598	2021-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20264J	\N	\N
30414	576	2021-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20264J	\N	\N
30415	604	2021-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20264J	\N	\N
30416	978	2021-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20264J	\N	\N
30417	573	2021-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20264J	\N	\N
30418	583	2021-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20264J	\N	\N
30419	577	2021-10-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20264J	\N	\N
30453	595	2021-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19707Y	\N	\N
30454	576	2021-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19707Y	\N	\N
30455	590	2021-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19707Y	\N	\N
30456	617	2021-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19705W	\N	\N
30481	624	2021-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19629C	\N	\N
30529	633	2022-02-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20110Q	\N	\N
30530	594	2022-03-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19826F	\N	\N
30642	659	2022-06-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	\N	\N
30643	629	2022-06-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	\N	\N
30657	575	2022-08-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20084G	\N	\N
30658	661	2022-08-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20084G	\N	\N
30775	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	19447X	\N	\N
30779	1014	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	10006L	\N	\N
30807	653	2023-02-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19766L	\N	\N
30808	653	2023-03-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19954N	\N	\N
30809	600	2023-03-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20122U	\N	\N
30854	610	2023-07-31 00:00:00	2023-08-02 00:00:00	ANCIEN	\N	\N	\N	20096L	\N	\N
30855	550	2023-07-31 00:00:00	2023-08-02 00:00:00	ANCIEN	\N	\N	\N	20096L	\N	\N
30856	579	2023-07-31 00:00:00	2023-08-02 00:00:00	ANCIEN	\N	\N	\N	20096L	\N	\N
30857	621	2023-07-31 00:00:00	2023-08-02 00:00:00	ANCIEN	\N	\N	\N	20096L	\N	\N
30858	589	2023-07-31 00:00:00	2023-08-02 00:00:00	ANCIEN	\N	\N	\N	20096L	\N	\N
30924	632	2023-10-08 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21066J	\N	\N
31400	598	2023-10-10 00:00:00	2023-11-13 00:00:00	ANCIEN	\N	\N	\N	20046A	\N	\N
34499	583	2024-04-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19111A	\N	\N
25980	534	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14038Y	2018-01-22 16:47:22	\N
25981	585	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04059M	2018-01-22 16:49:04	\N
26232	998	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04038G	\N	\N
26416	911	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14173T	\N	\N
26717	1007	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14147R	\N	\N
26839	674	2018-10-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14029X	\N	\N
26923	575	2018-11-27 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	\N
26924	626	2018-11-27 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	\N
26925	608	2018-11-27 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	\N
26926	617	2018-11-27 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	\N
26927	621	2018-11-27 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	08051V	\N	\N
26965	911	2019-02-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11041F	\N	\N
27057	624	2019-11-29 00:00:00	2020-03-03 00:00:00	ANCIEN	\N	\N	\N	11081P	\N	\N
27247	978	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19619A	\N	\N
27248	625	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19619A	\N	\N
27249	598	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	99004R	\N	\N
27250	595	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	99004R	\N	\N
27251	600	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19679N	\N	\N
27252	641	2020-10-07 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	04086Q	\N	\N
27253	601	2020-10-07 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	04086Q	\N	\N
27254	604	2020-10-07 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	04086Q	\N	\N
27255	581	2020-10-07 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	04086Q	\N	\N
27256	602	2020-10-07 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	04086Q	\N	\N
27257	595	2020-10-07 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	04086Q	\N	\N
27258	663	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19369B	\N	\N
27259	583	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19369B	\N	\N
28558	632	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20130U	\N	\N
28934	623	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20066E	\N	\N
28935	626	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20066E	\N	\N
28936	550	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20066E	\N	\N
28937	589	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20066E	\N	\N
28938	621	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20066E	\N	\N
28939	646	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20066E	\N	\N
28940	634	2020-10-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20066E	\N	\N
29043	851	2020-11-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14195A	\N	\N
29158	586	2020-12-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20106U	\N	\N
29159	611	2020-12-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20106U	\N	\N
29532	919	2020-12-22 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19782L	\N	\N
29533	1005	2020-12-22 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19782L	\N	\N
29628	907	2021-01-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14357A	\N	\N
29631	906	2021-01-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14357A	\N	\N
29776	1008	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19717B	\N	\N
29871	1007	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14213J	\N	\N
29976	911	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11090Q	\N	\N
29977	909	2021-01-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19533U	\N	\N
29978	909	2021-01-21 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14211G	\N	\N
30107	1010	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	10006L	\N	\N
30352	919	2021-06-14 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14030Q	\N	\N
30353	1012	2021-06-14 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14030Q	\N	\N
30374	934	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14193X	\N	\N
30469	624	2021-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20132W	\N	\N
30493	615	2021-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19503N	\N	\N
30494	603	2021-12-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14225N	\N	\N
30495	615	2021-12-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14225N	\N	\N
30692	1005	2021-03-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	16685X	\N	\N
30749	1014	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
30750	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	14189C	\N	\N
30842	600	2023-06-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14001X	\N	\N
31286	597	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14355X	\N	\N
31287	598	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14355X	\N	\N
31288	641	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14355X	\N	\N
31289	629	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14355X	\N	\N
31338	626	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14042U	\N	\N
31339	579	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14042U	\N	\N
31340	625	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14042U	\N	\N
31351	612	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14053L	\N	\N
31352	623	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14053L	\N	\N
31353	573	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14053L	\N	\N
31370	674	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19667J	\N	\N
31371	622	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19667J	\N	\N
31372	602	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19667J	\N	\N
31848	648	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14249W	\N	\N
31849	579	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14249W	\N	\N
31850	621	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14249W	\N	\N
31851	624	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14249W	\N	\N
31852	598	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14249W	\N	\N
31853	615	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14249W	\N	\N
31854	592	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14249W	\N	\N
31855	659	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14249W	\N	\N
31856	529	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14249W	\N	\N
32288	613	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14147R	\N	\N
32351	643	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14225N	\N	\N
32352	609	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14225N	\N	\N
32353	578	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14225N	\N	\N
32354	584	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14225N	\N	\N
32355	595	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14225N	\N	\N
32356	978	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14225N	\N	\N
32357	979	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14225N	\N	\N
32451	604	2023-10-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21031W	\N	\N
32452	661	2023-10-28 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21031W	\N	\N
32524	612	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20098N	\N	\N
32567	573	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21092L	\N	\N
32580	604	2023-10-31 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14033T	\N	\N
32606	604	2023-11-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20094J	\N	\N
32742	589	2023-11-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19479G	\N	\N
32757	613	2023-11-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08047A	\N	\N
32760	979	2023-11-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21050A	\N	\N
32782	595	2023-11-07 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14249W	\N	\N
32896	574	2023-11-14 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20134Y	\N	\N
32907	589	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21077M	\N	\N
32908	575	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21077M	\N	\N
33100	622	2023-11-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21045D	\N	\N
33101	611	2023-11-21 00:00:00	2023-12-18 00:00:00	ANCIEN	\N	\N	\N	21045D	\N	\N
33104	617	2023-11-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19421M	\N	\N
33178	661	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19611R	\N	\N
33179	616	2023-11-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19611R	\N	\N
32828	591	2023-11-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19681G	\N	\N
32832	573	2023-11-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19697Q	\N	\N
32833	628	2023-11-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19697Q	\N	\N
32834	623	2023-11-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19697Q	\N	\N
32853	608	2023-11-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20054A	\N	\N
33543	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14097Y	\N	\N
33545	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20028X	\N	\N
33546	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	04045F	\N	\N
33549	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20092G	\N	\N
33561	1004	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	19735D	\N	\N
33562	1004	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	20096L	\N	\N
33563	1004	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	21037D	\N	\N
33564	1004	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	14331P	\N	\N
33565	1004	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	19713W	\N	\N
33566	1004	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	21094N	\N	\N
33568	1004	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	20090E	\N	\N
33574	647	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11065P	\N	\N
33576	1013	2024-01-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14021P	\N	\N
33578	1004	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	14213J	\N	\N
33579	1004	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	19703U	\N	\N
33580	1004	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	19749K	\N	\N
33628	928	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	19563B	\N	\N
33583	934	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21078N	\N	\N
33584	934	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14123H	\N	\N
33599	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	21094N	\N	\N
33604	1004	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	20150Y	\N	\N
33629	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21084L	\N	\N
33630	928	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	14223L	\N	\N
33631	928	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	14071N	\N	\N
33639	928	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	20150Y	\N	\N
33656	948	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20106U	\N	\N
33679	1007	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20142Y	\N	\N
33683	1006	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20096L	\N	\N
33688	1006	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19719D	\N	\N
33689	1006	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20120S	\N	\N
33693	1006	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	11045K	\N	\N
33703	928	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	14211G	\N	\N
33705	550	2024-01-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19585H	\N	\N
33713	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20076G	\N	\N
33724	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20138D	\N	\N
33726	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14105F	\N	\N
33760	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20172F	\N	\N
33761	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19695N	\N	\N
33776	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19447X	\N	\N
33794	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14257W	\N	\N
33800	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19745F	\N	\N
33801	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19533U	\N	\N
33803	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20118Y	\N	\N
33804	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	05012A	\N	\N
33805	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	11090Q	\N	\N
33806	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19679N	\N	\N
33807	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20082E	\N	\N
33809	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21068L	\N	\N
33811	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20150Y	\N	\N
33812	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20020P	\N	\N
33814	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14107H	\N	\N
33815	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20092G	\N	\N
33816	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19421M	\N	\N
33819	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20098N	\N	\N
33822	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19713W	\N	\N
33823	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20062A	\N	\N
33825	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19413M	\N	\N
33827	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20026V	\N	\N
33829	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14173T	\N	\N
33837	619	2024-01-22 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19703U	\N	\N
33841	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	21087P	\N	\N
33846	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19760E	\N	\N
33847	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20076G	\N	\N
33865	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21062E	\N	\N
33866	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21086N	\N	\N
33876	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14033T	\N	\N
33895	922	2023-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20018V	\N	\N
33896	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14221J	\N	\N
33897	906	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20252E	\N	\N
33901	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20018V	\N	\N
33910	1005	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20090E	\N	\N
33912	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14169X	\N	\N
33924	1005	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20124W	\N	\N
33933	1005	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20056C	\N	\N
33935	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19619A	\N	\N
33937	1005	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19729F	\N	\N
33938	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20092G	\N	\N
33943	1005	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14109K	\N	\N
33944	918	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19621T	\N	\N
33948	1005	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	04045F	\N	\N
33954	918	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14179A	\N	\N
33955	918	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21044C	\N	\N
33958	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21052C	\N	\N
33959	918	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14109K	\N	\N
33964	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19681G	\N	\N
33965	1012	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14133K	\N	\N
33966	1012	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	05008E	\N	\N
33969	1012	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20114U	\N	\N
33970	908	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21084L	\N	\N
33984	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	18083K	\N	\N
33990	908	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20090E	\N	\N
33994	1012	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14221J	\N	\N
34007	908	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20180F	\N	\N
34009	912	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19575F	\N	\N
34010	908	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20106U	\N	\N
34011	912	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20090E	\N	\N
34014	912	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14026U	\N	\N
34015	908	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21044C	\N	\N
34017	908	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	08015R	\N	\N
34018	912	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14205J	\N	\N
34019	912	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14223L	\N	\N
34020	908	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14059S	\N	\N
34022	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20038A	\N	\N
34023	908	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14031R	\N	\N
34024	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	08056B	\N	\N
34025	908	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19826F	\N	\N
34026	912	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	05012A	\N	\N
34027	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14211G	\N	\N
34028	912	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20062A	\N	\N
34030	912	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14173T	\N	\N
25535	620	2017-12-04 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04034C	2017-12-05 09:35:04	\N
25926	909	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
25927	909	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11048N	\N	\N
25929	909	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14061L	\N	\N
25931	909	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
25932	909	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08010L	\N	\N
25982	586	2018-01-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19719D	2018-01-22 18:46:30	2018-01-23 17:48:32
25990	588	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14259Y	2018-01-24 11:44:04	\N
25991	572	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14259Y	2018-01-24 11:44:04	2018-01-25 09:44:18
25992	583	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	2018-01-24 11:46:37	\N
25998	573	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	2018-01-24 12:06:58	\N
25999	573	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	2018-01-24 12:09:31	\N
26000	573	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19725B	2018-01-24 12:10:50	\N
26001	573	2018-01-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08049C	2018-01-24 12:12:05	\N
26007	642	2018-01-24 00:00:00	2019-06-24 00:00:00	ANCIEN	\N	\N	\N	04061F	2018-01-24 12:13:47	\N
26130	616	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19611R	2018-01-26 14:49:03	\N
26163	909	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	80013X	\N	\N
26167	909	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19745F	\N	\N
26266	919	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08024S	\N	\N
26339	998	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11109J	\N	\N
26360	1005	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	16685X	\N	\N
26362	1005	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19657G	\N	\N
26376	623	2018-02-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	2018-02-09 09:45:51	\N
26377	612	2018-02-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	2018-02-09 09:45:51	\N
26478	957	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19681G	\N	\N
26692	918	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
26726	1007	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14219Q	\N	\N
26772	571	2018-05-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19593H	2018-06-05 10:15:17	\N
26966	907	2019-02-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14249W	\N	\N
26997	582	2019-03-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19543W	\N	\N
27026	597	2019-06-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14355X	\N	\N
27161	597	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14215L	\N	\N
27162	609	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14215L	\N	\N
27163	604	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14215L	\N	\N
27164	629	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14215L	\N	\N
27165	585	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14215L	\N	\N
27373	595	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20052X	\N	\N
27374	603	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20052X	\N	\N
27375	643	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20052X	\N	\N
27376	581	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14147R	\N	\N
27377	673	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14147R	\N	\N
27378	629	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14147R	\N	\N
29061	604	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19954N	\N	\N
29062	615	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19782L	\N	\N
29063	851	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19681G	\N	\N
29064	612	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19719D	\N	\N
29065	573	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19719D	\N	\N
29066	661	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19719D	\N	\N
29067	617	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17023S	\N	\N
29068	574	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17023S	\N	\N
29069	609	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17023S	\N	\N
29070	608	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17023S	\N	\N
29071	651	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17023S	\N	\N
29072	604	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17023S	\N	\N
29073	978	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17023S	\N	\N
29074	594	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17023S	\N	\N
29075	586	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17023S	\N	\N
29076	589	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17023S	\N	\N
29077	622	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17023S	\N	\N
29078	663	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17023S	\N	\N
29079	572	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17023S	\N	\N
29080	578	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17023S	\N	\N
29081	588	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14107H	\N	\N
29082	851	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14107H	\N	\N
29236	599	2020-12-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19333N	\N	\N
29407	906	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19533U	\N	\N
29518	907	2020-12-18 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
29590	909	2021-01-05 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19798U	\N	\N
29669	906	2021-01-05 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20038A	\N	\N
29684	948	2021-01-12 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20082E	\N	\N
29900	934	2020-10-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19533U	\N	\N
29901	934	2020-10-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19349W	\N	\N
29902	934	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20044X	\N	\N
29903	934	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20058E	\N	\N
30037	948	2021-01-26 00:00:00	2022-12-31 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
30040	919	2021-01-26 00:00:00	2022-12-31 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
30220	909	2021-03-03 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20042V	\N	\N
30452	1010	2021-10-27 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20264J	\N	\N
30479	624	2021-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19866P	\N	\N
30480	640	2021-11-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	18083K	\N	\N
30508	934	2022-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11048N	\N	\N
30510	615	2022-01-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19551W	\N	\N
30524	1013	2022-02-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19251M	\N	\N
30551	530	2022-03-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20024T	\N	\N
30609	530	2022-04-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
30789	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	14030Q	\N	\N
30846	1006	2023-10-01 00:00:00	2026-09-30 00:00:00	ANCIEN	\N	\N	\N	11027H	\N	\N
30847	1006	2023-06-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19593H	\N	\N
30863	641	2023-10-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17229F	\N	\N
31258	643	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08056B	\N	\N
31259	576	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08056B	\N	\N
31260	633	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08056B	\N	\N
31261	615	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08056B	\N	\N
31262	663	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08056B	\N	\N
31263	979	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08056B	\N	\N
31264	661	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08056B	\N	\N
31265	550	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08056B	\N	\N
31266	608	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08056B	\N	\N
31267	659	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08056B	\N	\N
31268	597	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08056B	\N	\N
31269	622	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08056B	\N	\N
31270	623	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08056B	\N	\N
31271	618	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08056B	\N	\N
32858	623	2023-11-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19057M	\N	\N
25774	605	2017-12-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	2017-12-27 17:06:47	\N
25775	586	2017-12-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	2017-12-27 17:06:47	\N
25776	851	2017-12-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	2017-12-27 17:06:47	\N
26181	912	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	05008E	\N	\N
26182	912	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19643A	\N	\N
26183	912	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	18083K	\N	\N
26185	912	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14249W	\N	\N
26186	912	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14281W	\N	\N
26188	912	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	\N	\N
26189	912	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
26190	912	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08034U	\N	\N
26191	912	2017-10-01 00:00:00	2018-04-13 00:00:00	ANCIEN	\N	\N	\N	19483C	\N	2018-04-13 17:54:29
26192	912	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
26193	912	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14205J	\N	\N
26194	912	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19657G	\N	\N
26195	912	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
26595	852	2018-02-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04086Q	2018-02-22 10:20:51	\N
26742	573	2018-04-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19703U	2018-04-10 09:46:11	\N
26768	627	2018-05-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08009T	2018-05-31 09:21:58	\N
26769	584	2018-05-03 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14277B	2018-05-31 09:39:47	\N
26781	629	2018-06-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19563B	2018-06-13 09:53:04	\N
26782	594	2018-05-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19717B	2018-06-13 09:53:19	\N
26805	934	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19766L	\N	\N
26882	907	2017-10-01 00:00:00	2020-06-27 00:00:00	ANCIEN	\N	\N	\N	14199E	\N	\N
26932	621	2018-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19747H	\N	\N
26933	604	2018-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19747H	\N	\N
26934	573	2018-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19747H	\N	\N
27028	966	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	02002K	\N	\N
27067	629	2020-01-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14169X	\N	\N
27379	602	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19768N	\N	\N
27380	610	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19768N	\N	\N
27381	578	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	\N	\N
27382	620	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	\N	\N
27383	673	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	\N	\N
27384	621	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	\N	\N
27385	629	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	\N	\N
27386	963	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	\N	\N
27387	591	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	\N	\N
27388	597	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	\N	\N
27389	595	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	\N	\N
27390	589	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	\N	\N
27391	572	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	\N	\N
27392	598	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	\N	\N
27393	604	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	\N	\N
27394	608	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	\N	\N
27395	575	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	\N	\N
27396	617	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	\N	\N
27397	594	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11040E	\N	\N
27398	608	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11040E	\N	\N
27399	581	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11040E	\N	\N
27400	852	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11040E	\N	\N
27401	626	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20126Y	\N	\N
27402	579	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20126Y	\N	\N
27403	604	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20126Y	\N	\N
27404	583	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20126Y	\N	\N
27405	580	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19553Y	\N	\N
27406	596	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19553Y	\N	\N
27407	613	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04043D	\N	\N
27408	578	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04043D	\N	\N
27409	653	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04043D	\N	\N
27410	663	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04043D	\N	\N
27411	577	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04043D	\N	\N
27412	590	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04043D	\N	\N
27413	651	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04043D	\N	\N
27414	618	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19421M	\N	\N
27415	622	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19421M	\N	\N
27416	628	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19421M	\N	\N
27417	572	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19421M	\N	\N
27418	573	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19421M	\N	\N
27419	617	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19421M	\N	\N
27420	588	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19421M	\N	\N
27421	963	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08028W	\N	\N
27422	529	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
27423	556	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
27424	642	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
27425	673	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
27426	609	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
27427	629	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
27428	588	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
27429	597	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
27430	595	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
27431	622	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
27432	643	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
27433	646	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
27434	653	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
27435	586	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
27436	616	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
27437	572	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
27438	573	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
27439	598	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
27440	608	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
27441	641	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
27442	651	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
27443	673	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19399H	\N	\N
27444	601	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19399H	\N	\N
28393	589	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20018V	\N	\N
28394	598	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20018V	\N	\N
28395	601	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20018V	\N	\N
28396	963	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20018V	\N	\N
28397	595	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11033F	\N	\N
28398	646	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11033F	\N	\N
28399	632	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11033F	\N	\N
28790	609	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
28791	634	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
28792	661	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
34040	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14179A	\N	\N
34041	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14213J	\N	\N
34043	1011	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20114U	\N	\N
34044	1011	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20090E	\N	\N
34046	908	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21051B	\N	\N
34047	1011	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19057M	\N	\N
34048	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14097Y	\N	\N
34049	1011	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14329V	\N	\N
34050	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20126Y	\N	\N
34051	1011	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21041Y	\N	\N
34052	1011	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20124W	\N	\N
34053	979	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20048C	\N	\N
34057	1011	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14097Y	\N	\N
34058	1011	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14059S	\N	\N
34059	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21058J	\N	\N
34061	1011	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20062A	\N	\N
34062	1011	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14173T	\N	\N
34063	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14221J	\N	\N
34065	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20018V	\N	\N
34070	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19679N	\N	\N
34071	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14331P	\N	\N
34072	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14107H	\N	\N
34073	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19619A	\N	\N
34075	584	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20048C	\N	\N
34124	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20088L	\N	\N
34130	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20090E	\N	\N
34131	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14207L	\N	\N
34132	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19629C	\N	\N
34134	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14038Y	\N	\N
34140	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14259Y	\N	\N
34137	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	11027H	\N	\N
34139	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14357A	\N	\N
34141	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19719D	\N	\N
34142	647	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21059K	\N	\N
34146	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21086N	\N	\N
34155	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14097Y	\N	\N
34156	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14073Q	\N	\N
34157	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20126Y	\N	\N
34158	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19723Y	\N	\N
34159	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	08015R	\N	\N
34161	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14037X	\N	\N
34162	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14059S	\N	\N
34164	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14147R	\N	\N
34165	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20028X	\N	\N
34167	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14109K	\N	\N
34168	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14257W	\N	\N
34169	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20096L	\N	\N
34184	928	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	21051B	\N	\N
34186	1004	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	21046E	\N	\N
34194	529	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14251Q	\N	\N
34195	550	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14251Q	\N	\N
34199	957	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21067K	\N	\N
34200	550	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21054E	\N	\N
34201	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19545Y	\N	\N
34204	912	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19545Y	\N	\N
34205	1012	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20144B	\N	\N
34206	615	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19782L	\N	\N
34207	532	2024-01-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19782L	\N	\N
34212	906	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20032T	\N	\N
34213	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20032T	\N	\N
34214	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20032T	\N	\N
34215	1005	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20032T	\N	\N
34216	1011	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20032T	\N	\N
34220	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20054A	\N	\N
34221	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20054A	\N	\N
34224	928	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	04045F	\N	\N
34227	912	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21046E	\N	\N
34228	909	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	21046E	\N	\N
34229	919	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20286Q	\N	\N
34230	1005	2023-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20286Q	\N	\N
34231	550	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14133K	\N	\N
34232	616	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14133K	\N	\N
34238	615	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19057M	\N	\N
34240	585	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14037X	\N	\N
34251	601	2024-01-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11074Q	\N	\N
34252	907	2023-12-14 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	17367Q	\N	\N
34262	957	2023-12-14 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	19533U	\N	\N
34267	673	2024-01-26 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19685L	\N	\N
34269	588	2024-01-29 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14111D	\N	\N
34276	934	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	21047F	\N	\N
34277	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	\N	\N	\N	\N	21095P	\N	\N
34278	928	2024-01-02 00:00:00	2027-03-01 00:00:00	\N	\N	\N	\N	21095P	\N	\N
34281	957	2023-12-14 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	14237S	\N	\N
34283	919	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	21047F	\N	\N
34285	909	2023-12-14 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	21047F	\N	\N
34288	919	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	11048N	\N	\N
34289	1006	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	19647E	\N	\N
34292	907	2023-12-14 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	20116W	\N	\N
34297	907	2023-12-14 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	08034U	\N	\N
34301	598	2024-02-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20116W	\N	\N
34302	978	2024-02-06 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20116W	\N	\N
34331	912	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	19447X	\N	\N
34332	912	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	08034U	\N	\N
34308	909	2023-12-14 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	20086J	\N	\N
34309	909	2023-12-14 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	08010L	\N	\N
34325	912	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	20138D	\N	\N
34333	907	2023-12-14 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	21048G	\N	\N
34337	922	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	19575F	\N	\N
34346	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	\N	\N	\N	\N	20020P	\N	\N
34353	922	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	11085T	\N	\N
34371	933	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	14225N	\N	\N
34379	933	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	20042V	\N	\N
34380	933	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	14083S	\N	\N
34381	933	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	11053K	\N	\N
34387	933	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	14179A	\N	\N
34389	933	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	19611R	\N	\N
34390	933	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	20052X	\N	\N
34391	933	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	14221J	\N	\N
34393	933	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	20096L	\N	\N
34395	933	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	21070E	\N	\N
25778	579	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	2018-01-02 17:37:45	\N
25819	646	2018-01-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19533U	2018-01-16 11:01:54	\N
26180	998	2017-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	19591F	\N	\N
26184	912	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	17589D	\N	\N
26247	909	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14211G	\N	\N
26564	933	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
26565	933	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14267Y	\N	\N
26698	1005	2018-02-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
26714	1007	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	17583W	\N	\N
26813	CHRETORIENT	2018-09-24 00:00:00	2023-10-05 00:00:00	ANCIEN	\N	\N	\N	19766L	\N	\N
26865	610	2018-10-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19533U	\N	\N
27457	647	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19667J	\N	\N
27458	674	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19667J	\N	\N
27459	646	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19667J	\N	\N
27939	621	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
27940	608	2020-10-19 00:00:00	2023-09-28 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
27941	598	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
27942	595	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
27943	591	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
27944	653	2020-10-19 00:00:00	2023-09-28 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
27945	609	2020-10-19 00:00:00	2023-09-28 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
27946	613	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
27947	584	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
28881	529	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11064N	\N	\N
28882	622	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	18193Q	\N	\N
28883	626	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	18193Q	\N	\N
28884	577	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	18193Q	\N	\N
28885	573	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	18193Q	\N	\N
28950	613	2020-11-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
28951	604	2020-11-13 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	14041T	\N	\N
28952	572	2020-11-13 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	14041T	\N	\N
28953	589	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19479G	\N	\N
28954	642	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19301E	\N	\N
28955	583	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19301E	\N	\N
28956	643	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19301E	\N	\N
28957	613	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20018V	\N	\N
29032	556	2020-11-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19713W	\N	\N
29033	573	2020-11-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20042V	\N	\N
29034	641	2020-11-18 00:00:00	2022-07-03 00:00:00	ANCIEN	\N	\N	\N	19689Q	\N	\N
29035	604	2020-11-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20086J	\N	\N
29156	633	2020-11-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19551W	\N	\N
29174	634	2020-12-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19667J	\N	\N
29188	584	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	18083K	\N	\N
29189	617	2020-12-07 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	14041T	\N	\N
29190	611	2020-11-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19697Q	\N	\N
29241	604	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20132W	\N	\N
29351	1005	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19631V	\N	\N
29654	907	2020-12-16 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	08061X	\N	\N
29731	908	2021-01-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
29965	1007	2020-10-01 00:00:00	2026-03-01 00:00:00	ACTIF	\N	\N	\N	14229S	\N	\N
29966	966	2020-10-01 00:00:00	2026-03-01 00:00:00	ACTIF	\N	\N	\N	14229S	\N	\N
29996	919	2021-01-21 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14053L	\N	\N
30065	911	2021-01-25 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14257W	\N	\N
30182	938	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	\N	\N
30184	938	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	17023S	\N	\N
30185	938	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14231L	\N	\N
30207	906	2021-02-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19820Y	\N	\N
30632	605	2022-05-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	18193Q	\N	\N
30695	906	2022-10-11 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14169X	\N	\N
31168	597	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20024T	\N	\N
31169	571	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20024T	\N	\N
31170	625	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20024T	\N	\N
31171	586	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20024T	\N	\N
31172	530	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20024T	\N	\N
31173	673	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20024T	\N	\N
31174	602	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20024T	\N	\N
31175	573	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20024T	\N	\N
31176	590	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20024T	\N	\N
31177	978	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20024T	\N	\N
31178	642	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20024T	\N	\N
31179	595	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20024T	\N	\N
31180	596	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20024T	\N	\N
31181	605	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20024T	\N	\N
31182	598	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20024T	\N	\N
31183	648	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20024T	\N	\N
31246	653	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	04008A	\N	\N
31272	624	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08056B	\N	\N
31273	598	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08056B	\N	\N
31274	602	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08056B	\N	\N
31275	610	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08056B	\N	\N
31276	605	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08056B	\N	\N
31277	534	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08056B	\N	\N
31278	583	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08056B	\N	\N
31307	573	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14267Y	\N	\N
31308	588	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14267Y	\N	\N
31309	659	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14267Y	\N	\N
31358	633	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19745F	\N	\N
31359	530	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19745F	\N	\N
31360	596	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19745F	\N	\N
31361	617	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19745F	\N	\N
31362	600	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19745F	\N	\N
31401	642	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20046A	\N	\N
32162	623	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20106U	\N	\N
32170	590	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	12016W	\N	\N
32171	642	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	12016W	\N	\N
32172	978	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	12016W	\N	\N
32173	573	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	12016W	\N	\N
32174	618	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	12016W	\N	\N
32239	573	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17023S	\N	\N
32240	530	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17023S	\N	\N
32241	574	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17023S	\N	\N
32242	617	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17023S	\N	\N
32243	622	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17023S	\N	\N
32244	598	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17023S	\N	\N
32245	663	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17023S	\N	\N
32246	609	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17023S	\N	\N
32915	530	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19553Y	\N	\N
25270	619	2017-11-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14217N	2017-11-16 10:23:14	\N
25271	627	2017-11-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	07004J	2017-11-16 10:23:57	\N
25272	619	2017-11-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	07004J	2017-11-16 10:23:57	\N
25273	648	2017-11-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	07004J	2017-11-16 10:23:57	\N
25274	573	2017-11-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	07004J	2017-11-16 10:23:57	\N
25275	663	2017-11-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19369B	2017-11-16 10:24:14	\N
25276	529	2017-11-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14195A	2017-11-16 10:24:30	\N
25277	594	2017-11-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19719D	2017-11-16 10:24:42	\N
25278	583	2017-10-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19717B	2017-11-16 10:25:00	\N
25629	550	2017-12-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	2017-12-14 15:15:05	\N
25755	640	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19575F	2017-12-22 13:49:14	\N
25903	646	2018-01-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2018-01-17 14:33:57	\N
25904	609	2018-01-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19333N	2018-01-17 14:34:15	\N
25905	582	2018-01-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19511N	2018-01-17 14:34:28	\N
25906	657	2018-01-15 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	2018-01-17 14:34:41	\N
25914	909	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14038Y	\N	\N
25916	909	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	\N	\N
25920	909	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14249W	\N	\N
25923	909	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14026U	\N	\N
25924	909	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19725B	\N	\N
26225	909	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19383Y	\N	\N
26254	919	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19515S	\N	\N
26255	919	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	05008E	\N	\N
26302	919	2018-02-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19369B	\N	\N
26303	919	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14257W	\N	\N
26305	919	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
26306	919	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19573D	\N	\N
26307	919	2018-01-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08061X	\N	\N
26310	919	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14135M	\N	\N
26664	1008	2018-03-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
26665	1008	2018-03-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	\N	\N
26666	1008	2018-03-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14026U	\N	\N
26986	911	2019-02-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	17583W	\N	\N
26987	912	2019-02-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	17583W	\N	\N
27010	673	2019-04-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
27047	922	2019-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	19820Y	\N	\N
27157	595	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	07004J	\N	\N
27158	573	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	07004J	\N	\N
27718	673	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08012N	\N	\N
27719	643	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19545Y	\N	\N
27720	550	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19545Y	\N	\N
27721	629	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19545Y	\N	\N
27722	621	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19545Y	\N	\N
27723	602	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19545Y	\N	\N
27724	597	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19545Y	\N	\N
27725	978	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14329V	\N	\N
27726	589	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14329V	\N	\N
27727	602	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14329V	\N	\N
27728	979	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14329V	\N	\N
27729	583	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20098N	\N	\N
27730	602	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20098N	\N	\N
27731	604	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20098N	\N	\N
27732	578	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17229F	\N	\N
27733	590	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17229F	\N	\N
27734	573	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17229F	\N	\N
27735	622	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17229F	\N	\N
27736	596	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17229F	\N	\N
27737	530	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17229F	\N	\N
27738	626	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17229F	\N	\N
28793	597	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
28794	673	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
28795	534	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
28796	595	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
28797	674	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20152B	\N	\N
29196	598	2020-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20086J	\N	\N
29197	644	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14133K	\N	\N
29198	640	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	\N	\N
29199	646	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	\N	\N
29200	604	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	\N	\N
29201	644	2020-12-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14030Q	\N	\N
29202	595	2020-12-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14030Q	\N	\N
29203	632	2020-12-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14030Q	\N	\N
29204	659	2020-12-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14030Q	\N	\N
29205	582	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	\N	\N
29206	529	2020-12-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
29240	599	2020-12-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19525U	\N	\N
29246	922	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19549D	\N	\N
29247	922	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20140W	\N	\N
29296	907	2020-12-18 00:00:00	2020-12-18 00:00:00	ANCIEN	\N	\N	\N	19760E	\N	\N
29297	907	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
29343	919	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20126Y	\N	\N
29344	919	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11099A	\N	\N
29345	919	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	08015R	\N	\N
29346	919	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19441R	\N	\N
29347	919	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20028X	\N	\N
29558	998	2020-12-23 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
29559	911	2020-12-23 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
29560	912	2020-12-23 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
29567	948	2020-12-23 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20076G	\N	\N
29583	998	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19637C	\N	\N
29587	919	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19637C	\N	\N
29595	912	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11097X	\N	\N
29621	918	2021-01-07 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20056C	\N	\N
29658	918	2021-01-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19679N	\N	\N
29807	1008	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14189C	\N	\N
29944	919	2021-01-20 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14237S	\N	\N
29953	624	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
29957	852	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19507S	\N	\N
29958	619	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19507S	\N	\N
29963	1008	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19735D	\N	\N
29964	1008	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14229S	\N	\N
30121	1010	2021-02-03 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	08017T	\N	\N
30019	934	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20098N	\N	\N
30122	1010	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19581D	\N	\N
30123	1010	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19657G	\N	\N
32946	673	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14071N	\N	\N
32948	673	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14031R	\N	\N
34403	1005	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	14069U	\N	\N
34409	938	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	05008E	\N	\N
34413	938	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	19575F	\N	\N
34416	938	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	08018U	\N	\N
34417	938	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	20024T	\N	\N
34418	938	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	19657G	\N	\N
34422	938	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	21092L	\N	\N
34423	938	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	19585H	\N	\N
34430	938	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	11027H	\N	\N
34431	938	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	19647E	\N	\N
34432	938	2023-10-01 00:00:00	2026-09-30 00:00:00	\N	\N	\N	\N	14229S	\N	\N
25845	1004	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11067R	\N	\N
25993	948	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08055A	\N	\N
25995	948	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08014Q	\N	\N
25996	948	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19467C	\N	\N
26023	948	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14169X	\N	\N
26025	948	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
26170	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11080N	\N	\N
26173	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
26174	907	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14119M	\N	\N
26175	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14169X	\N	\N
26512	908	2017-10-01 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
26533	938	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19671E	\N	\N
26649	1008	2018-03-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19741B	\N	\N
26651	1008	2018-03-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14093U	\N	\N
26654	1008	2018-03-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14089Y	\N	\N
26657	1008	2018-03-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19701S	\N	\N
26658	1008	2018-03-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04086Q	\N	\N
26662	1008	2018-03-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14187A	\N	\N
26761	661	2018-05-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19701S	2018-05-18 09:51:28	\N
26841	911	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19667J	\N	\N
26951	919	2019-01-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11101A	\N	\N
26988	622	2019-02-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	\N	\N
27000	CHRETORIENT	2019-03-20 00:00:00	2020-10-20 00:00:00	ANCIEN	\N	\N	\N	14229S	\N	\N
27003	617	2019-04-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19766L	\N	\N
27103	623	2020-09-03 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11041F	\N	\N
27791	575	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19631V	\N	\N
27792	583	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19631V	\N	\N
27793	963	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19631V	\N	\N
27794	578	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14107H	\N	\N
28188	597	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20088L	\N	\N
28189	620	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20088L	\N	\N
28190	589	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20088L	\N	\N
28191	575	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20088L	\N	\N
28192	591	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20088L	\N	\N
28193	598	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20088L	\N	\N
28547	596	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19649G	\N	\N
28548	576	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19649G	\N	\N
28549	583	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19649G	\N	\N
28550	618	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19649G	\N	\N
28551	602	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19649G	\N	\N
28552	625	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19649G	\N	\N
28553	590	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19649G	\N	\N
28554	597	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19649G	\N	\N
29141	605	2020-11-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20024T	\N	\N
29142	534	2020-11-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11041F	\N	\N
29143	625	2020-12-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19725B	\N	\N
29144	577	2020-12-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19725B	\N	\N
29145	588	2020-12-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19725B	\N	\N
29146	583	2020-12-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19725B	\N	\N
29215	978	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	\N	\N
29171	979	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	12028B	\N	\N
29214	582	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19543W	\N	\N
29216	978	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14021P	\N	\N
29232	646	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19599P	\N	\N
29709	907	2021-01-13 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
29760	948	2021-01-07 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20110Q	\N	\N
29834	1004	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19553Y	\N	\N
29868	1007	2020-10-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	07033P	\N	\N
29947	919	2021-01-20 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
29980	919	2021-01-20 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	14041T	\N	\N
30012	966	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19735D	\N	\N
30049	919	2021-01-25 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14217N	\N	\N
30191	1007	2020-10-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14329V	\N	\N
30192	1007	2020-10-01 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	14041T	\N	\N
30193	1007	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19671E	\N	\N
30199	919	2021-02-04 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	08034U	\N	\N
30365	1012	2021-06-21 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14221J	\N	\N
30381	908	2021-07-20 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14173T	\N	\N
30549	609	2022-03-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20052X	\N	\N
30620	911	2020-05-02 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14327T	\N	\N
30801	912	2023-02-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20138D	\N	\N
31150	661	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	18083K	\N	\N
31151	556	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	18083K	\N	\N
31152	643	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	18083K	\N	\N
31153	572	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	18083K	\N	\N
31154	576	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	18083K	\N	\N
31155	618	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	18083K	\N	\N
31156	575	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	18083K	\N	\N
31157	640	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	18083K	\N	\N
31158	646	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	18083K	\N	\N
31159	674	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	18083K	\N	\N
31160	622	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	18083K	\N	\N
31161	588	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	18083K	\N	\N
31162	573	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	18083K	\N	\N
31163	574	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	18083K	\N	\N
31164	596	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	18083K	\N	\N
31165	584	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	18083K	\N	\N
31476	590	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19693L	\N	\N
31477	674	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19693L	\N	\N
31478	621	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19693L	\N	\N
31479	598	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19693L	\N	\N
32247	578	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17023S	\N	\N
32248	623	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17023S	\N	\N
32249	596	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17023S	\N	\N
32304	602	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20022R	\N	\N
32305	583	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20022R	\N	\N
32306	640	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20022R	\N	\N
32307	600	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20022R	\N	\N
32308	596	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20022R	\N	\N
32309	661	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20022R	\N	\N
32310	604	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20022R	\N	\N
32311	625	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20022R	\N	\N
32312	610	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20022R	\N	\N
32338	591	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17737W	\N	\N
32339	585	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17737W	\N	\N
32345	589	2023-10-25 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17965H	\N	\N
32856	623	2023-11-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21096Q	\N	\N
32873	609	2023-11-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19569H	\N	\N
25166	584	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08061X	2017-11-09 14:53:20	\N
25167	598	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08061X	2017-11-09 14:53:20	\N
25168	628	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08061X	2017-11-09 14:53:20	\N
25169	595	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08061X	2017-11-09 14:53:20	\N
25170	603	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08061X	2017-11-09 14:53:20	\N
25171	641	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08061X	2017-11-09 14:53:20	\N
26003	948	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19719D	\N	\N
26004	948	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14042U	\N	\N
26067	906	2017-10-01 00:00:00	2019-06-24 00:00:00	ANCIEN	\N	\N	\N	04061F	\N	\N
26068	906	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
26069	906	2017-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	14219Q	\N	\N
26073	906	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14257W	\N	\N
26074	906	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14071N	\N	\N
26076	906	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
26078	906	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
26079	906	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	98050T	\N	\N
26080	906	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19739H	\N	\N
26081	906	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11012A	\N	\N
26258	919	2017-10-01 00:00:00	2020-03-03 00:00:00	ANCIEN	\N	\N	\N	11081P	\N	\N
26350	1005	2018-01-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11110B	\N	\N
26351	1005	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14187A	\N	\N
26359	1005	2018-02-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08015R	\N	\N
26366	1005	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14265W	\N	\N
26473	909	2017-10-01 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	07034Q	\N	\N
26611	1004	2018-02-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19701S	\N	\N
26655	1008	2018-03-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	\N	\N
26663	1008	2018-03-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19599P	\N	\N
26683	1008	2018-03-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14265W	\N	\N
26713	1007	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19349W	\N	\N
26727	918	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	\N	\N
27040	530	2019-10-02 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19525U	\N	\N
27045	909	2019-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	19713W	\N	\N
27084	922	2019-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	19713W	\N	\N
27092	644	2020-03-02 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19443T	\N	\N
27094	623	2020-04-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08052W	\N	\N
29109	604	2020-11-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20022R	\N	\N
29110	592	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01025N	\N	\N
29111	604	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14073Q	\N	\N
29521	948	2020-12-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	16685X	\N	\N
29555	919	2020-12-23 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
29557	907	2020-12-23 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
29570	907	2020-12-28 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20062A	\N	\N
29573	906	2020-12-28 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20062A	\N	\N
29574	919	2020-12-28 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20062A	\N	\N
29668	911	2021-01-05 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20038A	\N	\N
29693	907	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	05008E	\N	\N
29694	911	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	05008E	\N	\N
29716	919	2021-01-13 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20064C	\N	\N
29719	911	2021-01-13 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20064C	\N	\N
29727	908	2020-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14331P	\N	\N
29842	1004	2020-10-01 00:00:00	2023-12-31 00:00:00	ANCIEN	\N	\N	\N	14275Y	\N	\N
30047	911	2021-01-26 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20018V	\N	\N
30126	1010	2021-02-03 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14193X	\N	\N
30127	1010	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04043D	\N	\N
30128	1010	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14331P	\N	\N
30203	934	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20112S	\N	\N
30244	933	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20116W	\N	\N
30314	911	2021-03-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
30315	1011	2021-03-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
30325	602	2021-04-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14147R	\N	\N
30432	1010	2021-10-12 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14237S	\N	\N
30436	1010	2021-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20172F	\N	\N
30476	640	2021-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20120S	\N	\N
30477	640	2021-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14071N	\N	\N
30478	640	2021-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20138D	\N	\N
30483	623	2021-12-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14147R	\N	\N
30521	609	2022-02-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20026V	\N	\N
30533	611	2022-03-07 00:00:00	2023-09-28 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
30583	530	2022-03-31 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	16685X	\N	\N
30584	530	2022-04-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19798U	\N	\N
30585	1013	2022-04-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14187A	\N	\N
30587	1013	2022-04-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11033F	\N	\N
30588	1013	2022-04-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	10006L	\N	\N
30589	1013	2022-04-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19711U	\N	\N
30590	640	2022-04-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19713W	\N	\N
30615	574	2022-04-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08045X	\N	\N
30706	590	2022-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11090Q	\N	\N
30786	1014	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19383Y	\N	\N
30804	911	2023-02-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20138D	\N	\N
30821	601	2023-04-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11041F	\N	\N
30822	617	2023-04-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19745F	\N	\N
30861	621	2023-09-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14259Y	\N	\N
30838	579	2023-04-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20248J	\N	\N
30839	642	2023-04-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20248J	\N	\N
30932	602	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20124W	\N	\N
30933	598	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20124W	\N	\N
30934	634	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20124W	\N	\N
30935	610	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20124W	\N	\N
30936	612	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20124W	\N	\N
30937	979	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20124W	\N	\N
30938	615	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20124W	\N	\N
30939	673	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20124W	\N	\N
30940	625	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20124W	\N	\N
30941	595	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20124W	\N	\N
30942	978	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20124W	\N	\N
30960	622	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	07004J	\N	\N
30961	573	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	07004J	\N	\N
30962	530	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	07004J	\N	\N
30963	590	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	07004J	\N	\N
31439	589	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19820Y	\N	\N
31440	583	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19820Y	\N	\N
31577	583	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19719D	\N	\N
31578	589	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19719D	\N	\N
31579	661	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19719D	\N	\N
31580	602	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19719D	\N	\N
32923	592	2023-11-15 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14221J	\N	\N
25233	580	2017-11-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	17589D	2017-11-13 09:31:35	\N
25234	599	2017-11-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	17589D	2017-11-13 09:31:35	\N
25235	623	2017-11-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	17589D	2017-11-13 09:31:35	\N
25236	629	2017-11-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	17589D	2017-11-13 09:32:26	\N
25237	580	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04008A	2017-11-13 09:36:48	\N
25238	643	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04008A	2017-11-13 09:36:48	\N
25239	608	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04008A	2017-11-13 09:36:48	\N
25375	556	2017-11-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	2017-11-21 18:43:14	\N
25409	619	2017-11-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14147R	2017-11-23 14:27:38	\N
25410	653	2017-11-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14147R	2017-11-23 14:27:38	\N
25411	629	2017-11-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14147R	2017-11-23 14:27:38	\N
25412	613	2017-11-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	97011G	2017-11-23 15:05:03	\N
25413	592	2017-11-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11043H	2017-11-23 15:05:18	\N
25414	619	2017-11-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	98022P	2017-11-23 15:05:38	\N
25415	661	2017-11-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14133K	2017-11-23 15:05:55	\N
25416	619	2017-11-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11090Q	2017-11-23 15:06:11	\N
25417	619	2017-11-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	2017-11-23 15:06:29	\N
25418	613	2017-11-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04086Q	2017-11-23 15:06:45	\N
25419	619	2017-11-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14135M	2017-11-23 15:07:02	\N
25420	592	2017-11-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	2017-11-23 15:07:18	\N
25421	661	2017-11-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	2017-11-23 15:07:18	\N
25422	550	2017-11-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	2017-11-23 15:07:18	\N
25946	584	2017-11-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14053L	2018-01-17 17:15:39	\N
25947	556	2017-11-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14053L	2018-01-17 17:15:39	\N
25948	573	2017-11-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14053L	2018-01-17 17:15:39	\N
25949	598	2017-11-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14053L	2018-01-17 17:15:39	\N
25950	573	2018-01-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19549D	2018-01-17 17:27:02	\N
25989	573	2017-10-25 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14065Q	2018-01-24 11:40:14	\N
26028	1007	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19749K	\N	\N
26048	906	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	\N	\N
26049	906	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14038Y	\N	\N
26051	906	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	80013X	\N	\N
26105	928	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14031R	\N	\N
26106	928	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08053X	\N	\N
26107	928	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	19563B	\N	\N
26108	928	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14223L	\N	\N
26110	928	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14119M	\N	\N
26111	928	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	19679N	\N	\N
26114	928	2017-10-01 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
26115	928	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
26116	928	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	19669L	\N	\N
26117	928	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	19413M	\N	\N
26118	928	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	95067Q	\N	\N
26265	919	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19383Y	\N	\N
26287	919	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04097T	\N	\N
26288	919	2018-01-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11048N	\N	\N
26293	919	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11099A	\N	\N
26314	919	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14107H	\N	\N
26317	919	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	98035U	\N	\N
26320	919	2018-01-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	18083K	\N	\N
26474	957	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14133K	\N	\N
26477	957	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14195A	\N	\N
26554	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	07004J	\N	\N
26622	933	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14081Q	\N	\N
26992	998	2017-12-11 00:00:00	2019-03-01 00:00:00	ANCIEN	\N	\N	\N	19581D	\N	\N
26998	602	2018-12-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19768N	\N	\N
26999	634	2018-12-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19768N	\N	\N
27090	595	2020-02-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
27100	572	2020-07-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19543W	\N	\N
28472	609	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14133K	\N	\N
28473	641	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19687N	\N	\N
28474	620	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19687N	\N	\N
28475	590	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19687N	\N	\N
28476	601	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19687N	\N	\N
28477	626	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19687N	\N	\N
28478	575	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19687N	\N	\N
28479	573	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19687N	\N	\N
28480	621	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19687N	\N	\N
29207	634	2020-12-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14219Q	\N	\N
29208	646	2020-12-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14219Q	\N	\N
29209	659	2020-12-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14219Q	\N	\N
29481	998	2020-12-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19549D	\N	\N
29597	530	2020-12-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
29769	919	2021-01-18 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20090E	\N	\N
29949	1008	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14205J	\N	\N
29973	919	2021-01-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14331P	\N	\N
29992	918	2021-01-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19347U	\N	\N
29993	922	2021-01-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19347U	\N	\N
30039	1005	2021-01-26 00:00:00	2022-12-31 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
30044	906	2021-01-27 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14071N	\N	\N
30089	641	2021-02-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14189C	\N	\N
30146	615	2021-02-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	\N	\N
30444	661	2021-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20056C	\N	\N
30445	571	2021-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11040E	\N	\N
30516	615	2022-01-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19413M	\N	\N
30559	530	2022-03-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19631V	\N	\N
30560	530	2022-03-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19583F	\N	\N
30574	597	2022-04-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14355X	\N	\N
31119	604	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21082J	\N	\N
31120	629	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21082J	\N	\N
31121	580	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21082J	\N	\N
31122	852	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21082J	\N	\N
31123	978	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21082J	\N	\N
31291	574	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21036C	\N	\N
31292	627	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21036C	\N	\N
31293	597	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21036C	\N	\N
31294	575	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21036C	\N	\N
31295	588	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21036C	\N	\N
31296	573	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21036C	\N	\N
31297	617	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21036C	\N	\N
33097	612	2023-11-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20118Y	\N	\N
33098	673	2023-11-21 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20118Y	\N	\N
25485	673	2017-11-29 00:00:00	2018-01-09 00:00:00	ANCIEN	\N	\N	\N	98018T	2017-11-29 12:36:02	2018-01-09 11:35:03
25554	603	2017-12-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08012N	2017-12-06 14:41:24	\N
25562	530	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14237S	2017-12-07 16:10:25	\N
25563	530	2017-12-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14103D	2017-12-07 16:10:50	\N
25564	604	2017-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19565D	2017-12-07 16:11:14	\N
25565	588	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08073C	2017-12-07 16:11:45	\N
25566	626	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08073C	2017-12-07 16:11:45	\N
25567	575	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08073C	2017-12-07 16:11:45	\N
25568	643	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08073C	2017-12-07 16:11:45	\N
25569	653	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08073C	2017-12-07 16:11:45	\N
25570	600	2017-12-04 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01025N	2017-12-07 16:12:21	\N
25571	644	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01058X	2017-12-07 16:17:41	\N
25572	851	2017-12-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19387D	2017-12-07 16:18:19	\N
25847	1004	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
25849	1004	2017-12-19 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14135M	\N	\N
25915	909	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19467C	\N	\N
25918	909	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19719D	\N	\N
25922	909	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
26231	998	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19591F	\N	\N
26316	919	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
26353	1005	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	\N	\N
26588	629	2018-02-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19367Y	2018-02-20 17:00:06	\N
26725	573	2018-03-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	07033P	2018-03-22 16:49:00	\N
26750	911	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11099A	\N	\N
26784	576	2018-06-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14031R	\N	\N
26785	584	2018-06-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19631V	\N	\N
26786	657	2018-06-19 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14159V	\N	\N
26808	1005	2018-09-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14059S	\N	\N
26881	911	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11045K	\N	\N
26970	919	2019-02-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19762G	\N	\N
26973	911	2019-02-14 00:00:00	2019-02-15 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
27795	573	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20148F	\N	\N
27796	599	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20148F	\N	\N
27797	642	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20148F	\N	\N
28706	612	2020-11-02 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	14041T	\N	\N
28707	619	2020-11-02 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	14041T	\N	\N
28708	577	2020-11-02 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	14041T	\N	\N
28709	583	2020-11-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20046A	\N	\N
28710	598	2020-11-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20046A	\N	\N
28711	642	2020-11-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20046A	\N	\N
28909	963	2020-11-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20052X	\N	\N
28910	602	2020-11-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20144B	\N	\N
28911	596	2020-11-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20144B	\N	\N
28912	618	2020-11-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20144B	\N	\N
28913	621	2020-11-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20144B	\N	\N
28914	588	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19545Y	\N	\N
28915	651	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19545Y	\N	\N
28916	529	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19545Y	\N	\N
28917	556	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19545Y	\N	\N
28918	594	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19545Y	\N	\N
28919	661	2020-11-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19545Y	\N	\N
28920	575	2020-11-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11074Q	\N	\N
28981	605	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	\N	\N
28982	579	2020-11-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20118Y	\N	\N
29124	979	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19525U	\N	\N
29125	604	2020-11-25 00:00:00	2023-09-12 00:00:00	ANCIEN	\N	\N	\N	14259Y	\N	\N
29126	646	2020-11-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19685L	\N	\N
29127	661	2020-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
29128	599	2020-11-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20026V	\N	\N
29222	619	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14357A	\N	\N
29223	647	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	\N	\N
29224	674	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	\N	\N
29225	642	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	12016W	\N	\N
29226	646	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14026U	\N	\N
29227	634	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14026U	\N	\N
29228	619	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
29229	530	2020-12-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01025N	\N	\N
29231	616	2020-12-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	10006L	\N	\N
29261	918	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
29306	907	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20068G	\N	\N
29309	907	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20126Y	\N	\N
29349	919	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19503N	\N	\N
29352	1005	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14105F	\N	\N
29353	1005	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19693L	\N	\N
29436	909	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14187A	\N	\N
29438	909	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20132W	\N	\N
29491	922	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14097Y	\N	\N
29641	919	2021-01-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11097X	\N	\N
29645	919	2021-01-04 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14109K	\N	\N
29646	1005	2021-01-04 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14109K	\N	\N
29687	909	2021-01-11 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	08010L	\N	\N
30317	934	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	17965H	\N	\N
30359	1012	2021-06-22 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	08045X	\N	\N
30394	908	2021-09-17 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20140W	\N	\N
30496	928	2022-01-01 00:00:00	2023-12-31 00:00:00	ANCIEN	\N	\N	\N	20074E	\N	\N
30650	585	2022-07-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
31484	609	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14215L	\N	\N
31485	1013	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14215L	\N	\N
31486	597	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14215L	\N	\N
31487	629	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14215L	\N	\N
31520	598	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19621T	\N	\N
31521	595	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19621T	\N	\N
31522	623	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19621T	\N	\N
31523	641	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19621T	\N	\N
31524	589	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19621T	\N	\N
31581	851	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19719D	\N	\N
31582	596	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19719D	\N	\N
31583	612	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19719D	\N	\N
31584	584	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19719D	\N	\N
31807	651	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	17229F	\N	\N
31814	598	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14205J	\N	\N
31815	663	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14205J	\N	\N
31816	581	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14205J	\N	\N
25756	596	2017-12-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11045K	2017-12-22 16:50:13	\N
25844	1004	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19723Y	\N	\N
25848	1004	2017-12-19 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
25851	1004	2017-12-19 00:00:00	2019-09-30 00:00:00	ANCIEN	\N	\N	\N	95062K	\N	\N
25852	1004	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11097X	\N	\N
26131	998	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19549D	\N	\N
26132	998	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14195A	\N	\N
26135	998	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08045X	\N	\N
26140	998	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14223L	\N	\N
26141	998	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14071N	\N	\N
26142	998	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19689Q	\N	\N
26143	998	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19301E	\N	\N
26144	998	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08049C	\N	\N
26321	919	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14109K	\N	\N
26721	1007	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	\N	\N
26723	1007	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19479G	\N	\N
26842	922	2018-10-03 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19701S	\N	\N
27095	623	2020-04-02 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14219Q	\N	\N
29210	617	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17737W	\N	\N
29211	604	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17737W	\N	\N
29212	619	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17737W	\N	\N
29213	615	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20052X	\N	\N
29308	907	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14097Y	\N	\N
29317	907	2020-12-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19713W	\N	\N
29327	919	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19467C	\N	\N
29328	919	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19693L	\N	\N
29329	919	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14169X	\N	\N
29330	919	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19719D	\N	\N
29331	919	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01024M	\N	\N
29332	919	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14215L	\N	\N
29333	919	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20074E	\N	\N
29334	919	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14187A	\N	\N
29335	919	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01025N	\N	\N
29336	919	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	08045X	\N	\N
29337	919	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	17023S	\N	\N
29350	919	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
29354	1005	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14169X	\N	\N
29355	1005	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19719D	\N	\N
29371	998	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	17023S	\N	\N
29615	908	2021-01-07 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20110Q	\N	\N
29647	906	2021-01-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11012A	\N	\N
29659	948	2021-01-07 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19725B	\N	\N
29765	912	2020-12-18 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14173T	\N	\N
29898	934	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14237S	\N	\N
30152	572	2021-02-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
30251	933	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19681G	\N	\N
30400	571	2021-10-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19503N	\N	\N
30402	624	2021-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
30441	919	2021-10-19 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14001X	\N	\N
30448	603	2021-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14073Q	\N	\N
30449	603	2021-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19369B	\N	\N
30450	571	2021-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08045X	\N	\N
30451	571	2021-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14026U	\N	\N
30473	640	2021-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
30474	623	2021-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20110Q	\N	\N
30475	624	2021-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01028R	\N	\N
30606	623	2022-04-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11074Q	\N	\N
30652	911	2022-07-21 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20024T	\N	\N
30719	596	2022-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
30788	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	17737W	\N	\N
31298	598	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21036C	\N	\N
31299	580	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21036C	\N	\N
31300	657	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21036C	\N	\N
31301	622	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21036C	\N	\N
31302	646	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21036C	\N	\N
31303	572	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21036C	\N	\N
31304	620	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21036C	\N	\N
31305	609	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21036C	\N	\N
31447	604	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20054A	\N	\N
31448	634	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20054A	\N	\N
31449	590	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20054A	\N	\N
31450	610	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20054A	\N	\N
31480	625	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14231L	\N	\N
31481	659	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14231L	\N	\N
31482	595	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14231L	\N	\N
31525	580	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19721W	\N	\N
31526	598	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19721W	\N	\N
31527	573	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19721W	\N	\N
31533	598	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14133K	\N	\N
31534	575	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14133K	\N	\N
31535	600	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14133K	\N	\N
31536	643	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14133K	\N	\N
31537	979	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14133K	\N	\N
31538	659	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14133K	\N	\N
31539	617	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14133K	\N	\N
31540	589	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14133K	\N	\N
31541	534	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14133K	\N	\N
31542	619	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14133K	\N	\N
31543	610	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14133K	\N	\N
31544	585	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14133K	\N	\N
31545	978	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14133K	\N	\N
31546	581	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14133K	\N	\N
31547	576	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14133K	\N	\N
31548	673	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14133K	\N	\N
31549	624	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14133K	\N	\N
31550	584	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14133K	\N	\N
31551	595	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14133K	\N	\N
31552	620	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14133K	\N	\N
31559	640	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11048N	\N	\N
31560	629	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11048N	\N	\N
31561	580	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11048N	\N	\N
31562	583	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11048N	\N	\N
31563	597	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	11048N	\N	\N
32163	596	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14001X	\N	\N
32164	550	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14001X	\N	\N
32165	663	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14001X	\N	\N
32166	674	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14001X	\N	\N
25068	598	2017-11-02 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11110B	2017-11-06 10:25:52	\N
25069	632	2017-11-02 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11110B	2017-11-06 10:25:52	\N
25070	590	2017-11-02 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11110B	2017-11-06 10:25:52	\N
25071	623	2017-11-02 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11110B	2017-11-06 10:25:52	\N
25072	589	2017-11-02 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11110B	2017-11-06 10:25:52	\N
25073	626	2017-11-02 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11110B	2017-11-06 10:25:52	\N
25074	595	2017-11-02 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11110B	2017-11-06 10:25:52	\N
25075	581	2017-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14147R	2017-11-06 10:26:22	\N
25076	CHRETORIENT	2017-10-24 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	14147R	2017-11-06 10:26:22	\N
25077	597	2017-10-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19711U	2017-11-06 10:27:33	\N
25078	595	2017-10-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19711U	2017-11-06 10:27:33	\N
25079	608	2017-10-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19711U	2017-11-06 10:27:33	\N
25080	CHRETORIENT	2017-10-20 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19711U	2017-11-06 10:27:33	\N
25081	620	2017-11-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19711U	2017-11-06 10:28:02	\N
25647	572	2017-12-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	2017-12-15 17:17:12	\N
25706	934	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14030Q	\N	\N
25707	934	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19643A	\N	\N
25714	934	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14213J	\N	\N
25716	934	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14039A	\N	\N
25723	934	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14107H	\N	\N
25728	1007	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
25746	1006	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19573D	\N	\N
25758	1007	2017-12-07 00:00:00	2020-09-29 00:00:00	ANCIEN	\N	\N	\N	04018C	\N	\N
25761	934	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
25766	1006	2017-12-07 00:00:00	2020-09-29 00:00:00	ANCIEN	\N	\N	\N	04018C	\N	\N
25779	582	2018-01-03 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08009T	2018-01-05 10:00:24	\N
25970	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	17779H	\N	\N
26152	621	2018-01-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14229S	2018-01-30 09:25:24	\N
26153	586	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19705W	2018-01-30 09:26:33	\N
26201	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04033B	\N	\N
26205	928	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14053L	\N	\N
26355	1005	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	95037J	\N	\N
26408	911	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19745F	\N	\N
26409	911	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
26425	573	2018-01-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14219Q	2018-02-12 16:29:10	\N
26444	616	2018-02-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19667J	2018-02-12 18:22:48	\N
26445	646	2018-02-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19667J	2018-02-12 18:22:48	\N
26446	586	2018-01-24 00:00:00	2018-07-27 00:00:00	ANCIEN	\N	\N	\N	19707Y	2018-02-12 18:25:09	\N
26447	646	2018-02-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19599P	2018-02-12 18:26:10	\N
26541	1005	2017-10-01 00:00:00	2019-03-01 00:00:00	ANCIEN	\N	\N	\N	89017R	\N	\N
26567	933	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19739H	\N	\N
26597	852	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	96004D	2018-02-22 15:28:51	\N
26598	612	2018-02-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19575F	2018-02-22 15:29:07	\N
26625	627	2018-03-08 00:00:00	2020-07-31 00:00:00	ANCIEN	\N	\N	\N	08044W	2018-03-08 12:30:39	\N
26647	1008	2018-03-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19631V	\N	\N
26648	1008	2018-03-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19717B	\N	\N
26650	1008	2018-03-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19667J	\N	\N
26752	852	2018-03-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11074Q	2018-04-19 10:08:05	\N
26905	934	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19629C	\N	\N
26906	934	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14105F	\N	\N
26908	934	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08049C	\N	\N
26912	934	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14193X	\N	\N
26995	CHRETORIENT	2019-03-06 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	19399H	\N	\N
27054	612	2019-11-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19421M	\N	\N
27055	573	2019-11-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	95041E	\N	\N
27076	603	2020-01-23 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04069P	\N	\N
27958	604	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19782L	\N	\N
27959	604	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19651A	\N	\N
27960	613	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19651A	\N	\N
27961	591	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19651A	\N	\N
27962	590	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19651A	\N	\N
27963	597	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19651A	\N	\N
27964	616	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19651A	\N	\N
27965	611	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19651A	\N	\N
27966	573	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19651A	\N	\N
27967	598	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14281W	\N	\N
27968	674	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14281W	\N	\N
27969	640	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14187A	\N	\N
27970	621	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14187A	\N	\N
27971	583	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14187A	\N	\N
27972	596	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14187A	\N	\N
27973	597	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14187A	\N	\N
27974	598	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14187A	\N	\N
27975	673	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14187A	\N	\N
27976	572	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
27977	574	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
27978	617	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
27979	610	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
27980	573	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
27981	646	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
27982	978	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
27983	581	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
27984	599	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
27985	589	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
27986	659	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
27987	576	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
27988	621	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
27989	556	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
27990	578	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
27991	625	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
27992	590	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
27993	596	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
27994	580	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
27995	674	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
27996	661	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
27997	609	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
27998	534	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
27999	620	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
28000	601	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
28001	643	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
25240	580	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19697Q	2017-11-13 17:52:22	\N
25241	573	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19697Q	2017-11-13 17:52:22	\N
25242	628	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19697Q	2017-11-13 17:52:22	\N
25243	597	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19697Q	2017-11-13 17:52:22	\N
25244	CHRETORIENT	2017-11-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14055N	2017-11-13 17:52:54	\N
25245	CHRETORIENT	2017-11-09 00:00:00	2023-10-05 00:00:00	ANCIEN	\N	\N	\N	04071H	2017-11-13 17:53:14	\N
25598	530	2017-12-08 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	19737F	2017-12-08 11:44:56	\N
25786	663	2018-01-04 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14030Q	2018-01-10 09:52:32	\N
25787	629	2018-01-04 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14030Q	2018-01-10 09:52:32	\N
25788	586	2018-01-08 00:00:00	2019-03-11 00:00:00	ANCIEN	\N	\N	\N	08012N	2018-01-10 09:52:52	\N
25813	1007	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19611R	\N	\N
25822	1006	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
25850	1004	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14331P	\N	\N
25971	909	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14207L	\N	\N
26133	998	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08038Y	\N	\N
26211	934	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19349W	\N	\N
26241	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11090Q	\N	\N
26248	928	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
26271	919	2019-02-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19693L	\N	\N
26273	919	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14217N	\N	\N
26294	919	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
26352	1005	2018-01-23 00:00:00	2020-06-27 00:00:00	ANCIEN	\N	\N	\N	14199E	\N	\N
26354	1005	2018-01-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19725B	\N	\N
26594	911	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19511N	\N	\N
26797	578	2018-09-04 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
26868	674	2018-10-03 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14331P	\N	\N
27755	550	2020-10-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19723Y	\N	\N
27756	602	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20124W	\N	\N
27757	610	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20124W	\N	\N
27785	581	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14133K	\N	\N
27786	608	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14133K	\N	\N
27787	619	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14133K	\N	\N
27788	624	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14133K	\N	\N
27789	534	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14133K	\N	\N
27790	584	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14133K	\N	\N
28686	573	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19347U	\N	\N
28687	621	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19347U	\N	\N
28688	578	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19347U	\N	\N
28689	622	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19347U	\N	\N
28690	643	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19347U	\N	\N
28691	605	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19347U	\N	\N
28692	576	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19347U	\N	\N
28693	596	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19347U	\N	\N
28694	572	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19347U	\N	\N
28695	575	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19347U	\N	\N
28696	598	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19347U	\N	\N
28697	602	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19347U	\N	\N
28698	573	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11099A	\N	\N
28699	979	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11099A	\N	\N
28700	605	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11099A	\N	\N
28701	651	2020-10-31 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20110Q	\N	\N
28702	641	2020-10-31 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20110Q	\N	\N
28703	532	2020-10-31 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20110Q	\N	\N
28704	596	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19671E	\N	\N
28705	674	2020-10-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19671E	\N	\N
29193	582	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17023S	\N	\N
29194	584	2020-12-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19725B	\N	\N
29195	619	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	\N	\N
29439	909	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19820Y	\N	\N
29440	909	2020-12-17 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
29441	909	2020-12-17 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	08069G	\N	\N
29442	909	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14213J	\N	\N
29535	907	2020-12-22 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19782L	\N	\N
29685	907	2021-01-12 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20118Y	\N	\N
29696	919	2020-12-21 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20088L	\N	\N
29704	919	2021-01-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14329V	\N	\N
29766	534	2021-01-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17367Q	\N	\N
29823	1004	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19667J	\N	\N
30641	922	2022-06-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19503N	\N	\N
30646	948	2020-04-05 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20092G	\N	\N
31032	602	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	05012A	\N	\N
31033	574	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	05012A	\N	\N
31034	661	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	05012A	\N	\N
31035	978	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	05012A	\N	\N
31036	578	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	05012A	\N	\N
31063	581	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19349W	\N	\N
31064	590	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19349W	\N	\N
31065	641	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19349W	\N	\N
31896	602	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19709B	\N	\N
31897	622	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19709B	\N	\N
31898	673	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19709B	\N	\N
31899	534	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19709B	\N	\N
31900	643	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19709B	\N	\N
31901	581	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19709B	\N	\N
31902	642	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19709B	\N	\N
31903	651	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19709B	\N	\N
31904	618	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19709B	\N	\N
31905	598	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19709B	\N	\N
31906	653	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19709B	\N	\N
31907	661	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19709B	\N	\N
31908	601	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19709B	\N	\N
31909	604	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19709B	\N	\N
31910	584	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19709B	\N	\N
31911	573	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19709B	\N	\N
31912	626	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19709B	\N	\N
31913	556	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19709B	\N	\N
31914	617	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19709B	\N	\N
31915	590	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19709B	\N	\N
31916	597	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19709B	\N	\N
31917	580	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19709B	\N	\N
31918	595	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19709B	\N	\N
31919	589	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19709B	\N	\N
31920	1013	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19709B	\N	\N
31921	646	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19709B	\N	\N
25279	581	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19521Q	2017-11-16 14:07:36	\N
25749	578	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01043Q	2017-12-22 09:46:41	\N
25750	617	2017-12-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01043Q	2017-12-22 09:48:56	\N
25751	581	2017-12-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19643A	2017-12-22 09:49:28	\N
25752	579	2017-12-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19643A	2017-12-22 09:49:28	\N
25753	673	2017-12-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	10006L	2017-12-22 09:50:04	\N
25754	572	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14237S	2017-12-22 09:59:14	\N
25854	851	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19719D	2018-01-17 09:22:17	\N
25855	624	2017-12-20 00:00:00	2019-10-16 00:00:00	ANCIEN	\N	\N	\N	19719D	2018-01-17 09:22:18	\N
25856	592	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19719D	2018-01-17 09:22:18	\N
25857	578	2018-01-15 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14028W	2018-01-17 09:22:42	\N
25858	556	2018-01-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19713W	2018-01-17 09:23:03	\N
26056	906	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	17589D	\N	\N
26058	906	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01024M	\N	\N
26059	906	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14197C	\N	\N
26060	906	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
26134	998	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14281W	\N	\N
26431	922	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
26432	922	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11110B	\N	\N
26433	922	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14034U	\N	\N
26434	922	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04097T	\N	\N
26435	922	2018-01-03 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11048N	\N	\N
26436	922	2017-10-01 00:00:00	2020-07-31 00:00:00	ANCIEN	\N	\N	\N	08044W	\N	\N
26437	922	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
26438	922	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19657G	\N	\N
26439	922	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14031R	\N	\N
26440	922	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19637C	\N	\N
26442	922	2018-01-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14169X	\N	\N
26530	938	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14059S	\N	\N
26531	938	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19657G	\N	\N
26534	938	2017-10-01 00:00:00	2019-03-03 00:00:00	ANCIEN	\N	\N	\N	07034Q	\N	\N
26535	938	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19421M	\N	\N
26607	648	2018-02-21 00:00:00	2018-11-03 00:00:00	ANCIEN	\N	\N	\N	19251M	2018-02-23 17:44:41	\N
26608	534	2017-12-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	95041E	2018-02-23 18:06:56	\N
26612	852	2018-02-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14225N	2018-03-01 09:17:53	\N
26695	919	2018-02-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14038Y	\N	\N
26696	919	2018-02-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
26697	919	2018-02-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08012N	\N	\N
26715	1007	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19675J	\N	\N
26719	934	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
26796	CHRETORIENT	2018-07-19 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	19611R	\N	\N
26812	591	2018-09-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
26985	948	2019-02-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	17583W	\N	\N
27017	911	2019-05-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19762G	\N	\N
27060	659	2019-12-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14193X	\N	\N
27453	596	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14213J	\N	\N
27454	573	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14213J	\N	\N
27455	602	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14213J	\N	\N
27456	653	2020-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14213J	\N	\N
28002	595	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
28003	604	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
28004	608	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
28005	579	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
28006	653	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
28007	583	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
28008	597	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
28009	602	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
28010	598	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
28011	979	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
28012	628	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
28013	584	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
28014	641	2020-10-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
28015	590	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	12016W	\N	\N
28016	573	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	12016W	\N	\N
28017	978	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	12016W	\N	\N
28018	618	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	12016W	\N	\N
28481	629	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14189C	\N	\N
28482	673	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14189C	\N	\N
28483	596	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14189C	\N	\N
28484	621	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14189C	\N	\N
28485	629	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19511N	\N	\N
28486	661	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19511N	\N	\N
28487	621	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19511N	\N	\N
28488	604	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19820Y	\N	\N
28489	583	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19820Y	\N	\N
28490	589	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19820Y	\N	\N
28491	598	2020-10-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14357A	\N	\N
28492	CHRETORIENT	2020-10-23 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14357A	\N	\N
28493	673	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20140W	\N	\N
28494	CHRETORIENT	2020-10-27 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	20140W	\N	\N
28495	621	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20140W	\N	\N
28496	CHRETORIENT	2020-10-27 00:00:00	2023-10-05 00:00:00	ANCIEN	\N	\N	\N	19333N	\N	\N
28826	573	2020-11-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19721W	\N	\N
28827	620	2020-11-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19721W	\N	\N
28828	609	2020-11-04 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	04086Q	\N	\N
28829	594	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
28830	588	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
28831	651	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
28832	594	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19583F	\N	\N
28833	556	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19583F	\N	\N
28834	588	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19583F	\N	\N
28835	651	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19583F	\N	\N
28836	612	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
28837	605	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
28838	609	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19719D	\N	\N
28839	597	2020-11-04 00:00:00	2023-09-28 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
28840	529	2020-11-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20050V	\N	\N
29017	851	2020-11-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20132W	\N	\N
29160	605	2020-12-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14195A	\N	\N
29185	643	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
29186	604	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14105F	\N	\N
29348	919	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19745F	\N	\N
29473	918	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19631V	\N	\N
29474	918	2020-12-15 00:00:00	2022-07-19 00:00:00	ANCIEN	\N	\N	\N	20100N	\N	\N
25100	608	2017-10-10 00:00:00	2018-11-16 00:00:00	ANCIEN	\N	\N	\N	19253P	2017-11-06 16:40:54	\N
25101	624	2017-10-10 00:00:00	2018-11-16 00:00:00	ANCIEN	\N	\N	\N	19253P	2017-11-06 16:40:54	\N
25102	610	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11012A	2017-11-06 17:04:34	\N
25103	591	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11012A	2017-11-06 17:04:34	\N
25104	577	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11012A	2017-11-06 17:04:34	\N
25105	595	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11012A	2017-11-06 17:04:34	\N
25106	605	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11012A	2017-11-06 17:04:34	\N
25107	978	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11012A	2017-11-06 17:04:34	\N
25461	646	2017-11-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14265W	2017-11-24 18:15:26	\N
25462	574	2017-11-24 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14265W	2017-11-24 18:15:26	\N
25783	CHRETORIENT	2018-01-05 00:00:00	2023-12-12 00:00:00	ANCIEN	\N	\N	\N	19511N	2018-01-05 11:41:19	\N
25808	966	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14030Q	\N	\N
26052	906	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14357A	\N	\N
26053	906	2017-10-01 00:00:00	2018-03-12 00:00:00	ANCIEN	\N	\N	\N	14079W	\N	\N
26239	673	2018-01-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14123H	2018-02-02 17:51:55	\N
26340	1005	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08055A	\N	\N
26341	1005	2018-01-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08043V	\N	\N
26495	908	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19621T	\N	\N
26497	908	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	\N	\N
26498	908	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08024S	\N	\N
26500	908	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14281W	\N	\N
26501	908	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08045X	\N	\N
26502	908	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	15447F	\N	\N
26503	908	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19489J	\N	\N
26623	933	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19611R	\N	\N
26735	919	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19441R	\N	\N
26736	1005	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19441R	\N	\N
26778	CHRETORIENT	2018-06-11 00:00:00	2022-02-02 00:00:00	ANCIEN	\N	\N	\N	19289C	2018-06-11 17:36:54	\N
26836	1007	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
26894	963	2018-11-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	\N	\N
26936	907	2018-12-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04047H	\N	\N
26968	911	2019-02-12 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19723Y	\N	\N
27075	661	2020-01-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19333N	\N	\N
27798	629	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14169X	\N	\N
27799	601	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14169X	\N	\N
27800	628	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14169X	\N	\N
27801	576	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14169X	\N	\N
27802	661	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14169X	\N	\N
27803	651	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01058X	\N	\N
27804	626	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01058X	\N	\N
27805	979	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01058X	\N	\N
27806	634	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20056C	\N	\N
27807	615	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20056C	\N	\N
27808	633	2020-10-15 00:00:00	2023-10-04 00:00:00	ANCIEN	\N	\N	\N	20056C	\N	\N
27809	CHRETORIENT	2020-10-15 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	20056C	\N	\N
27810	626	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20056C	\N	\N
27811	599	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20056C	\N	\N
27812	574	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20056C	\N	\N
27813	590	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20056C	\N	\N
27814	591	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20056C	\N	\N
27815	596	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20056C	\N	\N
27816	623	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20056C	\N	\N
27817	646	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20056C	\N	\N
27818	577	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20052X	\N	\N
27819	590	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20052X	\N	\N
27820	576	2020-10-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20052X	\N	\N
28907	577	2020-11-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19543W	\N	\N
28908	579	2020-11-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14071N	\N	\N
28922	576	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20104S	\N	\N
28923	628	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20104S	\N	\N
28924	608	2020-10-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20104S	\N	\N
28925	963	2020-11-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19629C	\N	\N
28926	979	2020-11-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19629C	\N	\N
28927	610	2020-11-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19533U	\N	\N
28928	646	2020-11-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19533U	\N	\N
28929	604	2020-11-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19533U	\N	\N
28930	643	2020-11-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
28931	589	2020-11-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11067R	\N	\N
29052	580	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14331P	\N	\N
29053	604	2020-11-23 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14331P	\N	\N
29237	613	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14123H	\N	\N
29238	596	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14123H	\N	\N
29276	584	2020-12-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19747H	\N	\N
29277	573	2020-12-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19747H	\N	\N
29278	621	2020-12-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19747H	\N	\N
29279	604	2020-12-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19747H	\N	\N
29280	659	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
29281	615	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
29282	633	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04043D	\N	\N
29323	919	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
30227	661	2021-03-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11064N	\N	\N
30344	1012	2021-06-10 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14059S	\N	\N
30403	906	2021-10-07 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	17367Q	\N	\N
30614	530	2022-03-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14026U	\N	\N
30684	659	2022-09-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14151M	\N	\N
30782	1014	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14187A	\N	\N
30877	623	2023-10-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20026V	\N	\N
31667	641	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21089R	\N	\N
31922	576	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19709B	\N	\N
31923	659	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19709B	\N	\N
31924	610	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19709B	\N	\N
31925	577	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19709B	\N	\N
31926	583	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19709B	\N	\N
31927	592	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19709B	\N	\N
31928	621	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19709B	\N	\N
31929	641	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19709B	\N	\N
31930	572	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19709B	\N	\N
31931	600	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19709B	\N	\N
31932	609	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19709B	\N	\N
31933	625	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19709B	\N	\N
31934	588	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19709B	\N	\N
31935	647	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19709B	\N	\N
32289	583	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14281W	\N	\N
25555	556	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08009T	2017-12-07 09:33:29	\N
25556	530	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19739H	2017-12-07 09:34:45	\N
25557	530	2017-12-06 00:00:00	2018-12-30 00:00:00	ANCIEN	\N	\N	\N	98023Q	2017-12-07 09:35:05	\N
25558	643	2017-11-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19685L	2017-12-07 09:35:22	\N
25559	661	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11064N	2017-12-07 09:35:47	\N
25560	529	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11064N	2017-12-07 09:35:47	\N
25561	615	2017-12-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19569H	2017-12-07 10:19:15	\N
26035	948	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	88008L	\N	\N
26824	934	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14169X	\N	\N
26199	584	2018-01-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19747H	2018-01-31 16:53:03	\N
26200	628	2018-01-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14109K	2018-01-31 17:00:47	\N
26259	919	2018-01-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19549D	\N	\N
26382	1005	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14159V	\N	\N
26787	585	2018-01-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19671E	\N	\N
26840	674	2018-10-03 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	18083K	\N	\N
26873	628	2018-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19611R	\N	\N
26874	573	2018-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19611R	\N	\N
26875	661	2018-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19611R	\N	\N
26876	621	2018-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19611R	\N	\N
26877	588	2018-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19611R	\N	\N
26878	608	2018-10-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19611R	\N	\N
26898	851	2018-11-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
26918	590	2018-11-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19735D	\N	\N
26930	576	2018-12-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19289C	\N	\N
26972	907	2019-02-14 00:00:00	2019-02-15 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
26976	907	2019-02-15 00:00:00	2019-03-06 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
27023	613	2019-06-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
27046	948	2019-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	19713W	\N	\N
29475	918	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14109K	\N	\N
29503	919	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	\N	\N
29504	1005	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	\N	\N
29505	907	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	\N	\N
29506	911	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	\N	\N
29517	907	2020-12-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	16685X	\N	\N
29531	576	2020-12-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19441R	\N	\N
29598	909	2021-01-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11101A	\N	\N
29601	998	2021-01-05 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14257W	\N	\N
29602	906	2021-01-05 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14257W	\N	\N
29610	1005	2021-01-04 00:00:00	2022-06-20 00:00:00	ANCIEN	\N	\N	\N	20174H	\N	\N
29644	909	2021-01-04 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14109K	\N	\N
29649	919	2021-01-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11012A	\N	\N
29655	907	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	08061X	\N	\N
29686	948	2021-01-12 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20118Y	\N	\N
29701	909	2021-01-13 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14026U	\N	\N
29725	918	2021-01-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19643A	\N	\N
29726	918	2021-01-12 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14187A	\N	\N
29739	919	2021-01-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19563B	\N	\N
29785	1008	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20060X	\N	\N
29800	1008	2020-10-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19489J	\N	\N
29801	1008	2020-10-01 00:00:00	2026-10-01 00:00:00	ANCIEN	\N	\N	\N	19611R	\N	\N
29832	1004	2020-10-01 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	14041T	\N	\N
29845	1006	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
29846	1006	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20114U	\N	\N
29854	966	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	05008E	\N	\N
29855	966	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
29856	966	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20114U	\N	\N
29857	966	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20142Y	\N	\N
29860	966	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19723Y	\N	\N
29861	966	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20052X	\N	\N
29862	966	2020-10-01 00:00:00	2026-03-01 00:00:00	ACTIF	\N	\N	\N	14147R	\N	\N
29863	966	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20058E	\N	\N
29864	1007	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19515S	\N	\N
29865	1007	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
29866	1007	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	08028W	\N	\N
29869	1007	2020-10-01 00:00:00	2026-03-01 00:00:00	ACTIF	\N	\N	\N	14187A	\N	\N
29881	934	2020-10-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19621T	\N	\N
29906	928	2020-10-01 00:00:00	2023-12-31 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
29904	928	2020-10-01 00:00:00	2023-12-31 00:00:00	ANCIEN	\N	\N	\N	14133K	\N	\N
29905	928	2020-10-01 00:00:00	2023-12-31 00:00:00	ANCIEN	\N	\N	\N	20024T	\N	\N
29907	928	2020-10-01 00:00:00	2023-12-31 00:00:00	ANCIEN	\N	\N	\N	20114U	\N	\N
29908	928	2020-10-01 00:00:00	2023-12-31 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
29909	928	2020-10-01 00:00:00	2023-12-31 00:00:00	ANCIEN	\N	\N	\N	14053L	\N	\N
29910	928	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19681G	\N	\N
29911	928	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
29912	928	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17589D	\N	\N
29948	919	2021-01-20 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19768N	\N	\N
29960	934	2020-10-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19711U	\N	\N
29997	919	2021-01-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19701S	\N	\N
30053	919	2021-01-26 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20118Y	\N	\N
30054	919	2021-01-26 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20054A	\N	\N
30055	919	2021-01-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19762G	\N	\N
30056	948	2021-01-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19762G	\N	\N
30057	911	2021-01-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19762G	\N	\N
30208	922	2021-02-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20036X	\N	\N
30222	948	2021-03-04 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20128B	\N	\N
30226	556	2021-03-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	18083K	\N	\N
30264	933	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11077T	\N	\N
30265	933	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01048V	\N	\N
30266	933	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14221J	\N	\N
30267	933	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19671E	\N	\N
30268	933	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14169X	\N	\N
30269	933	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19745F	\N	\N
30270	933	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19739H	\N	\N
30274	933	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20150Y	\N	\N
30283	1007	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11090Q	\N	\N
30286	1011	2021-03-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11033F	\N	\N
30287	1011	2021-03-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19643A	\N	\N
30309	911	2021-03-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19685L	\N	\N
30351	1012	2021-06-11 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20144B	\N	\N
30385	648	2021-09-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	07004J	\N	\N
30442	674	2021-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20104S	\N	\N
30487	642	2021-12-07 00:00:00	2023-09-28 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
30513	620	2021-12-31 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20264J	\N	\N
30514	642	2021-12-31 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20264J	\N	\N
30515	590	2021-12-31 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20264J	\N	\N
30586	1013	2022-04-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19782L	\N	\N
24895	580	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19721W	2017-10-31 17:06:36	\N
24896	598	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19721W	2017-10-31 17:06:36	\N
24897	530	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	2017-10-31 17:18:21	\N
24898	611	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	2017-10-31 17:18:21	\N
24899	592	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	2017-10-31 17:18:21	\N
24900	589	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	2017-10-31 17:18:21	\N
24901	616	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	2017-10-31 17:18:21	\N
24902	674	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	2017-10-31 17:18:21	\N
24903	851	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	2017-10-31 17:18:21	\N
24904	573	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	2017-10-31 17:18:21	\N
24905	598	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	2017-10-31 17:18:21	\N
24906	609	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	2017-10-31 17:18:21	\N
24907	579	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	2017-10-31 17:18:21	\N
24908	605	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	2017-10-31 17:18:21	\N
24909	604	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	2017-10-31 17:18:21	\N
24910	581	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	2017-10-31 17:18:21	\N
24911	596	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	2017-10-31 17:18:21	\N
24912	529	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	2017-10-31 17:18:21	\N
24913	642	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	2017-10-31 17:18:21	\N
24914	572	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	2017-10-31 17:18:21	\N
24915	608	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	2017-10-31 17:18:21	\N
24916	582	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	2017-10-31 17:18:21	\N
24917	532	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	2017-10-31 17:18:21	\N
24918	584	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	2017-10-31 17:18:21	\N
24919	618	2017-10-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19649G	2017-10-31 17:24:27	\N
24920	584	2017-10-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19649G	2017-10-31 17:24:27	\N
24921	625	2017-10-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19649G	2017-10-31 17:24:27	\N
24922	602	2017-10-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04038G	2017-10-31 17:25:12	\N
24923	609	2017-10-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04038G	2017-10-31 17:25:12	\N
24924	621	2017-10-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04038G	2017-10-31 17:25:12	\N
24925	618	2017-10-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04038G	2017-10-31 17:25:12	\N
24926	583	2017-10-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04038G	2017-10-31 17:25:12	\N
24927	625	2017-10-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04038G	2017-10-31 17:25:12	\N
24928	534	2017-10-30 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04038G	2017-10-31 17:25:12	\N
24929	622	2017-10-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01043Q	2017-10-31 17:29:24	\N
24930	643	2017-10-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01043Q	2017-10-31 17:29:24	\N
24931	651	2017-10-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01043Q	2017-10-31 17:29:24	\N
24932	663	2017-10-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01043Q	2017-10-31 17:29:24	\N
24933	618	2017-10-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01043Q	2017-10-31 17:29:24	\N
24934	590	2017-10-27 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01043Q	2017-10-31 17:29:24	\N
24935	601	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19687N	2017-10-31 17:29:59	\N
24936	575	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19687N	2017-10-31 17:29:59	\N
24937	589	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19687N	2017-10-31 17:29:59	\N
24938	573	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19687N	2017-10-31 17:29:59	\N
24939	626	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19687N	2017-10-31 17:29:59	\N
24940	621	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19687N	2017-10-31 17:29:59	\N
24941	641	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19687N	2017-10-31 17:29:59	\N
24942	590	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19687N	2017-10-31 17:29:59	\N
24943	602	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	2017-10-31 17:30:32	\N
24944	573	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	2017-10-31 17:30:32	\N
24945	621	2017-10-30 00:00:00	2017-11-30 00:00:00	ANCIEN	\N	\N	\N	11027H	2017-10-31 17:30:32	2017-11-30 14:58:30
24946	661	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	2017-10-31 17:30:32	\N
24947	594	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	2017-10-31 17:30:32	\N
24948	623	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	2017-10-31 17:30:32	\N
24949	575	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	2017-10-31 17:30:32	\N
24950	629	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	2017-10-31 17:30:32	\N
24951	642	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	2017-10-31 17:30:32	\N
24952	673	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	2017-10-31 17:30:32	\N
24953	628	2017-10-30 00:00:00	2017-11-30 00:00:00	ANCIEN	\N	\N	\N	11027H	2017-10-31 17:30:32	2017-11-30 14:58:30
24954	583	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	2017-10-31 17:30:32	\N
24955	584	2017-10-30 00:00:00	2017-11-30 00:00:00	ANCIEN	\N	\N	\N	11027H	2017-10-31 17:30:32	2017-11-30 14:58:30
24956	601	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19695N	2017-10-31 17:35:15	\N
24957	574	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19695N	2017-10-31 17:35:15	\N
24958	632	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19695N	2017-10-31 17:35:15	\N
24959	642	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19695N	2017-10-31 17:35:15	\N
24960	663	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19695N	2017-10-31 17:35:15	\N
24961	577	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19695N	2017-10-31 17:35:15	\N
24962	601	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11064N	2017-10-31 18:02:18	\N
24963	617	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11064N	2017-10-31 18:02:18	\N
24964	575	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11064N	2017-10-31 18:02:18	\N
24965	573	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11064N	2017-10-31 18:02:18	\N
24966	598	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11064N	2017-10-31 18:02:18	\N
24967	550	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11064N	2017-10-31 18:02:18	\N
24968	651	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11064N	2017-10-31 18:02:18	\N
24969	597	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11064N	2017-10-31 18:02:18	\N
24970	578	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11064N	2017-10-31 18:02:18	\N
24971	584	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11064N	2017-10-31 18:02:53	\N
24972	659	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11064N	2017-10-31 18:02:53	\N
25609	657	2017-12-12 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14197C	2017-12-12 11:07:40	\N
25610	661	2017-12-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08061X	2017-12-12 11:07:57	\N
25611	609	2017-12-07 00:00:00	2018-01-17 00:00:00	ANCIEN	\N	\N	\N	14239U	2017-12-12 11:08:27	2018-01-22 11:42:55
25821	966	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04070G	\N	\N
25964	934	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19683J	\N	\N
26179	906	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04089T	\N	\N
26448	919	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	\N	\N
26449	919	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14085U	\N	\N
26451	919	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14225N	\N	\N
26452	911	2015-10-01 00:00:00	2017-09-30 00:00:00	ANCIEN	\N	\N	\N	08034U	\N	\N
25365	594	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11110B	2017-11-20 10:07:42	\N
25516	615	2017-11-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19637C	2017-11-30 17:36:18	\N
25517	595	2017-11-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19611R	2017-11-30 17:36:35	\N
25518	601	2017-11-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19611R	2017-11-30 17:36:35	\N
25632	644	2017-12-04 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	2017-12-15 09:26:17	\N
25633	603	2017-12-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	2017-12-15 09:26:41	\N
25634	550	2017-12-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	2017-12-15 09:26:41	\N
25635	530	2017-12-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	2017-12-15 09:26:41	\N
25984	572	2018-01-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11045K	2018-01-23 12:24:12	2018-01-23 12:25:45
26126	906	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19549D	\N	\N
26145	909	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14105F	\N	\N
26544	1005	2018-02-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14038Y	\N	\N
26589	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19383Y	\N	\N
26609	597	2018-02-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	2018-02-26 17:52:25	\N
26883	934	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14061L	\N	\N
26897	934	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14231L	\N	\N
27096	674	2020-05-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19549D	\N	\N
28947	576	2020-11-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	12028B	\N	\N
28948	613	2020-11-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
29534	909	2020-12-22 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19782L	\N	\N
29576	912	2020-12-28 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20062A	\N	\N
29670	906	2020-12-18 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14033T	\N	\N
29672	1005	2020-12-18 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14033T	\N	\N
29674	911	2020-12-18 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14033T	\N	\N
29742	907	2021-01-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19563B	\N	\N
29743	948	2021-01-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19563B	\N	\N
29775	1008	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20032T	\N	\N
29777	1008	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19631V	\N	\N
29778	1008	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20112S	\N	\N
29779	1008	2020-10-01 00:00:00	2026-09-30 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
29780	1008	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14069U	\N	\N
29781	1008	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20042V	\N	\N
29783	1008	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
29784	1008	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14083S	\N	\N
29824	1004	2020-10-01 00:00:00	2023-12-31 00:00:00	ANCIEN	\N	\N	\N	20024T	\N	\N
30021	934	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01062T	\N	\N
30246	933	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
30023	919	2021-01-26 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19747H	\N	\N
30024	919	2021-01-26 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20104S	\N	\N
30025	919	2021-01-26 00:00:00	2021-07-27 00:00:00	ANCIEN	\N	\N	\N	04086Q	\N	\N
30026	919	2021-01-26 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20140W	\N	\N
30027	919	2021-01-26 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
30028	919	2021-01-26 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19723Y	\N	\N
30029	906	2021-01-25 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14083S	\N	\N
30066	979	2021-01-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19631V	\N	\N
30070	616	2021-01-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	95063L	\N	\N
30087	934	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20120S	\N	\N
30209	918	2021-02-16 00:00:00	2021-02-16 00:00:00	ANCIEN	\N	\N	\N	14133K	\N	\N
30321	648	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19369B	\N	\N
30396	966	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20026V	\N	\N
30438	595	2021-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20042V	\N	\N
30439	600	2021-10-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20042V	\N	\N
30550	1013	2022-03-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04033B	\N	\N
30579	1013	2022-04-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20108W	\N	\N
30580	1013	2022-04-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20172F	\N	\N
30581	1013	2022-04-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14215L	\N	\N
30611	1013	2022-04-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
30612	641	2022-04-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	\N	\N
30645	906	2022-06-21 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20018V	\N	\N
30651	594	2022-07-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	\N	\N
30662	CHRETORIENT	2022-06-08 00:00:00	2032-10-01 00:00:00	ACTIF	\N	\N	\N	20026V	\N	\N
30663	CHRETORIENT	2022-06-01 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19593H	\N	\N
30677	580	2020-11-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20134Y	\N	\N
30678	589	2020-11-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20134Y	\N	\N
30679	604	2020-11-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20134Y	\N	\N
30680	621	2020-11-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20134Y	\N	\N
30681	659	2022-09-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14193X	\N	\N
30682	623	2022-09-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14111D	\N	\N
30683	659	2022-09-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14111D	\N	\N
30718	590	2022-12-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	07004J	\N	\N
30744	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	14059S	\N	\N
30745	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	14213J	\N	\N
30746	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	18193Q	\N	\N
30765	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	20034V	\N	\N
30783	1014	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20066E	\N	\N
30794	1014	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14219Q	\N	\N
30844	673	2023-06-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19369B	\N	\N
30840	673	2023-05-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20124W	\N	\N
30843	659	2023-06-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20120S	\N	\N
30850	626	2023-06-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	\N	\N
30862	589	2023-09-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	07033P	\N	\N
30990	625	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14275Y	\N	\N
30991	663	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14275Y	\N	\N
31028	591	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20074E	\N	\N
31029	604	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20074E	\N	\N
31030	673	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20074E	\N	\N
31031	600	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20074E	\N	\N
31075	530	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20106U	\N	\N
31076	580	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20106U	\N	\N
31077	625	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20106U	\N	\N
31078	978	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20106U	\N	\N
31079	589	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20106U	\N	\N
31080	640	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20106U	\N	\N
31081	643	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20106U	\N	\N
31082	594	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20106U	\N	\N
31083	596	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20106U	\N	\N
31084	979	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20106U	\N	\N
31146	589	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20032T	\N	\N
31147	978	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20032T	\N	\N
31148	596	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20032T	\N	\N
31149	600	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20032T	\N	\N
31253	605	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	18193Q	\N	\N
31254	573	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	18193Q	\N	\N
31255	622	2023-10-10 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	18193Q	\N	\N
25708	934	2017-10-01 00:00:00	2018-03-19 00:00:00	ANCIEN	\N	\N	\N	19721W	\N	\N
25709	934	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	87003B	\N	\N
25710	934	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14249W	\N	\N
25711	934	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11110B	\N	\N
25712	934	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19387D	\N	\N
25713	934	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19399H	\N	\N
25715	934	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14241N	\N	\N
25717	934	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19699S	\N	\N
25718	934	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19711U	\N	\N
25719	934	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08012N	\N	\N
25720	934	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14063N	\N	\N
25721	934	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19573D	\N	\N
25722	934	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19533U	\N	\N
25724	934	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11043H	\N	\N
25747	1006	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19735D	\N	\N
25891	907	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14265W	\N	\N
25892	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08061X	\N	\N
25893	907	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
25894	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
25895	907	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	98050T	\N	\N
25896	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19739H	\N	\N
25898	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14331P	\N	\N
26154	998	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14197C	\N	\N
26296	919	2017-10-01 00:00:00	2018-04-13 00:00:00	ANCIEN	\N	\N	\N	19483C	\N	2018-04-13 17:54:29
26297	919	2018-01-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	17779H	\N	\N
26393	911	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14281W	\N	\N
26471	928	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	19467C	\N	\N
26479	957	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08038Y	\N	\N
26481	957	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	\N	\N
26482	957	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
26486	957	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
26488	957	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14257W	\N	\N
26489	957	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	92040Q	\N	\N
26490	957	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
26507	908	2017-10-01 00:00:00	2019-08-27 00:00:00	ANCIEN	\N	\N	\N	80027E	\N	\N
26509	908	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19745F	\N	\N
26510	908	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	17583W	\N	\N
26602	852	2018-02-21 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19507S	2018-02-23 15:18:42	\N
26645	852	2018-03-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14231L	2018-03-13 17:10:39	\N
26724	1006	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19709B	\N	\N
26850	661	2018-10-10 00:00:00	2020-08-02 00:00:00	ANCIEN	\N	\N	\N	14239U	\N	\N
26851	627	2018-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	98022P	\N	\N
26922	963	2018-11-22 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08031R	\N	\N
26928	907	2018-11-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19760E	\N	\N
27038	590	2018-06-11 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	\N	\N
27053	573	2019-11-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19717B	\N	\N
27062	1005	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14357A	\N	\N
28958	579	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14053L	\N	\N
28959	612	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14053L	\N	\N
28960	573	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19611R	\N	\N
28961	608	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19611R	\N	\N
28962	601	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19611R	\N	\N
28963	617	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19611R	\N	\N
28964	661	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19611R	\N	\N
28965	588	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19611R	\N	\N
28966	595	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19611R	\N	\N
28967	616	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19611R	\N	\N
28968	621	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19611R	\N	\N
28969	628	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19611R	\N	\N
28970	573	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20090E	\N	\N
28971	613	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20090E	\N	\N
28972	613	2020-11-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08010L	\N	\N
28973	588	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
28974	663	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20132W	\N	\N
28975	597	2020-10-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20132W	\N	\N
28976	613	2020-11-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14331P	\N	\N
29013	851	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19387D	\N	\N
29014	592	2020-11-18 00:00:00	2023-10-04 00:00:00	ANCIEN	\N	\N	\N	20056C	\N	\N
29015	592	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08018U	\N	\N
29168	582	2020-12-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14071N	\N	\N
29217	600	2020-12-10 00:00:00	2023-10-02 00:00:00	ANCIEN	\N	\N	\N	20108W	\N	\N
29218	600	2020-12-10 00:00:00	2021-07-04 00:00:00	ANCIEN	\N	\N	\N	19966S	\N	\N
29219	673	2020-12-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20052X	\N	\N
29220	647	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19725B	\N	\N
29221	613	2020-11-27 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20100N	\N	\N
29262	918	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14107H	\N	\N
29264	918	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20058E	\N	\N
29284	634	2020-12-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19503N	\N	\N
29285	644	2020-12-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19503N	\N	\N
29286	657	2020-12-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19503N	\N	\N
29287	979	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20116W	\N	\N
29288	978	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20116W	\N	\N
29289	599	2020-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19531S	\N	\N
29290	600	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19713W	\N	\N
29310	907	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20030R	\N	\N
29342	919	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14097Y	\N	\N
29378	911	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19719D	\N	\N
29399	911	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20144B	\N	\N
29412	948	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14169X	\N	\N
29413	948	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19719D	\N	\N
29414	948	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14042U	\N	\N
29510	918	2020-12-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19621T	\N	\N
29626	909	2021-01-07 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19725B	\N	\N
29627	919	2021-01-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19515S	\N	\N
29629	907	2020-12-16 00:00:00	2020-12-16 00:00:00	ANCIEN	\N	\N	\N	08061X	\N	\N
29630	907	2020-12-17 00:00:00	2020-12-17 00:00:00	ANCIEN	\N	\N	\N	01058X	\N	\N
29634	1005	2021-01-07 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19725B	\N	\N
29708	909	2021-01-13 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	05012A	\N	\N
29839	1004	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14331P	\N	\N
29841	1004	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19703U	\N	\N
29982	619	2021-01-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19762G	\N	\N
29983	619	2021-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
30195	1007	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	05008E	\N	\N
30196	1007	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14030Q	\N	\N
30197	1007	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01025N	\N	\N
30198	1007	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	04035D	\N	\N
30252	933	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	17229F	\N	\N
25772	673	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08010L	2017-12-27 11:24:20	\N
25791	530	2017-12-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14093U	2018-01-10 13:44:33	\N
25792	571	2017-12-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14133K	2018-01-10 14:02:11	\N
25843	1004	2017-12-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19553Y	\N	\N
25860	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	05008E	\N	\N
25952	578	2018-01-16 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08052W	2018-01-18 09:35:48	\N
25953	646	2018-01-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14249W	2018-01-18 09:36:07	\N
25954	633	2018-01-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14249W	2018-01-18 09:36:07	\N
25955	673	2018-01-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14026U	2018-01-18 09:38:12	\N
25956	585	2018-01-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	12041X	2018-01-18 09:39:37	\N
25957	578	2018-01-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19479G	2018-01-18 09:47:35	\N
26029	1007	2017-12-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04049K	\N	\N
26165	909	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14259Y	\N	\N
26400	911	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	16685X	\N	\N
26401	911	2017-10-01 00:00:00	2018-04-13 00:00:00	ANCIEN	\N	\N	\N	19483C	\N	2018-04-13 17:54:29
26591	908	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14053L	\N	\N
26601	852	2018-02-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14147R	2018-02-23 14:28:51	\N
26731	1006	2017-12-07 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08039A	\N	\N
26774	627	2018-05-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	10015M	2018-06-06 12:36:46	\N
26935	572	2018-12-18 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19749K	\N	\N
27835	625	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20022R	\N	\N
27836	602	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20022R	\N	\N
27837	596	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20022R	\N	\N
27838	661	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20022R	\N	\N
27839	622	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19683J	\N	\N
27840	623	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19683J	\N	\N
27841	573	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19683J	\N	\N
27842	634	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19683J	\N	\N
27843	604	2020-10-14 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	08017T	\N	\N
27844	583	2020-10-14 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	08017T	\N	\N
27845	622	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
27846	591	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
27847	651	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
27848	581	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
27849	661	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
27850	590	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
27851	663	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01043Q	\N	\N
27852	628	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19697Q	\N	\N
27853	573	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19697Q	\N	\N
27854	626	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20096L	\N	\N
27855	572	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19766L	\N	\N
27856	602	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19766L	\N	\N
27857	617	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19766L	\N	\N
27858	608	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19766L	\N	\N
27859	584	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19766L	\N	\N
27860	661	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19766L	\N	\N
27861	629	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19766L	\N	\N
27862	573	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19766L	\N	\N
27863	583	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19766L	\N	\N
27864	588	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19766L	\N	\N
27865	643	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19766L	\N	\N
27866	597	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19766L	\N	\N
27867	590	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19766L	\N	\N
27868	622	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19749K	\N	\N
27869	572	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19749K	\N	\N
27870	621	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19749K	\N	\N
27871	604	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19749K	\N	\N
27872	573	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19749K	\N	\N
27873	583	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19749K	\N	\N
27874	629	2020-10-08 00:00:00	2021-07-04 00:00:00	ANCIEN	\N	\N	\N	19966S	\N	\N
27875	641	2020-10-08 00:00:00	2021-07-04 00:00:00	ANCIEN	\N	\N	\N	19966S	\N	\N
27876	597	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20108W	\N	\N
27877	595	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	10006L	\N	\N
27878	626	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	10006L	\N	\N
27879	619	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	10006L	\N	\N
27880	651	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	10006L	\N	\N
27901	623	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19621T	\N	\N
27902	595	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19621T	\N	\N
27903	589	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19621T	\N	\N
27904	598	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19621T	\N	\N
27905	CHRETORIENT	2020-10-19 00:00:00	2023-10-05 00:00:00	ANCIEN	\N	\N	\N	19515S	\N	\N
27906	851	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
27907	610	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
27908	592	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
27909	603	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
27910	618	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
27911	634	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
27912	621	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
27913	583	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
27914	640	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
27915	623	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
27916	578	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
27917	604	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
27918	625	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
27919	584	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
27920	595	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
27921	581	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
27922	852	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
27923	577	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
27924	612	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
27925	591	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
27926	611	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
27927	647	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
27928	529	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
27929	590	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
27930	598	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
27931	616	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
27932	633	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
27933	530	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
27934	609	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
27935	605	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
27936	599	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
27937	602	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
27938	978	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11083R	\N	\N
28497	663	2020-10-19 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14205J	\N	\N
33042	590	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14251Q	\N	\N
33043	530	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14251Q	\N	\N
25824	673	2018-01-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04008A	2018-01-16 14:49:59	\N
25826	571	2018-01-09 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14151M	2018-01-16 14:58:17	\N
25862	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
25863	907	2017-10-01 00:00:00	2020-03-03 00:00:00	ANCIEN	\N	\N	\N	11081P	\N	\N
26274	919	2019-01-19 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01024M	\N	\N
26275	919	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19507S	\N	\N
26517	852	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14026U	2018-02-14 15:16:52	\N
26518	938	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19631V	\N	\N
26521	938	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	\N	\N
26619	966	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19569H	\N	\N
26700	1007	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19671E	\N	\N
26844	1005	2018-10-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
27027	623	2019-07-10 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14135M	\N	\N
27093	624	2019-11-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14261S	\N	\N
27044	909	2019-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	19820Y	\N	\N
29252	922	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14031R	\N	\N
29260	918	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20140W	\N	\N
29444	909	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14073Q	\N	\N
29445	909	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20126Y	\N	\N
29446	909	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	08015R	\N	\N
29538	911	2020-12-16 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20040T	\N	\N
29786	1008	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14038Y	\N	\N
29787	1008	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	19693L	\N	\N
29788	1008	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	14169X	\N	\N
29789	1008	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20140W	\N	\N
29790	1008	2020-10-01 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20040T	\N	\N
30108	1010	2021-02-03 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	14041T	\N	\N
30109	1010	2021-02-03 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14215L	\N	\N
30110	1010	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19507S	\N	\N
30112	1010	2021-02-03 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20038A	\N	\N
30113	1010	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	\N	\N
30130	1010	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19705W	\N	\N
30276	933	2020-10-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11097X	\N	\N
30318	623	2021-04-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	\N	\N
30371	1008	2020-10-01 00:00:00	2026-09-30 00:00:00	ACTIF	\N	\N	\N	20022R	\N	\N
30511	634	2022-01-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20124W	\N	\N
30522	673	2022-02-02 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14133K	\N	\N
30591	1013	2022-04-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11085T	\N	\N
30592	1013	2022-04-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19569H	\N	\N
30593	1013	2022-04-05 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20038A	\N	\N
30594	640	2022-03-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20096L	\N	\N
30613	556	2022-04-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20042V	\N	\N
30676	659	2022-09-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19369B	\N	\N
30689	598	2022-10-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11074Q	\N	\N
30690	659	2022-09-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14073Q	\N	\N
30696	653	2022-10-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	\N	\N
30697	620	2022-10-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19669L	\N	\N
30704	647	2022-11-10 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08061X	\N	\N
30715	922	2022-11-24 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11085T	\N	\N
30737	1014	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11067R	\N	\N
30753	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	20058E	\N	\N
30760	1014	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20138D	\N	\N
30769	1014	2023-01-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19954N	\N	\N
30772	1014	2024-01-02 00:00:00	2027-03-01 00:00:00	ACTIF	\N	\N	\N	20056C	\N	\N
30806	601	2023-02-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17737W	\N	\N
30818	597	2023-04-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20248J	\N	\N
30819	661	2023-03-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20048C	\N	\N
30825	598	2023-05-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20116W	\N	\N
30944	556	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08015R	\N	\N
30945	643	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08015R	\N	\N
30946	577	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08015R	\N	\N
30947	646	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08015R	\N	\N
30948	618	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08015R	\N	\N
30949	617	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08015R	\N	\N
30950	629	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08015R	\N	\N
30951	661	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08015R	\N	\N
30952	979	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08015R	\N	\N
30995	629	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19367Y	\N	\N
30996	621	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19367Y	\N	\N
30997	595	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19367Y	\N	\N
31067	618	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19421M	\N	\N
31068	588	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19421M	\N	\N
31069	596	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19421M	\N	\N
31070	622	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19421M	\N	\N
31434	663	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	01034P	\N	\N
31483	571	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14059S	\N	\N
31493	978	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14329V	\N	\N
31494	591	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14329V	\N	\N
31495	663	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14329V	\N	\N
31496	979	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14329V	\N	\N
31505	661	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19695N	\N	\N
31506	578	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19695N	\N	\N
31507	576	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19695N	\N	\N
31508	978	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19695N	\N	\N
31509	573	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19695N	\N	\N
31510	590	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19695N	\N	\N
31511	589	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19695N	\N	\N
31512	632	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19695N	\N	\N
31513	663	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19695N	\N	\N
31514	651	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19695N	\N	\N
31515	596	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19695N	\N	\N
31516	572	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19695N	\N	\N
31517	979	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19695N	\N	\N
31518	575	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19695N	\N	\N
31519	574	2023-10-11 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19695N	\N	\N
31730	616	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20060X	\N	\N
31731	578	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20060X	\N	\N
31732	598	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20060X	\N	\N
31733	663	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20060X	\N	\N
31734	573	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20060X	\N	\N
31735	596	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20060X	\N	\N
31736	576	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20060X	\N	\N
31737	581	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20060X	\N	\N
31739	575	2023-10-13 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21041Y	\N	\N
31756	586	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19551W	\N	\N
31757	613	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19551W	\N	\N
25040	598	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11090Q	2017-11-03 11:05:49	\N
25041	573	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11090Q	2017-11-03 11:06:06	\N
25042	644	2017-10-31 00:00:00	2017-11-08 00:00:00	ANCIEN	\N	\N	\N	11090Q	2017-11-03 11:06:06	2017-11-08 09:28:00
25286	629	2017-11-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	19737F	2017-11-16 17:09:16	\N
25287	643	2017-11-14 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	19737F	2017-11-16 17:09:16	\N
25367	640	2017-11-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14265W	2017-11-20 15:24:02	\N
25368	529	2017-11-17 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14265W	2017-11-20 15:24:02	\N
25369	609	2017-11-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14225N	2017-11-20 15:44:30	\N
25370	595	2017-11-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14225N	2017-11-20 15:44:30	\N
25371	643	2017-11-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14225N	2017-11-20 15:44:30	\N
25372	625	2017-11-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14225N	2017-11-20 15:44:30	\N
25373	584	2017-11-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14225N	2017-11-20 15:44:30	\N
25374	623	2017-11-20 00:00:00	2018-05-23 00:00:00	ANCIEN	\N	\N	\N	14225N	2017-11-20 15:44:30	2018-05-24 10:57:56
25594	617	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08009T	2017-12-08 09:45:02	\N
25595	659	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08009T	2017-12-08 09:45:02	\N
25596	619	2017-12-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08024S	2017-12-08 09:45:37	\N
25597	651	2017-12-06 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08024S	2017-12-08 09:45:37	\N
25966	586	2018-01-17 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19721W	2018-01-19 09:42:58	\N
26385	911	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
26386	911	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19643A	\N	\N
26387	911	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08020N	\N	\N
26389	911	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	18083K	\N	\N
26394	911	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	08045X	\N	\N
26395	911	2017-10-01 00:00:00	2020-06-24 00:00:00	ANCIEN	\N	\N	\N	19727D	\N	\N
26396	911	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14033T	\N	\N
26417	909	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14159V	\N	\N
26468	918	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14265W	\N	\N
26508	908	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14031R	\N	\N
26513	908	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14051J	\N	\N
26558	933	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14059S	\N	\N
26559	933	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19349W	\N	\N
26577	933	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11097X	\N	\N
26644	1006	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14073Q	\N	\N
26754	928	2017-04-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
26838	601	2018-10-04 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19701S	\N	\N
26845	601	2018-10-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14111D	\N	\N
26846	627	2018-10-10 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19697Q	\N	\N
26990	909	2018-10-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14357A	\N	\N
27008	627	2019-04-05 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04034C	\N	\N
27009	1008	2018-01-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04043D	\N	\N
27018	912	2019-05-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19762G	\N	\N
27068	623	2020-01-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19543W	\N	\N
27226	663	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
27227	602	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
27228	610	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
27229	583	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
27230	659	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
27231	653	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
27232	608	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
27233	597	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
27234	576	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
27235	633	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
27236	550	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
27237	626	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
27238	661	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
27239	605	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
27240	623	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
27241	979	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
27242	534	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
27243	577	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
27244	618	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
27245	622	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
27246	598	2020-10-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08056B	\N	\N
28498	589	2020-10-28 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20090E	\N	\N
28864	556	2020-11-04 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19563B	\N	\N
28865	978	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11012A	\N	\N
28866	609	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11012A	\N	\N
28867	610	2020-11-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11012A	\N	\N
28949	633	2020-11-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20092G	\N	\N
28977	963	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14221J	\N	\N
28978	612	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20038A	\N	\N
28979	613	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14071N	\N	\N
28980	644	2020-11-17 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14071N	\N	\N
29022	594	2020-11-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08028W	\N	\N
29023	556	2020-11-20 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08009T	\N	\N
29024	579	2020-11-18 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14267Y	\N	\N
29248	922	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	01024M	\N	\N
29249	922	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20124W	\N	\N
29250	922	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19387D	\N	\N
29251	922	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14213J	\N	\N
29253	908	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20104S	\N	\N
29254	908	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	08045X	\N	\N
29255	908	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19599P	\N	\N
29256	908	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20180F	\N	\N
29257	908	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14213J	\N	\N
29258	908	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14031R	\N	\N
29259	908	2020-12-15 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14331P	\N	\N
29380	911	2020-12-15 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	08034U	\N	\N
29479	911	2020-12-18 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	08012N	\N	\N
29507	912	2020-12-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11115U	\N	\N
29523	909	2020-12-18 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	04092N	\N	\N
29566	907	2020-12-23 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20076G	\N	\N
29568	621	2020-12-09 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19553Y	\N	\N
29611	530	2021-01-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19739H	\N	\N
29612	532	2021-01-06 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11026G	\N	\N
29638	918	2021-01-07 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20066E	\N	\N
29639	908	2021-01-07 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20138D	\N	\N
29699	911	2021-01-13 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14026U	\N	\N
29700	912	2021-01-13 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14026U	\N	\N
29715	906	2021-01-13 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14031R	\N	\N
29730	575	2021-01-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19563B	\N	\N
29737	911	2021-01-11 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19383Y	\N	\N
29763	912	2021-01-11 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20122U	\N	\N
24973	604	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19515S	2017-11-02 09:53:37	\N
24974	621	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19515S	2017-11-02 09:53:37	\N
24975	584	2017-10-30 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19515S	2017-11-02 09:53:37	\N
24976	625	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11056N	2017-11-02 09:54:02	\N
24977	642	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11056N	2017-11-02 09:54:03	\N
24978	575	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11056N	2017-11-02 09:54:03	\N
24979	591	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11056N	2017-11-02 09:54:03	\N
24980	608	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11056N	2017-11-02 09:54:03	\N
24981	651	2017-10-31 00:00:00	2020-06-27 00:00:00	ANCIEN	\N	\N	\N	14199E	2017-11-02 09:54:42	\N
24982	618	2017-11-02 00:00:00	2020-06-27 00:00:00	ANCIEN	\N	\N	\N	14199E	2017-11-02 09:56:23	\N
24983	613	2017-11-02 00:00:00	2020-06-27 00:00:00	ANCIEN	\N	\N	\N	14199E	2017-11-02 09:56:23	\N
24984	653	2017-11-02 00:00:00	2020-06-27 00:00:00	ANCIEN	\N	\N	\N	14199E	2017-11-02 09:56:23	\N
24985	601	2017-11-02 00:00:00	2020-06-27 00:00:00	ANCIEN	\N	\N	\N	14199E	2017-11-02 09:56:23	\N
24986	616	2017-11-02 00:00:00	2020-06-27 00:00:00	ANCIEN	\N	\N	\N	14199E	2017-11-02 09:56:23	\N
24987	609	2017-11-02 00:00:00	2020-06-27 00:00:00	ANCIEN	\N	\N	\N	14199E	2017-11-02 09:56:23	\N
24988	590	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19347U	2017-11-02 09:56:55	\N
24989	575	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19347U	2017-11-02 09:56:55	\N
24990	596	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19347U	2017-11-02 09:56:55	\N
24991	573	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19347U	2017-11-02 09:56:55	\N
24992	576	2017-11-02 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19347U	2017-11-02 09:57:29	\N
24993	583	2017-11-02 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19347U	2017-11-02 09:57:29	\N
24994	571	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19551W	2017-11-02 10:00:50	\N
24995	613	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19551W	2017-11-02 10:00:50	\N
24996	625	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19551W	2017-11-02 10:00:50	\N
24997	627	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19551W	2017-11-02 10:00:50	\N
24998	580	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19551W	2017-11-02 10:00:50	\N
24999	586	2017-10-26 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19551W	2017-11-02 10:00:50	\N
25000	659	2017-10-31 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08031R	2017-11-02 10:02:34	\N
25001	598	2017-10-31 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08031R	2017-11-02 10:02:34	\N
25002	621	2017-10-31 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08031R	2017-11-02 10:02:34	\N
25003	589	2017-10-31 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08031R	2017-11-02 10:02:34	\N
25004	618	2017-10-31 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08031R	2017-11-02 10:02:34	\N
25005	576	2017-10-31 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08031R	2017-11-02 10:02:34	\N
25006	594	2017-10-31 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08031R	2017-11-02 10:02:34	\N
25007	626	2017-10-31 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08031R	2017-11-02 10:02:34	\N
25008	979	2017-10-31 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08031R	2017-11-02 10:02:34	\N
25009	617	2017-10-31 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08031R	2017-11-02 10:02:34	\N
25010	590	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19289C	2017-11-02 10:03:00	\N
25011	595	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19289C	2017-11-02 10:03:00	\N
25012	601	2017-10-31 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19289C	2017-11-02 10:03:00	\N
25013	583	2017-10-27 00:00:00	2018-04-03 00:00:00	ANCIEN	\N	\N	\N	08019V	2017-11-02 10:04:10	2018-04-03 14:56:24
25014	634	2017-10-27 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08019V	2017-11-02 10:04:10	\N
25015	590	2017-10-31 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14235Q	2017-11-02 10:07:04	\N
25016	632	2017-10-31 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14235Q	2017-11-02 10:07:04	\N
25017	620	2017-10-31 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14235Q	2017-11-02 10:07:04	\N
25018	575	2017-10-31 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14235Q	2017-11-02 10:07:04	\N
25019	556	2017-11-02 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	11063M	2017-11-02 10:20:31	\N
25020	598	2017-11-02 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	11063M	2017-11-02 10:20:31	\N
25021	632	2017-11-02 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	11063M	2017-11-02 10:20:31	\N
25022	978	2017-11-02 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	11063M	2017-11-02 10:20:31	\N
25023	642	2017-11-02 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	11063M	2017-11-02 10:20:31	\N
25024	626	2017-11-02 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	11063M	2017-11-02 10:20:31	\N
25025	628	2017-11-02 00:00:00	2018-06-30 00:00:00	ANCIEN	\N	\N	\N	11063M	2017-11-02 10:20:31	\N
25251	573	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	96004D	2017-11-14 16:06:37	\N
25252	661	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	96004D	2017-11-14 16:06:37	\N
25253	598	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14213J	2017-11-14 16:06:54	\N
25254	583	2017-11-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14213J	2017-11-14 16:06:54	\N
25805	934	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08031R	\N	\N
25806	934	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14081Q	\N	\N
25812	578	2018-01-15 00:00:00	2018-11-03 00:00:00	ANCIEN	\N	\N	\N	19251M	2018-01-15 12:50:52	\N
25827	578	2018-01-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14225N	2018-01-16 17:14:49	\N
26098	928	2017-10-01 00:00:00	2020-06-24 00:00:00	ANCIEN	\N	\N	\N	19727D	\N	\N
26099	928	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14026U	\N	\N
26100	928	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	19691J	\N	\N
26101	928	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	19333N	\N	\N
26104	928	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	19657G	\N	\N
26514	908	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14157T	\N	\N
26545	852	2018-02-14 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	97011G	2018-02-16 09:29:16	\N
26885	909	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04045F	\N	\N
26937	957	2017-10-01 00:00:00	2017-10-01 00:00:00	ANCIEN	\N	\N	\N	08028W	\N	\N
26982	911	2019-02-13 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
27099	623	2020-07-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11072N	\N	\N
29608	909	2021-01-04 00:00:00	2022-06-20 00:00:00	ANCIEN	\N	\N	\N	20174H	\N	\N
29740	919	2021-01-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11065P	\N	\N
29756	909	2021-01-14 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14207L	\N	\N
29986	907	2021-01-20 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20032T	\N	\N
29988	948	2021-01-20 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20032T	\N	\N
29989	909	2021-01-20 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	20032T	\N	\N
30340	1012	2021-06-09 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14213J	\N	\N
30485	615	2021-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19489J	\N	\N
30486	657	2021-12-08 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19647E	\N	\N
30567	530	2022-03-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11066Q	\N	\N
30568	530	2022-03-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19723Y	\N	\N
30569	1013	2022-04-01 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	17737W	\N	\N
30570	1013	2022-03-30 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19593H	\N	\N
30812	589	2023-03-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20264J	\N	\N
30813	609	2023-03-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20264J	\N	\N
30814	581	2023-03-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20264J	\N	\N
31570	556	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20118Y	\N	\N
31571	1013	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20118Y	\N	\N
31572	640	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20118Y	\N	\N
31573	530	2023-10-12 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20118Y	\N	\N
33041	673	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21061D	\N	\N
33046	597	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19545Y	\N	\N
33047	979	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19545Y	\N	\N
33048	629	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19545Y	\N	\N
33049	556	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19545Y	\N	\N
33050	596	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19545Y	\N	\N
33051	643	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19545Y	\N	\N
33052	623	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19545Y	\N	\N
33053	661	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19545Y	\N	\N
33054	621	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19545Y	\N	\N
33055	529	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19545Y	\N	\N
33056	651	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19545Y	\N	\N
33057	602	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19545Y	\N	\N
33058	588	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19545Y	\N	\N
33059	594	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19545Y	\N	\N
33060	550	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19545Y	\N	\N
33063	653	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14147R	\N	\N
33064	578	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14257W	\N	\N
33066	673	2023-11-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	21095P	\N	\N
25614	626	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14073Q	2017-12-13 09:45:54	\N
25615	608	2017-12-06 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	07033P	2017-12-13 09:46:12	\N
25616	963	2017-12-04 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19629C	2017-12-13 09:46:57	\N
25617	657	2017-12-12 00:00:00	2020-01-15 00:00:00	ANCIEN	\N	\N	\N	19591F	2017-12-13 09:47:31	\N
25618	613	2017-12-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04043D	2017-12-13 09:47:51	\N
25655	604	2017-12-15 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19575F	2017-12-19 15:21:08	\N
25987	550	2018-01-24 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14169X	2018-01-24 09:27:26	2018-01-24 15:04:34
25988	CHRETORIENT	2018-01-23 00:00:00	2023-10-05 00:00:00	ANCIEN	\N	\N	\N	19643A	2018-01-24 09:39:30	\N
26148	909	2017-10-01 00:00:00	2020-06-27 00:00:00	ANCIEN	\N	\N	\N	14199E	\N	\N
26168	907	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04089T	\N	\N
26390	911	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	17589D	\N	\N
26421	909	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14219Q	\N	\N
26450	919	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01062T	\N	\N
26583	933	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	\N	\N
26603	647	2018-02-08 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	01043Q	2018-02-23 16:08:41	\N
26604	585	2018-02-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14107H	2018-02-23 16:13:00	\N
26605	578	2018-02-22 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	2018-02-23 16:38:23	\N
26616	918	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14187A	\N	\N
26617	918	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14179A	\N	\N
26706	1007	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19515S	\N	\N
26708	1007	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	\N	\N
26710	1007	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	04057K	\N	\N
26711	1007	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19745F	\N	\N
26712	1007	2017-12-07 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19735D	\N	\N
26718	571	2018-03-20 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19413M	2018-03-21 12:29:35	\N
26740	598	2018-03-29 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14133K	2018-04-05 14:52:13	\N
26790	627	2018-07-04 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11033F	\N	\N
26806	609	2018-02-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19569H	\N	\N
26807	661	2018-02-28 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19569H	\N	\N
27758	589	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20116W	\N	\N
27759	602	2020-10-12 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19383Y	\N	\N
27760	590	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20120S	\N	\N
27761	629	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20120S	\N	\N
27762	979	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20120S	\N	\N
27763	577	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	20120S	\N	\N
27764	604	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14026U	\N	\N
27765	629	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14026U	\N	\N
27766	580	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14026U	\N	\N
27767	609	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14026U	\N	\N
27768	598	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	98022P	\N	\N
27769	585	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14001X	\N	\N
27770	591	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14001X	\N	\N
27771	621	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14001X	\N	\N
27772	651	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14001X	\N	\N
27773	589	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14001X	\N	\N
27774	978	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14001X	\N	\N
27775	578	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14001X	\N	\N
27776	643	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14001X	\N	\N
27777	661	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19573D	\N	\N
27778	621	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19573D	\N	\N
27779	590	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19573D	\N	\N
27780	608	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19573D	\N	\N
27781	595	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19573D	\N	\N
27782	674	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19762G	\N	\N
27783	613	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19762G	\N	\N
27784	595	2020-10-14 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19762G	\N	\N
28020	588	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28021	626	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28022	609	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28023	610	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28024	653	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28025	580	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28026	618	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28027	572	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28028	592	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28029	647	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28030	583	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28031	599	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28032	617	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28033	598	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28034	589	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28035	674	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28036	613	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28037	979	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28038	602	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28039	601	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28040	577	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28041	651	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28042	621	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28043	595	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28044	605	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28045	661	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28046	600	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28047	582	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28048	586	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28049	640	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28050	591	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28051	646	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28052	643	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28053	978	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28054	616	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28055	573	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28056	576	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28057	574	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28058	578	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28059	659	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28060	622	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28061	575	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28062	579	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28063	641	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28064	663	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28065	581	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28066	633	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
28067	963	2020-10-16 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14255U	\N	\N
24881	598	2017-10-26 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	2017-10-31 09:57:45	\N
25465	556	2017-11-23 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14327T	2017-11-27 11:24:00	\N
25466	594	2017-11-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19629C	2017-11-27 11:26:52	\N
25864	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	96004D	\N	\N
25865	907	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14069U	\N	\N
25885	907	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14103D	\N	\N
26097	928	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	08048B	\N	\N
26102	928	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	14213J	\N	\N
26113	928	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04033B	\N	\N
26453	918	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19631V	\N	\N
26456	918	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19621T	\N	\N
26457	918	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11101A	\N	\N
26458	918	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19629C	\N	\N
26459	918	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14038Y	\N	\N
26461	918	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11056N	\N	\N
26462	918	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14327T	\N	\N
26464	918	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	11110B	\N	\N
26465	918	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	97011G	\N	\N
26469	918	2017-10-01 00:00:00	2020-09-30 00:00:00	ANCIEN	\N	\N	\N	04088S	\N	\N
26515	911	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19447X	\N	\N
26733	909	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19441R	\N	\N
26921	957	2017-10-01 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
26971	911	2019-02-14 00:00:00	2019-02-15 00:00:00	ANCIEN	\N	\N	\N	11045K	\N	\N
27002	582	2019-03-25 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	14041T	\N	\N
27070	617	2020-01-16 00:00:00	2020-10-01 00:00:00	ANCIEN	\N	\N	\N	19333N	\N	\N
27739	588	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14193X	\N	\N
27740	610	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14193X	\N	\N
27741	621	2020-10-13 00:00:00	2020-12-09 00:00:00	ANCIEN	\N	\N	\N	14193X	\N	\N
27742	584	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14193X	\N	\N
27743	623	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14193X	\N	\N
27744	596	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14193X	\N	\N
27745	589	2020-10-13 00:00:00	2021-10-25 00:00:00	ANCIEN	\N	\N	\N	20036X	\N	\N
27746	580	2020-10-13 00:00:00	2021-10-25 00:00:00	ANCIEN	\N	\N	\N	20036X	\N	\N
27747	621	2020-10-13 00:00:00	2022-09-12 00:00:00	ANCIEN	\N	\N	\N	20036X	\N	\N
27748	643	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19585H	\N	\N
27749	661	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19585H	\N	\N
27750	622	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19585H	\N	\N
27751	651	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19585H	\N	\N
27752	642	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19585H	\N	\N
27753	576	2020-10-13 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19585H	\N	\N
28326	609	2020-10-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	05008E	\N	\N
28327	530	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08009T	\N	\N
28328	618	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08009T	\N	\N
28329	574	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08009T	\N	\N
28330	622	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08009T	\N	\N
28331	598	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08009T	\N	\N
28332	659	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08009T	\N	\N
28333	609	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08009T	\N	\N
28334	583	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08009T	\N	\N
28335	584	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08009T	\N	\N
28336	661	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08009T	\N	\N
28337	595	2020-10-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	08009T	\N	\N
29129	579	2020-11-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14097Y	\N	\N
29130	556	2020-11-26 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14169X	\N	\N
29657	922	2021-01-08 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	19575F	\N	\N
29967	919	2021-01-21 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	18083K	\N	\N
29968	919	2021-01-21 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14211G	\N	\N
30071	918	2021-01-19 00:00:00	2023-09-30 00:00:00	ANCIEN	\N	\N	\N	14189C	\N	\N
30101	1010	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	11027H	\N	\N
30105	1010	2021-02-03 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19693L	\N	\N
30106	1010	2021-02-03 00:00:00	2021-09-30 00:00:00	ANCIEN	\N	\N	\N	98018T	\N	\N
30144	648	2021-01-22 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14083S	\N	\N
30408	571	2021-10-07 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19713W	\N	\N
30667	615	2022-01-25 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	14229S	\N	\N
30668	530	2022-03-29 00:00:00	2023-10-01 00:00:00	ANCIEN	\N	\N	\N	19503N	\N	\N
31022	573	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19683J	\N	\N
31023	623	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19683J	\N	\N
31024	622	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19683J	\N	\N
31025	634	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19683J	\N	\N
31026	572	2023-10-09 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19683J	\N	\N
31758	580	2023-10-16 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	19551W	\N	\N
31808	577	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08045X	\N	\N
31809	633	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08045X	\N	\N
31810	618	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08045X	\N	\N
31811	651	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08045X	\N	\N
31812	571	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08045X	\N	\N
31867	661	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14169X	\N	\N
31868	623	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14169X	\N	\N
31869	576	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14169X	\N	\N
31870	600	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14169X	\N	\N
31871	629	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14169X	\N	\N
31872	581	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14169X	\N	\N
31873	621	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14169X	\N	\N
31874	601	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14169X	\N	\N
31875	556	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14169X	\N	\N
31876	583	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14169X	\N	\N
31937	651	2023-10-17 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	08018U	\N	\N
31987	573	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	12028B	\N	\N
31988	641	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	12028B	\N	\N
31989	572	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	12028B	\N	\N
31990	617	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	12028B	\N	\N
31991	575	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	12028B	\N	\N
31992	588	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	12028B	\N	\N
32042	604	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20038A	\N	\N
32043	612	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20038A	\N	\N
32044	651	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20038A	\N	\N
32045	556	2023-10-18 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	20038A	\N	\N
32151	597	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14237S	\N	\N
32152	610	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14237S	\N	\N
32153	651	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14237S	\N	\N
32154	623	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14237S	\N	\N
32155	572	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14237S	\N	\N
32156	530	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14237S	\N	\N
32157	622	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14237S	\N	\N
32158	618	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14237S	\N	\N
32159	659	2023-10-19 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14237S	\N	\N
32290	674	2023-10-24 00:00:00	2026-10-01 00:00:00	ACTIF	\N	\N	\N	14281W	\N	\N
\.


--
-- Data for Name: memorg; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY memorg (memorgid, senmat, orgcod, temvalcod, evelic, evelib, evelil, eveobs, memorgdatdeb, memorganndeb, memorgdatfin, memorgannfin, designcod, syscredat, sysmajdat) FROM stdin;
179	08021P	CES	ANCIEN	\N	\N	\N	\N	1999-04-01 00:00:00	1999	2004-03-31 00:00:00	2004	MEMBRE	\N	\N
69	95059Q	DCRUE	ANCIEN	\N	Membre de la délégation au Comité des régions de l'UE	Membre de la délégation au Comité des régions de l'Union européenne	Membre de la délégation au Comité des régions de l'Union européenne	2002-02-01 00:00:00	\N	2017-10-05 00:00:00	2002	MEMBRE	\N	2017-10-05 09:30:52
175	08046Y	CES	ANCIEN	\N	\N	Membre	\N	\N	1998	\N	2004	MEMBRE	\N	\N
71	98048A	DCRUE	ANCIEN	\N	Membre de la délégation au Comité des régions de l'UE	Membre de la délégation au Comité des régions de l'Union européenne	Membre de la délégation au Comité des régions de l'Union européenne	2002-02-01 00:00:00	\N	2022-10-17 00:00:00	\N	MEMBRE	\N	\N
72	92017R	DCRUE	ANCIEN	\N	Membre de la délégation au Comité des régions de l'UE	Membre de la délégation au Comité des régions de l'Union européenne	Membre de la délégation au Comité des régions de l'Union européenne	2002-02-01 00:00:00	\N	2022-10-17 00:00:00	\N	MEMBRE	\N	\N
74	04065K	CES	ANCIEN	\N	\N	\N	\N	\N	2001	2014-01-01 00:00:00	2003	MEMBRE	\N	2014-09-28 17:31:42
75	04048J	CES	ANCIEN	\N	\N	\N	\N	\N	1993	2016-11-30 00:00:00	1995	MEMBRE	\N	2016-12-01 10:36:52
1	95006B	CONCST	ANCIEN	\N	\N	\N	\N	\N	1986	2024-02-09 00:00:00	1995	MEMBRE	\N	\N
2	99002P	CES	ANCIEN	\N	\N	\N	\N	\N	1989	2017-06-17 00:00:00	1994	MEMBRE	\N	2017-06-19 12:20:22
184	08017T	CES	ANCIEN	\N	\N	\N	\N	\N	2005	2021-09-30 00:00:00	2006	MEMBRE	\N	\N
186	95025E	CES	ANCIEN	\N	\N	\N	\N	\N	1974	2014-01-01 00:00:00	1994	MEMBRE	\N	2014-09-28 17:09:16
183	08012N	COMREGUE	ANCIEN	\N	\N	\N	\N	\N	2000	\N	2013	MEMBRE	\N	2013-09-06 14:39:52
185	04064J	CES	ANCIEN	\N	\N	\N	\N	\N	1991	2018-05-24 00:00:00	1999	MEMBRE	\N	2018-05-30 17:03:14
188	92017R	MEDIATEUR	ANCIEN	\N	\N	\N	\N	\N	2004	2022-03-23 00:00:00	\N	MEMBRE	\N	\N
189	66002K	MEDIATEUR	ANCIEN	\N	\N	\N	\N	1992-03-01 00:00:00	1992	1998-02-28 00:00:00	1998	MEMBRE	\N	\N
131	89023P	BASMED	ACTIF	\N	\N	\N	\N	\N	\N	\N	\N	MEMBRE	\N	\N
178	08061X	CES	ANCIEN	\N	\N	\N	\N	\N	\N	\N	2008	MEMBRE	\N	\N
\.


--
-- Data for Name: minind; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY minind (minid, senmat, typmincod, gvtid, memgvtrngprt, mindatdeb, minanndeb, mindatfin, minannfin, mincirfin, temvalcod, evelic, evelib, evelil, eveobs, titmincod, mindel, syscredat, sysmajdat, poicon) FROM stdin;
111	000206	MIN	1	\N	\N	\N	1959-01-08 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre	\N	MINISTRE	NON	\N	\N	\N
112	59550S	MIN	1	\N	1959-01-08 00:00:00	\N	1966-01-08 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre	\N	MINISTRE	NON	\N	\N	\N
113	59552U	MIN	1	\N	1977-04-01 00:00:00	\N	1978-04-06 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'Etat	\N	SECRETMIN	NON	\N	\N	\N
114	000307	MIN	1	\N	1956-02-01 00:00:00	\N	1958-05-14 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'Etat	\N	SECRETMIN	NON	\N	\N	\N
116	59556Y	MIN	1	\N	1973-04-05 00:00:00	\N	1977-03-30 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre	\N	MINISTRE	NON	\N	\N	\N
117	59242H	MIN	1	\N	1974-05-28 00:00:00	\N	1974-10-29 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'Etat	\N	SECRETMIN	NON	\N	\N	\N
118	95064M	MIN	1	\N	\N	\N	1985-04-04 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre	\N	MINISTRE	NON	\N	\N	\N
119	74044S	MIN	1	\N	\N	\N	1973-03-15 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre	\N	MINISTRE	NON	\N	\N	\N
121	59560U	MIN	1	\N	1976-01-12 00:00:00	\N	1977-09-26 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre	\N	MINISTRE	NON	\N	\N	\N
126	000105	MIN	1	\N	\N	\N	1956-02-01 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre	\N	MINISTRE	NON	\N	\N	\N
127	000057	MIN	1	\N	1957-06-17 00:00:00	\N	1957-11-06 00:00:00	\N	\N	ANCIEN	\N	\N	4ème République	\N	SECRETMIN	NON	\N	\N	\N
128	000719	MIN	1	\N	\N	\N	1957-11-06 00:00:00	\N	\N	ANCIEN	\N	\N	4ème République	\N	SECRETMIN	NON	\N	\N	\N
135	000216	MIN	1	\N	1956-02-01 00:00:00	\N	1957-06-13 00:00:00	\N	\N	ANCIEN	\N	\N	Ancien secrétaire d'Etat, 4ème République	\N	SECRETMIN	NON	\N	\N	\N
136	000455	MIN	1	\N	1968-05-31 00:00:00	\N	1981-05-22 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre	\N	MINISTRE	NON	\N	\N	\N
137	000131	MIN	1	\N	\N	\N	1958-06-01 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre, 4ème République	\N	MINISTRE	NON	\N	\N	\N
138	000732	MIN	1	\N	\N	\N	1959-05-27 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre, 4ème République	\N	MINISTRE	NON	\N	\N	\N
139	000308	MIN	1	\N	\N	\N	1966-01-08 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre	\N	MINISTRE	NON	\N	\N	\N
140	000303	MIN	1	\N	1954-06-19 00:00:00	\N	1955-02-23 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'Etat	\N	SECRETMIN	NON	\N	\N	\N
141	000025	MIN	1	\N	\N	\N	1970-10-09 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre	\N	MINISTRE	NON	\N	\N	\N
142	000379	MIN	1	\N	\N	\N	1957-06-13 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre	\N	MINISTRE	NON	\N	\N	\N
143	000677	MIN	1	\N	1937-06-22 00:00:00	\N	1938-03-13 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre sous la 3ème République	\N	MINISTRE	NON	\N	\N	\N
144	57135W	MIN	1	\N	\N	\N	1955-02-23 00:00:00	\N	\N	ANCIEN	\N	\N	Ancien ministre	\N	MINISTRE	NON	\N	\N	\N
145	000027	MIN	1	\N	\N	\N	1957-11-06 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre	\N	MINISTRE	NON	\N	\N	\N
146	000736	MIN	1	\N	\N	\N	1947-10-22 00:00:00	\N	\N	ANCIEN	\N	\N	Ancien ministre 3ème et 4ème République	\N	MINISTRE	NON	\N	\N	\N
148	000158	MIN	1	\N	\N	\N	1958-06-01 00:00:00	\N	\N	ANCIEN	\N	\N	4 ème République	\N	MINISTRE	NON	\N	\N	\N
150	000417	MIN	1	\N	1974-05-28 00:00:00	\N	1976-08-27 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'État	\N	SECRETMIN	NON	\N	\N	\N
151	000268	MIN	1	\N	1949-10-29 00:00:00	\N	1950-07-12 00:00:00	\N	\N	ANCIEN	\N	\N	Ancien ministre IVème République	\N	MINISTRE	NON	\N	\N	\N
167	02053W	DEFENSE	1	\N	1997-06-04 00:00:00	1997	2000-03-27 00:00:00	2000	\N	ANCIEN	\N	\N	Ministre de l'intérieur	\N	MINISTRE	NON	\N	2016-12-08 17:45:55	\N
173	000135	MIN	1	\N	\N	\N	1957-06-13 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'État, 4ème République	\N	SECRETMIN	NON	\N	\N	\N
174	000574	COMMERCE	1	\N	1976-08-27 00:00:00	\N	1977-03-30 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre du commerce et de l'artisanat	\N	MINISTRE	NON	\N	\N	\N
175	000490	MIN	1	\N	1969-06-22 00:00:00	\N	1972-07-06 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'État	\N	SECRETMIN	NON	\N	\N	\N
176	000298	DEFENSE	1	\N	1974-05-28 00:00:00	\N	1975-01-31 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre de la défense	\N	MINISTRE	NON	\N	\N	\N
177	57321W	AGRICULTURE	1	\N	1961-08-24 00:00:00	\N	1966-01-08 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre de l'agriculture 	\N	MINISTRE	NON	\N	\N	\N
178	57321W	MIN	1	\N	1966-01-08 00:00:00	\N	1967-04-28 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre de l'équipement 	\N	MINISTRE	NON	\N	\N	\N
179	58328J	EDUCATION	1	\N	\N	1956	\N	1958	\N	ANCIEN	\N	\N	Ministre de l'éducation nationale 	\N	MINISTRE	NON	\N	\N	\N
180	000099	MIN	1	\N	1957-11-06 00:00:00	\N	1958-06-01 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre	\N	MINISTRE	NON	\N	\N	\N
181	000061	MIN	1	\N	1956-02-01 00:00:00	\N	1957-11-06 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'Etat	\N	SECRETMIN	NON	\N	\N	\N
182	000763	MIN	1	\N	1951-08-11 00:00:00	\N	1954-06-19 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'Etat	\N	MINISTRE	NON	\N	\N	\N
183	000738	MIN	1	\N	1947-01-22 00:00:00	\N	1947-05-04 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre	\N	MINISTRE	NON	\N	\N	\N
185	74041P	MIN	1	\N	\N	1981	\N	1983	\N	ANCIEN	\N	\N	Ministre de l'urbanisme et du logement	\N	MINISTRE	NON	\N	\N	\N
186	01048V	MIN	1	\N	1986-03-20 00:00:00	\N	1986-08-19 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'Etat chargé des PTT	\N	SECRETMIN	NON	\N	2016-12-12 14:50:41	\N
189	59715V	MIN	1	\N	\N	\N	1974-05-28 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre 	\N	MINISTRE	NON	\N	\N	\N
191	77053G	INTERIEUR	1	\N	1993-03-30 00:00:00	1993	1995-05-11 00:00:00	1995	\N	ANCIEN	\N	\N	Ministre de l'intérieur et de l'aménagement du territoire	\N	MINISTRE	NON	\N	\N	\N
192	86034E	TRAVAIL	3	25	2004-03-31 00:00:00	\N	2004-11-29 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre délégué aux relations du travail, auprès du ministre de l'emploi, du travail et de la cohésion sociale 	\N	MINDEL	OUI	\N	\N	\N
193	95051G	TRAVAIL	3	26	2004-03-31 00:00:00	2004	2004-10-28 00:00:00	2004	\N	ANCIEN	\N	\N	Ministre delegue a la lutte contre la precarite et l'exclusion, aupres du ministre de l'emploi, du travail et de la cohesion sociale	\N	MINDEL	OUI	\N	2016-12-09 10:58:56	\N
194	98025S	ENVIRON	3	13	2004-03-31 00:00:00	\N	2004-11-28 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre de l'écologie et du développement durable	\N	MINISTRE	NON	\N	\N	\N
198	02009S	EDUCATION	3	3	2004-03-31 00:00:00	2004	2004-11-28 00:00:00	2004	\N	ANCIEN	\N	\N	Ministre de l'éducation nationale, de l'enseignement supérieur et de la recherche	\N	MINISTRE	NON	\N	2016-12-08 18:57:14	\N
203	95008D	ETRANGER	3	8	2004-03-31 00:00:00	\N	2004-11-28 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre des affaires étrangères	\N	MINISTRE	NON	\N	\N	\N
217	95059Q	PREMIN	3	1	2004-03-31 00:00:00	\N	2004-11-28 00:00:00	\N	\N	ANCIEN	\N	\N	Premier ministre	\N	PREMIN	NON	\N	\N	\N
221	98031Q	COOPERATION	3	29	2004-03-31 00:00:00	2004	2004-11-28 00:00:00	2004	\N	ANCIEN	\N	\N	Ministre délégué à la coopération, au développement et à la francophonie	\N	MINDEL	OUI	\N	2016-12-09 08:48:20	\N
222	95031C	MIN	3	30	2004-03-31 00:00:00	2004	2004-10-28 00:00:00	2004	\N	ANCIEN	\N	\N	Ministre délégué aux personnes âgées	\N	MINDEL	OUI	\N	\N	\N
228	04008A	MIN	3	36	2004-03-31 00:00:00	2004	2004-10-28 00:00:00	2004	\N	ANCIEN	\N	\N	Secrétaire d'État au logement	\N	SECRETMIN	NON	\N	\N	\N
1	95050F	MIN	1	\N	1986-03-20 00:00:00	1986	1988-05-10 00:00:00	1988	\N	ANCIEN	\N	\N	Secretaire d'Etat francophonie	\N	SECRETMIN	NON	\N	2016-12-13 10:37:02	\N
2	68036E	COMMERCE	1	\N	1977-03-20 00:00:00	1977	1978-03-31 00:00:00	1978	\N	ANCIEN	\N	\N	Ministre de l'industrie, du commerce et de l'artisanat	\N	MINISTRE	NON	\N	\N	\N
4	77058M	MIN	1	\N	1972-07-05 00:00:00	1972	1973-03-28 00:00:00	1973	\N	ANCIEN	\N	\N	Secretaire d'Etat aupres du ministere d'Etat, charge des affaires sociales.	\N	SECRETMIN	NON	\N	2016-12-12 10:08:00	\N
5	77017C	MIN	1	\N	1981-05-22 00:00:00	\N	1981-06-23 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'Etat	\N	SECRETMIN	NON	\N	\N	\N
6	95060H	MIN	1	\N	1981-06-22 00:00:00	1981	1983-03-22 00:00:00	1983	\N	ANCIEN	\N	\N	Ministre de la sante	\N	MINISTRE	NON	\N	2016-12-13 14:50:05	\N
7	86010V	MIN	1	\N	1984-07-23 00:00:00	1984	1986-03-20 00:00:00	1986	\N	ANCIEN	\N	\N	Secrétaire d'Etat auprès du Ministre des Relations extérieures	\N	SECRETMIN	NON	\N	2017-03-13 10:29:46	\N
8	95008D	ENVIRON	1	\N	1993-03-30 00:00:00	1993	1995-05-11 00:00:00	1995	\N	ANCIEN	\N	\N	Ministre de l'environnement	\N	MINISTRE	NON	\N	2017-03-13 10:27:11	\N
9	95054K	MIN	1	\N	\N	\N	1981-05-22 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre	\N	MINISTRE	NON	\N	\N	\N
10	81015E	BUDGET	1	\N	1988-06-28 00:00:00	1988	1991-05-15 00:00:00	1991	\N	ANCIEN	\N	\N	Ministre delegue charge du Budget	\N	MINDEL	NON	\N	2016-12-08 19:36:48	\N
11	83008P	MIN	1	\N	1981-05-22 00:00:00	\N	1983-03-24 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'Etat	\N	MINISTRE	NON	\N	\N	\N
12	95026F	MIN	1	\N	1977-04-01 00:00:00	\N	1981-05-22 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'Etat	\N	SECRETMIN	NON	\N	\N	\N
13	77046H	MIN	1	\N	\N	\N	1968-07-10 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre	\N	MINISTRE	NON	\N	\N	\N
14	74042Q	MIN	1	\N	1988-06-28 00:00:00	1988	1991-05-15 00:00:00	1991	\N	ANCIEN	\N	\N	Ministre du commerce exterieur	\N	MINISTRE	NON	\N	2016-12-09 11:00:53	\N
16	92037V	PREMIN	1	\N	1981-05-21 00:00:00	\N	1984-07-17 00:00:00	\N	\N	ANCIEN	\N	\N	Premier ministre	\N	PREMIN	NON	\N	\N	\N
17	83011J	SOCIAL	1	\N	1986-03-20 00:00:00	1986	1987-01-20 00:00:00	1987	\N	ANCIEN	\N	\N	Secritaire d'etat du ministre des Affaires sociales et de l'Emploi	\N	SECRETMIN	NON	\N	2016-12-14 10:46:47	\N
18	83016P	MIN	1	\N	1972-07-06 00:00:00	1972	1973-03-28 00:00:00	1973	\N	ANCIEN	\N	\N	Secretaire d'Etat aupres du ministere de l'equipement,du logement et de l'amenagement du territoire.	\N	SECRETMIN	NON	\N	2016-12-12 17:15:25	\N
19	83012K	MIN	1	\N	1981-05-22 00:00:00	1981	1981-06-22 00:00:00	1981	\N	ANCIEN	\N	\N	Secretaire d'Etat  chargi de la securite sociale	\N	SECRETMIN	NON	\N	2017-03-13 10:24:26	\N
21	95006B	JUSTICE	1	\N	1981-06-23 00:00:00	1981	1983-03-22 00:00:00	1983	\N	ANCIEN	\N	\N	Garde des Sceaux	\N	GARSCEAUX	NON	\N	2017-03-13 10:25:41	\N
22	77019E	MIN	1	\N	1974-05-28 00:00:00	1974	1976-08-25 00:00:00	1976	\N	ANCIEN	\N	\N	Ministre de l'economie et des finances	\N	MINISTRE	NON	\N	2016-12-09 11:14:40	\N
24	80011V	MIN	1	\N	\N	\N	1980-10-02 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre	\N	MINISTRE	NON	\N	\N	\N
25	80046H	MIN	1	\N	1987-01-20 00:00:00	\N	1988-05-10 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre	\N	MINISTRE	NON	\N	\N	\N
26	80045G	MIN	1	\N	1973-03-28 00:00:00	1973	1973-10-23 00:00:00	1973	\N	ANCIEN	\N	\N	Secretaire d'Etat aupres du ministre du developpement industriel	\N	SECRETMIN	NON	\N	2016-12-09 11:08:54	\N
27	74050Q	MIN	1	\N	1981-05-22 00:00:00	\N	1986-03-20 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'Etat	\N	MINISTRE	NON	\N	\N	\N
28	80035E	AGRICULTURE	1	\N	1993-03-30 00:00:00	1993	1995-05-11 00:00:00	1995	\N	ANCIEN	\N	\N	Ministre de l'agriculture et de la pêche 	\N	MINISTRE	NON	\N	2016-12-12 09:58:05	\N
29	86010V	INTERIEUR	1	\N	1988-06-28 00:00:00	1988	1990-07-17 00:00:00	1990	\N	ANCIEN	\N	\N	Secrétaire d'Etat auprès du Ministre de l'Intérieur, chargé des collectivités territoriales	\N	SECRETMIN	NON	\N	2017-03-13 10:29:55	\N
30	77017C	MIN	1	\N	1991-05-17 00:00:00	\N	1993-03-30 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre	\N	MINISTRE	NON	\N	\N	\N
31	95064M	PREMIN	1	\N	1988-05-10 00:00:00	\N	1991-05-15 00:00:00	\N	\N	ANCIEN	\N	\N	Premier ministre	\N	PREMIN	NON	\N	\N	\N
32	59529V	PREMIN	1	\N	1968-07-10 00:00:00	\N	1969-06-20 00:00:00	\N	\N	ANCIEN	\N	\N	Premier ministre	\N	PREMIN	NON	\N	\N	\N
33	89029V	MIN	1	\N	1995-11-07 00:00:00	\N	1997-06-02 00:00:00	\N	\N	ANCIEN	\N	\N	Aménagement du Territoire, de la ville et de l'intégration	\N	MINISTRE	NON	\N	2016-12-12 14:45:18	\N
288	98031Q	COOPERATION	5	30	2004-11-29 00:00:00	2004	2005-05-31 00:00:00	2005	\N	ANCIEN	\N	\N	Ministre délégué à la coopération, au développement et à la francophonie	\N	MINDEL	OUI	\N	2016-12-09 08:48:27	\N
312	95051G	ENVIRON	6	14	2005-05-31 00:00:00	\N	2007-03-25 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre de l'écologie et du développement durable	\N	MINISTRE	NON	\N	2016-12-09 10:55:31	\N
342	06006G	COOPERATION	1	\N	1998-02-13 00:00:00	1998	2000-03-27 00:00:00	2000	\N	ANCIEN	\N	\N	Ministre délégué à la coopération et à la francophonie	\N	MINDEL	NON	\N	2016-12-09 14:37:45	\N
343	80035E	MIN	1	\N	1995-05-18 00:00:00	1995	1995-11-07 00:00:00	1995	\N	ANCIEN	\N	\N	Ministre de la fonction publique	\N	MINISTRE	NON	\N	2016-12-12 09:58:47	\N
346	05004A	INTERIEUR	6	\N	2007-03-26 00:00:00	\N	2007-05-15 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre de l'intérieur et de l'aménagement du territoire	\N	MINISTRE	NON	\N	\N	\N
347	05008E	SANTE	6	\N	2007-03-26 00:00:00	\N	2007-05-15 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre de la santé et des solidarités	\N	MINISTRE	NON	\N	\N	\N
349	02009S	PREMIN	9	1	2007-05-18 00:00:00	2007	2007-06-18 00:00:00	2007	\N	ANCIEN	\N	\N	Premier ministre	\N	PREMIN	NON	\N	2016-12-08 18:57:18	\N
370	02009S	PREMIN	11	1	2007-06-18 00:00:00	2007	2008-03-18 00:00:00	2008	\N	ANCIEN	\N	\N	Premier ministre	\N	PREMIN	NON	\N	2016-12-08 18:57:36	\N
357	98031Q	EDUCATION	9	9	2007-05-18 00:00:00	2007	2007-06-18 00:00:00	2007	\N	ANCIEN	\N	\N	Ministre de l'éducation nationale	\N	MINISTRE	NON	\N	2016-12-09 08:48:33	\N
365	99004R	MIN	9	17	2007-05-18 00:00:00	2007	2007-06-18 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'Etat chargé des relations avec le Parlement	\N	SECRETMIN	NON	\N	\N	\N
393	01043Q	MIN	11	21	2007-06-19 00:00:00	2007	2008-03-18 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'Etat chargée de la solidarité	\N	SECRETMIN	NON	\N	\N	\N
398	04040A	COOPERATION	11	26	2007-06-19 00:00:00	2007	2008-03-18 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'Etat chargé de la coopération et de la francophonie	\N	SECRETMIN	NON	\N	2016-12-12 16:23:31	\N
405	02009S	PREMIN	13	1	2008-03-18 00:00:00	2008	2010-11-13 00:00:00	2010	\N	ANCIEN	\N	\N	Premier ministre	\N	PREMIN	NON	\N	2016-12-08 18:59:10	\N
421	99004R	MIN	13	18	2008-03-18 00:00:00	2008	2009-06-23 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'État chargé des relations avec le Parlement	\N	SECRETMIN	NON	\N	\N	\N
426	01043Q	MIN	13	22	2008-03-18 00:00:00	2008	2009-06-23 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'État chargée de la solidarité	\N	SECRETMIN	NON	\N	\N	\N
377	95008D	AGRICULTURE	11	8	2007-06-18 00:00:00	2007	2008-03-18 00:00:00	2008	\N	ANCIEN	\N	\N	Ministre de l'agriculture et de la pêche	\N	MINISTRE	NON	\N	2017-03-13 10:27:35	\N
379	98031Q	EDUCATION	11	10	2007-06-18 00:00:00	2007	2008-03-18 00:00:00	2008	\N	ANCIEN	\N	\N	Ministre de l'éducation nationale	\N	MINISTRE	NON	\N	2016-12-09 08:49:31	\N
387	99004R	MIN	11	17	2007-06-19 00:00:00	2007	2008-03-18 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'Etat chargé des relations avec le Parlement	\N	SECRETMIN	NON	\N	\N	\N
430	04040A	ANCIENCOMBAT	13	26	2008-03-18 00:00:00	2008	2009-06-23 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'État à la défense et aux anciens combattants	\N	SECRETMIN	NON	\N	\N	\N
437	95031C	MIN	13	33	2008-03-18 00:00:00	2008	2009-06-23 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'Etat chargé de l'aménagement du territoire	\N	SECRETMIN	NON	\N	\N	\N
34	66002K	COOPERATION	1	\N	1978-04-06 00:00:00	1988	\N	1991	\N	ANCIEN	\N	\N	Ministère de la Coopération et du développement	\N	MINISTRE	NON	\N	\N	\N
35	98051U	AGRICULTURE	1	\N	1981-05-22 00:00:00	1981	1981-06-22 00:00:00	1981	\N	ANCIEN	\N	\N	Ministere de la mer	\N	MINISTRE	NON	\N	2016-12-13 10:20:27	\N
36	66002K	MIN	1	\N	\N	1978	\N	1981	\N	ANCIEN	\N	\N	Education nationale	\N	SECRETMIN	NON	\N	\N	\N
37	98052V	MIN	1	\N	1986-03-20 00:00:00	1986	1988-05-10 00:00:00	1988	\N	ANCIEN	\N	\N	Secrétaire d'état chargé du Pacifique Sud	\N	SECRETMIN	NON	\N	2016-12-08 19:28:18	\N
38	77029G	SANTE	1	\N	1978-04-06 00:00:00	1978	1980-10-02 00:00:00	1980	\N	ANCIEN	\N	\N	Secretaire d'Etat aupres du ministre de la sante et de la famille	\N	SECRETMIN	NON	\N	2016-12-12 14:25:01	\N
39	01005J	AGRICULTURE	1	\N	1977-04-01 00:00:00	1977	1978-03-31 00:00:00	1978	\N	ANCIEN	\N	\N	Secrétaire d'Etat à l'agriculture	\N	SECRETMIN	NON	\N	2016-12-08 11:54:11	\N
40	01028R	MIN	1	\N	1991-05-17 00:00:00	\N	1993-03-29 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'Etat aux collectivités locales	\N	SECRETMIN	NON	\N	2016-12-12 15:40:35	\N
41	01031L	MIN	1	\N	1988-06-28 00:00:00	1988	1991-05-15 00:00:00	1991	\N	ANCIEN	\N	\N	Secrétaire d'Etat aux droits des femmes	\N	SECRETMIN	NON	\N	2016-12-12 15:44:16	\N
42	01032M	MIN	1	\N	\N	1981	\N	1986	\N	ANCIEN	\N	\N	Ministre des relations avec le Parlement	\N	MINISTRE	NON	\N	\N	\N
43	01048V	COMMERCE	1	\N	1993-03-29 00:00:00	\N	1994-10-14 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre de l'industrie, des postes et télécommunications et du commerce extérieur	\N	MINISTRE	NON	\N	2016-12-12 14:51:27	\N
44	01020H	TRANSPORT	1	\N	1988-05-12 00:00:00	1988	1988-06-23 00:00:00	1988	\N	ANCIEN	\N	\N	Ministre des transports	\N	MINISTRE	NON	\N	2016-12-09 10:18:03	\N
45	01048V	TELECOM	1	\N	1986-08-19 00:00:00	\N	1988-05-10 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre délégué à la poste et des télécommunications	\N	MINDEL	OUI	\N	2016-12-12 14:51:04	\N
46	01020H	AGRICULTURE	1	\N	1990-10-02 00:00:00	1990	1991-05-15 00:00:00	1991	\N	ANCIEN	\N	\N	Ministre de l'agriculture et de la forêt	\N	MINISTRE	NON	\N	2016-12-09 10:18:46	\N
47	01020H	MIN	1	\N	1992-10-02 00:00:00	1992	1993-03-29 00:00:00	1993	\N	ANCIEN	\N	\N	Ministre des relations avec le parlement 	\N	MINISTRE	NON	\N	2016-12-09 10:19:41	\N
49	95059Q	PREMIN	1	\N	2002-05-07 00:00:00	2002	2002-06-17 00:00:00	\N	\N	ANCIEN	\N	\N	Premier ministre	\N	PREMIN	NON	\N	2016-12-13 11:27:42	\N
50	83042R	ANCIENCOMBAT	1	\N	1997-06-04 00:00:00	1997	2001-09-03 00:00:00	2001	\N	ANCIEN	\N	\N	Secrétaire d'Etat à la défense, chargé des anciens combattants  	\N	SECRETMIN	NON	\N	\N	\N
51	98031Q	EDUCATION	2	22	2002-06-17 00:00:00	2002	2004-03-30 00:00:00	2004	\N	ANCIEN	\N	\N	Ministre délégué à l'enseignement scolaire auprès du ministre de la jeunesse, de l'éducation nationale et de la recherche	\N	MINDEL	OUI	\N	2016-12-09 08:50:29	\N
52	92029V	BUDGET	2	17	2002-06-17 00:00:00	2002	2004-03-30 00:00:00	2004	\N	ANCIEN	\N	\N	Ministre délégué au Budget auprès du ministre de l'économie	\N	MINDEL	OUI	\N	2016-12-09 10:05:57	\N
53	92017R	MIN	2	14	2002-06-17 00:00:00	2002	2004-03-30 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre de la fonction publique, de la réforme de l'État et de l'aménagement du territoire	\N	MINISTRE	NON	\N	\N	\N
54	95031C	MIN	2	37	2002-06-17 00:00:00	2002	2004-03-30 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'Etat aux personnes âgées	\N	SECRETMIN	NON	\N	\N	\N
55	02007Q	MIN	1	\N	\N	1986	\N	1988	\N	ANCIEN	\N	\N	Jeunesse et sports	\N	SECRETMIN	NON	\N	\N	\N
60	95059Q	PREMIN	2	1	2002-06-17 00:00:00	2002	2004-03-30 00:00:00	\N	\N	ANCIEN	\N	\N	Premier ministre	\N	PREMIN	NON	\N	\N	\N
62	02009S	SOCIAL	2	3	2002-06-17 00:00:00	2002	2004-03-30 00:00:00	2004	\N	ANCIEN	\N	\N	Ministre des affaires sociales, du travail et de la solidarité	\N	MINISTRE	NON	\N	2016-12-08 18:59:49	\N
451	08046Y	MIN	1	\N	1992-03-01 00:00:00	1992	1993-09-01 00:00:00	1993	\N	ANCIEN	\N	\N	Ministre des affaires sociales et de l'intégration	\N	MINISTRE	NON	\N	\N	\N
95	58819Y	MIN	1	\N	1977-04-01 00:00:00	1977	1978-03-31 00:00:00	1978	\N	ANCIEN	\N	\N	Secretaire d'Etat aux Collectivites locales	\N	SECRETMIN	NON	\N	2016-12-08 19:34:48	\N
96	59522N	MIN	1	\N	\N	\N	1973-04-02 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre	\N	MINISTRE	NON	\N	\N	\N
97	58619S	MIN	1	\N	\N	\N	1958-06-01 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre	\N	MINISTRE	NON	\N	\N	\N
98	59571X	MIN	1	\N	\N	\N	1972-07-06 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre	\N	MINISTRE	NON	\N	\N	\N
99	000572	MIN	1	\N	1979-07-04 00:00:00	\N	1981-05-22 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre	\N	MINISTRE	NON	\N	\N	\N
100	59529V	MIN	1	\N	\N	\N	1968-07-10 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre	\N	MINISTRE	NON	\N	\N	\N
101	59226H	MIN	1	\N	1981-05-22 00:00:00	\N	1983-03-22 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre	\N	MINISTRE	NON	\N	\N	\N
102	59531P	MIN	1	\N	1962-04-14 00:00:00	\N	1969-06-20 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'Etat	\N	SECRETMIN	NON	\N	\N	\N
103	57714L	TRAVAIL	1	\N	1974-05-27 00:00:00	1974	1976-08-25 00:00:00	1976	\N	ANCIEN	\N	\N	Ministre du Travail	\N	MINISTRE	NON	\N	2016-12-08 18:19:26	\N
104	000197	MIN	1	\N	\N	\N	1973-04-22 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre	\N	MINISTRE	NON	\N	\N	\N
105	58818X	MIN	1	\N	\N	\N	1989-02-22 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre	\N	MINISTRE	NON	\N	\N	\N
106	59521M	MIN	1	\N	1976-01-12 00:00:00	\N	1976-08-27 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre	\N	MINISTRE	NON	\N	\N	\N
107	62001R	MIN	1	\N	\N	\N	1958-06-01 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'Etat	\N	SECRETMIN	NON	\N	\N	\N
108	89032Q	MIN	1	\N	\N	\N	1974-05-28 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre	\N	MINISTRE	NON	\N	\N	\N
109	59539X	MIN	1	\N	1974-05-28 00:00:00	\N	1976-01-12 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre	\N	MINISTRE	NON	\N	\N	\N
110	000442	MIN	1	\N	\N	\N	1977-03-30 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre d'Etat	\N	MINISTRE	NON	\N	\N	\N
313	05004A	DOMTOM	6	15	2005-06-02 00:00:00	\N	2007-03-26 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre de l'outre-mer	\N	MINISTRE	NON	\N	\N	\N
319	86034E	TRAVAIL	6	21	2005-06-02 00:00:00	\N	2007-05-15 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre délégué à l'emploi, au travail et à l'insertion professionnelle des jeunes	\N	MINDEL	OUI	\N	2016-12-13 10:38:45	\N
612	92005M	MIN	24	21	2011-06-29 00:00:00	2011	2012-05-10 00:00:00	\N	\N	ANCIEN	\N	\N	ministre auprès du ministre de l'intérieur, de l'outre-mer, des collectivités territoriales et de l'immigration, chargé des collectivités territoriales	\N	MINISTRE	NON	\N	\N	\N
613	86044G	MIN	24	20	2011-06-29 00:00:00	2011	2012-05-10 00:00:00	\N	\N	ANCIEN	\N	\N	ministre auprès du ministre d'État, ministre des affaires étrangères et européennes, chargé de la coopération	\N	MINISTRE	NON	\N	\N	\N
614	95049N	MIN	24	5	2011-06-29 00:00:00	2011	2012-05-10 00:00:00	\N	\N	ANCIEN	\N	\N	garde des sceaux, ministre de la justice et des libertés	\N	GARSCEAUX	NON	\N	\N	\N
615	01048V	MIN	24	3	2011-06-29 00:00:00	2011	2012-05-10 00:00:00	\N	\N	ANCIEN	\N	\N	ministre de la défense et des anciens combattants	\N	MINISTRE	NON	\N	\N	\N
616	02009S	PREMIN	16	1	2010-11-14 00:00:00	2010	2012-05-10 00:00:00	2012	\N	ANCIEN	\N	\N	Premier ministre 	\N	PREMIN	NON	\N	2016-12-14 15:13:59	\N
688	12016W	MIN	31	19	2012-06-21 00:00:00	\N	2014-04-01 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre des outre-mer	\N	MINISTRE	NON	\N	2014-04-02 11:45:00	\N
699	12028B	MIN	31	30	2012-06-21 00:00:00	\N	2014-04-01 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre déléguée auprès de la ministre des affaires sociales et de la santé, chargée des personnes handicapées et de la lutte contre l'exclusion	\N	MINDEL	NON	\N	2014-04-02 11:45:00	\N
705	04090L	MIN	31	32	2013-03-19 00:00:00	\N	2014-03-31 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre délégué auprès du ministre des affaires étrangères, chargé des affaires européennes	\N	MINDEL	NON	\N	2016-12-09 11:04:59	\N
706	08064B	MIN	31	37	2012-06-21 00:00:00	\N	2014-03-31 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre déléguée auprès de la ministre de la réforme de l'État, de la décentralisation et de la fonction publique, chargée de la décentralisation	\N	MINDEL	NON	\N	2014-04-02 11:45:00	\N
707	11027H	MIN	31	39	2012-06-21 00:00:00	\N	2014-03-31 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre déléguée auprès du ministre des affaires étrangères, chargée des Français de l'étranger	\N	MINDEL	NON	\N	2016-12-12 16:57:42	\N
708	04053F	MIN	31	9	2012-06-21 00:00:00	\N	2014-03-31 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre du commerce extérieur	\N	MINISTRE	NON	\N	2016-12-12 16:36:27	\N
635	11115U	MIN	24	34	2011-09-28 00:00:00	2011	2012-05-10 00:00:00	\N	\N	ANCIEN	\N	\N	secrétaire d'État auprès du ministre d'État, ministre des affaires étrangères et européennes, chargé des Français de l'étranger	\N	SECRETMIN	NON	\N	\N	\N
619	11089X	MIN	1	\N	1999-07-28 00:00:00	\N	2000-03-27 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'État à la santé et à l'action sociale	\N	SECRETMIN	NON	\N	2016-12-12 18:21:30	\N
620	11089X	MIN	1	\N	2000-03-27 00:00:00	\N	2001-02-06 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'État à la santé et aux handicapés	\N	SECRETMIN	NON	\N	\N	\N
621	11089X	MIN	1	\N	2001-02-06 00:00:00	\N	2001-03-27 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'État aux personnes âgées et aux personnes handicapées	\N	SECRETMIN	NON	\N	\N	\N
48	92018S	TOURISME	1	\N	1997-06-04 00:00:00	1997	2001-10-23 00:00:00	2001	\N	ANCIEN	\N	\N	Secrétaire d'Etat au tourisme	\N	SECRETMIN	NON	\N	2016-12-13 11:56:36	\N
632	11077T	MIN	1	\N	1992-04-02 00:00:00	\N	1993-03-29 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre déléguée au logement et au cadre de vie	\N	MINDEL	NON	\N	2016-12-12 14:48:57	\N
633	11077T	MIN	1	\N	2001-03-27 00:00:00	\N	2002-05-06 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'Etat au logement	\N	SECRETMIN	NON	\N	2016-12-12 14:49:38	\N
651	12016W	MIN	26	18	2012-05-16 00:00:00	2012	2012-06-18 00:00:00	2012	\N	ANCIEN	\N	\N	ministre des outre-mer	\N	MINISTRE	NON	\N	\N	\N
653	04053F	MIN	26	9	2012-05-16 00:00:00	2012	2012-06-18 00:00:00	2012	\N	ANCIEN	\N	\N	Ministre de l'écologie, du développement durable et de l'énergie	\N	MINISTRE	NON	\N	\N	\N
664	12028B	MIN	26	30	2012-05-16 00:00:00	2012	2012-06-18 00:00:00	2012	\N	ANCIEN	\N	\N	ministre déléguée auprès de la ministre des affaires sociales et de la santé, chargée des personnes handicapées	\N	MINDEL	NON	\N	\N	\N
623	11035H	MIN	1	\N	1984-07-19 00:00:00	\N	1986-03-20 00:00:00	\N	\N	ANCIEN	\N	\N	du Travail, de l'Emploi et de la Formation professionnel	\N	MINISTRE	NON	\N	\N	\N
624	11035H	MIN	1	\N	1988-05-12 00:00:00	\N	1988-06-23 00:00:00	\N	\N	ANCIEN	\N	\N	des affaires sociales et de l'emploi	\N	MINISTRE	NON	\N	2016-12-12 17:09:13	\N
625	11035H	MIN	1	\N	1988-06-28 00:00:00	\N	1989-02-22 00:00:00	\N	\N	ANCIEN	\N	\N	des transports et de la mer	\N	MINISTRE	NON	\N	2016-12-12 17:09:34	\N
626	11035H	MIN	1	\N	1989-02-22 00:00:00	\N	1990-12-21 00:00:00	\N	\N	ANCIEN	\N	\N	de l'Equipement, du logment, des transports et de la mer	\N	MINISTRE	NON	\N	\N	\N
627	11035H	MIN	1	\N	1990-12-21 00:00:00	\N	1991-05-15 00:00:00	\N	\N	ANCIEN	\N	\N	d'Etat, Ministre de la ville	\N	MINISTRE	NON	\N	\N	\N
628	11035H	MIN	1	\N	1991-05-16 00:00:00	\N	1992-04-02 00:00:00	\N	\N	ANCIEN	\N	\N	d'Etat, Ministre de la Fonction Publique et des réformes administratives	\N	MINISTRE	NON	\N	\N	\N
440	95041E	COOPERATION	13	36	2008-03-18 00:00:00	2008	2009-06-23 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'État chargé de la coopération et de la francophonie	\N	SECRETMIN	NON	\N	\N	\N
344	07003H	ETRANGER	1	\N	1978-09-11 00:00:00	1978	1981-05-13 00:00:00	1981	\N	ANCIEN	\N	\N	Secrétaire d'Etat auprès du ministre des Affaires étrangères	\N	SECRETMIN	NON	\N	2016-12-08 14:44:46	\N
345	07003H	ECONOMIE	1	\N	1977-03-30 00:00:00	1977	1978-03-31 00:00:00	1978	\N	ANCIEN	\N	\N	Secrétaire d'Etat auprès du ministère délégué à l'Economie et aux Finances	\N	SECRETMIN	NON	\N	2016-12-08 14:43:40	\N
444	08027V	MIN	1	\N	1981-05-22 00:00:00	1981	1981-06-22 00:00:00	1981	\N	ANCIEN	\N	\N	Ministre de la santé	\N	MINISTRE	NON	\N	2016-12-09 14:09:38	\N
445	08027V	MIN	1	\N	1981-06-23 00:00:00	1981	1983-03-22 00:00:00	1983	\N	ANCIEN	\N	\N	Ministre chargé de l'énergie	\N	MINISTRE	NON	\N	2016-12-09 14:10:13	\N
446	08027V	MIN	1	\N	1983-03-24 00:00:00	1983	1984-07-17 00:00:00	1984	\N	ANCIEN	\N	\N	Secrétaire d'Etat chargé de la santé	\N	SECRETMIN	NON	\N	2016-12-09 14:10:36	\N
447	08027V	MIN	1	\N	1984-07-23 00:00:00	1984	1986-03-20 00:00:00	1986	\N	ANCIEN	\N	\N	Secrétaire d'Etat chargé de la santé	\N	SECRETMIN	NON	\N	2016-12-09 14:10:58	\N
448	02053W	MIN	1	\N	1981-06-22 00:00:00	1981	1983-03-22 00:00:00	1983	\N	ANCIEN	\N	\N	ministre d'Etat, de la recherche et de la technologie	\N	MINETA	NON	\N	2016-12-08 17:45:04	\N
449	02053W	MIN	1	\N	1984-07-19 00:00:00	1984	1986-03-20 00:00:00	1986	\N	ANCIEN	\N	\N	Ministre  de l'éducation nationale	\N	MINISTRE	NON	\N	2016-12-08 17:45:46	\N
450	02053W	MIN	1	\N	1988-05-12 00:00:00	1988	1988-06-23 00:00:00	1988	\N	ANCIEN	\N	\N	ministre de la défense nationale	\N	MINISTRE	NON	\N	2016-12-08 17:47:45	\N
452	08061X	MIN	1	\N	2002-02-25 00:00:00	\N	2002-05-06 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre de l'agriculture et de la pêche	\N	MINISTRE	NON	\N	2016-12-12 14:54:31	\N
453	08061X	MIN	1	\N	2000-10-18 00:00:00	\N	2002-02-25 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'État aux petites et moyennes entreprises, au commerce, à l'artisanat et à la consommation	\N	SECRETMIN	NON	\N	2016-12-12 14:54:12	\N
412	95008D	AGRICULTURE	13	8	2008-03-18 00:00:00	2008	2009-06-23 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre de l'agriculture et de la pêche	\N	MINISTRE	NON	\N	\N	\N
414	98031Q	EDUCATION	13	10	2008-03-18 00:00:00	2008	2009-06-23 00:00:00	2009	\N	ANCIEN	\N	\N	Ministre de l'éducation nationale	\N	MINISTRE	NON	\N	2016-12-09 08:51:37	\N
238	86010V	TOURISME	1	\N	1990-07-17 00:00:00	1990	1991-05-15 00:00:00	1991	\N	ANCIEN	\N	\N	Ministre délégué auprès du ministre de l'Industrie et de l'aménagement du territoire, chargé du Tourisme	\N	MINDEL	OUI	\N	\N	\N
239	86010V	TOURISME	1	\N	1991-05-16 00:00:00	1991	1992-04-02 00:00:00	1992	\N	ANCIEN	\N	\N	Ministre délégué au Tourisme auprès du ministre de l'équipement, du logements et des transports	\N	MINDEL	OUI	\N	2016-12-14 10:49:46	\N
240	86010V	COMMERCE	1	\N	1992-04-02 00:00:00	1992	1993-03-29 00:00:00	1993	\N	ANCIEN	\N	\N	Ministre délégué au tourisme auprès du ministre de l'industrie et du commerce extérieur	\N	MINDEL	OUI	\N	2016-12-14 10:49:57	\N
242	77029G	TRANSPORT	1	\N	1980-10-02 00:00:00	1980	1981-05-13 00:00:00	1981	\N	ANCIEN	\N	\N	Ministre des Transports	\N	MINISTRE	NON	\N	2016-12-09 14:18:28	\N
243	77029G	MIN	1	\N	1993-03-30 00:00:00	1993	1995-05-11 00:00:00	1995	\N	ANCIEN	\N	\N	Ministre délégué à l'aménagement du territoire et aux collectivités locales	\N	MINDEL	OUI	\N	2016-12-09 14:18:58	\N
244	68036E	ECONOMIE	1	\N	1978-04-05 00:00:00	\N	1981-05-21 00:00:00	1981	\N	ANCIEN	\N	\N	Ministre de l'économie	\N	MINISTRE	NON	\N	\N	\N
245	68036E	EDUCATION	1	\N	1986-03-20 00:00:00	1986	1988-05-10 00:00:00	1988	\N	ANCIEN	\N	\N	Ministre de l'éducation nationale	\N	MINISTRE	NON	\N	\N	\N
246	04040A	COMMERCE	1	\N	1986-02-19 00:00:00	1986	1986-03-20 00:00:00	1986	\N	ANCIEN	\N	\N	Ministre du commerce,de l'artisanat et du tourisme 	\N	MINISTRE	NON	\N	2016-12-12 16:21:39	\N
247	86039K	EDUCATION	1	\N	2000-03-27 00:00:00	2000	2002-05-06 00:00:00	2002	\N	ANCIEN	\N	\N	Ministre délégué à l'enseignement professionnel	\N	MINDEL	OUI	\N	2016-12-09 10:13:25	\N
248	04056J	COMMUNICA	1	\N	1988-05-12 00:00:00	\N	1991-05-15 00:00:00	\N	\N	ANCIEN	\N	\N	ministre délégué auprès du ministre de la culture, de la communication, chargée de la communication	\N	MINDEL	OUI	\N	2016-12-12 14:56:16	\N
249	04056J	MIN	1	\N	1991-05-16 00:00:00	\N	1993-03-29 00:00:00	\N	\N	ANCIEN	\N	\N	secrétaire d'Etat à la francophonie et aux relations culturelles extérieures	\N	SECRETMIN	NON	\N	2016-12-12 14:55:59	\N
250	04056J	COMMUNICA	1	\N	2000-03-27 00:00:00	\N	2002-05-06 00:00:00	\N	\N	ANCIEN	\N	\N	ministre de la culture et de la communication	\N	MINISTRE	NON	\N	2016-12-12 14:56:39	\N
251	04082L	TERRIT	1	\N	1997-06-04 00:00:00	1997	2000-03-27 00:00:00	2000	\N	ANCIEN	\N	\N	ministre de l'aménagement du territoire et de l'environnement	\N	MINISTRE	NON	\N	2016-12-09 11:12:10	\N
252	04040A	COMMERCE	1	\N	1984-07-23 00:00:00	\N	1986-02-19 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'Etat auprès du Ministre du Commerce, de l'Artisanat et du Tourisme	\N	SECRETMIN	NON	\N	2016-12-13 18:09:48	\N
23	77053G	INTERIEUR	1	\N	1986-03-20 00:00:00	1986	1988-05-10 00:00:00	1988	\N	ANCIEN	\N	\N	Ministre de l'Intérieur	\N	MINETA	NON	\N	\N	\N
254	95051G	MIN	5	26	2004-10-28 00:00:00	2004	2004-11-28 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre delegue a l'integration, a l'egalite des chances et a la lutte contre l'exclusion	\N	MINDEL	OUI	\N	2016-12-09 10:58:02	\N
255	04008A	MIN	5	27	2004-10-28 00:00:00	2004	2005-05-31 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre délégué au logement et à la ville	\N	MINDEL	OUI	\N	\N	\N
261	95059Q	PREMIN	5	1	2004-11-29 00:00:00	\N	2005-05-31 00:00:00	\N	\N	ANCIEN	\N	\N	Premier ministre	\N	PREMIN	NON	\N	\N	\N
262	02009S	EDUCATION	5	2	2004-11-29 00:00:00	2004	2005-05-31 00:00:00	2005	\N	ANCIEN	\N	\N	Ministre de l'éducation nationale, de l'enseignement supérieur et de la recherche	\N	MINISTRE	NON	\N	2016-12-08 19:04:33	\N
258	59312E	MIN	1	\N	1993-03-30 00:00:00	1993	1995-05-11 00:00:00	1995	\N	ANCIEN	\N	\N	Ministre délégué en charge des relations avec le Sénat et des rapatriés	\N	MINDEL	OUI	\N	2016-12-12 14:46:10	\N
259	59312E	MIN	1	\N	1995-05-18 00:00:00	1995	1995-11-07 00:00:00	1995	\N	ANCIEN	\N	\N	Ministre en charge des relations avec le Parlement	\N	MINISTRE	NON	\N	2016-12-12 14:46:46	\N
268	95008D	ETRANGER	5	8	2004-11-29 00:00:00	\N	2005-05-31 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre des affaires étrangères	\N	MINISTRE	NON	\N	2016-12-08 15:42:40	\N
273	98025S	ENVIRON	5	13	2004-11-29 00:00:00	\N	2005-05-31 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre de l'écologie et du développement durable	\N	MINISTRE	NON	\N	\N	\N
285	86034E	TRAVAIL	5	25	2004-11-29 00:00:00	\N	2005-05-31 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre délégué aux relations du travail	\N	MINDEL	OUI	\N	\N	\N
570	92005M	MIN	22	20	2011-02-27 00:00:00	2011	2011-06-28 00:00:00	2011	\N	ANCIEN	\N	\N	ministre auprès du ministre de l'intérieur, de l'outre-mer, des collectivités territoriales et de l'immigration, chargé des collectivités territoriales	\N	MINISTRE	NON	\N	\N	\N
464	09001P	ENVIRON	13	40	2009-01-21 00:00:00	2009	2010-11-13 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'Etat chargée de l'écologie	\N	MINISTRE	NON	\N	\N	\N
507	95041E	MIN	16	34	2009-06-23 00:00:00	2009	2010-07-04 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'État chargé de la coopération et de la francophonie	\N	SECRETMIN	NON	\N	2016-12-13 10:35:37	\N
549	92005M	INTERIEUR	21	20	2010-11-14 00:00:00	2010	2011-02-26 00:00:00	2011	\N	ANCIEN	\N	\N	Ministre auprès du ministre de l'intérieur, de l'outre-mer, des collectivités territoriales et de l'immigration, chargé des collectivités territoriales	\N	MINISTRE	NON	\N	\N	\N
550	02009S	MIN	16	1	2012-02-22 00:00:00	2012	2012-05-10 00:00:00	2012	\N	ANCIEN	\N	\N	Premier ministre,ministre de l'ecologie, du developpement durable, des transports et du logement	\N	PREMIN	NON	\N	2016-12-08 19:13:26	\N
514	05004A	MIN	16	13	2010-03-22 00:00:00	2010	2010-11-13 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre du budget, des comptes publics et de la réforme de l'État	\N	MINISTRE	NON	\N	\N	\N
115	000211	MIN	1	\N	\N	\N	1958-05-14 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'Etat	\N	SECRETMIN	NON	\N	\N	\N
515	04008A	MIN	16	18	2010-03-22 00:00:00	2010	2010-11-13 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre de la jeunesse et des solidarités actives	\N	MINISTRE	NON	\N	\N	\N
509	01043Q	MIN	16	25	2009-06-23 00:00:00	2009	2010-11-13 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'Etat en charge des technologies vertes et des négociations sur le climat	\N	SECRETMIN	NON	\N	\N	\N
510	95049N	MIN	16	17	2009-06-23 00:00:00	2009	2010-11-13 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre de l'espace rural et de l'aménagement du territoire	\N	MINISTRE	NON	\N	2016-12-13 18:17:36	\N
511	86044G	MIN	16	19	2009-06-23 00:00:00	2009	2010-11-13 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre chargé des relations avec le Parlement	\N	MINISTRE	NON	\N	2016-12-13 11:31:10	\N
481	95031C	DEFENSE	16	32	2009-06-23 00:00:00	2009	2010-11-13 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'État à la défense et aux anciens combattants	\N	SECRETMIN	NON	\N	\N	\N
482	04040A	JUSTICE	16	26	2009-06-23 00:00:00	2009	2010-11-13 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'État à la justice	\N	SECRETMIN	NON	\N	\N	\N
487	98031Q	TRAVAIL	16	7	2009-06-23 00:00:00	2009	2010-03-22 00:00:00	2010	\N	ANCIEN	\N	\N	Ministre du travail, des relations sociales, de la famille, de la solidarité et de la ville	\N	MINISTRE	NON	\N	2016-12-09 08:51:54	\N
120	89005M	MIN	1	\N	1977-04-01 00:00:00	\N	1978-04-06 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'Etat	\N	SECRETMIN	NON	\N	\N	\N
20	83033Q	MIN	1	\N	1978-11-29 00:00:00	\N	1981-05-13 00:00:00	1981	\N	ANCIEN	\N	\N	Ministre	\N	MINISTRE	NON	\N	\N	\N
15	92031P	MIN	1	\N	1977-04-01 00:00:00	\N	1978-03-31 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'État auprès du ministre du travail	\N	SECRETMIN	NON	\N	2016-12-13 10:45:42	\N
583	95050F	MIN	1	\N	1993-03-30 00:00:00	1993	1995-05-11 00:00:00	1995	\N	ANCIEN	\N	\N	Ministre delegue chargee de l'Action humanitaire et des Droits de l'Homme	\N	MINDEL	NON	\N	2016-12-13 10:39:01	\N
584	05004A	MIN	24	7	2011-06-29 00:00:00	2011	2012-05-10 00:00:00	\N	\N	ANCIEN	\N	\N	ministre de l'économie, des finances et de l'industrie	\N	MINISTRE	NON	\N	\N	\N
326	05008E	MIN	6	28	2005-06-02 00:00:00	\N	2007-03-26 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre délégué à la sécurité sociale, aux personnes âgées, aux personnes handicapées et à la famille	\N	MINDEL	OUI	\N	\N	\N
335	02009S	TELECOM	1	\N	1995-11-07 00:00:00	1995	1997-06-02 00:00:00	1997	\N	ANCIEN	\N	\N	Ministre délégué chargé de la Poste, des Télécommunications et de l'Espace. 	\N	MINDEL	NON	\N	2016-12-08 19:16:29	\N
337	95063L	DEFENSE	1	\N	1997-06-04 00:00:00	1997	2002-05-06 00:00:00	2002	\N	ANCIEN	\N	\N	Ministre de la défense	\N	MINISTRE	NON	\N	\N	\N
338	06006G	TRANSPORT	1	\N	1985-11-15 00:00:00	1985	1986-03-20 00:00:00	1986	\N	ANCIEN	\N	\N	Secrétaire d'Etat auprès du ministre de l'urbanisme, du logement et des transports, chargé des transports	\N	MINISTRE	NON	\N	2016-12-09 14:47:38	\N
339	06006G	MIN	1	\N	1992-04-04 00:00:00	1992	1993-03-29 00:00:00	1993	\N	ANCIEN	\N	\N	Secrétaire d'Etat à la mer	\N	SECRETMIN	NON	\N	2016-12-09 14:38:53	\N
340	06006G	ETRANGER	1	\N	1997-06-04 00:00:00	1997	1998-02-13 00:00:00	1998	\N	ANCIEN	\N	\N	Secretaire d'Etat aupres du ministre des affaires etrangeres, a la cooperation et a la francophonie	\N	SECRETMIN	NON	\N	2016-12-09 14:44:30	\N
341	06006G	ETRANGER	1	\N	2000-03-27 00:00:00	2000	2002-05-06 00:00:00	2002	\N	ANCIEN	\N	\N	Secrétaire d'Etat auprès du ministre des affaires étrangères, à la coopération et à la francophonie	\N	MINDEL	NON	\N	2016-12-09 14:46:50	\N
520	95049N	MIN	21	5	2010-11-14 00:00:00	2010	2011-02-26 00:00:00	2011	\N	ANCIEN	\N	\N	garde des sceaux, ministre de la justice et des libertés	\N	GARSCEAUX	NON	\N	\N	\N
525	05004A	MIN	21	10	2010-11-14 00:00:00	2010	2011-02-26 00:00:00	2011	\N	ANCIEN	\N	\N	ministre du budget, des comptes publics, de la fonction publique et de la réforme de l'Etat, porte-parole du Gouvernement	\N	MINISTRE	NON	\N	\N	\N
530	09001P	MIN	21	16	2010-11-14 00:00:00	2010	2011-09-26 00:00:00	2011	\N	ANCIEN	\N	\N	ministre des sports	\N	MINISTRE	NON	\N	2016-12-13 10:32:57	\N
533	86044G	MIN	21	19	2010-11-14 00:00:00	2010	2011-02-26 00:00:00	2011	\N	ANCIEN	\N	\N	ministre auprès de la ministre d'Etat, ministre des affaires étrangères et européennes, chargé de la coopération	\N	MINISTRE	NON	\N	\N	\N
551	01048V	DEFENSE	22	3	2011-02-27 00:00:00	2011	2011-06-28 00:00:00	2011	\N	ANCIEN	\N	\N	ministre de la défense et des anciens combattants	\N	MINISTRE	NON	\N	2016-12-13 18:17:00	\N
556	95049N	JUSTICE	22	5	2011-02-27 00:00:00	2011	2011-06-28 00:00:00	2011	\N	ANCIEN	\N	\N	garde des sceaux, ministre de la justice et des libertés	\N	GARSCEAUX	NON	\N	\N	\N
560	05004A	BUDGET	22	10	2011-02-27 00:00:00	2011	2011-06-29 00:00:00	2011	\N	ANCIEN	\N	\N	ministre du budget, des comptes publics, de la fonction publique et de la réforme de l'Etat, porte-parole du Gouvernement	\N	MINISTRE	NON	\N	\N	\N
569	86044G	MIN	22	19	2011-02-27 00:00:00	2011	2011-06-28 00:00:00	2011	\N	ANCIEN	\N	\N	ministre auprès du ministre d'Etat, ministre des affaires étrangères et européennes, chargé de la coopération	\N	MINISTRE	NON	\N	\N	\N
1033	86010V	TERRIT	44	10	2016-12-06 00:00:00	\N	2017-05-10 00:00:00	\N	\N	ANCIEN	\N	\N	ministre de l'aménagement du territoire, de la ruralité et des collectivités territoriales	\N	MINISTRE	NON	2016-12-06 14:27:18	2017-05-18 09:38:39	\N
1038	21032X	MIN	44	16	2016-12-06 00:00:00	\N	2017-05-18 00:00:00	\N	\N	ANCIEN	\N	\N	ministre de la fonction publique	\N	MINISTRE	NON	2016-12-06 14:36:05	2023-11-20 15:31:12	\N
1039	11045K	MIN	44	15	2016-12-06 00:00:00	\N	2017-05-18 00:00:00	\N	\N	ANCIEN	\N	\N	ministre des familles, de l'enfance et des droits des femmes	\N	MINISTRE	NON	2016-12-06 14:36:06	2017-05-18 09:38:39	\N
1040	14021P	JEUNESSE	44	17	2016-12-06 00:00:00	\N	2017-05-18 00:00:00	\N	\N	ANCIEN	\N	\N	ministre de la ville, de la jeunesse et des sports	\N	MINISTRE	NON	2016-12-06 14:36:08	2017-05-18 09:38:39	\N
1041	11041F	MIN	44	19	2016-12-06 00:00:00	\N	2017-05-18 00:00:00	\N	\N	ANCIEN	\N	\N	secrétaire d'État auprès du Premier ministre, chargé des relations avec le Parlement	\N	SECRETMIN	NON	2016-12-06 14:39:30	2017-05-18 09:38:39	\N
1043	11069T	MIN	44	20	2016-12-06 00:00:00	\N	2017-05-10 00:00:00	\N	\N	ANCIEN	\N	\N	secrétaire d'État auprès du Premier ministre, chargé de la réforme de l'État et de la simplification	\N	SECRETMIN	NON	2016-12-06 14:39:32	2017-05-18 09:38:40	\N
1063	83011J	MIN	1	\N	1987-01-20 00:00:00	1987	1988-05-10 00:00:00	1988	\N	ANCIEN	\N	\N	Secretaire d'etat charge de la Consommation et de la Concurrence	\N	SECRETMIN	NON	2016-12-07 18:27:59	2016-12-07 18:43:09	\N
1065	83011J	MIN	1	\N	1995-05-18 00:00:00	1995	1995-08-26 00:00:00	1995	\N	ANCIEN	\N	\N	Ministre du Developpement economique et du Plan	\N	MINISTRE	NON	2016-12-07 18:30:46	2017-03-13 10:22:25	\N
1066	83011J	MIN	1	\N	1995-08-26 00:00:00	1995	1995-11-07 00:00:00	1995	\N	ANCIEN	\N	\N	Ministre de l'Economie et des Finances et du plan	\N	MINISTRE	NON	2016-12-07 18:43:43	2016-12-14 10:47:26	\N
1067	83012K	MIN	1	\N	1981-06-23 00:00:00	1981	1983-03-22 00:00:00	1983	\N	ANCIEN	\N	\N	Secretaire d'Etat charge des immigres.	\N	SECRETMIN	NON	2016-12-07 18:56:20	2016-12-07 18:59:47	\N
1069	83012K	DEFENSE	1	\N	1983-03-24 00:00:00	1983	1983-10-04 00:00:00	1983	\N	ANCIEN	\N	\N	Secretaire d'Etat aupres du ministere de la defense	\N	SECRETMIN	NON	2016-12-07 18:59:56	2016-12-14 10:50:40	\N
1093	98031Q	MIN	1	\N	2002-05-07 00:00:00	2002	2002-06-17 00:00:00	2002	\N	ANCIEN	\N	\N	Ministre chargede l'Enseignement scolaire	\N	MINISTRE	NON	2016-12-09 08:53:20	\N	\N
1094	92029V	BUDGET	1	\N	2002-05-07 00:00:00	2002	2002-06-17 00:00:00	2002	\N	ANCIEN	\N	\N	Ministre charge du Budget	\N	MINDEL	NON	2016-12-09 10:05:57	\N	\N
1095	58652T	MIN	1	\N	1981-06-23 00:00:00	1981	1983-03-22 00:00:00	1983	\N	ANCIEN	\N	\N	Ministre Delegue charge de la fonction publique et des reformes administratives	\N	MINDEL	NON	2016-12-09 10:08:26	\N	\N
1096	58652T	MIN	1	\N	1983-03-22 00:00:00	1983	1984-07-17 00:00:00	1984	\N	ANCIEN	\N	\N	Secretaire d'Etat Fonction publique et reformes administratives	\N	SECRETMIN	NON	2016-12-09 10:10:00	\N	\N
1097	01020H	MIN	1	\N	1981-05-22 00:00:00	1981	1981-06-22 00:00:00	1981	\N	ANCIEN	\N	\N	Ministre de l'Equipement et des Transports	\N	MINISTRE	NON	2016-12-09 10:15:47	\N	\N
1098	01020H	MIN	1	\N	1991-05-16 00:00:00	1991	1992-04-02 00:00:00	1992	\N	ANCIEN	\N	\N	Ministre de l'Agriculture et des forets	\N	MINISTRE	NON	2016-12-09 10:20:23	\N	\N
1099	01020H	MIN	1	\N	1992-04-02 00:00:00	1992	1992-10-02 00:00:00	1992	\N	ANCIEN	\N	\N	Ministre de l'Agriculture et du develloppement rural	\N	MINISTRE	NON	2016-12-09 10:21:21	\N	\N
1100	95051G	MIN	1	\N	2004-11-28 00:00:00	2004	2005-05-31 00:00:00	2005	\N	ANCIEN	\N	\N	Ministere charge de l'Integration, de l'egalite des chances et a la lutte contre l'exclusion	\N	MINDEL	NON	2016-12-09 10:52:08	2016-12-09 10:58:05	\N
1101	95051G	MIN	1	\N	2007-03-26 00:00:00	2007	2007-05-15 00:00:00	2007	\N	ANCIEN	\N	\N	Ministre de l'Ecologie et du developpement durable	\N	MINISTRE	NON	2016-12-09 10:56:26	2016-12-09 10:58:21	\N
1102	74042Q	MIN	1	\N	1991-05-16 00:00:00	1991	1992-04-02 00:00:00	1992	\N	ANCIEN	\N	\N	Ministere delegue charge des postes et des telecommunications	\N	MINDEL	NON	2016-12-09 11:00:53	\N	\N
1103	74042Q	MIN	1	\N	1992-04-02 00:00:00	1992	1992-10-02 00:00:00	1992	\N	ANCIEN	\N	\N	Ministre delegue charge du commerce et de l'artisanat	\N	MINDEL	NON	2016-12-09 11:02:19	\N	\N
1104	04090L	MIN	1	\N	2012-06-21 00:00:00	2012	2013-03-19 00:00:00	2013	\N	ANCIEN	\N	\N	Ministere delegue aupres du ministre du travail, de l'emploi	\N	MINDEL	NON	2016-12-09 11:04:59	\N	\N
1105	80045G	MIN	1	\N	1973-10-23 00:00:00	1973	1974-02-27 00:00:00	1974	\N	ANCIEN	\N	\N	Secretaire d'Etat aupres du ministre de l'economie et de finances	\N	SECRETMIN	NON	2016-12-09 11:08:54	\N	\N
1106	80045G	BUDGET	1	\N	1974-03-01 00:00:00	1974	1974-05-27 00:00:00	1974	\N	ANCIEN	\N	\N	Secretaire d'Etat budget	\N	SECRETMIN	NON	2016-12-09 11:10:03	\N	\N
1107	04082L	MIN	1	\N	2000-03-27 00:00:00	2000	2001-07-10 00:00:00	2001	\N	ANCIEN	\N	\N	ministre de l'amenagement du territoire et de l'environnement	\N	MINISTRE	NON	2016-12-09 11:12:10	\N	\N
1108	77019E	MIN	1	\N	1976-08-27 00:00:00	1976	1977-03-29 00:00:00	1977	\N	ANCIEN	\N	\N	Ministre de l'equipement	\N	MINISTRE	NON	2016-12-09 11:14:40	\N	\N
1109	77019E	MIN	1	\N	1977-03-30 00:00:00	1977	1977-09-26 00:00:00	1977	\N	ANCIEN	\N	\N	Ministere de l'equipement et de l'amenagement du territoire	\N	MINISTRE	NON	2016-12-09 11:15:28	\N	\N
1113	77058M	MIN	1	\N	1973-04-12 00:00:00	1973	1974-02-27 00:00:00	1974	\N	ANCIEN	\N	\N	Secretaire d'Etat aupres du ministre du travail, de l'emploi et de la population	\N	SECRETMIN	NON	2016-12-12 10:08:06	\N	\N
1114	77058M	MIN	1	\N	1974-03-01 00:00:00	1974	1974-05-27 00:00:00	1974	\N	ANCIEN	\N	\N	Secretaire d'Etat fonction publique	\N	SECRETMIN	NON	2016-12-12 10:10:20	\N	\N
1115	77058M	MIN	1	\N	1974-06-08 00:00:00	1974	1976-08-25 00:00:00	\N	\N	ANCIEN	\N	\N	Secretaire d'Etat budget	\N	SECRETMIN	NON	2016-12-12 10:11:29	\N	\N
1116	77058M	MIN	1	\N	1976-08-27 00:00:00	1976	1977-03-29 00:00:00	1977	\N	ANCIEN	\N	\N	Secretaire d'Etat budget	\N	SECRETMIN	NON	2016-12-12 10:14:01	\N	\N
1117	77058M	MIN	1	\N	1977-04-01 00:00:00	1977	1977-09-26 00:00:00	1977	\N	ANCIEN	\N	\N	Secretaire d'Etat relations avec le parlement	\N	SECRETMIN	NON	2016-12-12 10:15:23	2016-12-12 14:21:13	\N
1118	59312E	MIN	1	\N	1995-11-07 00:00:00	1995	1997-06-02 00:00:00	1997	\N	ANCIEN	\N	\N	Ministre en charge des relations avec le Parlement	\N	MINISTRE	NON	2016-12-12 14:47:05	\N	\N
1121	83016P	MIN	1	\N	1973-04-12 00:00:00	1973	1974-02-27 00:00:00	1974	\N	ANCIEN	\N	\N	Secretaire d'Etat aupres du ministere de l'equipement,du logement et de l'amenagement du territoire et du tourisme.	\N	SECRETMIN	NON	2016-12-12 17:16:06	\N	\N
1122	83016P	MIN	1	\N	1974-03-01 00:00:00	1974	1974-05-27 00:00:00	1974	\N	ANCIEN	\N	\N	Secretaire d'Etat logement	\N	SECRETMIN	NON	2016-12-12 17:17:43	\N	\N
1123	83016P	MIN	1	\N	1974-05-27 00:00:00	1974	1976-08-25 00:00:00	1976	\N	ANCIEN	\N	\N	Ministere de l'Agriculture.	\N	MINISTRE	NON	2016-12-12 17:18:36	\N	\N
1124	83016P	MIN	1	\N	1976-08-27 00:00:00	1976	1977-03-29 00:00:00	1977	\N	ANCIEN	\N	\N	Ministere de l'Agriculture.	\N	MINISTRE	NON	2016-12-12 17:19:47	\N	\N
1057	01062T	ANCIENCOMBAT	44	33	2016-12-06 00:00:00	\N	2017-05-18 00:00:00	\N	\N	ANCIEN	\N	\N	secrétaire d'État auprès du ministre de la défense, chargé des anciens combattants et de la mémoire	\N	SECRETMIN	NON	2016-12-06 15:15:51	2017-05-18 09:38:40	\N
1125	83016P	MIN	1	\N	1977-03-30 00:00:00	1977	1978-03-31 00:00:00	1978	\N	ANCIEN	\N	\N	Ministere de l'Interieur	\N	MINISTRE	NON	2016-12-12 17:20:23	\N	\N
1136	92031P	MIN	1	\N	1978-04-06 00:00:00	\N	1981-05-13 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'État auprès du ministre du travail, chargé de la formation professionnelle	\N	SECRETMIN	NON	2016-12-13 10:45:45	2016-12-13 10:47:01	\N
3	95059Q	MIN	1	\N	1995-05-18 00:00:00	\N	1997-06-02 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre	\N	MINISTRE	NON	\N	2016-12-13 11:25:10	\N
1137	83011J	MIN	1	\N	1995-11-07 00:00:00	1995	1997-06-02 00:00:00	1997	\N	ANCIEN	\N	\N	Ministre de l'Econmie et de Finances	\N	MINISTRE	NON	2016-12-14 10:47:30	\N	\N
1141	99002P	INTERIEUR	49	2	2017-05-17 00:00:00	\N	2017-06-19 00:00:00	\N	\N	ANCIEN	\N	Ministre d'État, ministre de l'intérieur	ministre d'État, ministre de l'intérieur	\N	MINETA	NON	2017-05-18 09:49:05	2017-06-22 12:00:10	903
959	14251Q	MIN	1	\N	1986-03-20 00:00:00	\N	1988-05-10 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'Etat chargé des Droits de l'Homme	Secrétaire d'Etat chargé des Droits de l'Homme	SECRETMIN	NON	2014-12-02 16:26:24	2016-12-12 14:52:10	\N
980	86010V	TERRIT	40	10	2016-02-11 00:00:00	\N	2016-12-06 00:00:00	\N	\N	ANCIEN	\N	\N	ministre de l'aménagement du territoire, de la ruralité et des collectivités territoriales	\N	MINISTRE	NON	2016-02-12 10:00:55	2016-12-06 10:29:26	\N
986	11045K	MIN	40	15	2016-02-11 00:00:00	\N	2016-12-06 00:00:00	\N	\N	ANCIEN	\N	\N	ministre des familles, de l'enfance et des droits des femmes	\N	MINISTRE	NON	2016-02-12 10:12:08	2016-12-06 10:29:26	\N
987	21032X	MIN	40	16	2016-02-11 00:00:00	\N	2016-12-06 00:00:00	\N	\N	ANCIEN	\N	\N	ministre de la fonction publique	\N	MINISTRE	NON	2016-02-12 10:13:26	2023-11-20 15:31:12	\N
997	11069T	MIN	40	20	2016-02-11 00:00:00	\N	2016-12-06 00:00:00	\N	\N	ANCIEN	\N	\N	secrétaire d'État auprès du Premier ministre, chargé de la réforme de l'État et de la simplification	\N	SECRETMIN	NON	2016-02-12 10:24:30	2016-12-06 10:29:26	\N
1001	01062T	ANCIENCOMBAT	40	34	2016-02-11 00:00:00	\N	2016-12-06 00:00:00	\N	\N	ANCIEN	\N	\N	secrétaire d'État auprès du ministre de la défense, chargé des anciens combattants et de la mémoire	\N	SECRETMIN	NON	2016-02-12 10:27:31	2016-12-06 10:29:26	\N
1134	95060H	MIN	1	\N	1983-03-22 00:00:00	1983	1984-07-17 00:00:00	1984	\N	ANCIEN	\N	\N	Ministre delegue charge de l'Emploi	\N	MINDEL	NON	2016-12-13 10:30:27	\N	\N
957	01062T	MIN	35	26	2014-11-22 00:00:00	\N	2016-02-12 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'État auprès du ministre de la défense, chargé des anciens combattants et de la mémoire	\N	SECRETMIN	NON	2014-11-24 09:45:25	2016-02-12 09:40:21	\N
964	11045K	MIN	35	27	2015-06-17 00:00:00	\N	2016-02-12 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'État auprès de la ministre des affaires sociales, de la santé et des droits des femmes, chargée de la famille, de l'enfance, des personnes âgées et de l'autonomie	\N	SECRETMIN	NON	2015-06-18 17:37:55	2016-02-12 09:40:21	\N
1009	11041F	MIN	40	24	2016-02-11 00:00:00	\N	2016-12-06 00:00:00	\N	\N	ANCIEN	\N	\N	secrétaire d'État auprès du ministre des affaires étrangères et du développement international, chargé du développement et de la francophonie	\N	SECRETMIN	NON	2016-02-12 10:31:54	2016-12-06 10:29:26	\N
1070	95008D	MIN	1	\N	1995-05-18 00:00:00	1995	1995-11-07 00:00:00	1995	\N	ANCIEN	\N	\N	Ministre delegue aux Affaires Europeennes	\N	MINDEL	NON	2016-12-08 15:48:54	2017-03-13 10:27:24	\N
1072	95008D	MIN	1	\N	1995-11-07 00:00:00	1995	1997-06-02 00:00:00	1997	\N	ANCIEN	\N	\N	Ministre delegue aux Affaires Europeennes	\N	MINDEL	NON	2016-12-08 15:57:14	\N	\N
1013	14021P	JEUNESSE	40	18	2016-02-11 00:00:00	\N	2016-12-06 00:00:00	\N	\N	ANCIEN	\N	\N	ministre de la ville, de la jeunesse et des sports	\N	MINISTRE	NON	2016-02-12 11:06:32	2016-12-06 10:29:26	\N
1075	02053W	DEFENSE	1	\N	1988-06-28 00:00:00	1988	1991-01-29 00:00:00	1991	\N	ANCIEN	\N	\N	Ministre de l'Interieur	\N	MINISTRE	NON	2016-12-08 17:48:40	2016-12-08 17:50:32	\N
1076	02053W	MIN	1	\N	1981-05-21 00:00:00	1981	1981-06-22 00:00:00	1981	\N	ANCIEN	\N	\N	ministre d'Etat, de la recherche et de la technologie	\N	MINETA	NON	2016-12-08 17:50:39	2016-12-08 17:52:25	\N
1077	02053W	DEFENSE	1	\N	2000-03-27 00:00:00	2000	2000-08-29 00:00:00	2000	\N	ANCIEN	\N	\N	Ministre de l'Interieur	\N	MINISTRE	NON	2016-12-08 17:52:35	\N	\N
1078	57714L	ECONOMIE	1	\N	1976-08-25 00:00:00	1976	1977-03-29 00:00:00	1977	\N	ANCIEN	\N	\N	Ministre delegue charge de l'Economie et des Finances	\N	MINDEL	NON	2016-12-08 18:22:08	\N	\N
1079	57714L	MIN	1	\N	1988-05-12 00:00:00	1988	1988-06-22 00:00:00	1988	\N	ANCIEN	\N	\N	Ministre de la Fonction Publique et de la Reforme administrative	\N	MINISTRE	NON	2016-12-08 18:26:19	\N	\N
1080	57714L	MIN	1	\N	1988-06-23 00:00:00	1988	1989-02-22 00:00:00	1989	\N	ANCIEN	\N	\N	Ministre de la Fonction Publique et des Reformes administratives	\N	MINISTRE	NON	2016-12-08 18:28:48	\N	\N
1081	57714L	MIN	1	\N	1989-02-22 00:00:00	1989	1991-05-15 00:00:00	1991	\N	ANCIEN	\N	\N	Ministre d'Etat, ministre de la Fonction Publique et des Reformes administratives	\N	MINETA	NON	2016-12-08 18:30:02	\N	\N
1082	02009S	SOCIAL	2	\N	2002-05-07 00:00:00	2002	2002-06-17 00:00:00	2002	\N	ANCIEN	\N	\N	Ministre des affaires sociales, du travail et de la solidarite	\N	MINISTRE	NON	2016-12-08 19:16:46	2016-12-08 19:19:02	\N
1083	02009S	MIN	1	\N	1995-05-18 00:00:00	1995	1995-11-07 00:00:00	1995	\N	ANCIEN	\N	\N	Ministre des Technologies de l'Information et de la Poste	\N	MINISTRE	NON	2016-12-08 19:19:33	\N	\N
1084	02009S	EDUCATION	1	\N	1993-03-30 00:00:00	1993	1995-05-11 00:00:00	1995	\N	ANCIEN	\N	\N	Ministre de l'Enseignement Superieur et de la Recherche	\N	MINISTRE	NON	2016-12-08 19:21:30	\N	\N
1085	95006B	JUSTICE	1	\N	1983-03-22 00:00:00	1983	1984-07-17 00:00:00	1984	\N	ANCIEN	\N	\N	Garde des Sceaux	\N	GARSCEAUX	NON	2016-12-08 19:29:36	2016-12-08 19:30:54	\N
1086	95006B	JUSTICE	1	\N	1984-07-19 00:00:00	1984	1986-02-19 00:00:00	1986	\N	ANCIEN	\N	\N	Garde des Sceaux	\N	GARSCEAUX	NON	2016-12-08 19:30:57	\N	\N
1087	59721T	COMMERCE	1	\N	1992-10-02 00:00:00	1992	1993-03-29 00:00:00	1993	\N	ANCIEN	\N	\N	Ministre delegue charge du Commerce et de l'Artisanat	\N	MINDEL	NON	2016-12-08 19:32:09	\N	\N
1088	58819Y	MIN	1	\N	1978-04-06 00:00:00	1978	1980-10-02 00:00:00	1980	\N	ANCIEN	\N	\N	Secretaire d'Etat aux Collectivites locales	\N	SECRETMIN	NON	2016-12-08 19:34:51	\N	\N
1089	81015E	BUDGET	1	\N	1991-05-16 00:00:00	1991	1992-04-02 00:00:00	1992	\N	ANCIEN	\N	\N	Ministre delegue charge du Budget	\N	MINDEL	NON	2016-12-08 19:36:51	2016-12-08 19:37:37	\N
1090	81015E	BUDGET	1	\N	1992-04-02 00:00:00	1992	1992-10-02 00:00:00	1992	\N	ANCIEN	\N	\N	Ministre du Budget	\N	MINISTRE	NON	2016-12-08 19:37:39	\N	\N
1091	92017R	MIN	1	\N	2002-05-07 00:00:00	2002	2002-06-17 00:00:00	2002	\N	ANCIEN	\N	\N	Ministre de la fonction publique, de la reforme de l'Etat et de l'amenagement du territoire	\N	MINISTRE	NON	2016-12-08 19:39:10	\N	\N
1092	97003G	MIN	1	\N	2000-03-27 00:00:00	2000	2002-05-06 00:00:00	2002	\N	ANCIEN	\N	\N	Secretaire d'Etat au Patrimoine et Decentralisation culturelle	\N	SECRETMIN	NON	2016-12-08 19:40:19	\N	\N
1119	05004A	MIN	1	\N	1995-05-18 00:00:00	\N	1995-11-07 00:00:00	\N	\N	ANCIEN	\N	\N	Porte-parole du Gouvernement	\N	SECRETMIN	NON	2016-12-12 15:52:00	2016-12-12 15:53:42	\N
1126	83016P	MIN	1	\N	1978-04-05 00:00:00	1978	1981-05-13 00:00:00	1981	\N	ANCIEN	\N	\N	Ministere de l'Interieur.	\N	MINISTRE	NON	2016-12-12 17:22:54	\N	\N
1127	98051U	MIN	1	\N	1981-06-23 00:00:00	1981	1983-03-22 00:00:00	1983	\N	ANCIEN	\N	\N	Ministere de la mer	\N	MINISTRE	NON	2016-12-13 10:20:27	\N	\N
1128	98051U	MIN	1	\N	1988-05-12 00:00:00	1988	1988-06-23 00:00:00	1988	\N	ANCIEN	\N	\N	Ministere de la mer	\N	MINISTRE	NON	2016-12-13 10:21:57	\N	\N
1129	98051U	MIN	1	\N	1988-06-28 00:00:00	1988	1989-02-14 00:00:00	1989	\N	ANCIEN	\N	\N	Ministere des Departements et Territoires d'Outre-Mer	\N	MINISTRE	NON	2016-12-13 10:22:35	\N	\N
1130	98051U	MIN	1	\N	1991-05-16 00:00:00	1991	1992-04-02 00:00:00	1992	\N	ANCIEN	\N	\N	Ministere des Departements et Territoires d'Outre-Mer	\N	MINISTRE	NON	2016-12-13 10:24:33	2016-12-13 10:25:41	\N
1131	98051U	MIN	1	\N	1992-04-02 00:00:00	1992	1993-03-29 00:00:00	1993	\N	ANCIEN	\N	\N	Ministere des Departements et Territoires d'Outre-Mer	\N	MINISTRE	NON	2016-12-13 10:25:42	\N	\N
1132	98051U	MIN	1	\N	1997-06-04 00:00:00	1997	1998-10-20 00:00:00	1998	\N	ANCIEN	\N	\N	Ministere de l'Agriculture et de la Peche	\N	MINISTRE	NON	2016-12-13 10:26:22	\N	\N
1133	98051U	MIN	1	\N	1989-02-14 00:00:00	1989	1991-05-15 00:00:00	1991	\N	ANCIEN	\N	\N	Ministere de DOM-TOM, Porte parole du Gouvernement	\N	MINISTRE	NON	2016-12-13 10:27:59	\N	\N
1135	95060H	MIN	1	\N	1984-07-17 00:00:00	1984	1986-03-20 00:00:00	1986	\N	ANCIEN	\N	\N	Ministre delegue charge de l'Emploi	\N	MINDEL	NON	2016-12-13 10:31:45	\N	\N
1217	83042R	DEFENSE	1	\N	2000-03-27 00:00:00	\N	2001-09-03 00:00:00	\N	\N	ANCIEN	\N	Anciens combattants	Défense	\N	SECRETMIN	NON	\N	\N	\N
816	11045K	MIN	33	30	2014-04-10 00:00:00	\N	2014-08-26 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'État auprès de la ministre des affaires sociales et de la santé, chargée de la famille, des personnes âgées et de l'autonomie	\N	SECRETMIN	NON	2014-04-10 09:36:38	2014-08-27 17:32:51	\N
817	21032X	MIN	33	22	2014-04-10 00:00:00	\N	2014-08-26 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'État auprès du ministre des affaires étrangères et du développement international, chargée du développement et de la francophonie	\N	SECRETMIN	NON	2014-04-10 09:36:40	2023-11-20 15:31:12	\N
814	08070Y	TRAVAIL	33	9	2014-04-02 00:00:00	\N	2014-08-26 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre du travail, de l'emploi et du dialogue social	\N	MINISTRE	NON	2014-04-02 12:07:45	2014-08-27 17:32:51	\N
830	11041F	MIN	33	29	2014-04-10 00:00:00	\N	2014-08-26 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'État auprès de la ministre de la décentralisation, de la réforme de l'État et de la fonction publique, chargé de la réforme territoriale	\N	SECRETMIN	NON	2014-04-10 09:36:45	2014-08-27 17:32:51	\N
855	08070Y	TRAVAIL	35	9	2014-08-26 00:00:00	\N	2015-09-02 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre du travail, de l'emploi, de la formation professionnelle et du dialogue social	\N	MINISTRE	NON	2014-08-27 17:42:50	2016-02-12 09:40:21	\N
862	14021P	JEUNESSE	35	16	2014-08-26 00:00:00	\N	2016-02-12 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre de la ville, de la jeunesse et des sports	\N	MINISTRE	NON	2014-08-27 17:50:26	2016-02-12 09:40:22	\N
867	21032X	MIN	35	21	2014-08-26 00:00:00	\N	2016-02-12 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'État auprès du Premier ministre, chargée du développement et de la francophonie	\N	SECRETMIN	NON	2014-08-27 17:57:13	2023-11-20 15:31:12	\N
873	11045K	MIN	35	27	2014-08-26 00:00:00	\N	2016-02-12 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'État auprès de la ministre des affaires sociales, de la santé et des droits des femmes, chargée de la famille, des personnes âgées et de l'autonomie	\N	SECRETMIN	NON	2014-08-27 18:05:47	2016-02-12 09:40:22	\N
878	11041F	MIN	35	32	2014-08-26 00:00:00	\N	2016-02-12 00:00:00	\N	\N	ANCIEN	\N	\N	Secrétaire d'État auprès de la ministre de la décentralisation et de la fonction publique, chargé de la réforme territoriale	\N	SECRETMIN	NON	2014-08-27 18:14:19	2016-02-12 09:40:22	\N
1211	11035H	MIN	1	\N	1992-04-02 00:00:00	\N	1993-03-29 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre	\N	MINISTRE	NON	\N	\N	\N
1212	11035H	MIN	1	\N	1988-06-28 00:00:00	\N	1989-02-22 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre	\N	MINISTRE	NON	\N	\N	\N
1214	92018S	MIN	1	\N	2000-03-27 00:00:00	\N	2001-10-23 00:00:00	\N	\N	ANCIEN	\N	\N	Ministre	\N	MINISTRE	NON	\N	\N	\N
1469	19265T	DEFENSE	57	6	2022-05-20 00:00:00	\N	2024-01-09 00:00:00	\N	\N	ANCIEN	\N	ministre des armées	ministre des armées	\N	MINISTRE	NON	\N	\N	944
1483	11030C	MIN	57	22	2022-05-20 00:00:00	\N	2022-07-04 00:00:00	\N	\N	ANCIEN	\N	ministre délégué chargé des collectivités territoriales	ministre délégué auprès de la ministre de la transition écologique et de la cohésion des territoires, chargé des collectivités territoriales	\N	MINDEL	OUI	\N	\N	\N
1416	19265T	DOMTOM	56	9	2020-07-07 00:00:00	\N	2022-05-16 00:00:00	\N	\N	ANCIEN	\N	ministre des outre-mer	ministre des outre-mer	\N	MINISTRE	NON	\N	\N	955
1417	01007L	TERRIT	56	10	2020-07-07 00:00:00	\N	2022-03-05 00:00:00	\N	\N	ANCIEN	\N	ministre de la cohésion des territoires et des relations avec les collectivités territoriales	ministre de la cohésion des territoires et des relations avec les collectivités territoriales	\N	MINISTRE	NON	\N	\N	946
1156	21032X	DOMTOM	49	16	2017-05-17 00:00:00	\N	2017-06-19 00:00:00	\N	\N	ANCIEN	\N	Ministre des outre-mer	ministre des outre-mer	\N	MINISTRE	NON	2017-05-18 10:06:11	2023-11-20 15:31:12	955
1549	19265T	DEFENSE	58	8	2024-01-12 00:00:00	\N	\N	\N	\N	ACTIF	\N	ministre des armées	ministre des armées	\N	MINISTRE	NON	\N	\N	944
1552	11030C	ENVIRON	58	11	2024-01-12 00:00:00	\N	\N	\N	\N	ACTIF	\N	ministre de la transition écologique et de la cohésion des territoires	ministre de la transition écologique et de la cohésion des territoires	\N	MINISTRE	NON	\N	\N	942
1258	01007L	MIN	50	13	2018-10-16 00:00:00	\N	2020-07-03 00:00:00	\N	\N	ANCIEN	\N	ministre de la cohésion des territoires et des relations avec les collectivités territoriales	ministre de la cohésion des territoires et des relations avec les collectivités territoriales	\N	MINISTRE	NON	\N	\N	946
1261	08016S	AGRICULTURE	50	16	2018-10-16 00:00:00	\N	2020-07-03 00:00:00	\N	\N	ANCIEN	\N	ministre de l'agriculture et de l'alimentation	ministre de l'agriculture et de l'alimentation	\N	MINISTRE	NON	\N	\N	952
1263	19265T	MIN	50	19	2018-10-16 00:00:00	\N	2020-07-03 00:00:00	\N	\N	ANCIEN	\N	ministre auprès de la ministre de la cohésion des territoires et des relations avec les collectivités territoriales	ministre auprès de la ministre de la cohésion des territoires et des relations avec les collectivités territoriales, chargé des collectivités territoriales	\N	MINISTRE	NON	\N	\N	946
1176	99002P	INTERIEUR	50	\N	2017-06-21 00:00:00	\N	2018-10-16 00:00:00	\N	\N	ANCIEN	\N	Ministre d'État, ministre de l'intérieur	ministre d'État, ministre de l'intérieur	\N	MINETA	NON	2017-05-18 09:49:05	2017-06-22 11:31:04	903
1177	21032X	DOMTOM	50	14	2017-06-21 00:00:00	\N	2020-07-03 00:00:00	\N	\N	ANCIEN	\N	ministre des outre-mer	ministre des outre-mer	\N	MINISTRE	NON	2017-05-18 10:06:11	2023-11-20 15:31:12	955
1342	92017R	SANTE	50	\N	2019-09-04 00:00:00	\N	2019-12-17 00:00:00	\N	\N	ANCIEN	\N	haut-commissaire aux retraites	haut-commissaire aux retraites, délégué auprès de la ministre des solidarités et de la santé	\N	HAUCOM	OUI	\N	\N	947
1422	21032X	MIN	56	14	2020-07-07 00:00:00	\N	2022-05-16 00:00:00	\N	\N	ANCIEN	\N	ministre de la mer	ministre de la mer	\N	MINISTRE	NON	\N	2023-11-20 15:31:12	\N
1455	14037X	ETRANGER	56	34	2020-07-27 00:00:00	\N	2021-12-08 00:00:00	\N	\N	ANCIEN	\N	secrétaire d'État chargé du tourisme, des Français de l'étranger et de la francophonie	secrétaire d'État auprès du ministre de l'Europe et des affaires étrangères, chargé du tourisme, des Français de l'étranger et de la francophonie	\N	SECRETMIN	NON	\N	\N	945
1457	14037X	MIN	56	21	2021-12-09 00:00:00	\N	2022-05-16 00:00:00	\N	\N	ANCIEN	\N	ministre délégué chargé du tourisme, des Français de l'étranger, de la francophonie, des petites et moyennes entreprises	ministre délégué auprès du ministre de l'Europe et des affaires étrangères, chargé du tourisme, des Français de l'étranger et de la francophonie, et auprès du ministre de l'économie, des finances et de la relance, chargé des PME	\N	MINDEL	OUI	\N	\N	945
1491	11030C	ENVIRON	57	11	2022-07-05 00:00:00	\N	2024-01-09 00:00:00	\N	\N	ANCIEN	\N	ministre de la transition écologique et de la cohésion des territoires	ministre de la transition écologique et de la cohésion des territoires	\N	MINISTRE	NON	\N	\N	942
1499	11044J	MIN	57	25	2022-07-05 00:00:00	\N	2022-11-28 00:00:00	\N	\N	ANCIEN	\N	ministre déléguée chargée des collectivités territoriales	ministre déléguée auprès du ministre de l'intérieur et des outre-mer et du ministre de la transition écologique et de la cohésion des territoires, chargée des collectivités territoriales	\N	MINDEL	OUI	\N	\N	\N
1193	01007L	INTERIEUR	50	\N	2017-06-21 00:00:00	\N	2018-10-16 00:00:00	\N	\N	ANCIEN	\N	Ministre auprès du ministre d'État, ministre de l'intérieur	ministre auprès du ministre d'État, ministre de l'intérieur	\N	MINISTRE	NON	2017-06-22 10:55:09	2017-06-22 11:41:21	903
1189	08051V	TERRIT	50	\N	2017-06-21 00:00:00	\N	2018-10-16 00:00:00	\N	\N	ANCIEN	\N	Ministre de la cohésion des territoires	ministre de la cohésion des territoires	\N	MINISTRE	NON	2017-06-22 10:13:57	2017-06-22 10:21:35	946
1195	19265T	ENVIRON	50	\N	2017-06-21 00:00:00	\N	2018-10-16 00:00:00	\N	\N	ANCIEN	\N	Secrétaire d'État auprès du ministre d'État, ministre de la transition écologique et solidaire	secrétaire d'État auprès du ministre d'État, ministre de la transition écologique et solidaire	\N	SECRETMIN	NON	2017-06-22 11:07:08	2017-06-22 11:36:59	942
1197	14037X	ETRANGER	50	24	2017-06-21 00:00:00	\N	2020-07-03 00:00:00	\N	\N	ANCIEN	\N	secrétaire d'État auprès du ministre de l'Europe et des affaires étrangères	secrétaire d'État auprès du ministre de l'Europe et des affaires étrangères	\N	SECRETMIN	NON	2017-06-22 11:13:17	2017-06-22 11:44:23	966
1204	08051V	AGRICULTURE	49	13	2017-05-17 00:00:00	\N	2017-06-19 00:00:00	\N	\N	ANCIEN	\N	Ministre de l'agriculture et de l'alimentation	ministre de l'agriculture et de l'alimentation	\N	MINISTRE	NON	2017-06-22 12:11:06	2017-06-23 11:00:12	952
\.


--
-- Data for Name: mismin; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY mismin (misid, minid, syscredat, sysmajdat) FROM stdin;
149	708	\N	\N
119	509	\N	\N
96	412	\N	\N
84	319	\N	\N
1	62	\N	\N
2	62	\N	\N
32	337	\N	\N
10	8	\N	\N
18	28	\N	\N
21	191	\N	\N
22	43	\N	\N
32	167	\N	\N
35	251	\N	\N
45	49	\N	\N
47	51	\N	\N
65	268	\N	\N
24	8	\N	\N
76	312	\N	\N
71	335	\N	\N
118	510	\N	\N
83	313	\N	\N
85	313	\N	\N
116	510	\N	\N
145	699	\N	\N
139	584	\N	\N
127	616	2016-12-22 16:10:00	\N
202	1258	\N	\N
202	1261	\N	\N
203	1261	\N	\N
205	1258	\N	\N
205	1177	\N	\N
153	699	2014-01-23 10:03:02	\N
159	878	2015-01-19 16:49:27	\N
166	862	2015-10-21 10:31:50	\N
179	1177	\N	\N
215	1417	\N	\N
156	699	2014-02-17 10:24:04	\N
190	1261	\N	\N
173	1013	2016-05-20 12:09:04	\N
\.


--
-- Data for Name: missen; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY missen (misid, senmat, syscredat, sysmajdat) FROM stdin;
150	04084N	\N	\N
152	07034Q	\N	\N
149	04034C	\N	\N
151	01022K	\N	\N
98	02002K	\N	\N
99	04061F	\N	\N
119	01055U	\N	\N
96	01057W	\N	\N
125	04040A	\N	\N
100	01045S	\N	\N
107	98036V	\N	\N
84	95035G	\N	\N
108	04033B	\N	\N
1	95035G	\N	\N
2	89041R	\N	\N
3	86030A	\N	\N
6	01010F	\N	\N
7	98039Y	\N	\N
8	95047L	\N	\N
10	82002D	\N	\N
16	86030A	\N	\N
18	83026R	\N	\N
19	86034E	\N	\N
21	86041D	\N	\N
22	92040Q	\N	\N
26	83043S	\N	\N
28	83052T	\N	\N
30	83028T	\N	\N
31	86006A	\N	\N
32	95039L	\N	\N
34	92008Q	\N	\N
35	98051U	\N	\N
36	97007L	\N	\N
37	82002D	\N	\N
38	95040D	\N	\N
44	89045V	\N	\N
45	98025S	\N	\N
46	96004D	\N	\N
47	95024D	\N	\N
48	98048A	\N	\N
49	95056M	\N	\N
50	98019U	\N	\N
51	95050F	\N	\N
53	02002K	\N	\N
54	89013M	\N	\N
56	89017R	\N	\N
59	04075M	\N	\N
33	95044H	\N	\N
68	95045J	\N	\N
63	92029V	\N	\N
64	01048V	\N	\N
65	98032R	\N	\N
67	86044G	\N	\N
70	89037V	\N	\N
71	86047K	\N	\N
29	86041D	\N	\N
27	92035T	\N	\N
24	92005M	\N	\N
72	92005M	\N	\N
20	92022N	\N	\N
17	86049M	\N	\N
73	59721T	\N	\N
74	98017S	\N	\N
75	92029V	\N	\N
76	92005M	\N	\N
67	95049N	\N	\N
3	89030N	\N	\N
95	86030A	\N	\N
82	02005N	\N	\N
86	92029V	\N	\N
97	89023P	\N	\N
118	08009T	\N	\N
122	95007C	\N	\N
83	04093P	\N	\N
87	01044R	\N	\N
87	82002D	\N	\N
94	95038K	\N	\N
115	04081K	\N	\N
105	07033P	\N	\N
85	95050F	\N	\N
120	90003B	\N	\N
121	08042U	\N	\N
126	95038K	\N	\N
127	01027Q	\N	\N
116	04061F	\N	\N
117	04047H	\N	\N
117	08028W	\N	\N
117	01057W	\N	\N
123	95024D	\N	\N
106	01047U	\N	\N
106	04047H	\N	\N
90	86034E	\N	\N
140	09001P	\N	\N
137	08028W	\N	\N
136	95024D	\N	\N
145	00003C	\N	\N
133	78006D	\N	\N
134	95013A	\N	\N
147	11065P	\N	\N
148	11035H	\N	\N
139	83011J	\N	\N
129	08064B	\N	\N
142	01043Q	\N	\N
146	11055M	\N	\N
160	11027H	\N	\N
161	14030Q	\N	\N
161	11107G	\N	\N
161	11069T	\N	\N
169	04049K	\N	\N
163	11055M	\N	\N
164	14229S	\N	\N
169	95062K	\N	\N
169	11037K	\N	\N
169	14093U	\N	\N
171	14123H	\N	\N
186	14197C	\N	\N
202	19531S	\N	\N
175	11112D	\N	\N
203	14221J	\N	\N
205	08073C	\N	\N
217	19749K	\N	\N
228	19591F	\N	\N
153	11020A	2014-01-23 10:02:45	\N
155	11081P	2014-02-12 14:50:30	\N
166	08024S	\N	\N
158	14175V	\N	\N
159	11108H	\N	\N
167	14197C	\N	\N
172	01022K	\N	\N
176	11035H	\N	\N
179	19301E	\N	\N
180	14093U	\N	\N
207	04045F	\N	\N
211	20106U	\N	\N
213	19651A	\N	\N
215	14327T	\N	\N
215	11110B	\N	\N
218	19301E	\N	\N
156	01007L	2014-02-17 10:23:51	\N
168	14151M	\N	\N
174	11066Q	\N	\N
187	14231L	\N	\N
174	90003B	\N	\N
190	11103C	\N	\N
200	14213J	\N	\N
222	14327T	\N	\N
220	19651A	\N	\N
226	08045X	\N	\N
165	04045F	\N	\N
165	10015M	\N	\N
173	04059M	\N	\N
189	19543W	\N	\N
191	19611R	\N	\N
204	07004J	\N	\N
210	19591F	\N	\N
216	19637C	\N	\N
230	11110B	\N	\N
231	19553Y	\N	\N
\.


--
-- Data for Name: moddes; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY moddes (moddescod, temvalcod, evelic, evelib, evelil, eveobs, moddesnumtri, syscredat, sysmajdat, avis_com_senat, avis_com_an, typmoddescod) FROM stdin;
PDTSEN	ACTIF	Président du Sénat	Président du Sénat	Président du Sénat	\N	1	\N	\N	NON	NON	OEP
COM	ACTIF	Commissions	Commissions	Commissions	\N	4	\N	\N	NON	NON	OEP
SENCOM	ACTIF	Sénat sur proposition d'une commission	Sénat sur proposition d'une commission	Sénat sur proposition d'une commission	\N	3	\N	\N	NON	NON	OEP
MEMBREDRT	ACTIF	Membre de droit	Membre de droit	Membre de droit	\N	5	\N	\N	NON	NON	OEP
SCRUTIN	ACTIF	Scrutin	Scrutin	Scrutin	\N	7	\N	\N	NON	NON	OEP
SENAT	ACTIF	Sénat	Sénat	Sénat	\N	6	\N	\N	NON	NON	OEP
OPECST	ACTIF	OPECST	Office parlementaire d'évaluation des choix scientifiques et technologiques	Office parlementaire d'évaluation des choix scientifiques et technologiques	\N	2	\N	\N	NON	NON	OEP
PQPDTSEN	ACTIF	Président du Sénat	Président du Sénat	Nomination d'une personnalité qualifiée par le Président du Sénat	\N	11	\N	\N	NON	NON	PERQUAL
PRART13	ACTIF	Président de la République, article 13 de la constitution	Président de la République, après avis de la commission permanente compétente (article 13 alinéa 5 de la constitution)	Nomination par la Président de la République après avis de la commission permanente compétente de chaque assemblée (alinéa 5 de l'article 13 de la Constitution)	\N	8	\N	\N	OUI	OUI	NOMEXT
AUDITION	ACTIF	Président de la République, après audition	Président de la République, après audition sans vote par la commission permanente compétente	Nomination par la Président de la République après audition sans vote par la commission permanente compétente de chaque assemblée	\N	10	\N	\N	OUI	NON	NOMEXT
PSENART13	ACTIF	Président du Sénat, analogue à l'art. 13 de la constitution	Président du Sénat, après avis de la com. perm. compétente (proc. analogue à l'article 13 alinéa 5 de la constitution)	Nomination par la Président du Sénat après avis de la commission permanente compétente, selon une procédure analogue à celle prévue à l'article 13 alinéa 5 de la constitution	\N	9	\N	\N	OUI	NON	NOMEXT
\.


--
-- Data for Name: nation; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY nation (nationcod, nationlibcog, nationnumtri, nationactual, nationannind, nationlibenr, nationancnom, nationlic, zongeocod, nationliccap, nationlictri, nationurlcmp, syscredat, sysmajdat) FROM stdin;
99213	PAKISTAN                                                              	\N	\N	\N	RÉPUBLIQUE ISLAMIQUE DU PAKISTAN                                      	                    	Pakistan	TEST	PAKISTAN	Pakistan	\N	\N	\N
99214	BHOUTAN                                                               	\N	\N	\N	ROYAUME DU BHOUTAN                                                    	                    	Bhoutan	TEST	BHOUTAN	Bhoutan	\N	\N	\N
99215	NÉPAL                                                                 	\N	\N	\N	ROYAUME DU NÉPAL                                                      	                    	Népal	TEST	NÉPAL	Népal	\N	\N	\N
99216	CHINE                                                                 	\N	\N	\N	RÉPUBLIQUE POPULAIRE DE CHINE                                         	                    	Chine	TEST	CHINE	Chine	\N	\N	\N
99219	THAÏLANDE                                                             	\N	\N	\N	ROYAUME DE THAÏLANDE                                                  	SIAM                	Thaïlande	TEST	THAÏLANDE	Thaïlande	\N	\N	\N
99220	PHILIPPINES                                                           	\N	\N	\N	RÉPUBLIQUE DES PHILIPPINES                                            	                    	Philippines	TEST	PHILIPPINES	Philippines	\N	\N	\N
99222	JORDANIE                                                              	\N	\N	\N	ROYAUME HACHÉMITE DE JORDANIE                                         	TRANSJORDANIE       	Jordanie	TEST	JORDANIE	Jordanie	\N	\N	\N
99223	INDE                                                                  	\N	\N	\N	RÉPUBLIQUE DE L'INDE                                                  	                    	Inde	TEST	INDE	Inde	\N	\N	\N
99224	BIRMANIE	\N	\N	\N	UNION DU MYANMAR                                                     	                    	Birmanie	TEST	BIRMANIE	Birmanie	\N	\N	\N
99225	BRUNÉI                                                                	\N	\N	\N	NEGARA BRUNÉI DARUSSALAM                                              	BORNÉO BRITANNIQUE  	Brunéi	TEST	BRUNÉI	Brunéi	\N	\N	\N
99227	MALAISIE                                                              	\N	\N	\N	MALAISIE                                                              	                    	Malaisie	TEST	MALAISIE	Malaisie	\N	\N	\N
99229	MALDIVES                                                              	\N	\N	\N	RÉPUBLIQUE DES MALDIVES                                               	ILES MALDIVES       	Maldives	TEST	MALDIVES	Maldives	\N	\N	\N
99231	INDONESIE                                                             	\N	\N	\N	RÉPUBLIQUE D'INDONÉSIE                                                	INDES NEER. ET PORT.	Indonésie	TEST	INDONESIE	Indonésie	\N	\N	\N
99234	CAMBODGE                                                              	\N	\N	\N	ROYAUME DU CAMBODGE                                                   	KAMPUCHEA DEM.      	Cambodge	TEST	CAMBODGE	Cambodge	\N	\N	\N
99235	SRI LANKA                                                             	\N	\N	\N	RÉPUBLIQUE DÉMOCRATIQUE SOCIALISTE DE SRI LANKA                     CE	YLAN                	Sri Lanka	TEST	SRI LANKA	Sri Lanka	\N	\N	\N
99236	TAIWAN                                                                	\N	\N	\N	TAÏWAN                                                              	FORMOSE             	Taïwan	TEST	TAIWAN	Taïwan	\N	\N	\N
99238	CORÉE (RÉPUBLIQUE POPULAIRE DÉMOCRATIQUE DE)                          	\N	\N	\N	RÉPUBLIQUE POPULAIRE DÉMOCRATIQUE DE CORÉE                            	                    	Corée (Rép. Pop. Dém. De)	TEST	CORÉE (RÉP. POP. DÉM. DE)	Corée (Rép. Pop. Dém. De)	\N	\N	\N
99240	KOWEÏT                                                                	\N	\N	\N	ÉTAT DU KOWEÏT                                                        	                    	Koweït	TEST	KOWEÏT	Koweït	\N	\N	\N
99241	LAOS                                                                  	\N	\N	\N	RÉPUBLIQUE DÉMOCRATIQUE POPULAIRE LAO                                 	                    	Laos	TEST	LAOS	Laos	\N	\N	\N
99242	MONGOLIE                                                              	\N	\N	\N	MONGOLIE                                                              	MONGOLIE EXTERIEURE 	Mongolie	TEST	MONGOLIE	Mongolie	\N	\N	\N
99243	VIET NAM                                                              	\N	\N	\N	RÉPUBLIQUE SOCIALISTE DU VIETNAM                                    	                    	Viêt Nam	TEST	VIET NAM	Viêt Nam	\N	\N	\N
99246	BANGLADESH                                                            	\N	\N	\N	RÉPUBLIQUE POPULAIRE DU BANGLADESH                                    	PAKISTAN ORIENTAL   	Bangladesh	TEST	BANGLADESH	Bangladesh	\N	\N	\N
99248	QATAR                                                                 	\N	\N	\N	ÉTAT DU QATAR                                                         	                    	Qatar	TEST	QATAR	Qatar	\N	\N	\N
99249	BAHREIN                                                               	\N	\N	\N	ÉTAT DE BAHREIN                                                       	                    	Bahreïn	TEST	BAHREÏN	Bahreïn	\N	\N	\N
99250	OMAN                                                                  	\N	\N	\N	SULTANAT D'OMAN                                                       	MASCATE-ET-OMAN     	Oman	TEST	OMAN	Oman	\N	\N	\N
99251	YÉMEN                                                                 	\N	\N	\N	RÉPUBLIQUE DU YÉMEN                                                   	                    	Yémen	TEST	YEMEN	Yémen	\N	\N	\N
99252	ARMÉNIE                                                               	\N	\N	\N	RÉPUBLIQUE D'ARMÉNIE                                                  	                    	Arménie	TEST	ARMENIE	Arménie	\N	\N	\N
99253	AZERBAIDJAN                                                           	\N	\N	\N	RÉPUBLIQUE D'AZERBAÎDJAN                                            	                    	Azerbaïdjan	TEST	AZERBAIDJAN	Azerbaïdjan	\N	\N	\N
99254	CHYPRE                                                                	\N	\N	\N	RÉPUBLIQUE DE CHYPRE                                                  	                    	Chypre	UE	CHYPRE	Chypre	\N	\N	\N
99255	GEORGIE                                                               	\N	\N	\N	RÉPUBLIQUE DE GÉORGIE                                                 	                    	Géorgie	TEST	GÉORGIE	Géorgie	\N	\N	\N
99101	DANEMARK                                                              	\N	\N	\N	ROYAUME DU DANEMARK                                                   	                    	Danemark	UE	DANEMARK	Danemark	\N	\N	\N
99102	ISLANDE                                                               	\N	\N	\N	RÉPUBLIQUE D'ISLANDE                                                  	                    	Islande	TEST	ISLANDE	Islande	\N	\N	\N
99103	NORVÈGE                                                               	\N	\N	\N	ROYAUME DE NORVÈGE                                                    	                    	Norvège	TEST	NORVÈGE	Norvège	\N	\N	\N
99104	SUÈDE                                                                 	\N	\N	\N	ROYAUME DE SUÈDE                                                      	                    	Suède	UE	SUÈDE	Suède	\N	\N	\N
99105	FINLANDE                                                              	\N	\N	\N	RÉPUBLIQUE DE FINLANDE                                                	                    	Finlande	UE	FINLANDE	Finlande	\N	\N	\N
99107	LETTONIE                                                              	\N	\N	\N	RÉPUBLIQUE DE LETTONIE                                                	                    	Lettonie	UE	LETTONIE	Lettonie	\N	\N	\N
99108	LITUANIE                                                              	\N	\N	\N	RÉPUBLIQUE DE LITUANIE                                                	                    	Lituanie	UE	LITUANIE	Lituanie	\N	\N	\N
99109	ALLEMAGNE                                                             	\N	\N	\N	RÉPUBLIQUE FÉDÉRALE D'ALLEMAGNE                                       	                    	Allemagne	UE	ALLEMAGNE	Allemagne	\N	\N	\N
99110	AUTRICHE                                                              	\N	\N	\N	RÉPUBLIQUE D'AUTRICHE                                                 	                    	Autriche	UE	AUTRICHE	Autriche	\N	\N	\N
99111	BULGARIE                                                              	\N	\N	\N	RÉPUBLIQUE DE BULGARIE                                                	                    	Bulgarie	UE	BULGARIE	Bulgarie	\N	\N	\N
99112	HONGRIE                                                               	\N	\N	\N	RÉPUBLIQUE DE HONGRIE                                                 	                    	Hongrie	UE	HONGRIE	Hongrie	\N	\N	\N
99114	ROUMANIE                                                              	\N	\N	\N	ROUMANIE                                                              	                    	Roumanie	UE	ROUMANIE	Roumanie	\N	\N	\N
99116	TCHÈQUE (RÉPUBLIQUE)                                                  	\N	\N	\N	RÉPUBLIQUE TCHÈQUE                                                    	                    	Tchèque (République)	UE	TCHÈQUE (REPUBLIQUE)	Tchèque (République)	\N	\N	\N
99117	SLOVAQUIE                                                             	\N	\N	\N	RÉPUBLIQUE SLOVAQUE                                                   	                    	Slovaquie	UE	SLOVAQUIE	Slovaquie	\N	\N	\N
99118	BOSNIE-HERZÉGOVINE                                                    	\N	\N	\N	RÉPUBLIQUE DE BOSNIE-HERZÉGOVINE                                      	                    	Bosnie-Herzégovine	TEST	BOSNIE-HERZÉGOVINE	Bosnie-Herzégovine	\N	\N	\N
99119	CROATIE                                                               	\N	\N	\N	RÉPUBLIQUE DE CROATIE                                                 	                    	Croatie	TEST	CROATIE	Croatie	\N	\N	\N
99122	POLOGNE                                                               	\N	\N	\N	RÉPUBLIQUE DE POLOGNE                                                 	                    	Pologne	UE	POLOGNE	Pologne	\N	\N	\N
99123	RUSSIE                                                                	\N	\N	\N	FÉDÉRATION DE RUSSIE                                                  	U.R.S.S.            	Russie	TEST	RUSSIE	Russie	\N	\N	\N
XX001	SERBIE-ET-MONTÉNÉGRO	\N	\N	\N	COMMUNAUTÉ D'ÉTATS SERBIE-ET-MONTÉNÉGRO	YOUGOSLAVIE	Serbie-et-Monténégro	TEST	SERBIE-ET-MONTÉNÉGRO	Serbie-et-Monténégro	\N	\N	\N
99125	ALBANIE                                                               	\N	\N	\N	RÉPUBLIQUE D'ALBANIE                                                  	                    	Albanie	TEST	ALBANIE	Albanie	\N	\N	\N
99126	GRÉCE                                                                 	\N	\N	\N	RÉPUBLIQUE HELLÉNIQUE                                                 	                    	Grèce	UE	GRÉCE	Grèce	\N	\N	\N
99127	ITALIE                                                                	\N	\N	\N	RÉPUBLIQUE ITALIENNE                                                  	                    	Italie	UE	ITALIE	Italie	\N	\N	\N
99128	SAINT-MARIN                                                           	\N	\N	\N	RÉPUBLIQUE DE SAINT-MARIN                                             	                    	Saint-Marin	TEST	SAINT-MARIN	Saint-Marin	\N	\N	\N
99130	ANDORRE                                                               	\N	\N	\N	PRINCIPAUTÉ D'ANDORRE                                                 	                    	Andorre	TEST	ANDORRE	Andorre	\N	\N	\N
99131	BELGIQUE                                                              	\N	\N	\N	ROYAUME DE BELGIQUE                                                   	                    	Belgique	UE	BELGIQUE	Belgique	\N	\N	\N
99405	MEXIQUE                                                               	\N	\N	\N	ÉTATS-UNIS DU MEXIQUE                                                 	                    	Mexique	TEST	MEXIQUE	Mexique	\N	\N	\N
99411	HONDURAS                                                              	\N	\N	\N	RÉPUBLIQUE DU HONDURAS                                                	                    	Honduras	TEST	HONDURAS	Honduras	\N	\N	\N
99417	CHILI                                                                 	\N	1	960 	RÉPUBLIQUE DU CHILI                                                   	                    	Chili	TEST	CHILI	Chili	\N	\N	\N
99424	VENEZUELA                                                             	\N	1	963 	RÉPUBLIQUE DU VENEZUELA                                               	                    	Venezuela	TEST	VENEZUELA	Venezuela	\N	\N	\N
99436	BAHAMAS                                                               	\N	1	1973	COMMONWEALTH DES BAHAMAS                                              	ILES  LUCAYES       	Bahamas	TEST	BAHAMAS	Bahamas	\N	\N	\N
99502	NOUVELLE-ZÉLANDE                                                      	\N	1	966 	NOUVELLE-ZÉLANDE                                                      	                    	Nouvelle-Zélande	TEST	NOUVELLE-ZÉLANDE	Nouvelle-Zélande	\N	\N	\N
99511	TUVALU                                                                	\N	1	1978	TUVALU                                                                	ILES ELLICE         	Tuvalu	TEST	TUVALU	Tuvalu	\N	\N	\N
99301	ÉGYPTE                                                                	\N	\N	\N	RÉPUBLIQUE ARABE D'ÉGYPTE                                             	                    	Égypte	TEST	ÉGYPTE	Egypte	\N	\N	\N
99311	NAMIBIE                                                               	\N	\N	\N	RÉPUBLIQUE DE NAMIBIE                                                 	SUD-OUEST AFRICAIN  	Namibie	TEST	NAMIBIE	Namibie	\N	\N	\N
99322	CAMEROUN                                                              	\N	\N	\N	RÉPUBLIQUE DU CAMEROUN                                                	                    	Cameroun	TEST	CAMEROUN	Cameroun	\N	\N	\N
99336	MAURITANIE                                                            	\N	\N	\N	RÉPUBLIQUE ISLAMIQUE DE MAURITANIE                                    	                    	Mauritanie	TEST	MAURITANIE	Mauritanie	\N	\N	\N
99343	SOUDAN                                                                	\N	\N	\N	RÉPUBLIQUE DU SOUDAN                                                  	ANGLO-EGYPTIEN      	Soudan	TEST	SOUDAN	Soudan	\N	\N	\N
99351	TUNISIE                                                               	\N	\N	\N	RÉPUBLIQUE TUNISIENNE                                                 	                    	Tunisie	TEST	TUNISIE	Tunisie	\N	\N	\N
99395	ANGOLA                                                                	\N	\N	\N	RÉPUBLIQUE D'ANGOLA                                                   	                    	Angola	TEST	ANGOLA	Angola	\N	\N	\N
99416	BRÉSIL                                                                	\N	1	960 	RÉPUBLIQUE FÉDÉRATIVE DU BRÉSIL                                       	                    	Brésil	TEST	BRÉSIL	Brésil	\N	\N	\N
99418	BOLIVIE                                                               	\N	1	960 	RÉPUBLIQUE DE BOLIVIE                                                 	                    	Bolivie	TEST	BOLIVIE	Bolivie	\N	\N	\N
99419	COLOMBIE                                                              	\N	1	960 	RÉPUBLIQUE DE COLOMBIE                                                	                    	Colombie	TEST	COLOMBIE	Colombie	\N	\N	\N
99420	EQUATEUR                                                              	\N	1	960 	RÉPUBLIQUE DE L'ÉQUATEUR                                              	                    	Equateur	TEST	EQUATEUR	Equateur	\N	\N	\N
99421	PARAGUAY                                                              	\N	1	957 	RÉPUBLIQUE DU PARAGUAY                                                	                    	Paraguay	TEST	PARAGUAY	Paraguay	\N	\N	\N
99422	PEROU                                                                 	\N	1	958 	RÉPUBLIQUE DU PÉROU                                                   	                    	Pérou	TEST	PEROU	Pérou	\N	\N	\N
99423	URUGUAY                                                               	\N	1	960 	RÉPUBLIQUE ORIENTALE DE L'URUGUAY                                     	                    	Uruguay	TEST	URUGUAY	Uruguay	\N	\N	\N
99426	JAMAIQUE                                                              	\N	1	1962	JAMAÏQUE                                                              	                    	Jamaïque	TEST	JAMAIQUE	Jamaque	\N	\N	\N
99428	GUYANA                                                                	\N	1	1966	RÉPUBLIQUE COOPÉRATIVE DE GUYANA                                      	GUYANE BRITANNIQUE  	Guyana	TEST	GUYANA	Guyana	\N	\N	\N
99429	BELIZE                                                                	\N	1	1981	BÉLIZE                                                                	HONDURAS BRITANNIQUE	Belize	TEST	BELIZE	Belize	\N	\N	\N
99433	TRINITE-ET-TOBAGO                                                     	\N	1	1962	RÉPUBLIQUE DE TRINITÉ-ET-TOBAGO                                       	                    	Trinité-et-Tobago	TEST	TRINITE-ET-TOBAGO	Trinité-et-Tobago	\N	\N	\N
99434	BARBADE                                                               	\N	1	1966	BARBADE                                                               	                    	Barbade	TEST	BARBADE	Barbade	\N	\N	\N
99435	GRENADE                                                               	\N	1	1974	GRENADE                                                               	                    	Grenade	TEST	GRENADE	Grenade	\N	\N	\N
99437	SURINAME                                                              	\N	1	1975	RÉPUBLIQUE DU SURINAME                                                	GUYANE NEERLANDAISE 	Suriname	TEST	SURINAME	Suriname	\N	\N	\N
99438	DOMINIQUE                                                             	\N	1	1978	COMMONWEALTH DE DOMINIQUE                                             	                    	Dominique	TEST	DOMINIQUE	Dominique	\N	\N	\N
99439	SAINTE-LUCIE                                                          	\N	1	1979	SAINTE-LUCIE                                                          	                    	Sainte-Lucie	TEST	SAINTE-LUCIE	Sainte-Lucie	\N	\N	\N
99440	SAINT-VINCENT-ET-LES GRENADINES                                       	\N	1	1979	SAINT-VINCENT-ET-LES GRENADINES                                       	                    	Saint-Vincent-Les Grenadines	TEST	SAINT-VINCENT-LES GRENADINES	Saint-Vincent-Les Grenadines	\N	\N	\N
99441	ANTIGUA-ET-BARBUDA                                                    	\N	1	1981	ANTIGUA-ET-BARBUDA                                                    	                    	Antigua-et-Barbuda	TEST	ANTIGUA-ET-BARBUDA	Antigua-et-Barbuda	\N	\N	\N
99442	SAINT-CHRISTOPHE-ET-NIEVES                                            	\N	1	1983	FÉDÉRATION DE SAINT-CHRISTOPHE-ET-NIEVES                              	                    	Saint-Christophe-et-Nieves	TEST	SAINT-CHRISTOPHE-ET-NIEVES	Saint-Christophe-et-Nieves	\N	\N	\N
99501	AUSTRALIE                                                             	\N	1	964 	COMMONWEALTH D'AUSTRALIE                                              	                    	Australie	TEST	AUSTRALIE	Australie	\N	\N	\N
99506	SAMOA                                                     	\N	1	1962	ÉTAT INDÉPENDANT DES SAMOA                             	                    	Samoa	TEST	SAMOA	Samoa	\N	\N	\N
99507	NAURU                                                                 	\N	1	1968	RÉPUBLIQUE DE NAURU                                                   	                    	Nauru	TEST	NAURU	Nauru	\N	\N	\N
99508	FIDJI                                                                 	\N	1	1970	RÉPUBLIQUE DES FIDJI                                                  	                    	Fidji	TEST	FIDJI	Fidji	\N	\N	\N
99509	TONGA                                                                 	\N	1	1970	ROYAUME DES TONGA                                                     	                    	Tonga	TEST	TONGA	Tonga	\N	\N	\N
99510	PAPOUASIE-NOUVELLE-GUINEE                                             	\N	1	1975	PAPOUASIE-NOUVELLE-GUINÉE                                             	                    	Papouasie-Nouvelle-Guinée	TEST	PAPOUASIE-NOUVELLE-GUINEE	Papouasie-Nouvelle-Guinée	\N	\N	\N
99512	SALOMON (ILES)                                                        	\N	1	1978	ILES SALOMON                                                          	ILES SALOMON DU SUD 	Salomon (Iles)	TEST	SALOMON (ILES)	Salomon (Iles)	\N	\N	\N
99513	KIRIBATI                                                              	\N	1	1979	RÉPUBLIQUE DES KIRIBATI                                               	ILES GILBERT        	Kiribati	TEST	KIRIBATI	Kiribati	\N	\N	\N
99514	VANUATU                                                               	\N	1	1980	RÉPUBLIQUE DE VANUATU                                                 	NOUVELLES-HEBRIDES  	Vanuatu	TEST	VANUATU	Vanuatu	\N	\N	\N
99133	GIBRALTAR	\N	4	\N	GIBRALTAR	\N	Gibraltar	TEST	GIBRALTAR	Gibraltar	\N	\N	\N
99262	TIMOR ORIENTAL	\N	1	\N	RÉPUBLIQUE DÉMOCRATIQUE DU TIMOR ORIENTAL	\N	Timor Oriental	TEST	TIMOR ORIENTAL	Timor Oriental	\N	\N	\N
99306	SAINTE-HELENE	\N	4	\N	SAINTE-HÉLÈNE	\N	Sainte-Hélène	TEST	SAINTE-HÉLÈNE	Sainte-Hélène	\N	\N	\N
99515	MARSHALL (ILES)                                                       	\N	1	1991	RÉPUBLIQUE DES ILES MARSHALL                                          	                    	Marshall (Iles)	TEST	MARSHALL (ILES)	Marshall (Iles)	\N	\N	\N
99516	MICRONÉSIE (ÉTATS FÉDÉRÉS DE)                                         	\N	1	1991	ÉTATS FÉDÉRÉS DE MICRONÉSIE                                           	                    	Micronésie (États fédérés de)	TEST	MICRONÉSIE (ÉTATS FÉDÉRÉS DE)	Micronésie (États fédérés de)	\N	\N	\N
99517	PALAOS (ILES)	\N	1	1994	RÉPUBLIQUE DES PALAOS                                            	BELAU               	Palaos (Iles)	TEST	PALAOS (ILES)	Palaos (Iles)	\N	\N	\N
XXXXX	FRANCE                                                                	\N	1	975 	RÉPUBLIQUE FRANÇAISE                                                  	                    	France	UE	FRANCE	France	\N	\N	\N
99121	SERBIE	\N	1	\N	SERBIE	SERBIE-ET-MONTÉNÉGRO	Serbie	TEST	SERBIE	Serbie	\N	\N	\N
99120	MONTÉNÉGRO	\N	1	\N	SERBIE-ET-MONTÉNÉGRO	SERBIE-ET-MONTÉNÉGRO	Monténégro	TEST	MONTÉNÉGRO	Monténégro	\N	\N	\N
XX002	KOSOVO	\N	\N	\N	KOSOVO	KOSOVO	Kosovo	TEST	KOSOVO	Kosovo	\N	\N	\N
99137	LUXEMBOURG                                                            	\N	\N	\N	GRAND-DUCHÉ DE LUXEMBOURG                                             	                    	Luxembourg	UE	LUXEMBOURG	Luxembourg	\N	\N	\N
995021	COOK (ILES)	\N	3	\N	COOK( ILES)	\N	Cook (Iles)	TEST	COOK (ILES)	Cook (Iles)	\N	\N	\N
995022	NIUÉ	\N	3	\N	NIUÉ	\N	Niué	TEST	NIUÉ	Niué	\N	\N	\N
995023	TOKELAU	\N	3	\N	TOKELAU	\N	Tokelau	TEST	TOKELAU	Tokelau	\N	\N	\N
XX003	QUEBEC	\N	0	\N	QUEBEC	QUEBEC	Québec	TEST	QUEBEC	Québec	\N	\N	\N
99257	KIRGHIZISTAN                                                          	\N	\N	\N	RÉPUBLIQUE DU KIRGHIZISTAN                                            	                    	Kirghizistan	TEST	KIRGHIZISTAN	Kirghizistan	\N	\N	\N
99258	OUZBEKISTAN                                                           	\N	\N	\N	RÉPUBLIQUE D'OUZBÉKISTAN                                              	                    	Ouzbékistan	TEST	OUZBEKISTAN	Ouzbékistan	\N	\N	\N
99259	TADJIKISTAN                                                           	\N	\N	\N	RÉPUBLIQUE DU TADJIKISTAN                                             	                    	Tadjikistan	TEST	TADJIKISTAN	Tadjikistan	\N	\N	\N
99260	TURKMENISTAN                                                          	\N	\N	\N	TURKMÉNISTAN                                                          	                    	Turkménistan	TEST	TURKMÉNISTAN	Turkménistan	\N	\N	\N
99261	PALESTINE                                                             	\N	\N	\N	TERR. ISRAÉLO-PALESTINIEN DE GAZA ET DE CISJORDANIE                   	                    	Palestine	TEST	PALESTINE	Palestine	\N	\N	\N
99302	LIBERIA                                                               	\N	\N	\N	RÉPUBLIQUE DU LIBÉRIA                                                 	                    	Liberia	TEST	LIBERIA	Liberia	\N	\N	\N
99303	AFRIQUE DU SUD                                                        	\N	\N	\N	REPUBLIQUE D'AFRIQUE DU SUD                                           	UNION SUD-AFRICAINE 	Afrique du Sud	TEST	AFRIQUE DU SUD	Afrique Du Sud	\N	\N	\N
99304	GAMBIE                                                                	\N	\N	\N	REPUBLIQUE DE GAMBIE                                                  	                    	Gambie	TEST	GAMBIE	Gambie	\N	\N	\N
99309	TANZANIE                                                              	\N	\N	\N	REPUBLIQUE UNIE DE TANZANIE                                           	TANGANYIKA, ZANZIBAR	Tanzanie	TEST	TANZANIE	Tanzanie	\N	\N	\N
99310	ZIMBABWE                                                              	\N	\N	\N	REPUBLIQUE DU ZIMBABWE                                                	RHODESIE DU SUD     	Zimbabwe	TEST	ZIMBABWE	Zimbabwe	\N	\N	\N
99312	CONGO (RÉPUBLIQUE DÉMOCRATIQUE)	\N	\N	\N	RÉPUBLIQUE DU ZAÏRE                                                   	CONGO-KINSHASA      	Congo - R. D.	TEST	CONGO - R. D.	Congo - R. D.	\N	\N	\N
99314	GUINÉE ÉQUATORIALE                                                    	\N	\N	\N	RÉPUBLIQUE DE GUINÉE ÉQUATORIALE                                      	GUINÉE ESPAGNOLE     	Guinée équatoriale	TEST	GUINÉE ÉQUATORIALE	Guinée équatoriale	\N	\N	\N
XX004	TIBET	\N	0	\N	TIBET	TIBET	Tibet	TEST	TIBET	Tibet	\N	\N	\N
99315	ÉTHIOPIE                                                              	\N	\N	\N	RÉPUBLIQUE D'ÉTHIOPIE                                                 	ABYSSINIE           	Éthiopie	TEST	ÉTHIOPIE	Ethiopie	\N	\N	\N
99316	LIBYE                                                                 	\N	\N	\N	JAMAHIRIYA ARABE LIBYENNE POPULAIRE ET SOCIALISTE                     	CYRÉNAÏQUE          	Libye	TEST	LIBYE	Libye	\N	\N	\N
99317	ÉRYTHRÉE                                                              	\N	\N	\N	RÉPUBLIQUE D'ÉRYTHRÉE                                                 	                    	Érythrée	TEST	ÉRYTHRÉE	Erythrée	\N	\N	\N
99318	SOMALIE                                                               	\N	\N	\N	SOMALIE                                                               	                    	Somalie	TEST	SOMALIE	Somalie	\N	\N	\N
99321	BURUNDI                                                               	\N	\N	\N	RÉPUBLIQUE DU BURUNDI                                                 	URUNDI              	Burundi	TEST	BURUNDI	Burundi	\N	\N	\N
99323	CENTRAFRICAINE (RÉPUBLIQUE)                                           	\N	\N	\N	RÉPUBLIQUE CENTRAFRICAINE                                             	OUBANGUI-CHARI      	Centrafrique	TEST	CENTRAFRIQUE	Centrafrique	\N	\N	\N
99308	OCEAN INDIEN (TERRITOIRE BRITANNIQUE DE L')	\N	4	\N	OCÉAN INDIEN (TERRITOIRE BRITANNIQUE DE L')	\N	Ocean Indien (Territoire Britannique De L')	TEST	OCEAN INDIEN (TERRITOIRE BRITANNIQUE DE L')	Ocean Indien (Territoire Britannique De L')	\N	\N	\N
99319	AÇORES, MADÈRE	\N	4	\N	AÇORES, MADÈRE	\N	Açores, Madère	TEST	AÇORES, MADÈRE	Açores, Madère	\N	\N	\N
99324	CONGO                                                                 	\N	\N	\N	RÉPUBLIQUE DU CONGO	CONGO-BRAZZAVILLE   	Congo (République du)	TEST	REPUBLIQUE DU CONGO	Congo	\N	\N	\N
99326	COTE D'IVOIRE                                                         	\N	\N	\N	RÉPUBLIQUE DE CÔTE D'IVOIRE                                          	                    	Côte d'Ivoire	TEST	COTE D'IVOIRE	Côte d'Ivoire	\N	\N	\N
99327	BÉNIN                                                                 	\N	\N	\N	RÉPUBLIQUE DU BÉNIN                                                   	DAHOMEY             	Bénin	TEST	BÉNIN	Bénin	\N	\N	\N
99328	GABON                                                                 	\N	\N	\N	RÉPUBLIQUE GABONAISE                                                  	                    	Gabon	TEST	GABON	Gabon	\N	\N	\N
99397	COMORES                                                               	\N	\N	\N	UNION DES COMORES                             	                    	Comores	TEST	COMORES	Comores	\N	\N	\N
99398	SEYCHELLES                                                            	\N	\N	\N	REPUBLIQUE DES SEYCHELLES                                             	                    	Seychelles	TEST	SEYCHELLES	Seychelles	\N	\N	\N
99399	DJIBOUTI                                                              	\N	\N	\N	RÉPUBLIQUE DE DJIBOUTI                                                	T.F. AFARS ET ISSAS 	Djibouti	TEST	DJIBOUTI	Djibouti	\N	\N	\N
99401	CANADA                                                                	\N	\N	\N	CANADA                                                                	                    	Canada	TEST	CANADA	Canada	\N	\N	\N
99404	ÉTATS-UNIS                                                            	\N	\N	\N	ÉTATS-UNIS D'AMÉRIQUE                                                 	                    	États-Unis	TEST	ÉTATS-UNIS	Etats-Unis	\N	\N	\N
99406	COSTA RICA                                                            	\N	\N	\N	RÉPUBLIQUE DU COSTA RICA                                              	                    	Costa Rica	TEST	COSTA RICA	Costa Rica	\N	\N	\N
99407	CUBA                                                                  	\N	\N	\N	RÉPUBLIQUE DE CUBA                                                    	                    	Cuba	TEST	CUBA	Cuba	\N	\N	\N
99408	DOMINICAINE (RÉPUBLIQUE)	\N	\N	\N	RÉPUBLIQUE DOMINICAINE                                                	SAINT-DOMINGUE      	Dominicaine (République)	TEST	RÉPUBLIQUE DOMINICAINE	République Dominicaine	\N	\N	\N
99409	GUATEMALA                                                             	\N	\N	\N	RÉPUBLIQUE DU GUATÉMALA                                               	                    	Guatemala	TEST	GUATEMALA	Guatemala	\N	\N	\N
99410	HAITI                                                                 	\N	\N	\N	RÉPUBLIQUE D'HAÏTI                                                    	                    	Haïti	TEST	HAITI	Haïti	\N	\N	\N
99412	NICARAGUA                                                             	\N	\N	\N	RÉPUBLIQUE DU NICARAGUA                                               	                    	Nicaragua	TEST	NICARAGUA	Nicaragua	\N	\N	\N
99413	PANAMA                                                                	\N	\N	\N	RÉPUBLIQUE DU PANAMA                                                  	                    	Panama	TEST	PANAMA	Panama	\N	\N	\N
99414	EL SALVADOR                                                           	\N	\N	\N	RÉPUBLIQUE DU SALVADOR                                                	                    	El Salvador	TEST	EL SALVADOR	El Salvador	\N	\N	\N
99415	ARGENTINE                                                             	\N	1	961 	RÉPUBLIQUE ARGENTINE                                                  	                    	Argentine	TEST	ARGENTINE	Argentine	\N	\N	\N
99132	ROYAUME-UNI                                                           	\N	\N	\N	ROYAUME-UNI DE GRANDE-BRETAGNE ET D'IRLANDE DU NORD                   	                    	Royaume-Uni	UE	ROYAUME-UNI	Royaume-Uni	\N	\N	\N
99134	ESPAGNE                                                               	\N	\N	\N	ROYAUME D'ESPAGNE                                                     	                    	Espagne	UE	ESPAGNE	Espagne	\N	\N	\N
99135	PAYS-BAS                                                              	\N	\N	\N	ROYAUME DES PAYS-BAS                                                  	HOLLANDE            	Pays-Bas	UE	PAYS-BAS	Pays-Bas	\N	\N	\N
99136	IRLANDE, ou EIRE                                                      	\N	\N	\N	RÉPUBLIQUE D'IRLANDE                                                  	                    	Irlande	UE	IRLANDE	Irlande	\N	\N	\N
99138	MONACO                                                                	\N	\N	\N	PRINCIPAUTE DE MONACO                                                 	                    	Monaco	TEST	MONACO	Monaco	\N	\N	\N
99139	PORTUGAL                                                              	\N	\N	\N	RÉPUBLIQUE PORTUGAISE                                                 	                    	Portugal	UE	PORTUGAL	Portugal	\N	\N	\N
99140	SUISSE                                                                	\N	\N	\N	CONFEDERATION SUISSE                                                  	                    	Suisse	TEST	SUISSE	Suisse	\N	\N	\N
99144	MALTE                                                                 	\N	\N	\N	RÉPUBLIQUE DE MALTE                                                   	                    	Malte	UE	MALTE	Malte	\N	\N	\N
99145	SLOVÉNIE                                                              	\N	\N	\N	RÉPUBLIQUE DE SLOVÉNIE                                                	                    	Slovénie	UE	SLOVÉNIE	Slovénie	\N	\N	\N
99148	BIÉLORUSSIE                                                           	\N	\N	\N	RÉPUBLIQUE DE BIÉLORUSSIE                                             	                    	Biélorussie	TEST	BIÉLORUSSIE	Biélorussie	\N	\N	\N
99155	UKRAINE                                                               	\N	\N	\N	UKRAINE                                                               	                    	Ukraine	TEST	UKRAINE	Ukraine	\N	\N	\N
99156	EX-RÉPUBLIQUE YOUGOSLAVE DE MACÉDOINE               	\N	\N	\N	EX-RÉPUBLIQUE YOUGOSLAVE DE MACÉDOINE                                 	                    	Macédoine	TEST	MACÉDOINE	Macédoine	\N	\N	\N
99203	IRAQ	\N	\N	\N	RÉPUBLIQUE D'IRAQ                    	                    	Iraq	TEST	IRAQ	Iraq	\N	\N	\N
99204	IRAN                                                                  	\N	\N	\N	RÉPUBLIQUE ISLAMIQUE D'IRAN                                           	PERSE               	Iran	TEST	IRAN	Iran	\N	\N	\N
99205	LIBAN                                                                 	\N	\N	\N	RÉPUBLIQUE LIBANAISE                                                  	                    	Liban	TEST	LIBAN	Liban	\N	\N	\N
99206	SYRIE                                                                 	\N	\N	\N	RÉPUBLIQUE ARABE SYRIENNE                                             	                    	Syrie	TEST	SYRIE	Syrie	\N	\N	\N
99207	ISRAËL                                                                	\N	\N	\N	ÉTAT D'ISRAËL                                                         	                    	Israël	TEST	ISRAËL	Israël	\N	\N	\N
99208	TURQUIE                                                               	\N	\N	\N	RÉPUBLIQUE TURQUE                                                     	                    	Turquie	TEST	TURQUIE	Turquie	\N	\N	\N
99212	AFGHANISTAN                                                           	\N	\N	\N	ÉTAT ISLAMIQUE D'AFGHANISTAN                                          	                    	Afghanistan	TEST	AFGHANISTAN	Afghanistan	\N	\N	\N
99329	GHANA                                                                 	\N	\N	\N	RÉPUBLIQUE DU GHANA                                                   	COTE-DE-L'OR        	Ghana	TEST	GHANA	Ghana	\N	\N	\N
99330	GUINEE                                                                	\N	\N	\N	RÉPUBLIQUE DE GUINÉE                                                  	GUINEE FRANCAISE    	Guinée Conakry	TEST	GUINEE CONAKRY	Guinée Conakry	\N	\N	\N
99331	BURKINA                                                               	\N	\N	\N	BURKINA FASO                                                          	HAUTE-VOLTA         	Burkina Faso	TEST	BURKINA FASO	Burkina Faso	\N	\N	\N
99332	KENYA                                                                 	\N	\N	\N	RÉPUBLIQUE DU KÉNYA                                                   	                    	Kenya	TEST	KENYA	Kenya	\N	\N	\N
99333	MADAGASCAR                                                            	\N	\N	\N	RÉPUBLIQUE DE MADAGASCAR                                              	                    	Madagascar	TEST	MADAGASCAR	Madagascar	\N	\N	\N
99334	MALAWI                                                                	\N	\N	\N	RÉPUBLIQUE DU MALAWI                                                  	NYASSALAND          	Malawi	TEST	MALAWI	Malawi	\N	\N	\N
99335	MALI                                                                  	\N	\N	\N	RÉPUBLIQUE DU MALI                                                    	SOUDAN FRANCAIS     	Mali	TEST	MALI	Mali	\N	\N	\N
99337	NIGER                                                                 	\N	\N	\N	RÉPUBLIQUE DU NIGER                                                   	                    	Niger	TEST	NIGER	Niger	\N	\N	\N
99338	NIGERIA                                                               	\N	\N	\N	REPUBLIQUE FEDERALE DU NIGERIA                                        	                    	Nigeria	TEST	NIGERIA	Nigeria	\N	\N	\N
99425	ANGUILLA	\N	4	\N	ANGUILLA	\N	Anguilla	TEST	ANGUILLA	Anguilla	\N	\N	\N
99430	GROENLAND	\N	4	\N	GROENLAND	\N	Groenland	TEST	GROENLAND	Groenland	\N	\N	\N
99503	PITCAIRN (ILE)	\N	4	\N	PITCAIRN (ÎLE)	\N	Pitcairn (Ile)	TEST	PITCAIRN (ILE)	Pitcairn (Ile)	\N	\N	\N
99339	OUGANDA                                                               	\N	\N	\N	REPUBLIQUE DE L'OUGANDA                                               	                    	Ouganda	TEST	OUGANDA	Ouganda	\N	\N	\N
99340	RWANDA                                                                	\N	\N	\N	REPUBLIQUE RWANDAISE                                                  	RUANDA              	Rwanda	TEST	RWANDA	Rwanda	\N	\N	\N
99341	SENEGAL                                                               	\N	\N	\N	REPUBLIQUE DU SENEGAL                                                 	                    	Sénégal	TEST	SENEGAL	Sénégal	\N	\N	\N
99342	SIERRA LEONE                                                          	\N	\N	\N	REPUBLIQUE DE SIERRA LEONE                                            	                    	Sierra Leone	TEST	SIERRA LEONE	Sierra Leone	\N	\N	\N
99344	TCHAD                                                                 	\N	\N	\N	REPUBLIQUE DU TCHAD                                                   	                    	Tchad (République du)	TEST	TCHAD (Republique du)	Tchad (République du)	\N	\N	\N
99345	TOGO                                                                  	\N	\N	\N	REPUBLIQUE TOGOLAISE                                                  	                    	Togo	TEST	TOGO	Togo	\N	\N	\N
99505	MARIANNES DU NORD (ILES)	\N	4	\N	MARIANNES DU NORD (ÎLES)	\N	Mariannes du Nord (Iles)	TEST	MARIANNES DU NORD (ILES)	Mariannes du Nord (Iles)	\N	\N	\N
99346	ZAMBIE                                                                	\N	\N	\N	REPUBLIQUE DE ZAMBIE                                                  	RHODESIE DU NORD    	Zambie	TEST	ZAMBIE	Zambie	\N	\N	\N
99347	BOTSWANA                                                              	\N	\N	\N	RÉPUBLIQUE DU BOTSWANA                                                	BECHUANALAND        	Botswana	TEST	BOTSWANA	Botswana	\N	\N	\N
99348	LESOTHO                                                               	\N	\N	\N	ROYAUME DU LESOTHO                                                    	BASUTOLAND          	Lesotho	TEST	LESOTHO	Lesotho	\N	\N	\N
99350	MAROC                                                                 	\N	\N	\N	ROYAUME DU MAROC                                                      	                    	Maroc	TEST	MAROC	Maroc	\N	\N	\N
99352	ALGÉRIE                                                               	\N	\N	\N	RÉPUBLIQUE ALGÉRIENNE DÉMOCRATIQUE ET POPULAIRE                       	                    	Algérie	TEST	ALGÉRIE	Algérie	\N	\N	\N
99389	SAHARA OCCIDENTAL                                                     	\N	\N	\N	SAHARA OCCIDENTAL                                                     	                    	Sahara Occidental	TEST	SAHARA OCCIDENTAL	Sahara Occidental	\N	\N	\N
99390	MAURICE                                                               	\N	\N	\N	RÉPUBLIQUE DE MAURICE                                                 	                    	Maurice (Ile)	TEST	MAURICE (Ile)	Maurice (Ile)	\N	\N	\N
99391	SWAZILAND                                                             	\N	\N	\N	ROYAUME DU SWAZILAND                                                  	                    	Swaziland	TEST	SWAZILAND	Swaziland	\N	\N	\N
99392	GUINÉE-BISSAU                                                         	\N	\N	\N	RÉPUBLIQUE DE GUINÉE-BISSAO                                           	GUINÉE PORTUGAISE   	Guinée-Bissau	TEST	GUINÉE-BISSAU	Guinée-Bissau	\N	\N	\N
99393	MOZAMBIQUE                                                            	\N	\N	\N	RÉPUBLIQUE DU MOZAMBIQUE                                              	                    	Mozambique	TEST	MOZAMBIQUE	Mozambique	\N	\N	\N
99394	SAO TOMÉ-ET-PRINCIPE                                                  	\N	\N	\N	RÉPUBLIQUE DÉMOCRATIQUE DE SAO TOMÉ-ET-PRINCIPE                       	                    	Sao Tomé-et-Principe	TEST	SAO TOMÉ-ET-PRINCIPE	Sao Tomé-et-Principe	\N	\N	\N
99396	CAP-VERT                                                              	\N	\N	\N	RÉPUBLIQUE DU CAP-VERT                                                	                    	Cap-Vert	TEST	CAP-VERT	Cap-Vert	\N	\N	\N
99151	MOLDAVIE                                                              	\N	\N	\N	RÉPUBLIQUE DE MOLDAVIE                                                	                    	Moldavie	TEST	MOLDAVIE	Moldavie	\N	\N	\N
99201	ARABIE SAOUDITE                                                       	\N	\N	\N	ROYAUME D'ARABIE SAOUDITE                                             	                    	Arabie saoudite	TEST	ARABIE SAOUDITE	Arabie saoudite	\N	\N	\N
99217	JAPON                                                                 	\N	\N	\N	JAPON                                                                 	                    	Japon	TEST	JAPON	Japon	\N	\N	\N
99226	SINGAPOUR                                                             	\N	\N	\N	RÉPUBLIQUE DE SINGAPOUR                                               	ETABLS. DES DETROITS	Singapour	TEST	SINGAPOUR	Singapour	\N	\N	\N
99239	COREE (REPUBLIQUE DE)                                                 	\N	\N	\N	RÉPUBLIQUE DE CORÉE                                                   	                    	Corée (Republique De)	TEST	COREE (REPUBLIQUE DE)	Corée (Republique De)	\N	\N	\N
99247	EMIRATS ARABES UNIS                                                   	\N	\N	\N	ÉMIRATS ARABES UNIS                                                   	                    	Émirats Arabes Unis	TEST	ÉMIRATS ARABES UNIS	Emirats Arabes Unis	\N	\N	\N
99256	KAZAKHSTAN                                                            	\N	\N	\N	RÉPUBLIQUE DU KAZAKHSTAN                                              	                    	Kazakhstan	TEST	KAZAKHSTAN	Kazakhstan	\N	\N	\N
99106	ESTONIE                                                               	\N	\N	\N	RÉPUBLIQUE D'ESTONIE                                                  	                    	Estonie	UE	ESTONIE	Estonie	\N	\N	\N
99113	LIECHTENSTEIN                                                         	\N	\N	\N	PRINCIPAUTÉ DU LIECHTENSTEIN                                          	                    	Liechtenstein	TEST	LIECHTENSTEIN	Liechtenstein	\N	\N	\N
99129	VATICAN, ou SAINT-SIÈGE                                               	\N	\N	\N	ÉTAT DE LA CITÉ DU VATICAN                                            	                    	Vatican, ou Saint-Siège	TEST	VATICAN, ou SAINT-SIÈGE	Vatican, ou Saint-Siège	\N	\N	\N
XX005	DAHOMEY	\N	\N	\N	RÉPUBLIQUE DU DAHOMEY	\N	Dahomey	TEST	DAHOMEY	Dahomey	\N	2015-02-10 11:08:49	\N
XX006	HAUTE-VOLTA	\N	\N	\N	RÉPUBLIQUE DE HAUTE-VOLTA	\N	Haute-Volta	TEST	HAUTE-VOLTA	Haute-Volta	\N	2015-02-10 11:08:53	\N
XX007	SOUDAN FRANCAIS	\N	\N	\N	SOUDAN FRANCAIS	\N	Soudan Français	TEST	SOUDAN FRANCAIS	Soudan Français	\N	2015-02-10 11:08:56	\N
XX008	TCHAD	\N	\N	\N	TCHAD	\N	Tchad	TEST	TCHAD	Tchad	\N	2015-02-10 11:08:59	\N
\.


--
-- Data for Name: nationgrpsen; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY nationgrpsen (nationgrpsenid, orgcod, nationcod, nationgpsendatdeb, nationgrpsendatfin, temvalcod, evelic, evelib, evelil, eveobs, syscredat, sysmajdat) FROM stdin;
1	674	99121	\N	\N	\N	\N	\N	\N	\N	\N	\N
2	674	99120	\N	\N	\N	\N	\N	\N	\N	\N	\N
3	674	99118	\N	\N	\N	\N	\N	\N	\N	\N	\N
4	674	99156	\N	\N	\N	\N	\N	\N	\N	\N	\N
5	626	99243	\N	\N	\N	\N	\N	\N	\N	\N	\N
6	673	99138	\N	\N	\N	\N	\N	\N	\N	\N	\N
7	634	XX004	\N	\N	\N	\N	\N	\N	\N	\N	\N
8	642	99425	\N	\N	\N	\N	\N	\N	\N	\N	\N
9	602	XX003	\N	\N	\N	\N	\N	\N	\N	\N	\N
10	627	99251	\N	\N	\N	\N	\N	\N	\N	\N	\N
11	651	995021	\N	\N	\N	\N	\N	\N	\N	\N	\N
12	651	99508	\N	\N	\N	\N	\N	\N	\N	\N	\N
13	651	99505	\N	\N	\N	\N	\N	\N	\N	\N	\N
14	651	995022	\N	\N	\N	\N	\N	\N	\N	\N	\N
15	651	99503	\N	\N	\N	\N	\N	\N	\N	\N	\N
16	651	995023	\N	\N	\N	\N	\N	\N	\N	\N	\N
17	572	99340	\N	\N	\N	\N	\N	\N	\N	\N	\N
18	572	99344	\N	\N	\N	\N	\N	\N	\N	\N	\N
19	556	99257	\N	\N	\N	\N	\N	\N	\N	\N	\N
20	556	99260	\N	\N	\N	\N	\N	\N	\N	\N	\N
21	609	99220	\N	\N	\N	\N	\N	\N	\N	\N	\N
22	609	99224	\N	\N	\N	\N	\N	\N	\N	\N	\N
23	642	99441	\N	\N	\N	\N	\N	\N	\N	\N	\N
24	642	99434	\N	\N	\N	\N	\N	\N	\N	\N	\N
25	642	99438	\N	\N	\N	\N	\N	\N	\N	\N	\N
26	642	99439	\N	\N	\N	\N	\N	\N	\N	\N	\N
27	642	99426	\N	\N	\N	\N	\N	\N	\N	\N	\N
28	588	99317	\N	\N	\N	\N	\N	\N	\N	\N	\N
29	625	99104	\N	\N	\N	\N	\N	\N	\N	\N	\N
30	625	99102	\N	\N	\N	\N	\N	\N	\N	\N	\N
31	622	99332	\N	\N	\N	\N	\N	\N	\N	\N	\N
32	622	99390	\N	\N	\N	\N	\N	\N	\N	\N	\N
33	622	99398	\N	\N	\N	\N	\N	\N	\N	\N	\N
34	643	99409	\N	\N	\N	\N	\N	\N	\N	\N	\N
35	643	99412	\N	\N	\N	\N	\N	\N	\N	\N	\N
36	643	99413	\N	\N	\N	\N	\N	\N	\N	\N	\N
37	616	99106	\N	\N	\N	\N	\N	\N	\N	\N	\N
38	616	99107	\N	\N	\N	\N	\N	\N	\N	\N	\N
39	573	99326	\N	\N	\N	\N	\N	\N	\N	\N	\N
40	573	99329	\N	\N	\N	\N	\N	\N	\N	\N	\N
41	573	99302	\N	\N	\N	\N	\N	\N	\N	\N	\N
42	573	99336	\N	\N	\N	\N	\N	\N	\N	\N	\N
43	573	99338	\N	\N	\N	\N	\N	\N	\N	\N	\N
44	573	99342	\N	\N	\N	\N	\N	\N	\N	\N	\N
45	576	99428	\N	\N	\N	\N	\N	\N	\N	\N	\N
46	574	99348	\N	\N	\N	\N	\N	\N	\N	\N	\N
47	577	99234	\N	\N	\N	\N	\N	\N	\N	\N	\N
48	580	99131	\N	\N	\N	\N	\N	\N	\N	\N	\N
49	648	99212	\N	\N	\N	\N	\N	\N	\N	\N	\N
50	604	99109	\N	\N	\N	\N	\N	\N	\N	\N	\N
51	578	99501	\N	\N	\N	\N	\N	\N	\N	\N	\N
52	582	99111	\N	\N	\N	\N	\N	\N	\N	\N	\N
53	584	99216	\N	\N	\N	\N	\N	\N	\N	\N	\N
54	586	99238	\N	\N	\N	\N	\N	\N	\N	\N	\N
55	617	99301	\N	\N	\N	\N	\N	\N	\N	\N	\N
56	575	99352	\N	\N	\N	\N	\N	\N	\N	\N	\N
57	591	99126	\N	\N	\N	\N	\N	\N	\N	\N	\N
58	534	99253	\N	\N	\N	\N	\N	\N	\N	\N	\N
59	534	99255	\N	\N	\N	\N	\N	\N	\N	\N	\N
60	646	99395	\N	\N	\N	\N	\N	\N	\N	\N	\N
61	646	99347	\N	\N	\N	\N	\N	\N	\N	\N	\N
62	646	99334	\N	\N	\N	\N	\N	\N	\N	\N	\N
63	646	99311	\N	\N	\N	\N	\N	\N	\N	\N	\N
64	646	99346	\N	\N	\N	\N	\N	\N	\N	\N	\N
65	646	99310	\N	\N	\N	\N	\N	\N	\N	\N	\N
66	572	99321	\N	\N	\N	\N	\N	\N	\N	\N	\N
67	572	99322	\N	\N	\N	\N	\N	\N	\N	\N	\N
68	572	99323	\N	\N	\N	\N	\N	\N	\N	\N	\N
69	572	99324	\N	\N	\N	\N	\N	\N	\N	\N	\N
70	572	99328	\N	\N	\N	\N	\N	\N	\N	\N	\N
71	572	99314	\N	\N	\N	\N	\N	\N	\N	\N	\N
72	572	99339	\N	\N	\N	\N	\N	\N	\N	\N	\N
73	572	99312	\N	\N	\N	\N	\N	\N	\N	\N	\N
74	572	99394	\N	\N	\N	\N	\N	\N	\N	\N	\N
75	556	99256	\N	\N	\N	\N	\N	\N	\N	\N	\N
76	556	99258	\N	\N	\N	\N	\N	\N	\N	\N	\N
77	556	99259	\N	\N	\N	\N	\N	\N	\N	\N	\N
78	609	99219	\N	\N	\N	\N	\N	\N	\N	\N	\N
79	609	99226	\N	\N	\N	\N	\N	\N	\N	\N	\N
80	609	99227	\N	\N	\N	\N	\N	\N	\N	\N	\N
81	609	99246	\N	\N	\N	\N	\N	\N	\N	\N	\N
82	609	99225	\N	\N	\N	\N	\N	\N	\N	\N	\N
83	642	99436	\N	\N	\N	\N	\N	\N	\N	\N	\N
84	642	99407	\N	\N	\N	\N	\N	\N	\N	\N	\N
85	642	99408	\N	\N	\N	\N	\N	\N	\N	\N	\N
86	642	99410	\N	\N	\N	\N	\N	\N	\N	\N	\N
87	642	99433	\N	\N	\N	\N	\N	\N	\N	\N	\N
88	588	99315	\N	\N	\N	\N	\N	\N	\N	\N	\N
89	588	99318	\N	\N	\N	\N	\N	\N	\N	\N	\N
90	625	99103	\N	\N	\N	\N	\N	\N	\N	\N	\N
91	625	99101	\N	\N	\N	\N	\N	\N	\N	\N	\N
92	622	99397	\N	\N	\N	\N	\N	\N	\N	\N	\N
93	622	99229	\N	\N	\N	\N	\N	\N	\N	\N	\N
94	622	99393	\N	\N	\N	\N	\N	\N	\N	\N	\N
95	622	99309	\N	\N	\N	\N	\N	\N	\N	\N	\N
96	643	99429	\N	\N	\N	\N	\N	\N	\N	\N	\N
97	643	99411	\N	\N	\N	\N	\N	\N	\N	\N	\N
98	643	99406	\N	\N	\N	\N	\N	\N	\N	\N	\N
99	643	99405	\N	\N	\N	\N	\N	\N	\N	\N	\N
100	588	99399	\N	\N	\N	\N	\N	\N	\N	\N	\N
101	616	99108	\N	\N	\N	\N	\N	\N	\N	\N	\N
102	661	99201	\N	\N	\N	\N	\N	\N	\N	\N	\N
103	661	99247	\N	\N	\N	\N	\N	\N	\N	\N	\N
104	661	99249	\N	\N	\N	\N	\N	\N	\N	\N	\N
105	661	99248	\N	\N	\N	\N	\N	\N	\N	\N	\N
106	661	99250	\N	\N	\N	\N	\N	\N	\N	\N	\N
107	651	99513	\N	\N	\N	\N	\N	\N	\N	\N	\N
108	651	99515	\N	\N	\N	\N	\N	\N	\N	\N	\N
109	651	99516	\N	\N	\N	\N	\N	\N	\N	\N	\N
110	651	99507	\N	\N	\N	\N	\N	\N	\N	\N	\N
111	651	99517	\N	\N	\N	\N	\N	\N	\N	\N	\N
112	651	99510	\N	\N	\N	\N	\N	\N	\N	\N	\N
113	651	99512	\N	\N	\N	\N	\N	\N	\N	\N	\N
114	651	99506	\N	\N	\N	\N	\N	\N	\N	\N	\N
115	651	99509	\N	\N	\N	\N	\N	\N	\N	\N	\N
116	651	99511	\N	\N	\N	\N	\N	\N	\N	\N	\N
117	651	99514	\N	\N	\N	\N	\N	\N	\N	\N	\N
118	573	99327	\N	\N	\N	\N	\N	\N	\N	\N	\N
119	573	99331	\N	\N	\N	\N	\N	\N	\N	\N	\N
120	573	99396	\N	\N	\N	\N	\N	\N	\N	\N	\N
121	573	99304	\N	\N	\N	\N	\N	\N	\N	\N	\N
122	573	99330	\N	\N	\N	\N	\N	\N	\N	\N	\N
123	573	99392	\N	\N	\N	\N	\N	\N	\N	\N	\N
124	573	99335	\N	\N	\N	\N	\N	\N	\N	\N	\N
125	573	99337	\N	\N	\N	\N	\N	\N	\N	\N	\N
126	573	99341	\N	\N	\N	\N	\N	\N	\N	\N	\N
127	573	99345	\N	\N	\N	\N	\N	\N	\N	\N	\N
128	576	99416	\N	\N	\N	\N	\N	\N	\N	\N	\N
129	576	99437	\N	\N	\N	\N	\N	\N	\N	\N	\N
130	574	99303	\N	\N	\N	\N	\N	\N	\N	\N	\N
131	574	99391	\N	\N	\N	\N	\N	\N	\N	\N	\N
132	577	99241	\N	\N	\N	\N	\N	\N	\N	\N	\N
133	580	99137	\N	\N	\N	\N	\N	\N	\N	\N	\N
134	588	99343	\N	\N	\N	\N	\N	\N	\N	\N	\N
135	571	99125	\N	\N	\N	\N	\N	\N	\N	\N	\N
136	641	99252	\N	\N	\N	\N	\N	\N	\N	\N	\N
137	579	99110	\N	\N	\N	\N	\N	\N	\N	\N	\N
138	662	99118	\N	\N	\N	\N	\N	\N	\N	\N	\N
139	583	99401	\N	\N	\N	\N	\N	\N	\N	\N	\N
140	585	99254	\N	\N	\N	\N	\N	\N	\N	\N	\N
141	613	99239	\N	\N	\N	\N	\N	\N	\N	\N	\N
142	647	99119	\N	\N	\N	\N	\N	\N	\N	\N	\N
143	589	99134	\N	\N	\N	\N	\N	\N	\N	\N	\N
144	590	99404	\N	\N	\N	\N	\N	\N	\N	\N	\N
145	640	99105	\N	\N	\N	\N	\N	\N	\N	\N	\N
146	592	99112	\N	\N	\N	\N	\N	\N	\N	\N	\N
147	618	99223	\N	\N	\N	\N	\N	\N	\N	\N	\N
148	628	99204	\N	\N	\N	\N	\N	\N	\N	\N	\N
149	615	99203	\N	\N	\N	\N	\N	\N	\N	\N	\N
150	594	99136	\N	\N	\N	\N	\N	\N	\N	\N	\N
151	595	99207	\N	\N	\N	\N	\N	\N	\N	\N	\N
152	621	99127	\N	\N	\N	\N	\N	\N	\N	\N	\N
153	596	99217	\N	\N	\N	\N	\N	\N	\N	\N	\N
154	659	99222	\N	\N	\N	\N	\N	\N	\N	\N	\N
155	535	99240	\N	\N	\N	\N	\N	\N	\N	\N	\N
156	597	99205	\N	\N	\N	\N	\N	\N	\N	\N	\N
157	657	99316	\N	\N	\N	\N	\N	\N	\N	\N	\N
158	528	99156	\N	\N	\N	\N	\N	\N	\N	\N	\N
159	622	99333	\N	\N	\N	\N	\N	\N	\N	\N	\N
160	603	99144	\N	\N	\N	\N	\N	\N	\N	\N	\N
161	598	99350	\N	\N	\N	\N	\N	\N	\N	\N	\N
162	643	99414	\N	\N	\N	\N	\N	\N	\N	\N	\N
163	851	99151	\N	\N	\N	\N	\N	\N	\N	\N	\N
164	612	99242	\N	\N	\N	\N	\N	\N	\N	\N	\N
165	633	99215	\N	\N	\N	\N	\N	\N	\N	\N	\N
166	663	99502	\N	\N	\N	\N	\N	\N	\N	\N	\N
167	619	99213	\N	\N	\N	\N	\N	\N	\N	\N	\N
168	632	99261	\N	\N	\N	\N	\N	\N	\N	\N	\N
169	599	99135	\N	\N	\N	\N	\N	\N	\N	\N	\N
170	600	99122	\N	\N	\N	\N	\N	\N	\N	\N	\N
171	601	99139	\N	\N	\N	\N	\N	\N	\N	\N	\N
172	605	99114	\N	\N	\N	\N	\N	\N	\N	\N	\N
173	581	99132	\N	\N	\N	\N	\N	\N	\N	\N	\N
174	608	99123	\N	\N	\N	\N	\N	\N	\N	\N	\N
175	629	99129	\N	\N	\N	\N	\N	\N	\N	\N	\N
176	532	99117	\N	\N	\N	\N	\N	\N	\N	\N	\N
177	529	99145	\N	\N	\N	\N	\N	\N	\N	\N	\N
178	610	99140	\N	\N	\N	\N	\N	\N	\N	\N	\N
179	644	99206	\N	\N	\N	\N	\N	\N	\N	\N	\N
180	623	99236	\N	\N	\N	\N	\N	\N	\N	\N	\N
181	611	99116	\N	\N	\N	\N	\N	\N	\N	\N	\N
182	620	99351	\N	\N	\N	\N	\N	\N	\N	\N	\N
183	624	99208	\N	\N	\N	\N	\N	\N	\N	\N	\N
184	530	99155	\N	\N	\N	\N	\N	\N	\N	\N	\N
185	963	99130	\N	\N	\N	\N	\N	\N	\N	\N	\N
186	661	99240	\N	\N	\N	\N	\N	\N	\N	\N	\N
187	979	99418	\N	\N	\N	\N	\N	\N	\N	\N	\N
188	979	99419	\N	\N	\N	\N	\N	\N	\N	\N	\N
189	979	99420	\N	\N	\N	\N	\N	\N	\N	\N	\N
190	979	99422	\N	\N	\N	\N	\N	\N	\N	\N	\N
191	979	99424	\N	\N	\N	\N	\N	\N	\N	\N	\N
192	978	99415	\N	\N	\N	\N	\N	\N	\N	\N	\N
193	978	99417	\N	\N	\N	\N	\N	\N	\N	\N	\N
194	978	99423	\N	\N	\N	\N	\N	\N	\N	\N	\N
195	978	99421	\N	\N	\N	\N	\N	\N	\N	\N	\N
196	674	XX002	\N	\N	\N	\N	\N	\N	\N	\N	\N
197	653	99231	\N	\N	\N	\N	\N	\N	\N	\N	\N
200	550	99235	\N	\N	\N	\N	\N	\N	\N	\N	\N
300	852	99148	\N	\N	\N	\N	\N	\N	\N	\N	\N
\.


--
-- Data for Name: org; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY org (typorgcod, orgcod, temvalcod, evelic, evelib, evelil, orgart, orgnumtri, orgdatcre, orgdatfin, orgurlsim, orgurlcmp, orgregjur, orgmoddes, orgmemdep, orgtemannu, syscredat, sysmajdat) FROM stdin;
CONCST	CONCST	ANCIEN	Conseil constitutionnel	Conseil constitutionnel	Conseil constitutionnel	du	1	1899-12-31 00:50:39	2022-03-23 00:00:00	\N	\N	\N	\N	NON	OUI	\N	2014-01-30 11:14:11
AUTRES	CES	ANCIEN	Conseil économique, social et environnemental	Conseil économique, social et environnemental	Conseil économique, social et environnemental	du 	20	1925-01-01 00:00:00	2022-03-23 00:00:00	\N	\N	\N	\N	NON	NON	\N	2014-01-30 11:14:11
AUTRES	DCRUE	ANCIEN	Délégation au Comité des régions de l'UE	Délégation au Comité des régions de l'Union européenne	Délégation au Comité des régions de l'Union européenne	de la	18	1900-01-01 00:00:00	2022-10-17 00:00:00	\N	\N	\N	\N	NON	OUI	\N	2014-01-30 11:14:11
AUTRES	BASMED	ACTIF	bassin méditerranéen	commission du bassin méditerranéen	commission du Bassin méditerranéen	de la 	19	1900-01-01 00:00:00	\N	\N	\N	\N	\N	NON	OUI	\N	2014-01-30 11:14:11
AUTRES	COMREGUE	ANCIEN	Comité des régions de l'UE	Comité des régions de l'Union européenne	Comité des régions de l'Union européenne	du 	\N	1899-12-31 00:50:39	2022-10-17 00:00:00	\N	\N	\N	\N	NON	OUI	\N	2014-01-30 11:14:11
AUTRES	MEDIATEUR	ANCIEN	institution du Médiateur de la République	institution du Médiateur de la République	institution du Médiateur de la République	\N	\N	1900-01-01 00:00:00	2022-03-23 00:00:00	\N	\N	\N	\N	NON	OUI	\N	2014-01-30 11:14:11
AUTRES	APM	ANCIEN	APM	APM	Assemblée parlementaire de la Méditerranée	de la	999	2014-01-30 00:00:00	2014-01-30 00:00:00	/orgs/nouv/index.html	\N	\N	\N	\N	OUI	2014-01-30 11:14:11	2014-01-30 11:14:32
\.


--
-- Data for Name: orgext; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY orgext (typorgcod, orgcod, orgnumtri, orgdatcre, orgdatfin, orgnumtie, orgextregjur, orgextrubclas, orgextnbrsen, orgextdurman, temvalcod, evelic, evelib, evelil, eveobs, orgart, orgextmoddes, orgextminrat, orgextrep, orgurlsim, orgurlcmp, orgtemannu, stajurcod, etaprrcod, orgextdatprr, syscredat, sysmajdat, basdescod, orgparite, typorgextcod, orgextprescod, codesgg) FROM stdin;
ORGEXT	35	35	\N	\N	\N	Arrêté du 25 février 1991 créant un fonds d'aide à l'expansion de la presse française à l'étranger (abrogé par le décret n°2004-1311 du 26 novembre 2004)	Affaires étrangères	1	Fin du mandat sénatorial	ANCIEN	\N	\N	Commission mixte chargée de donner un avis sur l'affectation et l'attribution des crédits du fonds d'aide à l'expansion de la presse française à l'étranger	\N	de la 	Président du Sénat parmi les sénateurs représentant les français de l'étranger	Communication,1 sénateur représentant français de l'étranger	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	35
ORGEXT	36	36	\N	\N	\N	Article R.531-5 du code forestier\r\nOEP supprimé (en 2000?) selon le SGG	Agriculture	1	Fin du mandat sénatorial	ANCIEN	\N	\N	Comité de contrôle du Fonds forestier national	\N	du 	Sénat sur proposition de la commission des finances	Agriculture	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	36
ORGEXT	37	37	\N	\N	\N	Décret n° 2002-1080 du 7 août 2002 relatif au Conseil supérieur de la forêt, des produits forestiers et de la transformation du bois\r\nDécret n° 2015-1256 du 8 octobre 2015\r\nArt. L.113-1  et D. 113-1 du code forestier	Agriculture	2	5 ans (depuis le  07/07/2002. Précédemment : 3 ans), sous réserve du mandat parlementaire	ACTIF	\N	\N	Conseil supérieur de la forêt et du bois	\N	du 	Sénat sur proposition de la commission des affaires économiques\r\narticle 9 du Règlement	Agriculture	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2017-09-13 15:37:49	LEG	OUI	INDETERMINEE	NON	37
ORGEXT	39	39	\N	2014-11-04 00:00:00	\N	Loi n° 51-1508 du 31 decembre 1951\r\nLa caducité de cet organisme a été constatée par le SGG le 4 novembre 2014.	Energie	1	Fin du mandat sénatorial	ANCIEN	\N	\N	Comité de contrôle du Fonds de soutien aux hydrocarbures ou assimilés d'origine nationale	\N	du 	Sénat, sur proposition conjointe de la commission des finances et de la commission des affaires économiques	Industrie	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2015-10-06 18:33:27	NEANT	NON	INDETERMINEE	NON	39
ORGEXT	42	42	\N	\N	\N	Article 9 de la loi n° 78-17 du 6 janvier 1978 relative à l'informatique, aux fichiers et aux libertés	Intérieur - Libertés publiques	2	Mandat sénatorial (voir précédent). Renouvelable une fois.	ACTIF	\N	\N	Commission nationale de l'informatique et des libertés (CNIL)	\N	de la 	Sénat: un candidat sur la proposition de la commission des affaires culturelles \r\net un candidat sur la proposition de la commission des lois	Justice	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2014-11-14 12:03:16	LEG	NON	AUT_ADMIN_INDEP	NON	42
ORGEXT	43	43	\N	2010-08-30 00:00:00	\N	Décret n° 53-953 du 30 septembre 1953 concernant l'organisation administrative et financière de l'établissement des invalides de guerre, modifié par le décret n°99-552 du 30 juin 1999\r\nAbrogé par le décret n° 2010-1009 du 30 août 2010 portant organisation administrative et financière de l'Établissement national des invalides de la marine car ne comptant plus de sénateurs	Santé	2	4 ans	ANCIEN	\N	\N	Conseil supérieur de l'établissement national des invalides de la marine	\N	du 	Sénat: un candidat proposé par la commission des affaires économiques et un candidat proposé par la commission des affaires sociales	Transports	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	43
ORGEXT	44	44	\N	2011-03-09 00:00:00	\N	Décret du 6 novembre 1934 (Art.2)/ Décret du 20 juillet 1959/Décret n° 75-978 du 22 octobre1975 portant modification du décret du 6 novembre 1934 instituant une commission chargée d'examiner les demandes d'autorisation ou de renouvellement des jeux intérieurs.\r\nDécret n° 2009-334 du 26 mars 2009 créée pour 5 ans fin prévue le 9 juin 2014\r\nAbrogé par le décret n° 2011-252 du 9 mars 2011 relatif au comité consultatif des jeux 	Intérieur - Libertés publiques	1	Fin du mandat sénatorial	ANCIEN	\N	\N	Commission chargée d'examiner les demandes d'autorisation ou de renouvellement d'autorisation de jeux	\N	de la 	Président du Sénat	Interieur	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	44
ORGEXT	251	251	\N	\N	\N	Art. L. 621-5 du code rural et de la pêche maritime	\N	1	durée du mandat sénatorial	ACTIF	\N	\N	Conseil d'administration de l'établissement public des produits de l'agriculture et de la mer, FranceAgriMer	\N	du 	Désignation par le Sénat (sur proposition de la commission des affaires économiques)	\N	\N	\N	\N	OUI	DECRET	ALERTE	\N	\N	2017-12-18 11:19:50	LEG	NON	OEP	NON	251
ORGEXT	49	49	\N	\N	\N	Légalisé loi 3 août 2018 Décret n° 2000-931 du 22 septembre 2000 modifiant le décret n° 92-1351 du 24 décembre 1992 portant statut et organisation du Centre national d'art et de culture Georges Pompidou(se substituant, à compter d'octobre 2000, à l'ancien conseil d'orientation)	Culture et éducation	2	Fin du mandat sénatorial	ACTIF	\N	\N	Conseil d'administration du Centre national d'art et de culture Georges Pompidou 	\N	du 	Président du Sénat	Culture	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	2014-11-14 12:02:49	LEG	NON	INDETERMINEE	NON	49
ORGEXT	52	52	\N	2011-05-17 00:00:00	\N	Décret n° 60-676 du 15 juillet 1960 modifiant la loi n° 49-956 du 16 juillet 1949 sur les publications destinées à la jeunesse /  décret n°66-172  du 25 mars 1966 modifiant la loi n°49-956 du 16 juillet 1949 sur les publications destinées à la jeunesse\r\nComposition nouvelle de la commission fixée par l'article 46 de la loi n° 2011-525 du 17 mai 2011 qui ne mentionne plus la présence de parlementaires 	Intérieur - Libertés publiques	4	3 ans	ANCIEN	\N	\N	Commission de surveillance et de contrôle des publications destinées à l'enfance et à l'adolescence	\N	de la 	Sénat sur proposition de la commission des affaires culturelles (deux titulaires et deux suppléants)	Justice	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	52
ORGEXT	72	72	\N	\N	\N	Articles L. 341-17 et R. 341-29 du code de l'environnement\r\n(anciennement commission supérieure des sites régie par le décret n°70-288 du 31 mars 1970)\r\nComposition modifiée par décret n° 2017-1321 du 6 septembre 2017	Environnement, logement, urbanisme	2	3 ans renouvelable sous réserve du mandat sénatorial	ACTIF	\N	\N	Commission supérieure des sites, perspectives et paysages	\N	de la 	Sénat: deux candidats (titulaire et suppléant) proposés par la commission des affaires culturelles et deux candidats (titulaire et suppléant) proposés par la commission du développement durable	Environnement	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2017-12-08 18:17:54	LEG	OUI	INDETERMINEE	NON	72
ORGEXT	75	75	\N	2014-11-04 00:00:00	\N	Décret n° 84-139 du 24 février 1984 relatif au Conseil national des transports et aux Comités régionaux et départementaux des transports.\r\nLa caducité de cet OEP a été constatée par le SGG le 4 novembre 2014.	Transports	4	3 ans (ou fin du mandat du sénateur remplacé).	ANCIEN	\N	\N	Assemblée générale et section permanente du Conseil national des transports	\N	de l'	Sénat: quatre candidats (deux titulaires et deux suppléants) proposés par la commission du développement durable	Transports	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2015-10-06 18:27:12	NEANT	NON	INDETERMINEE	NON	75
ORGEXT	123	123	\N	2015-05-26 00:00:00	\N	Décret n° 2003-1120 du 24 novembre 2003 relatif à la Commission nationale consultative des gens du voyage\r\nOEP supprimé et remplacé par l'OEP 337\r\n	Intérieur - Libertés publiques	2	3 ans (sous réserve du mndat sénatorial)	ANCIEN	\N	\N	Commission nationale consultative des gens du voyage	\N	de la 	Président du Sénat	intérieur	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2017-04-04 17:00:13	NEANT	NON	INDETERMINEE	NON	123
ORGEXT	245	245	\N	\N	\N	Article L213-1 du code de l'environnement et décret n° 2015-450 du 20 avril 2015 (article 6)\r\nArticle D. 213-1 du code de l'environnement\r\nArticle D 213-8 du code de l'environnement\r\nLégalisé par la loi n° 2018-699 du 3 août 2018\r\n	Environnement	2	Durée du mandat parlementaire	ACTIF	\N	\N	Comité national de l'eau\r\n et comité consultatif prévu au 4° de l'article L. 213-1 du code de l'environnement	\N	du 	Sénat sur proposition de la commission du développement durable\r\nDeux sénateurs\r\nNB M TANDONNET nommé par le Sénat le 16/06/2015 membre du comité consultatif au sein du CNE	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2019-02-25 11:34:06	LEG	OUI	INDETERMINEE	NON	245
ORGEXT	53	53	\N	2018-08-02 00:00:00	\N	Article R.6147-57 et suivants du code de la santé publique (anciennement décret n°92-1349 du 18 décembre 1992 relatif au centre hospitalier national d'ophtalmologie des Quinze-Vingts et à l'hôpital national de Saint Maurice et modifiant le code de la santé publique) modifié par le décret n° 2010-1610 du 22 décembre 2010	Santé	1	Renouvellement triennal	ACTIF	\N	\N	Conseil d'administration du centre hospitalier national d'ophtalmologie des Quinze-Vingts	\N	du 	Un sénateur désigné par la commission des affaires sociales	Sante	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2017-04-04 15:49:37	REG	NON	INDETERMINEE	NON	53
ORGEXT	56	56	\N	\N	\N	Loi n° 82-652 du 29 juillet 1982 sur la communication audiovisuelle (Art.39) /  Décret n° 82-789 du 17 septembre 1982.\r\nSupprimé par l'article 4-VIII de la loi n°86-1210 du 27 novembre 1986.	Communication	1	3 ans	ANCIEN	\N	\N	Conseil d'administration de la société TF1	\N	du 	Sénat sur proposition de la commission des affaires culturelles	Communication	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	56
ORGEXT	64	64	\N	2017-06-09 00:00:00	\N	Articles D. 149-1 à D. 149-6 du code de l'action sociale et des familles\r\nSupprimé le 9 juin 2017 sur indication du SGG	Sécurité sociale, travail	2	3 ans	ANCIEN	\N	\N	Comité national des retraités et des personnes âgées	\N	du 	Président du Sénat	Affaires sociales	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2017-06-13 12:02:37	REG	NON	INDETERMINEE	NON	64
ORGEXT	65	65	\N	2014-11-04 00:00:00	\N	Article R.6147-60 et suivants du code de la santé publique (anciennement décret n°92-1349 du 18 décembre 1992 relatif au centre hospitalier national d'ophtalmologie des Quinze-Vingts et à l'hopital national de Saint-Maurice et modifiant le code de la santé publique) tel que résultant du décret n° 2010-1273 du 25 octobre 2010	Santé	1	Après chaque renouvellement sénatorial	ANCIEN	\N	\N	Conseil d'administration des hôpitaux de Saint Maurice	\N	du 	Un sénateur désigné par la commission des affaires sociales.\r\nLa caducité de cet OEP a été constatée par le SGG le 4 novembre 2014.	Sante	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2015-10-06 18:27:48	NEANT	NON	INDETERMINEE	NON	65
ORGEXT	66	66	\N	\N	\N	Loi de nationalisation n° 82-155 du 11 février 1982 (Art. 53) /  Décret n° 99-255 du 2 avril 1999 relatif au Haut conseil du secteur public\r\nAbrogé par décret n° 2008-1029 du 9 octobre 2008 (art 6)	Economie, finances	4	3 ans	ANCIEN	\N	\N	Haut conseil du secteur public	\N	du 	Sénat: deux candidats sur proposition de la commission des finances; un candidat sur proposition de la commission des affaires sociales; un candidat sur proposition de la commission des lois	Premier Ministre	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	66
ORGEXT	69	69	\N	2017-06-12 00:00:00	\N	Articles D. 320-1 à D. 320-8 du code des juridictions financières (anciennement, décret n° 75-223 du 8 avril 1975 relatif au Comité central d'enquête sur le coût et le rendement des services publics. /  Décret n° 86-440 du 14 mars 1986).\r\nSupprimé par l'art. 180 du décret n° 2017-671 du 28 avril 2017, notification du SGG le 12 juin 2017	Economie, finances	4	Fin du mandat sénatorial	ANCIEN	\N	\N	Comité  d'enquête sur le coût et le rendement des services publics	\N	du 	4 sénateurs (deux titulaires et deux suppléants)\r\n désignés directement par la commission des finances parmi ses membres	Economie	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2017-06-13 10:45:00	REG	NON	INDETERMINEE	NON	69
ORGEXT	70	70	\N	\N	\N	art l.1231-1 du code général des collectivités territoriales /  Arrêté du Premier Ministre du 10 mai 1974.(supprimé par la loi n°2004-811 du 13 août 2004 relative à la modernisation de la sécurité  civile dont l'article 45 a abrogé l'article L. 1231-1 du code général des collectivités territoriales)	Collectivités locales	4	Fin du mandat sénatorial	ANCIEN	\N	\N	Conseil national des services publics departementaux et communaux	\N	du 	Sénat sur proposition de la commission des lois	Interieur	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	70
ORGEXT	238	238	\N	2008-06-17 00:00:00	\N	Décret n°2007-1144 du 30 juillet 2007	Défense	2	Jusqu'à la clôture de l'OEP (remise du rapport le 17 juin 2008)	ANCIEN	\N	\N	Commission chargée de l'élaboration du livre blanc sur la défense et la sécurité nationale	\N	de la 	Président du Sénat	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2014-10-06 17:13:37	NEANT	NON	INDETERMINEE	NON	238
ORGEXT	1	1	\N	\N	\N	Décret n° 80-917 du 20 novembre 1980 modifiant le décret n°67-909 du 12 octobre 1967 concernant la gestion du fonds national des abattoirs et l'attribution par lui de primes et de subventions (Abrogation de fait par décret n°90-702 du 1er août 1990).	Agriculture	2	Fin du mandat sénatorial	ANCIEN	\N	\N	Comité consultatif du Fonds national des abattoirs	\N	du 	Sénat sur proposition de la commission des affaires économiques	Agriculture	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	1
ORGEXT	2	2	\N	\N	\N	Décret n° 85-94 du 23 janvier 1985 modifiant la composition du comité consultatif prévu par l'article R 371-8 du code des communes\r\nconsidéré comme abrogé en application du décret n° 2006-672 du 8 juin 2006 (art 17 et 18)	Collectivités locales	2	Fin du mandat sénatorial	ANCIEN	\N	\N	Comité consultatif pour la gestion du Fonds national pour le developpement des adductions d'eau dans les communes rurales (FNDAE)	\N	du 	Un sénateur désigné par la commission des affaires économiques parmi ses membres et un sénateur désigné par la commission des finances parmi ses membres	Agriculture	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	2
ORGEXT	99	99	\N	\N	\N	Article 47-2 de la loi n°86-1067 du 30 septembre 1986 relative à la liberté de communication, créé par l'article 8 de la loi n° 2000-719 du 1er août 2000.	Communication	1	5 ans (à compter de 2001, fin des mandats de 3 ans), sous réserve du mandat parlemntaire	ACTIF	\N	\N	Conseil d'administration de la société Radio-France	\N	du 	Sénat sur proposition de la commission des affaires culturelles	Communication	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2015-03-19 09:56:03	LEG	NON	INDETERMINEE	NON	99
ORGEXT	100	100	\N	\N	\N	Article 47-1 de la loi n° 86-1067 relative à la liberté de la communication, créé par l'article 8 de la loi n° 2000-719 du 1er août 2000\r\nSupprimé par l'article 10 de la loi n° 2009-258 du 5 mars 2009 relative à la communication audiovisuelle et au nouveau service public de la télévision 	Communication	1	5 ans	ANCIEN	\N	\N	Conseil d'administration de la société France 2	\N	du 	Sénat sur proposition de la commission des affaires culturelles	Communication	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	100
ORGEXT	101	101	\N	\N	\N	Article 47-1 de la loi n°86-1067 du 30 septembre 1986 relative à la liberté de communication, créé par l'article 8 de la loi n° 2000-719 du 1er août 2000\r\nSupprimé par l'article 10 de la loi n° 2009-258 du 5 mars 2009 relative à la communication audiovisuelle et au nouveau service public de la télévision 	Communication	1	5 ans	ANCIEN	\N	\N	Conseil d'administration de la société France 3	\N	du 	Sénat sur proposition de la commission des affaires culturelles	Communication	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	101
ORGEXT	103	103	\N	\N	\N	Article 47-2 de la loi n°86-1067 du 30 septembre 1986 relative à la liberté de communication, créé par l'article 8 de la loi n° 2000-719 du 1er août 2000\r\nSupprimé par l'article 10 de la loi n° 2009-258 du 5 mars 2009 relative à la communication audiovisuelle et au nouveau service public de la télévision 	Communication	1	5 ans (à compter de 2001, fin des mandats de 3 ans).	ANCIEN	\N	\N	Conseil d'administration de la société  Radio-France internationale (RFI)	\N	du 	Sénat sur proposition de la commission des affaires culturelles	Communication	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	103
ORGEXT	104	104	\N	\N	\N	Article 50 de la loi n° 86-1067 du 30 septembre 1986 relative à la liberté de communication (modifié par l'article 13 de la loi n° 2000-719 du 1er aout 2000) et décret n° 2004-532 du 10 juin 2004 (changement d'interprétation sur le "peut être désigné" en juillet 2012 suite au renouvellement de l'AN)	Communication	2	5 ans (depuis 2001), sous réserve du mandat sénatorial	ACTIF	\N	\N	Conseil d'administration de l'Institut national de l'audiovisuel (INA)	\N	du 	Sénat sur proposition de la commission de la culture	Communication	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2014-12-16 12:17:15	LEG	NON	INDETERMINEE	NON	104
ORGEXT	107	107	\N	2015-02-24 00:00:00	\N	Art D.3121-1 et suivants du code de la santé publique (anciennement décret n° 89-83 du 8 février 1989 portant création d'un Conseil national du syndrome immunodéficitaire acquis)\r\nDécret n° 2015-210 du 24 février 2015 voir OEP 335 qui lui succède	Santé	1	5 ans (renouvelable une fois)	ANCIEN	\N	\N	Conseil national du syndrome immunodéficitaire acquis (SIDA)	\N	du 	Président du Sénat	AFFAIRES SOCIALES	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2015-04-17 10:21:01	NEANT	NON	INDETERMINEE	NON	107
ORGEXT	237	237	\N	2011-07-25 00:00:00	\N	Décret n° 2007-916 du 16 mai 2007\r\nAbrogé par le décret n° 2011-877 du 25 juillet 2011 relatif à la Commission nationale de la vidéoprotection  (n° 286)	Libertés publiques - Lois	2	Fin du mandat sénatorial	ANCIEN	\N	\N	Commission nationale de la vidéosurveillance	\N	de la 	Président du Sénat	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	237
ORGEXT	18	18	\N	\N	\N	Convention passée entre l'Etat et la Compagnie generale transatlantique le 23 decembre 1948, modifiée par le cinquieme avenant. Dernières désignations le 23 novembre 1973.	Transports	5	Fin du mandat sénatorial	ANCIEN	\N	\N	Comité consultatif des lignes de Corse	\N	du 	Président du Sénat	Transports	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	18
ORGEXT	20	20	\N	2017-03-07 00:00:00	\N	Articles L.512-71 et R.512-43 du code monétaire et financier\r\nArt. L. 512-71 du code monétaire et financier abrogé par l'art. 89 de la loi n° 2016-816 du 20 juin 2016 pour l'économie bleue\r\nSuppression de l'OEP notifiée par le SGG le 7 mars 2017	Economie, finances	3	Fin du mandat sénatorial	ANCIEN	\N	\N	Commission supérieure du Crédit maritime mutuel	\N	de la 	Sénat sur proposition de la commission des affaires économiques	Transports	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2017-03-16 12:47:23	NEANT	NON	INDETERMINEE	NON	20
ORGEXT	21	21	\N	\N	\N	Décret n°78-631 du 2 juin 1978 portant modification de la composition de la commission centrale de classement des débits de tabac (Décret modifié du 28 novembre 1873 instituant une commission chargée d'établir les listes de candidatures aux débits de tabac)\r\nConsidéré comme abrogé en application des articles 17 et 18 du décret n° 2006-672 du 8 juin 2006 relatif à la création , à la composition et au fonctionnement des commissions administratives à caractère consultatif	Economie, finances	1	1 an	ANCIEN	\N	\N	Commission centrale de classement des débits de tabac	\N	de la 	Sénat sur proposition de la commission des finances	Budget	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	21
ORGEXT	22	22	\N	\N	\N	Art. L. 341-1 du code des relations entre le public et l'administration	Intérieur - Libertés publiques	2	Durée du mandat parlementaire	ACTIF	\N	\N	Commission d'accès aux documents administratifs (CADA)	\N	de la 	Président du Sénat\r\nen application de l'article 23 de l'ordonnance n° 2005-650 du 6 juin 2005, \r\nle président du Sénat désigne également un élu d'une collectivité territoriale (et un suppléant)	Premier Ministre	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	2017-09-18 15:42:05	LEG	OUI	AUT_ADMIN_INDEP	NON	22
ORGEXT	23	23	\N	2014-10-10 00:00:00	\N	Article D.239-17 du code de l'éducation (anciennement Décret n° 67-802 du 19 septembre 1967 portant modification du décret du 12 avril 1958 modifiant le décret du 2 mai 1951 portant constitution de la commission nationale pour l'education, la science et la culture). Décret n° 2008-1400 du 19 décembre 2008. OEP supprimé par notification SGG le 10/10/2014 et 11/12/2014	Affaires étrangères	2	4 ans	ANCIEN	\N	\N	Commission nationale pour l'éducation, la science et la culture (UNESCO)	\N	de la 	Président du Sénat	Relations exterieures	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2017-04-04 16:59:47	NEANT	NON	INDETERMINEE	NON	23
ORGEXT	120	120	\N	\N	\N	Art. L. 131-4 du code de l'environnement /Art. R. 131-5 du code de l'environnement	Energie	1	5 ans renouvelable	ACTIF	\N	\N	Conseil d'administration de l'Agence de l'environnement et de la maîtrise de l'énergie (ADEME)	\N	du 	Sénat sur proposition de la commission du développement durable	environnement	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2018-03-20 10:45:53	LEG	NON	INDETERMINEE	NON	120
ORGEXT	121	121	\N	\N	\N	Décret n°91-833 du 30 aout 1991 relatif aux bourses scolaires au bénéfice d'enfants résidant avec leur famille à l'étranger\r\ncodifié à l'article D. 531-50 du code de l'éducation	Affaires étrangères	2	Fin du mandat sénatorial	ACTIF	\N	\N	Commission nationale des bourses de l'agence pour l'enseignement français à l'étranger	\N	de la 	Président du Sénat (parmi les sénateurs représentant les français établis hors de France)	affaires étrangères	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2014-11-24 09:48:23	REG	NON	INDETERMINEE	NON	121
ORGEXT	122	122	\N	\N	\N	Arrêté du 7 janvier 1992 fixant la composition de la commission prévue à l'article 125 de la loi n°91-1322 du 30 décembre 1991 portant loi de finances /  supprimé par l'article 79 de la loi de finances pour 1995 (n°94-1162 du 29 décembre 1994 .	Anciens combattants et victimes de guerre	5	Fin du mandat sénatorial	ANCIEN	\N	\N	Fonds de solidarité pour les anciens combattants d'Afrique du Nord en situation de chômage de longue durée, agés de plus de cinquante ans	\N	du 	Président du Sénat	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	122
ORGEXT	124	124	\N	\N	\N	Articles L. 6121-8 et R. 6122-15 du code de la santé publique	Santé	1	5 ans renouvelable	ACTIF	\N	\N	Comité national de l'organisation sanitaire et sociale	\N	du 	Deux sénateurs (un titulaire et un suppléant) \r\ndésignés directement et pour 5 ans par la commission des affaires sociales	affaires sociales	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2017-09-13 16:57:03	LEG	OUI	INDETERMINEE	NON	124
ORGEXT	125	125	\N	\N	\N	Décret n°91-1005 du 30-09-1991 pris pour l'application de la loi n° 90-559 du 04-07-1990 créant les fondations d'entreprises et modifiant les dispositions de la loi n° 87-571 du 23-07-1987 sur le développement du mécénat relatives aux fondations.\r\norganisme en sommeil	Culture et éducation	1	3 ans	ANCIEN	\N	\N	Conseil national des fondations	\N	du 	Sénat sur proposition de la commission des affaires culturelles	culture	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	125
ORGEXT	126	126	\N	\N	\N	Art. L. 515-13.-I du code monétaire et financier	Economie, finances	2	Trois ans	ACTIF	\N	\N	Conseil d'administration de l'Agence française de développement	\N	du 	Président du Sénat	Affaires étrangères	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	2017-11-06 18:49:03	LEG	NON	CONS_ADMIN	NON	126
ORGEXT	127	127	\N	\N	\N	Article L. 143-1 du code de l'action sociale et des familles (légalisé art. 74 loi du 3 août 2018)	Sécurité sociale, travail	2	3 ans	ACTIF	\N	\N	Conseil national des politiques de lutte contre la pauvreté et l'exclusion sociale	\N	du 	Président du Sénat depuis décret n° 2013-1161 du 17 décembre 2013. (Sénat sur proposition de la commission des Affaires sociales auparavant (avant 2009 : Président du Sénat) - Un titulaire et un suppléant	affaires sociales	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2017-09-13 16:47:25	LEG	OUI	INDETERMINEE	NON	127
ORGEXT	286	286	2011-12-15 00:00:00	2018-09-12 00:00:00	\N	Décret n° 2011-877 du 25 juillet 2011 décret n° 2006-672 du 8 juin 2006 (durée cinq ans..sauf prolongation expresse)\r\n(remplace la commission nationale de la vidéosurveillance ) n° 237	\N	2	mandat parlementaire	ANCIEN	\N	\N	Commission nationale de la vidéoprotection	\N	de la 	Sénat  sur proposition de la commission des lois\r\nDémission de M BUFFET au 9/4/2013 connue...le 4/3/2015.	\N	\N	\N	\N	OUI	DECRET	NEANT	\N	\N	2018-09-21 17:41:17	REG	OUI	INDETERMINEE	NON	286
ORGEXT	128	128	\N	\N	\N	Art. L. 135-1 du code de la sécurité sociale / Décret n°93-1354 du 30-12-1993 portant application des dispositions des titres I et III de la loi n°93-936 du 22-07-1993 relative aux pensions de retraite et à la sauvegarde de la protection sociale et modifiant le code de la sécurité sociale (Conseil d'Etat)Art. R. 135-6 du code de la sécurité sociale	Sécurité sociale, travail	2	3 ans renouvelable	ACTIF	\N	\N	Comité de surveillance du Fonds de solidarité vieillesse	\N	du 	Président du Sénat	affaires sociales	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2018-03-20 10:49:26	LEG	NON	INDETERMINEE	NON	128
ORGEXT	129	129	\N	\N	\N	Décret n°94-407 du 18 mai 1994 portant création de la commission consultative de l'action humanitaire abrogé par l'article 3 du décret n°96-791 du 11 septembre 1996.	Affaires étrangères	1	3 ans	ANCIEN	\N	\N	Commission consultative de l'action humanitaire (supprimée)	\N	de la 	Président du Sénat	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	129
ORGEXT	132	132	\N	\N	\N	Article 47 de la loi de finances pour 1995 (n°94-1162 du 29 décembre 1994) abrogé par l'article 35 de la loi de finances pour 2001(n°2000-1352 du 30 décembre 2000)	Transports	2	Fin du mandat sénatorial	ANCIEN	\N	\N	Comité de gestion du fonds d'investissement des transports terrestres et des voies navigables	\N	du 	Sénat: un candidat proposé par la commission des affaires économiques et un candidat proposé par la commission des finances	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	132
ORGEXT	133	133	\N	\N	\N	Article 47-1 de la loi n°86-1067 du 30 septembre 1986 relative à la liberté de communication, créé par l'article 8 de la loi n° 2000-719 du 1er août 2000.\r\nSupprimé par l'art 10 de la loi n° 2009-258 du 5 mars 2009 - art. 9	Communication	1	5 ans	ANCIEN	\N	\N	Conseil d'administration de la société La Cinquième (de 1995 à 2000 : Conseil d'administration de la société Télévision du savoir)	\N	du 	Sénat sur proposition de la commission des affaires culturelles	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	133
ORGEXT	134	134	\N	\N	\N	Décret n°2000-1106 du 14 novembre 2000 portant approbation des statuts de France 2, France 3 et de La Cinquième. (modification de l'article 45 de la loi du 30 juillet 1986 relative à la liberté de communication : caducité).	Communication	2	3 ans	ANCIEN	\N	\N	Comité d'orientation des programmes de la société nationale de programme La Cinquième ( anciennement : Télévision du savoir)	\N	du 	Sénat: deux candidats proposés par la commission des affaires culturelles	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	134
ORGEXT	285	285	2011-12-15 00:00:00	\N	\N	Art. 28 de la loi n° 2010-597 du 3 juin 2010 relative au Grand Paris codifié en art. L321-39 du code de l'urbanisme par la loi 2014-58 d'affirmation des métropoles (MAPTAM)\r\nArticle 13 du décret n°2010-911 du 3 août 2010 relatif à l'Etablissement public de Paris-Saclay (Devenu art.12, suite à modification par l'art. 1er du décret n° 2015-1927 du 31 décembre 2015 relatif à l'Etablissement public d'aménagement de Paris-Saclay ) \r\n	\N	1	six ans	ACTIF	\N	\N	Comité consultatif du conseil d'administration de l'établissement public de Paris-Saclay	\N	du 	par le Sénat sur proposition de la commission des affaires économiques\r\nDémission de Mme Lienemann 05/03/2014	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	2017-12-18 10:01:03	LEG	NON	INDETERMINEE	NON	285
ORGEXT	135	135	\N	\N	\N	Article 46 de la loi de finances pour 1995 (n° 94-1162 du 29 décembre 1994) modifié par l'article 75 de la loi de finances pour 1999 (n°98-1266 du 30 décembre 1998) abrogé par l'article 57 de la Loi n°2004-1484 du 30 décembre 2004 de finances pour 2005 /  Décret n°96-30 du 15 janvier 1996 modifié par le décret n°99-811 du 10 septembre 1999 abrogé par le Décret n° 2005-1556 du 7 décembre 2005.	Transports	2	Fin du mandat sénatorial	ANCIEN	\N	\N	Comité de gestion du Fonds d'intervention pour les aéroports et le transport aérien (FIATA) : Dessertes aériennes (Ancien Comité de gestion du Fonds de péréquation des transports aériens)	\N	du 	Sénat: un candidat sur proposition de la commission des affaires économiques et un candidat sur proposition de la commission des finances	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	135
ORGEXT	137	137	\N	2020-12-07 00:00:00	\N	Art. L. 3346-1 du code du travail - Supprimé loi ASAP n° 2020-1525 du 7 décembre 2020	Sécurité sociale, travail	2	À chaque renouvellement sénatorial	ACTIF	\N	\N	Conseil d'orientation de la participation, de l'intéressement, de l'épargne salariale et de l'actionnariat salarié	\N	du 	Président du Sénat\r\ndeux sénateurs nommés par le Sénat mais pas de saisine pour renouveler les membres qui avaient été confirmés par le Pdt	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	2017-09-13 16:29:19	LEG	OUI	INDETERMINEE	NON	137
ORGEXT	138	138	\N	2020-12-07 00:00:00	\N	Article D. 239-27 du code de l'éducation (anciennement décret n° 95-591 du 6 mai 1995 relatif à l'Observatoire national de la sécurité des établissements scolaires).Légalisé par la loi n° 2018-699 du 3 août 2018 - art. L. 239-2 du code de l'éducation - Supprimé loi ASAP n° 2020-1525 du 7 décembre 2020	Culture et éducation	2	3 ans, sous réserve du mandat sénatorial	ACTIF	\N	\N	Observatoire national de la sécurité et de l'accessibilité des établissements d'enseignement	\N	de l'	Sénat: trois candidats (un titulaire et deux suppléants) sur proposition de la commission des affaires culturelles	EDUCATION	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2019-02-26 15:44:27	LEG	OUI	INDETERMINEE	NON	138
ORGEXT	139	139	\N	\N	\N	Décret n°95-906 du 9 août 1995 portant création de la commission d'étude sur la retraite anticipée pour les anciens combattants d'Afrique du Nord (remise du rapport le 13 novembre 2001, caducité)	Anciens combattants et victimes de guerre	5	Fin du mandat sénatorial	ANCIEN	\N	\N	Commission d'étude sur la retraite anticipée pour les anciens combattants en Afrique du Nord	\N	de la 	Président du Sénat	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	139
ORGEXT	3	3	\N	\N	\N	Articles D. 237 du code de procédure pénale\r\nConsidéré comme abrogé en application des articles 17 et 18 du décret n° 2006-672 du 8 juin 2006 relatif à la création, à la composition et au fonctionnement des commissions administratives à caractère consultatif	Justice, législation générale	3	Fin du mandat sénatorial	ANCIEN	\N	\N	Conseil supérieur de l'administration pénitentiaire	\N	du 	Deux sénateurs désignés par le Sénat sur proposition de la commission deslLois parmi ses membres et un sénateur désigné par le Sénat sur proposition de la commission des finances parmi ses membres	Justice	\N	http://www.senat.fr/	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	3
ORGEXT	4	4	\N	2017-09-19 00:00:00	\N	Articles L.148.1 et D.148-1 du code de l'action sociale et des familles (Historique : décret n° 2002-473 du 8 avril 2002 relatif au Conseil supérieur de l'adoption puis article 12 de la loi n° 2002-93 du 22 janvier 2002 relative à l'accès aux origines des personnes adoptées et pupilles de l'Etat) Supprimé par notification du SGG le 19 septembre 2017\r\nL'OEP 263 a été supprimé en février 2014 dans le cadre des mesures de simplification administrative.	Justice, législation générale	1	Fin du mandat sénatorial	ANCIEN	\N	\N	Conseil supérieur de l'adoption	\N	du 	Président du Sénat	Justice et Sante	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2017-10-11 11:52:03	LEG	OUI	INDETERMINEE	NON	4
ORGEXT	8	8	\N	\N	\N	Article R. 612-1 du code des pensions militaires d'invalidité et des victimes de la guerre (décret n° 2016-1903 du 28 décembre 2016)\r\nLégalisé par la loi n° 2018-607 du 13 juillet 2018 - art. L. 612-1 du code des pensions militaires d'invalidité et des victimes de guerre	Anciens combattants et victimes de guerre	1	Mandat parlementaire	ACTIF	\N	\N	Conseil d'administration de l'Office national des anciens combattants et victimes de guerre 	\N	du 	Président du Sénat	Anciens combattants	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2019-02-25 17:43:23	LEG	NON	INDETERMINEE	NON	8
ORGEXT	11	11	\N	\N	\N	Décret no 83-226 du 22 mars 1983, La représentation sénatoriale a été supprimée par le décret n°88-606 du 6 mai 1988.	Culture et éducation	1	3 ans	ANCIEN	\N	\N	Conseil d'administration de la Bibliothèque Nationale	\N	du 	Président du Sénat	Education nationale	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	11
ORGEXT	12	12	\N	\N	\N	Article D.571-100 du code de l'environnement\r\nLégalisé par la loi n° 2018-699 du 3 août 2018 (art. L. 571-1-1 du code de l'environnement)	Environnement, logement, urbanisme	1	3 ans (ou fin du mandat restant à courir si remplacement)	ACTIF	\N	\N	Conseil national du bruit	\N	du 	Président du Sénat depuis décret n° 2013-476 du 5 juin 2013 (auparavant Sénat sur proposition de la commission des affaires sociales (1 titulaire et 1 suppléant) cf décret 2011-1518 du 15/11/2011 prorogeant mandat jusqu'au 31/10/2012 se téléscope avec demande du SGG de remplacement de Mme Schillinger)\r\nMme PRINTZ démissionne de son mandat sénatorial le 31 août 2014	Environnement	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2019-02-26 10:21:10	LEG	OUI	INDETERMINEE	NON	12
ORGEXT	13	13	\N	\N	\N	Article L.518-4 du code monétaire et financier (anciennement article 2 de la loi du 6 avril 1876  modifié par l'article 2 de  la loi n° 48-103 du 17 janvier 1948)	Economie, finances	2	3 ans	ACTIF	\N	\N	Commission de surveillance de la Caisse des dépôts et consignations	\N	de la 	Président du Sénat parmi les membres de la commission des finances	Finances	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2019-01-29 16:35:14	LEG	NON	INDETERMINEE	NON	13
ORGEXT	16	16	\N	2015-05-26 00:00:00	\N	Décret n° 76-356 du 20 avril 1976 relatif au Conseil supérieur de la coopération\r\nOEP supprimé Remplacé par l'OEP 338	Economie, finances	2	Fin du mandat sénatorial	ANCIEN	\N	\N	Conseil supérieur de la coopération	\N	du 	Sénat: un candidat proposé par la commission des affaires économiques et un candidat proposé par la commission des affaires sociales	Premier Ministre	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2015-05-27 10:16:09	NEANT	NON	INDETERMINEE	NON	16
ORGEXT	24	24	\N	\N	\N	art 70 de la loi n° 2005-781 du 13 juillet 2005 (modifiant l'art 45 de la loi n° 46-628) Art. R. 142-22 du code de l'énergie\r\nLégalisé par la loi n° 2018-699 du 3 août 2018 - art. L. 142-41 du code de l'énergie	Energie	3	Fin du mandat sénatorial	ACTIF	\N	\N	Conseil supérieur de l'énergie	\N	du 	Président du Sénat,  puis  recours à la procédure"ordinaire" (nomination par le Sénat par l'article 9 du Règlement), \r\nen l'absence de disposition spécifique dans le décret n° 2006-366.	Industrie	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	2019-02-26 11:45:50	LEG	OUI	INDETERMINEE	NON	24
ORGEXT	25	25	\N	\N	\N	Décret n°76-561 du 25 juin 1976 fixant le mode de fonctionnement, la composition et les attributions du Comité consultatif de l'utilisation de l'energie. Supprimé par l'article 44, paragraphe III, de la loi n° 96-1236 du 30-12-1996 sur l'air et l'utilisation rationnelle de l'énergie.	Energie	1	3 ans	ANCIEN	\N	\N	Comité consultatif de l'utilisation de l'énergie	\N	du 	Sénat sur proposition de la commission des affaires économiques. La désignation de 1999 était sans objet (erreur du SGG)	Industrie	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	25
ORGEXT	29	29	\N	\N	\N	Articles L.322-11 et R.322-17 du code de l'environnement	Environnement, logement, urbanisme	6	Fin du mandat sénatorial	ACTIF	\N	\N	Conseil d'administration du Conservatoire de l'espace littoral et des rivages lacustres 	\N	du 	Sénat: 2 candidats ( 1 tit et 1suppl) commission des affaires culturelles, 2  candidats (1 tit 1 suppl) commission des lois et 2 candidats ( 1 tit et 1 suppl) commission du développement durable\r\naussi dénommé conservatoire du littoral	Environnement	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2017-03-21 16:19:15	LEG	NON	INDETERMINEE	NON	29
ORGEXT	30	30	\N	\N	\N	Articles L.1412-2 et R.1412-1 et suivants du code de la santé publique	Santé	1	4 ans. Renouvelable une fois. Remplacement pour la durée restant à courir	ACTIF	\N	\N	Comité consultatif national d'éthique pour les sciences de la vie et de la santé	\N	du 	Président du Sénat	Recherche	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2016-02-09 16:36:43	LEG	NON	INDETERMINEE	NON	30
ORGEXT	33	33	\N	\N	\N	Décret n°84-712  du 17 juillet 1984 portant refonte du fonds d'investissement des départements d'outre-mer (F.I.D.O.M.)\r\n\r\nSupprimé par le décret n° 2003-580 du 27 juin 2003	Départements et territoires d'outre-mer	3	Fin du mandat sénatorial	ANCIEN	\N	\N	Comité directeur du Fonds d'investissement des départements d'outre-mer (FIDOM)	\N	du 	Président du Sénat (après avis de la commission des affaires économiques pour deux nominations et de la commission des finances pour la troisième)	Départements et territoires d'outre-mer.	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	33
ORGEXT	34	34	\N	\N	\N	Article L. 1211-2 du code général des collectivités territoriales (Loi nº 99-586 du 12 juillet 1999) - OEP créé par la Loi n° 79-15 du 3 janvier 1979 instituant la DGF (titulaires)/ Loi n° 80-1102 du 31 décembre 1980 (suppléants) Mandat prolongé jusqu'à la suite des élections municipales et cantonales 2008 par l'article 160 de la Loi n° 2006-1771 du 30 décembre 2006 de finances rectificative pour 2006.	Collectivités locales	4	renouvellement partiel du Sénat	ACTIF	\N	\N	Comité des finances locales	\N	du 	Président du Sénat	Interieur	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2017-09-13 16:20:42	LEG	OUI	INDETERMINEE	NON	34
ORGEXT	110	110	\N	\N	\N	Décret n°90-494 du 20 juin 1990 portant création et organisation d'un conseil supérieur du cheval abrogé par le décret n°96-1183 du 26 décembre 1996.	Agriculture	1	3 ans renouvelable	ANCIEN	\N	\N	Conseil supérieur du cheval (organisme supprimé)	\N	du 	Sénat: deux candidats (un titulaire et un suppléant) proposés par la commission des affaires économiques	Agriculture	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	110
ORGEXT	111	111	\N	\N	\N	Article 17 de la loi n°89-1014 portant adaptation du code des assurances à l'ouverture du marché européen (supprimé par modification de l'article L.411-1 du code des assurances par la loi du 1er août 2003 de sécurité financière qui a créé un Comité consultatif du secteur financier)	Economie, finances	1	3 ans renouvelable	ANCIEN	\N	\N	Conseil national des assurances	\N	du 	Sénat sur proposition de la commission des finances	ECONOMIE ET FINANCES	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	111
ORGEXT	113	113	\N	\N	\N	Abrogé par le décret n° 2005-596 du 27 mai 2005 (anciennement : Décret n°90-755 du 23 août 1990 pris pour l'application de l'article L.8 bis du code des pensions militaires d'invalidité et des victimes de guerre).	Anciens combattants et victimes de guerre	14	Fin du mandat sénatorial	ANCIEN	\N	\N	Commission consultative appelée à émettre un avis sur la modification de la valeur du point de pension	\N	de la 	Président du Sénat (7 titulaires et 7 suppléants) (après avis de la commission des affaires sociales)	ANCIENS COMBATTANTS	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	113
ORGEXT	114	114	\N	\N	\N	Décret n°90-702 du 1er août 1990. Rendu caduc par le décret  n° 98-590 du 6 juillet 1998 (lettre du ministre de l'agriculture au SGG lui signalant cette caducité; information répercutée au service de la séance le 17 juin 1999).	Agriculture	1	Fin du mandat sénatorial	ANCIEN	\N	\N	Comité consultatif du Fonds national des abattoirs (supprimé)	\N	du 	Président du Sénat (un titulaire et un suppléant sur proposition de la commission des affaires économiques)	AGRICULTURE	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	114
ORGEXT	116	116	\N	\N	\N	Arrêté du 15 novembre 1990 relatif au Comité de liaison pour le transport des personnes handicapées. Abrogé par l'arrêté du 16 décembre 1999 créant le COLIAC (voir: n° 163).	Santé	1	3 ans	ANCIEN	\N	\N	Comité de liaison pour le transport des personnes handicapées (COLITRAH)	\N	du 	Sénat sur proposition de la commission des affaires économiques	Affaires sociales	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	116
ORGEXT	118	118	\N	2015-09-29 00:00:00	\N	Loi n° 91-646 du 10 juillet 1991 relative au secret des correspondances émises par la voie des télécommunications\r\nSupprimée par le décret n° 2015-1186 du 29 septembre 2015 et remplacée par la commission nationale de contrôle des techniques de renseignement	Intérieur - Libertés publiques	1	Après chaque renouvellement sénatorial	ANCIEN	\N	\N	Commission nationale de contrôle des interceptions de sécurité	\N	de la 	Président du Sénat (Mandat non renouvelable sauf si remplacement pour finir mandat de la personne nommée exercé pendant  moins de 2 ans)	premier ministre	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2015-10-02 11:23:05	NEANT	NON	INDETERMINEE	NON	118
ORGEXT	119	119	\N	\N	\N	Loi n°91-635 du 10 juillet 1991 modifiant la loi n°83-557 du 1er juillet 1991  portant réforme des caisses d'épargne et de prévoyance.Caduc, en application de l'article 29-II de la loi n°99-532 du 25 juin 1999 relative à l'épargne et à la sécurité financière.	Economie, finances	1	Fin du mandat sénatorial	ANCIEN	\N	\N	Conseil de surveillance du Centre national des caisses d'épargne et de prévoyance	\N	du 	Sénat sur proposition de la commission des finances	finances	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	119
ORGEXT	213	213	\N	\N	\N	Décret n° 2005-326 du 7 avril 2005 portant création du Conseil d'orientation pour l'emploi\r\nLégalisé par la loi n° 2018-699 du 3 août 2018 - art. 34	Economie, finances	2	après chaque renouvellement triennal	ACTIF	\N	\N	Conseil d'orientation pour l'emploi	\N	du 	Président du Sénat	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	2019-02-25 18:00:37	LEG	OUI	INDETERMINEE	NON	213
ORGEXT	214	214	\N	\N	\N	Décret n° 2005-300 du 31 mars 2005\r\nArticle L. 1114-1 du code de la santé publique R.1114-6	Santé	2	mandat parlementaire	ACTIF	\N	\N	Commission nationale d'agrément des associations représentant les usagers dans les instances hospitalières ou de santé publique	\N	de la 	Un titulaire et un suppléant désignés par le Sénat sur proposition de la commission des affaires sociales	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2015-02-17 15:16:52	LEG	NON	INDETERMINEE	NON	214
ORGEXT	216	216	\N	2007-11-19 00:00:00	\N	Décret n° 2005-1021 du 25 août 2005 relatif à l'Agence de l'innovation industrielle\r\nOEP dissous en application du décret n° 2007-1629 du 19 novembre 2007 relatif à l'apport des biens, droits et obligations de l'Agence de l'innovation industrielle à l'établissement public industriel et commercial OSEO et à la société anonyme OSEO Innovation	Economie, finances	2	Durée du mandat parlementaire	ANCIEN	\N	\N	Conseil de surveillance de l'Agence de l'innovation industrielle	\N	du 	2 sénateurs désignés par le Président du Sénat	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	216
ORGEXT	215	215	\N	2008-03-12 00:00:00	\N	Article R.111-26 du code de l'entrée et du séjour des étrangers et du droit d'asile (abrogé par l'article 17 du décret n° 2008-246 du 12 mars 2008 relatif au Contrôleur général des lieux de privation de liberté)	Intérieur - Libertés publiques	1	2 ans (ou fin de mandat du sénateur remplacé)	ANCIEN	\N	\N	Commission nationale de contrôle des centres et locaux de rétention administrative et des zones d 'attente	\N	de la 	Par le Sénat sur proposition de la commission des Lois	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	215
ORGEXT	218	218	\N	2017-04-20 00:00:00	\N	Art. 141 du décret n° 2016-630 du 25 mars 2016 - arrêté en préparation\r\n(anciennement article 3 de l'arrêté du 10 novembre 2005 pris en application de l'article 130 du code des marchés publics\r\n"un représentant du président du Sénat")\r\nArrêté du 12 avril 2017 ne prévoit plus de sénateur dans cette instance - SGG 20 avril 2017\r\n	Economie, finances	1	Durée du mandat sénatorial	ANCIEN	\N	\N	Observatoire de la commande publique	\N	de l'	Président du Sénat	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2017-04-20 18:02:00	NEANT	NON	INDETERMINEE	NON	218
ORGEXT	258	258	\N	\N	\N	Art L. 321-1 du code de la construction et de l'habitation	\N	1	3 ans renouvelable (sous réserve du mandat sénatorial)	ACTIF	\N	\N	Conseil d'administration de l'Agence nationale de l'habitat	\N	du 	Président du Sénat	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	2017-04-04 16:27:19	LEG	NON	OEP	NON	258
ORGEXT	221	221	\N	\N	\N	Article 2 de la loi n°2006-10 du 5 janvier 2006 relative à la sécurité et au développement des transports ; décret n° 2006-369 du 28 mars 2006 (art 3).article L. 2221-2 du code des transports	Transports	1	Durée du mandat sénatorial	ACTIF	\N	\N	Conseil d'administration de l'établissement public de sécurité ferroviaire	\N	du 	Président du Sénat	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2017-04-04 16:24:11	LEG	NON	INDETERMINEE	NON	221
ORGEXT	220	220	\N	2018-09-12 00:00:00	\N	Art. 1er de la loi n° 2005-157 du 23 février 2005 Article 1er du décret n°2005-1424 du 17 novembre 2005\r\nSupprimé par le décret n° 2018-785 du 12 septembre 2018	Aménagement du territoire	3	3 ans renouvelable, sous réserve mandat parlementaire	ANCIEN	\N	\N	Conférence de la ruralité	\N	de la 	Président du Sénat	\N	\N	\N	\N	OUI	DECRET	NEANT	\N	\N	2018-09-21 17:24:42	LEG	OUI	INDETERMINEE	NON	220
ORGEXT	217	217	\N	2010-09-07 00:00:00	\N	Article 12 du décret n°2005-473 du 16 mai 2005 (organisme sensé remplacer le FIATA)\r\nConsidéré comme abrogé par décret n° 2006-672 du 8 juin 2006  (le 07/09/2010)	Transports	2	Durée du mandat parlementaire	ANCIEN	\N	\N	Comité consultatif des liaisons aériennes d'aménagement du territoire	\N	du 	Sénat sur proposition de la commission des finances (1) et de la commission des affaires économiques (1)	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	217
ORGEXT	222	222	\N	\N	\N	Décret n° 2005-1001 du 22 août 2005 portant modification du décret n°87-155 du 5 mars 1987 relatif aux missions et à l'organisation des oeuvres universitaires\r\nLoi n° 55-425 du 16 avril 1955 - Art. L 822-2 et R 822-4 du code de l'éducation\r\nLégalisé par la loi n° 2018-699 du 3 août 2018 - art. L. 822-2 du code de l'éducation	Culture et éducation	1	Durée du mandat parlementaire	ACTIF	\N	\N	Conseil d'administration du Centre national des oeuvres universitaires et scolaires (CNOUS)	\N	du 	Sénat sur proposition de la commission de la culture (article 9 du Règlement) \r\n	\N	\N	\N	\N	OUI	LOI	NEANT	\N	\N	2019-02-25 17:50:35	LEG	NON	INDETERMINEE	NON	222
ORGEXT	223	223	\N	2010-09-07 00:00:00	\N	Article 13 du décret n°2005-473 du 16 mai 2005 relatif aux règles d'attribution par l'Etat de compensations financières aux transporteurs aériens et aux exploitants d'aéronefs pour leurs missions relatives au sauvetage et à la lutte contre les incendies d'aéronefs,...... \r\nConsidéré comme abrogé en application du décret n° 2006-672 du 8 juin 2006  (le 07/09/2010)	Transports	1	Durée du mandat parlementaire	ANCIEN	\N	\N	Comité consultatif des subventions aux exploitants d'aérodromes	\N	du 	Sénat sur proposition de la commission des affaires économiques	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	223
ORGEXT	224	224	\N	2014-02-17 00:00:00	\N	Décret n° 2006-260 du 6 mars 2006 (art. 4)\r\nOrganisme supproimé par le décret n° 2014-132 du 17 février 2014	Economie, finances	2	Durée du mandat sénatorial	ANCIEN	\N	\N	Comité d'orientation du centre d'analyse stratégique	\N	du 	Président du Sénat	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2014-09-26 16:08:12	NEANT	NON	INDETERMINEE	NON	224
ORGEXT	225	225	\N	2014-02-17 00:00:00	\N	Article 69 de la loi n° 2006-11 du 5 janvier 2006\r\nDécret n° 2006-159 du 14 février 2006 portant création du Conseil de modération et de prévention\r\nSupprimé par le décret n° 2014-132 du 17 février 2014	Santé	4	trois ans renouvelables une fois ou fin du mandat sénatorial (remplacement pour la durée du mandat restant à courir)	ANCIEN	\N	\N	Conseil de modération et de prévention	\N	du 	Président du Sénat	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2014-09-26 14:06:14	NEANT	NON	INDETERMINEE	NON	225
ORGEXT	228	228	\N	2013-04-11 00:00:00	\N	Article 5 du décret n° 2006-515 du 5 mai 2006 relatif à la Conférence nationale des finances publiques et portant création du Conseil d'orientation des finances publiques\r\nAbrogé par le décret n° 2013-144 du 18 février 2013	Economie, finances	3	fin du mandat sénatorial	ANCIEN	\N	\N	Conseil d'orientation des finances publiques	\N	du 	Président du Sénat\r\nSupprimé en avril 2013 (simplification administrative)	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2013-10-03 17:12:10	NEANT	NON	INDETERMINEE	NON	228
ORGEXT	229	229	\N	2009-05-27 00:00:00	\N	art 5 de la loi n° 2003-660 du 21 juillet 2003 de programme pour l'outre-mer\r\nSupprimé par art. 74 de la loi n° 2009-594 du 27 mai 2009 pour le développement économique des outre-mer et décret n° 2010-1048 du 1er septembre 2010 relatif à la commission d'évaluation des politiques de l'État outre-mer \r\ncf OEP 270	Départements et territoires d'outre-mer	11	non précisée	ANCIEN	\N	\N	Commission d'évaluation des dispositifs de défiscalisation et d'exonération des charges sociales outre-mer	\N	de la 	Président du Sénat	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	229
ORGEXT	603	603	\N	\N	\N	Décret n°73-54 du 11-01-1973 abrogé par le décret n°91-1410 du 31-12-1991	Santé	1	\N	ANCIEN	\N	\N	Commission nationale de l'équipement sanitaire (organisme supprimé)	\N	de la 	Président de la commission des affaires sociales membre de droit	Affaires sociales	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	603
ORGEXT	230	230	\N	2017-06-22 00:00:00	\N	Article L. 331-29 du code de l'environnement (introduit par la loi n° 2006-436 du 14 avril 2006 relative aux parcs nationaux, aux parcs naturels marins et aux parcs naturels régionaux)\r\net article R. 331-79 (décret n° 2006-944 du 28 juillet 2006)\r\nSupprimé par notification du SGG le 22 juin 2017	Environnement, logement, urbanisme	1	six ans renouvelable, sous réserve du mandat parlementaire	ANCIEN	\N	\N	Conseil d'administration des "Parcs nationaux de France"	\N	du 	Sénat sur proposition de la commission du développement durable	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2017-06-26 11:36:13	LEG	NON	INDETERMINEE	NON	230
ORGEXT	236	236	\N	\N	\N	Décret n° 2006-1267 du 16 octobre 2006 instituant un Conseil de l'immobilier de l'Etat\r\nOEP reconduit pour cinq ans à compter du 30/10/2011 par le décret n° 2011-1388 du 28 octobre 2011\r\nOEP reconduit pour cinq ans à compter du 28/10/2016 par le décret n° 2016-1436 du 26 octobre 2016\r\nLégalisé par la loi n° 2018-699 du 3 août 2018 - art. L. 4211-1 du code général de la propriété des personnes publiques	économie, finances	2	Mandat parlementaire	ACTIF	\N	\N	Conseil de l'immobilier de l'Etat	\N	du 	Sénat\r\n	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	2019-02-25 18:13:56	LEG	OUI	INDETERMINEE	NON	236
ORGEXT	240	240	\N	2012-01-31 00:00:00	\N	Article 2 de la loi n° 2007-309 du 5 mars 2007 relative à la modernisation de la diffusion audiovisuelle et à la télévision du futur\r\ns'est éteinte le 30 novembre 2011 car elle n'a pas été prorogé	Culture	4	Jusqu'au 30 novembre 2011	ANCIEN	\N	\N	Commission du dividende numérique	\N	de la 	2 Sénateurs sur proposition de la commission des affaires économiques et 2 Sénateurs sur proposition de la commission de la culture\r\nla désignation avait été demandée après le renouvellement par le SGG dans l'attente d'une prolongation qui n'est pas inter	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	240
ORGEXT	239	239	\N	\N	\N	Décret n° 2007-634 du 27 avril 2007 (art.7)\r\nLégalisé par la loi n° 2018-699 du 3 août 2018 (art 30)	Recherche, sciences et techniques	1	3 ans (remplacement pour la durée du mandat restant à courir)	ACTIF	\N	\N	Conseil d'administration de l'Institut des hautes études pour la science et la technologie	\N	du 	1 sénateur, désigné par le Sénat	\N	\N	\N	\N	OUI	LOI	NEANT	\N	\N	2019-02-25 16:51:52	LEG	NON	INDETERMINEE	NON	239
ORGEXT	241	241	\N	2014-02-17 00:00:00	\N	Article R. 315-2 du code de l'entrée et du séjour des étrangers et du droit d'asile\r\nOrganisme supprimé par le décret n° 2014-1232 du 17 février 2014	Immigration, Police et sécurité, Affaires étrangères et coopération	1	2 ans	ANCIEN	\N	\N	Commission nationale des compétences et des talents	\N	de la 	Désignation par le Sénat sur proposition de la commission des Lois - nomination par arrêté ministériel	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2017-04-04 17:02:30	NEANT	NON	INDETERMINEE	NON	241
ORGEXT	243	243	\N	\N	\N	Art. L. 302-9-1-1 et R. 302-26 du code de la construction et de l'habitation (modifié par décret n° 2017-835 du 5 mai 2017 qui a fixé à trois ans la durée du mandat)	Urbanisme	2	3 ans	ACTIF	\N	\N	Commission nationale chargée de l'examen du respect des obligations de logements sociaux	\N	de la 	Sénat (sur proposition de la commission des affaires économiques)	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2017-12-18 10:23:42	LEG	NON	INDETERMINEE	NON	243
ORGEXT	232	232	\N	2016-03-23 00:00:00	\N	art 39 de la loi n° 2006-296 pour l'égalité des chances du 31 mars 2006 (art L. 121-15 du code de l'action sociale et des familles) et décret n° 2006-945 du 28 juillet 2006 (art R. 121-14 du code de l'action sociale et des familles)\r\nDissolution de l'OEP intervenue le 1er janvier 2016 en application du décret n° 2014-563 du 30 mai 2014 (indication du SGG le 23 mars 2016)	Affaires sociales	2	après chaque renouvellement partiel	ANCIEN	\N	\N	Conseil d'administration de l'Agence nationale pour la cohésion sociale et l'égalité des chances 	\N	du 	Sénat (proposition de la commission des affaires sociales)	\N	\N	\N	\N	OUI	LOI	NEANT	\N	\N	2016-03-23 17:51:06	NEANT	NON	INDETERMINEE	NON	232
ORGEXT	242	242	\N	2014-05-27 00:00:00	\N	Article 51 de la loi n° 2007-1199 du 10 août 2007 relative aux libertés et responsabilités des universités \r\nArticle 2 du décret n° 2008-72 du 23 janvier 2008\r\nNB: Cet OEP a étré frappé de caducité quinquennale sur indication du SGG le 27 mai 2014. JB	Education, enseignement supérieur	2	Fin du mandat parlementaire	ANCIEN	\N	\N	Comité de suivi de la loi relative aux libertés et responsabilités des universités	\N	du 	Sénat (sur proposition de la commission des Affaires culturelles)\r\n	\N	\N	\N	\N	OUI	LOI	NEANT	\N	\N	2014-10-06 16:57:11	NEANT	NON	INDETERMINEE	NON	242
ORGEXT	208	208	\N	2018-08-02 00:00:00	\N	Décret n° 2004-1350 du 9 décembre 2004 (art. 6)	Culture et éducation	1	3 ans renouvelable (remplacement pour la durée du mandat restant à courir)	ACTIF	\N	\N	Conseil d'administration de l'Établissement public du musée du quai Branly	\N	du 	Sénat sur proposition de la commission des affaires culturelles	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2017-04-04 16:23:13	REG	NON	INDETERMINEE	NON	208
ORGEXT	244	244	\N	2015-01-20 00:00:00	\N	Décret n° 2008-371 du 18 avril 2008 (articles 6 et 7) et décret n° 2010-333 du 25 mars 2010 \r\n "représentants des assemblées sont invités à participer aux travaux".organisme ad hoc : désignation par le président. Antérieurement, Sénat (1 sur proposition de la commission des affaires sociales, 1 sur proposition de la commission des finances). OEP supprimé 20/01/2015	Finances publiques	2	Fin du mandat parlementaire	ANCIEN	\N	\N	Comité national de lutte contre la fraude (et commission nationale de lutte contre le travail illégal)	\N	du 	Président du Sénat	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2015-02-18 17:40:30	NEANT	NON	INDETERMINEE	NON	244
ORGEXT	246	246	\N	\N	\N	Article L. 211-2-1 du code du patrimoine\r\nArticle 3 de l'arrêté du 21 janvier 1988 portant création du Conseil supérieur des archives 	Culture	1	Durée du mandat parlementaire	ACTIF	\N	\N	Conseil supérieur des archives	\N	du 	Sénat sur proposition de la commission des Lois	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2017-09-13 15:11:51	LEG	OUI	INDETERMINEE	NON	246
ORGEXT	247	247	\N	2017-06-09 00:00:00	\N	Article D. 141-3 du code de l'action sociale et de la famille\r\nSupprimé le 9 juin 2017 sur notification du SGG	Famille	2	Renouvellement triennal	ANCIEN	\N	\N	Haut conseil de la famille	\N	du 	Sénat sur proposition de la commission des Affaires sociales	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2017-06-13 11:59:16	REG	NON	INDETERMINEE	NON	247
ORGEXT	248	248	\N	2013-04-11 00:00:00	\N	Décret n° 2008-1475 du 30 décembre 2008\r\narticle L. 750-1-1 du code de commerce 	\N	1	Trois ans - Mandat renouvelable une fois - Remplacement pour la durée restante	ANCIEN	\N	\N	Conseil stratégique du commerce de proximité	\N	du 	Président du Sénat\r\nSupprimé en avril 2013 (simplification administrative)	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2013-10-03 17:13:33	NEANT	NON	INDETERMINEE	NON	248
ORGEXT	234	234	\N	2018-08-03 00:00:00	\N	Articles L.225-15 et L.225-16 du code de l'action sociale et des familles (Historique : loi n° 2005-744 du 4 juillet 2005 portant réforme de l'adoption et convention constitutive du Groupement d'intérêt public "Agence française de l'adoption") - L'AFA est créée sous forme de GIP, le code ne fixe pas la composition du comité de suivi (seuls les statuts du GIP prévoient la participation des Sénateurs).	famille + affaires étrangères	2	fin du mandat sénatorial (par défaut)	ACTIF	\N	\N	Comité de suivi de l'Agence française de l'adoption	\N	du 	Président du Sénat (pour la première nomination) - Une lecture stricte du texte constitutif pourrait attribuer le pouvoir de nomination au Sénat sur proposition de la commission des affaires sociales	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2017-04-04 16:26:03	REG	NON	INDETERMINEE	NON	234
ORGEXT	136	136	\N	2013-01-11 00:00:00	\N	Article 38 de la loi n°94-637 du 25 juillet 1994 relative à la sécurité social et Arrêté du 10 mars 1995 relatif à la composition du Comité national d'évaluation des dispositifs expérimentaux d'aide aux personnes âgée.\r\nCet OEP est supprimé par arrêté du 11/01/2013 confimé par SGG le 11/12/2014\r\n	Santé	2	Fin du mandat sénatorial	ANCIEN	\N	\N	Comité national d'évaluation des dispositifs expérimentaux d'aide aux personnes âgées dépendantes 	\N	du 	Président du Sénat (un titulaire et un suppléant)	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2015-10-06 19:16:25	NEANT	NON	INDETERMINEE	NON	136
ORGEXT	189	189	\N	2020-12-07 00:00:00	\N	Article L. 1512-8 du code des transportsArt. R. 1512-1 du code des transports - Supprimé loi ASAP n° 2020-1525 du 7 décembre 2020	Transports	2	3 ans	ACTIF	\N	\N	Conseil d'administration du Fonds pour le développement de l'intermodalité dans les transports	\N	du 	Sénat (article 9 du Règlement) sur proposition de la commission du développement durable (pour une candidature) et de la commission des finances (pour une candidature)\r\n	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	2017-06-13 15:36:12	LEG	NON	INDETERMINEE	NON	189
ORGEXT	190	190	\N	\N	\N	Décret  n°2002-1387 du 27/11/2002, article L.146-1 du code de l'action sociale et des familles, art. 1er de la loi n°2002-303 du 4 mars 2002 relative aux droits des malades et D 146-1du code de l'action sociale et des familles	Sécurité sociale, travail	1	Durée du mandat parlementaire	ACTIF	\N	\N	Conseil national consultatif des personnes handicapées	\N	du 	Sénat sur proposition de la commission des affaires sociales	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2017-09-13 16:47:04	LEG	OUI	INDETERMINEE	NON	190
ORGEXT	73	73	\N	\N	\N	article 1er bis de la loi du 7 juin 1951 modifié par l'art. 74 de la loi du 3 août 2018	Economie, finances	1	Mandat parlementaire	ACTIF	\N	\N	Conseil national de l'information statistique	\N	du 	Sénat: un candidat sur proposition de la commission des affaires économiques (article 9 du Règlement)	Economie	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	2017-12-18 11:30:40	LEG	OUI	OEP	NON	73
ORGEXT	191	191	\N	2010-09-09 00:00:00	\N	Décret n° 2002-1355 du 14 nov 2002 relatif au Haut conseil de la coopération internationale\r\nAbrogé par le décret n° 2008-273 du 20 mars 2008 supprimant le Haut Conseil de la coopération internationale \r\n\r\n	Affaires étrangères	2	Durée du mandat sénatorial	ANCIEN	\N	\N	Haut conseil de la coopération internationale	\N	du 	2 sénateurs désignés par le Sénat sur proposition de la commission des affaires étrangères (à noter que la première désignation a été effectuée directement par le Président du Sénat)	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	191
ORGEXT	192	192	\N	2015-01-23 00:00:00	\N	Article 50 de la loi n° 2003-721 du 1er aout 2003\r\nDécret n° 2004-103 du 30 janvier 2004\r\nNB OEP supprimé sur l'indication du SGG le 23/01/2015 voir OEP 329 Business France.	Economie, finances	1	fin du mandat parlementaire  ( en cas de remplacement, le remplaçant "hérite" de la durée du mandat de son prédécesseur)	ANCIEN	\N	\N	Conseil d'administration d'UBIFRANCE, Agence française pour le développement international des entreprises	\N	du 	Un sénateur sur proposition de la commission des affaires économiques (article 9 du Règlement)\r\n9 Janvier 2015 Démission de Mme LAMURE.\r\n	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2015-10-09 11:53:35	NEANT	NON	INDETERMINEE	NON	192
ORGEXT	194	194	\N	\N	\N	Loi n° 2005-15798 du 19 décembre 2005 et décret n° 2006-1370  du 9 novembre 2006 relatif à la composition et au fonctionnement du Haut conseil pour l'avenir de l'assurance maladie (décret 2003-959 du 7 octobre 2003 portant création d'un haut conseil pour l'avenir de l'assurance maladie : abrogé) \r\nLégalisé par la loi n° 2018-699 du 3 août 2018 - art. 72 de la loi n° 2005-1579 du 19 décembre 2005 de financement de la sécurité sociale pour 2006 \r\nArt. 72 de la loi n° 2005-1579 du 19 décembre 2005	Sécurité sociale, travail	3	3 ans - Renouvellement triennal	ACTIF	\N	\N	Haut conseil pour l'avenir de l'assurance maladie	\N	du 	Sénat (2 sur proposition commission des affaires sociales, 1 sur proposition commission des finances). Les désignations sont renouvelées après chaque renouvellement partiel, selon le dernier alinéa de l'art 2) \r\nMme des Esgaulx démissionne à compter du 1er novembre 2015.	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2019-02-26 15:25:29	LEG	OUI	INDETERMINEE	NON	194
ORGEXT	193	193	\N	\N	\N	Décret n° 2003-415 du 30 avril 2003 relatif à la composition et au fonctionnement de l'Observatoire national du service public de l'électricité et du gaz	Energie	4	Durée du mandat parlementaire	ACTIF	\N	\N	Observatoire national du service public de l'électricité et du gaz	\N	de l'	Sénat (article 9 du Règlement) sur proposition de la commission des affaires économiques (1 tit, 1 suppl) et des finances (1 tit, 1 suppl)	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2015-03-23 09:43:59	REG	NON	INDETERMINEE	NON	193
ORGEXT	196	196	\N	\N	\N	Article 3 de la loi n°52-893 du 25 juillet 1952 relative au droit d'asile (modifié par l'article 2 de la loi n°2003-1176 du 10 décembre 2003) article L. 722-1 du code de l'entrée et du séjour des étrangers et du droit d'asile\r\nmodifié par l'art. 8 de la loi n° 2015-925	Intérieur - Libertés publiques	2	Durée du mandat parlementaire	ACTIF	\N	\N	Conseil d'administration de l'Office français de protection des réfugiés et apatrides (OFPRA)	\N	du 	Sénat sur proposition de la commission des lois\r\nDeux sénateurs un homme et une femme (art 8 de la loi n° 2015-925)	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2017-04-04 16:21:44	LEG	NON	INDETERMINEE	NON	196
ORGEXT	140	140	\N	\N	\N	Article R.835-3 du code du travail (anciennement décret n°95-984 du 25 aoùt 1995 relatif à l'organisation et à la gestion du Fonds pour l'emploi dans les départements d'outre-mer et la collectivité de Saint Pierre-et-Miquelon et modifiant le code du travail).\r\nSupprimé en application du décret n° 2006-672 du du 8 juin 2006 relatif à la création, à la composition et au fonctionnement de commissions administratives à caractère consultatif. \r\n	Départements et territoires d'outre-mer	3	Fin du mandat sénatorial	ANCIEN	\N	\N	Comité directeur du Fonds pour l'emploi dans les départements d'outre-mer et la collectivité territoriale de Saint-Pierre-et-Miquelon (FEDOM)	\N	du 	Président du Sénat parmi les sénateurs des départements d'outre-mer et de St Pierre et Miquelon	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	140
ORGEXT	141	141	\N	2018-09-12 00:00:00	\N	Art. 2 de la loi n° 95-115 du 4 février 1995 Décret n°95-1066 du 29 septembre 1995 portant création du Conseil National de l'aménagement et du développement du territoire./Décret n°96-43 du 17 janvier 1996 modifiant le décret n°95-1066 du 29 septembre 1995./Décret n° 2000-907 du 19 septembre 2000 relatif au CNADT.\r\nArt. 3 de la loi n° 95-115 du 4 février 1995	Aménagement du territoire	5	Durée du mandat parlementaire - mandat renouvelable une fois	ANCIEN	\N	\N	Conseil national de l'aménagement et du développement du territoire (CNADT)	\N	du 	Sénat: trois candidats proposés par la commission du développement durable, un candidat proposé par la commission des finances et un candidat proposé par la commission des lois (article 9 du Règlement)	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2018-09-21 17:46:01	REG	OUI	INDETERMINEE	NON	141
ORGEXT	143	143	\N	2015-10-07 00:00:00	\N	Art. 5 de la loi n° 95-1251 du 28 novembre 1995 relative à l'action de l'État dans le plan de redressement du Crédit Lyonnais et du Comptoir des entrepreneurs, abrogé par l'art. 43 de la loi n° 2014-1654 du 29 décembre 2014 de finances pour 2015\r\nCaducité constatée par le SGG le 7 octobre 2015\r\n	Economie, finances	1	3 ans sous réserve du manadt parlementaire	ANCIEN	\N	\N	Conseil d'administration de l'Établissement public de financement et de restructuration	\N	du 	Sénat sur proposition de la commission des finances	PREMIER MINISTRE FINANCES	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2016-10-14 11:28:39	NEANT	NON	INDETERMINEE	NON	143
ORGEXT	144	144	\N	2015-10-07 00:00:00	\N	Art. 9 de la loi n° 95-1251 du 28 novembre 1995 relative à l'action de l'Etat dans les plans de redressement du Crédit Lyonnais et du Comptoir des entrepreneurs /  Décret n°96-125 du 20 février 1996 portant statuts de l'établissement de défaisance.\r\nArt. 9 de la loi de 1995 abrogé par l'art. 43 de la loi n° 2014-1654 du 29 décembre 2014 de finances pour 2015\r\nCaducité constatée par le SGG le 7 octobre 2015	Economie, finances	1	Fin du mandat parlementaire	ANCIEN	\N	\N	Conseil d'administration de l'Etablissement public de réalisation de défaisance	\N	du 	Sénat sur proposition de la commission des finances	Premier Ministre finances	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2016-10-14 11:23:48	NEANT	NON	INDETERMINEE	NON	144
ORGEXT	145	145	\N	\N	\N	Décret n°96-180 du 11 mars 1996 portant création du "comité pour la commémoration des origines : de la Gaule à la France"	Culture et éducation	1	jusqu'au 31-12-1997	ANCIEN	\N	\N	Comité pour la commémoration des origines: de la Gaule à la France (caduc au 31-12-1997)	\N	du 	Président du Sénat	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	145
ORGEXT	146	146	\N	2011-12-31 00:00:00	\N	Décret n° 96-190 du 12 mars 1996 relatif à la composition et aux modalités de fonctionnement de la Commission nationale des comptes de la formation professionnelle.\r\nArticles  L.910-3 et  D.910-22 et D. 910-24 du code du travail  abrogés par art. 154 loi n° 2002-73 et décret n° 2002-658\r\n	Sécurité sociale, travail	2	Fin du mandat sénatorial	ANCIEN	\N	\N	Commission nationale des comptes de la formation professionnelle	\N	de la 	Président du Sénat	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	146
ORGEXT	147	147	\N	\N	\N	Art. 3 de l'ordonnance n° 96-50 du 24 janvier 1996\r\nArt. 4 du décret n° 96-353 du 24 avril 1996 relatif à la caisse d'amortissement de la dette sociale	Sécurité sociale, travail	2	3 ans sous réserve du mandat sénatorial	ACTIF	\N	\N	Comité de surveillance de la Caisse d'amortissement de la dette sociale	\N	du 	Sénat: un candidat proposé par la commission des affaires sociales et un candidat proposé par la commission des finances	Finances	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2017-03-21 16:17:03	LEG	NON	INDETERMINEE	NON	147
ORGEXT	148	148	\N	2011-12-31 00:00:00	\N	Art.L.228-1 et R.228-1 du code de la sécurité sociale.\r\n\r\nAbrogé par la loi n° 2011-1906 du 21 décembre 2011 de financement de la sécurité sociale  (art. 110)	Sécurité sociale, travail	3	5 ans	ANCIEN	\N	\N	Conseil de surveillance de la Caisse nationale de l'assurance maladie des travailleurs salariés	\N	du 	Président du Sénat	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	148
ORGEXT	150	150	\N	2011-12-31 00:00:00	\N	Art. L.228-1 et R.228-3 du code de la sécurité sociale\r\n\r\nAbrogé par la loi n° 2011-1906 du 21 décembre 2011 de financement de la sécurité sociale  (art. 110)	Sécurité sociale, travail	3	5 ans	ANCIEN	\N	\N	Conseil de surveillance de la caisse nationale d'assurance vieillesse des travailleurs salariés	\N	du 	Président du Sénat	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	150
ORGEXT	152	152	\N	\N	\N	Art L.121-3 du code de l'environnement ( art 134 de la loi n° 2002-276 du 27 février 2002 relative à la démocratie de proximité).\r\nDémission REQUIER 4 mai 2015	Environnement, logement, urbanisme	1	durée du mandat ( renouvelable une fois )	ACTIF	\N	\N	Commission nationale du débat public	\N	de la 	Président du Sénat (auparavant Sénat sur proposition de la commission des affaires économiques)\r\nAu 15 avril 2014, M REQUIER remplace Mme ROSSIGNOL, démissionnaire. Son mandat court jusqu'aux élections sénatoriales de 2017.	Environnement	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2015-10-06 18:17:15	LEG	NON	INDETERMINEE	NON	152
ORGEXT	76	76	\N	\N	\N	Article L. 4642-2 du code du travail	Sécurité sociale, travail	1	Fin du mandat sénatorial	ACTIF	\N	\N	Conseil d'administration de l'Agence nationale pour l'amélioration des conditions de travail (ANACT)	\N	du 	un "représentant de chacune des commissions chargées des affaires sociales au Parlement" soit un sénateur désigné par la commission désigné par la commission des affaires sociales directement parmi ses membres	Travail	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2015-10-06 18:26:55	LEG	NON	INDETERMINEE	NON	76
ORGEXT	77	77	\N	2011-09-08 00:00:00	\N	Article  R. 5214-3 du code du travail\r\nAbrogé par le décret n° 2011-1073 du 8 septembre 2011 relatif à la suppression de commissions et instances administrative	Sécurité sociale, travail	2	Fin du mandat sénatorial	ANCIEN	\N	\N	Conseil supérieur pour le reclassement professionnel et social des travailleurs handicapés	\N	du 	Sénat sur proposition de la commission des affaires sociales	Sante	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	77
ORGEXT	82	82	\N	\N	\N	Décret n° 83-755 du 16 août 1983 instituant la commission consultative pour la production de carburants de substitution.\r\n\r\nSupprimé par le décret n° 2005-802 du 18 juillet 2005	Energie	2	3 ans	ANCIEN	\N	\N	Commission consultative pour la production de carburants de substitution	\N	de la 	Sénat sur proposition de la commission des affaires économiques	Industrie	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	82
ORGEXT	84	84	\N	2001-12-31 00:00:00	\N	Décret n°83-1083 du 8 décembre 1983 portant création d'un conseil national de la cinématographie.	Culture et éducation	4	Fin du mandat sénatorial	ANCIEN	\N	\N	Conseil national de la cinématographie	\N	du 	Deux sénateurs (un titulaire et un suppléant) désignés par la commission des affaires culturelles et deux sénateurs (un titulaire et un suppléant) désignés par la commission des finances	Culture	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	84
ORGEXT	86	86	\N	\N	\N	Loi n° 2007-292 et décret n° 2007-1137 (anciennement décret n° 84-72 du 30 janvier 1984 modifié relatif à la Commission nationale consultative des droits de l'homme) modifié	Intérieur - Libertés publiques	1	Fin du mandat sénatorial	ACTIF	\N	\N	Commission nationale consultative des droits de l'homme	\N	de la 	Président du Sénat (le décret de 2007 modifié par le décret 2012-1388 ne précise pas les conditions de désignation)	Relations Exterieures	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2015-10-07 12:08:27	LEG	NON	INDETERMINEE	NON	86
ORGEXT	87	87	\N	2004-08-23 00:00:00	\N	Décret n°84-709 du 24 juillet 1984 pris en application de la loi n°84-46 du 24 janvier 1984 relative à l'activité et au contrôle des établissements de crédit.\r\n\r\nSupprimé par le décret n° 2004-849 du 23 août 2004	Economie, finances	2	Fin du mandat sénatorial	ANCIEN	\N	\N	Conseil national du crédit	\N	du 	Sénat sur proposition de la commission des finances	Economie	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	87
ORGEXT	88	88	\N	2018-08-02 00:00:00	\N	Décret n°92-437 du 19 mai 1992 portant création d'une commission permanente pour la protection sociale des Français de l'étranger	Sécurité sociale, travail	1	3 ans renouvelable	ACTIF	\N	\N	Commission permanente pour la protection sociale des Français de l'étranger	\N	de la 	Sénat: un candidat proposé par la commission des affaires sociales parmi les sénateurs représentant les français établis hors de France	Relations exterieures	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2017-09-13 17:51:33	REG	OUI	INDETERMINEE	NON	88
ORGEXT	89	89	\N	\N	\N	Loi n° 84-409 du 1er juin 1984 relative à la création du Carrefour international de la communication	Communication	2	Fin du mandat sénatorial	ANCIEN	\N	\N	Carrefour international de la communication	\N	du 	Un sénateur désigné par la commission des affaires culturelles et un sénateur désigné par la commission des finances. (Un seule nomination en 1984)	Premier Ministre	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	89
ORGEXT	90	90	\N	\N	\N	Arrêté du 1er avril 1985 portant création du comité de l'éthique du loto sporti f(supprimé par le décret 2002-768 du 3 mai 2002)	Jeunesse, sports, tourisme, vie associative	2	Fin du mandat sénatorial	ANCIEN	\N	\N	Comité de l'éthique du loto sportif	\N	du 	Président du Sénat	SPORTS	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	90
ORGEXT	93	93	\N	2000-03-03 00:00:00	\N	Décret n°85-488 du 6 mai 1985 portant création du conseil de gestion du Fonds national pour le développement de la vie associative. Abrogé par le décret n°2000-202 du 3 mars 2000 (JO du 7 mars 2000)	Jeunesse, sports, tourisme, vie associative	1	Fin du mandat sénatorial	ANCIEN	\N	\N	Conseil de gestion du Fonds national pour le développement de la vie associative	\N	du 	Sénat sur proposition de la commission des affaires culturelles	Jeunesse et sports	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	93
ORGEXT	262	262	\N	2018-08-03 00:00:00	\N	Article 1er du décret n° 2009-1352 du 2 novembre 2009 relatif à la composition du Comité consultatif de gouvernance -\r\nArticle L. 213-4-1 du code de l'environnement\r\n	\N	1	durée du mandat parlementaire	ACTIF	\N	\N	Comité consultatif de gouvernance	\N	du 	Président du Sénat	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2014-10-06 17:00:37	REG	NON	INDETERMINEE	NON	262
ORGEXT	95	95	\N	\N	\N	Article 6 de la loi n° 85-30 du 9 janvier 1985 relative au développement et à la protection de la montagne (modifié par la loi n° 2016-1888 du 28 décembre 2016)\r\nDécret n° 2017-754 du 3 mai 2017	Agriculture	5	mandat parlementaire	ACTIF	\N	\N	Conseil national de la montagne	\N	du 	Sénat (article 9 du Règlement) deux candidats sur proposition de la commission des affaires économiques, deux candidats sur proposition de la commission du développement durable, un candidat sur proposition de la commission des lois	Aménagement du territoire	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2017-12-18 11:35:57	LEG	OUI	INDETERMINEE	NON	95
ORGEXT	96	96	\N	2013-10-03 00:00:00	\N	Loi n°85-699 du 11 juillet 1985 tendant à la constitution d'archives audiovisuelles de la justice.\r\narticle D. 221-8 du code du patrimoine Le SGG confirme la suppression de cet OEP le 11/12/2014	Justice, législation générale	1	3 ans renouvelable une seule fois - remplacement pour la durée du mandat restant à courir	ANCIEN	\N	\N	Commission consultative des archives audiovisuelles de la justice	\N	de la 	Sénat sur proposition de la commission des lois	Justice	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2014-12-11 16:41:23	NEANT	NON	INDETERMINEE	NON	96
ORGEXT	174	174	\N	2010-10-01 00:00:00	\N	Article 110 de la loi de finances pour 2001 (n° 2000-1352 du 30 décembre 2000). Décret n°2001-578 du 2 juillet 2001 instituant une commission d'étude de la revalorisation des rentes, des retraites et des pensions des anciens combattants de l'outre-mer./ (abrogation du décret n°2001-578 du 2 juillet 2001 par le décret 2005-414 du 29 avril 2005 relatif à la simplification de la composition des commissions administratives et à la réduction de leur nombre au ministère de la défense)	Anciens combattants et victimes de guerre	2	Durée du mandat sénatorial.	ANCIEN	\N	\N	Commission d'étude de la revalorisation des rentes, des retraites et des pensions des anciens combattants de l'outre-mer	\N	de la 	Président du Sénat	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	174
ORGEXT	175	175	\N	2020-12-07 00:00:00	\N	Article 72 de la loi n° 2000-516 du 15 juin 2000 renforçant la protection de la présomption d'innocence et les droits des victimes/ Décret n° 2001-709 du 31 juillet 2001 relatif à la commission de suivi de la détention provisoire et modifiant le code de procédure pénale. - Supprimé loi ASAP n° 2020-1525 du 7 décembre 2020	Justice, législation générale	1	3 ans	ACTIF	\N	\N	Commission de suivi de la détention provisoire	\N	de la 	Président du Sénat	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2017-09-13 16:37:37	LEG	OUI	INDETERMINEE	NON	175
ORGEXT	176	176	\N	\N	\N	Décret n° 2001-784 du 28 août 2001 portant création du Conseil national de la sécurité routière et modifiant le décret n° 75-360 du 15 mai 1975 relatif au comité interministériel de la sécurité routière\r\nLégalisé par la loi n° 2018-699 du 3 août 2018 - art. L. 130-10 du code de la route	Transports	2	mandat parlementaire	ACTIF	\N	\N	Conseil national de la sécurité routière	\N	du 	Sénat sur proposition de la commission du développement durable et des lois\r\n(Mme Tetuanui nommée le 19 janvier 2017 par le Président du Sénat en raison de l'urgence de la désignation.)	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2019-02-25 18:45:45	LEG	OUI	INDETERMINEE	NON	176
ORGEXT	177	177	\N	2013-02-11 00:00:00	\N	Loi n°2001-582 du 4 juillet 2001- Décret n°2001-900 du 2 octobre 2001 relatif à la Commission nationale pour l'autonomie des jeunes	Sécurité sociale, travail	3	Durée du mandat parlementaire	ANCIEN	\N	\N	Commission nationale pour l'autonomie des jeunes	\N	de la 	Président du Sénat	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2013-10-03 16:45:58	NEANT	NON	INDETERMINEE	NON	177
ORGEXT	178	178	\N	2004-12-31 00:00:00	\N	Articles L. 131-8 et R. 131-13 du code de la sécurité sociale en sommeil suite à la réforme du FOREC cf art 34 loi de finances pour 2004 n° 2003-1311 du 30/12/2003	Sécurité sociale, travail	2	3 ans	ANCIEN	\N	\N	Conseil de surveillance du Fonds de financement de la réforme des cotisations patronales de sécurité sociale	\N	du 	Sénat sur proposition de la commission des affaires sociales pour un candidat et sur proposition de la commission des Finances pour l'autre candidat	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	178
ORGEXT	179	179	\N	\N	\N	Article L. 440-1 du code de commerce\r\nDécret n° 2001-1370 du 31 décembre 2001 portant organisation de la commission d'examen des pratiques commerciales, décret 2002-1370 du 21 novembre 2002, décret n° 2009-559 du 19 mai 2009\r\nDécret n° 2009-559 du 19 mai 2009	Economie, finances	1	Fin du mandat sénatorial	ACTIF	\N	\N	Commission d'examen des pratiques commerciales	\N	de la 	Commission des affaires économiques	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2017-09-13 17:03:03	LEG	OUI	INDETERMINEE	NON	179
ORGEXT	180	180	\N	\N	\N	Art. L.135-8 et art. R.135-19 du code de la sécurité socialeLégalisé par la loi n° 2018-699 du 3 août 2018 	Sécurité sociale, travail	2	Fin du mandat sénatorial	ACTIF	\N	\N	Conseil de surveillance du Fonds de réserve pour les retraites	\N	du 	Sénat sur proposition de la commission des affaires sociales pour deux candidats (un titulaire et un suppléant) et sur proposition de la commission des Finances pour deux candidats (un titulaire et un suppléant)	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2019-02-25 18:17:23	LEG	NON	INDETERMINEE	NON	180
ORGEXT	50bis	50	\N	\N	\N	Décret n°73-251 du 6 mars 1973	Agriculture	2	3 ans	ANCIEN	\N	\N	Section de l'assurance des salariés agricoles contre les accidents du travail et les maladies professionnelles du Conseil supérieur des prestations agricoles	\N	de la 	Sénat parmi les sénateurs qu'il a désignés pour siéger au Conseil supérieur des prestations sociales agricoles: la commission des affaires sociales et la commission des finances désignent en alternance un titulaire et un suppléant	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	50bis
ORGEXT	17	17	\N	2019-01-01 00:00:00	\N	Décret n° 2000-880 du 11 septembre 2000 relatif au fonds de solidarité prioritaire du ministère des affaires étrangères. Abrogé par le décret n° 2018-1044 du 27 novembre 2018.	Affaires étrangères	2	Fin du mandat sénatorial	ACTIF	\N	\N	Conseil d'orientation stratégique du fonds de solidarité prioritaire (anciennement : Comité directeur du Fonds d'aide et de coopération)	\N	du 	Sénat sur proposition de la commission des finances pour un siège, sur proposition de la commission des affaires étrangères pour l'autre siège	Coopération	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2017-04-04 14:58:24	REG	NON	INDETERMINEE	NON	17
ORGEXT	38	38	\N	\N	\N	Accord Gouvernement-Sénat	Agriculture	4	Fin du mandat sénatorial	ANCIEN	\N	\N	Commission parlementaire chargée du contrôle périodique du Fonds d'Orientation et de Régularisation des marchés agricoles (FORMA)	\N	de la 	Deux sénateurs désignés par la commission des affaires économiques et deus sénateurs désignés par la commission des finances 	Agriculture	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	38
ORGEXT	46	46	\N	2020-12-07 00:00:00	\N	Légalisé par la loi n° 2018-699 du 3 août 2018 (art. L. 411-2 du code de la mutualité) Durée : art.R. 511-2 du code de la mutualité - Supprimé loi ASAP n° 2020-1525 du 7 décembre 2020	Sécurité sociale, travail	1	6 ans	ACTIF	\N	\N	Conseil supérieur de la mutualité	\N	du 	Sénat sur proposition de la commission des affaires sociales	Affaires sociales	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2019-02-26 11:53:03	LEG	NON	INDETERMINEE	NON	46
ORGEXT	181	181	\N	2014-02-17 00:00:00	\N	Décret n° 2007-403 du 22 mars 2007 - Anciennement Conseil d'administration de l'Agence de prévention et de surveillance des risques miniers créé par la loi n°99-245 du 30 mars 1999, supprimé par l'article 112 de la loi n°2006-1666 du 21 décembre 2006, de finances pour 2007 Organisme supprimé par le décret n° 2014-132 du 17 février 2014\r\nATTENTION Commission créée pour 5 ans 	Energie	2	fin du mandat au titre duquel ils ont été désignés	ANCIEN	\N	\N	Commission nationale de concertation sur les risques miniers 	\N	du 	Sénat sur proposition de la commission des affaires économiqueset de la commission du développement durable	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2014-09-26 14:13:33	NEANT	NON	INDETERMINEE	NON	181
ORGEXT	182	182	\N	2008-09-21 00:00:00	\N	loi n° 2001-647 du 20 juillet 2001 - remplacée par la caisse nationale de solidarité n° 212	Sécurité sociale, travail	2	3 ans	ANCIEN	\N	\N	Conseil de surveillance du fonds de financement de l'allocation personnalisée d'autonomie	\N	du 	Président du Sénat	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	182
ORGEXT	183	183	\N	2010-12-01 00:00:00	\N	Décret n°2002-258 du 22 février 2002 portant application de l'article 74 de la loi n°2000-1207 du 13 décembre 2000 et relatif à la création de la commission des comptes économiques et sociaux des départements d'outre-mer et de suivi de la loi d'orientation pour l'outre mer L'article 74 de la loi n° 2000-1207 du 13 décembre 2000 a été abrogé par l'article 10 6° de l'ordonnance n° 2004-637 du 1er juillet 2004.	Départements et territoires d'outre-mer	3	3 ans renouvelable	ANCIEN	\N	\N	Commission des comptes économiques et sociaux des départements d'outre-mer et de suivi de la loi d'orientation pour l'outre-mer	\N	de la 	Par le Président du Sénat parmi les Sénateurs élus dans un département d'outre-mer, à Saint-Pierre-et-Miquelon ou à Mayotte	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	183
ORGEXT	184	184	\N	2006-06-07 00:00:00	\N	Décret n°2002-484 du 9 avril 2002 portant création de la conférence permanente "habitat-construction-développement durable" (article 4) - abrogé par le décret n°2006-662 du 7 juin 2006	Environnement, logement, urbanisme	2	3 ans renouvelable, interrompu par la fin du mandat	ANCIEN	\N	\N	Conférence permanente "habitat-construction-développement durable"	\N	de la 	Sénat sur proposition de la commission des affaires économiques pour le membre titulaire et pour le membre suppléant	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	184
ORGEXT	185	185	\N	2017-02-20 00:00:00	\N	Art L. 229-2 du code de l'environnement\r\nOEP supprimé par le décret n° 2017-211 du 20 février 2017\r\nNotification du SGG le 16 mars 2017	Environnement, logement, urbanisme	2	 3 ans renouvelables ( ou fin du mandat restant à courir )	ANCIEN	\N	\N	Conseil d'orientation de l'Observatoire national sur les effets du réchauffement climatique en France métropolitaine et dans les départements et territoires d'outre-mer	\N	du 	Sénat sur proposition de la commission du développement durable pour le membre titulaire et pour le membre suppléant	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2017-03-21 16:26:53	NEANT	NON	INDETERMINEE	NON	185
ORGEXT	186	186	\N	\N	\N	article 3 de la loi n° 2002-5 du 4 janvier 2002 relative aux musées de France et décret n° 2002-628 du 25 avril 2002 pris pour l'application de la loi n° 2002-5 du 4 janvier 2002 relative aux musées de France	Culture et éducation	2	quatre ans renouvelable une fois (sous réserve du mandat parlementaire)	ACTIF	\N	\N	Haut conseil des musées de France	\N	du 	1 titulaire et 1 suppléant nommés par le Sénat sur proposition de la commission des affaires culturelles	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2017-09-13 15:11:18	LEG	OUI	INDETERMINEE	NON	186
ORGEXT	187	187	\N	\N	\N	Article L.141-4 du code monétaire et financier, décret n°2002-709 du 2 mai 2002 pris pour l'application de l'article L.141-4 du code monétaire et financier et relatif à l'Observatoire de la sécurité de cartes de paiement; décret n° 2009-654 du 9 juin 2009	Economie, finances	1	mandat renouvelable en cas de renouvellement de leur mandat de parlementaire	ACTIF	\N	\N	Observatoire de la sécurité de cartes de paiement	\N	de l'	Sénat sur proposition de la commission des finances	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2017-11-28 15:58:38	LEG	OUI	INDETERMINEE	NON	187
ORGEXT	188	188	\N	2014-06-04 00:00:00	\N	Article 154 de la loi n°2001-1275  de finances pour 2002\r\nmodifié par l'article 13 de la loi du 18 décembre 2013 de programmation militaire\r\nNB Cet OEP a été supprimé par décision du SGG du 4 juin 2014	Economie, finances	2	3 ans (après chaque renouvellement triennal)	ANCIEN	\N	\N	Commission de vérification des fonds spéciaux	\N	de la 	Avant 2013,  par le président du Sénat\r\nDepuis la loi 2013-1168, deux sénateurs membres de la délégation parlementaire au renseignement (DPR), \r\ndésignés de façon à assurer une représentation pluraliste\r\n	\N	\N	\N	\N	OUI	LOI	NEANT	\N	\N	2014-11-14 15:44:43	NEANT	NON	INDETERMINEE	NON	188
ORGEXT	153	153	\N	\N	\N	Arrêté du 24 décembre 1996 portant création d'un Comité national de l'Euro.	Economie, finances	2	6 ans (fin le 31/12/2002)	ANCIEN	\N	\N	Comité national de l'Euro	\N	du 	Président du Sénat	Economie	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	153
ORGEXT	290	290	2012-01-31 00:00:00	\N	\N	Art. 5 du décret n° 2011-2121 du 30 décembre 2011\r\nArt. 3 du décret n° 2006-672 du 8 juin 2006 (durée cinq ans)\r\nLégalisé par la loi n° 2018-699 du 3 août 2018 (art. 27)	\N	2	renouvellement sénatorial	ACTIF	\N	\N	Comité consultatif du fonds pour le développement de la vie associative	\N	du 	un titulaire et un suppléant désignés par le Sénat sur proposition de la commission de la culture	\N	\N	\N	\N	OUI	DECRET	ALERTE	\N	\N	2019-02-25 10:50:38	LEG	NON	INDETERMINEE	NON	290
ORGEXT	155	155	\N	2019-10-21 00:00:00	\N	Art. L. 325-1 et s. du code de l'urbanisme	Environnement, logement, urbanisme	1	3 ans (remplacement pour la durée restant à courir)	ACTIF	\N	\N	Conseil d'administration de l'établissement public national d'aménagement et de restructuration des espaces commerciaux et artisanaux (EPARECA)	\N	du 	Sénat sur proposition de la commission des affaires économiques	Commerce	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2018-03-20 10:53:45	LEG	NON	INDETERMINEE	NON	155
ORGEXT	156	156	\N	2025-02-01 00:00:00	\N	Article L.143-6 du code du patrimoine OEP supprimé par la loi n° 2021-710 du 4 juin 2021	Culture et éducation	1	Durée déterminée par les statuts de la fondation (4 ans) et sous réserve du mandat sénatorial	ACTIF	\N	\N	Conseil d'administration de la Fondation du patrimoine	\N	du 	Président du Sénat	Culture	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2017-04-04 16:18:10	LEG	NON	INDETERMINEE	NON	156
ORGEXT	158	158	\N	\N	\N	Article 2 de la loi n°98-567 du 8 juillet 1998 instituant une Commission consultative du secret de la défense nationale.\r\nCodifié dans le code de la défense (art. L. 2312-1 à L. 2312-8)	Défense	1	Renouvellement triennal.	ACTIF	\N	\N	Commission du secret de la défense nationale	\N	de la 	Président du Sénat	Défense	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2017-10-11 15:47:31	LEG	NON	INDETERMINEE	NON	158
ORGEXT	317	317	2013-11-15 00:00:00	\N	\N	loi n° 2013-1028 du 15 novembre 2013 article 18\r\n	\N	4	non précisée donc mandat parlementaire	ACTIF	\N	\N	Commission de modernisation de la diffusion audiovisuelle	\N	de la 	2 directement par affaires économiques et 2 directement par culture\r\nau moins un membre de l'opposition et parité	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2013-12-16 19:05:57	2014-11-13 17:17:17	LEG	NON	INDETERMINEE	NON	317
ORGEXT	206	206	\N	2017-12-26 00:00:00	\N	Décret n° 2004-967 du 7 septembre 2004 (organisme créé pour six ans, jusqu'au 7 septembre 2010) - Organisme créé pour 6 ans : disparaît en principe au 7 septembre 2010 a été prorogé par le décret n° 2011-887 du 26 juillet 2011 pour une durée de six ans.\r\nprésence des parlementaires supprimée par le décret n° 2017-1763 du 26 décembre 2017. \r\n	Collectivités locales	1	Durée du mandat parlementaire	ANCIEN	\N	\N	Observatoire des territoires	\N	de l'	Président du Sénat	\N	\N	\N	\N	OUI	NEANT	NEANT	2011-07-26 00:00:00	\N	2018-05-03 10:53:20	REG	OUI	INDETERMINEE	NON	206
ORGEXT	207	207	\N	2015-03-17 00:00:00	\N	Décret n° 2004-1135 du 22 octobre 2004\r\nOEP supprimé sur indication du SGG du 17/03/2015\r\nvoir décret n° 2015-77 du 27 janvier 2015 qui a abrogé le décret n° 2011-628 du 1er juin 2011	Collectivités locales	2	3 ans renouvelables, sous sréserve du mandat sénatorial	ANCIEN	\N	\N	Observatoire national des zones urbaines sensibles	\N	de l'	Sénat sur proposition de la commission des affaires économiques pour le titulaire \r\net Sénat sur proposition de la commission des affaires sociales pour le suppléant	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2017-04-04 17:00:27	NEANT	NON	INDETERMINEE	NON	207
ORGEXT	306	306	2012-12-31 00:00:00	\N	\N	Créé par la loi n° 2012-1559 du 31 décembre 2012 article 6ordonnance n° 2005-722 du 29 juin 2005 article 7-2 + décret 11 avril 2013	\N	2	Trois ans	ACTIF	\N	\N	Comité national d'orientation de la SA BPI Groupe	\N	du	Par le président du Sénat sur proposition de la commission des finances\r\nReprésentation pluraliste. Principe de parité.	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2017-04-04 16:35:07	LEG	NON	INDETERMINEE	NON	306
ORGEXT	304	304	2012-12-13 00:00:00	\N	\N	Institué par le décret n° 2012-1400 du 13 décembre 2012\r\nPrésence de parlementaires supprimée par le décret n° 2017-1677 du 8 décembre 2017\r\nLégalisé par la loi n° 2018-699 du 3 août 2018 (art. 33)\r\n	\N	2	Mandat parlementaire	ACTIF	\N	\N	Conseil national du numérique (formation élargie)	\N	du 	Président du Sénat\r\nDeux titulaires\r\n	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	2019-02-26 10:51:50	LEG	OUI	INDETERMINEE	NON	304
ORGEXT	210	210	\N	2017-12-20 00:00:00	\N	Décret n° 2005-99 du 8 février 2005 portant création du Conseil national de sécurité civile\r\nSuppression par le décret n° 2017-1721 du 20 décembre 2017 	Intérieur - Libertés publiques	2	3 ans	ANCIEN	\N	\N	Conseil national de sécurité civile	\N	du 	Un titulaire et un suppléant désignés par le Président du Sénat	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2018-01-08 18:29:03	REG	OUI	INDETERMINEE	NON	210
ORGEXT	211	211	\N	2014-10-13 00:00:00	\N	Articles L. 6123-2 du code du travail et D. 6123-2 à D. 6123-9 du code du travail (décret n° 2005-180 du 24 février 2005 relatif au Conseil national de la formation professionnelle tout au long de la vie et décret n° 2008-244 relatif à la partie réglementaire du code du travail) modifié par le décret n° 2011-1002 du 24 août 2011 OEP supprimé 13 octobre 2014 voir OEP 325\r\nmais art.4 prévoit fin de mandat 01/01/2012	Sécurité sociale, travail	4	3 ans	ANCIEN	\N	\N	Conseil national de la formation professionnelle tout au long de la vie	\N	du 	2 titulaires et 2 suppléants désignés par le Président du Sénat	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2014-10-13 15:59:13	NEANT	NON	INDETERMINEE	NON	211
ORGEXT	212	212	\N	\N	\N	Article L.14-10-1 et suivants et R.14-10-2 et suivants du code de l'action sociale et des familles\r\n\r\n(a remplacé le n° 182)	Sécurité sociale, travail	1	renouvellement triennal	ACTIF	\N	\N	Caisse nationale de solidarité pour l'autonomie	\N	de la 	Sénat sur proposition de la commission des affaires sociales	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2017-04-04 16:23:34	LEG	NON	INDETERMINEE	NON	212
ORGEXT	163	163	\N	2014-12-11 00:00:00	\N	Arrêté du 16 décembre 1999 (JO du 21 décembre 1999 , NOR: EQUP9901565A). Abroge notamment l'arrêté du 15 novembre 1990 qui créait le comité de liaison pour le transport des personnes handicapées (COLITRAH)\r\nLe SGG confirme que cet OEP n'existe plus le 11/12/2014	Santé	1	Durée du mandat parlementaire	ANCIEN	\N	\N	Comité de liaison pour l'accessibilité des transports et du cadre bâti (COLIAC)	\N	du 	Sénat sur proposition de la commission des affaires économiques	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2015-10-09 11:55:42	NEANT	NON	INDETERMINEE	NON	163
ORGEXT	164	164	\N	\N	\N	Art. L. 114-2 du code de la sécurité sociale Article D.114-4-0-2 du code de la sécurité sociale (Décret n° 2004-453 du 28 mai 2004 relatif à la composition et à l'organisation du Conseil d'orientation des retraites)\r\nArt. 6 de la loi n° 2003-775 du 21 août 2003	Sécurité sociale, travail	4	Désignation après chaque renouvellement triennal	ACTIF	\N	\N	Conseil d'orientation des retraites	\N	du 	Sénat sur proposition de la commission des affaires sociales pour trois postes et de la commission des Finances pour le quatrième	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2018-03-20 11:00:52	LEG	OUI	INDETERMINEE	NON	164
ORGEXT	165	165	\N	2011-03-29 00:00:00	\N	Article 2 de la loi n° 2000-494 du 6 juin 2000 portant création d'une commission nationale de déontologie de la sécurité\r\n\r\nDissoute en application de l'article 44 III de la loi n° 2011-333 du 29 mars 2011 relative au Défenseur des droits	Intérieur - Libertés publiques	2	6 ans non renouvelable; renouvelable par moitié ts les 3 ans	ANCIEN	\N	\N	Commission nationale de déontologie de la sécurité	\N	de la 	Président du Sénat	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	165
ORGEXT	166	166	\N	2006-06-08 00:00:00	\N	Décret n° 2000-663 du 13 juillet 2000 portant création de l'Observatoire de l'emploi public et décret n°2004-553 du 9 juin 2004\r\nde tabac)\r\nConsidéré comme abrogé en application des articles 17 et 18 du décret n° 2006-672 du 8 juin 2006 relatif à la création, à la composition et au fonctionnement des commissions administratives à caractère consultatif	Sécurité sociale, travail	2	Durée du mandat parlementaire	ANCIEN	\N	\N	Observatoire de l'emploi public	\N	de l'	Sénat sur proposition de la commission des finances pour un poste et Sénat sur proposition de la commission des Lois pour le deuxième poste	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	166
ORGEXT	167	167	\N	\N	\N	Article 47-1 de la loi n° 86-1067 du 30 septembre 1986 relative à la liberté de communication, créé par l'article 8 de la loi n° 2000-719 du 1er août 2000.	Communication	1	5 ans sous réserve du mandat sénatorial	ACTIF	\N	\N	Conseil d'administration de la société France Télévisions	\N	du 	Sénat sur proposition de la commission des affaires culturelles	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2017-04-04 16:19:08	LEG	NON	INDETERMINEE	NON	167
ORGEXT	168	168	\N	\N	\N	Article L. 4261-1 du code de la défense. Décret n° 2014-130 du 14 février 2014 relatif au conseil supérieur de la réserve militaire  \r\n	Défense	2	Durée du mandat parlementaire.	ACTIF	\N	\N	Conseil supérieur de la réserve militaire	\N	du 	1 titulaire et 1 suppléant désignés par le Président du Sénat	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	2017-09-13 16:38:47	REG	OUI	INDETERMINEE	NON	168
ORGEXT	267	267	\N	2017-06-20 00:00:00	\N	Articles 2 et 3 de l'arrêté du 7 juillet 2010 relatif à la composition du Conseil supérieur du travail social\r\nArt. D. 142-1 du code de l'action sociale et des familles\r\nSupprimé et remplacé par le haut conseil du travail social, crée par le décret n° 2016-905 du 1er juillet 2016 (SGG 20 juin 2017)	\N	2	mandat parlementaire	ANCIEN	\N	\N	Conseil supérieur du travail social	\N	du 	Sénat sur proposition de la commission des affaires sociales	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2017-06-20 17:57:49	REG	NON	INDETERMINEE	NON	267
ORGEXT	169	169	\N	\N	\N	Article D.133-26 et suivants du code de l'environnement (décret du 7 juillet 2000 portant création du comité de l'initiative française pour les récifs coralliens).\r\nRenouvelé pour un an par le décret n° 2015-622 du 5 juin 2015. Caduc depuis le 8 juin 2016 (SGG 20 mars 2017)\r\nLégalisé par la loi n° 2018-699 du 3 août 2018 - art. L. 213-20-1 du code de l'environnement	Environnement, logement, urbanisme	4	Durée du mandat parlementaire	ACTIF	\N	\N	Comité national de l'Initiative française pour les récifs coralliens (IFRECOR)	\N	du 	Sénat: 2 sur proposition de la commission du développement durable, 1 sur proposition de la commision des affaires culturelles et 1 sur proposition de la commission des lois	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2019-02-25 11:37:53	NEANT	NON	INDETERMINEE	NON	169
ORGEXT	94	94	\N	2010-09-07 00:00:00	\N	Article D 370-4 du code de l'aviation civile\r\nConsidéré comme abrogé par décret n° 2006-672 du 6 juin 2006 (le 07/09/2010)	Transports	2	3 ans (ou fin du mandat précédent en cas de remplacement)	ANCIEN	\N	\N	Conseil supérieur de l'aviation marchande	\N	du 	Sénat: deux candidats (un titulaire et un suppléant) proposés par la commission des affaires économiques - Au 16 juin 2008, JF Le GRAND nommé Président de cet OEP	Transports	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2017-04-10 09:35:37	NEANT	NON	INDETERMINEE	NON	94
ORGEXT	170	170	\N	2018-08-03 00:00:00	\N	Décret n° 2000-850 du 1er septembre 2000	Affaires étrangères	1	3 ans renouvelable (fin du mandat en cours si remplacement)	ACTIF	\N	\N	Commission permanente pour l'emploi et la formation professionnelle des Français de l'étranger	\N	de la 	Sénat sur proposition de la commission des affaires sociales, parmi les sénateurs représentant les Français établis hors de France	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2014-11-25 14:53:40	REG	NON	INDETERMINEE	NON	170
ORGEXT	171	171	\N	2004-07-13 00:00:00	\N	Décret n° 2000-1060 du 27 octobre 2000 relatif à la création du Haut Conseil de l'évaluation de l'école, abrogé par le Décret n° 2004-703 du 13 juillet 2004 (création du Haut conseil de l'éducation, 2 personnes nommés par Pdt du Sénat , dossier suivi par SGP)	Culture et éducation	2	3 ans, renouvelable 1 fois (fin du mandat en cours si rempl)	ANCIEN	\N	\N	Haut Conseil de l'évaluation de l'école	\N	du 	Sénat sur proposition de la commission des affaires culturelles	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	171
ORGEXT	172	172	\N	\N	\N	Article D.565-8 et suivants du code de l'environnement (Décret n° 2003-728 du 1er août 2003 portant création du conseil d'orientation pour la prévention des risques naturels majeurs).art L. 566-4 code de l'environnement\r\nnb Cet OEP a d'abord été supprimé le 22 juillet 2014 comme n'existant plus, puis rétabli par le SGG le 7/11/2014.\r\nLégalisé par la loi n° 2018-699 du 3 août 2018 - art. L. 565-3 du code de l'environnement	Environnement, logement, urbanisme	3	Durée du mandat parlementaire	ACTIF	\N	\N	Conseil d'orientation pour la prévention des risques naturels majeurs	\N	du 	Sénat (article 9 du Règlement) sur proposition des commissions des affaires culturelles, du développement durable et des lois	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	2019-02-25 18:08:01	LEG	OUI	INDETERMINEE	NON	172
ORGEXT	173	173	\N	2010-10-01 00:00:00	\N	Loi n°2001-7 du 4 janvier 2001 relative au contrôle des fonds publics accordés aux entreprises\r\nDécret n°2001-483 du 6 juin 2001 relatif à la Commission nationale et aux commissions régionales des aides publiques aux entreprises. (abrogation de la loi n° 2001-7 du 4 janvier 2001 par le deuxième collectif de 2002 : loi 2002-1576 du 30 décembre 2002)	Economie, finances	6	Durée du mandat sénatorial	ANCIEN	\N	\N	Commission nationale des aides publiques aux entreprises	\N	de la 	Sénat sur la proposition de la commission des finances pour 2 membres titulaires et 2 membres suppléants et sur la proposition de la commission des affaires économiques pour 1 membre titulaire et 1 membre suppléant	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	173
ORGEXT	199	199	\N	\N	\N	art L.1418-4 et R.1418-20 du code de la santé publique	Santé	3	3 ans - renouvelable une fois (remplacement pour la durée restant à accomplir)	ACTIF	\N	\N	Comité ad hoc chargé de donner un avis sur les autorisations de recherches sur l'embryon - \r\nConseil d'orientation de l'Agence de la biomédecine	\N	du 	Sénat sur proposition de la commission des affaires sociales	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2015-04-27 09:40:47	LEG	NON	INDETERMINEE	NON	199
ORGEXT	602	602	\N	2009-08-26 00:00:00	\N	Décret n°87-140 du 4 mars 1987 portant réforme de la commission des comptes et des budgets économiques de la nation abrogé par le décret n°99-416 du 26 mai 1999/ Décret n°99-417 du 26 mai 1999 portant création d'une conférence économique annuelle.\r\nSupprimé par le décret n° 2009-1032 du 26 août 2009	Economie, finances	2	\N	ANCIEN	\N	\N	Conférence économique annuelle (ancienne Commission des comptes et budgets économiques de la nation)	\N	de la 	Président de la commission des finances et rapporteur général du Budget membres de droit	Finances	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	602
ORGEXT	201	201	\N	\N	\N	Art. L. 614-2 et D. 614-2 du code monétaire et financier (anciennement décret n° 2004-850 du 23 août 2004 relatif au Comité consultatif de la législation et de la règlementation financières)\r\nLégalisé par la loi n° 2018-699 du 3 août 2018.	Economie, finances	1	Durée du mandat parlementaire	ACTIF	\N	\N	Comité consultatif de la législation et de la réglementation financières	\N	du 	Président du Sénat (1 titulaire)	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2019-02-25 10:21:47	LEG	NON	INDETERMINEE	NON	201
ORGEXT	203	203	\N	2018-08-03 00:00:00	\N	Décret n° 2009-1321 du 28 octobre 2009 relatif à l'Institut national des hautes études de la sécurité et de la justice remplace le décret n° 2004-750 du 27 juillet 2004 portant création de l'Institut national des hautes études de sécurité (art.21).\r\nArticles R. 123-8 et suivants du code de la sécurité intérieure	Intérieur - Libertés publiques	2	3 ans (mandat renouvelable)	ACTIF	\N	\N	Conseil d'orientation de l'Observatoire national de la délinquance et des réponses pénales	\N	du 	Président du Sénat	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2017-04-04 16:22:23	REG	NON	INDETERMINEE	NON	203
ORGEXT	200	200	\N	\N	\N	Art. L.614-1, D.614-1 et D. 614-3 du code monétaire et financier (remplace Décret n° 2004-850 du 23 août 2004 relatif au comité consultatif du secteur financier et au comité consultatif de la législation et de la règlementation financières - arrêté du 13 novembre 2007) Légalisé par la loi n° 2018-699 du 3 août 2018	Economie, finances	2	Durée du mandat parlementaire	ACTIF	\N	\N	Comité consultatif du secteur financier	\N	du 	Président du Sénat	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2019-02-25 10:56:05	LEG	OUI	INDETERMINEE	NON	200
ORGEXT	204	204	\N	\N	\N	Art 1er du décret n°2004-1134 du 22 octobre 2004 modifiant le décret n°2002-49 du 10 janvier 2002 relatif aux missions, à l'administration et au régime financier de l'Ecole nationale d'administration\r\nLégalisé par la loi n° 2018-699 du 3 août 2018 visant à garantir la présence des parlementaires dans certains organismes extérieurs (art. 39)\r\n	Justice, législation générale	1	Mandat parlementaire	ACTIF	\N	\N	Conseil d'administration de l'Ecole nationale d'administration (ENA)	\N	du 	Président du Sénat (1 titulaire)	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2019-03-15 17:28:01	LEG	NON	INDETERMINEE	NON	204
ORGEXT	609	609	\N	2015-09-28 00:00:00	\N	Autorité administrative indépendante\r\nArt L. 114-3-3 du code de la recherche (article 9 de la loi n° 2006-450 de programme pour la recherche)\r\nDécret n° 2006-1334 du 3 novembre 2006 relatif à l'organisation et au fonctionnement de l'AERES \r\nOEP supprimé avec la création de l'OEP 331.\r\nOEP supprimé avec la création de l'OEP 331\r\nLa loi n° 2013-660 du 22/07/2013 a créé un haut conseil. OEP supprimé. Voir le nouvel OEP 331	Education, recherche, enseignement	1	quatre ans renouvelable une fois, en cas de remplacement pour la fin du mandat restant à courir	ANCIEN	\N	\N	Conseil de l'Agence d'évaluation de la recherche et de l'enseignement supérieur	\N	du 	Président (après consultation du Président de l'OPECST)	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2015-09-28 18:32:56	NEANT	NON	INDETERMINEE	NON	609
ORGEXT	293	293	2012-04-11 00:00:00	2013-04-10 00:00:00	\N	Art. 2 du décret n° 2012-45 du 13 janvier 2012 portant création de la Conférence nationale du sport\r\nArticle D 142-40 du code des sports  \r\n  \r\n	\N	2	trois ans renouvelable	ANCIEN	\N	\N	Conférence nationale du sport	\N	de la 	un titulaire et un suppléant désigné par le Président (dans le décret référence à la parité homme/femme)	\N	\N	\N	\N	OUI	DECRET	NEANT	\N	\N	2017-04-04 17:01:44	NEANT	NON	INDETERMINEE	NON	293
ORGEXT	294	294	2012-02-17 00:00:00	2014-02-17 00:00:00	\N	Décret n° 2012-253 du 21 février 2012 relatif au Conseil supérieur des transports terrestres et de\r\n l'intermodalité\r\nOrganisme supprimé par le décret n° 2014-132 du 17 février 2014	\N	2	mandat parlementaire 	ANCIEN	\N	\N	Conseil supérieur des transports terrestres et de l'intermodalité	\N	du 	Sénat sur proposition de la commission du développement durable	\N	\N	\N	\N	OUI	DECRET	NEANT	\N	\N	2014-10-06 17:12:09	NEANT	NON	INDETERMINEE	NON	294
ORGEXT	296	296	2012-07-10 00:00:00	\N	\N	Décret n° 2012-428 du 29 mars 2012 \r\narticle D. 114-0-2 du code de la sécurité sociale\r\nLégalisé par la loi n° 2018-699 du 3 août 2018 - art. L. 114-1-A du code de la sécurité sociale	\N	2	Mandat parlementaire	ACTIF	\N	\N	Haut conseil du financement de la protection sociale	\N	du 	Président du Sénat	\N	\N	\N	\N	OUI	LOI	NEANT	\N	\N	2019-02-26 15:20:03	LEG	OUI	INDETERMINEE	NON	296
ORGEXT	300	300	2012-07-26 00:00:00	\N	\N	Art. L. 112-1 du code du cinéma et de l'image animée\r\nDécret n° 2006-672 du 8 juin 2006	\N	1	mandat parlementaire	ACTIF	\N	\N	Centre national du cinéma et de l'image animée	\N	du	commission de la culture	\N	\N	\N	\N	OUI	DECRET	ALERTE	\N	\N	2018-03-20 10:03:45	LEG	NON	INDETERMINEE	NON	300
ORGEXT	610	610	\N	\N	\N	Articles L. 531-4-1 et R. 531-12 du code de l'environnement 	Recherche, sciences et techniques	1	5 ans, renouvelable (remplacement pour la durée du mandat restant à courir) et sous réserve du mandat parlementaire	ACTIF	\N	\N	Comité économique, éthique et social du Haut conseil des biotechnologies	\N	du 	1 titulaire et 1 suppléant désignés par le Président de l'Office parlementaire des choix scientifiques et technologiques	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2017-11-07 18:15:53	LEG	NON	INDETERMINEE	NON	610
ORGEXT	282	282	\N	\N	\N	Art. L. 219-1 A du code de l'environnement Article 3 du décret n° 2011-637 du 9 juin 2011 et décret n° 2015-1361 du 27 octobre 2015 article 3NB Mme CLAIREAUX présidente 12/2014	\N	4	6 ans renouvelable une fois + exercice du mandat + fin du mandat si remplacement	ACTIF	\N	\N	Conseil national de la mer et des littoraux	\N	du 	2 tit (dont un représentant l'outre-mer)	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	2017-09-13 17:41:17	LEG	OUI	INDETERMINEE	NON	282
ORGEXT	284	284	\N	2017-06-20 00:00:00	\N	Décret n° 2011-738 du 28 juin 2011 \r\nArt. D. 371-3 du code de l'environnement\r\nArt. L. 371-2 du code de l'environnement\r\nSupprimé par le décret n° 2017-339 du 15 mars 2017 relatif au comité national de la biodiversité (SGG 20 juin 2017)	\N	1	fin du mandat	ANCIEN	\N	\N	Comité national des "trames verte et bleue"	\N	du 	Sénat sur proposition de la commission du développement durable	\N	\N	\N	\N	OUI	DECRET	NEANT	\N	\N	2017-06-20 17:43:41	REG	NON	INDETERMINEE	NON	284
ORGEXT	287	287	2011-12-15 00:00:00	2018-08-02 00:00:00	\N	Art. 51 de la loi n° 2010-874 du 27 juillet 2010 de modernisation de l'agriculture et de la pêche créant cet organisme dans le cadre de l'article L. 112-1 du code rural et de la pêche maritime\r\nArt. D. 112-1-13 du code rural et de la pêche maritime\r\n\r\nDécret n° 2006-672 du 8 juin 2006 (cinq ans sauf prolongation)\r\n	\N	1	cinq ans renouvelable, nomination par arrêté du ministre chargé de l'agriculture 	ACTIF	\N	\N	Observatoire national de la consommation des espaces agricoles	\N	de l'	Président du Sénat	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	2017-04-04 16:32:37	LEG	NON	INDETERMINEE	NON	287
ORGEXT	219	219	\N	2011-06-09 00:00:00	\N	Art. 43 de la loi n° 86-2 du 3 janvier 1986 relative à l'aménagement, la protection et la mise en valeur du littoral\r\nDécret n° 2005-1426 du 18 novembre 2005 relatif à la composition et au fonctionnement du Conseil national du littoral, abrogé par l'article 13 du décret n° 2011-637 du 9 juin 2011 créant le Conseil national de la mer et des littoraux (282)	Environnement, logement, urbanisme	3	3 ans (remplacement pour la durée du mandat restant à courir)	ANCIEN	\N	\N	Conseil national du littoral	\N	du 	Par le Président du Sénat	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	219
ORGEXT	288	288	2012-01-18 00:00:00	\N	\N	Article 8 de la loi n° 2010-597 du 3 juin 2010 relative au Grand Paris ; Décret en Conseil d'État n° 2010-756 du 7 juillet 2010 relatif à la société du Grand Paris (art.21)	\N	2	durée du mandat parlementaire	ACTIF	\N	\N	Comité stratégique de la Société du Grand Paris	\N	du 	Président du  Sénat	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	2017-04-04 16:33:29	LEG	NON	INDETERMINEE	NON	288
ORGEXT	289	289	2012-01-18 00:00:00	2018-09-12 00:00:00	\N	Décret n° 2011-834 du 12 juillet 2011 portant création du Conseil du service militaire adapté\r\nDécret n° 2006-672 du 8 juin 2006 sur les commissions administratives paritaires (5 ans)\r\nSupprimé par le décret n° 2018-785 du 12 septembre 2018	\N	1	trois ans -  mandat renouvelable	ANCIEN	\N	\N	Conseil du service militaire adapté	\N	du 	Président du Sénat	\N	\N	\N	\N	OUI	DECRET	NEANT	\N	\N	2018-09-21 17:39:14	REG	OUI	INDETERMINEE	NON	289
ORGEXT	149	149	\N	2011-12-31 00:00:00	\N	Art. L.228-1 et R.228-2 du code de la sécurité sociale.\r\n\r\nAbrogé par la loi n° 2011-1906 du 21 décembre 2011 de financement de la sécurité sociale  (art. 110)	Sécurité sociale, travail	3	5 ans	ANCIEN	\N	\N	Conseil de surveillance de la Caisse nationale des allocations familiales	\N	du 	Président du Sénat	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	149
ORGEXT	78	78	\N	\N	\N	Article 35 de la loi n° 93-122 du 29-1-93 relative à la prévention de la corruption et à la transparence de la vie écon. et des procédures publiques/Décret n°93-306 du 9-3-93 rel. à l'autorisation d'implantation de certains magasins de commerce de détail	Environnement, logement, urbanisme	1	Trois ans non renouvelable	ANCIEN	\N	\N	Commisssion nationale d'équipement commercial (remplacée par l'Etablissement public national d'aménagement et de restructuration des espaces commerciaux et artisanaux en 1997) 	\N	de la 	Président du Sénat	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	78
ORGEXT	10034	-1	2017-10-13 00:00:00	\N	\N	Art. 13 C	\N	0	\N	ACTIF	\N	\N	Haute autorité de santé	\N	de la 	Avis commission des affaires sociales	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	\N	LEG	NON	AUT_ADMIN_INDEP	NON	\N
ORGEXT	97	97	\N	2018-08-02 00:00:00	\N	Décret n°85-1392 du 27 déc. 1985 portant création dans la commune de Fresnes d'un établissement d'hospitalisation public spécifiquement destiné à l'accueil des personnes incarcérées./Décret n°95-236 du 2 mars 1995 (accueil des détenus)\r\nR. 6147-73 du code de la sécurité sociale (cf décret n° 2007-1555 du 30/10/2007)	Justice, législation générale	2	Fin du mandat sénatorial	ACTIF	\N	\N	Conseil d'administration de l'Etablissement public de santé national de Fresnes spécifiquement destiné à l'accueil des personnes incarcérées	\N	du 	Deux sénateurs (un titulaire et un suppléant) désignés par le Sénat sur proposition de  la commission des affaires sociales	Affaires sociales	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2015-01-06 14:41:15	REG	NON	INDETERMINEE	NON	97
ORGEXT	108	108	\N	\N	\N	Articles L 232-1, D.232-5 et D. 232-6 du code de l'éducation	Culture et éducation	2	4 ans (renouvelable une seule fois - remplacement pour la durée du mandat restant à accomplir)	ACTIF	\N	\N	Conseil national de l'enseignement supérieur et de la recherche	\N	du 	Sénat: un candidat titulaire désigné par la commission des affaires culturelles (généralement le rapporteur pour avis) et un candidat suppléant désigné par la commission des finances (généralement le rapporteur spécial)\r\nNB Mme GILLOT et M ADNOT jusqu'au 30 mai 2015 (indication du SGG du 14/1/2015).	Education	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	2019-02-25 18:30:59	LEG	OUI	INDETERMINEE	NON	108
ORGEXT	112	112	\N	\N	\N	Article L. 125 et article D. 571 du code des postes et des communications électroniques (loi n° 2004-669 du 9 juillet 2004)\r\n(ancienne commission supérieure du service public des postes et des communications électroniques)	Poste et télécommunications - Nouvelles technologies	7	Après chaque renouvellement triennal	ACTIF	\N	\N	Commission supérieure du numérique et des postes	\N	de la 	Président du Sénat depuis la loi n° 2018-699 du 3 août 2018 - AUPARAVANT Sénat: deux candidatures proposées par la commission des affaires économiques, deux candidatures proposées par la commission du développement durable, deux candidatures proposées par la commission des finances et une candidature proposée par la commission de la culture	POSTES ET TELECOMMUNICATIONS	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2018-09-21 10:17:54	LEG	OUI	INDETERMINEE	NON	112
ORGEXT	130	130	\N	\N	\N	Loi n° 93-1313 du 20 décembre 1993/Décret rel. aux modalités de fonctionnement de la commission d'évaluation prévue par la loi quinquennale sur l'emploi n° 94-572 du 11 juillet 1994/Loi n° 95-116 du 04-021995:art.101 portant à 3 le nombre de représentants	Sécurité sociale, travail	3	Rapport à remettre le 30-06-1996	ANCIEN	\N	\N	Commission chargée de contribuer à l'élaboration du rapport d'évaluation de la loi quinquennale n°93-1313 du 20 décembre 1993 relative au travail, à l'emploi et à la formation professionnelle (caduc au 30-06-1996)	\N	de la 	Sénat sur proposition de la commission des affaires sociales	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	130
ORGEXT	142	142	\N	\N	\N	Arrêté du 25 octobre 1995 portant création de la commission d'étude de l'indexation des pensions militaires d'invalidité.\r\n (caduc au 30-06-1996)	Anciens combattants et victimes de guerre	2	30 juin 1996	ANCIEN	\N	\N	Commission d'étude de l'indexation des pensions militaires d'invalidité	\N	de la 	Président du Sénat (deux titulaires et deux suppléants)	ANCIENS COMBATTANTS	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	142
ORGEXT	154	154	\N	\N	\N	Décret n° 97-134 du 12 février 1997 instituant une commission du suivi du mémorandum signé le 26 novembre 1996.\r\nConsidéré comme abrogé par décret n° 2006-672 du 8 juin 2006  (le 07/09/2010)	Economie, finances	2	Fin du mandat sénatorial	ANCIEN	\N	\N	Commission du suivi du mémorandum d'accord signé le 26 novembre 1996 entre la France et la Fédération de Russie	\N	de la 	Président du Sénat (un titulaire et un suppléant)	Economie	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	154
ORGEXT	266	266	\N	2014-02-17 00:00:00	\N	Article 49 de la loi n° 2010-737 du 1er juillet 2010 portant réforme du crédit à la consommation\r\nArticle 3 du décret n° 2010-827 du 20 juillet 2010\r\nSupprimé par le décret n° 2014-132 du 17 février 2014  \r\n	\N	1	car liée à la parution du rapport au Plt sur la création de ce registre dans un délia d1 an ( non remis au 20/09/2011)	ANCIEN	\N	\N	Comité chargé de préfigurer la création d'un registre national des crédits aux particuliers	\N	du 	Président du Sénat\r\n	\N	\N	\N	\N	OUI	LOI	NEANT	\N	\N	2016-01-25 18:07:46	NEANT	NON	INDETERMINEE	NON	266
ORGEXT	32	32	\N	2018-08-01 00:00:00	\N	Décret n°92-758 du 4 août 1992 portant réforme du Fonds d'investissement pour le développement économique et social des départements d'outre-mer\r\n\r\nSupprimé par le décret n° 2004-863 du 24 août 2004	Départements et territoires d'outre-mer	4	Fin du mandat sénatorial	ANCIEN	\N	\N	Comité directeur du fonds d'investissement pour le développement économique et social des territoires d'outre-mer (FIDES)	\N	du 	Président du Sénat	Departements et territoires d'outre-mer (DOM TOM)	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	32
ORGEXT	67	67	\N	\N	\N	Art. L. 114-1 du code de la sécurité sociale Décret n°79-237 du 22 mars 1979. Décret n°87-441 du 23 Juin 1987- Article Premier (Art. D 114-1 Code de la sécurité sociale)/Décret n°93-1295 du 10 décembre 1993 et décret n°94-305 du 14 avril 1994 modifiantl'article D. 114-1 du code de la sécurité sociale	Sécurité sociale, travail	4	Fin du mandat sénatorial	ACTIF	\N	\N	Commission des comptes de la sécurité sociale	\N	de la 	Président du Sénat (après avis de la commission des affaires sociales pour deux nominations et de la commission des finances pour les deux autres nominations)	Sante	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2017-09-13 16:54:24	LEG	OUI	INDETERMINEE	NON	67
ORGEXT	159	159	\N	2010-09-07 00:00:00	\N	Décret n°99-221 du 19 mars 1999 relatif au Conseil supérieur du service public ferroviaire et décret n°2003-374 du 15 avril 2003\r\nConsidéré comme abrogé par décret n° 2006-672 du 8 juin 2006  (le 07/09/2010)	Transports	3	3 ans (remplacement pour la durée du mandat restant à courir)	ANCIEN	\N	\N	Conseil supérieur du service public ferroviaire	\N	du 	Président du Sénat	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	159
ORGEXT	161	161	\N	\N	\N	Article 14 de la loi n° 91-1381 du 30 décembre 1991 relative aux recherches sur la gestion des déchets radioactifs  articles L.542-13 et R. 542-25 du code de l'environnement	Energie	2	Fin du mandat sénatorial.	ACTIF	\N	\N	Comité local d'information et de suivi du laboratoire souterrain de Bure	\N	du 	Sénat sur proposition de la commission des affaires économiques et de la commission du développement durable	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2015-03-05 14:02:55	LEG	NON	INDETERMINEE	NON	161
ORGEXT	302	302	2012-10-30 00:00:00	2014-12-11 00:00:00	\N	Art. 5 de la loi n° 2012-348 du 12 mars 2012 tendant à faciliter l'organisation des manifestations sportives et culturelles\r\nArt. 1 er de l'arrêté du 13 septembre 2012 relatif à la composition du Comité de préfiguration des modalités d'instauration du profil biologique des sportifs OEP supprimlé après rapport en 2013 Source: SGG 11/12/2014	\N	1	en principe doit disparaître après le rendu du rapport devant intervenir avant le 12 mars 2013	ANCIEN	\N	\N	Comité de préfiguration des modalités d'instauration du profil biologique des sportifs	\N	du	Sénat sur proposition de la commission de la culture	\N	\N	\N	\N	OUI	LOI	NEANT	\N	\N	2017-04-04 17:02:41	NEANT	NON	INDETERMINEE	NON	302
ORGEXT	162	162	\N	2020-12-14 00:00:00	\N	Article L. 862-1 du code de la sécurité sociale (Article 27 de la loi n° 99-641 du 27 juillet 1999 portant création d'une couverture maladie universelle)/ Article R. 862-6 du code de la Sécurité sociale (Article 4 du décret n° 99-1028 du 9 décembre 1999). - Supprimé par loi n° 2020-1576 du 14 décembre 2020 de financement de la sécurité sociale pour 2021	Sécurité sociale, travail	3	5 ans renouvelable	ACTIF	\N	\N	Conseil de surveillance du Fonds de financement de la protection complémentaire de la couverture universelle du risque maladie	\N	du 	Sénat sur proposition de la commission des affaires sociales pour 2 membres et de la commission des finances pour 1 membre	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2017-04-04 16:18:48	LEG	NON	INDETERMINEE	NON	162
ORGEXT	252	252	\N	2014-02-17 00:00:00	\N	Décret n° 2009-720 du 17 janvier 2009 relatif à la Commission du programme national de requalification des quartiers anciens dégradés (art.2)\r\nDécret n°2006-672 du 8 juin 2006 durée de cinq ans sauf prolongation fixée par un autre décret\r\nOrganisme supprimé par le décret n° 2014-132 du 17 février 2014	\N	1	durée du mandat + durée de la commission 	ANCIEN	\N	\N	Commission du programme national de requalification des quartiers anciens dégradés\r\nSupprimé par le décret n° 2014-132 du 17 février 2014 	\N	de la 	par le Sénat (sur proposition de la commission des affaires économiques)	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2014-11-14 15:30:29	NEANT	NON	INDETERMINEE	NON	252
ORGEXT	260	260	\N	2013-04-11 00:00:00	\N	Article 35 de la loi n° 2009-879 du 21 juillet 2009 portant réforme de l'hôpital et relative aux patients, à la santé et aux territoires\r\nDécret n° 2010-114 du 3 février 2010 relatif au Comité d'évaluation de la mise en oeuvre des dispositions relatives à la modernisation des établissements de santé de la loi portant réforme de l'hôpital et relative aux patients, à la santé et aux territoires	\N	1	fin du mandat sénatorial	ANCIEN	\N	\N	Comité d'évaluation de la mise en oeuvre des dispositions relatives à la modernisation des établissements de santé de la loi portant réforme de l'hôpital et relative aux patients, à la santé et aux territoires	\N	du 	Président du Sénat (dans le silence du texte)\r\nSupprimé par annonce en avril 2013 (simplification administrative)	\N	\N	\N	\N	OUI	LOI	NEANT	\N	\N	2013-10-03 17:11:05	NEANT	NON	INDETERMINEE	NON	260
ORGEXT	264	264	\N	\N	\N	Article L. 120-2 du code du service national, qui renvoie à la convention constitutive pour les précisions sur la composition du comité stratégique.	\N	2	trois ans, sous réserve du mandat parlementaire.	ACTIF	\N	\N	Comité stratégique de l'Agence du service civique	\N	du 	Président du Sénat\r\nil existe aussi un comité de suivi de la loi comportant deux sénateurs, nommés par le Président du Sénat	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2017-04-04 16:27:52	LEG	NON	INDETERMINEE	NON	264
ORGEXT	273	273	\N	\N	\N	Article 9 de la loi n° 2010-873 du 27 juillet 2010 relative à l'action extérieure de la France Article 6 du décret n° 2010-1695 du 30 décembre 2010 relatif à l'Institut français	\N	2	trois ans renouvelables une fois et prend fin de plein droit à l'expiration du mandat électif	ACTIF	\N	\N	Conseil d'administration de l'Institut français	\N	du 	par la commission des affaires étrangères	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	2014-10-06 17:06:07	LEG	NON	INDETERMINEE	NON	273
ORGEXT	274	274	\N	\N	\N	Loi n° 2010-873 du 27 juillet 2010 relative à l'action extérieure de la France \r\nArticle 5 du décret n° 2010-1695 du 30 décembre 2010 relatif à l'Institut français	\N	1	trois ans renouvelables. Prend fin de plein droit à l'expiration du mandat électif	ACTIF	\N	\N	Conseil d'orientation stratégique de l'Institut français	\N	du 	Sénat, sur proposition de la commission de la culture	\N	\N	\N	\N	OUI	LOI	NEANT	\N	\N	2015-03-19 10:00:48	LEG	NON	INDETERMINEE	NON	274
ORGEXT	275	275	\N	2016-11-03 00:00:00	\N	Article 3 de la loi n° 2010-476 du 12 mai 2010\r\nArticles 3 et 10 du décret n° 2011-252 du 9 mars 2011 relatif au comité consultatif des jeux (1)\r\nPlus de parlementaires dans ces instances depuis le décret n° 2016-1488 du 3 novembre 2016\r\nNotification du SGG le 14 mars 2017\r\n+ commission consultative des jeux de cercles et de casinos (2) \r\net commission consultative des jeux et paris sous droits exclusifs	\N	3	durée du mandat parlementaire	ANCIEN	\N	\N	Collège du comité consultatif des jeux et commission consultative des jeux de cercle et de casinos	\N	du 	Président	\N	\N	\N	\N	OUI	LOI	NEANT	\N	\N	2017-03-15 16:47:20	NEANT	NON	INDETERMINEE	NON	275
ORGEXT	272	272	\N	\N	\N	Article 7 de la loi n° 2010-2 du 5 janvier 2010 relative à la reconnaissance et à l'indemnisation des victimes des essais nucléaires français et décret n° 2010-653 du 11 juin 2010	\N	2	Durée du mandat parlementaire	ACTIF	\N	\N	Commission consultative de suivi des conséquences des essais nucléaires 	\N	de la 	Sénat proposition de la commission des affaires étrangères et de la défense (1 titulaire) et sur la proposition de la commission des affaires sociales (1 titulaire)	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	2017-09-13 16:53:57	LEG	OUI	INDETERMINEE	NON	272
ORGEXT	195	195	\N	2011-05-17 00:00:00	\N	Art 1er loi n° 2003-591 du 2 juillet 2003 habilitant le Gouvernement à simplifier le droit et décret n° 2003-1099 du 20 novembre 2003 portant création d'un conseil d'orientation de la simplification administrative\r\nAbrogé par le 4° de l'article 67 de la loi n° 2011-525 du 17 mai 2011 de simplification et d'amélioration de la qualité du droit et Décret n° 2011-1073 du 8 septembre 2011	Intérieur - Libertés publiques	6	5 ans, remplacés pour la durée restant à courir (si + de 6m)	ANCIEN	\N	\N	Conseil d'orientation de la simplification administrative	\N	du 	3 titulaires et 3 suppléants, nommés par le Président du Sénat	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	195
ORGEXT	261	261	\N	\N	\N	Article D.370-4 du code de l'aviation civile codifiant le décret n° 2010-248 du 10 mars 2010 portant création du Conseil supérieur de l'aviation civile\r\nLégalisé par la loi n° 2018-699 du 3 août 2018 - art. L. 6441-1 du code des transports	\N	1	Mandat parlementaire	ACTIF	\N	\N	Conseil supérieur de l'aviation civile	\N	du 	un sénateur désigné par le Sénat sur proposition de la commission de l'aménagement du territoire et du développement durable	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2019-02-26 11:10:00	LEG	OUI	INDETERMINEE	NON	261
ORGEXT	250	250	\N	\N	\N	Art. 47-3 de la loi n° 86-1067 du 30 septembre 1986 relative à la liberté de communication ( tel que résultant de l'article 12 de la loi n° 2009-258 du 5 mars 2009)	\N	1	5 ans	ACTIF	\N	\N	Conseil d'administration de la société en charge de l'audiovisuel extérieur de la France	\N	du 	par la commission chargée des affaires culturelles\r\nDémission Mme LEPAGE 18/03/2015	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2015-05-15 14:18:26	LEG	NON	INDETERMINEE	NON	250
ORGEXT	295	295	2012-02-14 00:00:00	\N	\N	Décret n° 2012-211 du 14 février 2011 et n° 2012-216 du 15 février 2012\r\nLégalisé par la loi n° 2018-699 du 3 août 2018 - art. L. 1111-7 du code des transports	\N	2	mandat parlementaire	ACTIF	\N	\N	Haut comité de la qualité du service dans les transports	\N	du 	Sénat sur proposition de la commission du développement  durable	\N	\N	\N	\N	OUI	DECRET	NEANT	\N	\N	2019-02-26 14:55:43	LEG	OUI	INDETERMINEE	NON	295
ORGEXT	2006	-1	\N	\N	\N	Art. L. 124-1 du code de la recherche	\N	0	\N	ACTIF	\N	\N	Conseil national de la culture scientifique, technique et industrielle	\N	du 	\N	\N	\N	\N	\N	\N	NEANT	ALERTE	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	\N
ORGEXT	253	253	\N	2014-11-04 00:00:00	\N	Article 20 de la loi n° 2006-739 du 28/06/2006\r\nart L. 594-11 et 594-12 du code de l'environnement\r\nprésident de la commission chargée de l'énergie ou présient de la commission des finances	\N	1	Durée des fonctions comme président de la commission au Sénat	ANCIEN	\N	\N	Commission nationale d'évaluation du financement des charges de démantèlement des installations nucléaires de base et de gestion des combustibles usés et déchets radioactifs	\N	de la 	Président du Sénat (qui effectue lechoix).\r\nLa caducité de cet OEP a été constatée par le SGG le 4 novembre 2014.	\N	\N	\N	\N	OUI	LOI	NEANT	\N	\N	2015-10-09 11:54:20	NEANT	NON	INDETERMINEE	NON	253
ORGEXT	249	249	\N	2018-09-12 00:00:00	\N	Décret n° 2009-495 du 30 avril 2009 instituant le comité chargé de suivre la mise en oeuvre du titre IV de la loi n° 2009-258  du 5 mars 2009 relative à la communication audiovisuelle et au nouveau service public de la télévision\r\nTitre IV de la loi n°  2009-258  du 5 mars 2009 relative à la communication audiovisuelle et au nouveau service public de la télévision (art.74)	\N	2	durée du mandat	ANCIEN	\N	\N	Comité de suivi de la mise en oeuvre des dispositions du titre IV de la loi du 5 mars 2009 relatives au cinéma et autres arts et industries de l'image animée	\N	du 	un titulaire et un suppléant désignés par la commission chargée des affaires culturelles	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2018-09-21 18:01:48	REG	NON	INDETERMINEE	NON	249
ORGEXT	268	268	\N	2015-06-24 00:00:00	\N	Décret n° 2006-826 du 10 juillet 2006 (articles3 et 4)\r\nL'article 7 du décret n°2015-732 du 24 juin 2015 relatif au Conseil supérieur de l'économie sociale et solidaire a abrogé le décret n° 2006-826 du 10 juillet 2006.	\N	2	3 ans mandat renouvelable une fois	ANCIEN	\N	\N	Conseil supérieur de l'économie sociale et solidaire	\N	du 	1 titulaire et 1 suppléant désignés par le Sénat sur proposition de la commission des affaires économiques	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2017-04-04 17:00:58	NEANT	NON	INDETERMINEE	NON	268
ORGEXT	271	271	\N	2017-03-28 00:00:00	\N	Article 2 de l'arrêté du 10 septembre 2010 portant création d'un Comité stratégique et d'un secrétariat permanent pour l'élaboration de la stratégie nationale de la recherche énergétique((non publiéau JORF, BO du MEEDDM du 10 octobre 2010, http://www.bulletinofficiel.developpement-durable.gouv.fr/fiches/BO201018/bo201018.pdf) \r\nNouvel arrêté du 21 décembre 2016 ne mentionne plus cet OEP - Notification du SGG le 28 mars 2017	\N	1	5 ans	ANCIEN	\N	\N	Comité stratégique pour l'élaboration et le suivi de la stratégie nationale de la recherche énergétique	\N	du 	Sénat sur proposition de la commission des affaires économiques	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2017-03-29 09:57:56	NEANT	NON	INDETERMINEE	NON	271
ORGEXT	276	276	\N	2020-12-07 00:00:00	\N	Articles L. 115-1 et L. 115-2 du code du patrimoineDécret n° 2011-160 du 8 février 2011 relatif à la Commission scientifique nationale des collections - Supprimé loi ASAP n° 2020-1525 du 7 décembre 2020	\N	1	durée du mandat parlementaire	ACTIF	\N	\N	Commission scientifique nationale des collections	\N	de la 	Président du Sénat	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	2017-09-13 15:15:39	LEG	OUI	INDETERMINEE	NON	276
ORGEXT	256	256	\N	2014-11-04 00:00:00	\N	Décret n° 2009-1112 du 11 septembre 2009 relatif à la composition du comité d'évaluation de l'impact du revenu de solidarité active.\r\nLa cadicité de cet OEP a été constatée par le SGG le 4 novembre 2014.	\N	1	trois ans ( délai au terme duquel doit se réunir la Conférence nationale chargée d'évaluer le RSA)	ANCIEN	\N	\N	Comité d'évaluation de l'impact du revenu de solidarité active (RSA)	\N	du 	par le Sénat sur proposition de la commission des affaires sociales	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2015-10-09 11:54:41	NEANT	NON	INDETERMINEE	NON	256
ORGEXT	263	263	\N	2014-02-17 00:00:00	\N	Article D. 134-3 du code de l'environnement\r\nOrganisme supprimé par le décret n° 2014-132 du 17 février 2014	\N	1	durée du mandat parlementaire	ANCIEN	\N	\N	Comité national du développement durable et du Grenelle de l'environnement 	\N	du 	Sénat (sur proposition de la commission du développement durable)\r\nnb: Aff éco a proposé M. Paul Raoult comme suppléant "non officiel"	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2014-10-06 17:01:13	NEANT	NON	INDETERMINEE	NON	263
ORGEXT	269	269	\N	2020-12-07 00:00:00	\N	Décret n° 99-706 du 3 août 1999 modifié par le décret n° 2010-1106 du 21 septembre 2010Légalisé par la loi n° 2018-699 du 3 août 2018 - art. 37 - Supprimé loi ASAP n° 2020-1525 du 7 décembre 2020	\N	1	durée du mandat parlementaire	ACTIF	\N	\N	Conseil national de l'aide aux victimes	\N	du 	Président du Sénat	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	2019-02-25 18:24:34	LEG	OUI	INDETERMINEE	NON	269
ORGEXT	270	270	\N	2020-12-07 00:00:00	\N	Loi n° 2009-594 du 27 mai 2009 Article 74Décret n° 2010-1048 du 1er septembre 2010 relatif à la Commission nationale d'évaluation des politiques de l'État outre-mer - Supprimé loi ASAP n° 2020-1525 du 7 décembre 2020	\N	20	cf. article 2 du décret n° 2010-1048 du 1er septembre 2010 (31/10 de l'année de remise du rapport biennal)	ACTIF	\N	\N	Commission nationale d'évaluation des politiques de l'État outre-mer	\N	de la 	10 titulaires et 10 suppléants : deux titulaires et deux suppléants proposés  par les commissions des affaires sociales, des finances et des lois; un titulaire et un suppléant proposés par les commissions des affaires économiques, du développement durable, de la culture et des affaires européennes	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2017-12-27 09:32:39	LEG	OUI	INDETERMINEE	NON	270
ORGEXT	98	98	\N	2018-09-12 00:00:00	\N	Articles D.122-5 et suivants du code du tourisme\r\nCommission prorogée de cinq ans par décret n° 2009-623 du 6 juin 2009 sauf nouvelle décision devrait disparaître en juin 2014\r\nRenouvelé pour cinq ans par le décret n° 2015-593 du 1er juin 2015	Jeunesse, sports, tourisme, vie associative	5	5 ans, sous réserve du mandat parlementaire	ANCIEN	\N	\N	Conseil national du tourisme	\N	du 	Par le Président du Sénat - (en cas de remplacement, le remplaçant est nommé dans les mêmes conditions et  pour la durée du mandat restant à courir)	Tourisme	\N	\N	\N	OUI	NEANT	NEANT	2015-06-01 00:00:00	\N	2018-09-21 17:38:14	REG	OUI	INDETERMINEE	NON	98
ORGEXT	254	254	\N	2016-03-18 00:00:00	\N	Décret n° 2009-300 du 17 mars 2009 portant création du service des achats de l'État (première demande de désignation le 23/11/2009). Supprimé en mars 2016.	\N	1	sénateur  pour un mandat de cinq ans renouvelable	ANCIEN	\N	\N	Conseil d'orientation du service des achats de l'État	\N	du 	Sénat sur proposition de la commission des finances, puis arrêté du ministre chargé du budget	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2016-03-18 16:34:51	NEANT	NON	INDETERMINEE	NON	254
ORGEXT	91	91	\N	\N	\N	Ancien Conseil d'administration de la Cité des sciences et de l'industrie régi par le décret n° 2006-222 du 24 février 2006 relatif au statut de la Cité des sciences et de l'industrie \r\nabrogé par l'article 30 du décret n° 2009-1491 du 3 décembre 2009 portant création de l'Etablissement public du palais de la Découverte et de la Cité des sciences et de l'industrie \r\nArticles 6 et 7 du décret n° 2009-1491 du 3 décembre 2009 précité\r\n	Culture et éducation	1	Durée du mandat sénatorial (5 ans jusqu'en 2006)	ANCIEN	\N	\N	Conseil d'administration de l'établissement public du Palais de la Découverte et de la Cité des sciences et de l'industrie	\N	du 	Sénat sur proposition de la commission des affaires économiques	Economie	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	91
ORGEXT	102	102	\N	\N	\N	Article 47-2 de la loi n°86-1067 du 30 septembre 1986 relative à la liberté de communication, article 8 de la loi n° 2000-719 du 1er août 2000, article 93 de la loi n°2004-669 du 9 juillet 2004 relative aux communications électroniques\r\nSupprimé par l'article 10 de la loi n° 2009-258 du 5 mars 2009 relative à la communication audiovisuelle et au nouveau service public de la télévision 	Communication	1	5 ans	ANCIEN	\N	\N	Conseil d'administration de la société Réseau France Outre-mer	\N	du 	Sénat sur proposition de la commission des affaires culturelles	Communication	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	102
ORGEXT	309	309	\N	\N	\N	Un titulaire\r\nDécret n° 2013-353 du 25 avril 2013 article 3\r\nLégalisé par la loi n° 2018-699 du 3 août 2018 (art. 36)	\N	1	mandat parlementaire	ACTIF	\N	\N	Conseil national des professions du spectacle	\N	du	Président du Sénat	\N	\N	\N	\N	OUI	LOI	NEANT	\N	2013-06-21 15:28:02	2019-02-26 10:08:58	LEG	OUI	INDETERMINEE	NON	309
ORGEXT	310	310	\N	\N	\N	Légalisé par la loi du 3 août 2018 (art. 40)	\N	2	mandat parlementaire	ACTIF	\N	\N	Conseil consultatif des terres australes et antarctiques françaises	\N	du	Président du Sénat	\N	\N	\N	\N	OUI	LOI	NEANT	\N	2013-06-27 10:20:39	2015-02-17 17:48:01	LEG	NON	INDETERMINEE	NON	310
ORGEXT	311	311	2013-07-11 00:00:00	2018-09-12 00:00:00	\N	Article L. 3211-7 (résultant de la loi n° 2013-61 du 18 janvier 2013) et articles R. 3211-17-5 et R. 3211-17-6 du code général de la propriété des personnes publiques	\N	4	mandat parlementaire	ANCIEN	\N	\N	Commission nationale de l'aménagement, de l'urbanisme et du foncier	\N	de la	Deux sénateurs titulaires\r\nDeux sénateurs suppléants	\N	\N	\N	\N	OUI	LOI	NEANT	\N	2013-07-11 14:43:45	2018-09-21 17:56:03	LEG	OUI	INDETERMINEE	NON	311
ORGEXT	312	312	2013-07-23 00:00:00	2020-12-07 00:00:00	\N	décret n° 2013-666 du 23 juillet 2013Légalisé par la loi n° 2018-699 du 3 août 2018 (art. 28) - Supprimé loi ASAP n° 2020-1525 du 7 décembre 2020	\N	2	non précisée par le décret mandat parlemntaire	ACTIF	\N	\N	Commission nationale des services	\N	de la 	président du Sénat (un titulaire, un suppléant)	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2013-07-29 15:14:39	2019-02-25 12:06:14	LEG	OUI	INDETERMINEE	NON	312
ORGEXT	313	313	\N	\N	\N	articles L. 231-14 et D. 231-34 du code de l'éducation	\N	3	5 ans sous réserve du mandat parlementaire	ACTIF	\N	\N	Conseil supérieur des programmes	\N	du 	Commission de la culture, de l'éducation et de la communication. Incompatibilité avec le conseil d'évaluation de l'école.	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2013-08-26 15:04:05	2017-09-13 17:30:05	LEG	OUI	INDETERMINEE	NON	313
ORGEXT	314	314	\N	\N	\N	Article L. 133-2 du code de l'environnement + Art. D. 134-3 du code de l'environnement	\N	3	Trois ans	ACTIF	\N	\N	Conseil national de la transition écologique	\N	du 	Par le Président du Sénat\r\nTrois sénateurs titulaires et trois sénateurs suppléants.	\N	\N	\N	\N	OUI	DECRET	ALERTE	\N	2013-08-26 15:07:42	2018-12-19 15:02:08	LEG	OUI	INDETERMINEE	NON	314
ORGEXT	308	308	2013-04-04 00:00:00	2018-08-02 00:00:00	\N	décret n° 2013-289 du 4 avril 2013\r\narticle R. 142-3 du code des sports	\N	2	jusqu'au 31 décembre 2016??	ACTIF	\N	\N	Conseil national du sport	\N	du 	Président du Sénat (un titulaire et un suppléant)	\N	\N	\N	\N	OUI	DECRET	ALERTE	\N	2013-08-27 11:51:52	2017-06-20 18:54:45	REG	OUI	INDETERMINEE	NON	308
ORGEXT	315	315	2013-09-09 00:00:00	2017-09-19 00:00:00	\N	décret n° 2013-809 du 9 septembre 2013\r\nNotification SGG le 19 septembre 2017	\N	4	mandat parlementaire. NB: durée de l'OEP: 4 ans ??	ANCIEN	\N	\N	Observatoire national du suicide	\N	de l'	Deux titulaires et deux suppléants\r\ndésignés par le Président du Sénat.\r\nTerme sous réserve du mandat sénatorial Les deux suppléants restent à désigner.	\N	\N	\N	\N	OUI	DECRET	ALERTE	\N	2013-09-13 10:46:13	2017-10-11 11:58:00	REG	OUI	INDETERMINEE	NON	315
ORGEXT	197	197	\N	2011-09-30 00:00:00	\N	Décret n°2003-1167 du 8 décembre 2003\r\nSupprimé en application du décret n° 2006-672 du 8 juin 2006	Poste et télécommunications - Nouvelles technologies	1	Mandat sénatorial (fin du mandat en cours si remplacement)	ANCIEN	\N	\N	Conseil consultatif de l'Internet	\N	du 	Sénat sur proposition de la commission des affaires économiques	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	197
ORGEXT	198	198	\N	2016-05-18 00:00:00	\N	Article L 524-14 du code du patrimoine - Art. 90 à 94 du décret n° 2004-490 du 3 juin 2004\r\nSupprimé par indication du SGG le 18 mai 2016	Culture et éducation	2	3 ans renouvelable	ANCIEN	\N	\N	Commission du Fonds national pour l'archéologie préventive	\N	de la 	1 titulaire et 1 suppléant désignés par le Sénat sur proposition de la commission des affaires culturelles	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2016-05-18 16:45:17	NEANT	NON	INDETERMINEE	NON	198
ORGEXT	281	281	\N	2014-12-11 00:00:00	\N	Art. L. 914-2 du code rural et de la pêche maritime\r\nDécret n° 2011-433 du 19 avril 2011 relatif à la composition et aux règles de fonctionnement du comité de liaison scientifique et technique des pêches maritimes et de l'aquaculture OEP supprimé décret n° 2013-420 et SGG 11/12/2014	\N	1	mandat parlementaire	ANCIEN	\N	\N	Comité de liaison scientifique et technique des pêches maritimes et de l'aquaculture	\N	du 	Président du Sénat	\N	\N	\N	\N	OUI	LOI	NEANT	\N	\N	2015-02-19 11:50:16	NEANT	NON	INDETERMINEE	NON	281
ORGEXT	279	279	\N	2015-01-06 00:00:00	\N	Article 12 de la loi n° 2010 873 du 27 juillet 2010 relative à l'action extérieure de la France\r\nArticle 4 du décret n° 2011-212 du 25 février 2011 relatif à France expertise internationale\r\nNB OEP supprimé par décison du SGG le 6 janvier 2015. Voir OEP 328 	\N	2	durée du mandat parlementaire	ANCIEN	\N	\N	Conseil d'administration de France expertise internationale	\N	du 	un sénateur directement désigné par la commission des affaires étrangères et un sénateur directement désigné par la commission des lois	\N	\N	\N	\N	OUI	LOI	NEANT	\N	\N	2015-03-04 18:15:12	NEANT	NON	INDETERMINEE	NON	279
ORGEXT	280	280	\N	2015-01-06 00:00:00	\N	Article 12 de la loi n° 2010 873 du 27 juillet 2010 relative à l'action extérieure de la France\r\nArticle 12 du décret n° 2011-212 du 25 février 2011 relatif à France expertise internationale\r\nNB OEP supprimé sur décsion du SGG du 6 janvier 2015 Voir OEP 328	\N	1	durée du mandat parlementaire	ANCIEN	\N	\N	Conseil d'orientation de France expertise internationale	\N	du 	par le Sénat sur proposition de la commission des affaires étrangères	\N	\N	\N	\N	OUI	LOI	NEANT	\N	\N	2015-03-04 18:15:28	NEANT	NON	INDETERMINEE	NON	280
ORGEXT	283	283	\N	\N	\N	Décret n° 2011-773 du 28 juin 2011 relatif au Haut Conseil à la vie associative\r\nDécret n° 2006-672 du 8 juin 2006 durée de vie cinq ans\r\nLégalisé par la loi n° 2018-699 du 3 août 2018 - art. 63 de la loi n° 2014-856 du 31 juillet 2014 	\N	1	mandat parlementaire	ACTIF	\N	\N	Haut Conseil à la vie associative	\N	du 	Président du Sénat	\N	\N	\N	\N	OUI	LOI	NEANT	\N	\N	2019-02-26 15:04:31	LEG	NON	INDETERMINEE	NON	283
ORGEXT	301	301	2012-07-31 00:00:00	2014-06-04 00:00:00	\N	Décret n° 2012-913 du 26 juillet 2012\r\nNB Cet OEP a été supprimé par décision du SGG le 4 juin 2014.	\N	3	\N	ANCIEN	\N	\N	Commission chargée de l'élaboration du livre blanc sur la défense et la sécurité nationale	\N	de la	en tant que membre de droit le président de la commission des affaires étrangères, de la défense et de forces armées + deux sénateurs nommés par le Président du Sénat	\N	\N	\N	\N	OUI	DECRET	NEANT	\N	\N	2014-10-06 17:13:06	NEANT	NON	INDETERMINEE	NON	301
HAUCOUJUS	611	611	\N	\N	\N	Article 67 de la Constitution - et article 5 de la LOI organique n° 2014-1392 du 24 novembre 2014 portant application de l'article 68 de la Constitution	\N	18	Le Parlement est constitué en Haute Cour - Le Bureau de la Haute Cour est composé de vingt-deux membres 	ANCIEN	\N	\N	Haute Cour de Justice	\N	de la 	Le Bureau de la Haute Cour est composé de vingt-deux membres désignés, en leur sein et en nombre égal, par le bureau de l'Assemblée nationale et par celui du Sénat	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	611
COUJUSREP	612	612	\N	\N	\N	Article 68-2 de la Constitution et loi organique n° 93-1252 du 23 novembre 1993 sur la Cour de Justice de la République	\N	12	Election après chaque renouvellement sénatorial	ACTIF	\N	\N	Cour de justice de la République	\N	de la 	Sénat par scrutin secret	\N	\N	/listes/cour_justice.html	\N	OUI	NEANT	ALERTE	\N	\N	2014-11-14 11:43:24	NEANT	NON	INDETERMINEE	NON	612
ORGEXT	303	303	2013-01-04 00:00:00	\N	\N	Art. 9-1 de la loi n° 2008-496 du 27 mai 2008 ; décret ° 2021-921 du 9 juillet 2021	\N	2	trois ans renouvelable une fois	ACTIF	\N	\N	Haut conseil à l'égalité entre les femmes et les hommes	\N	du 	Président du Sénat	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	2017-09-13 15:09:38	LEG	OUI	INDETERMINEE	NON	303
ORGEXT	259	259	\N	\N	\N	Art. 8 de la loi n° 2010-237 du 9 mars 2010\r\nDécret n° 2010-80 du 22 janvier 2010 relatif au commissaire général à l'investissement (article 3)\r\nDécret n° 2013-14 du 8 janvier 2013 (durée mandat des personnalités qualifiées siégrant au conseil)	\N	4	n'est pas définie par le décret  (fin de mandat sénatorial)	ACTIF	\N	\N	Comité de surveillance des investissements d'avenir	\N	du 	Président parmi les membres des commissions des finances, culture et économie	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2017-09-13 17:58:58	LEG	OUI	INDETERMINEE	NON	259
ORGEXT	305	305	2013-02-04 00:00:00	2017-05-19 00:00:00	\N	code de l'urbanisme art. L 313-1 et art. 313-18\r\ncode de l'ubanisme art R 313-18 (décret n° 2007-452 du 25 mars 2007)\r\nRemplacée par la commission nationale du patrimoine et de l'architecture (indication du SGG le 19 mai 2017)	\N	1	mandat parlementaire	ANCIEN	\N	\N	Commission nationale des secteurs sauvegardés	\N	de la	Arrêté interministériel (Culture/Urbanisme)\r\nSur proposition du président du Sénat en accord avec le président de l'Assemblée nationale	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2017-06-06 18:01:50	REG	NON	INDETERMINEE	NON	305
ORGEXT	292	292	2012-02-19 00:00:00	\N	\N	Loi n° 2010-873 du 27 juillet 2010 relative à l'action extérieure de la France\r\nDécret n° 2011-2048 du 30 décembre 2011 	\N	2	trois ans	ACTIF	\N	\N	Conseil d'administration de Campus France	\N	du 	1 par la commission des affaires étrangères et 1 par la commission de la culture	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	2014-10-06 17:11:22	LEG	NON	INDETERMINEE	NON	292
ORGEXT	160	160	\N	\N	\N	Loi n°98-564 du 8 juillet 1998 tendant à l'élimination des mines antipersonnel (Article 9)/ Décret n°99-358 du 10 mai 1999 instituant une Commission nationale pour l'élimination des mines antipersonnel (Articles premier et 2).\r\narticles R. 2343-2 et R. 2343-3 du code de la défense\r\nLégalisé par la loi n° 2018-699 du 3 août 2018 - art. L. 2345-1 du code de la défense	Défense	2	Mandat parlementaire	ACTIF	\N	\N	Commission nationale pour l'élimination des mines antipersonnel	\N	de la 	Président du Sénat	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	2019-02-25 12:12:30	LEG	OUI	INDETERMINEE	NON	160
ORGEXT	9	9	\N	2009-01-01 00:00:00	\N	Décret n° 83-774 du 31 août 1983 relatif à  l'établissement public Autoroutes de France\r\narticle R.122-18 du code de la voirie routière. Art 63 loi finances pour2009 dissolution EP	Transports	1	3 ans (le remplaçant finit le mandat de celui qu'il remplace)	ANCIEN	\N	\N	Conseil d'administration de l'Etablissement public Autoroutes de France	\N	du 	Sénat sur proposition de la commission des finances	Economie	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2017-04-04 17:03:23	NEANT	NON	INDETERMINEE	NON	9
ORGEXT	307	307	2013-04-04 00:00:00	2021-07-07 00:00:00	\N	Décret n° 2007-425 du 25 mars 2007 (article 4)Légalisé par la loi n° 2018-699 du 3 août 2018 (art. 35). Mail SGG du 7 juillet 2021 : « concernant le décret n° 2021-716 du 4 juin 2021 qui institue un comité interministériel à la laïcité, nous considérons qu'il rend caduc les dispositions de l'article 35 de la loi OEP. Nous supprimons donc le 307 si vous en êtes d'accord. »	\N	2	renouvellement triennal du Sénat	ACTIF	\N	\N	Observatoire de la laïcité	\N	de l'	Par le président du Sénat\r\nM BUFFET, désigné en avril 2013, démissionne en octobre 2013\r\nM PORTELLI démissionne le 19/11/2015.	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2013-04-05 09:42:37	2019-02-26 15:38:54	LEG	OUI	INDETERMINEE	NON	307
ORGEXT	299	299	2012-09-14 00:00:00	\N	\N	L. 5322-1 du code de la santé publique	\N	3	Renouvellement triennal du Sénat	ACTIF	\N	\N	Conseil d'administration de l'Agence nationale de sécurité du médicament et des produits de santé	\N	du	Président du Sénat	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2019-03-05 15:31:17	LEG	NON	INDETERMINEE	NON	299
ORGEXT	604	604	\N	2002-04-25 00:00:00	\N	Décret du 8 juin 1984 portant création du Comité national (abrogé par le décret n°2002-581 du 25 avril 2002 portant création de la Commission des archives constitutionnelles de la Ve République)	Justice, législation générale	1	\N	ANCIEN	\N	\N	Comité national chargé de la publication des travaux préparatoires des institutions de la Ve République	\N	du 	Président de la commission des lois membre de droit	JUSTICE	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	604
ORGEXT	209	209	\N	2011-04-10 00:00:00	\N	Décret n°2004-1428 du 23 décembre 2004 relatif à l'établissement de gestion du fonds de financement des prestations sociales des non salariés agricoles\r\nABROGÉ par Décret n° 2008-1495 du 30 décembre 2008 portant dissolution de l'établissement de gestion du fonds de financement des prestations sociales des non-salariés agricoles et transfert de ses droits et obligations dudit fonds à la Caisse centrale de la mutualité sociale agricole \r\n	Sécurité sociale, travail	3	3 ans renouvelable	ANCIEN	\N	\N	Comité de surveillance du Fonds de financement des prestations sociales des non salariés agricoles	\N	du 	Sénat sur proposition de la commission des affaires sociales pour 2 candidats et de la commission des finances pour un candidat. NB/ président désigné parmi les parlementaires (députés et sénateurs)	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	209
ORGEXT	297	297	2012-07-18 00:00:00	\N	\N	Art. L. 723-21 du code de la sécurité intérieure	\N	1	durée du mandat parlementaire	ACTIF	\N	\N	Conseil national des sapeurs-pompiers volontaires	\N	du	Président du Sénat	\N	\N	\N	\N	OUI	LOI	NEANT	\N	\N	2017-12-19 16:12:42	LEG	OUI	INDETERMINEE	NON	297
ORGEXT	298	298	2012-09-24 00:00:00	2017-12-30 00:00:00	\N	Loi n° 2011-835 du 13 juillet 2011 et Décret n° 2012-385 du 21 mars 2012\r\nSupprimée par l¿article 6 II de la loi n° 2017-1839 du 30 décembre 2017 	\N	1	renouvellement partiel 	ANCIEN	\N	\N	Commission nationale d'orientation, de suivi et d'évaluation des techniques d'exploration et d'exploitation des hydrocarbures liquides et gazeux	\N	de la	nommé par le Président du Sénat 	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2018-01-16 17:11:10	LEG	NON	INDETERMINEE	NON	298
ORGEXT	10011	-1	\N	\N	\N	(Ancien conseil supérieur de l'audiovisuel)	\N	0	\N	ACTIF	\N	\N	Autorité de régulation de la communication audiovisuelle et numérique	\N	du	\N	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	\N	LEG	NON	AUT_ADMIN_INDEP	NON	\N
ORGEXT	605	605	\N	2014-11-04 00:00:00	\N	Décret n° 82-308 du 1er avril 1982 portant création du haut comité du loisir social ,de l'éducation populaire et des activités de pleine nature.\r\nCet organisme a été considéré comme caduc par le SGG en date du 4 novembre 2014.	Jeunesse, sports, tourisme, vie associative	1	\N	ANCIEN	\N	\N	Haut comité du loisir social, de l'éducation populaire et des activités de pleine nature	\N	du 	Président de la commission des affaires culturelles membre de droit	Temps libre	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2017-04-04 16:51:35	NEANT	NON	INDETERMINEE	NON	605
ORGEXT	606	606	\N	2013-04-04 00:00:00	\N	Article R. 221-28 du code du sport\r\nCette disposition a été abrogée par le décret n° 2013-289 du 4 avril 2013 portant création du conseil national du sport	Jeunesse, sports, tourisme, vie associative	2	4 ans (Désignation tous les quatre ans après les jeux olympiques)	ANCIEN	\N	\N	Commission nationale du sport de haut niveau	\N	de la 	Rapporteur spécial pour le sport de la commission des finances membre de droit et un membre de la commission des affaires culturelles (librement désigné par elle au cas par cas)	Jeunesse et sports	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2017-04-04 17:02:56	NEANT	NON	INDETERMINEE	NON	606
ORGEXT	607	607	\N	2004-08-13 00:00:00	\N	Article L. 161-28-2 du code de la Sécurité sociale issu de l'article 21 de la loi de financement de la sécurité sociale pour 1999. Art. 1er du décret n°99-866 du 7 octobre 1999. (supprimé par la loi n° 2004-810 du 13 Août 2004 portant réforme de l'assurance maladie)	Sécurité sociale, travail	1	\N	ANCIEN	\N	\N	Conseil pour la transparence des statistiques de l'assurance-maladie	\N	du 	Président de la commission des affaires sociales, ou son représentant, membre de droit	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	607
ORGEXT	205	205	\N	\N	\N	Article 44 de la loi n° 2004-811 du 13 août 2004 de modernisation de la sécurité civile et  articles R.1424-59 et suivants du code général des collectivités territoriales	Intérieur - Libertés publiques	2	après chaque élection cantonale	ACTIF	\N	\N	Conférence nationale des services d'incendie et de secours	\N	de la 	Un titulaire et un suppléant désignés par le ministre de l'intérieur sur proposition du Président du Sénat	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2019-05-09 12:23:27	LEG	OUI	INDETERMINEE	NON	205
ORGEXT	277	277	\N	2014-12-20 00:00:00	\N	Article L. 313-3 du code de la consommation\r\nSupprimé par l'article 28 de la loi n° 2014-1545 du 20 décembre 2014	\N	1	deux ans à compter de la mise en place du comité	ANCIEN	\N	\N	Comité de suivi du niveau et de l'évolution des taux d'intérêt des prêts aux particuliers	\N	du 	Sénat sur proposition de la commission des finances	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2017-04-04 17:01:35	NEANT	NON	INDETERMINEE	NON	277
ORGEXT	50	50	\N	\N	\N	Article R. 721-3 du code rural (anciennement Décret n° 64-862 du 3 août 1964 modifié par le décret n° 69-671 du 19 juin 1969 portant règlement d'administration publique et relatif à la réorganisation de certains des conseils et commissions du ministère de l'agriculture / Décret n° 73-251 du 6 mars 1973 ; Décret n° 2010-357 du 1er avril 2010) Art. D. 721-7 du code rural et de la pêche maritime\r\nLégalisé par la loi n° 2018-699 du 3 août 2018 - art. L. 721-3 du code rural et de la pêche maritime	Sécurité sociale, travail	2	5 ans 	ACTIF	\N	\N	Conseil supérieur des prestations sociales agricoles 	\N	du 	1 titulaire proposé par la commission des affaires sociales et 1 titulaire proposé par la commission des finances	Agriculture	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2019-02-26 12:25:35	LEG	OUI	INDETERMINEE	NON	50
ORGEXT	151	151	\N	2011-12-21 00:00:00	\N	Art. L.228-1 et R.228-4 du code de la sécurité sociale\r\n\r\nAbrogé par la loi n° 2011-1906 du 21 décembre 2011 de financement de la sécurité sociale  (art. 110)	Sécurité sociale, travail	3	5 ans	ANCIEN	\N	\N	Conseil de surveillance de l'Agence centrale des organismes de sécurité sociale	\N	du 	Président du Sénat	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	151
ORGEXT	235	235	\N	2014-02-17 00:00:00	\N	Décret n° 2006-1286 du 20 octobre 2006 (art.  L. 313-14 du code de l'entrée et du séjour des étrangers et du droit d'asile et article R. 313-33 du même code)  à revoir  en attente d'un décret d'application de la loi n° 2011- 672 (octobre 2011)\r\nOrganisme supprimé par le décret n° 2014-132 du 17 février 12014	intérieur, libertés publiques	2	2 ans (remplacement pour la durée du mandat restant à courir)	ANCIEN	\N	\N	Commission nationale de l'admission exceptionnelle au séjour	\N	de la 	Sénat (1 membre titulaire et 1 membre suppléant désignés par le Sénat sur proposition de la commission des Lois)	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2017-04-04 17:00:44	NEANT	NON	INDETERMINEE	NON	235
ORGEXT	291	291	2012-03-07 00:00:00	\N	\N	Décret n° 2011-2109 du 30 décembre 2011 portant création du Conseil supérieur des gens de mer\r\nDécret n° 2006-672 du 8 juin 2006\r\nLégalisé par la loi n° 2018-699 du 3 août 2018 - art. L. 5581-1 du code des transports	\N	1	mandat parlementaire	ACTIF	\N	\N	Conseil supérieur des gens de mer	\N	du 	Président du Sénat	\N	\N	\N	\N	OUI	LOI	NEANT	\N	\N	2019-02-26 12:09:51	LEG	OUI	INDETERMINEE	NON	291
ORGEXT	202	202	\N	2020-12-07 00:00:00	\N	Décret n° 2009-1321 du 28 octobre 2009 (art 1-18) abrogeant le décret n° 2004-750 du 27 juillet 2004 portant création de l'Institut national des hautes études de sécurité (art 6 et 7)Légalisé par la loi n° 2018-699 du 3 août 2018 - art. L. 123-1 du code de la sécurité intérieure - Supprimé loi ASAP n° 2020-1525 du 7 décembre 2020	Intérieur - Libertés publiques	1	3 ans renouvelable une fois (dispositions prévues en cas de remplacement en cours de mandat)	ACTIF	\N	\N	Conseil d'administration de l'Institut national des hautes études de la sécurité et de la justice ( ancien Institut national des hautes études de sécurité - INHES)	\N	du 	Sénat article 9  (sur proposition de la commission des lois)\r\nMandat de trois ans, sous réserve de la durée du mandat parlementaire.	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2019-02-25 17:00:35	LEG	NON	INDETERMINEE	NON	202
ORGEXT	608	608	\N	2011-09-30 00:00:00	\N	Décret n° 2006-515 du 5 mai 2006 (article 1er)	Economie, finances	4	durée mandat es qualité	ACTIF	\N	\N	Conférence nationale des finances publiques	\N	de la 	ès qualités : présidents des commissions des finances et des affaires sociales, rapporteur général de la commission des finances, rapporteur spécial pour les crédits des programmes relatifs aux concours financiers de l'Etat aux collectivités territoriales	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	\N	LEG	NON	INDETERMINEE	NON	608
ORGEXT	321	321	2014-05-19 00:00:00	2017-09-30 00:00:00	\N	Art. 12 de la loi n° 2014-58 du 27 janvier 2014 décret n° 2014-508 du 19 mai 2014 (article 2)\r\nSupprimé par notification du SGG le 11 octobre 2017	\N	4	mandat parlementaire	ANCIEN	\N	\N	Conseil des élus de la mission de préfiguration de la métropole du Grand Paris	\N	du	Deux sénateurs et deux suppléants désignés par le Sénat (Président)\r\nNB Le Président n'a pas désigné deux suppléants en juin 2014 Ils restent à désigner	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2014-06-06 14:39:54	2017-10-11 18:21:58	LEG	NON	INDETERMINEE	NON	321
ORGEXT	10015	-1	\N	\N	\N	\N	\N	0	\N	ACTIF	\N	\N	Office national d'indemnisation des accidents médicaux, des affections iatrogènes et des infections nosocomiales	\N	\N	\N	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	\N
ORGEXT	326	326	2014-10-09 00:00:00	\N	\N	Décret n° 2014-1162 du 9 octobre 2014\r\narticles R. 40-53 et R. 40-54 du code de procédure pénale\r\nLégalisé par la loi n° 2018-699 du 3 août 2018 - art. 230-45 du code de procédure pénale	\N	1	Jusqu'au prochain renouvellement partiel du Sénat	ACTIF	\N	\N	Comité placé auprès de la personnalité qualifiée chargée de contrôler la plate-forme nationale \r\ndes interceptions judiciaires	\N	du	Un sénateur choisi par le président du Sénat, après chaque renouvellement partiel du Sénat, \r\nsur proposition de la commission compétente du Sénat (lois)	\N	\N	\N	\N	OUI	DECRET	ALERTE	\N	2014-10-17 08:42:50	2019-02-25 11:46:33	LEG	NON	INDETERMINEE	NON	326
ORGEXT	328	328	\N	\N	\N	art. 12 de la loi n° 2010-873 du 27 juillet 2010	\N	2	Cinq ans sous réserve du mandat parlementaire en cours lors de la désignation	ACTIF	\N	\N	Conseil d'administration de l'Agence française d'expertise technique internationale (AFETI)	\N	du 	Deux sénateurs titulaires désignés par le président du Sénat	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	2015-01-06 16:46:01	2017-11-13 12:17:10	LEG	NON	INDETERMINEE	NON	328
ORGEXT	337	337	2015-05-20 00:00:00	\N	\N	décret n° 2015-563 du 20 mai 2015 (articles 2 et 4)\r\nLégalisé par la loi n° 2018-699 du 3 août 2018 - art. 10-1 de la loi n° 2000-614 du 5 juillet 2000 	\N	1	Cinq ans, sous réserve du mandat parlementaire	ACTIF	\N	\N	Commission nationale consultative des gens du voyage	\N	de la 	Un sénateur désigné par le président du Sénat	\N	\N	\N	\N	OUI	LOI	NEANT	\N	2015-05-27 10:16:49	2019-02-25 11:59:43	LEG	OUI	INDETERMINEE	NON	337
ORGEXT	338	338	2015-05-20 00:00:00	2020-08-03 00:00:00	\N	décret n° 2015-562 du 20 mai 2015\r\nRespect de la parité (article 74 de la loi n° 2014-873 du 4 août 2014)\r\nNB succède à l'OEP n° 16	\N	4	5 ans sous réserve du mandat sénatorial	ACTIF	\N	\N	Conseil supérieur de la coopération	\N	du	Sénat: un candidat titulaire et un suppléant proposé par la commission des affaires économiques\r\n et un candidat titulaire et un suppléant proposé par la commission des affaires sociales	\N	\N	\N	\N	OUI	DECRET	ALERTE	\N	2015-05-27 10:35:04	2015-06-19 09:36:37	REG	NON	INDETERMINEE	NON	338
ORGEXT	339	339	2015-06-12 00:00:00	\N	\N	loi n° 2013-316 du 16 avril 2013 article 5\r\ndécret n° 2014-1629 du 26 décembre 2014 articles 1  2	\N	2	Quatre ans renouvelable une fois, sous réserve du mandat parlementaire	ACTIF	\N	\N	Commission nationale de la déontologie et des alertes en matière de santé publique et d'environnement	\N	de la 	Président du Sénat	\N	\N	\N	\N	OUI	LOI	NEANT	\N	2015-06-12 10:46:26	2017-09-13 17:58:21	LEG	OUI	INDETERMINEE	NON	339
ORGEXT	340	340	2015-06-24 00:00:00	\N	\N	loi n° 2014-856 du 31 juillet 2014 article 4\r\ndécret n° 2015-732 du 24 juin 2015 art 1 et 2\r\nCert OEP succède à l'OEP 268 de nom identique\r\nLégalisé par la loi n° 2018-699 du 3 août 2018 (art. 4 modifié de la loi n° 2014-856 du 31 juillet 2014)\r\n	\N	1	Renouvellement triennal du Sénat	ACTIF	\N	\N	Conseil supérieur de l'économie sociale et solidaire	\N	du 	L'article 4 de la loi n° 2014-856 prévoit un "représentant" désigné par le Sénat.\r\nL'article 1er du décret n° 2015-732 prévoit lui "un sénateur".\r\nRéférence à la loi n° 2014-873 du 4 août 2014 pour le respect de la parité\r\nPlus de suppléant	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2015-06-29 09:05:27	2019-02-26 11:37:53	LEG	OUI	INDETERMINEE	NON	340
ORGEXT	342	342	2015-07-25 00:00:00	\N	\N	loi n° 2015-912 du 24 juillet 2015 article 2\r\narticle L. 831-1 du code de la sécurité intérieure	\N	2	mandat parlementaire. 	ACTIF	\N	\N	Commission nationale de contrôle des techniques de renseignement	\N	de la 	Exigence de représentation pluraliste du Parlement. Président du Sénat.	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2015-07-29 09:04:10	2018-03-19 18:44:56	LEG	OUI	AUT_ADMIN_INDEP	NON	342
ORGEXT	347	347	2016-05-31 00:00:00	2020-08-03 00:00:00	\N	Article 5 de la loi n° 2015-1786 du 29 décembre 2015, codifié à l'art. L. 121-28-1 du code de l¿énergie. Sa composition est prévue par le décret n° 2016-310 du 16 mars 2016, codifié à l¿article D121-34 du même code.	\N	1	5 ans	ACTIF	\N	\N	Comité de gestion des charges de service public de l'électricité	\N	\N	\N	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2016-05-31 16:33:34	\N	REG	NON	INDETERMINEE	NON	347
ORGEXT	361	361	2017-05-18 00:00:00	\N	\N	Art. L. 1413-9 du code de la santé publique\r\nArt. R. 1413-3 et 1413-4 \r\n	\N	2	chaque renouvellement partiel du Sénat	ACTIF	\N	\N	Conseil d'administration de l'agence nationale de santé publique	\N	du 	Président du Sénat (art. R. 1413-3 du code de la santé publique)	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2017-06-06 16:57:46	2017-12-01 15:13:26	LEG	NON	INDETERMINEE	NON	361
ORGEXT	362	362	2017-05-19 00:00:00	\N	\N	Art. 74 de la loi n° 2016-925 du 7 juillet 2016 relative à la liberté de la création, à l'architecture et au patrimoine (art. L. 611-1 du code du patrimoine) et décret n° 2017-456 du 29 mars 2017 (art. R. 611-2 et R. 611-3 du code du patrimoine)\r\nUn titulaire et un suppléant désignés par leur assemblée\r\nRemplace la commission nationale des secteurs sauvegardés (OEP n° 305)	\N	2	5 ans	ACTIF	\N	\N	Commission nationale du patrimoine et de l'architecture	\N	de la 	Sénat sur proposition de la commission de la culture	\N	\N	\N	\N	OUI	LOI	NEANT	\N	2017-06-06 17:09:17	2017-09-13 15:16:52	LEG	OUI	INDETERMINEE	NON	362
ORGEXT	363	363	2017-05-22 00:00:00	\N	\N	Art. L. 682-1 du code rural et de la pêche maritime\r\nArt. D. 682-3 devrait être actualisé	\N	2	Renouvellement triennal	ACTIF	\N	\N	Comité de pilotage de l'observatoire de la formation des prix et des marges des produits alimentaires	\N	du	\N	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2017-06-06 18:02:18	2018-01-26 10:57:51	LEG	NON	INDETERMINEE	NON	363
ORGEXT	364	364	2017-05-30 00:00:00	\N	\N	Art. 5 et 7 de la loi n° 85-30 du 9 janvier 1985 relative au développement et à la protection de la montagne\r\nDécret n° 2017-755 du 3 mai 2017 	\N	4	6 ans, renouvelable	ACTIF	\N	\N	Comité de massif du massif des Alpes	\N	du 	\N	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2017-06-06 18:09:47	2017-06-06 18:29:26	LEG	NON	INDETERMINEE	NON	364
ORGEXT	365	365	2017-05-30 00:00:00	\N	\N	Art. 5 et 7 de la loi n° 85-30 du 9 janvier 1985 relative au développement et à la protection de la montagne\r\nDécret n° 2017-755 du 3 mai 2017 	\N	4	6 ans, renouvelable	ACTIF	\N	\N	Comité de massif du Massif central	\N	du 	\N	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2017-06-06 18:10:23	2017-06-06 18:29:52	LEG	NON	INDETERMINEE	NON	365
ORGEXT	366	366	2017-05-30 00:00:00	\N	\N	Art. 5 et 7 de la loi n° 85-30 du 9 janvier 1985 relative au développement et à la protection de la montagne\r\nDécret n° 2017-755 du 3 mai 2017 	\N	2	6 ans, renouvelable	ACTIF	\N	\N	Comité de massif du massif du Jura	\N	du 	\N	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2017-06-06 18:11:08	2017-06-06 18:30:13	LEG	NON	INDETERMINEE	NON	366
ORGEXT	367	367	2017-05-30 00:00:00	\N	\N	Art. 5 et 7 de la loi n° 85-30 du 9 janvier 1985 relative au développement et à la protection de la montagne\r\nDécret n° 2017-755 du 3 mai 2017 	\N	4	6 ans, renouvelable	ACTIF	\N	\N	Comité de massif du massif des Pyrénées	\N	du 	\N	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2017-06-06 18:12:06	2018-01-11 11:29:48	LEG	NON	INDETERMINEE	NON	367
ORGEXT	368	368	2017-05-30 00:00:00	\N	\N	Art. 5 et 7 de la loi n° 85-30 du 9 janvier 1985 relative au développement et à la protection de la montagne\r\nDécret n° 2017-755 du 3 mai 2017 	\N	4	6 ans, renouvelable	ACTIF	\N	\N	Comité de massif du massif des Vosges	\N	du 	\N	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2017-06-06 18:14:20	2017-06-06 18:30:56	LEG	NON	INDETERMINEE	NON	368
ORGEXT	327	327	2015-01-21 00:00:00	2018-08-03 00:00:00	\N	article 9 de la loi n° 91-1 du 3 janvier 1991\r\narticle 1er du décret n° 91-422 du 7 mai 1991 modifié par le décret n° 2014-1355 du 12 novembre 2014	\N	4	Mandat sénatorial (mais les autres membres pour 3 ans).	ACTIF	\N	\N	Conseil national de l'insertion par l'activité économique	\N	du 	M. le Président du Sénat (2° a) de l'article 1er du décret n° 91-422 du 7 mai 1991 modifié par le décret n° 2014-1355 du 12 novembre 2014.\r\nPremière désignation demandée le 21/01/2015.	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2015-01-21 14:08:08	2017-09-13 16:25:00	REG	OUI	INDETERMINEE	NON	327
ORGEXT	333	333	2015-03-17 00:00:00	\N	\N	loi n° 2014-173 du 21 février 2014\r\ndécret n° 2015-77 du 27 janvier 2015\r\nLégalisé par la loi n° 2018-699 du 3 août 2018 (art. 2-1 de la loi n° 2014-173 du 21 février 2014)	\N	2	Trois ans, renouvelable une fois, sous réserve du mandat parlementaire	ACTIF	\N	\N	Conseil national des villes	\N	du 	Cet organisme succède au Conseil national des villes (OEP 257), supprimé le 17/03/2015.\r\nDeux sénateurs désignés par le Sénat sur proposition de la commission des affaires économiques.	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2015-03-17 16:36:36	2019-02-26 10:11:39	LEG	OUI	INDETERMINEE	NON	333
ORGEXT	341	341	2015-04-17 00:00:00	\N	\N	article 4 de la loi n° 57-32 du 10 janvier 1957 modifié par l'article 13 de la loi n° 2015 du 17 avril 2015\r\ndécret n° 2015-721 du 23 juin 2015	\N	1	Cinq ans, renouvelable (sous réserve du mandat parlementaire)	ACTIF	\N	\N	Conseil supérieur de l'Agence France Presse	\N	\N	Désignation directe par la commission de la culture\r\nRespect d l'obligation de parité	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2015-07-06 15:25:31	2018-10-18 16:05:16	LEG	NON	INDETERMINEE	NON	341
ORGEXT	343	343	2015-07-29 00:00:00	\N	\N	Article L. 121-2 du code de l'entrée et du séjour des étrangers et du droit d'asile	\N	1	durée du mandat	ACTIF	\N	\N	Conseil d'administration de l'Office français de l'immigration et de l'intégration	\N	du	Président du Sénat (mail de la présidence du 9 octobre 2015)	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2015-09-04 09:56:03	2017-03-21 16:09:09	LEG	NON	INDETERMINEE	NON	343
ORGEXT	344	344	2015-06-29 00:00:00	\N	\N	loi n° 2014-1170 du 13 octobre 2014 article 25\r\ndécret n° 2015-779 du 29 juin 2015\r\narticles L. 112-1 D. 112-1-13 du code rural	\N	2	mandat sénatorial	ACTIF	\N	\N	Observatoire des espaces naturels, agricoles et forestiers	\N	de l'	Un titulaire nommé sur proposition de la commission des affaires économiques et un suppléant nommé sur proposition de la commission de l'aménagement du territoire et du développement durable	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2015-09-04 09:58:12	2018-03-26 17:13:23	LEG	OUI	OEP	NON	344
ORGEXT	346	346	2016-05-09 00:00:00	\N	\N	article L. 121-3 du code de la construction et de l'habitation  et décret n° 2016-551 du 4 mai 2016 relatif au Centre scientifique et technique du bâtiment	\N	1	Selon mandat parlementaire	ACTIF	\N	\N	Conseil d'administration du centre scientifique et technique du bâtiment	\N	du	\N	\N	\N	\N	\N	OUI	LOI	NEANT	\N	2016-05-09 16:35:18	2017-01-12 10:12:37	LEG	NON	INDETERMINEE	NON	346
ORGEXT	231	231	\N	2017-06-22 00:00:00	\N	Articles L.334-2, R.334-4, R. 334-5 et R. 334-6 du code de l'environnement\r\nSupprimé par notification du SGG le 22 juin 2017	Environnement, logement, urbanisme	1	Durée du mandat sénatorial	ANCIEN	\N	\N	Conseil d'administration de l'Agence des aires marines protégées	\N	du 	Sénat (proposition de la commission du développement durable)	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2017-06-26 11:40:49	LEG	NON	INDETERMINEE	NON	231
ORGEXT	379	379	2017-07-07 00:00:00	\N	\N	Décret n° 2016-283 du 10 mars 2016 relatif à l'Institut de radioprotection et de sûreté nucléaire (art. R. 592-4 du code de l'environnement)\r\nLégalisé par la loi n° 2018-699 du 3 août 2018 - art. L. 592-45 du code de l'environnement	\N	1	5 ans	ACTIF	\N	\N	Conseil d'administration de l'Institut de radioprotection et de sûreté nucléaire	\N	du	Président du Sénat	\N	\N	\N	\N	OUI	DECRET	ALERTE	\N	2017-09-12 11:00:22	2019-02-25 16:36:39	LEG	NON	INDETERMINEE	NON	379
ORGEXT	380	380	2017-09-05 00:00:00	\N	\N	Art. 66 de la loi n° 2012-1510 du 29 décembre 2012 de finances rectificative pour 2012 tel que modifié par l'article 81 de la loi n° 2014-1654 du 29 décembre 2014 de finances pour 2015	\N	2	mandat parlementaire	ACTIF	\N	\N	Comité de suivi du crédit d'impôt pour la compétitivité et l'emploi	\N	\N	Président du Sénat sur proposition de la commission des finances	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2017-09-12 11:02:07	2018-01-18 15:41:30	LEG	OUI	INDETERMINEE	NON	380
ORGEXT	332	332	\N	\N	\N	article L. 2102-7 du code des transports . art.1er de la loi n° 2014-872 du 4 août 2014\r\ndécret n° 2015-137 du 10 février 2015 art.9 (désignation Président du Sénat)	\N	1	mandat parlementaire	ACTIF	\N	\N	conseil de surveillance de la SNCF	\N	du	\N	\N	\N	\N	\N	OUI	LOI	NEANT	\N	2015-03-16 17:10:25	2017-10-02 17:46:23	LEG	NON	INDETERMINEE	NON	332
ORGEXT	383	383	2018-01-29 00:00:00	2020-10-01 00:00:00	\N	Art. 1650 B du CGI (27° du I de l'art. 30 de la loi n° 2017-1775 du 28 décembre 2017 de finances rectificative pour 2017) 	\N	93	Mandat parlementaire	ACTIF	\N	\N	Commission départementale des valeurs locatives des locaux professionnels 	\N	de la 	\N	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2018-03-26 10:02:35	2018-10-09 13:05:11	LEG	NON	INDETERMINEE	NON	383
ORGEXT	387	387	2018-10-25 00:00:00	\N	\N	Article 11 de la loi n° 2003-710 du 1er août 2003 modifié par article 44 de la loi n° 2018-699\r\ndécret n° 2004-123 du 9 février 2004	\N	1	Cinq ans	ACTIF	\N	\N	Conseil d'administration de l'agence nationale pour la rénovation urbaine	\N	du	Président du Sénat	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2019-02-26 16:12:26	2019-02-26 16:15:47	LEG	NON	INDETERMINEE	NON	\N
ORGEXT	384	384	2018-07-30 00:00:00	\N	\N	Article 28 de la loi n° 2018-202 du 26 mars 2018 relative à l'organisation des jeux Olympiques et Paralympiques de 2024	\N	1	mandat parlementaire	ACTIF	\N	\N	Comité d'éthique du comité d'organisation des jeux olympiques et paralympiques	\N	du	\N	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2019-02-26 16:16:44	\N	LEG	NON	INDETERMINEE	NON	\N
ORGEXT	385	385	2018-07-30 00:00:00	\N	\N	article 28 de la loi n° 20018-206 du 26 mars 2018 relative à l'organisation des jeux Olympiques et Paralympiques de 2024	\N	1	mandat parlementaire	ACTIF	\N	\N	Comité des rémunérations du comité d'organisation des jeux olympiques et paralympiques	\N	du	Président du Sénat	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2019-02-26 16:19:21	2019-02-26 16:27:45	LEG	NON	INDETERMINEE	NON	\N
ORGEXT	388	-1	2018-11-08 00:00:00	\N	\N	Art. L. 5211-43 CGCT	\N	158	mandat sénatorial	ACTIF	\N	\N	Commission départementale de la coopération intercommunale	\N	de la 	Président du Sénat	\N	\N	\N	\N	\N	LOI	ALERTE	\N	\N	\N	LEG	NON	INDETERMINEE	NON	388
ORGEXT	10001	-1	\N	\N	\N	\N	\N	0	\N	ACTIF	\N	\N	EDF	\N	\N	\N	\N	\N	\N	\N	\N	NEANT	ALERTE	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	\N
ORGEXT	10005	-1	2019-06-01 00:00:00	\N	\N	\N	\N	0	Cinq ans	ACTIF	\N	\N	Française des jeux	\N	de la 	\N	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	\N	LEG	NON	CONS_ADMIN	NON	\N
ORGEXT	DSBP-0001	-1	\N	\N	\N	\N	\N	0	6 ans	ACTIF	\N	\N	Commission nationale d'évaluation des recherches et études relatives à la gestion des matières et des déchets radioactifs	\N	L 542-2 du code l'environnement	Trois personnalités qualifiées désignées par le président du Sénat sur proposition de l'OPESCT	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	\N	NEANT	NON	COM_CONS_DELIB	NON	\N
ORGEXT	319	319	2013-12-23 00:00:00	2018-08-03 00:00:00	\N	loi n° 2013-595 du 8 juillet 2013 article 88\r\ndécret  n° 2013-1232 du 23 décembre 2013	\N	4	Jusqu'au renouvellement partiel du Sénat	ANCIEN	\N	\N	Comité de suivi de la loi d'orientation et de programmation pour la refondation de l'école de la République	\N	du 	Quatre sénateurs désignés par la commission compétente du Sénat en matière d'éducation\r\nSupprimé par la loi n° 2018-699 du 3 août 2018	\N	\N	\N	\N	OUI	LOI	NEANT	\N	2014-02-12 11:55:31	2018-10-15 16:33:08	LEG	NON	INDETERMINEE	NON	319
ORGEXT	325	325	2014-08-22 00:00:00	2018-09-05 00:00:00	\N	Loi n° 2014-288 du 5 mars 2014. Articles R. 6123-1-8 et R. 6123-1-10 du code du travail \r\n(décret n° 2014-965 du 22 août 2014).\r\nCet OEP succède à l'OEP 211 supprimé le 13 octobre 2014.	\N	2	3 ans, sous réserve du mandat sénatorial	ACTIF	\N	\N	Conseil national de l'emploi, de la formation et de l'orientation professionnelles	\N	du	Un sénateur titulaire et un suppléant sur proposition du président du Sénat	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	2014-10-13 16:03:48	2017-09-13 16:26:14	LEG	OUI	INDETERMINEE	NON	325
ORGEXT	335	335	2015-02-24 00:00:00	\N	\N	décret n° 2015-210 du 24 février 2015\r\net article D 3121-4 du code de la santé publique\r\nLégalisé par la loi n° 2018-699 du 3 août 2018 - art. L. 3121-3 du code de la santé publique	\N	1	5 ans (renouvelable une fois)	ACTIF	\N	\N	Conseil national du syndrome immunodéficitaire acquis (sida) et des hépatites virales chroniques	\N	du	Un sénateur désigné par M. le président du Sénat\r\nNB M Gilbert BARBIER nommé à l'OEP 207 en 2011	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	2015-04-17 10:21:05	2019-02-26 11:01:14	LEG	OUI	INDETERMINEE	NON	335
ORGEXT	355	355	2016-11-04 00:00:00	2019-12-31 00:00:00	\N	Art. L. 131-10 du code de l'environnement (créé par l'art. 21 de la loi n° 2016-1087 du 8 août 2016 pour la reconquête de la biodiversité, de la nature et des paysages)\r\nDécret n° 2016-1842 du 26 décembre 2016 (mandat des membres R. 131-28-3 du code de l'environnement)	\N	2	quatre ans	ANCIEN	\N	\N	Conseil d'administration de l'Agence française de la biodiversité	\N	du	Sénat sur proposition de la commission de l'aménagement du territoire et du développement durable	\N	\N	\N	\N	OUI	LOI	NEANT	\N	2016-11-04 19:06:49	2017-06-26 10:31:27	LEG	NON	INDETERMINEE	NON	355
ORGEXT	378	378	2017-07-03 00:00:00	\N	\N	Art. L. 239-1 du code de l'éducation\r\nComposition art. D. 239-2 du code de l'éducation\r\nLégalisé par la loi n° 2018-699 du 3 août 2018	\N	2	5 ans, renouvelable une fois	ACTIF	\N	\N	Conseil national de l'enseignement supérieur et de la recherche artistiques et culturels	\N	du 	Un titulaire et un suppléant, pas de précision sur l'autorité de désignation	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2017-07-04 16:44:46	2019-02-25 18:34:08	LEG	OUI	INDETERMINEE	NON	378
ORGEXT	10002	-1	\N	\N	\N	\N	\N	0	\N	ACTIF	\N	\N	RATP	\N	\N	\N	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	\N
ORGEXT	10012	-1	\N	\N	\N	\N	\N	0	\N	ACTIF	\N	\N	Institut national de la santé et de la recherche médicale	\N	de l'	\N	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	\N	LEG	NON	INDETERMINEE	NON	\N
ORGEXT	10017	-1	\N	\N	\N	\N	\N	0	\N	ACTIF	\N	\N	Agence nationale de sécurité sanitaire de l'alimentation, de l'environnement et du travail	\N	de l'	\N	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	\N	LEG	NON	AUT_ADMIN_INDEP	NON	\N
ORGEXT	395	-1	2020-05-25 00:00:00	\N	\N	Art. 11 de la loi n° 2020-546 du 11 mai 2020	\N	2	Mandat parlementaire	ACTIF	\N	\N	Comité de contrôle et de liaison covid-19 chargé d'associer la société civile	\N	du	Président du Sénat	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	\N	LEG	NON	OEP	NON	\N
ORGEXT	DSPB-006	-1	\N	\N	\N	art 460 du code des douanes	\N	0	3 ans	ACTIF	\N	\N	Comité du contentieux fiscal, douanier et des changes	\N	du 	Désignation par le Président du sénat	Ministère de l'Action et des comptes publics	\N	\N	\N	\N	NEANT	NEANT	\N	\N	\N	NEANT	OUI	COM_CONS_DELIB	NON	\N
ORGEXT	398	-1	2021-01-18 00:00:00	\N	\N	Art. 7 de la loi organique n° 2021-27 du 15 janvier 2021 relative au Conseil économique, social et environnemental (art. 7 de l'ordonnance n° 58-1360 du 29 décembre 1958) 	\N	3	\N	ACTIF	\N	\N	Comité chargé de proposer des évolutions de la composition du Conseil économique, social et environnemental	\N	du 	Président du Sénat, représentation pluraliste	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	\N	LEG	NON	OEP	NON	\N
ORGEXT	399	-1	2021-02-01 00:00:00	\N	\N	Art. L. 1212-1 du code des transports et décret n° 2020-1825 du 30 décembre 2020	\N	3	3 ans. Renouvelable.	ACTIF	\N	\N	Conseil d'orientation des infrastructures	\N	du 	Président du Sénat	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	\N	LEG	NON	OEP	NON	399
ORGEXT	DSPB-011	-1	\N	\N	\N	\N	\N	0	6 ans non renouvelable	ACTIF	\N	\N	Commission nationale d'aménagement commercial 	\N	L. 751-6 du code de commerce	Désignation d'un membre titulaire et d'un membre suppléant par le Président du sénat	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	\N	NEANT	NON	COM_CONS_DELIB	NON	\N
ORGEXT	10028	-1	2021-01-01 00:00:00	\N	\N	\N	\N	0	\N	ACTIF	\N	\N	Autorité de régulation des communications électroniques, des postes et de la distribution de presse	\N	de l'	\N	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	\N	LEG	NON	AUT_ADMIN_INDEP	NON	\N
ORGEXT	10030	-1	2003-08-01 00:00:00	\N	\N	Art. L. 821-2 du code de commerce	\N	0	\N	ACTIF	\N	\N	Haut conseil du commissariat aux comptes	\N	du 	\N	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	\N	LEG	NON	AUT_PUB_INDEP	NON	\N
ORGEXT	10031	-1	1961-12-19 00:00:00	\N	\N	Articles 10 de la loi n° 83-675 du 26 juillet 1983 et 2 du décret n° 84-510 du 28 juin 1984	\N	0	\N	ACTIF	\N	\N	Centre national d'études spatiales	\N	du 	\N	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	\N	LEG	NON	INDETERMINEE	NON	\N
ORGEXT	DSPB-012	-1	\N	\N	\N	\N	\N	0	\N	ACTIF	\N	\N	Autorité de la statistique publique	\N	\N	Personnalité qualifiée nommée par le Président du Sénat	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	\N	NEANT	NON	COM_CONS_DELIB	NON	\N
ORGEXT	400	-1	2021-09-23 00:00:00	\N	\N	Art. L. 541-1 du code de l'environnement (art. 26 de la loi n° 2021-1104 du 22 août 2021)	\N	2	5 ans (art. D. 541-3 du code de l'environnement)	ACTIF	\N	\N	Conseil national de l'économie circulaire	\N	du 	Président du Sénat	Transition écologique	\N	\N	\N	\N	LOI	ALERTE	\N	\N	\N	LEG	NON	OEP	NON	400
ORGEXT	401	-1	2021-10-01 00:00:00	\N	\N	Art. 27 de la loi n° 2018-699 du 3 août 2018	\N	244	Mandat parlementaire	ACTIF	\N	\N	collège consultatif de la commission du fonds pour le développement de la vie associative	\N	du 	Président du Sénat	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	\N	LEG	NON	COM_CONS_DELIB	NON	401
ORGEXT	10032	-1	2021-12-01 00:00:00	\N	\N	Art. L. 461-1 du code de commerce, art. 13C	\N	0	5 ans	ACTIF	\N	\N	Autorité de la concurrence	\N	de l'	Art. 13C	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	\N	LEG	NON	AUT_ADMIN_INDEP	NON	\N
ORGEXT	403	-1	2021-12-13 00:00:00	\N	\N	article 60 de la loi n° 2005-882 du 2 août 2005 modifié par l'art. 275 de la loi n° 2021-1104 du 22 août 2021 + décret n° 2013-333 du 22 avril 2013	\N	1	Mandat parlementaire	ACTIF	\N	\N	plateforme nationale d'actions globales pour la responsabilité sociétale des entreprises	\N	de la 	Président du Sénat	\N	\N	\N	\N	OUI	LOI	NEANT	\N	\N	\N	LEG	NON	OEP	NON	403
ORGEXT	404	-1	2022-01-06 00:00:00	\N	\N	article 9 de la loi n° 2021-1729 du 22 décembre 2021	\N	2	Jusqu'au 1er janvier 2023 ?	ACTIF	\N	\N	comité d'évaluation chargé du suivi de l'expérimentation prévue à l'article 63 de la loi n° 2019-222 du 23 mars 2019 de programmation 2018-2022 et de réforme pour la justice	\N	du 	Président du Sénat	\N	\N	\N	\N	OUI	LOI	NEANT	\N	\N	\N	LEG	NON	OEP	NON	404
ORGEXT	358	358	2017-02-10 00:00:00	\N	\N	Article 3 de l'ordonnance n° 2016-489 du 21 avril 2016\r\nDécret n° 2017-427 du 29 mars 2017\r\nL'article 1 de l'ordonnance précise que « la mission prévue au présent alinéa ne se poursuit pas au-delà de l'achèvement complet et de la réception des travaux de réalisation du canal Seine-Nord Europe ».\r\n	\N	1	mandat parlementaire	ACTIF	\N	\N	Conseil de surveillance de la société du canal Seine-Nord Europe	\N	\N	Un sénateur désigné par le Sénat sur proposition de la commission de l'aménagement du territoire (art. 9 du Règlement)	\N	\N	\N	\N	OUI	ORDON	NEANT	\N	2017-02-22 17:33:53	2017-12-01 18:40:50	LEG	NON	INDETERMINEE	NON	358
ORGEXT	359	359	2017-02-10 00:00:00	\N	\N	Article 4 de l'ordonnance n° 2016-489 du 21 avril 2016 relative à la Société du Canal Seine-Nord Europe.\r\nDécret n° 2017-427 du 29 mars 2017.\r\nL'article 1 de l'ordonnance précise que « la mission prévue au présent alinéa ne se poursuit pas au-delà de l'achèvement complet et de la réception des travaux de réalisation du canal Seine-Nord Europe ».\r\nDécret n° 2017-427 du 29 mars 2017.	\N	2	mandat parlementaire	ACTIF	\N	\N	Comité stratégique de la société du canal Seine-Nord Europe	\N	\N	Deux sénateurs désignés par le Sénat sur proposition de la commission de l'aménagement du territoire (art. 9 du Règlement)	\N	\N	\N	\N	OUI	ORDON	ALERTE	\N	2017-02-22 17:49:56	2017-12-01 18:41:45	LEG	NON	INDETERMINEE	NON	359
ORGEXT	278	278	\N	2017-10-20 00:00:00	\N	Article 6 de la loi n° 2010-1149 du 30 septembre 2010 relative à l'équipement numérique des établissements de spectacles cinématographiques\r\nDécret n° 2011-306 du 21 mars 2011 relatif au comité de suivi de la loi relative à l'équipement numérique des établissements de \r\nspectacles cinématographiques\r\nCaducité constatée par le SGG le 20 octobre 2017	\N	2	pas de durée précisée dans les textes mais des missions énumérées et explicites 	ANCIEN	\N	\N	Comité de suivi de la loi relative à l'équipement numérique des établissements de spectacles cinématographiques	\N	du 	par la commission de la culture 	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2017-10-23 11:06:36	LEG	NON	INDETERMINEE	NON	278
ORGEXT	31	31	\N	2015-10-07 00:00:00	\N	Décret n°66-221 du 14 avril 1966 portant création du Comité des prix de revient des fabrications d'armement\r\nProrogé par le décret n° 2014-596 du 6 juin 2014\r\nCaducité constatée par le SGG le 7 octobre 2015	Défense	1	Fin du mandat sénatorial	ANCIEN	\N	\N	Comité des prix de revient des fabrications d'armement	\N	du 	Sénat sur proposition de la commission des finances	Defense	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2015-10-08 11:38:48	NEANT	NON	INDETERMINEE	NON	31
ORGEXT	233	233	\N	\N	\N	Loi n° 2006-686 du 13 juin 2006 relative à la transparence et à la sécurité en matière nucléaire (art 23 )article L. 125-37 du code l'environnement	énergie	4	6 ans (sous réserve du mandat parlementaire). Cas remplacement: période restant à courir.	ACTIF	\N	\N	Haut Comité pour la transparence et l'information sur la sécurité nucléaire	\N	du 	Sénat (proposition de la commission des affaires économiques et de la commission du développement durable)\r\nLe mandat de MM SIDO et COURTEAU a pris fin le 27/02/2014 (lettre SGG du 29/10/2014)\r\n+ 2 suppléants : mail SGG du 2 février 2018	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	2018-02-02 16:48:55	LEG	NON	INDETERMINEE	NON	233
ORGEXT	135 bis	135	\N	\N	\N	Art. 75 de la loi de finances pour 1999 (n°98-1266) du 30 décembre 1998./ Art. 1er du décret n°99-811 du 10 septembre 1999 relatif aux comités de gestion du Fonds d'intervention pour les aéroports et le transport aérien.\r\nAbrogé du fait de la création du Comité consultatif des liaisons aériennes par l'article 12 du décret n°2005-473 du 16 mai 2005 (organisme sensé remplacer le FIATA)	Transports	2	Durée du mandat parlementaire	ANCIEN	\N	\N	Comité de gestion du Fonds d'intervention pour les aéroports et le transport aérien (FIATA) : Plates-formes aéroportuaires	\N	du 	Sénat sur proposition de la commission des affaires économiques pour un candidat, sur proposition de la commission des finances pour l'autre candidat	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	135 bis
ORGEXT	257	257	\N	2015-03-17 00:00:00	\N	Décret n° 2009-539 du 14 mai 2009 relatif aux instances en charge de la politique de la ville  (article 2) \r\nOEP supprimé sur indication du SGG le 17 mars 2015 car le décret n° 2015-77 du 27 janvier 2015 (article 12) a abrogé le décret n° 2011-628 du 1er juin 2011.	\N	2	trois ans (ou fin de mandat)	ANCIEN	\N	\N	Conseil national des villes	\N	du 	Sénat sur proposition de la commission des affaires économiques	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2017-04-04 17:00:52	NEANT	NON	INDETERMINEE	NON	257
ORGEXT	389	-1	2019-05-15 00:00:00	\N	\N	Art. L. 1415-4 et D. 1415-1-4 du code de la santé publique	\N	2	Chaque renouvellement sénatorial	ACTIF	\N	\N	Conseil d'administration de l'institut national du cancer	\N	du 	\N	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	\N	LEG	NON	OEP	NON	389
ORGEXT	392	-1	2019-09-16 00:00:00	\N	\N	Art. L. 112-17 du code du sport	\N	2	Mandat parlementaire	ACTIF	\N	\N	Conseil d'administration de l'agence nationale du sport	\N	\N	\N	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	\N	LEG	OUI	OEP	NON	392
ORGEXT	393	-1	2019-10-17 00:00:00	\N	\N	art. L. 131-10 du code de l'environnement	\N	4	5 ans sous réserve du mandat parlementaire	ACTIF	\N	\N	Conseil d'administration de l'office français de la biodiversité	\N	du 	\N	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	\N	LEG	OUI	OEP	NON	393
ORGEXT	394	-1	2019-10-21 00:00:00	\N	\N	Art. L. 1232-1 du code général des collectivités territoriales	\N	2	Mandat parlementaire	ACTIF	\N	\N	Conseil d'administration de l'agence nationale de la cohésion des territoires	\N	du 	\N	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	\N	LEG	NON	CONS_ADMIN	NON	394
ORGEXT	DSPB-002	-1	\N	\N	\N	L. 132-1 du code de justice administrative	\N	0	3 ans	ACTIF	\N	\N	Commission supérieure du Conseil d'Etat	\N	de la 	Désignée par le Président du sénat	\N	\N	\N	\N	OUI	LOI	NEANT	\N	\N	\N	LEG	NON	COM_CONS_DELIB	NON	\N
ORGEXT	DSPB-003	-1	\N	\N	\N	L. 612-5 du code monétaire et financier	\N	0	5 ans	ACTIF	\N	\N	Collège de supervision de l'Autorité de contrôle prudentiel et de résolution	\N	du 	Désignée par le Président du Sénat	Ministère de l'économie et des finances	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	\N	NEANT	NON	COM_CONS_DELIB	NON	\N
ORGEXT	10013	-1	\N	\N	\N	\N	\N	0	\N	ACTIF	\N	\N	Commission prévue à l'article 25 de la Constitution	\N	\N	\N	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	\N
ORGEXT	10016	-1	\N	\N	\N	\N	\N	0	\N	ACTIF	\N	\N	France compétences	\N	de 	\N	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	\N	LEG	NON	CONS_ADMIN	NON	\N
ORGEXT	10022	-1	\N	\N	\N	\N	\N	0	Six ans	ACTIF	\N	\N	Autorité de contrôle des nuisances aéroportuaires	\N	de l'	\N	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	\N	LEG	NON	AUT_ADMIN_INDEP	NON	\N
ORGEXT	10023	-1	2020-08-27 00:00:00	\N	\N	\N	\N	0	\N	ACTIF	\N	\N	Établissement français du sang	\N	de l'	\N	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	\N	LEG	NON	CONS_ADMIN	NON	\N
ORGEXT	10033	-1	2022-01-01 00:00:00	\N	\N	Article 13 C	\N	0	\N	ACTIF	\N	\N	centre national de la recherche scientifique	\N	du 	\N	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	\N	LEG	NON	INDETERMINEE	NON	\N
ORGEXT	406	-1	2022-03-22 00:00:00	\N	\N	article 4 de la loi n° 2022-229 du 23 février 2022 - décret n° 2022-394 du 18 mars 2022	\N	1	4 ans	ACTIF	\N	\N	commission nationale indépendante de reconnaissance et de réparation des préjudices subis par les harkis, les autres personnes rapatriées d'Algérie anciennement de statut civil de droit local et les membres de leurs familles	\N	de la 	\N	\N	\N	\N	\N	OUI	LOI	NEANT	\N	\N	\N	LEG	NON	OEP	NON	406
ORGEXT	316	316	2013-10-22 00:00:00	2019-09-24 00:00:00	\N	article L. 241-13 et D. 241-36 du code de l'éducation\r\narticle 33 de la loi n° 2013-595 du 8 juillet 2013\r\ndécret n° 2013-945 du 22 octobre 2013	\N	2	6 ans sous réserve mandat sénatorial	ACTIF	\N	\N	Conseil national d'évaluation du système scolaire	\N	du	deux sénateurs désignés par la commission compétente en matière d'éducation	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2013-10-28 11:54:46	2017-09-13 17:34:03	LEG	OUI	INDETERMINEE	NON	316
ORGEXT	318	318	2013-12-11 00:00:00	\N	\N	Art. 7 loi 2021-1031 - décret n° 2013-1154 du 11 décembre 2013	\N	2	3 ans renouvelable une fois	ACTIF	\N	\N	Conseil national du développement et de la solidarité internationale	\N	du 	Président du Sénat\r\n2 titulaires 	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2013-12-20 15:53:20	2019-02-26 10:30:50	LEG	OUI	INDETERMINEE	NON	318
ORGEXT	331	331	2015-03-11 00:00:00	\N	\N	Art l. 114-3-3 du code de la recherche (article 92 de la loi n° 2013-660)\r\ndécret n° 2014-1365 du 14 novembre 2014\r\nCet OEP succède à l'OEP 69 supprimé en 2015.	\N	1	Mandat parlementaire	ACTIF	\N	\N	Haut conseil d'évaluation de la recherche et de l'enseignement supérieur	\N	du 	Par la commission permanente compétente\r\nObligation de parité	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2015-03-11 16:17:50	2015-09-28 18:34:33	LEG	NON	INDETERMINEE	NON	331
ORGEXT	336	336	\N	\N	\N	article L. 2100-3 du code des transports.\r\nloi n° 2014-872 du 4 août 2014 article premier. loi n° 2014-873 du 4 août 2014 (égalité hommes femmes)\r\ndécret n° 2015-499 du 30 avril 2015 article 1er et 4.	\N	2	Cinq ans et renouvelable sous réserve du mandat parlementaire	ACTIF	\N	\N	Haut comité du système de transport ferroviaire 	\N	du 	Par le Président du Sénat	\N	\N	\N	\N	OUI	LOI	NEANT	\N	2015-05-06 19:01:59	2017-10-20 17:06:50	LEG	OUI	INDETERMINEE	NON	336
ORGEXT	227	227	\N	2016-05-18 00:00:00	\N	Décret n° 2006-429 du 12 avril 2006 relatif aux pôles d'excellence rurale (article 2)\r\nSupprimé par indication du SGG le 18 mai 2016 (art. 31 du décret n° 2015-1469 du 13 novembre 2015)	Aménagement du territoire	4	fin du mandat sénatorial	ANCIEN	\N	\N	Commission nationale de présélection des pôles d'excellence rurale	\N	de la 	Président du sénat	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2016-05-18 16:47:26	NEANT	NON	INDETERMINEE	NON	227
ORGEXT	348	348	2016-06-16 00:00:00	2021-09-30 00:00:00	\N	Art. 3 de la loi n° 2016-231 du 29 février 2016 d'expérimentation territoriale visant à résorber le chômage de longue duréeL'expérimentation doit durer 5 ans (art. 1 de la loi).  - Supprimé loi ASAP n° 2020-1525 du 7 décembre 2020	\N	1	Mandat parlementaire	ACTIF	\N	\N	Conseil d'administration du Fonds d'expérimentation territoriale contre le chômage de longue durée	\N	du	Président du Sénat (mail de Bruno Souchon, directeur-adjoint du cabinet, du 6 juillet 2016).	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2016-06-16 17:19:56	2017-03-21 16:11:33	LEG	NON	INDETERMINEE	NON	348
ORGEXT	10003	-1	2019-09-01 00:00:00	\N	\N	\N	\N	0	\N	ACTIF	\N	\N	Météo France	\N	\N	\N	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	\N	LEG	NON	CONS_ADMIN	NON	\N
ORGEXT	350	350	2016-07-28 00:00:00	\N	\N	Art. 6 de la loi n° 2016-564 du 10 mai 2016 renforçant le dialogue avec les supporters et la lutte contre le hooliganisme (art. L. 224-2 du code du sport). Composition fixée par le décret n° 2016-957 du 12 juillet 2016, modifié par le décret 2017-653 du 26 avril 2017\r\nRefus de nommer de la présidence - lettre du Président du 26 octobre 2016 \r\nLégalisé par la loi n° 2018-699 du 3 août 2018 - L. 224-2 du code du sport \r\nLégalisé par la loi n° 2018-699 du 3 août 2018	\N	1	3 ans (mandat renouvelable une fois)	ACTIF	\N	\N	Instance nationale du supportérisme	\N	de l'	Président du Sénat	\N	\N	\N	\N	OUI	LOI	NEANT	\N	2016-08-30 15:24:43	2019-02-26 15:34:17	LEG	NON	INDETERMINEE	NON	350
ORGEXT	345	345	2015-11-09 00:00:00	\N	\N	Refus de nommer faute de base légale\r\nDécret n° 2015-1311 du 19 octobre 2015\r\nLégalisé par la loi n° 2018-699 du 3 août 2018 (art. 60-1 de la loi n° 2005-882 du 2 août 2005)	\N	1	trois ans	ACTIF	\N	\N	Commission de concertation du commerce	\N	\N	\N	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	2016-08-30 15:31:42	2019-02-25 11:57:03	LEG	NON	INDETERMINEE	NON	345
ORGEXT	357	357	2017-01-26 00:00:00	\N	\N	article L. 2334-37 du code général des collectivités territoriales ( loi de finances pour 2017 du 29 décembre 2016)	\N	158	Renouvellement partiel du Sénat	ACTIF	\N	\N	Commission départementale de répartition des crédits de la dotation d'équipement des territoires ruraux	\N	de la 	Présidence du Sénat ( décision présidence)	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2017-01-26 17:13:25	2017-12-18 17:00:50	LEG	NON	INDETERMINEE	NON	357
ORGEXT	255	255	2011-11-23 00:00:00	\N	\N	Décret n° 2009-1102 du 8 septembre 2009 (première demande de désignation le 23/11/2009) la durée de vie du comité est limitée à cinq ans\r\nRenouvelé à l'annexe 1 du décret n° 2015-622 du 5 juin 2015\r\nLégalisé par la loi n° 2018-699 du 3 août 2018, art. L. 121-4 du code de la voirie routière	\N	1	mandat parlementaire	ACTIF	\N	\N	Comité des usagers du réseau routier national	\N	du 	nomination par le Sénat (sur proposition de la commission du développement durable)	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	2019-02-25 11:28:02	LEG	NON	INDETERMINEE	NON	255
ORGEXT	10004	-1	2019-06-01 00:00:00	\N	\N	\N	\N	0	\N	ACTIF	\N	\N	Voies navigables de France	\N	\N	\N	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	\N	LEG	NON	CONS_ADMIN	NON	\N
ORGEXT	391	-1	2019-09-06 00:00:00	\N	\N	Art. 40 loi n° 2019-791 du 26 juillet 2019 art. L. 241-13 du code de l'éducation. Incompatibilité avec le conseil supérieur des programmes.	\N	2	Mandat parlementaire + 2 personnalités qualifiées pour 6 ans 	ACTIF	\N	\N	Conseil d'évaluation de l'école	\N	du 	Commission de la culture	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	\N	LEG	OUI	OEP	NON	\N
ORGEXT	10009	-1	\N	\N	\N	\N	\N	0	\N	ACTIF	\N	\N	La Poste	\N	\N	\N	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	\N	LEG	NON	CONS_ADMIN	NON	\N
ORGEXT	10010	-1	\N	\N	\N	\N	\N	0	\N	ACTIF	\N	\N	Haute autorité pour la transparence de la vie publique	\N	de la 	\N	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	\N	LEG	NON	AUT_ADMIN_INDEP	NON	\N
ORGEXT	10014	-1	\N	\N	\N	\N	\N	0	\N	ACTIF	\N	\N	Conseil supérieur de la magistrature	\N	du	\N	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	\N	NEANT	NON	ORG_CONSTIT	NON	\N
ORGEXT	10018	-1	\N	\N	\N	\N	\N	0	\N	ACTIF	\N	\N	Autorité de sûreté nucléaire	\N	de l'	\N	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	\N	LEG	NON	AUT_ADMIN_INDEP	NON	\N
ORGEXT	10019	-1	\N	\N	\N	\N	\N	0	\N	ACTIF	\N	\N	Médiateur du crédit aux candidats et aux partis politiques	\N	\N	\N	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	\N	LEG	NON	AUT_ADMIN_INDEP	NON	\N
ORGEXT	DSPB-004	-1	\N	\N	\N	Art. L. 232-4 du code de justice administrative	\N	0	\N	ACTIF	\N	\N	Conseil supérieur des Tribunaux administratifs et des cours administratives d'appel	\N	du 	\N	\N	\N	\N	\N	\N	NEANT	NEANT	\N	\N	\N	NEANT	NON	COM_CONS_DELIB	NON	\N
ORGEXT	DSPB-010	-1	\N	\N	\N	\N	\N	0	5 ans, renouvelable une fois	ACTIF	\N	\N	Commission consultative aeroportuaire	\N	L. 228-2 du code de l'aviation civile	\N	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	\N	NEANT	NON	COM_CONS_DELIB	NON	\N
ORGEXT	DSPB-015	-1	2022-04-30 00:00:00	2026-04-30 00:00:00	\N	\N	\N	1	4 ans non renouvelable immédiatement	ACTIF	\N	\N	Commission d'intégration du Conseil d'Etat	\N	ART L.133-12-3 à L. 133-12-5 du code justice administrative	Nomination par le Président du Sénat	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	\N	NEANT	NON	COM_CONS_DELIB	NON	\N
ORGEXT	408	-1	2022-04-22 00:00:00	\N	\N	Art. L. 1432-3 du code de la santé publique	\N	18	Mandat sénatorial	ACTIF	\N	\N	conseil d'administration de l'agence régionale de santé	\N	du 	Président du Sénat parmi les membres de la commission des affaires sociales en priorité	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	\N	LEG	NON	CONS_ADMIN	NON	408
ORGEXT	329	329	\N	\N	\N	loi n° 2003-721 du 1er août 2003 article 50\r\nordonnance n° 2014-1555 du 22 décembre 2014\r\ndécret n° 2014-1571 articles 7 et 9	\N	1	Cinq ans sous réserve du mandat sénatorial. En cas de remplacement, jusqu'au terme du mandat.	ACTIF	\N	\N	conseil d'administration de Business France	\N	du 	Désignation par le Sénat sur proposition de la commission des affaires économiques (article 9 du Règlement).	\N	\N	\N	\N	OUI	LOI	NEANT	\N	2015-01-23 11:53:00	2015-01-27 17:05:07	LEG	NON	INDETERMINEE	NON	329
ORGEXT	330	330	2015-01-15 00:00:00	\N	\N	loi n° 46-2196 du 11 octobre 1946 créant une Caisse nationale des lettres. \r\ndécret n° 2014-1435 du 1er décembre 2014 relatif au Centre national du livre. article 4\r\nLégalisé par la loi n° 2018-699 du 3 août 2018	\N	1	Trois ans renouvelable sous réserve du mandat parlementaire.	ACTIF	\N	\N	Conseil d'administration du Centre national du livre	\N	du	Un sénateur, désigné par le Sénat	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2015-03-13 15:55:13	2019-02-25 17:52:46	LEG	NON	INDETERMINEE	NON	330
ORGEXT	352	352	2016-10-20 00:00:00	2017-01-27 00:00:00	\N	Créé par l'article 1er de la loi n° 2016-297 du 14 mars 2016 relative à la protection de l'enfant - Présence de parlementaires prévue par l'article D. 148-2 du code de l'action sociale et des familles\r\nRefus de désigner du Président du Sénat - lettre du 26 octobre 2016 \r\nDécret n° 2017-96 a modifié la composition en excluant la présence de parlementaires	\N	2	Trois ans, renouvelable une fois	ANCIEN	\N	\N	Conseil national de la protection de l'enfance	\N	\N	Président du Sénat	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	2016-10-27 10:59:49	2017-10-11 12:04:58	REG	NON	INDETERMINEE	NON	352
ORGEXT	353	353	2016-10-20 00:00:00	2017-01-23 00:00:00	\N	Art. 3 du décret n° 2016-1377 du 12 octobre 2016 \r\nRefus de désigner du Président du Sénat, lettre du 26 octobre 2016\r\nComposition modifiée par le décret n° 2017-59 du 23 janvier 2017 	\N	2	Trois ans, renouvelable une fois	ANCIEN	\N	\N	Conseil d'orientation des politiques de jeunesse	\N	\N	\N	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	2016-10-27 11:17:28	2017-10-11 12:12:27	REG	NON	INDETERMINEE	NON	353
ORGEXT	354	354	2016-10-20 00:00:00	2018-08-03 00:00:00	\N	Art. R. 20-44-28-1 du code des postes et des communications électroniques\r\nRefus de désigner du Président du Sénat le 26 octobre 2016	\N	2	mandat parlementaire	ACTIF	\N	\N	Comité national de dialogue de l'Agence nationale des fréquences 	\N	\N	\N	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	2016-10-27 11:23:43	2017-04-04 16:50:02	REG	NON	INDETERMINEE	NON	354
ORGEXT	369	369	2017-06-02 00:00:00	\N	\N	Art. L. 213-8 du code de l'environnement\r\nArt. D. 213-17 et D. 213-20 du code de l'environnement	\N	1	6 ans	ACTIF	\N	\N	Comité de bassin Adour-Garonne	\N	du	\N	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2017-06-07 10:14:15	\N	LEG	NON	INDETERMINEE	NON	369
ORGEXT	370	370	\N	\N	\N	Art. L. 213-8 du code de l'environnement\r\nArt. D. 213-17 et D. 213-20 du code de l'environnement	\N	1	6 ans	ACTIF	\N	\N	Comité de bassin Artois-Picardie	\N	du	\N	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2017-06-07 10:34:41	\N	LEG	NON	INDETERMINEE	NON	370
ORGEXT	371	371	2017-06-02 00:00:00	\N	\N	Art. L. 213-8 du code de l'environnement\r\nArt. D. 213-17 et D. 213-20 du code de l'environnement	\N	1	6 ans	ACTIF	\N	\N	Comité de bassin Loire-Bretagne	\N	du	\N	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2017-06-07 10:35:32	2017-06-07 10:37:25	LEG	NON	INDETERMINEE	NON	371
ORGEXT	372	372	2017-06-02 00:00:00	\N	\N	Art. L. 213-8 du code de l'environnement\r\nArt. D. 213-17 et D. 213-20 du code de l'environnement	\N	1	6 ans	ACTIF	\N	\N	Comité de bassin Rhin-Meuse	\N	du	\N	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2017-06-07 10:36:23	\N	LEG	NON	INDETERMINEE	NON	372
ORGEXT	373	373	2017-06-02 00:00:00	\N	\N	Art. L. 213-8 du code de l'environnement\r\nArt. D. 213-17 et D. 213-20 du code de l'environnement	\N	1	6 ans	ACTIF	\N	\N	Comité de bassin Rhône-Méditerranée	\N	du	\N	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2017-06-07 10:37:34	\N	LEG	NON	INDETERMINEE	NON	373
ORGEXT	374	374	2017-06-02 00:00:00	\N	\N	Art. L. 213-8 du code de l'environnement\r\nArt. D. 213-17 et D. 213-20 du code de l'environnement	\N	1	6 ans	ACTIF	\N	\N	Comité de bassin Seine-Normandie	\N	du	\N	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2017-06-07 10:38:28	\N	LEG	NON	INDETERMINEE	NON	374
ORGEXT	375	375	2017-06-09 00:00:00	\N	\N	Art. L. 142-1 du code de l'action sociale et des familles - Article 69 de la loi n° 2015-1776  du 28 décembre 2015 relative à l'adaptation de la société au vieillissementArt. D. 141-2 et D. 141-3 du code de l'action sociale et des famillesPour le Sénat, la parité s'apprécie sur l'ensemble des trois formations spécialisées du Haut conseil.Légalisé par la loi n° 2018-699 du 3 août 2018	\N	1	Jusqu'au prochain renouvellement sénatorial	ACTIF	\N	\N	Haut conseil de la famille, de l'enfance et de l'âge - famille	\N	du	Président du Sénat (art. D. 141-2 du code de l'action sociale et des familles)	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2017-06-13 11:40:00	2019-02-26 15:11:19	LEG	OUI	INDETERMINEE	NON	375
ORGEXT	376	376	2017-06-09 00:00:00	\N	\N	Article 69 de la loi n° 2015-1776  du 28 décembre 2015 relative à l'adaptation de la société au vieillissement\r\nArt. D. 141-2 et D. 141-3 du code de l'action sociale et des familles\r\nPour le Sénat, la parité s'apprécie sur l'ensemble des trois formations spécialisées du Haut conseil.\r\nLégalisé par la loi n° 2018-699 du 3 août 2018	\N	1	Jusqu'au prochain renouvellement sénatorial	ACTIF	\N	\N	Haut conseil de la famille, de l'enfance et de l'âge - enfance	\N	du	Président du Sénat (art. D. 141-2 du code de l'action sociale et des familles)	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2017-06-13 11:47:43	2019-02-26 15:10:06	LEG	OUI	INDETERMINEE	NON	376
ORGEXT	377	377	2017-06-09 00:00:00	\N	\N	Article 69 de la loi n° 2015-1776  du 28 décembre 2015 relative à l'adaptation de la société au vieillissement\r\nArt. D. 141-2 et D. 141-3 du code de l'action sociale et des familles\r\nPour le Sénat, la parité s'apprécie sur l'ensemble des trois formations spécialisées du Haut conseil.\r\nLégalisé par la loi n° 2018-699 du 3 août 2018 - art. L. 142-1 du code de l'action sociale et des familles	\N	1	Jusqu'au prochain renouvellement sénatorial	ACTIF	\N	\N	Haut conseil de la famille, de l'enfance et de l'âge - âge	\N	du	Président du Sénat (art. D. 141-2 du code de l'action sociale et des familles)	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2017-06-13 11:50:23	2019-02-26 15:08:54	LEG	OUI	INDETERMINEE	NON	377
ORGEXT	382	382	2017-11-30 00:00:00	2022-06-29 00:00:00	\N	Art. 113 de la loi n° 2017-256 du 28 février 2017 de programmation relative à l'égalité réelle outre-mer et portant autres dispositions en matière sociale et économique - Décret n° 2017-1592 du 21 novembre 2017 - Rapport remis le 15 nov. 2018 - OEP supprimé par échange de mails le 29 juin 2022	\N	3	Mandat sénatorial	ACTIF	\N	\N	Commission relative aux mesures d'indemnisation des victimes des essais nucléaires français	\N	de la 	Président du Sénat - décision du cabinet le 30 novembre 2017	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2017-11-30 15:06:54	\N	LEG	OUI	INDETERMINEE	NON	382
ORGEXT	2000	2000	2018-11-22 00:00:00	\N	\N	Art. L. 542-12-1 A du code de l'environnement	\N	1	5 ans	ACTIF	\N	\N	Conseil d'administration de l'agence nationale pour la gestion des déchets radioactifs	\N	du	1 député et 1 sénateur désignés par l'OPECST	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2018-11-29 10:37:03	\N	LEG	NON	INDETERMINEE	NON	2000
ORGEXT	10008	-1	2019-12-01 00:00:00	\N	\N	\N	\N	0	\N	ACTIF	\N	\N	Office national des forêts	\N	\N	\N	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	\N	NEANT	NON	CONS_ADMIN	NON	\N
ORGEXT	324	324	2014-08-01 00:00:00	2020-12-07 00:00:00	\N	loi n¿ 2009-1436 du 24 novembre 2009 p¿nitentiaire (article 7) Loi du 3 ao¿t 2018 - Supprimé loi ASAP n° 2020-1525 du 7 décembre 2020	\N	2	Quatre ans (sous r¿serve du mandat parlementaire)	ACTIF	\N	\N	Observatoire de la r¿cidive et de la d¿sistance	\N	de l'	Un titulaire et un suppl¿ant d¿sign¿s par le pr¿sident du S¿nat puis nomm¿s par arr¿t¿ du garde des sceaux	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2014-09-12 17:27:37	2017-09-13 16:29:50	LEG	OUI	INDETERMINEE	NON	324
ORGEXT	351	351	2016-09-20 00:00:00	2018-08-03 00:00:00	\N	Art. D. 214-2 du code de la route (décret n° 2016-815 du 17 juin 2016). (L'article 26 de la loi n° 2015-990 du 6 août 2015 a prévu la remise d'un rapport au Parlement présentant les modifications à apporter à la composition du CSER et prévoyant la présence de parlementaire au sein de ce conseil) 	\N	2	mandat parlementaire	ACTIF	\N	\N	Conseil supérieur de l'éducation routière	\N	du	Sénat sur proposition de la commission des lois (art. 9 du Règlement)	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	2016-09-21 10:22:13	2017-09-13 15:42:53	REG	OUI	INDETERMINEE	NON	351
ORGEXT	356	356	\N	\N	\N	Décret n° 2016-1364 du 13 octobre 2016	\N	1	Mandat parlementaire	ACTIF	\N	\N	Conseil consultatif de la garde nationale	\N	du	Par le Président du Sénat\r\nRefus de nommer - courrier du 20 décembre 2016\r\nLégalisé par la loi n° 2018-607 du 13 juillet 2018 (art. 21)	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2017-10-09 10:59:44	2019-02-25 12:34:08	LEG	NON	INDETERMINEE	NON	356
ORGEXT	349	349	2016-07-04 00:00:00	\N	\N	Art. 144 de la loi n° 2015-1785 du 29 décembre 2015 de finances pour 2016 (codifié à l'art. L. 435-1 du code de la construction et de l'habitation)\r\nDécret n°2016-901 du 1er juillet 2016 portant création du fonds national des aides à la pierre	\N	1	3 ans (sous réserve du mandat parlementaire, renouvelable)	ACTIF	\N	\N	Conseil d'administration du fonds national des aides à la pierre	\N	du	Sénat sur proposition de la commission des affaires économiques	\N	\N	\N	\N	OUI	LOI	NEANT	\N	2018-03-28 10:07:21	\N	LEG	NON	INDETERMINEE	NON	349
ORGEXT	390	-1	2019-05-03 00:00:00	\N	\N	Art. L. 1 du code rural et de la pêche maritime	\N	1	Mandat parlementaire	ACTIF	\N	\N	Conseil national de l'alimentation	\N	du	Président du Sénat	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	\N	LEG	NON	INDETERMINEE	NON	390
ORGEXT	10006	-1	\N	\N	\N	\N	\N	0	\N	ACTIF	\N	\N	Aéroports de Paris	\N	\N	\N	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	\N
ORGEXT	10007	-1	\N	\N	\N	\N	\N	0	\N	ACTIF	\N	\N	Conseil constitutionnel	\N	\N	\N	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	\N	NEANT	NON	ORG_CONSTIT	NON	\N
ORGEXT	10020	-1	\N	\N	\N	\N	\N	0	5 ans	ACTIF	\N	\N	Compagnie nationale du Rhône	\N	de la 	\N	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	\N	LEG	NON	CONS_ADMIN	NON	\N
ORGEXT	10021	-1	\N	\N	\N	\N	\N	0	\N	ACTIF	\N	\N	Commissariat à l'énergie atomique et aux énergies alternatives	\N	du	\N	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	\N	LEG	NON	CONS_ADMIN	NON	\N
ORGEXT	DSPB-005	-1	\N	\N	\N	\N	\N	0	6 ans	ACTIF	\N	\N	Autorité nationale des jeux (ANJ)	\N	de l'	\N	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	\N	LEG	NON	AUT_ADMIN_INDEP	NON	\N
ORGEXT	DSPB-007	-1	\N	\N	\N	Article 16 de la loi organique n° 2011-333 du 29 mars 2011 relative au Défenseur des droits	\N	0	6 ans renouvelable	ACTIF	\N	\N	Défenseur des droits 	\N	du 	\N	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	\N	NEANT	NON	AUT_ADMIN_INDEP	NON	\N
ORGEXT	10024	-1	2020-06-01 00:00:00	\N	\N	Art. L. 52-14 du code électoral	\N	0	5 ans	ACTIF	\N	\N	Commission nationale des comptes de campagne et des financements politiques	\N	de la 	\N	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	\N	LEG	NON	AUT_ADMIN_INDEP	NON	\N
ORGEXT	10025	-1	2020-12-01 00:00:00	\N	\N	\N	\N	0	3 ans. Renouvelable.	ACTIF	\N	\N	Pôle emploi	\N	de 	\N	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	\N	LEG	NON	CONS_ADMIN	NON	\N
ORGEXT	10026	-1	2020-07-01 00:00:00	\N	\N	\N	\N	0	4 ans. Renouvelable une fois.	ACTIF	\N	\N	Institut national de recherche pour l'agriculture, l'alimentation et l'environnement	\N	de l'	\N	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	\N	NEANT	NON	CONS_ADMIN	NON	\N
ORGEXT	10027	-1	2020-10-01 00:00:00	\N	\N	Loi n° 2007-1545 du 30 octobre 2007	\N	0	6 ans. Non renouvelable.	ACTIF	\N	\N	Contrôleur général des lieux de privation de liberté	\N	\N	\N	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	\N	LEG	NON	AUT_ADMIN_INDEP	NON	\N
ORGEXT	397	-1	2020-12-14 00:00:00	\N	\N	II bis art. L. 253-8 du code rural et de la pêche maritime (loi n° 2020-1578 du 14 décembre 2020) - Un membre de l'OPECST et un membre de l'opposition	\N	4	\N	ACTIF	\N	\N	Conseil de surveillance chargé du suivi et du contrôle de la recherche et de la mise en oeuvre d'alternatives aux produits phytopharmaceutiques contenant une ou des substances actives de la famille des néonicotinoïdes 	\N	du 	Président du Sénat	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	\N	LEG	OUI	OEP	STATUTAIRE	\N
ORGEXT	DSPB-008	-1	\N	\N	\N	\N	\N	0	6 ans	ACTIF	\N	\N	Conseil général de la Banque de France	\N	L.142-3 du code monétaire et financier	Deux membres nommés par le président du Sénat, compte tenu de leur compétence et de leur expérience professionnelle dans les domaines financier ou économique	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	\N	NEANT	NON	COM_CONS_DELIB	NON	\N
ORGEXT	DSPB-009	-1	\N	\N	\N	\N	\N	0	3 ans non renouvelable	ACTIF	\N	\N	Conseil supérieur des chambres régionales des comptes	\N	L. 220-13 du code des juridictions financières	Personnalité qualifiée qui n'exerce pas de mandat électif, désignée pour une période de trois ans non renouvelable par le Président du Sénat	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	\N	NEANT	NON	COM_CONS_DELIB	NON	\N
ORGEXT	396	-1	2021-01-01 00:00:00	\N	\N	Art. 15 de la loi n° 2019-1480 du 28 décembre 2019, décret n° 2020-1537 du 8 décembre 2020	\N	2	3 ans (durée de l'expérimentation)	ACTIF	\N	\N	comité de pilotage institué par la loi visant à agir contre les violences au sein de la famille	\N	du 	Président du Sénat	\N	\N	\N	\N	OUI	LOI	NEANT	\N	\N	\N	LEG	OUI	OEP	STATUTAIRE	396
ORGEXT	10029	-1	2009-01-22 00:00:00	\N	\N	Art. 2 de l'ordonnance n° 2009-79 du 22 janvier 2009	\N	0	\N	ACTIF	\N	\N	Autorité des normes comptables	\N	de l'	\N	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	\N	LEG	NON	INDETERMINEE	NON	\N
ORGEXT	DSPB-013	-1	2021-09-30 00:00:00	\N	\N	\N	\N	2	Mandat de 2 ans renouvelable 1 fois	ACTIF	\N	\N	Conseil des prélèvements obligatoires	\N	\N	Nomination par le Président du Sénat d'1 membre après avis du président et du rapporteur général de la commission du Sénat chargée des finances et d'1 membre après avis du président de la commission du Sénat chargée des affaires sociales	\N	\N	\N	\N	\N	NEANT	ALERTE	\N	\N	\N	NEANT	NON	COM_CONS_DELIB	NON	\N
ORGEXT	DSPB-014	-1	2021-10-06 00:00:00	\N	\N	\N	\N	0	Mandat de 6 ans non renouvelable	ACTIF	\N	\N	commission de régulation de l'énergie	\N	Art. L. 132-1 et L. 132-2 du code de l'énergie	Nomination par le Président du Sénat	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	\N	NEANT	NON	AUT_ADMIN_INDEP	NON	\N
ORGEXT	10035	-1	2022-10-01 00:00:00	\N	\N	Art. L. 621-2 du code monétaire et financier	\N	0	\N	ACTIF	\N	\N	Autorité des marchés financiers	\N	de l'	Art. 13, avis de la commission des finances	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	\N	LEG	NON	AUT_PUB_INDEP	NON	\N
ORGEXT	10036	-1	2016-01-01 00:00:00	\N	\N	Art. L. 1261-5 du code des transports	\N	0	\N	ACTIF	\N	\N	Autorité de régulation des transports	\N	de l'	Art. 13 C	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	\N	LEG	NON	AUT_PUB_INDEP	NON	\N
ORGEXT	410	-1	2023-01-18 00:00:00	\N	\N	Art. L. 147-12 et D. 147-34 du code de l'action sociale et des familles	\N	1	Mandat parlementaire	ACTIF	\N	\N	Conseil national de l'adoption	\N	du 	\N	\N	\N	\N	\N	OUI	LOI	NEANT	\N	\N	\N	LEG	NON	COM_CONS_DELIB	NON	410
ORGEXT	409	-1	2022-09-01 00:00:00	\N	\N	IX de l'art. 6 de la loi n° 2020-289 du 23 mars 2020 de finances rectificative pour 2020	\N	3	Mandat parlementaire	ACTIF	\N	\N	Comité chargé du suivi des mesures de soutien financier aux entreprises confrontées à l'épidémie de covid-19 et aux perturbations économiques engendrées par les conséquences de l'agression de la Russie contre l'Ukraine	\N	du 	\N	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	\N	LEG	NON	OEP	NON	409
ORGEXT	320	320	2014-04-30 00:00:00	\N	\N	Article l. 1212-1 du code général des collectivités territoriales)Voir aussi le décret  d'application n° 2014-446 du 30 avril 2014	\N	4	Trois ans (sous réserve du mandat sénatorial)	ACTIF	\N	\N	Conseil national d'évaluation des normes	\N	du 	Président du Sénat	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	2014-05-05 08:33:38	2019-03-18 12:18:16	LEG	OUI	INDETERMINEE	NON	320
ORGEXT	265	265	\N	\N	\N	Article 4 du décret n° 2010-596 du 3 juin 2010 relatif à la Conférence nationale de l'industrie\r\net décret n° 2013-162 du 22 février 2013\r\nPrésence de parlementaires supprimée par le décret n° 2017-1581 du 17 novembre 2017\r\nLégalisé par la loi n° 2018-699 du 3 août 2018 - art. 32	\N	1	durée du mandat parlementaire	ACTIF	\N	\N	Conseil national de l'industrie	\N	du 	Président du Sénat	\N	\N	\N	\N	OUI	LOI	NEANT	\N	\N	2019-02-25 18:43:41	LEG	OUI	INDETERMINEE	NON	265
ORGEXT	74	74	\N	2011-09-08 00:00:00	\N	Décret n° 73-278 du 13 mars 1973/Décret n° 81-978 du 77-623 du 6 juin 1977/Décret n° 81-978 du 29 octobre 1981/Décret n° 82-531 du 22 juin 1982/Décret n° 82-918 du 26 octobre 1982/Décret n° 85-140 du 28 janvier 1985/Décret n° 87-137 du 2 mars 1987\r\nSupprimé par le décret n° 2011-1073 du 8 septembre 2011 relatif à la suppression de commisssions et instances administratives \r\n	Energie	1	5 ans	ANCIEN	\N	\N	Conseil supérieur de la sûreté et de l'information nucléaires	\N	du 	Sénat sur proposition de la commission des affaires économiques	Industrie	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	74
ORGEXT	334	334	2015-03-23 00:00:00	\N	\N	Art. L. 142-5 du code de la constructiuon décret n° 2015-328 du 23 mars 2015\r\narticle R. 143-4 du code de la construction et de l'habitation	\N	1	trois ans renouvelable (sous réserve du mandat parlementaire)	ACTIF	\N	\N	Conseil supérieur de la construction et de l'efficacité énergétique	\N	du 	par le Sénat sur proposition de la commission des affaires économiques (article 9 du Règlement) démission de M CALVET le 5 octobre 2015.	\N	\N	\N	\N	OUI	NEANT	ALERTE	\N	2015-04-03 10:44:15	2018-03-20 11:16:51	LEG	OUI	INDETERMINEE	NON	334
ORGEXT	131	131	\N	\N	\N	Arrêté du 24 octobre 1994 relatif au Conseil national de l'enseignement supérieur privé (JO du 3 novembre 1994)\r\nConsidéré comme abrogé par décret n° 2006-672 du 8 juin 2006	Culture et éducation	2	3 ans (renouvelable une fois)	ANCIEN	\N	\N	Conseil national de l'enseignement supérieur privé	\N	du 	Président du Sénat (un titulaire - par convention, pour la première nomination: le rapporteur spécial de la commission des finances- et un suppléant- le rapporteur pour avis de la commission des affaires culturelles)	\N	\N	\N	\N	OUI	NEANT	NEANT	\N	\N	\N	NEANT	NON	INDETERMINEE	NON	131
ORGEXT	322	322	2014-04-29 00:00:00	\N	\N	article 92 de la loi n° 2013-1278 du 29 décembre 2013 de finances pour 2014\r\narticle 10 décret n° 2014-444 du 29 avril 2014 	\N	2	celle du mandat parlementaire	ACTIF	\N	\N	Comité national d'orientation et de suivi du fonds de soutien aux collectivités territoriales et à certains \r\nétablissements publics ayant souscrit des contrats de prêt ou des contrats financiers structurés à risque	\N	du	Un sénateur titulaire et un sénateur suppléant désignés directement par la commission des finances du Sénat.	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	\N	LEG	NON	INDETERMINEE	NON	322
ORGEXT	323	323	2014-05-23 00:00:00	\N	\N	décret n° 2014-530 du 22 mai 2014, devenu l'article R. 1512-13 du code des transports\r\nLégalisé par la loi n° 2018-699 du 3 août 2018 (art. L. 1512-19 du code des transports)	\N	1	Trois ans renouvelable	ACTIF	\N	\N	Conseil d'administration de l'Agence de financement des infrastructures de transport de France	\N	du	\N	\N	\N	\N	\N	OUI	DECRET	ALERTE	\N	\N	2019-02-25 12:40:36	LEG	NON	INDETERMINEE	NON	323
ORGEXT	109	109	\N	\N	\N	Décret n° 89-647 du 12 septembre 1989\r\nDécret n° 61-652 du 20 juin 1961 relatif à la composition de la commission supérieure chargée d'étudier la codification et la simplification des textes législatifs et réglementaires, abrogé./Décret n° 82-227 du 4 mars 1982.\r\nLégalisé par la loi n° 2018-699 du 3 août 2018 - Art. L. 351-1 du code des relations entre le public et l'administration	Justice, législation générale	1	Fin du mandat sénatorial	ACTIF	\N	\N	Commission supérieure de codification (ancienne commission supérieure de codification et de simplification des textes législatifs et réglementaires)	\N	de la 	Un sénateur désigné	Premier Ministre	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2019-02-25 12:29:45	LEG	OUI	INDETERMINEE	NON	109
ORGEXT	157	157	\N	\N	\N	Décret n° 97-817 du 5 septembre 1997 érigeant l'Institut des hautes études de défense nationale en établissement public remplacé par le décret n° 2009-752 du 23 juin 2009puis par le décret n° 2011-1899 du 19 décembre 2011 codifié à l'article R.1132-20 et suivants du code de la défense\r\nLégalisé par la loi n° 2018-699 du 3 août 2018 - art. L. 1132-1 du code de la défense	Défense	1	Mandat parlementaire	ACTIF	\N	\N	Conseil d'administration de l'Institut des hautes études de défense nationale (IHEDN)	\N	du 	Sénat sur proposition de la commission des affaires étrangères	Défense	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	2019-02-25 16:44:54	LEG	NON	INDETERMINEE	NON	157
ORGEXT	81	81	\N	\N	\N	Décret n° 83-465 du 8 juin 1983 relatif au Conseil national de l'habitat\r\nArticle R*361-4 du code de la construction et de l'habitation\r\nLégalisé par la loi n° 2018-699 du 3 août 2018 - art. L. 361-1 du code de la construction et de l'habitation\r\n	Environnement, logement, urbanisme	2	3 ans sous réserve du mandat sénatorial	ACTIF	\N	\N	Conseil national de l'habitat	\N	du 	Sénat sur proposition de la commission des affaires économiques (1 titulaire et 1 suppléant)	Logement	\N	\N	\N	OUI	LOI	ALERTE	\N	\N	2019-02-25 18:39:02	LEG	OUI	INDETERMINEE	NON	81
ORGEXT	360	360	2017-05-16 00:00:00	\N	\N	Article 2 du décret n° 2017-693 du 3 mai 2017 \r\n"Un député et un sénateur peuvent être désignés respectivement par le président de l'Assemblée nationale et le président du Sénat. Le mandat du député prend fin avec la législature au titre de laquelle il a été élu, le mandat du sénateur prend fin lors de chaque renouvellement partiel du Sénat."\r\nLégalisé par la loi n° 2018-699 du 3 août 2018 - art. L. 123-2 du code de la sécurité intérieure	\N	1	renouvelé à chaque renouvellement triennal du Sénat	ACTIF	\N	\N	Conseil scientifique sur les processus de radicalisation	\N	\N	Président du Sénat	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2017-06-06 16:08:59	2019-02-26 11:05:50	LEG	NON	INDETERMINEE	NON	360
ORGEXT	386	386	2018-10-25 00:00:00	\N	\N	Art. L. 221-6-1 du code de l'environnement (loi n° 2018-699 du 3 août 2018)	\N	1	trois ans	ACTIF	\N	\N	Conseil national de l'air	\N	du	\N	\N	\N	\N	\N	OUI	LOI	ALERTE	\N	2019-02-26 15:52:23	\N	LEG	NON	INDETERMINEE	NON	\N
ORGEXT	381	381	2018-08-03 00:00:00	\N	\N	Art. 31 de la loi n° 2018-699 du 3 août 2018 	\N	1	mandat parlementaire	ACTIF	\N	\N	Office franco-québécois pour la jeunesse	\N	de l'	Président du Sénat	\N	\N	\N	\N	OUI	LOI	NEANT	\N	2019-02-26 15:57:40	\N	LEG	NON	INDETERMINEE	NON	\N
ORGEXT	115	115	\N	\N	\N	Art L.452-6 et suivants du code de l'éducation (anciennement loi n°90-598 du 6 juillet 1990 portant création de l'Agence pour l'enseignement français à l'étranger) et Art D.452-3 et suivants du même code (anciennement décret n°2003-1288 du 23 décembre 2003) \r\nLoi n° 2010-873 du 27 juillet 2010 relative à l'action extérieure de l'État (art.2)	Affaires étrangères	2	3 ans (remplacement pour la durée du mandat restant à courir, mandat renouvelable)	ACTIF	\N	\N	Conseil d'administration de l'Agence pour l'enseignement français à l'étranger	\N	du 	Sénat sur proposition de la commission des affaires étrangères et de la commission de la culture	AFFAIRES ETRANGERES	\N	\N	\N	OUI	NEANT	ALERTE	\N	\N	2014-11-25 17:07:19	LEG	NON	INDETERMINEE	NON	115
ORGEXT	411	-1	2023-11-29 00:00:00	\N	\N	Art. 54 de la loi n° 2023-703 du 1er août 2023 - Pluralisme	\N	2	Mandat parlementaire	ACTIF	\N	\N	commission parlementaire d'évaluation de la politique du Gouvernement d'exportation de matériels de guerre et de matériels assimilés	\N	de la 	\N	\N	\N	\N	\N	OUI	LOI	NEANT	\N	\N	\N	LEG	NON	COM_CONS_DELIB	NON	411
ORGEXT	412	-1	2024-02-15 00:00:00	\N	\N	XI de l'art. 10 de la loi n° 2023-380 du 19 mai 2023 relative aux jeux Olympiques et Paralympiques de 2024	\N	2	Mandat parlementaire	ACTIF	\N	\N	comité de pilotage chargé de l'expérimentation prévue à l'article 10 de la loi n° 2023-380 du 19 mai 2023 relative aux jeux Olympiques et Paralympiques de 2024 	\N	du 	\N	\N	\N	\N	\N	OUI	LOI	NEANT	\N	\N	\N	LEG	NON	OEP	NON	412
\.


--
-- Data for Name: orgthe; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY orgthe (orgcod, thecle) FROM stdin;
155	0
204	0
22	0
2	1
205	1
206	1
207	1
245	1
285	1
320	1
321	1
322	1
34	1
70	1
1	2
110	2
114	2
251	2
287	2
36	2
37	2
38	2
50bis	2
95	2
123	3
136	3
177	3
203	3
207	3
252	3
257	3
264	3
269	3
290	3
303	3
307	3
315	3
605	3
606	3
90	3
93	3
98	3
115	4
121	4
126	4
129	4
154	4
16	4
17	4
191	4
23	4
234	4
241	4
273	4
274	4
292	4
318	4
328	4
329	4
338	4
342	4
35	4
118	5
165	5
195	5
196	5
202	5
203	5
205	5
210	5
215	5
22	5
235	5
237	5
241	5
275	5
286	5
337	5
42	5
44	5
52	5
86	5
12	7
152	7
155	7
169	7
172	7
181	7
184	7
185	7
219	7
230	7
231	7
245	7
253	7
262	7
263	7
282	7
284	7
29	7
294	7
311	7
314	7
333	7
334	7
72	7
78	7
81	7
246	9
42	9
612	9
86	9
111	10
119	10
126	10
13	10
143	10
144	10
153	10
154	10
16	10
17	10
173	10
179	10
187	10
188	10
192	10
20	10
200	10
201	10
21	10
213	10
216	10
218	10
224	10
228	10
236	10
34	10
602	10
608	10
66	10
67	10
69	10
73	10
87	10
100	12
101	12
102	12
103	12
104	12
108	12
11	12
125	12
131	12
133	12
134	12
138	12
145	12
156	12
167	12
171	12
186	12
198	12
208	12
222	12
23	12
240	12
246	12
249	12
250	12
273	12
274	12
276	12
278	12
292	12
304	12
305	12
309	12
317	12
330	12
341	12
49	12
56	12
84	12
89	12
91	12
99	12
149	13
234	13
247	13
4	13
52	13
109	14
175	14
195	14
202	14
204	14
215	14
22	14
235	14
269	14
3	14
324	14
326	14
4	14
42	14
604	14
86	14
96	14
97	14
108	15
112	15
197	15
239	15
272	15
278	15
282	15
30	15
304	15
331	15
610	15
91	15
12	16
123	16
152	16
155	16
172	16
184	16
185	16
219	16
230	16
231	16
243	16
252	16
257	16
258	16
29	16
305	16
311	16
333	16
334	16
346	16
72	16
78	16
81	16
111	17
119	17
126	17
13	17
143	17
144	17
153	17
154	17
16	17
17	17
173	17
179	17
187	17
188	17
192	17
20	17
200	17
201	17
21	17
213	17
216	17
218	17
224	17
228	17
236	17
244	17
248	17
254	17
259	17
263	17
265	17
268	17
275	17
277	17
306	17
312	17
322	17
34	17
44	17
602	17
608	17
66	17
69	17
73	17
87	17
140	18
183	18
229	18
270	18
289	18
310	18
32	18
33	18
166	19
204	19
236	19
107	20
116	20
123	20
124	20
127	20
136	20
163	20
199	20
214	20
225	20
232	20
243	20
247	20
256	20
260	20
267	20
268	20
272	20
291	20
296	20
30	20
302	20
315	20
335	20
337	20
43	20
53	20
603	20
65	20
97	20
132	21
135	21
135 bis	21
159	21
176	21
18	21
189	21
217	21
221	21
223	21
255	21
261	21
294	21
295	21
323	21
332	21
336	21
75	21
9	21
94	21
127	22
128	22
130	22
137	22
146	22
147	22
148	22
149	22
150	22
151	22
162	22
164	22
166	22
170	22
177	22
178	22
180	22
182	22
190	22
194	22
209	22
211	22
212	22
213	22
256	22
267	22
291	22
325	22
327	22
46	22
50	22
607	22
64	22
67	22
76	22
77	22
88	22
113	23
122	23
139	23
142	23
174	23
43	23
8	23
108	24
11	24
125	24
131	24
138	24
145	24
156	24
171	24
186	24
198	24
208	24
222	24
23	24
242	24
292	24
307	24
313	24
316	24
319	24
330	24
331	24
49	24
609	24
84	24
91	24
127	25
128	25
130	25
137	25
146	25
147	25
148	25
149	25
150	25
151	25
162	25
164	25
166	25
170	25
177	25
178	25
180	25
182	25
190	25
194	25
209	25
211	25
212	25
244	25
296	25
46	25
50	25
607	25
64	25
67	25
76	25
77	25
88	25
248	28
157	29
158	29
160	29
168	29
238	29
264	29
272	29
289	29
31	29
342	29
141	30
206	30
220	30
227	30
255	30
285	30
287	30
288	30
321	30
323	30
333	30
293	31
302	31
308	31
605	31
606	31
90	31
93	31
98	31
120	32
161	32
181	32
193	32
233	32
24	32
25	32
253	32
271	32
334	32
39	32
74	32
82	32
155	33
179	33
216	33
218	33
265	33
312	33
44	33
\.


--
-- Data for Name: pcs; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY pcs (pcscod, pcslil, pcs42cod) FROM stdin;
3000	Cadres et Professions intellectuelles supérieures	30
3100	Professions libérales	31
3112	Medecins libéraux généralistes	31
3113	Chirurgiens-dentistes (libéraux ou salariés)	31
3115	Vétérinaires (libéraux ou salariés)	31
3116	Pharmaciens libéraux	31
3121	Avocats	31
3128	Huissiers de justice, officiers ministériels et professions libérales divers	31
3300	Cadres de la fonction publique	33
3311	Personnels de direction de la fonction publique	33
3313	Magistrats	33
3400	Professeurs, professions scientifiques	34
3431	Médecins hospitaliers (sans activité libérale)	34
3500	Professions de l'information des arts et spectacles	35
3511	Journalistes, secrétaires de rédaction	35
3600	Cadres d'entreprise	36
3700	Cadres administratifs et commerciaux d'entreprise	37
3735	Cadres de la publicité; cadres des relations publiques	37
3800	Ingenieurs et cadres techniques d'entreprise	38
4200	Professeurs des écoles, instituteurs et assimilés	42
4300	Professions intermédiaires de la santé et du travail social	43
4400	Clergé, religieux	44
4500	Professions intermédiaires administratives de la fonction publique	45
4600	Professions intermédiaires administratives et commerciales d'entreprise	46
4700	Techniciens	47
4800	Contremaitre et agents de maitrise	48
5200	Employés civils et agents de service de la fonction publique	52
5300	Policiers et militaires	53
5400	Employés administratifs d'entreprise	54
5500	Employés de commerce	55
5600	Personnels des services directs aux particuliers	56
6000	Ouvriers	60
6200	Ouvriers qualifiés de type industriel	62
6300	Ouvriers qualifiés de type artisanal	63
6400	Chauffeurs	64
6500	Ouvriers qualifiés de la manutention, du magasinage et des transports	65
6700	Ouvriers non qualifiés de type industriel	67
6800	Ouvriers non qualifiés de type artisanal	68
6900	Ouvriers agricoles	69
7000	Retraités	70
7100	Anciens agriculteurs exploitants	71
7200	Anciens artisans, commercants, chefs d'entreprise	72
7300	Anciens cadres et professions liberales	73
7400	Anciens cadres	74
7500	Anciens professions intermédiaires	75
7700	Anciens employés	77
7800	Anciens ouvriers	78
8000	Autres personnes sans activité professionnelle	80
8100	Chomeurs n'ayant jamais travaillé	81
8300	Militaires du contingent	83
8400	Elève ou étudiant	84
8500	Personnes diverses sans activité professionnelle de moins de 60 ans (sauf retraités)	85
8600	Personnes diverses sans activité professionnelle de 60 ans et plus (sauf retraités)	86
2100	Artisans	21
2200	Commercants et assimilés	22
2300	Chefs d'entreprise de 10 salaries ou plus	23
1000	Agriculteurs exploitants	10
2000	Artisans, commercants et chefs d'entreprise	20
1100	Agriculteurs sur petite exploitation	11
1200	Agriculteurs sur moyenne exploitation	12
1300	Agriculteurs sur grande exploitation	13
\.


--
-- Data for Name: pcs24; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY pcs24 (pcs24cod, pcs24lib, pcs8cod) FROM stdin;
20	Artisans, Commercants et chefs d'entreprise	2
23	Chefs d'entreprise de 10 salariés ou plus	2
30	Cadres et professions intellectuelles supérieures	3
31	Professions libérales	3
32	Cadres de la fonction publique, professions intellectuelles et artistiques	3
36	Cadres d'entreprise	3
41	Professions intermédiaires de l'enseignement, de la santé, de la fonction publique et assimilés	4
46	Professions intermédiaires administratives et commerciales d'entreprise	4
47	Techniciens	4
48	Contremaitre et agents de maitrise	4
51	Employés de la fonction publique	5
54	Employés administratifs d'entreprise	5
55	Employés de commerce	5
56	Personnels des services directs aux particuliers	5
60	Ouvriers	6
61	Ouvriers qualifiés	6
66	Ouvriers non qualifiés	6
69	Ouvriers agricoles	6
70	Retraités	7
71	Anciens agriculteurs exploitants	7
72	Anciens artisans, commercants, chefs d'entreprise	7
73	Anciens cadres et professions intermédiaires	7
76	Anciens employés et ouvriers	7
80	Aucune profession déclarée ou divers	8
81	Chomeurs n'ayant jamais travaillé	8
82	Inactifs divers (autres que retraités)	8
10	Agriculteurs exploitants	1
21	Artisans	2
22	Commercants et assimilés	2
\.


--
-- Data for Name: pcs42; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY pcs42 (pcs42cod, pcs42lib, pcs24cod) FROM stdin;
30	Cadres et professions intellectuelles supérieures	30
31	Professions libérales	31
33	Cadres de la fonction publique	32
34	Professeurs, professions scientifiques	32
35	Professions de l'information des arts et spectacles	32
36	Cadres d'entreprise	36
37	Cadres administratifs et commerciaux d'entreprise	36
38	Ingénieurs et cadres techniques d'entreprise	36
42	Instituteurs et assimilés	41
43	Professions intermédiaires de la santé et du travail social	41
44	Clergé, religieux	41
45	Professions intermédiaires administratives de la fonction publique	41
46	Professions intermédiaires administratives et commerciales d'entreprise	46
47	Techniciens	47
48	Contremaitre et agents de maitrise	48
52	Employés civils et agents de service de la fonction publique	51
53	Policiers et militaires	51
54	Employés administratifs d'entreprise	54
55	Employés de commerce	55
56	Personnels des services directs aux particuliers	56
60	Ouvriers	60
62	Ouvriers qualifiés de type industriel	61
63	Ouvriers qualifiés de type artisanal	61
64	Chauffeurs	61
65	Ouvriers qualifiés de la manutention, du magasinage et des transports	61
67	Ouvriers non qualifiés de type industriel	66
68	Ouvriers non qualifiés de type artisanal	66
69	Ouvriers agricoles	69
70	Retraités	70
71	Anciens agriculteurs exploitants	71
72	Anciens artisans, commercants, chefs d'entreprise	72
73	Anciens cadres et professions intermédiaires	73
74	Anciens cadres	73
75	Anciens professions intermédiaires	73
77	Anciens employés	76
78	Anciens ouvriers	76
80	Aucune profession déclarée ou divers	80
81	Chomeurs n'ayant jamais travaillé	81
83	Militaires du contingent	82
84	Elève ou étudiant	82
85	Personnes diverses sans activité professionnelle de moins de 60 ans (sauf retraités)	82
86	Personnes diverses sans activité professionnelle de 60 ans et plus (sauf retraités)	82
13	Agriculteurs sur grande exploitation	10
20	Artisans, commercants et chefs d'entreprise	20
21	Artisans	21
22	Commercants et assimilés	22
23	Chefs d'entreprise de 10 salariés ou plus	23
12	Agriculteurs sur moyenne exploitation	10
10	Agriculteurs exploitants	10
11	Agriculteurs sur petite exploitation	10
\.


--
-- Data for Name: pcs8; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY pcs8 (pcs8cod, pcs8lil) FROM stdin;
2	Artisans, commercants et chefs d'entreprise
3	Cadres et professions intellectuelles supérieures
4	Professions intermédiaires
5	Employés
6	Ouvriers
7	Retraités
8	Autres personnes sans activité professionnelle
0	Aucune Profession déclarée ou divers
1	Agriculteurs exploitants
\.


--
-- Data for Name: pcscatpro; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY pcscatpro (catprocod, pcscod, procatprodef, pcscatproid) FROM stdin;
29	7200	DEFAUT	1
31	3800	DEFAUT	2
32	3600	DEFAUT	3
33	5400	DEFAUT	4
34	6000	DEFAUT	5
35	8000	DEFAUT	6
39	7300	DEFAUT	7
39	7700	\N	8
39	7800	\N	9
41	3431	DEFAUT	10
42	3112	DEFAUT	11
43	3112	DEFAUT	12
44	3116	DEFAUT	13
45	3113	DEFAUT	14
46	3115	DEFAUT	15
47	3100	DEFAUT	16
49	7400	DEFAUT	17
51	3121	DEFAUT	18
52	3128	DEFAUT	19
54	3511	DEFAUT	20
55	3735	DEFAUT	21
56	3313	DEFAUT	22
57	3100	DEFAUT	23
59	7400	DEFAUT	24
61	3400	DEFAUT	25
62	4200	DEFAUT	26
63	4200	DEFAUT	27
64	3400	DEFAUT	28
69	7400	DEFAUT	29
71	3311	DEFAUT	30
72	4500	DEFAUT	31
73	4500	DEFAUT	32
74	5300	DEFAUT	33
79	7400	DEFAUT	34
80	8000	DEFAUT	35
10	1000	DEFAUT	36
21	2300	DEFAUT	37
22	2200	DEFAUT	38
23	2200	DEFAUT	39
24	2100	DEFAUT	40
\.


--
-- Data for Name: poicon; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY poicon (poiconid, senmat, typpoiconcod, poiconlib, poiconnumtri, syscredat, sysmajdat) FROM stdin;
711	09010Q	SENAT	Nouveau point de contact	1	2014-04-23 09:57:24	\N
720	14018U	SENAT	Nouveau point de contact	1	2014-08-27 16:32:46	2016-05-26 15:40:05
732	14199E	SENAT	Nouveau point de contact	1	2014-09-28 14:31:41	2016-05-26 14:38:49
786	14251Q	SENAT	Nouveau point de contact	1	2014-09-28 18:32:19	2016-05-26 14:57:27
788	14121F	SENAT	Nouveau point de contact	1	2014-09-28 18:44:07	2016-05-26 14:45:29
794	14201E	SENAT	Nouveau point de contact	1	2014-09-28 18:59:41	2016-05-26 11:49:41
811	14044W	SENAT	Nouveau point de contact	1	2014-09-29 09:08:32	\N
818	11042G	SENAT	Nouveau point de contact	2	2014-10-23 13:23:55	2016-05-26 11:53:31
826	07032N	PERM	Nouveau point de contact	1	2014-10-23 17:13:22	2016-05-26 15:48:53
819	11042G	PERM	Nouveau point de contact	1	2014-10-23 13:23:59	2016-05-26 11:53:31
824	08053X	PERM	Nouveau point de contact	1	2014-10-23 14:39:19	2016-05-26 15:08:52
827	95030B	PERM	Nouveau point de contact	1	2014-10-24 16:36:57	2016-05-26 12:09:58
828	14169X	PERM	Nouveau point de contact	1	2014-10-24 16:44:00	2016-05-26 11:58:58
831	01062T	PERM	Nouveau point de contact	2	2014-10-27 15:25:35	2014-10-27 15:59:11
830	14030Q	PERM	Nouveau point de contact	1	2014-10-27 10:51:22	2016-05-26 15:59:53
832	11066Q	PERM	Nouveau point de contact	1	2014-10-28 16:28:47	2016-05-26 16:21:23
833	14013P	PERM	Nouveau point de contact	1	2014-11-03 11:39:01	2016-05-26 11:30:22
836	14167V	PERM	Nouveau point de contact	1	2014-12-04 23:17:25	2016-05-26 11:34:05
837	14263U	SENAT	Nouveau point de contact	1	2014-12-18 16:18:16	2016-05-26 10:56:17
839	08065C	PERM	Nouveau point de contact	1	2014-12-23 10:51:30	2016-05-26 14:29:02
840	14265W	SENAT	Nouveau point de contact	2	2014-12-29 15:45:40	2017-12-20 09:45:47
841	92045V	SENAT	Nouveau point de contact	1	2015-01-09 15:16:59	2016-05-26 16:21:11
843	14233N	PERM	Nouveau point de contact	2	2015-01-27 11:56:14	2015-01-27 11:56:16
844	87003B	PERM	Nouveau point de contact	1	2015-02-12 15:04:38	2016-05-26 12:06:35
845	14179A	PERM	Nouveau point de contact	1	2015-02-20 16:51:02	2016-05-26 14:42:50
846	14269B	SENAT	Nouveau point de contact	1	2015-03-04 14:32:20	2016-05-26 15:26:05
506	08055A	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 11:16:37
513	08062Y	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:08:41
520	08070Y	SENAT	\N	1	2014-01-30 11:33:53	\N
671	95049N	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:10:33
678	96003C	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 16:24:31
848	14271U	SENAT	Nouveau point de contact	1	2015-04-07 17:15:52	2016-05-26 15:31:14
849	14026U	PERM	Nouveau point de contact	1	2015-04-16 10:42:43	2016-05-26 15:46:03
850	14197C	PERM	Nouveau point de contact	1	2015-04-16 12:44:54	2016-05-26 12:08:29
851	14273W	SENAT	Nouveau point de contact	1	2015-04-22 16:49:30	2016-05-26 15:06:53
852	14275Y	SENAT	Nouveau point de contact	1	2015-05-04 10:27:12	2016-05-26 15:28:39
853	14277B	SENAT	Nouveau point de contact	1	2015-05-04 10:29:04	2016-05-26 14:51:49
857	87003B	AUTRE	Bureau parlementaire	3	2015-05-22 11:43:49	2015-05-22 11:44:15
856	14073Q	PERM	Nouveau point de contact	1	2015-05-19 14:12:52	2016-05-26 14:46:52
859	14281W	SENAT	Nouveles coordonnées	1	2015-06-12 15:35:57	2016-05-26 15:49:38
860	14147R	SENAT	Nouveles coordonnées	2	2015-06-12 15:40:17	2018-03-19 10:15:06
861	01024M	PERM	Nouvelles coordonnées	1	2015-06-30 10:17:33	2016-05-26 12:03:52
862	14265W	PERM	Nouvelles coordonnées	1	2015-06-30 11:46:51	2017-12-20 09:45:47
865	01016M	PERM	Nouvelles coordonnées	1	2015-06-30 16:26:53	2015-06-30 16:28:50
866	14061L	PERM	Nouvelles coordonnées	1	2015-07-01 11:28:01	2015-07-01 11:28:16
871	04065K	AUTRE	Contact	2	2015-07-13 15:16:05	2015-07-13 15:16:17
874	01063U	AUTRE	contact	2	2015-07-13 15:30:39	2015-07-13 15:30:48
873	07030L	AUTRE	contact	2	2015-07-13 15:29:09	2015-07-13 15:29:18
885	11067R	PERM	Nouvelles coordonnées	1	2015-07-17 12:04:28	2016-05-26 15:38:45
886	04049K	PERM	Nouvelles coordonnées	1	2015-07-17 16:06:00	2016-05-26 15:41:49
889	07029T	PERM	Nouvelles coordonnées	1	2015-07-29 10:37:18	2016-05-26 14:49:57
888	14187A	PERM	Nouvelles coordonnées	1	2015-07-21 13:49:38	2016-05-26 15:50:52
892	01007L	PERM	Nouvelles coordonnées	1	2015-09-08 14:03:08	2016-05-26 15:47:02
891	14327T	SENAT	Nouvelles coordonnées	2	2015-09-07 16:16:32	2018-01-08 19:08:33
908	14123H	PERM	Nouvelles coordonnées	1	2015-10-08 16:19:47	2016-05-26 14:40:43
905	11036J	AUTRE	52, rue de Saint-Quentin  59540 Caudry	1	2015-10-02 14:15:12	2016-05-26 16:00:38
910	14219Q	PERM	Nouvelles coordonnées	1	2015-10-12 14:44:05	2016-05-26 14:54:00
911	01047U	PERM	Nouvelles coordonnées	1	2015-10-19 16:58:25	2016-05-26 16:26:49
913	08012N	PERM	Nouvelles coordonnées	1	2015-12-21 17:54:47	2016-05-26 10:59:20
914	14331P	SENAT	Nouvelles coordonnées	1	2016-01-12 09:45:37	2016-05-26 15:53:10
916	04050C	SENAT	Nouvelles coordonnées	1	2016-03-11 18:10:19	2016-05-26 16:23:07
917	14014Q	PERM	Nouvelles coordonnées	1	2016-04-08 09:37:37	2016-05-26 15:48:12
410	04042C	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 11:47:43
541	11030C	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 11:16:48
451	05008E	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 11:16:59
579	11076S	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 11:20:23
766	14065Q	SENAT	Nouveau point de contact	2	2014-09-28 17:31:41	2016-05-26 11:26:11
789	14255U	SENAT	Nouveau point de contact	1	2014-09-28 18:46:12	2016-05-26 11:46:46
655	95015C	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 11:49:00
691	98023Q	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 11:55:54
757	14079W	SENAT	Nouveau point de contact	1	2014-09-28 17:14:20	2016-05-26 11:57:29
570	11065P	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 11:57:38
420	04055H	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 11:58:01
466	08011M	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 11:58:43
712	14012N	SENAT	Nouveau point de contact	1	2014-05-05 10:30:19	\N
713	04090L	SENAT	Nouveau point de contact	1	2014-05-05 10:31:01	\N
714	08064B	SENAT	Nouveau point de contact	1	2014-05-05 10:32:08	\N
721	83042R	SENAT	Nouveau point de contact	1	2014-09-01 10:22:08	2016-05-26 15:08:04
723	14193X	SENAT	Nouveau point de contact	1	2014-09-28 12:32:22	2017-12-20 10:09:31
724	14042U	SENAT	Nouveau point de contact	1	2014-09-28 12:34:20	2017-12-20 14:57:51
725	14195A	SENAT	Nouveau point de contact	2	2014-09-28 12:44:31	2016-05-26 11:51:01
726	14197C	SENAT	Nouveau point de contact	2	2014-09-28 12:54:15	2016-05-26 12:08:29
727	14103D	SENAT	Nouveau point de contact	1	2014-09-28 13:06:30	2016-05-26 14:55:15
728	05004A	SENAT	Nouveau point de contact	1	2014-09-28 13:16:32	\N
733	14030Q	SENAT	Nouveau point de contact	2	2014-09-28 16:40:49	2016-05-26 15:59:55
734	14031R	SENAT	Nouveau point de contact	1	2014-09-28 16:40:49	\N
735	14137P	SENAT	Nouveau point de contact	1	2014-09-28 16:42:03	\N
736	14133K	SENAT	Nouveau point de contact	1	2014-09-28 16:42:03	2016-05-26 11:20:31
737	14105F	SENAT	Nouveau point de contact	2	2014-09-28 16:49:55	2016-05-26 11:32:05
738	14109K	SENAT	Nouveau point de contact	1	2014-09-28 16:49:55	2016-05-26 15:36:22
739	14205J	SENAT	Nouveau point de contact	1	2014-09-28 16:54:08	2016-05-26 15:40:44
787	14253S	SENAT	Nouveau point de contact	1	2014-09-28 18:32:41	2016-05-26 15:20:36
812	04046G	AUTRE	Adresse	2	2014-10-13 10:50:05	2014-10-13 11:02:47
834	14059S	PERM	Nouveau point de contact	1	2014-11-13 17:05:23	2016-05-26 15:40:18
835	08056B	PERM	Nouveau point de contact	1	2014-11-13 17:32:23	2016-05-26 11:23:49
842	14267Y	SENAT	Nouveau point de contact	1	2015-01-26 16:17:48	2016-05-26 11:54:41
863	11046L	PERM	Nouvelles coordonnées	1	2015-06-30 13:02:51	2016-05-26 16:14:32
864	14065Q	PERM	Nouvelles coordonnées	1	2015-06-30 15:25:35	2016-05-26 11:26:11
867	14225N	PERM	Nouvelles coordonnées	1	2015-07-02 12:32:23	2016-05-26 16:06:05
880	08050U	AUTRE	contact	2	2015-07-13 15:38:10	2015-07-13 15:38:17
879	14002L	AUTRE	contact	2	2015-07-13 15:34:51	2015-07-13 15:34:59
881	13001T	AUTRE	contact	2	2015-07-13 15:40:31	2015-07-13 15:40:38
882	95005A	AUTRE	contact	2	2015-07-13 15:42:06	2015-07-13 15:42:20
883	09012S	AUTRE	contact	2	2015-07-13 15:44:04	2015-07-13 15:44:13
884	89022N	AUTRE	contact	2	2015-07-13 15:45:15	2015-07-13 15:45:22
554	11044J	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:57:31
909	14329V	SENAT	Nouvelles coordonnées	1	2015-10-12 09:41:57	2016-05-26 15:57:09
903	000800	MINISTERE	Intérieur Beauvau	2	2015-09-24 13:13:59	2017-05-12 16:27:16
918	14038Y	PERM	Nouvelles coordonnées	1	2016-05-19 14:36:01	2018-03-21 12:04:00
609	11113E	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 12:03:38
444	04089T	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 12:05:55
383	01041N	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 12:09:30
545	11034G	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 12:11:28
604	11107G	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 12:11:37
682	97011G	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 14:28:55
448	04095R	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 14:39:22
760	14123H	SENAT	Nouveau point de contact	2	2014-09-28 17:22:10	2016-05-26 14:40:43
569	11064N	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 14:42:12
519	08069G	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 14:44:09
765	14073Q	SENAT	Nouveau point de contact	2	2014-09-28 17:31:41	2016-05-26 14:46:52
597	11099A	SENAT	\N	2	2014-01-30 11:33:53	2018-02-16 11:07:27
447	04094Q	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 14:50:24
539	11026G	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 14:52:20
425	04065K	SENAT	\N	1	2014-01-30 11:33:53	\N
389	01048V	SENAT	\N	2	2014-01-30 11:33:53	2016-07-07 20:16:11
626	80027E	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 14:55:41
704	98046X	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:04:40
504	08053X	SENAT	\N	2	2014-01-30 11:33:53	2016-05-26 15:08:57
649	92039X	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:11:05
523	08073C	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:22:30
512	08061X	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:22:44
412	04044E	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:27:13
589	11090Q	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:32:59
763	14223L	SENAT	Nouveau point de contact	1	2014-09-28 17:27:34	2017-12-21 10:31:17
385	01043Q	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:41:15
433	04077P	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:42:33
409	04041B	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:45:15
375	01022K	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:45:28
758	14026U	SENAT	Nouveau point de contact	2	2014-09-28 17:15:41	2016-05-26 15:46:06
443	04088S	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:48:25
588	11089X	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:48:43
406	04035D	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:49:23
705	98050T	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:50:36
436	04080J	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:51:01
616	12042Y	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:53:18
645	92018S	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:55:38
394	01059Y	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:55:58
715	04053F	SENAT	Nouveau point de contact	1	2014-05-05 10:37:45	2016-05-26 15:58:19
540	11029K	SENAT	\N	2	2014-01-30 11:33:53	2016-05-26 15:58:42
365	00003C	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:58:03
366	01003G	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 14:25:08
367	01007L	SENAT	\N	2	2014-01-30 11:33:53	2016-05-26 15:47:05
368	01008M	SENAT	\N	1	2014-01-30 11:33:53	\N
369	01011G	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 14:39:34
371	01014K	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 16:11:16
372	01015L	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:54:31
373	01016M	SENAT	\N	2	2014-01-30 11:33:53	2016-05-26 15:51:46
374	01019Q	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 16:16:31
376	01024M	SENAT	\N	2	2014-01-30 11:33:53	2016-05-26 12:03:52
377	01025N	SENAT	\N	1	2014-01-30 11:33:53	2017-12-22 09:39:47
378	01027Q	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 12:05:02
379	01028R	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 16:19:27
380	01031L	SENAT	\N	1	2014-01-30 11:33:53	\N
381	01034P	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 16:20:54
382	01037S	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 14:36:04
384	01042P	SENAT	\N	1	2014-01-30 11:33:53	\N
386	01044R	SENAT	\N	1	2014-01-30 11:33:53	\N
387	01046T	SENAT	\N	1	2014-01-30 11:33:53	\N
390	01052R	SENAT	\N	1	2014-01-30 11:33:53	\N
392	01057W	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 14:41:43
393	01058X	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 16:19:05
395	01060R	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:08:17
396	01061S	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 14:53:45
397	01062T	SENAT	\N	1	2014-01-30 11:33:53	\N
398	01063U	SENAT	\N	1	2014-01-30 11:33:53	\N
399	01064V	SENAT	\N	1	2014-01-30 11:33:53	\N
400	01065W	SENAT	\N	1	2014-01-30 11:33:53	\N
401	02002K	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 14:28:43
402	02053W	SENAT	\N	1	2014-01-30 11:33:53	\N
403	03001N	SENAT	\N	1	2014-01-30 11:33:53	\N
404	04033B	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 16:13:00
405	04034C	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 16:25:41
407	04036E	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:43:03
408	04038G	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 11:55:16
411	04043D	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:32:34
413	04045F	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:30:16
414	04046G	SENAT	\N	1	2014-01-30 11:33:53	\N
415	04047H	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 11:46:17
416	04048J	SENAT	\N	1	2014-01-30 11:33:53	\N
417	04049K	SENAT	\N	2	2014-01-30 11:33:53	2016-05-26 15:41:51
418	04051D	SENAT	\N	1	2014-01-30 11:33:53	\N
419	04054G	SENAT	\N	1	2014-01-30 11:33:53	\N
421	04056J	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:29:06
422	04057K	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:39:42
423	04059M	SENAT	\N	1	2014-01-30 11:33:53	\N
424	04061F	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:42:42
426	04066L	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 11:47:01
427	04067M	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 12:03:30
428	04069P	SENAT	\N	1	2014-01-30 11:33:53	\N
429	04070G	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:33:46
430	04071H	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 12:05:45
431	04073K	SENAT	\N	1	2014-01-30 11:33:53	\N
432	04074L	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:50:48
434	04078Q	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 14:44:19
435	04079R	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 14:55:31
437	04081K	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:55:49
438	04083M	SENAT	\N	1	2014-01-30 11:33:53	\N
439	04084N	SENAT	\N	1	2014-01-30 11:33:53	\N
440	04085P	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 16:01:05
441	04086Q	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 11:56:19
442	04087R	SENAT	\N	1	2014-01-30 11:33:53	\N
445	04091M	SENAT	\N	1	2014-01-30 11:33:53	\N
446	04092N	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:10:55
449	04097T	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 14:45:06
450	04099V	SENAT	\N	1	2014-01-30 11:33:53	\N
452	05011Y	SENAT	\N	1	2014-01-30 11:33:53	\N
453	05012A	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:50:27
454	06004E	SENAT	\N	1	2014-01-30 11:33:53	\N
455	06005F	SENAT	\N	1	2014-01-30 11:33:53	\N
456	07003H	SENAT	\N	1	2014-01-30 11:33:53	\N
457	07004J	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:47:23
458	07024N	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 14:38:35
459	07026Q	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:47:34
460	07029T	SENAT	\N	2	2014-01-30 11:33:53	2016-05-26 14:49:57
461	07030L	SENAT	\N	1	2014-01-30 11:33:53	\N
462	07032N	SENAT	\N	2	2014-01-30 11:33:53	2016-05-26 15:48:55
463	07034Q	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:48:33
464	08009T	SENAT	\N	2	2014-01-30 11:33:53	2018-01-04 17:29:04
465	08010L	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 14:52:37
467	08012N	SENAT	\N	2	2014-01-30 11:33:53	2016-05-26 10:59:20
468	08014Q	SENAT	\N	1	2014-01-30 11:33:53	\N
469	08015R	SENAT	\N	2	2014-01-30 11:33:53	\N
470	08016S	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 14:42:24
471	08017T	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:41:27
472	08018U	SENAT	\N	1	2014-01-30 11:33:53	\N
473	08019V	SENAT	\N	1	2014-01-30 11:33:53	\N
474	08020N	SENAT	\N	1	2014-01-30 11:33:53	\N
475	08021P	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:13:42
476	08022Q	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:55:03
477	08024S	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:57:40
478	08025T	SENAT	\N	1	2014-01-30 11:33:53	\N
479	08026U	SENAT	\N	1	2014-01-30 11:33:53	\N
480	08027V	SENAT	\N	1	2014-01-30 11:33:53	\N
481	08028W	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 11:52:37
482	08029X	SENAT	\N	1	2014-01-30 11:33:53	\N
483	08031R	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:42:18
484	08032S	SENAT	\N	1	2014-01-30 11:33:53	\N
485	08033T	SENAT	\N	1	2014-01-30 11:33:53	\N
486	08034U	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 11:58:34
487	08035V	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:48:53
488	08037X	SENAT	\N	1	2014-01-30 11:33:53	\N
489	08038Y	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 11:58:23
490	08039A	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 14:52:56
491	08040S	SENAT	\N	1	2014-01-30 11:33:53	\N
492	08041T	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:47:59
493	08042U	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:19:14
495	08044W	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:44:35
496	08045X	SENAT	\N	2	2014-01-30 11:33:53	2017-11-27 17:13:37
497	08046Y	SENAT	\N	1	2014-01-30 11:33:53	\N
498	08047A	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:47:30
499	08048B	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 14:39:07
500	08049C	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 16:20:35
501	08050U	SENAT	\N	1	2014-01-30 11:33:53	\N
502	08051V	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:10:47
503	08052W	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 11:58:11
505	08054Y	SENAT	\N	1	2014-01-30 11:33:53	\N
507	08056B	SENAT	\N	2	2014-01-30 11:33:53	2016-05-26 11:23:49
508	08057C	SENAT	\N	1	2014-01-30 11:33:53	\N
509	08058D	SENAT	\N	1	2014-01-30 11:33:53	\N
510	08059E	SENAT	\N	1	2014-01-30 11:33:53	\N
511	08060W	SENAT	\N	2	2014-01-30 11:33:53	2016-05-26 15:59:14
514	08063A	SENAT	\N	1	2014-01-30 11:33:53	\N
515	08065C	SENAT	\N	2	2014-01-30 11:33:53	2016-05-26 14:29:02
516	08066D	SENAT	\N	1	2014-01-30 11:33:53	\N
517	08067E	SENAT	\N	1	2014-01-30 11:33:53	\N
518	08068F	SENAT	\N	1	2014-01-30 11:33:53	\N
521	08071A	SENAT	\N	1	2014-01-30 11:33:53	\N
522	08072B	SENAT	\N	1	2014-01-30 11:33:53	\N
524	09001P	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:44:19
525	09012S	SENAT	\N	1	2014-01-30 11:33:53	\N
526	10003H	SENAT	\N	1	2014-01-30 11:33:53	\N
527	10006L	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:55:26
529	11010L	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 14:37:00
530	11011M	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 16:22:54
531	11012A	SENAT	\N	2	2014-01-30 11:33:53	2016-05-26 16:11:49
532	11014C	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:37:54
533	11015D	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 14:39:44
534	11018G	SENAT	\N	1	2014-01-30 11:33:53	\N
535	11020A	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 12:11:47
536	11022C	SENAT	\N	1	2014-01-30 11:33:53	\N
537	11023D	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:56:54
538	11025F	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 16:24:41
542	11031D	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:56:31
543	11032E	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 11:49:30
544	11033F	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:59:39
546	11035H	SENAT	\N	1	2014-01-30 11:33:53	\N
547	11036J	SENAT	\N	2	2014-01-30 11:33:53	2016-05-26 16:00:38
549	11039M	SENAT	\N	1	2014-01-30 11:33:53	\N
550	11040E	SENAT	\N	1	2014-01-30 11:33:53	\N
551	11041F	SENAT	\N	1	2014-01-30 11:33:53	\N
553	11043H	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 16:18:50
555	11045K	SENAT	\N	1	2014-01-30 11:33:53	\N
556	11046L	SENAT	\N	2	2014-01-30 11:33:53	2016-05-26 16:14:35
557	11048N	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 14:45:17
558	11049P	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 14:40:29
559	11051H	SENAT	\N	1	2014-01-30 11:33:53	\N
560	11053K	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 11:48:21
561	11054L	SENAT	\N	1	2014-01-30 11:33:53	2017-12-21 10:46:53
562	11055M	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 16:01:14
563	11056N	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:56:11
564	11057P	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 16:25:09
565	11059R	SENAT	\N	1	2014-01-30 11:33:53	\N
566	11060J	SENAT	\N	1	2014-01-30 11:33:53	\N
567	11061K	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:49:03
568	11063M	SENAT	\N	1	2014-01-30 11:33:53	2016-11-22 15:35:49
571	11066Q	SENAT	\N	2	2014-01-30 11:33:53	2016-05-26 16:21:26
572	11067R	SENAT	\N	2	2014-01-30 11:33:53	2016-05-26 15:38:49
573	11068S	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 11:16:22
574	11069T	SENAT	\N	1	2014-01-30 11:33:53	\N
575	11070L	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 12:00:54
576	11071M	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 16:19:18
577	11072N	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:11:13
578	11074Q	SENAT	\N	1	2014-01-30 11:33:53	\N
580	11077T	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:40:59
582	11081P	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 11:21:28
583	11082Q	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:13:30
584	11083R	SENAT	\N	1	2014-01-30 11:33:53	\N
585	11084S	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 14:45:53
586	11085T	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:06:33
587	11088W	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 12:01:05
590	11091R	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:53:58
592	11094U	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 16:19:51
593	11095V	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 11:47:29
594	11096W	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 12:11:01
595	11097X	SENAT	\N	1	2014-01-30 11:33:53	2016-11-29 16:18:09
596	11098Y	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 14:52:04
598	11100Y	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 14:53:19
599	11101A	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 11:47:17
600	11103C	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 11:48:51
602	11105E	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:19:36
603	11106F	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 14:54:51
605	11108H	SENAT	\N	1	2014-01-30 11:33:53	\N
606	11109J	SENAT	\N	1	2014-01-30 11:33:53	\N
607	11111C	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 14:50:44
608	11112D	SENAT	\N	1	2014-01-30 11:33:53	\N
610	11114F	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 11:55:41
611	12035A	SENAT	\N	1	2014-01-30 11:33:53	\N
612	12038D	SENAT	\N	1	2014-01-30 11:33:53	\N
613	12039E	SENAT	\N	1	2014-01-30 11:33:53	\N
614	12040W	SENAT	\N	1	2014-01-30 11:33:53	\N
615	12041X	SENAT	\N	1	2014-01-30 11:33:53	\N
617	13001T	SENAT	\N	1	2014-01-30 11:33:53	\N
618	13002U	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:50:13
619	13003V	SENAT	\N	1	2014-01-30 11:33:53	\N
620	13005X	SENAT	\N	1	2014-01-30 11:33:53	\N
621	14001X	SENAT	\N	2	2014-01-30 11:33:53	2016-05-26 15:04:58
622	77002U	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 11:48:12
623	77043E	SENAT	\N	1	2014-01-30 11:33:53	\N
624	77058M	SENAT	\N	1	2014-01-30 11:33:53	\N
625	80013X	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 11:56:08
627	83011J	SENAT	\N	1	2014-01-30 11:33:53	\N
628	83047W	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:48:02
629	86010V	SENAT	\N	1	2014-01-30 11:33:53	\N
630	86034E	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 14:50:19
631	86044G	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 12:00:28
632	86049M	SENAT	\N	1	2014-01-30 11:33:53	\N
633	87003B	SENAT	\N	2	2014-01-30 11:33:53	2016-05-26 12:06:35
634	88008L	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 11:54:58
635	89007P	SENAT	\N	1	2014-01-30 11:33:53	\N
636	89013M	SENAT	\N	1	2014-01-30 11:33:53	\N
637	89014N	SENAT	\N	1	2014-01-30 11:33:53	\N
638	89015P	SENAT	\N	1	2014-01-30 11:33:53	\N
639	89017R	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 10:56:35
640	89022N	SENAT	\N	1	2014-01-30 11:33:53	\N
641	89029V	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 14:38:21
642	90003B	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 11:50:08
643	90004C	SENAT	\N	1	2014-01-30 11:33:53	\N
644	92015P	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 11:49:15
646	92020L	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:53:35
647	92031P	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 14:52:48
648	92035T	SENAT	\N	1	2014-01-30 11:33:53	\N
650	92040Q	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:13:14
651	92044U	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 16:20:26
652	94003T	SENAT	\N	1	2014-01-30 11:33:53	\N
653	95005A	SENAT	\N	1	2014-01-30 11:33:53	\N
654	95009E	SENAT	\N	1	2014-01-30 11:33:53	\N
656	95019G	SENAT	\N	1	2014-01-30 11:33:53	\N
657	95020Y	SENAT	\N	1	2014-01-30 11:33:53	\N
658	95021A	SENAT	\N	1	2014-01-30 11:33:53	\N
659	95025E	SENAT	\N	1	2014-01-30 11:33:53	\N
660	95028H	SENAT	\N	1	2014-01-30 11:33:53	\N
661	95030B	SENAT	\N	2	2014-01-30 11:33:53	2016-05-26 12:09:58
662	95031C	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 12:11:19
663	95032D	SENAT	\N	1	2014-01-30 11:33:53	\N
664	95034F	SENAT	\N	1	2014-01-30 11:33:53	\N
665	95035G	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 14:39:53
666	95036H	SENAT	\N	1	2014-01-30 11:33:53	\N
667	95037J	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 14:42:33
668	95038K	SENAT	\N	1	2014-01-30 11:33:53	\N
669	95039L	SENAT	\N	1	2014-01-30 11:33:53	\N
670	95047L	SENAT	\N	1	2014-01-30 11:33:53	\N
672	95052H	SENAT	\N	1	2014-01-30 11:33:53	\N
673	95055L	SENAT	\N	1	2014-01-30 11:33:53	\N
674	95059Q	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:51:25
675	95062K	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 16:13:12
16	13003V	PERM	\N	1	2013-12-10 10:15:02	\N
10	11012A	PERM	\N	1	2013-12-10 10:15:02	\N
11	11112D	PERM	\N	1	2013-12-10 10:15:02	\N
13	04040A	SENAT	\N	1	2013-12-10 10:15:02	2016-05-26 11:29:10
14	04040A	PERM	\N	2	2013-12-10 10:15:02	2016-05-26 11:29:10
15	11110B	SENAT	\N	1	2013-12-10 10:15:02	2016-05-26 15:51:37
1	000800	SENAT	\N	1	2013-12-10 10:15:02	\N
2	000800	SENAT	\N	1	2013-12-10 10:15:02	\N
716	11027H	SENAT	Nouveau point de contact	1	2014-05-05 10:40:21	2016-05-26 15:56:21
717	14013P	SENAT	Nouveau point de contact	2	2014-05-09 11:29:04	2016-05-26 11:30:22
718	14014Q	SENAT	Nouveau point de contact	2	2014-05-09 11:37:36	2016-05-26 15:48:15
719	14017T	SENAT	Nouveau point de contact	1	2014-06-25 15:52:44	2016-05-26 16:13:45
722	14191V	SENAT	Nouveau point de contact	1	2014-09-28 12:09:44	2016-05-26 15:22:18
729	14097Y	SENAT	Nouveau point de contact	1	2014-09-28 13:32:34	2016-05-26 15:43:52
730	14135M	SENAT	Nouveau point de contact	1	2014-09-28 13:40:32	2017-10-13 19:00:00
731	95041E	SENAT	Nouveau point de contact	1	2014-09-28 13:40:32	2016-05-26 14:45:44
740	14173T	SENAT	Nouveau point de contact	1	2014-09-28 16:59:40	2016-05-26 16:25:18
741	14167V	SENAT	Nouveau point de contact	2	2014-09-28 16:59:40	2016-05-26 11:34:05
742	14169X	SENAT	Nouveau point de contact	2	2014-09-28 16:59:40	2016-05-26 11:58:58
743	14083S	SENAT	Nouveau point de contact	1	2014-09-28 17:00:59	2016-05-26 11:48:00
744	14207L	SENAT	Nouveau point de contact	2	2014-09-28 17:03:41	2018-03-14 16:43:18
745	14209N	SENAT	Nouveau point de contact	1	2014-09-28 17:03:41	2016-05-26 11:55:26
746	14211G	SENAT	Nouveau point de contact	1	2014-09-28 17:03:41	2016-05-26 14:40:04
747	14213J	SENAT	Nouveau point de contact	1	2014-09-28 17:05:42	2016-05-26 15:45:01
748	14159V	SENAT	Nouveau point de contact	1	2014-09-28 17:05:42	\N
749	14059S	SENAT	Nouveau point de contact	2	2014-09-28 17:07:07	2016-05-26 15:40:22
750	14087W	SENAT	Nouveau point de contact	1	2014-09-28 17:07:40	2016-05-26 12:12:01
752	14081Q	SENAT	Nouveau point de contact	2	2014-09-28 17:07:40	2018-01-05 10:03:25
753	14215L	SENAT	Nouveau point de contact	1	2014-09-28 17:07:40	2016-05-26 15:54:41
754	14093U	SENAT	Nouveau point de contact	1	2014-09-28 17:09:16	2016-05-26 11:22:58
755	14063N	SENAT	Nouveau point de contact	1	2014-09-28 17:09:16	2016-05-26 15:03:43
756	14217N	SENAT	Nouveau point de contact	1	2014-09-28 17:12:40	2016-05-26 15:54:51
759	14219Q	SENAT	Nouveau point de contact	2	2014-09-28 17:22:10	2016-05-26 14:54:00
679	96004D	SENAT	\N	2	2014-01-30 11:33:53	2017-12-22 11:24:45
680	96006F	SENAT	\N	1	2014-01-30 11:33:53	\N
681	96007G	SENAT	\N	1	2014-01-30 11:33:53	\N
683	98005N	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 14:51:08
684	98006P	SENAT	\N	1	2014-01-30 11:33:53	\N
685	98010K	SENAT	\N	1	2014-01-30 11:33:53	\N
686	98011L	SENAT	\N	1	2014-01-30 11:33:53	\N
687	98018T	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 12:00:44
688	98019U	SENAT	\N	1	2014-01-30 11:33:53	\N
689	98021N	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 15:48:41
690	98022P	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 14:42:02
692	98024R	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 12:03:17
693	98027U	SENAT	\N	1	2014-01-30 11:33:53	\N
694	98028V	SENAT	\N	1	2014-01-30 11:33:53	\N
695	98029W	SENAT	\N	1	2014-01-30 11:33:53	2018-01-29 13:59:21
696	98030P	SENAT	\N	1	2014-01-30 11:33:53	\N
697	98032R	SENAT	\N	1	2014-01-30 11:33:53	\N
698	98035U	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 16:19:40
699	98036V	SENAT	\N	1	2014-01-30 11:33:53	\N
700	98037W	SENAT	\N	1	2014-01-30 11:33:53	\N
701	98038X	SENAT	\N	1	2014-01-30 11:33:53	\N
702	98041S	SENAT	\N	1	2014-01-30 11:33:53	\N
703	98042T	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 12:08:02
706	98052V	SENAT	\N	1	2014-01-30 11:33:53	\N
707	98053W	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 14:25:29
708	99002P	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 11:55:08
709	99004R	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 14:46:19
710	14002L	SENAT	Nouveau point de contact	1	2014-02-14 15:15:52	\N
761	14038Y	SENAT	Nouveau point de contact	2	2014-09-28 17:27:28	2016-05-25 14:45:55
762	14221J	SENAT	Nouveau point de contact	1	2014-09-28 17:27:34	2016-05-26 15:10:17
764	14225N	SENAT	Nouveau point de contact	2	2014-09-28 17:27:34	2016-05-26 16:06:05
767	14061L	SENAT	Nouveau point de contact	2	2014-09-28 17:31:41	2015-07-01 11:28:16
769	14229S	SENAT	Nouveau point de contact	1	2014-09-28 17:34:15	2016-05-26 15:30:38
770	14231L	SENAT	Nouveau point de contact	1	2014-09-28 17:34:15	2016-05-26 15:49:13
771	14233N	SENAT	Nouveau point de contact	1	2014-09-28 17:35:38	\N
772	14235Q	SENAT	Nouveau point de contact	1	2014-09-28 17:38:25	2016-05-26 15:31:49
773	14157T	SENAT	Nouveau point de contact	1	2014-09-28 17:38:25	2016-05-26 16:21:02
774	14237S	SENAT	Nouveau point de contact	1	2014-09-28 17:40:23	2016-05-26 15:47:46
775	14179A	SENAT	Nouveau point de contact	2	2014-09-28 17:40:23	2016-05-26 14:42:50
776	14239U	SENAT	Nouveau point de contact	1	2014-09-28 17:52:17	2016-05-26 11:20:45
777	14241N	SENAT	Nouveau point de contact	1	2014-09-28 17:52:17	2016-05-26 15:43:32
778	14055N	SENAT	Nouveau point de contact	1	2014-09-28 17:52:17	2016-05-26 16:05:52
781	14187A	SENAT	Nouveau point de contact	2	2014-09-28 17:58:04	2016-05-26 15:51:16
782	14051J	SENAT	Nouveau point de contact	1	2014-09-28 18:00:57	2016-05-26 15:27:42
783	14053L	SENAT	Nouveau point de contact	1	2014-09-28 18:00:57	2016-05-26 15:57:52
784	14247U	SENAT	Nouveau point de contact	1	2014-09-28 18:03:38	2016-05-26 15:51:16
790	14041T	SENAT	Nouveau point de contact	1	2014-09-28 18:46:12	2016-05-26 15:55:14
791	14033T	SENAT	Nouveau point de contact	1	2014-09-28 18:47:01	2016-05-26 14:40:17
792	14151M	SENAT	Nouveau point de contact	1	2014-09-28 18:58:20	2016-05-26 12:08:15
793	14037X	SENAT	Nouveau point de contact	1	2014-09-28 18:58:25	2016-05-26 14:53:06
795	14069U	SENAT	Nouveau point de contact	1	2014-09-28 19:03:03	\N
796	14111D	SENAT	Nouveau point de contact	1	2014-09-28 19:03:23	2016-05-26 15:04:11
797	14071N	SENAT	Nouveau point de contact	1	2014-09-28 19:05:58	2016-05-26 15:11:43
798	14119M	SENAT	Nouveau point de contact	1	2014-09-28 19:05:58	2017-12-19 20:29:31
799	14257W	SENAT	Nouveau point de contact	1	2014-09-28 19:07:43	2016-05-26 15:11:22
800	14107H	SENAT	Nouveau point de contact	3	2014-09-28 19:09:43	2016-05-26 16:16:19
801	14085U	SENAT	Nouveau point de contact	1	2014-09-28 19:13:08	2016-05-26 11:48:34
802	14089Y	SENAT	Nouveau point de contact	1	2014-09-28 19:13:08	\N
803	14034U	SENAT	Nouveau point de contact	1	2014-09-28 19:19:39	2016-05-26 14:37:12
804	14028W	SENAT	Nouveau point de contact	1	2014-09-28 19:19:39	2016-05-26 15:33:26
805	14259Y	SENAT	Nouveau point de contact	1	2014-09-28 19:20:16	2016-05-26 11:57:49
806	14175V	SENAT	Nouveau point de contact	1	2014-09-28 19:29:38	2016-05-26 11:43:20
807	14129P	SENAT	Nouveau point de contact	1	2014-09-28 19:45:29	\N
808	14261S	SENAT	Nouveau point de contact	1	2014-09-29 09:03:10	\N
809	14039A	SENAT	Nouveau point de contact	1	2014-09-29 09:05:47	2016-05-26 14:46:07
810	14043V	SENAT	Nouveau point de contact	1	2014-09-29 09:08:32	\N
923	01048V	PERM	Nouvelles coordonnées	1	2016-07-05 16:30:16	2016-07-07 20:16:11
991	17583W	SENAT	Nouvelles coordonnées	1	2017-09-24 17:04:01	\N
935	08014Q	PERM	Nouvelles coordonnées	2	2017-03-02 15:15:25	2017-03-02 15:15:35
995	19545Y	SENAT	Nouvelles coordonnées	1	2017-09-24 17:09:23	\N
996	19549D	SENAT	Nouvelles coordonnées	1	2017-09-24 17:09:23	\N
997	19533U	SENAT	Nouvelles coordonnées	1	2017-09-24 17:09:23	\N
998	16685X	SENAT	Nouvelles coordonnées	1	2017-09-24 17:14:26	\N
999	19447X	SENAT	Nouvelles coordonnées	1	2017-09-24 17:14:26	\N
1004	19675J	PERM	Nouvelles coordonnées	2	2017-09-24 17:18:02	2018-01-09 10:28:21
1005	19543W	SENAT	Nouvelles coordonnées	1	2017-09-24 17:18:02	\N
1008	19421M	SENAT	Nouvelles coordonnées	1	2017-09-24 17:28:55	\N
1015	19527W	SENAT	Nouvelles coordonnées	1	2017-09-24 17:42:25	\N
1016	19521Q	SENAT	Nouvelles coordonnées	1	2017-09-24 17:42:25	\N
1017	19525U	SENAT	Nouvelles coordonnées	1	2017-09-24 17:42:25	\N
1018	19681G	SENAT	Nouvelles coordonnées	1	2017-09-24 17:42:25	\N
1019	19649G	SENAT	Nouvelles coordonnées	1	2017-09-24 17:47:26	\N
1020	07033P	SENAT	Nouvelles coordonnées	1	2017-09-24 17:47:26	\N
1021	19651A	SENAT	Nouvelles coordonnées	1	2017-09-24 17:47:26	\N
1022	19643A	SENAT	Nouvelles coordonnées	1	2017-09-24 17:47:26	\N
1023	19683J	SENAT	Nouvelles coordonnées	1	2017-09-24 17:47:26	\N
1024	19647E	SENAT	Nouvelles coordonnées	1	2017-09-24 17:47:26	\N
1027	19687N	SENAT	Nouvelles coordonnées	1	2017-09-24 17:55:12	\N
1028	19611R	SENAT	Nouvelles coordonnées	1	2017-09-24 17:55:12	\N
1029	19689Q	SENAT	Nouvelles coordonnées	1	2017-09-24 17:55:12	\N
1030	19289C	SENAT	Nouvelles coordonnées	1	2017-09-24 18:05:40	\N
1031	19691J	SENAT	Nouvelles coordonnées	1	2017-09-24 18:05:40	\N
1032	19399H	SENAT	Nouvelles coordonnées	1	2017-09-24 18:05:40	\N
1033	19693L	SENAT	Nouvelles coordonnées	1	2017-09-24 18:05:40	\N
1036	19329S	SENAT	Nouvelles coordonnées	1	2017-09-24 18:16:33	\N
1050	19387D	SENAT	Nouvelles coordonnées	1	2017-09-24 18:20:09	2017-12-20 10:07:44
1051	19383Y	SENAT	Nouvelles coordonnées	1	2017-09-24 18:20:09	\N
1057	18083K	SENAT	Nouvelles coordonnées	1	2017-09-24 18:44:44	\N
1059	19575F	SENAT	Nouvelles coordonnées	1	2017-09-24 18:51:50	\N
1065	19563B	SENAT	Nouvelles coordonnées	1	2017-09-24 19:16:18	\N
1067	19369B	SENAT	Nouvelles coordonnées	1	2017-09-24 19:19:07	\N
1068	19367Y	SENAT	Nouvelles coordonnées	1	2017-09-24 19:19:07	\N
1069	17637T	SENAT	Nouvelles coordonnées	1	2017-09-24 19:25:09	\N
1070	19711U	SENAT	Nouvelles coordonnées	1	2017-09-24 19:25:09	\N
1071	19591F	SENAT	Nouvelles coordonnées	1	2017-09-24 19:25:09	\N
1072	19593H	SENAT	Nouvelles coordonnées	1	2017-09-24 19:25:09	\N
1075	19531S	SENAT	Nouvelles coordonnées	1	2017-09-24 19:31:54	\N
1448	20298U	SENAT	Nouvelles coordonnées	1	\N	\N
1076	19713W	SENAT	Nouvelles coordonnées	2	2017-09-24 19:31:54	2018-03-09 09:43:51
1084	19719D	SENAT	Nouvelles coordonnées	1	2017-10-01 09:26:48	2018-01-30 15:58:03
1096	19301E	PERM	Nouvelles coordonnées	2	2017-10-09 12:04:58	\N
1107	11043H	PERM	Nouvelles coordonnées	2	2017-11-14 10:28:11	2017-11-14 10:28:18
1132	19747H	SENAT	Nouvelles coordonnées	1	2017-12-18 14:43:34	\N
1184	19675J	SENAT	Nouvelles coordonnées	1	2018-01-09 10:11:32	2018-01-09 10:28:21
1446	20018V	PERM	Nouvelles coordonnées	2	\N	\N
1165	08047A	PERM	Nouvelles coordonnées	2	2017-12-21 10:41:57	2017-12-21 10:42:48
1183	14327T	PERM	Nouvelles coordonnées	1	2018-01-08 19:04:38	2018-01-08 19:08:33
1199	19349W	PERM	Nouvelles coordonnées	2	2018-01-30 19:36:23	2018-01-30 19:36:38
1268	19914E	SENAT	Nouvelles coordonnées	1	\N	\N
1263	19820Y	SENAT	Nouvelles coordonnées	1	\N	\N
1264	19826F	SENAT	Nouvelles coordonnées	1	\N	\N
1270	19926J	SENAT	Nouvelles coordonnées	1	\N	\N
1219	19758L	SENAT	Nouvelles coordonnées	2	2018-05-31 11:00:21	\N
1250	19794Q	SENAT	Nouvelles coordonnées	1	\N	\N
1251	19768N	PERM	Nouvelles coordonnées	2	\N	\N
1272	04040A	AUTRE	Nouvelles coordonnées	3	\N	\N
1273	04040A	AUTRE	Nouvelles coordonnées	4	\N	\N
1274	19954N	SENAT	Nouvelles coordonnées	1	\N	\N
1350	20142Y	SENAT	Nouvelles coordonnées	1	\N	\N
1352	17965H	SENAT	Nouvelles coordonnées	1	\N	\N
1464	20248J	PERM	Adresse Personnelle	2	\N	\N
1401	20028X	PERM	Nouvelles coordonnées	2	\N	\N
1403	20090E	PERM	Nouvelles coordonnées	2	\N	\N
1433	20056C	PERM	Nouvelles coordonnées	2	\N	\N
1434	11104D	SENAT	Nouvelles coordonnées	1	\N	\N
1435	14249W	SENAT	Nouvelles coordonnées	1	\N	\N
1442	08009T	PERM	Nouvelles coordonnées	3	\N	\N
1518	21052C	SENAT	Nouvelles coordonnées	1	\N	\N
1459	20914V	SENAT	Nouvelles coordonnées	1	\N	\N
1493	21085M	SENAT	Nouvelles coordonnées	1	\N	\N
1551	21067K	AUTRE	Nouvelles coordonnées	1	\N	\N
1522	21038E	SENAT	\N	1	\N	\N
494	08043V	SENAT	\N	2	2014-01-30 11:33:53	2017-11-27 17:21:59
370	01013J	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 16:00:23
920	01043Q	AUTRE	Nouvelles coordonnées	2	2016-06-02 16:37:25	\N
926	05001W	AUTRE	Nouvelles coordonnées	1	2016-11-14 18:40:41	\N
973	11091R	SENAT	Nouvelles coordonnées	2	2017-07-21 15:15:42	\N
1085	19721W	SENAT	Nouvelles coordonnées	1	2017-10-01 09:45:12	\N
1086	19723Y	SENAT	Nouvelles coordonnées	1	2017-10-01 10:06:58	\N
1087	19725B	SENAT	Nouvelles coordonnées	1	2017-10-01 10:44:23	\N
1088	19727D	SENAT	Nouvelles coordonnées	1	2017-10-01 10:54:01	\N
1089	19729F	SENAT	Nouvelles coordonnées	1	2017-10-01 11:03:20	\N
1090	19731Y	SENAT	Nouvelles coordonnées	1	2017-10-01 11:13:13	\N
1091	19733B	SENAT	Nouvelles coordonnées	1	2017-10-01 11:41:24	\N
1092	19735D	SENAT	Nouvelles coordonnées	1	2017-10-01 11:48:00	\N
1093	19737F	SENAT	Nouvelles coordonnées	1	2017-10-01 11:57:14	\N
1102	19739H	SENAT	Nouvelles coordonnées	1	2017-11-03 10:52:37	\N
1103	08028W	PERM	Nouvelles coordonnées	2	2017-11-08 16:07:39	2017-11-08 16:07:45
1104	14159V	PERM	Nouvelles coordonnées	2	2017-11-08 16:18:51	2017-11-08 16:18:55
1106	14213J	PERM	Nouvelles coordonnées	2	2017-11-14 09:23:08	2017-11-14 09:23:13
1445	20286Q	SENAT	Nouvelles coordonnées	1	\N	\N
1125	19741B	SENAT	Nouvelles coordonnées	1	2017-11-24 18:17:29	\N
1130	19253P	SENAT	Nouvelles coordonnées	1	2017-11-29 14:01:53	2017-11-29 14:01:56
1486	21030V	SENAT	Autre Adresse	1	2023-09-28 00:00:00	\N
1526	21036C	SENAT	\N	1	\N	\N
1155	08049C	PERM	Nouvelles coordonnées	2	2017-12-20 16:53:26	2017-12-20 16:53:29
1172	14089Y	PERM	Nouvelles coordonnées	2	2017-12-21 15:50:33	2017-12-21 15:50:36
1161	14223L	PERM	Nouvelles coordonnées	2	2017-12-21 10:25:55	2017-12-21 10:26:25
1171	19253P	PERM	Nouvelles coordonnées	2	2017-12-21 15:43:40	2017-12-21 15:43:44
1175	14081Q	PERM	Nouvelles coordonnées	1	2017-12-21 21:21:58	2018-01-05 10:03:25
1211	19413M	PERM	Nouvelles coordonnées	2	2018-02-20 14:07:23	2018-02-20 14:07:27
1212	19727D	PERM	Nouvelles coordonnées	2	2018-02-20 18:22:44	2018-03-28 10:02:40
1253	14055N	PERM	Nouvelles coordonnées	2	\N	\N
1277	19968U	SENAT	Nouvelles coordonnées	1	\N	\N
1356	20152B	SENAT	Nouvelles coordonnées	1	\N	\N
1377	20174H	PERM	Nouvelles coordonnées	2	\N	\N
1261	19812Y	SENAT	Nouvelles coordonnées	1	\N	\N
1359	14257W	PERM	Nouvelles coordonnées	2	\N	\N
1370	17023S	PERM	Nouvelles coordonnées	2	\N	\N
1386	20180F	SENAT	Nouvelles coordonnées	1	\N	\N
1413	01048V	AUTRE	Nouvelles coordonnées	3	\N	\N
1550	11026G	AUTRE	www.jyleconte.fr	3	\N	\N
1148	19553Y	PERM	Nouvelles coordonnées	2	2017-12-20 10:06:38	2017-12-20 10:06:46
940	14365A	AUTRE	Nouvelles coordonnées	1	2017-05-16 16:19:32	\N
958	07028S	AUTRE	Nouvelles coordonnées	1	2017-06-07 15:17:54	\N
977	15447F	SENAT	Nouvelles coordonnées	1	2017-09-22 10:59:04	\N
968	16813M	AUTRE	Nouvelles coordonnées	1	2017-06-19 17:55:47	\N
974	19269X	SENAT	Nouvelles coordonnées	1	2017-07-24 10:01:14	\N
988	19333N	SENAT	Nouvelles coordonnées	1	2017-09-24 16:43:41	\N
989	19619A	SENAT	Nouvelles coordonnées	1	2017-09-24 16:45:25	\N
990	19621T	SENAT	Nouvelles coordonnées	1	2017-09-24 16:45:25	\N
992	19443T	SENAT	Nouvelles coordonnées	1	2017-09-24 17:06:55	\N
993	19441R	SENAT	Nouvelles coordonnées	1	2017-09-24 17:06:55	\N
994	19515S	SENAT	Nouvelles coordonnées	1	2017-09-24 17:06:55	\N
1000	19667J	SENAT	Nouvelles coordonnées	1	2017-09-24 17:15:14	\N
1001	19669L	SENAT	Nouvelles coordonnées	1	2017-09-24 17:15:14	\N
1002	19671E	SENAT	Nouvelles coordonnées	1	2017-09-24 17:15:14	\N
1003	19673G	SENAT	Nouvelles coordonnées	1	2017-09-24 17:15:14	\N
1006	19551W	SENAT	Nouvelles coordonnées	1	2017-09-24 17:19:41	\N
1007	19553Y	SENAT	Nouvelles coordonnées	1	2017-09-24 17:19:41	\N
1009	19573D	SENAT	Nouvelles coordonnées	1	2017-09-24 17:29:36	\N
1010	19677L	SENAT	Nouvelles coordonnées	1	2017-09-24 17:29:36	\N
1011	11115U	SENAT	Nouvelles coordonnées	1	2017-09-24 17:29:36	\N
1012	19349W	SENAT	Nouvelles coordonnées	1	2017-09-24 17:35:13	\N
1013	19679N	SENAT	Nouvelles coordonnées	1	2017-09-24 17:35:13	\N
1014	19347U	SENAT	Nouvelles coordonnées	1	2017-09-24 17:35:13	\N
1025	19335Q	SENAT	Nouvelles coordonnées	1	2017-09-24 17:48:20	\N
1026	19685L	SENAT	Nouvelles coordonnées	1	2017-09-24 17:48:20	\N
1034	19695N	SENAT	Nouvelles coordonnées	1	2017-09-24 18:07:56	\N
1035	19663E	SENAT	Nouvelles coordonnées	1	2017-09-24 18:07:56	\N
1037	14021P	SENAT	Nouvelles coordonnées	1	2017-09-24 18:16:50	\N
1038	19637C	SENAT	Nouvelles coordonnées	1	2017-09-24 18:16:50	\N
1039	19599P	SENAT	Nouvelles coordonnées	1	2017-09-24 18:16:51	\N
1040	17589D	SENAT	Nouvelles coordonnées	1	2017-09-24 18:16:51	\N
1041	19581D	SENAT	Nouvelles coordonnées	1	2017-09-24 18:16:51	\N
1042	19569H	SENAT	Nouvelles coordonnées	1	2017-09-24 18:16:51	\N
1432	20252E	SENAT	Nouvelles coordonnées	1	\N	\N
1044	19585H	SENAT	Nouvelles coordonnées	1	2017-09-24 18:16:51	\N
1045	04008A	SENAT	Nouvelles coordonnées	1	2017-09-24 18:16:51	\N
1046	04018C	SENAT	Nouvelles coordonnées	1	2017-09-24 18:17:55	\N
1047	19697Q	SENAT	Nouvelles coordonnées	1	2017-09-24 18:17:55	\N
1048	19699S	SENAT	Nouvelles coordonnées	1	2017-09-24 18:17:55	\N
1049	19701S	SENAT	Nouvelles coordonnées	1	2017-09-24 18:17:55	\N
1052	19415P	SENAT	Nouvelles coordonnées	1	2017-09-24 18:23:21	\N
1053	19413M	SENAT	Nouvelles coordonnées	1	2017-09-24 18:23:21	\N
1054	19631V	SENAT	Nouvelles coordonnées	1	2017-09-24 18:27:44	\N
1055	17779H	SENAT	Nouvelles coordonnées	1	2017-09-24 18:41:37	\N
1056	19489J	SENAT	Nouvelles coordonnées	1	2017-09-24 18:41:37	\N
1058	19703U	SENAT	Nouvelles coordonnées	2	2017-09-24 18:49:56	2017-12-21 16:56:55
1060	19705W	SENAT	Nouvelles coordonnées	1	2017-09-24 18:59:59	\N
1061	19707Y	SENAT	Nouvelles coordonnées	1	2017-09-24 18:59:59	\N
1062	19709B	SENAT	Nouvelles coordonnées	1	2017-09-24 18:59:59	\N
1063	19503N	SENAT	Nouvelles coordonnées	1	2017-09-24 19:05:36	\N
1064	19511N	SENAT	Nouvelles coordonnées	1	2017-09-24 19:14:36	\N
1066	19483C	SENAT	Nouvelles coordonnées	1	2017-09-24 19:17:41	\N
1472	20066E	PERM	Nouvelles coordonnées	2	\N	\N
1074	19467C	SENAT	Nouvelles coordonnées	1	2017-09-24 19:26:20	\N
1164	11054L	AUTRE	Nouvelles coordonnées	2	2017-12-21 10:41:27	\N
1101	14119M	AUTRE	Nouvelles coordonnées	2	2017-10-30 09:49:57	\N
1147	19681G	PERM	Nouvelles coordonnées	2	2017-12-20 09:48:43	2017-12-20 09:49:07
1129	19443T	PERM	Nouvelles coordonnées	2	2017-11-28 15:05:58	2017-11-28 15:06:25
1149	19387D	PERM	Nouvelles coordonnées	2	2017-12-20 10:07:21	2017-12-20 10:07:44
1154	14042U	PERM	Nouvelles coordonnées	2	2017-12-20 14:57:48	2017-12-20 14:57:56
1474	20980G	SENAT	Nouvelles coordonnées	1	\N	\N
1444	20032T	PERM	Nouvelles coordonnées	1	\N	\N
1179	96004D	PERM	Nouvelles coordonnées	1	2017-12-22 11:19:01	2017-12-22 11:24:45
1185	19713W	PERM	Nouvelles coordonnées	1	2018-01-10 20:37:20	2018-03-09 09:43:49
1223	19467C	PERM	Nouvelles coordonnées	2	2018-06-11 09:35:31	2018-06-11 09:35:36
1244	08015R	AUTRE	Nouvelles coordonnées	1	\N	\N
1265	19866P	SENAT	Nouvelles coordonnées	1	\N	\N
1271	19930E	SENAT	Nouvelles coordonnées	1	\N	\N
1371	20172F	SENAT	Nouvelles coordonnées	1	\N	\N
1400	20180F	PERM	Nouvelles coordonnées	2	\N	\N
1528	21085M	PERM	Nouvelles coordonnées	2	\N	\N
1538	19111A	AUTRE	Nouvelles coordonnées	1	\N	\N
1539	14229S	PERM	Nouvelles coordonnées	2	\N	\N
954	000800	MINISTERE	Enseignement supérieur, recherche, innovation	16	2017-05-23 11:13:17	2017-05-23 11:13:41
955	000800	MINISTERE	Outre-mer	17	2017-05-23 11:13:45	2017-05-23 11:16:57
956	000800	MINISTERE	Sports	18	2017-05-23 11:17:28	2017-05-23 11:17:38
957	000800	MINISTERE	Transports	19	2017-05-23 11:24:59	2017-06-19 17:55:14
1144	14109K	PERM	Nouvelles coordonnées	2	2017-12-20 09:02:26	2017-12-20 09:02:36
982	19507S	SENAT	Nouvelles coordonnées	1	2017-09-24 12:57:08	\N
983	01007L	SENAT	Nouvelles coordonnées	3	2017-09-24 13:20:36	\N
1114	14355X	PERM	Nouvelles coordonnées	2	2017-11-16 11:48:36	2017-11-16 11:48:40
1157	19251M	PERM	Nouvelles coordonnées	2	2017-12-21 10:11:45	2017-12-21 10:17:36
1173	98035U	PERM	Nouvelles coordonnées	2	2017-12-21 16:06:28	2017-12-21 16:07:06
1206	10015M	PERM	Nouvelles coordonnées	2	2018-02-06 12:54:27	2018-02-06 12:54:30
1205	10015M	SENAT	Nouvelles coordonnées	1	2018-02-06 12:54:12	2018-02-06 12:54:17
1227	19760E	SENAT	Nouvelles coordonnées	1	\N	\N
1228	19762G	SENAT	Nouvelles coordonnées	1	\N	\N
1252	19563B	PERM	Nouvelles coordonnées	2	\N	\N
1243	19521Q	AUTRE	Nouvelles coordonnées	2	\N	\N
1254	19798U	SENAT	Nouvelles coordonnées	1	\N	\N
1452	14133K	AUTRE	Nouvelles coordonnées	2	\N	\N
1267	19912C	SENAT	Nouvelles coordonnées	1	\N	\N
1292	20040T	SENAT	Nouvelles coordonnées	1	\N	\N
1294	20044X	SENAT	Nouvelles coordonnées	1	\N	\N
1308	20070A	SENAT	Nouvelles coordonnées	1	\N	\N
1309	20072C	SENAT	Nouvelles coordonnées	1	\N	\N
1310	20074E	SENAT	Nouvelles coordonnées	1	\N	\N
1311	20076G	SENAT	Nouvelles coordonnées	1	\N	\N
1312	20078J	SENAT	Nouvelles coordonnées	1	\N	\N
1314	20080C	SENAT	Nouvelles coordonnées	1	\N	\N
1315	20082E	SENAT	Nouvelles coordonnées	1	\N	\N
1322	20096L	SENAT	Nouvelles coordonnées	1	\N	\N
1323	20098N	SENAT	Nouvelles coordonnées	3	\N	\N
1324	20100N	SENAT	Nouvelles coordonnées	1	\N	\N
1334	20114U	SENAT	Nouvelles coordonnées	1	\N	\N
1335	20116W	SENAT	Nouvelles coordonnées	2	\N	\N
1339	20122U	SENAT	Nouvelles coordonnées	2	\N	\N
1347	20136B	SENAT	Nouvelles coordonnées	1	\N	\N
1348	20138D	SENAT	Nouvelles coordonnées	1	\N	\N
1349	20140W	SENAT	Nouvelles coordonnées	1	\N	\N
1353	20146D	SENAT	Nouvelles coordonnées	1	\N	\N
1354	20148F	SENAT	Nouvelles coordonnées	1	\N	\N
1355	20150Y	SENAT	Nouvelles coordonnées	1	\N	\N
1387	14221J	PERM	Nouvelles coordonnées	2	\N	\N
1425	14195A	PERM	Nouvelles coordonnées	3	\N	\N
1378	20050V	PERM	Nouvelles coordonnées	2	\N	\N
1383	14193X	PERM	Nouvelles coordonnées	2	\N	\N
1441	20264J	AUTRE	Nouvelles coordonnées	2	\N	\N
1430	20070A	PERM	Nouvelles coordonnées	2	\N	\N
1454	19866P	PERM	Nouvelles coordonnées	2	\N	\N
1475	20040T	PERM	Nouvelles coordonnées	2	\N	\N
1549	21053D	SENAT	Casier de la Poste	1	\N	\N
921	14147R	PERM	Nouvelles coordonnées	1	2016-06-30 09:53:21	2018-03-19 10:15:06
941	000800	MINISTERE	Premier ministre	3	2017-05-18 10:34:14	2017-05-18 10:34:33
927	14355X	SENAT	Nouvelles coordonnées	1	2016-11-18 12:45:10	2017-12-20 09:15:57
932	14363X	SENAT	Nouvelles coordonnées	1	2017-01-03 11:10:58	2017-09-20 11:39:52
942	000800	MINISTERE	Transition écologique	4	2017-05-18 10:39:01	2017-05-18 10:40:23
963	19251M	SENAT	Nouvelles coordonnées	1	2017-06-19 16:45:46	2017-11-20 09:32:04
978	19319Q	SENAT	Nouvelles coordonnées	1	2017-09-24 10:41:27	\N
1110	17779H	PERM	Nouvelles coordonnées	2	2017-11-14 18:03:01	2017-11-14 18:03:04
1109	19629C	PERM	Nouvelles coordonnées	1	2017-11-14 17:59:33	2018-03-19 10:14:36
1111	14215L	PERM	Nouvelles coordonnées	2	2017-11-14 18:36:50	2017-11-14 18:36:53
1112	04097T	PERM	Nouvelles coordonnées	2	2017-11-14 18:41:24	2017-11-14 18:41:28
1113	19721W	PERM	Nouvelles coordonnées	2	2017-11-15 15:44:27	2017-11-15 15:44:29
1115	08043V	PERM	Nouvelles coordonnées	1	2017-11-16 16:21:47	2017-11-27 17:21:59
1116	08060W	PERM	Nouvelles coordonnées	1	2017-11-16 16:26:06	2017-11-16 16:26:08
1117	19679N	PERM	Nouvelles coordonnées	2	2017-11-16 19:49:35	2017-11-16 19:49:38
1419	19399H	AUTRE	Nouvelles coordonnées	3	\N	\N
1119	19565D	PERM	Nouvelles coordonnées	2	2017-11-16 19:53:49	2017-11-16 19:53:53
1525	21073H	SENAT	\N	1	\N	\N
1122	89017R	PERM	Nouvelles coordonnées	2	2017-11-23 17:09:59	2017-11-23 17:10:06
1152	19581D	PERM	Nouvelles coordonnées	2	2017-12-20 10:42:12	2017-12-20 10:42:22
1162	11080N	AUTRE	Nouvelles coordonnées	2	2017-12-21 10:38:42	\N
1163	11080N	AUTRE	Nouvelles coordonnées	3	2017-12-21 10:40:08	\N
1180	19511N	AUTRE	Nouvelles coordonnées	2	2018-01-02 17:31:50	\N
1214	14207L	PERM	Nouvelles coordonnées	1	2018-03-14 16:41:28	2018-03-14 16:43:18
1216	19703U	AUTRE	Nouvelles coordonnées	3	2018-04-09 12:25:19	\N
1229	19760E	PERM	Nouvelles coordonnées	2	\N	\N
1279	20016T	SENAT	Nouvelles coordonnées	1	\N	\N
1280	20018V	SENAT	Nouvelles coordonnées	1	\N	\N
1281	20020P	SENAT	Nouvelles coordonnées	1	\N	\N
1282	20022R	SENAT	Nouvelles coordonnées	1	\N	\N
1283	20024T	SENAT	Nouvelles coordonnées	1	\N	\N
1284	20026V	SENAT	Nouvelles coordonnées	1	\N	\N
1285	20028X	SENAT	Nouvelles coordonnées	1	\N	\N
1286	20030R	SENAT	Nouvelles coordonnées	1	\N	\N
1288	20034V	SENAT	Nouvelles coordonnées	1	\N	\N
1289	20036X	SENAT	Nouvelles coordonnées	1	\N	\N
1290	14189C	SENAT	Nouvelles coordonnées	2	\N	\N
1293	20042V	SENAT	Nouvelles coordonnées	1	\N	\N
1296	20048C	SENAT	Nouvelles coordonnées	1	\N	\N
1297	20050V	SENAT	Nouvelles coordonnées	1	\N	\N
1299	20054A	SENAT	Nouvelles coordonnées	1	\N	\N
1301	20058E	SENAT	Nouvelles coordonnées	1	\N	\N
1305	20064C	SENAT	Nouvelles coordonnées	1	\N	\N
1307	20068G	SENAT	Nouvelles coordonnées	1	\N	\N
1313	17023S	SENAT	Nouvelles coordonnées	1	\N	\N
1316	20084G	SENAT	Nouvelles coordonnées	1	\N	\N
1317	20086J	SENAT	Nouvelles coordonnées	2	\N	\N
1321	20094J	SENAT	Nouvelles coordonnées	1	\N	\N
1325	20102Q	SENAT	Nouvelles coordonnées	1	\N	\N
1326	18193Q	SENAT	Nouvelles coordonnées	1	\N	\N
1327	20104S	SENAT	Nouvelles coordonnées	1	\N	\N
1328	20106U	SENAT	Nouvelles coordonnées	1	\N	\N
1336	19265T	SENAT	Nouvelles coordonnées	1	\N	\N
1337	20118Y	SENAT	Nouvelles coordonnées	1	\N	\N
1340	20124W	SENAT	Nouvelles coordonnées	1	\N	\N
1341	20126Y	SENAT	Nouvelles coordonnées	1	\N	\N
1342	20128B	SENAT	Nouvelles coordonnées	1	\N	\N
1365	20038A	PERM	Nouvelles coordonnées	2	\N	\N
1366	20088L	PERM	Nouvelles coordonnées	2	\N	\N
1367	20020P	PERM	Nouvelles coordonnées	2	\N	\N
1368	20152B	PERM	Nouvelles coordonnées	2	\N	\N
1369	20062A	PERM	Nouvelles coordonnées	2	\N	\N
1372	20174H	SENAT	Nouvelles coordonnées	1	\N	\N
1389	19565D	SENAT	Nouvelles coordonnées	1	\N	\N
1402	20122U	PERM	Nouvelles coordonnées	1	\N	\N
1415	19479G	PERM	Nouvelles coordonnées	2	\N	\N
1414	19479G	SENAT	Nouvelles coordonnées	1	\N	\N
1418	19399H	PERM	7, Place du Général de Gaulle 91 470 Limours	2	\N	\N
1438	19057M	SENAT	Nouvelles coordonnées	1	\N	\N
1439	20264J	SENAT	Nouvelles coordonnées	1	\N	\N
1440	20266L	SENAT	Nouvelles coordonnées	1	\N	\N
1456	000800	MINISTERE	Première ministre	25	\N	\N
1479	19629C	AUTRE	Collaborateur : M. Julien Bégué	3	\N	\N
1500	20088L	AUTRE	Nouvelles coordonnées	3	\N	\N
1545	21043B	PERM	\N	1	\N	\N
1510	21097R	SENAT	Casier de la Poste	1	\N	\N
1524	21090J	SENAT	\N	1	\N	\N
1532	21080G	PERM	\N	1	\N	\N
931	14361V	SENAT	Nouvelles coordonnées	1	2016-12-12 15:59:30	2017-01-12 11:20:49
944	000800	MINISTERE	Armées	6	2017-05-18 16:54:24	2017-05-18 16:56:46
943	000800	MINISTERE	Justice	5	2017-05-18 16:52:05	2017-05-18 16:52:52
945	000800	MINISTERE	Europe et affaires étrangères	7	2017-05-18 17:02:31	2017-05-18 17:02:56
946	000800	MINISTERE	Cohésion des territoires	8	2017-05-18 17:10:40	2017-05-18 17:11:27
947	000800	MINISTERE	Solidarités et santé	9	2017-05-18 17:11:52	2017-05-18 17:14:39
948	000800	MINISTERE	Culture	10	2017-05-18 17:16:40	2017-05-18 17:16:53
949	000800	MINISTERE	Economie	11	2017-05-18 17:21:52	2017-05-18 17:22:05
950	000800	MINISTERE	Travail	12	2017-05-18 17:24:05	2017-05-18 17:24:22
951	000800	MINISTERE	Education nationale	13	2017-05-18 17:25:49	2017-05-18 17:26:04
952	000800	MINISTERE	Agriculture	14	2017-05-18 17:40:53	2017-05-18 17:41:10
953	000800	MINISTERE	Action et comptes publics	15	2017-05-19 15:54:45	2017-05-19 15:54:55
1126	08045X	PERM	Nouvelles coordonnées	1	2017-11-27 17:01:48	2017-11-27 17:13:37
981	19629C	SENAT	Nouvelles coordonnées	2	2017-09-24 12:39:58	2018-03-19 10:14:36
1097	14211G	PERM	Nouvelles coordonnées	2	2017-10-09 17:26:35	2017-10-09 17:26:58
1276	19966S	SENAT	Nouvelles coordonnées	1	\N	\N
1140	11049P	PERM	Nouvelles coordonnées	2	2017-12-19 18:01:35	2017-12-19 18:01:52
1544	21033Y	AUTRE	Nouvelles coordonnées	1	\N	\N
1463	20086J	PERM	Nouvelles coordonnées	3	\N	\N
1198	19719D	PERM	Nouvelles coordonnées	2	2018-01-30 15:58:28	2018-01-30 15:58:42
1247	19782L	SENAT	Nouvelles coordonnées	2	\N	\N
1248	01057W	AUTRE	Nouvelles coordonnées	2	\N	\N
1287	20032T	SENAT	Nouvelles coordonnées	2	\N	\N
1363	11026G	AUTRE	jyl@op.pl        ou  	2	\N	\N
1364	19551W	PERM	Nouvelles coordonnées	2	\N	\N
1416	20082E	PERM	Nouvelles coordonnées	2	\N	\N
1399	20052X	PERM	Nouvelles coordonnées	2	\N	\N
1428	18193Q	PERM	Nouvelles coordonnées	2	\N	\N
1542	21044C	PERM	Nouvelles coordonnées	1	\N	\N
676	95063L	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 16:13:27
591	11093T	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 16:14:01
768	14227Q	SENAT	Nouveau point de contact	1	2014-09-28 17:34:15	2016-05-26 16:20:02
391	01056V	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 16:20:11
548	11037K	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 16:20:45
677	95067Q	SENAT	\N	1	2014-01-30 11:33:53	2016-05-26 16:24:52
388	01047U	SENAT	\N	2	2014-01-30 11:33:53	2016-05-26 16:26:51
925	14231L	PERM	Nouvelles coordonnées	2	2016-11-10 11:54:17	2016-11-10 11:54:20
975	19285X	SENAT	Nouvelles coordonnées	1	2017-07-31 12:02:13	\N
1131	19745F	SENAT	Nouvelles coordonnées	1	2017-12-18 14:31:40	\N
1098	11040E	PERM	Nouvelles coordonnées	2	2017-10-11 10:21:35	2017-10-11 10:21:44
984	19657G	SENAT	Nouvelles coordonnées	1	2017-09-24 16:24:50	\N
985	19659J	SENAT	Nouvelles coordonnées	1	2017-09-24 16:24:50	\N
986	19577H	SENAT	Nouvelles coordonnées	1	2017-09-24 16:24:50	\N
987	19583F	SENAT	Nouvelles coordonnées	1	2017-09-24 16:24:50	\N
1100	19549D	PERM	Nouvelles coordonnées	2	2017-10-25 10:08:29	2017-10-25 10:08:43
1128	14251Q	PERM	Nouvelles coordonnées	2	2017-11-27 18:18:42	2017-11-27 18:18:46
1133	19749K	PERM	Nouvelles coordonnées	1	2017-12-18 14:52:08	2018-03-09 12:06:11
1167	19369B	PERM	Nouvelles coordonnées	2	2017-12-21 13:54:09	2017-12-21 13:54:18
1174	18083K	PERM	Nouvelles coordonnées	2	2017-12-21 17:34:27	2017-12-21 17:34:40
1195	98029W	PERM	Nouvelles coordonnées	2	2018-01-29 13:59:17	2018-01-29 13:59:38
1237	19758L	PERM	Nouvelles coordonnées	4	\N	\N
1232	19766L	SENAT	Nouvelles coordonnées	1	\N	\N
1236	19758L	PERM	Nouvelles coordonnées	3	\N	\N
1238	19489J	PERM	Nouvelles coordonnées	2	\N	\N
1269	19920C	SENAT	Nouvelles coordonnées	1	\N	\N
1373	20092G	PERM	Nouvelles coordonnées	2	\N	\N
1381	20046A	PERM	Nouvelles coordonnées	2	\N	\N
1382	20054A	PERM	Nouvelles coordonnées	2	\N	\N
1384	20176K	SENAT	Nouvelles coordonnées	1	\N	\N
1385	20178M	SENAT	Nouvelles coordonnées	1	\N	\N
1427	14053L	PERM	Nouvelles coordonnées	2	\N	\N
1391	20052X	SENAT	Nouvelles coordonnées	1	\N	\N
1431	20248J	SENAT	Nouvelles coordonnées	1	\N	\N
1451	19569H	PERM	Nouvelles coordonnées	2	\N	\N
1543	21056G	SENAT	\N	1	\N	\N
928	98053W	AUTRE	Nouvelles coordonnées	2	2016-11-22 09:33:11	\N
929	11063M	PERM	Adresse permanence	2	2016-11-22 15:35:57	2016-11-22 15:37:19
966	000800	MINISTERE	Affaires européennes	20	2017-06-19 17:55:02	2017-06-19 17:56:26
967	000800	MINISTERE	Relations avec le Parlement	21	2017-06-19 17:55:19	2017-06-19 17:58:03
969	000800	MINISTERE	Égalité femmes et hommes	22	2017-06-19 17:58:03	2017-06-19 18:00:46
970	000800	MINISTERE	Personnes handicapées	23	2017-06-19 17:58:15	2017-06-19 18:02:48
971	000800	MINISTERE	Numérique	24	2017-06-19 18:04:02	2017-06-19 18:04:09
1079	19301E	SENAT	Nouvelles coordonnées	1	2017-09-25 10:54:33	\N
1080	19715Y	SENAT	Nouvelles coordonnées	1	2017-09-25 10:54:33	\N
1081	12016W	SENAT	Nouvelles coordonnées	1	2017-09-25 10:54:33	\N
1082	19717B	SENAT	Nouvelles coordonnées	2	2017-09-25 10:56:48	2017-11-23 17:36:48
1083	19295A	SENAT	Nouvelles coordonnées	1	2017-09-25 11:00:40	\N
1095	14105F	AUTRE	Nouvelles coordonnées	3	2017-10-05 10:40:34	\N
1137	04008A	AUTRE	Nouvelles coordonnées	2	2017-12-19 17:36:30	\N
1145	19415P	PERM	Nouvelles coordonnées	2	2017-12-20 09:39:29	2017-12-20 09:41:04
1189	14051J	PERM	Nouvelles coordonnées	2	2018-01-16 13:00:12	2018-01-16 13:00:20
1207	11099A	PERM	Nouvelles coordonnées	1	2018-02-16 11:07:47	2018-02-16 11:10:49
1221	19637C	AUTRE	Nouvelles coordonnées	2	2018-06-06 10:45:12	\N
1213	19745F	PERM	Nouvelles coordonnées	2	2018-02-28 16:16:54	2018-04-04 14:09:45
1222	04061F	PERM	Nouvelles coordonnées	2	2018-06-06 16:33:12	2018-06-06 16:33:15
1233	19347U	PERM	Nouvelles coordonnées	2	\N	\N
1234	19768N	SENAT	Nouvelles coordonnées	1	\N	\N
1245	19762G	AUTRE	Nouvelles coordonnées	2	\N	\N
1246	11081P	PERM	Nouvelles coordonnées	2	\N	\N
1256	19782L	PERM	Nouvelles coordonnées	1	\N	\N
1278	20014R	SENAT	Nouvelles coordonnées	1	\N	\N
1275	19958S	SENAT	Nouvelles coordonnées	1	\N	\N
1291	20038A	SENAT	Nouvelles coordonnées	1	\N	\N
1295	20046A	SENAT	Nouvelles coordonnées	1	\N	\N
1420	19681G	AUTRE	Nouvelles coordonnées	3	\N	\N
1300	20056C	SENAT	Nouvelles coordonnées	1	\N	\N
1302	20060X	SENAT	Nouvelles coordonnées	1	\N	\N
1303	20062A	SENAT	Nouvelles coordonnées	1	\N	\N
1304	17229F	SENAT	Nouvelles coordonnées	1	\N	\N
1306	20066E	SENAT	Nouvelles coordonnées	1	\N	\N
1318	20088L	SENAT	Nouvelles coordonnées	1	\N	\N
1319	20090E	SENAT	Nouvelles coordonnées	1	\N	\N
1320	20092G	SENAT	Nouvelles coordonnées	1	\N	\N
1329	17737W	SENAT	Nouvelles coordonnées	1	\N	\N
1330	20108W	SENAT	Nouvelles coordonnées	1	\N	\N
1331	20110Q	SENAT	Nouvelles coordonnées	1	\N	\N
1332	20112S	SENAT	Nouvelles coordonnées	1	\N	\N
1333	12028B	SENAT	Nouvelles coordonnées	1	\N	\N
1338	20120S	SENAT	Nouvelles coordonnées	1	\N	\N
1343	20130U	SENAT	Nouvelles coordonnées	1	\N	\N
1344	17367Q	SENAT	Nouvelles coordonnées	1	\N	\N
1345	20132W	SENAT	Nouvelles coordonnées	1	\N	\N
1346	20134Y	SENAT	Nouvelles coordonnées	1	\N	\N
1351	20144B	SENAT	Nouvelles coordonnées	1	\N	\N
1361	17737W	PERM	Nouvelles coordonnées	2	\N	\N
1422	20098N	PERM	Nouvelles coordonnées	1	\N	\N
1465	20298U	AUTRE	Téléphone bureau	2	\N	\N
1467	20248J	AUTRE	Nouvelles coordonnées	3	\N	\N
1499	21077M	SENAT	Nouvelles coordonnées	1	\N	\N
1527	21076L	SENAT	\N	1	\N	\N
1536	21094N	AUTRE	Nouvelles coordonnées	1	\N	\N
\.


--
-- Data for Name: qua; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY qua (quacod, qualic, quanumtri, quacodsex, qualib, qualil, qualicplu, qualibplu, qualilplu, syscredat, sysmajdat) FROM stdin;
M.	Monsieur	1	1	Monsieur	Monsieur	Monsieur	Monsieur	Monsieur	\N	\N
Mme	Madame	2	2	Madame	Madame	Madame	Madame	Madame	\N	\N
Mlle	Mademoiselle	3	2	Mademoiselle	Mademoiselle	Mademoiselle	Mademoiselle	Mademoiselle	\N	\N
\.


--
-- Data for Name: reg; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY reg (regcod, territcod, reglib, regnumtri, regcodparlis, artreg, regurlcmp, syscredat, sysmajdat, regcodrpl, reglic, reglil, regdatdeb, regdatfin, regcodint) FROM stdin;
1	METROPOLE	Alsace	1	\N	d'	http://www.region-alsace.fr/	\N	2015-12-11 14:05:27	27	Alsace	Alsace	\N	2015-12-31 00:00:00	\N
10	METROPOLE	Ile-de-France	10	\N	d'	\N	\N	\N	10	Ile-de-France	Ile-de-France	\N	\N	11
11	METROPOLE	Languedoc-Roussillon	11	\N	du 	http://www.cr-languedocroussillon.fr/	\N	2015-12-11 14:05:27	29	Languedoc-Roussillon	Languedoc-Roussillon	\N	2015-12-31 00:00:00	\N
12	METROPOLE	Limousin	12	\N	du 	http://www.cr-limousin.fr/	\N	2015-12-11 14:05:27	28	Limousin	Limousin	\N	2015-12-31 00:00:00	\N
13	METROPOLE	Lorraine	13	\N	de 	http://www.cr-lorraine.fr/	\N	2015-12-11 14:05:27	27	Lorraine	Lorraine	\N	2015-12-31 00:00:00	\N
14	METROPOLE	Midi-Pyrénées	14	\N	de 	http://www.cr-mip.fr/	\N	2015-12-11 14:05:27	29	Midi-Pyrénées	Midi-Pyrénées	\N	2015-12-31 00:00:00	\N
15	METROPOLE	Nord-Pas-de-Calais	15	\N	du 	http://www.nordpasdecalais.fr/	\N	2015-12-11 14:05:27	26	Nord-Pas-de-Calais	Nord-Pas-de-Calais	\N	2015-12-31 00:00:00	\N
16	METROPOLE	Basse-Normandie	16	\N	de 	http://www.cr-basse-normandie.fr/	\N	2015-12-11 14:05:27	25	Basse-Normandie	Basse-Normandie	\N	2015-12-31 00:00:00	\N
17	METROPOLE	Haute-Normandie	17	\N	de 	http://www.cr-haute-normandie.fr/	\N	2015-12-11 14:05:27	25	Haute-Normandie	Haute-Normandie	\N	2015-12-31 00:00:00	\N
18	METROPOLE	Pays de la Loire	18	\N	des 	http://www.paysdelaloire.fr/	\N	\N	18	Pays de la Loire	Pays de la Loire	\N	\N	52
19	METROPOLE	Picardie	19	\N	de 	http://www.cr-picardie.fr/	\N	2015-12-11 14:05:27	26	Picardie	Picardie	\N	2015-12-31 00:00:00	\N
2	METROPOLE	Aquitaine	2	\N	d'	http://aquitaine.fr/	\N	2015-12-11 14:05:27	28	Aquitaine	Aquitaine	\N	2015-12-31 00:00:00	\N
20	METROPOLE	Poitou-Charentes	20	\N	de 	http://www.cr-poitou-charentes.fr/	\N	2015-12-11 14:05:27	28	Poitou-Charentes	Poitou-Charentes	\N	2015-12-31 00:00:00	\N
21	METROPOLE	Provence-Alpes-Côte d'Azur	21	\N	de 	\N	\N	\N	21	Provence-Alpes-Côte d'Azur	Provence-Alpes-Côte d'Azur	\N	\N	93
3	METROPOLE	Auvergne	3	\N	d'	http://www.cr-auvergne.fr/	\N	2015-12-11 14:05:27	30	Auvergne	Auvergne	\N	2015-12-31 00:00:00	\N
5	METROPOLE	Bretagne	5	\N	de 	http://www.region-bretagne.fr/	\N	\N	5	Bretagne	Bretagne	\N	\N	53
50	DOM	Guadeloupe	50	\N	de 	\N	\N	\N	50	Guadeloupe	Guadeloupe	\N	\N	01
52	DOM	Martinique	52	\N	de 	http://www.cr-martinique.fr/	\N	\N	52	Martinique	Martinique	\N	\N	\N
60	AUTCOM	Nouvelle-Calédonie	70	\N	de 	\N	\N	\N	60	Nouvelle-Calédonie	Nouvelle-Calédonie	\N	\N	\N
61	COM	Polynésie française	63	\N	de 	\N	\N	\N	61	Polynésie française	Polynésie française	\N	\N	\N
62	COM	Iles Wallis et Futuna	62	\N	des 	\N	\N	\N	62	Iles Wallis et Futuna	Iles Wallis et Futuna	\N	\N	\N
7	METROPOLE	Champagne-Ardenne	7	\N	de 	http://www.cr-champagne-ardenne.fr/	\N	2015-12-11 14:05:27	27	Champagne-Ardenne	Champagne-Ardenne	\N	2015-12-31 00:00:00	\N
70	DOM	Mayotte	60	\N	de 	\N	\N	\N	70	Mayotte	Mayotte	\N	\N	\N
71	COM	Saint-Pierre-et-Miquelon	61	\N	de 	\N	\N	\N	71	Saint-Pierre-et-Miquelon	Saint-Pierre-et-Miquelon	\N	\N	\N
8	METROPOLE	Corse	8	\N	de 	\N	\N	\N	8	Corse	Corse	\N	\N	\N
90	SENETRG	Sénateurs représentant les Français établis hors de France	90	\N	\N	\N	\N	\N	90	Sénateurs représentant les Français établis hors de France	Sénateurs représentant les Français établis hors de France	\N	\N	\N
93	ANCIEN5R	Région de la Ve République	93	\N	de 	\N	\N	\N	93	Région de la Ve République	Région de la Ve République	\N	1959-04-28 00:00:00	\N
40	ALGERIE	Départements d'Algérie	40	\N	des 	\N	\N	\N	40	Départements d'Algérie	Départements d'Algérie	\N	1962-07-03 00:00:00	\N
72	COLTERFRA	Côte française des Somalis/Territoire des Afar et des Issas	72	\N	de 	\N	\N	\N	72	Côte française des Somalis/Territoire des Afar et des Issas	Côte française des Somalis/Territoire des Afar et des Issas	\N	1977-03-19 00:00:00	\N
63	TOM	Comores	71	\N	des 	\N	\N	\N	63	Comores	Comores	\N	1975-07-06 00:00:00	\N
22	METROPOLE	Rhône-Alpes	22	\N	de 	http://www.cr-rhone-alpes.fr/	\N	2015-12-11 14:05:27	30	Rhône-Alpes	Rhône-Alpes	\N	2015-12-31 00:00:00	\N
4	METROPOLE	Bourgogne	4	\N	de 	http://www.cr-bourgogne.fr/	\N	2015-12-11 14:05:27	24	Bourgogne	Bourgogne	\N	2015-12-31 00:00:00	\N
51	DOM	Guyane	51	\N	de 	http://www.cr-guyane.fr	\N	\N	51	Guyane	Guyane	\N	\N	\N
53	DOM	La Réunion	53	\N	de 	http://www.region-reunion.com/	\N	\N	53	La Réunion	La Réunion	\N	\N	04
6	METROPOLE	Centre	6	\N	du 	http://www.regioncentre.fr/	\N	2015-12-11 14:05:27	23	Centre	Centre	\N	2015-12-31 00:00:00	\N
9	METROPOLE	Franche-Comté	9	\N	de 	http://www.cr-franche-comte.fr/	\N	2015-12-11 14:05:27	24	Franche-Comté	Franche-Comté	\N	2015-12-31 00:00:00	\N
54	COM	Saint-Barthélemy	54	\N	de 	\N	\N	\N	54	Saint-Barthélemy	Saint-Barthélemy	\N	\N	\N
55	COM	Saint-Martin	55	\N	de	\N	\N	\N	55	Saint-Martin	Saint-Martin	\N	\N	\N
91	ANCIEN4R	Régions de la 4e République	91	\N	\N	\N	\N	\N	91	Régions de la 4e République	Régions de la 4e République	\N	1959-04-26 00:00:00	\N
92	ANCIEN3R	Régions de la 3e République	92	\N	\N	\N	\N	\N	92	Régions de la 3e République	Régions de la 3e République	\N	1945-12-31 00:00:00	\N
23	METROPOLE	Centre-Val de Loire	23	\N	de 	\N	2015-12-11 14:05:11	\N	23	Centre-Val de Loire	Centre-Val de Loire	2016-01-01 00:00:00	\N	24
24	METROPOLE	Bourgogne-Franche-Comté	24	\N	de 	\N	2015-12-11 14:05:11	\N	24	Bourgogne-Franche-Comté	Bourgogne-Franche-Comté	2016-01-01 00:00:00	\N	27
25	METROPOLE	Normandie	25	\N	de 	\N	2015-12-11 14:05:11	\N	25	Normandie	Normandie	2016-01-01 00:00:00	\N	28
26	METROPOLE	Hauts-de-France	26	\N	des 	\N	2015-12-11 14:05:11	\N	26	Hauts-de-France	Hauts-de-France	2016-01-01 00:00:00	\N	32
27	METROPOLE	Grand Est	27	\N	du 	\N	2015-12-11 14:05:11	\N	27	Alsace-Champagne-Ardenne-Lorraine	Alsace-Champagne-Ardenne-Lorraine	2016-01-01 00:00:00	\N	44
28	METROPOLE	Nouvelle Aquitaine	28	\N	de 	\N	2015-12-11 14:05:11	\N	28	Aquitaine-Limousin-Poitou-Charentes	Aquitaine-Limousin-Poitou-Charentes	2016-01-01 00:00:00	\N	75
29	METROPOLE	Occitanie	29	\N	d' 	\N	2015-12-11 14:05:11	\N	29	Languedoc-Roussillon-Midi-Pyrénées	Languedoc-Roussillon-Midi-Pyrénées	2016-01-01 00:00:00	\N	76
30	METROPOLE	Auvergne-Rhône-Alpes	30	\N	d'	\N	2015-12-11 14:05:11	\N	30	Auvergne-Rhône-Alpes	Auvergne-Rhône-Alpes	2016-01-01 00:00:00	\N	84
ETRG	ETRG	Étranger	99	\N	\N	\N	2014-02-26 11:21:15	\N	ETRG	Étranger	Étranger	\N	2014-01-01 00:00:00	\N
\.


--
-- Data for Name: sen; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY sen (senmat, quacod, sennomuse, sennomtec, senprenomuse, sendatnai, sendatdec, etasencod, sendespro, pcscod, catprocod, sengrppolcodcou, sengrppolliccou, sentypappcou, sencomcodcou, sencomliccou, sencirnumcou, sencircou, senburliccou, senema, sennomusecap, senfem, sennumsie, syscredat, sysmajdat, sendaiurl) FROM stdin;
000339	M.	Bajeux	BAJEUX OCTAVE	Octave	1914-04-23 00:00:00	1986-09-19 00:00:00	ANCIEN	Agriculteur	1000	10	UCDP	U.C.D.P.	\N	ECON	ECON	590	Nord	\N	\N	BAJEUX	NON	\N	\N	\N	\N
59564Y	M.	Bangou	BANGOU HENRI	Henri	1922-07-15 00:00:00	2023-11-21 00:00:00	ANCIEN	Médecin	3112	42	C	C	-A	ECON	ECON	971	Guadeloupe	\N	\N	BANGOU	NON	\N	\N	\N	\N
79005G	M.	Barbier	BARBIER BERNARD	Bernard	1924-06-30 00:00:00	1998-02-25 00:00:00	ANCIEN	Négociant en vins	2200	23	RI	RI	\N	FINC	FINC	210	Côte-d'Or	\N	\N	BARBIER	NON	\N	\N	\N	\N
58109Y	M.	Bardol	BARDOL JEAN	Jean	1923-05-06 00:00:00	2004-03-15 00:00:00	ANCIEN	Instituteur	4200	63	C	C	\N	FINC	FINC	620	Pas-de-Calais	\N	\N	BARDOL	NON	\N	\N	\N	\N
58515K	M.	Barkat-Gourat	BARKAT-GOURAT HAMADOU	Hamadou	1930-01-01 00:00:00	2018-03-18 00:00:00	ANCIEN	Sans profession	8000	80	UNR	U.N.R.	\N	SOCI	SOCI	1012	Côte française des Somalis	\N	\N	BARKAT-GOURAT	NON	\N	\N	2018-03-27 17:33:27	\N
000002	M.	Barrachin	BARRACHIN EDMOND	Edmond	1900-01-12 00:00:00	1975-11-08 00:00:00	ANCIEN	Publiciste	3735	55	UCDP	U.C.D.P.	\N	AFCL	AFCL	335	Hauts-de-Seine	\N	\N	BARRACHIN	NON	\N	\N	\N	\N
000529	M.	Barras	BARRAS JEAN	Jean	1924-05-04 00:00:00	1990-04-11 00:00:00	ANCIEN	Directeur d'usine 	2300	21	RPR	RPR	\N	SOCI	SOCI	999	Français établis hors de France	\N	\N	BARRAS	NON	\N	\N	\N	\N
000277	M.	Barroux	BARROUX ANDRÉ	André	1911-09-10 00:00:00	1986-04-06 00:00:00	ANCIEN	Ingénieur	3800	31	SOC	SER	\N	ECON	ECON	630	Puy-de-Dôme	\N	\N	BARROUX	NON	\N	\N	2017-10-04 09:46:28	\N
000400	M.	Baumel	BAUMEL JACQUES	Jacques	1918-03-06 00:00:00	2006-02-17 00:00:00	ANCIEN	Publiciste	3735	55	UNR	U.N.R.	\N	AFCL	AFCL	1029	Seine	\N	\N	BAUMEL	NON	\N	\N	2017-06-15 09:44:01	\N
000663	M.	Bayle	BAYLE JEAN-PIERRE	Jean-Pierre	1947-09-27 00:00:00	\N	ANCIEN	Enseignant	4200	62	SOC	SER	\N	ETRD	ETRD	998	Français établis hors de France	\N	\N	BAYLE	NON	\N	\N	2017-10-04 09:46:28	\N
000116	M.	Bayrou	BAYROU MAURICE	Maurice	1905-03-02 00:00:00	1996-12-29 00:00:00	ANCIEN	Inspecteur général des services de l'élevage d'outre-mer	4500	72	UNR	U.N.R.	\N	ETRD	ETRD	615	Paris	Vice-président du Sénat	\N	BAYROU	NON	\N	\N	2015-02-10 12:00:26	\N
58819Y	M.	Becam	BECAM MARC	Marc	1931-10-09 00:00:00	2021-04-21 00:00:00	ANCIEN	Ingénieur	3800	31	RPR	RPR	\N	LOIS	LOIS	290	Finistère	\N	\N	BECAM	NON	\N	\N	2017-06-15 09:44:12	\N
000091	M.	Belabed	BELABED MOHAMED	Mohamed	1903-11-10 00:00:00	1983-05-25 00:00:00	ANCIEN	Négociant	2200	23	NI	NI	\N	AFCL	AFCL	1030	Oran-Tlemcen	\N	\N	BELABED	NON	\N	\N	2016-08-08 17:28:30	\N
000425	M.	Ahmed	AHMED ABDALLAH ABDERAMANE	Abdallah Abderamane	1919-06-12 00:00:00	1989-11-26 00:00:00	ANCIEN	Commerçant	2200	22	NI	NI	\N	AFCL	AFCL	1025	Comores	\N	\N	AHMED	NON	\N	\N	2015-02-10 12:00:26	\N
57316A	M.	Abdellatif	ABDELLATIF MOHAMED	Mohamed	1918-08-23 00:00:00	1998-12-02 00:00:00	ANCIEN	Propriétaire agriculteur	4500	72	RI	RI	\N	AFCL	AFCL	1040	Tizi-Ouzou	\N	\N	ABDELLATIF	NON	\N	\N	2015-04-24 11:07:46	\N
000346	M.	Achour	ACHOUR YOUSSEF	Youssef	1914-09-07 00:00:00	1992-12-15 00:00:00	ANCIEN	Sous-préfet	3311	71	GD	G.D.	\N	LOIS	LOIS	1021	Alger	\N	\N	ACHOUR	NON	\N	\N	2015-02-10 12:00:26	\N
59533R	M.	D'Aillieres	AILLIERES MICHEL (D')	Michel	1923-12-17 00:00:00	2010-10-31 00:00:00	ANCIEN	Propriétaire exploitant forestier	1000	10	RI	RI	\N	ETRD	ETRD	720	Sarthe	\N	\N	D'AILLIERES	NON	\N	\N	\N	\N
000260	M.	Al Sid Cheikh	AL SID CHEIKH CHEIKH	Cheikh	1910-11-25 00:00:00	1993-05-01 00:00:00	ANCIEN	Caïd des affaires civiles	4500	72	UNR	U.N.R.	-A	AFCL	AFCL	1041	Saoura	\N	\N	AL SID CHEIKH	NON	\N	\N	\N	\N
77002U	M.	Cantegrit	CANTEGRIT	Jean-Pierre	1933-07-02 00:00:00	\N	ANCIEN	Directeur de sociétés	2300	21	UMP	Les Républicains	\N	ETRD	ETRD	1053	Français établis hors de France	\N	jp.cantegrit@senat.fr	CANTEGRIT	NON	\N	\N	2017-10-09 16:22:46	\N
07030L	M.	Couderc	COUDERC RAYMOND	Raymond	1946-09-16 00:00:00	\N	ANCIEN	Professeur d'université	3400	61	UMP	Les Républicains	\N	ETRD	ETRD	340	Hérault	\N	r.couderc@senat.fr	COUDERC	NON	\N	\N	2017-10-09 16:22:47	\N
58343H	Mme	Alduy	ALDUY JACQUELINE	Jacqueline	1924-03-20 00:00:00	2016-03-15 00:00:00	ANCIEN	Sans profession	8000	80	NI	NI	\N	AFCL	AFCL	660	Pyrénées-Orientales	\N	\N	ALDUY	NON	\N	\N	2016-03-25 10:27:23	\N
59213C	M.	Alduy	ALDUY PAUL	Paul	1914-10-04 00:00:00	2006-01-23 00:00:00	ANCIEN	Ancien conseiller d'ambassade - Préfet honoraire	3311	71	UC	UC	-R	ETRD	ETRD	660	Pyrénées-Orientales	\N	\N	ALDUY	NON	\N	\N	2017-07-04 10:59:29	\N
000087	M.	Allies	ALLIES CHARLES	Charles	1903-09-19 00:00:00	1988-11-11 00:00:00	ANCIEN	Directeur de collège technique	4200	62	SOC	SER	\N	FINC	FINC	340	Hérault	\N	\N	ALLIES	NON	\N	\N	2017-10-04 09:46:28	\N
59214D	M.	Amelin	AMELIN JEAN	Jean	1927-05-28 00:00:00	2012-03-08 00:00:00	ANCIEN	Chirurgien dentiste	3113	45	RPR	RPR	\N	ECON	ECON	510	Marne	Secrétaire du Sénat	\N	AMELIN	NON	\N	\N	\N	\N
57716N	M.	Amic	AMIC AUGUSTE	Auguste	1921-09-11 00:00:00	2006-08-14 00:00:00	ANCIEN	Conseiller juridique	3100	57	SOC	SER	\N	FINC	FINC	830	Var	\N	\N	AMIC	NON	\N	\N	2017-10-04 09:46:28	\N
59215E	M.	D'Andigne	ANDIGNE HUBERT (D')	Hubert	1917-04-24 00:00:00	2005-09-22 00:00:00	ANCIEN	Exploitant agricole	1000	10	RPR	RPR	\N	AFCL	AFCL	610	Orne	Secrétaire du Sénat	\N	D'ANDIGNE	NON	\N	\N	\N	\N
000465	Mme	Anglade	ANGLADE MAGDELEINE	Magdeleine	1921-07-05 00:00:00	1998-03-25 00:00:00	ANCIEN	Directeur de société	2300	21	RPR	RPR	\N	AFCL	AFCL	615	Paris	\N	\N	ANGLADE	NON	\N	\N	\N	\N
000037	M.	Armengaud	ARMENGAUD ANDRÉ	André	1901-01-10 00:00:00	1974-03-11 00:00:00	ANCIEN	Ingénieur-conseil	3100	57	RI	RI	\N	FINC	FINC	999	Français établis hors de France	\N	\N	ARMENGAUD	NON	\N	\N	\N	\N
59520L	M.	Arreckx	ARRECKX MAURICE	Maurice	1917-12-13 00:00:00	2001-03-21 00:00:00	ANCIEN	Commerçant	2200	22	RI	RI	\N	AFCL	AFCL	830	Var	\N	\N	ARRECKX	NON	\N	\N	2017-06-15 09:43:49	\N
000012	M.	Auberger	AUBERGER FERNAND	Fernand	1900-05-07 00:00:00	1962-03-06 00:00:00	ANCIEN	Instituteur	4200	63	SOC	SER	\N	FINC	FINC	30	Allier	\N	\N	AUBERGER	NON	\N	\N	2017-10-04 09:46:28	\N
000051	M.	Aubin	AUBIN JEAN	Jean	1901-08-15 00:00:00	1994-01-06 00:00:00	ANCIEN	Agriculteur	1000	10	UC	UC	-A	AFCL	AFCL	50	Hautes-Alpes	\N	\N	AUBIN	NON	\N	\N	2017-07-04 10:59:29	\N
58614M	M.	Aubry	AUBRY ANDRÉ	André	1931-08-01 00:00:00	\N	ANCIEN	Ajusteur	6000	34	C	C	\N	SOCI	SOCI	335	Hauts-de-Seine	\N	\N	AUBRY	NON	\N	\N	\N	\N
000098	M.	Auburtin	AUBURTIN JEAN	Jean	1904-04-26 00:00:00	1981-06-23 00:00:00	ANCIEN	Avocat	3121	51	RPR	RPR	\N	LOIS	LOIS	615	Paris	\N	\N	AUBURTIN	NON	\N	\N	\N	\N
000292	M.	Audy	AUDY MARCEL	Marcel	1912-04-02 00:00:00	1968-01-06 00:00:00	ANCIEN	Industriel	2300	21	GD	G.D.	\N	SOCI	SOCI	190	Corrèze	\N	\N	AUDY	NON	\N	\N	2015-02-10 12:00:26	\N
95010W	M.	Billard	BILLARD CLAUDE	Claude	1941-10-27 00:00:00	\N	ANCIEN	Monteur-câbleur	6000	34	CRC	CRCE	\N	ECON	ECON	824	Val-de-Marne	\N	\N	BILLARD	NON	\N	\N	2017-10-04 09:44:05	\N
58328J	M.	Billeres	BILLERES RENÉ	René	1910-08-29 00:00:00	2004-10-02 00:00:00	ANCIEN	Enseignement supérieur	3400	61	GDSRG	G.D.S.R.G.	\N	AFCL	AFCL	650	Hautes-Pyrénées	\N	\N	BILLERES	NON	\N	\N	\N	\N
000083	M.	Billiemaz	BILLIEMAZ AUGUSTE	Auguste	1903-08-29 00:00:00	1983-04-25 00:00:00	ANCIEN	Industriel	2300	21	GDSRG	G.D.S.R.G.	\N	ECON	ECON	10	Ain	Secrétaire du Sénat	\N	BILLIEMAZ	NON	\N	\N	2015-02-10 12:00:26	\N
59567C	M.	Blanc	BLANC JEAN-PIERRE	Jean-Pierre	1920-09-11 00:00:00	2004-09-29 00:00:00	ANCIEN	Maraîcher	1000	10	UC	UC	\N	AFCL	AFCL	730	Savoie	\N	\N	BLANC	NON	\N	\N	2017-07-04 10:59:29	\N
57426F	M.	Blanchet	BLANCHET JEAN-PIERRE	Jean-Pierre	1914-02-28 00:00:00	2000-07-29 00:00:00	ANCIEN	Chirurgien-dentiste	3113	45	NI	NI	\N	SOCI	SOCI	420	Loire	Secrétaire du Sénat	\N	BLANCHET	NON	\N	\N	2015-08-24 17:13:23	\N
000165	M.	Blondelle	BLONDELLE RENÉ	René	1907-06-13 00:00:00	1971-02-25 00:00:00	ANCIEN	Agriculteur	1000	10	CRARS	CRARS	\N	ECON	ECON	20	Aisne	\N	\N	BLONDELLE	NON	\N	\N	\N	\N
000634	M.	Boeuf	BOEUF MARC	Marc	1934-01-08 00:00:00	1993-08-27 00:00:00	ANCIEN	Directeur de la Mutuelle Générale de l'Education Nationale	3600	32	SOC	SER	\N	SOCI	SOCI	330	Gironde	\N	\N	BOEUF	NON	\N	\N	2017-10-04 09:46:28	\N
000176	M.	Boin	BOIN RAYMOND	Raymond	1908-02-20 00:00:00	1987-05-19 00:00:00	ANCIEN	Médecin	3112	42	GD	G.D.	\N	ETRD	ETRD	520	Haute-Marne	Secrétaire du Sénat	\N	BOIN	NON	\N	\N	\N	\N
58920U	M.	Bonduel	BONDUEL STÉPHANE	Stéphane	1919-11-30 00:00:00	2021-12-16 00:00:00	ANCIEN	Médecin 	3112	42	RDE	R.D.E.	\N	FINC	FINC	170	Charente-Maritime	\N	\N	BONDUEL	NON	\N	\N	\N	\N
58921V	M.	Bonifay	BONIFAY CHARLES	Charles	1919-07-19 00:00:00	2017-01-28 00:00:00	ANCIEN	Directeur Honoraire de l'URSSAF des Bouches-du-Rhône	7300	39	SOC	SER	\N	SOCI	SOCI	130	Bouches-du-Rhône	Secrétaire du Sénat	\N	BONIFAY	NON	\N	\N	2017-10-04 09:46:28	\N
87002A	M.	Moinard	MOINARD	Louis	1930-10-31 00:00:00	2023-05-29 00:00:00	ANCIEN	Agriculteur	1000	10	UC	UC	\N	ETRD	ETRD	850	Vendée	\N	\N	MOINARD	NON	\N	\N	2017-07-04 10:59:30	\N
95059Q	M.	Raffarin	RAFFARIN	Jean-Pierre	1948-08-03 00:00:00	\N	ANCIEN	Consultant	3100	81	UMP	Les Républicains	\N	AFCL	AFCL	860	Vienne	\N	jp.raffarin@senat.fr	RAFFARIN	NON	\N	\N	2017-10-09 16:22:47	\N
90004C	M.	Demerliat	DEMERLIAT	Jean-Pierre	1943-05-08 00:00:00	\N	ANCIEN	Instituteur	4200	63	SOC	SER	\N	ETRD	ETRD	870	Haute-Vienne	\N	jp.demerliat@senat.fr	DEMERLIAT	NON	\N	\N	2017-10-04 09:46:28	\N
95055L	M.	Peyronnet	PEYRONNET	Jean-Claude	1940-11-07 00:00:00	\N	ANCIEN	Maître de conférences agrégé	3400	61	SOC	SER	\N	ETRD	ETRD	870	Haute-Vienne	\N	jc.peyronnet@senat.fr	PEYRONNET	NON	\N	\N	2017-10-04 09:46:28	\N
77058M	M.	Poncelet	PONCELET	Christian	1928-03-24 00:00:00	2020-09-11 00:00:00	ANCIEN	Haut fonctionnaire	3311	71	UMP	Les Républicains	\N	ETRD	ETRD	880	Vosges	\N	c.poncelet@senat.fr	PONCELET	NON	\N	\N	2017-10-09 16:22:47	\N
95004Y	M.	About	ABOUT	Nicolas	1947-07-14 00:00:00	\N	ANCIEN	Médecin	3112	42	UC	UC	\N	SOCI	SOCI	895	Yvelines	\N	n.about@senat.fr	ABOUT	NON	\N	\N	2017-07-04 10:59:30	\N
83003J	M.	François	FRANCOIS PHILIPPE	Philippe	1927-08-16 00:00:00	2019-03-30 00:00:00	ANCIEN	Agriculteur	1000	10	UMP	Les Républicains	\N	ETRD	ETRD	770	Seine-et-Marne	\N	\N	FRANÇOIS	NON	\N	\N	2017-10-09 16:22:47	\N
000665	M.	Bencherif	BENCHERIF MOUAOUIA	Mouaouia	1902-01-01 00:00:00	1982-12-23 00:00:00	ANCIEN	Agriculteur	1000	10	GD	G.D.	-A	AFCL	AFCL	1043	Orléansville-Médéa	\N	\N	BENCHERIF	NON	\N	\N	\N	\N
000047	M.	Bene	BENE JEAN	Jean	1901-07-12 00:00:00	1992-04-26 00:00:00	ANCIEN	Avocat	3121	51	SOC	SER	\N	ETRD	ETRD	340	Hérault	\N	\N	BENE	NON	\N	\N	2017-10-10 17:42:28	\N
59309K	M.	Benedetti	BENEDETTI GEORGES	Georges	1930-07-29 00:00:00	2018-11-19 00:00:00	ANCIEN	Médecin	3112	42	SOC	SER	\N	SOCI	SOCI	300	Gard	\N	\N	BENEDETTI	NON	\N	\N	2017-10-04 09:46:28	\N
68036E	M.	Monory	MONORY	René	1923-06-06 00:00:00	2009-04-11 00:00:00	ANCIEN	Négociant	2200	23	UMP	Les Républicains	\N	ECON	ECON	860	Vienne	\N	\N	MONORY	NON	\N	\N	2017-10-09 16:22:47	\N
95041E	M.	Joyandet	JOYANDET	Alain	1954-01-15 00:00:00	\N	ACTIF	Editeur	7200	29	UMP	Les Républicains	\N	ETRD	ETRD	700	Haute-Saône	\N	a.joyandet@senat.fr	JOYANDET	NON	270	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/joyandet-alain.html
95030B	M.	Émorine	EMORINE	Jean-Paul	1944-03-20 00:00:00	\N	ANCIEN	\N	1000	10	UMP	Les Républicains	\N	ETRD	ETRD	710	Saône-et-Loire	\N	JeanPaul.Emorine@wanadoo.fr	ÉMORINE	NON	\N	\N	2017-11-29 16:09:24	\N
86043F	M.	Pourny	POURNY	André	1928-11-30 00:00:00	2018-06-10 00:00:00	ANCIEN	Commerçant	2200	22	UMP	Les Républicains	-R	SOCI	SOCI	710	Saône-et-Loire	\N	\N	POURNY	NON	\N	\N	2017-10-09 16:22:47	\N
95020Y	M.	Courtois	COURTOIS	Jean-Patrick	1951-05-20 00:00:00	\N	ANCIEN	Attaché principal de préfecture	3300	79	UMP	Les Républicains	\N	LOIS	LOIS	710	Saône-et-Loire	\N	jp.courtois@senat.fr	COURTOIS	NON	\N	\N	2017-10-09 16:22:47	\N
77012W	M.	Chaumont	CHAUMONT	Jacques	1934-11-17 00:00:00	\N	ANCIEN	Secrétaire des Affaires étrangères (honoraire)	7400	79	UMP	Les Républicains	\N	FINC	FINC	720	Sarthe	\N	\N	CHAUMONT	NON	\N	\N	2017-10-09 16:22:47	\N
77043E	M.	du Luart	LUART ROLAND (DU)	Roland	1940-03-12 00:00:00	\N	ANCIEN	Exploitant agricole et forestier	1000	10	UMP	Les Républicains	\N	FINC	FINC	720	Sarthe	\N	r.duluart@senat.fr	du LUART	NON	\N	\N	2017-10-09 16:22:47	\N
77060F	M.	Rinchet	RINCHET	Roger	1933-06-16 00:00:00	\N	ANCIEN	Retraité de l'Education nationale	7400	69	SOC	SER	\N	ECON	ECON	730	Savoie	\N	\N	RINCHET	NON	\N	\N	2017-10-04 09:46:28	\N
95015C	M.	Carle	CARLE	Jean-Claude	1948-06-09 00:00:00	2019-12-13 00:00:00	ANCIEN	Agent technique	4700	39	UMP	Les Républicains	\N	AFCL	AFCL	740	Haute-Savoie	\N	jean-claude.carle@wanadoo.fr	CARLE	NON	\N	\N	2017-10-09 16:22:47	\N
07023M	Mme	Panis	PANIS JACQUELINE	Jacqueline	1948-04-16 00:00:00	\N	ANCIEN	Gérante de société	2000	21	UMP	Les Républicains	-R	ECON	ECON	540	Meurthe-et-Moselle	\N	j.panis@senat.fr	PANIS	NON	\N	\N	2017-10-09 16:22:47	\N
95038K	M.	Hérisson	HERISSON	Pierre	1945-06-12 00:00:00	\N	ANCIEN	Entrepreneur	2000	21	UMP	Les Républicains	\N	CAE	CAE	740	Haute-Savoie	\N	p.herisson@senat.fr	HÉRISSON	NON	\N	\N	2017-10-09 16:22:47	\N
95005A	M.	Amoudry	AMOUDRY	Jean-Paul	1950-03-30 00:00:00	\N	ANCIEN	Directeur territorial	4500	71	UC	UC	\N	SOCI	SOCI	740	Haute-Savoie	\N	jp.amoudry@senat.fr	AMOUDRY	NON	\N	\N	2017-07-04 10:59:30	\N
95014B	Mme	Bocandé	BOCANDE	Annick	1946-04-23 00:00:00	\N	ANCIEN	Sans profession déclarée	8000	80	UC	UC	\N	SOCI	SOCI	760	Seine-Maritime	Secrétaire du Sénat	\N	BOCANDÉ	NON	\N	\N	2017-07-04 10:59:30	\N
95062K	M.	Revet	REVET	Charles	1937-11-09 00:00:00	2021-11-30 00:00:00	ANCIEN	Agriculteur	1000	10	UMP	Les Républicains	\N	CDD	CDD	760	Seine-Maritime	\N	revet.charles@wanadoo.fr	REVET	NON	\N	\N	2017-10-09 16:22:47	\N
88006J	M.	Pagès	PAGES	Robert	1933-06-29 00:00:00	2011-02-23 00:00:00	ANCIEN	Instituteur	4200	63	CRC	CRCE	\N	LOIS	LOIS	760	Seine-Maritime	\N	\N	PAGÈS	NON	\N	\N	2017-10-04 09:44:05	\N
83021L	M.	Cazalet	CAZALET	Auguste	1938-09-07 00:00:00	2013-06-04 00:00:00	ANCIEN	Agriculteur	1000	10	UMP	Les Républicains	\N	FINC	FINC	640	Pyrénées-Atlantiques	\N	a.cazalet@senat.fr	CAZALET	NON	\N	\N	2017-10-09 16:22:47	\N
92013M	M.	Borotra	BOROTRA DIDIER	Didier	1937-08-30 00:00:00	\N	ANCIEN	Industriel	2300	21	UC	UC	\N	ETRD	ETRD	640	Pyrénées-Atlantiques	\N	d.borotra@senat.fr	BOROTRA	NON	\N	\N	2017-07-04 10:59:30	\N
000321	M.	Benard Mousseaux	BENARD MOUSSEAUX JEAN	Jean	1913-08-02 00:00:00	1996-05-29 00:00:00	ANCIEN	Agriculteur	1000	10	UREI	U.R.E.I.	\N	LOIS	LOIS	360	Indre	\N	\N	BENARD MOUSSEAUX	NON	\N	\N	\N	\N
92020L	Mme	Durrieu	DURRIEU	Josette	1937-03-20 00:00:00	\N	ANCIEN	Professeur	4200	62	SOC	SER	\N	ETRD	ETRD	650	Hautes-Pyrénées	\N	j.durrieu@senat.fr	DURRIEU	OUI	\N	\N	2017-10-04 09:46:28	\N
92036U	M.	Marquès	MARQUES	René	1923-01-17 00:00:00	2013-08-01 00:00:00	ANCIEN	Médecin	3112	42	UC	UC	\N	ETRD	ETRD	660	Pyrénées-Orientales	\N	\N	MARQUÈS	NON	\N	\N	2017-07-04 10:59:30	\N
92011K	M.	Blanc	BLANC PAUL	Paul	1937-01-29 00:00:00	\N	ANCIEN	Médecin	3112	42	UMP	Les Républicains	\N	SOCI	SOCI	660	Pyrénées-Orientales	\N	senateur.paul.blanc@wanadoo.fr	BLANC	NON	\N	\N	2017-10-09 16:22:47	\N
95036H	M.	Grignon	GRIGNON	Francis	1944-01-03 00:00:00	\N	ANCIEN	Ingénieur	3800	31	UMP	Les Républicains	-R	CDD	CDD	670	Bas-Rhin	\N	f.grignon@senat.fr	GRIGNON	NON	\N	\N	2017-10-09 16:22:47	\N
92005M	M.	Richert	RICHERT	Philippe	1953-05-22 00:00:00	\N	ANCIEN	Principal de collège	4200	62	UMP	Les Républicains	\N	AFCL	AFCL	670	Bas-Rhin	\N	p.richert@senat.fr	RICHERT	NON	\N	\N	2017-10-09 16:22:47	\N
95029J	M.	Eckenspieller	ECKENSPIELLER	Daniel	1931-12-15 00:00:00	2023-10-28 00:00:00	ANCIEN	Retraité de l'Education nationale	7400	69	UMP	Les Républicains	\N	AFCL	AFCL	680	Haut-Rhin	\N	\N	ECKENSPIELLER	NON	\N	\N	2017-10-09 16:22:47	\N
86030A	M.	Haenel	HAENEL	Hubert	1942-05-20 00:00:00	2015-08-10 00:00:00	ANCIEN	Maître des requêtes au Conseil d'Etat	3311	71	UMP	Les Républicains	\N	ETRD	ETRD	680	Haut-Rhin	\N	h.haenel@senat.fr	HAENEL	NON	\N	\N	2017-10-09 16:22:48	\N
11027H	Mme	Conway-Mouret	CONWAY_MOURET_HELENE	Hélène	1960-09-13 00:00:00	\N	ACTIF	Professeure d'université	8000	61	SOC	SER	\N	ETRD	ETRD	1053	Français établis hors de France	\N	h.conway-mouret@senat.fr	CONWAY-MOURET	OUI	151	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/conway-mouret-helene.html
58041V	M.	Bonnet	BONNET EUGÈNE	Eugène	1922-04-20 00:00:00	2003-07-17 00:00:00	ANCIEN	Fonctionnaire	4500	73	UREI	U.R.E.I.	-A	ETRD	ETRD	310	Haute-Garonne	\N	\N	BONNET	NON	\N	\N	\N	\N
000160	M.	Bonnet	BONNET GEORGES	Georges	1907-02-15 00:00:00	1973-06-25 00:00:00	ANCIEN	Chef de service à l'Electricité de France	4500	72	RI	RI	\N	ECON	ECON	480	Lozère	\N	\N	BONNET	NON	\N	\N	\N	\N
000198	M.	Bordeneuve	BORDENEUVE JACQUES	Jacques	1908-08-28 00:00:00	1981-01-03 00:00:00	ANCIEN	Avocat	3121	51	GD	G.D.	\N	AFCL	AFCL	470	Lot-et-Garonne	\N	\N	BORDENEUVE	NON	\N	\N	2015-02-10 12:00:26	\N
000081	M.	Bossus	BOSSUS RAYMOND	Raymond	1903-07-25 00:00:00	1981-02-06 00:00:00	ANCIEN	Ouvrier du bâtiment	6000	34	C	C	\N	SOCI	SOCI	615	Paris	\N	\N	BOSSUS	NON	\N	\N	\N	\N
58620K	M.	Boucheny	BOUCHENY SERGE	Serge	1929-03-22 00:00:00	\N	ANCIEN	Ouvrier	6000	34	C	C	\N	ETRD	ETRD	615	Paris	\N	\N	BOUCHENY	NON	\N	\N	\N	\N
000316	M.	Boulanger	BOULANGER GEORGES	Georges	1913-07-04 00:00:00	1976-11-14 00:00:00	ANCIEN	Directeur de mutualité agricole	4500	72	RP	RP	\N	LOIS	LOIS	620	Pas-de-Calais	\N	\N	BOULANGER	NON	\N	\N	\N	\N
000374	M.	Bouloux	BOULOUX JEAN-MARIE	Jean-Marie	1916-06-06 00:00:00	1992-01-22 00:00:00	ANCIEN	Cadre	3600	32	UC	UC	-R	SOCI	SOCI	860	Vienne	\N	\N	BOULOUX	NON	\N	\N	2017-07-04 10:59:30	\N
59217G	M.	Belin	BELIN GILBERT	Gilbert	1927-10-22 00:00:00	2020-02-13 00:00:00	ANCIEN	Professeur	4200	62	SOC	SER	\N	AFCL	AFCL	630	Puy-de-Dôme	\N	\N	BELIN	NON	\N	\N	2017-10-04 09:46:29	\N
000234	M.	Belkadi	BELKADI ABDENNOUR	Abdennour	1910-01-06 00:00:00	2014-10-08 00:00:00	ANCIEN	Agriculteur	1000	10	RI	RI	-A	SOCI	SOCI	1040	Tizi-Ouzou	\N	\N	BELKADI	NON	\N	\N	\N	\N
000021	M.	Benacer	BENACER SALAH	Salah	1900-07-06 00:00:00	1961-11-12 00:00:00	ANCIEN	Agriculteur, négociant et industriel	1000	10	NI	NI	\N	LOIS	LOIS	1040	Tizi-Ouzou	\N	\N	BENACER	NON	\N	\N	2015-02-10 12:00:26	\N
000541	M.	Benard	BENARD PAUL	Paul	1924-12-09 00:00:00	1987-02-02 00:00:00	ANCIEN	Pharmacien	3116	44	RPR	RPR	-A	AFCL	AFCL	974	La Réunion	\N	\N	BENARD	NON	\N	\N	\N	\N
58302X	M.	Benoist	BENOIST DANIEL	Daniel	1908-02-09 00:00:00	2004-05-03 00:00:00	ANCIEN	Chirurgien	3112	43	SOC	SER	\N	SOCI	SOCI	580	Nièvre	\N	\N	BENOIST	NON	\N	\N	2017-10-04 09:46:29	\N
56326X	M.	Bentchicou	BENTCHICOU AHMED	Ahmed	1910-08-11 00:00:00	2004-08-20 00:00:00	ANCIEN	Pharmacien	3116	44	UNR	U.N.R.	\N	ETRD	ETRD	1033	Constantine	\N	\N	BENTCHICOU	NON	\N	\N	2015-02-10 12:00:26	\N
000553	M.	Beranger	BERANGER JEAN	Jean	1925-08-21 00:00:00	1997-01-17 00:00:00	ANCIEN	Cadre	3600	32	GD	G.D.	\N	SOCI	SOCI	895	Yvelines	Secrétaire du Sénat	\N	BERANGER	NON	\N	\N	\N	\N
59566B	M.	Berard	BERARD JACQUES	Jacques	1929-06-07 00:00:00	2014-06-01 00:00:00	ANCIEN	Avocat honoraire	7400	59	RPR	RPR	\N	LOIS	LOIS	840	Vaucluse	\N	\N	BERARD	NON	\N	\N	2014-06-03 13:43:28	\N
59583C	M.	Bernard	BERNARD ROLAND	Roland	1944-10-11 00:00:00	2009-05-06 00:00:00	ANCIEN	Universitaire	3400	61	SOC	SER	\N	ETRD	ETRD	690	Rhône	\N	\N	BERNARD	NON	\N	\N	2017-10-04 09:46:29	\N
000340	M.	Bernier	BERNIER LUCIEN	Lucien	1914-05-27 00:00:00	1989-04-05 00:00:00	ANCIEN	Avocat	3121	51	SOC	SER	\N	SOCI	SOCI	971	Guadeloupe	Secrétaire du Sénat	\N	BERNIER	NON	\N	\N	2017-10-04 09:46:29	\N
000113	M.	Bertrand	BERTRAND MARCEL	Marcel	1904-11-06 00:00:00	1961-09-19 00:00:00	ANCIEN	Journaliste	3511	54	SOC	SER	\N	AFCL	AFCL	590	Nord	\N	\N	BERTRAND	NON	\N	\N	2017-10-04 09:46:29	\N
58911T	M.	Besse	BESSE GUY	Guy	1926-04-14 00:00:00	2017-12-17 00:00:00	ANCIEN	Artisan	2100	24	RDE	R.D.E.	\N	SOCI	SOCI	360	Indre	\N	\N	BESSE	NON	\N	\N	2018-01-08 09:01:23	\N
59522N	M.	Bettencourt	BETTENCOURT ANDRÉ	André	1919-04-21 00:00:00	2007-11-19 00:00:00	ANCIEN	Chef d'entreprise	2300	21	RI	RI	\N	ETRD	ETRD	760	Seine-Maritime	\N	\N	BETTENCOURT	NON	\N	\N	2017-12-19 15:12:17	\N
79002D	M.	Bialski	BIALSKI JACQUES	Jacques	1929-10-03 00:00:00	2013-06-10 00:00:00	ANCIEN	Cadre	3600	32	SOC	SER	\N	SOCI	SOCI	590	Nord	Questeur du Sénat	\N	BIALSKI	NON	\N	\N	2017-10-04 09:46:29	\N
57741P	M.	Bac	BAC JEAN	Jean	1915-04-01 00:00:00	2005-02-14 00:00:00	ANCIEN	Administrateur de sociétés	2300	21	RPR	RPR	\N	LOIS	LOIS	895	Yvelines	\N	\N	BAC	NON	\N	\N	\N	\N
000016	M.	de Bagneux	BAGNEUX JEAN DE	Jean	1900-07-17 00:00:00	1983-10-26 00:00:00	ANCIEN	Sans profession	8000	80	UREI	U.R.E.I.	\N	AFCL	AFCL	1026	Côtes-du-Nord	\N	\N	de BAGNEUX	NON	\N	\N	2014-05-30 11:39:47	\N
000490	M.	Bailly	BAILLY JEAN	Jean	1922-05-31 00:00:00	1984-04-21 00:00:00	ANCIEN	Administrateur Civil	3311	71	UDR	U.D.R.	\N	NEANT	Aucune	125	Territoire de Belfort	\N	\N	BAILLY	NON	\N	\N	\N	\N
71024A	M.	Le Jeune	LEJEUNEE	Edouard	1921-02-20 00:00:00	2017-04-09 00:00:00	ANCIEN	Agriculteur	1000	10	UC	UC	\N	ETRD	ETRD	290	Finistère	\N	\N	LE JEUNE	NON	\N	\N	2017-07-04 10:59:30	\N
86006A	M.	Gérard	GERARD	Alain	1937-12-02 00:00:00	2018-02-26 00:00:00	ANCIEN	Cadre administratif	3600	32	UMP	Les Républicains	\N	ECON	ECON	290	Finistère	\N	a.gerard@senat.fr	GÉRARD	NON	\N	\N	2018-02-28 11:07:39	\N
89034S	M.	de Menou	MENOU	Jacques	1932-10-30 00:00:00	2010-08-11 00:00:00	ANCIEN	Ingénieur agronome	3800	31	RPR	RPR	\N	ECON	ECON	290	Finistère	\N	\N	DE MENOU	NON	\N	\N	\N	\N
92046W	M.	Cavalier-Benezet	CAVALIER BENEZET	Francis	1922-01-22 00:00:00	2014-09-07 00:00:00	ANCIEN	Exploitant agricole	1000	10	SOC	SER	\N	SOCI	SOCI	300	Gard	\N	\N	CAVALIER-BENEZET	NON	\N	\N	2017-10-04 09:46:29	\N
80040B	M.	Rouvière	ROUVIERE	André	1936-04-29 00:00:00	2015-11-02 00:00:00	ANCIEN	Enseignant retraité	7400	69	SOC	SER	\N	ETRD	ETRD	300	Gard	\N	permanence.rouviere@wanadoo.fr	ROUVIÈRE	NON	\N	\N	2017-10-04 09:46:29	\N
80033C	M.	Peyrafitte	PEYRAFITTE	Jean	1922-06-15 00:00:00	2017-11-11 00:00:00	ANCIEN	Hôtelier	2200	22	SOC	SER	\N	ECON	ECON	310	Haute-Garonne	\N	\N	PEYRAFITTE	NON	\N	\N	2018-01-24 13:49:40	\N
89019T	Mme	Bergé-Lavigne	BERGE-LAVIGNE	Maryse	1941-01-29 00:00:00	\N	ANCIEN	Institutrice	4200	63	SOC	SER	\N	ETRD	ETRD	310	Haute-Garonne	\N	mbl.permanence@wanadoo.fr	BERGÉ-LAVIGNE	OUI	\N	\N	2017-10-04 09:46:29	\N
89008Q	M.	Castaing	CASTAING	Robert	1930-09-06 00:00:00	2002-11-11 00:00:00	ANCIEN	Professeur	4200	62	SOC	SER	\N	AFCL	AFCL	320	Gers	\N	\N	CASTAING	NON	\N	\N	2017-10-04 09:46:29	\N
93006S	Mme	Dusseau	DUSSEAU	Joëlle	1947-07-05 00:00:00	\N	ANCIEN	Professeur agrégé d'histoire et géographie	3400	61	RDSE	RDSE	\N	SOCI	SOCI	330	Gironde	\N	\N	DUSSEAU	NON	\N	\N	\N	\N
11029K	Mme	Bouchoux	BOUCHOUX_CORINNE_11029K	Corinne	1964-01-05 00:00:00	\N	ANCIEN	Personnel de direction, Éducation Nationale	3400	64	NI	NI	\N	AFCL	AFCL	490	Maine-et-Loire	Secrétaire du Sénat	c.bouchoux@senat.fr	BOUCHOUX	OUI	\N	\N	2017-09-24 17:09:24	\N
80021X	M.	Hugo	HUGO BERNARD CHARLES	Bernard Charles	1925-05-04 00:00:00	2001-10-15 00:00:00	ANCIEN	Proviseur de lycée	4200	62	RPR	RPR	\N	ECON	ECON	70	Ardèche	\N	\N	HUGO	NON	\N	\N	2017-11-08 17:00:20	\N
96005E	M.	Flandre	FLANDRE	Hilaire	1937-02-24 00:00:00	2004-10-18 00:00:00	ANCIEN	Agriculteur	1000	10	UMP	Les Républicains	\N	ECON	ECON	80	Ardennes	\N	\N	FLANDRE	NON	\N	\N	2017-10-09 16:22:48	\N
71003U	M.	Blin	BLIN	Maurice	1922-08-28 00:00:00	2016-06-16 00:00:00	ANCIEN	Universitaire	3400	61	UC	UC	\N	FINC	FINC	80	Ardennes	\N	m.blin@senat.fr	BLIN	NON	\N	\N	2017-07-04 10:59:30	\N
80004W	M.	Authié	AUTHIE	Germain	1927-07-04 00:00:00	2001-09-04 00:00:00	ANCIEN	Instituteur spécialisé	4200	63	SOC	SER	\N	LOIS	LOIS	90	Ariège	\N	\N	AUTHIÉ	NON	\N	\N	2017-10-04 09:46:29	\N
89017R	M.	Adnot	ADNOT	Philippe	1945-08-25 00:00:00	\N	ANCIEN	Agriculteur	1000	10	NI	NI	\N	FINC	FINC	100	Aube	\N	p.adnot@senat.fr	ADNOT	NON	\N	\N	2017-10-04 19:03:32	\N
94003T	M.	Gaillard	GAILLARD	Yann	1936-10-09 00:00:00	2022-11-06 00:00:00	ANCIEN	Inspecteur général des Finances	3311	71	UMP	Les Républicains	\N	FINC	FINC	100	Aube	\N	y.gaillard@senat.fr	GAILLARD	NON	\N	\N	2017-10-09 16:22:48	\N
74050Q	M.	Courrière	COURRIERE	Raymond	1932-08-23 00:00:00	2006-08-11 00:00:00	ANCIEN	Notaire honoraire	7400	59	SOC	SER	\N	LOIS	LOIS	110	Aude	\N	\N	COURRIÈRE	NON	\N	\N	2017-10-04 09:46:29	\N
80013X	M.	Courteau	COURTEAU	Roland	1943-02-24 00:00:00	\N	ANCIEN	Instituteur	4200	69	SOC	SER	\N	CAE	CAE	110	Aude	\N	roland.courteau@wanadoo.fr	COURTEAU	NON	\N	\N	2017-10-04 09:46:29	\N
80017C	M.	Dreyfus-Schmidt	DREYFUS-SCHMIDT	Michel	1932-06-17 00:00:00	2008-09-07 00:00:00	ANCIEN	Avocat	3121	51	SOC	SER	\N	LOIS	LOIS	125	Territoire de Belfort	\N	m.dreyfus-schmidt@senat.fr	DREYFUS-SCHMIDT	NON	\N	\N	2017-10-04 09:46:29	\N
78010Y	M.	Minetti	MINETTI	Louis	1925-09-01 00:00:00	2024-03-14 00:00:00	ANCIEN	Agriculteur	1000	10	CRC	CRCE	\N	ECON	ECON	130	Bouches-du-Rhône	\N	\N	MINETTI	NON	\N	\N	2017-10-04 09:44:05	\N
89024Q	M.	Camoin	CAMOIN	Jean-Pierre	1942-05-09 00:00:00	\N	ANCIEN	Médecin	3112	42	RPR	RPR	\N	FINC	FINC	130	Bouches-du-Rhône	\N	\N	CAMOIN	NON	\N	\N	\N	\N
000295	M.	Bourda	BOURDA PIERRE	Pierre	1912-07-01 00:00:00	1991-11-01 00:00:00	ANCIEN	Avocat	3121	51	GD	G.D.	\N	LOIS	LOIS	650	Hautes-Pyrénées	\N	\N	BOURDA	NON	\N	\N	\N	\N
95024D	M.	Demuynck	DEMUYNCK	Christian	1947-07-24 00:00:00	\N	ANCIEN	Professeur d'éducation physique et sportive	3400	64	UMP	Les Républicains	\N	AFCL	AFCL	775	Seine-Saint-Denis	\N	c.demuynck@senat.fr	DEMUYNCK	NON	\N	\N	2017-10-09 16:22:48	\N
95046K	M.	Mahéas	MAHEAS	Jacques	1939-07-10 00:00:00	2022-08-20 00:00:00	ANCIEN	Principal de collège	3311	62	SOC	SER	\N	LOIS	LOIS	775	Seine-Saint-Denis	\N	j.maheas@senat.fr	MAHÉAS	NON	\N	\N	2017-10-04 09:46:29	\N
95009E	M.	Bécot	BECOT	Michel	1939-10-10 00:00:00	\N	ANCIEN	Chef d'entreprise	2300	21	UMP	Les Républicains	\N	CAE	CAE	790	Deux-Sèvres	\N	m.becot@senat.fr	BÉCOT	NON	\N	\N	2017-10-09 16:22:48	\N
95028H	M.	Dulait	DULAIT	André	1937-11-14 00:00:00	2020-01-18 00:00:00	ANCIEN	Docteur vétérinaire	3115	46	UMP	Les Républicains	\N	ETRD	ETRD	790	Deux-Sèvres	\N	a.dulait@senat.fr	DULAIT	NON	\N	\N	2017-10-09 16:22:48	\N
95025E	M.	Deneux	DENEUX	Marcel	1928-08-16 00:00:00	\N	ANCIEN	Agriculteur	1000	10	UC	UC	\N	CDD	CDD	800	Somme	\N	m.deneux@senat.fr	DENEUX	NON	\N	\N	2017-07-04 10:59:30	\N
95047L	M.	Martin	MARTIN PIERRE	Pierre	1943-09-27 00:00:00	2023-07-11 00:00:00	ANCIEN	Directeur d'école	4200	63	UMP	Les Républicains	\N	AFCL	AFCL	800	Somme	\N	p.martin@senat.fr	MARTIN	NON	\N	\N	2017-10-09 16:22:48	\N
95048M	M.	Mazars	MAZARS	Georges	1934-11-03 00:00:00	1998-11-02 00:00:00	ANCIEN	Enseignant à la retraite	7400	69	SOC	SER	\N	SOCI	SOCI	810	Tarn	\N	\N	MAZARS	NON	\N	\N	2017-10-04 09:46:29	\N
88008L	M.	Collin	COLLIN	Yvon	1944-04-10 00:00:00	\N	ANCIEN	Directeur de Cabinet	3311	79	RDSE	RDSE	\N	FINC	FINC	820	Tarn-et-Garonne	\N	y.collin@senat.fr	COLLIN	NON	\N	\N	2017-10-04 18:42:23	\N
11020A	M.	Fontaine	FONTAINE_MICHEL_11020A	Michel	1952-05-06 00:00:00	\N	ANCIEN	Médecin radiologue	8000	42	UMP	Les Républicains	\N	CDD	CDD	974	La Réunion	\N	m.fontaine@senat.fr	FONTAINE	NON	\N	\N	2017-10-09 16:22:48	\N
77044F	Mme	Luc	LUC HELENE	Hélène	1932-03-13 00:00:00	\N	ANCIEN	Sans profession déclarée	8000	80	CRC	CRCE	\N	ETRD	ETRD	824	Val-de-Marne	\N	h.luc@senat.fr	LUC	OUI	\N	\N	2017-10-04 09:44:05	\N
000365	M.	Brosseau	BROSSEAU RAYMOND	Raymond	1915-06-16 00:00:00	1980-09-27 00:00:00	ANCIEN	Préparateur en pharmacie	3100	47	C	C	\N	LOIS	LOIS	265	Essonne	\N	\N	BROSSEAU	NON	\N	\N	2016-08-09 10:55:17	\N
000574	M.	Brousse	BROUSSE PIERRE	Pierre	1926-11-30 00:00:00	1992-07-30 00:00:00	ANCIEN	Chargé de mission au Cabinet du Président du Sénat	3000	32	GD	G.D.	\N	FINC	FINC	340	Hérault	\N	\N	BROUSSE	NON	\N	\N	\N	\N
58946F	M.	Brun	BRUN RAYMOND	Raymond	1915-03-18 00:00:00	2006-12-29 00:00:00	ANCIEN	Industriel	2300	21	RPR	RPR	-A	ECON	ECON	330	Gironde	\N	\N	BRUN	NON	\N	\N	\N	\N
000053	M.	Bruneau	BRUNEAU ANDRÉ	André	1901-09-05 00:00:00	1973-04-11 00:00:00	ANCIEN	Médecin	3112	42	UREI	U.R.E.I.	-R	SOCI	SOCI	720	Sarthe	\N	\N	BRUNEAU	NON	\N	\N	\N	\N
000035	M.	Brunhes	BRUNHES JULIEN	Julien	1900-11-25 00:00:00	1986-11-11 00:00:00	ANCIEN	Ingénieur	3800	31	UREI	U.R.E.I.	\N	ETRD	ETRD	1029	Seine	\N	\N	BRUNHES	NON	\N	\N	\N	\N
57432D	M.	Bruyneel	BRUYNEEL ROBERT	Robert	1905-06-25 00:00:00	1999-03-17 00:00:00	ANCIEN	Administrateur civil	8000	80	RI	RI	\N	LOIS	LOIS	410	Loir-et-Cher	\N	\N	BRUYNEEL	NON	\N	\N	\N	\N
000010	M.	Burgat	BURGAT GABRIEL	Gabriel	1899-03-20 00:00:00	1975-06-26 00:00:00	ANCIEN	Agriculteur	1000	10	UNR	U.N.R.	\N	ECON	ECON	1042	Bône	\N	\N	BURGAT	NON	\N	\N	2016-08-09 10:58:16	\N
000150	M.	Burret	BURRET ROBERT	Robert	1906-08-25 00:00:00	1985-03-08 00:00:00	ANCIEN	Technicien-géomètre	3100	57	RI	RI	\N	SOCI	SOCI	650	Hautes-Pyrénées	\N	\N	BURRET	NON	\N	\N	\N	\N
59524Q	M.	Cabana	CABANA CAMILLE	Camille	1930-12-11 00:00:00	2002-06-02 00:00:00	ANCIEN	Préfet honoraire	7400	79	RPR	RPR	\N	FINC	FINC	615	Paris	\N	\N	CABANA	NON	\N	\N	\N	\N
58411C	M.	Caillavet	CAILLAVET HENRI	Henri	1914-02-13 00:00:00	2013-02-27 00:00:00	ANCIEN	Avocat	3121	51	GDSRG	G.D.S.R.G.	\N	FINC	FINC	470	Lot-et-Garonne	\N	\N	CAILLAVET	NON	\N	\N	\N	\N
000538	M.	Caiveau	CAIVEAU LOUIS	Louis	1924-10-03 00:00:00	1987-02-27 00:00:00	ANCIEN	Ancien entrepreneur de travaux publics	7200	29	UC	UC	\N	ECON	ECON	850	Vendée	\N	\N	CAIVEAU	NON	\N	\N	2017-07-04 10:59:30	\N
59526S	M.	Caron	CARON PAUL	Paul	1921-07-13 00:00:00	2012-02-02 00:00:00	ANCIEN	Industriel	2300	21	UC	UC	\N	ETRD	ETRD	760	Seine-Maritime	\N	\N	CARON	NON	\N	\N	2017-07-04 10:59:30	\N
000326	M.	Carous	CAROUS PIERRE	Pierre	1913-09-17 00:00:00	1990-01-14 00:00:00	ANCIEN	Avocat	3121	51	RPR	RPR	\N	AFCL	AFCL	590	Nord	Vice-président du Sénat	\N	CAROUS	NON	\N	\N	2017-12-19 15:12:17	\N
000003	M.	Carrier	CARRIER MAURICE	Maurice	1900-01-15 00:00:00	1981-11-30 00:00:00	ANCIEN	Agriculteur	1000	10	UNR	U.N.R.	\N	ETRD	ETRD	998	Français établis hors de France	\N	\N	CARRIER	NON	\N	\N	2015-02-10 12:00:26	\N
58936D	M.	Castex	CASTEX MARC	Marc	1914-09-13 00:00:00	2002-05-17 00:00:00	ANCIEN	Directeur de société	7300	39	UREI	U.R.E.I.	\N	SOCI	SOCI	320	Gers	\N	\N	CASTEX	NON	\N	\N	\N	\N
000350	M.	Cathala	CATHALA CHARLES	Charles	1914-11-06 00:00:00	1996-11-24 00:00:00	ANCIEN	Directeur de société	2300	21	NI	NI	\N	SOCI	SOCI	775	Seine-Saint-Denis	Secrétaire du Sénat	\N	CATHALA	NON	\N	\N	\N	\N
59570W	M.	De Catuelan	CATUELAN LOUIS (DE)	Louis	1924-03-29 23:00:00	2003-03-31 00:00:00	ANCIEN	Agriculteur	1000	10	UC	UC	\N	ECON	ECON	895	Yvelines	\N	\N	DE CATUELAN	NON	\N	\N	2017-07-04 10:59:30	\N
000327	M.	Cauchon	CAUCHON JEAN	Jean	1913-11-21 00:00:00	1991-11-16 00:00:00	ANCIEN	Directeur de société	2300	21	UC	UC	\N	SOCI	SOCI	280	Eure-et-Loir	Questeur du Sénat	\N	CAUCHON	NON	\N	\N	2017-07-04 10:59:30	\N
000510	M.	Caupert	CAUPERT JOSEPH	Joseph	1923-07-04 00:00:00	1994-09-09 00:00:00	ANCIEN	Notaire	3128	52	RI	RI	\N	ECON	ECON	480	Lozère	\N	\N	CAUPERT	NON	\N	\N	\N	\N
58202U	M.	Cavaillé	CAVAILLE MARCEL	Marcel	1927-02-03 00:00:00	2013-02-14 00:00:00	ANCIEN	Ingénieur EDF	3800	31	RI	RI	\N	SOCI	SOCI	310	Haute-Garonne	\N	\N	CAVAILLÉ	NON	\N	\N	\N	\N
59601L	M.	Cayrel	CAYREL RAYMOND	Raymond	1921-07-29 00:00:00	2001-01-05 00:00:00	ANCIEN	Agriculteur	1000	10	RI	RI	\N	ECON	ECON	120	Aveyron	\N	\N	CAYREL	NON	\N	\N	\N	\N
59571X	M.	Chamant	CHAMANT JEAN	Jean	1913-11-23 00:00:00	2010-12-22 00:00:00	ANCIEN	Avocat	3121	51	RPR	RPR	\N	LOIS	LOIS	890	Yonne	Vice-président du Sénat	\N	CHAMANT	NON	\N	\N	\N	\N
000111	M.	Chambaretaud	CHAMBARETAUD LÉON	Léon	1904-10-27 00:00:00	1974-08-26 00:00:00	ANCIEN	Agent général d'assurances	3100	57	NI	NI	\N	ETRD	ETRD	690	Rhône	\N	\N	CHAMBARETAUD	NON	\N	\N	\N	\N
000061	M.	Champeix	CHAMPEIX MARCEL	Marcel	1902-03-31 00:00:00	1994-03-07 00:00:00	ANCIEN	Directeur de services industriels	4500	72	SOC	SER	\N	LOIS	LOIS	190	Corrèze	\N	\N	CHAMPEIX	NON	\N	\N	2017-10-04 09:46:29	\N
000439	M.	Chatelain	CHATELAIN FERNAND	Fernand	1920-01-31 00:00:00	1979-06-11 00:00:00	ANCIEN	Instituteur	4200	63	C	C	\N	ECON	ECON	828	Val-d'Oise	\N	\N	CHATELAIN	NON	\N	\N	\N	\N
59221C	M.	Chauty	CHAUTY MICHEL	Michel	1924-02-11 00:00:00	2007-08-16 00:00:00	ANCIEN	Représentant de tissages	2200	23	RPR	RPR	\N	ETRD	ETRD	440	Loire-Atlantique	\N	\N	CHAUTY	NON	\N	\N	\N	\N
000272	M.	Chauvin	CHAUVIN ADOLPHE	Adolphe	1911-06-07 00:00:00	1989-02-03 00:00:00	ANCIEN	Professeur	4200	62	UC	UC	\N	AFCL	AFCL	828	Val-d'Oise	\N	\N	CHAUVIN	NON	\N	\N	2017-07-04 10:59:30	\N
000222	M.	Chavanac	CHAVANAC ALBERT	Albert	1909-10-19 00:00:00	1972-09-14 00:00:00	ANCIEN	Administrateur de sociétés	3100	57	UDR	U.D.R.	\N	ECON	ECON	615	Paris	\N	\N	CHAVANAC	NON	\N	\N	\N	\N
58113U	M.	Chazalon	CHAZALON ANDRÉ	André	1924-03-18 00:00:00	2014-07-14 00:00:00	ANCIEN	Directeur d'entreprise	2300	21	RP	RP	\N	SOCI	SOCI	420	Loire	\N	\N	CHAZALON	NON	\N	\N	2014-07-24 10:30:04	\N
58349P	M.	Chazelle	CHAZELLE RENÉ	René	1917-07-24 00:00:00	2006-04-13 00:00:00	ANCIEN	Magistrat	7400	59	SOC	SER	\N	FINC	FINC	430	Haute-Loire	\N	\N	CHAZELLE	NON	\N	\N	2017-10-04 09:46:29	\N
58419L	M.	Cherrier	CHERRIER LIONEL	Lionel	1929-11-17 00:00:00	2016-10-25 00:00:00	ANCIEN	Ingénieur	3800	31	UREI	U.R.E.I.	\N	LOIS	LOIS	982	Nouvelle-Calédonie	\N	\N	CHERRIER	NON	\N	\N	2016-11-02 08:46:26	\N
59527T	M.	Chinaud	CHINAUD ROGER	Roger	1934-09-06 00:00:00	\N	ANCIEN	Publiciste	3735	55	RI	RI	\N	AFCL	AFCL	615	Paris	Vice-président du Sénat	\N	CHINAUD	NON	\N	\N	\N	\N
59222D	M.	Chupin	CHUPIN AUGUSTE	Auguste	1919-09-29 00:00:00	2007-03-09 00:00:00	ANCIEN	Pharmacien	3116	44	UC	UC	\N	ECON	ECON	490	Maine-et-Loire	\N	\N	CHUPIN	NON	\N	\N	2017-07-04 10:59:30	\N
56819Q	M.	Claireaux	CLAIREAUX HENRI	Henri	1911-02-03 00:00:00	2001-07-31 00:00:00	ANCIEN	Instituteur	4200	63	RP	RP	\N	ECON	ECON	995	Saint-Pierre-et-Miquelon	\N	\N	CLAIREAUX	NON	\N	\N	2017-12-19 15:12:17	\N
95045J	M.	Lorrain	LORRAIN	Jean-Louis	1948-03-12 00:00:00	2013-06-27 00:00:00	ANCIEN	Médecin	3112	42	UMP	Les Républicains	\N	SOCI	SOCI	680	Haut-Rhin	\N	jl.lorrain@senat.fr	LORRAIN	NON	\N	\N	2017-10-09 16:22:48	\N
77047J	M.	Mathieu	MATHIEU	Serge	1936-02-10 00:00:00	\N	ANCIEN	Viticulteur	1000	10	UMP	Les Républicains	\N	ETRD	ETRD	690	Rhône	Questeur du Sénat	\N	MATHIEU	NON	\N	\N	2017-10-09 16:22:48	\N
80002U	M.	Alloncle	ALLONCLE	Michel	1928-10-07 00:00:00	2003-04-23 00:00:00	ANCIEN	Médecin	3112	42	RPR	RPR	\N	ETRD	ETRD	160	Charente	\N	\N	ALLONCLE	NON	\N	\N	\N	\N
92024Q	M.	Goulet	GOULET	Daniel	1928-10-28 00:00:00	2007-02-25 00:00:00	ANCIEN	Directeur d'école libre	4200	63	UMP	Les Républicains	\N	ETRD	ETRD	610	Orne	\N	d.goulet@senat.fr	GOULET	NON	\N	\N	2017-10-09 16:22:48	\N
92029V	M.	Lambert	LAMBERT ALAIN	Alain	1946-07-20 00:00:00	\N	ANCIEN	Notaire	3128	52	UMP	Les Républicains	\N	FINC	FINC	610	Orne	\N	a.lambert@senat.fr	LAMBERT	NON	\N	\N	2017-10-09 16:22:48	\N
95011X	Mme	Borvo Cohen-Seat	BORVO COHEN-SEAT	Nicole	1945-12-08 00:00:00	\N	ANCIEN	Attachée principale d'administration	4500	71	CRC	CRCE	\N	LOIS	LOIS	615	Paris	\N	n.borvo@senat.fr	BORVO COHEN-SEAT	OUI	\N	\N	2017-10-04 09:44:05	\N
95056M	M.	Plasait	PLASAIT	Bernard	1940-06-20 00:00:00	\N	ANCIEN	Directeur de société	2300	21	UMP	Les Républicains	\N	ETRD	ETRD	615	Paris	\N	\N	PLASAIT	NON	\N	\N	2017-10-09 16:22:48	\N
86025D	M.	Estier	ESTIER	Claude	1925-06-08 00:00:00	2016-03-10 00:00:00	ANCIEN	Journaliste	3511	54	SOC	SER	\N	ETRD	ETRD	615	Paris	\N	\N	ESTIER	NON	\N	\N	2017-10-04 09:46:29	\N
86028G	M.	de Gaulle	GAULLE (DE)	Philippe	1921-12-28 00:00:00	2024-03-13 00:00:00	ANCIEN	Ancien inspecteur général de la marine	7400	79	UMP	Les Républicains	\N	ETRD	ETRD	615	Paris	\N	\N	de GAULLE	NON	\N	\N	2017-10-09 16:22:48	\N
93003P	M.	Ulrich	ULRICH	Maurice	1925-01-06 00:00:00	2012-11-14 00:00:00	ANCIEN	Conseiller d'Etat honoraire	3311	71	UMP	Les Républicains	\N	LOIS	LOIS	615	Paris	\N	\N	ULRICH	NON	\N	\N	2017-10-09 16:22:48	\N
77046H	M.	de La Malène	LAMALENE (DE)	Christian	1920-12-05 00:00:00	2007-09-26 00:00:00	ANCIEN	Sociologue	2300	21	UMP	Les Républicains	-R	ETRD	ETRD	615	Paris	\N	\N	de LA MALÈNE	NON	\N	\N	2017-10-09 16:22:48	\N
86004X	M.	Debavelaere	DEBAVELAERE	Désiré	1924-02-18 00:00:00	2002-05-10 00:00:00	ANCIEN	Agriculteur	1000	10	RPR	RPR	-A	ECON	ECON	620	Pas-de-Calais	\N	\N	DEBAVELAERE	NON	\N	\N	\N	\N
84003N	M.	Bécart	BECART	Jean-Luc	1947-08-23 00:00:00	\N	ANCIEN	Conseiller technique	3600	32	CRC	CRCE	\N	ETRD	ETRD	620	Pas-de-Calais	\N	\N	BÉCART	NON	\N	\N	2017-10-04 09:44:05	\N
89016Q	M.	Pépin	PEPIN	Jean	1939-11-23 00:00:00	2015-05-03 00:00:00	ANCIEN	Directeur de collège	4200	62	UMP	Les Républicains	\N	ECON	ECON	10	Ain	\N	\N	PÉPIN	NON	\N	\N	2017-10-09 16:22:48	\N
88005H	M.	Lesein	LESEIN	François	1929-12-11 00:00:00	2006-09-02 00:00:00	ANCIEN	Médecin	3112	42	RDSE	RDSE	\N	AFCL	AFCL	20	Aisne	Secrétaire du Sénat	\N	LESEIN	NON	\N	\N	\N	\N
78003A	M.	Girod	GIROD	Paul	1931-06-27 00:00:00	2021-09-28 00:00:00	ANCIEN	Agriculteur	1000	10	UMP	Les Républicains	\N	FINC	FINC	20	Aisne	\N	p.girod@senat.fr	GIROD	NON	\N	\N	2017-10-09 16:22:48	\N
71006X	M.	Braconnier	BRACONNIER	Jacques	1924-07-13 00:00:00	1999-12-15 00:00:00	ANCIEN	Directeur commercial	3700	32	RPR	RPR	\N	ECON	ECON	20	Aisne	Secrétaire du Sénat	\N	BRACONNIER	NON	\N	\N	\N	\N
86034E	M.	Larcher	LARCHER GERARD	Gérard	1949-09-14 00:00:00	\N	ACTIF	Docteur vétérinaire	3115	46	UMP	Les Républicains	\N	NEANT	Aucune	895	Yvelines	Président du Sénat	g.larcher@senat.fr	LARCHER	NON	9	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/larcher-gerard.html
95013A	M.	Braye	BRAYE	Dominique	1947-10-21 00:00:00	\N	ANCIEN	Docteur vétérinaire	3115	46	UMP	Les Républicains	\N	ECON	ECON	895	Yvelines	\N	d.braye@senat.fr	BRAYE	NON	\N	\N	2017-10-09 16:22:48	\N
95050F	Mme	Michaux-Chevry	MICHAUX-CHEVRY	Lucette	1929-03-05 00:00:00	2021-09-09 00:00:00	ANCIEN	Avocate	3121	51	UMP	Les Républicains	\N	ETRD	ETRD	971	Guadeloupe	\N	l.michaux-chevry@senat.fr	MICHAUX-CHEVRY	NON	\N	\N	2017-10-09 16:22:48	\N
89035T	M.	Othily	OTHILY	Georges	1944-01-07 00:00:00	2017-12-18 00:00:00	ANCIEN	Administrateur de biens	3100	57	RDSE	RDSE	\N	LOIS	LOIS	973	Guyane	\N	g.othily@senat.fr	OTHILY	NON	\N	\N	2018-01-08 09:00:07	\N
95044H	M.	Lise	LISE	Claude	1941-01-31 00:00:00	\N	ANCIEN	Médecin	3112	42	SOC	SER	-A	ECON	ECON	972	Martinique	\N	c.lise@senat.fr	LISE	NON	\N	\N	2017-10-04 09:46:29	\N
92033R	M.	Loueckhote	LOUECKHOTE	Simon	1957-05-07 00:00:00	\N	ANCIEN	Instituteur	4200	63	UMP	Les Républicains	\N	ETRD	ETRD	982	Nouvelle-Calédonie	\N	s.loueckhote@senat.fr	LOUECKHOTE	NON	\N	\N	2017-10-09 16:22:48	\N
77001T	M.	Millaud	MILLAUD	Daniel	1928-08-26 00:00:00	2016-06-21 00:00:00	ANCIEN	Dentiste	3113	45	UC	UC	\N	LOIS	LOIS	983	Polynésie française	Secrétaire du Sénat	\N	MILLAUD	NON	\N	\N	2017-07-04 10:59:30	\N
98004M	M.	Tui	TUI	Basile	1942-05-03 00:00:00	\N	ANCIEN	Fonctionnaire retraité	7400	79	UC	UC	\N	SOCI	SOCI	984	Iles Wallis et Futuna	\N	\N	TUI	NON	\N	\N	2017-07-04 10:59:30	\N
77028F	M.	Henry	HENRY	Marcel	1926-10-30 00:00:00	2021-08-30 00:00:00	ANCIEN	Gérant de société	2300	21	UC	UC	\N	AFCL	AFCL	990	Mayotte	\N	\N	HENRY	NON	\N	\N	2017-07-04 10:59:30	\N
69001W	M.	Habert	HABERT	Jacques	1919-09-26 00:00:00	2012-08-06 00:00:00	ANCIEN	Professeur, directeur de journal	3400	61	NI	NI	\N	ETRD	ETRD	997	Français établis hors de France	Secrétaire du Sénat	\N	HABERT	NON	\N	\N	\N	\N
89021M	M.	Biarnès	BIARNES	Pierre	1932-01-17 00:00:00	2022-07-18 00:00:00	ANCIEN	Journaliste	3511	54	CRC	CRCE	-R	ETRD	ETRD	997	Français établis hors de France	\N	p.biarnes@senat.fr	BIARNÈS	NON	\N	\N	2017-10-04 09:44:05	\N
89023P	Mme	Brisepierre	BRISEPIERRE	Paulette	1917-04-21 00:00:00	2012-07-07 00:00:00	ANCIEN	Sans profession déclarée 	8000	80	UMP	Les Républicains	\N	ETRD	ETRD	997	Français établis hors de France	\N	p.brisepierre@senat.fr	BRISEPIERRE	NON	\N	\N	2017-10-09 16:22:48	\N
97005J	Mme	Terrade	TERRADE	Odette	1949-02-21 00:00:00	\N	ANCIEN	Fonctionnaire	4500	73	CRC	CRCE	\N	ECON	ECON	824	Val-de-Marne	\N	o.terrade@senat.fr	TERRADE	NON	\N	\N	2017-10-04 09:44:05	\N
95051G	Mme	Olin	OLIN	Nelly	1941-03-23 00:00:00	2017-10-26 00:00:00	ANCIEN	Assistante de direction	3600	32	UMP	Les Républicains	\N	AFCL	AFCL	828	Val-d'Oise	\N	\N	OLIN	NON	\N	\N	2017-10-30 13:40:01	\N
95031C	M.	Falco	FALCO	Hubert	1947-05-15 00:00:00	\N	ANCIEN	Directeur général d'entreprise	2300	29	UMP	Les Républicains	\N	ETRD	ETRD	830	Var	\N	h.falco@senat.fr	FALCO	NON	\N	\N	2017-10-09 16:22:48	\N
86035F	M.	Laurin	LAURIN	René-Georges	1921-05-02 00:00:00	2006-04-29 00:00:00	ANCIEN	Commissaire priseur	3100	57	UMP	Les Républicains	\N	ETRD	ETRD	830	Var	\N	\N	LAURIN	NON	\N	\N	2017-10-09 16:22:48	\N
86049M	M.	Trucy	TRUCY	François	1931-06-09 00:00:00	\N	ANCIEN	Médecin biologiste	3112	42	UMP	Les Républicains	\N	FINC	FINC	830	Var	\N	f.trucy@senat.fr	TRUCY	NON	\N	\N	2017-10-09 16:22:48	\N
95021A	M.	Darniche	DARNICHE	Philippe	1943-02-23 00:00:00	\N	ANCIEN	Pharmacien	3116	44	NI	NI	\N	CDD	CDD	850	Vendée	\N	p.darniche@senat.fr	DARNICHE	NON	\N	\N	2014-09-28 16:40:49	\N
89025R	M.	Dussaut	DUSSAUT	Bernard	1941-11-14 00:00:00	\N	ANCIEN	Artisan	2100	24	SOC	SER	\N	ECON	ECON	330	Gironde	\N	b.dussaut@senat.fr	DUSSAUT	NON	\N	\N	2017-10-04 09:46:29	\N
80046H	M.	Valade	VALADE	Jacques	1930-05-04 00:00:00	2023-10-03 00:00:00	ANCIEN	Professeur d'université	3400	61	UMP	Les Républicains	\N	AFCL	AFCL	330	Gironde	\N	j.valade@senat.fr	VALADE	NON	\N	\N	2017-10-09 16:22:49	\N
97002F	M.	Motroni	MOTRONI	Jean-Baptiste	1934-11-10 00:00:00	\N	ANCIEN	Masseur kinésithérapeute	7400	49	SOC	SER	\N	ECON	ECON	205	Haute-Corse	\N	\N	MOTRONI	NON	\N	\N	2017-10-04 09:46:29	\N
98003L	M.	Grillot	GRILLOT	Louis	1932-04-18 00:00:00	2022-08-12 00:00:00	ANCIEN	Agriculteur	1000	10	UMP	Les Républicains	-A	ECON	ECON	210	Côte-d'Or	\N	l.grillot@senat.fr	GRILLOT	NON	\N	\N	2017-10-09 16:22:49	\N
80025C	M.	Lombard	LOMBARD MAURICE	Maurice	1922-02-04 00:00:00	2008-03-10 00:00:00	ANCIEN	Professeur	4200	62	RPR	RPR	\N	ETRD	ETRD	210	Côte-d'Or	\N	\N	LOMBARD	NON	\N	\N	\N	\N
80036F	M.	Régnault	REGNAULT	René	1936-08-23 00:00:00	\N	ANCIEN	Professeur d'enseignement technique	4200	62	SOC	SER	\N	FINC	FINC	1026	Côtes-du-Nord	\N	\N	RÉGNAULT	NON	\N	\N	2017-10-04 09:46:29	\N
97010F	M.	Derian	DERIAN	Jean	1932-10-16 00:00:00	2023-04-05 00:00:00	ANCIEN	Retraité de la SNCF	7400	79	CRC	CRCE	\N	LOIS	LOIS	220	Côtes-d'Armor	\N	\N	DERIAN	NON	\N	\N	2017-10-04 09:44:05	\N
89040Q	M.	Saunier	SAUNIER	Claude	1943-02-26 00:00:00	2022-10-17 00:00:00	ANCIEN	Professeur	4200	62	SOC	SER	\N	ECON	ECON	220	Côtes-d'Armor	\N	c.saunier@senat.fr	SAUNIER	NON	\N	\N	2017-10-04 09:46:29	\N
81010Y	M.	Chervy	CHERVY	William	1937-06-03 00:00:00	2021-02-12 00:00:00	ANCIEN	Médecin	3112	42	SOC	SER	\N	ECON	ECON	230	Creuse	\N	\N	CHERVY	NON	\N	\N	2017-10-04 09:46:29	\N
97001E	M.	Fayolle	FAYOLLE	Gérard	1937-10-11 00:00:00	\N	ANCIEN	Editeur	2300	21	RPR	RPR	\N	AFCL	AFCL	240	Dordogne	\N	\N	FAYOLLE	NON	\N	\N	\N	\N
92031P	M.	Legendre	LEGENDRE	Jacques	1941-12-02 00:00:00	\N	ANCIEN	Professeur agrégé d'histoire	4200	62	UMP	Les Républicains	\N	ETRD	ETRD	590	Nord	\N	jacques.legendre@wanadoo.fr	LEGENDRE	NON	\N	\N	2017-10-09 16:22:49	\N
85002R	M.	Renar	RENAR	Ivan	1937-04-26 00:00:00	2022-05-29 00:00:00	ANCIEN	Professeur	4200	62	CRC	CRCE	\N	AFCL	AFCL	590	Nord	\N	i.renar@wanadoo.fr	RENAR	NON	\N	\N	2017-10-04 09:44:05	\N
92044U	M.	Türk	TURK	Alex	1950-01-25 00:00:00	\N	ANCIEN	Maître de conférences à l'université	3400	61	NI	NI	\N	ETRD	ETRD	590	Nord	\N	Alex.turk@wanadoo.fr	TÜRK	NON	\N	\N	2017-09-24 18:16:51	\N
92037V	M.	Mauroy	MAUROY	Pierre	1928-07-05 00:00:00	2013-06-07 00:00:00	ANCIEN	Professeur de l'enseignement technique	3400	62	SOC	SER	\N	ETRD	ETRD	590	Nord	\N	p.mauroy@senat.fr	MAUROY	NON	\N	\N	2017-10-04 09:46:29	\N
92045V	M.	Vasselle	VASSELLE	Alain	1947-06-27 00:00:00	\N	ANCIEN	Agriculteur	1000	10	UMP	Les Républicains	\N	LOIS	LOIS	600	Oise	\N	a.vasselle@senat.fr	VASSELLE	NON	\N	\N	2017-10-09 16:22:49	\N
83038V	M.	Jolibois	JOLIBOIS	Charles	1928-10-04 00:00:00	2013-01-23 00:00:00	ANCIEN	Avocat	3121	51	RI	RI	\N	LOIS	LOIS	490	Maine-et-Loire	\N	\N	JOLIBOIS	NON	\N	\N	\N	\N
88002E	M.	Pourchet	POURCHET	Jean	1925-12-09 00:00:00	2010-02-27 00:00:00	ANCIEN	Agriculteur	1000	10	UC	UC	\N	ECON	ECON	250	Doubs	\N	\N	POURCHET	NON	\N	\N	2017-07-04 10:59:30	\N
80041C	M.	Souvet	SOUVET	Louis	1931-10-19 00:00:00	2020-06-29 00:00:00	ANCIEN	Cadre de l'industrie	3600	32	UMP	Les Républicains	\N	SOCI	SOCI	250	Doubs	\N	louis.souvet@wanadoo.fr	SOUVET	NON	\N	\N	2017-10-09 16:22:49	\N
89015P	M.	Besson	BESSON JEAN	Jean	1948-07-01 00:00:00	\N	ANCIEN	Agent d'assurances	3100	57	SOC	SER	\N	ETRD	ETRD	260	Drôme	\N	besson.jean@wanadoo.fr	BESSON	NON	\N	\N	2017-10-04 09:46:30	\N
11030C	M.	Béchu	BECHU_CHRISTOPHE_11030C	Christophe	1974-06-11 00:00:00	\N	ANCIEN	\N	8000	80	UMP	Les Républicains	\N	LOIS	LOIS	490	Maine-et-Loire	\N	c.bechu@senat.fr	BÉCHU	NON	\N	\N	2017-10-09 16:22:49	\N
86039K	M.	Mélenchon	MELENCHON	Jean-Luc	1951-08-19 00:00:00	\N	ANCIEN	Cadre administratif	3300	73	CRC	CRCE	\N	NEANT	Aucune	265	Essonne	\N	bureau.melenchon@lepartidegauche.fr	MÉLENCHON	NON	\N	\N	2017-10-04 09:44:05	\N
81014D	M.	Collard	COLLARD	Henri	1928-04-11 00:00:00	2012-01-13 00:00:00	ANCIEN	Médecin	3112	42	RDSE	RDSE	\N	FINC	FINC	270	Eure	\N	\N	COLLARD	NON	\N	\N	\N	\N
89044U	M.	Vigouroux	VIGOUROUX	Robert-Paul	1923-03-21 00:00:00	2017-07-08 00:00:00	ANCIEN	Professeur de médecine-Neurochirurgien des hôpitaux	3431	41	RDSE	RDSE	\N	LOIS	LOIS	130	Bouches-du-Rhône	\N	\N	VIGOUROUX	NON	\N	\N	2017-07-11 17:15:31	\N
89039X	M.	Rocca Serra	ROCCASERRA JACQUES	Jacques	1943-01-20 00:00:00	\N	ANCIEN	Kinésithérapeute	3100	47	UC	UC	\N	ECON	ECON	130	Bouches-du-Rhône	\N	\N	ROCCA SERRA	NON	\N	\N	2017-07-04 10:59:30	\N
95068R	M.	Lafond	LAFOND	Jean-Pierre	1940-02-17 00:00:00	\N	ANCIEN	Chef d'entreprise	2300	21	NI	NI	\N	SOCI	SOCI	130	Bouches-du-Rhône	\N	\N	LAFOND	NON	\N	\N	\N	\N
71018C	M.	Girault	GIRAULT	Jean-Marie	1926-02-09 00:00:00	2016-05-01 00:00:00	ANCIEN	Avocat	3121	51	RI	RI	\N	LOIS	LOIS	140	Calvados	\N	\N	GIRAULT	NON	\N	\N	2016-05-03 17:09:39	\N
83047W	M.	Percheron	PERCHERON	Daniel	1942-08-31 00:00:00	\N	ANCIEN	Professeur d'histoire-géographie	4200	62	SOC	SER	\N	AFCL	AFCL	620	Pas-de-Calais	\N	d.percheron@senat.fr	PERCHERON	NON	\N	\N	2017-10-04 09:46:30	\N
83017Q	M.	Bony	BONY	Marcel	1926-07-06 00:00:00	2010-09-02 00:00:00	ANCIEN	Agriculteur	1000	10	SOC	SER	\N	ECON	ECON	630	Puy-de-Dôme	\N	\N	BONY	NON	\N	\N	2017-10-04 09:46:30	\N
83050R	M.	de Rohan	ROHAN (DE)	Josselin	1938-06-05 00:00:00	\N	ANCIEN	Administrateur civil 	3311	71	UMP	Les Républicains	\N	ETRD	ETRD	560	Morbihan	\N	j.de-rohan@senat.fr	de ROHAN	NON	\N	\N	2017-10-09 16:22:49	\N
92016Q	M.	Charmant	CHARMANT	Marcel	1944-07-26 00:00:00	\N	ANCIEN	Cadre de Compagnie d'assurance	3600	32	SOC	SER	\N	LOIS	LOIS	580	Nièvre	\N	\N	CHARMANT	NON	\N	\N	2017-10-04 09:46:30	\N
86053H	M.	Signé	SIGNE	René-Pierre	1930-09-16 00:00:00	\N	ANCIEN	Médecin	3112	42	SOC	SER	\N	AFCL	AFCL	580	Nièvre	\N	Rene-Pierre.Signe@wanadoo.fr	SIGNÉ	NON	\N	\N	2017-10-04 09:46:30	\N
97006K	M.	Lefebvre	LEFEBVRE	Pierre	1938-09-11 00:00:00	\N	ANCIEN	Cadre honoraire de la SNCF	4500	72	CRC	CRCE	\N	ECON	ECON	590	Nord	\N	\N	LEFEBVRE	NON	\N	\N	2017-10-04 09:44:05	\N
65017N	M.	Diligent	DILIGENT	André	1919-05-10 00:00:00	2002-02-03 00:00:00	ANCIEN	Avocat honoraire	7400	59	UC	UC	\N	AFCL	AFCL	590	Nord	\N	\N	DILIGENT	NON	\N	\N	2017-07-04 10:59:38	\N
000545	M.	Bourgine	BOURGINE RAYMOND	Raymond	1925-03-09 00:00:00	1990-11-29 00:00:00	ANCIEN	Journaliste	3511	54	RPR	RPR	-A	FINC	FINC	615	Paris	\N	\N	BOURGINE	NON	\N	\N	\N	\N
59220B	M.	Bousch	BOUSCH JEAN-ERIC	Jean-Eric	1910-09-30 00:00:00	1999-04-06 00:00:00	ANCIEN	Ingénieur	3800	31	RPR	RPR	\N	ECON	ECON	570	Moselle	\N	\N	BOUSCH	NON	\N	\N	2015-02-10 12:00:26	\N
000140	M.	Boutemy	BOUTEMY ANDRÉ	André	1905-12-21 00:00:00	1959-07-14 00:00:00	ANCIEN	Préfet honoraire	3300	71	CRARS	CRARS	\N	FINC	FINC	770	Seine-et-Marne	\N	\N	BOUTEMY	NON	\N	\N	\N	\N
59568D	M.	Bouvier	BOUVIER RAYMOND	Raymond	1928-03-30 00:00:00	2001-10-18 00:00:00	ANCIEN	Agriculteur et commerçant	1000	10	UC	UC	\N	LOIS	LOIS	740	Haute-Savoie	Secrétaire du Sénat	\N	BOUVIER	NON	\N	\N	2017-07-04 10:59:30	\N
92014N	M.	Boyer	BOYER ERIC	Eric	1939-06-23 00:00:00	\N	ANCIEN	Professeur	4200	62	RPR	RPR	-A	SOCI	SOCI	974	La Réunion	\N	\N	BOYER	NON	\N	\N	\N	\N
000474	M.	Brantus	BRANTUS PIERRE	Pierre	1921-10-27 00:00:00	1989-09-17 00:00:00	ANCIEN	Journaliste	3511	54	UC	UC	\N	AFCL	AFCL	390	Jura	\N	\N	BRANTUS	NON	\N	\N	2017-07-04 10:59:30	\N
000039	M.	Brayard	BRAYARD JOSEPH	Joseph	1901-03-31 00:00:00	1972-07-03 00:00:00	ANCIEN	Cultivateur	1000	10	GDSRG	G.D.S.R.G.	\N	SOCI	SOCI	10	Ain	\N	\N	BRAYARD	NON	\N	\N	\N	\N
000020	M.	Bregegere	BREGEGERE MARCEL	Marcel	1900-08-29 00:00:00	1995-03-26 00:00:00	ANCIEN	Agriculteur	1000	10	SOC	SER	\N	ECON	ECON	240	Dordogne	\N	\N	BREGEGERE	NON	\N	\N	2017-10-04 09:46:30	\N
59523P	M.	Brives	BRIVES LOUIS	Louis	1912-07-24 00:00:00	2006-03-09 00:00:00	ANCIEN	Propriétaire exploitant	1000	10	RDE	R.D.E.	\N	SOCI	SOCI	810	Tarn	\N	\N	BRIVES	NON	\N	\N	\N	\N
77019E	M.	Fourcade	FOURCADE	Jean-Pierre	1929-10-18 00:00:00	\N	ANCIEN	Inspecteur des finances	7400	71	UMP	Les Républicains	\N	FINC	FINC	335	Hauts-de-Seine	\N	jp.fourcade@senat.fr	FOURCADE	NON	\N	\N	2017-10-09 16:22:49	\N
95016D	M.	Ceccaldi-Raynaud	CECCALDI-RAYNAUD	Charles	1925-06-25 00:00:00	2019-07-18 00:00:00	ANCIEN	Avocat	3121	51	UMP	Les Républicains	\N	LOIS	LOIS	335	Hauts-de-Seine	\N	\N	CECCALDI-RAYNAUD	NON	\N	\N	2017-10-09 16:22:49	\N
80015A	M.	Delfau	DELFAU	Gérard	1937-10-21 00:00:00	\N	ANCIEN	Universitaire	3400	61	RDSE	RDSE	\N	ECON	ECON	340	Hérault	\N	g.delfau@senat.fr	DELFAU	NON	\N	\N	\N	\N
89043T	M.	Vézinhet	VEZINHET	André	1939-09-07 00:00:00	\N	ANCIEN	Directeur de recherches	3600	32	SOC	SER	\N	ECON	ECON	340	Hérault	\N	andre.vezinhet@wanadoo.fr	VÉZINHET	NON	\N	\N	2017-10-04 09:46:30	\N
80048K	M.	Vidal	VIDAL	Marcel	1940-03-07 00:00:00	2006-07-08 00:00:00	ANCIEN	Viticulteur	1000	10	SOC	SER	-R	AFCL	AFCL	340	Hérault	\N	m.vidal@senat.fr	VIDAL	NON	\N	\N	2017-10-04 09:46:30	\N
80026D	M.	Madelain	MADELAIN	Jean	1924-01-09 00:00:00	2023-05-17 00:00:00	ANCIEN	Directeur d'usine	3600	21	UC	UC	\N	SOCI	SOCI	350	Ille-et-Vilaine	\N	\N	MADELAIN	NON	\N	\N	2017-07-04 10:59:30	\N
80014Y	M.	Daunay	DAUNAY	Marcel	1930-03-20 00:00:00	2008-04-09 00:00:00	ANCIEN	Agriculteur	1000	10	UC	UC	\N	ECON	ECON	350	Ille-et-Vilaine	Secrétaire du Sénat	\N	DAUNAY	NON	\N	\N	2017-07-04 10:59:30	\N
80011V	M.	Bourges	BOURGES	Yvon	1921-06-29 00:00:00	2009-04-18 00:00:00	ANCIEN	Gouverneur général de la France d'outre-mer	3311	71	RPR	RPR	\N	ETRD	ETRD	350	Ille-et-Vilaine	\N	\N	BOURGES	NON	\N	\N	\N	\N
89030N	M.	Gerbaud	GERBAUD	François	1927-04-10 00:00:00	2010-01-13 00:00:00	ANCIEN	Journaliste	3511	54	UMP	Les Républicains	\N	ECON	ECON	360	Indre	\N	f.gerbaud@senat.fr	GERBAUD	NON	\N	\N	2017-10-09 16:22:49	\N
92030N	M.	Leclerc	LECLERC	Dominique	1944-03-17 00:00:00	\N	ANCIEN	Pharmacien	3116	44	UMP	Les Républicains	\N	SOCI	SOCI	370	Indre-et-Loire	\N	d.leclerc@senat.fr	LECLERC	NON	\N	\N	2017-10-09 16:22:49	\N
92012L	M.	Bordas	BORDAS	James	1929-08-20 00:00:00	2020-12-28 00:00:00	ANCIEN	Inspecteur central du Trésor (Retraité)	7400	79	RI	RI	\N	AFCL	AFCL	370	Indre-et-Loire	\N	\N	BORDAS	NON	\N	\N	\N	\N
83031N	M.	Faure	FAURE	Jean	1937-01-14 00:00:00	2022-05-13 00:00:00	ANCIEN	Directeur d'organisme de tourisme	3600	32	UMP	Les Républicains	\N	ETRD	ETRD	380	Isère	\N	j.faure@senat.fr	FAURE	NON	\N	\N	2017-10-09 16:22:49	\N
83004K	M.	Pluchet	PLUCHET	Alain	1930-05-01 00:00:00	2020-11-24 00:00:00	ANCIEN	Agriculteur	1000	10	RPR	RPR	\N	ECON	ECON	270	Eure	\N	\N	PLUCHET	NON	\N	\N	\N	\N
89031P	M.	Grandon	GRANDON JEAN	Jean	1926-02-25 00:00:00	2010-12-20 00:00:00	ANCIEN	Agriculteur	1000	10	NI	NI	\N	ECON	ECON	280	Eure-et-Loir	\N	\N	GRANDON	NON	\N	\N	\N	\N
80003V	M.	Arzel	ARZEL	Alphonse	1927-09-20 00:00:00	2014-02-21 00:00:00	ANCIEN	Agriculteur	1000	10	UC	UC	\N	LOIS	LOIS	290	Finistère	\N	\N	ARZEL	NON	\N	\N	2017-07-04 10:59:30	\N
000310	Mme	de Hauteclocque	HAUTECLOCQUE NICOLE DE	Nicole	1913-03-10 00:00:00	1993-01-18 00:00:00	ANCIEN	Expert en relations publiques	7300	57	RPR	RPR	\N	ETRD	ETRD	615	Paris	\N	\N	de HAUTECLOCQUE	NON	\N	\N	2017-06-15 09:45:22	\N
000406	M.	Heder	HEDER LÉOPOLD	Léopold	1918-08-16 00:00:00	1978-06-09 00:00:00	ANCIEN	Directeur des hopitaux	4500	72	SOC	SER	-A	LOIS	LOIS	973	Guyane	\N	\N	HEDER	NON	\N	\N	2017-10-04 09:46:30	\N
000397	M.	Dailly	DAILLY ETIENNE	Etienne	1918-01-04 00:00:00	1996-12-24 00:00:00	ANCIEN	Administrateur de sociétés	2300	21	RDE	R.D.E.	\N	LOIS	LOIS	770	Seine-et-Marne	Vice-président du Sénat	\N	DAILLY	NON	\N	\N	2015-02-10 12:00:26	\N
000416	M.	Dardel	DARDEL GEORGES	Georges	1919-04-13 00:00:00	1982-10-01 00:00:00	ANCIEN	Employé à la société nationale des chemins de fer français	5400	33	NI	NI	\N	LOIS	LOIS	335	Hauts-de-Seine	\N	\N	DARDEL	NON	\N	\N	\N	\N
000524	M.	Darras	DARRAS MICHEL	Michel	1924-03-05 00:00:00	1992-01-06 00:00:00	ANCIEN	Ingénieur	3800	31	SOC	SER	\N	LOIS	LOIS	620	Pas-de-Calais	\N	\N	DARRAS	NON	\N	\N	2017-10-04 09:46:30	\N
000438	M.	Daugnac	DAUGNAC ANDRÉ	André	1919-12-14 00:00:00	1995-12-30 00:00:00	ANCIEN	Entrepreneur	2300	21	UC	UC	\N	LOIS	LOIS	660	Pyrénées-Orientales	\N	\N	DAUGNAC	NON	\N	\N	2017-07-04 10:59:30	\N
58019X	M.	David	DAVID JEAN	Jean	1924-03-01 00:00:00	2013-05-08 00:00:00	ANCIEN	Directeur des centres de formation des personnels communaux	4500	72	UCDP	U.C.D.P.	\N	AFCL	AFCL	100	Aube	\N	\N	DAVID	NON	\N	\N	2013-05-14 16:39:02	\N
57826T	M.	David	DAVID LÉON	Léon	1901-06-19 00:00:00	2000-08-26 00:00:00	ANCIEN	Artisan forgeron	2100	24	C	C	\N	ECON	ECON	130	Bouches-du-Rhône	\N	\N	DAVID	NON	\N	\N	\N	\N
000031	M.	Debesson	DEBESSON RENÉ	René	1900-11-13 00:00:00	1981-12-10 00:00:00	ANCIEN	Professeur honoraire	7400	69	SOC	SER	\N	ECON	ECON	590	Nord	\N	\N	DEBESSON	NON	\N	\N	2017-10-04 09:46:30	\N
000250	M.	Defferre	DEFFERRE GASTON	Gaston	1910-09-14 00:00:00	1986-05-07 00:00:00	ANCIEN	Directeur de journal	2300	21	SOC	SER	\N	ETRD	ETRD	130	Bouches-du-Rhône	\N	\N	DEFFERRE	NON	\N	\N	2017-10-04 09:46:30	\N
000199	M.	Delalande	DELALANDE JACQUES	Jacques	1908-07-09 00:00:00	1997-10-07 00:00:00	ANCIEN	Avocat	3121	51	RI	RI	\N	LOIS	LOIS	530	Mayenne	\N	\N	DELALANDE	NON	\N	\N	\N	\N
59575C	M.	Golliet	GOLLIET JACQUES	Jacques	1931-12-14 00:00:00	2020-10-31 00:00:00	ANCIEN	Maître de conférences	3400	61	UC	UC	\N	ETRD	ETRD	740	Haute-Savoie	\N	\N	GOLLIET	NON	\N	\N	2017-07-04 10:59:30	\N
000210	M.	Gonard	GONARD PIERRE	Pierre	1909-04-15 00:00:00	1989-09-23 00:00:00	ANCIEN	Artisan menuisier	2100	24	SOC	SER	\N	AFCL	AFCL	30	Allier	\N	\N	GONARD	NON	\N	\N	2017-10-04 09:46:30	\N
59230D	Mme	Gournay	GOURNAY MARIE-FANNY	Marie-Fanny	1926-03-06 00:00:00	2020-02-04 00:00:00	ANCIEN	Sans profession déclarée	8000	80	RPR	RPR	\N	SOCI	SOCI	590	Nord	\N	\N	GOURNAY	NON	\N	\N	2017-06-15 09:46:11	\N
58673Y	Mme	Goutmann	GOUTMANN MARIE-THÉRÈSE	Marie-Thérèse	1933-08-29 00:00:00	2016-09-29 00:00:00	ANCIEN	Directrice d'école	4200	63	C	C	\N	ETRD	ETRD	775	Seine-Saint-Denis	\N	\N	GOUTMANN	NON	\N	\N	2016-10-04 15:32:34	\N
000097	M.	Grand	GRAND LUCIEN	Lucien	1904-03-26 00:00:00	1978-05-08 00:00:00	ANCIEN	Médecin	3112	42	GD	G.D.	\N	SOCI	SOCI	170	Charente-Maritime	Secrétaire du Sénat	\N	GRAND	NON	\N	\N	2015-02-10 12:00:26	\N
58816V	M.	Grandon	GRANDON JACQUES	Jacques	1927-05-09 00:00:00	\N	ANCIEN	Avocat	3121	51	UC	UC	\N	LOIS	LOIS	860	Vienne	\N	\N	GRANDON	NON	\N	\N	2017-07-04 10:59:30	\N
000370	M.	Gravier	GRAVIER JEAN	Jean	1915-10-27 00:00:00	1991-08-03 00:00:00	ANCIEN	Directeur commercial	3600	32	UCDP	U.C.D.P.	\N	SOCI	SOCI	390	Jura	Secrétaire du Sénat	\N	GRAVIER	NON	\N	\N	\N	\N
57445J	M.	Gravier	GRAVIER ROBERT	Robert	1905-09-05 00:00:00	2005-07-15 00:00:00	ANCIEN	Agriculteur	1000	10	RI	RI	\N	ETRD	ETRD	540	Meurthe-et-Moselle	Questeur du Sénat	\N	GRAVIER	NON	\N	\N	2017-12-19 15:12:18	\N
59537V	M.	Graziani	GRAZIANI PAUL	Paul	1925-02-14 00:00:00	2012-07-30 00:00:00	ANCIEN	Administrateur civil	3311	71	RPR	RPR	\N	LOIS	LOIS	335	Hauts-de-Seine	\N	\N	GRAZIANI	NON	\N	\N	2016-12-20 15:55:37	\N
000226	M.	Gregory	GREGORY LÉON	Léon-Jean	1909-11-01 00:00:00	1982-10-22 00:00:00	ANCIEN	Avocat	3121	51	NI	NI	\N	AFCL	AFCL	660	Pyrénées-Orientales	\N	\N	GREGORY	NON	\N	\N	\N	\N
59232F	M.	Grimaldi	GRIMALDI ROLAND	Roland	1933-11-16 00:00:00	\N	ANCIEN	Professeur	4200	62	SOC	SER	\N	ECON	ECON	590	Nord	\N	\N	GRIMALDI	NON	\N	\N	2017-10-04 09:46:30	\N
000551	Mme	Gros	GROS BRIGITTE	Brigitte	1925-06-12 00:00:00	1985-03-11 00:00:00	ANCIEN	Journaliste	3511	54	GD	G.D.	\N	AFCL	AFCL	895	Yvelines	Secrétaire du Sénat	\N	GROS	NON	\N	\N	\N	\N
89032Q	M.	Guena	GUENA YVES	Yves	1922-07-06 00:00:00	2016-03-03 00:00:00	ANCIEN	Conseiller d'Etat honoraire	3311	71	RPR	RPR	\N	ETRD	ETRD	240	Dordogne	Vice-président du Sénat	\N	GUENA	NON	\N	\N	2017-06-15 09:45:15	\N
58949J	M.	Guenier	GUENIER JEAN	Jean	1923-03-11 00:00:00	2007-10-25 00:00:00	ANCIEN	Exploitant agricole	7100	10	UC	UC	\N	ECON	ECON	270	Eure	\N	\N	GUENIER	NON	\N	\N	2017-07-04 10:59:30	\N
56531B	M.	Gueroui	GUEROUI MOHAMMED	Mohammed	1915-12-21 00:00:00	2000-06-09 00:00:00	ANCIEN	Attaché de Préfecture	4500	72	UNR	U.N.R.	\N	ECON	ECON	1045	Setif-Batna	\N	\N	GUEROUI	NON	\N	\N	\N	\N
58332E	M.	Guillard	GUILLARD PAUL	Paul	1910-11-17 00:00:00	2008-11-19 00:00:00	ANCIEN	Maraîcher	1000	10	UREI	U.R.E.I.	\N	NEANT	Aucune	440	Loire-Atlantique	Questeur du Sénat	\N	GUILLARD	NON	\N	\N	\N	\N
59233G	M.	Guillaume	GUILLAUME ROBERT	Robert	1922-04-25 00:00:00	2004-04-07 00:00:00	ANCIEN	Retraité de l'éducation nationale	7400	79	SOC	SER	\N	AFCL	AFCL	580	Nièvre	\N	\N	GUILLAUME	NON	\N	\N	2017-10-04 09:46:30	\N
58625Q	M.	Guillaumot	GUILLAUMOT PAUL	Paul	1913-07-08 00:00:00	2011-11-11 00:00:00	ANCIEN	Agriculteur	1000	10	UREI	U.R.E.I.	\N	ECON	ECON	890	Yonne	\N	\N	GUILLAUMOT	NON	\N	\N	\N	\N
000216	M.	Guille	GUILLE GEORGES	Georges	1909-07-20 00:00:00	1985-11-17 00:00:00	ANCIEN	Instituteur	4200	63	SOC	SER	\N	ETRD	ETRD	110	Aude	\N	\N	GUILLE	NON	\N	\N	2017-10-04 09:46:30	\N
000459	M.	Guillou	GUILLOU LOUIS	Louis	1921-03-06 00:00:00	1998-03-07 00:00:00	ANCIEN	Cultivateur exploitant	1000	10	UCDP	U.C.D.P.	\N	SOCI	SOCI	290	Finistère	\N	\N	GUILLOU	NON	\N	\N	\N	\N
59538W	M.	Guyomard	GUYOMARD BERNARD	Bernard	1926-06-02 00:00:00	2010-11-10 00:00:00	ANCIEN	Administrateur civil	3311	71	UC	UC	\N	ETRD	ETRD	615	Paris	\N	\N	GUYOMARD	NON	\N	\N	2017-07-04 10:59:30	\N
000162	M.	Hakiki	HAKIKI DJILALI	Djilali	1907-03-28 00:00:00	1962-08-12 00:00:00	ANCIEN	Agriculteur	1000	10	GD	G.D.	-R	AFCL	AFCL	1030	Oran-Tlemcen	\N	\N	HAKIKI	NON	\N	\N	\N	\N
000602	M.	Hamecher	HAMECHER MARCEAU	Marceau	1929-08-29 00:00:00	1978-08-27 00:00:00	ANCIEN	Industriel	2300	21	GDSRG	G.D.S.R.G.	\N	SOCI	SOCI	820	Tarn-et-Garonne	\N	\N	HAMECHER	NON	\N	\N	\N	\N
58115W	M.	Hammann	HAMMANN JEAN-PAUL	Jean-Paul	1925-10-03 00:00:00	\N	ANCIEN	Exploitant agricole 	1000	10	RPR	RPR	\N	SOCI	SOCI	670	Bas-Rhin	\N	\N	HAMMANN	NON	\N	\N	\N	\N
000218	M.	Hamon	HAMON YVES	Yves	1909-09-09 00:00:00	1980-10-24 00:00:00	ANCIEN	Exploitant agricole	1000	10	UC	UC	\N	ECON	ECON	290	Finistère	\N	\N	HAMON	NON	\N	\N	2017-07-04 10:59:30	\N
56405V	M.	Kheirat	KHEIRAT M'HAMED	M'hamed	1910-11-03 00:00:00	1998-12-25 00:00:00	ANCIEN	Entrepreneur de transports publics de voyageurs	2000	21	GD	G.D.	-R	SOCI	SOCI	1044	Mostaganem-Tiaret	\N	\N	KHEIRAT	NON	\N	\N	\N	\N
000149	M.	Kieffer	KIEFFER ALFRED	Alfred	1906-08-22 00:00:00	1991-07-14 00:00:00	ANCIEN	Directeur de société	2300	21	UCDP	U.C.D.P.	\N	ECON	ECON	670	Bas-Rhin	\N	\N	KIEFFER	NON	\N	\N	\N	\N
000124	M.	L'Huillier	LHUILLIER WALDECK	Waldeck	1905-05-27 00:00:00	1986-02-04 00:00:00	ANCIEN	Ingénieur	3800	31	C	C	\N	LOIS	LOIS	1029	Seine	\N	\N	L'HUILLIER	NON	\N	\N	\N	\N
58945E	M.	De La Forest	LAFOREST LOUIS (DE)	Louis	1914-08-12 00:00:00	2013-09-30 00:00:00	ANCIEN	Agriculteur	1000	10	UREI	U.R.E.I.	\N	ETRD	ETRD	350	Ille-et-Vilaine	\N	\N	DE LA FOREST	NON	\N	\N	2013-10-02 12:20:57	\N
000068	M.	de La Gontrie	LAGONTRIE PIERRE DE	Pierre	1902-07-30 00:00:00	1971-05-06 00:00:00	ANCIEN	Avocat	3121	51	GD	G.D.	\N	LOIS	LOIS	730	Savoie	\N	\N	de LA GONTRIE	NON	\N	\N	\N	\N
000458	M.	Labeguerie	LABEGUERIE MICHEL	Michel	1921-03-04 00:00:00	1980-07-28 00:00:00	ANCIEN	Médecin	3112	42	UCDP	U.C.D.P.	\N	SOCI	SOCI	640	Pyrénées-Atlantiques	\N	\N	LABEGUERIE	NON	\N	\N	\N	\N
000237	M.	Labonde	LABONDE PIERRE	Pierre	1910-02-28 00:00:00	1981-11-22 00:00:00	ANCIEN	Agriculteur	1000	10	RI	RI	\N	ECON	ECON	100	Aube	\N	\N	LABONDE	NON	\N	\N	\N	\N
000231	M.	Lacaze	LACAZE JEAN	Jean	1909-12-26 00:00:00	1975-07-29 00:00:00	ANCIEN	Pharmacien	3116	44	GD	G.D.	\N	AFCL	AFCL	820	Tarn-et-Garonne	\N	\N	LACAZE	NON	\N	\N	\N	\N
000153	M.	Lachevre	LACHEVRE ROGER	Roger	1906-08-20 00:00:00	1988-03-31 00:00:00	ANCIEN	Administrateur de sociétés	3100	57	RI	RI	\N	FINC	FINC	1020	Seine-et-Oise	\N	\N	LACHEVRE	NON	\N	\N	\N	\N
57449N	M.	de Lachomette	LACHOMETTE JEAN 	Jean	1912-03-28 00:00:00	1999-01-12 00:00:00	ANCIEN	Industriel	2300	21	CRARS	CRARS	\N	ETRD	ETRD	430	Haute-Loire	\N	\N	de LACHOMETTE	NON	\N	\N	\N	\N
80022Y	M.	Lacour	LACOUR PIERRE	Pierre	1923-02-20 00:00:00	2008-05-22 00:00:00	ANCIEN	Vétérinaire	3115	46	RDSE	RDSE	-R	AFCL	AFCL	160	Charente	\N	\N	LACOUR	NON	\N	\N	\N	\N
000086	M.	Lafay	LAFAY BERNARD	Bernard	1905-09-08 00:00:00	1977-02-13 00:00:00	ANCIEN	Médecin	3112	42	GD	G.D.	\N	ETRD	ETRD	1029	Seine	\N	\N	LAFAY	NON	\N	\N	2016-12-13 15:12:59	\N
57728S	Mme	Lagatu	LAGATU CATHERINE	Catherine	1919-06-11 00:00:00	2007-03-01 00:00:00	ANCIEN	Professeur	4200	62	C	C	\N	AFCL	AFCL	615	Paris	Secrétaire du Sénat	\N	LAGATU	NON	\N	\N	\N	\N
56812H	M.	Lagrange	LAGRANGE ROGER	Roger	1913-05-04 00:00:00	2000-09-29 00:00:00	ANCIEN	Instituteur	4200	63	SOC	SER	\N	SOCI	SOCI	710	Saône-et-Loire	\N	\N	LAGRANGE	NON	\N	\N	2017-10-04 09:46:30	\N
000230	M.	Lamousse	LAMOUSSE GEORGES	Georges	1909-12-23 00:00:00	1992-08-01 00:00:00	ANCIEN	Professeur d'Ecole Normale	3400	61	SOC	SER	\N	AFCL	AFCL	870	Haute-Vienne	\N	\N	LAMOUSSE	NON	\N	\N	2017-10-04 09:46:30	\N
000303	M.	Lanet	LANET JOSEPH	Joseph	1912-12-20 00:00:00	1974-09-06 00:00:00	ANCIEN	Administrateur de sociétés	3100	57	GD	G.D.	\N	ETRD	ETRD	1029	Seine	\N	\N	LANET	NON	\N	\N	\N	\N
000107	M.	Larue	LARUE TONY	Tony	1904-08-18 00:00:00	1995-07-05 00:00:00	ANCIEN	Expert comptable	7400	59	SOC	SER	\N	FINC	FINC	760	Seine-Maritime	\N	\N	LARUE	NON	\N	\N	2017-10-04 09:52:11	\N
59541R	M.	Laucournet	LAUCOURNET ROBERT	Robert	1921-07-22 00:00:00	2008-10-14 00:00:00	ANCIEN	Assureur	3100	57	SOC	SER	\N	ECON	ECON	870	Haute-Vienne	Vice-président du Sénat	\N	LAUCOURNET	NON	\N	\N	2017-10-04 09:46:30	\N
000456	M.	Laurent	LAURENT BERNARD	Bernard	1921-01-19 00:00:00	1994-07-15 00:00:00	ANCIEN	Agriculteur	1000	10	UC	UC	\N	LOIS	LOIS	100	Aube	\N	\N	LAURENT	NON	\N	\N	2017-07-04 10:59:30	\N
000042	M.	Laurent-Thouverey	LAURENT-THOUVEREY CHARLES	Charles	1901-05-01 00:00:00	1989-09-16 00:00:00	ANCIEN	Agent d'assurances	3100	57	GD	G.D.	\N	AFCL	AFCL	390	Jura	\N	\N	LAURENT-THOUVEREY	NON	\N	\N	\N	\N
59542S	M.	Lauriol	LAURIOL MARC	Marc	1916-08-18 00:00:00	2006-10-20 00:00:00	ANCIEN	Commissaire aux comptes	3100	57	RPR	RPR	\N	ETRD	ETRD	895	Yvelines	\N	\N	LAURIOL	NON	\N	\N	2017-06-15 09:47:50	\N
58948H	M.	Lazuech	LAZUECH LOUIS	Louis	1912-04-21 00:00:00	2002-03-07 00:00:00	ANCIEN	Négociant	2200	23	UREI	U.R.E.I.	\N	SOCI	SOCI	120	Aveyron	\N	\N	LAZUECH	NON	\N	\N	\N	\N
000093	M.	Le Bellegou	LEBELLEGOU EDOUARD	Edouard	1903-12-20 00:00:00	1972-12-05 00:00:00	ANCIEN	Avocat	3121	51	SOC	SER	\N	LOIS	LOIS	830	Var	\N	\N	LE BELLEGOU	NON	\N	\N	2017-10-04 09:46:30	\N
000135	M.	Filippi	FILIPPI JEAN	Jean	1905-10-19 00:00:00	1993-01-15 00:00:00	ANCIEN	Inspecteur des finances	4500	72	GDSRG	G.D.S.R.G.	\N	ECON	ECON	1002	Corse	\N	\N	FILIPPI	NON	\N	\N	\N	\N
58021R	M.	Fontaine	FONTAINE MAURICE	Maurice	1919-09-20 00:00:00	2015-01-02 00:00:00	ANCIEN	Viticulteur	1000	10	GD	G.D.	\N	AFCL	AFCL	300	Gard	\N	\N	FONTAINE	NON	\N	\N	\N	\N
000451	M.	Fortier	FORTIER MARCEL	Marcel	1920-11-07 00:00:00	1995-09-14 00:00:00	ANCIEN	Médecin	3112	42	RPR	RPR	\N	FINC	FINC	370	Indre-et-Loire	\N	\N	FORTIER	NON	\N	\N	\N	\N
59521M	M.	Fosset	FOSSET ANDRÉ	André	1918-11-13 00:00:00	2001-03-27 00:00:00	ANCIEN	Administrateur de sociétés	2300	21	UC	UC	\N	ECON	ECON	335	Hauts-de-Seine	Questeur du Sénat	\N	FOSSET	NON	\N	\N	2017-07-04 10:59:30	\N
59574B	Mme	Fost	FOST PAULETTE	Paulette	1937-09-18 00:00:00	\N	ANCIEN	Secrétaire	5400	33	C	C	\N	FINC	FINC	775	Seine-Saint-Denis	\N	\N	FOST	NON	\N	\N	\N	\N
000296	M.	Fournis	FOURNIS HENRI	Henri	1912-07-21 00:00:00	1995-09-22 00:00:00	ANCIEN	Notaire	3128	52	RI	RI	\N	LOIS	LOIS	440	Loire-Atlantique	\N	\N	FOURNIS	NON	\N	\N	\N	\N
58944D	M.	Francou	FRANCOU JEAN	Jean	1920-05-27 00:00:00	2013-03-13 00:00:00	ANCIEN	Courtier en oléagineux	2200	23	UC	UC	\N	FINC	FINC	130	Bouches-du-Rhône	\N	\N	FRANCOU	NON	\N	\N	2017-07-04 10:59:31	\N
86027F	Mme	Fraysse-Cazalis	FRAYSSE-CAZALIS JACQUELINE	Jacqueline	1947-02-25 00:00:00	\N	ANCIEN	Médecin (cardiologue)	3112	42	CRC	CRCE	\N	SOCI	SOCI	335	Hauts-de-Seine	\N	\N	FRAYSSE-CAZALIS	NON	\N	\N	2017-10-04 09:44:05	\N
000139	M.	Freville	FREVILLE HENRI	Henri	1905-12-04 00:00:00	1987-06-15 00:00:00	ANCIEN	Professeur d'université	3400	61	UCDP	U.C.D.P.	\N	LOIS	LOIS	350	Ille-et-Vilaine	\N	\N	FREVILLE	NON	\N	\N	\N	\N
000533	M.	Fuzier	FUZIER CLAUDE	Claude	1924-06-02 00:00:00	1997-01-22 00:00:00	ANCIEN	Journaliste	3511	54	SOC	SER	\N	AFCL	AFCL	775	Seine-Saint-Denis	\N	\N	FUZIER	NON	\N	\N	2017-10-04 09:46:30	\N
59229L	M.	Gallet	GALLET HENRI	Henri	1921-12-23 00:00:00	2009-05-18 00:00:00	ANCIEN	Agriculteur retraité	1000	10	SOC	SER	\N	LOIS	LOIS	620	Pas-de-Calais	\N	\N	GALLET	NON	\N	\N	2017-10-04 09:46:30	\N
000455	M.	Galley	GALLEY ROBERT	Robert	1921-01-11 00:00:00	2012-06-08 00:00:00	ANCIEN	Ingénieur	3800	31	RPR	RPR	\N	SOCI	SOCI	100	Aube	\N	\N	GALLEY	NON	\N	\N	2017-06-15 09:46:04	\N
58668C	M.	Gamboa	GAMBOA PIERRE	Pierre	1933-02-01 00:00:00	2014-11-19 00:00:00	ANCIEN	Journaliste	3511	54	C	C	\N	FINC	FINC	265	Essonne	\N	\N	GAMBOA	NON	\N	\N	2014-11-21 10:53:26	\N
000040	M.	Hugues	HUGUES EMILE	Emile	1901-04-07 00:00:00	1966-02-10 00:00:00	ANCIEN	Notaire	3128	52	GD	G.D.	\N	LOIS	LOIS	60	Alpes-Maritimes	\N	\N	HUGUES	NON	\N	\N	\N	\N
000273	M.	Isautier	ISAUTIER ALFRED	Alfred	1911-06-29 00:00:00	1984-09-04 00:00:00	ANCIEN	Ingénieur Conseil	3100	57	RI	RI	\N	ECON	ECON	974	La Réunion	\N	\N	ISAUTIER	NON	\N	\N	2016-11-30 16:19:39	\N
000308	M.	Jacquet	JACQUET MARC	Marc	1913-02-17 00:00:00	1983-04-18 00:00:00	ANCIEN	Administrateur de sociétés	3100	57	RPR	RPR	\N	FINC	FINC	770	Seine-et-Marne	\N	\N	JACQUET	NON	\N	\N	2017-12-19 15:12:18	\N
000207	M.	Jager	JAGER RENÉ	René	1909-03-08 00:00:00	1983-07-28 00:00:00	ANCIEN	Journaliste	3511	54	UCDP	U.C.D.P.	\N	ECON	ECON	570	Moselle	Questeur du Sénat	\N	JAGER	NON	\N	\N	\N	\N
000630	M.	Janetti	JANETTI MAURICE	Maurice	1933-03-01 00:00:00	1999-07-22 00:00:00	ANCIEN	Instituteur (directeur d'école)	4200	63	SOC	SER	\N	ECON	ECON	830	Var	\N	\N	JANETTI	NON	\N	\N	2017-10-04 09:46:30	\N
58348N	M.	Jargot	JARGOT PAUL	Paul	1925-03-31 00:00:00	2003-07-04 00:00:00	ANCIEN	Maître assistant associé	4200	64	C	C	\N	FINC	FINC	380	Isère	\N	\N	JARGOT	NON	\N	\N	\N	\N
59539X	M.	Jarrot	JARROT ANDRÉ	André	1909-12-13 00:00:00	2000-04-21 00:00:00	ANCIEN	Electro-mécanicien	6000	34	RPR	RPR	\N	ETRD	ETRD	710	Saône-et-Loire	\N	\N	JARROT	NON	\N	\N	2017-06-15 09:46:39	\N
000171	M.	Javelly	JAVELLY MAXIME	Maxime	1907-11-05 00:00:00	1983-02-26 00:00:00	ANCIEN	Commerçant	2200	22	SOC	SER	\N	ECON	ECON	40	Alpes de Haute-Provence	\N	\N	JAVELLY	NON	\N	\N	2017-10-04 09:46:30	\N
58650R	M.	Jouany	JOUANY ANDRÉ	André	1925-11-24 00:00:00	2003-01-04 00:00:00	ANCIEN	Chef d'entreprise	2300	21	GD	G.D.	\N	SOCI	SOCI	820	Tarn-et-Garonne	\N	\N	JOUANY	NON	\N	\N	\N	\N
58039C	M.	Jourdan	JOURDAN PIERRE	Pierre	1923-06-23 00:00:00	2020-10-21 00:00:00	ANCIEN	Agriculteur exploitant	1000	10	UREI	U.R.E.I.	\N	LOIS	LOIS	70	Ardèche	\N	\N	JOURDAN	NON	\N	\N	\N	\N
000225	M.	Junillon	JUNILLON LUCIEN	Lucien	1909-10-31 00:00:00	1984-10-29 00:00:00	ANCIEN	Administrateur des P et T	4500	72	NI	NI	\N	ECON	ECON	260	Drôme	\N	\N	JUNILLON	NON	\N	\N	\N	\N
000348	M.	Kauffmann	KAUFFMANN MICHEL	Michel	1914-09-22 00:00:00	1987-05-25 00:00:00	ANCIEN	Ingénieur agricole	1000	10	UCDP	U.C.D.P.	\N	ETRD	ETRD	670	Bas-Rhin	\N	\N	KAUFFMANN	NON	\N	\N	2015-02-10 12:00:26	\N
83035S	M.	Huchon	HUCHON	Jean	1928-09-04 00:00:00	2009-12-08 00:00:00	ANCIEN	Exploitant agricole	1000	10	UC	UC	\N	ECON	ECON	490	Maine-et-Loire	\N	\N	HUCHON	NON	\N	\N	2017-07-04 10:59:31	\N
82002D	M.	Le Grand	LEGRAND	Jean-François	1942-06-08 00:00:00	\N	ANCIEN	Docteur vétérinaire	3115	46	NI	NI	\N	ECON	ECON	500	Manche	\N	jean-francois.le.grand@cg50.fr	LE GRAND	NON	\N	\N	\N	\N
96004D	M.	Bizet	BIZET	Jean	1947-08-30 00:00:00	\N	ANCIEN	Docteur vétérinaire 	3115	59	UMP	Les Républicains	\N	FINC	FINC	500	Manche	\N	j.bizet@senat.fr	BIZET	NON	\N	\N	2017-10-09 16:22:49	\N
83056X	M.	Vecten	VECTEN	Albert	1926-02-16 00:00:00	2023-05-14 00:00:00	ANCIEN	Agriculteur	1000	10	UC	UC	\N	AFCL	AFCL	510	Marne	\N	\N	VECTEN	NON	\N	\N	2017-07-04 10:59:31	\N
74011H	M.	Berchet	BERCHET	Georges	1926-06-13 00:00:00	2004-11-04 00:00:00	ANCIEN	Ingénieur en chef du Génie rural, des eaux et des forêts	3311	71	RDSE	RDSE	\N	ECON	ECON	520	Haute-Marne	\N	\N	BERCHET	NON	\N	\N	\N	\N
92009R	M.	Bernadaux	BERNADAUX	Jean	1935-02-23 00:00:00	\N	ANCIEN	Directeur d'école honoraire	7400	69	UC	UC	\N	AFCL	AFCL	540	Meurthe-et-Moselle	\N	\N	BERNADAUX	NON	\N	\N	2017-07-04 10:59:31	\N
92007P	M.	Baudot	BAUDOT	Jacques	1936-03-09 00:00:00	2007-06-21 00:00:00	ANCIEN	Chirurgien-Dentiste	3113	45	UMP	Les Républicains	\N	FINC	FINC	540	Meurthe-et-Moselle	\N	j.baudot@senat.fr	BAUDOT	NON	\N	\N	2017-10-09 16:22:49	\N
74022L	M.	Herment	HERMENT	Rémi	1932-06-23 00:00:00	\N	ANCIEN	Agriculteur	1000	10	UC	UC	\N	ECON	ECON	550	Meuse	\N	\N	HERMENT	NON	\N	\N	2017-07-04 10:59:31	\N
74024N	M.	Jeambrun	JEAMBRUN	Pierre	1921-06-04 00:00:00	2001-02-07 00:00:00	ANCIEN	Receveur des Finances	3311	71	RDSE	RDSE	\N	AFCL	AFCL	390	Jura	\N	\N	JEAMBRUN	NON	\N	\N	\N	\N
83039W	M.	Labeyrie	LABEYRIE	Philippe	1938-04-29 00:00:00	2012-10-13 00:00:00	ANCIEN	Médecin	3112	42	SOC	SER	\N	AFCL	AFCL	400	Landes	\N	\N	LABEYRIE	NON	\N	\N	2017-10-04 09:46:30	\N
92015P	M.	Carrère	CARRERE	Jean-Louis	1944-12-04 00:00:00	\N	ANCIEN	Instituteur	4200	63	SOC	SER	\N	AFCL	AFCL	400	Landes	\N	jl.carrere@wanadoo.fr	CARRÈRE	NON	\N	\N	2017-10-04 09:52:11	\N
92022N	M.	Fauchon	FAUCHON	Pierre	1929-07-13 00:00:00	2016-07-25 00:00:00	ANCIEN	Avocat	3121	51	UC	UC	\N	AFCL	AFCL	410	Loir-et-Cher	\N	p.fauchon@senat.fr	FAUCHON	NON	\N	\N	2017-07-04 10:59:31	\N
97011G	M.	Fournier	FOURNIER BERNARD	Bernard	1946-09-13 00:00:00	\N	ANCIEN	Conseil en entreprise	3100	81	UMP	Les Républicains	N	ETRD	ETRD	420	Loire	\N	b.fournier@senat.fr	FOURNIER	NON	\N	\N	2023-10-01 00:37:00	\N
78006D	M.	Gouteyron	GOUTEYRON	Adrien	1933-05-13 00:00:00	2020-08-26 00:00:00	ANCIEN	Inspecteur général de l'Education nationale	3311	71	UMP	Les Républicains	\N	FINC	FINC	430	Haute-Loire	\N	a.gouteyron@senat.fr	GOUTEYRON	NON	\N	\N	2017-10-09 16:22:49	\N
83023N	M.	de Cossé-Brissac	COSSE-BRISSAC (DE)	Charles-Henri	1936-03-16 00:00:00	2003-08-15 00:00:00	ANCIEN	Exploitant agricole	1000	10	RI	RI	\N	ETRD	ETRD	440	Loire-Atlantique	\N	\N	de COSSÉ-BRISSAC	NON	\N	\N	\N	\N
11059R	M.	Leroy	LEROY JEAN_CLAUDE_11059R	Jean-Claude	1952-06-03 00:00:00	\N	ANCIEN	Attaché territorial	8000	35	SOC	SER	\N	CDD	CDD	620	Pas-de-Calais	\N	jc.leroy@senat.fr	LEROY	NON	\N	\N	2017-10-04 09:46:30	\N
83012K	M.	Autain	AUTAIN	François	1935-06-16 00:00:00	2019-12-20 00:00:00	ANCIEN	Médecin	3112	42	CRC	CRCE	\N	SOCI	SOCI	440	Loire-Atlantique	\N	f.autain@senat.fr	AUTAIN	NON	\N	\N	2017-10-04 09:44:05	\N
11060J	Mme	Bouchart	BOUCHART_NATACHA_11060J	Natacha	1963-05-29 00:00:00	\N	ANCIEN	Directrice des ressources humaines	8000	32	UMP	Les Républicains	\N	CDD	CDD	620	Pas-de-Calais	\N	n.bouchart@senat.fr	BOUCHART	NON	\N	\N	2017-10-09 16:22:49	\N
88004G	M.	Boyer	BOYER ANDRE	André	1931-05-14 00:00:00	2008-09-24 00:00:00	ANCIEN	Médecin	3112	42	RDSE	RDSE	\N	ETRD	ETRD	460	Lot	\N	\N	BOYER	NON	\N	\N	\N	\N
83033Q	M.	François-Poncet	FRANCOISPONCET	Jean	1928-12-08 00:00:00	2012-07-18 00:00:00	ANCIEN	Ministre plénipotentiaire	3311	71	UMP	Les Républicains	\N	ETRD	ETRD	470	Lot-et-Garonne	\N	j.francois-poncet@senat.fr	FRANÇOIS-PONCET	NON	\N	\N	2017-10-09 16:22:49	\N
58626R	Mme	Le Bellegou-Beguin	LEBELLEGOU-BEGUIN GENEVIÈVE	Geneviève	1926-04-15 00:00:00	2012-04-27 00:00:00	ANCIEN	Avocate	3121	51	SOC	SER	\N	LOIS	LOIS	830	Var	\N	\N	LE BELLEGOU-BEGUIN	NON	\N	\N	2017-10-04 09:46:30	\N
58924Y	M.	Le Cozannet	LECOZANNET YVES	Yves	1927-04-13 00:00:00	2004-08-19 00:00:00	ANCIEN	Agriculteur	1000	10	UC	UC	-R	ECON	ECON	1026	Côtes-du-Nord	\N	\N	LE COZANNET	NON	\N	\N	2017-07-04 10:59:31	\N
000170	M.	Le Montagner	LEMONTAGNER LOUIS	Louis	1907-10-05 00:00:00	1983-01-30 00:00:00	ANCIEN	Directeur Commercial	2300	21	UCDP	U.C.D.P.	\N	ETRD	ETRD	560	Morbihan	\N	\N	LE MONTAGNER	NON	\N	\N	\N	\N
58652T	M.	Le Pors	LEPORS ANICET	Anicet	1931-04-28 00:00:00	\N	ANCIEN	Ingénieur	3311	71	C	C	\N	FINC	FINC	335	Hauts-de-Seine	\N	\N	LE PORS	NON	\N	\N	2016-12-14 15:23:15	\N
000014	M.	Lebreton	LEBRETON MARCEL	Marcel	1900-05-22 00:00:00	1979-09-29 00:00:00	ANCIEN	Agriculteur	1000	10	RI	RI	\N	ECON	ECON	760	Seine-Maritime	Secrétaire du Sénat	\N	LEBRETON	NON	\N	\N	\N	\N
000442	M.	Lecanuet	LECANUET JEAN	Jean	1920-03-04 00:00:00	1993-02-22 00:00:00	ANCIEN	Conseiller d'Etat	3311	71	UC	UC	\N	ETRD	ETRD	760	Seine-Maritime	\N	\N	LECANUET	NON	\N	\N	2017-07-04 10:59:31	\N
58941A	M.	Leccia	LECCIA BASTIEN	Bastien	1919-11-03 00:00:00	2004-04-09 00:00:00	ANCIEN	Directeur de société	7200	29	SOC	SER	\N	ETRD	ETRD	130	Bouches-du-Rhône	\N	\N	LECCIA	NON	\N	\N	2017-10-04 09:46:30	\N
000060	M.	Claparede	CLAPAREDE EMILE	Emile	1902-03-02 00:00:00	1967-08-03 00:00:00	ANCIEN	Viticulteur	2300	21	GD	G.D.	\N	SOCI	SOCI	340	Hérault	\N	\N	CLAPAREDE	NON	\N	\N	\N	\N
000235	M.	Colin	COLIN ANDRÉ	André	1910-01-19 00:00:00	1978-08-29 00:00:00	ANCIEN	Universitaire	3400	61	UCDP	U.C.D.P.	\N	ETRD	ETRD	290	Finistère	\N	\N	COLIN	NON	\N	\N	2015-02-10 12:00:26	\N
58805S	M.	Colin	COLIN JEAN	Jean	1923-03-21 00:00:00	2006-05-04 00:00:00	ANCIEN	Ancien administrateur des PTT	3311	71	UC	UC	\N	ECON	ECON	265	Essonne	\N	\N	COLIN	NON	\N	\N	2017-07-04 10:59:31	\N
000494	M.	Collery	COLLERY JEAN	Jean	1922-07-01 00:00:00	1976-03-18 00:00:00	ANCIEN	Viticulteur	1000	10	UCDP	U.C.D.P.	\N	AFCL	AFCL	510	Marne	\N	\N	COLLERY	NON	\N	\N	\N	\N
59528U	M.	Collomb	COLLOMB FRANCISQUE	Francisque	1910-12-19 00:00:00	2009-07-24 00:00:00	ANCIEN	Industriel	2300	21	UC	UC	-R	ECON	ECON	690	Rhône	\N	\N	COLLOMB	NON	\N	\N	2017-07-04 10:59:31	\N
000196	M.	Constant	CONSTANT GEORGES	Georges	1908-08-14 00:00:00	1989-10-16 00:00:00	ANCIEN	Médecin	3112	42	GD	G.D.	\N	ETRD	ETRD	460	Lot	\N	\N	CONSTANT	NON	\N	\N	\N	\N
57710G	M.	Coppenrath	COPPENRATH GÉRALD	Gérald	1922-04-27 00:00:00	2008-11-05 00:00:00	ANCIEN	Avocat	3121	51	UNR	U.N.R.	\N	AFCL	AFCL	983	Polynésie française	\N	\N	COPPENRATH	NON	\N	\N	2017-01-09 09:49:33	\N
89011K	M.	Cornac	CORNAC CLAUDE	Claude	1939-10-01 00:00:00	1996-01-12 00:00:00	ANCIEN	Cadre commercial	3600	32	SOC	SER	\N	LOIS	LOIS	310	Haute-Garonne	\N	\N	CORNAC	NON	\N	\N	2017-10-04 09:46:30	\N
000073	M.	Cornat	CORNAT HENRI	Henri	1903-02-14 00:00:00	1968-06-16 00:00:00	ANCIEN	Ingénieur	3800	31	RI	RI	\N	ECON	ECON	500	Manche	\N	\N	CORNAT	NON	\N	\N	\N	\N
000192	M.	Coudert	COUDERT JACQUES	Jacques	1908-07-30 00:00:00	1988-09-17 00:00:00	ANCIEN	Expert agricole	3100	57	RPR	RPR	-A	ECON	ECON	190	Corrèze	\N	\N	COUDERT	NON	\N	\N	\N	\N
000205	M.	Courriere	COURRIERE ANTOINE	Antoine	1909-01-23 00:00:00	1974-09-20 00:00:00	ANCIEN	Notaire	3128	52	SOC	SER	\N	FINC	FINC	110	Aude	\N	\N	COURRIERE	NON	\N	\N	2017-10-04 09:46:30	\N
000173	M.	Coutrot	COUTROT MAURICE	Maurice	1907-12-03 00:00:00	1992-09-17 00:00:00	ANCIEN	Employé de commerce	5400	33	SOC	SER	\N	ECON	ECON	775	Seine-Saint-Denis	\N	\N	COUTROT	NON	\N	\N	2017-10-04 09:46:30	\N
59529V	M.	Couve De Murville	COUVE DE MURVILLE MAURICE	Maurice	1907-01-24 00:00:00	1999-12-24 00:00:00	ANCIEN	Inspecteur général des finances en retraite	7400	71	RPR	RPR	\N	FINC	FINC	615	Paris	\N	\N	COUVE DE MURVILLE	NON	\N	\N	2017-06-15 09:44:27	\N
71011U	M.	Croze	CROZE PIERRE	Pierre	1921-05-14 00:00:00	1998-01-19 00:00:00	ANCIEN	Administrateur de sociétés	2300	21	RI	RI	\N	ETRD	ETRD	997	Français établis hors de France	\N	\N	CROZE	NON	\N	\N	\N	\N
59530N	M.	Crucis	CRUCIS MICHEL	Michel	1922-01-04 00:00:00	2012-09-10 00:00:00	ANCIEN	Conseiller juridique et fiscal	3100	57	RI	RI	\N	ETRD	ETRD	850	Vendée	\N	\N	CRUCIS	NON	\N	\N	2017-12-19 15:12:17	\N
70001N	M.	de Bourgoing	BOURGOING (DE)	Philippe	1921-07-25 00:00:00	2007-02-19 00:00:00	ANCIEN	Agriculteur	1000	10	RI	RI	\N	LOIS	LOIS	140	Calvados	\N	\N	DE BOURGOING	NON	\N	\N	\N	\N
89010J	M.	Besse	BESSE ROGER	Roger	1929-08-18 00:00:00	2009-01-07 00:00:00	ANCIEN	Commerçant (retraité)	2000	29	UMP	Les Républicains	\N	FINC	FINC	150	Cantal	\N	r.besse@senat.fr	BESSE	NON	\N	\N	2017-10-09 16:22:49	\N
89038W	M.	Rigaudière	RIGAUDIERE	Roger	1932-07-22 00:00:00	1999-02-17 00:00:00	ANCIEN	Agriculteur	1000	10	RPR	RPR	\N	ECON	ECON	150	Cantal	\N	\N	RIGAUDIÈRE	NON	\N	\N	\N	\N
96008H	M.	Arnaud	ARNAUD	Philippe	1949-02-01 00:00:00	2018-09-16 00:00:00	ANCIEN	Chef d'exploitation agricole	1000	10	UC	UC	\N	LOIS	LOIS	160	Charente	Secrétaire du Sénat	p.arnaud@senat.fr	ARNAUD	NON	\N	\N	2017-07-04 10:59:31	\N
89014N	M.	Doublet	DOUBLET	Michel	1939-09-26 00:00:00	2022-08-18 00:00:00	ANCIEN	Agriculteur	1000	10	UMP	Les Républicains	\N	AFCL	AFCL	170	Charente-Maritime	\N	Michel.Doublet@wanadoo.fr	DOUBLET	NON	\N	\N	2017-10-09 16:22:49	\N
89012L	M.	Blaizot	BLAIZOT	François	1923-09-21 00:00:00	2007-07-17 00:00:00	ANCIEN	Ingénieur général du génie rural en retraite	7400	79	UC	UC	\N	LOIS	LOIS	170	Charente-Maritime	\N	\N	BLAIZOT	NON	\N	\N	2017-07-04 10:59:31	\N
71017B	M.	Genton	GENTON	Jacques	1918-09-22 00:00:00	2008-11-27 00:00:00	ANCIEN	Secrétaire général honoraire du comité économique et social des communautés européennes	7400	79	UC	UC	\N	ETRD	ETRD	180	Cher	\N	\N	GENTON	NON	\N	\N	2017-07-04 10:59:31	\N
89045V	M.	Vinçon	VINCON	Serge	1949-06-17 00:00:00	2007-12-16 00:00:00	ANCIEN	Professeur de collège	4200	62	UMP	Les Républicains	\N	ETRD	ETRD	180	Cher	\N	s.vincon@senat.fr	VINÇON	NON	\N	\N	2017-10-09 16:22:49	\N
80007A	M.	Belcour	BELCOUR	Henri	1926-09-11 00:00:00	2003-11-19 00:00:00	ANCIEN	Médecin	3112	42	RPR	RPR	\N	SOCI	SOCI	190	Corrèze	\N	\N	BELCOUR	NON	\N	\N	2017-06-15 09:44:02	\N
71009B	M.	Cluzel	CLUZEL	Jean	1923-11-18 00:00:00	2020-09-12 00:00:00	ANCIEN	Sans profession déclarée	8000	80	UC	UC	\N	FINC	FINC	30	Allier	\N	\N	CLUZEL	NON	\N	\N	2017-07-04 10:59:31	\N
07024N	M.	Gautier	GAUTIER JACQUES	Jacques	1946-09-18 00:00:00	\N	ANCIEN	Conseiller d'entreprise	3100	21	UMP	Les Républicains	\N	ETRD	ETRD	335	Hauts-de-Seine	\N	jacques.gautier@senat.fr	GAUTIER	NON	\N	\N	2017-10-09 16:22:49	\N
89018S	M.	Barraux	BARRAUX	Bernard	1935-02-05 00:00:00	\N	ANCIEN	Commerçant	2300	21	UMP	Les Républicains	-R	ETRD	ETRD	30	Allier	\N	\N	BARRAUX	NON	\N	\N	2017-10-09 16:22:49	\N
80043E	M.	Tardy	TARDY	Fernand	1919-06-14 00:00:00	2017-04-04 00:00:00	ANCIEN	Ingénieur horticole	3800	31	SOC	SER	\N	ECON	ECON	40	Alpes de Haute-Provence	\N	\N	TARDY	NON	\N	\N	2017-10-04 09:46:30	\N
89046W	M.	Bailet	BAILET	Honoré	1920-02-27 00:00:00	2003-09-16 00:00:00	ANCIEN	Chevillard	2200	22	RPR	RPR	\N	AFCL	AFCL	60	Alpes-Maritimes	\N	\N	BAILET	NON	\N	\N	\N	\N
85003S	M.	Laffitte	LAFFITTE	Pierre	1925-01-01 00:00:00	2021-07-07 00:00:00	ANCIEN	Ingénieur général des Mines	3311	71	RDSE	RDSE	\N	AFCL	AFCL	60	Alpes-Maritimes	\N	p.laffitte@senat.fr	LAFFITTE	NON	\N	\N	\N	\N
59534S	M.	Garcia	GARCIA JEAN	Jean	1925-06-05 00:00:00	2012-02-08 00:00:00	ANCIEN	Tourneur	6000	34	C	C	\N	ETRD	ETRD	775	Seine-Saint-Denis	\N	\N	GARCIA	NON	\N	\N	\N	\N
000131	M.	Garet	GARET PIERRE	Pierre	1905-09-07 00:00:00	1972-12-10 00:00:00	ANCIEN	Avocat	3121	51	RI	RI	\N	LOIS	LOIS	800	Somme	Vice-président du Sénat	\N	GARET	NON	\N	\N	2015-02-10 12:00:26	\N
80020W	M.	Gaud	GAUD GÉRARD	Gérard	1925-06-02 00:00:00	1996-09-03 00:00:00	ANCIEN	Ingénieur	3800	31	SOC	SER	\N	ETRD	ETRD	260	Drôme	\N	\N	GAUD	NON	\N	\N	2017-10-04 09:46:30	\N
000306	M.	Gaudin	GAUDIN PIERRE	Pierre	1913-02-15 00:00:00	1978-01-02 00:00:00	ANCIEN	Agriculteur	1000	10	SOC	SER	\N	ECON	ECON	830	Var	\N	\N	GAUDIN	NON	\N	\N	2017-10-04 09:46:31	\N
000536	M.	Gaudon	GAUDON ROGER	Roger	1924-09-03 00:00:00	1997-02-12 00:00:00	ANCIEN	Ouvrier	6000	34	C	C	\N	FINC	FINC	824	Val-de-Marne	\N	\N	GAUDON	NON	\N	\N	\N	\N
000137	M.	Gauthier	GAUTHIER ABEL	Abel	1905-11-17 00:00:00	1991-02-28 00:00:00	ANCIEN	Agriculteur	1000	10	SOC	SER	\N	SOCI	SOCI	630	Puy-de-Dôme	\N	\N	GAUTHIER	NON	\N	\N	2017-10-04 09:46:31	\N
59535T	M.	Gautier	GAUTIER FRANÇOIS	François	1940-04-23 00:00:00	\N	ANCIEN	Conseiller référendaire à la Cour des Comptes	3311	71	UC	UC	\N	FINC	FINC	760	Seine-Maritime	\N	\N	GAUTIER	NON	\N	\N	2017-07-04 10:59:31	\N
000319	M.	Gautier	GAUTIER LUCIEN	Lucien	1913-07-27 00:00:00	1992-02-03 00:00:00	ANCIEN	Négociant	2200	23	RPR	RPR	\N	ETRD	ETRD	490	Maine-et-Loire	\N	\N	GAUTIER	NON	\N	\N	\N	\N
000071	M.	Gay	GAY ETIENNE	Etienne	1902-11-20 00:00:00	1984-03-04 00:00:00	ANCIEN	Négociant	2200	23	RI	RI	\N	SOCI	SOCI	1030	Oran-Tlemcen	\N	\N	GAY	NON	\N	\N	2017-12-19 15:12:18	\N
000114	M.	Geoffroy	GEOFFROY JEAN	Jean	1905-01-07 00:00:00	1991-02-03 00:00:00	ANCIEN	Notaire	3121	57	SOC	SER	\N	LOIS	LOIS	840	Vaucluse	\N	\N	GEOFFROY	NON	\N	\N	2017-10-04 09:46:31	\N
58656X	M.	Gerin	GERIN ALFRED	Alfred	1924-10-22 00:00:00	2009-06-01 00:00:00	ANCIEN	Agriculteur	1000	10	UC	UC	-R	ETRD	ETRD	690	Rhône	\N	\N	GERIN	NON	\N	\N	2017-07-04 10:59:31	\N
58631N	Mme	Goldet	GOLDET CÉCILE	Cécile	1914-03-15 00:00:00	2019-10-27 00:00:00	ANCIEN	Médecin	3112	42	SOC	SER	\N	SOCI	SOCI	615	Paris	\N	\N	GOLDET	NON	\N	\N	2017-10-04 09:46:31	\N
11022C	Mme	Farreyrol	FARREYROL_JACQUELINE_11022C	Jacqueline	1939-02-25 00:00:00	\N	ANCIEN	Chargé de mission à la culture	8000	62	UMP	Les Républicains	\N	AFCL	AFCL	974	La Réunion	\N	j.farreyrol@senat.fr	FARREYROL	OUI	\N	\N	2017-10-09 16:22:49	\N
000186	M.	de Hauteclocque	HAUTECLOCQUE BAUDOUIN DE	Baudouin	1908-06-13 00:00:00	1981-10-09 00:00:00	ANCIEN	Propriétaire exploitant	1000	10	UREI	U.R.E.I.	\N	LOIS	LOIS	620	Pas-de-Calais	Secrétaire du Sénat	\N	de HAUTECLOCQUE	NON	\N	\N	\N	\N
000095	M.	Tailhades	TAILHADES EDGAR	Edgar	1904-01-12 00:00:00	1986-06-23 00:00:00	ANCIEN	Avocat	3121	51	SOC	SER	\N	LOIS	LOIS	300	Gard	\N	\N	TAILHADES	NON	\N	\N	2017-10-04 09:46:31	\N
59560U	M.	Taittinger	TAITTINGER PIERRE-CHRISTIA	Pierre-Christian	1926-02-05 00:00:00	2009-09-27 00:00:00	ANCIEN	Chef d'entreprise	2300	21	RI	RI	\N	SOCI	SOCI	615	Paris	Vice-président du Sénat	\N	TAITTINGER	NON	\N	\N	\N	\N
000592	M.	Tajan	TAJAN PIERRE	Pierre	1928-09-27 00:00:00	1984-03-20 00:00:00	ANCIEN	Agriculteur	1000	10	GDSRG	G.D.S.R.G.	\N	ECON	ECON	820	Tarn-et-Garonne	\N	\N	TAJAN	NON	\N	\N	\N	\N
000302	M.	Talamoni	TALAMONI LOUIS	Louis	1912-12-19 00:00:00	1975-04-30 00:00:00	ANCIEN	Comptable	5400	33	C	C	\N	FINC	FINC	824	Val-de-Marne	\N	\N	TALAMONI	NON	\N	\N	\N	\N
58508L	M.	Talon	TALON BERNARD	Bernard	1930-06-16 00:00:00	2022-03-09 00:00:00	ANCIEN	Adjoint technique	5400	33	RPR	RPR	\N	SOCI	SOCI	125	Territoire de Belfort	\N	\N	TALON	NON	\N	\N	\N	\N
000006	M.	Terre	TERRE HENRI	Henri	1900-02-16 00:00:00	1978-10-13 00:00:00	ANCIEN	Négociant	2200	23	UREI	U.R.E.I.	\N	SOCI	SOCI	100	Aube	\N	\N	TERRE	NON	\N	\N	\N	\N
000118	M.	Thiebault	THIEBAULT ROGER	Roger	1905-03-12 00:00:00	1977-03-17 00:00:00	ANCIEN	Verrier	2100	24	SOC	SER	\N	SOCI	SOCI	760	Seine-Maritime	\N	\N	THIEBAULT	NON	\N	\N	2017-10-04 09:46:31	\N
98023Q	M.	Cornu	CORNU GERARD	Gérard	1952-02-06 00:00:00	\N	ANCIEN	Opticien-Audioprothésiste	2200	29	UMP	Les Républicains	-A	CDD	CDD	280	Eure-et-Loir	\N	g.cornu@senat.fr	CORNU	NON	\N	\N	2017-10-09 16:22:49	\N
98024R	M.	Dériot	DERIOT	Gérard	1944-11-01 00:00:00	\N	ANCIEN	Pharmacien	8000	44	UMP	Les Républicains	-R	SOCI	SOCI	30	Allier	\N	g.deriot@senat.fr	DÉRIOT	NON	\N	\N	2017-10-09 16:22:49	\N
98025S	M.	Lepeltier	LEPELTIER	Serge	1953-10-12 00:00:00	\N	ANCIEN	Cadre d'entreprise	8000	32	UMP	Les Républicains	\N	AFCL	AFCL	180	Cher	\N	\N	LEPELTIER	NON	\N	\N	2017-10-09 16:22:50	\N
98026T	M.	Vissac	VISSAC	Guy	1933-12-31 00:00:00	\N	ANCIEN	Commerçant retraité	8000	29	RPR	RPR	\N	SOCI	SOCI	430	Haute-Loire	\N	\N	VISSAC	NON	\N	\N	\N	\N
98027U	M.	Jarlier	JARLIER	Pierre	1954-07-14 00:00:00	\N	ANCIEN	Architecte	8000	35	UC	UC	\N	FINC	FINC	150	Cantal	\N	p.jarlier@senat.fr	JARLIER	NON	\N	\N	2017-07-04 10:59:31	\N
98029W	M.	Cazeau	CAZEAU	Bernard	1939-04-27 00:00:00	\N	ANCIEN	Médecin	3112	42	LREM	RDPI	\N	ETRD	ETRD	240	Dordogne	\N	b.cazeau@senat.fr	CAZEAU	NON	\N	\N	2017-11-08 09:39:51	\N
98030P	M.	Domeizel	DOMEIZEL	Claude	1940-05-16 00:00:00	\N	ANCIEN	Professeur des écoles	4200	63	SOC	SER	\N	AFCL	AFCL	40	Alpes de Haute-Provence	\N	c.domeizel@senat.fr	DOMEIZEL	NON	\N	\N	2017-10-04 09:46:31	\N
98032R	M.	de Montesquiou	MONTESQUIOU (DE)	Aymeri	1942-07-07 00:00:00	\N	ANCIEN	Exploitant agricole	8000	10	UC	UC	\N	ETRD	ETRD	320	Gers	\N	a.demontesquiou@senat.fr	de MONTESQUIOU	NON	\N	\N	2017-07-04 10:59:31	\N
98033S	M.	Rispat	RISPAT	Yves	1931-09-17 00:00:00	2015-01-15 00:00:00	ANCIEN	Exploitant agricole	8000	10	UMP	Les Républicains	\N	ETRD	ETRD	320	Gers	\N	y.rispat@senat.fr	RISPAT	NON	\N	\N	2017-10-09 16:22:50	\N
98034T	M.	Journet	JOURNET	Alain	1941-06-25 00:00:00	\N	ANCIEN	Géomètre-expert en disponibilité	8000	73	SOC	SER	\N	AFCL	AFCL	300	Gard	\N	JOURNET.Alain@wanadoo.fr	JOURNET	NON	\N	\N	2017-10-04 09:46:31	\N
98035U	M.	Sutour	SUTOUR	Simon	1952-08-18 00:00:00	\N	ANCIEN	Administrateur territorial	8000	79	SOC	SER	\N	LOIS	LOIS	300	Gard	\N	Simon.Sutour@orange.fr	SUTOUR	NON	\N	\N	2017-10-04 09:46:31	\N
59226H	M.	Delelis	DELELIS ANDRÉ	André	1924-05-23 00:00:00	2012-09-04 00:00:00	ANCIEN	Sans profession déclarée	8000	80	SOC	SER	\N	ETRD	ETRD	620	Pas-de-Calais	\N	\N	DELELIS	NON	\N	\N	2017-10-04 09:46:31	\N
59572Y	M.	Delga	DELGA FRANÇOIS	François	1919-05-14 00:00:00	2016-06-22 00:00:00	ANCIEN	Médecin	3112	42	NI	NI	\N	SOCI	SOCI	810	Tarn	\N	\N	DELGA	NON	\N	\N	2016-06-28 13:37:01	\N
92018S	Mme	Demessine	DEMESSINE MICHELLE	Michelle	1947-06-18 00:00:00	\N	ANCIEN	Secrétaire	5400	35	CRC	CRCE	\N	ETRD	ETRD	590	Nord	\N	m.demessine@senat.fr	DEMESSINE	OUI	\N	\N	2017-10-04 09:44:05	\N
000180	Mme	Dervaux	DERVAUX RENÉE	Renée	1908-03-09 00:00:00	1996-10-26 00:00:00	ANCIEN	Comptable	5400	33	C	C	\N	AFCL	AFCL	1029	Seine	\N	\N	DERVAUX	NON	\N	\N	\N	\N
58670V	M.	Desbriere	DESBRIERE BERNARD	Bernard	1935-05-10 00:00:00	\N	ANCIEN	Viticulteur	1000	10	SOC	SER	\N	ECON	ECON	710	Saône-et-Loire	\N	\N	DESBRIERE	NON	\N	\N	2017-10-04 09:46:31	\N
11048N	M.	Husson	HUSSON_JEAN_FRANCOIS_C4969	Jean-François	1961-04-17 00:00:00	\N	ACTIF	Agent d'assurance	8000	81	UMP	Les Républicains	\N	FINC	FINC	540	Meurthe-et-Moselle	\N	jf.husson@senat.fr	HUSSON	NON	59	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/husson-jean-francois.html
000331	M.	Descours Desacres	DESCOURS DESACRES JACQUES	Jacques	1914-01-21 00:00:00	1993-10-31 00:00:00	ANCIEN	Agriculteur	1000	10	UREI	U.R.E.I.	\N	FINC	FINC	140	Calvados	\N	\N	DESCOURS DESACRES	NON	\N	\N	\N	\N
58367R	M.	Desmarets	DESMARETS JEAN	Jean	1910-06-03 00:00:00	1999-10-23 00:00:00	ANCIEN	Négociant	2200	23	NI	NI	\N	ETRD	ETRD	590	Nord	\N	\N	DESMARETS	NON	\N	\N	\N	\N
000084	M.	Desseigne	DESSEIGNE HENRI	Henri	1903-08-21 00:00:00	1990-07-15 00:00:00	ANCIEN	Directeur de tissages	2300	21	UC	UC	\N	ECON	ECON	420	Loire	\N	\N	DESSEIGNE	NON	\N	\N	2017-07-04 10:59:31	\N
58043X	M.	Deveze	DEVEZE GILBERT	Gilbert	1921-06-21 00:00:00	2010-04-08 00:00:00	ANCIEN	Agriculteur, exploitant forestier, industriel	1000	10	RI	RI	\N	ETRD	ETRD	20	Aisne	\N	\N	DEVEZE	NON	\N	\N	\N	\N
58943C	M.	Didier	DIDIER EMILE	Emile	1909-12-30 00:00:00	2000-01-28 00:00:00	ANCIEN	Pharmacien	3116	44	RDE	R.D.E.	\N	ETRD	ETRD	50	Hautes-Alpes	\N	\N	DIDIER	NON	\N	\N	2017-06-15 09:45:03	\N
000220	M.	Driant	DRIANT PAUL	Paul	1909-09-24 00:00:00	1980-06-25 00:00:00	ANCIEN	Agriculteur	1000	10	RI	RI	\N	FINC	FINC	570	Moselle	\N	\N	DRIANT	NON	\N	\N	\N	\N
58330C	M.	Dubanchet	DUBANCHET FRANÇOIS	François	1923-05-05 00:00:00	2019-03-26 00:00:00	ANCIEN	Directeur de la Chambre d'Agriculture de la Loire	3600	32	UCDP	U.C.D.P.	\N	ETRD	ETRD	420	Loire	\N	\N	DUBANCHET	NON	\N	\N	\N	\N
000203	M.	Dubois	DUBOIS HECTOR	Hector	1908-11-30 00:00:00	1991-06-16 00:00:00	ANCIEN	Agriculteur	1000	10	NI	NI	\N	ECON	ECON	600	Oise	\N	\N	DUBOIS	NON	\N	\N	\N	\N
59227J	M.	Duboscq	DUBOSCQ FRANZ	Franz	1924-05-06 00:00:00	2012-12-07 00:00:00	ANCIEN	Agriculteur	1000	10	RPR	RPR	\N	ETRD	ETRD	640	Pyrénées-Atlantiques	\N	\N	DUBOSCQ	NON	\N	\N	\N	\N
000105	M.	Duchet	DUCHET ROGER	Roger	1904-07-04 00:00:00	1981-09-06 00:00:00	ANCIEN	Propriétaire-viticulteur	1000	10	RI	RI	\N	AFCL	AFCL	210	Côte-d'Or	\N	\N	DUCHET	NON	\N	\N	2015-02-10 12:00:26	\N
000164	M.	Duffaut	DUFFAUT HENRI	Henri	1907-06-07 00:00:00	1987-05-11 00:00:00	ANCIEN	Avocat	3121	51	SOC	SER	\N	FINC	FINC	840	Vaucluse	\N	\N	DUFFAUT	NON	\N	\N	2017-10-04 09:46:31	\N
07028S	Mme	Descamps	DESCAMPS BÉATRICE	Béatrice	1951-06-22 00:00:00	\N	ANCIEN	Professeur	3400	62	NI	NI	\N	NEANT	Aucune	590	Nord	\N	b.descamps@senat.fr	DESCAMPS	OUI	\N	\N	2017-06-19 16:13:09	\N
000009	M.	Dumas	DUMAS ALEXANDRE	Alexandre	1896-03-13 00:00:00	1989-11-14 00:00:00	ANCIEN	Agent d'assurances	4600	57	GD	G.D.	\N	AFCL	AFCL	160	Charente	\N	\N	DUMAS	NON	\N	\N	\N	\N
59531P	M.	Dumas	DUMAS PIERRE	Pierre	1924-11-15 00:00:00	2004-02-04 00:00:00	ANCIEN	Administrateur de société	2300	21	RPR	RPR	\N	ECON	ECON	730	Savoie	\N	\N	DUMAS	NON	\N	\N	\N	\N
000511	M.	Dumont	DUMONT CLAUDE	Claude	1923-07-06 00:00:00	1979-08-23 00:00:00	ANCIEN	Administrateur de sociétés	3100	57	UC	UC	\N	ETRD	ETRD	1045	Setif-Batna	\N	\N	DUMONT	NON	\N	\N	2017-07-04 10:59:31	\N
59573A	M.	Dumont	DUMONT JEAN	Jean	1930-11-27 00:00:00	2021-01-18 00:00:00	ANCIEN	Docteur vétérinaire	3115	46	RI	RI	\N	SOCI	SOCI	790	Deux-Sèvres	\N	\N	DUMONT	NON	\N	\N	\N	\N
58420D	M.	Dumont	DUMONT RAYMOND	Raymond	1925-10-13 00:00:00	2009-05-09 00:00:00	ANCIEN	Instituteur	4200	63	C	C	\N	ECON	ECON	620	Pas-de-Calais	\N	\N	DUMONT	NON	\N	\N	\N	\N
000041	M.	Durand	DURAND CHARLES	Charles	1901-04-15 00:00:00	1983-03-28 00:00:00	ANCIEN	Agriculteur	1000	10	UCDP	U.C.D.P.	\N	AFCL	AFCL	180	Cher	\N	\N	DURAND	NON	\N	\N	\N	\N
000647	M.	Durand	DURAND JACQUES	Jacques	1939-02-18 00:00:00	1991-01-05 00:00:00	ANCIEN	Professeur	4200	62	SOC	SER	\N	AFCL	AFCL	810	Tarn	\N	\N	DURAND	NON	\N	\N	2017-10-04 09:46:31	\N
58643S	M.	Durand	DURAND YVES	Yves	1910-03-12 00:00:00	2003-12-24 00:00:00	ANCIEN	Chef d'entreprise	2300	21	NI	NI	\N	FINC	FINC	850	Vendée	Secrétaire du Sénat	\N	DURAND	NON	\N	\N	\N	\N
59509R	M.	Durbec	DURBEC GUY	Guy	1942-04-01 00:00:00	\N	ANCIEN	Cadre des travaux publics	3600	32	SOC	SER	\N	SOCI	SOCI	830	Var	\N	\N	DURBEC	NON	\N	\N	2017-10-04 09:46:31	\N
000122	M.	Durieux	DURIEUX EMILE	Emile	1905-05-13 00:00:00	1995-05-05 00:00:00	ANCIEN	Agriculteur	1000	10	SOC	SER	\N	ECON	ECON	620	Pas-de-Calais	\N	\N	DURIEUX	NON	\N	\N	2017-10-04 09:46:31	\N
59305F	M.	Duromea	DUROMEA ANDRÉ	André	1917-09-05 00:00:00	2011-03-16 00:00:00	ANCIEN	Ajusteur	6000	34	C	C	\N	ECON	ECON	760	Seine-Maritime	\N	\N	DUROMEA	NON	\N	\N	2017-06-15 09:46:19	\N
000134	M.	Dutoit	DUTOIT ADOLPHE	Adolphe	1905-09-29 00:00:00	1980-07-20 00:00:00	ANCIEN	Employé de la Société nationale des chemins de fer français	5400	33	C	C	\N	SOCI	SOCI	590	Nord	\N	\N	DUTOIT	NON	\N	\N	\N	\N
000082	M.	Duval	DUVAL FRANCOIS	François	1903-08-10 00:00:00	1984-06-28 00:00:00	ANCIEN	Notaire	3128	52	RPR	RPR	\N	AFCL	AFCL	972	Martinique	\N	\N	DUVAL	NON	\N	\N	\N	\N
58630M	M.	Eberhard	EBERHARD JACQUES	Jacques	1919-05-25 00:00:00	2009-07-29 00:00:00	ANCIEN	Ouvrier	6000	34	C	C	\N	ECON	ECON	760	Seine-Maritime	Secrétaire du Sénat	\N	EBERHARD	NON	\N	\N	\N	\N
57721K	Mme	Edeline	EDELINE HÉLÈNE	Hélène	1919-12-02 00:00:00	2004-06-27 00:00:00	ANCIEN	Sans profession déclarée	8000	80	C	C	\N	AFCL	AFCL	824	Val-de-Marne	\N	\N	EDELINE	NON	\N	\N	\N	\N
000411	M.	Elby	ELBY HENRI	Henri	1918-11-22 00:00:00	1986-07-31 00:00:00	ANCIEN	Chef d'entreprise	2300	21	UREI	U.R.E.I.	-R	ECON	ECON	620	Pas-de-Calais	\N	\N	ELBY	NON	\N	\N	\N	\N
000215	M.	Errecart	ERRECART JEAN	Jean	1909-07-12 00:00:00	1971-01-17 00:00:00	ANCIEN	Agriculteur	1000	10	UCDP	U.C.D.P.	\N	ECON	ECON	1004	Basses-Pyrénées	\N	\N	ERRECART	NON	\N	\N	\N	\N
58351H	M.	Espagnac	ESPAGNAC RAYMOND	Raymond	1925-09-08 00:00:00	2003-11-13 00:00:00	ANCIEN	Artisan	2100	24	SOC	SER	\N	AFCL	AFCL	380	Isère	\N	\N	ESPAGNAC	NON	\N	\N	2017-10-04 09:46:31	\N
000057	M.	Faggianelli	FAGGIANELLI JACQUES	Jacques	1901-11-18 00:00:00	1989-04-30 00:00:00	ANCIEN	Professeur	4200	62	GD	G.D.	\N	AFCL	AFCL	1002	Corse	\N	\N	FAGGIANELLI	NON	\N	\N	\N	\N
58934B	M.	Faigt	FAIGT JULES	Jules	1916-12-30 00:00:00	2011-07-08 00:00:00	ANCIEN	Employé de commerce (VRP)	3600	32	SOC	SER	\N	AFCL	AFCL	340	Hérault	\N	\N	FAIGT	NON	\N	\N	2017-10-04 09:46:31	\N
000380	M.	Fastinger	FASTINGER PIERRE	Pierre	1916-11-07 00:00:00	1985-07-10 00:00:00	ANCIEN	Employé	5400	33	UREI	U.R.E.I.	\N	LOIS	LOIS	570	Moselle	\N	\N	FASTINGER	NON	\N	\N	\N	\N
000197	M.	Faure	FAURE EDGAR	Edgar	1908-08-18 00:00:00	1988-03-30 00:00:00	ANCIEN	Avocat	3121	51	GD	G.D.	\N	AFCL	AFCL	250	Doubs	\N	\N	FAURE	NON	\N	\N	2017-06-15 09:46:56	\N
58818X	M.	Faure	FAURE MAURICE	Maurice	1922-01-02 00:00:00	2014-03-06 00:00:00	ANCIEN	Professeur agrégé	3400	61	GD	G.D.	\N	ETRD	ETRD	460	Lot	\N	\N	FAURE	NON	\N	\N	2017-06-15 09:46:56	\N
000177	M.	Ferrant	FERRANT CHARLES	Charles	1908-02-23 00:00:00	1996-08-17 00:00:00	ANCIEN	Chef de centre des télécommunications	3300	73	UC	UC	\N	ETRD	ETRD	760	Seine-Maritime	\N	\N	FERRANT	NON	\N	\N	2017-07-04 10:59:31	\N
000075	M.	Ferre	FERRE MANUEL	Manuel	1903-04-18 00:00:00	1989-11-03 00:00:00	ANCIEN	Directeur de banque	3000	32	GD	G.D.	\N	AFCL	AFCL	1044	Mostaganem-Tiaret	\N	\N	FERRE	NON	\N	\N	\N	\N
56905M	M.	Fichoux	FICHOUX JEAN	Jean	1914-04-16 00:00:00	2002-03-07 00:00:00	ANCIEN	Agriculteur	1000	10	RI	RI	\N	SOCI	SOCI	290	Finistère	\N	\N	FICHOUX	NON	\N	\N	\N	\N
000405	M.	Touzet	TOUZET RENÉ	René	1918-07-06 00:00:00	1982-11-18 00:00:00	ANCIEN	Directeur de sociétés	2300	21	GD	G.D.	\N	SOCI	SOCI	360	Indre	\N	\N	TOUZET	NON	\N	\N	\N	\N
59249Q	M.	Travert	TRAVERT RENÉ	René	1919-10-14 00:00:00	2016-10-05 00:00:00	ANCIEN	Agriculteur	1000	10	UREI	U.R.E.I.	\N	ECON	ECON	500	Manche	\N	\N	TRAVERT	NON	\N	\N	2016-10-07 10:09:04	\N
59561V	M.	Treille	TREILLE GEORGES	Georges	1921-09-02 00:00:00	2006-05-18 00:00:00	ANCIEN	Pharmacien honoraire	7400	49	UC	UC	-R	ETRD	ETRD	790	Deux-Sèvres	\N	\N	TREILLE	NON	\N	\N	2017-07-04 10:59:31	\N
59250H	M.	Ukeiwe	UKEIWE DICK	Dick	1928-12-13 00:00:00	2013-09-03 00:00:00	ANCIEN	Chef de magasin	5400	33	RPR	RPR	\N	AFCL	AFCL	982	Nouvelle-Calédonie	Secrétaire du Sénat	\N	UKEIWE	NON	\N	\N	2013-09-05 10:09:01	\N
000311	M.	Valcin	VALCIN EDMOND	Edmond	1913-03-10 00:00:00	1997-09-06 00:00:00	ANCIEN	Avocat	3121	51	RPR	RPR	\N	NEANT	Aucune	972	Martinique	Questeur du Sénat	\N	VALCIN	NON	\N	\N	\N	\N
55510R	M.	Vallin	VALLIN CAMILLE	Camille	1918-11-22 00:00:00	2009-08-09 00:00:00	ANCIEN	Haut fonctionnaire	3311	71	C	C	\N	FINC	FINC	690	Rhône	\N	\N	VALLIN	NON	\N	\N	\N	\N
59582B	M.	Vallon	VALLON PIERRE	Pierre	1927-11-10 00:00:00	2016-10-24 00:00:00	ANCIEN	Chef d'entreprise	2300	21	UC	UC	\N	AFCL	AFCL	690	Rhône	\N	\N	VALLON	NON	\N	\N	2017-07-04 10:59:31	\N
000074	M.	Vanrullen	VANRULLEN EMILE	Emile	1903-03-07 00:00:00	1980-07-18 00:00:00	ANCIEN	Professeur	4200	62	SOC	SER	\N	ECON	ECON	620	Pas-de-Calais	\N	\N	VANRULLEN	NON	\N	\N	2017-10-04 09:46:31	\N
000377	M.	Varlet	VARLET JEAN	Jean	1916-09-14 00:00:00	1984-12-03 00:00:00	ANCIEN	Employé	5400	33	SOC	SER	\N	SOCI	SOCI	590	Nord	\N	\N	VARLET	NON	\N	\N	2017-10-04 09:46:31	\N
000078	M.	Vassor	VASSOR JACQUES	Jacques	1903-07-01 00:00:00	1995-12-25 00:00:00	ANCIEN	Agriculteur	1000	10	CRARS	CRARS	\N	ETRD	ETRD	370	Indre-et-Loire	\N	\N	VASSOR	NON	\N	\N	\N	\N
000154	M.	Verdeille	VERDEILLE FERNAND	Fernand	1906-09-26 00:00:00	1974-10-19 00:00:00	ANCIEN	Libraire	2200	22	SOC	SER	\N	LOIS	LOIS	810	Tarn	\N	\N	VERDEILLE	NON	\N	\N	2017-10-04 09:46:31	\N
95067Q	M.	Vial	VIAL JEAN-PIERRE	Jean-Pierre	1951-02-17 00:00:00	\N	ANCIEN	Avocat	3121	51	UMP	Les Républicains	\N	ETRD	ETRD	730	Savoie	\N	jp.vial@senat.fr	VIAL	NON	\N	\N	2017-10-09 16:22:50	\N
59543T	M.	Lederman	LEDERMAN CHARLES	Charles	1913-01-27 00:00:00	1998-09-25 00:00:00	ANCIEN	Avocat	3121	51	C	C	\N	LOIS	LOIS	824	Val-de-Marne	\N	\N	LEDERMAN	NON	\N	\N	\N	\N
000280	M.	Lefort	LEFORT FERNAND	Fernand	1911-10-09 00:00:00	1991-10-02 00:00:00	ANCIEN	Ouvrier	6000	34	C	C	\N	FINC	FINC	775	Seine-Saint-Denis	\N	\N	LEFORT	NON	\N	\N	\N	\N
000201	M.	Legouez	LEGOUEZ MODESTE	Modeste	1908-09-24 00:00:00	1989-01-30 00:00:00	ANCIEN	Agriculteur	1000	10	UREI	U.R.E.I.	\N	FINC	FINC	270	Eure	\N	\N	LEGOUEZ	NON	\N	\N	2015-02-10 12:00:26	\N
000531	M.	Legrand	LEGRAND BERNARD	Bernard	1924-05-15 00:00:00	1997-01-31 00:00:00	ANCIEN	Dessinateur	5400	33	RDE	R.D.E.	\N	ECON	ECON	440	Loire-Atlantique	\N	\N	LEGRAND	NON	\N	\N	\N	\N
000144	M.	Lemaire	LEMAIRE MARCEL	Marcel	1906-05-07 00:00:00	1985-11-15 00:00:00	ANCIEN	Agriculteur	1000	10	UCDP	U.C.D.P.	-R	ECON	ECON	510	Marne	\N	\N	LEMAIRE	NON	\N	\N	2015-02-10 12:00:26	\N
000320	M.	Lemarié	LEMARIE BERNARD	Bernard	1913-07-30 00:00:00	1996-04-24 00:00:00	ANCIEN	Pharmacien	3116	44	UC	UC	\N	SOCI	SOCI	1026	Côtes-du-Nord	Secrétaire du Sénat	\N	LEMARIÉ	NON	\N	\N	2017-07-04 10:59:31	\N
59545V	M.	Lenglet	LENGLET CHARLES-EDMOND	Charles-Edmond	1917-12-20 00:00:00	2005-01-02 00:00:00	ANCIEN	Agriculteur	1000	10	RDE	R.D.E.	\N	ECON	ECON	800	Somme	\N	\N	LENGLET	NON	\N	\N	\N	\N
57830P	M.	Letoquart	LETOQUART LÉANDRE	Léandre	1919-06-04 00:00:00	2004-03-20 00:00:00	ANCIEN	Ouvrier	6000	34	C	C	\N	ECON	ECON	620	Pas-de-Calais	\N	\N	LETOQUART	NON	\N	\N	\N	\N
57130R	M.	Levacher	LEVACHER FRANÇOIS	François	1915-08-24 00:00:00	2000-05-15 00:00:00	ANCIEN	Agriculteur-Eleveur	1000	10	CRARS	CRARS	\N	SOCI	SOCI	280	Eure-et-Loir	\N	\N	LEVACHER	NON	\N	\N	2015-02-10 12:00:26	\N
89033R	M.	Leyzour	LEYZOUR FÉLIX	Félix	1932-07-22 00:00:00	\N	ANCIEN	Instituteur en retraite	7400	69	CRC	CRCE	\N	ECON	ECON	1026	Côtes-du-Nord	\N	\N	LEYZOUR	NON	\N	\N	2017-10-04 09:44:05	\N
000200	M.	Liot	LIOT ROBERT	Robert	1908-09-18 00:00:00	1982-05-27 00:00:00	ANCIEN	Inspecteur central des contributions	4500	72	UNR	U.N.R.	\N	SOCI	SOCI	590	Nord	\N	\N	LIOT	NON	\N	\N	\N	\N
59546W	M.	Lise	LISE ROGER	Roger	1927-07-26 00:00:00	2023-04-26 00:00:00	ANCIEN	Capitaine au long cours	3600	32	UC	UC	\N	SOCI	SOCI	972	Martinique	\N	\N	LISE	NON	\N	\N	2017-07-04 10:59:31	\N
000017	M.	Longchambon	LONGCHAMBON HENRI	Henri	1896-07-27 00:00:00	1969-03-20 00:00:00	ANCIEN	Professeur d'Université	3400	61	GD	G.D.	\N	ECON	ECON	997	Français établis hors de France	\N	\N	LONGCHAMBON	NON	\N	\N	2015-02-10 12:00:26	\N
000351	M.	Longequeue	LONGEQUEUE LOUIS	Louis	1914-11-30 00:00:00	1990-08-11 00:00:00	ANCIEN	Pharmacien	3116	44	SOC	SER	\N	ETRD	ETRD	870	Haute-Vienne	\N	\N	LONGEQUEUE	NON	\N	\N	2017-10-04 09:46:31	\N
59547X	M.	Louisy	LOUISY FRANÇOIS	François	1921-12-19 00:00:00	2007-09-17 00:00:00	ANCIEN	Attaché des services extérieurs du Ministère de l'Agriculture	7400	79	SOC	SER	\N	SOCI	SOCI	971	Guadeloupe	\N	\N	LOUISY	NON	\N	\N	2017-10-04 09:46:31	\N
59548Y	M.	Louvot	LOUVOT PIERRE	Pierre	1922-06-29 00:00:00	2002-01-27 00:00:00	ANCIEN	Vétérinaire	3115	46	RI	RI	\N	SOCI	SOCI	700	Haute-Saône	\N	\N	LOUVOT	NON	\N	\N	\N	\N
59549A	M.	Lucotte	LUCOTTE MARCEL	Marcel	1922-01-16 00:00:00	2000-12-28 00:00:00	ANCIEN	Journaliste	3511	54	RI	RI	\N	AFCL	AFCL	710	Saône-et-Loire	\N	\N	LUCOTTE	NON	\N	\N	\N	\N
000633	M.	Machefer	MACHEFER PHILIPPE	Philippe	1933-12-29 00:00:00	1982-08-15 00:00:00	ANCIEN	Agrégé d'histoire	4200	62	SOC	SER	\N	ETRD	ETRD	895	Yvelines	\N	\N	MACHEFER	NON	\N	\N	2017-10-04 09:46:31	\N
000518	M.	Maille	MAILLE PIERRE	Pierre	1923-12-13 00:00:00	1973-11-16 00:00:00	ANCIEN	Cultivateur	1000	10	UCDP	U.C.D.P.	\N	AFCL	AFCL	800	Somme	\N	\N	MAILLE	NON	\N	\N	\N	\N
58947G	M.	Malassagne	MALASSAGNE PAUL	Paul	1918-03-24 00:00:00	2007-09-05 00:00:00	ANCIEN	Dentiste	3113	45	RPR	RPR	-A	ECON	ECON	150	Cantal	Secrétaire du Sénat	\N	MALASSAGNE	NON	\N	\N	\N	\N
59715V	M.	Marcellin	MARCELLIN RAYMOND	Raymond	1914-08-19 00:00:00	2004-09-08 00:00:00	ANCIEN	Avocat	3121	51	UREI	U.R.E.I.	\N	FINC	FINC	560	Morbihan	\N	\N	MARCELLIN	NON	\N	\N	2017-06-15 09:47:11	\N
56406W	M.	Marcellin	MARCELLIN ROGER	Roger	1906-08-25 00:00:00	2001-03-03 00:00:00	ANCIEN	Agriculteur	1000	10	RI	RI	\N	ETRD	ETRD	1040	Tizi-Ouzou	\N	\N	MARCELLIN	NON	\N	\N	2015-02-10 12:00:26	\N
000236	M.	Marcilhacy	MARCILHACY PIERRE	Pierre	1910-02-14 00:00:00	1987-07-06 00:00:00	ANCIEN	Avocat 	3128	51	NI	NI	\N	LOIS	LOIS	160	Charente	\N	\N	MARCILHACY	NON	\N	\N	2015-02-10 12:00:26	\N
57749X	M.	Marie Anne	MARIE ANNE GEORGES	Georges	1906-10-09 00:00:00	2001-02-21 00:00:00	ANCIEN	Inspecteur principal des Douanes	4500	72	RPR	RPR	\N	SOCI	SOCI	972	Martinique	Vice-président du Sénat	\N	MARIE ANNE	NON	\N	\N	\N	\N
000227	M.	Marre	MARRE LOUIS	Louis	1909-11-06 00:00:00	1992-12-12 00:00:00	ANCIEN	Hôtelier	2200	57	RI	RI	\N	ECON	ECON	730	Savoie	\N	\N	MARRE	NON	\N	\N	\N	\N
58633Q	M.	Marson	MARSON JAMES	James	1926-11-01 00:00:00	2017-12-01 00:00:00	ANCIEN	Dessinateur industriel	5400	33	C	C	\N	AFCL	AFCL	775	Seine-Saint-Denis	Secrétaire du Sénat	\N	MARSON	NON	\N	\N	2017-12-05 14:29:02	\N
000561	M.	Martin	MARTIN ANDRÉ	André	1926-02-01 00:00:00	1993-11-07 00:00:00	ANCIEN	Retraité de l'Education nationale	7400	69	RDE	R.D.E.	\N	SOCI	SOCI	760	Seine-Maritime	\N	\N	MARTIN	NON	\N	\N	\N	\N
59235J	M.	Martin	MARTIN HUBERT	Hubert	1912-02-23 00:00:00	2008-06-08 00:00:00	ANCIEN	Médecin	3112	42	UREI	U.R.E.I.	\N	AFCL	AFCL	540	Meurthe-et-Moselle	\N	\N	MARTIN	NON	\N	\N	\N	\N
58342G	M.	Martin	MARTIN LOUIS	Louis	1913-08-16 00:00:00	1999-08-16 00:00:00	ANCIEN	Directeur d'organisation agricole	3600	32	UREI	U.R.E.I.	-R	ETRD	ETRD	420	Loire	Secrétaire du Sénat	\N	MARTIN	NON	\N	\N	2015-02-10 12:00:26	\N
57456M	M.	Martin	MARTIN MARCEL	Marcel	1916-11-19 00:00:00	2009-05-31 00:00:00	ANCIEN	Conseiller d'Etat	3311	71	NI	NI	\N	FINC	FINC	540	Meurthe-et-Moselle	\N	\N	MARTIN	NON	\N	\N	\N	\N
000136	M.	Marzin	MARZIN PIERRE	Pierre	1905-10-24 00:00:00	1994-08-02 00:00:00	ANCIEN	Directeur Général des Télécommunications	3311	71	GD	G.D.	\N	ECON	ECON	1026	Côtes-du-Nord	Secrétaire du Sénat	\N	MARZIN	NON	\N	\N	2014-05-30 11:39:48	\N
000332	M.	Massa	MASSA PAUL	Paul	1914-02-01 00:00:00	1986-10-06 00:00:00	ANCIEN	Avocat	3121	51	GD	G.D.	-R	LOIS	LOIS	60	Alpes-Maritimes	\N	\N	MASSA	NON	\N	\N	\N	\N
58939G	M.	Masson	MASSON CHRISTIAN	Christian	1909-12-15 00:00:00	2003-06-13 00:00:00	ANCIEN	Agriculteur	1000	10	RPR	RPR	\N	AFCL	AFCL	80	Ardennes	\N	\N	MASSON	NON	\N	\N	\N	\N
000080	M.	Masteau	MASTEAU JACQUES	Jacques	1903-07-18 00:00:00	1994-03-27 00:00:00	ANCIEN	Avocat	3121	51	GD	G.D.	\N	FINC	FINC	860	Vienne	\N	\N	MASTEAU	NON	\N	\N	2015-02-10 12:00:26	\N
000314	M.	Mathias	MATHIAS JEAN-BAPTISTE	Jean-Baptiste	1913-06-29 00:00:00	1974-05-22 00:00:00	ANCIEN	Médecin	3112	42	UDR	U.D.R.	-R	SOCI	SOCI	730	Savoie	\N	\N	MATHIAS	NON	\N	\N	\N	\N
88011F	M.	Mathieu	MATHIEU FRANCOIS	François	1934-06-01 00:00:00	1997-11-17 00:00:00	ANCIEN	Chargé de mission au Crédit Agricole de la Loire	3600	32	UC	UC	\N	AFCL	AFCL	420	Loire	\N	\N	MATHIEU	NON	\N	\N	2017-07-04 10:59:31	\N
000502	M.	Matraja	MATRAJA PIERRE	Pierre	1923-02-14 00:00:00	1991-11-23 00:00:00	ANCIEN	Directeur de maison de repos	3600	32	SOC	SER	\N	ETRD	ETRD	130	Bouches-du-Rhône	\N	\N	MATRAJA	NON	\N	\N	2017-10-04 09:46:31	\N
000179	M.	Maury	MAURY JACQUES	Jacques	1908-02-26 00:00:00	1980-11-10 00:00:00	ANCIEN	Chirurgien	3112	43	UCDP	U.C.D.P.	\N	SOCI	SOCI	720	Sarthe	\N	\N	MAURY	NON	\N	\N	\N	\N
000355	M.	Menard	MENARD JACQUES	Jacques	1914-12-31 00:00:00	1988-11-18 00:00:00	ANCIEN	Vétérinaire	3115	46	UREI	U.R.E.I.	\N	ETRD	ETRD	790	Deux-Sèvres	Questeur du Sénat	\N	MENARD	NON	\N	\N	2015-02-10 12:00:26	\N
000233	M.	Menu	MENU ROGER	Roger	1910-01-03 00:00:00	1970-08-19 00:00:00	ANCIEN	Employé de la SNCF	5400	33	UCDP	U.C.D.P.	\N	SOCI	SOCI	510	Marne	\N	\N	MENU	NON	\N	\N	\N	\N
59717X	M.	Merli	MERLI PIERRE	Pierre	1920-02-06 00:00:00	2002-11-03 00:00:00	ANCIEN	Haut fonctionnaire	3311	71	GD	G.D.	\N	ETRD	ETRD	60	Alpes-Maritimes	\N	\N	MERLI	NON	\N	\N	2017-06-15 09:47:21	\N
000001	M.	Merred	MERRED ALI	Ali	1900-01-01 00:00:00	1994-08-19 00:00:00	ANCIEN	Lieutenant-Colonel en retraite	7400	79	UNR	U.N.R.	\N	ETRD	ETRD	1046	Oasis	\N	\N	MERRED	NON	\N	\N	2015-02-10 12:00:26	\N
000185	M.	Henneguelle	HENNEGUELLE HENRI	Henri	1908-06-11 00:00:00	1983-12-27 00:00:00	ANCIEN	Instituteur retraité	7400	69	SOC	SER	\N	FINC	FINC	620	Pas-de-Calais	\N	\N	HENNEGUELLE	NON	\N	\N	2017-10-04 09:46:31	\N
000243	M.	Heon	HEON GUSTAVE	Gustave	1910-05-30 00:00:00	1981-09-29 00:00:00	ANCIEN	Professeur	4200	62	GD	G.D.	\N	FINC	FINC	270	Eure	Secrétaire du Sénat	\N	HEON	NON	\N	\N	\N	\N
56829S	Mme	Thorez Vermeersch	THOREZ VERMEERSCH JEANNETTE	Jeannette	1910-11-26 00:00:00	2001-11-05 00:00:00	ANCIEN	Tisserande	2100	24	C	C	\N	AFCL	AFCL	1029	Seine	\N	\N	THOREZ VERMEERSCH	NON	\N	\N	\N	\N
000312	M.	Tinant	TINANT RENÉ	René	1913-04-24 00:00:00	1984-03-06 00:00:00	ANCIEN	Agriculteur	1000	10	UCDP	U.C.D.P.	\N	AFCL	AFCL	80	Ardennes	\N	\N	TINANT	NON	\N	\N	\N	\N
83001G	M.	Tizon	TIZON JEAN-PIERRE	Jean-Pierre	1920-10-26 00:00:00	2012-11-08 00:00:00	ANCIEN	Médecin	3112	42	RI	RI	\N	LOIS	LOIS	500	Manche	\N	\N	TIZON	NON	\N	\N	\N	\N
000417	M.	Tomasini	TOMASINI RENÉ	René	1919-04-14 00:00:00	1983-05-05 00:00:00	ANCIEN	Retraité du corps préfectoral	7400	79	RPR	RPR	\N	FINC	FINC	270	Eure	\N	\N	TOMASINI	NON	\N	\N	2017-12-19 15:12:18	\N
000301	M.	Toribio	TORIBIO RENÉ	René	1912-12-10 00:00:00	1990-07-27 00:00:00	ANCIEN	Directeur d'école	4200	63	SOC	SER	\N	ECON	ECON	971	Guadeloupe	Secrétaire du Sénat	\N	TORIBIO	NON	\N	\N	2017-10-04 09:46:31	\N
58036Y	M.	Tournan	TOURNAN HENRI	Henri	1915-12-22 00:00:00	2010-02-25 00:00:00	ANCIEN	Contrôleur d'Etat	3311	71	SOC	SER	\N	FINC	FINC	320	Gers	\N	\N	TOURNAN	NON	\N	\N	2017-10-04 09:46:31	\N
000161	M.	Perpere	PERPERE RAOUL	Raoul	1907-03-03 00:00:00	1994-08-12 00:00:00	ANCIEN	Exploitant agricole	1000	10	GD	G.D.	\N	ECON	ECON	470	Lot-et-Garonne	\N	\N	PERPERE	NON	\N	\N	\N	\N
58638V	M.	Rosette	ROSETTE MARCEL	Marcel	1925-12-03 00:00:00	2005-11-18 00:00:00	ANCIEN	Employé	5400	33	C	C	\N	ETRD	ETRD	824	Val-de-Marne	\N	\N	ROSETTE	NON	\N	\N	\N	\N
59580Y	M.	Perrein	PERREIN LOUIS	Louis	1917-01-18 00:00:00	2004-06-21 00:00:00	ANCIEN	Directeur honoraire des Postes et Télécommunications	3311	71	SOC	SER	\N	FINC	FINC	828	Val-d'Oise	\N	\N	PERREIN	NON	\N	\N	2017-10-04 09:46:31	\N
58335H	M.	Perrin	PERRIN PIERRE	Pierre	1918-12-30 00:00:00	2009-08-08 00:00:00	ANCIEN	Négociant	2200	23	NI	NI	\N	ECON	ECON	380	Isère	\N	\N	PERRIN	NON	\N	\N	\N	\N
000643	M.	Perron	PERRON JEAN-JACQUES	Jean-Jacques	1935-12-24 00:00:00	1978-10-05 00:00:00	ANCIEN	Médecin	3112	42	SOC	SER	\N	SOCI	SOCI	830	Var	\N	\N	PERRON	NON	\N	\N	2017-10-04 09:46:31	\N
000138	M.	Petit	PETIT GUY	Guy	1905-11-23 00:00:00	1988-10-31 00:00:00	ANCIEN	Avocat	3121	51	UREI	U.R.E.I.	\N	LOIS	LOIS	640	Pyrénées-Atlantiques	\N	\N	PETIT	NON	\N	\N	\N	\N
000023	M.	Philippon	PHILIPPON GUSTAVE	Gustave	1900-09-19 00:00:00	1974-12-16 00:00:00	ANCIEN	Avocat	3121	51	SOC	SER	\N	AFCL	AFCL	870	Haute-Vienne	Secrétaire du Sénat	\N	PHILIPPON	NON	\N	\N	2017-10-04 09:46:31	\N
59245L	M.	Ramassamy	RAMASSAMY ALBERT	Albert	1923-11-13 00:00:00	2018-11-04 00:00:00	ANCIEN	Proviseur	4200	62	SOC	SER	\N	LOIS	LOIS	974	La Réunion	\N	\N	RAMASSAMY	NON	\N	\N	2017-10-04 09:46:31	\N
000104	M.	Raybaud	RAYBAUD JOSEPH	Joseph	1904-06-27 00:00:00	1991-03-22 00:00:00	ANCIEN	Agriculteur	1000	10	RDE	R.D.E.	\N	FINC	FINC	60	Alpes-Maritimes	\N	\N	RAYBAUD	NON	\N	\N	\N	\N
000293	M.	Repiquet	REPIQUET GEORGES	Georges	1912-04-15 00:00:00	1988-09-30 00:00:00	ANCIEN	Agriculteur	1000	10	RPR	RPR	\N	ETRD	ETRD	974	La Réunion	\N	\N	REPIQUET	NON	\N	\N	\N	\N
000077	M.	Reptin	REPTIN ERNEST	Ernest	1903-06-17 00:00:00	1976-12-15 00:00:00	ANCIEN	Agriculteur	1000	10	RI	RI	\N	SOCI	SOCI	800	Somme	\N	\N	REPTIN	NON	\N	\N	\N	\N
57310T	M.	Richard	RICHARD JACQUES	Jacques	1918-03-23 00:00:00	2010-12-05 00:00:00	ANCIEN	Officier	4500	72	UNR	U.N.R.	\N	FINC	FINC	1020	Seine-et-Oise	\N	\N	RICHARD	NON	\N	\N	2015-02-10 12:00:26	\N
58938F	M.	Rigou	RIGOU MICHEL	Michel	1927-06-29 00:00:00	2016-09-29 00:00:00	ANCIEN	Vétérinaire	3115	46	RDE	R.D.E.	\N	ECON	ECON	170	Charente-Maritime	\N	\N	RIGOU	NON	\N	\N	2016-10-04 15:02:52	\N
000142	M.	Ritzenthaler	RITZENTHALER EUGÈNE	Eugène	1906-03-10 00:00:00	1986-03-16 00:00:00	ANCIEN	Agriculteur	1000	10	UNR	U.N.R.	\N	ECON	ECON	680	Haut-Rhin	\N	\N	RITZENTHALER	NON	\N	\N	\N	\N
58919C	M.	Robert	ROBERT PAUL	Paul	1912-03-03 00:00:00	2013-09-13 00:00:00	ANCIEN	Directeur départemental honoraire des impôts	7000	79	RDE	R.D.E.	\N	ETRD	ETRD	150	Cantal	\N	\N	ROBERT	NON	\N	\N	2013-09-18 16:46:37	\N
000125	M.	Robini	ROBINI VICTOR	Victor	1905-05-30 00:00:00	1984-12-25 00:00:00	ANCIEN	Médecin	3112	42	GD	G.D.	\N	SOCI	SOCI	60	Alpes-Maritimes	\N	\N	ROBINI	NON	\N	\N	\N	\N
95064M	M.	Rocard	ROCARD MICHEL	Michel	1930-08-23 00:00:00	2016-07-02 00:00:00	ANCIEN	Inspecteur général des Finances en retraite	7400	79	SOC	SER	\N	ETRD	ETRD	895	Yvelines	\N	\N	ROCARD	NON	\N	\N	2017-10-04 09:46:31	\N
000281	M.	de Rocca-Serra	ROCCASERRA JEAN-PAUL (DE)	Jean-Paul	1911-10-11 00:00:00	1998-04-06 00:00:00	ANCIEN	Médecin	3112	42	GD	G.D.	\N	LOIS	LOIS	1002	Corse	\N	\N	de ROCCA-SERRA	NON	\N	\N	\N	\N
56305S	M.	Rochereau	ROCHEREAU HENRI	Henri	1908-03-25 00:00:00	1999-01-25 00:00:00	ANCIEN	Exportateur	2000	21	RI	RI	\N	ECON	ECON	850	Vendée	\N	\N	ROCHEREAU	NON	\N	\N	\N	\N
000030	M.	Piales	PIALES PAUL	Paul	1895-11-12 00:00:00	1987-03-06 00:00:00	ANCIEN	Industriel	2300	21	CRARS	CRARS	\N	SOCI	SOCI	150	Cantal	\N	\N	PIALES	NON	\N	\N	\N	\N
59554W	M.	Piat	PIAT ROBERT	Robert	1914-09-03 00:00:00	2007-10-08 00:00:00	ANCIEN	Retraité de l'Education nationale	7400	69	UC	UC	\N	AFCL	AFCL	770	Seine-et-Marne	\N	\N	PIAT	NON	\N	\N	2017-07-04 10:59:31	\N
58341F	M.	Pillet	PILLET PAUL	Paul	1907-04-01 00:00:00	2002-12-17 00:00:00	ANCIEN	Administrateur de sociétés	2300	21	UCDP	U.C.D.P.	\N	LOIS	LOIS	420	Loire	\N	\N	PILLET	NON	\N	\N	\N	\N
000514	M.	Pintat	PINTAT JEAN-FRANÇOIS	Jean-François	1923-07-29 00:00:00	1990-06-14 00:00:00	ANCIEN	Ingénieur	3800	31	UREI	U.R.E.I.	\N	FINC	FINC	330	Gironde	\N	\N	PINTAT	NON	\N	\N	\N	\N
11018G	M.	Bourquin	BOURQUINCHRISTIAN_11018G	Christian	1954-10-07 00:00:00	2014-08-26 00:00:00	ANCIEN	Ingénieur des collectivités territoriales	8000	31	RDSE	RDSE	\N	FINC	FINC	660	Pyrénées-Orientales	\N	c.bourquin@senat.fr	BOURQUIN	NON	\N	\N	2017-06-15 09:45:10	\N
000052	M.	Pinton	PINTON AUGUSTE	Auguste	1901-08-25 00:00:00	1984-08-22 00:00:00	ANCIEN	Professeur agrégé	4200	62	GD	G.D.	\N	ETRD	ETRD	690	Rhône	\N	\N	PINTON	NON	\N	\N	\N	\N
59619W	M.	Plantegenest	PLANTEGENEST MARC	Marc	1943-06-11 00:00:00	\N	ANCIEN	Fonctionnaire	4500	72	SOC	SER	-A	SOCI	SOCI	995	Saint-Pierre-et-Miquelon	\N	\N	PLANTEGENEST	NON	\N	\N	2017-10-04 09:46:31	\N
96002B	M.	Ploton	PLOTON RÉGIS	Régis	1936-08-29 00:00:00	1998-02-02 00:00:00	ANCIEN	Exploitant agricole	1000	10	RI	RI	\N	ETRD	ETRD	430	Haute-Loire	\N	\N	PLOTON	NON	\N	\N	\N	\N
58916Y	M.	Poirier	POIRIER RAYMOND	Raymond	1917-07-02 00:00:00	2007-05-21 00:00:00	ANCIEN	Commerçant	7300	39	UC	UC	\N	AFCL	AFCL	280	Eure-et-Loir	\N	\N	POIRIER	NON	\N	\N	2017-07-04 10:59:31	\N
59556Y	M.	Poniatowski	PONIATOWSKI MICHEL	Michel	1922-05-16 00:00:00	2002-01-15 00:00:00	ANCIEN	Administrateur civil	3000	71	RI	RI	\N	ETRD	ETRD	828	Val-d'Oise	\N	\N	PONIATOWSKI	NON	\N	\N	\N	\N
56522A	M.	de Pontbriand	PONTBRIAND MICHEL 	Michel	1911-03-30 00:00:00	2000-08-28 00:00:00	ANCIEN	Propriétaire exploitant	1000	10	UNR	U.N.R.	\N	ECON	ECON	440	Loire-Atlantique	\N	\N	de PONTBRIAND	NON	\N	\N	\N	\N
000476	M.	Pontillon	PONTILLON ROBERT	Robert	1921-12-04 00:00:00	1992-03-20 00:00:00	ANCIEN	Journaliste	3511	54	SOC	SER	\N	ETRD	ETRD	335	Hauts-de-Seine	\N	\N	PONTILLON	NON	\N	\N	2017-10-04 09:46:31	\N
000141	M.	Poroi	POROI ALFRED	Alfred	1906-03-03 00:00:00	1994-08-27 00:00:00	ANCIEN	Propriétaire d'agence commerciale	2200	21	UNR	U.N.R.	-A	SOCI	SOCI	983	Polynésie française	\N	\N	POROI	NON	\N	\N	\N	\N
000156	M.	Porteu De La Morandiere	PORTEU DE LA MORANDIERE PAUL	Paul	1906-10-13 00:00:00	1993-01-21 00:00:00	ANCIEN	Directeur de banque	2300	21	RI	RI	\N	NEANT	Aucune	350	Ille-et-Vilaine	\N	\N	PORTEU DE LA MORANDIERE	NON	\N	\N	\N	\N
58917A	M.	Portier	PORTIER HENRI	Henri	1921-06-05 00:00:00	2009-06-12 00:00:00	ANCIEN	Agriculteur	1000	10	RPR	RPR	\N	SOCI	SOCI	100	Aube	\N	\N	PORTIER	NON	\N	\N	\N	\N
59242H	M.	Poudonson	POUDONSON ROGER	Roger	1922-12-14 00:00:00	2000-12-27 00:00:00	ANCIEN	Publiciste	3735	55	UC	UC	\N	ETRD	ETRD	620	Pas-de-Calais	\N	\N	POUDONSON	NON	\N	\N	2017-07-04 10:59:31	\N
11010L	M.	Frogier	FROGIER PIERRE	Pierre	1950-11-16 00:00:00	\N	ANCIEN	Gérant de sociétés	8000	23	UMP	Les Républicains	N	LOIS	LOIS	982	Nouvelle-Calédonie	\N	p.frogier@senat.fr	FROGIER	NON	\N	\N	2023-10-01 00:37:00	http://www.hatvp.fr/pages_nominatives/frogier-pierre.html
88010E	M.	Pradille	PRADILLE CLAUDE	Claude	1942-07-29 00:00:00	\N	ANCIEN	Restaurateur	2100	24	SOC	SER	\N	LOIS	LOIS	300	Gard	\N	\N	PRADILLE	NON	\N	\N	2017-10-04 09:46:31	\N
000202	M.	Prevoteau	PREVOTEAU MAURICE	Maurice	1908-11-06 00:00:00	1994-03-02 00:00:00	ANCIEN	Agriculteur	1000	10	UCDP	U.C.D.P.	\N	ECON	ECON	510	Marne	\N	\N	PREVOTEAU	NON	\N	\N	\N	\N
000275	M.	Prigent	PRIGENT FRANÇOIS	François	1911-07-28 00:00:00	1986-09-14 00:00:00	ANCIEN	Commerçant	2200	22	UC	UC	\N	ECON	ECON	290	Finistère	\N	\N	PRIGENT	NON	\N	\N	2017-07-04 10:59:31	\N
000639	M.	Proriol	PRORIOL JEAN	Jean	1934-11-25 00:00:00	\N	ANCIEN	Cadre commercial	3600	32	UREI	U.R.E.I.	\N	ECON	ECON	430	Haute-Loire	\N	\N	PRORIOL	NON	\N	\N	2017-06-15 09:48:11	\N
59244K	M.	Prouvoyeur	PROUVOYEUR CLAUDE	Claude	1927-01-05 00:00:00	2018-01-17 00:00:00	ANCIEN	Conseiller d'Administration scolaire et universitaire	7400	69	RPR	RPR	-A	SOCI	SOCI	590	Nord	Secrétaire du Sénat	\N	PROUVOYEUR	NON	\N	\N	2018-02-01 13:23:36	\N
58918B	M.	Rabineau	RABINEAU ANDRÉ	André	1911-01-16 00:00:00	2009-02-15 00:00:00	ANCIEN	Chef d'entreprise	2300	21	UC	UC	\N	SOCI	SOCI	30	Allier	\N	\N	RABINEAU	NON	\N	\N	2017-07-04 10:59:31	\N
98037W	M.	Teston	TESTON	Michel	1944-07-20 00:00:00	\N	ANCIEN	Administrateur à TéléDiffusion de France	8000	32	SOC	SER	\N	CDD	CDD	70	Ardèche	\N	m.teston@senat.fr	TESTON	NON	\N	\N	2017-10-04 09:46:31	\N
000214	M.	Roux	ROUX OLIVIER	Olivier	1909-07-10 00:00:00	1995-10-14 00:00:00	ANCIEN	Directeur de Banque Honoraire	7300	39	UC	UC	\N	SOCI	SOCI	998	Français établis hors de France	\N	\N	ROUX	NON	\N	\N	2017-07-04 10:59:31	\N
000505	M.	Rudloff	RUDLOFF MARCEL	Marcel	1923-03-15 00:00:00	1996-03-23 00:00:00	ANCIEN	Avocat	3121	51	UC	UC	\N	LOIS	LOIS	670	Bas-Rhin	\N	\N	RUDLOFF	NON	\N	\N	2017-07-04 10:59:31	\N
58928D	M.	Ruet	RUET ROLAND	Roland	1921-10-29 00:00:00	2001-01-26 00:00:00	ANCIEN	Chef d'entreprise	2300	21	UREI	U.R.E.I.	\N	AFCL	AFCL	10	Ain	Secrétaire du Sénat	\N	RUET	NON	\N	\N	\N	\N
000453	M.	Sallenave	SALLENAVE PIERRE	Pierre	1920-11-20 00:00:00	1983-05-31 00:00:00	ANCIEN	Négociant	2200	23	UREI	U.R.E.I.	\N	SOCI	SOCI	640	Pyrénées-Atlantiques	\N	\N	SALLENAVE	NON	\N	\N	\N	\N
000564	M.	Salvi	SALVI PIERRE	Pierre	1926-04-02 00:00:00	1989-01-09 00:00:00	ANCIEN	Ingénieur	3800	31	UC	UC	\N	LOIS	LOIS	828	Val-d'Oise	Secrétaire du Sénat	\N	SALVI	NON	\N	\N	2017-07-04 10:59:31	\N
57752S	M.	Sanglier	SANGLIER JACQUES	Jacques	1919-02-22 00:00:00	2014-03-03 00:00:00	ANCIEN	Editeur-Imprimeur	2300	21	RPR	RPR	\N	ETRD	ETRD	615	Paris	\N	\N	SANGLIER	NON	\N	\N	2014-03-06 15:00:51	\N
58336J	M.	Sauvage	SAUVAGE JEAN	Jean	1909-10-03 00:00:00	2005-07-15 00:00:00	ANCIEN	Cadre	3600	32	UCDP	U.C.D.P.	\N	AFCL	AFCL	490	Maine-et-Loire	\N	\N	SAUVAGE	NON	\N	\N	\N	\N
57738U	Mme	Scellier	SCELLIER GABRIELLE	Gabrielle	1911-03-11 00:00:00	2004-02-08 00:00:00	ANCIEN	Pharmacienne en retraite	7000	49	UCDP	U.C.D.P.	\N	SOCI	SOCI	800	Somme	\N	\N	SCELLIER	NON	\N	\N	\N	\N
59559C	M.	Schiele	SCHIELE PIERRE	Pierre	1925-07-05 00:00:00	2011-07-27 00:00:00	ANCIEN	Professeur	4200	62	UC	UC	\N	AFCL	AFCL	680	Haut-Rhin	Questeur du Sénat	\N	SCHIELE	NON	\N	\N	2017-07-04 10:59:31	\N
000278	M.	Schleiter	SCHLEITER FRANÇOIS	François	1911-09-15 00:00:00	1990-09-26 00:00:00	ANCIEN	Avocat	3121	51	UREI	U.R.E.I.	\N	AFCL	AFCL	550	Meuse	Vice-président du Sénat	\N	SCHLEITER	NON	\N	\N	2015-02-10 12:00:26	\N
58662V	M.	Schmaus	SCHMAUS GUY	Guy	1932-07-07 00:00:00	\N	ANCIEN	Ouvrier	6000	34	C	C	\N	AFCL	AFCL	335	Hauts-de-Seine	Secrétaire du Sénat	\N	SCHMAUS	NON	\N	\N	\N	\N
58352J	M.	Schmitt	SCHMITT ROBERT	Robert	1917-12-11 00:00:00	2003-12-06 00:00:00	ANCIEN	Pharmacien	3116	44	UREI	U.R.E.I.	\N	FINC	FINC	570	Moselle	\N	\N	SCHMITT	NON	\N	\N	\N	\N
74044S	M.	Schumann	SCHUMANN MAURICE	Maurice	1911-04-10 00:00:00	1998-02-09 00:00:00	ANCIEN	Ecrivain	3100	57	RPR	RPR	\N	FINC	FINC	590	Nord	Vice-président du Sénat	\N	SCHUMANN	NON	\N	\N	2017-12-19 15:12:18	\N
59307H	M.	Schwint	SCHWINT ROBERT	Robert	1928-01-11 00:00:00	2011-01-24 00:00:00	ANCIEN	Principal de collège	4200	62	SOC	SER	\N	FINC	FINC	250	Doubs	\N	\N	SCHWINT	NON	\N	\N	2017-10-04 09:46:31	\N
59581A	Mme	Seligmann	SELIGMANN FRANCOISE	Françoise	1919-06-09 00:00:00	2013-02-27 00:00:00	ANCIEN	Directrice de journal	3511	54	SOC	SER	\N	LOIS	LOIS	335	Hauts-de-Seine	\N	\N	SELIGMANN	NON	\N	\N	2017-10-04 09:46:31	\N
58933A	M.	Sempe	SEMPE ABEL	Abel	1912-01-24 00:00:00	2006-02-22 00:00:00	ANCIEN	Viticulteur négociant	1000	10	RDE	R.D.E.	-A	AFCL	AFCL	320	Gers	\N	\N	SEMPE	NON	\N	\N	\N	\N
000440	M.	Seramy	SERAMY PAUL	Paul	1920-02-04 00:00:00	1992-02-23 00:00:00	ANCIEN	Professeur de lycée	3400	69	UC	UC	\N	AFCL	AFCL	770	Seine-et-Marne	\N	\N	SERAMY	NON	\N	\N	2017-07-04 10:59:31	\N
000168	M.	Servat	SERVAT ANDRÉ	André	1907-08-24 00:00:00	1990-02-03 00:00:00	ANCIEN	Pharmacien 	3116	44	NI	NI	\N	NEANT	Aucune	310	Haute-Garonne	\N	\N	SERVAT	NON	\N	\N	\N	\N
000101	M.	Sibor	SIBOR HENRI	Henri	1904-05-16 00:00:00	1985-11-20 00:00:00	ANCIEN	Retraité des Caisses d'épargne	7400	79	UCDP	U.C.D.P.	\N	AFCL	AFCL	640	Pyrénées-Atlantiques	\N	\N	SIBOR	NON	\N	\N	\N	\N
000369	M.	Sicard	SICARD PIERRE	Pierre	1915-10-21 00:00:00	1989-12-13 00:00:00	ANCIEN	Agriculteur	1000	10	UC	UC	\N	AFCL	AFCL	180	Cher	\N	\N	SICARD	NON	\N	\N	2017-07-04 10:59:32	\N
000373	M.	Simonin	SIMONIN JEAN	Jean	1916-05-26 00:00:00	1993-11-06 00:00:00	ANCIEN	Ingénieur en retraite	3800	31	RPR	RPR	\N	ETRD	ETRD	265	Essonne	\N	\N	SIMONIN	NON	\N	\N	\N	\N
000364	M.	Sirgue	SIRGUE ALBERT	Albert	1915-06-05 00:00:00	1980-11-18 00:00:00	ANCIEN	Agriculteur	1000	10	UREI	U.R.E.I.	\N	SOCI	SOCI	120	Aveyron	\N	\N	SIRGUE	NON	\N	\N	\N	\N
000279	M.	Soldani	SOLDANI EDOUARD	Edouard	1911-09-19 00:00:00	1996-04-18 00:00:00	ANCIEN	Enseignement secondaire	4200	62	SOC	SER	\N	AFCL	AFCL	830	Var	\N	\N	SOLDANI	NON	\N	\N	2017-10-04 09:46:31	\N
000452	M.	Sordel	SORDEL MICHEL	Michel	1920-11-11 00:00:00	1994-02-23 00:00:00	ANCIEN	Agriculteur	1000	10	UREI	U.R.E.I.	\N	ECON	ECON	210	Côte-d'Or	\N	\N	SORDEL	NON	\N	\N	\N	\N
000123	M.	Soudant	SOUDANT ROBERT	Robert	1905-05-21 00:00:00	1980-12-26 00:00:00	ANCIEN	Agriculteur	1000	10	RPCD	RPCD	\N	SOCI	SOCI	510	Marne	\N	\N	SOUDANT	NON	\N	\N	\N	\N
59247N	M.	Souffrin	SOUFFRIN PAUL	Paul	1932-05-16 00:00:00	\N	ANCIEN	Médecin	3112	42	C	C	\N	SOCI	SOCI	570	Moselle	\N	\N	SOUFFRIN	NON	\N	\N	\N	\N
000334	M.	Souquet	SOUQUET MARCEL	Marcel	1914-02-24 00:00:00	1995-06-29 00:00:00	ANCIEN	Employé SNCF	5400	33	SOC	SER	\N	SOCI	SOCI	110	Aude	\N	\N	SOUQUET	NON	\N	\N	2017-10-04 09:46:32	\N
000499	M.	Stoessel	STOESSEL CHARLES	Charles	1922-11-30 00:00:00	1966-10-14 00:00:00	ANCIEN	Professeur	4200	62	RPCD	RPCD	\N	ECON	ECON	680	Haut-Rhin	\N	\N	STOESSEL	NON	\N	\N	\N	\N
000120	M.	Suran	SURAN CHARLES	Charles	1904-05-02 00:00:00	1971-08-01 00:00:00	ANCIEN	Professeur de Cours complémentaire	4200	62	SOC	SER	\N	FINC	FINC	310	Haute-Garonne	\N	\N	SURAN	NON	\N	\N	2017-10-04 09:46:32	\N
000681	M.	Duclos	DUCLOS JACQUES	Jacques	1896-10-02 00:00:00	1975-04-25 00:00:00	ANCIEN	Ouvrier pâtissier	6000	34	C	C	\N	ETRD	ETRD	775	Seine-Saint-Denis	\N	\N	DUCLOS	NON	\N	\N	\N	\N
000687	M.	Dufeu	DUFEU JEAN-BAPTISTE	Jean-Baptiste	1898-08-15 00:00:00	1980-12-22 00:00:00	ANCIEN	Directeur de cinéma	2200	22	GD	G.D.	\N	ECON	ECON	380	Isère	Questeur du Sénat	\N	DUFEU	NON	\N	\N	\N	\N
000699	M.	Enjalbert	ENJALBERT RENÉ	René	1890-09-08 00:00:00	1976-12-26 00:00:00	ANCIEN	Agriculteur	1000	10	RI	RI	\N	ECON	ECON	1030	Oran-Tlemcen	\N	\N	ENJALBERT	NON	\N	\N	\N	\N
000719	M.	de Felice	FELICE PIERRE DE	Pierre	1896-12-13 00:00:00	1978-01-12 00:00:00	ANCIEN	Avocat	3121	51	GD	G.D.	\N	LOIS	LOIS	450	Loiret	\N	\N	de FELICE	NON	\N	\N	2017-12-19 15:12:17	\N
000678	M.	Fil	FIL JULES	Jules	1899-02-02 00:00:00	1968-09-23 00:00:00	ANCIEN	Directeur d'école en retraite	7000	69	SOC	SER	\N	SOCI	SOCI	110	Aude	\N	\N	FIL	NON	\N	\N	2017-10-04 09:46:32	\N
000676	M.	Viallanes	VIALLANES ETIENNE	Etienne	1891-01-02 00:00:00	1978-07-30 00:00:00	ANCIEN	Agriculteur	1000	10	RI	RI	\N	AFCL	AFCL	210	Côte-d'Or	\N	\N	VIALLANES	NON	\N	\N	\N	\N
000668	M.	de Villeneuve Bargemont	VILLENEUVEBARGEMONT AUGUSTIN (DE)	Augustin	1909-07-16 00:00:00	1989-07-25 00:00:00	ANCIEN	Agriculteur	1000	10	NI	NI	\N	NEANT	Aucune	800	Somme	\N	\N	de VILLENEUVE BARGEMONT	NON	\N	\N	\N	\N
000669	M.	de Villoutreys de Brignac	VILLOUTREYS DE BRIGNAC PIERRE	Pierre	1897-04-29 00:00:00	1972-03-31 00:00:00	ANCIEN	Industriel	2300	21	RI	RI	\N	ECON	ECON	490	Maine-et-Loire	\N	\N	de VILLOUTREYS de BRIGNAC	NON	\N	\N	\N	\N
000740	M.	Walker	WALKER MAURICE	Maurice	1897-05-20 00:00:00	1959-04-29 00:00:00	ANCIEN	Industriel	2300	21	MRP	MRP	\N	FINC	FINC	590	Nord	\N	\N	WALKER	NON	\N	\N	\N	\N
000729	M.	Zussy	ZUSSY MODESTE	Modeste	1897-02-16 00:00:00	1993-04-18 00:00:00	ANCIEN	Comptable	5400	33	UNR	U.N.R.	\N	LOIS	LOIS	680	Haut-Rhin	\N	\N	ZUSSY	NON	\N	\N	\N	\N
99002P	M.	Collomb	COLLOMB GERARD	Gérard	1947-06-20 00:00:00	2023-11-25 00:00:00	ANCIEN	Professeur agrégé de lettres classiques	3400	62	NI	NI	\N	NEANT	Aucune	690	Rhône	\N	g.collomb@senat.fr	COLLOMB	NON	\N	\N	2017-10-04 09:46:32	\N
000731	M.	Beaujannot	BEAUJANNOT JOSEPH	Joseph	1898-01-27 00:00:00	1981-10-06 00:00:00	ANCIEN	Négociant	2200	23	RI	RI	\N	ECON	ECON	410	Loir-et-Cher	\N	\N	BEAUJANNOT	NON	\N	\N	2015-02-10 12:00:26	\N
000759	M.	Benhabyles	BENHABYLES CHÉRIF	Chérif	1891-12-25 00:00:00	1959-08-28 00:00:00	ANCIEN	\N	8000	80	GD	G.D.	\N	ETRD	ETRD	1033	Constantine	\N	\N	BENHABYLES	NON	\N	\N	\N	\N
000701	M.	Bertaud	BERTAUD JEAN	Jean	1898-09-09 00:00:00	1987-03-08 00:00:00	ANCIEN	Inspecteur honoraire de la SNCF	4500	72	RPR	RPR	\N	ECON	ECON	824	Val-de-Marne	\N	\N	BERTAUD	NON	\N	\N	\N	\N
000682	M.	Besson	BESSON ROGER	Roger	1888-12-02 00:00:00	1970-11-23 00:00:00	ANCIEN	Agriculteur	1000	10	SOC	SER	\N	AFCL	AFCL	30	Allier	\N	\N	BESSON	NON	\N	\N	2017-10-04 09:46:32	\N
000761	M.	Boisrond	BOISROND JACQUES	Jacques	1891-02-27 00:00:00	1961-10-03 00:00:00	ANCIEN	Administrateur d'immeubles	3100	57	RI	RI	\N	AFCL	AFCL	410	Loir-et-Cher	\N	\N	BOISROND	NON	\N	\N	\N	\N
000696	M.	Bonnefous	BONNEFOUS RAYMOND	Raymond	1893-05-08 00:00:00	1979-07-05 00:00:00	ANCIEN	Chirurgien	3112	43	RI	RI	\N	LOIS	LOIS	120	Aveyron	\N	\N	BONNEFOUS	NON	\N	\N	\N	\N
000690	M.	Bourguet	BOURGUET FRÉDÉRIC	Frédéric	1889-02-07 00:00:00	1978-04-20 00:00:00	ANCIEN	Industriel	2300	21	SOC	SER	\N	ECON	ECON	810	Tarn	\N	\N	BOURGUET	NON	\N	\N	2017-10-04 09:46:32	\N
000756	M.	Brajeux	BRAJEUX JEAN	Jean	1895-08-25 00:00:00	1990-05-29 00:00:00	ANCIEN	Ingénieur agronome	3800	31	RI	RI	\N	ETRD	ETRD	270	Eure	\N	\N	BRAJEUX	NON	\N	\N	2015-02-10 12:00:26	\N
000760	M.	Brousse	BROUSSE MARTIAL	Martial	1893-09-26 00:00:00	1980-12-11 00:00:00	ANCIEN	Agriculteur	1000	10	CRARS	CRARS	\N	FINC	FINC	550	Meuse	\N	\N	BROUSSE	NON	\N	\N	2015-02-10 12:00:26	\N
000735	M.	Calmels	CALMELS GABRIEL	Gabriel	1887-09-18 00:00:00	1979-09-03 00:00:00	ANCIEN	Agriculteur	1000	10	GD	G.D.	\N	AFCL	AFCL	340	Hérault	\N	\N	CALMELS	NON	\N	\N	\N	\N
000755	M.	Capelle	CAPELLE OMER	Omer	1891-07-25 00:00:00	1966-05-26 00:00:00	ANCIEN	Agriculteur	1000	10	CRARS	CRARS	\N	SOCI	SOCI	800	Somme	\N	\N	CAPELLE	NON	\N	\N	\N	\N
000723	M.	Chevalier	CHEVALIER ROBERT	Robert	1896-10-14 00:00:00	1971-03-17 00:00:00	ANCIEN	Notaire	3128	52	UNR	U.N.R.	\N	LOIS	LOIS	720	Sarthe	\N	\N	CHEVALIER	NON	\N	\N	\N	\N
000715	M.	Chevallier	CHEVALLIER PAUL	Paul	1893-12-12 00:00:00	1971-12-28 00:00:00	ANCIEN	Limonadier	2000	23	GD	G.D.	\N	FINC	FINC	730	Savoie	\N	\N	CHEVALLIER	NON	\N	\N	\N	\N
000726	M.	Clerc	CLERC JEAN	Jean	1892-04-15 00:00:00	1966-03-09 00:00:00	ANCIEN	Négociant	2200	23	RP	RP	\N	ETRD	ETRD	740	Haute-Savoie	\N	\N	CLERC	NON	\N	\N	\N	\N
000763	M.	Cornu	CORNU ANDRÉ	André	1892-06-27 00:00:00	1980-02-05 00:00:00	ANCIEN	Industriel	2000	21	GD	G.D.	\N	AFCL	AFCL	1026	Côtes-du-Nord	\N	\N	CORNU	NON	\N	\N	2014-05-30 11:39:47	\N
01014K	M.	Reiner	REINER	Daniel	1941-01-17 00:00:00	\N	ANCIEN	Professeur de mathématiques	8000	62	SOC	SER	\N	ETRD	ETRD	540	Meurthe-et-Moselle	\N	d.reiner@senat.fr	REINER	NON	\N	\N	2017-10-04 09:46:32	\N
01016M	M.	Raoul	RAOUL	Daniel	1941-07-28 00:00:00	\N	ANCIEN	Universitaire	8000	61	SOC	SER	\N	FINC	FINC	490	Maine-et-Loire	\N	d.raoul@senat.fr	RAOUL	NON	\N	\N	2017-10-04 09:46:32	\N
01018P	M.	Lardeux	LARDEUX	André	1946-08-22 00:00:00	\N	ANCIEN	Professeur agrégé d'histoire	8000	62	UMP	Les Républicains	\N	SOCI	SOCI	490	Maine-et-Loire	\N	a.lardeux@senat.fr	LARDEUX	NON	\N	\N	2017-10-09 16:22:50	\N
01020H	M.	Mermaz	MERMAZ	Louis	1931-08-20 00:00:00	\N	ANCIEN	Professeur agrégé d'histoire	3400	62	SOC	SER	\N	ETRD	ETRD	380	Isère	\N	l.mermaz@senat.fr	MERMAZ	NON	\N	\N	2017-10-04 09:46:32	\N
01021J	M.	Kergueris	KERGUERIS	Joseph	1938-10-02 00:00:00	\N	ANCIEN	Maître de conférence en gestion	8000	61	UC	UC	\N	ETRD	ETRD	560	Morbihan	\N	j.kergueris@senat.fr	KERGUERIS	NON	\N	\N	2017-07-04 10:59:32	\N
01022K	Mme	Herviaux	HERVIAUX	Odette	1948-01-06 00:00:00	\N	ANCIEN	Professeur de lettres et d'histoire	8000	62	SOC	SER	\N	CDD	CDD	560	Morbihan	\N	o.herviaux@senat.fr	HERVIAUX	OUI	\N	\N	2017-10-04 09:46:32	\N
01023L	M.	Vantomme	VANTOMME	André	1948-02-16 00:00:00	\N	ANCIEN	Inspecteur des domaines	8000	71	SOC	SER	\N	ETRD	ETRD	600	Oise	\N	senateur.vantomme@wanadoo.fr	VANTOMME	NON	\N	\N	2017-10-04 09:46:32	\N
01024M	M.	Détraigne	DETRAIGNE	Yves	1954-12-21 00:00:00	\N	ANCIEN	Conseiller de Chambre Régionale des Comptes	3300	56	UC	UC	N	ETRD	ETRD	510	Marne	\N	y.detraigne@senat.fr	DÉTRAIGNE	NON	\N	\N	2023-10-01 00:37:00	\N
01025N	Mme	Férat	FERAT FRANCOISE	Françoise	1949-03-05 00:00:00	\N	ANCIEN	Sans profession déclarée	8000	80	UC	UC	N	CAE	CAE	510	Marne	Secrétaire du Sénat	f.ferat@senat.fr	FÉRAT	NON	\N	\N	2023-10-01 00:37:00	\N
58929E	M.	Roudier	ROUDIER ROGER	Roger	1926-05-13 00:00:00	2002-03-04 00:00:00	ANCIEN	Retraité de l'enseignement	7400	69	SOC	SER	\N	ECON	ECON	240	Dordogne	\N	\N	ROUDIER	NON	\N	\N	2017-10-04 09:46:32	\N
01027Q	M.	Doligé	DOLIGE	Éric	1943-05-25 00:00:00	\N	ANCIEN	Chef d'entreprise	8000	21	UMP	Les Républicains	\N	FINC	FINC	450	Loiret	\N	e.dolige@senat.fr	DOLIGÉ	NON	\N	\N	2017-10-09 16:22:50	\N
01029S	Mme	Rozier	ROZIER	Janine	1938-04-13 00:00:00	\N	ANCIEN	Clerc de notaire	3128	57	UMP	Les Républicains	\N	SOCI	SOCI	450	Loiret	\N	j.rozier@senat.fr	ROZIER	NON	\N	\N	2017-10-09 16:22:50	\N
01030K	M.	Juilhard	JUILHARD	Jean-Marc	1940-02-05 00:00:00	2023-07-27 00:00:00	ANCIEN	Arboriculteur	8000	10	UMP	Les Républicains	\N	SOCI	SOCI	630	Puy-de-Dôme	\N	jeanmarc.juilhard@wanadoo.fr	JUILHARD	NON	\N	\N	2017-10-09 16:22:50	\N
000671	M.	Minot	MINOT PAUL	Paul	1899-02-01 00:00:00	1980-03-03 00:00:00	ANCIEN	Industriel	2300	21	RPR	RPR	\N	AFCL	AFCL	615	Paris	\N	\N	MINOT	NON	\N	\N	\N	\N
000677	M.	Monnerville	MONNERVILLE GASTON	Gaston	1897-01-02 00:00:00	1991-11-07 00:00:00	ANCIEN	Avocat	3121	51	GD	G.D.	\N	FINC	FINC	460	Lot	Président du Sénat	\N	MONNERVILLE	NON	\N	\N	2015-02-10 12:00:26	\N
000705	M.	de Montalembert	MONTALEMBERT GEOFFROY DE	Geoffroy	1898-10-10 00:00:00	1993-03-02 00:00:00	ANCIEN	Agriculteur	1000	10	RPR	RPR	\N	FINC	FINC	760	Seine-Maritime	\N	\N	de MONTALEMBERT	NON	\N	\N	2015-02-10 12:00:26	\N
000691	M.	Moreve	MOREVE ROGER	Roger	1897-06-07 00:00:00	1983-09-27 00:00:00	ANCIEN	Commerçant et Agriculteur	2200	22	GD	G.D.	\N	ETRD	ETRD	360	Indre	\N	\N	MOREVE	NON	\N	\N	\N	\N
000736	M.	Moutet	MOUTET MARIUS	Marius	1876-04-19 00:00:00	1968-10-29 00:00:00	ANCIEN	Avocat	3121	51	SOC	SER	\N	ETRD	ETRD	260	Drôme	\N	\N	MOUTET	NON	\N	\N	2017-10-04 09:46:32	\N
000712	M.	Neddaf	NEDDAF LABIDI	Labidi	1893-04-12 00:00:00	1981-12-23 00:00:00	ANCIEN	Commandant en retraite	7400	79	GD	G.D.	-A	ETRD	ETRD	1021	Alger	\N	\N	NEDDAF	NON	\N	\N	\N	\N
000725	M.	Paumelle	PAUMELLE HENRI	Henri	1899-03-15 00:00:00	1965-12-17 00:00:00	ANCIEN	Agent général d'assurances	3100	57	GD	G.D.	\N	AFCL	AFCL	760	Seine-Maritime	\N	\N	PAUMELLE	NON	\N	\N	2015-02-10 12:00:26	\N
000734	M.	Pellenc	PELLENC MARCEL	Marcel	1897-03-18 00:00:00	1972-10-19 00:00:00	ANCIEN	Inspecteur Général	4500	72	GD	G.D.	\N	FINC	FINC	840	Vaucluse	\N	\N	PELLENC	NON	\N	\N	2015-02-10 12:00:26	\N
000714	M.	Pelleray	PELLERAY PAUL	Paul	1895-07-12 00:00:00	1980-05-13 00:00:00	ANCIEN	Eleveur	1000	10	RI	RI	\N	ECON	ECON	610	Orne	\N	\N	PELLERAY	NON	\N	\N	\N	\N
000747	M.	Picard	PICARD ANDRÉ	André	1899-06-22 00:00:00	1979-07-05 00:00:00	ANCIEN	Agriculteur	1000	10	RI	RI	\N	AFCL	AFCL	210	Côte-d'Or	\N	\N	PICARD	NON	\N	\N	\N	\N
000730	M.	Pinchard	PINCHARD RAYMOND	Raymond	1889-07-16 00:00:00	1961-08-22 00:00:00	ANCIEN	Industriel	2300	21	RI	RI	\N	ECON	ECON	540	Meurthe-et-Moselle	\N	\N	PINCHARD	NON	\N	\N	\N	\N
000698	M.	Plait	PLAIT ANDRÉ	André	1892-07-08 00:00:00	1979-04-08 00:00:00	ANCIEN	Médecin	3112	42	RI	RI	\N	SOCI	SOCI	890	Yonne	\N	\N	PLAIT	NON	\N	\N	2017-12-19 15:12:18	\N
11014C	Mme	Michel	MICHELDANIELLE_C4522	Danielle	1947-04-03 00:00:00	\N	ANCIEN	Coordonnateur emploi-formation	8000	81	SOC	SER	\N	AFCL	AFCL	400	Landes	\N	d.michel@senat.fr	MICHEL	NON	\N	\N	2017-10-04 09:46:32	\N
000672	M.	Portmann	PORTMANN GEORGES	Georges	1890-07-01 00:00:00	1985-02-24 00:00:00	ANCIEN	Doyen de la Faculté de Médecine et de Pharmacie	3400	61	RI	RI	\N	FINC	FINC	330	Gironde	\N	\N	PORTMANN	NON	\N	\N	2015-02-10 12:00:26	\N
000772	M.	Prelot	PRELOT MARCEL	Marcel	1898-10-30 00:00:00	1972-12-26 00:00:00	ANCIEN	Professeur de Faculté	3400	61	UNR	U.N.R.	\N	LOIS	LOIS	250	Doubs	\N	\N	PRELOT	NON	\N	\N	\N	\N
95065N	M.	Rouquet	ROUQUET RENÉ	René	1946-02-15 00:00:00	\N	ANCIEN	Electromécanicien	6000	34	SOC	SER	\N	AFCL	AFCL	824	Val-de-Marne	\N	\N	ROUQUET	NON	\N	\N	2017-10-04 09:46:32	\N
000741	M.	Pretre	PRETRE HENRI	Henri	1892-08-20 00:00:00	1983-05-17 00:00:00	ANCIEN	Agriculteur	1000	10	RI	RI	\N	ECON	ECON	700	Haute-Saône	\N	\N	PRETRE	NON	\N	\N	2015-02-10 12:00:26	\N
000752	M.	Prost	PROST PIERRE	Pierre	1896-06-24 00:00:00	1982-12-14 00:00:00	ANCIEN	Trésorier Payeur Général honoraire, Contrôleur d'Etat honoraire	3311	71	NI	NI	\N	FINC	FINC	265	Essonne	Secrétaire du Sénat	\N	PROST	NON	\N	\N	\N	\N
000750	M.	Restat	RESTAT ETIENNE	Etienne	1898-05-23 00:00:00	1971-11-30 00:00:00	ANCIEN	Agriculteur	1000	10	GD	G.D.	\N	ECON	ECON	470	Lot-et-Garonne	\N	\N	RESTAT	NON	\N	\N	\N	\N
89020L	M.	Bernardet	BERNARDET	Daniel	1927-06-07 00:00:00	2007-11-21 00:00:00	ANCIEN	Conseiller en gestion	3600	32	UMP	Les Républicains	\N	SOCI	SOCI	360	Indre	\N	d.bernardet@senat.fr	BERNARDET	NON	\N	\N	2017-10-09 16:22:50	\N
80028F	M.	Manet	MANET	Michel	1924-03-24 00:00:00	2010-02-01 00:00:00	ANCIEN	Haut fonctionnaire	3311	71	SOC	SER	\N	SOCI	SOCI	240	Dordogne	\N	\N	MANET	NON	\N	\N	2017-10-04 09:46:32	\N
89036U	M.	Philibert	PHILIBERT	Louis	1912-07-12 00:00:00	2000-06-21 00:00:00	ANCIEN	Conducteur principal de travaux des Ponts et chaussées (retraité)	7300	39	SOC	SER	\N	AFCL	AFCL	130	Bouches-du-Rhône	\N	\N	PHILIBERT	NON	\N	\N	2017-10-04 09:46:32	\N
01006K	M.	Alduy	ALDUY	Jean-Paul	1942-05-07 00:00:00	\N	ANCIEN	Ingénieur général des ponts et chaussées	8000	71	UMP	Les Républicains	\N	FINC	FINC	660	Pyrénées-Orientales	\N	jp.alduy@senat.fr	ALDUY	NON	\N	\N	2017-10-09 16:22:50	\N
11039M	M.	Bailly	BAILLYDOMINIQUE_11039M	Dominique	1960-01-02 00:00:00	\N	ANCIEN	Fonctionnaire du ministère des Finances	8000	72	SOC	SER	\N	AFCL	AFCL	590	Nord	Questeur du Sénat	d.bailly@senat.fr	BAILLY	NON	\N	\N	2017-10-04 09:46:32	\N
01008M	M.	Bailly	BAILLYGERARD	Gérard	1940-01-28 00:00:00	\N	ANCIEN	Agriculteur	8000	10	UMP	Les Républicains	\N	CAE	CAE	390	Jura	\N	g.bailly@senat.fr	BAILLY	NON	\N	\N	2017-10-09 16:22:50	\N
01009N	Mme	Payet	PAYET ANNEMARIE	Anne-Marie	1949-08-01 00:00:00	\N	ANCIEN	Directrice d'école	8000	63	UC	UC	\N	SOCI	SOCI	974	La Réunion	Secrétaire du Sénat	am.payet@senat.fr	PAYET	NON	\N	\N	2017-07-04 10:59:32	\N
01010F	M.	Virapoullé	VIRAPOULLE JEANPAUL	Jean-Paul	1944-03-15 00:00:00	\N	ANCIEN	Conseiller en gestion	8000	57	UMP	Les Républicains	\N	LOIS	LOIS	974	La Réunion	Secrétaire du Sénat	jp.virapoulle@senat.fr	VIRAPOULLÉ	NON	\N	\N	2017-10-09 16:22:50	\N
01011G	M.	Godefroy	GODEFROY	Jean-Pierre	1944-09-23 00:00:00	\N	ANCIEN	Ouvrier chaudronnier	6200	34	SOC	SER	\N	SOCI	SOCI	500	Manche	\N	jp.godefroy@senat.fr	GODEFROY	NON	\N	\N	2017-10-04 09:46:32	\N
11040E	M.	Bocquet	BOCQUET_ERIC_11040E	Éric	1957-11-08 00:00:00	\N	ACTIF	Professeur	8000	62	CRC	CRCE-K	\N	FINC	FINC	590	Nord	\N	e.bocquet@senat.fr	BOCQUET	NON	14	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/bocquet-eric.html
59557A	Mme	Rodi	RODI NELLY	Nelly	1918-02-16 00:00:00	2004-04-15 00:00:00	ANCIEN	Sage-femme	7400	49	RPR	RPR	\N	SOCI	SOCI	895	Yvelines	\N	\N	RODI	NON	\N	\N	\N	\N
000537	M.	Roge	ROGE LÉON	Léon	1924-07-09 00:00:00	1969-09-12 00:00:00	ANCIEN	Professeur d'Education Physique	4200	62	C	C	\N	AFCL	AFCL	760	Seine-Maritime	\N	\N	ROGE	NON	\N	\N	\N	\N
59558B	M.	Roger	ROGER JEAN	Jean	1923-09-30 00:00:00	2011-06-18 00:00:00	ANCIEN	Vétérinaire	3115	46	RDE	R.D.E.	\N	ECON	ECON	820	Tarn-et-Garonne	\N	\N	ROGER	NON	\N	\N	\N	\N
000174	M.	Rollin	ROLLIN RENÉ	René	1907-12-07 00:00:00	1984-09-13 00:00:00	ANCIEN	Professeur en retraite	7000	69	GD	G.D.	\N	AFCL	AFCL	520	Haute-Marne	\N	\N	ROLLIN	NON	\N	\N	\N	\N
000128	M.	Romaine	ROMAINE EUGÈNE	Eugène	1905-07-13 00:00:00	1983-07-29 00:00:00	ANCIEN	Minotier	6000	34	GD	G.D.	\N	ETRD	ETRD	230	Creuse	Secrétaire du Sénat	\N	ROMAINE	NON	\N	\N	\N	\N
59312E	M.	Romani	ROMANI ROGER	Roger	1934-08-25 00:00:00	\N	ANCIEN	Cadre administratif	3600	32	UMP	Les Républicains	\N	ETRD	ETRD	615	Paris	Vice-président du Sénat	r.romani@senat.fr	ROMANI	NON	\N	\N	2017-10-09 16:22:50	\N
000050	M.	Messager	MESSAGER ANDRE	André	1901-08-04 00:00:00	1982-02-17 00:00:00	ANCIEN	Industriel	2300	21	UCDP	U.C.D.P.	\N	AFCL	AFCL	828	Val-d'Oise	\N	\N	MESSAGER	NON	\N	\N	\N	\N
000129	M.	Metayer	METAYER PIERRE	Pierre	1905-08-26 00:00:00	1979-06-05 00:00:00	ANCIEN	Professeur	4200	62	SOC	SER	\N	FINC	FINC	1020	Seine-et-Oise	\N	\N	METAYER	NON	\N	\N	2017-10-04 09:46:32	\N
000025	M.	Michelet	MICHELET EDMOND	Edmond	1899-10-08 00:00:00	1970-10-09 00:00:00	ANCIEN	Courtier assermenté	3100	57	UNR	U.N.R.	\N	ETRD	ETRD	1029	Seine	Vice-président du Sénat	\N	MICHELET	NON	\N	\N	2017-06-15 09:46:23	\N
58635S	Mme	Midy	MIDY MONIQUE	Monique	1930-06-27 00:00:00	2016-12-15 00:00:00	ANCIEN	Secrétaire	5400	33	C	C	\N	ECON	ECON	335	Hauts-de-Seine	\N	\N	MIDY	NON	\N	\N	2016-12-19 09:42:04	\N
000356	M.	Mignot	MIGNOT ANDRÉ	André	1915-01-19 00:00:00	1977-12-09 00:00:00	ANCIEN	Avocat	3121	51	RI	RI	\N	LOIS	LOIS	895	Yvelines	\N	\N	MIGNOT	NON	\N	\N	\N	\N
58003P	M.	Millot	MILLOT GUY	Guy	1925-01-31 00:00:00	2005-04-24 00:00:00	ANCIEN	Industriel	2300	21	NI	NI	\N	ECON	ECON	770	Seine-et-Marne	\N	\N	MILLOT	NON	\N	\N	\N	\N
59551T	M.	Miroudot	MIROUDOT MICHEL	Michel	1915-01-30 00:00:00	1999-06-25 00:00:00	ANCIEN	Médecin	3112	42	RI	RI	\N	AFCL	AFCL	700	Haute-Saône	\N	\N	MIROUDOT	NON	\N	\N	\N	\N
000103	M.	Mistral	MISTRAL PAUL	Paul	1904-06-23 00:00:00	1981-08-29 00:00:00	ANCIEN	Directeur de sociétés	2300	21	SOC	SER	\N	ECON	ECON	380	Isère	\N	\N	MISTRAL	NON	\N	\N	2017-10-04 09:46:32	\N
11023D	Mme	Claireaux	CLAIREAUX_KARINE_11023D	Karine	1963-11-15 00:00:00	\N	ANCIEN	Fonctionnaire des douanes	8000	72	LREM	RDPI	\N	SOCI	SOCI	995	Saint-Pierre-et-Miquelon	\N	k.claireaux@senat.fr	CLAIREAUX	NON	\N	\N	2017-10-04 09:45:00	\N
000379	M.	Mitterrand	MITTERRAND  FRANÇOIS	François	1916-10-26 00:00:00	1996-01-08 00:00:00	ANCIEN	Avocat	3121	51	GD	G.D.	\N	ETRD	ETRD	580	Nièvre	\N	\N	MITTERRAND	NON	\N	\N	2015-02-10 12:00:26	\N
58914W	M.	Moinet	MOINET JOSY	Josy	1929-10-23 00:00:00	2018-08-04 00:00:00	ANCIEN	Cadre	3600	32	RDE	R.D.E.	\N	FINC	FINC	170	Charente-Maritime	Secrétaire du Sénat	\N	MOINET	NON	\N	\N	\N	\N
000034	M.	Mokrane	MOKRANE MOHAMED	Mohamed	1898-11-24 00:00:00	1975-06-26 00:00:00	ANCIEN	\N	8000	80	UNR	U.N.R.	\N	AFCL	AFCL	1045	Setif-Batna	\N	\N	MOKRANE	NON	\N	\N	2016-12-30 15:21:07	\N
000033	M.	Monichon	MONICHON MAX	Max	1900-11-25 00:00:00	1977-10-05 00:00:00	ANCIEN	Administrateur de biens	3100	57	CRARS	CRARS	\N	FINC	FINC	330	Gironde	\N	\N	MONICHON	NON	\N	\N	\N	\N
000022	M.	Monsarrat	MONSARRAT FRANÇOIS	François	1900-09-12 00:00:00	1972-10-26 00:00:00	ANCIEN	Agriculteur	1000	10	GD	G.D.	\N	ECON	ECON	810	Tarn	Questeur du Sénat	\N	MONSARRAT	NON	\N	\N	\N	\N
59236K	M.	Mont	MONT CLAUDE	Claude	1913-06-30 00:00:00	2001-10-30 00:00:00	ANCIEN	Professeur 	4200	62	UC	UC	\N	ETRD	ETRD	420	Loire	\N	\N	MONT	NON	\N	\N	2017-07-04 10:59:32	\N
000132	M.	Montaldo	MONTALDO RENE	Rene	1905-09-07 00:00:00	1969-08-20 00:00:00	ANCIEN	Médecin	3112	42	GD	G.D.	-A	FINC	FINC	1043	Orléansville-Médéa	\N	\N	MONTALDO	NON	\N	\N	\N	\N
000209	M.	de Montigny	MONTIGNY LUCIEN DE	Lucien	1909-04-06 00:00:00	1975-07-05 00:00:00	ANCIEN	Avocat	3121	51	UCDP	U.C.D.P.	\N	LOIS	LOIS	530	Mayenne	\N	\N	de MONTIGNY	NON	\N	\N	\N	\N
000290	M.	Moquet	MOQUET JACQUES	Jacques	1912-03-19 00:00:00	1985-10-09 00:00:00	ANCIEN	Agriculteur	1000	10	UDR	U.D.R.	\N	AFCL	AFCL	20	Aisne	\N	\N	MOQUET	NON	\N	\N	\N	\N
000597	M.	Moreau	MOREAU PAUL	Paul	1929-07-02 00:00:00	1995-07-01 00:00:00	ANCIEN	Directeur de coopérative agricole	1000	10	RPR	RPR	\N	ECON	ECON	974	La Réunion	\N	\N	MOREAU	NON	\N	\N	\N	\N
000100	M.	Moreau	MOREAU ROGER	Roger	1904-05-15 00:00:00	1986-05-23 00:00:00	ANCIEN	Sans profession déclarée	8000	80	RPR	RPR	\N	AFCL	AFCL	370	Indre-et-Loire	\N	\N	MOREAU	NON	\N	\N	\N	\N
000284	M.	Morel	MOREL LÉOPOLD	Léopold	1912-01-09 00:00:00	1996-05-14 00:00:00	ANCIEN	Directeur de journal	2300	21	GD	G.D.	-R	LOIS	LOIS	1033	Constantine	\N	\N	MOREL	NON	\N	\N	2015-02-10 12:00:26	\N
000027	M.	Morice	MORICE ANDRÉ	André	1900-10-11 00:00:00	1990-01-17 00:00:00	ANCIEN	Chef d'entreprise	2300	21	GD	G.D.	\N	ETRD	ETRD	440	Loire-Atlantique	\N	\N	MORICE	NON	\N	\N	\N	\N
000586	M.	Mossion	MOSSION JACQUES	Jacques	1927-12-25 00:00:00	1996-02-03 00:00:00	ANCIEN	Géomètre expert (retraité)	7400	59	UC	UC	\N	FINC	FINC	800	Somme	Secrétaire du Sénat	\N	MOSSION	NON	\N	\N	2017-07-04 10:59:32	\N
59237L	M.	Moulin	MOULIN ARTHUR	Arthur	1924-07-04 00:00:00	2017-05-09 00:00:00	ANCIEN	Vétérinaire	3115	46	RPR	RPR	\N	SOCI	SOCI	590	Nord	\N	\N	MOULIN	NON	\N	\N	2017-05-12 08:51:31	\N
000528	M.	Moutet	MOUTET JACQUES	Jacques	1924-03-31 00:00:00	1998-04-23 00:00:00	ANCIEN	Chef d'entreprise	2300	21	UC	UC	-R	ECON	ECON	640	Pyrénées-Atlantiques	\N	\N	MOUTET	NON	\N	\N	2017-07-04 10:59:32	\N
000024	M.	Mustapha	MUSTAPHA MENAD	Menad	1898-01-01 00:00:00	1983-07-31 00:00:00	ANCIEN	Inspecteur de police	7400	79	GD	G.D.	-A	SOCI	SOCI	1043	Orléansville-Médéa	\N	\N	MUSTAPHA	NON	\N	\N	2015-02-10 12:00:26	\N
000187	M.	Namy	NAMY LOUIS	Louis	1908-06-14 00:00:00	1987-12-02 00:00:00	ANCIEN	Administrateur du journal La Marseillaise	3500	32	C	C	\N	LOIS	LOIS	265	Essonne	\N	\N	NAMY	NON	\N	\N	\N	\N
000126	M.	Natali	NATALI JEAN	Jean	1905-06-21 00:00:00	1997-12-01 00:00:00	ANCIEN	Médecin	3112	42	RPR	RPR	\N	ETRD	ETRD	600	Oise	\N	\N	NATALI	NON	\N	\N	\N	\N
000079	M.	Naveau	NAVEAU CHARLES	Charles	1903-07-14 00:00:00	1981-08-24 00:00:00	ANCIEN	Agriculteur	1000	10	SOC	SER	\N	ECON	ECON	590	Nord	\N	\N	NAVEAU	NON	\N	\N	2017-10-04 09:46:32	\N
000352	M.	Nayrou	NAYROU JEAN	Jean	1914-12-03 00:00:00	1983-02-06 00:00:00	ANCIEN	Instituteur	4200	63	SOC	SER	\N	LOIS	LOIS	90	Ariège	\N	\N	NAYROU	NON	\N	\N	2017-10-04 09:46:32	\N
000166	M.	Negre	NEGRE JEAN	Jean	1907-06-20 00:00:00	1972-05-08 00:00:00	ANCIEN	Professeur de lycée	4200	62	NI	NI	\N	SOCI	SOCI	30	Allier	\N	\N	NEGRE	NON	\N	\N	\N	\N
000428	M.	de Nicolay	NICOLAY FRANCOIS DE	François	1919-08-31 00:00:00	1963-11-21 00:00:00	ANCIEN	Exploitant agricole et forestier	1000	10	RI	RI	\N	ETRD	ETRD	720	Sarthe	\N	\N	de NICOLAY	NON	\N	\N	2015-02-10 12:00:26	\N
58645U	M.	Ooghe	OOGHE JEAN	Jean	1928-04-17 00:00:00	\N	ANCIEN	Cheminot	6000	34	C	C	\N	LOIS	LOIS	265	Essonne	\N	\N	OOGHE	NON	\N	\N	\N	\N
11036J	Mme	Bataille	BATAILLE_DELPHINE_11036J	Delphine	1969-09-16 00:00:00	\N	ANCIEN	Assistante parlementaire	8000	32	LREM	RDPI	\N	CAE	CAE	590	Nord	\N	d.bataille@senat.fr	BATAILLE	OUI	\N	\N	2017-10-04 09:45:00	\N
000019	M.	Oopa Tetuaapua	OOPA TETUAAPUA POUVANAA	Pouvanaa	1895-05-10 00:00:00	1977-01-10 00:00:00	ANCIEN	Entrepreneur dans le bâtiment	2100	24	UCDP	U.C.D.P.	\N	AFCL	AFCL	983	Polynésie française	\N	\N	OOPA TETUAAPUA	NON	\N	\N	\N	\N
000419	M.	Ornano	ORNANO CHARLES	Charles	1919-05-05 00:00:00	1994-02-19 00:00:00	ANCIEN	Directeur régional adjoint des services de l'équipement	7000	79	NI	NI	\N	LOIS	LOIS	200	Corse-du-Sud	\N	\N	ORNANO	NON	\N	\N	\N	\N
000354	M.	Vigier	VIGIER JEAN-LOUIS	Jean-Louis	1914-12-25 00:00:00	1992-10-08 00:00:00	ANCIEN	Publiciste	3735	55	RPR	RPR	\N	ETRD	ETRD	615	Paris	\N	\N	VIGIER	NON	\N	\N	2017-01-05 11:08:30	\N
000259	M.	Vignon	VIGNON ROBERT	Robert	1910-11-17 00:00:00	1989-10-09 00:00:00	ANCIEN	Préfet	3311	71	UNR	U.N.R.	-A	SOCI	SOCI	973	Guyane	\N	\N	VIGNON	NON	\N	\N	\N	\N
000283	M.	Villatte	VILLATTE RAYMOND	Raymond	1912-01-02 00:00:00	1975-07-21 00:00:00	ANCIEN	Maraîcher	1000	10	RIAS	R.I.A.S.	\N	ECON	ECON	370	Indre-et-Loire	\N	\N	VILLATTE	NON	\N	\N	\N	\N
59251J	M.	Virapoulle	VIRAPOULLE LOUIS	Louis	1934-08-09 00:00:00	2002-09-14 00:00:00	ANCIEN	Avocat	3121	51	UC	UC	\N	LOIS	LOIS	974	La Réunion	\N	\N	VIRAPOULLE	NON	\N	\N	2017-07-04 10:59:32	\N
59252K	M.	Viron	VIRON HECTOR	Hector	1922-01-19 00:00:00	2007-12-25 00:00:00	ANCIEN	Ouvrier	6000	34	C	C	\N	SOCI	SOCI	590	Nord	Secrétaire du Sénat	\N	VIRON	NON	\N	\N	\N	\N
59562W	M.	Vizet	VIZET ROBERT	Robert	1924-01-30 00:00:00	2018-08-13 00:00:00	ANCIEN	Conducteur typographe	6000	34	C	C	\N	FINC	FINC	265	Essonne	Secrétaire du Sénat	\N	VIZET	NON	\N	\N	\N	\N
59563X	M.	Voilquin	VOILQUIN ALBERT	Albert	1915-02-17 00:00:00	1999-08-02 00:00:00	ANCIEN	Inspecteur Central du Trésor	7400	79	RI	RI	\N	ETRD	ETRD	880	Vosges	\N	\N	VOILQUIN	NON	\N	\N	\N	\N
59253L	M.	Voisin	VOISIN ANDRÉ	André	1918-03-28 00:00:00	2008-06-28 00:00:00	ANCIEN	Exploitant forestier	1000	10	RPR	RPR	-A	FINC	FINC	370	Indre-et-Loire	\N	\N	VOISIN	NON	\N	\N	\N	\N
000148	M.	Wach	WACH PAUL	Paul	1906-08-10 00:00:00	1974-05-01 00:00:00	ANCIEN	Dentiste	3113	45	RPCD	RPCD	\N	ETRD	ETRD	670	Bas-Rhin	\N	\N	WACH	NON	\N	\N	\N	\N
59308J	M.	Wacheux	WACHEUX MARCEL	Marcel	1930-05-28 00:00:00	2008-09-19 00:00:00	ANCIEN	Professeur de collège	4500	62	SOC	SER	\N	NEANT	Aucune	620	Pas-de-Calais	\N	\N	WACHEUX	NON	\N	\N	2017-10-04 09:46:32	\N
000239	M.	de Wazieres	WAZIERES RAYMOND DE	Raymond	1910-03-25 00:00:00	1984-05-29 00:00:00	ANCIEN	Agriculteur	1000	10	GD	G.D.	\N	SOCI	SOCI	800	Somme	\N	\N	de WAZIERES	NON	\N	\N	\N	\N
000029	M.	Yanat	YANAT MOULOUD	Mouloud	1888-07-01 00:00:00	1988-05-10 00:00:00	ANCIEN	Industriel et Agriculteur	1000	10	UNR	U.N.R.	\N	SOCI	SOCI	1045	Setif-Batna	\N	\N	YANAT	NON	\N	\N	\N	\N
000169	M.	Yver	YVER MICHEL	Michel	1907-09-17 00:00:00	1979-01-10 00:00:00	ANCIEN	Agriculteur	1000	10	UREI	U.R.E.I.	\N	ETRD	ETRD	500	Manche	\N	\N	YVER	NON	\N	\N	\N	\N
58355M	M.	Yvon	YVON JOSEPH	Joseph	1906-08-28 00:00:00	1998-07-07 00:00:00	ANCIEN	Avocat	3121	51	UCDP	U.C.D.P.	\N	ECON	ECON	560	Morbihan	\N	\N	YVON	NON	\N	\N	\N	\N
58655W	M.	Zwickert	ZWICKERT CHARLES	Charles	1920-03-26 00:00:00	2005-09-27 00:00:00	ANCIEN	Agriculteur	1000	10	UC	UC	\N	ECON	ECON	680	Haut-Rhin	\N	\N	ZWICKERT	NON	\N	\N	2017-07-04 10:59:32	\N
98006P	M.	Bel	BEL	Jean-Pierre	1951-12-30 00:00:00	\N	ANCIEN	Juriste	8000	55	SOC	SER	\N	NEANT	Aucune	90	Ariège	Président du Sénat	bel1.jean-pierre@wanadoo.fr	BEL	NON	\N	\N	2017-10-04 09:46:32	\N
98009S	M.	Godard	GODARD	Serge	1936-03-25 00:00:00	\N	ANCIEN	Professeur d'université	8000	69	SOC	SER	\N	ECON	ECON	630	Puy-de-Dôme	\N	s.godard@senat.fr	GODARD	NON	\N	\N	2017-10-04 09:46:32	\N
98011L	M.	Auban	AUBAN	Bertrand	1947-01-18 00:00:00	\N	ANCIEN	Enseignant	8000	64	SOC	SER	\N	ETRD	ETRD	310	Haute-Garonne	\N	b.auban@senat.fr	AUBAN	NON	\N	\N	2017-10-04 09:46:32	\N
98012M	M.	Trémel	TREMEL	Pierre-Yvon	1946-08-09 00:00:00	2006-06-29 00:00:00	ANCIEN	Enseignant	8000	62	SOC	SER	\N	ECON	ECON	220	Côtes-d'Armor	\N	py.tremel@senat.fr	TRÉMEL	NON	\N	\N	2017-10-04 09:46:32	\N
98014P	M.	Branger	BRANGER	Jean-Guy	1935-04-15 00:00:00	\N	ANCIEN	Professeur de lycée	8000	62	UMP	Les Républicains	\N	ETRD	ETRD	170	Charente-Maritime	\N	jg.branger@senat.fr	BRANGER	NON	\N	\N	2017-10-09 16:22:50	\N
98017S	M.	Giraud	GIRAUD FRANCIS	Francis	1932-07-04 00:00:00	2010-10-23 00:00:00	ANCIEN	Professeur honoraire à la faculté de médecine	3400	73	UMP	Les Républicains	\N	SOCI	SOCI	130	Bouches-du-Rhône	\N	f.giraud@senat.fr	GIRAUD	NON	\N	\N	2017-10-09 16:22:50	\N
11015D	M.	Gorce	GORCE_GAETAN_C4649	Gaëtan	1958-12-02 00:00:00	\N	ANCIEN	Administrateur civil	8000	71	SOC	SER	\N	ETRD	ETRD	580	Nièvre	\N	g.gorce@senat.fr	GORCE	NON	\N	\N	2017-10-04 09:46:32	\N
98018T	M.	del Picchia	DEL PICCHIA	Robert	1942-11-10 00:00:00	\N	ANCIEN	Rédacteur en chef de radio	8000	81	UMP	Les Républicains	-R	ETRD	ETRD	1054	Français établis hors de France	\N	r.delpicchia@senat.fr	del PICCHIA	NON	\N	\N	2017-10-09 16:22:50	\N
98019U	M.	Ferrand	FERRAND ANDRE	André	1936-02-22 00:00:00	\N	ANCIEN	Dirigeant d'entreprise	8000	21	UMP	Les Républicains	\N	FINC	FINC	997	Français établis hors de France	\N	a.ferrand@senat.fr	FERRAND	NON	\N	\N	2017-10-09 16:22:50	\N
98021N	M.	Pintat	PINTAT XAVIER	Xavier	1954-03-15 00:00:00	\N	ANCIEN	Ingénieur CEA	8000	32	UMP	Les Républicains	\N	ETRD	ETRD	330	Gironde	\N	x.pintat@senat.fr	PINTAT	NON	\N	\N	2017-10-09 16:22:50	\N
98022P	M.	Guérini	GUERINI_JEANNOEL	Jean-Noël	1951-01-01 00:00:00	\N	ANCIEN	Sans profession déclarée	7500	39	RDSE	RDSE	\N	ETRD	ETRD	130	Bouches-du-Rhône	\N	jn.guerini@senat.fr	GUÉRINI	NON	83	\N	2024-03-21 09:37:00	\N
98008R	M.	Natali	NATALI PAUL	Paul	1933-11-13 00:00:00	2020-03-31 00:00:00	ANCIEN	Administrateur de sociétés retraité	8000	29	UMP	Les Républicains	\N	ECON	ECON	205	Haute-Corse	\N	\N	NATALI	NON	\N	\N	2017-10-09 16:22:50	\N
000704	M.	Rotinat	ROTINAT VINCENT	Vincent	1888-07-10 00:00:00	1975-03-14 00:00:00	ANCIEN	Professeur honoraire	7400	69	GD	G.D.	\N	ETRD	ETRD	360	Indre	\N	\N	ROTINAT	NON	\N	\N	\N	\N
000754	M.	Roy	ROY PIERRE	Pierre	1898-06-25 00:00:00	1984-07-15 00:00:00	ANCIEN	Négociant	2200	23	RI	RI	\N	AFCL	AFCL	850	Vendée	\N	\N	ROY	NON	\N	\N	2014-05-20 11:05:04	\N
000768	M.	Roy	ROY LOUIS	Louis	1898-04-29 00:00:00	1966-04-24 00:00:00	ANCIEN	Chirurgien	3431	43	UNR	U.N.R.	\N	SOCI	SOCI	20	Aisne	\N	\N	ROY	NON	\N	\N	\N	\N
000749	M.	Sambron	SAMBRON MAURICE	Maurice	1898-07-22 00:00:00	1973-12-13 00:00:00	ANCIEN	Industriel	2300	21	RI	RI	\N	ECON	ECON	440	Loire-Atlantique	\N	\N	SAMBRON	NON	\N	\N	\N	\N
000745	M.	Schiaffino	SCHIAFFINO LAURENT	Laurent	1897-01-22 00:00:00	1978-07-11 00:00:00	ANCIEN	Armateur	2300	21	GD	G.D.	-A	ECON	ECON	1021	Alger	\N	\N	SCHIAFFINO	NON	\N	\N	2017-12-19 15:12:18	\N
000716	M.	Sinsout	SINSOUT CHARLES	Charles	1889-01-13 00:00:00	1985-05-03 00:00:00	ANCIEN	Propriétaire exploitant	1000	10	GD	G.D.	\N	SOCI	SOCI	240	Dordogne	\N	\N	SINSOUT	NON	\N	\N	2014-10-09 15:54:29	\N
000692	M.	Symphor	SYMPHOR PAUL	Paul	1893-08-07 00:00:00	1968-03-27 00:00:00	ANCIEN	Directeur d'école	4200	63	SOC	SER	\N	AFCL	AFCL	972	Martinique	Secrétaire du Sénat	\N	SYMPHOR	NON	\N	\N	2017-10-04 09:46:32	\N
000717	M.	Tellier	TELLIER GABRIEL	Gabriel	1899-01-13 00:00:00	1976-09-09 00:00:00	ANCIEN	Agriculteur	1000	10	CRARS	CRARS	\N	ECON	ECON	620	Pas-de-Calais	\N	\N	TELLIER	NON	\N	\N	\N	\N
000674	M.	Thioleron	THIOLERON LOUIS	Louis	1890-11-01 00:00:00	1976-03-31 00:00:00	ANCIEN	Ancien négociant	7200	29	CRARS	CRARS	\N	AFCL	AFCL	150	Cantal	\N	\N	THIOLERON	NON	\N	\N	\N	\N
000667	M.	Traband	TRABAND ANDRÉ	André	1920-02-21 00:00:00	1992-04-06 00:00:00	ANCIEN	Inspecteur de l'Enseignement technique retraité	7000	69	UC	UC	\N	LOIS	LOIS	670	Bas-Rhin	\N	\N	TRABAND	NON	\N	\N	2017-07-04 10:59:32	\N
000684	M.	Valeau	VALEAU AMÉDÉE	Amédée	1897-04-05 00:00:00	1980-08-10 00:00:00	ANCIEN	Agriculteur	1000	10	RPR	RPR	\N	AFCL	AFCL	971	Guadeloupe	\N	\N	VALEAU	NON	\N	\N	\N	\N
000702	M.	Coude Du Foresto	COUDE DU FORESTO YVON	Yvon	1897-02-10 00:00:00	1980-01-24 00:00:00	ANCIEN	Ingénieur	3800	31	UCDP	U.C.D.P.	\N	FINC	FINC	790	Deux-Sèvres	\N	\N	COUDE du FORESTO	NON	\N	\N	2015-02-10 12:00:26	\N
000769	Mme	Cremieux	CREMIEUX SUZANNE	Suzanne	1895-06-29 00:00:00	1976-07-11 00:00:00	ANCIEN	Journaliste	3511	54	GD	G.D.	\N	AFCL	AFCL	300	Gard	\N	\N	CREMIEUX	NON	\N	\N	\N	\N
000683	M.	Darou	DAROU MARCEL	Marcel	1896-08-03 00:00:00	1986-01-29 00:00:00	ANCIEN	Directeur d'école	4200	63	SOC	SER	\N	SOCI	SOCI	590	Nord	\N	\N	DAROU	NON	\N	\N	2017-10-04 09:46:32	\N
000744	M.	Dehe	DEHE ALFRED	Alfred	1899-02-21 00:00:00	1969-01-11 00:00:00	ANCIEN	Entrepreneur de travaux publics	2300	21	RI	RI	\N	ECON	ECON	590	Nord	\N	\N	DEHE	NON	\N	\N	\N	\N
000685	M.	Delpuech	DELPUECH VINCENT	Vincent	1888-04-05 00:00:00	1966-03-09 00:00:00	ANCIEN	Administrateur de journaux	2300	21	GD	G.D.	\N	AFCL	AFCL	130	Bouches-du-Rhône	\N	\N	DELPUECH	NON	\N	\N	2015-02-10 12:00:26	\N
000728	M.	Desache	DESACHE MARC	Marc	1892-10-15 00:00:00	1982-01-15 00:00:00	ANCIEN	Agent de change honoraire	7400	59	UNR	U.N.R.	\N	FINC	FINC	370	Indre-et-Loire	\N	\N	DESACHE	NON	\N	\N	\N	\N
000713	M.	Dubois	DUBOIS RENÉ	René	1893-07-12 00:00:00	1982-04-11 00:00:00	ANCIEN	Chirurgien	3112	43	RI	RI	\N	FINC	FINC	440	Loire-Atlantique	\N	\N	DUBOIS	NON	\N	\N	2015-02-10 12:00:26	\N
92028U	M.	Lagourgue	LAGOURGUE PIERRE	Pierre	1921-01-03 00:00:00	1998-02-16 00:00:00	ANCIEN	Médecin radiologue	3100	49	UC	UC	\N	SOCI	SOCI	974	La Réunion	\N	\N	LAGOURGUE	NON	\N	\N	2017-07-04 10:59:32	\N
92021M	M.	Fatous	FATOUS	Léon	1926-02-11 00:00:00	2023-09-24 00:00:00	ANCIEN	Directeur commercial	3600	32	SOC	SER	\N	ECON	ECON	620	Pas-de-Calais	\N	\N	FATOUS	NON	\N	\N	2017-10-04 09:46:32	\N
83028T	M.	Descours	DESCOURS	Charles	1937-12-31 00:00:00	\N	ANCIEN	Chirurgien	3112	43	RPR	RPR	\N	SOCI	SOCI	380	Isère	\N	\N	DESCOURS	NON	\N	\N	\N	\N
88012G	M.	Ginésy	GINESY	Charles	1922-05-12 00:00:00	2012-12-30 00:00:00	ANCIEN	Enseignant	4200	62	UMP	Les Républicains	\N	ECON	ECON	60	Alpes-Maritimes	\N	c.ginesy@senat.fr	GINÉSY	NON	\N	\N	2017-10-09 16:22:50	\N
000501	M.	Collet	COLLET FRANÇOIS	François	1923-02-09 00:00:00	1994-09-27 00:00:00	ANCIEN	Ingénieur	3800	31	RPR	RPR	\N	LOIS	LOIS	615	Paris	\N	\N	COLLET	NON	\N	\N	\N	\N
57613G	M.	Favre	FAVRE PAUL	Paul	1921-05-31 00:00:00	2015-03-17 00:00:00	ANCIEN	Notaire	3128	57	RP	RP	\N	LOIS	LOIS	740	Haute-Savoie	\N	\N	FAVRE	NON	\N	\N	2015-03-24 17:08:49	\N
000219	M.	Laplace	LAPLACE ADRIEN	Adrien	1909-09-18 00:00:00	1992-06-05 00:00:00	ANCIEN	Agriculteur	1000	10	GD	G.D.	\N	AFCL	AFCL	820	Tarn-et-Garonne	\N	\N	LAPLACE	NON	\N	\N	\N	\N
000212	M.	de Raincourt	RAINCOURT PHILIPPE (DE)	Philippe	1909-05-01 00:00:00	1959-07-02 00:00:00	ANCIEN	Agriculteur	1000	10	RI	RI	\N	LOIS	LOIS	890	Yonne	\N	\N	de RAINCOURT	NON	\N	\N	\N	\N
000251	M.	Tinaud	TINAUD JEAN-LOUIS	Jean-Louis	1910-09-23 00:00:00	1990-08-13 00:00:00	ANCIEN	Avocat	3121	51	RI	RI	-A	ETRD	ETRD	1004	Basses-Pyrénées	\N	\N	TINAUD	NON	\N	\N	2015-02-10 12:00:26	\N
58808V	M.	Tricon	TRICON EMILE	Emile	1908-04-17 00:00:00	2000-01-11 00:00:00	ANCIEN	Attaché d'agent de change en retraite	4600	59	RPR	RPR	\N	ETRD	ETRD	335	Hauts-de-Seine	\N	\N	TRICON	NON	\N	\N	\N	\N
98007Q	M.	Murat	MURAT	Bernard	1946-02-19 00:00:00	2018-04-27 00:00:00	ANCIEN	Consultant	8000	57	UMP	Les Républicains	\N	AFCL	AFCL	190	Corrèze	\N	b.murat@senat.fr	MURAT	NON	\N	\N	2018-04-30 14:05:27	\N
000044	M.	Roubert	ROUBERT ALEX	Alex	1901-06-12 00:00:00	1980-01-14 00:00:00	ANCIEN	Avocat	3121	51	SOC	SER	\N	FINC	FINC	60	Alpes-Maritimes	\N	\N	ROUBERT	NON	\N	\N	2017-10-04 09:46:33	\N
000015	M.	Louvel	LOUVEL JEAN-MARIE	Jean-Marie	1900-07-01 00:00:00	1970-06-13 00:00:00	ANCIEN	Ingénieur	3800	31	UCDP	U.C.D.P.	\N	FINC	FINC	140	Calvados	\N	\N	LOUVEL	NON	\N	\N	2015-02-10 12:00:26	\N
000697	M.	Fournier	FOURNIER JEAN-LOUIS	Jean-Louis	1887-07-08 00:00:00	1968-11-20 00:00:00	ANCIEN	Chirurgien	3112	43	SOC	SER	\N	SOCI	SOCI	400	Landes	\N	\N	FOURNIER	NON	\N	\N	2017-10-04 09:46:33	\N
000766	M.	Fruh	FRUH CHARLES	Charles	1894-05-28 00:00:00	1982-05-20 00:00:00	ANCIEN	Avocat	3121	51	RI	RI	\N	AFCL	AFCL	1029	Seine	\N	\N	FRUH	NON	\N	\N	\N	\N
000675	M.	Gadoin	GADOIN JACQUES	Jacques	1892-12-01 00:00:00	1974-04-19 00:00:00	ANCIEN	Banquier	2300	21	GD	G.D.	\N	ECON	ECON	580	Nièvre	Questeur du Sénat	\N	GADOIN	NON	\N	\N	\N	\N
000753	M.	Ganeval	GANEVAL JEAN	Jean	1894-12-24 00:00:00	1981-01-12 00:00:00	ANCIEN	Général (de Corps d'armée)	5300	74	UNR	U.N.R.	\N	ETRD	ETRD	1029	Seine	\N	\N	GANEVAL	NON	\N	\N	2015-02-10 12:00:26	\N
07003H	M.	Bernard-Reymond	BERNARDREYMOND PIERRE	Pierre	1944-01-16 00:00:00	\N	ANCIEN	Sans profession déclarée	8000	80	NI	NI	\N	ETRD	ETRD	50	Hautes-Alpes	\N	senateur.pbr@orange.fr	BERNARD-REYMOND	NON	\N	\N	2017-06-15 09:44:07	\N
000721	M.	Guislain	GUISLAIN MARCEL	Marcel	1899-06-14 00:00:00	1986-07-10 00:00:00	ANCIEN	Medecin	3112	42	SOC	SER	\N	SOCI	SOCI	590	Nord	\N	\N	GUISLAIN	NON	\N	\N	2017-10-04 09:46:33	\N
000732	M.	Houdet	HOUDET ROGER	Roger	1899-06-14 00:00:00	1987-08-25 00:00:00	ANCIEN	Ingenieur general du Génie Rural	3800	31	RI	RI	\N	AFCL	AFCL	760	Seine-Maritime	\N	\N	HOUDET	NON	\N	\N	2015-02-10 12:00:26	\N
000680	M.	Jamain	JAMAIN EUGÈNE	Eugène	1891-05-02 00:00:00	1970-10-24 00:00:00	ANCIEN	Minotier	6000	34	CRARS	CRARS	\N	ECON	ECON	180	Cher	\N	\N	JAMAIN	NON	\N	\N	2015-02-10 12:00:26	\N
000727	M.	Kistler	KISTLER MICHEL	Michel	1897-06-16 00:00:00	1976-05-05 00:00:00	ANCIEN	Administrateur de sociétés	3100	57	UCDP	U.C.D.P.	\N	FINC	FINC	670	Bas-Rhin	\N	\N	KISTLER	NON	\N	\N	\N	\N
000686	M.	Lacoste	LACOSTE ROBERT	Robert	1898-07-05 00:00:00	1989-03-08 00:00:00	ANCIEN	Trésorier Payeur Général	4500	71	SOC	SER	\N	AFCL	AFCL	240	Dordogne	\N	\N	LACOSTE	NON	\N	\N	2017-10-04 09:46:33	\N
000670	M.	Lakhdari	LAKHDARI MOHAMED	Mohamed	1899-01-01 00:00:00	1971-03-17 00:00:00	ANCIEN	Conseiller des Affaires musulmanes	4500	72	GD	G.D.	-A	SOCI	SOCI	1033	Constantine	\N	\N	LAKHDARI	NON	\N	\N	\N	\N
000706	M.	Lambert	LAMBERT MARCEL	Marcel	1897-11-10 00:00:00	1982-05-14 00:00:00	ANCIEN	Industriel	2300	21	RI	RI	\N	SOCI	SOCI	560	Morbihan	\N	\N	LAMBERT	NON	\N	\N	2016-12-01 16:47:42	\N
000679	M.	Le Basser	LEBASSER FRANCIS	Francis	1889-04-02 00:00:00	1974-03-06 00:00:00	ANCIEN	Chirurgien	3112	43	UNR	U.N.R.	\N	SOCI	SOCI	530	Mayenne	\N	\N	LE BASSER	NON	\N	\N	\N	\N
000693	M.	Legros	LEGROS MARCEL	Marcel	1898-10-07 00:00:00	1971-10-28 00:00:00	ANCIEN	Viticulteur	1000	10	RI	RI	\N	ECON	ECON	710	Saône-et-Loire	\N	\N	LEGROS	NON	\N	\N	\N	\N
000707	M.	Le Sassier Boisauné	LESASSIER BOISAUNÉ ETIENNE	Etienne	1888-03-11 00:00:00	1983-03-14 00:00:00	ANCIEN	Agriculteur	1000	10	RI	RI	\N	ETRD	ETRD	610	Orne	\N	\N	LE SASSIER BOISAUNÉ	NON	\N	\N	\N	\N
000710	M.	Leveque	LEVEQUE PAUL	Paul	1895-07-11 00:00:00	1974-12-23 00:00:00	ANCIEN	Médécin	3112	42	RI	RI	\N	SOCI	SOCI	770	Seine-et-Marne	\N	\N	LEVEQUE	NON	\N	\N	\N	\N
000708	M.	Leygue	LEYGUE LOUIS	Louis	1891-07-11 00:00:00	1979-10-13 00:00:00	ANCIEN	Notaire	3128	52	GD	G.D.	\N	ETRD	ETRD	320	Gers	\N	\N	LEYGUE	NON	\N	\N	\N	\N
000762	M.	Loste	LOSTE HENRI	Henri	1899-05-27 00:00:00	1978-06-16 00:00:00	ANCIEN	Administrateur de sociétés	3100	57	RI	RI	\N	SOCI	SOCI	984	Iles Wallis et Futuna	\N	\N	LOSTE	NON	\N	\N	\N	\N
000742	M.	Male	MALE FERNAND	Fernand	1899-09-20 00:00:00	1961-02-21 00:00:00	ANCIEN	Eleveur producteur	1000	10	GD	G.D.	-R	AFCL	AFCL	1044	Mostaganem-Tiaret	\N	\N	MALE	NON	\N	\N	2017-12-19 15:12:18	\N
000746	M.	Maroselli	MAROSELLI ANDRÉ	André	1893-02-22 00:00:00	1970-04-07 00:00:00	ANCIEN	Administrateur de sociétés	3100	57	GD	G.D.	\N	FINC	FINC	700	Haute-Saône	\N	\N	MAROSELLI	NON	\N	\N	2015-02-10 12:00:26	\N
000738	M.	Marrane	MARRANE GEORGES	Georges	1888-01-20 00:00:00	1976-08-27 00:00:00	ANCIEN	Mécanicien	6000	34	C	C	\N	NEANT	Aucune	1029	Seine	\N	\N	MARRANE	NON	\N	\N	\N	\N
000771	M.	Mathey	MATHEY PIERRE	Pierre	1890-07-30 00:00:00	1972-11-27 00:00:00	ANCIEN	Agriculteur	1000	10	GD	G.D.	\N	AFCL	AFCL	520	Haute-Marne	Secrétaire du Sénat	\N	MATHEY	NON	\N	\N	\N	\N
000751	M.	Messaud	MESSAUD LÉON	Léon	1897-06-23 00:00:00	1983-12-04 00:00:00	ANCIEN	Avocat	3121	51	SOC	SER	\N	SOCI	SOCI	310	Haute-Garonne	\N	\N	MESSAUD	NON	\N	\N	2017-10-04 09:46:33	\N
98038X	M.	Le Cam	LECAM	Gérard	1954-02-24 00:00:00	\N	ANCIEN	Professeur de technologie	8000	62	CRC	CRCE	\N	CAE	CAE	220	Côtes-d'Armor	Secrétaire du Sénat	Gerard.Lecam@wanadoo.fr	LE CAM	NON	\N	\N	2017-10-04 09:44:05	\N
98039Y	M.	de Richemont	RICHEMONT (DE)	Henri	1946-12-06 00:00:00	\N	ANCIEN	Avocat	8000	51	UMP	Les Républicains	\N	LOIS	LOIS	160	Charente	\N	h.derichemont@senat.fr	de RICHEMONT	NON	\N	\N	2017-10-09 16:22:50	\N
98040R	M.	Peyrat	PEYRAT	Jacques	1931-10-18 00:00:00	\N	ANCIEN	Avocat	8000	51	UMP	Les Républicains	\N	ETRD	ETRD	60	Alpes-Maritimes	\N	j.peyrat@senat.fr	PEYRAT	NON	\N	\N	2017-10-09 16:22:50	\N
98045W	M.	Esneu	ESNEU	Michel	1943-07-18 00:00:00	\N	ANCIEN	Professeur	8000	62	UMP	Les Républicains	\N	SOCI	SOCI	350	Ille-et-Vilaine	\N	m.esneu@senat.fr	ESNEU	NON	\N	\N	2017-10-09 16:22:50	\N
98046X	M.	Marc	MARC_FRANCOIS	François	1950-03-19 00:00:00	\N	ANCIEN	Professeur d'université	8000	69	SOC	SER	\N	FINC	FINC	290	Finistère	\N	f.marc@senat.fr	MARC	NON	\N	\N	2017-10-04 09:46:33	\N
98048A	M.	de Broissia	BROISSIA (DE)	Louis	1943-06-01 00:00:00	\N	ANCIEN	\N	8000	80	UMP	Les Républicains	\N	AFCL	AFCL	210	Côte-d'Or	\N	l.debroissia@senat.fr	de BROISSIA	NON	\N	\N	2017-10-09 16:22:50	\N
98050T	M.	Poniatowski	PONIATOWSKI LADISLAS	Ladislas	1946-11-10 00:00:00	\N	ANCIEN	Cadre de sociétés	8000	81	UMP	Les Républicains	\N	ETRD	ETRD	270	Eure	\N	l.poniatowski@senat.fr	PONIATOWSKI	NON	\N	\N	2017-10-09 16:22:51	\N
58925A	M.	Lombard	LOMBARD GEORGES	Georges	1925-03-14 00:00:00	2010-09-13 00:00:00	ANCIEN	Avocat	3121	51	UC	UC	\N	FINC	FINC	290	Finistère	\N	\N	LOMBARD	NON	\N	\N	2017-07-04 10:59:32	\N
98051U	M.	Le Pensec	LEPENSEC	Louis	1937-01-08 00:00:00	2024-01-10 00:00:00	ANCIEN	Sans profession déclarée	8000	80	SOC	SER	\N	ETRD	ETRD	290	Finistère	\N	l.lepensec@senat.fr	LE PENSEC	NON	\N	\N	2017-10-04 09:46:33	\N
98052V	M.	Flosse	FLOSSE	Gaston	1931-06-24 00:00:00	\N	ANCIEN	Agent général d'assurance	3700	32	NI	NI	\N	AFCL	AFCL	983	Polynésie française	\N	\N	FLOSSE	NON	\N	\N	2017-06-15 09:45:53	\N
98054X	M.	Lagorsse	LAGORSSE	Roger	1930-04-05 00:00:00	2011-10-27 00:00:00	ANCIEN	Principal honoraire de collège	4500	69	SOC	SER	\N	SOCI	SOCI	810	Tarn	\N	\N	LAGORSSE	NON	\N	\N	2017-10-04 09:46:33	\N
000099	M.	Boscary-Monsservin	BOSCARY-MONSSERVIN ROLAND	Roland	1904-05-12 00:00:00	1988-11-13 00:00:00	ANCIEN	Avocat, agriculteur	3121	51	UREI	U.R.E.I.	\N	FINC	FINC	120	Aveyron	\N	\N	BOSCARY-MONSSERVIN	NON	\N	\N	\N	\N
000353	M.	Berrier	BERRIER NOËL	Noël	1914-12-24 00:00:00	1986-12-18 00:00:00	ANCIEN	Médecin	3112	42	SOC	SER	\N	ETRD	ETRD	580	Nièvre	\N	\N	BERRIER	NON	\N	\N	2017-10-04 09:46:33	\N
58613L	M.	Bastie	BASTIE PIERRE	Pierre	1925-09-17 00:00:00	2013-05-21 00:00:00	ANCIEN	Retraité	7400	69	SOC	SER	\N	SOCI	SOCI	110	Aude	\N	\N	BASTIE	NON	\N	\N	2017-10-04 09:46:33	\N
000376	M.	Andrieux	ANDRIEUX ANTOINE	Antoine	1916-08-30 00:00:00	1983-05-10 00:00:00	ANCIEN	Chef d'entreprise	2300	21	SOC	SER	\N	ETRD	ETRD	130	Bouches-du-Rhône	\N	\N	ANDRIEUX	NON	\N	\N	2017-10-04 09:46:33	\N
000391	M.	Bouvard	BOUVARD ROBERT	Robert	1901-09-01 00:00:00	1992-07-05 00:00:00	ANCIEN	Industriel	2300	21	RI	RI	\N	ECON	ECON	430	Haute-Loire	\N	\N	BOUVARD	NON	\N	\N	2015-02-10 12:00:26	\N
000018	M.	Brun	BRUN PIERRE	Pierre	1900-08-21 00:00:00	1976-03-02 00:00:00	ANCIEN	Industriel	2300	21	RPR	RPR	\N	AFCL	AFCL	770	Seine-et-Marne	\N	\N	BRUN	NON	\N	\N	\N	\N
83022M	M.	Chambriard	CHAMBRIARD JEAN-PAUL	Jean-Paul	1929-07-12 00:00:00	1996-01-24 00:00:00	ANCIEN	Chef d'entreprise	2300	21	RI	RI	\N	ETRD	ETRD	430	Haute-Loire	\N	\N	CHAMBRIARD	NON	\N	\N	\N	\N
000572	M.	Charretier	CHARRETIER MAURICE	Maurice	1926-09-17 00:00:00	1987-09-30 00:00:00	ANCIEN	Avocat	3121	51	UREI	U.R.E.I.	\N	LOIS	LOIS	840	Vaucluse	\N	\N	CHARRETIER	NON	\N	\N	2017-06-15 09:45:46	\N
000089	M.	Cousin	COUSIN AUGUSTE	Auguste	1903-11-03 00:00:00	1982-01-10 00:00:00	ANCIEN	Agriculteur	1000	10	UREI	U.R.E.I.	\N	AFCL	AFCL	500	Manche	\N	\N	COUSIN	NON	\N	\N	\N	\N
000360	M.	Dayan	DAYAN GEORGES	Georges	1915-03-06 00:00:00	1979-05-28 00:00:00	ANCIEN	Conseiller d'Etat	3311	71	SOC	SER	\N	LOIS	LOIS	615	Paris	\N	\N	DAYAN	NON	\N	\N	2017-10-04 09:46:33	\N
000621	M.	Delmas	DELMAS LUCIEN	Lucien	1931-06-19 00:00:00	1988-02-05 00:00:00	ANCIEN	Secrétaire Général de Mairie	3311	71	SOC	SER	\N	ECON	ECON	240	Dordogne	\N	\N	DELMAS	NON	\N	\N	2017-10-04 09:46:33	\N
000106	M.	Dussert	DUSSERT FERNAND	Fernand	1904-08-04 00:00:00	1975-12-29 00:00:00	ANCIEN	Industriel salaisonnier	3600	22	SOC	SER	\N	SOCI	SOCI	580	Nièvre	\N	\N	DUSSERT	NON	\N	\N	2017-10-04 09:46:33	\N
000056	M.	Esseul	ESSEUL FERNAND	Fernand	1901-10-19 00:00:00	1993-03-10 00:00:00	ANCIEN	Expert agricole et foncier	1000	10	RI	RI	\N	ECON	ECON	490	Maine-et-Loire	\N	\N	ESSEUL	NON	\N	\N	\N	\N
000388	M.	Fonteneau	FONTENEAU JEAN	Jean	1917-05-25 00:00:00	1991-12-28 00:00:00	ANCIEN	Gérant de socièté d'édition	3000	57	UCDP	U.C.D.P.	\N	AFCL	AFCL	335	Hauts-de-Seine	\N	\N	FONTENEAU	NON	\N	\N	\N	\N
000309	M.	Giraud	GIRAUD PIERRE	Pierre	1913-02-28 00:00:00	1988-05-14 00:00:00	ANCIEN	Professeur agrégé d'université	3400	61	SOC	SER	\N	ETRD	ETRD	615	Paris	\N	\N	GIRAUD	NON	\N	\N	2017-10-04 09:46:33	\N
000110	M.	Henriet	HENRIET JACQUES	Jacques	1904-10-06 00:00:00	1988-06-14 00:00:00	ANCIEN	Chirurgien	3112	43	UREI	U.R.E.I.	\N	SOCI	SOCI	250	Doubs	\N	\N	HENRIET	NON	\N	\N	\N	\N
000133	M.	Lavy	LAVY ARTHUR	Arthur	1905-09-11 00:00:00	1986-12-19 00:00:00	ANCIEN	Inspecteur principal des contributions directes	4500	72	RI	RI	\N	AFCL	AFCL	740	Haute-Savoie	\N	\N	LAVY	NON	\N	\N	\N	\N
000325	M.	Legaret	LEGARET JEAN	Jean	1913-08-29 00:00:00	1976-02-16 00:00:00	ANCIEN	Maître des Requêtes au Conseil d'Etat	3311	71	RI	RI	\N	AFCL	AFCL	615	Paris	\N	\N	LEGARET	NON	\N	\N	\N	\N
000323	M.	Meric	MERIC ANDRÉ	André	1913-08-14 00:00:00	1993-08-14 00:00:00	ANCIEN	Agent comptable	5400	33	SOC	SER	\N	SOCI	SOCI	310	Haute-Garonne	\N	\N	MERIC	NON	\N	\N	2017-10-04 09:46:33	\N
000088	M.	Montpied	MONTPIED GABRIEL	Gabriel	1903-09-29 00:00:00	1991-01-09 00:00:00	ANCIEN	Mécanicien	6000	34	SOC	SER	\N	LOIS	LOIS	630	Puy-de-Dôme	\N	\N	MONTPIED	NON	\N	\N	2017-10-04 09:46:33	\N
000119	M.	Nuninger	NUNINGER MARCEL	Marcel	1905-04-24 00:00:00	1978-06-22 00:00:00	ANCIEN	Avocat	3121	51	UCDP	U.C.D.P.	\N	LOIS	LOIS	680	Haut-Rhin	\N	\N	NUNINGER	NON	\N	\N	\N	\N
59578F	M.	Pelletier	PELLETIER CHARLES	Charles	1927-07-25 00:00:00	2019-08-13 00:00:00	ANCIEN	Agriculteur	1000	10	RDE	R.D.E.	\N	LOIS	LOIS	770	Seine-et-Marne	Secrétaire du Sénat	\N	PELLETIER	NON	\N	\N	\N	\N
59241G	M.	Peyou	PEYOU HUBERT	Hubert	1923-07-11 00:00:00	2006-12-27 00:00:00	ANCIEN	Cadre	3600	32	RDE	R.D.E.	\N	SOCI	SOCI	650	Hautes-Pyrénées	\N	\N	PEYOU	NON	\N	\N	\N	\N
000026	M.	Ouella	OUELLA HACÈNE	Hacène	1899-10-08 00:00:00	1980-05-24 00:00:00	ANCIEN	Agriculteur	1000	10	NI	NI	\N	SOCI	SOCI	1042	Bône	\N	\N	OUELLA	NON	\N	\N	\N	\N
000488	M.	Pado	PADO DOMINIQUE	Dominique	1922-05-24 00:00:00	1989-05-18 00:00:00	ANCIEN	Journaliste	3511	54	UC	UC	\N	AFCL	AFCL	615	Paris	\N	\N	PADO	NON	\N	\N	2017-07-04 10:59:32	\N
000254	Mme	Pagani	PAGANI_ODETTE	Odette	1910-09-30 00:00:00	1995-08-13 00:00:00	ANCIEN	Administrateur de sociétés	3100	57	RI	RI	\N	FINC	FINC	890	Yonne	\N	\N	PAGANI	NON	\N	\N	2018-05-09 16:23:07	\N
000393	M.	Palmero	PALMERO FRANCIS	Francis	1917-12-08 00:00:00	1985-05-13 00:00:00	ANCIEN	Haut fonctionnaire	3311	71	UC	UC	\N	ETRD	ETRD	60	Alpes-Maritimes	\N	\N	PALMERO	NON	\N	\N	2017-07-04 10:59:32	\N
000412	M.	Pams	PAMS GASTON	Gaston	1918-11-22 00:00:00	1981-02-19 00:00:00	ANCIEN	Propriétaire exploitant	1000	10	GD	G.D.	\N	AFCL	AFCL	660	Pyrénées-Orientales	\N	\N	PAMS	NON	\N	\N	2015-02-10 12:00:26	\N
71031Y	M.	Papilio	PAPILIO SOSÉFO MAKAPÉ	Soséfo Makapé	1928-02-27 00:00:00	1998-04-05 00:00:00	ANCIEN	Commerçant	2200	22	RPR	RPR	\N	SOCI	SOCI	984	Iles Wallis et Futuna	\N	\N	PAPILIO	NON	\N	\N	\N	\N
57761T	M.	Parenty	PARENTY ROBERT	Robert	1921-08-13 00:00:00	2017-01-07 00:00:00	ANCIEN	Inspecteur (Caisse Nationale des Marchés de l'Etat)	4500	72	UCDP	U.C.D.P.	\N	ECON	ECON	335	Hauts-de-Seine	\N	\N	PARENTY	NON	\N	\N	2017-01-10 18:23:31	\N
000109	M.	Pascaud	PASCAUD GUY	Guy	1904-09-11 00:00:00	1979-12-07 00:00:00	ANCIEN	Industriel	2300	21	GD	G.D.	\N	AFCL	AFCL	160	Charente	\N	\N	PASCAUD	NON	\N	\N	\N	\N
000182	M.	Patenotre	PATENOTRE FRANÇOIS	François	1908-04-05 00:00:00	1977-04-11 00:00:00	ANCIEN	Agriculteur	1000	10	RI	RI	\N	ECON	ECON	100	Aube	\N	\N	PATENOTRE	NON	\N	\N	\N	\N
000112	M.	Patria	PATRIA PIERRE	Pierre	1904-11-05 00:00:00	1983-05-25 00:00:00	ANCIEN	Agriculteur	1000	10	RI	RI	\N	ECON	ECON	600	Oise	\N	\N	PATRIA	NON	\N	\N	\N	\N
000090	M.	Paulian	PAULIAN GILBERT	Gilbert	1903-11-06 00:00:00	1984-05-22 00:00:00	ANCIEN	Directeur d'exploitation agricole	1000	10	RI	RI	-A	ECON	ECON	1021	Alger	\N	\N	PAULIAN	NON	\N	\N	\N	\N
000048	M.	Pauly	PAULY PAUL	Paul	1901-07-22 00:00:00	1973-06-27 00:00:00	ANCIEN	Percepteur	3300	72	SOC	SER	\N	FINC	FINC	230	Creuse	\N	\N	PAULY	NON	\N	\N	2017-10-04 09:46:33	\N
59553V	M.	Pellarin	PELLARIN BERNARD	Bernard	1928-09-18 00:00:00	2007-05-17 00:00:00	ANCIEN	Cadre	3600	32	RDE	R.D.E.	-R	LOIS	LOIS	740	Haute-Savoie	\N	\N	PELLARIN	NON	\N	\N	\N	\N
59579G	M.	Pen	PEN ALBERT	Albert	1931-03-01 00:00:00	2003-07-03 00:00:00	ANCIEN	Instituteur	4200	63	SOC	SER	-R	ECON	ECON	995	Saint-Pierre-et-Miquelon	\N	\N	PEN	NON	\N	\N	2017-10-04 09:46:33	\N
000208	M.	Peridier	PERIDIER JEAN	Jean	1909-04-02 00:00:00	1982-08-08 00:00:00	ANCIEN	Avocat	3121	51	SOC	SER	\N	ETRD	ETRD	340	Hérault	\N	\N	PERIDIER	NON	\N	\N	2017-10-04 09:46:33	\N
99004R	M.	Karoutchi	KAROUTCHI	Roger	1951-08-26 00:00:00	\N	ACTIF	Inspecteur général de l'Education nationale	3300	71	UMP	Les Républicains	\N	ETRD	ETRD	335	Hauts-de-Seine	\N	r.karoutchi@senat.fr	KAROUTCHI	NON	31	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/karoutchi-roger.html
00003C	Mme	Campion	CAMPION	Claire-Lise	1951-07-27 00:00:00	\N	ANCIEN	Sans profession déclarée	8000	80	SOC	SER	\N	SOCI	SOCI	265	Essonne	\N	cl.campion@senat.fr	CAMPION	OUI	\N	\N	2017-10-04 09:46:33	\N
00004D	M.	Hethener	HETHENER	Alain	1946-04-15 00:00:00	\N	ANCIEN	Urbaniste	3100	57	RPR	RPR	\N	SOCI	SOCI	570	Moselle	\N	\N	HETHENER	NON	\N	\N	\N	\N
01001E	M.	Béteille	BETEILLE	Laurent	1948-04-19 00:00:00	\N	ANCIEN	Avocat	3121	51	UMP	Les Républicains	\N	LOIS	LOIS	265	Essonne	\N	l.beteille@senat.fr	BÉTEILLE	NON	\N	\N	2017-10-09 16:22:51	\N
01002F	M.	Guichard	GUICHARD	Pierre	1948-05-01 00:00:00	\N	ANCIEN	Gérant de société	3700	21	RDSE	RDSE	\N	AFCL	AFCL	390	Jura	\N	\N	GUICHARD	NON	\N	\N	\N	\N
01003G	M.	Fortassin	FORTASSIN	François	1939-08-02 00:00:00	2017-05-15 00:00:00	ANCIEN	Professeur d'histoire-géographie	7000	62	RDSE	RDSE	\N	SOCI	SOCI	650	Hautes-Pyrénées	Secrétaire du Sénat	f.fortassin@senat.fr	FORTASSIN	NON	\N	\N	2017-05-16 15:18:13	\N
92008Q	Mme	Cerisier-ben Guiga	CERISIER-BEN GUIGA	Monique	1942-06-20 00:00:00	2021-05-09 00:00:00	ANCIEN	Professeur de lettres	4200	62	SOC	SER	\N	ETRD	ETRD	998	Français établis hors de France	Secrétaire du Sénat	m.cerisier-ben-guiga@senat.fr	CERISIER-ben GUIGA	OUI	\N	\N	2017-10-04 09:46:33	\N
98001J	M.	Gaspard	GASPARD	André	1925-02-17 00:00:00	1999-06-21 00:00:00	ANCIEN	Journaliste	7400	59	RI	RI	\N	ETRD	ETRD	997	Français établis hors de France	\N	\N	GASPARD	NON	\N	\N	\N	\N
86018E	M.	Clouet	CLOUET	Jean	1921-05-07 00:00:00	2008-10-20 00:00:00	ANCIEN	Retraité	7200	29	UMP	Les Républicains	\N	FINC	FINC	824	Val-de-Marne	\N	\N	CLOUET	NON	\N	\N	2017-10-09 16:22:51	\N
95049N	M.	Mercier	MERCIER_MICHEL	Michel	1947-03-07 00:00:00	\N	ANCIEN	Enseignant à la faculté de droit	3400	61	UC	UC	\N	LOIS	LOIS	690	Rhône	\N	m.mercier@senat.fr	MERCIER	NON	\N	\N	2017-10-01 10:42:05	\N
95006B	M.	Badinter	BADINTER	Robert	1928-03-30 00:00:00	2024-02-09 00:00:00	ANCIEN	Avocat, professeur d'Université	3400	61	SOC	SER	\N	ETRD	ETRD	335	Hauts-de-Seine	\N	r.badinter@senat.fr	BADINTER	NON	\N	\N	2017-10-04 09:46:33	\N
98047Y	M.	Fréville	FREVILLE	Yves	1934-12-01 00:00:00	\N	ANCIEN	Professeur d'université	8000	61	UMP	Les Républicains	-R	FINC	FINC	350	Ille-et-Vilaine	\N	y.freville@senat.fr	FRÉVILLE	NON	\N	\N	2017-10-09 16:22:51	\N
95060H	M.	Ralite	RALITE	Jack	1928-05-14 00:00:00	2017-11-12 00:00:00	ANCIEN	Journaliste	3511	54	CRC	CRCE	\N	AFCL	AFCL	775	Seine-Saint-Denis	\N	j.ralite@senat.fr	RALITE	NON	\N	\N	2018-03-01 16:24:46	\N
95019G	M.	Cléach	CLEACH	Marcel-Pierre	1934-01-16 00:00:00	2019-03-18 00:00:00	ANCIEN	Administrateur de sociétés	2300	21	UMP	Les Républicains	\N	ETRD	ETRD	720	Sarthe	\N	mp.cleach@senat.fr	CLÉACH	NON	\N	\N	2017-10-09 16:22:51	\N
58303Y	M.	Jozeau-Marigne	JOZEAU-MARIGNE LÉON	Léon	1909-07-21 00:00:00	2003-07-18 00:00:00	ANCIEN	Avoué	3128	52	UREI	U.R.E.I.	\N	LOIS	LOIS	500	Manche	Vice-président du Sénat	\N	JOZEAU-MARIGNE	NON	\N	\N	\N	\N
03002P	M.	Texier	TEXIER	Yannick	1948-05-20 00:00:00	\N	ANCIEN	Géomètre principal du cadastre retraité	7000	39	UMP	Les Républicains	\N	ECON	ECON	350	Ille-et-Vilaine	\N	y.texier@senat.fr	TEXIER	NON	\N	\N	2017-10-09 16:22:51	\N
000330	M.	Spenale	SPENALE GEORGES	Georges	1913-11-29 00:00:00	1983-08-20 00:00:00	ANCIEN	Gouverneur de la France d'Outre-mer	3311	71	SOC	SER	\N	ETRD	ETRD	810	Tarn	\N	\N	SPENALE	NON	\N	\N	2017-10-04 09:46:33	\N
58619S	M.	Bonnefous	BONNEFOUS EDOUARD	Edouard	1907-08-24 00:00:00	2007-02-24 00:00:00	ANCIEN	Professeur à l'Institut des hautes études internationales	3400	61	GD	G.D.	\N	FINC	FINC	895	Yvelines	\N	\N	BONNEFOUS	NON	\N	\N	\N	\N
000359	M.	Courroy	COURROY LOUIS	Louis	1915-03-04 00:00:00	1991-10-12 00:00:00	ANCIEN	Directeur commercial	3600	32	RI	RI	\N	AFCL	AFCL	880	Vosges	Questeur du Sénat	\N	COURROY	NON	\N	\N	2016-10-04 14:07:49	\N
000399	M.	Boyer-Andrivet	BOYER-ANDRIVET JACQUES	Jacques	1918-02-21 00:00:00	1990-06-08 00:00:00	ANCIEN	Viticulteur	1000	10	UC	UC	-R	ECON	ECON	330	Gironde	\N	\N	BOYER-ANDRIVET	NON	\N	\N	2017-07-04 10:59:32	\N
01013J	Mme	Beaufils	BEAUFILS	Marie-France	1946-11-22 00:00:00	\N	ANCIEN	Professeur des écoles	8000	63	CRC	CRCE	\N	FINC	FINC	370	Indre-et-Loire	\N	mariefrance.beaufils@wanadoo.fr	BEAUFILS	OUI	\N	\N	2017-10-04 09:44:06	\N
89027T	M.	Émin	EMIN	Jean-Paul	1939-06-17 00:00:00	\N	ANCIEN	Directeur commercial	3600	32	UMP	Les Républicains	\N	AFCL	AFCL	10	Ain	\N	emin.jean-paul@wanadoo.fr	ÉMIN	NON	\N	\N	2017-10-09 16:22:51	\N
03003Q	M.	Moulinier	MOULINIER	Jacques	1938-04-18 00:00:00	2010-12-17 00:00:00	ANCIEN	responsable d'entreprise	2000	21	UC	UC	\N	ECON	ECON	690	Rhône	\N	\N	MOULINIER	NON	\N	\N	2017-07-04 10:59:32	\N
03004R	M.	Mantienne	MANTIENNE	Bernard	1933-10-02 00:00:00	2016-11-03 00:00:00	ANCIEN	Cadre administratif retraité	7000	59	UC	UC	\N	ETRD	ETRD	265	Essonne	\N	\N	MANTIENNE	NON	\N	\N	2017-07-04 10:59:32	\N
00002B	M.	Muzeau	MUZEAU	Roland	1951-11-05 00:00:00	\N	ANCIEN	Technicien	4800	32	CRC	CRCE	\N	SOCI	SOCI	335	Hauts-de-Seine	\N	r.muzeau@senat.fr	MUZEAU	NON	\N	\N	2017-10-04 09:44:06	\N
04008A	M.	Daubresse	DAUBRESSE	Marc-Philippe	1953-08-01 00:00:00	\N	ACTIF	Directeur de société	2300	21	UMP	Les Républicains	\N	LOIS	LOIS	590	Nord	\N	mp.daubresse@senat.fr	DAUBRESSE	NON	10	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/daubresse-marc-philippe.html
73006G	M.	Moreigne	MOREIGNE	Michel	1934-05-06 00:00:00	\N	ANCIEN	Docteur en médecine	3112	42	SOC	SER	\N	FINC	FINC	230	Creuse	\N	michelmoreigne@wanadoo.fr	MOREIGNE	NON	\N	\N	2017-10-04 09:46:33	\N
98036V	M.	André	ANDRE P	Pierre	1947-06-29 00:00:00	\N	ANCIEN	Directeur général de CCI	8000	71	UMP	Les Républicains	\N	ETRD	ETRD	20	Aisne	\N	p.andre@senat.fr	ANDRÉ	NON	\N	\N	2017-10-09 16:22:51	\N
11032E	M.	Carvounas	CARVOUNAS_LUC_11032E	Luc	1971-06-08 00:00:00	\N	ANCIEN	Cadre territorial	8000	72	SOC	SER	\N	LOIS	LOIS	824	Val-de-Marne	\N	l.carvounas@senat.fr	CARVOUNAS	NON	\N	\N	2017-10-04 09:46:33	\N
97009N	M.	Angels	ANGELS	Bernard	1944-09-18 00:00:00	\N	ANCIEN	Principal de collège	4200	62	SOC	SER	\N	FINC	FINC	828	Val-d'Oise	\N	b.angels@senat.fr	ANGELS	NON	\N	\N	2017-10-04 09:46:33	\N
83011J	M.	Arthuis	ARTHUIS	Jean	1944-10-07 00:00:00	\N	ANCIEN	Expert comptable	3100	57	UC	UC	\N	FINC	FINC	530	Mayenne	\N	j.arthuis@senat.fr	ARTHUIS	NON	\N	\N	2017-07-04 10:59:32	\N
95007C	M.	Badré	BADRE	Denis	1943-01-03 00:00:00	\N	ANCIEN	Ingénieur général du Génie rural, des Eaux et Forêts	3800	73	UC	UC	\N	FINC	FINC	335	Hauts-de-Seine	\N	d.badre@senat.fr	BADRÉ	NON	\N	\N	2017-07-04 10:59:32	\N
84004P	M.	Balarello	BALARELLO	José	1926-12-25 00:00:00	2015-02-25 00:00:00	ANCIEN	Avocat honoraire	7400	59	UMP	Les Républicains	\N	LOIS	LOIS	60	Alpes-Maritimes	\N	jose.balarello@wanadoo.fr	BALARELLO	NON	\N	\N	2017-10-09 16:22:51	\N
07025P	M.	Le Vern	LEVERN ALAIN	Alain	1948-05-08 00:00:00	\N	ANCIEN	Directeur d'école	4200	63	SOC	SER	\N	CDD	CDD	760	Seine-Maritime	\N	\N	LE VERN	NON	\N	\N	2017-10-04 09:46:33	\N
98020M	M.	d'Attilio	ATTILIO (D')	Henri	1927-02-04 00:00:00	2008-11-12 00:00:00	ANCIEN	Cadre de l'aéronautique retraité	8000	29	SOC	SER	\N	SOCI	SOCI	130	Bouches-du-Rhône	\N	\N	d'ATTILIO	NON	\N	\N	2017-10-04 09:46:33	\N
07001F	M.	Danglot	DANGLOT JEAN-CLAUDE	Jean-Claude	1950-09-20 00:00:00	\N	ANCIEN	Sapeur-pompier professionnel	3300	73	CRC	CRCE	\N	ECON	ECON	620	Pas-de-Calais	\N	\N	DANGLOT	NON	\N	\N	2017-10-04 09:44:06	\N
86047K	M.	Trégouët	TREGOUET	René	1940-10-15 00:00:00	\N	ANCIEN	Chef d'entreprise	2300	21	UMP	Les Républicains	\N	FINC	FINC	690	Rhône	Secrétaire du Sénat	\N	TRÉGOUËT	NON	\N	\N	2017-10-09 16:22:51	\N
88009M	M.	Gruillot	GRUILLOT	Georges	1931-08-14 00:00:00	2021-03-07 00:00:00	ANCIEN	Docteur vétérinaire	3115	46	UMP	Les Républicains	\N	ECON	ECON	250	Doubs	\N	\N	GRUILLOT	NON	\N	\N	2017-10-09 16:22:51	\N
89042S	M.	Vallet	VALLET	André	1935-01-29 00:00:00	\N	ANCIEN	Directeur d'école (retraité)	7400	69	UC	UC	\N	AFCL	AFCL	130	Bouches-du-Rhône	\N	a.vallet@senat.fr	VALLET	NON	\N	\N	2017-07-04 10:59:32	\N
11034G	M.	Favier	FAVIER_CHRISTIAN_11034G	Christian	1951-02-20 00:00:00	\N	ANCIEN	Professeur des écoles	8000	63	CRC	CRCE	\N	LOIS	LOIS	824	Val-de-Marne	\N	c.favier@senat.fr	FAVIER	NON	\N	\N	2017-10-04 09:44:06	\N
83042R	M.	Masseret	MASSERET JEAN-PIERRE	Jean-Pierre	1944-08-23 00:00:00	\N	ANCIEN	Inspecteur principal des Impôts	3311	71	LREM	RDPI	\N	ETRD	ETRD	570	Moselle	\N	jp.masseret@senat.fr	MASSERET	NON	\N	\N	2017-10-04 09:45:00	\N
98015Q	M.	Picheral	PICHERAL	Jean-François	1934-02-26 00:00:00	\N	ANCIEN	Médecin radiologue	8000	42	SOC	SER	\N	AFCL	AFCL	130	Bouches-du-Rhône	\N	jf.picheral@senat.fr	PICHERAL	NON	\N	\N	2017-10-04 09:46:33	\N
98044V	M.	Nogrix	NOGRIX	Philippe	1942-06-03 00:00:00	\N	ANCIEN	Cadre de Direction	8000	32	UC	UC	\N	ETRD	ETRD	350	Ille-et-Vilaine	\N	p.nogrix@senat.fr	NOGRIX	NON	\N	\N	2017-07-04 10:59:32	\N
01015L	Mme	Didier	DIDIER EVELYNE	Évelyne	1948-03-14 00:00:00	\N	ANCIEN	Professeur de collège	8000	62	CRC	CRCE	\N	CDD	CDD	540	Meurthe-et-Moselle	\N	evelyne-didier@orange.fr	DIDIER	OUI	\N	\N	2017-10-04 09:44:06	\N
11061K	Mme	Génisson	GENISSON_CATHERINE_11061K	Catherine	1949-04-22 00:00:00	\N	ANCIEN	Médecin anesthésiste	8000	42	SOC	SER	\N	SOCI	SOCI	620	Pas-de-Calais	\N	c.genisson@senat.fr	GÉNISSON	OUI	\N	\N	2017-10-04 09:46:33	\N
01043Q	Mme	Létard	LETARD	Valérie	1962-10-13 00:00:00	\N	ANCIEN	Assistante sociale	8000	35	UC	UC	N	CAE	CAE	590	Nord	Vice-présidente du Sénat	v.letard@senat.fr	LÉTARD	OUI	\N	\N	2023-10-01 00:37:00	\N
000737	M.	Kalb	KALB 	Paul-Jacques	1898-08-19 00:00:00	1964-08-07 00:00:00	ANCIEN	Avocat	3121	51	UNR	U.N.R.	\N	LOIS	LOIS	680	Haut-Rhin	Vice-président du Sénat	\N	KALB	NON	\N	\N	\N	\N
02009S	M.	Fillon	FILLON	François	1954-03-04 00:00:00	\N	ANCIEN	Sans profession déclarée	7400	80	UMP	Les Républicains	\N	AFCL	AFCL	720	Sarthe	\N	ffillon@u-m-p.org	FILLON	NON	\N	\N	2017-12-15 15:46:11	\N
04034C	M.	Yung	YUNG RICHARD	Richard	1947-09-22 00:00:00	\N	ANCIEN	Directeur des affaires internationales de l'Office européen des brevets	3311	81	LREM	RDPI	\N	ETRD	ETRD	1054	Français établis hors de France	\N	r.yung@senat.fr	YUNG	NON	\N	\N	2017-10-04 18:57:33	\N
04033B	M.	Retailleau	RETAILLEAU BRUNO	Bruno	1960-11-20 00:00:00	\N	ACTIF	Sans profession déclarée	7400	39	UMP	Les Républicains	\N	AFCL	AFCL	850	Vendée	\N	b.retailleau@senat.fr	RETAILLEAU	NON	93	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/retailleau-bruno.html
04040A	M.	Bockel	BOCKEL JEAN-MARIE	Jean-Marie	1950-06-22 00:00:00	\N	ANCIEN	Avocat	3121	51	UC	UC	\N	ETRD	ETRD	680	Haut-Rhin	\N	jm.bockel@senat.fr	BOCKEL	NON	\N	\N	2018-01-12 11:43:00	\N
04041B	Mme	Hummel	HUMMEL CHRISTIANE	Christiane	1942-05-08 00:00:00	\N	ANCIEN	Chimiste	3400	69	UMP	Les Républicains	\N	AFCL	AFCL	830	Var	\N	c.hummel@senat.fr	HUMMEL	NON	\N	\N	2017-10-09 16:22:51	\N
04042C	M.	Cambon	CAMBON CHRISTIAN	Christian	1948-03-08 00:00:00	\N	ACTIF	Chef d'entreprise	2300	29	UMP	Les Républicains	\N	ETRD	ETRD	824	Val-de-Marne	\N	c.cambon@senat.fr	CAMBON	NON	60	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/cambon-christian.html
04044E	Mme	Troendlé	TROENDLE CATHERINE	Catherine	1961-02-20 00:00:00	\N	ANCIEN	\N	3000	81	UMP	Les Républicains	\N	LOIS	LOIS	680	Haut-Rhin	Vice-présidente du Sénat	c.troendle@senat.fr	TROENDLÉ	NON	\N	\N	2017-10-09 16:22:51	\N
04045F	Mme	Schillinger	SCHILLINGER	Patricia	1963-01-18 00:00:00	\N	ACTIF	Aide soignante	7700	39	LREM	RDPI	\N	LOIS	LOIS	680	Haut-Rhin	Secrétaire du Sénat	p.schillinger@senat.fr	SCHILLINGER	NON	47	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/schillinger-patricia.html
04046G	Mme	Demontès	DEMONTES CHRISTIANE	Christiane	1954-05-14 00:00:00	\N	ANCIEN	Directrice de centre d'information et d'orientation 	3300	72	SOC	SER	\N	SOCI	SOCI	690	Rhône	Vice-présidente du Sénat	c.demontes@senat.fr	DEMONTÈS	OUI	\N	\N	2017-10-04 09:46:33	\N
04047H	M.	Buffet	BUFFET FRANÇOIS-NOËL	François-Noël	1963-08-28 00:00:00	\N	ACTIF	Avocat	3100	57	UMP	Les Républicains	\N	LOIS	LOIS	690	Rhône	\N	fn.buffet@senat.fr	BUFFET	NON	29	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/buffet-francois-noel.html
01052R	M.	Boyer	BOYER JEAN 01052R	Jean	1937-01-04 00:00:00	\N	ANCIEN	Agriculteur	8000	10	UC	UC	\N	SOCI	SOCI	430	Haute-Loire	\N	contact@jean-boyer.com	BOYER	NON	\N	\N	2017-07-04 10:59:32	\N
000211	M.	Poher	POHER ALAIN	Alain	1909-04-17 00:00:00	1996-12-09 00:00:00	ANCIEN	Ingénieur civil des Mines	7400	79	UC	UC	\N	ETRD	ETRD	824	Val-de-Marne	\N	\N	POHER	NON	\N	\N	2017-07-04 10:59:32	\N
01026P	M.	Etienne	ETIENNE	Jean-Claude	1941-08-06 00:00:00	2017-03-11 00:00:00	ANCIEN	Professeur en médecine	3300	73	UMP	Les Républicains	\N	AFCL	AFCL	510	Marne	\N	jc.etienne@senat.fr	ETIENNE	NON	\N	\N	2017-10-09 16:22:51	\N
08021P	M.	Navarro	NAVARRO ROBERT	Robert	1952-05-01 00:00:00	\N	ANCIEN	Cadre de la Sncf	3600	39	LREM	RDPI	-R	CAE	CAE	340	Hérault	\N	r.navarro@senat.fr	NAVARRO	NON	\N	\N	2017-10-04 09:45:01	\N
05004A	M.	Baroin	BAROIN FRANÇOIS	François	1965-06-21 00:00:00	\N	ANCIEN	avocat	3121	51	UMP	Les Républicains	\N	FINC	FINC	100	Aube	\N	f.baroin@senat.fr	BAROIN	NON	\N	\N	2017-10-09 16:22:51	\N
05008E	M.	Bas	BAS PHILIPPE	Philippe	1958-07-20 00:00:00	\N	ACTIF	Conseiller d'Etat	8000	71	UMP	Les Républicains	\N	LOIS	LOIS	500	Manche	\N	p.bas@senat.fr	BAS	NON	90	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/bas-philippe.html
04079R	M.	Madec	MADEC ROGER	Roger	1950-10-27 00:00:00	\N	ANCIEN	Cadre administratif	3300	32	SOC	SER	\N	LOIS	LOIS	615	Paris	\N	r.madec@senat.fr	MADEC	NON	\N	\N	2017-10-04 09:46:34	\N
05012A	M.	Pointereau	POINTEREAU RÉMY	Rémy	1953-03-30 00:00:00	\N	ACTIF	Exploitant agricole	7100	10	UMP	Les Républicains	\N	CDD	CDD	180	Cher	\N	r.pointereau@senat.fr	POINTEREAU	NON	131	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/pointereau-remy.html
89037V	M.	Revol	REVOL	Henri	1936-02-14 00:00:00	\N	ANCIEN	Ingénieur Arts et métiers et ingénieur INSTN	3800	73	UMP	Les Républicains	-A	ECON	ECON	210	Côte-d'Or	\N	h.revol@senat.fr	REVOL	NON	\N	\N	2017-10-09 16:22:51	\N
80035E	M.	Puech	PUECH	Jean	1942-02-22 00:00:00	\N	ANCIEN	Professeur	4200	62	UMP	Les Républicains	\N	ETRD	ETRD	120	Aveyron	\N	j.puech@senat.fr	PUECH	NON	\N	\N	2017-10-09 16:22:52	\N
95037J	M.	Haut	HAUT	Claude	1944-12-22 00:00:00	\N	ANCIEN	Directeur territorial	3311	79	LREM	RDPI	\N	ETRD	ETRD	840	Vaucluse	\N	c.haut@senat.fr	HAUT	NON	\N	\N	2017-10-09 15:25:11	\N
66002K	M.	Pelletier	PELLETIER JACQUES	Jacques	1929-08-01 00:00:00	2007-09-03 00:00:00	ANCIEN	Agriculteur retraité	1000	10	RDSE	RDSE	\N	ECON	ECON	20	Aisne	\N	j.pelletier@senat.fr	PELLETIER	NON	\N	\N	\N	\N
98013N	M.	Miraux	MIRAUX	Jean-Luc	1953-04-17 00:00:00	\N	ANCIEN	Professeur de lettres	8000	62	UMP	Les Républicains	\N	AFCL	AFCL	270	Eure	\N	jl.miraux@senat.fr	MIRAUX	NON	\N	\N	2017-10-09 16:22:52	\N
04049K	Mme	Lamure	LAMURE ELISABETH	Élisabeth	1947-11-20 00:00:00	\N	ANCIEN	Chef d'entreprise	2300	80	UMP	Les Républicains	\N	CAE	CAE	690	Rhône	\N	e.lamure@senat.fr	LAMURE	NON	\N	\N	2017-10-09 16:22:52	\N
000460	M.	Beaupetit	BEAUPETIT CHARLES	Charles	1921-04-27 00:00:00	1986-09-09 00:00:00	ANCIEN	Géomètre-expert	3100	57	GD	G.D.	\N	ECON	ECON	410	Loir-et-Cher	\N	\N	BEAUPETIT	NON	\N	\N	\N	\N
01059Y	Mme	David	DAVID ANNIE	Annie	1963-01-17 00:00:00	\N	ANCIEN	Acheteuse en informatique	8000	33	CRC	CRCE	\N	SOCI	SOCI	380	Isère	\N	a.david@senat.fr	DAVID	OUI	\N	\N	2017-10-04 09:44:06	\N
05015D	M.	Megdoud	MEGDOUD	Mohamed	1908-01-16 00:00:00	1997-06-16 00:00:00	ANCIEN	Commercant	7200	22	UNR	U.N.R.	\N	NEANT	Aucune	1040	Tizi-Ouzou	\N	\N	MEGDOUD	NON	\N	\N	\N	\N
06001B	Mme	Jarraud-Vergnolle	JARRAUD-VERGNOLLE ANNIE	Annie	1948-02-07 00:00:00	\N	ANCIEN	Directrice d'entreprises de l'économie sociale	2000	21	SOC	SER	\N	SOCI	SOCI	640	Pyrénées-Atlantiques	\N	a.jarraud@senat.fr	JARRAUD-VERGNOLLE	OUI	\N	\N	2017-10-04 09:46:34	\N
06005F	M.	Rainaud	RAINAUD MARCEL	Marcel	1940-04-01 00:00:00	2020-04-10 00:00:00	ANCIEN	Professeur de mathématiques	3400	64	SOC	SER	\N	AFCL	AFCL	110	Aude	\N	marcel.rainaud@gmail.com	RAINAUD	NON	\N	\N	2017-10-04 09:46:34	\N
77053G	M.	Pasqua	PASQUA	Charles	1927-04-18 00:00:00	2015-06-29 00:00:00	ANCIEN	Sans profession déclarée	8000	80	UMP	Les Républicains	-A	ETRD	ETRD	335	Hauts-de-Seine	\N	\N	PASQUA	NON	\N	\N	2017-10-09 16:22:51	\N
98028V	M.	Humbert	HUMBERT	Jean-François	1952-10-17 00:00:00	\N	ANCIEN	Chargé de mission	8000	32	UMP	Les Républicains	\N	AFCL	AFCL	250	Doubs	Secrétaire du Sénat	\N	HUMBERT	NON	\N	\N	2017-10-09 16:22:52	\N
06006G	M.	Josselin	JOSSELIN CHARLES	Charles	1938-03-31 00:00:00	\N	ANCIEN	Économiste	3000	32	SOC	SER	\N	ECON	ECON	220	Côtes-d'Armor	\N	\N	JOSSELIN	NON	\N	\N	2017-10-04 09:46:34	\N
07004J	Mme	Goulet	GOULET NATHALIE	Nathalie	1958-05-24 00:00:00	\N	ACTIF	Ancien avocat au barreau de Paris	3121	51	UC	UC	\N	FINC	FINC	610	Orne	\N	n.goulet@senat.fr	GOULET	NON	162	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/goulet-nathalie.html
07002G	Mme	Roger-Coupin	ROGER-COUPIN MARYSE	Maryse	1949-07-12 00:00:00	\N	ANCIEN	Documentaliste	4500	72	NI	NI	\N	NEANT	Aucune	620	Pas-de-Calais	\N	\N	ROGER-COUPIN	NON	\N	\N	\N	\N
08015R	M.	Laurent	LAURENT DANIEL	Daniel	1949-02-04 00:00:00	\N	ACTIF	Viticulteur - Chef d'entreprise	7100	10	UMP	Les Républicains	\N	CAE	CAE	170	Charente-Maritime	\N	cab.daniel.laurent@orange.fr	LAURENT	NON	337	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/laurent-daniel.html
08017T	Mme	Lepage	LEPAGE CLAUDINE	Claudine	1949-08-10 00:00:00	\N	ANCIEN	Cadre dans le secteur de la formation	3600	64	SOC	SER	\N	AFCL	AFCL	1054	Français établis hors de France	\N	c.lepage@senat.fr	LEPAGE	OUI	\N	\N	2017-10-04 09:46:34	\N
08019V	M.	Magras	MAGRAS MICHEL	Michel	1954-01-06 00:00:00	\N	ANCIEN	Professeur de sciences de la vie et de la terre	3400	63	UMP	Les Républicains	\N	CAE	CAE	9713	Saint-Barthélemy	\N	m.magras@senat.fr	MAGRAS	NON	\N	\N	2017-10-09 16:22:52	\N
08010L	M.	Lefèvre	LEFEVRE ANTOINE	Antoine	1966-02-18 00:00:00	\N	ACTIF	Chargé d'études	3000	39	UMP	Les Républicains	\N	FINC	FINC	20	Aisne	Questeur du Sénat	a.lefevre@senat.fr	LEFÈVRE	NON	30	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/lefevre-antoine.html
08012N	M.	Lozach	LOZACH JEAN-JACQUES	Jean-Jacques	1954-02-08 00:00:00	\N	ACTIF	Professeur d'éducation physique et sportive	3400	61	SOC	SER	\N	AFCL	AFCL	230	Creuse	\N	jjlozach@jjlozach.fr	LOZACH	NON	145	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/lozach-jean-jacques.html
08022Q	Mme	Des Esgaulx	DESESGAULX MARIE-HÉLÈNE	Marie-Hélène	1950-05-26 00:00:00	\N	ANCIEN	Avocat à la Cour	3121	59	UMP	Les Républicains	\N	FINC	FINC	330	Gironde	\N	mh.des-esgaulx@senat.fr	DES ESGAULX	NON	\N	\N	2017-10-09 16:22:52	\N
08023R	M.	Fleming	FLEMING LOUIS-CONSTANT	Louis-Constant	1946-12-01 00:00:00	\N	ANCIEN	Directeur de société	2000	21	UMP	Les Républicains	\N	AFCL	AFCL	9715	Saint-Martin	\N	lc.fleming@senat.fr	FLEMING	NON	\N	\N	2017-10-09 16:22:52	\N
08024S	Mme	Cartron	CARTRON FRANÇOISE	Françoise	1949-03-27 00:00:00	\N	ANCIEN	Directrice d'école	4200	69	LREM	RDPI	\N	CDD	CDD	330	Gironde	\N	f.cartron@senat.fr	CARTRON	OUI	\N	\N	2017-10-04 18:54:10	\N
06004E	M.	Tropeano	TROPEANO ROBERT	Robert	1939-04-20 00:00:00	\N	ANCIEN	Inspecteur central des Postes	7400	71	RDSE	RDSE	\N	CAE	CAE	340	Hérault	\N	robert.tropeano@orange.fr	TROPEANO	NON	\N	\N	2014-09-28 17:03:41	\N
08027V	M.	Hervé	HERVE EDMOND	Edmond	1942-12-03 00:00:00	\N	ANCIEN	Enseignant	3400	61	SOC	SER	\N	FINC	FINC	350	Ille-et-Vilaine	\N	e.herve@senat.fr	HERVÉ	NON	\N	\N	2017-10-04 09:46:34	\N
08028W	M.	Chatillon	CHATILLON ALAIN	Alain	1943-03-15 00:00:00	\N	ACTIF	Chef d'entreprise	7400	39	UMP	Les Républicains	\N	CAE	CAE	310	Haute-Garonne	\N	a.chatillon@senat.fr	CHATILLON	NON	94	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/chatillon-alain.html
08039A	M.	Leleux	LELEUX JEAN-PIERRE	Jean-Pierre	1947-05-08 00:00:00	\N	ANCIEN	Enseignant en économie	3400	31	UMP	Les Républicains	\N	AFCL	AFCL	60	Alpes-Maritimes	\N	jp.leleux@senat.fr	LELEUX	NON	\N	\N	2017-10-09 16:22:52	\N
08031R	Mme	Laborde	LABORDE FRANÇOISE	Françoise	1958-07-08 00:00:00	\N	ANCIEN	Professeur des écoles	3400	63	RDSE	RDSE	\N	AFCL	AFCL	310	Haute-Garonne	\N	f.laborde@senat.fr	LABORDE	OUI	\N	\N	2017-09-18 14:58:57	\N
07026Q	Mme	Gonthier-Maurin	GONTHIER-MAURIN BRIGITTE	Brigitte	1956-04-23 00:00:00	\N	ANCIEN	Agent de maîtrise EDF	5200	32	CRC	CRCE	\N	AFCL	AFCL	335	Hauts-de-Seine	\N	b.gonthier-maurin@senat.fr	GONTHIER-MAURIN	OUI	\N	\N	2017-10-04 09:44:06	\N
08033T	M.	Mirassou	MIRASSOU JEAN-JACQUES	Jean-Jacques	1952-11-01 00:00:00	\N	ANCIEN	Chirurgien-dentiste	3113	45	SOC	SER	\N	CAE	CAE	310	Haute-Garonne	\N	jj.mirassou@senat.fr	MIRASSOU	NON	\N	\N	2017-10-04 09:46:34	\N
02003L	Mme	Bout	BOUT	Brigitte	1941-01-26 00:00:00	2024-02-05 00:00:00	ANCIEN	Ingénieur	3800	31	UMP	Les Républicains	\N	SOCI	SOCI	620	Pas-de-Calais	\N	b.bout@senat.fr	BOUT	NON	\N	\N	2017-10-09 16:22:52	\N
02007Q	M.	Bergelin	BERGELIN	Christian	1945-04-15 00:00:00	2008-03-26 00:00:00	ANCIEN	Transporteur	8000	80	UMP	Les Républicains	\N	SOCI	SOCI	700	Haute-Saône	\N	\N	BERGELIN	NON	\N	\N	2017-10-09 16:22:52	\N
000800	M.	<indéterminé>	ZZZZZZ 	<indéterminé>	1900-01-01 00:00:00	\N	AUTRE	\N	8000	80	\N	\N	\N	\N	\N	\N	\N	\N	\N	<INDÉTERMINÉ>	NON	\N	\N	\N	\N
01031L	Mme	André	ANDRE M	Michèle	1947-02-06 00:00:00	\N	ANCIEN	Directrice d'établissement médico-social public	8000	71	SOC	SER	\N	FINC	FINC	630	Puy-de-Dôme	\N	m.andre@senat.fr	ANDRÉ	OUI	\N	\N	2017-10-04 09:46:34	\N
03001N	M.	Krattinger	KRATTINGER	Yves	1948-11-05 00:00:00	\N	ANCIEN	Professeur	3400	61	SOC	SER	\N	FINC	FINC	700	Haute-Saône	\N	y.krattinger@senat.fr	KRATTINGER	NON	\N	\N	2017-10-04 09:46:34	\N
74041P	M.	Quilliot	QUILLIOT	Roger	1925-06-19 00:00:00	1998-07-17 00:00:00	ANCIEN	Professeur d'université	8000	61	SOC	SER	\N	AFCL	AFCL	630	Puy-de-Dôme	\N	\N	QUILLIOT	NON	\N	\N	2017-10-04 09:52:11	\N
000070	M.	Minvielle	MINVIELLE GÉRARD	Gérard	1902-10-25 00:00:00	1990-07-26 00:00:00	ANCIEN	Inspecteur des contributions	3300	71	SOC	SER	\N	NEANT	Aucune	400	Landes	Questeur du Sénat	\N	MINVIELLE	NON	\N	\N	2017-10-04 09:46:34	\N
02004M	Mme	Luypaert	LUYPAERT	Brigitte	1954-03-19 00:00:00	\N	ANCIEN	Agricultrice	1000	10	UMP	Les Républicains	\N	AFCL	AFCL	610	Orne	\N	\N	LUYPAERT	NON	\N	\N	2017-10-09 16:22:52	\N
02006P	M.	Geoffroy	GEOFFROY	André	1941-08-27 00:00:00	2019-07-13 00:00:00	ANCIEN	Chirurgien gynécologue obstétricien	3112	42	UMP	Les Républicains	\N	SOCI	SOCI	830	Var	\N	\N	GEOFFROY	NON	\N	\N	2017-10-09 16:22:52	\N
000305	M.	Sadi	SADI ABDELKRIM	Abdelkrim	1913-02-12 00:00:00	1975-06-18 00:00:00	ANCIEN	Officier de police	4500	72	UNR	U.N.R.	\N	LOIS	LOIS	1045	Setif-Batna	\N	\N	SADI	NON	\N	\N	\N	\N
58654V	M.	Bosson	BOSSON CHARLES	Charles	1908-08-02 00:00:00	2001-12-14 00:00:00	ANCIEN	Avocat	3121	51	UC	UC	\N	ETRD	ETRD	740	Haute-Savoie	\N	\N	BOSSON	NON	\N	\N	2017-07-04 10:59:32	\N
000032	M.	Bastit-St Martin	BASTIT-ST MARTIN ARMAND	Armand	1900-11-14 00:00:00	1984-03-13 00:00:00	ANCIEN	Viticulteur	1000	10	RIAS	R.I.A.S.	\N	LOIS	LOIS	330	Gironde	\N	\N	BASTIT-ST MARTIN	NON	\N	\N	\N	\N
95003X	M.	Massion	MASSION	Marc	1935-11-12 00:00:00	\N	ANCIEN	Inspecteur général des PTT	7400	71	SOC	SER	\N	FINC	FINC	760	Seine-Maritime	\N	m.massion@senat.fr	MASSION	NON	\N	\N	2017-10-04 09:46:34	\N
96001A	M.	Lèguevaques	LEGUEVAQUES	Guy	1936-01-06 00:00:00	\N	ANCIEN	Agent territorial	7400	79	SOC	SER	\N	LOIS	LOIS	310	Haute-Garonne	\N	\N	LÈGUEVAQUES	NON	\N	\N	2017-10-04 09:46:34	\N
000195	M.	Chochoy	CHOCHOY BERNARD	Bernard	1908-08-14 00:00:00	1981-04-23 00:00:00	ANCIEN	Instituteur	4200	63	SOC	SER	\N	AFCL	AFCL	620	Pas-de-Calais	\N	\N	CHOCHOY	NON	\N	\N	2017-10-04 09:46:34	\N
000043	M.	Flechet	FLECHET MAX	Max	1901-05-10 00:00:00	1983-10-11 00:00:00	ANCIEN	Industriel	2300	21	RI	RI	\N	FINC	FINC	420	Loire	\N	\N	FLECHET	NON	\N	\N	\N	\N
000271	M.	du Halgouet	HALGOUET ROGER DU	Roger	1911-04-30 00:00:00	1971-07-22 00:00:00	ANCIEN	Propriétaire exploitant	1000	10	UNR	U.N.R.	\N	ECON	ECON	350	Ille-et-Vilaine	Secrétaire du Sénat	\N	DU HALGOUET	NON	\N	\N	\N	\N
000516	M.	Kauss	KAUSS PAUL	Paul	1923-10-23 00:00:00	1991-11-03 00:00:00	ANCIEN	Expert-comptable	3100	57	RPR	RPR	\N	SOCI	SOCI	670	Bas-Rhin	\N	\N	KAUSS	NON	\N	\N	\N	\N
59550S	M.	Maurice-Bokanowski	MAURICE-BOKANOWSKI MICHEL	Michel	1912-11-06 00:00:00	2005-05-03 00:00:00	ANCIEN	Administrateur de sociétés	2300	21	RPR	RPR	\N	ETRD	ETRD	335	Hauts-de-Seine	\N	\N	MAURICE-BOKANOWSKI	NON	\N	\N	\N	\N
58926B	Mlle	Rapuzzi	RAPUZZI IRMA	Irma	1910-04-12 00:00:00	2018-04-03 00:00:00	ANCIEN	Professeur	4200	62	SOC	SER	\N	FINC	FINC	130	Bouches-du-Rhône	\N	\N	RAPUZZI	NON	\N	\N	2018-04-10 18:00:29	\N
000055	M.	Villard	VILLARD YVES	Yves	1901-10-15 00:00:00	1995-04-01 00:00:00	ANCIEN	Médecin	3112	42	CRARS	CRARS	\N	SOCI	SOCI	180	Cher	\N	\N	VILLARD	NON	\N	\N	\N	\N
98016R	M.	Bret	BRET	Robert	1949-04-10 00:00:00	\N	ANCIEN	Dessinateur en B. T. P.	8000	33	CRC	CRCE	\N	ETRD	ETRD	130	Bouches-du-Rhône	\N	robert.bret@wanadoo.fr	BRET	NON	\N	\N	2017-10-04 09:44:06	\N
000064	M.	Benali	BENALI BRAHIM	Brahim	1899-04-30 00:00:00	1994-01-29 00:00:00	ANCIEN	Commerçant	2200	22	GD	G.D.	-A	SOCI	SOCI	1043	Orléansville-Médéa	\N	\N	BENALI	NON	\N	\N	\N	\N
57773X	Mme	Alexandre Debray	ALEXANDRE DEBRAY JANINE	Janine	1910-05-03 00:00:00	2000-10-19 00:00:00	ANCIEN	Directrice de centre culturel	3600	32	RI	RI	\N	ETRD	ETRD	615	Paris	\N	\N	ALEXANDRE DEBRAY	NON	\N	\N	\N	\N
95033E	M.	Franchis	FRANCHIS	Serge	1933-09-10 00:00:00	\N	ANCIEN	Fonctionnaire des Finances	4500	73	UMP	Les Républicains	\N	SOCI	SOCI	890	Yonne	\N	\N	FRANCHIS	NON	\N	\N	2017-10-09 16:22:52	\N
95017E	M.	Chabroux	CHABROUX	Gilbert	1933-12-27 00:00:00	2017-12-01 00:00:00	ANCIEN	Professeur retraité	7400	69	SOC	SER	\N	SOCI	SOCI	690	Rhône	\N	\N	CHABROUX	NON	\N	\N	2017-12-11 16:31:15	\N
000595	M.	Toutain	TOUTAIN JACQUES	Jacques	1929-04-17 00:00:00	1985-09-01 00:00:00	ANCIEN	Inspecteur général des Finances	3311	71	GD	G.D.	\N	AFCL	AFCL	895	Yvelines	\N	\N	TOUTAIN	NON	\N	\N	\N	\N
92035T	M.	Marini	MARINI	Philippe	1950-01-28 00:00:00	\N	ANCIEN	Inspecteur des finances, avocat à la Cour	3121	51	UMP	Les Républicains	\N	AFCL	AFCL	600	Oise	\N	p.marini@senat.fr	MARINI	NON	\N	\N	2017-10-09 16:22:52	\N
89013M	M.	Belot	BELOT	Claude	1936-07-11 00:00:00	\N	ANCIEN	Professeur d'université	3400	61	UMP	Les Républicains	-R	FINC	FINC	170	Charente-Maritime	\N	c.belot@senat.fr	BELOT	NON	\N	\N	2017-10-09 16:22:52	\N
59525R	M.	Carat	CARAT JACQUES	Jacques	1919-09-21 00:00:00	2009-03-19 00:00:00	ANCIEN	Journaliste	3511	54	SOC	SER	\N	AFCL	AFCL	824	Val-de-Marne	\N	\N	CARAT	NON	\N	\N	2017-10-04 09:46:34	\N
58657Y	M.	Ceccaldi-Pavard	CECCALDI-PAVARD PIERRE	Pierre	1921-02-06 00:00:00	2004-12-31 00:00:00	ANCIEN	Assureur conseil	3100	57	UC	UC	\N	LOIS	LOIS	265	Essonne	Secrétaire du Sénat	\N	CECCALDI-PAVARD	NON	\N	\N	2017-07-04 10:59:32	\N
000066	M.	Delagnes	DELAGNES ROGER	Roger	1902-05-11 00:00:00	1976-04-06 00:00:00	ANCIEN	Instituteur en retraite	7400	69	SOC	SER	\N	ECON	ECON	130	Bouches-du-Rhône	\N	\N	DELAGNES	NON	\N	\N	2017-10-04 09:46:34	\N
000599	M.	Giraud	GIRAUD MICHEL	Michel	1929-07-14 00:00:00	2011-10-27 00:00:00	ANCIEN	Directeur de sociétés	2300	21	RPR	RPR	\N	ETRD	ETRD	824	Val-de-Marne	\N	\N	GIRAUD	NON	\N	\N	2017-06-15 09:45:33	\N
57135W	M.	Monteil	MONTEIL ANDRÉ	André	1915-08-15 00:00:00	1998-11-08 00:00:00	ANCIEN	Professeur agrégé	4200	62	UCDP	U.C.D.P.	\N	ETRD	ETRD	290	Finistère	\N	\N	MONTEIL	NON	\N	\N	2015-02-10 12:00:26	\N
000242	M.	Motte	MOTTE EUGÈNE	Eugène	1910-05-26 00:00:00	1983-04-18 00:00:00	ANCIEN	Industriel	2300	21	UNR	U.N.R.	\N	SOCI	SOCI	590	Nord	\N	\N	MOTTE	NON	\N	\N	2015-02-10 12:00:26	\N
57146A	M.	Rougeron	ROUGERON GEORGES	Georges	1911-01-06 00:00:00	2003-08-10 00:00:00	ANCIEN	Fonctionnaire communal	4500	73	SOC	SER	\N	AFCL	AFCL	30	Allier	\N	\N	ROUGERON	NON	\N	\N	2017-10-04 09:46:34	\N
000117	M.	Vivier	VIVIER 	Emile	1905-03-10 00:00:00	1991-01-03 00:00:00	ANCIEN	Directeur de Mutuelle d'assurances	3600	32	SOC	SER	\N	AFCL	AFCL	280	Eure-et-Loir	\N	\N	VIVIER	NON	\N	\N	2017-10-04 09:46:34	\N
01034P	M.	Vanlerenberghe	VANLERENBERGHE	Jean-Marie	1939-03-29 00:00:00	\N	ACTIF	Ingénieur	8000	31	UC	UC	\N	SOCI	SOCI	620	Pas-de-Calais	\N	jm.vanlerenberghe@senat.fr	VANLERENBERGHE	NON	85	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/vanlerenberghe-jean-marie.html
01035Q	M.	Coquelle	COQUELLE	Yves	1939-12-19 00:00:00	2015-04-07 00:00:00	ANCIEN	Carreleur	8000	34	CRC	CRCE	\N	ECON	ECON	620	Pas-de-Calais	\N	y.coquelle@senat.fr	COQUELLE	NON	\N	\N	2017-10-04 09:44:06	\N
01038T	Mme	Mathon-Poinat	MATHON-POINAT	Josiane	1954-08-23 00:00:00	\N	ANCIEN	Secrétaire	8000	33	CRC	CRCE	\N	LOIS	LOIS	420	Loire	\N	j.mathon@wanadoo.fr	MATHON-POINAT	OUI	\N	\N	2017-10-04 09:44:06	\N
01039U	M.	Thiollière	THIOLLIERE	Michel	1955-04-10 00:00:00	\N	ANCIEN	Professeur d'anglais	8000	62	UMP	Les Républicains	\N	AFCL	AFCL	420	Loire	\N	michel.thiolliere.senateur@wanadoo.fr	THIOLLIÈRE	NON	\N	\N	2017-10-09 16:22:52	\N
01040M	M.	Guerry	GUERRY	Michel	1932-12-02 00:00:00	\N	ANCIEN	Ingénieur	8000	21	UMP	Les Républicains	\N	ETRD	ETRD	998	Français établis hors de France	\N	m.guerry@senat.fr	GUERRY	NON	\N	\N	2017-10-09 16:22:52	\N
000007	M.	Rastoin	RASTOIN JACQUES	Jacques	1900-02-19 00:00:00	1979-06-17 00:00:00	ANCIEN	Administrateur de sociétés	3100	57	RI	RI	\N	AFCL	AFCL	130	Bouches-du-Rhône	\N	\N	RASTOIN	NON	\N	\N	\N	\N
89005M	M.	Sourdille	SOURDILLE JACQUES	Jacques	1922-06-19 00:00:00	1996-07-09 00:00:00	ANCIEN	Professeur agrégé de médecine	3431	41	RPR	RPR	\N	ECON	ECON	80	Ardennes	\N	\N	SOURDILLE	NON	\N	\N	2017-06-15 09:47:42	\N
59248P	M.	Thyraud	THYRAUD JACQUES	Jacques	1925-06-02 00:00:00	2005-05-16 00:00:00	ANCIEN	Avocat	3121	51	UREI	U.R.E.I.	\N	LOIS	LOIS	410	Loir-et-Cher	\N	\N	THYRAUD	NON	\N	\N	\N	\N
98031Q	M.	Darcos	DARCOS	Xavier	1947-07-14 00:00:00	\N	ANCIEN	Inspecteur général de l'Education Nationale	8000	71	RPR	RPR	-R	AFCL	AFCL	240	Dordogne	\N	\N	DARCOS	NON	\N	\N	2016-12-14 15:19:07	\N
58644T	M.	Hugo	HUGO BERNARD MICHEL	Bernard Michel	1930-10-04 00:00:00	2021-03-19 00:00:00	ANCIEN	Professeur	4200	62	C	C	\N	ECON	ECON	895	Yvelines	\N	\N	HUGO	NON	\N	\N	2017-11-08 16:59:32	\N
000190	M.	Vadepied	VADEPIED RAOUL	Raoul	1908-07-07 00:00:00	1995-03-29 00:00:00	ANCIEN	Agriculteur	1000	10	UCDP	U.C.D.P.	\N	ECON	ECON	530	Mayenne	Secrétaire du Sénat	\N	VADEPIED	NON	\N	\N	\N	\N
80024B	M.	Lejeune	LEJEUNE ANDRE	André	1935-07-04 00:00:00	2009-09-09 00:00:00	ANCIEN	Professeur de sciences physiques	3400	62	SOC	SER	\N	ECON	ECON	230	Creuse	\N	\N	LEJEUNE	NON	\N	\N	2017-10-04 09:46:34	\N
89029V	M.	Gaudin	GAUDIN JEANCLAUDE	Jean-Claude	1939-10-08 00:00:00	\N	ANCIEN	Professeur d'histoire-géographie	4200	69	UMP	Les Républicains	\N	AFCL	AFCL	130	Bouches-du-Rhône	Vice-président du Sénat	\N	GAUDIN	NON	\N	\N	2017-10-09 16:22:52	\N
000703	M.	Durand	DURAND  	Abel	1879-03-10 00:00:00	1975-11-02 00:00:00	ANCIEN	Avocat honoraire	3121	51	RI	RI	\N	LOIS	LOIS	440	Loire-Atlantique	\N	\N	DURAND	NON	\N	\N	\N	\N
000724	M.	Alric	ALRIC GUSTAVE	Gustave	1894-02-15 00:00:00	1967-10-17 00:00:00	ANCIEN	Ingénieur des arts et manufactures	3800	31	RI	RI	\N	FINC	FINC	100	Aube	\N	\N	ALRIC	NON	\N	\N	\N	\N
000689	M.	Andre	ANDRE LOUIS	Louis	1891-01-06 00:00:00	1978-07-24 00:00:00	ANCIEN	Agriculteur	1000	10	RI	RI	\N	ECON	ECON	140	Calvados	\N	\N	ANDRE	NON	\N	\N	\N	\N
000757	M.	d'Argenlieu	ARGENLIEU PHILIPPE D'	Philippe	1892-09-25 00:00:00	1977-05-21 00:00:00	ANCIEN	Propriétaire agriculteur	1000	10	UNR	U.N.R.	\N	ETRD	ETRD	720	Sarthe	\N	\N	d'ARGENLIEU	NON	\N	\N	\N	\N
04018C	M.	Schmitz	SCHMITZ 	Alain	1948-04-27 00:00:00	\N	ANCIEN	Ancien commissaire-priseur	3128	59	UMP	Les Républicains	\N	AFCL	AFCL	895	Yvelines	\N	a.schmitz@senat.fr	SCHMITZ	NON	\N	\N	2018-05-22 14:19:37	\N
95023C	M.	Demilly	DEMILLY	Fernand	1934-12-10 00:00:00	\N	ANCIEN	Retraité	7400	69	RDSE	RDSE	\N	AFCL	AFCL	800	Somme	\N	\N	DEMILLY	NON	\N	\N	\N	\N
95034F	M.	Gélard	GELARD	Patrice	1938-08-03 00:00:00	2020-06-25 00:00:00	ANCIEN	Professeur d'université	3400	62	UMP	Les Républicains	\N	LOIS	LOIS	760	Seine-Maritime	\N	p.gelard@senat.fr	GÉLARD	NON	\N	\N	2017-10-09 16:22:52	\N
89041R	M.	Seillier	SEILLIER	Bernard	1941-07-12 00:00:00	\N	ANCIEN	Administrateur civil	3311	71	RDSE	RDSE	\N	SOCI	SOCI	120	Aveyron	\N	b.seillier@senat.fr	SEILLIER	NON	\N	\N	\N	\N
08034U	M.	de Legge	LEGGE (DE) DOMINIQUE	Dominique	1952-02-18 00:00:00	\N	ACTIF	Cadre dirigeant dans le domaine de l'environnement	7400	39	UMP	Les Républicains	\N	FINC	FINC	350	Ille-et-Vilaine	\N	d.de-legge@senat.fr	de LEGGE	NON	56	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/de-legge-dominique.html
08035V	Mme	Ghali	GHALI SAMIA	Samia	1968-06-10 00:00:00	\N	ANCIEN	Fonctionnaire territoriale	5200	79	SOC	SER	\N	AFCL	AFCL	130	Bouches-du-Rhône	\N	s.ghali@senat.fr	GHALI	OUI	\N	\N	2017-10-04 09:46:34	\N
04037F	M.	Jégou	JEGOU JEAN JACQUES	Jean-Jacques	1945-03-24 00:00:00	\N	ANCIEN	Chef d'entreprise	2000	21	UC	UC	\N	FINC	FINC	824	Val-de-Marne	\N	jj.jegou@senat.fr	JÉGOU	NON	\N	\N	2017-07-04 10:59:32	\N
07034Q	M.	Pillet	PILLET FRANÇOIS	François	1950-05-13 00:00:00	\N	ANCIEN	Avocat honoraire	3121	59	UMP	Les Républicains	-R	LOIS	LOIS	180	Cher	\N	f.pillet@senat.fr	PILLET	NON	\N	\N	2017-10-09 16:22:52	\N
08038Y	M.	Daunis	DAUNIS MARC	Marc	1955-04-22 00:00:00	\N	ANCIEN	Professeur	4200	62	SOC	SER	\N	CAE	CAE	60	Alpes-Maritimes	\N	m.daunis@senat.fr	DAUNIS	NON	\N	\N	2017-10-04 09:46:34	\N
08040S	M.	Andreoni	ANDREONI SERGE	Serge	1940-03-15 00:00:00	\N	ANCIEN	Médecin du travail	3431	42	SOC	SER	\N	AFCL	AFCL	130	Bouches-du-Rhône	\N	s.andreoni@senat.fr	ANDREONI	NON	\N	\N	2017-10-04 09:46:34	\N
08042U	M.	Nègre	NEGRE LOUIS	Louis	1947-02-08 00:00:00	\N	ANCIEN	Professeur d'éducation physique et sportive	3400	69	UMP	Les Républicains	\N	CDD	CDD	60	Alpes-Maritimes	\N	l.negre@senat.fr	NÈGRE	NON	\N	\N	2017-10-09 16:22:52	\N
08043V	Mme	Blondin	BLONDIN MARYVONNE	Maryvonne	1947-01-20 00:00:00	\N	ANCIEN	Enseignante	3400	69	SOC	SER	\N	AFCL	AFCL	290	Finistère	\N	m.blondin@senat.fr	BLONDIN	OUI	\N	\N	2017-10-04 09:46:34	\N
08011M	M.	de Montgolfier	MONTGOLFIER	Albéric	1964-07-06 00:00:00	\N	ACTIF	Avocat au Conseil d'État et à la Cour de cassation	3100	57	UMP	Les Républicains	\N	FINC	FINC	280	Eure-et-Loir	\N	a.de-montgolfier@senat.fr	de MONTGOLFIER	NON	35	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/de-montgolfier-alberic.html
08013P	Mme	Chevé	CHEVE JACQUELINE	Jacqueline	1961-08-21 00:00:00	2010-03-15 00:00:00	ANCIEN	Directrice de foyer logement	4300	73	SOC	SER	\N	SOCI	SOCI	220	Côtes-d'Armor	\N	j.cheve@senat.fr	CHEVÉ	OUI	\N	\N	2017-10-04 09:46:34	\N
08014Q	M.	Botrel	BOTREL YANNICK	Yannick	1951-12-09 00:00:00	\N	ANCIEN	Aviculteur	1000	81	SOC	SER	\N	FINC	FINC	220	Côtes-d'Armor	\N	y.botrel@senat.fr	BOTREL	NON	\N	\N	2017-10-04 18:41:42	\N
95035G	M.	Gournac	GOURNAC	Alain	1943-09-13 00:00:00	\N	ANCIEN	Chef de publicité	3735	81	UMP	Les Républicains	\N	ETRD	ETRD	895	Yvelines	\N	a.gournac@senat.fr	GOURNAC	NON	\N	\N	2017-10-09 16:22:52	\N
96007G	Mme	Printz	PRINTZ	Gisèle	1933-06-27 00:00:00	\N	ANCIEN	Sténodactylo	5400	33	SOC	SER	\N	SOCI	SOCI	570	Moselle	\N	Gisele.Printz@wanadoo.fr	PRINTZ	OUI	\N	\N	2017-10-04 09:46:34	\N
59223E	M.	Collette	COLLETTE HENRI	Henri	1922-05-30 00:00:00	1998-12-12 00:00:00	ANCIEN	Notaire	3128	52	RPR	RPR	\N	ECON	ECON	620	Pas-de-Calais	\N	\N	COLLETTE	NON	\N	\N	\N	\N
59224F	M.	Costes	COSTES MARCEL	Marcel	1935-10-05 00:00:00	2013-05-27 00:00:00	ANCIEN	Artisan	2100	24	SOC	SER	\N	ECON	ECON	460	Lot	\N	\N	COSTES	NON	\N	\N	2017-10-04 09:46:34	\N
58502E	M.	Ehlers	EHLERS GÉRARD	Gérard	1930-03-29 00:00:00	2006-11-23 00:00:00	ANCIEN	Ouvrier	6000	34	C	C	\N	ECON	ECON	590	Nord	\N	\N	EHLERS	NON	\N	\N	\N	\N
58641Q	M.	Gargar	GARGAR MARCEL	Marcel	1911-07-19 00:00:00	2004-12-24 00:00:00	ANCIEN	Inspecteur central des Impôts	3311	71	C	C	-A	SOCI	SOCI	971	Guadeloupe	\N	\N	GARGAR	NON	\N	\N	2016-03-25 08:57:03	\N
58913V	M.	De La Verpilliere	LAVERPILLIERE GUY (DE)	Guy	1922-08-09 00:00:00	2006-04-25 00:00:00	ANCIEN	Agriculteur	1000	10	UREI	U.R.E.I.	\N	ECON	ECON	10	Ain	\N	\N	DE LA VERPILLIERE	NON	\N	\N	2017-06-15 09:49:14	\N
000204	M.	Lartigue	LARTIGUE EMMANUEL	Emmanuel	1908-12-28 00:00:00	1994-06-24 00:00:00	ANCIEN	Chirurgien-Dentiste	3113	45	UNR	U.N.R.	-A	ETRD	ETRD	1004	Basses-Pyrénées	\N	\N	LARTIGUE	NON	\N	\N	\N	\N
000102	M.	Mézard	MEZARD JEAN	Jean	1904-06-17 00:00:00	1997-03-04 00:00:00	ANCIEN	Médecin	3112	42	CNIP	C.N.I.P.	\N	SOCI	SOCI	150	Cantal	\N	\N	MÉZARD	NON	\N	\N	\N	\N
92026S	M.	Hugot	HUGOT	Jean-Paul	1948-04-02 00:00:00	2013-07-14 00:00:00	ANCIEN	Maître de conférences	3400	61	RPR	RPR	\N	AFCL	AFCL	490	Maine-et-Loire	\N	\N	HUGOT	NON	\N	\N	2013-07-18 09:30:45	\N
08020N	Mme	Bruguière	BRUGUIERE	Marie-Thérèse	1942-10-26 00:00:00	\N	ANCIEN	Cadre hospitalier 	3431	47	UMP	Les Républicains	-A	AFCL	AFCL	340	Hérault	\N	mt.bruguiere@senat.fr	BRUGUIÈRE	OUI	\N	\N	2018-01-25 16:30:38	\N
04080J	M.	Pozzo di Borgo	POZZO DI BORGO YVES	Yves	1948-05-03 00:00:00	\N	ANCIEN	Inspecteur général de l'administration de l'Education nationale	3311	71	UC	UC	\N	ETRD	ETRD	615	Paris	\N	y.pozzodiborgo@senat.fr	POZZO di BORGO	NON	\N	\N	2017-09-24 17:47:27	\N
04081K	Mme	Debré	DEBRE ISABELLE	Isabelle	1957-05-23 00:00:00	\N	ANCIEN	Gérante de société	8500	21	UMP	Les Républicains	\N	SOCI	SOCI	335	Hauts-de-Seine	Vice-présidente du Sénat	i.debre@senat.fr	DEBRÉ	NON	\N	\N	2017-10-09 16:22:53	\N
08001K	M.	Gallard	GALLARD MAURICE	Maurice	1891-03-17 00:00:00	1969-08-12 00:00:00	ANCIEN	Lieutenant Colonel en retraite	5300	74	NI	NI	\N	NEANT	Aucune	450	Loiret	\N	\N	GALLARD	NON	\N	\N	\N	\N
04085P	Mme	Assassi	ASSASSI ELIANE	Éliane	1958-10-02 00:00:00	\N	ANCIEN	Directrice de communication	3300	32	CRC	CRCE	N	LOIS	LOIS	775	Seine-Saint-Denis	\N	e.assassi@senat.fr	ASSASSI	OUI	\N	\N	2023-10-01 00:37:00	\N
04086Q	M.	Dallier	DALLIER PHILIPPE	Philippe	1962-12-08 00:00:00	\N	ANCIEN	Chef de projet en informatique	3800	32	UMP	Les Républicains	\N	FINC	FINC	775	Seine-Saint-Denis	\N	p.dallier@senat.fr	DALLIER	NON	\N	\N	2017-10-09 16:22:53	\N
04087R	Mme	Alquier	ALQUIER JACQUELINE	Jacqueline	1947-07-29 00:00:00	\N	ANCIEN	Secrétaire comptable	5400	33	SOC	SER	\N	SOCI	SOCI	810	Tarn	\N	j.alquier@senat.fr	ALQUIER	OUI	\N	\N	2017-10-04 09:46:34	\N
04088S	M.	Pierre	PIERRE JACKIE	Jackie	1946-05-27 00:00:00	\N	ANCIEN	Cadre	3600	39	UMP	Les Républicains	\N	CAE	CAE	880	Vosges	\N	j.pierre@senat.fr	PIERRE	NON	\N	\N	2017-10-09 16:23:01	\N
04089T	M.	Dubois	DUBOIS DANIEL	Daniel	1952-02-05 00:00:00	\N	ANCIEN	Directeur général d'OPAC	3600	81	UC	UC	\N	CAE	CAE	800	Somme	Secrétaire du Sénat	d.dubois@senat.fr	DUBOIS	NON	\N	\N	2017-10-04 14:47:53	\N
95063L	M.	Richard	RICHARD ALAIN	Alain	1945-08-29 00:00:00	\N	ANCIEN	Conseiller d'Etat	3311	71	LREM	RDPI	N	LOIS	LOIS	828	Val-d'Oise	Vice-président du Sénat	a.richard@senat.fr	RICHARD	NON	\N	\N	2023-10-01 00:37:00	\N
000094	M.	Tron	TRON LUDOVIC	Ludovic	1904-01-03 00:00:00	1968-10-24 00:00:00	ANCIEN	Inspecteur Général des Finances	3311	71	SOC	SER	-A	FINC	FINC	50	Hautes-Alpes	\N	\N	TRON	NON	\N	\N	2017-10-04 09:46:34	\N
000246	M.	Voyant	VOYANT JOSEPH	Joseph	1910-07-03 00:00:00	1997-03-20 00:00:00	ANCIEN	Conseil immobilier	3100	57	GD	G.D.	-R	ETRD	ETRD	690	Rhône	\N	\N	VOYANT	NON	\N	\N	\N	\N
04074L	M.	Portelli	PORTELLI HUGUES	Hugues	1947-12-22 00:00:00	\N	ANCIEN	Professeur des universités	3400	61	UMP	Les Républicains	\N	LOIS	LOIS	828	Val-d'Oise	\N	h.portelli@senat.fr	PORTELLI	NON	\N	\N	2017-10-09 16:22:53	\N
04056J	Mme	Tasca	TASCA CATHERINE	Catherine	1941-12-13 00:00:00	\N	ANCIEN	Responsable d'entreprises culturelles 	3000	32	SOC	SER	\N	LOIS	LOIS	895	Yvelines	Secrétaire du Sénat	c.tasca@senat.fr	TASCA	OUI	\N	\N	2017-10-04 09:46:34	\N
04058L	Mme	Dupont	DUPONT BERNADETTE	Bernadette	1936-12-06 00:00:00	\N	ANCIEN	Sans profession déclarée	8000	80	UMP	Les Républicains	-A	ETRD	ETRD	895	Yvelines	\N	b.dupont@senat.fr	DUPONT	NON	\N	\N	2017-10-09 16:22:53	\N
08009T	M.	Maurey	MAUREY HERVÉ	Hervé	1961-05-07 00:00:00	\N	ACTIF	Chef d'entreprise	8500	80	UC	UC	\N	FINC	FINC	270	Eure	\N	h.maurey@senat.fr	MAUREY	NON	121	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/maurey-herve.html
14267Y	M.	Cigolotti	CIGOLOTTI OLIVIER	Olivier	1963-08-16 00:00:00	\N	ACTIF	Directeur général d'un foyer de jeunes travailleurs	3300	35	UC	UC	\N	ETRD	ETRD	430	Haute-Loire	Questeur du Sénat	o.cigolotti@senat.fr	CIGOLOTTI	NON	123	2015-01-26 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/cigolotti-olivier.html
04083M	M.	Merceron	MERCERON JEAN-CLAUDE	Jean-Claude	1942-01-12 00:00:00	\N	ANCIEN	Architecte	3000	57	UC	UC	\N	CAE	CAE	850	Vendée	\N	jc.merceron@senat.fr	MERCERON	NON	\N	\N	2017-07-04 10:59:32	\N
04091M	M.	Beaumont	BEAUMONT RENÉ	René	1940-02-29 00:00:00	\N	ANCIEN	Docteur vétérinaire	3115	46	UMP	Les Républicains	\N	ETRD	ETRD	710	Saône-et-Loire	\N	r.beaumont@senat.fr	BEAUMONT	NON	\N	\N	2017-10-09 16:22:53	\N
59240F	M.	Olivier	OLIVIER HENRI	Henri	1917-01-17 00:00:00	2004-08-18 00:00:00	ANCIEN	Agriculteur	1000	10	UREI	U.R.E.I.	-R	ECON	ECON	610	Orne	\N	\N	OLIVIER	NON	\N	\N	\N	\N
04064J	M.	Giraud	GIRAUD ADRIEN	Adrien	1936-10-04 00:00:00	2018-05-24 00:00:00	ANCIEN	Directeur de société hôtelière	2000	21	UC	UC	\N	SOCI	SOCI	990	Mayotte	\N	a.giraud@senat.fr	GIRAUD	NON	\N	\N	2018-05-30 17:03:14	\N
04097T	M.	Huré	HURE BENOIT	Benoît	1953-06-05 00:00:00	\N	ANCIEN	Agriculteur	1000	10	UMP	Les Républicains	\N	CDD	CDD	80	Ardennes	\N	benoit.hure@orange.fr	HURÉ	NON	\N	\N	2017-11-15 09:54:03	\N
04098U	M.	Bertaud	BERTAUD 	Claude	1945-11-01 00:00:00	\N	ANCIEN	Enseignant retraité	4200	69	UMP	Les Républicains	\N	ECON	ECON	860	Vienne	\N	\N	BERTAUD	NON	\N	\N	2017-10-09 16:22:53	\N
04099V	M.	Chauveau	CHAUVEAU	Jean-Pierre	1942-11-08 00:00:00	\N	ANCIEN	Cadre de l'industrie	3600	32	UMP	Les Républicains	\N	AFCL	AFCL	720	Sarthe	\N	jp.chauveau@senat.fr	CHAUVEAU	NON	\N	\N	2017-10-09 16:22:53	\N
01012H	M.	Dauge	DAUGE	Yves	1935-01-26 00:00:00	\N	ANCIEN	Inspecteur général de l'équipement	7400	71	SOC	SER	\N	AFCL	AFCL	370	Indre-et-Loire	\N	y.dauge@senat.fr	DAUGE	NON	\N	\N	2017-10-04 09:46:35	\N
01017N	M.	Gaudin	GAUDIN CHRISTIAN	Christian	1950-01-13 00:00:00	\N	ANCIEN	Enseignant du supérieur	8000	61	UC	UC	\N	FINC	FINC	490	Maine-et-Loire	\N	c.gaudin@senat.fr	GAUDIN	NON	\N	\N	2017-07-04 10:59:32	\N
04101V	M.	Siffre	SIFFRE JACQUES	Jacques	1937-04-04 00:00:00	\N	ANCIEN	Médecin ophtalmologiste	3112	42	SOC	SER	\N	AFCL	AFCL	130	Bouches-du-Rhône	\N	j.siffre@senat.fr	SIFFRE	NON	\N	\N	2017-10-04 09:46:35	\N
04065K	M.	Ries	RIES ROLAND	Roland	1945-01-11 00:00:00	\N	ANCIEN	Consultant	3000	32	SOC	SER	\N	CDD	CDD	670	Bas-Rhin	\N	r.ries@senat.fr	RIES	NON	\N	\N	2017-10-04 09:46:35	\N
05001W	Mme	Hoarau	HOARAU_GELITA	Gélita	1956-01-15 00:00:00	\N	ANCIEN	Enseignante	3400	64	CRC	CRCE	\N	CDD	CDD	974	La Réunion	\N	gelita.hoarau974@wanadoo.fr	HOARAU	OUI	\N	\N	2017-10-04 09:44:06	\N
000028	M.	Boukikaz	BOUKIKAZ AHMED	Ahmed	1909-02-19 00:00:00	2012-08-14 00:00:00	ANCIEN	Fonctionnaire des services de santé	4500	73	GD	G.D.	-A	SOCI	SOCI	1033	Constantine	\N	\N	BOUKIKAZ	NON	\N	\N	\N	\N
000115	M.	Balestra	BALESTRA CLÉMENT	Clément	1905-02-24 00:00:00	1984-11-14 00:00:00	ANCIEN	Chef de travaux de la marine nationale	4500	73	SOC	SER	\N	AFCL	AFCL	830	Var	\N	\N	BALESTRA	NON	\N	\N	2017-10-04 09:46:35	\N
04068N	Mme	Hurel	HUREL SANDRINE	Sandrine	1968-08-07 00:00:00	\N	ANCIEN	Assistante parlementaire	3300	35	SOC	SER	\N	ECON	ECON	760	Seine-Maritime	\N	\N	HUREL	OUI	\N	\N	2017-10-04 09:46:35	\N
86044G	M.	de Raincourt	RAINCOURT HENRI (DE)	Henri	1948-11-17 00:00:00	\N	ANCIEN	Agriculteur	1000	10	UMP	Les Républicains	-R	ETRD	ETRD	890	Yonne	\N	h.deraincourt@senat.fr	de RAINCOURT	NON	\N	\N	2017-10-09 16:22:53	\N
83013L	M.	Bataille	BATAILLE	Jean-Paul	1929-08-18 00:00:00	1999-10-16 00:00:00	ANCIEN	Pharmacien	3116	44	RI	RI	\N	AFCL	AFCL	590	Nord	\N	\N	BATAILLE	NON	\N	\N	\N	\N
000076	M.	Carcassonne	CARCASSONNE ROGER	Roger	1903-06-15 00:00:00	1992-11-28 00:00:00	ANCIEN	Avocat	3121	51	SOC	SER	\N	ETRD	ETRD	130	Bouches-du-Rhône	\N	\N	CARCASSONNE	NON	\N	\N	2017-10-04 09:46:35	\N
000191	M.	Charpentier	CHARPENTIER MAURICE	Maurice	1908-07-21 00:00:00	1965-08-19 00:00:00	ANCIEN	Médecin	3112	42	RI	RI	\N	AFCL	AFCL	450	Loiret	\N	\N	CHARPENTIER	NON	\N	\N	2015-02-10 12:00:26	\N
000245	M.	Deguise	DEGUISE JEAN	Jean	1910-06-10 00:00:00	1981-01-03 00:00:00	ANCIEN	Agriculteur	1000	10	RP	RP	\N	LOIS	LOIS	20	Aisne	\N	\N	DEGUISE	NON	\N	\N	2015-02-10 12:00:26	\N
57714L	M.	Durafour	DURAFOUR MICHEL	Michel	1920-04-11 00:00:00	2017-07-27 00:00:00	ANCIEN	Professeur d'université	3400	61	GD	G.D.	\N	FINC	FINC	420	Loire	\N	\N	DURAFOUR	NON	\N	\N	2017-08-02 12:33:31	\N
000062	M.	Golvan	GOLVAN VICTOR	Victor	1902-04-06 00:00:00	1986-08-16 00:00:00	ANCIEN	Vétérinaire	3115	46	UDR	U.D.R.	\N	ECON	ECON	560	Morbihan	\N	\N	GOLVAN	NON	\N	\N	\N	\N
11043H	M.	Savin	SAVIN_MICHEL_C4802	Michel	1958-11-25 00:00:00	\N	ACTIF	Agent technique principal	8000	73	UMP	Les Républicains	\N	AFCL	AFCL	380	Isère	\N	m.savin@senat.fr	SAVIN	NON	96	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/savin-michel.html
000543	M.	Piot	PIOT JACQUES	Jacques	1925-02-03 00:00:00	1980-09-02 00:00:00	ANCIEN	Notaire	3128	52	RI	RI	\N	LOIS	LOIS	890	Yonne	Secrétaire du Sénat	\N	PIOT	NON	\N	\N	\N	\N
000108	M.	de Pommery	POMMERY JOSEPH (DE)	Joseph	1904-08-29 00:00:00	1981-06-18 00:00:00	ANCIEN	Agriculteur	1000	10	RI	RI	\N	SOCI	SOCI	540	Meurthe-et-Moselle	\N	\N	de POMMERY	NON	\N	\N	\N	\N
000443	M.	Roujon	ROUJON JULES	Jules	1920-03-18 00:00:00	1985-05-26 00:00:00	ANCIEN	Profession libérale	3100	57	UREI	U.R.E.I.	\N	ECON	ECON	480	Lozère	\N	\N	ROUJON	NON	\N	\N	\N	\N
000298	M.	Soufflet	SOUFFLET JACQUES	Jacques	1912-10-04 00:00:00	1990-01-09 00:00:00	ANCIEN	Ancien directeur de compagnies de navigation aérienne	7200	29	UDR	U.D.R.	\N	LOIS	LOIS	895	Yvelines	Vice-président du Sénat	\N	SOUFFLET	NON	\N	\N	\N	\N
000322	M.	Dubois	DUBOIS EMILE	Emile	1913-08-09 00:00:00	1973-09-09 00:00:00	ANCIEN	Secrétaire de mairie	4500	73	SOC	SER	\N	LOIS	LOIS	590	Nord	\N	\N	DUBOIS	NON	\N	\N	2017-10-04 09:46:35	\N
81015E	M.	Charasse	CHARASSE	Michel	1941-07-08 00:00:00	2020-02-21 00:00:00	ANCIEN	Fonctionnaire de l'Etat	7400	71	RDSE	RDSE	\N	FINC	FINC	630	Puy-de-Dôme	\N	\N	CHARASSE	NON	\N	\N	2016-12-14 15:18:35	\N
80039J	M.	Roujas	ROUJAS	Gérard	1943-09-08 00:00:00	\N	ANCIEN	Agent technique	5400	33	SOC	SER	\N	ETRD	ETRD	310	Haute-Garonne	\N	\N	ROUJAS	NON	\N	\N	2017-10-04 09:46:35	\N
89007P	M.	Dupont	DUPONT AMBROISE	Ambroise	1937-05-11 00:00:00	\N	ANCIEN	Agriculteur	1000	10	UMP	Les Républicains	\N	AFCL	AFCL	140	Calvados	\N	a.dupont@senat.fr	DUPONT	NON	\N	\N	2017-10-09 16:22:53	\N
98049B	Mme	Boyer	BOYER YOLANDE	Yolande	1950-11-19 00:00:00	\N	ANCIEN	Professeur	8000	62	SOC	SER	\N	ECON	ECON	290	Finistère	Secrétaire du Sénat	y.boyer@senat.fr	BOYER	OUI	\N	\N	2017-10-04 09:46:35	\N
01032M	M.	Labarrère	LABARRERE	André	1928-01-12 00:00:00	2006-05-16 00:00:00	ANCIEN	Agrégé d'université	8000	61	SOC	SER	\N	AFCL	AFCL	640	Pyrénées-Atlantiques	\N	a.labarrere@senat.fr	LABARRÈRE	NON	\N	\N	2017-10-04 09:46:35	\N
01036R	Mme	San Vicente-Baudrin	SANVICENTE-BAUDRIN	Michèle	1955-05-19 00:00:00	\N	ANCIEN	Sans profession déclarée	8000	80	SOC	SER	\N	SOCI	SOCI	620	Pas-de-Calais	\N	m.san-vicente@senat.fr	SAN VICENTE-BAUDRIN	NON	\N	\N	2017-10-04 09:46:35	\N
04043D	Mme	Procaccia	PROCACCIA CATHERINE	Catherine	1949-10-13 00:00:00	\N	ANCIEN	Cadre supérieur	3600	39	UMP	Les Républicains	N	SOCI	SOCI	824	Val-de-Marne	\N	c.procaccia@senat.fr	PROCACCIA	NON	\N	\N	2023-10-01 00:37:00	\N
04048J	M.	Houel	HOUEL MICHEL	Michel	1942-11-08 00:00:00	2016-11-30 00:00:00	ANCIEN	Gérant de société	2300	21	UMP	Les Républicains	\N	CAE	CAE	770	Seine-et-Marne	\N	m.houel@senat.fr	HOUEL	NON	\N	\N	2017-10-09 16:22:53	\N
04050C	M.	Vera	VERA BERNARD	Bernard	1950-03-05 00:00:00	\N	ANCIEN	Professeur d'éducation physique et sportive	3400	62	CRC	CRCE	\N	ETRD	ETRD	265	Essonne	\N	b.vera@senat.fr	VERA	NON	\N	\N	2017-10-04 09:44:06	\N
04051D	Mme	Dini	DINI MUGUETTE	Muguette	1940-03-16 00:00:00	\N	ANCIEN	Enseignante	3400	62	UC	UC	\N	SOCI	SOCI	690	Rhône	\N	m.dini@senat.fr	DINI	OUI	\N	\N	2017-07-04 10:59:32	\N
04053F	Mme	Bricq	BRICQ NICOLE	Nicole	1947-06-10 00:00:00	2017-08-06 00:00:00	ANCIEN	Cadre de direction	3600	32	LREM	RDPI	\N	SOCI	SOCI	770	Seine-et-Marne	\N	n.bricq@senat.fr	BRICQ	OUI	\N	\N	2017-10-04 09:45:01	\N
04054G	M.	Billout	BILLOUT MICHEL	Michel	1958-02-19 00:00:00	\N	ANCIEN	Professeur des écoles	4200	63	CRC	CRCE	\N	ETRD	ETRD	770	Seine-et-Marne	\N	m.billout@senat.fr	BILLOUT	NON	\N	\N	2017-10-04 09:44:06	\N
01044R	Mme	Blandin	BLANDIN	Marie-Christine	1952-09-22 00:00:00	\N	ANCIEN	Professeur de biologie	8000	62	NI	NI	\N	AFCL	AFCL	590	Nord	\N	mc.blandin@senat.fr	BLANDIN	OUI	\N	\N	2017-07-04 15:08:09	\N
01045S	Mme	Desmarescaux	DESMARESCAUX	Sylvie	1950-09-06 00:00:00	\N	ANCIEN	Assistante sociale	4300	32	NI	NI	\N	SOCI	SOCI	590	Nord	Secrétaire du Sénat	s.desmarescaux@senat.fr	DESMARESCAUX	NON	\N	\N	\N	\N
01046T	M.	Barbier	BARBIER GILBERT	Gilbert	1940-03-03 00:00:00	\N	ANCIEN	Chirurgien	8000	43	RDSE	RDSE	\N	SOCI	SOCI	390	Jura	\N	senat.barbiergilbert@wanadoo.fr	BARBIER	NON	\N	\N	2017-09-24 13:44:49	\N
01047U	M.	Zocchetto	ZOCCHETTO	François	1958-12-14 00:00:00	\N	ANCIEN	Avocat	8000	51	UC	UC	\N	LOIS	LOIS	530	Mayenne	\N	f.zocchetto@senat.fr	ZOCCHETTO	NON	\N	\N	2017-09-24 13:29:41	\N
01048V	M.	Longuet	LONGUET	Gérard	1946-02-24 00:00:00	\N	ANCIEN	Administrateur civil	8000	21	UMP	Les Républicains	N	FINC	FINC	550	Meuse	\N	contact@gerard-longuet.fr	LONGUET	NON	\N	\N	2023-10-01 00:37:00	http://www.hatvp.fr/pages_nominatives/longuet-gerard.html
01049W	M.	Biwer	BIWER	Claude	1936-05-15 00:00:00	\N	ANCIEN	Agriculteur	8000	10	UC	UC	\N	ECON	ECON	550	Meuse	\N	\N	BIWER	NON	\N	\N	2017-07-04 10:59:32	\N
01050P	M.	Soulage	SOULAGE	Daniel	1942-02-14 00:00:00	2020-09-14 00:00:00	ANCIEN	Agriculteur	8000	10	UC	UC	\N	ECON	ECON	470	Lot-et-Garonne	\N	d.soulage@senat.fr	SOULAGE	NON	\N	\N	2017-07-04 10:59:32	\N
01053S	M.	Gautier	GAUTIER CHARLES	Charles	1945-01-25 00:00:00	2014-06-11 00:00:00	ANCIEN	Ingénieur agronome	8000	73	SOC	SER	\N	LOIS	LOIS	440	Loire-Atlantique	\N	c.gautier@senat.fr	GAUTIER	NON	\N	\N	2017-10-04 09:46:35	\N
01054T	Mme	Papon	PAPON	Monique	1934-10-05 00:00:00	2018-06-04 00:00:00	ANCIEN	Professeur d'histoire	8000	62	UMP	Les Républicains	\N	AFCL	AFCL	440	Loire-Atlantique	Vice-présidente du Sénat	m.papon@senat.fr	PAPON	NON	\N	\N	2018-06-07 15:38:15	\N
01055U	Mme	Gautier	GAUTIER GISELE	Gisèle	1938-12-09 00:00:00	\N	ANCIEN	Chef d'entreprise	2300	21	UMP	Les Républicains	\N	ETRD	ETRD	440	Loire-Atlantique	\N	g.gautier@senat.fr	GAUTIER	OUI	\N	\N	2017-10-09 16:22:54	\N
01056V	M.	Trillard	TRILLARD	André	1947-10-24 00:00:00	\N	ANCIEN	Docteur vétérinaire	8000	46	UMP	Les Républicains	\N	ETRD	ETRD	440	Loire-Atlantique	\N	a.trillard@senat.fr	TRILLARD	NON	\N	\N	2017-10-09 16:22:54	\N
01057W	M.	Guené	GUENE	Charles	1952-04-06 00:00:00	\N	ANCIEN	Avocat	8000	59	UMP	Les Républicains	N	FINC	FINC	520	Haute-Marne	\N	c.guene@senat.fr	GUENÉ	NON	\N	\N	2023-10-01 00:37:00	\N
01058X	M.	Sido	SIDO	Bruno	1951-02-19 00:00:00	\N	ACTIF	Ingénieur agronome	3400	10	UMP	Les Républicains	\N	ETRD	ETRD	520	Haute-Marne	\N	b.sido@senat.fr	SIDO	NON	32	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/sido-bruno.html
01061S	M.	Leroy	LEROY PHILIPPE	Philippe	1940-02-03 00:00:00	2019-08-19 00:00:00	ANCIEN	Ingénieur général du Génie rural	8000	71	UMP	Les Républicains	\N	CAE	CAE	570	Moselle	\N	p.leroy@senat.fr	LEROY	NON	\N	\N	2017-10-09 16:22:54	\N
01062T	M.	Todeschini	TODESCHINI	Jean-Marc	1952-03-12 00:00:00	\N	ANCIEN	Inspecteur de l'éducation nationale	3300	69	SOC	SER	N	ETRD	ETRD	570	Moselle	\N	jm.todeschini@senat.fr	TODESCHINI	NON	\N	\N	2023-10-01 00:37:00	\N
01019Q	M.	Saugey	SAUGEY	Bernard	1943-03-03 00:00:00	\N	ANCIEN	Administrateur de journaux	8000	54	UMP	Les Républicains	\N	LOIS	LOIS	380	Isère	Questeur du Sénat	bernard.saugey@orange.fr	SAUGEY	NON	\N	\N	2017-10-09 16:22:54	\N
01041N	M.	Duvernois	DUVERNOIS	Louis	1941-05-17 00:00:00	\N	ANCIEN	Journaliste	8000	54	UMP	Les Républicains	\N	AFCL	AFCL	1053	Français établis hors de France	\N	l.duvernois@senat.fr	DUVERNOIS	NON	\N	\N	2017-10-09 16:22:54	\N
01063U	M.	Cointat	COINTAT	Christian	1943-07-11 00:00:00	\N	ANCIEN	Directeur général au Parlement européen	8000	71	UMP	Les Républicains	\N	LOIS	LOIS	1052	Français établis hors de France	\N	c.cointat@senat.fr	COINTAT	NON	\N	\N	2017-10-09 16:22:54	\N
01064V	M.	Billard	BILLARD JOEL	Joël	1953-03-21 00:00:00	\N	ANCIEN	Comptable	8000	57	UMP	Les Républicains	\N	CDD	CDD	280	Eure-et-Loir	\N	j.billard@senat.fr	BILLARD	NON	\N	\N	2017-10-09 16:22:54	\N
01007L	Mme	Gourault	GOURAULT	Jacqueline	1950-11-20 00:00:00	\N	ANCIEN	Professeur d'histoire-géographie	8000	69	UC	UC	\N	CDD	CDD	410	Loir-et-Cher	\N	j.gourault@senat.fr	GOURAULT	OUI	\N	\N	2017-11-03 10:47:39	\N
01065W	M.	Alfonsi	ALFONSI	Nicolas	1936-04-13 00:00:00	2020-03-16 00:00:00	ANCIEN	Avocat	3121	51	RDSE	RDSE	\N	LOIS	LOIS	200	Corse-du-Sud	\N	\N	ALFONSI	NON	\N	\N	2017-06-15 09:43:42	\N
01037S	M.	Frécon	FRECON	Jean-Claude	1944-09-03 00:00:00	2016-12-10 00:00:00	ANCIEN	Directeur d'école	4200	63	SOC	SER	\N	AFCL	AFCL	420	Loire	\N	jc.frecon@wanadoo.fr	FRÉCON	NON	\N	\N	2017-10-04 09:46:35	\N
02001J	M.	Frimat	FRIMAT	Bernard	1940-10-12 00:00:00	\N	ANCIEN	Maître de conférences	3400	61	SOC	SER	\N	LOIS	LOIS	590	Nord	Vice-président du Sénat	b.frimat@senat.fr	FRIMAT	NON	\N	\N	2017-10-04 09:46:35	\N
01028R	M.	Sueur	SUEUR	Jean-Pierre	1947-02-28 00:00:00	\N	ANCIEN	Maître de conférences à l'université	8000	69	SOC	SER	N	LOIS	LOIS	450	Loiret	Questeur du Sénat	jp.sueur@senat.fr	SUEUR	NON	\N	\N	2023-10-01 00:37:00	\N
02002K	M.	Fouché	FOUCHE	Alain	1942-12-04 00:00:00	\N	ANCIEN	Avocat à la Cour d'Appel	3121	59	RTLI	Les Indépendants	\N	CDD	CDD	860	Vienne	\N	a.fouche@senat.fr	FOUCHÉ	NON	\N	\N	2017-10-25 10:59:00	\N
08008S	M.	Ackermann	ACKERMANN YVES	Yves	1949-06-01 00:00:00	\N	ANCIEN	Juriste	3000	32	SOC	SER	\N	NEANT	Aucune	125	Territoire de Belfort	\N	\N	ACKERMANN	NON	\N	\N	2017-10-04 09:46:35	\N
08056B	Mme	Goy-Chavent	GOY-CHAVENT SYLVIE	Sylvie	1963-05-23 00:00:00	\N	ACTIF	Professeur de l'enseignement professionnel	3400	61	UMP	Les Républicains	\N	ETRD	ETRD	10	Ain	\N	s.goy-chavent@senat.fr	GOY-CHAVENT	NON	330	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/goy-chavent-sylvie.html
07029T	M.	Laménie	LAMENIE MARC	Marc	1956-07-11 00:00:00	\N	ACTIF	Chargé d'études	5600	81	UMP	Les Républicains	-A	FINC	FINC	80	Ardennes	\N	m.lamenie@senat.fr	LAMÉNIE	NON	340	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/lamenie-marc.html
08068F	M.	Bourquin	BOURQUINMARTIAL	Martial	1952-07-23 00:00:00	\N	ANCIEN	Employé	4800	33	SOC	SER	\N	CAE	CAE	250	Doubs	\N	m.bourquin@senat.fr	BOURQUIN	NON	\N	\N	2017-10-04 09:46:35	\N
04039H	M.	Voguet	VOGUET  JEAN FRANÇOIS	Jean-François	1949-08-08 00:00:00	2021-02-02 00:00:00	ANCIEN	Technicien	4700	33	CRC	CRCE	\N	AFCL	AFCL	824	Val-de-Marne	\N	jf.voguet@senat.fr	VOGUET	NON	\N	\N	2017-10-04 09:44:06	\N
10003H	M.	Kerdraon	KERDRAON RONAN	Ronan	1962-07-16 00:00:00	\N	ANCIEN	Enseignant	3400	62	SOC	SER	\N	SOCI	SOCI	220	Côtes-d'Armor	\N	r.kerdraon@senat.fr	KERDRAON	NON	\N	\N	2017-10-04 09:46:35	\N
08060W	Mme	Bonnefoy	BONNEFOY NICOLE	Nicole	1958-08-11 00:00:00	\N	ACTIF	Attachée parlementaire	8600	80	SOC	SER	\N	CDD	CDD	160	Charente	Secrétaire du Sénat	n.bonnefoy@senat.fr	BONNEFOY	OUI	41	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/bonnefoy-nicole.html
10007M	Mme	Oudit	OUDIT MIREILLE	Mireille	1945-10-10 00:00:00	\N	ANCIEN	Agriculteur	8000	10	UMP	Les Républicains	\N	AFCL	AFCL	510	Marne	\N	m.oudit@senat.fr	OUDIT	OUI	\N	\N	2017-10-09 16:22:54	\N
08025T	M.	Anziani	ANZIANI ALAIN	Alain	1951-05-30 00:00:00	\N	ANCIEN	Avocat	3121	51	SOC	SER	\N	LOIS	LOIS	330	Gironde	\N	a.anziani@senat.fr	ANZIANI	NON	\N	\N	2017-10-04 09:46:35	\N
08057C	M.	Chastan	CHASTAN YVES	Yves	1948-04-20 00:00:00	\N	ANCIEN	Cadre territorial	4500	72	SOC	SER	\N	CDD	CDD	70	Ardèche	\N	y.chastan@senat.fr	CHASTAN	NON	\N	\N	2017-10-04 09:46:35	\N
08063A	Mme	Laurent-Perrigot	LAURENT-PERRIGOT FRANÇOISE	Françoise	1950-02-27 00:00:00	\N	ANCIEN	Cadre administratif	5200	72	SOC	SER	\N	AFCL	AFCL	300	Gard	\N	f.laurent-perrigot@senat.fr	LAURENT-PERRIGOT	NON	\N	\N	2017-10-04 09:46:35	\N
08067E	M.	Jeannerot	JEANNEROT CLAUDE	Claude	1945-04-10 00:00:00	\N	ANCIEN	Directeur général adjoint de l'AFPA	3300	71	SOC	SER	\N	SOCI	SOCI	250	Doubs	\N	c.jeannerot@senat.fr	JEANNEROT	NON	\N	\N	2017-10-04 09:46:35	\N
08065C	M.	Fournier	FOURNIER JEAN-PAUL	Jean-Paul	1945-10-16 00:00:00	\N	ANCIEN	Chef d'entreprise	2100	29	UMP	Les Républicains	\N	ETRD	ETRD	300	Gard	\N	jp.fournier@senat.fr	FOURNIER	NON	\N	\N	2017-10-09 16:22:54	\N
14263U	M.	Abate	ABATE_patrick	Patrick	1956-12-28 00:00:00	\N	ANCIEN	Professeur	3400	61	CRC	CRCE	\N	AFCL	AFCL	570	Moselle	\N	p.abate@senat.fr	ABATE	NON	\N	2014-12-18 16:18:16	2017-10-04 09:44:06	\N
08037X	M.	Le Menn	LEMENN JACKY	Jacky	1941-03-17 00:00:00	\N	ANCIEN	Directeur général d'hôpital	3300	47	SOC	SER	\N	SOCI	SOCI	350	Ille-et-Vilaine	\N	j.le-menn@senat.fr	LE MENN	NON	\N	\N	2017-10-04 09:46:35	\N
07033P	Mme	Dumas	DUMAS CATHERINE	Catherine	1957-07-13 00:00:00	\N	ACTIF	\N	3300	71	UMP	Les Républicains	\N	ETRD	ETRD	615	Paris	\N	c.dumas@senat.fr	DUMAS	OUI	220	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/dumas-catherine.html
08049C	M.	Vall	VALL RAYMOND	Raymond	1942-01-13 00:00:00	\N	ANCIEN	Directeur commercial 	3700	32	RDSE	RDSE	\N	ETRD	ETRD	320	Gers	\N	r.vall@senat.fr	VALL	NON	\N	\N	2017-09-18 14:58:58	\N
02053W	M.	Chevènement	CHEVENEMENT	Jean-Pierre	1939-03-09 00:00:00	\N	ANCIEN	Conseiller du commerce extérieur	3300	71	RDSE	RDSE	\N	ETRD	ETRD	125	Territoire de Belfort	\N	jp.chevenement@senat.fr	CHEVÈNEMENT	NON	\N	\N	2017-06-15 09:45:50	\N
11001K	Mme	Cros	CROS ROSELLE	Roselle	1947-08-27 00:00:00	\N	ANCIEN	Consultante formatrice	3300	79	UC	UC	\N	SOCI	SOCI	895	Yvelines	\N	r.cros@senat.fr	CROS	NON	\N	\N	2017-07-04 10:59:32	\N
10005K	Mme	Longère	LONGERE CHRISTIANE	Christiane	1953-04-13 00:00:00	\N	ANCIEN	Cadre en action sociale	3300	72	UMP	Les Républicains	\N	AFCL	AFCL	420	Loire	\N	c.longere@senat.fr	LONGÈRE	NON	\N	\N	2017-10-09 16:22:55	\N
08048B	M.	Gilles	Gilles_Bruno	Bruno	1960-12-26 00:00:00	\N	ANCIEN	Attaché de direction	3100	80	UMP	Les Républicains	\N	SOCI	SOCI	130	Bouches-du-Rhône	\N	b.gilles@senat.fr	GILLES	NON	\N	\N	2017-10-09 16:23:01	\N
08053X	M.	Mazuir	MAZUIR RACHEL	Rachel	1940-02-12 00:00:00	\N	ANCIEN	Professeur d'éducation physique et sportive	7500	69	SOC	SER	\N	ETRD	ETRD	10	Ain	\N	r.mazuir@senat.fr	MAZUIR	NON	\N	\N	2017-10-04 09:46:35	\N
08059E	M.	Berthou	BERTHOU JACQUES	Jacques	1940-03-03 00:00:00	\N	ANCIEN	Ingénieur EDF	3800	31	SOC	SER	-A	ETRD	ETRD	10	Ain	\N	j.berthou@senat.fr	BERTHOU	NON	\N	\N	2017-10-04 09:46:35	\N
08061X	M.	Patriat	PATRIAT FRANÇOIS	François	1943-03-21 00:00:00	\N	ACTIF	Docteur vétérinaire	3100	57	LREM	RDPI	\N	SOCI	SOCI	210	Côte-d'Or	\N	f.patriat@senat.fr	PATRIAT	NON	1	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/patriat-francois.html
08070Y	M.	Rebsamen	REBSAMEN FRANÇOIS	François	1951-06-25 00:00:00	\N	ANCIEN	Administrateur territorial	3300	71	SOC	SER	\N	FINC	FINC	210	Côte-d'Or	\N	f.rebsamen@senat.fr	REBSAMEN	NON	\N	\N	2017-10-04 09:46:35	\N
08018U	M.	Frassa	FRASSA CHRISTOPHE ANDRÉ	Christophe-André	1968-02-04 00:00:00	\N	ACTIF	Consultant juridique	3100	57	UMP	Les Républicains	\N	LOIS	LOIS	1054	Français établis hors de France	\N	c.frassa@senat.fr	FRASSA	NON	341	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/frassa-christophe-andre.html
08016S	M.	Guillaume	GUILLAUME DIDIER	Didier	1959-05-11 00:00:00	\N	ANCIEN	Agent du Trésor public	4500	81	NI	NI	\N	NEANT	Aucune	260	Drôme	\N	d.guillaume@senat.fr	GUILLAUME	NON	\N	\N	2018-05-23 11:13:25	\N
08036W	M.	Vestri	VESTRI RENÉ	René	1938-10-25 00:00:00	2013-02-06 00:00:00	ANCIEN	Entrepreneur de travaux publics	2300	21	UMP	Les Républicains	\N	CDD	CDD	60	Alpes-Maritimes	\N	r.vestri@senat.fr	VESTRI	NON	\N	\N	2017-10-09 16:22:55	\N
08071A	M.	Tuheiava	TUHEIAVA RICHARD	Richard	1974-02-28 00:00:00	\N	ANCIEN	Avocat	3121	51	SOC	SER	-A	ETRD	ETRD	983	Polynésie française	\N	r.tuheiava@senat.fr	TUHEIAVA	NON	\N	\N	2017-10-04 09:46:36	\N
08072B	M.	Antoinette	ANTOINETTE JEAN-ETIENNE	Jean-Étienne	1966-01-29 00:00:00	\N	ANCIEN	Formateur	3400	64	SOC	SER	-A	AFCL	AFCL	973	Guyane	\N	je.antoinette@senat.fr	ANTOINETTE	NON	\N	\N	2017-10-04 09:46:36	\N
10006L	Mme	Deroche	DEROCHE CATHERINE	Catherine	1953-02-24 00:00:00	\N	ANCIEN	Médecin	3431	80	UMP	Les Républicains	N	SOCI	SOCI	490	Maine-et-Loire	\N	c.deroche@senat.fr	DEROCHE	OUI	\N	\N	2023-10-01 00:37:00	\N
08045X	M.	Fichet	FICHET JEAN-LUC	Jean-Luc	1953-07-15 00:00:00	\N	ACTIF	Directeur d'institut médico-éducatif	7400	39	SOC	SER	\N	SOCI	SOCI	290	Finistère	\N	jl.fichet@senat.fr	FICHET	NON	242	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/fichet-jean-luc.html
11003M	M.	Léonard	LEONARD CLAUDE	Claude	1948-03-11 00:00:00	\N	ANCIEN	Médecin	3112	42	UMP	Les Républicains	-A	SOCI	SOCI	550	Meuse	\N	\N	LÉONARD	NON	\N	\N	2017-10-09 16:22:55	\N
08047A	M.	Paul	PAUL PHILIPPE	Philippe	1965-01-25 00:00:00	\N	ACTIF	Cadre du secteur privé	3700	32	UMP	Les Républicains	-R	ETRD	ETRD	290	Finistère	\N	p.paul@senat.fr	PAUL	NON	224	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/paul-philippe.html
08051V	M.	Mézard	MEZARD JACQUES	Jacques	1947-12-03 00:00:00	\N	ANCIEN	Avocat	3121	59	RDSE	RDSE	\N	LOIS	LOIS	150	Cantal	\N	j.mezard@senat.fr	MÉZARD	NON	\N	\N	2017-06-19 12:20:59	\N
04090L	M.	Repentin	REPENTIN THIERRY	Thierry	1963-04-05 00:00:00	\N	ANCIEN	Cadre	3600	32	SOC	SER	\N	CDD	CDD	730	Savoie	\N	senat.repentin@wanadoo.fr	REPENTIN	NON	\N	\N	2017-10-04 09:46:36	\N
04093P	M.	Detcheverry	DETCHEVERRY DENIS	Denis	1953-04-29 00:00:00	\N	ANCIEN	Agent EDF	5200	33	RDSE	RDSE	\N	ECON	ECON	995	Saint-Pierre-et-Miquelon	\N	d.detcheverry@senat.fr	DETCHEVERRY	NON	\N	\N	\N	\N
04094Q	M.	Larcher	LARCHER SERGE	Serge	1945-10-17 00:00:00	\N	ANCIEN	Professeur de lettres	3400	62	SOC	SER	\N	CAE	CAE	972	Martinique	Secrétaire du Sénat	s.larcher@senat.fr	LARCHER	NON	\N	\N	2017-10-04 09:46:36	\N
04095R	M.	Gillot	GILLOT JACQUES	Jacques	1948-03-04 00:00:00	\N	ANCIEN	Médecin	8000	42	LREM	RDPI	\N	ETRD	ETRD	971	Guadeloupe	\N	j.gillot@senat.fr	GILLOT	NON	\N	\N	2017-10-04 09:45:01	\N
04096S	M.	Marsin	MARSIN DANIEL	Daniel	1951-11-13 00:00:00	\N	ANCIEN	Cadre supérieur de banque	8000	32	RDSE	RDSE	\N	ECON	ECON	971	Guadeloupe	\N	d.marsin@senat.fr	MARSIN	NON	\N	\N	2017-06-15 09:47:14	\N
04052E	M.	Bodin	BODIN YANNICK	Yannick	1942-08-08 00:00:00	2023-10-08 00:00:00	ANCIEN	Professeur de collège	3400	62	SOC	SER	\N	AFCL	AFCL	770	Seine-et-Marne	\N	y.bodin@senat.fr	BODIN	NON	\N	\N	2017-10-04 09:46:36	\N
04063H	Mme	Boumediene-Thiery	BOUMEDIENE-THIERY ALIMA	Alima	1956-07-24 00:00:00	\N	ANCIEN	Juriste internationale	3000	57	SOC	SER	-R	LOIS	LOIS	615	Paris	\N	a.boumediene-thiery@senat.fr	BOUMEDIENE-THIERY	OUI	\N	\N	2017-10-04 09:46:36	\N
04035D	Mme	Garriaud-Maylam	GARRIAUD-MAYLAM JOËLLE	Joëlle	1955-03-20 00:00:00	\N	ANCIEN	Juriste internationale	3000	57	UMP	Les Républicains	N	ETRD	ETRD	1053	Français établis hors de France	\N	j.garriaud-maylam@senat.fr	GARRIAUD-MAYLAM	NON	\N	\N	2023-10-01 00:37:00	\N
04057K	Mme	Mélot	MELOT COLETTE	Colette	1947-04-20 00:00:00	\N	ANCIEN	Professeur d'anglais	3400	69	RTLI	Les Indépendants	N	SOCI	SOCI	770	Seine-et-Marne	\N	c.melot@senat.fr	MÉLOT	OUI	\N	\N	2023-10-01 00:37:00	\N
04092N	M.	Milon	MILON ALAIN	Alain	1947-09-16 00:00:00	\N	ACTIF	Médecin	7500	39	UMP	Les Républicains	\N	SOCI	SOCI	840	Vaucluse	\N	a.milon@senat.fr	MILON	NON	58	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/milon-alain.html
08069G	M.	Houpert	HOUPERT ALAIN	Alain	1957-08-13 00:00:00	\N	ACTIF	Médecin radiologue	3100	57	UMP	Les Républicains	\N	ETRD	ETRD	210	Côte-d'Or	\N	a.houpert@senat.fr	HOUPERT	NON	61	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/houpert-alain.html
09012S	Mme	Nicoux	NICOUX RENÉE	Renée	1951-03-26 00:00:00	\N	ANCIEN	Enseignante	7000	69	SOC	SER	\N	CAE	CAE	230	Creuse	\N	r.nicoux@senat.fr	NICOUX	OUI	\N	\N	2017-10-04 09:46:36	\N
10015M	M.	Reichardt	REICHARDT  ANDRÉ	André	1949-12-05 00:00:00	\N	ACTIF	Directeur général de Chambre des métiers	7400	39	UMP	Les Républicains	-A	LOIS	LOIS	670	Bas-Rhin	\N	a.reichardt@senat.fr	REICHARDT	NON	97	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/reichardt-andre.html
08046Y	M.	Teulade	TEULADE RENÉ	René	1931-06-17 00:00:00	2014-02-13 00:00:00	ANCIEN	Principal de collège	3311	62	SOC	SER	\N	SOCI	SOCI	190	Corrèze	\N	r.teulade@senat.fr	TEULADE	NON	\N	\N	2017-10-04 09:46:36	\N
08050U	Mme	Bourzai	BOURZAI BERNADETTE	Bernadette	1945-05-28 00:00:00	\N	ANCIEN	Professeure agrégée	3400	62	SOC	SER	\N	CAE	CAE	190	Corrèze	\N	b.bourzai@senat.fr	BOURZAI	OUI	\N	\N	2017-10-04 09:46:36	\N
08052W	M.	Daudigny	DAUDIGNY YVES	Yves	1947-02-23 00:00:00	\N	ANCIEN	Professeur de physique	3400	69	SOC	SER	\N	SOCI	SOCI	20	Aisne	Secrétaire du Sénat	y.daudigny@senat.fr	DAUDIGNY	NON	\N	\N	2017-10-04 14:47:23	\N
08058D	M.	Boutant	BOUTANT MICHEL	Michel	1956-11-23 00:00:00	\N	ANCIEN	Professeur agrégé d'allemand	3400	62	SOC	SER	\N	ETRD	ETRD	160	Charente	\N	m.boutant@senat.fr	BOUTANT	NON	\N	\N	2017-10-04 09:46:36	\N
08062Y	M.	Mayet	MAYET JEAN-FRANÇOIS	Jean-François	1940-01-30 00:00:00	\N	ANCIEN	Industriel - Président Directeur Général	2300	29	UMP	Les Républicains	\N	CAE	CAE	360	Indre	\N	jf.mayet@senat.fr	MAYET	NON	\N	\N	2017-10-09 16:22:55	\N
08064B	Mme	Escoffier	ESCOFFIER ANNE-MARIE	Anne-Marie	1942-08-15 00:00:00	\N	ANCIEN	Inspecteur général de l'Administration	3300	71	RDSE	RDSE	\N	CDD	CDD	120	Aveyron	\N	am.escoffier@senat.fr	ESCOFFIER	NON	\N	\N	2016-12-14 15:21:07	\N
04038G	M.	Collombat	COLLOMBAT PIERRE-YVES	Pierre-Yves	1945-07-18 00:00:00	\N	ANCIEN	Professeur agrégé de philosophie	3400	69	CRC	CRCE	-R	LOIS	LOIS	830	Var	\N	py.collombat@senat.fr	COLLOMBAT	NON	\N	\N	2017-10-04 09:44:06	\N
08066D	M.	Fauconnier	FAUCONNIER ALAIN	Alain	1945-02-20 00:00:00	\N	ANCIEN	Conseiller principal d'éducation	4200	64	SOC	SER	\N	CAE	CAE	120	Aveyron	\N	a.fauconnier@senat.fr	FAUCONNIER	NON	\N	\N	2017-10-04 09:46:36	\N
08055A	M.	Bérit-Débat	BERITDEBAT CLAUDE	Claude	1946-02-19 00:00:00	\N	ANCIEN	Cadre de CCI 	3600	39	SOC	SER	\N	CDD	CDD	240	Dordogne	\N	c.berit-debat@senat.fr	BÉRIT-DÉBAT	NON	\N	\N	2017-12-19 15:12:17	\N
08041T	Mme	Giudicelli	GIUDICELLI COLETTE	Colette	1943-11-24 00:00:00	2020-09-24 00:00:00	ANCIEN	Sans profession déclarée	8000	80	UMP	Les Républicains	\N	SOCI	SOCI	60	Alpes-Maritimes	\N	c.giudicelli@senat.fr	GIUDICELLI	NON	\N	\N	2017-10-09 16:22:55	\N
08029X	M.	Povinelli	POVINELLI	Roland	1941-08-09 00:00:00	2020-05-11 00:00:00	ANCIEN	Cadre administratif	3700	32	SOC	SER	\N	ETRD	ETRD	130	Bouches-du-Rhône	\N	r.povinelli@senat.fr	POVINELLI	NON	\N	\N	2017-10-04 09:46:36	\N
04078Q	M.	Hue	HUE ROBERT	Robert	1946-10-19 00:00:00	\N	ANCIEN	Infirmier	4300	47	RDSE	RDSE	\N	ETRD	ETRD	828	Val-d'Oise	\N	robert.hue-senat@wanadoo.fr	HUE	NON	\N	\N	2017-09-24 17:15:15	\N
14029X	Mme	Lanfranchi Dorgal	LANFRANCHI_DORGAL_Christine	Christine	1961-04-24 00:00:00	\N	ANCIEN	Attachée territoriale	3300	72	UMP	Les Républicains	-A	CDD	CDD	830	Var	\N	c.lanfranchi-dorgal@senat.fr	LANFRANCHI DORGAL	OUI	\N	2014-09-16 14:40:24	2017-10-09 16:22:55	\N
11033F	Mme	Benbassa	BENBASSA_ESTHER_11033F	Esther	1950-03-27 00:00:00	\N	ANCIEN	Professeure d'université	8000	61	NI	NI	N	LOIS	LOIS	615	Paris	Secrétaire du Sénat	e.benbassa@senat.fr	BENBASSA	OUI	\N	\N	2023-10-01 00:37:00	\N
14030Q	Mme	Billon	BILLON_ANNICK	Annick	1967-08-03 00:00:00	\N	ACTIF	Cadre commercial	8500	80	UC	UC	\N	AFCL	AFCL	850	Vendée	\N	a.billon@senat.fr	BILLON	OUI	319	2014-09-16 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/billon-annick.html
14089Y	M.	Bonnecarrère	BONNECARRÈRE_PHILIPPE	Philippe	1955-07-12 00:00:00	\N	ACTIF	Avocat	3100	57	UC	UC	\N	LOIS	LOIS	810	Tarn	\N	p.bonnecarrere@senat.fr	BONNECARRÈRE	NON	53	2014-09-18 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/bonnecarrere-philippe.html
14093U	M.	Bignon	BIGNON_Jerome	Jérôme	1949-01-01 00:00:00	\N	ANCIEN	Avocat	3121	51	RTLI	Les Indépendants	\N	CDD	CDD	800	Somme	\N	jerome@bignon.info	BIGNON	NON	\N	2014-09-18 11:20:52	2017-10-25 10:59:00	\N
14119M	M.	Morisset	MORISSET_Jean_Marie	Jean-Marie	1947-08-18 00:00:00	\N	ANCIEN	Directeur informatique	3000	32	UMP	Les Républicains	\N	SOCI	SOCI	790	Deux-Sèvres	\N	jm.morisset@senat.fr	MORISSET	NON	\N	2014-09-18 12:10:10	2017-10-09 16:22:55	\N
14199E	M.	Genest	GENEST_Jacques	Jacques	1950-08-06 00:00:00	\N	ANCIEN	Inspecteur du trésor	3300	71	UMP	Les Républicains	\N	FINC	FINC	70	Ardèche	\N	j.genest@senat.fr	GENEST	NON	\N	2014-09-28 14:31:41	2017-10-09 16:22:55	\N
14251Q	M.	Malhuret	MALHURET_CLAUDE	Claude	1950-03-08 00:00:00	\N	ACTIF	Médecin	7400	39	RTLI	Les Indépendants	\N	ETRD	ETRD	30	Allier	\N	c.malhuret@senat.fr	MALHURET	NON	256	2014-09-28 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/malhuret-claude.html
17023S	M.	Folliot	FOLLIOT_PHILIPPE	Philippe	1963-07-14 00:00:00	\N	ACTIF	\N	8500	80	UC	UC	\N	ETRD	ETRD	810	Tarn	\N	p.folliot@senat.fr	FOLLIOT	NON	321	2017-06-15 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/folliot-philippe.html
14363X	Mme	de Rose	ROSE	Marie-France	1943-04-25 00:00:00	\N	ANCIEN	\N	8000	80	UMP	Les Républicains	\N	AFCL	AFCL	335	Hauts-de-Seine	\N	mf.de-rose@senat.fr	de ROSE	NON	\N	2017-01-03 11:10:58	2017-10-09 16:22:55	\N
08044W	Mme	Joissains	JOISSAINS SOPHIE	Sophie	1969-10-25 00:00:00	\N	ANCIEN	Juriste criminologue	3100	32	UC	UC	\N	LOIS	LOIS	130	Bouches-du-Rhône	\N	s.joissains@senat.fr	JOISSAINS	NON	\N	\N	2017-09-18 14:58:50	\N
08032S	Mme	Klès	KLES VIRGINIE	Virginie	1961-08-18 00:00:00	\N	ANCIEN	Vétérinaire toxicologue	3300	46	SOC	SER	\N	LOIS	LOIS	350	Ille-et-Vilaine	\N	v.kles@senat.fr	KLÈS	NON	\N	\N	2017-10-04 09:46:36	\N
08054Y	Mme	Schurch	SCHURCH MIREILLE	Mireille	1949-01-04 00:00:00	\N	ANCIEN	Professeur de sciences physiques	3400	62	CRC	CRCE	\N	CAE	CAE	30	Allier	\N	m.schurch@senat.fr	SCHURCH	OUI	\N	\N	2017-10-04 09:44:06	\N
10001F	Mme	Labarre	LABARRE MARIE-AGNÈS	Marie-Agnès	1945-06-12 00:00:00	\N	ANCIEN	Ingénieur micro-biologiste	7000	47	CRC	CRCE	\N	AFCL	AFCL	265	Essonne	\N	ma.labarre@senat.fr	LABARRE	OUI	\N	\N	2017-10-04 09:44:06	\N
08074D	M.	Milhau	MILHAU JEAN	Jean	1929-12-18 00:00:00	\N	ANCIEN	Pharmacien 	7000	44	RDSE	RDSE	\N	ETRD	ETRD	460	Lot	\N	senateurmilhau@orange.fr	MILHAU	NON	\N	\N	\N	\N
08026U	Mme	Pasquet	PASQUET	Isabelle	1962-03-08 00:00:00	\N	ANCIEN	Agent de maîtrise à la SNCF	5400	32	CRC	CRCE	\N	SOCI	SOCI	130	Bouches-du-Rhône	\N	i.pasquet@senat.fr	PASQUET	OUI	\N	\N	2017-10-04 09:44:06	\N
12016W	M.	Lurel	LUREL VICTORIN	Victorin	1951-08-20 00:00:00	\N	ACTIF	\N	7000	79	SOC	SER	\N	FINC	FINC	971	Guadeloupe	\N	v.lurel@senat.fr	LUREL	NON	73	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/lurel-victorin.html
11109J	M.	Antiste	ANTISTE_MAURICE_C4745	Maurice	1953-06-22 00:00:00	\N	ANCIEN	Professeur de lettres	8000	69	SOC	SER	N	AFCL	AFCL	972	Martinique	\N	m.antiste@senat.fr	ANTISTE	NON	\N	\N	2023-10-01 00:37:00	\N
14043V	M.	Dubois	DUBOIS_Vincent	Vincent	1981-08-05 00:00:00	\N	ANCIEN	Avocat	3121	51	UC	UC	-A	LOIS	LOIS	983	Polynésie française	\N	v.dubois@senat.fr	DUBOIS	NON	\N	\N	2017-07-04 10:59:32	\N
14063N	M.	Manable	MANABLE_Christian	Christian	1948-06-19 00:00:00	\N	ANCIEN	Enseignant	3400	62	SOC	SER	\N	AFCL	AFCL	800	Somme	\N	c.manable@senat.fr	MANABLE	NON	\N	2014-09-17 17:28:03	2017-10-04 09:46:36	\N
14071N	M.	Mouiller	MOUILLER_PHILIPPE	Philippe	1969-09-20 00:00:00	\N	ACTIF	\N	3300	71	UMP	Les Républicains	\N	SOCI	SOCI	790	Deux-Sèvres	\N	p.mouiller@senat.fr	MOUILLER	NON	129	2014-09-17 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/mouiller-philippe.html
11049P	M.	Grosdidier	GROSDIDIER_FRANCOIS_11049P	François	1961-02-25 00:00:00	\N	ANCIEN	Fonctionnaire territorial	8000	71	UMP	Les Républicains	\N	LOIS	LOIS	570	Moselle	\N	f.grosdidier@senat.fr	GROSDIDIER	NON	\N	\N	2017-10-09 16:22:55	\N
11041F	M.	Vallini	VALLINI_ANDRE_11041F	André	1956-07-15 00:00:00	\N	ANCIEN	Avocat	8000	51	SOC	SER	N	ETRD	ETRD	380	Isère	\N	a.vallini@senat.fr	VALLINI	NON	\N	\N	2023-10-01 00:37:00	\N
04060E	Mme	Gousseau	GOUSSEAU ADELINE	Adeline	1936-08-24 00:00:00	\N	ANCIEN	Agricultrice retraitée	7100	10	UMP	Les Républicains	\N	ECON	ECON	895	Yvelines	\N	a.gousseau@senat.fr	GOUSSEAU	NON	\N	\N	2017-10-09 16:22:55	\N
04061F	Mme	Keller	KELLER FABIENNE	Fabienne	1959-10-20 00:00:00	\N	ANCIEN	Ingénieur	3800	71	NI	NI	\N	FINC	FINC	670	Bas-Rhin	\N	f.keller@senat.fr	KELLER	NON	\N	\N	2017-10-09 16:22:55	\N
08007R	M.	Brun	BRUN ELIE	Elie	1948-10-15 00:00:00	\N	ANCIEN	Avocat	3121	51	UMP	Les Républicains	\N	LOIS	LOIS	830	Var	\N	\N	BRUN	NON	\N	\N	2017-10-09 16:22:55	\N
04062G	M.	Ibrahim Ramadani	IBRAHIM RAMADANI SOIBAHADINE	Soibahadine	1949-03-05 00:00:00	\N	ANCIEN	Chargé de mission auprès du vice-recteur de Mayotte	4200	64	UMP	Les Républicains	\N	AFCL	AFCL	990	Mayotte	\N	s.ibrahim@senat.fr	IBRAHIM RAMADANI	NON	\N	\N	2017-10-09 16:22:55	\N
11042G	M.	Chiron	CHIRON_JACQUES_C4832	Jacques	1949-10-03 00:00:00	\N	ANCIEN	Agent de la DGCCRF	8000	73	SOC	SER	\N	FINC	FINC	380	Isère	\N	j.chiron@senat.fr	CHIRON	NON	\N	\N	2017-10-04 09:46:36	\N
04066L	M.	Caffet	CAFFET JEAN-PIERRE	Jean-Pierre	1951-11-08 00:00:00	\N	ANCIEN	Fonctionnaire	3300	71	LREM	RDPI	\N	SOCI	SOCI	615	Paris	Vice-président du Sénat	jp.caffet@senat.fr	CAFFET	NON	\N	\N	2017-10-04 09:45:01	\N
04067M	M.	Desessard	DESESSARD JEAN	Jean	1952-09-06 00:00:00	\N	ANCIEN	Directeur de centre socio-culturel	3600	32	NI	NI	\N	SOCI	SOCI	615	Paris	\N	j.desessard@senat.fr	DESESSARD	NON	\N	\N	2017-09-24 17:47:27	\N
04055H	M.	Dassault	DASSAULT SERGE	Serge	1925-04-04 00:00:00	2018-05-28 00:00:00	ANCIEN	Président-directeur général de sociétés	2300	21	UMP	Les Républicains	\N	FINC	FINC	265	Essonne	\N	\N	DASSAULT	NON	\N	\N	2018-05-30 15:10:56	\N
04069P	Mme	Sittler	SITTLER ESTHER	Esther	1952-05-09 00:00:00	\N	ANCIEN	Secrétaire administrative	5200	73	UMP	Les Républicains	\N	CDD	CDD	670	Bas-Rhin	\N	e.sittler@senat.fr	SITTLER	NON	\N	\N	2017-10-09 16:22:55	\N
04070G	Mme	Morin-Desailly	MORIN-DESAILLY CATHERINE	Catherine	1960-07-06 00:00:00	\N	ACTIF	Professeur d'anglais	3400	61	UC	UC	\N	AFCL	AFCL	760	Seine-Maritime	\N	c.morin-desailly@senat.fr	MORIN-DESAILLY	OUI	54	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/morin-desailly-catherine.html
04071H	M.	Dominati	DOMINATI PHILIPPE	Philippe	1954-04-12 00:00:00	\N	ANCIEN	Chef d'entreprise	2000	21	UMP	Les Républicains	A	FINC	FINC	615	Paris	\N	ph.dominati@senat.fr	DOMINATI	NON	\N	\N	2023-10-01 00:37:00	\N
04072J	M.	Goujon	GOUJON PHILIPPE	Philippe	1954-04-30 00:00:00	\N	ANCIEN	Cadre de société	3600	32	UMP	Les Républicains	\N	AFCL	AFCL	615	Paris	\N	p.goujon@senat.fr	GOUJON	NON	\N	\N	2017-10-09 16:22:55	\N
04073K	M.	Bordier	BORDIER PIERRE	Pierre	1945-06-21 00:00:00	\N	ANCIEN	Docteur vétérinaire	7300	46	UMP	Les Républicains	\N	AFCL	AFCL	890	Yonne	\N	p.bordier@senat.fr	BORDIER	NON	\N	\N	2017-10-09 16:22:55	\N
04075M	Mme	Hermange	HERMANGE MARIE-THÉRÈSE	Marie-Thérèse	1947-09-17 00:00:00	\N	ANCIEN	Sans profession déclarée	8000	80	UMP	Les Républicains	\N	SOCI	SOCI	615	Paris	\N	mt.hermange@senat.fr	HERMANGE	NON	\N	\N	2017-10-09 16:22:55	\N
04076N	Mme	Le Texier	LETEXIER RAYMONDE	Raymonde	1939-10-29 00:00:00	\N	ANCIEN	Assistante sociale	4300	73	SOC	SER	\N	SOCI	SOCI	828	Val-d'Oise	\N	r.letexier@senat.fr	LE TEXIER	OUI	\N	\N	2017-10-04 09:46:36	\N
04077P	Mme	Khiari	KHIARI BARIZA	Bariza	1946-09-03 00:00:00	\N	ANCIEN	Déléguée régionale au tourisme	3311	72	LREM	RDPI	\N	ETRD	ETRD	615	Paris	\N	b.khiari@senat.fr	KHIARI	OUI	\N	\N	2017-10-04 09:45:01	\N
14355X	Mme	Gerbaud	GERBAUD_FREDERIQUE	Frédérique	1959-07-03 00:00:00	\N	ACTIF	Chargée de communication	7400	39	UMP	Les Républicains	\N	SOCI	SOCI	360	Indre	\N	f.gerbaud@senat.fr	GERBAUD	OUI	343	2016-11-18 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/gerbaud-frederique.html
16685X	M.	Le Nay	LE_NAY_JACQUES	Jacques	1949-11-19 00:00:00	\N	ANCIEN	Ancien chef d'entreprise horticole	1000	10	UC	UC	N	ETRD	ETRD	560	Morbihan	\N	j.le-nay@senat.fr	LE NAY	NON	\N	2017-06-15 00:00:00	2023-10-01 00:37:00	\N
12028B	Mme	Carlotti	CARLOTTI MARIE-ARLETTE	Marie-Arlette	1952-01-21 00:00:00	\N	ACTIF	Retraitée	3700	32	SOC	SER	\N	ETRD	ETRD	130	Bouches-du-Rhône	Questeure du Sénat	ma.carlotti@senat.fr	CARLOTTI	OUI	18	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/carlotti-marie-arlette.html
16813M	M.	Poyart	Poyart_Alain	Alain	1947-11-18 00:00:00	\N	ANCIEN	\N	8000	80	UMP	Les Républicains	\N	LOIS	LOIS	590	Nord	\N	\N	POYART	NON	\N	2017-06-15 09:48:09	2017-10-09 16:22:56	\N
14357A	M.	Cuypers	CUYPERS_PIERRE	Pierre	1944-03-23 00:00:00	\N	ACTIF	Exploitant agricole	1000	10	UMP	Les Républicains	\N	CAE	CAE	770	Seine-et-Marne	\N	\N	CUYPERS	NON	275	2016-12-01 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/cuypers-pierre.html
11045K	Mme	Rossignol	ROSSIGNOL_LAURENCE_11045K	Laurence	1957-12-22 00:00:00	\N	ACTIF	Juriste	8000	57	SOC	SER	\N	SOCI	SOCI	824	Val-de-Marne	\N	l.rossignol@senat.fr	ROSSIGNOL	OUI	76	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/rossignol-laurence.html
11071M	M.	Soilihi	SOILIHI_ABDOURAHAMANE_C4750	Abdourahamane	1959-10-04 00:00:00	\N	ANCIEN	Enseignant	8000	63	UMP	Les Républicains	\N	AFCL	AFCL	990	Mayotte	\N	a.soilihi@senat.fr	SOILIHI	NON	\N	\N	2017-10-09 16:22:56	\N
14079W	M.	Danesi	DANESI_Rene	René	1947-08-30 00:00:00	\N	ANCIEN	\N	3800	31	UMP	Les Républicains	\N	ETRD	ETRD	680	Haut-Rhin	\N	r.danesi@senat.fr	DANESI	NON	\N	2014-09-17 18:06:24	2017-10-09 16:22:56	\N
14081Q	Mme	Guillemot	GUILLEMOT_Annie	Annie	1956-01-27 00:00:00	\N	ANCIEN	Ingénieur	3300	71	SOC	SER	\N	CAE	CAE	690	Rhône	Secrétaire du Sénat	a.guillemot@senat.fr	GUILLEMOT	OUI	\N	2014-09-17 18:10:27	2017-10-04 14:48:31	\N
14273W	M.	Masclet	MASCLET_PATRICK	Patrick	1952-05-31 00:00:00	2017-06-04 00:00:00	ANCIEN	Professeur agrégé	3400	61	UMP	Les Républicains	\N	LOIS	LOIS	590	Nord	\N	p.masclet@senat.fr	MASCLET	NON	\N	2015-04-22 16:49:30	2017-10-09 16:22:56	\N
11074Q	M.	Éblé	EBLE_VINCENT_11074Q	Vincent	1957-10-15 00:00:00	\N	ACTIF	Fonctionnaire territorial	3300	72	SOC	SER	\N	FINC	FINC	770	Seine-et-Marne	\N	v.eble@senat.fr	ÉBLÉ	NON	39	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/eble-vincent.html
11113E	M.	Desplan	DESPLAN_FELIX11113E	Félix	1943-02-22 00:00:00	\N	ANCIEN	Principal de collège	7000	62	LREM	RDPI	-A	LOIS	LOIS	971	Guadeloupe	\N	f.desplan@senat.fr	DESPLAN	NON	\N	\N	2017-10-04 09:45:01	\N
14026U	Mme	Gruny	GRUNY_PASCALE	Pascale	1960-02-18 00:00:00	\N	ACTIF	Directeur administratif et financier	3700	32	UMP	Les Républicains	\N	SOCI	SOCI	20	Aisne	\N	p.gruny@senat.fr	GRUNY	NON	28	2014-09-16 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/gruny-pascale.html
11068S	M.	Berson	BERSON_MICHEL_11068S	Michel	1945-04-21 00:00:00	2021-04-08 00:00:00	ANCIEN	Cadre dans le secteur bancaire	8000	32	LREM	RDPI	\N	FINC	FINC	265	Essonne	\N	m.berson@senat.fr	BERSON	NON	\N	\N	2017-10-04 09:45:01	\N
14269B	Mme	Yonnet	Yonnet_evelyne	Évelyne	1954-10-09 00:00:00	\N	ANCIEN	Cadre administratif	3300	72	SOC	SER	\N	SOCI	SOCI	775	Seine-Saint-Denis	\N	e.yonnet@senat.fr	YONNET	OUI	\N	2015-03-04 14:32:20	2017-10-04 09:46:36	\N
11063M	M.	Watrin	WATRIN_DOMINIQUE_11063M	Dominique	1953-06-14 00:00:00	\N	ANCIEN	\N	8000	39	CRC	CRCE	\N	SOCI	SOCI	620	Pas-de-Calais	\N	d.watrin@senat.fr	WATRIN	NON	\N	\N	2017-10-04 09:44:06	\N
12035A	Mme	Lipietz	LIPIETZ HÉLÈNE	Hélène	1958-05-07 00:00:00	\N	ANCIEN	Restauratrice-bouquiniste	2100	24	NI	NI	\N	NEANT	Aucune	770	Seine-et-Marne	\N	h.lipietz@senat.fr	LIPIETZ	OUI	\N	\N	2017-12-19 15:12:18	\N
11035H	M.	Delebarre	DELEBARRE_MICHEL_11035H	Michel	1946-04-27 00:00:00	2022-04-09 00:00:00	ANCIEN	Préfet	8000	73	SOC	SER	\N	LOIS	LOIS	590	Nord	\N	m.delebarre@senat.fr	DELEBARRE	NON	\N	\N	2017-10-04 09:46:36	\N
11031D	Mme	Cohen	COHEN_LAURENCE_11031D	Laurence	1953-01-15 00:00:00	\N	ANCIEN	Orthophoniste	8000	59	CRC	CRCE	N	SOCI	SOCI	824	Val-de-Marne	\N	l.cohen@senat.fr	COHEN	OUI	\N	\N	2023-10-01 00:37:00	\N
14051J	Mme	Tocqueville	TOCQUEVILLE_Nelly	Nelly	1950-05-02 00:00:00	\N	ANCIEN	\N	3400	62	SOC	SER	\N	CDD	CDD	760	Seine-Maritime	\N	n.tocqueville@senat.fr	TOCQUEVILLE	OUI	\N	2014-09-17 15:24:25	2017-10-04 09:46:36	\N
14055N	M.	Ravier	RAVIER_STEPHANE	Stéphane	1969-08-04 00:00:00	\N	ACTIF	Fonctionnaire	5400	33	NI	NI	\N	ETRD	ETRD	130	Bouches-du-Rhône	\N	s.ravier@senat.fr	RAVIER	NON	325	2014-09-17 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/ravier-stephane.html
14085U	M.	Carcenac	CARCENAC_Thierry	Thierry	1950-12-19 00:00:00	\N	ANCIEN	Directeur divisionnaire des Impôts	3300	71	SOC	SER	\N	FINC	FINC	810	Tarn	\N	t.carcenac@senat.fr	CARCENAC	NON	\N	2014-09-18 10:06:55	2017-10-04 18:42:04	\N
14087W	M.	Forissier	FORISSIER_Michel	Michel	1943-09-12 00:00:00	\N	ANCIEN	Chef d'entreprise	2300	21	UMP	Les Républicains	\N	SOCI	SOCI	690	Rhône	\N	m.forissier@senat.fr	FORISSIER	NON	\N	2014-09-18 10:43:52	2017-10-09 16:22:56	\N
14107H	M.	Roux	ROUX_JEAN_YVES	Jean-Yves	1970-01-18 00:00:00	\N	ACTIF	\N	7700	39	RDSE	RDSE	\N	CDD	CDD	40	Alpes de Haute-Provence	\N	jy.roux@senat.fr	ROUX	NON	156	2014-09-18 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/roux-jean-yves.html
14129P	M.	Dusserre	DUSSERRE_Jean_Yves	Jean-Yves	1953-01-01 00:00:00	2014-12-27 00:00:00	ANCIEN	Commerçant	2300	22	UMP	Les Républicains	\N	SOCI	SOCI	50	Hautes-Alpes	\N	jy.dusserre@senat.fr	DUSSERRE	NON	\N	2014-09-18 12:21:16	2017-10-09 16:22:56	\N
14193X	M.	Perrin	PERRIN_CEDRIC	Cédric	1974-01-20 00:00:00	\N	ACTIF	Juriste	7400	39	UMP	Les Républicains	\N	ETRD	ETRD	125	Territoire de Belfort	\N	cedric.perrin@senat.fr	PERRIN	NON	136	2014-09-28 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/perrin-cedric.html
14195A	M.	Chasseing	CHASSEING_DANIEL	Daniel	1945-04-10 00:00:00	\N	ACTIF	Médecin	3100	57	RTLI	Les Indépendants	\N	SOCI	SOCI	190	Corrèze	\N	d.chasseing@senat.fr	CHASSEING	NON	310	2014-09-28 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/chasseing-daniel.html
14197C	M.	Duran	DURAN_Alain	Alain	1958-01-02 00:00:00	\N	ANCIEN	Professeur des écoles	4200	63	SOC	SER	\N	CAE	CAE	90	Ariège	\N	a.duran@senat.fr	DURAN	NON	\N	2014-09-28 12:54:15	2017-10-04 09:46:36	\N
14253S	M.	Nougein	NOUGEIN_CLAUDE	Claude	1946-12-04 00:00:00	\N	ACTIF	Chef d'entreprise	7200	29	UMP	Les Républicains	\N	FINC	FINC	190	Corrèze	\N	c.nougein@senat.fr	NOUGEIN	NON	176	2014-09-28 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/nougein-claude.html
11025F	M.	Vergoz	VERGOZ_MICHEL_11025F	Michel	1950-01-10 00:00:00	\N	ANCIEN	Pharmacien	8000	44	LREM	RDPI	\N	SOCI	SOCI	974	La Réunion	\N	m.vergoz@senat.fr	VERGOZ	NON	\N	\N	2017-10-04 09:45:01	\N
17229F	M.	Demilly	DEMILLY_STEPHANE	Stéphane	1963-06-26 00:00:00	\N	ACTIF	Formateur	3100	57	UC	UC	\N	CDD	CDD	800	Somme	\N	s.demilly@senat.fr	DEMILLY	NON	7	2017-06-15 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/demilly-stephane.html
000092	M.	Guyot	GUYOT RAYMOND	Raymond	1903-11-17 00:00:00	1986-04-17 00:00:00	ANCIEN	Comptable	5400	33	C	C	\N	ETRD	ETRD	615	Paris	\N	\N	GUYOT	NON	\N	\N	\N	\N
11044J	Mme	Cayeux	CAYEUX_CAROLINE_11044J	Caroline	1948-11-01 00:00:00	\N	ANCIEN	Enseignante	8000	61	UMP	Les Républicains	\N	SOCI	SOCI	600	Oise	\N	c.cayeux@senat.fr	CAYEUX	NON	\N	\N	2017-10-09 16:22:56	\N
11081P	M.	Bertrand	BERTRAND_ALAIN_C4582	Alain	1951-02-23 00:00:00	2020-03-03 00:00:00	ANCIEN	Inspecteur des domaines	3300	79	RDSE	RDSE	\N	CAE	CAE	480	Lozère	\N	a.bertrand@senat.fr	BERTRAND	NON	\N	\N	2017-09-25 13:39:23	\N
11051H	M.	Dilain	DILAIN_CLAUDE_11051H	Claude	1948-08-12 00:00:00	2015-03-03 00:00:00	ANCIEN	Médecin	8000	42	SOC	SER	\N	SOCI	SOCI	775	Seine-Saint-Denis	Secrétaire du Sénat	c.dilain@senat.fr	DILAIN	NON	\N	\N	2017-10-04 09:46:36	\N
11076S	Mme	Aïchi	AICHI_LEILA_11076S	Leila	1970-05-14 00:00:00	\N	ANCIEN	Avocate	8000	51	UC	UC	\N	ETRD	ETRD	615	Paris	Vice-présidente du Sénat	l.aichi@senat.fr	AÏCHI	OUI	\N	\N	2017-09-24 17:47:27	\N
17367Q	M.	Blanc	BLANC_ETIENNE	Étienne	1954-08-29 00:00:00	\N	ACTIF	Avocat retraité	3100	57	UMP	Les Républicains	\N	ETRD	ETRD	690	Rhône	\N	e.blanc@senat.fr	BLANC	NON	344	2017-06-15 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/blanc-etienne.html
11072N	M.	Mohamed Soilihi	MOHAMED_SOILIHI_THANI_11072N	Thani	1972-06-20 00:00:00	\N	ACTIF	Avocat	8000	51	LREM	RDPI	\N	LOIS	LOIS	990	Mayotte	\N	t.mohamed-soilihi@senat.fr	MOHAMED SOILIHI	NON	2	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/mohamed-soilihi-thani.html
14053L	Mme	Canayer	CANAYER_AGNES	Agnès	1965-09-21 00:00:00	\N	ACTIF	\N	8500	80	UMP	Les Républicains	-R	LOIS	LOIS	760	Seine-Maritime	\N	a.canayer@senat.fr	CANAYER	NON	126	2014-09-17 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/canayer-agnes.html
14097Y	Mme	Jourda	JOURDA_GISELE	Gisèle	1955-03-24 00:00:00	\N	ACTIF	Cadre territorial	3300	71	SOC	SER	\N	ETRD	ETRD	110	Aude	\N	g.jourda@senat.fr	JOURDA	OUI	109	2014-09-18 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/jourda-gisele.html
14103D	M.	Luche	LUCHE_Jean_Claude	Jean-Claude	1952-08-07 00:00:00	\N	ANCIEN	Cadre bancaire	3000	32	UC	UC	\N	CDD	CDD	120	Aveyron	\N	jc.luche@senat.fr	LUCHE	NON	\N	2014-09-18 11:51:04	2017-10-04 18:56:22	\N
14111D	M.	Marc	MARC_ALAIN	Alain	1957-01-29 00:00:00	\N	ACTIF	Enseignant	7400	39	RTLI	Les Indépendants	\N	LOIS	LOIS	120	Aveyron	Vice-président du Sénat	a.marc@senat.fr	MARC	NON	313	2014-09-18 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/marc-alain.html
14115H	Mme	Bertrand	BERTRAND_Anne_Marie	Anne-Marie	1942-11-27 00:00:00	\N	ANCIEN	Exploitante agricole	1000	10	UMP	Les Républicains	\N	CAE	CAE	130	Bouches-du-Rhône	\N	am.bertrand@senat.fr	BERTRAND	NON	\N	2014-09-18 12:07:44	2017-10-09 16:22:56	\N
14133K	M.	Allizard	ALLIZARD_PASCAL	Pascal	1962-12-19 00:00:00	\N	ACTIF	Assistant parlementaire	3300	71	UMP	Les Républicains	\N	ETRD	ETRD	140	Calvados	\N	p.allizard@senat.fr	ALLIZARD	NON	57	2014-09-18 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/allizard-pascal.html
14137P	M.	Aubey	AUBEY_Francois	François	1960-09-20 00:00:00	\N	ANCIEN	Fonctionnaire territorial	3300	72	SOC	SER	\N	CDD	CDD	140	Calvados	\N	f.aubey@senat.fr	AUBEY	NON	\N	2014-09-18 14:45:10	2017-10-04 09:46:37	\N
14031R	M.	Mandelli	MANDELLI_DIDIER	Didier	1964-08-07 00:00:00	\N	ACTIF	\N	2300	21	UMP	Les Républicains	\N	CDD	CDD	850	Vendée	\N	d.mandelli@senat.fr	MANDELLI	NON	179	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/mandelli-didier.html
11026G	M.	Leconte	LECONTE_JEAN_YVES_11026G	Jean-Yves	1966-10-31 00:00:00	\N	ANCIEN	Ingénieur	8000	31	SOC	SER	N	LOIS	LOIS	1053	Français établis hors de France	\N	jy.leconte@senat.fr	LECONTE	NON	\N	\N	2023-10-01 00:37:00	\N
17583W	M.	Priou	Priou_Christophe	Christophe	1958-05-02 00:00:00	\N	ANCIEN	Cadre de la CCI de Saint-Nazaire	3700	32	UMP	Les Républicains	\N	SOCI	SOCI	440	Loire-Atlantique	\N	c.priou@senat.fr	PRIOU	NON	\N	2017-06-15 09:49:31	2017-10-09 16:22:56	\N
17589D	M.	Decool	DECOOL_JEAN_PIERRE	Jean-Pierre	1952-10-19 00:00:00	\N	ANCIEN	Ancien professeur	7000	69	RTLI	Les Indépendants	A	AFCL	AFCL	590	Nord	\N	jp.decool@senat.fr	DECOOL	NON	\N	2017-06-15 00:00:00	2023-10-01 00:37:00	\N
11091R	Mme	Duchêne	DUCHENE_MARIE_ANNICK_11091R	Marie-Annick	1940-08-23 00:00:00	\N	ANCIEN	Professeur de lettres classiques	8000	62	UMP	Les Républicains	-R	AFCL	AFCL	895	Yvelines	\N	ma.duchene@senat.fr	DUCHÊNE	NON	\N	\N	2017-10-09 16:22:56	\N
17637T	M.	Pemezec	PEMEZEC_PHILIPPE	Philippe	1955-09-25 00:00:00	\N	ANCIEN	\N	3000	35	UMP	Les Républicains	N	CDD	CDD	335	Hauts-de-Seine	\N	p.pemezec@senat.fr	PEMEZEC	NON	\N	2017-06-15 00:00:00	2023-10-01 00:37:00	\N
11098Y	M.	Le Scouarnec	LESCOUARNEC_MICHEL_C4640	Michel	1949-07-12 00:00:00	\N	ANCIEN	Professeur des écoles	4200	63	CRC	CRCE	\N	CAE	CAE	560	Morbihan	\N	m.le-scouarnec@senat.fr	LE SCOUARNEC	NON	\N	\N	2017-10-04 09:44:06	\N
14028W	Mme	Perol-Dumont	PEROL_DUMONT_Marie_Francoise	Marie-Françoise	1952-05-26 00:00:00	\N	ANCIEN	Professeure	3400	62	SOC	SER	\N	ETRD	ETRD	870	Haute-Vienne	\N	mf.perol-dumont@senat.fr	PEROL-DUMONT	OUI	\N	2014-09-16 11:27:36	2017-10-04 09:46:37	\N
14033T	M.	Gremillet	GREMILLET_DANIEL	Daniel	1953-07-31 00:00:00	\N	ACTIF	Agriculteur	7100	10	UMP	Les Républicains	\N	CAE	CAE	880	Vosges	\N	d.gremillet@senat.fr	GREMILLET	NON	284	2014-09-16 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/gremillet-daniel.html
14034U	M.	Gabouty	GABOUTY_Jean_Marc	Jean-Marc	1949-05-17 00:00:00	\N	ANCIEN	Chef d'entreprise	2000	21	RDSE	RDSE	\N	FINC	FINC	870	Haute-Vienne	Vice-président du Sénat	jm.gabouty@senat.fr	GABOUTY	NON	\N	2014-09-16 17:00:14	2017-10-04 19:50:36	\N
14159V	M.	Lalande	LALANDE_Bernard	Bernard	1954-04-06 00:00:00	\N	ANCIEN	Commissaire aux comptes et expert comptable	3128	57	SOC	SER	\N	FINC	FINC	170	Charente-Maritime	Questeur du Sénat	b.lalande@senat.fr	LALANDE	NON	\N	2014-09-18 18:03:58	2017-10-04 14:45:59	\N
14167V	M.	Boulard	BOULARD_Jean_Claude	Jean-Claude	1943-03-28 00:00:00	2018-05-31 00:00:00	ANCIEN	Conseiller d'État	3311	71	LREM	RDPI	\N	FINC	FINC	720	Sarthe	\N	jc.boulard@senat.fr	BOULARD	NON	\N	2014-09-22 10:54:02	2018-06-04 11:44:26	\N
14169X	M.	de Nicolaÿ	NICOLAY_DE_LOUIS_JEAN	Louis-Jean	1949-09-18 00:00:00	\N	ACTIF	Gérant de société	8600	80	UMP	Les Républicains	\N	CDD	CDD	720	Sarthe	\N	lj.de-nicolay@senat.fr	de NICOLAY	NON	99	2014-09-22 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/de-nicolay-louis-jean.html
14173T	M.	Vogel	VOGEL_JEAN_PIERRE	Jean Pierre	1956-08-07 00:00:00	\N	ACTIF	Expert comptable	3100	57	UMP	Les Républicains	\N	FINC	FINC	720	Sarthe	\N	jp.vogel@senat.fr	VOGEL	NON	233	2014-09-22 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/vogel-jean-pierre.html
14205J	Mme	Loisier	LOISIER_ANNE_CATHERINE	Anne-Catherine	1969-03-13 00:00:00	\N	ACTIF	Gestionnaire de forêts	3700	32	UC	UC	-R	CAE	CAE	210	Côte-d'Or	\N	ac.loisier@senat.fr	LOISIER	OUI	320	2014-09-28 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/loisier-anne-catherine.html
19725B	Mme	Harribey	HARRIBEY_LAURENCE	Laurence	1953-02-08 00:00:00	\N	ACTIF	Enseignante chercheur	7700	39	SOC	SER	\N	LOIS	LOIS	330	Gironde	\N	l.harribey@senat.fr	HARRIBEY	OUI	45	2017-10-01 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/harribey-laurence-9619.html
11056N	Mme	Cukierman	CUKIERMAN_CECILE_C4857	Cécile	1976-04-26 00:00:00	\N	ACTIF	Professeur d'histoire-géographie	3400	62	CRC	CRCE-K	\N	LOIS	LOIS	420	Loire	\N	c.cukierman@senat.fr	CUKIERMAN	OUI	103	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/cukierman-cecile.html
11057P	M.	Vincent	VINCENT_MAURICE_C4858	Maurice	1955-09-20 00:00:00	\N	ANCIEN	Professeur des universités	3400	61	LREM	RDPI	\N	FINC	FINC	420	Loire	\N	m.vincent@senat.fr	VINCENT	NON	\N	\N	2017-10-04 09:45:01	\N
11111C	M.	Lasserre	LASSERRE_JEAN_JACQUES_11111C	Jean-Jacques	1944-03-11 00:00:00	\N	ANCIEN	Agriculteur	8000	10	UC	UC	\N	CAE	CAE	640	Pyrénées-Atlantiques	\N	jj.lasserre@senat.fr	LASSERRE	NON	\N	\N	2017-09-24 16:45:26	\N
58636T	M.	Noe	NOE PIERRE	Pierre	1926-06-22 00:00:00	2014-08-20 00:00:00	ANCIEN	Ingénieur	3800	31	SOC	SER	\N	ECON	ECON	265	Essonne	\N	\N	NOE	NON	\N	\N	2017-10-04 09:46:37	\N
11037K	M.	Vandierendonck	VANDIERENDONCK_RENE_11037K	René	1951-04-01 00:00:00	\N	ANCIEN	Administrateur territorial	8000	71	SOC	SER	\N	LOIS	LOIS	590	Nord	\N	r.vandierendonck@senat.fr	VANDIERENDONCK	NON	\N	\N	2017-10-04 09:46:37	\N
11101A	M.	Calvet	CALVET_FRANCOIS_11101A	François	1953-04-01 00:00:00	\N	ANCIEN	Avocat	8000	80	UMP	Les Républicains	N	CDD	CDD	660	Pyrénées-Orientales	\N	f.calvet@senat.fr	CALVET	NON	\N	\N	2023-10-01 00:37:00	\N
11103C	M.	Cardoux	CARDOUX_JEAN_NOEL_11103C	Jean-Noël	1946-12-18 00:00:00	\N	ANCIEN	Expert comptable	8000	59	UMP	Les Républicains	N	SOCI	SOCI	450	Loiret	\N	jn.cardoux@senat.fr	CARDOUX	NON	\N	\N	2023-10-01 00:37:00	\N
11064N	M.	Guerriau	GUERRIAU_JOEL_C4907	Joël	1957-11-09 00:00:00	\N	ACTIF	Directeur général de banque	3000	32	RTLI	Les Indépendants	\N	ETRD	ETRD	440	Loire-Atlantique	Secrétaire du Sénat	j.guerriau@senat.fr	GUERRIAU	NON	309	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/guerriau-joel.html
11083R	M.	Gattolin	GATTOLIN_ANDRE_11083R	André	1960-06-24 00:00:00	\N	ANCIEN	Consultant	8000	57	LREM	RDPI	N	ETRD	ETRD	335	Hauts-de-Seine	\N	a.gattolin@senat.fr	GATTOLIN	NON	\N	\N	2023-10-01 00:37:00	\N
11084S	M.	Kaltenbach	KALTENBACH_PHILIPPE_11084S	Philippe	1966-01-09 00:00:00	\N	ANCIEN	Administrateur à Pôle Emploi	8000	73	SOC	SER	\N	LOIS	LOIS	335	Hauts-de-Seine	\N	p.kaltenbach@senat.fr	KALTENBACH	NON	\N	\N	2017-10-04 09:46:37	\N
11085T	M.	Marseille	MARSEILLE_HERVE_11085T	Hervé	1954-08-20 00:00:00	\N	ACTIF	Cadre	8000	81	UC	UC	\N	LOIS	LOIS	335	Hauts-de-Seine	\N	h.marseille@senat.fr	MARSEILLE	NON	122	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/marseille-herve.html
11104D	M.	Magner	MAGNER_JACQUES_BERNARD_C4674	Jacques-Bernard	1952-06-01 00:00:00	\N	ANCIEN	Professeur des écoles	8000	63	SOC	SER	N	AFCL	AFCL	630	Puy-de-Dôme	\N	jb.magner@senat.fr	MAGNER	NON	\N	\N	2023-10-01 00:37:00	\N
11105E	M.	Néri	NERI_ALAIN_C4673	Alain	1942-05-01 00:00:00	\N	ANCIEN	Directeur-adjoint de collège	7000	64	SOC	SER	\N	ETRD	ETRD	630	Puy-de-Dôme	\N	a.neri@senat.fr	NÉRI	NON	\N	\N	2017-10-04 09:46:37	\N
89028U	M.	Garcia	GARCIA	Aubert	1931-09-07 00:00:00	2000-02-21 00:00:00	ANCIEN	Médecin	3112	42	SOC	SER	\N	ECON	ECON	320	Gers	\N	\N	GARCIA	NON	\N	\N	2017-10-04 09:46:37	\N
95052H	M.	Pastor	PASTOR	Jean-Marc	1950-02-12 00:00:00	\N	ANCIEN	Agriculteur	1000	10	SOC	SER	\N	ETRD	ETRD	810	Tarn	\N	j-m.pastor@wanadoo.fr	PASTOR	NON	\N	\N	2017-10-04 09:46:37	\N
59536U	M.	Goetschy	GOETSCHY HENRI	Henri	1926-09-04 00:00:00	2021-04-17 00:00:00	ANCIEN	Vétérinaire	3115	46	UC	UC	\N	FINC	FINC	680	Haut-Rhin	\N	\N	GOETSCHY	NON	\N	\N	2017-07-04 10:59:32	\N
92039X	M.	Miquel	MIQUEL	Gérard	1946-06-17 00:00:00	\N	ANCIEN	Agriculteur	1000	10	LREM	RDPI	\N	CDD	CDD	460	Lot	\N	g.miquel@senat.fr	MIQUEL	NON	\N	\N	2017-10-04 09:45:01	\N
11082Q	M.	Namy	NAMY_CHRISTIAN_C4633	Christian	1938-10-19 00:00:00	\N	ANCIEN	Consultant d'entreprises	3000	57	UC	UC	\N	ETRD	ETRD	550	Meuse	\N	c.namy@senat.fr	NAMY	NON	\N	\N	2017-09-24 19:16:18	\N
000307	M.	Pic	PIC MAURICE	Maurice	1913-02-15 00:00:00	1991-01-30 00:00:00	ANCIEN	Professeur de l' enseignement secondaire	4200	62	SOC	SER	\N	AFCL	AFCL	260	Drôme	\N	\N	PIC	NON	\N	\N	2017-10-04 09:46:37	\N
000470	M.	Pouille	POUILLE RICHARD	Richard	1921-08-15 00:00:00	1996-07-21 00:00:00	ANCIEN	Ingénieur	7300	39	UREI	U.R.E.I.	\N	ECON	ECON	540	Meurthe-et-Moselle	\N	\N	POUILLE	NON	\N	\N	\N	\N
11011M	M.	Vendegou	VENDEGOU HILARION	Hilarion	1941-09-04 00:00:00	2020-01-11 00:00:00	ANCIEN	Instituteur	8000	63	UMP	Les Républicains	\N	AFCL	AFCL	982	Nouvelle-Calédonie	\N	\N	VENDEGOU	NON	\N	\N	2017-10-09 16:22:56	\N
000694	M.	Peschaud	PESCHAUD HECTOR	Hector	1895-12-07 00:00:00	1968-09-21 00:00:00	ANCIEN	Médecin	3112	42	CNIP	C.N.I.P.	\N	AFCL	AFCL	150	Cantal	\N	\N	PESCHAUD	NON	\N	\N	2016-12-06 18:24:55	\N
000065	M.	Minard	MINARD FRANÇOIS	François	1902-05-05 00:00:00	1974-06-22 00:00:00	ANCIEN	Agriculteur	1000	10	SOC	SER	\N	AFCL	AFCL	30	Allier	\N	\N	MINARD	NON	\N	\N	2017-10-04 09:46:37	\N
14327T	M.	Delcros	DELCROS_BERNARD	Bernard	1953-02-12 00:00:00	\N	ACTIF	Enseignant	3400	61	UC	UC	\N	FINC	FINC	150	Cantal	\N	b.delcros@senat.fr	DELCROS	NON	27	2015-09-07 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/delcros-bernard.html
14331P	M.	Rapin	RAPIN JEAN FRANCOIS	Jean-François	1966-05-11 00:00:00	\N	ACTIF	Médecin généraliste	3112	42	UMP	Les Républicains	\N	FINC	FINC	620	Pas-de-Calais	\N	jf.rapin@senat.fr	RAPIN	NON	172	2016-01-12 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/rapin-jean-francois.html
17737W	Mme	Boyer	BOYER_VALERIE	Valérie	1962-06-11 00:00:00	\N	ACTIF	Cadre de santé	3300	71	UMP	Les Républicains	\N	ETRD	ETRD	130	Bouches-du-Rhône	\N	v.boyer@senat.fr	BOYER	OUI	174	2017-06-15 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/boyer-valerie.html
11067R	Mme	Meunier	MEUNIER_MICHELLE_11067R	Michelle	1956-01-24 00:00:00	\N	ANCIEN	Educatrice de jeunes enfants	8000	64	SOC	SER	N	SOCI	SOCI	440	Loire-Atlantique	\N	m.meunier@senat.fr	MEUNIER	OUI	\N	\N	2023-10-01 00:37:00	\N
19721W	M.	Cazabonne	CAZABONNE_ALAIN	Alain	1944-08-25 00:00:00	\N	ACTIF	Ancien gérant de société	8600	80	UC	UC	\N	ETRD	ETRD	330	Gironde	\N	a.cazabonne@senat.fr	CAZABONNE	NON	259	2017-10-01 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/cazabonne-alain.html
19723Y	Mme	Lassarade	LASSARADE_FLORENCE	Florence	1957-08-18 00:00:00	\N	ACTIF	Pédiatre	3100	57	UMP	Les Républicains	\N	SOCI	SOCI	330	Gironde	\N	f.lassarade@senat.fr	LASSARADE	OUI	290	2017-10-01 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/lassarade-florence.html
11077T	Mme	Lienemann	LIENEMANN_MARIE_NOELLE_11077T	Marie-Noëlle	1951-07-12 00:00:00	\N	ANCIEN	Professeur de l'Education nationale	8000	69	CRC	CRCE	R	CAE	CAE	615	Paris	\N	mn.lienemann@senat.fr	LIENEMANN	OUI	\N	\N	2023-10-01 00:37:00	\N
83025Q	M.	Dejoie	DEJOIE	Luc	1931-02-06 00:00:00	2006-01-21 00:00:00	ANCIEN	Notaire	3128	52	RPR	RPR	\N	LOIS	LOIS	440	Loire-Atlantique	\N	\N	DEJOIE	NON	\N	\N	\N	\N
11080N	M.	Charon	CHARON_PIERRE_11080N	Pierre	1951-03-01 00:00:00	\N	ANCIEN	Consultant en communication	8000	29	UMP	Les Républicains	N	ETRD	ETRD	615	Paris	\N	p.charon@senat.fr	CHARON	NON	\N	\N	2023-10-01 00:37:00	\N
11096W	M.	Esnol	ESNOL_PHILIPPE_11096W	Philippe	1954-04-02 00:00:00	\N	ANCIEN	Cadre supérieur	3000	32	RDSE	RDSE	\N	ETRD	ETRD	895	Yvelines	\N	p.esnol@senat.fr	ESNOL	NON	\N	\N	2017-09-24 18:17:56	\N
11097X	M.	Savary	SAVARY_RENE_PAUL_11097X	René-Paul	1953-01-03 00:00:00	\N	ANCIEN	Médecin	8000	42	UMP	Les Républicains	N	SOCI	SOCI	510	Marne	\N	rp.savary@senat.fr	SAVARY	NON	\N	\N	2023-10-01 00:37:00	\N
11100Y	M.	Lenoir	LENOIR_JEAN_CLAUDE_11100Y	Jean-Claude	1944-12-27 00:00:00	\N	ANCIEN	\N	8000	32	UMP	Les Républicains	\N	CAE	CAE	610	Orne	\N	jc.lenoir@senat.fr	LENOIR	NON	\N	\N	2017-10-09 16:22:56	\N
17779H	Mme	Lubin	LUBIN_MONIQUE	Monique	1963-07-16 00:00:00	\N	ACTIF	Collaboratrice parlementaire	4600	35	SOC	SER	\N	SOCI	SOCI	400	Landes	\N	m.lubin@senat.fr	LUBIN	OUI	241	2017-06-15 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/lubin-monique-5645.html
11053K	M.	Capo-Canellas	CAPO_CANELLAS_VINCENT_11053K	Vincent	1967-05-04 00:00:00	\N	ACTIF	Fonctionnaire territorial	8000	32	UC	UC	\N	FINC	FINC	775	Seine-Saint-Denis	\N	v.capo-canellas@senat.fr	CAPO-CANELLAS	NON	120	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/capo-canellas-vincent.html
11054L	M.	Roger	ROGER_GILBERT_11054L	Gilbert	1953-11-09 00:00:00	\N	ANCIEN	Maître-nageur sauveteur	8000	39	SOC	SER	N	ETRD	ETRD	775	Seine-Saint-Denis	\N	g.roger@senat.fr	ROGER	NON	\N	\N	2023-10-01 00:37:00	\N
11055M	Mme	Archimbaud	ARCHIMBAUD_ALINE_C5635	Aline	1948-11-02 00:00:00	\N	ANCIEN	Enseignante	8000	62	NI	NI	\N	SOCI	SOCI	775	Seine-Saint-Denis	\N	a.archimbaud@senat.fr	ARCHIMBAUD	OUI	\N	\N	2017-09-24 18:07:56	\N
11066Q	M.	Vaugrenard	VAUGRENARD_YANNICK_11066Q	Yannick	1950-06-25 00:00:00	\N	ANCIEN	Cadre bancaire	8000	39	SOC	SER	N	ETRD	ETRD	440	Loire-Atlantique	\N	y.vaugrenard@senat.fr	VAUGRENARD	NON	\N	\N	2023-10-01 00:37:00	\N
11070L	M.	Delahaye	DELAHAYE_VINCENT_11070L	Vincent	1959-08-23 00:00:00	\N	ACTIF	Expert comptable	8000	57	UC	UC	\N	FINC	FINC	265	Essonne	\N	v.delahaye@senat.fr	DELAHAYE	NON	209	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/delahaye-vincent.html
11110B	Mme	Espagnac	ESPAGNAC_FREDERIQUE_C4700	Frédérique	1972-04-19 00:00:00	\N	ACTIF	Cadre	8000	32	SOC	SER	\N	FINC	FINC	640	Pyrénées-Atlantiques	\N	f.espagnac@senat.fr	ESPAGNAC	OUI	243	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/espagnac-frederique.html
11112D	M.	Labazée	LABAZEE_GEORGES_11112D	Georges	1943-06-16 00:00:00	2022-02-03 00:00:00	ANCIEN	Professeur des écoles	8000	63	SOC	SER	\N	SOCI	SOCI	640	Pyrénées-Atlantiques	\N	g.labazee@senat.fr	LABAZÉE	NON	\N	\N	2017-10-04 09:46:37	\N
11088W	M.	Delattre	DELATTRE_FRANCIS_11088W	Francis	1946-09-11 00:00:00	\N	ANCIEN	Attaché principal d'administration	8000	72	UMP	Les Républicains	\N	FINC	FINC	828	Val-d'Oise	\N	f.delattre@senat.fr	DELATTRE	NON	\N	\N	2017-10-09 16:22:56	\N
11089X	Mme	Gillot	GILLOT DOMINIQUE_C5752	Dominique	1949-07-11 00:00:00	\N	ANCIEN	Enseignante	8000	63	SOC	SER	\N	AFCL	AFCL	828	Val-d'Oise	\N	d.gillot@senat.fr	GILLOT	OUI	\N	\N	2017-10-04 09:46:37	\N
11099A	M.	Labbé	LABBE_JOEL_C4641	Joël	1952-10-18 00:00:00	\N	ANCIEN	Assistant technique de laboratoire	8000	72	GEST	GEST	N	CAE	CAE	560	Morbihan	\N	j.labbe@senat.fr	LABBÉ	NON	\N	\N	2023-10-01 00:37:00	\N
11094U	M.	Tandonnet	TANDONNET_HENRI_C4575	Henri	1949-12-14 00:00:00	\N	ANCIEN	Avoué à la cour	8000	51	UC	UC	\N	CAE	CAE	470	Lot-et-Garonne	\N	h.tandonnet@senat.fr	TANDONNET	NON	\N	\N	2017-09-24 13:25:54	\N
11095V	M.	Camani	CAMANI_PIERRE_11095V	Pierre	1952-02-19 00:00:00	\N	ANCIEN	Cadre de la fonction publique territoriale	8000	71	SOC	SER	\N	CDD	CDD	470	Lot-et-Garonne	\N	p.camani@senat.fr	CAMANI	NON	\N	\N	2017-10-04 09:46:37	\N
11108H	M.	Germain	GERMAIN_JEAN_11108H	Jean	1947-09-11 00:00:00	2015-04-07 00:00:00	ANCIEN	Inspecteur général de l'Education nationale	8000	79	SOC	SER	\N	FINC	FINC	370	Indre-et-Loire	\N	j.germain@senat.fr	GERMAIN	NON	\N	\N	2017-10-04 09:46:37	\N
11046L	M.	Rome	ROME_YVES_11046L	Yves	1950-04-25 00:00:00	\N	ANCIEN	Conseiller en formation continue	8000	64	LREM	RDPI	\N	CAE	CAE	600	Oise	\N	y.rome@senat.fr	ROME	NON	\N	\N	2017-10-04 09:45:01	\N
14039A	M.	Karam	KARAM_Antoine	Antoine	1950-02-21 00:00:00	\N	ANCIEN	Professeur d'histoire	4200	63	LREM	RDPI	-A	AFCL	AFCL	973	Guyane	\N	a.karam@senat.fr	KARAM	NON	\N	2014-09-17 11:52:59	2017-10-04 18:43:22	\N
14041T	Mme	Deromedi	DEROMEDI_JACKY	Jacky	1944-06-15 00:00:00	\N	ANCIEN	Administrateur de sociétés	2300	21	UMP	Les Républicains	\N	LOIS	LOIS	1054	Français établis hors de France	\N	j.deromedi@senat.fr	DEROMEDI	NON	\N	2014-09-17 12:07:53	2017-10-09 16:22:56	\N
14042U	Mme	Doineau	DOINEAU_ELISABETH	Élisabeth	1961-04-07 00:00:00	\N	ACTIF	\N	8000	80	UC	UC	\N	SOCI	SOCI	530	Mayenne	\N	e.doineau@senat.fr	DOINEAU	OUI	262	2014-09-17 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/doineau-elisabeth.html
14044W	Mme	Iriti	IRITI_Teura	Teura	1965-01-07 00:00:00	\N	ANCIEN	Représentante de l'Assemblée de Polynésie	4300	35	UC	UC	-A	FINC	FINC	983	Polynésie française	\N	t.iriti@senat.fr	IRITI	OUI	\N	2014-09-17 12:17:04	2017-07-04 10:59:32	\N
14147R	Mme	Mercier	MERCIER_MARIE	Marie	1958-06-16 00:00:00	\N	ACTIF	Médecin	3100	42	UMP	Les Républicains	\N	LOIS	LOIS	710	Saône-et-Loire	\N	marie.mercier@senat.fr	MERCIER	NON	221	2014-09-18 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/mercier-marie.html
14151M	M.	Durain	DURAIN_JEROME	Jérôme	1969-06-02 00:00:00	\N	ACTIF	Fonctionnaire	3300	71	SOC	SER	\N	LOIS	LOIS	710	Saône-et-Loire	\N	j.durain@senat.fr	DURAIN	NON	43	2014-09-18 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/durain-jerome.html
14157T	M.	Vaspart	VASPART_Michel	Michel	1948-02-22 00:00:00	\N	ANCIEN	Chef d'entreprise	2000	21	UMP	Les Républicains	\N	CDD	CDD	220	Côtes-d'Armor	\N	m.vaspart@senat.fr	VASPART	NON	\N	2014-09-18 17:34:14	2017-10-09 16:22:56	\N
14261S	M.	Arnell	ARNELL_Guillaume	Guillaume	1958-01-20 00:00:00	\N	ANCIEN	Cadre administratif	3300	47	RDSE	RDSE	\N	SOCI	SOCI	9715	Saint-Martin	\N	g.arnell@senat.fr	ARNELL	NON	\N	2014-09-29 09:03:10	2017-10-04 18:53:19	\N
11106F	M.	Lorgeoux	LORGEOUX_JEANNY_11106F	Jeanny	1950-01-02 00:00:00	\N	ANCIEN	Directeur de développement	8000	32	SOC	SER	\N	ETRD	ETRD	410	Loir-et-Cher	\N	j.lorgeoux@senat.fr	LORGEOUX	NON	\N	\N	2017-10-04 09:46:37	\N
13002U	M.	Poher	POHER HERVÉ	Hervé	1952-05-19 00:00:00	\N	ANCIEN	Médecin généraliste	3112	42	SOC	SER	\N	CDD	CDD	620	Pas-de-Calais	\N	h.poher@senat.fr	POHER	NON	\N	\N	2017-10-04 09:46:37	\N
11065P	M.	Dantec	DANTEC_RONAN_11065P	Ronan	1963-08-05 00:00:00	\N	ACTIF	Auteur	3115	57	GEST	GEST	\N	CDD	CDD	440	Loire-Atlantique	\N	r.dantec@senat.fr	DANTEC	NON	302	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/dantec-ronan.html
12038D	M.	Vairetto	VAIRETTO ANDRÉ	André	1960-01-20 00:00:00	\N	ANCIEN	Attaché parlementaire	4500	35	SOC	SER	\N	CDD	CDD	730	Savoie	\N	\N	VAIRETTO	NON	\N	\N	2017-10-04 09:46:37	\N
14037X	M.	Lemoyne	LEMOYNE_Jean_Baptiste	Jean-Baptiste	1977-09-15 00:00:00	\N	ACTIF	\N	3300	71	LREM	RDPI	\N	ETRD	ETRD	890	Yonne	\N	jb.lemoyne@senat.fr	LEMOYNE	NON	21	2014-09-17 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/lemoyne-jean-baptiste.html
14038Y	M.	Chaize	CHAIZE_PATRICK	Patrick	1963-03-22 00:00:00	\N	ACTIF	Directeur de syndicat intercommunal	8500	80	UMP	Les Républicains	\N	CAE	CAE	10	Ain	\N	p.chaize@senat.fr	CHAIZE	NON	291	2014-09-17 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/chaize-patrick.html
14059S	Mme	Lopez	LOPEZ_VIVETTE	Vivette	1954-12-27 00:00:00	\N	ACTIF	Auditrice IHEDN	7400	39	UMP	Les Républicains	\N	ETRD	ETRD	300	Gard	\N	v.lopez@senat.fr	LOPEZ	NON	331	2014-09-17 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/lopez-vivette.html
14061L	M.	Kennel	KENNEL_Guy_Dominique	Guy-Dominique	1952-04-14 00:00:00	\N	ANCIEN	Inspecteur de l'Éducation nationale	3311	64	UMP	Les Républicains	\N	AFCL	AFCL	670	Bas-Rhin	Secrétaire du Sénat	gd.kennel@senat.fr	KENNEL	NON	\N	2014-09-17 17:22:51	2017-10-09 16:22:57	\N
14065Q	M.	Bigot	BIGOT_Jacques	Jacques	1952-07-31 00:00:00	\N	ANCIEN	Avocat	3121	51	SOC	SER	\N	LOIS	LOIS	670	Bas-Rhin	\N	jacques.bigot@senat.fr	BIGOT	NON	\N	2014-09-17 17:31:07	2017-10-23 15:13:03	\N
14073Q	M.	Kern	KERN_CLAUDE	Claude	1959-03-13 00:00:00	\N	ACTIF	\N	3400	61	UC	UC	\N	AFCL	AFCL	670	Bas-Rhin	\N	c.kern@senat.fr	KERN	NON	263	2014-09-17 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/kern-claude.html
14187A	Mme	Estrosi Sassone	ESTROSI_SASSONE_DOMINIQUE	Dominique	1958-11-14 00:00:00	\N	ACTIF	Fonctionnaire territoriale	8600	80	UMP	Les Républicains	\N	CAE	CAE	60	Alpes-Maritimes	\N	d.estrosi-sassone@senat.fr	ESTROSI SASSONE	NON	128	2014-09-26 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/estrosi-sassone-dominique.html
14189C	M.	Arnaud	ARNAUD_JEAN_MICHEL	Jean-Michel	1966-04-28 00:00:00	\N	ACTIF	Exploitant agricole	1100	10	UC	UC	\N	LOIS	LOIS	50	Hautes-Alpes	Secrétaire du Sénat	jm.arnaud@senat.fr	ARNAUD	NON	207	2014-09-26 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/arnaud-jean-michel.html
14233N	Mme	Jean	JEAN_Genevieve	Geneviève	1945-08-28 00:00:00	\N	ANCIEN	éducatrice spécialisée	3112	47	SOC	SER	\N	CDD	CDD	840	Vaucluse	\N	g.jean@senat.fr	JEAN	OUI	\N	2014-09-28 17:35:38	2017-10-04 09:46:37	\N
14235Q	Mme	Prunaud	PRUNAUD_Christine	Christine	1950-09-04 00:00:00	\N	ANCIEN	Agent d'assurance	4500	33	CRC	CRCE	\N	ETRD	ETRD	220	Côtes-d'Armor	\N	c.prunaud@senat.fr	PRUNAUD	OUI	\N	2014-09-28 17:38:25	2017-10-04 18:55:41	\N
14247U	M.	Rachline	RACHLINE_David	David	1987-12-02 00:00:00	\N	ANCIEN	\N	8000	80	NI	NI	\N	CDD	CDD	830	Var	\N	d.rachline@senat.fr	RACHLINE	NON	\N	2014-09-28 18:03:38	2017-10-01 10:25:16	\N
12042Y	Mme	Émery-Dumas	EMERY-DUMAS ANNE	Anne	1959-08-30 00:00:00	\N	ANCIEN	\N	8000	80	LREM	RDPI	\N	SOCI	SOCI	580	Nièvre	\N	\N	ÉMERY-DUMAS	OUI	\N	\N	2017-10-04 09:45:01	\N
11069T	M.	Placé	PLACE_JEAN_VINCENT_11069T	Jean-Vincent	1968-03-12 00:00:00	\N	ANCIEN	Directeur de centre de formation	8000	32	SOC	SER	\N	ETRD	ETRD	265	Essonne	\N	jv.place@senat.fr	PLACÉ	NON	\N	\N	2017-10-04 09:46:37	\N
11107G	M.	Filleul	FILLEUL_JEAN_JACQUES_11107G	Jean-Jacques	1943-06-22 00:00:00	\N	ANCIEN	Chargé de mission dans un laboratoire pharmaceutique	8000	32	LREM	RDPI	\N	CDD	CDD	370	Indre-et-Loire	\N	jj.filleul@senat.fr	FILLEUL	NON	\N	\N	2017-10-04 09:45:24	\N
11090Q	Mme	Primas	PRIMAS_SOPHIE_11090Q	Sophie	1962-06-07 00:00:00	\N	ACTIF	Directrice commerciale	8000	32	UMP	Les Républicains	\N	CAE	CAE	895	Yvelines	Vice-président du Sénat	s.primas@senat.fr	PRIMAS	NON	130	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/primas-sophie.html
11093T	M.	Roche	ROCHE_GERARD_11093T	Gérard	1942-12-29 00:00:00	\N	ANCIEN	Médecin	8000	42	UC	UC	\N	SOCI	SOCI	430	Haute-Loire	\N	g.roche@senat.fr	ROCHE	NON	\N	\N	2017-09-24 12:57:09	\N
12040W	Mme	Ango Ela	ANGO ELA KALLIOPI	Kalliopi	1962-09-24 00:00:00	\N	ANCIEN	Professeure agrégée de géographie	3400	61	ECO	Écologiste	\N	ETRD	ETRD	1053	Français établis hors de France	\N	k.ango-ela@senat.fr	ANGO ELA	OUI	\N	\N	2015-07-09 16:26:54	\N
12039E	M.	Mazars	MAZARS STÉPHANE	Stéphane	1969-03-25 00:00:00	\N	ANCIEN	\N	3121	51	RDSE	RDSE	\N	CDD	CDD	120	Aveyron	\N	s.mazars@senat.fr	MAZARS	NON	\N	\N	2017-06-19 09:39:27	\N
000121	M.	Courbatere	COURBATERE ROGER	Roger	1905-05-09 00:00:00	1998-02-16 00:00:00	ANCIEN	Artisan-décorateur	2100	24	GD	G.D.	\N	SOCI	SOCI	190	Corrèze	\N	\N	COURBATERE	NON	\N	\N	\N	\N
58649Y	M.	Dagonia	DAGONIA GEORGES	Georges	1930-12-09 00:00:00	2007-09-29 00:00:00	ANCIEN	Médecin	3112	42	SOC	SER	\N	SOCI	SOCI	971	Guadeloupe	Secrétaire du Sénat	\N	DAGONIA	NON	\N	\N	2017-10-04 09:46:37	\N
000213	M.	Kientzi	KIENTZI ARMAND	Armand	1909-06-22 00:00:00	1980-12-30 00:00:00	ANCIEN	Avocat	3121	51	UCDP	U.C.D.P.	\N	ETRD	ETRD	670	Bas-Rhin	\N	\N	KIENTZI	NON	\N	\N	2016-12-01 10:48:02	\N
000206	M.	Lejeune	LEJEUNE MAX	Max	1909-02-19 00:00:00	1995-11-23 00:00:00	ANCIEN	Professeur	4200	62	RDE	R.D.E.	\N	ETRD	ETRD	800	Somme	\N	\N	LEJEUNE	NON	\N	\N	2017-12-19 15:12:18	\N
000005	M.	Lhospied	LHOSPIED JEAN	Jean	1900-02-11 00:00:00	1983-05-25 00:00:00	ANCIEN	Directeur de journal	7300	54	SOC	SER	\N	ETRD	ETRD	580	Nièvre	\N	\N	LHOSPIED	NON	\N	\N	2017-10-04 09:46:38	\N
86001U	M.	Dessaigne	DESSAIGNE GEORGES	Georges	1925-08-29 00:00:00	2018-05-21 00:00:00	ANCIEN	Industriel	2300	21	UC	UC	\N	SOCI	SOCI	530	Mayenne	\N	\N	DESSAIGNE	NON	\N	\N	2018-05-23 11:11:23	\N
98010K	M.	Plancade	PLANCADE	Jean-Pierre	1949-08-02 00:00:00	\N	ANCIEN	Cadre du secteur social	8000	32	RDSE	RDSE	\N	AFCL	AFCL	310	Haute-Garonne	\N	jp.plancade@senat.fr	PLANCADE	NON	\N	\N	2014-10-07 15:54:49	\N
000764	M.	Emaille	EMAILLE JULES	Jules	1880-09-27 00:00:00	1966-09-26 00:00:00	ANCIEN	Industriel	2300	21	RP	RP	\N	AFCL	AFCL	590	Nord	\N	\N	EMAILLE	NON	\N	\N	\N	\N
000718	M.	Boucher	BOUCHER ALBERT	Albert	1888-11-13 00:00:00	1965-03-02 00:00:00	ANCIEN	Agriculteur	1000	10	RI	RI	\N	ECON	ECON	440	Loire-Atlantique	\N	\N	BOUCHER	NON	\N	\N	\N	\N
000722	Mme	Cardot	CARDOT MARIE-HÉLÈNE	Marie-Hélène	1899-07-14 00:00:00	1977-08-13 00:00:00	ANCIEN	Industriel	2300	21	UC	UC	\N	SOCI	SOCI	80	Ardennes	\N	\N	CARDOT	NON	\N	\N	2017-07-04 10:59:33	\N
000743	M.	Rabouin	RABOUIN ETIENNE	Etienne	1893-11-20 00:00:00	1979-11-24 00:00:00	ANCIEN	Notaire	3128	52	UNR	U.N.R.	\N	LOIS	LOIS	490	Maine-et-Loire	\N	\N	RABOUIN	NON	\N	\N	\N	\N
000069	M.	Molle	MOLLE MARCEL	Marcel	1902-10-12 00:00:00	1995-03-27 00:00:00	ANCIEN	Notaire	3128	52	CRARS	CRARS	\N	LOIS	LOIS	70	Ardèche	\N	\N	MOLLE	NON	\N	\N	\N	\N
000096	M.	Noury	NOURY JEAN	Jean	1904-02-19 00:00:00	1983-05-30 00:00:00	ANCIEN	Industriel	2300	21	UCDP	U.C.D.P.	\N	AFCL	AFCL	350	Ille-et-Vilaine	Secrétaire du Sénat	\N	NOURY	NON	\N	\N	\N	\N
000521	M.	Parmantier	PARMANTIER BERNARD	Bernard	1924-02-05 00:00:00	1993-11-22 00:00:00	ANCIEN	Directeur de Centre d'information et d'orientation	3600	32	SOC	SER	\N	FINC	FINC	615	Paris	\N	\N	PARMANTIER	NON	\N	\N	2017-10-04 09:46:38	\N
92043T	M.	Sergent	SERGENT	Michel	1943-12-27 00:00:00	\N	ANCIEN	Instituteur	4200	63	SOC	SER	\N	FINC	FINC	620	Pas-de-Calais	\N	sergent.michel@wanadoo.fr	SERGENT	NON	\N	\N	2017-10-04 09:46:38	\N
96006F	M.	Piras	PIRAS	Bernard	1942-06-05 00:00:00	2016-02-01 00:00:00	ANCIEN	Ingénieur agricole	1000	73	SOC	SER	\N	ETRD	ETRD	260	Drôme	\N	bernard.piras@wanadoo.fr	PIRAS	NON	\N	\N	2017-10-04 09:46:38	\N
000700	M.	de Geoffre de Chabrignac	GEOFFRE DE CHABRIGNAC JEAN	Jean	1889-11-08 00:00:00	1971-03-14 00:00:00	ANCIEN	Agriculteur	1000	10	UNR	U.N.R.	\N	ECON	ECON	490	Maine-et-Loire	\N	\N	de GEOFFRE de CHABRIGNAC	NON	\N	\N	\N	\N
000054	M.	Beguere	BEGUERE ANTOINE	Antoine	1901-09-29 00:00:00	1960-10-23 00:00:00	ANCIEN	Entrepreneur de travaux publics	2300	21	RI	RI	\N	SOCI	SOCI	650	Hautes-Pyrénées	\N	\N	BEGUERE	NON	\N	\N	\N	\N
000072	M.	de La Vasselais	LAVASSELAIS GUY DE	Guy	1902-12-05 00:00:00	1976-07-20 00:00:00	ANCIEN	Propriétaire-exploitant agricole	1000	10	NI	NI	\N	ETRD	ETRD	280	Eure-et-Loir	\N	\N	de LA VASSELAIS	NON	\N	\N	2015-02-10 12:00:26	\N
000611	M.	Male	MALE GUY	Guy	1930-07-01 00:00:00	1987-12-03 00:00:00	ANCIEN	Directeur technique	3600	32	UC	UC	\N	LOIS	LOIS	660	Pyrénées-Orientales	\N	\N	MALE	NON	\N	\N	2017-07-04 10:59:33	\N
59540Q	M.	Jung	JUNG LOUIS	Louis	1917-02-18 00:00:00	2015-10-22 00:00:00	ANCIEN	Directeur de société	2300	21	UC	UC	\N	ETRD	ETRD	670	Bas-Rhin	\N	\N	JUNG	NON	\N	\N	2017-07-04 10:59:33	\N
13001T	Mme	Masson-Maret	MASSONMARET HÉLÈNE	Hélène	1947-04-04 00:00:00	\N	ANCIEN	Professeur des universités	3400	63	UMP	Les Républicains	\N	CDD	CDD	60	Alpes-Maritimes	\N	\N	MASSON-MARET	NON	\N	\N	2017-10-09 16:22:57	\N
59218H	M.	Boileau	BOILEAU ROGER	Roger	1914-06-01 00:00:00	2001-09-12 00:00:00	ANCIEN	Pharmacien	3116	44	UC	UC	\N	AFCL	AFCL	540	Meurthe-et-Moselle	\N	\N	BOILEAU	NON	\N	\N	2017-07-04 10:59:33	\N
000328	M.	Boulangé	BOULANGE MARCEL	Marcel	1913-11-23 00:00:00	1995-05-29 00:00:00	ANCIEN	Attaché de préfecture	4500	72	SOC	SER	\N	ETRD	ETRD	125	Territoire de Belfort	\N	\N	BOULANGÉ	NON	\N	\N	2017-10-04 09:46:38	\N
000036	M.	Bethouart	BETHOUART ANTOINE	Antoine	1889-12-17 00:00:00	1982-10-17 00:00:00	ANCIEN	Militaire (Général d'armée)	5300	74	UCDP	U.C.D.P.	\N	ETRD	ETRD	997	Français établis hors de France	\N	\N	BETHOUART	NON	\N	\N	2016-08-08 17:59:12	\N
000146	M.	Aubert	AUBERT EMILE	Emile	1906-07-23 00:00:00	1969-08-22 00:00:00	ANCIEN	Industriel	2300	21	SOC	SER	\N	ECON	ECON	1011	Basses-Alpes	\N	\N	AUBERT	NON	\N	\N	2017-10-04 09:46:38	\N
000049	M.	Bruyas	BRUYAS FLORIAN	Florian	1901-07-26 00:00:00	1974-10-22 00:00:00	ANCIEN	Négociant	2200	23	RI	RI	\N	AFCL	AFCL	690	Rhône	\N	\N	BRUYAS	NON	\N	\N	\N	\N
000038	M.	Champleboux	CHAMPLEBOUX MICHEL	Michel	1901-03-27 00:00:00	1967-03-08 00:00:00	ANCIEN	Ingénieur électricien	3800	31	SOC	SER	\N	ECON	ECON	630	Puy-de-Dôme	\N	\N	CHAMPLEBOUX	NON	\N	\N	2017-10-04 09:46:38	\N
000067	M.	Gros	GROS LOUIS	Louis	1902-05-18 00:00:00	1984-10-08 00:00:00	ANCIEN	Avocat	3121	51	RI	RI	\N	SOCI	SOCI	998	Français établis hors de France	Vice-président du Sénat	\N	GROS	NON	\N	\N	2014-10-09 15:54:29	\N
000063	M.	Lafleur	LAFLEUR HENRI	Henri	1902-04-18 00:00:00	1974-10-13 00:00:00	ANCIEN	Industriel	2300	21	UREI	U.R.E.I.	\N	AFCL	AFCL	982	Nouvelle-Calédonie	\N	\N	LAFLEUR	NON	\N	\N	2015-02-10 12:00:26	\N
57129Y	M.	Laurens	LAURENS ROBERT	Robert	1910-09-26 00:00:00	2005-09-20 00:00:00	ANCIEN	Agriculteur	1000	10	RI	RI	\N	ECON	ECON	120	Aveyron	\N	\N	LAURENS	NON	\N	\N	2016-12-01 18:01:43	\N
87003B	M.	Dufaut	DUFAUT	Alain	1944-01-02 00:00:00	\N	ANCIEN	Géomètre expert DPLG	3100	57	UMP	Les Républicains	\N	AFCL	AFCL	840	Vaucluse	\N	alain.dufaut@orange.fr	DUFAUT	NON	\N	\N	2017-11-09 15:23:42	\N
000046	M.	Fleury	FLEURY JEAN	Jean	1901-07-08 00:00:00	1985-10-20 00:00:00	ANCIEN	Ingénieur	3800	31	RPR	RPR	\N	AFCL	AFCL	335	Hauts-de-Seine	\N	\N	FLEURY	NON	\N	\N	\N	\N
000143	M.	Pinsard	PINSARD JULES	Jules	1906-04-09 00:00:00	1991-12-09 00:00:00	ANCIEN	Viticulteur	1000	10	GD	G.D.	\N	ECON	ECON	710	Saône-et-Loire	\N	\N	PINSARD	NON	\N	\N	\N	\N
57321W	M.	Pisani	PISANI EDGARD	Edgard	1918-10-09 00:00:00	2016-06-20 00:00:00	ANCIEN	Ancien Préfet	7400	79	SOC	SER	\N	ETRD	ETRD	520	Haute-Marne	\N	\N	PISANI	NON	\N	\N	2017-10-04 09:46:38	\N
000188	M.	Delorme	DELORME CLAUDIUS	Claudius	1908-01-21 00:00:00	1980-09-03 00:00:00	ANCIEN	Agriculteur	1000	10	RIAS	R.I.A.S.	\N	AFCL	AFCL	690	Rhône	\N	\N	DELORME	NON	\N	\N	\N	\N
000184	M.	Bouneau	BOUNEAU PIERRE	Pierre	1908-04-23 00:00:00	1995-05-29 00:00:00	ANCIEN	Chef d'entreprise	2300	21	NI	NI	\N	SOCI	SOCI	400	Landes	\N	\N	BOUNEAU	NON	\N	\N	\N	\N
000011	M.	Dulin	DULIN ANDRÉ	André	1900-04-12 00:00:00	1973-03-05 00:00:00	ANCIEN	Président de l'association centrale des laiteries coopératives des Charentes et du Poitou	1000	10	GD	G.D.	\N	FINC	FINC	170	Charente-Maritime	\N	\N	DULIN	NON	\N	\N	2017-12-19 15:12:17	\N
000770	M.	Verneuil	VERNEUIL JACQUES	Jacques	1899-09-29 00:00:00	1982-03-09 00:00:00	ANCIEN	Ingénieur agricole, agriculteur	1000	10	GDSRG	G.D.S.R.G.	\N	SOCI	SOCI	170	Charente-Maritime	\N	\N	VERNEUIL	NON	\N	\N	\N	\N
000709	M.	Dassaud	DASSAUD FRANCIS	Francis	1895-07-11 00:00:00	1965-11-17 00:00:00	ANCIEN	Mécanicien	6000	34	SOC	SER	\N	SOCI	SOCI	630	Puy-de-Dôme	\N	\N	DASSAUD	NON	\N	\N	2017-10-04 09:46:38	\N
000711	M.	Berthoin	BERTHOIN JEAN	Jean	1895-01-12 00:00:00	1979-02-25 00:00:00	ANCIEN	Ancien secrétaire général du ministère de l'intérieur, ancien payeur général de la Seine	3311	71	GD	G.D.	\N	ETRD	ETRD	380	Isère	\N	\N	BERTHOIN	NON	\N	\N	\N	\N
000688	M.	Parisot	PARISOT HENRI	Henri	1895-09-05 00:00:00	1984-06-03 00:00:00	ANCIEN	Négociant	2200	23	RI	RI	\N	ETRD	ETRD	880	Vosges	\N	\N	PARISOT	NON	\N	\N	2015-02-10 12:00:26	\N
000739	M.	Petit	PETIT ERNEST	Ernest	1888-02-20 00:00:00	1971-05-28 00:00:00	ANCIEN	Général en retraite	7400	79	C	C	-A	ETRD	ETRD	1029	Seine	\N	\N	PETIT	NON	\N	\N	\N	\N
59219J	M.	Bouquerel	BOUQUEREL AMÉDÉE	Amédée	1908-07-01 00:00:00	2002-04-26 00:00:00	ANCIEN	Ingénieur des travaux publics de l'Etat honoraire	7400	79	RPR	RPR	\N	ETRD	ETRD	600	Oise	Questeur du Sénat	\N	BOUQUEREL	NON	\N	\N	2015-02-10 12:00:26	\N
000145	M.	Motais de Narbonne	MOTAIS DE NARBONNE LÉON	Léon	1906-06-21 00:00:00	1971-08-10 00:00:00	ANCIEN	Avocat	3121	51	UCDP	U.C.D.P.	\N	ETRD	ETRD	999	Français établis hors de France	\N	\N	MOTAIS de NARBONNE	NON	\N	\N	2015-02-10 12:00:26	\N
000008	M.	Perdereau	PERDEREAU LUCIEN	Lucien	1900-02-25 00:00:00	1975-05-01 00:00:00	ANCIEN	Agriculteur	1000	10	CRARS	CRARS	\N	SOCI	SOCI	450	Loiret	\N	\N	PERDEREAU	NON	\N	\N	\N	\N
000767	M.	de Maupeou	MAUPEOU 	Jacques	1899-12-28 00:00:00	1963-01-22 00:00:00	ANCIEN	Propriétaire-exploitant agricole	1000	10	RI	RI	\N	AFCL	AFCL	850	Vendée	\N	\N	de MAUPEOU	NON	\N	\N	2015-02-10 12:00:26	\N
000733	M.	Baratgin	BARATGIN PAUL	Paul	1890-12-17 00:00:00	1966-12-22 00:00:00	ANCIEN	Médecin	3112	42	GD	G.D.	\N	LOIS	LOIS	650	Hautes-Pyrénées	Questeur du Sénat	\N	BARATGIN	NON	\N	\N	\N	\N
000720	M.	Esteve	ESTEVE YVES	Yves	1899-02-14 00:00:00	1986-12-21 00:00:00	ANCIEN	Notaire	3128	52	RPR	RPR	\N	LOIS	LOIS	350	Ille-et-Vilaine	\N	\N	ESTEVE	NON	\N	\N	2015-02-10 12:00:26	\N
58923X	M.	Ciccolini	CICCOLINI FÉLIX	Félix	1916-10-02 00:00:00	2010-05-01 00:00:00	ANCIEN	Avocat	3121	51	SOC	SER	\N	LOIS	LOIS	130	Bouches-du-Rhône	Vice-président du Sénat	\N	CICCOLINI	NON	\N	\N	2017-10-04 09:46:38	\N
14201E	M.	Castelli	CASTELLI_Joseph	Joseph	1948-06-04 00:00:00	\N	ANCIEN	\N	2000	21	RDSE	RDSE	\N	AFCL	AFCL	205	Haute-Corse	\N	j.castelli@senat.fr	CASTELLI	NON	\N	2014-09-28 15:43:32	2017-09-18 14:58:56	\N
59552U	Mme	Missoffe	MISSOFFE HÉLÈNE	Hélène	1927-06-15 00:00:00	2015-01-22 00:00:00	ANCIEN	Sans profession déclarée	8000	80	RPR	RPR	\N	SOCI	SOCI	828	Val-d'Oise	\N	\N	MISSOFFE	NON	\N	\N	2017-06-15 09:46:25	\N
000437	M.	Orvoen	ORVOEN LOUIS	Louis	1919-12-09 00:00:00	1994-09-21 00:00:00	ANCIEN	Agriculteur	1000	10	UC	UC	\N	ECON	ECON	290	Finistère	\N	\N	ORVOEN	NON	\N	\N	2017-07-04 10:59:33	\N
80045G	M.	Torre	TORRE	Henri	1933-04-12 00:00:00	\N	ANCIEN	Sans profession déclarée	8000	80	UMP	Les Républicains	\N	FINC	FINC	70	Ardèche	\N	\N	TORRE	NON	\N	\N	2017-10-09 16:22:57	\N
000059	M.	Maillols	MAILLOLS SYLVAIN	Sylvain	1901-12-16 00:00:00	1988-01-20 00:00:00	ANCIEN	Sans profession déclarée	8000	80	RPR	RPR	\N	AFCL	AFCL	660	Pyrénées-Orientales	\N	\N	MAILLOLS	NON	\N	\N	\N	\N
14191V	M.	Panunzi	PANUNZI_JEAN_JACQUES	Jean-Jacques	1956-04-05 00:00:00	\N	ACTIF	Attaché d'administration	7200	29	UMP	Les Républicains	-A	ETRD	ETRD	200	Corse-du-Sud	\N	jj.panunzi@senat.fr	PANUNZI	NON	138	2014-09-28 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/panunzi-jean-jacques.html
01005J	M.	Blanc	BLANC JACQUES	Jacques	1939-10-21 00:00:00	\N	ANCIEN	Médecin neuro-psychiatre	8000	42	UMP	Les Républicains	\N	ETRD	ETRD	480	Lozère	\N	jacques.blanc@senat.fr	BLANC	NON	\N	\N	2017-10-09 16:22:57	\N
04036E	Mme	Kammermann	KAMMERMANNCHRISTIANE	Christiane	1932-07-10 00:00:00	\N	ANCIEN	Sans profession déclarée	8000	80	UMP	Les Républicains	\N	ETRD	ETRD	1053	Français établis hors de France	\N	c.kammermann@senat.fr	KAMMERMANN	NON	\N	\N	2017-10-09 16:22:57	\N
95042F	M.	Lachenaud	LACHENAUD	Jean-Philippe	1939-11-22 00:00:00	\N	ANCIEN	Conseiller maître à la Cour des comptes	3311	71	UMP	Les Républicains	\N	FINC	FINC	828	Val-d'Oise	\N	\N	LACHENAUD	NON	\N	\N	2017-10-09 16:22:57	\N
13005X	Mme	Gaouyer	GAOUYER MARIE-FRANÇOISE	Marie-Françoise	1949-08-17 00:00:00	\N	ANCIEN	Infirmière	4300	47	SOC	SER	\N	CDD	CDD	760	Seine-Maritime	\N	mf.gaouyer@senat.fr	GAOUYER	OUI	\N	2013-10-01 15:12:05	2017-10-04 09:46:38	\N
000285	M.	Bergeal	BERGEAL AIMÉ	Aimé	1912-01-11 00:00:00	1973-09-26 00:00:00	ANCIEN	Inspecteur central des Postes et télécommunications	4500	72	SOC	SER	\N	ECON	ECON	895	Yvelines	\N	\N	BERGEAL	NON	\N	\N	2017-10-04 09:46:38	\N
000765	M.	Grangier	GRANGIER EDOUARD	Edouard	1899-07-28 00:00:00	1997-03-27 00:00:00	ANCIEN	Chef de bataillon (infanterie de marine)	5300	74	GD	G.D.	\N	ETRD	ETRD	840	Vaucluse	\N	\N	GRANGIER	NON	\N	\N	2016-10-13 15:50:41	\N
000758	M.	Lalloy	LALLOY MAURICE	Maurice	1896-11-25 00:00:00	1985-12-19 00:00:00	ANCIEN	Ingenieur Général du Génie Rural	4500	72	RPR	RPR	-R	ECON	ECON	770	Seine-et-Marne	\N	\N	LALLOY	NON	\N	\N	\N	\N
98042T	M.	Dupont	DUPONT JEAN-LEONCE	Jean-Léonce	1955-01-31 00:00:00	\N	ANCIEN	Directeur d'école de commerce international	8000	64	UC	UC	\N	AFCL	AFCL	140	Calvados	Questeur du Sénat	jl.dupont@senat.fr	DUPONT	NON	\N	\N	2017-10-01 10:39:22	\N
000058	M.	Cogniot	COGNIOT GEORGES	Georges	1901-12-15 00:00:00	1978-03-12 00:00:00	ANCIEN	Professeur agrégé	4200	62	C	C	\N	AFCL	AFCL	615	Paris	\N	\N	COGNIOT	NON	\N	\N	\N	\N
000178	M.	Poignant	POIGNANT FERNAND	Fernand	1908-02-24 00:00:00	1988-12-20 00:00:00	ANCIEN	Professeur Honoraire	7400	69	SOC	SER	-R	AFCL	AFCL	720	Sarthe	\N	\N	POIGNANT	NON	\N	\N	2017-10-04 09:46:38	\N
89006N	M.	Lesbros	LESBROS	Marcel	1921-09-09 00:00:00	2007-01-25 00:00:00	ANCIEN	Médecin	3112	42	UMP	Les Républicains	\N	SOCI	SOCI	50	Hautes-Alpes	\N	m.lesbros@senat.fr	LESBROS	NON	\N	\N	2017-10-09 16:22:57	\N
000004	M.	du Luart	LUART LADISLAS (DU)	Ladislas	1900-02-05 00:00:00	1980-02-14 00:00:00	ANCIEN	Propriétaire exploitant, agricole et forestier	1000	10	RIAS	R.I.A.S.	\N	ETRD	ETRD	720	Sarthe	\N	\N	du LUART	NON	\N	\N	\N	\N
02005N	M.	Mortemousque	MORTEMOUSQUE	Dominique	1950-06-02 00:00:00	2022-05-07 00:00:00	ANCIEN	Agriculteur	1000	10	UMP	Les Républicains	\N	ECON	ECON	240	Dordogne	\N	d.mortemousque@senat.fr	MORTEMOUSQUE	NON	\N	\N	2017-10-09 16:22:57	\N
86050E	M.	de Villepin	VILLEPIN XAVIER (DE)	Xavier	1926-03-14 00:00:00	2014-10-29 00:00:00	ANCIEN	Industriel	2300	21	UMP	Les Républicains	\N	ETRD	ETRD	999	Français établis hors de France	\N	\N	de VILLEPIN	NON	\N	\N	2017-10-09 16:22:57	\N
14083S	M.	Canévet	CANEVET_Michel	Michel	1960-12-14 00:00:00	\N	ACTIF	Responsable de collectivités	3700	32	UC	UC	\N	FINC	FINC	290	Finistère	\N	m.canevet@senat.fr	CANÉVET	NON	264	2014-09-18 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/canevet-michel.html
14105F	M.	Bouchet	BOUCHET_GILBERT	Gilbert	1947-01-08 00:00:00	\N	ACTIF	Hôtelier	7200	29	UMP	Les Républicains	\N	ETRD	ETRD	260	Drôme	\N	g.bouchet@senat.fr	BOUCHET	NON	333	2014-09-18 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/bouchet-gilbert.html
000300	M.	Sassi	SASSI BENAISSA	Benaissa	1912-11-11 00:00:00	1961-07-18 00:00:00	ANCIEN	Propriétaire	1000	10	GD	G.D.	-R	ETRD	ETRD	1044	Mostaganem-Tiaret	\N	\N	SASSI	NON	\N	\N	\N	\N
01042P	M.	Lecerf	LECERF	Jean-René	1951-04-10 00:00:00	\N	ANCIEN	Enseignant du supérieur	8000	61	UMP	Les Républicains	\N	LOIS	LOIS	590	Nord	\N	jr.lecerf@senat.fr	LECERF	NON	\N	\N	2017-10-09 16:22:57	\N
01033N	Mme	Henneron	HENNERON	Françoise	1948-02-03 00:00:00	\N	ANCIEN	Secrétaire	8000	33	UMP	Les Républicains	\N	SOCI	SOCI	620	Pas-de-Calais	\N	f.henneron@senat.fr	HENNERON	NON	\N	\N	2017-10-09 16:22:57	\N
11012A	M.	Requier	REQUIER_JEAN_CLAUDE_C4565	Jean-Claude	1947-10-04 00:00:00	\N	ANCIEN	Professeur d'histoire-géographie	8000	69	RDSE	RDSE	N	FINC	FINC	460	Lot	\N	senateur-requier@orange.fr	REQUIER	NON	\N	\N	2023-10-01 00:37:00	\N
07027R	M.	Muller	MULLER JACQUES	Jacques	1954-10-30 00:00:00	\N	ANCIEN	Ingénieur du génie rural, des eaux et forêts	3300	73	SOC	SER	-R	ECON	ECON	680	Haut-Rhin	\N	j.muller@senat.fr	MULLER	NON	\N	\N	2017-10-04 09:46:38	\N
08073C	M.	Patient	PATIENT GEORGES	Georges	1949-04-01 00:00:00	\N	ACTIF	Consultant financier	3700	32	LREM	RDPI	\N	FINC	FINC	973	Guyane	\N	g.patient@senat.fr	PATIENT	NON	46	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/patient-georges.html
000268	M.	de Tinguy du Pouet	TINGUY DU POUET LIONEL (DE)	Lionel	1911-04-06 00:00:00	1981-09-09 00:00:00	ANCIEN	Conseiller d'Etat	3311	71	UCDP	U.C.D.P.	\N	LOIS	LOIS	850	Vendée	\N	\N	de TINGUY du POUET	NON	\N	\N	\N	\N
000013	M.	Belhabich	BELHABICH SLIMAN	Sliman	1900-05-15 00:00:00	1977-08-14 00:00:00	ANCIEN	Militaire (Lieutenant-colonel)	5300	74	UNR	U.N.R.	\N	SOCI	SOCI	1030	Oran-Tlemcen	\N	\N	BELHABICH	NON	\N	\N	2015-02-10 12:00:26	\N
58026W	M.	Moreau	MOREAU HENRI	Henri	1915-06-24 00:00:00	2004-02-01 00:00:00	ANCIEN	Vétérinaire	3115	46	GD	G.D.	\N	SOCI	SOCI	170	Charente-Maritime	\N	\N	MOREAU	NON	\N	\N	\N	\N
13003V	Mme	Boog	BOOG FRANÇOISE	Françoise	1960-08-02 00:00:00	\N	ANCIEN	Secrétaire médicale	8000	33	UMP	Les Républicains	\N	SOCI	SOCI	680	Haut-Rhin	\N	f.boog@senat.fr	BOOG	NON	\N	2013-07-01 09:35:33	2017-10-09 16:22:57	\N
04059M	M.	Assouline	ASSOULINE DAVID	David	1959-06-16 00:00:00	\N	ANCIEN	Professeur d'histoire-géographie	3400	62	SOC	SER	N	AFCL	AFCL	615	Paris	\N	d.assouline@senat.fr	ASSOULINE	NON	\N	\N	2023-10-01 00:37:00	\N
04084N	M.	Michel	MICHELJEAN-PIERRE	Jean-Pierre	1938-08-05 00:00:00	2021-01-24 00:00:00	ANCIEN	Magistrat	3313	56	SOC	SER	\N	LOIS	LOIS	700	Haute-Saône	\N	jp.michel@senat.fr	MICHEL	NON	\N	\N	2017-10-04 09:46:38	\N
04082L	Mme	Voynet	VOYNET DOMINIQUE	Dominique	1958-11-04 00:00:00	\N	ANCIEN	Consultante	3112	42	SOC	SER	-R	ETRD	ETRD	775	Seine-Saint-Denis	\N	d.voynet@senat.fr	VOYNET	OUI	\N	\N	2017-10-04 09:46:38	\N
11114F	M.	Cornano	CORNANO_JACQUES_11114F	Jacques	1956-11-18 00:00:00	\N	ANCIEN	Professeur de génie électrique	8000	62	LREM	RDPI	\N	CDD	CDD	971	Guadeloupe	\N	j.cornano@senat.fr	CORNANO	NON	\N	\N	2017-10-04 09:45:01	\N
14018U	Mme	Malherbe	MALHERBE_HERMELINE	Hermeline	1969-02-18 00:00:00	\N	ANCIEN	\N	8000	80	RDSE	RDSE	\N	SOCI	SOCI	660	Pyrénées-Orientales	\N	h.malherbe@senat.fr	MALHERBE	OUI	\N	2014-08-27 16:32:46	2017-09-24 18:49:56	\N
14021P	M.	Kanner	KANNER_PATRICK	Patrick	1957-04-29 00:00:00	\N	ACTIF	Administrateur territorial	3300	71	SOC	SER	\N	AFCL	AFCL	590	Nord	\N	p.kanner@senat.fr	KANNER	NON	77	2014-08-27 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/kanner-patrick.html
14109K	Mme	Monier	MONIER_MARIE_PIERRE	Marie-Pierre	1958-02-28 00:00:00	\N	ACTIF	Professeur	7400	39	SOC	SER	\N	AFCL	AFCL	260	Drôme	\N	mp.monier@senat.fr	MONIER	OUI	146	2014-09-18 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/monier-marie-pierre.html
14121F	M.	Jeansannetas	JEANSANNETAS_ÉRIC	Éric	1962-10-21 00:00:00	\N	ACTIF	Professeur des écoles	4200	63	SOC	SER	\N	FINC	FINC	230	Creuse	\N	e.jeansannetas@senat.fr	JEANSANNETAS	NON	244	2014-09-18 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/jeansannetas-eric.html
14123H	M.	Grosperrin	GROSPERRIN_JACQUES	Jacques	1955-10-17 00:00:00	\N	ACTIF	Professeur agrégé	7400	39	UMP	Les Républicains	\N	AFCL	AFCL	250	Doubs	\N	j.grosperrin@senat.fr	GROSPERRIN	NON	62	2014-09-18 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/grosperrin-jacques.html
14207L	M.	Cabanel	CABANEL_HENRI	Henri	1959-03-09 00:00:00	\N	ACTIF	Viticulteur	1200	10	RDSE	RDSE	\N	CAE	CAE	340	Hérault	\N	h.cabanel@senat.fr	CABANEL	NON	82	2014-09-28 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/cabanel-henri.html
14209N	M.	Commeinhes	COMMEINHES_Francois	François	1949-11-10 00:00:00	\N	ANCIEN	Médecin gynécologue	3431	43	UMP	Les Républicains	\N	AFCL	AFCL	340	Hérault	\N	f.commeinhes@senat.fr	COMMEINHES	NON	\N	2014-09-28 17:03:41	2017-10-09 16:22:57	\N
14211G	M.	Grand	GRAND_JEAN_PIERRE	Jean-Pierre	1950-11-18 00:00:00	\N	ACTIF	Cadre de la fonction publique	7400	39	RTLI	Les Indépendants	\N	ETRD	ETRD	340	Hérault	\N	jp.grand@senat.fr	GRAND	NON	202	2014-09-28 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/grand-jean-pierre.html
14255U	M.	Cadic	CADIC_OLIVIER	Olivier	1962-04-22 00:00:00	\N	ACTIF	Chef d'entreprise	2300	21	UC	UC	\N	ETRD	ETRD	1054	Français établis hors de France	\N	o.cadic@senat.fr	CADIC	NON	163	2014-09-28 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/cadic-olivier.html
11062L	Mme	Duriez	DURIEZ_ODETTE_11062L	Odette	1948-05-07 00:00:00	\N	ANCIEN	Comptable	8000	33	SOC	SER	\N	SOCI	SOCI	620	Pas-de-Calais	\N	\N	DURIEZ	OUI	\N	\N	2017-10-04 09:46:38	\N
14257W	M.	Montaugé	MONTAUGE_FRANCK	Franck	1961-09-14 00:00:00	\N	ACTIF	Ingénieur	3800	31	SOC	SER	\N	CAE	CAE	320	Gers	\N	f.montauge@senat.fr	MONTAUGÉ	NON	42	2014-09-28 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/montauge-franck.html
98005N	M.	Laufoaulu	LAUFOAULU	Robert	1947-07-07 00:00:00	\N	ANCIEN	Enseignant	4400	69	RTLI	Les Indépendants	\N	ETRD	ETRD	984	Iles Wallis et Futuna	\N	r.laufoaulu@senat.fr	LAUFOAULU	NON	\N	\N	2017-10-09 16:22:57	\N
000673	M.	Sauvageot	SAUVAGEOT EDMOND	Edmond	1898-10-01 00:00:00	1983-10-11 00:00:00	ANCIEN	Administrateur de Sociétés	3100	57	RI	RI	\N	FINC	FINC	999	Français établis hors de France	\N	\N	SAUVAGEOT	NON	\N	\N	\N	\N
000748	M.	Pauzet	PAUZET MARC	Marc	1897-07-22 00:00:00	1985-08-20 00:00:00	ANCIEN	Géomètre expert foncier	3100	57	CNIP	C.N.I.P.	\N	ECON	ECON	330	Gironde	\N	\N	PAUZET	NON	\N	\N	2015-02-10 12:00:26	\N
000172	M.	Rosselli	ROSSELLI JACQUES	Jacques	1907-11-15 00:00:00	1974-02-04 00:00:00	ANCIEN	Avocat	3121	51	UDR	U.D.R.	\N	LOIS	LOIS	999	Français établis hors de France	\N	\N	ROSSELLI	NON	\N	\N	\N	\N
92038W	M.	Metzinger	METZINGER CHARLES	Charles	1929-08-13 00:00:00	1996-09-10 00:00:00	ANCIEN	Professeur	7000	69	SOC	SER	\N	SOCI	SOCI	570	Moselle	\N	\N	METZINGER	NON	\N	\N	2017-10-04 09:46:38	\N
96003C	M.	Vergès	VERGES	Paul	1925-03-05 00:00:00	2016-11-12 00:00:00	ANCIEN	Journaliste	3511	54	CRC	CRCE	\N	CDD	CDD	974	La Réunion	\N	\N	VERGÈS	NON	\N	\N	2017-10-04 09:44:06	\N
000282	M.	Barbier	BARBIER PIERRE	Pierre	1912-01-02 00:00:00	1982-10-28 00:00:00	ANCIEN	Chirurgien	3112	43	GD	G.D.	\N	SOCI	SOCI	580	Nièvre	\N	\N	BARBIER	NON	\N	\N	\N	\N
59721T	M.	Baumet	BAUMET 	Gilbert	1943-02-05 00:00:00	\N	ANCIEN	Cadre supérieur	3600	32	RDE	R.D.E.	\N	SOCI	SOCI	300	Gard	\N	\N	BAUMET	NON	\N	\N	2017-06-15 09:44:10	\N
000448	M.	Agarande	AGARANDE HENRI	Henri	1920-09-13 00:00:00	1983-08-06 00:00:00	ANCIEN	Ancien directeur de collège	7400	69	SOC	SER	-A	AFCL	AFCL	973	Guyane	\N	\N	AGARANDE	NON	\N	\N	2017-10-04 09:46:38	\N
95039L	M.	Hyest	HYEST	Jean-Jacques	1943-03-02 00:00:00	\N	ANCIEN	Administrateur territorial	3311	71	UMP	Les Républicains	\N	LOIS	LOIS	770	Seine-et-Marne	\N	jj.hyest@senat.fr	HYEST	NON	\N	\N	2017-10-09 16:22:57	\N
95032D	M.	Fischer	FISCHER	Guy	1944-01-12 00:00:00	2014-11-01 00:00:00	ANCIEN	Instituteur	4200	63	CRC	CRCE	\N	SOCI	SOCI	690	Rhône	\N	g.fischer@senat.fr	FISCHER	NON	\N	\N	2017-10-04 09:44:06	\N
77033C	M.	Larché	LARCHE	Jacques	1920-02-04 00:00:00	2014-08-13 00:00:00	ANCIEN	Avocat	3121	51	UMP	Les Républicains	\N	LOIS	LOIS	770	Seine-et-Marne	\N	\N	LARCHÉ	NON	\N	\N	2017-10-09 16:22:57	\N
95026F	M.	Dominati	DOMINATI	Jacques	1927-03-11 00:00:00	2016-09-08 00:00:00	ANCIEN	Journaliste	3511	54	UMP	Les Républicains	\N	AFCL	AFCL	615	Paris	\N	\N	DOMINATI	NON	\N	\N	2017-10-09 16:22:57	\N
09001P	Mme	Jouanno	JOUANNO CHANTAL	Chantal	1969-07-12 00:00:00	\N	ANCIEN	Membre du corps préfectoral	8000	71	UC	UC	\N	CDD	CDD	615	Paris	\N	c.jouanno@senat.fr	JOUANNO	OUI	\N	\N	2017-09-24 17:47:27	\N
86042E	M.	Penne	PENNE	Guy	1925-06-09 00:00:00	2010-07-25 00:00:00	ANCIEN	Professeur d'Université. Chef de service du centre de soins de la Faculté de chirurgie dentaire	3431	41	SOC	SER	\N	ETRD	ETRD	999	Français établis hors de France	\N	\N	PENNE	NON	\N	\N	2017-10-04 09:46:38	\N
97003G	M.	Duffour	DUFFOUR	Michel	1940-11-08 00:00:00	\N	ANCIEN	Instituteur	4200	63	CRC	CRCE	\N	LOIS	LOIS	335	Hauts-de-Seine	\N	\N	DUFFOUR	NON	\N	\N	2017-10-04 09:44:07	\N
81001X	M.	Soucaret	SOUCARET	Raymond	1923-07-27 00:00:00	2014-06-08 00:00:00	ANCIEN	Entrepreneur de travaux agricoles	1000	10	RDSE	RDSE	\N	ETRD	ETRD	470	Lot-et-Garonne	\N	\N	SOUCARET	NON	\N	\N	2014-06-16 08:25:29	\N
81011A	M.	Le Breton	LEBRETON	Henri	1928-09-10 00:00:00	2022-10-18 00:00:00	ANCIEN	Animateur commercial	3700	33	UC	UC	\N	SOCI	SOCI	560	Morbihan	\N	\N	LE BRETON	NON	\N	\N	2017-07-04 10:59:33	\N
58951C	M.	Boyer	BOYER EUGÈNE	Eugène	1922-06-14 00:00:00	2017-09-23 00:00:00	ANCIEN	Docteur vétérinaire	3115	46	SOC	SER	\N	SOCI	SOCI	310	Haute-Garonne	\N	\N	BOYER	NON	\N	\N	2017-10-04 09:46:38	\N
89026S	M.	Égu	EGU	André	1929-07-12 00:00:00	2016-08-19 00:00:00	ANCIEN	Négociant en vins	7200	23	UC	UC	\N	AFCL	AFCL	350	Ille-et-Vilaine	\N	\N	ÉGU	NON	\N	\N	2017-07-04 10:59:33	\N
86037H	M.	Loridant	LORIDANT	Paul	1948-04-22 00:00:00	2020-12-21 00:00:00	ANCIEN	Directeur-adjoint à la Banque de France	3600	32	CRC	CRCE	\N	FINC	FINC	265	Essonne	\N	\N	LORIDANT	NON	\N	\N	2017-10-04 09:44:07	\N
83020K	M.	Cabanel	CABANEL	Guy-Pierre	1927-04-07 00:00:00	2016-03-15 00:00:00	ANCIEN	Professeur d'Université	3431	41	RDSE	RDSE	\N	LOIS	LOIS	380	Isère	\N	\N	CABANEL	NON	\N	\N	2016-03-17 17:27:03	\N
58366Q	M.	Cabocel	CABOCEL RÉMI	Rémi	1926-09-13 00:00:00	2009-10-22 00:00:00	ANCIEN	Agriculteur	1000	10	NI	NI	\N	NEANT	Aucune	570	Moselle	\N	\N	CABOCEL	NON	\N	\N	\N	\N
000257	M.	Chabaraka	CHABARAKA AHMED	Ahmed	1910-11-10 00:00:00	1995-01-12 00:00:00	ANCIEN	Magistrat	3313	73	GD	G.D.	-A	AFCL	AFCL	1044	Mostaganem-Tiaret	\N	\N	CHABARAKA	NON	\N	\N	\N	\N
57434F	M.	De Chevigny	CHEVIGNY PIERRE (DE)	Pierre	1914-06-03 00:00:00	2001-10-18 00:00:00	ANCIEN	Agriculteur	1000	10	RI	RI	\N	ETRD	ETRD	540	Meurthe-et-Moselle	\N	\N	DE CHEVIGNY	NON	\N	\N	2015-02-10 12:00:26	\N
62001R	M.	Giacobbi	GIACOBBI FRANCOIS	François	1919-07-19 00:00:00	1997-03-07 00:00:00	ANCIEN	Avocat	3121	51	RDSE	RDSE	\N	LOIS	LOIS	205	Haute-Corse	\N	\N	GIACOBBI	NON	\N	\N	\N	\N
000194	M.	Deblock	DEBLOCK ROGER	Roger	1908-08-10 00:00:00	1994-03-30 00:00:00	ANCIEN	Ancien agriculteur	1000	10	RI	RI	\N	ETRD	ETRD	590	Nord	\N	\N	DEBLOCK	NON	\N	\N	\N	\N
59231E	M.	Goussebaire-Dupin	GOUSSEBAIRE-DUPIN YVES	Yves	1930-07-19 00:00:00	2021-07-15 00:00:00	ANCIEN	Pharmacien	3116	44	UREI	U.R.E.I.	\N	ECON	ECON	400	Landes	\N	\N	GOUSSEBAIRE-DUPIN	NON	\N	\N	\N	\N
000224	M.	Gueril	GUERIL GEORGES	Georges	1909-10-28 00:00:00	1977-03-02 00:00:00	ANCIEN	Inspecteur Central des Douanes	4500	72	UNR	U.N.R.	\N	SOCI	SOCI	973	Guyane	\N	\N	GUERIL	NON	\N	\N	2015-02-10 12:00:26	\N
000449	M.	Fosse	FOSSE ROGER	Roger	1920-09-23 00:00:00	1996-12-18 00:00:00	ANCIEN	Administrateur de biens	7200	29	RPR	RPR	-A	ETRD	ETRD	760	Seine-Maritime	\N	\N	FOSSE	NON	\N	\N	2017-06-15 09:45:54	\N
56601X	M.	Garaudy	GARAUDY ROGER	Roger	1913-07-17 00:00:00	2012-06-13 00:00:00	ANCIEN	Professeur agrégé	4200	62	C	C	\N	AFCL	AFCL	1029	Seine	\N	\N	GARAUDY	NON	\N	\N	\N	\N
000403	M.	Jaffar El Amjad	JAFFAR EL AMJAD SAID MOHAMED	Said Mohamed	1918-04-14 00:00:00	1993-10-22 00:00:00	ANCIEN	Administrateur des Comores	3311	71	NI	NI	\N	ETRD	ETRD	1025	Comores	\N	\N	JAFFAR EL AMJAD	NON	\N	\N	\N	\N
57208W	M.	Kamil	KAMIL MOHAMED	Mohamed	1917-01-01 00:00:00	2002-06-09 00:00:00	ANCIEN	Comptable	5400	33	UNR	U.N.R.	\N	AFCL	AFCL	1012	Côte française des Somalis	\N	\N	KAMIL	NON	\N	\N	\N	\N
000248	M.	Lechenault	LECHENAULT FRANCE	France	1910-08-19 00:00:00	1995-05-06 00:00:00	ANCIEN	Agriculteur	1000	10	GD	G.D.	\N	ECON	ECON	710	Saône-et-Loire	\N	\N	LECHENAULT	NON	\N	\N	\N	\N
000223	M.	Mailhe	MAILHE PIERRE	Pierre	1909-10-22 00:00:00	1987-11-30 00:00:00	ANCIEN	Avocat	3121	51	GD	G.D.	\N	LOIS	LOIS	650	Hautes-Pyrénées	\N	\N	MAILHE	NON	\N	\N	\N	\N
000498	M.	Marette	MARETTE JACQUES	Jacques	1922-09-21 00:00:00	1984-04-25 00:00:00	ANCIEN	Cadre de l'industrie	3600	32	UNR	U.N.R.	\N	ECON	ECON	1029	Seine	\N	\N	MARETTE	NON	\N	\N	2017-06-15 09:47:12	\N
12041X	M.	Laurent	LAURENT PIERRE	Pierre	1957-07-01 00:00:00	\N	ANCIEN	Journaliste	3511	54	CRC	CRCE	N	ETRD	ETRD	615	Paris	Vice-président du Sénat	p.laurent@senat.fr	LAURENT	NON	\N	\N	2023-10-01 00:37:00	\N
58621L	M.	Martin	MARTIN RENÉ	René	1918-11-20 00:00:00	2010-12-20 00:00:00	ANCIEN	Directeur d'école	7000	79	C	C	\N	ECON	ECON	895	Yvelines	\N	\N	MARTIN	NON	\N	\N	\N	\N
000269	M.	Mathy	MATHY MARCEL	Marcel	1911-04-10 00:00:00	1982-03-20 00:00:00	ANCIEN	Agriculteur	1000	10	SOC	SER	\N	ECON	ECON	710	Saône-et-Loire	\N	\N	MATHY	NON	\N	\N	2017-10-04 09:46:38	\N
000337	M.	Mercier	MERCIER JEAN	Jean	1914-03-31 00:00:00	1988-01-11 00:00:00	ANCIEN	Avocat	3121	51	GD	G.D.	\N	AFCL	AFCL	690	Rhône	\N	\N	MERCIER	NON	\N	\N	\N	\N
58628T	Mme	Perlican	PERLICAN ROLANDE	Rolande	1931-09-19 00:00:00	\N	ANCIEN	Sténo-dactylo	5400	33	C	C	\N	ETRD	ETRD	615	Paris	\N	\N	PERLICAN	NON	\N	\N	\N	\N
000434	M.	Petit	PETIT PIERRE	Pierre	1919-11-29 00:00:00	1977-12-21 00:00:00	ANCIEN	Sans profession déclarée	8000	80	SOC	SER	\N	AFCL	AFCL	580	Nièvre	\N	\N	PETIT	NON	\N	\N	2017-10-04 09:46:38	\N
000158	M.	Ribeyre	RIBEYRE PAUL	Paul	1906-12-11 00:00:00	1988-01-14 00:00:00	ANCIEN	Directeur de sociétés	2300	21	CNIP	C.N.I.P.	\N	FINC	FINC	70	Ardèche	\N	\N	RIBEYRE	NON	\N	\N	\N	\N
77003V	M.	Robert	ROBERT GUY	Guy	1921-09-17 00:00:00	2011-10-24 00:00:00	ANCIEN	Agriculteur	1000	10	UC	UC	\N	ETRD	ETRD	860	Vienne	\N	\N	ROBERT	NON	\N	\N	2017-07-04 10:59:33	\N
000085	M.	Provo	PROVO VICTOR	Victor	1903-08-30 00:00:00	1983-10-04 00:00:00	ANCIEN	Trieur de laines	6000	34	SOC	SER	\N	AFCL	AFCL	590	Nord	\N	\N	PROVO	NON	\N	\N	2017-10-04 09:46:38	\N
000147	M.	Schwartz	SCHWARTZ RENÉ	René	1906-08-08 00:00:00	1960-05-09 00:00:00	ANCIEN	Ancien avocat	7400	59	RI	RI	\N	LOIS	LOIS	570	Moselle	\N	\N	SCHWARTZ	NON	\N	\N	\N	\N
000287	M.	Splingard	SPLINGARD RAYMOND	Raymond	1912-01-26 00:00:00	1995-06-14 00:00:00	ANCIEN	Négociant en retraite	2200	22	SOC	SER	\N	ECON	ECON	620	Pas-de-Calais	\N	\N	SPLINGARD	NON	\N	\N	2017-10-04 09:46:38	\N
58950B	M.	Tarcy	TARCY RAYMOND	Raymond	1936-11-18 00:00:00	2019-07-03 00:00:00	ANCIEN	Principal-adjoint de collège	4200	62	SOC	SER	-A	SOCI	SOCI	973	Guyane	\N	\N	TARCY	NON	\N	\N	2017-10-04 09:46:38	\N
07032N	M.	Pinton	PINTON LOUIS	Louis	1948-10-24 00:00:00	2016-11-17 00:00:00	ANCIEN	Docteur vétérinaire	3115	46	UMP	Les Républicains	\N	SOCI	SOCI	360	Indre	\N	l.pinton@senat.fr	PINTON	NON	\N	\N	2017-10-09 16:22:57	\N
000255	M.	Durand	DURAND HUBERT	Hubert	1910-10-21 00:00:00	1981-10-12 00:00:00	ANCIEN	Directeur de la fédération régionale Vendée Loire et Sèvres des caisses de Crédit mutuel libre	4500	72	RI	RI	\N	AFCL	AFCL	850	Vendée	\N	\N	DURAND	NON	\N	\N	\N	\N
58942B	M.	Eeckhoutte	EECKHOUTTE LÉON	Léon	1911-09-04 00:00:00	2004-01-31 00:00:00	ANCIEN	Professeur agrégé de l'université	3400	61	SOC	SER	\N	AFCL	AFCL	310	Haute-Garonne	\N	\N	EECKHOUTTE	NON	\N	\N	2017-10-04 09:46:38	\N
58048D	M.	Verillon	VERILLON MAURICE	Maurice	1906-10-14 00:00:00	2001-06-08 00:00:00	ANCIEN	Pharmacien	3116	44	SOC	SER	\N	AFCL	AFCL	260	Drôme	\N	\N	VERILLON	NON	\N	\N	2017-10-04 09:46:38	\N
58647W	M.	Wirth	WIRTH FRÉDÉRIC	Frédéric	1915-04-11 00:00:00	1999-07-13 00:00:00	ANCIEN	Chef d'entreprise	2300	21	UC	UC	\N	ECON	ECON	999	Français établis hors de France	\N	\N	WIRTH	NON	\N	\N	2017-07-04 10:59:33	\N
57701F	M.	Beloucif	BELOUCIF AMAR	Amar	1922-01-01 00:00:00	2002-02-17 00:00:00	ANCIEN	Administrateur des services civils d'Algérie	3311	71	NI	NI	\N	ECON	ECON	1042	Bône	\N	\N	BELOUCIF	NON	\N	\N	\N	\N
14365A	M.	Pélieu	Pelieu_Michel	Michel	1946-06-26 00:00:00	\N	ANCIEN	\N	8000	80	RDSE	RDSE	\N	NEANT	Aucune	650	Hautes-Pyrénées	\N	\N	PÉLIEU	NON	\N	2017-05-16 16:19:32	2017-09-24 12:39:59	\N
14013P	M.	Bosino	BOSINO	Jean-Pierre	1959-01-15 00:00:00	\N	ANCIEN	\N	8000	80	CRC	CRCE	\N	CAE	CAE	600	Oise	\N	jp.bosino@senat.fr	BOSINO	NON	\N	2014-05-09 11:29:04	2017-10-04 09:44:07	\N
14361V	Mme	Rivollier	RIVOLLIER_Evelyne	Évelyne	1958-05-13 00:00:00	\N	ANCIEN	conseillère technique	3600	32	CRC	CRCE	\N	AFCL	AFCL	420	Loire	\N	\N	RIVOLLIER	OUI	\N	2016-12-12 15:59:30	2017-10-04 09:44:07	\N
14014Q	Mme	Giraud	GIRAUD_ELIANE	Éliane	1952-03-12 00:00:00	\N	ANCIEN	Fonctionnaire territorial	3700	72	SOC	SER	\N	ETRD	ETRD	380	Isère	\N	e.giraud@senat.fr	GIRAUD	OUI	\N	2014-05-09 11:37:36	2017-10-04 09:46:38	\N
15197G	M.	Dhersin	DHERSIN_Franck	Franck	1962-06-18 00:00:00	\N	ACTIF	juriste	8000	80	UC	UC	-A	CDD	CDD	590	Nord	\N	f.dhersin@senat.fr	DHERSIN	NON	124	2017-06-15 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/dhersin-franck.html
14001X	M.	Marie	MARIE	Didier	1960-05-19 00:00:00	\N	ACTIF	Professeur des écoles	4200	63	SOC	SER	\N	ETRD	ETRD	760	Seine-Maritime	\N	d.marie@senat.fr	MARIE	NON	72	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/marie-didier.html
14219Q	M.	Longeot	LONGEOT_JEAN_FRANCOIS	Jean-François	1956-12-27 00:00:00	\N	ACTIF	Attaché territorial principal	7400	39	UC	UC	\N	CDD	CDD	250	Doubs	\N	jf.longeot@senat.fr	LONGEOT	NON	261	2014-09-28 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/longeot-jean-francois.html
14221J	M.	Médevielle	MEDEVIELLE_PIERRE	Pierre	1960-04-17 00:00:00	\N	ACTIF	Pharmacien	3100	57	RTLI	Les Indépendants	\N	CAE	CAE	310	Haute-Garonne	\N	p.medevielle@senat.fr	MÉDEVIELLE	NON	312	2014-09-28 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/medevielle-pierre.html
14223L	Mme	Micouleau	MICOULEAU_BRIGITTE	Brigitte	1951-09-10 00:00:00	\N	ACTIF	Assistante de direction	7400	39	UMP	Les Républicains	\N	SOCI	SOCI	310	Haute-Garonne	\N	b.micouleau@senat.fr	MICOULEAU	OUI	95	2014-09-28 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/micouleau-brigitte.html
14225N	M.	Raynal	RAYNAL_CLAUDE	Claude	1957-10-10 00:00:00	\N	ACTIF	Conseiller de tribunal administratif	3300	71	SOC	SER	\N	FINC	FINC	310	Haute-Garonne	\N	c.raynal@senat.fr	RAYNAL	NON	20	2014-09-28 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/raynal-claude.html
14227Q	M.	Tourenne	TOURENNE_Jean_Louis	Jean-Louis	1944-08-25 00:00:00	\N	ANCIEN	Principal de collège	3400	64	SOC	SER	\N	SOCI	SOCI	350	Ille-et-Vilaine	\N	jl.tourenne@senat.fr	TOURENNE	NON	\N	2014-09-28 17:34:15	2017-10-04 09:46:39	\N
14229S	Mme	Robert	ROBERT_SYLVIE	Sylvie	1963-08-28 00:00:00	\N	ACTIF	Cadre culturel	8000	81	SOC	SER	\N	AFCL	AFCL	350	Ille-et-Vilaine	Vice-présidente du Sénat	s.robert@senat.fr	ROBERT	OUI	19	2014-09-28 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/robert-sylvie.html
14231L	Mme	Gatel	GATEL_FRANCOISE	Françoise	1953-03-14 00:00:00	\N	ACTIF	\N	7400	39	UC	UC	\N	LOIS	LOIS	350	Ille-et-Vilaine	\N	f.gatel@senat.fr	GATEL	NON	5	2014-09-28 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/gatel-francoise.html
14237S	M.	Pellevat	PELLEVAT_CYRIL	Cyril	1981-02-18 00:00:00	\N	ACTIF	Directeur des ressources humaines	3700	32	UMP	Les Républicains	-R	CDD	CDD	740	Haute-Savoie	\N	c.pellevat@senat.fr	PELLEVAT	NON	135	2014-09-28 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/pellevat-cyril.html
14239U	M.	Amiel	AMIEL_Michel	Michel	1954-07-03 00:00:00	\N	ANCIEN	Médecin	3112	42	RTLI	Les Indépendants	\N	SOCI	SOCI	130	Bouches-du-Rhône	\N	m.amiel@senat.fr	AMIEL	NON	\N	2014-09-28 17:52:17	2017-10-04 18:46:05	\N
14241N	Mme	Jouve	JOUVE_Mireille	Mireille	1960-12-30 00:00:00	\N	ACTIF	Professeur	4200	63	RDSE	RDSE	\N	AFCL	AFCL	130	Bouches-du-Rhône	\N	m.jouve@senat.fr	JOUVE	NON	\N	2014-09-28 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/jouve-mireille.html
14299H	M.	de Ganay	de_Ganay_Claude	Claude	1953-09-05 00:00:00	\N	AUTRE	\N	8000	80	\N	\N	\N	\N	\N	\N	\N	\N	\N	DE GANAY	NON	\N	2015-07-01 17:32:34	2017-06-15 09:49:31	\N
14012N	Mme	Lajoux	LAJOUX_ISABELLE	Isabelle	1960-05-20 00:00:00	\N	ANCIEN	Employée de banque	5500	80	SOC	SER	\N	LOIS	LOIS	210	Côte-d'Or	\N	i.lajoux@senat.fr	LAJOUX	OUI	\N	2014-05-05 10:30:19	2017-10-04 09:46:39	\N
14002L	Mme	Bordas	BORDAS_PATRICIA	Patricia	1956-06-05 00:00:00	\N	ANCIEN	\N	8000	80	SOC	SER	\N	SOCI	SOCI	190	Corrèze	\N	p.bordas@senat.fr	BORDAS	OUI	\N	2014-02-14 15:15:52	2017-10-04 09:46:39	\N
14275Y	Mme	Tetuanui	TETUANUI_LANA	Lana	1970-02-23 00:00:00	\N	ACTIF	\N	4500	72	UC	UC	-A	LOIS	LOIS	983	Polynésie française	\N	l.tetuanui@senat.fr	TETUANUI	OUI	317	2015-05-04 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/tetuanui-lana.html
14277B	M.	Laurey	LAUREY_NUIHAU	Nuihau	1964-12-29 00:00:00	\N	ANCIEN	\N	8000	80	UC	UC	-A	FINC	FINC	983	Polynésie française	\N	n.laurey@senat.fr	LAUREY	NON	\N	2015-05-04 10:29:04	2017-09-18 14:59:30	\N
14281W	Mme	Féret	FERET_CORINNE	Corinne	1961-09-17 00:00:00	\N	ACTIF	Fonctionnaire de l'éducation nationale	3300	71	SOC	SER	\N	SOCI	SOCI	140	Calvados	\N	c.feret@senat.fr	FÉRET	OUI	147	2015-06-12 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/feret-corinne.html
14271U	Mme	Riocreux	RIOCREUX_STEPHANIE	Stéphanie	1966-05-20 00:00:00	\N	ANCIEN	Employée	5500	33	LREM	RDPI	\N	SOCI	SOCI	370	Indre-et-Loire	\N	s.riocreux@senat.fr	RIOCREUX	OUI	\N	2015-04-07 17:15:52	2017-10-04 09:45:02	\N
15447F	M.	Ginesta	GINESTA_Jordi	Jordi	1942-07-08 00:00:00	\N	ANCIEN	Agent d'assurance	4600	57	UMP	Les Républicains	\N	CDD	CDD	830	Var	\N	j.ginesta@senat.fr	GINESTA	NON	\N	2017-06-15 09:45:32	2018-03-28 11:14:31	\N
14017T	M.	Robert	ROBERT_DIDIER	Didier	1964-04-26 00:00:00	\N	ANCIEN	\N	8000	80	UMP	Les Républicains	\N	SOCI	SOCI	974	La Réunion	\N	didier.robert@senat.fr	ROBERT	NON	\N	2014-06-25 15:52:44	2017-10-09 16:22:57	\N
14179A	M.	Hervé	HERVE_LOIC	Loïc	1980-06-08 00:00:00	\N	ACTIF	Cadre territorial	3300	71	UC	UC	\N	ETRD	ETRD	740	Haute-Savoie	Vice-président du Sénat	l.herve@senat.fr	HERVÉ	NON	87	2014-09-22 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/herve-loic.html
14213J	Mme	Imbert	IMBERT_CORINNE	Corinne	1958-11-20 00:00:00	\N	ACTIF	Pharmacienne	3100	57	UMP	Les Républicains	-A	SOCI	SOCI	170	Charente-Maritime	\N	c.imbert@senat.fr	IMBERT	OUI	277	2014-09-28 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/imbert-corinne.html
14215L	Mme	Di Folco	DI_FOLCO_CATHERINE	Catherine	1960-11-30 00:00:00	\N	ACTIF	\N	8500	80	UMP	Les Républicains	-A	LOIS	LOIS	690	Rhône	Secrétaire du Sénat	c.di-folco@senat.fr	DI FOLCO	NON	133	2014-09-28 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/di-folco-catherine.html
14217N	Mme	Deseyne	DESEYNE_CHANTAL	Chantal	1957-01-29 00:00:00	\N	ACTIF	\N	3400	61	UMP	Les Républicains	\N	SOCI	SOCI	280	Eure-et-Loir	\N	c.deseyne@senat.fr	DESEYNE	NON	217	2014-09-28 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/deseyne-chantal.html
14259Y	M.	Darnaud	DARNAUD_MATHIEU	Mathieu	1975-07-11 00:00:00	\N	ACTIF	Chargé de mission	4600	32	UMP	Les Républicains	\N	LOIS	LOIS	70	Ardèche	Vice-président du Sénat	m.darnaud@senat.fr	DARNAUD	NON	63	2014-09-28 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/darnaud-mathieu.html
14249W	Mme	Duranton	DURANTON_NICOLE	Nicole	1958-10-13 00:00:00	\N	ACTIF	\N	8000	80	LREM	RDPI	\N	ETRD	ETRD	270	Eure	\N	n.duranton@senat.fr	DURANTON	NON	154	2014-09-28 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/duranton-nicole.html
16431B	M.	Roustan	Roustan_Max	Max	1944-09-29 00:00:00	\N	ANCIEN	\N	8000	80	AUCUN	NI	\N	NEANT	Aucune	300	Gard	\N	\N	ROUSTAN	NON	\N	2017-06-15 09:47:33	2017-10-02 10:14:13	\N
14265W	Mme	Morhet-Richaud	MORHET_RICHAUD_Patricia	Patricia	1961-07-28 00:00:00	\N	ANCIEN	\N	5500	33	UMP	Les Républicains	\N	CAE	CAE	50	Hautes-Alpes	\N	p.morhet-richaud@senat.fr	MORHET-RICHAUD	OUI	\N	2014-12-29 15:45:40	2017-10-09 16:22:58	\N
14329V	Mme	Chain-Larché	CHAIN LARCHE ANNE	Anne	1958-04-11 00:00:00	\N	ACTIF	Pharmacienne	3116	44	UMP	Les Républicains	\N	CAE	CAE	770	Seine-et-Marne	\N	a.chain-larche@senat.fr	CHAIN-LARCHÉ	OUI	276	2015-10-12 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/chain-larche-anne.html
14135M	M.	Raison	RAISON_Michel	Michel	1949-11-05 00:00:00	\N	ANCIEN	\N	1000	10	UMP	Les Républicains	\N	CAE	CAE	700	Haute-Saône	Secrétaire du Sénat	m.raison@senat.fr	RAISON	NON	\N	2014-09-18 14:44:37	2017-10-09 16:22:58	\N
14175V	M.	Bouvard	BOUVARD_Michel	Michel	1955-03-17 00:00:00	\N	ANCIEN	Conseiller maître à la Cour des Comptes	3300	71	UMP	Les Républicains	\N	FINC	FINC	730	Savoie	\N	m.bouvard@senat.fr	BOUVARD	NON	\N	2014-09-22 14:32:46	2017-10-09 16:22:58	\N
17965H	Mme	Poumirol	POUMIROL_EMILIENNE	Émilienne	1950-07-25 00:00:00	\N	ACTIF	Médecin retraité	3100	57	SOC	SER	\N	SOCI	SOCI	310	Haute-Garonne	\N	e.poumirol@senat.fr	POUMIROL	OUI	71	2017-06-15 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/poumirol-emilienne.html
18003S	M.	Aubert	Aubert_Julien	Julien	1978-06-11 00:00:00	\N	AUTRE	\N	8000	80	\N	\N	\N	\N	\N	\N	\N	\N	\N	AUBERT	NON	\N	2017-06-15 09:49:58	\N	\N
19794Q	Mme	Ramond	RAMOND_Françoise	Françoise	1940-09-29 00:00:00	\N	ANCIEN	Ingénieure	8000	80	UMP	Les Républicains	-A	CDD	CDD	280	Eure-et-Loir	\N	f.ramond@senat.fr	RAMOND	OUI	\N	\N	\N	\N
19383Y	M.	Boyer	BOYER_JEAN_MARC	Jean-Marc	1954-02-24 00:00:00	\N	ACTIF	Ancien professeur	7000	69	UMP	Les Républicains	\N	CAE	CAE	630	Puy-de-Dôme	\N	jm.boyer@senat.fr	BOYER	NON	274	2017-09-18 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/boyer-jean-marc.html
19820Y	M.	Gillé	GILLE_HERVE	Hervé	1960-10-09 00:00:00	\N	ACTIF	Directeur de mission locale	3700	32	SOC	SER	\N	CDD	CDD	330	Gironde	\N	h.gille@senat.fr	GILLÉ	NON	70	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/gille-herve-16452.html
19866P	Mme	Pantel	PANTEL_GUYLENE	Guylène	1963-12-14 00:00:00	\N	ACTIF	Cadre de la poste	3300	73	RDSE	RDSE	\N	SOCI	SOCI	480	Lozère	\N	g.pantel@senat.fr	PANTEL	OUI	81	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/pantel-guylene-6790.html
20172F	Mme	Garnier	GARNIER_LAURENCE	Laurence	1978-04-03 00:00:00	\N	ACTIF	Cadre d'entreprise	3600	32	UMP	Les Républicains	\N	AFCL	AFCL	440	Loire-Atlantique	\N	l.garnier@senat.fr	GARNIER	OUI	222	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/garnier-laurence.html
18083K	M.	Chevrollier	CHEVROLLIER_GUILLAUME	Guillaume	1974-10-27 00:00:00	\N	ACTIF	Directeur de programmes immobiliers	3600	32	UMP	Les Républicains	\N	CDD	CDD	530	Mayenne	\N	g.chevrollier@senat.fr	CHEVROLLIER	NON	12	2017-06-15 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/chevrollier-guillaume.html
18127E	Mme	Dufour-Tonini	Dufour_Tonini_Anne_Lise	Anne-Lise	1970-03-02 00:00:00	\N	ANCIEN	\N	8000	80	SOC	SER	\N	AFCL	AFCL	590	Nord	\N	\N	DUFOUR-TONINI	OUI	\N	2017-06-15 09:50:05	2017-10-04 09:52:11	\N
20034V	Mme	Jacques	JACQUES_MICHELINE	Micheline	1971-10-08 00:00:00	\N	ACTIF	Directrice d'école	4200	63	UMP	Les Républicains	\N	CAE	CAE	9713	Saint-Barthélemy	\N	m.jacques@senat.fr	JACQUES	NON	289	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/jacques-micheline.html
20248J	Mme	Devésa	DEVESA_BRIGITTE	Brigitte	1960-03-03 00:00:00	\N	ACTIF	Directrice de centre de formation	3700	32	UC	UC	\N	SOCI	SOCI	130	Bouches-du-Rhône	\N	b.devesa@senat.fr	DEVÉSA	OUI	267	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/devesa-brigitte.html
19657G	Mme	Malet	MALET_VIVIANE	Viviane	1954-10-28 00:00:00	\N	ACTIF	\N	8000	80	UMP	Les Républicains	\N	SOCI	SOCI	974	La Réunion	\N	v.malet@senat.fr	MALET	OUI	339	2017-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/malet-viviane-5657.html
19659J	M.	Dennemont	DENNEMONT_MICHEL	Michel	1949-02-11 00:00:00	\N	ANCIEN	Ancien infirmier libéral	7300	59	LREM	RDPI	N	CDD	CDD	974	La Réunion	\N	m.dennemont@senat.fr	DENNEMONT	NON	\N	2017-09-24 00:00:00	2023-10-01 00:37:00	\N
19727D	Mme	Grelet-Certenais	GRELET_CERTENAIS_Nadine	Nadine	1959-01-17 00:00:00	\N	ANCIEN	Travailleur social	5200	33	SOC	SER	\N	SOCI	SOCI	720	Sarthe	\N	n.grelet-certenais@senat.fr	GRELET-CERTENAIS	OUI	\N	2017-10-01 10:54:01	2017-10-04 18:55:56	\N
19729F	M.	Leroy	LEROY_HENRI	Henri	1945-03-31 00:00:00	\N	ACTIF	Officier de gendarmerie	7400	39	UMP	Les Républicains	\N	LOIS	LOIS	60	Alpes-Maritimes	\N	h.leroy@senat.fr	LEROY	NON	338	2017-10-01 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/leroy-henri.html
19731Y	Mme	Kauffmann	KAUFFMANN_Claudine	Claudine	1944-09-28 00:00:00	\N	ANCIEN	Ancien cadre	7400	29	NI	NI	\N	AFCL	AFCL	830	Var	\N	c.kauffmann@senat.fr	KAUFFMANN	OUI	\N	2017-10-01 11:13:13	2017-10-25 10:21:19	\N
19733B	Mme	Bories	BORIES_Pascale	Pascale	1969-04-01 00:00:00	\N	ANCIEN	Gérante de société	2300	21	UMP	Les Républicains	\N	CDD	CDD	300	Gard	\N	p.bories@senat.fr	BORIES	OUI	\N	2017-10-01 11:41:24	2017-10-09 16:22:58	\N
19735D	Mme	de La Provôté	LA PROVOTE_SONIA	Sonia	1968-12-25 00:00:00	\N	ACTIF	Médecin du travail	4300	47	UC	UC	\N	AFCL	AFCL	140	Calvados	Secrétaire du Sénat	s.delaprovote@senat.fr	de LA PROVÔTÉ	OUI	206	2017-10-01 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/de-la-provote-sonia.html
19737F	Mme	Vullien	VULLIEN_Michele	Michèle	1944-01-18 00:00:00	\N	ANCIEN	\N	8000	80	UC	UC	-A	CDD	CDD	690	Rhône	\N	m.vullien@senat.fr	VULLIEN	OUI	\N	2017-10-01 11:57:13	2017-10-04 18:57:36	\N
20252E	M.	Meignen	MEIGNEN_THIERRY	Thierry	1957-05-17 00:00:00	\N	ACTIF	Chef d'entreprise	3100	57	UMP	Les Républicains	\N	ETRD	ETRD	775	Seine-Saint-Denis	\N	\N	MEIGNEN	NON	215	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/meignen-thierry.html
18193Q	Mme	Le Houerou	LE_HOUEROU_ANNIE	Annie	1960-03-31 00:00:00	\N	ACTIF	Fonctionnaire	3300	71	SOC	SER	\N	SOCI	SOCI	220	Côtes-d'Armor	\N	a.le-houerou@senat.fr	LE HOUEROU	OUI	148	2017-06-15 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/le-houerou-annie.html
19577H	Mme	Dindar	DINDAR_NASSIMAH	Nassimah	1960-01-20 00:00:00	\N	ANCIEN	Professeur	3400	62	UC	UC	N	CDD	CDD	974	La Réunion	\N	n.dindar@senat.fr	DINDAR	OUI	\N	2017-09-22 00:00:00	2023-10-01 00:37:00	\N
19583F	M.	Lagourgue	LAGOURGUE_JEAN_LOUIS	Jean-Louis	1947-08-05 00:00:00	\N	ANCIEN	Directeur commercial société de courtage	3600	32	RTLI	Les Indépendants	N	ETRD	ETRD	974	La Réunion	\N	jl.lagourgue@senat.fr	LAGOURGUE	NON	\N	2017-09-22 00:00:00	2023-10-01 00:37:00	\N
19591F	M.	Iacovelli	IACOVELLI_XAVIER	Xavier	1981-03-31 00:00:00	\N	ACTIF	Attaché territorial contractuel	4500	33	LREM	RDPI	\N	SOCI	SOCI	335	Hauts-de-Seine	\N	x.iacovelli@senat.fr	IACOVELLI	NON	78	2017-09-22 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/iacovelli-xavier.html
19593H	M.	Ouzoulias	OUZOULIAS_PIERRE	Pierre	1964-01-28 00:00:00	\N	ACTIF	Chargé de recherche au CNRS	3400	71	CRC	CRCE-K	\N	AFCL	AFCL	335	Hauts-de-Seine	Vice-président du Sénat	p.ouzoulias@senat.fr	OUZOULIAS	NON	183	2017-09-22 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/ouzoulias-pierre.html
20178M	M.	Sévêque	Seveque_Alain	Alain	1950-10-27 00:00:00	\N	ANCIEN	\N	8000	80	NI	NI	\N	NEANT	Aucune	500	Manche	\N	\N	SÉVÊQUE	NON	\N	\N	\N	\N
18207D	Mme	Linkenheld	LINKENHELD_Audrey	Audrey	1973-10-11 00:00:00	\N	ACTIF	Cadre du secteur privé	3735	55	SOC	SER	\N	LOIS	LOIS	590	Nord	\N	a.linkenheld@senat.fr	LINKENHELD	OUI	112	2017-06-15 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/linkenheld-audrey.html
20020P	M.	Rojouan	ROJOUAN_BRUNO	Bruno	1957-03-06 00:00:00	\N	ACTIF	Retraité	7400	39	UMP	Les Républicains	-R	CDD	CDD	30	Allier	\N	b.rojouan@senat.fr	ROJOUAN	NON	271	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/rojouan-bruno-11548.html
20028X	M.	Mérillou	MERILLOU_SERGE	Serge	1952-02-14 00:00:00	\N	ACTIF	Retraité	7400	39	SOC	SER	\N	CAE	CAE	240	Dordogne	\N	s.merillou@senat.fr	MÉRILLOU	NON	296	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/merillou-serge-20694.html
20030R	M.	Pla	PLA_SEBASTIEN	Sebastien	1977-07-18 00:00:00	\N	ACTIF	Cadre tourisme	3700	32	SOC	SER	\N	CAE	CAE	110	Aude	\N	s.pla@senat.fr	PLA	NON	295	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/pla-sebastien-20788.html
20016T	M.	Kulimoetoke	KULIMOETOKE_MIKAELE	Mikaele	1963-06-17 00:00:00	\N	ACTIF	Retraité de la gendarmerie	5300	74	LREM	RDPI	\N	AFCL	AFCL	984	Iles Wallis et Futuna	\N	m.kulimoetoke@senat.fr	KULIMOETOKE	NON	308	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/kulimoetoke-mikaele-20713.html
18231D	Mme	Narassiguin	NARASSIGUIN_Corinne	Corinne	1975-03-07 00:00:00	\N	ACTIF	Ingénieure 	3800	31	SOC	SER	\N	LOIS	LOIS	775	Seine-Saint-Denis	\N	\N	NARASSIGUIN	OUI	240	2017-06-15 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/narassiguin-corinne-26163.html
19926J	Mme	Cabaret	Cabaret_Muriel	Muriel	1955-03-09 00:00:00	\N	ANCIEN	Retraitée de la fonction publique territoriale	7000	79	SOC	SER	\N	SOCI	SOCI	720	Sarthe	\N	\N	CABARET	OUI	\N	\N	\N	\N
19333N	M.	Houllegatte	HOULLEGATTE_JEAN_MICHEL	Jean-Michel	1958-05-30 00:00:00	\N	ANCIEN	Administrateur territorial contractuel	3300	71	SOC	SER	N	CDD	CDD	500	Manche	\N	jm.houllegatte@senat.fr	HOULLEGATTE	NON	\N	2017-09-15 00:00:00	2023-10-01 00:37:00	\N
20176K	Mme	Blandin	Blandin_Valerie	Valérie	1980-11-26 00:00:00	\N	ANCIEN	\N	8000	80	NI	NI	\N	NEANT	Aucune	500	Manche	\N	\N	BLANDIN	OUI	\N	\N	\N	\N
18395Y	Mme	Daniel	DANIEL_Karine	Karine	1974-06-22 00:00:00	\N	ACTIF	Economiste	3400	61	SOC	SER	\N	AFCL	AFCL	440	Loire-Atlantique	\N	k.daniel@senat.fr	DANIEL	OUI	192	2017-06-15 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/daniel-karine.html
21125C	Mme	Bellamy	BELLAMY_Marie_Jeanne	Marie-Jeanne	1966-01-05 00:00:00	\N	ACTIF	Collaboratrice agent assurance	3735	55	UMP	Les Républicains	-A	AFCL	AFCL	860	Vienne	\N	mj.bellamy@senat.fr	BELLAMY	OUI	67	2024-03-18 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/bellamy-marie-jeanne-26946.html
19531S	M.	Joly	JOLY_PATRICE	Patrice	1957-05-05 00:00:00	\N	ACTIF	Conseiller de chambre régionale des comptes	3300	71	SOC	SER	\N	ETRD	ETRD	580	Nièvre	\N	p.joly@senat.fr	JOLY	NON	190	2017-09-19 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/joly-patrice-4300.html
19543W	M.	de Belenet	BELENET_ARNAUD	Arnaud	1975-03-14 00:00:00	\N	ANCIEN	Juriste	3128	57	UC	UC	A	LOIS	LOIS	770	Seine-et-Marne	\N	a.de-belenet@senat.fr	de BELENET	NON	\N	2017-09-19 00:00:00	2023-10-01 00:37:00	\N
19253P	Mme	Costes	Costes_Josiane	Josiane	1947-08-23 00:00:00	\N	ANCIEN	Professeur agrégé d'anglais	7000	61	RDSE	RDSE	\N	LOIS	LOIS	150	Cantal	\N	\N	COSTES	OUI	\N	2017-06-19 16:48:14	2018-02-15 16:49:59	\N
19611R	M.	Lafon	LAFON_LAURENT	Laurent	1965-11-18 00:00:00	\N	ACTIF	Enseignant	8000	61	UC	UC	\N	AFCL	AFCL	824	Val-de-Marne	\N	l.lafon@senat.fr	LAFON	NON	52	2017-09-22 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/lafon-laurent.html
19663E	Mme	Delmont-Koropoulis	DELMONT_KOROPOULIS_ANNIE	Annie	1947-07-13 00:00:00	\N	ANCIEN	Médecin	3112	42	UMP	Les Républicains	N	SOCI	SOCI	775	Seine-Saint-Denis	\N	a.delmont-koropoulis@senat.fr	DELMONT-KOROPOULIS	OUI	\N	2017-09-24 00:00:00	2023-10-01 00:37:00	\N
14069U	M.	Bonhomme	BONHOMME_FRANCOIS	François	1969-05-05 00:00:00	\N	ACTIF	Fonctionnaire	7400	39	UMP	Les Républicains	-A	LOIS	LOIS	820	Tarn-et-Garonne	Secrétaire du Sénat	f.bonhomme@senat.fr	BONHOMME	NON	168	2014-09-17 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/bonhomme-francois.html
19758L	Mme	Brulin	BRULIN_CELINE	Céline	1970-03-04 00:00:00	\N	ACTIF	Attachée territoriale	3300	71	CRC	CRCE-K	\N	SOCI	SOCI	760	Seine-Maritime	\N	c.brulin@senat.fr	BRULIN	OUI	37	2018-05-31 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/brulin-celine.html
20142Y	Mme	de Marco	MARCO_DE_MONIQUE	Monique	1953-11-12 00:00:00	\N	ACTIF	Retraitée éducation nationale 	3400	61	GEST	GEST	\N	AFCL	AFCL	330	Gironde	\N	m.de-marco@senat.fr	de MARCO	OUI	307	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/de-marco-monique-20700.html
19347U	M.	Gontard	GONTARD_GUILLAUME	Guillaume	1971-03-11 00:00:00	\N	ACTIF	Architecte	3000	57	GEST	GEST	\N	ETRD	ETRD	380	Isère	\N	g.gontard@senat.fr	GONTARD	NON	248	2017-09-15 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/gontard-guillaume.html
19920C	M.	Chaudun	Chaudun_Christophe	Christophe	1969-11-20 00:00:00	\N	ANCIEN	\N	8000	80	NI	NI	\N	NEANT	Aucune	720	Sarthe	\N	\N	CHAUDUN	NON	\N	\N	\N	\N
19739H	M.	Prince	PRINCE_JEAN_PAUL	Jean-Paul	1944-07-08 00:00:00	\N	ANCIEN	Ancien fonctionnaire	8000	79	UC	UC	N	CDD	CDD	410	Loir-et-Cher	\N	\N	PRINCE	NON	\N	2017-11-03 00:00:00	2023-10-01 00:37:00	\N
19930E	Mme	André	Andre_Catherine	Catherine	1965-12-17 00:00:00	\N	ANCIEN	Conjointe salariée	5400	33	UMP	Les Républicains	\N	LOIS	LOIS	70	Ardèche	\N	catherine.andre@senat.fr	ANDRÉ	OUI	\N	\N	\N	\N
19295A	Mme	Conconne	CONCONNE_CATHERINE	Catherine	1963-05-18 00:00:00	\N	ACTIF	\N	8000	81	SOC	SER	\N	SOCI	SOCI	972	Martinique	Secrétaire du Sénat	c.conconne@senat.fr	CONCONNE	OUI	17	2017-09-15 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/conconne-catherine.html
19747H	M.	Bouloux	BOULOUX_YVES	Yves	1960-08-30 00:00:00	\N	ANCIEN	\N	8600	80	UMP	Les Républicains	\N	\N	AFCL	860	Vienne	\N	y.bouloux@senat.fr	BOULOUX	NON	\N	2017-12-18 00:00:00	2023-12-31 00:00:00	\N
19954N	Mme	Belrhiti	BELRHITI_CATHERINE	Catherine	1962-08-10 00:00:00	\N	ACTIF	Professeur d'histoire-géographie	4200	62	UMP	Les Républicains	\N	AFCL	AFCL	570	Moselle	\N	c.belrhiti@senat.fr	BELRHITI	OUI	226	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/belrhiti-catherine-19194.html
19369B	M.	Moga	MOGA_JEAN_PIERRE	Jean-Pierre	1947-05-19 00:00:00	\N	ANCIEN	Ancien chef de laboratoire	7000	39	UC	UC	N	CAE	CAE	470	Lot-et-Garonne	\N	jp.moga@senat.fr	MOGA	NON	\N	2017-09-15 00:00:00	2023-10-01 00:37:00	\N
19914E	M.	Cardenes	Cardenes_Stephane	Stéphane	1971-11-11 00:00:00	\N	ANCIEN	Fonctionnaire territorial	3300	72	UC	UC	-A	CDD	CDD	300	Gard	\N	\N	CARDENES	NON	\N	\N	\N	\N
20174H	Mme	Evrard	Evrard_Marie_Agnes	Marie	1957-06-10 00:00:00	\N	ANCIEN	Agricultrice	8600	10	LREM	RDPI	\N	CAE	CAE	890	Yonne	\N	ma.evrard@senat.fr	EVRARD	OUI	\N	\N	\N	\N
19269X	Mme	Rauscent	RAUSCENT_NOELLE	Noëlle	1946-10-10 00:00:00	\N	ANCIEN	\N	8000	80	LREM	RDPI	\N	CAE	CAE	890	Yonne	\N	\N	RAUSCENT	OUI	\N	2017-07-24 10:01:14	2018-02-15 16:48:35	\N
19515S	M.	Babary	BABARY_SERGE	Serge	1946-07-16 00:00:00	\N	ANCIEN	Chef d'entreprise	8000	29	UMP	Les Républicains	N	CAE	CAE	370	Indre-et-Loire	\N	s.babary@senat.fr	BABARY	NON	\N	2017-09-19 00:00:00	2023-10-01 00:37:00	\N
20036X	M.	Parigi	PARIGI_PAUL_TOUSSAINT	Paul Toussaint	1966-04-07 00:00:00	\N	ACTIF	Fonctionnaire de l'éducation nationale	3300	72	UC	UC	-R	LOIS	LOIS	205	Haute-Corse	\N	pt.parigi@senat.fr	PARIGI	NON	258	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/parigi-paul-toussaint-20910.html
20042V	M.	Bonneau	BONNEAU_FRANCOIS	François	1958-02-08 00:00:00	\N	ACTIF	Docteur en pharmacie	3100	57	UC	UC	-A	ETRD	ETRD	160	Charente	\N	f.bonneau@senat.fr	BONNEAU	NON	265	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/bonneau-francois-9270.html
20048C	M.	Hingray	HINGRAY_JEAN	Jean	1986-07-19 00:00:00	\N	ACTIF	Responsable d'entreprise	8500	21	UC	UC	\N	AFCL	AFCL	880	Vosges	\N	j.hingray@senat.fr	HINGRAY	NON	316	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/hingray-jean-20701.html
20050V	Mme	Paoli-Gagin	PAOLI_GAGIN_VANINA	Vanina	1967-01-25 00:00:00	\N	ACTIF	Avocat	3100	57	RTLI	Les Indépendants	\N	FINC	FINC	100	Aube	\N	v.paoli-gagin@senat.fr	PAOLI-GAGIN	NON	203	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/paoli-gagin-vanina-20708.html
20058E	M.	Vial	VIAL_CEDRIC	Cédric	1978-03-25 00:00:00	\N	ACTIF	Sans profession	8500	80	UMP	Les Républicains	-R	AFCL	AFCL	730	Savoie	\N	c.vial@senat.fr	VIAL	NON	348	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/vial-cedric.html
20064C	M.	Vallet	VALLET_MICKAEL	Mickaël	1979-05-26 00:00:00	\N	ACTIF	Diplomate	3300	71	SOC	SER	\N	ETRD	ETRD	170	Charente-Maritime	Secrétaire du Sénat	m.vallet@senat.fr	VALLET	NON	16	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/vallet-mickael-20712.html
20068G	M.	Gueret	GUERET_DANIEL	Daniel	1961-04-17 00:00:00	\N	ACTIF	Directeur commercial	3700	32	UMP	Les Républicains	-R	CDD	CDD	280	Eure-et-Loir	\N	d.gueret@senat.fr	GUERET	NON	345	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/gueret-daniel.html
20084G	M.	Stanzione	STANZIONE_LUCIEN	Lucien	1950-08-19 00:00:00	\N	ACTIF	Retraité	7400	39	SOC	SER	\N	CAE	CAE	840	Vaucluse	\N	l.stanzione@senat.fr	STANZIONE	NON	110	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/stanzione-lucien-20711.html
20086J	M.	Blanc	BLANC_JEAN_BAPTISTE	Jean-Baptiste	1972-09-03 00:00:00	\N	ACTIF	Avocat	3100	57	UMP	Les Républicains	\N	FINC	FINC	840	Vaucluse	\N	senateurjbblanc@gmail.com	BLANC	NON	273	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/blanc-jean-baptiste-1299.html
20094J	Mme	Blatrix Contat	BLATRIX_CONTAT_FLORENCE	Florence	1966-03-30 00:00:00	\N	ACTIF	Professeur agrégé	3400	61	SOC	SER	\N	FINC	FINC	10	Ain	\N	f.blatrix-contat@senat.fr	BLATRIX CONTAT	OUI	189	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/blatrix-contat-florence-20162.html
20102Q	M.	Lahellec	LAHELLEC_GERARD	Gérard	1954-04-04 00:00:00	\N	ACTIF	Retraité	7400	39	CRC	CRCE-K	\N	AFCL	AFCL	220	Côtes-d'Armor	\N	g.lahellec@senat.fr	LAHELLEC	NON	234	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/lahellec-gerard.html
20104S	M.	Cadec	CADEC_ALAIN	Alain	1953-06-21 00:00:00	\N	ACTIF	Retraité	7400	39	UMP	Les Républicains	-A	CAE	CAE	220	Côtes-d'Armor	\N	a.cadec@senat.fr	CADEC	NON	281	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/cadec-alain.html
20106U	Mme	Havet	HAVET_NADEGE	Nadège	1975-12-30 00:00:00	\N	ACTIF	Responsable d'équipe	3300	71	LREM	RDPI	\N	CDD	CDD	290	Finistère	\N	n.havet@senat.fr	HAVET	OUI	79	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/havet-nadege-20702.html
20118Y	Mme	Pluchet	PLUCHET_KRISTINA	Kristina	1973-05-01 00:00:00	\N	ACTIF	salariée	1200	10	UMP	Les Républicains	\N	CDD	CDD	270	Eure	\N	k.pluchet@senat.fr	PLUCHET	OUI	170	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/pluchet-kristina-20710.html
20124W	Mme	Drexler	DREXLER_SABINE	Sabine	1963-08-17 00:00:00	\N	ACTIF	Professeur des écoles	4200	63	UMP	Les Républicains	-A	AFCL	AFCL	680	Haut-Rhin	\N	s.drexler@senat.fr	DREXLER	NON	329	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/drexler-sabine-20705.html
20126Y	M.	Klinger	KLINGER_CHRISTIAN	Christian	1968-12-15 00:00:00	\N	ACTIF	Exploitant agricole et viticole	3700	10	UMP	Les Républicains	\N	FINC	FINC	680	Haut-Rhin	\N	c.klinger@senat.fr	KLINGER	NON	328	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/klinger-christian-17670.html
20128B	M.	Haye	HAYE_LUDOVIC	Ludovic	1975-01-18 00:00:00	\N	ACTIF	Ingénieur en cybersécurité	3800	31	LREM	RDPI	\N	ETRD	ETRD	680	Haut-Rhin	\N	l.haye@senat.fr	HAYE	NON	48	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/haye-ludovic-19557.html
19285X	M.	Dutheil	Dutheil_Laurent	Laurent	1956-04-04 00:00:00	\N	ANCIEN	\N	8000	80	SOC	SER	\N	LOIS	LOIS	824	Val-de-Marne	\N	\N	DUTHEIL	NON	\N	2017-07-31 12:02:13	2017-10-04 09:52:11	\N
19749K	Mme	Vérien	VERIEN_DOMINIQUE	Dominique	1965-08-29 00:00:00	\N	ACTIF	Ingénieure	3800	31	UC	UC	\N	LOIS	LOIS	890	Yonne	\N	d.verien@senat.fr	VÉRIEN	OUI	210	2017-12-18 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/verien-dominique.html
19745F	Mme	Perrot	PERROT_EVELYNE	Évelyne	1951-06-22 00:00:00	\N	ACTIF	\N	8600	80	UC	UC	\N	ETRD	ETRD	100	Aube	\N	\N	PERROT	OUI	89	2017-12-18 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/perrot-evelyne.html
19826F	M.	Martin	MARTIN_PASCAL	Pascal	1960-03-07 00:00:00	\N	ACTIF	Officier supérieur des sapeurs pompiers	7400	39	UC	UC	\N	CDD	CDD	760	Seine-Maritime	\N	p.martin@senat.fr	MARTIN	NON	211	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/martin-pascal-5947.html
19667J	M.	Bazin	BAZIN_ARNAUD	Arnaud	1959-01-10 00:00:00	\N	ACTIF	Vétérinaire	3115	46	UMP	Les Républicains	\N	FINC	FINC	828	Val-d'Oise	\N	a.bazin@senat.fr	BAZIN	NON	178	2017-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/bazin-arnaud-473.html
19669L	M.	Temal	TEMAL_RACHID	Rachid	1973-03-29 00:00:00	\N	ACTIF	Cadre supérieur	8000	32	SOC	SER	\N	ETRD	ETRD	828	Val-d'Oise	\N	r.temal@senat.fr	TEMAL	NON	113	2017-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/temal-rachid.html
19671E	M.	Meurant	MEURANT_SEBASTIEN	Sébastien	1971-03-18 00:00:00	\N	ANCIEN	Chef d'entreprise de conseil	2300	21	UMP	Les Républicains	N	FINC	FINC	828	Val-d'Oise	\N	s.meurant@senat.fr	MEURANT	NON	\N	2017-09-24 00:00:00	2023-10-01 00:37:00	\N
19673G	Mme	Eustache-Brinio	EUSTACHE_BRINIO_JACQUELINE	Jacqueline	1956-09-05 00:00:00	\N	ACTIF	Ancienne enseignante	7000	69	UMP	Les Républicains	\N	LOIS	LOIS	828	Val-d'Oise	\N	j.eustache-brinio@senat.fr	EUSTACHE-BRINIO	OUI	181	2017-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/eustache-brinio-jacqueline.html
19677L	Mme	Lefebvre	LEFEBVRE_Nadege	Nadège	1960-10-25 00:00:00	\N	ANCIEN	Fonctionnaire	8000	73	UMP	Les Républicains	\N	CDD	CDD	600	Oise	\N	n.lefebvre@senat.fr	LEFEBVRE	OUI	\N	2017-09-24 17:29:36	2017-11-24 23:59:34	\N
19679N	Mme	Puissat	PUISSAT_FREDERIQUE	Frédérique	1967-11-04 00:00:00	\N	ACTIF	Cadre financier	3700	32	UMP	Les Républicains	\N	SOCI	SOCI	380	Isère	\N	f.puissat@senat.fr	PUISSAT	NON	92	2017-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/puissat-frederique.html
19685L	Mme	Herzog	HERZOG_CHRISTINE	Christine	1968-12-30 00:00:00	\N	ACTIF	Gérante	2200	21	UC	UC	-R	CDD	CDD	570	Moselle	\N	c.herzog@senat.fr	HERZOG	OUI	324	2017-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/herzog-christine.html
19695N	M.	Gay	GAY_FABIEN	Fabien	1984-01-13 00:00:00	\N	ACTIF	Directeur événementiel	3735	32	CRC	CRCE-K	\N	CAE	CAE	775	Seine-Saint-Denis	\N	f.gay@senat.fr	GAY	NON	140	2017-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/gay-fabien.html
19697Q	M.	Lévrier	LEVRIER_MARTIN	Martin	1962-10-30 00:00:00	\N	ACTIF	Secrétaire général	3300	32	LREM	RDPI	\N	AFCL	AFCL	895	Yvelines	\N	m.levrier@senat.fr	LÉVRIER	NON	115	2017-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/levrier-martin.html
19699S	M.	Laugier	LAUGIER_MICHEL	Michel	1956-07-11 00:00:00	\N	ACTIF	Journaliste	3511	54	UC	UC	-A	AFCL	AFCL	895	Yvelines	\N	m.laugier@senat.fr	LAUGIER	NON	159	2017-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/laugier-michel.html
19701S	Mme	de Cidrac	CIDRAC_MARTA	Marta	1964-06-13 00:00:00	\N	ACTIF	Architecte	3100	57	UMP	Les Républicains	\N	CDD	CDD	895	Yvelines	\N	m.de-cidrac@senat.fr	de CIDRAC	OUI	127	2017-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/de-cidrac-marta.html
19703U	M.	Sol	SOL_JEAN	Jean	1952-06-03 00:00:00	\N	ACTIF	Directeur des Soins	3300	71	UMP	Les Républicains	\N	SOCI	SOCI	660	Pyrénées-Orientales	\N	j.sol@senat.fr	SOL	NON	8	2017-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/sol-jean.html
19705W	Mme	Renaud-Garabedian	RENAUD_GARABEDIAN_EVELYNE	Évelyne	1950-06-18 00:00:00	\N	ACTIF	Chef d'entreprise	2300	21	UMP	Les Républicains	-R	CAE	CAE	1053	Français établis hors de France	\N	e.renaud-garabedian@senat.fr	RENAUD-GARABEDIAN	NON	335	2017-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/renaud-garabedian-evelyne.html
19707Y	M.	Bansard	BANSARD_Jean_Pierre	Jean-Pierre	1940-05-15 00:00:00	\N	ACTIF	Président de compagnie	2300	21	UMP	Les Républicains	-R	CAE	CAE	1054	Français établis hors de France	\N	jp.bansard@senat.fr	BANSARD	NON	334	2017-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/bansard-jean-pierre.html
19709B	M.	Le Gleut	LE_GLEUT_RONAN	Ronan	1976-08-21 00:00:00	\N	ACTIF	Examinateur à l'office européen des brevets	8000	31	UMP	Les Républicains	\N	ETRD	ETRD	1053	Français établis hors de France	\N	r.le-gleut@senat.fr	LE GLEUT	NON	342	2017-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/le-gleut-ronan.html
19565D	Mme	Gréaume	GREAUME_MICHELLE	Michelle	1967-10-30 00:00:00	\N	ACTIF	Fonctionnaire territoriale	3300	72	CRC	CRCE-K	\N	ETRD	ETRD	590	Nord	\N	m.greaume@senat.fr	GRÉAUME	OUI	184	2017-09-21 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/greaume-michelle.html
19569H	M.	Henno	HENNO_OLIVIER	Olivier	1962-04-21 00:00:00	\N	ACTIF	Cadre commercial	3700	32	UC	UC	\N	SOCI	SOCI	590	Nord	\N	o.henno@senat.fr	HENNO	NON	208	2017-09-21 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/henno-olivier-4541.html
19619A	Mme	Saint-Pé	SAINT_PE_DENISE	Denise	1951-01-05 00:00:00	\N	ACTIF	\N	8000	80	UC	UC	\N	CDD	CDD	640	Pyrénées-Atlantiques	\N	d.saint-pe@senat.fr	SAINT-PÉ	NON	160	2017-09-22 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/saint-pe-denise-7859.html
19621T	M.	Brisson	BRISSON_MAX	Max	1957-03-08 00:00:00	\N	ACTIF	Inspecteur général de l'Éducation nationale	3300	64	UMP	Les Républicains	\N	AFCL	AFCL	640	Pyrénées-Atlantiques	\N	m.brisson@senat.fr	BRISSON	NON	13	2017-09-22 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/brisson-max-1869.html
20264J	M.	Chantrel	CHANTREL_Yan	Yan	1979-04-14 00:00:00	\N	ACTIF	Coordonnateur 	4600	33	SOC	SER	\N	AFCL	AFCL	1054	Français établis hors de France	\N	y.chantrel@senat.fr	CHANTREL	NON	300	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/chantrel-yan-22958.html
20266L	Mme	Vogel	VOGEL_Melanie	Mélanie	1985-05-22 00:00:00	\N	ACTIF	Conseillère politique	3300	73	GEST	GEST	\N	LOIS	LOIS	1054	Français établis hors de France	\N	m.vogel@senat.fr	VOGEL	OUI	249	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/vogel-melanie-22959.html
19319Q	M.	Poadja	POADJA_GERARD	Gérard	1963-09-30 00:00:00	\N	ANCIEN	Contractuel ADRAF	3700	32	UC	UC	A	ETRD	ETRD	982	Nouvelle-Calédonie	\N	g.poadja@senat.fr	POADJA	NON	\N	2017-09-15 00:00:00	2023-10-01 00:37:00	\N
19329S	M.	Hassani	HASSANI_ABDALLAH	Abdallah	1954-07-02 00:00:00	\N	ANCIEN	Ancien enseignant	7000	69	LREM	RDPI	N	SOCI	SOCI	990	Mayotte	\N	a.hassani@senat.fr	HASSANI	NON	\N	2017-09-15 00:00:00	2023-10-01 00:37:00	\N
19331L	M.	Omar Oili	OMAR_OILI_Said	Saïd	1957-06-20 00:00:00	\N	ACTIF	Retraité	3511	54	LREM	RDPI	\N	CDD	CDD	990	Mayotte	\N	s.omar-oili@senat.fr	OMAR OILI	NON	251	2017-09-15 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/omar-oili-said-14866.html
19335Q	M.	Mizzon	MIZZON_JEAN_MARIE	Jean-Marie	1956-03-31 00:00:00	\N	ACTIF	Chargé de mission	3300	71	UC	UC	\N	FINC	FINC	570	Moselle	\N	jm.mizzon@senat.fr	MIZZON	NON	323	2017-09-15 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/mizzon-jean-marie.html
19349W	M.	Rambaud	RAMBAUD_DIDIER	Didier	1959-05-12 00:00:00	\N	ACTIF	Cadre administratif	3300	72	LREM	RDPI	\N	FINC	FINC	380	Isère	\N	d.rambaud@senat.fr	RAMBAUD	NON	114	2017-09-15 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/rambaud-didier.html
19367Y	Mme	Bonfanti-Dossat	BONFANTI_DOSSAT_CHRISTINE	Christine	1956-05-25 00:00:00	\N	ACTIF	Infirmière libérale	4300	47	UMP	Les Républicains	\N	SOCI	SOCI	470	Lot-et-Garonne	\N	c.bonfanti-dossat@senat.fr	BONFANTI-DOSSAT	NON	36	2017-09-15 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/bonfanti-dossat-christine.html
19467C	Mme	Chauvin	CHAUVIN_MARIE_CHRISTINE	Marie-Christine	1954-11-20 00:00:00	\N	ANCIEN	Ancienne responsable hospitalière	7000	39	UMP	Les Républicains	N	CAE	CAE	390	Jura	\N	mc.chauvin@senat.fr	CHAUVIN	NON	\N	2017-09-18 00:00:00	2023-10-01 00:37:00	\N
19479G	Mme	Vermeillet	VERMEILLET_SYLVIE	Sylvie	1967-06-10 00:00:00	\N	ACTIF	Comptable	3700	32	UC	UC	\N	FINC	FINC	390	Jura	Vice-présidente du Sénat	s.vermeillet@senat.fr	VERMEILLET	OUI	260	2017-09-18 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/vermeillet-sylvie.html
19483C	M.	Leroux	LEROUX_Sebastien	Sébastien	1974-02-27 00:00:00	\N	ANCIEN	Chargé de mission en communication	8000	73	UMP	Les Républicains	\N	LOIS	LOIS	610	Orne	\N	s.leroux@senat.fr	LEROUX	NON	\N	2017-09-18 17:35:47	2018-04-13 17:54:29	\N
19489J	M.	Kerrouche	KERROUCHE_ERIC	Éric	1967-10-02 00:00:00	\N	ACTIF	Directeur de recherche au CNRS	3400	61	SOC	SER	\N	LOIS	LOIS	400	Landes	\N	e.kerrouche@senat.fr	KERROUCHE	NON	108	2017-09-18 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/kerrouche-eric-5218.html
19507S	M.	Duplomb	DUPLOMB_LAURENT	Laurent	1971-10-24 00:00:00	\N	ACTIF	Agriculteur	1000	10	UMP	Les Républicains	\N	CAE	CAE	430	Haute-Loire	\N	l.duplomb@senat.fr	DUPLOMB	NON	332	2017-09-18 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/duplomb-laurent.html
19511N	M.	Janssens	JANSSENS_JEAN_MARIE	Jean-Marie	1953-03-19 00:00:00	\N	ANCIEN	Ancien agriculteur-éleveur	7100	10	UC	UC	N	SOCI	SOCI	410	Loir-et-Cher	\N	jm.janssens@senat.fr	JANSSENS	NON	\N	2017-09-18 00:00:00	2023-10-01 00:37:00	\N
19675J	Mme	Thomas	THOMAS_CLAUDINE	Claudine	1961-08-19 00:00:00	\N	ANCIEN	\N	8000	80	UMP	Les Républicains	N	LOIS	LOIS	770	Seine-et-Marne	\N	c.thomas@senat.fr	THOMAS	OUI	\N	2017-09-24 00:00:00	2023-10-01 00:37:00	\N
19681G	M.	Corbisez	CORBISEZ_JEAN_PIERRE	Jean-Pierre	1960-03-07 00:00:00	\N	ACTIF	Ingénieur en aménagement du territoire	3800	31	CRC	CRCE-K	\N	CDD	CDD	620	Pas-de-Calais	\N	jp.corbisez@senat.fr	CORBISEZ	NON	235	2017-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/corbisez-jean-pierre-2112.html
19683J	M.	Jomier	JOMIER_BERNARD	Bernard	1963-10-09 00:00:00	\N	ACTIF	Médecin	3112	42	SOC	SER	\N	SOCI	SOCI	615	Paris	\N	b.jomier@senat.fr	JOMIER	NON	74	2017-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/jomier-bernard.html
19687N	M.	Savoldelli	SAVOLDELLI_PASCAL	Pascal	1961-01-14 00:00:00	\N	ACTIF	Employé de la fonction publique territoriale	4500	72	CRC	CRCE-K	\N	FINC	FINC	824	Val-de-Marne	\N	p.savoldelli@senat.fr	SAVOLDELLI	NON	69	2017-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/savoldelli-pascal-7907.html
19689Q	Mme	Taillé-Polian	TAILLE_POLIAN_SOPHIE	Sophie	1974-10-04 00:00:00	\N	ANCIEN	Fonctionnaire territoriale	8000	73	GEST	GEST	\N	FINC	FINC	824	Val-de-Marne	\N	s.taille-polian@senat.fr	TAILLÉ-POLIAN	OUI	\N	2017-09-24 17:55:12	2017-10-04 18:45:52	\N
19691J	Mme	Guidez	GUIDEZ_JOCELYNE	Jocelyne	1956-09-26 00:00:00	\N	ACTIF	Artiste	3500	81	UC	UC	\N	SOCI	SOCI	265	Essonne	\N	j.guidez@senat.fr	GUIDEZ	OUI	26	2017-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/guidez-jocelyne.html
19693L	Mme	Darcos	DARCOS_LAURE	Laure	1970-11-27 00:00:00	\N	ACTIF	\N	8000	80	RTLI	Les Indépendants	\N	AFCL	AFCL	265	Essonne	\N	l.darcos@senat.fr	DARCOS	OUI	255	2017-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/darcos-laure.html
19711U	Mme	Lavarde	LAVARDE_CHRISTINE	Christine	1984-10-16 00:00:00	\N	ACTIF	Ingénieur du Corps des Ponts	3300	71	UMP	Les Républicains	\N	FINC	FINC	335	Hauts-de-Seine	\N	c.lavarde@senat.fr	LAVARDE	NON	11	2017-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/lavarde-christine.html
19713W	Mme	Sollogoub	SOLLOGOUB_NADIA	Nadia	1961-11-09 00:00:00	\N	ACTIF	Mère au foyer	8000	80	UC	UC	\N	SOCI	SOCI	580	Nièvre	\N	n.sollogoub@senat.fr	SOLLOGOUB	NON	214	2017-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/sollogoub-nadia.html
19503N	Mme	Préville	PREVILLE_ANGELE	Angèle	1955-11-23 00:00:00	\N	ANCIEN	Ancien professeur	7000	69	SOC	SER	N	CDD	CDD	460	Lot	\N	\N	PRÉVILLE	OUI	\N	2017-09-18 00:00:00	2023-10-01 00:37:00	\N
19719D	Mme	Delattre	DELATTRE_NATHALIE	Nathalie	1968-12-02 00:00:00	\N	ACTIF	\N	8500	80	RDSE	RDSE	\N	LOIS	LOIS	330	Gironde	\N	n.delattre@senat.fr	DELATTRE	OUI	4	2017-10-01 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/delattre-nathalie.html
19573D	M.	Paccaud	PACCAUD_OLIVIER	Olivier	1969-04-13 00:00:00	\N	ACTIF	Professeur agrégé d'histoire-géographie	3400	61	UMP	Les Républicains	-A	FINC	FINC	600	Oise	\N	o.paccaud@senat.fr	PACCAUD	NON	98	2017-09-21 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/paccaud-olivier.html
19575F	Mme	Berthet	BERTHET_MARTINE	Martine	1961-03-27 00:00:00	\N	ACTIF	Pharmacienne	3100	57	UMP	Les Républicains	\N	CAE	CAE	730	Savoie	\N	m.berthet@senat.fr	BERTHET	OUI	33	2017-09-21 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/berthet-martine-885.html
19741B	M.	Bascher	BASCHER_JEROME	Jérôme	1973-05-31 00:00:00	\N	ANCIEN	Attaché statisticien hors classe	3300	72	UMP	Les Républicains	N	FINC	FINC	600	Oise	\N	j.bascher@senat.fr	BASCHER	NON	\N	2017-11-24 00:00:00	2023-10-01 00:37:00	\N
19766L	M.	Regnard	REGNARD_DAMIEN	Damien	1966-02-24 00:00:00	\N	ANCIEN	\N	8000	80	UMP	Les Républicains	N	AFCL	AFCL	1053	Français établis hors de France	\N	d.regnard@senat.fr	REGNARD	NON	\N	\N	2023-10-01 00:37:00	\N
20018V	M.	Michau	MICHAU_JEAN_JACQUES	Jean-Jacques	1956-07-23 00:00:00	\N	ACTIF	Retraité	7500	39	SOC	SER	\N	CAE	CAE	90	Ariège	\N	jj.michau@senat.fr	MICHAU	NON	237	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/michau-jean-jacques-20703.html
20022R	Mme	Bellurot	BELLUROT_NADINE	Nadine	1965-04-05 00:00:00	\N	ACTIF	Inspectrice Générale de l'Administration du Développement Durable (IGADD)	3300	71	UMP	Les Républicains	-A	LOIS	LOIS	360	Indre	\N	n.bellurot@senat.fr	BELLUROT	OUI	132	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/bellurot-nadine-995.html
20024T	M.	Belin	BELIN_BRUNO	Bruno	1962-06-08 00:00:00	\N	ACTIF	Pharmacien	3100	57	UMP	Les Républicains	-R	FINC	FINC	860	Vienne	\N	b.belin@senat.fr	BELIN	NON	278	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/belin-bruno-686.html
20026V	Mme	Ventalon	VENTALON_ANNE	Anne	1972-01-07 00:00:00	\N	ACTIF	Enseignante	3400	61	UMP	Les Républicains	-A	AFCL	AFCL	70	Ardèche	\N	a.ventalon@senat.fr	VENTALON	OUI	227	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/ventalon-anne-20690.html
19251M	M.	Devinaz	DEVINAZ_GILBERT_LUC	Gilbert-Luc	1953-07-19 00:00:00	\N	ACTIF	\N	7400	39	SOC	SER	\N	CDD	CDD	690	Rhône	\N	\N	DEVINAZ	NON	297	2017-06-19 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/devinaz-gilbert-luc.html
19387D	M.	Gold	GOLD_ERIC	Éric	1964-06-07 00:00:00	\N	ACTIF	Professeur des écoles	4200	63	RDSE	RDSE	\N	CDD	CDD	630	Puy-de-Dôme	\N	e.gold@senat.fr	GOLD	NON	118	2017-09-18 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/gold-eric-4022.html
19413M	M.	Tissot	TISSOT_JEAN_CLAUDE	Jean-Claude	1963-09-22 00:00:00	\N	ACTIF	Agriculteur	1000	10	SOC	SER	\N	CAE	CAE	420	Loire	\N	jc.tissot@senat.fr	TISSOT	NON	299	2017-09-18 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/tissot-jean-claude.html
19415P	M.	Bonne	BONNE BERNARD	Bernard	1948-09-18 00:00:00	\N	ANCIEN	Médecin	3112	42	UMP	Les Républicains	N	SOCI	SOCI	420	Loire	\N	b.bonne@senat.fr	BONNE	NON	\N	2017-09-18 00:00:00	2023-10-01 00:37:00	\N
19447X	Mme	Jourda	JOURDA_MURIEL	Muriel	1967-10-27 00:00:00	\N	ACTIF	Avocat	3121	51	UMP	Les Républicains	\N	LOIS	LOIS	560	Morbihan	\N	m.jourda@senat.fr	JOURDA	NON	232	2017-09-18 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/jourda-muriel.html
20298U	Mme	Ract-Madoux	Ract_Madoux_Daphne	Daphné	1972-05-13 00:00:00	\N	ANCIEN	Architecte - directrice de projets	3800	81	UC	UC	N	CAE	CAE	265	Essonne	\N	d.ract-madoux@senat.fr	RACT-MADOUX	OUI	\N	\N	2023-10-01 00:37:00	\N
19265T	M.	Lecornu	Lecornu_Sebastien	Sébastien	1986-06-11 00:00:00	\N	ANCIEN	\N	3300	71	LREM	RDPI	\N	ETRD	ETRD	270	Eure	\N	s.lecornu@senat.fr	LECORNU	NON	\N	2017-06-22 11:08:44	2017-09-25 13:16:08	\N
20180F	Mme	Gosselin	GOSSELIN_BEATRICE	Béatrice	1958-03-27 00:00:00	\N	ACTIF	Retraitée de l'éducation nationale	4200	80	UMP	Les Républicains	-A	AFCL	AFCL	500	Manche	\N	b.gosselin@senat.fr	GOSSELIN	OUI	228	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/gosselin-beatrice-21171.html
20286Q	Mme	Gacquerre	GACQUERRE_Amel	Amel	1976-12-20 00:00:00	\N	ACTIF	Consultante	3100	81	UC	UC	\N	CAE	CAE	620	Pas-de-Calais	\N	a.gacquerre@senat.fr	GACQUERRE	OUI	6	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/gacquerre-amel-22328.html
20054A	M.	Rietmann	RIETMANN_OLIVIER	Olivier	1971-11-22 00:00:00	\N	ACTIF	Exploitant agricole	1200	10	UMP	Les Républicains	\N	CAE	CAE	700	Haute-Saône	\N	o.rietmann@senat.fr	RIETMANN	NON	327	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/rietmann-olivier-20714.html
20116W	M.	Bilhac	BILHAC_CHRISTIAN	Christian	1955-04-10 00:00:00	\N	ACTIF	Retraité	7500	39	RDSE	RDSE	\N	FINC	FINC	340	Hérault	\N	c.bilhac@senat.fr	BILHAC	NON	49	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/bilhac-christian-20723.html
19521Q	Mme	Fournier	FOURNIER_CATHERINE	Catherine	1955-09-16 00:00:00	2021-12-07 00:00:00	ANCIEN	Ancien chef d'entreprise	7200	29	UC	UC	\N	CAE	CAE	620	Pas-de-Calais	\N	c.fournier@senat.fr	FOURNIER	OUI	\N	2017-09-19 16:03:29	2017-10-04 18:55:38	\N
19525U	M.	Dagbert	DAGBERT_MICHEL	Michel	1962-01-28 00:00:00	\N	ANCIEN	Aide-soignant	4300	47	LREM	RDPI	N	CDD	CDD	620	Pas-de-Calais	\N	m.dagbert@senat.fr	DAGBERT	NON	\N	2017-09-19 00:00:00	2023-10-01 00:37:00	\N
19527W	Mme	Van Heghe	VAN_HEGHE_SABINE	Sabine	1960-09-08 00:00:00	\N	ANCIEN	Assistante de direction	3300	72	SOC	SER	N	AFCL	AFCL	620	Pas-de-Calais	\N	s.van-heghe@senat.fr	VAN HEGHE	OUI	\N	2017-09-19 00:00:00	2023-10-01 00:37:00	\N
19533U	M.	Piednoir	PIEDNOIR_STEPHANE	Stéphane	1970-02-25 00:00:00	\N	ACTIF	Professeur	3400	62	UMP	Les Républicains	\N	AFCL	AFCL	490	Maine-et-Loire	\N	s.piednoir@senat.fr	PIEDNOIR	NON	169	2017-09-19 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/piednoir-stephane.html
19912C	Mme	Schoeller	Schoeller_Noelle	Marie-Noëlle	1946-12-12 00:00:00	\N	ANCIEN	Pensionnée de l'Éducation nationale	7000	79	SOC	SER	\N	CAE	CAE	250	Doubs	\N	\N	SCHOELLER	OUI	\N	\N	\N	\N
19958S	Mme	Garcia	Garcia_Daniele	Danièle	1948-03-12 00:00:00	\N	ANCIEN	Retraitée (agent immobilier)	7300	39	RDSE	RDSE	\N	SOCI	SOCI	130	Bouches-du-Rhône	\N	d.garcia@senat.fr	GARCIA	OUI	\N	\N	\N	\N
19968U	Mme	Einaudi	Einaudi_Michele	Michèle	1953-06-26 00:00:00	\N	ANCIEN	\N	8000	80	SOC	SER	\N	AFCL	AFCL	130	Bouches-du-Rhône	\N	\N	EINAUDI	OUI	\N	\N	\N	\N
19966S	M.	Boré	BORE_PATRICK	Patrick	1956-11-09 00:00:00	2021-07-05 00:00:00	ANCIEN	Pharmacien	3116	57	UMP	Les Républicains	\N	SOCI	SOCI	130	Bouches-du-Rhône	\N	p.bore@senat.fr	BORÉ	NON	\N	\N	\N	\N
19057M	Mme	Cazebonne	CAZEBONNE_Samantha	Samantha	1971-08-10 00:00:00	\N	ACTIF	Chef d'établissement de l'enseignement secondaire	3300	64	LREM	RDPI	\N	AFCL	AFCL	1054	Français établis hors de France	\N	\N	CAZEBONNE	OUI	155	2017-06-19 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/cazebonne-samantha.html
11115U	M.	Courtial	COURTIAL ÉDOUARD	Édouard	1973-06-28 00:00:00	\N	ACTIF	Chargé de mission commercial	3700	32	UC	UC	\N	ETRD	ETRD	600	Oise	\N	e.courtial@senat.fr	COURTIAL	NON	318	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/courtial-edouard.html
19768N	Mme	Noël	NOEL_SYLVIANE	Sylviane	1978-01-27 00:00:00	\N	ACTIF	Attachée parlementaire	8500	80	UMP	Les Républicains	\N	CAE	CAE	740	Haute-Savoie	\N	s.noel@senat.fr	NOËL	OUI	336	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/noel-sylviane.html
20044X	M.	Sautarel	SAUTAREL_STEPHANE	Stéphane	1965-01-29 00:00:00	\N	ACTIF	Consultant	3100	57	UMP	Les Républicains	-A	FINC	FINC	150	Cantal	\N	s.sautarel@senat.fr	SAUTAREL	NON	134	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/sautarel-stephane-15271.html
20130U	Mme	Poncet Monge	PONCET_RAYMONDE	Raymonde	1951-08-01 00:00:00	\N	ACTIF	Directrice d'association	3700	32	GEST	GEST	\N	SOCI	SOCI	690	Rhône	\N	r.poncet@senat.fr	PONCET MONGE	OUI	306	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/poncet-monge-raymonde-20704.html
19111A	Mme	Florennes	FLORENNES_Isabelle	Isabelle	1967-08-02 00:00:00	\N	ACTIF	\N	8000	80	UC	UC	\N	LOIS	LOIS	335	Hauts-de-Seine	\N	i.florennes@senat.fr	FLORENNES	OUI	88	2017-06-19 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/florennes-isabelle.html
19289C	M.	Léonhardt	LEONHARDT_OLIVIER	Olivier	1964-01-29 00:00:00	2022-02-02 00:00:00	ANCIEN	\N	8500	35	RDSE	RDSE	\N	SOCI	SOCI	265	Essonne	\N	o.leonhardt@senat.fr	LÉONHARDT	NON	\N	2017-09-14 11:04:38	2017-10-04 18:56:08	\N
19760E	Mme	Apourceau-Poly	APOURCEAU-POLY	Cathy	1965-04-18 00:00:00	\N	ACTIF	Attachée territoriale	8000	80	CRC	CRCE-K	\N	SOCI	SOCI	620	Pas-de-Calais	\N	c.apourceau-poly@senat.fr	APOURCEAU-POLY	OUI	38	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/apourceau-poly-cathy.html
19762G	M.	Segouin	SEGOUIN	Vincent	1972-07-01 00:00:00	\N	ANCIEN	Agent d'assurance	7500	80	UMP	Les Républicains	N	FINC	FINC	610	Orne	\N	v.segouin@senat.fr	SEGOUIN	NON	\N	\N	2023-10-01 00:37:00	\N
21063F	M.	Bruyen	BRUYEN_CHRISTIAN	Christian	1959-03-30 00:00:00	\N	ACTIF	Professeur des écoles, instituteur et assimilé	7500	81	UMP	Les Républicains	-A	AFCL	AFCL	510	Marne	\N	c.bruyen@senat.fr	BRUYEN	NON	346	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/bruyen-christian.html
21044C	Mme	Josende	JOSENDE_Lauriane	Lauriane	1977-06-13 00:00:00	\N	ACTIF	Avocat	3128	52	UMP	Les Républicains	\N	LOIS	LOIS	660	Pyrénées-Orientales	\N	l.josende@senat.fr	JOSENDE	OUI	102	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/josende-lauriane-14750.html
21041Y	M.	Daubet	DAUBET_Raphaël	Raphaël	1977-01-17 00:00:00	\N	ACTIF	Profession libérale	3128	52	RDSE	RDSE	\N	FINC	FINC	460	Lot	\N	r.daubet@senat.fr	DAUBET	NON	119	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/daubet-raphael-20101.html
21030V	M.	Xowie	XOWIE_Robert_Wienie	Robert Wienie	1962-08-29 00:00:00	\N	ACTIF	Ancien cadre	7400	79	CRC	CRCE-K	\N	ETRD	ETRD	982	Nouvelle-Calédonie	\N	rw.xowie@senat.fr	XOWIE	NON	185	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/xowie-robert-wienie26159.html
21051B	M.	Uzenat	UZENAT_Simon	Simon	1985-04-15 00:00:00	\N	ACTIF	Profession libérale	3128	52	SOC	SER	\N	CDD	CDD	560	Morbihan	\N	s.uzenat@senat.fr	UZENAT	NON	149	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/uzenat-simon-22835.html
21085M	M.	Hochart	HOCHART_Joshua	Joshua	1987-08-25 00:00:00	\N	ACTIF	Cadre de la fonction publique	3313	56	NI	NI	\N	CDD	CDD	590	Nord	\N	\N	HOCHART	NON	268	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/hochart-joshua-26161.html
20014R	Mme	Tubiana	Tubiana_Daniele	Danièle	1950-05-02 00:00:00	\N	ANCIEN	\N	8000	80	AUCUN	NI	\N	NEANT	Aucune	60	Alpes-Maritimes	\N	\N	TUBIANA	OUI	\N	\N	\N	\N
20032T	M.	Anglars	ANGLARS_JEAN_CLAUDE	Jean-Claude	1961-02-20 00:00:00	\N	ACTIF	Chargé de mission	3800	31	UMP	Les Républicains	\N	CDD	CDD	120	Aveyron	\N	jc.anglars@senat.fr	ANGLARS	NON	173	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/anglars-jean-claude.html
20052X	M.	Levi	LEVI_PIERRE_ANTOINE	Pierre-Antoine	1965-05-15 00:00:00	\N	ACTIF	cadre bancaire	3700	32	UC	UC	\N	AFCL	AFCL	820	Tarn-et-Garonne	\N	pa.levi@senat.fr	LEVI	NON	315	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/levi-pierre-antoine-20691.html
20056C	Mme	Joseph	JOSEPH_ELSE	Else	1961-12-24 00:00:00	\N	ACTIF	Professeur	3400	61	UMP	Les Républicains	\N	AFCL	AFCL	80	Ardennes	\N	e.joseph@senat.fr	JOSEPH	OUI	283	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/joseph-else-20706.html
20060X	M.	Cardon	CARDON_REMI	Rémi	1994-05-03 00:00:00	\N	ACTIF	Chef de projet numérique	3700	32	SOC	SER	\N	CAE	CAE	800	Somme	\N	r.cardon@senat.fr	CARDON	NON	186	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/cardon-remi-20693.html
20062A	M.	Somon	SOMON_LAURENT	Laurent	1957-12-28 00:00:00	\N	ACTIF	Vétérinaire 	3100	57	UMP	Les Républicains	\N	FINC	FINC	800	Somme	\N	l.somon@senat.fr	SOMON	NON	91	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/somon-laurent-8265.html
20066E	Mme	Jacquemet	JACQUEMET_ANNICK	Annick	1956-01-20 00:00:00	\N	ACTIF	Vétérinaire	3100	57	UC	UC	\N	CAE	CAE	250	Doubs	\N	a.jacquemet@senat.fr	JACQUEMET	OUI	86	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/jacquemet-annick-4471.html
20088L	M.	Bouad	BOUAD_DENIS	Denis	1952-11-01 00:00:00	\N	ACTIF	Retraité	7100	10	SOC	SER	\N	CAE	CAE	300	Gard	\N	d.bouad@senat.fr	BOUAD	NON	294	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/bouad-denis-1152.html
20090E	M.	Burgoa	BURGOA_LAURENT	Laurent	1969-02-04 00:00:00	\N	ACTIF	Sans profession	8500	80	UMP	Les Républicains	\N	SOCI	SOCI	300	Gard	\N	l.burgoa@senat.fr	BURGOA	NON	171	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/burgoa-laurent.html
20092G	M.	Salmon	SALMON_DANIEL	Daniel	1962-10-21 00:00:00	\N	ACTIF	Retraité de l'enseignement	7400	39	GEST	GEST	\N	CAE	CAE	350	Ille-et-Vilaine	\N	d.salmon@senat.fr	SALMON	NON	304	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/salmon-daniel-20689.html
20108W	M.	Le Rudulier	LE_RUDULIER_STEPHANE	Stéphane	1973-12-09 00:00:00	\N	ACTIF	Chargé d'enseignement	3400	61	UMP	Les Républicains	\N	LOIS	LOIS	130	Bouches-du-Rhône	\N	s.le-rudulier@senat.fr	LE RUDULIER	NON	280	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/le-rudulier-stephane-20911.html
20110Q	M.	Benarroche	BENARROCHE_GUY	Guy	1954-07-25 00:00:00	\N	ACTIF	Retraité	7400	39	GEST	GEST	\N	LOIS	LOIS	130	Bouches-du-Rhône	Secrétaire du Sénat	g.benarroche@senat.fr	BENARROCHE	NON	246	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/benarroche-guy-20692.html
20112S	M.	Bacchi	BACCHI_JEREMY	Jérémy	1986-03-08 00:00:00	\N	ACTIF	Permanent politique	4300	47	CRC	CRCE-K	\N	AFCL	AFCL	130	Bouches-du-Rhône	\N	j.bacchi@senat.fr	BACCHI	NON	236	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/bacchi-jeremy-20709.html
20132W	M.	Fialaire	FIALAIRE_BERNARD	Bernard	1957-09-13 00:00:00	\N	ACTIF	Médecin	3100	57	RDSE	RDSE	\N	AFCL	AFCL	690	Rhône	\N	b.fialaire@senat.fr	FIALAIRE	NON	51	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/fialaire-bernard.html
20134Y	M.	Dossus	DOSSUS_THOMAS	Thomas	1982-07-28 00:00:00	\N	ACTIF	Chargé de communication	4600	32	GEST	GEST	\N	FINC	FINC	690	Rhône	\N	t.dossus@senat.fr	DOSSUS	NON	197	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/dossus-thomas-20698.html
19301E	M.	Théophile	THEOPHILE_DOMINIQUE	Dominique	1960-08-04 00:00:00	\N	ACTIF	Contrôleur de gestion	3700	21	LREM	RDPI	\N	SOCI	SOCI	971	Guadeloupe	Vice-président du Sénat	d.theophile@senat.fr	THÉOPHILE	NON	22	2017-09-15 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/theophile-dominique.html
19545Y	M.	Capus	CAPUS_EMMANUEL	Emmanuel	1974-06-23 00:00:00	\N	ACTIF	Avocat	3121	51	RTLI	Les Indépendants	\N	FINC	FINC	490	Maine-et-Loire	\N	e.capus@senat.fr	CAPUS	NON	254	2017-09-20 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/capus-emmanuel.html
19549D	M.	Bigot	BIGOT_JOEL	Joël	1949-02-05 00:00:00	\N	ANCIEN	Ancien enseignant	7000	69	SOC	SER	N	CDD	CDD	490	Maine-et-Loire	\N	joel.bigot@senat.fr	BIGOT	NON	\N	2017-09-20 00:00:00	2023-10-01 00:37:00	\N
19551W	M.	Jacquin	JACQUIN_OLIVIER	Olivier	1964-05-08 00:00:00	\N	ACTIF	Agriculteur	1000	10	SOC	SER	\N	CDD	CDD	540	Meurthe-et-Moselle	\N	o.jacquin@senat.fr	JACQUIN	NON	298	2017-09-20 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/jacquin-olivier.html
19553Y	Mme	Guillotin	GUILLOTIN_VERONIQUE	Véronique	1962-11-03 00:00:00	\N	ACTIF	Médecin	3112	42	RDSE	RDSE	\N	SOCI	SOCI	540	Meurthe-et-Moselle	Secrétaire du Sénat	v.guillotin@senat.fr	GUILLOTIN	OUI	24	2017-09-20 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/guillotin-veronique-4702.html
20070A	M.	Cozic	COZIC_THIERRY	Thierry	1973-02-09 00:00:00	\N	ACTIF	Cadre territorial	3300	71	SOC	SER	\N	FINC	FINC	720	Sarthe	\N	t.cozic@senat.fr	COZIC	NON	40	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/cozic-thierry-17766.html
20072C	M.	Guiol	GUIOL_ANDRE	André	1954-06-28 00:00:00	\N	ACTIF	Ingénieur retraité	7400	39	RDSE	RDSE	\N	ETRD	ETRD	830	Var	\N	a.guiol@senat.fr	GUIOL	NON	50	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/guiol-andre-20722.html
20074E	Mme	Dumont	DUMONT_FRANCOISE	Françoise	1965-04-09 00:00:00	\N	ACTIF	Guide interprète	5600	81	UMP	Les Républicains	\N	LOIS	LOIS	830	Var	\N	f.dumont@senat.fr	DUMONT	OUI	65	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/dumont-francoise-14973.html
20078J	M.	Bonnus	BONNUS_MICHEL	Michel	1965-04-14 00:00:00	\N	ACTIF	Commerçant	2200	22	UMP	Les Républicains	\N	CAE	CAE	830	Var	\N	m.bonnus@senat.fr	BONNUS	NON	64	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/bonnus-michel.html
20080C	Mme	Briquet	BRIQUET_ISABELLE	Isabelle	1967-09-04 00:00:00	\N	ACTIF	Sans profession	8500	80	SOC	SER	\N	FINC	FINC	870	Haute-Vienne	\N	i.briquet@senat.fr	BRIQUET	OUI	106	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/briquet-isabelle-17778.html
20082E	M.	Redon-Sarrazy	REDON_SARRAZY_CHRISTIAN	Christian	1959-11-18 00:00:00	\N	ACTIF	Retraité	3400	61	SOC	SER	\N	CAE	CAE	870	Haute-Vienne	\N	c.redon-sarrazy@senat.fr	REDON-SARRAZY	NON	238	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/redon-sarrazy-christian-20724.html
20096L	Mme	Muller-Bronn	MULLER_BRONN_LAURENCE	Laurence	1961-11-04 00:00:00	\N	ACTIF	Guide interprète	3100	57	UMP	Les Républicains	-A	SOCI	SOCI	670	Bas-Rhin	\N	l.muller-bronn@senat.fr	MULLER-BRONN	OUI	229	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/muller-bronn-laurence-20699.html
20098N	Mme	Schalck	SCHALCK_ELSA	Elsa	1986-12-04 00:00:00	\N	ACTIF	Avocat	3100	57	UMP	Les Républicains	\N	LOIS	LOIS	670	Bas-Rhin	\N	e.schalck@senat.fr	SCHALCK	OUI	272	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/schalck-elsa.html
20100N	M.	Fernique	FERNIQUE_JACQUES	Jacques	1961-11-13 00:00:00	\N	ACTIF	Professeur des Lycées Professionnels	3400	61	GEST	GEST	\N	CDD	CDD	670	Bas-Rhin	\N	j.fernique@senat.fr	FERNIQUE	NON	303	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/fernique-jacques-20696.html
20122U	M.	Verzelen	VERZELEN_PIERRE_JEAN	Pierre-Jean	1983-08-29 00:00:00	\N	ACTIF	Cadre supérieur	8500	32	RTLI	Les Indépendants	\N	AFCL	AFCL	20	Aisne	\N	pj.verzelen@senat.fr	VERZELEN	NON	158	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/verzelen-pierre-jean-8728.html
19581D	Mme	Lherbier	LHERBIER_BRIGITTE	Brigitte	1956-06-21 00:00:00	\N	ANCIEN	Universitaire titulaire d'un doctorat de droit	3128	57	UMP	Les Républicains	N	LOIS	LOIS	590	Nord	\N	b.lherbier@senat.fr	LHERBIER	NON	\N	2017-09-22 00:00:00	2023-10-01 00:37:00	\N
19585H	M.	Wattebled	WATTEBLED_DANY	Dany	1951-11-22 00:00:00	\N	ACTIF	Ancien chef d'entreprise	7000	29	RTLI	Les Indépendants	\N	LOIS	LOIS	590	Nord	\N	d.wattebled@senat.fr	WATTEBLED	NON	314	2017-09-22 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/wattebled-dany.html
19599P	Mme	Filleul	FILLEUL_MARTINE	Martine	1953-06-06 00:00:00	\N	ANCIEN	Ancienne sociologue	7500	79	SOC	SER	N	CDD	CDD	590	Nord	Secrétaire du Sénat	m.filleul@senat.fr	FILLEUL	OUI	\N	2017-09-22 00:00:00	2023-10-01 00:37:00	\N
19812Y	Mme	Constant	CONSTANT_Agnes	Agnès	1962-04-16 00:00:00	\N	ANCIEN	Conjoint d'exploitant agricole	8000	80	LREM	RDPI	-A	CAE	CAE	340	Hérault	\N	a.constant@senat.fr	CONSTANT	OUI	\N	\N	\N	\N
19399H	M.	Hugonet	HUGONET_JEAN_RAYMOND	Jean-Raymond	1958-01-10 00:00:00	\N	ACTIF	Musicien	3500	57	UMP	Les Républicains	-A	FINC	FINC	265	Essonne	\N	jr.hugonet@senat.fr	HUGONET	NON	282	2017-09-18 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/hugonet-jean-raymond.html
21037D	Mme	Ollivier	OLLIVIER_Mathilde	Mathilde	1994-06-09 00:00:00	\N	ACTIF	Cadre administratif et commercial d'entreprise	3735	55	GEST	GEST	\N	AFCL	AFCL	1053	Français établis hors de France	\N	m.ollivier@senat.fr	OLLIVIER	OUI	194	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/ollivier-mathilde-26164.html
21039F	Mme	Nédélec	NEDELEC_Anne_Marie	Anne-Marie	1953-05-23 00:00:00	\N	ACTIF	Ancien cadre	7400	79	UMP	Les Républicains	-A	SOCI	SOCI	520	Haute-Marne	\N	am.nedelec@senat.fr	NÉDÉLEC	OUI	287	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/nedelec-anne-marie-6753.html
21048G	M.	Blanc	BLANC_Grégory	Grégory	1980-09-01 00:00:00	\N	ACTIF	Commerçant et assimilé	2200	23	GEST	GEST	\N	FINC	FINC	490	Maine-et-Loire	\N	g.blanc@senat.fr	BLANC	NON	198	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/blanc-gregory-26176.html
21050A	M.	Bleunven	BLEUNVEN_Yves	Yves	1963-02-02 00:00:00	\N	ACTIF	Chef d'entreprise de 10 salariés ou plus	2300	21	UC	UC	\N	CAE	CAE	560	Morbihan	\N	y.bleunven@senat.fr	BLEUNVEN	NON	55	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/bleunven-yves-18315.html
21052C	M.	Brault	BRAULT_Jean_Luc	Jean-Luc	1950-10-28 00:00:00	\N	ACTIF	Ancien artisan, commerçant, chef d'entreprise	7200	29	RTLI	Les Indépendants	\N	CAE	CAE	410	Loir-et-Cher	\N	jl.brault@senat.fr	BRAULT	NON	157	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/brault-jean-luc.html
21053D	M.	Pillefer	PILLEFER_Bernard	Bernard	1956-10-23 00:00:00	\N	ACTIF	Ancien cadre	7400	79	UC	UC	\N	CDD	CDD	410	Loir-et-Cher	\N	b.pillefer@senat.fr	PILLEFER	NON	213	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/pillefer-bernard-7451.html
21054E	M.	Louault	LOUAULT_Vincent	Vincent	1972-05-24 00:00:00	\N	ACTIF	Agriculteur sur moyenne exploitation	1200	81	RTLI	Les Indépendants	\N	CAE	CAE	370	Indre-et-Loire	\N	v.louault@senat.fr	LOUAULT	NON	257	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/louault-vincent.html
21073H	M.	Mellouli	MELLOULI_Akli	Akli	1959-12-02 00:00:00	\N	ACTIF	Profession libérale	3100	80	GEST	GEST	\N	ETRD	ETRD	824	Val-de-Marne	\N	a.mellouli@senat.fr	MELLOULI	NON	247	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/mellouli-akli-26179.html
21075K	Mme	Margaté	MARGATE_Marianne	Marianne	1971-09-17 00:00:00	\N	ACTIF	Cadre de la fonction publique	3313	56	CRC	CRCE-K	\N	CAE	CAE	770	Seine-et-Marne	\N	m.margate@senat.fr	MARGATÉ	OUI	15	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/margate-marianne-5861.html
21076L	M.	Vogel	VOGEL_Louis	Louis	1954-10-22 00:00:00	\N	ACTIF	Juriste, professeur des universités	3400	80	RTLI	Les Indépendants	\N	LOIS	LOIS	770	Seine-et-Marne	\N	l.vogel@senat.fr	VOGEL	NON	204	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/vogel-louis.html
21083K	M.	Cambier	CAMBIER_Guislain	Guislain	1971-07-18 00:00:00	\N	ACTIF	Cadre de la fonction publique	3313	56	UC	UC	\N	CAE	CAE	590	Nord	\N	g.cambier@senat.fr	CAMBIER	NON	322	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/cambier-guislain-10499.html
21086N	M.	Fargeot	FARGEOT_Daniel	Daniel	1958-05-31 00:00:00	\N	ACTIF	Chef d'entreprise de 10 salariés ou plus	2300	21	UC	UC	\N	CAE	CAE	828	Val-d'Oise	\N	d.fargeot@senat.fr	FARGEOT	NON	165	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/fargeot-daniel-18061.html
21093M	M.	Jadot	JADOT_Yannick	Yannick	1967-07-27 00:00:00	\N	ACTIF	Economiste	3128	52	GEST	GEST	\N	CAE	CAE	615	Paris	\N	y.jadot@senat.fr	JADOT	NON	196	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/jadot-yannick.html
21055F	M.	Paumier	PAUMIER_Jean_Gerard	Jean-Gérard	1952-07-26 00:00:00	\N	ACTIF	Cadre de la fonction publique	3313	56	UMP	Les Républicains	\N	AFCL	AFCL	370	Indre-et-Loire	\N	\N	PAUMIER	NON	182	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/paumier-jean-gerard-6412.html
21094N	Mme	Souyris	SOUYRIS_Anne	Anne	1964-08-29 00:00:00	\N	ACTIF	Professeure des écoles	4200	63	GEST	GEST	\N	SOCI	SOCI	615	Paris	\N	a.souyris@senat.fr	SOUYRIS	OUI	305	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/souyris-anne.html
21033Y	M.	Fouassin	FOUASSIN_Stephane	Stéphane	1960-10-17 00:00:00	\N	ACTIF	Profession libérale	3128	52	LREM	RDPI	-A	CAE	CAE	974	La Réunion	\N	s.fouassin@senat.fr	FOUASSIN	NON	252	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/fouassin-stephane-18118.html
21034A	Mme	Corbière Naminzo	CORBIERE_NAMINZO_Evelyne	Evelyne	1980-11-12 00:00:00	\N	ACTIF	Professeur des écoles, instituteur et assimilé	4200	63	CRC	CRCE-K	\N	CAE	CAE	974	La Réunion	\N	e.corbiere-naminzo@senat.fr	CORBIÈRE NAMINZO	OUI	141	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/corbiere-naminzo-evelyne-22924.html
21040X	M.	Masset	MASSET_Michel	Michel	1965-10-09 00:00:00	\N	ACTIF	Commerçant et assimilé	2200	23	RDSE	RDSE	\N	LOIS	LOIS	470	Lot-et-Garonne	\N	m.masset@senat.fr	MASSET	NON	25	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/masset-michel-16259.html
21046E	Mme	Bourcier	BOURCIER_Corinne	Corinne	1969-05-05 00:00:00	\N	ACTIF	Employé administratif d'entreprise	5400	33	RTLI	Les Indépendants	\N	SOCI	SOCI	490	Maine-et-Loire	\N	c.bourcier@senat.fr	BOURCIER	OUI	253	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/bourcier-corinne-26177.html
21047F	M.	Pernot	PERNOT_Clement	Clément	1961-12-21 00:00:00	\N	ACTIF	\N	2000	81	UMP	Les Républicains	-R	CDD	CDD	390	Jura	\N	c.pernot@senat.fr	PERNOT	NON	288	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/pernot-clement-7225.html
21066J	M.	Grosvalet	GROSVALET_Philippe	Philippe	1958-04-13 00:00:00	\N	ACTIF	Ancien cadre	7400	79	RDSE	RDSE	\N	CAE	CAE	440	Loire-Atlantique	\N	p.grosvalet@senat.fr	GROSVALET	NON	23	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/grosvalet-philippe-4586.html
21068L	M.	Reynaud	REYNAUD_Herve	Hervé	1972-07-04 00:00:00	\N	ACTIF	Cadre de la fonction publique	3313	56	UMP	Les Républicains	\N	CDD	CDD	420	Loire	\N	h.reynaud@senat.fr	REYNAUD	NON	231	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/reynaud-herve.html
21069M	M.	Szczurek	SZCZUREK_Christopher	Christopher	1985-06-11 00:00:00	\N	ACTIF	Profession intermédiaire administrative de la fonction publique	4500	73	NI	NI	\N	FINC	FINC	620	Pas-de-Calais	\N	c.szczurek@senat.fr	SZCZUREK	NON	269	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/szczurek-christopher-26155.html
21070E	M.	Rochette	ROCHETTE_Pierre_Jean	Pierre Jean	1982-02-01 00:00:00	\N	ACTIF	Chef d'entreprise de 10 salariés ou plus	2300	21	RTLI	Les Indépendants	\N	CDD	CDD	420	Loire	\N	pj.rochette@senat.fr	ROCHETTE	NON	201	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/rochette-pierre-jean-16232.html
21043B	M.	Bitz	BITZ_Olivier	Olivier	1975-09-16 00:00:00	\N	ACTIF	Administrateur de l'Etat	3313	56	LREM	RDPI	\N	LOIS	LOIS	610	Orne	\N	\N	BITZ	NON	153	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/bitz-olivier.html
21071F	Mme	Aeschlimann	AESCHLIMANN_Marie_Do	Marie-Do	1974-04-17 00:00:00	\N	ACTIF	Avocat	3128	52	UMP	Les Républicains	\N	SOCI	SOCI	335	Hauts-de-Seine	\N	md.aeschlimann@senat.fr	AESCHLIMANN	OUI	139	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/aeschlimann-marie-do-20223.html
21072G	Mme	Ciuntu	CIUNTU_Marie_Carole	Marie-Carole	1964-11-09 00:00:00	\N	ACTIF	Profession libérale	3128	52	UMP	Les Républicains	\N	FINC	FINC	824	Val-de-Marne	\N	\N	CIUNTU	OUI	137	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/ciuntu-marie-carole.html
19421M	M.	Saury	SAURY_HUGUES	Hugues	1958-11-12 00:00:00	\N	ACTIF	Pharmacien	3116	44	UMP	Les Républicains	\N	ETRD	ETRD	450	Loiret	\N	h.saury@senat.fr	SAURY	NON	177	2017-09-18 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/saury-hugues-7977.html
20980G	Mme	Del Fabro	Del_Fabro_Veronique	Véronique	1961-10-25 00:00:00	\N	ANCIEN	Professeur	3400	62	UMP	Les Républicains	A	AFCL	AFCL	540	Meurthe-et-Moselle	\N	\N	DEL FABRO	OUI	\N	\N	2023-10-01 00:37:00	\N
21074J	M.	Durox	DUROX_Aymeric	Aymeric	1985-08-06 00:00:00	\N	ACTIF	Professeur, profession scientifique	3400	61	NI	NI	\N	AFCL	AFCL	770	Seine-et-Marne	\N	a.durox@senat.fr	DUROX	NON	326	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/durox-aymeric-26171.html
21077M	M.	Ziane	ZIANE_Adel	Adel	1979-04-05 00:00:00	\N	ACTIF	Cadre supérieur de la fonction publique	3313	56	SOC	SER	\N	AFCL	AFCL	775	Seine-Saint-Denis	\N	\N	ZIANE	NON	188	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/ziane-adel-26160.html
21078N	M.	Laouedj	LAOUEDJ_Ahmed	Ahmed	1968-08-21 00:00:00	\N	ACTIF	Cadre de la fonction publique	3313	56	RDSE	RDSE	\N	AFCL	AFCL	775	Seine-Saint-Denis	\N	a.laouedj@senat.fr	LAOUEDJ	NON	84	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/laouedj-ahmed-26169.html
21081H	M.	Khalifé	KHALIFE_Khalife	Khalifé	1953-10-10 00:00:00	\N	ACTIF	Profession libérale	3100	80	UMP	Les Républicains	-A	SOCI	SOCI	570	Moselle	\N	k.khalife@senat.fr	KHALIFÉ	NON	225	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/khalife-khalife.html
21082J	M.	Weber	WEBER_Michaël	Michaël	1974-03-17 00:00:00	\N	ACTIF	Profession libérale	3128	52	SOC	SER	\N	CDD	CDD	570	Moselle	\N	m.weber@senat.fr	WEBER	NON	191	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/weber-michael-26158.html
21036C	M.	Ruelle	RUELLE JEAN_LUC	Jean-Luc	1952-04-01 00:00:00	\N	ACTIF	Chef d'entreprise de 10 salariés ou plus	2300	80	UMP	Les Républicains	-R	ETRD	ETRD	1053	Français établis hors de France	\N	jl.ruelle@senat.fr	RUELLE	NON	347	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/ruelle-jean-luc-26153.html
21049H	Mme	Silvani	SILVANI_Silvana	Silvana	1960-03-14 00:00:00	\N	ACTIF	Ancien cadre	7400	79	CRC	CRCE-K	\N	SOCI	SOCI	540	Meurthe-et-Moselle	\N	s.silvani@senat.fr	SILVANI	OUI	105	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/silvani-silvana-22629.html
21029D	M.	Naturel	NATUREL_Georges	Georges	1955-11-21 00:00:00	\N	ACTIF	Ancien cadre	7400	80	UMP	Les Républicains	\N	CDD	CDD	982	Nouvelle-Calédonie	\N	g.naturel@senat.fr	NATUREL	NON	180	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/naturel-georges.html
21031W	M.	Vayssouze-Faure	VAYSSOUZE_FAURE_Jean_Marc	Jean-Marc	1972-05-30 00:00:00	\N	ACTIF	Cadre de la fonction publique	3313	56	SOC	SER	\N	ETRD	ETRD	460	Lot	\N	jm.vayssouze-faure@senat.fr	VAYSSOUZE-FAURE	NON	150	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/vayssouze-faure-jean-marc.html
21035B	Mme	Bélim	BELIM_Audrey	Audrey	1987-04-16 00:00:00	\N	ACTIF	Juriste d'entreprise	8500	81	SOC	SER	\N	CDD	CDD	974	La Réunion	\N	a.belim@senat.fr	BÉLIM	OUI	301	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/belim-audrey-19820.html
21042A	Mme	Antoine	ANTOINE_Jocelyne	Jocelyne	1961-07-03 00:00:00	\N	ACTIF	Comptable	8600	81	UC	UC	\N	CDD	CDD	550	Meuse	\N	j.antoine@senat.fr	ANTOINE	OUI	212	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/antoine-jocelyne-22703.html
21045D	Mme	Canalès	CANALÈS_Marion	Marion	1980-01-15 00:00:00	\N	ACTIF	Cadre de la fonction publique	3313	56	SOC	SER	\N	SOCI	SOCI	630	Puy-de-Dôme	\N	m.canales@senat.fr	CANALÈS	OUI	239	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/canales-marion.html
21057H	M.	Chaillou	CHAILLOU_Christophe	Christophe	1964-11-13 00:00:00	\N	ACTIF	Cadre de la fonction publique	3313	56	SOC	SER	\N	LOIS	LOIS	450	Loiret	\N	c.chaillou@senat.fr	CHAILLOU	NON	143	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/chaillou-christophe-16143.html
21058J	Mme	Martin	MARTIN_Pauline	Pauline	1966-09-25 00:00:00	\N	ACTIF	Cadre administratif et commercial d'entreprise	3735	55	UMP	Les Républicains	\N	AFCL	AFCL	450	Loiret	\N	pauline.martin@senat.fr	MARTIN	OUI	230	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/martin-pauline-6149.html
21059K	M.	Ros	ROS_David	David	1970-08-10 00:00:00	\N	ACTIF	Professeur, profession scientifique	3400	61	SOC	SER	\N	AFCL	AFCL	265	Essonne	\N	d.ros@senat.fr	ROS	NON	245	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/ros-david.html
21060C	M.	Ouizille	OUIZILLE_Alexandre	Alexandre	1988-06-18 00:00:00	\N	ACTIF	Enseignant en économie 	3400	61	SOC	SER	\N	CDD	CDD	600	Oise	\N	a.ouizille@senat.fr	OUIZILLE	NON	107	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/ouizille-alexandre-26165.html
21062E	M.	Fagnen	FAGNEN_Sebastien	Sébastien	1987-11-08 00:00:00	\N	ACTIF	Collaborateur parlementaire	3313	56	SOC	SER	\N	CDD	CDD	500	Manche	\N	s.fagnen@senat.fr	FAGNEN	NON	144	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/fagnen-sebastien-20026.html
21064G	Mme	Romagny	ROMAGNY_Anne_Sophie	Anne-Sophie	1977-12-31 00:00:00	\N	ACTIF	Profession libérale	3600	32	UC	UC	\N	SOCI	SOCI	510	Marne	\N	as.romagny@senat.fr	ROMAGNY	OUI	125	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/romagny-anne-sophie-26168.html
21065H	M.	Chevalier	CHEVALIER_Cédric	Cédric	1973-03-10 00:00:00	\N	ACTIF	Chef d'entreprise de 10 salariés ou plus	2300	21	RTLI	Les Indépendants	\N	CDD	CDD	510	Marne	\N	c.chevalier@senat.fr	CHEVALIER	NON	205	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/chevalier-cedric-26172.html
21084L	M.	Barros	BARROS_Pierre	Pierre	1972-10-15 00:00:00	\N	ACTIF	Ingénieur et cadre technique d'entreprise	3800	31	CRC	CRCE-K	\N	CDD	CDD	828	Val-d'Oise	\N	p.barros@senat.fr	BARROS	NON	104	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/barros-pierre-19585.html
21087P	Mme	Lermytte	LERMYTTE_Marie_Claude	Marie-Claude	1965-06-04 00:00:00	\N	ACTIF	Profession intermédiaire de la santé et du travail social	4300	81	RTLI	Les Indépendants	\N	SOCI	SOCI	590	Nord	\N	mc.lermytte@senat.fr	LERMYTTE	OUI	311	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/lermytte-marie-claude-26173.html
21056G	M.	Roiron	ROIRON_Pierre_Alain	Pierre-Alain	1967-10-18 00:00:00	\N	ACTIF	Cadre de la fonction publique	3313	56	SOC	SER	\N	LOIS	LOIS	370	Indre-et-Loire	\N	pa.roiron@senat.fr	ROIRON	NON	193	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/roiron-pierre-alain.html
21079P	Mme	Senée	SENEE_Ghislaine	Ghislaine	1969-02-14 00:00:00	\N	ACTIF	Sans profession	8500	81	GEST	GEST	\N	FINC	FINC	895	Yvelines	\N	g.senee@senat.fr	SENÉE	OUI	195	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/senee-ghislaine-26154.html
21061D	Mme	Valente Le Hir	VALENTE_LE_HIR_Sylvie	Sylvie	1965-01-17 00:00:00	\N	ACTIF	Sans profession	8500	81	UMP	Les Républicains	-A	CDD	CDD	600	Oise	\N	\N	VALENTE LE HIR	OUI	100	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/valente-le-hir-sylvie-26157.html
20138D	Mme	Borchio Fontimp	BORCHIO_FONTIMP_ALEXANDRA	Alexandra	1981-10-05 00:00:00	\N	ACTIF	Journaliste	3700	32	UMP	Les Républicains	\N	AFCL	AFCL	60	Alpes-Maritimes	Secrétaire du Sénat	a.borchio-fontimp@senat.fr	BORCHIO FONTIMP	OUI	223	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/borchio-fontimp-alexandra.html
20140W	Mme	Demas	DEMAS_PATRICIA	Patricia	1966-09-15 00:00:00	\N	ACTIF	Chargée de mission - conseillère en prévention de perte d'autonomie	3700	32	UMP	Les Républicains	\N	SOCI	SOCI	60	Alpes-Maritimes	\N	p.demas@senat.fr	DEMAS	OUI	286	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/demas-patricia-20180.html
20144B	M.	Chauvet	CHAUVET_PATRICK	Patrick	1958-03-27 00:00:00	\N	ACTIF	Agriculteur	1200	10	UC	UC	\N	CAE	CAE	760	Seine-Maritime	\N	p.chauvet@senat.fr	CHAUVET	NON	161	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/chauvet-patrick-1641.html
20146D	Mme	Phinera-Horth	PHINERA_HORTH_MARIE_LAURE	Marie-Laure	1957-06-28 00:00:00	\N	ACTIF	Orthophoniste	4300	47	LREM	RDPI	\N	CDD	CDD	973	Guyane	\N	ml.phinera-horth@senat.fr	PHINERA-HORTH	OUI	152	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/phinera-horth-marie-laure.html
20148F	Mme	Petrus	PETRUS_ANNICK	Annick	1961-01-05 00:00:00	\N	ACTIF	Directrice d'école 	4200	63	UMP	Les Républicains	\N	SOCI	SOCI	9715	Saint-Martin	\N	a.petrus@senat.fr	PETRUS	OUI	279	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/petrus-annick.html
20150Y	M.	Rohfritsch	ROHFRITSCH_TEVA	Teva	1975-02-03 00:00:00	\N	ACTIF	Fondé de pouvoir - secteur bancaire 	2300	21	LREM	RDPI	\N	FINC	FINC	983	Polynésie française	\N	t.rohfritsch@senat.fr	ROHFRITSCH	NON	116	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/rohfritsch-teva.html
20152B	Mme	Bourrat	BOURRAT_TOINE	Toine	1968-11-28 00:00:00	\N	ANCIEN	Cadre du secteur privé	3700	32	UMP	Les Républicains	A	AFCL	AFCL	895	Yvelines	\N	t.bourrat@senat.fr	BOURRAT	OUI	\N	\N	2023-10-01 00:37:00	\N
20076G	M.	Bacci	BACCI_JEAN	Jean	1951-03-17 00:00:00	\N	ACTIF	Retraité	7400	39	UMP	Les Républicains	-A	CDD	CDD	830	Var	\N	j.bacci@senat.fr	BACCI	NON	66	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/bacci-jean-20697.html
20038A	M.	Favreau	FAVREAU_GILBERT	Gilbert	1949-05-04 00:00:00	\N	ACTIF	Avocat	3100	57	UMP	Les Républicains	\N	CAE	CAE	790	Deux-Sèvres	\N	g.favreau@senat.fr	FAVREAU	NON	285	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/favreau-gilbert.html
20040T	M.	Duffourg	DUFFOURG_ALAIN	Alain	1950-01-22 00:00:00	\N	ACTIF	Avocat	3100	57	UC	UC	\N	CDD	CDD	320	Gers	\N	a.duffourg@senat.fr	DUFFOURG	NON	266	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/duffourg-alain-20721.html
20120S	M.	Genet	GENET_FABIEN	Fabien	1975-03-22 00:00:00	\N	ACTIF	Juriste	4600	32	UMP	Les Républicains	-R	CDD	CDD	710	Saône-et-Loire	\N	f.genet@senat.fr	GENET	NON	216	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/genet-fabien-9706.html
20114U	M.	Bourgi	BOURGI_HUSSEIN	Hussein	1973-10-05 00:00:00	\N	ACTIF	Cadre	3300	71	SOC	SER	\N	LOIS	LOIS	340	Hérault	\N	h.bourgi@senat.fr	BOURGI	NON	111	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/bourgi-hussein-20695.html
20046A	Mme	Varaillas	VARAILLAS_MARIE_CLAUDE	Marie-Claude	1950-12-18 00:00:00	\N	ACTIF	Retraitée fonction publique territoriale	3300	71	CRC	CRCE-K	\N	CDD	CDD	240	Dordogne	\N	mc.varaillas@senat.fr	VARAILLAS	OUI	68	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/varaillas-marie-claude-8525.html
20136B	M.	Tabarot	TABAROT_PHILIPPE	Philippe	1970-11-25 00:00:00	\N	ACTIF	Chargé de mission	3500	81	UMP	Les Républicains	\N	CDD	CDD	60	Alpes-Maritimes	Secrétaire du Sénat	p.tabarot@senat.fr	TABAROT	NON	175	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/tabarot-philippe.html
21091K	Mme	Evren	EVREN_Agnès	Agnès	1970-12-27 00:00:00	\N	ACTIF	Cheffe d'entreprise	5200	81	UMP	Les Républicains	\N	AFCL	AFCL	615	Paris	\N	a.evren@senat.fr	EVREN	OUI	34	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/evren-agnes.html
20914V	M.	Breuiller	BREUILLER_Daniel	Daniel	1953-02-26 00:00:00	\N	ANCIEN	Retraité	3000	32	GEST	GEST	N	FINC	FINC	824	Val-de-Marne	\N	d.breuiller@senat.fr	BREUILLER	NON	\N	\N	2023-10-01 00:37:00	\N
19798U	Mme	Richer	RICHER_MARIE_PIERRE	Marie-Pierre	1963-04-19 00:00:00	\N	ACTIF	\N	8500	80	UMP	Les Républicains	-R	SOCI	SOCI	180	Cher	Secrétaire du Sénat	mp.richer@senat.fr	RICHER	OUI	167	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/richer-marie-pierre-14954.html
19443T	Mme	Raimond-Pavero	RAIMOND_PAVERO_ISABELLE	Isabelle	1961-02-23 00:00:00	\N	ANCIEN	Assistante juridique	3128	57	UMP	Les Républicains	N	ETRD	ETRD	370	Indre-et-Loire	\N	i.raimond-pavero@senat.fr	RAIMOND-PAVERO	NON	\N	2017-09-18 00:00:00	2023-10-01 00:37:00	\N
19629C	Mme	Carrère	CARRERE_MARYSE	Maryse	1967-04-08 00:00:00	\N	ACTIF	Cadre de la fonction publique territoriale	3300	71	RDSE	RDSE	\N	SOCI	SOCI	650	Hautes-Pyrénées	\N	m.carrere@senat.fr	CARRÈRE	OUI	117	2017-09-22 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/carrere-maryse.html
19631V	Mme	Artigalas	ARTIGALAS_VIVIANE	Viviane	1956-10-22 00:00:00	\N	ACTIF	Proviseur	3311	71	SOC	SER	\N	CAE	CAE	650	Hautes-Pyrénées	\N	v.artigalas@senat.fr	ARTIGALAS	OUI	293	2017-09-22 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/artigalas-viviane.html
19643A	Mme	Boulay-Espéronnier	BOULAY_ESPERONNIER_CELINE	Céline	1970-12-18 00:00:00	\N	ANCIEN	\N	8500	35	UMP	Les Républicains	A	AFCL	AFCL	615	Paris	\N	c.boulay-esperonnier@senat.fr	BOULAY-ESPÉRONNIER	OUI	\N	2017-09-22 00:00:00	2023-10-01 00:37:00	\N
19715Y	Mme	Jasmin	JASMIN_VICTOIRE	Victoire	1955-12-23 00:00:00	2023-10-06 00:00:00	ANCIEN	Cadre de santé	4300	32	SOC	SER	N	SOCI	SOCI	971	Guadeloupe	Secrétaire du Sénat	v.jasmin@senat.fr	JASMIN	OUI	\N	2017-09-25 00:00:00	2023-10-01 00:37:00	\N
19717B	M.	Artano	ARTANO_STEPHANE	Stéphane	1973-03-09 00:00:00	\N	ANCIEN	Conseiller en gestion de patrimoine	8000	32	RDSE	RDSE	N	SOCI	SOCI	995	Saint-Pierre-et-Miquelon	\N	s.artano@senat.fr	ARTANO	NON	\N	2017-09-25 00:00:00	2023-10-01 00:37:00	\N
21032X	Mme	Girardin	GIRARDIN_Annick	Annick	1964-08-03 00:00:00	\N	ACTIF	Cadre de la fonction publique	3313	56	RDSE	RDSE	\N	ETRD	ETRD	995	Saint-Pierre-et-Miquelon	\N	a.girardin@senat.fr	GIRARDIN	OUI	3	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/girardin-annick.html
21067K	M.	Darras	DARRAS_Jerome	Jérôme	1957-10-30 00:00:00	\N	ACTIF	Ancien cadre de la fonction publique	7400	79	SOC	SER	\N	ETRD	ETRD	620	Pas-de-Calais	\N	j.darras@senat.fr	DARRAS	NON	292	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/darras-jerome-10410.html
19441R	M.	Louault	LOUAULT_PIERRE	Pierre	1949-05-03 00:00:00	\N	ANCIEN	Ancien agriculteur	7100	10	UC	UC	N	CAE	CAE	370	Indre-et-Loire	\N	p.louault@senat.fr	LOUAULT	NON	\N	2017-09-18 00:00:00	2023-10-01 00:37:00	\N
19782L	M.	Buis	BUIS_BERNARD	Bernard	1956-06-23 00:00:00	\N	ACTIF	\N	7400	39	LREM	RDPI	\N	CAE	CAE	260	Drôme	\N	b.buis@senat.fr	BUIS	NON	80	\N	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/buis-bernard.html
19637C	M.	Marchand	MARCHAND_FREDERIC	Frédéric	1965-05-31 00:00:00	\N	ANCIEN	Chef d'entreprise	2300	21	LREM	RDPI	N	CDD	CDD	590	Nord	\N	f.marchand@senat.fr	MARCHAND	NON	\N	2017-09-22 00:00:00	2023-10-01 00:37:00	\N
19647E	M.	Féraud	FERAUD_REMI	Rémi	1971-08-24 00:00:00	\N	ACTIF	\N	8000	80	SOC	SER	\N	FINC	FINC	615	Paris	\N	r.feraud@senat.fr	FÉRAUD	NON	75	2017-09-22 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/feraud-remi.html
19651A	M.	Bargeton	BARGETON_JULIEN	Julien	1973-03-29 00:00:00	\N	ANCIEN	Magistrat financier	3313	71	LREM	RDPI	N	AFCL	AFCL	615	Paris	\N	j.bargeton@senat.fr	BARGETON	NON	\N	2017-09-22 00:00:00	2023-10-01 00:37:00	\N
19649G	Mme	de La Gontrie	LA GONTRIE_MARIE_PIERRE	Marie-Pierre	1958-12-18 00:00:00	\N	ACTIF	Avocate	3121	51	SOC	SER	\N	LOIS	LOIS	615	Paris	\N	\N	de LA GONTRIE	OUI	44	2017-09-22 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/de-la-gontrie-marie-pierre.html
21080G	M.	Michallet	MICHALLET_Damien	Damien	1975-05-31 00:00:00	\N	ACTIF	Cadre administratif et commercial d'entreprise	3735	55	UMP	Les Républicains	\N	CDD	CDD	380	Isère	\N	d.michallet@senat.fr	MICHALLET	NON	101	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/michallet-damien-18275.html
21090J	Mme	Carrère-Gée	CARRERE_GEE_Marie_Claire	Marie-Claire	1963-03-23 00:00:00	\N	ACTIF	Haut fonctionnaire, conseillère maitre à la Cour des comptes	3313	56	UMP	Les Républicains	\N	FINC	FINC	615	Paris	\N	mc.carrere-gee@senat.fr	CARRÈRE-GÉE	OUI	218	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/carrere-gee-marie-claire-23617.html
21095P	M.	Szpiner	SZPINER_Francis	Francis	1954-03-22 00:00:00	\N	ACTIF	Avocat	3128	52	UMP	Les Républicains	\N	LOIS	LOIS	615	Paris	\N	f.szpiner@senat.fr	SZPINER	NON	219	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/szpiner-francis-26156.html
19563B	M.	Menonville	MENONVILLE_FRANCK	Franck	1972-10-03 00:00:00	\N	ACTIF	Agriculteur	1000	10	UC	UC	\N	CAE	CAE	550	Meuse	\N	f.menonville@senat.fr	MENONVILLE	NON	166	2017-09-20 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/menonville-franck.html
21088Q	M.	Brossat	BROSSAT_Ian	Ian	1980-04-23 00:00:00	\N	ACTIF	Professeur, profession scientifique	3400	61	CRC	CRCE-K	\N	LOIS	LOIS	615	Paris	\N	\N	BROSSAT	NON	142	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/brossat-ian.html
21089R	Mme	Brossel	BROSSEL_Colombe	Colombe	1976-04-19 00:00:00	\N	ACTIF	Cadre administratif et commercial d'entreprise	3735	55	SOC	SER	\N	AFCL	AFCL	615	Paris	\N	\N	BROSSEL	OUI	187	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/brossel-colombe.html
21097R	Mme	Nadille	NADILLE_Solanges	Solanges	1976-09-24 00:00:00	\N	ACTIF	Profession intermédiaire de la santé et du travail social	4300	81	LREM	RDPI	\N	SOCI	SOCI	971	Guadeloupe	\N	s.nadille@senat.fr	NADILLE	OUI	199	2023-09-25 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/nadille-solanges-26162.html
21038E	Mme	Richard	RICHARD_Olivia	Olivia	1977-02-22 00:00:00	\N	ACTIF	Juriste - Collaboratrice parlementaire	3600	32	UC	UC	\N	LOIS	LOIS	1053	Français établis hors de France	\N	o.richard@senat.fr	RICHARD	OUI	164	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/richard-olivia-26167.html
21096Q	M.	Buval	BUVAL_Frederic	Frédéric	1951-03-24 00:00:00	\N	ACTIF	Ancien cadre	7400	79	LREM	RDPI	-A	CAE	CAE	972	Martinique	\N	\N	BUVAL	NON	200	2023-09-25 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/buval-frederic-1947.html
74019R	M.	de Cuttoli	CUTTOLI (DE)	Charles	1915-08-15 00:00:00	2007-12-11 00:00:00	ANCIEN	Avocat	3121	51	RPR	RPR	\N	ECON	ECON	998	Français établis hors de France	\N	\N	de CUTTOLI	NON	\N	\N	\N	\N
90002A	M.	Durand-Chastel	DURAND-CHASTEL	Hubert	1918-08-08 00:00:00	2007-10-19 00:00:00	ANCIEN	Ingénieur	3800	31	UMP	Les Républicains	-R	ETRD	ETRD	999	Français établis hors de France	\N	\N	DURAND-CHASTEL	NON	\N	\N	2017-10-09 16:22:47	\N
74032N	M.	d'Ornano	ORNANO (D')	Paul	1922-08-01 00:00:00	2002-05-24 00:00:00	ANCIEN	Ingénieur	3800	31	RPR	RPR	-R	LOIS	LOIS	999	Français établis hors de France	\N	\N	D'ORNANO	NON	\N	\N	\N	\N
95012Y	M.	Braun	BRAUN	Gérard	1937-06-02 00:00:00	\N	ANCIEN	Pharmacien	3116	44	UMP	Les Républicains	-A	FINC	FINC	880	Vosges	\N	\N	BRAUN	NON	\N	\N	2017-10-09 16:22:47	\N
78007E	Mme	Bidard-Reydet	BIDARD-REYDET	Danielle	1939-12-08 00:00:00	\N	ANCIEN	Agrégée de l'Université	4200	62	CRC	CRCE	\N	ETRD	ETRD	775	Seine-Saint-Denis	\N	\N	BIDARD-REYDET	NON	\N	\N	2017-10-04 09:44:05	\N
88013H	M.	Lanier	LANIER	Lucien	1919-10-16 00:00:00	2015-02-07 00:00:00	ANCIEN	Préfet honoraire	7400	79	UMP	Les Républicains	\N	LOIS	LOIS	824	Val-de-Marne	\N	\N	LANIER	NON	\N	\N	2017-10-09 16:22:47	\N
95057N	M.	Poirier	POIRIER JEAN-MARIE	Jean-Marie	1929-12-01 00:00:00	2007-01-30 00:00:00	ANCIEN	Conseiller d'Etat	3311	71	UMP	Les Républicains	\N	ETRD	ETRD	824	Val-de-Marne	\N	\N	POIRIER	NON	\N	\N	2017-10-09 16:22:47	\N
95040D	M.	Joly	JOLY	Bernard	1934-10-26 00:00:00	2020-01-10 00:00:00	ANCIEN	Chirurgien dentiste	3113	45	RDSE	RDSE	\N	ECON	ECON	700	Haute-Saône	Secrétaire du Sénat	\N	JOLY	NON	\N	\N	\N	\N
95008D	M.	Barnier	BARNIER	Michel	1951-01-09 00:00:00	\N	ANCIEN	\N	8000	80	RPR	RPR	\N	ETRD	ETRD	730	Savoie	\N	\N	BARNIER	NON	\N	\N	2017-06-15 09:43:56	\N
95066P	M.	Weber	WEBER	Henri	1944-06-23 00:00:00	2020-04-26 00:00:00	ANCIEN	Professeur	3400	64	SOC	SER	\N	AFCL	AFCL	760	Seine-Maritime	\N	\N	WEBER	NON	\N	\N	2017-10-04 09:46:28	\N
95054K	M.	Peyrefitte	PEYREFITTE	Alain	1925-08-26 00:00:00	1999-11-27 00:00:00	ANCIEN	Ministre plénipotentiaire honoraire	3311	71	RPR	RPR	\N	ETRD	ETRD	770	Seine-et-Marne	\N	\N	PEYREFITTE	NON	\N	\N	2017-06-15 09:48:48	\N
92006N	M.	Althapé	ALTHAPE	Louis	1947-11-06 00:00:00	\N	ANCIEN	Gérant de société	2300	21	RPR	RPR	\N	ECON	ECON	640	Pyrénées-Atlantiques	\N	\N	ALTHAPÉ	NON	\N	\N	2016-10-14 18:31:28	\N
77029G	M.	Hoeffel	HOEFFEL	Daniel	1929-01-23 00:00:00	\N	ANCIEN	Sans profession déclarée	8000	80	UMP	Les Républicains	\N	LOIS	LOIS	670	Bas-Rhin	Vice-président du Sénat	\N	HOEFFEL	NON	\N	\N	2017-10-09 16:22:47	\N
91002E	M.	Ostermann	OSTERMANN	Joseph	1937-11-26 00:00:00	2023-10-21 00:00:00	ANCIEN	Agent général d'assurances	3100	57	UMP	Les Républicains	\N	FINC	FINC	670	Bas-Rhin	\N	\N	OSTERMANN	NON	\N	\N	2017-10-09 16:22:47	\N
77017C	M.	Debarge	DEBARGE	Marcel	1929-09-16 00:00:00	2015-12-23 00:00:00	ANCIEN	Retraité des PTT	7400	79	SOC	SER	\N	LOIS	LOIS	775	Seine-Saint-Denis	Secrétaire du Sénat	\N	DEBARGE	NON	\N	\N	2017-10-04 09:46:29	\N
86014A	M.	Calméjane	CALMEJANE	Robert	1929-05-19 00:00:00	2002-12-10 00:00:00	ANCIEN	Administrateur de sociétés	7200	29	RPR	RPR	\N	ETRD	ETRD	775	Seine-Saint-Denis	\N	\N	CALMÉJANE	NON	\N	\N	\N	\N
59569E	M.	Cartigny	CARTIGNY ERNEST	Ernest	1923-07-18 00:00:00	2009-12-09 00:00:00	ANCIEN	Chef d'entreprise honoraire	7200	29	RDSE	RDSE	\N	ETRD	ETRD	775	Seine-Saint-Denis	\N	\N	CARTIGNY	NON	\N	\N	\N	\N
86031B	M.	Hamel	HAMEL	Emmanuel	1922-01-09 00:00:00	2003-11-04 00:00:00	ANCIEN	Conseiller honoraire à la Cour des Comptes	3311	71	UMP	Les Républicains	\N	ETRD	ETRD	690	Rhône	\N	\N	HAMEL	NON	\N	\N	2017-10-09 16:22:48	\N
77066M	M.	Sérusclat	SERUSCLAT	Franck	1921-07-07 00:00:00	2006-07-02 00:00:00	ANCIEN	Pharmacien	3116	44	SOC	SER	\N	AFCL	AFCL	690	Rhône	\N	\N	SÉRUSCLAT	NON	\N	\N	2017-10-04 09:46:29	\N
95022B	M.	Delanoë	DELANOE	Bertrand	1950-05-30 00:00:00	\N	ANCIEN	Conseil en communication	3600	32	SOC	SER	\N	ETRD	ETRD	615	Paris	\N	\N	DELANOË	NON	\N	\N	2017-10-04 09:46:29	\N
77009C	M.	Caldaguès	CALDAGUES	Michel	1926-09-28 00:00:00	2012-09-22 00:00:00	ANCIEN	Administrateur de sociétés	2300	21	RPR	RPR	\N	ETRD	ETRD	615	Paris	\N	\N	CALDAGUÈS	NON	\N	\N	\N	\N
95058P	Mme	Pourtaud	POURTAUD	Danièle	1951-10-23 00:00:00	\N	ANCIEN	Gérante de sociétés	2300	21	SOC	SER	\N	AFCL	AFCL	615	Paris	\N	\N	POURTAUD	NON	\N	\N	2017-10-04 09:46:29	\N
77013X	M.	Chérioux	CHERIOUX	Jean	1928-02-16 00:00:00	2016-04-25 00:00:00	ANCIEN	Administrateur de sociétés	2300	21	UMP	Les Républicains	\N	SOCI	SOCI	615	Paris	\N	\N	CHÉRIOUX	NON	\N	\N	2017-10-09 16:22:48	\N
95018F	M.	Charzat	CHARZAT	Michel	1942-12-25 00:00:00	\N	ANCIEN	Consultant d'entreprise	3100	57	SOC	SER	\N	AFCL	AFCL	615	Paris	\N	\N	CHARZAT	NON	\N	\N	2017-10-04 09:46:29	\N
92017R	M.	Delevoye	DELEVOYE	Jean-Paul	1947-01-22 00:00:00	\N	ANCIEN	Directeur de société	2200	23	RPR	RPR	\N	ETRD	ETRD	620	Pas-de-Calais	\N	\N	DELEVOYE	NON	\N	\N	2017-06-15 09:44:53	\N
86011W	M.	Bellanger	BELLANGER	Jacques	1931-06-25 00:00:00	2021-09-30 00:00:00	ANCIEN	Retraité	7300	39	SOC	SER	\N	ECON	ECON	895	Yvelines	\N	\N	BELLANGER	NON	\N	\N	2017-10-04 09:46:29	\N
86021Y	M.	Désiré	DESIRE	Rodolphe	1937-02-09 00:00:00	\N	ANCIEN	Médecin	3112	42	RDSE	RDSE	-R	ECON	ECON	972	Martinique	\N	\N	DÉSIRÉ	NON	\N	\N	\N	\N
98002K	M.	Payet	PAYET LYLIAN	Lylian	1945-06-03 00:00:00	\N	ANCIEN	Conseiller pédagogique	3400	64	RDSE	RDSE	\N	SOCI	SOCI	974	La Réunion	\N	\N	PAYET	NON	\N	\N	\N	\N
95061J	M.	Reux	REUX	Victor	1929-12-03 00:00:00	2016-06-01 00:00:00	ANCIEN	Enseignant retraité	7400	69	UMP	Les Républicains	\N	AFCL	AFCL	995	Saint-Pierre-et-Miquelon	\N	\N	REUX	NON	\N	\N	2017-10-09 16:22:48	\N
79004F	Mme	Beaudeau	BEAUDEAU	Marie-Claude	1937-10-30 00:00:00	\N	ANCIEN	Secrétaire de direction	3600	32	CRC	CRCE	\N	FINC	FINC	828	Val-d'Oise	\N	\N	BEAUDEAU	NON	\N	\N	2017-10-04 09:44:05	\N
86041D	M.	Oudin	OUDIN	Jacques	1939-10-07 00:00:00	2020-03-21 00:00:00	ANCIEN	Conseiller référendaire à la Cour des Comptes	3311	71	UMP	Les Républicains	\N	FINC	FINC	850	Vendée	\N	\N	OUDIN	NON	\N	\N	2017-10-09 16:22:48	\N
90003B	M.	César	CESAR	Gérard	1934-12-19 00:00:00	\N	ANCIEN	Agriculteur	1000	10	UMP	Les Républicains	\N	CAE	CAE	330	Gironde	\N	\N	CÉSAR	NON	\N	\N	2017-10-09 16:22:49	\N
80027E	M.	Madrelle	MADRELLE	Philippe	1937-04-21 00:00:00	2019-08-27 00:00:00	ANCIEN	Professeur d'anglais	4200	69	SOC	SER	\N	CDD	CDD	330	Gironde	\N	\N	MADRELLE	NON	\N	\N	2018-02-15 16:45:25	\N
93005R	M.	Schosteck	SCHOSTECK	Jean-Pierre	1942-03-16 00:00:00	\N	ANCIEN	\N	8000	80	UMP	Les Républicains	\N	LOIS	LOIS	335	Hauts-de-Seine	\N	\N	SCHOSTECK	NON	\N	\N	2017-10-09 16:22:49	\N
97007L	Mme	Derycke	DERYCKE	Dinah	1946-04-01 00:00:00	2002-01-19 00:00:00	ANCIEN	Conseiller référendaire à la Cour des Comptes	3311	71	SOC	SER	\N	LOIS	LOIS	590	Nord	\N	\N	DERYCKE	NON	\N	\N	2017-10-04 09:46:29	\N
92023P	M.	Foy	FOY	Alfred	1934-01-11 00:00:00	\N	ANCIEN	Professeur de collège	4200	62	NI	NI	\N	SOCI	SOCI	590	Nord	\N	\N	FOY	NON	\N	\N	\N	\N
92042S	M.	Raoult	RAOULT	Paul	1944-11-26 00:00:00	\N	ANCIEN	Professeur d'histoire-géographie	4200	62	SOC	SER	\N	ECON	ECON	590	Nord	\N	\N	RAOULT	NON	\N	\N	2017-10-04 09:46:29	\N
83010H	M.	Allouche	ALLOUCHE	Guy	1939-10-27 00:00:00	\N	ANCIEN	Conseiller pédagogique en éducation physique et sportive	4200	63	SOC	SER	\N	LOIS	LOIS	590	Nord	Vice-président du Sénat	\N	ALLOUCHE	NON	\N	\N	2017-10-04 09:46:30	\N
83054V	M.	Souplet	SOUPLET	Michel	1929-04-03 00:00:00	2020-05-14 00:00:00	ANCIEN	Agriculteur	1000	10	UC	UC	\N	ECON	ECON	600	Oise	\N	\N	SOUPLET	NON	\N	\N	2017-07-04 10:59:30	\N
94004U	Mme	Bardou	BARDOU	Janine	1927-09-16 00:00:00	2008-12-29 00:00:00	ANCIEN	Agent d'assurances	7400	59	RI	RI	\N	ECON	ECON	480	Lozère	\N	\N	BARDOU	NON	\N	\N	\N	\N
95027G	M.	Dugoin	DUGOIN	Xavier	1947-03-27 00:00:00	\N	ANCIEN	Cadre financier	3600	32	RPR	RPR	\N	ETRD	ETRD	265	Essonne	\N	\N	DUGOIN	NON	\N	\N	2017-06-15 09:46:15	\N
95053J	M.	Pelchat	PELCHAT	Michel	1935-07-08 00:00:00	2004-02-12 00:00:00	ANCIEN	Ingénieur CEA	3800	73	UMP	Les Républicains	\N	ETRD	ETRD	265	Essonne	\N	\N	PELCHAT	NON	\N	\N	2017-10-09 16:22:49	\N
88003F	M.	Robert	ROBERT JEANJACQUES	Jean-Jacques	1924-04-24 00:00:00	2000-03-18 00:00:00	ANCIEN	Président Directeur Général	2300	21	RPR	RPR	\N	ECON	ECON	265	Essonne	\N	\N	ROBERT	NON	\N	\N	\N	\N
89022N	M.	Bourdin	BOURDIN	Joël	1938-01-25 00:00:00	\N	ANCIEN	Professeur d'université	3400	61	UMP	Les Républicains	-R	FINC	FINC	270	Eure	\N	\N	BOURDIN	NON	\N	\N	2017-10-09 16:22:49	\N
74042Q	M.	Rausch	RAUSCH	Jean-Marie	1929-09-24 00:00:00	2024-01-05 00:00:00	ANCIEN	Chef d'entreprise	2300	21	RDSE	RDSE	-R	ECON	ECON	570	Moselle	\N	\N	RAUSCH	NON	\N	\N	2016-12-14 15:27:37	\N
83037U	M.	Husson	HUSSON	Roger	1924-06-12 00:00:00	2000-04-28 00:00:00	ANCIEN	Agent de maîtrise	3600	32	RPR	RPR	\N	ETRD	ETRD	570	Moselle	Secrétaire du Sénat	\N	HUSSON	NON	\N	\N	\N	\N
74013K	M.	Bohl	BOHL	André	1936-01-26 00:00:00	\N	ANCIEN	Ingénieur commercial	3800	31	UC	UC	\N	AFCL	AFCL	570	Moselle	\N	\N	BOHL	NON	\N	\N	2017-07-04 10:59:30	\N
97008M	M.	Hesling	HESLING	Roger	1931-08-19 00:00:00	\N	ANCIEN	Agriculteur	7100	10	SOC	SER	\N	AFCL	AFCL	570	Moselle	\N	\N	HESLING	NON	\N	\N	2017-10-04 09:46:30	\N
83026R	M.	Delaneau	DELANEAU	Jean	1933-08-29 00:00:00	2018-10-10 00:00:00	ANCIEN	Chirurgien	3112	43	RI	RI	\N	SOCI	SOCI	370	Indre-et-Loire	Vice-président du Sénat	\N	DELANEAU	NON	\N	\N	\N	\N
83018R	M.	Boyer	BOYER JEAN 83018R	Jean	1923-08-01 00:00:00	2010-07-18 00:00:00	ANCIEN	Cadre commercial	3600	32	RI	RI	\N	ECON	ECON	380	Isère	\N	\N	BOYER	NON	\N	\N	\N	\N
89009R	M.	Taugourdeau	TAUGOURDEAU	Martial	1926-12-14 00:00:00	2001-10-14 00:00:00	ANCIEN	Médecin	3112	42	RPR	RPR	\N	SOCI	SOCI	280	Eure-et-Loir	\N	\N	TAUGOURDEAU	NON	\N	\N	2017-06-15 09:48:38	\N
92025R	Mme	Heinis	HEINIS	Anne	1933-11-16 00:00:00	2009-12-18 00:00:00	ANCIEN	Inspecteur régional d'action sociale	8000	80	RI	RI	\N	ECON	ECON	500	Manche	\N	\N	HEINIS	NON	\N	\N	\N	\N
83040P	M.	Machet	MACHET	Jacques	1923-12-16 00:00:00	2015-02-06 00:00:00	ANCIEN	Agriculteur	1000	10	UC	UC	\N	LOIS	LOIS	510	Marne	Secrétaire du Sénat	\N	MACHET	NON	\N	\N	2017-07-04 10:59:31	\N
92010J	M.	Bernard	BERNARD JEAN	Jean	1924-10-17 00:00:00	2007-11-21 00:00:00	ANCIEN	Vétérinaire	3115	46	RPR	RPR	\N	ETRD	ETRD	510	Marne	\N	\N	BERNARD	NON	\N	\N	\N	\N
74008N	M.	Ballayer	BALLAYER	René	1915-03-02 00:00:00	2001-01-26 00:00:00	ANCIEN	Négociant en vins	8000	80	UC	UC	\N	FINC	FINC	530	Mayenne	\N	\N	BALLAYER	NON	\N	\N	2017-07-04 10:59:31	\N
83036T	M.	Huriet	HURIET	Claude	1930-05-24 00:00:00	\N	ANCIEN	Professeur agrégé de médecine	3431	41	UC	UC	\N	SOCI	SOCI	540	Meurthe-et-Moselle	Questeur du Sénat	\N	HURIET	NON	\N	\N	2017-07-04 10:59:31	\N
92040Q	M.	Nachbar	NACHBAR	Philippe	1950-09-26 00:00:00	\N	ANCIEN	Avocat	3121	59	UMP	Les Républicains	\N	AFCL	AFCL	540	Meurthe-et-Moselle	\N	\N	NACHBAR	NON	\N	\N	2018-02-15 16:46:24	\N
83052T	M.	Rufin	RUFIN	Michel	1920-08-12 00:00:00	2002-03-27 00:00:00	ANCIEN	Notaire	3128	52	RPR	RPR	\N	AFCL	AFCL	550	Meuse	\N	\N	RUFIN	NON	\N	\N	\N	\N
89004L	M.	Jourdain	JOURDAIN	André	1935-06-13 00:00:00	2019-09-16 00:00:00	ANCIEN	Professeur	3400	64	NI	NI	\N	SOCI	SOCI	390	Jura	\N	\N	JOURDAIN	NON	\N	\N	2014-05-30 11:39:47	\N
92041R	M.	Poirieux	POIRIEUX	Guy	1936-03-09 00:00:00	2012-03-21 00:00:00	ANCIEN	Médecin	3112	42	RI	RI	\N	AFCL	AFCL	420	Loire	\N	\N	POIRIEUX	NON	\N	\N	\N	\N
83044T	M.	Mercier	MERCIER LOUIS	Louis	1920-05-10 00:00:00	2014-04-14 00:00:00	ANCIEN	Agriculteur	1000	10	UC	UC	\N	ECON	ECON	420	Loire	\N	\N	MERCIER	NON	\N	\N	2017-07-04 10:59:31	\N
92019T	Mme	Dieulangard	DIEULANGARD	Marie-Madeleine	1936-07-19 00:00:00	\N	ANCIEN	Secrétaire médico-sociale	5400	33	SOC	SER	\N	SOCI	SOCI	440	Loire-Atlantique	Secrétaire du Sénat	\N	DIEULANGARD	NON	\N	\N	2017-10-04 09:46:30	\N
92032Q	M.	Lemaire	LEMAIRE	Guy	1938-06-06 00:00:00	\N	ANCIEN	Médecin biologiste	3112	42	RPR	RPR	\N	ECON	ECON	440	Loire-Atlantique	\N	\N	LEMAIRE	NON	\N	\N	2014-05-30 11:39:47	\N
74015M	M.	Boyer	BOYER LOUIS	Louis	1921-11-13 00:00:00	2017-05-11 00:00:00	ANCIEN	Médecin	3112	42	RI	RI	\N	SOCI	SOCI	450	Loiret	\N	\N	BOYER	NON	\N	\N	2017-05-15 16:04:19	\N
74028S	M.	Malécot	MALECOT	Kléber	1915-02-12 00:00:00	2008-01-03 00:00:00	ANCIEN	Négociant	2200	23	UC	UC	\N	ECON	ECON	450	Loiret	\N	\N	MALÉCOT	NON	\N	\N	2017-07-04 10:59:31	\N
80031A	M.	Mouly	MOULY	Georges	1931-02-21 00:00:00	2019-12-07 00:00:00	ANCIEN	Professeur	4200	62	RDSE	RDSE	\N	SOCI	SOCI	190	Corrèze	\N	\N	MOULY	NON	\N	\N	\N	\N
94002S	M.	de Rocca Serra	ROCCASERRA LOUISFERDINAND	Louis Ferdinand	1936-02-07 00:00:00	2021-12-17 00:00:00	ANCIEN	Chef d'agence de la Caisse d'Epargne	3600	32	RI	RI	\N	FINC	FINC	200	Corse-du-Sud	\N	\N	de ROCCA SERRA	NON	\N	\N	\N	\N
99001N	M.	Donnay	DONNAY	Jacques	1925-01-07 00:00:00	2024-03-13 00:00:00	ANCIEN	Commerçant	2200	22	NI	NI	\N	AFCL	AFCL	590	Nord	\N	\N	DONNAY	NON	\N	\N	\N	\N
99003Q	M.	Dubrule	DUBRULE	Paul	1934-07-06 00:00:00	\N	ANCIEN	Administrateur de sociétés	2300	21	UMP	Les Républicains	\N	ETRD	ETRD	770	Seine-et-Marne	\N	\N	DUBRULE	NON	\N	\N	2017-10-09 16:22:50	\N
98043U	M.	Lassourd	LASSOURD	Patrick	1942-09-03 00:00:00	2003-08-28 00:00:00	ANCIEN	Vétérinaire	8000	46	UMP	Les Républicains	\N	ECON	ECON	350	Ille-et-Vilaine	\N	\N	LASSOURD	NON	\N	\N	2017-10-09 16:22:50	\N
98053W	M.	Foucaud	FOUCAUD	Thierry	1954-01-18 00:00:00	\N	ANCIEN	Opérateur en produits chimiques	8000	39	CRC	CRCE	\N	ETRD	ETRD	760	Seine-Maritime	\N	\N	FOUCAUD	NON	\N	\N	2018-05-31 10:52:17	\N
00001A	M.	Autexier	AUTEXIER	Jean-Yves	1950-01-05 00:00:00	\N	ANCIEN	Cadre administratif	3700	32	CRC	CRCE	\N	ETRD	ETRD	615	Paris	\N	\N	AUTEXIER	NON	\N	\N	2017-10-04 09:44:05	\N
93007T	M.	Marest	MAREST	Max	1929-09-09 00:00:00	2016-03-19 00:00:00	ANCIEN	Directeur commercial (industrie)	3600	32	UMP	Les Républicains	\N	ECON	ECON	265	Essonne	\N	\N	MAREST	NON	\N	\N	2017-10-09 16:22:51	\N
01004H	M.	Mano	MANO	Jean-Yves	1947-09-25 00:00:00	\N	ANCIEN	Cadre commercial	3700	32	SOC	SER	\N	ECON	ECON	615	Paris	\N	\N	MANO	NON	\N	\N	2017-10-04 09:46:33	\N
83008P	M.	Abadie	ABADIE	François	1930-06-19 00:00:00	2001-03-02 00:00:00	ANCIEN	Directeur commercial	3600	32	RDSE	RDSE	\N	AFCL	AFCL	650	Hautes-Pyrénées	\N	\N	ABADIE	NON	\N	\N	2017-11-14 10:03:00	\N
81007E	M.	Delong	DELONG	Jacques-Richard	1921-08-14 00:00:00	2012-07-15 00:00:00	ANCIEN	Pharmacien 	3116	44	RPR	RPR	\N	FINC	FINC	520	Haute-Marne	\N	\N	DELONG	NON	\N	\N	\N	\N
86005Y	M.	Bimbenet	BIMBENET	Jacques	1928-07-02 00:00:00	2018-05-17 00:00:00	ANCIEN	Agent d'assurances	3100	57	RDSE	RDSE	\N	SOCI	SOCI	410	Loir-et-Cher	\N	\N	BIMBENET	NON	\N	\N	2018-05-23 11:13:25	\N
95002W	M.	Lauret	LAURET	Edmond	1949-05-17 00:00:00	\N	ANCIEN	Inspecteur du Trésor	3311	71	RPR	RPR	\N	LOIS	LOIS	974	La Réunion	\N	\N	LAURET	NON	\N	\N	\N	\N
92027T	M.	Huguet	HUGUET	Roland	1933-10-17 00:00:00	\N	ANCIEN	Professeur	4200	62	SOC	SER	\N	SOCI	SOCI	620	Pas-de-Calais	\N	\N	HUGUET	NON	\N	\N	2017-10-04 09:46:33	\N
83043S	M.	Masson	MASSON PAUL	Paul	1920-07-21 00:00:00	2009-05-28 00:00:00	ANCIEN	Préfet honoraire	3311	71	RPR	RPR	-R	ETRD	ETRD	450	Loiret	\N	\N	MASSON	NON	\N	\N	\N	\N
95043G	M.	Larifla	LARIFLA	Dominique	1936-07-06 00:00:00	\N	ANCIEN	Cardiologue (médecin des hôpitaux)	3112	73	RDSE	RDSE	\N	SOCI	SOCI	971	Guadeloupe	\N	\N	LARIFLA	NON	\N	\N	2017-06-15 09:47:50	\N
05011Y	M.	Vendasi	VENDASI FRANÇOIS	François	1940-06-24 00:00:00	2022-11-21 00:00:00	ANCIEN	Président-directeur général de sociétés	2300	21	RDSE	RDSE	\N	SOCI	SOCI	205	Haute-Corse	\N	\N	VENDASI	NON	\N	\N	2014-09-28 13:47:05	\N
86010V	M.	Baylet	BAYLET	Jean-Michel	1946-11-17 00:00:00	\N	ANCIEN	Président-directeur général d'un groupe de presse	3511	54	RDSE	RDSE	\N	ETRD	ETRD	820	Tarn-et-Garonne	\N	\N	BAYLET	NON	\N	\N	2017-06-15 09:44:10	\N
04016A	M.	Claudel	CLAUDEL 	Gérard	1925-02-23 00:00:00	2021-03-25 00:00:00	ANCIEN	Entrepreneur de travaux agricoles	1000	10	UMP	Les Républicains	-A	ECON	ECON	828	Val-d'Oise	\N	\N	CLAUDEL	NON	\N	\N	2017-10-09 16:22:52	\N
04017B	M.	Ginoux	GINOUX 	Georges	1933-11-08 00:00:00	2022-03-10 00:00:00	ANCIEN	Industriel retraité	7200	29	UMP	Les Républicains	\N	ECON	ECON	180	Cher	\N	\N	GINOUX	NON	\N	\N	2017-10-09 16:22:52	\N
83046V	M.	Neuwirth	NEUWIRTH	Lucien	1924-05-18 00:00:00	2013-11-26 00:00:00	ANCIEN	Administrateur Conseil	3100	57	RPR	RPR	\N	SOCI	SOCI	420	Loire	\N	\N	NEUWIRTH	NON	\N	\N	2013-11-27 11:13:00	\N
98041S	M.	Garrec	GARREC	René	1934-12-24 00:00:00	2023-10-12 00:00:00	ANCIEN	Conseiller d'Etat	8000	71	UMP	Les Républicains	\N	LOIS	LOIS	140	Calvados	\N	\N	GARREC	NON	\N	\N	2017-10-09 16:22:53	\N
04100U	Mme	Malovry	MALOVRY LUCIENNE	Lucienne	1931-04-11 00:00:00	\N	ANCIEN	Analyste	3128	57	UMP	Les Républicains	\N	AFCL	AFCL	828	Val-d'Oise	\N	\N	MALOVRY	NON	\N	\N	2017-10-09 16:22:53	\N
83016P	M.	Bonnet	BONNET	Christian	1921-06-14 00:00:00	2020-04-07 00:00:00	ANCIEN	Directeur de société	3600	32	RI	RI	\N	LOIS	LOIS	560	Morbihan	\N	\N	BONNET	NON	\N	\N	2017-06-15 09:43:38	\N
97004H	M.	Lagauche	LAGAUCHE	Serge	1940-01-02 00:00:00	\N	ANCIEN	Médecin	3112	42	SOC	SER	\N	AFCL	AFCL	824	Val-de-Marne	\N	\N	LAGAUCHE	NON	\N	\N	2017-10-04 09:46:35	\N
01051Q	M.	Boulaud	BOULAUD	Didier	1950-09-04 00:00:00	\N	ANCIEN	Instituteur	8000	63	SOC	SER	\N	ETRD	ETRD	580	Nièvre	\N	\N	BOULAUD	NON	\N	\N	2017-10-04 09:46:35	\N
01060R	M.	Masson	MASSON JEANLOUIS	Jean Louis	1947-03-25 00:00:00	\N	ANCIEN	Ingénieur en chef des mines	8000	31	NI	NI	N	AFCL	AFCL	570	Moselle	\N	\N	MASSON	NON	\N	\N	2023-10-01 00:37:00	\N
09010Q	M.	Pignard	PIGNARD JEAN-JACQUES	Jean-Jacques	1947-04-15 00:00:00	\N	ANCIEN	Professeur agrégé d'histoire	8000	72	UC	UC	\N	AFCL	AFCL	690	Rhône	\N	\N	PIGNARD	NON	\N	\N	2017-07-04 10:59:32	\N
09011R	M.	Villiers	VILLIERS ANDRÉ	André	1954-12-13 00:00:00	\N	ANCIEN	Agriculteur 	8000	10	UMP	Les Républicains	-R	SOCI	SOCI	890	Yonne	\N	\N	VILLIERS	NON	\N	\N	2017-10-09 16:22:55	\N
92034S	M.	Maman	MAMAN	André	1927-06-09 00:00:00	2018-04-13 00:00:00	ANCIEN	Professeur d'université	3400	61	UC	UC	-R	AFCL	AFCL	998	Français établis hors de France	\N	\N	MAMAN	NON	\N	\N	2018-05-28 17:17:08	\N
21092L	Mme	Guhl	GUHL_Antoinette	Antoinette	1970-06-10 00:00:00	\N	ACTIF	Cadre administratif et commercial d'entreprise	3735	55	GEST	GEST	\N	CAE	CAE	615	Paris	\N	\N	GUHL	OUI	250	2023-09-24 00:00:00	2024-04-16 04:37:00	http://www.hatvp.fr/pages_nominatives/guhl-antoinette.html
\.


--
-- Data for Name: senbur; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY senbur (senburid, burcod, senburdatdeb, senburdatfin, senburrelint, senburrngele, temvalcod, evelic, evelib, evelil, eveobs, senmat, senburhon, syscredat, sysmajdat) FROM stdin;
245	AUCUNSEN	\N	2004-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	77033C	NON	\N	\N
247	AUCUNSEN	\N	2015-10-11 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95039L	NON	\N	2015-10-13 14:16:30
249	AUCUNSEN	\N	2011-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95024D	NON	\N	\N
250	AUCUNSEN	\N	2011-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95046K	NON	\N	\N
252	AUCUNSEN	\N	2011-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95060H	NON	\N	\N
253	AUCUNSEN	\N	2002-12-10 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	86014A	NON	\N	\N
254	AUCUNSEN	\N	2014-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95009E	NON	\N	2014-09-28 12:56:42
255	AUCUNSEN	\N	2014-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95028H	NON	\N	2014-09-28 12:56:42
256	AUCUNSEN	\N	2004-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95023C	NON	\N	\N
258	AUCUNSEN	\N	2014-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95047L	NON	\N	2014-09-28 17:09:16
259	AUCUNSEN	\N	1998-11-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95048M	NON	\N	\N
260	AUCUNSEN	\N	2008-10-06 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95052H	NON	\N	\N
261	AUCUNSEN	\N	2014-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	86010V	NON	\N	2014-09-28 19:03:04
262	SECRETSEN	1998-10-06 00:00:00	2001-10-02 00:00:00	NON	2	ANCIEN	\N	\N	\N	\N	88008L	NON	\N	\N
263	AUCUNSEN	\N	2007-09-18 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	77044F	NON	\N	\N
264	AUCUNSEN	\N	2004-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	88013H	NON	\N	\N
265	AUCUNSEN	\N	2004-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95057N	NON	\N	\N
266	AUCUNSEN	\N	2011-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	97004H	NON	\N	\N
267	AUCUNSEN	\N	2004-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	86018E	NON	\N	\N
269	VICPDTSEN	2001-10-03 00:00:00	2004-10-05 00:00:00	NON	5	ANCIEN	\N	\N	\N	\N	97009N	NON	\N	\N
270	AUCUNSEN	\N	2004-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	79004F	NON	\N	\N
271	SECRETSEN	2001-10-03 00:00:00	2004-04-30 00:00:00	NON	9	ANCIEN	\N	\N	\N	\N	95051G	NON	\N	\N
272	AUCUNSEN	\N	2004-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95042F	NON	\N	\N
273	AUCUNSEN	\N	2002-07-17 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95031C	NON	\N	\N
274	AUCUNSEN	\N	2004-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	86035F	NON	\N	\N
275	AUCUNSEN	\N	2014-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	86049M	NON	\N	2014-09-28 18:03:38
276	AUCUNSEN	\N	2014-10-07 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95037J	NON	\N	2014-10-08 14:55:09
277	AUCUNSEN	\N	2008-10-06 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	87003B	NON	\N	\N
278	AUCUNSEN	\N	2004-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	86041D	NON	\N	\N
281	PDTSEN	1992-10-02 00:00:00	1998-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	68036E	NON	\N	\N
282	AUCUNSEN	\N	2002-06-06 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95059Q	NON	\N	\N
284	AUCUNSEN	\N	2014-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95055L	NON	\N	2014-09-28 13:21:47
285	PDTSEN	1998-10-01 00:00:00	2001-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	77058M	NON	\N	\N
286	AUCUNSEN	\N	2004-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95012Y	NON	\N	\N
287	AUCUNSEN	\N	2004-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95033E	NON	\N	\N
288	AUCUNSEN	1995-11-17 00:00:00	2009-07-23 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	86044G	NON	\N	\N
291	AUCUNSEN	1995-10-02 00:00:00	2017-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95035G	NON	\N	2017-09-24 18:17:56
292	AUCUNSEN	\N	2004-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	86011W	NON	\N	\N
294	AUCUNSEN	\N	2011-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95050F	NON	\N	\N
296	AUCUNSEN	\N	2008-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	89035T	NON	\N	\N
298	AUCUNSEN	\N	2011-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95044H	NON	\N	\N
299	AUCUNSEN	\N	2001-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	98002K	NON	\N	\N
300	AUCUNSEN	\N	2001-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95002W	NON	\N	\N
302	AUCUNSEN	\N	2011-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	92033R	NON	\N	\N
303	SECRETSEN	1986-10-07 00:00:00	1988-10-11 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	77001T	NON	\N	\N
304	AUCUNSEN	\N	1998-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	98004M	NON	\N	\N
305	AUCUNSEN	\N	2004-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	77028F	NON	\N	\N
306	AUCUNSEN	\N	2004-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95061J	NON	\N	\N
307	SECRETSEN	1982-11-19 00:00:00	1983-10-05 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	69001W	NON	\N	\N
308	AUCUNSEN	\N	1998-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	98001J	NON	\N	\N
309	AUCUNSEN	\N	2008-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	89021M	NON	\N	\N
310	AUCUNSEN	\N	2008-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	89023P	NON	\N	\N
311	AUCUNSEN	\N	2001-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	74019R	NON	\N	\N
312	AUCUNSEN	\N	2017-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	77002U	NON	\N	2017-09-24 18:59:59
313	AUCUNSEN	\N	2008-10-06 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	92008Q	NON	\N	\N
314	AUCUNSEN	\N	2001-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	92034S	NON	\N	\N
315	AUCUNSEN	\N	2004-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	90002A	NON	\N	\N
316	AUCUNSEN	\N	2001-10-10 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	74032N	NON	\N	\N
317	AUCUNSEN	\N	2004-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	86050E	NON	\N	\N
318	AUCUNSEN	\N	2004-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	86042E	NON	\N	\N
86	AUCUNSEN	\N	1998-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	93006S	NON	\N	\N
91	AUCUNSEN	\N	2000-03-28 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	97003G	NON	\N	\N
97	AUCUNSEN	\N	2004-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95016D	NON	\N	\N
183	AUCUNSEN	\N	2012-09-19 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95011X	NON	\N	\N
189	AUCUNSEN	\N	2001-03-27 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95022B	NON	\N	\N
195	AUCUNSEN	\N	2011-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	92043T	NON	\N	\N
201	AUCUNSEN	\N	2001-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	92027T	NON	\N	\N
283	AUCUNSEN	\N	2014-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	90004C	NON	\N	2014-09-28 13:21:47
289	AUCUNSEN	\N	2011-01-23 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95004Y	NON	\N	\N
295	AUCUNSEN	\N	2004-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95043G	NON	\N	\N
301	AUCUNSEN	\N	2004-07-19 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	96003C	NON	\N	\N
38	AUCUNSEN	\N	1998-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	80002U	NON	\N	\N
42	AUCUNSEN	\N	1998-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	89012L	NON	\N	\N
55	AUCUNSEN	\N	1998-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	81010Y	NON	\N	\N
85	AUCUNSEN	\N	1998-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	89028U	NON	\N	\N
81	AUCUNSEN	\N	1998-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	96001A	NON	\N	\N
58	AUCUNSEN	\N	1998-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	80028F	NON	\N	\N
8	AUCUNSEN	\N	1998-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	80043E	NON	\N	\N
319	AUCUNSEN	\N	2020-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98005N	NON	\N	\N
320	SECRETSEN	2001-10-03 00:00:00	2004-10-05 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	98006P	NON	\N	\N
321	AUCUNSEN	\N	2008-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98007Q	NON	\N	\N
322	AUCUNSEN	\N	2005-03-19 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98008R	NON	\N	\N
323	AUCUNSEN	\N	2001-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98009S	NON	\N	\N
324	AUCUNSEN	\N	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98010K	NON	\N	2014-09-28 17:27:35
325	AUCUNSEN	\N	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98011L	NON	\N	2014-09-28 17:27:35
326	AUCUNSEN	\N	2006-06-29 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98012M	NON	\N	\N
327	AUCUNSEN	\N	2008-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98013N	NON	\N	\N
328	AUCUNSEN	\N	2008-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98014P	NON	\N	\N
329	AUCUNSEN	\N	2008-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98015Q	NON	\N	\N
330	AUCUNSEN	\N	2008-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98016R	NON	\N	\N
331	AUCUNSEN	\N	2008-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98017S	NON	\N	\N
332	AUCUNSEN	\N	2021-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98018T	NON	\N	\N
333	AUCUNSEN	\N	2014-09-29 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98019U	NON	\N	2014-09-29 13:43:10
334	AUCUNSEN	1998-10-01 00:00:00	2004-12-23 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98020M	NON	\N	\N
335	AUCUNSEN	\N	2017-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98021N	NON	\N	2017-10-01 09:22:38
336	AUCUNSEN	\N	2008-10-06 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98022P	NON	\N	\N
73	AUCUNSEN	\N	1998-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	89031P	NON	\N	\N
338	AUCUNSEN	\N	2010-12-06 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98024R	NON	\N	\N
339	AUCUNSEN	\N	2004-04-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98025S	NON	\N	\N
340	AUCUNSEN	\N	2001-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98026T	NON	\N	\N
341	AUCUNSEN	\N	2015-06-12 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98027U	NON	\N	2015-06-12 16:01:58
342	AUCUNSEN	2011-10-01 00:00:00	2011-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98028V	NON	\N	\N
343	AUCUNSEN	\N	2020-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98029W	NON	\N	\N
346	AUCUNSEN	\N	2015-06-12 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98032R	NON	\N	2015-06-12 15:59:49
347	AUCUNSEN	1998-10-01 00:00:00	2008-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98033S	NON	\N	\N
348	AUCUNSEN	1998-10-01 00:00:00	2008-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98034T	NON	\N	\N
349	SECRETSEN	2004-10-06 00:00:00	2008-10-06 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98035U	NON	\N	\N
350	AUCUNSEN	\N	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98036V	NON	\N	2014-09-28 17:15:42
351	AUCUNSEN	\N	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98037W	NON	\N	2014-09-28 14:31:42
352	AUCUNSEN	2011-10-01 00:00:00	2011-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98038X	NON	\N	\N
353	AUCUNSEN	\N	2008-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98039Y	NON	\N	\N
354	AUCUNSEN	\N	2008-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98040R	NON	\N	\N
355	QUESTESEN	2004-10-06 00:00:00	2010-12-06 00:00:00	NON	2	ANCIEN	\N	\N	\N	\N	98041S	NON	\N	\N
356	AUCUNSEN	\N	2004-10-05 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98042T	NON	\N	\N
357	AUCUNSEN	\N	2003-08-28 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98043U	NON	\N	\N
358	AUCUNSEN	1998-10-01 00:00:00	2008-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98044V	NON	\N	\N
359	AUCUNSEN	\N	2008-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98045W	NON	\N	\N
60	AUCUNSEN	\N	1998-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	88002E	NON	\N	\N
360	AUCUNSEN	\N	2017-09-24 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98046X	NON	\N	2017-09-25 09:56:00
361	AUCUNSEN	\N	2008-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98047Y	NON	\N	\N
362	AUCUNSEN	\N	2008-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98048A	NON	\N	\N
363	AUCUNSEN	1998-10-01 00:00:00	2004-10-05 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98049B	NON	\N	\N
364	AUCUNSEN	\N	2020-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98050T	NON	\N	\N
365	AUCUNSEN	\N	2008-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98051U	NON	\N	\N
366	AUCUNSEN	\N	2014-09-16 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98052V	NON	\N	2014-09-16 14:55:28
372	AUCUNSEN	\N	1998-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	77058M	NON	\N	\N
113	VICPDTSEN	1992-10-07 00:00:00	1998-10-05 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	83031N	NON	\N	\N
371	AUCUNSEN	1998-10-02 00:00:00	2004-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	68036E	NON	\N	\N
416	AUCUNSEN	\N	2008-10-06 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01003G	NON	\N	\N
374	VICPDTSEN	1998-10-06 00:00:00	2001-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	83031N	NON	\N	\N
290	VICPDTSEN	1997-01-15 00:00:00	1998-10-05 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	86034E	NON	\N	\N
375	VICPDTSEN	1998-10-06 00:00:00	2001-10-02 00:00:00	NON	2	ANCIEN	\N	\N	\N	\N	86034E	NON	\N	\N
4	VICPDTSEN	1995-10-04 00:00:00	1998-10-05 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	78003A	NON	\N	\N
376	VICPDTSEN	1998-10-06 00:00:00	2001-10-02 00:00:00	NON	3	ANCIEN	\N	\N	\N	\N	78003A	NON	\N	\N
377	VICPDTSEN	1998-10-06 00:00:00	2001-10-02 00:00:00	NON	4	ANCIEN	\N	\N	\N	\N	80046H	NON	\N	\N
378	VICPDTSEN	1998-10-06 00:00:00	2001-10-02 00:00:00	NON	6	ANCIEN	\N	\N	\N	\N	89029V	NON	\N	\N
379	QUESTESEN	1998-10-06 00:00:00	2001-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	77047J	NON	\N	\N
382	AUCUNSEN	1998-10-06 00:00:00	2008-09-07 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	80017C	NON	\N	\N
107	VICPDTSEN	1995-11-06 00:00:00	1998-10-06 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	83026R	NON	\N	\N
384	SECRETSEN	1998-10-06 00:00:00	2001-10-03 00:00:00	NON	4	ANCIEN	\N	\N	\N	\N	89014N	NON	\N	\N
386	SECRETSEN	1998-10-06 00:00:00	2001-10-03 00:00:00	NON	5	ANCIEN	\N	\N	\N	\N	89030N	NON	\N	\N
154	SECRETSEN	1998-10-06 00:00:00	2001-10-03 00:00:00	NON	8	ANCIEN	\N	\N	\N	\N	92040Q	NON	\N	\N
63	SECRETSEN	1998-10-06 00:00:00	2001-10-03 00:00:00	NON	9	ANCIEN	\N	\N	\N	\N	96006F	NON	\N	\N
388	SECRETSEN	1998-10-06 00:00:00	2001-10-02 00:00:00	NON	11	ANCIEN	\N	\N	\N	\N	92005M	NON	\N	\N
389	AUCUNSEN	1998-10-06 00:00:00	2014-10-07 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	89017R	NON	\N	2014-10-08 14:52:55
205	SECRETSEN	1995-10-04 00:00:00	1998-10-06 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	92006N	NON	\N	\N
390	AUCUNSEN	1998-10-06 00:00:00	2001-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	92006N	NON	\N	\N
391	AUCUNSEN	1998-10-06 00:00:00	2008-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	89019T	NON	\N	\N
392	AUCUNSEN	1998-10-06 00:00:00	2001-10-02 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	81015E	NON	\N	\N
396	AUCUNSEN	1998-10-06 00:00:00	2008-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	80040B	NON	\N	\N
394	AUCUNSEN	1998-10-06 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	89007P	NON	\N	2014-09-28 16:42:05
397	AUCUNSEN	\N	2004-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98054X	NON	\N	\N
1	AUCUNSEN	\N	2008-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	89016Q	NON	\N	\N
14	AUCUNSEN	\N	2008-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	80045G	NON	\N	\N
25	VICPDTSEN	1986-10-07 00:00:00	1998-10-05 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	80017C	OUI	\N	\N
51	AUCUNSEN	\N	2008-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	89037V	NON	\N	\N
66	AUCUNSEN	\N	2004-02-12 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95053J	NON	\N	\N
77	AUCUNSEN	\N	1998-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	89034S	NON	\N	\N
95	AUCUNSEN	\N	2011-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	77019E	NON	\N	\N
112	AUCUNSEN	\N	2001-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	83028T	NON	\N	\N
135	AUCUNSEN	\N	2011-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	83033Q	NON	\N	\N
146	AUCUNSEN	\N	2001-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	83056X	NON	\N	\N
158	AUCUNSEN	\N	2011-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	83050R	NON	\N	\N
169	AUCUNSEN	\N	2002-01-19 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	97007L	NON	\N	\N
180	AUCUNSEN	\N	2001-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	83054V	NON	\N	\N
193	VICPDTSEN	1986-10-09 00:00:00	1989-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	77013X	NON	\N	\N
210	AUCUNSEN	\N	2011-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	92011K	NON	\N	\N
221	QUESTESEN	1992-10-07 00:00:00	1998-10-05 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	77047J	NON	\N	\N
235	SECRETSEN	2001-10-03 00:00:00	2004-10-05 00:00:00	NON	3	ANCIEN	\N	\N	\N	\N	95015C	NON	\N	\N
246	AUCUNSEN	\N	2004-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	83003J	NON	\N	\N
257	AUCUNSEN	\N	2014-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95025E	NON	\N	2014-09-28 17:09:16
268	AUCUNSEN	\N	2004-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	97005J	NON	\N	\N
279	AUCUNSEN	\N	2004-10-05 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95021A	NON	\N	\N
293	AUCUNSEN	\N	2002-12-05 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95013A	NON	\N	\N
398	AUCUNSEN	1998-11-01 00:00:00	2007-09-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	66002K	NON	\N	\N
399	AUCUNSEN	\N	2009-09-09 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	80024B	NON	\N	\N
400	AUCUNSEN	\N	2001-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	99001N	NON	\N	\N
403	AUCUNSEN	1999-11-02 00:00:00	2017-06-17 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	99002P	NON	\N	2017-06-19 12:20:22
404	AUCUNSEN	1999-11-14 00:00:00	2020-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	95067Q	NON	\N	\N
405	AUCUNSEN	\N	2004-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	99003Q	NON	\N	\N
406	AUCUNSEN	\N	2007-06-24 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	99004R	NON	\N	\N
407	AUCUNSEN	2000-01-19 00:00:00	2010-03-06 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	86030A	NON	\N	\N
408	AUCUNSEN	1998-10-01 00:00:00	2000-01-19 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	86047K	NON	\N	\N
409	AUCUNSEN	\N	2004-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	00001A	NON	\N	\N
410	AUCUNSEN	2000-03-19 00:00:00	2004-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	93007T	NON	\N	\N
411	AUCUNSEN	\N	2007-06-28 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	00002B	NON	\N	\N
412	AUCUNSEN	\N	2017-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	00003C	NON	\N	2017-09-24 18:05:41
413	AUCUNSEN	\N	2001-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	00004D	NON	\N	\N
414	AUCUNSEN	2001-01-17 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01001E	NON	\N	\N
415	AUCUNSEN	2001-02-08 00:00:00	2001-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01002F	NON	\N	\N
2	AUCUNSEN	\N	2008-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	89027T	NON	\N	\N
3	SECRETSEN	1992-10-07 00:00:00	1998-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	88005H	NON	\N	\N
5	SECRETSEN	1977-10-05 00:00:00	1980-10-07 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	71006X	NON	\N	\N
6	AUCUNSEN	\N	1998-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	71009B	NON	\N	\N
7	AUCUNSEN	\N	2008-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	89018S	NON	\N	\N
9	AUCUNSEN	\N	2007-01-25 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	89006N	NON	\N	\N
10	AUCUNSEN	\N	2008-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	88012G	NON	\N	\N
11	AUCUNSEN	\N	1998-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	89046W	NON	\N	\N
12	AUCUNSEN	\N	2008-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	84004P	NON	\N	\N
13	AUCUNSEN	\N	2008-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	85003S	NON	\N	\N
15	AUCUNSEN	\N	1998-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	80021X	NON	\N	\N
16	AUCUNSEN	\N	2004-10-18 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	96005E	NON	\N	\N
17	AUCUNSEN	\N	2007-07-04 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	71003U	NON	\N	\N
18	AUCUNSEN	\N	1998-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	80004W	NON	\N	\N
19	SECRETSEN	1992-10-07 00:00:00	1998-10-05 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	89017R	NON	\N	\N
20	AUCUNSEN	\N	2014-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	94003T	NON	\N	2014-09-28 13:16:32
21	AUCUNSEN	\N	2006-08-11 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	74050Q	NON	\N	\N
22	AUCUNSEN	\N	2020-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	80013X	NON	\N	\N
23	AUCUNSEN	\N	2008-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	89041R	NON	\N	\N
24	AUCUNSEN	\N	2008-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	80035E	NON	\N	\N
26	AUCUNSEN	\N	1998-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	78010Y	NON	\N	\N
27	AUCUNSEN	\N	1998-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	89024Q	NON	\N	\N
28	AUCUNSEN	2004-10-06 00:00:00	2008-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	89042S	NON	\N	\N
29	AUCUNSEN	\N	1998-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	89044U	NON	\N	\N
30	AUCUNSEN	\N	1998-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	89039X	NON	\N	\N
31	AUCUNSEN	\N	1998-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	89036U	NON	\N	\N
32	AUCUNSEN	\N	1998-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95068R	NON	\N	\N
33	AUCUNSEN	\N	1998-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	71018C	NON	\N	\N
34	AUCUNSEN	\N	1998-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	70001N	NON	\N	\N
35	SECRETSEN	1995-10-04 00:00:00	1998-10-05 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	89007P	NON	\N	\N
36	AUCUNSEN	\N	2008-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	89010J	NON	\N	\N
37	AUCUNSEN	\N	1998-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	89038W	NON	\N	\N
40	AUCUNSEN	\N	2014-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	89013M	NON	\N	2014-09-28 17:05:42
41	SECRETSEN	1995-10-04 00:00:00	1998-10-05 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	89014N	NON	\N	\N
631	QUESTESEN	\N	1966-12-22 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000733	NON	\N	\N
632	QUESTESEN	1974-10-03 00:00:00	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000359	NON	\N	\N
634	QUESTESEN	1962-10-04 00:00:00	1974-04-19 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000675	NON	\N	\N
636	QUESTESEN	1977-10-05 00:00:00	1983-10-02 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	58332E	NON	\N	\N
637	QUESTESEN	1971-10-05 00:00:00	1974-10-03 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000207	NON	\N	\N
638	QUESTESEN	1966-10-05 00:00:00	1974-10-03 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000355	NON	\N	\N
639	QUESTESEN	1959-05-05 00:00:00	1983-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000070	NON	\N	\N
641	QUESTESEN	1983-10-05 00:00:00	1986-10-01 00:00:00	NON	2	ANCIEN	\N	\N	\N	\N	000311	NON	\N	\N
643	SECRETSEN	1962-10-03 00:00:00	1963-10-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000340	NON	\N	\N
644	SECRETSEN	1971-10-05 00:00:00	1974-10-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000083	NON	\N	\N
645	SECRETSEN	1970-10-05 00:00:00	1974-10-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000350	NON	\N	\N
646	SECRETSEN	1983-10-05 00:00:00	1986-10-01 00:00:00	NON	4	ANCIEN	\N	\N	\N	\N	58657Y	NON	\N	\N
647	SECRETSEN	1980-10-07 00:00:00	1986-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58649Y	NON	\N	\N
650	SECRETSEN	1980-10-07 00:00:00	1983-10-05 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	58630M	NON	\N	\N
651	SECRETSEN	1968-10-04 00:00:00	1977-10-05 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000114	NON	\N	\N
652	SECRETSEN	1962-10-03 00:00:00	1978-05-08 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000097	NON	\N	\N
653	SECRETSEN	1974-10-03 00:00:00	1977-10-05 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000370	NON	\N	\N
654	SECRETSEN	1977-10-05 00:00:00	1980-10-07 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000551	NON	\N	\N
656	SECRETSEN	1971-10-05 00:00:00	1980-10-07 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000186	NON	\N	\N
657	AUCUNSEN	1962-10-04 00:00:00	1974-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000200	NON	\N	\N
658	SECRETSEN	1965-10-05 00:00:00	1967-10-11 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	57749X	NON	\N	\N
660	SECRETSEN	1967-10-11 00:00:00	1969-10-08 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	58342G	NON	\N	\N
661	AUCUNSEN	1971-10-06 00:00:00	1975-11-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000187	NON	\N	\N
662	SECRETSEN	1968-10-04 00:00:00	1971-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000096	NON	\N	\N
665	SECRETSEN	1977-10-05 00:00:00	1980-10-07 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58662V	NON	\N	\N
667	SECRETSEN	1977-10-05 00:00:00	1980-10-07 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000190	NON	\N	\N
668	AUCUNSEN	1968-10-05 00:00:00	1977-10-02 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000246	NON	\N	\N
669	AUCUNSEN	1965-10-06 00:00:00	1979-01-10 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000169	NON	\N	\N
671	AUCUNSEN	\N	1983-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58328J	NON	\N	\N
672	AUCUNSEN	\N	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59567C	NON	\N	\N
673	SECRETSEN	1969-10-08 00:00:00	1971-10-05 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	57426F	NON	\N	\N
674	AUCUNSEN	\N	1971-02-25 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000165	NON	\N	\N
675	AUCUNSEN	\N	1993-08-27 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000634	NON	\N	\N
676	AUCUNSEN	\N	1992-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59218H	NON	\N	\N
678	AUCUNSEN	\N	1989-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58920U	NON	\N	\N
679	SECRETSEN	1983-10-05 00:00:00	1989-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	58921V	NON	\N	\N
680	AUCUNSEN	\N	1986-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58619S	NON	\N	\N
681	AUCUNSEN	\N	1980-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58041V	NON	\N	\N
682	AUCUNSEN	\N	1973-06-25 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000160	NON	\N	\N
684	AUCUNSEN	\N	1986-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58654V	NON	\N	\N
685	AUCUNSEN	\N	1969-06-25 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000081	NON	\N	\N
686	AUCUNSEN	\N	1986-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58620K	NON	\N	\N
687	AUCUNSEN	\N	1962-07-04 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000028	NON	\N	\N
688	AUCUNSEN	\N	1971-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000328	NON	\N	\N
689	AUCUNSEN	\N	1965-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000316	NON	\N	\N
691	AUCUNSEN	\N	1962-07-04 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000013	NON	\N	\N
692	AUCUNSEN	\N	1992-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59217G	NON	\N	\N
693	AUCUNSEN	\N	1962-07-04 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000234	NON	\N	\N
694	AUCUNSEN	\N	1962-07-04 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	57701F	NON	\N	\N
695	AUCUNSEN	\N	1961-11-12 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000021	NON	\N	\N
697	AUCUNSEN	\N	1987-02-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000541	NON	\N	\N
698	AUCUNSEN	\N	1989-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000321	NON	\N	\N
699	AUCUNSEN	\N	1962-07-04 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000665	NON	\N	\N
700	AUCUNSEN	\N	1971-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000047	NON	\N	\N
121	AUCUNSEN	\N	2001-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	92041R	NON	\N	\N
122	AUCUNSEN	\N	2023-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	97011G	NON	\N	\N
123	AUCUNSEN	\N	2001-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	83044T	NON	\N	\N
125	AUCUNSEN	\N	2001-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	83025Q	NON	\N	\N
126	AUCUNSEN	\N	2001-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	83023N	NON	\N	\N
127	SECRETSEN	1998-10-06 00:00:00	2001-09-30 00:00:00	NON	3	ANCIEN	\N	\N	\N	\N	92019T	NON	\N	\N
128	AUCUNSEN	\N	2001-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	92032Q	NON	\N	\N
129	QUESTESEN	1995-10-04 00:00:00	1998-10-05 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	83012K	NON	\N	\N
130	AUCUNSEN	\N	2001-09-23 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	74015M	NON	\N	\N
131	AUCUNSEN	\N	2001-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	83043S	NON	\N	\N
133	SECRETSEN	1998-10-06 00:00:00	2001-10-03 00:00:00	NON	7	ANCIEN	\N	\N	\N	\N	92039X	NON	\N	\N
134	AUCUNSEN	\N	2008-09-24 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	88004G	NON	\N	\N
136	AUCUNSEN	\N	2001-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	81001X	NON	\N	\N
137	AUCUNSEN	\N	2001-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	94004U	NON	\N	\N
138	AUCUNSEN	\N	2001-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	83038V	NON	\N	\N
139	AUCUNSEN	\N	2001-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	83035S	NON	\N	\N
140	AUCUNSEN	\N	2001-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	92026S	NON	\N	\N
141	AUCUNSEN	\N	2001-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	92025R	NON	\N	\N
142	AUCUNSEN	1989-10-05 00:00:00	2011-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	82002D	NON	\N	\N
143	AUCUNSEN	\N	2020-11-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	96004D	NON	\N	\N
145	AUCUNSEN	\N	2001-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	92010J	NON	\N	\N
147	AUCUNSEN	\N	2001-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	81007E	NON	\N	\N
148	AUCUNSEN	\N	2001-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	74011H	NON	\N	\N
149	AUCUNSEN	\N	2014-07-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	83011J	NON	\N	2014-07-01 09:25:11
150	AUCUNSEN	\N	2001-01-26 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	74008N	NON	\N	\N
151	AUCUNSEN	\N	2001-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	92009R	NON	\N	\N
152	QUESTESEN	1998-10-06 00:00:00	2001-09-30 00:00:00	NON	2	ANCIEN	\N	\N	\N	\N	83036T	NON	\N	\N
153	AUCUNSEN	\N	2007-06-21 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	92007P	NON	\N	\N
155	AUCUNSEN	\N	2001-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	83052T	NON	\N	\N
156	AUCUNSEN	\N	2001-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	74022L	NON	\N	\N
157	AUCUNSEN	\N	2001-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	83016P	NON	\N	\N
159	AUCUNSEN	\N	2001-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	81011A	NON	\N	\N
160	AUCUNSEN	\N	2001-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	74042Q	NON	\N	\N
161	SECRETSEN	1989-10-04 00:00:00	1995-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	83037U	NON	\N	\N
783	AUCUNSEN	\N	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59526S	NON	\N	\N
784	VICPDTSEN	1968-10-04 00:00:00	1971-10-05 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000326	NON	\N	\N
785	AUCUNSEN	\N	1974-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000003	NON	\N	\N
786	AUCUNSEN	\N	1989-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58936D	NON	\N	\N
787	AUCUNSEN	\N	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59570W	NON	\N	\N
790	AUCUNSEN	\N	1974-07-09 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58202U	NON	\N	\N
791	AUCUNSEN	\N	1995-11-09 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59601L	NON	\N	\N
792	AUCUNSEN	\N	1962-07-04 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000257	NON	\N	\N
793	VICPDTSEN	1989-10-04 00:00:00	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59571X	NON	\N	\N
794	AUCUNSEN	\N	1974-08-26 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000111	NON	\N	\N
796	AUCUNSEN	\N	1967-03-08 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000038	NON	\N	\N
798	AUCUNSEN	\N	1979-06-11 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000439	NON	\N	\N
799	AUCUNSEN	\N	1992-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59221C	NON	\N	\N
800	AUCUNSEN	\N	1986-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000272	NON	\N	\N
802	AUCUNSEN	\N	1962-12-13 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58113U	NON	\N	\N
803	AUCUNSEN	\N	1983-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58349P	NON	\N	\N
804	AUCUNSEN	\N	1983-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58419L	NON	\N	\N
805	AUCUNSEN	\N	1974-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	57434F	NON	\N	\N
806	VICPDTSEN	1992-10-07 00:00:00	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59527T	NON	\N	\N
808	AUCUNSEN	\N	1992-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59222D	NON	\N	\N
809	VICPDTSEN	1983-10-05 00:00:00	1986-10-07 00:00:00	NON	4	ANCIEN	\N	\N	\N	\N	58923X	NON	\N	\N
810	AUCUNSEN	\N	1968-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	56819Q	NON	\N	\N
811	AUCUNSEN	\N	1967-08-03 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000060	NON	\N	\N
812	AUCUNSEN	\N	1978-08-29 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000235	NON	\N	\N
813	AUCUNSEN	\N	1988-05-13 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58805S	NON	\N	\N
815	AUCUNSEN	\N	1994-09-27 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000501	NON	\N	\N
816	AUCUNSEN	\N	1992-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59223E	NON	\N	\N
817	AUCUNSEN	\N	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59528U	NON	\N	\N
818	AUCUNSEN	\N	1983-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000196	NON	\N	\N
819	AUCUNSEN	\N	1962-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	57710G	NON	\N	\N
821	AUCUNSEN	\N	1968-06-16 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000073	NON	\N	\N
822	AUCUNSEN	\N	1992-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59224F	NON	\N	\N
823	AUCUNSEN	\N	1980-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000192	NON	\N	\N
824	AUCUNSEN	\N	1971-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000121	NON	\N	\N
825	AUCUNSEN	\N	1974-09-20 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000205	NON	\N	\N
826	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000173	NON	\N	\N
828	AUCUNSEN	\N	1998-01-19 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	71011U	NON	\N	\N
829	AUCUNSEN	\N	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59530N	NON	\N	\N
830	VICPDTSEN	1968-10-04 00:00:00	1995-03-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000397	NON	\N	\N
831	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000416	NON	\N	\N
832	AUCUNSEN	\N	1992-01-06 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000524	NON	\N	\N
834	AUCUNSEN	\N	1980-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58019X	NON	\N	\N
835	AUCUNSEN	\N	1978-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	57826T	NON	\N	\N
836	AUCUNSEN	\N	1979-04-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000031	NON	\N	\N
837	AUCUNSEN	\N	1974-03-16 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000194	NON	\N	\N
838	AUCUNSEN	\N	1962-12-13 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000250	NON	\N	\N
840	AUCUNSEN	\N	1974-01-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000066	NON	\N	\N
841	AUCUNSEN	\N	1965-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000199	NON	\N	\N
842	AUCUNSEN	\N	1992-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59226H	NON	\N	\N
843	AUCUNSEN	\N	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59572Y	NON	\N	\N
844	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000188	NON	\N	\N
845	AUCUNSEN	\N	1968-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000180	NON	\N	\N
847	AUCUNSEN	\N	1989-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000331	NON	\N	\N
848	AUCUNSEN	\N	1983-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58367R	NON	\N	\N
849	AUCUNSEN	\N	1997-06-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	86001U	NON	\N	\N
850	AUCUNSEN	\N	1974-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000084	NON	\N	\N
851	AUCUNSEN	\N	1980-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58043X	NON	\N	\N
853	AUCUNSEN	\N	1974-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000220	NON	\N	\N
854	AUCUNSEN	\N	1983-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58330C	NON	\N	\N
855	AUCUNSEN	\N	1983-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000203	NON	\N	\N
856	AUCUNSEN	\N	1992-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59227J	NON	\N	\N
857	AUCUNSEN	\N	1971-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000105	NON	\N	\N
858	AUCUNSEN	\N	1986-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000164	NON	\N	\N
860	AUCUNSEN	\N	1980-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000009	NON	\N	\N
861	AUCUNSEN	\N	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59531P	NON	\N	\N
862	AUCUNSEN	\N	1962-07-04 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000511	NON	\N	\N
863	AUCUNSEN	\N	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59573A	NON	\N	\N
864	AUCUNSEN	\N	1984-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58420D	NON	\N	\N
866	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000255	NON	\N	\N
867	AUCUNSEN	\N	1986-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000647	NON	\N	\N
868	AUCUNSEN	\N	1981-06-21 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59509R	NON	\N	\N
869	AUCUNSEN	\N	1983-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000122	NON	\N	\N
870	AUCUNSEN	\N	1988-07-13 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59305F	NON	\N	\N
871	AUCUNSEN	\N	1967-05-11 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000134	NON	\N	\N
874	AUCUNSEN	\N	1989-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58942B	NON	\N	\N
875	AUCUNSEN	\N	1985-04-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58502E	NON	\N	\N
876	AUCUNSEN	\N	1986-07-31 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000411	NON	\N	\N
877	AUCUNSEN	\N	1971-01-17 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000215	NON	\N	\N
879	AUCUNSEN	\N	1962-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000057	NON	\N	\N
881	AUCUNSEN	\N	1965-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000380	NON	\N	\N
882	AUCUNSEN	\N	1988-03-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000197	NON	\N	\N
884	AUCUNSEN	\N	1968-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	57613G	NON	\N	\N
885	AUCUNSEN	\N	1986-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000177	NON	\N	\N
886	AUCUNSEN	\N	1962-07-04 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000075	NON	\N	\N
887	AUCUNSEN	\N	1962-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	56905M	NON	\N	\N
888	AUCUNSEN	\N	1980-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000135	NON	\N	\N
890	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000046	NON	\N	\N
891	AUCUNSEN	\N	1980-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58021R	NON	\N	\N
892	AUCUNSEN	\N	1992-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000451	NON	\N	\N
893	AUCUNSEN	\N	1995-09-24 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000449	NON	\N	\N
894	QUESTESEN	1968-10-04 00:00:00	1971-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	59521M	NON	\N	\N
895	AUCUNSEN	\N	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59574B	NON	\N	\N
897	AUCUNSEN	\N	1989-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58944D	NON	\N	\N
898	AUCUNSEN	\N	1997-06-12 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	86027F	NON	\N	\N
899	AUCUNSEN	\N	1980-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000139	NON	\N	\N
900	AUCUNSEN	\N	1995-09-24 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000533	NON	\N	\N
901	AUCUNSEN	\N	1992-09-27 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59229L	NON	\N	\N
903	AUCUNSEN	\N	1986-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58668C	NON	\N	\N
904	AUCUNSEN	\N	1962-10-31 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	56601X	NON	\N	\N
905	AUCUNSEN	\N	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59534S	NON	\N	\N
906	AUCUNSEN	\N	1986-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58641Q	NON	\N	\N
907	AUCUNSEN	\N	1996-09-03 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	80020W	NON	\N	\N
908	AUCUNSEN	\N	1978-01-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000306	NON	\N	\N
910	AUCUNSEN	\N	1974-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000137	NON	\N	\N
911	AUCUNSEN	\N	1995-09-24 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59535T	NON	\N	\N
912	AUCUNSEN	\N	1983-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000319	NON	\N	\N
913	AUCUNSEN	\N	1962-07-04 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000071	NON	\N	\N
914	AUCUNSEN	\N	1986-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58656X	NON	\N	\N
916	AUCUNSEN	\N	1988-10-03 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000599	NON	\N	\N
917	AUCUNSEN	\N	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59536U	NON	\N	\N
918	AUCUNSEN	\N	1986-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58631N	NON	\N	\N
919	AUCUNSEN	\N	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59575C	NON	\N	\N
920	AUCUNSEN	\N	1974-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000062	NON	\N	\N
922	AUCUNSEN	\N	1992-09-27 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59230D	NON	\N	\N
923	AUCUNSEN	\N	1992-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59231E	NON	\N	\N
924	AUCUNSEN	\N	1978-07-23 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58673Y	NON	\N	\N
925	AUCUNSEN	\N	1988-07-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58816V	NON	\N	\N
926	AUCUNSEN	\N	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59537V	NON	\N	\N
927	AUCUNSEN	\N	1982-10-22 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000226	NON	\N	\N
929	VICPDTSEN	1992-10-07 00:00:00	1997-01-12 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	89032Q	NON	\N	\N
930	AUCUNSEN	\N	1989-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58949J	NON	\N	\N
931	AUCUNSEN	\N	1977-03-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000224	NON	\N	\N
932	AUCUNSEN	\N	1962-07-04 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	56531B	NON	\N	\N
933	AUCUNSEN	\N	1992-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59233G	NON	\N	\N
935	AUCUNSEN	\N	1967-04-03 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000216	NON	\N	\N
936	AUCUNSEN	\N	1971-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000459	NON	\N	\N
937	AUCUNSEN	\N	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59538W	NON	\N	\N
938	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000092	NON	\N	\N
939	AUCUNSEN	\N	1962-07-04 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000162	NON	\N	\N
940	AUCUNSEN	\N	1978-08-27 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000602	NON	\N	\N
942	AUCUNSEN	\N	1971-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000218	NON	\N	\N
943	AUCUNSEN	\N	1993-01-18 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000310	NON	\N	\N
944	AUCUNSEN	\N	1978-06-09 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000406	NON	\N	\N
945	AUCUNSEN	\N	1974-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000185	NON	\N	\N
946	SECRETSEN	1967-10-11 00:00:00	1968-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000243	NON	\N	\N
948	AUCUNSEN	\N	1974-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000273	NON	\N	\N
949	AUCUNSEN	\N	1983-04-18 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000308	NON	\N	\N
950	AUCUNSEN	\N	1975-11-06 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000403	NON	\N	\N
951	AUCUNSEN	\N	1986-04-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000630	NON	\N	\N
952	AUCUNSEN	\N	1983-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58348N	NON	\N	\N
953	AUCUNSEN	\N	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59539X	NON	\N	\N
956	AUCUNSEN	\N	1980-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58039C	NON	\N	\N
957	AUCUNSEN	\N	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59540Q	NON	\N	\N
958	AUCUNSEN	\N	1971-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000225	NON	\N	\N
959	AUCUNSEN	\N	1965-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	57208W	NON	\N	\N
960	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000348	NON	\N	\N
962	AUCUNSEN	\N	1962-07-04 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	56405V	NON	\N	\N
964	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000213	NON	\N	\N
965	AUCUNSEN	\N	1962-12-06 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000124	NON	\N	\N
966	AUCUNSEN	\N	1989-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58945E	NON	\N	\N
968	AUCUNSEN	\N	1989-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58913V	NON	\N	\N
969	AUCUNSEN	\N	1980-07-28 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000458	NON	\N	\N
970	AUCUNSEN	\N	1981-11-22 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000237	NON	\N	\N
971	AUCUNSEN	\N	1975-07-29 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000231	NON	\N	\N
972	AUCUNSEN	\N	1968-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000153	NON	\N	\N
974	AUCUNSEN	\N	1996-07-13 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	80022Y	NON	\N	\N
975	AUCUNSEN	\N	1967-04-18 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000086	NON	\N	\N
976	AUCUNSEN	\N	1974-10-13 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000063	NON	\N	\N
978	AUCUNSEN	\N	1998-02-16 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	92028U	NON	\N	\N
979	AUCUNSEN	\N	1967-04-03 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	56812H	NON	\N	\N
981	AUCUNSEN	\N	1968-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000303	NON	\N	\N
982	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000219	NON	\N	\N
983	AUCUNSEN	\N	1974-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000204	NON	\N	\N
984	AUCUNSEN	\N	1995-07-05 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000107	NON	\N	\N
985	VICPDTSEN	1980-10-07 00:00:00	1983-10-05 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59541R	NON	\N	\N
987	AUCUNSEN	\N	1994-07-15 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000456	NON	\N	\N
43	AUCUNSEN	\N	1998-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	71017B	NON	\N	\N
45	AUCUNSEN	\N	2008-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	80031A	NON	\N	\N
46	AUCUNSEN	\N	1998-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	80007A	NON	\N	\N
47	AUCUNSEN	\N	2001-09-20 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	94002S	NON	\N	\N
48	AUCUNSEN	\N	1998-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	97002F	NON	\N	\N
49	AUCUNSEN	\N	2008-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	98003L	NON	\N	\N
50	AUCUNSEN	\N	1998-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	80025C	NON	\N	\N
52	AUCUNSEN	\N	1998-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	80036F	NON	\N	\N
53	AUCUNSEN	\N	1998-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	97010F	NON	\N	\N
54	AUCUNSEN	\N	2008-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	89040Q	NON	\N	\N
56	AUCUNSEN	1983-10-06 00:00:00	2008-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	73006G	NON	\N	\N
57	AUCUNSEN	\N	1998-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	97001E	NON	\N	\N
59	AUCUNSEN	\N	2008-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	88009M	NON	\N	\N
61	AUCUNSEN	\N	2008-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	80041C	NON	\N	\N
62	AUCUNSEN	\N	2014-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	89015P	NON	\N	2014-09-28 16:50:17
64	AUCUNSEN	\N	2004-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	86037H	NON	\N	\N
65	AUCUNSEN	\N	2001-01-16 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95027G	NON	\N	\N
67	AUCUNSEN	\N	2000-04-27 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	86039K	NON	\N	\N
68	AUCUNSEN	\N	2000-03-18 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	88003F	NON	\N	\N
69	AUCUNSEN	\N	2014-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	89022N	NON	\N	2014-09-28 18:19:47
70	AUCUNSEN	\N	1998-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	81014D	NON	\N	\N
71	AUCUNSEN	\N	1998-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	83004K	NON	\N	\N
72	AUCUNSEN	\N	2001-10-14 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	89009R	NON	\N	\N
74	AUCUNSEN	\N	1998-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	80003V	NON	\N	\N
75	AUCUNSEN	\N	1998-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	71024A	NON	\N	\N
76	AUCUNSEN	\N	2008-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	86006A	NON	\N	\N
78	AUCUNSEN	\N	1998-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	92046W	NON	\N	\N
79	SECRETSEN	1992-10-07 00:00:00	1998-10-05 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	80040B	NON	\N	\N
80	AUCUNSEN	\N	1998-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	80033C	NON	\N	\N
82	AUCUNSEN	1980-10-02 00:00:00	2008-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	80039J	NON	\N	\N
83	SECRETSEN	1993-10-06 00:00:00	1998-10-05 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	89019T	NON	\N	\N
84	AUCUNSEN	\N	1998-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	89008Q	NON	\N	\N
87	SECRETSEN	1998-10-01 00:00:00	2001-10-03 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	90003B	NON	\N	\N
88	AUCUNSEN	\N	2019-08-27 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	80027E	NON	\N	\N
89	AUCUNSEN	\N	2008-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	89025R	NON	\N	\N
90	VICPDTSEN	1995-10-04 00:00:00	1998-10-05 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	80046H	NON	\N	\N
92	AUCUNSEN	\N	2004-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	93005R	NON	\N	\N
93	AUCUNSEN	\N	2011-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95007C	NON	\N	\N
94	AUCUNSEN	\N	2011-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95006B	NON	\N	\N
96	AUCUNSEN	\N	1999-12-16 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	77053G	NON	\N	\N
98	AUCUNSEN	\N	2008-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	80015A	NON	\N	\N
99	AUCUNSEN	\N	2007-06-28 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	89043T	NON	\N	\N
100	AUCUNSEN	\N	2006-07-08 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	80048K	NON	\N	\N
101	AUCUNSEN	\N	1998-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	80026D	NON	\N	\N
102	SECRETSEN	1988-10-18 00:00:00	1990-10-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	80014Y	NON	\N	\N
103	AUCUNSEN	\N	1998-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	80011V	NON	\N	\N
104	AUCUNSEN	\N	1998-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	89026S	NON	\N	\N
105	SECRETSEN	1995-10-04 00:00:00	1998-10-05 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	89030N	NON	\N	\N
106	AUCUNSEN	\N	2007-11-21 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	89020L	NON	\N	\N
108	AUCUNSEN	\N	2011-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	92030N	NON	\N	\N
109	AUCUNSEN	\N	2001-09-23 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	92012L	NON	\N	\N
111	AUCUNSEN	\N	2001-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	83018R	NON	\N	\N
114	AUCUNSEN	\N	2001-02-07 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	74024N	NON	\N	\N
115	AUCUNSEN	\N	2001-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	89004L	NON	\N	\N
116	AUCUNSEN	1983-10-03 00:00:00	2011-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	83039W	NON	\N	\N
117	AUCUNSEN	\N	2017-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	92015P	NON	\N	2017-09-24 13:14:55
118	AUCUNSEN	\N	2011-01-23 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	92022N	NON	\N	\N
119	AUCUNSEN	\N	2001-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	86005Y	NON	\N	\N
162	AUCUNSEN	\N	2001-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	74013K	NON	\N	\N
164	AUCUNSEN	\N	2001-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	97008M	NON	\N	\N
166	AUCUNSEN	\N	2011-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	86053H	NON	\N	\N
168	AUCUNSEN	\N	2001-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	65017N	NON	\N	\N
170	AUCUNSEN	\N	2017-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	92031P	NON	\N	2017-09-24 18:16:52
172	AUCUNSEN	\N	1999-10-16 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	83013L	NON	\N	\N
173	SECRETSEN	1995-10-04 00:00:00	1998-10-05 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	85002R	NON	\N	\N
174	AUCUNSEN	\N	2017-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	92044U	NON	\N	2017-09-24 18:16:52
175	AUCUNSEN	\N	2011-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	92037V	NON	\N	\N
176	AUCUNSEN	\N	2011-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	92042S	NON	\N	\N
177	VICPDTSEN	1998-10-06 00:00:00	2001-09-30 00:00:00	NON	5	ANCIEN	\N	\N	\N	\N	83010H	NON	\N	\N
178	AUCUNSEN	\N	2011-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	92045V	NON	\N	\N
179	AUCUNSEN	\N	2015-01-08 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	92035T	NON	\N	2015-01-08 17:14:29
181	AUCUNSEN	\N	2007-02-25 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	92024Q	NON	\N	\N
182	AUCUNSEN	\N	2002-06-07 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	92029V	NON	\N	\N
184	AUCUNSEN	\N	2004-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95056M	NON	\N	\N
185	AUCUNSEN	\N	2004-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	86025D	NON	\N	\N
186	AUCUNSEN	\N	2004-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95026F	NON	\N	\N
187	AUCUNSEN	\N	2004-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	86028G	NON	\N	\N
188	AUCUNSEN	\N	2004-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	93003P	NON	\N	\N
190	AUCUNSEN	\N	2002-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	77009C	NON	\N	\N
191	AUCUNSEN	\N	2004-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95058P	NON	\N	\N
192	AUCUNSEN	\N	2004-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	77046H	NON	\N	\N
194	AUCUNSEN	\N	2000-01-27 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95018F	NON	\N	\N
196	AUCUNSEN	\N	2002-06-07 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	92017R	NON	\N	\N
197	AUCUNSEN	\N	2001-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	86004X	NON	\N	\N
198	AUCUNSEN	\N	2001-09-23 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	84003N	NON	\N	\N
199	AUCUNSEN	\N	2001-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	92021M	NON	\N	\N
200	AUCUNSEN	\N	2017-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	83047W	NON	\N	2017-09-24 17:42:26
202	AUCUNSEN	\N	2001-09-23 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	83017Q	NON	\N	\N
203	SECRETSEN	1995-10-04 00:00:00	1998-10-05 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	81015E	NON	\N	\N
204	AUCUNSEN	\N	2011-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	83021L	NON	\N	\N
206	AUCUNSEN	\N	2011-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	92013M	NON	\N	\N
207	AUCUNSEN	\N	2017-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	92020L	NON	\N	2017-09-24 12:39:59
208	AUCUNSEN	\N	2001-03-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	83008P	NON	\N	\N
209	AUCUNSEN	\N	2001-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	92036U	NON	\N	\N
211	AUCUNSEN	1995-10-02 00:00:00	2004-11-26 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95036H	NON	\N	\N
212	SECRETSEN	1995-10-04 00:00:00	1998-10-05 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	92005M	NON	\N	\N
213	VICPDTSEN	2001-10-03 00:00:00	2004-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	77029G	NON	\N	\N
215	AUCUNSEN	\N	2004-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95029J	NON	\N	\N
216	SECRETSEN	1998-10-06 00:00:00	2000-01-18 00:00:00	NON	6	ANCIEN	\N	\N	\N	\N	86030A	NON	\N	\N
217	AUCUNSEN	\N	2004-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95045J	NON	\N	\N
218	AUCUNSEN	\N	2004-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95017E	NON	\N	\N
220	SECRETSEN	1992-10-07 00:00:00	1995-10-04 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	86031B	NON	\N	\N
222	AUCUNSEN	\N	1999-11-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	77066M	NON	\N	\N
223	AUCUNSEN	\N	2009-07-23 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95049N	NON	\N	\N
225	SECRETSEN	2001-10-03 00:00:00	2004-09-30 00:00:00	NON	8	ANCIEN	\N	\N	\N	\N	95040D	NON	\N	\N
226	AUCUNSEN	\N	2002-06-19 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95041E	NON	\N	2014-09-28 13:40:33
227	AUCUNSEN	\N	2017-07-12 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95030B	NON	\N	2014-09-28 21:58:57
228	AUCUNSEN	\N	2004-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	86043F	NON	\N	\N
230	AUCUNSEN	\N	2004-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	77012W	NON	\N	\N
231	AUCUNSEN	1989-10-05 00:00:00	2004-10-05 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	77043E	NON	\N	\N
232	AUCUNSEN	\N	2014-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95019G	NON	\N	2014-09-28 16:59:41
233	AUCUNSEN	\N	1999-09-23 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95008D	NON	\N	\N
234	AUCUNSEN	\N	2004-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	77060F	NON	\N	\N
1572	AUCUNSEN	\N	\N	NON	\N	ACTIF	\N	\N	\N	\N	04092N	NON	\N	\N
236	AUCUNSEN	\N	2014-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95038K	NON	\N	2014-09-28 17:40:23
237	AUCUNSEN	\N	2014-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95005A	NON	\N	2014-09-28 17:40:23
238	SECRETSEN	2001-10-03 00:00:00	2004-09-30 00:00:00	NON	2	ANCIEN	\N	\N	\N	\N	95014B	NON	\N	\N
239	AUCUNSEN	\N	2019-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95062K	NON	\N	\N
241	AUCUNSEN	\N	2008-10-06 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95003X	NON	\N	\N
242	AUCUNSEN	\N	1998-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	88006J	NON	\N	\N
243	AUCUNSEN	\N	2014-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95034F	NON	\N	2014-09-28 18:00:58
244	AUCUNSEN	\N	1999-11-27 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95054K	NON	\N	\N
1758	AUCUNSEN	2008-10-01 00:00:00	2020-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08053X	NON	\N	\N
1760	AUCUNSEN	2008-10-01 00:00:00	2014-10-07 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08055A	NON	\N	2014-10-08 14:50:36
1636	AUCUNSEN	1948-11-07 00:00:00	1980-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000720	NON	\N	\N
1637	AUCUNSEN	1992-10-02 00:00:00	2001-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	92016Q	NON	\N	\N
1638	AUCUNSEN	1965-10-02 00:00:00	1983-10-02 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	58336J	NON	\N	\N
1639	AUCUNSEN	1965-03-03 00:00:00	1968-10-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	58332E	NON	\N	\N
1640	AUCUNSEN	1974-10-04 00:00:00	1977-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	58332E	NON	\N	\N
1649	AUCUNSEN	\N	2009-07-23 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	07024N	NON	\N	\N
1761	AUCUNSEN	2008-10-01 00:00:00	\N	NON	\N	ACTIF	\N	\N	\N	\N	08056B	NON	\N	\N
1768	AUCUNSEN	2008-10-01 00:00:00	2020-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08058D	NON	\N	\N
1769	AUCUNSEN	2008-10-01 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08059E	NON	\N	2014-09-28 17:27:29
1770	AUCUNSEN	2008-10-01 00:00:00	2023-10-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08060W	NON	\N	\N
1771	AUCUNSEN	2008-10-01 00:00:00	\N	NON	\N	ACTIF	\N	\N	\N	\N	08061X	NON	\N	\N
1772	AUCUNSEN	2008-10-01 00:00:00	2020-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08062Y	NON	\N	\N
1774	AUCUNSEN	2008-10-01 00:00:00	2012-07-21 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08064B	NON	\N	\N
1776	AUCUNSEN	2008-10-01 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08066D	NON	\N	2014-09-28 19:03:23
1778	AUCUNSEN	2008-10-01 00:00:00	2020-06-15 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08068F	NON	\N	\N
1779	AUCUNSEN	2008-10-01 00:00:00	\N	NON	\N	ACTIF	\N	\N	\N	\N	08069G	NON	\N	\N
1780	AUCUNSEN	2008-10-02 00:00:00	2014-05-02 00:00:00	NON	0	ANCIEN	\N	\N	\N	\N	08070Y	NON	\N	2014-05-05 14:00:44
1781	AUCUNSEN	2008-10-01 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08071A	NON	\N	2014-09-29 09:08:33
1782	AUCUNSEN	2008-10-01 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08072B	NON	\N	2014-09-29 09:05:47
1783	AUCUNSEN	2008-10-01 00:00:00	2020-10-05 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08073C	NON	\N	\N
1784	AUCUNSEN	2008-09-25 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08074D	NON	\N	\N
1787	VICPDTSEN	2008-10-07 00:00:00	2011-10-04 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	04056J	NON	\N	\N
1789	VICPDTSEN	2008-10-07 00:00:00	2011-09-30 00:00:00	NON	2	ANCIEN	\N	\N	\N	\N	01054T	NON	\N	\N
1792	VICPDTSEN	2008-10-07 00:00:00	2011-10-04 00:00:00	NON	3	ANCIEN	\N	\N	\N	\N	77043E	NON	\N	\N
1793	VICPDTSEN	2008-10-07 00:00:00	2011-03-28 00:00:00	NON	4	ANCIEN	\N	\N	\N	\N	89029V	NON	\N	\N
1794	VICPDTSEN	2008-10-07 00:00:00	2011-09-30 00:00:00	NON	5	ANCIEN	\N	\N	\N	\N	59312E	NON	\N	\N
1795	VICPDTSEN	2008-10-07 00:00:00	2011-09-30 00:00:00	NON	6	ANCIEN	\N	\N	\N	\N	02001J	NON	\N	\N
1796	AUCUNSEN	2008-10-07 00:00:00	2017-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01031L	NON	\N	2017-09-24 18:20:10
1797	AUCUNSEN	2008-10-07 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	83031N	NON	\N	\N
1798	SECRETSEN	2008-10-07 00:00:00	2008-11-11 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	95032D	NON	\N	\N
1799	AUCUNSEN	2008-10-07 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	78006D	NON	\N	\N
1871	AUCUNSEN	\N	2023-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	11010L	NON	\N	\N
1872	AUCUNSEN	2011-10-01 00:00:00	2017-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	11011M	NON	\N	2017-09-24 10:41:28
1873	AUCUNSEN	2011-10-01 00:00:00	2011-11-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01048V	NON	\N	\N
1874	AUCUNSEN	2011-10-01 00:00:00	2014-08-26 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	11018G	NON	\N	2014-08-27 16:33:37
1875	AUCUNSEN	2011-10-01 00:00:00	2017-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	11015D	NON	\N	2017-09-24 13:42:36
1876	AUCUNSEN	2011-10-01 00:00:00	2017-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	11014C	NON	\N	2017-09-24 13:14:55
1877	AUCUNSEN	2011-10-01 00:00:00	2017-07-05 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	11012A	NON	\N	2017-07-06 10:38:53
1878	AUCUNSEN	2011-10-01 00:00:00	2017-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	11023D	NON	\N	2017-09-25 10:56:48
1879	AUCUNSEN	2011-10-01 00:00:00	2017-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	11030C	NON	\N	2017-09-24 17:09:24
1880	AUCUNSEN	2011-10-01 00:00:00	2017-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	11042G	NON	\N	2017-09-24 17:35:15
1881	AUCUNSEN	2011-10-01 00:00:00	2017-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	11057P	NON	\N	2017-09-24 18:23:22
1882	AUCUNSEN	2011-10-01 00:00:00	2023-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	11090Q	NON	\N	\N
1883	AUCUNSEN	2011-10-01 00:00:00	2023-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	11074Q	NON	\N	\N
1886	AUCUNSEN	2011-10-01 00:00:00	2016-03-11 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11069T	\N	\N	2016-03-11 18:02:51
701	AUCUNSEN	\N	1988-06-24 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59309K	NON	\N	\N
703	AUCUNSEN	\N	1962-07-04 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	56326X	NON	\N	\N
704	AUCUNSEN	\N	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59566B	NON	\N	\N
705	AUCUNSEN	\N	1973-09-26 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000285	NON	\N	\N
706	AUCUNSEN	\N	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59583C	NON	\N	\N
707	AUCUNSEN	\N	1961-09-19 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000113	NON	\N	\N
708	AUCUNSEN	\N	1989-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58911T	NON	\N	\N
710	AUCUNSEN	\N	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59522N	NON	\N	\N
711	QUESTESEN	1983-10-05 00:00:00	1995-10-04 00:00:00	NON	3	ANCIEN	\N	\N	\N	\N	79002D	NON	\N	\N
712	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	57741P	NON	\N	\N
713	AUCUNSEN	\N	1980-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000016	NON	\N	\N
714	AUCUNSEN	\N	1971-11-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000490	NON	\N	\N
716	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000115	NON	\N	\N
718	AUCUNSEN	\N	1998-02-25 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	79005G	NON	\N	\N
719	AUCUNSEN	\N	1974-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000282	NON	\N	\N
720	AUCUNSEN	\N	1973-04-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58109Y	NON	\N	\N
721	AUCUNSEN	\N	1980-06-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58515K	NON	\N	\N
722	AUCUNSEN	\N	1975-11-08 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000002	NON	\N	\N
723	AUCUNSEN	\N	1990-04-11 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000529	NON	\N	\N
725	AUCUNSEN	\N	1980-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000032	NON	\N	\N
726	AUCUNSEN	\N	1967-04-03 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000400	NON	\N	\N
727	AUCUNSEN	\N	1992-10-14 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59721T	NON	\N	\N
728	AUCUNSEN	\N	1992-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000663	NON	\N	\N
729	AUCUNSEN	\N	1986-09-09 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000460	NON	\N	\N
730	AUCUNSEN	\N	1986-04-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58819Y	NON	\N	\N
732	AUCUNSEN	\N	1973-01-09 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000425	NON	\N	\N
733	AUCUNSEN	\N	1962-07-04 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	57316A	NON	\N	\N
734	AUCUNSEN	\N	1962-07-04 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000346	NON	\N	\N
1256	AUCUNSEN	\N	1976-03-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000018	NON	\N	\N
1257	AUCUNSEN	\N	1996-01-24 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	83022M	NON	\N	\N
1258	AUCUNSEN	\N	1987-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000572	NON	\N	\N
1259	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000058	NON	\N	\N
1260	AUCUNSEN	\N	1982-01-10 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000089	NON	\N	\N
1262	AUCUNSEN	\N	1988-02-05 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000621	NON	\N	\N
1263	AUCUNSEN	\N	1973-09-09 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000322	NON	\N	\N
1264	AUCUNSEN	\N	1975-12-29 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000106	NON	\N	\N
1265	AUCUNSEN	\N	1974-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000056	NON	\N	\N
1266	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000388	NON	\N	\N
1268	AUCUNSEN	\N	1980-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000110	NON	\N	\N
1269	AUCUNSEN	\N	1971-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000072	NON	\N	\N
1270	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000133	NON	\N	\N
1271	AUCUNSEN	\N	1976-02-16 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000325	NON	\N	\N
1272	AUCUNSEN	\N	1989-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58925A	NON	\N	\N
1273	AUCUNSEN	\N	1987-12-03 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000611	NON	\N	\N
1275	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000119	NON	\N	\N
1276	SECRETSEN	1968-10-04 00:00:00	1971-10-05 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	59578F	NON	\N	\N
1277	AUCUNSEN	\N	1992-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59241G	NON	\N	\N
1278	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000178	NON	\N	\N
1279	AUCUNSEN	\N	1979-06-17 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000007	NON	\N	\N
1281	AUCUNSEN	\N	1961-07-18 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000300	NON	\N	\N
1282	AUCUNSEN	\N	1996-07-08 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	89005M	NON	\N	\N
1283	AUCUNSEN	\N	1992-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59248P	NON	\N	\N
1284	AUCUNSEN	\N	1985-09-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000595	NON	\N	\N
1285	AUCUNSEN	\N	1986-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58644T	NON	\N	\N
1288	AUCUNSEN	\N	1967-10-17 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000724	NON	\N	\N
1289	AUCUNSEN	\N	1971-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000689	NON	\N	\N
1290	AUCUNSEN	\N	1968-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000757	NON	\N	\N
1291	AUCUNSEN	\N	1974-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000731	NON	\N	\N
1292	AUCUNSEN	\N	1959-08-28 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000759	NON	\N	\N
1294	AUCUNSEN	\N	1974-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000711	NON	\N	\N
1296	AUCUNSEN	\N	1961-10-03 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000761	NON	\N	\N
1297	AUCUNSEN	\N	1971-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000696	NON	\N	\N
1298	AUCUNSEN	\N	1965-03-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000718	NON	\N	\N
1300	AUCUNSEN	\N	1962-11-23 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000756	NON	\N	\N
1301	AUCUNSEN	\N	1974-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000760	NON	\N	\N
1302	AUCUNSEN	\N	1979-09-03 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000735	NON	\N	\N
1303	AUCUNSEN	\N	1966-05-26 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000755	NON	\N	\N
1304	AUCUNSEN	\N	1968-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000723	NON	\N	\N
1306	AUCUNSEN	\N	1966-03-09 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000726	NON	\N	\N
1307	AUCUNSEN	\N	1971-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000763	NON	\N	\N
1308	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000702	NON	\N	\N
1309	AUCUNSEN	\N	1976-07-11 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000769	NON	\N	\N
1310	AUCUNSEN	\N	1974-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000683	NON	\N	\N
1311	AUCUNSEN	\N	1965-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000709	NON	\N	\N
1313	AUCUNSEN	\N	1966-03-09 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000685	NON	\N	\N
1314	AUCUNSEN	\N	1965-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000728	NON	\N	\N
1315	AUCUNSEN	\N	1965-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000713	NON	\N	\N
1316	AUCUNSEN	\N	1975-04-25 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000681	NON	\N	\N
1317	AUCUNSEN	\N	1965-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000764	NON	\N	\N
1320	AUCUNSEN	\N	1974-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000719	NON	\N	\N
1321	AUCUNSEN	\N	1968-09-23 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000678	NON	\N	\N
1322	AUCUNSEN	\N	1965-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000697	NON	\N	\N
1324	AUCUNSEN	\N	1968-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000766	NON	\N	\N
1326	AUCUNSEN	\N	1965-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000700	NON	\N	\N
1327	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000765	NON	\N	\N
1328	AUCUNSEN	\N	1974-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000721	NON	\N	\N
1329	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000732	NON	\N	\N
1330	AUCUNSEN	\N	1970-10-24 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000680	NON	\N	\N
1332	AUCUNSEN	\N	1976-05-05 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000727	NON	\N	\N
1333	AUCUNSEN	\N	1980-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000686	NON	\N	\N
1334	AUCUNSEN	\N	1962-07-04 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000670	NON	\N	\N
1335	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000758	NON	\N	\N
1336	AUCUNSEN	\N	1974-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000706	NON	\N	\N
1338	AUCUNSEN	\N	1971-10-28 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000693	NON	\N	\N
1339	AUCUNSEN	\N	1965-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000707	NON	\N	\N
1340	AUCUNSEN	\N	1968-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000710	NON	\N	\N
1633	AUCUNSEN	2006-07-09 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	06004E	NON	\N	2014-09-28 17:03:42
1652	AUCUNSEN	\N	2010-12-13 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	07027R	NON	\N	\N
1653	AUCUNSEN	\N	2010-12-13 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	07028S	NON	\N	\N
1667	AUCUNSEN	2007-12-17 00:00:00	2019-03-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	07034Q	NON	\N	\N
1785	PDTSEN	2008-10-01 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	86034E	NON	\N	\N
1786	AUCUNSEN	2008-10-01 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	77058M	NON	\N	2014-09-28 12:52:11
1788	QUESTESEN	2008-10-07 00:00:00	2010-11-25 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	92005M	NON	\N	\N
1790	QUESTESEN	2008-10-07 00:00:00	2010-12-06 00:00:00	NON	2	ANCIEN	\N	\N	\N	\N	95052H	NON	\N	\N
1800	AUCUNSEN	2008-10-07 00:00:00	2017-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	92039X	NON	\N	2017-09-24 13:47:46
1830	QUESTESEN	1989-05-16 00:00:00	1989-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	59521M	NON	\N	\N
1833	AUCUNSEN	2009-07-24 00:00:00	2012-06-16 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	09010Q	NON	\N	\N
1834	AUCUNSEN	2009-07-24 00:00:00	2012-06-16 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	09011R	NON	\N	\N
1835	AUCUNSEN	2009-07-29 00:00:00	2016-12-31 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	07024N	NON	\N	2017-01-03 11:09:24
1836	AUCUNSEN	1986-10-02 00:00:00	1989-10-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	86044G	NON	\N	\N
1837	AUCUNSEN	\N	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	09012S	NON	\N	2014-09-28 13:09:05
1842	AUCUNSEN	2010-01-08 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	10001F	NON	\N	\N
1847	AUCUNSEN	\N	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	10003H	NON	\N	2014-09-28 17:38:26
1844	AUCUNSEN	2010-03-07 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98009S	NON	\N	\N
1845	AUCUNSEN	2010-03-07 00:00:00	2013-06-27 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	95045J	NON	\N	\N
1849	AUCUNSEN	1986-10-02 00:00:00	1993-04-29 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	77029G	NON	\N	\N
1850	AUCUNSEN	1981-10-02 00:00:00	1986-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	77029G	NON	\N	\N
1851	AUCUNSEN	1995-10-02 00:00:00	2001-10-02 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	77029G	NON	\N	\N
1852	AUCUNSEN	1977-10-02 00:00:00	1978-05-05 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	77029G	NON	\N	\N
1853	AUCUNSEN	2010-10-12 00:00:00	2017-10-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	10006L	NON	\N	2017-10-04 14:47:28
1858	QUESTESEN	2010-12-07 00:00:00	2011-10-04 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95052H	NON	\N	\N
1859	QUESTESEN	2010-12-07 00:00:00	2011-10-04 00:00:00	NON	2	ANCIEN	\N	\N	\N	\N	98041S	NON	\N	\N
1863	AUCUNSEN	2010-12-15 00:00:00	\N	NON	\N	ACTIF	\N	\N	\N	\N	10015M	NON	\N	\N
1866	VICPDTSEN	2011-03-29 00:00:00	2011-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	95059Q	NON	\N	\N
1646	AUCUNSEN	2007-06-18 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04099V	NON	\N	2014-09-28 16:59:41
1660	AUCUNSEN	2007-10-01 00:00:00	2008-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	86034E	NON	\N	\N
1661	AUCUNSEN	1986-10-02 00:00:00	1989-10-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	86034E	NON	\N	\N
1662	AUCUNSEN	1995-10-05 00:00:00	1997-01-14 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	86034E	NON	\N	\N
1673	AUCUNSEN	2008-10-01 00:00:00	\N	NON	\N	ACTIF	\N	\N	\N	\N	08009T	NON	\N	\N
1675	AUCUNSEN	2008-10-01 00:00:00	\N	NON	\N	ACTIF	\N	\N	\N	\N	08011M	NON	\N	\N
1677	AUCUNSEN	2008-10-01 00:00:00	2010-03-15 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08013P	NON	\N	\N
1678	AUCUNSEN	2008-10-01 00:00:00	2020-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08014Q	NON	\N	\N
1683	AUCUNSEN	2008-10-01 00:00:00	\N	NON	\N	ACTIF	\N	\N	\N	\N	08018U	NON	\N	\N
1685	AUCUNSEN	2008-10-01 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08020N	NON	\N	2014-09-28 17:03:42
1686	AUCUNSEN	2008-10-01 00:00:00	2019-06-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08021P	NON	\N	\N
1689	AUCUNSEN	2008-10-01 00:00:00	2013-12-31 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08023R	NON	\N	\N
1704	AUCUNSEN	2008-10-01 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08027V	NON	\N	2014-09-28 17:34:16
1745	AUCUNSEN	2008-10-01 00:00:00	2020-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08043V	NON	\N	\N
1732	AUCUNSEN	2008-10-01 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08032S	NON	\N	2014-09-28 17:34:16
1734	AUCUNSEN	2008-10-01 00:00:00	2017-10-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08034U	NON	\N	2017-10-04 14:49:14
1737	AUCUNSEN	2008-10-01 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08037X	NON	\N	2014-09-28 17:34:16
1747	AUCUNSEN	2008-10-01 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08045X	NON	\N	2014-09-28 17:00:59
1749	AUCUNSEN	2008-10-01 00:00:00	\N	NON	\N	ACTIF	\N	\N	\N	\N	08047A	NON	\N	\N
1751	AUCUNSEN	2008-10-01 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08049C	NON	\N	2014-09-28 19:07:43
1755	AUCUNSEN	2008-10-01 00:00:00	2017-06-17 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08051V	NON	\N	2017-06-19 12:20:59
1759	AUCUNSEN	2008-10-01 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08054Y	NON	\N	2014-09-28 12:39:09
1767	AUCUNSEN	2008-10-01 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08057C	NON	\N	2014-09-28 14:31:42
1773	AUCUNSEN	2008-10-01 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08063A	NON	\N	2014-09-28 17:07:07
1775	AUCUNSEN	2008-10-01 00:00:00	2017-09-24 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08065C	NON	\N	2017-09-25 09:57:52
1777	AUCUNSEN	2008-10-01 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08067E	NON	\N	2014-09-28 17:22:11
1856	AUCUNSEN	2010-11-26 00:00:00	2010-12-14 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	92005M	NON	\N	\N
1860	AUCUNSEN	2010-12-14 00:00:00	2014-10-07 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01043Q	NON	\N	2014-10-08 14:55:52
1861	AUCUNSEN	2010-12-14 00:00:00	2020-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04040A	NON	\N	\N
1855	AUCUNSEN	2010-11-03 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	10007M	NON	\N	\N
1862	AUCUNSEN	2010-12-14 00:00:00	2011-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	95031C	NON	\N	\N
1629	AUCUNSEN	2005-09-19 00:00:00	2011-03-28 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	95059Q	NON	\N	\N
1867	AUCUNSEN	2011-03-29 00:00:00	2014-10-07 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	89029V	NON	\N	2014-10-08 14:48:10
1658	AUCUNSEN	2007-09-19 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	97005J	NON	\N	\N
1819	VICPDTSEN	2008-11-12 00:00:00	2011-10-04 00:00:00	NON	7	ANCIEN	\N	\N	\N	\N	98042T	NON	\N	\N
1820	VICPDTSEN	2008-11-12 00:00:00	2011-10-04 00:00:00	NON	8	ANCIEN	\N	\N	\N	\N	95032D	NON	\N	\N
1865	AUCUNSEN	2011-03-28 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	11003M	NON	\N	\N
2532	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20022R	\N	\N	\N
1664	AUCUNSEN	2007-11-22 00:00:00	2016-11-17 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	07032N	NON	\N	2016-11-18 12:37:49
1672	AUCUNSEN	2008-09-08 00:00:00	2008-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08008S	NON	\N	\N
373	AUCUNSEN	1998-10-03 00:00:00	2011-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98053W	NON	\N	\N
1848	AUCUNSEN	2010-04-17 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	10005K	NON	\N	\N
1644	AUCUNSEN	2007-01-26 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	07003H	NON	\N	2014-09-28 12:21:28
1645	AUCUNSEN	2007-02-26 00:00:00	2023-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	07004J	NON	\N	\N
1801	AUCUNSEN	2008-10-07 00:00:00	2012-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01051Q	NON	\N	\N
1802	AUCUNSEN	2008-10-07 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	95013A	NON	\N	\N
1803	AUCUNSEN	2008-10-07 00:00:00	2017-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	90003B	NON	\N	2017-10-01 10:01:39
1804	AUCUNSEN	2008-10-07 00:00:00	2020-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	88008L	NON	\N	\N
1805	AUCUNSEN	2008-10-07 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	95021A	NON	\N	2014-09-28 16:40:50
1806	SECRETSEN	2008-10-07 00:00:00	2011-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	92018S	NON	\N	\N
1807	SECRETSEN	2008-10-07 00:00:00	2008-11-11 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98042T	NON	\N	\N
1808	AUCUNSEN	2008-10-07 00:00:00	2010-01-07 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	86039K	NON	\N	\N
1809	AUCUNSEN	2008-10-07 00:00:00	2020-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98035U	NON	\N	\N
1810	SECRETSEN	2008-10-07 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	92008Q	NON	\N	\N
1811	SECRETSEN	2008-10-07 00:00:00	2011-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04046G	NON	\N	\N
1812	SECRETSEN	2008-10-07 00:00:00	2011-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	87003B	NON	\N	\N
1813	SECRETSEN	2008-10-07 00:00:00	2011-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01003G	NON	\N	\N
1814	SECRETSEN	2008-10-07 00:00:00	2011-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98022P	NON	\N	\N
1815	SECRETSEN	2008-10-07 00:00:00	2011-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	95003X	NON	\N	\N
1816	SECRETSEN	2008-10-07 00:00:00	2011-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	92040Q	NON	\N	\N
1817	SECRETSEN	2008-10-07 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01009N	NON	\N	\N
1818	SECRETSEN	2008-10-07 00:00:00	2011-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01019Q	NON	\N	\N
1864	AUCUNSEN	\N	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	11001K	NON	\N	\N
1671	AUCUNSEN	2008-04-19 00:00:00	2010-12-13 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08007R	NON	\N	\N
1757	AUCUNSEN	2008-10-01 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	02053W	NON	\N	2014-09-28 12:32:23
1821	SECRETSEN	2008-11-12 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01010F	NON	\N	\N
1822	SECRETSEN	2008-11-12 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01045S	NON	\N	\N
1823	SECRETSEN	2008-11-12 00:00:00	2011-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01011G	NON	\N	\N
1824	SECRETSEN	2008-11-12 00:00:00	2011-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01016M	NON	\N	\N
1857	QUESTESEN	2010-12-07 00:00:00	2014-09-30 00:00:00	NON	2	ANCIEN	\N	\N	\N	\N	98024R	NON	\N	2014-10-08 14:42:27
1078	AUCUNSEN	\N	1992-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000528	NON	\N	\N
1079	AUCUNSEN	\N	1962-07-04 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000024	NON	\N	\N
1080	AUCUNSEN	\N	1992-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000126	NON	\N	\N
1082	AUCUNSEN	\N	1980-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000352	NON	\N	\N
1083	AUCUNSEN	\N	1972-05-08 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000166	NON	\N	\N
1084	AUCUNSEN	\N	1963-11-21 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000428	NON	\N	\N
1085	AUCUNSEN	\N	1986-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58636T	NON	\N	\N
1086	AUCUNSEN	\N	1992-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59240F	NON	\N	\N
1088	AUCUNSEN	\N	1977-01-10 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000019	NON	\N	\N
1089	AUCUNSEN	\N	1994-02-19 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000419	NON	\N	\N
1090	AUCUNSEN	\N	1980-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000437	NON	\N	\N
1091	AUCUNSEN	\N	1962-07-04 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000026	NON	\N	\N
1092	AUCUNSEN	\N	1989-05-18 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000488	NON	\N	\N
1093	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000254	NON	\N	\N
1095	AUCUNSEN	\N	1981-02-19 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000412	NON	\N	\N
1096	AUCUNSEN	\N	1998-04-05 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	71031Y	NON	\N	\N
1097	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	57761T	NON	\N	\N
1098	AUCUNSEN	\N	1986-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000521	NON	\N	\N
1099	AUCUNSEN	\N	1979-12-07 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000109	NON	\N	\N
1100	AUCUNSEN	\N	1971-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000182	NON	\N	\N
1102	AUCUNSEN	\N	1962-07-04 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000090	NON	\N	\N
1103	AUCUNSEN	\N	1973-06-26 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000048	NON	\N	\N
1104	AUCUNSEN	\N	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59553V	NON	\N	\N
1105	AUCUNSEN	\N	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59579G	NON	\N	\N
1106	AUCUNSEN	\N	1974-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000008	NON	\N	\N
1107	AUCUNSEN	\N	1980-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000208	NON	\N	\N
1109	AUCUNSEN	\N	1974-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000161	NON	\N	\N
1110	AUCUNSEN	\N	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59580Y	NON	\N	\N
1111	AUCUNSEN	\N	1983-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58335H	NON	\N	\N
1112	AUCUNSEN	\N	1978-10-05 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000643	NON	\N	\N
1470	SECRETSEN	1989-10-04 00:00:00	1995-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	86044G	NON	\N	\N
1471	VICPDTSEN	1995-10-04 00:00:00	1995-11-16 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	86044G	NON	\N	\N
1472	SECRETSEN	1992-10-07 00:00:00	1993-10-05 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	89042S	NON	\N	\N
1473	AUCUNSEN	1968-10-02 00:00:00	1992-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	68036E	NON	\N	\N
1474	AUCUNSEN	1959-04-28 00:00:00	1964-10-06 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000039	NON	\N	\N
1476	AUCUNSEN	1946-12-08 00:00:00	1959-05-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000722	NON	\N	\N
1478	AUCUNSEN	1948-11-07 00:00:00	1959-05-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000323	NON	\N	\N
1479	AUCUNSEN	1952-05-18 00:00:00	1959-05-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000022	NON	\N	\N
1480	AUCUNSEN	1946-12-19 00:00:00	1959-05-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000705	NON	\N	\N
1481	AUCUNSEN	1959-04-28 00:00:00	1960-10-05 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000691	NON	\N	\N
1482	AUCUNSEN	1951-07-19 00:00:00	1959-05-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000187	NON	\N	\N
1483	AUCUNSEN	1952-05-18 00:00:00	1959-05-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000688	NON	\N	\N
1484	AUCUNSEN	1955-06-19 00:00:00	1959-05-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000672	NON	\N	\N
1485	AUCUNSEN	1971-10-06 00:00:00	1983-03-28 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000041	NON	\N	\N
1486	AUCUNSEN	1977-03-05 00:00:00	1977-03-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000067	NON	\N	\N
1487	AUCUNSEN	1946-12-08 00:00:00	1968-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000211	NON	\N	\N
1488	AUCUNSEN	1992-10-03 00:00:00	1995-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000211	NON	\N	\N
1489	AUCUNSEN	\N	2004-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04016A	NON	\N	\N
1490	AUCUNSEN	2004-05-01 00:00:00	2005-06-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04017B	NON	\N	\N
1491	AUCUNSEN	\N	2004-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04018C	NON	\N	\N
1492	SECRETSEN	2004-05-18 00:00:00	2008-10-06 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01054T	NON	\N	\N
214	AUCUNSEN	\N	2004-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	91002E	NON	\N	\N
240	AUCUNSEN	\N	2004-07-19 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95066P	NON	\N	\N
251	SECRETSEN	2001-10-03 00:00:00	2004-09-30 00:00:00	NON	6	ANCIEN	\N	\N	\N	\N	77017C	NON	\N	\N
280	AUCUNSEN	\N	2004-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	87002A	NON	\N	\N
1494	AUCUNSEN	2004-10-01 00:00:00	\N	NON	\N	ACTIF	\N	\N	\N	\N	04033B	NON	\N	\N
1495	AUCUNSEN	2004-10-01 00:00:00	2004-11-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	95059Q	NON	\N	\N
1496	AUCUNSEN	2004-09-26 00:00:00	2010-10-18 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	92029V	NON	\N	\N
1497	AUCUNSEN	2004-10-01 00:00:00	2004-11-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	02009S	NON	\N	\N
1498	AUCUNSEN	2004-10-01 00:00:00	2021-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04034C	NON	\N	\N
1502	AUCUNSEN	\N	2023-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04035D	NON	\N	\N
1503	AUCUNSEN	2004-10-01 00:00:00	2017-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04036E	NON	\N	2017-09-24 18:59:59
1504	AUCUNSEN	2004-10-01 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04037F	NON	\N	\N
1506	AUCUNSEN	2004-10-01 00:00:00	2020-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04038G	NON	\N	\N
1507	AUCUNSEN	2004-10-01 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04039H	NON	\N	\N
1508	AUCUNSEN	2004-10-01 00:00:00	2007-07-19 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04040A	NON	\N	\N
1511	AUCUNSEN	\N	2017-09-22 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04041B	NON	\N	2017-09-24 11:09:53
1512	AUCUNSEN	\N	2014-10-07 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04042C	NON	\N	2014-10-08 14:53:35
1514	AUCUNSEN	2011-10-01 00:00:00	2011-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04043D	NON	\N	\N
1515	AUCUNSEN	\N	2017-10-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04044E	NON	\N	2017-10-04 15:16:50
1516	AUCUNSEN	2004-10-01 00:00:00	2019-03-31 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04045F	NON	\N	\N
1517	AUCUNSEN	2004-10-01 00:00:00	2008-04-18 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	95031C	NON	\N	\N
1520	AUCUNSEN	2004-10-01 00:00:00	2008-10-06 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04046G	NON	\N	\N
1521	AUCUNSEN	\N	\N	NON	\N	ACTIF	\N	\N	\N	\N	04047H	NON	\N	\N
1523	AUCUNSEN	2004-10-01 00:00:00	2016-11-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04048J	NON	\N	2016-12-01 10:36:51
1524	AUCUNSEN	2004-10-01 00:00:00	2020-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04049K	NON	\N	\N
1525	AUCUNSEN	2004-10-01 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04050C	NON	\N	\N
1526	AUCUNSEN	2004-10-01 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04051D	NON	\N	2014-09-28 17:07:41
1527	AUCUNSEN	2004-10-01 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04052E	NON	\N	\N
1528	AUCUNSEN	2004-10-01 00:00:00	2012-06-16 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04053F	NON	\N	\N
1530	AUCUNSEN	2004-10-01 00:00:00	2017-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04054G	NON	\N	2017-09-24 17:18:03
1531	AUCUNSEN	2004-10-01 00:00:00	2017-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04055H	NON	\N	2017-09-24 18:05:41
1532	AUCUNSEN	2004-10-01 00:00:00	2008-10-06 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04056J	NON	\N	\N
1533	AUCUNSEN	\N	2014-10-07 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04057K	NON	\N	2014-10-08 14:56:08
1534	AUCUNSEN	\N	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04058L	NON	\N	\N
1535	AUCUNSEN	\N	2017-10-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04059M	NON	\N	2017-10-04 15:15:30
1536	AUCUNSEN	2004-10-01 00:00:00	2007-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04060E	NON	\N	\N
1537	AUCUNSEN	2004-10-01 00:00:00	2004-11-26 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04061F	NON	\N	\N
1538	AUCUNSEN	\N	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04062G	NON	\N	\N
1539	AUCUNSEN	\N	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04063H	NON	\N	\N
1541	AUCUNSEN	\N	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04064J	NON	\N	\N
1542	AUCUNSEN	2004-10-01 00:00:00	2004-11-26 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04065K	NON	\N	\N
1543	AUCUNSEN	2004-10-01 00:00:00	2014-10-07 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04066L	NON	\N	2014-10-08 14:50:17
1544	AUCUNSEN	2004-10-01 00:00:00	2011-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04067M	NON	\N	\N
1545	AUCUNSEN	2004-10-01 00:00:00	2007-06-28 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04068N	NON	\N	\N
1546	AUCUNSEN	2004-10-01 00:00:00	2004-10-05 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	86039K	NON	\N	\N
1547	AUCUNSEN	2004-10-01 00:00:00	2004-11-26 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04069P	NON	\N	\N
1548	AUCUNSEN	\N	\N	NON	\N	ACTIF	\N	\N	\N	\N	04070G	NON	\N	\N
1549	AUCUNSEN	2004-10-01 00:00:00	2023-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04071H	NON	\N	\N
1550	AUCUNSEN	\N	2007-11-29 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04072J	NON	\N	\N
1552	AUCUNSEN	2004-10-01 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04073K	NON	\N	2014-09-28 18:58:25
1551	AUCUNSEN	2004-10-01 00:00:00	2004-11-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	95051G	NON	\N	\N
1553	AUCUNSEN	\N	2017-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04074L	NON	\N	2017-09-24 17:15:15
1554	AUCUNSEN	\N	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04075M	NON	\N	\N
1555	AUCUNSEN	2004-10-01 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04076N	NON	\N	\N
1556	AUCUNSEN	2004-10-01 00:00:00	2011-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04077P	NON	\N	\N
1557	AUCUNSEN	2004-10-01 00:00:00	2017-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04078Q	NON	\N	2017-09-24 17:15:15
1559	AUCUNSEN	2004-10-01 00:00:00	2017-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04079R	NON	\N	2017-09-24 17:47:27
1558	AUCUNSEN	2004-10-01 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	77053G	NON	\N	\N
1560	AUCUNSEN	2004-10-01 00:00:00	2017-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04080J	NON	\N	2017-09-24 17:47:27
1561	AUCUNSEN	2004-10-01 00:00:00	2014-10-07 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04081K	NON	\N	2014-10-08 14:50:07
1562	AUCUNSEN	2004-10-01 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04082L	NON	\N	\N
1563	AUCUNSEN	2004-10-01 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04083M	NON	\N	2014-09-28 16:40:50
1564	AUCUNSEN	2004-10-01 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04084N	NON	\N	2014-09-28 13:40:33
1565	AUCUNSEN	\N	2023-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04085P	NON	\N	\N
1566	AUCUNSEN	2004-10-01 00:00:00	2017-10-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04086Q	NON	\N	2017-10-04 15:15:11
1567	AUCUNSEN	2004-10-01 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04087R	NON	\N	2014-09-28 13:39:21
1568	AUCUNSEN	2004-10-01 00:00:00	2014-10-07 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04088S	NON	\N	2014-10-08 14:56:52
988	AUCUNSEN	\N	1974-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000042	NON	\N	\N
989	AUCUNSEN	\N	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59542S	NON	\N	\N
990	AUCUNSEN	\N	1989-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58948H	NON	\N	\N
991	AUCUNSEN	\N	1972-12-05 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000093	NON	\N	\N
992	AUCUNSEN	\N	1986-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58626R	NON	\N	\N
994	AUCUNSEN	\N	1983-01-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000170	NON	\N	\N
995	AUCUNSEN	\N	1981-07-23 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58652T	NON	\N	\N
996	SECRETSEN	1967-10-11 00:00:00	1968-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000014	NON	\N	\N
997	AUCUNSEN	\N	1993-02-22 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000442	NON	\N	\N
998	AUCUNSEN	\N	1989-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58941A	NON	\N	\N
1000	AUCUNSEN	\N	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59543T	NON	\N	\N
1001	AUCUNSEN	\N	1986-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000280	NON	\N	\N
1002	AUCUNSEN	\N	1989-01-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000201	NON	\N	\N
1003	AUCUNSEN	\N	1992-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000531	NON	\N	\N
1004	AUCUNSEN	\N	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000206	NON	\N	\N
1006	SECRETSEN	1971-10-05 00:00:00	1974-10-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000320	NON	\N	\N
1007	AUCUNSEN	\N	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59545V	NON	\N	\N
1008	AUCUNSEN	\N	1978-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	57830P	NON	\N	\N
1009	AUCUNSEN	\N	1971-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	57130R	NON	\N	\N
1010	AUCUNSEN	\N	1997-06-12 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	89033R	NON	\N	\N
1011	AUCUNSEN	\N	1974-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000005	NON	\N	\N
1013	AUCUNSEN	\N	1969-03-20 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000017	NON	\N	\N
1014	AUCUNSEN	\N	1990-08-11 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000351	NON	\N	\N
1015	AUCUNSEN	\N	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59547X	NON	\N	\N
1016	AUCUNSEN	\N	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59548Y	NON	\N	\N
1017	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000004	NON	\N	\N
1019	AUCUNSEN	\N	1982-08-15 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000633	NON	\N	\N
1020	AUCUNSEN	\N	1974-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000223	NON	\N	\N
1021	AUCUNSEN	\N	1973-11-16 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000518	NON	\N	\N
1022	AUCUNSEN	\N	1983-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000059	NON	\N	\N
1023	SECRETSEN	1973-04-02 00:00:00	1977-10-05 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58947G	NON	\N	\N
1024	AUCUNSEN	\N	1981-06-21 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59715V	NON	\N	\N
1026	AUCUNSEN	\N	1980-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000236	NON	\N	\N
1027	AUCUNSEN	\N	1962-05-15 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000498	NON	\N	\N
1028	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000227	NON	\N	\N
1029	AUCUNSEN	\N	1993-11-07 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000561	NON	\N	\N
1030	AUCUNSEN	\N	1992-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59235J	NON	\N	\N
1032	AUCUNSEN	\N	1986-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58621L	NON	\N	\N
1033	SECRETSEN	1976-12-14 00:00:00	1977-10-05 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000136	NON	\N	\N
1034	AUCUNSEN	\N	1971-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000332	NON	\N	\N
1035	AUCUNSEN	\N	1989-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58939G	NON	\N	\N
1036	AUCUNSEN	\N	1968-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000080	NON	\N	\N
1037	AUCUNSEN	\N	1974-05-22 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000314	NON	\N	\N
1040	AUCUNSEN	\N	1989-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000502	NON	\N	\N
1041	AUCUNSEN	\N	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59550S	NON	\N	\N
1042	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000179	NON	\N	\N
1043	AUCUNSEN	\N	1970-08-19 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000233	NON	\N	\N
1047	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000050	NON	\N	\N
1048	AUCUNSEN	\N	1979-06-05 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000129	NON	\N	\N
1050	AUCUNSEN	\N	1980-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000102	NON	\N	\N
1051	VICPDTSEN	\N	1959-05-28 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000025	NON	\N	\N
1052	AUCUNSEN	\N	1986-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58635S	NON	\N	\N
1053	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000356	NON	\N	\N
1054	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58003P	NON	\N	\N
1056	AUCUNSEN	\N	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59551T	NON	\N	\N
1057	AUCUNSEN	\N	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59552U	NON	\N	\N
1058	AUCUNSEN	\N	1981-08-29 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000103	NON	\N	\N
1059	AUCUNSEN	\N	1962-12-13 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000379	NON	\N	\N
1060	SECRETSEN	1986-10-07 00:00:00	1989-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	58914W	NON	\N	\N
1061	AUCUNSEN	\N	1962-07-04 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000034	NON	\N	\N
1063	AUCUNSEN	\N	1977-10-05 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000033	NON	\N	\N
1064	AUCUNSEN	\N	1992-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59236K	NON	\N	\N
1065	AUCUNSEN	\N	1962-07-04 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000132	NON	\N	\N
1066	AUCUNSEN	\N	1971-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	57135W	NON	\N	\N
1067	AUCUNSEN	\N	1974-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000209	NON	\N	\N
1069	AUCUNSEN	\N	1980-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58026W	NON	\N	\N
1070	AUCUNSEN	\N	1995-07-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000597	NON	\N	\N
1071	AUCUNSEN	\N	1983-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000100	NON	\N	\N
1072	AUCUNSEN	\N	1962-07-04 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000284	NON	\N	\N
1073	AUCUNSEN	\N	1983-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000027	NON	\N	\N
1074	QUESTESEN	1989-10-04 00:00:00	1992-10-07 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000586	NON	\N	\N
2533	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20024T	\N	\N	\N
1076	AUCUNSEN	\N	1965-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000242	NON	\N	\N
1077	AUCUNSEN	\N	1992-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59237L	NON	\N	\N
501	AUCUNSEN	\N	2004-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01004H	NON	\N	\N
110	AUCUNSEN	\N	2001-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	83020K	NON	\N	\N
132	AUCUNSEN	\N	2001-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	74028S	NON	\N	\N
144	SECRETSEN	1998-10-06 00:00:00	2001-09-30 00:00:00	NON	6	ANCIEN	\N	\N	\N	\N	83040P	NON	\N	\N
171	AUCUNSEN	\N	2001-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	92023P	NON	\N	\N
504	AUCUNSEN	2001-10-01 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01005J	NON	\N	\N
505	AUCUNSEN	2001-10-01 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01006K	NON	\N	\N
506	AUCUNSEN	2001-10-01 00:00:00	2014-10-07 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01007L	NON	\N	2014-10-08 14:49:40
507	AUCUNSEN	2001-10-01 00:00:00	2017-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01008M	NON	\N	2017-09-24 13:44:49
508	AUCUNSEN	2001-10-01 00:00:00	2008-10-06 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01009N	NON	\N	\N
509	AUCUNSEN	2001-10-01 00:00:00	2008-11-11 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01010F	NON	\N	\N
510	AUCUNSEN	2001-10-01 00:00:00	2008-11-11 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01011G	NON	\N	\N
511	AUCUNSEN	2001-10-01 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01012H	NON	\N	\N
512	AUCUNSEN	2001-10-01 00:00:00	2017-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01013J	NON	\N	2017-09-24 17:06:55
513	AUCUNSEN	2001-10-01 00:00:00	2017-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01014K	NON	\N	2017-09-24 17:19:42
514	AUCUNSEN	2001-10-01 00:00:00	2017-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01015L	NON	\N	2017-09-24 17:19:42
515	AUCUNSEN	2001-10-01 00:00:00	2008-11-11 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01016M	NON	\N	\N
516	AUCUNSEN	2001-10-01 00:00:00	2010-10-11 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01017N	NON	\N	\N
517	AUCUNSEN	2001-10-01 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01018P	NON	\N	\N
518	AUCUNSEN	2001-10-01 00:00:00	2008-10-06 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01019Q	NON	\N	\N
519	AUCUNSEN	2001-10-01 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01020H	NON	\N	\N
520	AUCUNSEN	2001-10-01 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01021J	NON	\N	\N
521	AUCUNSEN	2001-10-01 00:00:00	2011-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01022K	NON	\N	\N
522	AUCUNSEN	2001-10-01 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01023L	NON	\N	\N
523	AUCUNSEN	2001-10-01 00:00:00	2023-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01024M	NON	\N	\N
524	AUCUNSEN	2001-10-01 00:00:00	2020-10-05 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01025N	NON	\N	\N
525	AUCUNSEN	2001-10-01 00:00:00	2010-11-02 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01026P	NON	\N	\N
526	AUCUNSEN	2001-10-01 00:00:00	2017-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01027Q	NON	\N	2017-09-24 17:28:55
527	AUCUNSEN	2001-10-01 00:00:00	2020-10-05 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01028R	NON	\N	\N
528	AUCUNSEN	2001-10-01 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01029S	NON	\N	\N
529	AUCUNSEN	2001-10-01 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01030K	NON	\N	\N
530	AUCUNSEN	2001-10-01 00:00:00	2004-10-05 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01031L	NON	\N	\N
531	AUCUNSEN	2001-10-01 00:00:00	2006-05-16 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01032M	NON	\N	\N
532	AUCUNSEN	2001-10-01 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01033N	NON	\N	\N
533	AUCUNSEN	2001-10-01 00:00:00	2023-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01034P	NON	\N	\N
534	AUCUNSEN	2001-10-01 00:00:00	2007-01-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01035Q	NON	\N	\N
535	AUCUNSEN	2001-10-01 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01036R	NON	\N	\N
536	AUCUNSEN	2001-10-01 00:00:00	2016-12-10 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01037S	NON	\N	2016-12-12 16:10:15
537	AUCUNSEN	2001-10-01 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01038T	NON	\N	\N
538	AUCUNSEN	2001-10-01 00:00:00	2010-04-16 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01039U	NON	\N	\N
539	AUCUNSEN	2001-10-01 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01040M	NON	\N	\N
540	AUCUNSEN	2001-10-01 00:00:00	2017-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01041N	NON	\N	2017-09-24 18:59:59
167	AUCUNSEN	\N	2001-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	97006K	NON	\N	\N
541	AUCUNSEN	2001-10-01 00:00:00	2015-04-21 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01042P	NON	\N	2015-04-21 17:14:30
542	AUCUNSEN	2001-10-01 00:00:00	2007-07-19 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01043Q	NON	\N	\N
543	SECRETSEN	2004-10-06 00:00:00	2008-10-06 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	92018S	NON	\N	\N
544	AUCUNSEN	2001-10-01 00:00:00	2017-07-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01044R	NON	\N	2017-07-04 15:08:09
545	AUCUNSEN	2001-10-01 00:00:00	2008-11-11 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01045S	NON	\N	\N
546	AUCUNSEN	2001-10-01 00:00:00	2017-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01046T	NON	\N	2017-09-24 13:44:49
547	AUCUNSEN	2001-10-01 00:00:00	2017-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01047U	NON	\N	2017-09-24 13:29:42
548	AUCUNSEN	2001-10-01 00:00:00	2011-03-27 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01048V	NON	\N	\N
549	AUCUNSEN	2001-10-01 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01049W	NON	\N	\N
550	AUCUNSEN	2001-10-01 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01050P	NON	\N	\N
551	AUCUNSEN	2001-10-01 00:00:00	2004-10-05 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01051Q	NON	\N	\N
552	AUCUNSEN	2001-10-01 00:00:00	2011-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01052R	NON	\N	\N
553	AUCUNSEN	2001-10-01 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01053S	NON	\N	\N
554	AUCUNSEN	2001-10-01 00:00:00	2004-05-17 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01054T	NON	\N	\N
555	AUCUNSEN	2001-10-01 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01055U	NON	\N	\N
556	AUCUNSEN	2001-10-01 00:00:00	2017-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01056V	NON	\N	2017-09-24 17:04:02
557	AUCUNSEN	2001-10-01 00:00:00	2011-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01057W	NON	\N	\N
558	AUCUNSEN	2001-10-01 00:00:00	2023-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01058X	NON	\N	\N
559	AUCUNSEN	2001-10-01 00:00:00	2017-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01059Y	NON	\N	2017-09-24 17:35:15
560	AUCUNSEN	2001-10-01 00:00:00	2023-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01060R	NON	\N	\N
561	AUCUNSEN	2001-10-01 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	83042R	NON	\N	\N
562	AUCUNSEN	2001-10-01 00:00:00	2017-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01061S	NON	\N	2017-09-24 17:48:21
563	AUCUNSEN	2001-10-01 00:00:00	2011-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01062T	NON	\N	\N
564	VICPDTSEN	2001-10-03 00:00:00	2004-10-05 00:00:00	NON	2	ANCIEN	\N	\N	\N	\N	89029V	NON	\N	\N
224	VICPDTSEN	2001-10-03 00:00:00	2004-10-05 00:00:00	NON	6	ANCIEN	\N	\N	\N	\N	95032D	NON	\N	\N
565	QUESTESEN	2001-10-03 00:00:00	2004-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	77047J	NON	\N	\N
566	QUESTESEN	2001-10-03 00:00:00	2004-10-05 00:00:00	NON	2	ANCIEN	\N	\N	\N	\N	83031N	NON	\N	\N
567	QUESTESEN	2001-10-03 00:00:00	2004-09-30 00:00:00	NON	3	ANCIEN	\N	\N	\N	\N	81015E	NON	\N	\N
380	QUESTESEN	1998-10-06 00:00:00	2001-10-03 00:00:00	NON	3	ANCIEN	\N	\N	\N	\N	83012K	NON	\N	\N
568	SECRETSEN	2001-10-03 00:00:00	2008-10-06 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	88008L	NON	\N	\N
163	SECRETSEN	2001-10-03 00:00:00	2004-10-05 00:00:00	NON	10	ANCIEN	\N	\N	\N	\N	96007G	NON	\N	\N
569	SECRETSEN	2001-10-03 00:00:00	2004-09-30 00:00:00	NON	11	ANCIEN	\N	\N	\N	\N	92005M	NON	\N	\N
219	SECRETSEN	2000-01-19 00:00:00	2001-10-02 00:00:00	NON	12	ANCIEN	\N	\N	\N	\N	86047K	NON	\N	\N
570	SECRETSEN	2001-10-03 00:00:00	2004-09-30 00:00:00	NON	12	ANCIEN	\N	\N	\N	\N	86047K	NON	\N	\N
387	SECRETSEN	1998-10-06 00:00:00	2001-10-03 00:00:00	NON	10	ANCIEN	\N	\N	\N	\N	85002R	NON	\N	\N
571	AUCUNSEN	2001-10-04 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	83012K	NON	\N	\N
572	AUCUNSEN	2001-10-04 00:00:00	2004-10-05 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	90003B	NON	\N	\N
573	AUCUNSEN	2001-10-04 00:00:00	2014-04-24 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	89014N	NON	\N	\N
574	AUCUNSEN	2001-10-04 00:00:00	2008-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	89030N	NON	\N	\N
575	AUCUNSEN	2001-10-04 00:00:00	2004-10-06 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	92039X	NON	\N	\N
576	AUCUNSEN	2001-10-04 00:00:00	2008-10-06 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	92040Q	NON	\N	\N
577	AUCUNSEN	2001-10-04 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	96006F	NON	\N	2014-09-28 16:50:17
578	AUCUNSEN	2001-10-04 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	85002R	NON	\N	\N
579	AUCUNSEN	2001-10-03 00:00:00	2008-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	78003A	NON	\N	\N
580	AUCUNSEN	2001-10-03 00:00:00	2004-04-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	86034E	NON	\N	\N
581	AUCUNSEN	2001-10-03 00:00:00	2008-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	80046H	NON	\N	\N
582	AUCUNSEN	2001-10-10 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01063U	NON	\N	2014-09-29 15:49:34
583	AUCUNSEN	2001-10-01 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01064V	NON	\N	2014-09-28 17:12:41
584	AUCUNSEN	2001-10-01 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01065W	NON	\N	2014-09-28 12:09:44
585	AUCUNSEN	2002-01-20 00:00:00	2008-10-06 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	02001J	NON	\N	\N
586	PDTSEN	2001-10-01 00:00:00	2008-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	77058M	NON	\N	\N
587	AUCUNSEN	\N	2020-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	02002K	NON	\N	\N
345	AUCUNSEN	\N	2002-06-07 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98031Q	NON	\N	\N
588	AUCUNSEN	\N	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	02003L	NON	\N	\N
589	AUCUNSEN	2002-06-08 00:00:00	2004-06-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	02004M	NON	\N	\N
590	AUCUNSEN	2002-06-08 00:00:00	2008-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	02005N	NON	\N	\N
597	AUCUNSEN	\N	2004-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	02006P	NON	\N	\N
598	AUCUNSEN	1989-10-02 00:00:00	2004-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	77013X	NON	\N	\N
600	AUCUNSEN	\N	2002-12-19 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	02007Q	NON	\N	\N
601	AUCUNSEN	\N	2008-10-06 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	59312E	NON	\N	\N
229	SECRETSEN	2001-10-03 00:00:00	2002-12-04 00:00:00	NON	5	ANCIEN	\N	\N	\N	\N	95020Y	NON	\N	\N
602	AUCUNSEN	2002-12-05 00:00:00	2011-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	95020Y	NON	\N	\N
603	SECRETSEN	2002-12-06 00:00:00	2008-10-06 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	95013A	NON	\N	\N
604	AUCUNSEN	2002-12-11 00:00:00	2004-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	59569E	NON	\N	\N
619	AUCUNSEN	2003-02-09 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	03001N	NON	\N	2014-09-28 13:40:33
621	PDTSEN	1959-05-05 00:00:00	1968-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000677	NON	\N	\N
622	VICPDTSEN	1965-10-05 00:00:00	1968-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000116	NON	\N	\N
623	AUCUNSEN	1968-10-05 00:00:00	1971-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000722	NON	\N	\N
624	VICPDTSEN	1965-10-05 00:00:00	1972-12-10 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000131	NON	\N	\N
625	VICPDTSEN	1974-10-03 00:00:00	1977-03-04 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000067	NON	\N	\N
626	VICPDTSEN	1962-10-03 00:00:00	1965-10-05 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	58303Y	NON	\N	\N
627	AUCUNSEN	1980-10-08 00:00:00	1988-07-29 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000323	NON	\N	\N
628	AUCUNSEN	1962-10-05 00:00:00	1971-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000672	NON	\N	\N
629	VICPDTSEN	1971-10-05 00:00:00	1974-10-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000278	NON	\N	\N
630	VICPDTSEN	1971-10-05 00:00:00	1974-05-28 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000298	NON	\N	\N
1094	AUCUNSEN	\N	1985-05-13 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000393	NON	\N	\N
1101	AUCUNSEN	\N	1965-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000112	NON	\N	\N
1108	AUCUNSEN	\N	1986-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58628T	NON	\N	\N
1114	AUCUNSEN	\N	1977-12-20 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000434	NON	\N	\N
1122	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000052	NON	\N	\N
1129	AUCUNSEN	\N	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59556Y	NON	\N	\N
1133	AUCUNSEN	\N	1971-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000156	NON	\N	\N
1139	AUCUNSEN	\N	1980-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000275	NON	\N	\N
1146	AUCUNSEN	\N	1989-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58926B	NON	\N	\N
1152	AUCUNSEN	\N	1967-05-16 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	57310T	NON	\N	\N
1159	AUCUNSEN	\N	1962-09-23 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000281	NON	\N	\N
1165	SECRETSEN	1963-10-03 00:00:00	1964-10-07 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000128	NON	\N	\N
1171	AUCUNSEN	\N	1997-10-14 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95065N	NON	\N	\N
1178	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	57752S	NON	\N	\N
1184	AUCUNSEN	\N	1960-05-09 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000147	NON	\N	\N
1191	AUCUNSEN	\N	1989-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000369	NON	\N	\N
1197	AUCUNSEN	\N	1992-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59247N	NON	\N	\N
1205	AUCUNSEN	\N	1984-03-20 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000592	NON	\N	\N
1212	AUCUNSEN	\N	1984-03-06 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000312	NON	\N	\N
1216	AUCUNSEN	\N	1983-05-05 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000417	NON	\N	\N
1222	AUCUNSEN	\N	1988-05-10 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58808V	NON	\N	\N
1229	AUCUNSEN	\N	1974-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000078	NON	\N	\N
1235	AUCUNSEN	\N	1975-07-21 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000283	NON	\N	\N
1241	AUCUNSEN	\N	1992-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59253L	NON	\N	\N
1248	AUCUNSEN	\N	1986-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58655W	NON	\N	\N
1254	AUCUNSEN	\N	1983-05-10 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000376	NON	\N	\N
1261	AUCUNSEN	\N	1979-05-28 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000360	NON	\N	\N
1267	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000309	NON	\N	\N
1274	AUCUNSEN	\N	1974-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000088	NON	\N	\N
1280	AUCUNSEN	\N	1971-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000044	NON	\N	\N
1287	AUCUNSEN	\N	1965-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000703	NON	\N	\N
1295	AUCUNSEN	\N	1970-11-23 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000682	NON	\N	\N
1299	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000690	NON	\N	\N
1305	AUCUNSEN	\N	1968-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000715	NON	\N	\N
1312	AUCUNSEN	\N	1969-01-11 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000744	NON	\N	\N
1318	AUCUNSEN	\N	1962-07-04 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000699	NON	\N	\N
1325	AUCUNSEN	\N	1968-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000753	NON	\N	\N
1331	VICPDTSEN	\N	1964-08-07 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000737	NON	\N	\N
1337	AUCUNSEN	\N	1965-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000679	NON	\N	\N
1344	AUCUNSEN	\N	1968-09-22 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000746	NON	\N	\N
1350	AUCUNSEN	1962-10-04 00:00:00	1993-03-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000705	NON	\N	\N
1357	AUCUNSEN	\N	1974-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000714	NON	\N	\N
1363	AUCUNSEN	\N	1971-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000772	NON	\N	\N
1371	AUCUNSEN	\N	1966-04-24 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000768	NON	\N	\N
1378	AUCUNSEN	\N	1992-04-06 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000667	NON	\N	\N
1401	QUESTESEN	1986-10-07 00:00:00	1989-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	59219J	NON	\N	\N
1390	VICPDTSEN	1976-04-06 00:00:00	1977-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	57749X	NON	\N	\N
1391	SECRETSEN	1992-10-07 00:00:00	1995-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000586	NON	\N	\N
1393	QUESTESEN	1983-10-05 00:00:00	1989-05-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59559C	NON	\N	\N
1405	VICPDTSEN	1959-05-05 00:00:00	1962-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000672	NON	\N	\N
1395	VICPDTSEN	1977-10-05 00:00:00	1983-10-05 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	74044S	NON	\N	\N
1396	SECRETSEN	1959-05-05 00:00:00	1959-10-08 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000692	NON	\N	\N
1398	VICPDTSEN	1977-10-05 00:00:00	1980-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000399	NON	\N	\N
1399	SECRETSEN	1955-10-06 00:00:00	1955-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000022	NON	\N	\N
1406	VICPDTSEN	1959-05-05 00:00:00	1962-10-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000705	NON	\N	\N
1186	AUCUNSEN	\N	1995-09-24 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59581A	NON	\N	\N
1187	AUCUNSEN	\N	1989-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58933A	NON	\N	\N
1188	AUCUNSEN	\N	1992-02-23 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000440	NON	\N	\N
1189	AUCUNSEN	\N	1971-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000168	NON	\N	\N
1190	AUCUNSEN	\N	1974-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000101	NON	\N	\N
1192	AUCUNSEN	\N	1993-11-06 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000373	NON	\N	\N
1193	AUCUNSEN	\N	1980-11-18 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000364	NON	\N	\N
1194	AUCUNSEN	\N	1986-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000279	NON	\N	\N
1195	AUCUNSEN	\N	1989-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000452	NON	\N	\N
1196	AUCUNSEN	\N	1974-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000123	NON	\N	\N
1198	AUCUNSEN	\N	1980-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000334	NON	\N	\N
1199	AUCUNSEN	\N	1983-08-20 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000330	NON	\N	\N
1200	AUCUNSEN	\N	1983-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000287	NON	\N	\N
1201	AUCUNSEN	\N	1966-10-14 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000499	NON	\N	\N
1202	AUCUNSEN	\N	1971-08-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000120	NON	\N	\N
1203	AUCUNSEN	\N	1986-06-23 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000095	NON	\N	\N
1206	AUCUNSEN	\N	1975-04-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000302	NON	\N	\N
1207	AUCUNSEN	\N	1980-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58508L	NON	\N	\N
1208	AUCUNSEN	\N	1989-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58950B	NON	\N	\N
1209	AUCUNSEN	\N	1978-10-13 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000006	NON	\N	\N
1211	AUCUNSEN	\N	1968-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	56829S	NON	\N	\N
1213	AUCUNSEN	\N	1969-07-22 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000251	NON	\N	\N
1214	AUCUNSEN	\N	1981-09-09 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000268	NON	\N	\N
1215	AUCUNSEN	\N	1996-05-15 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	83001G	NON	\N	\N
1217	SECRETSEN	1960-10-06 00:00:00	1961-10-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000301	NON	\N	\N
1218	AUCUNSEN	\N	1980-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58036Y	NON	\N	\N
1219	AUCUNSEN	\N	1982-11-17 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000405	NON	\N	\N
1220	AUCUNSEN	\N	1992-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59249Q	NON	\N	\N
1221	AUCUNSEN	\N	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59561V	NON	\N	\N
1223	AUCUNSEN	\N	1968-10-24 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000094	NON	\N	\N
1224	SECRETSEN	1983-10-05 00:00:00	1989-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	59250H	NON	\N	\N
1225	AUCUNSEN	\N	1986-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	55510R	NON	\N	\N
1226	AUCUNSEN	\N	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59582B	NON	\N	\N
1227	AUCUNSEN	\N	1965-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000074	NON	\N	\N
1228	AUCUNSEN	\N	1983-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000377	NON	\N	\N
1230	AUCUNSEN	\N	1974-10-19 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000154	NON	\N	\N
1231	AUCUNSEN	\N	1980-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58048D	NON	\N	\N
1232	AUCUNSEN	\N	1980-10-03 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000354	NON	\N	\N
1233	AUCUNSEN	\N	1971-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000259	NON	\N	\N
1234	AUCUNSEN	\N	1971-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000055	NON	\N	\N
1236	AUCUNSEN	\N	1992-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59251J	NON	\N	\N
1237	SECRETSEN	1971-10-05 00:00:00	1992-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	59252K	NON	\N	\N
1238	AUCUNSEN	\N	1980-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000117	NON	\N	\N
1240	AUCUNSEN	\N	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59563X	NON	\N	\N
1242	AUCUNSEN	\N	1968-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000148	NON	\N	\N
1243	AUCUNSEN	\N	1981-06-21 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59308J	NON	\N	\N
1244	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000239	NON	\N	\N
1245	AUCUNSEN	\N	1986-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58647W	NON	\N	\N
1246	AUCUNSEN	\N	1962-07-04 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000029	NON	\N	\N
1247	AUCUNSEN	\N	1983-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58355M	NON	\N	\N
1249	AUCUNSEN	\N	1998-07-14 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	74041P	NON	\N	\N
1250	AUCUNSEN	\N	1980-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000099	NON	\N	\N
1251	AUCUNSEN	\N	1986-12-18 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000353	NON	\N	\N
1252	AUCUNSEN	\N	1986-07-16 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58613L	NON	\N	\N
1253	AUCUNSEN	\N	1960-10-23 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000054	NON	\N	\N
1255	AUCUNSEN	\N	1974-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000391	NON	\N	\N
1407	VICPDTSEN	1959-05-05 00:00:00	1980-10-07 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000323	NON	\N	\N
1408	VICPDTSEN	1959-05-05 00:00:00	1968-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000722	NON	\N	\N
1409	SECRETSEN	1959-05-05 00:00:00	1960-10-06 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000687	NON	\N	\N
1410	SECRETSEN	1959-05-05 00:00:00	1971-10-05 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000041	NON	\N	\N
1411	SECRETSEN	1959-05-05 00:00:00	1962-10-03 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000200	NON	\N	\N
1412	SECRETSEN	1959-05-05 00:00:00	1971-10-05 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000187	NON	\N	\N
1413	SECRETSEN	1959-05-05 00:00:00	1968-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000688	NON	\N	\N
1414	SECRETSEN	1961-10-03 00:00:00	1962-10-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000692	NON	\N	\N
1417	SECRETSEN	1959-05-05 00:00:00	1968-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000246	NON	\N	\N
1418	SECRETSEN	1959-05-05 00:00:00	1965-10-05 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000169	NON	\N	\N
1420	QUESTESEN	1959-05-05 00:00:00	1962-10-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000022	NON	\N	\N
1421	QUESTESEN	1959-05-05 00:00:00	1966-10-05 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	57445J	NON	\N	\N
1422	SECRETSEN	1959-10-08 00:00:00	1960-10-06 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000340	NON	\N	\N
1432	SECRETSEN	1963-10-03 00:00:00	1964-10-07 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000301	NON	\N	\N
1424	AUCUNSEN	1952-05-18 00:00:00	1959-05-04 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	000041	\N	\N	\N
1425	AUCUNSEN	1952-05-18 00:00:00	1959-05-04 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	000200	\N	\N	\N
1428	AUCUNSEN	1946-12-08 00:00:00	1959-05-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000246	NON	\N	\N
1429	AUCUNSEN	1948-11-07 00:00:00	1959-05-04 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	000169	\N	\N	\N
1430	AUCUNSEN	1948-11-19 00:00:00	1974-10-02 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000067	NON	\N	\N
1431	SECRETSEN	1960-10-06 00:00:00	1961-10-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000691	NON	\N	\N
1433	SECRETSEN	1964-10-07 00:00:00	1965-10-05 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000039	NON	\N	\N
1434	SECRETSEN	1964-10-07 00:00:00	1965-10-05 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000692	NON	\N	\N
1435	SECRETSEN	1965-10-05 00:00:00	1966-10-05 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000340	NON	\N	\N
1436	SECRETSEN	1965-10-05 00:00:00	1966-10-05 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000083	NON	\N	\N
1437	SECRETSEN	1966-10-05 00:00:00	1967-10-11 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000301	NON	\N	\N
1438	SECRETSEN	1967-10-11 00:00:00	1968-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000692	NON	\N	\N
1439	SECRETSEN	1968-10-04 00:00:00	1970-10-07 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000271	NON	\N	\N
1440	SECRETSEN	1974-10-03 00:00:00	1972-10-02 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	57728S	NON	\N	\N
1442	AUCUNSEN	\N	2008-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	03002P	NON	\N	\N
1446	AUCUNSEN	2003-11-05 00:00:00	2004-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	03003Q	NON	\N	\N
1447	SECRETSEN	1974-10-03 00:00:00	1977-10-05 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59215E	NON	\N	\N
1448	SECRETSEN	1977-10-05 00:00:00	1980-10-02 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000083	NON	\N	\N
1449	VICPDTSEN	1980-10-07 00:00:00	1992-10-07 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	59560U	NON	\N	\N
1450	SECRETSEN	1980-10-07 00:00:00	1983-10-05 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000320	NON	\N	\N
1451	VICPDTSEN	1983-10-05 00:00:00	1986-10-07 00:00:00	NON	3	ANCIEN	\N	\N	\N	\N	000326	NON	\N	\N
1239	SECRETSEN	1986-10-07 00:00:00	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59562W	NON	\N	\N
1452	SECRETSEN	1989-10-04 00:00:00	1992-10-07 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	83010H	NON	\N	\N
1453	SECRETSEN	1992-10-07 00:00:00	1998-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	77001T	NON	\N	\N
120	QUESTESEN	1989-10-04 00:00:00	1998-10-05 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	83046V	OUI	\N	\N
1454	AUCUNSEN	\N	2018-12-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	98023Q	NON	\N	\N
1456	AUCUNSEN	1995-10-05 00:00:00	2003-11-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	86031B	NON	\N	\N
1457	AUCUNSEN	1959-10-09 00:00:00	1961-10-02 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000692	NON	\N	\N
1460	AUCUNSEN	1965-10-06 00:00:00	1967-10-10 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000692	NON	\N	\N
1459	AUCUNSEN	1962-10-04 00:00:00	1964-10-06 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000692	NON	\N	\N
1461	AUCUNSEN	\N	2004-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	03004R	NON	\N	\N
1462	SECRETSEN	1992-10-07 00:00:00	1995-10-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	83012K	NON	\N	\N
1463	SECRETSEN	1989-10-30 00:00:00	1992-10-07 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	83031N	NON	\N	\N
1464	SECRETSEN	1989-10-04 00:00:00	1995-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	86034E	NON	\N	\N
1465	SECRETSEN	1986-10-07 00:00:00	1989-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	82002D	NON	\N	\N
1466	SECRETSEN	1980-10-07 00:00:00	1989-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	77043E	NON	\N	\N
1467	SECRETSEN	1977-10-05 00:00:00	1983-10-05 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	73006G	NON	\N	\N
1469	SECRETSEN	1974-10-03 00:00:00	1977-10-05 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	66002K	NON	\N	\N
1113	AUCUNSEN	\N	1983-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000138	NON	\N	\N
1115	SECRETSEN	\N	1968-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000023	NON	\N	\N
1116	AUCUNSEN	\N	1971-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000030	NON	\N	\N
1117	AUCUNSEN	\N	1995-09-24 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59554W	NON	\N	\N
1118	AUCUNSEN	\N	1989-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000307	NON	\N	\N
1119	AUCUNSEN	\N	1983-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58341F	NON	\N	\N
1120	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000143	NON	\N	\N
1123	AUCUNSEN	\N	1981-05-26 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	57321W	NON	\N	\N
1124	AUCUNSEN	\N	1986-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59619W	NON	\N	\N
1125	AUCUNSEN	\N	1998-02-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	96002B	NON	\N	\N
1126	PDTSEN	1968-10-02 00:00:00	1992-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000211	NON	\N	\N
1128	AUCUNSEN	\N	1965-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000108	NON	\N	\N
1130	AUCUNSEN	\N	1965-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	56522A	NON	\N	\N
1131	AUCUNSEN	\N	1992-03-20 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000476	NON	\N	\N
1132	AUCUNSEN	\N	1971-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000141	NON	\N	\N
1134	AUCUNSEN	\N	1989-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58917A	NON	\N	\N
1135	AUCUNSEN	\N	1992-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59242H	NON	\N	\N
1136	AUCUNSEN	\N	1992-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000470	NON	\N	\N
1137	AUCUNSEN	\N	1997-09-11 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	88010E	NON	\N	\N
1138	AUCUNSEN	\N	1983-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000202	NON	\N	\N
1140	AUCUNSEN	\N	1978-03-12 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000639	NON	\N	\N
1141	SECRETSEN	1989-10-04 00:00:00	1992-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	59244K	NON	\N	\N
1142	AUCUNSEN	\N	1977-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000085	NON	\N	\N
1143	AUCUNSEN	\N	1989-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58918B	NON	\N	\N
1144	AUCUNSEN	\N	1959-07-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000212	NON	\N	\N
1145	AUCUNSEN	\N	1992-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59245L	NON	\N	\N
1147	AUCUNSEN	\N	1989-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000104	NON	\N	\N
1148	AUCUNSEN	\N	1983-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000293	NON	\N	\N
1149	AUCUNSEN	\N	1976-12-15 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000077	NON	\N	\N
1150	AUCUNSEN	\N	1980-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000158	NON	\N	\N
1151	AUCUNSEN	\N	1997-07-04 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95063L	NON	\N	\N
1153	AUCUNSEN	\N	1989-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58938F	NON	\N	\N
1154	AUCUNSEN	\N	1968-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000142	NON	\N	\N
1155	AUCUNSEN	\N	1997-06-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	77003V	NON	\N	\N
1156	AUCUNSEN	\N	1989-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58919C	NON	\N	\N
1157	AUCUNSEN	\N	1984-12-25 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000125	NON	\N	\N
1158	AUCUNSEN	\N	1997-11-18 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95064M	NON	\N	\N
1160	AUCUNSEN	\N	1959-06-28 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	56305S	NON	\N	\N
1161	AUCUNSEN	\N	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59557A	NON	\N	\N
1162	AUCUNSEN	\N	1969-09-12 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000537	NON	\N	\N
1163	AUCUNSEN	\N	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59558B	NON	\N	\N
1164	AUCUNSEN	\N	1983-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000174	NON	\N	\N
1166	AUCUNSEN	\N	1974-02-04 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000172	NON	\N	\N
1167	AUCUNSEN	\N	1986-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58638V	NON	\N	\N
1168	AUCUNSEN	\N	1989-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58929E	NON	\N	\N
1169	AUCUNSEN	\N	1971-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	57146A	NON	\N	\N
1170	AUCUNSEN	\N	1985-05-26 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000443	NON	\N	\N
1172	AUCUNSEN	\N	1992-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000214	NON	\N	\N
1173	AUCUNSEN	\N	1992-03-05 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000505	NON	\N	\N
1174	SECRETSEN	1977-10-05 00:00:00	1982-11-19 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58928D	NON	\N	\N
1175	AUCUNSEN	\N	1962-07-04 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000305	NON	\N	\N
1176	AUCUNSEN	\N	1983-05-31 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000453	NON	\N	\N
1177	SECRETSEN	\N	1989-01-09 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000564	NON	\N	\N
1180	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	57738U	NON	\N	\N
1182	AUCUNSEN	\N	1983-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58352J	NON	\N	\N
1185	AUCUNSEN	\N	1988-06-24 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59307H	NON	\N	\N
735	AUCUNSEN	\N	1980-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000448	NON	\N	\N
736	AUCUNSEN	\N	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59533R	NON	\N	\N
738	AUCUNSEN	\N	1983-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58343H	NON	\N	\N
739	AUCUNSEN	\N	1992-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59213C	NON	\N	\N
740	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	57773X	NON	\N	\N
741	AUCUNSEN	\N	1980-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000087	NON	\N	\N
742	SECRETSEN	1980-10-07 00:00:00	1983-10-05 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59214D	NON	\N	\N
745	AUCUNSEN	\N	1995-09-24 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000465	NON	\N	\N
746	AUCUNSEN	\N	1974-03-11 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000037	NON	\N	\N
747	AUCUNSEN	\N	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59520L	NON	\N	\N
748	AUCUNSEN	\N	1962-03-06 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000012	NON	\N	\N
749	AUCUNSEN	\N	1969-08-22 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000146	NON	\N	\N
751	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58614M	NON	\N	\N
752	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000098	NON	\N	\N
753	AUCUNSEN	\N	1962-09-22 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000292	NON	\N	\N
754	AUCUNSEN	\N	1983-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000184	NON	\N	\N
755	VICPDTSEN	1962-10-04 00:00:00	1965-10-05 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	59219J	NON	\N	\N
757	AUCUNSEN	\N	1990-11-29 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000545	NON	\N	\N
758	AUCUNSEN	\N	1992-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59220B	NON	\N	\N
759	AUCUNSEN	\N	1959-07-14 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000140	NON	\N	\N
760	SECRETSEN	1983-10-05 00:00:00	1986-10-07 00:00:00	NON	3	ANCIEN	\N	\N	\N	\N	59568D	NON	\N	\N
761	AUCUNSEN	\N	1996-01-20 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	92014N	NON	\N	\N
762	AUCUNSEN	\N	1989-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58951C	NON	\N	\N
764	AUCUNSEN	\N	1989-09-17 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000474	NON	\N	\N
765	AUCUNSEN	1965-10-06 00:00:00	1971-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000039	NON	\N	\N
766	AUCUNSEN	\N	1980-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000020	NON	\N	\N
767	AUCUNSEN	\N	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59523P	NON	\N	\N
768	AUCUNSEN	\N	1977-09-25 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000365	NON	\N	\N
770	AUCUNSEN	\N	1989-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58946F	NON	\N	\N
771	AUCUNSEN	\N	1968-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000053	NON	\N	\N
772	AUCUNSEN	\N	1968-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000035	NON	\N	\N
773	AUCUNSEN	\N	1968-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000049	NON	\N	\N
774	AUCUNSEN	\N	1974-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	57432D	NON	\N	\N
775	AUCUNSEN	\N	1962-07-04 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000010	NON	\N	\N
777	AUCUNSEN	\N	1995-09-24 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59524Q	NON	\N	\N
778	AUCUNSEN	\N	1983-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58366Q	NON	\N	\N
779	AUCUNSEN	\N	1983-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58411C	NON	\N	\N
780	AUCUNSEN	\N	1987-02-27 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000538	NON	\N	\N
781	AUCUNSEN	\N	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59525R	NON	\N	\N
1341	AUCUNSEN	\N	1962-09-23 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000708	NON	\N	\N
1342	AUCUNSEN	\N	1971-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000762	NON	\N	\N
1343	AUCUNSEN	\N	1961-02-21 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000742	NON	\N	\N
1345	AUCUNSEN	\N	1968-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000738	NON	\N	\N
1346	SECRETSEN	1961-10-03 00:00:00	1962-10-03 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000771	NON	\N	\N
1347	AUCUNSEN	\N	1963-01-22 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000767	NON	\N	\N
1348	AUCUNSEN	\N	1971-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000751	NON	\N	\N
1349	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000671	NON	\N	\N
1351	AUCUNSEN	1961-10-04 00:00:00	1971-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000691	NON	\N	\N
1352	AUCUNSEN	\N	1968-10-29 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000736	NON	\N	\N
1353	AUCUNSEN	\N	1962-07-04 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000712	NON	\N	\N
1354	AUCUNSEN	\N	1965-12-17 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000725	NON	\N	\N
1355	AUCUNSEN	\N	1971-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000748	NON	\N	\N
1356	AUCUNSEN	\N	1972-10-19 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000734	NON	\N	\N
1358	AUCUNSEN	\N	1968-09-19 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000694	NON	\N	\N
1359	AUCUNSEN	\N	1968-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000739	NON	\N	\N
1360	AUCUNSEN	\N	1979-07-05 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000747	NON	\N	\N
1361	AUCUNSEN	\N	1961-08-22 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000730	NON	\N	\N
1362	AUCUNSEN	\N	1968-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000698	NON	\N	\N
1364	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000741	NON	\N	\N
1365	SECRETSEN	1975-10-07 00:00:00	1976-11-09 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000752	NON	\N	\N
1366	AUCUNSEN	\N	1965-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000743	NON	\N	\N
1367	AUCUNSEN	\N	1971-11-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000750	NON	\N	\N
1368	AUCUNSEN	\N	1971-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000704	NON	\N	\N
1372	AUCUNSEN	\N	1973-12-13 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000749	NON	\N	\N
1373	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000673	NON	\N	\N
1374	AUCUNSEN	\N	1962-07-04 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000745	NON	\N	\N
1375	AUCUNSEN	\N	1971-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000716	NON	\N	\N
1377	AUCUNSEN	\N	1971-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000674	NON	\N	\N
1379	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000684	NON	\N	\N
1380	AUCUNSEN	\N	1980-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000770	NON	\N	\N
1381	AUCUNSEN	\N	1962-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000676	NON	\N	\N
1382	AUCUNSEN	\N	1966-06-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000668	NON	\N	\N
1383	AUCUNSEN	\N	1965-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000669	NON	\N	\N
1384	AUCUNSEN	\N	1959-04-29 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000740	NON	\N	\N
1385	AUCUNSEN	\N	1968-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000729	NON	\N	\N
788	QUESTESEN	1974-10-03 00:00:00	1983-10-05 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000327	NON	\N	\N
795	AUCUNSEN	\N	1980-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000061	NON	\N	\N
872	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000082	NON	\N	\N
878	AUCUNSEN	\N	1983-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58351H	NON	\N	\N
955	AUCUNSEN	\N	1986-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58650R	NON	\N	\N
961	AUCUNSEN	\N	1991-11-03 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000516	NON	\N	\N
659	SECRETSEN	1983-10-05 00:00:00	1986-10-01 00:00:00	NON	7	ANCIEN	\N	\N	\N	\N	58633Q	NON	\N	\N
1038	AUCUNSEN	\N	1997-11-17 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	88011F	NON	\N	\N
1044	AUCUNSEN	\N	1986-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000337	NON	\N	\N
1121	AUCUNSEN	\N	1990-06-14 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000514	NON	\N	\N
664	SECRETSEN	1970-10-07 00:00:00	1973-03-11 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000543	NON	\N	\N
1127	AUCUNSEN	\N	1989-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58916Y	NON	\N	\N
1204	VICPDTSEN	1974-07-02 00:00:00	1976-01-19 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59560U	NON	\N	\N
1210	AUCUNSEN	\N	1968-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000118	NON	\N	\N
1286	AUCUNSEN	\N	1970-06-13 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000015	NON	\N	\N
1293	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000701	NON	\N	\N
633	QUESTESEN	1965-10-05 00:00:00	1968-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000687	NON	\N	\N
1370	AUCUNSEN	\N	1968-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000754	NON	\N	\N
1376	AUCUNSEN	\N	1965-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000717	NON	\N	\N
1386	SECRETSEN	1968-10-04 00:00:00	1974-10-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	58332E	NON	\N	\N
1387	SECRETSEN	1962-10-03 00:00:00	1965-10-05 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000298	NON	\N	\N
642	SECRETSEN	1980-10-07 00:00:00	1986-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000553	NON	\N	\N
649	SECRETSEN	1974-10-03 00:00:00	1975-10-07 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58643S	NON	\N	\N
655	SECRETSEN	1965-10-05 00:00:00	1967-10-11 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000271	NON	\N	\N
663	AUCUNSEN	1968-10-05 00:00:00	1977-10-02 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000688	NON	\N	\N
670	AUCUNSEN	\N	1997-06-12 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	95010W	NON	\N	\N
677	SECRETSEN	1966-10-05 00:00:00	1967-10-11 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000176	NON	\N	\N
683	AUCUNSEN	\N	1981-01-03 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000198	NON	\N	\N
690	AUCUNSEN	\N	1986-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000374	NON	\N	\N
696	AUCUNSEN	\N	1962-07-04 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000064	NON	\N	\N
702	AUCUNSEN	\N	1967-04-03 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58302X	NON	\N	\N
709	AUCUNSEN	\N	1971-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000036	NON	\N	\N
715	AUCUNSEN	\N	1983-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000339	NON	\N	\N
717	AUCUNSEN	\N	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59564Y	NON	\N	\N
724	AUCUNSEN	\N	1983-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000277	NON	\N	\N
731	AUCUNSEN	\N	1962-07-04 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000091	NON	\N	\N
737	AUCUNSEN	\N	1962-07-04 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000260	NON	\N	\N
743	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	57716N	NON	\N	\N
750	AUCUNSEN	\N	1971-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000051	NON	\N	\N
756	AUCUNSEN	\N	1974-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000295	NON	\N	\N
763	AUCUNSEN	1987-02-21 00:00:00	1989-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000399	NON	\N	\N
769	AUCUNSEN	\N	1976-09-27 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000574	NON	\N	\N
776	AUCUNSEN	\N	1965-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000150	NON	\N	\N
782	AUCUNSEN	\N	1971-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000076	NON	\N	\N
789	AUCUNSEN	\N	1994-09-09 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000510	NON	\N	\N
797	AUCUNSEN	\N	1965-08-19 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000191	NON	\N	\N
801	AUCUNSEN	\N	1972-09-14 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000222	NON	\N	\N
807	AUCUNSEN	\N	1981-04-23 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000195	NON	\N	\N
814	AUCUNSEN	\N	1976-03-18 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000494	NON	\N	\N
820	AUCUNSEN	\N	1996-01-12 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	89011K	NON	\N	\N
827	AUCUNSEN	\N	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59529V	NON	\N	\N
833	AUCUNSEN	\N	1992-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000438	NON	\N	\N
839	AUCUNSEN	\N	1971-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000245	NON	\N	\N
846	AUCUNSEN	\N	1986-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58670V	NON	\N	\N
852	AUCUNSEN	\N	1989-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58943C	NON	\N	\N
859	AUCUNSEN	\N	1973-03-05 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000011	NON	\N	\N
865	AUCUNSEN	\N	1988-06-12 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	57714L	NON	\N	\N
873	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	57721K	NON	\N	\N
880	AUCUNSEN	\N	1989-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58934B	NON	\N	\N
883	AUCUNSEN	\N	1988-06-12 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58818X	NON	\N	\N
889	AUCUNSEN	\N	1965-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000043	NON	\N	\N
896	AUCUNSEN	\N	1974-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000296	NON	\N	\N
902	AUCUNSEN	\N	1980-11-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000455	NON	\N	\N
909	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000536	NON	\N	\N
915	AUCUNSEN	\N	1997-03-07 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	62001R	NON	\N	\N
921	AUCUNSEN	\N	1971-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000210	NON	\N	\N
928	AUCUNSEN	\N	1992-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59232F	NON	\N	\N
934	AUCUNSEN	\N	1986-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58625Q	NON	\N	\N
941	AUCUNSEN	\N	1995-09-24 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58115W	NON	\N	\N
947	AUCUNSEN	\N	1965-02-10 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000040	NON	\N	\N
954	AUCUNSEN	\N	1980-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000171	NON	\N	\N
963	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000149	NON	\N	\N
967	AUCUNSEN	\N	1968-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000068	NON	\N	\N
973	AUCUNSEN	\N	1974-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	57449N	NON	\N	\N
980	AUCUNSEN	\N	1977-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000230	NON	\N	\N
986	AUCUNSEN	\N	1971-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	57129Y	NON	\N	\N
993	AUCUNSEN	\N	1989-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58924Y	NON	\N	\N
999	AUCUNSEN	\N	1986-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000248	NON	\N	\N
1005	AUCUNSEN	\N	1983-10-02 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000144	NON	\N	\N
1012	AUCUNSEN	\N	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59546W	NON	\N	\N
1018	AUCUNSEN	\N	1995-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	59549A	NON	\N	\N
1025	AUCUNSEN	\N	1962-07-04 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	56406W	NON	\N	\N
1031	AUCUNSEN	\N	1974-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	57456M	NON	\N	\N
1039	AUCUNSEN	\N	1982-03-20 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000269	NON	\N	\N
1046	AUCUNSEN	\N	1962-07-04 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000001	NON	\N	\N
1049	AUCUNSEN	\N	1996-09-10 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	92038W	NON	\N	\N
1055	AUCUNSEN	\N	1962-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000065	NON	\N	\N
1062	AUCUNSEN	\N	1971-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000069	NON	\N	\N
1068	AUCUNSEN	\N	1971-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000290	NON	\N	\N
1075	AUCUNSEN	\N	1971-08-10 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000145	NON	\N	\N
1081	AUCUNSEN	\N	1967-04-03 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	000079	NON	\N	\N
1087	AUCUNSEN	\N	1986-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	58645U	NON	\N	\N
1738	AUCUNSEN	2008-10-01 00:00:00	2011-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08038Y	NON	\N	\N
1739	AUCUNSEN	2008-10-01 00:00:00	2014-10-07 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08039A	NON	\N	2014-10-08 14:55:38
1740	AUCUNSEN	2008-10-01 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08040S	NON	\N	2014-09-28 17:52:18
1741	AUCUNSEN	2008-10-01 00:00:00	2020-09-24 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08041T	NON	\N	\N
1742	AUCUNSEN	2008-10-01 00:00:00	2017-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08042U	NON	\N	2017-10-01 10:20:50
1746	AUCUNSEN	2008-10-01 00:00:00	2020-07-31 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08044W	NON	\N	\N
1748	AUCUNSEN	2008-10-01 00:00:00	2014-02-13 00:00:00	NON	0	ANCIEN	\N	\N	\N	\N	08046Y	NON	\N	2014-02-14 10:09:43
1750	AUCUNSEN	2008-10-01 00:00:00	2014-10-07 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08048B	NON	\N	2014-10-08 14:54:47
1754	AUCUNSEN	2008-10-01 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08050U	NON	\N	2014-09-28 12:44:31
1756	AUCUNSEN	2008-10-01 00:00:00	2017-10-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08052W	NON	\N	2017-10-04 14:47:20
2124	AUCUNSEN	2013-06-29 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	13003V	NON	2013-07-01 09:35:52	2014-09-28 17:14:21
1570	AUCUNSEN	2004-10-01 00:00:00	2012-07-21 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04090L	NON	\N	\N
1571	AUCUNSEN	\N	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04091M	NON	\N	2014-09-28 17:55:39
297	AUCUNSEN	\N	2004-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	86021Y	NON	\N	\N
1573	AUCUNSEN	\N	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04093P	NON	\N	\N
1574	AUCUNSEN	2004-10-01 00:00:00	2014-10-07 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04094Q	NON	\N	2014-10-08 14:55:23
248	AUCUNSEN	\N	2004-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	78007E	NON	\N	\N
1577	QUESTESEN	2004-10-06 00:00:00	2008-10-06 00:00:00	NON	2	ANCIEN	\N	\N	\N	\N	92039X	NON	\N	\N
1578	VICPDTSEN	2004-10-06 00:00:00	2004-11-26 00:00:00	NON	4	ANCIEN	\N	\N	\N	\N	92005M	NON	\N	\N
1579	VICPDTSEN	2004-10-06 00:00:00	2008-10-06 00:00:00	NON	3	ANCIEN	\N	\N	\N	\N	77043E	NON	\N	\N
1580	VICPDTSEN	2004-10-06 00:00:00	2008-10-06 00:00:00	NON	5	ANCIEN	\N	\N	\N	\N	01031L	NON	\N	\N
1581	SECRETSEN	2004-10-06 00:00:00	2008-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	96008H	NON	\N	\N
1582	SECRETSEN	2004-10-06 00:00:00	2008-10-06 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01051Q	NON	\N	\N
1583	SECRETSEN	2004-10-06 00:00:00	2008-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98049B	NON	\N	\N
1584	SECRETSEN	2004-10-06 00:00:00	2008-10-06 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	90003B	NON	\N	\N
1585	SECRETSEN	2004-10-06 00:00:00	2008-10-06 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	95021A	NON	\N	\N
1586	SECRETSEN	2004-10-06 00:00:00	2008-10-06 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98042T	NON	\N	\N
1587	SECRETSEN	2004-10-06 00:00:00	2008-10-06 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	86039K	NON	\N	\N
1588	AUCUNSEN	2004-10-06 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98006P	NON	\N	\N
1589	AUCUNSEN	2004-10-06 00:00:00	2011-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	95015C	NON	\N	\N
344	SECRETSEN	2001-10-03 00:00:00	2004-10-05 00:00:00	NON	7	ANCIEN	\N	\N	\N	\N	98030P	NON	\N	\N
1590	AUCUNSEN	2004-10-06 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98030P	NON	\N	2014-09-28 13:19:48
1591	AUCUNSEN	2004-10-06 00:00:00	2014-09-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	96007G	NON	\N	2014-09-01 10:21:13
44	VICPDTSEN	2001-10-03 00:00:00	2004-10-05 00:00:00	NON	3	ANCIEN	\N	\N	\N	\N	89045V	NON	\N	\N
1592	AUCUNSEN	2004-10-06 00:00:00	2007-12-16 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	89045V	NON	\N	\N
1593	AUCUNSEN	2004-10-06 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	97009N	NON	\N	\N
39	AUCUNSEN	1996-09-29 00:00:00	2004-10-05 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	96008H	NON	\N	\N
1594	AUCUNSEN	1977-10-03 00:00:00	1980-10-06 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	77043E	NON	\N	\N
1595	AUCUNSEN	1981-10-28 00:00:00	1988-07-27 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	81015E	NON	\N	\N
1596	AUCUNSEN	1992-10-02 00:00:00	1995-10-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	81015E	NON	\N	\N
1597	AUCUNSEN	2004-10-01 00:00:00	2010-03-06 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	81015E	NON	\N	\N
1598	AUCUNSEN	1982-04-04 00:00:00	1986-10-06 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	82002D	NON	\N	\N
1599	AUCUNSEN	1973-06-27 00:00:00	1977-10-05 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	73006G	NON	\N	\N
1600	AUCUNSEN	1966-06-26 00:00:00	1974-10-02 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	66002K	NON	\N	\N
1601	AUCUNSEN	1980-09-28 00:00:00	1988-06-12 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	66002K	NON	\N	\N
1602	AUCUNSEN	1989-10-02 00:00:00	1989-11-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	66002K	NON	\N	\N
1603	AUCUNSEN	1977-10-06 00:00:00	1978-05-06 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	66002K	NON	\N	\N
1604	VICPDTSEN	2004-10-06 00:00:00	2008-10-06 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	89029V	NON	\N	\N
124	VICPDTSEN	2001-10-03 00:00:00	2004-10-05 00:00:00	NON	4	ANCIEN	\N	\N	\N	\N	78006D	NON	\N	\N
1605	VICPDTSEN	2004-10-06 00:00:00	2008-10-06 00:00:00	NON	2	ANCIEN	\N	\N	\N	\N	78006D	NON	\N	\N
1606	VICPDTSEN	2004-10-06 00:00:00	2008-10-06 00:00:00	NON	6	ANCIEN	\N	\N	\N	\N	95032D	NON	\N	\N
1607	QUESTESEN	2004-10-06 00:00:00	2008-10-06 00:00:00	NON	3	ANCIEN	\N	\N	\N	\N	83031N	NON	\N	\N
1610	AUCUNSEN	\N	2020-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04097T	NON	\N	\N
1612	AUCUNSEN	2004-11-02 00:00:00	2005-06-28 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04098U	NON	\N	\N
1613	AUCUNSEN	2004-11-02 00:00:00	2005-06-27 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04099V	NON	\N	\N
1614	AUCUNSEN	\N	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04100U	NON	\N	\N
1615	AUCUNSEN	\N	2008-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04101V	NON	\N	\N
1618	AUCUNSEN	2005-02-24 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	05001W	NON	\N	\N
1620	AUCUNSEN	2005-02-21 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	95036H	NON	\N	2014-09-28 17:31:42
1621	AUCUNSEN	2005-02-21 00:00:00	2019-06-24 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04061F	NON	\N	\N
1622	AUCUNSEN	2005-02-21 00:00:00	2005-03-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	92005M	NON	\N	\N
1623	AUCUNSEN	2005-02-21 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04065K	NON	\N	2014-09-28 17:31:42
1624	AUCUNSEN	2005-02-21 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04069P	NON	\N	2014-09-28 17:31:42
1625	VICPDTSEN	2005-03-02 00:00:00	2008-10-06 00:00:00	NON	4	ANCIEN	\N	\N	\N	\N	92005M	NON	\N	\N
1626	AUCUNSEN	2005-06-19 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	05011Y	NON	\N	2014-09-28 13:47:05
1628	AUCUNSEN	2005-09-19 00:00:00	2017-10-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	05012A	NON	\N	2017-10-04 14:45:37
1630	AUCUNSEN	2005-09-19 00:00:00	2007-06-17 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	02009S	NON	\N	\N
1631	AUCUNSEN	1961-11-13 00:00:00	1962-07-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	05015D	NON	\N	\N
1632	AUCUNSEN	2006-05-17 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	06001B	NON	\N	\N
1634	AUCUNSEN	\N	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	06005F	NON	\N	2014-09-28 13:32:35
1635	AUCUNSEN	\N	2008-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	06006G	NON	\N	\N
1650	AUCUNSEN	2007-06-29 00:00:00	2013-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	07025P	NON	\N	\N
1651	AUCUNSEN	2007-06-29 00:00:00	2017-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	07026Q	NON	\N	2017-09-24 19:25:10
1655	AUCUNSEN	\N	\N	NON	\N	ACTIF	\N	\N	\N	\N	07029T	NON	\N	\N
1656	AUCUNSEN	\N	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	07030L	NON	\N	2014-09-28 17:03:42
1642	AUCUNSEN	2007-01-03 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	07001F	NON	\N	\N
1643	AUCUNSEN	\N	2007-01-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	07002G	NON	\N	\N
1648	AUCUNSEN	2007-06-22 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	07023M	NON	\N	\N
1665	AUCUNSEN	2007-11-30 00:00:00	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	07033P	NON	\N	\N
1669	AUCUNSEN	1965-08-20 00:00:00	1965-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08001K	NON	\N	\N
1674	AUCUNSEN	2008-10-01 00:00:00	2023-10-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08010L	NON	\N	\N
1676	AUCUNSEN	2008-10-01 00:00:00	\N	NON	\N	ACTIF	\N	\N	\N	\N	08012N	NON	\N	\N
1679	AUCUNSEN	2008-10-01 00:00:00	\N	NON	\N	ACTIF	\N	\N	\N	\N	08015R	NON	\N	\N
1681	AUCUNSEN	2008-10-01 00:00:00	2011-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08016S	NON	\N	\N
1682	AUCUNSEN	2008-10-01 00:00:00	2021-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08017T	NON	\N	\N
1684	AUCUNSEN	2008-10-01 00:00:00	2020-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08019V	NON	\N	\N
1688	AUCUNSEN	2008-10-01 00:00:00	2011-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08022Q	NON	\N	\N
1690	AUCUNSEN	2008-10-01 00:00:00	2014-10-07 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08024S	NON	\N	2014-10-08 14:48:34
1691	AUCUNSEN	2008-10-01 00:00:00	2011-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08025T	NON	\N	\N
1694	AUCUNSEN	2008-10-01 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08026U	NON	\N	2014-09-28 17:52:18
1709	AUCUNSEN	2008-10-01 00:00:00	\N	NON	\N	ACTIF	\N	\N	\N	\N	08028W	NON	\N	\N
1711	AUCUNSEN	2008-10-01 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08029X	NON	\N	2014-09-28 17:52:18
1730	AUCUNSEN	2008-10-01 00:00:00	2020-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08031R	NON	\N	\N
1733	AUCUNSEN	2008-10-01 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08033T	NON	\N	2014-09-28 17:27:35
1735	AUCUNSEN	2008-10-01 00:00:00	2020-08-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08035V	NON	\N	\N
1736	AUCUNSEN	2008-10-01 00:00:00	2013-02-06 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08036W	NON	\N	\N
2059	PDTSEN	2011-10-01 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98006P	NON	\N	2014-09-28 12:54:15
2060	AUCUNSEN	2011-10-01 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	86034E	NON	\N	2014-10-01 19:48:48
2102	AUCUNSEN	2011-11-02 00:00:00	2012-06-16 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	11003M	NON	\N	\N
2100	AUCUNSEN	1977-10-06 00:00:00	1986-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000114	NON	\N	\N
2101	AUCUNSEN	1959-04-28 00:00:00	1968-10-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	000114	NON	\N	\N
2058	AUCUNSEN	2011-10-01 00:00:00	2016-11-14 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	96003C	NON	\N	2016-11-14 09:37:35
2114	AUCUNSEN	1983-10-03 00:00:00	1989-10-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	83046V	NON	\N	\N
2116	AUCUNSEN	1998-10-06 00:00:00	2001-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	83046V	NON	\N	\N
2122	AUCUNSEN	2013-03-01 00:00:00	2017-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	13002U	NON	\N	2017-09-24 17:42:26
2056	AUCUNSEN	\N	2011-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04096S	NON	\N	\N
2057	AUCUNSEN	2011-10-01 00:00:00	2017-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	09001P	NON	\N	2017-09-24 17:47:27
1890	AUCUNSEN	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11068S	\N	\N	2017-09-24 18:05:41
2103	AUCUNSEN	2012-03-19 00:00:00	2020-03-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	11081P	NON	\N	\N
2105	AUCUNSEN	2012-06-17 00:00:00	2023-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01048V	NON	\N	\N
2106	AUCUNSEN	2012-06-17 00:00:00	2017-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	86044G	NON	\N	2017-10-01 10:32:58
2107	AUCUNSEN	2012-06-17 00:00:00	2014-04-24 00:00:00	NON	0	ANCIEN	\N	\N	\N	\N	95049N	NON	\N	2014-09-28 17:07:41
1897	AUCUNSEN	2011-10-01 00:00:00	2020-07-13 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11049P	\N	\N	\N
1899	AUCUNSEN	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11036J	\N	\N	2017-09-24 18:16:52
1900	AUCUNSEN	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11039M	\N	\N	2014-10-08 14:51:20
1902	AUCUNSEN	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11037K	\N	\N	2017-09-24 18:16:52
1908	AUCUNSEN	2011-10-01 00:00:00	2016-05-11 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11029K	\N	\N	2016-05-12 15:13:54
1910	AUCUNSEN	2011-10-01 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11048N	\N	\N	\N
1913	AUCUNSEN	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11095V	\N	\N	2017-09-24 13:25:54
1914	AUCUNSEN	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11094U	\N	\N	2017-09-24 13:25:54
1915	AUCUNSEN	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11082Q	\N	\N	2017-09-24 19:16:18
1917	AUCUNSEN	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11098Y	\N	\N	2017-09-24 17:14:27
1918	AUCUNSEN	2011-10-01 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11099A	\N	\N	\N
1919	AUCUNSEN	2011-10-01 00:00:00	2011-12-22 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11081P	\N	\N	\N
1922	AUCUNSEN	2011-10-01 00:00:00	2020-10-05 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	05008E	\N	\N	\N
1925	AUCUNSEN	2011-10-01 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11097X	\N	\N	\N
1935	AUCUNSEN	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11106F	\N	\N	2017-09-24 19:14:37
1937	AUCUNSEN	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11093T	\N	\N	2017-09-24 12:57:09
1941	AUCUNSEN	2011-10-01 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11103C	\N	\N	\N
1944	AUCUNSEN	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11112D	\N	\N	2017-09-24 16:45:26
1946	AUCUNSEN	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11107G	\N	\N	2017-09-24 17:06:55
1947	AUCUNSEN	2011-10-01 00:00:00	2015-04-07 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11108H	\N	\N	2015-04-07 16:50:27
1949	AUCUNSEN	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11111C	\N	\N	2017-09-24 16:45:26
1950	AUCUNSEN	2011-10-01 00:00:00	2015-03-16 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11110B	\N	\N	2015-03-17 15:32:30
1954	AUCUNSEN	2011-10-01 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11101A	\N	\N	\N
1955	SECRETSEN	2011-10-05 00:00:00	2014-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	04095R	\N	\N	2014-10-08 14:46:46
1956	AUCUNSEN	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11114F	\N	\N	2017-09-25 10:54:33
1957	AUCUNSEN	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11113E	\N	\N	2017-09-25 10:54:33
1959	AUCUNSEN	2011-10-01 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11109J	\N	\N	\N
1961	AUCUNSEN	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11071M	\N	\N	2017-09-24 18:16:33
2110	AUCUNSEN	2012-07-23 00:00:00	2014-05-04 00:00:00	NON	0	ANCIEN	\N	\N	\N	\N	12038D	NON	\N	2014-05-22 12:22:48
2111	AUCUNSEN	2012-07-23 00:00:00	2014-05-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	12039E	NON	\N	\N
2112	AUCUNSEN	2012-07-23 00:00:00	2014-05-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	12040W	NON	\N	\N
1967	AUCUNSEN	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11100Y	\N	\N	2017-09-24 13:57:40
1969	AUCUNSEN	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11105E	\N	\N	2017-09-24 18:20:10
1970	AUCUNSEN	2011-10-01 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11104D	\N	\N	\N
1971	AUCUNSEN	2011-10-01 00:00:00	2012-07-21 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11027H	\N	\N	\N
1972	AUCUNSEN	2011-10-01 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11026G	\N	\N	\N
1978	AUCUNSEN	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11088W	\N	\N	2017-09-24 17:15:15
1979	AUCUNSEN	2011-10-01 00:00:00	2022-03-31 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	95063L	\N	\N	\N
1980	AUCUNSEN	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11089X	\N	\N	2017-09-24 17:15:15
1982	AUCUNSEN	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11020A	\N	\N	2017-09-24 16:24:51
1983	AUCUNSEN	2011-10-01 00:00:00	2014-07-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11022C	\N	\N	2014-07-01 09:29:53
1985	AUCUNSEN	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11025F	\N	\N	2017-09-24 16:24:51
1989	AUCUNSEN	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11044J	\N	\N	2017-09-24 17:29:37
1990	AUCUNSEN	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11046L	\N	\N	2017-09-24 17:29:37
1991	AUCUNSEN	2011-10-01 00:00:00	2014-05-11 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11045K	\N	\N	2014-05-12 09:52:22
1993	AUCUNSEN	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11061K	\N	\N	2017-09-24 17:42:26
1994	AUCUNSEN	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11059R	\N	\N	2017-09-24 17:42:26
1995	AUCUNSEN	2011-10-01 00:00:00	2013-02-28 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11062L	\N	\N	\N
1997	AUCUNSEN	2011-10-01 00:00:00	2016-01-11 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11060J	\N	\N	2016-01-11 17:34:09
1998	AUCUNSEN	2011-10-01 00:00:00	2018-06-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11063M	\N	\N	\N
2002	AUCUNSEN	2011-10-01 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11056N	\N	\N	\N
2007	AUCUNSEN	2011-10-01 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11066Q	\N	\N	\N
2009	AUCUNSEN	2011-10-01 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11065P	\N	\N	\N
2014	AUCUNSEN	2011-10-01 00:00:00	2014-05-11 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11041F	\N	\N	2014-05-12 09:51:40
2027	AUCUNSEN	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11091R	\N	\N	2017-09-24 18:17:56
2031	AUCUNSEN	2011-10-01 00:00:00	2011-10-04 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11077T	\N	\N	\N
2035	AUCUNSEN	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11076S	\N	\N	2017-09-24 17:47:28
2036	AUCUNSEN	2011-10-01 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11080N	\N	\N	\N
2037	AUCUNSEN	2011-10-01 00:00:00	2017-07-28 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11032E	\N	\N	2017-08-03 11:38:41
2038	AUCUNSEN	2011-10-01 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11031D	\N	\N	\N
2039	AUCUNSEN	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11034G	\N	\N	2017-09-24 17:55:12
2040	AUCUNSEN	2011-10-01 00:00:00	2020-10-05 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11033F	\N	\N	\N
2041	AUCUNSEN	2011-10-01 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11054L	\N	\N	\N
2042	AUCUNSEN	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11055M	\N	\N	2017-09-24 18:07:57
2043	AUCUNSEN	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11051H	\N	\N	2014-10-08 14:54:01
2044	AUCUNSEN	2011-10-01 00:00:00	2017-10-03 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11053K	\N	\N	2017-10-04 14:46:15
2099	AUCUNSEN	1980-10-02 00:00:00	1988-06-24 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	59717X	NON	\N	\N
2050	AUCUNSEN	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11084S	\N	\N	2017-09-24 19:25:10
2053	AUCUNSEN	2011-10-01 00:00:00	2014-10-07 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11085T	\N	\N	2014-10-08 14:50:27
2054	AUCUNSEN	2011-10-01 00:00:00	2020-10-05 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	99004R	NON	\N	\N
2066	SECRETSEN	2011-10-05 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01052R	NON	\N	2014-10-08 14:43:53
2069	SECRETSEN	2011-10-05 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08038Y	NON	\N	2014-10-08 14:44:29
2071	SECRETSEN	2011-10-05 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	92018S	NON	\N	2014-10-08 14:44:47
2073	SECRETSEN	2011-10-05 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08022Q	NON	\N	2014-10-08 14:45:05
2075	SECRETSEN	2011-10-05 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04067M	NON	\N	2014-10-08 14:45:21
2077	SECRETSEN	2011-10-05 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	87003B	NON	\N	2014-09-28 17:35:38
2079	SECRETSEN	2011-10-05 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	95031C	NON	\N	2014-10-08 14:45:38
2081	SECRETSEN	2011-10-05 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01003G	NON	\N	2014-10-08 14:46:16
2084	SECRETSEN	2011-10-05 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01022K	NON	\N	2014-10-08 14:47:06
2085	SECRETSEN	2011-10-05 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98028V	NON	\N	2014-09-28 17:22:11
2087	SECRETSEN	2011-10-05 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98038X	NON	\N	2014-09-28 17:38:26
2088	SECRETSEN	2011-10-05 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	11077T	NON	\N	2014-10-08 14:47:33
2091	SECRETSEN	2011-10-05 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04043D	NON	\N	2014-10-08 14:47:49
2092	AUCUNSEN	2011-10-05 00:00:00	2014-04-28 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04046G	NON	\N	2014-04-29 14:52:47
2093	AUCUNSEN	2011-10-05 00:00:00	2017-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01011G	NON	\N	2017-09-24 16:43:43
2094	AUCUNSEN	2011-10-05 00:00:00	2024-03-20 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98022P	NON	\N	\N
2095	AUCUNSEN	2011-10-05 00:00:00	2013-12-31 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	95003X	NON	\N	\N
2096	AUCUNSEN	2011-10-05 00:00:00	2014-10-07 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	92040Q	NON	\N	2014-10-08 14:56:23
2097	AUCUNSEN	2011-10-05 00:00:00	2017-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01016M	NON	\N	2017-09-24 17:09:24
2098	AUCUNSEN	2011-10-05 00:00:00	2014-10-07 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01019Q	NON	\N	2014-10-08 14:50:56
2062	QUESTESEN	2011-10-05 00:00:00	2014-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	01062T	NON	\N	2014-10-08 14:41:56
2063	QUESTESEN	2011-10-05 00:00:00	2014-09-30 00:00:00	NON	3	ANCIEN	\N	\N	\N	\N	08025T	NON	\N	2014-10-08 14:42:48
2068	AUCUNSEN	2011-10-05 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	95052H	NON	\N	2014-09-28 13:39:21
2065	AUCUNSEN	2011-10-05 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98041S	NON	\N	2014-09-28 16:42:05
2072	VICPDTSEN	2011-10-05 00:00:00	2014-09-30 00:00:00	NON	2	ANCIEN	\N	\N	\N	\N	95059Q	NON	\N	2014-10-08 14:39:00
2070	VICPDTSEN	2011-10-05 00:00:00	2014-04-28 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	08016S	NON	\N	2014-04-29 14:52:37
2074	VICPDTSEN	2011-10-05 00:00:00	2014-09-30 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	04077P	NON	\N	2014-10-08 14:38:12
2076	VICPDTSEN	2011-10-05 00:00:00	2014-09-30 00:00:00	NON	4	ANCIEN	\N	\N	\N	\N	98053W	NON	\N	2014-10-08 14:39:23
2078	VICPDTSEN	2011-10-05 00:00:00	2014-09-30 00:00:00	NON	5	ANCIEN	\N	\N	\N	\N	98042T	NON	\N	2014-10-08 14:39:43
2080	VICPDTSEN	2011-10-05 00:00:00	2014-09-30 00:00:00	NON	6	ANCIEN	\N	\N	\N	\N	95020Y	NON	\N	2014-10-08 14:40:05
2082	VICPDTSEN	2011-10-05 00:00:00	2014-09-30 00:00:00	NON	7	ANCIEN	\N	\N	\N	\N	01057W	NON	\N	2014-10-08 14:40:34
2083	VICPDTSEN	2011-10-05 00:00:00	2014-09-30 00:00:00	NON	8	ANCIEN	\N	\N	\N	\N	95015C	NON	\N	2014-10-08 14:41:05
2086	AUCUNSEN	2011-10-05 00:00:00	2014-10-07 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04056J	NON	\N	2014-10-08 14:57:11
2089	AUCUNSEN	2011-10-05 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	77043E	NON	\N	2014-09-28 16:59:41
2090	AUCUNSEN	2011-10-05 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	95032D	NON	\N	2014-09-28 17:07:41
2108	AUCUNSEN	2012-06-17 00:00:00	2014-05-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	12035A	NON	\N	\N
2118	AUCUNSEN	2012-12-03 00:00:00	2017-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	12042Y	NON	\N	2017-09-24 19:31:54
2119	AUCUNSEN	2013-02-07 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	13001T	NON	\N	2014-09-28 17:58:05
2126	AUCUNSEN	2013-10-01 00:00:00	2014-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	13005X	NON	2013-10-01 15:26:12	2014-09-28 18:00:58
2286	AUCUNSEN	2014-12-28 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14265W	\N	2014-12-29 15:45:40	\N
2306	AUCUNSEN	2016-11-18 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14355X	\N	2016-11-18 12:45:10	\N
2307	AUCUNSEN	2016-12-01 00:00:00	2020-10-05 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14357A	\N	2016-12-01 10:39:20	\N
2316	AUCUNSEN	2017-06-18 00:00:00	2018-11-03 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19251M	\N	2017-06-19 16:45:46	\N
2317	AUCUNSEN	2017-06-18 00:00:00	2018-11-16 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19253P	\N	2017-06-19 16:48:14	\N
2324	AUCUNSEN	2017-07-22 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19269X	\N	2017-07-24 10:01:14	\N
2319	AUCUNSEN	2017-06-15 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	16813M	\N	2017-06-19 17:55:47	2017-09-24 18:16:52
2134	AUCUNSEN	2012-06-17 00:00:00	2014-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	09010Q	\N	2014-04-23 09:57:24	2014-09-28 17:07:41
2135	VICPDTSEN	2014-04-29 00:00:00	2014-09-30 00:00:00	\N	3	ANCIEN	\N	\N	\N	\N	04046G	\N	2014-04-29 14:52:46	2014-09-28 17:07:41
2145	AUCUNSEN	2014-08-27 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14018U	\N	2014-08-27 16:32:46	2017-09-24 18:49:56
2157	AUCUNSEN	2014-10-01 00:00:00	2020-06-27 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14199E	\N	2014-09-28 14:31:41	\N
2211	AUCUNSEN	2014-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14251Q	\N	2014-09-28 18:32:19	\N
2213	AUCUNSEN	2014-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14121F	\N	2014-09-28 18:44:07	\N
2219	AUCUNSEN	2014-10-01 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14201E	\N	2014-09-28 18:59:41	\N
2243	AUCUNSEN	2014-10-01 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	01057W	\N	2014-10-08 00:00:00	\N
2244	AUCUNSEN	2014-10-01 00:00:00	2018-08-06 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	95015C	\N	2014-10-08 14:41:05	\N
2245	AUCUNSEN	2014-10-01 00:00:00	2014-12-18 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	01062T	\N	2014-10-08 14:41:56	2014-12-18 16:15:04
2246	AUCUNSEN	2014-10-01 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	98024R	\N	2014-10-08 14:42:27	\N
2247	AUCUNSEN	2014-10-01 00:00:00	2017-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	08025T	\N	2014-10-08 14:42:47	2017-10-01 10:17:18
2248	AUCUNSEN	2014-10-01 00:00:00	2014-11-04 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	01052R	\N	2014-10-08 14:43:53	2014-11-04 11:22:47
2291	SECRETSEN	2015-03-17 00:00:00	2017-10-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	11110B	NON	2015-03-17 15:32:30	2017-10-04 15:45:52
2293	AUCUNSEN	2015-04-22 00:00:00	2017-06-04 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14273W	\N	2015-04-22 16:49:30	2017-06-07 09:38:00
2298	AUCUNSEN	2014-10-01 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	08049C	\N	2015-09-07 16:07:43	\N
2299	AUCUNSEN	2015-09-07 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14327T	\N	2015-09-07 16:16:32	2015-09-07 16:24:18
2304	AUCUNSEN	2016-05-13 00:00:00	2017-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04067M	NON	2016-05-24 14:59:55	2017-09-24 17:47:28
2312	AUCUNSEN	2017-06-18 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11069T	\N	2017-06-19 15:51:10	2017-09-24 18:05:41
2315	AUCUNSEN	2017-06-18 00:00:00	2020-10-05 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11045K	\N	2017-06-19 15:58:23	\N
2325	AUCUNSEN	2017-07-13 00:00:00	2023-10-01 00:00:00	NON	1	ANCIEN	\N	\N	\N	\N	04042C	NON	\N	2017-07-24 00:00:00
2331	AUCUNSEN	2017-09-23 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14029X	\N	2017-09-24 11:13:08	\N
2332	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19629C	\N	2017-09-24 00:00:00	\N
2333	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19507S	\N	2017-09-24 00:00:00	\N
2334	AUCUNSEN	2017-10-02 00:00:00	2017-11-02 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	01007L	\N	2017-09-24 13:20:36	2017-11-03 10:47:40
2343	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19443T	\N	2017-09-24 00:00:00	\N
2344	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19441R	\N	2017-09-24 00:00:00	\N
2345	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19515S	\N	2017-09-24 00:00:00	\N
2351	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19667J	\N	2017-09-24 00:00:00	\N
2352	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19669L	\N	2017-09-24 00:00:00	\N
2353	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19671E	\N	2017-09-24 00:00:00	\N
2354	AUCUNSEN	2017-10-02 00:00:00	2020-10-05 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19673G	\N	2017-09-24 17:15:14	\N
2357	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19551W	\N	2017-09-24 00:00:00	\N
2358	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19553Y	\N	2017-09-24 00:00:00	\N
2360	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19573D	\N	2017-09-24 00:00:00	\N
2361	AUCUNSEN	2017-10-02 00:00:00	2017-11-24 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19677L	\N	2017-09-24 17:29:36	2017-11-24 23:59:34
2362	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11115U	\N	2017-09-24 00:00:00	\N
2363	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19349W	\N	2017-09-24 00:00:00	\N
2364	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19679N	\N	2017-09-24 00:00:00	\N
2365	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19347U	\N	2017-09-24 00:00:00	\N
2376	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19335Q	\N	2017-09-24 00:00:00	\N
2377	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19685L	\N	2017-09-24 00:00:00	\N
2385	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19695N	\N	2017-09-24 00:00:00	\N
2386	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19663E	\N	2017-09-24 00:00:00	\N
2388	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14021P	\N	2017-09-24 00:00:00	\N
2389	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19637C	\N	2017-09-24 00:00:00	\N
2390	AUCUNSEN	2017-10-02 00:00:00	2020-10-05 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19599P	\N	2017-09-24 18:16:50	\N
2391	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	17589D	\N	2017-09-24 00:00:00	\N
2392	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19581D	\N	2017-09-24 00:00:00	\N
2393	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19569H	\N	2017-09-24 00:00:00	\N
2394	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19565D	\N	2017-09-24 00:00:00	\N
2395	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19585H	\N	2017-09-24 00:00:00	\N
2396	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	04008A	\N	2017-09-24 00:00:00	\N
1898	AUCUNSEN	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11035H	\N	\N	2017-09-24 18:16:52
2397	AUCUNSEN	2017-10-02 00:00:00	2020-09-29 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	04018C	\N	2017-09-24 18:17:55	\N
2398	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19697Q	\N	2017-09-24 00:00:00	\N
2399	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19699S	\N	2017-09-24 00:00:00	\N
2400	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19701S	\N	2017-09-24 00:00:00	\N
1892	AUCUNSEN	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11096W	\N	\N	2017-09-24 18:17:56
2403	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19415P	\N	2017-09-24 00:00:00	\N
2404	AUCUNSEN	2017-10-02 00:00:00	2020-10-05 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19413M	\N	2017-09-24 18:23:21	\N
2405	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19631V	\N	2017-09-24 00:00:00	\N
2534	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20026V	\N	\N	\N
2406	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	17779H	\N	2017-09-24 00:00:00	\N
2407	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19489J	\N	2017-09-24 00:00:00	\N
2409	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19703U	\N	2017-09-24 00:00:00	\N
2411	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19705W	\N	2017-09-24 00:00:00	\N
2412	AUCUNSEN	2017-10-02 00:00:00	2018-07-27 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19707Y	\N	2017-09-24 18:59:59	\N
2413	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19709B	\N	2017-09-24 00:00:00	\N
2414	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19503N	\N	2017-09-24 00:00:00	\N
2415	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19511N	\N	2017-09-24 00:00:00	\N
2417	AUCUNSEN	2017-10-02 00:00:00	2018-04-13 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19483C	\N	2017-09-24 19:17:41	2018-04-13 17:54:30
2424	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19479G	\N	2017-09-24 00:00:00	\N
2425	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19467C	\N	2017-09-24 00:00:00	\N
2429	AUCUNSEN	2017-09-25 00:00:00	2017-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	16431B	\N	2017-09-25 10:03:31	2017-10-01 10:37:45
2478	AUCUNSEN	2017-10-04 00:00:00	2023-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	11110B	NON	2017-10-04 00:00:00	\N
2472	AUCUNSEN	2017-10-04 00:00:00	2020-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08024S	NON	2017-10-04 15:55:01	\N
2473	AUCUNSEN	2017-10-04 00:00:00	2018-05-31 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	98053W	NON	2017-10-04 15:55:46	2018-05-31 10:52:17
2474	AUCUNSEN	2017-10-04 00:00:00	2023-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	11085T	NON	2017-10-04 00:00:00	\N
2475	AUCUNSEN	2017-10-04 00:00:00	2020-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08055A	NON	2017-10-04 15:56:18	\N
2476	AUCUNSEN	2017-10-04 00:00:00	2020-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	89017R	NON	2017-10-04 15:56:40	\N
2477	AUCUNSEN	2017-10-04 00:00:00	2020-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	95030B	NON	2017-10-04 15:57:06	\N
2479	AUCUNSEN	2017-10-04 00:00:00	2020-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08048B	NON	2017-10-04 15:59:07	\N
2480	AUCUNSEN	2017-10-04 00:00:00	2020-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	95037J	NON	2017-10-04 15:59:21	\N
2481	AUCUNSEN	2017-10-04 00:00:00	2023-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04057K	NON	2017-10-04 00:00:00	\N
2482	AUCUNSEN	2017-10-04 00:00:00	2022-12-31 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	92040Q	NON	2017-10-04 15:59:51	\N
2483	AUCUNSEN	2017-10-04 00:00:00	2020-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04088S	NON	2017-10-04 16:00:03	\N
2484	AUCUNSEN	2017-10-04 00:00:00	2023-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	11012A	NON	2017-10-04 00:00:00	\N
2485	AUCUNSEN	2017-10-04 00:00:00	2020-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08039A	NON	2017-10-04 16:02:17	2017-10-05 11:50:10
1569	AUCUNSEN	\N	2017-10-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04089T	NON	\N	2017-10-05 17:53:45
2497	VICPDTSEN	2018-11-01 00:00:00	2020-10-05 00:00:00	NON	8	ANCIEN	\N	\N	\N	\N	11027H	NON	\N	\N
2498	AUCUNSEN	2018-11-01 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11077T	\N	\N	\N
2502	AUCUNSEN	2018-12-06 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19251M	\N	\N	\N
2512	AUCUNSEN	2019-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19826F	\N	\N	\N
2513	AUCUNSEN	2020-03-04 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19866P	\N	\N	\N
2515	AUCUNSEN	2020-06-18 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19914E	\N	\N	\N
2528	AUCUNSEN	2020-09-25 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	20014R	\N	\N	\N
2529	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20016T	\N	\N	\N
2531	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20020P	\N	\N	\N
2535	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20028X	\N	\N	\N
2536	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20030R	\N	\N	\N
2132	AUCUNSEN	2014-01-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14001X	\N	2014-01-02 15:25:09	\N
2136	AUCUNSEN	2014-05-05 00:00:00	2014-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14012N	\N	2014-05-05 10:30:19	2014-09-28 16:54:10
2137	AUCUNSEN	2012-07-22 00:00:00	2014-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	04090L	\N	2014-05-05 10:31:01	2014-09-28 19:29:39
2138	AUCUNSEN	2012-07-22 00:00:00	2014-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	08064B	\N	2014-05-05 10:32:08	2014-09-28 19:03:23
2146	AUCUNSEN	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	83042R	\N	2014-09-01 10:22:08	2017-09-24 17:48:21
2148	AUCUNSEN	2014-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14193X	\N	2014-09-28 12:32:22	\N
2149	AUCUNSEN	2014-09-29 00:00:00	2023-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	14042U	NON	2014-09-28 00:00:00	2014-10-20 00:00:00
2150	AUCUNSEN	2014-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14195A	\N	2014-09-28 12:44:31	\N
2151	AUCUNSEN	2014-10-01 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14197C	\N	2014-09-28 12:54:15	\N
2152	AUCUNSEN	2014-10-01 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14103D	\N	2014-09-28 13:06:30	\N
2153	AUCUNSEN	2014-10-01 00:00:00	2017-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	05004A	\N	2014-09-28 13:16:32	2017-10-01 10:22:23
2158	AUCUNSEN	2014-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14030Q	\N	2014-09-28 16:40:49	\N
2159	AUCUNSEN	2014-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14031R	\N	2014-09-28 16:40:49	\N
2160	AUCUNSEN	2014-10-01 00:00:00	2015-06-12 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14137P	\N	2014-09-28 16:42:03	2015-06-12 15:59:18
2161	AUCUNSEN	2014-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14133K	\N	2014-09-28 16:42:03	\N
2162	AUCUNSEN	2014-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14105F	\N	2014-09-28 16:49:55	\N
2163	AUCUNSEN	2014-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14109K	\N	2014-09-28 16:49:55	\N
2164	AUCUNSEN	2014-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14205J	\N	2014-09-28 16:54:08	\N
2212	AUCUNSEN	2014-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14253S	\N	2014-09-28 18:32:41	\N
2249	AUCUNSEN	2014-10-01 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	08038Y	\N	2014-10-08 14:44:28	\N
2250	AUCUNSEN	2014-10-01 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	92018S	\N	2014-10-08 14:44:46	2017-09-24 18:16:52
2251	AUCUNSEN	2014-10-01 00:00:00	2017-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	08022Q	\N	2014-10-08 14:45:04	2017-10-01 09:41:22
2252	AUCUNSEN	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	04067M	\N	2014-10-08 14:45:20	2014-10-08 14:53:48
2253	AUCUNSEN	2014-10-01 00:00:00	2017-09-21 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	95031C	\N	2014-10-08 14:45:37	2017-09-22 10:42:23
2254	AUCUNSEN	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	01003G	\N	2014-10-08 14:46:15	2014-10-08 14:54:09
2255	AUCUNSEN	2014-10-01 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	04095R	\N	2014-10-08 14:46:45	2017-09-25 10:54:33
2256	AUCUNSEN	2014-10-01 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	01022K	\N	2014-10-08 14:47:05	2017-09-24 17:14:26
2257	AUCUNSEN	2014-10-01 00:00:00	2017-10-03 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11077T	\N	2014-10-08 14:47:32	2017-10-04 14:45:21
2258	AUCUNSEN	2014-10-01 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	04043D	\N	2014-10-08 00:00:00	\N
2259	VICPDTSEN	2014-10-08 00:00:00	2017-09-22 00:00:00	\N	2	ANCIEN	\N	\N	\N	\N	89029V	\N	2014-10-08 14:48:09	2017-09-24 11:09:53
2260	VICPDTSEN	2014-10-08 00:00:00	2017-10-03 00:00:00	NON	3	ANCIEN	\N	\N	\N	\N	08024S	NON	2014-10-08 14:48:32	2017-10-04 15:41:23
2261	VICPDTSEN	2014-10-08 00:00:00	2017-07-21 00:00:00	\N	4	ANCIEN	\N	\N	\N	\N	01007L	\N	2014-10-08 14:49:39	2017-07-24 09:56:26
2262	VICPDTSEN	2014-10-08 00:00:00	2017-10-03 00:00:00	NON	5	ANCIEN	\N	\N	\N	\N	98053W	NON	2014-10-08 14:49:50	2017-10-04 15:42:28
2263	VICPDTSEN	2014-10-08 00:00:00	2017-10-01 00:00:00	\N	6	ANCIEN	\N	\N	\N	\N	04081K	\N	2014-10-08 14:50:05	2017-09-24 19:25:10
2264	VICPDTSEN	2014-10-08 00:00:00	2017-10-01 00:00:00	\N	7	ANCIEN	\N	\N	\N	\N	04066L	\N	2014-10-08 14:50:15	2017-09-24 17:47:28
2265	VICPDTSEN	2014-10-08 00:00:00	2017-10-03 00:00:00	NON	8	ANCIEN	\N	\N	\N	\N	11085T	NON	2014-10-08 14:50:26	2017-10-04 15:44:45
2266	VICPDTSEN	2014-10-08 00:00:00	2017-10-03 00:00:00	NON	9	ANCIEN	\N	\N	\N	\N	08055A	NON	2014-10-08 14:50:35	2017-10-04 15:44:59
2267	QUESTESEN	2014-10-08 00:00:00	2017-10-01 00:00:00	\N	10	ANCIEN	\N	\N	\N	\N	01019Q	\N	2014-10-08 14:50:54	2017-09-24 17:35:15
2268	QUESTESEN	2014-10-08 00:00:00	2017-10-01 00:00:00	\N	11	ANCIEN	\N	\N	\N	\N	11039M	\N	2014-10-08 14:51:18	2017-09-24 18:16:52
2269	QUESTESEN	2014-10-08 00:00:00	2017-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	98042T	\N	2014-10-08 14:52:22	2017-10-01 10:39:23
2270	SECRETSEN	2014-10-08 00:00:00	2017-10-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	89017R	NON	2014-10-08 14:52:53	2017-10-04 15:45:12
2271	SECRETSEN	2014-10-08 00:00:00	2017-07-12 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04042C	NON	2014-10-08 14:53:34	2017-07-24 18:15:14
2272	SECRETSEN	2014-10-08 00:00:00	2016-05-12 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	04067M	\N	2014-10-08 14:53:47	2016-05-12 15:13:47
2273	SECRETSEN	2014-10-08 00:00:00	2015-03-03 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11051H	\N	2014-10-08 14:54:00	2015-03-03 10:16:55
2274	SECRETSEN	2014-10-08 00:00:00	2017-05-15 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	01003G	\N	2014-10-08 14:54:08	2017-05-16 15:18:13
2275	SECRETSEN	2014-10-08 00:00:00	2017-10-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08048B	NON	2014-10-08 14:54:46	2017-10-04 15:46:06
2276	SECRETSEN	2014-10-08 00:00:00	2017-10-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	95037J	NON	2014-10-08 14:55:07	2017-10-04 15:46:26
2277	SECRETSEN	2014-10-08 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	04094Q	\N	2014-10-08 14:55:22	2017-09-25 10:58:49
2278	SECRETSEN	2014-10-08 00:00:00	2017-10-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	08039A	NON	2014-10-08 14:55:36	2017-10-04 15:46:37
2279	SECRETSEN	2014-10-08 00:00:00	2017-10-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01043Q	NON	2014-10-08 14:55:51	2017-10-04 15:15:49
2280	SECRETSEN	2014-10-08 00:00:00	2017-10-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04057K	NON	2014-10-08 14:56:06	2017-10-04 15:46:51
2281	SECRETSEN	2014-10-08 00:00:00	2017-10-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	92040Q	NON	2014-10-08 14:56:21	2017-10-04 15:52:04
2282	SECRETSEN	2014-10-08 00:00:00	2017-10-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04088S	NON	2014-10-08 14:56:51	2017-10-04 15:47:15
2283	SECRETSEN	2014-10-08 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	04056J	\N	2014-10-08 14:57:10	2017-09-24 18:17:56
2288	AUCUNSEN	2015-01-26 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14267Y	\N	2015-01-26 00:00:00	\N
2296	AUCUNSEN	2015-06-12 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14281W	\N	2015-06-12 15:35:57	\N
2309	AUCUNSEN	2017-01-01 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14363X	\N	2017-01-03 11:10:58	2017-09-24 19:25:10
2310	AUCUNSEN	2017-05-15 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14365A	\N	2017-05-16 16:19:32	2017-09-24 12:39:59
2311	AUCUNSEN	2017-06-05 00:00:00	2017-06-14 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	07028S	\N	2017-06-07 15:17:54	2017-06-19 16:13:09
2313	AUCUNSEN	2017-06-18 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11041F	\N	2017-06-19 00:00:00	\N
2314	AUCUNSEN	2017-06-18 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	01062T	\N	2017-06-19 00:00:00	\N
2328	AUCUNSEN	2017-09-22 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	15447F	\N	2017-09-22 10:59:04	\N
2339	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19333N	\N	2017-09-24 00:00:00	\N
2342	AUCUNSEN	2017-10-02 00:00:00	2020-10-31 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	17583W	\N	2017-09-24 17:04:01	\N
2346	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19545Y	\N	2017-09-24 00:00:00	\N
2347	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19549D	\N	2017-09-24 00:00:00	\N
2348	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19533U	\N	2017-09-24 00:00:00	\N
2349	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	16685X	\N	2017-09-24 00:00:00	\N
2350	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19447X	\N	2017-09-24 00:00:00	\N
2355	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19675J	\N	2017-09-24 00:00:00	\N
2356	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19543W	\N	2017-09-24 00:00:00	\N
2359	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19421M	\N	2017-09-24 00:00:00	\N
2366	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19527W	\N	2017-09-24 00:00:00	\N
2367	AUCUNSEN	2017-10-02 00:00:00	2021-12-07 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19521Q	\N	2017-09-24 17:42:25	\N
2368	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19525U	\N	2017-09-24 00:00:00	\N
2369	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19681G	\N	2017-09-24 00:00:00	\N
2370	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19649G	\N	2017-09-24 00:00:00	\N
2371	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	07033P	\N	2017-09-24 00:00:00	\N
2372	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19651A	\N	2017-09-24 00:00:00	\N
2373	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19643A	\N	2017-09-24 00:00:00	\N
2374	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19683J	\N	2017-09-24 00:00:00	\N
2375	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19647E	\N	2017-09-24 00:00:00	\N
2378	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19687N	\N	2017-09-24 00:00:00	\N
2379	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19611R	\N	2017-09-24 00:00:00	\N
2380	AUCUNSEN	2017-10-02 00:00:00	2022-07-03 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19689Q	\N	2017-09-24 17:55:12	\N
2381	AUCUNSEN	2017-10-02 00:00:00	2022-02-02 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19289C	\N	2017-09-24 18:05:40	\N
2382	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19691J	\N	2017-09-24 00:00:00	\N
2383	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19399H	\N	2017-09-24 00:00:00	\N
2384	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19693L	\N	2017-09-24 00:00:00	\N
2387	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19329S	\N	2017-09-24 00:00:00	\N
2401	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19387D	\N	2017-09-24 00:00:00	\N
2402	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19383Y	\N	2017-09-24 00:00:00	\N
2408	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	18083K	\N	2017-09-24 00:00:00	\N
2410	AUCUNSEN	2017-09-25 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19575F	\N	2017-09-24 18:51:50	\N
2133	AUCUNSEN	2014-02-14 00:00:00	2014-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14002L	\N	2014-02-14 15:15:52	2014-09-28 18:32:43
2196	AUCUNSEN	2014-10-01 00:00:00	2015-02-12 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14233N	\N	2014-09-28 17:35:38	2015-02-12 15:03:17
2197	AUCUNSEN	2014-10-01 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14235Q	\N	2014-09-28 17:38:25	\N
2198	AUCUNSEN	2014-10-01 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14157T	\N	2014-09-28 17:38:25	\N
2206	AUCUNSEN	2014-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14187A	\N	2014-09-28 17:58:04	\N
2207	AUCUNSEN	2014-10-01 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14051J	\N	2014-09-28 18:00:57	\N
2208	AUCUNSEN	2014-10-01 00:00:00	2017-10-03 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14053L	\N	2014-09-28 18:00:57	2017-10-04 14:47:11
2209	AUCUNSEN	2014-10-01 00:00:00	2017-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14247U	\N	2014-09-28 18:03:38	2017-10-01 10:25:16
2217	AUCUNSEN	2014-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14151M	\N	2014-09-28 18:58:20	\N
2221	AUCUNSEN	2014-10-01 00:00:00	2023-10-03 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14111D	\N	2014-09-28 00:00:00	\N
2222	AUCUNSEN	2014-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14071N	\N	2014-09-28 19:05:58	\N
2223	AUCUNSEN	2014-10-01 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14119M	\N	2014-09-28 19:05:58	\N
2233	AUCUNSEN	2014-10-01 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14261S	\N	2014-09-29 09:03:10	\N
2234	AUCUNSEN	2014-10-01 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14039A	\N	2014-09-29 09:05:47	\N
2235	AUCUNSEN	2014-10-01 00:00:00	2015-02-06 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14043V	\N	2014-09-29 09:08:32	2015-02-06 14:27:55
2236	AUCUNSEN	2014-10-01 00:00:00	2015-02-06 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14044W	\N	2014-09-29 09:08:32	2015-02-06 14:32:44
2238	AUCUNSEN	2014-10-01 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	04077P	\N	2014-10-08 14:38:21	2017-09-24 17:47:27
2239	AUCUNSEN	2014-10-01 00:00:00	2017-10-04 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	95059Q	NON	2014-10-08 14:38:59	2017-10-05 09:34:31
2240	AUCUNSEN	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	98053W	\N	2014-10-08 14:39:23	2014-10-08 14:49:51
2241	AUCUNSEN	2014-10-01 00:00:00	2014-10-07 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	98042T	\N	2014-10-08 14:39:42	2014-10-08 14:52:23
2242	AUCUNSEN	2014-10-01 00:00:00	2015-06-12 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	95020Y	\N	2014-10-08 14:40:05	2015-06-12 16:01:25
2285	AUCUNSEN	2014-12-19 00:00:00	2014-12-21 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	01062T	NON	2014-12-18 16:23:55	2015-01-05 16:10:04
2290	AUCUNSEN	2015-03-04 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14269B	\N	2015-03-04 14:32:20	2017-09-24 18:07:57
2297	AUCUNSEN	2015-06-12 00:00:00	2020-10-05 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14147R	\N	2015-06-12 15:40:17	\N
2302	AUCUNSEN	2011-10-01 00:00:00	2017-06-17 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	04050C	\N	2016-03-11 18:10:19	2017-06-19 16:03:48
2303	SECRETSEN	2016-05-12 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11029K	\N	2016-05-12 15:13:54	2017-09-24 17:09:24
2305	AUCUNSEN	2016-11-13 00:00:00	2017-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	05001W	NON	2016-11-14 18:40:41	2017-09-24 16:24:51
2321	SECRETSEN	2017-07-06 00:00:00	2017-10-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	11012A	NON	2017-07-06 10:38:52	2017-10-04 15:47:27
2330	AUCUNSEN	2017-09-23 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14115H	\N	2017-09-24 11:11:57	\N
2323	SECRETSEN	2017-07-13 00:00:00	2017-10-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	95030B	NON	2017-07-13 14:47:06	2017-10-04 15:45:30
2416	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19563B	\N	2017-09-24 00:00:00	\N
2418	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19369B	\N	2017-09-24 00:00:00	\N
2419	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19367Y	\N	2017-09-24 00:00:00	\N
2420	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	17637T	\N	2017-09-24 00:00:00	\N
2421	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19711U	\N	2017-09-24 00:00:00	\N
2422	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19591F	\N	2017-09-24 00:00:00	\N
2423	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19593H	\N	2017-09-24 00:00:00	\N
2426	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19531S	\N	2017-09-24 00:00:00	\N
2427	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19713W	\N	2017-09-24 00:00:00	\N
2428	AUCUNSEN	2017-09-25 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	08045X	\N	2017-09-25 09:57:06	\N
2430	AUCUNSEN	2017-10-02 00:00:00	2021-10-04 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19301E	\N	2017-09-25 10:54:33	\N
2431	AUCUNSEN	2017-10-02 00:00:00	2020-10-05 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19715Y	\N	2017-09-25 10:54:33	\N
2432	AUCUNSEN	2017-10-02 00:00:00	2017-10-03 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	12016W	\N	2017-09-25 10:54:33	2017-10-04 14:49:31
2433	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19717B	\N	2017-09-25 00:00:00	\N
2434	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19295A	\N	2017-09-25 00:00:00	\N
2435	AUCUNSEN	2017-10-01 00:00:00	2020-10-05 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19719D	\N	2017-10-01 09:26:48	\N
2487	AUCUNSEN	2017-11-25 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19741B	\N	2017-11-24 00:00:00	\N
2488	AUCUNSEN	2017-12-18 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19745F	\N	2017-12-18 14:31:40	\N
2489	AUCUNSEN	2017-12-18 00:00:00	2023-12-31 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19747H	\N	2017-12-18 00:00:00	\N
2490	AUCUNSEN	2017-12-18 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19749K	\N	2017-12-18 14:52:08	\N
2491	AUCUNSEN	2018-06-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19758L	\N	2018-05-31 11:00:21	\N
2492	AUCUNSEN	2018-07-01 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19760E	\N	\N	\N
2493	AUCUNSEN	2018-07-01 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19762G	\N	\N	\N
2506	SECRETSEN	2019-04-01 00:00:00	2021-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04045F	NON	\N	\N
2504	AUCUNSEN	2019-03-04 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19253P	\N	\N	\N
2505	AUCUNSEN	2019-03-04 00:00:00	2023-10-03 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19798U	\N	\N	\N
2507	AUCUNSEN	2019-04-01 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14241N	\N	\N	\N
2508	AUCUNSEN	2019-06-24 00:00:00	2020-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04069P	NON	\N	\N
2520	AUCUNSEN	2020-07-14 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19954N	\N	\N	\N
2517	AUCUNSEN	2020-06-25 00:00:00	2020-06-25 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19920C	\N	\N	\N
2525	AUCUNSEN	2020-08-04 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19968U	\N	\N	\N
2526	AUCUNSEN	2020-08-07 00:00:00	2020-08-07 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	08016S	\N	\N	\N
2530	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20018V	\N	\N	\N
2538	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20034V	\N	\N	\N
2541	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20038A	\N	\N	\N
2585	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20114U	\N	\N	\N
2586	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20116W	\N	\N	\N
2587	AUCUNSEN	2020-10-01 00:00:00	2020-10-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19265T	\N	\N	\N
2588	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20118Y	\N	\N	\N
2589	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20120S	\N	\N	\N
2590	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20122U	\N	\N	\N
2591	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20124W	\N	\N	\N
2592	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20126Y	\N	\N	\N
2593	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20128B	\N	\N	\N
2594	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20130U	\N	\N	\N
2595	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	17367Q	\N	\N	\N
2596	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20132W	\N	\N	\N
2597	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20134Y	\N	\N	\N
2598	AUCUNSEN	2020-10-01 00:00:00	2023-10-03 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	20136B	\N	\N	\N
2599	AUCUNSEN	2020-10-01 00:00:00	2023-10-03 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	20138D	\N	\N	\N
2600	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20140W	\N	\N	\N
2601	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20142Y	\N	\N	\N
2603	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	17965H	\N	\N	\N
2607	AUCUNSEN	2020-10-01 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	20152B	\N	\N	\N
2629	SECRETSEN	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19673G	\N	\N	\N
2630	SECRETSEN	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	01025N	\N	\N	\N
2631	SECRETSEN	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19599P	\N	\N	\N
2632	SECRETSEN	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14033T	\N	\N	\N
2633	SECRETSEN	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14123H	\N	\N	\N
2634	SECRETSEN	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14179A	\N	\N	\N
2635	SECRETSEN	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14213J	\N	\N	\N
2636	SECRETSEN	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19715Y	\N	\N	\N
2637	SECRETSEN	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14147R	\N	\N	\N
2638	SECRETSEN	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19413M	\N	\N	\N
2639	AUCUNSEN	2020-10-06 00:00:00	\N	NON	\N	ACTIF	\N	\N	\N	\N	05012A	NON	\N	\N
2640	AUCUNSEN	2020-11-01 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	20172F	\N	\N	\N
2641	AUCUNSEN	2020-11-02 00:00:00	2022-06-20 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	20174H	\N	\N	\N
2642	AUCUNSEN	2020-11-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14249W	\N	\N	\N
2643	AUCUNSEN	2020-12-01 00:00:00	2020-12-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	20176K	\N	\N	\N
2644	AUCUNSEN	2020-12-02 00:00:00	2020-12-03 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	20178M	\N	\N	\N
2645	AUCUNSEN	2020-12-04 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	20180F	\N	\N	\N
2646	AUCUNSEN	2021-07-06 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20248J	\N	\N	\N
2647	AUCUNSEN	2021-07-28 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	20252E	\N	\N	\N
2648	AUCUNSEN	2021-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19707Y	\N	\N	\N
2649	AUCUNSEN	2021-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19057M	\N	\N	\N
2650	AUCUNSEN	2021-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20264J	\N	\N	\N
2651	AUCUNSEN	2021-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20266L	\N	\N	\N
2147	AUCUNSEN	2014-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14191V	\N	2014-09-28 12:09:44	\N
2154	AUCUNSEN	2014-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14097Y	\N	2014-09-28 13:32:34	\N
2168	AUCUNSEN	2014-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14083S	\N	2014-09-28 17:00:59	\N
2169	AUCUNSEN	2014-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14207L	\N	2014-09-28 17:03:41	\N
2170	AUCUNSEN	2014-10-01 00:00:00	2017-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14209N	\N	2014-09-28 17:03:41	2017-10-01 10:34:22
2171	AUCUNSEN	2014-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14211G	\N	2014-09-28 17:03:41	\N
2174	AUCUNSEN	2014-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14059S	\N	2014-09-28 17:07:07	\N
2179	AUCUNSEN	2014-10-01 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14093U	\N	2014-09-28 17:09:16	\N
2180	AUCUNSEN	2014-10-01 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14063N	\N	2014-09-28 17:09:16	\N
2214	AUCUNSEN	2014-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14255U	\N	2014-09-28 18:46:12	\N
2215	AUCUNSEN	2014-10-01 00:00:00	2017-10-03 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14041T	\N	2014-09-28 18:46:12	2017-10-04 14:47:36
2224	AUCUNSEN	2014-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14257W	\N	2014-09-28 19:07:43	\N
2228	AUCUNSEN	2014-10-01 00:00:00	2017-10-03 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14034U	\N	2014-09-28 19:19:39	2017-10-04 14:44:51
2229	AUCUNSEN	2014-10-01 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14028W	\N	2014-09-28 19:19:39	\N
2231	AUCUNSEN	2014-10-01 00:00:00	2017-06-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14175V	\N	2014-09-28 19:29:38	2017-06-02 10:02:56
2284	AUCUNSEN	2014-12-22 00:00:00	2017-06-17 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14263U	\N	2014-12-18 16:18:16	2017-06-19 16:04:13
2292	AUCUNSEN	2015-04-08 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14271U	\N	2015-04-07 17:15:52	2017-09-24 17:06:55
2301	AUCUNSEN	2016-01-12 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14331P	\N	2016-01-12 00:00:00	\N
2320	AUCUNSEN	2017-07-04 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	18127E	\N	2017-07-04 15:35:17	2017-09-24 18:16:52
2326	AUCUNSEN	2017-07-29 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19285X	\N	2017-07-31 12:02:13	2017-09-24 17:55:12
2327	AUCUNSEN	2017-08-07 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	12035A	\N	2017-08-07 17:15:07	2017-09-24 17:18:03
2340	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19619A	\N	2017-09-24 00:00:00	\N
2341	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19621T	\N	2017-09-24 00:00:00	\N
2436	AUCUNSEN	2017-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19721W	\N	2017-10-01 09:45:12	\N
2437	AUCUNSEN	2017-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19723Y	\N	2017-10-01 10:06:58	\N
2438	AUCUNSEN	2017-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19725B	\N	2017-10-01 10:44:23	\N
2439	AUCUNSEN	2017-10-01 00:00:00	2020-06-24 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19727D	\N	2017-10-01 10:54:01	\N
2440	AUCUNSEN	2017-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19729F	\N	2017-10-01 11:03:20	\N
2441	AUCUNSEN	2017-10-01 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19731Y	\N	2017-10-01 11:13:13	\N
2442	AUCUNSEN	2017-10-01 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	08020N	\N	2017-10-01 11:33:45	\N
2443	AUCUNSEN	2017-10-01 00:00:00	2020-06-17 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19733B	\N	2017-10-01 11:41:24	\N
2444	AUCUNSEN	2017-10-01 00:00:00	2023-10-03 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19735D	\N	2017-10-01 00:00:00	\N
2445	AUCUNSEN	2017-10-01 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19737F	\N	2017-10-01 11:57:14	\N
2446	VICPDTSEN	2017-10-04 00:00:00	2020-10-05 00:00:00	\N	2	ANCIEN	\N	\N	\N	\N	04086Q	\N	2017-10-04 14:44:28	2017-10-04 14:44:33
2447	VICPDTSEN	2017-10-04 00:00:00	2020-10-05 00:00:00	\N	3	ANCIEN	\N	\N	\N	\N	04059M	\N	2017-10-04 14:44:36	2017-10-04 14:44:40
2448	VICPDTSEN	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	4	ANCIEN	\N	\N	\N	\N	01043Q	\N	2017-10-04 00:00:00	2017-10-04 00:00:00
2449	VICPDTSEN	2017-10-04 00:00:00	2020-09-30 00:00:00	\N	5	ANCIEN	\N	\N	\N	\N	14034U	\N	2017-10-04 14:44:51	2017-10-04 14:44:54
2450	VICPDTSEN	2017-10-04 00:00:00	2020-10-05 00:00:00	\N	6	ANCIEN	\N	\N	\N	\N	11072N	\N	2017-10-04 14:44:59	2017-10-04 14:45:02
1962	AUCUNSEN	2011-10-01 00:00:00	2017-10-03 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11072N	\N	\N	2017-10-04 14:44:59
2451	VICPDTSEN	2017-10-04 00:00:00	2020-09-30 00:00:00	\N	7	ANCIEN	\N	\N	\N	\N	04044E	\N	2017-10-04 14:45:11	2017-10-04 14:45:15
2452	VICPDTSEN	2017-10-04 00:00:00	2018-10-31 00:00:00	\N	8	ANCIEN	\N	\N	\N	\N	11077T	\N	2017-10-04 14:45:21	2017-10-04 14:45:25
2453	VICPDTSEN	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	9	ANCIEN	\N	\N	\N	\N	11070L	\N	2017-10-04 00:00:00	2017-10-04 00:00:00
1889	AUCUNSEN	2011-10-01 00:00:00	2017-10-03 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11070L	\N	\N	2017-10-04 14:45:28
2454	QUESTESEN	2017-10-04 00:00:00	2020-10-05 00:00:00	\N	10	ANCIEN	\N	\N	\N	\N	05012A	\N	2017-10-04 14:45:37	2017-10-04 14:45:43
2455	QUESTESEN	2017-10-04 00:00:00	2020-09-30 00:00:00	\N	11	ANCIEN	\N	\N	\N	\N	14159V	\N	2017-10-04 14:45:47	2017-10-04 14:46:10
2456	QUESTESEN	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	12	ANCIEN	\N	\N	\N	\N	11053K	\N	2017-10-04 00:00:00	2017-10-04 00:00:00
2457	SECRETSEN	2017-10-04 00:00:00	2020-10-05 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11040E	\N	2017-10-04 14:46:48	2017-10-04 14:46:52
1904	AUCUNSEN	2011-10-01 00:00:00	2017-10-03 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11040E	\N	\N	2017-10-04 14:46:48
2458	SECRETSEN	2017-10-04 00:00:00	2020-10-05 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14053L	\N	2017-10-04 14:47:11	2017-10-04 14:47:15
2459	SECRETSEN	2017-10-04 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	08052W	\N	2017-10-04 14:47:20	2017-10-04 14:47:23
2460	SECRETSEN	2017-10-04 00:00:00	2020-10-05 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	10006L	\N	2017-10-04 14:47:28	2017-10-04 14:47:32
2461	SECRETSEN	2017-10-04 00:00:00	2020-10-05 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14041T	\N	2017-10-04 14:47:36	2017-10-04 14:47:40
2462	SECRETSEN	2017-10-04 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	04089T	\N	2017-10-04 14:47:49	2017-10-04 14:47:53
2463	SECRETSEN	2017-10-04 00:00:00	2020-10-05 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14231L	\N	2017-10-04 14:47:59	2017-10-04 14:48:02
2464	SECRETSEN	2017-10-04 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11064N	\N	2017-10-04 00:00:00	2017-10-04 00:00:00
2011	AUCUNSEN	2011-10-01 00:00:00	2017-10-03 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11064N	\N	\N	2017-10-04 14:48:11
2465	SECRETSEN	2017-10-04 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14081Q	\N	2017-10-04 14:48:28	2017-10-04 14:48:31
2466	SECRETSEN	2017-10-04 00:00:00	2019-03-31 00:00:00	NON	\N	ANCIEN	\N	\N	\N	Conformément à l'accord intervenu entre les présidents des groupes politiques, Mme Patricia SCHILLINGER remplacera Mme Mireille JOUVE en qualité de Secrétaire du Sénat à compter du 1er avril 2019, à 0 heure	14241N	NON	2017-10-04 14:48:39	2017-10-04 14:48:42
2467	SECRETSEN	2017-10-04 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14061L	\N	2017-10-04 14:48:48	2017-10-04 14:50:24
2468	SECRETSEN	2017-10-04 00:00:00	2020-10-05 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	08034U	\N	2017-10-04 14:49:14	2017-10-04 14:49:24
2469	SECRETSEN	2017-10-04 00:00:00	2020-10-05 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	12016W	\N	2017-10-04 14:49:31	2017-10-04 14:49:35
2470	SECRETSEN	2017-10-04 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14135M	\N	2017-10-04 14:49:43	2017-10-04 14:49:47
2486	AUCUNSEN	2017-11-03 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19739H	\N	2017-11-03 00:00:00	\N
2499	AUCUNSEN	2018-11-04 00:00:00	2018-12-05 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	99002P	\N	\N	\N
2524	AUCUNSEN	2020-08-03 00:00:00	2021-07-04 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19966S	\N	\N	\N
2511	AUCUNSEN	2019-08-28 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19820Y	\N	\N	\N
2514	AUCUNSEN	2020-06-16 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19912C	\N	\N	\N
2602	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20144B	\N	\N	\N
2604	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20146D	\N	\N	\N
2605	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20148F	\N	\N	\N
2606	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20150Y	\N	\N	\N
2608	VICPDTSEN	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	2	ANCIEN	\N	\N	\N	\N	99004R	\N	\N	\N
2609	VICPDTSEN	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	3	ANCIEN	\N	\N	\N	\N	11045K	\N	\N	\N
2610	VICPDTSEN	2020-10-06 00:00:00	2022-03-31 00:00:00	NON	5	ANCIEN	\N	\N	\N	\N	08073C	NON	\N	\N
2611	VICPDTSEN	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	6	ANCIEN	\N	\N	\N	\N	12041X	\N	\N	\N
2113	AUCUNSEN	2012-09-20 00:00:00	2020-10-05 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	12041X	NON	\N	\N
2612	VICPDTSEN	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	7	ANCIEN	\N	\N	\N	\N	19719D	\N	\N	\N
2613	VICPDTSEN	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	8	ANCIEN	\N	\N	\N	\N	14026U	\N	\N	\N
2614	AUCUNSEN	2020-10-06 00:00:00	2021-07-27 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04086Q	NON	\N	\N
2615	AUCUNSEN	2020-10-06 00:00:00	2023-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	11027H	NON	\N	\N
2616	AUCUNSEN	2020-10-06 00:00:00	2023-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04059M	NON	\N	\N
2617	AUCUNSEN	2020-10-06 00:00:00	2023-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	11072N	NON	\N	\N
2618	AUCUNSEN	2020-10-06 00:00:00	2023-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	11040E	NON	\N	\N
2619	AUCUNSEN	2020-10-06 00:00:00	\N	NON	\N	ACTIF	\N	\N	\N	\N	14053L	NON	\N	\N
2620	AUCUNSEN	2020-10-06 00:00:00	2023-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	10006L	NON	\N	\N
2621	AUCUNSEN	2020-10-06 00:00:00	2021-09-30 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	14041T	NON	\N	\N
2622	AUCUNSEN	2020-10-06 00:00:00	\N	NON	\N	ACTIF	\N	\N	\N	\N	14231L	NON	\N	\N
2623	AUCUNSEN	2020-10-06 00:00:00	\N	NON	\N	ACTIF	\N	\N	\N	\N	08034U	NON	\N	\N
2624	AUCUNSEN	2020-10-06 00:00:00	2023-10-01 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	12016W	NON	\N	\N
2625	QUESTESEN	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	10	ANCIEN	\N	\N	\N	\N	05008E	\N	\N	\N
2626	QUESTESEN	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	11	ANCIEN	\N	\N	\N	\N	01028R	\N	\N	\N
2627	SECRETSEN	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11033F	\N	\N	\N
2628	SECRETSEN	2020-10-06 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14357A	\N	\N	\N
2139	AUCUNSEN	2012-06-17 00:00:00	2017-08-06 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	04053F	\N	2014-05-05 10:37:45	2017-08-07 16:31:39
2140	AUCUNSEN	2012-07-22 00:00:00	2018-10-31 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11027H	\N	2014-05-05 10:40:21	\N
2141	AUCUNSEN	2014-05-09 00:00:00	2017-06-17 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14013P	\N	2014-05-09 11:29:04	2017-06-19 16:06:01
2142	AUCUNSEN	2014-05-09 00:00:00	2017-06-17 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14014Q	\N	2014-05-09 11:37:36	2017-06-19 16:06:51
2143	AUCUNSEN	2014-04-29 00:00:00	2018-11-16 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	08016S	\N	2014-05-09 16:44:06	\N
2144	AUCUNSEN	2014-06-25 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14017T	\N	2014-06-25 15:52:44	2017-09-24 16:24:51
2155	AUCUNSEN	2014-10-01 00:00:00	2017-10-03 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14135M	\N	2014-09-28 13:40:32	2017-10-04 14:49:44
2156	AUCUNSEN	2002-06-19 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	95041E	\N	2014-09-28 13:40:32	\N
2165	AUCUNSEN	2014-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14173T	\N	2014-09-28 16:59:40	\N
2166	AUCUNSEN	2014-10-01 00:00:00	2017-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14167V	\N	2014-09-28 16:59:40	2017-10-01 10:18:28
2167	AUCUNSEN	2014-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14169X	\N	2014-09-28 16:59:40	\N
2172	AUCUNSEN	2014-10-01 00:00:00	2020-10-05 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14213J	\N	2014-09-28 17:05:42	\N
2173	AUCUNSEN	2014-10-01 00:00:00	2017-10-03 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14159V	\N	2014-09-28 17:05:42	2017-10-04 14:45:47
2175	AUCUNSEN	2014-10-01 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14087W	\N	2014-09-28 17:07:40	\N
2176	AUCUNSEN	2014-04-24 00:00:00	2017-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	95049N	\N	2014-09-28 17:07:40	2017-10-01 10:42:05
2177	AUCUNSEN	2014-10-01 00:00:00	2017-10-03 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14081Q	\N	2014-09-28 17:07:40	2017-10-04 14:48:28
2178	AUCUNSEN	2014-10-01 00:00:00	2023-10-03 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14215L	\N	2014-09-28 00:00:00	\N
2181	AUCUNSEN	2014-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14217N	\N	2014-09-28 17:12:40	\N
2182	AUCUNSEN	2014-10-01 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14079W	\N	2014-09-28 17:14:20	\N
2183	AUCUNSEN	2014-10-01 00:00:00	2020-10-05 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14026U	\N	2014-09-28 17:15:41	\N
2184	AUCUNSEN	2014-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14219Q	\N	2014-09-28 17:22:10	\N
2185	AUCUNSEN	2014-10-01 00:00:00	2020-10-05 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14123H	\N	2014-09-28 17:22:10	\N
2186	AUCUNSEN	2014-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14038Y	\N	2014-09-28 17:27:28	\N
2187	AUCUNSEN	2014-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14221J	\N	2014-09-28 17:27:34	\N
2188	AUCUNSEN	2014-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14223L	\N	2014-09-28 17:27:34	\N
2189	AUCUNSEN	2014-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14225N	\N	2014-09-28 17:27:34	\N
2190	AUCUNSEN	2014-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14073Q	\N	2014-09-28 17:31:41	\N
2191	AUCUNSEN	2014-10-01 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14065Q	\N	2014-09-28 17:31:41	\N
2192	AUCUNSEN	2014-10-01 00:00:00	2017-10-03 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14061L	\N	2014-09-28 17:31:41	2017-10-04 14:48:48
2193	AUCUNSEN	2014-10-01 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14227Q	\N	2014-09-28 17:34:15	\N
2194	AUCUNSEN	2014-10-01 00:00:00	2023-10-03 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14229S	\N	2014-09-28 00:00:00	\N
2195	AUCUNSEN	2014-10-01 00:00:00	2017-10-03 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14231L	\N	2014-09-28 17:34:15	2017-10-04 14:47:59
2199	AUCUNSEN	2014-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14237S	\N	2014-09-28 17:40:23	\N
2200	AUCUNSEN	2014-10-01 00:00:00	2020-10-05 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14179A	\N	2014-09-28 17:40:23	\N
2201	AUCUNSEN	2014-10-01 00:00:00	2020-08-02 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14239U	\N	2014-09-28 17:52:17	\N
2202	AUCUNSEN	2014-10-01 00:00:00	2017-10-03 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14241N	\N	2014-09-28 17:52:17	2017-10-04 14:48:39
2203	AUCUNSEN	2014-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14055N	\N	2014-09-28 17:52:17	\N
2287	AUCUNSEN	2011-10-01 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	92045V	\N	2015-01-09 15:16:59	2017-09-24 17:29:37
2294	AUCUNSEN	2015-05-04 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14275Y	\N	2015-05-04 10:27:12	\N
2210	AUCUNSEN	2014-10-01 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14249W	\N	2014-09-28 18:19:47	\N
2216	AUCUNSEN	2014-10-01 00:00:00	2020-10-05 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14033T	\N	2014-09-28 18:47:00	\N
2218	AUCUNSEN	2014-10-01 00:00:00	2017-07-22 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14037X	\N	2014-09-28 18:58:25	2017-07-24 09:58:00
2220	AUCUNSEN	2014-10-01 00:00:00	2023-10-03 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14069U	\N	2014-09-28 00:00:00	\N
2225	AUCUNSEN	2014-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14107H	\N	2014-09-28 19:09:43	\N
2226	AUCUNSEN	2014-10-01 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14085U	\N	2014-09-28 19:13:08	\N
2227	AUCUNSEN	2014-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14089Y	\N	2014-09-28 19:13:08	\N
2230	AUCUNSEN	2014-10-01 00:00:00	2023-10-03 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14259Y	\N	2014-09-28 00:00:00	\N
2232	AUCUNSEN	2014-10-01 00:00:00	2014-12-27 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14129P	\N	2014-09-28 19:45:29	2014-12-29 15:40:09
2295	AUCUNSEN	2015-05-04 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14277B	\N	2015-05-04 10:29:04	\N
2300	AUCUNSEN	2015-10-12 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14329V	\N	2015-10-12 00:00:00	\N
2308	AUCUNSEN	2016-12-11 00:00:00	2017-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14361V	\N	2016-12-12 15:59:30	2017-09-24 18:23:22
2329	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19319Q	\N	2017-09-24 00:00:00	\N
2335	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19657G	\N	2017-09-24 00:00:00	\N
2336	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19659J	\N	2017-09-24 00:00:00	\N
2337	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19577H	\N	2017-09-24 00:00:00	\N
2338	AUCUNSEN	2017-10-02 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19583F	\N	2017-09-24 00:00:00	\N
2494	AUCUNSEN	2018-07-28 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19766L	\N	\N	\N
2495	AUCUNSEN	2018-08-07 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19768N	\N	\N	\N
2500	AUCUNSEN	2018-11-17 00:00:00	2019-03-03 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	08051V	\N	\N	\N
2501	AUCUNSEN	2018-11-17 00:00:00	2020-08-06 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19782L	\N	\N	\N
2503	AUCUNSEN	2018-12-31 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19794Q	\N	\N	\N
2509	AUCUNSEN	2019-07-01 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19812Y	\N	\N	\N
2518	AUCUNSEN	2020-06-26 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19926J	\N	\N	\N
2519	AUCUNSEN	2020-06-28 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19930E	\N	\N	\N
2521	AUCUNSEN	2020-08-03 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19958S	\N	\N	\N
2527	AUCUNSEN	2020-08-08 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19782L	\N	\N	\N
2537	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20032T	\N	\N	\N
2539	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20036X	\N	\N	\N
2540	AUCUNSEN	2020-10-01 00:00:00	2023-10-03 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14189C	\N	\N	\N
2542	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20040T	\N	\N	\N
2543	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20042V	\N	\N	\N
2544	AUCUNSEN	2020-10-01 00:00:00	2020-11-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14037X	\N	\N	\N
2545	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20044X	\N	\N	\N
2546	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20046A	\N	\N	\N
2547	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20048C	\N	\N	\N
2548	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20050V	\N	\N	\N
2549	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20052X	\N	\N	\N
2550	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20054A	\N	\N	\N
2551	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20056C	\N	\N	\N
2552	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20058E	\N	\N	\N
2553	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20060X	\N	\N	\N
2554	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20062A	\N	\N	\N
2555	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	17229F	\N	\N	\N
2556	AUCUNSEN	2020-10-01 00:00:00	2023-10-03 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	20064C	\N	\N	\N
2557	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20066E	\N	\N	\N
2558	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20068G	\N	\N	\N
2559	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20070A	\N	\N	\N
2560	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20072C	\N	\N	\N
2561	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20074E	\N	\N	\N
2562	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20076G	\N	\N	\N
2563	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20078J	\N	\N	\N
2564	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	17023S	\N	\N	\N
2565	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20080C	\N	\N	\N
2566	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20082E	\N	\N	\N
2289	AUCUNSEN	2014-10-01 00:00:00	2020-09-30 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	87003B	\N	2015-02-12 15:04:38	\N
2567	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20084G	\N	\N	\N
2568	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20086J	\N	\N	\N
2569	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20088L	\N	\N	\N
2570	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20090E	\N	\N	\N
2571	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20092G	\N	\N	\N
2572	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20094J	\N	\N	\N
2573	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20096L	\N	\N	\N
2574	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20098N	\N	\N	\N
2575	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20100N	\N	\N	\N
2576	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20102Q	\N	\N	\N
2577	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	18193Q	\N	\N	\N
2578	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20104S	\N	\N	\N
2579	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20106U	\N	\N	\N
2580	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	17737W	\N	\N	\N
2581	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20108W	\N	\N	\N
2582	AUCUNSEN	2020-10-01 00:00:00	2023-10-03 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	20110Q	\N	\N	\N
2583	AUCUNSEN	2020-10-01 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20112S	\N	\N	\N
2584	AUCUNSEN	2020-10-01 00:00:00	2023-10-03 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	12028B	\N	\N	\N
2653	SECRETSEN	2021-10-05 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19301E	\N	\N	\N
2660	AUCUNSEN	2022-06-21 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14037X	\N	\N	\N
2661	AUCUNSEN	2022-07-04 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	20914V	\N	\N	\N
2665	AUCUNSEN	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14267Y	\N	\N	\N
2666	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19507S	\N	\N	\N
2850	QUESTESEN	2023-10-04 00:00:00	\N	\N	10	ACTIF	\N	\N	\N	\N	08010L	\N	\N	\N
2866	SECRETSEN	2023-10-04 00:00:00	\N	\N	25	ACTIF	\N	\N	\N	\N	20136B	\N	\N	\N
2654	AUCUNSEN	2021-12-08 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	20286Q	\N	\N	\N
2687	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19705W	\N	\N	\N
2688	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	11027H	\N	\N	\N
2689	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19709B	\N	\N	\N
2690	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21037D	\N	\N	\N
2691	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21038E	\N	\N	\N
2692	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	01058X	\N	\N	\N
2710	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21048G	\N	\N	\N
2715	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19447X	\N	\N	\N
2716	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21050A	\N	\N	\N
2717	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21051B	\N	\N	\N
2718	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21052C	\N	\N	\N
2719	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21053D	\N	\N	\N
2720	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21054E	\N	\N	\N
2721	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21055F	\N	\N	\N
2765	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19687N	\N	\N	\N
2766	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19611R	\N	\N	\N
2767	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	99004R	\N	\N	\N
2768	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	04042C	\N	\N	\N
2769	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19711U	\N	\N	\N
2770	AUCUNSEN	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19593H	\N	\N	\N
2771	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21072G	\N	\N	\N
2772	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21073H	\N	\N	\N
2773	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21074J	\N	\N	\N
2774	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14329V	\N	\N	\N
2775	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14357A	\N	\N	\N
2776	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	11074Q	\N	\N	\N
2777	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21075K	\N	\N	\N
2778	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21076L	\N	\N	\N
2779	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	18231D	\N	\N	\N
2780	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21077M	\N	\N	\N
2781	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20252E	\N	\N	\N
2782	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21078N	\N	\N	\N
2783	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19695N	\N	\N	\N
2784	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	11053K	\N	\N	\N
2805	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19565D	\N	\N	\N
2806	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21083K	\N	\N	\N
2807	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	04008A	\N	\N	\N
2808	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	15197G	\N	\N	\N
2809	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19667J	\N	\N	\N
2810	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19673G	\N	\N	\N
2811	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19669L	\N	\N	\N
2814	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21085M	\N	\N	\N
2815	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21086N	\N	\N	\N
2817	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19585H	\N	\N	\N
2825	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21092L	\N	\N	\N
2826	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21093M	\N	\N	\N
2827	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19683J	\N	\N	\N
2828	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21094N	\N	\N	\N
2829	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21095P	\N	\N	\N
2836	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14033T	\N	\N	\N
2876	AUCUNSEN	2024-03-18 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21125C	\N	\N	\N
2662	AUCUNSEN	2023-01-01 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	20980G	\N	\N	\N
2818	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21088Q	\N	\N	\N
2819	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21089R	\N	\N	\N
2820	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21090J	\N	\N	\N
2821	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19649G	\N	\N	\N
2822	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19647E	\N	\N	\N
2823	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	07033P	\N	\N	\N
2824	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21091K	\N	\N	\N
2655	AUCUNSEN	2022-02-03 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	20298U	\N	\N	\N
2663	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21029D	\N	\N	\N
2659	VICPDTSEN	2022-04-01 00:00:00	2023-10-01 00:00:00	NON	5	ANCIEN	\N	\N	\N	\N	95063L	NON	\N	\N
2664	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21030V	\N	\N	\N
2674	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19563B	\N	\N	\N
2675	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21031W	\N	\N	\N
2676	AUCUNSEN	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19479G	\N	\N	\N
2685	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21035B	\N	\N	\N
2700	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19531S	\N	\N	\N
2726	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21057H	\N	\N	\N
2727	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21058J	\N	\N	\N
2728	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19421M	\N	\N	\N
2729	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19399H	\N	\N	\N
2730	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	11070L	\N	\N	\N
2731	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19691J	\N	\N	\N
2732	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19693L	\N	\N	\N
2733	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21059K	\N	\N	\N
2735	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21060C	\N	\N	\N
2736	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19573D	\N	\N	\N
2737	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21061D	\N	\N	\N
2738	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	05008E	\N	\N	\N
2739	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20180F	\N	\N	\N
2740	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21062E	\N	\N	\N
2742	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21064G	\N	\N	\N
2743	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21065H	\N	\N	\N
2812	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19569H	\N	\N	\N
2813	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21084L	\N	\N	\N
2816	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21087P	\N	\N	\N
2652	AUCUNSEN	2021-10-01 00:00:00	2023-10-03 00:00:00	NON	\N	ANCIEN	\N	\N	\N	\N	04045F	NON	\N	\N
2658	AUCUNSEN	2022-04-01 00:00:00	\N	NON	\N	ACTIF	\N	\N	\N	\N	08073C	NON	\N	\N
2722	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21056G	\N	\N	\N
2723	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19619A	\N	\N	\N
2724	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19621T	\N	\N	\N
2725	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	11110B	\N	\N	\N
2789	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19699S	\N	\N	\N
2790	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21079P	\N	\N	\N
2791	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19347U	\N	\N	\N
2832	AUCUNSEN	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19301E	\N	\N	\N
2833	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21097R	\N	\N	\N
2840	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14147R	\N	\N	\N
2845	VICPDTSEN	2023-10-04 00:00:00	\N	\N	5	ACTIF	\N	\N	\N	\N	19301E	\N	\N	\N
2877	AUCUNSEN	2024-03-21 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14241N	\N	\N	\N
2863	SECRETSEN	2023-10-04 00:00:00	\N	\N	22	ACTIF	\N	\N	\N	\N	19735D	\N	\N	\N
2865	SECRETSEN	2023-10-04 00:00:00	\N	\N	24	ACTIF	\N	\N	\N	\N	04045F	\N	\N	\N
2682	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19657G	\N	\N	\N
2683	AUCUNSEN	2023-10-02 00:00:00	2029-11-27 00:00:00	\N	\N	ACTIF	\N	\N	\N	\N	21033Y	\N	\N	\N
2684	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21034A	\N	\N	\N
2686	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21036C	\N	\N	\N
2693	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21039F	\N	\N	\N
2694	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19367Y	\N	\N	\N
2695	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21040X	\N	\N	\N
2696	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21041Y	\N	\N	\N
2699	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21043B	\N	\N	\N
2701	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21044C	\N	\N	\N
2702	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19703U	\N	\N	\N
2706	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19533U	\N	\N	\N
2707	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19545Y	\N	\N	\N
2708	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21046E	\N	\N	\N
2709	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21047F	\N	\N	\N
2711	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	11048N	\N	\N	\N
2712	AUCUNSEN	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19553Y	\N	\N	\N
2713	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19551W	\N	\N	\N
2714	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21049H	\N	\N	\N
2734	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	11115U	\N	\N	\N
2741	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21063F	\N	\N	\N
2744	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	18395Y	\N	\N	\N
2745	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	11065P	\N	\N	\N
2746	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20172F	\N	\N	\N
2747	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21066J	\N	\N	\N
2755	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14331P	\N	\N	\N
2756	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21068L	\N	\N	\N
2757	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21069M	\N	\N	\N
2758	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	01034P	\N	\N	\N
2759	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21070E	\N	\N	\N
2760	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21071F	\N	\N	\N
2761	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19111A	\N	\N	\N
2762	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	11085T	\N	\N	\N
2763	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	11045K	\N	\N	\N
2764	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19591F	\N	\N	\N
2785	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19697Q	\N	\N	\N
2797	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19335Q	\N	\N	\N
2798	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19954N	\N	\N	\N
2799	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21081H	\N	\N	\N
2800	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21082J	\N	\N	\N
2801	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19685L	\N	\N	\N
2802	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14021P	\N	\N	\N
2803	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	18207D	\N	\N	\N
2804	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	11040E	\N	\N	\N
2835	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14026U	\N	\N	\N
2837	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14123H	\N	\N	\N
2867	SECRETSEN	2023-10-04 00:00:00	\N	\N	26	ACTIF	\N	\N	\N	\N	20064C	\N	\N	\N
2669	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19866P	\N	\N	\N
2667	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19631V	\N	\N	\N
2668	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19629C	\N	\N	\N
2678	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19713W	\N	\N	\N
2680	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	11072N	\N	\N	\N
2681	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19331L	\N	\N	\N
2792	AUCUNSEN	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	19295A	\N	\N	\N
2793	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	11043H	\N	\N	\N
2013	AUCUNSEN	2011-10-01 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11043H	\N	\N	\N
2794	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19679N	\N	\N	\N
2795	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21080G	\N	\N	\N
2796	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19349W	\N	\N	\N
2830	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21096Q	\N	\N	\N
2831	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	12016W	\N	\N	\N
2838	AUCUNSEN	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	14179A	\N	\N	\N
2839	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14213J	\N	\N	\N
2841	PDTSEN	2023-10-02 00:00:00	\N	\N	1	ACTIF	\N	\N	\N	\N	86034E	\N	\N	\N
2008	AUCUNSEN	2011-10-01 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11067R	\N	\N	\N
2052	AUCUNSEN	2011-10-01 00:00:00	2023-10-01 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11083R	\N	\N	\N
2670	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19489J	\N	\N	\N
2671	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	17779H	\N	\N	\N
2679	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21032X	\N	\N	\N
2673	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	14042U	\N	\N	\N
2677	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	07004J	\N	\N	\N
2697	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21042A	\N	\N	\N
2698	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	18083K	\N	\N	\N
2703	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19383Y	\N	\N	\N
2704	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19387D	\N	\N	\N
2705	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21045D	\N	\N	\N
2749	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19760E	\N	\N	\N
2750	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19681G	\N	\N	\N
2751	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	21067K	\N	\N	\N
2752	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19413M	\N	\N	\N
2753	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	20286Q	\N	\N	\N
2754	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	11056N	\N	\N	\N
2237	PDTSEN	2014-10-01 00:00:00	2023-10-01 00:00:00	NON	2	ANCIEN	\N	\N	\N	\N	86034E	NON	2014-10-01 00:00:00	2014-10-08 00:00:00
2787	AUCUNSEN	2023-10-02 00:00:00	2023-10-03 00:00:00	\N	\N	ANCIEN	\N	\N	\N	\N	11090Q	\N	\N	\N
2788	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19701S	\N	\N	\N
2834	AUCUNSEN	2023-10-02 00:00:00	\N	\N	\N	ACTIF	\N	\N	\N	\N	19719D	\N	\N	\N
2842	VICPDTSEN	2023-10-04 00:00:00	\N	\N	2	ACTIF	\N	\N	\N	\N	14259Y	\N	\N	\N
2843	VICPDTSEN	2023-10-04 00:00:00	\N	\N	3	ACTIF	\N	\N	\N	\N	14229S	\N	\N	\N
2844	VICPDTSEN	2023-10-04 00:00:00	\N	\N	4	ACTIF	\N	\N	\N	\N	19479G	\N	\N	\N
2846	VICPDTSEN	2023-10-04 00:00:00	\N	\N	6	ACTIF	\N	\N	\N	\N	14111D	\N	\N	\N
2847	VICPDTSEN	2023-10-04 00:00:00	\N	\N	7	ACTIF	\N	\N	\N	\N	19593H	\N	\N	\N
2848	VICPDTSEN	2023-10-04 00:00:00	\N	\N	8	ACTIF	\N	\N	\N	\N	11090Q	\N	\N	\N
2849	VICPDTSEN	2023-10-04 00:00:00	\N	\N	9	ACTIF	\N	\N	\N	\N	14179A	\N	\N	\N
2851	QUESTESEN	2023-10-04 00:00:00	\N	\N	11	ACTIF	\N	\N	\N	\N	12028B	\N	\N	\N
2852	QUESTESEN	2023-10-04 00:00:00	\N	\N	12	ACTIF	\N	\N	\N	\N	14267Y	\N	\N	\N
2853	SECRETSEN	2023-10-04 00:00:00	\N	\N	13	ACTIF	\N	\N	\N	\N	14189C	\N	\N	\N
2854	SECRETSEN	2023-10-04 00:00:00	\N	\N	14	ACTIF	\N	\N	\N	\N	20110Q	\N	\N	\N
2855	SECRETSEN	2023-10-04 00:00:00	\N	\N	15	ACTIF	\N	\N	\N	\N	14069U	\N	\N	\N
2856	SECRETSEN	2023-10-04 00:00:00	\N	\N	16	ACTIF	\N	\N	\N	\N	08060W	\N	\N	\N
2857	SECRETSEN	2023-10-04 00:00:00	\N	\N	17	ACTIF	\N	\N	\N	\N	20138D	\N	\N	\N
2858	SECRETSEN	2023-10-04 00:00:00	\N	\N	18	ACTIF	\N	\N	\N	\N	19295A	\N	\N	\N
2859	SECRETSEN	2023-10-04 00:00:00	\N	\N	19	ACTIF	\N	\N	\N	\N	14215L	\N	\N	\N
2862	SECRETSEN	2023-10-04 00:00:00	\N	\N	21	ACTIF	\N	\N	\N	\N	19553Y	\N	\N	\N
2864	SECRETSEN	2023-10-04 00:00:00	\N	\N	23	ACTIF	\N	\N	\N	\N	19798U	\N	\N	\N
2868	SECRETSEN	2023-10-04 00:00:00	\N	\N	20	ACTIF	\N	\N	\N	\N	11064N	\N	\N	\N
\.


--
-- Data for Name: sennom; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY sennom (senmat, sennomdatdeb, sennomdatfin, quacod, sennomuse, sennomusecap, sennomtec, senprenomuse, syscredat, sysmajdat, sennomid) FROM stdin;
98018T	1942-11-10 00:00:00	\N	M.	del Picchia	del PICCHIA	DEL PICCHIA	Robert	\N	\N	99
98019U	1936-02-22 00:00:00	\N	M.	Ferrand	FERRAND	FERRAND ANDRE	André	\N	2013-10-09 14:18:51	100
98021N	1954-03-15 00:00:00	\N	M.	Pintat	PINTAT	PINTAT XAVIER	Xavier	\N	2013-10-08 12:11:52	101
98022P	1951-01-01 00:00:00	\N	M.	Guérini	GUÉRINI	GUERINI	Jean-Noël	\N	2014-09-28 20:26:57	102
98023Q	1952-02-06 00:00:00	\N	M.	Cornu	CORNU	CORNU GERARD	Gérard	\N	\N	103
98024R	1944-11-01 00:00:00	\N	M.	Dériot	DÉRIOT	DERIOT	Gérard	\N	\N	104
98025S	1953-10-12 00:00:00	\N	M.	Lepeltier	LEPELTIER	LEPELTIER	Serge	\N	\N	105
98026T	1933-12-31 00:00:00	\N	M.	Vissac	VISSAC	VISSAC	Guy	\N	\N	106
98027U	1954-07-14 00:00:00	\N	M.	Jarlier	JARLIER	JARLIER	Pierre	\N	2014-02-13 16:16:19	107
98029W	1939-04-27 00:00:00	\N	M.	Cazeau	CAZEAU	CAZEAU	Bernard	\N	2014-09-28 20:29:40	108
98030P	1940-05-16 00:00:00	\N	M.	Domeizel	DOMEIZEL	DOMEIZEL	Claude	\N	2013-11-19 11:24:43	109
98032R	1942-07-07 00:00:00	\N	M.	de Montesquiou	de MONTESQUIOU	MONTESQUIOU (DE)	Aymeri	\N	\N	110
98033S	1931-09-17 00:00:00	2015-01-15 00:00:00	M.	Rispat	RISPAT	RISPAT	Yves	\N	2015-01-19 09:37:30	111
98034T	1941-06-25 00:00:00	\N	M.	Journet	JOURNET	JOURNET	Alain	\N	\N	112
98035U	1952-08-18 00:00:00	\N	M.	Sutour	SUTOUR	SUTOUR	Simon	\N	2013-10-08 16:49:50	113
98037W	1944-07-20 00:00:00	\N	M.	Teston	TESTON	TESTON	Michel	\N	2013-08-23 11:19:34	114
000214	1909-07-10 00:00:00	1995-10-14 00:00:00	M.	Roux	ROUX	ROUX OLIVIER	Olivier	\N	\N	115
000505	1923-03-15 00:00:00	1996-03-23 00:00:00	M.	Rudloff	RUDLOFF	RUDLOFF MARCEL	Marcel	\N	\N	116
58928D	1921-10-29 00:00:00	2001-01-26 00:00:00	M.	Ruet	RUET	RUET ROLAND	Roland	\N	\N	117
000453	1920-11-20 00:00:00	1983-05-31 00:00:00	M.	Sallenave	SALLENAVE	SALLENAVE PIERRE	Pierre	\N	\N	118
000564	1926-04-02 00:00:00	1989-01-09 00:00:00	M.	Salvi	SALVI	SALVI PIERRE	Pierre	\N	\N	119
57752S	1919-02-22 00:00:00	2014-03-03 00:00:00	M.	Sanglier	SANGLIER	SANGLIER JACQUES	Jacques	\N	2014-03-06 14:59:35	120
58336J	1909-10-03 00:00:00	2005-07-15 00:00:00	M.	Sauvage	SAUVAGE	SAUVAGE JEAN	Jean	\N	\N	121
57738U	1911-03-11 00:00:00	2004-02-08 00:00:00	Mme	Scellier	SCELLIER	SCELLIER GABRIELLE	Gabrielle	\N	\N	122
59559C	1925-07-05 00:00:00	2011-07-27 00:00:00	M.	Schiele	SCHIELE	SCHIELE PIERRE	Pierre	\N	\N	123
000278	1911-09-15 00:00:00	1990-09-26 00:00:00	M.	Schleiter	SCHLEITER	SCHLEITER FRANÇOIS	François	\N	\N	124
58662V	1932-07-07 00:00:00	\N	M.	Schmaus	SCHMAUS	SCHMAUS GUY	Guy	\N	\N	125
58352J	1917-12-11 00:00:00	2003-12-06 00:00:00	M.	Schmitt	SCHMITT	SCHMITT ROBERT	Robert	\N	\N	126
74044S	1911-04-10 00:00:00	1998-02-09 00:00:00	M.	Schumann	SCHUMANN	SCHUMANN MAURICE	Maurice	\N	\N	127
000147	1906-08-08 00:00:00	1960-05-09 00:00:00	M.	Schwartz	SCHWARTZ	SCHWARTZ RENÉ	René	\N	\N	128
59307H	1928-01-11 00:00:00	2011-01-24 00:00:00	M.	Schwint	SCHWINT	SCHWINT ROBERT	Robert	\N	\N	129
59581A	1919-06-09 00:00:00	2013-02-27 00:00:00	Mme	Seligmann	SELIGMANN	SELIGMANN FRANCOISE	Françoise	\N	\N	130
58933A	1912-01-24 00:00:00	2006-02-22 00:00:00	M.	Sempe	SEMPE	SEMPE ABEL	Abel	\N	\N	131
000440	1920-02-04 00:00:00	1992-02-23 00:00:00	M.	Seramy	SERAMY	SERAMY PAUL	Paul	\N	\N	132
000168	1907-08-24 00:00:00	1990-02-03 00:00:00	M.	Servat	SERVAT	SERVAT ANDRÉ	André	\N	\N	133
000101	1904-05-16 00:00:00	1985-11-20 00:00:00	M.	Sibor	SIBOR	SIBOR HENRI	Henri	\N	\N	134
000369	1915-10-21 00:00:00	1989-12-13 00:00:00	M.	Sicard	SICARD	SICARD PIERRE	Pierre	\N	\N	135
000373	1916-05-26 00:00:00	1993-11-06 00:00:00	M.	Simonin	SIMONIN	SIMONIN JEAN	Jean	\N	\N	136
000364	1915-06-05 00:00:00	1980-11-18 00:00:00	M.	Sirgue	SIRGUE	SIRGUE ALBERT	Albert	\N	\N	137
000279	1911-09-19 00:00:00	1996-04-18 00:00:00	M.	Soldani	SOLDANI	SOLDANI EDOUARD	Edouard	\N	\N	138
000452	1920-11-11 00:00:00	1994-02-23 00:00:00	M.	Sordel	SORDEL	SORDEL MICHEL	Michel	\N	\N	139
000123	1905-05-21 00:00:00	1980-12-26 00:00:00	M.	Soudant	SOUDANT	SOUDANT ROBERT	Robert	\N	\N	140
59247N	1932-05-16 00:00:00	\N	M.	Souffrin	SOUFFRIN	SOUFFRIN PAUL	Paul	\N	\N	141
000334	1914-02-24 00:00:00	1995-06-29 00:00:00	M.	Souquet	SOUQUET	SOUQUET MARCEL	Marcel	\N	\N	142
000287	1912-01-26 00:00:00	1985-06-14 00:00:00	M.	Splingard	SPLINGARD	SPLINGARD RAYMOND	Raymond	\N	\N	143
000499	1922-11-30 00:00:00	1966-10-14 00:00:00	M.	Stoessel	STOESSEL	STOESSEL CHARLES	Charles	\N	\N	144
000120	1905-05-02 00:00:00	1971-08-01 00:00:00	M.	Suran	SURAN	SURAN CHARLES	Charles	\N	\N	145
000095	1904-01-12 00:00:00	1986-06-23 00:00:00	M.	Tailhades	TAILHADES	TAILHADES EDGAR	Edgar	\N	\N	146
59560U	1926-02-05 00:00:00	2009-09-27 00:00:00	M.	Taittinger	TAITTINGER	TAITTINGER PIERRE-CHRISTIA	Pierre-Christian	\N	\N	147
000592	1928-09-27 00:00:00	1984-03-20 00:00:00	M.	Tajan	TAJAN	TAJAN PIERRE	Pierre	\N	\N	148
000302	1912-12-19 00:00:00	1975-04-30 00:00:00	M.	Talamoni	TALAMONI	TALAMONI LOUIS	Louis	\N	\N	149
58508L	1930-06-16 00:00:00	\N	M.	Talon	TALON	TALON BERNARD	Bernard	\N	\N	150
58950B	1936-11-18 00:00:00	\N	M.	Tarcy	TARCY	TARCY RAYMOND	Raymond	\N	\N	151
000006	1900-02-16 00:00:00	1978-10-13 00:00:00	M.	Terre	TERRE	TERRE HENRI	Henri	\N	\N	152
56829S	1910-11-26 00:00:00	2001-11-05 00:00:00	Mme	Thorez Vermeersch	THOREZ VERMEERSCH	THOREZ VERMEERSCH JEANNETTE	Jeannette	\N	\N	154
000312	1913-04-24 00:00:00	1984-03-06 00:00:00	M.	Tinant	TINANT	TINANT RENÉ	René	\N	\N	155
83001G	1920-10-26 00:00:00	2012-11-08 00:00:00	M.	Tizon	TIZON	TIZON JEAN-PIERRE	Jean-Pierre	\N	\N	156
000417	1919-04-16 00:00:00	1983-05-05 00:00:00	M.	Tomasini	TOMASINI	TOMASINI RENÉ	René	\N	\N	157
000301	1912-12-10 00:00:00	1990-07-27 00:00:00	M.	Toribio	TORIBIO	TORIBIO RENÉ	René	\N	\N	158
58036Y	1915-12-22 00:00:00	2010-02-25 00:00:00	M.	Tournan	TOURNAN	TOURNAN HENRI	Henri	\N	\N	159
58628T	1931-09-19 00:00:00	\N	Mme	Perlican	PERLICAN	PERLICAN ROLANDE	Rolande	\N	\N	160
000161	1907-03-03 00:00:00	1994-08-12 00:00:00	M.	Perpere	PERPERE	PERPERE RAOUL	Raoul	\N	\N	161
59580Y	1917-01-18 00:00:00	2004-06-21 00:00:00	M.	Perrein	PERREIN	PERREIN LOUIS	Louis	\N	\N	162
58335H	1918-12-30 00:00:00	2009-08-08 00:00:00	M.	Perrin	PERRIN	PERRIN PIERRE	Pierre	\N	\N	163
000643	1935-12-24 00:00:00	1978-10-05 00:00:00	M.	Perron	PERRON	PERRON JEAN-JACQUES	Jean-Jacques	\N	\N	164
000138	1905-11-23 00:00:00	1988-10-31 00:00:00	M.	Petit	PETIT	PETIT GUY	Guy	\N	\N	165
000434	1919-11-29 00:00:00	1977-12-21 00:00:00	M.	Petit	PETIT	PETIT PIERRE	Pierre	\N	\N	166
000023	1900-09-19 00:00:00	1974-12-16 00:00:00	M.	Philippon	PHILIPPON	PHILIPPON GUSTAVE	Gustave	\N	\N	167
000030	1895-11-12 00:00:00	1987-03-06 00:00:00	M.	Piales	PIALES	PIALES PAUL	Paul	\N	\N	168
59554W	1914-09-03 00:00:00	2007-10-08 00:00:00	M.	Piat	PIAT	PIAT ROBERT	Robert	\N	\N	169
000307	1913-02-15 00:00:00	1991-01-30 00:00:00	M.	Pic	PIC	PIC MAURICE	Maurice	\N	\N	170
58341F	1907-04-01 00:00:00	2002-12-17 00:00:00	M.	Pillet	PILLET	PILLET PAUL	Paul	\N	\N	171
86053H	1930-09-16 00:00:00	\N	M.	Signé	SIGNÉ	SIGNE	René-Pierre	\N	\N	314
000143	1906-04-09 00:00:00	1991-12-09 00:00:00	M.	Pinsard	PINSARD	PINSARD JULES	Jules	\N	\N	172
000514	1923-07-29 00:00:00	1990-06-14 00:00:00	M.	Pintat	PINTAT	PINTAT JEAN-FRANÇOIS	Jean-François	\N	\N	173
000052	1901-08-25 00:00:00	1984-08-22 00:00:00	M.	Pinton	PINTON	PINTON AUGUSTE	Auguste	\N	\N	174
57321W	1918-10-09 00:00:00	2016-06-20 00:00:00	M.	Pisani	PISANI	PISANI EDGARD	Edgard	\N	2016-06-23 17:22:36	175
59619W	1943-06-11 00:00:00	\N	M.	Plantegenest	PLANTEGENEST	PLANTEGENEST MARC	Marc	\N	\N	176
96002B	1936-08-29 00:00:00	1998-02-02 00:00:00	M.	Ploton	PLOTON	PLOTON RÉGIS	Régis	\N	\N	177
58916Y	1917-07-02 00:00:00	2007-05-21 00:00:00	M.	Poirier	POIRIER	POIRIER RAYMOND	Raymond	\N	\N	178
59556Y	1922-05-16 00:00:00	2002-01-15 00:00:00	M.	Poniatowski	PONIATOWSKI	PONIATOWSKI MICHEL	Michel	\N	\N	179
56522A	1911-03-30 00:00:00	2000-08-28 00:00:00	M.	de Pontbriand	de PONTBRIAND	PONTBRIAND MICHEL 	Michel	\N	\N	180
000476	1921-12-04 00:00:00	1992-03-20 00:00:00	M.	Pontillon	PONTILLON	PONTILLON ROBERT	Robert	\N	\N	181
56406W	1906-08-25 00:00:00	2001-03-03 00:00:00	M.	Marcellin	MARCELLIN	MARCELLIN ROGER	Roger	\N	\N	182
000236	1910-02-14 00:00:00	1987-07-06 00:00:00	M.	Marcilhacy	MARCILHACY	MARCILHACY PIERRE	Pierre	\N	\N	183
000498	1922-09-21 00:00:00	1984-04-25 00:00:00	M.	Marette	MARETTE	MARETTE JACQUES	Jacques	\N	\N	184
57749X	1906-10-09 00:00:00	2001-02-21 00:00:00	M.	Marie Anne	MARIE ANNE	MARIE ANNE GEORGES	Georges	\N	\N	185
000227	1909-11-06 00:00:00	1992-12-12 00:00:00	M.	Marre	MARRE	MARRE LOUIS	Louis	\N	\N	186
58633Q	1926-11-01 00:00:00	2017-12-01 00:00:00	M.	Marson	MARSON	MARSON JAMES	James	\N	2017-12-05 14:28:30	187
000561	1926-02-01 00:00:00	1993-11-07 00:00:00	M.	Martin	MARTIN	MARTIN ANDRÉ	André	\N	\N	188
59235J	1912-02-23 00:00:00	2008-06-08 00:00:00	M.	Martin	MARTIN	MARTIN HUBERT	Hubert	\N	\N	189
58342G	1913-08-16 00:00:00	1999-08-16 00:00:00	M.	Martin	MARTIN	MARTIN LOUIS	Louis	\N	\N	190
57456M	1916-11-29 00:00:00	2009-05-31 00:00:00	M.	Martin	MARTIN	MARTIN MARCEL	Marcel	\N	\N	191
58621L	1918-11-20 00:00:00	2010-12-20 00:00:00	M.	Martin	MARTIN	MARTIN RENÉ	René	\N	\N	192
000136	1905-10-24 00:00:00	1994-08-02 00:00:00	M.	Marzin	MARZIN	MARZIN PIERRE	Pierre	\N	\N	193
000332	1914-02-01 00:00:00	1986-10-06 00:00:00	M.	Massa	MASSA	MASSA PAUL	Paul	\N	\N	194
58939G	1909-12-15 00:00:00	2003-06-13 00:00:00	M.	Masson	MASSON	MASSON CHRISTIAN	Christian	\N	\N	195
000080	1903-07-18 00:00:00	1994-03-27 00:00:00	M.	Masteau	MASTEAU	MASTEAU JACQUES	Jacques	\N	\N	196
000314	1913-06-29 00:00:00	1974-05-22 00:00:00	M.	Mathias	MATHIAS	MATHIAS JEAN-BAPTISTE	Jean-Baptiste	\N	\N	197
88011F	1934-06-01 00:00:00	1997-11-17 00:00:00	M.	Mathieu	MATHIEU	MATHIEU FRANCOIS	François	\N	\N	198
000269	1911-04-10 00:00:00	1982-03-20 00:00:00	M.	Mathy	MATHY	MATHY MARCEL	Marcel	\N	\N	199
000502	1923-02-14 00:00:00	1991-11-23 00:00:00	M.	Matraja	MATRAJA	MATRAJA PIERRE	Pierre	\N	\N	200
000179	1908-02-26 00:00:00	1980-11-10 00:00:00	M.	Maury	MAURY	MAURY JACQUES	Jacques	\N	\N	201
000355	1914-12-31 00:00:00	1988-11-18 00:00:00	M.	Menard	MENARD	MENARD JACQUES	Jacques	\N	\N	202
000233	1910-01-03 00:00:00	1970-08-19 00:00:00	M.	Menu	MENU	MENU ROGER	Roger	\N	\N	203
000337	1914-03-31 00:00:00	1988-01-11 00:00:00	M.	Mercier	MERCIER	MERCIER JEAN	Jean	\N	\N	204
59717X	1920-02-06 00:00:00	2002-11-03 00:00:00	M.	Merli	MERLI	MERLI PIERRE	Pierre	\N	\N	205
000001	1900-01-01 00:00:00	1994-08-19 00:00:00	M.	Merred	MERRED	MERRED ALI	Ali	\N	\N	206
000185	1908-06-11 00:00:00	1983-12-27 00:00:00	M.	Henneguelle	HENNEGUELLE	HENNEGUELLE HENRI	Henri	\N	\N	207
000243	1910-05-30 00:00:00	1981-09-29 00:00:00	M.	Heon	HEON	HEON GUSTAVE	Gustave	\N	\N	208
000040	1901-04-07 00:00:00	1966-02-10 00:00:00	M.	Hugues	HUGUES	HUGUES EMILE	Emile	\N	\N	209
000273	1911-06-29 00:00:00	1984-09-04 00:00:00	M.	Isautier	ISAUTIER	ISAUTIER ALFRED	Alfred	\N	2016-11-30 16:17:48	210
000308	1913-02-17 00:00:00	1983-04-18 00:00:00	M.	Jacquet	JACQUET	JACQUET MARC	Marc	\N	\N	211
000403	1918-04-14 00:00:00	1993-10-22 00:00:00	M.	Jaffar El Amjad	JAFFAR EL AMJAD	JAFFAR EL AMJAD SAID MOHAMED	Said Mohamed	\N	\N	212
000207	1909-03-08 00:00:00	1983-07-28 00:00:00	M.	Jager	JAGER	JAGER RENÉ	René	\N	\N	213
000630	1933-03-01 00:00:00	1999-07-22 00:00:00	M.	Janetti	JANETTI	JANETTI MAURICE	Maurice	\N	\N	214
58348N	1925-03-31 00:00:00	2003-07-04 00:00:00	M.	Jargot	JARGOT	JARGOT PAUL	Paul	\N	\N	215
59539X	1909-12-13 00:00:00	2000-04-21 00:00:00	M.	Jarrot	JARROT	JARROT ANDRÉ	André	\N	\N	216
000171	1907-11-05 00:00:00	1983-02-26 00:00:00	M.	Javelly	JAVELLY	JAVELLY MAXIME	Maxime	\N	\N	217
58650R	1925-11-24 00:00:00	2003-01-04 00:00:00	M.	Jouany	JOUANY	JOUANY ANDRÉ	André	\N	\N	218
58039C	1923-06-23 00:00:00	\N	M.	Jourdan	JOURDAN	JOURDAN PIERRE	Pierre	\N	\N	219
000225	1909-10-31 00:00:00	1984-10-29 00:00:00	M.	Junillon	JUNILLON	JUNILLON LUCIEN	Lucien	\N	\N	220
57208W	1917-01-01 00:00:00	2002-06-09 00:00:00	M.	Kamil	KAMIL	KAMIL MOHAMED	Mohamed	\N	\N	221
000348	1914-09-22 00:00:00	1987-05-25 00:00:00	M.	Kauffmann	KAUFFMANN	KAUFFMANN MICHEL	Michel	\N	\N	222
56405V	1910-11-03 00:00:00	1998-12-25 00:00:00	M.	Kheirat	KHEIRAT	KHEIRAT M'HAMED	M'hamed	\N	\N	223
000149	1906-08-22 00:00:00	1991-07-14 00:00:00	M.	Kieffer	KIEFFER	KIEFFER ALFRED	Alfred	\N	\N	224
000213	1909-06-22 00:00:00	1980-12-29 00:00:00	M.	Kientzi	KIENTZI	KIENTZI ARMAND	Armand	\N	2016-12-01 10:46:10	225
000124	1905-05-27 00:00:00	1986-02-04 00:00:00	M.	L'Huillier	L'HUILLIER	LHUILLIER WALDECK	Waldeck	\N	\N	226
58945E	1914-08-12 00:00:00	2013-09-30 00:00:00	M.	De La Forest	DE LA FOREST	LAFOREST LOUIS (DE)	Louis	\N	2013-10-02 12:20:57	227
000068	1902-07-30 00:00:00	1971-05-06 00:00:00	M.	de La Gontrie	de LA GONTRIE	LAGONTRIE PIERRE DE	Pierre	\N	\N	228
000458	1921-03-04 00:00:00	1980-07-28 00:00:00	M.	Labeguerie	LABEGUERIE	LABEGUERIE MICHEL	Michel	\N	\N	229
000237	1910-02-28 00:00:00	1981-11-22 00:00:00	M.	Labonde	LABONDE	LABONDE PIERRE	Pierre	\N	\N	230
000231	1909-12-26 00:00:00	1975-07-29 00:00:00	M.	Lacaze	LACAZE	LACAZE JEAN	Jean	\N	\N	231
000153	1906-08-20 00:00:00	1988-03-31 00:00:00	M.	Lachevre	LACHEVRE	LACHEVRE ROGER	Roger	\N	\N	232
57449N	1912-03-28 00:00:00	1999-01-12 00:00:00	M.	de Lachomette	de LACHOMETTE	LACHOMETTE JEAN 	Jean	\N	\N	233
80022Y	1923-02-20 00:00:00	2008-05-22 00:00:00	M.	Lacour	LACOUR	LACOUR PIERRE	Pierre	\N	\N	234
000086	1905-09-08 00:00:00	1977-02-13 00:00:00	M.	Lafay	LAFAY	LAFAY BERNARD	Bernard	\N	2016-12-13 15:13:00	235
000063	1902-04-18 00:00:00	1974-10-13 00:00:00	M.	Lafleur	LAFLEUR	LAFLEUR HENRI	Henri	\N	\N	236
57728S	1919-06-11 00:00:00	2007-03-01 00:00:00	Mme	Lagatu	LAGATU	LAGATU CATHERINE	Catherine	\N	\N	237
56812H	1913-05-04 00:00:00	2000-09-29 00:00:00	M.	Lagrange	LAGRANGE	LAGRANGE ROGER	Roger	\N	\N	238
000230	1909-12-23 00:00:00	1992-08-01 00:00:00	M.	Lamousse	LAMOUSSE	LAMOUSSE GEORGES	Georges	\N	\N	239
000303	1912-12-20 00:00:00	1974-09-06 00:00:00	M.	Lanet	LANET	LANET JOSEPH	Joseph	\N	\N	240
000107	1904-08-18 00:00:00	1995-07-05 00:00:00	M.	Larue	LARUE	LARUE TONY	Tony	\N	\N	241
59541R	1921-07-22 00:00:00	2008-10-14 00:00:00	M.	Laucournet	LAUCOURNET	LAUCOURNET ROBERT	Robert	\N	\N	242
57129Y	1910-09-27 00:00:00	2005-09-20 00:00:00	M.	Laurens	LAURENS	LAURENS ROBERT	Robert	\N	2016-12-01 17:59:51	243
000456	1921-01-19 00:00:00	1994-07-15 00:00:00	M.	Laurent	LAURENT	LAURENT BERNARD	Bernard	\N	\N	244
000042	1901-05-01 00:00:00	1989-09-16 00:00:00	M.	Laurent-Thouverey	LAURENT-THOUVEREY	LAURENT-THOUVEREY CHARLES	Charles	\N	\N	245
59542S	1916-08-18 00:00:00	2006-10-20 00:00:00	M.	Lauriol	LAURIOL	LAURIOL MARC	Marc	\N	\N	246
58948H	1912-04-21 00:00:00	2002-03-07 00:00:00	M.	Lazuech	LAZUECH	LAZUECH LOUIS	Louis	\N	\N	247
000093	1903-12-20 00:00:00	1972-12-05 00:00:00	M.	Le Bellegou	LE BELLEGOU	LEBELLEGOU EDOUARD	Edouard	\N	\N	248
000135	1905-10-19 00:00:00	1993-01-15 00:00:00	M.	Filippi	FILIPPI	FILIPPI JEAN	Jean	\N	\N	249
000046	1901-07-08 00:00:00	1985-10-20 00:00:00	M.	Fleury	FLEURY	FLEURY JEAN	Jean	\N	\N	250
58021R	1919-09-20 00:00:00	\N	M.	Fontaine	FONTAINE	FONTAINE MAURICE	Maurice	\N	\N	251
000451	1920-11-07 00:00:00	1995-09-14 00:00:00	M.	Fortier	FORTIER	FORTIER MARCEL	Marcel	\N	\N	252
000449	1920-09-23 00:00:00	1996-12-18 00:00:00	M.	Fosse	FOSSE	FOSSE ROGER	Roger	\N	\N	253
59521M	1918-11-13 00:00:00	2001-03-27 00:00:00	M.	Fosset	FOSSET	FOSSET ANDRÉ	André	\N	\N	254
59574B	1937-09-18 00:00:00	\N	Mme	Fost	FOST	FOST PAULETTE	Paulette	\N	\N	255
000296	1912-07-21 00:00:00	1995-09-22 00:00:00	M.	Fournis	FOURNIS	FOURNIS HENRI	Henri	\N	\N	256
58944D	1920-05-27 00:00:00	2013-03-13 00:00:00	M.	Francou	FRANCOU	FRANCOU JEAN	Jean	\N	2013-03-15 10:32:30	257
86027F	1947-02-25 00:00:00	\N	Mme	Fraysse-Cazalis	FRAYSSE-CAZALIS	FRAYSSE-CAZALIS JACQUELINE	Jacqueline	\N	\N	258
000139	1905-12-04 00:00:00	1987-06-15 00:00:00	M.	Freville	FREVILLE	FREVILLE HENRI	Henri	\N	\N	259
000533	1924-06-02 00:00:00	1997-01-22 00:00:00	M.	Fuzier	FUZIER	FUZIER CLAUDE	Claude	\N	\N	260
59229L	1921-12-23 00:00:00	2009-05-18 00:00:00	M.	Gallet	GALLET	GALLET HENRI	Henri	\N	\N	261
000455	1921-01-11 00:00:00	2012-06-08 00:00:00	M.	Galley	GALLEY	GALLEY ROBERT	Robert	\N	2014-06-04 13:52:17	262
58668C	1933-02-01 00:00:00	2014-11-19 00:00:00	M.	Gamboa	GAMBOA	GAMBOA PIERRE	Pierre	\N	2014-11-21 10:53:27	263
56601X	1913-07-17 00:00:00	2012-06-13 00:00:00	M.	Garaudy	GARAUDY	GARAUDY ROGER	Roger	\N	\N	264
59534S	1925-06-05 00:00:00	2012-02-08 00:00:00	M.	Garcia	GARCIA	GARCIA JEAN	Jean	\N	\N	265
000131	1905-09-07 00:00:00	1972-12-10 00:00:00	M.	Garet	GARET	GARET PIERRE	Pierre	\N	\N	266
80020W	1925-06-02 00:00:00	1996-09-03 00:00:00	M.	Gaud	GAUD	GAUD GÉRARD	Gérard	\N	\N	267
000306	1913-02-15 00:00:00	1978-01-02 00:00:00	M.	Gaudin	GAUDIN	GAUDIN PIERRE	Pierre	\N	\N	268
000536	1924-09-03 00:00:00	1997-02-12 00:00:00	M.	Gaudon	GAUDON	GAUDON ROGER	Roger	\N	\N	269
000137	1905-11-17 00:00:00	1991-02-28 00:00:00	M.	Gauthier	GAUTHIER	GAUTHIER ABEL	Abel	\N	\N	270
59535T	1940-04-23 00:00:00	\N	M.	Gautier	GAUTIER	GAUTIER FRANÇOIS	François	\N	\N	271
000319	1913-07-27 00:00:00	1992-02-03 00:00:00	M.	Gautier	GAUTIER	GAUTIER LUCIEN	Lucien	\N	\N	272
000071	1902-11-20 00:00:00	1984-03-04 00:00:00	M.	Gay	GAY	GAY ETIENNE	Etienne	\N	\N	273
000114	1905-01-07 00:00:00	1991-02-03 00:00:00	M.	Geoffroy	GEOFFROY	GEOFFROY JEAN	Jean	\N	\N	274
58656X	1924-10-22 00:00:00	2009-06-01 00:00:00	M.	Gerin	GERIN	GERIN ALFRED	Alfred	\N	\N	275
62001R	1919-07-19 00:00:00	1997-03-07 00:00:00	M.	Giacobbi	GIACOBBI	GIACOBBI FRANCOIS	François	\N	\N	276
59536U	1926-09-04 00:00:00	\N	M.	Goetschy	GOETSCHY	GOETSCHY HENRI	Henri	\N	\N	277
58631N	1914-03-15 00:00:00	\N	Mme	Goldet	GOLDET	GOLDET CÉCILE	Cécile	\N	\N	278
59575C	1931-12-14 00:00:00	\N	M.	Golliet	GOLLIET	GOLLIET JACQUES	Jacques	\N	\N	279
000210	1909-04-15 00:00:00	1989-09-23 00:00:00	M.	Gonard	GONARD	GONARD PIERRE	Pierre	\N	\N	280
59230D	1926-03-06 00:00:00	\N	Mme	Gournay	GOURNAY	GOURNAY MARIE-FANNY	Marie-Fanny	\N	\N	281
59231E	1930-07-19 00:00:00	\N	M.	Goussebaire-Dupin	GOUSSEBAIRE-DUPIN	GOUSSEBAIRE-DUPIN YVES	Yves	\N	\N	282
58673Y	1933-08-29 00:00:00	2016-09-29 00:00:00	Mme	Goutmann	GOUTMANN	GOUTMANN MARIE-THÉRÈSE	Marie-Thérèse	\N	2016-10-04 15:32:34	283
000097	1904-03-26 00:00:00	1978-05-08 00:00:00	M.	Grand	GRAND	GRAND LUCIEN	Lucien	\N	\N	284
58816V	1927-05-09 00:00:00	\N	M.	Grandon	GRANDON	GRANDON JACQUES	Jacques	\N	\N	285
000370	1915-10-27 00:00:00	1991-08-03 00:00:00	M.	Gravier	GRAVIER	GRAVIER JEAN	Jean	\N	\N	286
57445J	1905-09-05 00:00:00	2005-07-15 00:00:00	M.	Gravier	GRAVIER	GRAVIER ROBERT	Robert	\N	\N	287
59537V	1925-02-14 00:00:00	2012-07-30 00:00:00	M.	Graziani	GRAZIANI	GRAZIANI PAUL	Paul	\N	2016-12-20 15:55:38	288
000226	1909-11-01 00:00:00	1982-10-22 00:00:00	M.	Gregory	GREGORY	GREGORY LÉON	Léon-Jean	\N	\N	289
59232F	1933-11-16 00:00:00	\N	M.	Grimaldi	GRIMALDI	GRIMALDI ROLAND	Roland	\N	\N	290
000551	1925-06-12 00:00:00	1985-03-11 00:00:00	Mme	Gros	GROS	GROS BRIGITTE	Brigitte	\N	\N	291
000067	1902-05-18 00:00:00	1984-10-08 00:00:00	M.	Gros	GROS	GROS LOUIS	Louis	\N	\N	292
89032Q	1922-07-06 00:00:00	2016-03-03 00:00:00	M.	Guena	GUENA	GUENA YVES	Yves	\N	2016-03-04 17:06:27	293
58949J	1923-03-11 00:00:00	2007-10-25 00:00:00	M.	Guenier	GUENIER	GUENIER JEAN	Jean	\N	\N	294
000224	1909-10-28 00:00:00	1977-03-02 00:00:00	M.	Gueril	GUERIL	GUERIL GEORGES	Georges	\N	\N	295
56531B	1915-12-21 00:00:00	2000-06-09 00:00:00	M.	Gueroui	GUEROUI	GUEROUI MOHAMMED	Mohammed	\N	\N	296
58332E	1910-11-17 00:00:00	2008-11-19 00:00:00	M.	Guillard	GUILLARD	GUILLARD PAUL	Paul	\N	\N	297
59233G	1922-04-25 00:00:00	2004-04-07 00:00:00	M.	Guillaume	GUILLAUME	GUILLAUME ROBERT	Robert	\N	\N	298
58625Q	1913-07-08 00:00:00	2011-11-11 00:00:00	M.	Guillaumot	GUILLAUMOT	GUILLAUMOT PAUL	Paul	\N	\N	299
000216	1909-07-20 00:00:00	1985-11-17 00:00:00	M.	Guille	GUILLE	GUILLE GEORGES	Georges	\N	\N	300
000459	1921-03-06 00:00:00	1998-03-07 00:00:00	M.	Guillou	GUILLOU	GUILLOU LOUIS	Louis	\N	\N	301
59538W	1926-06-02 00:00:00	2010-11-10 00:00:00	M.	Guyomard	GUYOMARD	GUYOMARD BERNARD	Bernard	\N	\N	302
000162	1907-03-28 00:00:00	1962-08-12 00:00:00	M.	Hakiki	HAKIKI	HAKIKI DJILALI	Djilali	\N	\N	303
71018C	1926-02-09 00:00:00	2016-05-01 00:00:00	M.	Girault	GIRAULT	GIRAULT	Jean-Marie	\N	2016-05-03 17:09:42	304
83047W	1942-08-31 00:00:00	\N	M.	Percheron	PERCHERON	PERCHERON	Daniel	\N	\N	305
83017Q	1926-07-06 00:00:00	2010-09-02 00:00:00	M.	Bony	BONY	BONY	Marcel	\N	\N	306
83050R	1938-06-05 00:00:00	\N	M.	de Rohan	de ROHAN	ROHAN (DE)	Josselin	\N	\N	307
81011A	1928-09-10 00:00:00	\N	M.	Le Breton	LE BRETON	LEBRETON	Henri	\N	\N	308
74042Q	1929-09-24 00:00:00	\N	M.	Rausch	RAUSCH	RAUSCH	Jean-Marie	\N	2016-12-14 15:27:39	309
83037U	1924-06-12 00:00:00	2000-04-28 00:00:00	M.	Husson	HUSSON	HUSSON	Roger	\N	\N	310
74013K	1936-01-26 00:00:00	\N	M.	Bohl	BOHL	BOHL	André	\N	\N	311
97008M	1931-08-19 00:00:00	\N	M.	Hesling	HESLING	HESLING	Roger	\N	\N	312
92016Q	1944-07-26 00:00:00	\N	M.	Charmant	CHARMANT	CHARMANT	Marcel	\N	\N	313
97006K	1938-09-11 00:00:00	\N	M.	Lefebvre	LEFEBVRE	LEFEBVRE	Pierre	\N	\N	315
65017N	1919-05-10 00:00:00	2002-02-03 00:00:00	M.	Diligent	DILIGENT	DILIGENT	André	\N	\N	316
97007L	1946-04-01 00:00:00	2002-01-19 00:00:00	Mme	Derycke	DERYCKE	DERYCKE	Dinah	\N	\N	317
92031P	1941-12-02 00:00:00	\N	M.	Legendre	LEGENDRE	LEGENDRE	Jacques	\N	\N	318
92023P	1934-01-11 00:00:00	\N	M.	Foy	FOY	FOY	Alfred	\N	\N	319
85002R	1937-04-26 00:00:00	\N	M.	Renar	RENAR	RENAR	Ivan	\N	\N	320
92044U	1950-01-25 00:00:00	\N	M.	Türk	TÜRK	TURK	Alex	\N	\N	321
92037V	1928-07-05 00:00:00	2013-06-07 00:00:00	M.	Mauroy	MAUROY	MAUROY	Pierre	\N	2013-06-10 09:50:41	322
92042S	1944-11-26 00:00:00	\N	M.	Raoult	RAOULT	RAOULT	Paul	\N	\N	323
83010H	1939-10-27 00:00:00	\N	M.	Allouche	ALLOUCHE	ALLOUCHE	Guy	\N	\N	324
92045V	1947-06-27 00:00:00	\N	M.	Vasselle	VASSELLE	VASSELLE	Alain	\N	\N	325
83054V	1929-04-03 00:00:00	\N	M.	Souplet	SOUPLET	SOUPLET	Michel	\N	\N	326
81001X	1923-07-27 00:00:00	2014-06-08 00:00:00	M.	Soucaret	SOUCARET	SOUCARET	Raymond	\N	2014-06-16 08:25:30	327
83038V	1928-10-04 00:00:00	2013-01-23 00:00:00	M.	Jolibois	JOLIBOIS	JOLIBOIS	Charles	\N	\N	329
83035S	1928-09-04 00:00:00	2009-12-08 00:00:00	M.	Huchon	HUCHON	HUCHON	Jean	\N	\N	330
92025R	1933-11-16 00:00:00	2009-12-18 00:00:00	Mme	Heinis	HEINIS	HEINIS	Anne	\N	\N	331
82002D	1942-06-08 00:00:00	\N	M.	Le Grand	LE GRAND	LEGRAND	Jean-François	\N	\N	332
96004D	1947-08-30 00:00:00	\N	M.	Bizet	BIZET	BIZET	Jean	\N	\N	333
83040P	1923-12-16 00:00:00	2015-02-06 00:00:00	M.	Machet	MACHET	MACHET	Jacques	\N	2015-02-10 09:48:49	334
92010J	1924-10-17 00:00:00	2007-11-21 00:00:00	M.	Bernard	BERNARD	BERNARD JEAN	Jean	\N	\N	335
83056X	1926-02-16 00:00:00	\N	M.	Vecten	VECTEN	VECTEN	Albert	\N	\N	336
74011H	1926-06-13 00:00:00	2004-11-04 00:00:00	M.	Berchet	BERCHET	BERCHET	Georges	\N	\N	337
74008N	1915-03-02 00:00:00	2001-01-26 00:00:00	M.	Ballayer	BALLAYER	BALLAYER	René	\N	\N	338
92009R	1935-02-23 00:00:00	\N	M.	Bernadaux	BERNADAUX	BERNADAUX	Jean	\N	\N	339
83036T	1930-05-24 00:00:00	\N	M.	Huriet	HURIET	HURIET	Claude	\N	\N	340
92007P	1936-03-09 00:00:00	2007-06-21 00:00:00	M.	Baudot	BAUDOT	BAUDOT	Jacques	\N	\N	341
92040Q	1950-09-26 00:00:00	\N	M.	Nachbar	NACHBAR	NACHBAR	Philippe	\N	\N	342
83052T	1920-08-12 00:00:00	2002-03-27 00:00:00	M.	Rufin	RUFIN	RUFIN	Michel	\N	\N	343
74022L	1932-06-23 00:00:00	\N	M.	Herment	HERMENT	HERMENT	Rémi	\N	\N	344
74024N	1921-06-04 00:00:00	2001-02-07 00:00:00	M.	Jeambrun	JEAMBRUN	JEAMBRUN	Pierre	\N	\N	345
89004L	1935-06-13 00:00:00	\N	M.	Jourdain	JOURDAIN	JOURDAIN	André	\N	\N	346
83039W	1938-04-29 00:00:00	2012-10-13 00:00:00	M.	Labeyrie	LABEYRIE	LABEYRIE	Philippe	\N	\N	347
92015P	1944-12-04 00:00:00	\N	M.	Carrère	CARRÈRE	CARRERE	Jean-Louis	\N	\N	348
92022N	1929-07-13 00:00:00	2016-07-25 00:00:00	M.	Fauchon	FAUCHON	FAUCHON	Pierre	\N	2016-07-26 17:00:02	349
92041R	1936-03-09 00:00:00	2012-03-21 00:00:00	M.	Poirieux	POIRIEUX	POIRIEUX	Guy	\N	\N	350
97011G	1946-09-13 00:00:00	\N	M.	Fournier	FOURNIER	FOURNIER BERNARD	Bernard	\N	\N	351
83044T	1920-05-10 00:00:00	2014-04-14 00:00:00	M.	Mercier	MERCIER	MERCIER LOUIS	Louis	\N	2014-04-16 14:21:24	352
78006D	1933-05-13 00:00:00	\N	M.	Gouteyron	GOUTEYRON	GOUTEYRON	Adrien	\N	\N	353
83025Q	1931-02-06 00:00:00	2006-01-21 00:00:00	M.	Dejoie	DEJOIE	DEJOIE	Luc	\N	\N	354
83023N	1936-03-16 00:00:00	2003-08-15 00:00:00	M.	de Cossé-Brissac	de COSSÉ-BRISSAC	COSSE-BRISSAC (DE)	Charles-Henri	\N	\N	355
92019T	1936-07-19 00:00:00	\N	Mme	Dieulangard	DIEULANGARD	DIEULANGARD	Marie-Madeleine	\N	\N	356
92032Q	1938-06-06 00:00:00	\N	M.	Lemaire	LEMAIRE	LEMAIRE	Guy	\N	\N	357
83012K	1935-06-16 00:00:00	\N	M.	Autain	AUTAIN	AUTAIN	François	\N	\N	358
74015M	1921-11-13 00:00:00	2017-05-11 00:00:00	M.	Boyer	BOYER	BOYER LOUIS	Louis	\N	2017-05-15 16:04:18	359
74028S	1915-02-12 00:00:00	2008-01-03 00:00:00	M.	Malécot	MALÉCOT	MALECOT	Kléber	\N	\N	360
92039X	1946-06-17 00:00:00	\N	M.	Miquel	MIQUEL	MIQUEL	Gérard	\N	\N	361
88004G	1931-05-14 00:00:00	2008-09-24 00:00:00	M.	Boyer	BOYER	BOYER ANDRE	André	\N	\N	362
57721K	1919-12-02 00:00:00	2004-06-27 00:00:00	Mme	Edeline	EDELINE	EDELINE HÉLÈNE	Hélène	\N	\N	363
58942B	1911-09-04 00:00:00	2004-01-31 00:00:00	M.	Eeckhoutte	EECKHOUTTE	EECKHOUTTE LÉON	Léon	\N	\N	364
000411	1918-11-22 00:00:00	1986-07-31 00:00:00	M.	Elby	ELBY	ELBY HENRI	Henri	\N	\N	365
59543T	1913-01-27 00:00:00	1998-09-25 00:00:00	M.	Lederman	LEDERMAN	LEDERMAN CHARLES	Charles	\N	\N	366
000280	1911-10-09 00:00:00	1991-10-02 00:00:00	M.	Lefort	LEFORT	LEFORT FERNAND	Fernand	\N	\N	367
000201	1908-09-24 00:00:00	1989-01-30 00:00:00	M.	Legouez	LEGOUEZ	LEGOUEZ MODESTE	Modeste	\N	\N	368
000531	1924-05-15 00:00:00	1997-01-31 00:00:00	M.	Legrand	LEGRAND	LEGRAND BERNARD	Bernard	\N	\N	369
000206	1909-02-19 00:00:00	1995-11-23 00:00:00	M.	Lejeune	LEJEUNE	LEJEUNE MAX	Max	\N	\N	370
000144	1906-05-07 00:00:00	1985-11-15 00:00:00	M.	Lemaire	LEMAIRE	LEMAIRE MARCEL	Marcel	\N	\N	371
000320	1913-07-30 00:00:00	1996-04-24 00:00:00	M.	Lemarié	LEMARIÉ	LEMARIE BERNARD	Bernard	\N	\N	372
59545V	1917-12-20 00:00:00	2005-01-02 00:00:00	M.	Lenglet	LENGLET	LENGLET CHARLES-EDMOND	Charles-Edmond	\N	\N	373
57830P	1919-06-04 00:00:00	2004-03-20 00:00:00	M.	Letoquart	LETOQUART	LETOQUART LÉANDRE	Léandre	\N	\N	374
57130R	1915-08-24 00:00:00	2000-05-15 00:00:00	M.	Levacher	LEVACHER	LEVACHER FRANÇOIS	François	\N	\N	375
89033R	1932-07-22 00:00:00	\N	M.	Leyzour	LEYZOUR	LEYZOUR FÉLIX	Félix	\N	\N	376
000005	1900-02-11 00:00:00	1983-05-25 00:00:00	M.	Lhospied	LHOSPIED	LHOSPIED JEAN	Jean	\N	\N	377
000200	1908-09-18 00:00:00	1982-05-27 00:00:00	M.	Liot	LIOT	LIOT ROBERT	Robert	\N	\N	378
59546W	1927-07-26 00:00:00	\N	M.	Lise	LISE	LISE ROGER	Roger	\N	\N	379
000017	1896-07-27 00:00:00	1969-03-20 00:00:00	M.	Longchambon	LONGCHAMBON	LONGCHAMBON HENRI	Henri	\N	\N	380
000351	1914-11-30 00:00:00	1990-08-11 00:00:00	M.	Longequeue	LONGEQUEUE	LONGEQUEUE LOUIS	Louis	\N	\N	381
59547X	1921-12-12 00:00:00	\N	M.	Louisy	LOUISY	LOUISY FRANÇOIS	François	\N	2017-01-09 09:50:06	382
59548Y	1922-06-29 00:00:00	2002-01-27 00:00:00	M.	Louvot	LOUVOT	LOUVOT PIERRE	Pierre	\N	\N	383
59549A	1922-01-16 00:00:00	2000-12-28 00:00:00	M.	Lucotte	LUCOTTE	LUCOTTE MARCEL	Marcel	\N	\N	384
000633	1933-12-29 00:00:00	1982-08-15 00:00:00	M.	Machefer	MACHEFER	MACHEFER PHILIPPE	Philippe	\N	\N	385
000223	1909-10-22 00:00:00	1987-11-30 00:00:00	M.	Mailhe	MAILHE	MAILHE PIERRE	Pierre	\N	\N	386
58947G	1918-03-24 00:00:00	\N	M.	Malassagne	MALASSAGNE	MALASSAGNE PAUL	Paul	\N	\N	388
59715V	1914-08-19 00:00:00	2004-09-08 00:00:00	M.	Marcellin	MARCELLIN	MARCELLIN RAYMOND	Raymond	\N	\N	389
08015R	1949-02-04 00:00:00	\N	M.	Laurent	LAURENT	LAURENT DANIEL	Daniel	\N	\N	390
58302X	1908-02-09 00:00:00	2004-05-03 00:00:00	M.	Benoist	BENOIST	BENOIST DANIEL	Daniel	\N	2016-01-13 11:16:42	391
56326X	1910-08-11 00:00:00	2004-08-20 00:00:00	M.	Bentchicou	BENTCHICOU	BENTCHICOU AHMED	Ahmed	\N	\N	392
000553	1925-08-21 00:00:00	1997-01-17 00:00:00	M.	Beranger	BERANGER	BERANGER JEAN	Jean	\N	\N	393
59566B	1929-06-07 00:00:00	2014-06-01 00:00:00	M.	Berard	BERARD	BERARD JACQUES	Jacques	\N	2014-06-03 13:43:30	394
95066P	1944-06-23 00:00:00	\N	M.	Weber	WEBER	WEBER	Henri	\N	\N	492
000285	1912-01-11 00:00:00	1973-09-26 00:00:00	M.	Bergeal	BERGEAL	BERGEAL AIMÉ	Aimé	\N	\N	395
59583C	1944-10-11 00:00:00	2009-05-06 00:00:00	M.	Bernard	BERNARD	BERNARD ROLAND	Roland	\N	\N	396
000340	1914-05-27 00:00:00	1989-04-05 00:00:00	M.	Bernier	BERNIER	BERNIER LUCIEN	Lucien	\N	\N	397
000113	1904-11-06 00:00:00	1961-09-19 00:00:00	M.	Bertrand	BERTRAND	BERTRAND MARCEL	Marcel	\N	\N	398
58911T	1926-04-14 00:00:00	\N	M.	Besse	BESSE	BESSE GUY	Guy	\N	\N	399
000036	1900-12-17 00:00:00	1982-10-17 00:00:00	M.	Bethouart	BETHOUART	BETHOUART ANTOINE	Antoine	\N	2016-08-08 17:58:28	400
59522N	1919-04-21 00:00:00	2007-11-19 00:00:00	M.	Bettencourt	BETTENCOURT	BETTENCOURT ANDRÉ	André	\N	\N	401
79002D	1929-10-03 00:00:00	2013-06-10 00:00:00	M.	Bialski	BIALSKI	BIALSKI JACQUES	Jacques	\N	2013-06-12 11:33:35	402
57741P	1915-04-01 00:00:00	2005-02-14 00:00:00	M.	Bac	BAC	BAC JEAN	Jean	\N	\N	403
000016	1900-07-17 00:00:00	1983-10-26 00:00:00	M.	de Bagneux	de BAGNEUX	BAGNEUX JEAN DE	Jean	\N	\N	404
000490	1922-05-31 00:00:00	1984-04-21 00:00:00	M.	Bailly	BAILLY	BAILLY JEAN	Jean	\N	\N	405
000339	1914-04-23 00:00:00	1986-09-19 00:00:00	M.	Bajeux	BAJEUX	BAJEUX OCTAVE	Octave	\N	\N	406
59564Y	1922-07-15 00:00:00	\N	M.	Bangou	BANGOU	BANGOU HENRI	Henri	\N	\N	407
79005G	1924-06-30 00:00:00	1998-02-25 00:00:00	M.	Barbier	BARBIER	BARBIER BERNARD	Bernard	\N	\N	408
000282	1912-01-02 00:00:00	1982-10-28 00:00:00	M.	Barbier	BARBIER	BARBIER PIERRE	Pierre	\N	\N	409
58109Y	1923-05-06 00:00:00	2004-03-15 00:00:00	M.	Bardol	BARDOL	BARDOL JEAN	Jean	\N	\N	410
58515K	1930-01-01 00:00:00	\N	M.	Barkat-Gourat	BARKAT-GOURAT	BARKAT-GOURAT HAMADOU	Hamadou	\N	\N	411
000002	1900-01-12 00:00:00	1975-11-08 00:00:00	M.	Barrachin	BARRACHIN	BARRACHIN EDMOND	Edmond	\N	\N	412
000529	1924-05-04 00:00:00	1990-04-11 00:00:00	M.	Barras	BARRAS	BARRAS JEAN	Jean	\N	\N	413
000277	1911-09-10 00:00:00	1986-04-06 00:00:00	M.	Barroux	BARROUX	BARROUX ANDRÉ	André	\N	\N	414
000400	1918-03-06 00:00:00	2006-02-17 00:00:00	M.	Baumel	BAUMEL	BAUMEL JACQUES	Jacques	\N	\N	415
59721T	1943-02-05 00:00:00	\N	M.	Baumet	BAUMET	BAUMET 	Gilbert	\N	2016-12-14 15:17:37	416
000663	1947-09-27 00:00:00	\N	M.	Bayle	BAYLE	BAYLE JEAN-PIERRE	Jean-Pierre	\N	\N	417
000116	1905-03-02 00:00:00	1996-12-29 00:00:00	M.	Bayrou	BAYROU	BAYROU MAURICE	Maurice	\N	\N	418
58819Y	1931-10-09 00:00:00	\N	M.	Becam	BECAM	BECAM MARC	Marc	\N	\N	419
000091	1903-11-10 00:00:00	1983-05-23 00:00:00	M.	Belabed	BELABED	BELABED MOHAMED	Mohamed	\N	2016-08-08 17:27:46	420
000425	1919-06-12 00:00:00	1989-11-26 00:00:00	M.	Ahmed	AHMED	AHMED ABDALLAH ABDERAMANE	Abdallah Abderamane	\N	\N	421
57316A	1918-08-23 00:00:00	1998-12-02 00:00:00	M.	Abdellatif	ABDELLATIF	ABDELLATIF MOHAMED	Mohamed	\N	2015-04-24 11:07:48	422
000346	1914-09-07 00:00:00	1992-12-15 00:00:00	M.	Achour	ACHOUR	ACHOUR YOUSSEF	Youssef	\N	\N	423
000448	1920-09-13 00:00:00	1983-08-06 00:00:00	M.	Agarande	AGARANDE	AGARANDE HENRI	Henri	\N	\N	424
59533R	1923-12-17 00:00:00	2010-10-31 00:00:00	M.	D'Aillieres	D'AILLIERES	AILLIERES MICHEL (D')	Michel	\N	\N	425
000260	1910-11-25 00:00:00	1993-05-01 00:00:00	M.	Al Sid Cheikh	AL SID CHEIKH	AL SID CHEIKH CHEIKH	Cheikh	\N	\N	426
74019R	1915-08-15 00:00:00	2007-12-11 00:00:00	M.	de Cuttoli	de CUTTOLI	CUTTOLI (DE)	Charles	\N	\N	427
77002U	1933-07-02 00:00:00	\N	M.	Cantegrit	CANTEGRIT	CANTEGRIT	Jean-Pierre	\N	\N	428
92034S	1927-06-09 00:00:00	\N	M.	Maman	MAMAN	MAMAN	André	\N	\N	429
90002A	1918-08-08 00:00:00	2007-10-19 00:00:00	M.	Durand-Chastel	DURAND-CHASTEL	DURAND-CHASTEL	Hubert	\N	\N	430
74032N	1922-08-01 00:00:00	2002-05-24 00:00:00	M.	d'Ornano	D'ORNANO	ORNANO (D')	Paul	\N	\N	431
58343H	1924-03-20 00:00:00	2016-03-15 00:00:00	Mme	Alduy	ALDUY	ALDUY JACQUELINE	Jacqueline	\N	2016-03-25 10:27:17	432
59213C	1914-10-04 00:00:00	2006-01-23 00:00:00	M.	Alduy	ALDUY	ALDUY PAUL	Paul	\N	\N	433
000087	1903-09-19 00:00:00	1988-11-11 00:00:00	M.	Allies	ALLIES	ALLIES CHARLES	Charles	\N	\N	434
59214D	1927-05-28 00:00:00	2012-03-08 00:00:00	M.	Amelin	AMELIN	AMELIN JEAN	Jean	\N	\N	435
57716N	1921-09-11 00:00:00	2006-08-14 00:00:00	M.	Amic	AMIC	AMIC AUGUSTE	Auguste	\N	\N	436
59215E	1917-04-24 00:00:00	2005-09-22 00:00:00	M.	D'Andigne	D'ANDIGNE	ANDIGNE HUBERT (D')	Hubert	\N	\N	437
000465	1921-07-05 00:00:00	1998-03-25 00:00:00	Mme	Anglade	ANGLADE	ANGLADE MAGDELEINE	Magdeleine	\N	\N	438
000037	1901-01-10 00:00:00	1974-03-11 00:00:00	M.	Armengaud	ARMENGAUD	ARMENGAUD ANDRÉ	André	\N	\N	439
59520L	1917-12-13 00:00:00	2001-03-21 00:00:00	M.	Arreckx	ARRECKX	ARRECKX MAURICE	Maurice	\N	\N	440
000012	1900-05-07 00:00:00	1962-03-06 00:00:00	M.	Auberger	AUBERGER	AUBERGER FERNAND	Fernand	\N	\N	441
000146	1906-07-29 00:00:00	1969-08-22 00:00:00	M.	Aubert	AUBERT	AUBERT EMILE	Emile	\N	2016-08-04 16:00:26	442
000051	1901-08-15 00:00:00	1994-01-06 00:00:00	M.	Aubin	AUBIN	AUBIN JEAN	Jean	\N	\N	443
58614M	1931-08-01 00:00:00	\N	M.	Aubry	AUBRY	AUBRY ANDRÉ	André	\N	\N	444
000098	1904-04-26 00:00:00	1981-06-23 00:00:00	M.	Auburtin	AUBURTIN	AUBURTIN JEAN	Jean	\N	\N	445
000292	1912-04-02 00:00:00	1968-01-06 00:00:00	M.	Audy	AUDY	AUDY MARCEL	Marcel	\N	\N	446
95010W	1941-10-27 00:00:00	\N	M.	Billard	BILLARD	BILLARD CLAUDE	Claude	\N	\N	447
58328J	1910-08-29 00:00:00	2004-10-02 00:00:00	M.	Billeres	BILLERES	BILLERES RENÉ	René	\N	\N	448
000083	1903-08-28 00:00:00	1983-04-25 00:00:00	M.	Billiemaz	BILLIEMAZ	BILLIEMAZ AUGUSTE	Auguste	\N	\N	449
59567C	1920-09-11 00:00:00	2004-09-29 00:00:00	M.	Blanc	BLANC	BLANC JEAN-PIERRE	Jean-Pierre	\N	\N	450
57426F	1914-02-28 00:00:00	2000-07-28 00:00:00	M.	Blanchet	BLANCHET	BLANCHET JEAN-PIERRE	Jean-Pierre	\N	2015-08-24 17:13:17	451
000165	1907-06-13 00:00:00	1971-02-25 00:00:00	M.	Blondelle	BLONDELLE	BLONDELLE RENÉ	René	\N	\N	452
000634	1934-01-08 00:00:00	1993-08-27 00:00:00	M.	Boeuf	BOEUF	BOEUF MARC	Marc	\N	\N	453
59218H	1914-06-01 00:00:00	2001-09-12 00:00:00	M.	Boileau	BOILEAU	BOILEAU ROGER	Roger	\N	\N	454
000176	1908-02-20 00:00:00	1987-05-19 00:00:00	M.	Boin	BOIN	BOIN RAYMOND	Raymond	\N	\N	455
58920U	1919-11-30 00:00:00	\N	M.	Bonduel	BONDUEL	BONDUEL STÉPHANE	Stéphane	\N	\N	456
58921V	1919-07-19 00:00:00	2017-01-28 00:00:00	M.	Bonifay	BONIFAY	BONIFAY CHARLES	Charles	\N	2017-02-23 17:23:18	457
58041V	1922-04-20 00:00:00	2003-07-17 00:00:00	M.	Bonnet	BONNET	BONNET EUGÈNE	Eugène	\N	\N	458
000160	1907-02-15 00:00:00	1973-06-25 00:00:00	M.	Bonnet	BONNET	BONNET GEORGES	Georges	\N	\N	459
000198	1908-08-28 00:00:00	1981-01-03 00:00:00	M.	Bordeneuve	BORDENEUVE	BORDENEUVE JACQUES	Jacques	\N	\N	460
000081	1903-07-25 00:00:00	1981-02-06 00:00:00	M.	Bossus	BOSSUS	BOSSUS RAYMOND	Raymond	\N	\N	461
58620K	1929-03-22 00:00:00	\N	M.	Boucheny	BOUCHENY	BOUCHENY SERGE	Serge	\N	\N	462
000328	1913-11-23 00:00:00	1995-05-29 00:00:00	M.	Boulangé	BOULANGÉ	BOULANGE MARCEL	Marcel	\N	\N	463
000316	1913-07-04 00:00:00	1976-11-14 00:00:00	M.	Boulanger	BOULANGER	BOULANGER GEORGES	Georges	\N	\N	464
000374	1916-06-06 00:00:00	1992-01-22 00:00:00	M.	Bouloux	BOULOUX	BOULOUX JEAN-MARIE	Jean-Marie	\N	\N	465
59217G	1927-10-22 00:00:00	\N	M.	Belin	BELIN	BELIN GILBERT	Gilbert	\N	\N	466
000234	1910-01-06 00:00:00	\N	M.	Belkadi	BELKADI	BELKADI ABDENNOUR	Abdennour	\N	\N	467
57701F	1922-01-01 00:00:00	2002-02-17 00:00:00	M.	Beloucif	BELOUCIF	BELOUCIF AMAR	Amar	\N	\N	468
000021	1900-07-06 00:00:00	1961-11-12 00:00:00	M.	Benacer	BENACER	BENACER SALAH	Salah	\N	\N	469
000541	1924-12-09 00:00:00	1987-02-02 00:00:00	M.	Benard	BENARD	BENARD PAUL	Paul	\N	\N	470
000321	1913-08-02 00:00:00	1996-05-29 00:00:00	M.	Benard Mousseaux	BENARD MOUSSEAUX	BENARD MOUSSEAUX JEAN	Jean	\N	\N	471
000665	1902-01-01 00:00:00	1982-12-23 00:00:00	M.	Bencherif	BENCHERIF	BENCHERIF MOUAOUIA	Mouaouia	\N	\N	472
000047	1901-07-12 00:00:00	1992-04-26 00:00:00	M.	Bene	BENE	BENE JEAN	Jean	\N	2017-10-10 17:42:19	473
59309K	1930-07-29 00:00:00	\N	M.	Benedetti	BENEDETTI	BENEDETTI GEORGES	Georges	\N	\N	474
88013H	1919-10-16 00:00:00	2015-02-07 00:00:00	M.	Lanier	LANIER	LANIER	Lucien	\N	2015-02-10 17:08:07	475
95057N	1929-12-01 00:00:00	2007-01-30 00:00:00	M.	Poirier	POIRIER	POIRIER JEAN-MARIE	Jean-Marie	\N	\N	476
95032D	1944-01-12 00:00:00	2014-11-01 00:00:00	M.	Fischer	FISCHER	FISCHER	Guy	\N	2014-11-04 11:24:30	477
95040D	1934-10-26 00:00:00	\N	M.	Joly	JOLY	JOLY	Bernard	\N	\N	478
95041E	1954-01-15 00:00:00	\N	M.	Joyandet	JOYANDET	JOYANDET	Alain	\N	\N	479
95030B	1944-03-20 00:00:00	\N	M.	Émorine	ÉMORINE	EMORINE	Jean-Paul	\N	2016-10-31 11:47:29	480
86043F	1928-11-30 00:00:00	\N	M.	Pourny	POURNY	POURNY	André	\N	\N	481
95020Y	1951-05-20 00:00:00	\N	M.	Courtois	COURTOIS	COURTOIS	Jean-Patrick	\N	2014-09-28 20:33:07	482
77012W	1934-11-17 00:00:00	\N	M.	Chaumont	CHAUMONT	CHAUMONT	Jacques	\N	\N	483
77043E	1940-03-12 00:00:00	\N	M.	du Luart	du LUART	LUART ROLAND (DU)	Roland	\N	\N	484
95008D	1951-01-09 00:00:00	\N	M.	Barnier	BARNIER	BARNIER	Michel	\N	\N	485
77060F	1933-06-16 00:00:00	\N	M.	Rinchet	RINCHET	RINCHET	Roger	\N	\N	486
95015C	1948-06-09 00:00:00	\N	M.	Carle	CARLE	CARLE	Jean-Claude	\N	2014-09-28 20:34:51	487
95038K	1945-06-12 00:00:00	\N	M.	Hérisson	HÉRISSON	HERISSON	Pierre	\N	2013-10-14 17:04:46	488
95005A	1950-03-30 00:00:00	\N	M.	Amoudry	AMOUDRY	AMOUDRY	Jean-Paul	\N	2013-10-17 10:43:26	489
95014B	1946-04-23 00:00:00	\N	Mme	Bocandé	BOCANDÉ	BOCANDE	Annick	\N	\N	490
95062K	1937-11-09 00:00:00	\N	M.	Revet	REVET	REVET	Charles	\N	2014-09-28 20:36:20	491
000602	1929-08-29 00:00:00	1978-08-27 00:00:00	M.	Hamecher	HAMECHER	HAMECHER MARCEAU	Marceau	\N	\N	1
58115W	1925-10-03 00:00:00	\N	M.	Hammann	HAMMANN	HAMMANN JEAN-PAUL	Jean-Paul	\N	\N	2
000218	1909-09-09 00:00:00	1980-10-24 00:00:00	M.	Hamon	HAMON	HAMON YVES	Yves	\N	\N	3
000186	1908-06-13 00:00:00	1981-10-09 00:00:00	M.	de Hauteclocque	de HAUTECLOCQUE	HAUTECLOCQUE BAUDOUIN DE	Baudouin	\N	\N	4
000310	1913-03-10 00:00:00	1993-01-18 00:00:00	Mme	de Hauteclocque	de HAUTECLOCQUE	HAUTECLOCQUE NICOLE DE	Nicole	\N	\N	5
000406	1918-08-16 00:00:00	1978-06-09 00:00:00	M.	Heder	HEDER	HEDER LÉOPOLD	Léopold	\N	\N	6
000397	1918-01-04 00:00:00	1996-12-24 00:00:00	M.	Dailly	DAILLY	DAILLY ETIENNE	Etienne	\N	\N	7
000416	1919-04-13 00:00:00	1982-10-01 00:00:00	M.	Dardel	DARDEL	DARDEL GEORGES	Georges	\N	\N	8
000524	1924-03-05 00:00:00	1992-01-06 00:00:00	M.	Darras	DARRAS	DARRAS MICHEL	Michel	\N	\N	9
000438	1919-12-14 00:00:00	1995-12-30 00:00:00	M.	Daugnac	DAUGNAC	DAUGNAC ANDRÉ	André	\N	\N	10
58019X	1924-03-01 00:00:00	2013-05-08 00:00:00	M.	David	DAVID	DAVID JEAN	Jean	\N	2013-05-14 16:39:00	11
57826T	1901-06-19 00:00:00	2000-08-26 00:00:00	M.	David	DAVID	DAVID LÉON	Léon	\N	\N	12
000031	1900-11-13 00:00:00	1981-12-10 00:00:00	M.	Debesson	DEBESSON	DEBESSON RENÉ	René	\N	\N	13
000194	1908-08-10 00:00:00	1994-03-30 00:00:00	M.	Deblock	DEBLOCK	DEBLOCK ROGER	Roger	\N	\N	14
000250	1910-09-14 00:00:00	1986-05-07 00:00:00	M.	Defferre	DEFFERRE	DEFFERRE GASTON	Gaston	\N	\N	15
000199	1908-07-09 00:00:00	1997-10-07 00:00:00	M.	Delalande	DELALANDE	DELALANDE JACQUES	Jacques	\N	\N	16
59226H	1924-05-23 00:00:00	2012-09-04 00:00:00	M.	Delelis	DELELIS	DELELIS ANDRÉ	André	\N	\N	17
59572Y	1919-05-14 00:00:00	2016-06-22 00:00:00	M.	Delga	DELGA	DELGA FRANÇOIS	François	\N	2016-06-28 13:37:04	18
000188	1908-01-21 00:00:00	1980-09-03 00:00:00	M.	Delorme	DELORME	DELORME CLAUDIUS	Claudius	\N	\N	19
92018S	1947-06-18 00:00:00	\N	Mme	Demessine	DEMESSINE	DEMESSINE MICHELLE	Michelle	\N	\N	20
000180	1908-03-09 00:00:00	1996-10-26 00:00:00	Mme	Dervaux	DERVAUX	DERVAUX RENÉE	Renée	\N	\N	21
58670V	1935-05-10 00:00:00	\N	M.	Desbriere	DESBRIERE	DESBRIERE BERNARD	Bernard	\N	\N	22
000331	1914-01-21 00:00:00	1993-10-31 00:00:00	M.	Descours Desacres	DESCOURS DESACRES	DESCOURS DESACRES JACQUES	Jacques	\N	\N	23
58367R	1910-06-03 00:00:00	1999-10-23 00:00:00	M.	Desmarets	DESMARETS	DESMARETS JEAN	Jean	\N	\N	24
86001U	1925-08-29 00:00:00	\N	M.	Dessaigne	DESSAIGNE	DESSAIGNE GEORGES	Georges	\N	\N	25
000084	1903-08-21 00:00:00	1990-07-15 00:00:00	M.	Desseigne	DESSEIGNE	DESSEIGNE HENRI	Henri	\N	\N	26
58043X	1921-06-21 00:00:00	2010-04-08 00:00:00	M.	Deveze	DEVEZE	DEVEZE GILBERT	Gilbert	\N	\N	27
58943C	1909-12-30 00:00:00	2000-01-28 00:00:00	M.	Didier	DIDIER	DIDIER EMILE	Emile	\N	\N	28
000220	1909-09-24 00:00:00	1980-06-25 00:00:00	M.	Driant	DRIANT	DRIANT PAUL	Paul	\N	\N	29
58330C	1923-05-05 00:00:00	\N	M.	Dubanchet	DUBANCHET	DUBANCHET FRANÇOIS	François	\N	\N	30
000203	1908-11-30 00:00:00	1991-06-16 00:00:00	M.	Dubois	DUBOIS	DUBOIS HECTOR	Hector	\N	\N	31
59227J	1924-05-06 00:00:00	2012-12-07 00:00:00	M.	Duboscq	DUBOSCQ	DUBOSCQ FRANZ	Franz	\N	\N	32
000105	1904-07-04 00:00:00	1981-09-06 00:00:00	M.	Duchet	DUCHET	DUCHET ROGER	Roger	\N	\N	33
000164	1907-06-07 00:00:00	1987-05-11 00:00:00	M.	Duffaut	DUFFAUT	DUFFAUT HENRI	Henri	\N	\N	34
000011	1900-04-12 00:00:00	1973-03-05 00:00:00	M.	Dulin	DULIN	DULIN ANDRÉ	André	\N	\N	35
000009	1896-03-13 00:00:00	1989-11-14 00:00:00	M.	Dumas	DUMAS	DUMAS ALEXANDRE	Alexandre	\N	\N	36
59531P	1924-11-15 00:00:00	2004-02-04 00:00:00	M.	Dumas	DUMAS	DUMAS PIERRE	Pierre	\N	\N	37
000511	1923-07-06 00:00:00	1979-08-23 00:00:00	M.	Dumont	DUMONT	DUMONT CLAUDE	Claude	\N	\N	38
59573A	1930-11-27 00:00:00	\N	M.	Dumont	DUMONT	DUMONT JEAN	Jean	\N	\N	39
58420D	1925-10-13 00:00:00	2009-05-09 00:00:00	M.	Dumont	DUMONT	DUMONT RAYMOND	Raymond	\N	\N	40
000041	1901-04-15 00:00:00	1983-03-28 00:00:00	M.	Durand	DURAND	DURAND CHARLES	Charles	\N	\N	41
000255	1910-10-21 00:00:00	1981-10-12 00:00:00	M.	Durand	DURAND	DURAND HUBERT	Hubert	\N	\N	42
000647	1939-02-18 00:00:00	1991-01-05 00:00:00	M.	Durand	DURAND	DURAND JACQUES	Jacques	\N	\N	43
58643S	1910-03-12 00:00:00	2003-12-24 00:00:00	M.	Durand	DURAND	DURAND YVES	Yves	\N	\N	44
59509R	1942-04-01 00:00:00	\N	M.	Durbec	DURBEC	DURBEC GUY	Guy	\N	\N	45
000122	1905-05-13 00:00:00	1995-05-05 00:00:00	M.	Durieux	DURIEUX	DURIEUX EMILE	Emile	\N	\N	46
59305F	1917-09-05 00:00:00	2011-03-16 00:00:00	M.	Duromea	DUROMEA	DUROMEA ANDRÉ	André	\N	\N	47
000134	1905-09-29 00:00:00	1980-07-20 00:00:00	M.	Dutoit	DUTOIT	DUTOIT ADOLPHE	Adolphe	\N	\N	48
000082	1903-08-10 00:00:00	1984-06-28 00:00:00	M.	Duval	DUVAL	DUVAL FRANCOIS	François	\N	\N	49
58630M	1919-05-25 00:00:00	2009-07-29 00:00:00	M.	Eberhard	EBERHARD	EBERHARD JACQUES	Jacques	\N	\N	50
000215	1909-07-12 00:00:00	1971-01-17 00:00:00	M.	Errecart	ERRECART	ERRECART JEAN	Jean	\N	\N	51
58351H	1925-09-08 00:00:00	\N	M.	Espagnac	ESPAGNAC	ESPAGNAC RAYMOND	Raymond	\N	\N	52
000057	1901-11-18 00:00:00	1989-04-30 00:00:00	M.	Faggianelli	FAGGIANELLI	FAGGIANELLI JACQUES	Jacques	\N	\N	53
58934B	1916-12-30 00:00:00	2011-07-08 00:00:00	M.	Faigt	FAIGT	FAIGT JULES	Jules	\N	\N	54
000380	1916-11-07 00:00:00	1985-07-10 00:00:00	M.	Fastinger	FASTINGER	FASTINGER PIERRE	Pierre	\N	\N	55
000197	1908-08-18 00:00:00	1988-03-30 00:00:00	M.	Faure	FAURE	FAURE EDGAR	Edgar	\N	\N	56
58818X	1922-01-02 00:00:00	2014-03-06 00:00:00	M.	Faure	FAURE	FAURE MAURICE	Maurice	\N	2014-03-07 14:16:58	57
000177	1908-02-23 00:00:00	1996-08-17 00:00:00	M.	Ferrant	FERRANT	FERRANT CHARLES	Charles	\N	\N	58
000075	1903-04-18 00:00:00	1989-11-03 00:00:00	M.	Ferre	FERRE	FERRE MANUEL	Manuel	\N	\N	59
56905M	1914-04-16 00:00:00	2002-03-07 00:00:00	M.	Fichoux	FICHOUX	FICHOUX JEAN	Jean	\N	\N	60
000405	1918-07-06 00:00:00	1982-11-18 00:00:00	M.	Touzet	TOUZET	TOUZET RENÉ	René	\N	\N	61
59249Q	1919-10-14 00:00:00	2016-10-05 00:00:00	M.	Travert	TRAVERT	TRAVERT RENÉ	René	\N	2016-10-07 10:09:07	62
59561V	1921-09-02 00:00:00	2006-05-18 00:00:00	M.	Treille	TREILLE	TREILLE GEORGES	Georges	\N	\N	63
59250H	1928-12-13 00:00:00	2013-09-03 00:00:00	M.	Ukeiwe	UKEIWE	UKEIWE DICK	Dick	\N	2013-09-05 10:09:01	64
000311	1913-03-10 00:00:00	1997-09-06 00:00:00	M.	Valcin	VALCIN	VALCIN EDMOND	Edmond	\N	\N	65
55510R	1918-11-22 00:00:00	2009-08-09 00:00:00	M.	Vallin	VALLIN	VALLIN CAMILLE	Camille	\N	\N	66
59582B	1927-11-10 00:00:00	2016-10-24 00:00:00	M.	Vallon	VALLON	VALLON PIERRE	Pierre	\N	2016-10-24 17:50:26	67
000074	1903-03-07 00:00:00	1980-07-18 00:00:00	M.	Vanrullen	VANRULLEN	VANRULLEN EMILE	Emile	\N	\N	68
000377	1916-09-14 00:00:00	1984-12-03 00:00:00	M.	Varlet	VARLET	VARLET JEAN	Jean	\N	\N	69
000078	1903-07-01 00:00:00	1995-12-25 00:00:00	M.	Vassor	VASSOR	VASSOR JACQUES	Jacques	\N	\N	70
000154	1906-09-26 00:00:00	1974-10-19 00:00:00	M.	Verdeille	VERDEILLE	VERDEILLE FERNAND	Fernand	\N	\N	71
58048D	1906-10-14 00:00:00	2001-06-08 00:00:00	M.	Verillon	VERILLON	VERILLON MAURICE	Maurice	\N	\N	72
95067Q	1951-02-17 00:00:00	\N	M.	Vial	VIAL	VIAL JEAN-PIERRE	Jean-Pierre	\N	2014-09-28 20:34:26	73
000354	1914-12-24 00:00:00	1992-10-08 00:00:00	M.	Vigier	VIGIER	VIGIER JEAN-LOUIS	Jean-Louis	\N	2017-01-05 11:08:22	74
000259	1910-11-17 00:00:00	1989-10-09 00:00:00	M.	Vignon	VIGNON	VIGNON ROBERT	Robert	\N	\N	75
000283	1912-01-02 00:00:00	1975-07-21 00:00:00	M.	Villatte	VILLATTE	VILLATTE RAYMOND	Raymond	\N	\N	76
59251J	1934-08-09 00:00:00	2002-09-14 00:00:00	M.	Virapoulle	VIRAPOULLE	VIRAPOULLE LOUIS	Louis	\N	\N	77
59252K	1922-01-19 00:00:00	2007-12-25 00:00:00	M.	Viron	VIRON	VIRON HECTOR	Hector	\N	\N	78
59562W	1924-01-30 00:00:00	\N	M.	Vizet	VIZET	VIZET ROBERT	Robert	\N	\N	79
59563X	1915-02-17 00:00:00	1999-08-02 00:00:00	M.	Voilquin	VOILQUIN	VOILQUIN ALBERT	Albert	\N	\N	80
59253L	1918-03-28 00:00:00	2008-06-28 00:00:00	M.	Voisin	VOISIN	VOISIN ANDRÉ	André	\N	\N	81
000148	1906-08-10 00:00:00	1974-05-01 00:00:00	M.	Wach	WACH	WACH PAUL	Paul	\N	\N	82
59308J	1930-05-28 00:00:00	2008-09-19 00:00:00	M.	Wacheux	WACHEUX	WACHEUX MARCEL	Marcel	\N	\N	83
000239	1910-03-25 00:00:00	1984-05-29 00:00:00	M.	de Wazieres	de WAZIERES	WAZIERES RAYMOND DE	Raymond	\N	\N	84
58647W	1915-04-11 00:00:00	1999-07-13 00:00:00	M.	Wirth	WIRTH	WIRTH FRÉDÉRIC	Frédéric	\N	\N	85
000029	1888-07-01 00:00:00	1988-05-10 00:00:00	M.	Yanat	YANAT	YANAT MOULOUD	Mouloud	\N	\N	86
000169	1907-09-17 00:00:00	1979-01-10 00:00:00	M.	Yver	YVER	YVER MICHEL	Michel	\N	\N	87
58355M	1906-08-28 00:00:00	1998-07-07 00:00:00	M.	Yvon	YVON	YVON JOSEPH	Joseph	\N	\N	88
58655W	1920-03-26 00:00:00	2005-09-27 00:00:00	M.	Zwickert	ZWICKERT	ZWICKERT CHARLES	Charles	\N	\N	89
98005N	1947-07-07 00:00:00	\N	M.	Laufoaulu	LAUFOAULU	LAUFOAULU	Robert	\N	\N	90
98006P	1951-12-30 00:00:00	\N	M.	Bel	BEL	BEL	Jean-Pierre	\N	\N	91
98008R	1933-11-13 00:00:00	\N	M.	Natali	NATALI	NATALI PAUL	Paul	\N	\N	92
98009S	1936-03-25 00:00:00	\N	M.	Godard	GODARD	GODARD	Serge	\N	\N	93
98010K	1949-08-02 00:00:00	\N	M.	Plancade	PLANCADE	PLANCADE	Jean-Pierre	\N	2013-10-29 10:48:10	94
98011L	1947-01-18 00:00:00	\N	M.	Auban	AUBAN	AUBAN	Bertrand	\N	\N	95
98012M	1946-08-09 00:00:00	2006-06-29 00:00:00	M.	Trémel	TRÉMEL	TREMEL	Pierre-Yvon	\N	\N	96
98014P	1935-04-15 00:00:00	\N	M.	Branger	BRANGER	BRANGER	Jean-Guy	\N	\N	97
98017S	1932-07-04 00:00:00	2010-10-23 00:00:00	M.	Giraud	GIRAUD	GIRAUD FRANCIS	Francis	\N	\N	98
58926B	1910-04-12 00:00:00	\N	Mlle	Rapuzzi	RAPUZZI	RAPUZZI IRMA	Irma	\N	\N	1005
000055	1901-10-15 00:00:00	1995-04-01 00:00:00	M.	Villard	VILLARD	VILLARD YVES	Yves	\N	\N	1006
98016R	1949-04-10 00:00:00	\N	M.	Bret	BRET	BRET	Robert	\N	\N	1007
000064	1899-04-30 00:00:00	1994-01-29 00:00:00	M.	Benali	BENALI	BENALI BRAHIM	Brahim	\N	\N	1008
57773X	1910-05-03 00:00:00	2000-10-19 00:00:00	Mme	Alexandre Debray	ALEXANDRE DEBRAY	ALEXANDRE DEBRAY JANINE	Janine	\N	\N	1009
95033E	1933-09-10 00:00:00	\N	M.	Franchis	FRANCHIS	FRANCHIS	Serge	\N	\N	1010
95017E	1933-12-27 00:00:00	\N	M.	Chabroux	CHABROUX	CHABROUX	Gilbert	\N	\N	1011
92035T	1950-01-28 00:00:00	\N	M.	Marini	MARINI	MARINI	Philippe	\N	2013-10-08 11:49:36	1012
89013M	1936-07-11 00:00:00	\N	M.	Belot	BELOT	BELOT	Claude	\N	\N	1013
59525R	1919-09-21 00:00:00	2009-03-19 00:00:00	M.	Carat	CARAT	CARAT JACQUES	Jacques	\N	\N	1014
58657Y	1921-02-06 00:00:00	2004-12-31 00:00:00	M.	Ceccaldi-Pavard	CECCALDI-PAVARD	CECCALDI-PAVARD PIERRE	Pierre	\N	\N	1015
000066	1902-05-11 00:00:00	1976-04-06 00:00:00	M.	Delagnes	DELAGNES	DELAGNES ROGER	Roger	\N	\N	1016
000599	1929-07-14 00:00:00	2011-10-27 00:00:00	M.	Giraud	GIRAUD	GIRAUD MICHEL	Michel	\N	\N	1017
57135W	1915-08-15 00:00:00	1998-11-08 00:00:00	M.	Monteil	MONTEIL	MONTEIL ANDRÉ	André	\N	\N	1018
000242	1910-05-26 00:00:00	1983-04-18 00:00:00	M.	Motte	MOTTE	MOTTE EUGÈNE	Eugène	\N	\N	1019
57146A	1911-01-06 00:00:00	2003-08-10 00:00:00	M.	Rougeron	ROUGERON	ROUGERON GEORGES	Georges	\N	\N	1020
000117	1905-03-10 00:00:00	1991-01-03 00:00:00	M.	Vivier	VIVIER	VIVIER 	Emile	\N	2013-11-22 09:50:55	1021
98031Q	1947-07-14 00:00:00	\N	M.	Darcos	DARCOS	DARCOS	Xavier	\N	2016-12-14 15:19:08	1022
01033N	1948-02-03 00:00:00	\N	Mme	Henneron	HENNERON	HENNERON	Françoise	\N	\N	1023
01034P	1939-03-29 00:00:00	\N	M.	Vanlerenberghe	VANLERENBERGHE	VANLERENBERGHE	Jean-Marie	\N	2013-10-28 17:51:52	1024
01038T	2005-12-14 00:00:00	\N	Mme	Mathon-Poinat	MATHON-POINAT	MATHON-POINAT	Josiane	\N	\N	1026
01039U	1955-04-10 00:00:00	\N	M.	Thiollière	THIOLLIÈRE	THIOLLIERE	Michel	\N	\N	1027
01040M	1932-12-02 00:00:00	\N	M.	Guerry	GUERRY	GUERRY	Michel	\N	\N	1028
01044R	1952-09-22 00:00:00	\N	Mme	Blandin	BLANDIN	BLANDIN	Marie-Christine	\N	\N	1029
01045S	1950-09-06 00:00:00	\N	Mme	Desmarescaux	DESMARESCAUX	DESMARESCAUX	Sylvie	\N	\N	1030
01046T	1940-03-03 00:00:00	\N	M.	Barbier	BARBIER	BARBIER GILBERT	Gilbert	\N	\N	1031
01047U	1958-12-14 00:00:00	\N	M.	Zocchetto	ZOCCHETTO	ZOCCHETTO	François	\N	2013-10-15 18:00:06	1032
01048V	1946-02-24 00:00:00	\N	M.	Longuet	LONGUET	LONGUET	Gérard	\N	\N	1033
01049W	1936-05-15 00:00:00	\N	M.	Biwer	BIWER	BIWER	Claude	\N	\N	1034
01050P	1942-02-14 00:00:00	\N	M.	Soulage	SOULAGE	SOULAGE	Daniel	\N	\N	1035
01051Q	1950-09-04 00:00:00	\N	M.	Boulaud	BOULAUD	BOULAUD	Didier	\N	\N	1036
01053S	1945-01-25 00:00:00	2014-06-11 00:00:00	M.	Gautier	GAUTIER	GAUTIER CHARLES	Charles	\N	2014-06-13 09:14:00	1037
01054T	1934-10-05 00:00:00	\N	Mme	Papon	PAPON	PAPON	Monique	\N	\N	1038
01055U	1938-12-09 00:00:00	\N	Mme	Gautier	GAUTIER	GAUTIER GISELE	Gisèle	\N	\N	1039
01056V	1947-10-24 00:00:00	\N	M.	Trillard	TRILLARD	TRILLARD	André	\N	2013-10-08 16:33:25	1040
01057W	1952-04-06 00:00:00	\N	M.	Guené	GUENÉ	GUENE	Charles	\N	2013-10-10 13:32:18	1041
01058X	1951-02-19 00:00:00	\N	M.	Sido	SIDO	SIDO	Bruno	\N	\N	1042
01060R	1947-03-25 00:00:00	\N	M.	Masson	MASSON	MASSON JEANLOUIS	Jean Louis	\N	\N	1043
01061S	1940-02-03 00:00:00	\N	M.	Leroy	LEROY	LEROY PHILIPPE	Philippe	\N	\N	1044
01062T	1952-03-12 00:00:00	\N	M.	Todeschini	TODESCHINI	TODESCHINI	Jean-Marc	\N	2017-04-24 17:51:35	1045
01019Q	1943-03-03 00:00:00	\N	M.	Saugey	SAUGEY	SAUGEY	Bernard	\N	\N	1046
01041N	1941-05-17 00:00:00	\N	M.	Duvernois	DUVERNOIS	DUVERNOIS	Louis	\N	\N	1047
01063U	1943-07-11 00:00:00	\N	M.	Cointat	COINTAT	COINTAT	Christian	\N	\N	1048
01064V	1953-03-21 00:00:00	\N	M.	Billard	BILLARD	BILLARD JOEL	Joël	\N	\N	1049
01007L	1950-11-20 00:00:00	\N	Mme	Gourault	GOURAULT	GOURAULT	Jacqueline	\N	\N	1050
01065W	1936-04-13 00:00:00	\N	M.	Alfonsi	ALFONSI	ALFONSI	Nicolas	\N	\N	1051
01037S	1944-09-03 00:00:00	\N	M.	Frécon	FRÉCON	FRECON	Jean-Claude	\N	\N	1052
01028R	1947-02-28 00:00:00	\N	M.	Sueur	SUEUR	SUEUR	Jean-Pierre	\N	\N	1054
02002K	1944-12-04 00:00:00	\N	M.	Fouché	FOUCHÉ	FOUCHE	Alain	\N	2013-10-08 17:35:44	1055
02003L	1941-01-26 00:00:00	\N	Mme	Bout	BOUT	BOUT	Brigitte	\N	\N	1056
02004M	1954-03-19 00:00:00	\N	Mme	Luypaert	LUYPAERT	LUYPAERT	Brigitte	\N	\N	1057
02005N	1950-06-02 00:00:00	\N	M.	Mortemousque	MORTEMOUSQUE	MORTEMOUSQUE	Dominique	\N	\N	1058
02006P	1941-08-27 00:00:00	\N	M.	Geoffroy	GEOFFROY	GEOFFROY	André	\N	\N	1059
02007Q	1945-04-15 00:00:00	2008-03-26 00:00:00	M.	Bergelin	BERGELIN	BERGELIN	Christian	\N	\N	1060
000800	1900-01-01 00:00:00	\N	M.	<indéterminé>	<INDÉTERMINÉ>	ZZZZZZ 	<indéterminé>	\N	\N	1062
000300	1912-11-11 00:00:00	1961-07-18 00:00:00	M.	Sassi	SASSI	SASSI BENAISSA	Benaissa	\N	\N	1068
01031L	1947-02-06 00:00:00	\N	Mme	André	ANDRÉ	ANDRE M	Michèle	\N	\N	1069
01059Y	1963-01-17 00:00:00	\N	Mme	David	DAVID	DAVID ANNIE	Annie	\N	2013-10-08 14:21:26	1071
05015D	1908-01-16 00:00:00	1997-06-16 00:00:00	M.	Megdoud	MEGDOUD	MEGDOUD	Mohamed	\N	\N	1072
06001B	2006-09-06 00:00:00	\N	Mme	Jarraud-Vergnolle	JARRAUD-VERGNOLLE	JARRAUD-VERGNOLLE ANNIE	Annie	\N	\N	1073
06005F	1940-04-01 00:00:00	\N	M.	Rainaud	RAINAUD	RAINAUD MARCEL	Marcel	\N	\N	1076
06006G	1938-03-31 00:00:00	\N	M.	Josselin	JOSSELIN	JOSSELIN CHARLES	Charles	\N	\N	1077
06004E	1939-04-20 00:00:00	\N	M.	Tropeano	TROPEANO	TROPEANO ROBERT	Robert	\N	\N	1078
05004A	1965-06-21 00:00:00	\N	M.	Baroin	BAROIN	BAROIN FRANÇOIS	François	\N	\N	1080
05008E	1958-07-20 00:00:00	\N	M.	Bas	BAS	BAS PHILIPPE	Philippe	\N	2014-01-21 10:40:14	1084
05011Y	1940-06-24 00:00:00	\N	M.	Vendasi	VENDASI	VENDASI FRANÇOIS	François	\N	\N	1088
04082L	1958-11-04 00:00:00	\N	Mme	Voynet	VOYNET	VOYNET DOMINIQUE	Dominique	\N	\N	1089
04079R	1950-10-27 00:00:00	\N	M.	Madec	MADEC	MADEC ROGER	Roger	\N	\N	1090
77053G	1927-04-18 00:00:00	2015-06-29 00:00:00	M.	Pasqua	PASQUA	PASQUA	Charles	\N	2015-09-07 08:39:17	1091
05012A	1953-03-30 00:00:00	\N	M.	Pointereau	POINTEREAU	POINTEREAU RÉMY	Rémy	\N	\N	1092
89037V	1936-02-14 00:00:00	\N	M.	Revol	REVOL	REVOL	Henri	\N	\N	1095
80035E	1942-02-22 00:00:00	\N	M.	Puech	PUECH	PUECH	Jean	\N	2016-12-14 15:27:19	1096
95037J	1944-12-22 00:00:00	\N	M.	Haut	HAUT	HAUT	Claude	\N	2014-09-28 20:37:58	1097
66002K	1929-08-01 00:00:00	2007-09-03 00:00:00	M.	Pelletier	PELLETIER	PELLETIER JACQUES	Jacques	\N	\N	1098
95048M	1934-11-03 00:00:00	1998-11-02 00:00:00	M.	Mazars	MAZARS	MAZARS	Georges	\N	\N	579
98028V	1952-10-17 00:00:00	\N	M.	Humbert	HUMBERT	HUMBERT	Jean-François	\N	\N	1099
98013N	1953-04-17 00:00:00	\N	M.	Miraux	MIRAUX	MIRAUX	Jean-Luc	\N	\N	1100
04049K	1947-11-20 00:00:00	\N	Mme	Lamure	LAMURE	LAMURE ELISABETH	Élisabeth	\N	\N	1101
000460	1921-04-27 00:00:00	1986-09-09 00:00:00	M.	Beaupetit	BEAUPETIT	BEAUPETIT CHARLES	Charles	\N	\N	1102
95035G	1943-09-13 00:00:00	\N	M.	Gournac	GOURNAC	GOURNAC	Alain	\N	\N	1103
96007G	1933-06-27 00:00:00	\N	Mme	Printz	PRINTZ	PRINTZ	Gisèle	\N	\N	1104
92026S	1948-04-02 00:00:00	2013-07-14 00:00:00	M.	Hugot	HUGOT	HUGOT	Jean-Paul	\N	2013-07-18 09:30:43	1105
83046V	1924-05-18 00:00:00	2013-11-26 00:00:00	M.	Neuwirth	NEUWIRTH	NEUWIRTH	Lucien	\N	2013-11-27 11:12:42	1106
89006N	1921-09-09 00:00:00	2007-01-25 00:00:00	M.	Lesbros	LESBROS	LESBROS	Marcel	\N	\N	1107
59223E	1922-05-30 00:00:00	1998-12-12 00:00:00	M.	Collette	COLLETTE	COLLETTE HENRI	Henri	\N	\N	1108
04041B	1942-05-08 00:00:00	\N	Mme	Hummel	HUMMEL	HUMMEL CHRISTIANE	Christiane	\N	2014-09-28 20:37:37	1110
04042C	1948-03-08 00:00:00	\N	M.	Cambon	CAMBON	CAMBON CHRISTIAN	Christian	\N	2013-10-09 09:18:25	1111
04044E	1961-02-20 00:00:00	\N	Mme	Troendlé	TROENDLÉ	TROENDLE CATHERINE	Catherine	\N	2013-11-12 15:21:10	1112
04045F	1963-01-18 00:00:00	\N	Mme	Schillinger	SCHILLINGER	SCHILLINGER	Patricia	\N	2013-10-31 17:51:16	1113
04046G	1954-05-14 00:00:00	\N	Mme	Demontès	DEMONTÈS	DEMONTES CHRISTIANE	Christiane	\N	2014-01-28 17:06:43	1114
04047H	1963-08-28 00:00:00	\N	M.	Buffet	BUFFET	BUFFET FRANÇOIS-NOËL	François-Noël	\N	2013-10-18 10:03:42	1115
01052R	1937-01-04 00:00:00	\N	M.	Boyer	BOYER	BOYER JEAN 01052R	Jean	\N	\N	1116
000211	1909-04-17 00:00:00	1996-12-09 00:00:00	M.	Poher	POHER	POHER ALAIN	Alain	\N	\N	1117
01026P	1941-08-06 00:00:00	2017-03-11 00:00:00	M.	Etienne	ETIENNE	ETIENNE	Jean-Claude	\N	2017-03-14 15:27:55	1118
96006F	1942-06-05 00:00:00	2016-02-01 00:00:00	M.	Piras	PIRAS	PIRAS	Bernard	\N	2016-02-03 11:53:28	1119
92028U	1921-01-03 00:00:00	1998-02-16 00:00:00	M.	Lagourgue	LAGOURGUE	LAGOURGUE PIERRE	Pierre	\N	\N	1120
58303Y	1909-07-21 00:00:00	2003-07-18 00:00:00	M.	Jozeau-Marigne	JOZEAU-MARIGNE	JOZEAU-MARIGNE LÉON	Léon	\N	\N	1121
03002P	1948-05-20 00:00:00	\N	M.	Texier	TEXIER	TEXIER	Yannick	\N	\N	1122
000330	1913-11-29 00:00:00	1983-08-20 00:00:00	M.	Spenale	SPENALE	SPENALE GEORGES	Georges	\N	\N	1123
58619S	1907-08-24 00:00:00	2007-02-24 00:00:00	M.	Bonnefous	BONNEFOUS	BONNEFOUS EDOUARD	Edouard	\N	\N	1124
000059	1901-12-16 00:00:00	1988-01-20 00:00:00	M.	Maillols	MAILLOLS	MAILLOLS SYLVAIN	Sylvain	\N	\N	1125
03003Q	1938-04-18 00:00:00	2010-12-17 00:00:00	M.	Moulinier	MOULINIER	MOULINIER	Jacques	\N	\N	1126
000359	1915-03-04 00:00:00	1991-10-12 00:00:00	M.	Courroy	COURROY	COURROY LOUIS	Louis	\N	2016-10-04 14:06:33	1127
000399	1918-02-21 00:00:00	1990-06-08 00:00:00	M.	Boyer-Andrivet	BOYER-ANDRIVET	BOYER-ANDRIVET JACQUES	Jacques	\N	\N	1128
03004R	1933-10-02 00:00:00	2016-11-03 00:00:00	M.	Mantienne	MANTIENNE	MANTIENNE	Bernard	\N	2016-11-16 08:14:33	1130
01013J	1946-11-22 00:00:00	\N	Mme	Beaufils	BEAUFILS	BEAUFILS	Marie-France	\N	\N	1131
89027T	1939-06-17 00:00:00	\N	M.	Émin	ÉMIN	EMIN	Jean-Paul	\N	\N	1132
00002B	1951-11-05 00:00:00	\N	M.	Muzeau	MUZEAU	MUZEAU	Roland	\N	\N	1133
04008A	1953-08-01 00:00:00	\N	M.	Daubresse	DAUBRESSE	DAUBRESSE	Marc-Philippe	\N	\N	1139
73006G	1934-05-06 00:00:00	\N	M.	Moreigne	MOREIGNE	MOREIGNE	Michel	\N	\N	1146
98036V	1947-06-29 00:00:00	\N	M.	André	ANDRÉ	ANDRE P	Pierre	\N	\N	1147
97009N	1944-09-18 00:00:00	\N	M.	Angels	ANGELS	ANGELS	Bernard	\N	\N	1148
83011J	1944-10-07 00:00:00	\N	M.	Arthuis	ARTHUIS	ARTHUIS	Jean	\N	2017-03-13 10:23:05	1149
98020M	1927-02-04 00:00:00	2008-11-12 00:00:00	M.	d'Attilio	d'ATTILIO	ATTILIO (D')	Henri	\N	\N	1150
95007C	1943-01-03 00:00:00	\N	M.	Badré	BADRÉ	BADRE	Denis	\N	\N	1152
84004P	1926-12-25 00:00:00	2015-02-25 00:00:00	M.	Balarello	BALARELLO	BALARELLO	José	\N	2015-02-26 16:29:41	1153
83033Q	1928-12-08 00:00:00	2012-07-18 00:00:00	M.	François-Poncet	FRANÇOIS-PONCET	FRANCOISPONCET	Jean	\N	\N	1164
58626R	1926-04-15 00:00:00	2012-04-27 00:00:00	Mme	Le Bellegou-Beguin	LE BELLEGOU-BEGUIN	LEBELLEGOU-BEGUIN GENEVIÈVE	Geneviève	\N	\N	1165
58924Y	1927-04-13 00:00:00	2004-08-19 00:00:00	M.	Le Cozannet	LE COZANNET	LECOZANNET YVES	Yves	\N	\N	1166
000170	1907-10-05 00:00:00	1983-01-30 00:00:00	M.	Le Montagner	LE MONTAGNER	LEMONTAGNER LOUIS	Louis	\N	\N	1167
58652T	1931-04-28 00:00:00	\N	M.	Le Pors	LE PORS	LEPORS ANICET	Anicet	\N	2016-12-14 15:23:17	1168
000014	1900-05-22 00:00:00	1979-09-29 00:00:00	M.	Lebreton	LEBRETON	LEBRETON MARCEL	Marcel	\N	\N	1169
000442	1920-03-04 00:00:00	1993-02-22 00:00:00	M.	Lecanuet	LECANUET	LECANUET JEAN	Jean	\N	\N	1170
58941A	1919-11-03 00:00:00	2004-04-09 00:00:00	M.	Leccia	LECCIA	LECCIA BASTIEN	Bastien	\N	\N	1171
000248	1910-08-19 00:00:00	1995-05-06 00:00:00	M.	Lechenault	LECHENAULT	LECHENAULT FRANCE	France	\N	\N	1172
08069G	1957-08-13 00:00:00	\N	M.	Houpert	HOUPERT	HOUPERT ALAIN	Alain	\N	2013-10-09 14:13:04	1173
09012S	1951-03-26 00:00:00	\N	Mme	Nicoux	NICOUX	NICOUX RENÉE	Renée	\N	\N	1174
10015M	1949-12-05 00:00:00	\N	M.	Reichardt	REICHARDT	REICHARDT  ANDRÉ	André	\N	2014-09-28 20:41:25	1176
11001K	1947-08-27 00:00:00	\N	Mme	Cros	CROS	CROS ROSELLE	Roselle	\N	\N	1177
11003M	1948-03-11 00:00:00	\N	M.	Léonard	LÉONARD	LEONARD CLAUDE	Claude	\N	\N	1182
000275	1911-07-28 00:00:00	1986-09-14 00:00:00	M.	Prigent	PRIGENT	PRIGENT FRANÇOIS	François	\N	\N	1189
000639	1934-11-25 00:00:00	\N	M.	Proriol	PRORIOL	PRORIOL JEAN	Jean	\N	\N	1190
59244K	1927-01-05 00:00:00	\N	M.	Prouvoyeur	PROUVOYEUR	PROUVOYEUR CLAUDE	Claude	\N	\N	1191
000085	1903-08-30 00:00:00	1983-10-04 00:00:00	M.	Provo	PROVO	PROVO VICTOR	Victor	\N	\N	1192
58918B	1911-01-16 00:00:00	2009-02-15 00:00:00	M.	Rabineau	RABINEAU	RABINEAU ANDRÉ	André	\N	\N	1193
59245L	1923-11-13 00:00:00	\N	M.	Ramassamy	RAMASSAMY	RAMASSAMY ALBERT	Albert	\N	\N	1194
000104	1904-06-27 00:00:00	1991-03-22 00:00:00	M.	Raybaud	RAYBAUD	RAYBAUD JOSEPH	Joseph	\N	\N	1195
000293	1912-04-15 00:00:00	1988-09-30 00:00:00	M.	Repiquet	REPIQUET	REPIQUET GEORGES	Georges	\N	\N	1196
000077	1903-06-17 00:00:00	1976-12-15 00:00:00	M.	Reptin	REPTIN	REPTIN ERNEST	Ernest	\N	\N	1197
000158	1906-12-11 00:00:00	1988-01-14 00:00:00	M.	Ribeyre	RIBEYRE	RIBEYRE PAUL	Paul	\N	\N	1198
57310T	1918-03-23 00:00:00	2010-12-05 00:00:00	M.	Richard	RICHARD	RICHARD JACQUES	Jacques	\N	\N	1199
58938F	1927-06-29 00:00:00	2016-09-29 00:00:00	M.	Rigou	RIGOU	RIGOU MICHEL	Michel	\N	2016-10-04 15:02:53	1200
000142	1906-03-10 00:00:00	1986-03-16 00:00:00	M.	Ritzenthaler	RITZENTHALER	RITZENTHALER EUGÈNE	Eugène	\N	\N	1201
77003V	1921-09-17 00:00:00	2011-10-24 00:00:00	M.	Robert	ROBERT	ROBERT GUY	Guy	\N	\N	1202
58919C	1912-03-03 00:00:00	2013-09-13 00:00:00	M.	Robert	ROBERT	ROBERT PAUL	Paul	\N	2013-09-18 16:46:22	1203
000125	1905-05-30 00:00:00	1984-12-25 00:00:00	M.	Robini	ROBINI	ROBINI VICTOR	Victor	\N	\N	1204
95064M	1930-08-23 00:00:00	2016-07-02 00:00:00	M.	Rocard	ROCARD	ROCARD MICHEL	Michel	\N	2016-07-05 10:57:15	1205
000281	1911-10-11 00:00:00	1998-04-06 00:00:00	M.	de Rocca-Serra	de ROCCA-SERRA	ROCCASERRA JEAN-PAUL (DE)	Jean-Paul	\N	\N	1206
56305S	1908-03-25 00:00:00	1999-01-25 00:00:00	M.	Rochereau	ROCHEREAU	ROCHEREAU HENRI	Henri	\N	\N	1207
59557A	1918-02-16 00:00:00	2004-04-15 00:00:00	Mme	Rodi	RODI	RODI NELLY	Nelly	\N	\N	1208
000537	1924-07-09 00:00:00	1969-09-12 00:00:00	M.	Roge	ROGE	ROGE LÉON	Léon	\N	\N	1209
59558B	1923-09-30 00:00:00	2011-06-18 00:00:00	M.	Roger	ROGER	ROGER JEAN	Jean	\N	\N	1210
000174	1907-12-07 00:00:00	1984-09-13 00:00:00	M.	Rollin	ROLLIN	ROLLIN RENÉ	René	\N	\N	1211
000128	1905-07-13 00:00:00	1983-07-29 00:00:00	M.	Romaine	ROMAINE	ROMAINE EUGÈNE	Eugène	\N	\N	1212
000172	1907-11-15 00:00:00	1974-02-04 00:00:00	M.	Rosselli	ROSSELLI	ROSSELLI JACQUES	Jacques	\N	\N	1214
58638V	1925-12-03 00:00:00	2005-11-18 00:00:00	M.	Rosette	ROSETTE	ROSETTE MARCEL	Marcel	\N	\N	1215
58929E	1926-05-13 00:00:00	2002-03-04 00:00:00	M.	Roudier	ROUDIER	ROUDIER ROGER	Roger	\N	2016-01-11 17:15:43	1216
95065N	1946-02-15 00:00:00	\N	M.	Rouquet	ROUQUET	ROUQUET RENÉ	René	\N	\N	1217
000050	1901-08-04 00:00:00	1982-02-17 00:00:00	M.	Messager	MESSAGER	MESSAGER ANDRE	André	\N	\N	1218
000129	1905-08-26 00:00:00	1979-06-05 00:00:00	M.	Metayer	METAYER	METAYER PIERRE	Pierre	\N	\N	1219
92038W	1929-08-13 00:00:00	1996-09-10 00:00:00	M.	Metzinger	METZINGER	METZINGER CHARLES	Charles	\N	\N	1220
000025	1899-10-08 00:00:00	1970-10-09 00:00:00	M.	Michelet	MICHELET	MICHELET EDMOND	Edmond	\N	\N	1221
58635S	1930-06-27 00:00:00	2016-12-15 00:00:00	Mme	Midy	MIDY	MIDY MONIQUE	Monique	\N	2016-12-19 09:42:06	1222
000356	1915-01-19 00:00:00	1977-12-09 00:00:00	M.	Mignot	MIGNOT	MIGNOT ANDRÉ	André	\N	\N	1223
58003P	1925-01-31 00:00:00	2005-04-24 00:00:00	M.	Millot	MILLOT	MILLOT GUY	Guy	\N	\N	1224
000065	1902-05-05 00:00:00	1974-06-22 00:00:00	M.	Minard	MINARD	MINARD FRANÇOIS	François	\N	\N	1225
59551T	1915-01-30 00:00:00	1999-06-25 00:00:00	M.	Miroudot	MIROUDOT	MIROUDOT MICHEL	Michel	\N	\N	1226
59552U	1927-06-15 00:00:00	2015-01-22 00:00:00	Mme	Missoffe	MISSOFFE	MISSOFFE HÉLÈNE	Hélène	\N	2015-01-27 10:13:36	1227
000103	1904-06-23 00:00:00	1981-08-29 00:00:00	M.	Mistral	MISTRAL	MISTRAL PAUL	Paul	\N	\N	1228
000379	1916-10-26 00:00:00	1996-01-08 00:00:00	M.	Mitterrand	MITTERRAND	MITTERRAND  FRANÇOIS	François	\N	\N	1229
58914W	1929-10-23 00:00:00	\N	M.	Moinet	MOINET	MOINET JOSY	Josy	\N	\N	1230
000034	1898-01-01 00:00:00	1975-06-26 00:00:00	M.	Mokrane	MOKRANE	MOKRANE MOHAMED	Mohamed	\N	2016-12-30 15:21:05	1231
000069	1902-10-12 00:00:00	1995-03-27 00:00:00	M.	Molle	MOLLE	MOLLE MARCEL	Marcel	\N	\N	1232
000033	1900-11-25 00:00:00	1977-10-05 00:00:00	M.	Monichon	MONICHON	MONICHON MAX	Max	\N	\N	1233
000022	1900-09-12 00:00:00	1972-10-26 00:00:00	M.	Monsarrat	MONSARRAT	MONSARRAT FRANÇOIS	François	\N	\N	1234
59236K	1913-06-30 00:00:00	2001-10-30 00:00:00	M.	Mont	MONT	MONT CLAUDE	Claude	\N	\N	1235
000132	1905-09-07 00:00:00	1969-08-20 00:00:00	M.	Montaldo	MONTALDO	MONTALDO RENE	Rene	\N	\N	1236
000209	1909-04-06 00:00:00	1975-07-05 00:00:00	M.	de Montigny	de MONTIGNY	MONTIGNY LUCIEN DE	Lucien	\N	\N	1237
000290	1912-03-19 00:00:00	1985-10-09 00:00:00	M.	Moquet	MOQUET	MOQUET JACQUES	Jacques	\N	\N	1238
000597	1929-07-02 00:00:00	1995-07-01 00:00:00	M.	Moreau	MOREAU	MOREAU PAUL	Paul	\N	\N	1239
000100	1904-05-15 00:00:00	1986-05-23 00:00:00	M.	Moreau	MOREAU	MOREAU ROGER	Roger	\N	\N	1240
000284	1912-01-09 00:00:00	1996-05-14 00:00:00	M.	Morel	MOREL	MOREL LÉOPOLD	Léopold	\N	\N	1241
000027	1900-10-11 00:00:00	1990-01-17 00:00:00	M.	Morice	MORICE	MORICE ANDRÉ	André	\N	\N	1242
000586	1927-12-25 00:00:00	1996-02-03 00:00:00	M.	Mossion	MOSSION	MOSSION JACQUES	Jacques	\N	\N	1243
000145	1906-06-21 00:00:00	1971-08-10 00:00:00	M.	Motais de Narbonne	MOTAIS de NARBONNE	MOTAIS DE NARBONNE LÉON	Léon	\N	\N	1244
59237L	1924-07-04 00:00:00	2017-05-09 00:00:00	M.	Moulin	MOULIN	MOULIN ARTHUR	Arthur	\N	2017-05-12 08:51:11	1245
000528	1924-03-31 00:00:00	1998-04-23 00:00:00	M.	Moutet	MOUTET	MOUTET JACQUES	Jacques	\N	\N	1246
000024	1898-01-01 00:00:00	1983-07-31 00:00:00	M.	Mustapha	MUSTAPHA	MUSTAPHA MENAD	Menad	\N	\N	1247
000187	1908-06-14 00:00:00	1987-12-02 00:00:00	M.	Namy	NAMY	NAMY LOUIS	Louis	\N	\N	1248
000126	1905-06-21 00:00:00	1997-12-01 00:00:00	M.	Natali	NATALI	NATALI JEAN	Jean	\N	\N	1249
000079	1903-07-14 00:00:00	1981-08-24 00:00:00	M.	Naveau	NAVEAU	NAVEAU CHARLES	Charles	\N	\N	1250
000352	1914-12-03 00:00:00	1983-02-06 00:00:00	M.	Nayrou	NAYROU	NAYROU JEAN	Jean	\N	\N	1251
000166	1907-06-20 00:00:00	1972-05-08 00:00:00	M.	Negre	NEGRE	NEGRE JEAN	Jean	\N	\N	1252
000428	1919-08-31 00:00:00	1963-11-21 00:00:00	M.	de Nicolay	de NICOLAY	NICOLAY FRANCOIS DE	François	\N	\N	1253
58636T	1926-06-22 00:00:00	2014-08-20 00:00:00	M.	Noe	NOE	NOE PIERRE	Pierre	\N	2014-09-01 11:44:13	1254
000096	1904-02-19 00:00:00	1983-05-30 00:00:00	M.	Noury	NOURY	NOURY JEAN	Jean	\N	\N	1255
58645U	1928-04-17 00:00:00	\N	M.	Ooghe	OOGHE	OOGHE JEAN	Jean	\N	\N	1256
000019	1895-05-10 00:00:00	1977-01-10 00:00:00	M.	Oopa Tetuaapua	OOPA TETUAAPUA	OOPA TETUAAPUA POUVANAA	Pouvanaa	\N	\N	1257
000419	1919-05-05 00:00:00	1994-02-19 00:00:00	M.	Ornano	ORNANO	ORNANO CHARLES	Charles	\N	\N	1258
000437	1919-12-09 00:00:00	1994-09-21 00:00:00	M.	Orvoen	ORVOEN	ORVOEN LOUIS	Louis	\N	\N	1259
000026	1899-10-08 00:00:00	1980-05-24 00:00:00	M.	Ouella	OUELLA	OUELLA HACÈNE	Hacène	\N	\N	1260
000488	1922-05-24 00:00:00	1989-05-18 00:00:00	M.	Pado	PADO	PADO DOMINIQUE	Dominique	\N	\N	1261
000254	1910-09-30 00:00:00	1995-08-13 00:00:00	Mme	Pagani	PAGANI	PAGANI_ODETTE	Odette	\N	2018-05-09 16:23:07	1262
000393	1917-12-08 00:00:00	1985-05-13 00:00:00	M.	Palmero	PALMERO	PALMERO FRANCIS	Francis	\N	\N	1263
000412	1918-11-22 00:00:00	1981-02-19 00:00:00	M.	Pams	PAMS	PAMS GASTON	Gaston	\N	\N	1264
71031Y	1928-02-27 00:00:00	1998-04-05 00:00:00	M.	Papilio	PAPILIO	PAPILIO SOSÉFO MAKAPÉ	Soséfo Makapé	\N	\N	1265
57761T	1921-08-13 00:00:00	2017-01-07 00:00:00	M.	Parenty	PARENTY	PARENTY ROBERT	Robert	\N	2017-01-10 18:23:21	1266
000521	1924-02-05 00:00:00	1993-11-22 00:00:00	M.	Parmantier	PARMANTIER	PARMANTIER BERNARD	Bernard	\N	\N	1267
000109	1904-09-11 00:00:00	1979-12-07 00:00:00	M.	Pascaud	PASCAUD	PASCAUD GUY	Guy	\N	\N	1268
000182	1908-04-05 00:00:00	1977-04-11 00:00:00	M.	Patenotre	PATENOTRE	PATENOTRE FRANÇOIS	François	\N	\N	1269
000112	1904-11-05 00:00:00	1983-05-25 00:00:00	M.	Patria	PATRIA	PATRIA PIERRE	Pierre	\N	\N	1270
000090	1903-11-06 00:00:00	1984-05-22 00:00:00	M.	Paulian	PAULIAN	PAULIAN GILBERT	Gilbert	\N	\N	1271
000048	1901-07-22 00:00:00	1973-06-27 00:00:00	M.	Pauly	PAULY	PAULY PAUL	Paul	\N	\N	1272
59553V	1928-09-18 00:00:00	2007-05-17 00:00:00	M.	Pellarin	PELLARIN	PELLARIN BERNARD	Bernard	\N	\N	1273
59579G	1931-03-01 00:00:00	2003-07-03 00:00:00	M.	Pen	PEN	PEN ALBERT	Albert	\N	\N	1274
000008	1900-02-25 00:00:00	1975-05-01 00:00:00	M.	Perdereau	PERDEREAU	PERDEREAU LUCIEN	Lucien	\N	\N	1275
000208	1909-04-02 00:00:00	1982-08-08 00:00:00	M.	Peridier	PERIDIER	PERIDIER JEAN	Jean	\N	\N	1276
99004R	1951-08-26 00:00:00	\N	M.	Karoutchi	KAROUTCHI	KAROUTCHI	Roger	\N	\N	1277
00001A	1950-01-05 00:00:00	\N	M.	Autexier	AUTEXIER	AUTEXIER	Jean-Yves	\N	\N	1278
93007T	1929-09-09 00:00:00	2016-03-19 00:00:00	M.	Marest	MAREST	MAREST	Max	\N	2016-03-21 17:29:26	1279
00003C	1951-07-27 00:00:00	\N	Mme	Campion	CAMPION	CAMPION	Claire-Lise	\N	\N	1280
00004D	1946-04-15 00:00:00	\N	M.	Hethener	HETHENER	HETHENER	Alain	\N	\N	1281
01001E	1948-04-19 00:00:00	\N	M.	Béteille	BÉTEILLE	BETEILLE	Laurent	\N	\N	1282
01002F	1948-05-01 00:00:00	\N	M.	Guichard	GUICHARD	GUICHARD	Pierre	\N	\N	1283
01003G	1939-08-02 00:00:00	\N	M.	Fortassin	FORTASSIN	FORTASSIN	François	\N	2014-01-21 10:47:33	1284
01004H	1947-09-25 00:00:00	\N	M.	Mano	MANO	MANO	Jean-Yves	\N	\N	1285
92008Q	1942-06-20 00:00:00	\N	Mme	Cerisier-ben Guiga	CERISIER-ben GUIGA	CERISIER-BEN GUIGA	Monique	\N	\N	1286
98001J	1925-02-17 00:00:00	1999-06-21 00:00:00	M.	Gaspard	GASPARD	GASPARD	André	\N	\N	1287
86018E	1921-05-07 00:00:00	2008-10-20 00:00:00	M.	Clouet	CLOUET	CLOUET	Jean	\N	\N	1288
83008P	1930-06-19 00:00:00	2001-03-02 00:00:00	M.	Abadie	ABADIE	ABADIE	François	\N	2017-11-09 08:07:23	1289
95049N	1947-03-07 00:00:00	\N	M.	Mercier	MERCIER	MERCIER_MICHEL	Michel	\N	2015-10-20 15:45:37	1290
81007E	1921-08-14 00:00:00	2012-07-15 00:00:00	M.	Delong	DELONG	DELONG	Jacques-Richard	\N	\N	1291
86005Y	1928-07-02 00:00:00	\N	M.	Bimbenet	BIMBENET	BIMBENET	Jacques	\N	\N	1292
95006B	1928-03-30 00:00:00	\N	M.	Badinter	BADINTER	BADINTER	Robert	\N	\N	1293
80045G	1933-04-12 00:00:00	\N	M.	Torre	TORRE	TORRE	Henri	\N	\N	1294
98047Y	1934-12-01 00:00:00	\N	M.	Fréville	FRÉVILLE	FREVILLE	Yves	\N	\N	1295
95002W	1949-05-17 00:00:00	\N	M.	Lauret	LAURET	LAURET	Edmond	\N	\N	1296
95042F	1939-11-22 00:00:00	\N	M.	Lachenaud	LACHENAUD	LACHENAUD	Jean-Philippe	\N	\N	1297
95060H	1928-05-14 00:00:00	\N	M.	Ralite	RALITE	RALITE	Jack	\N	\N	1298
95019G	1934-01-16 00:00:00	\N	M.	Cléach	CLÉACH	CLEACH	Marcel-Pierre	\N	\N	1299
92027T	1933-10-17 00:00:00	\N	M.	Huguet	HUGUET	HUGUET	Roland	\N	\N	1300
83043S	1920-07-21 00:00:00	2009-05-28 00:00:00	M.	Masson	MASSON	MASSON PAUL	Paul	\N	\N	1301
89020L	1927-06-07 00:00:00	2007-11-21 00:00:00	M.	Bernardet	BERNARDET	BERNARDET	Daniel	\N	\N	1302
80028F	1924-03-24 00:00:00	2010-02-01 00:00:00	M.	Manet	MANET	MANET	Michel	\N	\N	1303
89036U	1912-07-12 00:00:00	2000-06-21 00:00:00	M.	Philibert	PHILIBERT	PHILIBERT	Louis	\N	\N	1304
59219J	1908-07-01 00:00:00	2002-04-26 00:00:00	M.	Bouquerel	BOUQUEREL	BOUQUEREL AMÉDÉE	Amédée	\N	\N	1305
01006K	1942-05-07 00:00:00	\N	M.	Alduy	ALDUY	ALDUY	Jean-Paul	\N	\N	1306
01008M	1940-01-28 00:00:00	\N	M.	Bailly	BAILLY	BAILLYGERARD	Gérard	\N	2014-01-21 10:37:00	1307
01009N	1949-08-01 00:00:00	\N	Mme	Payet	PAYET	PAYET ANNEMARIE	Anne-Marie	\N	\N	1308
01010F	1944-03-15 00:00:00	\N	M.	Virapoullé	VIRAPOULLÉ	VIRAPOULLE JEANPAUL	Jean-Paul	\N	\N	1309
01011G	1944-09-23 00:00:00	\N	M.	Godefroy	GODEFROY	GODEFROY	Jean-Pierre	\N	\N	1310
01014K	1941-01-17 00:00:00	\N	M.	Reiner	REINER	REINER	Daniel	\N	\N	1311
88006J	1933-06-29 00:00:00	2011-02-23 00:00:00	M.	Pagès	PAGÈS	PAGES	Robert	\N	\N	493
95054K	1925-08-26 00:00:00	1999-11-27 00:00:00	M.	Peyrefitte	PEYREFITTE	PEYREFITTE	Alain	\N	\N	494
77033C	1920-02-04 00:00:00	2014-08-13 00:00:00	M.	Larché	LARCHÉ	LARCHE	Jacques	\N	2014-09-01 11:45:50	495
83021L	1938-09-07 00:00:00	2013-06-04 00:00:00	M.	Cazalet	CAZALET	CAZALET	Auguste	\N	2013-06-07 13:39:29	496
92006N	1947-11-06 00:00:00	\N	M.	Althapé	ALTHAPÉ	ALTHAPE	Louis	\N	2016-10-14 18:34:05	497
92013M	1937-08-30 00:00:00	\N	M.	Borotra	BOROTRA	BOROTRA DIDIER	Didier	\N	\N	498
92020L	1937-03-20 00:00:00	\N	Mme	Durrieu	DURRIEU	DURRIEU	Josette	\N	2013-10-09 14:15:29	499
92036U	1923-01-17 00:00:00	2013-08-01 00:00:00	M.	Marquès	MARQUÈS	MARQUES	René	\N	2013-08-13 16:36:25	500
92011K	1937-01-29 00:00:00	\N	M.	Blanc	BLANC	BLANC PAUL	Paul	\N	\N	501
95036H	1944-01-03 00:00:00	\N	M.	Grignon	GRIGNON	GRIGNON	Francis	\N	\N	502
92005M	1953-05-22 00:00:00	\N	M.	Richert	RICHERT	RICHERT	Philippe	\N	\N	503
77029G	1929-01-23 00:00:00	\N	M.	Hoeffel	HOEFFEL	HOEFFEL	Daniel	\N	2016-12-14 15:21:56	504
91002E	1937-11-26 00:00:00	\N	M.	Ostermann	OSTERMANN	OSTERMANN	Joseph	\N	\N	505
95029J	1931-12-15 00:00:00	\N	M.	Eckenspieller	ECKENSPIELLER	ECKENSPIELLER	Daniel	\N	\N	506
86030A	1942-05-20 00:00:00	2015-08-10 00:00:00	M.	Haenel	HAENEL	HAENEL	Hubert	\N	2015-08-11 17:15:37	507
95045J	1948-03-12 00:00:00	2013-06-27 00:00:00	M.	Lorrain	LORRAIN	LORRAIN	Jean-Louis	\N	2013-07-08 14:16:27	508
86031B	1922-01-09 00:00:00	2003-11-04 00:00:00	M.	Hamel	HAMEL	HAMEL	Emmanuel	\N	\N	509
77047J	1936-02-10 00:00:00	\N	M.	Mathieu	MATHIEU	MATHIEU	Serge	\N	\N	510
77066M	1921-07-07 00:00:00	2006-07-02 00:00:00	M.	Sérusclat	SÉRUSCLAT	SERUSCLAT	Franck	\N	\N	511
92024Q	1928-10-28 00:00:00	2007-02-25 00:00:00	M.	Goulet	GOULET	GOULET	Daniel	\N	\N	512
92029V	1946-07-20 00:00:00	\N	M.	Lambert	LAMBERT	LAMBERT ALAIN	Alain	\N	2016-12-14 15:22:30	513
95011X	2004-01-30 00:00:00	\N	Mme	Borvo Cohen-Seat	BORVO COHEN-SEAT	BORVO COHEN-SEAT	Nicole	\N	\N	514
95056M	1940-06-20 00:00:00	\N	M.	Plasait	PLASAIT	PLASAIT	Bernard	\N	\N	515
86025D	1925-06-08 00:00:00	2016-03-10 00:00:00	M.	Estier	ESTIER	ESTIER	Claude	\N	2016-03-11 17:57:59	516
95026F	1927-03-11 00:00:00	2016-09-08 00:00:00	M.	Dominati	DOMINATI	DOMINATI	Jacques	\N	2016-09-12 16:59:41	517
86028G	1921-12-28 00:00:00	\N	M.	de Gaulle	de GAULLE	GAULLE (DE)	Philippe	\N	\N	518
93003P	1925-01-06 00:00:00	2012-11-14 00:00:00	M.	Ulrich	ULRICH	ULRICH	Maurice	\N	\N	519
95022B	1950-05-30 00:00:00	\N	M.	Delanoë	DELANOË	DELANOE	Bertrand	\N	\N	520
77009C	1926-09-28 00:00:00	2012-09-22 00:00:00	M.	Caldaguès	CALDAGUÈS	CALDAGUES	Michel	\N	\N	521
95058P	1951-10-23 00:00:00	\N	Mme	Pourtaud	POURTAUD	POURTAUD	Danièle	\N	\N	522
77046H	1920-12-05 00:00:00	\N	M.	de La Malène	de LA MALÈNE	LAMALENE (DE)	Christian	\N	\N	523
77013X	1928-02-16 00:00:00	2016-04-25 00:00:00	M.	Chérioux	CHÉRIOUX	CHERIOUX	Jean	\N	2016-04-26 17:26:42	524
95018F	1942-12-25 00:00:00	\N	M.	Charzat	CHARZAT	CHARZAT	Michel	\N	\N	525
92017R	1947-01-22 00:00:00	\N	M.	Delevoye	DELEVOYE	DELEVOYE	Jean-Paul	\N	2016-12-14 15:19:29	526
86004X	1924-02-18 00:00:00	2002-05-10 00:00:00	M.	Debavelaere	DEBAVELAERE	DEBAVELAERE	Désiré	\N	\N	527
84003N	1947-08-23 00:00:00	\N	M.	Bécart	BÉCART	BECART	Jean-Luc	\N	\N	528
86042E	1925-06-09 00:00:00	2010-07-25 00:00:00	M.	Penne	PENNE	PENNE	Guy	\N	\N	529
89016Q	1939-11-23 00:00:00	2015-05-03 00:00:00	M.	Pépin	PÉPIN	PEPIN	Jean	\N	2015-05-06 16:13:50	530
88005H	1929-12-11 00:00:00	2006-09-02 00:00:00	M.	Lesein	LESEIN	LESEIN	François	\N	\N	531
78003A	1931-06-27 00:00:00	\N	M.	Girod	GIROD	GIROD	Paul	\N	\N	532
71006X	1924-07-13 00:00:00	1999-12-15 00:00:00	M.	Braconnier	BRACONNIER	BRACONNIER	Jacques	\N	\N	533
86034E	1949-09-14 00:00:00	\N	M.	Larcher	LARCHER	LARCHER GERARD	Gérard	\N	\N	534
86011W	1931-06-25 00:00:00	\N	M.	Bellanger	BELLANGER	BELLANGER	Jacques	\N	\N	535
95013A	1947-10-21 00:00:00	\N	M.	Braye	BRAYE	BRAYE	Dominique	\N	\N	536
95050F	1929-03-05 00:00:00	\N	Mme	Michaux-Chevry	MICHAUX-CHEVRY	MICHAUX-CHEVRY	Lucette	\N	\N	537
89035T	1944-01-07 00:00:00	\N	M.	Othily	OTHILY	OTHILY	Georges	\N	\N	538
86021Y	1937-02-09 00:00:00	\N	M.	Désiré	DÉSIRÉ	DESIRE	Rodolphe	\N	\N	539
95044H	1941-01-31 00:00:00	\N	M.	Lise	LISE	LISE	Claude	\N	\N	540
98002K	1945-06-03 00:00:00	\N	M.	Payet	PAYET	PAYET LYLIAN	Lylian	\N	\N	541
96003C	1925-03-05 00:00:00	\N	M.	Vergès	VERGÈS	VERGES	Paul	\N	2013-05-21 17:52:24	542
77001T	1928-08-26 00:00:00	2016-06-21 00:00:00	M.	Millaud	MILLAUD	MILLAUD	Daniel	\N	2017-01-12 15:11:38	544
98004M	1942-05-03 00:00:00	\N	M.	Tui	TUI	TUI	Basile	\N	\N	545
77028F	1926-10-30 00:00:00	\N	M.	Henry	HENRY	HENRY	Marcel	\N	\N	546
95061J	1929-12-03 00:00:00	2016-06-01 00:00:00	M.	Reux	REUX	REUX	Victor	\N	2016-06-10 11:01:22	547
69001W	1919-09-26 00:00:00	2012-08-06 00:00:00	M.	Habert	HABERT	HABERT	Jacques	\N	\N	548
89021M	1932-01-17 00:00:00	\N	M.	Biarnès	BIARNÈS	BIARNES	Pierre	\N	\N	549
89023P	1917-04-21 00:00:00	2012-07-07 00:00:00	Mme	Brisepierre	BRISEPIERRE	BRISEPIERRE	Paulette	\N	\N	550
97005J	1949-02-21 00:00:00	\N	Mme	Terrade	TERRADE	TERRADE	Odette	\N	\N	551
79004F	1937-10-30 00:00:00	\N	Mme	Beaudeau	BEAUDEAU	BEAUDEAU	Marie-Claude	\N	\N	552
95051G	1941-03-23 00:00:00	2017-10-26 00:00:00	Mme	Olin	OLIN	OLIN	Nelly	\N	2017-10-30 13:40:03	553
95031C	1947-05-15 00:00:00	\N	M.	Falco	FALCO	FALCO	Hubert	\N	2014-09-28 20:37:16	554
86035F	1921-05-02 00:00:00	2006-04-29 00:00:00	M.	Laurin	LAURIN	LAURIN	René-Georges	\N	\N	555
86049M	1931-06-09 00:00:00	\N	M.	Trucy	TRUCY	TRUCY	François	\N	\N	556
87003B	1944-01-02 00:00:00	\N	M.	Dufaut	DUFAUT	DUFAUT	Alain	\N	\N	557
86041D	1939-10-07 00:00:00	\N	M.	Oudin	OUDIN	OUDIN	Jacques	\N	\N	558
95021A	1943-02-23 00:00:00	\N	M.	Darniche	DARNICHE	DARNICHE	Philippe	\N	\N	559
87002A	1930-10-31 00:00:00	\N	M.	Moinard	MOINARD	MOINARD	Louis	\N	\N	560
68036E	1923-06-06 00:00:00	2009-04-11 00:00:00	M.	Monory	MONORY	MONORY	René	\N	\N	561
95059Q	1948-08-03 00:00:00	\N	M.	Raffarin	RAFFARIN	RAFFARIN	Jean-Pierre	\N	\N	562
90004C	1943-05-08 00:00:00	\N	M.	Demerliat	DEMERLIAT	DEMERLIAT	Jean-Pierre	\N	2013-10-10 13:47:09	563
95055L	1940-11-07 00:00:00	\N	M.	Peyronnet	PEYRONNET	PEYRONNET	Jean-Claude	\N	\N	564
77058M	1928-03-24 00:00:00	\N	M.	Poncelet	PONCELET	PONCELET	Christian	\N	\N	565
95012Y	1937-06-02 00:00:00	\N	M.	Braun	BRAUN	BRAUN	Gérard	\N	\N	566
95004Y	1947-07-14 00:00:00	\N	M.	About	ABOUT	ABOUT	Nicolas	\N	\N	567
83003J	1927-08-16 00:00:00	\N	M.	François	FRANÇOIS	FRANCOIS PHILIPPE	Philippe	\N	\N	568
95039L	1943-03-02 00:00:00	\N	M.	Hyest	HYEST	HYEST	Jean-Jacques	\N	\N	569
78007E	1939-12-08 00:00:00	\N	Mme	Bidard-Reydet	BIDARD-REYDET	BIDARD-REYDET	Danielle	\N	\N	570
95024D	1947-07-24 00:00:00	\N	M.	Demuynck	DEMUYNCK	DEMUYNCK	Christian	\N	\N	571
77017C	1929-09-16 00:00:00	2015-12-23 00:00:00	M.	Debarge	DEBARGE	DEBARGE	Marcel	\N	2015-12-28 10:44:52	573
86014A	1929-05-19 00:00:00	2002-12-10 00:00:00	M.	Calméjane	CALMÉJANE	CALMEJANE	Robert	\N	\N	574
95009E	1939-10-10 00:00:00	\N	M.	Bécot	BÉCOT	BECOT	Michel	\N	\N	575
95028H	1937-11-14 00:00:00	\N	M.	Dulait	DULAIT	DULAIT	André	\N	\N	576
95025E	1928-08-16 00:00:00	\N	M.	Deneux	DENEUX	DENEUX	Marcel	\N	\N	577
95052H	1950-02-12 00:00:00	\N	M.	Pastor	PASTOR	PASTOR	Jean-Marc	\N	\N	580
88008L	1944-04-10 00:00:00	\N	M.	Collin	COLLIN	COLLIN	Yvon	\N	\N	581
77044F	1932-03-13 00:00:00	\N	Mme	Luc	LUC	LUC HELENE	Hélène	\N	\N	582
000365	1915-06-16 00:00:00	1980-09-27 00:00:00	M.	Brosseau	BROSSEAU	BROSSEAU RAYMOND	Raymond	\N	2016-08-09 10:54:33	583
000574	1926-11-30 00:00:00	1992-07-30 00:00:00	M.	Brousse	BROUSSE	BROUSSE PIERRE	Pierre	\N	\N	584
58946F	1915-03-18 00:00:00	2006-12-29 00:00:00	M.	Brun	BRUN	BRUN RAYMOND	Raymond	\N	\N	585
000053	1901-09-05 00:00:00	1973-04-11 00:00:00	M.	Bruneau	BRUNEAU	BRUNEAU ANDRÉ	André	\N	\N	586
000035	1900-11-25 00:00:00	1986-11-11 00:00:00	M.	Brunhes	BRUNHES	BRUNHES JULIEN	Julien	\N	\N	587
000049	1901-07-25 00:00:00	1974-10-22 00:00:00	M.	Bruyas	BRUYAS	BRUYAS FLORIAN	Florian	\N	\N	588
57432D	1905-06-25 00:00:00	1999-03-17 00:00:00	M.	Bruyneel	BRUYNEEL	BRUYNEEL ROBERT	Robert	\N	\N	589
000010	1900-03-20 00:00:00	1975-06-26 00:00:00	M.	Burgat	BURGAT	BURGAT GABRIEL	Gabriel	\N	2016-08-09 10:57:31	590
000150	1906-08-25 00:00:00	1985-03-08 00:00:00	M.	Burret	BURRET	BURRET ROBERT	Robert	\N	\N	591
59524Q	1930-12-11 00:00:00	2002-06-02 00:00:00	M.	Cabana	CABANA	CABANA CAMILLE	Camille	\N	\N	592
58366Q	1926-09-13 00:00:00	2009-10-22 00:00:00	M.	Cabocel	CABOCEL	CABOCEL RÉMI	Rémi	\N	\N	593
58411C	1914-02-13 00:00:00	2013-02-27 00:00:00	M.	Caillavet	CAILLAVET	CAILLAVET HENRI	Henri	\N	\N	594
000538	1924-10-03 00:00:00	1987-02-27 00:00:00	M.	Caiveau	CAIVEAU	CAIVEAU LOUIS	Louis	\N	\N	595
59526S	1921-07-13 00:00:00	2012-02-02 00:00:00	M.	Caron	CARON	CARON PAUL	Paul	\N	\N	596
000326	1913-09-17 00:00:00	1990-01-14 00:00:00	M.	Carous	CAROUS	CAROUS PIERRE	Pierre	\N	\N	597
000003	1900-01-15 00:00:00	1981-11-30 00:00:00	M.	Carrier	CARRIER	CARRIER MAURICE	Maurice	\N	\N	598
59569E	1923-07-18 00:00:00	2009-12-09 00:00:00	M.	Cartigny	CARTIGNY	CARTIGNY ERNEST	Ernest	\N	\N	599
58936D	1914-09-13 00:00:00	2002-05-17 00:00:00	M.	Castex	CASTEX	CASTEX MARC	Marc	\N	\N	600
000350	1914-11-06 00:00:00	1996-11-24 00:00:00	M.	Cathala	CATHALA	CATHALA CHARLES	Charles	\N	\N	601
59570W	1924-03-30 00:00:00	2003-03-31 00:00:00	M.	De Catuelan	DE CATUELAN	CATUELAN LOUIS (DE)	Louis	\N	\N	602
000327	1913-11-21 00:00:00	1991-11-16 00:00:00	M.	Cauchon	CAUCHON	CAUCHON JEAN	Jean	\N	\N	603
58202U	1927-02-03 00:00:00	2013-02-14 00:00:00	M.	Cavaillé	CAVAILLÉ	CAVAILLE MARCEL	Marcel	\N	\N	605
59601L	1921-07-29 00:00:00	2001-01-05 00:00:00	M.	Cayrel	CAYREL	CAYREL RAYMOND	Raymond	\N	\N	606
000257	1910-11-10 00:00:00	1995-01-12 00:00:00	M.	Chabaraka	CHABARAKA	CHABARAKA AHMED	Ahmed	\N	\N	607
59571X	1913-11-23 00:00:00	2010-12-22 00:00:00	M.	Chamant	CHAMANT	CHAMANT JEAN	Jean	\N	\N	608
000111	1904-10-27 00:00:00	1974-08-26 00:00:00	M.	Chambaretaud	CHAMBARETAUD	CHAMBARETAUD LÉON	Léon	\N	\N	609
000061	1902-03-31 00:00:00	1994-03-07 00:00:00	M.	Champeix	CHAMPEIX	CHAMPEIX MARCEL	Marcel	\N	\N	610
000038	1901-03-27 00:00:00	1967-03-08 00:00:00	M.	Champleboux	CHAMPLEBOUX	CHAMPLEBOUX MICHEL	Michel	\N	\N	611
000439	1920-01-31 00:00:00	1979-06-11 00:00:00	M.	Chatelain	CHATELAIN	CHATELAIN FERNAND	Fernand	\N	\N	612
59221C	1924-02-11 00:00:00	2007-08-16 00:00:00	M.	Chauty	CHAUTY	CHAUTY MICHEL	Michel	\N	\N	613
000272	1911-06-07 00:00:00	1989-02-03 00:00:00	M.	Chauvin	CHAUVIN	CHAUVIN ADOLPHE	Adolphe	\N	\N	614
000222	1909-10-19 00:00:00	1972-09-14 00:00:00	M.	Chavanac	CHAVANAC	CHAVANAC ALBERT	Albert	\N	\N	615
58113U	1924-03-18 00:00:00	\N	M.	Chazalon	CHAZALON	CHAZALON ANDRÉ	André	\N	\N	616
58349P	1917-07-24 00:00:00	2006-04-13 00:00:00	M.	Chazelle	CHAZELLE	CHAZELLE RENÉ	René	\N	\N	617
58419L	1929-11-17 00:00:00	2016-10-25 00:00:00	M.	Cherrier	CHERRIER	CHERRIER LIONEL	Lionel	\N	2016-11-02 08:44:51	618
57434F	1914-06-03 00:00:00	2001-10-18 00:00:00	M.	De Chevigny	DE CHEVIGNY	CHEVIGNY PIERRE (DE)	Pierre	\N	\N	619
59527T	1934-09-06 00:00:00	\N	M.	Chinaud	CHINAUD	CHINAUD ROGER	Roger	\N	\N	620
59222D	1919-09-29 00:00:00	2007-03-09 00:00:00	M.	Chupin	CHUPIN	CHUPIN AUGUSTE	Auguste	\N	\N	621
58923X	1916-10-02 00:00:00	2010-05-01 00:00:00	M.	Ciccolini	CICCOLINI	CICCOLINI FÉLIX	Félix	\N	\N	622
56819Q	1911-02-03 00:00:00	2001-07-31 00:00:00	M.	Claireaux	CLAIREAUX	CLAIREAUX HENRI	Henri	\N	\N	623
000060	1902-03-02 00:00:00	1967-08-03 00:00:00	M.	Claparede	CLAPAREDE	CLAPAREDE EMILE	Emile	\N	\N	624
000235	1910-01-19 00:00:00	1978-08-29 00:00:00	M.	Colin	COLIN	COLIN ANDRÉ	André	\N	\N	625
58805S	1923-03-21 00:00:00	2006-05-04 00:00:00	M.	Colin	COLIN	COLIN JEAN	Jean	\N	\N	626
000494	1922-07-01 00:00:00	1976-03-18 00:00:00	M.	Collery	COLLERY	COLLERY JEAN	Jean	\N	\N	627
59528U	1910-12-19 00:00:00	2009-07-24 00:00:00	M.	Collomb	COLLOMB	COLLOMB FRANCISQUE	Francisque	\N	\N	628
000196	1908-08-14 00:00:00	1989-10-16 00:00:00	M.	Constant	CONSTANT	CONSTANT GEORGES	Georges	\N	\N	629
57710G	1922-04-17 00:00:00	2008-11-05 00:00:00	M.	Coppenrath	COPPENRATH	COPPENRATH GÉRALD	Gérald	\N	2017-01-09 09:49:34	630
89011K	1939-10-01 00:00:00	1996-01-12 00:00:00	M.	Cornac	CORNAC	CORNAC CLAUDE	Claude	\N	\N	631
000073	1903-02-14 00:00:00	1968-06-16 00:00:00	M.	Cornat	CORNAT	CORNAT HENRI	Henri	\N	\N	632
000192	1908-07-30 00:00:00	1988-09-17 00:00:00	M.	Coudert	COUDERT	COUDERT JACQUES	Jacques	\N	\N	633
000121	1905-05-09 00:00:00	1998-02-16 00:00:00	M.	Courbatere	COURBATERE	COURBATERE ROGER	Roger	\N	\N	634
000205	1909-01-23 00:00:00	1974-09-20 00:00:00	M.	Courriere	COURRIERE	COURRIERE ANTOINE	Antoine	\N	\N	635
000173	1907-12-03 00:00:00	1992-09-17 00:00:00	M.	Coutrot	COUTROT	COUTROT MAURICE	Maurice	\N	\N	636
59529V	1907-01-24 00:00:00	1999-12-24 00:00:00	M.	Couve De Murville	COUVE DE MURVILLE	COUVE DE MURVILLE MAURICE	Maurice	\N	\N	637
71011U	1921-05-14 00:00:00	1998-01-19 00:00:00	M.	Croze	CROZE	CROZE PIERRE	Pierre	\N	\N	638
59530N	1922-01-04 00:00:00	2012-09-10 00:00:00	M.	Crucis	CRUCIS	CRUCIS MICHEL	Michel	\N	\N	639
58649Y	1930-12-09 00:00:00	2007-09-29 00:00:00	M.	Dagonia	DAGONIA	DAGONIA GEORGES	Georges	\N	\N	640
70001N	1921-07-25 00:00:00	2007-02-19 00:00:00	M.	de Bourgoing	DE BOURGOING	BOURGOING (DE)	Philippe	\N	\N	641
89010J	1929-08-18 00:00:00	2009-01-07 00:00:00	M.	Besse	BESSE	BESSE ROGER	Roger	\N	\N	642
89038W	1932-07-22 00:00:00	1999-02-17 00:00:00	M.	Rigaudière	RIGAUDIÈRE	RIGAUDIERE	Roger	\N	\N	643
80002U	1928-10-07 00:00:00	2003-04-23 00:00:00	M.	Alloncle	ALLONCLE	ALLONCLE	Michel	\N	\N	644
96008H	1949-02-01 00:00:00	\N	M.	Arnaud	ARNAUD	ARNAUD	Philippe	\N	\N	645
89014N	1939-09-26 00:00:00	\N	M.	Doublet	DOUBLET	DOUBLET	Michel	\N	2014-05-12 18:06:29	646
89012L	1923-09-21 00:00:00	2007-07-17 00:00:00	M.	Blaizot	BLAIZOT	BLAIZOT	François	\N	\N	647
71017B	1918-09-22 00:00:00	2008-11-27 00:00:00	M.	Genton	GENTON	GENTON	Jacques	\N	\N	648
89045V	1949-06-17 00:00:00	2007-12-16 00:00:00	M.	Vinçon	VINÇON	VINCON	Serge	\N	\N	649
80031A	1931-02-21 00:00:00	\N	M.	Mouly	MOULY	MOULY	Georges	\N	\N	650
80007A	1926-09-11 00:00:00	2003-11-19 00:00:00	M.	Belcour	BELCOUR	BELCOUR	Henri	\N	\N	651
89015P	1948-07-01 00:00:00	\N	M.	Besson	BESSON	BESSON JEAN	Jean	\N	\N	727
94002S	1936-02-07 00:00:00	\N	M.	de Rocca Serra	de ROCCA SERRA	ROCCASERRA LOUISFERDINAND	Louis Ferdinand	\N	\N	652
71009B	1923-11-18 00:00:00	\N	M.	Cluzel	CLUZEL	CLUZEL	Jean	\N	\N	653
89018S	1935-02-05 00:00:00	\N	M.	Barraux	BARRAUX	BARRAUX	Bernard	\N	\N	654
80043E	1919-06-14 00:00:00	2017-04-04 00:00:00	M.	Tardy	TARDY	TARDY	Fernand	\N	2017-04-05 14:54:17	655
89046W	1920-02-27 00:00:00	2003-09-16 00:00:00	M.	Bailet	BAILET	BAILET	Honoré	\N	\N	656
85003S	1925-01-01 00:00:00	\N	M.	Laffitte	LAFFITTE	LAFFITTE	Pierre	\N	\N	657
80021X	1925-05-04 00:00:00	2001-10-15 00:00:00	M.	Hugo	HUGO	HUGO BERNARD CHARLES	Bernard Charles	\N	2017-11-08 17:00:05	658
96005E	1937-02-24 00:00:00	2004-10-18 00:00:00	M.	Flandre	FLANDRE	FLANDRE	Hilaire	\N	\N	659
71003U	1922-08-28 00:00:00	2016-06-16 00:00:00	M.	Blin	BLIN	BLIN	Maurice	\N	2016-06-21 15:34:43	660
80004W	1927-07-04 00:00:00	2001-09-04 00:00:00	M.	Authié	AUTHIÉ	AUTHIE	Germain	\N	\N	661
89017R	1945-08-25 00:00:00	\N	M.	Adnot	ADNOT	ADNOT	Philippe	\N	\N	662
94003T	1936-10-09 00:00:00	\N	M.	Gaillard	GAILLARD	GAILLARD	Yann	\N	\N	663
74050Q	1932-08-23 00:00:00	2006-08-11 00:00:00	M.	Courrière	COURRIÈRE	COURRIERE	Raymond	\N	\N	664
80013X	1943-02-24 00:00:00	\N	M.	Courteau	COURTEAU	COURTEAU	Roland	\N	\N	665
80017C	1932-06-17 00:00:00	2008-09-07 00:00:00	M.	Dreyfus-Schmidt	DREYFUS-SCHMIDT	DREYFUS-SCHMIDT	Michel	\N	\N	666
78010Y	1925-09-01 00:00:00	\N	M.	Minetti	MINETTI	MINETTI	Louis	\N	\N	667
89024Q	1942-05-09 00:00:00	\N	M.	Camoin	CAMOIN	CAMOIN	Jean-Pierre	\N	\N	668
000184	1908-04-23 00:00:00	1995-05-29 00:00:00	M.	Bouneau	BOUNEAU	BOUNEAU PIERRE	Pierre	\N	\N	669
000295	1912-07-01 00:00:00	1991-11-01 00:00:00	M.	Bourda	BOURDA	BOURDA PIERRE	Pierre	\N	\N	670
000545	1925-03-09 00:00:00	1990-11-29 00:00:00	M.	Bourgine	BOURGINE	BOURGINE RAYMOND	Raymond	\N	\N	671
59220B	1910-09-30 00:00:00	1999-04-06 00:00:00	M.	Bousch	BOUSCH	BOUSCH JEAN-ERIC	Jean-Eric	\N	\N	672
000140	1905-12-21 00:00:00	1959-07-14 00:00:00	M.	Boutemy	BOUTEMY	BOUTEMY ANDRÉ	André	\N	\N	673
59568D	1928-03-30 00:00:00	2001-10-18 00:00:00	M.	Bouvier	BOUVIER	BOUVIER RAYMOND	Raymond	\N	\N	674
92014N	1939-06-23 00:00:00	\N	M.	Boyer	BOYER	BOYER ERIC	Eric	\N	\N	675
58951C	1922-06-14 00:00:00	2017-09-23 00:00:00	M.	Boyer	BOYER	BOYER EUGÈNE	Eugène	\N	2017-09-28 11:47:01	676
000474	1921-10-27 00:00:00	1989-09-17 00:00:00	M.	Brantus	BRANTUS	BRANTUS PIERRE	Pierre	\N	\N	677
000039	1901-03-31 00:00:00	1972-07-03 00:00:00	M.	Brayard	BRAYARD	BRAYARD JOSEPH	Joseph	\N	\N	678
000020	1900-08-29 00:00:00	1995-03-26 00:00:00	M.	Bregegere	BREGEGERE	BREGEGERE MARCEL	Marcel	\N	\N	679
59523P	1912-07-24 00:00:00	2006-03-09 00:00:00	M.	Brives	BRIVES	BRIVES LOUIS	Louis	\N	\N	680
77019E	1929-10-18 00:00:00	\N	M.	Fourcade	FOURCADE	FOURCADE	Jean-Pierre	\N	\N	681
95016D	1925-06-25 00:00:00	\N	M.	Ceccaldi-Raynaud	CECCALDI-RAYNAUD	CECCALDI-RAYNAUD	Charles	\N	\N	682
80015A	1937-10-21 00:00:00	\N	M.	Delfau	DELFAU	DELFAU	Gérard	\N	\N	683
89043T	1939-09-07 00:00:00	\N	M.	Vézinhet	VÉZINHET	VEZINHET	André	\N	\N	684
80048K	1940-03-07 00:00:00	2006-07-08 00:00:00	M.	Vidal	VIDAL	VIDAL	Marcel	\N	\N	685
80026D	1924-01-09 00:00:00	\N	M.	Madelain	MADELAIN	MADELAIN	Jean	\N	\N	686
80014Y	1930-03-20 00:00:00	2008-04-09 00:00:00	M.	Daunay	DAUNAY	DAUNAY	Marcel	\N	\N	687
80011V	1921-06-29 00:00:00	2009-04-18 00:00:00	M.	Bourges	BOURGES	BOURGES	Yvon	\N	\N	688
89026S	1929-07-12 00:00:00	2016-08-19 00:00:00	M.	Égu	ÉGU	EGU	André	\N	2016-08-23 10:50:27	689
89030N	1927-04-10 00:00:00	2010-01-13 00:00:00	M.	Gerbaud	GERBAUD	GERBAUD	François	\N	\N	690
83026R	1933-08-29 00:00:00	\N	M.	Delaneau	DELANEAU	DELANEAU	Jean	\N	\N	691
92030N	1944-03-17 00:00:00	\N	M.	Leclerc	LECLERC	LECLERC	Dominique	\N	\N	692
92012L	1929-08-20 00:00:00	\N	M.	Bordas	BORDAS	BORDAS	James	\N	\N	693
83020K	1927-04-07 00:00:00	2016-03-15 00:00:00	M.	Cabanel	CABANEL	CABANEL	Guy-Pierre	\N	2016-03-17 17:27:06	694
83018R	1923-08-01 00:00:00	2010-07-18 00:00:00	M.	Boyer	BOYER	BOYER JEAN 83018R	Jean	\N	\N	695
83031N	1937-01-14 00:00:00	\N	M.	Faure	FAURE	FAURE	Jean	\N	\N	696
83004K	1930-05-01 00:00:00	\N	M.	Pluchet	PLUCHET	PLUCHET	Alain	\N	\N	697
89009R	1926-12-14 00:00:00	2001-10-14 00:00:00	M.	Taugourdeau	TAUGOURDEAU	TAUGOURDEAU	Martial	\N	\N	698
89031P	1926-02-25 00:00:00	2010-12-20 00:00:00	M.	Grandon	GRANDON	GRANDON JEAN	Jean	\N	\N	699
80003V	1927-09-20 00:00:00	2014-02-21 00:00:00	M.	Arzel	ARZEL	ARZEL	Alphonse	\N	2014-02-25 12:10:11	700
71024A	1921-02-20 00:00:00	2017-04-09 00:00:00	M.	Le Jeune	LE JEUNE	LEJEUNEE	Edouard	\N	2017-04-11 17:00:28	701
86006A	1937-12-02 00:00:00	\N	M.	Gérard	GÉRARD	GERARD	Alain	\N	\N	702
89034S	1932-10-30 00:00:00	2010-08-11 00:00:00	M.	de Menou	DE MENOU	MENOU	Jacques	\N	\N	703
92046W	1922-01-22 00:00:00	2014-09-07 00:00:00	M.	Cavalier-Benezet	CAVALIER-BENEZET	CAVALIER BENEZET	Francis	\N	2014-09-16 10:32:43	704
80040B	1936-04-29 00:00:00	2015-11-02 00:00:00	M.	Rouvière	ROUVIÈRE	ROUVIERE	André	\N	2015-11-03 09:53:07	705
80033C	1922-06-15 00:00:00	\N	M.	Peyrafitte	PEYRAFITTE	PEYRAFITTE	Jean	\N	\N	706
89019T	1941-01-29 00:00:00	\N	Mme	Bergé-Lavigne	BERGÉ-LAVIGNE	BERGE-LAVIGNE	Maryse	\N	\N	707
89008Q	1930-09-06 00:00:00	2002-11-11 00:00:00	M.	Castaing	CASTAING	CASTAING	Robert	\N	\N	708
89028U	1931-09-07 00:00:00	2000-02-21 00:00:00	M.	Garcia	GARCIA	GARCIA	Aubert	\N	\N	709
93006S	1947-07-05 00:00:00	\N	Mme	Dusseau	DUSSEAU	DUSSEAU	Joëlle	\N	\N	710
90003B	1934-12-19 00:00:00	\N	M.	César	CÉSAR	CESAR	Gérard	\N	\N	711
80027E	1937-04-21 00:00:00	\N	M.	Madrelle	MADRELLE	MADRELLE	Philippe	\N	\N	712
89025R	1941-11-14 00:00:00	\N	M.	Dussaut	DUSSAUT	DUSSAUT	Bernard	\N	\N	713
80046H	1930-05-04 00:00:00	\N	M.	Valade	VALADE	VALADE	Jacques	\N	2016-12-14 15:31:26	714
97003G	1940-11-08 00:00:00	\N	M.	Duffour	DUFFOUR	DUFFOUR	Michel	\N	\N	715
93005R	1942-03-16 00:00:00	\N	M.	Schosteck	SCHOSTECK	SCHOSTECK	Jean-Pierre	\N	\N	716
97002F	1934-11-10 00:00:00	\N	M.	Motroni	MOTRONI	MOTRONI	Jean-Baptiste	\N	\N	717
98003L	1932-04-18 00:00:00	\N	M.	Grillot	GRILLOT	GRILLOT	Louis	\N	\N	718
80025C	1922-02-04 00:00:00	2008-03-10 00:00:00	M.	Lombard	LOMBARD	LOMBARD MAURICE	Maurice	\N	\N	719
80036F	1936-08-23 00:00:00	\N	M.	Régnault	RÉGNAULT	REGNAULT	René	\N	\N	720
97010F	1932-10-16 00:00:00	\N	M.	Derian	DERIAN	DERIAN	Jean	\N	\N	721
89040Q	1943-02-26 00:00:00	\N	M.	Saunier	SAUNIER	SAUNIER	Claude	\N	\N	722
81010Y	1937-06-03 00:00:00	\N	M.	Chervy	CHERVY	CHERVY	William	\N	\N	723
97001E	1937-10-11 00:00:00	\N	M.	Fayolle	FAYOLLE	FAYOLLE	Gérard	\N	\N	724
88002E	1925-12-09 00:00:00	2010-02-27 00:00:00	M.	Pourchet	POURCHET	POURCHET	Jean	\N	\N	725
80041C	1931-10-19 00:00:00	\N	M.	Souvet	SOUVET	SOUVET	Louis	\N	\N	726
86037H	1948-04-22 00:00:00	\N	M.	Loridant	LORIDANT	LORIDANT	Paul	\N	\N	728
95027G	1947-03-27 00:00:00	\N	M.	Dugoin	DUGOIN	DUGOIN	Xavier	\N	\N	729
95053J	1935-07-08 00:00:00	2004-02-12 00:00:00	M.	Pelchat	PELCHAT	PELCHAT	Michel	\N	\N	730
86039K	1951-08-19 00:00:00	\N	M.	Mélenchon	MÉLENCHON	MELENCHON	Jean-Luc	\N	2016-12-14 15:24:16	731
88003F	1924-04-24 00:00:00	2000-03-18 00:00:00	M.	Robert	ROBERT	ROBERT JEANJACQUES	Jean-Jacques	\N	\N	732
89022N	1938-01-25 00:00:00	\N	M.	Bourdin	BOURDIN	BOURDIN	Joël	\N	\N	733
81014D	1928-04-11 00:00:00	2012-01-13 00:00:00	M.	Collard	COLLARD	COLLARD	Henri	\N	\N	734
89044U	1923-03-21 00:00:00	2017-07-08 00:00:00	M.	Vigouroux	VIGOUROUX	VIGOUROUX	Robert-Paul	\N	2017-07-11 17:14:35	735
89039X	1943-01-20 00:00:00	\N	M.	Rocca Serra	ROCCA SERRA	ROCCASERRA JACQUES	Jacques	\N	\N	736
58502E	1930-03-29 00:00:00	2006-11-23 00:00:00	M.	Ehlers	EHLERS	EHLERS GÉRARD	Gérard	\N	\N	738
58641Q	1911-07-19 00:00:00	2004-12-24 00:00:00	M.	Gargar	GARGAR	GARGAR MARCEL	Marcel	\N	2016-03-25 08:56:57	739
58913V	1922-08-09 00:00:00	2006-04-25 00:00:00	M.	De La Verpilliere	DE LA VERPILLIERE	LAVERPILLIERE GUY (DE)	Guy	\N	\N	740
000204	1908-12-28 00:00:00	1994-06-24 00:00:00	M.	Lartigue	LARTIGUE	LARTIGUE EMMANUEL	Emmanuel	\N	\N	741
000004	1900-02-05 00:00:00	1980-02-14 00:00:00	M.	du Luart	du LUART	LUART LADISLAS (DU)	Ladislas	\N	\N	742
000102	1904-06-17 00:00:00	1997-03-04 00:00:00	M.	Mézard	MÉZARD	MEZARD JEAN	Jean	\N	\N	743
95063L	1945-08-29 00:00:00	\N	M.	Richard	RICHARD	RICHARD ALAIN	Alain	\N	\N	744
000268	1911-04-06 00:00:00	1981-09-09 00:00:00	M.	de Tinguy du Pouet	de TINGUY du POUET	TINGUY DU POUET LIONEL (DE)	Lionel	\N	\N	745
000094	1904-01-03 00:00:00	1968-10-24 00:00:00	M.	Tron	TRON	TRON LUDOVIC	Ludovic	\N	\N	746
000246	1910-07-03 00:00:00	1997-03-20 00:00:00	M.	Voyant	VOYANT	VOYANT JOSEPH	Joseph	\N	\N	747
04074L	1947-12-22 00:00:00	\N	M.	Portelli	PORTELLI	PORTELLI HUGUES	Hugues	\N	\N	748
04056J	1941-12-13 00:00:00	\N	Mme	Tasca	TASCA	TASCA CATHERINE	Catherine	\N	\N	749
04058L	1936-12-06 00:00:00	\N	Mme	Dupont	DUPONT	DUPONT BERNADETTE	Bernadette	\N	\N	750
04039H	1949-08-08 00:00:00	\N	M.	Voguet	VOGUET	VOGUET  JEAN FRANÇOIS	Jean-François	\N	\N	751
04037F	1945-03-24 00:00:00	\N	M.	Jégou	JÉGOU	JEGOU JEAN JACQUES	Jean-Jacques	\N	\N	752
04083M	1942-01-12 00:00:00	\N	M.	Merceron	MERCERON	MERCERON JEAN-CLAUDE	Jean-Claude	\N	\N	753
04091M	1940-02-29 00:00:00	\N	M.	Beaumont	BEAUMONT	BEAUMONT RENÉ	René	\N	\N	754
04068N	1968-08-07 00:00:00	\N	Mme	Hurel	HUREL	HUREL SANDRINE	Sandrine	\N	\N	755
59240F	1917-01-17 00:00:00	2004-08-18 00:00:00	M.	Olivier	OLIVIER	OLIVIER HENRI	Henri	\N	\N	756
98041S	1934-12-24 00:00:00	\N	M.	Garrec	GARREC	GARREC	René	\N	\N	757
04064J	1936-10-04 00:00:00	\N	M.	Giraud	GIRAUD	GIRAUD ADRIEN	Adrien	\N	\N	758
04097T	1953-06-05 00:00:00	\N	M.	Huré	HURÉ	HURE BENOIT	Benoît	\N	\N	759
04098U	1945-11-01 00:00:00	\N	M.	Bertaud	BERTAUD	BERTAUD 	Claude	\N	\N	760
04099V	1942-11-08 00:00:00	\N	M.	Chauveau	CHAUVEAU	CHAUVEAU	Jean-Pierre	\N	\N	761
04100U	1931-04-11 00:00:00	\N	Mme	Malovry	MALOVRY	MALOVRY LUCIENNE	Lucienne	\N	\N	762
01017N	1950-01-13 00:00:00	\N	M.	Gaudin	GAUDIN	GAUDIN CHRISTIAN	Christian	\N	\N	764
04101V	1937-04-04 00:00:00	\N	M.	Siffre	SIFFRE	SIFFRE JACQUES	Jacques	\N	\N	765
04065K	1945-01-11 00:00:00	\N	M.	Ries	RIES	RIES ROLAND	Roland	\N	2013-10-09 18:01:10	766
05001W	1956-01-15 00:00:00	\N	Mme	Hoarau	HOARAU	HOARAU_GELITA	Gélita	\N	2016-11-15 12:31:28	767
000028	1909-02-19 00:00:00	\N	M.	Boukikaz	BOUKIKAZ	BOUKIKAZ AHMED	Ahmed	\N	\N	769
000013	1900-05-15 00:00:00	1977-08-14 00:00:00	M.	Belhabich	BELHABICH	BELHABICH SLIMAN	Sliman	\N	\N	770
000115	1905-02-24 00:00:00	1984-11-14 00:00:00	M.	Balestra	BALESTRA	BALESTRA CLÉMENT	Clément	\N	\N	771
86044G	1948-11-17 00:00:00	\N	M.	de Raincourt	de RAINCOURT	RAINCOURT HENRI (DE)	Henri	\N	2014-09-28 20:39:00	772
83013L	1929-08-18 00:00:00	1999-10-16 00:00:00	M.	Bataille	BATAILLE	BATAILLE	Jean-Paul	\N	\N	773
83016P	1921-06-14 00:00:00	\N	M.	Bonnet	BONNET	BONNET	Christian	\N	\N	774
000076	1903-06-15 00:00:00	1992-11-28 00:00:00	M.	Carcassonne	CARCASSONNE	CARCASSONNE ROGER	Roger	\N	\N	775
000191	1908-07-21 00:00:00	1965-08-19 00:00:00	M.	Charpentier	CHARPENTIER	CHARPENTIER MAURICE	Maurice	\N	\N	776
000245	1910-06-10 00:00:00	1981-01-03 00:00:00	M.	Deguise	DEGUISE	DEGUISE JEAN	Jean	\N	\N	777
57714L	1920-04-11 00:00:00	2017-07-27 00:00:00	M.	Durafour	DURAFOUR	DURAFOUR MICHEL	Michel	\N	2017-08-02 12:33:43	778
000062	1902-04-06 00:00:00	1986-08-16 00:00:00	M.	Golvan	GOLVAN	GOLVAN VICTOR	Victor	\N	\N	779
000092	1903-11-17 00:00:00	1986-04-17 00:00:00	M.	Guyot	GUYOT	GUYOT RAYMOND	Raymond	\N	\N	780
59540Q	1917-02-18 00:00:00	2015-10-22 00:00:00	M.	Jung	JUNG	JUNG LOUIS	Louis	\N	2015-10-23 18:06:01	781
58026W	1915-06-24 00:00:00	2004-02-01 00:00:00	M.	Moreau	MOREAU	MOREAU HENRI	Henri	\N	\N	782
000543	1925-02-03 00:00:00	1980-09-02 00:00:00	M.	Piot	PIOT	PIOT JACQUES	Jacques	\N	\N	783
000108	1904-08-29 00:00:00	1981-06-18 00:00:00	M.	de Pommery	de POMMERY	POMMERY JOSEPH (DE)	Joseph	\N	\N	784
000443	1920-03-18 00:00:00	1985-05-26 00:00:00	M.	Roujon	ROUJON	ROUJON JULES	Jules	\N	\N	785
000298	1912-10-04 00:00:00	1990-01-09 00:00:00	M.	Soufflet	SOUFFLET	SOUFFLET JACQUES	Jacques	\N	\N	786
000322	1913-08-09 00:00:00	1973-09-09 00:00:00	M.	Dubois	DUBOIS	DUBOIS EMILE	Emile	\N	\N	787
81015E	1941-07-08 00:00:00	\N	M.	Charasse	CHARASSE	CHARASSE	Michel	\N	2016-12-14 15:18:36	788
80039J	1943-09-08 00:00:00	\N	M.	Roujas	ROUJAS	ROUJAS	Gérard	\N	\N	789
89007P	1937-05-11 00:00:00	\N	M.	Dupont	DUPONT	DUPONT AMBROISE	Ambroise	\N	\N	790
98049B	1950-11-19 00:00:00	\N	Mme	Boyer	BOYER	BOYER YOLANDE	Yolande	\N	\N	791
01032M	1928-01-12 00:00:00	2006-05-16 00:00:00	M.	Labarrère	LABARRÈRE	LABARRERE	André	\N	\N	792
01036R	2006-10-13 00:00:00	\N	Mme	San Vicente-Baudrin	SAN VICENTE-BAUDRIN	SANVICENTE-BAUDRIN	Michèle	\N	\N	793
97004H	1940-01-02 00:00:00	\N	M.	Lagauche	LAGAUCHE	LAGAUCHE	Serge	\N	\N	794
04043D	1949-10-13 00:00:00	\N	Mme	Procaccia	PROCACCIA	PROCACCIA CATHERINE	Catherine	\N	\N	795
04048J	1942-11-08 00:00:00	\N	M.	Houel	HOUEL	HOUEL MICHEL	Michel	\N	\N	796
04050C	1950-03-05 00:00:00	\N	M.	Vera	VERA	VERA BERNARD	Bernard	\N	\N	797
04051D	1940-03-16 00:00:00	\N	Mme	Dini	DINI	DINI MUGUETTE	Muguette	\N	2014-01-21 10:42:59	798
04053F	1947-06-10 00:00:00	\N	Mme	Bricq	BRICQ	BRICQ NICOLE	Nicole	\N	\N	799
04054G	1958-02-19 00:00:00	\N	M.	Billout	BILLOUT	BILLOUT MICHEL	Michel	\N	2013-12-04 10:36:18	800
04055H	1925-04-04 00:00:00	\N	M.	Dassault	DASSAULT	DASSAULT SERGE	Serge	\N	2014-01-21 10:44:52	801
04059M	1959-06-16 00:00:00	\N	M.	Assouline	ASSOULINE	ASSOULINE DAVID	David	\N	2013-11-07 16:14:41	802
04060E	1936-08-24 00:00:00	\N	Mme	Gousseau	GOUSSEAU	GOUSSEAU ADELINE	Adeline	\N	\N	803
04061F	1959-10-20 00:00:00	\N	Mme	Keller	KELLER	KELLER FABIENNE	Fabienne	\N	2014-09-28 20:41:04	804
04062G	1949-03-05 00:00:00	2007-11-19 00:00:00	M.	Ibrahim	IBRAHIM	IBRAHIM SOIBAHADDINE	Soibahaddine	\N	\N	805
04066L	1951-11-08 00:00:00	\N	M.	Caffet	CAFFET	CAFFET JEAN-PIERRE	Jean-Pierre	\N	\N	806
04067M	1952-09-06 00:00:00	\N	M.	Desessard	DESESSARD	DESESSARD JEAN	Jean	\N	\N	807
04069P	1952-05-09 00:00:00	\N	Mme	Sittler	SITTLER	SITTLER ESTHER	Esther	\N	\N	808
04070G	1960-07-06 00:00:00	\N	Mme	Morin-Desailly	MORIN-DESAILLY	MORIN-DESAILLY CATHERINE	Catherine	\N	2014-09-28 20:35:57	809
04071H	1954-04-12 00:00:00	\N	M.	Dominati	DOMINATI	DOMINATI PHILIPPE	Philippe	\N	\N	810
04072J	1954-04-30 00:00:00	\N	M.	Goujon	GOUJON	GOUJON PHILIPPE	Philippe	\N	\N	811
04073K	1945-06-21 00:00:00	\N	M.	Bordier	BORDIER	BORDIER PIERRE	Pierre	\N	\N	812
04075M	1947-09-17 00:00:00	\N	Mme	Hermange	HERMANGE	HERMANGE MARIE-THÉRÈSE	Marie-Thérèse	\N	\N	813
03001N	1948-11-05 00:00:00	\N	M.	Krattinger	KRATTINGER	KRATTINGER	Yves	\N	\N	827
74041P	1925-06-19 00:00:00	1998-07-17 00:00:00	M.	Quilliot	QUILLIOT	QUILLIOT	Roger	\N	\N	828
000070	1902-10-25 00:00:00	1990-07-26 00:00:00	M.	Minvielle	MINVIELLE	MINVIELLE GÉRARD	Gérard	\N	\N	829
000305	1913-02-12 00:00:00	1975-06-18 00:00:00	M.	Sadi	SADI	SADI ABDELKRIM	Abdelkrim	\N	\N	831
01042P	1951-04-10 00:00:00	\N	M.	Lecerf	LECERF	LECERF	Jean-René	\N	2013-10-18 14:25:43	832
000141	1906-03-03 00:00:00	1994-08-27 00:00:00	M.	Poroi	POROI	POROI ALFRED	Alfred	\N	\N	836
000156	1906-10-13 00:00:00	1993-01-21 00:00:00	M.	Porteu De La Morandiere	PORTEU DE LA MORANDIERE	PORTEU DE LA MORANDIERE PAUL	Paul	\N	\N	837
58917A	1921-06-05 00:00:00	2009-06-12 00:00:00	M.	Portier	PORTIER	PORTIER HENRI	Henri	\N	\N	838
59242H	1922-12-14 00:00:00	2000-12-27 00:00:00	M.	Poudonson	POUDONSON	POUDONSON ROGER	Roger	\N	\N	839
000470	1921-08-15 00:00:00	1996-07-21 00:00:00	M.	Pouille	POUILLE	POUILLE RICHARD	Richard	\N	\N	840
88010E	1942-07-29 00:00:00	\N	M.	Pradille	PRADILLE	PRADILLE CLAUDE	Claude	\N	\N	841
04077P	1946-09-03 00:00:00	\N	Mme	Khiari	KHIARI	KHIARI BARIZA	Bariza	\N	\N	843
04078Q	1946-10-19 00:00:00	\N	M.	Hue	HUE	HUE ROBERT	Robert	\N	\N	844
04080J	1948-05-03 00:00:00	\N	M.	Pozzo di Borgo	POZZO di BORGO	POZZO DI BORGO YVES	Yves	\N	\N	845
04081K	1957-05-23 00:00:00	\N	Mme	Debré	DEBRÉ	DEBRE ISABELLE	Isabelle	\N	\N	846
04084N	1938-08-05 00:00:00	\N	M.	Michel	MICHEL	MICHELJEAN-PIERRE	Jean-Pierre	\N	\N	847
04085P	1958-10-02 00:00:00	\N	Mme	Assassi	ASSASSI	ASSASSI ELIANE	Éliane	\N	\N	848
04086Q	1962-12-08 00:00:00	\N	M.	Dallier	DALLIER	DALLIER PHILIPPE	Philippe	\N	2013-10-08 15:52:09	849
04087R	1947-07-29 00:00:00	\N	Mme	Alquier	ALQUIER	ALQUIER JACQUELINE	Jacqueline	\N	\N	850
04088S	1946-05-27 00:00:00	\N	M.	Pierre	PIERRE	PIERRE JACKIE	Jackie	\N	2014-09-28 20:38:40	851
04089T	1952-02-05 00:00:00	\N	M.	Dubois	DUBOIS	DUBOIS DANIEL	Daniel	\N	2013-10-17 10:48:51	852
04090L	1963-04-05 00:00:00	\N	M.	Repentin	REPENTIN	REPENTIN THIERRY	Thierry	\N	2016-12-14 15:29:11	853
04093P	1953-04-29 00:00:00	\N	M.	Detcheverry	DETCHEVERRY	DETCHEVERRY DENIS	Denis	\N	\N	854
04094Q	1945-10-17 00:00:00	\N	M.	Larcher	LARCHER	LARCHER SERGE	Serge	\N	\N	855
04095R	1948-03-04 00:00:00	\N	M.	Gillot	GILLOT	GILLOT JACQUES	Jacques	\N	\N	856
04096S	1951-11-13 00:00:00	\N	M.	Marsin	MARSIN	MARSIN DANIEL	Daniel	\N	\N	857
04052E	1942-08-08 00:00:00	\N	M.	Bodin	BODIN	BODIN YANNICK	Yannick	\N	\N	858
04063H	1956-07-24 00:00:00	\N	Mme	Boumediene-Thiery	BOUMEDIENE-THIERY	BOUMEDIENE-THIERY ALIMA	Alima	\N	\N	859
04035D	1955-03-20 00:00:00	\N	Mme	Garriaud-Maylam	GARRIAUD-MAYLAM	GARRIAUD-MAYLAM JOËLLE	Joëlle	\N	\N	860
04057K	1947-04-20 00:00:00	\N	Mme	Mélot	MÉLOT	MELOT COLETTE	Colette	\N	\N	861
04092N	1947-09-16 00:00:00	\N	M.	Milon	MILON	MILON ALAIN	Alain	\N	2014-09-28 20:38:20	862
95011X	1945-12-08 00:00:00	2004-01-29 00:00:00	Mme	Borvo	BORVO	BORVO	Nicole	\N	\N	863
01038T	1954-08-23 00:00:00	2005-12-13 00:00:00	Mme	Mathon	MATHON	MATHON	Josiane	\N	\N	864
01036R	1955-05-19 00:00:00	2006-10-12 00:00:00	Mme	San Vicente	SAN VICENTE	SANVICENTE	Michèle	\N	\N	865
06001B	2006-06-07 00:00:00	2006-09-05 00:00:00	Mme	Jarraud	JARRAUD	JARRAUD	Annie	\N	\N	866
06001B	1948-02-07 00:00:00	2006-06-06 00:00:00	Mme	Jarraud-Mordrelle	JARRAUD-MORDRELLE	JARRAUDMORDRELLE	Annie	\N	\N	867
07002G	1949-07-12 00:00:00	\N	Mme	Roger-Coupin	ROGER-COUPIN	ROGER-COUPIN MARYSE	Maryse	\N	\N	869
07026Q	1956-04-23 00:00:00	\N	Mme	Gonthier-Maurin	GONTHIER-MAURIN	GONTHIER-MAURIN BRIGITTE	Brigitte	\N	2013-07-01 10:46:16	870
07023M	1948-04-16 00:00:00	\N	Mme	Panis	PANIS	PANIS JACQUELINE	Jacqueline	\N	\N	871
07025P	1948-05-08 00:00:00	\N	M.	Le Vern	LE VERN	LEVERN ALAIN	Alain	\N	2013-10-01 15:11:35	872
07024N	1946-09-18 00:00:00	\N	M.	Gautier	GAUTIER	GAUTIER JACQUES	Jacques	\N	2013-10-30 17:32:10	873
04062G	2007-11-19 00:00:00	\N	M.	Ibrahim Ramadani	IBRAHIM RAMADANI	IBRAHIM RAMADANI SOIBAHADINE	Soibahadine	\N	\N	875
07032N	1948-10-24 00:00:00	\N	M.	Pinton	PINTON	PINTON LOUIS	Louis	\N	\N	876
08001K	1891-03-17 00:00:00	1969-08-12 00:00:00	M.	Gallard	GALLARD	GALLARD MAURICE	Maurice	\N	\N	877
08007R	1948-10-15 00:00:00	\N	M.	Brun	BRUN	BRUN ELIE	Elie	\N	\N	878
08008S	1949-06-01 00:00:00	\N	M.	Ackermann	ACKERMANN	ACKERMANN YVES	Yves	\N	\N	879
08009T	1961-05-07 00:00:00	\N	M.	Maurey	MAUREY	MAUREY HERVÉ	Hervé	\N	2014-09-28 20:30:04	880
08010L	1966-02-18 00:00:00	\N	M.	Lefèvre	LEFÈVRE	LEFEVRE ANTOINE	Antoine	\N	\N	881
08011M	1964-07-06 00:00:00	\N	M.	de Montgolfier	de MONTGOLFIER	MONTGOLFIER	Albéric	\N	\N	882
08012N	1954-02-08 00:00:00	\N	M.	Lozach	LOZACH	LOZACH JEAN-JACQUES	Jean-Jacques	\N	2014-09-28 20:28:52	883
08013P	1961-08-21 00:00:00	2010-03-15 00:00:00	Mme	Chevé	CHEVÉ	CHEVE JACQUELINE	Jacqueline	\N	\N	884
08014Q	1951-12-09 00:00:00	\N	M.	Botrel	BOTREL	BOTREL YANNICK	Yannick	\N	2014-09-28 20:28:19	885
07029T	1956-07-01 00:00:00	\N	M.	Laménie	LAMÉNIE	LAMENIE MARC	Marc	\N	\N	886
07030L	1946-09-01 00:00:00	\N	M.	Couderc	COUDERC	COUDERC RAYMOND	Raymond	\N	2013-09-06 09:40:05	887
08016S	1959-05-11 00:00:00	\N	M.	Guillaume	GUILLAUME	GUILLAUME DIDIER	Didier	\N	\N	888
08018U	1968-02-04 00:00:00	\N	M.	Frassa	FRASSA	FRASSA CHRISTOPHE ANDRÉ	Christophe-André	\N	2013-10-08 14:02:52	889
08020N	1942-10-26 00:00:00	\N	Mme	Bruguière	BRUGUIÈRE	BRUGUIERE	Marie-Thérèse	\N	\N	890
08021P	1952-05-01 00:00:00	\N	M.	Navarro	NAVARRO	NAVARRO ROBERT	Robert	\N	2013-10-15 11:22:28	891
08023R	1946-12-01 00:00:00	\N	M.	Fleming	FLEMING	FLEMING LOUIS-CONSTANT	Louis-Constant	\N	2014-01-02 09:46:14	892
08026U	1962-03-08 00:00:00	\N	Mme	Pasquet	PASQUET	PASQUET	Isabelle	\N	\N	893
08027V	1942-12-03 00:00:00	\N	M.	Hervé	HERVÉ	HERVE EDMOND	Edmond	\N	\N	894
08029X	1941-08-09 00:00:00	\N	M.	Povinelli	POVINELLI	POVINELLI	Roland	\N	2014-01-21 10:39:26	895
08043V	1947-01-20 00:00:00	\N	Mme	Blondin	BLONDIN	BLONDIN MARYVONNE	Maryvonne	\N	2013-10-28 17:30:01	896
08032S	1961-08-18 00:00:00	\N	Mme	Klès	KLÈS	KLES VIRGINIE	Virginie	\N	2013-10-18 10:12:59	897
08034U	1952-02-18 00:00:00	\N	M.	de Legge	de LEGGE	LEGGE (DE) DOMINIQUE	Dominique	\N	2014-09-28 20:39:47	898
08035V	1968-06-10 00:00:00	\N	Mme	Ghali	GHALI	GHALI SAMIA	Samia	\N	2014-09-28 20:26:26	899
08037X	1941-03-17 00:00:00	\N	M.	Le Menn	LE MENN	LEMENN JACKY	Jacky	\N	\N	900
08040S	1940-03-15 00:00:00	\N	M.	Andreoni	ANDREONI	ANDREONI SERGE	Serge	\N	\N	901
08044W	1969-10-25 00:00:00	2014-11-20 00:00:00	Mlle	Joissains	JOISSAINS	JOISSAINS SOPHIE	Sophie	\N	2014-11-25 11:54:49	902
08045X	1953-07-15 00:00:00	\N	M.	Fichet	FICHET	FICHET JEAN-LUC	Jean-Luc	\N	2013-10-08 14:14:40	903
08047A	1965-01-25 00:00:00	\N	M.	Paul	PAUL	PAUL PHILIPPE	Philippe	\N	2013-10-09 17:57:38	904
08048B	1960-12-26 00:00:00	\N	M.	Gilles	GILLES	GILLES BRUNO	Bruno	\N	2014-09-28 20:26:43	905
08049C	1942-01-13 00:00:00	\N	M.	Vall	VALL	VALL RAYMOND	Raymond	\N	\N	906
08051V	1947-12-03 00:00:00	\N	M.	Mézard	MÉZARD	MEZARD JACQUES	Jacques	\N	2013-10-08 16:39:04	907
08053X	1940-02-12 00:00:00	\N	M.	Mazuir	MAZUIR	MAZUIR RACHEL	Rachel	\N	\N	908
08054Y	1949-01-04 00:00:00	\N	Mme	Schurch	SCHURCH	SCHURCH MIREILLE	Mireille	\N	\N	909
08056B	1963-05-25 00:00:00	\N	Mme	Goy-Chavent	GOY-CHAVENT	GOY-CHAVENT SYLVIE	Sylvie	\N	\N	910
08057C	1948-04-20 00:00:00	\N	M.	Chastan	CHASTAN	CHASTAN YVES	Yves	\N	2013-10-08 15:54:24	911
08059E	1940-03-03 00:00:00	\N	M.	Berthou	BERTHOU	BERTHOU JACQUES	Jacques	\N	\N	912
07033P	1957-07-13 00:00:00	\N	Mme	Dumas	DUMAS	DUMAS CATHERINE	Catherine	\N	\N	913
08061X	1943-03-21 00:00:00	\N	M.	Patriat	PATRIAT	PATRIAT FRANÇOIS	François	\N	2013-11-22 15:53:50	914
08062Y	1940-01-30 00:00:00	\N	M.	Mayet	MAYET	MAYET JEAN-FRANÇOIS	Jean-François	\N	2014-09-28 20:40:39	915
08063A	1950-02-27 00:00:00	\N	Mme	Laurent-Perrigot	LAURENT-PERRIGOT	LAURENT-PERRIGOT FRANÇOISE	Françoise	\N	\N	916
08064B	1942-08-15 00:00:00	\N	Mme	Escoffier	ESCOFFIER	ESCOFFIER ANNE-MARIE	Anne-Marie	\N	2016-12-14 15:21:08	917
08065C	1945-10-16 00:00:00	\N	M.	Fournier	FOURNIER	FOURNIER JEAN-PAUL	Jean-Paul	\N	2014-01-21 10:35:56	918
08066D	1945-02-20 00:00:00	\N	M.	Fauconnier	FAUCONNIER	FAUCONNIER ALAIN	Alain	\N	\N	919
08067E	1945-04-10 00:00:00	\N	M.	Jeannerot	JEANNEROT	JEANNEROT CLAUDE	Claude	\N	\N	920
08068F	1952-07-23 00:00:00	\N	M.	Bourquin	BOURQUIN	BOURQUINMARTIAL	Martial	\N	2013-08-19 17:30:49	921
08070Y	1951-06-25 00:00:00	\N	M.	Rebsamen	REBSAMEN	REBSAMEN FRANÇOIS	François	\N	2014-05-12 18:05:42	922
08071A	1974-02-28 00:00:00	\N	M.	Tuheiava	TUHEIAVA	TUHEIAVA RICHARD	Richard	\N	\N	923
08072B	1966-01-29 00:00:00	\N	M.	Antoinette	ANTOINETTE	ANTOINETTE JEAN-ETIENNE	Jean-Étienne	\N	\N	924
08073C	1949-04-01 00:00:00	\N	M.	Patient	PATIENT	PATIENT GEORGES	Georges	\N	2014-09-28 20:42:01	925
08074D	1929-12-18 00:00:00	\N	M.	Milhau	MILHAU	MILHAU JEAN	Jean	\N	\N	926
09001P	1969-07-12 00:00:00	\N	Mme	Jouanno	JOUANNO	JOUANNO CHANTAL	Chantal	\N	\N	928
09010Q	1947-04-15 00:00:00	\N	M.	Pignard	PIGNARD	PIGNARD JEAN-JACQUES	Jean-Jacques	\N	\N	930
09011R	1954-12-13 00:00:00	\N	M.	Villiers	VILLIERS	VILLIERS ANDRÉ	André	\N	\N	931
10001F	1945-06-12 00:00:00	\N	Mme	Labarre	LABARRE	LABARRE MARIE-AGNÈS	Marie-Agnès	\N	\N	932
10003H	1962-07-16 00:00:00	\N	M.	Kerdraon	KERDRAON	KERDRAON RONAN	Ronan	\N	2014-01-21 10:42:34	934
10005K	1953-04-13 00:00:00	\N	Mme	Longère	LONGÈRE	LONGERE CHRISTIANE	Christiane	\N	\N	935
10006L	1953-02-24 00:00:00	\N	Mme	Deroche	DEROCHE	DEROCHE CATHERINE	Catherine	\N	\N	936
10007M	1945-10-10 00:00:00	\N	Mme	Oudit	OUDIT	OUDIT MIREILLE	Mireille	\N	\N	937
07004J	1958-05-24 00:00:00	\N	Mme	Goulet	GOULET	GOULET NATHALIE	Nathalie	\N	\N	946
07003H	1944-01-16 00:00:00	\N	M.	Bernard-Reymond	BERNARD-REYMOND	BERNARDREYMOND PIERRE	Pierre	\N	\N	959
07027R	1954-10-30 00:00:00	\N	M.	Muller	MULLER	MULLER JACQUES	Jacques	\N	\N	964
07028S	1951-06-22 00:00:00	\N	Mme	Descamps	DESCAMPS	DESCAMPS BÉATRICE	Béatrice	\N	\N	965
07034Q	1950-05-13 00:00:00	\N	M.	Pillet	PILLET	PILLET FRANÇOIS	François	\N	\N	966
08019V	1954-01-06 00:00:00	\N	M.	Magras	MAGRAS	MAGRAS MICHEL	Michel	\N	2013-10-08 11:59:05	972
11115U	1973-06-28 00:00:00	\N	M.	Courtial	COURTIAL	COURTIAL ÉDOUARD	Édouard	\N	\N	973
08022Q	1950-05-26 00:00:00	\N	Mme	Des Esgaulx	DES ESGAULX	DESESGAULX MARIE-HÉLÈNE	Marie-Hélène	\N	2014-01-21 10:38:02	974
08024S	1949-03-27 00:00:00	\N	Mme	Cartron	CARTRON	CARTRON FRANÇOISE	Françoise	\N	2013-08-28 15:42:25	975
08025T	1951-05-30 00:00:00	\N	M.	Anziani	ANZIANI	ANZIANI ALAIN	Alain	\N	2013-10-09 17:19:22	976
08028W	1943-03-15 00:00:00	\N	M.	Chatillon	CHATILLON	CHATILLON ALAIN	Alain	\N	\N	977
08031R	1958-07-08 00:00:00	\N	Mme	Laborde	LABORDE	LABORDE FRANÇOISE	Françoise	\N	2013-10-29 09:33:27	978
08033T	1952-01-01 00:00:00	\N	M.	Mirassou	MIRASSOU	MIRASSOU JEAN-JACQUES	Jean-Jacques	\N	2013-10-08 15:57:59	979
08036W	1938-10-25 00:00:00	2013-02-06 00:00:00	M.	Vestri	VESTRI	VESTRI RENÉ	René	\N	\N	980
08038Y	1955-04-22 00:00:00	\N	M.	Daunis	DAUNIS	DAUNIS MARC	Marc	\N	2014-09-28 20:24:18	981
08039A	1947-05-08 00:00:00	\N	M.	Leleux	LELEUX	LELEUX JEAN-PIERRE	Jean-Pierre	\N	2014-09-28 20:25:08	982
08041T	1943-11-24 00:00:00	\N	Mme	Giudicelli	GIUDICELLI	GIUDICELLI COLETTE	Colette	\N	2014-09-28 20:24:46	983
08042U	1947-02-08 00:00:00	\N	M.	Nègre	NÈGRE	NEGRE LOUIS	Louis	\N	2014-09-28 20:25:30	984
08046Y	1931-06-17 00:00:00	\N	M.	Teulade	TEULADE	TEULADE RENÉ	René	\N	2014-02-14 10:20:26	985
08050U	1945-05-20 00:00:00	\N	Mme	Bourzai	BOURZAI	BOURZAI BERNADETTE	Bernadette	\N	2013-10-10 13:49:28	986
08052W	1947-02-23 00:00:00	\N	M.	Daudigny	DAUDIGNY	DAUDIGNY YVES	Yves	\N	2013-10-08 12:02:18	987
08055A	1946-02-19 00:00:00	\N	M.	Bérit-Débat	BÉRIT-DÉBAT	BERITDEBAT CLAUDE	Claude	\N	2014-09-28 20:29:15	988
08058D	1956-11-23 00:00:00	\N	M.	Boutant	BOUTANT	BOUTANT MICHEL	Michel	\N	\N	989
08060W	1958-08-18 00:00:00	\N	Mme	Bonnefoy	BONNEFOY	BONNEFOY NICOLE	Nicole	\N	\N	990
02053W	1940-01-01 00:00:00	\N	M.	Chevènement	CHEVÈNEMENT	CHEVENEMENT	Jean-Pierre	\N	\N	993
58654V	1908-08-02 00:00:00	2001-12-14 00:00:00	M.	Bosson	BOSSON	BOSSON CHARLES	Charles	\N	\N	996
000032	1900-11-14 00:00:00	1984-03-13 00:00:00	M.	Bastit-St Martin	BASTIT-ST MARTIN	BASTIT-ST MARTIN ARMAND	Armand	\N	\N	997
95003X	1935-11-12 00:00:00	\N	M.	Massion	MASSION	MASSION	Marc	\N	2014-01-02 09:46:53	998
96001A	1936-01-06 00:00:00	\N	M.	Lèguevaques	LÈGUEVAQUES	LEGUEVAQUES	Guy	\N	\N	999
000195	1908-08-14 00:00:00	1981-04-23 00:00:00	M.	Chochoy	CHOCHOY	CHOCHOY BERNARD	Bernard	\N	\N	1000
000043	1901-05-10 00:00:00	1983-10-11 00:00:00	M.	Flechet	FLECHET	FLECHET MAX	Max	\N	\N	1001
000271	1911-04-30 00:00:00	1971-07-22 00:00:00	M.	du Halgouet	DU HALGOUET	HALGOUET ROGER DU	Roger	\N	\N	1002
000516	1923-10-23 00:00:00	1991-11-03 00:00:00	M.	Kauss	KAUSS	KAUSS PAUL	Paul	\N	\N	1003
59550S	1912-11-06 00:00:00	2005-05-03 00:00:00	M.	Maurice-Bokanowski	MAURICE-BOKANOWSKI	MAURICE-BOKANOWSKI MICHEL	Michel	\N	\N	1004
89042S	1935-01-29 00:00:00	\N	M.	Vallet	VALLET	VALLET	André	\N	\N	1507
83042R	1944-08-23 00:00:00	\N	M.	Masseret	MASSERET	MASSERET JEAN-PIERRE	Jean-Pierre	\N	\N	1508
98015Q	1934-02-26 00:00:00	\N	M.	Picheral	PICHERAL	PICHERAL	Jean-François	\N	\N	1509
98044V	1942-06-03 00:00:00	\N	M.	Nogrix	NOGRIX	NOGRIX	Philippe	\N	\N	1510
92043T	1943-12-27 00:00:00	\N	M.	Sergent	SERGENT	SERGENT	Michel	\N	\N	1511
01015L	1948-03-14 00:00:00	\N	Mme	Didier	DIDIER	DIDIER EVELYNE	Évelyne	\N	2013-10-17 15:25:55	1512
01043Q	1962-10-13 00:00:00	\N	Mme	Létard	LÉTARD	LETARD	Valérie	\N	2013-10-28 17:55:28	1513
000737	1898-08-19 00:00:00	1964-08-07 00:00:00	M.	Kalb	KALB	KALB 	Paul-Jacques	\N	\N	1514
02009S	1954-03-04 00:00:00	\N	M.	Fillon	FILLON	FILLON	François	\N	\N	1515
04034C	1947-09-22 00:00:00	\N	M.	Yung	YUNG	YUNG RICHARD	Richard	\N	2013-10-08 16:28:26	1516
04036E	1932-07-10 00:00:00	\N	Mme	Kammermann	KAMMERMANN	KAMMERMANNCHRISTIANE	Christiane	\N	\N	1517
04033B	1960-11-20 00:00:00	\N	M.	Retailleau	RETAILLEAU	RETAILLEAU BRUNO	Bruno	\N	\N	1518
04038G	1945-07-18 00:00:00	\N	M.	Collombat	COLLOMBAT	COLLOMBAT PIERRE-YVES	Pierre-Yves	\N	2014-09-28 20:36:51	1519
14018U	1969-02-18 00:00:00	\N	Mme	Malherbe	MALHERBE	MALHERBE_HERMELINE	Hermeline	2014-08-27 16:32:46	2015-04-20 10:24:31	3021
14199E	1950-08-06 00:00:00	\N	M.	Genest	GENEST	GENEST_Jacques	Jacques	2014-09-28 14:31:41	\N	3281
14251Q	1950-03-08 00:00:00	\N	M.	Malhuret	MALHURET	MALHURET_Claude	Claude	2014-09-28 18:32:20	\N	3342
14265W	1961-07-28 00:00:00	\N	Mme	Morhet-Richaud	MORHET-RICHAUD	MORHET_RICHAUD_Patricia	Patricia	2014-12-29 15:45:40	2015-01-02 11:37:16	3461
14355X	1959-07-03 00:00:00	\N	Mme	Gerbaud	GERBAUD	GERBAUD_frederique	Frédérique	2016-11-18 12:45:10	\N	3821
11100Y	1944-12-27 00:00:00	\N	M.	Lenoir	LENOIR	LENOIR_JEAN_CLAUDE_11100Y	Jean-Claude	\N	\N	1528
11105E	1942-05-01 00:00:00	\N	M.	Néri	NÉRI	NERI_ALAIN_C4673	Alain	\N	\N	1538
11104D	1952-06-01 00:00:00	\N	M.	Magner	MAGNER	MAGNER_JACQUES_BERNARD_C4674	Jacques-Bernard	\N	\N	1539
11041F	1956-07-15 00:00:00	\N	M.	Vallini	VALLINI	VALLINI_ANDRE_11041F	André	\N	2017-04-24 17:52:38	1557
11042G	1949-10-03 00:00:00	\N	M.	Chiron	CHIRON	CHIRON_JACQUES_C4832	Jacques	\N	\N	1559
11112D	1943-06-16 00:00:00	\N	M.	Labazée	LABAZÉE	LABAZEE_GEORGES_11112D	Georges	\N	\N	1577
11111C	1944-03-11 00:00:00	\N	M.	Lasserre	LASSERRE	LASSERRE_JEAN_JACQUES_11111C	Jean-Jacques	\N	\N	1583
14021P	1957-04-29 00:00:00	\N	M.	Kanner	KANNER	KANNER_Patrick	Patrick	2014-08-27 17:51:28	2017-10-05 15:22:38	3024
14193X	1974-01-20 00:00:00	\N	M.	Perrin	PERRIN	PERRIN_Cedric	Cédric	2014-09-28 12:32:22	\N	3262
11110B	1972-04-19 00:00:00	\N	Mme	Espagnac	ESPAGNAC	ESPAGNAC_FREDERIQUE_C4700	Frédérique	\N	2013-05-13 17:35:51	1590
14195A	1945-04-10 00:00:00	\N	M.	Chasseing	CHASSEING	CHASSEING_Daniel	Daniel	2014-09-28 12:44:31	\N	3263
14197C	1958-01-02 00:00:00	\N	M.	Duran	DURAN	DURAN_Alain	Alain	2014-09-28 12:54:15	\N	3264
14253S	1946-12-04 00:00:00	\N	M.	Nougein	NOUGEIN	NOUGEIN_Claude	Claude	2014-09-28 18:32:41	\N	3343
01023L	1948-02-16 00:00:00	\N	M.	Vantomme	VANTOMME	VANTOMME	André	\N	\N	1317
11018G	1954-10-07 00:00:00	\N	M.	Bourquin	BOURQUIN	BOURQUINCHRISTIAN_11018G	Christian	\N	\N	1598
11101A	1953-04-01 00:00:00	\N	M.	Calvet	CALVET	CALVET_FRANCOIS_11101A	François	\N	\N	1600
000707	1888-03-11 00:00:00	1983-03-14 00:00:00	M.	Le Sassier Boisauné	LE SASSIER BOISAUNÉ	LESASSIER BOISAUNÉ ETIENNE	Etienne	\N	\N	1415
11114F	1956-11-18 00:00:00	\N	M.	Cornano	CORNANO	CORNANO_JACQUES_11114F	Jacques	\N	\N	1616
11113E	1943-02-22 00:00:00	\N	M.	Desplan	DESPLAN	DESPLAN_FELIX11113E	Félix	\N	\N	1618
000353	1914-12-24 00:00:00	1986-12-18 00:00:00	M.	Berrier	BERRIER	BERRIER NOËL	Noël	\N	\N	1439
11109J	1953-06-22 00:00:00	\N	M.	Antiste	ANTISTE	ANTISTE_MAURICE_C4745	Maurice	\N	\N	1629
11023D	1963-11-15 00:00:00	\N	Mme	Claireaux	CLAIREAUX	CLAIREAUX_KARINE_11023D	Karine	\N	\N	1631
04040A	1950-06-22 00:00:00	\N	M.	Bockel	BOCKEL	BOCKEL JEAN-MARIE	Jean-Marie	\N	2013-10-09 09:26:00	1520
11071M	1959-10-04 00:00:00	\N	M.	Soilihi	SOILIHI	SOILIHI_ABDOURAHAMANE_C4750	Abdourahamane	\N	\N	1633
11072N	1972-06-20 00:00:00	\N	M.	Mohamed Soilihi	MOHAMED SOILIHI	MOHAMED_SOILIHI_THANI_11072N	Thani	\N	\N	1640
13002U	1952-05-19 00:00:00	\N	M.	Poher	POHER	POHER HERVÉ	Hervé	\N	2013-07-17 12:06:44	1654
11107G	1943-06-22 00:00:00	\N	M.	Filleul	FILLEUL	FILLEUL_JEAN_JACQUES_11107G	Jean-Jacques	\N	\N	1657
11108H	1947-09-11 00:00:00	2015-04-07 00:00:00	M.	Germain	GERMAIN	GERMAIN_JEAN_11108H	Jean	\N	2015-04-09 10:26:00	1659
14037X	1977-09-15 00:00:00	\N	M.	Lemoyne	LEMOYNE	LEMOYNE_Jean_Baptiste	Jean-Baptiste	2014-09-17 11:34:42	2014-09-28 19:03:55	3102
14038Y	1963-03-22 00:00:00	\N	M.	Chaize	CHAIZE	CHAIZE_Patrick	Patrick	2014-09-17 11:38:49	2014-09-28 21:32:52	3103
14059S	1954-12-27 00:00:00	\N	Mme	Lopez	LOPEZ	LOPEZ_Vivette	Vivette	2014-09-17 17:05:45	2014-09-28 21:26:50	3125
14261S	2014-11-25 00:00:00	\N	M.	Arnell	ARNELL	ARNELL_Guillaume	Guillaume	2014-11-25 17:26:04	2014-11-25 17:27:37	3421
11043H	1958-11-25 00:00:00	\N	M.	Savin	SAVIN	SAVIN_MICHEL_C4802	Michel	\N	\N	1680
11014C	1947-04-03 00:00:00	\N	Mme	Michel	MICHEL	MICHELDANIELLE_C4522	Danielle	\N	\N	1704
11106F	1950-01-02 00:00:00	\N	M.	Lorgeoux	LORGEOUX	LORGEOUX_JEANNY_11106F	Jeanny	\N	\N	1713
11093T	1942-12-29 00:00:00	\N	M.	Roche	ROCHE	ROCHE_GERARD_11093T	Gérard	\N	\N	1723
11103C	1946-12-18 00:00:00	\N	M.	Cardoux	CARDOUX	CARDOUX_JEAN_NOEL_11103C	Jean-Noël	\N	\N	1732
11012A	1947-10-04 00:00:00	\N	M.	Requier	REQUIER	REQUIER_JEAN_CLAUDE_C4565	Jean-Claude	\N	\N	1739
11095V	1952-02-19 00:00:00	\N	M.	Camani	CAMANI	CAMANI_PIERRE_11095V	Pierre	\N	\N	1747
11094U	1949-12-14 00:00:00	\N	M.	Tandonnet	TANDONNET	TANDONNET_HENRI_C4575	Henri	\N	2013-10-28 17:47:47	1749
11081P	1951-02-23 00:00:00	\N	M.	Bertrand	BERTRAND	BERTRAND_ALAIN_C4582	Alain	\N	\N	1757
14191V	1956-04-05 00:00:00	\N	M.	Panunzi	PANUNZI	PANUNZI_Jean_Jacques	Jean-Jacques	2014-09-28 12:09:44	\N	3261
14357A	1899-12-31 00:00:00	\N	M.	Cuypers	CUYPERS	Cuypers_Pierre	Pierre	2016-12-01 10:39:20	\N	3841
11097X	1953-01-03 00:00:00	\N	M.	Savary	SAVARY	SAVARY_RENE_PAUL_11097X	René-Paul	\N	\N	1775
11082Q	1938-10-19 00:00:00	\N	M.	Namy	NAMY	NAMY_CHRISTIAN_C4633	Christian	\N	\N	1797
11098Y	1949-07-12 00:00:00	\N	M.	Le Scouarnec	LE SCOUARNEC	LESCOUARNEC_MICHEL_C4640	Michel	\N	2014-01-21 10:46:03	1802
11099A	1952-10-18 00:00:00	\N	M.	Labbé	LABBÉ	LABBE_JOEL_C4641	Joël	\N	2014-02-14 17:59:40	1803
11015D	1958-12-02 00:00:00	\N	M.	Gorce	GORCE	GORCE_GAETAN_C4649	Gaëtan	\N	\N	1808
11080N	1951-03-01 00:00:00	\N	M.	Charon	CHARON	CHARON_PIERRE_11080N	Pierre	\N	\N	1815
01012H	1935-01-26 00:00:00	\N	M.	Dauge	DAUGE	DAUGE	Yves	\N	\N	763
14263U	1956-12-28 00:00:00	\N	M.	Abate	ABATE	ABATE_patrick	Patrick	2014-12-18 16:18:16	2014-12-22 15:55:43	3441
04076N	1939-10-29 00:00:00	\N	Mme	Le Texier	LE TEXIER	LETEXIER RAYMONDE	Raymonde	\N	\N	814
11084S	1966-01-09 00:00:00	\N	M.	Kaltenbach	KALTENBACH	KALTENBACH_PHILIPPE_11084S	Philippe	\N	\N	1866
11083R	1960-06-24 00:00:00	\N	M.	Gattolin	GATTOLIN	GATTOLIN_ANDRE_11083R	André	\N	\N	1867
11085T	1954-08-20 00:00:00	\N	M.	Marseille	MARSEILLE	MARSEILLE_HERVE_11085T	Hervé	\N	\N	1874
000202	1908-11-06 00:00:00	1994-03-02 00:00:00	M.	Prevoteau	PREVOTEAU	PREVOTEAU MAURICE	Maurice	\N	\N	842
07001F	1950-09-20 00:00:00	\N	M.	Danglot	DANGLOT	DANGLOT JEAN-CLAUDE	Jean-Claude	\N	\N	868
14365A	1899-12-31 00:00:00	\N	M.	Pélieu	PÉLIEU	Pelieu_Michel	Michel	2017-05-16 16:19:32	\N	3921
14063N	1948-06-19 00:00:00	\N	M.	Manable	MANABLE	MANABLE_Christian	Christian	2014-09-17 17:28:03	2014-09-28 18:39:48	3127
14069U	1969-05-05 00:00:00	2024-01-15 00:00:00	M.	Bonhomme	BONHOMME	BONHOMME_Francois	François	2014-09-17 00:00:00	2024-01-15 00:00:00	3130
14071N	1969-09-20 00:00:00	\N	M.	Mouiller	MOUILLER	MOUILLER_Philippe	Philippe	2014-09-17 17:35:20	2014-09-28 21:24:07	3131
11074Q	1957-10-15 00:00:00	\N	M.	Éblé	ÉBLÉ	EBLE_VINCENT_11074Q	Vincent	\N	2016-10-31 11:47:52	1943
08017T	1949-08-10 00:00:00	\N	Mme	Lepage	LEPAGE	LEPAGE CLAUDINE	Claudine	\N	2013-10-08 16:43:25	970
01035Q	1939-12-19 00:00:00	2015-04-07 00:00:00	M.	Coquelle	COQUELLE	COQUELLE	Yves	\N	2015-04-09 10:27:02	1025
11090Q	1962-06-07 00:00:00	\N	Mme	Primas	PRIMAS	PRIMAS_SOPHIE_11090Q	Sophie	\N	\N	1949
01016M	1941-07-28 00:00:00	\N	M.	Raoul	RAOUL	RAOUL	Daniel	\N	\N	1312
01018P	1946-08-22 00:00:00	\N	M.	Lardeux	LARDEUX	LARDEUX	André	\N	\N	1313
01020H	1931-08-20 00:00:00	\N	M.	Mermaz	MERMAZ	MERMAZ	Louis	\N	\N	1314
01021J	1938-10-02 00:00:00	\N	M.	Kergueris	KERGUERIS	KERGUERIS	Joseph	\N	\N	1315
01022K	1948-01-06 00:00:00	\N	Mme	Herviaux	HERVIAUX	HERVIAUX	Odette	\N	\N	1316
01024M	1954-12-21 00:00:00	\N	M.	Détraigne	DÉTRAIGNE	DETRAIGNE	Yves	\N	2013-10-10 13:54:44	1318
01025N	1949-03-05 00:00:00	\N	Mme	Férat	FÉRAT	FERAT FRANCOISE	Françoise	\N	\N	1319
01027Q	1943-05-25 00:00:00	\N	M.	Doligé	DOLIGÉ	DOLIGE	Éric	\N	\N	1320
01029S	1938-04-13 00:00:00	\N	Mme	Rozier	ROZIER	ROZIER	Janine	\N	\N	1321
01030K	1940-02-05 00:00:00	\N	M.	Juilhard	JUILHARD	JUILHARD	Jean-Marc	\N	\N	1322
000671	1899-02-01 00:00:00	1980-03-03 00:00:00	M.	Minot	MINOT	MINOT PAUL	Paul	\N	\N	1323
000677	1897-01-02 00:00:00	1991-11-07 00:00:00	M.	Monnerville	MONNERVILLE	MONNERVILLE GASTON	Gaston	\N	\N	1324
000705	1898-10-10 00:00:00	1993-03-02 00:00:00	M.	de Montalembert	de MONTALEMBERT	MONTALEMBERT GEOFFROY DE	Geoffroy	\N	\N	1325
000691	1897-06-07 00:00:00	1983-09-27 00:00:00	M.	Moreve	MOREVE	MOREVE ROGER	Roger	\N	\N	1326
000736	1876-04-19 00:00:00	1968-10-29 00:00:00	M.	Moutet	MOUTET	MOUTET MARIUS	Marius	\N	\N	1327
000712	1893-04-12 00:00:00	1981-12-23 00:00:00	M.	Neddaf	NEDDAF	NEDDAF LABIDI	Labidi	\N	\N	1328
000688	1895-09-05 00:00:00	1984-06-03 00:00:00	M.	Parisot	PARISOT	PARISOT HENRI	Henri	\N	\N	1329
000725	1899-03-15 00:00:00	1965-12-17 00:00:00	M.	Paumelle	PAUMELLE	PAUMELLE HENRI	Henri	\N	\N	1330
000748	1897-07-22 00:00:00	1985-08-20 00:00:00	M.	Pauzet	PAUZET	PAUZET MARC	Marc	\N	\N	1331
000734	1897-03-18 00:00:00	1972-10-19 00:00:00	M.	Pellenc	PELLENC	PELLENC MARCEL	Marcel	\N	\N	1332
000714	1895-07-12 00:00:00	1980-05-13 00:00:00	M.	Pelleray	PELLERAY	PELLERAY PAUL	Paul	\N	\N	1333
000694	1895-12-07 00:00:00	1968-09-19 00:00:00	M.	Peschaud	PESCHAUD	PESCHAUD HECTOR	Hector	\N	2016-12-06 18:23:00	1334
000739	1888-02-20 00:00:00	1971-05-28 00:00:00	M.	Petit	PETIT	PETIT ERNEST	Ernest	\N	\N	1335
000747	1899-06-22 00:00:00	1979-07-05 00:00:00	M.	Picard	PICARD	PICARD ANDRÉ	André	\N	\N	1336
000730	1889-07-16 00:00:00	1961-08-22 00:00:00	M.	Pinchard	PINCHARD	PINCHARD RAYMOND	Raymond	\N	\N	1337
000698	1892-07-08 00:00:00	1979-04-08 00:00:00	M.	Plait	PLAIT	PLAIT ANDRÉ	André	\N	\N	1338
000672	1890-07-01 00:00:00	1985-02-24 00:00:00	M.	Portmann	PORTMANN	PORTMANN GEORGES	Georges	\N	\N	1339
000772	1898-10-30 00:00:00	1972-12-26 00:00:00	M.	Prelot	PRELOT	PRELOT MARCEL	Marcel	\N	\N	1340
000741	1892-08-20 00:00:00	1983-05-17 00:00:00	M.	Pretre	PRETRE	PRETRE HENRI	Henri	\N	\N	1341
000752	1896-06-24 00:00:00	1982-12-14 00:00:00	M.	Prost	PROST	PROST PIERRE	Pierre	\N	\N	1342
000743	1893-11-20 00:00:00	1979-11-24 00:00:00	M.	Rabouin	RABOUIN	RABOUIN ETIENNE	Etienne	\N	\N	1343
000750	1898-05-23 00:00:00	1971-11-30 00:00:00	M.	Restat	RESTAT	RESTAT ETIENNE	Etienne	\N	\N	1344
000704	1888-07-10 00:00:00	1975-03-14 00:00:00	M.	Rotinat	ROTINAT	ROTINAT VINCENT	Vincent	\N	\N	1345
000754	1898-06-25 00:00:00	1984-07-14 00:00:00	M.	Roy	ROY	ROY PIERRE	Pierre	\N	2014-05-20 11:05:04	1346
000768	1898-04-29 00:00:00	1966-04-24 00:00:00	M.	Roy	ROY	ROY LOUIS	Louis	\N	\N	1347
000749	1898-07-22 00:00:00	1973-12-13 00:00:00	M.	Sambron	SAMBRON	SAMBRON MAURICE	Maurice	\N	\N	1348
000673	1898-10-01 00:00:00	1983-10-11 00:00:00	M.	Sauvageot	SAUVAGEOT	SAUVAGEOT EDMOND	Edmond	\N	\N	1349
000745	1897-01-22 00:00:00	1978-07-11 00:00:00	M.	Schiaffino	SCHIAFFINO	SCHIAFFINO LAURENT	Laurent	\N	\N	1350
000716	1889-01-13 00:00:00	1985-05-03 00:00:00	M.	Sinsout	SINSOUT	SINSOUT CHARLES	Charles	\N	\N	1351
000692	1893-08-07 00:00:00	1968-03-27 00:00:00	M.	Symphor	SYMPHOR	SYMPHOR PAUL	Paul	\N	\N	1352
000717	1899-01-13 00:00:00	1976-09-09 00:00:00	M.	Tellier	TELLIER	TELLIER GABRIEL	Gabriel	\N	\N	1353
000674	1890-11-01 00:00:00	1976-03-31 00:00:00	M.	Thioleron	THIOLERON	THIOLERON LOUIS	Louis	\N	\N	1354
000667	1920-02-21 00:00:00	1992-04-06 00:00:00	M.	Traband	TRABAND	TRABAND ANDRÉ	André	\N	\N	1355
000684	1897-04-05 00:00:00	1980-08-10 00:00:00	M.	Valeau	VALEAU	VALEAU AMÉDÉE	Amédée	\N	\N	1356
000770	1899-09-29 00:00:00	1982-03-09 00:00:00	M.	Verneuil	VERNEUIL	VERNEUIL JACQUES	Jacques	\N	\N	1357
000676	1891-01-02 00:00:00	1978-07-30 00:00:00	M.	Viallanes	VIALLANES	VIALLANES ETIENNE	Etienne	\N	\N	1358
000668	1909-07-16 00:00:00	1989-07-25 00:00:00	M.	de Villeneuve Bargemont	de VILLENEUVE BARGEMONT	VILLENEUVEBARGEMONT AUGUSTIN (DE)	Augustin	\N	\N	1359
000669	1897-04-29 00:00:00	1972-03-31 00:00:00	M.	de Villoutreys de Brignac	de VILLOUTREYS de BRIGNAC	VILLOUTREYS DE BRIGNAC PIERRE	Pierre	\N	\N	1360
000740	1897-05-20 00:00:00	1959-04-29 00:00:00	M.	Walker	WALKER	WALKER MAURICE	Maurice	\N	\N	1361
000729	1897-02-16 00:00:00	1993-04-18 00:00:00	M.	Zussy	ZUSSY	ZUSSY MODESTE	Modeste	\N	\N	1362
99001N	1925-01-07 00:00:00	\N	M.	Donnay	DONNAY	DONNAY	Jacques	\N	\N	1363
99002P	1947-06-20 00:00:00	\N	M.	Collomb	COLLOMB	COLLOMB GERARD	Gérard	\N	\N	1364
99003Q	1934-07-06 00:00:00	\N	M.	Dubrule	DUBRULE	DUBRULE	Paul	\N	\N	1365
000731	1898-01-27 00:00:00	1981-10-06 00:00:00	M.	Beaujannot	BEAUJANNOT	BEAUJANNOT JOSEPH	Joseph	\N	\N	1366
000759	1891-12-25 00:00:00	1959-08-28 00:00:00	M.	Benhabyles	BENHABYLES	BENHABYLES CHÉRIF	Chérif	\N	\N	1367
000701	1898-09-09 00:00:00	1987-03-08 00:00:00	M.	Bertaud	BERTAUD	BERTAUD JEAN	Jean	\N	\N	1368
000711	1895-01-12 00:00:00	1979-02-25 00:00:00	M.	Berthoin	BERTHOIN	BERTHOIN JEAN	Jean	\N	\N	1369
000682	1888-12-02 00:00:00	1970-11-23 00:00:00	M.	Besson	BESSON	BESSON ROGER	Roger	\N	\N	1370
000761	1891-02-27 00:00:00	1961-10-03 00:00:00	M.	Boisrond	BOISROND	BOISROND JACQUES	Jacques	\N	\N	1371
000696	1893-05-08 00:00:00	1979-07-05 00:00:00	M.	Bonnefous	BONNEFOUS	BONNEFOUS RAYMOND	Raymond	\N	\N	1372
000718	1888-11-13 00:00:00	1965-03-02 00:00:00	M.	Boucher	BOUCHER	BOUCHER ALBERT	Albert	\N	\N	1373
000690	1899-02-07 00:00:00	1978-04-20 00:00:00	M.	Bourguet	BOURGUET	BOURGUET FRÉDÉRIC	Frédéric	\N	\N	1374
000756	1895-08-25 00:00:00	1990-05-29 00:00:00	M.	Brajeux	BRAJEUX	BRAJEUX JEAN	Jean	\N	\N	1375
000760	1893-09-26 00:00:00	1980-12-11 00:00:00	M.	Brousse	BROUSSE	BROUSSE MARTIAL	Martial	\N	\N	1376
000735	1887-09-18 00:00:00	1979-09-03 00:00:00	M.	Calmels	CALMELS	CALMELS GABRIEL	Gabriel	\N	\N	1377
000755	1891-07-25 00:00:00	1966-05-26 00:00:00	M.	Capelle	CAPELLE	CAPELLE OMER	Omer	\N	\N	1378
000722	1899-07-14 00:00:00	1977-08-13 00:00:00	Mme	Cardot	CARDOT	CARDOT MARIE-HÉLÈNE	Marie-Hélène	\N	\N	1379
000723	1896-10-14 00:00:00	1971-03-17 00:00:00	M.	Chevalier	CHEVALIER	CHEVALIER ROBERT	Robert	\N	\N	1380
000715	1893-12-12 00:00:00	1971-12-28 00:00:00	M.	Chevallier	CHEVALLIER	CHEVALLIER PAUL	Paul	\N	\N	1381
000726	1892-04-15 00:00:00	1966-03-09 00:00:00	M.	Clerc	CLERC	CLERC JEAN	Jean	\N	\N	1382
000763	1892-06-27 00:00:00	1980-02-05 00:00:00	M.	Cornu	CORNU	CORNU ANDRÉ	André	\N	\N	1383
000702	1897-02-10 00:00:00	1980-01-24 00:00:00	M.	Coude Du Foresto	COUDE du FORESTO	COUDE DU FORESTO YVON	Yvon	\N	\N	1384
000769	1895-06-29 00:00:00	1976-07-11 00:00:00	Mme	Cremieux	CREMIEUX	CREMIEUX SUZANNE	Suzanne	\N	\N	1385
000683	1896-08-03 00:00:00	1986-01-29 00:00:00	M.	Darou	DAROU	DAROU MARCEL	Marcel	\N	\N	1386
000709	1895-07-11 00:00:00	1965-11-17 00:00:00	M.	Dassaud	DASSAUD	DASSAUD FRANCIS	Francis	\N	\N	1387
000744	1889-02-21 00:00:00	1969-01-11 00:00:00	M.	Dehe	DEHE	DEHE ALFRED	Alfred	\N	\N	1388
000685	1888-04-05 00:00:00	1966-03-09 00:00:00	M.	Delpuech	DELPUECH	DELPUECH VINCENT	Vincent	\N	\N	1389
000728	1892-10-15 00:00:00	1982-01-15 00:00:00	M.	Desache	DESACHE	DESACHE MARC	Marc	\N	\N	1390
000713	1893-07-12 00:00:00	1982-04-11 00:00:00	M.	Dubois	DUBOIS	DUBOIS RENÉ	René	\N	\N	1391
000681	1896-10-02 00:00:00	1975-04-25 00:00:00	M.	Duclos	DUCLOS	DUCLOS JACQUES	Jacques	\N	\N	1392
000687	1898-08-15 00:00:00	1980-12-22 00:00:00	M.	Dufeu	DUFEU	DUFEU JEAN-BAPTISTE	Jean-Baptiste	\N	\N	1393
000764	1880-09-27 00:00:00	1966-09-26 00:00:00	M.	Emaille	EMAILLE	EMAILLE JULES	Jules	\N	\N	1394
000699	1890-09-08 00:00:00	1976-12-26 00:00:00	M.	Enjalbert	ENJALBERT	ENJALBERT RENÉ	René	\N	\N	1395
000720	1899-02-14 00:00:00	1986-12-21 00:00:00	M.	Esteve	ESTEVE	ESTEVE YVES	Yves	\N	\N	1396
000719	1896-12-13 00:00:00	1978-01-12 00:00:00	M.	de Felice	de FELICE	FELICE PIERRE DE	Pierre	\N	\N	1397
000678	1899-02-02 00:00:00	1968-09-23 00:00:00	M.	Fil	FIL	FIL JULES	Jules	\N	\N	1398
000697	1887-07-08 00:00:00	1968-11-20 00:00:00	M.	Fournier	FOURNIER	FOURNIER JEAN-LOUIS	Jean-Louis	\N	\N	1399
000766	1894-05-28 00:00:00	1982-05-20 00:00:00	M.	Fruh	FRUH	FRUH CHARLES	Charles	\N	\N	1400
000675	1892-12-01 00:00:00	1974-04-19 00:00:00	M.	Gadoin	GADOIN	GADOIN JACQUES	Jacques	\N	\N	1401
000753	1894-12-24 00:00:00	1981-01-12 00:00:00	M.	Ganeval	GANEVAL	GANEVAL JEAN	Jean	\N	\N	1402
000700	1889-11-08 00:00:00	1971-03-14 00:00:00	M.	de Geoffre de Chabrignac	de GEOFFRE de CHABRIGNAC	GEOFFRE DE CHABRIGNAC JEAN	Jean	\N	\N	1403
000765	1898-07-28 00:00:00	1997-03-27 00:00:00	M.	Grangier	GRANGIER	GRANGIER EDOUARD	Edouard	\N	2016-10-13 15:49:19	1404
000721	1899-06-14 00:00:00	1986-07-10 00:00:00	M.	Guislain	GUISLAIN	GUISLAIN MARCEL	Marcel	\N	\N	1405
000732	1899-06-14 00:00:00	1987-08-25 00:00:00	M.	Houdet	HOUDET	HOUDET ROGER	Roger	\N	\N	1406
000680	1891-05-02 00:00:00	1970-10-24 00:00:00	M.	Jamain	JAMAIN	JAMAIN EUGÈNE	Eugène	\N	\N	1407
000727	1897-06-16 00:00:00	1976-05-05 00:00:00	M.	Kistler	KISTLER	KISTLER MICHEL	Michel	\N	\N	1408
000686	1898-07-05 00:00:00	1989-03-08 00:00:00	M.	Lacoste	LACOSTE	LACOSTE ROBERT	Robert	\N	\N	1409
000670	1899-01-01 00:00:00	1971-03-17 00:00:00	M.	Lakhdari	LAKHDARI	LAKHDARI MOHAMED	Mohamed	\N	\N	1410
000758	1896-11-25 00:00:00	1985-12-19 00:00:00	M.	Lalloy	LALLOY	LALLOY MAURICE	Maurice	\N	\N	1411
000706	1897-11-10 00:00:00	1982-05-14 00:00:00	M.	Lambert	LAMBERT	LAMBERT MARCEL	Marcel	\N	2016-12-01 16:45:50	1412
000679	1889-04-02 00:00:00	1974-03-06 00:00:00	M.	Le Basser	LE BASSER	LEBASSER FRANCIS	Francis	\N	\N	1413
000693	1898-10-07 00:00:00	1971-10-28 00:00:00	M.	Legros	LEGROS	LEGROS MARCEL	Marcel	\N	\N	1414
000710	1895-07-11 00:00:00	1974-12-23 00:00:00	M.	Leveque	LEVEQUE	LEVEQUE PAUL	Paul	\N	\N	1416
000708	1891-07-11 00:00:00	1979-10-13 00:00:00	M.	Leygue	LEYGUE	LEYGUE LOUIS	Louis	\N	\N	1417
000762	1899-05-27 00:00:00	1978-06-16 00:00:00	M.	Loste	LOSTE	LOSTE HENRI	Henri	\N	\N	1418
000742	1899-09-20 00:00:00	1961-02-21 00:00:00	M.	Male	MALE	MALE FERNAND	Fernand	\N	\N	1419
000746	1893-02-22 00:00:00	1970-04-07 00:00:00	M.	Maroselli	MAROSELLI	MAROSELLI ANDRÉ	André	\N	\N	1420
000738	1888-01-20 00:00:00	1976-08-27 00:00:00	M.	Marrane	MARRANE	MARRANE GEORGES	Georges	\N	\N	1421
000771	1890-07-30 00:00:00	1972-11-27 00:00:00	M.	Mathey	MATHEY	MATHEY PIERRE	Pierre	\N	\N	1422
000767	1899-12-28 00:00:00	1963-01-22 00:00:00	M.	de Maupeou	de MAUPEOU	MAUPEOU 	Jacques	\N	\N	1423
000751	1897-06-23 00:00:00	1983-12-04 00:00:00	M.	Messaud	MESSAUD	MESSAUD LÉON	Léon	\N	\N	1424
98038X	1954-02-24 00:00:00	\N	M.	Le Cam	LE CAM	LECAM	Gérard	\N	\N	1425
98039Y	1946-12-06 00:00:00	\N	M.	de Richemont	de RICHEMONT	RICHEMONT (DE)	Henri	\N	\N	1426
98040R	1931-10-18 00:00:00	\N	M.	Peyrat	PEYRAT	PEYRAT	Jacques	\N	\N	1427
98042T	1955-01-31 00:00:00	\N	M.	Dupont	DUPONT	DUPONT JEAN-LEONCE	Jean-Léonce	\N	2013-10-14 09:10:24	1428
98043U	1942-09-03 00:00:00	2003-08-28 00:00:00	M.	Lassourd	LASSOURD	LASSOURD	Patrick	\N	\N	1429
98045W	1943-07-18 00:00:00	\N	M.	Esneu	ESNEU	ESNEU	Michel	\N	\N	1430
98046X	1950-03-19 00:00:00	\N	M.	Marc	MARC	MARC_FRANCOIS	François	\N	2015-10-20 15:45:07	1431
98048A	1943-06-01 00:00:00	\N	M.	de Broissia	de BROISSIA	BROISSIA (DE)	Louis	\N	\N	1432
98050T	1946-11-10 00:00:00	\N	M.	Poniatowski	PONIATOWSKI	PONIATOWSKI LADISLAS	Ladislas	\N	2014-09-28 20:30:39	1433
98051U	1937-01-08 00:00:00	\N	M.	Le Pensec	LE PENSEC	LEPENSEC	Louis	\N	\N	1434
98052V	1931-06-24 00:00:00	\N	M.	Flosse	FLOSSE	FLOSSE	Gaston	\N	\N	1435
98053W	1954-01-18 00:00:00	\N	M.	Foucaud	FOUCAUD	FOUCAUD	Thierry	\N	2014-09-28 20:35:12	1436
98054X	1930-04-05 00:00:00	2011-10-27 00:00:00	M.	Lagorsse	LAGORSSE	LAGORSSE	Roger	\N	\N	1437
000099	1904-05-12 00:00:00	1988-11-13 00:00:00	M.	Boscary-Monsservin	BOSCARY-MONSSERVIN	BOSCARY-MONSSERVIN ROLAND	Roland	\N	\N	1438
000054	1901-09-29 00:00:00	1960-10-23 00:00:00	M.	Beguere	BEGUERE	BEGUERE ANTOINE	Antoine	\N	\N	1441
000376	1916-08-30 00:00:00	1983-05-10 00:00:00	M.	Andrieux	ANDRIEUX	ANDRIEUX ANTOINE	Antoine	\N	\N	1443
000391	1917-09-01 00:00:00	1992-07-05 00:00:00	M.	Bouvard	BOUVARD	BOUVARD ROBERT	Robert	\N	\N	1444
000018	1900-08-21 00:00:00	1976-03-02 00:00:00	M.	Brun	BRUN	BRUN PIERRE	Pierre	\N	\N	1445
83022M	1929-07-12 00:00:00	1996-01-24 00:00:00	M.	Chambriard	CHAMBRIARD	CHAMBRIARD JEAN-PAUL	Jean-Paul	\N	\N	1446
000572	1926-09-17 00:00:00	1987-09-30 00:00:00	M.	Charretier	CHARRETIER	CHARRETIER MAURICE	Maurice	\N	\N	1447
000058	1901-12-15 00:00:00	1978-03-12 00:00:00	M.	Cogniot	COGNIOT	COGNIOT GEORGES	Georges	\N	\N	1448
000089	1903-11-03 00:00:00	1982-01-10 00:00:00	M.	Cousin	COUSIN	COUSIN AUGUSTE	Auguste	\N	\N	1449
000360	1915-03-06 00:00:00	1979-05-28 00:00:00	M.	Dayan	DAYAN	DAYAN GEORGES	Georges	\N	\N	1450
000621	1931-06-19 00:00:00	1988-02-05 00:00:00	M.	Delmas	DELMAS	DELMAS LUCIEN	Lucien	\N	\N	1451
000106	1904-08-04 00:00:00	1975-12-29 00:00:00	M.	Dussert	DUSSERT	DUSSERT FERNAND	Fernand	\N	\N	1452
000056	1901-10-19 00:00:00	1993-03-10 00:00:00	M.	Esseul	ESSEUL	ESSEUL FERNAND	Fernand	\N	\N	1453
000388	1917-05-25 00:00:00	1991-12-28 00:00:00	M.	Fonteneau	FONTENEAU	FONTENEAU JEAN	Jean	\N	\N	1454
000309	1913-02-28 00:00:00	1988-05-14 00:00:00	M.	Giraud	GIRAUD	GIRAUD PIERRE	Pierre	\N	\N	1455
000110	1904-10-06 00:00:00	1988-06-14 00:00:00	M.	Henriet	HENRIET	HENRIET JACQUES	Jacques	\N	\N	1456
000072	1902-12-05 00:00:00	1976-07-20 00:00:00	M.	de La Vasselais	de LA VASSELAIS	LAVASSELAIS GUY DE	Guy	\N	\N	1457
000133	1905-09-11 00:00:00	1986-12-19 00:00:00	M.	Lavy	LAVY	LAVY ARTHUR	Arthur	\N	\N	1458
000325	1913-08-29 00:00:00	1976-02-16 00:00:00	M.	Legaret	LEGARET	LEGARET JEAN	Jean	\N	\N	1459
58925A	1925-03-14 00:00:00	2010-09-13 00:00:00	M.	Lombard	LOMBARD	LOMBARD GEORGES	Georges	\N	\N	1460
000611	1930-07-01 00:00:00	1987-12-03 00:00:00	M.	Male	MALE	MALE GUY	Guy	\N	\N	1461
000323	1913-08-14 00:00:00	1993-08-14 00:00:00	M.	Meric	MERIC	MERIC ANDRÉ	André	\N	\N	1462
000088	1903-09-29 00:00:00	1991-01-09 00:00:00	M.	Montpied	MONTPIED	MONTPIED GABRIEL	Gabriel	\N	\N	1463
000119	1905-04-24 00:00:00	1978-06-21 00:00:00	M.	Nuninger	NUNINGER	NUNINGER MARCEL	Marcel	\N	\N	1464
59578F	1927-07-25 00:00:00	\N	M.	Pelletier	PELLETIER	PELLETIER CHARLES	Charles	\N	\N	1465
59241G	1923-07-11 00:00:00	2006-12-27 00:00:00	M.	Peyou	PEYOU	PEYOU HUBERT	Hubert	\N	\N	1466
000178	1908-02-24 00:00:00	1988-12-20 00:00:00	M.	Poignant	POIGNANT	POIGNANT FERNAND	Fernand	\N	\N	1468
000007	1900-02-19 00:00:00	1979-06-17 00:00:00	M.	Rastoin	RASTOIN	RASTOIN JACQUES	Jacques	\N	\N	1469
89005M	1922-06-19 00:00:00	1996-07-09 00:00:00	M.	Sourdille	SOURDILLE	SOURDILLE JACQUES	Jacques	\N	\N	1470
59248P	1925-06-02 00:00:00	2005-05-16 00:00:00	M.	Thyraud	THYRAUD	THYRAUD JACQUES	Jacques	\N	\N	1471
000595	1929-04-17 00:00:00	1985-09-01 00:00:00	M.	Toutain	TOUTAIN	TOUTAIN JACQUES	Jacques	\N	\N	1472
58644T	1930-10-04 00:00:00	\N	M.	Hugo	HUGO	HUGO BERNARD MICHEL	Bernard Michel	\N	2017-11-08 16:59:18	1473
000190	1908-07-07 00:00:00	1995-03-29 00:00:00	M.	Vadepied	VADEPIED	VADEPIED RAOUL	Raoul	\N	\N	1474
80024B	1935-07-04 00:00:00	2009-09-09 00:00:00	M.	Lejeune	LEJEUNE	LEJEUNE ANDRE	André	\N	\N	1475
89029V	1939-10-08 00:00:00	\N	M.	Gaudin	GAUDIN	GAUDIN JEANCLAUDE	Jean-Claude	\N	2014-09-28 20:26:10	1476
000703	1879-03-10 00:00:00	1975-11-02 00:00:00	M.	Durand	DURAND	DURAND  	Abel	\N	\N	1477
000724	1894-02-15 00:00:00	1967-10-17 00:00:00	M.	Alric	ALRIC	ALRIC GUSTAVE	Gustave	\N	\N	1478
000689	1891-01-06 00:00:00	1978-07-24 00:00:00	M.	Andre	ANDRE	ANDRE LOUIS	Louis	\N	\N	1479
000757	1892-09-25 00:00:00	1977-05-21 00:00:00	M.	d'Argenlieu	d'ARGENLIEU	ARGENLIEU PHILIPPE D'	Philippe	\N	\N	1480
000733	1890-12-17 00:00:00	1966-12-22 00:00:00	M.	Baratgin	BARATGIN	BARATGIN PAUL	Paul	\N	\N	1481
86010V	1946-11-17 00:00:00	\N	M.	Baylet	BAYLET	BAYLET	Jean-Michel	\N	\N	1482
04016A	1925-02-23 00:00:00	\N	M.	Claudel	CLAUDEL	CLAUDEL 	Gérard	\N	\N	1483
04017B	1933-11-08 00:00:00	\N	M.	Ginoux	GINOUX	GINOUX 	Georges	\N	\N	1484
04018C	1948-04-27 00:00:00	\N	M.	Schmitz	SCHMITZ	SCHMITZ 	Alain	\N	\N	1485
95023C	1934-12-10 00:00:00	\N	M.	Demilly	DEMILLY	DEMILLY	Fernand	\N	\N	1487
95034F	1938-08-03 00:00:00	\N	M.	Gélard	GÉLARD	GELARD	Patrice	\N	\N	1488
89041R	1941-07-12 00:00:00	\N	M.	Seillier	SEILLIER	SEILLIER	Bernard	\N	\N	1489
86050E	1926-03-14 00:00:00	2014-10-29 00:00:00	M.	de Villepin	de VILLEPIN	VILLEPIN XAVIER (DE)	Xavier	\N	2014-10-30 16:54:13	1490
92021M	1926-02-11 00:00:00	\N	M.	Fatous	FATOUS	FATOUS	Léon	\N	\N	1491
83028T	1937-12-31 00:00:00	\N	M.	Descours	DESCOURS	DESCOURS	Charles	\N	\N	1492
88012G	1922-05-12 00:00:00	2012-12-30 00:00:00	M.	Ginésy	GINÉSY	GINESY	Charles	\N	\N	1493
000501	1923-02-09 00:00:00	1994-09-27 00:00:00	M.	Collet	COLLET	COLLET FRANÇOIS	François	\N	\N	1494
57613G	1921-05-31 00:00:00	2015-03-17 00:00:00	M.	Favre	FAVRE	FAVRE PAUL	Paul	\N	2015-03-24 17:08:52	1495
000219	1909-09-18 00:00:00	1992-06-05 00:00:00	M.	Laplace	LAPLACE	LAPLACE ADRIEN	Adrien	\N	\N	1496
000212	1909-05-01 00:00:00	1959-07-02 00:00:00	M.	de Raincourt	de RAINCOURT	RAINCOURT PHILIPPE (DE)	Philippe	\N	\N	1497
000251	1910-09-23 00:00:00	1990-08-13 00:00:00	M.	Tinaud	TINAUD	TINAUD JEAN-LOUIS	Jean-Louis	\N	\N	1498
58808V	1908-04-17 00:00:00	2000-01-11 00:00:00	M.	Tricon	TRICON	TRICON EMILE	Emile	\N	\N	1499
98007Q	1946-02-19 00:00:00	\N	M.	Murat	MURAT	MURAT	Bernard	\N	\N	1500
000044	1901-06-12 00:00:00	1980-01-14 00:00:00	M.	Roubert	ROUBERT	ROUBERT ALEX	Alex	\N	\N	1501
000015	1900-07-01 00:00:00	1970-06-13 00:00:00	M.	Louvel	LOUVEL	LOUVEL JEAN-MARIE	Jean-Marie	\N	\N	1502
01005J	1939-10-21 00:00:00	\N	M.	Blanc	BLANC	BLANC JACQUES	Jacques	\N	\N	1503
95043G	1936-07-06 00:00:00	\N	M.	Larifla	LARIFLA	LARIFLA	Dominique	\N	\N	1504
86047K	1940-10-15 00:00:00	\N	M.	Trégouët	TRÉGOUËT	TREGOUET	René	\N	\N	1505
88009M	1931-08-14 00:00:00	\N	M.	Gruillot	GRUILLOT	GRUILLOT	Georges	\N	\N	1506
14053L	1965-09-21 00:00:00	\N	Mme	Canayer	CANAYER	CANAYER_Agnes	Agnès	2014-09-17 15:25:08	2014-09-28 18:28:13	3122
14061L	1952-04-14 00:00:00	\N	M.	Kennel	KENNEL	KENNEL_Guy_Dominique	Guy-Dominique	2014-09-17 17:22:51	2014-09-28 21:30:57	3126
11053K	1967-05-04 00:00:00	\N	M.	Capo-Canellas	CAPO-CANELLAS	CAPO_CANELLAS_VINCENT_11053K	Vincent	\N	2014-04-07 18:14:40	2393
14065Q	1952-07-31 00:00:00	\N	M.	Bigot	BIGOT	BIGOT_Jacques	Jacques	2014-09-17 17:31:07	2014-09-28 21:30:42	3128
14073Q	1959-03-13 00:00:00	\N	M.	Kern	KERN	KERN_Claude	Claude	2014-09-17 17:40:28	2014-09-28 21:31:11	3132
14233N	1945-08-28 00:00:00	\N	Mme	Jean	JEAN	JEAN_Genevieve	Geneviève	2014-09-28 17:35:38	\N	3317
14235Q	1950-09-04 00:00:00	\N	Mme	Prunaud	PRUNAUD	PRUNAUD_Christine	Christine	2014-09-28 17:38:25	\N	3318
14247U	1987-12-02 00:00:00	\N	M.	Rachline	RACHLINE	RACHLINE_David	David	2014-09-28 18:03:38	\N	3324
14271U	1966-05-20 00:00:00	\N	Mme	Riocreux	RIOCREUX	RIOCREUX_STEPHANIE	Stéphanie	2015-04-07 17:15:52	\N	3521
11032E	1971-06-08 00:00:00	\N	M.	Carvounas	CARVOUNAS	CARVOUNAS_LUC_11032E	Luc	\N	2013-10-09 18:22:40	2461
11031D	1953-01-15 00:00:00	\N	Mme	Cohen	COHEN	COHEN_LAURENCE_11031D	Laurence	\N	\N	2462
11034G	1951-02-20 00:00:00	\N	M.	Favier	FAVIER	FAVIER_CHRISTIAN_11034G	Christian	\N	\N	2463
11033F	1950-03-27 00:00:00	\N	Mme	Benbassa	BENBASSA	BENBASSA_ESTHER_11033F	Esther	\N	\N	2464
14207L	1959-03-09 00:00:00	\N	M.	Cabanel	CABANEL	CABANEL_Henri	Henri	2014-09-28 17:03:41	\N	3304
14209N	1949-11-10 00:00:00	\N	M.	Commeinhes	COMMEINHES	COMMEINHES_Francois	François	2014-09-28 17:03:41	\N	3305
14211G	1950-11-18 00:00:00	\N	M.	Grand	GRAND	GRAND_Jean_Pierre	Jean-Pierre	2014-09-28 17:03:41	\N	3306
14257W	1961-09-14 00:00:00	\N	M.	Montaugé	MONTAUGÉ	MONTAUGE_Franck	Franck	2014-09-28 19:07:43	\N	3345
14281W	1961-09-17 00:00:00	\N	Mme	Féret	FÉRET	FERET_CORINNE	Corinne	2015-06-12 15:35:57	2015-06-15 10:49:28	3601
13001T	1947-04-04 00:00:00	\N	Mme	Masson-Maret	MASSON-MARET	MASSONMARET HÉLÈNE	Hélène	\N	2013-05-28 11:09:17	2474
11029K	1964-01-05 00:00:00	\N	Mme	Bouchoux	BOUCHOUX	BOUCHOUX_CORINNE_11029K	Corinne	\N	\N	2475
11061K	1949-04-22 00:00:00	\N	Mme	Génisson	GÉNISSON	GENISSON_CATHERINE_11061K	Catherine	\N	\N	2513
11059R	1952-06-03 00:00:00	\N	M.	Leroy	LEROY	LEROY JEAN_CLAUDE_11059R	Jean-Claude	\N	\N	2514
11062L	1948-05-07 00:00:00	\N	Mme	Duriez	DURIEZ	DURIEZ_ODETTE_11062L	Odette	\N	\N	2515
11060J	1963-05-29 00:00:00	\N	Mme	Bouchart	BOUCHART	BOUCHART_NATACHA_11060J	Natacha	\N	2013-10-14 17:07:15	2530
11048N	1961-04-17 00:00:00	\N	M.	Husson	HUSSON	HUSSON_JEAN_FRANCOIS_C4969	Jean-François	\N	2013-09-11 15:03:23	2547
14013P	1959-01-15 00:00:00	\N	M.	Bosino	BOSINO	BOSINO	Jean-Pierre	2014-05-09 11:29:04	\N	2961
14014Q	1952-03-12 00:00:00	\N	Mme	Giraud	GIRAUD	GIRAUD_ELIANE	Éliane	2014-05-09 11:37:36	\N	2962
12038D	1963-04-05 00:00:00	\N	M.	Vairetto	VAIRETTO	VAIRETTO ANDRÉ	André	\N	\N	2553
12039E	1969-03-25 00:00:00	\N	M.	Mazars	MAZARS	MAZARS STÉPHANE	Stéphane	\N	2014-05-12 17:42:52	2554
12040W	1962-09-24 00:00:00	\N	Mme	Ango Ela	ANGO ELA	ANGO ELA KALLIOPI	Kalliopi	\N	2014-05-12 18:15:38	2559
11049P	1961-02-25 00:00:00	\N	M.	Grosdidier	GROSDIDIER	GROSDIDIER_FRANCOIS_11049P	François	\N	2014-01-16 11:57:41	2590
11035H	1946-04-27 00:00:00	\N	M.	Delebarre	DELEBARRE	DELEBARRE_MICHEL_11035H	Michel	\N	\N	2597
11036J	1969-09-16 00:00:00	\N	Mme	Bataille	BATAILLE	BATAILLE_DELPHINE_11036J	Delphine	\N	\N	2598
11039M	1960-01-02 00:00:00	\N	M.	Bailly	BAILLY	BAILLYDOMINIQUE_11039M	Dominique	\N	\N	2599
11037K	1951-04-01 00:00:00	\N	M.	Vandierendonck	VANDIERENDONCK	VANDIERENDONCK_RENE_11037K	René	\N	\N	2600
15197G	1962-06-18 00:00:00	\N	M.	Dhersin	DHERSIN	Dhersin_Franck	Franck	2017-06-15 09:45:02	\N	4358
11040E	1957-11-08 00:00:00	\N	M.	Bocquet	BOCQUET	BOCQUET_ERIC_11040E	Éric	\N	\N	2620
02001J	1940-10-12 00:00:00	\N	M.	Frimat	FRIMAT	FRIMAT	Bernard	\N	\N	1053
11091R	1940-08-23 00:00:00	\N	Mme	Duchêne	DUCHÊNE	DUCHENE_MARIE_ANNICK_11091R	Marie-Annick	\N	\N	1950
59224F	1935-10-05 00:00:00	2013-05-26 00:00:00	M.	Costes	COSTES	COSTES MARCEL	Marcel	\N	2016-10-07 14:18:31	1109
11096W	1954-04-02 00:00:00	\N	M.	Esnol	ESNOL	ESNOL_PHILIPPE_11096W	Philippe	\N	2013-12-04 10:44:13	1993
14167V	1943-03-28 00:00:00	\N	M.	Boulard	BOULARD	BOULARD_Jean_Claude	Jean-Claude	2014-09-22 10:54:02	2014-09-28 21:24:36	3221
14169X	1949-09-18 00:00:00	\N	M.	de Nicolaÿ	de NICOLAY	NICOLAY_DE_Louis_Jean	Louis-Jean	2014-09-22 11:01:18	2014-10-02 11:10:23	3222
14173T	1956-08-07 00:00:00	\N	M.	Vogel	VOGEL	VOGEL_Jean_Pierre	Jean Pierre	2014-09-22 11:13:38	2014-09-28 21:24:53	3224
14267Y	1963-08-16 00:00:00	\N	M.	Cigolotti	CIGOLOTTI	CIGOLOTTI OLIVIER	Olivier	2015-01-26 16:17:48	2015-01-26 17:53:10	3481
15447F	1942-07-08 00:00:00	\N	M.	Ginesta	GINESTA	GINESTA_Jordi	Jordi	2017-06-15 09:45:32	2018-03-28 11:14:31	4483
000118	1905-03-12 00:00:00	1977-03-17 00:00:00	M.	Thiebault	THIEBAULT	THIEBAULT ROGER	Roger	\N	\N	153
11070L	1959-08-23 00:00:00	\N	M.	Delahaye	DELAHAYE	DELAHAYE_VINCENT_11070L	Vincent	\N	2013-10-29 10:32:11	2050
11068S	1945-04-21 00:00:00	\N	M.	Berson	BERSON	BERSON_MICHEL_11068S	Michel	\N	\N	2057
11069T	1968-03-12 00:00:00	\N	M.	Placé	PLACÉ	PLACE_JEAN_VINCENT_11069T	Jean-Vincent	\N	2016-12-14 15:25:35	2064
94004U	1927-09-16 00:00:00	2008-12-29 00:00:00	Mme	Bardou	BARDOU	BARDOU	Janine	\N	\N	328
11063M	1953-06-14 00:00:00	\N	M.	Watrin	WATRIN	WATRIN_DOMINIQUE_11063M	Dominique	\N	\N	2086
14026U	1960-02-18 00:00:00	\N	Mme	Gruny	GRUNY	GRUNY_Pascale	Pascale	2014-09-16 11:24:36	2014-09-28 21:27:16	3062
14039A	1950-02-21 00:00:00	\N	M.	Karam	KARAM	KARAM_Antoine	Antoine	2014-09-17 11:52:59	2014-09-29 09:28:56	3104
14041T	1944-06-15 00:00:00	\N	Mme	Deromedi	DEROMEDI	DEROMEDI_Jacky	Jacky	2014-09-17 12:07:53	2014-09-28 19:13:12	3106
14042U	1961-04-01 00:00:00	\N	Mme	Doineau	DOINEAU	DOINEAU_Elisabeth	Élisabeth	2014-09-17 12:08:16	2014-11-27 12:22:09	3107
14043V	1981-08-05 00:00:00	\N	M.	Dubois	DUBOIS	DUBOIS_Vincent	Vincent	2014-09-17 12:14:48	2014-09-29 09:35:19	3109
14044W	1965-01-07 00:00:00	\N	Mme	Iriti	IRITI	IRITI_Teura	Teura	2014-09-17 12:17:04	2014-09-29 09:36:26	3110
14157T	1948-02-22 00:00:00	\N	M.	Vaspart	VASPART	VASPART_Michel	Michel	2014-09-18 17:34:14	2014-09-28 21:25:29	3194
000518	1923-12-13 00:00:00	1973-11-16 00:00:00	M.	Maille	MAILLE	MAILLE PIERRE	Pierre	\N	\N	387
92033R	1957-05-07 00:00:00	\N	M.	Loueckhote	LOUECKHOTE	LOUECKHOTE	Simon	\N	\N	543
95046K	1939-07-10 00:00:00	\N	M.	Mahéas	MAHÉAS	MAHEAS	Jacques	\N	\N	572
95047L	1943-09-27 00:00:00	\N	M.	Martin	MARTIN	MARTIN PIERRE	Pierre	\N	\N	578
000510	1923-07-04 00:00:00	1994-09-09 00:00:00	M.	Caupert	CAUPERT	CAUPERT JOSEPH	Joseph	\N	\N	604
11077T	1951-07-12 00:00:00	\N	Mme	Lienemann	LIENEMANN	LIENEMANN_MARIE_NOELLE_11077T	Marie-Noëlle	\N	2013-10-01 15:11:49	2139
12035A	1958-05-07 00:00:00	\N	Mme	Lipietz	LIPIETZ	LIPIETZ HÉLÈNE	Hélène	\N	2014-05-12 18:19:31	2140
95068R	1940-02-17 00:00:00	\N	M.	Lafond	LAFOND	LAFOND	Jean-Pierre	\N	\N	737
11076S	1970-05-14 00:00:00	\N	Mme	Aïchi	AÏCHI	AICHI_LEILA_11076S	Leila	\N	2013-11-26 14:47:16	2141
11088W	1946-09-11 00:00:00	\N	M.	Delattre	DELATTRE	DELATTRE_FRANCIS_11088W	Francis	\N	\N	2173
11089X	1949-07-11 00:00:00	\N	Mme	Gillot	GILLOT	GILLOT DOMINIQUE_C5752	Dominique	\N	\N	2180
11010L	1950-11-16 00:00:00	\N	M.	Frogier	FROGIER	FROGIER PIERRE	Pierre	\N	\N	2181
11011M	1941-09-04 00:00:00	\N	M.	Vendegou	VENDEGOU	VENDEGOU HILARION	Hilarion	\N	\N	2182
12016W	1951-08-20 00:00:00	\N	M.	Lurel	LUREL	LUREL VICTORIN	Victorin	\N	\N	2195
14255U	1962-04-22 00:00:00	\N	M.	Cadic	CADIC	CADIC_Olivier	Olivier	2014-09-28 18:46:12	\N	3344
14331P	1966-05-11 00:00:00	\N	M.	Rapin	RAPIN	RAPIN JEAN FRANCOIS	Jean-François	2016-01-12 09:45:37	2016-03-21 11:23:34	3721
11020A	1952-05-06 00:00:00	\N	M.	Fontaine	FONTAINE	FONTAINE_MICHEL_11020A	Michel	\N	\N	2215
11022C	1939-02-25 00:00:00	\N	Mme	Farreyrol	FARREYROL	FARREYROL_JACQUELINE_11022C	Jacqueline	\N	\N	2216
12028B	1952-01-21 00:00:00	\N	Mme	Carlotti	CARLOTTI	CARLOTTI MARIE-ARLETTE	Marie-Arlette	\N	\N	2237
11025F	1950-01-10 00:00:00	\N	M.	Vergoz	VERGOZ	VERGOZ_MICHEL_11025F	Michel	\N	\N	2243
11027H	1960-09-13 00:00:00	\N	Mme	Conway-Mouret	CONWAY-MOURET	CONWAY_MOURET_HELENE	Hélène	\N	\N	2273
11026G	1966-10-31 00:00:00	\N	M.	Leconte	LECONTE	LECONTE_JEAN_YVES_11026G	Jean-Yves	\N	\N	2274
12041X	2012-09-01 00:00:00	\N	M.	Laurent	LAURENT	LAURENT PIERRE	Pierre	\N	\N	2284
14135M	1949-11-05 00:00:00	\N	M.	Raison	RAISON	RAISON_Michel	Michel	2014-09-18 14:44:37	2014-09-28 16:08:19	3183
14175V	1955-03-17 00:00:00	\N	M.	Bouvard	BOUVARD	BOUVARD_Michel	Michel	2014-09-22 14:32:46	2014-09-28 21:32:37	3225
14299H	1953-09-05 00:00:00	\N	M.	de Ganay	DE GANAY	de_Ganay_Claude	Claude	2015-07-01 17:32:34	\N	3647
59312E	1934-08-25 00:00:00	\N	M.	Romani	ROMANI	ROMANI ROGER	Roger	\N	2016-12-14 15:30:05	1213
14363X	1943-04-25 00:00:00	\N	Mme	de Rose	de ROSE	ROSE	Marie-France	2017-01-03 11:10:58	2017-01-11 18:21:04	3901
58613L	1925-09-17 00:00:00	2013-05-21 00:00:00	M.	Bastie	BASTIE	BASTIE PIERRE	Pierre	\N	2013-05-24 10:26:31	1440
14051J	1950-05-02 00:00:00	\N	Mme	Tocqueville	TOCQUEVILLE	TOCQUEVILLE_Nelly	Nelly	2014-09-17 15:24:25	2014-09-28 18:24:40	3121
14055N	1969-08-04 00:00:00	\N	M.	Ravier	RAVIER	RAVIER_Stephane	Stéphane	2014-09-17 15:27:40	2014-09-28 21:33:07	3123
11054L	1953-11-09 00:00:00	\N	M.	Roger	ROGER	ROGER_GILBERT_11054L	Gilbert	\N	\N	2377
11055M	1948-11-02 00:00:00	\N	Mme	Archimbaud	ARCHIMBAUD	ARCHIMBAUD_ALINE_C5635	Aline	\N	\N	2378
11051H	1948-08-12 00:00:00	2015-03-03 00:00:00	M.	Dilain	DILAIN	DILAIN_CLAUDE_11051H	Claude	\N	2015-03-05 12:56:55	2379
13003V	1960-08-02 00:00:00	\N	Mme	Boog	BOOG	BOOG FRANÇOISE	Françoise	1899-12-30 10:37:44	2013-10-22 17:18:27	2841
16431B	1944-09-29 00:00:00	\N	M.	Roustan	ROUSTAN	Roustan_Max	Max	2017-06-15 09:47:33	\N	4975
11044J	1948-11-01 00:00:00	\N	Mme	Cayeux	CAYEUX	CAYEUX_CAROLINE_11044J	Caroline	\N	2013-10-10 13:59:44	2725
14028W	1952-05-26 00:00:00	\N	Mme	Perol-Dumont	PEROL-DUMONT	PEROL_DUMONT_Marie_Francoise	Marie-Françoise	2014-09-16 11:27:36	2014-09-28 21:30:08	3064
14033T	1953-07-31 00:00:00	\N	M.	Gremillet	GREMILLET	GREMILLET_Daniel	Daniel	2014-09-16 16:54:06	2014-09-28 21:32:22	3082
14034U	1949-05-17 00:00:00	\N	M.	Gabouty	GABOUTY	GABOUTY_Jean_Marc	Jean-Marc	2014-09-16 17:00:14	2014-09-28 21:30:25	3083
11046L	1950-04-25 00:00:00	\N	M.	Rome	ROME	ROME_YVES_11046L	Yves	\N	\N	2729
11045K	1957-12-22 00:00:00	\N	Mme	Rossignol	ROSSIGNOL	ROSSIGNOL_LAURENCE_11045K	Laurence	\N	2017-04-24 17:52:09	2730
14159V	1954-04-06 00:00:00	\N	M.	Lalande	LALANDE	LALANDE_Bernard	Bernard	2014-09-18 18:03:58	2014-09-28 21:22:45	3195
14269B	1954-10-09 00:00:00	\N	Mme	Yonnet	YONNET	Yonnet_evelyne	Évelyne	2015-03-04 14:32:20	2016-10-21 16:59:08	3501
14275Y	1970-02-23 00:00:00	\N	Mme	Tetuanui	TETUANUI	TETUANUI_LANA	Lana	2015-05-04 10:27:12	2017-10-17 16:24:59	3561
14277B	1899-12-30 00:50:39	\N	M.	Laurey	LAUREY	LAUREY_NUIHAU	Nuihau	2015-05-04 10:29:04	2015-06-29 16:29:17	3562
14327T	1953-02-12 00:00:00	\N	M.	Delcros	DELCROS	DELCROS_BERNARD	Bernard	2015-09-07 16:16:32	2015-09-07 16:24:18	3681
11056N	1976-04-26 00:00:00	\N	Mme	Cukierman	CUKIERMAN	CUKIERMAN_CECILE_C4857	Cécile	\N	\N	2748
11057P	1955-09-20 00:00:00	\N	M.	Vincent	VINCENT	VINCENT_MAURICE_C4858	Maurice	\N	\N	2749
11066Q	1950-06-25 00:00:00	\N	M.	Vaugrenard	VAUGRENARD	VAUGRENARD_YANNICK_11066Q	Yannick	\N	\N	2776
11067R	1956-01-24 00:00:00	\N	Mme	Meunier	MEUNIER	MEUNIER_MICHELLE_11067R	Michelle	\N	\N	2777
11065P	1963-08-05 00:00:00	\N	M.	Dantec	DANTEC	DANTEC_RONAN_11065P	Ronan	\N	2013-10-28 17:22:20	2778
11064N	1957-11-09 00:00:00	\N	M.	Guerriau	GUERRIAU	GUERRIAU_JOEL_C4907	Joël	\N	\N	2796
11030C	1974-06-11 00:00:00	\N	M.	Béchu	BÉCHU	BECHU_CHRISTOPHE_11030C	Christophe	\N	\N	2822
12042Y	1959-08-30 00:00:00	\N	Mme	Émery-Dumas	ÉMERY-DUMAS	EMERY-DUMAS ANNE	Anne	\N	2016-10-31 11:48:12	2823
13005X	1949-08-17 00:00:00	\N	Mme	Gaouyer	GAOUYER	GAOUYER MARIE-FRANÇOISE	Marie-Françoise	1899-12-30 15:26:29	2014-02-14 15:07:41	2861
14087W	1943-09-12 00:00:00	\N	M.	Forissier	FORISSIER	FORISSIER_Michel	Michel	2014-09-18 10:43:52	2014-09-28 18:36:17	3143
14085U	1950-12-19 00:00:00	\N	M.	Carcenac	CARCENAC	CARCENAC_Thierry	Thierry	2014-09-18 10:06:55	2014-09-28 21:31:44	3142
14089Y	1955-07-12 00:00:00	\N	M.	Bonnecarrère	BONNECARRÈRE	BONNECARRÈRE_Philippe	Philippe	2014-09-18 10:55:55	2014-10-14 16:09:47	3144
14093U	1949-01-01 00:00:00	\N	M.	Bignon	BIGNON	BIGNON_Jerome	Jérôme	2014-09-18 11:20:52	2014-09-28 18:47:56	3146
14097Y	1955-03-24 00:00:00	\N	Mme	Jourda	JOURDA	JOURDA_Gisele	Gisèle	2014-09-18 11:33:18	2014-09-28 21:26:12	3148
14103D	1952-08-07 00:00:00	\N	M.	Luche	LUCHE	LUCHE_Jean_Claude	Jean-Claude	2014-09-18 11:51:04	2014-09-28 21:29:21	3151
14107H	1970-01-18 00:00:00	\N	M.	Roux	ROUX	ROUX_Jean_Yves	Jean-Yves	2014-09-18 11:55:43	2014-09-28 19:53:33	3153
14111D	1957-01-29 00:00:00	\N	M.	Marc	MARC	MARC_Alain	Alain	2014-09-18 11:58:49	2014-09-28 21:29:03	3155
14119M	1947-08-18 00:00:00	\N	M.	Morisset	MORISSET	MORISSET_Jean_Marie	Jean-Marie	2014-09-18 12:10:10	2014-09-28 21:23:52	3159
14129P	1953-01-01 00:00:00	2014-12-27 00:00:00	M.	Dusserre	DUSSERRE	DUSSERRE_Jean_Yves	Jean-Yves	2014-09-18 12:21:16	2014-12-30 10:01:46	3164
14133K	1962-12-19 00:00:00	\N	M.	Allizard	ALLIZARD	ALLIZARD_Pascal	Pascal	2014-09-18 14:40:55	2014-09-28 21:29:36	3182
14137P	1960-09-20 00:00:00	\N	M.	Aubey	AUBEY	AUBEY_Francois	François	2014-09-18 14:45:10	2014-09-28 21:29:49	3184
14201E	1948-06-04 00:00:00	\N	M.	Castelli	CASTELLI	CASTELLI_Joseph	Joseph	2014-09-28 15:43:32	2014-09-28 21:24:20	3301
14205J	1969-03-13 00:00:00	\N	Mme	Loisier	LOISIER	LOISIER_Anne_Catherine	Anne-Catherine	2014-09-28 16:54:08	\N	3303
08044W	2014-11-21 00:00:00	\N	Mme	Joissains	JOISSAINS	JOISSAINS SOPHIE	Sophie	2014-11-25 11:48:18	2014-11-25 11:54:57	3401
14001X	2014-01-01 00:00:00	\N	M.	Marie	MARIE	MARIE	Didier	\N	2014-09-28 20:35:40	2840
14002L	1956-06-05 00:00:00	\N	Mme	Bordas	BORDAS	BORDAS_PATRICIA	Patricia	2014-02-14 15:15:52	2014-02-25 17:19:00	2881
14017T	1964-04-26 00:00:00	\N	M.	Robert	ROBERT	ROBERT_DIDIER	Didier	2014-06-25 15:52:44	2014-07-03 15:25:13	3001
14259Y	1975-07-11 00:00:00	\N	M.	Darnaud	DARNAUD	DARNAUD_Mathieu	Mathieu	2014-09-28 19:20:16	\N	3361
14083S	1960-12-14 00:00:00	\N	M.	Canévet	CANÉVET	CANEVET_Michel	Michel	2014-09-18 10:02:36	2014-09-28 21:28:07	3141
14105F	1947-01-08 00:00:00	\N	M.	Bouchet	BOUCHET	BOUCHET_Gilbert	Gilbert	2014-09-18 11:53:49	2014-09-28 21:22:45	3152
14109K	1958-02-28 00:00:00	\N	Mme	Monier	MONIER	MONIER_Marie_Pierre	Marie-Pierre	2014-09-18 11:56:25	2014-09-28 21:23:16	3154
14121F	1962-10-20 00:00:00	\N	M.	Jeansannetas	JEANSANNETAS	JEANSANNETAS_Éric	Éric	2014-09-18 12:11:37	2014-10-31 15:57:30	3160
14123H	1955-10-17 00:00:00	\N	M.	Grosperrin	GROSPERRIN	GROSPERRIN_Jacques	Jacques	2014-09-18 12:15:25	2014-09-28 21:25:49	3161
14179A	1980-06-08 00:00:00	\N	M.	Hervé	HERVÉ	HERVE_Loic	Loïc	2014-09-22 15:10:03	2014-09-28 17:48:16	3227
14187A	1958-11-14 00:00:00	\N	Mme	Estrosi Sassone	ESTROSI SASSONE	ESTROSI_SASSONE_Dominique	Dominique	2014-09-26 17:49:03	2014-09-28 18:14:17	3244
14213J	1958-11-20 00:00:00	\N	Mme	Imbert	IMBERT	IMBERT_Corinne	Corinne	2014-09-28 17:05:42	\N	3307
14215L	1960-11-30 00:00:00	\N	Mme	Di Folco	DI FOLCO	DI_FOLCO_Catherine	Catherine	2014-09-28 17:07:40	2015-09-24 10:06:00	3308
14217N	1957-01-29 00:00:00	\N	Mme	Deseyne	DESEYNE	DESEYNE_Chantal	Chantal	2014-09-28 17:12:40	\N	3309
14361V	1958-05-13 00:00:00	\N	Mme	Rivollier	RIVOLLIER	RIVOLLIER_Evelyne	Évelyne	2016-12-12 15:59:30	2016-12-12 16:02:43	3881
16685X	1949-11-19 00:00:00	\N	M.	Le Nay	LE NAY	Le_Nay_Jacques	Jacques	2017-06-15 09:47:53	\N	5102
14012N	1899-12-30 00:50:39	\N	Mme	Lajoux	LAJOUX	LAJOUX_ISABELLE	Isabelle	2014-05-05 10:30:19	2014-05-06 14:40:00	2941
14030Q	1967-08-03 00:00:00	\N	Mme	Billon	BILLON	BILLON_Annick	Annick	2014-09-16 15:03:46	2014-09-28 17:38:33	3066
14031R	1964-08-07 00:00:00	\N	M.	Mandelli	MANDELLI	MANDELLI_Didier	Didier	2014-09-16 15:33:05	2014-09-28 17:42:41	3068
14249W	1958-10-13 00:00:00	\N	Mme	Duranton	DURANTON	DURANTON_Nicole	Nicole	2014-09-28 18:19:47	\N	3341
16813M	1947-11-18 00:00:00	\N	M.	Poyart	POYART	Poyart_Alain	Alain	2017-06-15 09:48:09	\N	5166
14079W	1947-08-30 00:00:00	\N	M.	Danesi	DANESI	DANESI_Rene	René	2014-09-17 18:06:24	2014-09-28 21:31:28	3135
14081Q	1956-01-27 00:00:00	\N	Mme	Guillemot	GUILLEMOT	GUILLEMOT_Annie	Annie	2014-09-17 18:10:27	2014-09-28 21:28:44	3136
14147R	1958-06-16 00:00:00	\N	Mme	Mercier	MERCIER	MERCIER_Marie	Marie	2014-09-18 15:45:20	2015-06-12 15:47:24	3189
14151M	1969-06-02 00:00:00	\N	M.	Durain	DURAIN	DURAIN_Jerome	Jérôme	2014-09-18 15:54:22	2014-09-28 19:36:59	3191
14219Q	1956-12-27 00:00:00	\N	M.	Longeot	LONGEOT	LONGEOT_Jean_Francois	Jean-François	2014-09-28 17:22:10	\N	3310
14221J	1960-04-17 00:00:00	\N	M.	Médevielle	MÉDEVIELLE	MEDEVIELLE_Pierre	Pierre	2014-09-28 17:27:34	\N	3311
14223L	1951-09-10 00:00:00	\N	Mme	Micouleau	MICOULEAU	MICOULEAU_Brigitte	Brigitte	2014-09-28 17:27:34	\N	3312
14225N	1957-10-10 00:00:00	\N	M.	Raynal	RAYNAL	RAYNAL_Claude	Claude	2014-09-28 17:27:34	\N	3313
14227Q	1944-08-25 00:00:00	\N	M.	Tourenne	TOURENNE	TOURENNE_Jean_Louis	Jean-Louis	2014-09-28 17:34:15	\N	3314
14229S	1963-08-28 00:00:00	\N	Mme	Robert	ROBERT	ROBERT_Sylvie	Sylvie	2014-09-28 17:34:15	\N	3315
14231L	1953-03-14 00:00:00	\N	Mme	Gatel	GATEL	GATEL_Francoise	Françoise	2014-09-28 17:34:15	\N	3316
14237S	1981-02-18 00:00:00	\N	M.	Pellevat	PELLEVAT	PELLEVAT_Cyril	Cyril	2014-09-28 17:40:23	\N	3319
14239U	1954-07-03 00:00:00	\N	M.	Amiel	AMIEL	AMIEL_Michel	Michel	2014-09-28 17:52:17	\N	3320
14241N	1960-12-30 00:00:00	\N	Mme	Jouve	JOUVE	JOUVE_Mireille	Mireille	2014-09-28 17:52:17	\N	3321
14261S	1958-01-20 00:00:00	2014-11-24 00:00:00	M.	Arnell	ARNELL	ARNELL_Guillaume_Jacques	Guillaume Jacques	2014-09-29 09:03:10	2014-11-25 17:27:46	3381
14273W	1952-05-31 00:00:00	\N	M.	Masclet	MASCLET	MASCLET_PATRICK	Patrick	2015-04-22 16:49:30	\N	3541
14329V	1958-04-11 00:00:00	\N	Mme	Chain-Larché	CHAIN-LARCHÉ	CHAIN LARCHE ANNE	Anne	2015-10-12 09:41:57	\N	3701
17367Q	1954-08-29 00:00:00	\N	M.	Blanc	BLANC	Blanc_Etienne	Étienne	2017-06-15 09:49:07	\N	5443
17583W	1958-05-02 00:00:00	\N	M.	Priou	PRIOU	Priou_Christophe	Christophe	2017-06-15 09:49:31	\N	5551
17589D	1952-10-19 00:00:00	\N	M.	Decool	DECOOL	Decool_Jean_Pierre	Jean-Pierre	2017-06-15 09:49:31	\N	5554
17637T	1955-09-25 00:00:00	\N	M.	Pemezec	PEMEZEC	Pemezec_Philippe	Philippe	2017-06-15 09:49:35	\N	5578
18083K	1974-10-27 00:00:00	\N	M.	Chevrollier	CHEVROLLIER	CHEVROLLIER_Guillaume	Guillaume	2017-06-15 09:50:03	\N	5801
18127E	1970-03-02 00:00:00	\N	Mme	Dufour-Tonini	DUFOUR-TONINI	Dufour_Tonini_Anne_Lise	Anne-Lise	2017-06-15 09:50:05	\N	5823
18193Q	1960-03-31 00:00:00	\N	Mme	Le Houerou	LE HOUEROU	Le_Houerou_Annie	Annie	2017-06-15 09:50:07	\N	5856
18207D	1973-10-11 00:00:00	\N	Mme	Linkenheld	LINKENHELD	Linkenheld_Audrey	Audrey	2017-06-15 09:50:08	\N	5863
18231D	1975-03-07 00:00:00	\N	Mme	Narassiguin	NARASSIGUIN	Narassiguin_Corinne	Corinne	2017-06-15 09:50:09	\N	5875
18395Y	1974-06-22 00:00:00	\N	Mme	Daniel	DANIEL	Daniel_Karine	Karine	2017-06-15 09:50:15	\N	5957
17737W	1962-06-11 00:00:00	\N	Mme	Boyer	BOYER	Boyer_Valerie	Valérie	2017-06-15 09:49:42	\N	5628
17779H	1963-07-16 00:00:00	\N	Mme	Lubin	LUBIN	Lubin_Monique	Monique	2017-06-15 09:49:45	\N	5649
17965H	1950-07-25 00:00:00	\N	Mme	Poumirol	POUMIROL	Poumirol_Emilienne	Émilienne	2017-06-15 09:49:56	\N	5742
18003S	1978-06-11 00:00:00	\N	M.	Aubert	AUBERT	Aubert_Julien	Julien	2017-06-15 09:49:58	\N	5761
17023S	1963-07-14 00:00:00	\N	M.	Folliot	FOLLIOT	Folliot_Philippe	Philippe	2017-06-15 09:48:33	\N	5271
17229F	1963-06-26 00:00:00	\N	M.	Demilly	DEMILLY	Demilly_Stephane	Stéphane	2017-06-15 09:48:57	\N	5374
19251M	1953-07-19 00:00:00	\N	M.	Devinaz	DEVINAZ	DEVINAZ_Gilbert_Luc	Gilbert-Luc	2017-06-19 16:45:46	2017-06-19 16:53:52	6421
19253P	1947-08-23 00:00:00	\N	Mme	Costes	COSTES	Costes_Josiane	Josiane	2017-06-19 16:48:14	\N	6422
19265T	1986-06-11 00:00:00	\N	M.	Lecornu	LECORNU	Lecornu_Sebastien	Sébastien	2017-06-22 11:08:44	\N	6482
19289C	1964-01-29 00:00:00	\N	M.	Léonhardt	LÉONHARDT	LEONHARDT_Olivier	Olivier	2017-09-14 11:04:38	2017-09-28 09:32:20	6581
19301E	1960-08-04 00:00:00	\N	M.	Théophile	THÉOPHILE	THEOPHILE_Dominique	Dominique	2017-09-15 15:25:04	2017-09-25 11:00:34	6623
19319Q	1963-09-30 00:00:00	\N	M.	Poadja	POADJA	POADJA_Gerard	Gérard	2017-09-15 15:41:57	2017-09-24 09:56:57	6632
19329S	1954-07-02 00:00:00	\N	M.	Hassani	HASSANI	HASSANI_Abdallah	Abdallah	2017-09-15 15:50:41	2017-09-25 16:09:40	6637
19331L	1957-06-20 00:00:00	2023-09-27 11:56:53	M.	OMAR OILI	OMAR OILI	OMAR_OILI_Said	Saïd	2017-09-15 15:50:55	\N	6638
19333N	1958-05-30 00:00:00	\N	M.	Houllegatte	HOULLEGATTE	HOULLEGATTE_Jean_Michel	Jean-Michel	2017-09-15 16:05:41	2017-09-25 16:11:35	6641
19335Q	1956-03-31 00:00:00	\N	M.	Mizzon	MIZZON	MIZZON_Jean_Marie	Jean-Marie	2017-09-15 16:22:19	2017-09-25 15:14:54	6642
19347U	1971-03-11 00:00:00	\N	M.	Gontard	GONTARD	GONTARD_Guillaume	Guillaume	2017-09-15 16:24:26	2017-09-24 18:04:26	6648
19349W	1959-05-12 00:00:00	\N	M.	Rambaud	RAMBAUD	RAMBAUD_Didier	Didier	2017-09-15 16:24:54	2017-09-24 18:07:52	6649
19367Y	1956-05-25 00:00:00	\N	Mme	Bonfanti-Dossat	BONFANTI-DOSSAT	BONFANTI_DOSSAT_Christine	Christine	2017-09-15 16:34:14	2017-09-25 14:44:27	6658
19369B	1947-05-19 00:00:00	\N	M.	Moga	MOGA	MOGA_Jean_Pierre	Jean-Pierre	2017-09-15 16:34:29	2017-09-25 15:15:12	6659
19383Y	1954-02-24 00:00:00	\N	M.	Boyer	BOYER	BOYER_Jean_Marc	Jean-Marc	2017-09-18 16:38:52	2017-09-19 15:41:05	6681
19387D	1964-06-07 00:00:00	\N	M.	Gold	GOLD	GOLD_Eric	Éric	2017-09-18 16:39:36	2017-09-19 15:41:33	6683
19399H	1958-01-10 00:00:00	\N	M.	Hugonet	HUGONET	HUGONET_Jean_Raymond	Jean-Raymond	2017-09-18 16:52:16	2017-09-19 15:43:58	6689
19413M	1963-09-22 00:00:00	\N	M.	Tissot	TISSOT	TISSOT_Jean_Claude	Jean-Claude	2017-09-18 16:57:45	2017-09-19 15:28:45	6696
19415P	1948-09-18 00:00:00	\N	M.	Bonne	BONNE	BONNE Bernard	Bernard	2017-09-18 16:58:00	2017-09-19 15:29:05	6697
19421M	1958-11-12 00:00:00	\N	M.	Saury	SAURY	SAURY_Hugues	Hugues	2017-09-18 16:58:54	2017-09-19 15:31:12	6700
19441R	1949-05-03 00:00:00	\N	M.	Louault	LOUAULT	LOUAULT_Pierre	Pierre	2017-09-18 17:02:29	2017-09-19 15:14:26	6710
19443T	1961-02-23 00:00:00	\N	Mme	Raimond-Pavero	RAIMOND-PAVERO	RAIMOND_PAVERO_Isabelle	Isabelle	2017-09-18 17:02:36	2017-09-24 17:57:13	6711
19057M	1971-08-10 00:00:00	\N	Mme	Cazebonne	CAZEBONNE	Cazebonne_Samantha	Samantha	2017-06-19 09:39:50	\N	6314
19111A	1967-08-02 00:00:00	\N	Mme	Florennes	FLORENNES	Florennes_Isabelle	Isabelle	2017-06-19 09:39:51	\N	6341
19269X	1899-12-30 00:50:39	\N	Mme	Rauscent	RAUSCENT	RAUSCENT_NOELLE	Noëlle	2017-07-24 10:01:14	2017-10-17 17:52:34	6501
19285X	1899-12-31 00:00:00	\N	M.	Dutheil	DUTHEIL	Dutheil_Laurent	Laurent	2017-07-31 12:02:13	\N	6541
19295A	1963-05-18 00:00:00	\N	Mme	Conconne	CONCONNE	CONCONNE_Catherine	Catherine	2017-09-15 14:40:03	2017-09-25 11:17:32	6603
19447X	1967-10-27 00:00:00	\N	Mme	Jourda	JOURDA	JOURDA_Muriel	Muriel	2017-09-18 17:03:49	2017-09-19 15:35:43	6713
19467C	1954-11-20 00:00:00	\N	Mme	Chauvin	CHAUVIN	CHAUVIN_Marie_Christine	Marie-Christine	2017-09-18 17:32:52	2017-09-19 15:23:49	6723
19479G	1967-06-10 00:00:00	\N	Mme	Vermeillet	VERMEILLET	VERMEILLET_Sylvie	Sylvie	2017-09-18 17:33:13	2017-09-19 15:21:37	6729
19483C	1974-02-27 00:00:00	\N	M.	Leroux	LEROUX	LEROUX_Sebastien	Sébastien	2017-09-18 17:35:47	2017-09-19 15:38:48	6731
19489J	1967-10-01 00:00:00	\N	M.	Kerrouche	KERROUCHE	KERROUCHE_Eric	Éric	2017-09-18 17:37:18	2017-09-19 15:24:22	6734
19503N	1955-11-23 00:00:00	\N	Mme	Préville	PRÉVILLE	PREVILLE_Angele	Angèle	2017-09-18 17:39:48	2017-09-29 15:52:57	6741
19507S	1971-10-24 00:00:00	\N	M.	Duplomb	DUPLOMB	DUPLOMB_Laurent	Laurent	2017-09-18 17:45:15	2017-09-19 15:29:54	6743
19511N	1953-03-19 00:00:00	\N	M.	Janssens	JANSSENS	JANSSENS_Jean_Marie	Jean-Marie	2017-09-18 17:46:50	2017-09-19 15:25:31	6761
19515S	1946-07-16 00:00:00	\N	M.	Babary	BABARY	BABARY_Serge	Serge	2017-09-19 15:16:20	2017-09-19 15:20:22	6781
19521Q	1955-09-16 00:00:00	\N	Mme	Fournier	FOURNIER	FOURNIER_Catherine	Catherine	2017-09-19 16:03:29	2017-09-24 20:02:46	6801
19525U	1962-01-28 00:00:00	\N	M.	Dagbert	DAGBERT	DAGBERT_Michel	Michel	2017-09-19 16:32:20	2017-09-24 19:11:00	6803
19527W	1960-09-08 00:00:00	\N	Mme	Van Heghe	VAN HEGHE	VAN_HEGHE_Sabine	Sabine	2017-09-19 16:42:09	2017-09-24 19:29:35	6821
19531S	1957-05-05 00:00:00	\N	M.	Joly	JOLY	JOLY_Patrice	Patrice	2017-09-19 17:02:18	2017-09-25 15:13:22	6823
19533U	1970-02-25 00:00:00	\N	M.	Piednoir	PIEDNOIR	PIEDNOIR_Stephane	Stéphane	2017-09-19 17:19:25	2017-09-24 17:31:23	6824
19543W	1975-03-14 00:00:00	\N	M.	de Belenet	de BELENET	BELENET_Arnaud	Arnaud	2017-09-19 18:03:41	2017-10-04 19:39:28	6843
19545Y	1974-06-23 00:00:00	\N	M.	Capus	CAPUS	CAPUS_Emmanuel	Emmanuel	2017-09-20 10:41:39	2017-09-24 17:49:04	6861
19549D	1949-02-05 00:00:00	\N	M.	Bigot	BIGOT	BIGOT_Joel	Joël	2017-09-20 10:57:05	2017-09-24 17:46:24	6863
19551W	1964-05-08 00:00:00	\N	M.	Jacquin	JACQUIN	JACQUIN_Olivier	Olivier	2017-09-20 11:18:09	2017-09-25 15:13:03	6881
19553Y	1962-11-03 00:00:00	\N	Mme	Guillotin	GUILLOTIN	GUILLOTIN_Veronique	Véronique	2017-09-20 11:26:14	2017-09-25 11:58:15	6901
19563B	1972-10-03 00:00:00	\N	M.	Menonville	MENONVILLE	MENONVILLE_Franck	Franck	2017-09-20 16:37:06	2017-09-24 20:14:59	6961
19565D	1967-10-30 00:00:00	\N	Mme	Gréaume	GRÉAUME	GREAUME_Michelle	Michelle	2017-09-21 17:29:45	2017-09-24 19:31:28	6981
19569H	1962-04-21 00:00:00	\N	M.	Henno	HENNO	HENNO_Olivier	Olivier	2017-09-21 17:45:43	2017-09-25 15:10:11	6983
19573D	1969-04-12 00:00:00	\N	M.	Paccaud	PACCAUD	PACCAUD_Olivier	Olivier	2017-09-21 18:30:58	2017-09-24 18:07:30	7001
19575F	1961-03-27 00:00:00	\N	Mme	Berthet	BERTHET	BERTHET_Martine	Martine	2017-09-21 18:41:15	2017-09-24 20:05:45	7002
19577H	1960-01-20 00:00:00	\N	Mme	Dindar	DINDAR	DINDAR_Nassimah	Nassimah	2017-09-22 10:04:59	2017-09-24 16:27:34	7021
19581D	1956-06-21 00:00:00	\N	Mme	Lherbier	LHERBIER	LHERBIER_Brigitte	Brigitte	2017-09-22 10:17:31	2017-09-25 15:13:42	7042
19583F	1947-08-05 00:00:00	\N	M.	Lagourgue	LAGOURGUE	LAGOURGUE_Jean_Louis	Jean-Louis	2017-09-22 10:17:41	2017-09-24 16:29:00	7043
19585H	1951-11-22 00:00:00	\N	M.	Wattebled	WATTEBLED	WATTEBLED_Dany	Dany	2017-09-22 10:28:53	2017-09-25 15:15:35	7044
19591F	1987-03-31 00:00:00	\N	M.	Iacovelli	IACOVELLI	IACOVELLI_Xavier	Xavier	2017-09-22 11:11:35	2017-09-25 10:26:35	7081
19593H	1964-01-28 00:00:00	\N	M.	Ouzoulias	OUZOULIAS	OUZOULIAS_Pierre	Pierre	2017-09-22 11:17:31	2017-09-24 20:30:23	7082
19599P	1953-06-06 00:00:00	\N	Mme	Filleul	FILLEUL	FILLEUL_Martine	Martine	2017-09-22 11:41:01	2017-09-25 15:07:16	7103
19611R	1965-11-18 00:00:00	\N	M.	Lafon	LAFON	LAFON_Laurent	Laurent	2017-09-22 11:46:21	2017-09-24 18:50:05	7109
19619A	1951-01-05 00:00:00	\N	Mme	Saint-Pé	SAINT-PÉ	SAINT_PE_Denise	Denise	2017-09-22 13:40:29	2017-09-22 13:55:08	7121
19621T	1957-03-08 00:00:00	\N	M.	Brisson	BRISSON	BRISSON_Max	Max	2017-09-22 13:41:11	2017-09-22 13:42:42	7122
19675J	1961-08-19 00:00:00	\N	Mme	Thomas	THOMAS	THOMAS_Claudine	Claudine	2017-09-24 17:18:02	\N	7368
19681G	1960-03-07 00:00:00	\N	M.	Corbisez	CORBISEZ	CORBISEZ_Jean_Pierre	Jean-Pierre	2017-09-24 17:42:25	\N	7371
19683J	1963-10-09 00:00:00	\N	M.	Jomier	JOMIER	JOMIER_Bernard	Bernard	2017-09-24 17:47:26	\N	7372
19687N	1961-01-14 00:00:00	\N	M.	Savoldelli	SAVOLDELLI	SAVOLDELLI_Pascal	Pascal	2017-09-24 17:55:12	\N	7374
19689Q	1974-10-04 00:00:00	\N	Mme	Taillé-Polian	TAILLÉ-POLIAN	TAILLE_POLIAN_Sophie	Sophie	2017-09-24 17:55:12	\N	7375
19691J	1956-09-26 00:00:00	\N	Mme	Guidez	GUIDEZ	GUIDEZ_Jocelyne	Jocelyne	2017-09-24 18:05:40	\N	7376
19693L	1970-11-27 00:00:00	\N	Mme	Darcos	DARCOS	DARCOS_Laure	Laure	2017-09-24 18:05:40	\N	7377
19711U	1984-10-16 00:00:00	\N	Mme	Lavarde	LAVARDE	LAVARDE_Christine	Christine	2017-09-24 19:25:09	\N	7386
19713W	1961-11-09 00:00:00	\N	Mme	Sollogoub	SOLLOGOUB	SOLLOGOUB_Nadia	Nadia	2017-09-24 19:31:54	\N	7387
19719D	1968-12-02 00:00:00	\N	Mme	Delattre	DELATTRE	DELATTRE_Nathalie	Nathalie	2017-10-01 09:26:48	2017-10-01 09:36:11	7421
19747H	1960-08-30 00:00:00	2024-01-30 00:00:00	M.	Bouloux	BOULOUX	BOULOUX_Yves	Yves	2017-12-18 00:00:00	2024-01-30 00:00:00	7482
19758L	1970-03-04 00:00:00	\N	Mme	Brulin	BRULIN	BRULIN_Celine	Céline	2018-05-31 11:00:21	2018-06-04 13:56:15	9641
19794Q	1940-09-29 00:00:00	\N	Mme	Ramond	RAMOND	RAMOND_Françoise	Françoise	\N	\N	24581
19914E	1971-11-11 00:00:00	\N	M.	Cardenes	CARDENES	Cardenes_Stephane	Stéphane	\N	\N	71561
19926J	1955-03-09 00:00:00	\N	Mme	Cabaret	CABARET	Cabaret_Muriel	Muriel	\N	\N	71623
19954N	1962-08-10 00:00:00	\N	Mme	Belrhiti	BELRHITI	Belrhiti_Catherine	Catherine	\N	\N	71761
20142Y	1953-11-12 00:00:00	\N	Mme	de Marco	de MARCO	MARCO_DE_Monique	Monique	\N	\N	72144
19820Y	1960-10-09 00:00:00	\N	M.	Gillé	GILLÉ	GILLE_HERVE	Hervé	\N	\N	62762
19721W	1944-08-25 00:00:00	\N	M.	Cazabonne	CAZABONNE	CAZABONNE_Alain	Alain	2017-10-01 09:45:12	2017-10-02 09:39:41	7422
19723Y	1957-05-18 00:00:00	\N	Mme	Lassarade	LASSARADE	LASSARADE_Florence	Florence	2017-10-01 10:06:58	2017-10-01 10:15:17	7423
19725B	1953-02-08 00:00:00	\N	Mme	Harribey	HARRIBEY	HARRIBEY_Laurence	Laurence	2017-10-01 10:44:23	2017-10-01 10:52:00	7424
19727D	1959-01-17 00:00:00	\N	Mme	Grelet-Certenais	GRELET-CERTENAIS	GRELET_CERTENAIS_Nadine	Nadine	2017-10-01 10:54:01	2017-10-03 10:52:06	7425
19729F	1945-03-31 00:00:00	\N	M.	Leroy	LEROY	LEROY_Henri	Henri	2017-10-01 11:03:20	2017-10-01 11:10:27	7426
19731Y	1944-09-28 00:00:00	\N	Mme	Kauffmann	KAUFFMANN	KAUFFMANN_Claudine	Claudine	2017-10-01 11:13:13	2017-10-02 09:35:22	7427
19733B	1969-04-01 00:00:00	\N	Mme	Bories	BORIES	BORIES_Pascale	Pascale	2017-10-01 11:41:24	2017-10-01 11:45:26	7428
19735D	1968-12-25 00:00:00	\N	Mme	de La Provôté	de LA PROVÔTÉ	LA_PROVOTE_Sonia	Sonia	2017-10-01 11:48:00	2017-10-04 19:40:51	7429
19737F	1944-01-18 00:00:00	\N	Mme	Vullien	VULLIEN	VULLIEN_Michele	Michèle	2017-10-01 11:57:14	2017-10-01 12:02:34	7430
19739H	1944-07-08 00:00:00	\N	M.	Prince	PRINCE	Prince_Jean_Paul	Jean-Paul	2017-11-03 10:52:37	\N	7441
19741B	1973-05-31 00:00:00	\N	M.	Bascher	BASCHER	BASCHER_JEROME	Jérôme	2017-11-24 18:17:29	2018-01-18 15:15:12	7461
20980G	1961-10-25 00:00:00	\N	Mme	Del Fabro	DEL FABRO	Del_Fabro_Veronique	Véronique	\N	\N	77921
19667J	1959-01-10 00:00:00	\N	M.	Bazin	BAZIN	BAZIN_Arnaud	Arnaud	2017-09-24 17:15:14	\N	7364
19669L	1973-03-29 00:00:00	\N	M.	Temal	TEMAL	TEMAL_Rachid	Rachid	2017-09-24 17:15:14	\N	7365
19671E	1971-03-18 00:00:00	\N	M.	Meurant	MEURANT	MEURANT_Sebastien	Sébastien	2017-09-24 17:15:14	\N	7366
19673G	1956-09-05 00:00:00	\N	Mme	Eustache-Brinio	EUSTACHE-BRINIO	EUSTACHE_BRINIO_Jacqueline	Jacqueline	2017-09-24 17:15:14	\N	7367
19677L	1960-10-25 00:00:00	\N	Mme	Lefebvre	LEFEBVRE	LEFEBVRE_Nadege	Nadège	2017-09-24 17:29:36	\N	7369
19679N	1967-11-04 00:00:00	\N	Mme	Puissat	PUISSAT	PUISSAT_Frederique	Frédérique	2017-09-24 17:35:13	\N	7370
19685L	1968-12-30 00:00:00	\N	Mme	Herzog	HERZOG	HERZOG_Christine	Christine	2017-09-24 17:48:20	\N	7373
19695N	1984-01-13 00:00:00	\N	M.	Gay	GAY	GAY_Fabien	Fabien	2017-09-24 18:07:56	\N	7378
19697Q	1962-10-30 00:00:00	\N	M.	Lévrier	LÉVRIER	LEVRIER_Martin	Martin	2017-09-24 18:17:55	\N	7379
19699S	1956-07-11 00:00:00	\N	M.	Laugier	LAUGIER	LAUGIER_Michel	Michel	2017-09-24 18:17:55	\N	7380
19701S	1964-06-13 00:00:00	\N	Mme	de Cidrac	de CIDRAC	CIDRAC_Marta	Marta	2017-09-24 18:17:55	2017-10-04 19:39:49	7381
19703U	1952-06-03 00:00:00	\N	M.	Sol	SOL	SOL_Jean	Jean	2017-09-24 18:49:56	\N	7382
19705W	1950-06-18 00:00:00	\N	Mme	Renaud-Garabedian	RENAUD-GARABEDIAN	RENAUD_GARABEDIAN_Evelyne	Évelyne	2017-09-24 18:59:59	2017-09-24 20:47:15	7383
19707Y	1940-05-15 00:00:00	\N	M.	Bansard	BANSARD	BANSARD_Jean_Pierre	Jean-Pierre	2017-09-24 18:59:59	\N	7384
19709B	1976-08-21 00:00:00	\N	M.	Le Gleut	LE GLEUT	LE_GLEUT_Ronan	Ronan	2017-09-24 18:59:59	\N	7385
19866P	1899-12-30 00:50:39	\N	Mme	Pantel	PANTEL	Pantel_Guylene	Guylène	\N	\N	69381
20172F	1978-04-03 00:00:00	\N	Mme	Garnier	GARNIER	Garnier_Laurence	Laurence	\N	\N	72241
83008P	2001-03-02 00:00:00	2001-03-01 00:00:00	M.	Abadie	ABADIE	ABADIE	François	\N	\N	64661
19930E	1965-12-17 00:00:00	\N	Mme	André	ANDRÉ	Andre_Catherine	Catherine	\N	\N	71642
19826F	1960-03-07 00:00:00	\N	M.	Martin	MARTIN	MARTIN_Pascal	Pascal	\N	\N	63722
19637C	1965-05-31 00:00:00	\N	M.	Marchand	MARCHAND	MARCHAND_Frederic	Frédéric	2017-09-22 15:35:19	2017-09-25 15:14:06	7162
14115H	2017-09-23 00:00:00	\N	Mme	Bertrand	BERTRAND	BERTRAND_Anne_Marie	Anne-Marie	2017-09-24 11:17:24	2017-09-24 11:29:16	7282
19760E	1965-04-18 00:00:00	\N	Mme	Apourceau-Poly	APOURCEAU-POLY	APOURCEAU-POLY	Cathy	\N	\N	9661
19762G	1972-07-01 00:00:00	\N	M.	Segouin	SEGOUIN	SEGOUIN	Vincent	\N	\N	9662
20016T	1963-06-17 00:00:00	\N	M.	Kulimoetoke	KULIMOETOKE	KULIMOETOKE_Mikaele	Mikaele	\N	\N	72081
20018V	1956-07-23 00:00:00	\N	M.	Michau	MICHAU	MICHAU_Jean_Jacques	Jean-Jacques	\N	\N	72082
20020P	1957-03-06 00:00:00	\N	M.	Rojouan	ROJOUAN	ROJOUAN_Bruno	Bruno	\N	\N	72083
20022R	1965-04-05 00:00:00	\N	Mme	Bellurot	BELLUROT	BELLUROT_Nadine	Nadine	\N	\N	72084
20024T	1962-06-08 00:00:00	\N	M.	Belin	BELIN	BELIN_Bruno	Bruno	\N	\N	72085
20026V	1972-01-07 00:00:00	\N	Mme	Ventalon	VENTALON	VENTALON_Anne	Anne	\N	\N	72086
20028X	1952-02-14 00:00:00	\N	M.	Mérillou	MÉRILLOU	MERILLOU_Serge	Serge	\N	\N	72087
20030R	1977-07-18 00:00:00	\N	M.	Pla	PLA	PLA_Sebastien	Sebastien	\N	\N	72088
20034V	1971-10-08 00:00:00	\N	Mme	Jacques	JACQUES	JACQUES_Micheline	Micheline	\N	\N	72090
20036X	1966-04-07 00:00:00	\N	M.	Parigi	PARIGI	PARIGI_Paul_Toussaint	Paul Toussaint	\N	\N	72091
20042V	1958-02-08 00:00:00	\N	M.	Bonneau	BONNEAU	BONNEAU_Francois	François	\N	\N	72094
20048C	1986-07-19 00:00:00	\N	M.	Hingray	HINGRAY	HINGRAY_Jean	Jean	\N	\N	72097
20050V	1967-01-25 00:00:00	\N	Mme	Paoli-Gagin	PAOLI-GAGIN	PAOLI_GAGIN_Vanina	Vanina	\N	\N	72098
20054A	1971-11-22 00:00:00	\N	M.	Rietmann	RIETMANN	RIETMANN_Olivier	Olivier	\N	\N	72100
20058E	1978-03-25 00:00:00	\N	M.	Vial	VIAL	VIAL_Cedric	Cédric	\N	\N	72102
20064C	1979-05-26 00:00:00	\N	M.	Vallet	VALLET	VALLET_Mickael	Mickaël	\N	\N	72105
20068G	1961-04-17 00:00:00	\N	M.	Gueret	GUERET	GUERET_Daniel	Daniel	\N	\N	72107
20084G	1950-08-19 00:00:00	\N	M.	Stanzione	STANZIONE	STANZIONE_Lucien	Lucien	\N	\N	72115
20086J	1972-09-03 00:00:00	\N	M.	Blanc	BLANC	BLANC_Jean_Baptiste	Jean-Baptiste	\N	\N	72116
20094J	1966-03-30 00:00:00	\N	Mme	Blatrix Contat	BLATRIX CONTAT	BLATRIX_CONTAT_Florence	Florence	\N	\N	72120
20102Q	1954-04-04 00:00:00	\N	M.	Lahellec	LAHELLEC	LAHELLEC_Gerard	Gérard	\N	\N	72124
20104S	1953-06-21 00:00:00	\N	M.	Cadec	CADEC	CADEC_Alain	Alain	\N	\N	72125
20106U	1975-12-30 00:00:00	\N	Mme	Havet	HAVET	HAVET_Nadege	Nadège	\N	\N	72126
20118Y	1973-05-01 00:00:00	\N	Mme	Pluchet	PLUCHET	PLUCHET_Kristina	Kristina	\N	\N	72132
20124W	1963-08-17 00:00:00	\N	Mme	Drexler	DREXLER	DREXLER_Sabine	Sabine	\N	\N	72135
20126Y	1968-12-15 00:00:00	\N	M.	Klinger	KLINGER	KLINGER_Christian	Christian	\N	\N	72136
20128B	1975-01-18 00:00:00	\N	M.	Haye	HAYE	HAYE_Ludovic	Ludovic	\N	\N	72137
20174H	1957-06-10 00:00:00	\N	Mme	Evrard	EVRARD	Evrard_Marie_Agnes	Marie	\N	\N	72242
20264J	1979-04-14 00:00:00	\N	M.	Chantrel	CHANTREL	Chantrel_Yan	Yan	\N	\N	76221
14029X	2017-09-23 00:00:00	\N	Mme	Lanfranchi Dorgal	LANFRANCHI DORGAL	LANFRANCHI_DORGAL_Christine	Christine	2017-09-24 11:20:58	2017-09-24 11:30:01	7301
20266L	1899-12-31 00:00:00	\N	Mme	Vogel	VOGEL	Vogel_Melanie	Mélanie	\N	\N	76222
19657G	1954-10-28 00:00:00	\N	Mme	Malet	MALET	MALET_Viviane	Viviane	2017-09-24 16:24:50	\N	7341
19659J	1949-02-11 00:00:00	\N	M.	Dennemont	DENNEMONT	DENNEMONT_Michel	Michel	2017-09-24 16:24:50	\N	7342
19663E	1947-07-13 00:00:00	\N	Mme	Delmont-Koropoulis	DELMONT-KOROPOULIS	DELMONT_KOROPOULIS_Annie	Annie	2017-09-24 17:01:53	2017-09-24 19:25:06	7362
19745F	1951-06-22 00:00:00	\N	Mme	Perrot	PERROT	Perrot_Evelyne	Évelyne	2017-12-18 14:31:40	2017-12-18 15:08:03	7481
19749K	1965-08-29 00:00:00	\N	Mme	Vérien	VÉRIEN	Verien_Dominique	Dominique	2017-12-18 14:52:08	\N	7483
19766L	1966-02-24 00:00:00	\N	M.	Regnard	REGNARD	REGNARD_Damien	Damien	\N	\N	9761
14189C	1966-04-28 00:00:00	\N	M.	Arnaud	ARNAUD	ARNAUD_Jean_Michel	Jean-Michel	\N	\N	72164
19920C	1969-11-20 00:00:00	\N	M.	Chaudun	CHAUDUN	Chaudun_Christophe	Christophe	\N	\N	71601
19629C	1967-04-08 00:00:00	\N	Mme	Carrère	CARRÈRE	CARRERE_Maryse	Maryse	2017-09-22 13:44:39	2017-09-24 12:48:54	7126
19631V	1956-10-22 00:00:00	\N	Mme	Artigalas	ARTIGALAS	ARTIGALAS_Viviane	Viviane	2017-09-22 13:48:29	2017-09-25 11:07:11	7127
19643A	1970-12-18 00:00:00	\N	Mme	Boulay-Espéronnier	BOULAY-ESPÉRONNIER	BOULAY_ESPERONNIER_Celine	Céline	2017-09-22 16:42:25	2017-09-29 15:53:13	7201
19647E	1971-08-24 00:00:00	\N	M.	Féraud	FÉRAUD	FERAUD_Remi	Rémi	2017-09-22 18:25:07	2017-09-25 10:27:48	7222
19649G	1958-12-18 00:00:00	\N	Mme	de La Gontrie	de LA GONTRIE	LA_GONTRIE_Marie_Pierre	Marie-Pierre	2017-09-22 18:27:49	2017-10-04 19:40:25	7223
19651A	1973-03-29 00:00:00	\N	M.	Bargeton	BARGETON	BARGETON_Julien	Julien	2017-09-22 18:34:24	2017-09-24 19:07:07	7241
19715Y	1955-12-23 00:00:00	\N	Mme	Jasmin	JASMIN	JASMIN_Victoire	Victoire	2017-09-25 10:54:33	\N	7401
19717B	1973-03-09 00:00:00	\N	M.	Artano	ARTANO	ARTANO_Stephane	Stéphane	2017-09-25 10:56:48	\N	7402
19768N	1978-01-27 00:00:00	\N	Mme	Noël	NOËL	NOEL_Sylviane	Sylviane	\N	\N	9781
19782L	1899-12-30 00:50:39	\N	M.	Buis	BUIS	BUIS_Bernard	Bernard	\N	\N	16721
19958S	1948-03-12 00:00:00	\N	Mme	Garcia	GARCIA	Garcia_Daniele	Danièle	\N	\N	71821
19966S	1956-11-09 00:00:00	\N	M.	Boré	BORÉ	Bore_Patrick	Patrick	\N	\N	71861
19968U	1953-06-26 00:00:00	\N	Mme	Einaudi	EINAUDI	Einaudi_Michele	Michèle	\N	\N	71881
20014R	1950-05-02 00:00:00	\N	Mme	Tubiana	TUBIANA	Tubiana_Daniele	Danièle	\N	\N	72061
20032T	1961-02-20 00:00:00	\N	M.	Anglars	ANGLARS	ANGLARS_Jean_Claude	Jean-Claude	\N	\N	72089
20038A	1949-05-04 00:00:00	\N	M.	Favreau	FAVREAU	FAVREAU_Gilbert	Gilbert	\N	\N	72092
20046A	1950-12-18 00:00:00	\N	Mme	Varaillas	VARAILLAS	VARAILLAS_Marie_Claude	Marie-Claude	\N	\N	72096
20052X	1965-05-15 00:00:00	\N	M.	Levi	LEVI	LEVI_Pierre_Antoine	Pierre-Antoine	\N	\N	72099
20056C	1961-12-24 00:00:00	\N	Mme	Joseph	JOSEPH	JOSEPH_Else	Else	\N	\N	72101
20060X	1994-05-03 00:00:00	\N	M.	Cardon	CARDON	CARDON_Remi	Rémi	\N	\N	72103
20062A	1957-12-28 00:00:00	\N	M.	Somon	SOMON	SOMON_Laurent	Laurent	\N	\N	72104
20066E	1956-01-20 00:00:00	\N	Mme	Jacquemet	JACQUEMET	JACQUEMET_Annick	Annick	\N	\N	72106
20070A	1973-02-09 00:00:00	\N	M.	Cozic	COZIC	COZIC_Thierry	Thierry	\N	\N	72108
20072C	1954-06-28 00:00:00	\N	M.	Guiol	GUIOL	GUIOL_Andre	André	\N	\N	72109
20074E	1965-04-09 00:00:00	\N	Mme	Dumont	DUMONT	DUMONT_Francoise	Françoise	\N	\N	72110
20076G	1951-03-17 00:00:00	\N	M.	Bacci	BACCI	BACCI_Jean	Jean	\N	\N	72111
20078J	1965-04-14 00:00:00	\N	M.	Bonnus	BONNUS	BONNUS_Michel	Michel	\N	\N	72112
20080C	1967-09-04 00:00:00	\N	Mme	Briquet	BRIQUET	BRIQUET_Isabelle	Isabelle	\N	\N	72113
20082E	1959-11-18 00:00:00	\N	M.	Redon-Sarrazy	REDON-SARRAZY	REDON_SARRAZY_Christian	Christian	\N	\N	72114
20088L	1952-11-01 00:00:00	\N	M.	Bouad	BOUAD	BOUAD_Denis	Denis	\N	\N	72117
20090E	1969-02-04 00:00:00	\N	M.	Burgoa	BURGOA	BURGOA_Laurent	Laurent	\N	\N	72118
20092G	1962-10-21 00:00:00	\N	M.	Salmon	SALMON	SALMON_Daniel	Daniel	\N	\N	72119
20096L	1961-11-04 00:00:00	\N	Mme	Muller-Bronn	MULLER-BRONN	MULLER_BRONN_Laurence	Laurence	\N	\N	72121
20098N	1986-12-04 00:00:00	\N	Mme	Schalck	SCHALCK	SCHALCK_Elsa	Elsa	\N	\N	72122
20100N	1961-11-13 00:00:00	\N	M.	Fernique	FERNIQUE	FERNIQUE_Jacques	Jacques	\N	\N	72123
20108W	1973-12-09 00:00:00	\N	M.	Le Rudulier	LE RUDULIER	LE_RUDULIER_Stephane	Stéphane	\N	\N	72127
20110Q	1954-07-25 00:00:00	\N	M.	Benarroche	BENARROCHE	BENARROCHE_Guy	Guy	\N	\N	72128
20112S	1986-03-08 00:00:00	\N	M.	Bacchi	BACCHI	BACCHI_Jeremy	Jérémy	\N	\N	72129
20114U	1973-10-05 00:00:00	\N	M.	Bourgi	BOURGI	BOURGI_Hussein	Hussein	\N	\N	72130
20116W	1955-04-10 00:00:00	\N	M.	Bilhac	BILHAC	BILHAC_Christian	Christian	\N	\N	72131
20120S	1975-03-22 00:00:00	\N	M.	Genet	GENET	GENET_Fabien	Fabien	\N	\N	72133
20122U	1983-08-29 00:00:00	\N	M.	Verzelen	VERZELEN	VERZELEN_Pierre_Jean	Pierre-Jean	\N	\N	72134
20130U	1951-08-01 00:00:00	2020-10-18 00:00:00	Mme	Poncet	PONCET	PONCET_Raymonde	Raymonde	\N	\N	72138
20132W	1957-09-13 00:00:00	\N	M.	Fialaire	FIALAIRE	FIALAIRE_Bernard	Bernard	\N	\N	72139
20134Y	1982-07-28 00:00:00	\N	M.	Dossus	DOSSUS	DOSSUS_Thomas	Thomas	\N	\N	72140
20136B	1970-11-25 00:00:00	\N	M.	Tabarot	TABAROT	TABAROT_Philippe	Philippe	\N	\N	72141
20138D	1981-10-05 00:00:00	\N	Mme	Borchio Fontimp	BORCHIO FONTIMP	BORCHIO_FONTIMP_Alexandra	Alexandra	\N	\N	72142
20140W	1966-09-15 00:00:00	\N	Mme	Demas	DEMAS	DEMAS_Patricia	Patricia	\N	\N	72143
20144B	1958-03-27 00:00:00	\N	M.	Chauvet	CHAUVET	CHAUVET_Patrick	Patrick	\N	\N	72145
20146D	1957-06-28 00:00:00	\N	Mme	Phinera-Horth	PHINERA-HORTH	PHINERA_HORTH_Marie_Laure	Marie-Laure	\N	\N	72161
20148F	1961-01-05 00:00:00	\N	Mme	Petrus	PETRUS	PETRUS_Annick	Annick	\N	\N	72162
20150Y	1975-02-03 00:00:00	\N	M.	Rohfritsch	ROHFRITSCH	ROHFRITSCH_Teva	Teva	\N	\N	72163
20152B	1968-11-23 00:00:00	\N	Mme	Bourrat	BOURRAT	Bourrat_Toine	Toine	\N	\N	72181
20130U	2020-10-19 00:00:00	\N	Mme	Poncet Monge	PONCET MONGE	PONCET_Raymonde	Raymonde	\N	\N	72221
20178M	1950-10-27 00:00:00	\N	M.	Sévêque	SÉVÊQUE	Seveque_Alain	Alain	\N	\N	73181
21038E	2023-09-25 00:00:00	2023-10-04 17:28:43	Mme	Richard	RICHARD	RICHARD_Olivia	Olivia	\N	\N	79061
21085M	2023-09-25 00:00:00	\N	M.	Hochart	HOCHART	HOCHART_Joshua	Joshua	\N	\N	79062
21088Q	2023-09-26 11:24:54	2023-10-02 10:55:31	M.	Brossat	BROSSAT	Brossat_Ian	Ian	\N	\N	79065
21063F	2023-09-26 11:43:52	\N	M.	Bruyen	BRUYEN	Bruyen_Christian	Christian	\N	\N	79066
21035B	2023-09-26 00:00:00	\N	Mme	Bélim	BÉLIM	BELIM_Audrey	Audrey	\N	\N	79068
21045D	2023-09-26 00:00:00	2023-09-27 17:38:23	Mme	Canalès	CANALÈS	CANALES_Marion	Marion	\N	\N	79069
21076L	2023-09-26 00:00:00	\N	M.	Vogel	VOGEL	VOGEL_Louis	Louis	\N	\N	79073
21031W	2023-09-26 00:00:00	\N	M.	Vayssouze-Faure	VAYSSOUZE-FAURE	VAYSSOUZE_FAURE_Jean_Marc	Jean-Marc	\N	\N	79074
21065H	2023-09-26 12:35:48	\N	M.	Chevalier	CHEVALIER	Chevalier_Cédric	Cédric	\N	\N	79075
21091K	2023-09-26 00:00:00	2023-10-09 12:25:53	Mme	Evren	EVREN	EVREN_Agnes	Agnès	\N	\N	79076
21057H	2023-09-26 00:00:00	\N	M.	Chaillou	CHAILLOU	CHAILLOU_Christophe	Christophe	\N	\N	79078
21072G	2023-09-26 00:00:00	\N	Mme	Ciuntu	CIUNTU	CIUNTU_Marie_Carole	Marie-Carole	\N	\N	79079
21051B	2023-09-26 00:00:00	\N	M.	Uzenat	UZENAT	UZENAT_Simon	Simon	\N	\N	79080
21034A	2023-09-26 00:00:00	\N	Mme	Corbière Naminzo	CORBIÈRE NAMINZO	CORBIERE_NAMINZO_Evelyne	Evelyne	\N	\N	79081
21094N	2023-09-26 00:00:00	\N	Mme	Souyris	SOUYRIS	SOUYRIS_Anne	Anne	\N	\N	79082
21067K	2023-09-26 00:00:00	\N	M.	Darras	DARRAS	DARRAS_Jerome	Jérôme	\N	\N	79083
21041Y	2023-09-26 00:00:00	\N	M.	Daubet	DAUBET	DAUBET_Raphael	Raphaël	\N	\N	79084
21049H	2023-09-26 00:00:00	\N	Mme	Silvani	SILVANI	SILVANI_Silvana	Silvana	\N	\N	79085
21093M	2023-09-26 00:00:00	\N	M.	Jadot	JADOT	JADOT_Yannick	Yannick	\N	\N	79086
21059K	2023-09-26 00:00:00	\N	M.	Ros	ROS	ROS_David	David	\N	\N	79087
21062E	2023-09-26 00:00:00	\N	M.	Fagnen	FAGNEN	FAGNEN_Sebastien	Sébastien	\N	\N	79088
21086N	2023-09-26 00:00:00	\N	M.	Fargeot	FARGEOT	FARGEOT_Daniel	Daniel	\N	\N	79090
21070E	2023-09-26 00:00:00	\N	M.	Rochette	ROCHETTE	ROCHETTE_Pierre_Jean	Pierre Jean	\N	\N	79091
21092L	2023-09-26 00:00:00	\N	Mme	Guhl	GUHL	GUHL_Antoinette	Antoinette	\N	\N	79095
21044C	2023-09-26 00:00:00	\N	Mme	Josende	JOSENDE	JOSENDE_Lauriane	Lauriane	\N	\N	79096
21087P	2023-09-26 00:00:00	\N	Mme	Lermytte	LERMYTTE	LERMYTTE_Marie_Claude	Marie-Claude	\N	\N	79097
21054E	2023-09-26 00:00:00	\N	M.	Louault	LOUAULT	LOUAULT_Vincent	Vincent	\N	\N	79098
21055F	2023-09-26 00:00:00	\N	M.	Paumier	PAUMIER	PAUMIER_Jean_Gerard	Jean-Gérard	\N	\N	79099
21075K	2023-09-26 00:00:00	\N	Mme	Margaté	MARGATÉ	MARGATE_Marianne	Marianne	\N	\N	79100
21060C	2023-09-26 00:00:00	\N	M.	Ouizille	OUIZILLE	OUIZILLE_Alexandre	Alexandre	\N	\N	79101
21069M	2023-09-26 00:00:00	\N	M.	Szczurek	SZCZUREK	SZCZUREK_Christopher	Christopher	\N	\N	79103
21064G	2023-09-26 00:00:00	\N	Mme	Romagny	ROMAGNY	ROMAGNY_Anne_Sophie	Anne-Sophie	\N	\N	79104
21061D	2023-09-26 00:00:00	\N	Mme	Valente Le Hir	VALENTE LE HIR	VALENTE_LE_HIR_Sylvie	Sylvie	\N	\N	79105
21096Q	2023-09-26 00:00:00	2023-09-28 17:13:51	M.	Buval	BUVAL	BUVAL_Frederic	Frédéric	\N	\N	79106
21043B	2023-09-26 00:00:00	2023-09-28 17:11:11	M.	Bitz	BITZ	BITZ_Olivier	Olivier	\N	\N	79108
21081H	2023-09-27 00:00:00	\N	M.	Khalifé	KHALIFÉ	KHALIFE_Khalife	Khalifé	\N	\N	79118
21080G	2023-09-27 00:00:00	\N	M.	Michallet	MICHALLET	MICHALLET_Damien	Damien	\N	\N	79112
21042A	2023-09-27 00:00:00	\N	Mme	Antoine	ANTOINE	ANTOINE_Jocelyne	Jocelyne	\N	\N	79113
21058J	2023-09-27 00:00:00	\N	Mme	Martin	MARTIN	MARTIN_Pauline	Pauline	\N	\N	79114
21040X	2023-09-27 00:00:00	\N	M.	Masset	MASSET	MASSET_Michel	Michel	\N	\N	79115
21074J	2023-09-27 00:00:00	\N	M.	Durox	DUROX	DUROX_Aymeric	Aymeric	\N	\N	79116
19331L	2023-09-27 00:00:00	\N	M.	Omar Oili	OMAR OILI	OMAR_OILI_Said	Saïd	\N	\N	79117
21089R	2023-09-26 00:00:00	2023-09-28 17:13:12	Mme	Brossel	BROSSEL	BROSSEL_Colombe	Colombe	\N	\N	79067
21066J	2023-09-26 00:00:00	\N	M.	Grosvalet	GROSVALET	GROSVALET_Philippe	Philippe	\N	\N	79093
21068L	2023-09-26 00:00:00	2023-10-04 17:27:51	M.	Reynaud	REYNAUD	REYNAUD_Herve	Hervé	\N	\N	79094
21039F	2023-09-26 00:00:00	\N	Mme	Nédélec	NÉDÉLEC	Nedelec_Anne_Marie	Anne-Marie	\N	\N	79102
21048G	2023-09-27 00:00:00	2023-09-28 17:11:40	M.	Blanc	BLANC	BLANC_Gregory	Grégory	\N	\N	79111
21045D	2023-09-27 00:00:00	2023-10-03 00:00:00	Mme	CANALÈS	CANALÈS	CANALÈS_Marion	Marion	\N	2023-10-03 00:00:00	79121
21071F	2023-09-28 00:00:00	\N	Mme	Aeschlimann	AESCHLIMANN	AESCHLIMANN_Marie_Do	Marie-Do	\N	\N	79122
21033Y	2023-09-28 00:00:00	\N	M.	Fouassin	FOUASSIN	FOUASSIN_Stephane	Stéphane	\N	\N	79123
21095P	2023-09-28 00:00:00	\N	M.	Szpiner	SZPINER	SZPINER_Francis	Francis	\N	\N	79124
21052C	2023-09-28 00:00:00	\N	M.	Brault	BRAULT	BRAULT_Jean_Luc	Jean-Luc	\N	\N	79125
21029D	2023-09-28 00:00:00	\N	M.	Naturel	NATUREL	NATUREL_Georges	Georges	\N	\N	79126
21037D	2023-09-28 00:00:00	\N	Mme	Ollivier	OLLIVIER	OLLIVIER_Mathilde	Mathilde	\N	\N	79127
21030V	2023-09-28 00:00:00	\N	M.	Xowie	XOWIE	XOWIE_Robert_Wienie	Robert Wienie	\N	\N	79128
21097R	2023-09-28 00:00:00	\N	Mme	Nadille	NADILLE	NADILLE_Solanges	Solanges	\N	\N	79129
21073H	2023-09-28 00:00:00	\N	M.	Mellouli	MELLOULI	MELLOULI_Akli	Akli	\N	\N	79130
21043B	2023-09-28 00:00:00	2023-10-03 00:00:00	M.	BITZ	BITZ	BITZ_Olivier	Olivier	\N	2023-10-03 00:00:00	79133
21048G	2023-09-28 00:00:00	2023-10-03 00:00:00	M.	BLANC	BLANC	BLANC_Grégory	Grégory	\N	2023-10-03 00:00:00	79134
21050A	2023-09-28 00:00:00	2023-10-03 00:00:00	M.	BLEUNVEN	BLEUNVEN	BLEUNVEN_Yves	Yves	\N	2023-10-03 00:00:00	79135
21046E	2023-09-28 00:00:00	\N	Mme	Bourcier	BOURCIER	BOURCIER_Corinne	Corinne	\N	\N	79136
21089R	2023-09-28 00:00:00	2023-10-03 00:00:00	Mme	BROSSEL	BROSSEL	BROSSEL_Colombe	Colombe	\N	2023-10-03 00:00:00	79138
21096Q	2023-09-28 00:00:00	2023-10-03 00:00:00	M.	BUVAL	BUVAL	BUVAL_Frederic	Frédéric	\N	2023-10-03 00:00:00	79139
21032X	2023-09-29 00:00:00	\N	Mme	Girardin	GIRARDIN	GIRARDIN_Annick	Annick	\N	2023-12-11 00:00:00	79140
21056G	2023-09-29 00:00:00	2023-10-02 09:20:00	M.	Roiron	ROIRON	ROIRON_Pierre_Alain	Pierre-Alain	\N	\N	79141
21079P	2023-10-02 00:00:00	\N	Mme	Senée	SENÉE	SENEE_Ghislaine	Ghislaine	\N	\N	79143
14069U	2024-01-15 00:00:00	\N	M.	Bonhomme	BONHOMME	BONHOMME_FRANCOIS	François	2024-01-15 00:00:00	\N	79301
21056G	2023-10-02 00:00:00	2023-10-03 00:00:00	M.	ROIRON	ROIRON	ROIRON_Pierre_Alain	Pierre-Alain	\N	2023-10-03 00:00:00	79145
21088Q	2023-10-02 00:00:00	\N	M.	Brossat	BROSSAT	BROSSAT_Ian	Ian	\N	\N	79146
21047F	2023-10-02 00:00:00	2023-10-03 00:00:00	M.	Pernot	PERNOT	PERNOT_Clement	Clément	\N	2023-10-03 00:00:00	79147
21053D	2023-09-26 00:00:00	\N	M.	Pillefer	PILLEFER	PILLEFER_Bernard	Bernard	\N	\N	79148
19747H	2024-01-30 00:00:00	\N	M.	Bouloux	BOULOUX	BOULOUX_YVES	Yves	2024-01-30 00:00:00	\N	79321
21078N	2023-10-02 00:00:00	\N	M.	Laouedj	LAOUEDJ	LAOUEDJ_Ahmed	Ahmed	\N	\N	79150
21083K	2023-10-02 00:00:00	\N	M.	Cambier	CAMBIER	CAMBIER_Guislain	Guislain	\N	\N	79151
21047F	2023-10-03 00:00:00	\N	M.	Pernot	PERNOT	PERNOT_Clement	Clément	2023-10-03 00:00:00	\N	79152
21036C	2023-10-03 00:00:00	\N	M.	Ruelle	RUELLE	RUELLE JEAN_LUC	Jean-Luc	2023-10-03 00:00:00	\N	79153
21043B	2023-10-03 00:00:00	\N	M.	Bitz	BITZ	BITZ_Olivier	Olivier	2023-10-03 00:00:00	\N	79156
21096Q	2023-10-03 00:00:00	\N	M.	Buval	BUVAL	BUVAL_Frederic	Frédéric	2023-10-03 00:00:00	\N	79157
21089R	2023-10-03 00:00:00	\N	Mme	Brossel	BROSSEL	BROSSEL_Colombe	Colombe	2023-10-03 00:00:00	\N	79158
21045D	2023-10-03 00:00:00	\N	Mme	Canalès	CANALÈS	CANALÈS_Marion	Marion	2023-10-03 00:00:00	\N	79159
21056G	2023-10-03 00:00:00	\N	M.	Roiron	ROIRON	ROIRON_Pierre_Alain	Pierre-Alain	2023-10-03 00:00:00	\N	79160
21050A	2023-10-03 00:00:00	\N	M.	Bleunven	BLEUNVEN	BLEUNVEN_Yves	Yves	2023-10-03 00:00:00	\N	79161
21048G	2023-10-03 00:00:00	\N	M.	Blanc	BLANC	BLANC_Grégory	Grégory	2023-10-03 00:00:00	\N	79164
21084L	2023-09-26 00:00:00	\N	M.	Barros	BARROS	BARROS_Pierre	Pierre	\N	\N	79063
21068L	2023-10-04 00:00:00	\N	M.	Reynaud	REYNAUD	REYNAUD_Herve	Hervé	\N	\N	79182
21038E	2023-10-04 00:00:00	2023-10-05 00:00:00	Mme	RICHARD	RICHARD	RICHARD_Olivia	Olivia	\N	2023-10-05 00:00:00	79183
21038E	2023-10-05 00:00:00	\N	Mme	Richard	RICHARD	RICHARD_Olivia	Olivia	2023-10-05 00:00:00	\N	79187
21091K	2023-10-09 00:00:00	\N	Mme	Evren	EVREN	PRIVAT_DE_FRESSENEL_Agnès	Agnès	\N	2023-10-09 00:00:00	79205
19812Y	1899-12-30 00:50:39	\N	Mme	Constant	CONSTANT	CONSTANT_Agnes	Agnès	\N	\N	57321
19798U	1963-04-19 00:00:00	\N	Mme	Richer	RICHER	RICHER_Marie_Pierre	Marie-Pierre	\N	\N	34901
20248J	1960-03-03 00:00:00	\N	Mme	Devésa	DEVÉSA	Devesa_Brigitte	Brigitte	\N	\N	75241
20180F	1958-03-27 00:00:00	\N	Mme	Gosselin	GOSSELIN	Gosselin	Béatrice	\N	\N	73201
20252E	1957-05-17 00:00:00	\N	M.	Meignen	MEIGNEN	Meignen_Thierry	Thierry	\N	\N	75281
20040T	1950-01-22 00:00:00	\N	M.	Duffourg	DUFFOURG	DUFFOURG_Alain	Alain	\N	\N	72093
21125C	2024-03-26 14:55:25	\N	Mme	Bellamy	BELLAMY	BELLAMY_Marie_Jeanne	Marie-Jeanne	\N	2024-04-02 00:00:00	80321
21082J	2023-09-26 00:00:00	\N	M.	Weber	WEBER	WEBER_Michael	Michaël	\N	\N	79072
20044X	1965-01-29 00:00:00	\N	M.	Sautarel	SAUTAREL	SAUTAREL_Stephane	Stéphane	\N	\N	72095
20176K	1980-11-26 00:00:00	\N	Mme	Blandin	BLANDIN	Blandin_Valerie	Valérie	\N	\N	73161
21050A	2023-09-26 00:00:00	2023-09-28 17:11:58	M.	Bleunven	BLEUNVEN	BLEUNVEN_Yves	Yves	\N	\N	79064
21077M	2023-09-26 00:00:00	\N	M.	Ziane	ZIANE	ZIANE_Adel	Adel	\N	\N	79070
21090J	2023-09-26 00:00:00	\N	Mme	Carrère-Gée	CARRÈRE-GÉE	Carrere_Gee_Marie_Claire	Marie-Claire	\N	\N	79071
20286Q	1976-12-20 00:00:00	\N	Mme	Gacquerre	GACQUERRE	Gacquerre_Amel	Amel	\N	\N	76301
20298U	1972-05-13 00:00:00	\N	Mme	Ract-Madoux	RACT-MADOUX	Ract_Madoux_Daphne	Daphné	\N	\N	76363
19912C	1899-12-30 00:50:39	\N	Mme	Schoeller	SCHOELLER	Schoeller_Noelle	Marie-Noëlle	\N	\N	71541
20914V	1953-02-26 00:00:00	\N	M.	Breuiller	BREUILLER	BREUILLER_Daniel	Daniel	\N	\N	76801
\.


--
-- Data for Name: senurl; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY senurl (senurlid, senmat, typurlcod, senurlurl, evelic, evelib, evelil, eveobs, temvalcod, senurlnumtri, syscredat, sysmajdat) FROM stdin;
77	08033T	BLOG	http://jjmirassou.wordpress.com/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
78	08042U	PAGPER	http://www.louisnegre-senateur.fr/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
79	08013P	PAGPER	http://www.jacqueline-cheve.fr/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
80	08021P	PAGPER	http://www.robert-navarro.fr/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
81	04082L	BLOG	http://www.dominiquevoynet.net/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
82	04074L	BLOG	http://www.huguesportelli.fr/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	2014-10-14 11:58:55
83	01012H	PAGPER	http://www.yves-dauge.com/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
84	01017N	PAGPER	http://christiangaudin.blogspot.com/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
85	01032M	PAGPER	http://www.andre-labarrere.fr/blog/blog.php	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
86	01036R	PAGPER	http://www.michelesanvicentebaudrin.fr/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
87	97004H	PAGPER	http://www.serge-lagauche.fr/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
88	04043D	PAGPER	http://www.catherine-procaccia.com/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	4	\N	2017-09-25 17:52:52
89	04051D	PAGPER	http://www.m-dini-senat.fr/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
90	04053F	PAGPER	http://www.comfinances.fr/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
91	04054G	PAGPER	http://www.michelbillout.fr/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
1146	11077T	FACEBOOK	http://fr-fr.facebook.com/100057733555890	\N	\N	\N	\N	ACTIF	2	\N	2017-09-25 17:47:45
1147	11077T	TWEETER	https://twitter.com/mnlienemann	\N	\N	\N	\N	ACTIF	1	\N	2017-09-25 17:47:44
94	04070G	PAGPER	 https://catherine-morin-desailly.fr	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
95	04086Q	PAGPER	http://www.philippedallier.fr/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	2017-09-25 17:17:30
97	04052E	BLOG	http://www.yannick-bodin.fr	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
98	04063H	PAGPER	http://alima-boumediene.org/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
99	08050U	PAGPER	http://www.bernadette-bourzai.fr/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
100	08068F	PAGPER	https://martialbourquin.fr/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	2017-11-15 13:27:39
101	08055A	PAGPER	http://www.beritdebat2014.fr/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	2017-09-12 16:27:26
102	08060W	PAGPER	http://www.nicole-bonnefoy.com/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
103	08025T	BLOG	http://www.alainanziani.fr/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
104	08061X	PAGPER	http://www.francoispatriat.fr/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	2014-10-14 11:59:42
1145	11077T	PAGPER	http://www.mnlienemann.fr	\N	\N	\N	\N	ACTIF	2	\N	2017-09-25 17:47:43
1148	11054L	PAGPER	http://www.gilbert-roger.fr/	\N	\N	\N	\N	ACTIF	1	\N	2017-09-25 17:53:49
105	08071A	PAGPER	http://www.toofa-tuheiava.org	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
106	08047A	PAGPER	http://www.philippe-paul-senateur.fr/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	2	\N	2013-04-08 16:23:51
107	08037X	PAGPER	http://senateurs-socialistes35.fr/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
108	02053W	BLOG	http://www.chevenement.fr/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
109	08032S	PAGPER	http://senateurs-socialistes35.fr/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
110	02053W	FACEBOOK	http://www.facebook.com/jpchevenement	\N	\N	\N	\N	ACTIF	1	\N	\N
111	02053W	TWEETER	http://twitter.com/chevenement	\N	\N	\N	\N	ACTIF	1	\N	\N
166	08017T	BLOG	http://claudinelepage.eu/	\N	\N	\N	\N	ACTIF	1	\N	\N
167	08017T	FACEBOOK	http://fr-fr.facebook.com/claudinelepage	\N	\N	\N	\N	ACTIF	1	\N	\N
168	08017T	TWEETER	http://twitter.com/claudinelepage	\N	\N	\N	\N	ACTIF	1	\N	\N
301	01057W	BLOG	http://www.charlesguene.fr/	\N	\N	\N	\N	ACTIF	1	\N	2017-09-25 17:41:57
362	07027R	FACEBOOK	http://www.facebook.com/jacques.muller.senateur?ref=profile	\N	\N	\N	\N	ACTIF	1	\N	\N
171	07027R	PAGPER	http://jacquesmuller.fr 	\N	\N	\N	\N	ACTIF	1	\N	\N
173	07027R	FACEBOOK	http://www.facebook.com/home.php?#/pages/Jacques-Muller/116702509971 	\N	\N	\N	\N	ACTIF	1	\N	\N
441	08025T	FACEBOOK	http://fr-fr.facebook.com/people/Alain-Anziani/1522775800	\N	\N	\N	\N	ACTIF	1	\N	\N
465	04061F	TWEETER	http://twitter.com/fabienne_keller	\N	\N	\N	\N	ACTIF	1	\N	\N
581	08057C	BLOG	http://www.yveschastan.fr/	\N	\N	\N	\N	ACTIF	1	\N	\N
601	01053S	PAGPER	http://www.charles-gautier.com/	\N	\N	\N	\N	ACTIF	1	\N	\N
643	08070Y	PAGPER	http://www.francois-rebsamen.info/	\N	\N	\N	\N	ACTIF	1	\N	\N
741	07003H	PAGPER	http://www.senateur-pbr.fr	\N	\N	\N	\N	ACTIF	1	\N	\N
1165	05008E	PAGPER	http://www.philippe-bas.fr/	\N	\N	\N	\N	ACTIF	1	\N	2017-09-25 16:43:17
501	08069G	PAGPER	http://alain-houpert.fr/	\N	\N	\N	\N	ACTIF	4	\N	2016-07-29 14:39:06
542	08018U	FACEBOOK	http://www.facebook.com/100000994813808	\N	\N	\N	\N	ACTIF	1	\N	2014-10-23 17:10:37
721	08009T	FACEBOOK	https://www.facebook.com/100000825785840	\N	\N	\N	\N	ACTIF	2	\N	\N
881	08043V	PAGPER	http://www.maryvonne-blondin.fr/	\N	\N	\N	\N	ACTIF	1	\N	\N
1	77002U	PAGPER	http://www.cfe.fr/pages/cfe/jp-cantegrit.php	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
2	07030L	PAGPER	http://www.raymond-couderc.fr	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
3	95040D	PAGPER	http://www.bernard-joly.com/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
4	95038K	PAGPER	http://www.pierreherisson.fr	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
5	92020L	PAGPER	http://www.josette-durrieu.fr/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
6	86030A	PAGPER	http://www.huberthaenel.com/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
1149	11054L	TWEETER	https://twitter.com/gilbertroger_93?lang=fr	\N	\N	\N	\N	ACTIF	1	\N	2017-09-25 17:53:50
1041	04035D	BLOG	http://www.joellegarriaud.com/	\N	\N	\N	\N	ACTIF	1	\N	2017-09-25 17:38:43
1150	11054L	FACEBOOK	https://www.facebook.com/100057761663967	\N	\N	\N	\N	ACTIF	1	\N	2017-09-25 17:53:49
8	92029V	PAGPER	http://www.alain-lambert.org	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
9	95011X	PAGPER	http://www.nicoleborvo.fr/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
11	95059Q	PAGPER	http://www.carnetjpr.com/carnetjpr/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
12	90004C	PAGPER	http://jp-demerliat.info/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
13	95055L	PAGPER	http://www.jcpeyronnet.info	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
14	95024D	PAGPER	http://www.christian-demuynck.com/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
15	95046K	PAGPER	http://perso.wanadoo.fr/jacques.maheas/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
16	07024N	PAGPER	http://www.jacques-gautier.fr/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
17	77019E	PAGPER	http://www.jpfourcade.fr	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
18	92030N	PAGPER	http://www.dominiqueleclerc.fr/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
19	83031N	PAGPER	http://www.jean-faure.org/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
20	89015P	PAGPER	http://www.jeanbesson.net	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
21	86039K	BLOG	http://www.jean-luc-melenchon.fr/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
22	78006D	PAGPER	http://www.adriengouteyron.fr	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
23	83012K	PAGPER	http://perso.wanadoo.fr/francois.autain/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
25	98012M	PAGPER	http://www.pytremel.com/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
26	98019U	PAGPER	http://www.andre-ferrand.com/index.html	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
27	98021N	PAGPER	http://www.xavierpintat.com/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
28	98022P	BLOG	http://www.jn-guerini.fr/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	2015-11-04 10:39:25
29	98027U	PAGPER	http://www.pierrejarliersenateur.fr/jarlier/index.html	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
30	98029W	PAGPER	http://www.cazeau.eu/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	2017-10-30 14:27:10
121	04034C	PAGPER	http://www.richardyung.fr/	\N	\N	\N	\N	ACTIF	1	\N	\N
241	04047H	PAGPER	http://www.francoisnoelbuffet.com/	\N	\N	\N	\N	ACTIF	1	\N	2014-11-13 17:26:50
681	01005J	PAGPER	http://www.jacquesblanc.fr/	\N	\N	\N	\N	ACTIF	1	\N	\N
841	10003H	BLOG	http://www.ronan-kerdraon.fr/	\N	\N	\N	\N	ACTIF	1	\N	\N
861	08019V	PAGPER	http://www.michelmagras.fr/	\N	\N	\N	\N	ACTIF	1	\N	\N
161	04034C	FACEBOOK	http://www.facebook.com/senateur.richard.yung	\N	\N	\N	\N	ACTIF	1	\N	\N
381	08014Q	PAGPER	http://www.yannickbotrel-senateur.fr/	\N	\N	\N	\N	ACTIF	1	\N	2014-10-14 11:52:11
761	95020Y	PAGPER	http://www.jeanpatrickcourtois.fr/	\N	\N	\N	\N	ACTIF	1	\N	2014-10-14 11:56:22
204	08065C	BLOG	http://www.jean-paul-fournier.com/	\N	\N	\N	\N	ACTIF	1	\N	\N
221	08048B	BLOG	http://brunogilles.typepad.fr/blogbg/	\N	\N	\N	\N	ACTIF	1	\N	\N
223	08022Q	BLOG	http://blogmhde.fr/	\N	\N	\N	\N	ACTIF	1	\N	2014-10-14 11:57:35
461	04061F	BLOG	http://www.fabiennekeller.fr/	\N	\N	\N	\N	ACTIF	1	\N	\N
261	07033P	BLOG	http://www.direct-dumas.fr/	\N	\N	\N	\N	\N	4	\N	2017-09-26 11:01:39
262	07033P	FACEBOOK	http://fr-fr.facebook.com/people/Catherine-Dumas/1000416361	\N	\N	\N	\N	\N	5	\N	2017-09-26 11:01:41
781	01060R	PAGPER	http://www.rasnag-senat.fr/senateursni/cvmasson.htm	\N	\N	\N	\N	ACTIF	1	\N	2017-09-25 17:49:18
421	89015P	FACEBOOK	http://fr-fr.facebook.com/people/Jean-Besson/1155422798	\N	\N	\N	\N	ACTIF	2	\N	\N
422	89015P	TWEETER	http://twitter.com/bessonjean	\N	\N	\N	\N	ACTIF	3	\N	\N
821	04034C	TWEETER	http://twitter.com/SenateurRYung/	\N	\N	\N	\N	ACTIF	1	\N	\N
901	95005A	BLOG	http://blog.jean-paul-amoudry.org/	\N	\N	\N	\N	ACTIF	1	\N	\N
521	83047W	BLOG	http://danielpercheron.fr/	\N	\N	\N	\N	ACTIF	1	\N	2016-10-19 10:56:23
321	02002K	BLOG	http://www.alainfouche.fr/	\N	\N	\N	\N	ACTIF	1	\N	2015-04-08 15:53:01
401	01056V	BLOG	http://andre-trillard.over-blog.com/	\N	\N	\N	\N	ACTIF	1	\N	2017-02-16 15:47:18
661	01061S	PAGPER	http://www.senateur-philippe-leroy.fr/	\N	\N	\N	\N	ACTIF	1	\N	\N
701	08062Y	BLOG	http://leblog.ville-chateauroux.fr/	\N	\N	\N	\N	ACTIF	1	\N	\N
921	10015M	FACEBOOK	http://www.facebook.com/100000728160374	\N	\N	\N	\N	ACTIF	2	\N	2014-10-14 10:09:18
641	01053S	FACEBOOK	http://www.facebook.com/pages/Charles-Gautier/109375705773424?ref=ts	\N	\N	\N	\N	ACTIF	1	\N	\N
1021	01060R	PAGPER	http://www.massonmoselle.fr/	\N	\N	\N	\N	ACTIF	3	\N	2017-09-25 17:49:18
1081	04065K	PAGPER	http://rolandries.eu/	\N	\N	\N	\N	ACTIF	1	\N	\N
1082	04065K	FACEBOOK	https://www.facebook.com/roland.ries.strasbourg	\N	\N	\N	\N	ACTIF	1	\N	2013-06-17 11:35:37
1001	95045J	PAGPER	http://www.jeanlouislorrain.fr/	\N	\N	\N	\N	ACTIF	1	\N	\N
1163	11082Q	FACEBOOK	http://fr-fr.facebook.com/people/Christian-Namy/100001751767803	\N	\N	\N	\N	ACTIF	1	\N	2017-02-27 09:34:16
1170	11070L	PAGPER	http://vincentdelahaye.fr/	\N	\N	\N	\N	ACTIF	1	\N	2017-09-25 17:24:42
1441	01044R	FACEBOOK	http://www.facebook.com/pages/Marie-Christine-Blandin-Sénatrice/164514850245226	\N	\N	\N	\N	ACTIF	1	\N	\N
1442	01044R	TWEETER	http://twitter.com/mcblandin	\N	\N	\N	\N	ACTIF	1	\N	\N
1841	12040W	PAGPER	http://kalliopiangoela.eelv.fr/	\N	\N	\N	\N	ACTIF	1	\N	\N
941	95067Q	PAGPER	http://www.jp-vial.fr/	\N	\N	\N	\N	ACTIF	1	\N	2014-10-14 11:59:17
1241	11055M	BLOG	http://alinearchimbaud.eelv.fr/	\N	\N	\N	\N	ACTIF	1	\N	\N
1242	11055M	TWEETER	http://twitter.com/#!/AlineArchimbaud	\N	\N	\N	\N	ACTIF	1	\N	\N
1243	11055M	FACEBOOK	http://www.facebook.com/pages/Aline-Archimbaud/297507253594760	\N	\N	\N	\N	ACTIF	1	\N	\N
1321	11097X	FACEBOOK	http://www.facebook.com/100003088103076	\N	\N	\N	\N	ACTIF	2	\N	2017-09-25 17:54:28
1561	11099A	FACEBOOK	http://www.facebook.com/100057823881751	\N	\N	\N	\N	ACTIF	2	\N	2017-09-25 17:44:20
1461	09001P	BLOG	http://www.chantaljouanno.fr	\N	\N	\N	\N	ACTIF	1	\N	2017-02-17 12:09:32
1462	09001P	FACEBOOK	http://fr-fr.facebook.com/jouanno.chantal	\N	\N	\N	\N	ACTIF	1	\N	2017-02-17 12:09:33
1463	09001P	TWEETER	http://twitter.com/chantal_jouanno	\N	\N	\N	\N	ACTIF	1	\N	2017-02-17 12:09:34
1801	04040A	BLOG	http://www.jeanmariebockel.fr	\N	\N	\N	\N	ACTIF	1	\N	2013-06-14 17:12:41
1802	04040A	FACEBOOK	http://fr-fr.facebook.com/jeanmarie.bockel	\N	\N	\N	\N	ACTIF	1	\N	\N
1901	98046X	FACEBOOK	https://www.facebook.com/francoismarc.officiel	\N	\N	\N	\N	ACTIF	2	2013-04-08 11:14:25	\N
1861	86034E	BLOG	http://gerardlarcher.fr/	\N	\N	\N	\N	ACTIF	1	\N	2018-02-14 17:27:01
981	98010K	FACEBOOK	http://fr-fr.facebook.com/people/Jean-Pierre-Plancade/100002416394710	\N	\N	\N	\N	ACTIF	1	\N	\N
982	98010K	TWEETER	https://twitter.com/#!/JPPlancade	\N	\N	\N	\N	ACTIF	1	\N	\N
1262	11033F	FACEBOOK	https://www.facebook.com/195853667143729	\N	\N	\N	\N	ACTIF	1	\N	2017-09-25 16:47:21
1361	11026G	PAGPER	http://www.jyleconte.fr/	\N	\N	\N	\N	ACTIF	3	\N	\N
1621	08052W	PAGPER	http://www.yvesdaudigny.com/	\N	\N	\N	\N	ACTIF	1	\N	2015-01-14 16:41:06
1681	04043D	TWEETER	https://twitter.com/CProcaccia	\N	\N	\N	\N	ACTIF	1	\N	2017-09-25 17:52:51
1941	04055H	PAGPER	http://www.serge-dassault.fr/	\N	\N	\N	\N	ACTIF	1	2013-05-17 11:55:22	2017-03-02 14:32:23
1263	11083R	FACEBOOK	http://www.facebook.com/100044353700891	\N	\N	\N	\N	ACTIF	1	\N	2017-09-25 17:39:38
1581	11060J	PAGPER	http://www.natachabouchart.com	\N	\N	\N	\N	ACTIF	1	\N	\N
1061	08023R	PAGPER	http://www.louisconstantfleming.org/	\N	\N	\N	\N	ACTIF	1	\N	\N
1121	04059M	BLOG	http://www.david-assouline.net	\N	\N	\N	\N	ACTIF	1	\N	2017-09-25 16:40:01
1123	04059M	TWEETER	https://twitter.com/dassouline	\N	\N	\N	\N	ACTIF	3	\N	2017-09-25 16:40:02
1124	01044R	PAGPER	http://www.mariechristineblandin.fr/	\N	\N	\N	\N	ACTIF	1	\N	2015-03-26 15:28:05
1125	01059Y	PAGPER	http://www.anniedavid.fr/	\N	\N	\N	\N	ACTIF	1	\N	\N
1126	92018S	PAGPER	http://www.michelledemessine.fr/	\N	\N	\N	\N	ACTIF	1	\N	\N
1127	04079R	BLOG	http://www.rogermadec.fr/	\N	\N	\N	\N	ACTIF	1	\N	\N
1129	04079R	TWEETER	http://twitter.com/rogermadec	\N	\N	\N	\N	ACTIF	1	\N	\N
1401	08024S	PAGPER	http://www.francoisecartron.com	\N	\N	\N	\N	ACTIF	1	\N	2014-10-13 11:59:39
1404	11032E	FACEBOOK	http://www.facebook.com/profile.php?id=100003258944647&sk=wall	\N	\N	\N	\N	ACTIF	1	\N	2017-01-30 09:47:51
961	04089T	PAGPER	http://www.danieldubois.info/	\N	\N	\N	\N	ACTIF	1	\N	2015-04-14 11:18:34
1381	11065P	PAGPER	http://ronandantec.eelv.fr/	\N	\N	\N	\N	ACTIF	1	\N	2017-09-25 17:18:30
1382	11065P	FACEBOOK	https://www.facebook.com/100058201204685	\N	\N	\N	\N	ACTIF	1	\N	2017-09-25 17:18:30
1781	08024S	FACEBOOK	https://www.facebook.com/francoise.cartron	\N	\N	\N	\N	ACTIF	1	\N	\N
2001	08065C	TWEETER	https://twitter.com/j_paulfournier	\N	\N	\N	\N	ACTIF	1	2013-06-06 18:21:43	\N
2002	08065C	FACEBOOK	https://www.facebook.com/JeanPaulFournier30	\N	\N	\N	\N	ACTIF	1	2013-06-06 18:22:22	\N
2021	04040A	TWEETER	https://twitter.com/BockelJeanMarie	\N	\N	\N	\N	ACTIF	1	2013-06-14 16:48:33	\N
2022	11060J	TWEETER	https://twitter.com/NatachaBouchart	\N	\N	\N	\N	ACTIF	1	2013-06-14 16:58:21	2015-02-10 15:27:00
2023	11060J	FACEBOOK	https://www.facebook.com/natacha.bouchart.7	\N	\N	\N	\N	ACTIF	1	2013-06-14 17:16:28	2015-02-10 15:27:14
4510	01043Q	TWEETER	https://twitter.com/valerieletard	\N	\N	\N	\N	\N	1	\N	\N
2041	08018U	TWEETER	https://twitter.com/C_Frassa	\N	\N	\N	\N	ACTIF	1	2013-06-17 09:19:47	\N
2044	08018U	LINKEDIN	http://fr.linkedin.com/in/cfrassa	\N	\N	\N	\N	ACTIF	1	2013-06-17 10:28:56	\N
2051	11044J	PAGPER	http://www.carolinecayeux.com/	\N	\N	\N	\N	ACTIF	1	2013-06-17 11:50:39	2017-02-14 11:31:54
2052	11044J	FACEBOOK	https://www.facebook.com/caroline.cayeux.3	\N	\N	\N	\N	ACTIF	1	2013-06-17 11:50:45	2017-02-14 11:31:53
2053	11044J	FACEBOOK	https://www.facebook.com/caroline.cayeux	\N	\N	\N	\N	ACTIF	1	2013-06-17 11:51:01	2017-02-14 11:31:56
2054	11044J	TWEETER	https://twitter.com/carolinecayeux	\N	\N	\N	\N	ACTIF	1	2013-06-17 11:51:15	2017-02-14 11:31:55
2055	08031R	TWEETER	https://twitter.com/Laborde_Senat	\N	\N	\N	\N	ACTIF	1	2013-06-17 15:45:29	\N
2056	04035D	TWEETER	https://twitter.com/senateurJGM	\N	\N	\N	\N	ACTIF	1	2013-06-17 15:51:36	2017-09-25 17:38:42
2057	04035D	FACEBOOK	https://www.facebook.com/100003704870049	\N	\N	\N	\N	ACTIF	1	2013-06-17 15:52:20	2017-09-25 17:38:46
2061	11014C	FACEBOOK	https://www.facebook.com/danielle.michel.186	\N	\N	\N	\N	ACTIF	1	2013-06-18 15:27:42	\N
2062	11014C	TWEETER	https://twitter.com/danymichelsenat	\N	\N	\N	\N	ACTIF	1	2013-06-18 15:28:02	\N
2063	11032E	TWEETER	https://twitter.com/luccarvounas	\N	\N	\N	\N	ACTIF	1	2013-06-18 16:18:12	2017-01-30 09:47:52
2064	11032E	PAGPER	http://www.luccarvounas.fr/	\N	\N	\N	\N	ACTIF	1	2013-06-18 16:18:30	2014-10-14 11:53:32
2081	11065P	TWEETER	https://twitter.com/RonanDantec	\N	\N	\N	\N	ACTIF	1	2013-06-19 09:04:15	2017-09-25 17:18:29
2101	11066Q	FACEBOOK	https://www.facebook.com/100058094499783/	\N	\N	\N	\N	ACTIF	1	2013-06-19 11:16:07	2017-09-25 17:57:17
2121	11056N	BLOG	http://www.cecile-cukierman.fr	\N	\N	\N	\N	ACTIF	1	2013-06-20 16:59:07	2015-07-08 12:08:25
2122	11056N	TWEETER	https://twitter.com/CecileCukierman	\N	\N	\N	\N	ACTIF	1	2013-06-20 17:02:40	2015-07-08 12:08:27
2123	08025T	TWEETER	https://tw.unblock-us.com/aanziani	\N	\N	\N	\N	ACTIF	1	2013-06-20 17:09:41	\N
2141	92035T	FACEBOOK	https://www.facebook.com/philippe.marini	\N	\N	\N	\N	ACTIF	1	2013-06-25 11:22:05	\N
2142	92035T	TWEETER	https://twitter.com/Philippe_Marini	\N	\N	\N	\N	ACTIF	1	2013-06-25 11:22:11	\N
2143	01007L	FACEBOOK	https://www.facebook.com/pages/Jacqueline-Gourault/197662030388538	\N	\N	\N	\N	ACTIF	1	2013-06-25 15:58:31	2017-01-30 12:07:19
2161	07030L	FACEBOOK	https://www.facebook.com/raymond.couderc	\N	\N	\N	\N	ACTIF	1	2013-06-28 12:02:48	\N
2162	07030L	TWEETER	https://twitter.com/RAYMOND_COUDERC	\N	\N	\N	\N	ACTIF	1	2013-06-28 12:02:59	\N
2201	98035U	TWEETER	https://twitter.com/sutour	\N	\N	\N	\N	ACTIF	1	2013-10-08 16:49:22	\N
2202	98035U	PAGPER	http://simonsutour.fr/	\N	\N	\N	\N	ACTIF	1	2013-10-08 16:49:25	\N
2045	04059M	FACEBOOK	https://www.facebook.com/100057954164798	\N	\N	\N	\N	ACTIF	1	2013-06-17 11:13:38	2017-09-25 16:40:00
2046	08048B	FACEBOOK	https://fr-fr.facebook.com/pages/Bruno-GILLES/232795197899	\N	\N	\N	\N	ACTIF	1	2013-06-17 11:21:17	\N
2047	11015D	FACEBOOK	https://www.facebook.com/gaetan.gorce	\N	\N	\N	\N	ACTIF	1	2013-06-17 11:25:46	2017-01-31 10:21:04
2048	04061F	FACEBOOK	https://fr-fr.facebook.com/fabienne.keller3	\N	\N	\N	\N	ACTIF	1	2013-06-17 11:28:38	2014-10-14 11:54:31
2049	04079R	FACEBOOK	https://www.facebook.com/rogermadec	\N	\N	\N	\N	ACTIF	1	2013-06-17 11:31:46	\N
2182	13003V	PAGPER	http://www.francoiseboog.com	\N	\N	\N	\N	ACTIF	1	2013-09-11 10:23:57	2013-09-11 16:22:58
2183	13003V	FACEBOOK	https://www.facebook.com/francoise.boog	\N	\N	\N	\N	ACTIF	1	2013-09-11 10:24:02	\N
1083	04065K	TWEETER	https://twitter.com/Roland_Ries	\N	\N	\N	\N	ACTIF	1	\N	2013-06-17 11:36:13
1166	11033F	PAGPER	http://estherbenbassa.eelv.fr/	\N	\N	\N	\N	ACTIF	1	\N	2017-09-25 16:49:51
1168	11053K	PAGPER	http://vccblog.typepad.fr/	\N	\N	\N	\N	ACTIF	1	\N	2017-09-25 17:08:30
1169	11027H	PAGPER	http://www.helene-conway.com/	\N	\N	\N	\N	ACTIF	1	\N	2017-09-25 17:16:32
1181	11084S	BLOG	http://www.philippekaltenbach.com/	\N	\N	\N	\N	ACTIF	1	\N	\N
1201	11067R	TWEETER	https://twitter.com/meuniermichelle	\N	\N	\N	\N	ACTIF	1	\N	2017-09-25 17:51:00
1221	08073C	PAGPER	http://www.georgespatient.fr/	\N	\N	\N	\N	ACTIF	3	\N	\N
1281	04067M	PAGPER	http://www.desessard-senateur.org/	\N	\N	\N	\N	ACTIF	1	\N	\N
1301	11067R	FACEBOOK	http://www.facebook.com/ 100003010417030	\N	\N	\N	\N	ACTIF	1	\N	2017-09-25 17:51:01
1341	11094U	PAGPER	http://www.henritandonnet.com	\N	\N	\N	\N	ACTIF	1	\N	2017-01-30 11:47:24
1421	07004J	PAGPER	https://www.nathaliegoulet-senat.fr/	\N	\N	\N	\N	ACTIF	1	\N	2017-09-25 17:40:39
1481	11067R	PAGPER	http://www.michellemeunier.fr	\N	\N	\N	\N	ACTIF	1	\N	2017-09-25 17:51:02
1502	11015D	TWEETER	https://twitter.com/ggorce	\N	\N	\N	\N	ACTIF	1	\N	2017-01-31 10:21:02
1521	08029X	PAGPER	http://www.rolandpovinelli.fr/	\N	\N	\N	\N	ACTIF	1	\N	\N
1541	04086Q	TWEETER	https://twitter.com/#!/philippedallier	\N	\N	\N	\N	ACTIF	1	\N	2017-09-25 17:17:29
1601	10015M	BLOG	http://www.andrereichardt.com	\N	\N	\N	\N	ACTIF	3	\N	2014-10-14 10:09:18
1822	11014C	BLOG	http://www.danielle-michel.fr/	\N	\N	\N	\N	ACTIF	1	\N	\N
1881	98042T	BLOG	http://www.jeanleoncedupont.fr	\N	\N	\N	\N	ACTIF	2	2013-04-04 11:59:24	2013-04-04 12:00:04
1921	11110B	PAGPER	http://www.frederiqueespagnac.com	\N	\N	\N	\N	ACTIF	1	2013-05-13 17:33:51	2017-09-25 17:33:22
1981	11099A	PAGPER	http://www.joellabbe.fr	\N	\N	\N	\N	ACTIF	3	2013-05-24 11:00:41	2017-09-25 17:44:21
1923	11110B	TWEETER	https://twitter.com/FEspagnac	\N	\N	\N	\N	ACTIF	1	2013-05-13 17:34:57	2017-09-25 17:33:20
1961	04087R	PAGPER	http://senateurs-tarn.com/	\N	\N	\N	\N	ACTIF	1	2013-05-17 18:14:59	\N
1962	95052H	PAGPER	http://senateurs-tarn.com/	\N	\N	\N	\N	ACTIF	1	2013-05-17 18:19:21	\N
31	98037W	PAGPER	http://michelteston.typepad.fr/michelteston/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
33	00003C	PAGPER	http://www.clairelisecampion.fr/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	2017-02-21 11:37:21
34	92008Q	PAGPER	http://www.senateursdesfrancaisdumonde.net/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
35	95049N	PAGPER	http://www.senateursudf69.org/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	2014-10-14 12:00:25
36	01010F	BLOG	http://mondialisationloyale.blogspot.com/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
37	01016M	PAGPER	http://www.danielraoul.net/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
38	01022K	PAGPER	http://www.odetteherviaux.fr/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
42	98043U	PAGPER	http://patrick-lassourd.com/index.htm	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
43	98046X	BLOG	http://www.francois-marc.com	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
44	89029V	PAGPER	http://www.jeanclaudegaudin.net/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
45	95023C	PAGPER	http://www.demilly.org/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
46	86047K	PAGPER	http://www.tregouet.org/entre.html	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
47	83042R	PAGPER	http://www.au-service-de-la-moselle.net/site/index.php	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
48	01015L	PAGPER	http://www.evelynedidier.fr	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
50	04038G	PAGPER	http://www.collombat-py.fr/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	2014-11-07 15:29:27
52	04041B	PAGPER	http://www.christianehummel.fr/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
53	04042C	PAGPER	https://christian-cambon.fr	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	2017-12-18 11:06:34
54	04045F	PAGPER	http://www.patricia-schillinger.com/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	4	\N	\N
55	04046G	PAGPER	http://www.christianedemontes.fr/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
56	01013J	PAGPER	http://www.marie-francebeaufils.fr	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
57	98036V	PAGPER	http://www.pierreandre-senateur.com	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
58	97009N	PAGPER	http://www.bernard-angels.fr	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	2	\N	\N
60	95007C	BLOG	http://www.denisbadre.eu/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
141	01026P	PAGPER	http://www.jeanclaude-etienne.fr/	\N	\N	\N	\N	ACTIF	1	\N	\N
281	08045X	PAGPER	http://www.jeanlucfichet.fr/	\N	\N	\N	\N	ACTIF	1	\N	2017-09-28 10:16:26
341	92029V	BLOG	http://www.alain-lambert-blog.org/	\N	\N	\N	\N	ACTIF	1	\N	\N
342	92029V	FACEBOOK	http://www.facebook.com/alainlambert61	\N	\N	\N	\N	ACTIF	1	\N	\N
343	92029V	TWEETER	http://twitter.com/alainlambert	\N	\N	\N	\N	ACTIF	1	\N	\N
481	08054Y	BLOG	http://www.senat03.fr/	\N	\N	\N	\N	ACTIF	1	\N	\N
622	09012S	PAGPER	http://www.reneenicoux.fr/	\N	\N	\N	\N	ACTIF	1	\N	\N
801	83011J	TWEETER	https://twitter.com/JeanArthuis	\N	\N	\N	\N	ACTIF	1	\N	\N
61	01042P	PAGPER	http://jeanrenelecerf.hautetfort.com/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
62	92035T	PAGPER	http://www.philippe-marini.net/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
63	01039U	BLOG	http://www.michel-thiolliere.com	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
64	01040M	PAGPER	http://www.guerry.info	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
65	01047U	BLOG	http://francois-zocchetto.over-blog.com/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	2017-01-30 15:22:54
66	01048V	PAGPER	http://www.gerardlonguet.fr	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	4	\N	2017-09-25 17:48:22
67	01007L	PAGPER	http://www.jgourault.fr/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	2017-01-30 12:07:19
68	01037S	PAGPER	http://perso.wanadoo.fr/jean-claude.frecon/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
69	01028R	PAGPER	http://www.jpsueur.com/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	2017-09-25 17:55:06
1142	11061K	PAGPER	http://cgenisson.unblog.fr/	\N	\N	\N	\N	ACTIF	1	\N	2017-01-30 11:59:44
1143	11015D	BLOG	http://www.gorce.typepad.fr/	\N	\N	\N	\N	ACTIF	1	\N	2017-01-31 10:21:04
73	08022Q	PAGPER	http://mhdesesgaulx.com	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	2014-10-14 11:57:35
1141	11083R	PAGPER	http://andregattolin.eelv.fr/	\N	\N	\N	\N	ACTIF	1	\N	2017-09-25 17:39:36
74	08027V	PAGPER	http://senateurs-socialistes35.fr/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
75	08039A	BLOG	http://www.jpleleux.com/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
76	08031R	PAGPER	http://www.francoiselaborde.fr/	\N	\N	\N	Initialisation depuis SEN le 18/11/2009	ACTIF	1	\N	\N
2221	11083R	TWEETER	https://twitter.com/AndreGattolin	\N	\N	\N	\N	ACTIF	1	2014-01-15 10:41:19	2017-09-25 17:39:33
2222	11083R	TUMBLR	http://arctiquesenateur.tumblr.com/	\N	\N	\N	\N	ACTIF	1	2014-01-15 11:34:38	2017-09-25 17:39:35
2241	98038X	PAGPER	http://www.gerardlecam.fr/	\N	\N	\N	\N	ACTIF	1	2014-02-04 12:17:50	\N
2261	11048N	PAGPER	http://www.jeanfrancoishusson.fr/	\N	\N	\N	\N	\N	4	2014-05-14 10:09:45	2014-05-14 10:10:14
2321	11068S	BLOG	http://www.michelberson.fr	\N	\N	\N	\N	\N	1	2014-10-03 16:04:52	2014-10-03 16:05:11
2301	86034E	TWEETER	https://twitter.com/gerard_larcher	\N	\N	\N	\N	\N	2	2014-10-02 18:34:19	2017-09-25 17:45:24
2322	11068S	FACEBOOK	http://www.facebook.com/michel.berson	\N	\N	\N	\N	\N	2	2014-10-03 16:05:12	2014-10-03 16:05:28
2323	11068S	TWEETER	http://twitter.com/michel_berson	\N	\N	\N	\N	\N	3	2014-10-03 16:05:28	2014-10-06 13:57:39
2341	08024S	TWEETER	https://twitter.com/f_cartron	\N	\N	\N	\N	\N	2	2014-10-13 11:59:33	2014-10-13 11:59:54
2361	11100Y	PAGPER	http://www.jeanclaudelenoir.com/	\N	\N	\N	\N	\N	1	2014-10-15 17:17:58	2017-01-31 10:22:40
2381	11097X	TWEETER	https://twitter.com/renepaulsavary 	\N	\N	\N	\N	\N	1	2014-10-22 10:30:50	2017-09-25 17:54:29
2401	11080N	PAGPER	 http://www.pierrecharon.fr/	\N	\N	\N	\N	\N	1	2014-10-22 17:01:55	2017-09-25 17:15:20
2421	11027H	FACEBOOK	https://www.facebook.com/100058083039806	\N	\N	\N	\N	\N	2	2014-10-22 17:33:40	2017-09-25 17:16:33
2422	11027H	TWEETER	https://twitter.com/hconwaymouret	\N	\N	\N	\N	\N	3	2014-10-22 17:33:49	2017-09-25 17:16:34
2441	99004R	TWEETER	https://twitter.com/Rkaroutchi	\N	\N	\N	\N	\N	1	2014-10-22 17:49:54	2017-09-25 17:43:31
2461	11042G	PAGPER	http://www.jacques-chiron.fr	\N	\N	\N	\N	\N	1	2014-10-23 11:36:12	2014-10-23 11:36:25
2481	11029K	PAGPER	http://www.corinnebouchoux.eelv.fr	\N	\N	\N	\N	\N	1	2014-10-23 15:02:20	2014-10-23 15:02:29
2501	14249W	TWEETER	https://twitter.com/NicoleDuranton	\N	\N	\N	\N	\N	1	2014-10-23 15:52:45	2014-10-23 15:52:51
2521	14211G	BLOG	http://www.jeanpierregrand.fr	\N	\N	\N	\N	\N	1	2014-10-24 10:07:25	2014-10-24 10:10:32
2522	14211G	TWEETER	https://twitter.com/JeanPierreGrand	\N	\N	\N	\N	\N	2	2014-10-24 10:07:58	2014-10-24 10:08:29
2523	14211G	FACEBOOK	https://www.facebook.com/100003784918881	\N	\N	\N	\N	\N	3	2014-10-24 10:08:03	2014-10-24 10:09:19
2542	14169X	FACEBOOK	https://www.facebook.com/100057848477072	\N	\N	\N	\N	\N	2	2014-10-24 12:10:08	2014-10-24 12:10:25
2561	14041T	FACEBOOK	https://fr-fr.facebook.com/jacky.deromedi	\N	\N	\N	\N	\N	1	2014-10-24 16:34:00	2014-10-24 16:34:10
2562	14041T	LINKEDIN	http://sg.linkedin.com/pub/deromedi-jacky/0/4a4/631	\N	\N	\N	\N	\N	2	2014-10-24 16:34:10	2014-10-24 16:34:23
2581	10006L	FACEBOOK	https://www.facebook.com/100011258410215	\N	\N	\N	\N	\N	1	2014-10-27 10:35:44	2018-04-13 11:39:21
2582	11057P	PAGPER	http://www.maurice-vincent.fr	\N	\N	\N	\N	\N	1	2014-10-27 10:43:22	2017-02-01 16:45:05
2583	11057P	TWEETER	https://twitter.com/mauricevincent_	\N	\N	\N	\N	\N	2	2014-10-27 10:43:58	2017-02-01 16:45:05
2601	98042T	TWEETER	https://twitter.com/jldupont14	\N	\N	\N	\N	\N	3	2014-10-27 15:13:55	2014-10-27 15:14:10
2602	98042T	FACEBOOK	https://www.facebook.com/jeanleoncedupont	\N	\N	\N	\N	\N	4	2014-10-27 15:13:57	2014-10-27 15:14:36
2621	11066Q	PAGPER	http://www.yvaugrenard.fr	\N	\N	\N	\N	\N	2	2014-10-28 16:27:47	2017-09-25 17:57:18
2641	01034P	FACEBOOK	https://www.facebook.com/100063610072138	\N	\N	\N	\N	\N	2	2014-10-28 17:17:04	2017-09-25 17:56:29
2661	01007L	TWEETER	https://twitter.com/j_gourault	\N	\N	\N	\N	\N	2	2014-10-31 13:42:35	2017-01-30 12:07:21
2681	14013P	FACEBOOK	https://www.facebook.com/pages/Jean-Pierre-Bosino/1493062714264797	\N	\N	\N	\N	\N	1	2014-11-03 11:37:31	2017-01-30 09:42:06
2682	14013P	TWEETER	https://twitter.com/JPBosino	\N	\N	\N	\N	\N	2	2014-11-03 11:37:41	2017-01-30 09:42:07
2683	14013P	PAGPER	http://jpbosino.wordpress.com/	\N	\N	\N	\N	\N	3	2014-11-03 11:37:55	2017-01-30 09:42:07
2701	04047H	FACEBOOK	https://www.facebook.com/100002970954666	\N	\N	\N	\N	\N	2	2014-11-13 17:26:51	2014-11-13 17:28:01
2702	04047H	TWEETER	https://twitter.com/fnb_officiel	\N	\N	\N	\N	\N	3	2014-11-13 17:27:01	2014-11-13 17:27:16
2721	14087W	PAGPER	http://michelforissier.fr/	\N	\N	\N	\N	\N	1	2014-11-18 15:45:24	2018-04-10 12:25:42
2722	14087W	FACEBOOK	https://www.facebook.com/michel.forissier.69	\N	\N	\N	\N	\N	2	2014-11-18 15:45:56	2014-11-18 15:46:22
2723	14087W	TWEETER	https://twitter.com/michelforissier	\N	\N	\N	\N	\N	3	2014-11-18 15:45:58	2014-11-18 15:46:05
2741	07004J	TWEETER	https://twitter.com/senateur61	\N	\N	\N	\N	\N	2	2014-12-01 18:42:58	2017-09-25 17:40:40
2761	14167V	FACEBOOK	https://www.facebook.com/pages/Jean-Claude-Boulard/409456969208193?ref=aymt_homepage_panel	\N	\N	\N	\N	\N	1	2014-12-04 23:20:12	2014-12-04 23:20:20
2762	14167V	TWEETER	https://twitter.com/J_C_Boulard	\N	\N	\N	\N	\N	2	2014-12-04 23:20:21	2014-12-04 23:20:36
2781	14151M	PAGPER	http://jeromedurain.com/	\N	\N	\N	\N	\N	1	2015-01-14 14:41:19	2015-01-14 14:41:24
2801	14187A	FACEBOOK	https://fr-fr.facebook.com/100044328224592	\N	\N	\N	\N	\N	1	2015-01-14 16:43:22	2015-01-14 16:43:43
2802	14187A	TWEETER	https://twitter.com/dominiq_estrosi	\N	\N	\N	\N	\N	2	2015-01-14 16:43:44	2015-01-14 16:44:22
2841	11089X	BLOG	http://dominiquegillot.com/	\N	\N	\N	\N	\N	1	2015-01-28 11:52:19	2015-01-28 11:52:50
2901	11037K	PAGPER	http://www.renevandierendonck.fr/	\N	\N	\N	\N	\N	1	2015-02-17 15:44:22	2017-02-01 11:29:07
2902	14179A	PAGPER	https://loicherve.fr/	\N	\N	\N	\N	\N	1	2015-02-17 16:04:40	2015-02-17 16:05:14
2903	14179A	FACEBOOK	https://www.facebook.com/100058025893615	\N	\N	\N	\N	\N	2	2015-02-17 16:05:14	2015-02-17 16:05:25
2904	14179A	FACEBOOK	https://www.facebook.com/633789692	\N	\N	\N	\N	\N	3	2015-02-17 16:05:25	2015-02-17 16:05:36
2905	14179A	TWEETER	https://twitter.com/loichervepublic	\N	\N	\N	\N	\N	4	2015-02-17 16:05:36	2015-02-17 16:05:50
2906	14179A	LINKEDIN	https://www.linkedin.com/in/lherve/?originalSubdomain=fr	\N	\N	\N	\N	\N	7	2015-02-17 16:05:50	2015-02-17 16:07:02
2921	98046X	TWEETER	https://twitter.com/FMARC_Senat	\N	\N	\N	\N	\N	3	2015-03-03 15:02:40	2015-03-03 15:02:49
2961	14041T	TWEETER	 https://twitter.com/jacky_deromedi	\N	\N	\N	\N	\N	3	2015-05-06 17:44:20	2015-12-08 17:02:42
2962	14041T	BLOG	http://jackyderomedi.blogspot.sg/	\N	\N	\N	\N	\N	4	2015-05-06 17:46:47	2017-05-22 16:32:19
2981	11114F	PAGPER	http://jacquescornano.com 	\N	\N	\N	\N	\N	1	2015-05-07 14:38:10	2015-05-07 14:38:31
2982	11114F	TWEETER	https://twitter.com/CornanoJacques 	\N	\N	\N	\N	\N	2	2015-05-07 14:38:31	2015-05-07 14:40:40
2983	11114F	PAGPER	https://www.flickr.com/photos/130273576@N06/ 	\N	\N	\N	\N	\N	3	2015-05-07 14:40:41	2015-05-07 14:41:06
3001	04044E	PAGPER	http://www.catherinetroendle.fr/	\N	\N	\N	\N	\N	1	2015-06-03 18:34:05	2015-06-03 18:35:16
3002	04044E	TWEETER	https://twitter.com/C_Troendle	\N	\N	\N	\N	\N	2	2015-06-03 18:34:48	2015-06-03 18:35:23
3021	98029W	FACEBOOK	https://www.facebook.com/bernard.cazeau.5	\N	\N	\N	\N	\N	2	2015-07-08 12:12:54	2017-10-30 14:27:10
3022	98029W	TWEETER	https://twitter.com/bernardcazeau	\N	\N	\N	\N	\N	3	2015-07-08 12:13:08	2017-10-30 14:27:06
3640	19533U	TWEETER	https://twitter.com/StephPiednoir	\N	\N	\N	\N	\N	1	2017-11-10 17:53:12	2017-11-10 17:53:45
3639	19533U	FACEBOOK	https://www.facebook.com/100057733554173	\N	\N	\N	\N	\N	2	2017-11-10 17:52:47	2017-11-10 17:55:38
3647	11043H	PAGPER	http://www.michelsavin.fr	\N	\N	\N	\N	\N	4	2017-11-14 09:46:20	2017-11-14 09:46:37
3648	11043H	FACEBOOK	 https://www.facebook.com/100058189864935	\N	\N	\N	\N	\N	2	2017-11-14 09:46:37	2017-11-14 09:47:01
3649	11043H	TWEETER	https://twitter.com/MichelSavin38	\N	\N	\N	\N	\N	1	2017-11-14 09:47:38	2017-11-14 09:47:55
3660	08016S	FACEBOOK	https://www.facebook.com/DidierGuillaume26/	\N	\N	\N	\N	\N	1	2017-11-14 18:34:30	2017-11-14 18:34:47
3661	08016S	TWEETER	https://twitter.com/dguillaume26	\N	\N	\N	\N	\N	2	2017-11-14 18:34:47	2017-11-14 18:35:57
3741	14115H	PAGPER	http://ambertrand.org	\N	\N	\N	\N	\N	1	2017-12-11 14:45:22	2017-12-11 14:45:38
3761	14327T	PAGPER	http://www.bdelcros-senateur.fr/	\N	\N	\N	\N	\N	1	2018-01-08 19:12:28	2018-01-08 19:12:41
3762	14327T	FACEBOOK	https://www.facebook.com/100008522839242	\N	\N	\N	\N	\N	2	2018-01-08 19:12:42	2018-01-08 19:12:58
3763	14327T	TWEETER	https://twitter.com/bernarddelcros?lang=fr	\N	\N	\N	\N	\N	3	2018-01-08 19:12:58	2018-01-08 19:13:13
4283	20028X	FACEBOOK	https://www.facebook.com/100053924259632	\N	\N	\N	\N	\N	1	\N	\N
4284	20028X	TWEETER	https://twitter.com/MerillouSerge	\N	\N	\N	\N	\N	2	\N	\N
4503	01043Q	PAGPER	https://valerieletard.org/	\N	\N	\N	\N	\N	4	\N	\N
4504	19565D	TWEETER	https://twitter.com/michellegreaume	\N	\N	\N	\N	\N	1	\N	\N
4505	19565D	FACEBOOK	https://www.facebook.com/100064202014423	\N	\N	\N	\N	\N	2	\N	\N
4506	14042U	FACEBOOK	https://www.facebook.com/100057965834085	\N	\N	\N	\N	\N	1	\N	\N
4507	14042U	TWEETER	https://twitter.com/E_Doineau	\N	\N	\N	\N	\N	2	\N	\N
4508	14042U	BLOG	https://elisabethdoineau.wordpress.com/	\N	\N	\N	\N	\N	3	\N	\N
4509	14042U	INSTAGRAM	https://www.instagram.com/elisabeth_doineau/	\N	\N	\N	\N	\N	4	\N	\N
4511	01043Q	FACEBOOK	https://www.facebook.com/100058007233955	\N	\N	\N	\N	\N	2	\N	\N
4755	19747H	TWEETER	https://twitter.com/@YvesBouloux	\N	\N	\N	\N	\N	1	\N	\N
4756	19747H	FACEBOOK	https://www.facebook.com/100057747831763	\N	\N	\N	\N	\N	2	\N	\N
4757	19747H	LINKEDIN	https://www.linkedin.com/in/yves-bouloux-699207117/	\N	\N	\N	\N	\N	3	\N	\N
4758	20114U	TWEETER	https://twitter.com/@husseinbourgi	\N	\N	\N	\N	\N	1	\N	\N
4759	20114U	FACEBOOK	https://www.facebook.com/693945651	\N	\N	\N	\N	\N	2	\N	\N
4760	19383Y	TWEETER	https://twitter.com/@BoyerJ_M	\N	\N	\N	\N	\N	1	\N	\N
4761	17737W	TWEETER	https://twitter.com/@valerieboyer13	\N	\N	\N	\N	\N	1	\N	\N
4762	17737W	FACEBOOK	https://www.facebook.com/100044620530807	\N	\N	\N	\N	\N	2	\N	\N
4763	20080C	TWEETER	https://twitter.com/@IsabelleBrique2	\N	\N	\N	\N	\N	1	\N	\N
4764	20080C	FACEBOOK	https://www.facebook.com/100006997788594	\N	\N	\N	\N	\N	2	\N	\N
4765	19782L	TWEETER	https://twitter.com/@bernard_buis	\N	\N	\N	\N	\N	1	\N	\N
4766	19782L	FACEBOOK	https://www.facebook.com/100008837088741	\N	\N	\N	\N	\N	2	\N	\N
4767	19782L	LINKEDIN	https://www.linkedin.com/in/bernard-buis-59b9a81ba/	\N	\N	\N	\N	\N	3	\N	\N
4768	20090E	FACEBOOK	https://www.facebook.com/1546321676	\N	\N	\N	\N	\N	1	\N	\N
5043	19745F	FACEBOOK	https://www.facebook.com/EvelynePerrotSenatoriales2017	\N	\N	\N	\N	\N	1	\N	\N
4821	11031D	FACEBOOK	https://www.facebook.com/100008964159245	\N	\N	\N	\N	\N	2	\N	\N
5044	14193X	TWEETER	https://twitter.com/cperrin90	\N	\N	\N	\N	\N	1	\N	\N
5045	14193X	FACEBOOK	https://www.facebook.com/100063778643519	\N	\N	\N	\N	\N	2	\N	\N
5046	14193X	LINKEDIN	https://www.linkedin.com/in/cedric-perrin-0ab71576/	\N	\N	\N	\N	\N	3	\N	\N
5047	14193X	PAGPER	http://www.cedricperrin.fr	\N	\N	\N	\N	\N	4	\N	\N
5048	17637T	TWEETER	https://twitter.com/PhilippePemezec	\N	\N	\N	\N	\N	1	\N	\N
5049	17637T	FACEBOOK	https://www.facebook.com/100057858920677	\N	\N	\N	\N	\N	2	\N	\N
5052	14237S	FACEBOOK	https://www.facebook.com/100058283252790	\N	\N	\N	\N	\N	2	\N	\N
5051	14237S	TWEETER	https://twitter.com/CyrilPellevat	\N	\N	\N	\N	\N	1	\N	\N
5053	14237S	LINKEDIN	https://www.linkedin.com/in/cyril-pellevat-572bb93/	\N	\N	\N	\N	\N	3	\N	\N
5134	14205J	TWEETER	https://twitter.com/ac_loisier	\N	\N	\N	\N	\N	1	\N	\N
5135	14205J	FACEBOOK	https://www.facebook.com/100058276531132	\N	\N	\N	\N	\N	2	\N	\N
5136	14205J	LINKEDIN	https://www.linkedin.com/in/anne-catherine-loisier-845251103/	\N	\N	\N	\N	\N	3	\N	\N
5137	19581D	FACEBOOK	https://www.facebook.com/100004608904523	\N	\N	\N	\N	\N	1	\N	\N
5140	19697Q	FACEBOOK	https://www.facebook.com/100057916635915	\N	\N	\N	\N	\N	2	\N	\N
5139	19697Q	TWEETER	https://twitter.com/LevrierMartin	\N	\N	\N	\N	\N	1	\N	\N
5141	19697Q	LINKEDIN	https://www.linkedin.com/in/martin-l%C3%A9vrier-5a867926/	\N	\N	\N	\N	\N	3	\N	\N
5142	20052X	TWEETER	https://twitter.com/PALevisenat	\N	\N	\N	\N	\N	1	\N	\N
5143	20052X	FACEBOOK	https://www.facebook.com/100063970422324	\N	\N	\N	\N	\N	2	\N	\N
5144	01043Q	LINKEDIN	https://www.linkedin.com/in/val%C3%A9rie-l%C3%A9tard-16a0a5167/	\N	\N	\N	\N	\N	3	\N	\N
5145	19729F	TWEETER	https://twitter.com/senateurleroy	\N	\N	\N	\N	\N	1	\N	\N
5146	19729F	FACEBOOK	https://www.facebook.com/100000124342640	\N	\N	\N	\N	\N	2	\N	\N
5149	11026G	FACEBOOK	https://www.facebook.com/100003082008013	\N	\N	\N	\N	\N	2	\N	\N
5150	20108W	TWEETER	https://twitter.com/slerudulier	\N	\N	\N	\N	\N	1	\N	\N
5151	20108W	FACEBOOK	https://www.facebook.com/1662971306	\N	\N	\N	\N	\N	2	\N	\N
5152	16685X	LINKEDIN	https://www.linkedin.com/in/jacques-le-nay-59602414a/	\N	\N	\N	\N	\N	3	\N	\N
5153	18193Q	TWEETER	https://twitter.com/LeHouerouA	\N	\N	\N	\N	\N	1	\N	\N
5154	18193Q	FACEBOOK	https://www.facebook.com/100057838970118	\N	\N	\N	\N	\N	2	\N	\N
5157	19709B	FACEBOOK	https://www.facebook.com/717598083	\N	\N	\N	\N	\N	2	\N	\N
5156	19709B	TWEETER	https://twitter.com/ronan_legleut	\N	\N	\N	\N	\N	1	\N	\N
5158	19709B	LINKEDIN	https://www.linkedin.com/in/ronanlegleut/	\N	\N	\N	\N	\N	3	\N	\N
5195	19611R	FACEBOOK	https://www.facebook.com/ 100058103108525	\N	\N	\N	\N	\N	2	\N	\N
5196	19611R	LINKEDIN	https://www.linkedin.com/in/laurent-lafon-89b78a127/	\N	\N	\N	\N	\N	3	\N	\N
5198	11099A	TWEETER	https://twitter.com/JLabbeSenat	\N	\N	\N	\N	\N	1	\N	\N
5201	20016T	FACEBOOK	https://www.facebook.com/100064514996694	\N	\N	\N	\N	\N	2	\N	\N
5202	20016T	LINKEDIN	https://www.linkedin.com/in/mikaele-kulimoetoke-77b21162/	\N	\N	\N	\N	\N	3	\N	\N
5203	19489J	TWEETER	https://twitter.com/EricKerrouche	\N	\N	\N	\N	\N	1	\N	\N
5204	19489J	FACEBOOK	https://www.facebook.com/752244486	\N	\N	\N	\N	\N	2	\N	\N
5205	19489J	LINKEDIN	https://www.linkedin.com/in/eric-kerrouche-18b5b536/	\N	\N	\N	\N	\N	3	\N	\N
5210	14021P	TWEETER	https://twitter.com/PatrickKanner	\N	\N	\N	\N	\N	1	\N	\N
5207	99004R	FACEBOOK	https://www.facebook.com/564970768	\N	\N	\N	\N	\N	2	\N	\N
5211	14021P	FACEBOOK	https://www.facebook.com/100057824419392	\N	\N	\N	\N	\N	2	\N	\N
5216	95041E	FACEBOOK	https://www.facebook.com/100058280671994	\N	\N	\N	\N	\N	2	\N	\N
5215	95041E	TWEETER	https://twitter.com/AJoyandet	\N	\N	\N	\N	\N	1	\N	\N
5225	20056C	TWEETER	https://twitter.com/@ElseJOSEPH	\N	\N	\N	\N	\N	1	\N	\N
5221	19447X	FACEBOOK	https://www.facebook.com/100057969106426	\N	\N	\N	\N	\N	1	\N	\N
5227	19599P	FACEBOOK	https://www.facebook.com/100009996365012	\N	\N	\N	\N	\N	2	\N	\N
5228	17023S	TWEETER	https://twitter.com/philippefolliot	\N	\N	\N	\N	\N	1	\N	\N
5229	17023S	FACEBOOK	https://www.facebook.com/100057752665348	\N	\N	\N	\N	\N	2	\N	\N
5230	20056C	FACEBOOK	https://www.facebook.com/649413515	\N	\N	\N	\N	\N	2	\N	\N
3041	14265W	FACEBOOK	https://www.facebook.com/pages/S%C3%A9natrice-Patricia-Morhet-Richaud/941337435897393	\N	\N	\N	\N	\N	1	2015-09-09 10:29:09	2015-09-09 10:32:55
3042	14265W	TWEETER	https://twitter.com/MorhetRichaud	\N	\N	\N	\N	\N	2	2015-09-09 10:32:56	2015-09-09 10:34:52
3281	86044G	FACEBOOK	https://www.facebook.com/henri.deraincourt	\N	\N	\N	\N	\N	1	2016-03-07 15:11:35	2016-03-07 15:11:47
3621	14159V	PAGPER	http://www.bernardlalande.fr	\N	\N	\N	\N	\N	1	2017-11-08 16:18:04	2017-11-08 16:25:00
3622	14159V	FACEBOOK	http://www.facebook.com/senateurLalandeBernard/	\N	\N	\N	\N	\N	2	2017-11-08 16:18:12	2017-11-08 16:25:01
3623	14159V	TWEETER	http://www.twitter.com/LalandeBernard	\N	\N	\N	\N	\N	3	2017-11-08 16:18:20	2017-11-08 16:25:03
4123	19820Y	PAGPER	http://herve-gille.fr/	\N	\N	\N	\N	\N	4	\N	\N
4303	20062A	TWEETER	https://twitter.com/Laurent_Somon	\N	\N	\N	\N	\N	1	\N	\N
4304	20062A	FACEBOOK	https://www.facebook.com/100000148684432	\N	\N	\N	\N	\N	2	\N	\N
4443	20152B	TWEETER	https://twitter.com/ToineBourrat	\N	\N	\N	\N	\N	1	\N	\N
4583	16685X	PAGPER	http://jacques-lenay.com/index.php	\N	\N	\N	\N	\N	4	\N	\N
4584	16685X	FACEBOOK	http://www.facebook.com/100022858112456	\N	\N	\N	\N	\N	2	\N	\N
4585	16685X	TWEETER	http://twitter.com/JacquesLeNay	\N	\N	\N	\N	\N	1	\N	\N
4603	20096L	PAGPER	https://www.muller-bronn.fr	\N	\N	\N	\N	\N	1	\N	\N
4770	14207L	TWEETER	https://twitter.com/@senateurcabanel	\N	\N	\N	\N	\N	2	\N	\N
4771	14207L	FACEBOOK	https://www.facebook.com/100007414273615	\N	\N	\N	\N	\N	3	\N	\N
4772	20104S	TWEETER	https://twitter.com/@AlainCadec	\N	\N	\N	\N	\N	1	\N	\N
4773	20104S	FACEBOOK	https://www.facebook.com/100058060989555	\N	\N	\N	\N	\N	2	\N	\N
4774	14255U	TWEETER	https://twitter.com/@OlivierCadic	\N	\N	\N	\N	\N	1	\N	\N
4775	14255U	FACEBOOK	https://www.facebook.com/727383815	\N	\N	\N	\N	\N	2	\N	\N
4776	14255U	LINKEDIN	https://www.linkedin.com/in/olivier-cadic-6941562a/	\N	\N	\N	\N	\N	3	\N	\N
4777	11101A	TWEETER	https://twitter.com/@CalvetFrancois	\N	\N	\N	\N	\N	1	\N	\N
4778	11101A	FACEBOOK	https://www.facebook.com/100057732744170	\N	\N	\N	\N	\N	2	\N	\N
4779	04042C	TWEETER	https://twitter.com/@ChCambon	\N	\N	\N	\N	\N	2	\N	\N
4780	04042C	FACEBOOK	https://www.facebook.com/100008031431478	\N	\N	\N	\N	\N	3	\N	\N
4781	04042C	LINKEDIN	https://www.linkedin.com/search/results/all/?keywords=christian%20cambon&origin=RICH_QUERY_SUGGESTION&position=0&searchId=474f809b-4870-4f82-87cd-0472aa063e99	\N	\N	\N	\N	\N	4	\N	\N
4782	14053L	TWEETER	https://twitter.com/@ACanayer	\N	\N	\N	\N	\N	1	\N	\N
4783	14053L	FACEBOOK	https://www.facebook.com/1176894978	\N	\N	\N	\N	\N	2	\N	\N
4784	14053L	LINKEDIN	https://www.linkedin.com/in/agn%C3%A8s-canayer-s%C3%A9nat/	\N	\N	\N	\N	\N	3	\N	\N
4785	11053K	TWEETER	https://twitter.com/@Capo_Canellas	\N	\N	\N	\N	\N	2	\N	\N
4786	11053K	FACEBOOK	https://www.facebook.com/100058022561111	\N	\N	\N	\N	\N	3	\N	\N
4787	14083S	TWEETER	https://twitter.com/@michelcanevet	\N	\N	\N	\N	\N	1	\N	\N
4788	14083S	FACEBOOK	https://www.facebook.com/100057747502905	\N	\N	\N	\N	\N	2	\N	\N
4789	14083S	LINKEDIN	https://www.linkedin.com/in/michel-canevet-134b0a60/	\N	\N	\N	\N	\N	3	\N	\N
4790	19545Y	TWEETER	https://twitter.com/@EmmanuelCapus	\N	\N	\N	\N	\N	1	\N	\N
4791	19545Y	FACEBOOK	https://www.facebook.com/100057731692439	\N	\N	\N	\N	\N	2	\N	\N
4792	20060X	TWEETER	https://twitter.com/@Cardon_Remi	\N	\N	\N	\N	\N	1	\N	\N
4793	20060X	FACEBOOK	https://www.facebook.com/1259946388	\N	\N	\N	\N	\N	2	\N	\N
4794	20060X	LINKEDIN	https://www.linkedin.com/in/r%C3%A9mi-cardon-7a82748a/	\N	\N	\N	\N	\N	3	\N	\N
4796	12028B	TWEETER	https://twitter.com/@MACarlotti	\N	\N	\N	\N	\N	1	\N	\N
4800	19721W	TWEETER	https://twitter.com/@ACazabonne	\N	\N	\N	\N	\N	1	\N	\N
4798	12028B	LINKEDIN	https://www.linkedin.com/in/marie-arlette-carlotti-1150a4170/	\N	\N	\N	\N	\N	3	\N	\N
4799	19629C	FACEBOOK	https://www.facebook.com/100057856818295	\N	\N	\N	\N	\N	1	\N	\N
4801	19721W	FACEBOOK	https://www.facebook.com/1844025768	\N	\N	\N	\N	\N	2	\N	\N
4802	19721W	LINKEDIN	https://www.linkedin.com/in/alain-cazabonne-385b96201/	\N	\N	\N	\N	\N	3	\N	\N
4803	19057M	TWEETER	https://twitter.com/@scazebonne	\N	\N	\N	\N	\N	1	\N	\N
4804	19057M	FACEBOOK	https://www.facebook.com/100022593913067	\N	\N	\N	\N	\N	2	\N	\N
4805	19057M	LINKEDIN	https://www.linkedin.com/in/samantha-cazebonne-s%C3%A9natrice-74098015b/	\N	\N	\N	\N	\N	3	\N	\N
4806	14329V	TWEETER	https://twitter.com/@anne_chain	\N	\N	\N	\N	\N	1	\N	\N
4807	14329V	FACEBOOK	https://www.facebook.com/100032666798399	\N	\N	\N	\N	\N	2	\N	\N
4808	14038Y	LINKEDIN	https://www.linkedin.com/search/results/all/?keywords=patrick%20chaize&origin=RICH_QUERY_SUGGESTION&position=0&searchId=4c2d5105-fb1d-487e-9522-9fbb3b6dd849	\N	\N	\N	\N	\N	4	\N	\N
4809	20264J	FACEBOOK	https://www.facebook.com/100001635230244	\N	\N	\N	\N	\N	2	\N	\N
4810	20264J	LINKEDIN	https://www.linkedin.com/in/yan-chantrel-80aa6267/	\N	\N	\N	\N	\N	3	\N	\N
4811	11080N	TWEETER	https://twitter.com/@pierrecharon	\N	\N	\N	\N	\N	2	\N	\N
4812	11080N	FACEBOOK	https://www.facebook.com/100057336428718	\N	\N	\N	\N	\N	3	\N	\N
4814	19467C	TWEETER	https://twitter.com/@ChauvinMcm	\N	\N	\N	\N	\N	1	\N	\N
4815	19467C	FACEBOOK	https://www.facebook.com/1804959622	\N	\N	\N	\N	\N	2	\N	\N
4816	18083K	TWEETER	https://twitter.com/@gchevrollier	\N	\N	\N	\N	\N	1	\N	\N
4817	18083K	FACEBOOK	https://www.facebook.com/100058218183022	\N	\N	\N	\N	\N	2	\N	\N
4818	14267Y	FACEBOOK	https://www.facebook.com/100010059766794	\N	\N	\N	\N	\N	1	\N	\N
4819	11031D	TWEETER	https://twitter.com/@LaurenceCohen94	\N	\N	\N	\N	\N	1	\N	\N
4823	19295A	FACEBOOK	https://www.facebook.com/1810548402	\N	\N	\N	\N	\N	2	\N	\N
4822	19295A	TWEETER	https://twitter.com/CConconne	\N	\N	\N	\N	\N	1	\N	\N
4824	19295A	LINKEDIN	https://www.linkedin.com/in/catherine-conconne-1a282b124/	\N	\N	\N	\N	\N	3	\N	\N
4825	11027H	LINKEDIN	https://www.linkedin.com/in/h%C3%A9l%C3%A8ne-conway-mouret-283703a3/	\N	\N	\N	\N	\N	4	\N	\N
4828	19681G	FACEBOOK	https://www.facebook.com/100004830727552	\N	\N	\N	\N	\N	1	\N	\N
4829	19681G	LINKEDIN	https://www.linkedin.com/in/jean-pierre-corbisez-011906165/	\N	\N	\N	\N	\N	2	\N	\N
4830	11115U	TWEETER	https://twitter.com/EdouardCourtial	\N	\N	\N	\N	\N	1	\N	\N
4831	11115U	FACEBOOK	https://www.facebook.com/100058240384691	\N	\N	\N	\N	\N	2	\N	\N
4832	11115U	LINKEDIN	https://www.linkedin.com/in/%C3%A9douard-courtial-5636507a/	\N	\N	\N	\N	\N	3	\N	\N
4833	11056N	FACEBOOK	https://www.facebook.com/100000426845158	\N	\N	\N	\N	\N	2	\N	\N
4834	11056N	LINKEDIN	https://www.linkedin.com/in/cecile-cukierman-035b708b/	\N	\N	\N	\N	\N	3	\N	\N
4837	14357A	TWEETER	https://twitter.com/PierreCuypers77	\N	\N	\N	\N	\N	1	\N	\N
4838	14357A	FACEBOOK	https://www.facebook.com/100021969314976	\N	\N	\N	\N	\N	2	\N	\N
4839	14357A	LINKEDIN	https://www.linkedin.com/in/pierre-cuypers-640701166/	\N	\N	\N	\N	\N	3	\N	\N
4843	19525U	FACEBOOK	https://www.facebook.com/100008714986407	\N	\N	\N	\N	\N	1	\N	\N
4844	19693L	TWEETER	https://twitter.com/LDarcos	\N	\N	\N	\N	\N	1	\N	\N
4845	19693L	FACEBOOK	https://www.facebook.com/100009109571748	\N	\N	\N	\N	\N	2	\N	\N
4846	19693L	LINKEDIN	https://www.linkedin.com/in/laure-darcos-b4bbb3a3/	\N	\N	\N	\N	\N	3	\N	\N
4859	14259Y	TWEETER	https://twitter.com/mathdarnaud	\N	\N	\N	\N	\N	1	\N	\N
4860	14259Y	FACEBOOK	https://www.facebook.com/799474691	\N	\N	\N	\N	\N	2	\N	\N
5463	19591F	PAGPER	http://www.senat.fr/	\N	\N	\N	\N	\N	5	\N	\N
3301	14121F	TWEETER	https://twitter.com/ejeansannetas	\N	\N	\N	\N	\N	1	2016-03-11 10:04:04	2016-03-11 10:04:17
3302	14121F	FACEBOOK	https://www.facebook.com/100057907155185	\N	\N	\N	\N	\N	2	2016-03-11 10:04:19	2016-04-07 17:15:30
3321	04095R	FACEBOOK	https://www.facebook.com/jacquesgillotofficiel	\N	\N	\N	\N	\N	1	2016-03-16 09:47:33	2016-03-16 09:47:39
3461	11090Q	PAGPER	http://sophieprimas.fr/	\N	\N	\N	\N	\N	3	2016-10-06 11:43:06	2017-09-25 17:52:04
3462	11090Q	FACEBOOK	https://www.facebook.com/100042666172565	\N	\N	\N	\N	\N	2	2016-10-06 11:43:18	2017-09-25 17:52:05
3463	11090Q	TWEETER	https://twitter.com/sophieprimas	\N	\N	\N	\N	\N	1	2016-10-06 11:43:31	2017-09-25 17:52:06
3481	14169X	PAGPER	http://www.ljdenicolay.com/	\N	\N	\N	\N	\N	3	2016-10-13 09:39:09	2016-10-13 09:39:28
3541	14097Y	PAGPER	http://gisele-jourda.fr/	\N	\N	\N	\N	\N	1	2017-01-19 16:44:11	2017-01-23 12:14:57
3542	14097Y	TWEETER	https://twitter.com/GiseleJourda	\N	\N	\N	\N	\N	2	2017-01-19 16:44:21	2017-01-19 16:45:27
3543	14097Y	FACEBOOK	https://www.facebook.com/100058003124263	\N	\N	\N	\N	\N	3	2017-01-19 16:45:25	2017-01-19 16:46:38
3625	14257W	PAGPER	http://www.franckmontauge.fr	\N	\N	\N	\N	\N	2	2017-11-09 10:12:49	2017-11-09 11:13:15
3626	14081Q	PAGPER	https://www.annieguillemot.fr/	\N	\N	\N	\N	\N	1	2017-11-09 10:57:48	2017-11-09 10:58:01
3629	14195A	TWEETER	https://twitter.com/@DanielChasseing	\N	\N	\N	\N	\N	2	2017-11-09 11:09:35	2017-11-09 11:09:55
3628	14195A	FACEBOOK	https://www.facebook.com/100057799342101	\N	\N	\N	\N	\N	1	2017-11-09 11:09:08	2017-11-09 11:09:35
3634	14215L	PAGPER	http://www.catherinedifolco.com/	\N	\N	\N	\N	\N	1	2017-11-10 12:59:33	2017-11-10 12:59:39
4861	04008A	TWEETER	https://twitter.com/DAUBRESSE_MP	\N	\N	\N	\N	\N	1	\N	\N
3636	01028R	FACEBOOK	https://www.facebook.com/100058278721071	\N	\N	\N	\N	\N	3	2017-11-10 17:47:49	2017-11-10 17:47:59
3637	01028R	TWEETER	https://twitter.com/JP_Sueur	\N	\N	\N	\N	\N	4	2017-11-10 17:47:59	2017-11-10 17:48:08
3638	11085T	TWEETER	https://twitter.com/hervemarseille?lang=fr	\N	\N	\N	\N	\N	1	2017-11-10 17:51:32	2017-11-10 17:53:24
3665	08068F	TWEETER	https://twitter.com/bourquinmartial?lang=fr	\N	\N	\N	\N	\N	3	2017-11-15 13:27:58	2017-11-15 13:28:21
3664	08068F	FACEBOOK	https://www.facebook.com/martial.bourquin.3	\N	\N	\N	\N	\N	2	2017-11-15 13:27:20	2017-11-15 13:47:02
3666	14073Q	FACEBOOK	https://www.facebook.com/606424719	\N	\N	\N	\N	\N	2	2017-11-15 13:53:40	2017-11-15 13:53:51
3667	14073Q	TWEETER	https://twitter.com/claude_kern	\N	\N	\N	\N	\N	1	2017-11-15 13:53:52	2017-11-15 13:54:03
4023	19349W	PAGPER	https://www.didier-rambaud.fr/	\N	\N	\N	\N	\N	3	\N	\N
4163	19399H	FACEBOOK	https://www.facebook.com/100058110818127	\N	\N	\N	\N	\N	2	\N	\N
4164	19399H	TWEETER	https://twitter.com/jrhugonet	\N	\N	\N	\N	\N	1	\N	\N
4862	04008A	FACEBOOK	https://www.facebook.com/100057941235895	\N	\N	\N	\N	\N	2	\N	\N
4866	19543W	FACEBOOK	https://www.facebook.com/100001608600835	\N	\N	\N	\N	\N	1	\N	\N
4867	19543W	LINKEDIN	https://www.linkedin.com/in/arnaud-de-belenet-395204206/	\N	\N	\N	\N	\N	2	\N	\N
4871	19701S	LINKEDIN	https://www.linkedin.com/in/marta-de-cidrac-965a80/	\N	\N	\N	\N	\N	4	\N	\N
4879	19649G	TWEETER	https://twitter.com/mpdelagontrie	\N	\N	\N	\N	\N	1	\N	\N
4881	19649G	FACEBOOK	https://www.facebook.com/100057907605082	\N	\N	\N	\N	\N	2	\N	\N
4884	19735D	TWEETER	https://twitter.com/SoniadlpCaen	\N	\N	\N	\N	\N	1	\N	\N
4885	19735D	FACEBOOK	https://www.facebook.com/1407204158	\N	\N	\N	\N	\N	2	\N	\N
4886	08034U	TWEETER	https://twitter.com/Domdelegge	\N	\N	\N	\N	\N	1	\N	\N
4887	08034U	FACEBOOK	https://www.facebook.com/100058314511627	\N	\N	\N	\N	\N	2	\N	\N
4891	20142Y	TWEETER	https://twitter.com/moniquedemarco	\N	\N	\N	\N	\N	1	\N	\N
4892	20142Y	FACEBOOK	https://www.facebook.com/1016890097	\N	\N	\N	\N	\N	2	\N	\N
4893	20142Y	LINKEDIN	https://www.linkedin.com/search/results/all/?keywords=monique%20de%20marco&origin=RICH_QUERY_SUGGESTION&position=0&searchId=f2074b39-b125-43e1-b2b2-758cec2d10a0	\N	\N	\N	\N	\N	3	\N	\N
4896	08011M	FACEBOOK	https://www.facebook.com/100057823849689	\N	\N	\N	\N	\N	2	\N	\N
4901	14169X	LINKEDIN	https://www.linkedin.com/search/results/all/?keywords=louis-jean%20de%20nicolay&origin=RICH_QUERY_SUGGESTION&position=0&searchId=6ae2e616-35c4-4add-83dc-d5d412ca3394	\N	\N	\N	\N	\N	5	\N	\N
4902	17589D	TWEETER	https://twitter.com/jpdecool	\N	\N	\N	\N	\N	1	\N	\N
4903	17589D	FACEBOOK	https://www.facebook.com/100058188184628	\N	\N	\N	\N	\N	2	\N	\N
4904	11070L	TWEETER	https://twitter.com/V_Delahaye	\N	\N	\N	\N	\N	2	\N	\N
4905	11070L	FACEBOOK	https://www.facebook.com/100058013440369	\N	\N	\N	\N	\N	3	\N	\N
4906	11070L	LINKEDIN	https://www.linkedin.com/in/vincent-delahaye-b3aa8130/	\N	\N	\N	\N	\N	4	\N	\N
4909	19719D	LINKEDIN	https://www.linkedin.com/in/nathalie-delattre-a8243b18/	\N	\N	\N	\N	\N	4	\N	\N
4913	19663E	TWEETER	https://twitter.com/SenatriceADK	\N	\N	\N	\N	\N	1	\N	\N
4915	19663E	FACEBOOK	https://www.facebook.com/100065173325280	\N	\N	\N	\N	\N	2	\N	\N
4921	20140W	TWEETER	https://twitter.com/demas_patricia	\N	\N	\N	\N	\N	1	\N	\N
4922	20140W	FACEBOOK	https://www.facebook.com/100055526785139	\N	\N	\N	\N	\N	2	\N	\N
4925	17229F	FACEBOOK	https://www.facebook.com/1684842056	\N	\N	\N	\N	\N	1	\N	\N
4926	19659J	FACEBOOK	https://www.facebook.com/100005242597353	\N	\N	\N	\N	\N	1	\N	\N
4928	10006L	LINKEDIN	https://www.linkedin.com/in/catherine-deroche-60ab7b53/	\N	\N	\N	\N	\N	3	\N	\N
4930	14217N	FACEBOOK	https://www.facebook.com/100025503286241	\N	\N	\N	\N	\N	2	\N	\N
4934	01024M	TWEETER	https://twitter.com/YvesDetraigne	\N	\N	\N	\N	\N	2	\N	\N
4936	20248J	FACEBOOK	https://www.facebook.com/100001565787892	\N	\N	\N	\N	\N	1	\N	\N
5170	19507S	FACEBOOK	https://www.facebook.com/100058098908620	\N	\N	\N	\N	\N	1	\N	\N
5173	14151M	TWEETER	https://twitter.com/Jeromedurain	\N	\N	\N	\N	\N	2	\N	\N
5174	14151M	FACEBOOK	https://www.facebook.com/100058119668870	\N	\N	\N	\N	\N	3	\N	\N
5178	14249W	FACEBOOK	https://www.facebook.com/100010460109363	\N	\N	\N	\N	\N	2	\N	\N
5179	14249W	LINKEDIN	https://www.linkedin.com/in/nicole-duranton-08579b87/	\N	\N	\N	\N	\N	3	\N	\N
5180	11074Q	TWEETER	https://twitter.com/VincentEBLE	\N	\N	\N	\N	\N	1	\N	\N
5181	11074Q	FACEBOOK	https://www.facebook.com/1245925903	\N	\N	\N	\N	\N	2	\N	\N
5183	11110B	FACEBOOK	https://www.facebook.com/100057920656235	\N	\N	\N	\N	\N	2	\N	\N
5193	19673G	FACEBOOK	https://www.facebook.com/1016865502	\N	\N	\N	\N	\N	1	\N	\N
5189	14187A	LINKEDIN	https://www.linkedin.com/in/dominique-estrosi-sassone-738b57145/	\N	\N	\N	\N	\N	3	\N	\N
5197	20174H	FACEBOOK	https://www.facebook.com/marie.evrard.716	\N	\N	\N	\N	\N	1	\N	\N
5199	20038A	FACEBOOK	https://www.facebook.com/100009051262194	\N	\N	\N	\N	\N	1	\N	\N
5208	19647E	TWEETER	https://twitter.com/RemiFeraud	\N	\N	\N	\N	\N	1	\N	\N
5209	19647E	FACEBOOK	https://www.facebook.com/100057830059919	\N	\N	\N	\N	\N	2	\N	\N
5213	14281W	TWEETER	https://twitter.com/CorinneFeret	\N	\N	\N	\N	\N	1	\N	\N
5214	14281W	FACEBOOK	https://www.facebook.com/100058301791709	\N	\N	\N	\N	\N	2	\N	\N
5218	20100N	FACEBOOK	https://www.facebook.com/1607534182	\N	\N	\N	\N	\N	1	\N	\N
5219	20132W	TWEETER	https://twitter.com/BernardFialaire	\N	\N	\N	\N	\N	1	\N	\N
5220	20132W	FACEBOOK	https://www.facebook.com/100006429324480	\N	\N	\N	\N	\N	2	\N	\N
5222	20132W	LINKEDIN	https://www.linkedin.com/in/bernard-fialaire-7406516b/	\N	\N	\N	\N	\N	3	\N	\N
5224	08045X	FACEBOOK	https://www.facebook.com/100009309676928	\N	\N	\N	\N	\N	3	\N	\N
5226	19599P	TWEETER	https://twitter.com/martine_filleul	\N	\N	\N	\N	\N	1	\N	\N
3121	14239U	BLOG	http://michelamiel.fr/	\N	\N	\N	\N	\N	1	2015-11-26 13:40:34	2015-11-26 13:40:42
3361	14121F	PAGPER	http://www.ejeansannetas.fr/	\N	\N	\N	\N	\N	3	2016-04-07 17:15:30	2016-04-07 17:15:52
3581	11033F	TWEETER	https://twitter.com/estherbenbassa	\N	\N	\N	\N	\N	2	2017-09-25 16:48:15	2017-09-25 16:48:21
3582	01024M	PAGPER	http://www.senateur-detraigne.org/	\N	\N	\N	\N	\N	1	2017-09-25 17:28:05	2017-09-25 17:58:34
3583	01025N	PAGPER	http://www.senateur-ferat.org/	\N	\N	\N	\N	\N	1	2017-09-25 17:36:59	2017-09-25 17:37:40
3630	19719D	PAGPER	http://www.nathalie-delattre.fr/	\N	\N	\N	\N	\N	1	2017-11-09 13:43:05	2017-11-09 13:45:05
3631	19719D	TWEETER	https://twitter.com/n_delattre 	\N	\N	\N	\N	\N	2	2017-11-09 13:43:13	2017-11-09 13:43:27
3632	19719D	FACEBOOK	https://www.facebook.com/100057732863453	\N	\N	\N	\N	\N	3	2017-11-09 13:43:27	2017-11-09 13:43:35
3673	19621T	TWEETER	https://twitter.com/max_brisson	\N	\N	\N	\N	\N	2	2017-11-17 10:48:34	2017-11-17 10:48:54
3681	07004J	MEDIAPART	https://blogs.mediapart.fr/senateur-goulet/blog	\N	\N	\N	\N	\N	3	2017-11-22 09:53:30	2017-11-22 09:53:57
3672	19621T	FACEBOOK	https://www.facebook.com/1570173750	\N	\N	\N	\N	\N	1	2017-11-17 10:47:06	2017-11-17 10:48:33
3682	07004J	HUFFINGTON	http://www.huffingtonpost.fr/author/nathalie-goulet/	\N	\N	\N	\N	\N	4	2017-11-22 09:53:57	2017-11-22 09:54:16
3721	19593H	PAGPER	https://www.pierreouzoulias.fr/	\N	\N	\N	\N	\N	1	2017-12-07 15:59:59	2017-12-07 16:00:15
3722	19593H	FACEBOOK	https://www.facebook.com/100058054719947	\N	\N	\N	\N	\N	2	2017-12-07 16:00:15	2017-12-07 16:01:12
3723	19593H	TWEETER	https://twitter.com/OuzouliasP	\N	\N	\N	\N	\N	3	2017-12-07 16:01:12	2017-12-07 16:01:34
3901	19703U	FACEBOOK	https://www.facebook.com/100058029250527	\N	\N	\N	\N	\N	1	\N	\N
3902	19703U	TWEETER	https://twitter.com/JeanSOL__	\N	\N	\N	\N	\N	2	\N	\N
3923	19521Q	PAGPER	http://www.catherinefournier.fr/	\N	\N	\N	\N	\N	1	\N	\N
4513	19758L	TWEETER	 https://twitter.com/celine_brulin	\N	\N	\N	\N	\N	2	\N	\N
4003	08019V	TWEETER	https://twitter.com/MichelMagras	\N	\N	\N	\N	\N	3	\N	\N
4243	20046A	PAGPER	https://marieclaudevaraillas.fr	\N	\N	\N	\N	\N	1	\N	\N
4104	19820Y	FACEBOOK	http://www.facebook.com/100058222952522	\N	\N	\N	\N	\N	2	\N	\N
4105	19820Y	TWEETER	http://twitter.com/GilleHerve	\N	\N	\N	\N	\N	3	\N	\N
4244	20046A	FACEBOOK	https://www.facebook.com/100068918781826	\N	\N	\N	\N	\N	2	\N	\N
4245	20046A	TWEETER	https://twitter.com/MVaraillas	\N	\N	\N	\N	\N	3	\N	\N
4463	20116W	PAGPER	https://christianbilhac.wordpress.com/	\N	\N	\N	\N	\N	1	\N	\N
4512	19758L	FACEBOOK	https://www.facebook.com/100057705595682	\N	\N	\N	\N	\N	1	\N	\N
4543	20050V	PAGPER	 https://www.vaninapaoligagin.fr/	\N	\N	\N	\N	\N	5	\N	\N
4643	14133K	TWEETER	https://twitter.com/AllizardPascal	\N	\N	\N	\N	\N	1	\N	\N
4644	20264J	TWEETER	https://twitter.com/@YanChantrel	\N	\N	\N	\N	\N	1	\N	\N
4661	14133K	FACEBOOK	https://www.facebook.com/1153400834	\N	\N	\N	\N	\N	2	\N	\N
4662	14133K	LINKEDIN	https://www.linkedin.com/in/pascal-allizard-21440014a/	\N	\N	\N	\N	\N	3	\N	\N
4663	20032T	TWEETER	https://twitter.com/@JCAnglars	\N	\N	\N	\N	\N	1	\N	\N
4664	20032T	FACEBOOK	https://www.facebook.com/100005489411928	\N	\N	\N	\N	\N	2	\N	\N
4665	20032T	LINKEDIN	https://www.linkedin.com/in/anglars-jean-claude-64982354/	\N	\N	\N	\N	\N	3	\N	\N
4667	11109J	FACEBOOK	https://www.facebook.com/100006730352601	\N	\N	\N	\N	\N	2	\N	\N
4668	19760E	TWEETER	https://twitter.com/@Apourceau	\N	\N	\N	\N	\N	1	\N	\N
4669	19760E	FACEBOOK	https://www.facebook.com/100046971763251	\N	\N	\N	\N	\N	2	\N	\N
4670	14189C	TWEETER	https://twitter.com/@Arnaud_jm	\N	\N	\N	\N	\N	1	\N	\N
4203	20074E	PAGPER	http://www.francoisedumont.fr	\N	\N	\N	\N	\N	1	\N	\N
4671	14189C	FACEBOOK	https://www.facebook.com/1186870649	\N	\N	\N	\N	\N	2	\N	\N
4672	14189C	LINKEDIN	https://www.linkedin.com/in/jean-michel-arnaud-81865539/	\N	\N	\N	\N	\N	3	\N	\N
4673	19760E	LINKEDIN	https://www.linkedin.com/in/cathy-apourceau-poly-25144119a/	\N	\N	\N	\N	\N	3	\N	\N
4674	19717B	TWEETER	https://twitter.com/@StephaneArtano	\N	\N	\N	\N	\N	1	\N	\N
4675	19717B	FACEBOOK	https://www.facebook.com/1556591247	\N	\N	\N	\N	\N	2	\N	\N
4676	19717B	LINKEDIN	https://www.linkedin.com/in/st%C3%A9phane-artano-98262863/	\N	\N	\N	\N	\N	3	\N	\N
4679	19631V	LINKEDIN	https://www.linkedin.com/in/viviane-artigalas-77418058/	\N	\N	\N	\N	\N	2	\N	\N
4678	19631V	FACEBOOK	https://www.facebook.com/100005489764026	\N	\N	\N	\N	\N	1	\N	\N
4680	04085P	TWEETER	https://twitter.com/@ElianeAssassi 	\N	\N	\N	\N	\N	1	\N	\N
4681	04085P	FACEBOOK	https://www.facebook.com/100000246294749	\N	\N	\N	\N	\N	2	\N	\N
4682	19515S	FACEBOOK	https://fr-fr.facebook.com/100057680335794	\N	\N	\N	\N	\N	1	\N	\N
4683	20112S	TWEETER	https://twitter.com/@JeremyBacchi	\N	\N	\N	\N	\N	1	\N	\N
4686	20076G	FACEBOOK	https://m.facebook.com/JeanBacciSenateur/	\N	\N	\N	\N	\N	1	\N	\N
4685	20112S	FACEBOOK	https://www.facebook.com//100063935010927	\N	\N	\N	\N	\N	2	\N	\N
4687	19707Y	TWEETER	https://twitter.com/JPBansard	\N	\N	\N	\N	\N	1	\N	\N
4688	19651A	TWEETER	https://twitter.com/@JulienBargeton	\N	\N	\N	\N	\N	1	\N	\N
4689	19651A	FACEBOOK	https://fr-fr.facebook.com/100057903108711	\N	\N	\N	\N	\N	2	\N	\N
4690	19651A	LINKEDIN	https://www.linkedin.com/in/julienbargeton/	\N	\N	\N	\N	\N	3	\N	\N
4996	19577H	TWEETER	https://twitter.com/NassimahDindar	\N	\N	\N	\N	\N	1	\N	\N
4988	19251M	FACEBOOK	https://www.facebook.com/gldevinaz	\N	\N	\N	\N	\N	2	\N	\N
4994	20248J	TWEETER	https://twitter.com/DEVESA3	\N	\N	\N	\N	\N	3	\N	\N
4997	19577H	FACEBOOK	https://www.facebook.com/100001336576058	\N	\N	\N	\N	\N	2	\N	\N
4998	19577H	LINKEDIN	https://www.linkedin.com/search/results/all/?keywords=nassimah%20dindar&origin=RICH_QUERY_SUGGESTION&position=0&searchId=de35dced-ed47-4a7b-a5e8-216681b223f7	\N	\N	\N	\N	\N	3	\N	\N
4999	04071H	TWEETER	https://twitter.com/PhDominati	\N	\N	\N	\N	\N	1	\N	\N
5000	04071H	FACEBOOK	https://www.facebook.com/100001344530419	\N	\N	\N	\N	\N	2	\N	\N
5001	20134Y	TWEETER	https://twitter.com/tomdoss	\N	\N	\N	\N	\N	1	\N	\N
5002	20134Y	FACEBOOK	https://www.facebook.com/100002154834314	\N	\N	\N	\N	\N	2	\N	\N
5003	20134Y	LINKEDIN	https://www.linkedin.com/in/thomas-dossus/	\N	\N	\N	\N	\N	3	\N	\N
5004	20124W	TWEETER	https://twitter.com/DrexlerSabine	\N	\N	\N	\N	\N	1	\N	\N
5005	20124W	FACEBOOK	https://www.facebook.com/100063862400185	\N	\N	\N	\N	\N	2	\N	\N
5076	11072N	TWEETER	https://twitter.com/TMohamedSoilihi	\N	\N	\N	\N	\N	1	\N	\N
5077	11072N	FACEBOOK	https://www.facebook.com/100003090871052	\N	\N	\N	\N	\N	2	\N	\N
5078	19369B	LINKEDIN	https://www.linkedin.com/in/jean-pierre-moga-778055157/	\N	\N	\N	\N	\N	1	\N	\N
5080	19335Q	FACEBOOK	https://www.facebook.com/100057752514659	\N	\N	\N	\N	\N	2	\N	\N
5082	04092N	FACEBOOK	https://www.facebook.com/100064117114258	\N	\N	\N	\N	\N	2	\N	\N
5083	14223L	FACEBOOK	https://www.facebook.com/1091086152	\N	\N	\N	\N	\N	3	\N	\N
5084	19671E	TWEETER	https://twitter.com/SmeurantL	\N	\N	\N	\N	\N	1	\N	\N
5085	19671E	FACEBOOK	https://www.facebook.com/100057853308968	\N	\N	\N	\N	\N	2	\N	\N
5086	19671E	LINKEDIN	https://www.linkedin.com/in/s%C3%A9bastien-meurant-0057783/	\N	\N	\N	\N	\N	3	\N	\N
5088	14147R	FACEBOOK	https://www.facebook.com/100057734875332	\N	\N	\N	\N	\N	3	\N	\N
5089	19563B	TWEETER	https://twitter.com/F_Menonville	\N	\N	\N	\N	\N	1	\N	\N
5090	19563B	FACEBOOK	https://www.facebook.com/100063789469689	\N	\N	\N	\N	\N	2	\N	\N
5091	19563B	LINKEDIN	https://www.linkedin.com/in/franck-menonville-11151353/	\N	\N	\N	\N	\N	3	\N	\N
3201	08012N	PAGPER	http://www.jjlozach.fr	\N	\N	\N	\N	\N	3	2016-01-12 17:33:09	2016-01-12 17:33:16
3241	11040E	TWEETER	https://twitter.com/ericbocquet	\N	\N	\N	\N	\N	1	2016-02-18 17:53:01	2017-09-25 17:04:26
3633	19637C	FACEBOOK	https://www.facebook.com/100058187974510	\N	\N	\N	\N	\N	2	2017-11-09 16:49:08	2017-11-09 16:49:34
3654	19591F	PAGPER	https://iacovelli.fr/	\N	\N	\N	\N	\N	4	2017-11-14 15:40:38	2017-11-14 15:40:53
3655	19591F	FACEBOOK	https://www.facebook.com/596443558	\N	\N	\N	\N	\N	2	2017-11-14 15:40:53	2017-11-14 15:41:18
3656	19591F	TWEETER	https://twitter.com/iacovellixavier	\N	\N	\N	\N	\N	1	2017-11-14 15:41:18	2017-11-14 15:41:41
3657	11097X	YOUTUBE	https://www.youtube.com/channel/UClpcQzPR56-nwRD_xeHqhyA	\N	\N	\N	\N	\N	4	2017-11-14 17:53:04	2017-11-14 17:53:17
5058	08061X	TWEETER	https://twitter.com/f_patriat	\N	\N	\N	\N	\N	2	\N	\N
3659	04033B	TWEETER	https://twitter.com/brunoretailleau	\N	\N	\N	\N	\N	1	2017-11-14 18:34:22	2017-11-14 18:35:07
3662	04033B	FACEBOOK	https://www.facebook.com/100044178246660	\N	\N	\N	\N	\N	2	2017-11-14 18:34:59	2017-11-14 18:35:05
3663	04033B	INSTAGRAM	https://www.instagram.com/bruno_retailleau/	\N	\N	\N	\N	\N	5	2017-11-14 18:35:08	2017-11-14 18:35:19
3668	08060W	FACEBOOK	https://www.facebook.com/100010679208727	\N	\N	\N	\N	\N	2	2017-11-16 16:27:23	2017-11-16 16:30:41
3801	14207L	BLOG	https://senateurcabanel.com/	\N	\N	\N	\N	\N	1	2018-03-14 16:40:05	2018-03-14 16:40:41
3821	14038Y	PAGPER	http://www.patrick-chaize.fr/	\N	\N	\N	\N	\N	1	2018-03-21 11:39:00	2018-03-21 11:43:09
3822	14038Y	TWEETER	https://twitter.com/p_chaize	\N	\N	\N	\N	\N	2	2018-03-21 11:39:08	2018-03-21 11:39:27
3823	14038Y	FACEBOOK	https://www.facebook.com/100013049684042	\N	\N	\N	\N	\N	3	2018-03-21 11:39:28	2018-03-21 11:39:54
3841	10006L	TWEETER	https://twitter.com/cderoche_senat?lang=fr	\N	\N	\N	\N	\N	2	2018-04-13 11:38:06	2018-04-13 11:38:12
3924	19521Q	TWEETER	https://twitter.com/FournierSenat	\N	\N	\N	\N	\N	2	\N	\N
4524	20074E	TWEETER	https://twitter.com/frdumont83?lang=fr	\N	\N	\N	\N	\N	3	\N	\N
4063	14179A	INSTAGRAM	https://www.instagram.com/loichervepublic/	\N	\N	\N	\N	\N	5	\N	\N
4064	14179A	YOUTUBE	https://www.youtube.com/user/loicherve	\N	\N	\N	\N	\N	6	\N	\N
4204	20050V	PAGPER	https://www.v2020.fr/	\N	\N	\N	\N	\N	1	\N	\N
4223	20034V	FACEBOOK	https://www.facebook.com/100064316880925	\N	\N	\N	\N	\N	2	\N	\N
4224	20034V	TWEETER	https://twitter.com/micheline_jacqu	\N	\N	\N	\N	\N	1	\N	\N
4263	19643A	TWEETER	https://twitter.com/Senatrice_CBE	\N	\N	\N	\N	\N	1	\N	\N
4483	20070A	FACEBOOK	 https://www.facebook.com/1546360600	\N	\N	\N	\N	\N	1	\N	\N
4484	20070A	TWEETER	 https://twitter.com/Th_Cozic	\N	\N	\N	\N	\N	2	\N	\N
4485	20070A	LINKEDIN	https://www.linkedin.com/in/thierry-cozic-2444b0177/	\N	\N	\N	\N	\N	3	\N	\N
4523	20074E	FACEBOOK	https://www.facebook.com/100063901682312	\N	\N	\N	\N	\N	2	\N	\N
4525	20074E	INSTAGRAM	https://www.instagram.com/francoisedumont83/	\N	\N	\N	\N	\N	4	\N	\N
4564	20092G	PAGPER	http://www.danielsalmon.bzh	\N	\N	\N	\N	\N	3	\N	\N
4703	19741B	TWEETER	https://twitter.com/JeromeBascher	\N	\N	\N	\N	\N	1	\N	\N
4704	19741B	FACEBOOK	https://www.facebook.com/100007220139185	\N	\N	\N	\N	\N	2	\N	\N
4705	19667J	TWEETER	https://twitter.com/@arnaud_bazinVO	\N	\N	\N	\N	\N	1	\N	\N
5059	08061X	FACEBOOK	https://www.facebook.com/100057831827819	\N	\N	\N	\N	\N	3	\N	\N
5060	20050V	TWEETER	https://twitter.com/GaginPaoli	\N	\N	\N	\N	\N	2	\N	\N
4709	19741B	LINKEDIN	https://www.linkedin.com/in/jerome-bascher-9163ab104/	\N	\N	\N	\N	\N	3	\N	\N
5061	20050V	FACEBOOK	https://www.facebook.com/100076010277457	\N	\N	\N	\N	\N	3	\N	\N
5062	20050V	LINKEDIN	https://www.linkedin.com/in/vanina-paoli-gagin-24315034/	\N	\N	\N	\N	\N	4	\N	\N
5063	19866P	FACEBOOK	https://www.facebook.com/100057980894123	\N	\N	\N	\N	\N	1	\N	\N
5065	19573D	FACEBOOK	https://www.facebook.com/100007100076552	\N	\N	\N	\N	\N	2	\N	\N
5092	04057K	TWEETER	https://twitter.com/colettemelot	\N	\N	\N	\N	\N	1	\N	\N
5093	04057K	FACEBOOK	https://www.facebook.com/100058061828505	\N	\N	\N	\N	\N	2	\N	\N
5094	20252E	TWEETER	https://twitter.com/ThierryMeignen	\N	\N	\N	\N	\N	1	\N	\N
5095	20252E	FACEBOOK	https://www.facebook.com/100057822859263	\N	\N	\N	\N	\N	2	\N	\N
5096	08009T	TWEETER	https://twitter.com/HMaurey	\N	\N	\N	\N	\N	1	\N	\N
5097	08009T	LINKEDIN	https://www.linkedin.com/in/herv%C3%A9-maurey-5bb496191/	\N	\N	\N	\N	\N	3	\N	\N
5098	01060R	FACEBOOK	https://www.facebook.com/100005486293439	\N	\N	\N	\N	\N	2	\N	\N
5099	19826F	TWEETER	https://twitter.com/Pasc_Martin	\N	\N	\N	\N	\N	1	\N	\N
5100	19826F	FACEBOOK	https://www.facebook.com/ 100057628916285	\N	\N	\N	\N	\N	2	\N	\N
5101	14001X	TWEETER	https://twitter.com/Didier_Marie76	\N	\N	\N	\N	\N	1	\N	\N
5102	14001X	FACEBOOK	https://www.facebook.com/100064255712160	\N	\N	\N	\N	\N	2	\N	\N
5103	14001X	LINKEDIN	https://www.linkedin.com/in/didier-marie-8424881bb/	\N	\N	\N	\N	\N	3	\N	\N
5104	19637C	TWEETER	https://twitter.com/FMsenateur59	\N	\N	\N	\N	\N	1	\N	\N
5105	19637C	LINKEDIN	https://www.linkedin.com/in/frederic-marchand-23397888/	\N	\N	\N	\N	\N	3	\N	\N
5106	14111D	FACEBOOK	https://www.facebook.com/100003067449922	\N	\N	\N	\N	\N	1	\N	\N
5107	14111D	LINKEDIN	https://www.linkedin.com/in/alain-marc-414205ab/	\N	\N	\N	\N	\N	2	\N	\N
5108	14031R	TWEETER	https://twitter.com/DidierMandelli	\N	\N	\N	\N	\N	1	\N	\N
5109	14031R	FACEBOOK	https://www.facebook.com/100000728637910	\N	\N	\N	\N	\N	2	\N	\N
5110	14031R	LINKEDIN	https://www.linkedin.com/in/didier-mandelli-b52679116/	\N	\N	\N	\N	\N	3	\N	\N
5112	14251Q	FACEBOOK	https://www.facebook.com/100057729474461	\N	\N	\N	\N	\N	2	\N	\N
5117	11104D	PAGPER	http://www.jacques-bernard-magner.fr	\N	\N	\N	\N	\N	3	\N	\N
5118	12016W	TWEETER	https://twitter.com/VictorinLurel	\N	\N	\N	\N	\N	1	\N	\N
5119	12016W	FACEBOOK	https://www.facebook.com/100050168873514	\N	\N	\N	\N	\N	2	\N	\N
5121	17779H	FACEBOOK	https://www.facebook.com/100022490543308	\N	\N	\N	\N	\N	1	\N	\N
5123	08012N	FACEBOOK	https://www.facebook.com/100058215094569	\N	\N	\N	\N	\N	2	\N	\N
5124	19441R	TWEETER	https://twitter.com/PLouault	\N	\N	\N	\N	\N	1	\N	\N
5125	19441R	FACEBOOK	https://www.facebook.com/100058188454387	\N	\N	\N	\N	\N	2	\N	\N
5126	19441R	LINKEDIN	https://www.linkedin.com/in/pierre-louault-81573716b/	\N	\N	\N	\N	\N	3	\N	\N
5163	19711U	TWEETER	https://twitter.com/LavardeC	\N	\N	\N	\N	\N	1	\N	\N
5164	19711U	FACEBOOK	https://www.facebook.com/677306056	\N	\N	\N	\N	\N	2	\N	\N
5165	19711U	LINKEDIN	https://www.linkedin.com/in/christine-lavarde-19780a5/	\N	\N	\N	\N	\N	3	\N	\N
5166	08015R	PAGPER	http://www.senat.fr/	\N	\N	\N	\N	\N	1	\N	\N
5167	12041X	TWEETER	https://twitter.com/plaurent_pcf	\N	\N	\N	\N	\N	1	\N	\N
5168	12041X	FACEBOOK	https://www.facebook.com/100044437836228	\N	\N	\N	\N	\N	2	\N	\N
5169	12041X	PAGPER	http://www.pierrelaurent.org	\N	\N	\N	\N	\N	3	\N	\N
5171	19699S	TWEETER	https://twitter.com/LaugierMichel	\N	\N	\N	\N	\N	1	\N	\N
5172	19699S	LINKEDIN	https://www.linkedin.com/in/michel-laugier-27b49269/	\N	\N	\N	\N	\N	2	\N	\N
5175	19723Y	TWEETER	https://twitter.com/flolassarade	\N	\N	\N	\N	\N	1	\N	\N
5176	19723Y	FACEBOOK	https://www.facebook.com/100051158921189	\N	\N	\N	\N	\N	2	\N	\N
3061	04094Q	PAGPER	http://www.sergelarcher.com	\N	\N	\N	\N	\N	1	2015-10-06 16:02:16	2015-10-06 16:02:57
3101	05008E	TWEETER	https://twitter.com/basphilippe	\N	\N	\N	\N	\N	2	2015-11-18 09:54:49	2017-09-25 16:43:18
3141	14221J	BLOG	http://pierremedevielle.fr/	\N	\N	\N	\N	\N	1	2015-12-02 10:47:51	2015-12-02 10:48:12
3142	14221J	FACEBOOK	https://www.facebook.com/747541906	\N	\N	\N	\N	\N	2	2015-12-02 10:48:14	2015-12-02 10:48:32
3143	14221J	TWEETER	https://twitter.com/p_medevielle	\N	\N	\N	\N	\N	3	2015-12-02 10:48:36	2015-12-02 10:48:55
3144	14221J	LINKEDIN	https://fr.linkedin.com/in/pierre-medevielle-7bb48b45	\N	\N	\N	\N	\N	4	2015-12-02 10:49:11	2015-12-02 10:55:13
3161	11097X	PAGPER	http://www.renepaulsavary.fr/	\N	\N	\N	\N	\N	3	2015-12-08 17:08:19	2017-09-25 17:54:29
3181	01041N	FACEBOOK	https://www.facebook.com/Louis-Duvernois-913327902087011/	\N	\N	\N	\N	\N	1	2015-12-09 11:31:55	2017-02-20 16:31:05
3441	08069G	FACEBOOK	https://www.facebook.com/100063547937935	\N	\N	\N	\N	\N	2	2016-07-29 14:38:51	2016-07-29 14:38:56
3442	08069G	TWEETER	https://twitter.com/alainhoupert	\N	\N	\N	\N	\N	1	2016-07-29 15:37:14	2016-07-29 15:37:20
3644	14213J	FACEBOOK	https://www.facebook.com/100000259359868	\N	\N	\N	\N	\N	2	2017-11-13 19:03:30	2017-11-13 19:04:00
3645	14213J	TWEETER	https://twitter.com/imbertcorinne17	\N	\N	\N	\N	\N	1	2017-11-13 19:04:07	2017-11-13 19:04:49
3782	19421M	FACEBOOK	https://www.facebook.com/1387538804592949/	\N	\N	\N	\N	\N	2	2018-02-14 17:45:22	2018-02-14 17:46:09
3781	19421M	PAGPER	http://www.huguessaury.fr/	\N	\N	\N	\N	\N	3	2018-02-14 17:45:01	2018-02-14 17:45:20
3963	19727D	PAGPER	https://www.nadine-grelet-certenais-senatrice.fr/	\N	\N	\N	\N	\N	1	\N	\N
4043	14147R	PAGPER	http://www.senateurs-emorine-mercier.fr/	\N	\N	\N	\N	\N	1	\N	\N
4423	19701S	PAGPER	 https://www.martadecidrac.fr/	\N	\N	\N	\N	\N	1	\N	\N
4424	19701S	FACEBOOK	https://www.facebook.com/715289729	\N	\N	\N	\N	\N	2	\N	\N
4425	19701S	TWEETER	https://twitter.com/MartadeCidrac	\N	\N	\N	\N	\N	3	\N	\N
4963	20020P	FACEBOOK	https://www.facebook.com/100063607129465	\N	\N	\N	\N	\N	1	\N	\N
4966	20150Y	FACEBOOK	https://www.facebook.com/100063471800243	\N	\N	\N	\N	\N	2	\N	\N
4965	20150Y	TWEETER	https://twitter.com/RohfritschTeva	\N	\N	\N	\N	\N	1	\N	\N
4967	20150Y	LINKEDIN	https://www.linkedin.com/in/teva-rohfritsch-65356133/	\N	\N	\N	\N	\N	3	\N	\N
4968	14229S	TWEETER	https://twitter.com/Sy_robert	\N	\N	\N	\N	\N	1	\N	\N
4969	14229S	FACEBOOK	https://www.facebook.com/1668807611	\N	\N	\N	\N	\N	2	\N	\N
4970	14229S	LINKEDIN	https://www.linkedin.com/in/sylvie-robert-6283b3a9/	\N	\N	\N	\N	\N	3	\N	\N
4971	20054A	TWEETER	https://twitter.com/OlivierRietmann	\N	\N	\N	\N	\N	1	\N	\N
4972	20054A	FACEBOOK	https://www.facebook.com/100002363208382	\N	\N	\N	\N	\N	2	\N	\N
4973	19798U	TWEETER	https://twitter.com/MpRicher	\N	\N	\N	\N	\N	1	\N	\N
4974	19798U	FACEBOOK	https://www.facebook.com/100000270008620	\N	\N	\N	\N	\N	2	\N	\N
4976	04033B	LINKEDIN	https://www.linkedin.com/in/brunoretailleau/	\N	\N	\N	\N	\N	3	\N	\N
4978	19705W	TWEETER	https://twitter.com/e_renaud_G	\N	\N	\N	\N	\N	1	\N	\N
4979	19705W	FACEBOOK	https://www.facebook.com/100057984283482	\N	\N	\N	\N	\N	2	\N	\N
4980	19766L	TWEETER	https://twitter.com/damienregnard	\N	\N	\N	\N	\N	1	\N	\N
4981	19766L	FACEBOOK	https://www.facebook.com/100058164576066	\N	\N	\N	\N	\N	2	\N	\N
4982	19766L	LINKEDIN	https://www.linkedin.com/in/damien-regnard-a2557327/	\N	\N	\N	\N	\N	3	\N	\N
4983	20082E	TWEETER	https://twitter.com/@C_REDON_SARRAZY	\N	\N	\N	\N	\N	2	\N	\N
4984	20082E	FACEBOOK	https://www.facebook.com/1521879841	\N	\N	\N	\N	\N	3	\N	\N
4986	14225N	LINKEDIN	https://www.linkedin.com/in/claude-raynal-a9780a116/	\N	\N	\N	\N	\N	4	\N	\N
4990	14055N	TWEETER	https://twitter.com/Stephane_Ravier	\N	\N	\N	\N	\N	1	\N	\N
4991	14055N	FACEBOOK	https://www.facebook.com/100044635230175	\N	\N	\N	\N	\N	2	\N	\N
4992	14331P	TWEETER	https://twitter.com/RAPINJF	\N	\N	\N	\N	\N	1	\N	\N
4993	14331P	FACEBOOK	https://www.facebook.com/100058029069647	\N	\N	\N	\N	\N	2	\N	\N
4995	14331P	PAGPER	http://www.jeanfrancoisrapin.com	\N	\N	\N	\N	\N	3	\N	\N
5006	19349W	TWEETER	https://twitter.com/@didier_rambaud	\N	\N	\N	\N	\N	1	\N	\N
5007	19349W	FACEBOOK	https://www.facebook.com/100061302296422	\N	\N	\N	\N	\N	2	\N	\N
5008	19443T	FACEBOOK	https://www.facebook.com/profile.php?id=100012331421255	\N	\N	\N	\N	\N	1	\N	\N
5009	20298U	TWEETER	https://twitter.com/91DRM	\N	\N	\N	\N	\N	1	\N	\N
5010	20298U	FACEBOOK	https://www.facebook.com/91DRM	\N	\N	\N	\N	\N	2	\N	\N
5011	20298U	LINKEDIN	https://www.linkedin.com/in/ract-madoux-daphn%C3%A9-8a557214/	\N	\N	\N	\N	\N	3	\N	\N
5012	19679N	TWEETER	https://twitter.com/FPuissat	\N	\N	\N	\N	\N	1	\N	\N
5013	19679N	FACEBOOK	https://www.facebook.com/100001995412975	\N	\N	\N	\N	\N	2	\N	\N
5014	04043D	FACEBOOK	https://www.facebook.com/1049109674	\N	\N	\N	\N	\N	2	\N	\N
5015	04043D	LINKEDIN	https://www.linkedin.com/in/catherine-procaccia-5658256b/	\N	\N	\N	\N	\N	3	\N	\N
5016	19739H	TWEETER	https://twitter.com/JP_Prince_41	\N	\N	\N	\N	\N	1	\N	\N
5019	19503N	TWEETER	https://twitter.com/AngelePreville	\N	\N	\N	\N	\N	1	\N	\N
5018	11090Q	LINKEDIN	https://www.linkedin.com/in/sophie-primas-7763079b/	\N	\N	\N	\N	\N	4	\N	\N
5020	17965H	TWEETER	https://twitter.com/E_Poumirol	\N	\N	\N	\N	\N	1	\N	\N
5021	17965H	FACEBOOK	https://www.facebook.com/100063957911720	\N	\N	\N	\N	\N	2	\N	\N
5022	17965H	LINKEDIN	https://www.facebook.com/emiliennepoumirol	\N	\N	\N	\N	\N	3	\N	\N
5023	20130U	TWEETER	https://twitter.com/PoncetRaymonde	\N	\N	\N	\N	\N	1	\N	\N
5024	20130U	FACEBOOK	https://www.facebook.com/100064283641621	\N	\N	\N	\N	\N	2	\N	\N
5025	20130U	LINKEDIN	https://www.linkedin.com/in/raymonde-poncet-180b7a48/	\N	\N	\N	\N	\N	3	\N	\N
5028	05012A	FACEBOOK	https://www.facebook.com/100067161412318	\N	\N	\N	\N	\N	2	\N	\N
5027	05012A	TWEETER	https://twitter.com/remypointereau	\N	\N	\N	\N	\N	1	\N	\N
5031	20118Y	FACEBOOK	https://www.facebook.com/100046018625293	\N	\N	\N	\N	\N	1	\N	\N
5030	19319Q	FACEBOOK	https://www.facebook.com/100063698246207	\N	\N	\N	\N	\N	1	\N	\N
5034	20030R	FACEBOOK	https://www.facebook.com/100064131600985	\N	\N	\N	\N	\N	2	\N	\N
5033	20030R	TWEETER	https://twitter.com/sebastienpla	\N	\N	\N	\N	\N	1	\N	\N
5035	20030R	LINKEDIN	https://www.linkedin.com/in/s%C3%A9bastien-pla-b2b596165/	\N	\N	\N	\N	\N	3	\N	\N
5036	20030R	PAGPER	https://www.sebastienpla.com	\N	\N	\N	\N	\N	4	\N	\N
5037	19533U	LINKEDIN	https://www.linkedin.com/in/st%C3%A9phane-piednoir-58b05b54	\N	\N	\N	\N	\N	3	\N	\N
5038	20146D	TWEETER	https://twitter.com/MLPhineraHorth	\N	\N	\N	\N	\N	1	\N	\N
5039	20146D	FACEBOOK	https://www.facebook.com/100063737306320	\N	\N	\N	\N	\N	2	\N	\N
5040	20146D	LINKEDIN	https://www.linkedin.com/in/marie-laure-phinera-horth-45681319b/	\N	\N	\N	\N	\N	3	\N	\N
5041	20148F	TWEETER	https://twitter.com/AnnickPetrus	\N	\N	\N	\N	\N	1	\N	\N
5042	20148F	FACEBOOK	https://www.facebook.com/100063811999259	\N	\N	\N	\N	\N	2	\N	\N
5177	19723Y	LINKEDIN	https://www.linkedin.com/in/florence-lassarade-9077985a/	\N	\N	\N	\N	\N	3	\N	\N
5182	86034E	LINKEDIN	https://www.linkedin.com/in/g%C3%A9rard-larcher-93052219a/	\N	\N	\N	\N	\N	5	\N	\N
5184	20102Q	TWEETER	https://twitter.com/LahellecG	\N	\N	\N	\N	\N	1	\N	\N
5185	20102Q	FACEBOOK	https://www.facebook.com/100060089481173	\N	\N	\N	\N	\N	2	\N	\N
5187	20102Q	LINKEDIN	https://www.linkedin.com/in/g%C3%A9rard-lahellec-7959a1163/	\N	\N	\N	\N	\N	3	\N	\N
5188	20102Q	PAGPER	https://www.gerardlahellec.com	\N	\N	\N	\N	\N	4	\N	\N
5191	19583F	FACEBOOK	https://www.facebook.com/100034256326558	\N	\N	\N	\N	\N	2	\N	\N
5194	19611R	TWEETER	https://twitter.com/L_Lafon	\N	\N	\N	\N	\N	1	\N	\N
3221	08073C	FACEBOOK	https://www.facebook.com/1844665066	\N	\N	\N	\N	\N	2	2016-02-02 17:15:07	2016-02-02 17:15:24
3222	08073C	TWEETER	https://twitter.com/GeorgesPatient	\N	\N	\N	\N	\N	1	2016-02-02 17:15:29	2016-02-02 17:15:37
3341	14225N	PAGPER	http://www.claude-raynal.fr/	\N	\N	\N	\N	\N	3	2016-03-24 09:35:12	2016-03-24 09:35:58
3501	80013X	PAGPER	http://www.roland-courteau.com/	\N	\N	\N	\N	\N	1	2016-10-24 11:40:11	2016-10-24 11:40:20
3502	80013X	FACEBOOK	https://fr-fr.facebook.com/Roland-Courteau-233281690015566/ 	\N	\N	\N	\N	\N	2	2016-10-24 11:40:20	2016-10-24 11:40:34
3601	14231L	FACEBOOK	https://www.facebook.com/100058184434962	\N	\N	\N	\N	\N	1	2017-10-02 10:11:01	2017-10-02 10:11:12
3602	14231L	TWEETER	https://twitter.com/FrancoiseGatel	\N	\N	\N	\N	\N	2	2017-10-02 10:11:13	2017-10-02 10:11:20
3603	14231L	PAGPER	http://francoisegatel.fr/	\N	\N	\N	\N	\N	3	2017-10-02 10:15:54	2017-10-02 10:16:00
3703	14065Q	TWEETER	https://twitter.com/jacquesbigot	\N	\N	\N	\N	\N	2	2017-12-01 14:50:44	2017-12-01 14:51:46
3702	14065Q	FACEBOOK	https://www.facebook.com/jacques.bigot.35	\N	\N	\N	\N	\N	1	2017-12-01 14:49:36	2017-12-01 14:50:43
3861	14030Q	PAGPER	http://www.annickbillon.fr/	\N	\N	\N	\N	\N	1	2018-06-04 15:02:07	2018-06-04 15:03:40
3862	14030Q	FACEBOOK	https://www.facebook.com/100005951148289	\N	\N	\N	\N	\N	2	2018-06-04 15:03:05	2018-06-04 15:03:59
3863	14030Q	TWEETER	https://twitter.com/AnnickBillon	\N	\N	\N	\N	\N	3	2018-06-04 15:04:03	2018-06-04 15:04:18
3881	19713W	PAGPER	http://nadiasollogoub.fr/	\N	\N	\N	\N	\N	4	\N	\N
3943	19733B	PAGPER	https://www.pascalebories.fr/	\N	\N	\N	\N	\N	1	\N	\N
4343	86034E	FACEBOOK	https://www.facebook.com/100060710991349	\N	\N	\N	\N	\N	3	\N	\N
4344	86034E	FACEBOOK	https://www.facebook.com/100068893342637	\N	\N	\N	\N	\N	4	\N	\N
4363	20068G	FACEBOOK	https://www.facebook.com/100056621176185	\N	\N	\N	\N	\N	1	\N	\N
4827	11066Q	LINKEDIN	https://www.linkedin.com/in/yannick-vaugrenard-787629205/	\N	\N	\N	\N	\N	4	\N	\N
4835	01034P	TWEETER	https://twitter.com/JMV_62	\N	\N	\N	\N	\N	3	\N	\N
4841	19527W	FACEBOOK	https://www.facebook.com/697374475	\N	\N	\N	\N	\N	2	\N	\N
4840	19527W	TWEETER	https://twitter.com/VanHegheSabine	\N	\N	\N	\N	\N	1	\N	\N
4842	19527W	LINKEDIN	https://www.linkedin.com/in/sabine-van-heghe-90b1661b5/	\N	\N	\N	\N	\N	3	\N	\N
4847	11041F	TWEETER	https://twitter.com/VALLINIAndre	\N	\N	\N	\N	\N	1	\N	\N
4850	20064C	FACEBOOK	https://www.facebook.com/100058144987225	\N	\N	\N	\N	\N	2	\N	\N
4849	20064C	TWEETER	https://twitter.com/mickaelvallet	\N	\N	\N	\N	\N	1	\N	\N
4851	01062T	TWEETER	https://twitter.com/JM_Todeschini	\N	\N	\N	\N	\N	1	\N	\N
4852	01062T	FACEBOOK	https://www.facebook.com/100057834647735	\N	\N	\N	\N	\N	2	\N	\N
4853	19413M	TWEETER	https://twitter.com/@jctissot42	\N	\N	\N	\N	\N	1	\N	\N
4854	19413M	FACEBOOK	https://www.facebook.com/100000102025870	\N	\N	\N	\N	\N	2	\N	\N
4855	19413M	PAGPER	http://jc-tissot.fr	\N	\N	\N	\N	\N	3	\N	\N
4857	19675J	FACEBOOK	https://www.facebook.com/1414063402	\N	\N	\N	\N	\N	2	\N	\N
4858	19675J	LINKEDIN	https://www.linkedin.com/in/claudine-thomas-53218871/	\N	\N	\N	\N	\N	3	\N	\N
4863	19301E	TWEETER	https://twitter.com/@SenateurDTheoph	\N	\N	\N	\N	\N	1	\N	\N
4864	19301E	FACEBOOK	https://www.facebook.com/100057746902049	\N	\N	\N	\N	\N	2	\N	\N
4865	19301E	LINKEDIN	https://www.linkedin.com/in/theophile-dominique-3b671670/	\N	\N	\N	\N	\N	3	\N	\N
4869	14275Y	FACEBOOK	https://www.facebook.com/100057906977971	\N	\N	\N	\N	\N	2	\N	\N
4873	19669L	FACEBOOK	https://www.facebook.com/100004551222221	\N	\N	\N	\N	\N	2	\N	\N
4872	19669L	TWEETER	https://twitter.com/@RachidTemal	\N	\N	\N	\N	\N	1	\N	\N
4874	19689Q	TWEETER	https://twitter.com/@STaillePolian	\N	\N	\N	\N	\N	1	\N	\N
4875	19689Q	FACEBOOK	https://www.facebook.com/staillepolian	\N	\N	\N	\N	\N	2	\N	\N
4876	19689Q	LINKEDIN	https://www.linkedin.com/in/sophie-taill%C3%A9-polian-24079551/	\N	\N	\N	\N	\N	3	\N	\N
4877	19689Q	PAGPER	https://www.sophie-taille-polian.fr	\N	\N	\N	\N	\N	4	\N	\N
4878	20136B	TWEETER	https://twitter.com/@PhilippeTabarot	\N	\N	\N	\N	\N	1	\N	\N
4880	20136B	FACEBOOK	https://www.facebook.com/100058298461764	\N	\N	\N	\N	\N	2	\N	\N
4882	20136B	LINKEDIN	https://www.linkedin.com/in/philippe-tabarot-51b45497/	\N	\N	\N	\N	\N	3	\N	\N
4883	20136B	PAGPER	http://philippetabarot.fr	\N	\N	\N	\N	\N	4	\N	\N
4888	20084G	TWEETER	https://twitter.com/stanzionelucien	\N	\N	\N	\N	\N	1	\N	\N
4889	20084G	FACEBOOK	https://www.facebook.com/731254938	\N	\N	\N	\N	\N	2	\N	\N
4890	20084G	LINKEDIN	https://www.linkedin.com/in/lucien-stanzione-09a88b38/	\N	\N	\N	\N	\N	3	\N	\N
4894	20062A	LINKEDIN	https://www.linkedin.com/in/laurent-somon-5aaa151ba/	\N	\N	\N	\N	\N	3	\N	\N
4911	19762G	FACEBOOK	https://www.facebook.com/100000178215864	\N	\N	\N	\N	\N	2	\N	\N
4899	19713W	FACEBOOK	https://www.facebook.com/1668895538	\N	\N	\N	\N	\N	2	\N	\N
4900	19713W	LINKEDIN	https://www.linkedin.com/in/nadia-sollogoub-84ab2335/	\N	\N	\N	\N	\N	3	\N	\N
4910	19762G	TWEETER	https://twitter.com/SegouinV	\N	\N	\N	\N	\N	1	\N	\N
4912	19762G	LINKEDIN	http://www.senat.fr/	\N	\N	\N	\N	\N	3	\N	\N
4914	04045F	TWEETER	https://twitter.com/PSchillinger68	\N	\N	\N	\N	\N	1	\N	\N
4916	04045F	FACEBOOK	https://www.facebook.com/100013735087569	\N	\N	\N	\N	\N	2	\N	\N
4917	04045F	LINKEDIN	https://www.linkedin.com/in/schillinger-patricia-27b12049/	\N	\N	\N	\N	\N	3	\N	\N
4918	20098N	TWEETER	https://twitter.com/ElsaSchalck	\N	\N	\N	\N	\N	1	\N	\N
4919	20098N	FACEBOOK	https://www.facebook.com/100063880593563	\N	\N	\N	\N	\N	2	\N	\N
4920	20098N	LINKEDIN	https://www.linkedin.com/in/elsa-schalck-77398a18a/	\N	\N	\N	\N	\N	3	\N	\N
4923	19687N	TWEETER	https://twitter.com/PSavoldelli94	\N	\N	\N	\N	\N	1	\N	\N
4924	19687N	FACEBOOK	https://www.facebook.com/100058135986949	\N	\N	\N	\N	\N	2	\N	\N
4927	11043H	LINKEDIN	https://www.linkedin.com/in/michel-savin-aa486b177/	\N	\N	\N	\N	\N	3	\N	\N
4931	20044X	TWEETER	https://twitter.com/@SautarelS	\N	\N	\N	\N	\N	1	\N	\N
4932	20044X	FACEBOOK	https://www.facebook.com/100051467599429	\N	\N	\N	\N	\N	2	\N	\N
4933	20044X	LINKEDIN	https://www.linkedin.com/in/stephane-sautarel-18964613a/	\N	\N	\N	\N	\N	3	\N	\N
4935	19421M	TWEETER	https://twitter.com/@HSaury	\N	\N	\N	\N	\N	1	\N	\N
4937	20092G	TWEETER	https://twitter.com/@Senateur_Salmon	\N	\N	\N	\N	\N	1	\N	\N
4938	20092G	FACEBOOK	https://www.facebook.com/100063760915054	\N	\N	\N	\N	\N	2	\N	\N
4939	19619A	TWEETER	https://twitter.com/@DeniseSaintPe	\N	\N	\N	\N	\N	1	\N	\N
4942	14107H	FACEBOOK	https://www.facebook.com/100075638287528	\N	\N	\N	\N	\N	2	\N	\N
4941	14107H	TWEETER	https://twitter.com/rouxjy	\N	\N	\N	\N	\N	1	\N	\N
4943	14107H	LINKEDIN	https://www.linkedin.com/in/jean-yves-roux-244a7419b/	\N	\N	\N	\N	\N	3	\N	\N
4944	11045K	TWEETER	https://twitter.com/@laurossignol	\N	\N	\N	\N	\N	1	\N	\N
4945	11045K	FACEBOOK	https://www.facebook.com/100058135596444	\N	\N	\N	\N	\N	2	\N	\N
5054	07033P	TWEETER	https://twitter.com/catherine_dumas	\N	\N	\N	\N	\N	1	\N	\N
5056	07033P	FACEBOOK	https://www.facebook.com/100005509571240	\N	\N	\N	\N	\N	3	\N	\N
5057	07033P	LINKEDIN	https://www.linkedin.com/search/results/all/?keywords=catherine%20dumas&origin=RICH_QUERY_SUGGESTION&position=0&searchId=53e08a40-ac6b-46c9-87de-8168a60014fd	\N	\N	\N	\N	\N	2	\N	\N
5066	19768N	TWEETER	https://twitter.com/noel_sylviane	\N	\N	\N	\N	\N	1	\N	\N
5067	19768N	FACEBOOK	https://www.facebook.com/835524589	\N	\N	\N	\N	\N	2	\N	\N
3081	08019V	FACEBOOK	https://www.facebook.com/Michel-Magras-345234268906087/timeline/	\N	\N	\N	\N	\N	2	2015-10-09 14:24:14	2015-10-09 14:24:58
3381	14223L	PAGPER	http://brigittemicouleau.fr/	\N	\N	\N	\N	\N	2	2016-05-13 09:31:24	2016-05-13 09:31:40
3382	14223L	TWEETER	https://twitter.com/bmicouleau	\N	\N	\N	\N	\N	1	2016-05-13 09:31:40	2016-05-13 09:32:03
3522	14235Q	PAGPER	http://christineprunaud.fr/	\N	\N	\N	\N	\N	2	2016-11-25 17:21:58	2016-11-25 17:22:20
3521	14235Q	FACEBOOK	https://www.facebook.com/Christine-Prunaud-S%C3%A9natrice-des-C%C3%B4tes-dArmor-322233454640961/	\N	\N	\N	\N	\N	1	2016-11-25 17:21:15	2016-11-25 17:21:54
3669	08060W	TWEETER	https://twitter.com/bonnefoy_n	\N	\N	\N	\N	\N	3	2017-11-16 16:31:06	2017-11-16 16:31:20
4383	14225N	FACEBOOK	https://www.facebook.com/100008491358548	\N	\N	\N	\N	\N	2	\N	\N
4623	20018V	PAGPER	https://www.jeanjacquesmichau.com/	\N	\N	\N	\N	\N	1	\N	\N
4624	20018V	FACEBOOK	https://www.facebook.com/100063877743752	\N	\N	\N	\N	\N	2	\N	\N
3701	95030B	PAGPER	http://www.senateurs-emorine-mercier.fr	\N	\N	\N	\N	\N	1	2017-11-30 14:33:43	2017-11-30 14:34:02
3921	19347U	PAGPER	http://guillaume-gontard.fr/	\N	\N	\N	\N	\N	1	\N	\N
3922	19347U	TWEETER	https://twitter.com/GuillaumGontard	\N	\N	\N	\N	\N	2	\N	\N
4143	14205J	PAGPER	http://acloisier.fr/	\N	\N	\N	\N	\N	4	\N	\N
4384	14225N	TWEETER	https://twitter.com/clauderaynal?lang=fr	\N	\N	\N	\N	\N	1	\N	\N
4403	08010L	FACEBOOK	https://www.facebook.com/100058089369863	\N	\N	\N	\N	\N	2	\N	\N
4404	08010L	LINKEDIN	https://fr.linkedin.com/in/antoine-lef%C3%A8vre-41046a206	\N	\N	\N	\N	\N	3	\N	\N
4645	19585H	TWEETER	https://twitter.com/danywattebled	\N	\N	\N	\N	\N	1	\N	\N
4646	19585H	FACEBOOK	https://fr-fr.facebook.com/100057902925294	\N	\N	\N	\N	\N	2	\N	\N
4647	20266L	FACEBOOK	https://www.facebook.com/100078760544031	\N	\N	\N	\N	\N	1	\N	\N
4648	20266L	TWEETER	https://twitter.com/Melanie_Vogel_?ref_src=twsrc%5Egoogle%7Ctwcamp%5Eserp%7Ctwgr%5Eauthor	\N	\N	\N	\N	\N	2	\N	\N
4649	20058E	FACEBOOK	https://fr-fr.facebook.com/1214227894	\N	\N	\N	\N	\N	1	\N	\N
4650	20058E	TWEETER	https://twitter.com/cedricvial	\N	\N	\N	\N	\N	2	\N	\N
4653	20122U	FACEBOOK	https://www.facebook.com/100063453024506	\N	\N	\N	\N	\N	2	\N	\N
4652	20122U	TWEETER	https://twitter.com/pjverzelen	\N	\N	\N	\N	\N	1	\N	\N
4656	19479G	LINKEDIN	https://fr.linkedin.com/in/sylvie-vermeillet-87a945194	\N	\N	\N	\N	\N	2	\N	\N
4655	19479G	TWEETER	https://twitter.com/s_vermeillet	\N	\N	\N	\N	\N	1	\N	\N
4657	19749K	TWEETER	https://twitter.com/verienparent	\N	\N	\N	\N	\N	1	\N	\N
4658	19749K	FACEBOOK	https://fr-fr.facebook.com/100058233634368	\N	\N	\N	\N	\N	2	\N	\N
4711	19667J	FACEBOOK	https://www.facebook.com/100057929957443	\N	\N	\N	\N	\N	2	\N	\N
4660	20026V	TWEETER	https://twitter.com/anneventalon	\N	\N	\N	\N	\N	1	\N	\N
4712	20024T	FACEBOOK	https://www.facebook.com/677350901	\N	\N	\N	\N	\N	1	\N	\N
4713	20024T	TWEETER	https://twitter.com/@brunobelin	\N	\N	\N	\N	\N	2	\N	\N
4714	20022R	TWEETER	https://twitter.com/@nbellurot	\N	\N	\N	\N	\N	1	\N	\N
4715	20022R	FACEBOOK	https://www.facebook.com/100063840938941	\N	\N	\N	\N	\N	2	\N	\N
4718	19954N	FACEBOOK	https://www.facebook.com/100003094434363	\N	\N	\N	\N	\N	2	\N	\N
4717	19954N	TWEETER	https://twitter.com/@CatBELRHITI	\N	\N	\N	\N	\N	1	\N	\N
4719	20110Q	FACEBOOK	https://www.facebook.com/100036621184741	\N	\N	\N	\N	\N	1	\N	\N
4720	19575F	TWEETER	https://twitter.com/@MartineBerthet	\N	\N	\N	\N	\N	1	\N	\N
4721	19575F	FACEBOOK	https://www.facebook.com/100058063478619	\N	\N	\N	\N	\N	2	\N	\N
4722	19549D	TWEETER	https://twitter.com/@Joelbigot49	\N	\N	\N	\N	\N	1	\N	\N
4723	19549D	FACEBOOK	https://www.facebook.com/100021766428125	\N	\N	\N	\N	\N	2	\N	\N
4724	20116W	FACEBOOK	https://www.facebook.com/100000085483951	\N	\N	\N	\N	\N	2	\N	\N
4725	20116W	LINKEDIN	https://www.linkedin.com/in/bilhac-christian-3932b791/	\N	\N	\N	\N	\N	3	\N	\N
4726	14030Q	LINKEDIN	https://www.linkedin.com/in/annick-billon-5bb58686/	\N	\N	\N	\N	\N	4	\N	\N
4727	17367Q	TWEETER	https://twitter.com/@blanc_etienne	\N	\N	\N	\N	\N	1	\N	\N
4728	17367Q	FACEBOOK	https://fr-fr.facebook.com/100063790746936	\N	\N	\N	\N	\N	2	\N	\N
4729	17367Q	LINKEDIN	https://www.linkedin.com/in/etienneblancaura/	\N	\N	\N	\N	\N	3	\N	\N
4730	20086J	TWEETER	https://twitter.com/@jbblanc84	\N	\N	\N	\N	\N	1	\N	\N
4731	20086J	FACEBOOK	https://www.facebook.com/100056145245008	\N	\N	\N	\N	\N	2	\N	\N
4732	20094J	TWEETER	https://twitter.com/@FlorenceBlatrix	\N	\N	\N	\N	\N	1	\N	\N
4733	20094J	FACEBOOK	https://fr-fr.facebook.com/100063615443852	\N	\N	\N	\N	\N	2	\N	\N
4734	11040E	FACEBOOK	https://www.facebook.com/100008929988476	\N	\N	\N	\N	\N	2	\N	\N
4737	19367Y	FACEBOOK	https://fr-fr.facebook.com/100003148763275	\N	\N	\N	\N	\N	2	\N	\N
4736	19367Y	TWEETER	https://twitter.com/cbonfantidossat	\N	\N	\N	\N	\N	1	\N	\N
4738	11040E	PAGPER	https://ericbocquet.fr/	\N	\N	\N	\N	\N	3	\N	\N
4739	14069U	TWEETER	https://twitter.com/F_Bonhomme	\N	\N	\N	\N	\N	1	\N	2023-11-22 00:00:00
4740	14069U	FACEBOOK	https://www.facebook.com/100057713033480	\N	\N	\N	\N	\N	2	\N	\N
4741	20042V	TWEETER	https://twitter.com/@FBonneauSenat	\N	\N	\N	\N	\N	1	\N	\N
4742	20042V	FACEBOOK	https://www.facebook.com/100058061591173	\N	\N	\N	\N	\N	2	\N	\N
4743	20042V	LINKEDIN	https://www.linkedin.com/in/fran%C3%A7ois-bonneau-7742901b9/	\N	\N	\N	\N	\N	3	\N	\N
4744	08060W	LINKEDIN	https://www.linkedin.com/in/bonnefoy-nicole-3b67a985/	\N	\N	\N	\N	\N	4	\N	\N
4745	20078J	TWEETER	https://twitter.com/@MichelBonnus	\N	\N	\N	\N	\N	1	\N	\N
4746	20078J	FACEBOOK	https://www.facebook.com/100057808582481	\N	\N	\N	\N	\N	2	\N	\N
4747	20138D	TWEETER	https://twitter.com/alexndraborchio?lang=fr	\N	\N	\N	\N	\N	1	\N	\N
4748	20138D	FACEBOOK	https://www.facebook.com/669618683	\N	\N	\N	\N	\N	2	\N	\N
4749	20088L	TWEETER	https://twitter.com/dbouad	\N	\N	\N	\N	\N	1	\N	\N
4750	20088L	FACEBOOK	https://www.facebook.com/100014861104877	\N	\N	\N	\N	\N	2	\N	\N
4751	14105F	TWEETER	https://twitter.com/BouchetGilbert	\N	\N	\N	\N	\N	1	\N	\N
4752	14105F	FACEBOOK	https://fr-fr.facebook.com/100057903857811	\N	\N	\N	\N	\N	2	\N	\N
4753	19643A	FACEBOOK	https://www.facebook.com/100002530770576	\N	\N	\N	\N	\N	2	\N	\N
4754	19643A	LINKEDIN	https://www.linkedin.com/in/c%C3%A9line-boulay-esp%C3%A9ronnier-180537150/	\N	\N	\N	\N	\N	3	\N	\N
4985	20248J	LINKEDIN	https://www.linkedin.com/in/brigitte-dev%C3%A9sa-51b09330/	\N	\N	\N	\N	\N	2	\N	\N
5068	19768N	LINKEDIN	https://www.linkedin.com/in/sylviane-noel-253979174/	\N	\N	\N	\N	\N	3	\N	\N
5069	20096L	FACEBOOK	https://www.facebook.com/100005101215154	\N	\N	\N	\N	\N	2	\N	\N
5070	14071N	TWEETER	https://twitter.com/Mouiller_P	\N	\N	\N	\N	\N	1	\N	\N
5071	14071N	FACEBOOK	https://www.facebook.com/100057976483030	\N	\N	\N	\N	\N	2	\N	\N
5072	04070G	TWEETER	https://twitter.com/C_MorinDesailly	\N	\N	\N	\N	\N	2	\N	\N
5073	04070G	FACEBOOK	https://www.facebook.com/100057881865916	\N	\N	\N	\N	\N	3	\N	\N
5074	14257W	TWEETER	https://twitter.com/FranckMontauge	\N	\N	\N	\N	\N	1	\N	\N
5075	14109K	FACEBOOK	https://www.facebook.com/100057951104992	\N	\N	\N	\N	\N	1	\N	\N
5127	14059S	FACEBOOK	https://www.facebook.com/100051594191958	\N	\N	\N	\N	\N	1	\N	\N
5128	01048V	TWEETER	https://twitter.com/gerardlonguet55	\N	\N	\N	\N	\N	1	\N	\N
5129	01048V	FACEBOOK	https://www.facebook.com/ 100057749603780	\N	\N	\N	\N	\N	2	\N	\N
5130	01048V	LINKEDIN	https://www.linkedin.com/in/gerardlonguet55/	\N	\N	\N	\N	\N	3	\N	\N
5131	14219Q	TWEETER	https://twitter.com/jf_longeot	\N	\N	\N	\N	\N	1	\N	\N
5132	14219Q	FACEBOOK	https://www.facebook.com/ 100058128217566	\N	\N	\N	\N	\N	2	\N	\N
5133	14219Q	LINKEDIN	https://www.linkedin.com/in/jean-fran%C3%A7ois-longeot-8a6496201/	\N	\N	\N	\N	\N	3	\N	\N
5231	20056C	LINKEDIN	https://www.linkedin.com/in/else-joseph-8a1a124a/	\N	\N	\N	\N	\N	3	\N	\N
5240	19683J	TWEETER	https://twitter.com/@BernardJomier	\N	\N	\N	\N	\N	1	\N	\N
5241	19683J	FACEBOOK	https://www.facebook.com/100057960404447	\N	\N	\N	\N	\N	2	\N	\N
5625	21048G	PAGPER	http://www.gregoryblanc.fr	\N	\N	\N	Importé par Irene	ACTIF	1	\N	\N
5245	19715Y	TWEETER	https://twitter.com/SenatriceJasmin	\N	\N	\N	\N	\N	1	\N	\N
5244	14121F	LINKEDIN	https://www.linkedin.com/in/%C3%A9ric-jeansannetas-37b937172/	\N	\N	\N	\N	\N	4	\N	\N
5246	19715Y	FACEBOOK	https://www.facebook.com/100058175043867	\N	\N	\N	\N	\N	2	\N	\N
5247	19715Y	LINKEDIN	https://www.linkedin.com/in/victoire-jasmin-ab751611a/	\N	\N	\N	\N	\N	3	\N	\N
5248	19511N	TWEETER	https://twitter.com/jmjanssens	\N	\N	\N	\N	\N	1	\N	\N
5249	19511N	FACEBOOK	https://www.facebook.com/100000602959919	\N	\N	\N	\N	\N	2	\N	\N
5252	19551W	FACEBOOK	https://www.facebook.com/100004069132238	\N	\N	\N	\N	\N	2	\N	\N
5251	19551W	TWEETER	https://twitter.com/Jacquin_Olivier	\N	\N	\N	\N	\N	1	\N	\N
5255	20066E	FACEBOOK	https://www.facebook.com/100064112110078	\N	\N	\N	\N	\N	2	\N	\N
5254	20066E	TWEETER	https://twitter.com/JacquemetAnnick	\N	\N	\N	\N	\N	1	\N	\N
5256	20066E	LINKEDIN	https://www.linkedin.com/in/annick-jacquemet-b41315159/	\N	\N	\N	\N	\N	3	\N	\N
5264	19695N	TWEETER	https://twitter.com/fabien_gay	\N	\N	\N	\N	\N	1	\N	\N
5267	19695N	FACEBOOK	https://www.facebook.com/100044361462853	\N	\N	\N	\N	\N	2	\N	\N
5269	19695N	LINKEDIN	https://www.linkedin.com/in/fabien-gay-683285109/	\N	\N	\N	\N	\N	3	\N	\N
5563	20034V	INSTAGRAM	https://www.instagram.com/micheline.jacques.senateur/	\N	\N	\N	\N	\N	3	\N	\N
5273	20120S	FACEBOOK	https://www.facebook.com/100063525588113	\N	\N	\N	\N	\N	2	\N	\N
5274	20120S	LINKEDIN	https://www.linkedin.com/in/fabien-genet-207a1956/	\N	\N	\N	\N	\N	3	\N	\N
5626	21089R	FACEBOOK	https://www.facebook.com/ColombeBrosselParis	\N	\N	\N	Importé par Irene	ACTIF	1	\N	2023-11-06 00:00:00
5276	14355X	FACEBOOK	https://www.facebook.com/100014911986800	\N	\N	\N	\N	\N	2	\N	\N
5278	19387D	TWEETER	https://twitter.com/egold_senat	\N	\N	\N	\N	\N	1	\N	\N
5279	19387D	FACEBOOK	https://www.facebook.com/1626575065	\N	\N	\N	\N	\N	2	\N	\N
5280	19387D	LINKEDIN	https://www.linkedin.com/in/%C3%A9ric-gold-2a55b5165/	\N	\N	\N	\N	\N	3	\N	\N
5282	19347U	FACEBOOK	https://www.facebook.com/100009151634114	\N	\N	\N	\N	\N	3	\N	\N
5285	20180F	FACEBOOK	https://www.facebook.com/100061942819989	\N	\N	\N	\N	\N	1	\N	\N
5289	07004J	FACEBOOK	https://www.facebook.com/100057751881737	\N	\N	\N	\N	\N	5	\N	\N
5293	08056B	TWEETER	https://twitter.com/SGoyChavent	\N	\N	\N	\N	\N	1	\N	\N
5294	08056B	FACEBOOK	https://www.facebook.com/100023178783040	\N	\N	\N	\N	\N	2	\N	\N
5762	21071F	INSTAGRAM	htthttps://www.instagram.com/mariedoaeschlimann/	\N	\N	\N	\N	\N	4	\N	\N
5757	21029D	FACEBOOK	https://www.facebook.com/georgesnaturel2023	\N	\N	\N	\N	\N	2	\N	\N
5764	21046E	INSTAGRAM	https://www.instagram.com/corinne_bourcier/	\N	\N	\N	\N	\N	4	\N	\N
5765	21088Q	INSTAGRAM	https://www.instagram.com/ianbrossatsenateur/	\N	\N	\N	\N	\N	3	\N	\N
5766	21096Q	INSTAGRAM	https://www.instagram.com/frederic_buval/	\N	\N	\N	\N	\N	2	\N	\N
5906	19489J	YOUTUBE	https://www.youtube.com/channel/UC3iQl2sXyEPmDL2N3BniqDw	\N	\N	\N	\N	\N	4	2023-11-14 00:00:00	\N
5768	21065H	FACEBOOK	https://www.facebook.com/profile.php?id=61551806835411&sk=about	\N	\N	\N	\N	\N	1	\N	2023-11-08 00:00:00
5769	21074J	INSTAGRAM	https://www.instagram.com/aymeric_durox/	\N	\N	\N	\N	\N	4	\N	\N
5770	21091K	INSTAGRAM	https://www.instagram.com/agnes.evren/	\N	\N	\N	\N	\N	3	\N	\N
5771	19111A	INSTAGRAM	https://www.instagram.com/isabelle.florennes2023/	\N	\N	\N	\N	\N	4	\N	\N
5772	21032X	INSTAGRAM	https://www.instagram.com/annickgirardin/	\N	\N	\N	\N	\N	4	\N	\N
5773	21066J	INSTAGRAM	https://www.instagram.com/pgrosvalet/	\N	\N	\N	\N	\N	1	\N	\N
5774	21092L	INSTAGRAM	https://www.instagram.com/guhlantoinette/	\N	\N	\N	\N	\N	4	\N	\N
5777	21093M	INSTAGRAM	https://www.instagram.com/yannickjadot/	\N	\N	\N	\N	\N	4	\N	\N
5776	21085M	INSTAGRAM	https://www.instagram.com/joshua_hochart/	\N	\N	\N	\N	\N	2	\N	\N
5778	21044C	INSTAGRAM	https://www.instagram.com/lauriane_josende/	\N	\N	\N	\N	\N	4	\N	\N
5803	21029D	TWEETER	https://twitter.com/georgesNaturel	\N	\N	\N	\N	\N	1	\N	\N
5780	21087P	INSTAGRAM	https://www.instagram.com/telam59/	\N	\N	\N	\N	\N	1	\N	\N
5903	18395Y	TWEETER	https://twitter.com/KarineDaniel44	\N	\N	\N	\N	\N	1	\N	2023-11-14 00:00:00
6063	19111A	PAGPER	https://www.isabelleflorennes.fr/	\N	\N	\N	\N	\N	5	2024-03-26 00:00:00	2024-03-26 00:00:00
5425	20914V	PAGPER	https://danielbreuiller.com 	\N	\N	\N	\N	\N	1	\N	\N
5365	20078J	PAGPER	http://www.senat.fr/	\N	\N	\N	\N	\N	3	\N	\N
5366	19057M	PAGPER	https://www.samantha-cazebonne.com 	\N	\N	\N	\N	\N	4	\N	\N
5426	20914V	FACEBOOK	https://www.facebook.com/1195722539	\N	\N	\N	\N	\N	2	\N	\N
5720	21070E	FACEBOOK	https://www.facebook.com/pjrochette	\N	\N	\N	\N	\N	1	\N	\N
5725	21038E	LINKEDIN	https://www.linkedin.com/in/olivia-richard-771653b5/	\N	\N	\N	\N	\N	1	\N	2023-11-23 00:00:00
5883	21065H	TWEETER	https://twitter.com/ChevalierSenat	\N	\N	\N	\N	\N	2	2023-11-08 00:00:00	\N
5618	21060C	PAGPER	https://alexandreouizille.fr/	\N	\N	\N	Importé par Irene	ACTIF	1	\N	\N
5619	21060C	FACEBOOK	https://www.facebook.com/AlexandreOuizille/	\N	\N	\N	Importé par Irene	ACTIF	1	\N	\N
5620	21060C	TWEETER	https://twitter.com/Aouizille	\N	\N	\N	Importé par Irene	ACTIF	1	\N	\N
5621	21060C	LINKEDIN	https://fr.linkedin.com/in/alexandreouizille	\N	\N	\N	Importé par Irene	ACTIF	1	\N	\N
5622	21060C	INSTAGRAM	https://www.instagram.com/alexandreouizille/	\N	\N	\N	Importé par Irene	ACTIF	1	\N	\N
5623	21060C	YOUTUBE	https://www.youtube.com/channel/UCQJXm1FSsmRXnkx2IgM6WhA	\N	\N	\N	Importé par Irene	ACTIF	1	\N	\N
5646	21042A	TWEETER	https://twitter.com/Antoinejocelyn6	\N	\N	\N	\N	\N	1	\N	\N
5647	21042A	FACEBOOK	https://www.facebook.com/suzanne.golfier	\N	\N	\N	\N	\N	2	\N	\N
5806	21035B	LINKEDIN	https://www.linkedin.com/in/audrey-belim-4a335b104/	\N	\N	\N	\N	\N	2	\N	\N
5650	21084L	FACEBOOK	https://www.facebook.com/profile.php?id=100092547395047	\N	\N	\N	\N	\N	2	\N	\N
5653	21084L	LINKEDIN	https://www.linkedin.com/in/pierre-barros-50b50286/	\N	\N	\N	\N	\N	3	\N	\N
5667	21043B	FACEBOOK	https://www.facebook.com/profile.php?id=61556997327696	\N	\N	\N	\N	\N	1	\N	2024-03-19 00:00:00
5675	21077M	FACEBOOK	https://www.facebook.com/adel.ziane.senat/	\N	\N	\N	\N	\N	2	\N	2023-10-24 00:00:00
5674	21077M	TWEETER	https://twitter.com/adel_ziane	\N	\N	\N	\N	\N	1	\N	\N
5677	21077M	LINKEDIN	https://www.linkedin.com/in/adel-ziane-30395920/	\N	\N	\N	\N	\N	3	\N	\N
5680	21082J	TWEETER	https://twitter.com/MichaelWeber1	\N	\N	\N	\N	\N	1	\N	\N
5682	21082J	FACEBOOK	https://www.facebook.com/Michael.Weber.Senat	\N	\N	\N	\N	\N	2	\N	2024-01-04 00:00:00
5684	21076L	FACEBOOK	https://www.facebook.com/lvogel77	\N	\N	\N	\N	\N	2	\N	\N
5685	21076L	TWEETER	https://twitter.com/louisvogel	\N	\N	\N	\N	\N	1	\N	\N
5691	21031W	TWEETER	https://twitter.com/jmvayssouze	\N	\N	\N	\N	\N	1	\N	\N
5693	21031W	FACEBOOK	https://www.facebook.com/jeanmarc.vayssouzefaure	\N	\N	\N	\N	\N	2	\N	\N
5697	21051B	TWEETER	https://twitter.com/SimonUzenat	\N	\N	\N	\N	\N	1	\N	\N
5698	21051B	FACEBOOK	https://www.facebook.com/s.uzenat	\N	\N	\N	\N	\N	2	\N	\N
5807	21089R	LINKEDIN	https://www.linkedin.com/in/colombe-brossel-20882b23b/	\N	\N	\N	\N	\N	2	\N	\N
5700	21051B	LINKEDIN	https://www.linkedin.com/in/simonuzenat/	\N	\N	\N	\N	\N	3	\N	\N
5787	21034A	INSTAGRAM	https://www.instagram.com/evelynecorbiere/	\N	\N	\N	\N	\N	2	\N	\N
5808	21045D	LINKEDIN	https://www.linkedin.com/in/marion-canales-0a0640161/	\N	\N	\N	\N	\N	3	\N	\N
5809	21090J	LINKEDIN	https://www.linkedin.com/in/marie-claire-carrere-gee-b15b61157/	\N	\N	\N	\N	\N	4	\N	\N
5810	21072G	LINKEDIN	https://www.linkedin.com/in/marie-carole-ciuntu/	\N	\N	\N	\N	\N	3	\N	\N
5811	21087P	LINKEDIN	https://www.linkedin.com/in/marie-c-lermytte-bavay-4511657a/	\N	\N	\N	\N	\N	2	\N	\N
5812	21058J	LINKEDIN	https://www.linkedin.com/in/pauline-martin-506b14170/	\N	\N	\N	\N	\N	1	\N	\N
5813	21040X	LINKEDIN	https://www.linkedin.com/in/michel-masset-5998b7b9/	\N	\N	\N	\N	\N	1	\N	\N
5814	21080G	LINKEDIN	https://www.linkedin.com/in/damien-michallet-5649287/	\N	\N	\N	\N	\N	3	\N	\N
5815	18231D	LINKEDIN	https://www.linkedin.com/in/corinnenarassiguin/	\N	\N	\N	\N	\N	4	\N	\N
5816	21029D	LINKEDIN	https://www.linkedin.com/in/georges-naturel-440a72170/	\N	\N	\N	\N	\N	3	\N	\N
5817	19331L	LINKEDIN	https://www.linkedin.com/in/sa%C3%AFd-omar-oili-30844a168/	\N	\N	\N	\N	\N	2	\N	\N
5818	21068L	LINKEDIN	https://www.linkedin.com/in/hervereynaud/	\N	\N	\N	\N	\N	2	\N	\N
5819	21070E	LINKEDIN	https://www.linkedin.com/in/pierrejeanrochette/	\N	\N	\N	\N	\N	2	\N	\N
5820	21064G	LINKEDIN	https://www.linkedin.com/in/anne-sophie-romagny-00233215/	\N	\N	\N	\N	\N	1	\N	\N
5821	21059K	LINKEDIN	https://www.linkedin.com/in/david-ros-a9038710a/	\N	\N	\N	\N	\N	2	\N	\N
5822	21036C	LINKEDIN	https://www.linkedin.com/in/jean-luc-ruelle-0b737229/	\N	\N	\N	\N	\N	1	\N	\N
5823	21049H	LINKEDIN	https://www.linkedin.com/in/silvana-silvani-3a26b852/	\N	\N	\N	\N	\N	2	\N	\N
5824	21095P	LINKEDIN	https://www.linkedin.com/in/francis-szpiner/	\N	\N	\N	\N	\N	3	\N	\N
5825	21076L	LINKEDIN	https://www.linkedin.com/in/louis-vogel-5609a787/	\N	\N	\N	\N	\N	3	\N	\N
5923	21040X	FACEBOOK	https://www.facebook.com/profile.php?id=61553676331171	\N	\N	\N	\N	\N	2	2023-11-23 00:00:00	\N
5943	21080G	TWEETER	https://twitter.com/DMichallet	\N	\N	\N	\N	\N	4	2024-01-16 00:00:00	\N
5983	19703U	YOUTUBE	https://www.youtube.com/@JeanSOLSenateur	\N	\N	\N	\N	\N	5	2024-02-01 00:00:00	2024-02-01 00:00:00
5984	19703U	LINKEDIN	https://www.linkedin.com/in/jean-sol-senateur	\N	\N	\N	\N	\N	3	2024-02-01 00:00:00	\N
5985	19703U	INSTAGRAM	https://www.instagram.com/jeansol66	\N	\N	\N	\N	\N	4	2024-02-01 00:00:00	2024-02-01 00:00:00
5443	20082E	PAGPER	https://credonsarrazy.fr/	\N	\N	\N	\N	\N	1	\N	\N
5583	14089Y	PAGPER	http://www.philippebonnecarrere.fr/	\N	\N	\N	\N	\N	1	\N	\N
5584	14089Y	YOUTUBE	https://www.youtube.com/channel/UCVKKJnrFnp318hrMRLUHW7A	\N	\N	\N	\N	\N	2	\N	\N
5616	21085M	FACEBOOK	https://www.facebook.com/JoshuaHochart	\N	\N	\N	Importé par Irene	ACTIF	1	\N	\N
5617	21085M	TWEETER	https://twitter.com/joshuaHochart	\N	\N	\N	Importé par Irene	ACTIF	1	\N	\N
5781	21075K	INSTAGRAM	https://www.instagram.com/margatemarianne/	\N	\N	\N	\N	\N	3	\N	\N
5782	21073H	INSTAGRAM	https://www.instagram.com/akli_mellouli_/	\N	\N	\N	\N	\N	4	\N	\N
5783	21080G	INSTAGRAM	https://www.instagram.com/damien_michallet/	\N	\N	\N	\N	\N	2	\N	\N
5784	21097R	INSTAGRAM	https://www.instagram.com/solanges_vala_nadille/	\N	\N	\N	\N	\N	1	\N	\N
5785	18231D	INSTAGRAM	https://www.instagram.com/corinnenarassiguin/	\N	\N	\N	\N	\N	3	\N	\N
5963	20034V	PAGPER	https://michelinejacques.fr/	\N	\N	\N	\N	\N	4	2024-01-30 00:00:00	\N
6023	21043B	TWEETER	https://twitter.com/OlivierBitz	\N	\N	\N	\N	\N	2	2024-03-19 00:00:00	\N
5232	20286Q	TWEETER	https://twitter.com/amel_gacquerre	\N	\N	\N	\N	\N	1	\N	\N
5233	20286Q	FACEBOOK	https://www.facebook.com/1618332965	\N	\N	\N	\N	\N	2	\N	\N
5234	20286Q	LINKEDIN	https://www.linkedin.com/in/amel-gacquerre-29a59086/	\N	\N	\N	\N	\N	3	\N	\N
5235	20172F	TWEETER	https://twitter.com/LGarnier44	\N	\N	\N	\N	\N	1	\N	\N
5236	20172F	FACEBOOK	https://www.facebook.com/100060185894411	\N	\N	\N	\N	\N	2	\N	\N
5237	20172F	LINKEDIN	https://www.linkedin.com/in/laurence-garnier-77256080/	\N	\N	\N	\N	\N	3	\N	\N
5238	04035D	LINKEDIN	https://www.linkedin.com/in/jgarriaudmaylam/	\N	\N	\N	\N	\N	2	\N	\N
5239	11083R	LINKEDIN	hhttps://www.linkedin.com/in/andr%C3%A9-gattolin-5712925/	\N	\N	\N	\N	\N	2	\N	\N
5257	14213J	LINKEDIN	https://www.linkedin.com/in/corinne-imbert-b67a03166/	\N	\N	\N	\N	\N	3	\N	\N
5258	19591F	LINKEDIN	https://www.linkedin.com/in/xavier-iacovelli-35239445/	\N	\N	\N	\N	\N	3	\N	\N
5259	11048N	TWEETER	https://twitter.com/jf_husson	\N	\N	\N	\N	\N	1	\N	\N
5260	11048N	FACEBOOK	https://www.facebook.com/100063871803630	\N	\N	\N	\N	\N	2	\N	\N
5261	11048N	LINKEDIN	https://www.linkedin.com/in/jean-francois-husson-587749ab/	\N	\N	\N	\N	\N	3	\N	\N
5262	19399H	LINKEDIN	https://www.linkedin.com/in/jean-raymond-hugonet-a4880133/	\N	\N	\N	\N	\N	3	\N	\N
5263	08069G	LINKEDIN	https://www.linkedin.com/in/alain-h-b910078a/	\N	\N	\N	\N	\N	3	\N	\N
5363	19745F	PAGPER	 https://evelyneperrot.wordpress.com/	\N	\N	\N	\N	\N	2	\N	\N
5383	20264J	PAGPER	www.yanchantrel.com 	\N	\N	\N	\N	\N	4	\N	\N
5423	19621T	PAGPER	https://www.maxbrisson.fr	\N	\N	\N	\N	\N	3	\N	\N
5643	21071F	TWEETER	https://twitter.com/MDoAeschlimann	\N	\N	\N	\N	\N	1	\N	\N
5644	21071F	FACEBOOK	https://www.facebook.com/mariedo.aeschlimann	\N	\N	\N	\N	\N	2	\N	\N
5610	21094N	PAGPER	http://www.annesouyris.fr	\N	\N	\N	Importé par Irene	ACTIF	6	\N	\N
5611	21094N	FACEBOOK	https://www.facebook.com/annesouyrisparis	\N	\N	\N	Importé par Irene	ACTIF	2	\N	\N
5612	21094N	TWEETER	https://x.com/annesouyris	\N	\N	\N	Importé par Irene	ACTIF	1	\N	\N
5613	21094N	LINKEDIN	https://www.linkedin.com/in/annesouyris	\N	\N	\N	Importé par Irene	ACTIF	3	\N	\N
5614	21094N	INSTAGRAM	https://instagram.com/annesouyris	\N	\N	\N	Importé par Irene	ACTIF	4	\N	\N
5615	21094N	YOUTUBE	http://www.youtube.com/@annesouyris2498	\N	\N	\N	Importé par Irene	ACTIF	5	\N	\N
5863	21089R	TWEETER	https://twitter.com/cbrossel	\N	\N	\N	\N	\N	3	2023-11-06 00:00:00	\N
6043	19533U	PAGPER	https://stephanepiednoir.fr	\N	\N	\N	\N	\N	4	2024-03-22 00:00:00	\N
5299	20072C	FACEBOOK	https://www.facebook.com/100064751168753	\N	\N	\N	\N	\N	1	\N	\N
5300	19553Y	TWEETER	https://twitter.com/VGUILLOTIN	\N	\N	\N	\N	\N	1	\N	\N
5301	19553Y	FACEBOOK	https://www.facebook.com/100057736792408	\N	\N	\N	\N	\N	2	\N	\N
5304	19691J	FACEBOOK	https://www.facebook.com/100013697561509	\N	\N	\N	\N	\N	2	\N	\N
5303	19691J	TWEETER	https://twitter.com/JocelyneGuidez	\N	\N	\N	\N	\N	1	\N	\N
5305	11064N	LINKEDIN	https://www.linkedin.com/in/joelguerriau/	\N	\N	\N	\N	\N	3	\N	\N
5701	21095P	TWEETER	https://twitter.com/fszpiner	\N	\N	\N	\N	\N	1	\N	\N
5307	98022P	FACEBOOK	https://www.facebook.com/100057957312899	\N	\N	\N	\N	\N	3	\N	\N
5308	14026U	TWEETER	https://twitter.com/PascaleGruny02	\N	\N	\N	\N	\N	1	\N	\N
5309	14026U	FACEBOOK	https://www.facebook.com/100000736606812	\N	\N	\N	\N	\N	2	\N	\N
5312	14123H	FACEBOOK	https://www.facebook.com/100066851857850	\N	\N	\N	\N	\N	2	\N	\N
5702	21095P	FACEBOOK	https://www.facebook.com/profile.php?id=100087130636110	\N	\N	\N	\N	\N	2	\N	\N
5313	14123H	LINKEDIN	https://www.linkedin.com/in/jacques-grosperrin-61b9b477/	\N	\N	\N	\N	\N	3	\N	\N
5703	21069M	TWEETER	https://twitter.com/C_Szczurek	\N	\N	\N	\N	\N	1	\N	\N
5708	21049H	FACEBOOK	https://www.facebook.com/silvana.silvani.1	\N	\N	\N	\N	\N	1	\N	\N
5709	21079P	TWEETER	https://twitter.com/GhislaineSenee	\N	\N	\N	\N	\N	1	\N	\N
5904	19489J	PAGPER	 https://erickerrouche.fr/	\N	\N	\N	\N	\N	5	\N	2023-11-14 00:00:00
5715	21059K	TWEETER	https://twitter.com/DavidRos_91	\N	\N	\N	\N	\N	1	\N	\N
5729	21068L	FACEBOOK	https://www.facebook.com/herve.reynaud.10	\N	\N	\N	\N	\N	1	\N	\N
5718	21056G	FACEBOOK	https://www.facebook.com/pierrealain.roiron.16	\N	\N	\N	\N	\N	1	\N	\N
5730	21053D	FACEBOOK	https://www.facebook.com/bernard.pillefer.3?locale=fr_FR	\N	\N	\N	\N	\N	1	\N	\N
5733	21047F	FACEBOOK	https://www.facebook.com/clement.pernot.50/?locale=fr_FR	\N	\N	\N	\N	\N	1	\N	\N
5749	19331L	FACEBOOK	https://www.facebook.com/profile.php?id=100064592356524	\N	\N	\N	\N	\N	1	\N	\N
5750	21037D	TWEETER	https://twitter.com/Mat_OLLIVIER	\N	\N	\N	\N	\N	1	\N	\N
5752	21037D	FACEBOOK	https://www.facebook.com/Mathilde.Ollivier.Circo7	\N	\N	\N	\N	\N	2	\N	\N
5755	21037D	INSTAGRAM	https://www.instagram.com/mathilde_ollivier/	\N	\N	\N	\N	\N	3	\N	\N
5758	18395Y	FACEBOOK	https://www.facebook.com/KarineDanielNantes	\N	\N	\N	\N	\N	2	\N	\N
5759	18395Y	LINKEDIN	https://www.linkedin.com/in/karine-daniel-740b85a5/	\N	\N	\N	\N	\N	3	\N	\N
5760	21067K	FACEBOOK	https://www.facebook.com/jerome.darras.528	\N	\N	\N	\N	\N	1	\N	\N
5761	21077M	INSTAGRAM	https://www.instagram.com/adelziane/	\N	\N	\N	\N	\N	4	\N	\N
5763	21082J	INSTAGRAM	https://www.instagram.com/michael_weber974/	\N	\N	\N	\N	\N	3	\N	\N
5843	21079P	INSTAGRAM	https://www.instagram.com/ghislainesenee/	\N	\N	\N	\N	\N	2	2023-10-25 00:00:00	\N
6004	21056G	LINKEDIN	https://www.linkedin.com/in/pierre-alain-roiron-b748502a0/	\N	\N	\N	\N	\N	3	2024-02-07 00:00:00	\N
6003	21056G	TWEETER	https://twitter.com/paroiron37	\N	\N	\N	\N	\N	2	2024-02-07 00:00:00	\N
5265	19333N	TWEETER	https://twitter.com/JMHoullegatte	\N	\N	\N	\N	\N	1	\N	\N
5266	19333N	FACEBOOK	https://www.facebook.com/100000647933122	\N	\N	\N	\N	\N	2	\N	\N
5268	19333N	LINKEDIN	https://www.linkedin.com/in/jean-michel-houllegatte-6582a43b/	\N	\N	\N	\N	\N	3	\N	\N
5607	21090J	PAGPER	https://marieclairecarreregee.com/	\N	\N	\N	Importé par Irene	ACTIF	1	\N	\N
5272	20048C	FACEBOOK	https://www.facebook.com/575063842	\N	\N	\N	\N	\N	2	\N	\N
5277	19685L	FACEBOOK	https://www.facebook.com/100063569657337	\N	\N	\N	\N	\N	1	\N	\N
5281	19569H	TWEETER	https://twitter.com/OHenno	\N	\N	\N	\N	\N	1	\N	\N
5283	19569H	FACEBOOK	https://www.facebook.com/1516694139	\N	\N	\N	\N	\N	2	\N	\N
5284	19569H	LINKEDIN	https://www.linkedin.com/in/olivier-henno-28641964/	\N	\N	\N	\N	\N	3	\N	\N
5543	20082E	FACEBOOK	https://www.facebook.com/100088163585941	\N	\N	\N	\N	\N	4	\N	\N
5287	20128B	FACEBOOK	https://www.facebook.com/100064162956438	\N	\N	\N	\N	\N	2	\N	\N
5288	20128B	LINKEDIN	https://www.linkedin.com/in/ludovic-haye-89a41978/	\N	\N	\N	\N	\N	3	\N	\N
5292	20106U	LINKEDIN	https://www.linkedin.com/in/nadege-havet/	\N	\N	\N	\N	\N	3	\N	\N
5608	21090J	TWEETER	https://twitter.com/@mccg	\N	\N	\N	Importé par Irene	ACTIF	2	\N	\N
5296	19725B	FACEBOOK	https://www.facebook.com/1609743481	\N	\N	\N	\N	\N	2	\N	\N
5297	19725B	LINKEDIN	https://www.linkedin.com/in/laurence-harribey-2b7b8858/	\N	\N	\N	\N	\N	3	\N	\N
5403	20110Q	TWEETER	https://twitter.com/GuyBenarroche	\N	\N	\N	\N	\N	2	\N	\N
5404	20110Q	PAGPER	https://guy-benarroche.fr/	\N	\N	\N	\N	\N	3	\N	\N
5464	19585H	PAGPER	http://www.senat.fr/	\N	\N	\N	\N	\N	3	\N	\N
5483	20040T	FACEBOOK	https://fr-fr.facebook.com/100077989782277	\N	\N	\N	\N	\N	1	\N	\N
5609	21090J	INSTAGRAM	https://www.instagram.com/marieclairecarreregee	\N	\N	\N	Importé par Irene	ACTIF	3	\N	\N
5503	14069U	PAGPER	http://www.senat.fr/	\N	\N	\N	\N	\N	3	\N	\N
5645	21071F	LINKEDIN	https://www.linkedin.com/in/marie-do-aeschlimann-36a4b576/	\N	\N	\N	\N	\N	3	\N	\N
5648	21084L	TWEETER	https://twitter.com/PierreBarros95	\N	\N	\N	\N	\N	1	\N	\N
5654	21035B	FACEBOOK	https://www.facebook.com/AudreyBelimElue	\N	\N	\N	\N	\N	1	\N	\N
5655	21048G	TWEETER	https://twitter.com/gregory_blanc	\N	\N	\N	\N	\N	2	\N	\N
5656	21048G	FACEBOOK	https://www.facebook.com/gregory.blanc.927	\N	\N	\N	\N	\N	3	\N	\N
5657	21050A	FACEBOOK	https://www.facebook.com/yves.bleunven.7	\N	\N	\N	\N	\N	1	\N	\N
5658	21046E	TWEETER	https://twitter.com/BourcierCorinne	\N	\N	\N	\N	\N	1	\N	\N
5659	21046E	FACEBOOK	https://www.facebook.com/corinne.pouplard.5	\N	\N	\N	\N	\N	2	\N	\N
5660	21046E	LINKEDIN	https://www.linkedin.com/in/corinne-bourcier-8138a1107/	\N	\N	\N	\N	\N	3	\N	\N
5661	21088Q	TWEETER	https://twitter.com/IanBrossat	\N	\N	\N	\N	\N	1	\N	\N
5662	21088Q	FACEBOOK	https://www.facebook.com/BrossatIan	\N	\N	\N	\N	\N	2	\N	\N
5663	21063F	TWEETER	https://twitter.com/ChristianBruyen	\N	\N	\N	\N	\N	1	\N	\N
5664	21063F	FACEBOOK	https://www.facebook.com/Bruyen.Christian	\N	\N	\N	\N	\N	2	\N	\N
5665	21096Q	FACEBOOK	https://www.facebook.com/buval.frederic.7	\N	\N	\N	\N	\N	1	\N	\N
5669	21083K	FACEBOOK	https://www.facebook.com/guislain.cambier	\N	\N	\N	\N	\N	2	\N	\N
5668	21083K	TWEETER	https://twitter.com/CambierGuislain	\N	\N	\N	\N	\N	1	\N	\N
5670	21083K	PAGPER	http://www.senat.fr/	\N	\N	\N	\N	\N	3	\N	\N
5672	21045D	TWEETER	https://twitter.com/MarionCanales	\N	\N	\N	\N	\N	1	\N	\N
5673	21045D	FACEBOOK	https://www.facebook.com/marioncanales63	\N	\N	\N	\N	\N	2	\N	\N
5676	21057H	TWEETER	https://twitter.com/C_Chaillou	\N	\N	\N	\N	\N	1	\N	\N
5678	21057H	FACEBOOK	https://www.facebook.com/ChaillouChristophe	\N	\N	\N	\N	\N	2	\N	\N
5679	21072G	TWEETER	https://twitter.com/mcciuntu	\N	\N	\N	\N	\N	1	\N	\N
5681	21072G	FACEBOOK	https://www.facebook.com/mariecarole.ciuntu	\N	\N	\N	\N	\N	2	\N	\N
5683	21034A	FACEBOOK	https://www.facebook.com/profile.php?id=100092330057501	\N	\N	\N	\N	\N	1	\N	\N
5686	15197G	TWEETER	https://twitter.com/FDhersin	\N	\N	\N	\N	\N	1	\N	\N
5687	15197G	FACEBOOK	https://www.facebook.com/franck.dhersin.3	\N	\N	\N	\N	\N	2	\N	\N
5688	15197G	LINKEDIN	https://www.linkedin.com/in/franck-dhersin-ab286b166/	\N	\N	\N	\N	\N	3	\N	\N
5689	21074J	TWEETER	https://twitter.com/AymericDurox	\N	\N	\N	\N	\N	1	\N	\N
5690	21074J	FACEBOOK	https://www.facebook.com/aymericdurox	\N	\N	\N	\N	\N	2	\N	\N
5692	21074J	LINKEDIN	https://www.linkedin.com/in/aymeric-durox-45008a162/	\N	\N	\N	\N	\N	3	\N	\N
5694	21091K	LINKEDIN	https://www.linkedin.com/in/agnes-evren-17047585/	\N	\N	\N	\N	\N	2	\N	\N
5695	21091K	TWEETER	https://twitter.com/AgnesEvren	\N	\N	\N	\N	\N	1	\N	\N
5705	21062E	FACEBOOK	https://www.facebook.com/sebastien.fagnen	\N	\N	\N	\N	\N	2	\N	\N
5704	21062E	TWEETER	https://twitter.com/sebastienfagnen	\N	\N	\N	\N	\N	1	\N	\N
5706	21062E	LINKEDIN	https://www.linkedin.com/in/s%C3%A9bastien-fagnen-a7645b37/	\N	\N	\N	\N	\N	3	\N	\N
5711	21086N	FACEBOOK	https://www.facebook.com/fargeot.daniel/	\N	\N	\N	\N	\N	2	\N	2024-01-08 00:00:00
5710	21086N	TWEETER	https://twitter.com/DanielFargeot	\N	\N	\N	\N	\N	1	\N	\N
5713	19111A	TWEETER	https://twitter.com/iflorennes92	\N	\N	\N	\N	\N	1	\N	\N
5714	19111A	FACEBOOK	https://www.facebook.com/IFlorennes	\N	\N	\N	\N	\N	2	\N	\N
5717	19111A	LINKEDIN	https://www.linkedin.com/in/isabelle-florennes-82406911/	\N	\N	\N	\N	\N	3	\N	\N
5719	21033Y	FACEBOOK	https://www.facebook.com/FouassinStephaneOff	\N	\N	\N	\N	\N	1	\N	\N
5721	21032X	TWEETER	https://twitter.com/AnnickGirardin	\N	\N	\N	\N	\N	1	\N	\N
5722	21032X	FACEBOOK	https://www.facebook.com/annickgirardin.fr	\N	\N	\N	\N	\N	2	\N	\N
5724	21032X	LINKEDIN	https://www.linkedin.com/in/annick-girardin-9597b026a/	\N	\N	\N	\N	\N	3	\N	\N
5726	21092L	TWEETER	https://twitter.com/antoinetteguhl	\N	\N	\N	\N	\N	1	\N	\N
5727	21092L	FACEBOOK	https://www.facebook.com/antoinetteguhl	\N	\N	\N	\N	\N	2	\N	\N
5728	21092L	LINKEDIN	https://www.linkedin.com/in/antoinetteguhl/	\N	\N	\N	\N	\N	3	\N	\N
5731	21093M	TWEETER	https://twitter.com/yjadot	\N	\N	\N	\N	\N	1	\N	\N
5732	21093M	FACEBOOK	https://www.facebook.com/yjadot	\N	\N	\N	\N	\N	2	\N	\N
5734	21093M	LINKEDIN	https://www.linkedin.com/in/yannick-jadot/	\N	\N	\N	\N	\N	3	\N	\N
5735	21044C	TWEETER	https://twitter.com/LJosende	\N	\N	\N	\N	\N	1	\N	\N
5737	21044C	LINKEDIN	https://www.linkedin.com/in/lauriane-josende-04b97a32/	\N	\N	\N	\N	\N	3	\N	\N
5738	21081H	FACEBOOK	https://www.facebook.com/khalife.khalife	\N	\N	\N	\N	\N	1	\N	\N
5739	21078N	TWEETER	https://twitter.com/Ahmedlaouedj68	\N	\N	\N	\N	\N	1	\N	\N
5740	21078N	FACEBOOK	https://www.facebook.com/ahmed.laouedj.7/	\N	\N	\N	\N	\N	2	\N	\N
5741	21054E	TWEETER	https://twitter.com/vincent_louault	\N	\N	\N	\N	\N	1	\N	\N
5742	21054E	FACEBOOK	https://www.facebook.com/vince.louault	\N	\N	\N	\N	\N	2	\N	\N
5743	21054E	LINKEDIN	https://www.linkedin.com/in/vincent-louault-64977582/	\N	\N	\N	\N	\N	3	\N	\N
5744	21075K	TWEETER	https://twitter.com/MargateMarianne	\N	\N	\N	\N	\N	1	\N	\N
5745	21075K	FACEBOOK	https://www.facebook.com/margate77	\N	\N	\N	\N	\N	2	\N	\N
5746	21073H	TWEETER	https://twitter.com/aklimellouli	\N	\N	\N	\N	\N	1	\N	\N
5747	21073H	FACEBOOK	https://www.facebook.com/profile.php?id=100057136281344	\N	\N	\N	\N	\N	2	\N	\N
5748	21073H	LINKEDIN	https://www.linkedin.com/in/akli-mellouli-b053b245/	\N	\N	\N	\N	\N	3	\N	\N
5751	21080G	FACEBOOK	https://www.facebook.com/profile.php?id=100009146313984	\N	\N	\N	\N	\N	1	\N	\N
5753	18231D	TWEETER	https://twitter.com/CorinneNara	\N	\N	\N	\N	\N	1	\N	\N
5754	18231D	FACEBOOK	https://www.facebook.com/CorinneNara	\N	\N	\N	\N	\N	2	\N	\N
\.


--
-- Data for Name: stajur; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY stajur (stajurcod, stajurlic, stajurlib, stajurnumtri, syscredat, sysmajdat) FROM stdin;
NEANT	Indéterminé	Indéterminé	0	\N	\N
DECRET	Décret	Décret	1	\N	\N
LOI	Loi	Loi	2	\N	\N
ORDON	Ordonnance	Ordonnance	3	\N	\N
\.


--
-- Data for Name: telephone; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY telephone (telid, typtelcod, poiconid, telnum, telnumtri, syscredat, sysmajdat) FROM stdin;
55	FIX	885	0228245793	1	2015-07-17 12:05:18	2015-07-17 12:05:40
71	FIX	923	0329794724	1	2016-07-05 16:31:03	2016-07-05 16:31:19
72	MOB	925	0643747435	1	2016-11-10 11:54:52	2016-11-10 11:55:16
79	FIX	1106	0546263223	1	2017-11-14 09:24:19	2017-11-14 09:25:03
86	FIX	1115	02 98 52 42 09	1	2017-11-16 16:22:17	2017-11-16 16:22:24
87	FIX	1119	0320630814	1	2017-11-16 19:54:57	2017-11-16 19:55:05
88	MOB	1119	0674199470 	2	2017-11-16 19:55:10	2017-11-16 19:55:16
174	FIX	1416	05 44 23 24 70	1	\N	\N
93	FIX	1145	0477618694	1	2017-12-20 09:43:31	2017-12-20 09:43:57
102	FIX	561	0142343686	1	2017-12-21 10:47:33	2017-12-21 10:48:09
185	FIX	725	01 42 34 14 25	1	\N	\N
123	FIX	1198	05 56 10 21 29	1	2018-01-30 16:00:14	2018-01-30 16:01:48
124	FIX	1084	01 42 34 40 71	1	2018-01-30 16:03:43	2018-01-30 16:04:09
129	FIX	1222	03 88 16 17 43	1	2018-06-06 16:34:13	2018-06-06 16:34:49
138	FIX	1246	04 66 31 85 48	1	\N	\N
150	FIX	679	02 33 59 44 54	1	\N	\N
178	FIX	1425	0555210793	1	\N	\N
191	FIX	1465	06 08 88 85 27	2	\N	\N
196	MOB	1479	06 08 84 91 74	1	\N	\N
190	FIX	1465	01 42 34 36 91	1	\N	\N
37	FIX	834	04 66 77 23 92	1	2014-11-13 17:06:04	2014-11-13 17:06:17
38	FIX	835	04 74 47 42 40	1	2014-11-13 17:33:03	2015-01-29 15:21:17
159	FIX	1315	01 42 34 44 77	1	\N	\N
48	FIX	863	0142344833	1	2015-06-30 13:06:02	2015-06-30 13:06:19
53	FIX	867	0561107100	1	2015-07-02 12:33:58	2015-07-02 12:34:15
69	FIX	918	04 74 42 63 92	1	2016-05-19 14:37:05	2018-03-21 12:06:28
211	FIX	1545	0233252844	1	2024-02-19 00:00:00	2024-02-19 00:00:00
80	FIX	1110	0558050905	1	2017-11-14 18:03:56	2018-04-13 11:36:17
81	FIX	1111	0478560155	1	2017-11-14 18:37:20	2017-11-14 18:37:27
82	FIX	1112	03 24 59 97 86	1	2017-11-14 18:41:52	2017-11-14 18:41:59
85	FIX	1114	02 54 22 85 04	1	2017-11-16 11:49:23	2017-11-16 11:49:37
90	FIX	1126	 02 98 62 02 30	1	2017-11-27 17:03:32	2017-11-27 17:03:51
130	FIX	1223	03 84 69 50 33	1	2018-06-11 09:36:31	2018-06-11 09:36:42
143	FIX	1	0142343713	1	2013-12-10 10:15:02	\N
144	FIX	1238	05 58 35 23 40 	1	\N	\N
169	FIX	1391	0142344068	1	\N	\N
168	FIX	1399	0563649402	1	\N	\N
171	FIX	1377	0386666841	1	\N	\N
180	FIX	1430	02.43.25.07.64	1	\N	\N
179	MOB	1428	06 73 25 9225	1	\N	\N
181	FIX	1433	03 24 40 43 88 	1	\N	\N
194	FIX	1459	01 42 34 32 42	2	\N	\N
193	FIX	1459	01 42 34 32 41	1	\N	\N
198	MOB	1500	06 07 60 47 63	1	\N	\N
40	FIX	849	03 23 61 17 15	1	2015-04-16 10:44:53	2015-04-16 10:45:11
46	FIX	861	03 26 46 12 58	1	2015-06-30 10:18:54	2015-06-30 10:19:18
49	FIX	865	02 41 87 16 12	1	2015-06-30 16:30:40	2015-06-30 16:32:53
50	FAX	865	02 41 87 16 09	2	2015-06-30 16:33:02	2015-06-30 16:33:59
51	FIX	373	01 42 34 27 81	1	2015-06-30 16:34:36	2015-06-30 16:36:19
64	FIX	910	0381823648	1	2015-10-12 14:44:47	2015-10-12 14:45:07
61	FIX	905	03 27 76 08 16	1	2015-10-02 14:22:47	2015-10-02 14:23:53
62	FAX	905	03 27 76 11 10	2	2015-10-02 14:23:26	2015-10-02 14:24:17
65	FAX	910	0381835482	2	2015-10-12 14:45:08	2015-10-12 14:45:23
66	FIX	913	05 55 64 14 19	1	2015-12-21 17:55:22	2015-12-21 17:55:35
100	FIX	1161	0562172706	1	2017-12-21 10:29:32	2017-12-21 10:30:40
118	FIX	1185	03 86 22 48 86	1	2018-01-10 20:39:14	2018-01-10 20:39:41
121	MOB	695	06 70 24 28 66	1	2018-01-29 14:00:04	2018-01-29 14:00:24
122	MOB	1195	06 80 65 28 84	1	2018-01-29 14:02:55	2018-01-29 14:03:35
132	FIX	1229	03 21 08 12 14	1	\N	\N
153	FIX	1359	0562612188	1	\N	\N
142	FIX	1251	0450143241	1	\N	\N
145	FIX	1098	0320630825	1	\N	\N
156	FIX	1367	0470489831	1	\N	\N
158	FIX	1165	02 98 92 16 10	1	\N	\N
173	FIX	1415	0384379932	1	\N	\N
170	FIX	1400	02 33 59 44 54	1	\N	\N
176	FIX	1147	03 21 22 87 55	1	\N	\N
182	FIX	1442	02 32 56 65 73	1	\N	\N
26	FIX	824	04 74 218622	1	2014-10-23 14:41:02	2016-09-19 15:03:03
27	FAX	824	04 74 228160	2	2014-10-23 14:41:43	2016-09-19 15:03:19
75	MOB	857	07 85 54 72 43	1	2017-10-10 13:32:17	2017-10-10 13:32:41
29	FIX	826	02 54 27 93 44	1	2014-10-23 17:14:33	2014-10-23 17:14:49
44	FIX	844	0490820418	1	2015-05-22 11:39:21	2015-05-22 11:39:33
45	FAX	844	0490852244	2	2015-05-22 11:39:37	2015-05-22 11:39:50
133	FIX	1233	04 38 86 28 74	1	\N	\N
56	FIX	886	0474680983	1	2015-07-17 16:08:44	2015-07-17 16:09:07
57	FIX	892	0254554041	1	2015-09-08 14:03:48	2015-09-08 14:04:12
58	FIX	830	02 51 36 16 99	1	2015-09-16 18:17:07	2015-09-16 18:17:23
59	FIX	850	05 34 09 80 80	1	2015-09-22 09:47:42	2015-09-22 09:47:55
84	FIX	1113	\N	1	2017-11-15 15:44:31	2017-11-23 12:12:18
115	FIX	1183	04 71 20 26 27 	1	2018-01-08 19:05:51	2018-01-08 19:06:07
116	FIX	891	01 42 34 22 73 	1	2018-01-08 19:07:15	2018-01-08 19:07:26
126	FIX	1211	04 77 74 97 39	1	2018-02-20 14:08:44	2018-02-20 14:09:32
128	FIX	1213	03 25 76 20 45	1	2018-04-04 14:13:18	2018-04-04 14:13:32
151	FIX	845	0450473948	1	\N	\N
140	FIX	1212	02.43.48.80.08 	1	\N	\N
152	FIX	775	0142343368	1	\N	\N
161	FIX	1297	0142344038	1	\N	\N
183	FIX	1444	0565555343	1	\N	\N
188	MOB	1451	07 85 16 80 38	1	\N	\N
195	FIX	1475	05 62 58 76 60	1	\N	\N
210	FIX	1542	0468832984	1	\N	\N
16	FIX	16	0368073075	1	2013-12-10 10:15:02	\N
10	FIX	10	0565378815	1	2013-12-10 10:15:02	\N
11	FIX	11	0559705639	1	2013-12-10 10:15:02	\N
91	FIX	1140	0372395497	1	2017-12-19 18:03:11	2017-12-19 18:04:27
13	FIX	13	0142344591	1	2013-12-10 10:15:02	\N
14	FIX	14	0389543499	1	2013-12-10 10:15:02	\N
15	FIX	15	0142344849	1	2013-12-10 10:15:02	\N
154	FIX	1361	0491065433	1	\N	\N
21	FAX	11	0559705771	2	2013-12-10 10:15:02	\N
199	FIX	1493	0142344560	1	\N	\N
63	FIX	908	0381573790 	1	2015-10-08 16:20:35	2015-10-08 16:21:02
30	FIX	827	03 85 44 97 77	1	2014-10-24 16:39:12	2014-10-24 16:39:28
32	MOB	828	0674436416	1	2014-10-24 16:44:32	2017-11-08 16:00:09
77	MOB	1104	0640110848	1	2017-11-08 16:19:56	2017-11-08 16:20:43
34	FIX	742	01 42 34 14 33 	1	2014-10-24 16:46:18	2014-10-24 16:46:28
35	FAX	742	01 42 34 15 64	2	2014-10-24 16:46:29	2014-10-24 16:46:39
36	MOB	833	06 76 78 39 03	1	2014-11-03 11:39:43	2014-11-03 11:39:58
43	FIX	856	03 88 23 84 95	1	2015-05-19 14:13:47	2015-05-19 14:14:00
47	FIX	862	0492552663	1	2015-06-30 11:55:51	2015-06-30 11:56:08
70	FIX	921	03 85 94 70 52	1	2016-06-30 09:54:27	2016-06-30 09:54:43
92	FIX	1140	\N	2	2017-12-19 18:03:48	2017-12-19 18:05:20
76	FIX	376	01 42 34 29 81	1	2017-10-25 11:13:39	2017-10-25 11:13:53
94	FIX	1148	03 82 39 04 26	1	2017-12-20 10:10:50	2017-12-20 10:11:14
95	FIX	1155	0562645929	1	2017-12-20 16:54:24	2017-12-20 16:56:27
96	FIX	500	0142342819	1	2017-12-20 16:59:13	2017-12-20 16:59:27
97	FIX	1157	04 72 31 27 05	1	2017-12-21 10:14:31	2017-12-21 10:15:03
105	FIX	1173	0466369966	1	2017-12-21 16:08:18	2017-12-21 16:08:39
111	FAX	1179	09 70 06 59 57	2	2017-12-22 11:20:37	2017-12-22 11:20:50
208	MOB	1532	04 37 05 94 85 	\N	2024-01-23 00:00:00	\N
110	FIX	1179	02 33 59 44 54 	1	2017-12-22 11:20:18	2017-12-22 11:20:32
149	FIX	1171	04 71 48 06 49	1	\N	\N
114	FIX	1175	04 72 75 95 51	1	2018-01-05 09:36:45	2018-01-05 09:37:01
209	FIX	1539	02 99 41 70 54	1	\N	\N
162	FIX	1107	04 76 63 22 54	1	\N	\N
\.


--
-- Data for Name: temval; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY temval (temvalcod, temvallic, temvallib) FROM stdin;
FUTUR	Futur	Futur
ACTIF	Actif	Activité
ANCIEN	Ancien	Ancien
\.


--
-- Data for Name: territ; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY territ (territcod, territlib, territnumtri, territart, territurlcmp, syscredat, sysmajdat, catterritcod, territlic, territlil) FROM stdin;
COLTERFRA	Collectivités territoriales de la République française	6	\N	\N	\N	\N	DOMCOMAUT	Collectivités territoriales de la République française	Collectivités territoriales de la République française
DOM	Départements d'Outre-mer	2	\N	\N	\N	\N	DOMCOMAUT	Départements d'Outre-mer	Départements d'Outre-mer
METROPOLE	Départements métropolitains	1	\N	\N	\N	\N	METROPOLE	Départements métropolitains	Départements métropolitains
SENETRG	Sénateurs représentant les Français établis hors de France	5	\N	\N	\N	\N	SENETRG	Sénateurs représentant les Français établis hors de France	Sénateurs représentant les Français établis hors de France
TOM	Territoires d'Outre-mer	3	\N	\N	\N	\N	DOMCOMAUT	Territoires d'Outre-mer	Territoires d'Outre-mer
ANCIEN5R	Territoires de la Ve République	8	\N	\N	\N	\N	ANCIEN	Territoires de la Ve République	Territoires de la Ve République
ALGERIE	Départements d'Algérie	7	\N	\N	\N	\N	ANCIEN	Départements d'Algérie	Départements d'Algérie
COM	Collectivités d'Outre-mer	3	\N	\N	\N	\N	DOMCOMAUT	Collectivités d'Outre-mer	Collectivités d'Outre-mer
AUTCOM	Autres collectivités	4	\N	\N	\N	\N	DOMCOMAUT	Autres collectivités	Autres collectivités
ANCIEN3R	Territoires de la 3e République	10	\N	\N	\N	\N	ANCIEN	Territoires de la 3e République	Territoires de la 3e République
ANCIEN4R	Territoires de la 4e République	9	\N	\N	\N	\N	ANCIEN	Territoires de la 4e République	Territoires de la 4e République
ETRG	Étranger	99	\N	\N	2014-02-26 11:21:12	\N	ANCIEN	\N	\N
\.


--
-- Data for Name: titele; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY titele (titelecod, titelelic, typmancod, titelelib, titelelil, titelenumtri, titelelicfem, titelelibfem, titelelilfem, titelelicplu, titelelibplu, titelelilplu, titelelibhon, titelelibhonfem, titelelibhonplu, titeleurltempub, titeledef, syscredat, sysmajdat) FROM stdin;
PDTAN	Président	DEPUTE	Président de l'Assemblée nationale	Président de l'Assemblée nationale	1	Présidente de l'Assemblée nationale	Présidente de l'Assemblée nationale	Présidente de l'Assemblée nationale	Présidents	Présidents	Présidents de l'Assemblée Nationale	Président honoraire de l'Assemblée Nationale	Présidente honoraire de l'Assemblée Nationale	Présidents honoraires de l'Assemblée Nationale	OUI	NON	\N	\N
CONSREG	Conseiller régional	REGION	Conseiller régional	Conseiller régional	4	Conseillère régionale	Conseillère régionale	Conseillère régionale	Conseillers régionaux	Conseillers régional	Conseillers régionaux	Conseiller régional honoraire	Conseillère régionale honoraire	Conseillers régionaux honoraires	NON	OUI	\N	\N
MAIREDEL	Maire délégué	MUNICIPAL	Maire délégué	Maire délégué	80	Maire déléguée	Maire déléguée	Maire déléguée	Maires délégués	Maires délégués	Maires délégués	Maire délégué honoraire	Maire déléguée honoraire	Maires délégués honoraires	NON	NON	\N	\N
PDTINTCOM	Président	INTERCOM	Président	Président	1	Présidente	Présidente	Présidente	Présidents	Présidents	Présidents	Président honoraire	Présidente honoraire	Présidents honoraires	OUI	NON	\N	\N
PDTDELINTCOM	Président délégué	INTERCOM	Président délégué	Président délégué	2	Présidente déléguée	Présidente déléguée	Présidente déléguée	Présidents délégués	Présidents délégués	Présidents délégués	Président honoraire	Présidente déléguée honoraire	Présidents délégués honoraires	OUI	NON	\N	\N
PREPDTINTCOM	Premier Vice-Président	INTERCOM	Premier Vice-Président	Premier Vice-Président	3	Première Vice-Présidente	Première Vice-Présidente	Première Vice-Présidente	Premiers Vice-Présidents	Premiers Vice-Présidents	Premiers Vice-Présidents	Premier Vice-Président honoraire	Première Vice-Présidente honoraire	Premiers Vice-Présidents honoraires	NON	NON	\N	\N
VICPDTINTCOM	Vice-Président	INTERCOM	Vice-Président	Vice-Président	4	Vice-Présidente	Vice-Présidente	Vice-Présidente	Vice-Présidents	Vice-Présidents	Vice-Présidents	Vice-Président honoraire	Vice-Présidente honoraire	Vice-Présidents honoraires	NON	NON	\N	\N
CONSINTCOM	Conseiller	INTERCOM	Conseiller	Conseiller	7	Conseillère	Conseillère	Conseillère	Conseillers	Conseillers	Conseillers	Conseiller honoraire	Conseillère honoraire	Conseillers honoraires	NON	NON	\N	\N
DELINTCOM	Délégué	INTERCOM	Délégué	Délégué	8	Déléguée	Déléguée	Déléguée	Délégués	Délégués	Délégués	Délégué honoraire	Déléguée honoraire	Délégués honoraires	NON	NON	\N	\N
DELTITINTCOM	Délégué titulaire	INTERCOM	Délégué titulaire	Délégué titulaire	9	Déléguée titulaire	Déléguée titulaire	Déléguée titulaire	Délégués titulaires	Délégués titulaires	Délégués titulaires	Délégué titulaire honoraire	Déléguée titulaire honoraire	Délégués titulaires honoraires	NON	NON	\N	\N
DELSUPINTCOM	Délégué suppléant	INTERCOM	Délégué suppléant	Délégué suppléant	8	Déléguée suppléant	Déléguée suppléant	Déléguée suppléant	Délégués suppléants	Délégués suppléants	Délégués suppléants	Délégué suppléant honoraire	Déléguée suppléant honoraire	Délégués suppléants honoraires	NON	NON	\N	\N
MEMBREINTCOM	Membre	INTERCOM	Membre	Membre	10	Membre	Membre	Membre	Membres	Membres	Membres	Membre honoraire	Membre honoraire	Membres honoraires	NON	OUI	\N	\N
CONSARR	Conseiller d'arrondissement	MUNICIPAL	Conseiller d'arrondissement	Conseiller d'arrondissement	70	Conseillère d'arrondissement	Conseillère d'arrondissement	Conseillère d'arrondissement	Conseillers d'arrondissement	Conseillers d'arrondissement	Conseillers d'arrondissement	Conseiller d'arrondissement honoraire	Conseillère d'arrondissement honoraire	Conseillers d'arrondissement honoraires	NON	NON	\N	\N
CGPARIPDT	Président du Conseil de Paris	CANTON	Président du Conseil	Président du Conseil	5	Présidente du Conseil	Présidente du Conseil	Présidente du Conseil	Présidents du Conseil	Présidents du Conseil	Présidents du Conseil	Président honoraire du Conseil 	Président honoraire du Conseil 	Présidents honoraires du Conseil 	NON	NON	\N	\N
MAIREARR	Maire d'arrondissement	MUNICIPAL	Maire d'arrondissement	Maire d'arrondissement	50	Maire d'arrondissement	Maire d'arrondissement	Maire d'arrondissement	Maires d'arrondissement	Maires d'arrondissement	Maires d'arrondissement	Maire d'arrondissement honoraire	Maire d'arrondissement honoraire	Maires d'arrondissement honoraires	NON	NON	\N	\N
MAIRESEC	Maire de secteur	MUNICIPAL	Maire de secteur	Maire de secteur	40	Maire de secteur	Maire de secteur	Maire de secteur	Maires de secteur	Maires de secteur	Maires de secteur	Maire de secteur honoraire	Maire de secteur honoraire	Maires de secteur honoraires	NON	NON	\N	\N
CONSGENE	Conseiller général	CANTON	Conseiller général	Conseiller général	4	Conseillère générale	Conseillère générale	Conseillère générale	Conseillers généraux	Conseillers général	Conseillers généraux	Conseiller général honoraire	Conseiller général honoraire	Conseillers généraux honoraires	NON	OUI	\N	\N
CONSGENEPARI	Conseiller de Paris	CANTON	Conseiller de Paris	Conseiller de Paris	7	Conseillère de Paris	Conseillère de Paris	Conseillère de Paris	Conseillers de Paris	Conseillers de Paris	Conseillers de Paris	Conseiller de Paris honoraire	Conseiller de Paris honoraire	Conseillers de Paris honoraires	NON	NON	\N	\N
CONSPARI	Conseiller de Paris	MUNICIPAL	Conseiller de Paris	Conseiller	60	Conseillère de Paris	Conseillère de Paris	Conseillère	Conseillers de Paris	Conseillers de Paris	Conseillers	Conseiller de Paris honoraire	Conseillère de Paris honoraire	Conseillers de Paris honoraires	NON	NON	\N	\N
DEPUTE	Député	DEPUTE	Député	Député Assemblée nationale	5	Députée	Députée	Députée Assemblée nationale	Députés	Députés	Députés Assemblée Nationale	Député honoraire	Députée honoraire	Députés honoraires	NON	OUI	\N	\N
MAIRE	Maire	MUNICIPAL	Maire	Maire	1	Maire	Maire	Maire	Maires	Maires	Maires	Maire honoraire	Maire honoraire	Maires honoraires	NON	NON	\N	\N
MAIREADJOINT	Adjoint au maire	MUNICIPAL	Adjoint au maire	Adjoint au maire	20	Adjointe au maire	Adjointe au maire	Adjointe au maire	Adjoints au maire	Adjoints au maire	Adjoints au maire	Adjoint au maire honoraire	Adjointe au maire honoraire	Adjoints au maire honoraires	NON	NON	\N	\N
PDTGEN	Président	CANTON	Président du conseil général	Président du conseil général	1	Présidente	Présidente du conseil général	Présidente du conseil général	Présidents	Présidents du conseil général	Présidents du conseil général	Président honoraire du conseil général	Présidente honoraire du conseil général	Présidents honoraires du conseil général	OUI	NON	\N	\N
VICPDTAN	Vice-président	DEPUTE	Vice-président de l'Assemblée nationale	Vice-président de l'Assemblée nationale	2	Vice-présidente de l'Assemblée nationale	Vice-présidente de l'Assemblée nationale	Vice-présidente de l'Assemblé nationale	Vice-Présidents	Vice-Présidents	Vice-Présidents de l'Assemblée Nationale	Vice-Président honoraire de l'Assemblée Nationale	Vice-Présidente honoraire de l'Assemblée Nationale	Vice-Présidents honoraires de l'Assemblée Nationale	NON	NON	\N	\N
CGPARIVICPDT	Conseiller de Paris (Vice-Pdt)	CANTON	Conseiller de Paris (Vice-Président)	Conseiller de Paris (Vice-Président)	6	Conseillère de Paris (Vice-Pdte)	Conseillère de Paris (Vice-Présidente)	Conseillère de Paris (Vice-Présidente)	Conseillers de Paris (Vice-Pdts)	Conseillers de Paris (Vice-Présidents)	Conseillers de Paris (Vice-Présidents)	Conseiller de Paris honoraire (Vice-Président) 	Conseiller de Paris honoraire (Vice-Président)	Conseillers de Paris honoraires (Vice-Présidents) 	NON	NON	\N	\N
PDTREG	Président	REGION	Président du conseil régional	Président du conseil régional	1	Présidente	Présidente du conseil régional	Présidente du conseil régional	Présidents	Présidents du conseil régional	Présidents du conseil régional	Président honoraire du conseil régional	Présidente honoraire du conseil régional	Présidents honoraires du conseil régional	OUI	NON	\N	\N
VICPDTGEN	Vice-Président	CANTON	Vice-Président du conseil général	Vice-Président du conseil général	3	Vice-Présidente	Vice-Présidente du conseil général	Vice-Présidente du conseil général	Vice-Présidents	Vice-Présidents du conseil général	Vice-Présidents du conseil général	Vice-Président honoraire du conseil général	Vice-Présidente honoraire du conseil général	Vice-Présidents honoraires du conseil général	NON	NON	\N	\N
VICPDTREG	Vice-Président	REGION	Vice-Président du conseil régional	Vice-Président du conseil régional	3	Vice-Présidente	Vice-Présidente du conseil régional	Vice-Présidente du conseil régional	Vice-Présidents	Vice-Présidents du conseil régional	Vice-Présidents du conseil régional	Vice-Président honoraire du conseil régional	Vice-Présidente honoraire du conseil régional	Vice-Présidents honoraires du conseil régional	NON	NON	\N	\N
PREVICPDTGEN	Premier Vice-Président	CANTON	Premier Vice-Président du conseil général	Premier Vice-Président du conseil général	2	Première Vice-Présidente	Première Vice-Président du conseil général	Première Vice-Président du conseil général	Premiers Vice-Présidents	Premiere Vice-Présidents du conseil général	Premiers Vice-Présidents du conseil général	Premier Vice-Président honoraire du conseil général	Première Vice-Président honoraire du conseil général	Premiers Vice-Présidents honoraires du conseil général	NON	NON	\N	\N
PREVICPDTREG	Premier Vice-Président	REGION	Premier Vice-Président du conseil régional	Premier Vice-Président du conseil régional	2	Première Vice-Présidente	Première Vice-Présidente du conseil régional	Première Vice-Présidente du conseil régional	Premiers Vice-Présidents	Premiers Vice-Présidents du conseil régional	Premiers Vice-Présidents du conseil régional	Premier Vice-Président honoraire du conseil régional	Première Vice-Présidente honoraire du conseil régional	Premiers Vice-Présidents honoraires du conseil régional	NON	NON	\N	\N
CONSMUNI	Conseiller municipal	MUNICIPAL	Conseiller municipal	Conseiller municipal	30	Conseillère municipale	Conseillère municipale	Conseillère municipale	Conseillers municipaux	Conseillers municipaux	Conseillers municipaux	Conseiller municipal honoraire	Conseillère municipale honoraire	Conseillers municipaux honoraires	NON	OUI	\N	\N
PDTMET	Président	METROPOLE	Président	Président	1	Présidente	Présidente	Présidente	Présidents	Présidents	Présidents	Président honoraire	Présidente honoraire	Présidents honoraires	\N	\N	\N	\N
VICPDTMET	Vice-Président	METROPOLE	Vice-Président	Vice-Président	4	Vice-Présidente	Vice-Présidente	Vice-Présidente	Vice-Présidents	Vice-Présidents	Vice-Présidents	Vice-Président honoraire	Vice-Présidente honoraire	Vice-Présidents honoraires	\N	\N	\N	\N
CONSMET	Conseiller	METROPOLE	Conseiller	Conseiller	5	Conseillère	Conseillère	Conseillère	Conseillers	Conseillers	Conseillers	Conseiller honoraire	Conseillère honoraire	Conseillers honoraires	\N	OUI	\N	\N
PREVICPDTDPT	Premier Vice-Président	DEPART	Premier Vice-Président du conseil départemental	Premier Vice-Président du conseil départemental	2	Première Vice-Présidente	Première Vice-Présidente du conseil départemental	Première Vice-Présidente du conseil départemental	Premiers Vice-Présidents	Premiers Vice-Présidents du conseil départemental	Premiers Vice-Présidents du conseil départemental	Premier Vice-Président honoraire du conseil départemental	Première Vice-Présidente honoraire du conseil départemental	Premiers Vice-Présidents honoraires du conseil départemental	NON	NON	2017-05-31 17:56:44	\N
QUESTAN	Questeur	DEPUTE	Questeur de l'Assemblée nationale	Questeur de l'Assemblée nationale	3	Questeur	Questeur de l'Assemblée nationale	Questeur de l'Assemblée nationale	Questeurs	Questeurs de l'Assemblée nationale	Questeurs de l'Assemblée nationale	Questeur honoraire	Questeur honoraire de l'Assemblée nationale	Questeurs honoraires de l'Assemblée nationale	\N	\N	\N	\N
SECAN	Secrétaire	DEPUTE	Secrétaire de l'Assemblée nationale	Secrétaire de l'Assemblée nationale	4	Secrétaire	Secrétaire de l'Assemblée nationale	Secrétaire de l'Assemblée nationale	Secrétaires	Secrétaires de l'Assemblée nationale	Secrétaires de l'Assemblée nationale	Secrétaire honoraire	Secrétaire honoraire de l'Assemblée nationale	Secrétaires honoraires de l'Assemblée nationale	\N	\N	\N	\N
PREMADJOINT	1er adjoint au maire	MUNICIPAL	Premier adjoint au maire	Premier adjoint au maire	10	1ère adjointe au maire	Première adjointe au maire	Première adjointe au maire	1ers adjoints au maire	Premiers adjoints au maire	Premiers adjoints au maire	Premier adjoint au maire honoraire	Première adjointe au maire honoraire	Premiers adjoints au maire honoraires	NON	NON	\N	\N
DEUXADJOINT	2ème adjoint au maire	MUNICIPAL	Deuxième adjoint au maire	Deuxième adjoint au maire	11	2ème adjointe au maire	Deuxième adjointe au maire	Deuxième adjointe au maire	Deuxièmes adjoints au maire	Deuxièmes adjoints au maire	Deuxièmes adjoints au maire	Deuxième adjoint au maire honoraire	Deuxième adjointe au maire honoraire	Deuxièmes adjoints au maire honoraires	NON	NON	\N	\N
TROISADJOINT	3ème adjoint au maire	MUNICIPAL	Troisième adjoint au maire	Troisième adjoint au maire	12	3ème adjointe au maire	Troisième adjointe au maire	Troisième adjointe au maire	Troisièmes adjoints au maire	Troisièmes adjoints au maire	Troisièmes adjoints au maire	Troisième adjoint au maire honoraire	Troisième adjointe au maire honoraire	Troisièmes adjoints au maire honoraires	NON	NON	\N	\N
QUATADJOINT	4ème adjoint au maire	MUNICIPAL	Quatrième adjoint au maire	Quatrième adjoint au maire	13	4ème adjointe au maire	Quatrième adjointe au maire	Quatrième adjointe au maire	Quatrièmes adjoints au maire	Quatrièmes adjoints au maire	Quatrièmes adjoints au maire	Quatrième adjoint au maire honoraire	Quatrième adjointe au maire honoraire	Quatrièmes adjoints au maire honoraires	NON	NON	\N	\N
CINQADJOINT	5ème adjoint au maire	MUNICIPAL	Cinquième adjoint au maire	Cinquième adjoint au maire	14	5ème adjointe au maire	Cinquième adjointe au maire	Cinquième adjointe au maire	Cinquièmes adjoints au maire	Cinquièmes adjoints au maire	Cinquièmes adjoints au maire	Cinquième adjoint au maire honoraire	Cinquième adjointe au maire honoraire	Cinquièmes adjoints au maire honoraires	NON	NON	\N	\N
SIXADJOINT	6ème adjoint au maire	MUNICIPAL	Sixième adjoint au maire	Sixième adjoint au maire	15	6ème adjointe au maire	Sixième adjointe au maire	Sixième adjointe au maire	Sixièmes adjoints au maire	Sixièmes adjoints au maire	Sixièmes adjoints au maire	Sixième adjoint au maire honoraire	Sixième adjointe au maire honoraire	Sixièmes adjoints au maire honoraires	NON	NON	\N	\N
SEPTADJOINT	7ème adjoint au maire	MUNICIPAL	Septième adjoint au maire	Septième adjoint au maire	16	7ème adjointe au maire	Septième adjointe au maire	Septième adjointe au maire	Septièmes adjoints au maire	Septièmes adjoints au maire	Septièmes adjoints au maire	Septième adjoint au maire honoraire	Septième adjointe au maire honoraire	Septièmes adjoints au maire honoraires	NON	NON	\N	\N
HUITADJOINT	8ème adjoint au maire	MUNICIPAL	Huitième adjoint au maire	Huitième adjoint au maire	17	8ème adjointe au maire	Huitième adjointe au maire	Huitième adjointe au maire	Huitièmes adjoints au maire	Huitièmes adjoints au maire	Huitièmes adjoints au maire	Huitième adjoint au maire honoraire	Huitième adjointe au maire honoraire	Huitièmes adjoints au maire honoraires	NON	NON	\N	\N
CONSCOMINT	Conseiller communautaire	INTERCOM	Conseiller communautaire	Conseiller communautaire	6	Conseillère communautaire	Conseillère communautaire	Conseillère communautaire	Conseillers communautaires	Conseillers communautaires	Conseillers communautaires	Conseiller communautaire honoraire	Conseillère communautaire honoraire	Conseillers communautaires honoraires	NON	\N	\N	\N
PDTDPT	Président	DEPART	Président du conseil départemental	Président du conseil départemental	1	Présidente	Présidente du conseil départemental	Présidente du conseil départemental	Présidents	Présidents du conseil départemental	Présidents du conseil départemental	Président honoraire du conseil départemental	Présidente honoraire du conseil départemental	Présidents honoraires du conseil départemental	OUI	NON	2015-03-30 17:31:44	\N
VICPDTDPT	Vice-Président	DEPART	Vice-Président du conseil départemental	Vice-Président du conseil départemental	3	Vice-Présidente	Vice-Présidente du conseil départemental	Vice-Présidente du conseil départemental	Vice-Présidents	Vice-Présidents du conseil départemental	Vice-Présidents du conseil départemental	Vice-Président honoraire du conseil départemental	Vice-Présidente honoraire du conseil départemental	Vice-Présidents honoraires du conseil départemental	NON	NON	2015-03-30 17:31:44	\N
CONSDPT	Conseiller départemental	DEPART	Conseiller départemental	Conseiller départemental	4	Conseillère départementale	Conseillère départementale	Conseillère départementale	Conseillers départementaux	Conseillers départementaux	Conseillers départementaux	Conseiller départemental honoraire	Conseillère départementale honoraire	Conseillers départementaux honoraires	NON	OUI	2015-03-30 17:31:44	\N
\.


--
-- Data for Name: typadr; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY typadr (typadrcod, typadrlic, typadrlib, typadrnumtri, syscredat, sysmajdat) FROM stdin;
PERM	Permanence	Permanence parlementaire	2	\N	\N
DOMICILE	Domicile	Domicile	3	\N	\N
SENAT	Adresse Sénat	Adresse Sénat	1	\N	\N
\.


--
-- Data for Name: typapppol; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY typapppol (typapppolcod, typapppollib, typapppollic, typapppolnumtri, typapppollil, typapppollicfem, typapppollibfem, typapppollilfem, typapppollicplu, typapppollibplu, typapppollilplu, syscredat, sysmajdat) FROM stdin;
N	Membre	\N	1	Membre	\N	Membre	Membre	\N	Membres	Membres	\N	\N
R	Rattaché	-R	3	Membre rattaché 	-R	Rattachée	Membre rattachée	-R	Rattachés	Membres rattachés	\N	\N
A	Apparenté	-A	2	Membre apparenté	-A	Apparentée	Membre apparentée	-A	Apparentés	Membres apparentés	\N	\N
\.


--
-- Data for Name: typbister; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY typbister (typbistercod, typbisterlic, typbisterlib, typbisternumtri) FROM stdin;
NEANT	\N	\N	1
BIS	B	Bis	2
TER	T	Ter	3
QUATER	Q	Quater	4
\.


--
-- Data for Name: type_activite; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY type_activite (typactcod, typactlic, typactlib, typactlibtap) FROM stdin;
CONF_PRES	Conf. Prés.	Conférence des Présidents	Conférence des Présidents
QUESTURE	Questure	Questure	Questure
BUREAU	Bureau	Bureau	Bureau du Sénat
COM_DEONTOLOGIE	Comité de déontologie	Comité de déontologie parlementaire du Sénat	\N
RENSEIGNEMENT	Renseignement	Délégation au Renseignement	\N
EXCUSES	Excuses hors 23bis	Excuses ne valant pas au sens de l'article 23bis du règlement	\N
COM_APURATION	Commission d'Apuration des Comptes	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne	\N
SEANCE_PLENIERE	Séance	Séance plénière	Séance plénière
COM_PERMANENTE	Permanente	Commission permanente	\N
COM_EURO	Européennes	Commission des affaires européennes	\N
COM_SPECIALE	Spéciale	Commission spéciale	\N
MISSION	Mission	Mission	\N
DELEGATION	Délégation	Délégation	\N
COM_ENQUETE	Enquête	Commission d'enquête	\N
AUTRE_TEMPORAIRE	Autre temporaire	Réunion d'une autre structure temporaire	Réunion d'une autre structure temporaire
INSTANCE_INTERNATIONALE	Internationale	Réunion d'une instance parlementaire internationale	Réunion d'une instance parlementaire internationale
GIA	GIA/GL	Groupe Interparlementaire d'Amitié ou Autre	Groupe interparlementaire d'amitié ou autre
ETUDES	Études	Groupe d'Études	Groupe d'études
MECSS	MECSS	Mission d'évaluation et de contrôle de la sécurité sociale	\N
CMP	CMP	Commission mixte paritaire	Commission mixte paritaire
\.


--
-- Data for Name: type_activite_participant; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY type_activite_participant (typactparcod, typactparlib, typactparlibfem) FROM stdin;
PRESENT	Présent	Présente
EXCUSE	Excusé	Excusée
\.


--
-- Data for Name: type_activite_senateur; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY type_activite_senateur (typactsencod, typactsenlic, typactsenlib, numtri) FROM stdin;
REU_TRAV_PARL	Réunion travail parlementaire	Réunion de travail parlementaire	10
ORGEXTPAR	OEP	Représentation du Sénat dans un organisme extraparlementaire	20
REU_GVT	Réunion Gouvernement	Réunion avec les services du Gouvernement	30
ACC_DEPL_INTER	Accueil délég. internationale / Représentation diplomatique	Accueil d'une délégation internationale / représentation diplomatique	40
DEL_ACT_PAR	Délégation action parlementaire	Rencontre d'une délégation pour action parlementaire	50
ORG_POL	Réunion organisation politique	Réunion d'une organisation politique	60
ACC_VISIT	Accueil visiteurs	Accueil d'un groupe de visiteurs	70
DEPL_PRES_GVT	Déplacement présidentiel, gouvernemental ou officiel	Participation à un déplacement présidentiel ou gouvernemental, ou à un déplacement à caractère officiel	80
ELUS_LOCAUX	Réunion élus locaux	Réunion avec des élus locaux du département	90
COLL_TER	Réunion collectivité territoriale	Réunion d'une collectivité territoriale	100
CEREMONIE	Cérémonie officielle	Cérémonie officielle	110
COLLOQUE	Colloque Sénat	Colloque au Sénat	120
\.


--
-- Data for Name: type_categorie; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY type_categorie (typactcod, catactcod, par_defaut) FROM stdin;
CONF_PRES	AUCUNE	OUI
QUESTURE	AUCUNE	OUI
BUREAU	AUCUNE	OUI
COM_EURO	PLEIN_NON_JO	NON
COM_PERMANENTE	PLEIN_NON_JO	NON
AUTRE_TEMPORAIRE	PLEIN_NON_JO	NON
MISSION	PLEIN_NON_JO	NON
AUTRE_TEMPORAIRE	PEC_NON_MML	NON
COM_ENQUETE	PEC_NON_MML	NON
COM_EURO	PEC_NON_MML	NON
COM_PERMANENTE	PEC_NON_MML	NON
COM_SPECIALE	PEC_NON_MML	NON
MECSS	PEC_NON_MML	NON
MISSION	PEC_NON_MML	NON
COM_DEONTOLOGIE	AUCUNE	OUI
RENSEIGNEMENT	AUCUNE	OUI
COM_PERMANENTE	AUTRE_NON_PLENIERE	NON
COM_EURO	AUTRE_NON_PLENIERE	NON
DELEGATION	AUTRE_NON_PLENIERE	NON
COM_ENQUETE	DEPLACEMENT	NON
COM_EURO	DEPLACEMENT	NON
COM_PERMANENTE	DEPLACEMENT	NON
COM_SPECIALE	DEPLACEMENT	NON
DELEGATION	DEPLACEMENT	NON
MISSION	DEPLACEMENT	NON
AUTRE_TEMPORAIRE	DEPLACEMENT	NON
EXCUSES	AUTRE_NON_PLENIERE	OUI
COM_APURATION	AUCUNE	OUI
SEANCE_PLENIERE	DEBAT	OUI
SEANCE_PLENIERE	ALLOCUTION	NON
COM_PERMANENTE	AUDRAP	NON
SEANCE_PLENIERE	DECL_GVT	NON
SEANCE_PLENIERE	ELOGE_FUNEBRE	NON
SEANCE_PLENIERE	HOMMAGE	NON
COM_EURO	AUDRAP	NON
COM_SPECIALE	AUDRAP	NON
MISSION	AUDRAP	NON
SEANCE_PLENIERE	RECEPTION	NON
COM_ENQUETE	AUDRAP	NON
SEANCE_PLENIERE	CONGRES	NON
SEANCE_PLENIERE	OUV_SESSION	NON
SEANCE_PLENIERE	ALLOC_FIN_SESS	NON
SEANCE_PLENIERE	MESS_PRESIDENT	NON
AUTRE_TEMPORAIRE	AUDRAP	NON
SEANCE_PLENIERE	EXAMEN	NON
SEANCE_PLENIERE	QO	NON
SEANCE_PLENIERE	QOD	NON
MECSS	AUDRAP	NON
SEANCE_PLENIERE	QAG	NON
SEANCE_PLENIERE	EXPLI_VOTE_SCRUSOL	NON
SEANCE_PLENIERE	SCRUSOL	NON
SEANCE_PLENIERE	AUTRE	NON
COM_PERMANENTE	AUTRE	NON
GIA	AUCUNE	OUI
COM_EURO	CONTROLE	OUI
COM_EURO	AUTRE	NON
ETUDES	AUCUNE	OUI
MISSION	AUCUNE	OUI
DELEGATION	AUCUNE	OUI
AUTRE_TEMPORAIRE	AUTRE	NON
INSTANCE_INTERNATIONALE	AUCUNE	OUI
MECSS	AUCUNE	OUI
DELEGATION	AUDRAP	NON
COM_PERMANENTE	GROUPE_TRAVAIL	NON
COM_EURO	GROUPE_TRAVAIL	NON
DELEGATION	GROUPE_TRAVAIL	NON
COM_ENQUETE	PLENIERE	OUI
COM_SPECIALE	PLENIERE	OUI
\.


--
-- Data for Name: typele; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY typele (typelecod, typelelic, typelelib, typelelil, typelenumtri, syscredat, sysmajdat) FROM stdin;
NEANT	Non renseigné	Non renseigné	Non renseigné	10	\N	\N
SM	Majoritaire	Scrutin majoritaire	Scrutin majoritaire	1	\N	\N
RP	Proportionnelle	Représentation proportionnelle	Représentation proportionnelle	5	\N	\N
\.


--
-- Data for Name: typgrpsen; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY typgrpsen (typgrpsencod, temvalcod, evelic, evelib, evelil, typgrpsennumtri, syscredat, sysmajdat) FROM stdin;
AMITIE	ACTIF	Groupe interparlementaire	Groupes interparlementaires	Groupes interparlementaires	1	\N	\N
INFO	ACTIF	Groupe d'information	Groupes sénatoriaux d'information	Groupes sénatoriaux d'information	2	\N	\N
ETUDES	ACTIF	Groupe d'études	Groupe d'études	Groupe d'études	3	\N	\N
LIAISON	ACTIF	Groupe de liaison	Groupe de liaison	Groupe de liaison	4	\N	\N
\.


--
-- Data for Name: typman; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY typman (typmancod, typmanlib, typmantypele, typmannumtri, syscredat, sysmajdat) FROM stdin;
CANTON	Cantonales	\N	2	\N	\N
DEPUTE	Députés	\N	10	\N	\N
DIVERS	Mandats divers	\N	9	\N	\N
EUROPE	Européennes	\N	7	\N	\N
INTERCOM	Inter-communales	\N	6	\N	\N
MUNICIPAL	Municipales	Pro	1	\N	\N
REGION	Régionales	\N	3	\N	\N
SENAT	Sénatoriales	SM et RP	0	\N	\N
ASSTER	Assemblée Territoriale	\N	8	\N	\N
AUTFONLOC	Autres fonctions locales	\N	11	\N	\N
ETAT	Chef d'état	SM	12	\N	\N
SENAT4R	Sénat 4e République	\N	13	\N	\N
SENAT3R	Sénat 3e République	\N	14	\N	\N
DEPART	Départementales	\N	2	2015-03-30 17:24:02	\N
METROPOLE	Métropoles	\N	5	2015-01-15 09:53:19	\N
SENATCOMMU	Sénateur de la Communauté	\N	14	2015-02-10 11:59:38	\N
DIVERSCOMMU	Mandat Divers des Sénateurs de la Communauté	\N	15	2015-02-10 11:59:43	\N
SENAT2E	Sénat 2nd Empire	\N	15	2014-02-26 11:19:19	\N
\.


--
-- Data for Name: typorg; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY typorg (typorgcod, typorglib, typorglic, typorgnumtri, typorgurlsim, typorgurlcmp, typorglibplu, syscredat, sysmajdat) FROM stdin;
COMITE	Comité	Comité	18	\N	\N	Comités	\N	\N
AUCUN	(aucun)	(aucun)	0	\N	\N	(aucun)	\N	\N
AUTRES	Autres organismes	Autres organismes             	60	\N	\N	Autres organismes	\N	\N
COM	Commission permanente	Commission permanente	7	\N	\N	Commissions permanentes	\N	\N
DELEGA	Délégation	Délégation	16	\N	\N	Délégations	\N	\N
ETUDES	Groupe d'études	Groupes d'études	50	\N	\N	Groupes d'études	\N	\N
GRPSEN	Groupe interparlementaire d'amitié	Groupe d'amitié	50	\N	\N	Groupes interparlementaires d'amitiés	\N	\N
OFFICE	Office parlementaire	Office	16	\N	\N	Offices parlementaires	\N	\N
ORGEXT	Organisme Extra-Parlementaire	Extra-Parlementaire	27	\N	\N	Organismes Extra-Parlementaires	\N	\N
CONEUR	Conseil de l'Europe et UEO	Conseil de l'Europe et UEO	19	\N	\N	Conseil de l'Europe et UEO	\N	\N
GRPPOL	Groupe politique	Groupe politique	11	\N	\N	Groupes politiques	\N	\N
COUJUSREP	Cour de Justice de la République	Cour Justice République	14	\N	\N	Cour de Justice de la République	\N	\N
SENAT	Sénat	Sénat	40	\N	\N	Sénat	\N	\N
CONCST	Conseil Constitutionnel	Conseil Constitutionnel	6	\N	\N	Conseil Constitutionnel	\N	\N
BUR	Bureau du Sénat	Bureau du Sénat	1	\N	\N	Bureau du Sénat	\N	\N
MINIST	Ministère	Ministère	30	\N	\N	Ministères	\N	\N
COMENQ	Commission d'enquête	Commission d'enquête	25	/commission/enquete/index.html	\N	Commissions d'enquête	\N	\N
MISINF	Mission d'information	Mission d'information	43	/commission/missions/index.html	\N	Missions d'information	\N	\N
MISINFCOM	Mission commune d'information 	Mission commune d'information	42	/commission/missions/index.html	\N	Missions communes d'informations	\N	\N
PARPOL	Parti politique	Parti politique	51	\N	\N	Partis politiques	\N	\N
COMPOU	Commission de poursuite	Commission de poursuite	22	\N	\N	Commissions de poursuite	\N	\N
COMADHOC	Commission ad'hoc	Commission ad'hoc	23	\N	\N	Commissions ad'hoc	\N	\N
CMP	Commission mixte paritaire	CMP	27	/commission/cmp/index.html	\N	Commissions mixtes paritaires	\N	\N
ETUDESSCN	Section d'un groupe d'études	Section d'un groupe d'études	51	\N	\N	Sections d'un groupe d'études	\N	\N
OBS	Observatoire	Observatoire	17	\N	\N	Observatoires	\N	\N
COMEUR	Commission européenne	Commission européenne	8	\N	\N	Commission européenne	\N	\N
MISCOM	Mission commune	Mission commune	44	\N	\N	Missions communes	\N	\N
MECSS	Mission d'évaluation et de contrôle de la sécurité sociale	Mission d'évaluation de la SS	21	\N	\N	Mission d'évaluation et de contrôle de la sécurité sociale	\N	\N
GRPSENSCN	Section d'un Groupe interparlementaire d'amitié	Section d'un Groupe d'amitié	50	\N	\N	Sections d'un Groupe interparlementaire d'amitié	\N	\N
CSCE	Conférence sur la sécurité et la coopération en Europe	Conf. sécurité coop. Europe	20	\N	\N	Conférence sur la sécurité et la coopération en Europe	\N	\N
GRPPOLNI	Groupe politique des Non Inscrits	Groupe politique NI	12	\N	\N	Groupe politique des Non Inscrits	\N	\N
COMSPE	Commission spéciale	Commission spéciale	24	/commission/spec/index.html	\N	Commissions spéciales	\N	\N
HAUCOUJUS	Haute Cour de Justice	Haute Cour de Justice	13	\N	\N	Haute Cour de Justice	\N	\N
COMSPEAPU	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne	Commission contrôle comptes	15	\N	\N	Commission spéciale chargée du contrôle des comptes et de l'évaluation interne	\N	\N
COMAPLEG	Commission en charge de l'application des lois	Commission application des lois	9	\N	\N	Commission en charge de l'application des lois	\N	\N
COMSENCOMMU	Commission du Sénat de la Communauté	Commission de la Communauté	55	\N	\N	\N	2015-02-10 14:18:09	\N
GRPLIAISON	Groupe de liaison	Groupe de liaison	\N	\N	\N	\N	\N	\N
\.


--
-- Data for Name: typurl; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY typurl (typurlcod, temvalcod, evelic, evelib, evelil, eveobs, typurllogo, typurlnumtri, typurllogoref, syscredat, sysmajdat) FROM stdin;
LINKEDIN	ACTIF	Linkedin	Compte Linkedin	Compte Linkedin	\N	bi-linkedin	5	/fileadmin/templates/images/data/picto_contact_linkedin.png	\N	\N
PAGPER	ACTIF	Site perso.	Site personnel	Site personnel du sénateur	\N	bi-globe	1	/fileadmin/templates/images/data/picto_contact_site.png	\N	\N
BLOG	ACTIF	Blog	Blog	Blog du sénateur	\N	bi-blog	2	/fileadmin/templates/images/data/picto_contact_blog.png	\N	\N
FACEBOOK	ACTIF	Facebook	Profil Facebook	Profil Facebook	\N	bi-facebook	3	/fileadmin/templates/images/data/picto_contact_facebook.png	\N	\N
TWEETER	ACTIF	Twitter	Compte Twitter	Compte Twitter	\N	bi-twitter-x	4	/fileadmin/templates/images/data/picto_contact_twitter.png	\N	\N
TIKTOK	ACTIF	TikTok	Compte TikTok	Compte TikTok	\N	bi-tiktok	11	/fileadmin/templates/images/data/picto_tiktok.png	2023-10-19 17:55:33	\N
HUFFINGTON	ACTIF	Huffpost	Compte Huffpost	Compte Le Huffington Post	\N	bi-huffington	9	/fileadmin/templates/images/data/picto_huffington.png	2017-11-22 09:06:17	\N
MEDIAPART	ACTIF	Mediapart	Blog Mediapart	Blog Mediapart	\N	bi-mediapart	10	/fileadmin/templates/images/data/picto_mediapart.png	2017-11-22 09:06:17	\N
INSTAGRAM	ACTIF	Instagram	Compte Instagram	Compte Instagram	\N	bi-instagram	7	/fileadmin/templates/images/data/picto_instagram_pour_notices.png	2015-01-30 00:00:00	\N
YOUTUBE	ACTIF	YouTube	Compte YouTube	Compte YouTube	\N	bi-youtube	8	/fileadmin/templates/images/data/picto_contact_youtube.png	2017-11-14 16:49:17	\N
TUMBLR	ACTIF	Tumblr	Tumblr	Tumblr	\N	bi-tumblr	6	/fileadmin/templates/images/data/picto_contact_tumblr.png	\N	\N
\.


--
-- Data for Name: typvoi; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY typvoi (typvoicod, typvoilic, typvoilib, typvoinumtri) FROM stdin;
BLVD	\N	boulevard	5
AUCUN	\N	\N	6
RUE	\N	rue	1
AVE	\N	avenue	2
PLACE	\N	place	3
QUAI	\N	quai	4
NEANT	\N	A définir	100
\.


--
-- Data for Name: zongeo; Type: TABLE DATA; Schema: public; Owner: opendata
--

COPY zongeo (zongeocod, concod, zongeolib, zongeolic, zongeonumtri, syscredat, sysmajdat) FROM stdin;
AFRIQNORD	AFRIQUE	Afrique du Nord               	Afrique du Nord               	\N	\N	\N
MAGHREB	AFRIQUE	Maghreb                       	Maghreb                       	\N	\N	\N
TEST	AFRIQUE	Zone de test                  	Zone de test                  	\N	\N	\N
UE	EUROPE	Union européenne	Pays de l'Union européenne	\N	\N	\N
\.


--
-- Name: activite_delegation_actid_key; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY activite_delegation
    ADD CONSTRAINT activite_delegation_actid_key UNIQUE (actid, senmat, delegidx);


--
-- Name: activite_delegation_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY activite_delegation
    ADD CONSTRAINT activite_delegation_pkey PRIMARY KEY (delegactid);


--
-- Name: activite_loi_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY activite_loi
    ADD CONSTRAINT activite_loi_pkey PRIMARY KEY (actid, loicod);


--
-- Name: activite_participant_actid_key; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY activite_participant
    ADD CONSTRAINT activite_participant_actid_key UNIQUE (actid, senmat);


--
-- Name: activite_participant_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY activite_participant
    ADD CONSTRAINT activite_participant_pkey PRIMARY KEY (actparid);


--
-- Name: activite_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY activite
    ADD CONSTRAINT activite_pkey PRIMARY KEY (actid);


--
-- Name: activite_senateur_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY activite_senateur
    ADD CONSTRAINT activite_senateur_pkey PRIMARY KEY (actsenid);


--
-- Name: activites_liees_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY activites_liees
    ADD CONSTRAINT activites_liees_pkey PRIMARY KEY (gauche, droite);


--
-- Name: actpro_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY actpro
    ADD CONSTRAINT actpro_pkey PRIMARY KEY (actprocod);


--
-- Name: adresse_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY adresse
    ADD CONSTRAINT adresse_pkey PRIMARY KEY (adrid);


--
-- Name: asster_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY asster
    ADD CONSTRAINT asster_pkey PRIMARY KEY (asstercod);


--
-- Name: bur_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY bur
    ADD CONSTRAINT bur_pkey PRIMARY KEY (burcod);


--
-- Name: categorie_activite_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY categorie_activite
    ADD CONSTRAINT categorie_activite_pkey PRIMARY KEY (catactcod);


--
-- Name: com_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY com
    ADD CONSTRAINT com_pkey PRIMARY KEY (orgcod);


--
-- Name: csp_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY csp
    ADD CONSTRAINT csp_pkey PRIMARY KEY (cspcod);


--
-- Name: delega_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY delega
    ADD CONSTRAINT delega_pkey PRIMARY KEY (orgcod);


--
-- Name: design_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY design
    ADD CONSTRAINT design_pkey PRIMARY KEY (designcod);


--
-- Name: designoep_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY designoep
    ADD CONSTRAINT designoep_pkey PRIMARY KEY (designoepid);


--
-- Name: designorg_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY designorg
    ADD CONSTRAINT designorg_pkey PRIMARY KEY (designcod);


--
-- Name: dpt_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY dpt
    ADD CONSTRAINT dpt_pkey PRIMARY KEY (dptnum);


--
-- Name: dptele_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY dptele
    ADD CONSTRAINT dptele_pkey PRIMARY KEY (dpteleid);


--
-- Name: dpttypman_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY dpttypman
    ADD CONSTRAINT dpttypman_pkey PRIMARY KEY (dpttypmanid);


--
-- Name: ele_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY ele
    ADD CONSTRAINT ele_pkey PRIMARY KEY (eleid);


--
-- Name: elucan_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY elucan
    ADD CONSTRAINT elucan_pkey PRIMARY KEY (eluid);


--
-- Name: eludep_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY eludep
    ADD CONSTRAINT eludep_pkey PRIMARY KEY (eluid);


--
-- Name: eludiv_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY eludiv
    ADD CONSTRAINT eludiv_pkey PRIMARY KEY (eluid);


--
-- Name: elueur_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY elueur
    ADD CONSTRAINT elueur_pkey PRIMARY KEY (eluid);


--
-- Name: elureg_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY elureg
    ADD CONSTRAINT elureg_pkey PRIMARY KEY (eluid);


--
-- Name: elusen_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY elusen
    ADD CONSTRAINT elusen_pkey PRIMARY KEY (eluid);


--
-- Name: eluter_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY eluter
    ADD CONSTRAINT eluter_pkey PRIMARY KEY (eluid);


--
-- Name: elutit_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY elutit
    ADD CONSTRAINT elutit_pkey PRIMARY KEY (titeluid);


--
-- Name: eluvil_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY eluvil
    ADD CONSTRAINT eluvil_pkey PRIMARY KEY (eluid);


--
-- Name: etadebman_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY etadebman
    ADD CONSTRAINT etadebman_pkey PRIMARY KEY (etadebmancod);


--
-- Name: etafinman_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY etafinman
    ADD CONSTRAINT etafinman_pkey PRIMARY KEY (etafinmancod);


--
-- Name: etasen_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY etasen
    ADD CONSTRAINT etasen_pkey PRIMARY KEY (etasencod);


--
-- Name: fonact_participant_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY fonact_participant
    ADD CONSTRAINT fonact_participant_pkey PRIMARY KEY (fapcod);


--
-- Name: foncom_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY foncom
    ADD CONSTRAINT foncom_pkey PRIMARY KEY (foncomcod);


--
-- Name: fondelega_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY fondelega
    ADD CONSTRAINT fondelega_pkey PRIMARY KEY (fondelcod);


--
-- Name: fongrppol_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY fongrppol
    ADD CONSTRAINT fongrppol_pkey PRIMARY KEY (fongrppolcod);


--
-- Name: fongrpsen_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY fongrpsen
    ADD CONSTRAINT fongrpsen_pkey PRIMARY KEY (fongrpsencod);


--
-- Name: fonmemcom_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY fonmemcom
    ADD CONSTRAINT fonmemcom_pkey PRIMARY KEY (fonmemcomid);


--
-- Name: fonmemdelega_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY fonmemdelega
    ADD CONSTRAINT fonmemdelega_pkey PRIMARY KEY (fonmemdelid);


--
-- Name: fonmemgrppol_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY fonmemgrppol
    ADD CONSTRAINT fonmemgrppol_pkey PRIMARY KEY (fonmemgrppolid);


--
-- Name: fonmemgrpsen_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY fonmemgrpsen
    ADD CONSTRAINT fonmemgrpsen_pkey PRIMARY KEY (fonmemgrpsenid);


--
-- Name: fonmemorg_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY fonmemorg
    ADD CONSTRAINT fonmemorg_pkey PRIMARY KEY (fonmemorgid);


--
-- Name: fonorg_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY fonorg
    ADD CONSTRAINT fonorg_pkey PRIMARY KEY (fonorgcod);


--
-- Name: grppol_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY grppol
    ADD CONSTRAINT grppol_pkey PRIMARY KEY (grppolcod);


--
-- Name: grpsenami_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY grpsenami
    ADD CONSTRAINT grpsenami_pkey PRIMARY KEY (orgcod);


--
-- Name: libcom_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY libcom
    ADD CONSTRAINT libcom_pkey PRIMARY KEY (libcomid);


--
-- Name: libdelega_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY libdelega
    ADD CONSTRAINT libdelega_pkey PRIMARY KEY (libdelegaid);


--
-- Name: libgrppol_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY libgrppol
    ADD CONSTRAINT libgrppol_pkey PRIMARY KEY (libgrppolid);


--
-- Name: libgrpsen_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY libgrpsen
    ADD CONSTRAINT libgrpsen_pkey PRIMARY KEY (libgrpsenid);


--
-- Name: liborg_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY liborg
    ADD CONSTRAINT liborg_pkey PRIMARY KEY (liborgid);


--
-- Name: mel_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY mel
    ADD CONSTRAINT mel_pkey PRIMARY KEY (melid);


--
-- Name: memcom_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY memcom
    ADD CONSTRAINT memcom_pkey PRIMARY KEY (memcomid);


--
-- Name: memdelega_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY memdelega
    ADD CONSTRAINT memdelega_pkey PRIMARY KEY (memdelegaid);


--
-- Name: memextpar_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY memextpar
    ADD CONSTRAINT memextpar_pkey PRIMARY KEY (memextparid);


--
-- Name: memgrppol_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY memgrppol
    ADD CONSTRAINT memgrppol_pkey PRIMARY KEY (memgrppolid);


--
-- Name: memgrpsen_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY memgrpsen
    ADD CONSTRAINT memgrpsen_pkey PRIMARY KEY (memgrpsenid);


--
-- Name: memorg_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY memorg
    ADD CONSTRAINT memorg_pkey PRIMARY KEY (memorgid);


--
-- Name: minind_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY minind
    ADD CONSTRAINT minind_pkey PRIMARY KEY (minid);


--
-- Name: mismin_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY mismin
    ADD CONSTRAINT mismin_pkey PRIMARY KEY (minid, misid);


--
-- Name: missen_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY missen
    ADD CONSTRAINT missen_pkey PRIMARY KEY (misid, senmat);


--
-- Name: moddes_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY moddes
    ADD CONSTRAINT moddes_pkey PRIMARY KEY (moddescod);


--
-- Name: nation_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY nation
    ADD CONSTRAINT nation_pkey PRIMARY KEY (nationcod);


--
-- Name: nationgrpsen_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY nationgrpsen
    ADD CONSTRAINT nationgrpsen_pkey PRIMARY KEY (nationgrpsenid);


--
-- Name: org_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY org
    ADD CONSTRAINT org_pkey PRIMARY KEY (orgcod);


--
-- Name: orgext_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY orgext
    ADD CONSTRAINT orgext_pkey PRIMARY KEY (orgcod);


--
-- Name: pcs24_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY pcs24
    ADD CONSTRAINT pcs24_pkey PRIMARY KEY (pcs24cod);


--
-- Name: pcs42_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY pcs42
    ADD CONSTRAINT pcs42_pkey PRIMARY KEY (pcs42cod);


--
-- Name: pcs8_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY pcs8
    ADD CONSTRAINT pcs8_pkey PRIMARY KEY (pcs8cod);


--
-- Name: pcs_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY pcs
    ADD CONSTRAINT pcs_pkey PRIMARY KEY (pcscod);


--
-- Name: pcscatpro_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY pcscatpro
    ADD CONSTRAINT pcscatpro_pkey PRIMARY KEY (pcscatproid);


--
-- Name: poicon_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY poicon
    ADD CONSTRAINT poicon_pkey PRIMARY KEY (poiconid);


--
-- Name: qua_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY qua
    ADD CONSTRAINT qua_pkey PRIMARY KEY (quacod);


--
-- Name: reg_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY reg
    ADD CONSTRAINT reg_pkey PRIMARY KEY (regcod);


--
-- Name: sen_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY sen
    ADD CONSTRAINT sen_pkey PRIMARY KEY (senmat);


--
-- Name: senbur_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY senbur
    ADD CONSTRAINT senbur_pkey PRIMARY KEY (senburid);


--
-- Name: sennom_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY sennom
    ADD CONSTRAINT sennom_pkey PRIMARY KEY (sennomid);


--
-- Name: senurl_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY senurl
    ADD CONSTRAINT senurl_pkey PRIMARY KEY (senurlid);


--
-- Name: stajur_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY stajur
    ADD CONSTRAINT stajur_pkey PRIMARY KEY (stajurcod);


--
-- Name: telephone_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY telephone
    ADD CONSTRAINT telephone_pkey PRIMARY KEY (telid);


--
-- Name: temval_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY temval
    ADD CONSTRAINT temval_pkey PRIMARY KEY (temvalcod);


--
-- Name: territ_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY territ
    ADD CONSTRAINT territ_pkey PRIMARY KEY (territcod);


--
-- Name: titele_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY titele
    ADD CONSTRAINT titele_pkey PRIMARY KEY (titelecod);


--
-- Name: typadr_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY typadr
    ADD CONSTRAINT typadr_pkey PRIMARY KEY (typadrcod);


--
-- Name: typapppol_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY typapppol
    ADD CONSTRAINT typapppol_pkey PRIMARY KEY (typapppolcod);


--
-- Name: typbister_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY typbister
    ADD CONSTRAINT typbister_pkey PRIMARY KEY (typbistercod);


--
-- Name: type_activite_participant_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY type_activite_participant
    ADD CONSTRAINT type_activite_participant_pkey PRIMARY KEY (typactparcod);


--
-- Name: type_activite_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY type_activite
    ADD CONSTRAINT type_activite_pkey PRIMARY KEY (typactcod);


--
-- Name: type_activite_senateur_numtri_key; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY type_activite_senateur
    ADD CONSTRAINT type_activite_senateur_numtri_key UNIQUE (numtri);


--
-- Name: type_activite_senateur_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY type_activite_senateur
    ADD CONSTRAINT type_activite_senateur_pkey PRIMARY KEY (typactsencod);


--
-- Name: type_categorie_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY type_categorie
    ADD CONSTRAINT type_categorie_pkey PRIMARY KEY (typactcod, catactcod);


--
-- Name: typele_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY typele
    ADD CONSTRAINT typele_pkey PRIMARY KEY (typelecod);


--
-- Name: typgrpsen_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY typgrpsen
    ADD CONSTRAINT typgrpsen_pkey PRIMARY KEY (typgrpsencod);


--
-- Name: typman_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY typman
    ADD CONSTRAINT typman_pkey PRIMARY KEY (typmancod);


--
-- Name: typorg_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY typorg
    ADD CONSTRAINT typorg_pkey PRIMARY KEY (typorgcod);


--
-- Name: typurl_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY typurl
    ADD CONSTRAINT typurl_pkey PRIMARY KEY (typurlcod);


--
-- Name: typvoi_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY typvoi
    ADD CONSTRAINT typvoi_pkey PRIMARY KEY (typvoicod);


--
-- Name: zongeo_pkey; Type: CONSTRAINT; Schema: public; Owner: opendata; Tablespace: 
--

ALTER TABLE ONLY zongeo
    ADD CONSTRAINT zongeo_pkey PRIMARY KEY (zongeocod);


--
-- Name: act_par_actid; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX act_par_actid ON activite_participant USING btree (actid);


--
-- Name: act_par_senmat; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX act_par_senmat ON activite_participant USING btree (senmat);


--
-- Name: idx_actdatdeb; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX idx_actdatdeb ON activite USING btree (datdeb);


--
-- Name: idx_actdatfin; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX idx_actdatfin ON activite USING btree (datfin);


--
-- Name: idx_actenvjodat; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX idx_actenvjodat ON activite USING btree (envjodat);


--
-- Name: idx_actvaliddat; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX idx_actvaliddat ON activite USING btree (validdat);


--
-- Name: idx_sen_nom_prenom_datnai; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE UNIQUE INDEX idx_sen_nom_prenom_datnai ON sen USING btree (sennomuse, senprenomuse, sendatnai);


--
-- Name: ixe_assoc_38447; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_assoc_38447 ON grppol USING btree (typorgcod);


--
-- Name: ixe_association_209; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_association_209 ON orgthe USING btree (orgcod);


--
-- Name: ixe_bassenorg; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_bassenorg ON orgext USING btree (basdescod);


--
-- Name: ixe_bursenbur; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_bursenbur ON senbur USING btree (burcod);


--
-- Name: ixe_catterrit; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_catterrit ON territ USING btree (catterritcod);


--
-- Name: ixe_com; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_com ON memcom USING btree (orgcod);


--
-- Name: ixe_comdiv; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_comdiv ON com USING btree (divcod);


--
-- Name: ixe_correspondance_cat_csp; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_correspondance_cat_csp ON csp USING btree (catprocod);


--
-- Name: ixe_designatairede; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_designatairede ON designoep USING btree (designcod);


--
-- Name: ixe_designcom; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_designcom ON design USING btree (orgcod);


--
-- Name: ixe_designe; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_designe ON designoep USING btree (orgcod);


--
-- Name: ixe_designmemdelega; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_designmemdelega ON memdelega USING btree (designcod);


--
-- Name: ixe_designmemextpar; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_designmemextpar ON memextpar USING btree (designcod);


--
-- Name: ixe_designmemorg; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_designmemorg ON memorg USING btree (designcod);


--
-- Name: ixe_dptele2; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_dptele2 ON dptele USING btree (dptnum);


--
-- Name: ixe_dpttypman; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_dpttypman ON dpttypman USING btree (dptnum);


--
-- Name: ixe_dpttypman2; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_dpttypman2 ON dpttypman USING btree (typmancod);


--
-- Name: ixe_eleann; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_eleann ON dptele USING btree (eleid);


--
-- Name: ixe_elections; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_elections ON ele USING btree (typmancod);


--
-- Name: ixe_elutur; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_elutur ON elusen USING btree (turelucod);


--
-- Name: ixe_etaprrorg; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_etaprrorg ON orgext USING btree (etaprrcod);


--
-- Name: ixe_famille_csp; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_famille_csp ON csp USING btree (cspfamcod);


--
-- Name: ixe_fondelmem; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_fondelmem ON fonmemdelega USING btree (fondelcod);


--
-- Name: ixe_fongrppolmem; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_fongrppolmem ON fonmemgrppol USING btree (fongrppolcod);


--
-- Name: ixe_fongrpsenmem; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_fongrpsenmem ON fonmemgrpsen USING btree (fongrpsencod);


--
-- Name: ixe_fonmemcommemcom; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_fonmemcommemcom ON fonmemcom USING btree (foncomcod);


--
-- Name: ixe_fonorgmem; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_fonorgmem ON fonmemorg USING btree (fonorgcod);


--
-- Name: ixe_grppol; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_grppol ON memgrppol USING btree (grppolcod);


--
-- Name: ixe_grpsen; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_grpsen ON memgrpsen USING btree (orgcod);


--
-- Name: ixe_grpsencom; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_grpsencom ON grpsenami USING btree (comorgcod);


--
-- Name: ixe_grpsennat; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_grpsennat ON nationgrpsen USING btree (orgcod);


--
-- Name: ixe_libcom; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_libcom ON libcom USING btree (orgcod);


--
-- Name: ixe_libdelega; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_libdelega ON libdelega USING btree (orgcod);


--
-- Name: ixe_libgrppol; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_libgrppol ON libgrppol USING btree (grppolcod);


--
-- Name: ixe_libgrpsen; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_libgrpsen ON libgrpsen USING btree (orgcod);


--
-- Name: ixe_liborg; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_liborg ON liborg USING btree (orgcod);


--
-- Name: ixe_lien_32089; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_lien_32089 ON pcscatpro USING btree (catprocod);


--
-- Name: ixe_lien_32095; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_lien_32095 ON pcscatpro USING btree (pcscod);


--
-- Name: ixe_manasster; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_manasster ON eluter USING btree (asstercod);


--
-- Name: ixe_mancandpt; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_mancandpt ON elucan USING btree (dptnum);


--
-- Name: ixe_mandep; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_mandep ON eludep USING btree (depcod);


--
-- Name: ixe_mandpt; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_mandpt ON elusen USING btree (dptnum);


--
-- Name: ixe_maneur; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_maneur ON elueur USING btree (nationcod);


--
-- Name: ixe_manreg; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_manreg ON elureg USING btree (regcod);


--
-- Name: ixe_memcom; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_memcom ON memcom USING btree (senmat);


--
-- Name: ixe_memcomfon; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_memcomfon ON fonmemcom USING btree (memcomid);


--
-- Name: ixe_memdelfon; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_memdelfon ON fonmemdelega USING btree (memdelegaid);


--
-- Name: ixe_memgrppol; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_memgrppol ON memgrppol USING btree (senmat);


--
-- Name: ixe_memgrppolfon; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_memgrppolfon ON fonmemgrppol USING btree (memgrppolid);


--
-- Name: ixe_memgrpsen; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_memgrpsen ON memgrpsen USING btree (senmat);


--
-- Name: ixe_memgrpsenfon; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_memgrpsenfon ON fonmemgrpsen USING btree (memgrpsenid);


--
-- Name: ixe_memgvt; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_memgvt ON minind USING btree (gvtid);


--
-- Name: ixe_memorg; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_memorg ON memorg USING btree (senmat);


--
-- Name: ixe_memorgfon; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_memorgfon ON fonmemorg USING btree (memorgid);


--
-- Name: ixe_memorgorg; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_memorgorg ON memorg USING btree (orgcod);


--
-- Name: ixe_minindtypmin; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_minindtypmin ON minind USING btree (typmincod);


--
-- Name: ixe_mismin2; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_mismin2 ON mismin USING btree (minid);


--
-- Name: ixe_mismin3; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_mismin3 ON mismin USING btree (misid);


--
-- Name: ixe_missen2; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_missen2 ON missen USING btree (senmat);


--
-- Name: ixe_missen3; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_missen3 ON missen USING btree (misid);


--
-- Name: ixe_natgrpsen; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_natgrpsen ON nationgrpsen USING btree (nationcod);


--
-- Name: ixe_natzongeo; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_natzongeo ON nation USING btree (zongeocod);


--
-- Name: ixe_orgext; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_orgext ON memextpar USING btree (orgcod);


--
-- Name: ixe_orgextmoddes; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_orgextmoddes ON design USING btree (moddescod);


--
-- Name: ixe_orgthe2; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_orgthe2 ON orgthe USING btree (thecle);


--
-- Name: ixe_participat1; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_participat1 ON dptele USING btree (participaidt1);


--
-- Name: ixe_participat2; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_participat2 ON dptele USING btree (participaidt2);


--
-- Name: ixe_pcs24pcs8; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_pcs24pcs8 ON pcs24 USING btree (pcs8cod);


--
-- Name: ixe_pcs42pcs24; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_pcs42pcs24 ON pcs42 USING btree (pcs24cod);


--
-- Name: ixe_pcspcs42; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_pcspcs42 ON pcs USING btree (pcs42cod);


--
-- Name: ixe_plaind; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_plaind ON grpsenami USING btree (plaindcod);


--
-- Name: ixe_poiconadr; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_poiconadr ON adresse USING btree (poiconid);


--
-- Name: ixe_poiconmel; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_poiconmel ON mel USING btree (poiconid);


--
-- Name: ixe_poicontel; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_poicontel ON telephone USING btree (poiconid);


--
-- Name: ixe_point_de_contact; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_point_de_contact ON poicon USING btree (senmat);


--
-- Name: ixe_pro; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_pro ON sen USING btree (pcscod);


--
-- Name: ixe_qualite; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_qualite ON sennom USING btree (quacod);


--
-- Name: ixe_ratdelega; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_ratdelega ON memdelega USING btree (orgcod);


--
-- Name: ixe_ref_116202; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_ref_116202 ON memdelega USING btree (temvalcod);


--
-- Name: ixe_ref_116203; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_ref_116203 ON memcom USING btree (temvalcod);


--
-- Name: ixe_ref_116204; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_ref_116204 ON fonmemdelega USING btree (temvalcod);


--
-- Name: ixe_ref_116205; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_ref_116205 ON fonmemcom USING btree (temvalcod);


--
-- Name: ixe_ref_116206; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_ref_116206 ON memextpar USING btree (temvalcod);


--
-- Name: ixe_ref_116207; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_ref_116207 ON memgrppol USING btree (temvalcod);


--
-- Name: ixe_ref_116208; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_ref_116208 ON senbur USING btree (temvalcod);


--
-- Name: ixe_ref_116209; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_ref_116209 ON fonmemgrppol USING btree (temvalcod);


--
-- Name: ixe_ref_116211; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_ref_116211 ON libgrppol USING btree (temvalcod);


--
-- Name: ixe_ref_116212; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_ref_116212 ON grppol USING btree (temvalcod);


--
-- Name: ixe_ref_116213; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_ref_116213 ON minind USING btree (temvalcod);


--
-- Name: ixe_ref_116215; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_ref_116215 ON fonmemgrpsen USING btree (temvalcod);


--
-- Name: ixe_ref_116216; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_ref_116216 ON memgrpsen USING btree (temvalcod);


--
-- Name: ixe_ref_116220; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_ref_116220 ON nationgrpsen USING btree (temvalcod);


--
-- Name: ixe_ref_116339; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_ref_116339 ON sen USING btree (quacod);


--
-- Name: ixe_ref_162007; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_ref_162007 ON org USING btree (temvalcod);


--
-- Name: ixe_ref_188374; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_ref_188374 ON elusen USING btree (senmat);


--
-- Name: ixe_ref_188375; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_ref_188375 ON elusen USING btree (etadebmancod);


--
-- Name: ixe_ref_188376; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_ref_188376 ON elusen USING btree (etafinmancod);


--
-- Name: ixe_ref_188378; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_ref_188378 ON elusen USING btree (typmancod);


--
-- Name: ixe_ref_188379; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_ref_188379 ON elusen USING btree (temvalcod);


--
-- Name: ixe_ref_188383; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_ref_188383 ON eluvil USING btree (senmat);


--
-- Name: ixe_ref_188387; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_ref_188387 ON eluvil USING btree (typmancod);


--
-- Name: ixe_ref_188388; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_ref_188388 ON eluvil USING btree (temvalcod);


--
-- Name: ixe_ref_188392; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_ref_188392 ON elucan USING btree (senmat);


--
-- Name: ixe_ref_188396; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_ref_188396 ON elucan USING btree (typmancod);


--
-- Name: ixe_ref_188397; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_ref_188397 ON elucan USING btree (temvalcod);


--
-- Name: ixe_ref_188401; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_ref_188401 ON elureg USING btree (senmat);


--
-- Name: ixe_ref_188405; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_ref_188405 ON elureg USING btree (typmancod);


--
-- Name: ixe_ref_188406; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_ref_188406 ON elureg USING btree (temvalcod);


--
-- Name: ixe_ref_188410; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_ref_188410 ON eludep USING btree (senmat);


--
-- Name: ixe_ref_188414; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_ref_188414 ON eludep USING btree (typmancod);


--
-- Name: ixe_ref_188415; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_ref_188415 ON eludep USING btree (temvalcod);


--
-- Name: ixe_ref_188419; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_ref_188419 ON eludiv USING btree (senmat);


--
-- Name: ixe_ref_188423; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_ref_188423 ON eludiv USING btree (typmancod);


--
-- Name: ixe_ref_188424; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_ref_188424 ON eludiv USING btree (temvalcod);


--
-- Name: ixe_ref_188428; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_ref_188428 ON elueur USING btree (senmat);


--
-- Name: ixe_ref_188432; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_ref_188432 ON elueur USING btree (typmancod);


--
-- Name: ixe_ref_188433; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_ref_188433 ON elueur USING btree (temvalcod);


--
-- Name: ixe_ref_188437; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_ref_188437 ON eluter USING btree (senmat);


--
-- Name: ixe_ref_188441; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_ref_188441 ON eluter USING btree (typmancod);


--
-- Name: ixe_ref_188442; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_ref_188442 ON eluter USING btree (temvalcod);


--
-- Name: ixe_ref_242232; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_ref_242232 ON memorg USING btree (temvalcod);


--
-- Name: ixe_regterrit; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_regterrit ON reg USING btree (territcod);


--
-- Name: ixe_remplacepar; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_remplacepar ON reg USING btree (regcodrpl);


--
-- Name: ixe_section; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_section ON grpsenami USING btree (scnorgcod);


--
-- Name: ixe_sencatpro; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_sencatpro ON sen USING btree (catprocod);


--
-- Name: ixe_sencirnumcou; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_sencirnumcou ON sen USING btree (sencirnumcou);


--
-- Name: ixe_sendelega; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_sendelega ON memdelega USING btree (senmat);


--
-- Name: ixe_seneta; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_seneta ON sen USING btree (etasencod);


--
-- Name: ixe_senetaciv; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_senetaciv ON sennom USING btree (senmat);


--
-- Name: ixe_senmin; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_senmin ON minind USING btree (senmat);


--
-- Name: ixe_sennom; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE UNIQUE INDEX ixe_sennom ON sennom USING btree (senmat, sennomdatdeb);


--
-- Name: ixe_sennomina; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_sennomina ON memextpar USING btree (senmat);


--
-- Name: ixe_sensenbur; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_sensenbur ON senbur USING btree (senmat);


--
-- Name: ixe_senurl; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_senurl ON senurl USING btree (senmat);


--
-- Name: ixe_sitdanreg; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_sitdanreg ON dpt USING btree (regcod);


--
-- Name: ixe_stajurorg; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_stajurorg ON orgext USING btree (stajurcod);


--
-- Name: ixe_temval; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_temval ON dpt USING btree (temvalcod);


--
-- Name: ixe_temval10; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_temval10 ON moddes USING btree (temvalcod);


--
-- Name: ixe_temval23; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_temval23 ON elutit USING btree (temvalcod);


--
-- Name: ixe_temval31; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_temval31 ON fonmemorg USING btree (temvalcod);


--
-- Name: ixe_temval32; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_temval32 ON typgrpsen USING btree (temvalcod);


--
-- Name: ixe_temval34; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_temval34 ON design USING btree (temvalcod);


--
-- Name: ixe_temval35; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_temval35 ON designoep USING btree (temvalcod);


--
-- Name: ixe_temval36; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_temval36 ON designorg USING btree (temvalcod);


--
-- Name: ixe_temval37; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_temval37 ON liborg USING btree (temvalcod);


--
-- Name: ixe_temval38; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_temval38 ON libcom USING btree (temvalcod);


--
-- Name: ixe_temval39; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_temval39 ON libdelega USING btree (temvalcod);


--
-- Name: ixe_temval40; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_temval40 ON typurl USING btree (temvalcod);


--
-- Name: ixe_temval41; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_temval41 ON senurl USING btree (temvalcod);


--
-- Name: ixe_titeletypman; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_titeletypman ON titele USING btree (typmancod);


--
-- Name: ixe_titelu; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_titelu ON elutit USING btree (eluid);


--
-- Name: ixe_titelutit; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_titelutit ON elutit USING btree (titelecod);


--
-- Name: ixe_titmin; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_titmin ON minind USING btree (titmincod);


--
-- Name: ixe_typapppol; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_typapppol ON memgrppol USING btree (typapppolcod);


--
-- Name: ixe_typbister; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_typbister ON adresse USING btree (typbistercod);


--
-- Name: ixe_typele; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_typele ON dptele USING btree (typelecod);


--
-- Name: ixe_typgrpsen; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_typgrpsen ON grpsenami USING btree (typgrpsencod);


--
-- Name: ixe_typorg; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_typorg ON org USING btree (typorgcod);


--
-- Name: ixe_typorg_com; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_typorg_com ON com USING btree (typorgcod);


--
-- Name: ixe_typorg_delega; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_typorg_delega ON delega USING btree (typorgcod);


--
-- Name: ixe_typorg_grpsenami; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_typorg_grpsenami ON grpsenami USING btree (typorgcod);


--
-- Name: ixe_typorg_orgext; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_typorg_orgext ON orgext USING btree (typorgcod);


--
-- Name: ixe_typpoicon; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_typpoicon ON poicon USING btree (typpoiconcod);


--
-- Name: ixe_typtel; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_typtel ON telephone USING btree (typtelcod);


--
-- Name: ixe_typurlsen; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_typurlsen ON senurl USING btree (typurlcod);


--
-- Name: ixe_typvoi; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_typvoi ON adresse USING btree (typvoicod);


--
-- Name: ixe_validation; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_validation ON dptele USING btree (validcod);


--
-- Name: ixe_validation2; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_validation2 ON dptele USING btree (valid2cod);


--
-- Name: ixe_zongeocon; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixe_zongeocon ON zongeo USING btree (concod);


--
-- Name: ixi_elucandatdeb; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_elucandatdeb ON elucan USING btree (eludatdeb);


--
-- Name: ixi_elucandatfin; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_elucandatfin ON elucan USING btree (eludatfin);


--
-- Name: ixi_eludepdatdeb; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_eludepdatdeb ON eludep USING btree (eludatdeb);


--
-- Name: ixi_eludepdatfin; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_eludepdatfin ON eludep USING btree (eludatfin);


--
-- Name: ixi_eludivdatdeb; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_eludivdatdeb ON eludiv USING btree (eludatdeb);


--
-- Name: ixi_eludivdatfin; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_eludivdatfin ON eludiv USING btree (eludatfin);


--
-- Name: ixi_elueurdatdeb; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_elueurdatdeb ON elueur USING btree (eludatdeb);


--
-- Name: ixi_elueurdatfin; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_elueurdatfin ON elueur USING btree (eludatfin);


--
-- Name: ixi_elureg; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_elureg ON elureg USING btree (eludatdeb);


--
-- Name: ixi_eluregdatfin; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_eluregdatfin ON elureg USING btree (eludatfin);


--
-- Name: ixi_elusendatdeb; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_elusendatdeb ON elusen USING btree (eludatdeb);


--
-- Name: ixi_elusendatfin; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_elusendatfin ON elusen USING btree (eludatfin);


--
-- Name: ixi_eluterdatdeb; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_eluterdatdeb ON eluter USING btree (eludatdeb);


--
-- Name: ixi_eluterdatfin; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_eluterdatfin ON eluter USING btree (eludatfin);


--
-- Name: ixi_elutitdatdeb; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_elutitdatdeb ON elutit USING btree (titeludatdeb);


--
-- Name: ixi_elutitdatfin; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_elutitdatfin ON elutit USING btree (titeludatfin);


--
-- Name: ixi_eluvildatdeb; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_eluvildatdeb ON eluvil USING btree (eludatdeb);


--
-- Name: ixi_eluvildatfin; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_eluvildatfin ON eluvil USING btree (eludatfin);


--
-- Name: ixi_fonmemcomdatfin; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_fonmemcomdatfin ON fonmemcom USING btree (fonmemcomdatfin);


--
-- Name: ixi_fonmemdeldatfin; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_fonmemdeldatfin ON fonmemdelega USING btree (fonmemdeldatfin);


--
-- Name: ixi_fonmemgrppoldatdeb; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_fonmemgrppoldatdeb ON fonmemgrppol USING btree (fonmemgrppoldatdeb);


--
-- Name: ixi_fonmemgrppoldatfin; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_fonmemgrppoldatfin ON fonmemgrppol USING btree (fonmemgrppoldatfin);


--
-- Name: ixi_fonmemgrpsendatdeb; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_fonmemgrpsendatdeb ON fonmemgrpsen USING btree (fonmemgrpsendatdeb);


--
-- Name: ixi_fonmemgrpsendatfin; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_fonmemgrpsendatfin ON fonmemgrpsen USING btree (fonmemgrpsendatfin);


--
-- Name: ixi_fonmemorgdatdeb; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_fonmemorgdatdeb ON fonmemorg USING btree (fonmemorgdatdeb);


--
-- Name: ixi_fonmemorgdatfin; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_fonmemorgdatfin ON fonmemorg USING btree (fonmemorgdatfin);


--
-- Name: ixi_fonmencomdatdeb; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_fonmencomdatdeb ON fonmemcom USING btree (fonmemcomdatdeb);


--
-- Name: ixi_fonmendeldatdeb; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_fonmendeldatdeb ON fonmemdelega USING btree (fonmemdeldatdeb);


--
-- Name: ixi_grpsenami; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_grpsenami ON grpsenami USING btree (evelic);


--
-- Name: ixi_libcomdatdeb; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_libcomdatdeb ON libcom USING btree (libcomdatdeb);


--
-- Name: ixi_libcomdatfin; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_libcomdatfin ON libcom USING btree (libcomdatfin);


--
-- Name: ixi_libdelegadatdeb; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_libdelegadatdeb ON libdelega USING btree (libdelegadatdeb);


--
-- Name: ixi_libdelegadatfin; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_libdelegadatfin ON libdelega USING btree (libdelegadatfin);


--
-- Name: ixi_libgrppoldatdeb; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_libgrppoldatdeb ON libgrppol USING btree (libgrppoldatdeb);


--
-- Name: ixi_libgrppoldatfin; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_libgrppoldatfin ON libgrppol USING btree (libgrppoldatfin);


--
-- Name: ixi_libgrpsendatautbur; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_libgrpsendatautbur ON libgrpsen USING btree (libgrpsendatautbur);


--
-- Name: ixi_libgrpsendatfin; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_libgrpsendatfin ON libgrpsen USING btree (libgrpsendatfin);


--
-- Name: ixi_liborgdatdeb; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_liborgdatdeb ON liborg USING btree (liborgdatdeb);


--
-- Name: ixi_liborgdatfin; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_liborgdatfin ON liborg USING btree (liborgdatfin);


--
-- Name: ixi_memcomdatdeb; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_memcomdatdeb ON memcom USING btree (memcomdatdeb);


--
-- Name: ixi_memcomdatfin; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_memcomdatfin ON memcom USING btree (memcomdatfin);


--
-- Name: ixi_memdelegadatdeb; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_memdelegadatdeb ON memdelega USING btree (memdelegadatdeb);


--
-- Name: ixi_memdelegadatfin; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_memdelegadatfin ON memdelega USING btree (memdelegadatfin);


--
-- Name: ixi_memextpardatdeb; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_memextpardatdeb ON memextpar USING btree (memextpardatdeb);


--
-- Name: ixi_memextpardatfin; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_memextpardatfin ON memextpar USING btree (memextpardatfin);


--
-- Name: ixi_memextparrngele; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_memextparrngele ON memextpar USING btree (memextparrngele, memextpartitsup, memextpardatdeb);


--
-- Name: ixi_memgrppoldatdeb; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_memgrppoldatdeb ON memgrppol USING btree (memgrppoldatdeb);


--
-- Name: ixi_memgrppoldatfin; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_memgrppoldatfin ON memgrppol USING btree (memgrppoldatfin);


--
-- Name: ixi_memgrpsendatent; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_memgrpsendatent ON memgrpsen USING btree (memgrpsendatent);


--
-- Name: ixi_memgrpsendatfin; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_memgrpsendatfin ON memgrpsen USING btree (memgrpsendatsor);


--
-- Name: ixi_memorgdatdeb; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_memorgdatdeb ON memorg USING btree (memorgdatdeb);


--
-- Name: ixi_memorgdatfin; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_memorgdatfin ON memorg USING btree (memorgdatfin);


--
-- Name: ixi_mininddatdeb; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_mininddatdeb ON minind USING btree (mindatdeb);


--
-- Name: ixi_mininddatfin; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_mininddatfin ON minind USING btree (mindatfin);


--
-- Name: ixi_nation; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_nation ON nation USING btree (nationlibcog);


--
-- Name: ixi_orgnumtri; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_orgnumtri ON orgext USING btree (orgnumtri);


--
-- Name: ixi_senburdatdeb; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_senburdatdeb ON senbur USING btree (senburdatdeb);


--
-- Name: ixi_senburdatfin; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_senburdatfin ON senbur USING btree (senburdatfin);


--
-- Name: ixi_sendatnai; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_sendatnai ON sen USING btree (sendatnai);


--
-- Name: ixi_sennomdatdeb; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_sennomdatdeb ON sennom USING btree (sennomdatdeb);


--
-- Name: ixi_sennomdatfin; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE INDEX ixi_sennomdatfin ON sennom USING btree (sennomdatfin);


--
-- Name: ixi_sennomtec; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE UNIQUE INDEX ixi_sennomtec ON sen USING btree (sennomtec);


--
-- Name: ixu_libcom; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE UNIQUE INDEX ixu_libcom ON libcom USING btree (orgcod, libcomdatdeb);


--
-- Name: ixu_libdelega; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE UNIQUE INDEX ixu_libdelega ON libdelega USING btree (orgcod, libdelegadatdeb);


--
-- Name: ixu_libgrppol; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE UNIQUE INDEX ixu_libgrppol ON libgrppol USING btree (grppolcod, libgrppoldatdeb);


--
-- Name: ixu_libgrpsen; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE UNIQUE INDEX ixu_libgrpsen ON libgrpsen USING btree (orgcod, libgrpsendatautbur);


--
-- Name: ixu_liborg; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE UNIQUE INDEX ixu_liborg ON liborg USING btree (orgcod, liborgdatdeb);


--
-- Name: ixu_orgthe; Type: INDEX; Schema: public; Owner: opendata; Tablespace: 
--

CREATE UNIQUE INDEX ixu_orgthe ON orgthe USING btree (thecle, orgcod);


--
-- Name: fk_act_deleg_act; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY activite_delegation
    ADD CONSTRAINT fk_act_deleg_act FOREIGN KEY (actid) REFERENCES activite(actid);


--
-- Name: fk_act_deleg_del; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY activite_delegation
    ADD CONSTRAINT fk_act_deleg_del FOREIGN KEY (senmat_delegue) REFERENCES sen(senmat);


--
-- Name: fk_act_deleg_sen; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY activite_delegation
    ADD CONSTRAINT fk_act_deleg_sen FOREIGN KEY (senmat) REFERENCES sen(senmat);


--
-- Name: fk_act_ge; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY activite
    ADD CONSTRAINT fk_act_ge FOREIGN KEY (gecod) REFERENCES grpsenami(orgcod);


--
-- Name: fk_act_gia; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY activite
    ADD CONSTRAINT fk_act_gia FOREIGN KEY (giacod) REFERENCES grpsenami(orgcod);


--
-- Name: fk_act_liees_act_d; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY activites_liees
    ADD CONSTRAINT fk_act_liees_act_d FOREIGN KEY (droite) REFERENCES activite(actid);


--
-- Name: fk_act_liees_act_g; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY activites_liees
    ADD CONSTRAINT fk_act_liees_act_g FOREIGN KEY (gauche) REFERENCES activite(actid);


--
-- Name: fk_act_participant_act; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY activite_participant
    ADD CONSTRAINT fk_act_participant_act FOREIGN KEY (actid) REFERENCES activite(actid);


--
-- Name: fk_actisen_sen; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY activite_senateur
    ADD CONSTRAINT fk_actisen_sen FOREIGN KEY (senmat) REFERENCES sen(senmat);


--
-- Name: fk_activite_categorie; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY activite
    ADD CONSTRAINT fk_activite_categorie FOREIGN KEY (catactcod) REFERENCES categorie_activite(catactcod);


--
-- Name: fk_activite_com; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY activite
    ADD CONSTRAINT fk_activite_com FOREIGN KEY (comcod) REFERENCES com(orgcod);


--
-- Name: fk_activite_delega; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY activite
    ADD CONSTRAINT fk_activite_delega FOREIGN KEY (delegacod) REFERENCES delega(orgcod);


--
-- Name: fk_activite_participant_sen; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY activite_participant
    ADD CONSTRAINT fk_activite_participant_sen FOREIGN KEY (senmat) REFERENCES sen(senmat);


--
-- Name: fk_activite_participant_type; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY activite_participant
    ADD CONSTRAINT fk_activite_participant_type FOREIGN KEY (typactparcod) REFERENCES type_activite_participant(typactparcod);


--
-- Name: fk_activite_type; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY activite
    ADD CONSTRAINT fk_activite_type FOREIGN KEY (typactcod) REFERENCES type_activite(typactcod);


--
-- Name: fk_actloi_act; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY activite_loi
    ADD CONSTRAINT fk_actloi_act FOREIGN KEY (actid) REFERENCES activite(actid);


--
-- Name: fk_actsen_type; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY activite_senateur
    ADD CONSTRAINT fk_actsen_type FOREIGN KEY (typactsencod) REFERENCES type_activite_senateur(typactsencod);


--
-- Name: fk_adresse_poiconadr_poicon; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY adresse
    ADD CONSTRAINT fk_adresse_poiconadr_poicon FOREIGN KEY (poiconid) REFERENCES poicon(poiconid);


--
-- Name: fk_adresse_typbister_typbiste; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY adresse
    ADD CONSTRAINT fk_adresse_typbister_typbiste FOREIGN KEY (typbistercod) REFERENCES typbister(typbistercod);


--
-- Name: fk_adresse_typvoi_typvoi; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY adresse
    ADD CONSTRAINT fk_adresse_typvoi_typvoi FOREIGN KEY (typvoicod) REFERENCES typvoi(typvoicod);


--
-- Name: fk_com_com_temva_temval; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY com
    ADD CONSTRAINT fk_com_com_temva_temval FOREIGN KEY (temvalcod) REFERENCES temval(temvalcod);


--
-- Name: fk_com_reference_typorg; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY com
    ADD CONSTRAINT fk_com_reference_typorg FOREIGN KEY (typorgcod) REFERENCES typorg(typorgcod);


--
-- Name: fk_delega_delega_te_temval; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY delega
    ADD CONSTRAINT fk_delega_delega_te_temval FOREIGN KEY (temvalcod) REFERENCES temval(temvalcod);


--
-- Name: fk_delega_typorg_typorg; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY delega
    ADD CONSTRAINT fk_delega_typorg_typorg FOREIGN KEY (typorgcod) REFERENCES typorg(typorgcod);


--
-- Name: fk_design_designcom_com; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY design
    ADD CONSTRAINT fk_design_designcom_com FOREIGN KEY (orgcod) REFERENCES com(orgcod);


--
-- Name: fk_design_orgextmod_moddes; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY design
    ADD CONSTRAINT fk_design_orgextmod_moddes FOREIGN KEY (moddescod) REFERENCES moddes(moddescod);


--
-- Name: fk_design_temval_temval; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY design
    ADD CONSTRAINT fk_design_temval_temval FOREIGN KEY (temvalcod) REFERENCES temval(temvalcod);


--
-- Name: fk_designoe_designata_design; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY designoep
    ADD CONSTRAINT fk_designoe_designata_design FOREIGN KEY (designcod) REFERENCES design(designcod);


--
-- Name: fk_designoe_designe_orgext; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY designoep
    ADD CONSTRAINT fk_designoe_designe_orgext FOREIGN KEY (orgcod) REFERENCES orgext(orgcod);


--
-- Name: fk_designoe_temval_temval; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY designoep
    ADD CONSTRAINT fk_designoe_temval_temval FOREIGN KEY (temvalcod) REFERENCES temval(temvalcod);


--
-- Name: fk_designor_temval_temval; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY designorg
    ADD CONSTRAINT fk_designor_temval_temval FOREIGN KEY (temvalcod) REFERENCES temval(temvalcod);


--
-- Name: fk_dpt_sitdanreg_reg; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY dpt
    ADD CONSTRAINT fk_dpt_sitdanreg_reg FOREIGN KEY (regcod) REFERENCES reg(regcod);


--
-- Name: fk_dpt_temval; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY dpt
    ADD CONSTRAINT fk_dpt_temval FOREIGN KEY (temvalcod) REFERENCES temval(temvalcod);


--
-- Name: fk_dptele_dptele_dpt; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY dptele
    ADD CONSTRAINT fk_dptele_dptele_dpt FOREIGN KEY (dptnum) REFERENCES dpt(dptnum);


--
-- Name: fk_dptele_dptele_typele; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY dptele
    ADD CONSTRAINT fk_dptele_dptele_typele FOREIGN KEY (typelecod) REFERENCES typele(typelecod);


--
-- Name: fk_dptele_eleann_ele; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY dptele
    ADD CONSTRAINT fk_dptele_eleann_ele FOREIGN KEY (eleid) REFERENCES ele(eleid);


--
-- Name: fk_dpttypma_associati_dpt; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY dpttypman
    ADD CONSTRAINT fk_dpttypma_associati_dpt FOREIGN KEY (dptnum) REFERENCES dpt(dptnum);


--
-- Name: fk_dpttypma_associati_typman; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY dpttypman
    ADD CONSTRAINT fk_dpttypma_associati_typman FOREIGN KEY (typmancod) REFERENCES typman(typmancod);


--
-- Name: fk_ele_elections_typman; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY ele
    ADD CONSTRAINT fk_ele_elections_typman FOREIGN KEY (typmancod) REFERENCES typman(typmancod);


--
-- Name: fk_eleloc_eleloctit_titele; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY elutit
    ADD CONSTRAINT fk_eleloc_eleloctit_titele FOREIGN KEY (titelecod) REFERENCES titele(titelecod);


--
-- Name: fk_elucan_mancandpt_dpt; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY elucan
    ADD CONSTRAINT fk_elucan_mancandpt_dpt FOREIGN KEY (dptnum) REFERENCES dpt(dptnum);


--
-- Name: fk_elucan_ref_18839_sen; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY elucan
    ADD CONSTRAINT fk_elucan_ref_18839_sen FOREIGN KEY (senmat) REFERENCES sen(senmat);


--
-- Name: fk_elucan_ref_18839_temval; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY elucan
    ADD CONSTRAINT fk_elucan_ref_18839_temval FOREIGN KEY (temvalcod) REFERENCES temval(temvalcod);


--
-- Name: fk_elucan_ref_18839_typman; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY elucan
    ADD CONSTRAINT fk_elucan_ref_18839_typman FOREIGN KEY (typmancod) REFERENCES typman(typmancod);


--
-- Name: fk_eludep_circo_dpt; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY eludep
    ADD CONSTRAINT fk_eludep_circo_dpt FOREIGN KEY (circo) REFERENCES dpt(dptnum);


--
-- Name: fk_eludep_ref_18841_sen; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY eludep
    ADD CONSTRAINT fk_eludep_ref_18841_sen FOREIGN KEY (senmat) REFERENCES sen(senmat);


--
-- Name: fk_eludep_ref_18841_temval; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY eludep
    ADD CONSTRAINT fk_eludep_ref_18841_temval FOREIGN KEY (temvalcod) REFERENCES temval(temvalcod);


--
-- Name: fk_eludep_ref_18841_typman; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY eludep
    ADD CONSTRAINT fk_eludep_ref_18841_typman FOREIGN KEY (typmancod) REFERENCES typman(typmancod);


--
-- Name: fk_eludiv_ref_18841_sen; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY eludiv
    ADD CONSTRAINT fk_eludiv_ref_18841_sen FOREIGN KEY (senmat) REFERENCES sen(senmat);


--
-- Name: fk_eludiv_ref_18842_temval; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY eludiv
    ADD CONSTRAINT fk_eludiv_ref_18842_temval FOREIGN KEY (temvalcod) REFERENCES temval(temvalcod);


--
-- Name: fk_eludiv_ref_18842_typman; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY eludiv
    ADD CONSTRAINT fk_eludiv_ref_18842_typman FOREIGN KEY (typmancod) REFERENCES typman(typmancod);


--
-- Name: fk_elueur_maneur_nation; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY elueur
    ADD CONSTRAINT fk_elueur_maneur_nation FOREIGN KEY (nationcod) REFERENCES nation(nationcod);


--
-- Name: fk_elueur_ref_18842_sen; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY elueur
    ADD CONSTRAINT fk_elueur_ref_18842_sen FOREIGN KEY (senmat) REFERENCES sen(senmat);


--
-- Name: fk_elueur_ref_18843_temval; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY elueur
    ADD CONSTRAINT fk_elueur_ref_18843_temval FOREIGN KEY (temvalcod) REFERENCES temval(temvalcod);


--
-- Name: fk_elueur_ref_18843_typman; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY elueur
    ADD CONSTRAINT fk_elueur_ref_18843_typman FOREIGN KEY (typmancod) REFERENCES typman(typmancod);


--
-- Name: fk_elureg_manreg_reg; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY elureg
    ADD CONSTRAINT fk_elureg_manreg_reg FOREIGN KEY (regcod) REFERENCES reg(regcod);


--
-- Name: fk_elureg_ref_18840_sen; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY elureg
    ADD CONSTRAINT fk_elureg_ref_18840_sen FOREIGN KEY (senmat) REFERENCES sen(senmat);


--
-- Name: fk_elureg_ref_18840_temval; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY elureg
    ADD CONSTRAINT fk_elureg_ref_18840_temval FOREIGN KEY (temvalcod) REFERENCES temval(temvalcod);


--
-- Name: fk_elureg_ref_18840_typman; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY elureg
    ADD CONSTRAINT fk_elureg_ref_18840_typman FOREIGN KEY (typmancod) REFERENCES typman(typmancod);


--
-- Name: fk_elusen_mandpt_dpt; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY elusen
    ADD CONSTRAINT fk_elusen_mandpt_dpt FOREIGN KEY (dptnum) REFERENCES dpt(dptnum);


--
-- Name: fk_elusen_ref_18837_etadebma; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY elusen
    ADD CONSTRAINT fk_elusen_ref_18837_etadebma FOREIGN KEY (etadebmancod) REFERENCES etadebman(etadebmancod);


--
-- Name: fk_elusen_ref_18837_etafinma; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY elusen
    ADD CONSTRAINT fk_elusen_ref_18837_etafinma FOREIGN KEY (etafinmancod) REFERENCES etafinman(etafinmancod);


--
-- Name: fk_elusen_ref_18837_sen; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY elusen
    ADD CONSTRAINT fk_elusen_ref_18837_sen FOREIGN KEY (senmat) REFERENCES sen(senmat);


--
-- Name: fk_elusen_ref_18837_temval; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY elusen
    ADD CONSTRAINT fk_elusen_ref_18837_temval FOREIGN KEY (temvalcod) REFERENCES temval(temvalcod);


--
-- Name: fk_elusen_ref_18837_typman; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY elusen
    ADD CONSTRAINT fk_elusen_ref_18837_typman FOREIGN KEY (typmancod) REFERENCES typman(typmancod);


--
-- Name: fk_eluter_manasster_asster; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY eluter
    ADD CONSTRAINT fk_eluter_manasster_asster FOREIGN KEY (asstercod) REFERENCES asster(asstercod);


--
-- Name: fk_eluter_ref_18843_sen; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY eluter
    ADD CONSTRAINT fk_eluter_ref_18843_sen FOREIGN KEY (senmat) REFERENCES sen(senmat);


--
-- Name: fk_eluter_ref_18844_temval; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY eluter
    ADD CONSTRAINT fk_eluter_ref_18844_temval FOREIGN KEY (temvalcod) REFERENCES temval(temvalcod);


--
-- Name: fk_eluter_ref_18844_typman; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY eluter
    ADD CONSTRAINT fk_eluter_ref_18844_typman FOREIGN KEY (typmancod) REFERENCES typman(typmancod);


--
-- Name: fk_elutit_ref_11621_temval; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY elutit
    ADD CONSTRAINT fk_elutit_ref_11621_temval FOREIGN KEY (temvalcod) REFERENCES temval(temvalcod);


--
-- Name: fk_eluvil_ref_18838_sen; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY eluvil
    ADD CONSTRAINT fk_eluvil_ref_18838_sen FOREIGN KEY (senmat) REFERENCES sen(senmat);


--
-- Name: fk_eluvil_ref_18838_temval; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY eluvil
    ADD CONSTRAINT fk_eluvil_ref_18838_temval FOREIGN KEY (temvalcod) REFERENCES temval(temvalcod);


--
-- Name: fk_eluvil_ref_18838_typman; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY eluvil
    ADD CONSTRAINT fk_eluvil_ref_18838_typman FOREIGN KEY (typmancod) REFERENCES typman(typmancod);


--
-- Name: fk_fonact_participant; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY activite_participant
    ADD CONSTRAINT fk_fonact_participant FOREIGN KEY (fapcod) REFERENCES fonact_participant(fapcod);


--
-- Name: fk_fonmemco_fonmemcom_foncom; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY fonmemcom
    ADD CONSTRAINT fk_fonmemco_fonmemcom_foncom FOREIGN KEY (foncomcod) REFERENCES foncom(foncomcod);


--
-- Name: fk_fonmemco_memcomfon_memcom; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY fonmemcom
    ADD CONSTRAINT fk_fonmemco_memcomfon_memcom FOREIGN KEY (memcomid) REFERENCES memcom(memcomid) ON DELETE CASCADE;


--
-- Name: fk_fonmemco_ref_11620_temval; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY fonmemcom
    ADD CONSTRAINT fk_fonmemco_ref_11620_temval FOREIGN KEY (temvalcod) REFERENCES temval(temvalcod);


--
-- Name: fk_fonmemde_fondelmem_fondeleg; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY fonmemdelega
    ADD CONSTRAINT fk_fonmemde_fondelmem_fondeleg FOREIGN KEY (fondelcod) REFERENCES fondelega(fondelcod);


--
-- Name: fk_fonmemde_memdelfon_memdeleg; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY fonmemdelega
    ADD CONSTRAINT fk_fonmemde_memdelfon_memdeleg FOREIGN KEY (memdelegaid) REFERENCES memdelega(memdelegaid) ON DELETE CASCADE;


--
-- Name: fk_fonmemde_ref_11620_temval; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY fonmemdelega
    ADD CONSTRAINT fk_fonmemde_ref_11620_temval FOREIGN KEY (temvalcod) REFERENCES temval(temvalcod);


--
-- Name: fk_fonmemgr_fongrppol_fongrppo; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY fonmemgrppol
    ADD CONSTRAINT fk_fonmemgr_fongrppol_fongrppo FOREIGN KEY (fongrppolcod) REFERENCES fongrppol(fongrppolcod);


--
-- Name: fk_fonmemgr_fongrpsen_fongrpse; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY fonmemgrpsen
    ADD CONSTRAINT fk_fonmemgr_fongrpsen_fongrpse FOREIGN KEY (fongrpsencod) REFERENCES fongrpsen(fongrpsencod);


--
-- Name: fk_fonmemgr_memgrppol_memgrppo; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY fonmemgrppol
    ADD CONSTRAINT fk_fonmemgr_memgrppol_memgrppo FOREIGN KEY (memgrppolid) REFERENCES memgrppol(memgrppolid) ON DELETE CASCADE;


--
-- Name: fk_fonmemgr_memgrpsen_memgrpse; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY fonmemgrpsen
    ADD CONSTRAINT fk_fonmemgr_memgrpsen_memgrpse FOREIGN KEY (memgrpsenid) REFERENCES memgrpsen(memgrpsenid) ON DELETE CASCADE;


--
-- Name: fk_fonmemgr_ref_11620_temval; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY fonmemgrppol
    ADD CONSTRAINT fk_fonmemgr_ref_11620_temval FOREIGN KEY (temvalcod) REFERENCES temval(temvalcod);


--
-- Name: fk_fonmemgr_ref_11621_temval; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY fonmemgrpsen
    ADD CONSTRAINT fk_fonmemgr_ref_11621_temval FOREIGN KEY (temvalcod) REFERENCES temval(temvalcod);


--
-- Name: fk_fonmemor_fonorgmem_fonorg; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY fonmemorg
    ADD CONSTRAINT fk_fonmemor_fonorgmem_fonorg FOREIGN KEY (fonorgcod) REFERENCES fonorg(fonorgcod);


--
-- Name: fk_fonmemor_memorgfon_memorg; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY fonmemorg
    ADD CONSTRAINT fk_fonmemor_memorgfon_memorg FOREIGN KEY (memorgid) REFERENCES memorg(memorgid) ON DELETE CASCADE;


--
-- Name: fk_fonmemor_temval_temval; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY fonmemorg
    ADD CONSTRAINT fk_fonmemor_temval_temval FOREIGN KEY (temvalcod) REFERENCES temval(temvalcod);


--
-- Name: fk_grppol_assoc_384_org; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY grppol
    ADD CONSTRAINT fk_grppol_assoc_384_org FOREIGN KEY (typorgcod) REFERENCES typorg(typorgcod);


--
-- Name: fk_grppol_ref_11621_temval; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY grppol
    ADD CONSTRAINT fk_grppol_ref_11621_temval FOREIGN KEY (temvalcod) REFERENCES temval(temvalcod);


--
-- Name: fk_grpsenam_grpsenami_temval; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY grpsenami
    ADD CONSTRAINT fk_grpsenam_grpsenami_temval FOREIGN KEY (temvalcod) REFERENCES temval(temvalcod);


--
-- Name: fk_grpsenam_grpsencom_com; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY grpsenami
    ADD CONSTRAINT fk_grpsenam_grpsencom_com FOREIGN KEY (comorgcod) REFERENCES com(orgcod);


--
-- Name: fk_grpsenam_section_grpsenam; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY grpsenami
    ADD CONSTRAINT fk_grpsenam_section_grpsenam FOREIGN KEY (scnorgcod) REFERENCES grpsenami(orgcod);


--
-- Name: fk_grpsenam_typgrpsen_typgrpse; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY grpsenami
    ADD CONSTRAINT fk_grpsenam_typgrpsen_typgrpse FOREIGN KEY (typgrpsencod) REFERENCES typgrpsen(typgrpsencod);


--
-- Name: fk_grpsenami_typorg_typorg; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY grpsenami
    ADD CONSTRAINT fk_grpsenami_typorg_typorg FOREIGN KEY (typorgcod) REFERENCES typorg(typorgcod);


--
-- Name: fk_libcom_libcom_com; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY libcom
    ADD CONSTRAINT fk_libcom_libcom_com FOREIGN KEY (orgcod) REFERENCES com(orgcod);


--
-- Name: fk_libcom_temval_temval; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY libcom
    ADD CONSTRAINT fk_libcom_temval_temval FOREIGN KEY (temvalcod) REFERENCES temval(temvalcod);


--
-- Name: fk_libdeleg_libdelega_delega; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY libdelega
    ADD CONSTRAINT fk_libdeleg_libdelega_delega FOREIGN KEY (orgcod) REFERENCES delega(orgcod);


--
-- Name: fk_libdeleg_temval_temval; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY libdelega
    ADD CONSTRAINT fk_libdeleg_temval_temval FOREIGN KEY (temvalcod) REFERENCES temval(temvalcod);


--
-- Name: fk_libgrppo_libgrppol_grppol; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY libgrppol
    ADD CONSTRAINT fk_libgrppo_libgrppol_grppol FOREIGN KEY (grppolcod) REFERENCES grppol(grppolcod) ON DELETE CASCADE;


--
-- Name: fk_libgrppo_ref_11621_temval; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY libgrppol
    ADD CONSTRAINT fk_libgrppo_ref_11621_temval FOREIGN KEY (temvalcod) REFERENCES temval(temvalcod);


--
-- Name: fk_libgrpse_libgrpsen_grpsenam; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY libgrpsen
    ADD CONSTRAINT fk_libgrpse_libgrpsen_grpsenam FOREIGN KEY (orgcod) REFERENCES grpsenami(orgcod);


--
-- Name: fk_liborg_liborg_org; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY liborg
    ADD CONSTRAINT fk_liborg_liborg_org FOREIGN KEY (orgcod) REFERENCES org(orgcod);


--
-- Name: fk_liborg_temval_temval; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY liborg
    ADD CONSTRAINT fk_liborg_temval_temval FOREIGN KEY (temvalcod) REFERENCES temval(temvalcod);


--
-- Name: fk_mel_poiconmel_poicon; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY mel
    ADD CONSTRAINT fk_mel_poiconmel_poicon FOREIGN KEY (poiconid) REFERENCES poicon(poiconid);


--
-- Name: fk_memcom_com_com; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY memcom
    ADD CONSTRAINT fk_memcom_com_com FOREIGN KEY (orgcod) REFERENCES com(orgcod);


--
-- Name: fk_memcom_memcom_sen; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY memcom
    ADD CONSTRAINT fk_memcom_memcom_sen FOREIGN KEY (senmat) REFERENCES sen(senmat);


--
-- Name: fk_memcom_ref_11620_temval; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY memcom
    ADD CONSTRAINT fk_memcom_ref_11620_temval FOREIGN KEY (temvalcod) REFERENCES temval(temvalcod);


--
-- Name: fk_memdeleg_designmem_designor; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY memdelega
    ADD CONSTRAINT fk_memdeleg_designmem_designor FOREIGN KEY (designcod) REFERENCES designorg(designcod);


--
-- Name: fk_memdeleg_ratdelega_delega; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY memdelega
    ADD CONSTRAINT fk_memdeleg_ratdelega_delega FOREIGN KEY (orgcod) REFERENCES delega(orgcod);


--
-- Name: fk_memdeleg_ref_11620_temval; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY memdelega
    ADD CONSTRAINT fk_memdeleg_ref_11620_temval FOREIGN KEY (temvalcod) REFERENCES temval(temvalcod);


--
-- Name: fk_memdeleg_sendelega_sen; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY memdelega
    ADD CONSTRAINT fk_memdeleg_sendelega_sen FOREIGN KEY (senmat) REFERENCES sen(senmat);


--
-- Name: fk_memextpa_design_design; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY memextpar
    ADD CONSTRAINT fk_memextpa_design_design FOREIGN KEY (designcod) REFERENCES design(designcod);


--
-- Name: fk_memextpa_nmiorgext_orgext; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY memextpar
    ADD CONSTRAINT fk_memextpa_nmiorgext_orgext FOREIGN KEY (orgcod) REFERENCES orgext(orgcod);


--
-- Name: fk_memextpa_ref_11620_temval; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY memextpar
    ADD CONSTRAINT fk_memextpa_ref_11620_temval FOREIGN KEY (temvalcod) REFERENCES temval(temvalcod);


--
-- Name: fk_memextpa_sennomina_sen; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY memextpar
    ADD CONSTRAINT fk_memextpa_sennomina_sen FOREIGN KEY (senmat) REFERENCES sen(senmat);


--
-- Name: fk_memgrppo_grppol_grppol; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY memgrppol
    ADD CONSTRAINT fk_memgrppo_grppol_grppol FOREIGN KEY (grppolcod) REFERENCES grppol(grppolcod);


--
-- Name: fk_memgrppo_memgrppol_sen; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY memgrppol
    ADD CONSTRAINT fk_memgrppo_memgrppol_sen FOREIGN KEY (senmat) REFERENCES sen(senmat);


--
-- Name: fk_memgrppo_ref_11620_temval; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY memgrppol
    ADD CONSTRAINT fk_memgrppo_ref_11620_temval FOREIGN KEY (temvalcod) REFERENCES temval(temvalcod);


--
-- Name: fk_memgrppo_typapppol_typapppo; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY memgrppol
    ADD CONSTRAINT fk_memgrppo_typapppol_typapppo FOREIGN KEY (typapppolcod) REFERENCES typapppol(typapppolcod);


--
-- Name: fk_memgrpse_grpsen_grpsenam; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY memgrpsen
    ADD CONSTRAINT fk_memgrpse_grpsen_grpsenam FOREIGN KEY (orgcod) REFERENCES grpsenami(orgcod);


--
-- Name: fk_memgrpse_memgrpsen_sen; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY memgrpsen
    ADD CONSTRAINT fk_memgrpse_memgrpsen_sen FOREIGN KEY (senmat) REFERENCES sen(senmat);


--
-- Name: fk_memgrpse_ref_11621_temval; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY memgrpsen
    ADD CONSTRAINT fk_memgrpse_ref_11621_temval FOREIGN KEY (temvalcod) REFERENCES temval(temvalcod);


--
-- Name: fk_memorg_designmem_designor; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY memorg
    ADD CONSTRAINT fk_memorg_designmem_designor FOREIGN KEY (designcod) REFERENCES designorg(designcod);


--
-- Name: fk_memorg_memorg_sen; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY memorg
    ADD CONSTRAINT fk_memorg_memorg_sen FOREIGN KEY (senmat) REFERENCES sen(senmat);


--
-- Name: fk_memorg_memorgorg_org; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY memorg
    ADD CONSTRAINT fk_memorg_memorgorg_org FOREIGN KEY (orgcod) REFERENCES org(orgcod);


--
-- Name: fk_memorg_ref_24223_temval; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY memorg
    ADD CONSTRAINT fk_memorg_ref_24223_temval FOREIGN KEY (temvalcod) REFERENCES temval(temvalcod);


--
-- Name: fk_minind_poicon; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY minind
    ADD CONSTRAINT fk_minind_poicon FOREIGN KEY (poicon) REFERENCES poicon(poiconid);


--
-- Name: fk_minind_ref_11621_temval; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY minind
    ADD CONSTRAINT fk_minind_ref_11621_temval FOREIGN KEY (temvalcod) REFERENCES temval(temvalcod);


--
-- Name: fk_minind_senmin_sen; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY minind
    ADD CONSTRAINT fk_minind_senmin_sen FOREIGN KEY (senmat) REFERENCES sen(senmat);


--
-- Name: fk_mismin_mismin_minind; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY mismin
    ADD CONSTRAINT fk_mismin_mismin_minind FOREIGN KEY (minid) REFERENCES minind(minid);


--
-- Name: fk_missen_missen_sen; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY missen
    ADD CONSTRAINT fk_missen_missen_sen FOREIGN KEY (senmat) REFERENCES sen(senmat);


--
-- Name: fk_moddes_temval_temval; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY moddes
    ADD CONSTRAINT fk_moddes_temval_temval FOREIGN KEY (temvalcod) REFERENCES temval(temvalcod);


--
-- Name: fk_nation_natzongeo_zongeo; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY nation
    ADD CONSTRAINT fk_nation_natzongeo_zongeo FOREIGN KEY (zongeocod) REFERENCES zongeo(zongeocod);


--
-- Name: fk_nationgr_grpsennat_grpsenam; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY nationgrpsen
    ADD CONSTRAINT fk_nationgr_grpsennat_grpsenam FOREIGN KEY (orgcod) REFERENCES grpsenami(orgcod);


--
-- Name: fk_nationgr_natgrpsen_nation; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY nationgrpsen
    ADD CONSTRAINT fk_nationgr_natgrpsen_nation FOREIGN KEY (nationcod) REFERENCES nation(nationcod);


--
-- Name: fk_nationgr_ref_11622_temval; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY nationgrpsen
    ADD CONSTRAINT fk_nationgr_ref_11622_temval FOREIGN KEY (temvalcod) REFERENCES temval(temvalcod);


--
-- Name: fk_org_ref_16200_temval; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY org
    ADD CONSTRAINT fk_org_ref_16200_temval FOREIGN KEY (temvalcod) REFERENCES temval(temvalcod);


--
-- Name: fk_org_typorg_typorg; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY org
    ADD CONSTRAINT fk_org_typorg_typorg FOREIGN KEY (typorgcod) REFERENCES typorg(typorgcod);


--
-- Name: fk_orgext_orgext_te_temval; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY orgext
    ADD CONSTRAINT fk_orgext_orgext_te_temval FOREIGN KEY (temvalcod) REFERENCES temval(temvalcod);


--
-- Name: fk_orgext_stajur_typstaju; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY orgext
    ADD CONSTRAINT fk_orgext_stajur_typstaju FOREIGN KEY (stajurcod) REFERENCES stajur(stajurcod);


--
-- Name: fk_orgext_typorg_typorg; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY orgext
    ADD CONSTRAINT fk_orgext_typorg_typorg FOREIGN KEY (typorgcod) REFERENCES typorg(typorgcod);


--
-- Name: fk_orgthe_associati_orgext; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY orgthe
    ADD CONSTRAINT fk_orgthe_associati_orgext FOREIGN KEY (orgcod) REFERENCES orgext(orgcod);


--
-- Name: fk_pcs24_pcs24pcs8_pcs8; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY pcs24
    ADD CONSTRAINT fk_pcs24_pcs24pcs8_pcs8 FOREIGN KEY (pcs8cod) REFERENCES pcs8(pcs8cod);


--
-- Name: fk_pcs42_pcs42pcs2_pcs24; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY pcs42
    ADD CONSTRAINT fk_pcs42_pcs42pcs2_pcs24 FOREIGN KEY (pcs24cod) REFERENCES pcs24(pcs24cod);


--
-- Name: fk_pcs_pcspcs42_pcs42; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY pcs
    ADD CONSTRAINT fk_pcs_pcspcs42_pcs42 FOREIGN KEY (pcs42cod) REFERENCES pcs42(pcs42cod);


--
-- Name: fk_pcscatpr_associati_pcs; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY pcscatpro
    ADD CONSTRAINT fk_pcscatpr_associati_pcs FOREIGN KEY (pcscod) REFERENCES pcs(pcscod);


--
-- Name: fk_poicon_point_de__sen; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY poicon
    ADD CONSTRAINT fk_poicon_point_de__sen FOREIGN KEY (senmat) REFERENCES sen(senmat);


--
-- Name: fk_reg_regterrit_territ; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY reg
    ADD CONSTRAINT fk_reg_regterrit_territ FOREIGN KEY (territcod) REFERENCES territ(territcod);


--
-- Name: fk_reg_remplacep_reg; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY reg
    ADD CONSTRAINT fk_reg_remplacep_reg FOREIGN KEY (regcodrpl) REFERENCES reg(regcod);


--
-- Name: fk_sen_com; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY sen
    ADD CONSTRAINT fk_sen_com FOREIGN KEY (sencomcodcou) REFERENCES com(orgcod);


--
-- Name: fk_sen_grppol; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY sen
    ADD CONSTRAINT fk_sen_grppol FOREIGN KEY (sengrppolcodcou) REFERENCES grppol(grppolcod);


--
-- Name: fk_sen_pro_pcs; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY sen
    ADD CONSTRAINT fk_sen_pro_pcs FOREIGN KEY (pcscod) REFERENCES pcs(pcscod);


--
-- Name: fk_sen_ref_11633_qua; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY sen
    ADD CONSTRAINT fk_sen_ref_11633_qua FOREIGN KEY (quacod) REFERENCES qua(quacod);


--
-- Name: fk_sen_sencirnum_dpt; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY sen
    ADD CONSTRAINT fk_sen_sencirnum_dpt FOREIGN KEY (sencirnumcou) REFERENCES dpt(dptnum);


--
-- Name: fk_sen_seneta_etasen; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY sen
    ADD CONSTRAINT fk_sen_seneta_etasen FOREIGN KEY (etasencod) REFERENCES etasen(etasencod);


--
-- Name: fk_senbur_bursenbur_bur; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY senbur
    ADD CONSTRAINT fk_senbur_bursenbur_bur FOREIGN KEY (burcod) REFERENCES bur(burcod);


--
-- Name: fk_senbur_ref_11620_temval; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY senbur
    ADD CONSTRAINT fk_senbur_ref_11620_temval FOREIGN KEY (temvalcod) REFERENCES temval(temvalcod);


--
-- Name: fk_senbur_sensenbur_sen; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY senbur
    ADD CONSTRAINT fk_senbur_sensenbur_sen FOREIGN KEY (senmat) REFERENCES sen(senmat);


--
-- Name: fk_sennom_qualite_qua; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY sennom
    ADD CONSTRAINT fk_sennom_qualite_qua FOREIGN KEY (quacod) REFERENCES qua(quacod);


--
-- Name: fk_sennom_sennom_sen; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY sennom
    ADD CONSTRAINT fk_sennom_sennom_sen FOREIGN KEY (senmat) REFERENCES sen(senmat);


--
-- Name: fk_senurl_senurl_sen; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY senurl
    ADD CONSTRAINT fk_senurl_senurl_sen FOREIGN KEY (senmat) REFERENCES sen(senmat);


--
-- Name: fk_senurl_temval_temval; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY senurl
    ADD CONSTRAINT fk_senurl_temval_temval FOREIGN KEY (temvalcod) REFERENCES temval(temvalcod);


--
-- Name: fk_senurl_typurlsen_typurl; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY senurl
    ADD CONSTRAINT fk_senurl_typurlsen_typurl FOREIGN KEY (typurlcod) REFERENCES typurl(typurlcod);


--
-- Name: fk_telephon_poicontel_poicon; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY telephone
    ADD CONSTRAINT fk_telephon_poicontel_poicon FOREIGN KEY (poiconid) REFERENCES poicon(poiconid);


--
-- Name: fk_titele_titeletyp_typman; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY titele
    ADD CONSTRAINT fk_titele_titeletyp_typman FOREIGN KEY (typmancod) REFERENCES typman(typmancod);


--
-- Name: fk_type_categorie_categorie; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY type_categorie
    ADD CONSTRAINT fk_type_categorie_categorie FOREIGN KEY (catactcod) REFERENCES categorie_activite(catactcod);


--
-- Name: fk_type_categorie_type; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY type_categorie
    ADD CONSTRAINT fk_type_categorie_type FOREIGN KEY (typactcod) REFERENCES type_activite(typactcod);


--
-- Name: fk_typgrpse_temval_temval; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY typgrpsen
    ADD CONSTRAINT fk_typgrpse_temval_temval FOREIGN KEY (temvalcod) REFERENCES temval(temvalcod);


--
-- Name: fk_typurl_temval_temval; Type: FK CONSTRAINT; Schema: public; Owner: opendata
--

ALTER TABLE ONLY typurl
    ADD CONSTRAINT fk_typurl_temval_temval FOREIGN KEY (temvalcod) REFERENCES temval(temvalcod);


--
-- Name: public; Type: ACL; Schema: -; Owner: postgres
--

REVOKE ALL ON SCHEMA public FROM PUBLIC;
REVOKE ALL ON SCHEMA public FROM postgres;
GRANT ALL ON SCHEMA public TO postgres;
GRANT ALL ON SCHEMA public TO PUBLIC;


--
-- PostgreSQL database dump complete
--

